(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  49221442,    1378447]*)
(*NotebookOutlinePosition[  49916555,    1391980]*)
(*  CellTagsIndexPosition[  49909984,    1391784]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Advanced Optica",
    FontSlant->"Italic"],
  " Guide"
}], "Section",
  CellTags->{
  "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
    "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
    "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],

Cell[TextData[ButtonBox["1. Introduction",
  ButtonData:>"1",
  ButtonStyle->"Hyperlink"]], "Outline1",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->"AOG0."],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["2. Symbolic Calculations",
  ButtonData:>"2",
  ButtonStyle->"Hyperlink"]], "Outline1",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG2.", "AOG0.", "AOG2.1", "AOG2.2", "AOG2.3"}],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["2.1 Overview",
  ButtonData:>"2.1",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG2.", "AOG2.1", "AOG0."}],

Cell[TextData[{
  ButtonBox["Introduction",
    ButtonData:>"2.1.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["How to Enter Symbolic Parameters",
    ButtonData:>"2.1.2",
    ButtonStyle->"Hyperlink"],
  StyleBox["\n",
    FontSlant->"Italic"],
  ButtonBox["How SymbolicTrace works",
    ButtonData:>"2.1.3",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Light sources and SymbolicTrace",
    ButtonData:>"2.1.4",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Options of SymbolicTrace",
    ButtonData:>"2.1.5",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Working with SymbolicTrace",
    ButtonData:>"2.1.6",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Multiple Light Paths",
    ButtonData:>"2.1.7",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Infinite Precision Calculations",
    ButtonData:>"2.1.8",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG2.", "AOG2.1", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["2.2 Symbolic Optimization",
  ButtonData:>"2.2",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG2.", "AOG2.2", "AOG0."}],

Cell[TextData[{
  ButtonBox["Infinite-Conjugate Spherical Lens Design",
    ButtonData:>"2.2.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Finite-Conjugate Spherical Lens Design",
    ButtonData:>"2.2.2",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Doublet Lens Design",
    ButtonData:>"2.2.3",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG2.", "AOG2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["2.3 Geometric Intensity Analysis",
  ButtonData:>"2.3",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0."}],

Cell[TextData[{
  ButtonBox["Set-up System",
    ButtonData:>"2.3.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Preliminary Characterization",
    ButtonData:>"2.3.2",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Inverse Position",
    ButtonData:>"2.3.3",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Geometric Intensity Analysis",
    ButtonData:>"2.3.4",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["3. ABCD Matrix Calculations",
  ButtonData:>"3",
  ButtonStyle->"Hyperlink"]], "Outline1",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG3.", "AOG0.", "AOG3.3"}],

Cell[TextData[{
  ButtonBox["3.1 Overview",
    ButtonData:>"3.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["3.2 SphericalMirror Examples",
    ButtonData:>"3.2",
    ButtonStyle->"Hyperlink"]
}], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG3.", "AOG0."}],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["3.3 PlanoConvexLens Examples",
  ButtonData:>"3.3",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG3.", "AOG0.", "AOG3.3"}],

Cell[TextData[{
  ButtonBox["Simple lens",
    ButtonData:>"3.3.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Off-axis lens",
    ButtonData:>"3.3.2",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Cylindrical lens",
    ButtonData:>"3.3.3",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG0.", "AOG3.3"}]
}, Open  ]],

Cell[TextData[{
  ButtonBox["3.4 SphericalLens Examples",
    ButtonData:>"3.4",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["3.5 ThinLens, and Custom ABCD Input",
    ButtonData:>"3.5",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["3.6 Grating Examples",
    ButtonData:>"3.6",
    ButtonStyle->"Hyperlink"]
}], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG3.", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4. Gaussian Beam Calculations",
  ButtonData:>"4",
  ButtonStyle->"Hyperlink"]], "Outline1",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{
  "AOG4.", "AOG0.", "AOG4.1", "AOG4.2", "AOG4.3", "AOG4.4", "AOG4.5", 
    "AOG4.6"}],

Cell[TextData[ButtonBox["4.1 Overview",
  ButtonData:>"4.1",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG4.", "AOG0."}],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.2 Reflected Lens Example",
  ButtonData:>"4.2",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG4.", "AOG0.", "AOG4.2"}],

Cell[TextData[{
  ButtonBox["Set-up",
    ButtonData:>"4.2.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["GaussianTrace",
    ButtonData:>"4.2.2",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["GaussianPlot",
    ButtonData:>"4.2.3",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["ShowGaussian",
    ButtonData:>"4.2.4",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG4.2", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.3 Reflected ThickLens Example",
  ButtonData:>"4.3",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG4.", "AOG0.", "AOG4.3"}],

Cell[TextData[{
  ButtonBox["Set-up",
    ButtonData:>"4.3.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["GaussianTrace",
    ButtonData:>"4.3.2",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["GaussianPlot",
    ButtonData:>"4.3.3",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["ShowGaussian",
    ButtonData:>"4.4.4",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG4.3", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.4 Off-Axis Beam Example",
  ButtonData:>"4.4",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG4.", "AOG0.", "AOG4.4"}],

Cell[TextData[{
  ButtonBox["Set-up",
    ButtonData:>"4.4.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["GaussianTrace",
    ButtonData:>"4.4.2",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["GaussianPlot",
    ButtonData:>"4.4.3",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["ShowGaussian",
    ButtonData:>"4.4.4",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG4.4", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.5 CylindricalLens Example",
  ButtonData:>"4.5",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG4.", "AOG0.", "AOG4.5"}],

Cell[TextData[{
  ButtonBox["Set-up",
    ButtonData:>"4.5.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["GaussianTrace",
    ButtonData:>"4.5.2",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["GaussianPlot",
    ButtonData:>"4.5.3",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["ShowGaussian",
    ButtonData:>"4.5.4",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG4.5", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["4.6 Prism-Lens Example",
  ButtonData:>"4.6",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG4.", "AOG0.", "AOG4.6"}],

Cell[TextData[{
  ButtonBox["Set-up",
    ButtonData:>"4.6.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["GaussianTrace",
    ButtonData:>"4.6.2",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["GaussianPlot",
    ButtonData:>"4.6.3",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["ShowGaussian",
    ButtonData:>"4.6.4",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG4.6", "AOG4."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["5. Imaging Calculations",
  ButtonData:>"5",
  ButtonStyle->"Hyperlink"]], "Outline1",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG5.", "AOG0."}],

Cell[TextData[{
  ButtonBox["5.1 Overview",
    ButtonData:>"5.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["5.2 FindLensParameters",
    ButtonData:>"5.2",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["5.3 PupilFunction",
    ButtonData:>"5.3",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["5.4 Zernike Polynomials and Seidel Aberrations",
    ButtonData:>"5.4",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["5.5 PointSpreadFunction",
    ButtonData:>"5.5",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["5.6 OpticalTransferFunction",
    ButtonData:>"5.6",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["5.7 GeometricPointSpreadFunction",
    ButtonData:>"5.7",
    ButtonStyle->"Hyperlink"]
}], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG5.", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["6. Interference and Wavefront Calculations",
  ButtonData:>"6",
  ButtonStyle->"Hyperlink"]], "Outline1",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG6.", "AOG0.", "AOG6.2", "AOG6.3", "AOG6.4"}],

Cell[TextData[ButtonBox["6.1 Overview",
  ButtonData:>"6.1",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG6.", "AOG0."}],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["6.2 One-Dimensional Wavefronts",
  ButtonData:>"6.2",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG6.", "AOG0.", "AOG6.2"}],

Cell[TextData[{
  ButtonBox["Example 1",
    ButtonData:>"6.2.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Example 2",
    ButtonData:>"6.2.2",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Example 3",
    ButtonData:>"6.2.3",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Example 4",
    ButtonData:>"6.2.4",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Example 5",
    ButtonData:>"6.2.5",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["6.3 Two-Dimensional Wavefronts",
  ButtonData:>"6.3",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG6.", "AOG0.", "AOG6.3"}],

Cell[TextData[{
  ButtonBox["Example 1",
    ButtonData:>"6.3.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Example 2",
    ButtonData:>"6.3.2",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Example 3",
    ButtonData:>"6.3.3",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["6.4 Wavefront Propagation with Gaussian Wavelets",
  ButtonData:>"6.4",
  ButtonStyle->"Hyperlink"]], "Outline2",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG6.", "AOG6.4", "AOG0."}],

Cell[TextData[{
  ButtonBox["Introduction to Wavelet Analysis",
    ButtonData:>"6.4.1",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Define LineOfWavelets",
    ButtonData:>"6.4.2",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Define FindField",
    ButtonData:>"6.4.3",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Collimated Beam of Wavelets",
    ButtonData:>"6.4.4",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["One Wavelet with Lens",
    ButtonData:>"6.4.5",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Two Wavelets with Lens",
    ButtonData:>"6.4.6",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Three Wavelets with Lens",
    ButtonData:>"6.4.7",
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Wavelet analysis of an Imaging System",
    ButtonData:>"6.4.8",
    ButtonStyle->"Hyperlink"]
}], "Outline3",
  CellMargins->{{Inherited, Inherited}, {2, 2}},
  CellTags->{"AOG6.", "AOG6.4", "AOG0."}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. Introduction", "Section",
  CellTags->{"1", "AOG1.", "AOG0."}],

Cell[TextData[{
  "Welcome to the Advanced ",
  StyleBox["Optica ",
    FontSlant->"Italic"],
  "Guide, the first optical design package to utilize analytic solutions for \
optical systems. With its revolutionary approach to optical design, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " taps into the symbolic powers of ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"]
}], "Text",
  CellTags->{"AOG1.", "AOG0."}],

Cell["\<\
Copyright \[Copyright] 2000-2007 by Optica Software, Urbana Il. All Rights \
Reserved.\
\>", "Text",
  CellTags->{"AOG1.", "AOG0."}],

Cell[CellGroupData[{

Cell["Loading Optica", "Subsubsection",
  CellTags->{"AOG1.", "AOG0."}],

Cell[TextData[{
  StyleBox["Optica",
    FontSlant->"Italic"],
  " is loaded with the following command. "
}], "Text",
  CellTags->{"AOG1.", "AOG0."}],

Cell[CellGroupData[{

Cell["Needs[\"Optica`Optica`\"]", "Input",
  CellLabel->"In[1]:=",
  CellTags->{"AOG1.", "AOG0."}],

Cell["+++++++++++++++++++++++++++++++++", "Print",
  CellLabel->"From In[1]:=",
  CellTags->{"AOG1.", "AOG0."}],

Cell[BoxData[
    \("Optica 3.0 was loaded in 101 s and needs 11264 kilobytes of memory on \
top of 6373 kilobytes already used"\)], "Print",
  CellLabel->"From In[1]:=",
  CellTags->{"AOG1.", "AOG0."}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->"AOG0."]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Symbolic Calculations: SymbolicTrace", "Section",
  CellTags->{"AOG0.", "2", "AOG2."}],

Cell[CellGroupData[{

Cell["2.1 Overview", "Subsection",
  CellTags->{"AOG0.", "2.1", "AOG2.", "AOG2.1"}],

Cell[CellGroupData[{

Cell["Introduction", "Subsubsection",
  CellTags->{"AOG0.", "2.1.1", "AOG2.", "AOG2.1", "AOG2.1.1"}],

Cell[TextData[{
  "The principle function responsible for symbolic calculations is ",
  StyleBox["SymbolicTrace", "Input"],
  ". ",
  StyleBox["SymbolicTrace", "Input"],
  " creates the symbolic solution to an optical system. In its output, ",
  StyleBox["SymbolicTrace", "Input"],
  " returns a host of symbolic parameters in the form of rules.  Each \
parameter has rule name identified with it, and the most important ones are: \
",
  StyleBox["SymbolicRayEnd", "Input"],
  ", ",
  StyleBox["SymbolicRayTilt", "Input"],
  ", ",
  StyleBox["SymbolicIntensity", "Input"],
  ", ",
  StyleBox["SymbolicSurfaceCoordinates", "Input"],
  ", and ",
  StyleBox["SymbolicOpticalLength", "Input"],
  ". Nearly all important functions in the ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " package depend on ",
  StyleBox["SymbolicTrace", "Input"],
  " in some fashion. Functions like ",
  StyleBox["GaussianTrace", "Input",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FindABCDMatrix", "Input"],
  " depend entirely on first order ",
  StyleBox["SymbolicTrace", "Input"],
  " results. Therefore, it is best to first study ",
  StyleBox["SymbolicTrace", "Input"],
  " in order to acquire a good understanding of these two functions. ",
  StyleBox["FindLensParameters", "Input"],
  " uses ",
  StyleBox["SymbolicTrace", "Input"],
  " for pupil calculations and finding paraxial information such as the lens \
principle points, magnification, and the lens focal length. Other functions \
such as ",
  StyleBox["PointSpreadFunction", "Input"],
  " (",
  StyleBox["PSF", "Input"],
  ") and ",
  StyleBox["OpticalTransferFunction", "Input"],
  " (",
  StyleBox["MTF", "Input"],
  ") use ",
  StyleBox["SymbolicTrace", "Input"],
  " indirectly through ",
  StyleBox["FindLensParameters", "Input"],
  ". However, it is not necessary to study ",
  StyleBox["SymbolicTrace", "Input"],
  " before learning about these latter functions."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.1"}],

Cell[CellGroupData[{

Cell["?SymbolicTrace", "Input",
  CellLabel->"In[2]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.1"}],

Cell[BoxData[
    \("SymbolicTrace[opticalsystem, assumptions, options] is a function that \
finds the symbolic solution of one or more light sources passing through \
optical system.\n\nSymbolicTrace can also take the symbolic Taylor-series \
expansion of one or more specified parameters, as given in assumptions, in \
order to reduce the overall complexity of the resulting solution."\)], "Print",\

  CellTags->{
  "Info3312042809-6749329", "AOG2.", "AOG2.1", "AOG2.1.1", "AOG0."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["How to Enter Symbolic Parameters", "Subsubsection",
  CellTags->{"AOG0.", "2.1.2", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[TextData[{
  "The basic ",
  StyleBox["Ray",
    FontSlant->"Italic"],
  "ica system permits symbolic entry of most system parameters. These \
parameters may then be used to construct symbolic variables within the \
system. In many cases, the symbolic parameter \"piggy-backs\" together with a \
numerical value in the form of an ordered list. In general, ",
  StyleBox["Ray",
    FontSlant->"Italic"],
  "ica requires that all symbolic parameters are also accompanied by a \
numerical value. Here is an example of symbolic parameter entry within ",
  StyleBox["PlanoConvexLens", "Input"],
  "."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{

Cell["symbolicLens = PlanoConvexLens[{f,100},{a,50},{t,10}]", "Input",
  CellLabel->"In[3]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[BoxData[
    TagBox[
      StyleBox[
        TagBox[\(PlanoConvexLens[{f, 100}, {a, 50}, {t, 10}]\),
          HoldForm],
        FontColor->RGBColor[0, 0.392187, 0]],
      DisplayForm]], "Output",
  CellLabel->"Out[3]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],

Cell[TextData[{
  "In other cases, the symbolic parameter is given in the form of an option. \
This occurs in particular for numerical option parameters. However, in this \
case, the symbolic value does not piggy-back with the numeric option, but \
instead gets its own option name that is prefixed with the word \"",
  StyleBox["Symbolic", "Input"],
  "\" in front of the corresponding numerical option name.  Two such options \
are ",
  StyleBox["SymbolicWaveLength", "Input"],
  " and ",
  StyleBox["SymbolicIntensity", "Input"],
  ". An exception is ",
  StyleBox["NumberOfRays", "Input"],
  ", which must be a numeric at all times."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{

Cell[TextData[{
  "symbolicSource = LineOfRays[40, SymbolicWaveLength->\[Lambda], \
SymbolicIntensity->i, ",
  StyleBox["NumberOfRays", "Input"],
  "->4]"
}], "Input",
  CellLabel->"In[4]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[BoxData[
    TagBox[
      StyleBox[
        TagBox[\(LineOfRays[40, NumberOfRays \[Rule] 4, 
            SymbolicIntensity \[Rule] i, 
            SymbolicWaveLength \[Rule] \[Lambda]]\),
          HoldForm],
        FontColor->RGBColor[0, 0.392187, 0]],
      DisplayForm]], "Output",
  CellLabel->"Out[4]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],

Cell[TextData[{
  "Most types of light source functions cannot accept symbolic values for its \
built-in parameters. The ",
  StyleBox["LineOfRays", "Input"],
  " source given above is one such example. Here, the ",
  StyleBox["linewidth",
    FontSlant->"Italic"],
  " parameter must be a numeric value. In error message is generated \
otherwise."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{

Cell["LineOfRays[{s,10}]", "Input",
  CellLabel->"In[5]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[BoxData[
    \(Source::"symbolic" \(\(:\)\(\ \)\) 
      "\!\(LineOfRays\) cannot take symbolic parameters \
\!\(LineOfRays\)."\)], "Message",
  CellLabel->"From In[5]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],

Cell[BoxData[
    \($Aborted\)], "Output",
  CellLabel->"Out[5]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],

Cell[TextData[{
  "An exception is the ",
  StyleBox["GaussianBeam", "Input"],
  " source, which can take direct symbolic parameters."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{

Cell["\<\
symbolicGaussianSource = GaussianBeam[{w,10},{div,.001}, SymbolicWaveLength->\
\[Lambda], NumberOfRays->4]\
\>", "Input",
  CellLabel->"In[6]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[BoxData[
    TagBox[
      StyleBox[
        TagBox[\(GaussianBeam[{w, 10}, {div, 0.001`}, NumberOfRays \[Rule] 4, 
            SymbolicWaveLength \[Rule] \[Lambda]]\),
          HoldForm],
        FontColor->RGBColor[0, 0.392187, 0]],
      DisplayForm]], "Output",
  CellLabel->"Out[6]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Move", "Input"],
  " function accepts symbolic parameters as long as a numeric value is also \
given with each one. Angles may also be specified in a similar fashion. \
Remember, that any angular information will use units of Degrees for ",
  StyleBox["Rayica'",
    FontSlant->"Italic"],
  "s ",
  StyleBox["Move", "Input"],
  " functions. This is in contrast with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built-in trigonometric functions, which takes radians by default."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{

Cell["\<\
symbolicLensSystem = 
\t{Move[LineOfRays[40],{0,{y,0}}],
\tMove[symbolicLens, {d,50}],
\tMove[Screen[50],{x,200},{\[Alpha],10}]}\
\>", "Input",
  CellLabel->"In[7]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox[
            TagBox[\(Move[LineOfRays[40], {0, {y, 0}}]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            
            TagBox[\(Move[
                PlanoConvexLens[{f, 100}, {a, 50}, {t, 10}], {d, 50.`}]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            
            TagBox[\(Move[
                Screen[50], {{x, 200.`}, 0}, {\[Alpha], 
                  10.000000000000002`}]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm]}], "}"}]], "Output",
  CellLabel->"Out[7]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],

Cell[TextData[{
  "Once a system has been defined with symbolic parameters, you can use ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  StyleBox["'s",
    FontSlant->"Italic"],
  " ",
  StyleBox["SymbolicTrace", "Input"],
  " function to calculate the symbolic solution to the optical system."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{

Cell["\<\
TableForm[SymbolicTrace[symbolicLensSystem,{{f>0},{y,0,2}}, \
FinalFormat->False]]\
\>", "Input",
  CellLabel->"In[8]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(SymbolicOpticalLength \[Rule] 
              1.0002694514570802`\ \((d + \(28766183\ y\^2\)\/\(29843208\ \
f\))\) + 1.5194724325673066`\ \((\(-\(\(0.9639105487586991`\ y\^2\)\/f\)\) + 
                      t\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) + \
\(0.2169662417380651`\ y\^2\)\/f\^2)\))\) + \(1.0002694514570802`\ \
\((\(-1.`\)\ d\ f\^2 - 1.`\ f\^2\ t + 1.`\ f\^2\ x - 0.5006610497082115`\ d\ \
y\^2 - 0.5006610497082115`\ t\ y\^2 + 0.5006610497082115`\ x\ y\^2 + f\ \
\((\(-1.0006608313591687`\)\ d - 1.`\ f - 0.3419253127508808`\ t + \
1.0006608313591687`\ x)\)\ y\ Tan[\[Degree]\ \[Alpha]] + \
\((\(-1.0013220994164227`\)\ d - 1.0006608313591687`\ f - 0.3421512677200401`\
\ t + 1.0013220994164227`\ x)\)\ y\^2\ Tan[\[Degree]\ \[Alpha]]\^2)\)\)\/f\^2\
\)},
          {\(SymbolicRayEnd \[Rule] {\(2\ f\^2\ x + f\ \
\((\(-2.0013216627183374`\)\ d - 2.`\ f - 0.6838506255017616`\ t + \
2.0013216627183374`\ x)\)\ y\ Tan[\[Degree]\ \[Alpha]] + \
\((\(-2.0026441988328454`\)\ d - 2.0013216627183374`\ f - 0.6843025354400802`\
\ t + 2.0026441988328454`\ x)\)\ y\^2\ Tan[\[Degree]\ \[Alpha]]\^2\)\/\(2\ \
f\^2\), \(y\ \((f\ \((2.0013216627183374`\ d + 2.`\ f + 0.6838506255017616`\ \
t - 2.0013216627183374`\ x)\) + \((2.0026441988328454`\ d + \
2.0013216627183374`\ f + 0.6843025354400802`\ t - 2.0026441988328454`\ x)\)\ \
y\ Tan[\[Degree]\ \[Alpha]])\)\)\/\(2\ f\^2\), 0}\)},
          {\(SymbolicRayTilt \[Rule] {\(\(1.`\)\(\[InvisibleSpace]\)\) - \
\(0.5006610497082115`\ y\^2\)\/f\^2, \(-\(\(1.0006608313591687`\ y\)\/f\)\), 
                0}\)},
          {\(SymbolicSurfaceCoordinates \[Rule] {\(y\ Sec[\[Degree]\ \
\[Alpha]]\ \((f\ \((2.0013216627183374`\ d + 2.`\ f + 0.6838506255017616`\ t \
- 2.0013216627183374`\ x)\) + \((2.0026441988328454`\ d + 2.0013216627183374`\
\ f + 0.6843025354400802`\ t - 2.0026441988328454`\ x)\)\ y\ Tan[\[Degree]\ \
\[Alpha]])\)\)\/\(2\ f\^2\), 0}\)},
          {\(SymbolicIntensity \[Rule] 
              100\ \[ExponentialE]\^\(\(-\(\(4\ y\^2\)\/a\^2\)\) - \(4\ \((y \
- \(0.6587355186082879`\ t\ y\)\/f)\)\^2\)\/a\^2 - \(y\^2\ Sec[\[Degree]\ \
\[Alpha]]\^2\ \((f\ \((2.0013216627183374`\ d + 2.`\ f + 0.6838506255017616`\ \
t - 2.0013216627183374`\ x)\) + \((2.0026441988328454`\ d + \
2.0013216627183374`\ f + 0.6843025354400802`\ t - 2.0026441988328454`\ x)\)\ \
y\ Tan[\[Degree]\ \[Alpha]])\)\^2\)\/\(2500\ f\^4\)\)\)},
          {\(SymbolicSurfaceBoundary \[Rule] {50, 50}\)},
          {\(SymbolicOffAxis \[Rule] {0, 0}\)},
          {\(SymbolicTranslationVector \[Rule] {x, 0, 0}\)},
          {\(SymbolicRotationMatrix \[Rule] {{Cos[\[Degree]\ \
\[Alpha]]\/\@\(Cos[\[Degree]\ \[Alpha]]\^2 + Sin[\[Degree]\ \[Alpha]]\^2\), 
                  Sin[\[Degree]\ \[Alpha]]\/\@\(Cos[\[Degree]\ \[Alpha]]\^2 + \
Sin[\[Degree]\ \[Alpha]]\^2\), 
                  0}, {\(-\(Sin[\[Degree]\ \[Alpha]]\/\@\(Cos[\[Degree]\ \
\[Alpha]]\^2 + Sin[\[Degree]\ \[Alpha]]\^2\)\)\), 
                  Cos[\[Degree]\ \[Alpha]]\/\@\(Cos[\[Degree]\ \[Alpha]]\^2 + \
Sin[\[Degree]\ \[Alpha]]\^2\), 0}, {0, 0, 1}}\)},
          {\(SymbolicWaveLength \[Rule] 133\/250\)},
          {\(SymbolicSurfaceNormalFunction \[Rule] {1, 0, 0}\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {SymbolicOpticalLength -> Plus[ 
          Times[ 1.0002694514570802, 
            Plus[ d, 
              Times[ 
                Rational[ 28766183, 29843208], 
                Power[ f, -1], 
                Power[ y, 2]]]], 
          Times[ 1.5194724325673066, 
            Plus[ 
              Times[ -0.96391054875869908, 
                Power[ f, -1], 
                Power[ y, 2]], 
              Times[ t, 
                Plus[ 1.0, 
                  Times[ 0.21696624173806511, 
                    Power[ f, -2], 
                    Power[ y, 2]]]]]], 
          Times[ 1.0002694514570802, 
            Power[ f, -2], 
            Plus[ 
              Times[ -1.0, d, 
                Power[ f, 2]], 
              Times[ -1.0, 
                Power[ f, 2], t], 
              Times[ 1.0, 
                Power[ f, 2], x], 
              Times[ -0.50066104970821146, d, 
                Power[ y, 2]], 
              Times[ -0.50066104970821146, t, 
                Power[ y, 2]], 
              Times[ 0.50066104970821146, x, 
                Power[ y, 2]], 
              Times[ f, 
                Plus[ 
                  Times[ -1.0006608313591687, d], 
                  Times[ -1.0, f], 
                  Times[ -0.34192531275088078, t], 
                  Times[ 1.0006608313591687, x]], y, 
                Tan[ 
                  Times[ Degree, \[Alpha]]]], 
              Times[ 
                Plus[ 
                  Times[ -1.0013220994164227, d], 
                  Times[ -1.0006608313591687, f], 
                  Times[ -0.34215126772004012, t], 
                  Times[ 1.0013220994164227, x]], 
                Power[ y, 2], 
                Power[ 
                  Tan[ 
                    Times[ Degree, \[Alpha]]], 2]]]]], SymbolicRayEnd -> {
        Times[ 
          Rational[ 1, 2], 
          Power[ f, -2], 
          Plus[ 
            Times[ 2, 
              Power[ f, 2], x], 
            Times[ f, 
              Plus[ 
                Times[ -2.0013216627183374, d], 
                Times[ -2.0, f], 
                Times[ -0.68385062550176157, t], 
                Times[ 2.0013216627183374, x]], y, 
              Tan[ 
                Times[ Degree, \[Alpha]]]], 
            Times[ 
              Plus[ 
                Times[ -2.0026441988328454, d], 
                Times[ -2.0013216627183374, f], 
                Times[ -0.68430253544008024, t], 
                Times[ 2.0026441988328454, x]], 
              Power[ y, 2], 
              Power[ 
                Tan[ 
                  Times[ Degree, \[Alpha]]], 2]]]], 
        Times[ 
          Rational[ 1, 2], 
          Power[ f, -2], y, 
          Plus[ 
            Times[ f, 
              Plus[ 
                Times[ 2.0013216627183374, d], 
                Times[ 2.0, f], 
                Times[ 0.68385062550176157, t], 
                Times[ -2.0013216627183374, x]]], 
            Times[ 
              Plus[ 
                Times[ 2.0026441988328454, d], 
                Times[ 2.0013216627183374, f], 
                Times[ 0.68430253544008024, t], 
                Times[ -2.0026441988328454, x]], y, 
              Tan[ 
                Times[ Degree, \[Alpha]]]]]], 0}, SymbolicRayTilt -> {
        Plus[ 1.0, 
          Times[ -0.50066104970821146, 
            Power[ f, -2], 
            Power[ y, 2]]], 
        Times[ -1.0006608313591687, 
          Power[ f, -1], y], 0}, SymbolicSurfaceCoordinates -> {
        Times[ 
          Rational[ 1, 2], 
          Power[ f, -2], y, 
          Sec[ 
            Times[ Degree, \[Alpha]]], 
          Plus[ 
            Times[ f, 
              Plus[ 
                Times[ 2.0013216627183374, d], 
                Times[ 2.0, f], 
                Times[ 0.68385062550176157, t], 
                Times[ -2.0013216627183374, x]]], 
            Times[ 
              Plus[ 
                Times[ 2.0026441988328454, d], 
                Times[ 2.0013216627183374, f], 
                Times[ 0.68430253544008024, t], 
                Times[ -2.0026441988328454, x]], y, 
              Tan[ 
                Times[ Degree, \[Alpha]]]]]], 0}, SymbolicIntensity -> Times[ 
        100, 
          Power[ E, 
            Plus[ 
              Times[ -4, 
                Power[ a, -2], 
                Power[ y, 2]], 
              Times[ -4, 
                Power[ a, -2], 
                Power[ 
                  Plus[ y, 
                    Times[ -0.65873551860828794, 
                      Power[ f, -1], t, y]], 2]], 
              Times[ 
                Rational[ -1, 2500], 
                Power[ f, -4], 
                Power[ y, 2], 
                Power[ 
                  Sec[ 
                    Times[ Degree, \[Alpha]]], 2], 
                Power[ 
                  Plus[ 
                    Times[ f, 
                      Plus[ 
                        Times[ 2.0013216627183374, d], 
                        Times[ 2.0, f], 
                        Times[ 0.68385062550176157, t], 
                        Times[ -2.0013216627183374, x]]], 
                    Times[ 
                      Plus[ 
                        Times[ 2.0026441988328454, d], 
                        Times[ 2.0013216627183374, f], 
                        Times[ 0.68430253544008024, t], 
                        Times[ -2.0026441988328454, x]], y, 
                      Tan[ 
                        Times[ Degree, \[Alpha]]]]], 2]]]]], 
        SymbolicSurfaceBoundary -> {50, 50}, SymbolicOffAxis -> {0, 0}, 
        SymbolicTranslationVector -> {x, 0, 0}, SymbolicRotationMatrix -> {{
        Times[ 
          Cos[ 
            Times[ Degree, \[Alpha]]], 
          Power[ 
            Plus[ 
              Power[ 
                Cos[ 
                  Times[ Degree, \[Alpha]]], 2], 
              Power[ 
                Sin[ 
                  Times[ Degree, \[Alpha]]], 2]], 
            Rational[ -1, 2]]], 
        Times[ 
          Sin[ 
            Times[ Degree, \[Alpha]]], 
          Power[ 
            Plus[ 
              Power[ 
                Cos[ 
                  Times[ Degree, \[Alpha]]], 2], 
              Power[ 
                Sin[ 
                  Times[ Degree, \[Alpha]]], 2]], 
            Rational[ -1, 2]]], 0}, {
        Times[ -1, 
          Sin[ 
            Times[ Degree, \[Alpha]]], 
          Power[ 
            Plus[ 
              Power[ 
                Cos[ 
                  Times[ Degree, \[Alpha]]], 2], 
              Power[ 
                Sin[ 
                  Times[ Degree, \[Alpha]]], 2]], 
            Rational[ -1, 2]]], 
        Times[ 
          Cos[ 
            Times[ Degree, \[Alpha]]], 
          Power[ 
            Plus[ 
              Power[ 
                Cos[ 
                  Times[ Degree, \[Alpha]]], 2], 
              Power[ 
                Sin[ 
                  Times[ Degree, \[Alpha]]], 2]], 
            Rational[ -1, 2]]], 0}, {0, 0, 1}}, SymbolicWaveLength -> 
        Rational[ 133, 250], SymbolicSurfaceNormalFunction -> {1, 0, 
        0}}]]], "Output",
  CellLabel->"Out[8]//TableForm=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],

Cell[TextData[{
  "At the same time, you can use ",
  StyleBox["AnalyzeSystem", "Input"],
  " to conduct a numeric ray-trace of the system."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[symbolicLensSystem,PlotType->TopView]", "Input",
  CellLabel->"In[9]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .26842 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00464068 0.146014 0.00464068 [
[.27905 .00639 -5.03125 -6 ]
[.27905 .00639 5.03125 6 ]
[.97619 .00851 -4.75 -6 ]
[.97619 .00851 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .26842 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.28565 .03 m
.30225 .03 L
.30225 .06867 L
.26861 .06867 L
.28565 .03 L
F
.26861 .06867 m
.30225 .06867 L
.30225 .10734 L
.25897 .10734 L
.26861 .06867 L
F
.25897 .10734 m
.30225 .10734 L
.30225 .14601 L
.25584 .14601 L
.25897 .10734 L
F
.25584 .14601 m
.30225 .14601 L
.30225 .18469 L
.25897 .18469 L
.25584 .14601 L
F
.25897 .18469 m
.30225 .18469 L
.30225 .22336 L
.26861 .22336 L
.25897 .18469 L
F
.26861 .22336 m
.30225 .22336 L
.30225 .26203 L
.28565 .26203 L
.26861 .22336 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.28565 .03 m
.26861 .06867 L
.25897 .10734 L
.25584 .14601 L
.25897 .18469 L
.26861 .22336 L
.28565 .26203 L
.30225 .26203 L
.30225 .22336 L
.30225 .18469 L
.30225 .14601 L
.30225 .10734 L
.30225 .06867 L
.30225 .03 L
.28565 .03 L
s
.5 g
.28565 .14601 m
.30225 .14601 L
.30225 .14601 L
.26861 .14601 L
.28565 .14601 L
F
.26861 .14601 m
.30225 .14601 L
.30225 .14601 L
.25897 .14601 L
.26861 .14601 L
F
.25897 .14601 m
.30225 .14601 L
.30225 .14601 L
.25584 .14601 L
.25897 .14601 L
F
.25584 .14601 m
.30225 .14601 L
.30225 .14601 L
.25897 .14601 L
.25584 .14601 L
F
.25897 .14601 m
.30225 .14601 L
.30225 .14601 L
.26861 .14601 L
.25897 .14601 L
F
.26861 .14601 m
.30225 .14601 L
.30225 .14601 L
.28565 .14601 L
.26861 .14601 L
F
0 g
.28565 .14601 m
.26861 .14601 L
.25897 .14601 L
.25584 .14601 L
.25897 .14601 L
.26861 .14601 L
.28565 .14601 L
.30225 .14601 L
.30225 .14601 L
.30225 .14601 L
.30225 .14601 L
.30225 .14601 L
.30225 .14601 L
.30225 .14601 L
.28565 .14601 L
s
.28565 .26203 m
.30225 .26203 L
.30225 .25808 L
.28565 .25808 L
.28565 .26203 L
s
.28565 .25808 m
.30225 .25808 L
.30225 .24649 L
.28565 .24649 L
.28565 .25808 L
s
.28565 .24649 m
.30225 .24649 L
.30225 .22805 L
.28565 .22805 L
.28565 .24649 L
s
.28565 .22805 m
.30225 .22805 L
.30225 .20402 L
.28565 .20402 L
.28565 .22805 L
s
.28565 .20402 m
.30225 .20402 L
.30225 .17604 L
.28565 .17604 L
.28565 .20402 L
s
.28565 .17604 m
.30225 .17604 L
.30225 .14601 L
.28565 .14601 L
.28565 .17604 L
s
.28565 .14601 m
.30225 .14601 L
.30225 .11599 L
.28565 .11599 L
.28565 .14601 L
s
.28565 .11599 m
.30225 .11599 L
.30225 .08801 L
.28565 .08801 L
.28565 .11599 L
s
.28565 .08801 m
.30225 .08801 L
.30225 .06398 L
.28565 .06398 L
.28565 .08801 L
s
.28565 .06398 m
.30225 .06398 L
.30225 .04554 L
.28565 .04554 L
.28565 .06398 L
s
.28565 .04554 m
.30225 .04554 L
.30225 .03395 L
.28565 .03395 L
.28565 .04554 L
s
.28565 .03395 m
.30225 .03395 L
.30225 .03 L
.28565 .03 L
.28565 .03395 L
s
.28565 .03 m
.30225 .03 L
.30225 .03395 L
.28565 .03395 L
.28565 .03 L
s
.28565 .03395 m
.30225 .03395 L
.30225 .04554 L
.28565 .04554 L
.28565 .03395 L
s
.28565 .04554 m
.30225 .04554 L
.30225 .06398 L
.28565 .06398 L
.28565 .04554 L
s
.28565 .06398 m
.30225 .06398 L
.30225 .08801 L
.28565 .08801 L
.28565 .06398 L
s
.28565 .08801 m
.30225 .08801 L
.30225 .11599 L
.28565 .11599 L
.28565 .08801 L
s
.28565 .11599 m
.30225 .11599 L
.30225 .14601 L
.28565 .14601 L
.28565 .11599 L
s
.28565 .14601 m
.30225 .14601 L
.30225 .17604 L
.28565 .17604 L
.28565 .14601 L
s
.28565 .17604 m
.30225 .17604 L
.30225 .20402 L
.28565 .20402 L
.28565 .17604 L
s
.28565 .20402 m
.30225 .20402 L
.30225 .22805 L
.28565 .22805 L
.28565 .20402 L
s
.28565 .22805 m
.30225 .22805 L
.30225 .24649 L
.28565 .24649 L
.28565 .22805 L
s
.28565 .24649 m
.30225 .24649 L
.30225 .25808 L
.28565 .25808 L
.28565 .24649 L
s
.28565 .25808 m
.30225 .25808 L
.30225 .26203 L
.28565 .26203 L
.28565 .25808 L
s
.97209 .03176 m
.96538 .06984 L
.95866 .10793 L
.95195 .14601 L
.94523 .1841 L
.93851 .22218 L
.9318 .26027 L
.9318 .26027 L
.93851 .22218 L
.94523 .1841 L
.95195 .14601 L
.95866 .10793 L
.96538 .06984 L
.97209 .03176 L
.97209 .03176 L
s
.95195 .14601 m
.95195 .14601 L
.95195 .14601 L
.95195 .14601 L
.95195 .14601 L
.95195 .14601 L
.95195 .14601 L
.95195 .14601 L
.95195 .14601 L
.95195 .14601 L
.95195 .14601 L
.95195 .14601 L
.95195 .14601 L
.95195 .14601 L
.95195 .14601 L
s
.9318 .26027 m
.93249 .25638 L
.9345 .24496 L
.9377 .2268 L
.94187 .20314 L
.94673 .17559 L
.95195 .14601 L
.95716 .11644 L
.96202 .08889 L
.96619 .06522 L
.96939 .04707 L
.9714 .03565 L
.97209 .03176 L
.9714 .03565 L
.96939 .04707 L
.96619 .06522 L
.96202 .08889 L
.95716 .11644 L
.95195 .14601 L
.94673 .17559 L
.94187 .20314 L
.9377 .2268 L
.9345 .24496 L
.93249 .25638 L
.9318 .26027 L
s
.039 .916 .04 r
.02381 .0532 m
.27446 .0532 L
s
% Start of user PostScript
0 -20. 54.0107 -20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.27446 .0532 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14601 m
.25584 .14601 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.25584 .14601 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23883 m
.27446 .23883 L
s
% Start of user PostScript
0 20. 54.0107 20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.27446 .23883 Mdot
.039 .916 .04 r
.5 Mabswid
.27446 .0532 m
.30225 .05709 L
s
% Start of user PostScript
54.0107 -20. 60. -19.1609 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30225 .05709 Mdot
.039 .916 .04 r
.5 Mabswid
.25584 .14601 m
.30225 .14601 L
s
% Start of user PostScript
50. 0 60. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30225 .14601 Mdot
.039 .916 .04 r
.5 Mabswid
.27446 .23883 m
.30225 .23493 L
s
% Start of user PostScript
54.0107 20. 60. 19.1609 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30225 .23493 Mdot
.039 .916 .04 r
.5 Mabswid
.30225 .05709 m
.94325 .1953 L
s
% Start of user PostScript
60. -19.1609 198.127 10.6203 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.94325 .1953 Mdot
.039 .916 .04 r
.5 Mabswid
.30225 .14601 m
.95195 .14601 L
s
% Start of user PostScript
60. 0 200. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.95195 .14601 Mdot
.039 .916 .04 r
.5 Mabswid
.30225 .23493 m
.96132 .09283 L
s
% Start of user PostScript
60. 19.1609 202.021 -11.4597 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.96132 .09283 Mdot
gsave
.27905 .00639 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00851 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .26842 L
0 .26842 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[9]:=",
  ImageSize->{474.062, 127.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007J0000Ob000`400?l00000o`00003ooooooooK
ooooo`00oooooooKooooo`00oooooooKooooo`00oooooooKooooo`00Q?ooool6o`000?ooooooDOoo
ool008Gooooo00Go0000ooooooooooooooooo`00003ooooooccooooo0ol0000Booooo`00QOooool0
0ol0003oooooooooo`3oooooockooooo00Co0000oooooooooooo00004Oooool008Gooooo00?o0000
ooooooooool0oooooom1ooooo`03o`000?oooooooooo00oooooo0025ooooo`03o`000?oooooooooo
0?oooooo?oooool2o`0001;ooooo0025ooooo`03o`000?oooooooooo0?oooooo?_ooool00ol0003o
ooooooooo`0Booooo`00Q?ooool3o`000?oooooo?oooool01?l0003oooooooooool0000Aooooo`00
ooooooo7ooooo`?o00004Oooool00?oooooofoooool00?oooooofoooool00?oooooofoooool00?oo
oooofoooool00?oooooofoooool008[ooooo2?l0003oooooodWooooo002:ooooo`03o`000?moOgoo
Ogmo00CoOgmo00?o0000ooooooooool0oooooolbooooo`03o`000?oooooooooo01;ooooo0029oooo
o`Wo0000ooooooldooooo`03o`000?oooooooooo01;ooooo0029ooooo`;o00001_moOgl00ol0003o
ooooooooo`3ooooooc7ooooo0_l0000Dooooo`00R?ooool00ol0003oOgmoo`000006ogmoO`03o`00
0?oooooooooo0?oooooo<Oooool2o`0001Cooooo0028ooooo`03o`000?moOgoo000000KoOgmo00?o
0000ooooooooool0oooooolaooooo`03o`000?oooooooooo01?ooooo0028ooooo`03o`000?moOgoo
000000KoOgmo00?o0000ooooooooool0ooooool`ooooo`;o00005Oooool008Oooooo00?o0000ogmo
OomoOgl02?l0003ooooooc;ooooo0_l0000Eooooo`00Qoooool01?l0003oOgmoogmoOol00006ogmo
O`03o`000?oooooooooo0?oooooo<?ooool2o`0001Gooooo001mooooo`?o2NX:1_ooool01?l0003o
OgmoogmoOomoOgl2o`WZ2PGoOgmo00?o0000ooooooooool0ooooool`ooooo`;o00005Oooool007ko
oooo1_l9jPX3o`0000?oOgmo1?l9jPX3ogmoO`03o`000?oooooooooo0?oooooo<?ooool00ol0003o
ooooooooo`0Dooooo`004_oooombo`WZ2P03o`000?l9jP[o2NX:00;o2NX:00?oOgmoo`000?l9jPX0
0ol9jPX2ogmoO`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Dooooo`00O_oo
ool5o`WZ2P;ooooo00Co0000ogmoOomoOgooOgmo2?l9jPX2o`000?oooooo<Oooool00ol0003ooooo
ooooo`0Dooooo`00OOooool2o`WZ2PGooooo00?o0000ogmoOomoOgl00_moOgl;o`WZ2_oooooo;ooo
ool2o`0001Kooooo0024ooooo`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl01?moOgl0
0ol0003oooooooooo`05o`WZ2_oooooo:_ooool2o`0001Kooooo0024ooooo`03o`000?moOgooOgmo
00?oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`05ooooo`Go2NX:oooooolUoooo
o`;o00005_ooool008?ooooo00?o0000ogmoOomoOgl01?moOgl8o`0000cooooo1?l9jP[oooooob7o
oooo00?o0000ooooooooool05Oooool008?ooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmo
ogmoO`04ogmoO`03o`000?oooooooooo00kooooo1Ol9jP[ooooooacooooo00?o0000ooooooooool0
5Oooool008;ooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oo
oooooooo01?ooooo1Ol9jP[ooooooaOooooo00?o0000ooooooooool05Oooool008;ooooo00?o0000
ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo01Sooooo1?l9jP[o
oooooa?ooooo00?o0000ooooooooool05Oooool008;ooooo00?o0000ogmoOomoOgl01OmoOgl00ol0
003oOgmoogmoO`04ogmoO`03o`000?oooooooooo01cooooo1Ol9jP[oooooo`gooooo0_l0000Goooo
o`00POooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000oooooooo
ool08Oooool5o`WZ2_oooooo2?ooool2o`0001Oooooo0021ooooo`03o`000?moOgooOgmo00KoOgmo
00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`0Vooooo`Co2NX:ooooool4ooooo`03o`00
0?oooooooooo01Kooooo0021ooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oooooooooo`0Zooooo`Go2NX:o_ooool00ol0003oooooooooo`0Fooooo`00P?ooool0
0ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0;oooool5
o`WZ2_Wooooo00?o0000ooooooooool05_ooool0083ooooo00?o0000ogmoOomoOgl01omoOgl00ol0
003oOgmoogmoO`04ogmoO`03o`000?oooooooooo03Cooooo1?l9jP[dooooo`;o00006?ooool0083o
oooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo03So
oooo1Ol9jP[_ooooo`;o00006?ooool0083ooooo00?o0000ogmoOomoOgl01omoOgl8o`0003oooooo
1Ol9jP[Zooooo`;o00006?ooool007oooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmo
O`04ogmoO`03o`000?oooooooooo04;ooooo1?l9jP[Uooooo`;o00006Oooool007oooooo00?o0000
ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo04Kooooo1Ol9jP[H
ooooo`So2NX:0_l0000Iooooo`00Ooooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo
00CoOgmo00?o0000ooooooooool0Boooool5o`WZ2]Gooooo1_l9jPX00ooooooo0000ooooo`0Hoooo
o`00Ooooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000oooooooo
ool0D?ooool4o`WZ2/cooooo1Ol9jPX01?oooooo2NX:o`WZ2_l9jPX2ooooo`;o00006Oooool007ko
oooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo05Co
oooo1Ol9jP[3ooooo`Co2NX:1Oooool2o`WZ2PCooooo0_l0000Iooooo`00O_ooool00ol0003oOgmo
ogmoO`09ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0FOooool5o`WZ2[Wooooo
1Ol9jPX8ooooo`03o`WZ2_oooooooooo00Cooooo0_l0000Iooooo`00O_ooool00ol0003oOgmoogmo
O`09ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0G_ooool4o`WZ2[3ooooo1Ol9
jPXDooooo`03o`000?oooooooooo01Sooooo001mooooo`03o`000?moOgooOgmo00[oOgmo00?o0000
ogmoOomoOgl01?moOgl00ol0003oooooooooo`1Rooooo`Go2NX:Yoooool4o`WZ2QWooooo00?o0000
ooooooooool06?ooool007gooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`04ogmo
O`03o`000?oooooooooo06Oooooo1Ol9jPZMooooo`Go2NX:7Oooool00ol0003oooooooooo`0Hoooo
o`00OOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000oooooooo
ool0K?ooool4o`WZ2YCooooo1Ol9jPXRooooo`03o`000?oooooooooo01Sooooo001mooooo`03o`00
0?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`1`ooooo`Go2NX:
Roooool4o`WZ2RKooooo0_l0000Jooooo`00OOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?mo
OgooOgmo00CoOgmo00?o0000ooooooooool0MOooool5o`WZ2X7ooooo1Ol9jPXZooooo`03o`000?oo
oooooooo01Wooooo001mooooo`03o`000?moOgooOgmo00[oOgmo2?l0001looooo`Co2NX:N?ooool5
o`WZ2Roooooo00?o0000ooooooooool06Oooool007gooooo00?o0000ogmoOomoOgl02_moOgl00ol0
003oOgmoogmoO`04ogmoO`03o`000?oooooooooo07kooooo1Ol9jPY_ooooo`Co2NX:=?ooool00ol0
003oooooooooo`0Iooooo`00OOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00Co
Ogmo00?o0000ooooooooool0Poooool5o`WZ2VGooooo1Ol9jPXhooooo`03o`000?oooooooooo01Wo
oooo001mooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003ooooo
ooooo`28ooooo`Co2NX:G?ooool5o`WZ2Scooooo00?o0000ooooooooool06_ooool007gooooo00?o
0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo08cooooo1Ol9
jPYCooooo`Co2NX:@Oooool00ol0003oooooooooo`0Jooooo`00O?ooool00ol0003oOgmoogmoO`0;
ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0TOooool5o`WZ2TWooooo1Ol9jPY5
ooooo`03o`000?oooooooooo01[ooooo001looooo`03o`000?moOgooOgmo00_oOgmo00?o0000ogmo
OomoOgl01?moOgl00ol0003oooooooooo`2Fooooo`Co2NX:@?ooool5o`WZ2T[ooooo00?o0000oooo
ooooool06_ooool007cooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`04ogmoO`03
o`000?oooooooooo09[ooooo1Ol9jPXgooooo`Co2NX:C_ooool2o`0001cooooo001looooo`03o`00
0?moOgooOgmo00_oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`2Oooooo`Go2NX:
;Oooool5o`WZ2U;ooooo00?o0000ooooooooool06oooool007cooooo00?o0000ogmoOomoOgl02omo
Ogl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo0:Cooooo1?l9jPXTooooo`Go2NX:Eooo
ool00ol0003oooooooooo`0Kooooo`00O?ooool00ol0003oOgmoogmoO`0;ogmoO`03o`000?moOgoo
Ogmo00CoOgmo00?o0000ooooooooool0Z?ooool5o`WZ2Q_ooooo1?l9jPYLooooo`03o`000?oooooo
oooo01_ooooo001dooooo`?o2NX:1Oooool00ol0003oOgmoogmoO`0:ogmoO`?o2NX:1OmoOgl00ol0
003oooooooooo`2]ooooo`Go2NX:4Oooool5o`WZ2UOooooo0ol9jPX6ooooo`03o`000?oooooooooo
01_ooooo001eooooo`Ko2NX:00?oooooo`000?moOgl03?moOgl6o`WZ2P03ogmoOol0003ooooo0;?o
oooo1?l9jPX8ooooo`Go2NX:GOooool6o`WZ2P03ooooool0003ooooo01gooooo000BooooofWo2NX:
00?o0000o`WZ2_l9jPX0ool9jPXno`WZ2P;o00007Oooool007Gooooo1Ol9jPX00ooooooo0000o`00
000=ogmoO`Go2NX:0_moOgl2o`000;Kooooo1Ol9jPX00ooooooo2NX:o`WZ2P03o`WZ2V3ooooo1Ol9
jPX2ooooo`;o00007Oooool007Cooooo0_l9jPX6ooooo`03o`000?moOgooOgmo00[oOgmo0_l9jPX6
ogmoO`03o`000?oooooooooo0;3ooooo1Ol9jPX;ooooo`Co2NX:Foooool2o`WZ2PKooooo00?o0000
ooooooooool07?ooool007cooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`04ogmo
O`03o`000?oooooooooo0:cooooo1?l9jPXDooooo`Go2NX:G_ooool00ol0003oooooooooo`0Loooo
o`00O?ooool00ol0003oOgmoogmoO`0;ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000oooooooo
ool0Yoooool5o`WZ2Qgooooo1Ol9jPYHooooo`03o`000?oooooooooo01gooooo001looooo`03o`00
0?moOgooOgmo00_oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`2Rooooo`Go2NX:
9oooool4o`WZ2UCooooo00?o0000ooooooooool07Oooool007cooooo00?o0000ogmoOomoOgl02omo
Ogl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo09kooooo1?l9jPX`ooooo`Go2NX:Cooo
ool00ol0003oooooooooo`0Mooooo`00O?ooool00ol0003oOgmoogmoO`0;ogmoO`03o`000?moOgoo
Ogmo00CoOgmo00?o0000ooooooooool0VOooool5o`WZ2SWooooo1Ol9jPY:ooooo`03o`000?oooooo
oooo01gooooo001looooo`03o`000?moOgooOgmo00_oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0
003oooooooooo`2Dooooo`Go2NX:@oooool4o`WZ2TKooooo00?o0000ooooooooool07Oooool007co
oooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo093o
oooo1?l9jPY<ooooo`Go2NX:@Oooool00ol0003oooooooooo`0Mooooo`00OOooool00ol0003oOgmo
ogmoO`0:ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0Roooool5o`WZ2UGooooo
1Ol9jPXkooooo`;o00007oooool007gooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmo
O`04ogmoO`03o`000?oooooooooo08Oooooo1?l9jPYOooooo`Co2NX:=oooool00ol0003ooooooooo
o`0Nooooo`00OOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000
ooooooooool0P_ooool5o`WZ2VOooooo1Ol9jPXbooooo`03o`000?oooooooooo01kooooo001moooo
o`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`1moooo
o`Go2NX:LOooool5o`WZ2Rgooooo00?o0000ooooooooool07_ooool007gooooo00?o0000ogmoOomo
Ogl02_moOgl8o`0007_ooooo1?l9jPYkooooo`Co2NX::Oooool00ol0003oooooooooo`0Nooooo`00
OOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0
M?ooool5o`WZ2X?ooooo1Ol9jPXTooooo`03o`000?oooooooooo01kooooo001mooooo`03o`000?mo
OgooOgmo00[oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`1_ooooo`Go2NX:SOoo
ool5o`WZ2Qkooooo0_l0000Pooooo`00OOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgoo
Ogmo00CoOgmo00?o0000ooooooooool0Joooool4o`WZ2YOooooo1?l9jPXJooooo`;o00008?ooool0
07gooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo
06Kooooo1Ol9jPZOooooo`Go2NX:5Oooool00ol0003oooooooooo`0Oooooo`00OOooool00ol0003o
OgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0HOooool5o`WZ2ZWo
oooo1Ol9jPX8ooooo`;o2NX:1_ooool00ol0003oooooooooo`0Oooooo`00OOooool00ol0003oOgmo
ogmoO`0:ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0GOooool4o`WZ2[?ooooo
1?l9jPX4ooooo`Co2NX:1?ooool00ol0003oooooooooo`0Oooooo`00O_ooool00ol0003oOgmoogmo
O`09ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0F?ooool5o`WZ2[_ooooo2Ol9
jPX3ooooo`03o`000?oooooooooo01oooooo001nooooo`03o`000?moOgooOgmo00WoOgmo00?o0000
ogmoOomoOgl01?moOgl00ol0003oooooooooo`1Cooooo`Go2NX:aOooool6o`WZ2P;o00008Oooool0
07kooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo
04oooooo1?l9jP[8ooooo`So2NX:0_l0000Qooooo`00Ooooool00ol0003oOgmoogmoO`08ogmoO`03
o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0B_ooool5o`WZ2]Cooooo0_l0000Qooooo`00
Ooooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0
AOooool5o`WZ2]Wooooo00?o0000ooooooooool08?ooool007oooooo00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo047ooooo1?l9jP[Nooooo`03o`000?oo
oooooooo023ooooo001oooooo`03o`000?moOgooOgmo00SoOgmo2?l0000nooooo`Go2NX:hOooool2
o`0002;ooooo0020ooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0
003oooooooooo`0gooooo`Go2NX:i_ooool2o`0002;ooooo0020ooooo`03o`000?moOgooOgmo00Oo
Ogmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`0cooooo`Co2NX:joooool2o`0002;o
oooo0020ooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003ooooo
ooooo`0^ooooo`Go2NX:koooool00ol0003oooooooooo`0Qooooo`00P?ooool00ol0003oOgmoogmo
O`07ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0:Oooool5o`WZ2_Cooooo00?o
0000ooooooooool08Oooool0087ooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`04
ogmoO`03o`000?oooooooooo02Gooooo1?l9jP[iooooo`03o`000?oooooooooo027ooooo0021oooo
o`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`0Poooo
o`Go2NX:o?ooool2o`0002?ooooo0021ooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomo
Ogl01?moOgl00ol0003oooooooooo`0Kooooo`Go2NX:ooooool2ooooo`;o00008oooool008;ooooo
00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo01Oooooo
1?l9jP[oooooo`Oooooo00?o0000ooooooooool08_ooool008;ooooo00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo01;ooooo1Ol9jP[oooooo`_ooooo00?o
0000ooooooooool08_ooool008;ooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`04
ogmoO`03o`000?oooooooooo00gooooo1Ol9jP[ooooooa3ooooo00?o0000ooooooooool08_ooool0
08?ooooo00?o0000ogmoOomoOgl01?moOgl8o`0000_ooooo1?l9jP[ooooooaGooooo00?o0000oooo
ooooool08_ooool008?ooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`04ogmoO`03
o`000?oooooooooo00Cooooo1Ol9jP[ooooooaSooooo0_l0000Tooooo`00Q?ooool00ol0003oOgmo
ogmoO`02ogmoO`Go2NX:0omoOgl00ol0003oooooo`WZ2P04o`WZ2_oooooo7Oooool00ol0003ooooo
ooooo`0Sooooo`00OOooool3o`WZ2PCooooo00?o0000ogmoOomoOgl00omoOgl9o`WZ2_oooooo8_oo
ool00ol0003oooooooooo`0Sooooo`00O_ooool6o`WZ2P;o00000_moOgl8o`WZ2P03ogmoOol0003o
00000?oooooo8_ooool00ol0003oooooooooo`0Sooooo`004_oooombo`WZ2P04o`000?l9jP[o2NX:
o`WZ2P;oOgmo00?o0000o`WZ2_l9jPX01?moOgl00ol0003oooooooooo`3oooooob7ooooo00?o0000
ooooooooool08oooool007kooooo1Ol9jPX2ooooo`03o`000?moOgooOgmo00;oOgmo00?o2NX:ogmo
OomoOgl01?moOgl00ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool08oooool007go
oooo0_l9jPX7ooooo`05o`000?moOgooOgmoogmoOol000001_moOgl00ol0003oooooooooo`3ooooo
ob3ooooo00?o0000ooooooooool09?ooool008Kooooo00Co0000ogmoOomoOgooOgmo2?l0003ooooo
ob;ooooo00?o0000ooooooooool09?ooool008Oooooo00Co0000ogmoOomoOgoo00001_moOgl00ol0
003oooooooooo`3oooooob3ooooo00?o0000ooooooooool09?ooool008Oooooo00Co0000ogmoOomo
Ogoo00001_moOgl00ol0003oooooooooo`3oooooob3ooooo00?o0000ooooooooool09?ooool008So
oooo00?o0000ogmoOol000001_moOgl00ol0003oooooooooo`3oooooob3ooooo00?o0000oooooooo
ool09?ooool008Sooooo00?o0000ogmoOol000001_moOgl00ol0003oooooooooo`3oooooob3ooooo
00?o0000ooooooooool09?ooool008Sooooo00?o0000ogmoOol000001_moOgl00ol0003ooooooooo
o`3ooooooaoooooo0_l0000Vooooo`00ROooool9o`000?oooooo8Oooool2o`0002Kooooo0029oooo
o`;o00001_moOgl00ol0003oooooooooo`3ooooooaoooooo00?o0000ooooooooool09Oooool008[o
oooo2?l0003oooooodWooooo003oooooom_ooooo003oooooom_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 473.062}, {126.25, 0}} -> {-8.45276, -32.9046, \
0.469557, 0.469557}},
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],

Cell[BoxData[
    TagBox[
      StyleBox[
        TagBox[\(AnalyzeSystem[{Move[LineOfRays[40], {0, {y, 0}}], 
              Move[PlanoConvexLens[{f, 100}, {a, 50}, {t, 10}], {d, 50.`}], 
              Move[Screen[50], {{x, 200.`}, 0}, {\[Alpha], 
                  10.000000000000002`}]}, PlotType \[Rule] TopView]\),
          HoldForm],
        FontColor->RGBColor[0, 0.392187, 0]],
      DisplayForm]], "Print",
  CellLabel->"From In[9]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],

Cell[BoxData[
    \("-9 ray/surface intersections-"\)], "Output",
  CellLabel->"Out[9]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],

Cell[TextData[{
  "When you include a Gaussian-beam light source in a system, you can use ",
  StyleBox["FindABCDMatrix", "Input"],
  " to calculate the symbolic ABCD matrix of the system."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{

Cell["\<\
symbolicGaussianSystem = 
\t{symbolicGaussianSource,
\tMove[symbolicLens, {d,50}],
\tMove[Screen[50],{{x,200},{y,0}}]}\
\>", "Input",
  CellLabel->"In[10]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox[
            
            TagBox[\(GaussianBeam[{w, 10}, {div, 0.001`}, 
                NumberOfRays \[Rule] 4, 
                SymbolicWaveLength \[Rule] \[Lambda]]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            
            TagBox[\(Move[
                PlanoConvexLens[{f, 100}, {a, 50}, {t, 10}], {d, 50.`}]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            TagBox[\(Move[Screen[50], {{x, 200.`}, {y, 0}}]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm]}], "}"}]], "Output",
  CellLabel->"Out[10]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[symbolicGaussianSystem,{f>0}, MatrixForm->True]\
\>", "Input",
  CellLabel->"In[11]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(\(-1.0013220994164227`\)\ d\^2 + 
                    f\ \((f + 0.3419253127508808`\ t - 
                          1.0006608313591687`\ x)\) + 
                    d\ \((\(-0.3421512677200401`\)\ t + 
                          1.0013220994164227`\ x)\)\)\/\(f\ \
\@\(1.0013220994164227`\ d\^2 - 2.0013216627183374`\ d\ f + f\^2\)\)\), \
\(\(\(-1.0013220994164227`\)\ d\^3 + 
                    d\ f\ \((0.6838506255017616`\ t - 
                          2.0013216627183374`\ x)\) + 
                    f\^2\ \((\(-0.34169950700124185`\)\ t + x)\) + 
                    d\^2\ \((1.0006608313591687`\ f - 
                          0.3421512677200401`\ t + 
                          1.0013220994164227`\ x)\)\)\/\(f\ \
\@\(1.0013220994164227`\ d\^2 - 2.0013216627183374`\ d\ f + f\^2\)\)\)},
            {\(\(1.0013220994164227`\ d - 
                    1.0006608313591687`\ f\)\/\(f\ \@\(1.0013220994164227`\ d\
\^2 - 2.0013216627183374`\ d\ f + f\^2\)\)\), \(\@\(1.0013220994164227`\ d\^2 \
- 2.0013216627183374`\ d\ f + f\^2\)\/f\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[11]//MatrixForm=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],

Cell[TextData[{
  "If you use the ",
  StyleBox["ShowGaussian->True", "Input"],
  " option with ",
  StyleBox["AnalyzeSystem", "Input"],
  ", you can see the Gaussian wave-front behavior superimposed on the normal \
numeric ray-trace."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[symbolicGaussianSystem,PlotType->TopView,ShowGaussian->True]\
\>", "Input",
  CellLabel->"In[12]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238276 0.00476181 0.149402 0.00476181 [
[.28573 .00655 -5.03125 -6 ]
[.28573 .00655 5.03125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.2925 .03036 m
.30954 .03036 L
.30954 .07004 L
.27502 .07004 L
.2925 .03036 L
F
.27502 .07004 m
.30954 .07004 L
.30954 .10972 L
.26513 .10972 L
.27502 .07004 L
F
.26513 .10972 m
.30954 .10972 L
.30954 .1494 L
.26192 .1494 L
.26513 .10972 L
F
.26192 .1494 m
.30954 .1494 L
.30954 .18908 L
.26513 .18908 L
.26192 .1494 L
F
.26513 .18908 m
.30954 .18908 L
.30954 .22877 L
.27502 .22877 L
.26513 .18908 L
F
.27502 .22877 m
.30954 .22877 L
.30954 .26845 L
.2925 .26845 L
.27502 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.2925 .03036 m
.27502 .07004 L
.26513 .10972 L
.26192 .1494 L
.26513 .18908 L
.27502 .22877 L
.2925 .26845 L
.30954 .26845 L
.30954 .22877 L
.30954 .18908 L
.30954 .1494 L
.30954 .10972 L
.30954 .07004 L
.30954 .03036 L
.2925 .03036 L
s
.5 g
.2925 .1494 m
.30954 .1494 L
.30954 .1494 L
.27502 .1494 L
.2925 .1494 L
F
.27502 .1494 m
.30954 .1494 L
.30954 .1494 L
.26513 .1494 L
.27502 .1494 L
F
.26513 .1494 m
.30954 .1494 L
.30954 .1494 L
.26192 .1494 L
.26513 .1494 L
F
.26192 .1494 m
.30954 .1494 L
.30954 .1494 L
.26513 .1494 L
.26192 .1494 L
F
.26513 .1494 m
.30954 .1494 L
.30954 .1494 L
.27502 .1494 L
.26513 .1494 L
F
.27502 .1494 m
.30954 .1494 L
.30954 .1494 L
.2925 .1494 L
.27502 .1494 L
F
0 g
.2925 .1494 m
.27502 .1494 L
.26513 .1494 L
.26192 .1494 L
.26513 .1494 L
.27502 .1494 L
.2925 .1494 L
.30954 .1494 L
.30954 .1494 L
.30954 .1494 L
.30954 .1494 L
.30954 .1494 L
.30954 .1494 L
.30954 .1494 L
.2925 .1494 L
s
.2925 .26845 m
.30954 .26845 L
.30954 .26439 L
.2925 .26439 L
.2925 .26845 L
s
.2925 .26439 m
.30954 .26439 L
.30954 .2525 L
.2925 .2525 L
.2925 .26439 L
s
.2925 .2525 m
.30954 .2525 L
.30954 .23358 L
.2925 .23358 L
.2925 .2525 L
s
.2925 .23358 m
.30954 .23358 L
.30954 .20892 L
.2925 .20892 L
.2925 .23358 L
s
.2925 .20892 m
.30954 .20892 L
.30954 .18021 L
.2925 .18021 L
.2925 .20892 L
s
.2925 .18021 m
.30954 .18021 L
.30954 .1494 L
.2925 .1494 L
.2925 .18021 L
s
.2925 .1494 m
.30954 .1494 L
.30954 .11859 L
.2925 .11859 L
.2925 .1494 L
s
.2925 .11859 m
.30954 .11859 L
.30954 .08988 L
.2925 .08988 L
.2925 .11859 L
s
.2925 .08988 m
.30954 .08988 L
.30954 .06522 L
.2925 .06522 L
.2925 .08988 L
s
.2925 .06522 m
.30954 .06522 L
.30954 .04631 L
.2925 .04631 L
.2925 .06522 L
s
.2925 .04631 m
.30954 .04631 L
.30954 .03441 L
.2925 .03441 L
.2925 .04631 L
s
.2925 .03441 m
.30954 .03441 L
.30954 .03036 L
.2925 .03036 L
.2925 .03441 L
s
.2925 .03036 m
.30954 .03036 L
.30954 .03441 L
.2925 .03441 L
.2925 .03036 L
s
.2925 .03441 m
.30954 .03441 L
.30954 .04631 L
.2925 .04631 L
.2925 .03441 L
s
.2925 .04631 m
.30954 .04631 L
.30954 .06522 L
.2925 .06522 L
.2925 .04631 L
s
.2925 .06522 m
.30954 .06522 L
.30954 .08988 L
.2925 .08988 L
.2925 .06522 L
s
.2925 .08988 m
.30954 .08988 L
.30954 .11859 L
.2925 .11859 L
.2925 .08988 L
s
.2925 .11859 m
.30954 .11859 L
.30954 .1494 L
.2925 .1494 L
.2925 .11859 L
s
.2925 .1494 m
.30954 .1494 L
.30954 .18021 L
.2925 .18021 L
.2925 .1494 L
s
.2925 .18021 m
.30954 .18021 L
.30954 .20892 L
.2925 .20892 L
.2925 .18021 L
s
.2925 .20892 m
.30954 .20892 L
.30954 .23358 L
.2925 .23358 L
.2925 .20892 L
s
.2925 .23358 m
.30954 .23358 L
.30954 .2525 L
.2925 .2525 L
.2925 .23358 L
s
.2925 .2525 m
.30954 .2525 L
.30954 .26439 L
.2925 .26439 L
.2925 .2525 L
s
.2925 .26439 m
.30954 .26439 L
.30954 .26845 L
.2925 .26845 L
.2925 .26439 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18908 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18908 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .26439 L
.97619 .2525 L
.97619 .23358 L
.97619 .20892 L
.97619 .18021 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06522 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06522 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18021 L
.97619 .20892 L
.97619 .23358 L
.97619 .2525 L
.97619 .26439 L
.97619 .26845 L
s
.039 .916 .04 r
.02382 .10178 m
.26658 .10166 L
s
% Start of user PostScript
-0.00249857 -10. 50.978 -10.0255 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.26658 .10166 Mdot
.039 .916 .04 r
.5 Mabswid
.02383 .13353 m
.26243 .13349 L
s
% Start of user PostScript
-0.000277618 -3.33333 50.1078 -3.34168 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.26243 .13349 Mdot
.039 .916 .04 r
.5 Mabswid
.02383 .16527 m
.26243 .16531 L
s
% Start of user PostScript
-0.000277618 3.33333 50.1078 3.34168 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.26243 .16531 Mdot
.039 .916 .04 r
.5 Mabswid
.02382 .19702 m
.26658 .19714 L
s
% Start of user PostScript
-0.00249857 10. 50.978 10.0255 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.26658 .19714 Mdot
.039 .916 .04 r
.5 Mabswid
.26658 .10166 m
.30954 .10453 L
s
% Start of user PostScript
50.978 -10.0255 60. -9.42378 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30954 .10453 Mdot
.039 .916 .04 r
.5 Mabswid
.26243 .13349 m
.30954 .13452 L
s
% Start of user PostScript
50.1078 -3.34168 60. -3.12466 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30954 .13452 Mdot
.039 .916 .04 r
.5 Mabswid
.26243 .16531 m
.30954 .16428 L
s
% Start of user PostScript
50.1078 3.34168 60. 3.12466 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30954 .16428 Mdot
.039 .916 .04 r
.5 Mabswid
.26658 .19714 m
.30954 .19428 L
s
% Start of user PostScript
50.978 10.0255 60. 9.42378 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30954 .19428 Mdot
.039 .916 .04 r
.5 Mabswid
.30954 .10453 m
.97619 .17226 L
s
% Start of user PostScript
60. -9.42378 200. 4.80112 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .17226 Mdot
.039 .916 .04 r
.5 Mabswid
.30954 .13452 m
.97619 .15675 L
s
% Start of user PostScript
60. -3.12466 200. 1.5425 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .15675 Mdot
.039 .916 .04 r
.5 Mabswid
.30954 .16428 m
.97619 .14206 L
s
% Start of user PostScript
60. 3.12466 200. -1.5425 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .14206 Mdot
.039 .916 .04 r
.5 Mabswid
.30954 .19428 m
.97619 .12654 L
s
% Start of user PostScript
60. 9.42378 200. -4.80112 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .12654 Mdot
gsave
.28573 .00655 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
1 Mabswid
.02383 .19702 m
.0397 .19703 L
.05557 .19704 L
.07145 .19704 L
.08732 .19705 L
.10319 .19706 L
.11906 .19707 L
.13494 .19708 L
.15081 .19708 L
.16668 .19709 L
.18255 .1971 L
.19843 .19711 L
.2143 .19712 L
.23017 .19712 L
.24605 .19713 L
.26192 .19714 L
.27779 .1961 L
.29366 .19505 L
.30954 .19401 L
.32541 .19243 L
.34128 .19084 L
.35715 .18926 L
.37303 .18767 L
.3889 .18609 L
.40477 .1845 L
.42065 .18292 L
.43652 .18134 L
.45239 .17975 L
.46826 .17817 L
.48414 .17658 L
.50001 .175 L
.51588 .17341 L
.53175 .17183 L
.54763 .17024 L
.5635 .16866 L
.57937 .16708 L
.59525 .16549 L
.61112 .16391 L
.62699 .16232 L
.64286 .16074 L
.65874 .15915 L
.67461 .15757 L
.69048 .15599 L
.70635 .1544 L
.72223 .15282 L
.7381 .15123 L
.75397 .14965 L
.76985 .15074 L
.78572 .15232 L
.80159 .15391 L
Mistroke
.81746 .15549 L
.83334 .15708 L
.84921 .15866 L
.86508 .16025 L
.88095 .16183 L
.89683 .16342 L
.9127 .165 L
.92857 .16658 L
.94445 .16817 L
.96032 .16975 L
.97619 .17134 L
Mfstroke
.02383 .10178 m
.0397 .10178 L
.05557 .10177 L
.07145 .10176 L
.08732 .10175 L
.10319 .10174 L
.11906 .10174 L
.13494 .10173 L
.15081 .10172 L
.16668 .10171 L
.18255 .1017 L
.19843 .1017 L
.2143 .10169 L
.23017 .10168 L
.24605 .10167 L
.26192 .10167 L
.27779 .10271 L
.29366 .10375 L
.30954 .10479 L
.32541 .10638 L
.34128 .10796 L
.35715 .10955 L
.37303 .11113 L
.3889 .11272 L
.40477 .1143 L
.42065 .11588 L
.43652 .11747 L
.45239 .11905 L
.46826 .12064 L
.48414 .12222 L
.50001 .12381 L
.51588 .12539 L
.53175 .12697 L
.54763 .12856 L
.5635 .13014 L
.57937 .13173 L
.59525 .13331 L
.61112 .1349 L
.62699 .13648 L
.64286 .13807 L
.65874 .13965 L
.67461 .14123 L
.69048 .14282 L
.70635 .1444 L
.72223 .14599 L
.7381 .14757 L
.75397 .14916 L
.76985 .14806 L
.78572 .14648 L
.80159 .1449 L
Mistroke
.81746 .14331 L
.83334 .14173 L
.84921 .14014 L
.86508 .13856 L
.88095 .13697 L
.89683 .13539 L
.9127 .1338 L
.92857 .13222 L
.94445 .13064 L
.96032 .12905 L
.97619 .12747 L
Mfstroke
0 0 0 r
.02383 .1494 m
.26192 .1494 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
.26192 .1494 m
.30954 .1494 L
s
% Start of user PostScript
50. 0 60. 0 MAarrowhead1
% End of user PostScript
.30954 .1494 m
.97619 .1494 L
s
% Start of user PostScript
60. 0 200. 0 MAarrowhead1
% End of user PostScript
.97619 .1494 m
.97619 .1494 L
s
% Start of user PostScript
200. 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .10655 m
.02381 .1094 L
.02381 .11226 L
.02382 .11512 L
.02382 .11797 L
.02382 .12083 L
.02382 .12369 L
.02382 .12655 L
.02382 .1294 L
.02382 .13226 L
.02383 .13512 L
.02383 .13797 L
.02383 .14083 L
.02383 .14369 L
.02383 .14655 L
.02383 .1494 L
.02383 .15226 L
.02383 .15512 L
.02383 .15797 L
.02383 .16083 L
.02383 .16369 L
.02382 .16654 L
.02382 .1694 L
.02382 .17226 L
.02382 .17512 L
.02382 .17797 L
.02382 .18083 L
.02382 .18369 L
.02381 .18654 L
.02381 .1894 L
.02381 .19226 L
s
.04762 .10654 m
.04762 .10939 L
.04762 .11225 L
.04763 .11511 L
.04763 .11797 L
.04763 .12082 L
.04763 .12368 L
.04763 .12654 L
.04763 .1294 L
.04763 .13226 L
.04763 .13511 L
.04764 .13797 L
.04764 .14083 L
.04764 .14369 L
.04764 .14654 L
.04764 .1494 L
.04764 .15226 L
.04764 .15512 L
.04764 .15798 L
.04764 .16083 L
.04763 .16369 L
.04763 .16655 L
.04763 .16941 L
.04763 .17226 L
.04763 .17512 L
.04763 .17798 L
.04763 .18084 L
.04763 .1837 L
.04762 .18655 L
.04762 .18941 L
.04762 .19227 L
s
.07143 .10652 m
.07143 .10938 L
.07143 .11224 L
.07143 .1151 L
.07144 .11796 L
.07144 .12082 L
.07144 .12368 L
.07144 .12653 L
.07144 .12939 L
.07144 .13225 L
.07144 .13511 L
.07144 .13797 L
.07145 .14083 L
.07145 .14369 L
.07145 .14654 L
.07145 .1494 L
.07145 .15226 L
.07145 .15512 L
.07145 .15798 L
.07144 .16084 L
.07144 .16369 L
.07144 .16655 L
.07144 .16941 L
.07144 .17227 L
.07144 .17513 L
.07144 .17799 L
.07144 .18085 L
.07143 .1837 L
.07143 .18656 L
.07143 .18942 L
.07143 .19228 L
s
.09524 .10651 m
.09524 .10937 L
.09524 .11223 L
.09524 .11509 L
.09525 .11795 L
.09525 .12081 L
.09525 .12367 L
.09525 .12653 L
.09525 .12939 L
.09525 .13225 L
.09525 .13511 L
.09525 .13797 L
.09525 .14082 L
.09525 .14368 L
.09525 .14654 L
.09525 .1494 L
.09525 .15226 L
.09525 .15512 L
.09525 .15798 L
.09525 .16084 L
.09525 .1637 L
.09525 .16656 L
.09525 .16942 L
.09525 .17228 L
.09525 .17514 L
.09525 .17799 L
.09525 .18085 L
.09524 .18371 L
.09524 .18657 L
.09524 .18943 L
.09524 .19229 L
s
.11905 .1065 m
.11905 .10936 L
.11905 .11222 L
.11905 .11508 L
.11905 .11794 L
.11906 .1208 L
.11906 .12366 L
.11906 .12652 L
.11906 .12938 L
.11906 .13224 L
.11906 .1351 L
.11906 .13796 L
.11906 .14082 L
.11906 .14368 L
.11906 .14654 L
.11906 .1494 L
.11906 .15226 L
.11906 .15512 L
.11906 .15798 L
.11906 .16084 L
.11906 .1637 L
.11906 .16656 L
.11906 .16942 L
.11906 .17228 L
.11906 .17514 L
.11906 .178 L
.11905 .18086 L
.11905 .18372 L
.11905 .18658 L
.11905 .18944 L
.11905 .1923 L
s
.14285 .10649 m
.14286 .10935 L
.14286 .11221 L
.14286 .11507 L
.14286 .11793 L
.14286 .1208 L
.14287 .12366 L
.14287 .12652 L
.14287 .12938 L
.14287 .13224 L
.14287 .1351 L
.14287 .13796 L
.14287 .14082 L
.14287 .14368 L
.14287 .14654 L
.14287 .1494 L
.14287 .15226 L
.14287 .15512 L
.14287 .15798 L
.14287 .16084 L
.14287 .16371 L
.14287 .16657 L
.14287 .16943 L
.14287 .17229 L
.14287 .17515 L
.14286 .17801 L
.14286 .18087 L
.14286 .18373 L
.14286 .18659 L
.14286 .18945 L
.14285 .19231 L
s
.16666 .10648 m
.16667 .10934 L
.16667 .1122 L
.16667 .11507 L
.16667 .11793 L
.16667 .12079 L
.16668 .12365 L
.16668 .12651 L
.16668 .12937 L
.16668 .13223 L
.16668 .1351 L
.16668 .13796 L
.16668 .14082 L
.16668 .14368 L
.16668 .14654 L
.16668 .1494 L
.16668 .15226 L
.16668 .15512 L
.16668 .15799 L
.16668 .16085 L
.16668 .16371 L
.16668 .16657 L
.16668 .16943 L
.16668 .17229 L
.16668 .17515 L
.16667 .17802 L
.16667 .18088 L
.16667 .18374 L
.16667 .1866 L
.16667 .18946 L
.16666 .19232 L
s
.19047 .10647 m
.19048 .10933 L
.19048 .1122 L
.19048 .11506 L
.19048 .11792 L
.19048 .12078 L
.19048 .12364 L
.19049 .12651 L
.19049 .12937 L
.19049 .13223 L
.19049 .13509 L
.19049 .13795 L
.19049 .14082 L
.19049 .14368 L
.19049 .14654 L
.19049 .1494 L
.19049 .15226 L
.19049 .15513 L
.19049 .15799 L
.19049 .16085 L
.19049 .16371 L
.19049 .16657 L
.19049 .16944 L
.19049 .1723 L
.19048 .17516 L
.19048 .17802 L
.19048 .18089 L
.19048 .18375 L
.19048 .18661 L
.19048 .18947 L
.19047 .19233 L
s
.21428 .10646 m
.21428 .10932 L
.21429 .11219 L
.21429 .11505 L
.21429 .11791 L
.21429 .12077 L
.21429 .12364 L
.2143 .1265 L
.2143 .12936 L
.2143 .13223 L
.2143 .13509 L
.2143 .13795 L
.2143 .14081 L
.2143 .14368 L
.2143 .14654 L
.2143 .1494 L
.2143 .15226 L
.2143 .15513 L
.2143 .15799 L
.2143 .16085 L
.2143 .16372 L
.2143 .16658 L
.2143 .16944 L
.2143 .1723 L
.21429 .17517 L
.21429 .17803 L
.21429 .18089 L
.21429 .18376 L
.21429 .18662 L
.21428 .18948 L
.21428 .19234 L
s
.23809 .10645 m
.23809 .10931 L
.2381 .11218 L
.2381 .11504 L
.2381 .1179 L
.2381 .12077 L
.2381 .12363 L
.2381 .12649 L
.23811 .12936 L
.23811 .13222 L
.23811 .13508 L
.23811 .13795 L
.23811 .14081 L
.23811 .14368 L
.23811 .14654 L
.23811 .1494 L
.23811 .15227 L
.23811 .15513 L
.23811 .15799 L
.23811 .16086 L
.23811 .16372 L
.23811 .16658 L
.23811 .16945 L
.2381 .17231 L
.2381 .17517 L
.2381 .17804 L
.2381 .1809 L
.2381 .18376 L
.2381 .18663 L
.23809 .18949 L
.23809 .19235 L
s
.26349 .10644 m
.26329 .1093 L
.2631 .11217 L
.26292 .11503 L
.26276 .1179 L
.26262 .12076 L
.26248 .12362 L
.26237 .12649 L
.26226 .12935 L
.26217 .13222 L
.26209 .13508 L
.26203 .13795 L
.26198 .14081 L
.26195 .14367 L
.26193 .14654 L
.26192 .1494 L
.26193 .15227 L
.26195 .15513 L
.26198 .15799 L
.26203 .16086 L
.26209 .16372 L
.26217 .16659 L
.26226 .16945 L
.26237 .17232 L
.26248 .17518 L
.26262 .17804 L
.26276 .18091 L
.26292 .18377 L
.2631 .18664 L
.26329 .1895 L
.26349 .19237 L
s
.28725 .10785 m
.28705 .11062 L
.28687 .11339 L
.2867 .11616 L
.28654 .11893 L
.2864 .1217 L
.28627 .12447 L
.28616 .12724 L
.28606 .13001 L
.28597 .13278 L
.2859 .13555 L
.28584 .13832 L
.28579 .14109 L
.28575 .14386 L
.28573 .14663 L
.28573 .1494 L
.28573 .15217 L
.28575 .15494 L
.28579 .15771 L
.28584 .16048 L
.2859 .16325 L
.28597 .16602 L
.28606 .16879 L
.28616 .17157 L
.28627 .17434 L
.2864 .17711 L
.28654 .17988 L
.2867 .18265 L
.28687 .18542 L
.28705 .18819 L
.28725 .19096 L
s
.31293 .10925 m
.31249 .11193 L
.31208 .11461 L
.31171 .11728 L
.31136 .11996 L
.31104 .12264 L
.31076 .12531 L
.3105 .12799 L
.31027 .13067 L
.31008 .13334 L
.30991 .13602 L
.30978 .1387 L
.30967 .14137 L
.3096 .14405 L
.30955 .14673 L
.30954 .1494 L
.30955 .15208 L
.3096 .15476 L
.30967 .15743 L
.30978 .16011 L
.30991 .16278 L
.31008 .16546 L
.31027 .16814 L
.3105 .17081 L
.31076 .17349 L
.31104 .17617 L
.31136 .17884 L
.31171 .18152 L
.31208 .1842 L
.31249 .18687 L
.31293 .18955 L
s
.33655 .11139 m
.33614 .11393 L
.33576 .11646 L
.3354 .119 L
.33507 .12153 L
.33477 .12406 L
.3345 .1266 L
.33426 .12913 L
.33404 .13166 L
.33386 .1342 L
.3337 .13673 L
.33357 .13927 L
.33347 .1418 L
.3334 .14433 L
.33336 .14687 L
.33335 .1494 L
.33336 .15194 L
.3334 .15447 L
.33347 .157 L
.33357 .15954 L
.3337 .16207 L
.33386 .16461 L
.33404 .16714 L
.33426 .16967 L
.3345 .17221 L
.33477 .17474 L
.33507 .17728 L
.3354 .17981 L
.33576 .18234 L
.33614 .18488 L
.33655 .18741 L
s
.36018 .11353 m
.35979 .11592 L
.35943 .11832 L
.35909 .12071 L
.35878 .1231 L
.3585 .12549 L
.35824 .12788 L
.35802 .13027 L
.35781 .13266 L
.35764 .13505 L
.35749 .13745 L
.35737 .13984 L
.35728 .14223 L
.35721 .14462 L
.35717 .14701 L
.35715 .1494 L
.35717 .15179 L
.35721 .15418 L
.35728 .15658 L
.35737 .15897 L
.35749 .16136 L
.35764 .16375 L
.35781 .16614 L
.35802 .16853 L
.35824 .17092 L
.3585 .17332 L
.35878 .17571 L
.35909 .1781 L
.35943 .18049 L
.35979 .18288 L
.36018 .18527 L
s
.38381 .11567 m
.38344 .11792 L
.3831 .12017 L
.38279 .12242 L
.38249 .12467 L
.38223 .12692 L
.38199 .12916 L
.38177 .13141 L
.38158 .13366 L
.38142 .13591 L
.38128 .13816 L
.38117 .14041 L
.38108 .14266 L
.38101 .1449 L
.38098 .14715 L
.38096 .1494 L
.38098 .15165 L
.38101 .1539 L
.38108 .15615 L
.38117 .1584 L
.38128 .16065 L
.38142 .16289 L
.38158 .16514 L
.38177 .16739 L
.38199 .16964 L
.38223 .17189 L
.38249 .17414 L
.38279 .17639 L
.3831 .17864 L
.38344 .18088 L
.38381 .18313 L
s
.40744 .11781 m
.4071 .11992 L
.40678 .12202 L
.40648 .12413 L
.40621 .12623 L
.40596 .12834 L
.40573 .13045 L
.40553 .13255 L
.40535 .13466 L
.4052 .13677 L
.40507 .13887 L
.40496 .14098 L
.40488 .14308 L
.40482 .14519 L
.40478 .1473 L
.40477 .1494 L
.40478 .15151 L
.40482 .15361 L
.40488 .15572 L
.40496 .15783 L
.40507 .15993 L
.4052 .16204 L
.40535 .16415 L
.40553 .16625 L
.40573 .16836 L
.40596 .17046 L
.40621 .17257 L
.40648 .17468 L
.40678 .17678 L
.4071 .17889 L
.40744 .18099 L
s
.43107 .11995 m
.43075 .12191 L
.43045 .12388 L
.43017 .12584 L
.42992 .1278 L
.42969 .12977 L
.42948 .13173 L
.42929 .13369 L
.42912 .13566 L
.42898 .13762 L
.42886 .13958 L
.42876 .14155 L
.42868 .14351 L
.42863 .14548 L
.42859 .14744 L
.42858 .1494 L
.42859 .15137 L
.42863 .15333 L
.42868 .15529 L
.42876 .15726 L
.42886 .15922 L
.42898 .16118 L
.42912 .16315 L
.42929 .16511 L
.42948 .16707 L
.42969 .16904 L
.42992 .171 L
.43017 .17296 L
.43045 .17493 L
.43075 .17689 L
.43107 .17886 L
s
.4547 .12209 m
.4544 .12391 L
.45412 .12573 L
.45387 .12755 L
.45363 .12937 L
.45342 .13119 L
.45322 .13301 L
.45305 .13483 L
.45289 .13666 L
.45276 .13848 L
.45265 .1403 L
.45255 .14212 L
.45248 .14394 L
.45243 .14576 L
.4524 .14758 L
.45239 .1494 L
.4524 .15122 L
.45243 .15304 L
.45248 .15486 L
.45255 .15669 L
.45265 .15851 L
.45276 .16033 L
.45289 .16215 L
.45305 .16397 L
.45322 .16579 L
.45342 .16761 L
.45363 .16943 L
.45387 .17125 L
.45412 .17307 L
.4544 .1749 L
.4547 .17672 L
s
.47832 .12423 m
.47805 .12591 L
.4778 .12758 L
.47756 .12926 L
.47734 .13094 L
.47714 .13262 L
.47696 .1343 L
.4768 .13598 L
.47666 .13765 L
.47654 .13933 L
.47644 .14101 L
.47635 .14269 L
.47628 .14437 L
.47624 .14605 L
.47621 .14772 L
.4762 .1494 L
.47621 .15108 L
.47624 .15276 L
.47628 .15444 L
.47635 .15612 L
.47644 .15779 L
.47654 .15947 L
.47666 .16115 L
.4768 .16283 L
.47696 .16451 L
.47714 .16619 L
.47734 .16786 L
.47756 .16954 L
.4778 .17122 L
.47805 .1729 L
.47832 .17458 L
s
.50195 .12637 m
.5017 .1279 L
.50147 .12944 L
.50125 .13097 L
.50105 .13251 L
.50087 .13404 L
.50071 .13558 L
.50056 .13712 L
.50043 .13865 L
.50032 .14019 L
.50023 .14172 L
.50015 .14326 L
.50009 .14479 L
.50004 .14633 L
.50002 .14787 L
.50001 .1494 L
.50002 .15094 L
.50004 .15247 L
.50009 .15401 L
.50015 .15555 L
.50023 .15708 L
.50032 .15862 L
.50043 .16015 L
.50056 .16169 L
.50071 .16322 L
.50087 .16476 L
.50105 .1663 L
.50125 .16783 L
.50147 .16937 L
.5017 .1709 L
.50195 .17244 L
s
.52558 .1285 m
.52535 .1299 L
.52514 .13129 L
.52495 .13268 L
.52477 .13408 L
.5246 .13547 L
.52445 .13686 L
.52432 .13826 L
.5242 .13965 L
.5241 .14104 L
.52401 .14244 L
.52394 .14383 L
.52389 .14522 L
.52385 .14662 L
.52383 .14801 L
.52382 .1494 L
.52383 .1508 L
.52385 .15219 L
.52389 .15358 L
.52394 .15497 L
.52401 .15637 L
.5241 .15776 L
.5242 .15915 L
.52432 .16055 L
.52445 .16194 L
.5246 .16333 L
.52477 .16473 L
.52495 .16612 L
.52514 .16751 L
.52535 .16891 L
.52558 .1703 L
s
.54921 .13064 m
.54901 .13189 L
.54882 .13314 L
.54864 .1344 L
.54848 .13565 L
.54833 .1369 L
.5482 .13815 L
.54808 .1394 L
.54797 .14065 L
.54788 .1419 L
.5478 .14315 L
.54774 .1444 L
.54769 .14565 L
.54766 .1469 L
.54763 .14815 L
.54763 .1494 L
.54763 .15065 L
.54766 .1519 L
.54769 .15315 L
.54774 .1544 L
.5478 .15566 L
.54788 .15691 L
.54797 .15816 L
.54808 .15941 L
.5482 .16066 L
.54833 .16191 L
.54848 .16316 L
.54864 .16441 L
.54882 .16566 L
.54901 .16691 L
.54921 .16816 L
s
.57284 .13278 m
.57266 .13389 L
.57249 .135 L
.57233 .13611 L
.57219 .13721 L
.57206 .13832 L
.57194 .13943 L
.57184 .14054 L
.57174 .14165 L
.57166 .14275 L
.57159 .14386 L
.57154 .14497 L
.57149 .14608 L
.57146 .14719 L
.57144 .14829 L
.57144 .1494 L
.57144 .15051 L
.57146 .15162 L
.57149 .15273 L
.57154 .15383 L
.57159 .15494 L
.57166 .15605 L
.57174 .15716 L
.57184 .15827 L
.57194 .15937 L
.57206 .16048 L
.57219 .16159 L
.57233 .1627 L
.57249 .16381 L
.57266 .16491 L
.57284 .16602 L
s
.59647 .13492 m
.59631 .13589 L
.59616 .13685 L
.59603 .13782 L
.5959 .13878 L
.59579 .13975 L
.59569 .14071 L
.59559 .14168 L
.59551 .14264 L
.59544 .14361 L
.59538 .14458 L
.59533 .14554 L
.59529 .14651 L
.59527 .14747 L
.59525 .14844 L
.59525 .1494 L
.59525 .15037 L
.59527 .15133 L
.59529 .1523 L
.59533 .15326 L
.59538 .15423 L
.59544 .15519 L
.59551 .15616 L
.59559 .15713 L
.59569 .15809 L
.59579 .15906 L
.5959 .16002 L
.59603 .16099 L
.59616 .16195 L
.59631 .16292 L
.59647 .16388 L
s
.6201 .13706 m
.61996 .13788 L
.61984 .13871 L
.61972 .13953 L
.61961 .14035 L
.61952 .14117 L
.61943 .142 L
.61935 .14282 L
.61928 .14364 L
.61922 .14447 L
.61917 .14529 L
.61913 .14611 L
.6191 .14693 L
.61907 .14776 L
.61906 .14858 L
.61905 .1494 L
.61906 .15022 L
.61907 .15105 L
.6191 .15187 L
.61913 .15269 L
.61917 .15352 L
.61922 .15434 L
.61928 .15516 L
.61935 .15598 L
.61943 .15681 L
.61952 .15763 L
.61961 .15845 L
.61972 .15928 L
.61984 .1601 L
.61996 .16092 L
.6201 .16174 L
s
.64372 .1392 m
.64361 .13988 L
.64351 .14056 L
.64341 .14124 L
.64333 .14192 L
.64325 .1426 L
.64317 .14328 L
.64311 .14396 L
.64305 .14464 L
.643 .14532 L
.64296 .146 L
.64292 .14668 L
.6429 .14736 L
.64288 .14804 L
.64287 .14872 L
.64286 .1494 L
.64287 .15008 L
.64288 .15076 L
.6429 .15144 L
.64292 .15212 L
.64296 .1528 L
.643 .15348 L
.64305 .15416 L
.64311 .15484 L
.64317 .15552 L
.64325 .1562 L
.64333 .15688 L
.64341 .15756 L
.64351 .15824 L
.64361 .15892 L
.64372 .15961 L
s
.66735 .14134 m
.66727 .14188 L
.66718 .14241 L
.66711 .14295 L
.66704 .14349 L
.66698 .14403 L
.66692 .14456 L
.66687 .1451 L
.66682 .14564 L
.66678 .14618 L
.66675 .14671 L
.66672 .14725 L
.6667 .14779 L
.66668 .14833 L
.66668 .14886 L
.66667 .1494 L
.66668 .14994 L
.66668 .15048 L
.6667 .15101 L
.66672 .15155 L
.66675 .15209 L
.66678 .15263 L
.66682 .15317 L
.66687 .1537 L
.66692 .15424 L
.66698 .15478 L
.66704 .15532 L
.66711 .15585 L
.66718 .15639 L
.66727 .15693 L
.66735 .15747 L
s
.69098 .14348 m
.69092 .14387 L
.69086 .14427 L
.6908 .14466 L
.69075 .14506 L
.6907 .14545 L
.69066 .14585 L
.69062 .14624 L
.69059 .14664 L
.69056 .14703 L
.69054 .14743 L
.69052 .14782 L
.6905 .14822 L
.69049 .14861 L
.69048 .14901 L
.69048 .1494 L
.69048 .1498 L
.69049 .15019 L
.6905 .15059 L
.69052 .15098 L
.69054 .15138 L
.69056 .15177 L
.69059 .15217 L
.69062 .15256 L
.69066 .15296 L
.6907 .15335 L
.69075 .15375 L
.6908 .15414 L
.69086 .15454 L
.69092 .15493 L
.69098 .15533 L
s
.71461 .14562 m
.71457 .14587 L
.71453 .14612 L
.7145 .14637 L
.71446 .14663 L
.71443 .14688 L
.71441 .14713 L
.71438 .14738 L
.71436 .14764 L
.71434 .14789 L
.71433 .14814 L
.71431 .14839 L
.7143 .14864 L
.7143 .1489 L
.71429 .14915 L
.71429 .1494 L
.71429 .14965 L
.7143 .14991 L
.7143 .15016 L
.71431 .15041 L
.71433 .15066 L
.71434 .15092 L
.71436 .15117 L
.71438 .15142 L
.71441 .15167 L
.71443 .15193 L
.71446 .15218 L
.7145 .15243 L
.71453 .15268 L
.71457 .15294 L
.71461 .15319 L
s
.73824 .14775 m
.73822 .14786 L
.7382 .14797 L
.73819 .14808 L
.73817 .14819 L
.73816 .1483 L
.73815 .14841 L
.73814 .14852 L
.73813 .14863 L
.73812 .14874 L
.73812 .14885 L
.73811 .14896 L
.73811 .14907 L
.7381 .14918 L
.7381 .14929 L
.7381 .1494 L
.7381 .14951 L
.7381 .14962 L
.73811 .14973 L
.73811 .14984 L
.73812 .14995 L
.73812 .15006 L
.73813 .15017 L
.73814 .15028 L
.73815 .15039 L
.73816 .1505 L
.73817 .15061 L
.73819 .15072 L
.7382 .15083 L
.73822 .15094 L
.73824 .15105 L
s
.76187 .14891 m
.76187 .14894 L
.76188 .14898 L
.76188 .14901 L
.76189 .14904 L
.76189 .14907 L
.76189 .14911 L
.7619 .14914 L
.7619 .14917 L
.7619 .14921 L
.7619 .14924 L
.76191 .14927 L
.76191 .1493 L
.76191 .14934 L
.76191 .14937 L
.76191 .1494 L
.76191 .14943 L
.76191 .14947 L
.76191 .1495 L
.76191 .14953 L
.7619 .14957 L
.7619 .1496 L
.7619 .14963 L
.7619 .14966 L
.76189 .1497 L
.76189 .14973 L
.76189 .14976 L
.76188 .1498 L
.76188 .14983 L
.76187 .14986 L
.76187 .14989 L
s
.7855 .14677 m
.78552 .14695 L
.78555 .14712 L
.78558 .1473 L
.7856 .14747 L
.78562 .14765 L
.78564 .14782 L
.78565 .148 L
.78567 .14817 L
.78568 .14835 L
.78569 .14853 L
.7857 .1487 L
.78571 .14888 L
.78571 .14905 L
.78572 .14923 L
.78572 .1494 L
.78572 .14958 L
.78571 .14975 L
.78571 .14993 L
.7857 .1501 L
.78569 .15028 L
.78568 .15045 L
.78567 .15063 L
.78565 .1508 L
.78564 .15098 L
.78562 .15116 L
.7856 .15133 L
.78558 .15151 L
.78555 .15168 L
.78552 .15186 L
.7855 .15203 L
s
.80912 .14463 m
.80918 .14495 L
.80922 .14527 L
.80927 .14559 L
.80931 .1459 L
.80935 .14622 L
.80938 .14654 L
.80941 .14686 L
.80944 .14718 L
.80946 .14749 L
.80948 .14781 L
.8095 .14813 L
.80951 .14845 L
.80952 .14877 L
.80953 .14908 L
.80953 .1494 L
.80953 .14972 L
.80952 .15004 L
.80951 .15036 L
.8095 .15067 L
.80948 .15099 L
.80946 .15131 L
.80944 .15163 L
.80941 .15195 L
.80938 .15226 L
.80935 .15258 L
.80931 .1529 L
.80927 .15322 L
.80922 .15354 L
.80918 .15385 L
.80912 .15417 L
s
.83275 .14249 m
.83283 .14295 L
.8329 .14342 L
.83296 .14388 L
.83302 .14434 L
.83308 .1448 L
.83313 .14526 L
.83317 .14572 L
.83321 .14618 L
.83324 .14664 L
.83327 .1471 L
.83329 .14756 L
.83331 .14802 L
.83333 .14848 L
.83333 .14894 L
.83334 .1494 L
.83333 .14986 L
.83333 .15032 L
.83331 .15078 L
.83329 .15124 L
.83327 .1517 L
.83324 .15217 L
.83321 .15263 L
.83317 .15309 L
.83313 .15355 L
.83308 .15401 L
.83302 .15447 L
.83296 .15493 L
.8329 .15539 L
.83283 .15585 L
.83275 .15631 L
s
.85638 .14036 m
.85648 .14096 L
.85657 .14156 L
.85666 .14216 L
.85673 .14277 L
.85681 .14337 L
.85687 .14397 L
.85693 .14458 L
.85698 .14518 L
.85702 .14578 L
.85706 .14639 L
.85709 .14699 L
.85711 .14759 L
.85713 .1482 L
.85714 .1488 L
.85715 .1494 L
.85714 .15001 L
.85713 .15061 L
.85711 .15121 L
.85709 .15181 L
.85706 .15242 L
.85702 .15302 L
.85698 .15362 L
.85693 .15423 L
.85687 .15483 L
.85681 .15543 L
.85673 .15604 L
.85666 .15664 L
.85657 .15724 L
.85648 .15785 L
.85638 .15845 L
s
.88001 .13822 m
.88013 .13896 L
.88025 .13971 L
.88035 .14045 L
.88045 .1412 L
.88053 .14194 L
.88061 .14269 L
.88069 .14344 L
.88075 .14418 L
.8808 .14493 L
.88085 .14567 L
.88089 .14642 L
.88092 .14717 L
.88094 .14791 L
.88095 .14866 L
.88095 .1494 L
.88095 .15015 L
.88094 .15089 L
.88092 .15164 L
.88089 .15239 L
.88085 .15313 L
.8808 .15388 L
.88075 .15462 L
.88069 .15537 L
.88061 .15611 L
.88053 .15686 L
.88045 .15761 L
.88035 .15835 L
.88025 .1591 L
.88013 .15984 L
.88001 .16059 L
s
.90364 .13608 m
.90378 .13697 L
.90392 .13785 L
.90404 .13874 L
.90416 .13963 L
.90426 .14052 L
.90436 .14141 L
.90444 .1423 L
.90452 .14318 L
.90458 .14407 L
.90464 .14496 L
.90468 .14585 L
.90472 .14674 L
.90474 .14763 L
.90476 .14851 L
.90476 .1494 L
.90476 .15029 L
.90474 .15118 L
.90472 .15207 L
.90468 .15296 L
.90464 .15384 L
.90458 .15473 L
.90452 .15562 L
.90444 .15651 L
.90436 .1574 L
.90426 .15829 L
.90416 .15917 L
.90404 .16006 L
.90392 .16095 L
.90378 .16184 L
.90364 .16273 L
s
.92727 .13394 m
.92744 .13497 L
.92759 .136 L
.92774 .13703 L
.92787 .13806 L
.92799 .13909 L
.9281 .14012 L
.9282 .14115 L
.92829 .14219 L
.92836 .14322 L
.92843 .14425 L
.92848 .14528 L
.92852 .14631 L
.92855 .14734 L
.92857 .14837 L
.92857 .1494 L
.92857 .15043 L
.92855 .15146 L
.92852 .15249 L
.92848 .15353 L
.92843 .15456 L
.92836 .15559 L
.92829 .15662 L
.9282 .15765 L
.9281 .15868 L
.92799 .15971 L
.92787 .16074 L
.92774 .16177 L
.92759 .1628 L
.92744 .16383 L
.92727 .16487 L
s
.9509 .1318 m
.95109 .13297 L
.95127 .13415 L
.95143 .13532 L
.95158 .13649 L
.95172 .13767 L
.95185 .13884 L
.95196 .14001 L
.95206 .14119 L
.95214 .14236 L
.95222 .14353 L
.95228 .14471 L
.95232 .14588 L
.95235 .14706 L
.95237 .14823 L
.95238 .1494 L
.95237 .15058 L
.95235 .15175 L
.95232 .15292 L
.95228 .1541 L
.95222 .15527 L
.95214 .15644 L
.95206 .15762 L
.95196 .15879 L
.95185 .15996 L
.95172 .16114 L
.95158 .16231 L
.95143 .16348 L
.95127 .16466 L
.95109 .16583 L
.9509 .167 L
s
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[12]:=",
  ImageSize->{531, 146},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008C0000TR000`400?l00000o`00003ooooooooo
oooooaGooooo003ooooooooooooo5Oooool00?oooooooooooolEooooo`00oooooooooooooaGooooo
002Gooooo`Ko0000oooooomQooooo`?o00004oooool009Sooooo00Go0000ooooooooooooooooo`00
003oooooof7ooooo00Co0000oooooooooooo00004_ooool009Sooooo00?o0000ooooooooool0oooo
oomVooooo`03o`000?oooooooooo013ooooo002Hooooo`03o`000?oooooooooo0?ooooooI?ooool2
o`0001?ooooo002Hooooo`03o`000?oooooooooo0?ooooooHoooool00ol0003oooooooooo`0Coooo
o`00V?ooool00ol0003oooooooooo`3oooooof?ooooo00Co0000oooooooooooo00004_ooool009Oo
oooo0ol0003oooooofGooooo0ol0000Booooo`00oooooooooooooaGooooo003ooooooooooooo5Ooo
ool00?oooooooooooolEooooo`00oooooooooooooaGooooo003ooooooooooooo5Oooool00?oooooo
oooooolEooooo`00oooooooooooooaGooooo003ooooooooooooo5Oooool009gooooo2_l0003ooooo
oeWooooo00?o0000ooooooooool04Oooool009gooooo00?o0000ogmoOomoOgl01_moOgl00ol0003o
ooooooooo`3ooooooeOooooo00?o0000ooooooooool04Oooool009cooooo2ol0003ooooooeWooooo
00?o0000ooooooooool04Oooool009cooooo0_l00008ogmoO`03o`000?oooooooooo0?ooooooEooo
ool00ol0003oooooooooo`0Aooooo`00Voooool00ol0003oOgmoo`000008ogmoO`03o`000?oooooo
oooo0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00Voooool00ol0003oOgmoo`000008ogmo
O`03o`000?oooooooooo0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00Voooool00ol0003o
Ogmoo`000008ogmoO`03o`000?oooooooooo0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00
V_ooool01?l0003oOgmoogmoOol00008ogmoO`03o`000?oooooooooo0?ooooooEoooool00ol0003o
ooooooooo`0Aooooo`00V_ooool00ol0003oOgmoogmoO`0:o`000?ooooooFOooool00ol0003ooooo
ooooo`0Aooooo`00VOooool01Ol0003oOgmoogmoOomoOgoo000000SoOgmo00?o0000ooooooooool0
oooooomGooooo`03o`000?oooooooooo017ooooo002Iooooo`05o`000?moOgooOgmoogmoOol00000
2?moOgl00ol0003oooooooooo`3ooooooeOooooo00?o0000ooooooooool04Oooool009Sooooo00?o
0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooooooo0?ooooooEooo
ool00ol0003oooooooooo`0Aooooo`00V?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgoo
Ogmo00KoOgmo00?o0000ooooooooool0oooooomGooooo`03o`000?oooooooooo017ooooo002Goooo
o`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`3ooooo
oeOooooo00?o0000ooooooooool04Oooool009Oooooo00?o0000ogmoOomoOgl00omoOgl00ol0003o
OgmoogmoO`06ogmoO`03o`000?oooooooooo0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00
U_ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0
oooooomGooooo`03o`000?oooooooooo017ooooo002Fooooo`03o`000?moOgooOgmo00CoOgmo00?o
0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`3ooooooeOooooo00?o0000ooooooooool04Ooo
ool009Kooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooo
oooo0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00UOooool00ol0003oOgmoogmoO`05ogmo
O`[o0000oooooomIooooo`03o`000?oooooooooo017ooooo002Eooooo`03o`000?moOgooOgmo00Go
Ogmo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`3ooooooeOooooo00?o0000oooooooo
ool04Oooool009Cooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`06ogmoO`03o`00
0?oooooooooo0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00U?ooool00ol0003oOgmoogmo
O`06ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0oooooomGooooo`03o`000?oo
oooooooo017ooooo002Dooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl01_moOgl0
0ol0003oooooooooo`3ooooooeOooooo00?o0000ooooooooool04Oooool009?ooooo00?o0000ogmo
OomoOgl01omoOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooooooo0?ooooooEoooool00ol0
003oooooooooo`0Aooooo`00Toooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00Ko
Ogmo00?o0000ooooooooool0oooooomGooooo`03o`000?oooooooooo017ooooo002Cooooo`03o`00
0?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`3ooooooeOooooo
00?o0000ooooooooool04Oooool009?ooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmo
O`06ogmoO`03o`000?oooooooooo0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00T_ooool0
0ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0oooooomG
ooooo`03o`000?oooooooooo017ooooo002Booooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmo
OomoOgl01_moOgl00ol0003oooooooooo`3ooooooeOooooo00?o0000ooooooooool04Oooool009;o
oooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooooooo0?oo
ooooEoooool00ol0003oooooooooo`0Aooooo`00T_ooool00ol0003oOgmoogmoO`08ogmoO`03o`00
0?moOgooOgmo00KoOgmo00?o0000ooooooooool0oooooomGooooo`03o`000?oooooooooo017ooooo
002Aooooo`03o`000?moOgooOgmo00WoOgmo2_l0003ooooooeWooooo00?o0000ooooooooool04Ooo
ool0097ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooo
oooo0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00TOooool00ol0003oOgmoogmoO`09ogmo
O`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0oooooomGooooo`03o`000?oooooooooo
017ooooo002Aooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003o
ooooooooo`3ooooooeOooooo00?o0000ooooooooool04Oooool008Sooooo0ol9jPX6ooooo`03o`00
0?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`3ooooooeOooooo
00?o0000ooooooooool04Oooool008Wooooo1_l9jPX2o`0000coOgmo00Co0000o`WZ2_l9jP[o2NX:
1OmoOgl00ol0003oooooooooo`3ooooooeOooooo00?o0000ooooooooool04Oooool001;oooooR_l9
jPX00omoOgoo0000ogmoO`06o`WZ2P03ogmoOol0003ooooo0?ooooooF?ooool00ol0003ooooooooo
o`0Aooooo`00ROooool5o`WZ2P;ooooo00?o0000ogmoOomoOgl02?moOglAo`WZ2_ooooooE?ooool0
0ol0003oooooooooo`0Aooooo`004_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`04ooooo`;o2NX:1?ooool00ol9
jP[oooooo`00000<ogmoO`03o`000?moOgoo2NX:00Co2NX:00?oOgmoo`000?l000001?ooool;o`WZ
2_ooooooB_ooool00ol0003oooooooooo`0Aooooo`004_ooool00ol9jP[oooooooooo`09ooooo`03
o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03
o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03
o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_l0003oOgmo00WoOgmo00Co2NX:ogmoOomoOgoo00000_l9jPX6ogmoO`03o`000?oooooooooo
00[ooooo3Ol9jP[ooooood3ooooo00?o0000ooooooooool04Oooool001;ooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02_ooool00ol9jP[o0000ogmoO`09ogmoO`04o`WZ2_moOgooOgmoo`0000SoOgmo00?o0000oooo
ool9jPX04oooool>o`WZ2_oooooo=_ooool00ol0003oooooooooo`0Aooooo`004_ooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_l0003oOgmo00WoOgmo00Co2NX:ogmoOomoOgoo00002?moOgl00ol0
003o2NX:ooooo`0;ooooo`03o`WZ2_oooooooooo00gooooo4?l9jP[oooooobcooooo00?o0000oooo
ooooool04Oooool001;ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[o0000ogmoO`09ogmoO`04
o`WZ2_moOgooOgmoo`0000SoOgmo00?o0000o`WZ2_ooool02oooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo013ooooo2_l9jP[oooooob?ooooo00?o0000ooooooooool04Oooool001;o
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wo
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wo
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wo
oooo00?o2NX:ooooooooool02_ooool00ol9jP[o0000ogmoO`09ogmoO`04o`WZ2_moOgooOgmoo`00
00SoOgmo00?o0000o`WZ2_ooool02_ooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool03Oooool;o`WZ2_oooooo6Oooool00ol0003oooooooooo`0Aoooo
o`004_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_l0003oOgmo00WoOgmo00Co2NX:ogmoOomo
Ogoo00002?moOgl00ol0003o2NX:ooooo`0:ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:oooo
ooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo3?l9jP[ooooo
o`oooooo00?o0000ooooooooool04Oooool001;ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[o
0000ogmoO`09ogmoO`03o`WZ2_moOgooOgmo00[o000000?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Gooooo3_l9jP[oooooo`Gooooo00?o0000oooooooo
ool04Oooool001;ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ
2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ
2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ
2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oOgmoogmoO`09ogmoO`04o`WZ
2_moOgooOgmoo`0000SoOgmo00?o0000o`WZ2_ooool02_ooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_oooooooooo00Wooooo00Co2NX:oooooooooooooooo4Ol9jP[iooooo`03o`000?oooooooooo
017ooooo000Booooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ogmoOomoOgl02OmoOgl01?l9jP[o
OgmoogmoOol00008ogmoO`03o`000?l9jP[ooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool01Oooool:o`WZ
2_3ooooo00?o0000ooooooooool04Oooool001;ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[o
OgmoogmoO`09ogmoO`04o`WZ2_moOgooOgmoo`0000SoOgmo00?o0000o`WZ2_ooool02_ooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`0>ooooo`[o2NX:goooool5o`WZ2P?ooooo0_l0000Booooo`004_ooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_l0003oOgmo00[oOgmo00Co2NX:ogmoOomoOgoo00002?moOgl00ol9
jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo0_l9jPX;ooooo`co2NX:eoooool7o`WZ
2P03o`000?oooooooooo013ooooo000Booooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02_ooool00ol9jP[oooooooooo`09ooooo`04o`WZ2_ooooooooooooooo`?o2NX:1Oooool00ol9
jP[o0000ogmoO`0:ogmoO`04o`WZ2_moOgooOgmoo`0000SoOgmo00?o2NX:ooooooooool02_ooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool01OoooolA
o`WZ2/7ooooo3Ol9jPX2ooooo`03o`000?oooooooooo017ooooo000Booooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00;ooooo1_l9jPX00ooooooo2NX:o`00000;ogmoO`04o`WZ2_moOgooOgmoo`0000?o2NX:1OmoOgl0
0ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool0
0ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool0
0ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Oooooo2ol9jPZ_ooooo`go2NX:1?ooool2
o`WZ2PKooooo00?o0000ooooooooool04Oooool001;oooooROl9jPX2ogmoO`03o`000?moOgoo2NX:
00Go2NX:00?o0000o`WZ2_ooool02oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Gooooo2_l9jPZJoooooa7o2NX:1oooool00ol9jP[oooooooooo`0:ooooo`03o`000?oooooooooo
017ooooo000Booooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00;ooooo1Ol9jPX2ooooo`03o`WZ2_l0003oOgmo00[o
Ogmo2ol9jPX00ol0003o2NX:o`WZ2P0?o`WZ2PSooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`02ooooo`_o2NX:R?ooool:o`WZ2P[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`000?oooooooooo017ooooo000Booooo`03o`WZ2_oooooooooo00Wooooo
00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo
00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo
00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`04o`WZ2_ooooooooooooooo`;o
2NX:1_ooool00ol9jP[o0000ogmoO`0:ogmoO`05o`WZ2_moOgooOgmoo`000?moOgl01Ol9jPX2ogmo
O`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool00_oooolOo`WZ2P03ooooool9jP[ooooo
00_ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`go2NX:MOooool:o`WZ
2PKooooo0_l9jPX;ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol0
003oooooooooo`0Aooooo`004_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[o
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[o
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[o
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_l0003oOgmo00[o
Ogmo00Co2NX:ogmoOomoOgoo00000_l9jPX6ogmoO`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooo
ooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Sooooo7ol9jPX7oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09oooo
o`;o2NX:1ooooolAo`WZ2Uoooooo2ol9jPX3ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:oooo
ooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00;ooooo0ol9jPX5oooo
o`03o`000?oooooooooo017ooooo000Booooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ogmoOomo
Ogl02_moOgl01?l9jP[oOgmoogmoOol00008ogmoO`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooo
ooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooo
ooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00;ooooo8Ol9jPX;oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool01oooool;o`WZ2TWooooo4Ol9jPX;oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:oooo
o`03o`WZ2_oooooooooo00;ooooo1_l9jPX00ooooooo0000o`00000Booooo`004_ooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_moOgooOgmo00[oOgmo00Co2NX:ogmoOomoOgoo00002?moOgl00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02OoooolOo`WZ
2PKooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool01Oooool:o`WZ2SSooooo3Ol9jPX;ooooo`03o`WZ2_oooooooooo
00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Kooooo4?l9jPX2o`0001;ooooo000Booooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02_ooool00ol9jP[oooooooooo`09ooooo`04o`WZ2_ooooooooooooooo`?o00001Oooool00ol9
jP[oOgmoogmoO`0:ogmoO`03o`WZ2_moOgooOgmo00Co00001OmoOgl00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool00ooooolPo`WZ2P_ooooo00?o2NX:oooo
ooooool02Oooool00ol9jP[oooooooooo`02ooooo`_o2NX:9_ooool:o`WZ2P[ooooo00?o2NX:oooo
ooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooo2NX:01ko2NX:1?ooool01?l9
jP[oooooooooooooool3o`0000?o2NX:0_ooool00ol0003oooooooooo`0Aooooo`004_ooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`02ooooo`Ko000000?oooooo`WZ2_moOgl02omoOgl01Ol9jP[oOgmoogmoOol0003o
Ogmo00Ko000000?oOgmoo`WZ2_ooool02_ooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooob7o2NX:1Oooool=
o`WZ2Q;ooooo2_l9jPX8ooooo`03o`WZ2_oooooooooo00Gooooo7ol9jPX:ooooo`03o`WZ2_oooooo
oooo00Wooooo00?o2NX:ooooooooool02_ooool01Ol9jP[ooooooooooooooooo2NX:00Ko000000?o
ooooo`000?ooool04_ooool001;ooooo00?o2NX:o`000?l000002Ol000000ol9jP[o0000o`00000:
o`000003o`WZ2_l0003o000000Wo000000?o2NX:o`000?l000002Ol000000ol9jP[o0000o`00000:
o`000003o`WZ2_l0003o000000Wo000000?o2NX:o`000?l000002Ol000000ol9jP[o0000o`00000:
o`000003o`WZ2_l0003o000000Wo000000?o2NX:o`000?l000002Ol000000ol9jP[o0000o`00000:
o`000003o`WZ2_l0003o000000Wo000000?o2NX:o`000?l000002Ol000000ol9jP[o0000o`00000:
o`000003o`WZ2_l0003o000000Wo000000?o2NX:o`000?l000002Ol000000ol9jP[o0000o`00000:
o`000003o`WZ2_l0003o000000Wo000000?o2NX:o`000?l000002Ol000000ol9jP[o0000o`00000:
o`000003o`WZ2_l0003o000000Wo000000?o2NX:o`000?l000002Ol000000ol9jP[o0000o`000009
o`000003o`WZ2_l0003o000000[o000000?o2NX:o`000?l000002Ol000000ol9jP[o0000o`000009
o`000003o`WZ2_l0003o000000[o000000?o2NX:o`000?l000002Ol000000ol9jP[o0000o`000009
o`000003o`WZ2_l0003o000000[o000000?o2NX:o`000?l000002Ol000000ol9jP[o0000o`000009
o`000003o`WZ2_l0003o000000[o000000?o2NX:o`000?l000002Ol000000ol9jP[o0000o`000009
o`000003o`WZ2_l0003o000000[o000000?o2NX:o`000?l000002Ol000000ol9jP[o0000o`000009
o`000003o`WZ2_l0003o000000[o000000?o2NX:o`000?l000002_l0000Cooooo`004_ooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`02ooooo`Go00000_ooool00ol9jP[oOgmoogmoO`0:ogmoO`05o`WZ2_moOgooOgmo
o`000?moOgl01Ol00002ogmoO`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool0
0ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool0
0ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool01?oooom0
o`WZ2P?ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo00;ooooo1Ol00002ooooo`03o`000?oooooooooo017ooooo000Booooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`04o`WZ2_oooooooooo
ooooo`;o00001_ooool00ol9jP[oOgmoogmoO`0:ogmoO`03o`WZ2_moOgooOgmo00?o00001_moOgl0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo8?l9jPX6ooooo`co2NX:5Oooool9
o`WZ2POooooo00?o2NX:ooooooooool01_oooolOo`WZ2PWooooo00?o2NX:ooooooooool02Oooool0
0ol9jP[oooooooooo`0:ooooo`04o`WZ2_ooooooooooooooo`;o000000?o2NX:ooooooooool00ooo
ool00ol0003oooooooooo`0Aooooo`004_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooo
oooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooo
oooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooo
oooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_moOgoo
Ogmo00[oOgmo00Co2NX:ogmoOomoOgoo00002?moOgl00ol9jP[oooooooooo`09ooooo`03o`WZ2_oo
oooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oo
oooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oo
oooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oo
oooooooo00[ooooo00?o2NX:ooooooooool00_oooolOo`WZ2P03ooooool9jP[ooooo00[ooooo00?o
2NX:ooooooooool02Oooool01?l9jP[oooooooooooooool;o`WZ2RSooooo2_l9jPX9ooooo`03o`WZ
2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`0Oo`WZ2P?ooooo
00?o2NX:ooooooooool00_ooool6o`WZ2P03ooooool0003ooooo01;ooooo000Booooo`03o`WZ2_oo
oooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oo
oooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oo
oooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oo
oooooooo00Wooooo00?o2NX:ogmoOomoOgl02_moOgl01?l9jP[oOgmoogmoOol00008ogmoO`03o`WZ
2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ
2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ
2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`08oooooaoo2NX:
1oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool0
2Oooool00ol9jP[oooooooooo`04ooooo`[o2NX:>_ooool@o`WZ2POooooo00?o2NX:ooooooooool0
2_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool0
1oooool?o`WZ2P;o00004_ooool001;ooooo00?o2NX:ooooooooool02Oooool00ol9jP[ooooooooo
o`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[ooooooooo
o`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[ooooooooo
o`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oOgmoogmo
O`0:ogmoO`04o`WZ2_moOgooOgmoo`0000SoOgmo00?o2NX:ooooooooool02Oooool00ol9jP[ooooo
ooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[ooooo
ooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00Co2NX:oooooooooooooooo8?l9jPX00ooooooo
2NX:ooooo`0:ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool01_ooool;o`WZ2Too
oooo3Ol9jPX:ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00;ooooo1Ol9jPX2ooooo`;o00004_ooool001;ooooo
00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo
00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo
00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo
00?o2NX:ooooooooool02Oooool00ol9jP[o0000ogmoO`0:ogmoO`04o`WZ2_moOgooOgmoo`0000?o
2NX:1OmoOgl00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`07oooooaoo2NX:2?ooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool2o`WZ2PKooooo4Ol9jPYQooooo`_o
2NX:0_ooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`02ooooo`;o2NX:1_ooool00ol0003oooooooooo`0Aooooo`00
4_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool0
2Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool0
2Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool0
2Oooool01?l9jP[oooooooooooooool3o`WZ2PGooooo00?o2NX:o`000?moOgl02_moOgl01Ol9jP[o
OgmoogmoOol0003oOgmo00Ko2NX:00?oOgmoo`WZ2_ooool02_ooool01?l9jP[ooooooooooooooolO
o`WZ2P;ooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooo
oooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooo
oooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooo
oooo00Wooooo3?l9jPYhooooo`[o2NX:1Oooool2o`WZ2P_ooooo00?o2NX:ooooooooool02Oooool0
0ol9jP[oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo000Booooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00;ooooo1_l9jPX00ooooooo2NX:o`00000;ogmoO`_o2NX:00?o0000o`WZ2_l9jPX03_l9jPX9oooo
o`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:oooo
o`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00Wooooo00Co2NX:oooooooooooooooo2ol9jPZ:ooooo`_o2NX:2?ooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o0000ooooooooool04Oooool0
01;oooooROl9jPX2ogmoO`03o`000?moOgoo2NX:00Co2NX:00?oOgmoo`000?l9jPX02oooool00ol9
jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Cooooo2_l9jPZLoooooa7o2NX:1_ooool00ol9
jP[oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo000Booooo`03o`WZ2_oooooooooo00Wo
oooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wo
oooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wo
oooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00;o
oooo1Ol9jPX2ooooo`03o`WZ2_l0003oOgmo00[oOgmo00Co2NX:ogmoOomoOgoo00000_l9jPX6ogmo
O`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:oooo
o`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool04Ol9jPZaooooo`go2NX:0oooool3o`WZ
2PGooooo00?o0000ooooooooool04Oooool001;ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00Co2NX:oooooooooooooooo0_l9jPX6oooo
o`03o`WZ2_l0003oOgmo00[oOgmo00Co2NX:ogmoOomoOgoo00002?moOgl00ol9jP[oooooooooo`0:
ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:
ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:
ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`04
ooooo`ko2NX:a_ooool=o`WZ2P03ooooool0003ooooo01;ooooo000Booooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:o`000?moOgl02_moOgl01?l9jP[oOgmoogmoOol00008ogmoO`03o`WZ2_oooooo
oooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo00Wooooo00?o2NX:ooooooooool02Oooool2o`WZ2P[ooooo3?l9jP[Gooooo`So2NX:00?o0000
ooooooooool04?ooool001;ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:oooo
o`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:oooo
o`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:oooo
o`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[o0000ogmoO`0:ogmo
O`04o`WZ2_moOgooOgmoo`0000SoOgmo00?o0000o`WZ2_ooool02_ooool00ol9jP[oooooooooo`09
ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09
ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0=
ooooo`[o2NX:h?ooool4o`WZ2PCooooo0_l0000Booooo`004_ooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:oooo
o`03o`WZ2_moOgooOgmo00WoOgmo00Co2NX:ogmoOomoOgoo00002?moOgl00ol0003o2NX:ooooo`0:
ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09
ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09
ooooo`03o`WZ2_oooooooooo00Cooooo2Ol9jP[booooo`03o`000?oooooooooo017ooooo000Boooo
o`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ogmoOomoOgl02OmoOgl01?l9jP[oOgmoogmoOol00008
ogmoO`03o`000?l9jP[ooooo00[ooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09
ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09
ooooo`03o`WZ2_oooooooooo017o2NX:n_ooool00ol0003oooooooooo`0Aooooo`004_ooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`0:ooooo`03o`WZ2_moOgooOgmo00WoOgmo00?o2NX:ogmoOomoOgl02_l000000ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool01?ooool>o`WZ
2_oooooo1_ooool00ol0003oooooooooo`0Aooooo`004_ooool00ol9jP[oooooooooo`09ooooo`03
o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03
o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03
o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_l0003oOgmo00WoOgmo00Co2NX:ogmoOomoOgoo00002?moOgl00ol0003o2NX:ooooo`0:oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:oooo
o`03o`WZ2_oooooooooo00Sooooo3?l9jP[ooooooa3ooooo00?o0000ooooooooool04Oooool001;o
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wo
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wo
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wo
oooo00?o2NX:ooooooooool02_ooool00ol9jP[o0000ogmoO`09ogmoO`04o`WZ2_moOgooOgmoo`00
00SoOgmo00?o0000o`WZ2_ooool02_ooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool03?ooool;o`WZ2_oooooo6_ooool00ol0003oooooooooo`0Aoooo
o`004_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_l0003oOgmo00WoOgmo00Co2NX:ogmoOomo
Ogoo00002?moOgl00ol0003o2NX:ooooo`0;ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooo
ooooool02?oooolAo`WZ2_oooooo9?ooool00ol0003oooooooooo`0Aooooo`004_ooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_l0003oOgmo00WoOgmo00Co2NX:ogmoOomoOgoo00002?moOgl00ol0
003o2NX:ooooo`0;ooooo`03o`WZ2_oooooooooo00cooooo3ol9jP[oooooobkooooo00?o0000oooo
ooooool04Oooool001;ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02_ooool00ol9jP[o0000ogmoO`09ogmoO`04
o`WZ2_moOgooOgmoo`0000SoOgmo00?o0000ooooool9jPX04_ooool=o`WZ2_oooooo>?ooool00ol0
003oooooooooo`0Aooooo`004_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[o
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[o
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00[o
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_l0003oOgmo00Wo
Ogmo00Co2NX:ogmoOomoOgoo00000ol9jPX5ogmoO`03o`000?oooooooooo00Wooooo3Ol9jP[ooooo
od7ooooo00?o0000ooooooooool04Oooool001;ooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[o
ooooooooo`0:ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool01?ooool3o`WZ2P?o
oooo00?o2NX:o`000?moOgl03?moOgl00ol0003oOgmoo`WZ2P05o`WZ2P;o00000oooool;o`WZ2_oo
ooooBoooool00ol0003oooooooooo`0Aooooo`00ROooool6o`WZ2P03ooooool0003oOgmo00SoOgmo
4Ol9jP[ooooooeGooooo00?o0000ooooooooool04Oooool001;oooooROl9jPX2ogmoO`03o`000?mo
Ogoo2NX:00Co2NX:0_moOgl00ol0003oooooooooo`3ooooooeOooooo00?o0000ooooooooool04Ooo
ool008Wooooo1Ol9jPX00ooooooo0000o`00000<ogmoO`03o`000?l9jP[o2NX:00KoOgmo00?o0000
ooooooooool0oooooomGooooo`03o`000?oooooooooo017ooooo0028ooooo`;o2NX:1_ooool00ol0
003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0oooooomGoooo
o`03o`000?oooooooooo017ooooo002Aooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomo
Ogl01_moOgl00ol0003oooooooooo`3ooooooeOooooo00?o0000ooooooooool04Oooool0097ooooo
00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooooooo0?oooooo
Eoooool00ol0003oooooooooo`0Aooooo`00TOooool00ol0003oOgmoogmoO`09ogmoO`03o`000?mo
OgooOgmo00KoOgmo00?o0000ooooooooool0oooooomGooooo`03o`000?oooooooooo017ooooo002A
ooooo`03o`000?moOgooOgmo00WoOgmo2_l0003ooooooeWooooo00?o0000ooooooooool04Oooool0
09;ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooooooo
0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00T_ooool00ol0003oOgmoogmoO`08ogmoO`03
o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0oooooomGooooo`03o`000?oooooooooo017o
oooo002Booooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003ooooo
ooooo`3ooooooeOooooo00?o0000ooooooooool04Oooool009;ooooo00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooooooo0?ooooooEoooool00ol0003ooooooooo
o`0Aooooo`00T_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000
ooooooooool0oooooomGooooo`03o`000?oooooooooo017ooooo002Cooooo`03o`000?moOgooOgmo
00OoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`3ooooooeOooooo00?o0000oooo
ooooool04Oooool009?ooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`06ogmoO`03
o`000?oooooooooo0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00Toooool00ol0003oOgmo
ogmoO`07ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0oooooomGooooo`03o`00
0?oooooooooo017ooooo002Cooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oooooooooo`3ooooooeOooooo00?o0000ooooooooool04Oooool009Cooooo00?o0000
ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooooooo0?ooooooEoooool0
0ol0003oooooooooo`0Aooooo`00U?ooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo
00KoOgmo00?o0000ooooooooool0oooooomGooooo`03o`000?oooooooooo017ooooo002Dooooo`03
o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`3ooooooeOo
oooo00?o0000ooooooooool04Oooool009Gooooo00?o0000ogmoOomoOgl01OmoOgl:o`000?oooooo
FOooool00ol0003oooooooooo`0Aooooo`00UOooool00ol0003oOgmoogmoO`05ogmoO`03o`000?mo
OgooOgmo00KoOgmo00?o0000ooooooooool0oooooomGooooo`03o`000?oooooooooo017ooooo002F
ooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`3o
oooooeOooooo00?o0000ooooooooool04Oooool009Kooooo00?o0000ogmoOomoOgl01?moOgl00ol0
003oOgmoogmoO`06ogmoO`03o`000?oooooooooo0?ooooooEoooool00ol0003oooooooooo`0Aoooo
o`00U_ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000oooooooo
ool0oooooomGooooo`03o`000?oooooooooo017ooooo002Gooooo`03o`000?moOgooOgmo00?oOgmo
00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`3ooooooeOooooo00?o0000ooooooooool0
4Oooool009Oooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oo
oooooooo0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00V?ooool00ol0003oOgmoogmoO`02
ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0oooooomGooooo`03o`000?oooooo
oooo017ooooo002Hooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl01_moOgl00ol0
003oooooooooo`3ooooooeOooooo00?o0000ooooooooool04Oooool009Wooooo00Go0000ogmoOomo
OgooOgmoo`000008ogmoO`03o`000?oooooooooo0?ooooooEoooool00ol0003oooooooooo`0Aoooo
o`00VOooool01?l0003oOgmoogmoOomoOgl:o`000?ooooooFOooool00ol0003oooooooooo`0Aoooo
o`00V_ooool01?l0003oOgmoogmoOol00008ogmoO`03o`000?oooooooooo0?ooooooEoooool00ol0
003oooooooooo`0Aooooo`00V_ooool01?l0003oOgmoogmoOol00008ogmoO`03o`000?oooooooooo
0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00Voooool00ol0003oOgmoo`000008ogmoO`03
o`000?oooooooooo0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00Voooool00ol0003oOgmo
o`000008ogmoO`03o`000?oooooooooo0?ooooooEoooool00ol0003oooooooooo`0Aooooo`00Vooo
ool00ol0003oOgmoo`000008ogmoO`03o`000?oooooooooo0?ooooooEoooool00ol0003ooooooooo
o`0Aooooo`00W?ooool;o`000?ooooooFOooool00ol0003oooooooooo`0Aooooo`00W?ooool2o`00
00SoOgmo00?o0000ooooooooool0oooooomGooooo`03o`000?oooooooooo017ooooo002Mooooo`[o
0000oooooomIooooo`03o`000?oooooooooo017ooooo003ooooooooooooo5Oooool00?oooooooooo
oolEooooo`00oooooooooooooaGooooo0000\
\>"],
  ImageRangeCache->{{{0, 530}, {145, 0}} -> {-7.48158, -32.4333, 0.405584, \
0.405584}},
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],

Cell[BoxData[
    TagBox[
      StyleBox[
        TagBox[\(AnalyzeSystem[{GaussianBeam[{w, 10}, {div, 0.001`}, 
                NumberOfRays \[Rule] 4, 
                SymbolicWaveLength \[Rule] \[Lambda]], 
              Move[PlanoConvexLens[{f, 100}, {a, 50}, {t, 10}], {d, 50.`}], 
              Move[Screen[50], {{x, 200.`}, {y, 0}}]}, 
            PlotType \[Rule] TopView, ShowGaussian \[Rule] True]\),
          HoldForm],
        FontColor->RGBColor[0, 0.392187, 0]],
      DisplayForm]], "Print",
  CellLabel->"From In[12]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],

Cell[BoxData[
    \("-12 ray/surface intersections-"\)], "Output",
  CellLabel->"Out[12]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["How SymbolicTrace works", "Subsubsection",
  CellTags->{"AOG0.", "2.1.3", "AOG2.", "AOG2.1", "AOG2.1.3"}],

Cell[TextData[{
  StyleBox["SymbolicTrace", "Input"],
  " initially works by tracing a single chief ray through the optical system \
and constructing symbolic expressions that represent light propagation \
through the optical surfaces in the system. First, ",
  StyleBox["SymbolicTrace", "Input"],
  " uses ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " to make a numerical trace of the chief ray through the optical system. \
From this chief ray, the surface sequence is determined as well as positions \
and directions of the chief ray at each surface. In addition to the numerical \
results, ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " also provides any user-specified symbolic parameter information about the \
system to ",
  StyleBox["SymbolicTrace", "Input"],
  ". ",
  StyleBox["SymbolicTrace", "Input"],
  " then uses the numerical values of the initial ray trace as boundary \
conditions to determine the symbolic solution required in symbolic \
calculations. In particular, many surface functions have more than one \
intercept solution. In the case of a spherical surface, for example, there \
are two intercept solutions for the same spherical function, but ",
  StyleBox["SymbolicTrace", "Input"],
  " must choose to work with only one of the two possible intercept \
solutions. In such an event, ",
  StyleBox["SymbolicTrace", "Input"],
  " uses the solution determined from the numerical trace (where only numbers \
are present and no variables are present) to dictate its choice of symbolic \
ray-surface intercept solution."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],

Cell[TextData[{
  StyleBox["SymbolicTrace", "Input"],
  " performs its calculations in two stages. In the first stage, ",
  StyleBox["SymbolicTrace", "Input"],
  " determines the symbolic solution at each optical surface. In this stage, \
the surface functions are calculated in the local coordinate system of the \
particular surface. After each local surface result is calculated, it is then \
transformed in the global coordinate system before progressing to the second \
stage of operation. Finally in the second stage of operation, ",
  StyleBox["SymbolicTrace", "Input"],
  " constructs a single, nested solution of the optical system by cascading \
together the symbolic results of each individual surface."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],

Cell[TextData[{
  "In addition to constructing a symbolic solution, ",
  StyleBox["SymbolicTrace", "Input"],
  " can use symbolic Taylor's series expansions during the course of its \
calculations in order to reduce the size and complexity of the resulting \
solution. For example, ",
  StyleBox["SymbolicTrace", "Input"],
  " can give the paraxial solution to system by taking the first order \
Taylors series expansion of the result. Such a solution is useful for \
determining the abcd matrix representation of the system and for calculating \
Gaussian beam propagation through the system. However, in other cases, ",
  StyleBox["SymbolicTrace", "Input"],
  " can use a higher order Taylor series expansion in order to maintain a \
higher degree of accuracy in the final results. In some cases, ",
  StyleBox["SymbolicTrace", "Input"],
  " may return a fully unexpanded symbolic solution that completely models \
the system with machine-precision, or even infinite precision. In cases where \
Taylor's series expansions are used, the numerical surface intercepts from \
the ray-trace solution provide the fixed points for the symbolic Taylor's \
series calculations."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Light Sources and SymbolicTrace", "Subsubsection",
  CellTags->{"AOG0.", "2.1.4", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],

Cell[TextData[{
  "In order to function, ",
  StyleBox["SymbolicTrace", "Input"],
  " requires the presence of at least one light source as well as one or more \
optical surfaces. However, ",
  StyleBox["SymbolicTrace", "Input"],
  " does not use light sources in the same way as ",
  StyleBox["PropagateSystem", "Input"],
  ". In particular, only the chief ray of the light source is utilized and \
any other rays from the light source are ignored by ",
  StyleBox["SymbolicTrace", "Input"],
  ". To illustrate this point, consider the following three examples."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],

Cell[CellGroupData[{

Cell["\<\
raySystem = {
\tMove[SingleRay[],{-50,{y,0}}],
\tPlanoConvexLens[{f,100},50,10],
\tMove[Screen[50],100]};
AnalyzeSystem[raySystem,PlotType->TopView];
SymbolicOpticalLength/.SymbolicTrace[raySystem,{{y,0,3},{f>0}}]\
\>", "Input",
  CellLabel->"In[13]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.192698 0.00634921 [
[.37302 .00857 -5.03125 -6 ]
[.37302 .00857 5.03125 6 ]
[.97619 .00857 -4.75 -6 ]
[.97619 .00857 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .36 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.38204 .03397 m
.40476 .03397 L
.40476 .08688 L
.35873 .08688 L
.38204 .03397 L
F
.35873 .08688 m
.40476 .08688 L
.40476 .13979 L
.34555 .13979 L
.35873 .08688 L
F
.34555 .13979 m
.40476 .13979 L
.40476 .1927 L
.34127 .1927 L
.34555 .13979 L
F
.34127 .1927 m
.40476 .1927 L
.40476 .24561 L
.34555 .24561 L
.34127 .1927 L
F
.34555 .24561 m
.40476 .24561 L
.40476 .29852 L
.35873 .29852 L
.34555 .24561 L
F
.35873 .29852 m
.40476 .29852 L
.40476 .35143 L
.38204 .35143 L
.35873 .29852 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.38204 .03397 m
.35873 .08688 L
.34555 .13979 L
.34127 .1927 L
.34555 .24561 L
.35873 .29852 L
.38204 .35143 L
.40476 .35143 L
.40476 .29852 L
.40476 .24561 L
.40476 .1927 L
.40476 .13979 L
.40476 .08688 L
.40476 .03397 L
.38204 .03397 L
s
.5 g
.38204 .1927 m
.40476 .1927 L
.40476 .1927 L
.35873 .1927 L
.38204 .1927 L
F
.35873 .1927 m
.40476 .1927 L
.40476 .1927 L
.34555 .1927 L
.35873 .1927 L
F
.34555 .1927 m
.40476 .1927 L
.40476 .1927 L
.34127 .1927 L
.34555 .1927 L
F
.34127 .1927 m
.40476 .1927 L
.40476 .1927 L
.34555 .1927 L
.34127 .1927 L
F
.34555 .1927 m
.40476 .1927 L
.40476 .1927 L
.35873 .1927 L
.34555 .1927 L
F
.35873 .1927 m
.40476 .1927 L
.40476 .1927 L
.38204 .1927 L
.35873 .1927 L
F
0 g
.38204 .1927 m
.35873 .1927 L
.34555 .1927 L
.34127 .1927 L
.34555 .1927 L
.35873 .1927 L
.38204 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.38204 .1927 L
s
.38204 .35143 m
.40476 .35143 L
.40476 .34602 L
.38204 .34602 L
.38204 .35143 L
s
.38204 .34602 m
.40476 .34602 L
.40476 .33016 L
.38204 .33016 L
.38204 .34602 L
s
.38204 .33016 m
.40476 .33016 L
.40476 .30494 L
.38204 .30494 L
.38204 .33016 L
s
.38204 .30494 m
.40476 .30494 L
.40476 .27206 L
.38204 .27206 L
.38204 .30494 L
s
.38204 .27206 m
.40476 .27206 L
.40476 .23378 L
.38204 .23378 L
.38204 .27206 L
s
.38204 .23378 m
.40476 .23378 L
.40476 .1927 L
.38204 .1927 L
.38204 .23378 L
s
.38204 .1927 m
.40476 .1927 L
.40476 .15162 L
.38204 .15162 L
.38204 .1927 L
s
.38204 .15162 m
.40476 .15162 L
.40476 .11333 L
.38204 .11333 L
.38204 .15162 L
s
.38204 .11333 m
.40476 .11333 L
.40476 .08046 L
.38204 .08046 L
.38204 .11333 L
s
.38204 .08046 m
.40476 .08046 L
.40476 .05523 L
.38204 .05523 L
.38204 .08046 L
s
.38204 .05523 m
.40476 .05523 L
.40476 .03938 L
.38204 .03938 L
.38204 .05523 L
s
.38204 .03938 m
.40476 .03938 L
.40476 .03397 L
.38204 .03397 L
.38204 .03938 L
s
.38204 .03397 m
.40476 .03397 L
.40476 .03938 L
.38204 .03938 L
.38204 .03397 L
s
.38204 .03938 m
.40476 .03938 L
.40476 .05523 L
.38204 .05523 L
.38204 .03938 L
s
.38204 .05523 m
.40476 .05523 L
.40476 .08046 L
.38204 .08046 L
.38204 .05523 L
s
.38204 .08046 m
.40476 .08046 L
.40476 .11333 L
.38204 .11333 L
.38204 .08046 L
s
.38204 .11333 m
.40476 .11333 L
.40476 .15162 L
.38204 .15162 L
.38204 .11333 L
s
.38204 .15162 m
.40476 .15162 L
.40476 .1927 L
.38204 .1927 L
.38204 .15162 L
s
.38204 .1927 m
.40476 .1927 L
.40476 .23378 L
.38204 .23378 L
.38204 .1927 L
s
.38204 .23378 m
.40476 .23378 L
.40476 .27206 L
.38204 .27206 L
.38204 .23378 L
s
.38204 .27206 m
.40476 .27206 L
.40476 .30494 L
.38204 .30494 L
.38204 .27206 L
s
.38204 .30494 m
.40476 .30494 L
.40476 .33016 L
.38204 .33016 L
.38204 .30494 L
s
.38204 .33016 m
.40476 .33016 L
.40476 .34602 L
.38204 .34602 L
.38204 .33016 L
s
.38204 .34602 m
.40476 .34602 L
.40476 .35143 L
.38204 .35143 L
.38204 .34602 L
s
.97619 .03397 m
.97619 .08688 L
.97619 .13979 L
.97619 .1927 L
.97619 .24561 L
.97619 .29852 L
.97619 .35143 L
.97619 .35143 L
.97619 .29852 L
.97619 .24561 L
.97619 .1927 L
.97619 .13979 L
.97619 .08688 L
.97619 .03397 L
.97619 .03397 L
s
.97619 .1927 m
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
s
.97619 .35143 m
.97619 .34602 L
.97619 .33016 L
.97619 .30494 L
.97619 .27206 L
.97619 .23378 L
.97619 .1927 L
.97619 .15162 L
.97619 .11333 L
.97619 .08046 L
.97619 .05523 L
.97619 .03938 L
.97619 .03397 L
.97619 .03938 L
.97619 .05523 L
.97619 .08046 L
.97619 .11333 L
.97619 .15162 L
.97619 .1927 L
.97619 .23378 L
.97619 .27206 L
.97619 .30494 L
.97619 .33016 L
.97619 .34602 L
.97619 .35143 L
s
.039 .916 .04 r
.02381 .1927 m
.34127 .1927 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .1927 m
.40476 .1927 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .1927 m
.97619 .1927 L
s
% Start of user PostScript
10. 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1927 Mdot
gsave
.37302 .00857 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00857 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .36 L
0 .36 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{288, 103.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ib000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00JOooool6o`000:7ooooo0ol0
000=ooooo`00J_ooool01Ol0003ooooooooooooooooo00000:7ooooo00Co0000oooooooooooo0000
3?ooool006[ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0:ooooo`00J_ooool0
0ol0003oooooooooo`2Tooooo`;o00003Oooool006[ooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`0=ooooo`00J_ooool00ol0003oooooooooo`2Sooooo`04o`000?ooooooooooo`00
00cooooo001Yooooo`?o0000YOooool3o`0000cooooo003oooooob7ooooo003oooooob7ooooo001_
ooooo`Oo0000W?ooool00ol0003oooooooooo`0;ooooo`00Koooool7o`0009cooooo00?o0000oooo
ooooool02oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooooooo
ool02oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
2oooool006gooooo00?o0000ogmoOol000001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001]ooooo`03o`000?moOgoo000000GoOgmo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0;ooooo`00K?ooool00ol0003oOgmoogmoO`07o`0009cooooo00?o0000oooo
ooooool02oooool006cooooo00Co0000ogmoOomoOgoo00001OmoOgl00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo00_ooooo001[ooooo`05o`000?moOgooOgmoogmoOol000001OmoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001[ooooo`05o`000?moOgooOgmoogmo
Ool000001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Zooooo`03
o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo00_ooooo001Zooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Yooooo`03o`000?mo
OgooOgmo00?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001Yooooo`03o`000?moOgooOgmo00?oOgmo1ol0002Looooo`03o`000?oooooo
oooo00_ooooo001Xooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Xooooo`03o`000?moOgooOgmo00Co
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_o
oooo001Xooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o
0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001W
ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmo
OomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Wooooo`03
o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?mo
OgooOgmo00KoOgmo1ol0002Looooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?moOgoo
Ogmo00KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooo
oooo00_ooooo001Vooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?moOgooOgmo00Ko
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_o
oooo001Vooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Uooooo`03o`000?moOgooOgmo00OoOgmo00?o
0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001U
ooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo00_ooooo001Uooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmo
OomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Uooooo`03
o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo00_ooooo001Uooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Uooooo`03o`000?mo
OgooOgmo00OoOgmo1ol0002Looooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`000?moOgoo
Ogmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooo
oooo00_ooooo001Tooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`000?moOgooOgmo00So
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_o
oooo001Tooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`000?moOgooOgmo00SoOgmo00?o
0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001T
ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmo
OomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Sooooo`03
o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo00_ooooo001Kooooo`?o2NX:1Oooool00ol0003oOgmoogmoO`07ogmoO`?o2NX:
1OmoOgl00ol0003oooooooooo`2Booooo`?o2NX:1Oooool00ol0003oooooooooo`0;ooooo`00G?oo
ool6o`WZ2P03ooooool0003oOgmo00WoOgmo1_l9jPX00omoOgoo0000ooooo`2Dooooo`Ko2NX:00?o
ooooo`000?ooool03?ooool000coooooJ?l9jPX00ol0003o2NX:o`WZ2P2Jo`WZ2P;o00003Oooool0
05cooooo1Ol9jPX2ooooo`;o00002OmoOgl5o`WZ2P03ogmoOol0003o000009Gooooo1Ol9jPX00ooo
oooo0000o`00000=ooooo`00Foooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01omoOgl2o`WZ2P03
o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0T_ooool2o`WZ2PKooooo00?o0000oooooooo
ool02oooool006?ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`00
0?oooooooooo09[ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02ooo
ool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo09[ooooo00?o0000ooooooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0
003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Co
oooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[o
oooo00?o0000ooooooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Cooooo00?o
0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o
0000ooooooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Cooooo00?o0000ogmo
OomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooo
ooooool02oooool006Gooooo00?o0000ogmoOomoOgl01omoOgl7o`0009cooooo00?o0000oooooooo
ool02oooool006Gooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`00
0?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Gooooo00?o0000ogmoOomoOgl01omo
Ogl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02ooo
ool006Gooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo09[ooooo00?o0000ooooooooool02oooool006Gooooo00?o0000ogmoOomoOgl01omoOgl00ol0
003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Go
oooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[o
oooo00?o0000ooooooooool02oooool006Kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Kooooo00?o
0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o
0000ooooooooool02oooool006Kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Kooooo00?o0000ogmo
OomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooo
ooooool02oooool006Kooooo00?o0000ogmoOomoOgl01_moOgl7o`0009cooooo00?o0000oooooooo
ool02oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`00
0?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Oooooo00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02ooo
ool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo09[ooooo00?o0000ooooooooool02oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0
003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Oo
oooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[o
oooo00?o0000ooooooooool02oooool006Sooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Sooooo00?o
0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o
0000ooooooooool02oooool006Sooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Sooooo00?o0000ogmo
OomoOgl01?moOgl7o`0009cooooo00?o0000ooooooooool02oooool006Wooooo00?o0000ogmoOomo
Ogl00omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooooooo
ool02oooool006Wooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`00
0?oooooooooo09[ooooo00?o0000ooooooooool02oooool006[ooooo00?o0000ogmoOomoOgl00_mo
Ogl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02ooo
ool006[ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo09[ooooo00?o0000ooooooooool02oooool006_ooooo00Go0000ogmoOomoOgooOgmoo`000005
ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006_ooooo00Go0000ogmo
OomoOgooOgmoo`000005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool0
06cooooo00?o0000ogmoOomoOgl01ol0002Looooo`03o`000?oooooooooo00_ooooo001/ooooo`04
o`000?moOgooOgmoo`0000GoOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;oooo
o`00KOooool00ol0003oOgmoo`000005ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooooooo
ool02oooool006gooooo00?o0000ogmoOol000001OmoOgl00ol0003oooooooooo`2Jooooo`03o`00
0?oooooooooo00_ooooo001^ooooo`;o00001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001^ooooo`So0000W?ooool00ol0003oooooooooo`0;ooooo`00Koooool7o`00
09cooooo00?o0000ooooooooool02oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {102.625, 0}} -> {-57.2027, -32.4375, \
0.572841, 0.572841}},
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],

Cell[BoxData[
    \(\(\(155.23244752966428`\)\(\[InvisibleSpace]\)\) + \
\(48.368378051367515`\ y\^2\)\/f\^2 - \(0.5004652304391106`\ y\^2\)\/f\)], \
"Output",
  CellLabel->"Out[15]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
linearSystem = {
\tMove[LineOfRays[20],{-50,{y,0}}],
\tPlanoConvexLens[{f,100},50,10],
\tMove[Screen[50],100]};
AnalyzeSystem[linearSystem,PlotType->TopView];
SymbolicOpticalLength/.SymbolicTrace[linearSystem,{{y,0,3},{f>0}}]\
\>", "Input",
  CellLabel->"In[16]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.192698 0.00634921 [
[.37302 .00857 -5.03125 -6 ]
[.37302 .00857 5.03125 6 ]
[.97619 .00857 -4.75 -6 ]
[.97619 .00857 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .36 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.38204 .03397 m
.40476 .03397 L
.40476 .08688 L
.35873 .08688 L
.38204 .03397 L
F
.35873 .08688 m
.40476 .08688 L
.40476 .13979 L
.34555 .13979 L
.35873 .08688 L
F
.34555 .13979 m
.40476 .13979 L
.40476 .1927 L
.34127 .1927 L
.34555 .13979 L
F
.34127 .1927 m
.40476 .1927 L
.40476 .24561 L
.34555 .24561 L
.34127 .1927 L
F
.34555 .24561 m
.40476 .24561 L
.40476 .29852 L
.35873 .29852 L
.34555 .24561 L
F
.35873 .29852 m
.40476 .29852 L
.40476 .35143 L
.38204 .35143 L
.35873 .29852 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.38204 .03397 m
.35873 .08688 L
.34555 .13979 L
.34127 .1927 L
.34555 .24561 L
.35873 .29852 L
.38204 .35143 L
.40476 .35143 L
.40476 .29852 L
.40476 .24561 L
.40476 .1927 L
.40476 .13979 L
.40476 .08688 L
.40476 .03397 L
.38204 .03397 L
s
.5 g
.38204 .1927 m
.40476 .1927 L
.40476 .1927 L
.35873 .1927 L
.38204 .1927 L
F
.35873 .1927 m
.40476 .1927 L
.40476 .1927 L
.34555 .1927 L
.35873 .1927 L
F
.34555 .1927 m
.40476 .1927 L
.40476 .1927 L
.34127 .1927 L
.34555 .1927 L
F
.34127 .1927 m
.40476 .1927 L
.40476 .1927 L
.34555 .1927 L
.34127 .1927 L
F
.34555 .1927 m
.40476 .1927 L
.40476 .1927 L
.35873 .1927 L
.34555 .1927 L
F
.35873 .1927 m
.40476 .1927 L
.40476 .1927 L
.38204 .1927 L
.35873 .1927 L
F
0 g
.38204 .1927 m
.35873 .1927 L
.34555 .1927 L
.34127 .1927 L
.34555 .1927 L
.35873 .1927 L
.38204 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.38204 .1927 L
s
.38204 .35143 m
.40476 .35143 L
.40476 .34602 L
.38204 .34602 L
.38204 .35143 L
s
.38204 .34602 m
.40476 .34602 L
.40476 .33016 L
.38204 .33016 L
.38204 .34602 L
s
.38204 .33016 m
.40476 .33016 L
.40476 .30494 L
.38204 .30494 L
.38204 .33016 L
s
.38204 .30494 m
.40476 .30494 L
.40476 .27206 L
.38204 .27206 L
.38204 .30494 L
s
.38204 .27206 m
.40476 .27206 L
.40476 .23378 L
.38204 .23378 L
.38204 .27206 L
s
.38204 .23378 m
.40476 .23378 L
.40476 .1927 L
.38204 .1927 L
.38204 .23378 L
s
.38204 .1927 m
.40476 .1927 L
.40476 .15162 L
.38204 .15162 L
.38204 .1927 L
s
.38204 .15162 m
.40476 .15162 L
.40476 .11333 L
.38204 .11333 L
.38204 .15162 L
s
.38204 .11333 m
.40476 .11333 L
.40476 .08046 L
.38204 .08046 L
.38204 .11333 L
s
.38204 .08046 m
.40476 .08046 L
.40476 .05523 L
.38204 .05523 L
.38204 .08046 L
s
.38204 .05523 m
.40476 .05523 L
.40476 .03938 L
.38204 .03938 L
.38204 .05523 L
s
.38204 .03938 m
.40476 .03938 L
.40476 .03397 L
.38204 .03397 L
.38204 .03938 L
s
.38204 .03397 m
.40476 .03397 L
.40476 .03938 L
.38204 .03938 L
.38204 .03397 L
s
.38204 .03938 m
.40476 .03938 L
.40476 .05523 L
.38204 .05523 L
.38204 .03938 L
s
.38204 .05523 m
.40476 .05523 L
.40476 .08046 L
.38204 .08046 L
.38204 .05523 L
s
.38204 .08046 m
.40476 .08046 L
.40476 .11333 L
.38204 .11333 L
.38204 .08046 L
s
.38204 .11333 m
.40476 .11333 L
.40476 .15162 L
.38204 .15162 L
.38204 .11333 L
s
.38204 .15162 m
.40476 .15162 L
.40476 .1927 L
.38204 .1927 L
.38204 .15162 L
s
.38204 .1927 m
.40476 .1927 L
.40476 .23378 L
.38204 .23378 L
.38204 .1927 L
s
.38204 .23378 m
.40476 .23378 L
.40476 .27206 L
.38204 .27206 L
.38204 .23378 L
s
.38204 .27206 m
.40476 .27206 L
.40476 .30494 L
.38204 .30494 L
.38204 .27206 L
s
.38204 .30494 m
.40476 .30494 L
.40476 .33016 L
.38204 .33016 L
.38204 .30494 L
s
.38204 .33016 m
.40476 .33016 L
.40476 .34602 L
.38204 .34602 L
.38204 .33016 L
s
.38204 .34602 m
.40476 .34602 L
.40476 .35143 L
.38204 .35143 L
.38204 .34602 L
s
.97619 .03397 m
.97619 .08688 L
.97619 .13979 L
.97619 .1927 L
.97619 .24561 L
.97619 .29852 L
.97619 .35143 L
.97619 .35143 L
.97619 .29852 L
.97619 .24561 L
.97619 .1927 L
.97619 .13979 L
.97619 .08688 L
.97619 .03397 L
.97619 .03397 L
s
.97619 .1927 m
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
s
.97619 .35143 m
.97619 .34602 L
.97619 .33016 L
.97619 .30494 L
.97619 .27206 L
.97619 .23378 L
.97619 .1927 L
.97619 .15162 L
.97619 .11333 L
.97619 .08046 L
.97619 .05523 L
.97619 .03938 L
.97619 .03397 L
.97619 .03938 L
.97619 .05523 L
.97619 .08046 L
.97619 .11333 L
.97619 .15162 L
.97619 .1927 L
.97619 .23378 L
.97619 .27206 L
.97619 .30494 L
.97619 .33016 L
.97619 .34602 L
.97619 .35143 L
s
.039 .916 .04 r
.02381 .12921 m
.34745 .12921 L
s
% Start of user PostScript
-50. -10. 0.973037 -10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34745 .12921 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1927 m
.34127 .1927 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25619 m
.34745 .25619 L
s
% Start of user PostScript
-50. 10. 0.973037 10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34745 .25619 Mdot
.039 .916 .04 r
.5 Mabswid
.34745 .12921 m
.40476 .13304 L
s
% Start of user PostScript
0.973037 -10. 10. -9.3966 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .13304 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .1927 m
.40476 .1927 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.34745 .25619 m
.40476 .25236 L
s
% Start of user PostScript
0.973037 10. 10. 9.3966 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .25236 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .13304 m
.97619 .19123 L
s
% Start of user PostScript
10. -9.3966 100. -0.231131 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19123 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .1927 m
.97619 .1927 L
s
% Start of user PostScript
10. 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .25236 m
.97619 .19417 L
s
% Start of user PostScript
10. 9.3966 100. 0.231131 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19417 Mdot
gsave
.37302 .00857 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00857 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .36 L
0 .36 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[16]:=",
  ImageSize->{288, 103.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ib000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00JOooool6o`000:7ooooo0ol0
000=ooooo`00J_ooool01Ol0003ooooooooooooooooo00000:7ooooo00Co0000oooooooooooo0000
3?ooool006[ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0:ooooo`00J_ooool0
0ol0003oooooooooo`2Tooooo`;o00003Oooool006[ooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`0=ooooo`00J_ooool00ol0003oooooooooo`2Sooooo`04o`000?ooooooooooo`00
00cooooo001Yooooo`?o0000YOooool3o`0000cooooo003oooooob7ooooo003oooooob7ooooo001_
ooooo`Oo0000W?ooool00ol0003oooooooooo`0;ooooo`00Koooool7o`0009cooooo00?o0000oooo
ooooool02oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooooooo
ool02oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
2oooool006gooooo00?o0000ogmoOol000001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001]ooooo`03o`000?moOgoo000000GoOgmo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0;ooooo`00K?ooool00ol0003oOgmoogmoO`07o`0009cooooo00?o0000oooo
ooooool02oooool006cooooo00Co0000ogmoOomoOgoo00001OmoOgl00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo00_ooooo001[ooooo`05o`000?moOgooOgmoogmoOol000001OmoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001[ooooo`05o`000?moOgooOgmoogmo
Ool000001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Zooooo`03
o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo00_ooooo001Zooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Yooooo`03o`000?mo
OgooOgmo00?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001Yooooo`03o`000?moOgooOgmo00?oOgmo1ol0002Looooo`03o`000?oooooo
oooo00_ooooo001Xooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Xooooo`03o`000?moOgooOgmo00Co
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_o
oooo001Xooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o
0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001W
ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmo
OomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Wooooo`03
o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?mo
OgooOgmo00KoOgmo1ol0002Looooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?moOgoo
Ogmo00KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooo
oooo00_ooooo001Mooooo`?o2NX:1_ooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo
00?oOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00G_ooool6o`WZ2P;o
oooo00?o0000ogmoOomoOgl01?moOgl3o`WZ2PGoOgmo00?o0000ooooooooool0V_ooool00ol0003o
ooooooooo`0;ooooo`003?oooomXo`WZ2P03ogmoOol0003ooooo09_ooooo00?o0000ooooooooool0
2oooool005kooooo1Ol9jPX2ooooo`;o00001omoOgl6o`WZ2P03o`000?l9jP[o2NX:00Co2NX:Uooo
ool00ol0003oooooooooo`0;ooooo`00GOooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01_moOgl5
o`WZ2P03ogmoOol0003o000000Gooooo2_l9jPZ=ooooo`03o`000?oooooooooo00_ooooo001Uoooo
o`03o`000?moOgooOgmo00GoOgmo0_l9jPX00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo
00gooooo2_l9jPZ3ooooo`03o`000?oooooooooo00_ooooo001Uooooo`03o`000?moOgooOgmo00Oo
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0Gooooo`Wo2NX:N_ooool00ol0003o
ooooooooo`0;ooooo`00IOooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00?oOgmo
00?o0000ooooooooool08?ooool:o`WZ2W3ooooo00?o0000ooooooooool02oooool006Gooooo00?o
0000ogmoOomoOgl01omoOgl7o`0002cooooo2_l9jPYVooooo`03o`000?oooooooooo00_ooooo001T
ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0d
ooooo`[o2NX:G?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmo
O`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0?_ooool:o`WZ2U;ooooo00?o0000oooo
ooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo04Sooooo2Ol9jPY9ooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`00
0?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1Aooooo`[o2NX:
?oooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?mo
OgooOgmo00?oOgmo00?o0000ooooooooool0Foooool:o`WZ2SGooooo00?o0000ooooooooool02ooo
ool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo06Gooooo2_l9jPX[ooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`000?moOgooOgmo
00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1_ooooo`[o2NX:8Oooool00ol0
003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0NOooool9o`WZ2Q3ooooo0_l9jPX6ooooo`03o`000?oooooooooo00_o
oooo001Kooooo`?o2NX:1Oooool00ol0003oOgmoogmoO`07ogmoO`?o2NX:1OmoOgl00ol0003ooooo
ooooo`22ooooo`[o2NX:1_ooool5o`WZ2P?ooooo00?o0000ooooooooool02oooool005cooooo1_l9
jPX00ooooooo0000ogmoO`09ogmoO`Ko2NX:00?oOgmoo`000?ooool0SOooool>o`WZ2P03o`000?oo
oooooooo00_ooooo000<ooooofSo2NX:00?o0000o`WZ2_l9jPX0V_l9jPX2o`0000gooooo001Loooo
o`Go2NX:0_ooool2o`0000WoOgmo1Ol9jPX00omoOgoo0000o`00002Dooooo`Oo2NX:0_l0000=oooo
o`00Foooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01omoOgl2o`WZ2P03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0Roooool>o`WZ2P03ooooool0003ooooo00cooooo001Sooooo`03o`00
0?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`21ooooo`[o2NX:
2?ooool3o`WZ2PCooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo07Sooooo2Ol9jPXAooooo`03o`WZ2_oo
oooooooo00Gooooo00?o0000ooooooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl0
0ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo06kooooo2_l9jPXRooooo`03o`000?oooooo
oooo00_ooooo001Tooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`1Tooooo`[o2NX:;?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003o
OgmoogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0F_ooool:o`WZ2SKo
oooo00?o0000ooooooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo053ooooo2_l9jPY0ooooo`03o`000?oooooooooo00_ooooo
001Tooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`17ooooo`Wo2NX:B_ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08
ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0?Oooool:o`WZ2U?ooooo00?o0000
ooooooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo03?ooooo2_l9jPYMooooo`03o`000?oooooooooo00_ooooo001Uooooo`03
o`000?moOgooOgmo00OoOgmo1ol0000[ooooo`[o2NX:Ioooool00ol0003oooooooooo`0;ooooo`00
IOooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0
7oooool:o`WZ2W7ooooo00?o0000ooooooooool02oooool006Gooooo00?o0000ogmoOomoOgl01omo
Ogl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo01Kooooo2Ol9jPYkooooo`03o`000?oo
oooooooo00_ooooo001Uooooo`03o`000?moOgooOgmo00GoOgmo0ol9jPX5ogmoO`03o`000?oooooo
oooo00cooooo2_l9jPZ4ooooo`03o`000?oooooooooo00_ooooo001Mooooo`?o2NX:1Oooool00ol0
003oOgmoogmoO`06ogmoO`Ko2NX:0_l00004ooooo`[o2NX:S_ooool00ol0003oooooooooo`0;oooo
o`00G_ooool6o`WZ2P03ooooool0003o000000KoOgmo1ol9jPX00ol0003o2NX:o`WZ2P03o`WZ2YSo
oooo00?o0000ooooooooool02oooool000coooooHOl9jPX00omoOgoo2NX:o`WZ2P03o`WZ2P;oOgmo
00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00G_ooool5o`WZ2P?ooooo00?o
0000ogmoOomoOgl01?moOgl2o`WZ2P03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_oo
ool00ol0003oooooooooo`0;ooooo`00GOooool2o`WZ2POooooo00?o0000ogmoOomoOgl01_moOgl0
0ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool0
06Kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo
09[ooooo00?o0000ooooooooool02oooool006Kooooo00?o0000ogmoOomoOgl01_moOgl7o`0009co
oooo00?o0000ooooooooool02oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Oooooo00?o
0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o
0000ooooooooool02oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Oooooo00?o0000ogmo
OomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooo
ooooool02oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Sooooo00?o0000ogmoOomoOgl0
1?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
2oooool006Sooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oo
oooooooo09[ooooo00?o0000ooooooooool02oooool006Sooooo00?o0000ogmoOomoOgl01?moOgl0
0ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool0
06Sooooo00?o0000ogmoOomoOgl01?moOgl7o`0009cooooo00?o0000ooooooooool02oooool006Wo
oooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[o
oooo00?o0000ooooooooool02oooool006Wooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006[ooooo00?o
0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o
0000ooooooooool02oooool006[ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006_ooooo00Go0000ogmo
OomoOgooOgmoo`000005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool0
06_ooooo00Go0000ogmoOomoOgooOgmoo`000005ogmoO`03o`000?oooooooooo09[ooooo00?o0000
ooooooooool02oooool006cooooo00?o0000ogmoOomoOgl01ol0002Looooo`03o`000?oooooooooo
00_ooooo001/ooooo`04o`000?moOgooOgmoo`0000GoOgmo00?o0000ooooooooool0V_ooool00ol0
003oooooooooo`0;ooooo`00KOooool00ol0003oOgmoo`000005ogmoO`03o`000?oooooooooo09[o
oooo00?o0000ooooooooool02oooool006gooooo00?o0000ogmoOol000001OmoOgl00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00_ooooo001^ooooo`;o00001OmoOgl00ol0003ooooooooo
o`2Jooooo`03o`000?oooooooooo00_ooooo001^ooooo`So0000W?ooool00ol0003oooooooooo`0;
ooooo`00Koooool7o`0009cooooo00?o0000ooooooooool02oooool00?oooooo8Oooool00?oooooo
8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {102.625, 0}} -> {-57.2027, -32.4375, \
0.572841, 0.572841}},
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],

Cell[BoxData[
    \(\(\(155.23244752966428`\)\(\[InvisibleSpace]\)\) + \
\(48.368378051367515`\ y\^2\)\/f\^2 - \(0.5004652304391106`\ y\^2\)\/f\)], \
"Output",
  CellLabel->"Out[18]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
wedgeSystem = {
\tMove[WedgeOfRays[20],{-50,{y,0}}],
\tPlanoConvexLens[{f,100},50,10],
\tMove[Screen[50],100]};
AnalyzeSystem[wedgeSystem,PlotType->TopView];
SymbolicOpticalLength/.SymbolicTrace[wedgeSystem,{{y,0,3},{f>0}}]\
\>", "Input",
  CellLabel->"In[19]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.192698 0.00634921 [
[.37302 .00857 -5.03125 -6 ]
[.37302 .00857 5.03125 6 ]
[.97619 .00857 -4.75 -6 ]
[.97619 .00857 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .36 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.38204 .03397 m
.40476 .03397 L
.40476 .08688 L
.35873 .08688 L
.38204 .03397 L
F
.35873 .08688 m
.40476 .08688 L
.40476 .13979 L
.34555 .13979 L
.35873 .08688 L
F
.34555 .13979 m
.40476 .13979 L
.40476 .1927 L
.34127 .1927 L
.34555 .13979 L
F
.34127 .1927 m
.40476 .1927 L
.40476 .24561 L
.34555 .24561 L
.34127 .1927 L
F
.34555 .24561 m
.40476 .24561 L
.40476 .29852 L
.35873 .29852 L
.34555 .24561 L
F
.35873 .29852 m
.40476 .29852 L
.40476 .35143 L
.38204 .35143 L
.35873 .29852 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.38204 .03397 m
.35873 .08688 L
.34555 .13979 L
.34127 .1927 L
.34555 .24561 L
.35873 .29852 L
.38204 .35143 L
.40476 .35143 L
.40476 .29852 L
.40476 .24561 L
.40476 .1927 L
.40476 .13979 L
.40476 .08688 L
.40476 .03397 L
.38204 .03397 L
s
.5 g
.38204 .1927 m
.40476 .1927 L
.40476 .1927 L
.35873 .1927 L
.38204 .1927 L
F
.35873 .1927 m
.40476 .1927 L
.40476 .1927 L
.34555 .1927 L
.35873 .1927 L
F
.34555 .1927 m
.40476 .1927 L
.40476 .1927 L
.34127 .1927 L
.34555 .1927 L
F
.34127 .1927 m
.40476 .1927 L
.40476 .1927 L
.34555 .1927 L
.34127 .1927 L
F
.34555 .1927 m
.40476 .1927 L
.40476 .1927 L
.35873 .1927 L
.34555 .1927 L
F
.35873 .1927 m
.40476 .1927 L
.40476 .1927 L
.38204 .1927 L
.35873 .1927 L
F
0 g
.38204 .1927 m
.35873 .1927 L
.34555 .1927 L
.34127 .1927 L
.34555 .1927 L
.35873 .1927 L
.38204 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.38204 .1927 L
s
.38204 .35143 m
.40476 .35143 L
.40476 .34602 L
.38204 .34602 L
.38204 .35143 L
s
.38204 .34602 m
.40476 .34602 L
.40476 .33016 L
.38204 .33016 L
.38204 .34602 L
s
.38204 .33016 m
.40476 .33016 L
.40476 .30494 L
.38204 .30494 L
.38204 .33016 L
s
.38204 .30494 m
.40476 .30494 L
.40476 .27206 L
.38204 .27206 L
.38204 .30494 L
s
.38204 .27206 m
.40476 .27206 L
.40476 .23378 L
.38204 .23378 L
.38204 .27206 L
s
.38204 .23378 m
.40476 .23378 L
.40476 .1927 L
.38204 .1927 L
.38204 .23378 L
s
.38204 .1927 m
.40476 .1927 L
.40476 .15162 L
.38204 .15162 L
.38204 .1927 L
s
.38204 .15162 m
.40476 .15162 L
.40476 .11333 L
.38204 .11333 L
.38204 .15162 L
s
.38204 .11333 m
.40476 .11333 L
.40476 .08046 L
.38204 .08046 L
.38204 .11333 L
s
.38204 .08046 m
.40476 .08046 L
.40476 .05523 L
.38204 .05523 L
.38204 .08046 L
s
.38204 .05523 m
.40476 .05523 L
.40476 .03938 L
.38204 .03938 L
.38204 .05523 L
s
.38204 .03938 m
.40476 .03938 L
.40476 .03397 L
.38204 .03397 L
.38204 .03938 L
s
.38204 .03397 m
.40476 .03397 L
.40476 .03938 L
.38204 .03938 L
.38204 .03397 L
s
.38204 .03938 m
.40476 .03938 L
.40476 .05523 L
.38204 .05523 L
.38204 .03938 L
s
.38204 .05523 m
.40476 .05523 L
.40476 .08046 L
.38204 .08046 L
.38204 .05523 L
s
.38204 .08046 m
.40476 .08046 L
.40476 .11333 L
.38204 .11333 L
.38204 .08046 L
s
.38204 .11333 m
.40476 .11333 L
.40476 .15162 L
.38204 .15162 L
.38204 .11333 L
s
.38204 .15162 m
.40476 .15162 L
.40476 .1927 L
.38204 .1927 L
.38204 .15162 L
s
.38204 .1927 m
.40476 .1927 L
.40476 .23378 L
.38204 .23378 L
.38204 .1927 L
s
.38204 .23378 m
.40476 .23378 L
.40476 .27206 L
.38204 .27206 L
.38204 .23378 L
s
.38204 .27206 m
.40476 .27206 L
.40476 .30494 L
.38204 .30494 L
.38204 .27206 L
s
.38204 .30494 m
.40476 .30494 L
.40476 .33016 L
.38204 .33016 L
.38204 .30494 L
s
.38204 .33016 m
.40476 .33016 L
.40476 .34602 L
.38204 .34602 L
.38204 .33016 L
s
.38204 .34602 m
.40476 .34602 L
.40476 .35143 L
.38204 .35143 L
.38204 .34602 L
s
.97619 .03397 m
.97619 .08688 L
.97619 .13979 L
.97619 .1927 L
.97619 .24561 L
.97619 .29852 L
.97619 .35143 L
.97619 .35143 L
.97619 .29852 L
.97619 .24561 L
.97619 .1927 L
.97619 .13979 L
.97619 .08688 L
.97619 .03397 L
.97619 .03397 L
s
.97619 .1927 m
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
s
.97619 .35143 m
.97619 .34602 L
.97619 .33016 L
.97619 .30494 L
.97619 .27206 L
.97619 .23378 L
.97619 .1927 L
.97619 .15162 L
.97619 .11333 L
.97619 .08046 L
.97619 .05523 L
.97619 .03938 L
.97619 .03397 L
.97619 .03938 L
.97619 .05523 L
.97619 .08046 L
.97619 .11333 L
.97619 .15162 L
.97619 .1927 L
.97619 .23378 L
.97619 .27206 L
.97619 .30494 L
.97619 .33016 L
.97619 .34602 L
.97619 .35143 L
s
.039 .916 .04 r
.02381 .1927 m
.34621 .24955 L
s
% Start of user PostScript
-50. 0 0.778587 8.95363 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34621 .24955 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1927 m
.34127 .1927 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1927 m
.34621 .13585 L
s
% Start of user PostScript
-50. 0 0.778587 -8.95363 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34621 .13585 Mdot
.039 .916 .04 r
.5 Mabswid
.34621 .24955 m
.40476 .25265 L
s
% Start of user PostScript
0.778587 8.95363 10. 9.44237 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .25265 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .1927 m
.40476 .1927 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.34621 .13585 m
.40476 .13275 L
s
% Start of user PostScript
0.778587 -8.95363 10. -9.44237 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .13275 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .25265 m
.97619 .29874 L
s
% Start of user PostScript
10. 9.44237 100. 16.7017 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .29874 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .1927 m
.97619 .1927 L
s
% Start of user PostScript
10. 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .13275 m
.97619 .08666 L
s
% Start of user PostScript
10. -9.44237 100. -16.7017 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .08666 Mdot
gsave
.37302 .00857 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00857 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .36 L
0 .36 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 103.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ib000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00JOooool6o`000:7ooooo0ol0
000=ooooo`00J_ooool01Ol0003ooooooooooooooooo00000:7ooooo00Co0000oooooooooooo0000
3?ooool006[ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0:ooooo`00J_ooool0
0ol0003oooooooooo`2Tooooo`;o00003Oooool006[ooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`0=ooooo`00J_ooool00ol0003oooooooooo`2Sooooo`04o`000?ooooooooooo`00
00cooooo001Yooooo`?o0000YOooool3o`0000cooooo003oooooob7ooooo003oooooob7ooooo001_
ooooo`Oo0000W?ooool00ol0003oooooooooo`0;ooooo`00Koooool7o`0009cooooo00?o0000oooo
ooooool02oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooooooo
ool02oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
2oooool006gooooo00?o0000ogmoOol000001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001]ooooo`03o`000?moOgoo000000GoOgmo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0;ooooo`00K?ooool00ol0003oOgmoogmoO`07o`0009cooooo00?o0000oooo
ooooool02oooool006cooooo00Co0000ogmoOomoOgoo00001OmoOgl00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo00_ooooo001[ooooo`05o`000?moOgooOgmoogmoOol000001OmoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001[ooooo`05o`000?moOgooOgmoogmo
Ool000001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Zooooo`03
o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo00_ooooo001Zooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Yooooo`03o`000?mo
OgooOgmo00?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001Yooooo`03o`000?moOgooOgmo00?oOgmo1ol0002Dooooo`Go2NX:0oooool0
0ol0003oooooooooo`0;ooooo`00J?ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo
00?oOgmo00?o0000ooooooooool0Toooool6o`WZ2P;o00003Oooool006Sooooo00?o0000ogmoOomo
Ogl01?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo08Sooooo4Ol9jPX2o`0000go
oooo001Xooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`1looooo`co2NX:2oooool3o`WZ2PCooooo00?o0000ooooooooool02oooool006Oooooo00?o
0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo073ooooo3?l9
jPXFooooo`03o`WZ2_oooooooooo00Gooooo00?o0000ooooooooool02oooool006Oooooo00?o0000
ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo06Cooooo3?l9jPXZ
ooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmo
OomoOgl00omoOgl00ol0003oooooooooo`1Hooooo`co2NX:=_ooool00ol0003oooooooooo`0;oooo
o`00Ioooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000oooooooo
ool0Boooool=o`WZ2T;ooooo00?o0000ooooooooool02oooool006Oooooo00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo03oooooo3?l9jPY?ooooo`03o`00
0?oooooooooo00_ooooo001Vooooo`03o`000?moOgooOgmo00KoOgmo1ol0000eooooo`co2NX:Fooo
ool00ol0003oooooooooo`0;ooooo`00I_ooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ooooooooool09oooool<o`WZ2VOooooo00?o0000ooooooooool02oooool0
06Kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo
01_ooooo3?l9jPYcooooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?moOgooOgmo00Co
Ogmo0ol9jPX5ogmoO`03o`000?oooooooooo00oooooo3?l9jPYoooooo`03o`000?oooooooooo00_o
oooo001Vooooo`03o`000?moOgooOgmo00GoOgmo1_l9jPX00omoOgoo0000ooooo`04ooooo`co2NX:
Roooool00ol0003oooooooooo`0;ooooo`00G?ooool6o`WZ2P;ooooo0_l00007ogmoO`Oo2NX:00?o
0000o`WZ2_l9jPX01?l9jPZGooooo`03o`000?oooooooooo00_ooooo001Nooooo`Ko2NX:00?o0000
o`WZ2_l9jPX01_l9jPX00omoOgoo2NX:o`WZ2P03o`WZ2P03ogmoOol0003o000009cooooo00?o0000
ooooooooool02oooool005cooooo2?l9jPX00ooooooo0000ogmoO`06ogmoO`;o2NX:00?o0000ogmo
OomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Fooooo`Ko
2NX:0_ooool3o`WZ2PCooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool0053ooooo1_l9jPX7ooooo`03o`WZ
2_oooooooooo00Gooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`00
0?oooooooooo09[ooooo00?o0000ooooooooool02oooool004[ooooo1_l9jPXEooooo`03o`000?mo
OgooOgmo00OoOgmo1ol0002Looooo`03o`000?oooooooooo00_ooooo0014ooooo`Ko2NX:6_ooool0
0ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0;ooooo`00?_ooool6o`WZ2R3ooooo00?o0000ogmoOomoOgl02?moOgl00ol0
003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool003So
oooo1_l9jPXVooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo000cooooo`Go2NX:;?ooool00ol0003oOgmo
ogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003ooooo
ooooo`0;ooooo`00;Oooool6o`WZ2S7ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmo
O`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool002Oooooo1_l9jPXg
ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo00_ooooo000Qooooo`Ko2NX:?Oooool00ol0003oOgmoogmoO`08ogmo
O`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;oooo
o`006oooool6o`WZ2T;ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool001Gooooo1_l9jPY0ooooo`?o2NX:
1Oooool00ol0003oOgmoogmoO`07ogmoO`?o2NX:1OmoOgl00ol0003oooooooooo`2Booooo`?o2NX:
1Oooool00ol0003oooooooooo`0;ooooo`003oooool6o`WZ2TOooooo1_l9jPX00ooooooo0000ogmo
O`09ogmoO`Ko2NX:00?oOgmoo`000?ooool0U?ooool6o`WZ2P03ooooool0003ooooo00cooooo000<
ooooofSo2NX:00?o0000o`WZ2_l9jPX0V_l9jPX2o`0000gooooo000@ooooo`Go2NX:Aoooool5o`WZ
2P;ooooo0_l00009ogmoO`Go2NX:00?oOgmoo`000?l00000UOooool5o`WZ2P03ooooool0003o0000
00gooooo000Eooooo`Ko2NX:@?ooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01omoOgl2o`WZ2P03
o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0T_ooool2o`WZ2PKooooo00?o0000oooooooo
ool02oooool001_ooooo1Ol9jPY3ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo000Pooooo`Ko2NX:?Ooo
ool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_oo
ool00ol0003oooooooooo`0;ooooo`009_ooool6o`WZ2SSooooo00?o0000ogmoOomoOgl02?moOgl0
0ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool0
02cooooo1Ol9jPXcooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo000aooooo`Ko2NX:;Oooool00ol0003o
OgmoogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003o
ooooooooo`0;ooooo`00=oooool5o`WZ2RSooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool003cooooo1_l9
jPXRooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`2Jooooo`03o`000?oooooooooo00_ooooo0012ooooo`Go2NX:7Oooool00ol0003oOgmoogmoO`08
ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;
ooooo`00Aoooool6o`WZ2QOooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool004gooooo1_l9jPXBooooo`03
o`000?moOgooOgmo00OoOgmo1ol0002Looooo`03o`000?oooooooooo00_ooooo001Cooooo`Go2NX:
1Oooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`00
0?oooooooooo09[ooooo00?o0000ooooooooool02oooool005Sooooo2_l9jPX3ooooo`03o`000?mo
OgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001Nooooo`Oo2NX:00?o0000ogmoOomoOgl01OmoOgl3o`WZ2PGoOgmo00?o0000
ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00GOooool7o`WZ2P03o`000?l9jP[o2NX:
00go2NX:0_l0002Looooo`03o`000?oooooooooo00_ooooo001Looooo`Go2NX:0oooool2o`0000So
Ogmo1_l9jPX00ol0003o2NX:o`WZ2P05o`WZ2YKooooo00?o0000ooooooooool02oooool006Kooooo
00?o0000ogmoOomoOgl01OmoOgl5o`WZ2P;oOgmo00?o0000ooooooooool01?ooool<o`WZ2X[ooooo
00?o0000ooooooooool02oooool006Kooooo00?o0000ogmoOomoOgl01?moOgl2o`WZ2P03o`000?mo
OgooOgmo00?oOgmo00?o0000ooooooooool04?ooool<o`WZ2Wkooooo00?o0000ooooooooool02ooo
ool006Kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo01cooooo3?l9jPYbooooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?moOgooOgmo
00KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0Xooooo`co2NX:I_ooool00ol0
003oooooooooo`0;ooooo`00I_ooool00ol0003oOgmoogmoO`06ogmoO`Oo0000=_ooool<o`WZ2U[o
oooo00?o0000ooooooooool02oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo043ooooo3Ol9jPY=ooooo`03o`000?oooooooooo00_ooooo
001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`1=ooooo`co2NX:@Oooool00ol0003oooooooooo`0;ooooo`00Ioooool00ol0003oOgmoogmoO`05
ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0FOooool<o`WZ2SGooooo00?o0000
ooooooooool02oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo06Gooooo3?l9jPXYooooo`03o`000?oooooooooo00_ooooo001Wooooo`03
o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1aooooo`co
2NX:5Oooool2o`WZ2PKooooo00?o0000ooooooooool02oooool006Sooooo00?o0000ogmoOomoOgl0
1?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo07gooooo3?l9jPX:ooooo`Co2NX:
0oooool00ol0003oooooooooo`0;ooooo`00J?ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?mo
OgooOgmo00?oOgmo00?o0000ooooooooool0ROooool@o`WZ2P;o00003Oooool006Sooooo00?o0000
ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09?ooooo1_l9jPX2
o`0000gooooo001Xooooo`03o`000?moOgooOgmo00CoOgmo1ol0002Dooooo`Co2NX:1?ooool00ol0
003oooooooooo`0;ooooo`00JOooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00JOooool00ol0003oOgmo
ogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003ooooo
ooooo`0;ooooo`00J_ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o
0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00J_ooool00ol0003oOgmoogmoO`02
ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;
ooooo`00Joooool01Ol0003oOgmoogmoOomoOgoo000000GoOgmo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0;ooooo`00Joooool01Ol0003oOgmoogmoOomoOgoo000000GoOgmo00?o0000
ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00K?ooool00ol0003oOgmoogmoO`07o`00
09cooooo00?o0000ooooooooool02oooool006cooooo00Co0000ogmoOomoOgoo00001OmoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001]ooooo`03o`000?moOgoo000000Go
Ogmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00KOooool00ol0003oOgmo
o`000005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006kooooo0_l0
0005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006kooooo2?l0002L
ooooo`03o`000?oooooooooo00_ooooo001_ooooo`Oo0000W?ooool00ol0003oooooooooo`0;oooo
o`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {102.625, 0}} -> {-57.2027, -32.4375, \
0.572841, 0.572841}},
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],

Cell[BoxData[
    \(\(\(155.23244752966428`\)\(\[InvisibleSpace]\)\) + \
\(48.368378051367515`\ y\^2\)\/f\^2 - \(0.5004652304391106`\ y\^2\)\/f\)], \
"Output",
  CellLabel->"Out[21]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}]
}, Open  ]],

Cell[TextData[{
  "In all three cases, even though the three different light sources have \
different characteristics, the resulting symbolic solution is exactly the \
same. This is because the chief ray from each source follows the same \
trajectory through the optics. Therefore, when ",
  StyleBox["SymbolicTrace", "Input"],
  " is involved, the type of light source is not as important as the starting \
position and direction of its chief ray."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options of SymbolicTrace", "Subsubsection",
  CellTags->{"AOG0.", "2.1.5", "AOG2.", "AOG2.1", "AOG2.1.5"}],

Cell[TextData[{
  StyleBox["SymbolicTrace", "Input"],
  " has many special option settings, many of which are seldom changed by the \
user. However, one of the best ways to understand ",
  StyleBox["SymbolicTrace", "Input"],
  " is to study its options. These many options are present in order to \
provide complete user control over the symbolic solution creation process. \
See the Help Browser listing for ",
  StyleBox["SymbolicTrace", "Input"],
  " to learn more about its options. In addition to ",
  StyleBox["SymbolicTrace", "Input"],
  ", many of these options are shared by other functions in ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " including: ",
  StyleBox["FindABCDMatrix", "Input"],
  ", ",
  StyleBox["GaussianTrace", "Input"],
  ", and ",
  StyleBox["GaussianPlot", "Input"],
  "."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],

Cell[CellGroupData[{

Cell["Options[SymbolicTrace]", "Input",
  CellLabel->"In[22]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(Simplify \[Rule] Automatic\), 
        ",", \(ParentFunction \[Rule] SymbolicTrace\), 
        ",", \(SeriesOrder \[Rule] 1\), 
        ",", \(LocalCoordinateExpansions \[Rule] {{SCx, 
              Hold[SurfaceCoordinates\[LeftDoubleBracket]1\
\[RightDoubleBracket]], SeriesOrder}, {SCy, 
              Hold[SurfaceCoordinates\[LeftDoubleBracket]2\
\[RightDoubleBracket]], SeriesOrder}, {RSy, 
              Hold[RayStart\[LeftDoubleBracket]2\[RightDoubleBracket]], 
              SeriesOrder}, {RSz, 
              Hold[RayStart\[LeftDoubleBracket]3\[RightDoubleBracket]], 
              SeriesOrder}, {RTx, 
              Hold[RayTilt\[LeftDoubleBracket]1\[RightDoubleBracket]], 
              SeriesOrder}, {RTy, 
              Hold[RayTilt\[LeftDoubleBracket]2\[RightDoubleBracket]], 
              SeriesOrder}, {RTz, 
              Hold[RayTilt\[LeftDoubleBracket]3\[RightDoubleBracket]], 
              SeriesOrder}}\), ",", \(SeriesExpand \[Rule] Automatic\), 
        ",", \(SymbolicRayEnd \[Rule] SeriesOrder\), 
        ",", \(SymbolicRayTilt \[Rule] SeriesOrder\), 
        ",", \(SymbolicRayLength \[Rule] SeriesOrder\), 
        ",", \(SymbolicSurfaceFunction \[Rule] SeriesOrder\), 
        ",", \(SymbolicSurfaceNormalFunction \[Rule] SeriesOrder\), 
        ",", \(SymbolicSurfaceCoordinates \[Rule] SeriesOrder\), ",", 
        RowBox[{"SymbolicAperture", "\[Rule]", 
          InterpretationBox["\[Infinity]",
            DirectedInfinity[ 1]]}], ",", 
        RowBox[{"SymbolicIntensity", "\[Rule]", 
          InterpretationBox["\[Infinity]",
            DirectedInfinity[ 1]]}], 
        ",", \(ApertureOrder \[Rule] SeriesOrder\), 
        ",", \(SymbolicRefractiveModels \[Rule] Automatic\), 
        ",", \(NormalizeSurfaceNormal \[Rule] True\), 
        ",", \(MaxByteCount \[Rule] 20000\), 
        ",", \(ByteCountLimit \[Rule] 20000000\), 
        ",", \(ExpandAlways \[Rule] False\), 
        ",", \(EliminateCrossTerms \[Rule] False\), 
        ",", \(FinalFormat \[Rule] True\), 
        ",", \(NestSurfaceSolutions \[Rule] True\), 
        ",", \(RunningCommentary \[Rule] False\), 
        ",", \(GlobalSurfaceCoordinates \[Rule] True\), 
        ",", \(ReportedSurfaces \[Rule] {\(-1\)}\), 
        ",", \(ReportedParameters \[Rule] All\), 
        ",", \(NumericalResults \[Rule] False\), 
        ",", \(TaylorSeries \[Rule] Automatic\), 
        ",", \(TimeConstraint \[Rule] 10\), ",", \(SkipSimplify \[Rule] {}\), 
        ",", \(FilterTrace \[Rule] False\), 
        ",", \(MakeFloatingPoint \[Rule] {RefractiveIndex}\), 
        ",", \(Precision \[Rule] 16\)}], "}"}]], "Output",
  CellLabel->"Out[22]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["SeriesOrder", "Input"],
  " option is one of the most important ways of controlling the form of the \
resulting symbolic solution. ",
  StyleBox["SymbolicTrace", "Input"],
  " uses ",
  StyleBox["SeriesOrder->1", "Input"],
  " as its default option setting. ",
  StyleBox["SeriesOrder->1", "Input"],
  " returns the first order Taylor's series symbolic solution to the optical \
system. ",
  StyleBox["SeriesOrder->Infinity", "Input"],
  " returns the complete, unapproximated symbolic solution to the system. \
Sometimes, however, ",
  StyleBox["SeriesOrder->Infinity", "Input"],
  " may result in a solution that is too large for your computer system's \
memory, possibly consuming hundreds of megabytes of space. Therefore, ",
  StyleBox["SeriesOrder", "Input"],
  " must be used with some care and respect."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],

Cell[CellGroupData[{

Cell["?SeriesOrder", "Input",
  CellLabel->"In[23]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],

Cell[BoxData[
    \("SeriesOrder is a option that specifies Taylor series expansion order \
used for symbolic calculations.\n\nSee also: SeriesExpand and \
LocalCoordinateExpansions."\)], "Print",
  CellTags->{
  "Info3312042819-8757440", "AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
opticalsystem = {
Move[LineOfRays[20], {-50,{y,0}}],
PlanoConvexLens[100,50,10,DesignWaveLength->.532],
Move[Screen[50],{d,100}]};
AnalyzeSystem[opticalsystem,PlotType->TopView];
SymbolicTrace[opticalsystem] (*SeriesOrder->1*)
ByteCount[%]\
\>", "Input",
  CellLabel->"In[24]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.192698 0.00634921 [
[.37302 .00857 -5.03125 -6 ]
[.37302 .00857 5.03125 6 ]
[.97619 .00857 -4.75 -6 ]
[.97619 .00857 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .36 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.38198 .03397 m
.40476 .03397 L
.40476 .08688 L
.35871 .08688 L
.38198 .03397 L
F
.35871 .08688 m
.40476 .08688 L
.40476 .13979 L
.34554 .13979 L
.35871 .08688 L
F
.34554 .13979 m
.40476 .13979 L
.40476 .1927 L
.34127 .1927 L
.34554 .13979 L
F
.34127 .1927 m
.40476 .1927 L
.40476 .24561 L
.34554 .24561 L
.34127 .1927 L
F
.34554 .24561 m
.40476 .24561 L
.40476 .29852 L
.35871 .29852 L
.34554 .24561 L
F
.35871 .29852 m
.40476 .29852 L
.40476 .35143 L
.38198 .35143 L
.35871 .29852 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.38198 .03397 m
.35871 .08688 L
.34554 .13979 L
.34127 .1927 L
.34554 .24561 L
.35871 .29852 L
.38198 .35143 L
.40476 .35143 L
.40476 .29852 L
.40476 .24561 L
.40476 .1927 L
.40476 .13979 L
.40476 .08688 L
.40476 .03397 L
.38198 .03397 L
s
.5 g
.38198 .1927 m
.40476 .1927 L
.40476 .1927 L
.35871 .1927 L
.38198 .1927 L
F
.35871 .1927 m
.40476 .1927 L
.40476 .1927 L
.34554 .1927 L
.35871 .1927 L
F
.34554 .1927 m
.40476 .1927 L
.40476 .1927 L
.34127 .1927 L
.34554 .1927 L
F
.34127 .1927 m
.40476 .1927 L
.40476 .1927 L
.34554 .1927 L
.34127 .1927 L
F
.34554 .1927 m
.40476 .1927 L
.40476 .1927 L
.35871 .1927 L
.34554 .1927 L
F
.35871 .1927 m
.40476 .1927 L
.40476 .1927 L
.38198 .1927 L
.35871 .1927 L
F
0 g
.38198 .1927 m
.35871 .1927 L
.34554 .1927 L
.34127 .1927 L
.34554 .1927 L
.35871 .1927 L
.38198 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.38198 .1927 L
s
.38198 .35143 m
.40476 .35143 L
.40476 .34602 L
.38198 .34602 L
.38198 .35143 L
s
.38198 .34602 m
.40476 .34602 L
.40476 .33016 L
.38198 .33016 L
.38198 .34602 L
s
.38198 .33016 m
.40476 .33016 L
.40476 .30494 L
.38198 .30494 L
.38198 .33016 L
s
.38198 .30494 m
.40476 .30494 L
.40476 .27206 L
.38198 .27206 L
.38198 .30494 L
s
.38198 .27206 m
.40476 .27206 L
.40476 .23378 L
.38198 .23378 L
.38198 .27206 L
s
.38198 .23378 m
.40476 .23378 L
.40476 .1927 L
.38198 .1927 L
.38198 .23378 L
s
.38198 .1927 m
.40476 .1927 L
.40476 .15162 L
.38198 .15162 L
.38198 .1927 L
s
.38198 .15162 m
.40476 .15162 L
.40476 .11333 L
.38198 .11333 L
.38198 .15162 L
s
.38198 .11333 m
.40476 .11333 L
.40476 .08046 L
.38198 .08046 L
.38198 .11333 L
s
.38198 .08046 m
.40476 .08046 L
.40476 .05523 L
.38198 .05523 L
.38198 .08046 L
s
.38198 .05523 m
.40476 .05523 L
.40476 .03938 L
.38198 .03938 L
.38198 .05523 L
s
.38198 .03938 m
.40476 .03938 L
.40476 .03397 L
.38198 .03397 L
.38198 .03938 L
s
.38198 .03397 m
.40476 .03397 L
.40476 .03938 L
.38198 .03938 L
.38198 .03397 L
s
.38198 .03938 m
.40476 .03938 L
.40476 .05523 L
.38198 .05523 L
.38198 .03938 L
s
.38198 .05523 m
.40476 .05523 L
.40476 .08046 L
.38198 .08046 L
.38198 .05523 L
s
.38198 .08046 m
.40476 .08046 L
.40476 .11333 L
.38198 .11333 L
.38198 .08046 L
s
.38198 .11333 m
.40476 .11333 L
.40476 .15162 L
.38198 .15162 L
.38198 .11333 L
s
.38198 .15162 m
.40476 .15162 L
.40476 .1927 L
.38198 .1927 L
.38198 .15162 L
s
.38198 .1927 m
.40476 .1927 L
.40476 .23378 L
.38198 .23378 L
.38198 .1927 L
s
.38198 .23378 m
.40476 .23378 L
.40476 .27206 L
.38198 .27206 L
.38198 .23378 L
s
.38198 .27206 m
.40476 .27206 L
.40476 .30494 L
.38198 .30494 L
.38198 .27206 L
s
.38198 .30494 m
.40476 .30494 L
.40476 .33016 L
.38198 .33016 L
.38198 .30494 L
s
.38198 .33016 m
.40476 .33016 L
.40476 .34602 L
.38198 .34602 L
.38198 .33016 L
s
.38198 .34602 m
.40476 .34602 L
.40476 .35143 L
.38198 .35143 L
.38198 .34602 L
s
.97619 .03397 m
.97619 .08688 L
.97619 .13979 L
.97619 .1927 L
.97619 .24561 L
.97619 .29852 L
.97619 .35143 L
.97619 .35143 L
.97619 .29852 L
.97619 .24561 L
.97619 .1927 L
.97619 .13979 L
.97619 .08688 L
.97619 .03397 L
.97619 .03397 L
s
.97619 .1927 m
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
s
.97619 .35143 m
.97619 .34602 L
.97619 .33016 L
.97619 .30494 L
.97619 .27206 L
.97619 .23378 L
.97619 .1927 L
.97619 .15162 L
.97619 .11333 L
.97619 .08046 L
.97619 .05523 L
.97619 .03938 L
.97619 .03397 L
.97619 .03938 L
.97619 .05523 L
.97619 .08046 L
.97619 .11333 L
.97619 .15162 L
.97619 .1927 L
.97619 .23378 L
.97619 .27206 L
.97619 .30494 L
.97619 .33016 L
.97619 .34602 L
.97619 .35143 L
s
.039 .916 .04 r
.02381 .12921 m
.34744 .12921 L
s
% Start of user PostScript
-50. -10. 0.971601 -10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34744 .12921 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1927 m
.34127 .1927 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25619 m
.34744 .25619 L
s
% Start of user PostScript
-50. 10. 0.971601 10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34744 .25619 Mdot
.039 .916 .04 r
.5 Mabswid
.34744 .12921 m
.40476 .13303 L
s
% Start of user PostScript
0.971601 -10. 10. -9.3974 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .13303 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .1927 m
.40476 .1927 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.34744 .25619 m
.40476 .25236 L
s
% Start of user PostScript
0.971601 10. 10. 9.3974 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .25236 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .13303 m
.97619 .19114 L
s
% Start of user PostScript
10. -9.3974 100. -0.245678 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19114 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .1927 m
.97619 .1927 L
s
% Start of user PostScript
10. 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .25236 m
.97619 .19426 L
s
% Start of user PostScript
10. 9.3974 100. 0.245678 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19426 Mdot
gsave
.37302 .00857 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00857 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .36 L
0 .36 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{288, 103.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ib000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00JOooool6o`000:7ooooo0ol0
000=ooooo`00J_ooool01Ol0003ooooooooooooooooo00000:7ooooo00Co0000oooooooooooo0000
3?ooool006[ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0:ooooo`00J_ooool0
0ol0003oooooooooo`2Tooooo`;o00003Oooool006[ooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`0=ooooo`00J_ooool00ol0003oooooooooo`2Sooooo`04o`000?ooooooooooo`00
00cooooo001Yooooo`?o0000YOooool3o`0000cooooo003oooooob7ooooo003oooooob7ooooo001_
ooooo`Oo0000W?ooool00ol0003oooooooooo`0;ooooo`00Koooool7o`0009cooooo00?o0000oooo
ooooool02oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooooooo
ool02oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
2oooool006gooooo00?o0000ogmoOol000001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001]ooooo`03o`000?moOgoo000000GoOgmo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0;ooooo`00K?ooool00ol0003oOgmoogmoO`07o`0009cooooo00?o0000oooo
ooooool02oooool006cooooo00Co0000ogmoOomoOgoo00001OmoOgl00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo00_ooooo001[ooooo`05o`000?moOgooOgmoogmoOol000001OmoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001[ooooo`05o`000?moOgooOgmoogmo
Ool000001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Zooooo`03
o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo00_ooooo001Zooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Yooooo`03o`000?mo
OgooOgmo00?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001Yooooo`03o`000?moOgooOgmo00?oOgmo1ol0002Looooo`03o`000?oooooo
oooo00_ooooo001Xooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Xooooo`03o`000?moOgooOgmo00Co
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_o
oooo001Xooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o
0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001W
ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmo
OomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Wooooo`03
o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?mo
OgooOgmo00KoOgmo1ol0002Looooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?moOgoo
Ogmo00KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooo
oooo00_ooooo001Mooooo`?o2NX:1_ooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo
00?oOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00G_ooool6o`WZ2P;o
oooo00?o0000ogmoOomoOgl01?moOgl3o`WZ2PGoOgmo00?o0000ooooooooool0V_ooool00ol0003o
ooooooooo`0;ooooo`003?oooomXo`WZ2P03ogmoOol0003ooooo09_ooooo00?o0000ooooooooool0
2oooool005kooooo1Ol9jPX2ooooo`;o00001omoOgl6o`WZ2P03o`000?l9jP[o2NX:00Co2NX:Uooo
ool00ol0003oooooooooo`0;ooooo`00GOooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01_moOgl5
o`WZ2P03ogmoOol0003o000000Gooooo2_l9jPZ=ooooo`03o`000?oooooooooo00_ooooo001Uoooo
o`03o`000?moOgooOgmo00GoOgmo0_l9jPX00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo
00gooooo2_l9jPZ3ooooo`03o`000?oooooooooo00_ooooo001Uooooo`03o`000?moOgooOgmo00Oo
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0Gooooo`Wo2NX:N_ooool00ol0003o
ooooooooo`0;ooooo`00IOooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00?oOgmo
00?o0000ooooooooool08?ooool:o`WZ2W3ooooo00?o0000ooooooooool02oooool006Gooooo00?o
0000ogmoOomoOgl01omoOgl7o`0002cooooo2_l9jPYVooooo`03o`000?oooooooooo00_ooooo001T
ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0d
ooooo`[o2NX:G?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmo
O`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0?_ooool:o`WZ2U;ooooo00?o0000oooo
ooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo04Sooooo2Ol9jPY9ooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`00
0?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1Aooooo`[o2NX:
?oooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?mo
OgooOgmo00?oOgmo00?o0000ooooooooool0Foooool:o`WZ2SGooooo00?o0000ooooooooool02ooo
ool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo06Gooooo2_l9jPX[ooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`000?moOgooOgmo
00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1_ooooo`[o2NX:8Oooool00ol0
003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0NOooool9o`WZ2Q3ooooo0_l9jPX6ooooo`03o`000?oooooooooo00_o
oooo001Kooooo`?o2NX:1Oooool00ol0003oOgmoogmoO`07ogmoO`?o2NX:1OmoOgl00ol0003ooooo
ooooo`22ooooo`[o2NX:1_ooool5o`WZ2P?ooooo00?o0000ooooooooool02oooool005cooooo1_l9
jPX00ooooooo0000ogmoO`09ogmoO`Ko2NX:00?oOgmoo`000?ooool0SOooool>o`WZ2P03o`000?oo
oooooooo00_ooooo000<ooooofSo2NX:00?o0000o`WZ2_l9jPX0V_l9jPX2o`0000gooooo001Loooo
o`Go2NX:0_ooool2o`0000WoOgmo1Ol9jPX00omoOgoo0000o`00002Dooooo`Oo2NX:0_l0000=oooo
o`00Foooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01omoOgl2o`WZ2P03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0Roooool>o`WZ2P03ooooool0003ooooo00cooooo001Sooooo`03o`00
0?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`21ooooo`[o2NX:
2?ooool3o`WZ2PCooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo07Sooooo2Ol9jPXAooooo`03o`WZ2_oo
oooooooo00Gooooo00?o0000ooooooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl0
0ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo06kooooo2_l9jPXRooooo`03o`000?oooooo
oooo00_ooooo001Tooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`1Tooooo`[o2NX:;?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003o
OgmoogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0F_ooool:o`WZ2SKo
oooo00?o0000ooooooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo053ooooo2_l9jPY0ooooo`03o`000?oooooooooo00_ooooo
001Tooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`17ooooo`Wo2NX:B_ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08
ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0?Oooool:o`WZ2U?ooooo00?o0000
ooooooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo03?ooooo2_l9jPYMooooo`03o`000?oooooooooo00_ooooo001Uooooo`03
o`000?moOgooOgmo00OoOgmo1ol0000[ooooo`[o2NX:Ioooool00ol0003oooooooooo`0;ooooo`00
IOooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0
7oooool:o`WZ2W7ooooo00?o0000ooooooooool02oooool006Gooooo00?o0000ogmoOomoOgl01omo
Ogl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo01Kooooo2Ol9jPYkooooo`03o`000?oo
oooooooo00_ooooo001Uooooo`03o`000?moOgooOgmo00GoOgmo0ol9jPX5ogmoO`03o`000?oooooo
oooo00cooooo2_l9jPZ4ooooo`03o`000?oooooooooo00_ooooo001Mooooo`?o2NX:1Oooool00ol0
003oOgmoogmoO`06ogmoO`Ko2NX:0_l00004ooooo`[o2NX:S_ooool00ol0003oooooooooo`0;oooo
o`00G_ooool6o`WZ2P03ooooool0003o000000KoOgmo1ol9jPX00ol0003o2NX:o`WZ2P03o`WZ2YSo
oooo00?o0000ooooooooool02oooool000coooooHOl9jPX00omoOgoo2NX:o`WZ2P03o`WZ2P;oOgmo
00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00G_ooool5o`WZ2P?ooooo00?o
0000ogmoOomoOgl01?moOgl2o`WZ2P03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_oo
ool00ol0003oooooooooo`0;ooooo`00GOooool2o`WZ2POooooo00?o0000ogmoOomoOgl01_moOgl0
0ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool0
06Kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo
09[ooooo00?o0000ooooooooool02oooool006Kooooo00?o0000ogmoOomoOgl01_moOgl7o`0009co
oooo00?o0000ooooooooool02oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Oooooo00?o
0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o
0000ooooooooool02oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Oooooo00?o0000ogmo
OomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooo
ooooool02oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006Sooooo00?o0000ogmoOomoOgl0
1?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
2oooool006Sooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oo
oooooooo09[ooooo00?o0000ooooooooool02oooool006Sooooo00?o0000ogmoOomoOgl01?moOgl0
0ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool0
06Sooooo00?o0000ogmoOomoOgl01?moOgl7o`0009cooooo00?o0000ooooooooool02oooool006Wo
oooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[o
oooo00?o0000ooooooooool02oooool006Wooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006[ooooo00?o
0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09[ooooo00?o
0000ooooooooool02oooool006[ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006_ooooo00Go0000ogmo
OomoOgooOgmoo`000005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool0
06_ooooo00Go0000ogmoOomoOgooOgmoo`000005ogmoO`03o`000?oooooooooo09[ooooo00?o0000
ooooooooool02oooool006cooooo00?o0000ogmoOomoOgl01ol0002Looooo`03o`000?oooooooooo
00_ooooo001/ooooo`04o`000?moOgooOgmoo`0000GoOgmo00?o0000ooooooooool0V_ooool00ol0
003oooooooooo`0;ooooo`00KOooool00ol0003oOgmoo`000005ogmoO`03o`000?oooooooooo09[o
oooo00?o0000ooooooooool02oooool006gooooo00?o0000ogmoOol000001OmoOgl00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00_ooooo001^ooooo`;o00001OmoOgl00ol0003ooooooooo
o`2Jooooo`03o`000?oooooooooo00_ooooo001^ooooo`So0000W?ooool00ol0003oooooooooo`0;
ooooo`00Koooool7o`0009cooooo00?o0000ooooooooool02oooool00?oooooo8Oooool00?oooooo
8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {102.625, 0}} -> {-57.2027, -32.4375, \
0.572841, 0.572841}},
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],

Cell[BoxData[
    \({SymbolicOpticalLength \[Rule] \(\(55.20550238395627`\)\(\
\[InvisibleSpace]\)\) + 1.0002694514570802`\ d, 
      SymbolicRayEnd \[Rule] {d, 
          1.0341430267856087`\ y - 0.00999212058725169`\ d\ y, 0}, 
      SymbolicRayTilt \[Rule] {1, \(-0.00999212058725169`\)\ y, 0}, 
      SymbolicSurfaceCoordinates \[Rule] {1.0341430267856087`\ y - 
            0.00999212058725169`\ d\ y, 0}, 
      SymbolicIntensity \[Rule] 
        100\ \[ExponentialE]\^\(\(-0.0029964326570722766`\)\ y\^2 - 1\/625\ \
\((\(\(1.0341430267856087`\)\(\[InvisibleSpace]\)\) - 0.00999212058725169`\ \
d)\)\^2\ y\^2\), SymbolicSurfaceBoundary \[Rule] {50, 50}, 
      SymbolicOffAxis \[Rule] {0, 0}, 
      SymbolicTranslationVector \[Rule] {d, 0, 0}, 
      SymbolicRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
      SymbolicWaveLength \[Rule] 133\/250, 
      SymbolicSurfaceNormalFunction \[Rule] {1, 0, 0}}\)], "Output",
  CellLabel->"Out[26]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],

Cell[BoxData[
    \(1656\)], "Output",
  CellLabel->"Out[27]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
SymbolicTrace[opticalsystem,SeriesOrder->2]
ByteCount[%]\
\>", "Input",
  CellLabel->"In[28]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],

Cell[BoxData[
    \(Simplify::"time" \(\(:\)\(\ \)\) 
      "Time spent on a transformation exceeded \!\(10\) seconds, and the \
transformation was aborted. Increasing the value of TimeConstraint option may \
improve the result of simplification."\)], "Message",
  CellLabel->"From In[28]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("$SimplifyByteConstraint has been reset to "\
\[InvisibleSpace]4164\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "$SimplifyByteConstraint has been reset to ", 4164, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[28]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],

Cell[BoxData[
    \({SymbolicOpticalLength \[Rule] \(\(55.20550238395628`\)\(\
\[InvisibleSpace]\)\) + 1.0002694514570802`\ d - 
          0.005168033072976129`\ y\^2 + 0.00004993468826511552`\ d\ y\^2 - 
          3.412773542524526`*^-7\ y\^4 + 3.1990624711963984`*^-9\ d\ y\^4, 
      SymbolicRayEnd \[Rule] {d, 
          1.0341430267856087`\ y - 0.00999212058725169`\ d\ y + 
            0.00006687763828783325`\ y\^3 - 4.988190191203349`*^-7\ d\ y\^3 + 
            1.6584747506818816`*^-9\ y\^5, 0}, 
      SymbolicRayTilt \[Rule] {\(\(1.`\)\(\[InvisibleSpace]\)\) - 
            0.00004992123691508951`\ y\^2 - 
            7.060708162221938`*^-10\ y\^4, \(-0.00999212058725169`\)\ y, 0}, 
      SymbolicSurfaceCoordinates \[Rule] {1.0341430267856087`\ y - 
            0.00999212058725169`\ d\ y + 0.00006687763828783325`\ y\^3 - 
            4.988190191203349`*^-7\ d\ y\^3 + 1.6584747506818816`*^-9\ y\^5, 
          0}, SymbolicIntensity \[Rule] 
        100\ \[ExponentialE]\^\(\(-\(y\^4\/390625\)\) - \
\((0.9342218209130917`\ y + 0.0000618894480966299`\ y\^3 + \
1.3389066789809796`*^-9\ y\^5)\)\^4\/390625 - \(y\^4\ \
\((\(\(1.0341430267856087`\)\(\[InvisibleSpace]\)\) + 0.00006687763828783325`\
\ y\^2 + 1.6584747506818816`*^-9\ y\^4 + d\ \((\(-0.00999212058725169`\) - \
4.988190191203349`*^-7\ y\^2)\))\)\^4\)\/390625\), 
      SymbolicSurfaceBoundary \[Rule] {50, 50}, 
      SymbolicOffAxis \[Rule] {0, 0}, 
      SymbolicTranslationVector \[Rule] {d, 0, 0}, 
      SymbolicRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
      SymbolicWaveLength \[Rule] 133\/250, 
      SymbolicSurfaceNormalFunction \[Rule] {1, 0, 0}}\)], "Output",
  CellLabel->"Out[28]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],

Cell[BoxData[
    \(3280\)], "Output",
  CellLabel->"Out[29]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}]
}, Open  ]],

Cell["\<\
SymbolicTrace[opticalsystem, SeriesOrder->Infinity, \
MakeFloatingPoint->True]\
\>", "Input",
  CellLabel->"In[30]:=",
  ShowCellBracket->True,
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],

Cell[CellGroupData[{

Cell["ByteCount[%]", "Input",
  CellLabel->"In[31]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],

Cell[BoxData[
    \(23232\)], "Output",
  CellLabel->"Out[31]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Working with SymbolicTrace", "Subsubsection",
  CellTags->{"AOG0.", "2.1.6", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[TextData[{
  "In addition to using the ",
  StyleBox["SeriesOrder", "Input"],
  " option, the power expansion of a particular user-specified variable may \
be directly given. In such a case, the resulting solution order corresponds \
directly with the specified order. This is because the expansion takes place \
after the surface solutions are combined. If desired, the Taylor series \
expansion process can be closely monitered with the ",
  StyleBox["RunningCommentary->All", "Input"],
  " option setting."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[CellGroupData[{

Cell[TextData[{
  "SymbolicTrace[opticalsystem, {{y,0,2}}, ",
  StyleBox["RunningCommentary->All", "Input"],
  "]"
}], "Input",
  CellLabel->"In[32]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[BoxData[
    \("Starting SymbolicTrace"\)], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    \("Construct surface equations."\)], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    \("Calling TurboTrace to get symbolic system information for each \
wavefront."\)], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    \("Reducing surface variables into x-y planar geometry."\)], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Surface "\[InvisibleSpace]{1, 1}\),
      SequenceForm[ "Surface ", {1, 1}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Building SymbolicSurfaceIntersectionFunction for "\
\[InvisibleSpace]SphericalShape\[InvisibleSpace]"."\),
      SequenceForm[ 
      "Building SymbolicSurfaceIntersectionFunction for ", SphericalShape, 
        "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Creating SymbolicRayTilt \
"\[InvisibleSpace]{Refraction, {IntrinsicMedium, BK7}, 
          Intensity \[Rule] {IntrinsicMedium, BK7}, 
          FresnelReflections \[Rule] False, Theory \[Rule] Automatic}\),
      SequenceForm[ 
      "Creating SymbolicRayTilt ", {Refraction, {IntrinsicMedium, BK7}, 
        Intensity -> {IntrinsicMedium, BK7}, FresnelReflections -> False, 
        Theory -> Automatic}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(0.02999999999999403`\[InvisibleSpace]" Seconds \
consumed at Surface."\),
      SequenceForm[ 0.029999999999994031, " Seconds consumed at Surface."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(7576\[InvisibleSpace]" Bytes consumed at Surface."\),
      SequenceForm[ 7576, " Bytes consumed at Surface."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Surface "\[InvisibleSpace]{1, 2}\),
      SequenceForm[ "Surface ", {1, 2}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Building SymbolicSurfaceIntersectionFunction for "\
\[InvisibleSpace]PlanarShape\[InvisibleSpace]"."\),
      SequenceForm[ 
      "Building SymbolicSurfaceIntersectionFunction for ", PlanarShape, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Creating SymbolicRayTilt \
"\[InvisibleSpace]{Refraction, {IntrinsicMedium, BK7}, 
          Intensity \[Rule] {IntrinsicMedium, BK7}, 
          FresnelReflections \[Rule] False, Theory \[Rule] Automatic}\),
      SequenceForm[ 
      "Creating SymbolicRayTilt ", {Refraction, {IntrinsicMedium, BK7}, 
        Intensity -> {IntrinsicMedium, BK7}, FresnelReflections -> False, 
        Theory -> Automatic}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(0.030000000000001137`\[InvisibleSpace]" Seconds \
consumed at Surface."\),
      SequenceForm[ 0.030000000000001137, " Seconds consumed at Surface."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(5044\[InvisibleSpace]" Bytes consumed at Surface."\),
      SequenceForm[ 5044, " Bytes consumed at Surface."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Surface "\[InvisibleSpace]{1, 3}\),
      SequenceForm[ "Surface ", {1, 3}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Building SymbolicSurfaceIntersectionFunction for "\
\[InvisibleSpace]PlanarShape\[InvisibleSpace]"."\),
      SequenceForm[ 
      "Building SymbolicSurfaceIntersectionFunction for ", PlanarShape, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Creating SymbolicRayTilt \
"\[InvisibleSpace]{Transmission, 100}\),
      SequenceForm[ "Creating SymbolicRayTilt ", {Transmission, 100}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(0.020000000000003126`\[InvisibleSpace]" Seconds \
consumed at Surface."\),
      SequenceForm[ 0.020000000000003126, " Seconds consumed at Surface."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(3024\[InvisibleSpace]" Bytes consumed at Surface."\),
      SequenceForm[ 3024, " Bytes consumed at Surface."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(0.46999999999999886`\[InvisibleSpace]" Seconds \
consumed constructing surface equations."\),
      SequenceForm[ 
      0.46999999999999886, 
        " Seconds consumed constructing surface equations."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    \("Begin nesting of surface equations."\)], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Wavefront #"\[InvisibleSpace]1\),
      SequenceForm[ "Wavefront #", 1],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Nesting Surface #"\[InvisibleSpace]1\),
      SequenceForm[ "Nesting Surface #", 1],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicRayLength\[InvisibleSpace]" with \
"\[InvisibleSpace]348\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 
            2}}\),
      SequenceForm[ 
      "Taylor series expand ", SymbolicRayLength, " with ", 348, 
        " Bytes: ", {{y, 0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayLength\[InvisibleSpace]" with \
"\[InvisibleSpace]144\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]28\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayLength, " with ", 144, 
        " Bytes: $SimplifyID = ", 28, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayLength\
\[InvisibleSpace]" now contains "\[InvisibleSpace]144\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayLength, " now contains ", 144, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]36\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 2}}\),
      SequenceForm[ 
      "Taylor series expand ", SymbolicSurfaceCoordinates, " with ", 36, 
        " Bytes: ", {{y, 0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]36\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]29\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceCoordinates, " with ", 36, 
        " Bytes: $SimplifyID = ", 29, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" now contains "\
\[InvisibleSpace]36\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceCoordinates, " now contains ", 36, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" with "\
\[InvisibleSpace]1068\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 
            2}}\),
      SequenceForm[ 
      "Taylor series expand ", SymbolicSurfaceNormalFunction, " with ", 1068, 
        " Bytes: ", {{y, 0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" with "\
\[InvisibleSpace]280\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]30\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceNormalFunction, " with ", 280, 
        " Bytes: $SimplifyID = ", 30, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" now \
contains "\[InvisibleSpace]280\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceNormalFunction, " now contains ", 280, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]388\
\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 2}}\),
      SequenceForm[ 
      "Taylor series expand ", SymbolicRayEnd, " with ", 388, " Bytes: ", {{y,
         0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]148\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]31\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayEnd, " with ", 148, " Bytes: $SimplifyID = ", 
        31, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayEnd\
\[InvisibleSpace]" now contains "\[InvisibleSpace]148\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayEnd, " now contains ", 148, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]1748\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 
            2}}\),
      SequenceForm[ 
      "Taylor series expand ", SymbolicRayTilt, " with ", 1748, " Bytes: ", {{
        y, 0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]196\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]32\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayTilt, " with ", 196, " Bytes: $SimplifyID = ",
         32, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayTilt\
\[InvisibleSpace]" now contains "\[InvisibleSpace]196\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayTilt, " now contains ", 196, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Nesting Surface #"\[InvisibleSpace]2\),
      SequenceForm[ "Nesting Surface #", 2],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicRayLength\[InvisibleSpace]" with \
"\[InvisibleSpace]336\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 
            2}}\),
      SequenceForm[ 
      "Taylor series expand ", SymbolicRayLength, " with ", 336, 
        " Bytes: ", {{y, 0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayLength\[InvisibleSpace]" with \
"\[InvisibleSpace]116\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]34\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayLength, " with ", 116, 
        " Bytes: $SimplifyID = ", 34, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayLength\
\[InvisibleSpace]" now contains "\[InvisibleSpace]116\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayLength, " now contains ", 116, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]404\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 2}}\),
      
      SequenceForm[ 
      "Taylor series expand ", SymbolicSurfaceCoordinates, " with ", 404, 
        " Bytes: ", {{y, 0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]76\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]35\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceCoordinates, " with ", 76, 
        " Bytes: $SimplifyID = ", 35, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" now contains "\
\[InvisibleSpace]76\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceCoordinates, " now contains ", 76, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" with "\
\[InvisibleSpace]64\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]36\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceNormalFunction, " with ", 64, 
        " Bytes: $SimplifyID = ", 36, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" now \
contains "\[InvisibleSpace]64\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceNormalFunction, " now contains ", 64, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]92\
\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 2}}\),
      SequenceForm[ 
      "Taylor series expand ", SymbolicRayEnd, " with ", 92, " Bytes: ", {{y, 
        0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]92\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]37\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayEnd, " with ", 92, " Bytes: $SimplifyID = ", 
        37, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayEnd\
\[InvisibleSpace]" now contains "\[InvisibleSpace]92\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayEnd, " now contains ", 92, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]632\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 
            2}}\),
      SequenceForm[ 
      "Taylor series expand ", SymbolicRayTilt, " with ", 632, " Bytes: ", {{
        y, 0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]196\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]38\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayTilt, " with ", 196, " Bytes: $SimplifyID = ",
         38, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayTilt\
\[InvisibleSpace]" now contains "\[InvisibleSpace]196\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayTilt, " now contains ", 196, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Nesting Surface #"\[InvisibleSpace]3\),
      SequenceForm[ "Nesting Surface #", 3],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicRayLength\[InvisibleSpace]" with \
"\[InvisibleSpace]264\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 
            2}}\),
      SequenceForm[ 
      "Taylor series expand ", SymbolicRayLength, " with ", 264, 
        " Bytes: ", {{y, 0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayLength\[InvisibleSpace]" with \
"\[InvisibleSpace]288\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]40\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayLength, " with ", 288, 
        " Bytes: $SimplifyID = ", 40, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayLength\
\[InvisibleSpace]" now contains "\[InvisibleSpace]260\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayLength, " now contains ", 260, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]372\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 2}}\),
      
      SequenceForm[ 
      "Taylor series expand ", SymbolicSurfaceCoordinates, " with ", 372, 
        " Bytes: ", {{y, 0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]212\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]41\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceCoordinates, " with ", 212, 
        " Bytes: $SimplifyID = ", 41, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" now contains "\
\[InvisibleSpace]140\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceCoordinates, " now contains ", 140, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]144\
\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 2}}\),
      SequenceForm[ 
      "Taylor series expand ", SymbolicRayEnd, " with ", 144, " Bytes: ", {{y,
         0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]144\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]42\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayEnd, " with ", 144, " Bytes: $SimplifyID = ", 
        42, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayEnd\
\[InvisibleSpace]" now contains "\[InvisibleSpace]144\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayEnd, " now contains ", 144, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Taylor series expand \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]196\[InvisibleSpace]" Bytes: "\[InvisibleSpace]{{y, 0, 
            2}}\),
      SequenceForm[ 
      "Taylor series expand ", SymbolicRayTilt, " with ", 196, " Bytes: ", {{
        y, 0, 2}}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]196\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]43\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayTilt, " with ", 196, " Bytes: $SimplifyID = ",
         43, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayTilt\
\[InvisibleSpace]" now contains "\[InvisibleSpace]196\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayTilt, " now contains ", 196, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("A final formatting of \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]140\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]45\[InvisibleSpace]"."\),
      SequenceForm[ 
      "A final formatting of ", SymbolicSurfaceCoordinates, " with ", 140, 
        " Bytes: $SimplifyID = ", 45, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Formated \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" finally \
contains "\[InvisibleSpace]144\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Formated ", SymbolicSurfaceCoordinates, " finally contains ", 144, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("A final formatting of \
"\[InvisibleSpace]SymbolicOpticalLength\[InvisibleSpace]" with "\
\[InvisibleSpace]668\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]46\[InvisibleSpace]"."\),
      SequenceForm[ 
      "A final formatting of ", SymbolicOpticalLength, " with ", 668, 
        " Bytes: $SimplifyID = ", 46, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Formated "\[InvisibleSpace]SymbolicOpticalLength\
\[InvisibleSpace]" finally contains "\[InvisibleSpace]244\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Formated ", SymbolicOpticalLength, " finally contains ", 244, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("A final formatting of \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]144\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]47\[InvisibleSpace]"."\),
      SequenceForm[ 
      "A final formatting of ", SymbolicRayEnd, " with ", 144, 
        " Bytes: $SimplifyID = ", 47, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Formated "\[InvisibleSpace]SymbolicRayEnd\
\[InvisibleSpace]" finally contains "\[InvisibleSpace]148\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Formated ", SymbolicRayEnd, " finally contains ", 148, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("A final formatting of \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]196\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]48\[InvisibleSpace]"."\),
      SequenceForm[ 
      "A final formatting of ", SymbolicRayTilt, " with ", 196, 
        " Bytes: $SimplifyID = ", 48, "."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Formated "\[InvisibleSpace]SymbolicRayTilt\
\[InvisibleSpace]" finally contains "\[InvisibleSpace]196\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Formated ", SymbolicRayTilt, " finally contains ", 196, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(0.1599999999999966`\[InvisibleSpace]" total Seconds \
consumed for wavefront segment."\),
      SequenceForm[ 
      0.15999999999999659, " total Seconds consumed for wavefront segment."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(1944\[InvisibleSpace]" total Bytes consumed for \
wavefront segment."\),
      SequenceForm[ 1944, " total Bytes consumed for wavefront segment."],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    \("Ending SymbolicTrace"\)], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    \({SymbolicOpticalLength \[Rule] \(\(55.20550238395628`\)\(\
\[InvisibleSpace]\)\) + 1.0002694514570802`\ d - 
          0.005168033072976129`\ y\^2 + 0.00004993468826511558`\ d\ y\^2, 
      SymbolicRayEnd \[Rule] {d, 
          1.0341430267856087`\ y - 0.009992120587251692`\ d\ y, 0}, 
      SymbolicRayTilt \[Rule] {\(\(1.`\)\(\[InvisibleSpace]\)\) - 
            0.00004992123691508956`\ y\^2, \(-0.009992120587251692`\)\ y, 0}, 
      SymbolicSurfaceCoordinates \[Rule] {1.0341430267856087`\ y - 
            0.009992120587251692`\ d\ y, 0}, 
      SymbolicIntensity \[Rule] 
        100\ \[ExponentialE]\^\(\(-0.0029964326570722766`\)\ y\^2 - 1\/625\ \
\((\(\(1.0341430267856087`\)\(\[InvisibleSpace]\)\) - 0.009992120587251692`\ \
d)\)\^2\ y\^2\), SymbolicSurfaceBoundary \[Rule] {50, 50}, 
      SymbolicOffAxis \[Rule] {0, 0}, 
      SymbolicTranslationVector \[Rule] {d, 0, 0}, 
      SymbolicRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
      SymbolicWaveLength \[Rule] 133\/250, 
      SymbolicSurfaceNormalFunction \[Rule] {1, 0, 0}}\)], "Output",
  CellLabel->"Out[32]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ByteCount[%]", "Input",
  CellLabel->"In[33]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[BoxData[
    \(1924\)], "Output",
  CellLabel->"Out[33]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  StyleBox["SymbolicTrace", "Input"],
  " can take, within its second argument, a list of assumptions that get \
passed internally to the ",
  StyleBox["Simplify", "Input"],
  " operations. These assumptions are used to further simplify the resulting \
expression. Here is the ",
  StyleBox["SymbolicTrace", "Input"],
  " operation without any assumptions given."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[CellGroupData[{

Cell["\<\
opticalsystem = {
Move[LineOfRays[20], {-50,{y,0}}],
PlanoConvexLens[{f,100},50,10,DesignWaveLength->.532],
Move[Screen[50],{d,100}]};
SymbolicTrace[opticalsystem]\
\>", "Input",
  CellLabel->"In[34]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[BoxData[
    \({SymbolicOpticalLength \[Rule] \(\(55.20550238395627`\)\(\
\[InvisibleSpace]\)\) + 1.0002694514570802`\ d - 0.26971163559352673`\ f - 
          0.5196124051711749`\ \@f\^2 + 0.7893240407647016`\ \@f\^2\ Sign[f], 
      SymbolicRayEnd \[Rule] {d, 
          y + \(3.41430267856086`\ \@f\^2\ y\ Sign[f]\)\/f\^2 - \
\(0.9992120587251689`\ d\ \@f\^2\ y\ Sign[f]\)\/f\^2 + \(0.34169950700124185`\
\ \@f\^2\ y\ Sign[f]\)\/f - 0.34169950700124185`\ y\ Sign[f]\^2, 0}, 
      SymbolicRayTilt \[Rule] {1, \(-\(\(0.9992120587251689`\ \@f\^2\ y\ Sign[
                    f]\)\/f\^2\)\), 0}, 
      SymbolicSurfaceCoordinates \[Rule] {y + \(3.41430267856086`\ \@f\^2\ y\ \
Sign[f]\)\/f\^2 - \(0.9992120587251689`\ d\ \@f\^2\ y\ Sign[f]\)\/f\^2 + \
\(0.34169950700124185`\ \@f\^2\ y\ Sign[f]\)\/f - 
            0.34169950700124185`\ y\ Sign[f]\^2, 0}, 
      SymbolicIntensity \[Rule] 
        100\ \[ExponentialE]\^\(\(-\(y\^2\/625\)\) - \(y\^2\ \((f\^2 + \
\((\(-6.577817908690829`\) + 0.34169950700124185`\ f)\)\ \@f\^2\ Sign[f] - \
0.34169950700124185`\ f\^2\ Sign[f]\^2)\)\^2\)\/\(625\ f\^4\) - \(y\^2\ \
\((f\^2 + \((\(\(3.41430267856086`\)\(\[InvisibleSpace]\)\) - \
0.9992120587251689`\ d + 0.34169950700124185`\ f)\)\ \@f\^2\ Sign[f] - \
0.34169950700124185`\ f\^2\ Sign[f]\^2)\)\^2\)\/\(625\ f\^4\)\), 
      SymbolicSurfaceBoundary \[Rule] {50, 50}, 
      SymbolicOffAxis \[Rule] {0, 0}, 
      SymbolicTranslationVector \[Rule] {d, 0, 0}, 
      SymbolicRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
      SymbolicWaveLength \[Rule] 133\/250, 
      SymbolicSurfaceNormalFunction \[Rule] {1, 0, 0}}\)], "Output",
  CellLabel->"Out[35]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "Here is the same operation with some assumptions included about the user \
variables. The ",
  StyleBox["RunningCommentary->Simplify", "Input"],
  " setting is used here to moniter the internal simplification steps."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[CellGroupData[{

Cell[TextData[{
  "SymbolicTrace[opticalsystem, {f>0, d\[Element]Reals}, ",
  StyleBox["RunningCommentary->Simplify", "Input"],
  "]"
}], "Input",
  CellLabel->"In[36]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[BoxData[
    \("Starting SymbolicTrace"\)], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceFunction\[InvisibleSpace]" with "\
\[InvisibleSpace]316\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]1\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceFunction, " with ", 316, 
        " Bytes: $SimplifyID = ", 1, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicSurfaceFunction\
\[InvisibleSpace]" now contains "\[InvisibleSpace]52\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceFunction, " now contains ", 52, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceIntersectionFunction\[InvisibleSpace]" with \
"\[InvisibleSpace]1508\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]2\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceIntersectionFunction, " with ", 1508, 
        " Bytes: $SimplifyID = ", 2, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceIntersectionFunction\[InvisibleSpace]" now \
contains "\[InvisibleSpace]1508\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceIntersectionFunction, " now contains ", 
        1508, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]1388\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]3\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceCoordinates, " with ", 1388, 
        " Bytes: $SimplifyID = ", 3, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" now contains "\
\[InvisibleSpace]356\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceCoordinates, " now contains ", 356, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" with "\
\[InvisibleSpace]236\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]4\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceNormalFunction, " with ", 236, 
        " Bytes: $SimplifyID = ", 4, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" now \
contains "\[InvisibleSpace]164\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceNormalFunction, " now contains ", 164, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" with "\
\[InvisibleSpace]484\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]5\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceNormalFunction, " with ", 484, 
        " Bytes: $SimplifyID = ", 5, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" now \
contains "\[InvisibleSpace]444\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceNormalFunction, " now contains ", 444, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]2788\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]6\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayTilt, " with ", 2788, 
        " Bytes: $SimplifyID = ", 6, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayTilt\
\[InvisibleSpace]" now contains "\[InvisibleSpace]1892\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayTilt, " now contains ", 1892, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]412\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]7\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayEnd, " with ", 412, " Bytes: $SimplifyID = ", 
        7, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayEnd\
\[InvisibleSpace]" now contains "\[InvisibleSpace]372\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayEnd, " now contains ", 372, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayLength\[InvisibleSpace]" with \
"\[InvisibleSpace]3072\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]8\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayLength, " with ", 3072, 
        " Bytes: $SimplifyID = ", 8, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayLength\
\[InvisibleSpace]" now contains "\[InvisibleSpace]808\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayLength, " now contains ", 808, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicAperture\[InvisibleSpace]" with \
"\[InvisibleSpace]264\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]9\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicAperture, " with ", 264, 
        " Bytes: $SimplifyID = ", 9, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicAperture\
\[InvisibleSpace]" now contains "\[InvisibleSpace]264\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicAperture, " now contains ", 264, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" "\[InvisibleSpace]"inverse \
input-coordinate transformation"\[InvisibleSpace]" with "\[InvisibleSpace]184\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]10\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", "inverse input-coordinate transformation", " with ", 184,
         " Bytes: $SimplifyID = ", 10, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]"inverse \
input-coordinate transformation"\[InvisibleSpace]" now contains "\
\[InvisibleSpace]184\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", "inverse input-coordinate transformation", 
        " now contains ", 184, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceFunction\[InvisibleSpace]" with "\
\[InvisibleSpace]52\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]11\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceFunction, " with ", 52, 
        " Bytes: $SimplifyID = ", 11, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicSurfaceFunction\
\[InvisibleSpace]" now contains "\[InvisibleSpace]52\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceFunction, " now contains ", 52, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceIntersectionFunction\[InvisibleSpace]" with \
"\[InvisibleSpace]220\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]12\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceIntersectionFunction, " with ", 220, 
        " Bytes: $SimplifyID = ", 12, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceIntersectionFunction\[InvisibleSpace]" now \
contains "\[InvisibleSpace]220\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceIntersectionFunction, " now contains ", 
        220, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]204\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]13\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceCoordinates, " with ", 204, 
        " Bytes: $SimplifyID = ", 13, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" now contains "\
\[InvisibleSpace]124\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceCoordinates, " now contains ", 124, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" with "\
\[InvisibleSpace]64\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]14\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceNormalFunction, " with ", 64, 
        " Bytes: $SimplifyID = ", 14, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" now \
contains "\[InvisibleSpace]64\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceNormalFunction, " now contains ", 64, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" with "\
\[InvisibleSpace]64\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]15\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceNormalFunction, " with ", 64, 
        " Bytes: $SimplifyID = ", 15, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" now \
contains "\[InvisibleSpace]64\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceNormalFunction, " now contains ", 64, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]276\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]16\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayTilt, " with ", 276, " Bytes: $SimplifyID = ",
         16, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayTilt\
\[InvisibleSpace]" now contains "\[InvisibleSpace]276\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayTilt, " now contains ", 276, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]220\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]17\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayEnd, " with ", 220, " Bytes: $SimplifyID = ", 
        17, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayEnd\
\[InvisibleSpace]" now contains "\[InvisibleSpace]140\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayEnd, " now contains ", 140, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayLength\[InvisibleSpace]" with \
"\[InvisibleSpace]120\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]18\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayLength, " with ", 120, 
        " Bytes: $SimplifyID = ", 18, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayLength\
\[InvisibleSpace]" now contains "\[InvisibleSpace]60\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayLength, " now contains ", 60, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicAperture\[InvisibleSpace]" with \
"\[InvisibleSpace]264\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]19\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicAperture, " with ", 264, 
        " Bytes: $SimplifyID = ", 19, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicAperture\
\[InvisibleSpace]" now contains "\[InvisibleSpace]264\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicAperture, " now contains ", 264, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" "\[InvisibleSpace]"inverse \
input-coordinate transformation"\[InvisibleSpace]" with "\[InvisibleSpace]220\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]20\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", "inverse input-coordinate transformation", " with ", 220,
         " Bytes: $SimplifyID = ", 20, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]"inverse \
input-coordinate transformation"\[InvisibleSpace]" now contains "\
\[InvisibleSpace]220\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", "inverse input-coordinate transformation", 
        " now contains ", 220, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceFunction\[InvisibleSpace]" with "\
\[InvisibleSpace]52\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]21\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceFunction, " with ", 52, 
        " Bytes: $SimplifyID = ", 21, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicSurfaceFunction\
\[InvisibleSpace]" now contains "\[InvisibleSpace]52\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceFunction, " now contains ", 52, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceIntersectionFunction\[InvisibleSpace]" with \
"\[InvisibleSpace]220\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]22\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceIntersectionFunction, " with ", 220, 
        " Bytes: $SimplifyID = ", 22, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceIntersectionFunction\[InvisibleSpace]" now \
contains "\[InvisibleSpace]220\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceIntersectionFunction, " now contains ", 
        220, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]204\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]23\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceCoordinates, " with ", 204, 
        " Bytes: $SimplifyID = ", 23, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" now contains "\
\[InvisibleSpace]124\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceCoordinates, " now contains ", 124, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" with "\
\[InvisibleSpace]64\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]24\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceNormalFunction, " with ", 64, 
        " Bytes: $SimplifyID = ", 24, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" now \
contains "\[InvisibleSpace]64\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceNormalFunction, " now contains ", 64, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" with "\
\[InvisibleSpace]64\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]25\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceNormalFunction, " with ", 64, 
        " Bytes: $SimplifyID = ", 25, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceNormalFunction\[InvisibleSpace]" now \
contains "\[InvisibleSpace]64\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceNormalFunction, " now contains ", 64, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with "\[InvisibleSpace]40\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]26\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayTilt, " with ", 40, " Bytes: $SimplifyID = ", 
        26, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayTilt\
\[InvisibleSpace]" now contains "\[InvisibleSpace]40\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayTilt, " now contains ", 40, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]220\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]27\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayEnd, " with ", 220, " Bytes: $SimplifyID = ", 
        27, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayEnd\
\[InvisibleSpace]" now contains "\[InvisibleSpace]140\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayEnd, " now contains ", 140, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayLength\[InvisibleSpace]" with \
"\[InvisibleSpace]120\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]28\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayLength, " with ", 120, 
        " Bytes: $SimplifyID = ", 28, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayLength\
\[InvisibleSpace]" now contains "\[InvisibleSpace]60\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayLength, " now contains ", 60, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicAperture\[InvisibleSpace]" with \
"\[InvisibleSpace]264\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]29\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicAperture, " with ", 264, 
        " Bytes: $SimplifyID = ", 29, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicAperture\
\[InvisibleSpace]" now contains "\[InvisibleSpace]264\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicAperture, " now contains ", 264, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" "\[InvisibleSpace]"inverse \
input-coordinate transformation"\[InvisibleSpace]" with "\[InvisibleSpace]244\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]30\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", "inverse input-coordinate transformation", " with ", 244,
         " Bytes: $SimplifyID = ", 30, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]"inverse \
input-coordinate transformation"\[InvisibleSpace]" now contains "\
\[InvisibleSpace]244\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", "inverse input-coordinate transformation", 
        " now contains ", 244, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayLength\[InvisibleSpace]" with \
"\[InvisibleSpace]12\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]31\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayLength, " with ", 12, 
        " Bytes: $SimplifyID = ", 31, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayLength\
\[InvisibleSpace]" now contains "\[InvisibleSpace]12\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayLength, " now contains ", 12, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]36\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]32\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceCoordinates, " with ", 36, 
        " Bytes: $SimplifyID = ", 32, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" now contains "\
\[InvisibleSpace]36\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceCoordinates, " now contains ", 36, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]52\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]33\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayEnd, " with ", 52, " Bytes: $SimplifyID = ", 
        33, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayEnd\
\[InvisibleSpace]" now contains "\[InvisibleSpace]52\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayEnd, " now contains ", 52, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]132\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]34\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayTilt, " with ", 132, " Bytes: $SimplifyID = ",
         34, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayTilt\
\[InvisibleSpace]" now contains "\[InvisibleSpace]132\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayTilt, " now contains ", 132, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayLength\[InvisibleSpace]" with \
"\[InvisibleSpace]12\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]36\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayLength, " with ", 12, 
        " Bytes: $SimplifyID = ", 36, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayLength\
\[InvisibleSpace]" now contains "\[InvisibleSpace]12\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayLength, " now contains ", 12, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]140\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]37\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceCoordinates, " with ", 140, 
        " Bytes: $SimplifyID = ", 37, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" now contains "\
\[InvisibleSpace]140\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceCoordinates, " now contains ", 140, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]156\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]38\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayEnd, " with ", 156, " Bytes: $SimplifyID = ", 
        38, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayEnd\
\[InvisibleSpace]" now contains "\[InvisibleSpace]156\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayEnd, " now contains ", 156, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]132\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]39\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayTilt, " with ", 132, " Bytes: $SimplifyID = ",
         39, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayTilt\
\[InvisibleSpace]" now contains "\[InvisibleSpace]132\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayTilt, " now contains ", 132, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayLength\[InvisibleSpace]" with \
"\[InvisibleSpace]36\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]41\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayLength, " with ", 36, 
        " Bytes: $SimplifyID = ", 41, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayLength\
\[InvisibleSpace]" now contains "\[InvisibleSpace]36\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayLength, " now contains ", 36, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]300\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]42\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicSurfaceCoordinates, " with ", 300, 
        " Bytes: $SimplifyID = ", 42, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" now contains "\
\[InvisibleSpace]184\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicSurfaceCoordinates, " now contains ", 184, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]304\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]43\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayEnd, " with ", 304, " Bytes: $SimplifyID = ", 
        43, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayEnd\
\[InvisibleSpace]" now contains "\[InvisibleSpace]188\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayEnd, " now contains ", 188, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\(Simplify\[InvisibleSpace]" \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]132\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]44\[InvisibleSpace]"."\),
      SequenceForm[ 
      Simplify, " ", SymbolicRayTilt, " with ", 132, " Bytes: $SimplifyID = ",
         44, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Simplified "\[InvisibleSpace]SymbolicRayTilt\
\[InvisibleSpace]" now contains "\[InvisibleSpace]132\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Simplified ", SymbolicRayTilt, " now contains ", 132, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("A final formatting of \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" with "\
\[InvisibleSpace]184\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]46\[InvisibleSpace]"."\),
      SequenceForm[ 
      "A final formatting of ", SymbolicSurfaceCoordinates, " with ", 184, 
        " Bytes: $SimplifyID = ", 46, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Formated \
"\[InvisibleSpace]SymbolicSurfaceCoordinates\[InvisibleSpace]" finally \
contains "\[InvisibleSpace]228\[InvisibleSpace]" Bytes."\),
      SequenceForm[ 
      "Formated ", SymbolicSurfaceCoordinates, " finally contains ", 228, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("A final formatting of \
"\[InvisibleSpace]SymbolicOpticalLength\[InvisibleSpace]" with "\
\[InvisibleSpace]116\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]47\[InvisibleSpace]"."\),
      SequenceForm[ 
      "A final formatting of ", SymbolicOpticalLength, " with ", 116, 
        " Bytes: $SimplifyID = ", 47, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Formated "\[InvisibleSpace]SymbolicOpticalLength\
\[InvisibleSpace]" finally contains "\[InvisibleSpace]80\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Formated ", SymbolicOpticalLength, " finally contains ", 80, 
        " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("A final formatting of \
"\[InvisibleSpace]SymbolicRayEnd\[InvisibleSpace]" with "\[InvisibleSpace]188\
\[InvisibleSpace]" Bytes: $SimplifyID = \
"\[InvisibleSpace]48\[InvisibleSpace]"."\),
      SequenceForm[ 
      "A final formatting of ", SymbolicRayEnd, " with ", 188, 
        " Bytes: $SimplifyID = ", 48, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Formated "\[InvisibleSpace]SymbolicRayEnd\
\[InvisibleSpace]" finally contains "\[InvisibleSpace]232\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Formated ", SymbolicRayEnd, " finally contains ", 232, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("A final formatting of \
"\[InvisibleSpace]SymbolicRayTilt\[InvisibleSpace]" with \
"\[InvisibleSpace]132\[InvisibleSpace]" Bytes: $SimplifyID = "\
\[InvisibleSpace]49\[InvisibleSpace]"."\),
      SequenceForm[ 
      "A final formatting of ", SymbolicRayTilt, " with ", 132, 
        " Bytes: $SimplifyID = ", 49, "."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    InterpretationBox[\("Formated "\[InvisibleSpace]SymbolicRayTilt\
\[InvisibleSpace]" finally contains "\[InvisibleSpace]132\[InvisibleSpace]" \
Bytes."\),
      SequenceForm[ 
      "Formated ", SymbolicRayTilt, " finally contains ", 132, " Bytes."],
      Editable->False]], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    \("Ending SymbolicTrace"\)], "Print",
  CellLabel->"From In[36]:=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],

Cell[BoxData[
    \({SymbolicOpticalLength \[Rule] \(\(55.20550238395627`\)\(\
\[InvisibleSpace]\)\) + 1.0002694514570802`\ d, 
      SymbolicRayEnd \[Rule] {d, 
          y + \(3.414302678560862`\ y\)\/f - \(0.9992120587251688`\ d\ \
y\)\/f, 0}, 
      SymbolicRayTilt \[Rule] {1, \(-\(\(0.9992120587251688`\ y\)\/f\)\), 0}, 
      SymbolicSurfaceCoordinates \[Rule] {y + \(3.414302678560862`\ y\)\/f - \
\(0.9992120587251688`\ d\ y\)\/f, 0}, 
      SymbolicIntensity \[Rule] 
        100\ \[ExponentialE]\^\(\(-\(y\^2\/625\)\) - \
\(\((\(\(3.414302678560862`\)\(\[InvisibleSpace]\)\) - 0.9992120587251688`\ d \
+ f)\)\^2\ y\^2\)\/\(625\ f\^2\) - 1\/625\ \((y - \(6.577817908690827`\ \
y\)\/f)\)\^2\), SymbolicSurfaceBoundary \[Rule] {50, 50}, 
      SymbolicOffAxis \[Rule] {0, 0}, 
      SymbolicTranslationVector \[Rule] {d, 0, 0}, 
      SymbolicRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
      SymbolicWaveLength \[Rule] 133\/250, 
      SymbolicSurfaceNormalFunction \[Rule] {1, 0, 0}}\)], "Output",
  CellLabel->"Out[36]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "In some cases, the second argument of ",
  StyleBox["SymbolicTrace", "Input"],
  " may include both assumptions as well as specifications for Taylor series \
expansion of symbolic system variables."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[CellGroupData[{

Cell["\<\
SymbolicTrace[opticalsystem, {{y,0,2},{f,100,1},{f>0, d\[Element]Reals}}]\
\>", "Input",
  CellLabel->"In[37]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[BoxData[
    \({SymbolicOpticalLength \[Rule] \(\(55.20550238395628`\)\(\
\[InvisibleSpace]\)\) + 1.0002694514570802`\ d - 
          0.010506692729576762`\ y\^2 + 0.00014980406479534652`\ d\ y\^2 + 
          0.00005338659656600637`\ f\ y\^2 - 
          9.986937653023097`*^-7\ d\ f\ y\^2, 
      SymbolicRayEnd \[Rule] {d, 
          1.068286053571217`\ y - 0.019984241174503377`\ d\ y - 
            0.00034143026785608604`\ f\ y + 0.00009992120587251688`\ d\ f\ y, 
          0}, SymbolicRayTilt \[Rule] {\(\(1.`\)\(\[InvisibleSpace]\)\) - 
            0.00014976371074526846`\ y\^2 + 
            9.984247383017894`*^-7\ f\ y\^2, \(-0.019984241174503377`\)\ y + 
            0.00009992120587251688`\ f\ y, 0}, 
      SymbolicSurfaceCoordinates \[Rule] {1.068286053571217`\ y - 
            0.019984241174503377`\ d\ y - 0.00034143026785608604`\ f\ y + 
            0.00009992120587251688`\ d\ f\ y, 0}, 
      SymbolicIntensity \[Rule] 
        100\ \[ExponentialE]\^\(\(-\(y\^2\/625\)\) - 1\/625\ \
\((\(\(1.068286053571217`\)\(\[InvisibleSpace]\)\) + d\ \
\((\(-0.019984241174503377`\) + 0.00009992120587251688`\ f)\) - \
0.00034143026785608604`\ f)\)\^2\ y\^2 - 1\/625\ \((\(\(0.8684436418261834`\)\
\(\[InvisibleSpace]\)\) + 0.0006577817908690828`\ f)\)\^2\ y\^2\), 
      SymbolicSurfaceBoundary \[Rule] {50, 50}, 
      SymbolicOffAxis \[Rule] {0, 0}, 
      SymbolicTranslationVector \[Rule] {d, 0, 0}, 
      SymbolicRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
      SymbolicWaveLength \[Rule] 133\/250, 
      SymbolicSurfaceNormalFunction \[Rule] {1, 0, 0}}\)], "Output",
  CellLabel->"Out[37]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multiple Light Paths", "Subsubsection",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7", "2.1.7"}],

Cell[TextData[{
  "In addition to using the ",
  StyleBox["SymbolicTrace", "Input"],
  " with linearly ordered systems, it is also possible to work with systems \
involving multiple light paths. Each light path produces a different solution \
in the output. Here is an example that uses two light sources. In general, \
every distinct light source produces a distinct light path. In this event, \
the two light sources produce two distinct symbolic solutions."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],

Cell[CellGroupData[{

Cell["\<\
twoSourceSystem = {
\tMove[LineOfRays[20],{-50,{y,0}}],
\tMove[LineOfRays[20],{-50,{y,0}},5],
\tPlanoConvexLens[100,50,10],
\tMove[Screen[50],{d,100}]};
AnalyzeSystem[twoSourceSystem,PlotType->TopView];
SymbolicTrace[twoSourceSystem]\
\>", "Input",
  CellLabel->"In[38]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35804 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.344938 0.00631253 0.191698 0.00631253 [
[.3765 .00852 -5.03125 -6 ]
[.3765 .00852 5.03125 6 ]
[.97619 .00852 -4.75 -6 ]
[.97619 .00852 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .35804 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.38548 .03388 m
.40806 .03388 L
.40806 .08649 L
.3623 .08649 L
.38548 .03388 L
F
.3623 .08649 m
.40806 .08649 L
.40806 .13909 L
.34919 .13909 L
.3623 .08649 L
F
.34919 .13909 m
.40806 .13909 L
.40806 .1917 L
.34494 .1917 L
.34919 .13909 L
F
.34494 .1917 m
.40806 .1917 L
.40806 .2443 L
.34919 .2443 L
.34494 .1917 L
F
.34919 .2443 m
.40806 .2443 L
.40806 .29691 L
.3623 .29691 L
.34919 .2443 L
F
.3623 .29691 m
.40806 .29691 L
.40806 .34951 L
.38548 .34951 L
.3623 .29691 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.38548 .03388 m
.3623 .08649 L
.34919 .13909 L
.34494 .1917 L
.34919 .2443 L
.3623 .29691 L
.38548 .34951 L
.40806 .34951 L
.40806 .29691 L
.40806 .2443 L
.40806 .1917 L
.40806 .13909 L
.40806 .08649 L
.40806 .03388 L
.38548 .03388 L
s
.5 g
.38548 .1917 m
.40806 .1917 L
.40806 .1917 L
.3623 .1917 L
.38548 .1917 L
F
.3623 .1917 m
.40806 .1917 L
.40806 .1917 L
.34919 .1917 L
.3623 .1917 L
F
.34919 .1917 m
.40806 .1917 L
.40806 .1917 L
.34494 .1917 L
.34919 .1917 L
F
.34494 .1917 m
.40806 .1917 L
.40806 .1917 L
.34919 .1917 L
.34494 .1917 L
F
.34919 .1917 m
.40806 .1917 L
.40806 .1917 L
.3623 .1917 L
.34919 .1917 L
F
.3623 .1917 m
.40806 .1917 L
.40806 .1917 L
.38548 .1917 L
.3623 .1917 L
F
0 g
.38548 .1917 m
.3623 .1917 L
.34919 .1917 L
.34494 .1917 L
.34919 .1917 L
.3623 .1917 L
.38548 .1917 L
.40806 .1917 L
.40806 .1917 L
.40806 .1917 L
.40806 .1917 L
.40806 .1917 L
.40806 .1917 L
.40806 .1917 L
.38548 .1917 L
s
.38548 .34951 m
.40806 .34951 L
.40806 .34413 L
.38548 .34413 L
.38548 .34951 L
s
.38548 .34413 m
.40806 .34413 L
.40806 .32837 L
.38548 .32837 L
.38548 .34413 L
s
.38548 .32837 m
.40806 .32837 L
.40806 .30329 L
.38548 .30329 L
.38548 .32837 L
s
.38548 .30329 m
.40806 .30329 L
.40806 .2706 L
.38548 .2706 L
.38548 .30329 L
s
.38548 .2706 m
.40806 .2706 L
.40806 .23254 L
.38548 .23254 L
.38548 .2706 L
s
.38548 .23254 m
.40806 .23254 L
.40806 .1917 L
.38548 .1917 L
.38548 .23254 L
s
.38548 .1917 m
.40806 .1917 L
.40806 .15085 L
.38548 .15085 L
.38548 .1917 L
s
.38548 .15085 m
.40806 .15085 L
.40806 .11279 L
.38548 .11279 L
.38548 .15085 L
s
.38548 .11279 m
.40806 .11279 L
.40806 .08011 L
.38548 .08011 L
.38548 .11279 L
s
.38548 .08011 m
.40806 .08011 L
.40806 .05503 L
.38548 .05503 L
.38548 .08011 L
s
.38548 .05503 m
.40806 .05503 L
.40806 .03926 L
.38548 .03926 L
.38548 .05503 L
s
.38548 .03926 m
.40806 .03926 L
.40806 .03388 L
.38548 .03388 L
.38548 .03926 L
s
.38548 .03388 m
.40806 .03388 L
.40806 .03926 L
.38548 .03926 L
.38548 .03388 L
s
.38548 .03926 m
.40806 .03926 L
.40806 .05503 L
.38548 .05503 L
.38548 .03926 L
s
.38548 .05503 m
.40806 .05503 L
.40806 .08011 L
.38548 .08011 L
.38548 .05503 L
s
.38548 .08011 m
.40806 .08011 L
.40806 .11279 L
.38548 .11279 L
.38548 .08011 L
s
.38548 .11279 m
.40806 .11279 L
.40806 .15085 L
.38548 .15085 L
.38548 .11279 L
s
.38548 .15085 m
.40806 .15085 L
.40806 .1917 L
.38548 .1917 L
.38548 .15085 L
s
.38548 .1917 m
.40806 .1917 L
.40806 .23254 L
.38548 .23254 L
.38548 .1917 L
s
.38548 .23254 m
.40806 .23254 L
.40806 .2706 L
.38548 .2706 L
.38548 .23254 L
s
.38548 .2706 m
.40806 .2706 L
.40806 .30329 L
.38548 .30329 L
.38548 .2706 L
s
.38548 .30329 m
.40806 .30329 L
.40806 .32837 L
.38548 .32837 L
.38548 .30329 L
s
.38548 .32837 m
.40806 .32837 L
.40806 .34413 L
.38548 .34413 L
.38548 .32837 L
s
.38548 .34413 m
.40806 .34413 L
.40806 .34951 L
.38548 .34951 L
.38548 .34413 L
s
.97619 .03388 m
.97619 .08649 L
.97619 .13909 L
.97619 .1917 L
.97619 .2443 L
.97619 .29691 L
.97619 .34951 L
.97619 .34951 L
.97619 .29691 L
.97619 .2443 L
.97619 .1917 L
.97619 .13909 L
.97619 .08649 L
.97619 .03388 L
.97619 .03388 L
s
.97619 .1917 m
.97619 .1917 L
.97619 .1917 L
.97619 .1917 L
.97619 .1917 L
.97619 .1917 L
.97619 .1917 L
.97619 .1917 L
.97619 .1917 L
.97619 .1917 L
.97619 .1917 L
.97619 .1917 L
.97619 .1917 L
.97619 .1917 L
.97619 .1917 L
s
.97619 .34951 m
.97619 .34413 L
.97619 .32837 L
.97619 .30329 L
.97619 .2706 L
.97619 .23254 L
.97619 .1917 L
.97619 .15085 L
.97619 .11279 L
.97619 .08011 L
.97619 .05503 L
.97619 .03926 L
.97619 .03388 L
.97619 .03926 L
.97619 .05503 L
.97619 .08011 L
.97619 .11279 L
.97619 .15085 L
.97619 .1917 L
.97619 .23254 L
.97619 .2706 L
.97619 .30329 L
.97619 .32837 L
.97619 .34413 L
.97619 .34951 L
s
.039 .916 .04 r
.02931 .12857 m
.35108 .12857 L
s
% Start of user PostScript
-50. -10. 0.973037 -10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.35108 .12857 Mdot
.039 .916 .04 r
.5 Mabswid
.02931 .1917 m
.34494 .1917 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34494 .1917 Mdot
.039 .916 .04 r
.5 Mabswid
.02931 .25482 m
.35108 .25482 L
s
% Start of user PostScript
-50. 10. 0.973037 10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.35108 .25482 Mdot
.039 .916 .04 r
.5 Mabswid
.03481 .12881 m
.34688 .15611 L
s
% Start of user PostScript
-49.1284 -9.96195 0.307188 -5.63689 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34688 .15611 Mdot
.039 .916 .04 r
.5 Mabswid
.02931 .1917 m
.34611 .21941 L
s
% Start of user PostScript
-50. 0 0.186161 4.39072 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34611 .21941 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25458 m
.35817 .28384 L
s
% Start of user PostScript
-50.8716 9.96195 2.09589 14.596 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.35817 .28384 Mdot
.039 .916 .04 r
.5 Mabswid
.35108 .12857 m
.40806 .13238 L
s
% Start of user PostScript
0.973037 -10. 10. -9.3966 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40806 .13238 Mdot
.039 .916 .04 r
.5 Mabswid
.34494 .1917 m
.40806 .1917 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40806 .1917 Mdot
.039 .916 .04 r
.5 Mabswid
.35108 .25482 m
.40806 .25101 L
s
% Start of user PostScript
0.973037 10. 10. 9.3966 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40806 .25101 Mdot
.039 .916 .04 r
.5 Mabswid
.34688 .15611 m
.40806 .16192 L
s
% Start of user PostScript
0.307188 -5.63689 10. -4.71668 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40806 .16192 Mdot
.039 .916 .04 r
.5 Mabswid
.34611 .21941 m
.40806 .22116 L
s
% Start of user PostScript
0.186161 4.39072 10. 4.66727 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40806 .22116 Mdot
.039 .916 .04 r
.5 Mabswid
.35817 .28384 m
.40806 .28167 L
s
% Start of user PostScript
2.09589 14.596 10. 14.2536 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40806 .28167 Mdot
.039 .916 .04 r
.5 Mabswid
.40806 .13238 m
.97619 .19024 L
s
% Start of user PostScript
10. -9.3966 100. -0.231131 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19024 Mdot
.039 .916 .04 r
.5 Mabswid
.40806 .1917 m
.97619 .1917 L
s
% Start of user PostScript
10. 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1917 Mdot
.039 .916 .04 r
.5 Mabswid
.40806 .25101 m
.97619 .19316 L
s
% Start of user PostScript
10. 9.3966 100. 0.231131 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19316 Mdot
.039 .916 .04 r
.5 Mabswid
.40806 .16192 m
.97619 .24434 L
s
% Start of user PostScript
10. -4.71668 100. 8.33994 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .24434 Mdot
.039 .916 .04 r
.5 Mabswid
.40806 .22116 m
.97619 .24549 L
s
% Start of user PostScript
10. 4.66727 100. 8.52183 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .24549 Mdot
.039 .916 .04 r
.5 Mabswid
.40806 .28167 m
.97619 .24424 L
s
% Start of user PostScript
10. 14.2536 100. 8.32333 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .24424 Mdot
gsave
.3765 .00852 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00852 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35804 L
0 .35804 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{288, 103.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ib000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00J_ooool6o`000:3ooooo0ol0
000=ooooo`00Joooool01Ol0003ooooooooooooooooo00000:3ooooo00Co0000oooooooooooo0000
3?ooool006_ooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`0:ooooo`00Joooool0
0ol0003oooooooooo`2Sooooo`;o00003Oooool006_ooooo00?o0000ooooooooool0X_ooool00ol0
003oooooooooo`0=ooooo`00Joooool00ol0003oooooooooo`2Rooooo`04o`000?ooooooooooo`00
00cooooo001Zooooo`?o0000Y?ooool3o`0000cooooo003oooooob7ooooo003oooooob7ooooo001`
ooooo`Oo0000Voooool00ol0003oooooooooo`0;ooooo`00L?ooool00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo09Wooooo00?o0000ooooooooool02oooool006oooooo2?l0002Kooooo`03
o`000?oooooooooo00_ooooo001_ooooo`;o00001OmoOgl00ol0003oooooooooo`2Iooooo`03o`00
0?oooooooooo00_ooooo001^ooooo`03o`000?moOgoo000000GoOgmo00?o0000ooooooooool0VOoo
ool00ol0003oooooooooo`0;ooooo`00K_ooool00ol0003oOgmoo`000005ogmoO`03o`000?oooooo
oooo09Wooooo00?o0000ooooooooool02oooool006gooooo00?o0000ogmoOomoOgl01ol0002Koooo
o`03o`000?oooooooooo00_ooooo001]ooooo`04o`000?moOgooOgmoo`0000GoOgmo00?o0000oooo
ooooool0VOooool00ol0003oooooooooo`0;ooooo`00K?ooool01Ol0003oOgmoogmoOomoOgoo0000
00GoOgmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0;ooooo`00K?ooool01Ol0003o
OgmoogmoOomoOgoo000000GoOgmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0;oooo
o`00K?ooool01Ol0003oOgmoogmoOomoOgoo000000GoOgmo00?o0000ooooooooool0VOooool00ol0
003oooooooooo`0;ooooo`00Joooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0;ooooo`00Joooool00ol0003oOgmo
ogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0VOooool00ol0003ooooo
ooooo`0;ooooo`00J_ooool00ol0003oOgmoogmoO`03ogmoO`Oo0000Voooool00ol0003ooooooooo
o`0;ooooo`00J_ooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000
ooooooooool0VOooool00ol0003oooooooooo`0;ooooo`00JOooool00ol0003oOgmoogmoO`04ogmo
O`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0;oooo
o`00JOooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0;ooooo`00JOooool00ol0003oOgmoogmoO`04ogmoO`03o`00
0?moOgooOgmo00?oOgmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0;ooooo`00J?oo
ool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0VOoo
ool00ol0003oooooooooo`0;ooooo`00J?ooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0;ooooo`00J?ooool00ol0
003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0VOooool00ol0
003oooooooooo`0;ooooo`00J?ooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0;ooooo`00J?ooool00ol0003oOgmo
ogmoO`05ogmoO`Oo0000Voooool00ol0003oooooooooo`0;ooooo`00Ioooool00ol0003oOgmoogmo
O`06ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0VOooool00ol0003ooooooooo
o`0;ooooo`00G_ooool3o`WZ2PKooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo09Wooooo00?o0000ooooooooool02oooool005oooooo1_l9jPX2oooo
o`03o`000?moOgooOgmo00CoOgmo0ol9jPX5ogmoO`03o`000?oooooooooo09Wooooo00?o0000oooo
ooooool02oooool000koooooIol9jPX00omoOgoo0000ooooo`2Jooooo`03o`000?oooooooooo00_o
oooo000Eooooo`_o2NX:?oooool5o`WZ2P;ooooo0_l00007ogmoO`Ko2NX:00?o0000o`WZ2_l9jPX0
1?l9jPZFooooo`03o`000?oooooooooo00_ooooo000Pooooo`_o2NX:<oooool2o`WZ2PKooooo00?o
0000ogmoOomoOgl01_moOgl5o`WZ2P03ogmoOol0003o000000Gooooo2_l9jPZ<ooooo`03o`000?oo
oooooooo00_ooooo000[ooooo`_o2NX:<?ooool00ol0003oOgmoogmoO`05ogmoO`;o2NX:00?o0000
ogmoOomoOgl00omoOgl00ol0003oooooooooo`0=ooooo`Wo2NX:Poooool00ol0003oooooooooo`0;
ooooo`00=_ooool:o`WZ2RKooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo01Kooooo2_l9jPYiooooo`03o`000?oooooooooo00_ooooo0010ooooo`_o
2NX:4_ooool2o`WZ2POooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo023ooooo2_l9jPY_ooooo`03o`000?oooooooooo00_ooooo001;ooooo`_o2NX:
1oooool5o`WZ2PCooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`00
0?oooooooooo02[ooooo2_l9jPYUooooo`03o`000?oooooooooo00_ooooo001Fooooo`ko2NX:0ol0
0007ogmoO`;o2NX:1ol0000fooooo`Wo2NX:G?ooool00ol0003oooooooooo`0;ooooo`00G_ooool6
o`WZ2P03o`000?l9jP[o2NX:00?o2NX:1OmoOgl4o`WZ2P?oOgmo00?o0000ooooooooool0?Oooool:
o`WZ2U;ooooo00?o0000ooooooooool02oooool005gooooo1?l9jPX4ooooo`03o`000?moOgooOgmo
00;oOgmo2ol9jPX2o`0004Wooooo2_l9jPY8ooooo`03o`000?oooooooooo00_ooooo001Uooooo`03
o`000?moOgooOgmo00OoOgmo1_l9jPX00ol0003o2NX:o`WZ2P03o`WZ2Toooooo2_l9jPXnooooo`03
o`000?oooooooooo00_ooooo001Uooooo`03o`000?moOgooOgmo00KoOgmo1?l9jPX4ogmoO`03o`00
0?oooooooooo00;ooooo1ol9jPYBooooo`Wo2NX:=Oooool00ol0003oooooooooo`0;ooooo`00IOoo
ool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool02Ooo
ool7o`WZ2UCooooo2_l9jPX[ooooo`03o`000?oooooooooo00_ooooo001Uooooo`03o`000?moOgoo
Ogmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0@ooooo`Oo2NX:Eoooool:
o`WZ2R7ooooo00?o0000ooooooooool02oooool006Gooooo00?o0000ogmoOomoOgl02?moOgl00ol0
003oOgmoogmoO`03ogmoO`03o`000?oooooooooo01Oooooo1ol9jPYJooooo`[o2NX:5oooool00ol0
003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool07_ooool7o`WZ2Ugooooo2Ol9jPX6ooooo`?o2NX:1Oooool00ol0003o
ooooooooo`0;ooooo`00G?ooool3o`WZ2PGooooo00?o0000ogmoOomoOgl01omoOgl3o`WZ2PGoOgmo
00?o0000ooooooooool09Oooool7o`WZ2Uoooooo3Ol9jPX00ooooooo0000ooooo`0<ooooo`00GOoo
ool6o`WZ2P03ooooool0003o000000WoOgmo1_l9jPX2o`0002kooooo1ol9jPYNooooo`Oo2NX:0_l0
000=ooooo`003_oooomWo`WZ2P03o`000?l9jP[o2NX:09Wo2NX:0_l0000=ooooo`005Oooool=o`WZ
2S_ooooo1Ol9jPX2ooooo`03o`000?moOgooOgmo00SoOgmo1Ol9jPX2ogmoO`03o`000?oooooooooo
03[ooooo1ol9jPY9ooooo`ko2NX:0_l0000=ooooo`008_ooool<o`WZ2Rkooooo0_l9jPX6ooooo`03
o`000?moOgooOgmo00OoOgmo0_l9jPX00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo047o
oooo1ol9jPXiooooo`Wo2NX:1oooool4o`WZ2PCooooo00?o0000ooooooooool02oooool002kooooo
3Ol9jPXYooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`18ooooo`So2NX:9oooool:o`WZ2Q3ooooo00?o2NX:ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`00>oooool<o`WZ2Qkooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmo
O`03ogmoO`03o`000?oooooooooo053ooooo1ol9jPXFooooo`[o2NX:8_ooool00ol0003ooooooooo
o`0;ooooo`00Aoooool<o`WZ2P[ooooo0ol9jPX5ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000
ogmoOomoOgl00omoOgl00ol0003oooooooooo`1Gooooo`Oo2NX:1Oooool:o`WZ2Rcooooo00?o0000
ooooooooool02oooool005?ooooo4Ol9jPX00ooooooo0000ogmoO`07ogmoO`?o2NX:1OmoOgl00ol0
003oooooooooo`1Jooooo`_o2NX:=?ooool00ol0003oooooooooo`0;ooooo`00Goooool5o`WZ2P03
o`000?l9jP[o2NX:00ko2NX:0_l0001Booooo`[o2NX:2oooool7o`WZ2Rgooooo00?o0000oooooooo
ool02oooool005kooooo1Ol9jPX00ooooooo0000o`000009ogmoO`Ko2NX:00?o0000o`WZ2_l9jPX0
2_l9jPXmooooo`[o2NX:7?ooool7o`WZ2RKooooo00?o0000ooooooooool02oooool005gooooo0_l9
jPX6ooooo`03o`000?moOgooOgmo00OoOgmo1Ol9jPX2ogmoO`03o`000?oooooooooo00Wooooo5_l9
jPXMooooo`[o2NX:;Oooool7o`WZ2Qoooooo00?o0000ooooooooool02oooool006Gooooo00?o0000
ogmoOomoOgl01_moOgl2o`WZ2P03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool07ooooolM
o`WZ2Skooooo1ol9jPXHooooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?moOgooOgmo
00OoOgmo1ol0000[ooooo`[o2NX:0ooooolFo`WZ2SGooooo1ol9jPX9ooooo`;o2NX:1_ooool00ol0
003oooooooooo`0;ooooo`00I_ooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool07oooool:o`WZ2R?ooooo5_l9jPXVooooo`Oo2NX:0_ooool5o`WZ2P?o
oooo00?o0000ooooooooool02oooool006Kooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo01Gooooo2_l9jPY3oooooaOo2NX:5_ooool:o`WZ2P03o`00
0?oooooooooo00_ooooo001Vooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omo
Ogl00ol0003oooooooooo`0<ooooo`Wo2NX:I?oooolFo`WZ2P?ooooo1_l9jPX2o`0000gooooo001N
ooooo`?o2NX:1Oooool00ol0003oOgmoogmoO`05ogmoO`Go2NX:0omoOgl00ol0003oooooooooo`02
ooooo`[o2NX:N?oooolDo`WZ2P;o00003Oooool005oooooo1_l9jPX00ooooooo0000ogmoO`06ogmo
O`Oo2NX:00?o0000o`WZ2_l9jPX00ol9jPYdooooo`ko2NX:3Oooool4o`WZ2PCooooo00?o0000oooo
ooooool02oooool000coooooH_l9jPX2ogmoO`Go2NX:0_l0001Yooooo`oo2NX:6oooool00ol9jP[o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo000Cooooo`_o2NX:@Oooool5o`WZ2P;ooooo
0_l00007ogmoO`?o2NX:1?moOgl00ol0003oooooooooo`1Iooooo`ko2NX:<_ooool00ol0003ooooo
ooooo`0;ooooo`007_ooool<o`WZ2SCooooo0_l9jPX7ooooo`03o`000?moOgooOgmo00CoOgmo00?o
2NX:ogmoOol000001OmoOgl00ol0003oooooooooo`1;ooooo`ko2NX:@?ooool00ol0003ooooooooo
o`0;ooooo`00:_ooool;o`WZ2S;ooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo03gooooo3_l9jPY>ooooo`03o`000?oooooooooo00_ooooo000eoooo
o`co2NX:9_ooool00ol0003oOgmoogmoO`06ogmoO`Oo0000<Oooool>o`WZ2Ucooooo00?o0000oooo
ooooool02oooool0047ooooo2ol9jPXDooooo`;o2NX:1_ooool00ol0003oOgmoogmoO`05ogmoO`03
o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool08?ooool?o`WZ2V[ooooo00?o0000oooooooo
ool02oooool004cooooo3?l9jPX8ooooo`Go2NX:0oooool00ol0003oOgmoogmoO`03ogmoO`?o2NX:
1OmoOgl00ol0003oooooooooo`0Booooo`ko2NX:NOooool00ol0003oooooooooo`0;ooooo`00F?oo
ool@o`WZ2P03o`000?moOgooOgmo00CoOgmo1_l9jPX2o`0000Kooooo3_l9jPZ7ooooo`03o`000?oo
oooooooo00_ooooo001QoooooaCo2NX:00?o0000o`WZ2_l9jPX01Ol9jPZEooooo`03o`000?oooooo
oooo00_ooooo001Pooooo`Co2NX:1?ooool2o`0000GoOgmo1Ol9jPX2ogmoO`03o`000?oooooooooo
09Wooooo00?o0000ooooooooool02oooool006Wooooo00?o0000ogmoOomoOgl00_moOgl2o`WZ2P03
o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0;ooooo`00
JOooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0
VOooool00ol0003oooooooooo`0;ooooo`00JOooool00ol0003oOgmoogmoO`04ogmoO`03o`000?mo
OgooOgmo00?oOgmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0;ooooo`00JOooool0
0ol0003oOgmoogmoO`04ogmoO`Oo0000Voooool00ol0003oooooooooo`0;ooooo`00J_ooool00ol0
003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0VOooool00ol0
003oooooooooo`0;ooooo`00J_ooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0;ooooo`00Joooool00ol0003oOgmo
ogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0VOooool00ol0003ooooo
ooooo`0;ooooo`00Joooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o
0000ooooooooool0VOooool00ol0003oooooooooo`0;ooooo`00K?ooool01Ol0003oOgmoogmoOomo
Ogoo000000GoOgmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0;ooooo`00K?ooool0
1Ol0003oOgmoogmoOomoOgoo000000GoOgmo00?o0000ooooooooool0VOooool00ol0003ooooooooo
o`0;ooooo`00KOooool00ol0003oOgmoogmoO`07o`0009_ooooo00?o0000ooooooooool02oooool0
06gooooo00Co0000ogmoOomoOgoo00001OmoOgl00ol0003oooooooooo`2Iooooo`03o`000?oooooo
oooo00_ooooo001^ooooo`03o`000?moOgoo000000GoOgmo00?o0000ooooooooool0VOooool00ol0
003oooooooooo`0;ooooo`00K_ooool00ol0003oOgmoo`000005ogmoO`03o`000?oooooooooo09Wo
oooo00?o0000ooooooooool02oooool006oooooo0_l00005ogmoO`03o`000?oooooooooo09Wooooo
00?o0000ooooooooool02oooool006oooooo2?l0002Kooooo`03o`000?oooooooooo00_ooooo001`
ooooo`Oo0000Voooool00ol0003oooooooooo`0;ooooo`00oooooolQooooo`00oooooolQooooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {102.062, 0}} -> {-58.1483, -32.4768, \
0.576393, 0.576393}},
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],

Cell[BoxData[
    \({{SymbolicOpticalLength \[Rule] \(\(55.20550238395627`\)\(\
\[InvisibleSpace]\)\) + 1.0002694514570802`\ d, 
        SymbolicRayEnd \[Rule] {d, 
            1.0341925312750881`\ y - 0.010006608313591682`\ d\ y, 0}, 
        SymbolicRayTilt \[Rule] {1, \(-0.010006608313591682`\)\ y, 0}, 
        SymbolicSurfaceCoordinates \[Rule] {1.0341925312750881`\ y - 
              0.010006608313591682`\ d\ y, 0}, 
        SymbolicIntensity \[Rule] 
          100\ \[ExponentialE]\^\(\(-0.002996147553780966`\)\ y\^2 - 1\/625\ \
\((\(\(1.0341925312750881`\)\(\[InvisibleSpace]\)\) - 0.010006608313591682`\ \
d)\)\^2\ y\^2\), SymbolicSurfaceBoundary \[Rule] {50, 50}, 
        SymbolicOffAxis \[Rule] {0, 0}, 
        SymbolicTranslationVector \[Rule] {d, 0, 0}, 
        SymbolicRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        SymbolicWaveLength \[Rule] 133\/250, 
        SymbolicSurfaceNormalFunction \[Rule] {1, 0, 
            0}}, {SymbolicOpticalLength \[Rule] \(\(55.2973515224337`\)\(\
\[InvisibleSpace]\)\) + 1.0011864162510171`\ d - 0.04259537293417272`\ y - 
            0.00044113179776276274`\ d\ y + 0.000024815299078989668`\ y\^2, 
        SymbolicRayEnd \[Rule] {d, \(\(4.2389832450685825`\)\(\
\[InvisibleSpace]\)\) + 0.04282844775942982`\ d + 1.0416605374009464`\ y - 
              0.010306636679539015`\ d\ y + 0.0005471286471773104`\ y\^2 + 
              4.532882858962548`*^-6\ d\ y\^2 - 
              1.1050298419971593`*^-7\ y\^3, 0}, 
        SymbolicRayTilt \[Rule] {\(\(0.9990841218188213`\)\(\[InvisibleSpace]\
\)\) + 0.0004402055078059199`\ y, \(\(0.042789222118593206`\)\(\
\[InvisibleSpace]\)\) - 0.01027834373728841`\ y, 0}, 
        SymbolicSurfaceCoordinates \[Rule] {\(\(4.2389832450685825`\)\(\
\[InvisibleSpace]\)\) + 0.04282844775942982`\ d + 1.0416605374009464`\ y - 
              0.010306636679539015`\ d\ y + 0.0005471286471773104`\ y\^2 + 
              4.532882858962548`*^-6\ d\ y\^2 - 
              1.1050298419971593`*^-7\ y\^3, 0}, 
        SymbolicIntensity \[Rule] 
          100\ \[ExponentialE]\^\(\(-\(1\/625\)\)\ \
\((\(\(4.390720136531939`\)\(\[InvisibleSpace]\)\) + 1.007487821666863`\ y)\)\
\^2 - 1\/625\ \((4.532882858962548`*^-6\ d\ \((\(-2269.5856914614155`\) + \
y)\)\ \((\(-4.163046421901598`\) + y)\) - 1.1050298419971593`*^-7\ \
\((\(-6420.403189954843`\) + y)\)\ \((\(\(4.078190767804189`\)\(\
\[InvisibleSpace]\)\) + y)\)\ \
\((\(\(1465.068242279319`\)\(\[InvisibleSpace]\)\) + y)\))\)\^2\), 
        SymbolicSurfaceBoundary \[Rule] {50, 50}, 
        SymbolicOffAxis \[Rule] {0, 0}, 
        SymbolicTranslationVector \[Rule] {d, 0, 0}, 
        SymbolicRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        SymbolicWaveLength \[Rule] 133\/250, 
        SymbolicSurfaceNormalFunction \[Rule] {1, 0, 0}}}\)], "Output",
  CellLabel->"Out[40]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}]
}, Open  ]],

Cell["\<\
In some cases, the optical arrangement may produce multiple light paths from \
a single light source. Here is an example that uses a beam splitter to create \
two light paths.\
\>", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],

Cell[CellGroupData[{

Cell["\<\
beamSplitterSystem = {
\tMove[LineOfRays[20],{-50,{y,0}}],
\tPlanoConvexLens[100,50,10],
\tMove[BeamSplitter[{50,50},50],50,-45],
\tMove[Screen[50],{d1,100}],
\tMove[Screen[50],{50,{d2,50}},90]
\t};
AnalyzeSystem[beamSplitterSystem,PlotType->TopView];
SymbolicTrace[beamSplitterSystem]\
\>", "Input",
  CellLabel->"In[41]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.199921 0.00634921 [
[.37302 .01262 -5.03125 -6 ]
[.37302 .01262 5.03125 6 ]
[.52629 .06748 -8.0625 -6 ]
[.52629 .06748 8.0625 6 ]
[.97619 .01262 -7.25 -6 ]
[.97619 .01262 7.25 6 ]
[.84603 .51738 -7.25 -6 ]
[.84603 .51738 7.25 6 ]
[ 0 0 0 0 ]
[ 1 .53 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.38204 .04119 m
.40476 .04119 L
.40476 .0941 L
.35873 .0941 L
.38204 .04119 L
F
.35873 .0941 m
.40476 .0941 L
.40476 .14701 L
.34555 .14701 L
.35873 .0941 L
F
.34555 .14701 m
.40476 .14701 L
.40476 .19992 L
.34127 .19992 L
.34555 .14701 L
F
.34127 .19992 m
.40476 .19992 L
.40476 .25283 L
.34555 .25283 L
.34127 .19992 L
F
.34555 .25283 m
.40476 .25283 L
.40476 .30574 L
.35873 .30574 L
.34555 .25283 L
F
.35873 .30574 m
.40476 .30574 L
.40476 .35865 L
.38204 .35865 L
.35873 .30574 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.38204 .04119 m
.35873 .0941 L
.34555 .14701 L
.34127 .19992 L
.34555 .25283 L
.35873 .30574 L
.38204 .35865 L
.40476 .35865 L
.40476 .30574 L
.40476 .25283 L
.40476 .19992 L
.40476 .14701 L
.40476 .0941 L
.40476 .04119 L
.38204 .04119 L
s
.5 g
.38204 .19992 m
.40476 .19992 L
.40476 .19992 L
.35873 .19992 L
.38204 .19992 L
F
.35873 .19992 m
.40476 .19992 L
.40476 .19992 L
.34555 .19992 L
.35873 .19992 L
F
.34555 .19992 m
.40476 .19992 L
.40476 .19992 L
.34127 .19992 L
.34555 .19992 L
F
.34127 .19992 m
.40476 .19992 L
.40476 .19992 L
.34555 .19992 L
.34127 .19992 L
F
.34555 .19992 m
.40476 .19992 L
.40476 .19992 L
.35873 .19992 L
.34555 .19992 L
F
.35873 .19992 m
.40476 .19992 L
.40476 .19992 L
.38204 .19992 L
.35873 .19992 L
F
0 g
.38204 .19992 m
.35873 .19992 L
.34555 .19992 L
.34127 .19992 L
.34555 .19992 L
.35873 .19992 L
.38204 .19992 L
.40476 .19992 L
.40476 .19992 L
.40476 .19992 L
.40476 .19992 L
.40476 .19992 L
.40476 .19992 L
.40476 .19992 L
.38204 .19992 L
s
.38204 .35865 m
.40476 .35865 L
.40476 .35324 L
.38204 .35324 L
.38204 .35865 L
s
.38204 .35324 m
.40476 .35324 L
.40476 .33738 L
.38204 .33738 L
.38204 .35324 L
s
.38204 .33738 m
.40476 .33738 L
.40476 .31216 L
.38204 .31216 L
.38204 .33738 L
s
.38204 .31216 m
.40476 .31216 L
.40476 .27929 L
.38204 .27929 L
.38204 .31216 L
s
.38204 .27929 m
.40476 .27929 L
.40476 .241 L
.38204 .241 L
.38204 .27929 L
s
.38204 .241 m
.40476 .241 L
.40476 .19992 L
.38204 .19992 L
.38204 .241 L
s
.38204 .19992 m
.40476 .19992 L
.40476 .15884 L
.38204 .15884 L
.38204 .19992 L
s
.38204 .15884 m
.40476 .15884 L
.40476 .12056 L
.38204 .12056 L
.38204 .15884 L
s
.38204 .12056 m
.40476 .12056 L
.40476 .08768 L
.38204 .08768 L
.38204 .12056 L
s
.38204 .08768 m
.40476 .08768 L
.40476 .06246 L
.38204 .06246 L
.38204 .08768 L
s
.38204 .06246 m
.40476 .06246 L
.40476 .0466 L
.38204 .0466 L
.38204 .06246 L
s
.38204 .0466 m
.40476 .0466 L
.40476 .04119 L
.38204 .04119 L
.38204 .0466 L
s
.38204 .04119 m
.40476 .04119 L
.40476 .0466 L
.38204 .0466 L
.38204 .04119 L
s
.38204 .0466 m
.40476 .0466 L
.40476 .06246 L
.38204 .06246 L
.38204 .0466 L
s
.38204 .06246 m
.40476 .06246 L
.40476 .08768 L
.38204 .08768 L
.38204 .06246 L
s
.38204 .08768 m
.40476 .08768 L
.40476 .12056 L
.38204 .12056 L
.38204 .08768 L
s
.38204 .12056 m
.40476 .12056 L
.40476 .15884 L
.38204 .15884 L
.38204 .12056 L
s
.38204 .15884 m
.40476 .15884 L
.40476 .19992 L
.38204 .19992 L
.38204 .15884 L
s
.38204 .19992 m
.40476 .19992 L
.40476 .241 L
.38204 .241 L
.38204 .19992 L
s
.38204 .241 m
.40476 .241 L
.40476 .27929 L
.38204 .27929 L
.38204 .241 L
s
.38204 .27929 m
.40476 .27929 L
.40476 .31216 L
.38204 .31216 L
.38204 .27929 L
s
.38204 .31216 m
.40476 .31216 L
.40476 .33738 L
.38204 .33738 L
.38204 .31216 L
s
.38204 .33738 m
.40476 .33738 L
.40476 .35324 L
.38204 .35324 L
.38204 .33738 L
s
.38204 .35324 m
.40476 .35324 L
.40476 .35865 L
.38204 .35865 L
.38204 .35324 L
s
.5 g
.54649 .08768 m
.54649 .08768 L
.5839 .12509 L
.5839 .12509 L
.54649 .08768 L
F
.5839 .12509 m
.5839 .12509 L
.62132 .16251 L
.62132 .16251 L
.5839 .12509 L
F
.62132 .16251 m
.62132 .16251 L
.65873 .19992 L
.65873 .19992 L
.62132 .16251 L
F
.65873 .19992 m
.65873 .19992 L
.69614 .23733 L
.69614 .23733 L
.65873 .19992 L
F
.69614 .23733 m
.69614 .23733 L
.73356 .27475 L
.73356 .27475 L
.69614 .23733 L
F
.73356 .27475 m
.73356 .27475 L
.77097 .31216 L
.77097 .31216 L
.73356 .27475 L
F
0 g
.54649 .08768 m
.5839 .12509 L
.62132 .16251 L
.65873 .19992 L
.69614 .23733 L
.73356 .27475 L
.77097 .31216 L
.77097 .31216 L
.73356 .27475 L
.69614 .23733 L
.65873 .19992 L
.62132 .16251 L
.5839 .12509 L
.54649 .08768 L
.54649 .08768 L
s
.5 g
.65873 .19992 m
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
F
.65873 .19992 m
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
F
.65873 .19992 m
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
F
.65873 .19992 m
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
F
.65873 .19992 m
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
F
.65873 .19992 m
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
F
0 g
.65873 .19992 m
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
s
.5 g
.65873 .19992 m
.69614 .23733 L
.69487 .23606 L
.65873 .19992 L
.65873 .19992 L
F
.69614 .23733 m
.73356 .27475 L
.73101 .2722 L
.69487 .23606 L
.69614 .23733 L
F
.73356 .27475 m
.77097 .31216 L
.76714 .30834 L
.73101 .2722 L
.73356 .27475 L
F
.65873 .19992 m
.69487 .23606 L
.69113 .23232 L
.65873 .19992 L
.65873 .19992 L
F
.69487 .23606 m
.73101 .2722 L
.72353 .26472 L
.69113 .23232 L
.69487 .23606 L
F
.73101 .2722 m
.76714 .30834 L
.75593 .29712 L
.72353 .26472 L
.73101 .2722 L
F
.65873 .19992 m
.69113 .23232 L
.68519 .22638 L
.65873 .19992 L
.65873 .19992 L
F
.69113 .23232 m
.72353 .26472 L
.71164 .25283 L
.68519 .22638 L
.69113 .23232 L
F
.72353 .26472 m
.75593 .29712 L
.7381 .27929 L
.71164 .25283 L
.72353 .26472 L
F
.65873 .19992 m
.68519 .22638 L
.67744 .21863 L
.65873 .19992 L
.65873 .19992 L
F
.68519 .22638 m
.71164 .25283 L
.69614 .23733 L
.67744 .21863 L
.68519 .22638 L
F
.71164 .25283 m
.7381 .27929 L
.71485 .25604 L
.69614 .23733 L
.71164 .25283 L
F
.65873 .19992 m
.67744 .21863 L
.66841 .2096 L
.65873 .19992 L
.65873 .19992 L
F
.67744 .21863 m
.69614 .23733 L
.6781 .21929 L
.66841 .2096 L
.67744 .21863 L
F
.69614 .23733 m
.71485 .25604 L
.68778 .22897 L
.6781 .21929 L
.69614 .23733 L
F
.65873 .19992 m
.66841 .2096 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
F
.66841 .2096 m
.6781 .21929 L
.65873 .19992 L
.65873 .19992 L
.66841 .2096 L
F
.6781 .21929 m
.68778 .22897 L
.65873 .19992 L
.65873 .19992 L
.6781 .21929 L
F
.65873 .19992 m
.65873 .19992 L
.64905 .19024 L
.65873 .19992 L
.65873 .19992 L
F
.65873 .19992 m
.65873 .19992 L
.63936 .18055 L
.64905 .19024 L
.65873 .19992 L
F
.65873 .19992 m
.65873 .19992 L
.62968 .17087 L
.63936 .18055 L
.65873 .19992 L
F
.65873 .19992 m
.64905 .19024 L
.64002 .18121 L
.65873 .19992 L
.65873 .19992 L
F
.64905 .19024 m
.63936 .18055 L
.62132 .16251 L
.64002 .18121 L
.64905 .19024 L
F
.63936 .18055 m
.62968 .17087 L
.60261 .1438 L
.62132 .16251 L
.63936 .18055 L
F
.65873 .19992 m
.64002 .18121 L
.63228 .17347 L
.65873 .19992 L
.65873 .19992 L
F
.64002 .18121 m
.62132 .16251 L
.60582 .14701 L
.63228 .17347 L
.64002 .18121 L
F
.62132 .16251 m
.60261 .1438 L
.57937 .12056 L
.60582 .14701 L
.62132 .16251 L
F
.65873 .19992 m
.63228 .17347 L
.62633 .16752 L
.65873 .19992 L
.65873 .19992 L
F
.63228 .17347 m
.60582 .14701 L
.59393 .13512 L
.62633 .16752 L
.63228 .17347 L
F
.60582 .14701 m
.57937 .12056 L
.56153 .10272 L
.59393 .13512 L
.60582 .14701 L
F
.65873 .19992 m
.62633 .16752 L
.62259 .16378 L
.65873 .19992 L
.65873 .19992 L
F
.62633 .16752 m
.59393 .13512 L
.58645 .12764 L
.62259 .16378 L
.62633 .16752 L
F
.59393 .13512 m
.56153 .10272 L
.55032 .09151 L
.58645 .12764 L
.59393 .13512 L
F
.65873 .19992 m
.62259 .16378 L
.62132 .16251 L
.65873 .19992 L
.65873 .19992 L
F
.62259 .16378 m
.58645 .12764 L
.5839 .12509 L
.62132 .16251 L
.62259 .16378 L
F
.58645 .12764 m
.55032 .09151 L
.54649 .08768 L
.5839 .12509 L
.58645 .12764 L
F
.65873 .19992 m
.62132 .16251 L
.62259 .16378 L
.65873 .19992 L
.65873 .19992 L
F
.62132 .16251 m
.5839 .12509 L
.58645 .12764 L
.62259 .16378 L
.62132 .16251 L
F
.5839 .12509 m
.54649 .08768 L
.55032 .09151 L
.58645 .12764 L
.5839 .12509 L
F
.65873 .19992 m
.62259 .16378 L
.62633 .16752 L
.65873 .19992 L
.65873 .19992 L
F
.62259 .16378 m
.58645 .12764 L
.59393 .13512 L
.62633 .16752 L
.62259 .16378 L
F
.58645 .12764 m
.55032 .09151 L
.56153 .10272 L
.59393 .13512 L
.58645 .12764 L
F
.65873 .19992 m
.62633 .16752 L
.63228 .17347 L
.65873 .19992 L
.65873 .19992 L
F
.62633 .16752 m
.59393 .13512 L
.60582 .14701 L
.63228 .17347 L
.62633 .16752 L
F
.59393 .13512 m
.56153 .10272 L
.57937 .12056 L
.60582 .14701 L
.59393 .13512 L
F
.65873 .19992 m
.63228 .17347 L
.64002 .18121 L
.65873 .19992 L
.65873 .19992 L
F
.63228 .17347 m
.60582 .14701 L
.62132 .16251 L
.64002 .18121 L
.63228 .17347 L
F
.60582 .14701 m
.57937 .12056 L
.60261 .1438 L
.62132 .16251 L
.60582 .14701 L
F
.65873 .19992 m
.64002 .18121 L
.64905 .19024 L
.65873 .19992 L
.65873 .19992 L
F
.64002 .18121 m
.62132 .16251 L
.63936 .18055 L
.64905 .19024 L
.64002 .18121 L
F
.62132 .16251 m
.60261 .1438 L
.62968 .17087 L
.63936 .18055 L
.62132 .16251 L
F
.65873 .19992 m
.64905 .19024 L
.65873 .19992 L
.65873 .19992 L
.65873 .19992 L
F
.64905 .19024 m
.63936 .18055 L
.65873 .19992 L
.65873 .19992 L
.64905 .19024 L
F
.63936 .18055 m
.62968 .17087 L
.65873 .19992 L
.65873 .19992 L
.63936 .18055 L
F
.65873 .19992 m
.65873 .19992 L
.66841 .2096 L
.65873 .19992 L
.65873 .19992 L
F
.65873 .19992 m
.65873 .19992 L
.6781 .21929 L
.66841 .2096 L
.65873 .19992 L
F
.65873 .19992 m
.65873 .19992 L
.68778 .22897 L
.6781 .21929 L
.65873 .19992 L
F
.65873 .19992 m
.66841 .2096 L
.67744 .21863 L
.65873 .19992 L
.65873 .19992 L
F
.66841 .2096 m
.6781 .21929 L
.69614 .23733 L
.67744 .21863 L
.66841 .2096 L
F
.6781 .21929 m
.68778 .22897 L
.71485 .25604 L
.69614 .23733 L
.6781 .21929 L
F
.65873 .19992 m
.67744 .21863 L
.68519 .22638 L
.65873 .19992 L
.65873 .19992 L
F
.67744 .21863 m
.69614 .23733 L
.71164 .25283 L
.68519 .22638 L
.67744 .21863 L
F
.69614 .23733 m
.71485 .25604 L
.7381 .27929 L
.71164 .25283 L
.69614 .23733 L
F
.65873 .19992 m
.68519 .22638 L
.69113 .23232 L
.65873 .19992 L
.65873 .19992 L
F
.68519 .22638 m
.71164 .25283 L
.72353 .26472 L
.69113 .23232 L
.68519 .22638 L
F
.71164 .25283 m
.7381 .27929 L
.75593 .29712 L
.72353 .26472 L
.71164 .25283 L
F
.65873 .19992 m
.69113 .23232 L
.69487 .23606 L
.65873 .19992 L
.65873 .19992 L
F
.69113 .23232 m
.72353 .26472 L
.73101 .2722 L
.69487 .23606 L
.69113 .23232 L
F
.72353 .26472 m
.75593 .29712 L
.76714 .30834 L
.73101 .2722 L
.72353 .26472 L
F
.65873 .19992 m
.69487 .23606 L
.69614 .23733 L
.65873 .19992 L
.65873 .19992 L
F
.69487 .23606 m
.73101 .2722 L
.73356 .27475 L
.69614 .23733 L
.69487 .23606 L
F
.73101 .2722 m
.76714 .30834 L
.77097 .31216 L
.73356 .27475 L
.73101 .2722 L
F
0 g
.77097 .31216 m
.76714 .30834 L
.75593 .29712 L
.7381 .27929 L
.71485 .25604 L
.68778 .22897 L
.65873 .19992 L
.62968 .17087 L
.60261 .1438 L
.57937 .12056 L
.56153 .10272 L
.55032 .09151 L
.54649 .08768 L
.55032 .09151 L
.56153 .10272 L
.57937 .12056 L
.60261 .1438 L
.62968 .17087 L
.65873 .19992 L
.68778 .22897 L
.71485 .25604 L
.7381 .27929 L
.75593 .29712 L
.76714 .30834 L
.77097 .31216 L
s
.97619 .04119 m
.97619 .0941 L
.97619 .14701 L
.97619 .19992 L
.97619 .25283 L
.97619 .30574 L
.97619 .35865 L
.97619 .35865 L
.97619 .30574 L
.97619 .25283 L
.97619 .19992 L
.97619 .14701 L
.97619 .0941 L
.97619 .04119 L
.97619 .04119 L
s
.97619 .19992 m
.97619 .19992 L
.97619 .19992 L
.97619 .19992 L
.97619 .19992 L
.97619 .19992 L
.97619 .19992 L
.97619 .19992 L
.97619 .19992 L
.97619 .19992 L
.97619 .19992 L
.97619 .19992 L
.97619 .19992 L
.97619 .19992 L
.97619 .19992 L
s
.97619 .35865 m
.97619 .35324 L
.97619 .33738 L
.97619 .31216 L
.97619 .27929 L
.97619 .241 L
.97619 .19992 L
.97619 .15884 L
.97619 .12056 L
.97619 .08768 L
.97619 .06246 L
.97619 .0466 L
.97619 .04119 L
.97619 .0466 L
.97619 .06246 L
.97619 .08768 L
.97619 .12056 L
.97619 .15884 L
.97619 .19992 L
.97619 .241 L
.97619 .27929 L
.97619 .31216 L
.97619 .33738 L
.97619 .35324 L
.97619 .35865 L
s
.81746 .51738 m
.76455 .51738 L
.71164 .51738 L
.65873 .51738 L
.60582 .51738 L
.55291 .51738 L
.5 .51738 L
.5 .51738 L
.55291 .51738 L
.60582 .51738 L
.65873 .51738 L
.71164 .51738 L
.76455 .51738 L
.81746 .51738 L
.81746 .51738 L
s
.65873 .51738 m
.65873 .51738 L
.65873 .51738 L
.65873 .51738 L
.65873 .51738 L
.65873 .51738 L
.65873 .51738 L
.65873 .51738 L
.65873 .51738 L
.65873 .51738 L
.65873 .51738 L
.65873 .51738 L
.65873 .51738 L
.65873 .51738 L
.65873 .51738 L
s
.5 .51738 m
.50541 .51738 L
.52127 .51738 L
.54649 .51738 L
.57937 .51738 L
.61765 .51738 L
.65873 .51738 L
.69981 .51738 L
.7381 .51738 L
.77097 .51738 L
.79619 .51738 L
.81205 .51738 L
.81746 .51738 L
.81205 .51738 L
.79619 .51738 L
.77097 .51738 L
.7381 .51738 L
.69981 .51738 L
.65873 .51738 L
.61765 .51738 L
.57937 .51738 L
.54649 .51738 L
.52127 .51738 L
.50541 .51738 L
.5 .51738 L
s
.039 .916 .04 r
.02381 .13643 m
.34745 .13643 L
s
% Start of user PostScript
-50. -10. 0.973037 -10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34745 .13643 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19992 m
.34127 .19992 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .19992 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26341 m
.34745 .26341 L
s
% Start of user PostScript
-50. 10. 0.973037 10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34745 .26341 Mdot
.039 .916 .04 r
.5 Mabswid
.34745 .13643 m
.40476 .14026 L
s
% Start of user PostScript
0.973037 -10. 10. -9.3966 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .14026 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .19992 m
.40476 .19992 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .19992 Mdot
.039 .916 .04 r
.5 Mabswid
.34745 .26341 m
.40476 .25958 L
s
% Start of user PostScript
0.973037 10. 10. 9.3966 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .25958 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .14026 m
.6211 .16229 L
s
% Start of user PostScript
10. -9.3966 44.0734 -5.92662 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6211 .16229 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .19992 m
.65873 .19992 L
s
% Start of user PostScript
10. 0 50. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.65873 .19992 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .25958 m
.6894 .23059 L
s
% Start of user PostScript
10. 9.3966 54.8311 4.83107 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6894 .23059 Mdot
.039 .916 .04 r
.5 Mabswid
.6211 .16229 m
.97619 .19845 L
s
% Start of user PostScript
44.0734 -5.92662 100. -0.231131 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19845 Mdot
.039 .916 .04 r
.5 Mabswid
.6211 .16229 m
.65726 .51738 L
s
% Start of user PostScript
44.0734 -5.92662 49.7689 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.65726 .51738 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .19992 m
.97619 .19992 L
s
% Start of user PostScript
50. 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19992 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .19992 m
.65873 .51738 L
s
% Start of user PostScript
50. 0 50. 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.65873 .51738 Mdot
.039 .916 .04 r
.5 Mabswid
.6894 .23059 m
.97619 .20139 L
s
% Start of user PostScript
54.8311 4.83107 100. 0.231131 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .20139 Mdot
.039 .916 .04 r
.5 Mabswid
.6894 .23059 m
.6602 .51738 L
s
% Start of user PostScript
54.8311 4.83107 50.2311 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6602 .51738 Mdot
gsave
.37302 .01262 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52629 .06748 -69.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BS) show
75.125 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .01262 -68.25 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S1) show
73.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84603 .51738 -68.25 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S2) show
73.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .53 L
0 .53 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[41]:=",
  ImageSize->{288, 152.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000V2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00JOooool6o`0009oooooo0ol0
0003ooooo`?o00002Oooool006[ooooo00Go0000ooooooooooooooooo`00002Oooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool02?ooool006[ooooo00?o0000ooooooooool0Y?oo
ool01Ol0003ooooooooooooooooo000000[ooooo001Zooooo`03o`000?oooooooooo0:;ooooo0_l0
0004ooooo`03o`000?oooooooooo00Sooooo001Zooooo`03o`000?oooooooooo0:7ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`08ooooo`00J_ooool00ol0003oooooooooo`2Qoooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool006Wooooo0ol0002Soooo
o`?o00000_ooool2o`0000[ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo001^
ooooo`Oo0000WOooool2o`0000cooooo001^ooooo`Oo0000WOooool00ol0003oooooooooo`0;oooo
o`00KOooool2o`0000GoOgmo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0;ooooo`00
KOooool2o`0000GoOgmo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0;ooooo`00K?oo
ool00ol0003oOgmoo`000005ogmoO`03o`000?oooooooooo09_ooooo00?o0000ooooooooool02ooo
ool006cooooo00?o0000ogmoOol000001OmoOgl00ol0003oooooooooo`0Iooooo`Go00000oooool3
o`0007Oooooo00?o0000ooooooooool02oooool006cooooo00?o0000ogmoOol000001_l0000Loooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001fooooo`03o`000?oo
oooooooo00_ooooo001[ooooo`04o`000?moOgooOgmoo`0000GoOgmo00?o0000ooooooooool06_oo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
ooooo`0;ooooo`00Joooool01?l0003oOgmoogmoOol00005ogmoO`03o`000?oooooooooo01[ooooo
1?l00004ooooo`;o0000Moooool00ol0003oooooooooo`0;ooooo`00J_ooool01Ol0003oOgmoogmo
OomoOgoo000000GoOgmo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0;ooooo`00J_ooool01Ol0003oOgmo
ogmoOomoOgoo000000GoOgmo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo0000M_ooool00ol0003oooooooooo`0;ooooo`00JOooool00ol0
003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool06Oooool5o`00
00Cooooo0ol0001fooooo`03o`000?oooooooooo00_ooooo001Yooooo`03o`000?moOgooOgmo00;o
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool02oooool006Wooooo00?o0000ogmoOomoOgl00_moOgl7o`0002Oooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`0;ooooo`00J?ooool00ol0003oOgmoogmo
O`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo00_ooooo001Xooooo`03o`000?moOgooOgmo00?oOgmo00?o0000
ogmoOomoOgl00omoOgl00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool02oooool006Sooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0;oooo
o`00Ioooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`00
0?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool02oooool006Oooooo00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0;ooooo`00Ioooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo00_ooooo001Vooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02oooool006Ko
oooo00?o0000ogmoOomoOgl01OmoOgl7o`00033ooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`0;ooooo`00I_ooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00_ooooo
001Looooo`?o2NX:1_ooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo00?oOgmo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00_ooooo001M
ooooo`Ko2NX:0_ooool00ol0003oOgmoogmoO`04ogmoO`?o2NX:1OmoOgl00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool02oooool000_oooooJ?l9jPX00omo
Ogoo0000ooooo`0cooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool02oooool005go
oooo1Ol9jPX2ooooo`;o00001omoOgl=o`WZ2S3ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`0;ooooo`00G?ooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01_moOgl5o`WZ2P;oOgmo
0_l00004ooooo`[o2NX:9oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00_ooooo
001Tooooo`03o`000?moOgooOgmo00GoOgmo0_l9jPX00ol0003oOgmoogmoO`03ogmoO`03o`000?oo
oooooooo00gooooo2_l9jPXNooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool02ooo
ool006Cooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo01Oooooo2_l9jPXEooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool02oooool0
06Cooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo
027ooooo2_l9jPX6ooooo`?o2NX:0oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00_ooooo001Tooooo`03o`000?moOgooOgmo00OoOgmo1ol0000]ooooo`go2NX:00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`07ogmoO`03o`00
0?moOgooOgmo00?oOgmo00?o0000ooooooooool0<_ooool=o`WZ2Ucooooo00?o0000ooooooooool0
2oooool006Cooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oo
oooooooo037ooooo1?l9jPX4ooooo`03o`WZ2_l0003ooooo00?ooooo2_l9jPYBooooo`03o`000?oo
oooooooo00_ooooo001Tooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl0
0ol0003oooooooooo`0iooooo`03o`WZ2_moOgoo000000gooooo2_l9jPY8ooooo`03o`000?oooooo
oooo00_ooooo001Tooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`0iooooo`04o`WZ2_ooooooOgmoo`0001Kooooo2Ol9jPXoooooo`03o`000?oooooo
oooo00_ooooo001Sooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`0iooooo`05o`WZ2_ooooooooooogmoOol000007_ooool:o`WZ2SGooooo00?o0000
ooooooooool02oooool006?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo03Wooooo00Ko2NX:ooooooooooooooooogmoOol0000Wooooo`[o2NX::ooo
ool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ooooooooool0>_ooool01_l9jP[oooooooooooooooooOgmoo`00033ooooo
2_l9jPXQooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?moOgooOgmo00SoOgmo00?o
0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0jooooo`03o`WZ2_oooooooooo00?ooooo00?o
0000ooooooooool0=oooool:o`WZ2QOooooo00?o0000ooooooooool02oooool006?ooooo00?o0000
ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo03[ooooo00?o2NX:
ooooooooool01?ooool00ol0003oooooooooo`10ooooo`Wo2NX:1oooool3o`WZ2PCooooo00?o0000
ooooooooool02oooool005_ooooo0ol9jPX5ooooo`03o`000?moOgooOgmo00KoOgmo0ol9jPX5ogmo
O`03o`000?oooooooooo03[ooooo00?o2NX:ooooool9jPX00_l9jPX3ooooo`03o`000?oooooooooo
04Sooooo3Ol9jPX00ooooooo0000ooooo`0<ooooo`00G?ooool6o`WZ2P;o00002OmoOgl6o`WZ2P03
ogmoOol0003o000003_ooooo00?o2NX:ooooooooool01_l9jPX2o`0004kooooo2?l9jPX2o`0000co
oooo000;oooooeOo2NX:00?o0000o`WZ2_l9jPX0EOl9jPX00ol0003o2NX:o`WZ2P1Eo`WZ2P;o0000
3?ooool005cooooo1Ol9jPX2ooooo`03o`000?moOgooOgmo00OoOgmo1Ol9jPX2ogmoO`03o`000?oo
oooooooo03[ooooo00?o2NX:ooooooooool01Ol9jPX2ooooo`03o`WZ2_l0003ooooo04Gooooo3_l9
jPX00ooooooo0000o`00000<ooooo`00Foooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01_moOgl2
o`WZ2P03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0>_ooool01?l9jP[oooooo`WZ2_l9
jPX6ooooo`03o`WZ2_oooooo000003_ooooo2_l9jPX7ooooo`Co2NX:1?ooool00ol0003ooooooooo
o`0;ooooo`00Hoooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000
ooooooooool0>_ooool00ol9jP[oooooooooo`07ooooo`04o`WZ2_ooooooooooo`00033ooooo2_l9
jPXBooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool02oooool006?ooooo00?o0000
ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo03[ooooo00?o2NX:
ooooooooool01oooool01Ol9jP[ooooooooooooooooo000002Kooooo2Ol9jPXSooooo`03o`000?oo
oooooooo00_ooooo001Sooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl0
0ol0003oooooooooo`0kooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool00_ooool0
0ol0003oooooooooo`0Iooooo`[o2NX:;?ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0
003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0>oooool00ol9
jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo00?ooooo00?o0000ooooooooool03_ooool:o`WZ
2SKooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003o
OgmoogmoO`03ogmoO`03o`000?oooooooooo03_ooooo00?o2NX:ooooooooool01_ooool5o`WZ2P;o
oooo00?o0000ooooooooool00oooool:o`WZ2T3ooooo00?o0000ooooooooool02oooool006Cooooo
00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo03_ooooo
00?o2NX:ooooooooool01_ooool=o`WZ2T[ooooo00?o0000ooooooooool02oooool006Cooooo00?o
0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo03_ooooo00?o
2NX:ooooool9jPX03Ol9jPX00ooooooo2NX:o`00001=ooooo`03o`000?oooooooooo00_ooooo001T
ooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0c
ooooo`[o2NX:1oooool4o`WZ2PCooooo00?o2NX:ooooool00000C?ooool00ol0003oooooooooo`0;
ooooo`00I?ooool00ol0003oOgmoogmoO`07ogmoO`Oo0000:oooool:o`WZ2PSooooo00?o2NX:oooo
ooooool01_ooool00ol9jP[oooooooooo`05ooooo`04o`WZ2_ooooooooooo`0004_ooooo00?o0000
ooooooooool02oooool006Cooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo023ooooo2Ol9jPXBooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:oooo
ooooool01Oooool01Ol9jP[ooooooooooooooooo000004[ooooo00?o0000ooooooooool02oooool0
06Cooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo
01Kooooo2_l9jPXKooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool01Oooool00ol9
jP[oooooooooo`02ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool02oooool006Co
oooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo00co
oooo2_l9jPXVooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`04ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool02oooool005cooooo
0ol9jPX5ooooo`03o`000?moOgooOgmo00GoOgmo1Ol9jPX3ogmoO`03o`000?oooooooooo00;ooooo
2_l9jPX`ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`05ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02oooool005gooooo1_l9
jPX00ooooooo0000ogmoO`06ogmoO`go2NX:>_ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01_ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo00_ooooo000;ooooof7o2NX:0_moOgl5o`WZ2P03ogmoOol0003o000003gooooo00?o2NX:
ooooooooool01Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Oooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`0;ooooo`00GOooool5o`WZ2P;ooooo0_l00007ogmo
O`?o2NX:1?moOgl00ol0003oooooooooo`0looooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`08ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool02oooool005cooooo0_l9jPX7ooooo`03o`000?moOgooOgmo00CoOgmo00?o2NX:ogmoOol0
00001OmoOgl00ol0003oooooooooo`0looooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`08ooooo`03ogmoOol0003ooooo04;ooooo00?o0000oooooooo
ool02oooool006Gooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`00
0?oooooooooo03cooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Wooooo00?oOgmoo`000?ooool0@Oooool00ol0003oooooooooo`0;ooooo`00I_oo
ool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0??oo
ool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool02_oo
ool00omoOgoo0000ooooo`10ooooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?moOgoo
Ogmo00GoOgmo1ol0000nooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`0;ooooo`03ogmoOol0003ooooo03oooooo00?o0000ooooooooool02oooool0
06Kooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo
03cooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00cooooo0_l0000oooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00Co
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0mooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0>ooooo`;o0000?_ooool00ol0003o
ooooooooo`0;ooooo`00Ioooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00?oOgmo
00?o0000ooooooooool0?Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool03oooool2o`0003gooooo00?o0000ooooooooool02oooool006Oooooo00?o
0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo03gooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo013ooooo0_l0
000looooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00CoOgmo00?o0000
ogmoOomoOgl00omoOgl00ol0003oooooooooo`0mooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`0Aooooo`;o0000>oooool00ol0003oooooooooo`0;
ooooo`00J?ooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000oooo
ooooool0?Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool04oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00_ooooo001Xooooo`03
o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0mooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Dooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool006Sooooo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo03gooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo01Gooooo0_l0000gooooo`03o`00
0?oooooooooo00_ooooo001Yooooo`03o`000?moOgooOgmo00;oOgmo1ol0000oooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Fooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool02oooool006Wooooo00?o0000ogmoOomoOgl00_moOgl0
0ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo03gooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo04kooooo00?o0000ooooooooool02oooool0
06Wooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo
03gooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
04kooooo00?o0000ooooooooool02oooool006[ooooo00Go0000ogmoOomoOgooOgmoo`000005ogmo
O`03o`000?oooooooooo03kooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02oooo
o`03o`WZ2_oooooooooo04oooooo00?o0000ooooooooool02oooool006[ooooo00Go0000ogmoOomo
OgooOgmoo`000005ogmoO`03o`000?oooooooooo03kooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo04oooooo00?o0000ooooooooool02oooool006_o
oooo00Co0000ogmoOomoOgoo00001OmoOgl00ol0003oooooooooo`0nooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`1?ooooo`03o`000?oooooooooo
00_ooooo001[ooooo`04o`000?moOgooOgmoo`0000GoOgmo00?o0000ooooooooool0?_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0Coooool00ol0
003oooooooooo`0;ooooo`00Joooool00ol0003oOgmoogmoO`07o`00043ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo04oooooo00?o0000oooooooo
ool02oooool006cooooo00?o0000ogmoOol000001OmoOgl00ol0003oooooooooo`0nooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`1?ooooo`03o`00
0?oooooooooo00_ooooo001/ooooo`03o`000?moOgoo000000GoOgmo00?o0000ooooooooool0?_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0Cooo
ool00ol0003oooooooooo`0;ooooo`00KOooool2o`0000GoOgmo00?o0000ooooooooool0?_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0Coooool0
0ol0003oooooooooo`0;ooooo`00KOooool8o`00043ooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo04oooooo00?o0000ooooooooool02oooool006go
oooo0_l00005ogmoO`03o`000?oooooooooo03kooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooooooo04oooooo0_l0000<ooooo`00K_ooool7o`00047ooooo
00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:05;ooooo00?o0000oooooooo
ool02oooool00;Kooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:063o
oooo002fooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P1Pooooo`00
]_ooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX0H?ooool00;Kooooo
00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:063ooooo002fooooo`03o`WZ
2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P1Pooooo`00]_ooool00ol9jP[ooooo
ooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX0H?ooool00;Kooooo00?o2NX:ooooooooool0
0_ooool01Ol9jP[ooooooooooooooooo2NX:063ooooo002fooooo`03o`WZ2_oooooooooo00;ooooo
00Go2NX:ooooooooooooooooo`WZ2P1Pooooo`00]_ooool00ol9jP[oooooooooo`02ooooo`04o`WZ
2_ooooooooooo`WZ2V7ooooo002gooooo`05o`WZ2_ooooooooooooooool9jPX00_ooool00ol9jP[o
ooooooooo`1Oooooo`00]oooool01Ol9jP[ooooooooooooooooo2NX:00;ooooo00?o2NX:oooooooo
ool0Goooool00;Oooooo00Go2NX:ooooooooooooooooo`WZ2P02ooooo`03o`WZ2_oooooooooo05oo
oooo002gooooo`05o`WZ2_ooooooooooooooool9jPX00_ooool00ol9jP[oooooooooo`1Oooooo`00
]oooool01Ol9jP[ooooooooooooooooo2NX:00;ooooo00?o2NX:ooooooooool0Goooool00;Oooooo
00Go2NX:ooooooooooooooooo`WZ2P02ooooo`03o`WZ2_oooooooooo05oooooo002gooooo`05o`WZ
2_ooooooooooooooool9jPX00_ooool00ol9jP[oooooooooo`1Oooooo`00]oooool01Ol9jP[ooooo
oooooooooooo2NX:00;ooooo00?o2NX:ooooooooool0Goooool00;Oooooo00Go2NX:oooooooooooo
ooooo`WZ2P02ooooo`03o`WZ2_oooooooooo05oooooo002hooooo`06o`WZ2_ooooooooooo`WZ2_oo
oooo2NX:H_ooool00;Sooooo00Ko2NX:oooooooooooo2NX:ooooool9jPYRooooo`00^?ooool01_l9
jP[oooooooooool9jP[oooooo`WZ2V;ooooo002hooooo`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:
H_ooool00;Sooooo00Ko2NX:oooooooooooo2NX:ooooool9jPYRooooo`00^?ooool01_l9jP[ooooo
ooooool9jP[oooooo`WZ2V;ooooo002hooooo`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:H_ooool0
0;Sooooo00Ko2NX:oooooooooooo2NX:ooooool9jPYRooooo`00^?ooool01_l9jP[oooooooooool9
jP[oooooo`WZ2V;ooooo002hooooo`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:H_ooool00;Wooooo
00Co2NX:ooooool9jP[o2NX:Hoooool00;Wooooo00Co2NX:ooooool9jP[o2NX:Hoooool00;Wooooo
00Co2NX:ooooool9jP[o2NX:Hoooool00;Wooooo00Co2NX:ooooool9jP[o2NX:Hoooool00;Wooooo
00Co2NX:ooooool9jP[o2NX:Hoooool00;Wooooo00Co2NX:ooooool9jP[o2NX:Hoooool00;Wooooo
1Ol9jPYRooooo`00]oooool8o`WZ2V7ooooo002gooooo`So2NX:HOooool00;Sooooo1_l9jPYRoooo
o`00^?ooool6o`WZ2V;ooooo002iooooo`Co2NX:Hoooool00;Wooooo1?l9jPX]ooooo`?o00000_oo
ool3o`0002kooooo002iooooo`Co2NX:;Oooool01_l0003oooooooooool0003oooooo`0000;ooooo
00?o0000ooooooooool0:oooool008ooooooFOl00005ooooo`04o`000?ooooooooooo`0002oooooo
002jooooo`;o0000;oooool2o`0000?ooooo00?o0000ooooooooool0;Oooool00>[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0/ooooo`00j_ooool02?l0003oooooooooool0003o
ooooo`000?oooooo0000;_ooool00>_ooooo0ol00002ooooo`03o`000?oooooooooo02gooooo003o
ooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {151.625, 0}} -> {-56.5179, -32.9166, \
0.569385, 0.569385}},
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],

Cell[BoxData[
    \({{SymbolicOpticalLength \[Rule] \(\(55.20550238395628`\)\(\
\[InvisibleSpace]\)\) + 1.0002694514570802`\ d1 - 
            0.0020031838142302314`\ y\^2 - 0.00004678067453391911`\ y\^3, 
        SymbolicRayEnd \[Rule] {d1, 
            1.034192531275088`\ y - 0.010006608313591682`\ d1\ y - 
              0.002002644198832842`\ y\^2 - 0.000026728396719349143`\ y\^3 + 
              4.6798978617675763`*^-7\ y\^4, 0}, 
        SymbolicRayTilt \[Rule] {1, \(-0.010006608313591682`\)\ y, 0}, 
        SymbolicSurfaceCoordinates \[Rule] {1.034192531275088`\ y - 
              0.010006608313591682`\ d1\ y - 0.002002644198832842`\ y\^2 - 
              0.000026728396719349143`\ y\^3 + 4.6798978617675763`*^-7\ y\^4, 
            0}, SymbolicIntensity \[Rule] 
          50\ \[ExponentialE]\^\(\(-0.002996147553780966`\)\ y\^2 - 1\/625\ y\
\^2\ \((\(\(0.7549950443123548`\)\(\[InvisibleSpace]\)\) - \
0.010387106273733737`\ y + 0.00006614004285191227`\ y\^2)\)\^2 - 1\/625\ y\^2\
\ \((\(-0.010006608313591682`\)\ d1 + 4.6798978617675763`*^-7\ \
\((\(\(123.20411237448683`\)\(\[InvisibleSpace]\)\) + y)\)\ \
\((\(\(17936.58740233302`\)\(\[InvisibleSpace]\)\) - 180.31731763844516`\ y + \
y\^2)\))\)\^2\), SymbolicSurfaceBoundary \[Rule] {50, 50}, 
        SymbolicOffAxis \[Rule] {0, 0}, 
        SymbolicTranslationVector \[Rule] {d1, 0, 0}, 
        SymbolicRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        SymbolicWaveLength \[Rule] 133\/250, 
        SymbolicSurfaceNormalFunction \[Rule] {1, 0, 
            0}}, {SymbolicOpticalLength \[Rule] \(\(105.2189749568103`\)\(\
\[InvisibleSpace]\)\) + 1.0002694514570802`\ d2 - 
            0.0020031838142302322`\ y\^2 - 0.00004678067453391911`\ y\^3, 
        SymbolicRayEnd \[Rule] {\(\(50.`\)\(\[InvisibleSpace]\)\) + 
              0.5338621155955039`\ y - 0.010006608313591682`\ d2\ y - 
              0.002002644198832844`\ y\^2 - 0.000026728396719349116`\ y\^3 + 
              4.6798978617675763`*^-7\ y\^4, d2, 0}, 
        SymbolicRayTilt \[Rule] {\(-0.010006608313591682`\)\ y, 
            0.9999999999999999`, 0}, 
        SymbolicSurfaceCoordinates \[Rule] {\(-0.5338621155955039`\)\ y + 
              0.010006608313591682`\ d2\ y + 0.002002644198832844`\ y\^2 + 
              0.000026728396719349116`\ y\^3 - 4.6798978617675763`*^-7\ y\^4, 
            0}, SymbolicIntensity \[Rule] 
          50\ \[ExponentialE]\^\(\(-0.002996147553780966`\)\ y\^2 - 1\/625\ y\
\^2\ \((\(\(0.7549950443123548`\)\(\[InvisibleSpace]\)\) + \
\((\(-0.010387106273733737`\) + 0.00006614004285191227`\ y)\)\ y)\)\^2 - \
1\/625\ y\^2\ \((0.010006608313591682`\ d2 - 4.6798978617675763`*^-7\ \
\((\(\(99.93396050505238`\)\(\[InvisibleSpace]\)\) + y)\)\ \
\((\(\(11415.09759833072`\)\(\[InvisibleSpace]\)\) + \((\(-157.0471657690107`\
\) + y)\)\ y)\))\)\^2\), SymbolicSurfaceBoundary \[Rule] {50, 50}, 
        SymbolicOffAxis \[Rule] {0, 0}, 
        SymbolicTranslationVector \[Rule] {50, d2, 0}, 
        SymbolicRotationMatrix \[Rule] {{0, 1, 0}, {\(-1\), 0, 0}, {0, 0, 
              1}}, SymbolicWaveLength \[Rule] 133\/250, 
        SymbolicSurfaceNormalFunction \[Rule] {1, 0, 0}}}\)], "Output",
  CellLabel->"Out[43]=",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Infinite Precision Calculations", "Subsubsection",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8", "2.1.8"}],

Cell[TextData[{
  StyleBox["SymbolicTrace", "Input"],
  " is also capable of producing solutions with infinite precision. This \
happens automatically when the input parameters are all pure integers, \
integer fractions, or symbols. Here is an example of a reflective spherical \
mirror calculation."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],

Cell[CellGroupData[{

Cell["\<\
opticalSystem = {
\tMove[LineOfRays[20],{0,{y,0}}],
\tMove[SphericalMirror[{r,-100},50,10],25],
\tMove[Screen[50],{d,-25}]};
AnalyzeSystem[opticalSystem,PlotType->TopView];
SymbolicTrace[opticalSystem, \
{{y,0,5},{r<0}},SymbolicRefractiveModels->{Air->1}]\
\>", "Input",
  CellLabel->"In[105]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .87 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.420635 0.015873 0.45246 0.015873 [
[.89683 .02071 -6.4375 -6 ]
[.89683 .02071 6.4375 6 ]
[.02381 .02071 -4.75 -6 ]
[.02381 .02071 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .87 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.76706 .05563 m
.97619 .05563 L
.97619 .18791 L
.79526 .18791 L
.76706 .05563 L
F
.79526 .18791 m
.97619 .18791 L
.97619 .32019 L
.81194 .32019 L
.79526 .18791 L
F
.81194 .32019 m
.97619 .32019 L
.97619 .45246 L
.81746 .45246 L
.81194 .32019 L
F
.81746 .45246 m
.97619 .45246 L
.97619 .58474 L
.81194 .58474 L
.81746 .45246 L
F
.81194 .58474 m
.97619 .58474 L
.97619 .71701 L
.79526 .71701 L
.81194 .58474 L
F
.79526 .71701 m
.97619 .71701 L
.97619 .84929 L
.76706 .84929 L
.79526 .71701 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.76706 .05563 m
.79526 .18791 L
.81194 .32019 L
.81746 .45246 L
.81194 .58474 L
.79526 .71701 L
.76706 .84929 L
.97619 .84929 L
.97619 .71701 L
.97619 .58474 L
.97619 .45246 L
.97619 .32019 L
.97619 .18791 L
.97619 .05563 L
.76706 .05563 L
s
.5 g
.76706 .45246 m
.97619 .45246 L
.97619 .45246 L
.79526 .45246 L
.76706 .45246 L
F
.79526 .45246 m
.97619 .45246 L
.97619 .45246 L
.81194 .45246 L
.79526 .45246 L
F
.81194 .45246 m
.97619 .45246 L
.97619 .45246 L
.81746 .45246 L
.81194 .45246 L
F
.81746 .45246 m
.97619 .45246 L
.97619 .45246 L
.81194 .45246 L
.81746 .45246 L
F
.81194 .45246 m
.97619 .45246 L
.97619 .45246 L
.79526 .45246 L
.81194 .45246 L
F
.79526 .45246 m
.97619 .45246 L
.97619 .45246 L
.76706 .45246 L
.79526 .45246 L
F
0 g
.76706 .45246 m
.79526 .45246 L
.81194 .45246 L
.81746 .45246 L
.81194 .45246 L
.79526 .45246 L
.76706 .45246 L
.97619 .45246 L
.97619 .45246 L
.97619 .45246 L
.97619 .45246 L
.97619 .45246 L
.97619 .45246 L
.97619 .45246 L
.76706 .45246 L
s
.5 g
.81746 .45246 m
.81194 .58474 L
.81194 .58023 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .58474 m
.79526 .71701 L
.79526 .708 L
.81194 .58023 L
.81194 .58474 L
F
.79526 .71701 m
.76706 .84929 L
.76706 .83576 L
.79526 .708 L
.79526 .71701 L
F
.81746 .45246 m
.81194 .58023 L
.81194 .56701 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .58023 m
.79526 .708 L
.79526 .68157 L
.81194 .56701 L
.81194 .58023 L
F
.79526 .708 m
.76706 .83576 L
.76706 .79612 L
.79526 .68157 L
.79526 .708 L
F
.81746 .45246 m
.81194 .56701 L
.81194 .54599 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .56701 m
.79526 .68157 L
.79526 .63953 L
.81194 .54599 L
.81194 .56701 L
F
.79526 .68157 m
.76706 .79612 L
.76706 .73306 L
.79526 .63953 L
.79526 .68157 L
F
.81746 .45246 m
.81194 .54599 L
.81194 .5186 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .54599 m
.79526 .63953 L
.79526 .58474 L
.81194 .5186 L
.81194 .54599 L
F
.79526 .63953 m
.76706 .73306 L
.76706 .65087 L
.79526 .58474 L
.79526 .63953 L
F
.81746 .45246 m
.81194 .5186 L
.81194 .4867 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .5186 m
.79526 .58474 L
.79526 .52093 L
.81194 .4867 L
.81194 .5186 L
F
.79526 .58474 m
.76706 .65087 L
.76706 .55517 L
.79526 .52093 L
.79526 .58474 L
F
.81746 .45246 m
.81194 .4867 L
.81194 .45246 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .4867 m
.79526 .52093 L
.79526 .45246 L
.81194 .45246 L
.81194 .4867 L
F
.79526 .52093 m
.76706 .55517 L
.76706 .45246 L
.79526 .45246 L
.79526 .52093 L
F
.81746 .45246 m
.81194 .45246 L
.81194 .41822 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .45246 m
.79526 .45246 L
.79526 .38399 L
.81194 .41822 L
.81194 .45246 L
F
.79526 .45246 m
.76706 .45246 L
.76706 .34975 L
.79526 .38399 L
.79526 .45246 L
F
.81746 .45246 m
.81194 .41822 L
.81194 .38632 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .41822 m
.79526 .38399 L
.79526 .32019 L
.81194 .38632 L
.81194 .41822 L
F
.79526 .38399 m
.76706 .34975 L
.76706 .25405 L
.79526 .32019 L
.79526 .38399 L
F
.81746 .45246 m
.81194 .38632 L
.81194 .35893 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .38632 m
.79526 .32019 L
.79526 .2654 L
.81194 .35893 L
.81194 .38632 L
F
.79526 .32019 m
.76706 .25405 L
.76706 .17186 L
.79526 .2654 L
.79526 .32019 L
F
.81746 .45246 m
.81194 .35893 L
.81194 .33791 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .35893 m
.79526 .2654 L
.79526 .22335 L
.81194 .33791 L
.81194 .35893 L
F
.79526 .2654 m
.76706 .17186 L
.76706 .1088 L
.79526 .22335 L
.79526 .2654 L
F
.81746 .45246 m
.81194 .33791 L
.81194 .32469 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .33791 m
.79526 .22335 L
.79526 .19692 L
.81194 .32469 L
.81194 .33791 L
F
.79526 .22335 m
.76706 .1088 L
.76706 .06916 L
.79526 .19692 L
.79526 .22335 L
F
.81746 .45246 m
.81194 .32469 L
.81194 .32019 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .32469 m
.79526 .19692 L
.79526 .18791 L
.81194 .32019 L
.81194 .32469 L
F
.79526 .19692 m
.76706 .06916 L
.76706 .05563 L
.79526 .18791 L
.79526 .19692 L
F
.81746 .45246 m
.81194 .32019 L
.81194 .32469 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .32019 m
.79526 .18791 L
.79526 .19692 L
.81194 .32469 L
.81194 .32019 L
F
.79526 .18791 m
.76706 .05563 L
.76706 .06916 L
.79526 .19692 L
.79526 .18791 L
F
.81746 .45246 m
.81194 .32469 L
.81194 .33791 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .32469 m
.79526 .19692 L
.79526 .22335 L
.81194 .33791 L
.81194 .32469 L
F
.79526 .19692 m
.76706 .06916 L
.76706 .1088 L
.79526 .22335 L
.79526 .19692 L
F
.81746 .45246 m
.81194 .33791 L
.81194 .35893 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .33791 m
.79526 .22335 L
.79526 .2654 L
.81194 .35893 L
.81194 .33791 L
F
.79526 .22335 m
.76706 .1088 L
.76706 .17186 L
.79526 .2654 L
.79526 .22335 L
F
.81746 .45246 m
.81194 .35893 L
.81194 .38632 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .35893 m
.79526 .2654 L
.79526 .32019 L
.81194 .38632 L
.81194 .35893 L
F
.79526 .2654 m
.76706 .17186 L
.76706 .25405 L
.79526 .32019 L
.79526 .2654 L
F
.81746 .45246 m
.81194 .38632 L
.81194 .41822 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .38632 m
.79526 .32019 L
.79526 .38399 L
.81194 .41822 L
.81194 .38632 L
F
.79526 .32019 m
.76706 .25405 L
.76706 .34975 L
.79526 .38399 L
.79526 .32019 L
F
.81746 .45246 m
.81194 .41822 L
.81194 .45246 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .41822 m
.79526 .38399 L
.79526 .45246 L
.81194 .45246 L
.81194 .41822 L
F
.79526 .38399 m
.76706 .34975 L
.76706 .45246 L
.79526 .45246 L
.79526 .38399 L
F
.81746 .45246 m
.81194 .45246 L
.81194 .4867 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .45246 m
.79526 .45246 L
.79526 .52093 L
.81194 .4867 L
.81194 .45246 L
F
.79526 .45246 m
.76706 .45246 L
.76706 .55517 L
.79526 .52093 L
.79526 .45246 L
F
.81746 .45246 m
.81194 .4867 L
.81194 .5186 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .4867 m
.79526 .52093 L
.79526 .58474 L
.81194 .5186 L
.81194 .4867 L
F
.79526 .52093 m
.76706 .55517 L
.76706 .65087 L
.79526 .58474 L
.79526 .52093 L
F
.81746 .45246 m
.81194 .5186 L
.81194 .54599 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .5186 m
.79526 .58474 L
.79526 .63953 L
.81194 .54599 L
.81194 .5186 L
F
.79526 .58474 m
.76706 .65087 L
.76706 .73306 L
.79526 .63953 L
.79526 .58474 L
F
.81746 .45246 m
.81194 .54599 L
.81194 .56701 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .54599 m
.79526 .63953 L
.79526 .68157 L
.81194 .56701 L
.81194 .54599 L
F
.79526 .63953 m
.76706 .73306 L
.76706 .79612 L
.79526 .68157 L
.79526 .63953 L
F
.81746 .45246 m
.81194 .56701 L
.81194 .58023 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .56701 m
.79526 .68157 L
.79526 .708 L
.81194 .58023 L
.81194 .56701 L
F
.79526 .68157 m
.76706 .79612 L
.76706 .83576 L
.79526 .708 L
.79526 .68157 L
F
.81746 .45246 m
.81194 .58023 L
.81194 .58474 L
.81746 .45246 L
.81746 .45246 L
F
.81194 .58023 m
.79526 .708 L
.79526 .71701 L
.81194 .58474 L
.81194 .58023 L
F
.79526 .708 m
.76706 .83576 L
.76706 .84929 L
.79526 .71701 L
.79526 .708 L
F
0 g
.76706 .84929 m
.76706 .83576 L
.76706 .79612 L
.76706 .73306 L
.76706 .65087 L
.76706 .55517 L
.76706 .45246 L
.76706 .34975 L
.76706 .25405 L
.76706 .17186 L
.76706 .1088 L
.76706 .06916 L
.76706 .05563 L
.76706 .06916 L
.76706 .1088 L
.76706 .17186 L
.76706 .25405 L
.76706 .34975 L
.76706 .45246 L
.76706 .55517 L
.76706 .65087 L
.76706 .73306 L
.76706 .79612 L
.76706 .83576 L
.76706 .84929 L
s
.97619 .84929 m
.97619 .83576 L
.97619 .79612 L
.97619 .73306 L
.97619 .65087 L
.97619 .55517 L
.97619 .45246 L
.97619 .34975 L
.97619 .25405 L
.97619 .17186 L
.97619 .1088 L
.97619 .06916 L
.97619 .05563 L
.97619 .06916 L
.97619 .1088 L
.97619 .17186 L
.97619 .25405 L
.97619 .34975 L
.97619 .45246 L
.97619 .55517 L
.97619 .65087 L
.97619 .73306 L
.97619 .79612 L
.97619 .83576 L
.97619 .84929 L
s
.76706 .84929 m
.97619 .84929 L
.97619 .83576 L
.76706 .83576 L
.76706 .84929 L
s
.76706 .83576 m
.97619 .83576 L
.97619 .79612 L
.76706 .79612 L
.76706 .83576 L
s
.76706 .79612 m
.97619 .79612 L
.97619 .73306 L
.76706 .73306 L
.76706 .79612 L
s
.76706 .73306 m
.97619 .73306 L
.97619 .65087 L
.76706 .65087 L
.76706 .73306 L
s
.76706 .65087 m
.97619 .65087 L
.97619 .55517 L
.76706 .55517 L
.76706 .65087 L
s
.76706 .55517 m
.97619 .55517 L
.97619 .45246 L
.76706 .45246 L
.76706 .55517 L
s
.76706 .45246 m
.97619 .45246 L
.97619 .34975 L
.76706 .34975 L
.76706 .45246 L
s
.76706 .34975 m
.97619 .34975 L
.97619 .25405 L
.76706 .25405 L
.76706 .34975 L
s
.76706 .25405 m
.97619 .25405 L
.97619 .17186 L
.76706 .17186 L
.76706 .25405 L
s
.76706 .17186 m
.97619 .17186 L
.97619 .1088 L
.76706 .1088 L
.76706 .17186 L
s
.76706 .1088 m
.97619 .1088 L
.97619 .06916 L
.76706 .06916 L
.76706 .1088 L
s
.76706 .06916 m
.97619 .06916 L
.97619 .05563 L
.76706 .05563 L
.76706 .06916 L
s
.76706 .05563 m
.97619 .05563 L
.97619 .06916 L
.76706 .06916 L
.76706 .05563 L
s
.76706 .06916 m
.97619 .06916 L
.97619 .1088 L
.76706 .1088 L
.76706 .06916 L
s
.76706 .1088 m
.97619 .1088 L
.97619 .17186 L
.76706 .17186 L
.76706 .1088 L
s
.76706 .17186 m
.97619 .17186 L
.97619 .25405 L
.76706 .25405 L
.76706 .17186 L
s
.76706 .25405 m
.97619 .25405 L
.97619 .34975 L
.76706 .34975 L
.76706 .25405 L
s
.76706 .34975 m
.97619 .34975 L
.97619 .45246 L
.76706 .45246 L
.76706 .34975 L
s
.76706 .45246 m
.97619 .45246 L
.97619 .55517 L
.76706 .55517 L
.76706 .45246 L
s
.76706 .55517 m
.97619 .55517 L
.97619 .65087 L
.76706 .65087 L
.76706 .55517 L
s
.76706 .65087 m
.97619 .65087 L
.97619 .73306 L
.76706 .73306 L
.76706 .65087 L
s
.76706 .73306 m
.97619 .73306 L
.97619 .79612 L
.76706 .79612 L
.76706 .73306 L
s
.76706 .79612 m
.97619 .79612 L
.97619 .83576 L
.76706 .83576 L
.76706 .79612 L
s
.76706 .83576 m
.97619 .83576 L
.97619 .84929 L
.76706 .84929 L
.76706 .83576 L
s
.02381 .05563 m
.02381 .18791 L
.02381 .32019 L
.02381 .45246 L
.02381 .58474 L
.02381 .71701 L
.02381 .84929 L
.02381 .84929 L
.02381 .71701 L
.02381 .58474 L
.02381 .45246 L
.02381 .32019 L
.02381 .18791 L
.02381 .05563 L
.02381 .05563 L
s
.02381 .45246 m
.02381 .45246 L
.02381 .45246 L
.02381 .45246 L
.02381 .45246 L
.02381 .45246 L
.02381 .45246 L
.02381 .45246 L
.02381 .45246 L
.02381 .45246 L
.02381 .45246 L
.02381 .45246 L
.02381 .45246 L
.02381 .45246 L
.02381 .45246 L
s
.02381 .84929 m
.02381 .83576 L
.02381 .79612 L
.02381 .73306 L
.02381 .65087 L
.02381 .55517 L
.02381 .45246 L
.02381 .34975 L
.02381 .25405 L
.02381 .17186 L
.02381 .1088 L
.02381 .06916 L
.02381 .05563 L
.02381 .06916 L
.02381 .1088 L
.02381 .17186 L
.02381 .25405 L
.02381 .34975 L
.02381 .45246 L
.02381 .55517 L
.02381 .65087 L
.02381 .73306 L
.02381 .79612 L
.02381 .83576 L
.02381 .84929 L
s
.039 .916 .04 r
.42063 .29373 m
.8095 .29373 L
s
% Start of user PostScript
0 -10. 24.4987 -10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.8095 .29373 Mdot
.039 .916 .04 r
.5 Mabswid
.42063 .45246 m
.81746 .45246 L
s
% Start of user PostScript
0 0 25. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81746 .45246 Mdot
.039 .916 .04 r
.5 Mabswid
.42063 .61119 m
.8095 .61119 L
s
% Start of user PostScript
0 10. 24.4987 10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.8095 .61119 Mdot
.039 .916 .04 r
.5 Mabswid
.8095 .29373 m
.02381 .45327 L
s
% Start of user PostScript
24.4987 -10. -25. 0.0511486 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.02381 .45327 Mdot
.039 .916 .04 r
.5 Mabswid
.81746 .45246 m
.02381 .45246 L
s
% Start of user PostScript
25. 0 -25. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.02381 .45246 Mdot
.039 .916 .04 r
.5 Mabswid
.8095 .61119 m
.02381 .45165 L
s
% Start of user PostScript
24.4987 10. -25. -0.0511486 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.02381 .45165 Mdot
gsave
.89683 .02071 -67.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
71.875 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02381 .02071 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .87 L
0 .87 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[105]:=",
  ImageSize->{288, 250.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000nR000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`001Oooool3o`000?Cooooo0ol0
00000ooooooo0000ooooo`03o`0001_ooooo0005ooooo`04o`000?ooooooooooo`000?Cooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0Jooooo`002?ooool00ol0003ooooooooo
o`3booooo`07o`000?oooooo0000ooooool0003oooooo`00000Looooo`001_ooool2o`000?Gooooo
00Oo0000ooooool0003oooooo`000?oooooo000001cooooo0005ooooo`03o`000?oooooooooo0?Go
oooo0_l00003ooooo`;o00007?ooool000Gooooo00Co0000oooooooooooo0000m?ooool2o`0000?o
oooo0_l0000Looooo`001_ooool3o`000??ooooo0_l00005ooooo`;o00006oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool000Kooooo0_l0
003Dooooocgo00001oooool000Kooooo00?o0000ooooooooool0doooool00ol0003oOgmoogmoO`0i
ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmo
OomoOgl0>OmoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`;o
0000>_moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooocgo0000
1oooool000Kooooo00?o0000ooooooooool0doooool2o`0003[oOgmo00?o0000ooooooooool01Ooo
ool000Kooooo00?o0000ooooooooool0doooool2o`0003[oOgmo00?o0000ooooooooool01Oooool0
00Kooooo00?o0000ooooooooool0doooool2o`0003[oOgmo00?o0000ooooooooool01Oooool000Ko
oooo00?o0000ooooooooool0doooool00ol0003oOgmoo`00000iogmoO`03o`000?oooooooooo00Go
oooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOol00000>OmoOgl00ol0003ooooo
ooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgoo000003WoOgmo00?o
0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0doooool00ol0003oOgmoo`00000i
ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmo
Ool00000>OmoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`04
o`000?moOgooOgmoo`0003SoOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000oooooooo
ool0doooool01?l0003oOgmoogmoOol0000hogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03
o`000?oooooooooo0=?ooooo?Ol00007ooooo`001_ooool00ol0003oooooooooo`3Cooooo`04o`00
0?moOgooOgmoo`0003SoOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0
doooool01?l0003oOgmoogmoOol0000hogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`00
0?oooooooooo0=?ooooo00Go0000ogmoOomoOgooOgmoo`00000gogmoO`03o`000?oooooooooo00Go
oooo0006ooooo`03o`000?oooooooooo0=?ooooo00Go0000ogmoOomoOgooOgmoo`00000gogmoO`03
o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00Go0000ogmoOomoOgoo
Ogmoo`00000gogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo
00Go0000ogmoOomoOgooOgmoo`00000gogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`00
0?oooooooooo0=?ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0dogmoO`03o`00
0?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl00_mo
Ogl00ol0003oOgmoogmoO`0dogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooo
oooo0=?ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0dogmoO`03o`000?oooooo
oooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl00_moOgl00ol0
003oOgmoogmoO`0dogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?o
oooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0dogmoO`03o`000?oooooooooo00Go
oooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmo
ogmoO`0cogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o
0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`0cogmoO`03o`000?oooooooooo00Gooooo0006
ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`0c
ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmo
OomoOgl00omoOgl00ol0003oOgmoogmoO`0cogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03
o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`0cogmoO`03
o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl0
1?moOgl00ol0003oOgmoogmoO`0bogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oo
oooooooo0=?ooooo?Ol00007ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgoo
Ogmo00CoOgmo00?o0000ogmoOomoOgl0<_moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0
003oooooooooo`3Cooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl0<_moOgl00ol0
003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00Co
Ogmo00?o0000ogmoOomoOgl0<_moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003ooooo
ooooo`3Cooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl0<OmoOgl00ol0003ooooo
ooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00GoOgmo00?o
0000ogmoOomoOgl0<OmoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3C
ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl0<OmoOgl00ol0003oooooooooo`05
ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmo
OomoOgl0<OmoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03
o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl0<OmoOgl00ol0003oooooooooo`05ooooo`00
1_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl0
<OmoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?mo
OgooOgmo00GoOgmo00?o0000ogmoOomoOgl0<OmoOgl00ol0003oooooooooo`05ooooo`001_ooool0
0ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl0<?moOgl0
0ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo
00KoOgmo00?o0000ogmoOomoOgl0<?moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003o
ooooooooo`3Cooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl0<?moOgl00ol0003o
ooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00KoOgmo
00?o0000ogmoOomoOgl0<?moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003ooooooooo
o`3Cooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl0<?moOgl00ol0003ooooooooo
o`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00KoOgmo00?o0000
ogmoOomoOgl0<?moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Coooo
o`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl0<?moOgl00ol0003oooooooooo`05oooo
o`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomo
Ogl0<?moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`00
0?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl0<?moOgl00ol0003oooooooooo`05ooooo`001_oo
ool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl0;omo
Ogl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgoo
Ogmo00OoOgmo00?o0000ogmoOomoOgl0;omoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0
003oooooooooo`3Cooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl0;omoOgl00ol0
003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00Oo
Ogmo00?o0000ogmoOomoOgl0;omoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003ooooo
ooooo`3Cooooocgo00001oooool000Kooooo00?o0000ooooooooool0doooool00ol0003oOgmoogmo
O`07ogmoO`03o`000?moOgooOgmo02ooOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000
ooooooooool0doooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo02ooOgmo00?o0000
ooooooooool01Oooool000Kooooo00?o0000ooooooooool0doooool00ol0003oOgmoogmoO`07ogmo
O`03o`000?moOgooOgmo02ooOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000oooooooo
ool0doooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo02ooOgmo00?o0000oooooooo
ool01Oooool000Kooooo00?o0000ooooooooool0doooool00ol0003oOgmoogmoO`07ogmoO`03o`00
0?moOgooOgmo02ooOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0dooo
ool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo02koOgmo00?o0000ooooooooool01Ooo
ool000Kooooo00?o0000ooooooooool0doooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgoo
Ogmo02koOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0doooool00ol0
003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo02koOgmo00?o0000ooooooooool01Oooool000Ko
oooo00?o0000ooooooooool0doooool01?l0003oOgmoogmoOomoOgl3o`WZ2PCoOgmo00?o0000ogmo
OomoOgl0;_moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03
o`000?moOgooOgmo00;oOgmo1_l9jPX00ol0003oOgmoogmoO`0^ogmoO`03o`000?oooooooooo00Go
oooo0006ooooo`03o`000?oooooooooo06ooooooLOl9jPX_ogmoO`03o`000?oooooooooo00Gooooo
0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl00_moOgl5o`WZ2P03ogmoOol0
003o000002ooOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0doooool6
o`WZ2PGoOgmo00?o0000ogmoOomoOgl0;_moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0
003oooooooooo`3>ooooo`Go2NX:00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`0^ogmo
O`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0<Wooooo1Ol9jPX5ooooo`03
o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl0;OmoOgl00ol0003oooooooooo`05ooooo`00
1_ooool00ol0003oooooooooo`34ooooo`Go2NX:2_ooool00ol0003oOgmoogmoO`09ogmoO`03o`00
0?moOgooOgmo02goOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0_ooo
ool5o`WZ2Poooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0]ogmoO`03o`000?oo
oooooooo00Gooooo0006ooooo`03o`000?oooooooooo0;[ooooo1Ol9jPXDooooo`03o`000?moOgoo
Ogmo00WoOgmo00?o0000ogmoOomoOgl0;OmoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0
003oooooooooo`2eooooo`Go2NX:6Oooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo
02goOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0/?ooool5o`WZ2Qko
oooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0]ogmoO`03o`000?oooooooooo00Go
oooo0006ooooo`03o`000?oooooooooo0:_ooooo1Ol9jPXSooooo`03o`000?moOgooOgmo00WoOgmo
00?o0000ogmoOomoOgl0;OmoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003ooooooooo
o`2Vooooo`Go2NX::?ooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo02goOgmo00?o
0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0X_ooool4o`WZ2Rgooooo00?o0000
ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0]ogmoO`03o`000?oooooooooo00Gooooo0006oooo
o`03o`000?oooooooooo09gooooo1Ol9jPXaooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmo
OomoOgl0;OmoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`2Hooooo`Go
2NX:=_ooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo02goOgmo00?o0000oooooooo
ool01Oooool000Kooooo00?o0000ooooooooool0Toooool5o`WZ2S_ooooo00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oOgmoogmoO`0]ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oo
oooooooo08kooooo1Ol9jPY0ooooocgo00001oooool000Kooooo00?o0000ooooooooool0ROooool5
o`WZ2TGooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0]ogmoO`03o`000?oooooo
oooo00Gooooo0006ooooo`03o`000?oooooooooo08Cooooo1Ol9jPY:ooooo`03o`000?moOgooOgmo
00[oOgmo00?o0000ogmoOomoOgl0;?moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003o
ooooooooo`1oooooo`Go2NX:Coooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo02co
Ogmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0N_ooool5o`WZ2UCooooo
00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0/ogmoO`03o`000?oooooooooo00Gooooo
0006ooooo`03o`000?oooooooooo07Gooooo1Ol9jPYIooooo`03o`000?moOgooOgmo00[oOgmo00?o
0000ogmoOomoOgl0;?moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`1`
ooooo`Go2NX:G_ooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo02coOgmo00?o0000
ooooooooool01Oooool000Kooooo00?o0000ooooooooool0K?ooool4o`WZ2V?ooooo00?o0000ogmo
OomoOgl02_moOgl00ol0003oOgmoogmoO`0/ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03
o`000?oooooooooo06Oooooo1Ol9jPYWooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomo
Ogl0;?moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`1Rooooo`Go2NX:
K?ooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo02coOgmo00?o0000ooooooooool0
1Oooool000Kooooo00?o0000ooooooooool0GOooool5o`WZ2W7ooooo00?o0000ogmoOomoOgl02_mo
Ogl00ol0003oOgmoogmoO`0/ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooo
oooo05Sooooo1Ol9jPYfooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl0;?moOgl0
0ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`1Cooooo`Go2NX:Noooool00ol0
003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo02coOgmo00?o0000ooooooooool01Oooool000Ko
oooo00?o0000ooooooooool0C_ooool5o`WZ2X3ooooo00?o0000ogmoOomoOgl02_moOgl00ol0003o
OgmoogmoO`0/ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo04Wooooo
1Ol9jPZ5ooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl0;?moOgl00ol0003ooooo
ooooo`05ooooo`001_ooool00ol0003oooooooooo`14ooooo`Go2NX:R_ooool00ol0003oOgmoogmo
O`0:ogmoO`03o`000?moOgooOgmo02coOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000
ooooooooool0?oooool5o`WZ2Xoooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0/
ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo03[ooooo1Ol9jPZDoooo
o`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl0;?moOgl00ol0003oooooooooo`05oooo
o`001_ooool00ol0003oooooooooo`0eooooo`Go2NX:VOooool00ol0003oOgmoogmoO`0:ogmoO`03
o`000?moOgooOgmo02coOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0
<Oooool4o`WZ2Ykooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0/ogmoO`03o`00
0?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo02cooooo1Ol9jPZRooooo`03o`000?mo
OgooOgmo00[oOgmo00?o0000ogmoOomoOgl0;?moOgl00ol0003oooooooooo`05ooooo`001_ooool0
0ol0003oooooooooo`0Wooooo`Go2NX:Yoooool00ol0003oOgmoogmoO`0;ogmoO`03o`000?moOgoo
Ogmo02_oOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool08_ooool5o`WZ
2Zcooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0[ogmoO`03o`000?oooooooooo
00Gooooo0006ooooo`03o`000?oooooooooo01gooooo1Ol9jPZaooooo`03o`000?moOgooOgmo00_o
Ogmo00?o0000ogmoOomoOgl0:omoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003ooooo
ooooo`0Hooooo`Go2NX:]_ooool00ol0003oOgmoogmoO`0;ogmoO`03o`000?moOgooOgmo02_oOgmo
00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool04oooool5o`WZ2[_ooooo00?o
0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0[ogmoO`03o`000?oooooooooo00Gooooo0006
ooooo`03o`000?oooooooooo00kooooo1Ol9jP[0ooooo`03o`000?moOgooOgmo00_oOgmo00?o0000
ogmoOomoOgl0:omoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`04oooo
o`;o2NX:0oooool5o`WZ2/Gooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0[ogmo
O`03o`000?oooooooooo00Gooooo0006ooooo`04o`000?ooooooooooooooo`So2NX:b_ooool00ol0
003oOgmoogmoO`03ogmoO`?o2NX:1OmoOgl00ol0003oOgmoogmoO`0[ogmoO`03o`000?oooooooooo
00Gooooo0006ooooo`;o00002?l9jP[<ooooo`03o`000?moOgooOgmo00CoOgmo1_l9jPX00omoOgoo
0000o`00000/ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`;o0000hol9jPX^o`0000Oooooo
0006ooooo`;o00001ol9jP[=ooooo`03o`000?moOgooOgmo00CoOgmo1Ol9jPX2ogmoO`03o`000?mo
OgooOgmo02_oOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool00_ooool9
o`WZ2/Sooooo00?o0000ogmoOomoOgl00omoOgl2o`WZ2PKoOgmo00?o0000ogmoOomoOgl0:omoOgl0
0ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`05ooooo`03o`WZ2_oooooooooo
00?ooooo1Ol9jP[3ooooo`03o`000?moOgooOgmo00_oOgmo00?o0000ogmoOomoOgl0:omoOgl00ol0
003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`0@ooooo`Go2NX:__ooool00ol0003o
OgmoogmoO`0;ogmoO`03o`000?moOgooOgmo02_oOgmo00?o0000ooooooooool01Oooool000Kooooo
00?o0000ooooooooool05Oooool5o`WZ2[Wooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmo
ogmoO`0[ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo01[ooooo1Ol9
jPZdooooo`03o`000?moOgooOgmo00_oOgmo00?o0000ogmoOomoOgl0:omoOgl00ol0003ooooooooo
o`05ooooo`001_ooool00ol0003oooooooooo`0Oooooo`Go2NX:[oooool00ol0003oOgmoogmoO`0;
ogmoO`03o`000?moOgooOgmo02_oOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000oooo
ooooool09?ooool5o`WZ2Z[ooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0[ogmo
O`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo02Wooooo1Ol9jPZUooooo`03
o`000?moOgooOgmo00_oOgmo00?o0000ogmoOomoOgl0:omoOgl00ol0003oooooooooo`05ooooo`00
1_ooool00ol0003oooooooooo`0^ooooo`Go2NX:X?ooool00ol0003oOgmoogmoO`0iogmoO`03o`00
0?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo03?ooooo1Ol9jPZKooooo`03o`000?mo
OgooOgmo00[oOgmo00?o0000ogmoOomoOgl0;?moOgl00ol0003oooooooooo`05ooooo`001_ooool0
0ol0003oooooooooo`0hooooo`Go2NX:U_ooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgoo
Ogmo02coOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0?Oooool5o`WZ
2Y7ooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0/ogmoO`03o`000?oooooooooo
00Gooooo0006ooooo`03o`000?oooooooooo04;ooooo1Ol9jPZ<ooooo`03o`000?moOgooOgmo00[o
Ogmo00?o0000ogmoOomoOgl0;?moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003ooooo
ooooo`17ooooo`Go2NX:Qoooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo02coOgmo
00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0C?ooool5o`WZ2X;ooooo00?o
0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0/ogmoO`03o`000?oooooooooo00Gooooo0006
ooooo`03o`000?oooooooooo057ooooo1Ol9jPYmooooo`03o`000?moOgooOgmo00[oOgmo00?o0000
ogmoOomoOgl0;?moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`1Foooo
o`Go2NX:N?ooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo02coOgmo00?o0000oooo
ooooool01Oooool000Kooooo00?o0000ooooooooool0Foooool5o`WZ2W?ooooo00?o0000ogmoOomo
Ogl02_moOgl00ol0003oOgmoogmoO`0/ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`00
0?oooooooooo063ooooo1Ol9jPY^ooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl0
;?moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`1Uooooo`Go2NX:JOoo
ool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo02coOgmo00?o0000ooooooooool01Ooo
ool000Kooooo00?o0000ooooooooool0J_ooool5o`WZ2VCooooo00?o0000ogmoOomoOgl02_moOgl0
0ol0003oOgmoogmoO`0/ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo
06oooooo1Ol9jPYOooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl0;?moOgl00ol0
003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`1dooooo`Go2NX:F_ooool00ol0003o
OgmoogmoO`0:ogmoO`03o`000?moOgooOgmo02coOgmo00?o0000ooooooooool01Oooool000Kooooo
00?o0000ooooooooool0NOooool5o`WZ2UGooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmo
ogmoO`0/ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo07kooooo1Ol9
jPY@ooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl0;?moOgl00ol0003ooooooooo
o`05ooooo`001_ooool00ol0003oooooooooo`23ooooo`Go2NX:Boooool00ol0003oOgmoogmoO`0:
ogmoO`03o`000?moOgooOgmo02coOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000oooo
ooooool0R?ooool5o`WZ2TKooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0/ogmo
O`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo08gooooo1Ol9jPY1ooooocgo
00001oooool000Kooooo00?o0000ooooooooool0T_ooool5o`WZ2Scooooo00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oOgmoogmoO`0]ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oo
oooooooo09Oooooo1Ol9jPXgooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl0;Omo
Ogl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`2Looooo`Go2NX:<_ooool0
0ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo02goOgmo00?o0000ooooooooool01Oooool0
00Kooooo00?o0000ooooooooool0XOooool5o`WZ2Rgooooo00?o0000ogmoOomoOgl02OmoOgl00ol0
003oOgmoogmoO`0]ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0:Ko
oooo1Ol9jPXXooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl0;OmoOgl00ol0003o
ooooooooo`05ooooo`001_ooool00ol0003oooooooooo`2[ooooo`Go2NX:8oooool00ol0003oOgmo
ogmoO`09ogmoO`03o`000?moOgooOgmo02goOgmo00?o0000ooooooooool01Oooool000Kooooo00?o
0000ooooooooool0/?ooool5o`WZ2Qkooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmo
O`0]ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0;Gooooo1Ol9jPXI
ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl0;OmoOgl00ol0003oooooooooo`05
ooooo`001_ooool00ol0003oooooooooo`2jooooo`Go2NX:5?ooool00ol0003oOgmoogmoO`09ogmo
O`03o`000?moOgooOgmo02goOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000oooooooo
ool0_oooool5o`WZ2Poooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0]ogmoO`03
o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0<Cooooo1Ol9jPX:ooooo`03o`00
0?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl0;OmoOgl00ol0003oooooooooo`05ooooo`001_oo
ool00ol0003oooooooooo`39ooooo`Go2NX:1Oooool00ol0003oOgmoogmoO`09ogmoO`03o`000?mo
OgooOgmo02goOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0c_ooool5
o`WZ2P03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl0;OmoOgl00ol0003oooooooooo`05
ooooo`001_ooool00ol0003oooooooooo`3Cooooo`Oo2NX:1OmoOgl00ol0003oOgmoogmoO`0]ogmo
O`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomo
Ogl00_moOgl6o`WZ2S7oOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0
Kooooomao`WZ2RooOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0dooo
ool00ol0003oOgmoogmoO`02ogmoO`Go2NX:00?oOgmoo`000?l00000;omoOgl00ol0003ooooooooo
o`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`04o`000?moOgooOgmoogmoO`;o2NX:1Omo
Ogl00ol0003oOgmoogmoO`0^ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooo
oooo0=?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`0^ogmoO`03o`000?oooooo
oooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0
003oOgmoogmoO`0^ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?o
oooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`0^ogmoO`03o`000?oooooooooo00Go
oooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmo
ogmoO`0^ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o
0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`0^ogmoO`03o`000?oooooooooo00Gooooo0006
ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl0>OmoOgl00ol0003oooooooooo`05
ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmo
OomoOgl0;omoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03
o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl0;omoOgl00ol0003oooooooooo`05ooooo`00
1_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl0
;omoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooocgo00001ooo
ool000Kooooo00?o0000ooooooooool0doooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgoo
Ogmo02ooOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0doooool00ol0
003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo02ooOgmo00?o0000ooooooooool01Oooool000Ko
oooo00?o0000ooooooooool0doooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo02oo
Ogmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0doooool00ol0003oOgmo
ogmoO`07ogmoO`03o`000?moOgooOgmo02ooOgmo00?o0000ooooooooool01Oooool000Kooooo00?o
0000ooooooooool0doooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo02ooOgmo00?o
0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0doooool00ol0003oOgmoogmoO`0i
ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmo
OomoOgl01_moOgl00ol0003oOgmoogmoO`0`ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03
o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0`ogmoO`03
o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl0
1_moOgl00ol0003oOgmoogmoO`0`ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oo
oooooooo0=?ooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0`ogmoO`03o`000?oo
oooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl01_moOgl0
0ol0003oOgmoogmoO`0`ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo
0=?ooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0`ogmoO`03o`000?oooooooooo
00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl01_moOgl00ol0003o
OgmoogmoO`0`ogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo
00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0`ogmoO`03o`000?oooooooooo00Gooooo
0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl0>OmoOgl00ol0003ooooooooo
o`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00GoOgmo00?o0000
ogmoOomoOgl0<OmoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Coooo
o`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl0<OmoOgl00ol0003oooooooooo`05oooo
o`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomo
Ogl0<OmoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`00
0?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl0<OmoOgl00ol0003oooooooooo`05ooooo`001_oo
ool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl0<Omo
Ogl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgoo
Ogmo00GoOgmo00?o0000ogmoOomoOgl0<OmoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0
003oooooooooo`3Cooooo`03o`000?moOgooOgmo03WoOgmo00?o0000ooooooooool01Oooool000Ko
oooo00?o0000ooooooooool0dooooolmo`0000Oooooo0006ooooo`03o`000?oooooooooo0=?ooooo
00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`0bogmoO`03o`000?oooooooooo00Gooooo
0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmo
O`0bogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000
ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`0bogmoO`03o`000?oooooooooo00Gooooo0006oooo
o`03o`000?oooooooooo0=?ooooo00?o0000ogmoOomoOgl0>OmoOgl00ol0003oooooooooo`05oooo
o`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomo
Ogl0<omoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`00
0?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl0<omoOgl00ol0003oooooooooo`05ooooo`001_oo
ool00ol0003oooooooooo`3Cooooo`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl0<omo
Ogl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ogmoOomoOgl0<omoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0
003oooooooooo`3Cooooo`03o`000?moOgooOgmo03WoOgmo00?o0000ooooooooool01Oooool000Ko
oooo00?o0000ooooooooool0doooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo03Co
Ogmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0doooool00ol0003oOgmo
ogmoO`02ogmoO`03o`000?moOgooOgmo03CoOgmo00?o0000ooooooooool01Oooool000Kooooo00?o
0000ooooooooool0doooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo03CoOgmo00?o
0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0doooool00ol0003oOgmoogmoO`02
ogmoO`03o`000?moOgooOgmo03CoOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000oooo
ooooool0doooool00ol0003oOgmoogmoO`0iogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03
o`000?oooooooooo0=?ooooo00Go0000ogmoOomoOgooOgmoo`00000gogmoO`03o`000?oooooooooo
00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00Go0000ogmoOomoOgooOgmoo`00000gogmo
O`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00Go0000ogmoOomo
OgooOgmoo`00000gogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?o
oooo?Ol00007ooooo`001_ooool00ol0003oooooooooo`3Cooooo`04o`000?moOgooOgmoo`0003So
Ogmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0doooool01?l0003oOgmo
ogmoOol0000hogmoO`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo
00Co0000ogmoOomoOgoo0000>?moOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003ooooo
ooooo`3Cooooo`04o`000?moOgooOgmoo`0003SoOgmo00?o0000ooooooooool01Oooool000Kooooo
00?o0000ooooooooool0doooool00ol0003oOgmoogmoO`0iogmoO`03o`000?oooooooooo00Gooooo
0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOol00000>OmoOgl00ol0003ooooooooo
o`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`000?moOgoo000003WoOgmo00?o0000
ooooooooool01Oooool000Kooooo00?o0000ooooooooool0doooool00ol0003oOgmoo`00000iogmo
O`03o`000?oooooooooo00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo00?o0000ogmoOol0
0000>OmoOgl00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`3Cooooo`03o`00
0?moOgooOgmo03WoOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0dooo
ool2o`0003[oOgmo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0dooooolm
o`0000Oooooo0006ooooo`03o`000?oooooooooo0=?ooooo0_l0000jogmoO`03o`000?oooooooooo
00Gooooo0006ooooo`03o`000?oooooooooo0=?ooooo0_l0000jogmoO`03o`000?oooooooooo00Go
oooo0006ooooo`;o0000e?ooool00ol0003oOgmoogmoO`0iogmoO`03o`000?oooooooooo00Gooooo
0006ooooo`03o`000?oooooooooo0=?ooooo?Ol00007ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {249.5, 0}} -> {-26.5322, -28.519, 0.219737, \
0.219737}},
  CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],

Cell[BoxData[
    \({SymbolicOpticalLength \[Rule] 
        50 - d + \(50\ y\^2\)\/r\^2 - \(2\ d\ y\^2\)\/r\^2 + 
          y\^2\/r + \(100\ y\^4\)\/r\^4 - \(4\ d\ y\^4\)\/r\^4 + \(5\ \
y\^4\)\/\(4\ r\^3\), 
      SymbolicRayEnd \[Rule] {d, 
          y + \(50\ y\)\/r - \(2\ d\ y\)\/r + \(75\ y\^3\)\/r\^3 - \(3\ d\ \
y\^3\)\/r\^3 + 
            y\^3\/r\^2 + \(575\ y\^5\)\/\(4\ r\^5\) - \(23\ d\ y\^5\)\/\(4\ r\
\^5\) + \(7\ y\^5\)\/\(4\ r\^4\), 0}, 
      SymbolicRayTilt \[Rule] {\(-1\) + \(2\ y\^2\)\/r\^2, \(2\ y\)\/r - 
            y\^3\/r\^3 - y\^5\/\(4\ r\^5\), 0}, 
      SymbolicSurfaceCoordinates \[Rule] {y + \(50\ y\)\/r - \(2\ d\ y\)\/r + \
\(75\ y\^3\)\/r\^3 - \(3\ d\ y\^3\)\/r\^3 + 
            y\^3\/r\^2 + \(575\ y\^5\)\/\(4\ r\^5\) - \(23\ d\ y\^5\)\/\(4\ r\
\^5\) + \(7\ y\^5\)\/\(4\ r\^4\), 0}, 
      SymbolicIntensity \[Rule] 
        100\ \[ExponentialE]\^\(\(-\(y\^2\/625\)\) - \(y\^2\ \((\(-8\)\ \
\((\(-25\) + d)\)\ r\^4 + 4\ r\^5 - 12\ \((\(-25\) + d)\)\ r\^2\ y\^2 + 4\ \
r\^3\ y\^2 - 23\ \((\(-25\) + d)\)\ y\^4 + 7\ r\ y\^4)\)\^2\)\/\(10000\ r\^10\
\)\), SymbolicSurfaceBoundary \[Rule] {50, 50}, 
      SymbolicOffAxis \[Rule] {0, 0}, 
      SymbolicTranslationVector \[Rule] {d, 0, 0}, 
      SymbolicRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
      SymbolicWaveLength \[Rule] 133\/250, 
      SymbolicSurfaceNormalFunction \[Rule] {\(-1\), 0, 0}}\)], "Output",
  CellLabel->"Out[107]=",
  CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "When refraction is involved, the index model needs to be substituted for a \
pure fraction of integer numbers within ",
  StyleBox["SymbolicTrace", "Input"],
  " in order to maintain infinite precision. This example uses 3/2 for the ",
  StyleBox["BK7", "Input"],
  " refractive index and 1 as the value of ",
  StyleBox["Air", "Input"],
  ". For this, ",
  StyleBox["SymbolicTrace", "Input"],
  " takes the ",
  StyleBox["SymbolicRefractiveModels", "Input"],
  " as an option."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],

Cell[CellGroupData[{

Cell[TextData[{
  "?",
  StyleBox["SymbolicRefractiveModels", "Input"]
}], "Input",
  CellLabel->"In[47]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],

Cell[BoxData[
    \("SymbolicRefractiveModels -> {opticalmedium->symbolicexpression,...} is \
an option of TurboTrace and SymbolicTrace that provides a mechanism to \
replace pre-existing refractive index models with new models that contain \
user-defined symbolic parameters. \n\nIn this, each specified \
symbolicexpression holds the symbolic refractive index model to be exchanged \
with the pre-existing model identified by opticalmedium. See also: \
OpticalMedium."\)], "Print",
  CellTags->{
  "Info3312042871-8199869", "AOG2.", "AOG2.1", "AOG2.1.8", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
opticalSystem = {
\tMove[LineOfRays[20],{-50,{y,0}}],
\tSphericalLens[{r,50},Infinity,50,10],
\tMove[Screen[50],{d,100}]};
AnalyzeSystem[opticalSystem,PlotType->TopView];
SymbolicTrace[opticalSystem, \
{{y,0,5},{r>0}},SymbolicRefractiveModels->{BK7->3/2,Air->1}]\
\>", "Input",
  CellLabel->"In[99]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.192698 0.00634921 [
[.37302 .00857 -5.03125 -6 ]
[.37302 .00857 5.03125 6 ]
[.97619 .00857 -4.75 -6 ]
[.97619 .00857 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .36 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.3838 .03397 m
.40476 .03397 L
.40476 .08688 L
.35943 .08688 L
.3838 .03397 L
F
.35943 .08688 m
.40476 .08688 L
.40476 .13979 L
.34571 .13979 L
.35943 .08688 L
F
.34571 .13979 m
.40476 .13979 L
.40476 .1927 L
.34127 .1927 L
.34571 .13979 L
F
.34127 .1927 m
.40476 .1927 L
.40476 .24561 L
.34571 .24561 L
.34127 .1927 L
F
.34571 .24561 m
.40476 .24561 L
.40476 .29852 L
.35943 .29852 L
.34571 .24561 L
F
.35943 .29852 m
.40476 .29852 L
.40476 .35143 L
.3838 .35143 L
.35943 .29852 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.3838 .03397 m
.35943 .08688 L
.34571 .13979 L
.34127 .1927 L
.34571 .24561 L
.35943 .29852 L
.3838 .35143 L
.40476 .35143 L
.40476 .29852 L
.40476 .24561 L
.40476 .1927 L
.40476 .13979 L
.40476 .08688 L
.40476 .03397 L
.3838 .03397 L
s
.5 g
.3838 .1927 m
.40476 .1927 L
.40476 .1927 L
.35943 .1927 L
.3838 .1927 L
F
.35943 .1927 m
.40476 .1927 L
.40476 .1927 L
.34571 .1927 L
.35943 .1927 L
F
.34571 .1927 m
.40476 .1927 L
.40476 .1927 L
.34127 .1927 L
.34571 .1927 L
F
.34127 .1927 m
.40476 .1927 L
.40476 .1927 L
.34571 .1927 L
.34127 .1927 L
F
.34571 .1927 m
.40476 .1927 L
.40476 .1927 L
.35943 .1927 L
.34571 .1927 L
F
.35943 .1927 m
.40476 .1927 L
.40476 .1927 L
.3838 .1927 L
.35943 .1927 L
F
0 g
.3838 .1927 m
.35943 .1927 L
.34571 .1927 L
.34127 .1927 L
.34571 .1927 L
.35943 .1927 L
.3838 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.3838 .1927 L
s
.3838 .35143 m
.40476 .35143 L
.40476 .34602 L
.3838 .34602 L
.3838 .35143 L
s
.3838 .34602 m
.40476 .34602 L
.40476 .33016 L
.3838 .33016 L
.3838 .34602 L
s
.3838 .33016 m
.40476 .33016 L
.40476 .30494 L
.3838 .30494 L
.3838 .33016 L
s
.3838 .30494 m
.40476 .30494 L
.40476 .27206 L
.3838 .27206 L
.3838 .30494 L
s
.3838 .27206 m
.40476 .27206 L
.40476 .23378 L
.3838 .23378 L
.3838 .27206 L
s
.3838 .23378 m
.40476 .23378 L
.40476 .1927 L
.3838 .1927 L
.3838 .23378 L
s
.3838 .1927 m
.40476 .1927 L
.40476 .15162 L
.3838 .15162 L
.3838 .1927 L
s
.3838 .15162 m
.40476 .15162 L
.40476 .11333 L
.3838 .11333 L
.3838 .15162 L
s
.3838 .11333 m
.40476 .11333 L
.40476 .08046 L
.3838 .08046 L
.3838 .11333 L
s
.3838 .08046 m
.40476 .08046 L
.40476 .05523 L
.3838 .05523 L
.3838 .08046 L
s
.3838 .05523 m
.40476 .05523 L
.40476 .03938 L
.3838 .03938 L
.3838 .05523 L
s
.3838 .03938 m
.40476 .03938 L
.40476 .03397 L
.3838 .03397 L
.3838 .03938 L
s
.3838 .03397 m
.40476 .03397 L
.40476 .03938 L
.3838 .03938 L
.3838 .03397 L
s
.3838 .03938 m
.40476 .03938 L
.40476 .05523 L
.3838 .05523 L
.3838 .03938 L
s
.3838 .05523 m
.40476 .05523 L
.40476 .08046 L
.3838 .08046 L
.3838 .05523 L
s
.3838 .08046 m
.40476 .08046 L
.40476 .11333 L
.3838 .11333 L
.3838 .08046 L
s
.3838 .11333 m
.40476 .11333 L
.40476 .15162 L
.3838 .15162 L
.3838 .11333 L
s
.3838 .15162 m
.40476 .15162 L
.40476 .1927 L
.3838 .1927 L
.3838 .15162 L
s
.3838 .1927 m
.40476 .1927 L
.40476 .23378 L
.3838 .23378 L
.3838 .1927 L
s
.3838 .23378 m
.40476 .23378 L
.40476 .27206 L
.3838 .27206 L
.3838 .23378 L
s
.3838 .27206 m
.40476 .27206 L
.40476 .30494 L
.3838 .30494 L
.3838 .27206 L
s
.3838 .30494 m
.40476 .30494 L
.40476 .33016 L
.3838 .33016 L
.3838 .30494 L
s
.3838 .33016 m
.40476 .33016 L
.40476 .34602 L
.3838 .34602 L
.3838 .33016 L
s
.3838 .34602 m
.40476 .34602 L
.40476 .35143 L
.3838 .35143 L
.3838 .34602 L
s
.97619 .03397 m
.97619 .08688 L
.97619 .13979 L
.97619 .1927 L
.97619 .24561 L
.97619 .29852 L
.97619 .35143 L
.97619 .35143 L
.97619 .29852 L
.97619 .24561 L
.97619 .1927 L
.97619 .13979 L
.97619 .08688 L
.97619 .03397 L
.97619 .03397 L
s
.97619 .1927 m
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
s
.97619 .35143 m
.97619 .34602 L
.97619 .33016 L
.97619 .30494 L
.97619 .27206 L
.97619 .23378 L
.97619 .1927 L
.97619 .15162 L
.97619 .11333 L
.97619 .08046 L
.97619 .05523 L
.97619 .03938 L
.97619 .03397 L
.97619 .03938 L
.97619 .05523 L
.97619 .08046 L
.97619 .11333 L
.97619 .15162 L
.97619 .1927 L
.97619 .23378 L
.97619 .27206 L
.97619 .30494 L
.97619 .33016 L
.97619 .34602 L
.97619 .35143 L
s
.039 .916 .04 r
.02381 .12921 m
.34768 .12921 L
s
% Start of user PostScript
-50. -10. 1.01021 -10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34768 .12921 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1927 m
.34127 .1927 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25619 m
.34768 .25619 L
s
% Start of user PostScript
-50. 10. 1.01021 10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34768 .25619 Mdot
.039 .916 .04 r
.5 Mabswid
.34768 .12921 m
.40476 .13317 L
s
% Start of user PostScript
1.01021 -10. 10. -9.37588 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .13317 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .1927 m
.40476 .1927 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.34768 .25619 m
.40476 .25223 L
s
% Start of user PostScript
1.01021 10. 10. 9.37588 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .25223 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .13317 m
.97619 .19362 L
s
% Start of user PostScript
10. -9.37588 100. 0.145752 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19362 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .1927 m
.97619 .1927 L
s
% Start of user PostScript
10. 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .25223 m
.97619 .19177 L
s
% Start of user PostScript
10. 9.37588 100. -0.145752 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19177 Mdot
gsave
.37302 .00857 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00857 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .36 L
0 .36 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[99]:=",
  ImageSize->{288, 103.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ib000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00JOooool6o`000:7ooooo0ol0
000=ooooo`00J_ooool01Ol0003ooooooooooooooooo00000:7ooooo00Co0000oooooooooooo0000
3?ooool006[ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0:ooooo`00J_ooool0
0ol0003oooooooooo`2Tooooo`;o00003Oooool006[ooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`0=ooooo`00J_ooool00ol0003oooooooooo`2Sooooo`04o`000?ooooooooooo`00
00cooooo001Yooooo`?o0000YOooool3o`0000cooooo003oooooob7ooooo003oooooob7ooooo001_
ooooo`Oo0000W?ooool00ol0003oooooooooo`0;ooooo`00Koooool7o`0009cooooo00?o0000oooo
ooooool02oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooooooo
ool02oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
2oooool006gooooo00?o0000ogmoOol000001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001]ooooo`03o`000?moOgoo000000GoOgmo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0;ooooo`00K?ooool00ol0003oOgmoogmoO`07o`0009cooooo00?o0000oooo
ooooool02oooool006cooooo00Co0000ogmoOomoOgoo00001OmoOgl00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo00_ooooo001[ooooo`05o`000?moOgooOgmoogmoOol000001OmoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001[ooooo`05o`000?moOgooOgmoogmo
Ool000001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Zooooo`03
o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo00_ooooo001Zooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Yooooo`03o`000?mo
OgooOgmo00?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001Yooooo`03o`000?moOgooOgmo00?oOgmo1ol0002Looooo`03o`000?oooooo
oooo00_ooooo001Xooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Xooooo`03o`000?moOgooOgmo00Co
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_o
oooo001Xooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o
0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001W
ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmo
OomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Wooooo`03
o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?mo
OgooOgmo00KoOgmo1ol0002Looooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?moOgoo
Ogmo00KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooo
oooo00_ooooo001Mooooo`?o2NX:1_ooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo
00?oOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00G_ooool6o`WZ2P;o
oooo00?o0000ogmoOomoOgl01?moOgl3o`WZ2PGoOgmo00?o0000ooooooooool0V_ooool00ol0003o
ooooooooo`0;ooooo`003?oooomXo`WZ2P03ogmoOol0003ooooo09_ooooo00?o0000ooooooooool0
2oooool005kooooo1Ol9jPX2ooooo`;o00001omoOgl6o`WZ2P03o`000?l9jP[o2NX:00Co2NX:Uooo
ool00ol0003oooooooooo`0;ooooo`00GOooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01_moOgl5
o`WZ2P03ogmoOol0003o000000Gooooo2Ol9jPZ>ooooo`03o`000?oooooooooo00_ooooo001Uoooo
o`03o`000?moOgooOgmo00GoOgmo0_l9jPX00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo
00cooooo2Ol9jPZ5ooooo`03o`000?oooooooooo00_ooooo001Uooooo`03o`000?moOgooOgmo00Oo
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0Eooooo`Wo2NX:O?ooool00ol0003o
ooooooooo`0;ooooo`00IOooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00?oOgmo
00?o0000ooooooooool07_ooool:o`WZ2W;ooooo00?o0000ooooooooool02oooool006Gooooo00?o
0000ogmoOomoOgl01omoOgl7o`0002[ooooo2Ol9jPYYooooo`03o`000?oooooooooo00_ooooo001T
ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0a
ooooo`Wo2NX:H?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmo
O`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0>_ooool9o`WZ2UOooooo00?o0000oooo
ooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo04?ooooo2_l9jPY=ooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`00
0?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1=ooooo`Wo2NX:
A?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?mo
OgooOgmo00?oOgmo00?o0000ooooooooool0E_ooool9o`WZ2S_ooooo00?o0000ooooooooool02ooo
ool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo05oooooo2Ol9jPXbooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`000?moOgooOgmo
00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1Xooooo`Wo2NX::Oooool00ol0
003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0LOooool:o`WZ2Qoooooo00?o0000ooooooooool02oooool005_ooooo
0ol9jPX5ooooo`03o`000?moOgooOgmo00OoOgmo0ol9jPX5ogmoO`03o`000?oooooooooo07_ooooo
2Ol9jPX>ooooo`?o2NX:1Oooool00ol0003oooooooooo`0;ooooo`00G?ooool6o`WZ2P03ooooool0
003oOgmo00WoOgmo1_l9jPX00omoOgoo0000ooooo`25ooooo`Wo2NX:1Oooool7o`WZ2P03ooooool0
003ooooo00cooooo000<ooooofSo2NX:00?o0000o`WZ2_l9jPX0V_l9jPX2o`0000gooooo001Loooo
o`Go2NX:0_ooool2o`0000WoOgmo1Ol9jPX00omoOgoo0000o`00002>ooooo`go2NX:0_l0000=oooo
o`00Foooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01omoOgl2o`WZ2P03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0Poooool9o`WZ2PKooooo1?l9jPX4ooooo`03o`000?oooooooooo00_o
oooo001Sooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`1jooooo`Wo2NX:3oooool00ol9jP[oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo
001Sooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`1`ooooo`[o2NX:8?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08
ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0Ioooool9o`WZ2R[ooooo00?o0000
ooooooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo05kooooo2Ol9jPXcooooo`03o`000?oooooooooo00_ooooo001Tooooo`03
o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1Eooooo`Wo
2NX:??ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmoO`03o`00
0?moOgooOgmo00?oOgmo00?o0000ooooooooool0Boooool:o`WZ2TGooooo00?o0000ooooooooool0
2oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oo
oooooooo04;ooooo2Ol9jPY?ooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`000?moOgoo
Ogmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0iooooo`Wo2NX:F?ooool0
0ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo
00?oOgmo00?o0000ooooooooool0<?ooool9o`WZ2V7ooooo00?o0000ooooooooool02oooool006Go
oooo00?o0000ogmoOomoOgl01omoOgl7o`0002Wooooo2Ol9jPYZooooo`03o`000?oooooooooo00_o
oooo001Uooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`0Mooooo`[o2NX:Loooool00ol0003oooooooooo`0;ooooo`00IOooool00ol0003oOgmoogmo
O`07ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool05?ooool9o`WZ2Wgooooo00?o
0000ooooooooool02oooool006Gooooo00?o0000ogmoOomoOgl01OmoOgl3o`WZ2PGoOgmo00?o0000
ooooooooool02oooool9o`WZ2XKooooo00?o0000ooooooooool02oooool005gooooo0ol9jPX5oooo
o`03o`000?moOgooOgmo00KoOgmo1_l9jPX2o`0000Cooooo2Ol9jPZ?ooooo`03o`000?oooooooooo
00_ooooo001Nooooo`Ko2NX:00?oooooo`000?l000001_moOgl7o`WZ2P03o`000?l9jP[o2NX:00?o
2NX:V?ooool00ol0003oooooooooo`0;ooooo`003?oooomQo`WZ2P03ogmoOol9jP[o2NX:00?o2NX:
0_moOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Nooooo`Go2NX:0ooo
ool00ol0003oOgmoogmoO`04ogmoO`;o2NX:00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`2Jooooo`03o`000?oooooooooo00_ooooo001Mooooo`;o2NX:1oooool00ol0003oOgmoogmoO`06
ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;
ooooo`00I_ooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000oooo
ooooool0V_ooool00ol0003oooooooooo`0;ooooo`00I_ooool00ol0003oOgmoogmoO`06ogmoO`Oo
0000W?ooool00ol0003oooooooooo`0;ooooo`00Ioooool00ol0003oOgmoogmoO`05ogmoO`03o`00
0?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00Iooo
ool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_oo
ool00ol0003oooooooooo`0;ooooo`00Ioooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00Ioooool00ol0
003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0
003oooooooooo`0;ooooo`00Ioooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00J?ooool00ol0003oOgmo
ogmoO`04ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003ooooo
ooooo`0;ooooo`00J?ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00?oOgmo00?o
0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00J?ooool00ol0003oOgmoogmoO`04
ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;
ooooo`00J?ooool00ol0003oOgmoogmoO`04ogmoO`Oo0000W?ooool00ol0003oooooooooo`0;oooo
o`00JOooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000oooooooo
ool0V_ooool00ol0003oooooooooo`0;ooooo`00JOooool00ol0003oOgmoogmoO`03ogmoO`03o`00
0?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00J_oo
ool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0V_oo
ool00ol0003oooooooooo`0;ooooo`00J_ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00Joooool01Ol0
003oOgmoogmoOomoOgoo000000GoOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;
ooooo`00Joooool01Ol0003oOgmoogmoOomoOgoo000000GoOgmo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0;ooooo`00K?ooool00ol0003oOgmoogmoO`07o`0009cooooo00?o0000oooo
ooooool02oooool006cooooo00Co0000ogmoOomoOgoo00001OmoOgl00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo00_ooooo001]ooooo`03o`000?moOgoo000000GoOgmo00?o0000oooooooo
ool0V_ooool00ol0003oooooooooo`0;ooooo`00KOooool00ol0003oOgmoo`000005ogmoO`03o`00
0?oooooooooo09[ooooo00?o0000ooooooooool02oooool006kooooo0_l00005ogmoO`03o`000?oo
oooooooo09[ooooo00?o0000ooooooooool02oooool006kooooo2?l0002Looooo`03o`000?oooooo
oooo00_ooooo001_ooooo`Oo0000W?ooool00ol0003oooooooooo`0;ooooo`00oooooolQooooo`00
oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {102.625, 0}} -> {-57.2027, -32.4375, \
0.572841, 0.572841}},
  CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],

Cell[BoxData[
    \({SymbolicOpticalLength \[Rule] 
        55 + d - \(5\ y\^2\)\/\(12\ r\^2\) + \(d\ y\^2\)\/\(8\ r\^2\) - 
          y\^2\/\(4\ r\) - \(85\ y\^4\)\/\(192\ r\^4\) + \(41\ d\ \
y\^4\)\/\(384\ r\^4\) - \(5\ y\^4\)\/\(48\ r\^3\), 
      SymbolicRayEnd \[Rule] {d, 
          y + \(5\ y\)\/\(3\ r\) - \(d\ y\)\/\(2\ r\) + \(215\ y\^3\)\/\(216\ \
r\^3\) - \(11\ d\ y\^3\)\/\(48\ r\^3\) + 
            y\^3\/\(6\ r\^2\) + \(2885\ y\^5\)\/\(3456\ r\^5\) - \(1121\ d\ y\
\^5\)\/\(6912\ r\^5\) + \(23\ y\^5\)\/\(216\ r\^4\), 0}, 
      SymbolicRayTilt \[Rule] {1 - 
            y\^2\/\(8\ r\^2\) - \(35\ y\^4\)\/\(384\ r\^4\), \(-\(y\/\(2\ r\)\
\)\) - y\^3\/\(6\ r\^3\) - \(19\ y\^5\)\/\(216\ r\^5\), 0}, 
      SymbolicSurfaceCoordinates \[Rule] {y + \(5\ y\)\/\(3\ r\) - \(d\ y\)\/\
\(2\ r\) + \(215\ y\^3\)\/\(216\ r\^3\) - \(11\ d\ y\^3\)\/\(48\ r\^3\) + 
            y\^3\/\(6\ r\^2\) + \(2885\ y\^5\)\/\(3456\ r\^5\) - \(1121\ d\ y\
\^5\)\/\(6912\ r\^5\) + \(23\ y\^5\)\/\(216\ r\^4\), 0}, 
      SymbolicIntensity \[Rule] 
        100\ \[ExponentialE]\^\(\(-\(y\^2\/625\)\) - \(y\^2\ \((\(-720\)\ \
r\^4 + 216\ r\^5 - 280\ r\^2\ y\^2 + 36\ r\^3\ y\^2 - 170\ y\^4 + 23\ r\ \
y\^4)\)\^2\)\/\(29160000\ r\^10\) - \(y\^2\ \((\(-1152\)\ \((\(-10\) + 3\ \
d)\)\ r\^4 + 6912\ r\^5 - 16\ \((\(-430\) + 99\ d)\)\ r\^2\ y\^2 + 1152\ r\^3\
\ y\^2 + \((5770 - 1121\ d)\)\ y\^4 + 736\ r\ y\^4)\)\^2\)\/\(29859840000\ \
r\^10\)\), SymbolicSurfaceBoundary \[Rule] {50, 50}, 
      SymbolicOffAxis \[Rule] {0, 0}, 
      SymbolicTranslationVector \[Rule] {d, 0, 0}, 
      SymbolicRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
      SymbolicWaveLength \[Rule] 133\/250, 
      SymbolicSurfaceNormalFunction \[Rule] {1, 0, 0}}\)], "Output",
  CellLabel->"Out[101]=",
  CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "In this example, the original component medium, ",
  StyleBox["BK7", "Input"],
  ", is replaced with ",
  StyleBox["3/2", "Input"],
  ", and surrounding intrinsic medium, ",
  StyleBox["Air", "Input"],
  ", is replaced with ",
  StyleBox["1", "Input"],
  ". We can also specify the level of precision with the ",
  StyleBox["Precision", "Input"],
  " option of ",
  StyleBox["SymbolicTrace", "Input"],
  "."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.8"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2 Symbolic Optimization", "Subsection",
  CellTags->{"AOG0.", "2.2", "AOG2.", "AOG2.2"}],

Cell[TextData[{
  "In this section, we will consider how to use ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " for symbolic optimization purposes. In particular, we will examine \
several different examples that illustrate some ways that symbolic \
optimization can be carried out with ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ". Unlike numeric optimization procedures, symbolic raises the possibility \
of the finding the global minimum automatically."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2"}],

Cell[CellGroupData[{

Cell["Infinite-Conjugate Spherical Lens Design", "Subsubsection",
  CellTags->{"AOG0.", "2.2.1", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[TextData[{
  "In this example, we find the optimal parameters for spherical lens system \
that focusses a plane wave onto a point at a surface. We first use \
SymbolicTrace to calculate a symbolic solution of a symbolic ray transversing \
through the system for different lens curvatures (represented by symbolic \
parameters ",
  StyleBox["c1", "Input"],
  " and ",
  StyleBox["c2", "Input"],
  ") and different transverse ",
  StyleBox["y", "Input"],
  " positions of ray entry into the lens. First we define the optical system. \
In order to make the solution more clean, we assign integer values to the \
refractive index parameters of the system."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell["Clear[y,c1,c2];", "Input",
  CellLabel->"In[51]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell["\<\
opticalsystem = {
\tMove[LineOfRays[10, IntrinsicMedium->1],{-20,{y,0}}],
\tSphericalLens[{1/c1,35},{1/c2,-55},30,10,ComponentMedium->3/2],
\tMove[Screen[30],50]};\
\>", "Input",
  CellLabel->"In[52]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell["\<\
Here is a numeric ray-trace of the system. Note that we have the trace is not \
optimized but instead uses the numeric assignments made to the optical system \
during its initial definition.\
\>", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["\<\
plot = TurboPlot[opticalsystem,PlotType->TopView, ShowArrows->True, \
EmbedRays->False];\
\>", "Input",
  CellLabel->"In[53]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42857 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.295918 0.0136054 0.214286 0.0136054 [
[ 0 0 0 0 ]
[ 1 .42857 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.34187 .0102 m
.40361 .0102 L
.4195 .07823 L
.31577 .07823 L
.34187 .0102 L
F
.31577 .07823 m
.4195 .07823 L
.42887 .14626 L
.3008 .14626 L
.31577 .07823 L
F
.3008 .14626 m
.42887 .14626 L
.43197 .21429 L
.29592 .21429 L
.3008 .14626 L
F
.29592 .21429 m
.43197 .21429 L
.42887 .28231 L
.3008 .28231 L
.29592 .21429 L
F
.3008 .28231 m
.42887 .28231 L
.4195 .35034 L
.31577 .35034 L
.3008 .28231 L
F
.31577 .35034 m
.4195 .35034 L
.40361 .41837 L
.34187 .41837 L
.31577 .35034 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.34187 .0102 m
.31577 .07823 L
.3008 .14626 L
.29592 .21429 L
.3008 .28231 L
.31577 .35034 L
.34187 .41837 L
.40361 .41837 L
.4195 .35034 L
.42887 .28231 L
.43197 .21429 L
.42887 .14626 L
.4195 .07823 L
.40361 .0102 L
.34187 .0102 L
s
.5 g
.34187 .21429 m
.40361 .21429 L
.4195 .21429 L
.31577 .21429 L
.34187 .21429 L
F
.31577 .21429 m
.4195 .21429 L
.42887 .21429 L
.3008 .21429 L
.31577 .21429 L
F
.3008 .21429 m
.42887 .21429 L
.43197 .21429 L
.29592 .21429 L
.3008 .21429 L
F
.29592 .21429 m
.43197 .21429 L
.42887 .21429 L
.3008 .21429 L
.29592 .21429 L
F
.3008 .21429 m
.42887 .21429 L
.4195 .21429 L
.31577 .21429 L
.3008 .21429 L
F
.31577 .21429 m
.4195 .21429 L
.40361 .21429 L
.34187 .21429 L
.31577 .21429 L
F
0 g
.34187 .21429 m
.31577 .21429 L
.3008 .21429 L
.29592 .21429 L
.3008 .21429 L
.31577 .21429 L
.34187 .21429 L
.40361 .21429 L
.4195 .21429 L
.42887 .21429 L
.43197 .21429 L
.42887 .21429 L
.4195 .21429 L
.40361 .21429 L
.34187 .21429 L
s
.34187 .41837 m
.40361 .41837 L
.40361 .41141 L
.34187 .41141 L
.34187 .41837 L
s
.34187 .41141 m
.40361 .41141 L
.40361 .39103 L
.34187 .39103 L
.34187 .41141 L
s
.34187 .39103 m
.40361 .39103 L
.40361 .35859 L
.34187 .35859 L
.34187 .39103 L
s
.34187 .35859 m
.40361 .35859 L
.40361 .31633 L
.34187 .31633 L
.34187 .35859 L
s
.34187 .31633 m
.40361 .31633 L
.40361 .26711 L
.34187 .26711 L
.34187 .31633 L
s
.34187 .26711 m
.40361 .26711 L
.40361 .21429 L
.34187 .21429 L
.34187 .26711 L
s
.34187 .21429 m
.40361 .21429 L
.40361 .16147 L
.34187 .16147 L
.34187 .21429 L
s
.34187 .16147 m
.40361 .16147 L
.40361 .11224 L
.34187 .11224 L
.34187 .16147 L
s
.34187 .11224 m
.40361 .11224 L
.40361 .06998 L
.34187 .06998 L
.34187 .11224 L
s
.34187 .06998 m
.40361 .06998 L
.40361 .03755 L
.34187 .03755 L
.34187 .06998 L
s
.34187 .03755 m
.40361 .03755 L
.40361 .01716 L
.34187 .01716 L
.34187 .03755 L
s
.34187 .01716 m
.40361 .01716 L
.40361 .0102 L
.34187 .0102 L
.34187 .01716 L
s
.34187 .0102 m
.40361 .0102 L
.40361 .01716 L
.34187 .01716 L
.34187 .0102 L
s
.34187 .01716 m
.40361 .01716 L
.40361 .03755 L
.34187 .03755 L
.34187 .01716 L
s
.34187 .03755 m
.40361 .03755 L
.40361 .06998 L
.34187 .06998 L
.34187 .03755 L
s
.34187 .06998 m
.40361 .06998 L
.40361 .11224 L
.34187 .11224 L
.34187 .06998 L
s
.34187 .11224 m
.40361 .11224 L
.40361 .16147 L
.34187 .16147 L
.34187 .11224 L
s
.34187 .16147 m
.40361 .16147 L
.40361 .21429 L
.34187 .21429 L
.34187 .16147 L
s
.34187 .21429 m
.40361 .21429 L
.40361 .26711 L
.34187 .26711 L
.34187 .21429 L
s
.34187 .26711 m
.40361 .26711 L
.40361 .31633 L
.34187 .31633 L
.34187 .26711 L
s
.34187 .31633 m
.40361 .31633 L
.40361 .35859 L
.34187 .35859 L
.34187 .31633 L
s
.34187 .35859 m
.40361 .35859 L
.40361 .39103 L
.34187 .39103 L
.34187 .35859 L
s
.34187 .39103 m
.40361 .39103 L
.40361 .41141 L
.34187 .41141 L
.34187 .39103 L
s
.34187 .41141 m
.40361 .41141 L
.40361 .41837 L
.34187 .41837 L
.34187 .41141 L
s
.97619 .0102 m
.97619 .07823 L
.97619 .14626 L
.97619 .21429 L
.97619 .28231 L
.97619 .35034 L
.97619 .41837 L
.97619 .41837 L
.97619 .35034 L
.97619 .28231 L
.97619 .21429 L
.97619 .14626 L
.97619 .07823 L
.97619 .0102 L
.97619 .0102 L
s
.97619 .21429 m
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
s
.97619 .41837 m
.97619 .41141 L
.97619 .39103 L
.97619 .35859 L
.97619 .31633 L
.97619 .26711 L
.97619 .21429 L
.97619 .16147 L
.97619 .11224 L
.97619 .06998 L
.97619 .03755 L
.97619 .01716 L
.97619 .0102 L
.97619 .01716 L
.97619 .03755 L
.97619 .06998 L
.97619 .11224 L
.97619 .16147 L
.97619 .21429 L
.97619 .26711 L
.97619 .31633 L
.97619 .35859 L
.97619 .39103 L
.97619 .41141 L
.97619 .41837 L
s
.039 .916 .04 r
.02381 .14626 m
.3008 .14626 L
s
% Start of user PostScript
-20. -5. 0.358984 -5. MAarrowhead1
% End of user PostScript
0 0 0 r
2.5 Mabswid
.3008 .14626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21429 m
.29592 .21429 L
s
% Start of user PostScript
-20. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2.5 Mabswid
.29592 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28231 m
.3008 .28231 L
s
% Start of user PostScript
-20. 5. 0.358984 5. MAarrowhead1
% End of user PostScript
0 0 0 r
2.5 Mabswid
.3008 .28231 Mdot
.039 .916 .04 r
.5 Mabswid
.3008 .14626 m
.42941 .15243 L
s
% Start of user PostScript
0.358984 -5. 9.81178 -4.54625 MAarrowhead1
% End of user PostScript
0 0 0 r
2.5 Mabswid
.42941 .15243 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21429 m
.43197 .21429 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2.5 Mabswid
.43197 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.3008 .28231 m
.42941 .27614 L
s
% Start of user PostScript
0.358984 5. 9.81178 4.54625 MAarrowhead1
% End of user PostScript
0 0 0 r
2.5 Mabswid
.42941 .27614 Mdot
.039 .916 .04 r
.5 Mabswid
.42941 .15243 m
.97619 .21505 L
s
% Start of user PostScript
9.81178 -4.54625 50. 0.0565355 MAarrowhead1
% End of user PostScript
0 0 0 r
2.5 Mabswid
.97619 .21505 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21429 m
.97619 .21429 L
s
% Start of user PostScript
10. 0 50. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.42941 .27614 m
.97619 .21352 L
s
% Start of user PostScript
9.81178 4.54625 50. -0.0565355 MAarrowhead1
% End of user PostScript
0 0 0 r
2.5 Mabswid
.97619 .21352 Mdot
0 0 m
1 0 L
1 .42857 L
0 .42857 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[53]:=",
  ImageSize->{288, 123.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Nb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00H_oooolBo`000:?ooooo00?o0000ooooooooool0
1_ooool006;ooooo00?o0000ogmoOomoOgl03_moOgl00ol0003oooooooooo`2Qooooo`03o`000?oo
oooooooo00Kooooo001Qoooooa?o0000Xoooool00ol0003oooooooooo`06ooooo`00HOooool2o`00
013oOgmo0_l0002Rooooo`03o`000?oooooooooo00Kooooo001Qooooo`;o00004?moOgl2o`000:;o
oooo00?o0000ooooooooool01_ooool0063ooooo00?o0000ogmoOol000004?moOgl2o`000:;ooooo
00?o0000ooooooooool01_ooool0063ooooo00?o0000ogmoOol000004?moOgl2o`000:;ooooo00?o
0000ooooooooool01_ooool005oooooo00Co0000ogmoOomoOgoo00004?moOgl00ol0003oOgmoo`00
002Qooooo`03o`000?oooooooooo00Kooooo001Oooooo`03o`000?moOgooOgmo01;o000000?oOgmo
o`000?ooool0X?ooool00ol0003oooooooooo`06ooooo`00G_ooool01Ol0003oOgmoogmoOomoOgoo
0000013oOgmo00?o0000ogmoOol00000XOooool00ol0003oooooooooo`06ooooo`00G_ooool01Ol0
003oOgmoogmoOomoOgoo0000013oOgmo00Co0000ogmoOomoOgoo0000X?ooool00ol0003ooooooooo
o`06ooooo`00G_ooool01Ol0003oOgmoogmoOomoOgoo0000013oOgmo00Co0000ogmoOomoOgoo0000
X?ooool00ol0003oooooooooo`06ooooo`00GOooool00ol0003oOgmoogmoO`02ogmoO`03o`000?mo
OgooOgmo00koOgmo00Co0000ogmoOomoOgoo0000X?ooool00ol0003oooooooooo`06ooooo`00GOoo
ool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00koOgmo00Co0000ogmoOomoOgoo0000
X?ooool00ol0003oooooooooo`06ooooo`00G?ooool00ol0003oOgmoogmoO`03ogmoO`03o`000?mo
OgooOgmo00koOgmo00Go0000ogmoOomoOgooOgmoo`00002Oooooo`03o`000?oooooooooo00Kooooo
001Looooo`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl03_moOgl01Ol0003oOgmoogmo
OomoOgoo000009oooooo00?o0000ooooooooool01_ooool005_ooooo00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oOgmoogmoO`0>ogmoO`05o`000?moOgooOgmoogmoOol00000Woooool00ol0003ooooo
ooooo`06ooooo`00Foooool00ol0003oOgmoogmoO`04ogmoOa;o00000omoOgl00ol0003ooooooooo
o`2Mooooo`03o`000?oooooooooo00Kooooo001Kooooo`03o`000?moOgooOgmo00CoOgmo00?o0000
ogmoOomoOgl03_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo09cooooo00?o0000
ooooooooool01_ooool005[ooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`0>ogmo
O`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`06oooo
o`00F_ooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomo
Ogl00_moOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00Kooooo001Jooooo`03o`00
0?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`00
0?oooooooooo09cooooo00?o0000ooooooooool01_ooool005Wooooo00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0W?oo
ool00ol0003oooooooooo`06ooooo`00FOooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgoo
Ogmo00koOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Kooooo`03o`000?oooooo
oooo00Kooooo001Iooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl03_moOgl00ol0
003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool005Wo
oooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0Voooool00ol0003oooooooooo`06ooooo`00FOooool00ol0003oOgmo
ogmoO`06ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`2Kooooo`03o`000?oooooooooo00Kooooo001Hooooo`03o`000?moOgooOgmo00OoOgmo00?o
0000ogmoOomoOgl03_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09_ooooo00?o
0000ooooooooool01_ooool005Sooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`0>
ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0Voooool00ol0003oooooooooo`06
ooooo`00F?ooool00ol0003oOgmoogmoO`07ogmoOa;o00001OmoOgl00ol0003oooooooooo`2Koooo
o`03o`000?oooooooooo00Kooooo001Hooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomo
Ogl03_moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooooooo
ool01_ooool005Sooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`0>ogmoO`03o`00
0?moOgooOgmo00CoOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`06ooooo`00Eooo
ool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00Kooooo001Gooooo`03o`000?moOgoo
Ogmo00SoOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooo
oooo09[ooooo00?o0000ooooooooool01_ooool005Oooooo00?o0000ogmoOomoOgl02?moOgl00ol0
003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0V_ooool00ol0
003oooooooooo`06ooooo`00Eoooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00ko
Ogmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00Ko
oooo001Gooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003oOgmo
ogmoO`04ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool01_ooool004kooooo0ol9
jPX5ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003oOgmoogmo
O`05ogmoO`03o`000?oooooooooo09Wooooo00?o0000ooooooooool01_ooool004oooooo1_l9jPX0
0ooooooo0000ogmoO`0:ogmoO`03o`000?moOgooOgmo00koOgmo0_l9jPX6ogmoO`03o`000?oooooo
oooo09Wooooo00?o0000ooooooooool01_ooool000OoooooC_l9jPX00ol0003o2NX:o`WZ2P08o`WZ
2P;oOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003o2NX:o`WZ2P02o`WZ2P?oOgmo00?o0000oooo
ooooool0VOooool00ol0003oooooooooo`06ooooo`00Coooool5o`WZ2P03ooooool0003o000000Wo
Ogmo4ol9jPX00ol0003oOgmoo`WZ2P04o`WZ2P;o0000Voooool00ol0003oooooooooo`06ooooo`00
C_ooool2o`WZ2PKooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0>ogmoO`Oo2NX:
00?o0000o`WZ2_l9jPX00ol9jPZGooooo`03o`000?oooooooooo00Kooooo001Fooooo`03o`000?mo
OgooOgmo00WoOgmo00?o0000ogmoOomoOgl03_moOgl4o`WZ2PCoOgmo00?o0000ooooooooool00_oo
ool9o`WZ2Xkooooo00?o0000ooooooooool01_ooool005Kooooo00?o0000ogmoOomoOgl02OmoOglB
o`0000OoOgmo00?o0000ooooooooool02oooool9o`WZ2XGooooo00?o0000ooooooooool01_ooool0
05Kooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo
00GoOgmo00?o0000ooooooooool05?ooool8o`WZ2Wgooooo00?o0000ooooooooool01_ooool005Ko
oooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00Go
Ogmo00?o0000ooooooooool07?ooool9o`WZ2WCooooo00?o0000ooooooooool01_ooool005Kooooo
00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00GoOgmo
00?o0000ooooooooool09Oooool9o`WZ2V_ooooo00?o0000ooooooooool01_ooool005Kooooo00?o
0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00GoOgmo00?o
0000ooooooooool0;_ooool8o`WZ2V?ooooo00?o0000ooooooooool01_ooool005Kooooo00?o0000
ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000
ooooooooool0=_ooool9o`WZ2U[ooooo00?o0000ooooooooool01_ooool005Gooooo00?o0000ogmo
OomoOgl02_moOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000oooo
ooooool0?_ooool9o`WZ2U7ooooo00?o0000ooooooooool01_ooool005Gooooo00?o0000ogmoOomo
Ogl02_moOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000oooooooo
ool0Aoooool8o`WZ2TWooooo00?o0000ooooooooool01_ooool005Gooooo00?o0000ogmoOomoOgl0
2_moOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0
Coooool9o`WZ2T3ooooo00?o0000ooooooooool01_ooool005Gooooo00?o0000ogmoOomoOgl02_mo
Ogl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0F?oo
ool9o`WZ2SOooooo00?o0000ooooooooool01_ooool005Gooooo00?o0000ogmoOomoOgl02_moOgl0
0ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0HOooool8
o`WZ2Roooooo00?o0000ooooooooool01_ooool005Gooooo00?o0000ogmoOomoOgl02_moOgl00ol0
003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0JOooool9o`WZ
2RKooooo00?o0000ooooooooool01_ooool005Gooooo00?o0000ogmoOomoOgl02_moOgl00ol0003o
OgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0L_ooool9o`WZ2Qgo
oooo00?o0000ooooooooool01_ooool004gooooo0ol9jPX5ooooo`03o`000?moOgooOgmo00[oOgmo
00?o0000ogmoOomoOgl03_moOgl01?l0003o2NX:o`WZ2_l9jPX5ogmoO`03o`000?oooooooooo07_o
oooo2?l9jPX=ooooo`?o2NX:1Oooool00ol0003oooooooooo`06ooooo`00C_ooool6o`WZ2P03oooo
ool0003oOgmo00_oOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003oOgmoo`WZ2P05o`WZ2P03ogmo
Ool0003ooooo08Cooooo2Ol9jPX4ooooo`Oo2NX:00?oooooo`000?ooool01oooool000OoooooCOl9
jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:09So2NX:0_l00008ooooo`00C_ooool5
o`WZ2P03ooooool0003o000000coOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003oOgmoo`WZ2P04
o`WZ2P03ogmoOol0003o000008gooooo3?l9jPX2o`0000Sooooo001=ooooo`;o2NX:1_ooool00ol0
003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000o`WZ2_l9jPX01_moOgl00ol0
003oooooooooo`22ooooo`Wo2NX:1Oooool4o`WZ2PCooooo00?o0000ooooooooool01_ooool005Go
oooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00Ko
Ogmo00?o0000ooooooooool0N_ooool8o`WZ2Pkooooo00?o2NX:ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`00EOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00koOgmo
00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`1aooooo`Wo2NX:7_ooool00ol0003ooooo
ooooo`06ooooo`00EOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00koOgmo00?o
0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`1Xooooo`Wo2NX:9oooool00ol0003ooooooooo
o`06ooooo`00EOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000
ogmoOomoOgl01_moOgl00ol0003oooooooooo`1Pooooo`So2NX:<?ooool00ol0003oooooooooo`06
ooooo`00EOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmo
OomoOgl01_moOgl00ol0003oooooooooo`1Gooooo`Wo2NX:>?ooool00ol0003oooooooooo`06oooo
o`00EOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomo
Ogl01_moOgl00ol0003oooooooooo`1>ooooo`Wo2NX:@Oooool00ol0003oooooooooo`06ooooo`00
EOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl0
1_moOgl00ol0003oooooooooo`16ooooo`So2NX:B_ooool00ol0003oooooooooo`06ooooo`00EOoo
ool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oooooooooo`0mooooo`Wo2NX:D_ooool00ol0003oooooooooo`06ooooo`00E_ooool0
0ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oooooooooo`0eooooo`Wo2NX:Foooool00ol0003oooooooooo`06ooooo`00E_ooool00ol0
003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0
003oooooooooo`0]ooooo`So2NX:I?ooool00ol0003oooooooooo`06ooooo`00E_ooool00ol0003o
OgmoogmoO`09ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003o
ooooooooo`0Tooooo`Wo2NX:K?ooool00ol0003oooooooooo`06ooooo`00E_ooool00ol0003oOgmo
ogmoO`09ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003ooooo
ooooo`0Kooooo`Wo2NX:MOooool00ol0003oooooooooo`06ooooo`00E_ooool00ol0003oOgmoogmo
O`09ogmoOa;o00001omoOgl00ol0003oooooooooo`0Cooooo`So2NX:O_ooool00ol0003ooooooooo
o`06ooooo`00E_ooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00koOgmo0ol9jPX5
ogmoO`03o`000?oooooooooo00[ooooo2Ol9jPZ6ooooo`03o`000?oooooooooo00Kooooo001Foooo
o`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003o2NX:o`WZ2P04o`WZ
2P03ogmoOol0003ooooo00;ooooo2Ol9jPZ?ooooo`03o`000?oooooooooo00Kooooo001>ooooo`?o
2NX:1Oooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00goOgmo2?l9jPX00ol0003o
2NX:o`WZ2P02o`WZ2YSooooo00?o0000ooooooooool01_ooool004oooooo1_l9jPX2o`0000SoOgmo
4ol9jPX00omoOgoo0000o`WZ2P04o`WZ2P03ogmoOol0003o000009_ooooo00?o0000ooooooooool0
1_ooool000OoooooC_l9jPX00ol0003o2NX:o`WZ2P07o`WZ2P?oOgmo00?o0000ogmoOomoOgl03_mo
Ogl2o`WZ2PKoOgmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`06ooooo`00Coooool5
o`WZ2P;ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgoo
Ogmo00GoOgmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`06ooooo`00C_ooool2o`WZ
2PKooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo
00GoOgmo00?o0000ooooooooool0VOooool00ol0003oooooooooo`06ooooo`00Eoooool00ol0003o
OgmoogmoO`08ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003o
ooooooooo`2Iooooo`03o`000?oooooooooo00Kooooo001Gooooo`03o`000?moOgooOgmo00SoOgmo
00?o0000ogmoOomoOgl03_moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo09[ooooo
00?o0000ooooooooool01_ooool005Oooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmo
O`0>ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0V_ooool00ol0003ooooooooo
o`06ooooo`00Eoooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000
ogmoOomoOgl01?moOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00Kooooo001Goooo
o`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003oOgmoogmoO`04ogmo
O`03o`000?oooooooooo09[ooooo00?o0000ooooooooool01_ooool005Sooooo00?o0000ogmoOomo
Ogl01omoOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000oooooooo
ool0V_ooool00ol0003oooooooooo`06ooooo`00F?ooool00ol0003oOgmoogmoO`07ogmoOa;o0000
1_moOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00Kooooo001Hooooo`03o`000?mo
OgooOgmo00OoOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oo
oooooooo09_ooooo00?o0000ooooooooool01_ooool005Sooooo00?o0000ogmoOomoOgl01omoOgl0
0ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0Voooool0
0ol0003oooooooooo`06ooooo`00F?ooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo
00koOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
00Kooooo001Iooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003o
OgmoogmoO`03ogmoO`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool005Wooooo
00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00?oOgmo
00?o0000ooooooooool0Voooool00ol0003oooooooooo`06ooooo`00FOooool00ol0003oOgmoogmo
O`06ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`2Kooooo`03o`000?oooooooooo00Kooooo001Iooooo`03o`000?moOgooOgmo00KoOgmo00?o0000
ogmoOomoOgl03_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo09_ooooo00?o0000
ooooooooool01_ooool005Wooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0>ogmo
O`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`06oooo
o`00F_ooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomo
Ogl00_moOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00Kooooo001Jooooo`03o`00
0?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`00
0?oooooooooo09cooooo00?o0000ooooooooool01_ooool005[ooooo00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0W?oo
ool00ol0003oooooooooo`06ooooo`00Foooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgoo
Ogmo00koOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`2Looooo`03o`000?oooooo
oooo00Kooooo001Kooooo`03o`000?moOgooOgmo00CoOgmo4_l00003ogmoO`03o`000?oooooooooo
09gooooo00?o0000ooooooooool01_ooool005_ooooo00?o0000ogmoOomoOgl01?moOgl00ol0003o
OgmoogmoO`0>ogmoO`05o`000?moOgooOgmoogmoOol00000Woooool00ol0003oooooooooo`06oooo
o`00G?ooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00koOgmo00Go0000ogmoOomo
OgooOgmoo`00002Oooooo`03o`000?oooooooooo00Kooooo001Looooo`03o`000?moOgooOgmo00?o
Ogmo00?o0000ogmoOomoOgl03_moOgl01Ol0003oOgmoogmoOomoOgoo000009oooooo00?o0000oooo
ooooool01_ooool005gooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0>ogmoO`04
o`000?moOgooOgmoo`000:3ooooo00?o0000ooooooooool01_ooool005gooooo00?o0000ogmoOomo
Ogl00_moOgl00ol0003oOgmoogmoO`0>ogmoO`04o`000?moOgooOgmoo`000:3ooooo00?o0000oooo
ooooool01_ooool005gooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0>ogmoO`04
o`000?moOgooOgmoo`000:3ooooo00?o0000ooooooooool01_ooool005kooooo00Go0000ogmoOomo
OgooOgmoo`00000@ogmoO`04o`000?moOgooOgmoo`000:3ooooo00?o0000ooooooooool01_ooool0
05kooooo00Go0000ogmoOomoOgooOgmoo`00000@ogmoO`03o`000?moOgoo00000:7ooooo00?o0000
ooooooooool01_ooool005oooooo00?o0000ogmoOomoOgl04_l000000omoOgoo0000ooooo`2Poooo
o`03o`000?oooooooooo00Kooooo001Oooooo`04o`000?moOgooOgmoo`00013oOgmo00?o0000ogmo
Ool00000XOooool00ol0003oooooooooo`06ooooo`00Goooool01?l0003oOgmoogmoOol0000@ogmo
O`03o`000?moOgoo00000:7ooooo00?o0000ooooooooool01_ooool0063ooooo00?o0000ogmoOol0
00004?moOgl2o`000:;ooooo00?o0000ooooooooool01_ooool0063ooooo00?o0000ogmoOol00000
4?moOgl2o`000:;ooooo00?o0000ooooooooool01_ooool0067ooooo0_l0000@ogmoO`;o0000X_oo
ool00ol0003oooooooooo`06ooooo`00HOoooolDo`000:;ooooo00?o0000ooooooooool01_ooool0
067ooooo0_l0000@ogmoO`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool01_ooool006;o
oooo4_l0002Sooooo`03o`000?oooooooooo00Kooooo003oooooob7ooooo003oooooob7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {122.375, 0}} -> {-21.938, -15.7502, 0.257408, \
0.257408}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "Next, we use ",
  StyleBox["SymbolicTrace", "Input"],
  " function to calculate the third order symbolic solution to the optical \
system. Although ",
  StyleBox["SymbolicTrace", "Input"],
  " calculates several types of symbolic results, we will only use the ",
  StyleBox["SymbolicSurfaceCoordinates", "Input"],
  " for optimization purposes. Here, ",
  StyleBox["MakeFloatingPoint", "Input"],
  " retains the pure integer values of the numeric system parameters."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["\<\
Py = (SymbolicSurfaceCoordinates/. 
\tSymbolicTrace[opticalsystem,{{y,0,3}, {c1>0,c2<0,y\[Element]Reals}},
\t\tMakeFloatingPoint->False])[[1]]\
\>", "Input",
  CellLabel->"In[54]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[BoxData[
    \(y - \(70\ c1\ y\)\/3 + 
      20\ c2\ y - \(200\ c1\ c2\ y\)\/3 + \(c1\^2\ y\^3\)\/6 - \(565\ c1\^3\ \
y\^3\)\/54 + 1\/12\ c1\ c2\ y\^3 + 215\/18\ c1\^2\ c2\ y\^3 - 
      500\/9\ c1\^3\ c2\ y\^3 - \(c2\^2\ y\^3\)\/4 - 55\/3\ c1\ c2\^2\ y\^3 + 
      1175\/9\ c1\^2\ c2\^2\ y\^3 - 
      2000\/9\ c1\^3\ c2\^2\ y\^3 + \(35\ c2\^3\ y\^3\)\/2 - 
      175\ c1\ c2\^3\ y\^3 + 1750\/3\ c1\^2\ c2\^3\ y\^3 - 
      17500\/27\ c1\^3\ c2\^3\ y\^3\)], "Output",
  CellLabel->"Out[54]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "Now we are ready to calculate a symbolic figure of merit for the system \
performance. In particular, we want to base the performance of the system on \
every ",
  StyleBox["y", "Input"],
  " value of the input ray across a finite aperture runs between -5 and 5. \
This is accomplished by integrating the square of the focal intercept \
solution given by ",
  StyleBox["Py", "Input"],
  ", above."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["meritFunction = Expand[Integrate[Expand[Py^2],{y,-5,5}]]", "Input",
  CellLabel->"In[55]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[BoxData[
    \(250\/3 - \(35000\ c1\)\/9 + \(1236250\ c1\^2\)\/27 - \(968750\ \
c1\^3\)\/27 + \(692828125\ c1\^4\)\/1134 - \(44140625\ c1\^5\)\/567 + \
\(24939453125\ c1\^6\)\/10206 + \(10000\ c2\)\/3 - \(798125\ c1\ c2\)\/9 + \
\(7900000\ c1\^2\ c2\)\/27 - \(523890625\ c1\^3\ c2\)\/378 + \(1903046875\ c1\
\^4\ c2\)\/378 - \(10193359375\ c1\^5\ c2\)\/1701 + \(44140625000\ c1\^6\ \
c2\)\/1701 + \(98125\ c2\^2\)\/3 - \(2243750\ c1\ c2\^2\)\/9 + \(3549921875\ \
c1\^2\ c2\^2\)\/1512 - \(2440937500\ c1\^3\ c2\^2\)\/189 + \(39389453125\ \
c1\^4\ c2\^2\)\/1134 - \(156933593750\ c1\^5\ c2\^2\)\/1701 + \(293750000000\ \
c1\^6\ c2\^2\)\/1701 + 
      31250\ c2\^3 - \(65359375\ c1\ c2\^3\)\/28 + \(2668515625\ c1\^2\ c2\^3\
\)\/126 - \(16379687500\ c1\^3\ c2\^3\)\/189 + \(156031250000\ c1\^4\ c2\^3\)\
\/567 - \(408007812500\ c1\^5\ c2\^3\)\/567 + \(4357421875000\ c1\^6\ c2\^3\)\
\/5103 + \(49078125\ c2\^4\)\/56 - \(478671875\ c1\ c2\^4\)\/42 + \
\(4602734375\ c1\^2\ c2\^4\)\/63 - \(23218750000\ c1\^3\ c2\^4\)\/63 + \
\(801191406250\ c1\^4\ c2\^4\)\/567 - \(5251953125000\ c1\^5\ c2\^4\)\/1701 + \
\(4609375000000\ c1\^6\ c2\^4\)\/1701 - \(390625\ c2\^5\)\/2 - \(37109375\ c1\
\ c2\^5\)\/3 + \(2148437500\ c1\^2\ c2\^5\)\/9 - \(44921875000\ c1\^3\ \
c2\^5\)\/27 + \(458984375000\ c1\^4\ c2\^5\)\/81 - \(2324218750000\ c1\^5\ c2\
\^5\)\/243 + \(1562500000000\ c1\^6\ c2\^5\)\/243 + \(13671875\ c2\^6\)\/2 - 
      136718750\ c1\ c2\^6 + \(3417968750\ c1\^2\ c2\^6\)\/3 - \(136718750000\
\ c1\^3\ c2\^6\)\/27 + \(341796875000\ c1\^4\ c2\^6\)\/27 - \(1367187500000\ \
c1\^5\ c2\^6\)\/81 + \(6835937500000\ c1\^6\ c2\^6\)\/729\)], "Output",
  CellLabel->"Out[55]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell["\<\
Here is a plot of the resulting merit function for diffferent lens \
curvatures.\
\>", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["Plot3D[meritFunction,{c1,0,.1},{c2,-.1,0}];", "Input",
  CellLabel->"In[56]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -23.848 -9 ]
[.14598 .19958 .15205 0 ]
[.27013 .15073 -22.8472 -9 ]
[.27013 .15073 1.15281 0 ]
[.40046 .09948 -21.8464 -9 ]
[.40046 .09948 2.15358 0 ]
[.53743 .04564 -20.8457 -9 ]
[.53743 .04564 3.15434 0 ]
[.68156 -0.01098 -14.8837 -9 ]
[.68156 -0.01098 3.11632 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 24 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 30 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 30 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 30 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 30 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01592 .31649 -18 -2.78576 ]
[.01592 .31649 0 6.21424 ]
[.00744 .36962 -18 -2.83082 ]
[.00744 .36962 0 6.16918 ]
[-0.00133 .42458 -18 -2.87761 ]
[-0.00133 .42458 0 6.12239 ]
[-0.01041 .48147 -18 -2.92621 ]
[-0.01041 .48147 0 6.07379 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.02)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.04)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.06)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.08)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-0.1)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(-0.08)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(-0.06)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(-0.04)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(-0.02)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02818 .31182 m
.03431 .30948 L
s
[(200)] .01592 .31649 1 -0.38094 Mshowa
.01974 .36505 m
.02589 .36277 L
s
[(400)] .00744 .36962 1 -0.37093 Mshowa
.01101 .42013 m
.01719 .4179 L
s
[(600)] -0.00133 .42458 1 -0.36053 Mshowa
.00198 .47714 m
.00817 .47497 L
s
[(800)] -0.01041 .48147 1 -0.34973 Mshowa
.125 Mabswid
.03432 .27305 m
.03799 .27162 L
s
.03229 .28586 m
.03596 .28445 L
s
.03024 .29879 m
.03392 .29738 L
s
.0261 .32496 m
.02978 .32357 L
s
.024 .33821 m
.02768 .33683 L
s
.02188 .35158 m
.02557 .3502 L
s
.01759 .37864 m
.02128 .37728 L
s
.01542 .39235 m
.01911 .391 L
s
.01322 .40618 m
.01692 .40484 L
s
.00879 .43419 m
.01249 .43287 L
s
.00654 .44838 m
.01025 .44706 L
s
.00427 .4627 m
.00798 .46139 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.699 .709 .856 r
.38253 .59758 .40444 .62316 .44156 .60621 .41992 .58134 Metetra
.693 .715 .865 r
.41992 .58134 .44156 .60621 .47904 .59018 .4577 .56596 Metetra
.687 .721 .875 r
.4577 .56596 .47904 .59018 .51694 .57505 .49592 .55145 Metetra
.679 .726 .885 r
.49592 .55145 .51694 .57505 .55528 .56083 .53461 .53782 Metetra
.671 .731 .895 r
.53461 .53782 .55528 .56083 .59413 .54754 .57382 .52508 Metetra
.661 .736 .906 r
.57382 .52508 .59413 .54754 .63352 .53519 .61361 .51328 Metetra
.649 .74 .916 r
.61361 .51328 .63352 .53519 .67352 .52385 .65403 .50244 Metetra
.636 .743 .926 r
.65403 .50244 .67352 .52385 .71417 .51354 .69513 .49264 Metetra
.62 .746 .936 r
.69513 .49264 .71417 .51354 .75554 .50435 .73698 .48393 Metetra
.603 .747 .946 r
.73698 .48393 .75554 .50435 .79771 .49636 .77966 .47641 Metetra
.582 .746 .955 r
.77966 .47641 .79771 .49636 .84075 .48965 .82324 .47016 Metetra
.558 .744 .963 r
.82324 .47016 .84075 .48965 .88476 .48434 .86782 .46531 Metetra
.531 .739 .971 r
.86782 .46531 .88476 .48434 .92983 .48058 .91351 .462 Metetra
.499 .732 .977 r
.91351 .462 .92983 .48058 .97608 .47851 .96042 .46039 Metetra
.693 .713 .864 r
.36008 .57221 .38253 .59758 .41992 .58134 .39774 .55663 Metetra
.687 .719 .873 r
.39774 .55663 .41992 .58134 .4577 .56596 .43582 .54188 Metetra
.68 .725 .883 r
.43582 .54188 .4577 .56596 .49592 .55145 .47436 .52796 Metetra
.672 .73 .893 r
.47436 .52796 .49592 .55145 .53461 .53782 .5134 .5149 Metetra
.663 .735 .903 r
.5134 .5149 .53461 .53782 .57382 .52508 .55299 .5027 Metetra
.652 .739 .913 r
.55299 .5027 .57382 .52508 .61361 .51328 .59318 .49141 Metetra
.64 .743 .923 r
.59318 .49141 .61361 .51328 .65403 .50244 .63402 .48108 Metetra
.626 .746 .933 r
.63402 .48108 .65403 .50244 .69513 .49264 .67558 .47176 Metetra
.61 .748 .943 r
.67558 .47176 .69513 .49264 .73698 .48393 .71792 .46353 Metetra
.591 .748 .952 r
.71792 .46353 .73698 .48393 .77966 .47641 .76111 .45647 Metetra
.569 .747 .961 r
.76111 .45647 .77966 .47641 .82324 .47016 .80525 .45068 Metetra
.544 .744 .969 r
.80525 .45068 .82324 .47016 .86782 .46531 .85042 .44628 Metetra
.516 .739 .975 r
.85042 .44628 .86782 .46531 .91351 .462 .89673 .44342 Metetra
.483 .731 .98 r
.89673 .44342 .91351 .462 .96042 .46039 .9443 .44225 Metetra
.687 .717 .872 r
.33706 .54702 .36008 .57221 .39774 .55663 .375 .53208 Metetra
.681 .723 .882 r
.375 .53208 .39774 .55663 .43582 .54188 .41337 .51794 Metetra
.673 .729 .892 r
.41337 .51794 .43582 .54188 .47436 .52796 .45224 .50459 Metetra
.664 .734 .902 r
.45224 .50459 .47436 .52796 .5134 .5149 .49162 .49207 Metetra
.654 .739 .911 r
.49162 .49207 .5134 .5149 .55299 .5027 .53159 .48041 Metetra
.643 .743 .921 r
.53159 .48041 .55299 .5027 .59318 .49141 .57218 .46962 Metetra
.63 .746 .931 r
.57218 .46962 .59318 .49141 .63402 .48108 .61346 .45978 Metetra
.615 .749 .941 r
.61346 .45978 .63402 .48108 .67558 .47176 .65548 .45094 Metetra
.598 .75 .95 r
.65548 .45094 .67558 .47176 .71792 .46353 .69831 .44317 Metetra
.578 .75 .959 r
.69831 .44317 .71792 .46353 .76111 .45647 .74204 .43656 Metetra
.555 .749 .967 r
.74204 .43656 .76111 .45647 .80525 .45068 .78673 .43122 Metetra
.529 .745 .974 r
.78673 .43122 .80525 .45068 .85042 .44628 .83251 .42727 Metetra
.5 .738 .98 r
.83251 .42727 .85042 .44628 .89673 .44342 .87946 .42485 Metetra
.466 .729 .983 r
.87946 .42485 .89673 .44342 .9443 .44225 .92772 .42412 Metetra
.681 .722 .881 r
.31343 .52204 .33706 .54702 .375 .53208 .35164 .50772 Metetra
.673 .728 .89 r
.35164 .50772 .375 .53208 .41337 .51794 .39032 .49415 Metetra
.665 .733 .9 r
.39032 .49415 .41337 .51794 .45224 .50459 .42951 .48137 Metetra
.656 .738 .91 r
.42951 .48137 .45224 .50459 .49162 .49207 .46925 .46938 Metetra
.645 .743 .92 r
.46925 .46938 .49162 .49207 .53159 .48041 .50959 .45822 Metetra
.633 .746 .93 r
.50959 .45822 .53159 .48041 .57218 .46962 .55059 .44794 Metetra
.62 .75 .939 r
.55059 .44794 .57218 .46962 .61346 .45978 .59231 .43857 Metetra
.604 .752 .948 r
.59231 .43857 .61346 .45978 .65548 .45094 .6348 .4302 Metetra
.585 .753 .957 r
.6348 .4302 .65548 .45094 .69831 .44317 .67813 .42289 Metetra
.565 .752 .966 r
.67813 .42289 .69831 .44317 .74204 .43656 .7224 .41673 Metetra
.541 .75 .973 r
.7224 .41673 .74204 .43656 .78673 .43122 .76767 .41183 Metetra
.513 .745 .979 r
.76767 .41183 .78673 .43122 .83251 .42727 .81406 .40831 Metetra
.482 .737 .983 r
.81406 .40831 .83251 .42727 .87946 .42485 .86167 .40633 Metetra
.447 .727 .986 r
.86167 .40633 .87946 .42485 .92772 .42412 .91064 .40603 Metetra
.673 .727 .89 r
.28916 .49728 .31343 .52204 .35164 .50772 .32764 .48355 Metetra
.666 .732 .9 r
.32764 .48355 .35164 .50772 .39032 .49415 .36661 .47056 Metetra
.657 .738 .909 r
.36661 .47056 .39032 .49415 .42951 .48137 .40613 .45831 Metetra
.647 .742 .919 r
.40613 .45831 .42951 .48137 .46925 .46938 .44622 .44685 Metetra
.636 .747 .929 r
.44622 .44685 .46925 .46938 .50959 .45822 .48695 .43619 Metetra
.623 .75 .938 r
.48695 .43619 .50959 .45822 .55059 .44794 .52837 .42639 Metetra
.608 .753 .947 r
.52837 .42639 .55059 .44794 .59231 .43857 .57053 .4175 Metetra
.591 .755 .956 r
.57053 .4175 .59231 .43857 .6348 .4302 .61349 .40958 Metetra
.572 .755 .964 r
.61349 .40958 .6348 .4302 .67813 .42289 .65734 .40272 Metetra
.55 .754 .972 r
.65734 .40272 .67813 .42289 .7224 .41673 .70216 .397 Metetra
.524 .75 .978 r
.70216 .397 .7224 .41673 .76767 .41183 .74802 .39253 Metetra
.496 .745 .983 r
.74802 .39253 .76767 .41183 .81406 .40831 .79504 .38945 Metetra
.464 .736 .987 r
.79504 .38945 .81406 .40831 .86167 .40633 .84333 .38789 Metetra
.428 .724 .987 r
.84333 .38789 .86167 .40633 .91064 .40603 .89303 .38802 Metetra
.666 .732 .899 r
.26418 .47277 .28916 .49728 .32764 .48355 .30294 .45962 Metetra
.657 .738 .909 r
.30294 .45962 .32764 .48355 .36661 .47056 .34221 .44719 Metetra
.648 .743 .919 r
.34221 .44719 .36661 .47056 .40613 .45831 .38205 .43548 Metetra
.637 .747 .928 r
.38205 .43548 .40613 .45831 .44622 .44685 .42251 .42452 Metetra
.625 .751 .938 r
.42251 .42452 .44622 .44685 .48695 .43619 .46362 .41436 Metetra
.611 .755 .947 r
.46362 .41436 .48695 .43619 .52837 .42639 .50546 .40503 Metetra
.595 .757 .956 r
.50546 .40503 .52837 .42639 .57053 .4175 .54807 .3966 Metetra
.577 .758 .964 r
.54807 .3966 .57053 .4175 .61349 .40958 .59153 .38913 Metetra
.557 .757 .971 r
.59153 .38913 .61349 .40958 .65734 .40272 .6359 .38271 Metetra
.533 .755 .978 r
.6359 .38271 .65734 .40272 .70216 .397 .68127 .37742 Metetra
.507 .751 .983 r
.68127 .37742 .70216 .397 .74802 .39253 .72774 .37339 Metetra
.477 .744 .987 r
.72774 .37339 .74802 .39253 .79504 .38945 .77541 .37072 Metetra
.444 .734 .989 r
.77541 .37072 .79504 .38945 .84333 .38789 .8244 .36958 Metetra
.406 .721 .988 r
.8244 .36958 .84333 .38789 .89303 .38802 .87484 .37013 Metetra
.657 .738 .909 r
.23845 .44857 .26418 .47277 .30294 .45962 .27748 .436 Metetra
.648 .743 .919 r
.27748 .436 .30294 .45962 .34221 .44719 .31706 .4241 Metetra
.638 .748 .928 r
.31706 .4241 .34221 .44719 .38205 .43548 .35723 .41291 Metetra
.626 .752 .938 r
.35723 .41291 .38205 .43548 .42251 .42452 .39804 .40246 Metetra
.613 .756 .947 r
.39804 .40246 .42251 .42452 .46362 .41436 .43955 .39278 Metetra
.598 .759 .956 r
.43955 .39278 .46362 .41436 .50546 .40503 .48181 .38392 Metetra
.581 .761 .964 r
.48181 .38392 .50546 .40503 .54807 .3966 .52489 .37594 Metetra
.562 .761 .971 r
.52489 .37594 .54807 .3966 .59153 .38913 .56884 .36892 Metetra
.54 .76 .978 r
.56884 .36892 .59153 .38913 .6359 .38271 .61375 .36292 Metetra
.515 .757 .984 r
.61375 .36292 .6359 .38271 .68127 .37742 .6597 .35806 Metetra
.488 .751 .988 r
.6597 .35806 .68127 .37742 .72774 .37339 .70679 .35444 Metetra
.457 .743 .99 r
.70679 .35444 .72774 .37339 .77541 .37072 .75513 .35219 Metetra
.422 .732 .99 r
.75513 .35219 .77541 .37072 .8244 .36958 .80483 .35145 Metetra
.384 .718 .988 r
.80483 .35145 .8244 .36958 .87484 .37013 .85605 .35241 Metetra
.647 .744 .92 r
.21191 .42475 .23845 .44857 .27748 .436 .25121 .41274 Metetra
.637 .749 .929 r
.25121 .41274 .27748 .436 .31706 .4241 .29109 .40138 Metetra
.626 .754 .939 r
.29109 .40138 .31706 .4241 .35723 .41291 .3316 .3907 Metetra
.614 .758 .948 r
.3316 .3907 .35723 .41291 .39804 .40246 .37278 .38074 Metetra
.6 .761 .956 r
.37278 .38074 .39804 .40246 .43955 .39278 .41469 .37153 Metetra
.584 .764 .964 r
.41469 .37153 .43955 .39278 .48181 .38392 .45738 .36313 Metetra
.565 .765 .972 r
.45738 .36313 .48181 .38392 .52489 .37594 .50092 .35559 Metetra
.545 .764 .979 r
.50092 .35559 .52489 .37594 .56884 .36892 .54538 .349 Metetra
.522 .762 .984 r
.54538 .349 .56884 .36892 .61375 .36292 .59084 .34343 Metetra
.496 .758 .989 r
.59084 .34343 .61375 .36292 .6597 .35806 .63739 .33898 Metetra
.467 .751 .991 r
.63739 .33898 .6597 .35806 .70679 .35444 .68511 .33576 Metetra
.434 .742 .992 r
.68511 .33576 .70679 .35444 .75513 .35219 .73414 .3339 Metetra
.399 .729 .99 r
.73414 .3339 .75513 .35219 .80483 .35145 .78458 .33356 Metetra
.36 .713 .986 r
.78458 .33356 .80483 .35145 .85605 .35241 .8366 .33491 Metetra
.636 .751 .931 r
.18449 .40141 .21191 .42475 .25121 .41274 .22406 .38994 Metetra
.626 .756 .94 r
.22406 .38994 .25121 .41274 .29109 .40138 .26424 .3791 Metetra
.614 .761 .949 r
.26424 .3791 .29109 .40138 .3316 .3907 .30508 .36893 Metetra
.6 .764 .958 r
.30508 .36893 .3316 .3907 .37278 .38074 .34663 .35944 Metetra
.585 .767 .966 r
.34663 .35944 .37278 .38074 .41469 .37153 .38895 .3507 Metetra
.567 .768 .973 r
.38895 .3507 .41469 .37153 .45738 .36313 .43209 .34274 Metetra
.548 .769 .98 r
.43209 .34274 .45738 .36313 .50092 .35559 .47611 .33564 Metetra
.526 .767 .985 r
.47611 .33564 .50092 .35559 .54538 .349 .52109 .32946 Metetra
.501 .764 .99 r
.52109 .32946 .54538 .349 .59084 .34343 .56712 .3243 Metetra
.474 .758 .993 r
.56712 .3243 .59084 .34343 .63739 .33898 .61427 .32025 Metetra
.443 .75 .994 r
.61427 .32025 .63739 .33898 .68511 .33576 .66265 .31742 Metetra
.41 .739 .992 r
.66265 .31742 .68511 .33576 .73414 .3339 .71238 .31594 Metetra
.373 .726 .989 r
.71238 .31594 .73414 .3339 .78458 .33356 .7636 .31598 Metetra
.334 .708 .983 r
.7636 .31598 .78458 .33356 .8366 .33491 .81644 .3177 Metetra
.624 .759 .943 r
.15609 .37865 .18449 .40141 .22406 .38994 .19594 .36772 Metetra
.612 .764 .952 r
.19594 .36772 .22406 .38994 .26424 .3791 .23643 .35739 Metetra
.599 .768 .96 r
.23643 .35739 .26424 .3791 .30508 .36893 .27761 .3477 Metetra
.584 .771 .968 r
.27761 .3477 .30508 .36893 .34663 .35944 .31954 .33869 Metetra
.567 .773 .975 r
.31954 .33869 .34663 .35944 .38895 .3507 .36227 .33039 Metetra
.549 .773 .982 r
.36227 .33039 .38895 .3507 .43209 .34274 .40586 .32287 Metetra
.528 .773 .987 r
.40586 .32287 .43209 .34274 .47611 .33564 .45037 .31618 Metetra
.505 .77 .991 r
.45037 .31618 .47611 .33564 .52109 .32946 .49589 .31041 Metetra
.479 .765 .994 r
.49589 .31041 .52109 .32946 .56712 .3243 .5425 .30564 Metetra
.45 .758 .995 r
.5425 .30564 .56712 .3243 .61427 .32025 .59028 .30196 Metetra
.418 .749 .994 r
.59028 .30196 .61427 .32025 .66265 .31742 .63934 .2995 Metetra
.384 .736 .991 r
.63934 .2995 .66265 .31742 .71238 .31594 .68981 .29839 Metetra
.346 .721 .986 r
.68981 .29839 .71238 .31594 .7636 .31598 .74181 .29879 Metetra
.306 .702 .977 r
.74181 .29879 .7636 .31598 .81644 .3177 .79551 .30085 Metetra
.61 .768 .956 r
.12663 .35661 .15609 .37865 .19594 .36772 .16675 .34621 Metetra
.597 .772 .964 r
.16675 .34621 .19594 .36772 .23643 .35739 .20755 .33638 Metetra
.582 .775 .971 r
.20755 .33638 .23643 .35739 .27761 .3477 .24909 .32716 Metetra
.566 .778 .978 r
.24909 .32716 .27761 .3477 .31954 .33869 .2914 .3186 Metetra
.548 .779 .984 r
.2914 .3186 .31954 .33869 .36227 .33039 .33455 .31074 Metetra
.528 .778 .989 r
.33455 .31074 .36227 .33039 .40586 .32287 .37861 .30363 Metetra
.505 .776 .993 r
.37861 .30363 .40586 .32287 .45037 .31618 .42363 .29734 Metetra
.481 .772 .995 r
.42363 .29734 .45037 .31618 .49589 .31041 .4697 .29195 Metetra
.453 .766 .996 r
.4697 .29195 .49589 .31041 .5425 .30564 .5169 .28755 Metetra
.423 .757 .995 r
.5169 .28755 .5425 .30564 .59028 .30196 .56533 .28423 Metetra
.39 .746 .992 r
.56533 .28423 .59028 .30196 .63934 .2995 .6151 .28212 Metetra
.355 .732 .987 r
.6151 .28212 .63934 .2995 .68981 .29839 .66633 .28135 Metetra
.317 .715 .98 r
.66633 .28135 .68981 .29839 .74181 .29879 .71916 .28207 Metetra
.277 .695 .97 r
.71916 .28207 .74181 .29879 .79551 .30085 .77375 .28446 Metetra
.593 .777 .968 r
.09598 .33548 .12663 .35661 .16675 .34621 .13638 .32558 Metetra
.579 .781 .975 r
.13638 .32558 .16675 .34621 .20755 .33638 .17751 .31623 Metetra
.563 .783 .982 r
.17751 .31623 .20755 .33638 .24909 .32716 .2194 .30747 Metetra
.545 .784 .987 r
.2194 .30747 .24909 .32716 .2914 .3186 .26211 .29934 Metetra
.525 .784 .992 r
.26211 .29934 .2914 .3186 .33455 .31074 .3057 .29188 Metetra
.504 .782 .995 r
.3057 .29188 .33455 .31074 .37861 .30363 .35023 .28517 Metetra
.48 .779 .997 r
.35023 .28517 .37861 .30363 .42363 .29734 .39578 .27925 Metetra
.454 .773 .997 r
.39578 .27925 .42363 .29734 .4697 .29195 .44242 .27422 Metetra
.425 .765 .996 r
.44242 .27422 .4697 .29195 .5169 .28755 .49024 .27016 Metetra
.394 .755 .993 r
.49024 .27016 .5169 .28755 .56533 .28423 .53935 .26717 Metetra
.36 .742 .988 r
.53935 .26717 .56533 .28423 .6151 .28212 .58985 .26538 Metetra
.324 .726 .98 r
.58985 .26538 .6151 .28212 .66633 .28135 .64187 .26492 Metetra
.286 .708 .971 r
.64187 .26492 .66633 .28135 .71916 .28207 .69555 .26594 Metetra
.247 .686 .959 r
.69555 .26594 .71916 .28207 .77375 .28446 .75107 .26863 Metetra
.573 .788 .98 r
.06401 .31545 .09598 .33548 .13638 .32558 .10471 .30603 Metetra
.557 .79 .986 r
.10471 .30603 .13638 .32558 .17751 .31623 .14616 .29714 Metetra
.54 .791 .991 r
.14616 .29714 .17751 .31623 .2194 .30747 .18842 .2888 Metetra
.52 .791 .995 r
.18842 .2888 .2194 .30747 .26211 .29934 .23154 .28108 Metetra
.499 .789 .997 r
.23154 .28108 .26211 .29934 .3057 .29188 .27558 .27401 Metetra
.476 .786 .998 r
.27558 .27401 .3057 .29188 .35023 .28517 .32061 .26765 Metetra
.451 .78 .998 r
.32061 .26765 .35023 .28517 .39578 .27925 .3667 .26208 Metetra
.423 .773 .996 r
.3667 .26208 .39578 .27925 .44242 .27422 .41394 .25738 Metetra
.393 .763 .993 r
.41394 .25738 .44242 .27422 .49024 .27016 .46241 .25363 Metetra
.362 .751 .987 r
.46241 .25363 .49024 .27016 .53935 .26717 .51221 .25094 Metetra
.328 .736 .98 r
.51221 .25094 .53935 .26717 .58985 .26538 .56347 .24943 Metetra
.292 .719 .97 r
.56347 .24943 .58985 .26538 .64187 .26492 .61632 .24924 Metetra
.254 .699 .958 r
.61632 .24924 .64187 .26492 .69555 .26594 .6709 .25052 Metetra
.215 .677 .945 r
.6709 .25052 .69555 .26594 .75107 .26863 .7274 .25346 Metetra
.549 .798 .991 r
.03056 .29678 .06401 .31545 .10471 .30603 .07156 .28781 Metetra
.531 .799 .995 r
.07156 .28781 .10471 .30603 .14616 .29714 .11335 .27934 Metetra
.512 .798 .997 r
.11335 .27934 .14616 .29714 .18842 .2888 .15599 .2714 Metetra
.491 .796 .999 r
.15599 .2714 .18842 .2888 .23154 .28108 .19954 .26404 Metetra
.469 .793 .999 r
.19954 .26404 .23154 .28108 .27558 .27401 .24405 .25732 Metetra
.444 .787 .998 r
.24405 .25732 .27558 .27401 .32061 .26765 .2896 .25129 Metetra
.418 .78 .995 r
.2896 .25129 .32061 .26765 .3667 .26208 .33626 .24602 Metetra
.389 .77 .991 r
.33626 .24602 .3667 .26208 .41394 .25738 .38412 .2416 Metetra
.359 .759 .985 r
.38412 .2416 .41394 .25738 .46241 .25363 .43326 .23813 Metetra
.327 .745 .977 r
.43326 .23813 .46241 .25363 .51221 .25094 .48381 .23569 Metetra
.293 .728 .967 r
.48381 .23569 .51221 .25094 .56347 .24943 .53586 .23442 Metetra
.257 .709 .955 r
.53586 .23442 .56347 .24943 .61632 .24924 .58958 .23446 Metetra
.22 .688 .942 r
.58958 .23446 .61632 .24924 .6709 .25052 .6451 .23596 Metetra
.182 .665 .928 r
.6451 .23596 .6709 .25052 .7274 .25346 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.02)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.04)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.06)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.08)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[56]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00]?ooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0005kooooo002cooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0GOooool00;?ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`1Mooooo`00/oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo05gooooo002c
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0GOooool00;?ooooo00Co0000
oooooooooooo00002?ooool2o`0000cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0
0015ooooo`00]?ooool2o`0000[ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo04Cooooo0035ooooo`Go00000_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo04Cooooo003<ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0A?ooool00<cooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`14ooooo`00c?ooool01?l0003oooooooooool00008ooooo`;o0000A_ooool00<7ooooo0_l0000:
ooooo`;o00002_ooool00ol0003oooooooooo`14ooooo`00__ooool3o`000003ooooool0003o0000
05cooooo002looooo`;o00001?ooool2o`0005cooooo0029ooooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`;o00000oooool3o`0001cooooo0ol00006ooooo`03o`000?oooooo000005_ooooo
0028ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo01Kooooo0ol000000ooooooo0000ooooo`06ooooo`03o`000?oooooo0000
05_ooooo0028ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`04o`000?ooooooooooo`0005[ooooo
0028ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool3o`0001Co
oooo0ol0000>ooooo`04o`000?ooooooooooooooo`;o0000F?ooool008Sooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool03ooo
ool2o`00017ooooo00Go0000ooooooooooooooooo`00001Iooooo`00R?ooool01?l0003ooooooooo
ool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0<oooo
o`?o000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05Kooooo0029ooooo`;o00002_ooool2o`0000?ooooo0ol0000=ooooo`;o00005oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05Gooooo002Wooooo`?o00006Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo05Gooooo002Uooooo`?o00006oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05Cooooo002Rooooo`?o00007_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05?ooooo002Oooooo`?o00008Oooool00ol0003oooooooooo`04oooo
o`;o0000E?ooool009gooooo0_l0000Tooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0D_ooool009[ooooo0ol00002ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Aooooo`00V?ooool2o`0002Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Aooooo`00I_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000?ooooo0ol0000Kooooo`?o0000:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo053ooooo001Uooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`0[ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Coooool006Gooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool04oooool3o`00
033ooooo00?o0000ooooooooool02?ooool2o`00053ooooo001Uooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000oooooooooooo0000ooooo`04o`0001?ooooo0ol0000cooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000?ooooo0ol0000^ooooo`00IOooool01?l0003oooooooooool00008ooooo`06o`000?oooooo
ooooo`000?oooooo00005?ooool3o`0003Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0;ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooooooo02_ooooo001Uooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0>ooooo`?o0000>?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00?ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo02_ooooo001Vooooo`;o
00002_ooool2o`0000Cooooo0_l0000<ooooo`;o0000>oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002
ooooo`?o0000;_ooool008?ooooo0ol0000nooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0[ooooo`00POooool2o`0000;ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0;ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0[ooooo`00O_ooool3o`0004?o
oooo00?o0000ooooooooool02oooool2o`0000[ooooo0_l0000:ooooo`;o00000oooool3o`0002ko
oooo001kooooo`?o0000A_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04[ooooo
001iooooo`Co0000Aoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Wooooo001f
ooooo`?o00001?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0B?ooool004Cooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`?o00006oooool2o`0004kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`18oooo
o`00@oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool05oooool4o`0004oooooo00?o0000ooooooooool03oooool2o`0004Sooooo0013oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`05o`0001Kooooo0_l0
001Cooooo`03o`000?oooooooooo00oooooo0_l00018ooooo`00@oooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`0Booooo`?o
0000EOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Kooooo0013ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00000Boooo
o`;o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Gooooo0013ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool2o`0000oooooo0ol00002
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`14
ooooo`00A?ooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo0ol0001Moooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0A?ooool006;ooooo0_l0001Pooooo`03
o`000?oooooooooo01?ooooo0_l00014ooooo`00Goooool3o`000003ooooool0003ooooo05oooooo
00?o0000ooooooooool04oooool2o`0004Cooooo001Mooooo`;o0000IOooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04;ooooo001Jooooo`?o0000J?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo047ooooo001Hooooo`;o00000_ooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@?ooool002?ooooo0_l00004ooooo`03
o`000?oooooooooo00?ooooo0_l00002ooooo`Go00007Oooool3o`0006gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`10ooooo`008_ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006oooool2o`00073ooooo00?o0000
ooooooooool05_ooool2o`0000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003
ooooo`?o00007_ooool002;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo01Sooooo1?l0001aooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool02oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`0Kooooo`008_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05?ooool3o`0007Gooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`04ooooo`Go00000_ooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Kooooo`00
8_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`0Aooooo`;o0000N?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co0000
7_ooool002;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool03_ooool3o`000003ooooool0003ooooo07Oooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool0000Qooooo`008oooool2o`0000[ooooo0_l00003ooooo`?o00003ooo
ool2o`0007gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Nooooo`00
@oooool3o`0007oooooo00?o0000ooooooooool06Oooool2o`0000_ooooo0_l0000:ooooo`;o0000
1?ooool2o`0001kooooo0011ooooo`;o000000?oooooo`000?ooool0Ooooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo03[ooooo000nooooo`?o0000Q?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo03[ooooo000kooooo`?o0000Qoooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo03Wooooo000iooooo`;o000000?oooooo`000?ooool0Qoooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo03Sooooo000Gooooo`;o00007Oooool3o`0000Cooooo
00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Mooooo`;o0000>Oooool001Kooooo00Co
0000oooooooooooo00006_ooool2o`00093ooooo00?o0000ooooooooool07?ooool2o`0003Wooooo
000Fooooo`04o`000?ooooooooooo`0001Oooooo1?l0002Aooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0=oooool001Kooooo00Co0000oooooooooooo00005Oooool2o`0009Gooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0fooooo`005_ooool01?l0003ooooooooo
ool0000Booooo`?o0000Uoooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Gooooo
000Fooooo`04o`000?ooooooooooo`00013ooooo0_l000000ooooooo0000ooooo`1IooooocSo0000
1_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Gooooo000Gooooo`;o00003_oo
ool3o`0005;ooooo3?l00008oe>nnP;o00003?m;^_L2o`0000_o@KGd0_l0000<ocR`l@;o00001Ol^
Z^d8o`00027ooooo0_l0000eooooo`009?ooool3o`0004Sooooo3Ol00008oe_2o0;o00003?mC__X2
o`0000coBk[g00?o0000od6em?m1]O@02_m1]O@00ol0003o>;3aocR`l@0;ocR`l@03o`000?l^Z^go
;Z[]00So;Z[]00?o0000objZkOl000008Oooool00ol0003oooooooooo`0cooooo`008_ooool2o`00
00;ooooo00?o0000ooooooooool0>_ooool<o`0000SoHlGm0_l0000=oe_2o003o`000?mC__[oDkkj
00_oDkkj0_l0000;od^jm`;o00002om1]O@2o`0000co>;3a0_l00007objZk@;o00000_l^Z^d2o`00
01oooooo00?o0000ooooooooool0<oooool001oooooo0ol0000hooooo`Wo00002?m[aoh2o`0000co
HlGm0_l0000<oe_2o0;o00001omC__Xgo`0000Co;Z[]00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0booooo`007_ooool2o`0003Gooooo1Ol00005og79o`;o00003?m[aoh2o`0000coHlGm
0_l00006oe_2o0go00002?mL`?`2o`0000_oDkcj00?o0000odZhn?m:^?P02_m:^?P00ol0003o@K;e
od6bm@0:od6bm@?o00001?lg[O48o`0001kooooo00?o0000ooooooooool0<Oooool001gooooo1?l0
000/ooooo`So00003?mabOl2o`0000coJlOn0_l00006of?5o@co00002?mT`oh2o`0000goG<3l00?o
0000oe>ln_mC_?X02OmC_?X2o`0000_oB[Sh0_l00007od6bm@?o00000_m1/_D2o`0000Go=jga00?o
0000ocN]lOlg[O400olg[O42o`0001cooooo0_l0000>ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool3o`0000oooooo000Fooooo`;o00001_ooool01?l0003oooooooooool0
000Rooooo`Wo00001omhbol2o`0000goLLWo0_l00006of_7oPco00002?m/aOh2o`0000coI<?n00?o
0000oec0o?mL`?`02omL`?`2o`0000_oDkcj00?o0000odZhn?m:^?P02_m:^?P01?l0003o@K;eod6b
mOm1/_D3o`0000Oo@K;e00?o0000ocN]lOlg[O400olg[O400ol0003o=jgaocN]l@04ocN]l@;o0000
6oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0>ooooo`005Oooool01?l0003oooooooooool00005oooo
o`05o`000?ooooooooooooooool000007?ooool5o`0000GoOL_o00?o0000ogS;oomhbol02_mhbol2
o`0000[oLLWo2Ol00008og?7o`;o00003?m/aOh00ol0003oI<?nofC3oP0:ofC3oP;o00001omL`?`m
o`0001[ooooo00?o0000ooooooooool00oooool5o`0000;ooooo00Co0000oooooooooooo00002?oo
ool01Ol0003oooooooooool0003ooooo00Go00003oooool001Gooooo00Co0000oooooooooooo0000
1?ooool2o`0000Cooooo00?o0000ooooooooool04oooool6o`0000_oOL_o0_l0000<ogS;o`;o0000
0omabOl5o`0000GoNLWo00?o0000og?7oomcaol02omcaol00ol0003oK<Gnofc5oP0:ofc5oP;o0000
1_mT`oh=o`0000SoI<7n00?o0000oebmo?mL_O`02OmL_O`2o`0000KoD[Wj0ol00002oe:inP;o0000
3?m9]OP01Ol0003o?joeocn_mOlo[oGo000000Wo?joe00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0:ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0002ooooo`03o`000?oooooooooo00kooooo000Eooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`Go00001On3c?l00ol0003oOL_oogg;
o`0;ogg;o`;o00002Omhbol6o`0000_oNLWo0_l0000<og?7o`;o00001_m/aOh<o`0000SoK<?n0_l0
000<ofC1oP;o00002omL_O`00ol0003oD[Wjoe:inP03o`0000OoD[Wj00?o0000odVen?m9]OP02_m9
]OP2o`0000;o?joe00?o0000ocn_mOlo[oD01olo[oD2o`0001Sooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool0
00004?ooool001Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo1_l0000;oh?<o`;o00003Ommbol01?l0003oN<_oogS;oomhbol5o`00
00GoOlWo0_l0000<ogW9o`;o00002Omcaol9o`0000SoM<Go0_l0000<ofc3oP03o`000?mT`OkoI<7n
00_oI<7n00?o0000oebmo?mL_O`02?mL_O`3o`0000_oD[Wj0_l0000<odVen003o`000?lo[oGo0000
00_o?joe00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000oooool2o`00013ooooo000Eooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05o`0000GoQlcn00?o
0000oh?<oon3c?l02on3c?l2o`0000WoOL_o1_l0000<ogo9o`03o`000?mibOooNLWo00_oNLWo00Co
0000og?7oomcaoooLlOo1Ol00005og[7o`03o`000?mdaOooM<Go00_oM<Go00?o0000ofc3o_m/`oh0
2_m/`oh2o`0000KoI<7n??l0000Fooooo`;o00002oooool2o`0000[ooooo0_l00005ooooo`03o`00
0?oooooooooo00kooooo000Fooooo`;o00001?ooool2o`0000Kooooo1Ol0000;ohO<oP;o00003On3
c?l01?l0003oOL_oogg;oommbol5o`0000GoQL[n0_l0000<ogo9o`;o00001_mibOl9o`0000_oN/Oo
0_l0000<ogC5o`;o00001_m/`oh<o`0000SoK<7n00?o0000of>noOl000000_l00008of>no@03o`00
0?mJ^ocoF[_l00[oF[_l00?o0000oe6gn_mA]oX02_mA]oX2o`0000_oA[7h00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0/ooooo`007Oooool01?l0003oooooooooooooool3o`0000CoS<cm
0_l0000<ohO<oP;o00002On3c?l6o`0000coQL[n00?o0000ogo9oomobOl02?mobOl9o`0000SoPLSn
0_l0000<og[7o`03o`000?mdaOooM<Go00SoM<Go2Ol00008og?4oP03o`000?m/`OkoK<7n00SoK<7n
0ol0000<of>no@;o00002omJ^o`2o`0000_oDKOj0_l0000;odJan003o`000?oooooooooo01Gooooo
00?o0000ooooooooool0:oooool001cooooo00?o0000ooooool000000_l00009ohc<o@;o00003?n7
c?h01?l0003oPlcooh?<oon3c?l5o`0000GoR/[m0_l0000<ohG:oP;o00000omobOl5o`0000GoQ/Sm
00?o0000oh78o_n1b?h02on1b?h00ol0003oN/Ooog[7o`0:og[7o`04o`000?mdaOooM<GoogC5o`Ko
00001OmkaOh00ol0003oLlCnog?4oP0:og?4oP03o`000?m/`OkoK<7n00GoK<7n0_l00003ofc1oP03
o`000?mS__goHkkm00_oHkkm00?o0000oeZko?mJ^o`02_mJ^o`00ol0003oDKOjoe6gnP09oe6gnP;o
00002om6/OP00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02_ooooo000Looooo`;o0000
3_n<c?d00ol0003oQlcnohO<oP08ohO<oPGo00003?n:b_d2o`0000[oQL[n1Ol0000;ohK8o@;o0000
3?n1b?h2o`0000KoN/Oo2?l0000<og_5oP;o00002omca?h01?l0003oK<7nofc1o_m/`Oh3o`0000Ko
K<7n00?o0000of>noOmS__d01OmS__dXo`0000CoA[7h00?o0000ooooooooool05?ooool2o`0002_o
oooo000Looooo`04o`000?oooooo0000o`0000goS<cm0_l00003ohO<oPGo00001?n>b_`00ol0003o
R/[moh[:o@0<oh[:o@;o00000on5b_h5o`0000CoRlSl00?o0000ohK8oOn6b?d02on6b?d2o`0000Wo
PLSn2Ol00007oh76oP03o`000?mkaOkoNlGn00coNlGn00?o0000og?4o_mca?h02Omca?h3o`0000Co
K<7n3Ol00008of^ooP03o`000?mR_?goH[cm00[oH[cm00?o0000oeRho?mH^?`02?mH^?`00ol0003o
F;Slo`000005odjcnPOo00005?ooool2o`0002_ooooo000Looooo`04o`000?ooooooooooooooo`;o
00002_n<c?d6o`0000[oS/[l0_l0000<oh[:o@Go00002_n;b?`2o`0000goQ/Sm00Co0000oh78o_n1
b?koPLSn1Ol00005ohO7o@03o`000?n1a_koPLKn00WoPLKn0_l0000=og_5oP03o`000?mca?koLlCn
00CoLlCn2ol00008og?2oP03o`000?m[_okoJkon00_oJkon00?o0000of:loOmR_?d02_mR_?d00ol0
003oF;SloeRho008oeRho003o`000?mH^?co000000_oC[?j00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Yooooo`006oooool3o`0000Cooooo0_l00003ohc<o@Go00001OnBbOX00ol0003o
S/[lohk:o00:ohk:o0;o00001_n:b_d4o`0000CoT<Sk00?o0000oh_8o?n;b?`02_n;b?`2o`0000Wo
Q/Sm1_l0000;ohO7o@;o00002on1a_h00ol0003oNlGnog_5oP08og_5oP[o00001_mj`oh00ol0003o
Ll;nog?2oP0:og?2oP03o`000?m[_okoJkon00_oJkon00?o0000of:loOmR_?d02_mR_?d00ol0003o
F;SloeRho007oeRho004o`000?mH^?coF;Slo`0000_oC[?j0_l0000Cooooo`03o`000?oooooooooo
02Sooooo0006ooooo`Go00000oooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo00Go
oooo0ol0000;oi;9nP;o00003?n>b_`00ol0003oR/[moh[:o@03o`0000WoT<Sk0_l0000<oh_8o004
o`000?n6b?goQ/SmohK8o@Go00001On<ao/00ol0003oQlOmohO7o@0;ohO7o@03o`000?n1a_koPLKn
00WoPLKn00Co0000og_5o_mkaOkoNlGn1_l00004oh75o@?o00002_mj`oh2o`0000_oLl;n00?o0000
of^oo_m[_oh02om[_oh00ol0003oH[cmof:lo@04of:loA_o00001Om>/oX00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02Oooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Sooooo
00?o0000oi;9n_nBbOX02onBbOX2o`0000WoS/[l1?l0000>oi38n`03o`000?n;b?coRlSl00OoRlSl
1_l0000;ohc7n`;o00003?n7aod00ol0003oPLKnoh76oP04oh76oPSo00001on1aOd3o`0000;oPLGm
00?o0000og[3o_mj`oh02_mj`oh00ol0003oLl;nog?2oP09og?2oP03o`000?m[_okoJkon00GoJkon
3?l00008ofRmo@03o`000?mO^OgoGkWm00KoGkWm00Go0000oenioOmO^OgoGkWmo`000005oeFen`So
00004Oooool2o`0002Sooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`;o00002_ooool2o`0000goT/Wj00Co0000ohk:
o?n>b_coS/[l1Ol00004oiC7n@03o`000?n@b?_oT<Sk00coT<Sk00Co0000oh_8o?n;b?coRlSl1Ol0
0005oi37nP03o`000?n<ao_oS<Ok00_oS<Ok00?o0000ohO7oOn7aod01on7aod9o`0000OoQlGl0_l0
0003oh75o@?o00001_n1aOd00ol0003oN/?nog[3oP0:og[3oP03o`000?mc`_koLl;n00CoLl;n3?l0
0008og6ooP03o`000?mX_OgoJ;gm00[oJ;gm00?o0000oenioOmO^Od01OmO^Od00ol0003oGkWmoeni
o@02oenio@03o`000?mE]O_oEKGk00[oEKGk00?o0000ooooooooool03_ooool2o`0002Sooooo0009
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02oooool2o`0000WoT/Wj1_l0000:oiC7n@;o0000
2on@b?/5o`0000_oT<Oj0_l0000<ohc7n`04o`000?n7aogoQlOmohO7o@Go00001On<aO/00ol0003o
QlGlohO5o00:ohO5o0?o00002_n1aOd00ol0003oN/?nog[3oP04og[3oPco00001omi`_h00ol0003o
LKonog6ooP0;og6ooP03o`000?mX_OgoJ;gm00[oJ;gm00?o0000oenioOmO^Od01OmO^Od00ol0003o
GkWmoenio@02oenio@03o`000?mE]O_oEKGk00[oEKGk00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Uooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00gooooo00Co0000
oi;9n_nBbO[oT/Wj1Ol00005oiO6m`03o`000?nDaoWoU<Oi00[oU<Oi0_l00006oi38n`?o00001?nD
a_P00ol0003oT<Ojoi37nP0;oi37nP03o`000?n<ao_oS<Ok00OoS<Ok1_l0000;ohc5n`03o`000?n7
aOcoQlGl00KoQlGl0ol000000on7aOco0000o`000006oh75o@_o00002?n0`od00ol0003oNL;nogW2
oP09ogW2oP;o00003?ma_oh00ol0003oJ;gmofRmo@0:ofRmo@03o`000?mO^OgoGkWm00GoGkWm00?o
0000oenioOmO^Od00_mO^Od00ol0003oEKGkoeFen`0:oeFen`03o`000?oooooooooo00kooooo00?o
0000ooooooooool09Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0>ooooo`?o
00002onGa_L2o`0000coU<Oi00?o0000oi38non@b?/00ol00008oiC6n0;o00003?n@aoX01?l0003o
S<Okohc7non<ao/5o`0000GoTLGi00?o0000ohc5non<aO/02_n<aO/00ol0003oQlGlohO5o002ohO5
o0?o00000on7aO`9o`0000OoQ/Cl00?o0000oh33oOn0`od02_n0`od2o`0000_oNL;n00?o0000og6o
o_ma_oh01?ma_oh^o`00013ooooo00?o0000ooooooooool09?ooool000Oooooo0ol00004ooooo`;o
00001?ooool2o`0000Cooooo0_l0000Booooo`03o`000?nGa_OoUlKg00_oUlKg00?o0000oiC7nOnD
aoT01onDaoT5o`0000goU<Kh00?o0000oi37n_n@aoX01on@aoX6o`0000_oTLGi00?o0000ohc5non<
aO/02_n<aO/:o`0000GoS<Cj00?o0000ohK4o?n6a?`02On6a?`00ol0003oP<?moh33o@0;oh33o@03
o`000?mi`_koNL;n00CoNL;n2ol00008ogO0o@03o`000?m__OgoKkgm00WoKkgm00?o0000ofJjoOmV
^_d01?mV^_d00ol0003oI[[mofJjo@04ofJjo@03o`000?mL]_coG;Kl00WoG;Kl00?o0000oooooooo
ool03Oooool2o`0000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go
00000_ooool001[ooooo00?o0000ooooooooool04_ooool00ol0003oUlKgoiO6m`0;oiO6m`04o`00
0?nDaoWoU<OioiC7n@Go00001OnHaOH00ol0003oU<KhoiC6n00;oiC6n004o`000?n@ao[oT<Ojoi37
nPGo00001OnEaOL00ol0003oTLGioi75n@0:oi75n@03o`000?n<aO_oS<Gk00OoS<Gk1_l0000<ohc4
nP03o`000?n6a?coQ/Cl00WoQ/Cl00?o0000oh33oOn0`od02?n0`od9o`0000OoO/;m00?o0000ogO0
oOmg`?d02_mg`?d00ol0003oKkgmofnmo@09ofnmo@03o`000?mV^_goI[[m00CoI[[m00?o0000ofJj
oOmV^_d01?mV^_d00ol0003oG;Kloebfo009oebfo003o`000?oooooooooo00gooooo00?o0000oooo
ooooool02oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool001[ooooo00?o0000ooooooooool04oooool2o`0000[oUlKg1Ol0
000;oiS5mP;o00002_nDa_P5o`0000_oULGg0_l0000;oi75n@04o`000?n<aO_oS<Gkohc5n`Ko0000
1?nAa?T00ol0003oS<Cjohc4nP0;ohc4nP03o`000?n6a?coQ/Cl00WoQ/Cl00Co0000oh33oOn0`ogo
P<?m1_l00004ohG3n`03o`000?mn`_goO/;m00[oO/;m00?o0000ogO0oOmg`?d02_mg`?d00ol0003o
Kkgmofnmo@09ofnmo@03o`000?mV^_goI[[m00CoI[[m00?o0000ofJjoOmV^_d01?mV^_d00ol0003o
G;Kloebfo009oebfo003o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool5o`0000;o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00;ooooo000Jooooo`;o00005_ooool00ol0003oUlKgoiO6m`04oiO6m`?o00001?nLa?@00ol0
003oV<GfoiS5mP0;oiS5mP03o`000?nDa_SoU<Kh00CoU<Kh0ol00004oiW4m@03o`000?nEaOOoULGg
00_oULGg00?o0000oi75nOnAaOT01onAaOT8o`0000SoTLCi0_l0000<ohc4nP03o`000?n6a?coQ/Cl
00CoQ/Cl2?l0000;ohG3n`03o`000?mn`_goO/;m00[oO/;m00?o0000ogO0oOmg`?d02_mg`?d00ol0
003oKkgmofnmo@09ofnmo@03o`000?mV^_goI[[m00CoI[[m3ol00004oebfo003o`000?oooooooooo
00gooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00Oooool001[ooooo00?o0000ooooooooool05_ooool0
0ol0003oUlKgoiO6m`03o`0000SoW<Cd00?o0000oiS5m_nHaOH02onHaOH00ol0003oU<KhoiC6n003
o`0000SoVLCe00?o0000oiG5monEaOL02onEaOL01?l0003oTLGioi75nOnAaOT5o`0000;oULCg0ol0
000=oi74n@03o`000?n<a?[oS<Cj00OoS<Cj2Ol00007oh_3nP03o`000?n5`o_oQL?k00[oQL?k00?o
0000ogk2oOmn`_d02_mn`_d00ol0003oMl3mogO0o@04ogO0oAWo00001om/^od00ol0003oH[Olof:g
o004of:go0Ko00003_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`7o00000Oooool1ooooo`006_ooool00ol0003o
ooooooooo`0Gooooo`;o00003?nLa?@2o`0000[oV<Gf1?l0000<oiW4m@03o`000?nEaOOoULGg00Wo
ULGg1Ol00004oiG4m`?o00000onEa?L2o`0000coTLCi00Co0000ohc4n_n<a?[oS<Cj1Ol00004oi33
n003o`000?n;`o[oRl?j00[oRl?j00?o0000ohG3non5`o/02_n5`o/00ol0003oO/;mogk2o@04ogk2
o@co00001oml`?`00ol0003oM;kmogBno@0:ogBno@03o`000?m/^ogoK;_m00;oK;_m00?o0000ofbk
oOm/^od01Om/^od00ol0003oH[Olof:go009of:go003o`000?oooooooooo00_ooooo0_l0000:oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`7o0000
0Oooool1ooooo`006_ooool2o`0001[ooooo00?o0000oic4m?nLa?@02onLa?@00ol0003oV<GfoiS5
mP04oiS5mP?o00001?nL`o<00ol0003oVLCeoiW4m@0:oiW4m@03o`000?nEaOOoULGg00CoULGg1?l0
0003oiW3m@03o`000?nEa?OoULCg00?o00002?nEa?L00ol0003oTLCioi74n@07oi74n@Ko00002_n@
`oP00ol0003oRl?joh_3nP0:oh_3nP03o`000?n5`o_oQL?k00OoQL?k2Ol00007oh?1n`03o`000?ml
`?coO<3l00[oO<3l00?o0000ogBnoOmd__d02_md__d00ol0003oK;_mofbko@02ofbko@03o`000?m/
^ogoK;_m00GoK;_m00?o0000of:go?mR]o`02OmR]o`00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Wooooo0_l0000:ooooo`;o00000oooool3o`0000?ooooo000Iooooo`03o`000?oooooo
oooo01_ooooo0_l0000<oic4m003o`000?nHaOKoV<Gf00?o00002?nL`o<2o`0000_oVLCe00?o0000
oiG5monEaOL00ol00007oiW3m@?o00003?nEa?L01?l0003oTLCioi74nOnAa?T5o`0000CoUL?f00?o
0000oi33n?n@`oP02_n@`oP00ol0003oRl?joh_3nP0:oh_3nP04o`000?n5`o_oQL?kohG3n`Go0000
1On:`_X00ol0003oPl7koh?1n`09oh?1n`03o`000?ml`?coO<3l00[oO<3l00?o0000ogBnoOmd__d0
2_md__d01Ol0003oK;_mofbkoOm/^ogo000000SoK;_m00?o0000of:go?mR]o`02OmR]o`00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01oooooo0006ooooo`?o00000oooool2o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo01gooooo0_l00009oic4m0Co00003OnL`o<00ol0003oVLCe
oiW4m@07oiW4m@Co00001onI`oD3o`0000;oVL?e00?o0000oiG4monEa?L02OnEa?L5o`0000[oUL?f
00?o0000oi33n?n@`oP02_n@`oP00ol0003oRl?joh_3nP07oh_3nPKo00002on:`_X00ol0003oPl7k
oh?1n`09oh?1n`03o`000?ml`?coO<3l00[oO<3l00?o0000ogBnoOmd__d01?md__dPo`0000gooooo
00?o0000ooooooooool07_ooool000Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`04
o`000?nLa?CoW<Cdoic4m0Go00001?nO`_400ol0003oW<?coic3l`0;oic3l`04o`000?nIa?GoVLCe
oiW4m@Go00001?nM`_801?l0003oVL?eoiW3mOnI`oD3o`0000KoVL?e00?o0000oiG4monEa?L01?nE
a?L4o`0000?oVL;d00?o0000oiG3m_nE`oH02_nE`oH00ol0003oT<?hoi33n00:oi33n004o`000?n;
`o[oRl?joh_3nPGo00001On?`_P00ol0003oR/;joh[2nP0:oh[2nP03o`000?n3`O_oPl7k00WoPl7k
00?o0000ogc0o?ml`?`01?ml`?`<o`0000OoN[kl00Go0000og6koOma^ogoLK_mo`000007og6ko@03
o`000?mW^?coIkSl00[oIkSl00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Nooooo`00
1?ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`;o00008Oooool3o`0000[oWl;a0_l0000:oic3l`Go00002_nM`_83o`0000[oVL?e00?o0000oiG4
monEa?L00ol00008oiW2m003o`000?nE`oKoUL?f00[oUL?f00?o0000oi33n?n@`oP01on@`oP6o`00
00_oSl;h00?o0000oh[2n_n:`_X02_n:`_X00ol0003oPl7koh?1n`04oh?1n`_o00001on1`?/00ol0
003oN[klogZno00:ogZno005o`000?ma^ogoLK_mog6koOl000001oma^od00ol0003oIkSlofNho00:
ofNho003o`000?oooooooooo00Wooooo0_l0000Oooooo`001?ooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?nO`_7oWl;a00[oWl;a00?o0000oic3lonL`o<01?nL`o<3o`0000CoX<7`
00?o0000oig2l_nM`_801OnM`_83o`0000;oWL;b00?o0000oiW3mOnI`oD01onI`oD4o`0000coVL;d
00?o0000oiG3m_nE`oH02_nE`oH01?l0003oT<?hoi33n?n@`oP5o`0000GoU<;f00?o0000oho2n?n?
`_P02_n?`_P00ol0003oR/;joh[2nP07oh[2nPWo00001on8`OX00ol0003oPL3koh70n`09oh70n`03
o`000?mj__coN[kl00[oN[kl00Co0000og6koOma^ogo00002?ma^od00ol0003oIkSlofNho00:ofNh
o003o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool000Gooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool09?ooool00ol0003oWl;aoio2l@0:oio2l@03o`000?nL`o?oW<?c00?o00002?nP`O00
1?l0003oWL;boig2l_nM`_83o`0000KoWL;b00Co0000oiW3mOnI`oGoVL?e1Ol00004oig2lP03o`00
0?nI`_CoVL;d00[oVL;d00?o0000oiG3m_nE`oH01onE`oH6o`0000_oU<;f00?o0000oho2n?n?`_P0
2_n?`_P01?l0003oR/;joh[2n_n:`_X5o`0000CoS/7h00?o0000ohS1n_n8`OX02_n8`OX00ol0003o
PL3koh70n`09oh70n`03o`000?mj__coN[kl00[oN[kl00Co0000og6koOma^ogo00002?ma^od00ol0
003oIkSlofNho00:ofNho003o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool000Ko
oooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool2
o`0002Kooooo00?o0000oio2lOnO`_402?nO`_44o`0000coX<7`0ol00008oig2lPGo00002_nM`_82
o`0000_oVL;d00Co0000oiG3m_nE`oKoUL?f1Ol00005oiW2m003o`000?nD`_KoU<;f00[oU<;f00?o
0000oho2n?n?`_P01on?`_P6o`0000[oS/7h00?o0000ohS1n_n8`OX02_n8`OX00ol0003oPL3koh70
n`09oh70n`03o`000?mj__coN[kl00CoN[kl8?l0000;ooooo`03o`000?oooooooooo01_ooooo0007
ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001?ooool00ol0003oooooooooo`0V
ooooo`03o`000?nO`_7oWl;a00CoWl;a0ol00004oj;0kP03o`000?nP`O3oX<7`00OoX<7`0_l00000
0onP`O3o0000oig2lP05oig2lP?o00000onP`O000ol0003oWL;boig2lP0;oig2lP03o`000?nI`_Co
VL;d00OoVL;d1Ol0000;oiW2m003o`000?nD`_KoU<;f00[oU<;f00Co0000oho2n?n?`_SoSl;h1Ol0
0004oi?2mP03o`000?n>`OSoS/7h00[oS/7h00?o0000ohS1n_n8`OX02_n8`OX00ol0003oPL3koh70
n`04oh70n`_o00001omn__/01?l0003oM[clogJlo?l00009ogJlo003o`000?m]^OcoKKWl00WoKKWl
00?o0000ooooooooool02?ooool2o`0001cooooo000Hooooo`03o`000?oooooooooo02Oooooo00?o
0000oio2lOnO`_400ol00008oj;0kP03o`000?nP`O3oX<7`00?oX<7`0ol00004oj31l003o`000?nM
`_;oWL;b00?o00001onP`O000ol0003oWL;boig2lP0;oig2lP04o`000?nI`_CoVL;doiW2m0Go0000
1?nL`O800ol0003oVL;doiW2m00:oiW2m003o`000?nD`_KoU<;f00OoU<;f1_l0000:oi?2mP03o`00
0?n>`OSoS/7h00[oS/7h00?o0000ohS1n_n8`OX01?n8`OX<o`0000KoQ[oj00?o0000ogjnnomn__/0
2_mn__/00ol0003oM[clo`00000:ogJlo003o`000?m]^OcoKKWl00WoKKWl00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Jooooo`006?ooool00ol0003oooooooooo`0Xooooo`;o00003?nR
`>h00ol0003oX<7`o`000002o`0000KoX<7`1?l0000;oj31l003o`000?nM`_;oWL;b00WoWL;b1Ol0
000:oic1lP03o`000?nI`_CoVL;d00[oVL;d00Co0000oiC2m_nD`_KoU<;f1Ol00004oiS1m003o`00
0?nC`_KoTl;f00[oTl;f00?o0000ohk1n?n>`OP01on>`OP9o`0000OoS<7h00?o0000ohJon_n6_oX0
2On6_oX00ol0003oO[kkogjnn`0:ogjnn`03o`000?mf_?co000000[oM[cl00?o0000offio?m]^O`0
2Om]^O`00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo000Gooooo`;o0000;?oo
ool00ol0003oX/3^oj;0kP08oj;0kP?o00001_nP`O03o`0000?oXko]00?o0000oj31l?nP`O002_nP
`O000ol0003oWL;boig2lP04oig2lPCo00000onP`?000ol0003oW<7boic1lP0:oic1lP03o`000?nI
`_CoVL;d00OoVL;d1_l0000:oiS1m003o`000?nC`_KoTl;f00[oTl;f00Co0000ohk1n?n>`OSoS/7h
1Ol00005oi;1mP03o`000?n<`OSoS<7h00WoS<7h00?o0000ohJon_n6_oX02On6_oX00ol0003oO[kk
ogjnn`0:ogjnn`03o`000?mf_?co000000CoM[cl4ol0000:ooooo`03o`000?oooooooooo01Sooooo
000Gooooo`03o`000?oooooooooo02cooooo00?o0000oj;0k_nR`>h01?nR`>h3o`0000?oX/3^00?o
0000oj31l?nP`O000ol00007oj>ok@03o`000?nP`O3oX<7`00[oX<7`00?o0000oig2l_nM`_800ol0
0008oj30l003o`000?nL`O;oW<7b00[oW<7b00Co0000oiW2m?nI`_CoVL;d1Ol00005oic1lP03o`00
0?nH`OCoV<7d00WoV<7d00?o0000oi?2m_nC`_H01onC`_H6o`0000_oT/7f00?o0000ohc1n?n<`OP0
2On<`OP00ol0003oQ[ojohJonP09ohJonP03o`000?mn___oO[kk00CoO[kk3?l00007og^ln`03o`00
0?mb^_coL[[l00WoL[[l00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`;o0000
4?ooool001Oooooo00?o0000ooooooooool0;Oooool00ol0003oX/3^oj;0kP03o`0000GoX/3^1?l0
000;oj>ok@03o`000?nP`O3oX<7`00SoX<7`1?l0000<oj30l003o`000?nL`O;oW<7b00SoW<7b1Ol0
000;oic1lP03o`000?nH`OCoV<7d00WoV<7d00Co0000oi?2m_nC`_KoTl;f1Ol00005oiO1m003o`00
0?nB`OKoT/7f00[oT/7f00?o0000ohc1n?n<`OP02On<`OP00ol0003oQ[ojohJonP04ohJonP_o0000
1on3__X2o`0000_oNkck00?o0000og:jo?mb^_`02Omb^_`00ol0003oooooooooo`06ooooo`;o0000
1_ooool01?l0003oooooooooool0000?ooooo`005oooool2o`0002kooooo0ol00005oj;0kP?o0000
0onU_^/00ol0003oXko]oj>ok@0:oj>ok@03o`000?nP`O3oX<7`00CoX<7`0ol00004oj>ok@03o`00
0?nP`?3oX<3`00[oX<3`00?o0000oic1l_nL`O801?nL`O83o`0000?oWl3`00?o0000oic1l_nL`O80
2onL`O800ol0003oV<7doiS1m007oiS1m0Go00002onG`O@00ol0003oT/7foi;1mP0:oi;1mP03o`00
0?n<`OSoS<7h00CoS<7h2ol00006ohZon@03o`000?n3__[oPkkj00[oPkkj0_l0000;og^ln`03o`00
0?mb^_coL[[l00WoL[[l00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000oooooo0003ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo02[ooooo0ol00002ooooo`03o`000?nR`>koX/3^00?o00001onU_^/00ol0003oXko]
oj>ok@0:oj>ok@03o`000?nP`O3oX<7`00?o00002?nS_nd00ol0003oX<3`oj30l00:oj30l003o`00
0?nL`O;oW<7b00?o00001onO`?000ol0003oW<7boic1lP0;oic1lP04o`000?nH`OCoV<7doiS1m0Go
00001?nK`?800ol0003oUl7doiO1m00:oiO1m003o`000?nB`OKoT/7f00OoT/7f2Ol00006oi30m`03
o`000?n:_oWoR[oi00WoR[oi00?o0000oh>nn_n3__X02_n3__X2o`0000_oNkck00?o0000og:jo?mb
^_`02Omb^_`00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00003oooool000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Wooooo`?o00001_oo
ool2o`0000_oYKk[00?o0000oj>okOnS_nd02?nS_nd4o`0000coXko]00?o0000oj30l?nP`?002?nP
`?04o`0000_oWl3`00?o0000oic1l_nL`O802OnL`O85o`0000[oVl3b00?o0000oiO1m?nG`O@02_nG
`O@01?l0003oT/7foi;1m_nB`OH5o`0000?oUL3d00?o0000oi30mon@`?L02_n@`?L00ol0003oR[oi
ohZon@09ohZon@03o`000?n3__[oPkkj00[oPkkj00?o0000og^lnomk_?/01?mk_?/Co`0000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000?ooooo`000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo02Cooooo0ol0000:ooooo`03o`000?nU_^_oYKk[00[oYKk[00?o0000
oj>okOnS_nd01?nS_nd3o`0000CoYKk[00?o0000oj>okOnS_nd02_nS_nd00ol0003oX<3`oj30l004
oj30l0?o00000onS_nd00ol0003oWl3`oio0l00:oio0l003o`000?nL`O;oW<7b00CoW<7b1?l00002
oinol003o`000?nK`?;oVl3b00_oVl3b00?o0000oiO1m?nG`O@01onG`O@6o`0000WoUL3d00?o0000
oi30mon@`?L02_n@`?L00ol0003oR[oiohZon@09ohZon@03o`000?n3__[oPkkj00CoPkkj3?l00006
ognlnP03o`000?mg^__oMk[k00[oMk[k00?o0000ooooooooool01?ooool3o`0000?ooooo00Co0000
oooooooooooo00003oooool000;ooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000oooool2o`0002?ooooo0ol0000>ooooo`03o`000?nU_^_oYKk[00[oYKk[
00?o0000oj>okOnS_nd00ol00008ojFnj`03o`000?nS_ngoXko]00[oXko]00?o0000oj30l?nP`?00
0ol00007oj>ok@03o`000?nO`?3oWl3`00[oWl3`00?o0000oic1l_nL`O800ol00007oinol003o`00
0?nK`?;oVl3b00_oVl3b00Co0000oiO1m?nG`OCoUl7d1Ol00003oi[0lP03o`000?nE`?CoUL3d00[o
UL3d00?o0000oi30mon@`?L02_n@`?L00ol0003oR[oiohZon@04ohZon@_o00001on7__T00ol0003o
OkcjognlnP09ognlnP03o`000?mg^__oMk[k00[oMk[k00?o0000ooooooooool00ol000000ooooooo
0000o`000004ooooo`;o00004?ooool000;ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07oooool3o`00
01;ooooo00?o0000ojFnjonU_^/02?nU_^/4o`0000coYKk[00?o0000oj>okOnS_nd02?nS_nd4o`00
00_oXko]00?o0000oio0l?nO`?002?nO`?04o`0000_oWko`00?o0000oi_0l_nK`?802OnK`?85o`00
00WoV/3b00?o0000oiG0m?nE`?@02_nE`?@00ol0003oT<3goi30m`07oi30m`Wo00001_n>_oL00ol0
003oQkkiohNnn@0:ohNnn@03o`000?mo_?[oOkcj00WoOkcj00?o0000ogNjnomg^_/02_mg^_/2o`00
00Gooooo00?o0000ooooooooool05?ooool000?ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07Oooool2
o`0001Kooooo00?o0000ojFnjonU_^/01?nU_^/3o`0000CoZ;cX00?o0000ojFnjonU_^/02_nU_^/0
0ol0003oXko]oj>ok@04oj>ok@?o00001?nU_^/00ol0003oXko]oj>ok@09oj>ok@03o`000?nO`?3o
Wl3`00CoWl3`0ol00004oj:ok@03o`000?nO_o3oWko`00WoWko`00?o0000oi_0l_nK`?801?nK`?84
o`0000;oW[o`00?o0000oi[0l_nJ`?802_nJ`?800ol0003oUL3doiG0m00:oiG0m004o`000?n@`?Oo
T<3goi30m`Go00001?nC_oD00ol0003oS[ogohjom`09ohjom`03o`000?n7__WoQkki00WoQkki0_l0
000;ognlnP03o`000?mg^__oMk[k00CoMk[k1ol00005ooooo`03o`000?oooooooooo01Cooooo0004
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo01[ooooo0ol0000I
ooooo`03o`000?nU_^_oYKk[00?o00002?nX_>P00ol0003oYKk[ojFnj`0:ojFnj`03o`000?nS_ngo
Xko]00?o00002?nU_^/00ol0003oXko]oj>ok@09oj>ok@03o`000?nO`?3oWl3`00?o00002?nR_nd0
0ol0003oWko`oinol009oinol003o`000?nK`?;oVl3b00?o00001onN_o000ol0003oV/3boi[0lP0:
oi[0lP03o`000?nE`?CoUL3d00OoUL3d1_l0000:oi>om@03o`000?n>_oOoS[og00WoS[og00?o0000
ohNnnOn7__T01on7__TEo`0000KoNk_j00?o0000ooooooooool00oooool00ol0003oooooooooo`0D
ooooo`005_ooool2o`0001Sooooo0ol0000Mooooo`;o00003?nX_>P00ol0003oYKk[ojFnj`08ojFn
j`Co00003?nU_^/00ol0003oXko]oj>ok@07oj>ok@Co00003?nR_nd00ol0003oWko`oinol007oino
l0Co00002onN_o000ol0003oV/3boi[0lP0:oi[0lP04o`000?nE`?CoUL3doiG0m0Go00001?nI_o<0
0ol0003oTkoeoi>om@0:oi>om@03o`000?n>_oOoS[og00WoS[og00Co0000ohNnnOn7__WoQkki1Ol0
0003oh^nn0;o00002on4_OT00ol0003oNk_jog^knP09og^knP03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04oooool001Kooooo00?o0000ooooooooool05?ooool3o`0002;ooooo00?o0000
ojRlj?nX_>P02_nX_>P00ol0003oYKk[ojFnj`04ojFnj`?o00000onX_>P00ol0003oYKk[ojFnj`0;
ojFnj`04o`000?nS_ngoXko]oj>ok@Go00001?nU_N/00ol0003oX[o]oj:ok@0:oj:ok@04o`000?nO
_o3oWko`oinol0Go00001?nR_^h00ol0003oW[o`oijol009oijol003o`000?nJ`?;oV/3b00OoV/3b
1_l0000:oiVol`03o`000?nC_oGoTkoe00[oTkoe00?o0000ohjomon>_oL01?n>_oL8o`0000WoRkkh
0_l0000;ohBmn@03o`000?mk^o[oNk_j00WoNk_j00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Cooooo`005Oooool00ol0003oooooooooo`0Booooo`?o00009_ooool00ol0003oZ;cXojRl
j00:ojRlj003o`000?nU_^_oYKk[00?o00001onX_>P00ol0003oYKk[ojFnj`0:ojFnj`Co00002_nU
_N/00ol0003oX[o]oj:ok@08oj:ok@Go00002_nR_^h00ol0003oW[o`oijol009oijol004o`000?nJ
`?;oV/3boi[0lPGo00001?nM_o000ol0003oVKocoiVol`0:oiVol`03o`000?nC_oGoTkoe00OoTkoe
2Ol00006oi6omP03o`000?n;__SoRkkh00SoRkkh00?o0000oh^nn?l000002on4_OT00ol0003oNk_j
og^knP09og^knP05o`000?ooooooooooooooool000005Oooool001Gooooo0_l0000@ooooo`?o0000
:_ooool00ol0003oZ;cXojRlj008ojRlj0Co00002onX_>P00ol0003oYKk[ojFnj`06ojFnj`?o0000
0_nX_>P00ol0003oYKg[ojFmj`0:ojFmj`03o`000?nR_ngoX[o]00CoX[o]0ol00003ojFnj`03o`00
0?nR_^koX[k^00[oX[k^00?o0000oijol?nN_o001onN_o05o`0000[oWKo`00?o0000oiVolonI_o<0
2_nI_o<01?l0003oTkoeoi>omOnC_oD5o`0000?oUkoc00?o0000oi6om_nA_oH02_nA_oH00ol0003o
Rkkhoh^nn008oh^nn003o`000?n;__So000000KoQ;gi4_l00002ooooo`03o`000?oooooooooo01?o
oooo000Eooooo`03o`000?oooooooooo00cooooo0ol0000^ooooo`03o`000?nX_>SoZ;cX00CoZ;cX
0ol00003ojZkiP03o`000?nX_>SoZ;cX00[oZ;cX00?o0000ojFnjonU_^/00onU_^/2o`0000KoZ;cX
00?o0000ojFmjonU_N/02_nU_N/00ol0003oX[o]oj:ok@03o`0000OoYKk[00?o0000oj:nk_nR_^h0
2_nR_^h01?l0003oW[o`oijol?nN_o05o`0000?oXKk^00?o0000oifol?nM_o002_nM_o000ol0003o
VKocoiVol`07oiVol`Ko00002OnG_o<00ol0003oTKofoi6omP0:oi6omP03o`000?n;__SoRkkh00Co
Rkkh3?l00005ohNmn003o`000?mo^o[oOk_j00WoOk_j00Co0000oooooooooooo00005Oooool001Go
oooo00?o0000ooooooooool02Oooool3o`0003;ooooo00?o0000ojRlj?nX_>P00ol00007ojZkiP03
o`000?nX_>SoZ;cX00[oZ;cX00?o0000ojFnjol000000_l00009ojRlj003o`000?nU_N_oYKg[00So
YKg[1?l0000;ojFnj`03o`000?nR_^koX[k^00SoX[k^1Ol00009oj6nkP03o`000?nM_o3oWKo`00[o
WKo`00Co0000oiVolonI_o?oVKoc1Ol00003oibol@03o`000?nG_o?oUkoc00[oUkoc00?o0000oi6o
m_nA_oH01onA_oH9o`0000CoS[kf00?o0000ohjnm_l000002on7_OP00ol0003oOk_jognknP09ognk
nP03o`000?oooooo000001Gooooo000Eooooo`03o`000?oooooooooo00Kooooo0ol0000fooooo`;o
00002onZ^nH00ol0003oZ;cXojRlj008ojRlj0?o00003OnX_>P00ol0003oYKg[ojFmj`04ojFmj`?o
00000_nW_>P00ol0003oYKk[ojFnj`0;ojFnj`03o`000?nR_^koX[k^00CoX[k^0ol00002ojBnj`03
o`000?nQ_^koXKk^00[oXKk^00?o0000oifol?nM_o001onM_o06o`0000WoW;oa00?o0000oiNolonG
_o<02_nG_o<01?l0003oTKofoi6om_nA_oH5o`0000CoU;kd00?o0000ohjnm_n>__H01on>__H00ol0
003oS[kfo`00000;ohNmn003o`000?mo^o[oOk_j00WoOk_j0_l0000Eooooo`005Oooool2o`0000Co
oooo0ol0000jooooo`03o`000?nZ^nKoZ[_V00[oZ[_V00?o0000ojRlj?nX_>P01?nX_>P3o`0000?o
Z[_V00?o0000ojRlj?nX_>P02onX_>P00ol0003oYKg[ojFmj`03o`0000KoYkcX00?o0000ojFnjonU
_^/02onU_^/00ol0003oX[k^oj:nkP03o`0000KoY;k[00?o0000oj6nk_nQ_^h02_nQ_^h01?l0003o
WKo`oifol?nM_o05o`0000CoX;k^00?o0000oibolOnL_o402OnL_o400ol0003oUkocoiNol`07oiNo
l`Ko00002_nD__@00ol0003oS[kfohjnmP07ohjnmP03o`000?n>__Ko000000_oQkgh00?o0000ognk
n_mo^oX02Omo^oX2o`0001Cooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`00
00Cooooo00Co0000oooooooooooooooo0ol0000nooooo`03o`000?nZ^nKoZ[_V00[oZ[_V00?o0000
ojRlj?nX_>P00ol00007ojZkiP03o`000?nX_>SoZ;cX00[oZ;cX0ol0000:ojNlj003o`000?nU_^_o
YKk[00WoYKk[1?l0000:ojBnj`03o`000?nQ_^koXKk^00SoXKk^1Ol0000:oj2nkP03o`000?nL_o7o
W;oa00WoW;oa00Co0000oiNolonG_o?oUkoc1Ol00004oiZolP03o`000?nD__CoU;kd00[oU;kd00?o
0000ohjnm_n>__H01on>__H00ol0003oS[kfo`000006ohNmn1;o00005?ooool00005o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo1?l00012ooooo`03o`000?nZ^nKoZ[_V00SoZ[_V1?l0000;ojZkiP03o`000?nX_>SoZ;cX00Ko
Z;cX0ol000000onZ^nKo0000ojNlj00;ojNlj003o`000?nU_^_oYKk[00CoYKk[1?l00002ojNmj@03
o`000?nT_^_oY;k[00[oY;k[00?o0000oj6nk_nQ_^h01?nQ_^h3o`0000?oXkk/00?o0000oj2nk_nP
_^h02_nP_^h00ol0003oW;oaoibol@07oibol@Go00002_nJ_o800ol0003oU;kdoiBnm00:oiBnm003
o`000?n>__KoS[kf00CoS[kf2ol0000Aooooo`03o`000?oooooooooo01;ooooo00001Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003
ooooo`;o0000AOooool00ol0003oZ[_VojZkiP04ojZkiP?o00000on/^^<00ol0003oZ[_VojZkiP0:
ojZkiP03o`000?nX_>SoZ;cX00?oZ;cX0_l00005ojZkiP03o`000?nW_>SoYkcX00[oYkcX00?o0000
ojFnjonU_^/00ol00007ojNmj@03o`000?nT_^_oY;k[00[oY;k[00?o0000oj6nk_nQ_^h00ol00007
oj>nk003o`000?nP_^koX;k^00[oX;k^00Co0000oibolOnL_o7oW;oa1Ol00003oijnk`03o`000?nJ
_o;oV[ob00[oV[ob00?o0000oiBnm?nD__@01onD__@9o`0000?ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Booooo`0000Coooooo`000?l0003o00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0@oooool00ol0003o
Z[_VojZkiP03o`0000Oo[;[S00?o0000ojZki_nZ^nH02_nZ^nH00ol0003oZ;cXo`000002o`0000So
Z[_V00?o0000ojNlj?nW_>P02?nW_>P4o`0000_oYkgY00?o0000ojBnjonT_^/02?nT_^/4o`0000_o
Xkk/00?o0000oj2nk_nP_^h02?nP_^h5o`0000WoW[k_00?o0000oiZol_nJ_o802_nJ_o801?l0003o
U;kdoiBnm?nD__@5o`0000gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Boooo
o`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`13ooooo`;o00002on/^^<00ol0003oZ[_VojZk
iP08ojZkiP?o00003?nZ^nH00ol0003oYkcXojNlj004ojNlj0?o00000onY^nH00ol0003oYkgYojNm
j@0:ojNmj@03o`000?nT_^_oY;k[00CoY;k[0ol00003ojJmj@03o`000?nS_^coXkk/00[oXkk/00?o
0000oj2nk_nP_^h01?nP_^h3o`0000?oX[k]00?o0000oijnkonN_^l02OnN_^l00ol0003oV[oboiZo
lP07oiZolPKo00004oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo0000
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo04;ooooo00?o0000ojbjhon/^^<02on/^^<00ol0003o
Z[_VojZkiP04ojZkiP?o00000on/^^<00ol0003oZ[_VojZkiP0:ojZkiP03o`000?nW_>SoYkcX00?o
00001onY^nH00ol0003oYkgYojNmj@0:ojNmj@03o`000?nT_^_oY;k[00?o00001onV_NT00ol0003o
Xkk/oj>nk00:oj>nk003o`000?nP_^koX;k^00?o00001onR_^d00ol0003oW[k_oijnk`09oijnk`04
o`000?nJ_o;oV[oboiZolPGo00006Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
01;ooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Wooooo0_l00013oooo
o`03o`000?n/^^?o[;[S00_o[;[S00?o0000ojZki_nZ^nH00ol00007ojbjh`03o`000?nZ^nKoZ[_V
00WoZ[_V0ol0000;ojVkiP03o`000?nW_NWoYkgY00SoYkgY1?l0000;ojJmj@03o`000?nS_^coXkk/
00OoXkk/1Ol0000;oj:nk@03o`000?nN_^ooW[k_00OoW[k_1Ol0000Oooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool04Oooool001_ooooo00?o0000ooooooooool0@Oooool00ol0003o
[;[Sojbjh`0:ojbjh`?o00002on/^^<00ol0003oZ[_VojZkiP06ojZkiP;o00000_n/^^@00ol0003o
ZK_VojVkiP0:ojVkiP03o`000?nW_NWoYkgY00CoYkgY0ol00003ojVli`03o`000?nV_NWoY[gY00[o
Y[gY00Co0000oj>nk?nS_^coXkk/1Ol00003ojJmjP03o`000?nR_^goX[k]00_oX[k]00Co0000oijn
konN_^ooW[k_1Ol0000Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool0
01cooooo00?o0000ooooooooool0@Oooool00ol0003o[;[Sojbjh`06ojbjh`?o00000_n^^>400ol0
003o[;[Sojbjh`0:ojbjh`03o`000?nZ^nKoZ[_V00;oZ[_V0ol00005ojbji003o`000?nY^nKoZK_V
00[oZK_V00?o0000ojNmjOnW_NT00ol00007ojVli`03o`000?nV_NWoY[gY00SoY[gY1Ol00009ojJm
jP03o`000?nR_^goX[k]00WoX[k]1Ol0000Zooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04Oooool001gooooo00?o0000ooooooooool0@Oooool00ol0003o[;[Sojbjh`03ojbjh`;o
00001_n^^>400ol0003o[;[Sojbjh`0:ojbjh`04o`000?nZ^nKo0000o`0000Wo[;[T00?o0000ojVk
i_nY^nH02?nY^nH4o`0000_oZKcW00?o0000ojJmjOnV_NT01?nV_NT3o`0000;oZKcW00?o0000ojJm
j_nV_NX02_nV_NX00ol0003oX[k]oj:nk@04oj:nk@Co0000<?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo017ooooo000Nooooo`03o`000?oooooooooo047ooooo00?o0000ojbjhol0
00000_l00009ojjhh@03o`000?n/^^?o[;[S00So[;[S0ol0000<ojbji003o`000?nY^nKoZK_V00Co
ZK_V0ol00002ojbji003o`000?nY_>OoZKcW00_oZKcW00?o0000ojJmjOnV_NT00ol00006ojVli`03
o`000?nV_N[oY[gZ00[oY[gZ00?o0000oj:nkOnR_^d00ol0000eooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool001oooooo0_l00012ooooo`03o`000?n^^>7o[[SQ00_o[[SQ
00?o0000ojbjhon/^^<01?n/^^<3o`0000;o[[WQ00?o0000ojbji?n/^^@02on/^^@00ol0003oZK_V
ojVkiP03o`0000Ko[;[T00?o0000ojVlionY_>L02_nY_>L3o`0000[oZKcW00?o0000ojJmj_nV_NX0
2?nV_NX4o`0003Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`008Ooo
ool00ol0003oooooooooo`10ooooo`03o`000?n^^>7o[[SQ00_o[[SQ00?o0000ojbjhon/^^<00ol0
0006ojjih@03o`000?n/^^Co[;[T00[o[;[T0ol0000:ojbji003o`000?nY_>OoZKcW00KoZKcW0ol0
00000on[^nGo0000ojVli`0;ojVli`03o`000?nV_N[oY[gZ00CoY[gZ0ol0000mooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0@?ooool0
0ol0003o[[SQojjhh@0:ojjhh@?o00002_n^^N400ol0003o[;[Tojbji006ojbji0?o00000_n^^N80
0ol0003o[;[Tojbji009ojbji003o`000?nY_>OoZKcW00?oZKcW0_l00005oj^ki@03o`000?nY_>Oo
ZKcW00[oZKcW00?o0000ojJmj_nV_NX00ol00011ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool002?ooooo00?o0000ooooooooool0@?ooool00ol0003o[[SQojjhh@06ojjh
h@?o00000_n_]ml00ol0003o[[WQojjih@09ojjih@03o`000?n/^^Co[;[T00?o[;[T0_l00006ojji
hP03o`000?n/^^Co[;[T00Wo[;[T00?o0000ojVliol000000_l00008oj^ki@03o`000?nY_>OoZKcW
00SoZKcW1?l00015ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool002Co
oooo0_l00011ooooo`03o`000?n^^>7o[[SQ00?o[[SQ0_l00006ojngg`03o`000?n^^N7o[[WQ00Wo
[[WQ00?o0000ojbji?l000000_l00009ojjihP03o`000?n/^^Co[;[T00So[;[T0ol0000;oj^ki@03
o`000?nY_>OoZKcW00CoZKcW0ol0001:ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool04?ooool002Kooooo00?o0000ooooooooool0?oooool00ol0003o[[SQo`000002o`0000Wo[kOO
00?o0000ojjihOn^^N402?n^^N42o`0000go[[WR00?o0000ojbji?n/^^@01?n/^^@3o`0000?o[KWR
00?o0000oj^kiOn[^nD02On[^nD00ol0003oZKcWojVli`03o`0004gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0@ooooo`009oooool00ol0003oooooooooo`0oooooo`03o`000?n_
]moo[kOO00_o[kOO00?o0000ojjihOn^^N401?n^^N43o`0000;o[kSO00?o0000ojjih_n^^N802on^
^N800ol0003o[;[Tojbji003o`0000Oo[KWR00?o0000oj^kiOn[^nD02?n[^nD3o`00057ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`00:?ooool00ol0003oooooooooo`0o
ooooo`03o`000?n_]moo[kOO00_o[kOO00?o0000ojjihOn^^N400ol00006ojnhg`03o`000?n^^N;o
[[WR00[o[[WR0ol0000;ojfihP03o`000?n[^nGoZk_U00CoZk_U0ol0001Eooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool04?ooool002Wooooo0_l00010ooooo`03o`000?n_]moo[kOO
00[o[kOO0ol0000:ojnhg`03o`000?n^^N;o[[WR00Ko[[WR0ol000000on_^=oo0000ojfihP0<ojfi
hP03o`000?n[^nGoZk_U00?o0000F?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
013ooooo000[ooooo`03o`000?oooooooooo03kooooo00?o0000ojnggon_]ml01_n_]ml3o`000003
ok6fgOl0003o[kSO00_o[kSO00?o0000ojjih_n^^N800on^^N82o`0000Go[kSO00?o0000ojfih_n]
^N802_n]^N83o`0005cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`00
;?ooool00ol0003oooooooooo`0nooooo`03o`000?n_]moo[kOO00?o[kOO0_l00005ok6fg@03o`00
0?n_^=oo[kSO00[o[kSO00?o0000ojjih_l000000_l00008ojnhg`03o`000?n]^N;o[KWR00Ko[KWR
0ol0001Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool002gooooo00?o
0000ooooooooool0?_ooool00ol0003o[kOOo`000002o`0000So/KKM00?o0000ojnhgon_^=l02On_
^=l2o`0000co[kSO00?o0000ojfih_n]^N800on]^N82o`0006Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0?ooooo`00;_ooool00ol0003oooooooooo`0nooooo`03o`000?na]]go
/KKM00[o/KKM00?o0000ojnhgon_^=l01On_^=l3o`000003ok6ggOl0003o[kSO00co[kSO00?o0000
ojfih_l000000_l0001Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool0
02oooooo0_l0000nooooo`03o`000?na]]go/KKM00[o/KKM00?o0000ojnhgon_^=l00on_^=l2o`00
00Go/KOM00?o0000ojnhgon_^=l02_n_^=l2o`0006[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0?ooooo`00<Oooool00ol0003oooooooooo`0looooo`03o`000?na]]go/KKM00[o
/KKM00?o0000ojnhgol000000_l00008ok6gg@03o`000?n_^=oo[kSO00Ko[kSO0ol0001]ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool003;ooooo00?o0000ooooooooool0
??ooool00ol0003o/KKMok6fg@09ok6fg@;o00003?na]md00ol0003o[kSOojnhg`03ojnhg`;o0000
LOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo000cooooo`03o`000?oo
oooooooo03cooooo00?o0000ok6fgOna]]d01_na]]d2o`0000;o/[GK00?o0000ok6ggOna]md02_na
]md00ol0003o[kSOo`000002o`0007?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0>ooooo`00=?ooool2o`0003gooooo00?o0000ok6fgOna]]d00_na]]d3o`0000Go/[GK00?o0000
ok6ggOna]md02Ona]md2o`0007Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>
ooooo`00=_ooool00ol0003oooooooooo`0kooooo`04o`000?na]]go0000o`0000Wo/[GK00?o0000
ok6ggOna]md01_na]md2o`0007[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>
ooooo`00=oooool00ol0003oooooooooo`0kooooo`03o`000?nb]M_o/[GK00[o/[GK00?o0000ok6g
gOna]md00_na]md3o`0007cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>oooo
o`00>?ooool00ol0003oooooooooo`0jooooo`03o`000?nb]M_o/[GK00_o/[GK00Co0000ok6ggOl0
003o0000P?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo000iooooo`;o
0000>oooool00ol0003o/[GKok:ef`0:ok:ef`;o0000Poooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00kooooo000kooooo`03o`000?oooooooooo03Wooooo00?o0000ok:efonb]M/0
1_nb]M/3o`0008Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`00??oo
ool00ol0003oooooooooo`0iooooo`03o`000?nb]M_o/[GK00?o/[GK0_l00029ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03Oooool003gooooo00?o0000ooooooooool0>Oooool0
0ol0003o/[GKo`000002o`0008cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=
ooooo`00?_ooool00ol0003oooooooooo`0iooooo`;o0000Soooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00gooooo000oooooo`;o0000>_ooool00ol0003oooooooooo`2>ooooo`05
o`000?ooooooooooooooool000003oooool0047ooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`2>ooooo`05o`000?ooooooooooooooool000003oooool004;ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`2?ooooo`04o`000?ooooooooooo`0000oooooo0013ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0T?ooool00ol0003oooooo`00000?ooooo`00
A?ooool2o`0003Gooooo00?o0000ooooooooool0T?ooool01?l0003oooooooooool0000>ooooo`00
A_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo097ooooo00?o0000ooooool00000
3_ooool004Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`;o00003_oo
ool004Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Booooo`?o00003_ooool0
04Wooooo0_l0000_ooooo`03o`000?oooooooooo08kooooo1?l0000Aooooo`00Boooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo08[ooooo1?l0000Eooooo`00C?ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo08Oooooo0ol0000Iooooo`00COooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo08?ooooo1?l0000Looooo`00C_ooool2o`0002[ooooo00?o0000
ooooooooool0Ooooool4o`00023ooooo001@ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0Noooool4o`0002Cooooo001Aooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0Moooool4o`0002Sooooo001Booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
M?ooool3o`0002cooooo001Cooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L?oo
ool4o`0002oooooo001Dooooo`;o00009?ooool00ol0003oooooooooo`1/ooooo`Co0000<oooool0
05Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Xooooo`Co0000=oooool005Oo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Tooooo`Co0000>oooool005Sooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`1Qooooo`?o0000?oooool005Wooooo0_l0
000Oooooo`03o`000?oooooooooo05gooooo1?l00012ooooo`00Foooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo05Wooooo1?l00016ooooo`00G?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo05Gooooo1?l0001:ooooo`00GOooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo057ooooo1?l0001>ooooo`00G_ooool2o`0001[ooooo00?o0000ooooooooool0
C_ooool3o`0005;ooooo001Pooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B_oo
ool4o`0005Gooooo001Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4
o`0005Wooooo001Rooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool4o`00
05gooooo001Sooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool4o`00067o
oooo001Tooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`?o0000IOooool006Kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`Co0000J?ooool006Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0cooooo`Co0000K?ooool006Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0_ooooo`Co0000L?ooool006Wooooo0_l0000>ooooo`03
o`000?oooooooooo02cooooo1?l0001dooooo`00Joooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Wooooo0ol0001hooooo`00K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02Gooooo1?l0001kooooo`00KOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo027ooooo1?l0001oooooo`00K_ooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`00
08?ooooo001`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool4o`0008Oo
oooo001aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool3o`0008_ooooo
001booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`0008kooooo001c
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`0009;ooooo001doooo
o`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000U_ooool007Kooooo00Co0000oooooooo
oooo00002?ooool4o`0009[ooooo001gooooo`03o`000?oooooo000000Gooooo0ol0002Nooooo`00
N?ooool2o`000003ooooool0003o000000;o0000XOooool007Wooooo0_l0002Uooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0777325, -0.00917165, \
0.00376731, 0.00376731}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell["\<\
Using minimization techniques in Calculus, we can find the symbolic global \
optimization for this lens configuration:\
\>", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["Dc1 = D[meritFunction,c1]", "Input",
  CellLabel->"In[57]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[BoxData[
    \(\(-\(35000\/9\)\) + \(2472500\ c1\)\/27 - \(968750\ c1\^2\)\/9 + \
\(1385656250\ c1\^3\)\/567 - \(220703125\ c1\^4\)\/567 + \(24939453125\ c1\^5\
\)\/1701 - \(798125\ c2\)\/9 + \(15800000\ c1\ c2\)\/27 - \(523890625\ c1\^2\ \
c2\)\/126 + \(3806093750\ c1\^3\ c2\)\/189 - \(50966796875\ c1\^4\ c2\)\/1701 \
+ \(88281250000\ c1\^5\ c2\)\/567 - \(2243750\ c2\^2\)\/9 + \(3549921875\ c1\ \
c2\^2\)\/756 - \(2440937500\ c1\^2\ c2\^2\)\/63 + \(78778906250\ c1\^3\ c2\^2\
\)\/567 - \(784667968750\ c1\^4\ c2\^2\)\/1701 + \(587500000000\ c1\^5\ c2\^2\
\)\/567 - \(65359375\ c2\^3\)\/28 + \(2668515625\ c1\ c2\^3\)\/63 - \
\(16379687500\ c1\^2\ c2\^3\)\/63 + \(624125000000\ c1\^3\ c2\^3\)\/567 - \
\(2040039062500\ c1\^4\ c2\^3\)\/567 + \(8714843750000\ c1\^5\ c2\^3\)\/1701 \
- \(478671875\ c2\^4\)\/42 + \(9205468750\ c1\ c2\^4\)\/63 - \(23218750000\ \
c1\^2\ c2\^4\)\/21 + \(3204765625000\ c1\^3\ c2\^4\)\/567 - \(26259765625000\ \
c1\^4\ c2\^4\)\/1701 + \(9218750000000\ c1\^5\ c2\^4\)\/567 - \(37109375\ \
c2\^5\)\/3 + \(4296875000\ c1\ c2\^5\)\/9 - \(44921875000\ c1\^2\ c2\^5\)\/9 \
+ \(1835937500000\ c1\^3\ c2\^5\)\/81 - \(11621093750000\ c1\^4\ c2\^5\)\/243 \
+ \(3125000000000\ c1\^5\ c2\^5\)\/81 - 
      136718750\ c2\^6 + \(6835937500\ c1\ c2\^6\)\/3 - \(136718750000\ c1\^2\
\ c2\^6\)\/9 + \(1367187500000\ c1\^3\ c2\^6\)\/27 - \(6835937500000\ c1\^4\ \
c2\^6\)\/81 + \(13671875000000\ c1\^5\ c2\^6\)\/243\)], "Output",
  CellLabel->"Out[57]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dc2 = D[meritFunction,c2]", "Input",
  CellLabel->"In[58]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[BoxData[
    \(10000\/3 - \(798125\ c1\)\/9 + \(7900000\ c1\^2\)\/27 - \(523890625\ c1\
\^3\)\/378 + \(1903046875\ c1\^4\)\/378 - \(10193359375\ c1\^5\)\/1701 + \
\(44140625000\ c1\^6\)\/1701 + \(196250\ c2\)\/3 - \(4487500\ c1\ c2\)\/9 + \
\(3549921875\ c1\^2\ c2\)\/756 - \(4881875000\ c1\^3\ c2\)\/189 + \
\(39389453125\ c1\^4\ c2\)\/567 - \(313867187500\ c1\^5\ c2\)\/1701 + \
\(587500000000\ c1\^6\ c2\)\/1701 + 
      93750\ c2\^2 - \(196078125\ c1\ c2\^2\)\/28 + \(2668515625\ c1\^2\ \
c2\^2\)\/42 - \(16379687500\ c1\^3\ c2\^2\)\/63 + \(156031250000\ c1\^4\ \
c2\^2\)\/189 - \(408007812500\ c1\^5\ c2\^2\)\/189 + \(4357421875000\ c1\^6\ \
c2\^2\)\/1701 + \(49078125\ c2\^3\)\/14 - \(957343750\ c1\ c2\^3\)\/21 + \
\(18410937500\ c1\^2\ c2\^3\)\/63 - \(92875000000\ c1\^3\ c2\^3\)\/63 + \
\(3204765625000\ c1\^4\ c2\^3\)\/567 - \(21007812500000\ c1\^5\ c2\^3\)\/1701 \
+ \(18437500000000\ c1\^6\ c2\^3\)\/1701 - \(1953125\ c2\^4\)\/2 - \
\(185546875\ c1\ c2\^4\)\/3 + \(10742187500\ c1\^2\ c2\^4\)\/9 - \
\(224609375000\ c1\^3\ c2\^4\)\/27 + \(2294921875000\ c1\^4\ c2\^4\)\/81 - \
\(11621093750000\ c1\^5\ c2\^4\)\/243 + \(7812500000000\ c1\^6\ c2\^4\)\/243 \
+ 41015625\ c2\^5 - 820312500\ c1\ c2\^5 + 
      6835937500\ c1\^2\ c2\^5 - \(273437500000\ c1\^3\ c2\^5\)\/9 + \
\(683593750000\ c1\^4\ c2\^5\)\/9 - \(2734375000000\ c1\^5\ c2\^5\)\/27 + \
\(13671875000000\ c1\^6\ c2\^5\)\/243\)], "Output",
  CellLabel->"Out[58]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "Next we use ",
  StyleBox["NSolve", "Input"],
  " to find the roots of the these two equations. These roots contain all \
possible solutions to third order system model."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["extrema = NSolve[{Dc1==0,Dc2==0},{c1,c2}]", "Input",
  CellLabel->"In[59]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[BoxData[
    \({{c1 \[Rule] \(\(0.3584748566166932`\)\(\[InvisibleSpace]\)\) + 
            0.050156730898569125`\ \[ImaginaryI], 
        c2 \[Rule] \(\(1.0100351501178007`\)\(\[InvisibleSpace]\)\) + 
            1.7221016911851141`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.3584748566166932`\)\(\[InvisibleSpace]\)\) - 
            0.050156730898569125`\ \[ImaginaryI], 
        c2 \[Rule] \(\(1.0100351501178007`\)\(\[InvisibleSpace]\)\) - 
            1.7221016911851141`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.43626211470838483`, 
        c2 \[Rule] \(-0.5936637439323198`\)}, {c1 \[Rule] \
\(\(0.3826220919888144`\)\(\[InvisibleSpace]\)\) + 
            0.05018395115859074`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.06162446958114401`\)\(\[InvisibleSpace]\)\) + 
            0.9490318958118463`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.3826220919888144`\)\(\[InvisibleSpace]\)\) - 
            0.05018395115859074`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.06162446958114401`\)\(\[InvisibleSpace]\)\) - 
            0.9490318958118463`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.2554981048605343`\)\(\[InvisibleSpace]\)\) + 
            0.08853537912795245`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.6428364914030485`\) + 
            0.4586048609547116`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.2554981048605343`\)\(\[InvisibleSpace]\)\) - 
            0.08853537912795245`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.6428364914030485`\) - 
            0.4586048609547116`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.21860622574563549`\)\(\[InvisibleSpace]\)\) + 
            0.10902293708261396`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.24746252546819902`\) + 
            0.49654236027339155`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.21860622574563549`\)\(\[InvisibleSpace]\)\) - 
            0.10902293708261396`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.24746252546819902`\) - 
            0.49654236027339155`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.26760796976475704`, 
        c2 \[Rule] \(-0.326480208395864`\)}, {c1 \[Rule] \
\(-0.012919963591326107`\) - 0.2708872706201766`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.06779891436503256`\)\(\[InvisibleSpace]\)\) + 
            0.05537784158867771`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.012919963591326107`\) + 0.2708872706201766`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.06779891436503256`\)\(\[InvisibleSpace]\)\) - 
            0.05537784158867771`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.025406397447847298`\) - 0.3789633133707507`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.15919224256515488`\) - 
            0.08928859759778178`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.025406397447847298`\) + 0.3789633133707507`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.15919224256515488`\) + 
            0.08928859759778178`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.1433277394774435`\)\(\[InvisibleSpace]\)\) + 
            0.17327224011209766`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.09160452035221976`\) + 
            0.28577339373247646`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.1433277394774435`\)\(\[InvisibleSpace]\)\) - 
            0.17327224011209766`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.09160452035221976`\) - 
            0.28577339373247646`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.08540713899805957`\)\(\[InvisibleSpace]\)\) - 
            0.29801550029830015`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.1571076629390315`\) - 
            0.1340207866105467`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.08540713899805957`\)\(\[InvisibleSpace]\)\) + 
            0.29801550029830015`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.1571076629390315`\) + 
            0.1340207866105467`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.007905548909328307`\)\(\[InvisibleSpace]\)\) - 
            0.1893304176339929`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.045948394692479556`\)\(\[InvisibleSpace]\)\) + 
            0.05645116009553218`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.007905548909328307`\)\(\[InvisibleSpace]\)\) + 
            0.1893304176339929`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.045948394692479556`\)\(\[InvisibleSpace]\)\) - 
            0.05645116009553218`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.12718750337057397`\)\(\[InvisibleSpace]\)\) + 
            0.11623187724882396`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.008388495703382055`\) + 
            0.25592333191749045`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.12718750337057397`\)\(\[InvisibleSpace]\)\) - 
            0.11623187724882396`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.008388495703382055`\) - 
            0.25592333191749045`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.0377631696134961`\)\(\[InvisibleSpace]\)\) + 
            0.017928478566161917`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.008395479647990586`\) + 
            0.023354649734799626`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.0377631696134961`\)\(\[InvisibleSpace]\)\) - 
            0.017928478566161917`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.008395479647990586`\) - 
            0.023354649734799626`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.037751126953392236`, 
        c2 \[Rule] \(-0.0064093546817556276`\)}}\)], "Output",
  CellLabel->"Out[59]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell["\<\
Note that many of the roots contain imaginary components. In addition, some \
of the solutions are local minima and do not represent the global solution to \
the system. However, by shifting through the different roots and comparing \
their results we can determine the global solution to the system.\
\>", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["\<\
finalextrema = \
Select[Union[Chop[Transpose[{meritFunction/.extrema,extrema}]]],
\t(#[[1]]==Re[#[[1]]]&&#[[1]]<1&&#[[1]]>0)&]\
\>", "Input",
  CellLabel->"In[60]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[BoxData[
    \({{0.000789449635032969`, {c1 \[Rule] 0.037751126953392236`, 
          c2 \[Rule] \(-0.0064093546817556276`\)}}}\)], "Output",
  CellLabel->"Out[60]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "Finally, we can verify the resulting solution by numerically tracing the \
resulting system and calculating the resulting focal point and spot size with \
",
  StyleBox["FindFocusFast", "Input"],
  ". "
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["\<\
FindFocusFast[TurboPlot[
\tMove[LineOfRays[10,NumberOfRays->201,IntrinsicMedium->1],{-20,0}],
\tplot,SymbolicValues->finalextrema[[1,2]], PlotType->TopView]]\
\>", "Input",
  CellLabel->"In[61]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42857 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.295918 0.0136054 0.214286 0.0136054 [
[ 0 0 0 0 ]
[ 1 .42857 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.35927 .0102 m
.42214 .0102 L
.42761 .07823 L
.32259 .07823 L
.35927 .0102 L
F
.32259 .07823 m
.42761 .07823 L
.43088 .14626 L
.3024 .14626 L
.32259 .07823 L
F
.3024 .14626 m
.43088 .14626 L
.43197 .21429 L
.29592 .21429 L
.3024 .14626 L
F
.29592 .21429 m
.43197 .21429 L
.43088 .28231 L
.3024 .28231 L
.29592 .21429 L
F
.3024 .28231 m
.43088 .28231 L
.42761 .35034 L
.32259 .35034 L
.3024 .28231 L
F
.32259 .35034 m
.42761 .35034 L
.42214 .41837 L
.35927 .41837 L
.32259 .35034 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.35927 .0102 m
.32259 .07823 L
.3024 .14626 L
.29592 .21429 L
.3024 .28231 L
.32259 .35034 L
.35927 .41837 L
.42214 .41837 L
.42761 .35034 L
.43088 .28231 L
.43197 .21429 L
.43088 .14626 L
.42761 .07823 L
.42214 .0102 L
.35927 .0102 L
s
.5 g
.35927 .21429 m
.42214 .21429 L
.42761 .21429 L
.32259 .21429 L
.35927 .21429 L
F
.32259 .21429 m
.42761 .21429 L
.43088 .21429 L
.3024 .21429 L
.32259 .21429 L
F
.3024 .21429 m
.43088 .21429 L
.43197 .21429 L
.29592 .21429 L
.3024 .21429 L
F
.29592 .21429 m
.43197 .21429 L
.43088 .21429 L
.3024 .21429 L
.29592 .21429 L
F
.3024 .21429 m
.43088 .21429 L
.42761 .21429 L
.32259 .21429 L
.3024 .21429 L
F
.32259 .21429 m
.42761 .21429 L
.42214 .21429 L
.35927 .21429 L
.32259 .21429 L
F
0 g
.35927 .21429 m
.32259 .21429 L
.3024 .21429 L
.29592 .21429 L
.3024 .21429 L
.32259 .21429 L
.35927 .21429 L
.42214 .21429 L
.42761 .21429 L
.43088 .21429 L
.43197 .21429 L
.43088 .21429 L
.42761 .21429 L
.42214 .21429 L
.35927 .21429 L
s
.35927 .41837 m
.42214 .41837 L
.42214 .41141 L
.35927 .41141 L
.35927 .41837 L
s
.35927 .41141 m
.42214 .41141 L
.42214 .39103 L
.35927 .39103 L
.35927 .41141 L
s
.35927 .39103 m
.42214 .39103 L
.42214 .35859 L
.35927 .35859 L
.35927 .39103 L
s
.35927 .35859 m
.42214 .35859 L
.42214 .31633 L
.35927 .31633 L
.35927 .35859 L
s
.35927 .31633 m
.42214 .31633 L
.42214 .26711 L
.35927 .26711 L
.35927 .31633 L
s
.35927 .26711 m
.42214 .26711 L
.42214 .21429 L
.35927 .21429 L
.35927 .26711 L
s
.35927 .21429 m
.42214 .21429 L
.42214 .16147 L
.35927 .16147 L
.35927 .21429 L
s
.35927 .16147 m
.42214 .16147 L
.42214 .11224 L
.35927 .11224 L
.35927 .16147 L
s
.35927 .11224 m
.42214 .11224 L
.42214 .06998 L
.35927 .06998 L
.35927 .11224 L
s
.35927 .06998 m
.42214 .06998 L
.42214 .03755 L
.35927 .03755 L
.35927 .06998 L
s
.35927 .03755 m
.42214 .03755 L
.42214 .01716 L
.35927 .01716 L
.35927 .03755 L
s
.35927 .01716 m
.42214 .01716 L
.42214 .0102 L
.35927 .0102 L
.35927 .01716 L
s
.35927 .0102 m
.42214 .0102 L
.42214 .01716 L
.35927 .01716 L
.35927 .0102 L
s
.35927 .01716 m
.42214 .01716 L
.42214 .03755 L
.35927 .03755 L
.35927 .01716 L
s
.35927 .03755 m
.42214 .03755 L
.42214 .06998 L
.35927 .06998 L
.35927 .03755 L
s
.35927 .06998 m
.42214 .06998 L
.42214 .11224 L
.35927 .11224 L
.35927 .06998 L
s
.35927 .11224 m
.42214 .11224 L
.42214 .16147 L
.35927 .16147 L
.35927 .11224 L
s
.35927 .16147 m
.42214 .16147 L
.42214 .21429 L
.35927 .21429 L
.35927 .16147 L
s
.35927 .21429 m
.42214 .21429 L
.42214 .26711 L
.35927 .26711 L
.35927 .21429 L
s
.35927 .26711 m
.42214 .26711 L
.42214 .31633 L
.35927 .31633 L
.35927 .26711 L
s
.35927 .31633 m
.42214 .31633 L
.42214 .35859 L
.35927 .35859 L
.35927 .31633 L
s
.35927 .35859 m
.42214 .35859 L
.42214 .39103 L
.35927 .39103 L
.35927 .35859 L
s
.35927 .39103 m
.42214 .39103 L
.42214 .41141 L
.35927 .41141 L
.35927 .39103 L
s
.35927 .41141 m
.42214 .41141 L
.42214 .41837 L
.35927 .41837 L
.35927 .41141 L
s
.97619 .0102 m
.97619 .07823 L
.97619 .14626 L
.97619 .21429 L
.97619 .28231 L
.97619 .35034 L
.97619 .41837 L
.97619 .41837 L
.97619 .35034 L
.97619 .28231 L
.97619 .21429 L
.97619 .14626 L
.97619 .07823 L
.97619 .0102 L
.97619 .0102 L
s
.97619 .21429 m
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
s
.97619 .41837 m
.97619 .41141 L
.97619 .39103 L
.97619 .35859 L
.97619 .31633 L
.97619 .26711 L
.97619 .21429 L
.97619 .16147 L
.97619 .11224 L
.97619 .06998 L
.97619 .03755 L
.97619 .01716 L
.97619 .0102 L
.97619 .01716 L
.97619 .03755 L
.97619 .06998 L
.97619 .11224 L
.97619 .16147 L
.97619 .21429 L
.97619 .26711 L
.97619 .31633 L
.97619 .35859 L
.97619 .39103 L
.97619 .41141 L
.97619 .41837 L
s
.039 .916 .04 r
.02381 .14626 m
.3024 .14626 L
s
0 0 0 r
2.5 Mabswid
.3024 .14626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14694 m
.30227 .14694 L
s
0 0 0 r
2.5 Mabswid
.30227 .14694 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14762 m
.30214 .14762 L
s
0 0 0 r
2.5 Mabswid
.30214 .14762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1483 m
.30201 .1483 L
s
0 0 0 r
2.5 Mabswid
.30201 .1483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14898 m
.30188 .14898 L
s
0 0 0 r
2.5 Mabswid
.30188 .14898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14966 m
.30176 .14966 L
s
0 0 0 r
2.5 Mabswid
.30176 .14966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15034 m
.30164 .15034 L
s
0 0 0 r
2.5 Mabswid
.30164 .15034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15102 m
.30151 .15102 L
s
0 0 0 r
2.5 Mabswid
.30151 .15102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1517 m
.30139 .1517 L
s
0 0 0 r
2.5 Mabswid
.30139 .1517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15238 m
.30127 .15238 L
s
0 0 0 r
2.5 Mabswid
.30127 .15238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15306 m
.30116 .15306 L
s
0 0 0 r
2.5 Mabswid
.30116 .15306 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15374 m
.30104 .15374 L
s
0 0 0 r
2.5 Mabswid
.30104 .15374 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15442 m
.30092 .15442 L
s
0 0 0 r
2.5 Mabswid
.30092 .15442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1551 m
.30081 .1551 L
s
0 0 0 r
2.5 Mabswid
.30081 .1551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15578 m
.3007 .15578 L
s
0 0 0 r
2.5 Mabswid
.3007 .15578 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15646 m
.30059 .15646 L
s
0 0 0 r
2.5 Mabswid
.30059 .15646 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15714 m
.30048 .15714 L
s
0 0 0 r
2.5 Mabswid
.30048 .15714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15782 m
.30037 .15782 L
s
0 0 0 r
2.5 Mabswid
.30037 .15782 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1585 m
.30026 .1585 L
s
0 0 0 r
2.5 Mabswid
.30026 .1585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15918 m
.30016 .15918 L
s
0 0 0 r
2.5 Mabswid
.30016 .15918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15986 m
.30005 .15986 L
s
0 0 0 r
2.5 Mabswid
.30005 .15986 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16054 m
.29995 .16054 L
s
0 0 0 r
2.5 Mabswid
.29995 .16054 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16122 m
.29985 .16122 L
s
0 0 0 r
2.5 Mabswid
.29985 .16122 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1619 m
.29975 .1619 L
s
0 0 0 r
2.5 Mabswid
.29975 .1619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16259 m
.29965 .16259 L
s
0 0 0 r
2.5 Mabswid
.29965 .16259 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16327 m
.29955 .16327 L
s
0 0 0 r
2.5 Mabswid
.29955 .16327 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16395 m
.29945 .16395 L
s
0 0 0 r
2.5 Mabswid
.29945 .16395 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16463 m
.29936 .16463 L
s
0 0 0 r
2.5 Mabswid
.29936 .16463 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16531 m
.29926 .16531 L
s
0 0 0 r
2.5 Mabswid
.29926 .16531 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16599 m
.29917 .16599 L
s
0 0 0 r
2.5 Mabswid
.29917 .16599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16667 m
.29908 .16667 L
s
0 0 0 r
2.5 Mabswid
.29908 .16667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16735 m
.29899 .16735 L
s
0 0 0 r
2.5 Mabswid
.29899 .16735 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16803 m
.2989 .16803 L
s
0 0 0 r
2.5 Mabswid
.2989 .16803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16871 m
.29881 .16871 L
s
0 0 0 r
2.5 Mabswid
.29881 .16871 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16939 m
.29873 .16939 L
s
0 0 0 r
2.5 Mabswid
.29873 .16939 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17007 m
.29864 .17007 L
s
0 0 0 r
2.5 Mabswid
.29864 .17007 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17075 m
.29856 .17075 L
s
0 0 0 r
2.5 Mabswid
.29856 .17075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17143 m
.29848 .17143 L
s
0 0 0 r
2.5 Mabswid
.29848 .17143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17211 m
.29839 .17211 L
s
0 0 0 r
2.5 Mabswid
.29839 .17211 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17279 m
.29832 .17279 L
s
0 0 0 r
2.5 Mabswid
.29832 .17279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17347 m
.29824 .17347 L
s
0 0 0 r
2.5 Mabswid
.29824 .17347 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17415 m
.29816 .17415 L
s
0 0 0 r
2.5 Mabswid
.29816 .17415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17483 m
.29808 .17483 L
s
0 0 0 r
2.5 Mabswid
.29808 .17483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17551 m
.29801 .17551 L
s
0 0 0 r
2.5 Mabswid
.29801 .17551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17619 m
.29794 .17619 L
s
0 0 0 r
2.5 Mabswid
.29794 .17619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17687 m
.29787 .17687 L
s
0 0 0 r
2.5 Mabswid
.29787 .17687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17755 m
.2978 .17755 L
s
0 0 0 r
2.5 Mabswid
.2978 .17755 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17823 m
.29773 .17823 L
s
0 0 0 r
2.5 Mabswid
.29773 .17823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17891 m
.29766 .17891 L
s
0 0 0 r
2.5 Mabswid
.29766 .17891 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17959 m
.29759 .17959 L
s
0 0 0 r
2.5 Mabswid
.29759 .17959 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18027 m
.29753 .18027 L
s
0 0 0 r
2.5 Mabswid
.29753 .18027 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18095 m
.29746 .18095 L
s
0 0 0 r
2.5 Mabswid
.29746 .18095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18163 m
.2974 .18163 L
s
0 0 0 r
2.5 Mabswid
.2974 .18163 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18231 m
.29734 .18231 L
s
0 0 0 r
2.5 Mabswid
.29734 .18231 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18299 m
.29728 .18299 L
s
0 0 0 r
2.5 Mabswid
.29728 .18299 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18367 m
.29722 .18367 L
s
0 0 0 r
2.5 Mabswid
.29722 .18367 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18435 m
.29716 .18435 L
s
0 0 0 r
2.5 Mabswid
.29716 .18435 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18503 m
.29711 .18503 L
s
0 0 0 r
2.5 Mabswid
.29711 .18503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18571 m
.29705 .18571 L
s
0 0 0 r
2.5 Mabswid
.29705 .18571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18639 m
.297 .18639 L
s
0 0 0 r
2.5 Mabswid
.297 .18639 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18707 m
.29695 .18707 L
s
0 0 0 r
2.5 Mabswid
.29695 .18707 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18776 m
.2969 .18776 L
s
0 0 0 r
2.5 Mabswid
.2969 .18776 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18844 m
.29685 .18844 L
s
0 0 0 r
2.5 Mabswid
.29685 .18844 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18912 m
.2968 .18912 L
s
0 0 0 r
2.5 Mabswid
.2968 .18912 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1898 m
.29675 .1898 L
s
0 0 0 r
2.5 Mabswid
.29675 .1898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19048 m
.29671 .19048 L
s
0 0 0 r
2.5 Mabswid
.29671 .19048 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19116 m
.29666 .19116 L
s
0 0 0 r
2.5 Mabswid
.29666 .19116 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19184 m
.29662 .19184 L
s
0 0 0 r
2.5 Mabswid
.29662 .19184 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19252 m
.29658 .19252 L
s
0 0 0 r
2.5 Mabswid
.29658 .19252 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1932 m
.29654 .1932 L
s
0 0 0 r
2.5 Mabswid
.29654 .1932 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19388 m
.2965 .19388 L
s
0 0 0 r
2.5 Mabswid
.2965 .19388 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19456 m
.29646 .19456 L
s
0 0 0 r
2.5 Mabswid
.29646 .19456 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19524 m
.29642 .19524 L
s
0 0 0 r
2.5 Mabswid
.29642 .19524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19592 m
.29639 .19592 L
s
0 0 0 r
2.5 Mabswid
.29639 .19592 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1966 m
.29635 .1966 L
s
0 0 0 r
2.5 Mabswid
.29635 .1966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19728 m
.29632 .19728 L
s
0 0 0 r
2.5 Mabswid
.29632 .19728 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19796 m
.29629 .19796 L
s
0 0 0 r
2.5 Mabswid
.29629 .19796 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19864 m
.29626 .19864 L
s
0 0 0 r
2.5 Mabswid
.29626 .19864 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19932 m
.29623 .19932 L
s
0 0 0 r
2.5 Mabswid
.29623 .19932 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2 m
.2962 .2 L
s
0 0 0 r
2.5 Mabswid
.2962 .2 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20068 m
.29618 .20068 L
s
0 0 0 r
2.5 Mabswid
.29618 .20068 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20136 m
.29615 .20136 L
s
0 0 0 r
2.5 Mabswid
.29615 .20136 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20204 m
.29613 .20204 L
s
0 0 0 r
2.5 Mabswid
.29613 .20204 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20272 m
.2961 .20272 L
s
0 0 0 r
2.5 Mabswid
.2961 .20272 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2034 m
.29608 .2034 L
s
0 0 0 r
2.5 Mabswid
.29608 .2034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20408 m
.29606 .20408 L
s
0 0 0 r
2.5 Mabswid
.29606 .20408 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20476 m
.29604 .20476 L
s
0 0 0 r
2.5 Mabswid
.29604 .20476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20544 m
.29603 .20544 L
s
0 0 0 r
2.5 Mabswid
.29603 .20544 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20612 m
.29601 .20612 L
s
0 0 0 r
2.5 Mabswid
.29601 .20612 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2068 m
.296 .2068 L
s
0 0 0 r
2.5 Mabswid
.296 .2068 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20748 m
.29598 .20748 L
s
0 0 0 r
2.5 Mabswid
.29598 .20748 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20816 m
.29597 .20816 L
s
0 0 0 r
2.5 Mabswid
.29597 .20816 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20884 m
.29596 .20884 L
s
0 0 0 r
2.5 Mabswid
.29596 .20884 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20952 m
.29595 .20952 L
s
0 0 0 r
2.5 Mabswid
.29595 .20952 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2102 m
.29594 .2102 L
s
0 0 0 r
2.5 Mabswid
.29594 .2102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21088 m
.29593 .21088 L
s
0 0 0 r
2.5 Mabswid
.29593 .21088 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21156 m
.29593 .21156 L
s
0 0 0 r
2.5 Mabswid
.29593 .21156 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21224 m
.29592 .21224 L
s
0 0 0 r
2.5 Mabswid
.29592 .21224 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21293 m
.29592 .21293 L
s
0 0 0 r
2.5 Mabswid
.29592 .21293 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21361 m
.29592 .21361 L
s
0 0 0 r
2.5 Mabswid
.29592 .21361 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21429 m
.29592 .21429 L
s
0 0 0 r
2.5 Mabswid
.29592 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21497 m
.29592 .21497 L
s
0 0 0 r
2.5 Mabswid
.29592 .21497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21565 m
.29592 .21565 L
s
0 0 0 r
2.5 Mabswid
.29592 .21565 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21633 m
.29592 .21633 L
s
0 0 0 r
2.5 Mabswid
.29592 .21633 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21701 m
.29593 .21701 L
s
0 0 0 r
2.5 Mabswid
.29593 .21701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21769 m
.29593 .21769 L
s
0 0 0 r
2.5 Mabswid
.29593 .21769 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21837 m
.29594 .21837 L
s
0 0 0 r
2.5 Mabswid
.29594 .21837 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21905 m
.29595 .21905 L
s
0 0 0 r
2.5 Mabswid
.29595 .21905 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21973 m
.29596 .21973 L
s
0 0 0 r
2.5 Mabswid
.29596 .21973 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22041 m
.29597 .22041 L
s
0 0 0 r
2.5 Mabswid
.29597 .22041 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22109 m
.29598 .22109 L
s
0 0 0 r
2.5 Mabswid
.29598 .22109 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22177 m
.296 .22177 L
s
0 0 0 r
2.5 Mabswid
.296 .22177 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22245 m
.29601 .22245 L
s
0 0 0 r
2.5 Mabswid
.29601 .22245 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22313 m
.29603 .22313 L
s
0 0 0 r
2.5 Mabswid
.29603 .22313 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22381 m
.29604 .22381 L
s
0 0 0 r
2.5 Mabswid
.29604 .22381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22449 m
.29606 .22449 L
s
0 0 0 r
2.5 Mabswid
.29606 .22449 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22517 m
.29608 .22517 L
s
0 0 0 r
2.5 Mabswid
.29608 .22517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22585 m
.2961 .22585 L
s
0 0 0 r
2.5 Mabswid
.2961 .22585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22653 m
.29613 .22653 L
s
0 0 0 r
2.5 Mabswid
.29613 .22653 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22721 m
.29615 .22721 L
s
0 0 0 r
2.5 Mabswid
.29615 .22721 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22789 m
.29618 .22789 L
s
0 0 0 r
2.5 Mabswid
.29618 .22789 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22857 m
.2962 .22857 L
s
0 0 0 r
2.5 Mabswid
.2962 .22857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22925 m
.29623 .22925 L
s
0 0 0 r
2.5 Mabswid
.29623 .22925 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22993 m
.29626 .22993 L
s
0 0 0 r
2.5 Mabswid
.29626 .22993 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23061 m
.29629 .23061 L
s
0 0 0 r
2.5 Mabswid
.29629 .23061 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23129 m
.29632 .23129 L
s
0 0 0 r
2.5 Mabswid
.29632 .23129 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23197 m
.29635 .23197 L
s
0 0 0 r
2.5 Mabswid
.29635 .23197 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23265 m
.29639 .23265 L
s
0 0 0 r
2.5 Mabswid
.29639 .23265 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23333 m
.29642 .23333 L
s
0 0 0 r
2.5 Mabswid
.29642 .23333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23401 m
.29646 .23401 L
s
0 0 0 r
2.5 Mabswid
.29646 .23401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23469 m
.2965 .23469 L
s
0 0 0 r
2.5 Mabswid
.2965 .23469 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23537 m
.29654 .23537 L
s
0 0 0 r
2.5 Mabswid
.29654 .23537 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23605 m
.29658 .23605 L
s
0 0 0 r
2.5 Mabswid
.29658 .23605 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23673 m
.29662 .23673 L
s
0 0 0 r
2.5 Mabswid
.29662 .23673 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23741 m
.29666 .23741 L
s
0 0 0 r
2.5 Mabswid
.29666 .23741 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2381 m
.29671 .2381 L
s
0 0 0 r
2.5 Mabswid
.29671 .2381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23878 m
.29675 .23878 L
s
0 0 0 r
2.5 Mabswid
.29675 .23878 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23946 m
.2968 .23946 L
s
0 0 0 r
2.5 Mabswid
.2968 .23946 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24014 m
.29685 .24014 L
s
0 0 0 r
2.5 Mabswid
.29685 .24014 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24082 m
.2969 .24082 L
s
0 0 0 r
2.5 Mabswid
.2969 .24082 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2415 m
.29695 .2415 L
s
0 0 0 r
2.5 Mabswid
.29695 .2415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24218 m
.297 .24218 L
s
0 0 0 r
2.5 Mabswid
.297 .24218 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24286 m
.29705 .24286 L
s
0 0 0 r
2.5 Mabswid
.29705 .24286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24354 m
.29711 .24354 L
s
0 0 0 r
2.5 Mabswid
.29711 .24354 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24422 m
.29716 .24422 L
s
0 0 0 r
2.5 Mabswid
.29716 .24422 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2449 m
.29722 .2449 L
s
0 0 0 r
2.5 Mabswid
.29722 .2449 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24558 m
.29728 .24558 L
s
0 0 0 r
2.5 Mabswid
.29728 .24558 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24626 m
.29734 .24626 L
s
0 0 0 r
2.5 Mabswid
.29734 .24626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24694 m
.2974 .24694 L
s
0 0 0 r
2.5 Mabswid
.2974 .24694 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24762 m
.29746 .24762 L
s
0 0 0 r
2.5 Mabswid
.29746 .24762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2483 m
.29753 .2483 L
s
0 0 0 r
2.5 Mabswid
.29753 .2483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24898 m
.29759 .24898 L
s
0 0 0 r
2.5 Mabswid
.29759 .24898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24966 m
.29766 .24966 L
s
0 0 0 r
2.5 Mabswid
.29766 .24966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25034 m
.29773 .25034 L
s
0 0 0 r
2.5 Mabswid
.29773 .25034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25102 m
.2978 .25102 L
s
0 0 0 r
2.5 Mabswid
.2978 .25102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2517 m
.29787 .2517 L
s
0 0 0 r
2.5 Mabswid
.29787 .2517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25238 m
.29794 .25238 L
s
0 0 0 r
2.5 Mabswid
.29794 .25238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25306 m
.29801 .25306 L
s
0 0 0 r
2.5 Mabswid
.29801 .25306 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25374 m
.29808 .25374 L
s
0 0 0 r
2.5 Mabswid
.29808 .25374 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25442 m
.29816 .25442 L
s
0 0 0 r
2.5 Mabswid
.29816 .25442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2551 m
.29824 .2551 L
s
0 0 0 r
2.5 Mabswid
.29824 .2551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25578 m
.29832 .25578 L
s
0 0 0 r
2.5 Mabswid
.29832 .25578 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25646 m
.29839 .25646 L
s
0 0 0 r
2.5 Mabswid
.29839 .25646 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25714 m
.29848 .25714 L
s
0 0 0 r
2.5 Mabswid
.29848 .25714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25782 m
.29856 .25782 L
s
0 0 0 r
2.5 Mabswid
.29856 .25782 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2585 m
.29864 .2585 L
s
0 0 0 r
2.5 Mabswid
.29864 .2585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25918 m
.29873 .25918 L
s
0 0 0 r
2.5 Mabswid
.29873 .25918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25986 m
.29881 .25986 L
s
0 0 0 r
2.5 Mabswid
.29881 .25986 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26054 m
.2989 .26054 L
s
0 0 0 r
2.5 Mabswid
.2989 .26054 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26122 m
.29899 .26122 L
s
0 0 0 r
2.5 Mabswid
.29899 .26122 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2619 m
.29908 .2619 L
s
0 0 0 r
2.5 Mabswid
.29908 .2619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26259 m
.29917 .26259 L
s
0 0 0 r
2.5 Mabswid
.29917 .26259 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26327 m
.29926 .26327 L
s
0 0 0 r
2.5 Mabswid
.29926 .26327 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26395 m
.29936 .26395 L
s
0 0 0 r
2.5 Mabswid
.29936 .26395 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26463 m
.29945 .26463 L
s
0 0 0 r
2.5 Mabswid
.29945 .26463 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26531 m
.29955 .26531 L
s
0 0 0 r
2.5 Mabswid
.29955 .26531 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26599 m
.29965 .26599 L
s
0 0 0 r
2.5 Mabswid
.29965 .26599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26667 m
.29975 .26667 L
s
0 0 0 r
2.5 Mabswid
.29975 .26667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26735 m
.29985 .26735 L
s
0 0 0 r
2.5 Mabswid
.29985 .26735 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26803 m
.29995 .26803 L
s
0 0 0 r
2.5 Mabswid
.29995 .26803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26871 m
.30005 .26871 L
s
0 0 0 r
2.5 Mabswid
.30005 .26871 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26939 m
.30016 .26939 L
s
0 0 0 r
2.5 Mabswid
.30016 .26939 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27007 m
.30026 .27007 L
s
0 0 0 r
2.5 Mabswid
.30026 .27007 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27075 m
.30037 .27075 L
s
0 0 0 r
2.5 Mabswid
.30037 .27075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27143 m
.30048 .27143 L
s
0 0 0 r
2.5 Mabswid
.30048 .27143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27211 m
.30059 .27211 L
s
0 0 0 r
2.5 Mabswid
.30059 .27211 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27279 m
.3007 .27279 L
s
0 0 0 r
2.5 Mabswid
.3007 .27279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27347 m
.30081 .27347 L
s
0 0 0 r
2.5 Mabswid
.30081 .27347 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27415 m
.30092 .27415 L
s
0 0 0 r
2.5 Mabswid
.30092 .27415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27483 m
.30104 .27483 L
s
0 0 0 r
2.5 Mabswid
.30104 .27483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27551 m
.30116 .27551 L
s
0 0 0 r
2.5 Mabswid
.30116 .27551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27619 m
.30127 .27619 L
s
0 0 0 r
2.5 Mabswid
.30127 .27619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27687 m
.30139 .27687 L
s
0 0 0 r
2.5 Mabswid
.30139 .27687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27755 m
.30151 .27755 L
s
0 0 0 r
2.5 Mabswid
.30151 .27755 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27823 m
.30164 .27823 L
s
0 0 0 r
2.5 Mabswid
.30164 .27823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27891 m
.30176 .27891 L
s
0 0 0 r
2.5 Mabswid
.30176 .27891 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27959 m
.30188 .27959 L
s
0 0 0 r
2.5 Mabswid
.30188 .27959 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28027 m
.30201 .28027 L
s
0 0 0 r
2.5 Mabswid
.30201 .28027 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28095 m
.30214 .28095 L
s
0 0 0 r
2.5 Mabswid
.30214 .28095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28163 m
.30227 .28163 L
s
0 0 0 r
2.5 Mabswid
.30227 .28163 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28231 m
.3024 .28231 L
s
0 0 0 r
2.5 Mabswid
.3024 .28231 Mdot
.039 .916 .04 r
.5 Mabswid
.3024 .14626 m
.43113 .15447 L
s
0 0 0 r
2.5 Mabswid
.43113 .15447 Mdot
.039 .916 .04 r
.5 Mabswid
.30227 .14694 m
.43115 .15508 L
s
0 0 0 r
2.5 Mabswid
.43115 .15508 Mdot
.039 .916 .04 r
.5 Mabswid
.30214 .14762 m
.43116 .15568 L
s
0 0 0 r
2.5 Mabswid
.43116 .15568 Mdot
.039 .916 .04 r
.5 Mabswid
.30201 .1483 m
.43118 .15629 L
s
0 0 0 r
2.5 Mabswid
.43118 .15629 Mdot
.039 .916 .04 r
.5 Mabswid
.30188 .14898 m
.4312 .15689 L
s
0 0 0 r
2.5 Mabswid
.4312 .15689 Mdot
.039 .916 .04 r
.5 Mabswid
.30176 .14966 m
.43121 .1575 L
s
0 0 0 r
2.5 Mabswid
.43121 .1575 Mdot
.039 .916 .04 r
.5 Mabswid
.30164 .15034 m
.43123 .1581 L
s
0 0 0 r
2.5 Mabswid
.43123 .1581 Mdot
.039 .916 .04 r
.5 Mabswid
.30151 .15102 m
.43124 .1587 L
s
0 0 0 r
2.5 Mabswid
.43124 .1587 Mdot
.039 .916 .04 r
.5 Mabswid
.30139 .1517 m
.43126 .15931 L
s
0 0 0 r
2.5 Mabswid
.43126 .15931 Mdot
.039 .916 .04 r
.5 Mabswid
.30127 .15238 m
.43128 .15991 L
s
0 0 0 r
2.5 Mabswid
.43128 .15991 Mdot
.039 .916 .04 r
.5 Mabswid
.30116 .15306 m
.43129 .16051 L
s
0 0 0 r
2.5 Mabswid
.43129 .16051 Mdot
.039 .916 .04 r
.5 Mabswid
.30104 .15374 m
.43131 .16112 L
s
0 0 0 r
2.5 Mabswid
.43131 .16112 Mdot
.039 .916 .04 r
.5 Mabswid
.30092 .15442 m
.43132 .16172 L
s
0 0 0 r
2.5 Mabswid
.43132 .16172 Mdot
.039 .916 .04 r
.5 Mabswid
.30081 .1551 m
.43134 .16232 L
s
0 0 0 r
2.5 Mabswid
.43134 .16232 Mdot
.039 .916 .04 r
.5 Mabswid
.3007 .15578 m
.43135 .16293 L
s
0 0 0 r
2.5 Mabswid
.43135 .16293 Mdot
.039 .916 .04 r
.5 Mabswid
.30059 .15646 m
.43137 .16353 L
s
0 0 0 r
2.5 Mabswid
.43137 .16353 Mdot
.039 .916 .04 r
.5 Mabswid
.30048 .15714 m
.43138 .16413 L
s
0 0 0 r
2.5 Mabswid
.43138 .16413 Mdot
.039 .916 .04 r
.5 Mabswid
.30037 .15782 m
.43139 .16473 L
s
0 0 0 r
2.5 Mabswid
.43139 .16473 Mdot
.039 .916 .04 r
.5 Mabswid
.30026 .1585 m
.43141 .16533 L
s
0 0 0 r
2.5 Mabswid
.43141 .16533 Mdot
.039 .916 .04 r
.5 Mabswid
.30016 .15918 m
.43142 .16594 L
s
0 0 0 r
2.5 Mabswid
.43142 .16594 Mdot
.039 .916 .04 r
.5 Mabswid
.30005 .15986 m
.43144 .16654 L
s
0 0 0 r
2.5 Mabswid
.43144 .16654 Mdot
.039 .916 .04 r
.5 Mabswid
.29995 .16054 m
.43145 .16714 L
s
0 0 0 r
2.5 Mabswid
.43145 .16714 Mdot
.039 .916 .04 r
.5 Mabswid
.29985 .16122 m
.43146 .16774 L
s
0 0 0 r
2.5 Mabswid
.43146 .16774 Mdot
.039 .916 .04 r
.5 Mabswid
.29975 .1619 m
.43148 .16834 L
s
0 0 0 r
2.5 Mabswid
.43148 .16834 Mdot
.039 .916 .04 r
.5 Mabswid
.29965 .16259 m
.43149 .16894 L
s
0 0 0 r
2.5 Mabswid
.43149 .16894 Mdot
.039 .916 .04 r
.5 Mabswid
.29955 .16327 m
.4315 .16954 L
s
0 0 0 r
2.5 Mabswid
.4315 .16954 Mdot
.039 .916 .04 r
.5 Mabswid
.29945 .16395 m
.43151 .17014 L
s
0 0 0 r
2.5 Mabswid
.43151 .17014 Mdot
.039 .916 .04 r
.5 Mabswid
.29936 .16463 m
.43153 .17074 L
s
0 0 0 r
2.5 Mabswid
.43153 .17074 Mdot
.039 .916 .04 r
.5 Mabswid
.29926 .16531 m
.43154 .17134 L
s
0 0 0 r
2.5 Mabswid
.43154 .17134 Mdot
.039 .916 .04 r
.5 Mabswid
.29917 .16599 m
.43155 .17194 L
s
0 0 0 r
2.5 Mabswid
.43155 .17194 Mdot
.039 .916 .04 r
.5 Mabswid
.29908 .16667 m
.43156 .17254 L
s
0 0 0 r
2.5 Mabswid
.43156 .17254 Mdot
.039 .916 .04 r
.5 Mabswid
.29899 .16735 m
.43157 .17314 L
s
0 0 0 r
2.5 Mabswid
.43157 .17314 Mdot
.039 .916 .04 r
.5 Mabswid
.2989 .16803 m
.43159 .17374 L
s
0 0 0 r
2.5 Mabswid
.43159 .17374 Mdot
.039 .916 .04 r
.5 Mabswid
.29881 .16871 m
.4316 .17434 L
s
0 0 0 r
2.5 Mabswid
.4316 .17434 Mdot
.039 .916 .04 r
.5 Mabswid
.29873 .16939 m
.43161 .17494 L
s
0 0 0 r
2.5 Mabswid
.43161 .17494 Mdot
.039 .916 .04 r
.5 Mabswid
.29864 .17007 m
.43162 .17554 L
s
0 0 0 r
2.5 Mabswid
.43162 .17554 Mdot
.039 .916 .04 r
.5 Mabswid
.29856 .17075 m
.43163 .17614 L
s
0 0 0 r
2.5 Mabswid
.43163 .17614 Mdot
.039 .916 .04 r
.5 Mabswid
.29848 .17143 m
.43164 .17674 L
s
0 0 0 r
2.5 Mabswid
.43164 .17674 Mdot
.039 .916 .04 r
.5 Mabswid
.29839 .17211 m
.43165 .17734 L
s
0 0 0 r
2.5 Mabswid
.43165 .17734 Mdot
.039 .916 .04 r
.5 Mabswid
.29832 .17279 m
.43166 .17793 L
s
0 0 0 r
2.5 Mabswid
.43166 .17793 Mdot
.039 .916 .04 r
.5 Mabswid
.29824 .17347 m
.43167 .17853 L
s
0 0 0 r
2.5 Mabswid
.43167 .17853 Mdot
.039 .916 .04 r
.5 Mabswid
.29816 .17415 m
.43168 .17913 L
s
0 0 0 r
2.5 Mabswid
.43168 .17913 Mdot
.039 .916 .04 r
.5 Mabswid
.29808 .17483 m
.43169 .17973 L
s
0 0 0 r
2.5 Mabswid
.43169 .17973 Mdot
.039 .916 .04 r
.5 Mabswid
.29801 .17551 m
.4317 .18033 L
s
0 0 0 r
2.5 Mabswid
.4317 .18033 Mdot
.039 .916 .04 r
.5 Mabswid
.29794 .17619 m
.43171 .18092 L
s
0 0 0 r
2.5 Mabswid
.43171 .18092 Mdot
.039 .916 .04 r
.5 Mabswid
.29787 .17687 m
.43172 .18152 L
s
0 0 0 r
2.5 Mabswid
.43172 .18152 Mdot
.039 .916 .04 r
.5 Mabswid
.2978 .17755 m
.43173 .18212 L
s
0 0 0 r
2.5 Mabswid
.43173 .18212 Mdot
.039 .916 .04 r
.5 Mabswid
.29773 .17823 m
.43174 .18272 L
s
0 0 0 r
2.5 Mabswid
.43174 .18272 Mdot
.039 .916 .04 r
.5 Mabswid
.29766 .17891 m
.43175 .18332 L
s
0 0 0 r
2.5 Mabswid
.43175 .18332 Mdot
.039 .916 .04 r
.5 Mabswid
.29759 .17959 m
.43176 .18391 L
s
0 0 0 r
2.5 Mabswid
.43176 .18391 Mdot
.039 .916 .04 r
.5 Mabswid
.29753 .18027 m
.43176 .18451 L
s
0 0 0 r
2.5 Mabswid
.43176 .18451 Mdot
.039 .916 .04 r
.5 Mabswid
.29746 .18095 m
.43177 .18511 L
s
0 0 0 r
2.5 Mabswid
.43177 .18511 Mdot
.039 .916 .04 r
.5 Mabswid
.2974 .18163 m
.43178 .1857 L
s
0 0 0 r
2.5 Mabswid
.43178 .1857 Mdot
.039 .916 .04 r
.5 Mabswid
.29734 .18231 m
.43179 .1863 L
s
0 0 0 r
2.5 Mabswid
.43179 .1863 Mdot
.039 .916 .04 r
.5 Mabswid
.29728 .18299 m
.4318 .1869 L
s
0 0 0 r
2.5 Mabswid
.4318 .1869 Mdot
.039 .916 .04 r
.5 Mabswid
.29722 .18367 m
.4318 .18749 L
s
0 0 0 r
2.5 Mabswid
.4318 .18749 Mdot
.039 .916 .04 r
.5 Mabswid
.29716 .18435 m
.43181 .18809 L
s
0 0 0 r
2.5 Mabswid
.43181 .18809 Mdot
.039 .916 .04 r
.5 Mabswid
.29711 .18503 m
.43182 .18869 L
s
0 0 0 r
2.5 Mabswid
.43182 .18869 Mdot
.039 .916 .04 r
.5 Mabswid
.29705 .18571 m
.43183 .18928 L
s
0 0 0 r
2.5 Mabswid
.43183 .18928 Mdot
.039 .916 .04 r
.5 Mabswid
.297 .18639 m
.43183 .18988 L
s
0 0 0 r
2.5 Mabswid
.43183 .18988 Mdot
.039 .916 .04 r
.5 Mabswid
.29695 .18707 m
.43184 .19048 L
s
0 0 0 r
2.5 Mabswid
.43184 .19048 Mdot
.039 .916 .04 r
.5 Mabswid
.2969 .18776 m
.43185 .19107 L
s
0 0 0 r
2.5 Mabswid
.43185 .19107 Mdot
.039 .916 .04 r
.5 Mabswid
.29685 .18844 m
.43185 .19167 L
s
0 0 0 r
2.5 Mabswid
.43185 .19167 Mdot
.039 .916 .04 r
.5 Mabswid
.2968 .18912 m
.43186 .19227 L
s
0 0 0 r
2.5 Mabswid
.43186 .19227 Mdot
.039 .916 .04 r
.5 Mabswid
.29675 .1898 m
.43186 .19286 L
s
0 0 0 r
2.5 Mabswid
.43186 .19286 Mdot
.039 .916 .04 r
.5 Mabswid
.29671 .19048 m
.43187 .19346 L
s
0 0 0 r
2.5 Mabswid
.43187 .19346 Mdot
.039 .916 .04 r
.5 Mabswid
.29666 .19116 m
.43188 .19405 L
s
0 0 0 r
2.5 Mabswid
.43188 .19405 Mdot
.039 .916 .04 r
.5 Mabswid
.29662 .19184 m
.43188 .19465 L
s
0 0 0 r
2.5 Mabswid
.43188 .19465 Mdot
.039 .916 .04 r
.5 Mabswid
.29658 .19252 m
.43189 .19525 L
s
0 0 0 r
2.5 Mabswid
.43189 .19525 Mdot
.039 .916 .04 r
.5 Mabswid
.29654 .1932 m
.43189 .19584 L
s
0 0 0 r
2.5 Mabswid
.43189 .19584 Mdot
.039 .916 .04 r
.5 Mabswid
.2965 .19388 m
.4319 .19644 L
s
0 0 0 r
2.5 Mabswid
.4319 .19644 Mdot
.039 .916 .04 r
.5 Mabswid
.29646 .19456 m
.4319 .19703 L
s
0 0 0 r
2.5 Mabswid
.4319 .19703 Mdot
.039 .916 .04 r
.5 Mabswid
.29642 .19524 m
.43191 .19763 L
s
0 0 0 r
2.5 Mabswid
.43191 .19763 Mdot
.039 .916 .04 r
.5 Mabswid
.29639 .19592 m
.43191 .19822 L
s
0 0 0 r
2.5 Mabswid
.43191 .19822 Mdot
.039 .916 .04 r
.5 Mabswid
.29635 .1966 m
.43192 .19882 L
s
0 0 0 r
2.5 Mabswid
.43192 .19882 Mdot
.039 .916 .04 r
.5 Mabswid
.29632 .19728 m
.43192 .19941 L
s
0 0 0 r
2.5 Mabswid
.43192 .19941 Mdot
.039 .916 .04 r
.5 Mabswid
.29629 .19796 m
.43192 .20001 L
s
0 0 0 r
2.5 Mabswid
.43192 .20001 Mdot
.039 .916 .04 r
.5 Mabswid
.29626 .19864 m
.43193 .2006 L
s
0 0 0 r
2.5 Mabswid
.43193 .2006 Mdot
.039 .916 .04 r
.5 Mabswid
.29623 .19932 m
.43193 .2012 L
s
0 0 0 r
2.5 Mabswid
.43193 .2012 Mdot
.039 .916 .04 r
.5 Mabswid
.2962 .2 m
.43194 .20179 L
s
0 0 0 r
2.5 Mabswid
.43194 .20179 Mdot
.039 .916 .04 r
.5 Mabswid
.29618 .20068 m
.43194 .20239 L
s
0 0 0 r
2.5 Mabswid
.43194 .20239 Mdot
.039 .916 .04 r
.5 Mabswid
.29615 .20136 m
.43194 .20298 L
s
0 0 0 r
2.5 Mabswid
.43194 .20298 Mdot
.039 .916 .04 r
.5 Mabswid
.29613 .20204 m
.43195 .20358 L
s
0 0 0 r
2.5 Mabswid
.43195 .20358 Mdot
.039 .916 .04 r
.5 Mabswid
.2961 .20272 m
.43195 .20417 L
s
0 0 0 r
2.5 Mabswid
.43195 .20417 Mdot
.039 .916 .04 r
.5 Mabswid
.29608 .2034 m
.43195 .20477 L
s
0 0 0 r
2.5 Mabswid
.43195 .20477 Mdot
.039 .916 .04 r
.5 Mabswid
.29606 .20408 m
.43195 .20536 L
s
0 0 0 r
2.5 Mabswid
.43195 .20536 Mdot
.039 .916 .04 r
.5 Mabswid
.29604 .20476 m
.43196 .20596 L
s
0 0 0 r
2.5 Mabswid
.43196 .20596 Mdot
.039 .916 .04 r
.5 Mabswid
.29603 .20544 m
.43196 .20655 L
s
0 0 0 r
2.5 Mabswid
.43196 .20655 Mdot
.039 .916 .04 r
.5 Mabswid
.29601 .20612 m
.43196 .20715 L
s
0 0 0 r
2.5 Mabswid
.43196 .20715 Mdot
.039 .916 .04 r
.5 Mabswid
.296 .2068 m
.43196 .20774 L
s
0 0 0 r
2.5 Mabswid
.43196 .20774 Mdot
.039 .916 .04 r
.5 Mabswid
.29598 .20748 m
.43196 .20834 L
s
0 0 0 r
2.5 Mabswid
.43196 .20834 Mdot
.039 .916 .04 r
.5 Mabswid
.29597 .20816 m
.43197 .20893 L
s
0 0 0 r
2.5 Mabswid
.43197 .20893 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .20884 m
.43197 .20953 L
s
0 0 0 r
2.5 Mabswid
.43197 .20953 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .20952 m
.43197 .21012 L
s
0 0 0 r
2.5 Mabswid
.43197 .21012 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .2102 m
.43197 .21072 L
s
0 0 0 r
2.5 Mabswid
.43197 .21072 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21088 m
.43197 .21131 L
s
0 0 0 r
2.5 Mabswid
.43197 .21131 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21156 m
.43197 .21191 L
s
0 0 0 r
2.5 Mabswid
.43197 .21191 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21224 m
.43197 .2125 L
s
0 0 0 r
2.5 Mabswid
.43197 .2125 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21293 m
.43197 .2131 L
s
0 0 0 r
2.5 Mabswid
.43197 .2131 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21361 m
.43197 .21369 L
s
0 0 0 r
2.5 Mabswid
.43197 .21369 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21429 m
.43197 .21429 L
s
0 0 0 r
2.5 Mabswid
.43197 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21497 m
.43197 .21488 L
s
0 0 0 r
2.5 Mabswid
.43197 .21488 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21565 m
.43197 .21548 L
s
0 0 0 r
2.5 Mabswid
.43197 .21548 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21633 m
.43197 .21607 L
s
0 0 0 r
2.5 Mabswid
.43197 .21607 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21701 m
.43197 .21666 L
s
0 0 0 r
2.5 Mabswid
.43197 .21666 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21769 m
.43197 .21726 L
s
0 0 0 r
2.5 Mabswid
.43197 .21726 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .21837 m
.43197 .21785 L
s
0 0 0 r
2.5 Mabswid
.43197 .21785 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .21905 m
.43197 .21845 L
s
0 0 0 r
2.5 Mabswid
.43197 .21845 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .21973 m
.43197 .21904 L
s
0 0 0 r
2.5 Mabswid
.43197 .21904 Mdot
.039 .916 .04 r
.5 Mabswid
.29597 .22041 m
.43197 .21964 L
s
0 0 0 r
2.5 Mabswid
.43197 .21964 Mdot
.039 .916 .04 r
.5 Mabswid
.29598 .22109 m
.43196 .22023 L
s
0 0 0 r
2.5 Mabswid
.43196 .22023 Mdot
.039 .916 .04 r
.5 Mabswid
.296 .22177 m
.43196 .22083 L
s
0 0 0 r
2.5 Mabswid
.43196 .22083 Mdot
.039 .916 .04 r
.5 Mabswid
.29601 .22245 m
.43196 .22142 L
s
0 0 0 r
2.5 Mabswid
.43196 .22142 Mdot
.039 .916 .04 r
.5 Mabswid
.29603 .22313 m
.43196 .22202 L
s
0 0 0 r
2.5 Mabswid
.43196 .22202 Mdot
.039 .916 .04 r
.5 Mabswid
.29604 .22381 m
.43196 .22261 L
s
0 0 0 r
2.5 Mabswid
.43196 .22261 Mdot
.039 .916 .04 r
.5 Mabswid
.29606 .22449 m
.43195 .22321 L
s
0 0 0 r
2.5 Mabswid
.43195 .22321 Mdot
.039 .916 .04 r
.5 Mabswid
.29608 .22517 m
.43195 .2238 L
s
0 0 0 r
2.5 Mabswid
.43195 .2238 Mdot
.039 .916 .04 r
.5 Mabswid
.2961 .22585 m
.43195 .2244 L
s
0 0 0 r
2.5 Mabswid
.43195 .2244 Mdot
.039 .916 .04 r
.5 Mabswid
.29613 .22653 m
.43195 .22499 L
s
0 0 0 r
2.5 Mabswid
.43195 .22499 Mdot
.039 .916 .04 r
.5 Mabswid
.29615 .22721 m
.43194 .22559 L
s
0 0 0 r
2.5 Mabswid
.43194 .22559 Mdot
.039 .916 .04 r
.5 Mabswid
.29618 .22789 m
.43194 .22618 L
s
0 0 0 r
2.5 Mabswid
.43194 .22618 Mdot
.039 .916 .04 r
.5 Mabswid
.2962 .22857 m
.43194 .22678 L
s
0 0 0 r
2.5 Mabswid
.43194 .22678 Mdot
.039 .916 .04 r
.5 Mabswid
.29623 .22925 m
.43193 .22737 L
s
0 0 0 r
2.5 Mabswid
.43193 .22737 Mdot
.039 .916 .04 r
.5 Mabswid
.29626 .22993 m
.43193 .22797 L
s
0 0 0 r
2.5 Mabswid
.43193 .22797 Mdot
.039 .916 .04 r
.5 Mabswid
.29629 .23061 m
.43192 .22856 L
s
0 0 0 r
2.5 Mabswid
.43192 .22856 Mdot
.039 .916 .04 r
.5 Mabswid
.29632 .23129 m
.43192 .22916 L
s
0 0 0 r
2.5 Mabswid
.43192 .22916 Mdot
.039 .916 .04 r
.5 Mabswid
.29635 .23197 m
.43192 .22975 L
s
0 0 0 r
2.5 Mabswid
.43192 .22975 Mdot
.039 .916 .04 r
.5 Mabswid
.29639 .23265 m
.43191 .23035 L
s
0 0 0 r
2.5 Mabswid
.43191 .23035 Mdot
.039 .916 .04 r
.5 Mabswid
.29642 .23333 m
.43191 .23094 L
s
0 0 0 r
2.5 Mabswid
.43191 .23094 Mdot
.039 .916 .04 r
.5 Mabswid
.29646 .23401 m
.4319 .23154 L
s
0 0 0 r
2.5 Mabswid
.4319 .23154 Mdot
.039 .916 .04 r
.5 Mabswid
.2965 .23469 m
.4319 .23213 L
s
0 0 0 r
2.5 Mabswid
.4319 .23213 Mdot
.039 .916 .04 r
.5 Mabswid
.29654 .23537 m
.43189 .23273 L
s
0 0 0 r
2.5 Mabswid
.43189 .23273 Mdot
.039 .916 .04 r
.5 Mabswid
.29658 .23605 m
.43189 .23333 L
s
0 0 0 r
2.5 Mabswid
.43189 .23333 Mdot
.039 .916 .04 r
.5 Mabswid
.29662 .23673 m
.43188 .23392 L
s
0 0 0 r
2.5 Mabswid
.43188 .23392 Mdot
.039 .916 .04 r
.5 Mabswid
.29666 .23741 m
.43188 .23452 L
s
0 0 0 r
2.5 Mabswid
.43188 .23452 Mdot
.039 .916 .04 r
.5 Mabswid
.29671 .2381 m
.43187 .23511 L
s
0 0 0 r
2.5 Mabswid
.43187 .23511 Mdot
.039 .916 .04 r
.5 Mabswid
.29675 .23878 m
.43186 .23571 L
s
0 0 0 r
2.5 Mabswid
.43186 .23571 Mdot
.039 .916 .04 r
.5 Mabswid
.2968 .23946 m
.43186 .23631 L
s
0 0 0 r
2.5 Mabswid
.43186 .23631 Mdot
.039 .916 .04 r
.5 Mabswid
.29685 .24014 m
.43185 .2369 L
s
0 0 0 r
2.5 Mabswid
.43185 .2369 Mdot
.039 .916 .04 r
.5 Mabswid
.2969 .24082 m
.43185 .2375 L
s
0 0 0 r
2.5 Mabswid
.43185 .2375 Mdot
.039 .916 .04 r
.5 Mabswid
.29695 .2415 m
.43184 .23809 L
s
0 0 0 r
2.5 Mabswid
.43184 .23809 Mdot
.039 .916 .04 r
.5 Mabswid
.297 .24218 m
.43183 .23869 L
s
0 0 0 r
2.5 Mabswid
.43183 .23869 Mdot
.039 .916 .04 r
.5 Mabswid
.29705 .24286 m
.43183 .23929 L
s
0 0 0 r
2.5 Mabswid
.43183 .23929 Mdot
.039 .916 .04 r
.5 Mabswid
.29711 .24354 m
.43182 .23988 L
s
0 0 0 r
2.5 Mabswid
.43182 .23988 Mdot
.039 .916 .04 r
.5 Mabswid
.29716 .24422 m
.43181 .24048 L
s
0 0 0 r
2.5 Mabswid
.43181 .24048 Mdot
.039 .916 .04 r
.5 Mabswid
.29722 .2449 m
.4318 .24108 L
s
0 0 0 r
2.5 Mabswid
.4318 .24108 Mdot
.039 .916 .04 r
.5 Mabswid
.29728 .24558 m
.4318 .24167 L
s
0 0 0 r
2.5 Mabswid
.4318 .24167 Mdot
.039 .916 .04 r
.5 Mabswid
.29734 .24626 m
.43179 .24227 L
s
0 0 0 r
2.5 Mabswid
.43179 .24227 Mdot
.039 .916 .04 r
.5 Mabswid
.2974 .24694 m
.43178 .24287 L
s
0 0 0 r
2.5 Mabswid
.43178 .24287 Mdot
.039 .916 .04 r
.5 Mabswid
.29746 .24762 m
.43177 .24346 L
s
0 0 0 r
2.5 Mabswid
.43177 .24346 Mdot
.039 .916 .04 r
.5 Mabswid
.29753 .2483 m
.43176 .24406 L
s
0 0 0 r
2.5 Mabswid
.43176 .24406 Mdot
.039 .916 .04 r
.5 Mabswid
.29759 .24898 m
.43176 .24466 L
s
0 0 0 r
2.5 Mabswid
.43176 .24466 Mdot
.039 .916 .04 r
.5 Mabswid
.29766 .24966 m
.43175 .24526 L
s
0 0 0 r
2.5 Mabswid
.43175 .24526 Mdot
.039 .916 .04 r
.5 Mabswid
.29773 .25034 m
.43174 .24585 L
s
0 0 0 r
2.5 Mabswid
.43174 .24585 Mdot
.039 .916 .04 r
.5 Mabswid
.2978 .25102 m
.43173 .24645 L
s
0 0 0 r
2.5 Mabswid
.43173 .24645 Mdot
.039 .916 .04 r
.5 Mabswid
.29787 .2517 m
.43172 .24705 L
s
0 0 0 r
2.5 Mabswid
.43172 .24705 Mdot
.039 .916 .04 r
.5 Mabswid
.29794 .25238 m
.43171 .24765 L
s
0 0 0 r
2.5 Mabswid
.43171 .24765 Mdot
.039 .916 .04 r
.5 Mabswid
.29801 .25306 m
.4317 .24824 L
s
0 0 0 r
2.5 Mabswid
.4317 .24824 Mdot
.039 .916 .04 r
.5 Mabswid
.29808 .25374 m
.43169 .24884 L
s
0 0 0 r
2.5 Mabswid
.43169 .24884 Mdot
.039 .916 .04 r
.5 Mabswid
.29816 .25442 m
.43168 .24944 L
s
0 0 0 r
2.5 Mabswid
.43168 .24944 Mdot
.039 .916 .04 r
.5 Mabswid
.29824 .2551 m
.43167 .25004 L
s
0 0 0 r
2.5 Mabswid
.43167 .25004 Mdot
.039 .916 .04 r
.5 Mabswid
.29832 .25578 m
.43166 .25064 L
s
0 0 0 r
2.5 Mabswid
.43166 .25064 Mdot
.039 .916 .04 r
.5 Mabswid
.29839 .25646 m
.43165 .25124 L
s
0 0 0 r
2.5 Mabswid
.43165 .25124 Mdot
.039 .916 .04 r
.5 Mabswid
.29848 .25714 m
.43164 .25184 L
s
0 0 0 r
2.5 Mabswid
.43164 .25184 Mdot
.039 .916 .04 r
.5 Mabswid
.29856 .25782 m
.43163 .25243 L
s
0 0 0 r
2.5 Mabswid
.43163 .25243 Mdot
.039 .916 .04 r
.5 Mabswid
.29864 .2585 m
.43162 .25303 L
s
0 0 0 r
2.5 Mabswid
.43162 .25303 Mdot
.039 .916 .04 r
.5 Mabswid
.29873 .25918 m
.43161 .25363 L
s
0 0 0 r
2.5 Mabswid
.43161 .25363 Mdot
.039 .916 .04 r
.5 Mabswid
.29881 .25986 m
.4316 .25423 L
s
0 0 0 r
2.5 Mabswid
.4316 .25423 Mdot
.039 .916 .04 r
.5 Mabswid
.2989 .26054 m
.43159 .25483 L
s
0 0 0 r
2.5 Mabswid
.43159 .25483 Mdot
.039 .916 .04 r
.5 Mabswid
.29899 .26122 m
.43157 .25543 L
s
0 0 0 r
2.5 Mabswid
.43157 .25543 Mdot
.039 .916 .04 r
.5 Mabswid
.29908 .2619 m
.43156 .25603 L
s
0 0 0 r
2.5 Mabswid
.43156 .25603 Mdot
.039 .916 .04 r
.5 Mabswid
.29917 .26259 m
.43155 .25663 L
s
0 0 0 r
2.5 Mabswid
.43155 .25663 Mdot
.039 .916 .04 r
.5 Mabswid
.29926 .26327 m
.43154 .25723 L
s
0 0 0 r
2.5 Mabswid
.43154 .25723 Mdot
.039 .916 .04 r
.5 Mabswid
.29936 .26395 m
.43153 .25783 L
s
0 0 0 r
2.5 Mabswid
.43153 .25783 Mdot
.039 .916 .04 r
.5 Mabswid
.29945 .26463 m
.43151 .25843 L
s
0 0 0 r
2.5 Mabswid
.43151 .25843 Mdot
.039 .916 .04 r
.5 Mabswid
.29955 .26531 m
.4315 .25903 L
s
0 0 0 r
2.5 Mabswid
.4315 .25903 Mdot
.039 .916 .04 r
.5 Mabswid
.29965 .26599 m
.43149 .25963 L
s
0 0 0 r
2.5 Mabswid
.43149 .25963 Mdot
.039 .916 .04 r
.5 Mabswid
.29975 .26667 m
.43148 .26023 L
s
0 0 0 r
2.5 Mabswid
.43148 .26023 Mdot
.039 .916 .04 r
.5 Mabswid
.29985 .26735 m
.43146 .26083 L
s
0 0 0 r
2.5 Mabswid
.43146 .26083 Mdot
.039 .916 .04 r
.5 Mabswid
.29995 .26803 m
.43145 .26143 L
s
0 0 0 r
2.5 Mabswid
.43145 .26143 Mdot
.039 .916 .04 r
.5 Mabswid
.30005 .26871 m
.43144 .26203 L
s
0 0 0 r
2.5 Mabswid
.43144 .26203 Mdot
.039 .916 .04 r
.5 Mabswid
.30016 .26939 m
.43142 .26264 L
s
0 0 0 r
2.5 Mabswid
.43142 .26264 Mdot
.039 .916 .04 r
.5 Mabswid
.30026 .27007 m
.43141 .26324 L
s
0 0 0 r
2.5 Mabswid
.43141 .26324 Mdot
.039 .916 .04 r
.5 Mabswid
.30037 .27075 m
.43139 .26384 L
s
0 0 0 r
2.5 Mabswid
.43139 .26384 Mdot
.039 .916 .04 r
.5 Mabswid
.30048 .27143 m
.43138 .26444 L
s
0 0 0 r
2.5 Mabswid
.43138 .26444 Mdot
.039 .916 .04 r
.5 Mabswid
.30059 .27211 m
.43137 .26504 L
s
0 0 0 r
2.5 Mabswid
.43137 .26504 Mdot
.039 .916 .04 r
.5 Mabswid
.3007 .27279 m
.43135 .26565 L
s
0 0 0 r
2.5 Mabswid
.43135 .26565 Mdot
.039 .916 .04 r
.5 Mabswid
.30081 .27347 m
.43134 .26625 L
s
0 0 0 r
2.5 Mabswid
.43134 .26625 Mdot
.039 .916 .04 r
.5 Mabswid
.30092 .27415 m
.43132 .26685 L
s
0 0 0 r
2.5 Mabswid
.43132 .26685 Mdot
.039 .916 .04 r
.5 Mabswid
.30104 .27483 m
.43131 .26745 L
s
0 0 0 r
2.5 Mabswid
.43131 .26745 Mdot
.039 .916 .04 r
.5 Mabswid
.30116 .27551 m
.43129 .26806 L
s
0 0 0 r
2.5 Mabswid
.43129 .26806 Mdot
.039 .916 .04 r
.5 Mabswid
.30127 .27619 m
.43128 .26866 L
s
0 0 0 r
2.5 Mabswid
.43128 .26866 Mdot
.039 .916 .04 r
.5 Mabswid
.30139 .27687 m
.43126 .26926 L
s
0 0 0 r
2.5 Mabswid
.43126 .26926 Mdot
.039 .916 .04 r
.5 Mabswid
.30151 .27755 m
.43124 .26987 L
s
0 0 0 r
2.5 Mabswid
.43124 .26987 Mdot
.039 .916 .04 r
.5 Mabswid
.30164 .27823 m
.43123 .27047 L
s
0 0 0 r
2.5 Mabswid
.43123 .27047 Mdot
.039 .916 .04 r
.5 Mabswid
.30176 .27891 m
.43121 .27108 L
s
0 0 0 r
2.5 Mabswid
.43121 .27108 Mdot
.039 .916 .04 r
.5 Mabswid
.30188 .27959 m
.4312 .27168 L
s
0 0 0 r
2.5 Mabswid
.4312 .27168 Mdot
.039 .916 .04 r
.5 Mabswid
.30201 .28027 m
.43118 .27228 L
s
0 0 0 r
2.5 Mabswid
.43118 .27228 Mdot
.039 .916 .04 r
.5 Mabswid
.30214 .28095 m
.43116 .27289 L
s
0 0 0 r
2.5 Mabswid
.43116 .27289 Mdot
.039 .916 .04 r
.5 Mabswid
.30227 .28163 m
.43115 .27349 L
s
0 0 0 r
2.5 Mabswid
.43115 .27349 Mdot
.039 .916 .04 r
.5 Mabswid
.3024 .28231 m
.43113 .2741 L
s
0 0 0 r
2.5 Mabswid
.43113 .2741 Mdot
.039 .916 .04 r
.5 Mabswid
.43113 .15447 m
.97619 .21463 L
s
0 0 0 r
2.5 Mabswid
.97619 .21463 Mdot
.039 .916 .04 r
.5 Mabswid
.43115 .15508 m
.97619 .21461 L
s
0 0 0 r
2.5 Mabswid
.97619 .21461 Mdot
.039 .916 .04 r
.5 Mabswid
.43116 .15568 m
.97619 .21459 L
s
0 0 0 r
2.5 Mabswid
.97619 .21459 Mdot
.039 .916 .04 r
.5 Mabswid
.43118 .15629 m
.97619 .21457 L
s
0 0 0 r
2.5 Mabswid
.97619 .21457 Mdot
.039 .916 .04 r
.5 Mabswid
.4312 .15689 m
.97619 .21455 L
s
0 0 0 r
2.5 Mabswid
.97619 .21455 Mdot
.039 .916 .04 r
.5 Mabswid
.43121 .1575 m
.97619 .21453 L
s
0 0 0 r
2.5 Mabswid
.97619 .21453 Mdot
.039 .916 .04 r
.5 Mabswid
.43123 .1581 m
.97619 .21452 L
s
0 0 0 r
2.5 Mabswid
.97619 .21452 Mdot
.039 .916 .04 r
.5 Mabswid
.43124 .1587 m
.97619 .2145 L
s
0 0 0 r
2.5 Mabswid
.97619 .2145 Mdot
.039 .916 .04 r
.5 Mabswid
.43126 .15931 m
.97619 .21448 L
s
0 0 0 r
2.5 Mabswid
.97619 .21448 Mdot
.039 .916 .04 r
.5 Mabswid
.43128 .15991 m
.97619 .21447 L
s
0 0 0 r
2.5 Mabswid
.97619 .21447 Mdot
.039 .916 .04 r
.5 Mabswid
.43129 .16051 m
.97619 .21445 L
s
0 0 0 r
2.5 Mabswid
.97619 .21445 Mdot
.039 .916 .04 r
.5 Mabswid
.43131 .16112 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43132 .16172 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43134 .16232 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43135 .16293 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43137 .16353 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43138 .16413 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43139 .16473 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43141 .16533 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43142 .16594 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43144 .16654 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43145 .16714 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43146 .16774 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43148 .16834 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43149 .16894 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.4315 .16954 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43151 .17014 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43153 .17074 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43154 .17134 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .17194 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43156 .17254 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43157 .17314 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .17374 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.4316 .17434 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .17494 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43162 .17554 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .17614 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43164 .17674 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .17734 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .17793 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .17853 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .17913 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .17973 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .18033 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .18092 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .18152 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .18212 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .18272 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .18332 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .18391 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .18451 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .18511 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .1857 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .1863 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .1869 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .18749 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .18809 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .18869 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .18928 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .18988 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .19048 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .19107 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .19167 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .19227 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .19286 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .19346 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .19405 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .19465 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19525 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19584 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19644 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19703 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .19763 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .19822 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19882 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19941 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .20001 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .2006 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .2012 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20179 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20239 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20298 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20358 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20417 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20477 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20536 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20596 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20655 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20715 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20774 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20834 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20893 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20953 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21012 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21072 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21131 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21191 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .2125 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .2131 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21369 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21429 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21488 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21548 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21607 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21666 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21726 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21785 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21845 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21904 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21964 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22023 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22083 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22142 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22202 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22261 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22321 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .2238 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .2244 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22499 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22559 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22618 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22678 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22737 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22797 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22856 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22916 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22975 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23035 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23094 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23154 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23213 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23273 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23333 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .23392 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .23452 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .23511 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .23571 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .23631 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .2369 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .2375 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .23809 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .23869 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .23929 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .23988 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .24048 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .24108 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .24167 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .24227 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .24287 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .24346 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .24406 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .24466 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .24526 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .24585 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .24645 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .24705 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .24765 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .24824 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .24884 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .24944 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .25004 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .25064 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .25124 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43164 .25184 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .25243 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43162 .25303 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .25363 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.4316 .25423 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .25483 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43157 .25543 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43156 .25603 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .25663 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43154 .25723 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43153 .25783 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43151 .25843 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.4315 .25903 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43149 .25963 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43148 .26023 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43146 .26083 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43145 .26143 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43144 .26203 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43142 .26264 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43141 .26324 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43139 .26384 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43138 .26444 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43137 .26504 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43135 .26565 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43134 .26625 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43132 .26685 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43131 .26745 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43129 .26806 m
.97619 .21412 L
s
0 0 0 r
2.5 Mabswid
.97619 .21412 Mdot
.039 .916 .04 r
.5 Mabswid
.43128 .26866 m
.97619 .21411 L
s
0 0 0 r
2.5 Mabswid
.97619 .21411 Mdot
.039 .916 .04 r
.5 Mabswid
.43126 .26926 m
.97619 .21409 L
s
0 0 0 r
2.5 Mabswid
.97619 .21409 Mdot
.039 .916 .04 r
.5 Mabswid
.43124 .26987 m
.97619 .21407 L
s
0 0 0 r
2.5 Mabswid
.97619 .21407 Mdot
.039 .916 .04 r
.5 Mabswid
.43123 .27047 m
.97619 .21406 L
s
0 0 0 r
2.5 Mabswid
.97619 .21406 Mdot
.039 .916 .04 r
.5 Mabswid
.43121 .27108 m
.97619 .21404 L
s
0 0 0 r
2.5 Mabswid
.97619 .21404 Mdot
.039 .916 .04 r
.5 Mabswid
.4312 .27168 m
.97619 .21402 L
s
0 0 0 r
2.5 Mabswid
.97619 .21402 Mdot
.039 .916 .04 r
.5 Mabswid
.43118 .27228 m
.97619 .214 L
s
0 0 0 r
2.5 Mabswid
.97619 .214 Mdot
.039 .916 .04 r
.5 Mabswid
.43116 .27289 m
.97619 .21398 L
s
0 0 0 r
2.5 Mabswid
.97619 .21398 Mdot
.039 .916 .04 r
.5 Mabswid
.43115 .27349 m
.97619 .21396 L
s
0 0 0 r
2.5 Mabswid
.97619 .21396 Mdot
.039 .916 .04 r
.5 Mabswid
.43113 .2741 m
.97619 .21394 L
s
0 0 0 r
2.5 Mabswid
.97619 .21394 Mdot
0 0 m
1 0 L
1 .42857 L
0 .42857 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[61]:=",
  ImageSize->{288, 123.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Nb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00IooooolCo`0009gooooo00?o0000ooooooooool0
1_ooool006Oooooo00?o0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`2Kooooo`03o`000?oo
oooooooo00Kooooo001VoooooaCo0000WOooool00ol0003oooooooooo`06ooooo`00I_ooool2o`00
017oOgmo00?o0000ooooooooool0Voooool00ol0003oooooooooo`06ooooo`00IOooool00ol0003o
Ogmoo`00000AogmoO`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool006Cooooo
00Co0000ogmoOomoOgoo00004OmoOgl00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Ko
oooo001Tooooo`04o`000?moOgooOgmoo`00017oOgmo00?o0000ooooooooool0Voooool00ol0003o
ooooooooo`06ooooo`00Hoooool01Ol0003oOgmoogmoOomoOgoo0000017oOgmo00?o0000oooooooo
ool0Voooool00ol0003oooooooooo`06ooooo`00Hoooool01?l0003oOgmoogmoOomoOglCo`0009go
oooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmo
ogmoO`0?ogmoO`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool0067ooooo00?o
0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003ooooooooo
o`06ooooo`00HOooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002L
ooooo`03o`000?oooooooooo00Kooooo001Pooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmo
OomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool0063ooooo00?o0000ogmoOomo
Ogl01?moOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00
Goooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`00
0?oooooooooo00Kooooo001Oooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl03omo
Ogl2o`0009cooooo00?o0000ooooooooool01_ooool005kooooo00?o0000ogmoOomoOgl01_moOgl0
0ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00GOooool00ol0
003oOgmoogmoO`07ogmoOaCo0000W?ooool00ol0003oooooooooo`06ooooo`00GOooool00ol0003o
OgmoogmoO`07ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Ko
oooo001Looooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo
00?o0000ooooooooool01_ooool005cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmo
O`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00G?ooool00ol0003oOgmoogmoO`08
ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Koooo
o`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000oooo
ooooool01_ooool005_ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0?ogmoO`;o
0000W?ooool00ol0003oooooooooo`06ooooo`00Foooool00ol0003oOgmoogmoO`09ogmoO`03o`00
0?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Kooooo`03o`000?mo
OgooOgmo00WoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_oo
ool005[ooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool0
0ol0003oooooooooo`06ooooo`00F_ooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo
00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Jooooo`03o`000?moOgooOgmo00[o
Ogmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool005[ooooo
00?o0000ogmoOomoOgl02_moOglDo`0009cooooo00?o0000ooooooooool01_ooool005Wooooo00?o
0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o
0000ooooooooool01_ooool005Wooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0?
ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool005Wooooo00?o0000ogmo
OomoOgl02omoOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000oooo
ooooool01_ooool005Wooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0?ogmoO`03
o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool005Sooooo00?o0000ogmoOomoOgl0
3?moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool0
1_ooool005Sooooo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?mo
Ogoo000009_ooooo00?o0000ooooooooool01_ooool005Sooooo00?o0000ogmoOomoOgl03?moOgl0
0ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool0
05Sooooo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo0000
09_ooooo00?o0000ooooooooool01_ooool005Oooooo00?o0000ogmoOomoOgl03OmoOgl00ol0003o
OgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool000Oooooo
F_l9jPX6ogmoO`03o`000?moOgooOgmo00ooOgmo00?o0000ogmoOol00000Voooool00ol0003ooooo
ooooo`06ooooo`001ooooom/o`WZ2PKoOgmo00?o0000ogmoOol00000Voooool00ol0003ooooooooo
o`06ooooo`001ooooom>o`WZ2P03o`000?l9jP[o2NX:02Wo2NX:U_ooool00ol0003oooooooooo`06
ooooo`001ooooom>o`WZ2P03o`000?l9jP[o2NX:03;o2NX:SOooool00ol0003oooooooooo`06oooo
o`001ooooom>o`WZ2P03o`000?l9jP[o2NX:03_o2NX:Q?ooool00ol0003oooooooooo`06ooooo`00
1ooooom>o`WZ2P03o`000?l9jP[o2NX:04Co2NX:Noooool00ol0003oooooooooo`06ooooo`001ooo
oom>o`WZ2P03o`000?l9jP[o2NX:04go2NX:L_ooool00ol0003oooooooooo`06ooooo`001ooooonW
o`WZ2VWooooo00?o0000ooooooooool01_ooool000Oooooo/Ol9jPYOooooo`03o`000?oooooooooo
00Kooooo0007ooooodgo2NX:00?o0000o`WZ2_l9jPX0J_l9jPYFooooo`03o`000?oooooooooo00Ko
oooo0007ooooodgo2NX:00?o0000o`WZ2_l9jPX0Lol9jPY=ooooo`03o`000?oooooooooo00Kooooo
0007ooooodgo2NX:00?o0000o`WZ2_l9jPX09?l9jPX00ol0003o2NX:o`WZ2P1Eo`WZ2TCooooo00?o
0000ooooooooool01_ooool000OoooooCOl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o
2NX:05ko2NX:>oooool00ol0003oooooooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:
02Co2NX:00?o0000o`WZ2_l9jPX0J?l9jPXaooooo`03o`000?oooooooooo00Kooooo0007ooooodgo
2NX:00?o0000o`WZ2_l9jPX09?l9jPX00ol0003o2NX:o`WZ2P1ao`WZ2RSooooo00?o0000oooooooo
ool01_ooool000OoooooCOl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:07[o2NX:
7oooool00ol0003oooooooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o
0000o`WZ2_l9jPX0Pol9jPXFooooo`03o`000?oooooooooo00Kooooo0007ooooodgo2NX:00?o0000
o`WZ2_l9jPX09?l9jPX00ol0003o2NX:o`WZ2P2<o`WZ2Pgooooo00?o0000ooooooooool01_ooool0
00OoooooCOl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:09Go2NX:1?ooool00ol0
003oooooooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o0000o`WZ2_l9
jPX0V?l9jPX2o`0000Sooooo0007ooooodgo2NX:00?o0000o`WZ2_l9jPX09?l9jPX00ol0003o2NX:
o`WZ2P2Do`WZ2PCooooo0_l00008ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o
0000o`WZ2_l9jPX0Rol9jPX>ooooo`03o`000?oooooooooo00Kooooo0007ooooodgo2NX:00?o0000
o`WZ2_l9jPX09?l9jPX00ol0003o2NX:o`WZ2P22o`WZ2QOooooo00?o0000ooooooooool01_ooool0
00OoooooCOl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:07Wo2NX:8?ooool00ol0
003oooooooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o0000o`WZ2_l9
jPX0L?l9jPXYooooo`03o`000?oooooooooo00Kooooo0007ooooodgo2NX:00?o0000o`WZ2_l9jPX0
9?l9jPX00ol0003o2NX:o`WZ2P1Wo`WZ2S;ooooo00?o0000ooooooooool01_ooool000OoooooCOl9
jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:05go2NX:??ooool00ol0003ooooooooo
o`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o0000o`WZ2_l9jPX0E?l9jPY5
ooooo`03o`000?oooooooooo00Kooooo0007ooooodgo2NX:00?o0000o`WZ2_l9jPX09?l9jPX00ol0
003o2NX:o`WZ2P1;o`WZ2Tkooooo00?o0000ooooooooool01_ooool000OoooooCOl9jPX00ol0003o
2NX:o`WZ2P1Yo`WZ2UOooooo00?o0000ooooooooool01_ooool000Oooooo/?l9jPYPooooo`03o`00
0?oooooooooo00Kooooo0007ooooojKo2NX:J_ooool00ol0003oooooooooo`06ooooo`001ooooonM
o`WZ2W?ooooo00?o0000ooooooooool01_ooool000OoooooC_l9jPX00ol0003o2NX:o`WZ2P13o`WZ
2Wcooooo00?o0000ooooooooool01_ooool000OoooooC_l9jPX00ol0003o2NX:o`WZ2P0jo`WZ2XGo
oooo00?o0000ooooooooool01_ooool000OoooooC_l9jPX00ol0003o2NX:o`WZ2P0ao`WZ2Xkooooo
00?o0000ooooooooool01_ooool000OoooooC_l9jPX00ol0003o2NX:o`WZ2P0Xo`WZ2YOooooo00?o
0000ooooooooool01_ooool000OoooooK_l9jPX4ogmoO`04o`000?moOgoo0000o`0009[ooooo00?o
0000ooooooooool01_ooool000OoooooH_l9jPX@ogmoO`03o`000?moOgoo000009_ooooo00?o0000
ooooooooool01_ooool000OoooooCol9jPX00ol0003o2NX:o`WZ2P04o`WZ2P[oOgmo00?o0000ogmo
OomoOgl03omoOgl00ol0003oOgmoo`00002Kooooo`03o`000?oooooooooo00Kooooo001Gooooo`03
o`000?moOgooOgmo00goOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoo`00002Kooooo`03
o`000?oooooooooo00Kooooo001Gooooo`03o`000?moOgooOgmo00goOgmo00?o0000ogmoOomoOgl0
3omoOgl00ol0003oOgmoo`00002Kooooo`03o`000?oooooooooo00Kooooo001Hooooo`03o`000?mo
OgooOgmo00coOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoo`00002Kooooo`03o`000?oo
oooooooo00Kooooo001Hooooo`03o`000?moOgooOgmo00coOgmo00?o0000ogmoOomoOgl03omoOgl0
0ol0003oOgmoo`00002Kooooo`03o`000?oooooooooo00Kooooo001Hooooo`03o`000?moOgooOgmo
00coOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoo`00002Kooooo`03o`000?oooooooooo
00Kooooo001Hooooo`03o`000?moOgooOgmo00coOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003o
Ogmoo`00002Kooooo`03o`000?oooooooooo00Kooooo001Iooooo`03o`000?moOgooOgmo00_oOgmo
00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoo`00002Kooooo`03o`000?oooooooooo00Kooooo
001Iooooo`03o`000?moOgooOgmo00_oOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoo`00
002Kooooo`03o`000?oooooooooo00Kooooo001Iooooo`03o`000?moOgooOgmo00_oOgmo4ol00000
0omoOgoo0000ooooo`2Jooooo`03o`000?oooooooooo00Kooooo001Jooooo`03o`000?moOgooOgmo
00[oOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool005[o
oooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003o
ooooooooo`06ooooo`00F_ooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00ooOgmo
0_l0002Looooo`03o`000?oooooooooo00Kooooo001Jooooo`03o`000?moOgooOgmo00[oOgmo00?o
0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool005_ooooo00?o0000
ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06
ooooo`00Foooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Loooo
o`03o`000?oooooooooo00Kooooo001Kooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomo
Ogl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool005_ooooo00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00G?oo
ool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oo
oooooooo00Kooooo001Looooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl03omoOgl2
o`0009cooooo00?o0000ooooooooool01_ooool005cooooo00?o0000ogmoOomoOgl02?moOgl00ol0
003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00GOooool00ol0003o
OgmoogmoO`07ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Ko
oooo001Mooooo`03o`000?moOgooOgmo00OoOgmo5?l0002Looooo`03o`000?oooooooooo00Kooooo
001Nooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o
0000ooooooooool01_ooool005kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0?
ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00Goooool00ol0003oOgmoogmoO`05ogmo
O`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Pooooo`03
o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000oooooooo
ool01_ooool0063ooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000
W?ooool00ol0003oooooooooo`06ooooo`00HOooool00ol0003oOgmoogmoO`03ogmoO`03o`000?mo
OgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Qooooo`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool0
06;ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?oooooooooo
09_ooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ogmoOomoOgl00_moOglCo`0009go
oooo00?o0000ooooooooool01_ooool006?ooooo00Go0000ogmoOomoOgooOgmoo`00000AogmoO`03
o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool006?ooooo00Go0000ogmoOomoOgoo
Ogmoo`00000AogmoO`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool006Cooooo
00Co0000ogmoOomoOgoo00004OmoOgl00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Ko
oooo001Uooooo`03o`000?moOgoo0000017oOgmo00?o0000ooooooooool0Voooool00ol0003ooooo
ooooo`06ooooo`00IOooool00ol0003oOgmoo`00000AogmoO`03o`000?oooooooooo09_ooooo00?o
0000ooooooooool01_ooool006Kooooo5?l0002Mooooo`03o`000?oooooooooo00Kooooo001Voooo
o`;o00004OmoOgl00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Kooooo001Woooooa?o
0000WOooool00ol0003oooooooooo`06ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {122.375, 0}} -> {-21.938, -15.7502, 0.257408, \
0.257408}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],

Cell[BoxData[
    \({FocalPoint \[Rule] {49.990270160471816`, 0, 0}, 
      FocusType \[Rule] RMSFocus, 
      WeightedSpotSize \[Rule] 0.00933055833491677`, 
      SpotSize \[Rule] 0.00933055833491677`, 
      BackFocalLength \[Rule] 40.01102877939476`, 
      FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
      TurboRays \[Rule] TurboRays}\)], "Output",
  CellLabel->"Out[61]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "It is interesting to note that the calculated focal point position ( \
49.9903) is slightly different from the final surface position (50). This is \
partly because the symbolic model uses an infinite number of rays in its \
integration calculation while ",
  StyleBox["TurboPlot", "Input"],
  " is using only a finite number of rays. In addition, however, the symbolic \
model is a third order solution and, as such, does not perfectly model the \
actual system. Therefore, we will next try to improve the accuracy of our \
symbolic model by using a fifth order symbolic solution."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["\<\
Py = (SymbolicSurfaceCoordinates/. 
\tSymbolicTrace[opticalsystem,{{y,0,5}, {c1>0,c2<0,y\[Element]Reals}}, \
MakeFloatingPoint->False])[[1]]\
\>", "Input",
  CellLabel->"In[62]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[BoxData[
    \(\(1\/7776\) \((\(-2592\)\ \((\(-3\) - 60\ c2 + 
                10\ c1\ \((7 + 20\ c2)\))\)\ y - 
          72\ \((2\ c1\^2\ \((\(-9\) + 565\ c1)\) + 
                3\ c1\ \((\(-3\) + 10\ c1\ \((\(-43\) + 200\ c1)\))\)\ c2 + 
                3\ \((3 - 10\ c1)\)\^2\ \((1 + 80\ c1)\)\ c2\^2 + 
                70\ \((\(-3\) + 10\ c1)\)\^3\ c2\^3)\)\ y\^3 - \((9\ c1\^4\ \
\((\(-92\) + 6285\ c1)\) + 
                3\ c1\^3\ \((\(-201\) + 
                      25\ c1\ \((\(-1277\) + 5946\ c1)\))\)\ c2 + 
                c1\^2\ \((\(-3\) + 10\ c1)\)\ \((\(-693\) + 
                      10\ c1\ \((\(-6489\) + 30400\ c1)\))\)\ c2\^2 + 
                15\ \((3 - 10\ c1)\)\^2\ c1\ \((\(-21\) + 
                      2\ c1\ \((\(-1159\) + 
                            5100\ c1)\))\)\ c2\^3 + \((3 - 10\ c1)\)\^4\ \
\((27 + 4295\ c1)\)\ c2\^4 + 
                765\ \((\(-3\) + 10\ c1)\)\^5\ c2\^5)\)\ y\^5)\)\)], "Output",\

  CellLabel->"Out[62]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell["\<\
Once again, we integrate across the system aperture to calculate a symbolic \
merit function for the system's performance.\
\>", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["meritFunction = Expand[Integrate[Expand[Py^2],{y,-5,5}]]", "Input",
  CellLabel->"In[63]:=",
  ShowGroupOpenCloseIcon->True,
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[BoxData[
    \(250\/3 - \(35000\ c1\)\/9 + \(1236250\ c1\^2\)\/27 - \(968750\ \
c1\^3\)\/27 + \(349109375\ c1\^4\)\/567 - \(2329296875\ c1\^5\)\/4536 + \
\(102431640625\ c1\^6\)\/10206 - \(212001953125\ c1\^7\)\/104976 + \
\(50938525390625\ c1\^8\)\/769824 - \(2352783203125\ c1\^9\)\/171072 + \
\(214307861328125\ c1\^10\)\/456192 + \(10000\ c2\)\/3 - \(798125\ c1\ \
c2\)\/9 + \(7900000\ c1\^2\ c2\)\/27 - \(2090328125\ c1\^3\ c2\)\/1512 + \
\(25395546875\ c1\^4\ c2\)\/4536 - \(2300486328125\ c1\^5\ c2\)\/81648 + \
\(160184697265625\ c1\^6\ c2\)\/1469664 - \(2779331298828125\ c1\^7\ \
c2\)\/13856832 + \(1486375732421875\ c1\^8\ c2\)\/1679616 - \
\(1162784423828125\ c1\^9\ c2\)\/684288 + \(2534356689453125\ c1\^10\ \
c2\)\/342144 + \(98125\ c2\^2\)\/3 - \(2243750\ c1\ c2\^2\)\/9 + \(441484375\ \
c1\^2\ c2\^2\)\/189 - \(1473671875\ c1\^3\ c2\^2\)\/108 + \(12991157421875\ \
c1\^4\ c2\^2\)\/163296 - \(99485732421875\ c1\^5\ c2\^2\)\/244944 + \
\(322325887451171875\ c1\^6\ c2\^2\)\/258660864 - \(6768020263671875\ c1\^7\ \
c2\^2\)\/1732104 + \(4152190914306640625\ c1\^8\ c2\^2\)\/332563968 - \
\(362196966552734375\ c1\^9\ c2\^2\)\/9237888 + \(245400482177734375\ c1\^10\ \
c2\^2\)\/3079296 + 
      31250\ c2\^3 - \(389421875\ c1\ c2\^3\)\/168 + \(200234375\ c1\^2\ \
c2\^3\)\/9 - \(1510480859375\ c1\^3\ c2\^3\)\/9072 + \(24587552734375\ c1\^4\ \
c2\^3\)\/23328 - \(20983917822265625\ c1\^5\ c2\^3\)\/4790016 + \
\(68883686767578125\ c1\^6\ c2\^3\)\/4618944 - \(2957855224609375\ c1\^7\ \
c2\^3\)\/57024 + \(1246444476318359375\ c1\^8\ c2\^3\)\/6928416 - \
\(218181732177734375\ c1\^9\ c2\^3\)\/433026 + \(376575469970703125\ c1\^10\ \
c2\^3\)\/577368 + \(6046875\ c2\^4\)\/7 - \(2118203125\ c1\ c2\^4\)\/168 + \
\(1580979296875\ c1\^2\ c2\^4\)\/9072 - \(1607212890625\ c1\^3\ c2\^4\)\/1008 \
+ \(253555792197265625\ c1\^4\ c2\^4\)\/28740096 - \(798616814697265625\ \
c1\^5\ c2\^4\)\/21555072 + \(2104258258056640625\ c1\^6\ c2\^4\)\/14370048 - \
\(3988927069091796875\ c1\^7\ c2\^4\)\/6928416 + \(2563099151611328125\ c1\^8\
\ c2\^4\)\/1299078 - \(940356750488281250\ c1\^9\ c2\^4\)\/216513 + \
\(3848905181884765625\ c1\^10\ c2\^4\)\/944784 + \(34765625\ c2\^5\)\/56 - \
\(19638671875\ c1\ c2\^5\)\/216 + \(8404970703125\ c1\^2\ c2\^5\)\/6048 - \
\(2823120654296875\ c1\^3\ c2\^5\)\/266112 + \(211972466552734375\ c1\^4\ \
c2\^5\)\/3592512 - \(6230438472900390625\ c1\^5\ c2\^5\)\/21555072 + \
\(14390346649169921875\ c1\^6\ c2\^5\)\/10777536 - \(6310224212646484375\ \
c1\^7\ c2\^5\)\/1154736 + \(84513123931884765625\ c1\^8\ c2\^5\)\/5196312 - \
\(48772490692138671875\ c1\^9\ c2\^5\)\/1732104 + \(1977787017822265625\ \
c1\^10\ c2\^5\)\/96228 + \(6326171875\ c2\^6\)\/224 - \(1641962890625\ c1\ c2\
\^6\)\/3024 + \(6314786669921875\ c1\^2\ c2\^6\)\/1064448 - \
\(20271781005859375\ c1\^3\ c2\^6\)\/399168 + \(465213931884765625\ c1\^4\ c2\
\^6\)\/1306368 - \(7652917498779296875\ c1\^5\ c2\^6\)\/3592512 + \
\(115843923309326171875\ c1\^6\ c2\^6\)\/10777536 - \(6395081329345703125\ c1\
\^7\ c2\^6\)\/157464 + \(346760147857666015625\ c1\^8\ c2\^6\)\/3464208 - \
\(120812252044677734375\ c1\^9\ c2\^6\)\/866052 + \(214941539764404296875\ c1\
\^10\ c2\^6\)\/2598156 - \(302734375\ c2\^7\)\/32 - \(66585302734375\ c1\ \
c2\^7\)\/76032 + \(324571533203125\ c1\^2\ c2\^7\)\/14256 - \
\(15572891845703125\ c1\^3\ c2\^7\)\/57024 + \(591092437744140625\ c1\^4\ \
c2\^7\)\/256608 - \(5760250885009765625\ c1\^5\ c2\^7\)\/384912 + \
\(13644067230224609375\ c1\^6\ c2\^7\)\/192456 - \(196852710723876953125\ \
c1\^7\ c2\^7\)\/866052 + \(597395549774169921875\ c1\^8\ c2\^7\)\/1299078 - \
\(114205551147460937500\ c1\^9\ c2\^7\)\/216513 + \(18855094909667968750\ \
c1\^10\ c2\^7\)\/72171 + \(2049267578125\ c2\^8\)\/5632 - \(39387939453125\ \
c1\ c2\^8\)\/4224 + \(2339837646484375\ c1\^2\ c2\^8\)\/16896 - \
\(562030029296875\ c1\^3\ c2\^8\)\/352 + \(43555816650390625\ c1\^4\ \
c2\^8\)\/3168 - \(586810760498046875\ c1\^5\ c2\^8\)\/7128 + \
\(14212165069580078125\ c1\^6\ c2\^8\)\/42768 - \(14196491241455078125\ c1\^7\
\ c2\^8\)\/16038 + \(35912551879882812500\ c1\^8\ c2\^8\)\/24057 - \
\(313185501098632812500\ c1\^9\ c2\^8\)\/216513 + \(798340320587158203125\ c1\
\^10\ c2\^8\)\/1299078 - \(336181640625\ c2\^9\)\/2816 - \(43392333984375\ c1\
\ c2\^9\)\/2816 + \(734930419921875\ c1\^2\ c2\^9\)\/1408 - \
\(1271575927734375\ c1\^3\ c2\^9\)\/176 + \(1888427734375000\ c1\^4\ \
c2\^9\)\/33 - \(76354217529296875\ c1\^5\ c2\^9\)\/264 + \(34954071044921875\ \
c1\^6\ c2\^9\)\/36 - \(1932201385498046875\ c1\^7\ c2\^9\)\/891 + \
\(2770709991455078125\ c1\^8\ c2\^9\)\/891 - \(6947040557861328125\ c1\^9\ c2\
\^9\)\/2673 + \(69632530212402343750\ c1\^10\ c2\^9\)\/72171 + \
\(28575439453125\ c2\^10\)\/5632 - \(238128662109375\ c1\ c2\^10\)\/1408 + \
\(3571929931640625\ c1\^2\ c2\^10\)\/1408 - \(1984405517578125\ c1\^3\ c2\^10\
\)\/88 + \(23151397705078125\ c1\^4\ c2\^10\)\/176 - \(23151397705078125\ \
c1\^5\ c2\^10\)\/44 + \(192928314208984375\ c1\^6\ c2\^10\)\/132 - \
\(275611877441406250\ c1\^7\ c2\^10\)\/99 + \(689029693603515625\ c1\^8\ \
c2\^10\)\/198 - \(6890296936035156250\ c1\^9\ c2\^10\)\/2673 + \
\(6890296936035156250\ c1\^10\ c2\^10\)\/8019\)], "Output",
  CellLabel->"Out[63]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "This time, since we already have the third-order global minimum for lens \
system, we will use its solution as a starting point for a search with ",
  StyleBox["FindMinimum", "Input"],
  " on the fifth-order model."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["\<\
localminimum = \
FindMinimum[meritFunction,{c1,Evaluate[c1/.finalextrema[[1,2]]]},{c2,Evaluate[\
c2/.finalextrema[[1,2]]]}, AccuracyGoal->12]\
\>", "Input",
  CellLabel->"In[64]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[BoxData[
    \({0.0008424998851486139`, {c1 \[Rule] 0.037687861910365064`, 
        c2 \[Rule] \(-0.006483581897499261`\)}}\)], "Output",
  CellLabel->"Out[64]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "Since the third-order solution was already determined, the fifth-order \
result with FindMinimum is calculated very quickly. And we can, once again, \
verify the resulting solution by numerically tracing the resulting system and \
calculating the resulting focal point and spot size with ",
  StyleBox["FindFocusFast", "Input"],
  "."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["\<\
FindFocusFast[TurboPlot[
\tMove[LineOfRays[10,NumberOfRays->201,IntrinsicMedium->1],{-20,0}],
\tplot,SymbolicValues->localminimum[[2]], PlotType->TopView]]\
\>", "Input",
  CellLabel->"In[65]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42857 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.295918 0.0136054 0.214286 0.0136054 [
[ 0 0 0 0 ]
[ 1 .42857 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.35914 .0102 m
.42203 .0102 L
.42756 .07823 L
.32254 .07823 L
.35914 .0102 L
F
.32254 .07823 m
.42756 .07823 L
.43087 .14626 L
.30239 .14626 L
.32254 .07823 L
F
.30239 .14626 m
.43087 .14626 L
.43197 .21429 L
.29592 .21429 L
.30239 .14626 L
F
.29592 .21429 m
.43197 .21429 L
.43087 .28231 L
.30239 .28231 L
.29592 .21429 L
F
.30239 .28231 m
.43087 .28231 L
.42756 .35034 L
.32254 .35034 L
.30239 .28231 L
F
.32254 .35034 m
.42756 .35034 L
.42203 .41837 L
.35914 .41837 L
.32254 .35034 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.35914 .0102 m
.32254 .07823 L
.30239 .14626 L
.29592 .21429 L
.30239 .28231 L
.32254 .35034 L
.35914 .41837 L
.42203 .41837 L
.42756 .35034 L
.43087 .28231 L
.43197 .21429 L
.43087 .14626 L
.42756 .07823 L
.42203 .0102 L
.35914 .0102 L
s
.5 g
.35914 .21429 m
.42203 .21429 L
.42756 .21429 L
.32254 .21429 L
.35914 .21429 L
F
.32254 .21429 m
.42756 .21429 L
.43087 .21429 L
.30239 .21429 L
.32254 .21429 L
F
.30239 .21429 m
.43087 .21429 L
.43197 .21429 L
.29592 .21429 L
.30239 .21429 L
F
.29592 .21429 m
.43197 .21429 L
.43087 .21429 L
.30239 .21429 L
.29592 .21429 L
F
.30239 .21429 m
.43087 .21429 L
.42756 .21429 L
.32254 .21429 L
.30239 .21429 L
F
.32254 .21429 m
.42756 .21429 L
.42203 .21429 L
.35914 .21429 L
.32254 .21429 L
F
0 g
.35914 .21429 m
.32254 .21429 L
.30239 .21429 L
.29592 .21429 L
.30239 .21429 L
.32254 .21429 L
.35914 .21429 L
.42203 .21429 L
.42756 .21429 L
.43087 .21429 L
.43197 .21429 L
.43087 .21429 L
.42756 .21429 L
.42203 .21429 L
.35914 .21429 L
s
.35914 .41837 m
.42203 .41837 L
.42203 .41141 L
.35914 .41141 L
.35914 .41837 L
s
.35914 .41141 m
.42203 .41141 L
.42203 .39103 L
.35914 .39103 L
.35914 .41141 L
s
.35914 .39103 m
.42203 .39103 L
.42203 .35859 L
.35914 .35859 L
.35914 .39103 L
s
.35914 .35859 m
.42203 .35859 L
.42203 .31633 L
.35914 .31633 L
.35914 .35859 L
s
.35914 .31633 m
.42203 .31633 L
.42203 .26711 L
.35914 .26711 L
.35914 .31633 L
s
.35914 .26711 m
.42203 .26711 L
.42203 .21429 L
.35914 .21429 L
.35914 .26711 L
s
.35914 .21429 m
.42203 .21429 L
.42203 .16147 L
.35914 .16147 L
.35914 .21429 L
s
.35914 .16147 m
.42203 .16147 L
.42203 .11224 L
.35914 .11224 L
.35914 .16147 L
s
.35914 .11224 m
.42203 .11224 L
.42203 .06998 L
.35914 .06998 L
.35914 .11224 L
s
.35914 .06998 m
.42203 .06998 L
.42203 .03755 L
.35914 .03755 L
.35914 .06998 L
s
.35914 .03755 m
.42203 .03755 L
.42203 .01716 L
.35914 .01716 L
.35914 .03755 L
s
.35914 .01716 m
.42203 .01716 L
.42203 .0102 L
.35914 .0102 L
.35914 .01716 L
s
.35914 .0102 m
.42203 .0102 L
.42203 .01716 L
.35914 .01716 L
.35914 .0102 L
s
.35914 .01716 m
.42203 .01716 L
.42203 .03755 L
.35914 .03755 L
.35914 .01716 L
s
.35914 .03755 m
.42203 .03755 L
.42203 .06998 L
.35914 .06998 L
.35914 .03755 L
s
.35914 .06998 m
.42203 .06998 L
.42203 .11224 L
.35914 .11224 L
.35914 .06998 L
s
.35914 .11224 m
.42203 .11224 L
.42203 .16147 L
.35914 .16147 L
.35914 .11224 L
s
.35914 .16147 m
.42203 .16147 L
.42203 .21429 L
.35914 .21429 L
.35914 .16147 L
s
.35914 .21429 m
.42203 .21429 L
.42203 .26711 L
.35914 .26711 L
.35914 .21429 L
s
.35914 .26711 m
.42203 .26711 L
.42203 .31633 L
.35914 .31633 L
.35914 .26711 L
s
.35914 .31633 m
.42203 .31633 L
.42203 .35859 L
.35914 .35859 L
.35914 .31633 L
s
.35914 .35859 m
.42203 .35859 L
.42203 .39103 L
.35914 .39103 L
.35914 .35859 L
s
.35914 .39103 m
.42203 .39103 L
.42203 .41141 L
.35914 .41141 L
.35914 .39103 L
s
.35914 .41141 m
.42203 .41141 L
.42203 .41837 L
.35914 .41837 L
.35914 .41141 L
s
.97619 .0102 m
.97619 .07823 L
.97619 .14626 L
.97619 .21429 L
.97619 .28231 L
.97619 .35034 L
.97619 .41837 L
.97619 .41837 L
.97619 .35034 L
.97619 .28231 L
.97619 .21429 L
.97619 .14626 L
.97619 .07823 L
.97619 .0102 L
.97619 .0102 L
s
.97619 .21429 m
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
s
.97619 .41837 m
.97619 .41141 L
.97619 .39103 L
.97619 .35859 L
.97619 .31633 L
.97619 .26711 L
.97619 .21429 L
.97619 .16147 L
.97619 .11224 L
.97619 .06998 L
.97619 .03755 L
.97619 .01716 L
.97619 .0102 L
.97619 .01716 L
.97619 .03755 L
.97619 .06998 L
.97619 .11224 L
.97619 .16147 L
.97619 .21429 L
.97619 .26711 L
.97619 .31633 L
.97619 .35859 L
.97619 .39103 L
.97619 .41141 L
.97619 .41837 L
s
.039 .916 .04 r
.02381 .14626 m
.30239 .14626 L
s
0 0 0 r
2.5 Mabswid
.30239 .14626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14694 m
.30226 .14694 L
s
0 0 0 r
2.5 Mabswid
.30226 .14694 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14762 m
.30213 .14762 L
s
0 0 0 r
2.5 Mabswid
.30213 .14762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1483 m
.302 .1483 L
s
0 0 0 r
2.5 Mabswid
.302 .1483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14898 m
.30187 .14898 L
s
0 0 0 r
2.5 Mabswid
.30187 .14898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14966 m
.30175 .14966 L
s
0 0 0 r
2.5 Mabswid
.30175 .14966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15034 m
.30163 .15034 L
s
0 0 0 r
2.5 Mabswid
.30163 .15034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15102 m
.30151 .15102 L
s
0 0 0 r
2.5 Mabswid
.30151 .15102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1517 m
.30138 .1517 L
s
0 0 0 r
2.5 Mabswid
.30138 .1517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15238 m
.30127 .15238 L
s
0 0 0 r
2.5 Mabswid
.30127 .15238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15306 m
.30115 .15306 L
s
0 0 0 r
2.5 Mabswid
.30115 .15306 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15374 m
.30103 .15374 L
s
0 0 0 r
2.5 Mabswid
.30103 .15374 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15442 m
.30092 .15442 L
s
0 0 0 r
2.5 Mabswid
.30092 .15442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1551 m
.3008 .1551 L
s
0 0 0 r
2.5 Mabswid
.3008 .1551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15578 m
.30069 .15578 L
s
0 0 0 r
2.5 Mabswid
.30069 .15578 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15646 m
.30058 .15646 L
s
0 0 0 r
2.5 Mabswid
.30058 .15646 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15714 m
.30047 .15714 L
s
0 0 0 r
2.5 Mabswid
.30047 .15714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15782 m
.30036 .15782 L
s
0 0 0 r
2.5 Mabswid
.30036 .15782 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1585 m
.30025 .1585 L
s
0 0 0 r
2.5 Mabswid
.30025 .1585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15918 m
.30015 .15918 L
s
0 0 0 r
2.5 Mabswid
.30015 .15918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15986 m
.30004 .15986 L
s
0 0 0 r
2.5 Mabswid
.30004 .15986 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16054 m
.29994 .16054 L
s
0 0 0 r
2.5 Mabswid
.29994 .16054 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16122 m
.29984 .16122 L
s
0 0 0 r
2.5 Mabswid
.29984 .16122 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1619 m
.29974 .1619 L
s
0 0 0 r
2.5 Mabswid
.29974 .1619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16259 m
.29964 .16259 L
s
0 0 0 r
2.5 Mabswid
.29964 .16259 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16327 m
.29954 .16327 L
s
0 0 0 r
2.5 Mabswid
.29954 .16327 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16395 m
.29945 .16395 L
s
0 0 0 r
2.5 Mabswid
.29945 .16395 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16463 m
.29935 .16463 L
s
0 0 0 r
2.5 Mabswid
.29935 .16463 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16531 m
.29926 .16531 L
s
0 0 0 r
2.5 Mabswid
.29926 .16531 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16599 m
.29916 .16599 L
s
0 0 0 r
2.5 Mabswid
.29916 .16599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16667 m
.29907 .16667 L
s
0 0 0 r
2.5 Mabswid
.29907 .16667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16735 m
.29898 .16735 L
s
0 0 0 r
2.5 Mabswid
.29898 .16735 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16803 m
.29889 .16803 L
s
0 0 0 r
2.5 Mabswid
.29889 .16803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16871 m
.29881 .16871 L
s
0 0 0 r
2.5 Mabswid
.29881 .16871 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16939 m
.29872 .16939 L
s
0 0 0 r
2.5 Mabswid
.29872 .16939 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17007 m
.29864 .17007 L
s
0 0 0 r
2.5 Mabswid
.29864 .17007 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17075 m
.29855 .17075 L
s
0 0 0 r
2.5 Mabswid
.29855 .17075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17143 m
.29847 .17143 L
s
0 0 0 r
2.5 Mabswid
.29847 .17143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17211 m
.29839 .17211 L
s
0 0 0 r
2.5 Mabswid
.29839 .17211 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17279 m
.29831 .17279 L
s
0 0 0 r
2.5 Mabswid
.29831 .17279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17347 m
.29823 .17347 L
s
0 0 0 r
2.5 Mabswid
.29823 .17347 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17415 m
.29816 .17415 L
s
0 0 0 r
2.5 Mabswid
.29816 .17415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17483 m
.29808 .17483 L
s
0 0 0 r
2.5 Mabswid
.29808 .17483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17551 m
.29801 .17551 L
s
0 0 0 r
2.5 Mabswid
.29801 .17551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17619 m
.29793 .17619 L
s
0 0 0 r
2.5 Mabswid
.29793 .17619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17687 m
.29786 .17687 L
s
0 0 0 r
2.5 Mabswid
.29786 .17687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17755 m
.29779 .17755 L
s
0 0 0 r
2.5 Mabswid
.29779 .17755 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17823 m
.29772 .17823 L
s
0 0 0 r
2.5 Mabswid
.29772 .17823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17891 m
.29766 .17891 L
s
0 0 0 r
2.5 Mabswid
.29766 .17891 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17959 m
.29759 .17959 L
s
0 0 0 r
2.5 Mabswid
.29759 .17959 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18027 m
.29752 .18027 L
s
0 0 0 r
2.5 Mabswid
.29752 .18027 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18095 m
.29746 .18095 L
s
0 0 0 r
2.5 Mabswid
.29746 .18095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18163 m
.2974 .18163 L
s
0 0 0 r
2.5 Mabswid
.2974 .18163 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18231 m
.29734 .18231 L
s
0 0 0 r
2.5 Mabswid
.29734 .18231 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18299 m
.29728 .18299 L
s
0 0 0 r
2.5 Mabswid
.29728 .18299 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18367 m
.29722 .18367 L
s
0 0 0 r
2.5 Mabswid
.29722 .18367 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18435 m
.29716 .18435 L
s
0 0 0 r
2.5 Mabswid
.29716 .18435 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18503 m
.29711 .18503 L
s
0 0 0 r
2.5 Mabswid
.29711 .18503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18571 m
.29705 .18571 L
s
0 0 0 r
2.5 Mabswid
.29705 .18571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18639 m
.297 .18639 L
s
0 0 0 r
2.5 Mabswid
.297 .18639 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18707 m
.29695 .18707 L
s
0 0 0 r
2.5 Mabswid
.29695 .18707 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18776 m
.29689 .18776 L
s
0 0 0 r
2.5 Mabswid
.29689 .18776 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18844 m
.29685 .18844 L
s
0 0 0 r
2.5 Mabswid
.29685 .18844 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18912 m
.2968 .18912 L
s
0 0 0 r
2.5 Mabswid
.2968 .18912 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1898 m
.29675 .1898 L
s
0 0 0 r
2.5 Mabswid
.29675 .1898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19048 m
.2967 .19048 L
s
0 0 0 r
2.5 Mabswid
.2967 .19048 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19116 m
.29666 .19116 L
s
0 0 0 r
2.5 Mabswid
.29666 .19116 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19184 m
.29662 .19184 L
s
0 0 0 r
2.5 Mabswid
.29662 .19184 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19252 m
.29658 .19252 L
s
0 0 0 r
2.5 Mabswid
.29658 .19252 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1932 m
.29653 .1932 L
s
0 0 0 r
2.5 Mabswid
.29653 .1932 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19388 m
.2965 .19388 L
s
0 0 0 r
2.5 Mabswid
.2965 .19388 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19456 m
.29646 .19456 L
s
0 0 0 r
2.5 Mabswid
.29646 .19456 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19524 m
.29642 .19524 L
s
0 0 0 r
2.5 Mabswid
.29642 .19524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19592 m
.29639 .19592 L
s
0 0 0 r
2.5 Mabswid
.29639 .19592 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1966 m
.29635 .1966 L
s
0 0 0 r
2.5 Mabswid
.29635 .1966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19728 m
.29632 .19728 L
s
0 0 0 r
2.5 Mabswid
.29632 .19728 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19796 m
.29629 .19796 L
s
0 0 0 r
2.5 Mabswid
.29629 .19796 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19864 m
.29626 .19864 L
s
0 0 0 r
2.5 Mabswid
.29626 .19864 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19932 m
.29623 .19932 L
s
0 0 0 r
2.5 Mabswid
.29623 .19932 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2 m
.2962 .2 L
s
0 0 0 r
2.5 Mabswid
.2962 .2 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20068 m
.29617 .20068 L
s
0 0 0 r
2.5 Mabswid
.29617 .20068 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20136 m
.29615 .20136 L
s
0 0 0 r
2.5 Mabswid
.29615 .20136 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20204 m
.29613 .20204 L
s
0 0 0 r
2.5 Mabswid
.29613 .20204 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20272 m
.2961 .20272 L
s
0 0 0 r
2.5 Mabswid
.2961 .20272 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2034 m
.29608 .2034 L
s
0 0 0 r
2.5 Mabswid
.29608 .2034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20408 m
.29606 .20408 L
s
0 0 0 r
2.5 Mabswid
.29606 .20408 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20476 m
.29604 .20476 L
s
0 0 0 r
2.5 Mabswid
.29604 .20476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20544 m
.29603 .20544 L
s
0 0 0 r
2.5 Mabswid
.29603 .20544 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20612 m
.29601 .20612 L
s
0 0 0 r
2.5 Mabswid
.29601 .20612 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2068 m
.296 .2068 L
s
0 0 0 r
2.5 Mabswid
.296 .2068 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20748 m
.29598 .20748 L
s
0 0 0 r
2.5 Mabswid
.29598 .20748 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20816 m
.29597 .20816 L
s
0 0 0 r
2.5 Mabswid
.29597 .20816 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20884 m
.29596 .20884 L
s
0 0 0 r
2.5 Mabswid
.29596 .20884 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20952 m
.29595 .20952 L
s
0 0 0 r
2.5 Mabswid
.29595 .20952 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2102 m
.29594 .2102 L
s
0 0 0 r
2.5 Mabswid
.29594 .2102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21088 m
.29593 .21088 L
s
0 0 0 r
2.5 Mabswid
.29593 .21088 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21156 m
.29593 .21156 L
s
0 0 0 r
2.5 Mabswid
.29593 .21156 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21224 m
.29592 .21224 L
s
0 0 0 r
2.5 Mabswid
.29592 .21224 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21293 m
.29592 .21293 L
s
0 0 0 r
2.5 Mabswid
.29592 .21293 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21361 m
.29592 .21361 L
s
0 0 0 r
2.5 Mabswid
.29592 .21361 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21429 m
.29592 .21429 L
s
0 0 0 r
2.5 Mabswid
.29592 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21497 m
.29592 .21497 L
s
0 0 0 r
2.5 Mabswid
.29592 .21497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21565 m
.29592 .21565 L
s
0 0 0 r
2.5 Mabswid
.29592 .21565 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21633 m
.29592 .21633 L
s
0 0 0 r
2.5 Mabswid
.29592 .21633 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21701 m
.29593 .21701 L
s
0 0 0 r
2.5 Mabswid
.29593 .21701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21769 m
.29593 .21769 L
s
0 0 0 r
2.5 Mabswid
.29593 .21769 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21837 m
.29594 .21837 L
s
0 0 0 r
2.5 Mabswid
.29594 .21837 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21905 m
.29595 .21905 L
s
0 0 0 r
2.5 Mabswid
.29595 .21905 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21973 m
.29596 .21973 L
s
0 0 0 r
2.5 Mabswid
.29596 .21973 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22041 m
.29597 .22041 L
s
0 0 0 r
2.5 Mabswid
.29597 .22041 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22109 m
.29598 .22109 L
s
0 0 0 r
2.5 Mabswid
.29598 .22109 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22177 m
.296 .22177 L
s
0 0 0 r
2.5 Mabswid
.296 .22177 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22245 m
.29601 .22245 L
s
0 0 0 r
2.5 Mabswid
.29601 .22245 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22313 m
.29603 .22313 L
s
0 0 0 r
2.5 Mabswid
.29603 .22313 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22381 m
.29604 .22381 L
s
0 0 0 r
2.5 Mabswid
.29604 .22381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22449 m
.29606 .22449 L
s
0 0 0 r
2.5 Mabswid
.29606 .22449 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22517 m
.29608 .22517 L
s
0 0 0 r
2.5 Mabswid
.29608 .22517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22585 m
.2961 .22585 L
s
0 0 0 r
2.5 Mabswid
.2961 .22585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22653 m
.29613 .22653 L
s
0 0 0 r
2.5 Mabswid
.29613 .22653 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22721 m
.29615 .22721 L
s
0 0 0 r
2.5 Mabswid
.29615 .22721 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22789 m
.29617 .22789 L
s
0 0 0 r
2.5 Mabswid
.29617 .22789 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22857 m
.2962 .22857 L
s
0 0 0 r
2.5 Mabswid
.2962 .22857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22925 m
.29623 .22925 L
s
0 0 0 r
2.5 Mabswid
.29623 .22925 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22993 m
.29626 .22993 L
s
0 0 0 r
2.5 Mabswid
.29626 .22993 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23061 m
.29629 .23061 L
s
0 0 0 r
2.5 Mabswid
.29629 .23061 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23129 m
.29632 .23129 L
s
0 0 0 r
2.5 Mabswid
.29632 .23129 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23197 m
.29635 .23197 L
s
0 0 0 r
2.5 Mabswid
.29635 .23197 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23265 m
.29639 .23265 L
s
0 0 0 r
2.5 Mabswid
.29639 .23265 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23333 m
.29642 .23333 L
s
0 0 0 r
2.5 Mabswid
.29642 .23333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23401 m
.29646 .23401 L
s
0 0 0 r
2.5 Mabswid
.29646 .23401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23469 m
.2965 .23469 L
s
0 0 0 r
2.5 Mabswid
.2965 .23469 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23537 m
.29653 .23537 L
s
0 0 0 r
2.5 Mabswid
.29653 .23537 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23605 m
.29658 .23605 L
s
0 0 0 r
2.5 Mabswid
.29658 .23605 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23673 m
.29662 .23673 L
s
0 0 0 r
2.5 Mabswid
.29662 .23673 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23741 m
.29666 .23741 L
s
0 0 0 r
2.5 Mabswid
.29666 .23741 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2381 m
.2967 .2381 L
s
0 0 0 r
2.5 Mabswid
.2967 .2381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23878 m
.29675 .23878 L
s
0 0 0 r
2.5 Mabswid
.29675 .23878 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23946 m
.2968 .23946 L
s
0 0 0 r
2.5 Mabswid
.2968 .23946 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24014 m
.29685 .24014 L
s
0 0 0 r
2.5 Mabswid
.29685 .24014 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24082 m
.29689 .24082 L
s
0 0 0 r
2.5 Mabswid
.29689 .24082 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2415 m
.29695 .2415 L
s
0 0 0 r
2.5 Mabswid
.29695 .2415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24218 m
.297 .24218 L
s
0 0 0 r
2.5 Mabswid
.297 .24218 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24286 m
.29705 .24286 L
s
0 0 0 r
2.5 Mabswid
.29705 .24286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24354 m
.29711 .24354 L
s
0 0 0 r
2.5 Mabswid
.29711 .24354 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24422 m
.29716 .24422 L
s
0 0 0 r
2.5 Mabswid
.29716 .24422 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2449 m
.29722 .2449 L
s
0 0 0 r
2.5 Mabswid
.29722 .2449 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24558 m
.29728 .24558 L
s
0 0 0 r
2.5 Mabswid
.29728 .24558 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24626 m
.29734 .24626 L
s
0 0 0 r
2.5 Mabswid
.29734 .24626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24694 m
.2974 .24694 L
s
0 0 0 r
2.5 Mabswid
.2974 .24694 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24762 m
.29746 .24762 L
s
0 0 0 r
2.5 Mabswid
.29746 .24762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2483 m
.29752 .2483 L
s
0 0 0 r
2.5 Mabswid
.29752 .2483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24898 m
.29759 .24898 L
s
0 0 0 r
2.5 Mabswid
.29759 .24898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24966 m
.29766 .24966 L
s
0 0 0 r
2.5 Mabswid
.29766 .24966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25034 m
.29772 .25034 L
s
0 0 0 r
2.5 Mabswid
.29772 .25034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25102 m
.29779 .25102 L
s
0 0 0 r
2.5 Mabswid
.29779 .25102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2517 m
.29786 .2517 L
s
0 0 0 r
2.5 Mabswid
.29786 .2517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25238 m
.29793 .25238 L
s
0 0 0 r
2.5 Mabswid
.29793 .25238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25306 m
.29801 .25306 L
s
0 0 0 r
2.5 Mabswid
.29801 .25306 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25374 m
.29808 .25374 L
s
0 0 0 r
2.5 Mabswid
.29808 .25374 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25442 m
.29816 .25442 L
s
0 0 0 r
2.5 Mabswid
.29816 .25442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2551 m
.29823 .2551 L
s
0 0 0 r
2.5 Mabswid
.29823 .2551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25578 m
.29831 .25578 L
s
0 0 0 r
2.5 Mabswid
.29831 .25578 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25646 m
.29839 .25646 L
s
0 0 0 r
2.5 Mabswid
.29839 .25646 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25714 m
.29847 .25714 L
s
0 0 0 r
2.5 Mabswid
.29847 .25714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25782 m
.29855 .25782 L
s
0 0 0 r
2.5 Mabswid
.29855 .25782 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2585 m
.29864 .2585 L
s
0 0 0 r
2.5 Mabswid
.29864 .2585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25918 m
.29872 .25918 L
s
0 0 0 r
2.5 Mabswid
.29872 .25918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25986 m
.29881 .25986 L
s
0 0 0 r
2.5 Mabswid
.29881 .25986 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26054 m
.29889 .26054 L
s
0 0 0 r
2.5 Mabswid
.29889 .26054 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26122 m
.29898 .26122 L
s
0 0 0 r
2.5 Mabswid
.29898 .26122 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2619 m
.29907 .2619 L
s
0 0 0 r
2.5 Mabswid
.29907 .2619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26259 m
.29916 .26259 L
s
0 0 0 r
2.5 Mabswid
.29916 .26259 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26327 m
.29926 .26327 L
s
0 0 0 r
2.5 Mabswid
.29926 .26327 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26395 m
.29935 .26395 L
s
0 0 0 r
2.5 Mabswid
.29935 .26395 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26463 m
.29945 .26463 L
s
0 0 0 r
2.5 Mabswid
.29945 .26463 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26531 m
.29954 .26531 L
s
0 0 0 r
2.5 Mabswid
.29954 .26531 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26599 m
.29964 .26599 L
s
0 0 0 r
2.5 Mabswid
.29964 .26599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26667 m
.29974 .26667 L
s
0 0 0 r
2.5 Mabswid
.29974 .26667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26735 m
.29984 .26735 L
s
0 0 0 r
2.5 Mabswid
.29984 .26735 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26803 m
.29994 .26803 L
s
0 0 0 r
2.5 Mabswid
.29994 .26803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26871 m
.30004 .26871 L
s
0 0 0 r
2.5 Mabswid
.30004 .26871 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26939 m
.30015 .26939 L
s
0 0 0 r
2.5 Mabswid
.30015 .26939 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27007 m
.30025 .27007 L
s
0 0 0 r
2.5 Mabswid
.30025 .27007 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27075 m
.30036 .27075 L
s
0 0 0 r
2.5 Mabswid
.30036 .27075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27143 m
.30047 .27143 L
s
0 0 0 r
2.5 Mabswid
.30047 .27143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27211 m
.30058 .27211 L
s
0 0 0 r
2.5 Mabswid
.30058 .27211 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27279 m
.30069 .27279 L
s
0 0 0 r
2.5 Mabswid
.30069 .27279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27347 m
.3008 .27347 L
s
0 0 0 r
2.5 Mabswid
.3008 .27347 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27415 m
.30092 .27415 L
s
0 0 0 r
2.5 Mabswid
.30092 .27415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27483 m
.30103 .27483 L
s
0 0 0 r
2.5 Mabswid
.30103 .27483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27551 m
.30115 .27551 L
s
0 0 0 r
2.5 Mabswid
.30115 .27551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27619 m
.30127 .27619 L
s
0 0 0 r
2.5 Mabswid
.30127 .27619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27687 m
.30138 .27687 L
s
0 0 0 r
2.5 Mabswid
.30138 .27687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27755 m
.30151 .27755 L
s
0 0 0 r
2.5 Mabswid
.30151 .27755 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27823 m
.30163 .27823 L
s
0 0 0 r
2.5 Mabswid
.30163 .27823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27891 m
.30175 .27891 L
s
0 0 0 r
2.5 Mabswid
.30175 .27891 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27959 m
.30187 .27959 L
s
0 0 0 r
2.5 Mabswid
.30187 .27959 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28027 m
.302 .28027 L
s
0 0 0 r
2.5 Mabswid
.302 .28027 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28095 m
.30213 .28095 L
s
0 0 0 r
2.5 Mabswid
.30213 .28095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28163 m
.30226 .28163 L
s
0 0 0 r
2.5 Mabswid
.30226 .28163 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28231 m
.30239 .28231 L
s
0 0 0 r
2.5 Mabswid
.30239 .28231 Mdot
.039 .916 .04 r
.5 Mabswid
.30239 .14626 m
.43112 .15446 L
s
0 0 0 r
2.5 Mabswid
.43112 .15446 Mdot
.039 .916 .04 r
.5 Mabswid
.30226 .14694 m
.43114 .15506 L
s
0 0 0 r
2.5 Mabswid
.43114 .15506 Mdot
.039 .916 .04 r
.5 Mabswid
.30213 .14762 m
.43115 .15567 L
s
0 0 0 r
2.5 Mabswid
.43115 .15567 Mdot
.039 .916 .04 r
.5 Mabswid
.302 .1483 m
.43117 .15627 L
s
0 0 0 r
2.5 Mabswid
.43117 .15627 Mdot
.039 .916 .04 r
.5 Mabswid
.30187 .14898 m
.43119 .15688 L
s
0 0 0 r
2.5 Mabswid
.43119 .15688 Mdot
.039 .916 .04 r
.5 Mabswid
.30175 .14966 m
.4312 .15748 L
s
0 0 0 r
2.5 Mabswid
.4312 .15748 Mdot
.039 .916 .04 r
.5 Mabswid
.30163 .15034 m
.43122 .15809 L
s
0 0 0 r
2.5 Mabswid
.43122 .15809 Mdot
.039 .916 .04 r
.5 Mabswid
.30151 .15102 m
.43124 .15869 L
s
0 0 0 r
2.5 Mabswid
.43124 .15869 Mdot
.039 .916 .04 r
.5 Mabswid
.30138 .1517 m
.43125 .15929 L
s
0 0 0 r
2.5 Mabswid
.43125 .15929 Mdot
.039 .916 .04 r
.5 Mabswid
.30127 .15238 m
.43127 .1599 L
s
0 0 0 r
2.5 Mabswid
.43127 .1599 Mdot
.039 .916 .04 r
.5 Mabswid
.30115 .15306 m
.43128 .1605 L
s
0 0 0 r
2.5 Mabswid
.43128 .1605 Mdot
.039 .916 .04 r
.5 Mabswid
.30103 .15374 m
.4313 .1611 L
s
0 0 0 r
2.5 Mabswid
.4313 .1611 Mdot
.039 .916 .04 r
.5 Mabswid
.30092 .15442 m
.43131 .16171 L
s
0 0 0 r
2.5 Mabswid
.43131 .16171 Mdot
.039 .916 .04 r
.5 Mabswid
.3008 .1551 m
.43133 .16231 L
s
0 0 0 r
2.5 Mabswid
.43133 .16231 Mdot
.039 .916 .04 r
.5 Mabswid
.30069 .15578 m
.43134 .16291 L
s
0 0 0 r
2.5 Mabswid
.43134 .16291 Mdot
.039 .916 .04 r
.5 Mabswid
.30058 .15646 m
.43136 .16352 L
s
0 0 0 r
2.5 Mabswid
.43136 .16352 Mdot
.039 .916 .04 r
.5 Mabswid
.30047 .15714 m
.43137 .16412 L
s
0 0 0 r
2.5 Mabswid
.43137 .16412 Mdot
.039 .916 .04 r
.5 Mabswid
.30036 .15782 m
.43139 .16472 L
s
0 0 0 r
2.5 Mabswid
.43139 .16472 Mdot
.039 .916 .04 r
.5 Mabswid
.30025 .1585 m
.4314 .16532 L
s
0 0 0 r
2.5 Mabswid
.4314 .16532 Mdot
.039 .916 .04 r
.5 Mabswid
.30015 .15918 m
.43142 .16592 L
s
0 0 0 r
2.5 Mabswid
.43142 .16592 Mdot
.039 .916 .04 r
.5 Mabswid
.30004 .15986 m
.43143 .16653 L
s
0 0 0 r
2.5 Mabswid
.43143 .16653 Mdot
.039 .916 .04 r
.5 Mabswid
.29994 .16054 m
.43144 .16713 L
s
0 0 0 r
2.5 Mabswid
.43144 .16713 Mdot
.039 .916 .04 r
.5 Mabswid
.29984 .16122 m
.43146 .16773 L
s
0 0 0 r
2.5 Mabswid
.43146 .16773 Mdot
.039 .916 .04 r
.5 Mabswid
.29974 .1619 m
.43147 .16833 L
s
0 0 0 r
2.5 Mabswid
.43147 .16833 Mdot
.039 .916 .04 r
.5 Mabswid
.29964 .16259 m
.43148 .16893 L
s
0 0 0 r
2.5 Mabswid
.43148 .16893 Mdot
.039 .916 .04 r
.5 Mabswid
.29954 .16327 m
.4315 .16953 L
s
0 0 0 r
2.5 Mabswid
.4315 .16953 Mdot
.039 .916 .04 r
.5 Mabswid
.29945 .16395 m
.43151 .17013 L
s
0 0 0 r
2.5 Mabswid
.43151 .17013 Mdot
.039 .916 .04 r
.5 Mabswid
.29935 .16463 m
.43152 .17073 L
s
0 0 0 r
2.5 Mabswid
.43152 .17073 Mdot
.039 .916 .04 r
.5 Mabswid
.29926 .16531 m
.43153 .17133 L
s
0 0 0 r
2.5 Mabswid
.43153 .17133 Mdot
.039 .916 .04 r
.5 Mabswid
.29916 .16599 m
.43155 .17193 L
s
0 0 0 r
2.5 Mabswid
.43155 .17193 Mdot
.039 .916 .04 r
.5 Mabswid
.29907 .16667 m
.43156 .17253 L
s
0 0 0 r
2.5 Mabswid
.43156 .17253 Mdot
.039 .916 .04 r
.5 Mabswid
.29898 .16735 m
.43157 .17313 L
s
0 0 0 r
2.5 Mabswid
.43157 .17313 Mdot
.039 .916 .04 r
.5 Mabswid
.29889 .16803 m
.43158 .17373 L
s
0 0 0 r
2.5 Mabswid
.43158 .17373 Mdot
.039 .916 .04 r
.5 Mabswid
.29881 .16871 m
.43159 .17433 L
s
0 0 0 r
2.5 Mabswid
.43159 .17433 Mdot
.039 .916 .04 r
.5 Mabswid
.29872 .16939 m
.4316 .17493 L
s
0 0 0 r
2.5 Mabswid
.4316 .17493 Mdot
.039 .916 .04 r
.5 Mabswid
.29864 .17007 m
.43161 .17553 L
s
0 0 0 r
2.5 Mabswid
.43161 .17553 Mdot
.039 .916 .04 r
.5 Mabswid
.29855 .17075 m
.43163 .17613 L
s
0 0 0 r
2.5 Mabswid
.43163 .17613 Mdot
.039 .916 .04 r
.5 Mabswid
.29847 .17143 m
.43164 .17673 L
s
0 0 0 r
2.5 Mabswid
.43164 .17673 Mdot
.039 .916 .04 r
.5 Mabswid
.29839 .17211 m
.43165 .17733 L
s
0 0 0 r
2.5 Mabswid
.43165 .17733 Mdot
.039 .916 .04 r
.5 Mabswid
.29831 .17279 m
.43166 .17792 L
s
0 0 0 r
2.5 Mabswid
.43166 .17792 Mdot
.039 .916 .04 r
.5 Mabswid
.29823 .17347 m
.43167 .17852 L
s
0 0 0 r
2.5 Mabswid
.43167 .17852 Mdot
.039 .916 .04 r
.5 Mabswid
.29816 .17415 m
.43168 .17912 L
s
0 0 0 r
2.5 Mabswid
.43168 .17912 Mdot
.039 .916 .04 r
.5 Mabswid
.29808 .17483 m
.43169 .17972 L
s
0 0 0 r
2.5 Mabswid
.43169 .17972 Mdot
.039 .916 .04 r
.5 Mabswid
.29801 .17551 m
.4317 .18032 L
s
0 0 0 r
2.5 Mabswid
.4317 .18032 Mdot
.039 .916 .04 r
.5 Mabswid
.29793 .17619 m
.43171 .18092 L
s
0 0 0 r
2.5 Mabswid
.43171 .18092 Mdot
.039 .916 .04 r
.5 Mabswid
.29786 .17687 m
.43172 .18151 L
s
0 0 0 r
2.5 Mabswid
.43172 .18151 Mdot
.039 .916 .04 r
.5 Mabswid
.29779 .17755 m
.43173 .18211 L
s
0 0 0 r
2.5 Mabswid
.43173 .18211 Mdot
.039 .916 .04 r
.5 Mabswid
.29772 .17823 m
.43174 .18271 L
s
0 0 0 r
2.5 Mabswid
.43174 .18271 Mdot
.039 .916 .04 r
.5 Mabswid
.29766 .17891 m
.43174 .18331 L
s
0 0 0 r
2.5 Mabswid
.43174 .18331 Mdot
.039 .916 .04 r
.5 Mabswid
.29759 .17959 m
.43175 .18391 L
s
0 0 0 r
2.5 Mabswid
.43175 .18391 Mdot
.039 .916 .04 r
.5 Mabswid
.29752 .18027 m
.43176 .1845 L
s
0 0 0 r
2.5 Mabswid
.43176 .1845 Mdot
.039 .916 .04 r
.5 Mabswid
.29746 .18095 m
.43177 .1851 L
s
0 0 0 r
2.5 Mabswid
.43177 .1851 Mdot
.039 .916 .04 r
.5 Mabswid
.2974 .18163 m
.43178 .1857 L
s
0 0 0 r
2.5 Mabswid
.43178 .1857 Mdot
.039 .916 .04 r
.5 Mabswid
.29734 .18231 m
.43179 .18629 L
s
0 0 0 r
2.5 Mabswid
.43179 .18629 Mdot
.039 .916 .04 r
.5 Mabswid
.29728 .18299 m
.43179 .18689 L
s
0 0 0 r
2.5 Mabswid
.43179 .18689 Mdot
.039 .916 .04 r
.5 Mabswid
.29722 .18367 m
.4318 .18749 L
s
0 0 0 r
2.5 Mabswid
.4318 .18749 Mdot
.039 .916 .04 r
.5 Mabswid
.29716 .18435 m
.43181 .18809 L
s
0 0 0 r
2.5 Mabswid
.43181 .18809 Mdot
.039 .916 .04 r
.5 Mabswid
.29711 .18503 m
.43182 .18868 L
s
0 0 0 r
2.5 Mabswid
.43182 .18868 Mdot
.039 .916 .04 r
.5 Mabswid
.29705 .18571 m
.43182 .18928 L
s
0 0 0 r
2.5 Mabswid
.43182 .18928 Mdot
.039 .916 .04 r
.5 Mabswid
.297 .18639 m
.43183 .18988 L
s
0 0 0 r
2.5 Mabswid
.43183 .18988 Mdot
.039 .916 .04 r
.5 Mabswid
.29695 .18707 m
.43184 .19047 L
s
0 0 0 r
2.5 Mabswid
.43184 .19047 Mdot
.039 .916 .04 r
.5 Mabswid
.29689 .18776 m
.43184 .19107 L
s
0 0 0 r
2.5 Mabswid
.43184 .19107 Mdot
.039 .916 .04 r
.5 Mabswid
.29685 .18844 m
.43185 .19166 L
s
0 0 0 r
2.5 Mabswid
.43185 .19166 Mdot
.039 .916 .04 r
.5 Mabswid
.2968 .18912 m
.43186 .19226 L
s
0 0 0 r
2.5 Mabswid
.43186 .19226 Mdot
.039 .916 .04 r
.5 Mabswid
.29675 .1898 m
.43186 .19286 L
s
0 0 0 r
2.5 Mabswid
.43186 .19286 Mdot
.039 .916 .04 r
.5 Mabswid
.2967 .19048 m
.43187 .19345 L
s
0 0 0 r
2.5 Mabswid
.43187 .19345 Mdot
.039 .916 .04 r
.5 Mabswid
.29666 .19116 m
.43188 .19405 L
s
0 0 0 r
2.5 Mabswid
.43188 .19405 Mdot
.039 .916 .04 r
.5 Mabswid
.29662 .19184 m
.43188 .19464 L
s
0 0 0 r
2.5 Mabswid
.43188 .19464 Mdot
.039 .916 .04 r
.5 Mabswid
.29658 .19252 m
.43189 .19524 L
s
0 0 0 r
2.5 Mabswid
.43189 .19524 Mdot
.039 .916 .04 r
.5 Mabswid
.29653 .1932 m
.43189 .19584 L
s
0 0 0 r
2.5 Mabswid
.43189 .19584 Mdot
.039 .916 .04 r
.5 Mabswid
.2965 .19388 m
.4319 .19643 L
s
0 0 0 r
2.5 Mabswid
.4319 .19643 Mdot
.039 .916 .04 r
.5 Mabswid
.29646 .19456 m
.4319 .19703 L
s
0 0 0 r
2.5 Mabswid
.4319 .19703 Mdot
.039 .916 .04 r
.5 Mabswid
.29642 .19524 m
.43191 .19762 L
s
0 0 0 r
2.5 Mabswid
.43191 .19762 Mdot
.039 .916 .04 r
.5 Mabswid
.29639 .19592 m
.43191 .19822 L
s
0 0 0 r
2.5 Mabswid
.43191 .19822 Mdot
.039 .916 .04 r
.5 Mabswid
.29635 .1966 m
.43192 .19881 L
s
0 0 0 r
2.5 Mabswid
.43192 .19881 Mdot
.039 .916 .04 r
.5 Mabswid
.29632 .19728 m
.43192 .19941 L
s
0 0 0 r
2.5 Mabswid
.43192 .19941 Mdot
.039 .916 .04 r
.5 Mabswid
.29629 .19796 m
.43192 .20001 L
s
0 0 0 r
2.5 Mabswid
.43192 .20001 Mdot
.039 .916 .04 r
.5 Mabswid
.29626 .19864 m
.43193 .2006 L
s
0 0 0 r
2.5 Mabswid
.43193 .2006 Mdot
.039 .916 .04 r
.5 Mabswid
.29623 .19932 m
.43193 .2012 L
s
0 0 0 r
2.5 Mabswid
.43193 .2012 Mdot
.039 .916 .04 r
.5 Mabswid
.2962 .2 m
.43194 .20179 L
s
0 0 0 r
2.5 Mabswid
.43194 .20179 Mdot
.039 .916 .04 r
.5 Mabswid
.29617 .20068 m
.43194 .20239 L
s
0 0 0 r
2.5 Mabswid
.43194 .20239 Mdot
.039 .916 .04 r
.5 Mabswid
.29615 .20136 m
.43194 .20298 L
s
0 0 0 r
2.5 Mabswid
.43194 .20298 Mdot
.039 .916 .04 r
.5 Mabswid
.29613 .20204 m
.43195 .20358 L
s
0 0 0 r
2.5 Mabswid
.43195 .20358 Mdot
.039 .916 .04 r
.5 Mabswid
.2961 .20272 m
.43195 .20417 L
s
0 0 0 r
2.5 Mabswid
.43195 .20417 Mdot
.039 .916 .04 r
.5 Mabswid
.29608 .2034 m
.43195 .20477 L
s
0 0 0 r
2.5 Mabswid
.43195 .20477 Mdot
.039 .916 .04 r
.5 Mabswid
.29606 .20408 m
.43195 .20536 L
s
0 0 0 r
2.5 Mabswid
.43195 .20536 Mdot
.039 .916 .04 r
.5 Mabswid
.29604 .20476 m
.43196 .20596 L
s
0 0 0 r
2.5 Mabswid
.43196 .20596 Mdot
.039 .916 .04 r
.5 Mabswid
.29603 .20544 m
.43196 .20655 L
s
0 0 0 r
2.5 Mabswid
.43196 .20655 Mdot
.039 .916 .04 r
.5 Mabswid
.29601 .20612 m
.43196 .20715 L
s
0 0 0 r
2.5 Mabswid
.43196 .20715 Mdot
.039 .916 .04 r
.5 Mabswid
.296 .2068 m
.43196 .20774 L
s
0 0 0 r
2.5 Mabswid
.43196 .20774 Mdot
.039 .916 .04 r
.5 Mabswid
.29598 .20748 m
.43196 .20834 L
s
0 0 0 r
2.5 Mabswid
.43196 .20834 Mdot
.039 .916 .04 r
.5 Mabswid
.29597 .20816 m
.43197 .20893 L
s
0 0 0 r
2.5 Mabswid
.43197 .20893 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .20884 m
.43197 .20953 L
s
0 0 0 r
2.5 Mabswid
.43197 .20953 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .20952 m
.43197 .21012 L
s
0 0 0 r
2.5 Mabswid
.43197 .21012 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .2102 m
.43197 .21072 L
s
0 0 0 r
2.5 Mabswid
.43197 .21072 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21088 m
.43197 .21131 L
s
0 0 0 r
2.5 Mabswid
.43197 .21131 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21156 m
.43197 .21191 L
s
0 0 0 r
2.5 Mabswid
.43197 .21191 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21224 m
.43197 .2125 L
s
0 0 0 r
2.5 Mabswid
.43197 .2125 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21293 m
.43197 .2131 L
s
0 0 0 r
2.5 Mabswid
.43197 .2131 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21361 m
.43197 .21369 L
s
0 0 0 r
2.5 Mabswid
.43197 .21369 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21429 m
.43197 .21429 L
s
0 0 0 r
2.5 Mabswid
.43197 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21497 m
.43197 .21488 L
s
0 0 0 r
2.5 Mabswid
.43197 .21488 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21565 m
.43197 .21548 L
s
0 0 0 r
2.5 Mabswid
.43197 .21548 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21633 m
.43197 .21607 L
s
0 0 0 r
2.5 Mabswid
.43197 .21607 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21701 m
.43197 .21666 L
s
0 0 0 r
2.5 Mabswid
.43197 .21666 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21769 m
.43197 .21726 L
s
0 0 0 r
2.5 Mabswid
.43197 .21726 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .21837 m
.43197 .21785 L
s
0 0 0 r
2.5 Mabswid
.43197 .21785 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .21905 m
.43197 .21845 L
s
0 0 0 r
2.5 Mabswid
.43197 .21845 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .21973 m
.43197 .21904 L
s
0 0 0 r
2.5 Mabswid
.43197 .21904 Mdot
.039 .916 .04 r
.5 Mabswid
.29597 .22041 m
.43197 .21964 L
s
0 0 0 r
2.5 Mabswid
.43197 .21964 Mdot
.039 .916 .04 r
.5 Mabswid
.29598 .22109 m
.43196 .22023 L
s
0 0 0 r
2.5 Mabswid
.43196 .22023 Mdot
.039 .916 .04 r
.5 Mabswid
.296 .22177 m
.43196 .22083 L
s
0 0 0 r
2.5 Mabswid
.43196 .22083 Mdot
.039 .916 .04 r
.5 Mabswid
.29601 .22245 m
.43196 .22142 L
s
0 0 0 r
2.5 Mabswid
.43196 .22142 Mdot
.039 .916 .04 r
.5 Mabswid
.29603 .22313 m
.43196 .22202 L
s
0 0 0 r
2.5 Mabswid
.43196 .22202 Mdot
.039 .916 .04 r
.5 Mabswid
.29604 .22381 m
.43196 .22261 L
s
0 0 0 r
2.5 Mabswid
.43196 .22261 Mdot
.039 .916 .04 r
.5 Mabswid
.29606 .22449 m
.43195 .22321 L
s
0 0 0 r
2.5 Mabswid
.43195 .22321 Mdot
.039 .916 .04 r
.5 Mabswid
.29608 .22517 m
.43195 .2238 L
s
0 0 0 r
2.5 Mabswid
.43195 .2238 Mdot
.039 .916 .04 r
.5 Mabswid
.2961 .22585 m
.43195 .2244 L
s
0 0 0 r
2.5 Mabswid
.43195 .2244 Mdot
.039 .916 .04 r
.5 Mabswid
.29613 .22653 m
.43195 .22499 L
s
0 0 0 r
2.5 Mabswid
.43195 .22499 Mdot
.039 .916 .04 r
.5 Mabswid
.29615 .22721 m
.43194 .22559 L
s
0 0 0 r
2.5 Mabswid
.43194 .22559 Mdot
.039 .916 .04 r
.5 Mabswid
.29617 .22789 m
.43194 .22618 L
s
0 0 0 r
2.5 Mabswid
.43194 .22618 Mdot
.039 .916 .04 r
.5 Mabswid
.2962 .22857 m
.43194 .22678 L
s
0 0 0 r
2.5 Mabswid
.43194 .22678 Mdot
.039 .916 .04 r
.5 Mabswid
.29623 .22925 m
.43193 .22738 L
s
0 0 0 r
2.5 Mabswid
.43193 .22738 Mdot
.039 .916 .04 r
.5 Mabswid
.29626 .22993 m
.43193 .22797 L
s
0 0 0 r
2.5 Mabswid
.43193 .22797 Mdot
.039 .916 .04 r
.5 Mabswid
.29629 .23061 m
.43192 .22857 L
s
0 0 0 r
2.5 Mabswid
.43192 .22857 Mdot
.039 .916 .04 r
.5 Mabswid
.29632 .23129 m
.43192 .22916 L
s
0 0 0 r
2.5 Mabswid
.43192 .22916 Mdot
.039 .916 .04 r
.5 Mabswid
.29635 .23197 m
.43192 .22976 L
s
0 0 0 r
2.5 Mabswid
.43192 .22976 Mdot
.039 .916 .04 r
.5 Mabswid
.29639 .23265 m
.43191 .23035 L
s
0 0 0 r
2.5 Mabswid
.43191 .23035 Mdot
.039 .916 .04 r
.5 Mabswid
.29642 .23333 m
.43191 .23095 L
s
0 0 0 r
2.5 Mabswid
.43191 .23095 Mdot
.039 .916 .04 r
.5 Mabswid
.29646 .23401 m
.4319 .23154 L
s
0 0 0 r
2.5 Mabswid
.4319 .23154 Mdot
.039 .916 .04 r
.5 Mabswid
.2965 .23469 m
.4319 .23214 L
s
0 0 0 r
2.5 Mabswid
.4319 .23214 Mdot
.039 .916 .04 r
.5 Mabswid
.29653 .23537 m
.43189 .23273 L
s
0 0 0 r
2.5 Mabswid
.43189 .23273 Mdot
.039 .916 .04 r
.5 Mabswid
.29658 .23605 m
.43189 .23333 L
s
0 0 0 r
2.5 Mabswid
.43189 .23333 Mdot
.039 .916 .04 r
.5 Mabswid
.29662 .23673 m
.43188 .23393 L
s
0 0 0 r
2.5 Mabswid
.43188 .23393 Mdot
.039 .916 .04 r
.5 Mabswid
.29666 .23741 m
.43188 .23452 L
s
0 0 0 r
2.5 Mabswid
.43188 .23452 Mdot
.039 .916 .04 r
.5 Mabswid
.2967 .2381 m
.43187 .23512 L
s
0 0 0 r
2.5 Mabswid
.43187 .23512 Mdot
.039 .916 .04 r
.5 Mabswid
.29675 .23878 m
.43186 .23571 L
s
0 0 0 r
2.5 Mabswid
.43186 .23571 Mdot
.039 .916 .04 r
.5 Mabswid
.2968 .23946 m
.43186 .23631 L
s
0 0 0 r
2.5 Mabswid
.43186 .23631 Mdot
.039 .916 .04 r
.5 Mabswid
.29685 .24014 m
.43185 .23691 L
s
0 0 0 r
2.5 Mabswid
.43185 .23691 Mdot
.039 .916 .04 r
.5 Mabswid
.29689 .24082 m
.43184 .2375 L
s
0 0 0 r
2.5 Mabswid
.43184 .2375 Mdot
.039 .916 .04 r
.5 Mabswid
.29695 .2415 m
.43184 .2381 L
s
0 0 0 r
2.5 Mabswid
.43184 .2381 Mdot
.039 .916 .04 r
.5 Mabswid
.297 .24218 m
.43183 .2387 L
s
0 0 0 r
2.5 Mabswid
.43183 .2387 Mdot
.039 .916 .04 r
.5 Mabswid
.29705 .24286 m
.43182 .23929 L
s
0 0 0 r
2.5 Mabswid
.43182 .23929 Mdot
.039 .916 .04 r
.5 Mabswid
.29711 .24354 m
.43182 .23989 L
s
0 0 0 r
2.5 Mabswid
.43182 .23989 Mdot
.039 .916 .04 r
.5 Mabswid
.29716 .24422 m
.43181 .24049 L
s
0 0 0 r
2.5 Mabswid
.43181 .24049 Mdot
.039 .916 .04 r
.5 Mabswid
.29722 .2449 m
.4318 .24108 L
s
0 0 0 r
2.5 Mabswid
.4318 .24108 Mdot
.039 .916 .04 r
.5 Mabswid
.29728 .24558 m
.43179 .24168 L
s
0 0 0 r
2.5 Mabswid
.43179 .24168 Mdot
.039 .916 .04 r
.5 Mabswid
.29734 .24626 m
.43179 .24228 L
s
0 0 0 r
2.5 Mabswid
.43179 .24228 Mdot
.039 .916 .04 r
.5 Mabswid
.2974 .24694 m
.43178 .24287 L
s
0 0 0 r
2.5 Mabswid
.43178 .24287 Mdot
.039 .916 .04 r
.5 Mabswid
.29746 .24762 m
.43177 .24347 L
s
0 0 0 r
2.5 Mabswid
.43177 .24347 Mdot
.039 .916 .04 r
.5 Mabswid
.29752 .2483 m
.43176 .24407 L
s
0 0 0 r
2.5 Mabswid
.43176 .24407 Mdot
.039 .916 .04 r
.5 Mabswid
.29759 .24898 m
.43175 .24467 L
s
0 0 0 r
2.5 Mabswid
.43175 .24467 Mdot
.039 .916 .04 r
.5 Mabswid
.29766 .24966 m
.43174 .24526 L
s
0 0 0 r
2.5 Mabswid
.43174 .24526 Mdot
.039 .916 .04 r
.5 Mabswid
.29772 .25034 m
.43174 .24586 L
s
0 0 0 r
2.5 Mabswid
.43174 .24586 Mdot
.039 .916 .04 r
.5 Mabswid
.29779 .25102 m
.43173 .24646 L
s
0 0 0 r
2.5 Mabswid
.43173 .24646 Mdot
.039 .916 .04 r
.5 Mabswid
.29786 .2517 m
.43172 .24706 L
s
0 0 0 r
2.5 Mabswid
.43172 .24706 Mdot
.039 .916 .04 r
.5 Mabswid
.29793 .25238 m
.43171 .24765 L
s
0 0 0 r
2.5 Mabswid
.43171 .24765 Mdot
.039 .916 .04 r
.5 Mabswid
.29801 .25306 m
.4317 .24825 L
s
0 0 0 r
2.5 Mabswid
.4317 .24825 Mdot
.039 .916 .04 r
.5 Mabswid
.29808 .25374 m
.43169 .24885 L
s
0 0 0 r
2.5 Mabswid
.43169 .24885 Mdot
.039 .916 .04 r
.5 Mabswid
.29816 .25442 m
.43168 .24945 L
s
0 0 0 r
2.5 Mabswid
.43168 .24945 Mdot
.039 .916 .04 r
.5 Mabswid
.29823 .2551 m
.43167 .25005 L
s
0 0 0 r
2.5 Mabswid
.43167 .25005 Mdot
.039 .916 .04 r
.5 Mabswid
.29831 .25578 m
.43166 .25065 L
s
0 0 0 r
2.5 Mabswid
.43166 .25065 Mdot
.039 .916 .04 r
.5 Mabswid
.29839 .25646 m
.43165 .25125 L
s
0 0 0 r
2.5 Mabswid
.43165 .25125 Mdot
.039 .916 .04 r
.5 Mabswid
.29847 .25714 m
.43164 .25184 L
s
0 0 0 r
2.5 Mabswid
.43164 .25184 Mdot
.039 .916 .04 r
.5 Mabswid
.29855 .25782 m
.43163 .25244 L
s
0 0 0 r
2.5 Mabswid
.43163 .25244 Mdot
.039 .916 .04 r
.5 Mabswid
.29864 .2585 m
.43161 .25304 L
s
0 0 0 r
2.5 Mabswid
.43161 .25304 Mdot
.039 .916 .04 r
.5 Mabswid
.29872 .25918 m
.4316 .25364 L
s
0 0 0 r
2.5 Mabswid
.4316 .25364 Mdot
.039 .916 .04 r
.5 Mabswid
.29881 .25986 m
.43159 .25424 L
s
0 0 0 r
2.5 Mabswid
.43159 .25424 Mdot
.039 .916 .04 r
.5 Mabswid
.29889 .26054 m
.43158 .25484 L
s
0 0 0 r
2.5 Mabswid
.43158 .25484 Mdot
.039 .916 .04 r
.5 Mabswid
.29898 .26122 m
.43157 .25544 L
s
0 0 0 r
2.5 Mabswid
.43157 .25544 Mdot
.039 .916 .04 r
.5 Mabswid
.29907 .2619 m
.43156 .25604 L
s
0 0 0 r
2.5 Mabswid
.43156 .25604 Mdot
.039 .916 .04 r
.5 Mabswid
.29916 .26259 m
.43155 .25664 L
s
0 0 0 r
2.5 Mabswid
.43155 .25664 Mdot
.039 .916 .04 r
.5 Mabswid
.29926 .26327 m
.43153 .25724 L
s
0 0 0 r
2.5 Mabswid
.43153 .25724 Mdot
.039 .916 .04 r
.5 Mabswid
.29935 .26395 m
.43152 .25784 L
s
0 0 0 r
2.5 Mabswid
.43152 .25784 Mdot
.039 .916 .04 r
.5 Mabswid
.29945 .26463 m
.43151 .25844 L
s
0 0 0 r
2.5 Mabswid
.43151 .25844 Mdot
.039 .916 .04 r
.5 Mabswid
.29954 .26531 m
.4315 .25904 L
s
0 0 0 r
2.5 Mabswid
.4315 .25904 Mdot
.039 .916 .04 r
.5 Mabswid
.29964 .26599 m
.43148 .25964 L
s
0 0 0 r
2.5 Mabswid
.43148 .25964 Mdot
.039 .916 .04 r
.5 Mabswid
.29974 .26667 m
.43147 .26024 L
s
0 0 0 r
2.5 Mabswid
.43147 .26024 Mdot
.039 .916 .04 r
.5 Mabswid
.29984 .26735 m
.43146 .26084 L
s
0 0 0 r
2.5 Mabswid
.43146 .26084 Mdot
.039 .916 .04 r
.5 Mabswid
.29994 .26803 m
.43144 .26144 L
s
0 0 0 r
2.5 Mabswid
.43144 .26144 Mdot
.039 .916 .04 r
.5 Mabswid
.30004 .26871 m
.43143 .26205 L
s
0 0 0 r
2.5 Mabswid
.43143 .26205 Mdot
.039 .916 .04 r
.5 Mabswid
.30015 .26939 m
.43142 .26265 L
s
0 0 0 r
2.5 Mabswid
.43142 .26265 Mdot
.039 .916 .04 r
.5 Mabswid
.30025 .27007 m
.4314 .26325 L
s
0 0 0 r
2.5 Mabswid
.4314 .26325 Mdot
.039 .916 .04 r
.5 Mabswid
.30036 .27075 m
.43139 .26385 L
s
0 0 0 r
2.5 Mabswid
.43139 .26385 Mdot
.039 .916 .04 r
.5 Mabswid
.30047 .27143 m
.43137 .26445 L
s
0 0 0 r
2.5 Mabswid
.43137 .26445 Mdot
.039 .916 .04 r
.5 Mabswid
.30058 .27211 m
.43136 .26506 L
s
0 0 0 r
2.5 Mabswid
.43136 .26506 Mdot
.039 .916 .04 r
.5 Mabswid
.30069 .27279 m
.43134 .26566 L
s
0 0 0 r
2.5 Mabswid
.43134 .26566 Mdot
.039 .916 .04 r
.5 Mabswid
.3008 .27347 m
.43133 .26626 L
s
0 0 0 r
2.5 Mabswid
.43133 .26626 Mdot
.039 .916 .04 r
.5 Mabswid
.30092 .27415 m
.43131 .26686 L
s
0 0 0 r
2.5 Mabswid
.43131 .26686 Mdot
.039 .916 .04 r
.5 Mabswid
.30103 .27483 m
.4313 .26747 L
s
0 0 0 r
2.5 Mabswid
.4313 .26747 Mdot
.039 .916 .04 r
.5 Mabswid
.30115 .27551 m
.43128 .26807 L
s
0 0 0 r
2.5 Mabswid
.43128 .26807 Mdot
.039 .916 .04 r
.5 Mabswid
.30127 .27619 m
.43127 .26867 L
s
0 0 0 r
2.5 Mabswid
.43127 .26867 Mdot
.039 .916 .04 r
.5 Mabswid
.30138 .27687 m
.43125 .26928 L
s
0 0 0 r
2.5 Mabswid
.43125 .26928 Mdot
.039 .916 .04 r
.5 Mabswid
.30151 .27755 m
.43124 .26988 L
s
0 0 0 r
2.5 Mabswid
.43124 .26988 Mdot
.039 .916 .04 r
.5 Mabswid
.30163 .27823 m
.43122 .27048 L
s
0 0 0 r
2.5 Mabswid
.43122 .27048 Mdot
.039 .916 .04 r
.5 Mabswid
.30175 .27891 m
.4312 .27109 L
s
0 0 0 r
2.5 Mabswid
.4312 .27109 Mdot
.039 .916 .04 r
.5 Mabswid
.30187 .27959 m
.43119 .27169 L
s
0 0 0 r
2.5 Mabswid
.43119 .27169 Mdot
.039 .916 .04 r
.5 Mabswid
.302 .28027 m
.43117 .2723 L
s
0 0 0 r
2.5 Mabswid
.43117 .2723 Mdot
.039 .916 .04 r
.5 Mabswid
.30213 .28095 m
.43115 .2729 L
s
0 0 0 r
2.5 Mabswid
.43115 .2729 Mdot
.039 .916 .04 r
.5 Mabswid
.30226 .28163 m
.43114 .27351 L
s
0 0 0 r
2.5 Mabswid
.43114 .27351 Mdot
.039 .916 .04 r
.5 Mabswid
.30239 .28231 m
.43112 .27411 L
s
0 0 0 r
2.5 Mabswid
.43112 .27411 Mdot
.039 .916 .04 r
.5 Mabswid
.43112 .15446 m
.97619 .21462 L
s
0 0 0 r
2.5 Mabswid
.97619 .21462 Mdot
.039 .916 .04 r
.5 Mabswid
.43114 .15506 m
.97619 .2146 L
s
0 0 0 r
2.5 Mabswid
.97619 .2146 Mdot
.039 .916 .04 r
.5 Mabswid
.43115 .15567 m
.97619 .21458 L
s
0 0 0 r
2.5 Mabswid
.97619 .21458 Mdot
.039 .916 .04 r
.5 Mabswid
.43117 .15627 m
.97619 .21456 L
s
0 0 0 r
2.5 Mabswid
.97619 .21456 Mdot
.039 .916 .04 r
.5 Mabswid
.43119 .15688 m
.97619 .21454 L
s
0 0 0 r
2.5 Mabswid
.97619 .21454 Mdot
.039 .916 .04 r
.5 Mabswid
.4312 .15748 m
.97619 .21452 L
s
0 0 0 r
2.5 Mabswid
.97619 .21452 Mdot
.039 .916 .04 r
.5 Mabswid
.43122 .15809 m
.97619 .21451 L
s
0 0 0 r
2.5 Mabswid
.97619 .21451 Mdot
.039 .916 .04 r
.5 Mabswid
.43124 .15869 m
.97619 .21449 L
s
0 0 0 r
2.5 Mabswid
.97619 .21449 Mdot
.039 .916 .04 r
.5 Mabswid
.43125 .15929 m
.97619 .21447 L
s
0 0 0 r
2.5 Mabswid
.97619 .21447 Mdot
.039 .916 .04 r
.5 Mabswid
.43127 .1599 m
.97619 .21446 L
s
0 0 0 r
2.5 Mabswid
.97619 .21446 Mdot
.039 .916 .04 r
.5 Mabswid
.43128 .1605 m
.97619 .21444 L
s
0 0 0 r
2.5 Mabswid
.97619 .21444 Mdot
.039 .916 .04 r
.5 Mabswid
.4313 .1611 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43131 .16171 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43133 .16231 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43134 .16291 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43136 .16352 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43137 .16412 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43139 .16472 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.4314 .16532 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43142 .16592 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43143 .16653 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43144 .16713 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43146 .16773 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43147 .16833 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43148 .16893 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.4315 .16953 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43151 .17013 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43152 .17073 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43153 .17133 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .17193 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43156 .17253 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43157 .17313 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43158 .17373 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .17433 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.4316 .17493 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .17553 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .17613 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43164 .17673 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .17733 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .17792 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .17852 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .17912 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .17972 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .18032 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .18092 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .18151 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .18211 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .18271 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .18331 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .18391 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .1845 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .1851 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .1857 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .18629 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .18689 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .18749 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .18809 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .18868 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .18928 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .18988 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .19047 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .19107 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .19166 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .19226 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .19286 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .19345 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .19405 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .19464 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19524 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19584 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19643 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19703 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .19762 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .19822 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19881 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19941 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .20001 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .2006 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .2012 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20179 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20239 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20298 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20358 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20417 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20477 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20536 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20596 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20655 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20715 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20774 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20834 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20893 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20953 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21012 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21072 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21131 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21191 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .2125 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .2131 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21369 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21429 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21488 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21548 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21607 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21666 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21726 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21785 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21845 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21904 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21964 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22023 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22083 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22142 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22202 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22261 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22321 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .2238 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .2244 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22499 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22559 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22618 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22678 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22738 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22797 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22857 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22916 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22976 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23035 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23095 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23154 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23214 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23273 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23333 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .23393 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .23452 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .23512 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .23571 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .23631 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .23691 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .2375 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .2381 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .2387 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .23929 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .23989 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .24049 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .24108 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .24168 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .24228 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .24287 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .24347 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .24407 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .24467 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .24526 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .24586 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .24646 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .24706 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .24765 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .24825 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .24885 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .24945 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .25005 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .25065 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .25125 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43164 .25184 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .25244 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .25304 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.4316 .25364 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .25424 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43158 .25484 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43157 .25544 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43156 .25604 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .25664 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43153 .25724 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43152 .25784 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43151 .25844 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.4315 .25904 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43148 .25964 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43147 .26024 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43146 .26084 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43144 .26144 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43143 .26205 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43142 .26265 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.4314 .26325 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43139 .26385 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43137 .26445 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43136 .26506 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43134 .26566 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43133 .26626 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43131 .26686 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4313 .26747 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43128 .26807 m
.97619 .21413 L
s
0 0 0 r
2.5 Mabswid
.97619 .21413 Mdot
.039 .916 .04 r
.5 Mabswid
.43127 .26867 m
.97619 .21412 L
s
0 0 0 r
2.5 Mabswid
.97619 .21412 Mdot
.039 .916 .04 r
.5 Mabswid
.43125 .26928 m
.97619 .2141 L
s
0 0 0 r
2.5 Mabswid
.97619 .2141 Mdot
.039 .916 .04 r
.5 Mabswid
.43124 .26988 m
.97619 .21408 L
s
0 0 0 r
2.5 Mabswid
.97619 .21408 Mdot
.039 .916 .04 r
.5 Mabswid
.43122 .27048 m
.97619 .21407 L
s
0 0 0 r
2.5 Mabswid
.97619 .21407 Mdot
.039 .916 .04 r
.5 Mabswid
.4312 .27109 m
.97619 .21405 L
s
0 0 0 r
2.5 Mabswid
.97619 .21405 Mdot
.039 .916 .04 r
.5 Mabswid
.43119 .27169 m
.97619 .21403 L
s
0 0 0 r
2.5 Mabswid
.97619 .21403 Mdot
.039 .916 .04 r
.5 Mabswid
.43117 .2723 m
.97619 .21401 L
s
0 0 0 r
2.5 Mabswid
.97619 .21401 Mdot
.039 .916 .04 r
.5 Mabswid
.43115 .2729 m
.97619 .21399 L
s
0 0 0 r
2.5 Mabswid
.97619 .21399 Mdot
.039 .916 .04 r
.5 Mabswid
.43114 .27351 m
.97619 .21397 L
s
0 0 0 r
2.5 Mabswid
.97619 .21397 Mdot
.039 .916 .04 r
.5 Mabswid
.43112 .27411 m
.97619 .21395 L
s
0 0 0 r
2.5 Mabswid
.97619 .21395 Mdot
0 0 m
1 0 L
1 .42857 L
0 .42857 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[65]:=",
  ImageSize->{288, 123.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Nb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00IooooolCo`0009gooooo00?o0000ooooooooool0
1_ooool006Oooooo00?o0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`2Kooooo`03o`000?oo
oooooooo00Kooooo001VoooooaCo0000WOooool00ol0003oooooooooo`06ooooo`00I_ooool2o`00
017oOgmo00?o0000ooooooooool0Voooool00ol0003oooooooooo`06ooooo`00IOooool00ol0003o
Ogmoo`00000AogmoO`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool006Cooooo
00Co0000ogmoOomoOgoo00004OmoOgl00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Ko
oooo001Tooooo`04o`000?moOgooOgmoo`00017oOgmo00?o0000ooooooooool0Voooool00ol0003o
ooooooooo`06ooooo`00Hoooool01Ol0003oOgmoogmoOomoOgoo0000017oOgmo00?o0000oooooooo
ool0Voooool00ol0003oooooooooo`06ooooo`00Hoooool01?l0003oOgmoogmoOomoOglCo`0009go
oooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmo
ogmoO`0?ogmoO`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool0067ooooo00?o
0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003ooooooooo
o`06ooooo`00HOooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002L
ooooo`03o`000?oooooooooo00Kooooo001Pooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmo
OomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool0063ooooo00?o0000ogmoOomo
Ogl01?moOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00
Goooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`00
0?oooooooooo00Kooooo001Oooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl03omo
Ogl2o`0009cooooo00?o0000ooooooooool01_ooool005kooooo00?o0000ogmoOomoOgl01_moOgl0
0ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00GOooool00ol0
003oOgmoogmoO`07ogmoOaCo0000W?ooool00ol0003oooooooooo`06ooooo`00GOooool00ol0003o
OgmoogmoO`07ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Ko
oooo001Looooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo
00?o0000ooooooooool01_ooool005cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmo
O`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00G?ooool00ol0003oOgmoogmoO`08
ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Koooo
o`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000oooo
ooooool01_ooool005_ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0?ogmoO`;o
0000W?ooool00ol0003oooooooooo`06ooooo`00Foooool00ol0003oOgmoogmoO`09ogmoO`03o`00
0?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Kooooo`03o`000?mo
OgooOgmo00WoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_oo
ool005[ooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool0
0ol0003oooooooooo`06ooooo`00F_ooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo
00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Jooooo`03o`000?moOgooOgmo00[o
Ogmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool005[ooooo
00?o0000ogmoOomoOgl02_moOglDo`0009cooooo00?o0000ooooooooool01_ooool005Wooooo00?o
0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o
0000ooooooooool01_ooool005Wooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0?
ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool005Wooooo00?o0000ogmo
OomoOgl02omoOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000oooo
ooooool01_ooool005Wooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0?ogmoO`03
o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool005Sooooo00?o0000ogmoOomoOgl0
3?moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool0
1_ooool005Sooooo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?mo
Ogoo000009_ooooo00?o0000ooooooooool01_ooool005Sooooo00?o0000ogmoOomoOgl03?moOgl0
0ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool0
05Sooooo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo0000
09_ooooo00?o0000ooooooooool01_ooool005Oooooo00?o0000ogmoOomoOgl03OmoOgl00ol0003o
OgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool000Oooooo
F_l9jPX6ogmoO`03o`000?moOgooOgmo00ooOgmo00?o0000ogmoOol00000Voooool00ol0003ooooo
ooooo`06ooooo`001ooooom/o`WZ2PKoOgmo00?o0000ogmoOol00000Voooool00ol0003ooooooooo
o`06ooooo`001ooooom>o`WZ2P03o`000?l9jP[o2NX:02Wo2NX:U_ooool00ol0003oooooooooo`06
ooooo`001ooooom>o`WZ2P03o`000?l9jP[o2NX:03;o2NX:SOooool00ol0003oooooooooo`06oooo
o`001ooooom>o`WZ2P03o`000?l9jP[o2NX:03_o2NX:Q?ooool00ol0003oooooooooo`06ooooo`00
1ooooom>o`WZ2P03o`000?l9jP[o2NX:04Co2NX:Noooool00ol0003oooooooooo`06ooooo`001ooo
oom>o`WZ2P03o`000?l9jP[o2NX:04go2NX:L_ooool00ol0003oooooooooo`06ooooo`001ooooonW
o`WZ2VWooooo00?o0000ooooooooool01_ooool000Oooooo/Ol9jPYOooooo`03o`000?oooooooooo
00Kooooo0007ooooodgo2NX:00?o0000o`WZ2_l9jPX0J_l9jPYFooooo`03o`000?oooooooooo00Ko
oooo0007ooooodgo2NX:00?o0000o`WZ2_l9jPX0Lol9jPY=ooooo`03o`000?oooooooooo00Kooooo
0007ooooodgo2NX:00?o0000o`WZ2_l9jPX09?l9jPX00ol0003o2NX:o`WZ2P1Eo`WZ2TCooooo00?o
0000ooooooooool01_ooool000OoooooCOl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o
2NX:05ko2NX:>oooool00ol0003oooooooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:
02Co2NX:00?o0000o`WZ2_l9jPX0J?l9jPXaooooo`03o`000?oooooooooo00Kooooo0007ooooodgo
2NX:00?o0000o`WZ2_l9jPX09?l9jPX00ol0003o2NX:o`WZ2P1ao`WZ2RSooooo00?o0000oooooooo
ool01_ooool000OoooooCOl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:07[o2NX:
7oooool00ol0003oooooooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o
0000o`WZ2_l9jPX0Pol9jPXFooooo`03o`000?oooooooooo00Kooooo0007ooooodgo2NX:00?o0000
o`WZ2_l9jPX09?l9jPX00ol0003o2NX:o`WZ2P2<o`WZ2Pgooooo00?o0000ooooooooool01_ooool0
00OoooooCOl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:09Go2NX:1?ooool00ol0
003oooooooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o0000o`WZ2_l9
jPX0V?l9jPX2o`0000Sooooo0007ooooodgo2NX:00?o0000o`WZ2_l9jPX09?l9jPX00ol0003o2NX:
o`WZ2P2Do`WZ2PCooooo0_l00008ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o
0000o`WZ2_l9jPX0Rol9jPX>ooooo`03o`000?oooooooooo00Kooooo0007ooooodgo2NX:00?o0000
o`WZ2_l9jPX09?l9jPX00ol0003o2NX:o`WZ2P22o`WZ2QOooooo00?o0000ooooooooool01_ooool0
00OoooooCOl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:07Wo2NX:8?ooool00ol0
003oooooooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o0000o`WZ2_l9
jPX0L?l9jPXYooooo`03o`000?oooooooooo00Kooooo0007ooooodgo2NX:00?o0000o`WZ2_l9jPX0
9?l9jPX00ol0003o2NX:o`WZ2P1Wo`WZ2S;ooooo00?o0000ooooooooool01_ooool000OoooooCOl9
jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:05go2NX:??ooool00ol0003ooooooooo
o`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o0000o`WZ2_l9jPX0E?l9jPY5
ooooo`03o`000?oooooooooo00Kooooo0007ooooodgo2NX:00?o0000o`WZ2_l9jPX09?l9jPX00ol0
003o2NX:o`WZ2P1;o`WZ2Tkooooo00?o0000ooooooooool01_ooool000OoooooCOl9jPX00ol0003o
2NX:o`WZ2P1Yo`WZ2UOooooo00?o0000ooooooooool01_ooool000Oooooo/?l9jPYPooooo`03o`00
0?oooooooooo00Kooooo0007ooooojKo2NX:J_ooool00ol0003oooooooooo`06ooooo`001ooooonM
o`WZ2W?ooooo00?o0000ooooooooool01_ooool000OoooooC_l9jPX00ol0003o2NX:o`WZ2P13o`WZ
2Wcooooo00?o0000ooooooooool01_ooool000OoooooC_l9jPX00ol0003o2NX:o`WZ2P0jo`WZ2XGo
oooo00?o0000ooooooooool01_ooool000OoooooC_l9jPX00ol0003o2NX:o`WZ2P0ao`WZ2Xkooooo
00?o0000ooooooooool01_ooool000OoooooC_l9jPX00ol0003o2NX:o`WZ2P0Xo`WZ2YOooooo00?o
0000ooooooooool01_ooool000OoooooK_l9jPX4ogmoO`04o`000?moOgoo0000o`0009[ooooo00?o
0000ooooooooool01_ooool000OoooooH_l9jPX@ogmoO`03o`000?moOgoo000009_ooooo00?o0000
ooooooooool01_ooool000OoooooCol9jPX00ol0003o2NX:o`WZ2P04o`WZ2P[oOgmo00?o0000ogmo
OomoOgl03omoOgl00ol0003oOgmoo`00002Kooooo`03o`000?oooooooooo00Kooooo001Gooooo`03
o`000?moOgooOgmo00goOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoo`00002Kooooo`03
o`000?oooooooooo00Kooooo001Gooooo`03o`000?moOgooOgmo00goOgmo00?o0000ogmoOomoOgl0
3omoOgl00ol0003oOgmoo`00002Kooooo`03o`000?oooooooooo00Kooooo001Hooooo`03o`000?mo
OgooOgmo00coOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoo`00002Kooooo`03o`000?oo
oooooooo00Kooooo001Hooooo`03o`000?moOgooOgmo00coOgmo00?o0000ogmoOomoOgl03omoOgl0
0ol0003oOgmoo`00002Kooooo`03o`000?oooooooooo00Kooooo001Hooooo`03o`000?moOgooOgmo
00coOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoo`00002Kooooo`03o`000?oooooooooo
00Kooooo001Hooooo`03o`000?moOgooOgmo00coOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003o
Ogmoo`00002Kooooo`03o`000?oooooooooo00Kooooo001Iooooo`03o`000?moOgooOgmo00_oOgmo
00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoo`00002Kooooo`03o`000?oooooooooo00Kooooo
001Iooooo`03o`000?moOgooOgmo00_oOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoo`00
002Kooooo`03o`000?oooooooooo00Kooooo001Iooooo`03o`000?moOgooOgmo00_oOgmo4ol00000
0omoOgoo0000ooooo`2Jooooo`03o`000?oooooooooo00Kooooo001Jooooo`03o`000?moOgooOgmo
00[oOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool005[o
oooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003o
ooooooooo`06ooooo`00F_ooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00ooOgmo
0_l0002Looooo`03o`000?oooooooooo00Kooooo001Jooooo`03o`000?moOgooOgmo00[oOgmo00?o
0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool005_ooooo00?o0000
ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06
ooooo`00Foooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Loooo
o`03o`000?oooooooooo00Kooooo001Kooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomo
Ogl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool005_ooooo00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00G?oo
ool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oo
oooooooo00Kooooo001Looooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl03omoOgl2
o`0009cooooo00?o0000ooooooooool01_ooool005cooooo00?o0000ogmoOomoOgl02?moOgl00ol0
003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00GOooool00ol0003o
OgmoogmoO`07ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Ko
oooo001Mooooo`03o`000?moOgooOgmo00OoOgmo5?l0002Looooo`03o`000?oooooooooo00Kooooo
001Nooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o
0000ooooooooool01_ooool005kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0?
ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00Goooool00ol0003oOgmoogmoO`05ogmo
O`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Pooooo`03
o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000oooooooo
ool01_ooool0063ooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000
W?ooool00ol0003oooooooooo`06ooooo`00HOooool00ol0003oOgmoogmoO`03ogmoO`03o`000?mo
OgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Qooooo`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool0
06;ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?oooooooooo
09_ooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ogmoOomoOgl00_moOglCo`0009go
oooo00?o0000ooooooooool01_ooool006?ooooo00Go0000ogmoOomoOgooOgmoo`00000AogmoO`03
o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool006?ooooo00Go0000ogmoOomoOgoo
Ogmoo`00000AogmoO`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool006Cooooo
00Co0000ogmoOomoOgoo00004OmoOgl00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Ko
oooo001Uooooo`03o`000?moOgoo0000017oOgmo00?o0000ooooooooool0Voooool00ol0003ooooo
ooooo`06ooooo`00IOooool00ol0003oOgmoo`00000AogmoO`03o`000?oooooooooo09_ooooo00?o
0000ooooooooool01_ooool006Kooooo5?l0002Mooooo`03o`000?oooooooooo00Kooooo001Voooo
o`;o00004OmoOgl00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Kooooo001Woooooa?o
0000WOooool00ol0003oooooooooo`06ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {122.375, 0}} -> {-21.938, -15.7502, 0.257408, \
0.257408}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],

Cell[BoxData[
    \({FocalPoint \[Rule] {49.99734409637844`, 0, 0}, 
      FocusType \[Rule] RMSFocus, 
      WeightedSpotSize \[Rule] 0.0093276240996801`, 
      SpotSize \[Rule] 0.009327624099680099`, 
      BackFocalLength \[Rule] 40.01835317933643`, 
      FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
      TurboRays \[Rule] TurboRays}\)], "Output",
  CellLabel->"Out[65]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell["\<\
When we trace the system with 101 rays, this time, the calculated focal point \
is much better than the third order model. However the result still does not \
completely match the focal surface position of the system model. However, \
when we increase the number of traced rays to 1001, the resulting focal \
position matches the final surface position precisely.\
\>", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{

Cell["\<\
FindFocusFast[TurboPlot[
\tMove[LineOfRays[10,NumberOfRays->1001,IntrinsicMedium->1],{-20,0}],
\tplot,SymbolicValues->localminimum[[2]], PlotType->TopView]]\
\>", "Input",
  CellLabel->"In[66]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42857 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.295918 0.0136054 0.214286 0.0136054 [
[ 0 0 0 0 ]
[ 1 .42857 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.35914 .0102 m
.42203 .0102 L
.42756 .07823 L
.32254 .07823 L
.35914 .0102 L
F
.32254 .07823 m
.42756 .07823 L
.43087 .14626 L
.30239 .14626 L
.32254 .07823 L
F
.30239 .14626 m
.43087 .14626 L
.43197 .21429 L
.29592 .21429 L
.30239 .14626 L
F
.29592 .21429 m
.43197 .21429 L
.43087 .28231 L
.30239 .28231 L
.29592 .21429 L
F
.30239 .28231 m
.43087 .28231 L
.42756 .35034 L
.32254 .35034 L
.30239 .28231 L
F
.32254 .35034 m
.42756 .35034 L
.42203 .41837 L
.35914 .41837 L
.32254 .35034 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.35914 .0102 m
.32254 .07823 L
.30239 .14626 L
.29592 .21429 L
.30239 .28231 L
.32254 .35034 L
.35914 .41837 L
.42203 .41837 L
.42756 .35034 L
.43087 .28231 L
.43197 .21429 L
.43087 .14626 L
.42756 .07823 L
.42203 .0102 L
.35914 .0102 L
s
.5 g
.35914 .21429 m
.42203 .21429 L
.42756 .21429 L
.32254 .21429 L
.35914 .21429 L
F
.32254 .21429 m
.42756 .21429 L
.43087 .21429 L
.30239 .21429 L
.32254 .21429 L
F
.30239 .21429 m
.43087 .21429 L
.43197 .21429 L
.29592 .21429 L
.30239 .21429 L
F
.29592 .21429 m
.43197 .21429 L
.43087 .21429 L
.30239 .21429 L
.29592 .21429 L
F
.30239 .21429 m
.43087 .21429 L
.42756 .21429 L
.32254 .21429 L
.30239 .21429 L
F
.32254 .21429 m
.42756 .21429 L
.42203 .21429 L
.35914 .21429 L
.32254 .21429 L
F
0 g
.35914 .21429 m
.32254 .21429 L
.30239 .21429 L
.29592 .21429 L
.30239 .21429 L
.32254 .21429 L
.35914 .21429 L
.42203 .21429 L
.42756 .21429 L
.43087 .21429 L
.43197 .21429 L
.43087 .21429 L
.42756 .21429 L
.42203 .21429 L
.35914 .21429 L
s
.35914 .41837 m
.42203 .41837 L
.42203 .41141 L
.35914 .41141 L
.35914 .41837 L
s
.35914 .41141 m
.42203 .41141 L
.42203 .39103 L
.35914 .39103 L
.35914 .41141 L
s
.35914 .39103 m
.42203 .39103 L
.42203 .35859 L
.35914 .35859 L
.35914 .39103 L
s
.35914 .35859 m
.42203 .35859 L
.42203 .31633 L
.35914 .31633 L
.35914 .35859 L
s
.35914 .31633 m
.42203 .31633 L
.42203 .26711 L
.35914 .26711 L
.35914 .31633 L
s
.35914 .26711 m
.42203 .26711 L
.42203 .21429 L
.35914 .21429 L
.35914 .26711 L
s
.35914 .21429 m
.42203 .21429 L
.42203 .16147 L
.35914 .16147 L
.35914 .21429 L
s
.35914 .16147 m
.42203 .16147 L
.42203 .11224 L
.35914 .11224 L
.35914 .16147 L
s
.35914 .11224 m
.42203 .11224 L
.42203 .06998 L
.35914 .06998 L
.35914 .11224 L
s
.35914 .06998 m
.42203 .06998 L
.42203 .03755 L
.35914 .03755 L
.35914 .06998 L
s
.35914 .03755 m
.42203 .03755 L
.42203 .01716 L
.35914 .01716 L
.35914 .03755 L
s
.35914 .01716 m
.42203 .01716 L
.42203 .0102 L
.35914 .0102 L
.35914 .01716 L
s
.35914 .0102 m
.42203 .0102 L
.42203 .01716 L
.35914 .01716 L
.35914 .0102 L
s
.35914 .01716 m
.42203 .01716 L
.42203 .03755 L
.35914 .03755 L
.35914 .01716 L
s
.35914 .03755 m
.42203 .03755 L
.42203 .06998 L
.35914 .06998 L
.35914 .03755 L
s
.35914 .06998 m
.42203 .06998 L
.42203 .11224 L
.35914 .11224 L
.35914 .06998 L
s
.35914 .11224 m
.42203 .11224 L
.42203 .16147 L
.35914 .16147 L
.35914 .11224 L
s
.35914 .16147 m
.42203 .16147 L
.42203 .21429 L
.35914 .21429 L
.35914 .16147 L
s
.35914 .21429 m
.42203 .21429 L
.42203 .26711 L
.35914 .26711 L
.35914 .21429 L
s
.35914 .26711 m
.42203 .26711 L
.42203 .31633 L
.35914 .31633 L
.35914 .26711 L
s
.35914 .31633 m
.42203 .31633 L
.42203 .35859 L
.35914 .35859 L
.35914 .31633 L
s
.35914 .35859 m
.42203 .35859 L
.42203 .39103 L
.35914 .39103 L
.35914 .35859 L
s
.35914 .39103 m
.42203 .39103 L
.42203 .41141 L
.35914 .41141 L
.35914 .39103 L
s
.35914 .41141 m
.42203 .41141 L
.42203 .41837 L
.35914 .41837 L
.35914 .41141 L
s
.97619 .0102 m
.97619 .07823 L
.97619 .14626 L
.97619 .21429 L
.97619 .28231 L
.97619 .35034 L
.97619 .41837 L
.97619 .41837 L
.97619 .35034 L
.97619 .28231 L
.97619 .21429 L
.97619 .14626 L
.97619 .07823 L
.97619 .0102 L
.97619 .0102 L
s
.97619 .21429 m
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
.97619 .21429 L
s
.97619 .41837 m
.97619 .41141 L
.97619 .39103 L
.97619 .35859 L
.97619 .31633 L
.97619 .26711 L
.97619 .21429 L
.97619 .16147 L
.97619 .11224 L
.97619 .06998 L
.97619 .03755 L
.97619 .01716 L
.97619 .0102 L
.97619 .01716 L
.97619 .03755 L
.97619 .06998 L
.97619 .11224 L
.97619 .16147 L
.97619 .21429 L
.97619 .26711 L
.97619 .31633 L
.97619 .35859 L
.97619 .39103 L
.97619 .41141 L
.97619 .41837 L
s
.039 .916 .04 r
.02381 .14626 m
.30239 .14626 L
s
0 0 0 r
2.5 Mabswid
.30239 .14626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14639 m
.30236 .14639 L
s
0 0 0 r
2.5 Mabswid
.30236 .14639 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14653 m
.30233 .14653 L
s
0 0 0 r
2.5 Mabswid
.30233 .14653 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14667 m
.30231 .14667 L
s
0 0 0 r
2.5 Mabswid
.30231 .14667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1468 m
.30228 .1468 L
s
0 0 0 r
2.5 Mabswid
.30228 .1468 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14694 m
.30226 .14694 L
s
0 0 0 r
2.5 Mabswid
.30226 .14694 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14707 m
.30223 .14707 L
s
0 0 0 r
2.5 Mabswid
.30223 .14707 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14721 m
.3022 .14721 L
s
0 0 0 r
2.5 Mabswid
.3022 .14721 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14735 m
.30218 .14735 L
s
0 0 0 r
2.5 Mabswid
.30218 .14735 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14748 m
.30215 .14748 L
s
0 0 0 r
2.5 Mabswid
.30215 .14748 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14762 m
.30213 .14762 L
s
0 0 0 r
2.5 Mabswid
.30213 .14762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14776 m
.3021 .14776 L
s
0 0 0 r
2.5 Mabswid
.3021 .14776 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14789 m
.30208 .14789 L
s
0 0 0 r
2.5 Mabswid
.30208 .14789 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14803 m
.30205 .14803 L
s
0 0 0 r
2.5 Mabswid
.30205 .14803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14816 m
.30203 .14816 L
s
0 0 0 r
2.5 Mabswid
.30203 .14816 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1483 m
.302 .1483 L
s
0 0 0 r
2.5 Mabswid
.302 .1483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14844 m
.30198 .14844 L
s
0 0 0 r
2.5 Mabswid
.30198 .14844 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14857 m
.30195 .14857 L
s
0 0 0 r
2.5 Mabswid
.30195 .14857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14871 m
.30192 .14871 L
s
0 0 0 r
2.5 Mabswid
.30192 .14871 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14884 m
.3019 .14884 L
s
0 0 0 r
2.5 Mabswid
.3019 .14884 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14898 m
.30187 .14898 L
s
0 0 0 r
2.5 Mabswid
.30187 .14898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14912 m
.30185 .14912 L
s
0 0 0 r
2.5 Mabswid
.30185 .14912 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14925 m
.30182 .14925 L
s
0 0 0 r
2.5 Mabswid
.30182 .14925 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14939 m
.3018 .14939 L
s
0 0 0 r
2.5 Mabswid
.3018 .14939 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14952 m
.30177 .14952 L
s
0 0 0 r
2.5 Mabswid
.30177 .14952 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14966 m
.30175 .14966 L
s
0 0 0 r
2.5 Mabswid
.30175 .14966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1498 m
.30173 .1498 L
s
0 0 0 r
2.5 Mabswid
.30173 .1498 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14993 m
.3017 .14993 L
s
0 0 0 r
2.5 Mabswid
.3017 .14993 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15007 m
.30168 .15007 L
s
0 0 0 r
2.5 Mabswid
.30168 .15007 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1502 m
.30165 .1502 L
s
0 0 0 r
2.5 Mabswid
.30165 .1502 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15034 m
.30163 .15034 L
s
0 0 0 r
2.5 Mabswid
.30163 .15034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15048 m
.3016 .15048 L
s
0 0 0 r
2.5 Mabswid
.3016 .15048 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15061 m
.30158 .15061 L
s
0 0 0 r
2.5 Mabswid
.30158 .15061 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15075 m
.30155 .15075 L
s
0 0 0 r
2.5 Mabswid
.30155 .15075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15088 m
.30153 .15088 L
s
0 0 0 r
2.5 Mabswid
.30153 .15088 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15102 m
.30151 .15102 L
s
0 0 0 r
2.5 Mabswid
.30151 .15102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15116 m
.30148 .15116 L
s
0 0 0 r
2.5 Mabswid
.30148 .15116 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15129 m
.30146 .15129 L
s
0 0 0 r
2.5 Mabswid
.30146 .15129 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15143 m
.30143 .15143 L
s
0 0 0 r
2.5 Mabswid
.30143 .15143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15156 m
.30141 .15156 L
s
0 0 0 r
2.5 Mabswid
.30141 .15156 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1517 m
.30138 .1517 L
s
0 0 0 r
2.5 Mabswid
.30138 .1517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15184 m
.30136 .15184 L
s
0 0 0 r
2.5 Mabswid
.30136 .15184 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15197 m
.30134 .15197 L
s
0 0 0 r
2.5 Mabswid
.30134 .15197 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15211 m
.30131 .15211 L
s
0 0 0 r
2.5 Mabswid
.30131 .15211 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15224 m
.30129 .15224 L
s
0 0 0 r
2.5 Mabswid
.30129 .15224 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15238 m
.30127 .15238 L
s
0 0 0 r
2.5 Mabswid
.30127 .15238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15252 m
.30124 .15252 L
s
0 0 0 r
2.5 Mabswid
.30124 .15252 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15265 m
.30122 .15265 L
s
0 0 0 r
2.5 Mabswid
.30122 .15265 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15279 m
.30119 .15279 L
s
0 0 0 r
2.5 Mabswid
.30119 .15279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15293 m
.30117 .15293 L
s
0 0 0 r
2.5 Mabswid
.30117 .15293 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15306 m
.30115 .15306 L
s
0 0 0 r
2.5 Mabswid
.30115 .15306 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1532 m
.30112 .1532 L
s
0 0 0 r
2.5 Mabswid
.30112 .1532 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15333 m
.3011 .15333 L
s
0 0 0 r
2.5 Mabswid
.3011 .15333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15347 m
.30108 .15347 L
s
0 0 0 r
2.5 Mabswid
.30108 .15347 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15361 m
.30105 .15361 L
s
0 0 0 r
2.5 Mabswid
.30105 .15361 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15374 m
.30103 .15374 L
s
0 0 0 r
2.5 Mabswid
.30103 .15374 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15388 m
.30101 .15388 L
s
0 0 0 r
2.5 Mabswid
.30101 .15388 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15401 m
.30099 .15401 L
s
0 0 0 r
2.5 Mabswid
.30099 .15401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15415 m
.30096 .15415 L
s
0 0 0 r
2.5 Mabswid
.30096 .15415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15429 m
.30094 .15429 L
s
0 0 0 r
2.5 Mabswid
.30094 .15429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15442 m
.30092 .15442 L
s
0 0 0 r
2.5 Mabswid
.30092 .15442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15456 m
.30089 .15456 L
s
0 0 0 r
2.5 Mabswid
.30089 .15456 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15469 m
.30087 .15469 L
s
0 0 0 r
2.5 Mabswid
.30087 .15469 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15483 m
.30085 .15483 L
s
0 0 0 r
2.5 Mabswid
.30085 .15483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15497 m
.30083 .15497 L
s
0 0 0 r
2.5 Mabswid
.30083 .15497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1551 m
.3008 .1551 L
s
0 0 0 r
2.5 Mabswid
.3008 .1551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15524 m
.30078 .15524 L
s
0 0 0 r
2.5 Mabswid
.30078 .15524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15537 m
.30076 .15537 L
s
0 0 0 r
2.5 Mabswid
.30076 .15537 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15551 m
.30074 .15551 L
s
0 0 0 r
2.5 Mabswid
.30074 .15551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15565 m
.30071 .15565 L
s
0 0 0 r
2.5 Mabswid
.30071 .15565 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15578 m
.30069 .15578 L
s
0 0 0 r
2.5 Mabswid
.30069 .15578 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15592 m
.30067 .15592 L
s
0 0 0 r
2.5 Mabswid
.30067 .15592 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15605 m
.30065 .15605 L
s
0 0 0 r
2.5 Mabswid
.30065 .15605 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15619 m
.30062 .15619 L
s
0 0 0 r
2.5 Mabswid
.30062 .15619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15633 m
.3006 .15633 L
s
0 0 0 r
2.5 Mabswid
.3006 .15633 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15646 m
.30058 .15646 L
s
0 0 0 r
2.5 Mabswid
.30058 .15646 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1566 m
.30056 .1566 L
s
0 0 0 r
2.5 Mabswid
.30056 .1566 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15673 m
.30054 .15673 L
s
0 0 0 r
2.5 Mabswid
.30054 .15673 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15687 m
.30051 .15687 L
s
0 0 0 r
2.5 Mabswid
.30051 .15687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15701 m
.30049 .15701 L
s
0 0 0 r
2.5 Mabswid
.30049 .15701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15714 m
.30047 .15714 L
s
0 0 0 r
2.5 Mabswid
.30047 .15714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15728 m
.30045 .15728 L
s
0 0 0 r
2.5 Mabswid
.30045 .15728 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15741 m
.30043 .15741 L
s
0 0 0 r
2.5 Mabswid
.30043 .15741 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15755 m
.3004 .15755 L
s
0 0 0 r
2.5 Mabswid
.3004 .15755 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15769 m
.30038 .15769 L
s
0 0 0 r
2.5 Mabswid
.30038 .15769 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15782 m
.30036 .15782 L
s
0 0 0 r
2.5 Mabswid
.30036 .15782 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15796 m
.30034 .15796 L
s
0 0 0 r
2.5 Mabswid
.30034 .15796 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1581 m
.30032 .1581 L
s
0 0 0 r
2.5 Mabswid
.30032 .1581 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15823 m
.3003 .15823 L
s
0 0 0 r
2.5 Mabswid
.3003 .15823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15837 m
.30028 .15837 L
s
0 0 0 r
2.5 Mabswid
.30028 .15837 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1585 m
.30025 .1585 L
s
0 0 0 r
2.5 Mabswid
.30025 .1585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15864 m
.30023 .15864 L
s
0 0 0 r
2.5 Mabswid
.30023 .15864 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15878 m
.30021 .15878 L
s
0 0 0 r
2.5 Mabswid
.30021 .15878 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15891 m
.30019 .15891 L
s
0 0 0 r
2.5 Mabswid
.30019 .15891 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15905 m
.30017 .15905 L
s
0 0 0 r
2.5 Mabswid
.30017 .15905 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15918 m
.30015 .15918 L
s
0 0 0 r
2.5 Mabswid
.30015 .15918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15932 m
.30013 .15932 L
s
0 0 0 r
2.5 Mabswid
.30013 .15932 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15946 m
.30011 .15946 L
s
0 0 0 r
2.5 Mabswid
.30011 .15946 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15959 m
.30009 .15959 L
s
0 0 0 r
2.5 Mabswid
.30009 .15959 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15973 m
.30006 .15973 L
s
0 0 0 r
2.5 Mabswid
.30006 .15973 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15986 m
.30004 .15986 L
s
0 0 0 r
2.5 Mabswid
.30004 .15986 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16 m
.30002 .16 L
s
0 0 0 r
2.5 Mabswid
.30002 .16 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16014 m
.3 .16014 L
s
0 0 0 r
2.5 Mabswid
.3 .16014 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16027 m
.29998 .16027 L
s
0 0 0 r
2.5 Mabswid
.29998 .16027 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16041 m
.29996 .16041 L
s
0 0 0 r
2.5 Mabswid
.29996 .16041 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16054 m
.29994 .16054 L
s
0 0 0 r
2.5 Mabswid
.29994 .16054 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16068 m
.29992 .16068 L
s
0 0 0 r
2.5 Mabswid
.29992 .16068 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16082 m
.2999 .16082 L
s
0 0 0 r
2.5 Mabswid
.2999 .16082 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16095 m
.29988 .16095 L
s
0 0 0 r
2.5 Mabswid
.29988 .16095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16109 m
.29986 .16109 L
s
0 0 0 r
2.5 Mabswid
.29986 .16109 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16122 m
.29984 .16122 L
s
0 0 0 r
2.5 Mabswid
.29984 .16122 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16136 m
.29982 .16136 L
s
0 0 0 r
2.5 Mabswid
.29982 .16136 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1615 m
.2998 .1615 L
s
0 0 0 r
2.5 Mabswid
.2998 .1615 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16163 m
.29978 .16163 L
s
0 0 0 r
2.5 Mabswid
.29978 .16163 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16177 m
.29976 .16177 L
s
0 0 0 r
2.5 Mabswid
.29976 .16177 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1619 m
.29974 .1619 L
s
0 0 0 r
2.5 Mabswid
.29974 .1619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16204 m
.29972 .16204 L
s
0 0 0 r
2.5 Mabswid
.29972 .16204 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16218 m
.2997 .16218 L
s
0 0 0 r
2.5 Mabswid
.2997 .16218 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16231 m
.29968 .16231 L
s
0 0 0 r
2.5 Mabswid
.29968 .16231 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16245 m
.29966 .16245 L
s
0 0 0 r
2.5 Mabswid
.29966 .16245 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16259 m
.29964 .16259 L
s
0 0 0 r
2.5 Mabswid
.29964 .16259 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16272 m
.29962 .16272 L
s
0 0 0 r
2.5 Mabswid
.29962 .16272 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16286 m
.2996 .16286 L
s
0 0 0 r
2.5 Mabswid
.2996 .16286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16299 m
.29958 .16299 L
s
0 0 0 r
2.5 Mabswid
.29958 .16299 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16313 m
.29956 .16313 L
s
0 0 0 r
2.5 Mabswid
.29956 .16313 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16327 m
.29954 .16327 L
s
0 0 0 r
2.5 Mabswid
.29954 .16327 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1634 m
.29952 .1634 L
s
0 0 0 r
2.5 Mabswid
.29952 .1634 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16354 m
.2995 .16354 L
s
0 0 0 r
2.5 Mabswid
.2995 .16354 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16367 m
.29948 .16367 L
s
0 0 0 r
2.5 Mabswid
.29948 .16367 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16381 m
.29946 .16381 L
s
0 0 0 r
2.5 Mabswid
.29946 .16381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16395 m
.29945 .16395 L
s
0 0 0 r
2.5 Mabswid
.29945 .16395 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16408 m
.29943 .16408 L
s
0 0 0 r
2.5 Mabswid
.29943 .16408 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16422 m
.29941 .16422 L
s
0 0 0 r
2.5 Mabswid
.29941 .16422 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16435 m
.29939 .16435 L
s
0 0 0 r
2.5 Mabswid
.29939 .16435 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16449 m
.29937 .16449 L
s
0 0 0 r
2.5 Mabswid
.29937 .16449 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16463 m
.29935 .16463 L
s
0 0 0 r
2.5 Mabswid
.29935 .16463 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16476 m
.29933 .16476 L
s
0 0 0 r
2.5 Mabswid
.29933 .16476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1649 m
.29931 .1649 L
s
0 0 0 r
2.5 Mabswid
.29931 .1649 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16503 m
.29929 .16503 L
s
0 0 0 r
2.5 Mabswid
.29929 .16503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16517 m
.29928 .16517 L
s
0 0 0 r
2.5 Mabswid
.29928 .16517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16531 m
.29926 .16531 L
s
0 0 0 r
2.5 Mabswid
.29926 .16531 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16544 m
.29924 .16544 L
s
0 0 0 r
2.5 Mabswid
.29924 .16544 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16558 m
.29922 .16558 L
s
0 0 0 r
2.5 Mabswid
.29922 .16558 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16571 m
.2992 .16571 L
s
0 0 0 r
2.5 Mabswid
.2992 .16571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16585 m
.29918 .16585 L
s
0 0 0 r
2.5 Mabswid
.29918 .16585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16599 m
.29916 .16599 L
s
0 0 0 r
2.5 Mabswid
.29916 .16599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16612 m
.29915 .16612 L
s
0 0 0 r
2.5 Mabswid
.29915 .16612 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16626 m
.29913 .16626 L
s
0 0 0 r
2.5 Mabswid
.29913 .16626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16639 m
.29911 .16639 L
s
0 0 0 r
2.5 Mabswid
.29911 .16639 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16653 m
.29909 .16653 L
s
0 0 0 r
2.5 Mabswid
.29909 .16653 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16667 m
.29907 .16667 L
s
0 0 0 r
2.5 Mabswid
.29907 .16667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1668 m
.29905 .1668 L
s
0 0 0 r
2.5 Mabswid
.29905 .1668 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16694 m
.29904 .16694 L
s
0 0 0 r
2.5 Mabswid
.29904 .16694 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16707 m
.29902 .16707 L
s
0 0 0 r
2.5 Mabswid
.29902 .16707 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16721 m
.299 .16721 L
s
0 0 0 r
2.5 Mabswid
.299 .16721 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16735 m
.29898 .16735 L
s
0 0 0 r
2.5 Mabswid
.29898 .16735 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16748 m
.29897 .16748 L
s
0 0 0 r
2.5 Mabswid
.29897 .16748 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16762 m
.29895 .16762 L
s
0 0 0 r
2.5 Mabswid
.29895 .16762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16776 m
.29893 .16776 L
s
0 0 0 r
2.5 Mabswid
.29893 .16776 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16789 m
.29891 .16789 L
s
0 0 0 r
2.5 Mabswid
.29891 .16789 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16803 m
.29889 .16803 L
s
0 0 0 r
2.5 Mabswid
.29889 .16803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16816 m
.29888 .16816 L
s
0 0 0 r
2.5 Mabswid
.29888 .16816 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1683 m
.29886 .1683 L
s
0 0 0 r
2.5 Mabswid
.29886 .1683 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16844 m
.29884 .16844 L
s
0 0 0 r
2.5 Mabswid
.29884 .16844 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16857 m
.29882 .16857 L
s
0 0 0 r
2.5 Mabswid
.29882 .16857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16871 m
.29881 .16871 L
s
0 0 0 r
2.5 Mabswid
.29881 .16871 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16884 m
.29879 .16884 L
s
0 0 0 r
2.5 Mabswid
.29879 .16884 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16898 m
.29877 .16898 L
s
0 0 0 r
2.5 Mabswid
.29877 .16898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16912 m
.29876 .16912 L
s
0 0 0 r
2.5 Mabswid
.29876 .16912 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16925 m
.29874 .16925 L
s
0 0 0 r
2.5 Mabswid
.29874 .16925 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16939 m
.29872 .16939 L
s
0 0 0 r
2.5 Mabswid
.29872 .16939 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16952 m
.2987 .16952 L
s
0 0 0 r
2.5 Mabswid
.2987 .16952 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16966 m
.29869 .16966 L
s
0 0 0 r
2.5 Mabswid
.29869 .16966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1698 m
.29867 .1698 L
s
0 0 0 r
2.5 Mabswid
.29867 .1698 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16993 m
.29865 .16993 L
s
0 0 0 r
2.5 Mabswid
.29865 .16993 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17007 m
.29864 .17007 L
s
0 0 0 r
2.5 Mabswid
.29864 .17007 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1702 m
.29862 .1702 L
s
0 0 0 r
2.5 Mabswid
.29862 .1702 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17034 m
.2986 .17034 L
s
0 0 0 r
2.5 Mabswid
.2986 .17034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17048 m
.29859 .17048 L
s
0 0 0 r
2.5 Mabswid
.29859 .17048 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17061 m
.29857 .17061 L
s
0 0 0 r
2.5 Mabswid
.29857 .17061 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17075 m
.29855 .17075 L
s
0 0 0 r
2.5 Mabswid
.29855 .17075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17088 m
.29854 .17088 L
s
0 0 0 r
2.5 Mabswid
.29854 .17088 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17102 m
.29852 .17102 L
s
0 0 0 r
2.5 Mabswid
.29852 .17102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17116 m
.2985 .17116 L
s
0 0 0 r
2.5 Mabswid
.2985 .17116 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17129 m
.29849 .17129 L
s
0 0 0 r
2.5 Mabswid
.29849 .17129 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17143 m
.29847 .17143 L
s
0 0 0 r
2.5 Mabswid
.29847 .17143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17156 m
.29846 .17156 L
s
0 0 0 r
2.5 Mabswid
.29846 .17156 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1717 m
.29844 .1717 L
s
0 0 0 r
2.5 Mabswid
.29844 .1717 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17184 m
.29842 .17184 L
s
0 0 0 r
2.5 Mabswid
.29842 .17184 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17197 m
.29841 .17197 L
s
0 0 0 r
2.5 Mabswid
.29841 .17197 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17211 m
.29839 .17211 L
s
0 0 0 r
2.5 Mabswid
.29839 .17211 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17224 m
.29837 .17224 L
s
0 0 0 r
2.5 Mabswid
.29837 .17224 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17238 m
.29836 .17238 L
s
0 0 0 r
2.5 Mabswid
.29836 .17238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17252 m
.29834 .17252 L
s
0 0 0 r
2.5 Mabswid
.29834 .17252 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17265 m
.29833 .17265 L
s
0 0 0 r
2.5 Mabswid
.29833 .17265 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17279 m
.29831 .17279 L
s
0 0 0 r
2.5 Mabswid
.29831 .17279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17293 m
.2983 .17293 L
s
0 0 0 r
2.5 Mabswid
.2983 .17293 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17306 m
.29828 .17306 L
s
0 0 0 r
2.5 Mabswid
.29828 .17306 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1732 m
.29826 .1732 L
s
0 0 0 r
2.5 Mabswid
.29826 .1732 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17333 m
.29825 .17333 L
s
0 0 0 r
2.5 Mabswid
.29825 .17333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17347 m
.29823 .17347 L
s
0 0 0 r
2.5 Mabswid
.29823 .17347 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17361 m
.29822 .17361 L
s
0 0 0 r
2.5 Mabswid
.29822 .17361 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17374 m
.2982 .17374 L
s
0 0 0 r
2.5 Mabswid
.2982 .17374 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17388 m
.29819 .17388 L
s
0 0 0 r
2.5 Mabswid
.29819 .17388 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17401 m
.29817 .17401 L
s
0 0 0 r
2.5 Mabswid
.29817 .17401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17415 m
.29816 .17415 L
s
0 0 0 r
2.5 Mabswid
.29816 .17415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17429 m
.29814 .17429 L
s
0 0 0 r
2.5 Mabswid
.29814 .17429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17442 m
.29813 .17442 L
s
0 0 0 r
2.5 Mabswid
.29813 .17442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17456 m
.29811 .17456 L
s
0 0 0 r
2.5 Mabswid
.29811 .17456 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17469 m
.2981 .17469 L
s
0 0 0 r
2.5 Mabswid
.2981 .17469 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17483 m
.29808 .17483 L
s
0 0 0 r
2.5 Mabswid
.29808 .17483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17497 m
.29807 .17497 L
s
0 0 0 r
2.5 Mabswid
.29807 .17497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1751 m
.29805 .1751 L
s
0 0 0 r
2.5 Mabswid
.29805 .1751 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17524 m
.29804 .17524 L
s
0 0 0 r
2.5 Mabswid
.29804 .17524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17537 m
.29802 .17537 L
s
0 0 0 r
2.5 Mabswid
.29802 .17537 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17551 m
.29801 .17551 L
s
0 0 0 r
2.5 Mabswid
.29801 .17551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17565 m
.29799 .17565 L
s
0 0 0 r
2.5 Mabswid
.29799 .17565 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17578 m
.29798 .17578 L
s
0 0 0 r
2.5 Mabswid
.29798 .17578 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17592 m
.29796 .17592 L
s
0 0 0 r
2.5 Mabswid
.29796 .17592 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17605 m
.29795 .17605 L
s
0 0 0 r
2.5 Mabswid
.29795 .17605 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17619 m
.29793 .17619 L
s
0 0 0 r
2.5 Mabswid
.29793 .17619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17633 m
.29792 .17633 L
s
0 0 0 r
2.5 Mabswid
.29792 .17633 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17646 m
.29791 .17646 L
s
0 0 0 r
2.5 Mabswid
.29791 .17646 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1766 m
.29789 .1766 L
s
0 0 0 r
2.5 Mabswid
.29789 .1766 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17673 m
.29788 .17673 L
s
0 0 0 r
2.5 Mabswid
.29788 .17673 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17687 m
.29786 .17687 L
s
0 0 0 r
2.5 Mabswid
.29786 .17687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17701 m
.29785 .17701 L
s
0 0 0 r
2.5 Mabswid
.29785 .17701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17714 m
.29783 .17714 L
s
0 0 0 r
2.5 Mabswid
.29783 .17714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17728 m
.29782 .17728 L
s
0 0 0 r
2.5 Mabswid
.29782 .17728 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17741 m
.29781 .17741 L
s
0 0 0 r
2.5 Mabswid
.29781 .17741 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17755 m
.29779 .17755 L
s
0 0 0 r
2.5 Mabswid
.29779 .17755 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17769 m
.29778 .17769 L
s
0 0 0 r
2.5 Mabswid
.29778 .17769 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17782 m
.29776 .17782 L
s
0 0 0 r
2.5 Mabswid
.29776 .17782 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17796 m
.29775 .17796 L
s
0 0 0 r
2.5 Mabswid
.29775 .17796 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1781 m
.29774 .1781 L
s
0 0 0 r
2.5 Mabswid
.29774 .1781 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17823 m
.29772 .17823 L
s
0 0 0 r
2.5 Mabswid
.29772 .17823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17837 m
.29771 .17837 L
s
0 0 0 r
2.5 Mabswid
.29771 .17837 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1785 m
.2977 .1785 L
s
0 0 0 r
2.5 Mabswid
.2977 .1785 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17864 m
.29768 .17864 L
s
0 0 0 r
2.5 Mabswid
.29768 .17864 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17878 m
.29767 .17878 L
s
0 0 0 r
2.5 Mabswid
.29767 .17878 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17891 m
.29766 .17891 L
s
0 0 0 r
2.5 Mabswid
.29766 .17891 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17905 m
.29764 .17905 L
s
0 0 0 r
2.5 Mabswid
.29764 .17905 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17918 m
.29763 .17918 L
s
0 0 0 r
2.5 Mabswid
.29763 .17918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17932 m
.29762 .17932 L
s
0 0 0 r
2.5 Mabswid
.29762 .17932 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17946 m
.2976 .17946 L
s
0 0 0 r
2.5 Mabswid
.2976 .17946 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17959 m
.29759 .17959 L
s
0 0 0 r
2.5 Mabswid
.29759 .17959 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17973 m
.29758 .17973 L
s
0 0 0 r
2.5 Mabswid
.29758 .17973 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17986 m
.29756 .17986 L
s
0 0 0 r
2.5 Mabswid
.29756 .17986 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18 m
.29755 .18 L
s
0 0 0 r
2.5 Mabswid
.29755 .18 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18014 m
.29754 .18014 L
s
0 0 0 r
2.5 Mabswid
.29754 .18014 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18027 m
.29752 .18027 L
s
0 0 0 r
2.5 Mabswid
.29752 .18027 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18041 m
.29751 .18041 L
s
0 0 0 r
2.5 Mabswid
.29751 .18041 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18054 m
.2975 .18054 L
s
0 0 0 r
2.5 Mabswid
.2975 .18054 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18068 m
.29749 .18068 L
s
0 0 0 r
2.5 Mabswid
.29749 .18068 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18082 m
.29747 .18082 L
s
0 0 0 r
2.5 Mabswid
.29747 .18082 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18095 m
.29746 .18095 L
s
0 0 0 r
2.5 Mabswid
.29746 .18095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18109 m
.29745 .18109 L
s
0 0 0 r
2.5 Mabswid
.29745 .18109 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18122 m
.29744 .18122 L
s
0 0 0 r
2.5 Mabswid
.29744 .18122 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18136 m
.29742 .18136 L
s
0 0 0 r
2.5 Mabswid
.29742 .18136 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1815 m
.29741 .1815 L
s
0 0 0 r
2.5 Mabswid
.29741 .1815 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18163 m
.2974 .18163 L
s
0 0 0 r
2.5 Mabswid
.2974 .18163 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18177 m
.29739 .18177 L
s
0 0 0 r
2.5 Mabswid
.29739 .18177 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1819 m
.29737 .1819 L
s
0 0 0 r
2.5 Mabswid
.29737 .1819 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18204 m
.29736 .18204 L
s
0 0 0 r
2.5 Mabswid
.29736 .18204 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18218 m
.29735 .18218 L
s
0 0 0 r
2.5 Mabswid
.29735 .18218 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18231 m
.29734 .18231 L
s
0 0 0 r
2.5 Mabswid
.29734 .18231 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18245 m
.29732 .18245 L
s
0 0 0 r
2.5 Mabswid
.29732 .18245 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18259 m
.29731 .18259 L
s
0 0 0 r
2.5 Mabswid
.29731 .18259 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18272 m
.2973 .18272 L
s
0 0 0 r
2.5 Mabswid
.2973 .18272 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18286 m
.29729 .18286 L
s
0 0 0 r
2.5 Mabswid
.29729 .18286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18299 m
.29728 .18299 L
s
0 0 0 r
2.5 Mabswid
.29728 .18299 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18313 m
.29727 .18313 L
s
0 0 0 r
2.5 Mabswid
.29727 .18313 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18327 m
.29725 .18327 L
s
0 0 0 r
2.5 Mabswid
.29725 .18327 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1834 m
.29724 .1834 L
s
0 0 0 r
2.5 Mabswid
.29724 .1834 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18354 m
.29723 .18354 L
s
0 0 0 r
2.5 Mabswid
.29723 .18354 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18367 m
.29722 .18367 L
s
0 0 0 r
2.5 Mabswid
.29722 .18367 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18381 m
.29721 .18381 L
s
0 0 0 r
2.5 Mabswid
.29721 .18381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18395 m
.2972 .18395 L
s
0 0 0 r
2.5 Mabswid
.2972 .18395 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18408 m
.29718 .18408 L
s
0 0 0 r
2.5 Mabswid
.29718 .18408 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18422 m
.29717 .18422 L
s
0 0 0 r
2.5 Mabswid
.29717 .18422 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18435 m
.29716 .18435 L
s
0 0 0 r
2.5 Mabswid
.29716 .18435 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18449 m
.29715 .18449 L
s
0 0 0 r
2.5 Mabswid
.29715 .18449 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18463 m
.29714 .18463 L
s
0 0 0 r
2.5 Mabswid
.29714 .18463 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18476 m
.29713 .18476 L
s
0 0 0 r
2.5 Mabswid
.29713 .18476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1849 m
.29712 .1849 L
s
0 0 0 r
2.5 Mabswid
.29712 .1849 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18503 m
.29711 .18503 L
s
0 0 0 r
2.5 Mabswid
.29711 .18503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18517 m
.29709 .18517 L
s
0 0 0 r
2.5 Mabswid
.29709 .18517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18531 m
.29708 .18531 L
s
0 0 0 r
2.5 Mabswid
.29708 .18531 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18544 m
.29707 .18544 L
s
0 0 0 r
2.5 Mabswid
.29707 .18544 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18558 m
.29706 .18558 L
s
0 0 0 r
2.5 Mabswid
.29706 .18558 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18571 m
.29705 .18571 L
s
0 0 0 r
2.5 Mabswid
.29705 .18571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18585 m
.29704 .18585 L
s
0 0 0 r
2.5 Mabswid
.29704 .18585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18599 m
.29703 .18599 L
s
0 0 0 r
2.5 Mabswid
.29703 .18599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18612 m
.29702 .18612 L
s
0 0 0 r
2.5 Mabswid
.29702 .18612 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18626 m
.29701 .18626 L
s
0 0 0 r
2.5 Mabswid
.29701 .18626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18639 m
.297 .18639 L
s
0 0 0 r
2.5 Mabswid
.297 .18639 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18653 m
.29699 .18653 L
s
0 0 0 r
2.5 Mabswid
.29699 .18653 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18667 m
.29698 .18667 L
s
0 0 0 r
2.5 Mabswid
.29698 .18667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1868 m
.29697 .1868 L
s
0 0 0 r
2.5 Mabswid
.29697 .1868 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18694 m
.29696 .18694 L
s
0 0 0 r
2.5 Mabswid
.29696 .18694 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18707 m
.29695 .18707 L
s
0 0 0 r
2.5 Mabswid
.29695 .18707 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18721 m
.29694 .18721 L
s
0 0 0 r
2.5 Mabswid
.29694 .18721 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18735 m
.29692 .18735 L
s
0 0 0 r
2.5 Mabswid
.29692 .18735 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18748 m
.29691 .18748 L
s
0 0 0 r
2.5 Mabswid
.29691 .18748 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18762 m
.2969 .18762 L
s
0 0 0 r
2.5 Mabswid
.2969 .18762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18776 m
.29689 .18776 L
s
0 0 0 r
2.5 Mabswid
.29689 .18776 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18789 m
.29688 .18789 L
s
0 0 0 r
2.5 Mabswid
.29688 .18789 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18803 m
.29687 .18803 L
s
0 0 0 r
2.5 Mabswid
.29687 .18803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18816 m
.29686 .18816 L
s
0 0 0 r
2.5 Mabswid
.29686 .18816 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1883 m
.29685 .1883 L
s
0 0 0 r
2.5 Mabswid
.29685 .1883 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18844 m
.29685 .18844 L
s
0 0 0 r
2.5 Mabswid
.29685 .18844 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18857 m
.29684 .18857 L
s
0 0 0 r
2.5 Mabswid
.29684 .18857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18871 m
.29683 .18871 L
s
0 0 0 r
2.5 Mabswid
.29683 .18871 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18884 m
.29682 .18884 L
s
0 0 0 r
2.5 Mabswid
.29682 .18884 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18898 m
.29681 .18898 L
s
0 0 0 r
2.5 Mabswid
.29681 .18898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18912 m
.2968 .18912 L
s
0 0 0 r
2.5 Mabswid
.2968 .18912 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18925 m
.29679 .18925 L
s
0 0 0 r
2.5 Mabswid
.29679 .18925 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18939 m
.29678 .18939 L
s
0 0 0 r
2.5 Mabswid
.29678 .18939 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18952 m
.29677 .18952 L
s
0 0 0 r
2.5 Mabswid
.29677 .18952 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18966 m
.29676 .18966 L
s
0 0 0 r
2.5 Mabswid
.29676 .18966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1898 m
.29675 .1898 L
s
0 0 0 r
2.5 Mabswid
.29675 .1898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .18993 m
.29674 .18993 L
s
0 0 0 r
2.5 Mabswid
.29674 .18993 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19007 m
.29673 .19007 L
s
0 0 0 r
2.5 Mabswid
.29673 .19007 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1902 m
.29672 .1902 L
s
0 0 0 r
2.5 Mabswid
.29672 .1902 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19034 m
.29671 .19034 L
s
0 0 0 r
2.5 Mabswid
.29671 .19034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19048 m
.2967 .19048 L
s
0 0 0 r
2.5 Mabswid
.2967 .19048 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19061 m
.2967 .19061 L
s
0 0 0 r
2.5 Mabswid
.2967 .19061 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19075 m
.29669 .19075 L
s
0 0 0 r
2.5 Mabswid
.29669 .19075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19088 m
.29668 .19088 L
s
0 0 0 r
2.5 Mabswid
.29668 .19088 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19102 m
.29667 .19102 L
s
0 0 0 r
2.5 Mabswid
.29667 .19102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19116 m
.29666 .19116 L
s
0 0 0 r
2.5 Mabswid
.29666 .19116 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19129 m
.29665 .19129 L
s
0 0 0 r
2.5 Mabswid
.29665 .19129 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19143 m
.29664 .19143 L
s
0 0 0 r
2.5 Mabswid
.29664 .19143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19156 m
.29663 .19156 L
s
0 0 0 r
2.5 Mabswid
.29663 .19156 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1917 m
.29663 .1917 L
s
0 0 0 r
2.5 Mabswid
.29663 .1917 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19184 m
.29662 .19184 L
s
0 0 0 r
2.5 Mabswid
.29662 .19184 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19197 m
.29661 .19197 L
s
0 0 0 r
2.5 Mabswid
.29661 .19197 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19211 m
.2966 .19211 L
s
0 0 0 r
2.5 Mabswid
.2966 .19211 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19224 m
.29659 .19224 L
s
0 0 0 r
2.5 Mabswid
.29659 .19224 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19238 m
.29658 .19238 L
s
0 0 0 r
2.5 Mabswid
.29658 .19238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19252 m
.29658 .19252 L
s
0 0 0 r
2.5 Mabswid
.29658 .19252 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19265 m
.29657 .19265 L
s
0 0 0 r
2.5 Mabswid
.29657 .19265 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19279 m
.29656 .19279 L
s
0 0 0 r
2.5 Mabswid
.29656 .19279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19293 m
.29655 .19293 L
s
0 0 0 r
2.5 Mabswid
.29655 .19293 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19306 m
.29654 .19306 L
s
0 0 0 r
2.5 Mabswid
.29654 .19306 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1932 m
.29653 .1932 L
s
0 0 0 r
2.5 Mabswid
.29653 .1932 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19333 m
.29653 .19333 L
s
0 0 0 r
2.5 Mabswid
.29653 .19333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19347 m
.29652 .19347 L
s
0 0 0 r
2.5 Mabswid
.29652 .19347 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19361 m
.29651 .19361 L
s
0 0 0 r
2.5 Mabswid
.29651 .19361 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19374 m
.2965 .19374 L
s
0 0 0 r
2.5 Mabswid
.2965 .19374 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19388 m
.2965 .19388 L
s
0 0 0 r
2.5 Mabswid
.2965 .19388 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19401 m
.29649 .19401 L
s
0 0 0 r
2.5 Mabswid
.29649 .19401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19415 m
.29648 .19415 L
s
0 0 0 r
2.5 Mabswid
.29648 .19415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19429 m
.29647 .19429 L
s
0 0 0 r
2.5 Mabswid
.29647 .19429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19442 m
.29647 .19442 L
s
0 0 0 r
2.5 Mabswid
.29647 .19442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19456 m
.29646 .19456 L
s
0 0 0 r
2.5 Mabswid
.29646 .19456 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19469 m
.29645 .19469 L
s
0 0 0 r
2.5 Mabswid
.29645 .19469 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19483 m
.29644 .19483 L
s
0 0 0 r
2.5 Mabswid
.29644 .19483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19497 m
.29644 .19497 L
s
0 0 0 r
2.5 Mabswid
.29644 .19497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1951 m
.29643 .1951 L
s
0 0 0 r
2.5 Mabswid
.29643 .1951 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19524 m
.29642 .19524 L
s
0 0 0 r
2.5 Mabswid
.29642 .19524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19537 m
.29641 .19537 L
s
0 0 0 r
2.5 Mabswid
.29641 .19537 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19551 m
.29641 .19551 L
s
0 0 0 r
2.5 Mabswid
.29641 .19551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19565 m
.2964 .19565 L
s
0 0 0 r
2.5 Mabswid
.2964 .19565 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19578 m
.29639 .19578 L
s
0 0 0 r
2.5 Mabswid
.29639 .19578 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19592 m
.29639 .19592 L
s
0 0 0 r
2.5 Mabswid
.29639 .19592 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19605 m
.29638 .19605 L
s
0 0 0 r
2.5 Mabswid
.29638 .19605 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19619 m
.29637 .19619 L
s
0 0 0 r
2.5 Mabswid
.29637 .19619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19633 m
.29637 .19633 L
s
0 0 0 r
2.5 Mabswid
.29637 .19633 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19646 m
.29636 .19646 L
s
0 0 0 r
2.5 Mabswid
.29636 .19646 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1966 m
.29635 .1966 L
s
0 0 0 r
2.5 Mabswid
.29635 .1966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19673 m
.29635 .19673 L
s
0 0 0 r
2.5 Mabswid
.29635 .19673 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19687 m
.29634 .19687 L
s
0 0 0 r
2.5 Mabswid
.29634 .19687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19701 m
.29633 .19701 L
s
0 0 0 r
2.5 Mabswid
.29633 .19701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19714 m
.29633 .19714 L
s
0 0 0 r
2.5 Mabswid
.29633 .19714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19728 m
.29632 .19728 L
s
0 0 0 r
2.5 Mabswid
.29632 .19728 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19741 m
.29631 .19741 L
s
0 0 0 r
2.5 Mabswid
.29631 .19741 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19755 m
.29631 .19755 L
s
0 0 0 r
2.5 Mabswid
.29631 .19755 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19769 m
.2963 .19769 L
s
0 0 0 r
2.5 Mabswid
.2963 .19769 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19782 m
.29629 .19782 L
s
0 0 0 r
2.5 Mabswid
.29629 .19782 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19796 m
.29629 .19796 L
s
0 0 0 r
2.5 Mabswid
.29629 .19796 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1981 m
.29628 .1981 L
s
0 0 0 r
2.5 Mabswid
.29628 .1981 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19823 m
.29628 .19823 L
s
0 0 0 r
2.5 Mabswid
.29628 .19823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19837 m
.29627 .19837 L
s
0 0 0 r
2.5 Mabswid
.29627 .19837 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1985 m
.29626 .1985 L
s
0 0 0 r
2.5 Mabswid
.29626 .1985 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19864 m
.29626 .19864 L
s
0 0 0 r
2.5 Mabswid
.29626 .19864 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19878 m
.29625 .19878 L
s
0 0 0 r
2.5 Mabswid
.29625 .19878 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19891 m
.29625 .19891 L
s
0 0 0 r
2.5 Mabswid
.29625 .19891 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19905 m
.29624 .19905 L
s
0 0 0 r
2.5 Mabswid
.29624 .19905 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19918 m
.29623 .19918 L
s
0 0 0 r
2.5 Mabswid
.29623 .19918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19932 m
.29623 .19932 L
s
0 0 0 r
2.5 Mabswid
.29623 .19932 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19946 m
.29622 .19946 L
s
0 0 0 r
2.5 Mabswid
.29622 .19946 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19959 m
.29622 .19959 L
s
0 0 0 r
2.5 Mabswid
.29622 .19959 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19973 m
.29621 .19973 L
s
0 0 0 r
2.5 Mabswid
.29621 .19973 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19986 m
.29621 .19986 L
s
0 0 0 r
2.5 Mabswid
.29621 .19986 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2 m
.2962 .2 L
s
0 0 0 r
2.5 Mabswid
.2962 .2 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20014 m
.2962 .20014 L
s
0 0 0 r
2.5 Mabswid
.2962 .20014 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20027 m
.29619 .20027 L
s
0 0 0 r
2.5 Mabswid
.29619 .20027 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20041 m
.29619 .20041 L
s
0 0 0 r
2.5 Mabswid
.29619 .20041 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20054 m
.29618 .20054 L
s
0 0 0 r
2.5 Mabswid
.29618 .20054 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20068 m
.29617 .20068 L
s
0 0 0 r
2.5 Mabswid
.29617 .20068 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20082 m
.29617 .20082 L
s
0 0 0 r
2.5 Mabswid
.29617 .20082 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20095 m
.29616 .20095 L
s
0 0 0 r
2.5 Mabswid
.29616 .20095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20109 m
.29616 .20109 L
s
0 0 0 r
2.5 Mabswid
.29616 .20109 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20122 m
.29615 .20122 L
s
0 0 0 r
2.5 Mabswid
.29615 .20122 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20136 m
.29615 .20136 L
s
0 0 0 r
2.5 Mabswid
.29615 .20136 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2015 m
.29614 .2015 L
s
0 0 0 r
2.5 Mabswid
.29614 .2015 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20163 m
.29614 .20163 L
s
0 0 0 r
2.5 Mabswid
.29614 .20163 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20177 m
.29614 .20177 L
s
0 0 0 r
2.5 Mabswid
.29614 .20177 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2019 m
.29613 .2019 L
s
0 0 0 r
2.5 Mabswid
.29613 .2019 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20204 m
.29613 .20204 L
s
0 0 0 r
2.5 Mabswid
.29613 .20204 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20218 m
.29612 .20218 L
s
0 0 0 r
2.5 Mabswid
.29612 .20218 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20231 m
.29612 .20231 L
s
0 0 0 r
2.5 Mabswid
.29612 .20231 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20245 m
.29611 .20245 L
s
0 0 0 r
2.5 Mabswid
.29611 .20245 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20259 m
.29611 .20259 L
s
0 0 0 r
2.5 Mabswid
.29611 .20259 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20272 m
.2961 .20272 L
s
0 0 0 r
2.5 Mabswid
.2961 .20272 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20286 m
.2961 .20286 L
s
0 0 0 r
2.5 Mabswid
.2961 .20286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20299 m
.2961 .20299 L
s
0 0 0 r
2.5 Mabswid
.2961 .20299 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20313 m
.29609 .20313 L
s
0 0 0 r
2.5 Mabswid
.29609 .20313 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20327 m
.29609 .20327 L
s
0 0 0 r
2.5 Mabswid
.29609 .20327 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2034 m
.29608 .2034 L
s
0 0 0 r
2.5 Mabswid
.29608 .2034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20354 m
.29608 .20354 L
s
0 0 0 r
2.5 Mabswid
.29608 .20354 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20367 m
.29607 .20367 L
s
0 0 0 r
2.5 Mabswid
.29607 .20367 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20381 m
.29607 .20381 L
s
0 0 0 r
2.5 Mabswid
.29607 .20381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20395 m
.29607 .20395 L
s
0 0 0 r
2.5 Mabswid
.29607 .20395 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20408 m
.29606 .20408 L
s
0 0 0 r
2.5 Mabswid
.29606 .20408 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20422 m
.29606 .20422 L
s
0 0 0 r
2.5 Mabswid
.29606 .20422 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20435 m
.29606 .20435 L
s
0 0 0 r
2.5 Mabswid
.29606 .20435 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20449 m
.29605 .20449 L
s
0 0 0 r
2.5 Mabswid
.29605 .20449 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20463 m
.29605 .20463 L
s
0 0 0 r
2.5 Mabswid
.29605 .20463 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20476 m
.29604 .20476 L
s
0 0 0 r
2.5 Mabswid
.29604 .20476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2049 m
.29604 .2049 L
s
0 0 0 r
2.5 Mabswid
.29604 .2049 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20503 m
.29604 .20503 L
s
0 0 0 r
2.5 Mabswid
.29604 .20503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20517 m
.29603 .20517 L
s
0 0 0 r
2.5 Mabswid
.29603 .20517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20531 m
.29603 .20531 L
s
0 0 0 r
2.5 Mabswid
.29603 .20531 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20544 m
.29603 .20544 L
s
0 0 0 r
2.5 Mabswid
.29603 .20544 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20558 m
.29602 .20558 L
s
0 0 0 r
2.5 Mabswid
.29602 .20558 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20571 m
.29602 .20571 L
s
0 0 0 r
2.5 Mabswid
.29602 .20571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20585 m
.29602 .20585 L
s
0 0 0 r
2.5 Mabswid
.29602 .20585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20599 m
.29601 .20599 L
s
0 0 0 r
2.5 Mabswid
.29601 .20599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20612 m
.29601 .20612 L
s
0 0 0 r
2.5 Mabswid
.29601 .20612 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20626 m
.29601 .20626 L
s
0 0 0 r
2.5 Mabswid
.29601 .20626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20639 m
.296 .20639 L
s
0 0 0 r
2.5 Mabswid
.296 .20639 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20653 m
.296 .20653 L
s
0 0 0 r
2.5 Mabswid
.296 .20653 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20667 m
.296 .20667 L
s
0 0 0 r
2.5 Mabswid
.296 .20667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2068 m
.296 .2068 L
s
0 0 0 r
2.5 Mabswid
.296 .2068 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20694 m
.29599 .20694 L
s
0 0 0 r
2.5 Mabswid
.29599 .20694 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20707 m
.29599 .20707 L
s
0 0 0 r
2.5 Mabswid
.29599 .20707 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20721 m
.29599 .20721 L
s
0 0 0 r
2.5 Mabswid
.29599 .20721 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20735 m
.29599 .20735 L
s
0 0 0 r
2.5 Mabswid
.29599 .20735 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20748 m
.29598 .20748 L
s
0 0 0 r
2.5 Mabswid
.29598 .20748 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20762 m
.29598 .20762 L
s
0 0 0 r
2.5 Mabswid
.29598 .20762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20776 m
.29598 .20776 L
s
0 0 0 r
2.5 Mabswid
.29598 .20776 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20789 m
.29598 .20789 L
s
0 0 0 r
2.5 Mabswid
.29598 .20789 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20803 m
.29597 .20803 L
s
0 0 0 r
2.5 Mabswid
.29597 .20803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20816 m
.29597 .20816 L
s
0 0 0 r
2.5 Mabswid
.29597 .20816 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2083 m
.29597 .2083 L
s
0 0 0 r
2.5 Mabswid
.29597 .2083 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20844 m
.29597 .20844 L
s
0 0 0 r
2.5 Mabswid
.29597 .20844 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20857 m
.29596 .20857 L
s
0 0 0 r
2.5 Mabswid
.29596 .20857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20871 m
.29596 .20871 L
s
0 0 0 r
2.5 Mabswid
.29596 .20871 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20884 m
.29596 .20884 L
s
0 0 0 r
2.5 Mabswid
.29596 .20884 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20898 m
.29596 .20898 L
s
0 0 0 r
2.5 Mabswid
.29596 .20898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20912 m
.29596 .20912 L
s
0 0 0 r
2.5 Mabswid
.29596 .20912 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20925 m
.29595 .20925 L
s
0 0 0 r
2.5 Mabswid
.29595 .20925 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20939 m
.29595 .20939 L
s
0 0 0 r
2.5 Mabswid
.29595 .20939 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20952 m
.29595 .20952 L
s
0 0 0 r
2.5 Mabswid
.29595 .20952 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20966 m
.29595 .20966 L
s
0 0 0 r
2.5 Mabswid
.29595 .20966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2098 m
.29595 .2098 L
s
0 0 0 r
2.5 Mabswid
.29595 .2098 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .20993 m
.29594 .20993 L
s
0 0 0 r
2.5 Mabswid
.29594 .20993 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21007 m
.29594 .21007 L
s
0 0 0 r
2.5 Mabswid
.29594 .21007 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2102 m
.29594 .2102 L
s
0 0 0 r
2.5 Mabswid
.29594 .2102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21034 m
.29594 .21034 L
s
0 0 0 r
2.5 Mabswid
.29594 .21034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21048 m
.29594 .21048 L
s
0 0 0 r
2.5 Mabswid
.29594 .21048 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21061 m
.29594 .21061 L
s
0 0 0 r
2.5 Mabswid
.29594 .21061 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21075 m
.29594 .21075 L
s
0 0 0 r
2.5 Mabswid
.29594 .21075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21088 m
.29593 .21088 L
s
0 0 0 r
2.5 Mabswid
.29593 .21088 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21102 m
.29593 .21102 L
s
0 0 0 r
2.5 Mabswid
.29593 .21102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21116 m
.29593 .21116 L
s
0 0 0 r
2.5 Mabswid
.29593 .21116 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21129 m
.29593 .21129 L
s
0 0 0 r
2.5 Mabswid
.29593 .21129 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21143 m
.29593 .21143 L
s
0 0 0 r
2.5 Mabswid
.29593 .21143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21156 m
.29593 .21156 L
s
0 0 0 r
2.5 Mabswid
.29593 .21156 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2117 m
.29593 .2117 L
s
0 0 0 r
2.5 Mabswid
.29593 .2117 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21184 m
.29593 .21184 L
s
0 0 0 r
2.5 Mabswid
.29593 .21184 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21197 m
.29593 .21197 L
s
0 0 0 r
2.5 Mabswid
.29593 .21197 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21211 m
.29592 .21211 L
s
0 0 0 r
2.5 Mabswid
.29592 .21211 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21224 m
.29592 .21224 L
s
0 0 0 r
2.5 Mabswid
.29592 .21224 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21238 m
.29592 .21238 L
s
0 0 0 r
2.5 Mabswid
.29592 .21238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21252 m
.29592 .21252 L
s
0 0 0 r
2.5 Mabswid
.29592 .21252 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21265 m
.29592 .21265 L
s
0 0 0 r
2.5 Mabswid
.29592 .21265 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21279 m
.29592 .21279 L
s
0 0 0 r
2.5 Mabswid
.29592 .21279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21293 m
.29592 .21293 L
s
0 0 0 r
2.5 Mabswid
.29592 .21293 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21306 m
.29592 .21306 L
s
0 0 0 r
2.5 Mabswid
.29592 .21306 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2132 m
.29592 .2132 L
s
0 0 0 r
2.5 Mabswid
.29592 .2132 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21333 m
.29592 .21333 L
s
0 0 0 r
2.5 Mabswid
.29592 .21333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21347 m
.29592 .21347 L
s
0 0 0 r
2.5 Mabswid
.29592 .21347 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21361 m
.29592 .21361 L
s
0 0 0 r
2.5 Mabswid
.29592 .21361 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21374 m
.29592 .21374 L
s
0 0 0 r
2.5 Mabswid
.29592 .21374 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21388 m
.29592 .21388 L
s
0 0 0 r
2.5 Mabswid
.29592 .21388 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21401 m
.29592 .21401 L
s
0 0 0 r
2.5 Mabswid
.29592 .21401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21415 m
.29592 .21415 L
s
0 0 0 r
2.5 Mabswid
.29592 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21429 m
.29592 .21429 L
s
0 0 0 r
2.5 Mabswid
.29592 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21442 m
.29592 .21442 L
s
0 0 0 r
2.5 Mabswid
.29592 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21456 m
.29592 .21456 L
s
0 0 0 r
2.5 Mabswid
.29592 .21456 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21469 m
.29592 .21469 L
s
0 0 0 r
2.5 Mabswid
.29592 .21469 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21483 m
.29592 .21483 L
s
0 0 0 r
2.5 Mabswid
.29592 .21483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21497 m
.29592 .21497 L
s
0 0 0 r
2.5 Mabswid
.29592 .21497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2151 m
.29592 .2151 L
s
0 0 0 r
2.5 Mabswid
.29592 .2151 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21524 m
.29592 .21524 L
s
0 0 0 r
2.5 Mabswid
.29592 .21524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21537 m
.29592 .21537 L
s
0 0 0 r
2.5 Mabswid
.29592 .21537 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21551 m
.29592 .21551 L
s
0 0 0 r
2.5 Mabswid
.29592 .21551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21565 m
.29592 .21565 L
s
0 0 0 r
2.5 Mabswid
.29592 .21565 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21578 m
.29592 .21578 L
s
0 0 0 r
2.5 Mabswid
.29592 .21578 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21592 m
.29592 .21592 L
s
0 0 0 r
2.5 Mabswid
.29592 .21592 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21605 m
.29592 .21605 L
s
0 0 0 r
2.5 Mabswid
.29592 .21605 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21619 m
.29592 .21619 L
s
0 0 0 r
2.5 Mabswid
.29592 .21619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21633 m
.29592 .21633 L
s
0 0 0 r
2.5 Mabswid
.29592 .21633 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21646 m
.29592 .21646 L
s
0 0 0 r
2.5 Mabswid
.29592 .21646 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2166 m
.29593 .2166 L
s
0 0 0 r
2.5 Mabswid
.29593 .2166 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21673 m
.29593 .21673 L
s
0 0 0 r
2.5 Mabswid
.29593 .21673 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21687 m
.29593 .21687 L
s
0 0 0 r
2.5 Mabswid
.29593 .21687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21701 m
.29593 .21701 L
s
0 0 0 r
2.5 Mabswid
.29593 .21701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21714 m
.29593 .21714 L
s
0 0 0 r
2.5 Mabswid
.29593 .21714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21728 m
.29593 .21728 L
s
0 0 0 r
2.5 Mabswid
.29593 .21728 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21741 m
.29593 .21741 L
s
0 0 0 r
2.5 Mabswid
.29593 .21741 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21755 m
.29593 .21755 L
s
0 0 0 r
2.5 Mabswid
.29593 .21755 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21769 m
.29593 .21769 L
s
0 0 0 r
2.5 Mabswid
.29593 .21769 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21782 m
.29594 .21782 L
s
0 0 0 r
2.5 Mabswid
.29594 .21782 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21796 m
.29594 .21796 L
s
0 0 0 r
2.5 Mabswid
.29594 .21796 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2181 m
.29594 .2181 L
s
0 0 0 r
2.5 Mabswid
.29594 .2181 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21823 m
.29594 .21823 L
s
0 0 0 r
2.5 Mabswid
.29594 .21823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21837 m
.29594 .21837 L
s
0 0 0 r
2.5 Mabswid
.29594 .21837 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2185 m
.29594 .2185 L
s
0 0 0 r
2.5 Mabswid
.29594 .2185 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21864 m
.29594 .21864 L
s
0 0 0 r
2.5 Mabswid
.29594 .21864 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21878 m
.29595 .21878 L
s
0 0 0 r
2.5 Mabswid
.29595 .21878 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21891 m
.29595 .21891 L
s
0 0 0 r
2.5 Mabswid
.29595 .21891 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21905 m
.29595 .21905 L
s
0 0 0 r
2.5 Mabswid
.29595 .21905 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21918 m
.29595 .21918 L
s
0 0 0 r
2.5 Mabswid
.29595 .21918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21932 m
.29595 .21932 L
s
0 0 0 r
2.5 Mabswid
.29595 .21932 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21946 m
.29596 .21946 L
s
0 0 0 r
2.5 Mabswid
.29596 .21946 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21959 m
.29596 .21959 L
s
0 0 0 r
2.5 Mabswid
.29596 .21959 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21973 m
.29596 .21973 L
s
0 0 0 r
2.5 Mabswid
.29596 .21973 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21986 m
.29596 .21986 L
s
0 0 0 r
2.5 Mabswid
.29596 .21986 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22 m
.29596 .22 L
s
0 0 0 r
2.5 Mabswid
.29596 .22 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22014 m
.29597 .22014 L
s
0 0 0 r
2.5 Mabswid
.29597 .22014 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22027 m
.29597 .22027 L
s
0 0 0 r
2.5 Mabswid
.29597 .22027 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22041 m
.29597 .22041 L
s
0 0 0 r
2.5 Mabswid
.29597 .22041 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22054 m
.29597 .22054 L
s
0 0 0 r
2.5 Mabswid
.29597 .22054 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22068 m
.29598 .22068 L
s
0 0 0 r
2.5 Mabswid
.29598 .22068 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22082 m
.29598 .22082 L
s
0 0 0 r
2.5 Mabswid
.29598 .22082 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22095 m
.29598 .22095 L
s
0 0 0 r
2.5 Mabswid
.29598 .22095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22109 m
.29598 .22109 L
s
0 0 0 r
2.5 Mabswid
.29598 .22109 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22122 m
.29599 .22122 L
s
0 0 0 r
2.5 Mabswid
.29599 .22122 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22136 m
.29599 .22136 L
s
0 0 0 r
2.5 Mabswid
.29599 .22136 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2215 m
.29599 .2215 L
s
0 0 0 r
2.5 Mabswid
.29599 .2215 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22163 m
.29599 .22163 L
s
0 0 0 r
2.5 Mabswid
.29599 .22163 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22177 m
.296 .22177 L
s
0 0 0 r
2.5 Mabswid
.296 .22177 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2219 m
.296 .2219 L
s
0 0 0 r
2.5 Mabswid
.296 .2219 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22204 m
.296 .22204 L
s
0 0 0 r
2.5 Mabswid
.296 .22204 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22218 m
.296 .22218 L
s
0 0 0 r
2.5 Mabswid
.296 .22218 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22231 m
.29601 .22231 L
s
0 0 0 r
2.5 Mabswid
.29601 .22231 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22245 m
.29601 .22245 L
s
0 0 0 r
2.5 Mabswid
.29601 .22245 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22259 m
.29601 .22259 L
s
0 0 0 r
2.5 Mabswid
.29601 .22259 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22272 m
.29602 .22272 L
s
0 0 0 r
2.5 Mabswid
.29602 .22272 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22286 m
.29602 .22286 L
s
0 0 0 r
2.5 Mabswid
.29602 .22286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22299 m
.29602 .22299 L
s
0 0 0 r
2.5 Mabswid
.29602 .22299 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22313 m
.29603 .22313 L
s
0 0 0 r
2.5 Mabswid
.29603 .22313 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22327 m
.29603 .22327 L
s
0 0 0 r
2.5 Mabswid
.29603 .22327 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2234 m
.29603 .2234 L
s
0 0 0 r
2.5 Mabswid
.29603 .2234 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22354 m
.29604 .22354 L
s
0 0 0 r
2.5 Mabswid
.29604 .22354 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22367 m
.29604 .22367 L
s
0 0 0 r
2.5 Mabswid
.29604 .22367 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22381 m
.29604 .22381 L
s
0 0 0 r
2.5 Mabswid
.29604 .22381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22395 m
.29605 .22395 L
s
0 0 0 r
2.5 Mabswid
.29605 .22395 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22408 m
.29605 .22408 L
s
0 0 0 r
2.5 Mabswid
.29605 .22408 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22422 m
.29606 .22422 L
s
0 0 0 r
2.5 Mabswid
.29606 .22422 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22435 m
.29606 .22435 L
s
0 0 0 r
2.5 Mabswid
.29606 .22435 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22449 m
.29606 .22449 L
s
0 0 0 r
2.5 Mabswid
.29606 .22449 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22463 m
.29607 .22463 L
s
0 0 0 r
2.5 Mabswid
.29607 .22463 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22476 m
.29607 .22476 L
s
0 0 0 r
2.5 Mabswid
.29607 .22476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2249 m
.29607 .2249 L
s
0 0 0 r
2.5 Mabswid
.29607 .2249 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22503 m
.29608 .22503 L
s
0 0 0 r
2.5 Mabswid
.29608 .22503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22517 m
.29608 .22517 L
s
0 0 0 r
2.5 Mabswid
.29608 .22517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22531 m
.29609 .22531 L
s
0 0 0 r
2.5 Mabswid
.29609 .22531 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22544 m
.29609 .22544 L
s
0 0 0 r
2.5 Mabswid
.29609 .22544 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22558 m
.2961 .22558 L
s
0 0 0 r
2.5 Mabswid
.2961 .22558 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22571 m
.2961 .22571 L
s
0 0 0 r
2.5 Mabswid
.2961 .22571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22585 m
.2961 .22585 L
s
0 0 0 r
2.5 Mabswid
.2961 .22585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22599 m
.29611 .22599 L
s
0 0 0 r
2.5 Mabswid
.29611 .22599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22612 m
.29611 .22612 L
s
0 0 0 r
2.5 Mabswid
.29611 .22612 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22626 m
.29612 .22626 L
s
0 0 0 r
2.5 Mabswid
.29612 .22626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22639 m
.29612 .22639 L
s
0 0 0 r
2.5 Mabswid
.29612 .22639 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22653 m
.29613 .22653 L
s
0 0 0 r
2.5 Mabswid
.29613 .22653 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22667 m
.29613 .22667 L
s
0 0 0 r
2.5 Mabswid
.29613 .22667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2268 m
.29614 .2268 L
s
0 0 0 r
2.5 Mabswid
.29614 .2268 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22694 m
.29614 .22694 L
s
0 0 0 r
2.5 Mabswid
.29614 .22694 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22707 m
.29614 .22707 L
s
0 0 0 r
2.5 Mabswid
.29614 .22707 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22721 m
.29615 .22721 L
s
0 0 0 r
2.5 Mabswid
.29615 .22721 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22735 m
.29615 .22735 L
s
0 0 0 r
2.5 Mabswid
.29615 .22735 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22748 m
.29616 .22748 L
s
0 0 0 r
2.5 Mabswid
.29616 .22748 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22762 m
.29616 .22762 L
s
0 0 0 r
2.5 Mabswid
.29616 .22762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22776 m
.29617 .22776 L
s
0 0 0 r
2.5 Mabswid
.29617 .22776 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22789 m
.29617 .22789 L
s
0 0 0 r
2.5 Mabswid
.29617 .22789 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22803 m
.29618 .22803 L
s
0 0 0 r
2.5 Mabswid
.29618 .22803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22816 m
.29619 .22816 L
s
0 0 0 r
2.5 Mabswid
.29619 .22816 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2283 m
.29619 .2283 L
s
0 0 0 r
2.5 Mabswid
.29619 .2283 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22844 m
.2962 .22844 L
s
0 0 0 r
2.5 Mabswid
.2962 .22844 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22857 m
.2962 .22857 L
s
0 0 0 r
2.5 Mabswid
.2962 .22857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22871 m
.29621 .22871 L
s
0 0 0 r
2.5 Mabswid
.29621 .22871 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22884 m
.29621 .22884 L
s
0 0 0 r
2.5 Mabswid
.29621 .22884 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22898 m
.29622 .22898 L
s
0 0 0 r
2.5 Mabswid
.29622 .22898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22912 m
.29622 .22912 L
s
0 0 0 r
2.5 Mabswid
.29622 .22912 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22925 m
.29623 .22925 L
s
0 0 0 r
2.5 Mabswid
.29623 .22925 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22939 m
.29623 .22939 L
s
0 0 0 r
2.5 Mabswid
.29623 .22939 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22952 m
.29624 .22952 L
s
0 0 0 r
2.5 Mabswid
.29624 .22952 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22966 m
.29625 .22966 L
s
0 0 0 r
2.5 Mabswid
.29625 .22966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2298 m
.29625 .2298 L
s
0 0 0 r
2.5 Mabswid
.29625 .2298 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .22993 m
.29626 .22993 L
s
0 0 0 r
2.5 Mabswid
.29626 .22993 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23007 m
.29626 .23007 L
s
0 0 0 r
2.5 Mabswid
.29626 .23007 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2302 m
.29627 .2302 L
s
0 0 0 r
2.5 Mabswid
.29627 .2302 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23034 m
.29628 .23034 L
s
0 0 0 r
2.5 Mabswid
.29628 .23034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23048 m
.29628 .23048 L
s
0 0 0 r
2.5 Mabswid
.29628 .23048 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23061 m
.29629 .23061 L
s
0 0 0 r
2.5 Mabswid
.29629 .23061 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23075 m
.29629 .23075 L
s
0 0 0 r
2.5 Mabswid
.29629 .23075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23088 m
.2963 .23088 L
s
0 0 0 r
2.5 Mabswid
.2963 .23088 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23102 m
.29631 .23102 L
s
0 0 0 r
2.5 Mabswid
.29631 .23102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23116 m
.29631 .23116 L
s
0 0 0 r
2.5 Mabswid
.29631 .23116 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23129 m
.29632 .23129 L
s
0 0 0 r
2.5 Mabswid
.29632 .23129 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23143 m
.29633 .23143 L
s
0 0 0 r
2.5 Mabswid
.29633 .23143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23156 m
.29633 .23156 L
s
0 0 0 r
2.5 Mabswid
.29633 .23156 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2317 m
.29634 .2317 L
s
0 0 0 r
2.5 Mabswid
.29634 .2317 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23184 m
.29635 .23184 L
s
0 0 0 r
2.5 Mabswid
.29635 .23184 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23197 m
.29635 .23197 L
s
0 0 0 r
2.5 Mabswid
.29635 .23197 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23211 m
.29636 .23211 L
s
0 0 0 r
2.5 Mabswid
.29636 .23211 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23224 m
.29637 .23224 L
s
0 0 0 r
2.5 Mabswid
.29637 .23224 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23238 m
.29637 .23238 L
s
0 0 0 r
2.5 Mabswid
.29637 .23238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23252 m
.29638 .23252 L
s
0 0 0 r
2.5 Mabswid
.29638 .23252 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23265 m
.29639 .23265 L
s
0 0 0 r
2.5 Mabswid
.29639 .23265 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23279 m
.29639 .23279 L
s
0 0 0 r
2.5 Mabswid
.29639 .23279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23293 m
.2964 .23293 L
s
0 0 0 r
2.5 Mabswid
.2964 .23293 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23306 m
.29641 .23306 L
s
0 0 0 r
2.5 Mabswid
.29641 .23306 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2332 m
.29641 .2332 L
s
0 0 0 r
2.5 Mabswid
.29641 .2332 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23333 m
.29642 .23333 L
s
0 0 0 r
2.5 Mabswid
.29642 .23333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23347 m
.29643 .23347 L
s
0 0 0 r
2.5 Mabswid
.29643 .23347 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23361 m
.29644 .23361 L
s
0 0 0 r
2.5 Mabswid
.29644 .23361 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23374 m
.29644 .23374 L
s
0 0 0 r
2.5 Mabswid
.29644 .23374 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23388 m
.29645 .23388 L
s
0 0 0 r
2.5 Mabswid
.29645 .23388 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23401 m
.29646 .23401 L
s
0 0 0 r
2.5 Mabswid
.29646 .23401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23415 m
.29647 .23415 L
s
0 0 0 r
2.5 Mabswid
.29647 .23415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23429 m
.29647 .23429 L
s
0 0 0 r
2.5 Mabswid
.29647 .23429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23442 m
.29648 .23442 L
s
0 0 0 r
2.5 Mabswid
.29648 .23442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23456 m
.29649 .23456 L
s
0 0 0 r
2.5 Mabswid
.29649 .23456 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23469 m
.2965 .23469 L
s
0 0 0 r
2.5 Mabswid
.2965 .23469 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23483 m
.2965 .23483 L
s
0 0 0 r
2.5 Mabswid
.2965 .23483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23497 m
.29651 .23497 L
s
0 0 0 r
2.5 Mabswid
.29651 .23497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2351 m
.29652 .2351 L
s
0 0 0 r
2.5 Mabswid
.29652 .2351 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23524 m
.29653 .23524 L
s
0 0 0 r
2.5 Mabswid
.29653 .23524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23537 m
.29653 .23537 L
s
0 0 0 r
2.5 Mabswid
.29653 .23537 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23551 m
.29654 .23551 L
s
0 0 0 r
2.5 Mabswid
.29654 .23551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23565 m
.29655 .23565 L
s
0 0 0 r
2.5 Mabswid
.29655 .23565 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23578 m
.29656 .23578 L
s
0 0 0 r
2.5 Mabswid
.29656 .23578 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23592 m
.29657 .23592 L
s
0 0 0 r
2.5 Mabswid
.29657 .23592 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23605 m
.29658 .23605 L
s
0 0 0 r
2.5 Mabswid
.29658 .23605 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23619 m
.29658 .23619 L
s
0 0 0 r
2.5 Mabswid
.29658 .23619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23633 m
.29659 .23633 L
s
0 0 0 r
2.5 Mabswid
.29659 .23633 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23646 m
.2966 .23646 L
s
0 0 0 r
2.5 Mabswid
.2966 .23646 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2366 m
.29661 .2366 L
s
0 0 0 r
2.5 Mabswid
.29661 .2366 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23673 m
.29662 .23673 L
s
0 0 0 r
2.5 Mabswid
.29662 .23673 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23687 m
.29663 .23687 L
s
0 0 0 r
2.5 Mabswid
.29663 .23687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23701 m
.29663 .23701 L
s
0 0 0 r
2.5 Mabswid
.29663 .23701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23714 m
.29664 .23714 L
s
0 0 0 r
2.5 Mabswid
.29664 .23714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23728 m
.29665 .23728 L
s
0 0 0 r
2.5 Mabswid
.29665 .23728 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23741 m
.29666 .23741 L
s
0 0 0 r
2.5 Mabswid
.29666 .23741 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23755 m
.29667 .23755 L
s
0 0 0 r
2.5 Mabswid
.29667 .23755 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23769 m
.29668 .23769 L
s
0 0 0 r
2.5 Mabswid
.29668 .23769 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23782 m
.29669 .23782 L
s
0 0 0 r
2.5 Mabswid
.29669 .23782 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23796 m
.2967 .23796 L
s
0 0 0 r
2.5 Mabswid
.2967 .23796 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2381 m
.2967 .2381 L
s
0 0 0 r
2.5 Mabswid
.2967 .2381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23823 m
.29671 .23823 L
s
0 0 0 r
2.5 Mabswid
.29671 .23823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23837 m
.29672 .23837 L
s
0 0 0 r
2.5 Mabswid
.29672 .23837 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2385 m
.29673 .2385 L
s
0 0 0 r
2.5 Mabswid
.29673 .2385 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23864 m
.29674 .23864 L
s
0 0 0 r
2.5 Mabswid
.29674 .23864 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23878 m
.29675 .23878 L
s
0 0 0 r
2.5 Mabswid
.29675 .23878 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23891 m
.29676 .23891 L
s
0 0 0 r
2.5 Mabswid
.29676 .23891 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23905 m
.29677 .23905 L
s
0 0 0 r
2.5 Mabswid
.29677 .23905 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23918 m
.29678 .23918 L
s
0 0 0 r
2.5 Mabswid
.29678 .23918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23932 m
.29679 .23932 L
s
0 0 0 r
2.5 Mabswid
.29679 .23932 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23946 m
.2968 .23946 L
s
0 0 0 r
2.5 Mabswid
.2968 .23946 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23959 m
.29681 .23959 L
s
0 0 0 r
2.5 Mabswid
.29681 .23959 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23973 m
.29682 .23973 L
s
0 0 0 r
2.5 Mabswid
.29682 .23973 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23986 m
.29683 .23986 L
s
0 0 0 r
2.5 Mabswid
.29683 .23986 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24 m
.29684 .24 L
s
0 0 0 r
2.5 Mabswid
.29684 .24 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24014 m
.29685 .24014 L
s
0 0 0 r
2.5 Mabswid
.29685 .24014 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24027 m
.29685 .24027 L
s
0 0 0 r
2.5 Mabswid
.29685 .24027 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24041 m
.29686 .24041 L
s
0 0 0 r
2.5 Mabswid
.29686 .24041 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24054 m
.29687 .24054 L
s
0 0 0 r
2.5 Mabswid
.29687 .24054 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24068 m
.29688 .24068 L
s
0 0 0 r
2.5 Mabswid
.29688 .24068 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24082 m
.29689 .24082 L
s
0 0 0 r
2.5 Mabswid
.29689 .24082 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24095 m
.2969 .24095 L
s
0 0 0 r
2.5 Mabswid
.2969 .24095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24109 m
.29691 .24109 L
s
0 0 0 r
2.5 Mabswid
.29691 .24109 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24122 m
.29692 .24122 L
s
0 0 0 r
2.5 Mabswid
.29692 .24122 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24136 m
.29694 .24136 L
s
0 0 0 r
2.5 Mabswid
.29694 .24136 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2415 m
.29695 .2415 L
s
0 0 0 r
2.5 Mabswid
.29695 .2415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24163 m
.29696 .24163 L
s
0 0 0 r
2.5 Mabswid
.29696 .24163 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24177 m
.29697 .24177 L
s
0 0 0 r
2.5 Mabswid
.29697 .24177 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2419 m
.29698 .2419 L
s
0 0 0 r
2.5 Mabswid
.29698 .2419 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24204 m
.29699 .24204 L
s
0 0 0 r
2.5 Mabswid
.29699 .24204 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24218 m
.297 .24218 L
s
0 0 0 r
2.5 Mabswid
.297 .24218 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24231 m
.29701 .24231 L
s
0 0 0 r
2.5 Mabswid
.29701 .24231 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24245 m
.29702 .24245 L
s
0 0 0 r
2.5 Mabswid
.29702 .24245 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24259 m
.29703 .24259 L
s
0 0 0 r
2.5 Mabswid
.29703 .24259 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24272 m
.29704 .24272 L
s
0 0 0 r
2.5 Mabswid
.29704 .24272 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24286 m
.29705 .24286 L
s
0 0 0 r
2.5 Mabswid
.29705 .24286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24299 m
.29706 .24299 L
s
0 0 0 r
2.5 Mabswid
.29706 .24299 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24313 m
.29707 .24313 L
s
0 0 0 r
2.5 Mabswid
.29707 .24313 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24327 m
.29708 .24327 L
s
0 0 0 r
2.5 Mabswid
.29708 .24327 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2434 m
.29709 .2434 L
s
0 0 0 r
2.5 Mabswid
.29709 .2434 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24354 m
.29711 .24354 L
s
0 0 0 r
2.5 Mabswid
.29711 .24354 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24367 m
.29712 .24367 L
s
0 0 0 r
2.5 Mabswid
.29712 .24367 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24381 m
.29713 .24381 L
s
0 0 0 r
2.5 Mabswid
.29713 .24381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24395 m
.29714 .24395 L
s
0 0 0 r
2.5 Mabswid
.29714 .24395 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24408 m
.29715 .24408 L
s
0 0 0 r
2.5 Mabswid
.29715 .24408 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24422 m
.29716 .24422 L
s
0 0 0 r
2.5 Mabswid
.29716 .24422 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24435 m
.29717 .24435 L
s
0 0 0 r
2.5 Mabswid
.29717 .24435 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24449 m
.29718 .24449 L
s
0 0 0 r
2.5 Mabswid
.29718 .24449 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24463 m
.2972 .24463 L
s
0 0 0 r
2.5 Mabswid
.2972 .24463 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24476 m
.29721 .24476 L
s
0 0 0 r
2.5 Mabswid
.29721 .24476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2449 m
.29722 .2449 L
s
0 0 0 r
2.5 Mabswid
.29722 .2449 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24503 m
.29723 .24503 L
s
0 0 0 r
2.5 Mabswid
.29723 .24503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24517 m
.29724 .24517 L
s
0 0 0 r
2.5 Mabswid
.29724 .24517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24531 m
.29725 .24531 L
s
0 0 0 r
2.5 Mabswid
.29725 .24531 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24544 m
.29727 .24544 L
s
0 0 0 r
2.5 Mabswid
.29727 .24544 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24558 m
.29728 .24558 L
s
0 0 0 r
2.5 Mabswid
.29728 .24558 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24571 m
.29729 .24571 L
s
0 0 0 r
2.5 Mabswid
.29729 .24571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24585 m
.2973 .24585 L
s
0 0 0 r
2.5 Mabswid
.2973 .24585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24599 m
.29731 .24599 L
s
0 0 0 r
2.5 Mabswid
.29731 .24599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24612 m
.29732 .24612 L
s
0 0 0 r
2.5 Mabswid
.29732 .24612 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24626 m
.29734 .24626 L
s
0 0 0 r
2.5 Mabswid
.29734 .24626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24639 m
.29735 .24639 L
s
0 0 0 r
2.5 Mabswid
.29735 .24639 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24653 m
.29736 .24653 L
s
0 0 0 r
2.5 Mabswid
.29736 .24653 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24667 m
.29737 .24667 L
s
0 0 0 r
2.5 Mabswid
.29737 .24667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2468 m
.29739 .2468 L
s
0 0 0 r
2.5 Mabswid
.29739 .2468 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24694 m
.2974 .24694 L
s
0 0 0 r
2.5 Mabswid
.2974 .24694 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24707 m
.29741 .24707 L
s
0 0 0 r
2.5 Mabswid
.29741 .24707 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24721 m
.29742 .24721 L
s
0 0 0 r
2.5 Mabswid
.29742 .24721 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24735 m
.29744 .24735 L
s
0 0 0 r
2.5 Mabswid
.29744 .24735 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24748 m
.29745 .24748 L
s
0 0 0 r
2.5 Mabswid
.29745 .24748 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24762 m
.29746 .24762 L
s
0 0 0 r
2.5 Mabswid
.29746 .24762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24776 m
.29747 .24776 L
s
0 0 0 r
2.5 Mabswid
.29747 .24776 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24789 m
.29749 .24789 L
s
0 0 0 r
2.5 Mabswid
.29749 .24789 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24803 m
.2975 .24803 L
s
0 0 0 r
2.5 Mabswid
.2975 .24803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24816 m
.29751 .24816 L
s
0 0 0 r
2.5 Mabswid
.29751 .24816 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2483 m
.29752 .2483 L
s
0 0 0 r
2.5 Mabswid
.29752 .2483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24844 m
.29754 .24844 L
s
0 0 0 r
2.5 Mabswid
.29754 .24844 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24857 m
.29755 .24857 L
s
0 0 0 r
2.5 Mabswid
.29755 .24857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24871 m
.29756 .24871 L
s
0 0 0 r
2.5 Mabswid
.29756 .24871 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24884 m
.29758 .24884 L
s
0 0 0 r
2.5 Mabswid
.29758 .24884 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24898 m
.29759 .24898 L
s
0 0 0 r
2.5 Mabswid
.29759 .24898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24912 m
.2976 .24912 L
s
0 0 0 r
2.5 Mabswid
.2976 .24912 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24925 m
.29762 .24925 L
s
0 0 0 r
2.5 Mabswid
.29762 .24925 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24939 m
.29763 .24939 L
s
0 0 0 r
2.5 Mabswid
.29763 .24939 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24952 m
.29764 .24952 L
s
0 0 0 r
2.5 Mabswid
.29764 .24952 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24966 m
.29766 .24966 L
s
0 0 0 r
2.5 Mabswid
.29766 .24966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2498 m
.29767 .2498 L
s
0 0 0 r
2.5 Mabswid
.29767 .2498 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24993 m
.29768 .24993 L
s
0 0 0 r
2.5 Mabswid
.29768 .24993 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25007 m
.2977 .25007 L
s
0 0 0 r
2.5 Mabswid
.2977 .25007 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2502 m
.29771 .2502 L
s
0 0 0 r
2.5 Mabswid
.29771 .2502 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25034 m
.29772 .25034 L
s
0 0 0 r
2.5 Mabswid
.29772 .25034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25048 m
.29774 .25048 L
s
0 0 0 r
2.5 Mabswid
.29774 .25048 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25061 m
.29775 .25061 L
s
0 0 0 r
2.5 Mabswid
.29775 .25061 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25075 m
.29776 .25075 L
s
0 0 0 r
2.5 Mabswid
.29776 .25075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25088 m
.29778 .25088 L
s
0 0 0 r
2.5 Mabswid
.29778 .25088 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25102 m
.29779 .25102 L
s
0 0 0 r
2.5 Mabswid
.29779 .25102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25116 m
.29781 .25116 L
s
0 0 0 r
2.5 Mabswid
.29781 .25116 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25129 m
.29782 .25129 L
s
0 0 0 r
2.5 Mabswid
.29782 .25129 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25143 m
.29783 .25143 L
s
0 0 0 r
2.5 Mabswid
.29783 .25143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25156 m
.29785 .25156 L
s
0 0 0 r
2.5 Mabswid
.29785 .25156 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2517 m
.29786 .2517 L
s
0 0 0 r
2.5 Mabswid
.29786 .2517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25184 m
.29788 .25184 L
s
0 0 0 r
2.5 Mabswid
.29788 .25184 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25197 m
.29789 .25197 L
s
0 0 0 r
2.5 Mabswid
.29789 .25197 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25211 m
.29791 .25211 L
s
0 0 0 r
2.5 Mabswid
.29791 .25211 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25224 m
.29792 .25224 L
s
0 0 0 r
2.5 Mabswid
.29792 .25224 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25238 m
.29793 .25238 L
s
0 0 0 r
2.5 Mabswid
.29793 .25238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25252 m
.29795 .25252 L
s
0 0 0 r
2.5 Mabswid
.29795 .25252 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25265 m
.29796 .25265 L
s
0 0 0 r
2.5 Mabswid
.29796 .25265 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25279 m
.29798 .25279 L
s
0 0 0 r
2.5 Mabswid
.29798 .25279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25293 m
.29799 .25293 L
s
0 0 0 r
2.5 Mabswid
.29799 .25293 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25306 m
.29801 .25306 L
s
0 0 0 r
2.5 Mabswid
.29801 .25306 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2532 m
.29802 .2532 L
s
0 0 0 r
2.5 Mabswid
.29802 .2532 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25333 m
.29804 .25333 L
s
0 0 0 r
2.5 Mabswid
.29804 .25333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25347 m
.29805 .25347 L
s
0 0 0 r
2.5 Mabswid
.29805 .25347 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25361 m
.29807 .25361 L
s
0 0 0 r
2.5 Mabswid
.29807 .25361 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25374 m
.29808 .25374 L
s
0 0 0 r
2.5 Mabswid
.29808 .25374 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25388 m
.2981 .25388 L
s
0 0 0 r
2.5 Mabswid
.2981 .25388 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25401 m
.29811 .25401 L
s
0 0 0 r
2.5 Mabswid
.29811 .25401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25415 m
.29813 .25415 L
s
0 0 0 r
2.5 Mabswid
.29813 .25415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25429 m
.29814 .25429 L
s
0 0 0 r
2.5 Mabswid
.29814 .25429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25442 m
.29816 .25442 L
s
0 0 0 r
2.5 Mabswid
.29816 .25442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25456 m
.29817 .25456 L
s
0 0 0 r
2.5 Mabswid
.29817 .25456 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25469 m
.29819 .25469 L
s
0 0 0 r
2.5 Mabswid
.29819 .25469 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25483 m
.2982 .25483 L
s
0 0 0 r
2.5 Mabswid
.2982 .25483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25497 m
.29822 .25497 L
s
0 0 0 r
2.5 Mabswid
.29822 .25497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2551 m
.29823 .2551 L
s
0 0 0 r
2.5 Mabswid
.29823 .2551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25524 m
.29825 .25524 L
s
0 0 0 r
2.5 Mabswid
.29825 .25524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25537 m
.29826 .25537 L
s
0 0 0 r
2.5 Mabswid
.29826 .25537 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25551 m
.29828 .25551 L
s
0 0 0 r
2.5 Mabswid
.29828 .25551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25565 m
.2983 .25565 L
s
0 0 0 r
2.5 Mabswid
.2983 .25565 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25578 m
.29831 .25578 L
s
0 0 0 r
2.5 Mabswid
.29831 .25578 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25592 m
.29833 .25592 L
s
0 0 0 r
2.5 Mabswid
.29833 .25592 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25605 m
.29834 .25605 L
s
0 0 0 r
2.5 Mabswid
.29834 .25605 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25619 m
.29836 .25619 L
s
0 0 0 r
2.5 Mabswid
.29836 .25619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25633 m
.29837 .25633 L
s
0 0 0 r
2.5 Mabswid
.29837 .25633 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25646 m
.29839 .25646 L
s
0 0 0 r
2.5 Mabswid
.29839 .25646 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2566 m
.29841 .2566 L
s
0 0 0 r
2.5 Mabswid
.29841 .2566 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25673 m
.29842 .25673 L
s
0 0 0 r
2.5 Mabswid
.29842 .25673 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25687 m
.29844 .25687 L
s
0 0 0 r
2.5 Mabswid
.29844 .25687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25701 m
.29846 .25701 L
s
0 0 0 r
2.5 Mabswid
.29846 .25701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25714 m
.29847 .25714 L
s
0 0 0 r
2.5 Mabswid
.29847 .25714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25728 m
.29849 .25728 L
s
0 0 0 r
2.5 Mabswid
.29849 .25728 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25741 m
.2985 .25741 L
s
0 0 0 r
2.5 Mabswid
.2985 .25741 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25755 m
.29852 .25755 L
s
0 0 0 r
2.5 Mabswid
.29852 .25755 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25769 m
.29854 .25769 L
s
0 0 0 r
2.5 Mabswid
.29854 .25769 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25782 m
.29855 .25782 L
s
0 0 0 r
2.5 Mabswid
.29855 .25782 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25796 m
.29857 .25796 L
s
0 0 0 r
2.5 Mabswid
.29857 .25796 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2581 m
.29859 .2581 L
s
0 0 0 r
2.5 Mabswid
.29859 .2581 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25823 m
.2986 .25823 L
s
0 0 0 r
2.5 Mabswid
.2986 .25823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25837 m
.29862 .25837 L
s
0 0 0 r
2.5 Mabswid
.29862 .25837 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2585 m
.29864 .2585 L
s
0 0 0 r
2.5 Mabswid
.29864 .2585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25864 m
.29865 .25864 L
s
0 0 0 r
2.5 Mabswid
.29865 .25864 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25878 m
.29867 .25878 L
s
0 0 0 r
2.5 Mabswid
.29867 .25878 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25891 m
.29869 .25891 L
s
0 0 0 r
2.5 Mabswid
.29869 .25891 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25905 m
.2987 .25905 L
s
0 0 0 r
2.5 Mabswid
.2987 .25905 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25918 m
.29872 .25918 L
s
0 0 0 r
2.5 Mabswid
.29872 .25918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25932 m
.29874 .25932 L
s
0 0 0 r
2.5 Mabswid
.29874 .25932 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25946 m
.29876 .25946 L
s
0 0 0 r
2.5 Mabswid
.29876 .25946 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25959 m
.29877 .25959 L
s
0 0 0 r
2.5 Mabswid
.29877 .25959 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25973 m
.29879 .25973 L
s
0 0 0 r
2.5 Mabswid
.29879 .25973 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25986 m
.29881 .25986 L
s
0 0 0 r
2.5 Mabswid
.29881 .25986 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26 m
.29882 .26 L
s
0 0 0 r
2.5 Mabswid
.29882 .26 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26014 m
.29884 .26014 L
s
0 0 0 r
2.5 Mabswid
.29884 .26014 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26027 m
.29886 .26027 L
s
0 0 0 r
2.5 Mabswid
.29886 .26027 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26041 m
.29888 .26041 L
s
0 0 0 r
2.5 Mabswid
.29888 .26041 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26054 m
.29889 .26054 L
s
0 0 0 r
2.5 Mabswid
.29889 .26054 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26068 m
.29891 .26068 L
s
0 0 0 r
2.5 Mabswid
.29891 .26068 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26082 m
.29893 .26082 L
s
0 0 0 r
2.5 Mabswid
.29893 .26082 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26095 m
.29895 .26095 L
s
0 0 0 r
2.5 Mabswid
.29895 .26095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26109 m
.29897 .26109 L
s
0 0 0 r
2.5 Mabswid
.29897 .26109 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26122 m
.29898 .26122 L
s
0 0 0 r
2.5 Mabswid
.29898 .26122 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26136 m
.299 .26136 L
s
0 0 0 r
2.5 Mabswid
.299 .26136 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2615 m
.29902 .2615 L
s
0 0 0 r
2.5 Mabswid
.29902 .2615 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26163 m
.29904 .26163 L
s
0 0 0 r
2.5 Mabswid
.29904 .26163 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26177 m
.29905 .26177 L
s
0 0 0 r
2.5 Mabswid
.29905 .26177 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2619 m
.29907 .2619 L
s
0 0 0 r
2.5 Mabswid
.29907 .2619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26204 m
.29909 .26204 L
s
0 0 0 r
2.5 Mabswid
.29909 .26204 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26218 m
.29911 .26218 L
s
0 0 0 r
2.5 Mabswid
.29911 .26218 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26231 m
.29913 .26231 L
s
0 0 0 r
2.5 Mabswid
.29913 .26231 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26245 m
.29915 .26245 L
s
0 0 0 r
2.5 Mabswid
.29915 .26245 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26259 m
.29916 .26259 L
s
0 0 0 r
2.5 Mabswid
.29916 .26259 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26272 m
.29918 .26272 L
s
0 0 0 r
2.5 Mabswid
.29918 .26272 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26286 m
.2992 .26286 L
s
0 0 0 r
2.5 Mabswid
.2992 .26286 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26299 m
.29922 .26299 L
s
0 0 0 r
2.5 Mabswid
.29922 .26299 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26313 m
.29924 .26313 L
s
0 0 0 r
2.5 Mabswid
.29924 .26313 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26327 m
.29926 .26327 L
s
0 0 0 r
2.5 Mabswid
.29926 .26327 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2634 m
.29928 .2634 L
s
0 0 0 r
2.5 Mabswid
.29928 .2634 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26354 m
.29929 .26354 L
s
0 0 0 r
2.5 Mabswid
.29929 .26354 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26367 m
.29931 .26367 L
s
0 0 0 r
2.5 Mabswid
.29931 .26367 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26381 m
.29933 .26381 L
s
0 0 0 r
2.5 Mabswid
.29933 .26381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26395 m
.29935 .26395 L
s
0 0 0 r
2.5 Mabswid
.29935 .26395 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26408 m
.29937 .26408 L
s
0 0 0 r
2.5 Mabswid
.29937 .26408 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26422 m
.29939 .26422 L
s
0 0 0 r
2.5 Mabswid
.29939 .26422 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26435 m
.29941 .26435 L
s
0 0 0 r
2.5 Mabswid
.29941 .26435 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26449 m
.29943 .26449 L
s
0 0 0 r
2.5 Mabswid
.29943 .26449 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26463 m
.29945 .26463 L
s
0 0 0 r
2.5 Mabswid
.29945 .26463 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26476 m
.29946 .26476 L
s
0 0 0 r
2.5 Mabswid
.29946 .26476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2649 m
.29948 .2649 L
s
0 0 0 r
2.5 Mabswid
.29948 .2649 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26503 m
.2995 .26503 L
s
0 0 0 r
2.5 Mabswid
.2995 .26503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26517 m
.29952 .26517 L
s
0 0 0 r
2.5 Mabswid
.29952 .26517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26531 m
.29954 .26531 L
s
0 0 0 r
2.5 Mabswid
.29954 .26531 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26544 m
.29956 .26544 L
s
0 0 0 r
2.5 Mabswid
.29956 .26544 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26558 m
.29958 .26558 L
s
0 0 0 r
2.5 Mabswid
.29958 .26558 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26571 m
.2996 .26571 L
s
0 0 0 r
2.5 Mabswid
.2996 .26571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26585 m
.29962 .26585 L
s
0 0 0 r
2.5 Mabswid
.29962 .26585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26599 m
.29964 .26599 L
s
0 0 0 r
2.5 Mabswid
.29964 .26599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26612 m
.29966 .26612 L
s
0 0 0 r
2.5 Mabswid
.29966 .26612 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26626 m
.29968 .26626 L
s
0 0 0 r
2.5 Mabswid
.29968 .26626 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26639 m
.2997 .26639 L
s
0 0 0 r
2.5 Mabswid
.2997 .26639 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26653 m
.29972 .26653 L
s
0 0 0 r
2.5 Mabswid
.29972 .26653 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26667 m
.29974 .26667 L
s
0 0 0 r
2.5 Mabswid
.29974 .26667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2668 m
.29976 .2668 L
s
0 0 0 r
2.5 Mabswid
.29976 .2668 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26694 m
.29978 .26694 L
s
0 0 0 r
2.5 Mabswid
.29978 .26694 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26707 m
.2998 .26707 L
s
0 0 0 r
2.5 Mabswid
.2998 .26707 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26721 m
.29982 .26721 L
s
0 0 0 r
2.5 Mabswid
.29982 .26721 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26735 m
.29984 .26735 L
s
0 0 0 r
2.5 Mabswid
.29984 .26735 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26748 m
.29986 .26748 L
s
0 0 0 r
2.5 Mabswid
.29986 .26748 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26762 m
.29988 .26762 L
s
0 0 0 r
2.5 Mabswid
.29988 .26762 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26776 m
.2999 .26776 L
s
0 0 0 r
2.5 Mabswid
.2999 .26776 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26789 m
.29992 .26789 L
s
0 0 0 r
2.5 Mabswid
.29992 .26789 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26803 m
.29994 .26803 L
s
0 0 0 r
2.5 Mabswid
.29994 .26803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26816 m
.29996 .26816 L
s
0 0 0 r
2.5 Mabswid
.29996 .26816 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2683 m
.29998 .2683 L
s
0 0 0 r
2.5 Mabswid
.29998 .2683 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26844 m
.3 .26844 L
s
0 0 0 r
2.5 Mabswid
.3 .26844 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26857 m
.30002 .26857 L
s
0 0 0 r
2.5 Mabswid
.30002 .26857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26871 m
.30004 .26871 L
s
0 0 0 r
2.5 Mabswid
.30004 .26871 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26884 m
.30006 .26884 L
s
0 0 0 r
2.5 Mabswid
.30006 .26884 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26898 m
.30009 .26898 L
s
0 0 0 r
2.5 Mabswid
.30009 .26898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26912 m
.30011 .26912 L
s
0 0 0 r
2.5 Mabswid
.30011 .26912 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26925 m
.30013 .26925 L
s
0 0 0 r
2.5 Mabswid
.30013 .26925 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26939 m
.30015 .26939 L
s
0 0 0 r
2.5 Mabswid
.30015 .26939 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26952 m
.30017 .26952 L
s
0 0 0 r
2.5 Mabswid
.30017 .26952 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26966 m
.30019 .26966 L
s
0 0 0 r
2.5 Mabswid
.30019 .26966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2698 m
.30021 .2698 L
s
0 0 0 r
2.5 Mabswid
.30021 .2698 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26993 m
.30023 .26993 L
s
0 0 0 r
2.5 Mabswid
.30023 .26993 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27007 m
.30025 .27007 L
s
0 0 0 r
2.5 Mabswid
.30025 .27007 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2702 m
.30028 .2702 L
s
0 0 0 r
2.5 Mabswid
.30028 .2702 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27034 m
.3003 .27034 L
s
0 0 0 r
2.5 Mabswid
.3003 .27034 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27048 m
.30032 .27048 L
s
0 0 0 r
2.5 Mabswid
.30032 .27048 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27061 m
.30034 .27061 L
s
0 0 0 r
2.5 Mabswid
.30034 .27061 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27075 m
.30036 .27075 L
s
0 0 0 r
2.5 Mabswid
.30036 .27075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27088 m
.30038 .27088 L
s
0 0 0 r
2.5 Mabswid
.30038 .27088 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27102 m
.3004 .27102 L
s
0 0 0 r
2.5 Mabswid
.3004 .27102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27116 m
.30043 .27116 L
s
0 0 0 r
2.5 Mabswid
.30043 .27116 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27129 m
.30045 .27129 L
s
0 0 0 r
2.5 Mabswid
.30045 .27129 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27143 m
.30047 .27143 L
s
0 0 0 r
2.5 Mabswid
.30047 .27143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27156 m
.30049 .27156 L
s
0 0 0 r
2.5 Mabswid
.30049 .27156 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2717 m
.30051 .2717 L
s
0 0 0 r
2.5 Mabswid
.30051 .2717 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27184 m
.30054 .27184 L
s
0 0 0 r
2.5 Mabswid
.30054 .27184 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27197 m
.30056 .27197 L
s
0 0 0 r
2.5 Mabswid
.30056 .27197 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27211 m
.30058 .27211 L
s
0 0 0 r
2.5 Mabswid
.30058 .27211 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27224 m
.3006 .27224 L
s
0 0 0 r
2.5 Mabswid
.3006 .27224 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27238 m
.30062 .27238 L
s
0 0 0 r
2.5 Mabswid
.30062 .27238 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27252 m
.30065 .27252 L
s
0 0 0 r
2.5 Mabswid
.30065 .27252 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27265 m
.30067 .27265 L
s
0 0 0 r
2.5 Mabswid
.30067 .27265 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27279 m
.30069 .27279 L
s
0 0 0 r
2.5 Mabswid
.30069 .27279 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27293 m
.30071 .27293 L
s
0 0 0 r
2.5 Mabswid
.30071 .27293 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27306 m
.30074 .27306 L
s
0 0 0 r
2.5 Mabswid
.30074 .27306 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2732 m
.30076 .2732 L
s
0 0 0 r
2.5 Mabswid
.30076 .2732 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27333 m
.30078 .27333 L
s
0 0 0 r
2.5 Mabswid
.30078 .27333 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27347 m
.3008 .27347 L
s
0 0 0 r
2.5 Mabswid
.3008 .27347 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27361 m
.30083 .27361 L
s
0 0 0 r
2.5 Mabswid
.30083 .27361 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27374 m
.30085 .27374 L
s
0 0 0 r
2.5 Mabswid
.30085 .27374 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27388 m
.30087 .27388 L
s
0 0 0 r
2.5 Mabswid
.30087 .27388 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27401 m
.30089 .27401 L
s
0 0 0 r
2.5 Mabswid
.30089 .27401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27415 m
.30092 .27415 L
s
0 0 0 r
2.5 Mabswid
.30092 .27415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27429 m
.30094 .27429 L
s
0 0 0 r
2.5 Mabswid
.30094 .27429 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27442 m
.30096 .27442 L
s
0 0 0 r
2.5 Mabswid
.30096 .27442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27456 m
.30099 .27456 L
s
0 0 0 r
2.5 Mabswid
.30099 .27456 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27469 m
.30101 .27469 L
s
0 0 0 r
2.5 Mabswid
.30101 .27469 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27483 m
.30103 .27483 L
s
0 0 0 r
2.5 Mabswid
.30103 .27483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27497 m
.30105 .27497 L
s
0 0 0 r
2.5 Mabswid
.30105 .27497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2751 m
.30108 .2751 L
s
0 0 0 r
2.5 Mabswid
.30108 .2751 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27524 m
.3011 .27524 L
s
0 0 0 r
2.5 Mabswid
.3011 .27524 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27537 m
.30112 .27537 L
s
0 0 0 r
2.5 Mabswid
.30112 .27537 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27551 m
.30115 .27551 L
s
0 0 0 r
2.5 Mabswid
.30115 .27551 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27565 m
.30117 .27565 L
s
0 0 0 r
2.5 Mabswid
.30117 .27565 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27578 m
.30119 .27578 L
s
0 0 0 r
2.5 Mabswid
.30119 .27578 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27592 m
.30122 .27592 L
s
0 0 0 r
2.5 Mabswid
.30122 .27592 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27605 m
.30124 .27605 L
s
0 0 0 r
2.5 Mabswid
.30124 .27605 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27619 m
.30127 .27619 L
s
0 0 0 r
2.5 Mabswid
.30127 .27619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27633 m
.30129 .27633 L
s
0 0 0 r
2.5 Mabswid
.30129 .27633 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27646 m
.30131 .27646 L
s
0 0 0 r
2.5 Mabswid
.30131 .27646 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2766 m
.30134 .2766 L
s
0 0 0 r
2.5 Mabswid
.30134 .2766 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27673 m
.30136 .27673 L
s
0 0 0 r
2.5 Mabswid
.30136 .27673 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27687 m
.30138 .27687 L
s
0 0 0 r
2.5 Mabswid
.30138 .27687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27701 m
.30141 .27701 L
s
0 0 0 r
2.5 Mabswid
.30141 .27701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27714 m
.30143 .27714 L
s
0 0 0 r
2.5 Mabswid
.30143 .27714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27728 m
.30146 .27728 L
s
0 0 0 r
2.5 Mabswid
.30146 .27728 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27741 m
.30148 .27741 L
s
0 0 0 r
2.5 Mabswid
.30148 .27741 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27755 m
.30151 .27755 L
s
0 0 0 r
2.5 Mabswid
.30151 .27755 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27769 m
.30153 .27769 L
s
0 0 0 r
2.5 Mabswid
.30153 .27769 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27782 m
.30155 .27782 L
s
0 0 0 r
2.5 Mabswid
.30155 .27782 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27796 m
.30158 .27796 L
s
0 0 0 r
2.5 Mabswid
.30158 .27796 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2781 m
.3016 .2781 L
s
0 0 0 r
2.5 Mabswid
.3016 .2781 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27823 m
.30163 .27823 L
s
0 0 0 r
2.5 Mabswid
.30163 .27823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27837 m
.30165 .27837 L
s
0 0 0 r
2.5 Mabswid
.30165 .27837 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2785 m
.30168 .2785 L
s
0 0 0 r
2.5 Mabswid
.30168 .2785 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27864 m
.3017 .27864 L
s
0 0 0 r
2.5 Mabswid
.3017 .27864 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27878 m
.30173 .27878 L
s
0 0 0 r
2.5 Mabswid
.30173 .27878 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27891 m
.30175 .27891 L
s
0 0 0 r
2.5 Mabswid
.30175 .27891 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27905 m
.30177 .27905 L
s
0 0 0 r
2.5 Mabswid
.30177 .27905 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27918 m
.3018 .27918 L
s
0 0 0 r
2.5 Mabswid
.3018 .27918 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27932 m
.30182 .27932 L
s
0 0 0 r
2.5 Mabswid
.30182 .27932 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27946 m
.30185 .27946 L
s
0 0 0 r
2.5 Mabswid
.30185 .27946 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27959 m
.30187 .27959 L
s
0 0 0 r
2.5 Mabswid
.30187 .27959 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27973 m
.3019 .27973 L
s
0 0 0 r
2.5 Mabswid
.3019 .27973 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27986 m
.30192 .27986 L
s
0 0 0 r
2.5 Mabswid
.30192 .27986 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28 m
.30195 .28 L
s
0 0 0 r
2.5 Mabswid
.30195 .28 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28014 m
.30198 .28014 L
s
0 0 0 r
2.5 Mabswid
.30198 .28014 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28027 m
.302 .28027 L
s
0 0 0 r
2.5 Mabswid
.302 .28027 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28041 m
.30203 .28041 L
s
0 0 0 r
2.5 Mabswid
.30203 .28041 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28054 m
.30205 .28054 L
s
0 0 0 r
2.5 Mabswid
.30205 .28054 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28068 m
.30208 .28068 L
s
0 0 0 r
2.5 Mabswid
.30208 .28068 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28082 m
.3021 .28082 L
s
0 0 0 r
2.5 Mabswid
.3021 .28082 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28095 m
.30213 .28095 L
s
0 0 0 r
2.5 Mabswid
.30213 .28095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28109 m
.30215 .28109 L
s
0 0 0 r
2.5 Mabswid
.30215 .28109 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28122 m
.30218 .28122 L
s
0 0 0 r
2.5 Mabswid
.30218 .28122 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28136 m
.3022 .28136 L
s
0 0 0 r
2.5 Mabswid
.3022 .28136 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2815 m
.30223 .2815 L
s
0 0 0 r
2.5 Mabswid
.30223 .2815 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28163 m
.30226 .28163 L
s
0 0 0 r
2.5 Mabswid
.30226 .28163 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28177 m
.30228 .28177 L
s
0 0 0 r
2.5 Mabswid
.30228 .28177 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .2819 m
.30231 .2819 L
s
0 0 0 r
2.5 Mabswid
.30231 .2819 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28204 m
.30233 .28204 L
s
0 0 0 r
2.5 Mabswid
.30233 .28204 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28218 m
.30236 .28218 L
s
0 0 0 r
2.5 Mabswid
.30236 .28218 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28231 m
.30239 .28231 L
s
0 0 0 r
2.5 Mabswid
.30239 .28231 Mdot
.039 .916 .04 r
.5 Mabswid
.30239 .14626 m
.43112 .15446 L
s
0 0 0 r
2.5 Mabswid
.43112 .15446 Mdot
.039 .916 .04 r
.5 Mabswid
.30236 .14639 m
.43112 .15458 L
s
0 0 0 r
2.5 Mabswid
.43112 .15458 Mdot
.039 .916 .04 r
.5 Mabswid
.30233 .14653 m
.43113 .1547 L
s
0 0 0 r
2.5 Mabswid
.43113 .1547 Mdot
.039 .916 .04 r
.5 Mabswid
.30231 .14667 m
.43113 .15482 L
s
0 0 0 r
2.5 Mabswid
.43113 .15482 Mdot
.039 .916 .04 r
.5 Mabswid
.30228 .1468 m
.43113 .15494 L
s
0 0 0 r
2.5 Mabswid
.43113 .15494 Mdot
.039 .916 .04 r
.5 Mabswid
.30226 .14694 m
.43114 .15506 L
s
0 0 0 r
2.5 Mabswid
.43114 .15506 Mdot
.039 .916 .04 r
.5 Mabswid
.30223 .14707 m
.43114 .15519 L
s
0 0 0 r
2.5 Mabswid
.43114 .15519 Mdot
.039 .916 .04 r
.5 Mabswid
.3022 .14721 m
.43114 .15531 L
s
0 0 0 r
2.5 Mabswid
.43114 .15531 Mdot
.039 .916 .04 r
.5 Mabswid
.30218 .14735 m
.43115 .15543 L
s
0 0 0 r
2.5 Mabswid
.43115 .15543 Mdot
.039 .916 .04 r
.5 Mabswid
.30215 .14748 m
.43115 .15555 L
s
0 0 0 r
2.5 Mabswid
.43115 .15555 Mdot
.039 .916 .04 r
.5 Mabswid
.30213 .14762 m
.43115 .15567 L
s
0 0 0 r
2.5 Mabswid
.43115 .15567 Mdot
.039 .916 .04 r
.5 Mabswid
.3021 .14776 m
.43116 .15579 L
s
0 0 0 r
2.5 Mabswid
.43116 .15579 Mdot
.039 .916 .04 r
.5 Mabswid
.30208 .14789 m
.43116 .15591 L
s
0 0 0 r
2.5 Mabswid
.43116 .15591 Mdot
.039 .916 .04 r
.5 Mabswid
.30205 .14803 m
.43116 .15603 L
s
0 0 0 r
2.5 Mabswid
.43116 .15603 Mdot
.039 .916 .04 r
.5 Mabswid
.30203 .14816 m
.43117 .15615 L
s
0 0 0 r
2.5 Mabswid
.43117 .15615 Mdot
.039 .916 .04 r
.5 Mabswid
.302 .1483 m
.43117 .15627 L
s
0 0 0 r
2.5 Mabswid
.43117 .15627 Mdot
.039 .916 .04 r
.5 Mabswid
.30198 .14844 m
.43117 .15639 L
s
0 0 0 r
2.5 Mabswid
.43117 .15639 Mdot
.039 .916 .04 r
.5 Mabswid
.30195 .14857 m
.43118 .15652 L
s
0 0 0 r
2.5 Mabswid
.43118 .15652 Mdot
.039 .916 .04 r
.5 Mabswid
.30192 .14871 m
.43118 .15664 L
s
0 0 0 r
2.5 Mabswid
.43118 .15664 Mdot
.039 .916 .04 r
.5 Mabswid
.3019 .14884 m
.43118 .15676 L
s
0 0 0 r
2.5 Mabswid
.43118 .15676 Mdot
.039 .916 .04 r
.5 Mabswid
.30187 .14898 m
.43119 .15688 L
s
0 0 0 r
2.5 Mabswid
.43119 .15688 Mdot
.039 .916 .04 r
.5 Mabswid
.30185 .14912 m
.43119 .157 L
s
0 0 0 r
2.5 Mabswid
.43119 .157 Mdot
.039 .916 .04 r
.5 Mabswid
.30182 .14925 m
.43119 .15712 L
s
0 0 0 r
2.5 Mabswid
.43119 .15712 Mdot
.039 .916 .04 r
.5 Mabswid
.3018 .14939 m
.4312 .15724 L
s
0 0 0 r
2.5 Mabswid
.4312 .15724 Mdot
.039 .916 .04 r
.5 Mabswid
.30177 .14952 m
.4312 .15736 L
s
0 0 0 r
2.5 Mabswid
.4312 .15736 Mdot
.039 .916 .04 r
.5 Mabswid
.30175 .14966 m
.4312 .15748 L
s
0 0 0 r
2.5 Mabswid
.4312 .15748 Mdot
.039 .916 .04 r
.5 Mabswid
.30173 .1498 m
.43121 .1576 L
s
0 0 0 r
2.5 Mabswid
.43121 .1576 Mdot
.039 .916 .04 r
.5 Mabswid
.3017 .14993 m
.43121 .15772 L
s
0 0 0 r
2.5 Mabswid
.43121 .15772 Mdot
.039 .916 .04 r
.5 Mabswid
.30168 .15007 m
.43121 .15785 L
s
0 0 0 r
2.5 Mabswid
.43121 .15785 Mdot
.039 .916 .04 r
.5 Mabswid
.30165 .1502 m
.43122 .15797 L
s
0 0 0 r
2.5 Mabswid
.43122 .15797 Mdot
.039 .916 .04 r
.5 Mabswid
.30163 .15034 m
.43122 .15809 L
s
0 0 0 r
2.5 Mabswid
.43122 .15809 Mdot
.039 .916 .04 r
.5 Mabswid
.3016 .15048 m
.43122 .15821 L
s
0 0 0 r
2.5 Mabswid
.43122 .15821 Mdot
.039 .916 .04 r
.5 Mabswid
.30158 .15061 m
.43123 .15833 L
s
0 0 0 r
2.5 Mabswid
.43123 .15833 Mdot
.039 .916 .04 r
.5 Mabswid
.30155 .15075 m
.43123 .15845 L
s
0 0 0 r
2.5 Mabswid
.43123 .15845 Mdot
.039 .916 .04 r
.5 Mabswid
.30153 .15088 m
.43123 .15857 L
s
0 0 0 r
2.5 Mabswid
.43123 .15857 Mdot
.039 .916 .04 r
.5 Mabswid
.30151 .15102 m
.43124 .15869 L
s
0 0 0 r
2.5 Mabswid
.43124 .15869 Mdot
.039 .916 .04 r
.5 Mabswid
.30148 .15116 m
.43124 .15881 L
s
0 0 0 r
2.5 Mabswid
.43124 .15881 Mdot
.039 .916 .04 r
.5 Mabswid
.30146 .15129 m
.43124 .15893 L
s
0 0 0 r
2.5 Mabswid
.43124 .15893 Mdot
.039 .916 .04 r
.5 Mabswid
.30143 .15143 m
.43125 .15905 L
s
0 0 0 r
2.5 Mabswid
.43125 .15905 Mdot
.039 .916 .04 r
.5 Mabswid
.30141 .15156 m
.43125 .15917 L
s
0 0 0 r
2.5 Mabswid
.43125 .15917 Mdot
.039 .916 .04 r
.5 Mabswid
.30138 .1517 m
.43125 .15929 L
s
0 0 0 r
2.5 Mabswid
.43125 .15929 Mdot
.039 .916 .04 r
.5 Mabswid
.30136 .15184 m
.43126 .15942 L
s
0 0 0 r
2.5 Mabswid
.43126 .15942 Mdot
.039 .916 .04 r
.5 Mabswid
.30134 .15197 m
.43126 .15954 L
s
0 0 0 r
2.5 Mabswid
.43126 .15954 Mdot
.039 .916 .04 r
.5 Mabswid
.30131 .15211 m
.43126 .15966 L
s
0 0 0 r
2.5 Mabswid
.43126 .15966 Mdot
.039 .916 .04 r
.5 Mabswid
.30129 .15224 m
.43126 .15978 L
s
0 0 0 r
2.5 Mabswid
.43126 .15978 Mdot
.039 .916 .04 r
.5 Mabswid
.30127 .15238 m
.43127 .1599 L
s
0 0 0 r
2.5 Mabswid
.43127 .1599 Mdot
.039 .916 .04 r
.5 Mabswid
.30124 .15252 m
.43127 .16002 L
s
0 0 0 r
2.5 Mabswid
.43127 .16002 Mdot
.039 .916 .04 r
.5 Mabswid
.30122 .15265 m
.43127 .16014 L
s
0 0 0 r
2.5 Mabswid
.43127 .16014 Mdot
.039 .916 .04 r
.5 Mabswid
.30119 .15279 m
.43128 .16026 L
s
0 0 0 r
2.5 Mabswid
.43128 .16026 Mdot
.039 .916 .04 r
.5 Mabswid
.30117 .15293 m
.43128 .16038 L
s
0 0 0 r
2.5 Mabswid
.43128 .16038 Mdot
.039 .916 .04 r
.5 Mabswid
.30115 .15306 m
.43128 .1605 L
s
0 0 0 r
2.5 Mabswid
.43128 .1605 Mdot
.039 .916 .04 r
.5 Mabswid
.30112 .1532 m
.43129 .16062 L
s
0 0 0 r
2.5 Mabswid
.43129 .16062 Mdot
.039 .916 .04 r
.5 Mabswid
.3011 .15333 m
.43129 .16074 L
s
0 0 0 r
2.5 Mabswid
.43129 .16074 Mdot
.039 .916 .04 r
.5 Mabswid
.30108 .15347 m
.43129 .16086 L
s
0 0 0 r
2.5 Mabswid
.43129 .16086 Mdot
.039 .916 .04 r
.5 Mabswid
.30105 .15361 m
.4313 .16098 L
s
0 0 0 r
2.5 Mabswid
.4313 .16098 Mdot
.039 .916 .04 r
.5 Mabswid
.30103 .15374 m
.4313 .1611 L
s
0 0 0 r
2.5 Mabswid
.4313 .1611 Mdot
.039 .916 .04 r
.5 Mabswid
.30101 .15388 m
.4313 .16123 L
s
0 0 0 r
2.5 Mabswid
.4313 .16123 Mdot
.039 .916 .04 r
.5 Mabswid
.30099 .15401 m
.4313 .16135 L
s
0 0 0 r
2.5 Mabswid
.4313 .16135 Mdot
.039 .916 .04 r
.5 Mabswid
.30096 .15415 m
.43131 .16147 L
s
0 0 0 r
2.5 Mabswid
.43131 .16147 Mdot
.039 .916 .04 r
.5 Mabswid
.30094 .15429 m
.43131 .16159 L
s
0 0 0 r
2.5 Mabswid
.43131 .16159 Mdot
.039 .916 .04 r
.5 Mabswid
.30092 .15442 m
.43131 .16171 L
s
0 0 0 r
2.5 Mabswid
.43131 .16171 Mdot
.039 .916 .04 r
.5 Mabswid
.30089 .15456 m
.43132 .16183 L
s
0 0 0 r
2.5 Mabswid
.43132 .16183 Mdot
.039 .916 .04 r
.5 Mabswid
.30087 .15469 m
.43132 .16195 L
s
0 0 0 r
2.5 Mabswid
.43132 .16195 Mdot
.039 .916 .04 r
.5 Mabswid
.30085 .15483 m
.43132 .16207 L
s
0 0 0 r
2.5 Mabswid
.43132 .16207 Mdot
.039 .916 .04 r
.5 Mabswid
.30083 .15497 m
.43133 .16219 L
s
0 0 0 r
2.5 Mabswid
.43133 .16219 Mdot
.039 .916 .04 r
.5 Mabswid
.3008 .1551 m
.43133 .16231 L
s
0 0 0 r
2.5 Mabswid
.43133 .16231 Mdot
.039 .916 .04 r
.5 Mabswid
.30078 .15524 m
.43133 .16243 L
s
0 0 0 r
2.5 Mabswid
.43133 .16243 Mdot
.039 .916 .04 r
.5 Mabswid
.30076 .15537 m
.43133 .16255 L
s
0 0 0 r
2.5 Mabswid
.43133 .16255 Mdot
.039 .916 .04 r
.5 Mabswid
.30074 .15551 m
.43134 .16267 L
s
0 0 0 r
2.5 Mabswid
.43134 .16267 Mdot
.039 .916 .04 r
.5 Mabswid
.30071 .15565 m
.43134 .16279 L
s
0 0 0 r
2.5 Mabswid
.43134 .16279 Mdot
.039 .916 .04 r
.5 Mabswid
.30069 .15578 m
.43134 .16291 L
s
0 0 0 r
2.5 Mabswid
.43134 .16291 Mdot
.039 .916 .04 r
.5 Mabswid
.30067 .15592 m
.43135 .16303 L
s
0 0 0 r
2.5 Mabswid
.43135 .16303 Mdot
.039 .916 .04 r
.5 Mabswid
.30065 .15605 m
.43135 .16315 L
s
0 0 0 r
2.5 Mabswid
.43135 .16315 Mdot
.039 .916 .04 r
.5 Mabswid
.30062 .15619 m
.43135 .16327 L
s
0 0 0 r
2.5 Mabswid
.43135 .16327 Mdot
.039 .916 .04 r
.5 Mabswid
.3006 .15633 m
.43136 .1634 L
s
0 0 0 r
2.5 Mabswid
.43136 .1634 Mdot
.039 .916 .04 r
.5 Mabswid
.30058 .15646 m
.43136 .16352 L
s
0 0 0 r
2.5 Mabswid
.43136 .16352 Mdot
.039 .916 .04 r
.5 Mabswid
.30056 .1566 m
.43136 .16364 L
s
0 0 0 r
2.5 Mabswid
.43136 .16364 Mdot
.039 .916 .04 r
.5 Mabswid
.30054 .15673 m
.43136 .16376 L
s
0 0 0 r
2.5 Mabswid
.43136 .16376 Mdot
.039 .916 .04 r
.5 Mabswid
.30051 .15687 m
.43137 .16388 L
s
0 0 0 r
2.5 Mabswid
.43137 .16388 Mdot
.039 .916 .04 r
.5 Mabswid
.30049 .15701 m
.43137 .164 L
s
0 0 0 r
2.5 Mabswid
.43137 .164 Mdot
.039 .916 .04 r
.5 Mabswid
.30047 .15714 m
.43137 .16412 L
s
0 0 0 r
2.5 Mabswid
.43137 .16412 Mdot
.039 .916 .04 r
.5 Mabswid
.30045 .15728 m
.43138 .16424 L
s
0 0 0 r
2.5 Mabswid
.43138 .16424 Mdot
.039 .916 .04 r
.5 Mabswid
.30043 .15741 m
.43138 .16436 L
s
0 0 0 r
2.5 Mabswid
.43138 .16436 Mdot
.039 .916 .04 r
.5 Mabswid
.3004 .15755 m
.43138 .16448 L
s
0 0 0 r
2.5 Mabswid
.43138 .16448 Mdot
.039 .916 .04 r
.5 Mabswid
.30038 .15769 m
.43138 .1646 L
s
0 0 0 r
2.5 Mabswid
.43138 .1646 Mdot
.039 .916 .04 r
.5 Mabswid
.30036 .15782 m
.43139 .16472 L
s
0 0 0 r
2.5 Mabswid
.43139 .16472 Mdot
.039 .916 .04 r
.5 Mabswid
.30034 .15796 m
.43139 .16484 L
s
0 0 0 r
2.5 Mabswid
.43139 .16484 Mdot
.039 .916 .04 r
.5 Mabswid
.30032 .1581 m
.43139 .16496 L
s
0 0 0 r
2.5 Mabswid
.43139 .16496 Mdot
.039 .916 .04 r
.5 Mabswid
.3003 .15823 m
.4314 .16508 L
s
0 0 0 r
2.5 Mabswid
.4314 .16508 Mdot
.039 .916 .04 r
.5 Mabswid
.30028 .15837 m
.4314 .1652 L
s
0 0 0 r
2.5 Mabswid
.4314 .1652 Mdot
.039 .916 .04 r
.5 Mabswid
.30025 .1585 m
.4314 .16532 L
s
0 0 0 r
2.5 Mabswid
.4314 .16532 Mdot
.039 .916 .04 r
.5 Mabswid
.30023 .15864 m
.4314 .16544 L
s
0 0 0 r
2.5 Mabswid
.4314 .16544 Mdot
.039 .916 .04 r
.5 Mabswid
.30021 .15878 m
.43141 .16556 L
s
0 0 0 r
2.5 Mabswid
.43141 .16556 Mdot
.039 .916 .04 r
.5 Mabswid
.30019 .15891 m
.43141 .16568 L
s
0 0 0 r
2.5 Mabswid
.43141 .16568 Mdot
.039 .916 .04 r
.5 Mabswid
.30017 .15905 m
.43141 .1658 L
s
0 0 0 r
2.5 Mabswid
.43141 .1658 Mdot
.039 .916 .04 r
.5 Mabswid
.30015 .15918 m
.43142 .16592 L
s
0 0 0 r
2.5 Mabswid
.43142 .16592 Mdot
.039 .916 .04 r
.5 Mabswid
.30013 .15932 m
.43142 .16604 L
s
0 0 0 r
2.5 Mabswid
.43142 .16604 Mdot
.039 .916 .04 r
.5 Mabswid
.30011 .15946 m
.43142 .16616 L
s
0 0 0 r
2.5 Mabswid
.43142 .16616 Mdot
.039 .916 .04 r
.5 Mabswid
.30009 .15959 m
.43142 .16628 L
s
0 0 0 r
2.5 Mabswid
.43142 .16628 Mdot
.039 .916 .04 r
.5 Mabswid
.30006 .15973 m
.43143 .1664 L
s
0 0 0 r
2.5 Mabswid
.43143 .1664 Mdot
.039 .916 .04 r
.5 Mabswid
.30004 .15986 m
.43143 .16653 L
s
0 0 0 r
2.5 Mabswid
.43143 .16653 Mdot
.039 .916 .04 r
.5 Mabswid
.30002 .16 m
.43143 .16665 L
s
0 0 0 r
2.5 Mabswid
.43143 .16665 Mdot
.039 .916 .04 r
.5 Mabswid
.3 .16014 m
.43143 .16677 L
s
0 0 0 r
2.5 Mabswid
.43143 .16677 Mdot
.039 .916 .04 r
.5 Mabswid
.29998 .16027 m
.43144 .16689 L
s
0 0 0 r
2.5 Mabswid
.43144 .16689 Mdot
.039 .916 .04 r
.5 Mabswid
.29996 .16041 m
.43144 .16701 L
s
0 0 0 r
2.5 Mabswid
.43144 .16701 Mdot
.039 .916 .04 r
.5 Mabswid
.29994 .16054 m
.43144 .16713 L
s
0 0 0 r
2.5 Mabswid
.43144 .16713 Mdot
.039 .916 .04 r
.5 Mabswid
.29992 .16068 m
.43145 .16725 L
s
0 0 0 r
2.5 Mabswid
.43145 .16725 Mdot
.039 .916 .04 r
.5 Mabswid
.2999 .16082 m
.43145 .16737 L
s
0 0 0 r
2.5 Mabswid
.43145 .16737 Mdot
.039 .916 .04 r
.5 Mabswid
.29988 .16095 m
.43145 .16749 L
s
0 0 0 r
2.5 Mabswid
.43145 .16749 Mdot
.039 .916 .04 r
.5 Mabswid
.29986 .16109 m
.43145 .16761 L
s
0 0 0 r
2.5 Mabswid
.43145 .16761 Mdot
.039 .916 .04 r
.5 Mabswid
.29984 .16122 m
.43146 .16773 L
s
0 0 0 r
2.5 Mabswid
.43146 .16773 Mdot
.039 .916 .04 r
.5 Mabswid
.29982 .16136 m
.43146 .16785 L
s
0 0 0 r
2.5 Mabswid
.43146 .16785 Mdot
.039 .916 .04 r
.5 Mabswid
.2998 .1615 m
.43146 .16797 L
s
0 0 0 r
2.5 Mabswid
.43146 .16797 Mdot
.039 .916 .04 r
.5 Mabswid
.29978 .16163 m
.43146 .16809 L
s
0 0 0 r
2.5 Mabswid
.43146 .16809 Mdot
.039 .916 .04 r
.5 Mabswid
.29976 .16177 m
.43147 .16821 L
s
0 0 0 r
2.5 Mabswid
.43147 .16821 Mdot
.039 .916 .04 r
.5 Mabswid
.29974 .1619 m
.43147 .16833 L
s
0 0 0 r
2.5 Mabswid
.43147 .16833 Mdot
.039 .916 .04 r
.5 Mabswid
.29972 .16204 m
.43147 .16845 L
s
0 0 0 r
2.5 Mabswid
.43147 .16845 Mdot
.039 .916 .04 r
.5 Mabswid
.2997 .16218 m
.43147 .16857 L
s
0 0 0 r
2.5 Mabswid
.43147 .16857 Mdot
.039 .916 .04 r
.5 Mabswid
.29968 .16231 m
.43148 .16869 L
s
0 0 0 r
2.5 Mabswid
.43148 .16869 Mdot
.039 .916 .04 r
.5 Mabswid
.29966 .16245 m
.43148 .16881 L
s
0 0 0 r
2.5 Mabswid
.43148 .16881 Mdot
.039 .916 .04 r
.5 Mabswid
.29964 .16259 m
.43148 .16893 L
s
0 0 0 r
2.5 Mabswid
.43148 .16893 Mdot
.039 .916 .04 r
.5 Mabswid
.29962 .16272 m
.43149 .16905 L
s
0 0 0 r
2.5 Mabswid
.43149 .16905 Mdot
.039 .916 .04 r
.5 Mabswid
.2996 .16286 m
.43149 .16917 L
s
0 0 0 r
2.5 Mabswid
.43149 .16917 Mdot
.039 .916 .04 r
.5 Mabswid
.29958 .16299 m
.43149 .16929 L
s
0 0 0 r
2.5 Mabswid
.43149 .16929 Mdot
.039 .916 .04 r
.5 Mabswid
.29956 .16313 m
.43149 .16941 L
s
0 0 0 r
2.5 Mabswid
.43149 .16941 Mdot
.039 .916 .04 r
.5 Mabswid
.29954 .16327 m
.4315 .16953 L
s
0 0 0 r
2.5 Mabswid
.4315 .16953 Mdot
.039 .916 .04 r
.5 Mabswid
.29952 .1634 m
.4315 .16965 L
s
0 0 0 r
2.5 Mabswid
.4315 .16965 Mdot
.039 .916 .04 r
.5 Mabswid
.2995 .16354 m
.4315 .16977 L
s
0 0 0 r
2.5 Mabswid
.4315 .16977 Mdot
.039 .916 .04 r
.5 Mabswid
.29948 .16367 m
.4315 .16989 L
s
0 0 0 r
2.5 Mabswid
.4315 .16989 Mdot
.039 .916 .04 r
.5 Mabswid
.29946 .16381 m
.43151 .17001 L
s
0 0 0 r
2.5 Mabswid
.43151 .17001 Mdot
.039 .916 .04 r
.5 Mabswid
.29945 .16395 m
.43151 .17013 L
s
0 0 0 r
2.5 Mabswid
.43151 .17013 Mdot
.039 .916 .04 r
.5 Mabswid
.29943 .16408 m
.43151 .17025 L
s
0 0 0 r
2.5 Mabswid
.43151 .17025 Mdot
.039 .916 .04 r
.5 Mabswid
.29941 .16422 m
.43151 .17037 L
s
0 0 0 r
2.5 Mabswid
.43151 .17037 Mdot
.039 .916 .04 r
.5 Mabswid
.29939 .16435 m
.43152 .17049 L
s
0 0 0 r
2.5 Mabswid
.43152 .17049 Mdot
.039 .916 .04 r
.5 Mabswid
.29937 .16449 m
.43152 .17061 L
s
0 0 0 r
2.5 Mabswid
.43152 .17061 Mdot
.039 .916 .04 r
.5 Mabswid
.29935 .16463 m
.43152 .17073 L
s
0 0 0 r
2.5 Mabswid
.43152 .17073 Mdot
.039 .916 .04 r
.5 Mabswid
.29933 .16476 m
.43152 .17085 L
s
0 0 0 r
2.5 Mabswid
.43152 .17085 Mdot
.039 .916 .04 r
.5 Mabswid
.29931 .1649 m
.43153 .17097 L
s
0 0 0 r
2.5 Mabswid
.43153 .17097 Mdot
.039 .916 .04 r
.5 Mabswid
.29929 .16503 m
.43153 .17109 L
s
0 0 0 r
2.5 Mabswid
.43153 .17109 Mdot
.039 .916 .04 r
.5 Mabswid
.29928 .16517 m
.43153 .17121 L
s
0 0 0 r
2.5 Mabswid
.43153 .17121 Mdot
.039 .916 .04 r
.5 Mabswid
.29926 .16531 m
.43153 .17133 L
s
0 0 0 r
2.5 Mabswid
.43153 .17133 Mdot
.039 .916 .04 r
.5 Mabswid
.29924 .16544 m
.43154 .17145 L
s
0 0 0 r
2.5 Mabswid
.43154 .17145 Mdot
.039 .916 .04 r
.5 Mabswid
.29922 .16558 m
.43154 .17157 L
s
0 0 0 r
2.5 Mabswid
.43154 .17157 Mdot
.039 .916 .04 r
.5 Mabswid
.2992 .16571 m
.43154 .17169 L
s
0 0 0 r
2.5 Mabswid
.43154 .17169 Mdot
.039 .916 .04 r
.5 Mabswid
.29918 .16585 m
.43154 .17181 L
s
0 0 0 r
2.5 Mabswid
.43154 .17181 Mdot
.039 .916 .04 r
.5 Mabswid
.29916 .16599 m
.43155 .17193 L
s
0 0 0 r
2.5 Mabswid
.43155 .17193 Mdot
.039 .916 .04 r
.5 Mabswid
.29915 .16612 m
.43155 .17205 L
s
0 0 0 r
2.5 Mabswid
.43155 .17205 Mdot
.039 .916 .04 r
.5 Mabswid
.29913 .16626 m
.43155 .17217 L
s
0 0 0 r
2.5 Mabswid
.43155 .17217 Mdot
.039 .916 .04 r
.5 Mabswid
.29911 .16639 m
.43155 .17229 L
s
0 0 0 r
2.5 Mabswid
.43155 .17229 Mdot
.039 .916 .04 r
.5 Mabswid
.29909 .16653 m
.43155 .17241 L
s
0 0 0 r
2.5 Mabswid
.43155 .17241 Mdot
.039 .916 .04 r
.5 Mabswid
.29907 .16667 m
.43156 .17253 L
s
0 0 0 r
2.5 Mabswid
.43156 .17253 Mdot
.039 .916 .04 r
.5 Mabswid
.29905 .1668 m
.43156 .17265 L
s
0 0 0 r
2.5 Mabswid
.43156 .17265 Mdot
.039 .916 .04 r
.5 Mabswid
.29904 .16694 m
.43156 .17277 L
s
0 0 0 r
2.5 Mabswid
.43156 .17277 Mdot
.039 .916 .04 r
.5 Mabswid
.29902 .16707 m
.43156 .17289 L
s
0 0 0 r
2.5 Mabswid
.43156 .17289 Mdot
.039 .916 .04 r
.5 Mabswid
.299 .16721 m
.43157 .17301 L
s
0 0 0 r
2.5 Mabswid
.43157 .17301 Mdot
.039 .916 .04 r
.5 Mabswid
.29898 .16735 m
.43157 .17313 L
s
0 0 0 r
2.5 Mabswid
.43157 .17313 Mdot
.039 .916 .04 r
.5 Mabswid
.29897 .16748 m
.43157 .17325 L
s
0 0 0 r
2.5 Mabswid
.43157 .17325 Mdot
.039 .916 .04 r
.5 Mabswid
.29895 .16762 m
.43157 .17337 L
s
0 0 0 r
2.5 Mabswid
.43157 .17337 Mdot
.039 .916 .04 r
.5 Mabswid
.29893 .16776 m
.43158 .17349 L
s
0 0 0 r
2.5 Mabswid
.43158 .17349 Mdot
.039 .916 .04 r
.5 Mabswid
.29891 .16789 m
.43158 .17361 L
s
0 0 0 r
2.5 Mabswid
.43158 .17361 Mdot
.039 .916 .04 r
.5 Mabswid
.29889 .16803 m
.43158 .17373 L
s
0 0 0 r
2.5 Mabswid
.43158 .17373 Mdot
.039 .916 .04 r
.5 Mabswid
.29888 .16816 m
.43158 .17385 L
s
0 0 0 r
2.5 Mabswid
.43158 .17385 Mdot
.039 .916 .04 r
.5 Mabswid
.29886 .1683 m
.43159 .17397 L
s
0 0 0 r
2.5 Mabswid
.43159 .17397 Mdot
.039 .916 .04 r
.5 Mabswid
.29884 .16844 m
.43159 .17409 L
s
0 0 0 r
2.5 Mabswid
.43159 .17409 Mdot
.039 .916 .04 r
.5 Mabswid
.29882 .16857 m
.43159 .17421 L
s
0 0 0 r
2.5 Mabswid
.43159 .17421 Mdot
.039 .916 .04 r
.5 Mabswid
.29881 .16871 m
.43159 .17433 L
s
0 0 0 r
2.5 Mabswid
.43159 .17433 Mdot
.039 .916 .04 r
.5 Mabswid
.29879 .16884 m
.43159 .17445 L
s
0 0 0 r
2.5 Mabswid
.43159 .17445 Mdot
.039 .916 .04 r
.5 Mabswid
.29877 .16898 m
.4316 .17457 L
s
0 0 0 r
2.5 Mabswid
.4316 .17457 Mdot
.039 .916 .04 r
.5 Mabswid
.29876 .16912 m
.4316 .17469 L
s
0 0 0 r
2.5 Mabswid
.4316 .17469 Mdot
.039 .916 .04 r
.5 Mabswid
.29874 .16925 m
.4316 .17481 L
s
0 0 0 r
2.5 Mabswid
.4316 .17481 Mdot
.039 .916 .04 r
.5 Mabswid
.29872 .16939 m
.4316 .17493 L
s
0 0 0 r
2.5 Mabswid
.4316 .17493 Mdot
.039 .916 .04 r
.5 Mabswid
.2987 .16952 m
.43161 .17505 L
s
0 0 0 r
2.5 Mabswid
.43161 .17505 Mdot
.039 .916 .04 r
.5 Mabswid
.29869 .16966 m
.43161 .17517 L
s
0 0 0 r
2.5 Mabswid
.43161 .17517 Mdot
.039 .916 .04 r
.5 Mabswid
.29867 .1698 m
.43161 .17529 L
s
0 0 0 r
2.5 Mabswid
.43161 .17529 Mdot
.039 .916 .04 r
.5 Mabswid
.29865 .16993 m
.43161 .17541 L
s
0 0 0 r
2.5 Mabswid
.43161 .17541 Mdot
.039 .916 .04 r
.5 Mabswid
.29864 .17007 m
.43161 .17553 L
s
0 0 0 r
2.5 Mabswid
.43161 .17553 Mdot
.039 .916 .04 r
.5 Mabswid
.29862 .1702 m
.43162 .17565 L
s
0 0 0 r
2.5 Mabswid
.43162 .17565 Mdot
.039 .916 .04 r
.5 Mabswid
.2986 .17034 m
.43162 .17577 L
s
0 0 0 r
2.5 Mabswid
.43162 .17577 Mdot
.039 .916 .04 r
.5 Mabswid
.29859 .17048 m
.43162 .17589 L
s
0 0 0 r
2.5 Mabswid
.43162 .17589 Mdot
.039 .916 .04 r
.5 Mabswid
.29857 .17061 m
.43162 .17601 L
s
0 0 0 r
2.5 Mabswid
.43162 .17601 Mdot
.039 .916 .04 r
.5 Mabswid
.29855 .17075 m
.43163 .17613 L
s
0 0 0 r
2.5 Mabswid
.43163 .17613 Mdot
.039 .916 .04 r
.5 Mabswid
.29854 .17088 m
.43163 .17625 L
s
0 0 0 r
2.5 Mabswid
.43163 .17625 Mdot
.039 .916 .04 r
.5 Mabswid
.29852 .17102 m
.43163 .17637 L
s
0 0 0 r
2.5 Mabswid
.43163 .17637 Mdot
.039 .916 .04 r
.5 Mabswid
.2985 .17116 m
.43163 .17649 L
s
0 0 0 r
2.5 Mabswid
.43163 .17649 Mdot
.039 .916 .04 r
.5 Mabswid
.29849 .17129 m
.43163 .17661 L
s
0 0 0 r
2.5 Mabswid
.43163 .17661 Mdot
.039 .916 .04 r
.5 Mabswid
.29847 .17143 m
.43164 .17673 L
s
0 0 0 r
2.5 Mabswid
.43164 .17673 Mdot
.039 .916 .04 r
.5 Mabswid
.29846 .17156 m
.43164 .17685 L
s
0 0 0 r
2.5 Mabswid
.43164 .17685 Mdot
.039 .916 .04 r
.5 Mabswid
.29844 .1717 m
.43164 .17697 L
s
0 0 0 r
2.5 Mabswid
.43164 .17697 Mdot
.039 .916 .04 r
.5 Mabswid
.29842 .17184 m
.43164 .17709 L
s
0 0 0 r
2.5 Mabswid
.43164 .17709 Mdot
.039 .916 .04 r
.5 Mabswid
.29841 .17197 m
.43165 .17721 L
s
0 0 0 r
2.5 Mabswid
.43165 .17721 Mdot
.039 .916 .04 r
.5 Mabswid
.29839 .17211 m
.43165 .17733 L
s
0 0 0 r
2.5 Mabswid
.43165 .17733 Mdot
.039 .916 .04 r
.5 Mabswid
.29837 .17224 m
.43165 .17745 L
s
0 0 0 r
2.5 Mabswid
.43165 .17745 Mdot
.039 .916 .04 r
.5 Mabswid
.29836 .17238 m
.43165 .17757 L
s
0 0 0 r
2.5 Mabswid
.43165 .17757 Mdot
.039 .916 .04 r
.5 Mabswid
.29834 .17252 m
.43165 .17769 L
s
0 0 0 r
2.5 Mabswid
.43165 .17769 Mdot
.039 .916 .04 r
.5 Mabswid
.29833 .17265 m
.43166 .17781 L
s
0 0 0 r
2.5 Mabswid
.43166 .17781 Mdot
.039 .916 .04 r
.5 Mabswid
.29831 .17279 m
.43166 .17792 L
s
0 0 0 r
2.5 Mabswid
.43166 .17792 Mdot
.039 .916 .04 r
.5 Mabswid
.2983 .17293 m
.43166 .17804 L
s
0 0 0 r
2.5 Mabswid
.43166 .17804 Mdot
.039 .916 .04 r
.5 Mabswid
.29828 .17306 m
.43166 .17816 L
s
0 0 0 r
2.5 Mabswid
.43166 .17816 Mdot
.039 .916 .04 r
.5 Mabswid
.29826 .1732 m
.43166 .17828 L
s
0 0 0 r
2.5 Mabswid
.43166 .17828 Mdot
.039 .916 .04 r
.5 Mabswid
.29825 .17333 m
.43167 .1784 L
s
0 0 0 r
2.5 Mabswid
.43167 .1784 Mdot
.039 .916 .04 r
.5 Mabswid
.29823 .17347 m
.43167 .17852 L
s
0 0 0 r
2.5 Mabswid
.43167 .17852 Mdot
.039 .916 .04 r
.5 Mabswid
.29822 .17361 m
.43167 .17864 L
s
0 0 0 r
2.5 Mabswid
.43167 .17864 Mdot
.039 .916 .04 r
.5 Mabswid
.2982 .17374 m
.43167 .17876 L
s
0 0 0 r
2.5 Mabswid
.43167 .17876 Mdot
.039 .916 .04 r
.5 Mabswid
.29819 .17388 m
.43167 .17888 L
s
0 0 0 r
2.5 Mabswid
.43167 .17888 Mdot
.039 .916 .04 r
.5 Mabswid
.29817 .17401 m
.43168 .179 L
s
0 0 0 r
2.5 Mabswid
.43168 .179 Mdot
.039 .916 .04 r
.5 Mabswid
.29816 .17415 m
.43168 .17912 L
s
0 0 0 r
2.5 Mabswid
.43168 .17912 Mdot
.039 .916 .04 r
.5 Mabswid
.29814 .17429 m
.43168 .17924 L
s
0 0 0 r
2.5 Mabswid
.43168 .17924 Mdot
.039 .916 .04 r
.5 Mabswid
.29813 .17442 m
.43168 .17936 L
s
0 0 0 r
2.5 Mabswid
.43168 .17936 Mdot
.039 .916 .04 r
.5 Mabswid
.29811 .17456 m
.43168 .17948 L
s
0 0 0 r
2.5 Mabswid
.43168 .17948 Mdot
.039 .916 .04 r
.5 Mabswid
.2981 .17469 m
.43169 .1796 L
s
0 0 0 r
2.5 Mabswid
.43169 .1796 Mdot
.039 .916 .04 r
.5 Mabswid
.29808 .17483 m
.43169 .17972 L
s
0 0 0 r
2.5 Mabswid
.43169 .17972 Mdot
.039 .916 .04 r
.5 Mabswid
.29807 .17497 m
.43169 .17984 L
s
0 0 0 r
2.5 Mabswid
.43169 .17984 Mdot
.039 .916 .04 r
.5 Mabswid
.29805 .1751 m
.43169 .17996 L
s
0 0 0 r
2.5 Mabswid
.43169 .17996 Mdot
.039 .916 .04 r
.5 Mabswid
.29804 .17524 m
.43169 .18008 L
s
0 0 0 r
2.5 Mabswid
.43169 .18008 Mdot
.039 .916 .04 r
.5 Mabswid
.29802 .17537 m
.4317 .1802 L
s
0 0 0 r
2.5 Mabswid
.4317 .1802 Mdot
.039 .916 .04 r
.5 Mabswid
.29801 .17551 m
.4317 .18032 L
s
0 0 0 r
2.5 Mabswid
.4317 .18032 Mdot
.039 .916 .04 r
.5 Mabswid
.29799 .17565 m
.4317 .18044 L
s
0 0 0 r
2.5 Mabswid
.4317 .18044 Mdot
.039 .916 .04 r
.5 Mabswid
.29798 .17578 m
.4317 .18056 L
s
0 0 0 r
2.5 Mabswid
.4317 .18056 Mdot
.039 .916 .04 r
.5 Mabswid
.29796 .17592 m
.4317 .18068 L
s
0 0 0 r
2.5 Mabswid
.4317 .18068 Mdot
.039 .916 .04 r
.5 Mabswid
.29795 .17605 m
.43171 .1808 L
s
0 0 0 r
2.5 Mabswid
.43171 .1808 Mdot
.039 .916 .04 r
.5 Mabswid
.29793 .17619 m
.43171 .18092 L
s
0 0 0 r
2.5 Mabswid
.43171 .18092 Mdot
.039 .916 .04 r
.5 Mabswid
.29792 .17633 m
.43171 .18104 L
s
0 0 0 r
2.5 Mabswid
.43171 .18104 Mdot
.039 .916 .04 r
.5 Mabswid
.29791 .17646 m
.43171 .18116 L
s
0 0 0 r
2.5 Mabswid
.43171 .18116 Mdot
.039 .916 .04 r
.5 Mabswid
.29789 .1766 m
.43171 .18128 L
s
0 0 0 r
2.5 Mabswid
.43171 .18128 Mdot
.039 .916 .04 r
.5 Mabswid
.29788 .17673 m
.43172 .18139 L
s
0 0 0 r
2.5 Mabswid
.43172 .18139 Mdot
.039 .916 .04 r
.5 Mabswid
.29786 .17687 m
.43172 .18151 L
s
0 0 0 r
2.5 Mabswid
.43172 .18151 Mdot
.039 .916 .04 r
.5 Mabswid
.29785 .17701 m
.43172 .18163 L
s
0 0 0 r
2.5 Mabswid
.43172 .18163 Mdot
.039 .916 .04 r
.5 Mabswid
.29783 .17714 m
.43172 .18175 L
s
0 0 0 r
2.5 Mabswid
.43172 .18175 Mdot
.039 .916 .04 r
.5 Mabswid
.29782 .17728 m
.43172 .18187 L
s
0 0 0 r
2.5 Mabswid
.43172 .18187 Mdot
.039 .916 .04 r
.5 Mabswid
.29781 .17741 m
.43172 .18199 L
s
0 0 0 r
2.5 Mabswid
.43172 .18199 Mdot
.039 .916 .04 r
.5 Mabswid
.29779 .17755 m
.43173 .18211 L
s
0 0 0 r
2.5 Mabswid
.43173 .18211 Mdot
.039 .916 .04 r
.5 Mabswid
.29778 .17769 m
.43173 .18223 L
s
0 0 0 r
2.5 Mabswid
.43173 .18223 Mdot
.039 .916 .04 r
.5 Mabswid
.29776 .17782 m
.43173 .18235 L
s
0 0 0 r
2.5 Mabswid
.43173 .18235 Mdot
.039 .916 .04 r
.5 Mabswid
.29775 .17796 m
.43173 .18247 L
s
0 0 0 r
2.5 Mabswid
.43173 .18247 Mdot
.039 .916 .04 r
.5 Mabswid
.29774 .1781 m
.43173 .18259 L
s
0 0 0 r
2.5 Mabswid
.43173 .18259 Mdot
.039 .916 .04 r
.5 Mabswid
.29772 .17823 m
.43174 .18271 L
s
0 0 0 r
2.5 Mabswid
.43174 .18271 Mdot
.039 .916 .04 r
.5 Mabswid
.29771 .17837 m
.43174 .18283 L
s
0 0 0 r
2.5 Mabswid
.43174 .18283 Mdot
.039 .916 .04 r
.5 Mabswid
.2977 .1785 m
.43174 .18295 L
s
0 0 0 r
2.5 Mabswid
.43174 .18295 Mdot
.039 .916 .04 r
.5 Mabswid
.29768 .17864 m
.43174 .18307 L
s
0 0 0 r
2.5 Mabswid
.43174 .18307 Mdot
.039 .916 .04 r
.5 Mabswid
.29767 .17878 m
.43174 .18319 L
s
0 0 0 r
2.5 Mabswid
.43174 .18319 Mdot
.039 .916 .04 r
.5 Mabswid
.29766 .17891 m
.43174 .18331 L
s
0 0 0 r
2.5 Mabswid
.43174 .18331 Mdot
.039 .916 .04 r
.5 Mabswid
.29764 .17905 m
.43175 .18343 L
s
0 0 0 r
2.5 Mabswid
.43175 .18343 Mdot
.039 .916 .04 r
.5 Mabswid
.29763 .17918 m
.43175 .18355 L
s
0 0 0 r
2.5 Mabswid
.43175 .18355 Mdot
.039 .916 .04 r
.5 Mabswid
.29762 .17932 m
.43175 .18367 L
s
0 0 0 r
2.5 Mabswid
.43175 .18367 Mdot
.039 .916 .04 r
.5 Mabswid
.2976 .17946 m
.43175 .18379 L
s
0 0 0 r
2.5 Mabswid
.43175 .18379 Mdot
.039 .916 .04 r
.5 Mabswid
.29759 .17959 m
.43175 .18391 L
s
0 0 0 r
2.5 Mabswid
.43175 .18391 Mdot
.039 .916 .04 r
.5 Mabswid
.29758 .17973 m
.43175 .18402 L
s
0 0 0 r
2.5 Mabswid
.43175 .18402 Mdot
.039 .916 .04 r
.5 Mabswid
.29756 .17986 m
.43176 .18414 L
s
0 0 0 r
2.5 Mabswid
.43176 .18414 Mdot
.039 .916 .04 r
.5 Mabswid
.29755 .18 m
.43176 .18426 L
s
0 0 0 r
2.5 Mabswid
.43176 .18426 Mdot
.039 .916 .04 r
.5 Mabswid
.29754 .18014 m
.43176 .18438 L
s
0 0 0 r
2.5 Mabswid
.43176 .18438 Mdot
.039 .916 .04 r
.5 Mabswid
.29752 .18027 m
.43176 .1845 L
s
0 0 0 r
2.5 Mabswid
.43176 .1845 Mdot
.039 .916 .04 r
.5 Mabswid
.29751 .18041 m
.43176 .18462 L
s
0 0 0 r
2.5 Mabswid
.43176 .18462 Mdot
.039 .916 .04 r
.5 Mabswid
.2975 .18054 m
.43176 .18474 L
s
0 0 0 r
2.5 Mabswid
.43176 .18474 Mdot
.039 .916 .04 r
.5 Mabswid
.29749 .18068 m
.43177 .18486 L
s
0 0 0 r
2.5 Mabswid
.43177 .18486 Mdot
.039 .916 .04 r
.5 Mabswid
.29747 .18082 m
.43177 .18498 L
s
0 0 0 r
2.5 Mabswid
.43177 .18498 Mdot
.039 .916 .04 r
.5 Mabswid
.29746 .18095 m
.43177 .1851 L
s
0 0 0 r
2.5 Mabswid
.43177 .1851 Mdot
.039 .916 .04 r
.5 Mabswid
.29745 .18109 m
.43177 .18522 L
s
0 0 0 r
2.5 Mabswid
.43177 .18522 Mdot
.039 .916 .04 r
.5 Mabswid
.29744 .18122 m
.43177 .18534 L
s
0 0 0 r
2.5 Mabswid
.43177 .18534 Mdot
.039 .916 .04 r
.5 Mabswid
.29742 .18136 m
.43177 .18546 L
s
0 0 0 r
2.5 Mabswid
.43177 .18546 Mdot
.039 .916 .04 r
.5 Mabswid
.29741 .1815 m
.43178 .18558 L
s
0 0 0 r
2.5 Mabswid
.43178 .18558 Mdot
.039 .916 .04 r
.5 Mabswid
.2974 .18163 m
.43178 .1857 L
s
0 0 0 r
2.5 Mabswid
.43178 .1857 Mdot
.039 .916 .04 r
.5 Mabswid
.29739 .18177 m
.43178 .18582 L
s
0 0 0 r
2.5 Mabswid
.43178 .18582 Mdot
.039 .916 .04 r
.5 Mabswid
.29737 .1819 m
.43178 .18594 L
s
0 0 0 r
2.5 Mabswid
.43178 .18594 Mdot
.039 .916 .04 r
.5 Mabswid
.29736 .18204 m
.43178 .18606 L
s
0 0 0 r
2.5 Mabswid
.43178 .18606 Mdot
.039 .916 .04 r
.5 Mabswid
.29735 .18218 m
.43178 .18617 L
s
0 0 0 r
2.5 Mabswid
.43178 .18617 Mdot
.039 .916 .04 r
.5 Mabswid
.29734 .18231 m
.43179 .18629 L
s
0 0 0 r
2.5 Mabswid
.43179 .18629 Mdot
.039 .916 .04 r
.5 Mabswid
.29732 .18245 m
.43179 .18641 L
s
0 0 0 r
2.5 Mabswid
.43179 .18641 Mdot
.039 .916 .04 r
.5 Mabswid
.29731 .18259 m
.43179 .18653 L
s
0 0 0 r
2.5 Mabswid
.43179 .18653 Mdot
.039 .916 .04 r
.5 Mabswid
.2973 .18272 m
.43179 .18665 L
s
0 0 0 r
2.5 Mabswid
.43179 .18665 Mdot
.039 .916 .04 r
.5 Mabswid
.29729 .18286 m
.43179 .18677 L
s
0 0 0 r
2.5 Mabswid
.43179 .18677 Mdot
.039 .916 .04 r
.5 Mabswid
.29728 .18299 m
.43179 .18689 L
s
0 0 0 r
2.5 Mabswid
.43179 .18689 Mdot
.039 .916 .04 r
.5 Mabswid
.29727 .18313 m
.4318 .18701 L
s
0 0 0 r
2.5 Mabswid
.4318 .18701 Mdot
.039 .916 .04 r
.5 Mabswid
.29725 .18327 m
.4318 .18713 L
s
0 0 0 r
2.5 Mabswid
.4318 .18713 Mdot
.039 .916 .04 r
.5 Mabswid
.29724 .1834 m
.4318 .18725 L
s
0 0 0 r
2.5 Mabswid
.4318 .18725 Mdot
.039 .916 .04 r
.5 Mabswid
.29723 .18354 m
.4318 .18737 L
s
0 0 0 r
2.5 Mabswid
.4318 .18737 Mdot
.039 .916 .04 r
.5 Mabswid
.29722 .18367 m
.4318 .18749 L
s
0 0 0 r
2.5 Mabswid
.4318 .18749 Mdot
.039 .916 .04 r
.5 Mabswid
.29721 .18381 m
.4318 .18761 L
s
0 0 0 r
2.5 Mabswid
.4318 .18761 Mdot
.039 .916 .04 r
.5 Mabswid
.2972 .18395 m
.4318 .18773 L
s
0 0 0 r
2.5 Mabswid
.4318 .18773 Mdot
.039 .916 .04 r
.5 Mabswid
.29718 .18408 m
.43181 .18785 L
s
0 0 0 r
2.5 Mabswid
.43181 .18785 Mdot
.039 .916 .04 r
.5 Mabswid
.29717 .18422 m
.43181 .18797 L
s
0 0 0 r
2.5 Mabswid
.43181 .18797 Mdot
.039 .916 .04 r
.5 Mabswid
.29716 .18435 m
.43181 .18809 L
s
0 0 0 r
2.5 Mabswid
.43181 .18809 Mdot
.039 .916 .04 r
.5 Mabswid
.29715 .18449 m
.43181 .1882 L
s
0 0 0 r
2.5 Mabswid
.43181 .1882 Mdot
.039 .916 .04 r
.5 Mabswid
.29714 .18463 m
.43181 .18832 L
s
0 0 0 r
2.5 Mabswid
.43181 .18832 Mdot
.039 .916 .04 r
.5 Mabswid
.29713 .18476 m
.43181 .18844 L
s
0 0 0 r
2.5 Mabswid
.43181 .18844 Mdot
.039 .916 .04 r
.5 Mabswid
.29712 .1849 m
.43182 .18856 L
s
0 0 0 r
2.5 Mabswid
.43182 .18856 Mdot
.039 .916 .04 r
.5 Mabswid
.29711 .18503 m
.43182 .18868 L
s
0 0 0 r
2.5 Mabswid
.43182 .18868 Mdot
.039 .916 .04 r
.5 Mabswid
.29709 .18517 m
.43182 .1888 L
s
0 0 0 r
2.5 Mabswid
.43182 .1888 Mdot
.039 .916 .04 r
.5 Mabswid
.29708 .18531 m
.43182 .18892 L
s
0 0 0 r
2.5 Mabswid
.43182 .18892 Mdot
.039 .916 .04 r
.5 Mabswid
.29707 .18544 m
.43182 .18904 L
s
0 0 0 r
2.5 Mabswid
.43182 .18904 Mdot
.039 .916 .04 r
.5 Mabswid
.29706 .18558 m
.43182 .18916 L
s
0 0 0 r
2.5 Mabswid
.43182 .18916 Mdot
.039 .916 .04 r
.5 Mabswid
.29705 .18571 m
.43182 .18928 L
s
0 0 0 r
2.5 Mabswid
.43182 .18928 Mdot
.039 .916 .04 r
.5 Mabswid
.29704 .18585 m
.43183 .1894 L
s
0 0 0 r
2.5 Mabswid
.43183 .1894 Mdot
.039 .916 .04 r
.5 Mabswid
.29703 .18599 m
.43183 .18952 L
s
0 0 0 r
2.5 Mabswid
.43183 .18952 Mdot
.039 .916 .04 r
.5 Mabswid
.29702 .18612 m
.43183 .18964 L
s
0 0 0 r
2.5 Mabswid
.43183 .18964 Mdot
.039 .916 .04 r
.5 Mabswid
.29701 .18626 m
.43183 .18976 L
s
0 0 0 r
2.5 Mabswid
.43183 .18976 Mdot
.039 .916 .04 r
.5 Mabswid
.297 .18639 m
.43183 .18988 L
s
0 0 0 r
2.5 Mabswid
.43183 .18988 Mdot
.039 .916 .04 r
.5 Mabswid
.29699 .18653 m
.43183 .18999 L
s
0 0 0 r
2.5 Mabswid
.43183 .18999 Mdot
.039 .916 .04 r
.5 Mabswid
.29698 .18667 m
.43183 .19011 L
s
0 0 0 r
2.5 Mabswid
.43183 .19011 Mdot
.039 .916 .04 r
.5 Mabswid
.29697 .1868 m
.43183 .19023 L
s
0 0 0 r
2.5 Mabswid
.43183 .19023 Mdot
.039 .916 .04 r
.5 Mabswid
.29696 .18694 m
.43184 .19035 L
s
0 0 0 r
2.5 Mabswid
.43184 .19035 Mdot
.039 .916 .04 r
.5 Mabswid
.29695 .18707 m
.43184 .19047 L
s
0 0 0 r
2.5 Mabswid
.43184 .19047 Mdot
.039 .916 .04 r
.5 Mabswid
.29694 .18721 m
.43184 .19059 L
s
0 0 0 r
2.5 Mabswid
.43184 .19059 Mdot
.039 .916 .04 r
.5 Mabswid
.29692 .18735 m
.43184 .19071 L
s
0 0 0 r
2.5 Mabswid
.43184 .19071 Mdot
.039 .916 .04 r
.5 Mabswid
.29691 .18748 m
.43184 .19083 L
s
0 0 0 r
2.5 Mabswid
.43184 .19083 Mdot
.039 .916 .04 r
.5 Mabswid
.2969 .18762 m
.43184 .19095 L
s
0 0 0 r
2.5 Mabswid
.43184 .19095 Mdot
.039 .916 .04 r
.5 Mabswid
.29689 .18776 m
.43184 .19107 L
s
0 0 0 r
2.5 Mabswid
.43184 .19107 Mdot
.039 .916 .04 r
.5 Mabswid
.29688 .18789 m
.43185 .19119 L
s
0 0 0 r
2.5 Mabswid
.43185 .19119 Mdot
.039 .916 .04 r
.5 Mabswid
.29687 .18803 m
.43185 .19131 L
s
0 0 0 r
2.5 Mabswid
.43185 .19131 Mdot
.039 .916 .04 r
.5 Mabswid
.29686 .18816 m
.43185 .19143 L
s
0 0 0 r
2.5 Mabswid
.43185 .19143 Mdot
.039 .916 .04 r
.5 Mabswid
.29685 .1883 m
.43185 .19155 L
s
0 0 0 r
2.5 Mabswid
.43185 .19155 Mdot
.039 .916 .04 r
.5 Mabswid
.29685 .18844 m
.43185 .19166 L
s
0 0 0 r
2.5 Mabswid
.43185 .19166 Mdot
.039 .916 .04 r
.5 Mabswid
.29684 .18857 m
.43185 .19178 L
s
0 0 0 r
2.5 Mabswid
.43185 .19178 Mdot
.039 .916 .04 r
.5 Mabswid
.29683 .18871 m
.43185 .1919 L
s
0 0 0 r
2.5 Mabswid
.43185 .1919 Mdot
.039 .916 .04 r
.5 Mabswid
.29682 .18884 m
.43185 .19202 L
s
0 0 0 r
2.5 Mabswid
.43185 .19202 Mdot
.039 .916 .04 r
.5 Mabswid
.29681 .18898 m
.43186 .19214 L
s
0 0 0 r
2.5 Mabswid
.43186 .19214 Mdot
.039 .916 .04 r
.5 Mabswid
.2968 .18912 m
.43186 .19226 L
s
0 0 0 r
2.5 Mabswid
.43186 .19226 Mdot
.039 .916 .04 r
.5 Mabswid
.29679 .18925 m
.43186 .19238 L
s
0 0 0 r
2.5 Mabswid
.43186 .19238 Mdot
.039 .916 .04 r
.5 Mabswid
.29678 .18939 m
.43186 .1925 L
s
0 0 0 r
2.5 Mabswid
.43186 .1925 Mdot
.039 .916 .04 r
.5 Mabswid
.29677 .18952 m
.43186 .19262 L
s
0 0 0 r
2.5 Mabswid
.43186 .19262 Mdot
.039 .916 .04 r
.5 Mabswid
.29676 .18966 m
.43186 .19274 L
s
0 0 0 r
2.5 Mabswid
.43186 .19274 Mdot
.039 .916 .04 r
.5 Mabswid
.29675 .1898 m
.43186 .19286 L
s
0 0 0 r
2.5 Mabswid
.43186 .19286 Mdot
.039 .916 .04 r
.5 Mabswid
.29674 .18993 m
.43186 .19298 L
s
0 0 0 r
2.5 Mabswid
.43186 .19298 Mdot
.039 .916 .04 r
.5 Mabswid
.29673 .19007 m
.43187 .1931 L
s
0 0 0 r
2.5 Mabswid
.43187 .1931 Mdot
.039 .916 .04 r
.5 Mabswid
.29672 .1902 m
.43187 .19321 L
s
0 0 0 r
2.5 Mabswid
.43187 .19321 Mdot
.039 .916 .04 r
.5 Mabswid
.29671 .19034 m
.43187 .19333 L
s
0 0 0 r
2.5 Mabswid
.43187 .19333 Mdot
.039 .916 .04 r
.5 Mabswid
.2967 .19048 m
.43187 .19345 L
s
0 0 0 r
2.5 Mabswid
.43187 .19345 Mdot
.039 .916 .04 r
.5 Mabswid
.2967 .19061 m
.43187 .19357 L
s
0 0 0 r
2.5 Mabswid
.43187 .19357 Mdot
.039 .916 .04 r
.5 Mabswid
.29669 .19075 m
.43187 .19369 L
s
0 0 0 r
2.5 Mabswid
.43187 .19369 Mdot
.039 .916 .04 r
.5 Mabswid
.29668 .19088 m
.43187 .19381 L
s
0 0 0 r
2.5 Mabswid
.43187 .19381 Mdot
.039 .916 .04 r
.5 Mabswid
.29667 .19102 m
.43187 .19393 L
s
0 0 0 r
2.5 Mabswid
.43187 .19393 Mdot
.039 .916 .04 r
.5 Mabswid
.29666 .19116 m
.43188 .19405 L
s
0 0 0 r
2.5 Mabswid
.43188 .19405 Mdot
.039 .916 .04 r
.5 Mabswid
.29665 .19129 m
.43188 .19417 L
s
0 0 0 r
2.5 Mabswid
.43188 .19417 Mdot
.039 .916 .04 r
.5 Mabswid
.29664 .19143 m
.43188 .19429 L
s
0 0 0 r
2.5 Mabswid
.43188 .19429 Mdot
.039 .916 .04 r
.5 Mabswid
.29663 .19156 m
.43188 .19441 L
s
0 0 0 r
2.5 Mabswid
.43188 .19441 Mdot
.039 .916 .04 r
.5 Mabswid
.29663 .1917 m
.43188 .19453 L
s
0 0 0 r
2.5 Mabswid
.43188 .19453 Mdot
.039 .916 .04 r
.5 Mabswid
.29662 .19184 m
.43188 .19464 L
s
0 0 0 r
2.5 Mabswid
.43188 .19464 Mdot
.039 .916 .04 r
.5 Mabswid
.29661 .19197 m
.43188 .19476 L
s
0 0 0 r
2.5 Mabswid
.43188 .19476 Mdot
.039 .916 .04 r
.5 Mabswid
.2966 .19211 m
.43188 .19488 L
s
0 0 0 r
2.5 Mabswid
.43188 .19488 Mdot
.039 .916 .04 r
.5 Mabswid
.29659 .19224 m
.43188 .195 L
s
0 0 0 r
2.5 Mabswid
.43188 .195 Mdot
.039 .916 .04 r
.5 Mabswid
.29658 .19238 m
.43189 .19512 L
s
0 0 0 r
2.5 Mabswid
.43189 .19512 Mdot
.039 .916 .04 r
.5 Mabswid
.29658 .19252 m
.43189 .19524 L
s
0 0 0 r
2.5 Mabswid
.43189 .19524 Mdot
.039 .916 .04 r
.5 Mabswid
.29657 .19265 m
.43189 .19536 L
s
0 0 0 r
2.5 Mabswid
.43189 .19536 Mdot
.039 .916 .04 r
.5 Mabswid
.29656 .19279 m
.43189 .19548 L
s
0 0 0 r
2.5 Mabswid
.43189 .19548 Mdot
.039 .916 .04 r
.5 Mabswid
.29655 .19293 m
.43189 .1956 L
s
0 0 0 r
2.5 Mabswid
.43189 .1956 Mdot
.039 .916 .04 r
.5 Mabswid
.29654 .19306 m
.43189 .19572 L
s
0 0 0 r
2.5 Mabswid
.43189 .19572 Mdot
.039 .916 .04 r
.5 Mabswid
.29653 .1932 m
.43189 .19584 L
s
0 0 0 r
2.5 Mabswid
.43189 .19584 Mdot
.039 .916 .04 r
.5 Mabswid
.29653 .19333 m
.43189 .19596 L
s
0 0 0 r
2.5 Mabswid
.43189 .19596 Mdot
.039 .916 .04 r
.5 Mabswid
.29652 .19347 m
.43189 .19607 L
s
0 0 0 r
2.5 Mabswid
.43189 .19607 Mdot
.039 .916 .04 r
.5 Mabswid
.29651 .19361 m
.43189 .19619 L
s
0 0 0 r
2.5 Mabswid
.43189 .19619 Mdot
.039 .916 .04 r
.5 Mabswid
.2965 .19374 m
.4319 .19631 L
s
0 0 0 r
2.5 Mabswid
.4319 .19631 Mdot
.039 .916 .04 r
.5 Mabswid
.2965 .19388 m
.4319 .19643 L
s
0 0 0 r
2.5 Mabswid
.4319 .19643 Mdot
.039 .916 .04 r
.5 Mabswid
.29649 .19401 m
.4319 .19655 L
s
0 0 0 r
2.5 Mabswid
.4319 .19655 Mdot
.039 .916 .04 r
.5 Mabswid
.29648 .19415 m
.4319 .19667 L
s
0 0 0 r
2.5 Mabswid
.4319 .19667 Mdot
.039 .916 .04 r
.5 Mabswid
.29647 .19429 m
.4319 .19679 L
s
0 0 0 r
2.5 Mabswid
.4319 .19679 Mdot
.039 .916 .04 r
.5 Mabswid
.29647 .19442 m
.4319 .19691 L
s
0 0 0 r
2.5 Mabswid
.4319 .19691 Mdot
.039 .916 .04 r
.5 Mabswid
.29646 .19456 m
.4319 .19703 L
s
0 0 0 r
2.5 Mabswid
.4319 .19703 Mdot
.039 .916 .04 r
.5 Mabswid
.29645 .19469 m
.4319 .19715 L
s
0 0 0 r
2.5 Mabswid
.4319 .19715 Mdot
.039 .916 .04 r
.5 Mabswid
.29644 .19483 m
.4319 .19727 L
s
0 0 0 r
2.5 Mabswid
.4319 .19727 Mdot
.039 .916 .04 r
.5 Mabswid
.29644 .19497 m
.4319 .19739 L
s
0 0 0 r
2.5 Mabswid
.4319 .19739 Mdot
.039 .916 .04 r
.5 Mabswid
.29643 .1951 m
.43191 .1975 L
s
0 0 0 r
2.5 Mabswid
.43191 .1975 Mdot
.039 .916 .04 r
.5 Mabswid
.29642 .19524 m
.43191 .19762 L
s
0 0 0 r
2.5 Mabswid
.43191 .19762 Mdot
.039 .916 .04 r
.5 Mabswid
.29641 .19537 m
.43191 .19774 L
s
0 0 0 r
2.5 Mabswid
.43191 .19774 Mdot
.039 .916 .04 r
.5 Mabswid
.29641 .19551 m
.43191 .19786 L
s
0 0 0 r
2.5 Mabswid
.43191 .19786 Mdot
.039 .916 .04 r
.5 Mabswid
.2964 .19565 m
.43191 .19798 L
s
0 0 0 r
2.5 Mabswid
.43191 .19798 Mdot
.039 .916 .04 r
.5 Mabswid
.29639 .19578 m
.43191 .1981 L
s
0 0 0 r
2.5 Mabswid
.43191 .1981 Mdot
.039 .916 .04 r
.5 Mabswid
.29639 .19592 m
.43191 .19822 L
s
0 0 0 r
2.5 Mabswid
.43191 .19822 Mdot
.039 .916 .04 r
.5 Mabswid
.29638 .19605 m
.43191 .19834 L
s
0 0 0 r
2.5 Mabswid
.43191 .19834 Mdot
.039 .916 .04 r
.5 Mabswid
.29637 .19619 m
.43191 .19846 L
s
0 0 0 r
2.5 Mabswid
.43191 .19846 Mdot
.039 .916 .04 r
.5 Mabswid
.29637 .19633 m
.43191 .19858 L
s
0 0 0 r
2.5 Mabswid
.43191 .19858 Mdot
.039 .916 .04 r
.5 Mabswid
.29636 .19646 m
.43191 .1987 L
s
0 0 0 r
2.5 Mabswid
.43191 .1987 Mdot
.039 .916 .04 r
.5 Mabswid
.29635 .1966 m
.43192 .19881 L
s
0 0 0 r
2.5 Mabswid
.43192 .19881 Mdot
.039 .916 .04 r
.5 Mabswid
.29635 .19673 m
.43192 .19893 L
s
0 0 0 r
2.5 Mabswid
.43192 .19893 Mdot
.039 .916 .04 r
.5 Mabswid
.29634 .19687 m
.43192 .19905 L
s
0 0 0 r
2.5 Mabswid
.43192 .19905 Mdot
.039 .916 .04 r
.5 Mabswid
.29633 .19701 m
.43192 .19917 L
s
0 0 0 r
2.5 Mabswid
.43192 .19917 Mdot
.039 .916 .04 r
.5 Mabswid
.29633 .19714 m
.43192 .19929 L
s
0 0 0 r
2.5 Mabswid
.43192 .19929 Mdot
.039 .916 .04 r
.5 Mabswid
.29632 .19728 m
.43192 .19941 L
s
0 0 0 r
2.5 Mabswid
.43192 .19941 Mdot
.039 .916 .04 r
.5 Mabswid
.29631 .19741 m
.43192 .19953 L
s
0 0 0 r
2.5 Mabswid
.43192 .19953 Mdot
.039 .916 .04 r
.5 Mabswid
.29631 .19755 m
.43192 .19965 L
s
0 0 0 r
2.5 Mabswid
.43192 .19965 Mdot
.039 .916 .04 r
.5 Mabswid
.2963 .19769 m
.43192 .19977 L
s
0 0 0 r
2.5 Mabswid
.43192 .19977 Mdot
.039 .916 .04 r
.5 Mabswid
.29629 .19782 m
.43192 .19989 L
s
0 0 0 r
2.5 Mabswid
.43192 .19989 Mdot
.039 .916 .04 r
.5 Mabswid
.29629 .19796 m
.43192 .20001 L
s
0 0 0 r
2.5 Mabswid
.43192 .20001 Mdot
.039 .916 .04 r
.5 Mabswid
.29628 .1981 m
.43193 .20012 L
s
0 0 0 r
2.5 Mabswid
.43193 .20012 Mdot
.039 .916 .04 r
.5 Mabswid
.29628 .19823 m
.43193 .20024 L
s
0 0 0 r
2.5 Mabswid
.43193 .20024 Mdot
.039 .916 .04 r
.5 Mabswid
.29627 .19837 m
.43193 .20036 L
s
0 0 0 r
2.5 Mabswid
.43193 .20036 Mdot
.039 .916 .04 r
.5 Mabswid
.29626 .1985 m
.43193 .20048 L
s
0 0 0 r
2.5 Mabswid
.43193 .20048 Mdot
.039 .916 .04 r
.5 Mabswid
.29626 .19864 m
.43193 .2006 L
s
0 0 0 r
2.5 Mabswid
.43193 .2006 Mdot
.039 .916 .04 r
.5 Mabswid
.29625 .19878 m
.43193 .20072 L
s
0 0 0 r
2.5 Mabswid
.43193 .20072 Mdot
.039 .916 .04 r
.5 Mabswid
.29625 .19891 m
.43193 .20084 L
s
0 0 0 r
2.5 Mabswid
.43193 .20084 Mdot
.039 .916 .04 r
.5 Mabswid
.29624 .19905 m
.43193 .20096 L
s
0 0 0 r
2.5 Mabswid
.43193 .20096 Mdot
.039 .916 .04 r
.5 Mabswid
.29623 .19918 m
.43193 .20108 L
s
0 0 0 r
2.5 Mabswid
.43193 .20108 Mdot
.039 .916 .04 r
.5 Mabswid
.29623 .19932 m
.43193 .2012 L
s
0 0 0 r
2.5 Mabswid
.43193 .2012 Mdot
.039 .916 .04 r
.5 Mabswid
.29622 .19946 m
.43193 .20132 L
s
0 0 0 r
2.5 Mabswid
.43193 .20132 Mdot
.039 .916 .04 r
.5 Mabswid
.29622 .19959 m
.43193 .20143 L
s
0 0 0 r
2.5 Mabswid
.43193 .20143 Mdot
.039 .916 .04 r
.5 Mabswid
.29621 .19973 m
.43193 .20155 L
s
0 0 0 r
2.5 Mabswid
.43193 .20155 Mdot
.039 .916 .04 r
.5 Mabswid
.29621 .19986 m
.43193 .20167 L
s
0 0 0 r
2.5 Mabswid
.43193 .20167 Mdot
.039 .916 .04 r
.5 Mabswid
.2962 .2 m
.43194 .20179 L
s
0 0 0 r
2.5 Mabswid
.43194 .20179 Mdot
.039 .916 .04 r
.5 Mabswid
.2962 .20014 m
.43194 .20191 L
s
0 0 0 r
2.5 Mabswid
.43194 .20191 Mdot
.039 .916 .04 r
.5 Mabswid
.29619 .20027 m
.43194 .20203 L
s
0 0 0 r
2.5 Mabswid
.43194 .20203 Mdot
.039 .916 .04 r
.5 Mabswid
.29619 .20041 m
.43194 .20215 L
s
0 0 0 r
2.5 Mabswid
.43194 .20215 Mdot
.039 .916 .04 r
.5 Mabswid
.29618 .20054 m
.43194 .20227 L
s
0 0 0 r
2.5 Mabswid
.43194 .20227 Mdot
.039 .916 .04 r
.5 Mabswid
.29617 .20068 m
.43194 .20239 L
s
0 0 0 r
2.5 Mabswid
.43194 .20239 Mdot
.039 .916 .04 r
.5 Mabswid
.29617 .20082 m
.43194 .20251 L
s
0 0 0 r
2.5 Mabswid
.43194 .20251 Mdot
.039 .916 .04 r
.5 Mabswid
.29616 .20095 m
.43194 .20262 L
s
0 0 0 r
2.5 Mabswid
.43194 .20262 Mdot
.039 .916 .04 r
.5 Mabswid
.29616 .20109 m
.43194 .20274 L
s
0 0 0 r
2.5 Mabswid
.43194 .20274 Mdot
.039 .916 .04 r
.5 Mabswid
.29615 .20122 m
.43194 .20286 L
s
0 0 0 r
2.5 Mabswid
.43194 .20286 Mdot
.039 .916 .04 r
.5 Mabswid
.29615 .20136 m
.43194 .20298 L
s
0 0 0 r
2.5 Mabswid
.43194 .20298 Mdot
.039 .916 .04 r
.5 Mabswid
.29614 .2015 m
.43194 .2031 L
s
0 0 0 r
2.5 Mabswid
.43194 .2031 Mdot
.039 .916 .04 r
.5 Mabswid
.29614 .20163 m
.43194 .20322 L
s
0 0 0 r
2.5 Mabswid
.43194 .20322 Mdot
.039 .916 .04 r
.5 Mabswid
.29614 .20177 m
.43194 .20334 L
s
0 0 0 r
2.5 Mabswid
.43194 .20334 Mdot
.039 .916 .04 r
.5 Mabswid
.29613 .2019 m
.43194 .20346 L
s
0 0 0 r
2.5 Mabswid
.43194 .20346 Mdot
.039 .916 .04 r
.5 Mabswid
.29613 .20204 m
.43195 .20358 L
s
0 0 0 r
2.5 Mabswid
.43195 .20358 Mdot
.039 .916 .04 r
.5 Mabswid
.29612 .20218 m
.43195 .2037 L
s
0 0 0 r
2.5 Mabswid
.43195 .2037 Mdot
.039 .916 .04 r
.5 Mabswid
.29612 .20231 m
.43195 .20382 L
s
0 0 0 r
2.5 Mabswid
.43195 .20382 Mdot
.039 .916 .04 r
.5 Mabswid
.29611 .20245 m
.43195 .20393 L
s
0 0 0 r
2.5 Mabswid
.43195 .20393 Mdot
.039 .916 .04 r
.5 Mabswid
.29611 .20259 m
.43195 .20405 L
s
0 0 0 r
2.5 Mabswid
.43195 .20405 Mdot
.039 .916 .04 r
.5 Mabswid
.2961 .20272 m
.43195 .20417 L
s
0 0 0 r
2.5 Mabswid
.43195 .20417 Mdot
.039 .916 .04 r
.5 Mabswid
.2961 .20286 m
.43195 .20429 L
s
0 0 0 r
2.5 Mabswid
.43195 .20429 Mdot
.039 .916 .04 r
.5 Mabswid
.2961 .20299 m
.43195 .20441 L
s
0 0 0 r
2.5 Mabswid
.43195 .20441 Mdot
.039 .916 .04 r
.5 Mabswid
.29609 .20313 m
.43195 .20453 L
s
0 0 0 r
2.5 Mabswid
.43195 .20453 Mdot
.039 .916 .04 r
.5 Mabswid
.29609 .20327 m
.43195 .20465 L
s
0 0 0 r
2.5 Mabswid
.43195 .20465 Mdot
.039 .916 .04 r
.5 Mabswid
.29608 .2034 m
.43195 .20477 L
s
0 0 0 r
2.5 Mabswid
.43195 .20477 Mdot
.039 .916 .04 r
.5 Mabswid
.29608 .20354 m
.43195 .20489 L
s
0 0 0 r
2.5 Mabswid
.43195 .20489 Mdot
.039 .916 .04 r
.5 Mabswid
.29607 .20367 m
.43195 .20501 L
s
0 0 0 r
2.5 Mabswid
.43195 .20501 Mdot
.039 .916 .04 r
.5 Mabswid
.29607 .20381 m
.43195 .20512 L
s
0 0 0 r
2.5 Mabswid
.43195 .20512 Mdot
.039 .916 .04 r
.5 Mabswid
.29607 .20395 m
.43195 .20524 L
s
0 0 0 r
2.5 Mabswid
.43195 .20524 Mdot
.039 .916 .04 r
.5 Mabswid
.29606 .20408 m
.43195 .20536 L
s
0 0 0 r
2.5 Mabswid
.43195 .20536 Mdot
.039 .916 .04 r
.5 Mabswid
.29606 .20422 m
.43195 .20548 L
s
0 0 0 r
2.5 Mabswid
.43195 .20548 Mdot
.039 .916 .04 r
.5 Mabswid
.29606 .20435 m
.43195 .2056 L
s
0 0 0 r
2.5 Mabswid
.43195 .2056 Mdot
.039 .916 .04 r
.5 Mabswid
.29605 .20449 m
.43196 .20572 L
s
0 0 0 r
2.5 Mabswid
.43196 .20572 Mdot
.039 .916 .04 r
.5 Mabswid
.29605 .20463 m
.43196 .20584 L
s
0 0 0 r
2.5 Mabswid
.43196 .20584 Mdot
.039 .916 .04 r
.5 Mabswid
.29604 .20476 m
.43196 .20596 L
s
0 0 0 r
2.5 Mabswid
.43196 .20596 Mdot
.039 .916 .04 r
.5 Mabswid
.29604 .2049 m
.43196 .20608 L
s
0 0 0 r
2.5 Mabswid
.43196 .20608 Mdot
.039 .916 .04 r
.5 Mabswid
.29604 .20503 m
.43196 .2062 L
s
0 0 0 r
2.5 Mabswid
.43196 .2062 Mdot
.039 .916 .04 r
.5 Mabswid
.29603 .20517 m
.43196 .20631 L
s
0 0 0 r
2.5 Mabswid
.43196 .20631 Mdot
.039 .916 .04 r
.5 Mabswid
.29603 .20531 m
.43196 .20643 L
s
0 0 0 r
2.5 Mabswid
.43196 .20643 Mdot
.039 .916 .04 r
.5 Mabswid
.29603 .20544 m
.43196 .20655 L
s
0 0 0 r
2.5 Mabswid
.43196 .20655 Mdot
.039 .916 .04 r
.5 Mabswid
.29602 .20558 m
.43196 .20667 L
s
0 0 0 r
2.5 Mabswid
.43196 .20667 Mdot
.039 .916 .04 r
.5 Mabswid
.29602 .20571 m
.43196 .20679 L
s
0 0 0 r
2.5 Mabswid
.43196 .20679 Mdot
.039 .916 .04 r
.5 Mabswid
.29602 .20585 m
.43196 .20691 L
s
0 0 0 r
2.5 Mabswid
.43196 .20691 Mdot
.039 .916 .04 r
.5 Mabswid
.29601 .20599 m
.43196 .20703 L
s
0 0 0 r
2.5 Mabswid
.43196 .20703 Mdot
.039 .916 .04 r
.5 Mabswid
.29601 .20612 m
.43196 .20715 L
s
0 0 0 r
2.5 Mabswid
.43196 .20715 Mdot
.039 .916 .04 r
.5 Mabswid
.29601 .20626 m
.43196 .20727 L
s
0 0 0 r
2.5 Mabswid
.43196 .20727 Mdot
.039 .916 .04 r
.5 Mabswid
.296 .20639 m
.43196 .20739 L
s
0 0 0 r
2.5 Mabswid
.43196 .20739 Mdot
.039 .916 .04 r
.5 Mabswid
.296 .20653 m
.43196 .2075 L
s
0 0 0 r
2.5 Mabswid
.43196 .2075 Mdot
.039 .916 .04 r
.5 Mabswid
.296 .20667 m
.43196 .20762 L
s
0 0 0 r
2.5 Mabswid
.43196 .20762 Mdot
.039 .916 .04 r
.5 Mabswid
.296 .2068 m
.43196 .20774 L
s
0 0 0 r
2.5 Mabswid
.43196 .20774 Mdot
.039 .916 .04 r
.5 Mabswid
.29599 .20694 m
.43196 .20786 L
s
0 0 0 r
2.5 Mabswid
.43196 .20786 Mdot
.039 .916 .04 r
.5 Mabswid
.29599 .20707 m
.43196 .20798 L
s
0 0 0 r
2.5 Mabswid
.43196 .20798 Mdot
.039 .916 .04 r
.5 Mabswid
.29599 .20721 m
.43196 .2081 L
s
0 0 0 r
2.5 Mabswid
.43196 .2081 Mdot
.039 .916 .04 r
.5 Mabswid
.29599 .20735 m
.43196 .20822 L
s
0 0 0 r
2.5 Mabswid
.43196 .20822 Mdot
.039 .916 .04 r
.5 Mabswid
.29598 .20748 m
.43196 .20834 L
s
0 0 0 r
2.5 Mabswid
.43196 .20834 Mdot
.039 .916 .04 r
.5 Mabswid
.29598 .20762 m
.43196 .20846 L
s
0 0 0 r
2.5 Mabswid
.43196 .20846 Mdot
.039 .916 .04 r
.5 Mabswid
.29598 .20776 m
.43197 .20858 L
s
0 0 0 r
2.5 Mabswid
.43197 .20858 Mdot
.039 .916 .04 r
.5 Mabswid
.29598 .20789 m
.43197 .20869 L
s
0 0 0 r
2.5 Mabswid
.43197 .20869 Mdot
.039 .916 .04 r
.5 Mabswid
.29597 .20803 m
.43197 .20881 L
s
0 0 0 r
2.5 Mabswid
.43197 .20881 Mdot
.039 .916 .04 r
.5 Mabswid
.29597 .20816 m
.43197 .20893 L
s
0 0 0 r
2.5 Mabswid
.43197 .20893 Mdot
.039 .916 .04 r
.5 Mabswid
.29597 .2083 m
.43197 .20905 L
s
0 0 0 r
2.5 Mabswid
.43197 .20905 Mdot
.039 .916 .04 r
.5 Mabswid
.29597 .20844 m
.43197 .20917 L
s
0 0 0 r
2.5 Mabswid
.43197 .20917 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .20857 m
.43197 .20929 L
s
0 0 0 r
2.5 Mabswid
.43197 .20929 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .20871 m
.43197 .20941 L
s
0 0 0 r
2.5 Mabswid
.43197 .20941 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .20884 m
.43197 .20953 L
s
0 0 0 r
2.5 Mabswid
.43197 .20953 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .20898 m
.43197 .20965 L
s
0 0 0 r
2.5 Mabswid
.43197 .20965 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .20912 m
.43197 .20976 L
s
0 0 0 r
2.5 Mabswid
.43197 .20976 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .20925 m
.43197 .20988 L
s
0 0 0 r
2.5 Mabswid
.43197 .20988 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .20939 m
.43197 .21 L
s
0 0 0 r
2.5 Mabswid
.43197 .21 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .20952 m
.43197 .21012 L
s
0 0 0 r
2.5 Mabswid
.43197 .21012 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .20966 m
.43197 .21024 L
s
0 0 0 r
2.5 Mabswid
.43197 .21024 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .2098 m
.43197 .21036 L
s
0 0 0 r
2.5 Mabswid
.43197 .21036 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .20993 m
.43197 .21048 L
s
0 0 0 r
2.5 Mabswid
.43197 .21048 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .21007 m
.43197 .2106 L
s
0 0 0 r
2.5 Mabswid
.43197 .2106 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .2102 m
.43197 .21072 L
s
0 0 0 r
2.5 Mabswid
.43197 .21072 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .21034 m
.43197 .21084 L
s
0 0 0 r
2.5 Mabswid
.43197 .21084 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .21048 m
.43197 .21095 L
s
0 0 0 r
2.5 Mabswid
.43197 .21095 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .21061 m
.43197 .21107 L
s
0 0 0 r
2.5 Mabswid
.43197 .21107 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .21075 m
.43197 .21119 L
s
0 0 0 r
2.5 Mabswid
.43197 .21119 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21088 m
.43197 .21131 L
s
0 0 0 r
2.5 Mabswid
.43197 .21131 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21102 m
.43197 .21143 L
s
0 0 0 r
2.5 Mabswid
.43197 .21143 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21116 m
.43197 .21155 L
s
0 0 0 r
2.5 Mabswid
.43197 .21155 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21129 m
.43197 .21167 L
s
0 0 0 r
2.5 Mabswid
.43197 .21167 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21143 m
.43197 .21179 L
s
0 0 0 r
2.5 Mabswid
.43197 .21179 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21156 m
.43197 .21191 L
s
0 0 0 r
2.5 Mabswid
.43197 .21191 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .2117 m
.43197 .21203 L
s
0 0 0 r
2.5 Mabswid
.43197 .21203 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21184 m
.43197 .21214 L
s
0 0 0 r
2.5 Mabswid
.43197 .21214 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21197 m
.43197 .21226 L
s
0 0 0 r
2.5 Mabswid
.43197 .21226 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21211 m
.43197 .21238 L
s
0 0 0 r
2.5 Mabswid
.43197 .21238 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21224 m
.43197 .2125 L
s
0 0 0 r
2.5 Mabswid
.43197 .2125 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21238 m
.43197 .21262 L
s
0 0 0 r
2.5 Mabswid
.43197 .21262 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21252 m
.43197 .21274 L
s
0 0 0 r
2.5 Mabswid
.43197 .21274 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21265 m
.43197 .21286 L
s
0 0 0 r
2.5 Mabswid
.43197 .21286 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21279 m
.43197 .21298 L
s
0 0 0 r
2.5 Mabswid
.43197 .21298 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21293 m
.43197 .2131 L
s
0 0 0 r
2.5 Mabswid
.43197 .2131 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21306 m
.43197 .21322 L
s
0 0 0 r
2.5 Mabswid
.43197 .21322 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .2132 m
.43197 .21333 L
s
0 0 0 r
2.5 Mabswid
.43197 .21333 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21333 m
.43197 .21345 L
s
0 0 0 r
2.5 Mabswid
.43197 .21345 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21347 m
.43197 .21357 L
s
0 0 0 r
2.5 Mabswid
.43197 .21357 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21361 m
.43197 .21369 L
s
0 0 0 r
2.5 Mabswid
.43197 .21369 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21374 m
.43197 .21381 L
s
0 0 0 r
2.5 Mabswid
.43197 .21381 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21388 m
.43197 .21393 L
s
0 0 0 r
2.5 Mabswid
.43197 .21393 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21401 m
.43197 .21405 L
s
0 0 0 r
2.5 Mabswid
.43197 .21405 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21415 m
.43197 .21417 L
s
0 0 0 r
2.5 Mabswid
.43197 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21429 m
.43197 .21429 L
s
0 0 0 r
2.5 Mabswid
.43197 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21442 m
.43197 .2144 L
s
0 0 0 r
2.5 Mabswid
.43197 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21456 m
.43197 .21452 L
s
0 0 0 r
2.5 Mabswid
.43197 .21452 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21469 m
.43197 .21464 L
s
0 0 0 r
2.5 Mabswid
.43197 .21464 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21483 m
.43197 .21476 L
s
0 0 0 r
2.5 Mabswid
.43197 .21476 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21497 m
.43197 .21488 L
s
0 0 0 r
2.5 Mabswid
.43197 .21488 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .2151 m
.43197 .215 L
s
0 0 0 r
2.5 Mabswid
.43197 .215 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21524 m
.43197 .21512 L
s
0 0 0 r
2.5 Mabswid
.43197 .21512 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21537 m
.43197 .21524 L
s
0 0 0 r
2.5 Mabswid
.43197 .21524 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21551 m
.43197 .21536 L
s
0 0 0 r
2.5 Mabswid
.43197 .21536 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21565 m
.43197 .21548 L
s
0 0 0 r
2.5 Mabswid
.43197 .21548 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21578 m
.43197 .21559 L
s
0 0 0 r
2.5 Mabswid
.43197 .21559 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21592 m
.43197 .21571 L
s
0 0 0 r
2.5 Mabswid
.43197 .21571 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21605 m
.43197 .21583 L
s
0 0 0 r
2.5 Mabswid
.43197 .21583 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21619 m
.43197 .21595 L
s
0 0 0 r
2.5 Mabswid
.43197 .21595 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21633 m
.43197 .21607 L
s
0 0 0 r
2.5 Mabswid
.43197 .21607 Mdot
.039 .916 .04 r
.5 Mabswid
.29592 .21646 m
.43197 .21619 L
s
0 0 0 r
2.5 Mabswid
.43197 .21619 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .2166 m
.43197 .21631 L
s
0 0 0 r
2.5 Mabswid
.43197 .21631 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21673 m
.43197 .21643 L
s
0 0 0 r
2.5 Mabswid
.43197 .21643 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21687 m
.43197 .21655 L
s
0 0 0 r
2.5 Mabswid
.43197 .21655 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21701 m
.43197 .21666 L
s
0 0 0 r
2.5 Mabswid
.43197 .21666 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21714 m
.43197 .21678 L
s
0 0 0 r
2.5 Mabswid
.43197 .21678 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21728 m
.43197 .2169 L
s
0 0 0 r
2.5 Mabswid
.43197 .2169 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21741 m
.43197 .21702 L
s
0 0 0 r
2.5 Mabswid
.43197 .21702 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21755 m
.43197 .21714 L
s
0 0 0 r
2.5 Mabswid
.43197 .21714 Mdot
.039 .916 .04 r
.5 Mabswid
.29593 .21769 m
.43197 .21726 L
s
0 0 0 r
2.5 Mabswid
.43197 .21726 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .21782 m
.43197 .21738 L
s
0 0 0 r
2.5 Mabswid
.43197 .21738 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .21796 m
.43197 .2175 L
s
0 0 0 r
2.5 Mabswid
.43197 .2175 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .2181 m
.43197 .21762 L
s
0 0 0 r
2.5 Mabswid
.43197 .21762 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .21823 m
.43197 .21774 L
s
0 0 0 r
2.5 Mabswid
.43197 .21774 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .21837 m
.43197 .21785 L
s
0 0 0 r
2.5 Mabswid
.43197 .21785 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .2185 m
.43197 .21797 L
s
0 0 0 r
2.5 Mabswid
.43197 .21797 Mdot
.039 .916 .04 r
.5 Mabswid
.29594 .21864 m
.43197 .21809 L
s
0 0 0 r
2.5 Mabswid
.43197 .21809 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .21878 m
.43197 .21821 L
s
0 0 0 r
2.5 Mabswid
.43197 .21821 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .21891 m
.43197 .21833 L
s
0 0 0 r
2.5 Mabswid
.43197 .21833 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .21905 m
.43197 .21845 L
s
0 0 0 r
2.5 Mabswid
.43197 .21845 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .21918 m
.43197 .21857 L
s
0 0 0 r
2.5 Mabswid
.43197 .21857 Mdot
.039 .916 .04 r
.5 Mabswid
.29595 .21932 m
.43197 .21869 L
s
0 0 0 r
2.5 Mabswid
.43197 .21869 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .21946 m
.43197 .21881 L
s
0 0 0 r
2.5 Mabswid
.43197 .21881 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .21959 m
.43197 .21893 L
s
0 0 0 r
2.5 Mabswid
.43197 .21893 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .21973 m
.43197 .21904 L
s
0 0 0 r
2.5 Mabswid
.43197 .21904 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .21986 m
.43197 .21916 L
s
0 0 0 r
2.5 Mabswid
.43197 .21916 Mdot
.039 .916 .04 r
.5 Mabswid
.29596 .22 m
.43197 .21928 L
s
0 0 0 r
2.5 Mabswid
.43197 .21928 Mdot
.039 .916 .04 r
.5 Mabswid
.29597 .22014 m
.43197 .2194 L
s
0 0 0 r
2.5 Mabswid
.43197 .2194 Mdot
.039 .916 .04 r
.5 Mabswid
.29597 .22027 m
.43197 .21952 L
s
0 0 0 r
2.5 Mabswid
.43197 .21952 Mdot
.039 .916 .04 r
.5 Mabswid
.29597 .22041 m
.43197 .21964 L
s
0 0 0 r
2.5 Mabswid
.43197 .21964 Mdot
.039 .916 .04 r
.5 Mabswid
.29597 .22054 m
.43197 .21976 L
s
0 0 0 r
2.5 Mabswid
.43197 .21976 Mdot
.039 .916 .04 r
.5 Mabswid
.29598 .22068 m
.43197 .21988 L
s
0 0 0 r
2.5 Mabswid
.43197 .21988 Mdot
.039 .916 .04 r
.5 Mabswid
.29598 .22082 m
.43197 .22 L
s
0 0 0 r
2.5 Mabswid
.43197 .22 Mdot
.039 .916 .04 r
.5 Mabswid
.29598 .22095 m
.43196 .22012 L
s
0 0 0 r
2.5 Mabswid
.43196 .22012 Mdot
.039 .916 .04 r
.5 Mabswid
.29598 .22109 m
.43196 .22023 L
s
0 0 0 r
2.5 Mabswid
.43196 .22023 Mdot
.039 .916 .04 r
.5 Mabswid
.29599 .22122 m
.43196 .22035 L
s
0 0 0 r
2.5 Mabswid
.43196 .22035 Mdot
.039 .916 .04 r
.5 Mabswid
.29599 .22136 m
.43196 .22047 L
s
0 0 0 r
2.5 Mabswid
.43196 .22047 Mdot
.039 .916 .04 r
.5 Mabswid
.29599 .2215 m
.43196 .22059 L
s
0 0 0 r
2.5 Mabswid
.43196 .22059 Mdot
.039 .916 .04 r
.5 Mabswid
.29599 .22163 m
.43196 .22071 L
s
0 0 0 r
2.5 Mabswid
.43196 .22071 Mdot
.039 .916 .04 r
.5 Mabswid
.296 .22177 m
.43196 .22083 L
s
0 0 0 r
2.5 Mabswid
.43196 .22083 Mdot
.039 .916 .04 r
.5 Mabswid
.296 .2219 m
.43196 .22095 L
s
0 0 0 r
2.5 Mabswid
.43196 .22095 Mdot
.039 .916 .04 r
.5 Mabswid
.296 .22204 m
.43196 .22107 L
s
0 0 0 r
2.5 Mabswid
.43196 .22107 Mdot
.039 .916 .04 r
.5 Mabswid
.296 .22218 m
.43196 .22119 L
s
0 0 0 r
2.5 Mabswid
.43196 .22119 Mdot
.039 .916 .04 r
.5 Mabswid
.29601 .22231 m
.43196 .22131 L
s
0 0 0 r
2.5 Mabswid
.43196 .22131 Mdot
.039 .916 .04 r
.5 Mabswid
.29601 .22245 m
.43196 .22142 L
s
0 0 0 r
2.5 Mabswid
.43196 .22142 Mdot
.039 .916 .04 r
.5 Mabswid
.29601 .22259 m
.43196 .22154 L
s
0 0 0 r
2.5 Mabswid
.43196 .22154 Mdot
.039 .916 .04 r
.5 Mabswid
.29602 .22272 m
.43196 .22166 L
s
0 0 0 r
2.5 Mabswid
.43196 .22166 Mdot
.039 .916 .04 r
.5 Mabswid
.29602 .22286 m
.43196 .22178 L
s
0 0 0 r
2.5 Mabswid
.43196 .22178 Mdot
.039 .916 .04 r
.5 Mabswid
.29602 .22299 m
.43196 .2219 L
s
0 0 0 r
2.5 Mabswid
.43196 .2219 Mdot
.039 .916 .04 r
.5 Mabswid
.29603 .22313 m
.43196 .22202 L
s
0 0 0 r
2.5 Mabswid
.43196 .22202 Mdot
.039 .916 .04 r
.5 Mabswid
.29603 .22327 m
.43196 .22214 L
s
0 0 0 r
2.5 Mabswid
.43196 .22214 Mdot
.039 .916 .04 r
.5 Mabswid
.29603 .2234 m
.43196 .22226 L
s
0 0 0 r
2.5 Mabswid
.43196 .22226 Mdot
.039 .916 .04 r
.5 Mabswid
.29604 .22354 m
.43196 .22238 L
s
0 0 0 r
2.5 Mabswid
.43196 .22238 Mdot
.039 .916 .04 r
.5 Mabswid
.29604 .22367 m
.43196 .2225 L
s
0 0 0 r
2.5 Mabswid
.43196 .2225 Mdot
.039 .916 .04 r
.5 Mabswid
.29604 .22381 m
.43196 .22261 L
s
0 0 0 r
2.5 Mabswid
.43196 .22261 Mdot
.039 .916 .04 r
.5 Mabswid
.29605 .22395 m
.43196 .22273 L
s
0 0 0 r
2.5 Mabswid
.43196 .22273 Mdot
.039 .916 .04 r
.5 Mabswid
.29605 .22408 m
.43196 .22285 L
s
0 0 0 r
2.5 Mabswid
.43196 .22285 Mdot
.039 .916 .04 r
.5 Mabswid
.29606 .22422 m
.43195 .22297 L
s
0 0 0 r
2.5 Mabswid
.43195 .22297 Mdot
.039 .916 .04 r
.5 Mabswid
.29606 .22435 m
.43195 .22309 L
s
0 0 0 r
2.5 Mabswid
.43195 .22309 Mdot
.039 .916 .04 r
.5 Mabswid
.29606 .22449 m
.43195 .22321 L
s
0 0 0 r
2.5 Mabswid
.43195 .22321 Mdot
.039 .916 .04 r
.5 Mabswid
.29607 .22463 m
.43195 .22333 L
s
0 0 0 r
2.5 Mabswid
.43195 .22333 Mdot
.039 .916 .04 r
.5 Mabswid
.29607 .22476 m
.43195 .22345 L
s
0 0 0 r
2.5 Mabswid
.43195 .22345 Mdot
.039 .916 .04 r
.5 Mabswid
.29607 .2249 m
.43195 .22357 L
s
0 0 0 r
2.5 Mabswid
.43195 .22357 Mdot
.039 .916 .04 r
.5 Mabswid
.29608 .22503 m
.43195 .22369 L
s
0 0 0 r
2.5 Mabswid
.43195 .22369 Mdot
.039 .916 .04 r
.5 Mabswid
.29608 .22517 m
.43195 .2238 L
s
0 0 0 r
2.5 Mabswid
.43195 .2238 Mdot
.039 .916 .04 r
.5 Mabswid
.29609 .22531 m
.43195 .22392 L
s
0 0 0 r
2.5 Mabswid
.43195 .22392 Mdot
.039 .916 .04 r
.5 Mabswid
.29609 .22544 m
.43195 .22404 L
s
0 0 0 r
2.5 Mabswid
.43195 .22404 Mdot
.039 .916 .04 r
.5 Mabswid
.2961 .22558 m
.43195 .22416 L
s
0 0 0 r
2.5 Mabswid
.43195 .22416 Mdot
.039 .916 .04 r
.5 Mabswid
.2961 .22571 m
.43195 .22428 L
s
0 0 0 r
2.5 Mabswid
.43195 .22428 Mdot
.039 .916 .04 r
.5 Mabswid
.2961 .22585 m
.43195 .2244 L
s
0 0 0 r
2.5 Mabswid
.43195 .2244 Mdot
.039 .916 .04 r
.5 Mabswid
.29611 .22599 m
.43195 .22452 L
s
0 0 0 r
2.5 Mabswid
.43195 .22452 Mdot
.039 .916 .04 r
.5 Mabswid
.29611 .22612 m
.43195 .22464 L
s
0 0 0 r
2.5 Mabswid
.43195 .22464 Mdot
.039 .916 .04 r
.5 Mabswid
.29612 .22626 m
.43195 .22476 L
s
0 0 0 r
2.5 Mabswid
.43195 .22476 Mdot
.039 .916 .04 r
.5 Mabswid
.29612 .22639 m
.43195 .22488 L
s
0 0 0 r
2.5 Mabswid
.43195 .22488 Mdot
.039 .916 .04 r
.5 Mabswid
.29613 .22653 m
.43195 .22499 L
s
0 0 0 r
2.5 Mabswid
.43195 .22499 Mdot
.039 .916 .04 r
.5 Mabswid
.29613 .22667 m
.43194 .22511 L
s
0 0 0 r
2.5 Mabswid
.43194 .22511 Mdot
.039 .916 .04 r
.5 Mabswid
.29614 .2268 m
.43194 .22523 L
s
0 0 0 r
2.5 Mabswid
.43194 .22523 Mdot
.039 .916 .04 r
.5 Mabswid
.29614 .22694 m
.43194 .22535 L
s
0 0 0 r
2.5 Mabswid
.43194 .22535 Mdot
.039 .916 .04 r
.5 Mabswid
.29614 .22707 m
.43194 .22547 L
s
0 0 0 r
2.5 Mabswid
.43194 .22547 Mdot
.039 .916 .04 r
.5 Mabswid
.29615 .22721 m
.43194 .22559 L
s
0 0 0 r
2.5 Mabswid
.43194 .22559 Mdot
.039 .916 .04 r
.5 Mabswid
.29615 .22735 m
.43194 .22571 L
s
0 0 0 r
2.5 Mabswid
.43194 .22571 Mdot
.039 .916 .04 r
.5 Mabswid
.29616 .22748 m
.43194 .22583 L
s
0 0 0 r
2.5 Mabswid
.43194 .22583 Mdot
.039 .916 .04 r
.5 Mabswid
.29616 .22762 m
.43194 .22595 L
s
0 0 0 r
2.5 Mabswid
.43194 .22595 Mdot
.039 .916 .04 r
.5 Mabswid
.29617 .22776 m
.43194 .22607 L
s
0 0 0 r
2.5 Mabswid
.43194 .22607 Mdot
.039 .916 .04 r
.5 Mabswid
.29617 .22789 m
.43194 .22618 L
s
0 0 0 r
2.5 Mabswid
.43194 .22618 Mdot
.039 .916 .04 r
.5 Mabswid
.29618 .22803 m
.43194 .2263 L
s
0 0 0 r
2.5 Mabswid
.43194 .2263 Mdot
.039 .916 .04 r
.5 Mabswid
.29619 .22816 m
.43194 .22642 L
s
0 0 0 r
2.5 Mabswid
.43194 .22642 Mdot
.039 .916 .04 r
.5 Mabswid
.29619 .2283 m
.43194 .22654 L
s
0 0 0 r
2.5 Mabswid
.43194 .22654 Mdot
.039 .916 .04 r
.5 Mabswid
.2962 .22844 m
.43194 .22666 L
s
0 0 0 r
2.5 Mabswid
.43194 .22666 Mdot
.039 .916 .04 r
.5 Mabswid
.2962 .22857 m
.43194 .22678 L
s
0 0 0 r
2.5 Mabswid
.43194 .22678 Mdot
.039 .916 .04 r
.5 Mabswid
.29621 .22871 m
.43193 .2269 L
s
0 0 0 r
2.5 Mabswid
.43193 .2269 Mdot
.039 .916 .04 r
.5 Mabswid
.29621 .22884 m
.43193 .22702 L
s
0 0 0 r
2.5 Mabswid
.43193 .22702 Mdot
.039 .916 .04 r
.5 Mabswid
.29622 .22898 m
.43193 .22714 L
s
0 0 0 r
2.5 Mabswid
.43193 .22714 Mdot
.039 .916 .04 r
.5 Mabswid
.29622 .22912 m
.43193 .22726 L
s
0 0 0 r
2.5 Mabswid
.43193 .22726 Mdot
.039 .916 .04 r
.5 Mabswid
.29623 .22925 m
.43193 .22738 L
s
0 0 0 r
2.5 Mabswid
.43193 .22738 Mdot
.039 .916 .04 r
.5 Mabswid
.29623 .22939 m
.43193 .22749 L
s
0 0 0 r
2.5 Mabswid
.43193 .22749 Mdot
.039 .916 .04 r
.5 Mabswid
.29624 .22952 m
.43193 .22761 L
s
0 0 0 r
2.5 Mabswid
.43193 .22761 Mdot
.039 .916 .04 r
.5 Mabswid
.29625 .22966 m
.43193 .22773 L
s
0 0 0 r
2.5 Mabswid
.43193 .22773 Mdot
.039 .916 .04 r
.5 Mabswid
.29625 .2298 m
.43193 .22785 L
s
0 0 0 r
2.5 Mabswid
.43193 .22785 Mdot
.039 .916 .04 r
.5 Mabswid
.29626 .22993 m
.43193 .22797 L
s
0 0 0 r
2.5 Mabswid
.43193 .22797 Mdot
.039 .916 .04 r
.5 Mabswid
.29626 .23007 m
.43193 .22809 L
s
0 0 0 r
2.5 Mabswid
.43193 .22809 Mdot
.039 .916 .04 r
.5 Mabswid
.29627 .2302 m
.43193 .22821 L
s
0 0 0 r
2.5 Mabswid
.43193 .22821 Mdot
.039 .916 .04 r
.5 Mabswid
.29628 .23034 m
.43193 .22833 L
s
0 0 0 r
2.5 Mabswid
.43193 .22833 Mdot
.039 .916 .04 r
.5 Mabswid
.29628 .23048 m
.43193 .22845 L
s
0 0 0 r
2.5 Mabswid
.43193 .22845 Mdot
.039 .916 .04 r
.5 Mabswid
.29629 .23061 m
.43192 .22857 L
s
0 0 0 r
2.5 Mabswid
.43192 .22857 Mdot
.039 .916 .04 r
.5 Mabswid
.29629 .23075 m
.43192 .22868 L
s
0 0 0 r
2.5 Mabswid
.43192 .22868 Mdot
.039 .916 .04 r
.5 Mabswid
.2963 .23088 m
.43192 .2288 L
s
0 0 0 r
2.5 Mabswid
.43192 .2288 Mdot
.039 .916 .04 r
.5 Mabswid
.29631 .23102 m
.43192 .22892 L
s
0 0 0 r
2.5 Mabswid
.43192 .22892 Mdot
.039 .916 .04 r
.5 Mabswid
.29631 .23116 m
.43192 .22904 L
s
0 0 0 r
2.5 Mabswid
.43192 .22904 Mdot
.039 .916 .04 r
.5 Mabswid
.29632 .23129 m
.43192 .22916 L
s
0 0 0 r
2.5 Mabswid
.43192 .22916 Mdot
.039 .916 .04 r
.5 Mabswid
.29633 .23143 m
.43192 .22928 L
s
0 0 0 r
2.5 Mabswid
.43192 .22928 Mdot
.039 .916 .04 r
.5 Mabswid
.29633 .23156 m
.43192 .2294 L
s
0 0 0 r
2.5 Mabswid
.43192 .2294 Mdot
.039 .916 .04 r
.5 Mabswid
.29634 .2317 m
.43192 .22952 L
s
0 0 0 r
2.5 Mabswid
.43192 .22952 Mdot
.039 .916 .04 r
.5 Mabswid
.29635 .23184 m
.43192 .22964 L
s
0 0 0 r
2.5 Mabswid
.43192 .22964 Mdot
.039 .916 .04 r
.5 Mabswid
.29635 .23197 m
.43192 .22976 L
s
0 0 0 r
2.5 Mabswid
.43192 .22976 Mdot
.039 .916 .04 r
.5 Mabswid
.29636 .23211 m
.43191 .22988 L
s
0 0 0 r
2.5 Mabswid
.43191 .22988 Mdot
.039 .916 .04 r
.5 Mabswid
.29637 .23224 m
.43191 .22999 L
s
0 0 0 r
2.5 Mabswid
.43191 .22999 Mdot
.039 .916 .04 r
.5 Mabswid
.29637 .23238 m
.43191 .23011 L
s
0 0 0 r
2.5 Mabswid
.43191 .23011 Mdot
.039 .916 .04 r
.5 Mabswid
.29638 .23252 m
.43191 .23023 L
s
0 0 0 r
2.5 Mabswid
.43191 .23023 Mdot
.039 .916 .04 r
.5 Mabswid
.29639 .23265 m
.43191 .23035 L
s
0 0 0 r
2.5 Mabswid
.43191 .23035 Mdot
.039 .916 .04 r
.5 Mabswid
.29639 .23279 m
.43191 .23047 L
s
0 0 0 r
2.5 Mabswid
.43191 .23047 Mdot
.039 .916 .04 r
.5 Mabswid
.2964 .23293 m
.43191 .23059 L
s
0 0 0 r
2.5 Mabswid
.43191 .23059 Mdot
.039 .916 .04 r
.5 Mabswid
.29641 .23306 m
.43191 .23071 L
s
0 0 0 r
2.5 Mabswid
.43191 .23071 Mdot
.039 .916 .04 r
.5 Mabswid
.29641 .2332 m
.43191 .23083 L
s
0 0 0 r
2.5 Mabswid
.43191 .23083 Mdot
.039 .916 .04 r
.5 Mabswid
.29642 .23333 m
.43191 .23095 L
s
0 0 0 r
2.5 Mabswid
.43191 .23095 Mdot
.039 .916 .04 r
.5 Mabswid
.29643 .23347 m
.43191 .23107 L
s
0 0 0 r
2.5 Mabswid
.43191 .23107 Mdot
.039 .916 .04 r
.5 Mabswid
.29644 .23361 m
.4319 .23119 L
s
0 0 0 r
2.5 Mabswid
.4319 .23119 Mdot
.039 .916 .04 r
.5 Mabswid
.29644 .23374 m
.4319 .23131 L
s
0 0 0 r
2.5 Mabswid
.4319 .23131 Mdot
.039 .916 .04 r
.5 Mabswid
.29645 .23388 m
.4319 .23142 L
s
0 0 0 r
2.5 Mabswid
.4319 .23142 Mdot
.039 .916 .04 r
.5 Mabswid
.29646 .23401 m
.4319 .23154 L
s
0 0 0 r
2.5 Mabswid
.4319 .23154 Mdot
.039 .916 .04 r
.5 Mabswid
.29647 .23415 m
.4319 .23166 L
s
0 0 0 r
2.5 Mabswid
.4319 .23166 Mdot
.039 .916 .04 r
.5 Mabswid
.29647 .23429 m
.4319 .23178 L
s
0 0 0 r
2.5 Mabswid
.4319 .23178 Mdot
.039 .916 .04 r
.5 Mabswid
.29648 .23442 m
.4319 .2319 L
s
0 0 0 r
2.5 Mabswid
.4319 .2319 Mdot
.039 .916 .04 r
.5 Mabswid
.29649 .23456 m
.4319 .23202 L
s
0 0 0 r
2.5 Mabswid
.4319 .23202 Mdot
.039 .916 .04 r
.5 Mabswid
.2965 .23469 m
.4319 .23214 L
s
0 0 0 r
2.5 Mabswid
.4319 .23214 Mdot
.039 .916 .04 r
.5 Mabswid
.2965 .23483 m
.4319 .23226 L
s
0 0 0 r
2.5 Mabswid
.4319 .23226 Mdot
.039 .916 .04 r
.5 Mabswid
.29651 .23497 m
.43189 .23238 L
s
0 0 0 r
2.5 Mabswid
.43189 .23238 Mdot
.039 .916 .04 r
.5 Mabswid
.29652 .2351 m
.43189 .2325 L
s
0 0 0 r
2.5 Mabswid
.43189 .2325 Mdot
.039 .916 .04 r
.5 Mabswid
.29653 .23524 m
.43189 .23262 L
s
0 0 0 r
2.5 Mabswid
.43189 .23262 Mdot
.039 .916 .04 r
.5 Mabswid
.29653 .23537 m
.43189 .23273 L
s
0 0 0 r
2.5 Mabswid
.43189 .23273 Mdot
.039 .916 .04 r
.5 Mabswid
.29654 .23551 m
.43189 .23285 L
s
0 0 0 r
2.5 Mabswid
.43189 .23285 Mdot
.039 .916 .04 r
.5 Mabswid
.29655 .23565 m
.43189 .23297 L
s
0 0 0 r
2.5 Mabswid
.43189 .23297 Mdot
.039 .916 .04 r
.5 Mabswid
.29656 .23578 m
.43189 .23309 L
s
0 0 0 r
2.5 Mabswid
.43189 .23309 Mdot
.039 .916 .04 r
.5 Mabswid
.29657 .23592 m
.43189 .23321 L
s
0 0 0 r
2.5 Mabswid
.43189 .23321 Mdot
.039 .916 .04 r
.5 Mabswid
.29658 .23605 m
.43189 .23333 L
s
0 0 0 r
2.5 Mabswid
.43189 .23333 Mdot
.039 .916 .04 r
.5 Mabswid
.29658 .23619 m
.43189 .23345 L
s
0 0 0 r
2.5 Mabswid
.43189 .23345 Mdot
.039 .916 .04 r
.5 Mabswid
.29659 .23633 m
.43188 .23357 L
s
0 0 0 r
2.5 Mabswid
.43188 .23357 Mdot
.039 .916 .04 r
.5 Mabswid
.2966 .23646 m
.43188 .23369 L
s
0 0 0 r
2.5 Mabswid
.43188 .23369 Mdot
.039 .916 .04 r
.5 Mabswid
.29661 .2366 m
.43188 .23381 L
s
0 0 0 r
2.5 Mabswid
.43188 .23381 Mdot
.039 .916 .04 r
.5 Mabswid
.29662 .23673 m
.43188 .23393 L
s
0 0 0 r
2.5 Mabswid
.43188 .23393 Mdot
.039 .916 .04 r
.5 Mabswid
.29663 .23687 m
.43188 .23405 L
s
0 0 0 r
2.5 Mabswid
.43188 .23405 Mdot
.039 .916 .04 r
.5 Mabswid
.29663 .23701 m
.43188 .23417 L
s
0 0 0 r
2.5 Mabswid
.43188 .23417 Mdot
.039 .916 .04 r
.5 Mabswid
.29664 .23714 m
.43188 .23428 L
s
0 0 0 r
2.5 Mabswid
.43188 .23428 Mdot
.039 .916 .04 r
.5 Mabswid
.29665 .23728 m
.43188 .2344 L
s
0 0 0 r
2.5 Mabswid
.43188 .2344 Mdot
.039 .916 .04 r
.5 Mabswid
.29666 .23741 m
.43188 .23452 L
s
0 0 0 r
2.5 Mabswid
.43188 .23452 Mdot
.039 .916 .04 r
.5 Mabswid
.29667 .23755 m
.43187 .23464 L
s
0 0 0 r
2.5 Mabswid
.43187 .23464 Mdot
.039 .916 .04 r
.5 Mabswid
.29668 .23769 m
.43187 .23476 L
s
0 0 0 r
2.5 Mabswid
.43187 .23476 Mdot
.039 .916 .04 r
.5 Mabswid
.29669 .23782 m
.43187 .23488 L
s
0 0 0 r
2.5 Mabswid
.43187 .23488 Mdot
.039 .916 .04 r
.5 Mabswid
.2967 .23796 m
.43187 .235 L
s
0 0 0 r
2.5 Mabswid
.43187 .235 Mdot
.039 .916 .04 r
.5 Mabswid
.2967 .2381 m
.43187 .23512 L
s
0 0 0 r
2.5 Mabswid
.43187 .23512 Mdot
.039 .916 .04 r
.5 Mabswid
.29671 .23823 m
.43187 .23524 L
s
0 0 0 r
2.5 Mabswid
.43187 .23524 Mdot
.039 .916 .04 r
.5 Mabswid
.29672 .23837 m
.43187 .23536 L
s
0 0 0 r
2.5 Mabswid
.43187 .23536 Mdot
.039 .916 .04 r
.5 Mabswid
.29673 .2385 m
.43187 .23548 L
s
0 0 0 r
2.5 Mabswid
.43187 .23548 Mdot
.039 .916 .04 r
.5 Mabswid
.29674 .23864 m
.43186 .2356 L
s
0 0 0 r
2.5 Mabswid
.43186 .2356 Mdot
.039 .916 .04 r
.5 Mabswid
.29675 .23878 m
.43186 .23571 L
s
0 0 0 r
2.5 Mabswid
.43186 .23571 Mdot
.039 .916 .04 r
.5 Mabswid
.29676 .23891 m
.43186 .23583 L
s
0 0 0 r
2.5 Mabswid
.43186 .23583 Mdot
.039 .916 .04 r
.5 Mabswid
.29677 .23905 m
.43186 .23595 L
s
0 0 0 r
2.5 Mabswid
.43186 .23595 Mdot
.039 .916 .04 r
.5 Mabswid
.29678 .23918 m
.43186 .23607 L
s
0 0 0 r
2.5 Mabswid
.43186 .23607 Mdot
.039 .916 .04 r
.5 Mabswid
.29679 .23932 m
.43186 .23619 L
s
0 0 0 r
2.5 Mabswid
.43186 .23619 Mdot
.039 .916 .04 r
.5 Mabswid
.2968 .23946 m
.43186 .23631 L
s
0 0 0 r
2.5 Mabswid
.43186 .23631 Mdot
.039 .916 .04 r
.5 Mabswid
.29681 .23959 m
.43186 .23643 L
s
0 0 0 r
2.5 Mabswid
.43186 .23643 Mdot
.039 .916 .04 r
.5 Mabswid
.29682 .23973 m
.43185 .23655 L
s
0 0 0 r
2.5 Mabswid
.43185 .23655 Mdot
.039 .916 .04 r
.5 Mabswid
.29683 .23986 m
.43185 .23667 L
s
0 0 0 r
2.5 Mabswid
.43185 .23667 Mdot
.039 .916 .04 r
.5 Mabswid
.29684 .24 m
.43185 .23679 L
s
0 0 0 r
2.5 Mabswid
.43185 .23679 Mdot
.039 .916 .04 r
.5 Mabswid
.29685 .24014 m
.43185 .23691 L
s
0 0 0 r
2.5 Mabswid
.43185 .23691 Mdot
.039 .916 .04 r
.5 Mabswid
.29685 .24027 m
.43185 .23703 L
s
0 0 0 r
2.5 Mabswid
.43185 .23703 Mdot
.039 .916 .04 r
.5 Mabswid
.29686 .24041 m
.43185 .23715 L
s
0 0 0 r
2.5 Mabswid
.43185 .23715 Mdot
.039 .916 .04 r
.5 Mabswid
.29687 .24054 m
.43185 .23726 L
s
0 0 0 r
2.5 Mabswid
.43185 .23726 Mdot
.039 .916 .04 r
.5 Mabswid
.29688 .24068 m
.43185 .23738 L
s
0 0 0 r
2.5 Mabswid
.43185 .23738 Mdot
.039 .916 .04 r
.5 Mabswid
.29689 .24082 m
.43184 .2375 L
s
0 0 0 r
2.5 Mabswid
.43184 .2375 Mdot
.039 .916 .04 r
.5 Mabswid
.2969 .24095 m
.43184 .23762 L
s
0 0 0 r
2.5 Mabswid
.43184 .23762 Mdot
.039 .916 .04 r
.5 Mabswid
.29691 .24109 m
.43184 .23774 L
s
0 0 0 r
2.5 Mabswid
.43184 .23774 Mdot
.039 .916 .04 r
.5 Mabswid
.29692 .24122 m
.43184 .23786 L
s
0 0 0 r
2.5 Mabswid
.43184 .23786 Mdot
.039 .916 .04 r
.5 Mabswid
.29694 .24136 m
.43184 .23798 L
s
0 0 0 r
2.5 Mabswid
.43184 .23798 Mdot
.039 .916 .04 r
.5 Mabswid
.29695 .2415 m
.43184 .2381 L
s
0 0 0 r
2.5 Mabswid
.43184 .2381 Mdot
.039 .916 .04 r
.5 Mabswid
.29696 .24163 m
.43184 .23822 L
s
0 0 0 r
2.5 Mabswid
.43184 .23822 Mdot
.039 .916 .04 r
.5 Mabswid
.29697 .24177 m
.43183 .23834 L
s
0 0 0 r
2.5 Mabswid
.43183 .23834 Mdot
.039 .916 .04 r
.5 Mabswid
.29698 .2419 m
.43183 .23846 L
s
0 0 0 r
2.5 Mabswid
.43183 .23846 Mdot
.039 .916 .04 r
.5 Mabswid
.29699 .24204 m
.43183 .23858 L
s
0 0 0 r
2.5 Mabswid
.43183 .23858 Mdot
.039 .916 .04 r
.5 Mabswid
.297 .24218 m
.43183 .2387 L
s
0 0 0 r
2.5 Mabswid
.43183 .2387 Mdot
.039 .916 .04 r
.5 Mabswid
.29701 .24231 m
.43183 .23882 L
s
0 0 0 r
2.5 Mabswid
.43183 .23882 Mdot
.039 .916 .04 r
.5 Mabswid
.29702 .24245 m
.43183 .23893 L
s
0 0 0 r
2.5 Mabswid
.43183 .23893 Mdot
.039 .916 .04 r
.5 Mabswid
.29703 .24259 m
.43183 .23905 L
s
0 0 0 r
2.5 Mabswid
.43183 .23905 Mdot
.039 .916 .04 r
.5 Mabswid
.29704 .24272 m
.43183 .23917 L
s
0 0 0 r
2.5 Mabswid
.43183 .23917 Mdot
.039 .916 .04 r
.5 Mabswid
.29705 .24286 m
.43182 .23929 L
s
0 0 0 r
2.5 Mabswid
.43182 .23929 Mdot
.039 .916 .04 r
.5 Mabswid
.29706 .24299 m
.43182 .23941 L
s
0 0 0 r
2.5 Mabswid
.43182 .23941 Mdot
.039 .916 .04 r
.5 Mabswid
.29707 .24313 m
.43182 .23953 L
s
0 0 0 r
2.5 Mabswid
.43182 .23953 Mdot
.039 .916 .04 r
.5 Mabswid
.29708 .24327 m
.43182 .23965 L
s
0 0 0 r
2.5 Mabswid
.43182 .23965 Mdot
.039 .916 .04 r
.5 Mabswid
.29709 .2434 m
.43182 .23977 L
s
0 0 0 r
2.5 Mabswid
.43182 .23977 Mdot
.039 .916 .04 r
.5 Mabswid
.29711 .24354 m
.43182 .23989 L
s
0 0 0 r
2.5 Mabswid
.43182 .23989 Mdot
.039 .916 .04 r
.5 Mabswid
.29712 .24367 m
.43182 .24001 L
s
0 0 0 r
2.5 Mabswid
.43182 .24001 Mdot
.039 .916 .04 r
.5 Mabswid
.29713 .24381 m
.43181 .24013 L
s
0 0 0 r
2.5 Mabswid
.43181 .24013 Mdot
.039 .916 .04 r
.5 Mabswid
.29714 .24395 m
.43181 .24025 L
s
0 0 0 r
2.5 Mabswid
.43181 .24025 Mdot
.039 .916 .04 r
.5 Mabswid
.29715 .24408 m
.43181 .24037 L
s
0 0 0 r
2.5 Mabswid
.43181 .24037 Mdot
.039 .916 .04 r
.5 Mabswid
.29716 .24422 m
.43181 .24049 L
s
0 0 0 r
2.5 Mabswid
.43181 .24049 Mdot
.039 .916 .04 r
.5 Mabswid
.29717 .24435 m
.43181 .24061 L
s
0 0 0 r
2.5 Mabswid
.43181 .24061 Mdot
.039 .916 .04 r
.5 Mabswid
.29718 .24449 m
.43181 .24073 L
s
0 0 0 r
2.5 Mabswid
.43181 .24073 Mdot
.039 .916 .04 r
.5 Mabswid
.2972 .24463 m
.4318 .24084 L
s
0 0 0 r
2.5 Mabswid
.4318 .24084 Mdot
.039 .916 .04 r
.5 Mabswid
.29721 .24476 m
.4318 .24096 L
s
0 0 0 r
2.5 Mabswid
.4318 .24096 Mdot
.039 .916 .04 r
.5 Mabswid
.29722 .2449 m
.4318 .24108 L
s
0 0 0 r
2.5 Mabswid
.4318 .24108 Mdot
.039 .916 .04 r
.5 Mabswid
.29723 .24503 m
.4318 .2412 L
s
0 0 0 r
2.5 Mabswid
.4318 .2412 Mdot
.039 .916 .04 r
.5 Mabswid
.29724 .24517 m
.4318 .24132 L
s
0 0 0 r
2.5 Mabswid
.4318 .24132 Mdot
.039 .916 .04 r
.5 Mabswid
.29725 .24531 m
.4318 .24144 L
s
0 0 0 r
2.5 Mabswid
.4318 .24144 Mdot
.039 .916 .04 r
.5 Mabswid
.29727 .24544 m
.4318 .24156 L
s
0 0 0 r
2.5 Mabswid
.4318 .24156 Mdot
.039 .916 .04 r
.5 Mabswid
.29728 .24558 m
.43179 .24168 L
s
0 0 0 r
2.5 Mabswid
.43179 .24168 Mdot
.039 .916 .04 r
.5 Mabswid
.29729 .24571 m
.43179 .2418 L
s
0 0 0 r
2.5 Mabswid
.43179 .2418 Mdot
.039 .916 .04 r
.5 Mabswid
.2973 .24585 m
.43179 .24192 L
s
0 0 0 r
2.5 Mabswid
.43179 .24192 Mdot
.039 .916 .04 r
.5 Mabswid
.29731 .24599 m
.43179 .24204 L
s
0 0 0 r
2.5 Mabswid
.43179 .24204 Mdot
.039 .916 .04 r
.5 Mabswid
.29732 .24612 m
.43179 .24216 L
s
0 0 0 r
2.5 Mabswid
.43179 .24216 Mdot
.039 .916 .04 r
.5 Mabswid
.29734 .24626 m
.43179 .24228 L
s
0 0 0 r
2.5 Mabswid
.43179 .24228 Mdot
.039 .916 .04 r
.5 Mabswid
.29735 .24639 m
.43178 .2424 L
s
0 0 0 r
2.5 Mabswid
.43178 .2424 Mdot
.039 .916 .04 r
.5 Mabswid
.29736 .24653 m
.43178 .24252 L
s
0 0 0 r
2.5 Mabswid
.43178 .24252 Mdot
.039 .916 .04 r
.5 Mabswid
.29737 .24667 m
.43178 .24264 L
s
0 0 0 r
2.5 Mabswid
.43178 .24264 Mdot
.039 .916 .04 r
.5 Mabswid
.29739 .2468 m
.43178 .24275 L
s
0 0 0 r
2.5 Mabswid
.43178 .24275 Mdot
.039 .916 .04 r
.5 Mabswid
.2974 .24694 m
.43178 .24287 L
s
0 0 0 r
2.5 Mabswid
.43178 .24287 Mdot
.039 .916 .04 r
.5 Mabswid
.29741 .24707 m
.43178 .24299 L
s
0 0 0 r
2.5 Mabswid
.43178 .24299 Mdot
.039 .916 .04 r
.5 Mabswid
.29742 .24721 m
.43177 .24311 L
s
0 0 0 r
2.5 Mabswid
.43177 .24311 Mdot
.039 .916 .04 r
.5 Mabswid
.29744 .24735 m
.43177 .24323 L
s
0 0 0 r
2.5 Mabswid
.43177 .24323 Mdot
.039 .916 .04 r
.5 Mabswid
.29745 .24748 m
.43177 .24335 L
s
0 0 0 r
2.5 Mabswid
.43177 .24335 Mdot
.039 .916 .04 r
.5 Mabswid
.29746 .24762 m
.43177 .24347 L
s
0 0 0 r
2.5 Mabswid
.43177 .24347 Mdot
.039 .916 .04 r
.5 Mabswid
.29747 .24776 m
.43177 .24359 L
s
0 0 0 r
2.5 Mabswid
.43177 .24359 Mdot
.039 .916 .04 r
.5 Mabswid
.29749 .24789 m
.43177 .24371 L
s
0 0 0 r
2.5 Mabswid
.43177 .24371 Mdot
.039 .916 .04 r
.5 Mabswid
.2975 .24803 m
.43176 .24383 L
s
0 0 0 r
2.5 Mabswid
.43176 .24383 Mdot
.039 .916 .04 r
.5 Mabswid
.29751 .24816 m
.43176 .24395 L
s
0 0 0 r
2.5 Mabswid
.43176 .24395 Mdot
.039 .916 .04 r
.5 Mabswid
.29752 .2483 m
.43176 .24407 L
s
0 0 0 r
2.5 Mabswid
.43176 .24407 Mdot
.039 .916 .04 r
.5 Mabswid
.29754 .24844 m
.43176 .24419 L
s
0 0 0 r
2.5 Mabswid
.43176 .24419 Mdot
.039 .916 .04 r
.5 Mabswid
.29755 .24857 m
.43176 .24431 L
s
0 0 0 r
2.5 Mabswid
.43176 .24431 Mdot
.039 .916 .04 r
.5 Mabswid
.29756 .24871 m
.43176 .24443 L
s
0 0 0 r
2.5 Mabswid
.43176 .24443 Mdot
.039 .916 .04 r
.5 Mabswid
.29758 .24884 m
.43175 .24455 L
s
0 0 0 r
2.5 Mabswid
.43175 .24455 Mdot
.039 .916 .04 r
.5 Mabswid
.29759 .24898 m
.43175 .24467 L
s
0 0 0 r
2.5 Mabswid
.43175 .24467 Mdot
.039 .916 .04 r
.5 Mabswid
.2976 .24912 m
.43175 .24479 L
s
0 0 0 r
2.5 Mabswid
.43175 .24479 Mdot
.039 .916 .04 r
.5 Mabswid
.29762 .24925 m
.43175 .24491 L
s
0 0 0 r
2.5 Mabswid
.43175 .24491 Mdot
.039 .916 .04 r
.5 Mabswid
.29763 .24939 m
.43175 .24502 L
s
0 0 0 r
2.5 Mabswid
.43175 .24502 Mdot
.039 .916 .04 r
.5 Mabswid
.29764 .24952 m
.43175 .24514 L
s
0 0 0 r
2.5 Mabswid
.43175 .24514 Mdot
.039 .916 .04 r
.5 Mabswid
.29766 .24966 m
.43174 .24526 L
s
0 0 0 r
2.5 Mabswid
.43174 .24526 Mdot
.039 .916 .04 r
.5 Mabswid
.29767 .2498 m
.43174 .24538 L
s
0 0 0 r
2.5 Mabswid
.43174 .24538 Mdot
.039 .916 .04 r
.5 Mabswid
.29768 .24993 m
.43174 .2455 L
s
0 0 0 r
2.5 Mabswid
.43174 .2455 Mdot
.039 .916 .04 r
.5 Mabswid
.2977 .25007 m
.43174 .24562 L
s
0 0 0 r
2.5 Mabswid
.43174 .24562 Mdot
.039 .916 .04 r
.5 Mabswid
.29771 .2502 m
.43174 .24574 L
s
0 0 0 r
2.5 Mabswid
.43174 .24574 Mdot
.039 .916 .04 r
.5 Mabswid
.29772 .25034 m
.43174 .24586 L
s
0 0 0 r
2.5 Mabswid
.43174 .24586 Mdot
.039 .916 .04 r
.5 Mabswid
.29774 .25048 m
.43173 .24598 L
s
0 0 0 r
2.5 Mabswid
.43173 .24598 Mdot
.039 .916 .04 r
.5 Mabswid
.29775 .25061 m
.43173 .2461 L
s
0 0 0 r
2.5 Mabswid
.43173 .2461 Mdot
.039 .916 .04 r
.5 Mabswid
.29776 .25075 m
.43173 .24622 L
s
0 0 0 r
2.5 Mabswid
.43173 .24622 Mdot
.039 .916 .04 r
.5 Mabswid
.29778 .25088 m
.43173 .24634 L
s
0 0 0 r
2.5 Mabswid
.43173 .24634 Mdot
.039 .916 .04 r
.5 Mabswid
.29779 .25102 m
.43173 .24646 L
s
0 0 0 r
2.5 Mabswid
.43173 .24646 Mdot
.039 .916 .04 r
.5 Mabswid
.29781 .25116 m
.43172 .24658 L
s
0 0 0 r
2.5 Mabswid
.43172 .24658 Mdot
.039 .916 .04 r
.5 Mabswid
.29782 .25129 m
.43172 .2467 L
s
0 0 0 r
2.5 Mabswid
.43172 .2467 Mdot
.039 .916 .04 r
.5 Mabswid
.29783 .25143 m
.43172 .24682 L
s
0 0 0 r
2.5 Mabswid
.43172 .24682 Mdot
.039 .916 .04 r
.5 Mabswid
.29785 .25156 m
.43172 .24694 L
s
0 0 0 r
2.5 Mabswid
.43172 .24694 Mdot
.039 .916 .04 r
.5 Mabswid
.29786 .2517 m
.43172 .24706 L
s
0 0 0 r
2.5 Mabswid
.43172 .24706 Mdot
.039 .916 .04 r
.5 Mabswid
.29788 .25184 m
.43172 .24718 L
s
0 0 0 r
2.5 Mabswid
.43172 .24718 Mdot
.039 .916 .04 r
.5 Mabswid
.29789 .25197 m
.43171 .2473 L
s
0 0 0 r
2.5 Mabswid
.43171 .2473 Mdot
.039 .916 .04 r
.5 Mabswid
.29791 .25211 m
.43171 .24742 L
s
0 0 0 r
2.5 Mabswid
.43171 .24742 Mdot
.039 .916 .04 r
.5 Mabswid
.29792 .25224 m
.43171 .24754 L
s
0 0 0 r
2.5 Mabswid
.43171 .24754 Mdot
.039 .916 .04 r
.5 Mabswid
.29793 .25238 m
.43171 .24765 L
s
0 0 0 r
2.5 Mabswid
.43171 .24765 Mdot
.039 .916 .04 r
.5 Mabswid
.29795 .25252 m
.43171 .24777 L
s
0 0 0 r
2.5 Mabswid
.43171 .24777 Mdot
.039 .916 .04 r
.5 Mabswid
.29796 .25265 m
.4317 .24789 L
s
0 0 0 r
2.5 Mabswid
.4317 .24789 Mdot
.039 .916 .04 r
.5 Mabswid
.29798 .25279 m
.4317 .24801 L
s
0 0 0 r
2.5 Mabswid
.4317 .24801 Mdot
.039 .916 .04 r
.5 Mabswid
.29799 .25293 m
.4317 .24813 L
s
0 0 0 r
2.5 Mabswid
.4317 .24813 Mdot
.039 .916 .04 r
.5 Mabswid
.29801 .25306 m
.4317 .24825 L
s
0 0 0 r
2.5 Mabswid
.4317 .24825 Mdot
.039 .916 .04 r
.5 Mabswid
.29802 .2532 m
.4317 .24837 L
s
0 0 0 r
2.5 Mabswid
.4317 .24837 Mdot
.039 .916 .04 r
.5 Mabswid
.29804 .25333 m
.43169 .24849 L
s
0 0 0 r
2.5 Mabswid
.43169 .24849 Mdot
.039 .916 .04 r
.5 Mabswid
.29805 .25347 m
.43169 .24861 L
s
0 0 0 r
2.5 Mabswid
.43169 .24861 Mdot
.039 .916 .04 r
.5 Mabswid
.29807 .25361 m
.43169 .24873 L
s
0 0 0 r
2.5 Mabswid
.43169 .24873 Mdot
.039 .916 .04 r
.5 Mabswid
.29808 .25374 m
.43169 .24885 L
s
0 0 0 r
2.5 Mabswid
.43169 .24885 Mdot
.039 .916 .04 r
.5 Mabswid
.2981 .25388 m
.43169 .24897 L
s
0 0 0 r
2.5 Mabswid
.43169 .24897 Mdot
.039 .916 .04 r
.5 Mabswid
.29811 .25401 m
.43168 .24909 L
s
0 0 0 r
2.5 Mabswid
.43168 .24909 Mdot
.039 .916 .04 r
.5 Mabswid
.29813 .25415 m
.43168 .24921 L
s
0 0 0 r
2.5 Mabswid
.43168 .24921 Mdot
.039 .916 .04 r
.5 Mabswid
.29814 .25429 m
.43168 .24933 L
s
0 0 0 r
2.5 Mabswid
.43168 .24933 Mdot
.039 .916 .04 r
.5 Mabswid
.29816 .25442 m
.43168 .24945 L
s
0 0 0 r
2.5 Mabswid
.43168 .24945 Mdot
.039 .916 .04 r
.5 Mabswid
.29817 .25456 m
.43168 .24957 L
s
0 0 0 r
2.5 Mabswid
.43168 .24957 Mdot
.039 .916 .04 r
.5 Mabswid
.29819 .25469 m
.43167 .24969 L
s
0 0 0 r
2.5 Mabswid
.43167 .24969 Mdot
.039 .916 .04 r
.5 Mabswid
.2982 .25483 m
.43167 .24981 L
s
0 0 0 r
2.5 Mabswid
.43167 .24981 Mdot
.039 .916 .04 r
.5 Mabswid
.29822 .25497 m
.43167 .24993 L
s
0 0 0 r
2.5 Mabswid
.43167 .24993 Mdot
.039 .916 .04 r
.5 Mabswid
.29823 .2551 m
.43167 .25005 L
s
0 0 0 r
2.5 Mabswid
.43167 .25005 Mdot
.039 .916 .04 r
.5 Mabswid
.29825 .25524 m
.43167 .25017 L
s
0 0 0 r
2.5 Mabswid
.43167 .25017 Mdot
.039 .916 .04 r
.5 Mabswid
.29826 .25537 m
.43166 .25029 L
s
0 0 0 r
2.5 Mabswid
.43166 .25029 Mdot
.039 .916 .04 r
.5 Mabswid
.29828 .25551 m
.43166 .25041 L
s
0 0 0 r
2.5 Mabswid
.43166 .25041 Mdot
.039 .916 .04 r
.5 Mabswid
.2983 .25565 m
.43166 .25053 L
s
0 0 0 r
2.5 Mabswid
.43166 .25053 Mdot
.039 .916 .04 r
.5 Mabswid
.29831 .25578 m
.43166 .25065 L
s
0 0 0 r
2.5 Mabswid
.43166 .25065 Mdot
.039 .916 .04 r
.5 Mabswid
.29833 .25592 m
.43166 .25077 L
s
0 0 0 r
2.5 Mabswid
.43166 .25077 Mdot
.039 .916 .04 r
.5 Mabswid
.29834 .25605 m
.43165 .25089 L
s
0 0 0 r
2.5 Mabswid
.43165 .25089 Mdot
.039 .916 .04 r
.5 Mabswid
.29836 .25619 m
.43165 .25101 L
s
0 0 0 r
2.5 Mabswid
.43165 .25101 Mdot
.039 .916 .04 r
.5 Mabswid
.29837 .25633 m
.43165 .25113 L
s
0 0 0 r
2.5 Mabswid
.43165 .25113 Mdot
.039 .916 .04 r
.5 Mabswid
.29839 .25646 m
.43165 .25125 L
s
0 0 0 r
2.5 Mabswid
.43165 .25125 Mdot
.039 .916 .04 r
.5 Mabswid
.29841 .2566 m
.43165 .25136 L
s
0 0 0 r
2.5 Mabswid
.43165 .25136 Mdot
.039 .916 .04 r
.5 Mabswid
.29842 .25673 m
.43164 .25148 L
s
0 0 0 r
2.5 Mabswid
.43164 .25148 Mdot
.039 .916 .04 r
.5 Mabswid
.29844 .25687 m
.43164 .2516 L
s
0 0 0 r
2.5 Mabswid
.43164 .2516 Mdot
.039 .916 .04 r
.5 Mabswid
.29846 .25701 m
.43164 .25172 L
s
0 0 0 r
2.5 Mabswid
.43164 .25172 Mdot
.039 .916 .04 r
.5 Mabswid
.29847 .25714 m
.43164 .25184 L
s
0 0 0 r
2.5 Mabswid
.43164 .25184 Mdot
.039 .916 .04 r
.5 Mabswid
.29849 .25728 m
.43163 .25196 L
s
0 0 0 r
2.5 Mabswid
.43163 .25196 Mdot
.039 .916 .04 r
.5 Mabswid
.2985 .25741 m
.43163 .25208 L
s
0 0 0 r
2.5 Mabswid
.43163 .25208 Mdot
.039 .916 .04 r
.5 Mabswid
.29852 .25755 m
.43163 .2522 L
s
0 0 0 r
2.5 Mabswid
.43163 .2522 Mdot
.039 .916 .04 r
.5 Mabswid
.29854 .25769 m
.43163 .25232 L
s
0 0 0 r
2.5 Mabswid
.43163 .25232 Mdot
.039 .916 .04 r
.5 Mabswid
.29855 .25782 m
.43163 .25244 L
s
0 0 0 r
2.5 Mabswid
.43163 .25244 Mdot
.039 .916 .04 r
.5 Mabswid
.29857 .25796 m
.43162 .25256 L
s
0 0 0 r
2.5 Mabswid
.43162 .25256 Mdot
.039 .916 .04 r
.5 Mabswid
.29859 .2581 m
.43162 .25268 L
s
0 0 0 r
2.5 Mabswid
.43162 .25268 Mdot
.039 .916 .04 r
.5 Mabswid
.2986 .25823 m
.43162 .2528 L
s
0 0 0 r
2.5 Mabswid
.43162 .2528 Mdot
.039 .916 .04 r
.5 Mabswid
.29862 .25837 m
.43162 .25292 L
s
0 0 0 r
2.5 Mabswid
.43162 .25292 Mdot
.039 .916 .04 r
.5 Mabswid
.29864 .2585 m
.43161 .25304 L
s
0 0 0 r
2.5 Mabswid
.43161 .25304 Mdot
.039 .916 .04 r
.5 Mabswid
.29865 .25864 m
.43161 .25316 L
s
0 0 0 r
2.5 Mabswid
.43161 .25316 Mdot
.039 .916 .04 r
.5 Mabswid
.29867 .25878 m
.43161 .25328 L
s
0 0 0 r
2.5 Mabswid
.43161 .25328 Mdot
.039 .916 .04 r
.5 Mabswid
.29869 .25891 m
.43161 .2534 L
s
0 0 0 r
2.5 Mabswid
.43161 .2534 Mdot
.039 .916 .04 r
.5 Mabswid
.2987 .25905 m
.43161 .25352 L
s
0 0 0 r
2.5 Mabswid
.43161 .25352 Mdot
.039 .916 .04 r
.5 Mabswid
.29872 .25918 m
.4316 .25364 L
s
0 0 0 r
2.5 Mabswid
.4316 .25364 Mdot
.039 .916 .04 r
.5 Mabswid
.29874 .25932 m
.4316 .25376 L
s
0 0 0 r
2.5 Mabswid
.4316 .25376 Mdot
.039 .916 .04 r
.5 Mabswid
.29876 .25946 m
.4316 .25388 L
s
0 0 0 r
2.5 Mabswid
.4316 .25388 Mdot
.039 .916 .04 r
.5 Mabswid
.29877 .25959 m
.4316 .254 L
s
0 0 0 r
2.5 Mabswid
.4316 .254 Mdot
.039 .916 .04 r
.5 Mabswid
.29879 .25973 m
.43159 .25412 L
s
0 0 0 r
2.5 Mabswid
.43159 .25412 Mdot
.039 .916 .04 r
.5 Mabswid
.29881 .25986 m
.43159 .25424 L
s
0 0 0 r
2.5 Mabswid
.43159 .25424 Mdot
.039 .916 .04 r
.5 Mabswid
.29882 .26 m
.43159 .25436 L
s
0 0 0 r
2.5 Mabswid
.43159 .25436 Mdot
.039 .916 .04 r
.5 Mabswid
.29884 .26014 m
.43159 .25448 L
s
0 0 0 r
2.5 Mabswid
.43159 .25448 Mdot
.039 .916 .04 r
.5 Mabswid
.29886 .26027 m
.43159 .2546 L
s
0 0 0 r
2.5 Mabswid
.43159 .2546 Mdot
.039 .916 .04 r
.5 Mabswid
.29888 .26041 m
.43158 .25472 L
s
0 0 0 r
2.5 Mabswid
.43158 .25472 Mdot
.039 .916 .04 r
.5 Mabswid
.29889 .26054 m
.43158 .25484 L
s
0 0 0 r
2.5 Mabswid
.43158 .25484 Mdot
.039 .916 .04 r
.5 Mabswid
.29891 .26068 m
.43158 .25496 L
s
0 0 0 r
2.5 Mabswid
.43158 .25496 Mdot
.039 .916 .04 r
.5 Mabswid
.29893 .26082 m
.43158 .25508 L
s
0 0 0 r
2.5 Mabswid
.43158 .25508 Mdot
.039 .916 .04 r
.5 Mabswid
.29895 .26095 m
.43157 .2552 L
s
0 0 0 r
2.5 Mabswid
.43157 .2552 Mdot
.039 .916 .04 r
.5 Mabswid
.29897 .26109 m
.43157 .25532 L
s
0 0 0 r
2.5 Mabswid
.43157 .25532 Mdot
.039 .916 .04 r
.5 Mabswid
.29898 .26122 m
.43157 .25544 L
s
0 0 0 r
2.5 Mabswid
.43157 .25544 Mdot
.039 .916 .04 r
.5 Mabswid
.299 .26136 m
.43157 .25556 L
s
0 0 0 r
2.5 Mabswid
.43157 .25556 Mdot
.039 .916 .04 r
.5 Mabswid
.29902 .2615 m
.43156 .25568 L
s
0 0 0 r
2.5 Mabswid
.43156 .25568 Mdot
.039 .916 .04 r
.5 Mabswid
.29904 .26163 m
.43156 .2558 L
s
0 0 0 r
2.5 Mabswid
.43156 .2558 Mdot
.039 .916 .04 r
.5 Mabswid
.29905 .26177 m
.43156 .25592 L
s
0 0 0 r
2.5 Mabswid
.43156 .25592 Mdot
.039 .916 .04 r
.5 Mabswid
.29907 .2619 m
.43156 .25604 L
s
0 0 0 r
2.5 Mabswid
.43156 .25604 Mdot
.039 .916 .04 r
.5 Mabswid
.29909 .26204 m
.43155 .25616 L
s
0 0 0 r
2.5 Mabswid
.43155 .25616 Mdot
.039 .916 .04 r
.5 Mabswid
.29911 .26218 m
.43155 .25628 L
s
0 0 0 r
2.5 Mabswid
.43155 .25628 Mdot
.039 .916 .04 r
.5 Mabswid
.29913 .26231 m
.43155 .2564 L
s
0 0 0 r
2.5 Mabswid
.43155 .2564 Mdot
.039 .916 .04 r
.5 Mabswid
.29915 .26245 m
.43155 .25652 L
s
0 0 0 r
2.5 Mabswid
.43155 .25652 Mdot
.039 .916 .04 r
.5 Mabswid
.29916 .26259 m
.43155 .25664 L
s
0 0 0 r
2.5 Mabswid
.43155 .25664 Mdot
.039 .916 .04 r
.5 Mabswid
.29918 .26272 m
.43154 .25676 L
s
0 0 0 r
2.5 Mabswid
.43154 .25676 Mdot
.039 .916 .04 r
.5 Mabswid
.2992 .26286 m
.43154 .25688 L
s
0 0 0 r
2.5 Mabswid
.43154 .25688 Mdot
.039 .916 .04 r
.5 Mabswid
.29922 .26299 m
.43154 .257 L
s
0 0 0 r
2.5 Mabswid
.43154 .257 Mdot
.039 .916 .04 r
.5 Mabswid
.29924 .26313 m
.43154 .25712 L
s
0 0 0 r
2.5 Mabswid
.43154 .25712 Mdot
.039 .916 .04 r
.5 Mabswid
.29926 .26327 m
.43153 .25724 L
s
0 0 0 r
2.5 Mabswid
.43153 .25724 Mdot
.039 .916 .04 r
.5 Mabswid
.29928 .2634 m
.43153 .25736 L
s
0 0 0 r
2.5 Mabswid
.43153 .25736 Mdot
.039 .916 .04 r
.5 Mabswid
.29929 .26354 m
.43153 .25748 L
s
0 0 0 r
2.5 Mabswid
.43153 .25748 Mdot
.039 .916 .04 r
.5 Mabswid
.29931 .26367 m
.43153 .2576 L
s
0 0 0 r
2.5 Mabswid
.43153 .2576 Mdot
.039 .916 .04 r
.5 Mabswid
.29933 .26381 m
.43152 .25772 L
s
0 0 0 r
2.5 Mabswid
.43152 .25772 Mdot
.039 .916 .04 r
.5 Mabswid
.29935 .26395 m
.43152 .25784 L
s
0 0 0 r
2.5 Mabswid
.43152 .25784 Mdot
.039 .916 .04 r
.5 Mabswid
.29937 .26408 m
.43152 .25796 L
s
0 0 0 r
2.5 Mabswid
.43152 .25796 Mdot
.039 .916 .04 r
.5 Mabswid
.29939 .26422 m
.43152 .25808 L
s
0 0 0 r
2.5 Mabswid
.43152 .25808 Mdot
.039 .916 .04 r
.5 Mabswid
.29941 .26435 m
.43151 .2582 L
s
0 0 0 r
2.5 Mabswid
.43151 .2582 Mdot
.039 .916 .04 r
.5 Mabswid
.29943 .26449 m
.43151 .25832 L
s
0 0 0 r
2.5 Mabswid
.43151 .25832 Mdot
.039 .916 .04 r
.5 Mabswid
.29945 .26463 m
.43151 .25844 L
s
0 0 0 r
2.5 Mabswid
.43151 .25844 Mdot
.039 .916 .04 r
.5 Mabswid
.29946 .26476 m
.43151 .25856 L
s
0 0 0 r
2.5 Mabswid
.43151 .25856 Mdot
.039 .916 .04 r
.5 Mabswid
.29948 .2649 m
.4315 .25868 L
s
0 0 0 r
2.5 Mabswid
.4315 .25868 Mdot
.039 .916 .04 r
.5 Mabswid
.2995 .26503 m
.4315 .2588 L
s
0 0 0 r
2.5 Mabswid
.4315 .2588 Mdot
.039 .916 .04 r
.5 Mabswid
.29952 .26517 m
.4315 .25892 L
s
0 0 0 r
2.5 Mabswid
.4315 .25892 Mdot
.039 .916 .04 r
.5 Mabswid
.29954 .26531 m
.4315 .25904 L
s
0 0 0 r
2.5 Mabswid
.4315 .25904 Mdot
.039 .916 .04 r
.5 Mabswid
.29956 .26544 m
.43149 .25916 L
s
0 0 0 r
2.5 Mabswid
.43149 .25916 Mdot
.039 .916 .04 r
.5 Mabswid
.29958 .26558 m
.43149 .25928 L
s
0 0 0 r
2.5 Mabswid
.43149 .25928 Mdot
.039 .916 .04 r
.5 Mabswid
.2996 .26571 m
.43149 .2594 L
s
0 0 0 r
2.5 Mabswid
.43149 .2594 Mdot
.039 .916 .04 r
.5 Mabswid
.29962 .26585 m
.43149 .25952 L
s
0 0 0 r
2.5 Mabswid
.43149 .25952 Mdot
.039 .916 .04 r
.5 Mabswid
.29964 .26599 m
.43148 .25964 L
s
0 0 0 r
2.5 Mabswid
.43148 .25964 Mdot
.039 .916 .04 r
.5 Mabswid
.29966 .26612 m
.43148 .25976 L
s
0 0 0 r
2.5 Mabswid
.43148 .25976 Mdot
.039 .916 .04 r
.5 Mabswid
.29968 .26626 m
.43148 .25988 L
s
0 0 0 r
2.5 Mabswid
.43148 .25988 Mdot
.039 .916 .04 r
.5 Mabswid
.2997 .26639 m
.43147 .26 L
s
0 0 0 r
2.5 Mabswid
.43147 .26 Mdot
.039 .916 .04 r
.5 Mabswid
.29972 .26653 m
.43147 .26012 L
s
0 0 0 r
2.5 Mabswid
.43147 .26012 Mdot
.039 .916 .04 r
.5 Mabswid
.29974 .26667 m
.43147 .26024 L
s
0 0 0 r
2.5 Mabswid
.43147 .26024 Mdot
.039 .916 .04 r
.5 Mabswid
.29976 .2668 m
.43147 .26036 L
s
0 0 0 r
2.5 Mabswid
.43147 .26036 Mdot
.039 .916 .04 r
.5 Mabswid
.29978 .26694 m
.43146 .26048 L
s
0 0 0 r
2.5 Mabswid
.43146 .26048 Mdot
.039 .916 .04 r
.5 Mabswid
.2998 .26707 m
.43146 .2606 L
s
0 0 0 r
2.5 Mabswid
.43146 .2606 Mdot
.039 .916 .04 r
.5 Mabswid
.29982 .26721 m
.43146 .26072 L
s
0 0 0 r
2.5 Mabswid
.43146 .26072 Mdot
.039 .916 .04 r
.5 Mabswid
.29984 .26735 m
.43146 .26084 L
s
0 0 0 r
2.5 Mabswid
.43146 .26084 Mdot
.039 .916 .04 r
.5 Mabswid
.29986 .26748 m
.43145 .26096 L
s
0 0 0 r
2.5 Mabswid
.43145 .26096 Mdot
.039 .916 .04 r
.5 Mabswid
.29988 .26762 m
.43145 .26108 L
s
0 0 0 r
2.5 Mabswid
.43145 .26108 Mdot
.039 .916 .04 r
.5 Mabswid
.2999 .26776 m
.43145 .2612 L
s
0 0 0 r
2.5 Mabswid
.43145 .2612 Mdot
.039 .916 .04 r
.5 Mabswid
.29992 .26789 m
.43145 .26132 L
s
0 0 0 r
2.5 Mabswid
.43145 .26132 Mdot
.039 .916 .04 r
.5 Mabswid
.29994 .26803 m
.43144 .26144 L
s
0 0 0 r
2.5 Mabswid
.43144 .26144 Mdot
.039 .916 .04 r
.5 Mabswid
.29996 .26816 m
.43144 .26157 L
s
0 0 0 r
2.5 Mabswid
.43144 .26157 Mdot
.039 .916 .04 r
.5 Mabswid
.29998 .2683 m
.43144 .26169 L
s
0 0 0 r
2.5 Mabswid
.43144 .26169 Mdot
.039 .916 .04 r
.5 Mabswid
.3 .26844 m
.43143 .26181 L
s
0 0 0 r
2.5 Mabswid
.43143 .26181 Mdot
.039 .916 .04 r
.5 Mabswid
.30002 .26857 m
.43143 .26193 L
s
0 0 0 r
2.5 Mabswid
.43143 .26193 Mdot
.039 .916 .04 r
.5 Mabswid
.30004 .26871 m
.43143 .26205 L
s
0 0 0 r
2.5 Mabswid
.43143 .26205 Mdot
.039 .916 .04 r
.5 Mabswid
.30006 .26884 m
.43143 .26217 L
s
0 0 0 r
2.5 Mabswid
.43143 .26217 Mdot
.039 .916 .04 r
.5 Mabswid
.30009 .26898 m
.43142 .26229 L
s
0 0 0 r
2.5 Mabswid
.43142 .26229 Mdot
.039 .916 .04 r
.5 Mabswid
.30011 .26912 m
.43142 .26241 L
s
0 0 0 r
2.5 Mabswid
.43142 .26241 Mdot
.039 .916 .04 r
.5 Mabswid
.30013 .26925 m
.43142 .26253 L
s
0 0 0 r
2.5 Mabswid
.43142 .26253 Mdot
.039 .916 .04 r
.5 Mabswid
.30015 .26939 m
.43142 .26265 L
s
0 0 0 r
2.5 Mabswid
.43142 .26265 Mdot
.039 .916 .04 r
.5 Mabswid
.30017 .26952 m
.43141 .26277 L
s
0 0 0 r
2.5 Mabswid
.43141 .26277 Mdot
.039 .916 .04 r
.5 Mabswid
.30019 .26966 m
.43141 .26289 L
s
0 0 0 r
2.5 Mabswid
.43141 .26289 Mdot
.039 .916 .04 r
.5 Mabswid
.30021 .2698 m
.43141 .26301 L
s
0 0 0 r
2.5 Mabswid
.43141 .26301 Mdot
.039 .916 .04 r
.5 Mabswid
.30023 .26993 m
.4314 .26313 L
s
0 0 0 r
2.5 Mabswid
.4314 .26313 Mdot
.039 .916 .04 r
.5 Mabswid
.30025 .27007 m
.4314 .26325 L
s
0 0 0 r
2.5 Mabswid
.4314 .26325 Mdot
.039 .916 .04 r
.5 Mabswid
.30028 .2702 m
.4314 .26337 L
s
0 0 0 r
2.5 Mabswid
.4314 .26337 Mdot
.039 .916 .04 r
.5 Mabswid
.3003 .27034 m
.4314 .26349 L
s
0 0 0 r
2.5 Mabswid
.4314 .26349 Mdot
.039 .916 .04 r
.5 Mabswid
.30032 .27048 m
.43139 .26361 L
s
0 0 0 r
2.5 Mabswid
.43139 .26361 Mdot
.039 .916 .04 r
.5 Mabswid
.30034 .27061 m
.43139 .26373 L
s
0 0 0 r
2.5 Mabswid
.43139 .26373 Mdot
.039 .916 .04 r
.5 Mabswid
.30036 .27075 m
.43139 .26385 L
s
0 0 0 r
2.5 Mabswid
.43139 .26385 Mdot
.039 .916 .04 r
.5 Mabswid
.30038 .27088 m
.43138 .26397 L
s
0 0 0 r
2.5 Mabswid
.43138 .26397 Mdot
.039 .916 .04 r
.5 Mabswid
.3004 .27102 m
.43138 .26409 L
s
0 0 0 r
2.5 Mabswid
.43138 .26409 Mdot
.039 .916 .04 r
.5 Mabswid
.30043 .27116 m
.43138 .26421 L
s
0 0 0 r
2.5 Mabswid
.43138 .26421 Mdot
.039 .916 .04 r
.5 Mabswid
.30045 .27129 m
.43138 .26433 L
s
0 0 0 r
2.5 Mabswid
.43138 .26433 Mdot
.039 .916 .04 r
.5 Mabswid
.30047 .27143 m
.43137 .26445 L
s
0 0 0 r
2.5 Mabswid
.43137 .26445 Mdot
.039 .916 .04 r
.5 Mabswid
.30049 .27156 m
.43137 .26457 L
s
0 0 0 r
2.5 Mabswid
.43137 .26457 Mdot
.039 .916 .04 r
.5 Mabswid
.30051 .2717 m
.43137 .26469 L
s
0 0 0 r
2.5 Mabswid
.43137 .26469 Mdot
.039 .916 .04 r
.5 Mabswid
.30054 .27184 m
.43136 .26481 L
s
0 0 0 r
2.5 Mabswid
.43136 .26481 Mdot
.039 .916 .04 r
.5 Mabswid
.30056 .27197 m
.43136 .26494 L
s
0 0 0 r
2.5 Mabswid
.43136 .26494 Mdot
.039 .916 .04 r
.5 Mabswid
.30058 .27211 m
.43136 .26506 L
s
0 0 0 r
2.5 Mabswid
.43136 .26506 Mdot
.039 .916 .04 r
.5 Mabswid
.3006 .27224 m
.43136 .26518 L
s
0 0 0 r
2.5 Mabswid
.43136 .26518 Mdot
.039 .916 .04 r
.5 Mabswid
.30062 .27238 m
.43135 .2653 L
s
0 0 0 r
2.5 Mabswid
.43135 .2653 Mdot
.039 .916 .04 r
.5 Mabswid
.30065 .27252 m
.43135 .26542 L
s
0 0 0 r
2.5 Mabswid
.43135 .26542 Mdot
.039 .916 .04 r
.5 Mabswid
.30067 .27265 m
.43135 .26554 L
s
0 0 0 r
2.5 Mabswid
.43135 .26554 Mdot
.039 .916 .04 r
.5 Mabswid
.30069 .27279 m
.43134 .26566 L
s
0 0 0 r
2.5 Mabswid
.43134 .26566 Mdot
.039 .916 .04 r
.5 Mabswid
.30071 .27293 m
.43134 .26578 L
s
0 0 0 r
2.5 Mabswid
.43134 .26578 Mdot
.039 .916 .04 r
.5 Mabswid
.30074 .27306 m
.43134 .2659 L
s
0 0 0 r
2.5 Mabswid
.43134 .2659 Mdot
.039 .916 .04 r
.5 Mabswid
.30076 .2732 m
.43133 .26602 L
s
0 0 0 r
2.5 Mabswid
.43133 .26602 Mdot
.039 .916 .04 r
.5 Mabswid
.30078 .27333 m
.43133 .26614 L
s
0 0 0 r
2.5 Mabswid
.43133 .26614 Mdot
.039 .916 .04 r
.5 Mabswid
.3008 .27347 m
.43133 .26626 L
s
0 0 0 r
2.5 Mabswid
.43133 .26626 Mdot
.039 .916 .04 r
.5 Mabswid
.30083 .27361 m
.43133 .26638 L
s
0 0 0 r
2.5 Mabswid
.43133 .26638 Mdot
.039 .916 .04 r
.5 Mabswid
.30085 .27374 m
.43132 .2665 L
s
0 0 0 r
2.5 Mabswid
.43132 .2665 Mdot
.039 .916 .04 r
.5 Mabswid
.30087 .27388 m
.43132 .26662 L
s
0 0 0 r
2.5 Mabswid
.43132 .26662 Mdot
.039 .916 .04 r
.5 Mabswid
.30089 .27401 m
.43132 .26674 L
s
0 0 0 r
2.5 Mabswid
.43132 .26674 Mdot
.039 .916 .04 r
.5 Mabswid
.30092 .27415 m
.43131 .26686 L
s
0 0 0 r
2.5 Mabswid
.43131 .26686 Mdot
.039 .916 .04 r
.5 Mabswid
.30094 .27429 m
.43131 .26698 L
s
0 0 0 r
2.5 Mabswid
.43131 .26698 Mdot
.039 .916 .04 r
.5 Mabswid
.30096 .27442 m
.43131 .2671 L
s
0 0 0 r
2.5 Mabswid
.43131 .2671 Mdot
.039 .916 .04 r
.5 Mabswid
.30099 .27456 m
.4313 .26723 L
s
0 0 0 r
2.5 Mabswid
.4313 .26723 Mdot
.039 .916 .04 r
.5 Mabswid
.30101 .27469 m
.4313 .26735 L
s
0 0 0 r
2.5 Mabswid
.4313 .26735 Mdot
.039 .916 .04 r
.5 Mabswid
.30103 .27483 m
.4313 .26747 L
s
0 0 0 r
2.5 Mabswid
.4313 .26747 Mdot
.039 .916 .04 r
.5 Mabswid
.30105 .27497 m
.4313 .26759 L
s
0 0 0 r
2.5 Mabswid
.4313 .26759 Mdot
.039 .916 .04 r
.5 Mabswid
.30108 .2751 m
.43129 .26771 L
s
0 0 0 r
2.5 Mabswid
.43129 .26771 Mdot
.039 .916 .04 r
.5 Mabswid
.3011 .27524 m
.43129 .26783 L
s
0 0 0 r
2.5 Mabswid
.43129 .26783 Mdot
.039 .916 .04 r
.5 Mabswid
.30112 .27537 m
.43129 .26795 L
s
0 0 0 r
2.5 Mabswid
.43129 .26795 Mdot
.039 .916 .04 r
.5 Mabswid
.30115 .27551 m
.43128 .26807 L
s
0 0 0 r
2.5 Mabswid
.43128 .26807 Mdot
.039 .916 .04 r
.5 Mabswid
.30117 .27565 m
.43128 .26819 L
s
0 0 0 r
2.5 Mabswid
.43128 .26819 Mdot
.039 .916 .04 r
.5 Mabswid
.30119 .27578 m
.43128 .26831 L
s
0 0 0 r
2.5 Mabswid
.43128 .26831 Mdot
.039 .916 .04 r
.5 Mabswid
.30122 .27592 m
.43127 .26843 L
s
0 0 0 r
2.5 Mabswid
.43127 .26843 Mdot
.039 .916 .04 r
.5 Mabswid
.30124 .27605 m
.43127 .26855 L
s
0 0 0 r
2.5 Mabswid
.43127 .26855 Mdot
.039 .916 .04 r
.5 Mabswid
.30127 .27619 m
.43127 .26867 L
s
0 0 0 r
2.5 Mabswid
.43127 .26867 Mdot
.039 .916 .04 r
.5 Mabswid
.30129 .27633 m
.43126 .26879 L
s
0 0 0 r
2.5 Mabswid
.43126 .26879 Mdot
.039 .916 .04 r
.5 Mabswid
.30131 .27646 m
.43126 .26891 L
s
0 0 0 r
2.5 Mabswid
.43126 .26891 Mdot
.039 .916 .04 r
.5 Mabswid
.30134 .2766 m
.43126 .26904 L
s
0 0 0 r
2.5 Mabswid
.43126 .26904 Mdot
.039 .916 .04 r
.5 Mabswid
.30136 .27673 m
.43126 .26916 L
s
0 0 0 r
2.5 Mabswid
.43126 .26916 Mdot
.039 .916 .04 r
.5 Mabswid
.30138 .27687 m
.43125 .26928 L
s
0 0 0 r
2.5 Mabswid
.43125 .26928 Mdot
.039 .916 .04 r
.5 Mabswid
.30141 .27701 m
.43125 .2694 L
s
0 0 0 r
2.5 Mabswid
.43125 .2694 Mdot
.039 .916 .04 r
.5 Mabswid
.30143 .27714 m
.43125 .26952 L
s
0 0 0 r
2.5 Mabswid
.43125 .26952 Mdot
.039 .916 .04 r
.5 Mabswid
.30146 .27728 m
.43124 .26964 L
s
0 0 0 r
2.5 Mabswid
.43124 .26964 Mdot
.039 .916 .04 r
.5 Mabswid
.30148 .27741 m
.43124 .26976 L
s
0 0 0 r
2.5 Mabswid
.43124 .26976 Mdot
.039 .916 .04 r
.5 Mabswid
.30151 .27755 m
.43124 .26988 L
s
0 0 0 r
2.5 Mabswid
.43124 .26988 Mdot
.039 .916 .04 r
.5 Mabswid
.30153 .27769 m
.43123 .27 L
s
0 0 0 r
2.5 Mabswid
.43123 .27 Mdot
.039 .916 .04 r
.5 Mabswid
.30155 .27782 m
.43123 .27012 L
s
0 0 0 r
2.5 Mabswid
.43123 .27012 Mdot
.039 .916 .04 r
.5 Mabswid
.30158 .27796 m
.43123 .27024 L
s
0 0 0 r
2.5 Mabswid
.43123 .27024 Mdot
.039 .916 .04 r
.5 Mabswid
.3016 .2781 m
.43122 .27036 L
s
0 0 0 r
2.5 Mabswid
.43122 .27036 Mdot
.039 .916 .04 r
.5 Mabswid
.30163 .27823 m
.43122 .27048 L
s
0 0 0 r
2.5 Mabswid
.43122 .27048 Mdot
.039 .916 .04 r
.5 Mabswid
.30165 .27837 m
.43122 .27061 L
s
0 0 0 r
2.5 Mabswid
.43122 .27061 Mdot
.039 .916 .04 r
.5 Mabswid
.30168 .2785 m
.43121 .27073 L
s
0 0 0 r
2.5 Mabswid
.43121 .27073 Mdot
.039 .916 .04 r
.5 Mabswid
.3017 .27864 m
.43121 .27085 L
s
0 0 0 r
2.5 Mabswid
.43121 .27085 Mdot
.039 .916 .04 r
.5 Mabswid
.30173 .27878 m
.43121 .27097 L
s
0 0 0 r
2.5 Mabswid
.43121 .27097 Mdot
.039 .916 .04 r
.5 Mabswid
.30175 .27891 m
.4312 .27109 L
s
0 0 0 r
2.5 Mabswid
.4312 .27109 Mdot
.039 .916 .04 r
.5 Mabswid
.30177 .27905 m
.4312 .27121 L
s
0 0 0 r
2.5 Mabswid
.4312 .27121 Mdot
.039 .916 .04 r
.5 Mabswid
.3018 .27918 m
.4312 .27133 L
s
0 0 0 r
2.5 Mabswid
.4312 .27133 Mdot
.039 .916 .04 r
.5 Mabswid
.30182 .27932 m
.43119 .27145 L
s
0 0 0 r
2.5 Mabswid
.43119 .27145 Mdot
.039 .916 .04 r
.5 Mabswid
.30185 .27946 m
.43119 .27157 L
s
0 0 0 r
2.5 Mabswid
.43119 .27157 Mdot
.039 .916 .04 r
.5 Mabswid
.30187 .27959 m
.43119 .27169 L
s
0 0 0 r
2.5 Mabswid
.43119 .27169 Mdot
.039 .916 .04 r
.5 Mabswid
.3019 .27973 m
.43118 .27181 L
s
0 0 0 r
2.5 Mabswid
.43118 .27181 Mdot
.039 .916 .04 r
.5 Mabswid
.30192 .27986 m
.43118 .27193 L
s
0 0 0 r
2.5 Mabswid
.43118 .27193 Mdot
.039 .916 .04 r
.5 Mabswid
.30195 .28 m
.43118 .27206 L
s
0 0 0 r
2.5 Mabswid
.43118 .27206 Mdot
.039 .916 .04 r
.5 Mabswid
.30198 .28014 m
.43117 .27218 L
s
0 0 0 r
2.5 Mabswid
.43117 .27218 Mdot
.039 .916 .04 r
.5 Mabswid
.302 .28027 m
.43117 .2723 L
s
0 0 0 r
2.5 Mabswid
.43117 .2723 Mdot
.039 .916 .04 r
.5 Mabswid
.30203 .28041 m
.43117 .27242 L
s
0 0 0 r
2.5 Mabswid
.43117 .27242 Mdot
.039 .916 .04 r
.5 Mabswid
.30205 .28054 m
.43116 .27254 L
s
0 0 0 r
2.5 Mabswid
.43116 .27254 Mdot
.039 .916 .04 r
.5 Mabswid
.30208 .28068 m
.43116 .27266 L
s
0 0 0 r
2.5 Mabswid
.43116 .27266 Mdot
.039 .916 .04 r
.5 Mabswid
.3021 .28082 m
.43116 .27278 L
s
0 0 0 r
2.5 Mabswid
.43116 .27278 Mdot
.039 .916 .04 r
.5 Mabswid
.30213 .28095 m
.43115 .2729 L
s
0 0 0 r
2.5 Mabswid
.43115 .2729 Mdot
.039 .916 .04 r
.5 Mabswid
.30215 .28109 m
.43115 .27302 L
s
0 0 0 r
2.5 Mabswid
.43115 .27302 Mdot
.039 .916 .04 r
.5 Mabswid
.30218 .28122 m
.43115 .27314 L
s
0 0 0 r
2.5 Mabswid
.43115 .27314 Mdot
.039 .916 .04 r
.5 Mabswid
.3022 .28136 m
.43114 .27327 L
s
0 0 0 r
2.5 Mabswid
.43114 .27327 Mdot
.039 .916 .04 r
.5 Mabswid
.30223 .2815 m
.43114 .27339 L
s
0 0 0 r
2.5 Mabswid
.43114 .27339 Mdot
.039 .916 .04 r
.5 Mabswid
.30226 .28163 m
.43114 .27351 L
s
0 0 0 r
2.5 Mabswid
.43114 .27351 Mdot
.039 .916 .04 r
.5 Mabswid
.30228 .28177 m
.43113 .27363 L
s
0 0 0 r
2.5 Mabswid
.43113 .27363 Mdot
.039 .916 .04 r
.5 Mabswid
.30231 .2819 m
.43113 .27375 L
s
0 0 0 r
2.5 Mabswid
.43113 .27375 Mdot
.039 .916 .04 r
.5 Mabswid
.30233 .28204 m
.43113 .27387 L
s
0 0 0 r
2.5 Mabswid
.43113 .27387 Mdot
.039 .916 .04 r
.5 Mabswid
.30236 .28218 m
.43112 .27399 L
s
0 0 0 r
2.5 Mabswid
.43112 .27399 Mdot
.039 .916 .04 r
.5 Mabswid
.30239 .28231 m
.43112 .27411 L
s
0 0 0 r
2.5 Mabswid
.43112 .27411 Mdot
.039 .916 .04 r
.5 Mabswid
.43112 .15446 m
.97619 .21462 L
s
0 0 0 r
2.5 Mabswid
.97619 .21462 Mdot
.039 .916 .04 r
.5 Mabswid
.43112 .15458 m
.97619 .21461 L
s
0 0 0 r
2.5 Mabswid
.97619 .21461 Mdot
.039 .916 .04 r
.5 Mabswid
.43113 .1547 m
.97619 .21461 L
s
0 0 0 r
2.5 Mabswid
.97619 .21461 Mdot
.039 .916 .04 r
.5 Mabswid
.43113 .15482 m
.97619 .21461 L
s
0 0 0 r
2.5 Mabswid
.97619 .21461 Mdot
.039 .916 .04 r
.5 Mabswid
.43113 .15494 m
.97619 .2146 L
s
0 0 0 r
2.5 Mabswid
.97619 .2146 Mdot
.039 .916 .04 r
.5 Mabswid
.43114 .15506 m
.97619 .2146 L
s
0 0 0 r
2.5 Mabswid
.97619 .2146 Mdot
.039 .916 .04 r
.5 Mabswid
.43114 .15519 m
.97619 .21459 L
s
0 0 0 r
2.5 Mabswid
.97619 .21459 Mdot
.039 .916 .04 r
.5 Mabswid
.43114 .15531 m
.97619 .21459 L
s
0 0 0 r
2.5 Mabswid
.97619 .21459 Mdot
.039 .916 .04 r
.5 Mabswid
.43115 .15543 m
.97619 .21459 L
s
0 0 0 r
2.5 Mabswid
.97619 .21459 Mdot
.039 .916 .04 r
.5 Mabswid
.43115 .15555 m
.97619 .21458 L
s
0 0 0 r
2.5 Mabswid
.97619 .21458 Mdot
.039 .916 .04 r
.5 Mabswid
.43115 .15567 m
.97619 .21458 L
s
0 0 0 r
2.5 Mabswid
.97619 .21458 Mdot
.039 .916 .04 r
.5 Mabswid
.43116 .15579 m
.97619 .21457 L
s
0 0 0 r
2.5 Mabswid
.97619 .21457 Mdot
.039 .916 .04 r
.5 Mabswid
.43116 .15591 m
.97619 .21457 L
s
0 0 0 r
2.5 Mabswid
.97619 .21457 Mdot
.039 .916 .04 r
.5 Mabswid
.43116 .15603 m
.97619 .21457 L
s
0 0 0 r
2.5 Mabswid
.97619 .21457 Mdot
.039 .916 .04 r
.5 Mabswid
.43117 .15615 m
.97619 .21456 L
s
0 0 0 r
2.5 Mabswid
.97619 .21456 Mdot
.039 .916 .04 r
.5 Mabswid
.43117 .15627 m
.97619 .21456 L
s
0 0 0 r
2.5 Mabswid
.97619 .21456 Mdot
.039 .916 .04 r
.5 Mabswid
.43117 .15639 m
.97619 .21456 L
s
0 0 0 r
2.5 Mabswid
.97619 .21456 Mdot
.039 .916 .04 r
.5 Mabswid
.43118 .15652 m
.97619 .21455 L
s
0 0 0 r
2.5 Mabswid
.97619 .21455 Mdot
.039 .916 .04 r
.5 Mabswid
.43118 .15664 m
.97619 .21455 L
s
0 0 0 r
2.5 Mabswid
.97619 .21455 Mdot
.039 .916 .04 r
.5 Mabswid
.43118 .15676 m
.97619 .21454 L
s
0 0 0 r
2.5 Mabswid
.97619 .21454 Mdot
.039 .916 .04 r
.5 Mabswid
.43119 .15688 m
.97619 .21454 L
s
0 0 0 r
2.5 Mabswid
.97619 .21454 Mdot
.039 .916 .04 r
.5 Mabswid
.43119 .157 m
.97619 .21454 L
s
0 0 0 r
2.5 Mabswid
.97619 .21454 Mdot
.039 .916 .04 r
.5 Mabswid
.43119 .15712 m
.97619 .21453 L
s
0 0 0 r
2.5 Mabswid
.97619 .21453 Mdot
.039 .916 .04 r
.5 Mabswid
.4312 .15724 m
.97619 .21453 L
s
0 0 0 r
2.5 Mabswid
.97619 .21453 Mdot
.039 .916 .04 r
.5 Mabswid
.4312 .15736 m
.97619 .21453 L
s
0 0 0 r
2.5 Mabswid
.97619 .21453 Mdot
.039 .916 .04 r
.5 Mabswid
.4312 .15748 m
.97619 .21452 L
s
0 0 0 r
2.5 Mabswid
.97619 .21452 Mdot
.039 .916 .04 r
.5 Mabswid
.43121 .1576 m
.97619 .21452 L
s
0 0 0 r
2.5 Mabswid
.97619 .21452 Mdot
.039 .916 .04 r
.5 Mabswid
.43121 .15772 m
.97619 .21452 L
s
0 0 0 r
2.5 Mabswid
.97619 .21452 Mdot
.039 .916 .04 r
.5 Mabswid
.43121 .15785 m
.97619 .21451 L
s
0 0 0 r
2.5 Mabswid
.97619 .21451 Mdot
.039 .916 .04 r
.5 Mabswid
.43122 .15797 m
.97619 .21451 L
s
0 0 0 r
2.5 Mabswid
.97619 .21451 Mdot
.039 .916 .04 r
.5 Mabswid
.43122 .15809 m
.97619 .21451 L
s
0 0 0 r
2.5 Mabswid
.97619 .21451 Mdot
.039 .916 .04 r
.5 Mabswid
.43122 .15821 m
.97619 .2145 L
s
0 0 0 r
2.5 Mabswid
.97619 .2145 Mdot
.039 .916 .04 r
.5 Mabswid
.43123 .15833 m
.97619 .2145 L
s
0 0 0 r
2.5 Mabswid
.97619 .2145 Mdot
.039 .916 .04 r
.5 Mabswid
.43123 .15845 m
.97619 .21449 L
s
0 0 0 r
2.5 Mabswid
.97619 .21449 Mdot
.039 .916 .04 r
.5 Mabswid
.43123 .15857 m
.97619 .21449 L
s
0 0 0 r
2.5 Mabswid
.97619 .21449 Mdot
.039 .916 .04 r
.5 Mabswid
.43124 .15869 m
.97619 .21449 L
s
0 0 0 r
2.5 Mabswid
.97619 .21449 Mdot
.039 .916 .04 r
.5 Mabswid
.43124 .15881 m
.97619 .21448 L
s
0 0 0 r
2.5 Mabswid
.97619 .21448 Mdot
.039 .916 .04 r
.5 Mabswid
.43124 .15893 m
.97619 .21448 L
s
0 0 0 r
2.5 Mabswid
.97619 .21448 Mdot
.039 .916 .04 r
.5 Mabswid
.43125 .15905 m
.97619 .21448 L
s
0 0 0 r
2.5 Mabswid
.97619 .21448 Mdot
.039 .916 .04 r
.5 Mabswid
.43125 .15917 m
.97619 .21447 L
s
0 0 0 r
2.5 Mabswid
.97619 .21447 Mdot
.039 .916 .04 r
.5 Mabswid
.43125 .15929 m
.97619 .21447 L
s
0 0 0 r
2.5 Mabswid
.97619 .21447 Mdot
.039 .916 .04 r
.5 Mabswid
.43126 .15942 m
.97619 .21447 L
s
0 0 0 r
2.5 Mabswid
.97619 .21447 Mdot
.039 .916 .04 r
.5 Mabswid
.43126 .15954 m
.97619 .21447 L
s
0 0 0 r
2.5 Mabswid
.97619 .21447 Mdot
.039 .916 .04 r
.5 Mabswid
.43126 .15966 m
.97619 .21446 L
s
0 0 0 r
2.5 Mabswid
.97619 .21446 Mdot
.039 .916 .04 r
.5 Mabswid
.43126 .15978 m
.97619 .21446 L
s
0 0 0 r
2.5 Mabswid
.97619 .21446 Mdot
.039 .916 .04 r
.5 Mabswid
.43127 .1599 m
.97619 .21446 L
s
0 0 0 r
2.5 Mabswid
.97619 .21446 Mdot
.039 .916 .04 r
.5 Mabswid
.43127 .16002 m
.97619 .21445 L
s
0 0 0 r
2.5 Mabswid
.97619 .21445 Mdot
.039 .916 .04 r
.5 Mabswid
.43127 .16014 m
.97619 .21445 L
s
0 0 0 r
2.5 Mabswid
.97619 .21445 Mdot
.039 .916 .04 r
.5 Mabswid
.43128 .16026 m
.97619 .21445 L
s
0 0 0 r
2.5 Mabswid
.97619 .21445 Mdot
.039 .916 .04 r
.5 Mabswid
.43128 .16038 m
.97619 .21444 L
s
0 0 0 r
2.5 Mabswid
.97619 .21444 Mdot
.039 .916 .04 r
.5 Mabswid
.43128 .1605 m
.97619 .21444 L
s
0 0 0 r
2.5 Mabswid
.97619 .21444 Mdot
.039 .916 .04 r
.5 Mabswid
.43129 .16062 m
.97619 .21444 L
s
0 0 0 r
2.5 Mabswid
.97619 .21444 Mdot
.039 .916 .04 r
.5 Mabswid
.43129 .16074 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43129 .16086 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.4313 .16098 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.4313 .1611 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.4313 .16123 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.4313 .16135 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43131 .16147 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43131 .16159 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43131 .16171 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43132 .16183 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43132 .16195 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43132 .16207 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43133 .16219 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43133 .16231 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43133 .16243 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43133 .16255 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43134 .16267 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43134 .16279 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43134 .16291 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43135 .16303 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43135 .16315 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43135 .16327 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43136 .1634 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43136 .16352 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43136 .16364 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43136 .16376 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43137 .16388 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43137 .164 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43137 .16412 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43138 .16424 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43138 .16436 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43138 .16448 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43138 .1646 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43139 .16472 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43139 .16484 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43139 .16496 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.4314 .16508 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.4314 .1652 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.4314 .16532 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.4314 .16544 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43141 .16556 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43141 .16568 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43141 .1658 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43142 .16592 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43142 .16604 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43142 .16616 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43142 .16628 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43143 .1664 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43143 .16653 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43143 .16665 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43143 .16677 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43144 .16689 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43144 .16701 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43144 .16713 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43145 .16725 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43145 .16737 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43145 .16749 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43145 .16761 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43146 .16773 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43146 .16785 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43146 .16797 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43146 .16809 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43147 .16821 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43147 .16833 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43147 .16845 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43147 .16857 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43148 .16869 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43148 .16881 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43148 .16893 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43149 .16905 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43149 .16917 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43149 .16929 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43149 .16941 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.4315 .16953 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.4315 .16965 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.4315 .16977 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.4315 .16989 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43151 .17001 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43151 .17013 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43151 .17025 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43151 .17037 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43152 .17049 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43152 .17061 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43152 .17073 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43152 .17085 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43153 .17097 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43153 .17109 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43153 .17121 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43153 .17133 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43154 .17145 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43154 .17157 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43154 .17169 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43154 .17181 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .17193 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .17205 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .17217 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .17229 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .17241 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43156 .17253 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43156 .17265 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43156 .17277 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43156 .17289 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43157 .17301 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43157 .17313 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43157 .17325 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43157 .17337 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43158 .17349 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43158 .17361 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43158 .17373 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43158 .17385 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .17397 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .17409 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .17421 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .17433 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .17445 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.4316 .17457 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.4316 .17469 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.4316 .17481 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.4316 .17493 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .17505 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .17517 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .17529 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .17541 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .17553 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43162 .17565 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43162 .17577 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43162 .17589 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43162 .17601 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .17613 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .17625 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .17637 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .17649 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .17661 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43164 .17673 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43164 .17685 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43164 .17697 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43164 .17709 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .17721 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .17733 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .17745 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .17757 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .17769 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .17781 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .17792 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .17804 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .17816 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .17828 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .1784 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .17852 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .17864 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .17876 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .17888 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .179 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .17912 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .17924 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .17936 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .17948 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .1796 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .17972 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .17984 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .17996 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .18008 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .1802 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .18032 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .18044 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .18056 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .18068 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .1808 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .18092 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .18104 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .18116 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .18128 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .18139 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .18151 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .18163 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .18175 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .18187 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .18199 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .18211 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .18223 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .18235 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .18247 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .18259 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .18271 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .18283 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .18295 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .18307 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .18319 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .18331 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .18343 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .18355 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .18367 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .18379 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .18391 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .18402 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .18414 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .18426 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .18438 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .1845 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .18462 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .18474 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .18486 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .18498 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .1851 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .18522 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .18534 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .18546 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .18558 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .1857 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .18582 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .18594 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .18606 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .18617 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .18629 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .18641 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .18653 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .18665 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .18677 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .18689 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .18701 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .18713 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .18725 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .18737 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .18749 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .18761 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .18773 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .18785 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .18797 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .18809 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .1882 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .18832 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .18844 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .18856 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .18868 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .1888 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .18892 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .18904 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .18916 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .18928 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .1894 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .18952 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .18964 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .18976 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .18988 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .18999 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .19011 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .19023 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .19035 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .19047 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .19059 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .19071 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .19083 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .19095 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .19107 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .19119 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .19131 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .19143 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .19155 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .19166 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .19178 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .1919 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .19202 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .19214 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .19226 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .19238 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .1925 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .19262 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .19274 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .19286 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .19298 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .1931 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .19321 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .19333 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .19345 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .19357 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .19369 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .19381 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .19393 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .19405 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .19417 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .19429 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .19441 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .19453 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .19464 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .19476 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .19488 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .195 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19512 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19524 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19536 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19548 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .1956 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19572 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19584 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19596 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19607 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .19619 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19631 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19643 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19655 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19667 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19679 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19691 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19703 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19715 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19727 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .19739 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .1975 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .19762 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .19774 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .19786 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .19798 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .1981 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .19822 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .19834 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .19846 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .19858 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .1987 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19881 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19893 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19905 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19917 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19929 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19941 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19953 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19965 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19977 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .19989 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .20001 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .20012 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .20024 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .20036 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .20048 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .2006 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .20072 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .20084 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .20096 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .20108 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .2012 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .20132 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .20143 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .20155 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .20167 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20179 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20191 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20203 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20215 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20227 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20239 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20251 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20262 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20274 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20286 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20298 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .2031 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20322 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20334 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .20346 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20358 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .2037 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20382 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20393 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20405 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20417 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20429 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20441 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20453 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20465 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20477 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20489 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20501 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20512 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20524 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20536 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .20548 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .2056 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20572 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20584 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20596 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20608 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .2062 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20631 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20643 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20655 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20667 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20679 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20691 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20703 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20715 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20727 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20739 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .2075 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20762 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20774 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20786 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20798 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .2081 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20822 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20834 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .20846 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20858 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20869 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20881 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20893 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20905 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20917 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20929 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20941 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20953 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20965 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20976 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .20988 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21012 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21024 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21036 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21048 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .2106 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21072 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21084 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21095 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21107 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21119 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21131 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21143 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21155 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21167 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21179 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21191 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21203 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21214 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21226 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21238 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .2125 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21262 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21274 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21286 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21298 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .2131 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21322 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21333 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21345 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21357 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21369 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21381 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21393 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21405 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21417 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21429 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .2144 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21452 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21464 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21476 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21488 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .215 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21512 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21524 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21536 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21548 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21559 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21571 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21583 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21595 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21607 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21619 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21631 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21643 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21655 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21666 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21678 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .2169 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21702 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21714 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21726 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21738 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .2175 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21762 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21774 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21785 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21797 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21809 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21821 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21833 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21845 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21857 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21869 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21881 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21893 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21904 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21916 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21928 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .2194 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21952 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21964 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21976 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .21988 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43197 .22 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22012 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22023 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22035 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22047 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22059 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22071 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22083 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22095 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22107 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22119 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22131 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22142 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22154 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22166 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22178 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .2219 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22202 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22214 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22226 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22238 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .2225 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22261 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22273 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43196 .22285 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22297 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22309 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22321 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22333 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22345 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22357 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22369 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .2238 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22392 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22404 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22416 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22428 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .2244 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22452 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22464 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22476 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22488 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43195 .22499 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22511 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22523 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22535 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22547 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22559 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22571 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22583 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22595 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22607 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22618 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .2263 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22642 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22654 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22666 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43194 .22678 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .2269 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22702 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22714 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22726 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22738 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22749 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22761 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22773 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22785 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22797 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22809 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22821 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22833 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43193 .22845 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22857 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22868 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .2288 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22892 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22904 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22916 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22928 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .2294 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22952 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22964 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43192 .22976 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .22988 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .22999 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23011 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23023 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23035 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23047 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23059 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23071 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23083 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23095 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43191 .23107 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23119 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23131 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23142 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23154 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23166 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23178 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .2319 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23202 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23214 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.4319 .23226 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23238 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .2325 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23262 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23273 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23285 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23297 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23309 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23321 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23333 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43189 .23345 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .23357 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .23369 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .23381 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .23393 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .23405 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .23417 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .23428 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .2344 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43188 .23452 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .23464 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .23476 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .23488 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .235 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .23512 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .23524 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .23536 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43187 .23548 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .2356 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .23571 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .23583 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .23595 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .23607 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .23619 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .23631 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43186 .23643 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .23655 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .23667 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .23679 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .23691 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .23703 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .23715 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .23726 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43185 .23738 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .2375 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .23762 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .23774 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .23786 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .23798 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .2381 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43184 .23822 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .23834 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .23846 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .23858 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .2387 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .23882 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .23893 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .23905 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43183 .23917 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .23929 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .23941 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .23953 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .23965 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .23977 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .23989 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43182 .24001 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .24013 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .24025 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .24037 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .24049 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .24061 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43181 .24073 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .24084 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .24096 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .24108 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .2412 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .24132 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .24144 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.4318 .24156 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .24168 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .2418 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .24192 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .24204 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .24216 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43179 .24228 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .2424 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .24252 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .24264 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .24275 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .24287 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43178 .24299 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .24311 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .24323 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .24335 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .24347 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .24359 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43177 .24371 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .24383 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .24395 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .24407 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .24419 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .24431 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43176 .24443 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .24455 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .24467 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .24479 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .24491 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .24502 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43175 .24514 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .24526 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .24538 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .2455 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .24562 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .24574 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43174 .24586 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .24598 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .2461 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .24622 m
.97619 .21443 L
s
0 0 0 r
2.5 Mabswid
.97619 .21443 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .24634 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43173 .24646 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .24658 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .2467 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .24682 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .24694 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .24706 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43172 .24718 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .2473 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .24742 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .24754 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .24765 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43171 .24777 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .24789 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .24801 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .24813 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .24825 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.4317 .24837 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .24849 m
.97619 .21442 L
s
0 0 0 r
2.5 Mabswid
.97619 .21442 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .24861 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .24873 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .24885 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43169 .24897 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .24909 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .24921 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .24933 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .24945 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43168 .24957 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .24969 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .24981 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .24993 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .25005 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43167 .25017 m
.97619 .21441 L
s
0 0 0 r
2.5 Mabswid
.97619 .21441 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .25029 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .25041 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .25053 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .25065 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43166 .25077 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .25089 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .25101 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .25113 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .25125 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43165 .25136 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43164 .25148 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43164 .2516 m
.97619 .2144 L
s
0 0 0 r
2.5 Mabswid
.97619 .2144 Mdot
.039 .916 .04 r
.5 Mabswid
.43164 .25172 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43164 .25184 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .25196 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .25208 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .2522 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .25232 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43163 .25244 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43162 .25256 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43162 .25268 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43162 .2528 m
.97619 .21439 L
s
0 0 0 r
2.5 Mabswid
.97619 .21439 Mdot
.039 .916 .04 r
.5 Mabswid
.43162 .25292 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .25304 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .25316 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .25328 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .2534 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.43161 .25352 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.4316 .25364 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.4316 .25376 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.4316 .25388 m
.97619 .21438 L
s
0 0 0 r
2.5 Mabswid
.97619 .21438 Mdot
.039 .916 .04 r
.5 Mabswid
.4316 .254 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .25412 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .25424 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .25436 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .25448 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43159 .2546 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43158 .25472 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43158 .25484 m
.97619 .21437 L
s
0 0 0 r
2.5 Mabswid
.97619 .21437 Mdot
.039 .916 .04 r
.5 Mabswid
.43158 .25496 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43158 .25508 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43157 .2552 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43157 .25532 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43157 .25544 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43157 .25556 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43156 .25568 m
.97619 .21436 L
s
0 0 0 r
2.5 Mabswid
.97619 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.43156 .2558 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43156 .25592 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43156 .25604 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .25616 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .25628 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .2564 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .25652 m
.97619 .21435 L
s
0 0 0 r
2.5 Mabswid
.97619 .21435 Mdot
.039 .916 .04 r
.5 Mabswid
.43155 .25664 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43154 .25676 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43154 .25688 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43154 .257 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43154 .25712 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43153 .25724 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43153 .25736 m
.97619 .21434 L
s
0 0 0 r
2.5 Mabswid
.97619 .21434 Mdot
.039 .916 .04 r
.5 Mabswid
.43153 .25748 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43153 .2576 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43152 .25772 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43152 .25784 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43152 .25796 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43152 .25808 m
.97619 .21433 L
s
0 0 0 r
2.5 Mabswid
.97619 .21433 Mdot
.039 .916 .04 r
.5 Mabswid
.43151 .2582 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43151 .25832 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43151 .25844 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.43151 .25856 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.4315 .25868 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.4315 .2588 m
.97619 .21432 L
s
0 0 0 r
2.5 Mabswid
.97619 .21432 Mdot
.039 .916 .04 r
.5 Mabswid
.4315 .25892 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.4315 .25904 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43149 .25916 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43149 .25928 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43149 .2594 m
.97619 .21431 L
s
0 0 0 r
2.5 Mabswid
.97619 .21431 Mdot
.039 .916 .04 r
.5 Mabswid
.43149 .25952 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43148 .25964 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43148 .25976 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43148 .25988 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43147 .26 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43147 .26012 m
.97619 .2143 L
s
0 0 0 r
2.5 Mabswid
.97619 .2143 Mdot
.039 .916 .04 r
.5 Mabswid
.43147 .26024 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43147 .26036 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43146 .26048 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43146 .2606 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43146 .26072 m
.97619 .21429 L
s
0 0 0 r
2.5 Mabswid
.97619 .21429 Mdot
.039 .916 .04 r
.5 Mabswid
.43146 .26084 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43145 .26096 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43145 .26108 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43145 .2612 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43145 .26132 m
.97619 .21428 L
s
0 0 0 r
2.5 Mabswid
.97619 .21428 Mdot
.039 .916 .04 r
.5 Mabswid
.43144 .26144 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43144 .26157 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43144 .26169 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43143 .26181 m
.97619 .21427 L
s
0 0 0 r
2.5 Mabswid
.97619 .21427 Mdot
.039 .916 .04 r
.5 Mabswid
.43143 .26193 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43143 .26205 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43143 .26217 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43142 .26229 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43142 .26241 m
.97619 .21426 L
s
0 0 0 r
2.5 Mabswid
.97619 .21426 Mdot
.039 .916 .04 r
.5 Mabswid
.43142 .26253 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43142 .26265 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43141 .26277 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43141 .26289 m
.97619 .21425 L
s
0 0 0 r
2.5 Mabswid
.97619 .21425 Mdot
.039 .916 .04 r
.5 Mabswid
.43141 .26301 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.4314 .26313 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.4314 .26325 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.4314 .26337 m
.97619 .21424 L
s
0 0 0 r
2.5 Mabswid
.97619 .21424 Mdot
.039 .916 .04 r
.5 Mabswid
.4314 .26349 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43139 .26361 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43139 .26373 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43139 .26385 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43138 .26397 m
.97619 .21423 L
s
0 0 0 r
2.5 Mabswid
.97619 .21423 Mdot
.039 .916 .04 r
.5 Mabswid
.43138 .26409 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43138 .26421 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43138 .26433 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43137 .26445 m
.97619 .21422 L
s
0 0 0 r
2.5 Mabswid
.97619 .21422 Mdot
.039 .916 .04 r
.5 Mabswid
.43137 .26457 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43137 .26469 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43136 .26481 m
.97619 .21421 L
s
0 0 0 r
2.5 Mabswid
.97619 .21421 Mdot
.039 .916 .04 r
.5 Mabswid
.43136 .26494 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43136 .26506 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43136 .26518 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43135 .2653 m
.97619 .2142 L
s
0 0 0 r
2.5 Mabswid
.97619 .2142 Mdot
.039 .916 .04 r
.5 Mabswid
.43135 .26542 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43135 .26554 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43134 .26566 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43134 .26578 m
.97619 .21419 L
s
0 0 0 r
2.5 Mabswid
.97619 .21419 Mdot
.039 .916 .04 r
.5 Mabswid
.43134 .2659 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43133 .26602 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43133 .26614 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43133 .26626 m
.97619 .21418 L
s
0 0 0 r
2.5 Mabswid
.97619 .21418 Mdot
.039 .916 .04 r
.5 Mabswid
.43133 .26638 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43132 .2665 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43132 .26662 m
.97619 .21417 L
s
0 0 0 r
2.5 Mabswid
.97619 .21417 Mdot
.039 .916 .04 r
.5 Mabswid
.43132 .26674 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43131 .26686 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43131 .26698 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.43131 .2671 m
.97619 .21416 L
s
0 0 0 r
2.5 Mabswid
.97619 .21416 Mdot
.039 .916 .04 r
.5 Mabswid
.4313 .26723 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.4313 .26735 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.4313 .26747 m
.97619 .21415 L
s
0 0 0 r
2.5 Mabswid
.97619 .21415 Mdot
.039 .916 .04 r
.5 Mabswid
.4313 .26759 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43129 .26771 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43129 .26783 m
.97619 .21414 L
s
0 0 0 r
2.5 Mabswid
.97619 .21414 Mdot
.039 .916 .04 r
.5 Mabswid
.43129 .26795 m
.97619 .21413 L
s
0 0 0 r
2.5 Mabswid
.97619 .21413 Mdot
.039 .916 .04 r
.5 Mabswid
.43128 .26807 m
.97619 .21413 L
s
0 0 0 r
2.5 Mabswid
.97619 .21413 Mdot
.039 .916 .04 r
.5 Mabswid
.43128 .26819 m
.97619 .21413 L
s
0 0 0 r
2.5 Mabswid
.97619 .21413 Mdot
.039 .916 .04 r
.5 Mabswid
.43128 .26831 m
.97619 .21413 L
s
0 0 0 r
2.5 Mabswid
.97619 .21413 Mdot
.039 .916 .04 r
.5 Mabswid
.43127 .26843 m
.97619 .21412 L
s
0 0 0 r
2.5 Mabswid
.97619 .21412 Mdot
.039 .916 .04 r
.5 Mabswid
.43127 .26855 m
.97619 .21412 L
s
0 0 0 r
2.5 Mabswid
.97619 .21412 Mdot
.039 .916 .04 r
.5 Mabswid
.43127 .26867 m
.97619 .21412 L
s
0 0 0 r
2.5 Mabswid
.97619 .21412 Mdot
.039 .916 .04 r
.5 Mabswid
.43126 .26879 m
.97619 .21411 L
s
0 0 0 r
2.5 Mabswid
.97619 .21411 Mdot
.039 .916 .04 r
.5 Mabswid
.43126 .26891 m
.97619 .21411 L
s
0 0 0 r
2.5 Mabswid
.97619 .21411 Mdot
.039 .916 .04 r
.5 Mabswid
.43126 .26904 m
.97619 .21411 L
s
0 0 0 r
2.5 Mabswid
.97619 .21411 Mdot
.039 .916 .04 r
.5 Mabswid
.43126 .26916 m
.97619 .2141 L
s
0 0 0 r
2.5 Mabswid
.97619 .2141 Mdot
.039 .916 .04 r
.5 Mabswid
.43125 .26928 m
.97619 .2141 L
s
0 0 0 r
2.5 Mabswid
.97619 .2141 Mdot
.039 .916 .04 r
.5 Mabswid
.43125 .2694 m
.97619 .2141 L
s
0 0 0 r
2.5 Mabswid
.97619 .2141 Mdot
.039 .916 .04 r
.5 Mabswid
.43125 .26952 m
.97619 .21409 L
s
0 0 0 r
2.5 Mabswid
.97619 .21409 Mdot
.039 .916 .04 r
.5 Mabswid
.43124 .26964 m
.97619 .21409 L
s
0 0 0 r
2.5 Mabswid
.97619 .21409 Mdot
.039 .916 .04 r
.5 Mabswid
.43124 .26976 m
.97619 .21409 L
s
0 0 0 r
2.5 Mabswid
.97619 .21409 Mdot
.039 .916 .04 r
.5 Mabswid
.43124 .26988 m
.97619 .21408 L
s
0 0 0 r
2.5 Mabswid
.97619 .21408 Mdot
.039 .916 .04 r
.5 Mabswid
.43123 .27 m
.97619 .21408 L
s
0 0 0 r
2.5 Mabswid
.97619 .21408 Mdot
.039 .916 .04 r
.5 Mabswid
.43123 .27012 m
.97619 .21408 L
s
0 0 0 r
2.5 Mabswid
.97619 .21408 Mdot
.039 .916 .04 r
.5 Mabswid
.43123 .27024 m
.97619 .21407 L
s
0 0 0 r
2.5 Mabswid
.97619 .21407 Mdot
.039 .916 .04 r
.5 Mabswid
.43122 .27036 m
.97619 .21407 L
s
0 0 0 r
2.5 Mabswid
.97619 .21407 Mdot
.039 .916 .04 r
.5 Mabswid
.43122 .27048 m
.97619 .21407 L
s
0 0 0 r
2.5 Mabswid
.97619 .21407 Mdot
.039 .916 .04 r
.5 Mabswid
.43122 .27061 m
.97619 .21406 L
s
0 0 0 r
2.5 Mabswid
.97619 .21406 Mdot
.039 .916 .04 r
.5 Mabswid
.43121 .27073 m
.97619 .21406 L
s
0 0 0 r
2.5 Mabswid
.97619 .21406 Mdot
.039 .916 .04 r
.5 Mabswid
.43121 .27085 m
.97619 .21406 L
s
0 0 0 r
2.5 Mabswid
.97619 .21406 Mdot
.039 .916 .04 r
.5 Mabswid
.43121 .27097 m
.97619 .21405 L
s
0 0 0 r
2.5 Mabswid
.97619 .21405 Mdot
.039 .916 .04 r
.5 Mabswid
.4312 .27109 m
.97619 .21405 L
s
0 0 0 r
2.5 Mabswid
.97619 .21405 Mdot
.039 .916 .04 r
.5 Mabswid
.4312 .27121 m
.97619 .21405 L
s
0 0 0 r
2.5 Mabswid
.97619 .21405 Mdot
.039 .916 .04 r
.5 Mabswid
.4312 .27133 m
.97619 .21404 L
s
0 0 0 r
2.5 Mabswid
.97619 .21404 Mdot
.039 .916 .04 r
.5 Mabswid
.43119 .27145 m
.97619 .21404 L
s
0 0 0 r
2.5 Mabswid
.97619 .21404 Mdot
.039 .916 .04 r
.5 Mabswid
.43119 .27157 m
.97619 .21403 L
s
0 0 0 r
2.5 Mabswid
.97619 .21403 Mdot
.039 .916 .04 r
.5 Mabswid
.43119 .27169 m
.97619 .21403 L
s
0 0 0 r
2.5 Mabswid
.97619 .21403 Mdot
.039 .916 .04 r
.5 Mabswid
.43118 .27181 m
.97619 .21403 L
s
0 0 0 r
2.5 Mabswid
.97619 .21403 Mdot
.039 .916 .04 r
.5 Mabswid
.43118 .27193 m
.97619 .21402 L
s
0 0 0 r
2.5 Mabswid
.97619 .21402 Mdot
.039 .916 .04 r
.5 Mabswid
.43118 .27206 m
.97619 .21402 L
s
0 0 0 r
2.5 Mabswid
.97619 .21402 Mdot
.039 .916 .04 r
.5 Mabswid
.43117 .27218 m
.97619 .21402 L
s
0 0 0 r
2.5 Mabswid
.97619 .21402 Mdot
.039 .916 .04 r
.5 Mabswid
.43117 .2723 m
.97619 .21401 L
s
0 0 0 r
2.5 Mabswid
.97619 .21401 Mdot
.039 .916 .04 r
.5 Mabswid
.43117 .27242 m
.97619 .21401 L
s
0 0 0 r
2.5 Mabswid
.97619 .21401 Mdot
.039 .916 .04 r
.5 Mabswid
.43116 .27254 m
.97619 .214 L
s
0 0 0 r
2.5 Mabswid
.97619 .214 Mdot
.039 .916 .04 r
.5 Mabswid
.43116 .27266 m
.97619 .214 L
s
0 0 0 r
2.5 Mabswid
.97619 .214 Mdot
.039 .916 .04 r
.5 Mabswid
.43116 .27278 m
.97619 .214 L
s
0 0 0 r
2.5 Mabswid
.97619 .214 Mdot
.039 .916 .04 r
.5 Mabswid
.43115 .2729 m
.97619 .21399 L
s
0 0 0 r
2.5 Mabswid
.97619 .21399 Mdot
.039 .916 .04 r
.5 Mabswid
.43115 .27302 m
.97619 .21399 L
s
0 0 0 r
2.5 Mabswid
.97619 .21399 Mdot
.039 .916 .04 r
.5 Mabswid
.43115 .27314 m
.97619 .21399 L
s
0 0 0 r
2.5 Mabswid
.97619 .21399 Mdot
.039 .916 .04 r
.5 Mabswid
.43114 .27327 m
.97619 .21398 L
s
0 0 0 r
2.5 Mabswid
.97619 .21398 Mdot
.039 .916 .04 r
.5 Mabswid
.43114 .27339 m
.97619 .21398 L
s
0 0 0 r
2.5 Mabswid
.97619 .21398 Mdot
.039 .916 .04 r
.5 Mabswid
.43114 .27351 m
.97619 .21397 L
s
0 0 0 r
2.5 Mabswid
.97619 .21397 Mdot
.039 .916 .04 r
.5 Mabswid
.43113 .27363 m
.97619 .21397 L
s
0 0 0 r
2.5 Mabswid
.97619 .21397 Mdot
.039 .916 .04 r
.5 Mabswid
.43113 .27375 m
.97619 .21397 L
s
0 0 0 r
2.5 Mabswid
.97619 .21397 Mdot
.039 .916 .04 r
.5 Mabswid
.43113 .27387 m
.97619 .21396 L
s
0 0 0 r
2.5 Mabswid
.97619 .21396 Mdot
.039 .916 .04 r
.5 Mabswid
.43112 .27399 m
.97619 .21396 L
s
0 0 0 r
2.5 Mabswid
.97619 .21396 Mdot
.039 .916 .04 r
.5 Mabswid
.43112 .27411 m
.97619 .21395 L
s
0 0 0 r
2.5 Mabswid
.97619 .21395 Mdot
0 0 m
1 0 L
1 .42857 L
0 .42857 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[66]:=",
  ImageSize->{288, 123.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Nb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00IooooolCo`0009gooooo00?o0000ooooooooool0
1_ooool006Oooooo00?o0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`2Kooooo`03o`000?oo
oooooooo00Kooooo001VoooooaCo0000WOooool00ol0003oooooooooo`06ooooo`00I_ooool2o`00
017oOgmo00?o0000ooooooooool0Voooool00ol0003oooooooooo`06ooooo`00IOooool00ol0003o
Ogmoo`00000AogmoO`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool006Cooooo
00Co0000ogmoOomoOgoo00004OmoOgl00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Ko
oooo001Tooooo`04o`000?moOgooOgmoo`00017oOgmo00?o0000ooooooooool0Voooool00ol0003o
ooooooooo`06ooooo`00Hoooool01Ol0003oOgmoogmoOomoOgoo0000017oOgmo00?o0000oooooooo
ool0Voooool00ol0003oooooooooo`06ooooo`00Hoooool01?l0003oOgmoogmoOomoOglCo`0009go
oooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmo
ogmoO`0?ogmoO`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool0067ooooo00?o
0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003ooooooooo
o`06ooooo`00HOooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002L
ooooo`03o`000?oooooooooo00Kooooo001Pooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmo
OomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool0063ooooo00?o0000ogmoOomo
Ogl01?moOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00
Goooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`00
0?oooooooooo00Kooooo001Oooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl03omo
Ogl2o`0009cooooo00?o0000ooooooooool01_ooool005kooooo00?o0000ogmoOomoOgl01_moOgl0
0ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00GOooool00ol0
003oOgmoogmoO`07ogmoOaCo0000W?ooool00ol0003oooooooooo`06ooooo`00GOooool00ol0003o
OgmoogmoO`07ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Ko
oooo001Looooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo
00?o0000ooooooooool01_ooool005cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmo
O`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00G?ooool00ol0003oOgmoogmoO`08
ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Koooo
o`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000oooo
ooooool01_ooool005_ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0?ogmoO`;o
0000W?ooool00ol0003oooooooooo`06ooooo`00Foooool00ol0003oOgmoogmoO`09ogmoO`03o`00
0?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Kooooo`03o`000?mo
OgooOgmo00WoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_oo
ool005[ooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool0
0ol0003oooooooooo`06ooooo`00F_ooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo
00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Jooooo`03o`000?moOgooOgmo00[o
Ogmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool005[ooooo
00?o0000ogmoOomoOgl02_moOglDo`0009cooooo00?o0000ooooooooool01_ooool005Wooooo00?o
0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o
0000ooooooooool01_ooool005Wooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0?
ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool005Wooooo00?o0000ogmo
OomoOgl02omoOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000oooo
ooooool01_ooool005Wooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0?ogmoO`03
o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool005Sooooo00?o0000ogmoOomoOgl0
3?moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool0
1_ooool005Sooooo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?mo
Ogoo000009_ooooo00?o0000ooooooooool01_ooool005Sooooo00?o0000ogmoOomoOgl03?moOgl0
0ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool0
05Sooooo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo0000
09_ooooo00?o0000ooooooooool01_ooool005Oooooo00?o0000ogmoOomoOgl03OmoOgl00ol0003o
OgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool000Oooooo
F_l9jPX6ogmoO`03o`000?moOgooOgmo00ooOgmo00?o0000ogmoOol00000Voooool00ol0003ooooo
ooooo`06ooooo`001ooooom>o`WZ2P03o`000?l9jP[o2NX:01_o2NX:1_moOgl00ol0003oOgmoo`00
002Kooooo`03o`000?oooooooooo00Kooooo0007ooooodko2NX:00?o0000o`WZ2_l9jPX0:Ol9jPZF
ooooo`03o`000?oooooooooo00Kooooo0007ooooodko2NX:00?o0000o`WZ2_l9jPX0<_l9jPZ=oooo
o`03o`000?oooooooooo00Kooooo0007ooooodko2NX:00?o0000o`WZ2_l9jPX0>ol9jPZ4ooooo`03
o`000?oooooooooo00Kooooo0007ooooodko2NX:00?o0000o`WZ2_l9jPX0A?l9jPYkooooo`03o`00
0?oooooooooo00Kooooo0007ooooodko2NX:00?o0000o`WZ2_l9jPX0COl9jPYbooooo`03o`000?oo
oooooooo00Kooooo0007ooooojOo2NX:JOooool00ol0003oooooooooo`06ooooo`001ooooonao`WZ
2Uoooooo00?o0000ooooooooool01_ooool000OoooooCOl9jPX00ol0003o2NX:o`WZ2P1Zo`WZ2UKo
oooo00?o0000ooooooooool01_ooool000OoooooCOl9jPX00ol0003o2NX:o`WZ2P1co`WZ2Tgooooo
00?o0000ooooooooool01_ooool000OoooooCOl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9
jP[o2NX:05Go2NX:A?ooool00ol0003oooooooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o
2NX:02Co2NX:00?o0000o`WZ2_l9jPX0G_l9jPXkooooo`03o`000?oooooooooo00Kooooo0007oooo
odgo2NX:00?o0000o`WZ2_l9jPX09?l9jPX00ol0003o2NX:o`WZ2P1Xo`WZ2S7ooooo00?o0000oooo
ooooool01_ooool000OoooooCOl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:077o
2NX::?ooool00ol0003oooooooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:
00?o0000o`WZ2_l9jPX0N_l9jPXOooooo`03o`000?oooooooooo00Kooooo0007ooooodgo2NX:00?o
0000o`WZ2_l9jPX09?l9jPX00ol0003o2NX:o`WZ2P23o`WZ2QKooooo00?o0000ooooooooool01_oo
ool000OoooooCOl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:08co2NX:3Oooool0
0ol0003oooooooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o0000o`WZ
2_l9jPX0UOl9jPX4ooooo`03o`000?oooooooooo00Kooooo0007ooooodgo2NX:00?o0000o`WZ2_l9
jPX09?l9jPX00ol0003o2NX:o`WZ2P2Ho`WZ2P;o00002?ooool000OoooooCOl9jPX00ol0003o2NX:
o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:09Co2NX:1?ooool2o`0000Sooooo0007ooooodgo2NX:00?o
0000o`WZ2_l9jPX09?l9jPX00ol0003o2NX:o`WZ2P2;o`WZ2Pkooooo00?o0000ooooooooool01_oo
ool000OoooooCOl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:08;o2NX:5oooool0
0ol0003oooooooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o0000o`WZ
2_l9jPX0NOl9jPXPooooo`03o`000?oooooooooo00Kooooo0007ooooodgo2NX:00?o0000o`WZ2_l9
jPX09?l9jPX00ol0003o2NX:o`WZ2P1`o`WZ2RWooooo00?o0000ooooooooool01_ooool000Oooooo
COl9jPX00ol0003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:06Oo2NX:<_ooool00ol0003ooooo
ooooo`06ooooo`001ooooom=o`WZ2P03o`000?l9jP[o2NX:02Co2NX:00?o0000o`WZ2_l9jPX0GOl9
jPXlooooo`03o`000?oooooooooo00Kooooo0007ooooodgo2NX:00?o0000o`WZ2_l9jPX09?l9jPX0
0ol0003o2NX:o`WZ2P1Do`WZ2TGooooo00?o0000ooooooooool01_ooool000OoooooCOl9jPX00ol0
003o2NX:o`WZ2P0To`WZ2P03o`000?l9jP[o2NX:04_o2NX:C_ooool00ol0003oooooooooo`06oooo
o`001ooooom=o`WZ2P03o`000?l9jP[o2NX:06Wo2NX:Eoooool00ol0003oooooooooo`06ooooo`00
1ooooon`o`WZ2V3ooooo00?o0000ooooooooool01_ooool000OoooooY_l9jPYZooooo`03o`000?oo
oooooooo00Kooooo0007oooooigo2NX:Loooool00ol0003oooooooooo`06ooooo`001ooooom>o`WZ
2P03o`000?l9jP[o2NX:04?o2NX:O?ooool00ol0003oooooooooo`06ooooo`001ooooom>o`WZ2P03
o`000?l9jP[o2NX:03[o2NX:QOooool00ol0003oooooooooo`06ooooo`001ooooom>o`WZ2P03o`00
0?l9jP[o2NX:037o2NX:S_ooool00ol0003oooooooooo`06ooooo`001ooooom>o`WZ2P03o`000?l9
jP[o2NX:02So2NX:Uoooool00ol0003oooooooooo`06ooooo`001ooooom^o`WZ2PCoOgmo00Co0000
ogmoOol0003o0000V_ooool00ol0003oooooooooo`06ooooo`001ooooomRo`WZ2Q3oOgmo00?o0000
ogmoOol00000Voooool00ol0003oooooooooo`06ooooo`001ooooom?o`WZ2P03o`000?l9jP[o2NX:
00Co2NX:2_moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000oooo
ooooool01_ooool005Oooooo00?o0000ogmoOomoOgl03OmoOgl00ol0003oOgmoogmoO`0?ogmoO`03
o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool005Oooooo00?o0000ogmoOomoOgl0
3OmoOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool0
1_ooool005Sooooo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?mo
Ogoo000009_ooooo00?o0000ooooooooool01_ooool005Sooooo00?o0000ogmoOomoOgl03?moOgl0
0ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool0
05Sooooo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo0000
09_ooooo00?o0000ooooooooool01_ooool005Sooooo00?o0000ogmoOomoOgl03?moOgl00ol0003o
OgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool005Wooooo
00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgoo000009_ooooo
00?o0000ooooooooool01_ooool005Wooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmo
O`0?ogmoO`03o`000?moOgoo000009_ooooo00?o0000ooooooooool01_ooool005Wooooo00?o0000
ogmoOomoOgl02omoOglCo`000003ogmoOol0003ooooo09[ooooo00?o0000ooooooooool01_ooool0
05[ooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0
003oooooooooo`06ooooo`00F_ooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00oo
Ogmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Jooooo`03o`000?moOgooOgmo00[oOgmo
00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool005[ooooo00?o
0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003ooooooooo
o`06ooooo`00Foooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002L
ooooo`03o`000?oooooooooo00Kooooo001Kooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmo
OomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_ooool005_ooooo00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00
Foooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`00
0?oooooooooo00Kooooo001Looooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl03omo
Ogl2o`0009cooooo00?o0000ooooooooool01_ooool005cooooo00?o0000ogmoOomoOgl02?moOgl0
0ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00G?ooool00ol0
003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo
00Kooooo001Mooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009co
oooo00?o0000ooooooooool01_ooool005gooooo00?o0000ogmoOomoOgl01omoOglDo`0009cooooo
00?o0000ooooooooool01_ooool005kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmo
O`0?ogmoO`;o0000W?ooool00ol0003oooooooooo`06ooooo`00G_ooool00ol0003oOgmoogmoO`06
ogmoO`03o`000?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Ooooo
o`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000oooo
ooooool01_ooool0063ooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`0?ogmoO`;o
0000W?ooool00ol0003oooooooooo`06ooooo`00H?ooool00ol0003oOgmoogmoO`04ogmoO`03o`00
0?moOgooOgmo00ooOgmo0_l0002Looooo`03o`000?oooooooooo00Kooooo001Qooooo`03o`000?mo
OgooOgmo00?oOgmo00?o0000ogmoOomoOgl03omoOgl2o`0009cooooo00?o0000ooooooooool01_oo
ool0067ooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`0?ogmoO`;o0000W?ooool0
0ol0003oooooooooo`06ooooo`00H_ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo
00ooOgmo00?o0000ooooooooool0Voooool00ol0003oooooooooo`06ooooo`00H_ooool00ol0003o
OgmoogmoO`02ogmoOa?o0000WOooool00ol0003oooooooooo`06ooooo`00Hoooool01Ol0003oOgmo
ogmoOomoOgoo0000017oOgmo00?o0000ooooooooool0Voooool00ol0003oooooooooo`06ooooo`00
Hoooool01Ol0003oOgmoogmoOomoOgoo0000017oOgmo00?o0000ooooooooool0Voooool00ol0003o
ooooooooo`06ooooo`00I?ooool01?l0003oOgmoogmoOol0000AogmoO`03o`000?oooooooooo09_o
oooo00?o0000ooooooooool01_ooool006Gooooo00?o0000ogmoOol000004OmoOgl00ol0003ooooo
ooooo`2Kooooo`03o`000?oooooooooo00Kooooo001Uooooo`03o`000?moOgoo0000017oOgmo00?o
0000ooooooooool0Voooool00ol0003oooooooooo`06ooooo`00I_oooolDo`0009gooooo00?o0000
ooooooooool01_ooool006Kooooo0_l0000AogmoO`03o`000?oooooooooo09_ooooo00?o0000oooo
ooooool01_ooool006Oooooo4ol0002Mooooo`03o`000?oooooooooo00Kooooo003oooooob7ooooo
003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {122.375, 0}} -> {-21.938, -15.7502, 0.257408, \
0.257408}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],

Cell[BoxData[
    \({FocalPoint \[Rule] {50.0000333518818`, 0, 0}, 
      FocusType \[Rule] RMSFocus, 
      WeightedSpotSize \[Rule] 0.00921651959420652`, 
      SpotSize \[Rule] 0.009216519594206527`, 
      BackFocalLength \[Rule] 40.0208748389164`, 
      FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
      TurboRays \[Rule] TurboRays}\)], "Output",
  CellLabel->"Out[66]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell["\<\
This final calculation indicates that the fifth-order symbolic solution is a \
close fit to the actual system.\
\>", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.2", "AOG2.", "AOG2.2.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Finite-Conjugate Spherical Lens Design", "Subsubsection",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2", "2.2.2"}],

Cell[TextData[{
  "In this section, we will consider the application of symbolic optimization \
to a finite-conjugate lens system. Finite-conjugate lens systems are \
considerably more difficult to accurately represent symbolically than a \
similar finite-conjugate system. In particular, the use of symbolic angular \
parameters requires a greater number of expansion terms in order order to \
obtain the same modelling accuracy. This can significantly increase the size \
of the symbolic solution as well as the amount of time required for the \
symbolic calculation. Let us now consider such an optical system that images \
a point source of light onto a surface. This is defined for the ",
  StyleBox["opticalsystem", "Input"],
  " shown below."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell["\<\
opticalsystem = {
\tMove[WedgeOfRays[10,NumberOfRays->101, \
IntrinsicMedium->1],-90,{\[Theta]/Degree,0}],
\tSphericalLens[{1/c1,35},{1/c2,-35},30,10, ComponentMedium->3/2],
\tMove[Screen[30],60]};\
\>", "Input",
  CellLabel->"In[67]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{

Cell["\<\
plot = TurboPlot[opticalsystem,PlotType->TopView, EmbedRays->False];\
\>", "Input",
  CellLabel->"In[68]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.595238 0.00634921 0.1 0.00634921 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.61668 .00476 m
.63729 .00476 L
.64947 .03651 L
.6045 .03651 L
.61668 .00476 L
F
.6045 .03651 m
.64947 .03651 L
.65645 .06825 L
.59752 .06825 L
.6045 .03651 L
F
.59752 .06825 m
.65645 .06825 L
.65873 .1 L
.59524 .1 L
.59752 .06825 L
F
.59524 .1 m
.65873 .1 L
.65645 .13175 L
.59752 .13175 L
.59524 .1 L
F
.59752 .13175 m
.65645 .13175 L
.64947 .16349 L
.6045 .16349 L
.59752 .13175 L
F
.6045 .16349 m
.64947 .16349 L
.63729 .19524 L
.61668 .19524 L
.6045 .16349 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.61668 .00476 m
.6045 .03651 L
.59752 .06825 L
.59524 .1 L
.59752 .13175 L
.6045 .16349 L
.61668 .19524 L
.63729 .19524 L
.64947 .16349 L
.65645 .13175 L
.65873 .1 L
.65645 .06825 L
.64947 .03651 L
.63729 .00476 L
.61668 .00476 L
s
.5 g
.61668 .1 m
.63729 .1 L
.64947 .1 L
.6045 .1 L
.61668 .1 L
F
.6045 .1 m
.64947 .1 L
.65645 .1 L
.59752 .1 L
.6045 .1 L
F
.59752 .1 m
.65645 .1 L
.65873 .1 L
.59524 .1 L
.59752 .1 L
F
.59524 .1 m
.65873 .1 L
.65645 .1 L
.59752 .1 L
.59524 .1 L
F
.59752 .1 m
.65645 .1 L
.64947 .1 L
.6045 .1 L
.59752 .1 L
F
.6045 .1 m
.64947 .1 L
.63729 .1 L
.61668 .1 L
.6045 .1 L
F
0 g
.61668 .1 m
.6045 .1 L
.59752 .1 L
.59524 .1 L
.59752 .1 L
.6045 .1 L
.61668 .1 L
.63729 .1 L
.64947 .1 L
.65645 .1 L
.65873 .1 L
.65645 .1 L
.64947 .1 L
.63729 .1 L
.61668 .1 L
s
.61668 .19524 m
.63729 .19524 L
.63729 .19199 L
.61668 .19199 L
.61668 .19524 L
s
.61668 .19199 m
.63729 .19199 L
.63729 .18248 L
.61668 .18248 L
.61668 .19199 L
s
.61668 .18248 m
.63729 .18248 L
.63729 .16734 L
.61668 .16734 L
.61668 .18248 L
s
.61668 .16734 m
.63729 .16734 L
.63729 .14762 L
.61668 .14762 L
.61668 .16734 L
s
.61668 .14762 m
.63729 .14762 L
.63729 .12465 L
.61668 .12465 L
.61668 .14762 L
s
.61668 .12465 m
.63729 .12465 L
.63729 .1 L
.61668 .1 L
.61668 .12465 L
s
.61668 .1 m
.63729 .1 L
.63729 .07535 L
.61668 .07535 L
.61668 .1 L
s
.61668 .07535 m
.63729 .07535 L
.63729 .05238 L
.61668 .05238 L
.61668 .07535 L
s
.61668 .05238 m
.63729 .05238 L
.63729 .03266 L
.61668 .03266 L
.61668 .05238 L
s
.61668 .03266 m
.63729 .03266 L
.63729 .01752 L
.61668 .01752 L
.61668 .03266 L
s
.61668 .01752 m
.63729 .01752 L
.63729 .00801 L
.61668 .00801 L
.61668 .01752 L
s
.61668 .00801 m
.63729 .00801 L
.63729 .00476 L
.61668 .00476 L
.61668 .00801 L
s
.61668 .00476 m
.63729 .00476 L
.63729 .00801 L
.61668 .00801 L
.61668 .00476 L
s
.61668 .00801 m
.63729 .00801 L
.63729 .01752 L
.61668 .01752 L
.61668 .00801 L
s
.61668 .01752 m
.63729 .01752 L
.63729 .03266 L
.61668 .03266 L
.61668 .01752 L
s
.61668 .03266 m
.63729 .03266 L
.63729 .05238 L
.61668 .05238 L
.61668 .03266 L
s
.61668 .05238 m
.63729 .05238 L
.63729 .07535 L
.61668 .07535 L
.61668 .05238 L
s
.61668 .07535 m
.63729 .07535 L
.63729 .1 L
.61668 .1 L
.61668 .07535 L
s
.61668 .1 m
.63729 .1 L
.63729 .12465 L
.61668 .12465 L
.61668 .1 L
s
.61668 .12465 m
.63729 .12465 L
.63729 .14762 L
.61668 .14762 L
.61668 .12465 L
s
.61668 .14762 m
.63729 .14762 L
.63729 .16734 L
.61668 .16734 L
.61668 .14762 L
s
.61668 .16734 m
.63729 .16734 L
.63729 .18248 L
.61668 .18248 L
.61668 .16734 L
s
.61668 .18248 m
.63729 .18248 L
.63729 .19199 L
.61668 .19199 L
.61668 .18248 L
s
.61668 .19199 m
.63729 .19199 L
.63729 .19524 L
.61668 .19524 L
.61668 .19199 L
s
.97619 .00476 m
.97619 .03651 L
.97619 .06825 L
.97619 .1 L
.97619 .13175 L
.97619 .16349 L
.97619 .19524 L
.97619 .19524 L
.97619 .16349 L
.97619 .13175 L
.97619 .1 L
.97619 .06825 L
.97619 .03651 L
.97619 .00476 L
.97619 .00476 L
s
.97619 .1 m
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
s
.97619 .19524 m
.97619 .19199 L
.97619 .18248 L
.97619 .16734 L
.97619 .14762 L
.97619 .12465 L
.97619 .1 L
.97619 .07535 L
.97619 .05238 L
.97619 .03266 L
.97619 .01752 L
.97619 .00801 L
.97619 .00476 L
.97619 .00801 L
.97619 .01752 L
.97619 .03266 L
.97619 .05238 L
.97619 .07535 L
.97619 .1 L
.97619 .12465 L
.97619 .14762 L
.97619 .16734 L
.97619 .18248 L
.97619 .19199 L
.97619 .19524 L
s
.039 .916 .04 r
.02381 .1 m
.60105 .1505 L
s
0 0 0 r
2.5 Mabswid
.60105 .1505 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60081 .14947 L
s
0 0 0 r
2.5 Mabswid
.60081 .14947 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60058 .14843 L
s
0 0 0 r
2.5 Mabswid
.60058 .14843 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60035 .1474 L
s
0 0 0 r
2.5 Mabswid
.60035 .1474 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60013 .14637 L
s
0 0 0 r
2.5 Mabswid
.60013 .14637 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59991 .14534 L
s
0 0 0 r
2.5 Mabswid
.59991 .14534 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5997 .14431 L
s
0 0 0 r
2.5 Mabswid
.5997 .14431 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59949 .14329 L
s
0 0 0 r
2.5 Mabswid
.59949 .14329 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59929 .14226 L
s
0 0 0 r
2.5 Mabswid
.59929 .14226 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5991 .14124 L
s
0 0 0 r
2.5 Mabswid
.5991 .14124 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59891 .14021 L
s
0 0 0 r
2.5 Mabswid
.59891 .14021 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59872 .13919 L
s
0 0 0 r
2.5 Mabswid
.59872 .13919 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59854 .13817 L
s
0 0 0 r
2.5 Mabswid
.59854 .13817 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59837 .13715 L
s
0 0 0 r
2.5 Mabswid
.59837 .13715 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5982 .13614 L
s
0 0 0 r
2.5 Mabswid
.5982 .13614 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59803 .13512 L
s
0 0 0 r
2.5 Mabswid
.59803 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59787 .13411 L
s
0 0 0 r
2.5 Mabswid
.59787 .13411 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59772 .13309 L
s
0 0 0 r
2.5 Mabswid
.59772 .13309 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59757 .13208 L
s
0 0 0 r
2.5 Mabswid
.59757 .13208 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59742 .13107 L
s
0 0 0 r
2.5 Mabswid
.59742 .13107 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59728 .13005 L
s
0 0 0 r
2.5 Mabswid
.59728 .13005 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59714 .12904 L
s
0 0 0 r
2.5 Mabswid
.59714 .12904 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59701 .12803 L
s
0 0 0 r
2.5 Mabswid
.59701 .12803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59689 .12703 L
s
0 0 0 r
2.5 Mabswid
.59689 .12703 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59677 .12602 L
s
0 0 0 r
2.5 Mabswid
.59677 .12602 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59665 .12501 L
s
0 0 0 r
2.5 Mabswid
.59665 .12501 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59654 .124 L
s
0 0 0 r
2.5 Mabswid
.59654 .124 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59643 .123 L
s
0 0 0 r
2.5 Mabswid
.59643 .123 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59633 .12199 L
s
0 0 0 r
2.5 Mabswid
.59633 .12199 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59623 .12099 L
s
0 0 0 r
2.5 Mabswid
.59623 .12099 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59614 .11999 L
s
0 0 0 r
2.5 Mabswid
.59614 .11999 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59605 .11898 L
s
0 0 0 r
2.5 Mabswid
.59605 .11898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59597 .11798 L
s
0 0 0 r
2.5 Mabswid
.59597 .11798 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59589 .11698 L
s
0 0 0 r
2.5 Mabswid
.59589 .11698 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59581 .11598 L
s
0 0 0 r
2.5 Mabswid
.59581 .11598 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59574 .11498 L
s
0 0 0 r
2.5 Mabswid
.59574 .11498 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59568 .11398 L
s
0 0 0 r
2.5 Mabswid
.59568 .11398 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59562 .11298 L
s
0 0 0 r
2.5 Mabswid
.59562 .11298 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59556 .11198 L
s
0 0 0 r
2.5 Mabswid
.59556 .11198 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59551 .11098 L
s
0 0 0 r
2.5 Mabswid
.59551 .11098 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59546 .10998 L
s
0 0 0 r
2.5 Mabswid
.59546 .10998 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59542 .10898 L
s
0 0 0 r
2.5 Mabswid
.59542 .10898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59538 .10798 L
s
0 0 0 r
2.5 Mabswid
.59538 .10798 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59535 .10698 L
s
0 0 0 r
2.5 Mabswid
.59535 .10698 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59532 .10599 L
s
0 0 0 r
2.5 Mabswid
.59532 .10599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59529 .10499 L
s
0 0 0 r
2.5 Mabswid
.59529 .10499 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59527 .10399 L
s
0 0 0 r
2.5 Mabswid
.59527 .10399 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59526 .10299 L
s
0 0 0 r
2.5 Mabswid
.59526 .10299 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59525 .10199 L
s
0 0 0 r
2.5 Mabswid
.59525 .10199 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .101 L
s
0 0 0 r
2.5 Mabswid
.59524 .101 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .1 L
s
0 0 0 r
2.5 Mabswid
.59524 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .099 L
s
0 0 0 r
2.5 Mabswid
.59524 .099 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59525 .09801 L
s
0 0 0 r
2.5 Mabswid
.59525 .09801 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59526 .09701 L
s
0 0 0 r
2.5 Mabswid
.59526 .09701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59527 .09601 L
s
0 0 0 r
2.5 Mabswid
.59527 .09601 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59529 .09501 L
s
0 0 0 r
2.5 Mabswid
.59529 .09501 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59532 .09401 L
s
0 0 0 r
2.5 Mabswid
.59532 .09401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59535 .09302 L
s
0 0 0 r
2.5 Mabswid
.59535 .09302 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59538 .09202 L
s
0 0 0 r
2.5 Mabswid
.59538 .09202 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59542 .09102 L
s
0 0 0 r
2.5 Mabswid
.59542 .09102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59546 .09002 L
s
0 0 0 r
2.5 Mabswid
.59546 .09002 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59551 .08902 L
s
0 0 0 r
2.5 Mabswid
.59551 .08902 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59556 .08802 L
s
0 0 0 r
2.5 Mabswid
.59556 .08802 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59562 .08702 L
s
0 0 0 r
2.5 Mabswid
.59562 .08702 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59568 .08602 L
s
0 0 0 r
2.5 Mabswid
.59568 .08602 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59574 .08502 L
s
0 0 0 r
2.5 Mabswid
.59574 .08502 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59581 .08402 L
s
0 0 0 r
2.5 Mabswid
.59581 .08402 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59589 .08302 L
s
0 0 0 r
2.5 Mabswid
.59589 .08302 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59597 .08202 L
s
0 0 0 r
2.5 Mabswid
.59597 .08202 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59605 .08102 L
s
0 0 0 r
2.5 Mabswid
.59605 .08102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59614 .08001 L
s
0 0 0 r
2.5 Mabswid
.59614 .08001 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59623 .07901 L
s
0 0 0 r
2.5 Mabswid
.59623 .07901 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59633 .07801 L
s
0 0 0 r
2.5 Mabswid
.59633 .07801 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59643 .077 L
s
0 0 0 r
2.5 Mabswid
.59643 .077 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59654 .076 L
s
0 0 0 r
2.5 Mabswid
.59654 .076 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59665 .07499 L
s
0 0 0 r
2.5 Mabswid
.59665 .07499 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59677 .07398 L
s
0 0 0 r
2.5 Mabswid
.59677 .07398 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59689 .07297 L
s
0 0 0 r
2.5 Mabswid
.59689 .07297 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59701 .07197 L
s
0 0 0 r
2.5 Mabswid
.59701 .07197 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59714 .07096 L
s
0 0 0 r
2.5 Mabswid
.59714 .07096 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59728 .06995 L
s
0 0 0 r
2.5 Mabswid
.59728 .06995 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59742 .06893 L
s
0 0 0 r
2.5 Mabswid
.59742 .06893 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59757 .06792 L
s
0 0 0 r
2.5 Mabswid
.59757 .06792 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59772 .06691 L
s
0 0 0 r
2.5 Mabswid
.59772 .06691 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59787 .06589 L
s
0 0 0 r
2.5 Mabswid
.59787 .06589 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59803 .06488 L
s
0 0 0 r
2.5 Mabswid
.59803 .06488 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5982 .06386 L
s
0 0 0 r
2.5 Mabswid
.5982 .06386 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59837 .06285 L
s
0 0 0 r
2.5 Mabswid
.59837 .06285 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59854 .06183 L
s
0 0 0 r
2.5 Mabswid
.59854 .06183 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59872 .06081 L
s
0 0 0 r
2.5 Mabswid
.59872 .06081 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59891 .05979 L
s
0 0 0 r
2.5 Mabswid
.59891 .05979 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5991 .05876 L
s
0 0 0 r
2.5 Mabswid
.5991 .05876 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59929 .05774 L
s
0 0 0 r
2.5 Mabswid
.59929 .05774 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59949 .05671 L
s
0 0 0 r
2.5 Mabswid
.59949 .05671 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5997 .05569 L
s
0 0 0 r
2.5 Mabswid
.5997 .05569 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59991 .05466 L
s
0 0 0 r
2.5 Mabswid
.59991 .05466 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60013 .05363 L
s
0 0 0 r
2.5 Mabswid
.60013 .05363 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60035 .0526 L
s
0 0 0 r
2.5 Mabswid
.60035 .0526 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60058 .05157 L
s
0 0 0 r
2.5 Mabswid
.60058 .05157 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60081 .05053 L
s
0 0 0 r
2.5 Mabswid
.60081 .05053 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60105 .0495 L
s
0 0 0 r
2.5 Mabswid
.60105 .0495 Mdot
.039 .916 .04 r
.5 Mabswid
.60105 .1505 m
.65316 .14945 L
s
0 0 0 r
2.5 Mabswid
.65316 .14945 Mdot
.039 .916 .04 r
.5 Mabswid
.60081 .14947 m
.65339 .14843 L
s
0 0 0 r
2.5 Mabswid
.65339 .14843 Mdot
.039 .916 .04 r
.5 Mabswid
.60058 .14843 m
.65361 .14742 L
s
0 0 0 r
2.5 Mabswid
.65361 .14742 Mdot
.039 .916 .04 r
.5 Mabswid
.60035 .1474 m
.65383 .14641 L
s
0 0 0 r
2.5 Mabswid
.65383 .14641 Mdot
.039 .916 .04 r
.5 Mabswid
.60013 .14637 m
.65404 .14539 L
s
0 0 0 r
2.5 Mabswid
.65404 .14539 Mdot
.039 .916 .04 r
.5 Mabswid
.59991 .14534 m
.65425 .14439 L
s
0 0 0 r
2.5 Mabswid
.65425 .14439 Mdot
.039 .916 .04 r
.5 Mabswid
.5997 .14431 m
.65446 .14338 L
s
0 0 0 r
2.5 Mabswid
.65446 .14338 Mdot
.039 .916 .04 r
.5 Mabswid
.59949 .14329 m
.65465 .14237 L
s
0 0 0 r
2.5 Mabswid
.65465 .14237 Mdot
.039 .916 .04 r
.5 Mabswid
.59929 .14226 m
.65485 .14137 L
s
0 0 0 r
2.5 Mabswid
.65485 .14137 Mdot
.039 .916 .04 r
.5 Mabswid
.5991 .14124 m
.65503 .14037 L
s
0 0 0 r
2.5 Mabswid
.65503 .14037 Mdot
.039 .916 .04 r
.5 Mabswid
.59891 .14021 m
.65522 .13936 L
s
0 0 0 r
2.5 Mabswid
.65522 .13936 Mdot
.039 .916 .04 r
.5 Mabswid
.59872 .13919 m
.65539 .13836 L
s
0 0 0 r
2.5 Mabswid
.65539 .13836 Mdot
.039 .916 .04 r
.5 Mabswid
.59854 .13817 m
.65557 .13736 L
s
0 0 0 r
2.5 Mabswid
.65557 .13736 Mdot
.039 .916 .04 r
.5 Mabswid
.59837 .13715 m
.65573 .13637 L
s
0 0 0 r
2.5 Mabswid
.65573 .13637 Mdot
.039 .916 .04 r
.5 Mabswid
.5982 .13614 m
.6559 .13537 L
s
0 0 0 r
2.5 Mabswid
.6559 .13537 Mdot
.039 .916 .04 r
.5 Mabswid
.59803 .13512 m
.65606 .13438 L
s
0 0 0 r
2.5 Mabswid
.65606 .13438 Mdot
.039 .916 .04 r
.5 Mabswid
.59787 .13411 m
.65621 .13338 L
s
0 0 0 r
2.5 Mabswid
.65621 .13338 Mdot
.039 .916 .04 r
.5 Mabswid
.59772 .13309 m
.65636 .13239 L
s
0 0 0 r
2.5 Mabswid
.65636 .13239 Mdot
.039 .916 .04 r
.5 Mabswid
.59757 .13208 m
.6565 .1314 L
s
0 0 0 r
2.5 Mabswid
.6565 .1314 Mdot
.039 .916 .04 r
.5 Mabswid
.59742 .13107 m
.65664 .13041 L
s
0 0 0 r
2.5 Mabswid
.65664 .13041 Mdot
.039 .916 .04 r
.5 Mabswid
.59728 .13005 m
.65677 .12942 L
s
0 0 0 r
2.5 Mabswid
.65677 .12942 Mdot
.039 .916 .04 r
.5 Mabswid
.59714 .12904 m
.6569 .12843 L
s
0 0 0 r
2.5 Mabswid
.6569 .12843 Mdot
.039 .916 .04 r
.5 Mabswid
.59701 .12803 m
.65703 .12744 L
s
0 0 0 r
2.5 Mabswid
.65703 .12744 Mdot
.039 .916 .04 r
.5 Mabswid
.59689 .12703 m
.65715 .12645 L
s
0 0 0 r
2.5 Mabswid
.65715 .12645 Mdot
.039 .916 .04 r
.5 Mabswid
.59677 .12602 m
.65727 .12547 L
s
0 0 0 r
2.5 Mabswid
.65727 .12547 Mdot
.039 .916 .04 r
.5 Mabswid
.59665 .12501 m
.65738 .12448 L
s
0 0 0 r
2.5 Mabswid
.65738 .12448 Mdot
.039 .916 .04 r
.5 Mabswid
.59654 .124 m
.65748 .12349 L
s
0 0 0 r
2.5 Mabswid
.65748 .12349 Mdot
.039 .916 .04 r
.5 Mabswid
.59643 .123 m
.65759 .12251 L
s
0 0 0 r
2.5 Mabswid
.65759 .12251 Mdot
.039 .916 .04 r
.5 Mabswid
.59633 .12199 m
.65769 .12153 L
s
0 0 0 r
2.5 Mabswid
.65769 .12153 Mdot
.039 .916 .04 r
.5 Mabswid
.59623 .12099 m
.65778 .12054 L
s
0 0 0 r
2.5 Mabswid
.65778 .12054 Mdot
.039 .916 .04 r
.5 Mabswid
.59614 .11999 m
.65787 .11956 L
s
0 0 0 r
2.5 Mabswid
.65787 .11956 Mdot
.039 .916 .04 r
.5 Mabswid
.59605 .11898 m
.65795 .11858 L
s
0 0 0 r
2.5 Mabswid
.65795 .11858 Mdot
.039 .916 .04 r
.5 Mabswid
.59597 .11798 m
.65803 .1176 L
s
0 0 0 r
2.5 Mabswid
.65803 .1176 Mdot
.039 .916 .04 r
.5 Mabswid
.59589 .11698 m
.65811 .11662 L
s
0 0 0 r
2.5 Mabswid
.65811 .11662 Mdot
.039 .916 .04 r
.5 Mabswid
.59581 .11598 m
.65818 .11564 L
s
0 0 0 r
2.5 Mabswid
.65818 .11564 Mdot
.039 .916 .04 r
.5 Mabswid
.59574 .11498 m
.65825 .11466 L
s
0 0 0 r
2.5 Mabswid
.65825 .11466 Mdot
.039 .916 .04 r
.5 Mabswid
.59568 .11398 m
.65831 .11368 L
s
0 0 0 r
2.5 Mabswid
.65831 .11368 Mdot
.039 .916 .04 r
.5 Mabswid
.59562 .11298 m
.65837 .1127 L
s
0 0 0 r
2.5 Mabswid
.65837 .1127 Mdot
.039 .916 .04 r
.5 Mabswid
.59556 .11198 m
.65842 .11172 L
s
0 0 0 r
2.5 Mabswid
.65842 .11172 Mdot
.039 .916 .04 r
.5 Mabswid
.59551 .11098 m
.65847 .11074 L
s
0 0 0 r
2.5 Mabswid
.65847 .11074 Mdot
.039 .916 .04 r
.5 Mabswid
.59546 .10998 m
.65852 .10977 L
s
0 0 0 r
2.5 Mabswid
.65852 .10977 Mdot
.039 .916 .04 r
.5 Mabswid
.59542 .10898 m
.65856 .10879 L
s
0 0 0 r
2.5 Mabswid
.65856 .10879 Mdot
.039 .916 .04 r
.5 Mabswid
.59538 .10798 m
.65859 .10781 L
s
0 0 0 r
2.5 Mabswid
.65859 .10781 Mdot
.039 .916 .04 r
.5 Mabswid
.59535 .10698 m
.65863 .10684 L
s
0 0 0 r
2.5 Mabswid
.65863 .10684 Mdot
.039 .916 .04 r
.5 Mabswid
.59532 .10599 m
.65865 .10586 L
s
0 0 0 r
2.5 Mabswid
.65865 .10586 Mdot
.039 .916 .04 r
.5 Mabswid
.59529 .10499 m
.65868 .10488 L
s
0 0 0 r
2.5 Mabswid
.65868 .10488 Mdot
.039 .916 .04 r
.5 Mabswid
.59527 .10399 m
.6587 .10391 L
s
0 0 0 r
2.5 Mabswid
.6587 .10391 Mdot
.039 .916 .04 r
.5 Mabswid
.59526 .10299 m
.65871 .10293 L
s
0 0 0 r
2.5 Mabswid
.65871 .10293 Mdot
.039 .916 .04 r
.5 Mabswid
.59525 .10199 m
.65872 .10195 L
s
0 0 0 r
2.5 Mabswid
.65872 .10195 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .101 m
.65873 .10098 L
s
0 0 0 r
2.5 Mabswid
.65873 .10098 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .1 m
.65873 .1 L
s
0 0 0 r
2.5 Mabswid
.65873 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .099 m
.65873 .09902 L
s
0 0 0 r
2.5 Mabswid
.65873 .09902 Mdot
.039 .916 .04 r
.5 Mabswid
.59525 .09801 m
.65872 .09805 L
s
0 0 0 r
2.5 Mabswid
.65872 .09805 Mdot
.039 .916 .04 r
.5 Mabswid
.59526 .09701 m
.65871 .09707 L
s
0 0 0 r
2.5 Mabswid
.65871 .09707 Mdot
.039 .916 .04 r
.5 Mabswid
.59527 .09601 m
.6587 .09609 L
s
0 0 0 r
2.5 Mabswid
.6587 .09609 Mdot
.039 .916 .04 r
.5 Mabswid
.59529 .09501 m
.65868 .09512 L
s
0 0 0 r
2.5 Mabswid
.65868 .09512 Mdot
.039 .916 .04 r
.5 Mabswid
.59532 .09401 m
.65865 .09414 L
s
0 0 0 r
2.5 Mabswid
.65865 .09414 Mdot
.039 .916 .04 r
.5 Mabswid
.59535 .09302 m
.65863 .09316 L
s
0 0 0 r
2.5 Mabswid
.65863 .09316 Mdot
.039 .916 .04 r
.5 Mabswid
.59538 .09202 m
.65859 .09219 L
s
0 0 0 r
2.5 Mabswid
.65859 .09219 Mdot
.039 .916 .04 r
.5 Mabswid
.59542 .09102 m
.65856 .09121 L
s
0 0 0 r
2.5 Mabswid
.65856 .09121 Mdot
.039 .916 .04 r
.5 Mabswid
.59546 .09002 m
.65852 .09023 L
s
0 0 0 r
2.5 Mabswid
.65852 .09023 Mdot
.039 .916 .04 r
.5 Mabswid
.59551 .08902 m
.65847 .08926 L
s
0 0 0 r
2.5 Mabswid
.65847 .08926 Mdot
.039 .916 .04 r
.5 Mabswid
.59556 .08802 m
.65842 .08828 L
s
0 0 0 r
2.5 Mabswid
.65842 .08828 Mdot
.039 .916 .04 r
.5 Mabswid
.59562 .08702 m
.65837 .0873 L
s
0 0 0 r
2.5 Mabswid
.65837 .0873 Mdot
.039 .916 .04 r
.5 Mabswid
.59568 .08602 m
.65831 .08632 L
s
0 0 0 r
2.5 Mabswid
.65831 .08632 Mdot
.039 .916 .04 r
.5 Mabswid
.59574 .08502 m
.65825 .08534 L
s
0 0 0 r
2.5 Mabswid
.65825 .08534 Mdot
.039 .916 .04 r
.5 Mabswid
.59581 .08402 m
.65818 .08436 L
s
0 0 0 r
2.5 Mabswid
.65818 .08436 Mdot
.039 .916 .04 r
.5 Mabswid
.59589 .08302 m
.65811 .08338 L
s
0 0 0 r
2.5 Mabswid
.65811 .08338 Mdot
.039 .916 .04 r
.5 Mabswid
.59597 .08202 m
.65803 .0824 L
s
0 0 0 r
2.5 Mabswid
.65803 .0824 Mdot
.039 .916 .04 r
.5 Mabswid
.59605 .08102 m
.65795 .08142 L
s
0 0 0 r
2.5 Mabswid
.65795 .08142 Mdot
.039 .916 .04 r
.5 Mabswid
.59614 .08001 m
.65787 .08044 L
s
0 0 0 r
2.5 Mabswid
.65787 .08044 Mdot
.039 .916 .04 r
.5 Mabswid
.59623 .07901 m
.65778 .07946 L
s
0 0 0 r
2.5 Mabswid
.65778 .07946 Mdot
.039 .916 .04 r
.5 Mabswid
.59633 .07801 m
.65769 .07847 L
s
0 0 0 r
2.5 Mabswid
.65769 .07847 Mdot
.039 .916 .04 r
.5 Mabswid
.59643 .077 m
.65759 .07749 L
s
0 0 0 r
2.5 Mabswid
.65759 .07749 Mdot
.039 .916 .04 r
.5 Mabswid
.59654 .076 m
.65748 .07651 L
s
0 0 0 r
2.5 Mabswid
.65748 .07651 Mdot
.039 .916 .04 r
.5 Mabswid
.59665 .07499 m
.65738 .07552 L
s
0 0 0 r
2.5 Mabswid
.65738 .07552 Mdot
.039 .916 .04 r
.5 Mabswid
.59677 .07398 m
.65727 .07453 L
s
0 0 0 r
2.5 Mabswid
.65727 .07453 Mdot
.039 .916 .04 r
.5 Mabswid
.59689 .07297 m
.65715 .07355 L
s
0 0 0 r
2.5 Mabswid
.65715 .07355 Mdot
.039 .916 .04 r
.5 Mabswid
.59701 .07197 m
.65703 .07256 L
s
0 0 0 r
2.5 Mabswid
.65703 .07256 Mdot
.039 .916 .04 r
.5 Mabswid
.59714 .07096 m
.6569 .07157 L
s
0 0 0 r
2.5 Mabswid
.6569 .07157 Mdot
.039 .916 .04 r
.5 Mabswid
.59728 .06995 m
.65677 .07058 L
s
0 0 0 r
2.5 Mabswid
.65677 .07058 Mdot
.039 .916 .04 r
.5 Mabswid
.59742 .06893 m
.65664 .06959 L
s
0 0 0 r
2.5 Mabswid
.65664 .06959 Mdot
.039 .916 .04 r
.5 Mabswid
.59757 .06792 m
.6565 .0686 L
s
0 0 0 r
2.5 Mabswid
.6565 .0686 Mdot
.039 .916 .04 r
.5 Mabswid
.59772 .06691 m
.65636 .06761 L
s
0 0 0 r
2.5 Mabswid
.65636 .06761 Mdot
.039 .916 .04 r
.5 Mabswid
.59787 .06589 m
.65621 .06662 L
s
0 0 0 r
2.5 Mabswid
.65621 .06662 Mdot
.039 .916 .04 r
.5 Mabswid
.59803 .06488 m
.65606 .06562 L
s
0 0 0 r
2.5 Mabswid
.65606 .06562 Mdot
.039 .916 .04 r
.5 Mabswid
.5982 .06386 m
.6559 .06463 L
s
0 0 0 r
2.5 Mabswid
.6559 .06463 Mdot
.039 .916 .04 r
.5 Mabswid
.59837 .06285 m
.65573 .06363 L
s
0 0 0 r
2.5 Mabswid
.65573 .06363 Mdot
.039 .916 .04 r
.5 Mabswid
.59854 .06183 m
.65557 .06264 L
s
0 0 0 r
2.5 Mabswid
.65557 .06264 Mdot
.039 .916 .04 r
.5 Mabswid
.59872 .06081 m
.65539 .06164 L
s
0 0 0 r
2.5 Mabswid
.65539 .06164 Mdot
.039 .916 .04 r
.5 Mabswid
.59891 .05979 m
.65522 .06064 L
s
0 0 0 r
2.5 Mabswid
.65522 .06064 Mdot
.039 .916 .04 r
.5 Mabswid
.5991 .05876 m
.65503 .05963 L
s
0 0 0 r
2.5 Mabswid
.65503 .05963 Mdot
.039 .916 .04 r
.5 Mabswid
.59929 .05774 m
.65485 .05863 L
s
0 0 0 r
2.5 Mabswid
.65485 .05863 Mdot
.039 .916 .04 r
.5 Mabswid
.59949 .05671 m
.65465 .05763 L
s
0 0 0 r
2.5 Mabswid
.65465 .05763 Mdot
.039 .916 .04 r
.5 Mabswid
.5997 .05569 m
.65446 .05662 L
s
0 0 0 r
2.5 Mabswid
.65446 .05662 Mdot
.039 .916 .04 r
.5 Mabswid
.59991 .05466 m
.65425 .05561 L
s
0 0 0 r
2.5 Mabswid
.65425 .05561 Mdot
.039 .916 .04 r
.5 Mabswid
.60013 .05363 m
.65404 .05461 L
s
0 0 0 r
2.5 Mabswid
.65404 .05461 Mdot
.039 .916 .04 r
.5 Mabswid
.60035 .0526 m
.65383 .05359 L
s
0 0 0 r
2.5 Mabswid
.65383 .05359 Mdot
.039 .916 .04 r
.5 Mabswid
.60058 .05157 m
.65361 .05258 L
s
0 0 0 r
2.5 Mabswid
.65361 .05258 Mdot
.039 .916 .04 r
.5 Mabswid
.60081 .05053 m
.65339 .05157 L
s
0 0 0 r
2.5 Mabswid
.65339 .05157 Mdot
.039 .916 .04 r
.5 Mabswid
.60105 .0495 m
.65316 .05055 L
s
0 0 0 r
2.5 Mabswid
.65316 .05055 Mdot
.039 .916 .04 r
.5 Mabswid
.65316 .14945 m
.97619 .10148 L
s
0 0 0 r
2.5 Mabswid
.97619 .10148 Mdot
.039 .916 .04 r
.5 Mabswid
.65339 .14843 m
.97619 .10165 L
s
0 0 0 r
2.5 Mabswid
.97619 .10165 Mdot
.039 .916 .04 r
.5 Mabswid
.65361 .14742 m
.97619 .10181 L
s
0 0 0 r
2.5 Mabswid
.97619 .10181 Mdot
.039 .916 .04 r
.5 Mabswid
.65383 .14641 m
.97619 .10195 L
s
0 0 0 r
2.5 Mabswid
.97619 .10195 Mdot
.039 .916 .04 r
.5 Mabswid
.65404 .14539 m
.97619 .10208 L
s
0 0 0 r
2.5 Mabswid
.97619 .10208 Mdot
.039 .916 .04 r
.5 Mabswid
.65425 .14439 m
.97619 .10219 L
s
0 0 0 r
2.5 Mabswid
.97619 .10219 Mdot
.039 .916 .04 r
.5 Mabswid
.65446 .14338 m
.97619 .1023 L
s
0 0 0 r
2.5 Mabswid
.97619 .1023 Mdot
.039 .916 .04 r
.5 Mabswid
.65465 .14237 m
.97619 .10239 L
s
0 0 0 r
2.5 Mabswid
.97619 .10239 Mdot
.039 .916 .04 r
.5 Mabswid
.65485 .14137 m
.97619 .10247 L
s
0 0 0 r
2.5 Mabswid
.97619 .10247 Mdot
.039 .916 .04 r
.5 Mabswid
.65503 .14037 m
.97619 .10254 L
s
0 0 0 r
2.5 Mabswid
.97619 .10254 Mdot
.039 .916 .04 r
.5 Mabswid
.65522 .13936 m
.97619 .1026 L
s
0 0 0 r
2.5 Mabswid
.97619 .1026 Mdot
.039 .916 .04 r
.5 Mabswid
.65539 .13836 m
.97619 .10265 L
s
0 0 0 r
2.5 Mabswid
.97619 .10265 Mdot
.039 .916 .04 r
.5 Mabswid
.65557 .13736 m
.97619 .10269 L
s
0 0 0 r
2.5 Mabswid
.97619 .10269 Mdot
.039 .916 .04 r
.5 Mabswid
.65573 .13637 m
.97619 .10272 L
s
0 0 0 r
2.5 Mabswid
.97619 .10272 Mdot
.039 .916 .04 r
.5 Mabswid
.6559 .13537 m
.97619 .10274 L
s
0 0 0 r
2.5 Mabswid
.97619 .10274 Mdot
.039 .916 .04 r
.5 Mabswid
.65606 .13438 m
.97619 .10276 L
s
0 0 0 r
2.5 Mabswid
.97619 .10276 Mdot
.039 .916 .04 r
.5 Mabswid
.65621 .13338 m
.97619 .10276 L
s
0 0 0 r
2.5 Mabswid
.97619 .10276 Mdot
.039 .916 .04 r
.5 Mabswid
.65636 .13239 m
.97619 .10276 L
s
0 0 0 r
2.5 Mabswid
.97619 .10276 Mdot
.039 .916 .04 r
.5 Mabswid
.6565 .1314 m
.97619 .10275 L
s
0 0 0 r
2.5 Mabswid
.97619 .10275 Mdot
.039 .916 .04 r
.5 Mabswid
.65664 .13041 m
.97619 .10274 L
s
0 0 0 r
2.5 Mabswid
.97619 .10274 Mdot
.039 .916 .04 r
.5 Mabswid
.65677 .12942 m
.97619 .10271 L
s
0 0 0 r
2.5 Mabswid
.97619 .10271 Mdot
.039 .916 .04 r
.5 Mabswid
.6569 .12843 m
.97619 .10268 L
s
0 0 0 r
2.5 Mabswid
.97619 .10268 Mdot
.039 .916 .04 r
.5 Mabswid
.65703 .12744 m
.97619 .10264 L
s
0 0 0 r
2.5 Mabswid
.97619 .10264 Mdot
.039 .916 .04 r
.5 Mabswid
.65715 .12645 m
.97619 .1026 L
s
0 0 0 r
2.5 Mabswid
.97619 .1026 Mdot
.039 .916 .04 r
.5 Mabswid
.65727 .12547 m
.97619 .10255 L
s
0 0 0 r
2.5 Mabswid
.97619 .10255 Mdot
.039 .916 .04 r
.5 Mabswid
.65738 .12448 m
.97619 .1025 L
s
0 0 0 r
2.5 Mabswid
.97619 .1025 Mdot
.039 .916 .04 r
.5 Mabswid
.65748 .12349 m
.97619 .10244 L
s
0 0 0 r
2.5 Mabswid
.97619 .10244 Mdot
.039 .916 .04 r
.5 Mabswid
.65759 .12251 m
.97619 .10237 L
s
0 0 0 r
2.5 Mabswid
.97619 .10237 Mdot
.039 .916 .04 r
.5 Mabswid
.65769 .12153 m
.97619 .1023 L
s
0 0 0 r
2.5 Mabswid
.97619 .1023 Mdot
.039 .916 .04 r
.5 Mabswid
.65778 .12054 m
.97619 .10223 L
s
0 0 0 r
2.5 Mabswid
.97619 .10223 Mdot
.039 .916 .04 r
.5 Mabswid
.65787 .11956 m
.97619 .10215 L
s
0 0 0 r
2.5 Mabswid
.97619 .10215 Mdot
.039 .916 .04 r
.5 Mabswid
.65795 .11858 m
.97619 .10207 L
s
0 0 0 r
2.5 Mabswid
.97619 .10207 Mdot
.039 .916 .04 r
.5 Mabswid
.65803 .1176 m
.97619 .10198 L
s
0 0 0 r
2.5 Mabswid
.97619 .10198 Mdot
.039 .916 .04 r
.5 Mabswid
.65811 .11662 m
.97619 .10189 L
s
0 0 0 r
2.5 Mabswid
.97619 .10189 Mdot
.039 .916 .04 r
.5 Mabswid
.65818 .11564 m
.97619 .1018 L
s
0 0 0 r
2.5 Mabswid
.97619 .1018 Mdot
.039 .916 .04 r
.5 Mabswid
.65825 .11466 m
.97619 .1017 L
s
0 0 0 r
2.5 Mabswid
.97619 .1017 Mdot
.039 .916 .04 r
.5 Mabswid
.65831 .11368 m
.97619 .1016 L
s
0 0 0 r
2.5 Mabswid
.97619 .1016 Mdot
.039 .916 .04 r
.5 Mabswid
.65837 .1127 m
.97619 .1015 L
s
0 0 0 r
2.5 Mabswid
.97619 .1015 Mdot
.039 .916 .04 r
.5 Mabswid
.65842 .11172 m
.97619 .10139 L
s
0 0 0 r
2.5 Mabswid
.97619 .10139 Mdot
.039 .916 .04 r
.5 Mabswid
.65847 .11074 m
.97619 .10128 L
s
0 0 0 r
2.5 Mabswid
.97619 .10128 Mdot
.039 .916 .04 r
.5 Mabswid
.65852 .10977 m
.97619 .10117 L
s
0 0 0 r
2.5 Mabswid
.97619 .10117 Mdot
.039 .916 .04 r
.5 Mabswid
.65856 .10879 m
.97619 .10106 L
s
0 0 0 r
2.5 Mabswid
.97619 .10106 Mdot
.039 .916 .04 r
.5 Mabswid
.65859 .10781 m
.97619 .10095 L
s
0 0 0 r
2.5 Mabswid
.97619 .10095 Mdot
.039 .916 .04 r
.5 Mabswid
.65863 .10684 m
.97619 .10083 L
s
0 0 0 r
2.5 Mabswid
.97619 .10083 Mdot
.039 .916 .04 r
.5 Mabswid
.65865 .10586 m
.97619 .10072 L
s
0 0 0 r
2.5 Mabswid
.97619 .10072 Mdot
.039 .916 .04 r
.5 Mabswid
.65868 .10488 m
.97619 .1006 L
s
0 0 0 r
2.5 Mabswid
.97619 .1006 Mdot
.039 .916 .04 r
.5 Mabswid
.6587 .10391 m
.97619 .10048 L
s
0 0 0 r
2.5 Mabswid
.97619 .10048 Mdot
.039 .916 .04 r
.5 Mabswid
.65871 .10293 m
.97619 .10036 L
s
0 0 0 r
2.5 Mabswid
.97619 .10036 Mdot
.039 .916 .04 r
.5 Mabswid
.65872 .10195 m
.97619 .10024 L
s
0 0 0 r
2.5 Mabswid
.97619 .10024 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .10098 m
.97619 .10012 L
s
0 0 0 r
2.5 Mabswid
.97619 .10012 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .1 m
.97619 .1 L
s
0 0 0 r
2.5 Mabswid
.97619 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .09902 m
.97619 .09988 L
s
0 0 0 r
2.5 Mabswid
.97619 .09988 Mdot
.039 .916 .04 r
.5 Mabswid
.65872 .09805 m
.97619 .09976 L
s
0 0 0 r
2.5 Mabswid
.97619 .09976 Mdot
.039 .916 .04 r
.5 Mabswid
.65871 .09707 m
.97619 .09964 L
s
0 0 0 r
2.5 Mabswid
.97619 .09964 Mdot
.039 .916 .04 r
.5 Mabswid
.6587 .09609 m
.97619 .09952 L
s
0 0 0 r
2.5 Mabswid
.97619 .09952 Mdot
.039 .916 .04 r
.5 Mabswid
.65868 .09512 m
.97619 .0994 L
s
0 0 0 r
2.5 Mabswid
.97619 .0994 Mdot
.039 .916 .04 r
.5 Mabswid
.65865 .09414 m
.97619 .09928 L
s
0 0 0 r
2.5 Mabswid
.97619 .09928 Mdot
.039 .916 .04 r
.5 Mabswid
.65863 .09316 m
.97619 .09917 L
s
0 0 0 r
2.5 Mabswid
.97619 .09917 Mdot
.039 .916 .04 r
.5 Mabswid
.65859 .09219 m
.97619 .09905 L
s
0 0 0 r
2.5 Mabswid
.97619 .09905 Mdot
.039 .916 .04 r
.5 Mabswid
.65856 .09121 m
.97619 .09894 L
s
0 0 0 r
2.5 Mabswid
.97619 .09894 Mdot
.039 .916 .04 r
.5 Mabswid
.65852 .09023 m
.97619 .09883 L
s
0 0 0 r
2.5 Mabswid
.97619 .09883 Mdot
.039 .916 .04 r
.5 Mabswid
.65847 .08926 m
.97619 .09872 L
s
0 0 0 r
2.5 Mabswid
.97619 .09872 Mdot
.039 .916 .04 r
.5 Mabswid
.65842 .08828 m
.97619 .09861 L
s
0 0 0 r
2.5 Mabswid
.97619 .09861 Mdot
.039 .916 .04 r
.5 Mabswid
.65837 .0873 m
.97619 .0985 L
s
0 0 0 r
2.5 Mabswid
.97619 .0985 Mdot
.039 .916 .04 r
.5 Mabswid
.65831 .08632 m
.97619 .0984 L
s
0 0 0 r
2.5 Mabswid
.97619 .0984 Mdot
.039 .916 .04 r
.5 Mabswid
.65825 .08534 m
.97619 .0983 L
s
0 0 0 r
2.5 Mabswid
.97619 .0983 Mdot
.039 .916 .04 r
.5 Mabswid
.65818 .08436 m
.97619 .0982 L
s
0 0 0 r
2.5 Mabswid
.97619 .0982 Mdot
.039 .916 .04 r
.5 Mabswid
.65811 .08338 m
.97619 .09811 L
s
0 0 0 r
2.5 Mabswid
.97619 .09811 Mdot
.039 .916 .04 r
.5 Mabswid
.65803 .0824 m
.97619 .09802 L
s
0 0 0 r
2.5 Mabswid
.97619 .09802 Mdot
.039 .916 .04 r
.5 Mabswid
.65795 .08142 m
.97619 .09793 L
s
0 0 0 r
2.5 Mabswid
.97619 .09793 Mdot
.039 .916 .04 r
.5 Mabswid
.65787 .08044 m
.97619 .09785 L
s
0 0 0 r
2.5 Mabswid
.97619 .09785 Mdot
.039 .916 .04 r
.5 Mabswid
.65778 .07946 m
.97619 .09777 L
s
0 0 0 r
2.5 Mabswid
.97619 .09777 Mdot
.039 .916 .04 r
.5 Mabswid
.65769 .07847 m
.97619 .0977 L
s
0 0 0 r
2.5 Mabswid
.97619 .0977 Mdot
.039 .916 .04 r
.5 Mabswid
.65759 .07749 m
.97619 .09763 L
s
0 0 0 r
2.5 Mabswid
.97619 .09763 Mdot
.039 .916 .04 r
.5 Mabswid
.65748 .07651 m
.97619 .09756 L
s
0 0 0 r
2.5 Mabswid
.97619 .09756 Mdot
.039 .916 .04 r
.5 Mabswid
.65738 .07552 m
.97619 .0975 L
s
0 0 0 r
2.5 Mabswid
.97619 .0975 Mdot
.039 .916 .04 r
.5 Mabswid
.65727 .07453 m
.97619 .09745 L
s
0 0 0 r
2.5 Mabswid
.97619 .09745 Mdot
.039 .916 .04 r
.5 Mabswid
.65715 .07355 m
.97619 .0974 L
s
0 0 0 r
2.5 Mabswid
.97619 .0974 Mdot
.039 .916 .04 r
.5 Mabswid
.65703 .07256 m
.97619 .09736 L
s
0 0 0 r
2.5 Mabswid
.97619 .09736 Mdot
.039 .916 .04 r
.5 Mabswid
.6569 .07157 m
.97619 .09732 L
s
0 0 0 r
2.5 Mabswid
.97619 .09732 Mdot
.039 .916 .04 r
.5 Mabswid
.65677 .07058 m
.97619 .09729 L
s
0 0 0 r
2.5 Mabswid
.97619 .09729 Mdot
.039 .916 .04 r
.5 Mabswid
.65664 .06959 m
.97619 .09726 L
s
0 0 0 r
2.5 Mabswid
.97619 .09726 Mdot
.039 .916 .04 r
.5 Mabswid
.6565 .0686 m
.97619 .09725 L
s
0 0 0 r
2.5 Mabswid
.97619 .09725 Mdot
.039 .916 .04 r
.5 Mabswid
.65636 .06761 m
.97619 .09724 L
s
0 0 0 r
2.5 Mabswid
.97619 .09724 Mdot
.039 .916 .04 r
.5 Mabswid
.65621 .06662 m
.97619 .09724 L
s
0 0 0 r
2.5 Mabswid
.97619 .09724 Mdot
.039 .916 .04 r
.5 Mabswid
.65606 .06562 m
.97619 .09724 L
s
0 0 0 r
2.5 Mabswid
.97619 .09724 Mdot
.039 .916 .04 r
.5 Mabswid
.6559 .06463 m
.97619 .09726 L
s
0 0 0 r
2.5 Mabswid
.97619 .09726 Mdot
.039 .916 .04 r
.5 Mabswid
.65573 .06363 m
.97619 .09728 L
s
0 0 0 r
2.5 Mabswid
.97619 .09728 Mdot
.039 .916 .04 r
.5 Mabswid
.65557 .06264 m
.97619 .09731 L
s
0 0 0 r
2.5 Mabswid
.97619 .09731 Mdot
.039 .916 .04 r
.5 Mabswid
.65539 .06164 m
.97619 .09735 L
s
0 0 0 r
2.5 Mabswid
.97619 .09735 Mdot
.039 .916 .04 r
.5 Mabswid
.65522 .06064 m
.97619 .0974 L
s
0 0 0 r
2.5 Mabswid
.97619 .0974 Mdot
.039 .916 .04 r
.5 Mabswid
.65503 .05963 m
.97619 .09746 L
s
0 0 0 r
2.5 Mabswid
.97619 .09746 Mdot
.039 .916 .04 r
.5 Mabswid
.65485 .05863 m
.97619 .09753 L
s
0 0 0 r
2.5 Mabswid
.97619 .09753 Mdot
.039 .916 .04 r
.5 Mabswid
.65465 .05763 m
.97619 .09761 L
s
0 0 0 r
2.5 Mabswid
.97619 .09761 Mdot
.039 .916 .04 r
.5 Mabswid
.65446 .05662 m
.97619 .0977 L
s
0 0 0 r
2.5 Mabswid
.97619 .0977 Mdot
.039 .916 .04 r
.5 Mabswid
.65425 .05561 m
.97619 .09781 L
s
0 0 0 r
2.5 Mabswid
.97619 .09781 Mdot
.039 .916 .04 r
.5 Mabswid
.65404 .05461 m
.97619 .09792 L
s
0 0 0 r
2.5 Mabswid
.97619 .09792 Mdot
.039 .916 .04 r
.5 Mabswid
.65383 .05359 m
.97619 .09805 L
s
0 0 0 r
2.5 Mabswid
.97619 .09805 Mdot
.039 .916 .04 r
.5 Mabswid
.65361 .05258 m
.97619 .09819 L
s
0 0 0 r
2.5 Mabswid
.97619 .09819 Mdot
.039 .916 .04 r
.5 Mabswid
.65339 .05157 m
.97619 .09835 L
s
0 0 0 r
2.5 Mabswid
.97619 .09835 Mdot
.039 .916 .04 r
.5 Mabswid
.65316 .05055 m
.97619 .09852 L
s
0 0 0 r
2.5 Mabswid
.97619 .09852 Mdot
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 57.5625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000>B000`400?l00000o`00003ooooooolQ
ooooo`00/?ooool7o`0005oooooo00?o0000ooooooooool01oooool00;3ooooo1ol0001Oooooo`03
o`000?oooooooooo00Oooooo002_ooooo`;o00001OmoOgl2o`0005kooooo00?o0000ooooooooool0
1oooool00:oooooo0_l00005ogmoO`;o0000G_ooool00ol0003oooooooooo`07ooooo`00[oooool9
o`0005kooooo00?o0000ooooooooool01oooool00:kooooo00?o0000ogmoOol000001OmoOgl00ol0
003oOgmoo`00001Mooooo`03o`000?oooooooooo00Oooooo002^ooooo`03o`000?moOgoo000000Go
Ogmo00?o0000ogmoOol00000GOooool00ol0003oooooooooo`07ooooo`00[_ooool00ol0003oOgmo
o`000005ogmoO`03o`000?moOgoo000005gooooo00?o0000ooooooooool01oooool00:gooooo00?o
0000ogmoOomoOgl01ol00002ogmoO`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01ooo
ool00:gooooo00Co0000ogmoOomoOgoo00001OmoOgl01?l0003oOgmoogmoOol0001Looooo`03o`00
0?oooooooooo00Oooooo002]ooooo`04o`000?moOgooOgmoo`0000GoOgmo00Co0000ogmoOomoOgoo
0000G?ooool00ol0003oooooooooo`07ooooo`00[Oooool01?l0003oOgmoogmoOol00005ogmoO`04
o`000?moOgooOgmoo`0005cooooo00?o0000ooooooooool01oooool00:cooooo00Go0000ogmoOomo
OgooOgmoo`000005ogmoO`05o`000?moOgooOgmoogmoOol00000Foooool00ol0003oooooooooo`07
ooooo`00Y_ooool5o`WZ2P03o`000?l9jP[o2NX:013o2NX:F?ooool00ol0003oooooooooo`07oooo
o`00V_ooool[o`WZ2U7ooooo00?o0000ooooooooool01oooool008oooooo6ol9jPX00ol0003o2NX:
o`WZ2P0=o`WZ2P03o`000?l9jP[o2NX:00ko2NX:Boooool00ol0003oooooooooo`07ooooo`00Pooo
oolWo`WZ2P03o`000?l9jP[o2NX:00go2NX:00?o0000o`WZ2_l9jPX05Ol9jPY4ooooo`03o`000?oo
oooooooo00Oooooo001goooooc?o2NX:00?o0000o`WZ2_l9jPX03Ol9jPX00ol0003o2NX:o`WZ2P0L
o`WZ2Sgooooo00?o0000ooooooooool01oooool006cooooo?_l9jPX00ol0003o2NX:o`WZ2P0=o`WZ
2P03o`000?l9jP[o2NX:02;o2NX:=oooool00ol0003oooooooooo`07ooooo`00H?oooomJo`WZ2P03
o`000?l9jP[o2NX:02Wo2NX:<?ooool00ol0003oooooooooo`07ooooo`00E?oooonHo`WZ2R[ooooo
00?o0000ooooooooool01oooool004SoooooLol9jPX00ol0003o2NX:o`WZ2P0eo`WZ2R?ooooo00?o
0000ooooooooool01oooool003goooooK?l9jPX00ol0003o2NX:o`WZ2P0?o`WZ2P03o`000?l9jP[o
2NX:03_o2NX:7Oooool00ol0003oooooooooo`07ooooo`00<Ooooomho`WZ2P03o`000?l9jP[o2NX:
00oo2NX:00?o0000o`WZ2_l9jPX0@_l9jPXFooooo`03o`000?oooooooooo00Oooooo000UooooohCo
2NX:00?o0000o`WZ2_l9jPX03ol9jPX00ol0003o2NX:o`WZ2P1;o`WZ2Pgooooo00?o0000oooooooo
ool01oooool001[oooooSol9jPX00ol0003o2NX:o`WZ2P0?o`WZ2P03o`000?l9jP[o2NX:05Co2NX:
1?ooool00ol0003oooooooooo`07ooooo`003_oooonKo`WZ2P03o`000?l9jP[o2NX:00oo2NX:00?o
0000o`WZ2_l9jPX0Eol9jPX2o`0000Wooooo0008oooooj7o2NX:00?o0000o`WZ2_l9jPX03ol9jPX0
0ol0003o2NX:o`WZ2P1Go`WZ2P;o00002Oooool000ooooooV_l9jPX00ol0003o2NX:o`WZ2P0?o`WZ
2P03o`000?l9jP[o2NX:05Oo2NX:0_l00009ooooo`006_oooon?o`WZ2P03o`000?l9jP[o2NX:00oo
2NX:00?o0000o`WZ2_l9jPX0E?l9jPX3ooooo`;o00002Oooool002KoooooPol9jPX00ol0003o2NX:
o`WZ2P0?o`WZ2P03o`000?l9jP[o2NX:04go2NX:2oooool00ol0003oooooooooo`07ooooo`00<_oo
oomgo`WZ2P03o`000?l9jP[o2NX:00oo2NX:00?o0000o`WZ2_l9jPX0A_l9jPXBooooo`03o`000?oo
oooooooo00Oooooo000mooooofco2NX:00?o0000o`WZ2_l9jPX03ol9jPX00ol0003o2NX:o`WZ2P0o
o`WZ2QWooooo00?o0000ooooooooool01oooool004WoooooH?l9jPX00ol0003o2NX:o`WZ2P0?o`WZ
2P03o`000?l9jP[o2NX:03So2NX:8?ooool00ol0003oooooooooo`07ooooo`00EOoooomDo`WZ2P03
o`000?l9jP[o2NX:04?o2NX:9oooool00ol0003oooooooooo`07ooooo`00H?oooon8o`WZ2Rkooooo
00?o0000ooooooooool01oooool006cooooo?_l9jPX00ol0003o2NX:o`WZ2P0do`WZ2SGooooo00?o
0000ooooooooool01oooool007Sooooo<_l9jPX00ol0003o2NX:o`WZ2P0=o`WZ2P03o`000?l9jP[o
2NX:01go2NX:??ooool00ol0003oooooooooo`07ooooo`00PooooolWo`WZ2P03o`000?l9jP[o2NX:
00go2NX:00?o0000o`WZ2_l9jPX05_l9jPY3ooooo`03o`000?oooooooooo00Oooooo002?oooooa_o
2NX:00?o0000o`WZ2_l9jPX03Ol9jPX00ol0003o2NX:o`WZ2P0?o`WZ2T[ooooo00?o0000oooooooo
ool01oooool009_ooooo3ol9jPX00ol0003o2NX:o`WZ2P0=o`WZ2P03o`000?l9jP[o2NX:00So2NX:
DOooool00ol0003oooooooooo`07ooooo`00Y_oooolHo`WZ2USooooo00?o0000ooooooooool01ooo
ool00:_ooooo0_l00003ogmoO`03o`000?moOgooOgmo00?oOgmo00Co0000ogmoOomoOgooOgmo0_l0
001Jooooo`03o`000?oooooooooo00Oooooo002/ooooo`05o`000?moOgooOgmoogmoOol000001Omo
Ogl01Ol0003oOgmoogmoOomoOgoo000005_ooooo00?o0000ooooooooool01oooool00:gooooo00Co
0000ogmoOomoOgoo00001OmoOgl01?l0003oOgmoogmoOol0001Looooo`03o`000?oooooooooo00Oo
oooo002]ooooo`04o`000?moOgooOgmoo`0000GoOgmo00Co0000ogmoOomoOgoo0000G?ooool00ol0
003oooooooooo`07ooooo`00[Oooool00ol0003oOgmoogmoO`07o`0000;oOgmo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`07ooooo`00[_ooool00ol0003oOgmoo`000005ogmoO`03o`00
0?moOgoo000005gooooo00?o0000ooooooooool01oooool00:kooooo00?o0000ogmoOol000001Omo
Ogl00ol0003oOgmoo`00001Mooooo`03o`000?oooooooooo00Oooooo002^ooooo`03o`000?moOgoo
000000GoOgmo00?o0000ogmoOol00000GOooool00ol0003oooooooooo`07ooooo`00[oooool2o`00
00GoOgmo0_l0001Nooooo`03o`000?oooooooooo00Oooooo002_ooooo`Wo0000G_ooool00ol0003o
ooooooooo`07ooooo`00[oooool2o`0000GoOgmo0_l0001Nooooo`03o`000?oooooooooo00Oooooo
002`ooooo`Oo0000Goooool00ol0003oooooooooo`07ooooo`00/?ooool7o`0005oooooo00?o0000
ooooooooool01oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {56.5625, 0}} -> {-94.9167, -15.7501, \
0.556911, 0.556911}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "Next we use ",
  StyleBox["SymbolicTrace", "Input"],
  " to determine the fifth order solution to the symbolic optical path length \
of the system as function of lens curvatures, ",
  StyleBox["c1", "Input"],
  " and ",
  StyleBox["c2", "Input"],
  ", and input ray angle, ",
  StyleBox["\[Theta]", "Input"],
  "."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{

Cell["\<\
OL = SymbolicOpticalLength/.SymbolicTrace[opticalsystem, {{\[Theta],0,5}, \
{c1>0,c2<0,\[Theta]\[Element]Reals}}, \
ReportedParameters->SymbolicOpticalLength, MakeFloatingPoint->False]\
\>", "Input",
  CellLabel->"In[69]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[BoxData[
    \(155 + 
      5\/9\ \((132 + 8555\ c2 + 105125\ c2\^2 + 
            2025\ c1\^2\ \((51 + 320\ c2 + 500\ c2\^2)\) - 
            45\ c1\ \((183 + 5230\ c2 + 14500\ c2\^2)\))\)\ \[Theta]\^2 + 
      25\/324\ \((378 + 70972\ c2 + 7447490\ c2\^2 + 524363500\ c2\^3 + 
            11935366875\ c2\^4 + 
            820125\ c1\^4\ \((6183 + 53000\ c2 + 243400\ c2\^2 + 
                  860000\ c2\^3 + 1350000\ c2\^4)\) - 
            72900\ c1\^3\ \((1584 + 165425\ c2 + 1715950\ c2\^2 + 
                  9567500\ c2\^3 + 19575000\ c2\^4)\) + 
            2430\ c1\^2\ \((\(-57\) + 115240\ c2 + 8920575\ c2\^2 + 
                  96642500\ c2\^3 + 283837500\ c2\^4)\) - 
            36\ c1\ \((1989 + 207815\ c2 + 19394875\ c2\^2 + 
                  791065625\ c2\^3 + 
                  4115643750\ c2\^4)\))\)\ \[Theta]\^4\)], "Output",
  CellLabel->"Out[69]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell["\<\
Here is a plot of the symbolic optical path length as a function of ray \
angle. This uses the default initial settings of lens curvature.\
\>", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{

Cell["\<\
oplot = Plot[OL/.{c1->1/35,c2->-1/35},{\[Theta],-3. Degree, 3. Degree}];\
\>", "Input",
  CellLabel->"In[70]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 9.09457 -6057.42 39.084 [
[.13622 .59082 -15 -9 ]
[.13622 .59082 15 0 ]
[.31811 .59082 -15 -9 ]
[.31811 .59082 15 0 ]
[.68189 .59082 -12 -9 ]
[.68189 .59082 12 0 ]
[.86378 .59082 -12 -9 ]
[.86378 .59082 12 0 ]
[.4875 .05614 -42 -4.5 ]
[.4875 .05614 0 4.5 ]
[.4875 .13431 -42 -4.5 ]
[.4875 .13431 0 4.5 ]
[.4875 .21248 -36 -4.5 ]
[.4875 .21248 0 4.5 ]
[.4875 .29065 -42 -4.5 ]
[.4875 .29065 0 4.5 ]
[.4875 .36882 -42 -4.5 ]
[.4875 .36882 0 4.5 ]
[.4875 .44698 -42 -4.5 ]
[.4875 .44698 0 4.5 ]
[.4875 .52515 -42 -4.5 ]
[.4875 .52515 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13622 .60332 m
.13622 .60957 L
s
[(-0.04)] .13622 .59082 0 1 Mshowa
.31811 .60332 m
.31811 .60957 L
s
[(-0.02)] .31811 .59082 0 1 Mshowa
.68189 .60332 m
.68189 .60957 L
s
[(0.02)] .68189 .59082 0 1 Mshowa
.86378 .60332 m
.86378 .60957 L
s
[(0.04)] .86378 .59082 0 1 Mshowa
.125 Mabswid
.18169 .60332 m
.18169 .60707 L
s
.22716 .60332 m
.22716 .60707 L
s
.27264 .60332 m
.27264 .60707 L
s
.36358 .60332 m
.36358 .60707 L
s
.40905 .60332 m
.40905 .60707 L
s
.45453 .60332 m
.45453 .60707 L
s
.54547 .60332 m
.54547 .60707 L
s
.59095 .60332 m
.59095 .60707 L
s
.63642 .60332 m
.63642 .60707 L
s
.72736 .60332 m
.72736 .60707 L
s
.77284 .60332 m
.77284 .60707 L
s
.81831 .60332 m
.81831 .60707 L
s
.09074 .60332 m
.09074 .60707 L
s
.04527 .60332 m
.04527 .60707 L
s
.90926 .60332 m
.90926 .60707 L
s
.95473 .60332 m
.95473 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.5 .05614 m
.50625 .05614 L
s
[(154.986)] .4875 .05614 1 0 Mshowa
.5 .13431 m
.50625 .13431 L
s
[(154.988)] .4875 .13431 1 0 Mshowa
.5 .21248 m
.50625 .21248 L
s
[(154.99)] .4875 .21248 1 0 Mshowa
.5 .29065 m
.50625 .29065 L
s
[(154.992)] .4875 .29065 1 0 Mshowa
.5 .36882 m
.50625 .36882 L
s
[(154.994)] .4875 .36882 1 0 Mshowa
.5 .44698 m
.50625 .44698 L
s
[(154.996)] .4875 .44698 1 0 Mshowa
.5 .52515 m
.50625 .52515 L
s
[(154.998)] .4875 .52515 1 0 Mshowa
.125 Mabswid
.5 .07569 m
.50375 .07569 L
s
.5 .09523 m
.50375 .09523 L
s
.5 .11477 m
.50375 .11477 L
s
.5 .15385 m
.50375 .15385 L
s
.5 .1734 m
.50375 .1734 L
s
.5 .19294 m
.50375 .19294 L
s
.5 .23202 m
.50375 .23202 L
s
.5 .25156 m
.50375 .25156 L
s
.5 .27111 m
.50375 .27111 L
s
.5 .31019 m
.50375 .31019 L
s
.5 .32973 m
.50375 .32973 L
s
.5 .34927 m
.50375 .34927 L
s
.5 .38836 m
.50375 .38836 L
s
.5 .4079 m
.50375 .4079 L
s
.5 .42744 m
.50375 .42744 L
s
.5 .46653 m
.50375 .46653 L
s
.5 .48607 m
.50375 .48607 L
s
.5 .50561 m
.50375 .50561 L
s
.5 .54469 m
.50375 .54469 L
s
.5 .56424 m
.50375 .56424 L
s
.5 .58378 m
.50375 .58378 L
s
.5 .0366 m
.50375 .0366 L
s
.5 .01706 m
.50375 .01706 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .06536 L
.10458 .13069 L
.14415 .19772 L
.18221 .26413 L
.22272 .33385 L
.26171 .39739 L
.30316 .45855 L
.34309 .50922 L
.3815 .54875 L
.40095 .56494 L
.42237 .57961 L
.44268 .59034 L
.45178 .59412 L
.46172 .59751 L
.4671 .59903 L
.4721 .60023 L
.47727 .60127 L
.48196 .60203 L
.48658 .6026 L
.4887 .60281 L
.49093 .60299 L
.49332 .60314 L
.49438 .60319 L
.49552 .60324 L
.49675 .60328 L
.49789 .6033 L
.49859 .60331 L
.49925 .60332 L
.50049 .60332 L
.50163 .60331 L
.50286 .60329 L
.50401 .60326 L
.50508 .60322 L
.50754 .60309 L
.51014 .60291 L
.51268 .60268 L
.51504 .60242 L
.5204 .60167 L
.5293 .59991 L
.53882 .59735 L
.54906 .5938 L
.56016 .58902 L
.58032 .57796 L
.62123 .54626 L
.66064 .50489 L
.69852 .45623 L
.73886 .39649 L
.77769 .33317 L
.81897 .26208 L
Mistroke
.85873 .19274 L
.89697 .12815 L
.93767 .06519 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oSoooool0
0ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003o
ooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`001oooool00ol0003ooooooooo
o`25ooooo`;o0000Q_ooool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`25
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000oooo
ooooool0Q?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00Oooooo0009ooooo`03
o`000?oooooooooo08?ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`08ooooo`00
2_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
2Oooool000_ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo00[ooooo000;ooooo`03o`000?oooooooooo087ooooo0_l00022ooooo`03o`000?oooooo
oooo00[ooooo000<ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0P?ooool00ol0
003oooooooooo`0;ooooo`003Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0DOooool3o`0000?ooooo
0ol00004ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`;o00001?ooool3o`0000?ooooo
0ol00006ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool03Oooool000kooooo00?o
0000ooooooooool0D_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool0
00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool03Oooool000oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooo000000Co00002oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00kooooo
000@ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo00Oooooo1?l00002ooooo`?o00000_ooool4o`0000Kooooo0ol0
001looooo`03o`000?oooooooooo00oooooo000Aooooo`03o`000?oooooooooo04oooooo00Co0000
oooooooooooooooo1?l00003ooooo`03o`000?oooooo000000Sooooo00Oo0000oooooooooooooooo
o`000?oooooo000000?ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo013ooooo000Booooo`03o`000?oooooooooo04gooooo0_l00003ooooo`03o`00
0?oooooooooo00Gooooo0_l00008ooooo`07o`000?ooooooooooooooool0003oooooo`000003oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0A
ooooo`004_ooool00ol0003oooooooooo`1>ooooo`04o`000?ooooooooooooooo`Go00001?ooool0
0ol0003oooooooooo`07ooooo`?o00000oooool3o`0000Cooooo0_l00006ooooo`03o`000?oooooo
oooo07[ooooo00?o0000ooooooooool04Oooool001?ooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`1iooooo`03o`000?oooooooooo01;ooooo000Dooooo`03o`000?oooooooooo07So
oooo0_l0001iooooo`03o`000?oooooooooo01?ooooo000Dooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Cooooo`005Oooool00ol0003ooooooooo
o`1gooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool05?ooool001Gooooo00?o0000
ooooooooool0Moooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo01Cooooo000Foooo
o`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eoooo
o`005oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo07Gooooo00?o0000oooooooo
ool05_ooool001Oooooo00?o0000ooooooooool0MOooool2o`0007Kooooo00?o0000ooooooooool0
5_ooool001Sooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo01Oooooo000Iooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooooooo`0Gooooo`006Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool06?ooool001[ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo01Wooooo000Kooooo`03o`000?oooooooooo077ooooo
0_l0001cooooo`03o`000?oooooooooo01Wooooo000Kooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`0Jooooo`007?ooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool06_ooool001cooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01_ooooo000Mooooo`03
o`000?oooooooooo04;ooooo0ol00003ooooo`?o00001?ooool3o`0000?ooooo00?o0000oooooooo
ool00_ooool2o`0000Cooooo0ol00003ooooo`?o00001_ooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo04;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1_ooooo`03o`000?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooo`000004o`0000_ooooo00?o0000ooooool0
00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo0ol0001^ooooo`03
o`000?oooooooooo01gooooo000Oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Oooooo1?l00002ooooo`?o0000
0oooool3o`0000Kooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Mooooo`007ooo
ool00ol0003oooooooooo`11ooooo`04o`000?ooooooooooooooo`Co00000oooool00ol0003ooooo
o`000008ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo0000
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
01kooooo000Pooooo`03o`000?oooooooooo03oooooo0_l00003ooooo`03o`000?oooooooooo00Go
oooo0_l00008ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo01oooooo000Qooooo`03o`000?oooooooooo03oooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`?o00000oooool3o`0000Kooooo00?o0000
ooooooooool0K?ooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`1[oooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool08?ooool002;ooooo00?o0000oooooooo
ool0J_ooool2o`0006cooooo00?o0000ooooooooool08?ooool002;ooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo027ooooo000Sooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Rooooo`009?ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool08_ooool0
02Cooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
02?ooooo000Uooooo`03o`000?oooooooooo06Oooooo0_l0001Yooooo`03o`000?oooooooooo02?o
oooo000Uooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`0Tooooo`009_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool09?ooool002Kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1V
ooooo`03o`000?oooooooooo02Gooooo000Wooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0Vooooo`00:?ooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool09_ooool002Sooooo00?o0000ooooooooool0
I?ooool2o`0006Gooooo00?o0000ooooooooool09oooool002Wooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Oooooo000Yooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Xooooo`00:_ooool00ol0
003oooooooooo`0kooooo`?o00000oooool3o`0000Cooooo0ol00003ooooo`03o`000?oooooooooo
00;ooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
02Wooooo000Zooooo`03o`000?oooooooooo03cooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Yoooo
o`00:oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool0
00001?l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool3o`00067o
oooo00?o0000ooooooooool0:_ooool002cooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01oooool4o`0000;ooooo
1?l00005ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0:_ooool002cooooo00?o
0000ooooooooool0>_ooool01?l0003oooooooooooooool4o`0000?ooooo00?o0000ooooool00000
2?ooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0:oooool002gooooo00?o0000oooooooo
ool0>?ooool2o`0000?ooooo00?o0000ooooooooool01Oooool2o`0000Sooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo02cooooo000]ooooo`03o`000?oooooooooo03Wooooo00Co0000oooo
oooooooooooo1Ol00004ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`?o00001_ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02cooooo000^ooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0]ooooo`00;oooool00ol0003o
ooooooooo`1Mooooo`;o0000Goooool00ol0003oooooooooo`0]ooooo`00;oooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0;_ooool0033ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02oooooo000`
ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0_
ooooo`00<Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool0<?ooool0037ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo033ooooo000booooo`03o`000?oooooooooo05[ooooo0_l0001Kooooo`03o`00
0?oooooooooo037ooooo000cooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`0booooo`00<oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool0<_ooool003Cooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo03?ooooo000dooooo`03o`000?oooooooooo05So
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0cooooo`00=Oooool00ol0003ooooo
ooooo`1Gooooo`;o0000F?ooool00ol0003oooooooooo`0dooooo`00=_ooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0=?ooool003Kooooo00?o0000
ooooooooool0E_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo03Gooooo000goooo
o`03o`000?oooooooooo02Sooooo0ol00003ooooo`?o00001?ooool3o`0000?ooooo00?o0000oooo
ooooool00_ooool2o`0000Cooooo0_l00003ooooo`Go00001Oooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo03Gooooo000gooooo`03o`000?oooooooooo02Wooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0=_ooool003Sooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Co00002oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo03Oooooo000iooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Oooooo1?l00002oooo
o`Co00001?ooool00ol0003oooooooooo`04ooooo`?o0000E?ooool00ol0003oooooooooo`0goooo
o`00>Oooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooooooo`Co00000oooool00ol0
003oooooo`000008ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`000?oo
oooooooo03Sooooo000jooooo`03o`000?oooooooooo02Gooooo0_l00003ooooo`03o`000?oooooo
oooo00Gooooo0_l00008ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo03Sooooo000jooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooooooo
1Ol00004ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`?o00000oooool3o`0000Kooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0iooooo`00>oooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0>Oooool003cooooo00?o0000
ooooooooool0D?ooool2o`0005;ooooo00?o0000ooooooooool0>_ooool003cooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo03[ooooo000mooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0kooooo`00
?Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0
??ooool003kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo03cooooo000oooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0mooooo`00?oooool00ol0003oooooooooo`1=ooooo`;o0000Coooool00ol0
003oooooooooo`0mooooo`00@?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool0?_ooool0043ooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo03kooooo0011ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`0oooooo`00@_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0@?ooool004;ooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo043ooooo0013ooooo`03
o`000?oooooooooo04Wooooo0_l0001;ooooo`03o`000?oooooooooo047ooooo0013ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00A?oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_oo
ool004Gooooo00?o0000ooooooooool06_ooool3o`0000?ooooo0ol00004ooooo`?o00000oooool0
0ol0003oooooooooo`02ooooo`;o00001?ooool2o`0000Gooooo0ol00005ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool0@oooool004Gooooo00?o0000ooooooooool06oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0A?ooool004Kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Co00002oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Co00001Oooool3o`0004Oooooo00?o0000oooo
ooooool0A?ooool004Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool01oooool4o`0000;ooooo1?l000001Ooooooo
0000oooooooooooo000000Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15oooo
o`00Aoooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooooooo`Co00000oooool00ol0
003oooooo`000008ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`06o`000?oo
ooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Ko
oooo0018ooooo`03o`000?oooooooooo01Oooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo
0_l00008ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`04o`000?oooooooooo
ooooo`;o00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Kooooo0018oooo
o`03o`000?oooooooooo01Sooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooo
oooo00Oooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool0Aoooool004Wooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo04Sooooo0019ooooo`03o`000?oooooooooo04?o
oooo0_l00014ooooo`03o`000?oooooooooo04Sooooo001:ooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`19ooooo`00Boooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0B_ooool004_ooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04[ooooo001<oooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1;oooo
o`00COooool00ol0003oooooooooo`0oooooo`;o0000@?ooool00ol0003oooooooooo`1<ooooo`00
COooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
C?ooool004kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo04gooooo001?ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`1>ooooo`00Coooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool0C_ooool0053ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo04oooooo001Aooooo`03o`000?oooooooooo03_ooooo
0_l0000looooo`03o`000?oooooooooo053ooooo001Aooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`1@ooooo`00D_ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0DOooool005?ooooo00?o0000oooo
ooooool03?ooool3o`0000?ooooo0ol00004ooooo`?o00000oooool00ol0003oooooooooo`02oooo
o`;o00001?ooool2o`0000Cooooo0ol00006ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0DOooool005?ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0D_ooool005Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooo000000Co00002oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo05?ooooo001Eooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Oooooo1?l00002ooooo`Co
000000?oooooo`000?l000000_l00006ooooo`?o0000>?ooool00ol0003oooooooooo`1Cooooo`00
EOooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooooooo`Co00000oooool00ol0003o
ooooo`000008ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
000000Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Dooooo`00E_ooool00ol0
003oooooooooo`09ooooo`;o00000oooool00ol0003oooooooooo`05ooooo`;o00002?ooool01ol0
003ooooooooooooooooo0000ooooool000000oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0EOooool005Oooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool01oooool3o`0000?ooooo
0ol00004ooooo`;o00001_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo05Gooooo
001Gooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`1Fooooo`00F?ooool00ol0003oooooooooo`0dooooo`;o0000=Oooool00ol0003oooooooooo`1G
ooooo`00FOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0F?ooool005[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo05Wooooo001Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`1Iooooo`00Foooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0F_ooool005cooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05_ooooo001Mooooo`03o`000?oooooooooo
02oooooo0_l0000`ooooo`03o`000?oooooooooo05cooooo001Nooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Looooo`00G_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0GOooool005oooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05kooooo001P
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1O
ooooo`00HOooool00ol0003oooooooooo`0[ooooo`;o0000;?ooool00ol0003oooooooooo`1Poooo
o`00H_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0H?ooool006;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo067ooooo001Rooooo`?o00000oooool3o`0000Cooooo0ol00003ooooo`03o`000?oo
oooooooo00;ooooo0_l00004ooooo`;o00001?ooool3o`0000Kooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`1Rooooo`00Hoooool2o`0000;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1Sooooo`00Hoooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Co00002ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06Cooooo001Sooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`07ooooo`Co00000_oo
ool4o`0000;ooooo0ol00006ooooo`?o00009_ooool00ol0003oooooooooo`1Uooooo`00Hoooool0
1?l0003oooooooooooooool4o`0000?ooooo00?o0000ooooool000002?ooool01ol0003ooooooooo
oooooooo0000ooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Vooooo`00H_ooool2o`0000?ooooo
0_l00006ooooo`;o00002?ooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1Wooooo`00Hoooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000oooo
ooooool01oooool3o`0000?ooooo0ol00003ooooo`?o00001_ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo06Sooooo001Zooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1Yooooo`00Joooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0J_ooool006cooooo00?o0000ooooooooool08?oo
ool2o`00023ooooo0_l0001]ooooo`00KOooool2o`00023ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1]ooooo`00Koooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0K_ooool0073ooooo0_l0000Mooooo`03o`000?oooooooooo01_o
oooo0_l0001aooooo`00L_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0LOooool0023ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`?o00007oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol0
000:ooooo`;o00006_ooool2o`0001[ooooo00?o0000ooooooooool02oooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000;ooooo1Ol0000Oooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool3o`0001kooooo000Oooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool05oooool2o`0000gooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001kooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01gooooo000Hoooo
o`Go00000_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01Ol0
000Gooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool03Oooool2o`0001Oooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`0Nooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000
ooooo`05o`0001kooooo000Oooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00002ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool07Ooo
ool001oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooo000001oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool03_ooool2o`0001Cooooo00?o0000ooooooooool04oooool2
o`00017ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooooooool07?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooool000007oooool001oooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00003ooooo`;o00007oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool2o`0001?ooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07?ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000Oooooo`008?ooool2o`0000[o
oooo0_l00005ooooo`03o`000?oooooooooo01kooooo0_l0000:ooooo`;o00000oooool3o`0001Co
oooo0_l0000Aooooo`;o00004?ooool2o`0001Kooooo0_l0000:ooooo`;o00000oooool3o`00023o
oooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`0Mooooo`00O_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo0_l0001oooooo`00Ooooool2o`0000kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1oooooo`00POooool3o`0000_ooooo00?o0000
ooooooooool02_ooool2o`0008;ooooo0024ooooo`Co00001oooool00ol0003oooooooooo`04oooo
o`Ko0000Q?ooool00?oo00008?l00001ooooo`003Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Vooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0
003oooooooooo`2>ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0551142, 154.985, \
0.000384071, 8.93707*^-5}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "We can now compare this symbolic result with a numeric trace of the same \
system to see how close the fifth-order symbolic model matches the actual \
system. To this end, we need to extract the numeric transfer function of the \
optical system via a numeric ray-trace of the default lens configuration. We \
use ",
  StyleBox["ReadTurboRays", "Input"],
  " to extract the numeric data from the trace."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell["\<\
data = ReadTurboRays[plot, \
{RayTilt,OpticalLength,IntersectionNumber,RaySourceNumber}];\
\>", "Input",
  CellLabel->"In[71]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{

Cell["\<\
inputangles = \
Map[{ArcTan[#[[1,1]],#[[1,2]]],#[[4]]}&,Select[data,(#[[3]]==1)&]]\
\>", "Input",
  CellLabel->"In[72]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[BoxData[
    \({{0.08726646259971646`, {{1.`, 101.`}, {1.`, 
            0.`}}}, {0.08552113334772216`, {{2.`, 101.`}, {2.`, 
            0.`}}}, {0.08377580409572781`, {{3.`, 101.`}, {3.`, 
            0.`}}}, {0.08203047484373349`, {{4.`, 101.`}, {4.`, 
            0.`}}}, {0.08028514559173916`, {{5.`, 101.`}, {5.`, 
            0.`}}}, {0.07853981633974484`, {{6.`, 101.`}, {6.`, 
            0.`}}}, {0.07679448708775051`, {{7.`, 101.`}, {7.`, 
            0.`}}}, {0.07504915783575618`, {{8.`, 101.`}, {8.`, 
            0.`}}}, {0.07330382858376185`, {{9.`, 101.`}, {9.`, 
            0.`}}}, {0.07155849933176751`, {{10.`, 101.`}, {10.`, 
            0.`}}}, {0.06981317007977318`, {{11.`, 101.`}, {11.`, 
            0.`}}}, {0.06806784082777885`, {{12.`, 101.`}, {12.`, 
            0.`}}}, {0.06632251157578452`, {{13.`, 101.`}, {13.`, 
            0.`}}}, {0.0645771823237902`, {{14.`, 101.`}, {14.`, 
            0.`}}}, {0.06283185307179585`, {{15.`, 101.`}, {15.`, 
            0.`}}}, {0.06108652381980154`, {{16.`, 101.`}, {16.`, 
            0.`}}}, {0.059341194567807204`, {{17.`, 101.`}, {17.`, 
            0.`}}}, {0.05759586531581287`, {{18.`, 101.`}, {18.`, 
            0.`}}}, {0.05585053606381855`, {{19.`, 101.`}, {19.`, 
            0.`}}}, {0.054105206811824215`, {{20.`, 101.`}, {20.`, 
            0.`}}}, {0.05235987755982989`, {{21.`, 101.`}, {21.`, 
            0.`}}}, {0.05061454830783555`, {{22.`, 101.`}, {22.`, 
            0.`}}}, {0.04886921905584122`, {{23.`, 101.`}, {23.`, 
            0.`}}}, {0.047123889803846894`, {{24.`, 101.`}, {24.`, 
            0.`}}}, {0.04537856055185256`, {{25.`, 101.`}, {25.`, 
            0.`}}}, {0.04363323129985824`, {{26.`, 101.`}, {26.`, 
            0.`}}}, {0.0418879020478639`, {{27.`, 101.`}, {27.`, 
            0.`}}}, {0.04014257279586958`, {{28.`, 101.`}, {28.`, 
            0.`}}}, {0.03839724354387525`, {{29.`, 101.`}, {29.`, 
            0.`}}}, {0.036651914291880916`, {{30.`, 101.`}, {30.`, 
            0.`}}}, {0.03490658503988659`, {{31.`, 101.`}, {31.`, 
            0.`}}}, {0.03316125578789225`, {{32.`, 101.`}, {32.`, 
            0.`}}}, {0.03141592653589793`, {{33.`, 101.`}, {33.`, 
            0.`}}}, {0.0296705972839036`, {{34.`, 101.`}, {34.`, 
            0.`}}}, {0.027925268031909267`, {{35.`, 101.`}, {35.`, 
            0.`}}}, {0.02617993877991494`, {{36.`, 101.`}, {36.`, 
            0.`}}}, {0.024434609527920613`, {{37.`, 101.`}, {37.`, 
            0.`}}}, {0.022689280275926278`, {{38.`, 101.`}, {38.`, 
            0.`}}}, {0.02094395102393195`, {{39.`, 101.`}, {39.`, 
            0.`}}}, {0.019198621771937624`, {{40.`, 101.`}, {40.`, 
            0.`}}}, {0.017453292519943295`, {{41.`, 101.`}, {41.`, 
            0.`}}}, {0.015707963267948957`, {{42.`, 101.`}, {42.`, 
            0.`}}}, {0.013962634015954633`, {{43.`, 101.`}, {43.`, 
            0.`}}}, {0.01221730476396031`, {{44.`, 101.`}, {44.`, 
            0.`}}}, {0.010471975511965971`, {{45.`, 101.`}, {45.`, 
            0.`}}}, {0.008726646259971648`, {{46.`, 101.`}, {46.`, 
            0.`}}}, {0.006981317007977309`, {{47.`, 101.`}, {47.`, 
            0.`}}}, {0.0052359877559829855`, {{48.`, 101.`}, {48.`, 
            0.`}}}, {0.0034906585039886466`, {{49.`, 101.`}, {49.`, 
            0.`}}}, {0.0017453292519943233`, {{50.`, 101.`}, {50.`, 
            0.`}}}, {0.`, {{51.`, 101.`}, {51.`, 
            0.`}}}, {\(-0.001745329251994339`\), {{52.`, 101.`}, {52.`, 
            0.`}}}, {\(-0.0034906585039886622`\), {{53.`, 101.`}, {53.`, 
            0.`}}}, {\(-0.005235987755983001`\), {{54.`, 101.`}, {54.`, 
            0.`}}}, {\(-0.0069813170079773244`\), {{55.`, 101.`}, {55.`, 
            0.`}}}, {\(-0.008726646259971648`\), {{56.`, 101.`}, {56.`, 
            0.`}}}, {\(-0.010471975511965987`\), {{57.`, 101.`}, {57.`, 
            0.`}}}, {\(-0.01221730476396031`\), {{58.`, 101.`}, {58.`, 
            0.`}}}, {\(-0.013962634015954649`\), {{59.`, 101.`}, {59.`, 
            0.`}}}, {\(-0.01570796326794897`\), {{60.`, 101.`}, {60.`, 
            0.`}}}, {\(-0.017453292519943295`\), {{61.`, 101.`}, {61.`, 
            0.`}}}, {\(-0.019198621771937638`\), {{62.`, 101.`}, {62.`, 
            0.`}}}, {\(-0.020943951023931956`\), {{63.`, 101.`}, {63.`, 
            0.`}}}, {\(-0.02268928027592629`\), {{64.`, 101.`}, {64.`, 
            0.`}}}, {\(-0.02443460952792062`\), {{65.`, 101.`}, {65.`, 
            0.`}}}, {\(-0.02617993877991494`\), {{66.`, 101.`}, {66.`, 
            0.`}}}, {\(-0.02792526803190928`\), {{67.`, 101.`}, {67.`, 
            0.`}}}, {\(-0.029670597283903605`\), {{68.`, 101.`}, {68.`, 
            0.`}}}, {\(-0.03141592653589794`\), {{69.`, 101.`}, {69.`, 
            0.`}}}, {\(-0.03316125578789226`\), {{70.`, 101.`}, {70.`, 
            0.`}}}, {\(-0.03490658503988659`\), {{71.`, 101.`}, {71.`, 
            0.`}}}, {\(-0.03665191429188093`\), {{72.`, 101.`}, {72.`, 
            0.`}}}, {\(-0.038397243543875255`\), {{73.`, 101.`}, {73.`, 
            0.`}}}, {\(-0.040142572795869594`\), {{74.`, 101.`}, {74.`, 
            0.`}}}, {\(-0.041887902047863905`\), {{75.`, 101.`}, {75.`, 
            0.`}}}, {\(-0.04363323129985824`\), {{76.`, 101.`}, {76.`, 
            0.`}}}, {\(-0.045378560551852576`\), {{77.`, 101.`}, {77.`, 
            0.`}}}, {\(-0.0471238898038469`\), {{78.`, 101.`}, {78.`, 
            0.`}}}, {\(-0.04886921905584123`\), {{79.`, 101.`}, {79.`, 
            0.`}}}, {\(-0.05061454830783556`\), {{80.`, 101.`}, {80.`, 
            0.`}}}, {\(-0.05235987755982989`\), {{81.`, 101.`}, {81.`, 
            0.`}}}, {\(-0.054105206811824215`\), {{82.`, 101.`}, {82.`, 
            0.`}}}, {\(-0.05585053606381856`\), {{83.`, 101.`}, {83.`, 
            0.`}}}, {\(-0.057595865315812886`\), {{84.`, 101.`}, {84.`, 
            0.`}}}, {\(-0.05934119456780721`\), {{85.`, 101.`}, {85.`, 
            0.`}}}, {\(-0.06108652381980154`\), {{86.`, 101.`}, {86.`, 
            0.`}}}, {\(-0.06283185307179585`\), {{87.`, 101.`}, {87.`, 
            0.`}}}, {\(-0.06457718232379021`\), {{88.`, 101.`}, {88.`, 
            0.`}}}, {\(-0.06632251157578453`\), {{89.`, 101.`}, {89.`, 
            0.`}}}, {\(-0.06806784082777886`\), {{90.`, 101.`}, {90.`, 
            0.`}}}, {\(-0.06981317007977318`\), {{91.`, 101.`}, {91.`, 
            0.`}}}, {\(-0.07155849933176751`\), {{92.`, 101.`}, {92.`, 
            0.`}}}, {\(-0.07330382858376186`\), {{93.`, 101.`}, {93.`, 
            0.`}}}, {\(-0.07504915783575619`\), {{94.`, 101.`}, {94.`, 
            0.`}}}, {\(-0.07679448708775051`\), {{95.`, 101.`}, {95.`, 
            0.`}}}, {\(-0.07853981633974484`\), {{96.`, 101.`}, {96.`, 
            0.`}}}, {\(-0.08028514559173919`\), {{97.`, 101.`}, {97.`, 
            0.`}}}, {\(-0.0820304748437335`\), {{98.`, 101.`}, {98.`, 
            0.`}}}, {\(-0.08377580409572782`\), {{99.`, 101.`}, {99.`, 
            0.`}}}, {\(-0.08552113334772216`\), {{100.`, 101.`}, {100.`, 
            0.`}}}, {\(-0.08726646259971646`\), {{101.`, 101.`}, {101.`, 
            0.`}}}}\)], "Output",
  CellLabel->"Out[72]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[TextData[{
  "Next, we use ",
  StyleBox["ListPlot", "Input"],
  " to plot the optical transfer function of the system."
}], "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{

Cell["\<\
dataplot = \
ListPlot[Map[{#[[1,1]],#[[2,2]]}&,Transpose[{inputangles,Select[data,(#[[3]]==\
3)&]}]]];\
\>", "Input",
  CellLabel->"In[73]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 5.45674 -3489.05 22.5123 [
[.09074 .34509 -18 -9 ]
[.09074 .34509 18 0 ]
[.22716 .34509 -15 -9 ]
[.22716 .34509 15 0 ]
[.36358 .34509 -18 -9 ]
[.36358 .34509 18 0 ]
[.63642 .34509 -15 -9 ]
[.63642 .34509 15 0 ]
[.77284 .34509 -12 -9 ]
[.77284 .34509 12 0 ]
[.90926 .34509 -15 -9 ]
[.90926 .34509 15 0 ]
[.4875 .01991 -42 -4.5 ]
[.4875 .01991 0 4.5 ]
[.4875 .13247 -36 -4.5 ]
[.4875 .13247 0 4.5 ]
[.4875 .24503 -42 -4.5 ]
[.4875 .24503 0 4.5 ]
[.4875 .47015 -42 -4.5 ]
[.4875 .47015 0 4.5 ]
[.4875 .58272 -36 -4.5 ]
[.4875 .58272 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09074 .35759 m
.09074 .36384 L
s
[(-0.075)] .09074 .34509 0 1 Mshowa
.22716 .35759 m
.22716 .36384 L
s
[(-0.05)] .22716 .34509 0 1 Mshowa
.36358 .35759 m
.36358 .36384 L
s
[(-0.025)] .36358 .34509 0 1 Mshowa
.63642 .35759 m
.63642 .36384 L
s
[(0.025)] .63642 .34509 0 1 Mshowa
.77284 .35759 m
.77284 .36384 L
s
[(0.05)] .77284 .34509 0 1 Mshowa
.90926 .35759 m
.90926 .36384 L
s
[(0.075)] .90926 .34509 0 1 Mshowa
.125 Mabswid
.11803 .35759 m
.11803 .36134 L
s
.14531 .35759 m
.14531 .36134 L
s
.1726 .35759 m
.1726 .36134 L
s
.19988 .35759 m
.19988 .36134 L
s
.25445 .35759 m
.25445 .36134 L
s
.28173 .35759 m
.28173 .36134 L
s
.30901 .35759 m
.30901 .36134 L
s
.3363 .35759 m
.3363 .36134 L
s
.39087 .35759 m
.39087 .36134 L
s
.41815 .35759 m
.41815 .36134 L
s
.44543 .35759 m
.44543 .36134 L
s
.47272 .35759 m
.47272 .36134 L
s
.52728 .35759 m
.52728 .36134 L
s
.55457 .35759 m
.55457 .36134 L
s
.58185 .35759 m
.58185 .36134 L
s
.60913 .35759 m
.60913 .36134 L
s
.6637 .35759 m
.6637 .36134 L
s
.69099 .35759 m
.69099 .36134 L
s
.71827 .35759 m
.71827 .36134 L
s
.74555 .35759 m
.74555 .36134 L
s
.80012 .35759 m
.80012 .36134 L
s
.8274 .35759 m
.8274 .36134 L
s
.85469 .35759 m
.85469 .36134 L
s
.88197 .35759 m
.88197 .36134 L
s
.06346 .35759 m
.06346 .36134 L
s
.03618 .35759 m
.03618 .36134 L
s
.00889 .35759 m
.00889 .36134 L
s
.93654 .35759 m
.93654 .36134 L
s
.96382 .35759 m
.96382 .36134 L
s
.99111 .35759 m
.99111 .36134 L
s
.25 Mabswid
0 .35759 m
1 .35759 L
s
.5 .01991 m
.50625 .01991 L
s
[(154.985)] .4875 .01991 1 0 Mshowa
.5 .13247 m
.50625 .13247 L
s
[(154.99)] .4875 .13247 1 0 Mshowa
.5 .24503 m
.50625 .24503 L
s
[(154.995)] .4875 .24503 1 0 Mshowa
.5 .47015 m
.50625 .47015 L
s
[(155.005)] .4875 .47015 1 0 Mshowa
.5 .58272 m
.50625 .58272 L
s
[(155.01)] .4875 .58272 1 0 Mshowa
.125 Mabswid
.5 .04242 m
.50375 .04242 L
s
.5 .06493 m
.50375 .06493 L
s
.5 .08745 m
.50375 .08745 L
s
.5 .10996 m
.50375 .10996 L
s
.5 .15498 m
.50375 .15498 L
s
.5 .17749 m
.50375 .17749 L
s
.5 .20001 m
.50375 .20001 L
s
.5 .22252 m
.50375 .22252 L
s
.5 .26754 m
.50375 .26754 L
s
.5 .29006 m
.50375 .29006 L
s
.5 .31257 m
.50375 .31257 L
s
.5 .33508 m
.50375 .33508 L
s
.5 .38011 m
.50375 .38011 L
s
.5 .40262 m
.50375 .40262 L
s
.5 .42513 m
.50375 .42513 L
s
.5 .44764 m
.50375 .44764 L
s
.5 .49267 m
.50375 .49267 L
s
.5 .51518 m
.50375 .51518 L
s
.5 .53769 m
.50375 .53769 L
s
.5 .5602 m
.50375 .5602 L
s
.5 .60523 m
.50375 .60523 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.97619 .60332 Mdot
.96667 .5165 Mdot
.95714 .43877 Mdot
.94762 .36951 Mdot
.9381 .30814 Mdot
.92857 .25411 Mdot
.91905 .20691 Mdot
.90952 .16605 Mdot
.9 .13107 Mdot
.89048 .10152 Mdot
.88095 .07699 Mdot
.87143 .05709 Mdot
.8619 .04146 Mdot
.85238 .02972 Mdot
.84286 .02156 Mdot
.83333 .01666 Mdot
.82381 .01472 Mdot
.81429 .01544 Mdot
.80476 .01858 Mdot
.79524 .02386 Mdot
.78571 .03106 Mdot
.77619 .03994 Mdot
.76667 .05029 Mdot
.75714 .0619 Mdot
.74762 .07458 Mdot
.7381 .08814 Mdot
.72857 .10243 Mdot
.71905 .11727 Mdot
.70952 .1325 Mdot
.7 .148 Mdot
.69048 .16362 Mdot
.68095 .17923 Mdot
.67143 .19471 Mdot
.6619 .20996 Mdot
.65238 .22487 Mdot
.64286 .23934 Mdot
.63333 .25328 Mdot
.62381 .26661 Mdot
.61429 .27925 Mdot
.60476 .29114 Mdot
.59524 .3022 Mdot
.58571 .31238 Mdot
.57619 .32162 Mdot
.56667 .32989 Mdot
.55714 .33713 Mdot
.54762 .34332 Mdot
.5381 .34843 Mdot
.52857 .35242 Mdot
.51905 .35529 Mdot
.50952 .35702 Mdot
.5 .35759 Mdot
.49048 .35702 Mdot
.48095 .35529 Mdot
.47143 .35242 Mdot
.4619 .34843 Mdot
.45238 .34332 Mdot
.44286 .33713 Mdot
.43333 .32989 Mdot
.42381 .32162 Mdot
.41429 .31238 Mdot
.40476 .3022 Mdot
.39524 .29114 Mdot
.38571 .27925 Mdot
.37619 .26661 Mdot
.36667 .25328 Mdot
.35714 .23934 Mdot
.34762 .22487 Mdot
.3381 .20996 Mdot
.32857 .19471 Mdot
.31905 .17923 Mdot
.30952 .16362 Mdot
.3 .148 Mdot
.29048 .1325 Mdot
.28095 .11727 Mdot
.27143 .10243 Mdot
.2619 .08814 Mdot
.25238 .07458 Mdot
.24286 .0619 Mdot
.23333 .05029 Mdot
.22381 .03994 Mdot
.21429 .03106 Mdot
.20476 .02386 Mdot
.19524 .01858 Mdot
.18571 .01544 Mdot
.17619 .01472 Mdot
.16667 .01666 Mdot
.15714 .02156 Mdot
.14762 .02972 Mdot
.1381 .04146 Mdot
.12857 .05709 Mdot
.11905 .07699 Mdot
.10952 .10152 Mdot
.1 .13107 Mdot
.09048 .16605 Mdot
.08095 .20691 Mdot
.07143 .25411 Mdot
.0619 .30814 Mdot
.05238 .36951 Mdot
.04286 .43877 Mdot
.03333 .5165 Mdot
.02381 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[73]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oSoooool0
0ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003o
ooooooooo`2>ooooo`00<_ooool2o`0002kooooo0ol00003ooooo`?o00001?ooool3o`0000?ooooo
00?o0000ooooooooool00_ooool2o`0000Cooooo0ol00003ooooo`?o00001_ooool00ol0003ooooo
ooooo`1Iooooo`;o0000<oooool002oooooo0_l000000ooooooo0000o`000002o`0002gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Fooooo`;o000000Coooooo`000?l0003ooooo0_l0000`oooo
o`00;?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000Zooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000001?l0000;ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`?o0000E?ooool4o`0000Co
oooo0_l000000ooooooo0000o`00000]ooooo`00;?ooool2o`0000Wooooo0_l000000ooooooo0000
o`00000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`07ooooo`Co00000_ooool3o`0000Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Aooooo`;o000000?oooooo`000?l000002Oooool2o`0002gooooo000jooooo`;o00009ooo
ool01?l0003oooooooooooooool4o`0000?ooooo00?o0000ooooool000002?ooool01ol0003ooooo
oooooooooooo0000ooooool000000oooool00ol0003oooooo`000003o`0000Kooooo00?o0000oooo
ooooool0DOooool2o`0003_ooooo000Yooooo`;o00004_ooool2o`0002?ooooo0_l00003ooooo`03
o`000?oooooooooo00Gooooo0_l00008ooooo`07o`000?ooooooooooooooool0003oooooo`000003
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0C_ooool2o`00017ooooo0_l0000[
ooooo`00:Oooool2o`0001;ooooo0_l0000Tooooo`04o`000?ooooooooooooooo`Go00001?ooool0
0ol0003oooooooooo`07ooooo`?o00000oooool3o`0000;ooooo1Ol00005ooooo`03o`000?oooooo
oooo04kooooo0_l0000Aooooo`;o0000:oooool008oooooo00?o0000ooooooooool0S_ooool002Oo
oooo0_l0000Fooooo`;o0000C_ooool00ol0003oooooooooo`1;ooooo`;o00005oooool2o`0002So
oooo000Wooooo`;o00005_ooool2o`0004kooooo0_l0001<ooooo`;o00005oooool2o`0002Sooooo
002?ooooo`03o`000?oooooooooo08kooooo0012ooooo`;o0000Boooool00ol0003oooooooooo`19
ooooo`;o0000@oooool004;ooooo0_l0001;ooooo`03o`000?oooooooooo04Wooooo0_l00013oooo
o`009?ooool2o`0006Wooooo00?o0000ooooooooool0Ioooool2o`0002Gooooo000Tooooo`;o0000
7oooool2o`0004Sooooo00?o0000ooooooooool0A_ooool2o`0001oooooo0_l0000Uooooo`00AOoo
ool2o`0004Sooooo0_l00017ooooo`;o0000A_ooool008oooooo00?o0000ooooooooool0S_ooool0
08oooooo00?o0000ooooooooool0S_ooool0027ooooo0_l0000Tooooo`;o0000A_ooool00ol0003o
ooooooooo`13ooooo`;o00009?ooool2o`0002?ooooo000Qooooo`;o00009?ooool2o`0004Kooooo
00?o0000ooooooooool0@oooool2o`0002Cooooo0_l0000Sooooo`00Soooool00ol0003ooooooooo
o`2>ooooo`00B_ooool2o`0004?ooooo00?o0000ooooooooool0@Oooool2o`0004_ooooo001:oooo
o`;o0000@oooool2o`0004;ooooo0_l0001;ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00
Soooool00ol0003oooooooooo`2>ooooo`007oooool2o`0006kooooo00?o0000ooooooooool0K?oo
ool2o`00023ooooo000Oooooo`;o0000;?ooool2o`00043ooooo00?o0000ooooooooool0?_ooool2
o`0002cooooo0_l0000Pooooo`00COooool2o`00043ooooo00?o0000ooooooooool0?_ooool2o`00
04kooooo002?ooooo`;o0000Soooool008oooooo00?o0000ooooooooool0S_ooool0053ooooo0_l0
000mooooo`03o`000?oooooooooo03_ooooo0_l0001Aooooo`00D?ooool2o`0003gooooo00?o0000
ooooooooool0>oooool2o`00057ooooo001Xooooo`?o00000oooool3o`0000Cooooo0ol00003oooo
o`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`2>oooo
o`00JOooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2>ooooo`007?ooool2o`0003Cooooo0_l0000Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooool000001?l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool3o`0003Sooooo0_l0000eooooo`;o00007Oooool001cooooo0_l0000dooooo`;o0000
5Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
1oooool4o`0000;ooooo1?l00005ooooo`03o`000?oooooooooo03Sooooo0_l0000eooooo`;o0000
7Oooool006Wooooo00Co0000oooooooooooooooo1?l00003ooooo`03o`000?oooooo000000Sooooo
00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2>ooooo`00J?ooool2o`0000?ooooo00?o0000ooooooooool01Oooool2o`0000So
oooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2>ooooo`00JOooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000
ooooooooool01oooool3o`0000?ooooo0ol00006ooooo`03o`000?oooooooooo08kooooo001Eoooo
o`;o0000>?ooool00ol0003oooooooooo`0fooooo`;o0000E_ooool005Gooooo0_l0000hooooo`03
o`000?oooooooooo03Kooooo0_l0001Fooooo`00Soooool2o`0008oooooo002?ooooo`03o`000?oo
oooooooo08kooooo001Hooooo`;o0000=Oooool00ol0003oooooooooo`0cooooo`;o0000FOooool0
01Wooooo0_l0000mooooo`;o0000=Oooool00ol0003oooooooooo`0cooooo`;o0000?Oooool2o`00
01[ooooo000Iooooo`;o0000M?ooool00ol0003oooooooooo`1booooo`;o00006_ooool008oooooo
00?o0000ooooooooool0S_ooool005_ooooo0_l0000booooo`;o0000<Oooool2o`0005cooooo001K
ooooo`;o0000<_ooool00ol0003oooooooooo`0`ooooo`;o0000G?ooool008oooooo00?o0000oooo
ooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0
S_ooool005gooooo0_l0000`ooooo`03o`000?oooooooooo02gooooo0_l0001Oooooo`00GOooool2
o`00033ooooo00?o0000ooooooooool0;Oooool2o`0005oooooo002?ooooo`;o0000Soooool001Ko
oooo0_l0001gooooo`03o`000?oooooooooo07Cooooo0_l0000Hooooo`005_ooool2o`0004Sooooo
0_l0000]ooooo`03o`000?oooooooooo02_ooooo0_l00017ooooo`;o00006?ooool0063ooooo0_l0
000]ooooo`03o`000?oooooooooo02_ooooo0_l0001Qooooo`00Soooool00ol0003oooooooooo`2>
ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool2o`0008oooooo001Sooooo`;o0000
:_ooool00ol0003oooooooooo`0Xooooo`;o0000I?ooool006?ooooo0_l0000Zooooo`03o`000?oo
oooooooo02Sooooo0_l0001Tooooo`00Soooool00ol0003oooooooooo`2>ooooo`00H_ooool3o`00
00?ooooo0ol00004ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`;o00001?ooool2o`00
00Cooooo0ol00006ooooo`03o`000?oooooooooo08kooooo001Sooooo`03o`000?oooooo000000;o
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool09Oooool2o`0006Oooooo001Sooooo`04o`000?oooooo0000o`0000Cooooo00?o0000oooo
ool000001?l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo0_l0001Wooooo`00Hoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01oooool4o`0000;o
oooo1?l00005ooooo`03o`000?oooooooooo00?ooooo0ol0002>ooooo`00Hoooool01?l0003ooooo
ooooooooool4o`0000?ooooo00?o0000ooooool000002?ooool01ol0003ooooooooooooooooo0000
ooooool000000oooool00ol0003oooooo`000003o`0000Kooooo00?o0000ooooooooool0S_ooool0
01Cooooo0_l0001<ooooo`;o00000oooool3o`0000Gooooo0_l00008ooooo`07o`000?oooooooooo
ooooool0003oooooo`000003ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool08ooo
ool2o`0005;ooooo0_l0000Eooooo`005?ooool2o`0004gooooo00Co0000oooooooooooooooo1Ol0
0004ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`?o00000_ooool5o`0000Gooooo00?o
0000ooooooooool08oooool2o`0005;ooooo0_l0000Eooooo`00Soooool00ol0003oooooooooo`2>
ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Joooool2o`0002;ooooo0_l0000Qooooo`;o
0000K?ooool006_ooooo0_l0000Rooooo`03o`000?oooooooooo023ooooo0_l0001/ooooo`00Sooo
ool00ol0003oooooooooo`2>ooooo`00K_ooool2o`0001oooooo00?o0000ooooooooool07Oooool2
o`0006oooooo001^ooooo`;o00007oooool00ol0003oooooooooo`0Mooooo`;o0000Koooool008oo
oooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool0073ooooo0_l0
000Mooooo`;o00006oooool2o`0007;ooooo001`ooooo`;o00007Oooool00ol0003oooooooooo`0J
ooooo`;o0000L_ooool008oooooo00?o0000ooooooooool0S_ooool007?ooooo0_l0000Jooooo`03
o`000?oooooooooo01Sooooo0_l0001dooooo`004Oooool2o`00063ooooo0_l0000Jooooo`03o`00
0?oooooooooo01Sooooo0_l0001Pooooo`;o00004_ooool0017ooooo0_l0001looooo`03o`000?oo
oooooooo07[ooooo0_l0000Booooo`00M_ooool2o`0001Oooooo0_l0000Fooooo`;o0000Moooool0
013ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol0000@ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`00
013ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3o`00
01Oooooo00?o0000ooooooooool05Oooool4o`0000Cooooo00?o0000ooooooooool00oooool2o`00
00;ooooo1Ol00002ooooo`?o00004?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`00
00?ooooo0ol0000@ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00003oooool000oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0<ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool3o`0001Cooooo00?o0000oooooooo
ool04_ooool2o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0<ooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0<ooooo`002?ooool5o`0000;ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Gooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`?o
00005?ooool00ol0003oooooooooo`0Booooo`;o00000_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`0<ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo000?ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo00cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Foooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0
00oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooo000000?o00003oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?oo
ool01?l0000?ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooo000000?o00000oooool2o`0001;ooooo00?o0000ooooooooool03ooo
ool2o`0000Gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooool000000ol0000?ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
oooooooooooo0000ooooo`04o`0000oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooo000000?o00003oooool000oooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000004_ooool0
1?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00004_ooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00
0006ooooo`;o00004_ooool2o`00013ooooo0_l00005ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000001;ooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0001;ooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000004_ooool0
013ooooo0_l0000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00003oooool2o`00
00[ooooo0_l00002ooooo`Go00003oooool2o`0000[ooooo0_l00003ooooo`?o00000_ooool5o`00
00Gooooo0_l0000?ooooo`03o`000?oooooooooo00gooooo0_l00008ooooo`;o00002_ooool2o`00
00?ooooo0ol00002ooooo`Go00003oooool2o`0000[ooooo0_l00002ooooo`Go00003oooool2o`00
00[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol0000>ooooo`00O_ooool2o`000003
ooooool0003o000000cooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003o000007oo
oooo0021ooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`;o0000P_ooool008?ooooo0_l0
000:ooooo`03o`000?oooooooooo00Oooooo0_l00025ooooo`00Poooool2o`000003ooooool0003o
000000Oooooo00?o0000ooooooooool01Oooool4o`0008Gooooo0026ooooo`;o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000ooooo`02o`000004ooooool0003o0000ooooo`;o0000Qooo
ool00?oo00008?l00001ooooo`000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo007ooooo000Jooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Wo
oooo000>ooooo`;o0000Ooooool00ol0003oooooooooo`1mooooo`;o00003oooool000kooooo0_l0
001oooooo`03o`000?oooooooooo07gooooo0_l0000?ooooo`00Soooool00ol0003oooooooooo`2>
ooooo`00Soooool2o`0008oooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`00
0?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooo
oooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08ko
oooo002?ooooo`;o0000Soooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000
ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000oooooooo
ool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo0_l0002?ooooo`00Soooool0
0ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003o
ooooooooo`2>ooooo`003?ooool2o`00087ooooo00?o0000ooooooooool0Ooooool2o`0000gooooo
000<ooooo`;o0000POooool00ol0003oooooooooo`1oooooo`;o00003Oooool008oooooo00?o0000
ooooooooool0S_ooool008oooooo0_l0002?ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00
Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00H_ooool3
o`0000?ooooo0ol00003ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2
o`0000?ooooo0ol00006ooooo`03o`000?oooooooooo08kooooo001Sooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Co0000
oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2>ooooo`00Hoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool3o`0008kooooo001Sooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo08kooooo001Sooooo`04o`000?ooooooooooooooo`Co00000_ooool4
o`0000Wooooo00Co0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo00Co0000
1_ooool00ol0003oooooooooo`2>ooooo`00H_ooool2o`0000?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo
0000ooooool00009ooooo`03o`000?oooooooooo08kooooo001Sooooo`04o`000?oooooooooooooo
o`Go000000?oooooo`000?l000000ol00009ooooo`;o00001?ooool2o`0000;ooooo1Ol00005oooo
o`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`00
0?oooooooooo08kooooo002?ooooo`;o0000Soooool008oooooo00?o0000ooooooooool0S_ooool0
08oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo
00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool000Wooooo0_l00024
ooooo`;o0000Poooool2o`0000[ooooo0009ooooo`;o0000Q?ooool00ol0003oooooooooo`22oooo
o`;o00002_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0
S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool0
08oooooo0_l0002?ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003ooooo
ooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>
ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00
Soooool2o`0008oooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooo
oooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo001Xooooo`?o00000oooool3o`0000?o
oooo0ol00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001_ooool00ol0003o
ooooooooo`2>ooooo`00JOooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool0
00000oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2>ooooo`00JOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00Gooooo0ol0002>ooooo`00JOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S_ooool006Wooooo00Co0000oooooooo
oooooooo1?l00002ooooo`Co00002Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0S_ooool006Sooooo0_l00003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00002ooooo`;o00001oooool0
0ol0003oooooooooo`2>ooooo`00JOooool01?l0003oooooooooooooool5o`000003ooooool0003o
000000?o00002Oooool2o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2>
ooooo`00Soooool00ol0003oooooooooo`2>ooooo`001_ooool2o`0008Oooooo00?o0000oooooooo
ool0QOooool2o`0000Oooooo0006ooooo`;o0000Qoooool2o`0008Kooooo0_l00007ooooo`00Sooo
ool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0
003oooooooooo`2>ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0918571, 154.984, \
0.000640119, 0.000155158}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell["\<\
Finally, we can compare a plot of numeric ray-trace points with the result \
given by the symbolic equation.\
\>", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{

Cell["Show[dataplot,oplot];", "Input",
  CellLabel->"In[74]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 5.45674 -3489.05 22.5123 [
[.09074 .34509 -18 -9 ]
[.09074 .34509 18 0 ]
[.22716 .34509 -15 -9 ]
[.22716 .34509 15 0 ]
[.36358 .34509 -18 -9 ]
[.36358 .34509 18 0 ]
[.63642 .34509 -15 -9 ]
[.63642 .34509 15 0 ]
[.77284 .34509 -12 -9 ]
[.77284 .34509 12 0 ]
[.90926 .34509 -15 -9 ]
[.90926 .34509 15 0 ]
[.4875 .01991 -42 -4.5 ]
[.4875 .01991 0 4.5 ]
[.4875 .13247 -36 -4.5 ]
[.4875 .13247 0 4.5 ]
[.4875 .24503 -42 -4.5 ]
[.4875 .24503 0 4.5 ]
[.4875 .47015 -42 -4.5 ]
[.4875 .47015 0 4.5 ]
[.4875 .58272 -36 -4.5 ]
[.4875 .58272 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09074 .35759 m
.09074 .36384 L
s
[(-0.075)] .09074 .34509 0 1 Mshowa
.22716 .35759 m
.22716 .36384 L
s
[(-0.05)] .22716 .34509 0 1 Mshowa
.36358 .35759 m
.36358 .36384 L
s
[(-0.025)] .36358 .34509 0 1 Mshowa
.63642 .35759 m
.63642 .36384 L
s
[(0.025)] .63642 .34509 0 1 Mshowa
.77284 .35759 m
.77284 .36384 L
s
[(0.05)] .77284 .34509 0 1 Mshowa
.90926 .35759 m
.90926 .36384 L
s
[(0.075)] .90926 .34509 0 1 Mshowa
.125 Mabswid
.11803 .35759 m
.11803 .36134 L
s
.14531 .35759 m
.14531 .36134 L
s
.1726 .35759 m
.1726 .36134 L
s
.19988 .35759 m
.19988 .36134 L
s
.25445 .35759 m
.25445 .36134 L
s
.28173 .35759 m
.28173 .36134 L
s
.30901 .35759 m
.30901 .36134 L
s
.3363 .35759 m
.3363 .36134 L
s
.39087 .35759 m
.39087 .36134 L
s
.41815 .35759 m
.41815 .36134 L
s
.44543 .35759 m
.44543 .36134 L
s
.47272 .35759 m
.47272 .36134 L
s
.52728 .35759 m
.52728 .36134 L
s
.55457 .35759 m
.55457 .36134 L
s
.58185 .35759 m
.58185 .36134 L
s
.60913 .35759 m
.60913 .36134 L
s
.6637 .35759 m
.6637 .36134 L
s
.69099 .35759 m
.69099 .36134 L
s
.71827 .35759 m
.71827 .36134 L
s
.74555 .35759 m
.74555 .36134 L
s
.80012 .35759 m
.80012 .36134 L
s
.8274 .35759 m
.8274 .36134 L
s
.85469 .35759 m
.85469 .36134 L
s
.88197 .35759 m
.88197 .36134 L
s
.06346 .35759 m
.06346 .36134 L
s
.03618 .35759 m
.03618 .36134 L
s
.00889 .35759 m
.00889 .36134 L
s
.93654 .35759 m
.93654 .36134 L
s
.96382 .35759 m
.96382 .36134 L
s
.99111 .35759 m
.99111 .36134 L
s
.25 Mabswid
0 .35759 m
1 .35759 L
s
.5 .01991 m
.50625 .01991 L
s
[(154.985)] .4875 .01991 1 0 Mshowa
.5 .13247 m
.50625 .13247 L
s
[(154.99)] .4875 .13247 1 0 Mshowa
.5 .24503 m
.50625 .24503 L
s
[(154.995)] .4875 .24503 1 0 Mshowa
.5 .47015 m
.50625 .47015 L
s
[(155.005)] .4875 .47015 1 0 Mshowa
.5 .58272 m
.50625 .58272 L
s
[(155.01)] .4875 .58272 1 0 Mshowa
.125 Mabswid
.5 .04242 m
.50375 .04242 L
s
.5 .06493 m
.50375 .06493 L
s
.5 .08745 m
.50375 .08745 L
s
.5 .10996 m
.50375 .10996 L
s
.5 .15498 m
.50375 .15498 L
s
.5 .17749 m
.50375 .17749 L
s
.5 .20001 m
.50375 .20001 L
s
.5 .22252 m
.50375 .22252 L
s
.5 .26754 m
.50375 .26754 L
s
.5 .29006 m
.50375 .29006 L
s
.5 .31257 m
.50375 .31257 L
s
.5 .33508 m
.50375 .33508 L
s
.5 .38011 m
.50375 .38011 L
s
.5 .40262 m
.50375 .40262 L
s
.5 .42513 m
.50375 .42513 L
s
.5 .44764 m
.50375 .44764 L
s
.5 .49267 m
.50375 .49267 L
s
.5 .51518 m
.50375 .51518 L
s
.5 .53769 m
.50375 .53769 L
s
.5 .5602 m
.50375 .5602 L
s
.5 .60523 m
.50375 .60523 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.97619 .60332 Mdot
.96667 .5165 Mdot
.95714 .43877 Mdot
.94762 .36951 Mdot
.9381 .30814 Mdot
.92857 .25411 Mdot
.91905 .20691 Mdot
.90952 .16605 Mdot
.9 .13107 Mdot
.89048 .10152 Mdot
.88095 .07699 Mdot
.87143 .05709 Mdot
.8619 .04146 Mdot
.85238 .02972 Mdot
.84286 .02156 Mdot
.83333 .01666 Mdot
.82381 .01472 Mdot
.81429 .01544 Mdot
.80476 .01858 Mdot
.79524 .02386 Mdot
.78571 .03106 Mdot
.77619 .03994 Mdot
.76667 .05029 Mdot
.75714 .0619 Mdot
.74762 .07458 Mdot
.7381 .08814 Mdot
.72857 .10243 Mdot
.71905 .11727 Mdot
.70952 .1325 Mdot
.7 .148 Mdot
.69048 .16362 Mdot
.68095 .17923 Mdot
.67143 .19471 Mdot
.6619 .20996 Mdot
.65238 .22487 Mdot
.64286 .23934 Mdot
.63333 .25328 Mdot
.62381 .26661 Mdot
.61429 .27925 Mdot
.60476 .29114 Mdot
.59524 .3022 Mdot
.58571 .31238 Mdot
.57619 .32162 Mdot
.56667 .32989 Mdot
.55714 .33713 Mdot
.54762 .34332 Mdot
.5381 .34843 Mdot
.52857 .35242 Mdot
.51905 .35529 Mdot
.50952 .35702 Mdot
.5 .35759 Mdot
.49048 .35702 Mdot
.48095 .35529 Mdot
.47143 .35242 Mdot
.4619 .34843 Mdot
.45238 .34332 Mdot
.44286 .33713 Mdot
.43333 .32989 Mdot
.42381 .32162 Mdot
.41429 .31238 Mdot
.40476 .3022 Mdot
.39524 .29114 Mdot
.38571 .27925 Mdot
.37619 .26661 Mdot
.36667 .25328 Mdot
.35714 .23934 Mdot
.34762 .22487 Mdot
.3381 .20996 Mdot
.32857 .19471 Mdot
.31905 .17923 Mdot
.30952 .16362 Mdot
.3 .148 Mdot
.29048 .1325 Mdot
.28095 .11727 Mdot
.27143 .10243 Mdot
.2619 .08814 Mdot
.25238 .07458 Mdot
.24286 .0619 Mdot
.23333 .05029 Mdot
.22381 .03994 Mdot
.21429 .03106 Mdot
.20476 .02386 Mdot
.19524 .01858 Mdot
.18571 .01544 Mdot
.17619 .01472 Mdot
.16667 .01666 Mdot
.15714 .02156 Mdot
.14762 .02972 Mdot
.1381 .04146 Mdot
.12857 .05709 Mdot
.11905 .07699 Mdot
.10952 .10152 Mdot
.1 .13107 Mdot
.09048 .16605 Mdot
.08095 .20691 Mdot
.07143 .25411 Mdot
.0619 .30814 Mdot
.05238 .36951 Mdot
.04286 .43877 Mdot
.03333 .5165 Mdot
.02381 .60332 Mdot
.5 Mabswid
.21429 .01856 m
.23747 .04773 L
.26275 .08536 L
.28649 .12397 L
.30932 .16222 L
.33363 .20238 L
.35703 .23898 L
.38189 .27421 L
.40585 .30339 L
.4289 .32616 L
.44057 .33549 L
.45342 .34393 L
.46561 .35012 L
.47107 .35229 L
.47703 .35425 L
.48026 .35512 L
.48326 .35581 L
.48636 .35641 L
.48918 .35685 L
.49195 .35718 L
.49322 .3573 L
.49456 .3574 L
.49599 .35749 L
.49663 .35752 L
.49731 .35755 L
.49805 .35757 L
.49873 .35758 L
.49915 .35759 L
.49955 .35759 L
.50029 .35759 L
.50098 .35759 L
.50171 .35757 L
.50241 .35756 L
.50305 .35753 L
.50453 .35746 L
.50609 .35736 L
.50761 .35723 L
.50902 .35708 L
.51224 .35664 L
.51758 .35563 L
.52329 .35415 L
.52944 .35211 L
.5361 .34936 L
.54819 .34298 L
.57274 .32473 L
.59638 .30089 L
.61911 .27287 L
.64332 .23846 L
.66661 .20199 L
.69138 .16104 L
Mistroke
.71524 .1211 L
.73818 .0839 L
.7626 .04763 L
.78571 .01856 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[74]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oSoooool0
0ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003o
ooooooooo`2>ooooo`00<_ooool2o`0002kooooo0ol00003ooooo`?o00001?ooool3o`0000?ooooo
00?o0000ooooooooool00_ooool2o`0000Cooooo0ol00003ooooo`?o00001_ooool00ol0003ooooo
ooooo`1Iooooo`;o0000<oooool002oooooo0_l000000ooooooo0000o`000002o`0002gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Fooooo`;o000000Coooooo`000?l0003ooooo0_l0000`oooo
o`00;?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000004ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000004o`0000_o
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo0ol0001?ooooo`03o`000?oooooooooo00;ooooo1?l00004ooooo`;o000000?oooooo`000?l0
0000;Oooool002cooooo0_l00009ooooo`;o000000Goooooo`000?l0003oooooo`00000Uooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`07ooooo`Co
00000_ooool3o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1?ooooo`05
o`000?oooooo0000o`000?ooool00_l00009ooooo`;o0000;Oooool003[ooooo0_l00002ooooo`03
o`000?oooooooooo02;ooooo00Co0000oooooooooooooooo1?l00003ooooo`03o`000?oooooo0000
00Sooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000ol0
0006ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool00_l0000kooooo`00:Oooool2
o`0001;ooooo0ol0000Rooooo`;o00000oooool00ol0003oooooooooo`05ooooo`;o00002?ooool0
1ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000009ooooo`03o`00
0?oooooooooo04gooooo0ol0000Aooooo`;o0000:oooool002Wooooo0_l0000Booooo`;o000000?o
ooooo`000?ooool08Oooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool0
1oooool3o`0000?ooooo0ol00002ooooo`Go00001Oooool00ol0003oooooooooo`1<ooooo`04o`00
0?oooooo0000o`00017ooooo0_l0000[ooooo`00@Oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool0@?ooool002Oooooo0_l0000Fooooo`;o000000?o
ooooo`000?ooool0Boooool00ol0003oooooooooo`1:ooooo`?o00005oooool2o`0002Sooooo000W
ooooo`;o00005_ooool2o`0000;ooooo00?o0000ooooooooool0BOooool2o`0004[ooooo00Co0000
ooooool0003o00005oooool2o`0002Sooooo0014ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`13ooooo`00@_ooool3o`0004[ooooo00?o0000oooo
ooooool0B?ooool3o`0004?ooooo0012ooooo`;o000000?oooooo`000?ooool0B?ooool00ol0003o
ooooooooo`17ooooo`04o`000?oooooo0000o`0004?ooooo000Tooooo`;o00008?ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07_ooool2o`0002Go
oooo000Tooooo`;o00007oooool2o`0004Sooooo00?o0000ooooooooool0A_ooool2o`0001oooooo
0_l0000Uooooo`00AOooool3o`0004Oooooo0_l00016ooooo`?o0000A_ooool004Sooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Oooooo0018oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`17oooo
o`008Oooool2o`0002Cooooo0ol00015ooooo`03o`000?oooooooooo04?ooooo0_l0000Tooooo`;o
00008oooool0027ooooo0_l0000Tooooo`?o0000AOooool00ol0003oooooooooo`13ooooo`;o0000
9?ooool2o`0002?ooooo001:ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`19ooooo`00B_ooool2o`0004?ooooo00?o0000ooooooooool0@Oooool2
o`0004_ooooo001:ooooo`;o0000@oooool2o`0004;ooooo0_l0001;ooooo`00C?ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0Boooool004gooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo04cooooo
000Oooooo`;o0000;?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0:_ooool2o`00023ooooo000Oooooo`;o0000;?ooool2o`00043ooooo00?o0000
ooooooooool0?_ooool2o`0002cooooo0_l0000Pooooo`00COooool3o`0003oooooo00?o0000oooo
ooooool0?_ooool2o`0004kooooo001?ooooo`03o`000?oooooooooo03gooooo0_l0000nooooo`03
o`000?oooooooooo04kooooo001@ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1?ooooo`00D?ooool2o`0003gooooo00?o0000ooooooooool0>ooo
ool2o`00057ooooo001@ooooo`;o0000?Oooool00ol0003oooooooooo`0kooooo`;o0000DOooool0
05;ooooo00?o0000ooooooooool04oooool3o`0000?ooooo0ol00004ooooo`?o00000oooool00ol0
003oooooooooo`02ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`1@ooooo`00D_ooool00ol0003oooooooooo`0Dooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0DOooool001cooooo0_l0000dooooo`;o00005Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000000Co00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo0ol0000hooooo`?o0000=?ooool2o`0001gooooo000Looooo`;o0000=?ooool2o`0001Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Oooooo
1?l00002ooooo`Co00001Oooool00ol0003oooooooooo`0hooooo`;o0000=Oooool2o`0001gooooo
001Dooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo1?l00003ooooo`03o`00
0?oooooo000000Sooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05?ooooo001Dooooo`03
o`000?oooooooooo017ooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00EOooool00ol0003oooooooooo`0Aoooo
o`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`07ooooo`?o00000oooool3
o`0000Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Dooooo`00EOooool2o`00
03Sooooo00?o0000ooooooooool0=_ooool2o`0005Kooooo001Eooooo`;o0000>?ooool00ol0003o
ooooooooo`0fooooo`;o0000E_ooool005Oooooo00?o0000ooooooooool0=Oooool2o`0003Kooooo
00?o0000ooooooooool0E_ooool005Oooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo05Kooooo001Hooooo`;o0000=Oooool00ol0003oooooooooo`0c
ooooo`;o0000FOooool001Wooooo0_l0000mooooo`;o0000=Oooool00ol0003oooooooooo`0coooo
o`;o0000?Oooool2o`0001[ooooo000Iooooo`;o0000?_ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0??ooool2o`0001[ooooo001Iooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1Iooooo`00F_oo
ool3o`0003;ooooo0_l0000aooooo`?o0000Foooool005_ooooo0_l0000booooo`03o`000?oooooo
oooo033ooooo0_l0001Looooo`00Foooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0Foooool005cooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo05_ooooo001Looooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Looooo`00GOooool2o`00033ooooo00?o
0000ooooooooool0;Oooool3o`0005kooooo001Mooooo`;o0000<?ooool00ol0003oooooooooo`0]
ooooo`;o0000Goooool005kooooo00?o0000ooooooooool0;_ooool2o`0002kooooo00?o0000oooo
ooooool0G_ooool001Kooooo0_l00017ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`14ooooo`;o00006?ooool001Kooooo0_l00017ooooo`?o0000
;Oooool00ol0003oooooooooo`0[ooooo`;o0000Aoooool2o`0001Sooooo001Pooooo`;o0000;Ooo
ool00ol0003oooooooooo`0[ooooo`;o0000HOooool0067ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo063ooooo001Qooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Qooooo`00H_ooool00ol0003o
ooooooooo`0Zooooo`;o0000:_ooool00ol0003oooooooooo`1Rooooo`00Hoooool2o`0002[ooooo
00?o0000ooooooooool0:?ooool2o`0006Cooooo001Sooooo`;o0000:_ooool00ol0003ooooooooo
o`0Xooooo`;o0000I?ooool006Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo06?ooooo001Rooooo`Co00000_ooool3o`0000Cooooo0ol00003oooo
o`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001?ooool3o`0000Kooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1Tooooo`00Hoooool00ol0003oooooo`000002o`0000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Gooooo0_l0001Wooooo`00Hoooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooo0000
00Co00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Uooooo`;o0000Ioooool006?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01oooool4o`00
00;ooooo1?l00005ooooo`03o`000?oooooooooo00?ooooo0ol0000Uooooo`03o`000?oooooooooo
06Kooooo001Sooooo`04o`000?ooooooooooooooo`Co00000oooool00ol0003oooooo`000008oooo
o`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000?o00001_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Oooooo000Dooooo`;o0000C?ooool2
o`0000?ooooo0ol00005ooooo`;o00002?ooool01ol0003ooooooooooooooooo0000ooooool00000
0oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo02?ooooo0_l0001Booooo`;o0000
5Oooool001Cooooo0_l0001=ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003ooooo
ooooo`07ooooo`?o00000oooool3o`0000;ooooo1Ol00005ooooo`03o`000?oooooooooo02?ooooo
0_l0001Booooo`;o00005Oooool006[ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo06Wooooo001[ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`1Zooooo`00Joooool2o`0002;ooooo0_l0000Qoooo
o`;o0000K?ooool006_ooooo0_l0000Rooooo`03o`000?oooooooooo023ooooo0_l0001/ooooo`00
KOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
K?ooool006gooooo0ol0000Oooooo`03o`000?oooooooooo01gooooo0ol0001^ooooo`00K_ooool2
o`0001oooooo00?o0000ooooooooool07Oooool2o`0006oooooo001_ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1^ooooo`00L?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Koooool0073ooooo
0_l0000Mooooo`;o00006oooool3o`00077ooooo001`ooooo`?o00007?ooool00ol0003ooooooooo
o`0Jooooo`;o0000L_ooool007?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo077ooooo001cooooo`;o00006_ooool00ol0003oooooooooo`0Hoooo
o`;o0000M?ooool0017ooooo0_l0001Pooooo`?o00006Oooool00ol0003oooooooooo`0Hooooo`;o
0000H?ooool2o`0001;ooooo000Aooooo`;o0000Hoooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0H?ooool2o`0001;ooooo001fooooo`;o00005ooo
ool2o`0001Kooooo0_l0001gooooo`004?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`00013ooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0_l00003ooooo`?o00004?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000;ooooo1Ol00002ooooo`Co00005_ooool00ol0003oooooooooo`0Eooooo`Co00001?ooool0
0ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol0000@ooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`;o00000oooool3o`00013ooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000?ooooo`003oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`?o00005?ooool00ol0003oooooooooo`0Booooo`?o000000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo00cooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00cooooo0008ooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`Go00000_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
1Oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00Gooooo0ol0000Dooooo`03o`000?oooooooooo01;ooooo0_l00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0
00oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
000Cooooo`03o`000?oooooooooo017ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00co
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03?ooool000oooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o00003oooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l0000?ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o
00000oooool2o`0001;ooooo00?o0000ooooooooool03oooool2o`0000Gooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol0
000?ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000oo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
000000?o00003oooool000oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooool000004_ooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00004_ooool01?l0003oooooooooool00008ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooo`000006ooooo`?o00004Oooool2o`0000oo
oooo0ol00005ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooo000001;ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0001;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooool000004_ooool0013ooooo0_l0000:ooooo`;o00000_oo
ool5o`000003ooooool0003o000000?o00003oooool2o`0000[ooooo0_l00002ooooo`Go00003ooo
ool2o`0000[ooooo0_l00003ooooo`?o00000_ooool5o`0000Gooooo0_l0000?ooooo`03o`000?oo
oooooooo00gooooo0_l00008ooooo`;o00002_ooool2o`0000?ooooo0ol00002ooooo`Go00003ooo
ool2o`0000[ooooo0_l00002ooooo`Go00003oooool2o`0000[ooooo0_l00002ooooo`Go000000?o
ooooo`000?l000000ol0000>ooooo`00O_ooool5o`0000cooooo00?o0000ooooooooool02_ooool5
o`0007oooooo0021ooooo`?o00002oooool00ol0003oooooooooo`0:ooooo`;o0000P_ooool008?o
oooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo0ol00024ooooo`00Poooool5o`0000Oooooo
00?o0000ooooooooool01Oooool4o`0008Gooooo0026ooooo`Go000000Koooooo`000?l0003ooooo
o`000?ooool2o`000003ooooool0003o000000?o0000Qoooool00?oo00008?l00001ooooo`000_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo007ooooo000Jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Wooooo000>ooooo`;o0000Ooooool00ol0
003oooooooooo`1mooooo`;o00003oooool000kooooo0_l0001oooooo`03o`000?oooooooooo07go
oooo0_l0000?ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool2o`0008oooooo002?
ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03
o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oo
oooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`;o0000Soooool008oo
oooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o
0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000oooo
ooooool0S_ooool008oooooo0_l0002?ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Sooo
ool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`003?ooool2o`00
087ooooo00?o0000ooooooooool0Ooooool2o`0000gooooo000<ooooo`;o0000POooool00ol0003o
ooooooooo`1oooooo`;o00003Oooool008oooooo00?o0000ooooooooool0S_ooool008oooooo0_l0
002?ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>oooo
o`00Soooool00ol0003oooooooooo`2>ooooo`00H_ooool3o`0000?ooooo0ol00003ooooo`?o0000
1?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000?ooooo0ol00006ooooo`03o`00
0?oooooooooo08kooooo001Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
o`000003ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000_ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2>
ooooo`00Hoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool00oooool3o`0008kooooo001Sooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08kooooo
001Sooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`0000Wooooo00Co0000oooooooooooo
00000_ooool01Ol0003oooooooooool0003ooooo00Co00001_ooool00ol0003oooooooooo`2>oooo
o`00H_ooool2o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`04
o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00009ooooo`03o`000?oo
oooooooo08kooooo001Sooooo`04o`000?ooooooooooooooo`Go000000?oooooo`000?l000000ol0
0009ooooo`;o00001?ooool2o`0000;ooooo1Ol00005ooooo`03o`000?oooooooooo08kooooo002?
ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`;o
0000Soooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_oo
ool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oo
oooo00?o0000ooooooooool0S_ooool000Wooooo0_l00024ooooo`;o0000Poooool2o`0000[ooooo
0009ooooo`;o0000Q?ooool00ol0003oooooooooo`22ooooo`;o00002_ooool008oooooo00?o0000
ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000oooooooo
ool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo0_l0002?ooooo`00Soooool0
0ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003o
ooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003ooooooooo
o`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool2o`0008oooooo002?ooooo`03
o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oo
oooooooo08kooooo001Xooooo`?o00000oooool3o`0000?ooooo0ol00004ooooo`03o`000?oooooo
oooo00?ooooo0_l00003ooooo`?o00001_ooool00ol0003oooooooooo`2>ooooo`00JOooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2>ooooo`00JOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo0ol0
002>ooooo`00JOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0S_ooool006Wooooo00Co0000oooooooooooooooo1?l00002ooooo`Co00002Ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
S_ooool006Sooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_oo
ool01?l0003oooooooooool00002ooooo`;o00001oooool00ol0003oooooooooo`2>ooooo`00JOoo
ool01?l0003oooooooooooooool5o`000003ooooool0003o000000?o00002Oooool2o`0000Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003ooooooooo
o`2>ooooo`001_ooool2o`0008Oooooo00?o0000ooooooooool0QOooool2o`0000Oooooo0006oooo
o`;o0000Qoooool2o`0008Kooooo0_l00007ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00
Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0918571, 154.984, \
0.000640119, 0.000155158}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell["\<\
From this, we see that the symbolic result follows the numeric behavior quite \
well, although the symbolic result begins to deviate from the numeric result \
after about .05 radians. For this reason, we will limit the absolute angular \
values of our symbolic model to less than .05 radians. Based on this \
knowledge, we can now construct a merit function that integrates between the \
-.05 and .05 radians of angular space.\
\>", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{

Cell["\<\
meritFunction=Expand[Integrate[Expand[D[OL,\[Theta]]^2],{\[Theta],-5/100,5/\
100}]]\
\>", "Input",
  CellLabel->"In[75]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[BoxData[
    \(12419989\/6912000 - \(8630209\ c1\)\/38400 + \(8811546167\ \
c1\^2\)\/896000 - \(15844701609\ c1\^3\)\/89600 + \(5534665929\ c1\^4\)\/4480 \
- \(33096701331\ c1\^5\)\/7168 + \(647294186655\ c1\^6\)\/14336 - \
\(11155832325\ c1\^7\)\/448 + \(31352959666125\ c1\^8\)\/57344 + \(26892241\ \
c2\)\/115200 - \(765076197961\ c1\ c2\)\/36288000 + \(23372228129\ c1\^2\ \
c2\)\/38400 - \(29509050087\ c1\^3\ c2\)\/4480 + \(224966885553\ c1\^4\ \
c2\)\/7168 - \(1786598855595\ c1\^5\ c2\)\/7168 + \(704189997675\ c1\^6\ c2\)\
\/896 - \(20170970274375\ c1\^7\ c2\)\/7168 + \(33594267796875\ c1\^8\ \
c2\)\/3584 + \(61871970916463\ c2\^2\)\/5878656000 - \(20605878091867\ c1\ c2\
\^2\)\/32659200 + \(1179668318711\ c1\^2\ c2\^2\)\/103680 - \(693823511411\ \
c1\^3\ c2\^2\)\/8064 + \(10050522993905\ c1\^4\ c2\^2\)\/14336 - \
\(3587655036375\ c1\^5\ c2\^2\)\/1024 + \(193824341575875\ c1\^6\ \
c2\^2\)\/14336 - \(180088418863125\ c1\^7\ c2\^2\)\/3584 + \(42609040790625\ \
c1\^8\ c2\^2\)\/512 + \(57939265257631\ c2\^3\)\/293932800 - \(25056690243373\
\ c1\ c2\^3\)\/3265920 + \(246343020685\ c1\^2\ c2\^3\)\/2268 - \
\(41202259097225\ c1\^3\ c2\^3\)\/32256 + \(61675184754625\ c1\^4\ \
c2\^3\)\/7168 - \(303799448021625\ c1\^5\ c2\^3\)\/7168 + \(651472050369375\ \
c1\^6\ c2\^3\)\/3584 - \(873560187421875\ c1\^7\ c2\^3\)\/1792 + \
\(466896649921875\ c1\^8\ c2\^3\)\/896 + \(33835684341709\ c2\^4\)\/19595520 \
- \(109573523754215\ c1\ c2\^4\)\/1741824 + \(514226287860895\ c1\^2\ c2\^4\)\
\/387072 - \(19371732084925\ c1\^3\ c2\^4\)\/1536 + \(2328575367204375\ c1\^4\
\ c2\^4\)\/28672 - \(1528970573739375\ c1\^5\ c2\^4\)\/3584 + \
\(5515791492515625\ c1\^6\ c2\^4\)\/3584 - \(2711369369671875\ c1\^7\ c2\^4\)\
\/896 + \(4282530262734375\ c1\^8\ c2\^4\)\/1792 + \(643459028623135\ c2\^5\)\
\/47029248 - \(3471452792609575\ c1\ c2\^5\)\/5225472 + \(2760340174365125\ \
c1\^2\ c2\^5\)\/290304 - \(5769695677095625\ c1\^3\ c2\^5\)\/64512 + \
\(2271449403078125\ c1\^4\ c2\^5\)\/3584 - \(2689378265671875\ c1\^5\ c2\^5\)\
\/896 + \(3806609801484375\ c1\^6\ c2\^5\)\/448 - \(5769630917578125\ c1\^7\ \
c2\^5\)\/448 + \(1799623353515625\ c1\^8\ c2\^5\)\/224 + \(11023412952266075\ \
c2\^6\)\/94058496 - \(15882376167869125\ c1\ c2\^6\)\/5225472 + \
\(62291223823971875\ c1\^2\ c2\^6\)\/1161216 - \(18878932318259375\ c1\^3\ c2\
\^6\)\/32256 + \(13443069926328125\ c1\^4\ c2\^6\)\/3584 - \(3198944306953125\
\ c1\^5\ c2\^6\)\/224 + \(28628237942578125\ c1\^6\ c2\^6\)\/896 - \
\(8719032216796875\ c1\^7\ c2\^6\)\/224 + \(639248994140625\ c1\^8\ \
c2\^6\)\/32 + \(463590425804375\ c2\^7\)\/1741824 - \(3436963501653125\ c1\ \
c2\^7\)\/193536 + \(482332488203125\ c1\^2\ c2\^7\)\/1536 - \(691422433828125\
\ c1\^3\ c2\^7\)\/256 + \(1714422849609375\ c1\^4\ c2\^7\)\/128 - \
\(2591658123046875\ c1\^5\ c2\^7\)\/64 + \(2370310751953125\ c1\^6\ \
c2\^7\)\/32 - \(8471955322265625\ c1\^7\ c2\^7\)\/112 + \(1859697509765625\ \
c1\^8\ c2\^7\)\/56 + \(1563270040503125\ c2\^8\)\/516096 - \(269529317328125\ \
c1\ c2\^8\)\/3584 + \(418235147578125\ c1\^2\ c2\^8\)\/512 - \
\(648985573828125\ c1\^3\ c2\^8\)\/128 + \(5035232900390625\ c1\^4\ \
c2\^8\)\/256 - \(1562658486328125\ c1\^5\ c2\^8\)\/32 + \(2424814892578125\ \
c1\^6\ c2\^8\)\/32 - \(3762643798828125\ c1\^7\ c2\^8\)\/56 + \
\(5838585205078125\ c1\^8\ c2\^8\)\/224\)], "Output",
  CellLabel->"Out[75]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dc1 = D[meritFunction,c1]", "Input",
  CellLabel->"In[76]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[BoxData[
    \(\(-\(8630209\/38400\)\) + \(8811546167\ c1\)\/448000 - \(47534104827\ \
c1\^2\)\/89600 + \(5534665929\ c1\^3\)\/1120 - \(165483506655\ c1\^4\)\/7168 \
+ \(1941882559965\ c1\^5\)\/7168 - \(11155832325\ c1\^6\)\/64 + \
\(31352959666125\ c1\^7\)\/7168 - \(765076197961\ c2\)\/36288000 + \
\(23372228129\ c1\ c2\)\/19200 - \(88527150261\ c1\^2\ c2\)\/4480 + \
\(224966885553\ c1\^3\ c2\)\/1792 - \(8932994277975\ c1\^4\ c2\)\/7168 + \
\(2112569993025\ c1\^5\ c2\)\/448 - \(20170970274375\ c1\^6\ c2\)\/1024 + \
\(33594267796875\ c1\^7\ c2\)\/448 - \(20605878091867\ c2\^2\)\/32659200 + \
\(1179668318711\ c1\ c2\^2\)\/51840 - \(693823511411\ c1\^2\ c2\^2\)\/2688 + \
\(10050522993905\ c1\^3\ c2\^2\)\/3584 - \(17938275181875\ c1\^4\ \
c2\^2\)\/1024 + \(581473024727625\ c1\^5\ c2\^2\)\/7168 - \(180088418863125\ \
c1\^6\ c2\^2\)\/512 + \(42609040790625\ c1\^7\ c2\^2\)\/64 - \(25056690243373\
\ c2\^3\)\/3265920 + \(246343020685\ c1\ c2\^3\)\/1134 - \(41202259097225\ c1\
\^2\ c2\^3\)\/10752 + \(61675184754625\ c1\^3\ c2\^3\)\/1792 - \
\(1518997240108125\ c1\^4\ c2\^3\)\/7168 + \(1954416151108125\ c1\^5\ c2\^3\)\
\/1792 - \(873560187421875\ c1\^6\ c2\^3\)\/256 + \(466896649921875\ c1\^7\ \
c2\^3\)\/112 - \(109573523754215\ c2\^4\)\/1741824 + \(514226287860895\ c1\ \
c2\^4\)\/193536 - \(19371732084925\ c1\^2\ c2\^4\)\/512 + \(2328575367204375\ \
c1\^3\ c2\^4\)\/7168 - \(7644852868696875\ c1\^4\ c2\^4\)\/3584 + \
\(16547374477546875\ c1\^5\ c2\^4\)\/1792 - \(2711369369671875\ c1\^6\ \
c2\^4\)\/128 + \(4282530262734375\ c1\^7\ c2\^4\)\/224 - \(3471452792609575\ \
c2\^5\)\/5225472 + \(2760340174365125\ c1\ c2\^5\)\/145152 - \
\(5769695677095625\ c1\^2\ c2\^5\)\/21504 + \(2271449403078125\ c1\^3\ \
c2\^5\)\/896 - \(13446891328359375\ c1\^4\ c2\^5\)\/896 + \(11419829404453125\
\ c1\^5\ c2\^5\)\/224 - \(5769630917578125\ c1\^6\ c2\^5\)\/64 + \
\(1799623353515625\ c1\^7\ c2\^5\)\/28 - \(15882376167869125\ \
c2\^6\)\/5225472 + \(62291223823971875\ c1\ c2\^6\)\/580608 - \
\(18878932318259375\ c1\^2\ c2\^6\)\/10752 + \(13443069926328125\ c1\^3\ \
c2\^6\)\/896 - \(15994721534765625\ c1\^4\ c2\^6\)\/224 + \(85884713827734375\
\ c1\^5\ c2\^6\)\/448 - \(8719032216796875\ c1\^6\ c2\^6\)\/32 + \
\(639248994140625\ c1\^7\ c2\^6\)\/4 - \(3436963501653125\ c2\^7\)\/193536 + \
\(482332488203125\ c1\ c2\^7\)\/768 - \(2074267301484375\ c1\^2\ c2\^7\)\/256 \
+ \(1714422849609375\ c1\^3\ c2\^7\)\/32 - \(12958290615234375\ c1\^4\ \
c2\^7\)\/64 + \(7110932255859375\ c1\^5\ c2\^7\)\/16 - \(8471955322265625\ c1\
\^6\ c2\^7\)\/16 + \(1859697509765625\ c1\^7\ c2\^7\)\/7 - \(269529317328125\ \
c2\^8\)\/3584 + \(418235147578125\ c1\ c2\^8\)\/256 - \(1946956721484375\ \
c1\^2\ c2\^8\)\/128 + \(5035232900390625\ c1\^3\ c2\^8\)\/64 - \
\(7813292431640625\ c1\^4\ c2\^8\)\/32 + \(7274444677734375\ c1\^5\ \
c2\^8\)\/16 - \(3762643798828125\ c1\^6\ c2\^8\)\/8 + \(5838585205078125\ \
c1\^7\ c2\^8\)\/28\)], "Output",
  CellLabel->"Out[76]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dc2 = D[meritFunction,c2]", "Input",
  CellLabel->"In[77]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[BoxData[
    \(26892241\/115200 - \(765076197961\ c1\)\/36288000 + \(23372228129\ \
c1\^2\)\/38400 - \(29509050087\ c1\^3\)\/4480 + \(224966885553\ c1\^4\)\/7168 \
- \(1786598855595\ c1\^5\)\/7168 + \(704189997675\ c1\^6\)\/896 - \
\(20170970274375\ c1\^7\)\/7168 + \(33594267796875\ c1\^8\)\/3584 + \
\(61871970916463\ c2\)\/2939328000 - \(20605878091867\ c1\ c2\)\/16329600 + \
\(1179668318711\ c1\^2\ c2\)\/51840 - \(693823511411\ c1\^3\ c2\)\/4032 + \
\(10050522993905\ c1\^4\ c2\)\/7168 - \(3587655036375\ c1\^5\ c2\)\/512 + \
\(193824341575875\ c1\^6\ c2\)\/7168 - \(180088418863125\ c1\^7\ c2\)\/1792 + \
\(42609040790625\ c1\^8\ c2\)\/256 + \(57939265257631\ c2\^2\)\/97977600 - \
\(25056690243373\ c1\ c2\^2\)\/1088640 + \(246343020685\ c1\^2\ c2\^2\)\/756 \
- \(41202259097225\ c1\^3\ c2\^2\)\/10752 + \(185025554263875\ c1\^4\ c2\^2\)\
\/7168 - \(911398344064875\ c1\^5\ c2\^2\)\/7168 + \(1954416151108125\ c1\^6\ \
c2\^2\)\/3584 - \(2620680562265625\ c1\^7\ c2\^2\)\/1792 + \(1400689949765625\
\ c1\^8\ c2\^2\)\/896 + \(33835684341709\ c2\^3\)\/4898880 - \
\(109573523754215\ c1\ c2\^3\)\/435456 + \(514226287860895\ c1\^2\ \
c2\^3\)\/96768 - \(19371732084925\ c1\^3\ c2\^3\)\/384 + \(2328575367204375\ \
c1\^4\ c2\^3\)\/7168 - \(1528970573739375\ c1\^5\ c2\^3\)\/896 + \
\(5515791492515625\ c1\^6\ c2\^3\)\/896 - \(2711369369671875\ c1\^7\ \
c2\^3\)\/224 + \(4282530262734375\ c1\^8\ c2\^3\)\/448 + \(3217295143115675\ \
c2\^4\)\/47029248 - \(17357263963047875\ c1\ c2\^4\)\/5225472 + \
\(13801700871825625\ c1\^2\ c2\^4\)\/290304 - \(28848478385478125\ c1\^3\ \
c2\^4\)\/64512 + \(11357247015390625\ c1\^4\ c2\^4\)\/3584 - \
\(13446891328359375\ c1\^5\ c2\^4\)\/896 + \(19033049007421875\ c1\^6\ \
c2\^4\)\/448 - \(28848154587890625\ c1\^7\ c2\^4\)\/448 + \(8998116767578125\ \
c1\^8\ c2\^4\)\/224 + \(11023412952266075\ c2\^5\)\/15676416 - \
\(15882376167869125\ c1\ c2\^5\)\/870912 + \(62291223823971875\ c1\^2\ \
c2\^5\)\/193536 - \(18878932318259375\ c1\^3\ c2\^5\)\/5376 + \
\(40329209778984375\ c1\^4\ c2\^5\)\/1792 - \(9596832920859375\ c1\^5\ \
c2\^5\)\/112 + \(85884713827734375\ c1\^6\ c2\^5\)\/448 - \(26157096650390625\
\ c1\^7\ c2\^5\)\/112 + \(1917746982421875\ c1\^8\ c2\^5\)\/16 + \
\(463590425804375\ c2\^6\)\/248832 - \(3436963501653125\ c1\ c2\^6\)\/27648 + \
\(3376327417421875\ c1\^2\ c2\^6\)\/1536 - \(4839957036796875\ c1\^3\ c2\^6\)\
\/256 + \(12000959947265625\ c1\^4\ c2\^6\)\/128 - \(18141606861328125\ c1\^5\
\ c2\^6\)\/64 + \(16592175263671875\ c1\^6\ c2\^6\)\/32 - \(8471955322265625\ \
c1\^7\ c2\^6\)\/16 + \(1859697509765625\ c1\^8\ c2\^6\)\/8 + \
\(1563270040503125\ c2\^7\)\/64512 - \(269529317328125\ c1\ c2\^7\)\/448 + \
\(418235147578125\ c1\^2\ c2\^7\)\/64 - \(648985573828125\ c1\^3\ c2\^7\)\/16 \
+ \(5035232900390625\ c1\^4\ c2\^7\)\/32 - \(1562658486328125\ c1\^5\ c2\^7\)\
\/4 + \(2424814892578125\ c1\^6\ c2\^7\)\/4 - \(3762643798828125\ c1\^7\ \
c2\^7\)\/7 + \(5838585205078125\ c1\^8\ c2\^7\)\/28\)], "Output",
  CellLabel->"Out[77]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Show[{Plot3D[Dc1,{c1,0,.05},{c2,-.05,0},ColorFunction->(Red&), \
PlotPoints->50],
\tPlot3D[Dc2,{c1,0,.05},{c2,-.05,0},ColorFunction->(Green&), PlotPoints->50],
\tPlot3D[0,{c1,0,.05},{c2,-.05,0},ColorFunction->(Blue&), PlotPoints->50]},
\tViewPoint->{-1.309, -1.983, 2.409}];\
\>", "Input",
  CellLabel->"In[78]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -23.848 -9 ]
[.14598 .19958 .15205 0 ]
[.27013 .15073 -22.8472 -9 ]
[.27013 .15073 1.15281 0 ]
[.40046 .09948 -21.8464 -9 ]
[.40046 .09948 2.15358 0 ]
[.53743 .04564 -20.8457 -9 ]
[.53743 .04564 3.15434 0 ]
[.68156 -0.01098 -19.8449 -9 ]
[.68156 -0.01098 4.1551 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 30 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 30 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 30 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 30 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 30 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02067 .28667 -24 -2.76053 ]
[.02067 .28667 0 6.23947 ]
[.01032 .35156 -6 -2.81549 ]
[.01032 .35156 0 6.18451 ]
[-0.00048 .41922 -18 -2.87304 ]
[-0.00048 .41922 0 6.12696 ]
[-0.01174 .48985 -18 -2.93338 ]
[-0.01174 .48985 0 6.06662 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.01)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.02)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.03)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.04)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.05)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06033 .24606 m
.06319 .24877 L
s
.08372 .23691 m
.08655 .23964 L
s
.10732 .22766 m
.11013 .23042 L
s
.13115 .21833 m
.13394 .22111 L
s
.17948 .19941 m
.18222 .20223 L
s
.20399 .18981 m
.2067 .19266 L
s
.22873 .18012 m
.23142 .183 L
s
.25371 .17034 m
.25638 .17324 L
s
.3044 .15049 m
.30701 .15344 L
s
.33011 .14043 m
.3327 .14339 L
s
.35608 .13026 m
.35864 .13325 L
s
.3823 .11999 m
.38483 .12301 L
s
.43553 .09915 m
.43799 .10222 L
s
.46254 .08857 m
.46497 .09167 L
s
.48982 .07789 m
.49222 .08101 L
s
.51738 .0671 m
.51975 .07024 L
s
.57333 .04519 m
.57563 .04838 L
s
.60174 .03407 m
.60401 .03728 L
s
.63044 .02283 m
.63267 .02607 L
s
.65944 .01147 m
.66163 .01474 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-0.05)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(-0.04)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(-0.03)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(-0.02)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(-0.01)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70252 .02109 m
.69885 .02251 L
s
.71605 .04178 m
.71237 .04318 L
s
.72932 .06208 m
.72564 .06347 L
s
.74235 .08201 m
.73866 .08339 L
s
.7677 .12078 m
.764 .12213 L
s
.78003 .13965 m
.77633 .14098 L
s
.79214 .15817 m
.78843 .1595 L
s
.80404 .17637 m
.80033 .17768 L
s
.82721 .21182 m
.82349 .21311 L
s
.8385 .22909 m
.83478 .23037 L
s
.8496 .24606 m
.84587 .24733 L
s
.86051 .26275 m
.85677 .264 L
s
.88178 .29529 m
.87804 .29651 L
s
.89215 .31115 m
.88841 .31237 L
s
.90235 .32676 m
.89861 .32797 L
s
.91239 .34211 m
.90864 .34331 L
s
.93198 .37208 m
.92823 .37326 L
s
.94155 .38671 m
.93779 .38788 L
s
.95096 .40111 m
.9472 .40226 L
s
.96022 .41528 m
.95646 .41643 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03291 .28194 m
.03903 .27957 L
s
[(-100)] .02067 .28667 1 -0.38655 Mshowa
.02261 .34696 m
.02875 .34466 L
s
[(0)] .01032 .35156 1 -0.37434 Mshowa
.01186 .41476 m
.01803 .41253 L
s
[(100)] -0.00048 .41922 1 -0.36155 Mshowa
.00065 .48553 m
.00685 .48337 L
s
[(200)] -0.01174 .48985 1 -0.34814 Mshowa
.125 Mabswid
.03089 .29473 m
.03456 .29331 L
s
.02884 .30762 m
.03252 .30622 L
s
.02678 .32063 m
.03046 .31923 L
s
.0247 .33374 m
.02839 .33235 L
s
.0205 .36029 m
.02419 .35892 L
s
.01837 .37374 m
.02206 .37237 L
s
.01622 .3873 m
.01991 .38594 L
s
.01405 .40097 m
.01775 .39962 L
s
.00966 .42867 m
.01336 .42734 L
s
.00744 .4427 m
.01114 .44138 L
s
.00519 .45686 m
.00891 .45554 L
s
.00293 .47113 m
.00665 .46983 L
s
.03492 .26925 m
.03859 .26782 L
s
.03692 .25667 m
.04058 .25523 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
1 0 0 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Metetra
1 0 0 r
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Metetra
1 0 0 r
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Metetra
1 0 0 r
.43059 .58361 .43673 .58949 .44729 .58631 .44109 .5837 Metetra
1 0 0 r
.44109 .5837 .44729 .58631 .45784 .58594 .45155 .58882 Metetra
1 0 0 r
.45155 .58882 .45784 .58594 .46835 .59112 .46212 .59344 Metetra
1 0 0 r
.46212 .59344 .46835 .59112 .47897 .59581 .47278 .59759 Metetra
1 0 0 r
.47278 .59759 .47897 .59581 .48968 .60001 .48354 .60126 Metetra
1 0 0 r
.48354 .60126 .48968 .60001 .50048 .60373 .49438 .60446 Metetra
1 0 0 r
.49438 .60446 .50048 .60373 .51138 .60699 .50532 .60721 Metetra
1 0 0 r
.50532 .60721 .51138 .60699 .52236 .60978 .51634 .60951 Metetra
1 0 0 r
.51634 .60951 .52236 .60978 .53342 .61212 .52744 .61138 Metetra
1 0 0 r
.52744 .61138 .53342 .61212 .54456 .61403 .53861 .61282 Metetra
1 0 0 r
.53861 .61282 .54456 .61403 .55577 .6155 .54986 .61384 Metetra
1 0 0 r
.54986 .61384 .55577 .6155 .56706 .61656 .56118 .61447 Metetra
1 0 0 r
.56118 .61447 .56706 .61656 .57841 .61721 .57257 .6147 Metetra
1 0 0 r
.57257 .6147 .57841 .61721 .58983 .61746 .58401 .61455 Metetra
1 0 0 r
.58401 .61455 .58983 .61746 .60131 .61734 .59552 .61404 Metetra
1 0 0 r
.59552 .61404 .60131 .61734 .61285 .61684 .60709 .61318 Metetra
1 0 0 r
.60709 .61318 .61285 .61684 .62445 .61599 .61871 .61197 Metetra
1 0 0 r
.61871 .61197 .62445 .61599 .6361 .6148 .63039 .61044 Metetra
1 0 0 r
.63039 .61044 .6361 .6148 .6478 .61328 .64212 .6086 Metetra
1 0 0 r
.64212 .6086 .6478 .61328 .65955 .61145 .65389 .60647 Metetra
1 0 0 r
.65389 .60647 .65955 .61145 .67134 .60931 .66571 .60405 Metetra
1 0 0 r
.66571 .60405 .67134 .60931 .68319 .6069 .67758 .60136 Metetra
1 0 0 r
.67758 .60136 .68319 .6069 .69507 .60422 .68949 .59843 Metetra
1 0 0 r
.68949 .59843 .69507 .60422 .707 .60128 .70144 .59526 Metetra
1 0 0 r
.70144 .59526 .707 .60128 .71897 .59811 .71344 .59188 Metetra
1 0 0 r
.71344 .59188 .71897 .59811 .73097 .59473 .72547 .58829 Metetra
1 0 0 r
.72547 .58829 .73097 .59473 .74302 .59114 .73754 .58452 Metetra
1 0 0 r
.73754 .58452 .74302 .59114 .75511 .58737 .74965 .58059 Metetra
1 0 0 r
.74965 .58059 .75511 .58737 .76723 .58344 .7618 .57651 Metetra
1 0 0 r
.7618 .57651 .76723 .58344 .77939 .57936 .77399 .57231 Metetra
1 0 0 r
.77399 .57231 .77939 .57936 .79159 .57516 .78623 .568 Metetra
1 0 0 r
.78623 .568 .79159 .57516 .80384 .57085 .7985 .56359 Metetra
1 0 0 r
.7985 .56359 .80384 .57085 .81612 .56645 .81081 .55913 Metetra
1 0 0 r
.81081 .55913 .81612 .56645 .82844 .56199 .82317 .55461 Metetra
1 0 0 r
.82317 .55461 .82844 .56199 .84081 .55749 .83557 .55007 Metetra
1 0 0 r
.83557 .55007 .84081 .55749 .85322 .55296 .84802 .54553 Metetra
1 0 0 r
.84802 .54553 .85322 .55296 .86568 .54844 .86052 .541 Metetra
1 0 0 r
.86052 .541 .86568 .54844 .87819 .54394 .87308 .53652 Metetra
1 0 0 r
.87308 .53652 .87819 .54394 .89076 .53948 .88569 .53211 Metetra
1 0 0 r
.88569 .53211 .89076 .53948 .90338 .5351 .89836 .52779 Metetra
1 0 0 r
.89836 .52779 .90338 .5351 .91607 .53082 .9111 .52358 Metetra
1 0 0 r
.9111 .52358 .91607 .53082 .92883 .52666 .92391 .51952 Metetra
1 0 0 r
.92391 .51952 .92883 .52666 .94165 .52265 .9368 .51563 Metetra
1 0 0 r
.9368 .51563 .94165 .52265 .95456 .51882 .94977 .51194 Metetra
1 0 0 r
.94977 .51194 .95456 .51882 .96755 .51519 .96282 .50848 Metetra
1 0 0 r
.96282 .50848 .96755 .51519 .98063 .51181 .97598 .50527 Metetra
1 0 0 r
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Metetra
1 0 0 r
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Metetra
1 0 0 r
.41383 .58091 .42004 .5868 .43059 .58361 .42429 .5815 Metetra
1 0 0 r
.42429 .5815 .43059 .58361 .44109 .5837 .43469 .58655 Metetra
1 0 0 r
.43469 .58655 .44109 .5837 .45155 .58882 .44521 .59112 Metetra
1 0 0 r
.44521 .59112 .45155 .58882 .46212 .59344 .45582 .5952 Metetra
1 0 0 r
.45582 .5952 .46212 .59344 .47278 .59759 .46653 .59882 Metetra
1 0 0 r
.46653 .59882 .47278 .59759 .48354 .60126 .47733 .60197 Metetra
1 0 0 r
.47733 .60197 .48354 .60126 .49438 .60446 .48822 .60467 Metetra
1 0 0 r
.48822 .60467 .49438 .60446 .50532 .60721 .4992 .60693 Metetra
1 0 0 r
.4992 .60693 .50532 .60721 .51634 .60951 .51025 .60875 Metetra
1 0 0 r
.51025 .60875 .51634 .60951 .52744 .61138 .52139 .61016 Metetra
1 0 0 r
.52139 .61016 .52744 .61138 .53861 .61282 .5326 .61115 Metetra
1 0 0 r
.5326 .61115 .53861 .61282 .54986 .61384 .54389 .61174 Metetra
1 0 0 r
.54389 .61174 .54986 .61384 .56118 .61447 .55524 .61195 Metetra
1 0 0 r
.55524 .61195 .56118 .61447 .57257 .6147 .56666 .61178 Metetra
1 0 0 r
.56666 .61178 .57257 .6147 .58401 .61455 .57813 .61125 Metetra
1 0 0 r
.57813 .61125 .58401 .61455 .59552 .61404 .58967 .61037 Metetra
1 0 0 r
.58967 .61037 .59552 .61404 .60709 .61318 .60127 .60915 Metetra
1 0 0 r
.60127 .60915 .60709 .61318 .61871 .61197 .61292 .60761 Metetra
1 0 0 r
.61292 .60761 .61871 .61197 .63039 .61044 .62462 .60576 Metetra
1 0 0 r
.62462 .60576 .63039 .61044 .64212 .6086 .63638 .60362 Metetra
1 0 0 r
.63638 .60362 .64212 .6086 .65389 .60647 .64818 .60119 Metetra
1 0 0 r
.64818 .60119 .65389 .60647 .66571 .60405 .66003 .5985 Metetra
1 0 0 r
.66003 .5985 .66571 .60405 .67758 .60136 .67192 .59557 Metetra
1 0 0 r
.67192 .59557 .67758 .60136 .68949 .59843 .68385 .5924 Metetra
1 0 0 r
.68385 .5924 .68949 .59843 .70144 .59526 .69583 .58901 Metetra
1 0 0 r
.69583 .58901 .70144 .59526 .71344 .59188 .70785 .58543 Metetra
1 0 0 r
.70785 .58543 .71344 .59188 .72547 .58829 .71991 .58166 Metetra
1 0 0 r
.71991 .58166 .72547 .58829 .73754 .58452 .73201 .57773 Metetra
1 0 0 r
.73201 .57773 .73754 .58452 .74965 .58059 .74415 .57365 Metetra
1 0 0 r
.74415 .57365 .74965 .58059 .7618 .57651 .75633 .56944 Metetra
1 0 0 r
.75633 .56944 .7618 .57651 .77399 .57231 .76855 .56512 Metetra
1 0 0 r
.76855 .56512 .77399 .57231 .78623 .568 .78081 .56072 Metetra
1 0 0 r
.78081 .56072 .78623 .568 .7985 .56359 .79312 .55624 Metetra
1 0 0 r
.79312 .55624 .7985 .56359 .81081 .55913 .80546 .55172 Metetra
1 0 0 r
.80546 .55172 .81081 .55913 .82317 .55461 .81786 .54716 Metetra
1 0 0 r
.81786 .54716 .82317 .55461 .83557 .55007 .8303 .5426 Metetra
1 0 0 r
.8303 .5426 .83557 .55007 .84802 .54553 .84279 .53806 Metetra
1 0 0 r
.84279 .53806 .84802 .54553 .86052 .541 .85533 .53355 Metetra
1 0 0 r
.85533 .53355 .86052 .541 .87308 .53652 .86793 .52911 Metetra
1 0 0 r
.86793 .52911 .87308 .53652 .88569 .53211 .88059 .52475 Metetra
1 0 0 r
.88059 .52475 .88569 .53211 .89836 .52779 .89331 .5205 Metetra
1 0 0 r
.89331 .5205 .89836 .52779 .9111 .52358 .9061 .51639 Metetra
1 0 0 r
.9061 .51639 .9111 .52358 .92391 .51952 .91897 .51245 Metetra
1 0 0 r
.91897 .51245 .92391 .51952 .9368 .51563 .93192 .50869 Metetra
1 0 0 r
.93192 .50869 .9368 .51563 .94977 .51194 .94495 .50515 Metetra
1 0 0 r
.94495 .50515 .94977 .51194 .96282 .50848 .95808 .50187 Metetra
1 0 0 r
.95808 .50187 .96282 .50848 .97598 .50527 .97131 .49886 Metetra
1 0 0 r
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Metetra
1 0 0 r
.39701 .57819 .4033 .5841 .41383 .58091 .40742 .57935 Metetra
1 0 0 r
.40742 .57935 .41383 .58091 .42429 .5815 .41777 .58433 Metetra
1 0 0 r
.41777 .58433 .42429 .5815 .43469 .58655 .42823 .58883 Metetra
1 0 0 r
.42823 .58883 .43469 .58655 .44521 .59112 .4388 .59285 Metetra
1 0 0 r
.4388 .59285 .44521 .59112 .45582 .5952 .44946 .59641 Metetra
1 0 0 r
.44946 .59641 .45582 .5952 .46653 .59882 .46021 .59951 Metetra
1 0 0 r
.46021 .59951 .46653 .59882 .47733 .60197 .47106 .60216 Metetra
1 0 0 r
.47106 .60216 .47733 .60197 .48822 .60467 .48199 .60437 Metetra
1 0 0 r
.48199 .60437 .48822 .60467 .4992 .60693 .49301 .60615 Metetra
1 0 0 r
.49301 .60615 .4992 .60693 .51025 .60875 .50411 .60752 Metetra
1 0 0 r
.50411 .60752 .51025 .60875 .52139 .61016 .51528 .60848 Metetra
1 0 0 r
.51528 .60848 .52139 .61016 .5326 .61115 .52653 .60904 Metetra
1 0 0 r
.52653 .60904 .5326 .61115 .54389 .61174 .53785 .60922 Metetra
1 0 0 r
.53785 .60922 .54389 .61174 .55524 .61195 .54924 .60902 Metetra
1 0 0 r
.54924 .60902 .55524 .61195 .56666 .61178 .56068 .60847 Metetra
1 0 0 r
.56068 .60847 .56666 .61178 .57813 .61125 .5722 .60757 Metetra
1 0 0 r
.5722 .60757 .57813 .61125 .58967 .61037 .58377 .60633 Metetra
1 0 0 r
.58377 .60633 .58967 .61037 .60127 .60915 .59539 .60478 Metetra
1 0 0 r
.59539 .60478 .60127 .60915 .61292 .60761 .60707 .60292 Metetra
1 0 0 r
.60707 .60292 .61292 .60761 .62462 .60576 .6188 .60076 Metetra
1 0 0 r
.6188 .60076 .62462 .60576 .63638 .60362 .63058 .59833 Metetra
1 0 0 r
.63058 .59833 .63638 .60362 .64818 .60119 .64241 .59564 Metetra
1 0 0 r
.64241 .59564 .64818 .60119 .66003 .5985 .65428 .5927 Metetra
1 0 0 r
.65428 .5927 .66003 .5985 .67192 .59557 .6662 .58952 Metetra
1 0 0 r
.6662 .58952 .67192 .59557 .68385 .5924 .67817 .58613 Metetra
1 0 0 r
.67817 .58613 .68385 .5924 .69583 .58901 .69017 .58255 Metetra
1 0 0 r
.69017 .58255 .69583 .58901 .70785 .58543 .70222 .57878 Metetra
1 0 0 r
.70222 .57878 .70785 .58543 .71991 .58166 .7143 .57484 Metetra
1 0 0 r
.7143 .57484 .71991 .58166 .73201 .57773 .72643 .57076 Metetra
1 0 0 r
.72643 .57076 .73201 .57773 .74415 .57365 .7386 .56655 Metetra
1 0 0 r
.7386 .56655 .74415 .57365 .75633 .56944 .75081 .56223 Metetra
1 0 0 r
.75081 .56223 .75633 .56944 .76855 .56512 .76306 .55782 Metetra
1 0 0 r
.76306 .55782 .76855 .56512 .78081 .56072 .77535 .55334 Metetra
1 0 0 r
.77535 .55334 .78081 .56072 .79312 .55624 .78769 .5488 Metetra
1 0 0 r
.78769 .5488 .79312 .55624 .80546 .55172 .80007 .54424 Metetra
1 0 0 r
.80007 .54424 .80546 .55172 .81786 .54716 .8125 .53966 Metetra
1 0 0 r
.8125 .53966 .81786 .54716 .8303 .5426 .82498 .5351 Metetra
1 0 0 r
.82498 .5351 .8303 .5426 .84279 .53806 .83751 .53057 Metetra
1 0 0 r
.83751 .53057 .84279 .53806 .85533 .53355 .8501 .52609 Metetra
1 0 0 r
.8501 .52609 .85533 .53355 .86793 .52911 .86275 .5217 Metetra
1 0 0 r
.86275 .5217 .86793 .52911 .88059 .52475 .87546 .51742 Metetra
1 0 0 r
.87546 .51742 .88059 .52475 .89331 .5205 .88823 .51326 Metetra
1 0 0 r
.88823 .51326 .89331 .5205 .9061 .51639 .90108 .50926 Metetra
1 0 0 r
.90108 .50926 .9061 .51639 .91897 .51245 .91401 .50544 Metetra
1 0 0 r
.91401 .50544 .91897 .51245 .93192 .50869 .92702 .50184 Metetra
1 0 0 r
.92702 .50184 .93192 .50869 .94495 .50515 .94012 .49847 Metetra
1 0 0 r
.94012 .49847 .94495 .50515 .95808 .50187 .95332 .49537 Metetra
1 0 0 r
.95332 .49537 .95808 .50187 .97131 .49886 .96662 .49258 Metetra
1 0 0 r
.38014 .57546 .3865 .5814 .39701 .57819 .39049 .57725 Metetra
1 0 0 r
.39049 .57725 .39701 .57819 .40742 .57935 .40079 .58216 Metetra
1 0 0 r
.40079 .58216 .40742 .57935 .41777 .58433 .4112 .58658 Metetra
1 0 0 r
.4112 .58658 .41777 .58433 .42823 .58883 .42171 .59054 Metetra
1 0 0 r
.42171 .59054 .42823 .58883 .4388 .59285 .43232 .59404 Metetra
1 0 0 r
.43232 .59404 .4388 .59285 .44946 .59641 .44303 .59708 Metetra
1 0 0 r
.44303 .59708 .44946 .59641 .46021 .59951 .45384 .59968 Metetra
1 0 0 r
.45384 .59968 .46021 .59951 .47106 .60216 .46473 .60184 Metetra
1 0 0 r
.46473 .60184 .47106 .60216 .48199 .60437 .47571 .60358 Metetra
1 0 0 r
.47571 .60358 .48199 .60437 .49301 .60615 .48677 .6049 Metetra
1 0 0 r
.48677 .6049 .49301 .60615 .50411 .60752 .4979 .60582 Metetra
1 0 0 r
.4979 .60582 .50411 .60752 .51528 .60848 .50912 .60635 Metetra
1 0 0 r
.50912 .60635 .51528 .60848 .52653 .60904 .5204 .6065 Metetra
1 0 0 r
.5204 .6065 .52653 .60904 .53785 .60922 .53175 .60628 Metetra
1 0 0 r
.53175 .60628 .53785 .60922 .54924 .60902 .54317 .6057 Metetra
1 0 0 r
.54317 .6057 .54924 .60902 .56068 .60847 .55466 .60478 Metetra
1 0 0 r
.55466 .60478 .56068 .60847 .5722 .60757 .5662 .60352 Metetra
1 0 0 r
.5662 .60352 .5722 .60757 .58377 .60633 .5778 .60195 Metetra
1 0 0 r
.5778 .60195 .58377 .60633 .59539 .60478 .58945 .60007 Metetra
1 0 0 r
.58945 .60007 .59539 .60478 .60707 .60292 .60116 .59791 Metetra
1 0 0 r
.60116 .59791 .60707 .60292 .6188 .60076 .61292 .59547 Metetra
1 0 0 r
.61292 .59547 .6188 .60076 .63058 .59833 .62473 .59277 Metetra
1 0 0 r
.62473 .59277 .63058 .59833 .64241 .59564 .63659 .58982 Metetra
1 0 0 r
.63659 .58982 .64241 .59564 .65428 .5927 .64849 .58664 Metetra
1 0 0 r
.64849 .58664 .65428 .5927 .6662 .58952 .66043 .58325 Metetra
1 0 0 r
.66043 .58325 .6662 .58952 .67817 .58613 .67242 .57966 Metetra
1 0 0 r
.67242 .57966 .67817 .58613 .69017 .58255 .68446 .57588 Metetra
1 0 0 r
.68446 .57588 .69017 .58255 .70222 .57878 .69653 .57195 Metetra
1 0 0 r
.69653 .57195 .70222 .57878 .7143 .57484 .70865 .56786 Metetra
1 0 0 r
.70865 .56786 .7143 .57484 .72643 .57076 .7208 .56365 Metetra
1 0 0 r
.7208 .56365 .72643 .57076 .7386 .56655 .733 .55932 Metetra
1 0 0 r
.733 .55932 .7386 .56655 .75081 .56223 .74524 .55491 Metetra
1 0 0 r
.74524 .55491 .75081 .56223 .76306 .55782 .75752 .55041 Metetra
1 0 0 r
.75752 .55041 .76306 .55782 .77535 .55334 .76985 .54587 Metetra
1 0 0 r
.76985 .54587 .77535 .55334 .78769 .5488 .78222 .54129 Metetra
1 0 0 r
.78222 .54129 .78769 .5488 .80007 .54424 .79464 .5367 Metetra
1 0 0 r
.79464 .5367 .80007 .54424 .8125 .53966 .80711 .53212 Metetra
1 0 0 r
.80711 .53212 .8125 .53966 .82498 .5351 .81963 .52757 Metetra
1 0 0 r
.81963 .52757 .82498 .5351 .83751 .53057 .83221 .52307 Metetra
1 0 0 r
.83221 .52307 .83751 .53057 .8501 .52609 .84484 .51864 Metetra
1 0 0 r
.84484 .51864 .8501 .52609 .86275 .5217 .85753 .51432 Metetra
1 0 0 r
.85753 .51432 .86275 .5217 .87546 .51742 .87029 .51012 Metetra
1 0 0 r
.87029 .51012 .87546 .51742 .88823 .51326 .88312 .50607 Metetra
1 0 0 r
.88312 .50607 .88823 .51326 .90108 .50926 .89603 .50219 Metetra
1 0 0 r
.89603 .50219 .90108 .50926 .91401 .50544 .90902 .49852 Metetra
1 0 0 r
.90902 .49852 .91401 .50544 .92702 .50184 .92209 .49508 Metetra
1 0 0 r
.92209 .49508 .92702 .50184 .94012 .49847 .93527 .4919 Metetra
1 0 0 r
.93527 .4919 .94012 .49847 .95332 .49537 .94854 .48901 Metetra
1 0 0 r
.94854 .48901 .95332 .49537 .96662 .49258 .96193 .48645 Metetra
1 0 0 r
.37349 .57519 .38014 .57546 .39049 .57725 .38374 .58002 Metetra
1 0 0 r
.38374 .58002 .39049 .57725 .40079 .58216 .3941 .58438 Metetra
1 0 0 r
.3941 .58438 .40079 .58216 .4112 .58658 .40456 .58827 Metetra
1 0 0 r
.40456 .58827 .4112 .58658 .42171 .59054 .41513 .5917 Metetra
1 0 0 r
.41513 .5917 .42171 .59054 .43232 .59404 .42579 .59469 Metetra
1 0 0 r
.42579 .59469 .43232 .59404 .44303 .59708 .43655 .59723 Metetra
1 0 0 r
.43655 .59723 .44303 .59708 .45384 .59968 .4474 .59934 Metetra
1 0 0 r
.4474 .59934 .45384 .59968 .46473 .60184 .45834 .60103 Metetra
1 0 0 r
.45834 .60103 .46473 .60184 .47571 .60358 .46936 .60231 Metetra
1 0 0 r
.46936 .60231 .47571 .60358 .48677 .6049 .48046 .60319 Metetra
1 0 0 r
.48046 .60319 .48677 .6049 .4979 .60582 .49164 .60368 Metetra
1 0 0 r
.49164 .60368 .4979 .60582 .50912 .60635 .50289 .60379 Metetra
1 0 0 r
.50289 .60379 .50912 .60635 .5204 .6065 .51421 .60354 Metetra
1 0 0 r
.51421 .60354 .5204 .6065 .53175 .60628 .5256 .60294 Metetra
1 0 0 r
.5256 .60294 .53175 .60628 .54317 .6057 .53705 .60199 Metetra
1 0 0 r
.53705 .60199 .54317 .6057 .55466 .60478 .54857 .60071 Metetra
1 0 0 r
.54857 .60071 .55466 .60478 .5662 .60352 .56014 .59912 Metetra
1 0 0 r
.56014 .59912 .5662 .60352 .5778 .60195 .57178 .59723 Metetra
1 0 0 r
.57178 .59723 .5778 .60195 .58945 .60007 .58346 .59505 Metetra
1 0 0 r
.58346 .59505 .58945 .60007 .60116 .59791 .5952 .5926 Metetra
1 0 0 r
.5952 .5926 .60116 .59791 .61292 .59547 .60699 .58989 Metetra
1 0 0 r
.60699 .58989 .61292 .59547 .62473 .59277 .61883 .58693 Metetra
1 0 0 r
.61883 .58693 .62473 .59277 .63659 .58982 .63071 .58375 Metetra
1 0 0 r
.63071 .58375 .63659 .58982 .64849 .58664 .64264 .58035 Metetra
1 0 0 r
.64264 .58035 .64849 .58664 .66043 .58325 .65461 .57675 Metetra
1 0 0 r
.65461 .57675 .66043 .58325 .67242 .57966 .66663 .57298 Metetra
1 0 0 r
.66663 .57298 .67242 .57966 .68446 .57588 .67869 .56903 Metetra
1 0 0 r
.67869 .56903 .68446 .57588 .69653 .57195 .69079 .56495 Metetra
1 0 0 r
.69079 .56495 .69653 .57195 .70865 .56786 .70294 .56073 Metetra
1 0 0 r
.70294 .56073 .70865 .56786 .7208 .56365 .71513 .5564 Metetra
1 0 0 r
.71513 .5564 .7208 .56365 .733 .55932 .72736 .55197 Metetra
1 0 0 r
.72736 .55197 .733 .55932 .74524 .55491 .73963 .54747 Metetra
1 0 0 r
.73963 .54747 .74524 .55491 .75752 .55041 .75195 .54292 Metetra
1 0 0 r
.75195 .54292 .75752 .55041 .76985 .54587 .76431 .53833 Metetra
1 0 0 r
.76431 .53833 .76985 .54587 .78222 .54129 .77672 .53372 Metetra
1 0 0 r
.77672 .53372 .78222 .54129 .79464 .5367 .78917 .52912 Metetra
1 0 0 r
.78917 .52912 .79464 .5367 .80711 .53212 .80168 .52455 Metetra
1 0 0 r
.80168 .52455 .80711 .53212 .81963 .52757 .81424 .52002 Metetra
1 0 0 r
.81424 .52002 .81963 .52757 .83221 .52307 .82686 .51557 Metetra
1 0 0 r
.82686 .51557 .83221 .52307 .84484 .51864 .83954 .51121 Metetra
1 0 0 r
.83954 .51121 .84484 .51864 .85753 .51432 .85229 .50697 Metetra
1 0 0 r
.85229 .50697 .85753 .51432 .87029 .51012 .8651 .50287 Metetra
1 0 0 r
.8651 .50287 .87029 .51012 .88312 .50607 .87799 .49894 Metetra
1 0 0 r
.87799 .49894 .88312 .50607 .89603 .50219 .89095 .49521 Metetra
1 0 0 r
.89095 .49521 .89603 .50219 .90902 .49852 .90401 .4917 Metetra
1 0 0 r
.90401 .4917 .90902 .49852 .92209 .49508 .91715 .48844 Metetra
1 0 0 r
.91715 .48844 .92209 .49508 .93527 .4919 .93039 .48546 Metetra
1 0 0 r
.93039 .48546 .93527 .4919 .94854 .48901 .94375 .4828 Metetra
1 0 0 r
.94375 .4828 .94854 .48901 .96193 .48645 .95721 .48048 Metetra
1 0 0 r
.36662 .57793 .37349 .57519 .38374 .58002 .37693 .58221 Metetra
1 0 0 r
.37693 .58221 .38374 .58002 .3941 .58438 .38735 .58603 Metetra
1 0 0 r
.38735 .58603 .3941 .58438 .40456 .58827 .39787 .5894 Metetra
1 0 0 r
.39787 .5894 .40456 .58827 .41513 .5917 .40849 .59232 Metetra
1 0 0 r
.40849 .59232 .41513 .5917 .42579 .59469 .4192 .59481 Metetra
1 0 0 r
.4192 .59481 .42579 .59469 .43655 .59723 .43001 .59687 Metetra
1 0 0 r
.43001 .59687 .43655 .59723 .4474 .59934 .44091 .59851 Metetra
1 0 0 r
.44091 .59851 .4474 .59934 .45834 .60103 .45189 .59974 Metetra
1 0 0 r
.45189 .59974 .45834 .60103 .46936 .60231 .46296 .60058 Metetra
1 0 0 r
.46296 .60058 .46936 .60231 .48046 .60319 .4741 .60103 Metetra
1 0 0 r
.4741 .60103 .48046 .60319 .49164 .60368 .48532 .6011 Metetra
1 0 0 r
.48532 .6011 .49164 .60368 .50289 .60379 .49661 .60082 Metetra
1 0 0 r
.49661 .60082 .50289 .60379 .51421 .60354 .50796 .60018 Metetra
1 0 0 r
.50796 .60018 .51421 .60354 .5256 .60294 .51939 .59921 Metetra
1 0 0 r
.51939 .59921 .5256 .60294 .53705 .60199 .53088 .59791 Metetra
1 0 0 r
.53088 .59791 .53705 .60199 .54857 .60071 .54243 .5963 Metetra
1 0 0 r
.54243 .5963 .54857 .60071 .56014 .59912 .55403 .59439 Metetra
1 0 0 r
.55403 .59439 .56014 .59912 .57178 .59723 .5657 .5922 Metetra
1 0 0 r
.5657 .5922 .57178 .59723 .58346 .59505 .57741 .58973 Metetra
1 0 0 r
.57741 .58973 .58346 .59505 .5952 .5926 .58918 .587 Metetra
1 0 0 r
.58918 .587 .5952 .5926 .60699 .58989 .601 .58404 Metetra
1 0 0 r
.601 .58404 .60699 .58989 .61883 .58693 .61287 .58084 Metetra
1 0 0 r
.61287 .58084 .61883 .58693 .63071 .58375 .62478 .57744 Metetra
1 0 0 r
.62478 .57744 .63071 .58375 .64264 .58035 .63674 .57384 Metetra
1 0 0 r
.63674 .57384 .64264 .58035 .65461 .57675 .64874 .57005 Metetra
1 0 0 r
.64874 .57005 .65461 .57675 .66663 .57298 .66079 .56611 Metetra
1 0 0 r
.66079 .56611 .66663 .57298 .67869 .56903 .67288 .56201 Metetra
1 0 0 r
.67288 .56201 .67869 .56903 .69079 .56495 .68501 .55779 Metetra
1 0 0 r
.68501 .55779 .69079 .56495 .70294 .56073 .69719 .55345 Metetra
1 0 0 r
.69719 .55345 .70294 .56073 .71513 .5564 .7094 .54902 Metetra
1 0 0 r
.7094 .54902 .71513 .5564 .72736 .55197 .72167 .54451 Metetra
1 0 0 r
.72167 .54451 .72736 .55197 .73963 .54747 .73397 .53995 Metetra
1 0 0 r
.73397 .53995 .73963 .54747 .75195 .54292 .74632 .53535 Metetra
1 0 0 r
.74632 .53535 .75195 .54292 .76431 .53833 .75872 .53073 Metetra
1 0 0 r
.75872 .53073 .76431 .53833 .77672 .53372 .77117 .52611 Metetra
1 0 0 r
.77117 .52611 .77672 .53372 .78917 .52912 .78366 .52152 Metetra
1 0 0 r
.78366 .52152 .78917 .52912 .80168 .52455 .79622 .51697 Metetra
1 0 0 r
.79622 .51697 .80168 .52455 .81424 .52002 .80882 .51248 Metetra
1 0 0 r
.80882 .51248 .81424 .52002 .82686 .51557 .82149 .50809 Metetra
1 0 0 r
.82149 .50809 .82686 .51557 .83954 .51121 .83422 .50381 Metetra
1 0 0 r
.83422 .50381 .83954 .51121 .85229 .50697 .84701 .49967 Metetra
1 0 0 r
.84701 .49967 .85229 .50697 .8651 .50287 .85988 .49569 Metetra
1 0 0 r
.85988 .49569 .8651 .50287 .87799 .49894 .87282 .4919 Metetra
1 0 0 r
.87282 .4919 .87799 .49894 .89095 .49521 .88585 .48832 Metetra
1 0 0 r
.88585 .48832 .89095 .49521 .90401 .4917 .89897 .48499 Metetra
1 0 0 r
.89897 .48499 .90401 .4917 .91715 .48844 .91219 .48192 Metetra
1 0 0 r
.91219 .48192 .91715 .48844 .93039 .48546 .9255 .47917 Metetra
1 0 0 r
.9255 .47917 .93039 .48546 .94375 .4828 .93894 .47674 Metetra
1 0 0 r
.93894 .47674 .94375 .4828 .95721 .48048 .95249 .47468 Metetra
1 0 0 r
.3597 .58008 .36662 .57793 .37693 .58221 .37007 .58383 Metetra
1 0 0 r
.37007 .58383 .37693 .58221 .38735 .58603 .38054 .58713 Metetra
1 0 0 r
.38054 .58713 .38735 .58603 .39787 .5894 .39112 .58999 Metetra
1 0 0 r
.39112 .58999 .39787 .5894 .40849 .59232 .40179 .59242 Metetra
1 0 0 r
.40179 .59242 .40849 .59232 .4192 .59481 .41256 .59442 Metetra
1 0 0 r
.41256 .59442 .4192 .59481 .43001 .59687 .42341 .59601 Metetra
1 0 0 r
.42341 .59601 .43001 .59687 .44091 .59851 .43436 .59719 Metetra
1 0 0 r
.43436 .59719 .44091 .59851 .45189 .59974 .44539 .59798 Metetra
1 0 0 r
.44539 .59798 .45189 .59974 .46296 .60058 .45649 .59839 Metetra
1 0 0 r
.45649 .59839 .46296 .60058 .4741 .60103 .46768 .59843 Metetra
1 0 0 r
.46768 .59843 .4741 .60103 .48532 .6011 .47894 .59811 Metetra
1 0 0 r
.47894 .59811 .48532 .6011 .49661 .60082 .49027 .59744 Metetra
1 0 0 r
.49027 .59744 .49661 .60082 .50796 .60018 .50166 .59644 Metetra
1 0 0 r
.50166 .59644 .50796 .60018 .51939 .59921 .51312 .59511 Metetra
1 0 0 r
.51312 .59511 .51939 .59921 .53088 .59791 .52465 .59348 Metetra
1 0 0 r
.52465 .59348 .53088 .59791 .54243 .5963 .53623 .59155 Metetra
1 0 0 r
.53623 .59155 .54243 .5963 .55403 .59439 .54787 .58934 Metetra
1 0 0 r
.54787 .58934 .55403 .59439 .5657 .5922 .55956 .58685 Metetra
1 0 0 r
.55956 .58685 .5657 .5922 .57741 .58973 .57131 .58411 Metetra
1 0 0 r
.57131 .58411 .57741 .58973 .58918 .587 .58311 .58114 Metetra
1 0 0 r
.58311 .58114 .58918 .587 .601 .58404 .59496 .57793 Metetra
1 0 0 r
.59496 .57793 .601 .58404 .61287 .58084 .60686 .57452 Metetra
1 0 0 r
.60686 .57452 .61287 .58084 .62478 .57744 .6188 .57091 Metetra
1 0 0 r
.6188 .57091 .62478 .57744 .63674 .57384 .63079 .56712 Metetra
1 0 0 r
.63079 .56712 .63674 .57384 .64874 .57005 .64282 .56316 Metetra
1 0 0 r
.64282 .56316 .64874 .57005 .66079 .56611 .6549 .55906 Metetra
1 0 0 r
.6549 .55906 .66079 .56611 .67288 .56201 .66702 .55483 Metetra
1 0 0 r
.66702 .55483 .67288 .56201 .68501 .55779 .67918 .55049 Metetra
1 0 0 r
.67918 .55049 .68501 .55779 .69719 .55345 .69139 .54605 Metetra
1 0 0 r
.69139 .54605 .69719 .55345 .7094 .54902 .70364 .54153 Metetra
1 0 0 r
.70364 .54153 .7094 .54902 .72167 .54451 .71593 .53696 Metetra
1 0 0 r
.71593 .53696 .72167 .54451 .73397 .53995 .72827 .53235 Metetra
1 0 0 r
.72827 .53235 .73397 .53995 .74632 .53535 .74066 .52771 Metetra
1 0 0 r
.74066 .52771 .74632 .53535 .75872 .53073 .75309 .52308 Metetra
1 0 0 r
.75309 .52308 .75872 .53073 .77117 .52611 .76558 .51846 Metetra
1 0 0 r
.76558 .51846 .77117 .52611 .78366 .52152 .77812 .51389 Metetra
1 0 0 r
.77812 .51389 .78366 .52152 .79622 .51697 .79071 .50938 Metetra
1 0 0 r
.79071 .50938 .79622 .51697 .80882 .51248 .80336 .50496 Metetra
1 0 0 r
.80336 .50496 .80882 .51248 .82149 .50809 .81608 .50064 Metetra
1 0 0 r
.81608 .50064 .82149 .50809 .83422 .50381 .82885 .49646 Metetra
1 0 0 r
.82885 .49646 .83422 .50381 .84701 .49967 .8417 .49243 Metetra
1 0 0 r
.8417 .49243 .84701 .49967 .85988 .49569 .85463 .48858 Metetra
1 0 0 r
.85463 .48858 .85988 .49569 .87282 .4919 .86764 .48494 Metetra
1 0 0 r
.86764 .48494 .87282 .4919 .88585 .48832 .88073 .48154 Metetra
1 0 0 r
.88073 .48154 .88585 .48832 .89897 .48499 .89391 .4784 Metetra
1 0 0 r
.89391 .4784 .89897 .48499 .91219 .48192 .9072 .47555 Metetra
1 0 0 r
.9072 .47555 .91219 .48192 .9255 .47917 .9206 .47303 Metetra
1 0 0 r
.9206 .47303 .9255 .47917 .93894 .47674 .93411 .47086 Metetra
1 0 0 r
.93411 .47086 .93894 .47674 .95249 .47468 .94775 .46908 Metetra
1 0 0 r
.35272 .58167 .3597 .58008 .37007 .58383 .36315 .5849 Metetra
1 0 0 r
.36315 .5849 .37007 .58383 .38054 .58713 .37368 .58769 Metetra
1 0 0 r
.37368 .58769 .38054 .58713 .39112 .58999 .38431 .59005 Metetra
1 0 0 r
.38431 .59005 .39112 .58999 .40179 .59242 .39504 .592 Metetra
1 0 0 r
.39504 .592 .40179 .59242 .41256 .59442 .40585 .59353 Metetra
1 0 0 r
.40585 .59353 .41256 .59442 .42341 .59601 .41676 .59466 Metetra
1 0 0 r
.41676 .59466 .42341 .59601 .43436 .59719 .42775 .5954 Metetra
1 0 0 r
.42775 .5954 .43436 .59719 .44539 .59798 .43883 .59577 Metetra
1 0 0 r
.43883 .59577 .44539 .59798 .45649 .59839 .44998 .59577 Metetra
1 0 0 r
.44998 .59577 .45649 .59839 .46768 .59843 .4612 .59541 Metetra
1 0 0 r
.4612 .59541 .46768 .59843 .47894 .59811 .4725 .59471 Metetra
1 0 0 r
.4725 .59471 .47894 .59811 .49027 .59744 .48387 .59367 Metetra
1 0 0 r
.48387 .59367 .49027 .59744 .50166 .59644 .4953 .59232 Metetra
1 0 0 r
.4953 .59232 .50166 .59644 .51312 .59511 .5068 .59066 Metetra
1 0 0 r
.5068 .59066 .51312 .59511 .52465 .59348 .51836 .58871 Metetra
1 0 0 r
.51836 .58871 .52465 .59348 .53623 .59155 .52998 .58647 Metetra
1 0 0 r
.52998 .58647 .53623 .59155 .54787 .58934 .54165 .58397 Metetra
1 0 0 r
.54165 .58397 .54787 .58934 .55956 .58685 .55338 .58122 Metetra
1 0 0 r
.55338 .58122 .55956 .58685 .57131 .58411 .56516 .57823 Metetra
1 0 0 r
.56516 .57823 .57131 .58411 .58311 .58114 .57699 .57501 Metetra
1 0 0 r
.57699 .57501 .58311 .58114 .59496 .57793 .58887 .57158 Metetra
1 0 0 r
.58887 .57158 .59496 .57793 .60686 .57452 .60079 .56796 Metetra
1 0 0 r
.60079 .56796 .60686 .57452 .6188 .57091 .61276 .56417 Metetra
1 0 0 r
.61276 .56417 .6188 .57091 .63079 .56712 .62478 .5602 Metetra
1 0 0 r
.62478 .5602 .63079 .56712 .64282 .56316 .63685 .5561 Metetra
1 0 0 r
.63685 .5561 .64282 .56316 .6549 .55906 .64895 .55186 Metetra
1 0 0 r
.64895 .55186 .6549 .55906 .66702 .55483 .6611 .54751 Metetra
1 0 0 r
.6611 .54751 .66702 .55483 .67918 .55049 .6733 .54306 Metetra
1 0 0 r
.6733 .54306 .67918 .55049 .69139 .54605 .68554 .53854 Metetra
1 0 0 r
.68554 .53854 .69139 .54605 .70364 .54153 .69782 .53395 Metetra
1 0 0 r
.69782 .53395 .70364 .54153 .71593 .53696 .71015 .52933 Metetra
1 0 0 r
.71015 .52933 .71593 .53696 .72827 .53235 .72253 .52468 Metetra
1 0 0 r
.72253 .52468 .72827 .53235 .74066 .52771 .73495 .52003 Metetra
1 0 0 r
.73495 .52003 .74066 .52771 .75309 .52308 .74742 .5154 Metetra
1 0 0 r
.74742 .5154 .75309 .52308 .76558 .51846 .75995 .5108 Metetra
1 0 0 r
.75995 .5108 .76558 .51846 .77812 .51389 .77253 .50627 Metetra
1 0 0 r
.77253 .50627 .77812 .51389 .79071 .50938 .78517 .50181 Metetra
1 0 0 r
.78517 .50181 .79071 .50938 .80336 .50496 .79787 .49746 Metetra
1 0 0 r
.79787 .49746 .80336 .50496 .81608 .50064 .81063 .49324 Metetra
1 0 0 r
.81063 .49324 .81608 .50064 .82885 .49646 .82346 .48916 Metetra
1 0 0 r
.82346 .48916 .82885 .49646 .8417 .49243 .83637 .48527 Metetra
1 0 0 r
.83637 .48527 .8417 .49243 .85463 .48858 .84935 .48157 Metetra
1 0 0 r
.84935 .48157 .85463 .48858 .86764 .48494 .86242 .4781 Metetra
1 0 0 r
.86242 .4781 .86764 .48494 .88073 .48154 .87558 .47488 Metetra
1 0 0 r
.87558 .47488 .88073 .48154 .89391 .4784 .88883 .47195 Metetra
1 0 0 r
.88883 .47195 .89391 .4784 .9072 .47555 .9022 .46933 Metetra
1 0 0 r
.9022 .46933 .9072 .47555 .9206 .47303 .91567 .46706 Metetra
1 0 0 r
.91567 .46706 .9206 .47303 .93411 .47086 .92927 .46516 Metetra
1 0 0 r
.92927 .46516 .93411 .47086 .94775 .46908 .943 .46368 Metetra
1 0 0 r
.34569 .5827 .35272 .58167 .36315 .5849 .35617 .58542 Metetra
1 0 0 r
.35617 .58542 .36315 .5849 .37368 .58769 .36676 .58772 Metetra
1 0 0 r
.36676 .58772 .37368 .58769 .38431 .59005 .37745 .5896 Metetra
1 0 0 r
.37745 .5896 .38431 .59005 .39504 .592 .38823 .59107 Metetra
1 0 0 r
.38823 .59107 .39504 .592 .40585 .59353 .3991 .59215 Metetra
1 0 0 r
.3991 .59215 .40585 .59353 .41676 .59466 .41005 .59285 Metetra
1 0 0 r
.41005 .59285 .41676 .59466 .42775 .5954 .42109 .59316 Metetra
1 0 0 r
.42109 .59316 .42775 .5954 .43883 .59577 .43221 .59312 Metetra
1 0 0 r
.43221 .59312 .43883 .59577 .44998 .59577 .44341 .59272 Metetra
1 0 0 r
.44341 .59272 .44998 .59577 .4612 .59541 .45467 .59198 Metetra
1 0 0 r
.45467 .59198 .4612 .59541 .4725 .59471 .46601 .59092 Metetra
1 0 0 r
.46601 .59092 .4725 .59471 .48387 .59367 .47742 .58953 Metetra
1 0 0 r
.47742 .58953 .48387 .59367 .4953 .59232 .48889 .58784 Metetra
1 0 0 r
.48889 .58784 .4953 .59232 .5068 .59066 .50043 .58587 Metetra
1 0 0 r
.50043 .58587 .5068 .59066 .51836 .58871 .51202 .58361 Metetra
1 0 0 r
.51202 .58361 .51836 .58871 .52998 .58647 .52367 .58109 Metetra
1 0 0 r
.52367 .58109 .52998 .58647 .54165 .58397 .53538 .57832 Metetra
1 0 0 r
.53538 .57832 .54165 .58397 .55338 .58122 .54714 .57531 Metetra
1 0 0 r
.54714 .57531 .55338 .58122 .56516 .57823 .55895 .57208 Metetra
1 0 0 r
.55895 .57208 .56516 .57823 .57699 .57501 .57081 .56864 Metetra
1 0 0 r
.57081 .56864 .57699 .57501 .58887 .57158 .58272 .56501 Metetra
1 0 0 r
.58272 .56501 .58887 .57158 .60079 .56796 .59468 .5612 Metetra
1 0 0 r
.59468 .5612 .60079 .56796 .61276 .56417 .60668 .55723 Metetra
1 0 0 r
.60668 .55723 .61276 .56417 .62478 .5602 .61873 .55311 Metetra
1 0 0 r
.61873 .55311 .62478 .5602 .63685 .5561 .63082 .54887 Metetra
1 0 0 r
.63082 .54887 .63685 .5561 .64895 .55186 .64296 .54451 Metetra
1 0 0 r
.64296 .54451 .64895 .55186 .6611 .54751 .65514 .54005 Metetra
1 0 0 r
.65514 .54005 .6611 .54751 .6733 .54306 .66737 .53552 Metetra
1 0 0 r
.66737 .53552 .6733 .54306 .68554 .53854 .67964 .53093 Metetra
1 0 0 r
.67964 .53093 .68554 .53854 .69782 .53395 .69196 .52629 Metetra
1 0 0 r
.69196 .52629 .69782 .53395 .71015 .52933 .70433 .52163 Metetra
1 0 0 r
.70433 .52163 .71015 .52933 .72253 .52468 .71674 .51696 Metetra
1 0 0 r
.71674 .51696 .72253 .52468 .73495 .52003 .7292 .51231 Metetra
1 0 0 r
.7292 .51231 .73495 .52003 .74742 .5154 .74171 .5077 Metetra
1 0 0 r
.74171 .5077 .74742 .5154 .75995 .5108 .75428 .50314 Metetra
1 0 0 r
.75428 .50314 .75995 .5108 .77253 .50627 .76691 .49865 Metetra
1 0 0 r
.76691 .49865 .77253 .50627 .78517 .50181 .77959 .49427 Metetra
1 0 0 r
.77959 .49427 .78517 .50181 .79787 .49746 .79234 .49001 Metetra
1 0 0 r
.79234 .49001 .79787 .49746 .81063 .49324 .80515 .48589 Metetra
1 0 0 r
.80515 .48589 .81063 .49324 .82346 .48916 .81804 .48194 Metetra
1 0 0 r
.81804 .48194 .82346 .48916 .83637 .48527 .831 .47819 Metetra
1 0 0 r
.831 .47819 .83637 .48527 .84935 .48157 .84404 .47466 Metetra
1 0 0 r
.84404 .47466 .84935 .48157 .86242 .4781 .85718 .47137 Metetra
1 0 0 r
.85718 .47137 .86242 .4781 .87558 .47488 .8704 .46836 Metetra
1 0 0 r
.8704 .46836 .87558 .47488 .88883 .47195 .88373 .46566 Metetra
1 0 0 r
.88373 .46566 .88883 .47195 .9022 .46933 .89717 .46329 Metetra
1 0 0 r
.89717 .46329 .9022 .46933 .91567 .46706 .91073 .46128 Metetra
1 0 0 r
.91073 .46128 .91567 .46706 .92927 .46516 .92442 .45967 Metetra
1 0 0 r
.92442 .45967 .92927 .46516 .943 .46368 .93824 .4585 Metetra
1 0 0 r
.3386 .58318 .34569 .5827 .35617 .58542 .34915 .58541 Metetra
1 0 0 r
.34915 .58541 .35617 .58542 .36676 .58772 .3598 .58723 Metetra
1 0 0 r
.3598 .58723 .36676 .58772 .37745 .5896 .37054 .58864 Metetra
1 0 0 r
.37054 .58864 .37745 .5896 .38823 .59107 .38137 .58966 Metetra
1 0 0 r
.38137 .58966 .38823 .59107 .3991 .59215 .39229 .5903 Metetra
1 0 0 r
.39229 .5903 .3991 .59215 .41005 .59285 .40329 .59057 Metetra
1 0 0 r
.40329 .59057 .41005 .59285 .42109 .59316 .41438 .59048 Metetra
1 0 0 r
.41438 .59048 .42109 .59316 .43221 .59312 .42554 .59004 Metetra
1 0 0 r
.42554 .59004 .43221 .59312 .44341 .59272 .43678 .58927 Metetra
1 0 0 r
.43678 .58927 .44341 .59272 .45467 .59198 .44809 .58816 Metetra
1 0 0 r
.44809 .58816 .45467 .59198 .46601 .59092 .45947 .58675 Metetra
1 0 0 r
.45947 .58675 .46601 .59092 .47742 .58953 .47092 .58503 Metetra
1 0 0 r
.47092 .58503 .47742 .58953 .48889 .58784 .48243 .58302 Metetra
1 0 0 r
.48243 .58302 .48889 .58784 .50043 .58587 .494 .58074 Metetra
1 0 0 r
.494 .58074 .50043 .58587 .51202 .58361 .50563 .5782 Metetra
1 0 0 r
.50563 .5782 .51202 .58361 .52367 .58109 .51731 .57541 Metetra
1 0 0 r
.51731 .57541 .52367 .58109 .53538 .57832 .52905 .57238 Metetra
1 0 0 r
.52905 .57238 .53538 .57832 .54714 .57531 .54084 .56914 Metetra
1 0 0 r
.54084 .56914 .54714 .57531 .55895 .57208 .55269 .56568 Metetra
1 0 0 r
.55269 .56568 .55895 .57208 .57081 .56864 .56458 .56204 Metetra
1 0 0 r
.56458 .56204 .57081 .56864 .58272 .56501 .57652 .55822 Metetra
1 0 0 r
.57652 .55822 .58272 .56501 .59468 .5612 .58851 .55424 Metetra
1 0 0 r
.58851 .55424 .59468 .5612 .60668 .55723 .60055 .55012 Metetra
1 0 0 r
.60055 .55012 .60668 .55723 .61873 .55311 .61263 .54586 Metetra
1 0 0 r
.61263 .54586 .61873 .55311 .63082 .54887 .62475 .54149 Metetra
1 0 0 r
.62475 .54149 .63082 .54887 .64296 .54451 .63692 .53703 Metetra
1 0 0 r
.63692 .53703 .64296 .54451 .65514 .54005 .64914 .53248 Metetra
1 0 0 r
.64914 .53248 .65514 .54005 .66737 .53552 .6614 .52788 Metetra
1 0 0 r
.6614 .52788 .66737 .53552 .67964 .53093 .6737 .52323 Metetra
1 0 0 r
.6737 .52323 .67964 .53093 .69196 .52629 .68606 .51856 Metetra
1 0 0 r
.68606 .51856 .69196 .52629 .70433 .52163 .69846 .51388 Metetra
1 0 0 r
.69846 .51388 .70433 .52163 .71674 .51696 .71091 .50921 Metetra
1 0 0 r
.71091 .50921 .71674 .51696 .7292 .51231 .72341 .50457 Metetra
1 0 0 r
.72341 .50457 .7292 .51231 .74171 .5077 .73596 .49999 Metetra
1 0 0 r
.73596 .49999 .74171 .5077 .75428 .50314 .74858 .49548 Metetra
1 0 0 r
.74858 .49548 .75428 .50314 .76691 .49865 .76124 .49107 Metetra
1 0 0 r
.76124 .49107 .76691 .49865 .77959 .49427 .77398 .48677 Metetra
1 0 0 r
.77398 .48677 .77959 .49427 .79234 .49001 .78677 .48261 Metetra
1 0 0 r
.78677 .48261 .79234 .49001 .80515 .48589 .79964 .47862 Metetra
1 0 0 r
.79964 .47862 .80515 .48589 .81804 .48194 .81258 .47481 Metetra
1 0 0 r
.81258 .47481 .81804 .48194 .831 .47819 .8256 .47122 Metetra
1 0 0 r
.8256 .47122 .831 .47819 .84404 .47466 .83871 .46787 Metetra
1 0 0 r
.83871 .46787 .84404 .47466 .85718 .47137 .85191 .46479 Metetra
1 0 0 r
.85191 .46479 .85718 .47137 .8704 .46836 .86521 .462 Metetra
1 0 0 r
.86521 .462 .8704 .46836 .88373 .46566 .87861 .45953 Metetra
1 0 0 r
.87861 .45953 .88373 .46566 .89717 .46329 .89213 .45742 Metetra
1 0 0 r
.89213 .45742 .89717 .46329 .91073 .46128 .90577 .4557 Metetra
1 0 0 r
.90577 .4557 .91073 .46128 .92442 .45967 .91955 .4544 Metetra
1 0 0 r
.91955 .4544 .92442 .45967 .93824 .4585 .93347 .45356 Metetra
1 0 0 r
.33147 .58313 .3386 .58318 .34915 .58541 .34208 .58488 Metetra
1 0 0 r
.34208 .58488 .34915 .58541 .3598 .58723 .35278 .58623 Metetra
1 0 0 r
.35278 .58623 .3598 .58723 .37054 .58864 .36357 .58719 Metetra
1 0 0 r
.36357 .58719 .37054 .58864 .38137 .58966 .37446 .58778 Metetra
1 0 0 r
.37446 .58778 .38137 .58966 .39229 .5903 .38543 .588 Metetra
1 0 0 r
.38543 .588 .39229 .5903 .40329 .59057 .39648 .58786 Metetra
1 0 0 r
.39648 .58786 .40329 .59057 .41438 .59048 .40761 .58738 Metetra
1 0 0 r
.40761 .58738 .41438 .59048 .42554 .59004 .41882 .58656 Metetra
1 0 0 r
.41882 .58656 .42554 .59004 .43678 .58927 .4301 .58542 Metetra
1 0 0 r
.4301 .58542 .43678 .58927 .44809 .58816 .44146 .58397 Metetra
1 0 0 r
.44146 .58397 .44809 .58816 .45947 .58675 .45288 .58222 Metetra
1 0 0 r
.45288 .58222 .45947 .58675 .47092 .58503 .46436 .58018 Metetra
1 0 0 r
.46436 .58018 .47092 .58503 .48243 .58302 .47591 .57787 Metetra
1 0 0 r
.47591 .57787 .48243 .58302 .494 .58074 .48751 .57531 Metetra
1 0 0 r
.48751 .57531 .494 .58074 .50563 .5782 .49918 .57249 Metetra
1 0 0 r
.49918 .57249 .50563 .5782 .51731 .57541 .5109 .56945 Metetra
1 0 0 r
.5109 .56945 .51731 .57541 .52905 .57238 .52267 .56619 Metetra
1 0 0 r
.52267 .56619 .52905 .57238 .54084 .56914 .5345 .56272 Metetra
1 0 0 r
.5345 .56272 .54084 .56914 .55269 .56568 .54638 .55906 Metetra
1 0 0 r
.54638 .55906 .55269 .56568 .56458 .56204 .5583 .55523 Metetra
1 0 0 r
.5583 .55523 .56458 .56204 .57652 .55822 .57027 .55124 Metetra
1 0 0 r
.57027 .55124 .57652 .55822 .58851 .55424 .5823 .5471 Metetra
1 0 0 r
.5823 .5471 .58851 .55424 .60055 .55012 .59436 .54283 Metetra
1 0 0 r
.59436 .54283 .60055 .55012 .61263 .54586 .60647 .53846 Metetra
1 0 0 r
.60647 .53846 .61263 .54586 .62475 .54149 .61863 .53398 Metetra
1 0 0 r
.61863 .53398 .62475 .54149 .63692 .53703 .63084 .52943 Metetra
1 0 0 r
.63084 .52943 .63692 .53703 .64914 .53248 .64308 .52481 Metetra
1 0 0 r
.64308 .52481 .64914 .53248 .6614 .52788 .65538 .52015 Metetra
1 0 0 r
.65538 .52015 .6614 .52788 .6737 .52323 .66772 .51547 Metetra
1 0 0 r
.66772 .51547 .6737 .52323 .68606 .51856 .68011 .51077 Metetra
1 0 0 r
.68011 .51077 .68606 .51856 .69846 .51388 .69255 .50608 Metetra
1 0 0 r
.69255 .50608 .69846 .51388 .71091 .50921 .70504 .50143 Metetra
1 0 0 r
.70504 .50143 .71091 .50921 .72341 .50457 .71758 .49682 Metetra
1 0 0 r
.71758 .49682 .72341 .50457 .73596 .49999 .73017 .49229 Metetra
1 0 0 r
.73017 .49229 .73596 .49999 .74858 .49548 .74283 .48785 Metetra
1 0 0 r
.74283 .48785 .74858 .49548 .76124 .49107 .75554 .48352 Metetra
1 0 0 r
.75554 .48352 .76124 .49107 .77398 .48677 .76832 .47932 Metetra
1 0 0 r
.76832 .47932 .77398 .48677 .78677 .48261 .78117 .47529 Metetra
1 0 0 r
.78117 .47529 .78677 .48261 .79964 .47862 .79409 .47143 Metetra
1 0 0 r
.79409 .47143 .79964 .47862 .81258 .47481 .80709 .46778 Metetra
1 0 0 r
.80709 .46778 .81258 .47481 .8256 .47122 .82018 .46437 Metetra
1 0 0 r
.82018 .46437 .8256 .47122 .83871 .46787 .83335 .46122 Metetra
1 0 0 r
.83335 .46122 .83871 .46787 .85191 .46479 .84662 .45835 Metetra
1 0 0 r
.84662 .45835 .85191 .46479 .86521 .462 .85999 .4558 Metetra
1 0 0 r
.85999 .4558 .86521 .462 .87861 .45953 .87347 .45359 Metetra
1 0 0 r
.87347 .45359 .87861 .45953 .89213 .45742 .88707 .45176 Metetra
1 0 0 r
.88707 .45176 .89213 .45742 .90577 .4557 .9008 .45034 Metetra
1 0 0 r
.9008 .45034 .90577 .4557 .91955 .4544 .91467 .44937 Metetra
1 0 0 r
.91467 .44937 .91955 .4544 .93347 .45356 .92869 .44888 Metetra
1 0 0 r
.32429 .58255 .33147 .58313 .34208 .58488 .33495 .58384 Metetra
1 0 0 r
.33495 .58384 .34208 .58488 .35278 .58623 .34571 .58474 Metetra
1 0 0 r
.34571 .58474 .35278 .58623 .36357 .58719 .35656 .58527 Metetra
1 0 0 r
.35656 .58527 .36357 .58719 .37446 .58778 .3675 .58544 Metetra
1 0 0 r
.3675 .58544 .37446 .58778 .38543 .588 .37852 .58525 Metetra
1 0 0 r
.37852 .58525 .38543 .588 .39648 .58786 .38962 .58472 Metetra
1 0 0 r
.38962 .58472 .39648 .58786 .40761 .58738 .4008 .58386 Metetra
1 0 0 r
.4008 .58386 .40761 .58738 .41882 .58656 .41205 .58268 Metetra
1 0 0 r
.41205 .58268 .41882 .58656 .4301 .58542 .42338 .58119 Metetra
1 0 0 r
.42338 .58119 .4301 .58542 .44146 .58397 .43477 .5794 Metetra
1 0 0 r
.43477 .5794 .44146 .58397 .45288 .58222 .44623 .57734 Metetra
1 0 0 r
.44623 .57734 .45288 .58222 .46436 .58018 .45775 .575 Metetra
1 0 0 r
.45775 .575 .46436 .58018 .47591 .57787 .46934 .57241 Metetra
1 0 0 r
.46934 .57241 .47591 .57787 .48751 .57531 .48098 .56957 Metetra
1 0 0 r
.48098 .56957 .48751 .57531 .49918 .57249 .49268 .56651 Metetra
1 0 0 r
.49268 .56651 .49918 .57249 .5109 .56945 .50444 .56323 Metetra
1 0 0 r
.50444 .56323 .5109 .56945 .52267 .56619 .51624 .55974 Metetra
1 0 0 r
.51624 .55974 .52267 .56619 .5345 .56272 .5281 .55607 Metetra
1 0 0 r
.5281 .55607 .5345 .56272 .54638 .55906 .54001 .55222 Metetra
1 0 0 r
.54001 .55222 .54638 .55906 .5583 .55523 .55197 .54822 Metetra
1 0 0 r
.55197 .54822 .5583 .55523 .57027 .55124 .56398 .54407 Metetra
1 0 0 r
.56398 .54407 .57027 .55124 .5823 .5471 .57603 .53979 Metetra
1 0 0 r
.57603 .53979 .5823 .5471 .59436 .54283 .58813 .5354 Metetra
1 0 0 r
.58813 .5354 .59436 .54283 .60647 .53846 .60027 .53092 Metetra
1 0 0 r
.60027 .53092 .60647 .53846 .61863 .53398 .61246 .52635 Metetra
1 0 0 r
.61246 .52635 .61863 .53398 .63084 .52943 .6247 .52173 Metetra
1 0 0 r
.6247 .52173 .63084 .52943 .64308 .52481 .63698 .51705 Metetra
1 0 0 r
.63698 .51705 .64308 .52481 .65538 .52015 .64931 .51235 Metetra
1 0 0 r
.64931 .51235 .65538 .52015 .66772 .51547 .66169 .50764 Metetra
1 0 0 r
.66169 .50764 .66772 .51547 .68011 .51077 .67412 .50294 Metetra
1 0 0 r
.67412 .50294 .68011 .51077 .69255 .50608 .68659 .49827 Metetra
1 0 0 r
.68659 .49827 .69255 .50608 .70504 .50143 .69912 .49364 Metetra
1 0 0 r
.69912 .49364 .70504 .50143 .71758 .49682 .7117 .48908 Metetra
1 0 0 r
.7117 .48908 .71758 .49682 .73017 .49229 .72434 .48461 Metetra
1 0 0 r
.72434 .48461 .73017 .49229 .74283 .48785 .73704 .48025 Metetra
1 0 0 r
.73704 .48025 .74283 .48785 .75554 .48352 .74981 .47602 Metetra
1 0 0 r
.74981 .47602 .75554 .48352 .76832 .47932 .76264 .47194 Metetra
1 0 0 r
.76264 .47194 .76832 .47932 .78117 .47529 .77554 .46804 Metetra
1 0 0 r
.77554 .46804 .78117 .47529 .79409 .47143 .78852 .46435 Metetra
1 0 0 r
.78852 .46435 .79409 .47143 .80709 .46778 .80157 .46087 Metetra
1 0 0 r
.80157 .46087 .80709 .46778 .82018 .46437 .81472 .45765 Metetra
1 0 0 r
.81472 .45765 .82018 .46437 .83335 .46122 .82796 .45471 Metetra
1 0 0 r
.82796 .45471 .83335 .46122 .84662 .45835 .8413 .45208 Metetra
1 0 0 r
.8413 .45208 .84662 .45835 .85999 .4558 .85474 .44978 Metetra
1 0 0 r
.85474 .44978 .85999 .4558 .87347 .45359 .8683 .44785 Metetra
1 0 0 r
.8683 .44785 .87347 .45359 .88707 .45176 .88199 .44632 Metetra
1 0 0 r
.88199 .44632 .88707 .45176 .9008 .45034 .89581 .44522 Metetra
1 0 0 r
.89581 .44522 .9008 .45034 .91467 .44937 .90978 .44459 Metetra
1 0 0 r
.90978 .44459 .91467 .44937 .92869 .44888 .9239 .44447 Metetra
1 0 0 r
.31705 .58147 .32429 .58255 .33495 .58384 .32778 .58231 Metetra
1 0 0 r
.32778 .58231 .33495 .58384 .34571 .58474 .33859 .58278 Metetra
1 0 0 r
.33859 .58278 .34571 .58474 .35656 .58527 .3495 .58289 Metetra
1 0 0 r
.3495 .58289 .35656 .58527 .3675 .58544 .36048 .58265 Metetra
1 0 0 r
.36048 .58265 .3675 .58544 .37852 .58525 .37156 .58207 Metetra
1 0 0 r
.37156 .58207 .37852 .58525 .38962 .58472 .38271 .58116 Metetra
1 0 0 r
.38271 .58116 .38962 .58472 .4008 .58386 .39393 .57994 Metetra
1 0 0 r
.39393 .57994 .4008 .58386 .41205 .58268 .40523 .57841 Metetra
1 0 0 r
.40523 .57841 .41205 .58268 .42338 .58119 .4166 .57659 Metetra
1 0 0 r
.4166 .57659 .42338 .58119 .43477 .5794 .42803 .57449 Metetra
1 0 0 r
.42803 .57449 .43477 .5794 .44623 .57734 .43953 .57213 Metetra
1 0 0 r
.43953 .57213 .44623 .57734 .45775 .575 .45109 .56951 Metetra
1 0 0 r
.45109 .56951 .45775 .575 .46934 .57241 .46272 .56665 Metetra
1 0 0 r
.46272 .56665 .46934 .57241 .48098 .56957 .4744 .56356 Metetra
1 0 0 r
.4744 .56356 .48098 .56957 .49268 .56651 .48613 .56025 Metetra
1 0 0 r
.48613 .56025 .49268 .56651 .50444 .56323 .49792 .55675 Metetra
1 0 0 r
.49792 .55675 .50444 .56323 .51624 .55974 .50976 .55306 Metetra
1 0 0 r
.50976 .55306 .51624 .55974 .5281 .55607 .52166 .5492 Metetra
1 0 0 r
.52166 .5492 .5281 .55607 .54001 .55222 .5336 .54518 Metetra
1 0 0 r
.5336 .54518 .54001 .55222 .55197 .54822 .54559 .54102 Metetra
1 0 0 r
.54559 .54102 .55197 .54822 .56398 .54407 .55763 .53673 Metetra
1 0 0 r
.55763 .53673 .56398 .54407 .57603 .53979 .56971 .53233 Metetra
1 0 0 r
.56971 .53233 .57603 .53979 .58813 .5354 .58185 .52783 Metetra
1 0 0 r
.58185 .52783 .58813 .5354 .60027 .53092 .59402 .52326 Metetra
1 0 0 r
.59402 .52326 .60027 .53092 .61246 .52635 .60625 .51862 Metetra
1 0 0 r
.60625 .51862 .61246 .52635 .6247 .52173 .61852 .51394 Metetra
1 0 0 r
.61852 .51394 .6247 .52173 .63698 .51705 .63083 .50922 Metetra
1 0 0 r
.63083 .50922 .63698 .51705 .64931 .51235 .6432 .5045 Metetra
1 0 0 r
.6432 .5045 .64931 .51235 .66169 .50764 .65561 .49978 Metetra
1 0 0 r
.65561 .49978 .66169 .50764 .67412 .50294 .66808 .49509 Metetra
1 0 0 r
.66808 .49509 .67412 .50294 .68659 .49827 .68059 .49045 Metetra
1 0 0 r
.68059 .49045 .68659 .49827 .69912 .49364 .69316 .48586 Metetra
1 0 0 r
.69316 .48586 .69912 .49364 .7117 .48908 .70579 .48137 Metetra
1 0 0 r
.70579 .48137 .7117 .48908 .72434 .48461 .71847 .47698 Metetra
1 0 0 r
.71847 .47698 .72434 .48461 .73704 .48025 .73122 .47271 Metetra
1 0 0 r
.73122 .47271 .73704 .48025 .74981 .47602 .74403 .4686 Metetra
1 0 0 r
.74403 .4686 .74981 .47602 .76264 .47194 .75691 .46465 Metetra
1 0 0 r
.75691 .46465 .76264 .47194 .77554 .46804 .76987 .4609 Metetra
1 0 0 r
.76987 .4609 .77554 .46804 .78852 .46435 .7829 .45738 Metetra
1 0 0 r
.7829 .45738 .78852 .46435 .80157 .46087 .79602 .45409 Metetra
1 0 0 r
.79602 .45409 .80157 .46087 .81472 .45765 .80923 .45108 Metetra
1 0 0 r
.80923 .45108 .81472 .45765 .82796 .45471 .82254 .44837 Metetra
1 0 0 r
.82254 .44837 .82796 .45471 .8413 .45208 .83595 .44599 Metetra
1 0 0 r
.83595 .44599 .8413 .45208 .85474 .44978 .84947 .44396 Metetra
1 0 0 r
.84947 .44396 .85474 .44978 .8683 .44785 .86312 .44232 Metetra
1 0 0 r
.86312 .44232 .8683 .44785 .88199 .44632 .87689 .44111 Metetra
1 0 0 r
.87689 .44111 .88199 .44632 .89581 .44522 .8908 .44035 Metetra
1 0 0 r
.8908 .44035 .89581 .44522 .90978 .44459 .90487 .44008 Metetra
1 0 0 r
.90487 .44008 .90978 .44459 .9239 .44447 .9191 .44034 Metetra
1 0 0 r
.30978 .5799 .31705 .58147 .32778 .58231 .32056 .58031 Metetra
1 0 0 r
.32056 .58031 .32778 .58231 .33859 .58278 .33143 .58036 Metetra
1 0 0 r
.33143 .58036 .33859 .58278 .3495 .58289 .34238 .58006 Metetra
1 0 0 r
.34238 .58006 .3495 .58289 .36048 .58265 .35342 .57943 Metetra
1 0 0 r
.35342 .57943 .36048 .58265 .37156 .58207 .36454 .57847 Metetra
1 0 0 r
.36454 .57847 .37156 .58207 .38271 .58116 .37574 .57721 Metetra
1 0 0 r
.37574 .57721 .38271 .58116 .39393 .57994 .38701 .57564 Metetra
1 0 0 r
.38701 .57564 .39393 .57994 .40523 .57841 .39836 .57378 Metetra
1 0 0 r
.39836 .57378 .40523 .57841 .4166 .57659 .40977 .57165 Metetra
1 0 0 r
.40977 .57165 .4166 .57659 .42803 .57449 .42124 .56925 Metetra
1 0 0 r
.42124 .56925 .42803 .57449 .43953 .57213 .43278 .5666 Metetra
1 0 0 r
.43278 .5666 .43953 .57213 .45109 .56951 .44438 .56371 Metetra
1 0 0 r
.44438 .56371 .45109 .56951 .46272 .56665 .45604 .5606 Metetra
1 0 0 r
.45604 .5606 .46272 .56665 .4744 .56356 .46776 .55727 Metetra
1 0 0 r
.46776 .55727 .4744 .56356 .48613 .56025 .47953 .55375 Metetra
1 0 0 r
.47953 .55375 .48613 .56025 .49792 .55675 .49136 .55004 Metetra
1 0 0 r
.49136 .55004 .49792 .55675 .50976 .55306 .50323 .54616 Metetra
1 0 0 r
.50323 .54616 .50976 .55306 .52166 .5492 .51516 .54213 Metetra
1 0 0 r
.51516 .54213 .52166 .5492 .5336 .54518 .52714 .53795 Metetra
1 0 0 r
.52714 .53795 .5336 .54518 .54559 .54102 .53916 .53365 Metetra
1 0 0 r
.53916 .53365 .54559 .54102 .55763 .53673 .55123 .52924 Metetra
1 0 0 r
.55123 .52924 .55763 .53673 .56971 .53233 .56335 .52473 Metetra
1 0 0 r
.56335 .52473 .56971 .53233 .58185 .52783 .57551 .52014 Metetra
1 0 0 r
.57551 .52014 .58185 .52783 .59402 .52326 .58773 .51549 Metetra
1 0 0 r
.58773 .51549 .59402 .52326 .60625 .51862 .59998 .5108 Metetra
1 0 0 r
.59998 .5108 .60625 .51862 .61852 .51394 .61229 .50607 Metetra
1 0 0 r
.61229 .50607 .61852 .51394 .63083 .50922 .62464 .50133 Metetra
1 0 0 r
.62464 .50133 .63083 .50922 .6432 .5045 .63704 .4966 Metetra
1 0 0 r
.63704 .4966 .6432 .5045 .65561 .49978 .64949 .49189 Metetra
1 0 0 r
.64949 .49189 .65561 .49978 .66808 .49509 .66199 .48723 Metetra
1 0 0 r
.66199 .48723 .66808 .49509 .68059 .49045 .67455 .48263 Metetra
1 0 0 r
.67455 .48263 .68059 .49045 .69316 .48586 .68716 .4781 Metetra
1 0 0 r
.68716 .4781 .69316 .48586 .70579 .48137 .69983 .47368 Metetra
1 0 0 r
.69983 .47368 .70579 .48137 .71847 .47698 .71256 .46939 Metetra
1 0 0 r
.71256 .46939 .71847 .47698 .73122 .47271 .72535 .46524 Metetra
1 0 0 r
.72535 .46524 .73122 .47271 .74403 .4686 .73822 .46125 Metetra
1 0 0 r
.73822 .46125 .74403 .4686 .75691 .46465 .75115 .45746 Metetra
1 0 0 r
.75115 .45746 .75691 .46465 .76987 .4609 .76416 .45388 Metetra
1 0 0 r
.76416 .45388 .76987 .4609 .7829 .45738 .77726 .45054 Metetra
1 0 0 r
.77726 .45054 .7829 .45738 .79602 .45409 .79044 .44746 Metetra
1 0 0 r
.79044 .44746 .79602 .45409 .80923 .45108 .80372 .44468 Metetra
1 0 0 r
.80372 .44468 .80923 .45108 .82254 .44837 .81709 .44221 Metetra
1 0 0 r
.81709 .44221 .82254 .44837 .83595 .44599 .83058 .4401 Metetra
1 0 0 r
.83058 .4401 .83595 .44599 .84947 .44396 .84418 .43836 Metetra
1 0 0 r
.84418 .43836 .84947 .44396 .86312 .44232 .85791 .43703 Metetra
1 0 0 r
.85791 .43703 .86312 .44232 .87689 .44111 .87177 .43615 Metetra
1 0 0 r
.87177 .43615 .87689 .44111 .8908 .44035 .88578 .43575 Metetra
1 0 0 r
.88578 .43575 .8908 .44035 .90487 .44008 .89995 .43586 Metetra
1 0 0 r
.89995 .43586 .90487 .44008 .9191 .44034 .91429 .43653 Metetra
1 0 0 r
.30245 .57784 .30978 .5799 .32056 .58031 .31329 .57783 Metetra
1 0 0 r
.31329 .57783 .32056 .58031 .33143 .58036 .32421 .57748 Metetra
1 0 0 r
.32421 .57748 .33143 .58036 .34238 .58006 .33523 .5768 Metetra
1 0 0 r
.33523 .5768 .34238 .58006 .35342 .57943 .34632 .57579 Metetra
1 0 0 r
.34632 .57579 .35342 .57943 .36454 .57847 .35749 .57448 Metetra
1 0 0 r
.35749 .57448 .36454 .57847 .37574 .57721 .36873 .57287 Metetra
1 0 0 r
.36873 .57287 .37574 .57721 .38701 .57564 .38005 .57097 Metetra
1 0 0 r
.38005 .57097 .38701 .57564 .39836 .57378 .39143 .5688 Metetra
1 0 0 r
.39143 .5688 .39836 .57378 .40977 .57165 .40289 .56637 Metetra
1 0 0 r
.40289 .56637 .40977 .57165 .42124 .56925 .41441 .56369 Metetra
1 0 0 r
.41441 .56369 .42124 .56925 .43278 .5666 .42599 .56077 Metetra
1 0 0 r
.42599 .56077 .43278 .5666 .44438 .56371 .43762 .55763 Metetra
1 0 0 r
.43762 .55763 .44438 .56371 .45604 .5606 .44932 .55428 Metetra
1 0 0 r
.44932 .55428 .45604 .5606 .46776 .55727 .46108 .55074 Metetra
1 0 0 r
.46108 .55074 .46776 .55727 .47953 .55375 .47288 .54701 Metetra
1 0 0 r
.47288 .54701 .47953 .55375 .49136 .55004 .48474 .54311 Metetra
1 0 0 r
.48474 .54311 .49136 .55004 .50323 .54616 .49665 .53906 Metetra
1 0 0 r
.49665 .53906 .50323 .54616 .51516 .54213 .50861 .53487 Metetra
1 0 0 r
.50861 .53487 .51516 .54213 .52714 .53795 .52062 .53055 Metetra
1 0 0 r
.52062 .53055 .52714 .53795 .53916 .53365 .53268 .52613 Metetra
1 0 0 r
.53268 .52613 .53916 .53365 .55123 .52924 .54478 .52161 Metetra
1 0 0 r
.54478 .52161 .55123 .52924 .56335 .52473 .55694 .51701 Metetra
1 0 0 r
.55694 .51701 .56335 .52473 .57551 .52014 .56913 .51235 Metetra
1 0 0 r
.56913 .51235 .57551 .52014 .58773 .51549 .58138 .50764 Metetra
1 0 0 r
.58138 .50764 .58773 .51549 .59998 .5108 .59367 .5029 Metetra
1 0 0 r
.59367 .5029 .59998 .5108 .61229 .50607 .60601 .49815 Metetra
1 0 0 r
.60601 .49815 .61229 .50607 .62464 .50133 .6184 .4934 Metetra
1 0 0 r
.6184 .4934 .62464 .50133 .63704 .4966 .63084 .48868 Metetra
1 0 0 r
.63084 .48868 .63704 .4966 .64949 .49189 .64332 .48399 Metetra
1 0 0 r
.64332 .48399 .64949 .49189 .66199 .48723 .65587 .47937 Metetra
1 0 0 r
.65587 .47937 .66199 .48723 .67455 .48263 .66846 .47482 Metetra
1 0 0 r
.66846 .47482 .67455 .48263 .68716 .4781 .68112 .47038 Metetra
1 0 0 r
.68112 .47038 .68716 .4781 .69983 .47368 .69383 .46605 Metetra
1 0 0 r
.69383 .46605 .69983 .47368 .71256 .46939 .70661 .46187 Metetra
1 0 0 r
.70661 .46187 .71256 .46939 .72535 .46524 .71945 .45785 Metetra
1 0 0 r
.71945 .45785 .72535 .46524 .73822 .46125 .73236 .45401 Metetra
1 0 0 r
.73236 .45401 .73822 .46125 .75115 .45746 .74535 .45038 Metetra
1 0 0 r
.74535 .45038 .75115 .45746 .76416 .45388 .75842 .44699 Metetra
1 0 0 r
.75842 .44699 .76416 .45388 .77726 .45054 .77158 .44385 Metetra
1 0 0 r
.77158 .44385 .77726 .45054 .79044 .44746 .78482 .44099 Metetra
1 0 0 r
.78482 .44099 .79044 .44746 .80372 .44468 .79817 .43845 Metetra
1 0 0 r
.79817 .43845 .80372 .44468 .81709 .44221 .81162 .43625 Metetra
1 0 0 r
.81162 .43625 .81709 .44221 .83058 .4401 .82518 .43442 Metetra
1 0 0 r
.82518 .43442 .83058 .4401 .84418 .43836 .83886 .43299 Metetra
1 0 0 r
.83886 .43299 .84418 .43836 .85791 .43703 .85268 .43199 Metetra
1 0 0 r
.85268 .43199 .85791 .43703 .87177 .43615 .86664 .43146 Metetra
1 0 0 r
.86664 .43146 .87177 .43615 .88578 .43575 .88074 .43143 Metetra
1 0 0 r
.88074 .43143 .88578 .43575 .89995 .43586 .89502 .43194 Metetra
1 0 0 r
.89502 .43194 .89995 .43586 .91429 .43653 .90946 .43304 Metetra
1 0 0 r
.29508 .57532 .30245 .57784 .31329 .57783 .30598 .57491 Metetra
1 0 0 r
.30598 .57491 .31329 .57783 .32421 .57748 .31696 .57417 Metetra
1 0 0 r
.31696 .57417 .32421 .57748 .33523 .5768 .32802 .57312 Metetra
1 0 0 r
.32802 .57312 .33523 .5768 .34632 .57579 .33916 .57175 Metetra
1 0 0 r
.33916 .57175 .34632 .57579 .35749 .57448 .35038 .5701 Metetra
1 0 0 r
.35038 .5701 .35749 .57448 .36873 .57287 .36167 .56816 Metetra
1 0 0 r
.36167 .56816 .36873 .57287 .38005 .57097 .37303 .56595 Metetra
1 0 0 r
.37303 .56595 .38005 .57097 .39143 .5688 .38446 .56348 Metetra
1 0 0 r
.38446 .56348 .39143 .5688 .40289 .56637 .39596 .56077 Metetra
1 0 0 r
.39596 .56077 .40289 .56637 .41441 .56369 .40752 .55782 Metetra
1 0 0 r
.40752 .55782 .41441 .56369 .42599 .56077 .41914 .55465 Metetra
1 0 0 r
.41914 .55465 .42599 .56077 .43762 .55763 .43082 .55128 Metetra
1 0 0 r
.43082 .55128 .43762 .55763 .44932 .55428 .44255 .54771 Metetra
1 0 0 r
.44255 .54771 .44932 .55428 .46108 .55074 .45434 .54396 Metetra
1 0 0 r
.45434 .54396 .46108 .55074 .47288 .54701 .46618 .54004 Metetra
1 0 0 r
.46618 .54004 .47288 .54701 .48474 .54311 .47808 .53598 Metetra
1 0 0 r
.47808 .53598 .48474 .54311 .49665 .53906 .49002 .53177 Metetra
1 0 0 r
.49002 .53177 .49665 .53906 .50861 .53487 .50202 .52744 Metetra
1 0 0 r
.50202 .52744 .50861 .53487 .52062 .53055 .51406 .523 Metetra
1 0 0 r
.51406 .523 .52062 .53055 .53268 .52613 .52615 .51847 Metetra
1 0 0 r
.52615 .51847 .53268 .52613 .54478 .52161 .53829 .51385 Metetra
1 0 0 r
.53829 .51385 .54478 .52161 .55694 .51701 .55047 .50918 Metetra
1 0 0 r
.55047 .50918 .55694 .51701 .56913 .51235 .5627 .50446 Metetra
1 0 0 r
.5627 .50446 .56913 .51235 .58138 .50764 .57498 .49971 Metetra
1 0 0 r
.57498 .49971 .58138 .50764 .59367 .5029 .58731 .49494 Metetra
1 0 0 r
.58731 .49494 .59367 .5029 .60601 .49815 .59968 .49018 Metetra
1 0 0 r
.59968 .49018 .60601 .49815 .6184 .4934 .61211 .48544 Metetra
1 0 0 r
.61211 .48544 .6184 .4934 .63084 .48868 .62458 .48074 Metetra
1 0 0 r
.62458 .48074 .63084 .48868 .64332 .48399 .63711 .4761 Metetra
1 0 0 r
.63711 .4761 .64332 .48399 .65587 .47937 .64969 .47153 Metetra
1 0 0 r
.64969 .47153 .65587 .47937 .66846 .47482 .66233 .46706 Metetra
1 0 0 r
.66233 .46706 .66846 .47482 .68112 .47038 .67503 .46271 Metetra
1 0 0 r
.67503 .46271 .68112 .47038 .69383 .46605 .68779 .45849 Metetra
1 0 0 r
.68779 .45849 .69383 .46605 .70661 .46187 .70061 .45443 Metetra
1 0 0 r
.70061 .45443 .70661 .46187 .71945 .45785 .71351 .45055 Metetra
1 0 0 r
.71351 .45055 .71945 .45785 .73236 .45401 .72647 .44688 Metetra
1 0 0 r
.72647 .44688 .73236 .45401 .74535 .45038 .73952 .44343 Metetra
1 0 0 r
.73952 .44343 .74535 .45038 .75842 .44699 .75265 .44024 Metetra
1 0 0 r
.75265 .44024 .75842 .44699 .77158 .44385 .76586 .43732 Metetra
1 0 0 r
.76586 .43732 .77158 .44385 .78482 .44099 .77918 .43471 Metetra
1 0 0 r
.77918 .43471 .78482 .44099 .79817 .43845 .79259 .43242 Metetra
1 0 0 r
.79259 .43242 .79817 .43845 .81162 .43625 .80611 .4305 Metetra
1 0 0 r
.80611 .4305 .81162 .43625 .82518 .43442 .81976 .42897 Metetra
1 0 0 r
.81976 .42897 .82518 .43442 .83886 .43299 .83352 .42787 Metetra
1 0 0 r
.83352 .42787 .83886 .43299 .85268 .43199 .84743 .42721 Metetra
1 0 0 r
.84743 .42721 .85268 .43199 .86664 .43146 .86148 .42705 Metetra
1 0 0 r
.86148 .42705 .86664 .43146 .88074 .43143 .87569 .42742 Metetra
1 0 0 r
.87569 .42742 .88074 .43143 .89502 .43194 .89007 .42836 Metetra
1 0 0 r
.89007 .42836 .89502 .43194 .90946 .43304 .90463 .4299 Metetra
1 0 0 r
.28767 .57235 .29508 .57532 .30598 .57491 .29862 .57156 Metetra
1 0 0 r
.29862 .57156 .30598 .57491 .31696 .57417 .30965 .57045 Metetra
1 0 0 r
.30965 .57045 .31696 .57417 .32802 .57312 .32077 .56903 Metetra
1 0 0 r
.32077 .56903 .32802 .57312 .33916 .57175 .33196 .56733 Metetra
1 0 0 r
.33196 .56733 .33916 .57175 .35038 .5701 .34323 .56535 Metetra
1 0 0 r
.34323 .56535 .35038 .5701 .36167 .56816 .35456 .5631 Metetra
1 0 0 r
.35456 .5631 .36167 .56816 .37303 .56595 .36597 .56059 Metetra
1 0 0 r
.36597 .56059 .37303 .56595 .38446 .56348 .37744 .55784 Metetra
1 0 0 r
.37744 .55784 .38446 .56348 .39596 .56077 .38898 .55486 Metetra
1 0 0 r
.38898 .55486 .39596 .56077 .40752 .55782 .40058 .55167 Metetra
1 0 0 r
.40058 .55167 .40752 .55782 .41914 .55465 .41224 .54826 Metetra
1 0 0 r
.41224 .54826 .41914 .55465 .43082 .55128 .42396 .54467 Metetra
1 0 0 r
.42396 .54467 .43082 .55128 .44255 .54771 .43573 .5409 Metetra
1 0 0 r
.43573 .5409 .44255 .54771 .45434 .54396 .44755 .53696 Metetra
1 0 0 r
.44755 .53696 .45434 .54396 .46618 .54004 .45943 .53288 Metetra
1 0 0 r
.45943 .53288 .46618 .54004 .47808 .53598 .47136 .52865 Metetra
1 0 0 r
.47136 .52865 .47808 .53598 .49002 .53177 .48334 .52431 Metetra
1 0 0 r
.48334 .52431 .49002 .53177 .50202 .52744 .49537 .51985 Metetra
1 0 0 r
.49537 .51985 .50202 .52744 .51406 .523 .50744 .5153 Metetra
1 0 0 r
.50744 .5153 .51406 .523 .52615 .51847 .51957 .51068 Metetra
1 0 0 r
.51957 .51068 .52615 .51847 .53829 .51385 .53174 .50599 Metetra
1 0 0 r
.53174 .50599 .53829 .51385 .55047 .50918 .54396 .50126 Metetra
1 0 0 r
.54396 .50126 .55047 .50918 .5627 .50446 .55622 .49649 Metetra
1 0 0 r
.55622 .49649 .5627 .50446 .57498 .49971 .56854 .49172 Metetra
1 0 0 r
.56854 .49172 .57498 .49971 .58731 .49494 .5809 .48694 Metetra
1 0 0 r
.5809 .48694 .58731 .49494 .59968 .49018 .59331 .48218 Metetra
1 0 0 r
.59331 .48218 .59968 .49018 .61211 .48544 .60577 .47747 Metetra
1 0 0 r
.60577 .47747 .61211 .48544 .62458 .48074 .61829 .4728 Metetra
1 0 0 r
.61829 .4728 .62458 .48074 .63711 .4761 .63085 .46822 Metetra
1 0 0 r
.63085 .46822 .63711 .4761 .64969 .47153 .64348 .46372 Metetra
1 0 0 r
.64348 .46372 .64969 .47153 .66233 .46706 .65616 .45934 Metetra
1 0 0 r
.65616 .45934 .66233 .46706 .67503 .46271 .6689 .4551 Metetra
1 0 0 r
.6689 .4551 .67503 .46271 .68779 .45849 .6817 .45101 Metetra
1 0 0 r
.6817 .45101 .68779 .45849 .70061 .45443 .69458 .44709 Metetra
1 0 0 r
.69458 .44709 .70061 .45443 .71351 .45055 .70752 .44337 Metetra
1 0 0 r
.70752 .44337 .71351 .45055 .72647 .44688 .72054 .43988 Metetra
1 0 0 r
.72054 .43988 .72647 .44688 .73952 .44343 .73365 .43663 Metetra
1 0 0 r
.73365 .43663 .73952 .44343 .75265 .44024 .74683 .43365 Metetra
1 0 0 r
.74683 .43365 .75265 .44024 .76586 .43732 .76012 .43097 Metetra
1 0 0 r
.76012 .43097 .76586 .43732 .77918 .43471 .7735 .42861 Metetra
1 0 0 r
.7735 .42861 .77918 .43471 .79259 .43242 .78698 .42661 Metetra
1 0 0 r
.78698 .42661 .79259 .43242 .80611 .4305 .80058 .42499 Metetra
1 0 0 r
.80058 .42499 .80611 .4305 .81976 .42897 .8143 .42378 Metetra
1 0 0 r
.8143 .42378 .81976 .42897 .83352 .42787 .82816 .42301 Metetra
1 0 0 r
.82816 .42301 .83352 .42787 .84743 .42721 .84216 .42273 Metetra
1 0 0 r
.84216 .42273 .84743 .42721 .86148 .42705 .8563 .42296 Metetra
1 0 0 r
.8563 .42296 .86148 .42705 .87569 .42742 .87062 .42374 Metetra
1 0 0 r
.87062 .42374 .87569 .42742 .89007 .42836 .88511 .42512 Metetra
1 0 0 r
.88511 .42512 .89007 .42836 .90463 .4299 .89979 .42713 Metetra
1 0 0 r
.28021 .56894 .28767 .57235 .29862 .57156 .29122 .56778 Metetra
1 0 0 r
.29122 .56778 .29862 .57156 .30965 .57045 .3023 .56631 Metetra
1 0 0 r
.3023 .56631 .30965 .57045 .32077 .56903 .31347 .56456 Metetra
1 0 0 r
.31347 .56456 .32077 .56903 .33196 .56733 .32471 .56253 Metetra
1 0 0 r
.32471 .56253 .33196 .56733 .34323 .56535 .33603 .56024 Metetra
1 0 0 r
.33603 .56024 .34323 .56535 .35456 .5631 .34741 .55769 Metetra
1 0 0 r
.34741 .55769 .35456 .5631 .36597 .56059 .35886 .55491 Metetra
1 0 0 r
.35886 .55491 .36597 .56059 .37744 .55784 .37038 .5519 Metetra
1 0 0 r
.37038 .5519 .37744 .55784 .38898 .55486 .38196 .54867 Metetra
1 0 0 r
.38196 .54867 .38898 .55486 .40058 .55167 .39359 .54524 Metetra
1 0 0 r
.39359 .54524 .40058 .55167 .41224 .54826 .40529 .54162 Metetra
1 0 0 r
.40529 .54162 .41224 .54826 .42396 .54467 .41705 .53782 Metetra
1 0 0 r
.41705 .53782 .42396 .54467 .43573 .5409 .42885 .53387 Metetra
1 0 0 r
.42885 .53387 .43573 .5409 .44755 .53696 .44072 .52976 Metetra
1 0 0 r
.44072 .52976 .44755 .53696 .45943 .53288 .45263 .52552 Metetra
1 0 0 r
.45263 .52552 .45943 .53288 .47136 .52865 .46459 .52115 Metetra
1 0 0 r
.46459 .52115 .47136 .52865 .48334 .52431 .47661 .51668 Metetra
1 0 0 r
.47661 .51668 .48334 .52431 .49537 .51985 .48867 .51212 Metetra
1 0 0 r
.48867 .51212 .49537 .51985 .50744 .5153 .50078 .50748 Metetra
1 0 0 r
.50078 .50748 .50744 .5153 .51957 .51068 .51294 .50278 Metetra
1 0 0 r
.51294 .50278 .51957 .51068 .53174 .50599 .52514 .49804 Metetra
1 0 0 r
.52514 .49804 .53174 .50599 .54396 .50126 .53739 .49326 Metetra
1 0 0 r
.53739 .49326 .54396 .50126 .55622 .49649 .54969 .48847 Metetra
1 0 0 r
.54969 .48847 .55622 .49649 .56854 .49172 .56204 .48368 Metetra
1 0 0 r
.56204 .48368 .56854 .49172 .5809 .48694 .57444 .47891 Metetra
1 0 0 r
.57444 .47891 .5809 .48694 .59331 .48218 .58689 .47417 Metetra
1 0 0 r
.58689 .47417 .59331 .48218 .60577 .47747 .59939 .46949 Metetra
1 0 0 r
.59939 .46949 .60577 .47747 .61829 .4728 .61194 .46489 Metetra
1 0 0 r
.61194 .46489 .61829 .4728 .63085 .46822 .62455 .46037 Metetra
1 0 0 r
.62455 .46037 .63085 .46822 .64348 .46372 .63721 .45597 Metetra
1 0 0 r
.63721 .45597 .64348 .46372 .65616 .45934 .64994 .45169 Metetra
1 0 0 r
.64994 .45169 .65616 .45934 .6689 .4551 .66272 .44757 Metetra
1 0 0 r
.66272 .44757 .6689 .4551 .6817 .45101 .67558 .44362 Metetra
1 0 0 r
.67558 .44362 .6817 .45101 .69458 .44709 .6885 .43986 Metetra
1 0 0 r
.6885 .43986 .69458 .44709 .70752 .44337 .7015 .43632 Metetra
1 0 0 r
.7015 .43632 .70752 .44337 .72054 .43988 .71457 .43302 Metetra
1 0 0 r
.71457 .43302 .72054 .43988 .73365 .43663 .72773 .42999 Metetra
1 0 0 r
.72773 .42999 .73365 .43663 .74683 .43365 .74099 .42725 Metetra
1 0 0 r
.74099 .42725 .74683 .43365 .76012 .43097 .75433 .42482 Metetra
1 0 0 r
.75433 .42482 .76012 .43097 .7735 .42861 .76778 .42273 Metetra
1 0 0 r
.76778 .42273 .7735 .42861 .78698 .42661 .78134 .42102 Metetra
1 0 0 r
.78134 .42102 .78698 .42661 .80058 .42499 .79502 .41972 Metetra
1 0 0 r
.79502 .41972 .80058 .42499 .8143 .42378 .80883 .41885 Metetra
1 0 0 r
.80883 .41885 .8143 .42378 .82816 .42301 .82277 .41844 Metetra
1 0 0 r
.82277 .41844 .82816 .42301 .84216 .42273 .83686 .41854 Metetra
1 0 0 r
.83686 .41854 .84216 .42273 .8563 .42296 .85111 .41918 Metetra
1 0 0 r
.85111 .41918 .8563 .42296 .87062 .42374 .86553 .4204 Metetra
1 0 0 r
.86553 .4204 .87062 .42374 .88511 .42512 .88014 .42225 Metetra
1 0 0 r
.88014 .42225 .88511 .42512 .89979 .42713 .89494 .42475 Metetra
1 0 0 r
.27271 .56511 .28021 .56894 .29122 .56778 .28377 .56359 Metetra
1 0 0 r
.28377 .56359 .29122 .56778 .3023 .56631 .29491 .56179 Metetra
1 0 0 r
.29491 .56179 .3023 .56631 .31347 .56456 .30613 .55971 Metetra
1 0 0 r
.30613 .55971 .31347 .56456 .32471 .56253 .31742 .55738 Metetra
1 0 0 r
.31742 .55738 .32471 .56253 .33603 .56024 .32878 .55479 Metetra
1 0 0 r
.32878 .55479 .33603 .56024 .34741 .55769 .34021 .55197 Metetra
1 0 0 r
.34021 .55197 .34741 .55769 .35886 .55491 .3517 .54892 Metetra
1 0 0 r
.3517 .54892 .35886 .55491 .37038 .5519 .36326 .54566 Metetra
1 0 0 r
.36326 .54566 .37038 .5519 .38196 .54867 .37488 .5422 Metetra
1 0 0 r
.37488 .5422 .38196 .54867 .39359 .54524 .38656 .53855 Metetra
1 0 0 r
.38656 .53855 .39359 .54524 .40529 .54162 .3983 .53473 Metetra
1 0 0 r
.3983 .53473 .40529 .54162 .41705 .53782 .41009 .53075 Metetra
1 0 0 r
.41009 .53075 .41705 .53782 .42885 .53387 .42193 .52663 Metetra
1 0 0 r
.42193 .52663 .42885 .53387 .44072 .52976 .43383 .52236 Metetra
1 0 0 r
.43383 .52236 .44072 .52976 .45263 .52552 .44578 .51798 Metetra
1 0 0 r
.44578 .51798 .45263 .52552 .46459 .52115 .45778 .5135 Metetra
1 0 0 r
.45778 .5135 .46459 .52115 .47661 .51668 .46982 .50892 Metetra
1 0 0 r
.46982 .50892 .47661 .51668 .48867 .51212 .48192 .50427 Metetra
1 0 0 r
.48192 .50427 .48867 .51212 .50078 .50748 .49406 .49955 Metetra
1 0 0 r
.49406 .49955 .50078 .50748 .51294 .50278 .50625 .49479 Metetra
1 0 0 r
.50625 .49479 .51294 .50278 .52514 .49804 .51849 .49 Metetra
1 0 0 r
.51849 .49 .52514 .49804 .53739 .49326 .53078 .4852 Metetra
1 0 0 r
.53078 .4852 .53739 .49326 .54969 .48847 .54312 .4804 Metetra
1 0 0 r
.54312 .4804 .54969 .48847 .56204 .48368 .5555 .47561 Metetra
1 0 0 r
.5555 .47561 .56204 .48368 .57444 .47891 .56793 .47086 Metetra
1 0 0 r
.56793 .47086 .57444 .47891 .58689 .47417 .58042 .46617 Metetra
1 0 0 r
.58042 .46617 .58689 .47417 .59939 .46949 .59295 .46154 Metetra
1 0 0 r
.59295 .46154 .59939 .46949 .61194 .46489 .60555 .457 Metetra
1 0 0 r
.60555 .457 .61194 .46489 .62455 .46037 .61819 .45258 Metetra
1 0 0 r
.61819 .45258 .62455 .46037 .63721 .45597 .6309 .44828 Metetra
1 0 0 r
.6309 .44828 .63721 .45597 .64994 .45169 .64367 .44412 Metetra
1 0 0 r
.64367 .44412 .64994 .45169 .66272 .44757 .6565 .44014 Metetra
1 0 0 r
.6565 .44014 .66272 .44757 .67558 .44362 .6694 .43635 Metetra
1 0 0 r
.6694 .43635 .67558 .44362 .6885 .43986 .68238 .43277 Metetra
1 0 0 r
.68238 .43277 .6885 .43986 .7015 .43632 .69543 .42942 Metetra
1 0 0 r
.69543 .42942 .7015 .43632 .71457 .43302 .70856 .42633 Metetra
1 0 0 r
.70856 .42633 .71457 .43302 .72773 .42999 .72178 .42353 Metetra
1 0 0 r
.72178 .42353 .72773 .42999 .74099 .42725 .7351 .42104 Metetra
1 0 0 r
.7351 .42104 .74099 .42725 .75433 .42482 .74851 .41888 Metetra
1 0 0 r
.74851 .41888 .75433 .42482 .76778 .42273 .76203 .41709 Metetra
1 0 0 r
.76203 .41709 .76778 .42273 .78134 .42102 .77567 .41569 Metetra
1 0 0 r
.77567 .41569 .78134 .42102 .79502 .41972 .78943 .41472 Metetra
1 0 0 r
.78943 .41472 .79502 .41972 .80883 .41885 .80332 .4142 Metetra
1 0 0 r
.80332 .4142 .80883 .41885 .82277 .41844 .81735 .41418 Metetra
1 0 0 r
.81735 .41418 .82277 .41844 .83686 .41854 .83154 .41469 Metetra
1 0 0 r
.83154 .41469 .83686 .41854 .85111 .41918 .84589 .41576 Metetra
1 0 0 r
.84589 .41576 .85111 .41918 .86553 .4204 .86043 .41744 Metetra
1 0 0 r
.86043 .41744 .86553 .4204 .88014 .42225 .87515 .41976 Metetra
1 0 0 r
.87515 .41976 .88014 .42225 .89494 .42475 .89008 .42279 Metetra
1 0 0 r
.26516 .56087 .27271 .56511 .28377 .56359 .27628 .55902 Metetra
1 0 0 r
.27628 .55902 .28377 .56359 .29491 .56179 .28747 .55689 Metetra
1 0 0 r
.28747 .55689 .29491 .56179 .30613 .55971 .29874 .55451 Metetra
1 0 0 r
.29874 .55451 .30613 .55971 .31742 .55738 .31008 .55188 Metetra
1 0 0 r
.31008 .55188 .31742 .55738 .32878 .55479 .32149 .54902 Metetra
1 0 0 r
.32149 .54902 .32878 .55479 .34021 .55197 .33296 .54593 Metetra
1 0 0 r
.33296 .54593 .34021 .55197 .3517 .54892 .3445 .54264 Metetra
1 0 0 r
.3445 .54264 .3517 .54892 .36326 .54566 .3561 .53915 Metetra
1 0 0 r
.3561 .53915 .36326 .54566 .37488 .5422 .36776 .53547 Metetra
1 0 0 r
.36776 .53547 .37488 .5422 .38656 .53855 .37948 .53163 Metetra
1 0 0 r
.37948 .53163 .38656 .53855 .3983 .53473 .39125 .52762 Metetra
1 0 0 r
.39125 .52762 .3983 .53473 .41009 .53075 .40308 .52347 Metetra
1 0 0 r
.40308 .52347 .41009 .53075 .42193 .52663 .41496 .51919 Metetra
1 0 0 r
.41496 .51919 .42193 .52663 .43383 .52236 .42689 .51479 Metetra
1 0 0 r
.42689 .51479 .43383 .52236 .44578 .51798 .43888 .51029 Metetra
1 0 0 r
.43888 .51029 .44578 .51798 .45778 .5135 .45091 .5057 Metetra
1 0 0 r
.45091 .5057 .45778 .5135 .46982 .50892 .46299 .50103 Metetra
1 0 0 r
.46299 .50103 .46982 .50892 .48192 .50427 .47512 .4963 Metetra
1 0 0 r
.47512 .4963 .48192 .50427 .49406 .49955 .4873 .49153 Metetra
1 0 0 r
.4873 .49153 .49406 .49955 .50625 .49479 .49952 .48673 Metetra
1 0 0 r
.49952 .48673 .50625 .49479 .51849 .49 .51179 .48191 Metetra
1 0 0 r
.51179 .48191 .51849 .49 .53078 .4852 .52412 .47709 Metetra
1 0 0 r
.52412 .47709 .53078 .4852 .54312 .4804 .53648 .47229 Metetra
1 0 0 r
.53648 .47229 .54312 .4804 .5555 .47561 .5489 .46753 Metetra
1 0 0 r
.5489 .46753 .5555 .47561 .56793 .47086 .56137 .46282 Metetra
1 0 0 r
.56137 .46282 .56793 .47086 .58042 .46617 .5739 .45818 Metetra
1 0 0 r
.5739 .45818 .58042 .46617 .59295 .46154 .58647 .45362 Metetra
1 0 0 r
.58647 .45362 .59295 .46154 .60555 .457 .5991 .44917 Metetra
1 0 0 r
.5991 .44917 .60555 .457 .61819 .45258 .61179 .44485 Metetra
1 0 0 r
.61179 .44485 .61819 .45258 .6309 .44828 .62454 .44067 Metetra
1 0 0 r
.62454 .44067 .6309 .44828 .64367 .44412 .63735 .43665 Metetra
1 0 0 r
.63735 .43665 .64367 .44412 .6565 .44014 .65024 .43282 Metetra
1 0 0 r
.65024 .43282 .6565 .44014 .6694 .43635 .66319 .4292 Metetra
1 0 0 r
.66319 .4292 .6694 .43635 .68238 .43277 .67621 .42581 Metetra
1 0 0 r
.67621 .42581 .68238 .43277 .69543 .42942 .68932 .42268 Metetra
1 0 0 r
.68932 .42268 .69543 .42942 .70856 .42633 .70251 .41982 Metetra
1 0 0 r
.70251 .41982 .70856 .42633 .72178 .42353 .71579 .41726 Metetra
1 0 0 r
.71579 .41726 .72178 .42353 .7351 .42104 .72917 .41504 Metetra
1 0 0 r
.72917 .41504 .7351 .42104 .74851 .41888 .74265 .41317 Metetra
1 0 0 r
.74265 .41317 .74851 .41888 .76203 .41709 .75625 .41169 Metetra
1 0 0 r
.75625 .41169 .76203 .41709 .77567 .41569 .76996 .41062 Metetra
1 0 0 r
.76996 .41062 .77567 .41569 .78943 .41472 .7838 .41 Metetra
1 0 0 r
.7838 .41 .78943 .41472 .80332 .4142 .79778 .40987 Metetra
1 0 0 r
.79778 .40987 .80332 .4142 .81735 .41418 .81191 .41025 Metetra
1 0 0 r
.81191 .41025 .81735 .41418 .83154 .41469 .8262 .41118 Metetra
1 0 0 r
.8262 .41118 .83154 .41469 .84589 .41576 .84066 .4127 Metetra
1 0 0 r
.84066 .4127 .84589 .41576 .86043 .41744 .8553 .41486 Metetra
1 0 0 r
.8553 .41486 .86043 .41744 .87515 .41976 .87015 .4177 Metetra
1 0 0 r
.87015 .4177 .87515 .41976 .89008 .42279 .88521 .42126 Metetra
1 0 0 r
.25758 .55625 .26516 .56087 .27628 .55902 .26875 .55407 Metetra
1 0 0 r
.26875 .55407 .27628 .55902 .28747 .55689 .27999 .55164 Metetra
1 0 0 r
.27999 .55164 .28747 .55689 .29874 .55451 .29131 .54897 Metetra
1 0 0 r
.29131 .54897 .29874 .55451 .31008 .55188 .30269 .54606 Metetra
1 0 0 r
.30269 .54606 .31008 .55188 .32149 .54902 .31415 .54294 Metetra
1 0 0 r
.31415 .54294 .32149 .54902 .33296 .54593 .32566 .53961 Metetra
1 0 0 r
.32566 .53961 .33296 .54593 .3445 .54264 .33725 .53609 Metetra
1 0 0 r
.33725 .53609 .3445 .54264 .3561 .53915 .34889 .53238 Metetra
1 0 0 r
.34889 .53238 .3561 .53915 .36776 .53547 .36059 .52851 Metetra
1 0 0 r
.36059 .52851 .36776 .53547 .37948 .53163 .37234 .52448 Metetra
1 0 0 r
.37234 .52448 .37948 .53163 .39125 .52762 .38415 .5203 Metetra
1 0 0 r
.38415 .5203 .39125 .52762 .40308 .52347 .39602 .516 Metetra
1 0 0 r
.39602 .516 .40308 .52347 .41496 .51919 .40794 .51158 Metetra
1 0 0 r
.40794 .51158 .41496 .51919 .42689 .51479 .4199 .50706 Metetra
1 0 0 r
.4199 .50706 .42689 .51479 .43888 .51029 .43192 .50245 Metetra
1 0 0 r
.43192 .50245 .43888 .51029 .45091 .5057 .44399 .49777 Metetra
1 0 0 r
.44399 .49777 .45091 .5057 .46299 .50103 .4561 .49303 Metetra
1 0 0 r
.4561 .49303 .46299 .50103 .47512 .4963 .46827 .48824 Metetra
1 0 0 r
.46827 .48824 .47512 .4963 .4873 .49153 .48048 .48343 Metetra
1 0 0 r
.48048 .48343 .4873 .49153 .49952 .48673 .49274 .4786 Metetra
1 0 0 r
.49274 .4786 .49952 .48673 .51179 .48191 .50504 .47377 Metetra
1 0 0 r
.50504 .47377 .51179 .48191 .52412 .47709 .5174 .46896 Metetra
1 0 0 r
.5174 .46896 .52412 .47709 .53648 .47229 .5298 .46418 Metetra
1 0 0 r
.5298 .46418 .53648 .47229 .5489 .46753 .54226 .45945 Metetra
1 0 0 r
.54226 .45945 .5489 .46753 .56137 .46282 .55476 .45479 Metetra
1 0 0 r
.55476 .45479 .56137 .46282 .5739 .45818 .56732 .45022 Metetra
1 0 0 r
.56732 .45022 .5739 .45818 .58647 .45362 .57994 .44575 Metetra
1 0 0 r
.57994 .44575 .58647 .45362 .5991 .44917 .59261 .4414 Metetra
1 0 0 r
.59261 .4414 .5991 .44917 .61179 .44485 .60534 .4372 Metetra
1 0 0 r
.60534 .4372 .61179 .44485 .62454 .44067 .61813 .43316 Metetra
1 0 0 r
.61813 .43316 .62454 .44067 .63735 .43665 .63099 .42929 Metetra
1 0 0 r
.63099 .42929 .63735 .43665 .65024 .43282 .64392 .42564 Metetra
1 0 0 r
.64392 .42564 .65024 .43282 .66319 .4292 .65692 .42221 Metetra
1 0 0 r
.65692 .42221 .66319 .4292 .67621 .42581 .67 .41903 Metetra
1 0 0 r
.67 .41903 .67621 .42581 .68932 .42268 .68317 .41612 Metetra
1 0 0 r
.68317 .41612 .68932 .42268 .70251 .41982 .69642 .4135 Metetra
1 0 0 r
.69642 .4135 .70251 .41982 .71579 .41726 .70976 .41121 Metetra
1 0 0 r
.70976 .41121 .71579 .41726 .72917 .41504 .72321 .40927 Metetra
1 0 0 r
.72321 .40927 .72917 .41504 .74265 .41317 .73676 .40771 Metetra
1 0 0 r
.73676 .40771 .74265 .41317 .75625 .41169 .75043 .40656 Metetra
1 0 0 r
.75043 .40656 .75625 .41169 .76996 .41062 .76422 .40584 Metetra
1 0 0 r
.76422 .40584 .76996 .41062 .7838 .41 .77815 .4056 Metetra
1 0 0 r
.77815 .4056 .7838 .41 .79778 .40987 .79222 .40586 Metetra
1 0 0 r
.79222 .40586 .79778 .40987 .81191 .41025 .80644 .40666 Metetra
1 0 0 r
.80644 .40666 .81191 .41025 .8262 .41118 .82083 .40804 Metetra
1 0 0 r
.82083 .40804 .8262 .41118 .84066 .4127 .8354 .41004 Metetra
1 0 0 r
.8354 .41004 .84066 .4127 .8553 .41486 .85016 .4127 Metetra
1 0 0 r
.85016 .4127 .8553 .41486 .87015 .4177 .86513 .41607 Metetra
1 0 0 r
.86513 .41607 .87015 .4177 .88521 .42126 .88033 .4202 Metetra
1 0 0 r
.24995 .55124 .25758 .55625 .26875 .55407 .26117 .54876 Metetra
1 0 0 r
.26117 .54876 .26875 .55407 .27999 .55164 .27246 .54604 Metetra
1 0 0 r
.27246 .54604 .27999 .55164 .29131 .54897 .28383 .54309 Metetra
1 0 0 r
.28383 .54309 .29131 .54897 .30269 .54606 .29526 .53993 Metetra
1 0 0 r
.29526 .53993 .30269 .54606 .31415 .54294 .30676 .53657 Metetra
1 0 0 r
.30676 .53657 .31415 .54294 .32566 .53961 .31832 .53301 Metetra
1 0 0 r
.31832 .53301 .32566 .53961 .33725 .53609 .32994 .52927 Metetra
1 0 0 r
.32994 .52927 .33725 .53609 .34889 .53238 .34163 .52537 Metetra
1 0 0 r
.34163 .52537 .34889 .53238 .36059 .52851 .35337 .52131 Metetra
1 0 0 r
.35337 .52131 .36059 .52851 .37234 .52448 .36516 .51712 Metetra
1 0 0 r
.36516 .51712 .37234 .52448 .38415 .5203 .37701 .51279 Metetra
1 0 0 r
.37701 .51279 .38415 .5203 .39602 .516 .38891 .50836 Metetra
1 0 0 r
.38891 .50836 .39602 .516 .40794 .51158 .40086 .50382 Metetra
1 0 0 r
.40086 .50382 .40794 .51158 .4199 .50706 .41286 .49919 Metetra
1 0 0 r
.41286 .49919 .4199 .50706 .43192 .50245 .42492 .49449 Metetra
1 0 0 r
.42492 .49449 .43192 .50245 .44399 .49777 .43702 .48974 Metetra
1 0 0 r
.43702 .48974 .44399 .49777 .4561 .49303 .44916 .48494 Metetra
1 0 0 r
.44916 .48494 .4561 .49303 .46827 .48824 .46136 .48011 Metetra
1 0 0 r
.46136 .48011 .46827 .48824 .48048 .48343 .47361 .47526 Metetra
1 0 0 r
.47361 .47526 .48048 .48343 .49274 .4786 .4859 .47042 Metetra
1 0 0 r
.4859 .47042 .49274 .4786 .50504 .47377 .49824 .4656 Metetra
1 0 0 r
.49824 .4656 .50504 .47377 .5174 .46896 .51063 .4608 Metetra
1 0 0 r
.51063 .4608 .5174 .46896 .5298 .46418 .52307 .45606 Metetra
1 0 0 r
.52307 .45606 .5298 .46418 .54226 .45945 .53556 .45139 Metetra
1 0 0 r
.53556 .45139 .54226 .45945 .55476 .45479 .5481 .4468 Metetra
1 0 0 r
.5481 .4468 .55476 .45479 .56732 .45022 .5607 .44231 Metetra
1 0 0 r
.5607 .44231 .56732 .45022 .57994 .44575 .57335 .43794 Metetra
1 0 0 r
.57335 .43794 .57994 .44575 .59261 .4414 .58607 .43372 Metetra
1 0 0 r
.58607 .43372 .59261 .4414 .60534 .4372 .59884 .42965 Metetra
1 0 0 r
.59884 .42965 .60534 .4372 .61813 .43316 .61168 .42576 Metetra
1 0 0 r
.61168 .42576 .61813 .43316 .63099 .42929 .62458 .42207 Metetra
1 0 0 r
.62458 .42207 .63099 .42929 .64392 .42564 .63756 .4186 Metetra
1 0 0 r
.63756 .4186 .64392 .42564 .65692 .42221 .65061 .41538 Metetra
1 0 0 r
.65061 .41538 .65692 .42221 .67 .41903 .66375 .41242 Metetra
1 0 0 r
.66375 .41242 .67 .41903 .68317 .41612 .67697 .40975 Metetra
1 0 0 r
.67697 .40975 .68317 .41612 .69642 .4135 .69028 .4074 Metetra
1 0 0 r
.69028 .4074 .69642 .4135 .70976 .41121 .70369 .4054 Metetra
1 0 0 r
.70369 .4054 .70976 .41121 .72321 .40927 .7172 .40376 Metetra
1 0 0 r
.7172 .40376 .72321 .40927 .73676 .40771 .73082 .40252 Metetra
1 0 0 r
.73082 .40252 .73676 .40771 .75043 .40656 .74457 .40172 Metetra
1 0 0 r
.74457 .40172 .75043 .40656 .76422 .40584 .75844 .40137 Metetra
1 0 0 r
.75844 .40137 .76422 .40584 .77815 .4056 .77246 .40152 Metetra
1 0 0 r
.77246 .40152 .77815 .4056 .79222 .40586 .78662 .4022 Metetra
1 0 0 r
.78662 .4022 .79222 .40586 .80644 .40666 .80094 .40344 Metetra
1 0 0 r
.80094 .40344 .80644 .40666 .82083 .40804 .81544 .40529 Metetra
1 0 0 r
.81544 .40529 .82083 .40804 .8354 .41004 .83012 .40779 Metetra
1 0 0 r
.83012 .40779 .8354 .41004 .85016 .4127 .845 .41098 Metetra
1 0 0 r
.845 .41098 .85016 .4127 .86513 .41607 .8601 .41491 Metetra
1 0 0 r
.8601 .41491 .86513 .41607 .88033 .4202 .87544 .41963 Metetra
1 0 0 r
.24228 .54588 .24995 .55124 .26117 .54876 .25355 .54311 Metetra
1 0 0 r
.25355 .54311 .26117 .54876 .27246 .54604 .26489 .54012 Metetra
1 0 0 r
.26489 .54012 .27246 .54604 .28383 .54309 .27631 .53691 Metetra
1 0 0 r
.27631 .53691 .28383 .54309 .29526 .53993 .28779 .53351 Metetra
1 0 0 r
.28779 .53351 .29526 .53993 .30676 .53657 .29933 .52992 Metetra
1 0 0 r
.29933 .52992 .30676 .53657 .31832 .53301 .31093 .52615 Metetra
1 0 0 r
.31093 .52615 .31832 .53301 .32994 .52927 .3226 .52222 Metetra
1 0 0 r
.3226 .52222 .32994 .52927 .34163 .52537 .33432 .51813 Metetra
1 0 0 r
.33432 .51813 .34163 .52537 .35337 .52131 .34609 .51391 Metetra
1 0 0 r
.34609 .51391 .35337 .52131 .36516 .51712 .35793 .50957 Metetra
1 0 0 r
.35793 .50957 .36516 .51712 .37701 .51279 .36981 .50511 Metetra
1 0 0 r
.36981 .50511 .37701 .51279 .38891 .50836 .38175 .50055 Metetra
1 0 0 r
.38175 .50055 .38891 .50836 .40086 .50382 .39374 .49591 Metetra
1 0 0 r
.39374 .49591 .40086 .50382 .41286 .49919 .40577 .49119 Metetra
1 0 0 r
.40577 .49119 .41286 .49919 .42492 .49449 .41786 .48642 Metetra
1 0 0 r
.41786 .48642 .42492 .49449 .43702 .48974 .42999 .48161 Metetra
1 0 0 r
.42999 .48161 .43702 .48974 .44916 .48494 .44217 .47676 Metetra
1 0 0 r
.44217 .47676 .44916 .48494 .46136 .48011 .4544 .47191 Metetra
1 0 0 r
.4544 .47191 .46136 .48011 .47361 .47526 .46668 .46705 Metetra
1 0 0 r
.46668 .46705 .47361 .47526 .4859 .47042 .47901 .46222 Metetra
1 0 0 r
.47901 .46222 .4859 .47042 .49824 .4656 .49138 .45741 Metetra
1 0 0 r
.49138 .45741 .49824 .4656 .51063 .4608 .50381 .45266 Metetra
1 0 0 r
.50381 .45266 .51063 .4608 .52307 .45606 .51628 .44797 Metetra
1 0 0 r
.51628 .44797 .52307 .45606 .53556 .45139 .52881 .44336 Metetra
1 0 0 r
.52881 .44336 .53556 .45139 .5481 .4468 .54139 .43886 Metetra
1 0 0 r
.54139 .43886 .5481 .4468 .5607 .44231 .55402 .43447 Metetra
1 0 0 r
.55402 .43447 .5607 .44231 .57335 .43794 .56672 .43022 Metetra
1 0 0 r
.56672 .43022 .57335 .43794 .58607 .43372 .57947 .42613 Metetra
1 0 0 r
.57947 .42613 .58607 .43372 .59884 .42965 .59229 .42221 Metetra
1 0 0 r
.59229 .42221 .59884 .42965 .61168 .42576 .60517 .41849 Metetra
1 0 0 r
.60517 .41849 .61168 .42576 .62458 .42207 .61812 .41499 Metetra
1 0 0 r
.61812 .41499 .62458 .42207 .63756 .4186 .63115 .41173 Metetra
1 0 0 r
.63115 .41173 .63756 .4186 .65061 .41538 .64425 .40873 Metetra
1 0 0 r
.64425 .40873 .65061 .41538 .66375 .41242 .65744 .40601 Metetra
1 0 0 r
.65744 .40601 .66375 .41242 .67697 .40975 .67072 .40361 Metetra
1 0 0 r
.67072 .40361 .67697 .40975 .69028 .4074 .68409 .40154 Metetra
1 0 0 r
.68409 .40154 .69028 .4074 .70369 .4054 .69757 .39983 Metetra
1 0 0 r
.69757 .39983 .70369 .4054 .7172 .40376 .71115 .39852 Metetra
1 0 0 r
.71115 .39852 .7172 .40376 .73082 .40252 .72485 .39763 Metetra
1 0 0 r
.72485 .39763 .73082 .40252 .74457 .40172 .73867 .39718 Metetra
1 0 0 r
.73867 .39718 .74457 .40172 .75844 .40137 .75263 .39723 Metetra
1 0 0 r
.75263 .39723 .75844 .40137 .77246 .40152 .76673 .39779 Metetra
1 0 0 r
.76673 .39779 .77246 .40152 .78662 .4022 .78099 .3989 Metetra
1 0 0 r
.78099 .3989 .78662 .4022 .80094 .40344 .79542 .40061 Metetra
1 0 0 r
.79542 .40061 .80094 .40344 .81544 .40529 .81002 .40296 Metetra
1 0 0 r
.81002 .40296 .81544 .40529 .83012 .40779 .82482 .40598 Metetra
1 0 0 r
.82482 .40598 .83012 .40779 .845 .41098 .83983 .40972 Metetra
1 0 0 r
.83983 .40972 .845 .41098 .8601 .41491 .85506 .41423 Metetra
1 0 0 r
.85506 .41423 .8601 .41491 .87544 .41963 .87053 .41957 Metetra
1 0 0 r
.23457 .54017 .24228 .54588 .25355 .54311 .24589 .53713 Metetra
1 0 0 r
.24589 .53713 .25355 .54311 .26489 .54012 .25728 .53388 Metetra
1 0 0 r
.25728 .53388 .26489 .54012 .27631 .53691 .26874 .53044 Metetra
1 0 0 r
.26874 .53044 .27631 .53691 .28779 .53351 .28026 .52681 Metetra
1 0 0 r
.28026 .52681 .28779 .53351 .29933 .52992 .29185 .52301 Metetra
1 0 0 r
.29185 .52301 .29933 .52992 .31093 .52615 .30349 .51905 Metetra
1 0 0 r
.30349 .51905 .31093 .52615 .3226 .52222 .3152 .51494 Metetra
1 0 0 r
.3152 .51494 .3226 .52222 .33432 .51813 .32696 .51069 Metetra
1 0 0 r
.32696 .51069 .33432 .51813 .34609 .51391 .33877 .50632 Metetra
1 0 0 r
.33877 .50632 .34609 .51391 .35793 .50957 .35064 .50184 Metetra
1 0 0 r
.35064 .50184 .35793 .50957 .36981 .50511 .36256 .49726 Metetra
1 0 0 r
.36256 .49726 .36981 .50511 .38175 .50055 .37453 .4926 Metetra
1 0 0 r
.37453 .4926 .38175 .50055 .39374 .49591 .38656 .48787 Metetra
1 0 0 r
.38656 .48787 .39374 .49591 .40577 .49119 .39863 .48308 Metetra
1 0 0 r
.39863 .48308 .40577 .49119 .41786 .48642 .41075 .47825 Metetra
1 0 0 r
.41075 .47825 .41786 .48642 .42999 .48161 .42291 .4734 Metetra
1 0 0 r
.42291 .4734 .42999 .48161 .44217 .47676 .43513 .46853 Metetra
1 0 0 r
.43513 .46853 .44217 .47676 .4544 .47191 .44739 .46366 Metetra
1 0 0 r
.44739 .46366 .4544 .47191 .46668 .46705 .4597 .45881 Metetra
1 0 0 r
.4597 .45881 .46668 .46705 .47901 .46222 .47206 .454 Metetra
1 0 0 r
.47206 .454 .47901 .46222 .49138 .45741 .48447 .44923 Metetra
1 0 0 r
.48447 .44923 .49138 .45741 .50381 .45266 .49693 .44453 Metetra
1 0 0 r
.49693 .44453 .50381 .45266 .51628 .44797 .50944 .43991 Metetra
1 0 0 r
.50944 .43991 .51628 .44797 .52881 .44336 .522 .43539 Metetra
1 0 0 r
.522 .43539 .52881 .44336 .54139 .43886 .53462 .43098 Metetra
1 0 0 r
.53462 .43098 .54139 .43886 .55402 .43447 .54729 .42672 Metetra
1 0 0 r
.54729 .42672 .55402 .43447 .56672 .43022 .56003 .4226 Metetra
1 0 0 r
.56003 .4226 .56672 .43022 .57947 .42613 .57282 .41866 Metetra
1 0 0 r
.57282 .41866 .57947 .42613 .59229 .42221 .58568 .41491 Metetra
1 0 0 r
.58568 .41491 .59229 .42221 .60517 .41849 .59861 .41138 Metetra
1 0 0 r
.59861 .41138 .60517 .41849 .61812 .41499 .61161 .40808 Metetra
1 0 0 r
.61161 .40808 .61812 .41499 .63115 .41173 .62469 .40504 Metetra
1 0 0 r
.62469 .40504 .63115 .41173 .64425 .40873 .63784 .40228 Metetra
1 0 0 r
.63784 .40228 .64425 .40873 .65744 .40601 .65109 .39982 Metetra
1 0 0 r
.65109 .39982 .65744 .40601 .67072 .40361 .66443 .39769 Metetra
1 0 0 r
.66443 .39769 .67072 .40361 .68409 .40154 .67786 .39593 Metetra
1 0 0 r
.67786 .39593 .68409 .40154 .69757 .39983 .6914 .39454 Metetra
1 0 0 r
.6914 .39454 .69757 .39983 .71115 .39852 .70506 .39357 Metetra
1 0 0 r
.70506 .39357 .71115 .39852 .72485 .39763 .71883 .39304 Metetra
1 0 0 r
.71883 .39304 .72485 .39763 .73867 .39718 .73274 .39298 Metetra
1 0 0 r
.73274 .39298 .73867 .39718 .75263 .39723 .74678 .39343 Metetra
1 0 0 r
.74678 .39343 .75263 .39723 .76673 .39779 .76097 .39443 Metetra
1 0 0 r
.76097 .39443 .76673 .39779 .78099 .3989 .77533 .39601 Metetra
1 0 0 r
.77533 .39601 .78099 .3989 .79542 .40061 .78986 .39821 Metetra
1 0 0 r
.78986 .39821 .79542 .40061 .81002 .40296 .80457 .40107 Metetra
1 0 0 r
.80457 .40107 .81002 .40296 .82482 .40598 .81949 .40463 Metetra
1 0 0 r
.81949 .40463 .82482 .40598 .83983 .40972 .83462 .40896 Metetra
1 0 0 r
.83462 .40896 .83983 .40972 .85506 .41423 .84999 .41408 Metetra
1 0 0 r
.84999 .41408 .85506 .41423 .87053 .41957 .86562 .42007 Metetra
1 0 0 r
.22681 .53413 .23457 .54017 .24589 .53713 .23818 .53084 Metetra
1 0 0 r
.23818 .53084 .24589 .53713 .25728 .53388 .24962 .52736 Metetra
1 0 0 r
.24962 .52736 .25728 .53388 .26874 .53044 .26113 .52369 Metetra
1 0 0 r
.26113 .52369 .26874 .53044 .28026 .52681 .27269 .51985 Metetra
1 0 0 r
.27269 .51985 .28026 .52681 .29185 .52301 .28432 .51586 Metetra
1 0 0 r
.28432 .51586 .29185 .52301 .30349 .51905 .29601 .51172 Metetra
1 0 0 r
.29601 .51172 .30349 .51905 .3152 .51494 .30775 .50744 Metetra
1 0 0 r
.30775 .50744 .3152 .51494 .32696 .51069 .31955 .50305 Metetra
1 0 0 r
.31955 .50305 .32696 .51069 .33877 .50632 .3314 .49855 Metetra
1 0 0 r
.3314 .49855 .33877 .50632 .35064 .50184 .34331 .49395 Metetra
1 0 0 r
.34331 .49395 .35064 .50184 .36256 .49726 .35526 .48927 Metetra
1 0 0 r
.35526 .48927 .36256 .49726 .37453 .4926 .36727 .48452 Metetra
1 0 0 r
.36727 .48452 .37453 .4926 .38656 .48787 .37932 .47972 Metetra
1 0 0 r
.37932 .47972 .38656 .48787 .39863 .48308 .39143 .47488 Metetra
1 0 0 r
.39143 .47488 .39863 .48308 .41075 .47825 .40358 .47001 Metetra
1 0 0 r
.40358 .47001 .41075 .47825 .42291 .4734 .41578 .46513 Metetra
1 0 0 r
.41578 .46513 .42291 .4734 .43513 .46853 .42803 .46025 Metetra
1 0 0 r
.42803 .46025 .43513 .46853 .44739 .46366 .44032 .45539 Metetra
1 0 0 r
.44032 .45539 .44739 .46366 .4597 .45881 .45267 .45056 Metetra
1 0 0 r
.45267 .45056 .4597 .45881 .47206 .454 .46506 .44578 Metetra
1 0 0 r
.46506 .44578 .47206 .454 .48447 .44923 .4775 .44107 Metetra
1 0 0 r
.4775 .44107 .48447 .44923 .49693 .44453 .48999 .43644 Metetra
1 0 0 r
.48999 .43644 .49693 .44453 .50944 .43991 .50254 .4319 Metetra
1 0 0 r
.50254 .4319 .50944 .43991 .522 .43539 .51514 .42748 Metetra
1 0 0 r
.51514 .42748 .522 .43539 .53462 .43098 .52779 .4232 Metetra
1 0 0 r
.52779 .4232 .53462 .43098 .54729 .42672 .5405 .41906 Metetra
1 0 0 r
.5405 .41906 .54729 .42672 .56003 .4226 .55328 .4151 Metetra
1 0 0 r
.55328 .4151 .56003 .4226 .57282 .41866 .56612 .41132 Metetra
1 0 0 r
.56612 .41132 .57282 .41866 .58568 .41491 .57902 .40776 Metetra
1 0 0 r
.57902 .40776 .58568 .41491 .59861 .41138 .59199 .40443 Metetra
1 0 0 r
.59199 .40443 .59861 .41138 .61161 .40808 .60504 .40135 Metetra
1 0 0 r
.60504 .40135 .61161 .40808 .62469 .40504 .61817 .39855 Metetra
1 0 0 r
.61817 .39855 .62469 .40504 .63784 .40228 .63138 .39604 Metetra
1 0 0 r
.63138 .39604 .63784 .40228 .65109 .39982 .64468 .39387 Metetra
1 0 0 r
.64468 .39387 .65109 .39982 .66443 .39769 .65808 .39204 Metetra
1 0 0 r
.65808 .39204 .66443 .39769 .67786 .39593 .67158 .39059 Metetra
1 0 0 r
.67158 .39059 .67786 .39593 .6914 .39454 .68519 .38954 Metetra
1 0 0 r
.68519 .38954 .6914 .39454 .70506 .39357 .69892 .38893 Metetra
1 0 0 r
.69892 .38893 .70506 .39357 .71883 .39304 .71277 .38878 Metetra
1 0 0 r
.71277 .38878 .71883 .39304 .73274 .39298 .72676 .38913 Metetra
1 0 0 r
.72676 .38913 .73274 .39298 .74678 .39343 .74089 .39002 Metetra
1 0 0 r
.74089 .39002 .74678 .39343 .76097 .39443 .75518 .39147 Metetra
1 0 0 r
.75518 .39147 .76097 .39443 .77533 .39601 .76963 .39353 Metetra
1 0 0 r
.76963 .39353 .77533 .39601 .78986 .39821 .78427 .39624 Metetra
1 0 0 r
.78427 .39624 .78986 .39821 .80457 .40107 .7991 .39964 Metetra
1 0 0 r
.7991 .39964 .80457 .40107 .81949 .40463 .81414 .40378 Metetra
1 0 0 r
.81414 .40378 .81949 .40463 .83462 .40896 .8294 .40871 Metetra
1 0 0 r
.8294 .40871 .83462 .40896 .84999 .41408 .84491 .41448 Metetra
1 0 0 r
.84491 .41448 .84999 .41408 .86562 .42007 .86069 .42115 Metetra
1 0 0 r
.21901 .52778 .22681 .53413 .23818 .53084 .23043 .52426 Metetra
1 0 0 r
.23043 .52426 .23818 .53084 .24962 .52736 .24192 .52055 Metetra
1 0 0 r
.24192 .52055 .24962 .52736 .26113 .52369 .25347 .51668 Metetra
1 0 0 r
.25347 .51668 .26113 .52369 .27269 .51985 .26508 .51265 Metetra
1 0 0 r
.26508 .51265 .27269 .51985 .28432 .51586 .27675 .50848 Metetra
1 0 0 r
.27675 .50848 .28432 .51586 .29601 .51172 .28847 .50418 Metetra
1 0 0 r
.28847 .50418 .29601 .51172 .30775 .50744 .30026 .49976 Metetra
1 0 0 r
.30026 .49976 .30775 .50744 .31955 .50305 .31209 .49524 Metetra
1 0 0 r
.31209 .49524 .31955 .50305 .3314 .49855 .32398 .49062 Metetra
1 0 0 r
.32398 .49062 .3314 .49855 .34331 .49395 .33592 .48592 Metetra
1 0 0 r
.33592 .48592 .34331 .49395 .35526 .48927 .34791 .48116 Metetra
1 0 0 r
.34791 .48116 .35526 .48927 .36727 .48452 .35995 .47634 Metetra
1 0 0 r
.35995 .47634 .36727 .48452 .37932 .47972 .37204 .47148 Metetra
1 0 0 r
.37204 .47148 .37932 .47972 .39143 .47488 .38417 .4666 Metetra
1 0 0 r
.38417 .4666 .39143 .47488 .40358 .47001 .39636 .46171 Metetra
1 0 0 r
.39636 .46171 .40358 .47001 .41578 .46513 .40859 .45682 Metetra
1 0 0 r
.40859 .45682 .41578 .46513 .42803 .46025 .42087 .45195 Metetra
1 0 0 r
.42087 .45195 .42803 .46025 .44032 .45539 .4332 .44711 Metetra
1 0 0 r
.4332 .44711 .44032 .45539 .45267 .45056 .44557 .44232 Metetra
1 0 0 r
.44557 .44232 .45267 .45056 .46506 .44578 .458 .43759 Metetra
1 0 0 r
.458 .43759 .46506 .44578 .4775 .44107 .47047 .43295 Metetra
1 0 0 r
.47047 .43295 .4775 .44107 .48999 .43644 .483 .4284 Metetra
1 0 0 r
.483 .4284 .48999 .43644 .50254 .4319 .49558 .42397 Metetra
1 0 0 r
.49558 .42397 .50254 .4319 .51514 .42748 .50822 .41966 Metetra
1 0 0 r
.50822 .41966 .51514 .42748 .52779 .4232 .52091 .41551 Metetra
1 0 0 r
.52091 .41551 .52779 .4232 .5405 .41906 .53366 .41153 Metetra
1 0 0 r
.53366 .41153 .5405 .41906 .55328 .4151 .54647 .40773 Metetra
1 0 0 r
.54647 .40773 .55328 .4151 .56612 .41132 .55935 .40414 Metetra
1 0 0 r
.55935 .40414 .56612 .41132 .57902 .40776 .5723 .40078 Metetra
1 0 0 r
.5723 .40078 .57902 .40776 .59199 .40443 .58532 .39767 Metetra
1 0 0 r
.58532 .39767 .59199 .40443 .60504 .40135 .59842 .39483 Metetra
1 0 0 r
.59842 .39483 .60504 .40135 .61817 .39855 .6116 .39228 Metetra
1 0 0 r
.6116 .39228 .61817 .39855 .63138 .39604 .62487 .39005 Metetra
1 0 0 r
.62487 .39005 .63138 .39604 .64468 .39387 .63823 .38817 Metetra
1 0 0 r
.63823 .38817 .64468 .39387 .65808 .39204 .65169 .38666 Metetra
1 0 0 r
.65169 .38666 .65808 .39204 .67158 .39059 .66525 .38554 Metetra
1 0 0 r
.66525 .38554 .67158 .39059 .68519 .38954 .67893 .38485 Metetra
1 0 0 r
.67893 .38485 .68519 .38954 .69892 .38893 .69273 .38462 Metetra
1 0 0 r
.69273 .38462 .69892 .38893 .71277 .38878 .70666 .38488 Metetra
1 0 0 r
.70666 .38488 .71277 .38878 .72676 .38913 .72073 .38566 Metetra
1 0 0 r
.72073 .38566 .72676 .38913 .74089 .39002 .73495 .38699 Metetra
1 0 0 r
.73495 .38699 .74089 .39002 .75518 .39147 .74934 .38893 Metetra
1 0 0 r
.74934 .38893 .75518 .39147 .76963 .39353 .7639 .3915 Metetra
1 0 0 r
.7639 .3915 .76963 .39353 .78427 .39624 .77864 .39474 Metetra
1 0 0 r
.77864 .39474 .78427 .39624 .7991 .39964 .79359 .39871 Metetra
1 0 0 r
.79359 .39871 .7991 .39964 .81414 .40378 .80876 .40346 Metetra
1 0 0 r
.80876 .40346 .81414 .40378 .8294 .40871 .82416 .40902 Metetra
1 0 0 r
.82416 .40902 .8294 .40871 .84491 .41448 .83981 .41547 Metetra
1 0 0 r
.83981 .41547 .84491 .41448 .86069 .42115 .85574 .42285 Metetra
1 0 0 r
.21117 .52114 .21901 .52778 .23043 .52426 .22264 .5174 Metetra
1 0 0 r
.22264 .5174 .23043 .52426 .24192 .52055 .23417 .51349 Metetra
1 0 0 r
.23417 .51349 .24192 .52055 .25347 .51668 .24576 .50943 Metetra
1 0 0 r
.24576 .50943 .25347 .51668 .26508 .51265 .25741 .50523 Metetra
1 0 0 r
.25741 .50523 .26508 .51265 .27675 .50848 .26912 .5009 Metetra
1 0 0 r
.26912 .5009 .27675 .50848 .28847 .50418 .28089 .49645 Metetra
1 0 0 r
.28089 .49645 .28847 .50418 .30026 .49976 .29271 .4919 Metetra
1 0 0 r
.29271 .4919 .30026 .49976 .31209 .49524 .30458 .48726 Metetra
1 0 0 r
.30458 .48726 .31209 .49524 .32398 .49062 .3165 .48255 Metetra
1 0 0 r
.3165 .48255 .32398 .49062 .33592 .48592 .32848 .47777 Metetra
1 0 0 r
.32848 .47777 .33592 .48592 .34791 .48116 .3405 .47293 Metetra
1 0 0 r
.3405 .47293 .34791 .48116 .35995 .47634 .35257 .46806 Metetra
1 0 0 r
.35257 .46806 .35995 .47634 .37204 .47148 .36469 .46317 Metetra
1 0 0 r
.36469 .46317 .37204 .47148 .38417 .4666 .37686 .45826 Metetra
1 0 0 r
.37686 .45826 .38417 .4666 .39636 .46171 .38908 .45336 Metetra
1 0 0 r
.38908 .45336 .39636 .46171 .40859 .45682 .40134 .44848 Metetra
1 0 0 r
.40134 .44848 .40859 .45682 .42087 .45195 .41365 .44363 Metetra
1 0 0 r
.41365 .44363 .42087 .45195 .4332 .44711 .42601 .43883 Metetra
1 0 0 r
.42601 .43883 .4332 .44711 .44557 .44232 .43842 .4341 Metetra
1 0 0 r
.43842 .4341 .44557 .44232 .458 .43759 .45088 .42944 Metetra
1 0 0 r
.45088 .42944 .458 .43759 .47047 .43295 .46339 .42488 Metetra
1 0 0 r
.46339 .42488 .47047 .43295 .483 .4284 .47595 .42043 Metetra
1 0 0 r
.47595 .42043 .483 .4284 .49558 .42397 .48856 .41612 Metetra
1 0 0 r
.48856 .41612 .49558 .42397 .50822 .41966 .50124 .41195 Metetra
1 0 0 r
.50124 .41195 .50822 .41966 .52091 .41551 .51397 .40795 Metetra
1 0 0 r
.51397 .40795 .52091 .41551 .53366 .41153 .52676 .40413 Metetra
1 0 0 r
.52676 .40413 .53366 .41153 .54647 .40773 .53961 .40051 Metetra
1 0 0 r
.53961 .40051 .54647 .40773 .55935 .40414 .55253 .39713 Metetra
1 0 0 r
.55253 .39713 .55935 .40414 .5723 .40078 .56553 .39398 Metetra
1 0 0 r
.56553 .39398 .5723 .40078 .58532 .39767 .57859 .39111 Metetra
1 0 0 r
.57859 .39111 .58532 .39767 .59842 .39483 .59174 .38852 Metetra
1 0 0 r
.59174 .38852 .59842 .39483 .6116 .39228 .60497 .38625 Metetra
1 0 0 r
.60497 .38625 .6116 .39228 .62487 .39005 .6183 .38432 Metetra
1 0 0 r
.6183 .38432 .62487 .39005 .63823 .38817 .63172 .38275 Metetra
1 0 0 r
.63172 .38275 .63823 .38817 .65169 .38666 .64524 .38157 Metetra
1 0 0 r
.64524 .38157 .65169 .38666 .66525 .38554 .65887 .38081 Metetra
1 0 0 r
.65887 .38081 .66525 .38554 .67893 .38485 .67262 .3805 Metetra
1 0 0 r
.67262 .3805 .67893 .38485 .69273 .38462 .6865 .38067 Metetra
1 0 0 r
.6865 .38067 .69273 .38462 .70666 .38488 .70051 .38135 Metetra
1 0 0 r
.70051 .38135 .70666 .38488 .72073 .38566 .71466 .38258 Metetra
1 0 0 r
.71466 .38258 .72073 .38566 .73495 .38699 .72898 .3844 Metetra
1 0 0 r
.72898 .3844 .73495 .38699 .74934 .38893 .74346 .38683 Metetra
1 0 0 r
.74346 .38683 .74934 .38893 .7639 .3915 .75812 .38993 Metetra
1 0 0 r
.75812 .38993 .7639 .3915 .77864 .39474 .77298 .39375 Metetra
1 0 0 r
.77298 .39375 .77864 .39474 .79359 .39871 .78805 .39831 Metetra
1 0 0 r
.78805 .39831 .79359 .39871 .80876 .40346 .80335 .40368 Metetra
1 0 0 r
.80335 .40368 .80876 .40346 .82416 .40902 .81889 .40992 Metetra
1 0 0 r
.81889 .40992 .82416 .40902 .83981 .41547 .83469 .41707 Metetra
1 0 0 r
.83469 .41707 .83981 .41547 .85574 .42285 .85079 .4252 Metetra
1 0 0 r
.20329 .51423 .21117 .52114 .22264 .5174 .2148 .51028 Metetra
1 0 0 r
.2148 .51028 .22264 .5174 .23417 .51349 .22638 .50618 Metetra
1 0 0 r
.22638 .50618 .23417 .51349 .24576 .50943 .23801 .50195 Metetra
1 0 0 r
.23801 .50195 .24576 .50943 .25741 .50523 .2497 .49759 Metetra
1 0 0 r
.2497 .49759 .25741 .50523 .26912 .5009 .26145 .49312 Metetra
1 0 0 r
.26145 .49312 .26912 .5009 .28089 .49645 .27325 .48855 Metetra
1 0 0 r
.27325 .48855 .28089 .49645 .29271 .4919 .28511 .48389 Metetra
1 0 0 r
.28511 .48389 .29271 .4919 .30458 .48726 .29701 .47915 Metetra
1 0 0 r
.29701 .47915 .30458 .48726 .3165 .48255 .30897 .47435 Metetra
1 0 0 r
.30897 .47435 .3165 .48255 .32848 .47777 .32098 .4695 Metetra
1 0 0 r
.32098 .4695 .32848 .47777 .3405 .47293 .33304 .46462 Metetra
1 0 0 r
.33304 .46462 .3405 .47293 .35257 .46806 .34514 .45971 Metetra
1 0 0 r
.34514 .45971 .35257 .46806 .36469 .46317 .35729 .4548 Metetra
1 0 0 r
.35729 .4548 .36469 .46317 .37686 .45826 .36949 .44988 Metetra
1 0 0 r
.36949 .44988 .37686 .45826 .38908 .45336 .38174 .44499 Metetra
1 0 0 r
.38174 .44499 .38908 .45336 .40134 .44848 .39403 .44013 Metetra
1 0 0 r
.39403 .44013 .40134 .44848 .41365 .44363 .40638 .43533 Metetra
1 0 0 r
.40638 .43533 .41365 .44363 .42601 .43883 .41877 .43058 Metetra
1 0 0 r
.41877 .43058 .42601 .43883 .43842 .4341 .43121 .42591 Metetra
1 0 0 r
.43121 .42591 .43842 .4341 .45088 .42944 .4437 .42134 Metetra
1 0 0 r
.4437 .42134 .45088 .42944 .46339 .42488 .45624 .41689 Metetra
1 0 0 r
.45624 .41689 .46339 .42488 .47595 .42043 .46884 .41256 Metetra
1 0 0 r
.46884 .41256 .47595 .42043 .48856 .41612 .48149 .40837 Metetra
1 0 0 r
.48149 .40837 .48856 .41612 .50124 .41195 .49419 .40436 Metetra
1 0 0 r
.49419 .40436 .50124 .41195 .51397 .40795 .50696 .40052 Metetra
1 0 0 r
.50696 .40052 .51397 .40795 .52676 .40413 .51979 .39689 Metetra
1 0 0 r
.51979 .39689 .52676 .40413 .53961 .40051 .53269 .39347 Metetra
1 0 0 r
.53269 .39347 .53961 .40051 .55253 .39713 .54565 .3903 Metetra
1 0 0 r
.54565 .3903 .55253 .39713 .56553 .39398 .55869 .3874 Metetra
1 0 0 r
.55869 .3874 .56553 .39398 .57859 .39111 .57181 .38478 Metetra
1 0 0 r
.57181 .38478 .57859 .39111 .59174 .38852 .585 .38247 Metetra
1 0 0 r
.585 .38247 .59174 .38852 .60497 .38625 .59829 .38049 Metetra
1 0 0 r
.59829 .38049 .60497 .38625 .6183 .38432 .61167 .37887 Metetra
1 0 0 r
.61167 .37887 .6183 .38432 .63172 .38275 .62515 .37763 Metetra
1 0 0 r
.62515 .37763 .63172 .38275 .64524 .38157 .63873 .3768 Metetra
1 0 0 r
.63873 .3768 .64524 .38157 .65887 .38081 .65243 .37642 Metetra
1 0 0 r
.65243 .37642 .65887 .38081 .67262 .3805 .66625 .37651 Metetra
1 0 0 r
.66625 .37651 .67262 .3805 .6865 .38067 .68021 .3771 Metetra
1 0 0 r
.68021 .3771 .6865 .38067 .70051 .38135 .6943 .37823 Metetra
1 0 0 r
.6943 .37823 .70051 .38135 .71466 .38258 .70855 .37993 Metetra
1 0 0 r
.70855 .37993 .71466 .38258 .72898 .3844 .72295 .38225 Metetra
1 0 0 r
.72295 .38225 .72898 .3844 .74346 .38683 .73754 .38521 Metetra
1 0 0 r
.73754 .38521 .74346 .38683 .75812 .38993 .75231 .38887 Metetra
1 0 0 r
.75231 .38887 .75812 .38993 .77298 .39375 .76728 .39328 Metetra
1 0 0 r
.76728 .39328 .77298 .39375 .78805 .39831 .78248 .39847 Metetra
1 0 0 r
.78248 .39847 .78805 .39831 .80335 .40368 .79791 .4045 Metetra
1 0 0 r
.79791 .4045 .80335 .40368 .81889 .40992 .81359 .41143 Metetra
1 0 0 r
.81359 .41143 .81889 .40992 .83469 .41707 .82955 .41932 Metetra
1 0 0 r
.82955 .41932 .83469 .41707 .85079 .4252 .84581 .42823 Metetra
1 0 0 r
.19536 .50705 .20329 .51423 .2148 .51028 .20692 .50292 Metetra
1 0 0 r
.20692 .50292 .2148 .51028 .22638 .50618 .21853 .49865 Metetra
1 0 0 r
.21853 .49865 .22638 .50618 .23801 .50195 .23021 .49427 Metetra
1 0 0 r
.23021 .49427 .23801 .50195 .2497 .49759 .24194 .48977 Metetra
1 0 0 r
.24194 .48977 .2497 .49759 .26145 .49312 .25372 .48517 Metetra
1 0 0 r
.25372 .48517 .26145 .49312 .27325 .48855 .26556 .48049 Metetra
1 0 0 r
.26556 .48049 .27325 .48855 .28511 .48389 .27745 .47573 Metetra
1 0 0 r
.27745 .47573 .28511 .48389 .29701 .47915 .2894 .47092 Metetra
1 0 0 r
.2894 .47092 .29701 .47915 .30897 .47435 .30139 .46605 Metetra
1 0 0 r
.30139 .46605 .30897 .47435 .32098 .4695 .31343 .46115 Metetra
1 0 0 r
.31343 .46115 .32098 .4695 .33304 .46462 .32551 .45623 Metetra
1 0 0 r
.32551 .45623 .33304 .46462 .34514 .45971 .33765 .45131 Metetra
1 0 0 r
.33765 .45131 .34514 .45971 .35729 .4548 .34983 .44638 Metetra
1 0 0 r
.34983 .44638 .35729 .4548 .36949 .44988 .36206 .44148 Metetra
1 0 0 r
.36206 .44148 .36949 .44988 .38174 .44499 .37434 .43662 Metetra
1 0 0 r
.37434 .43662 .38174 .44499 .39403 .44013 .38667 .4318 Metetra
1 0 0 r
.38667 .4318 .39403 .44013 .40638 .43533 .39904 .42704 Metetra
1 0 0 r
.39904 .42704 .40638 .43533 .41877 .43058 .41146 .42237 Metetra
1 0 0 r
.41146 .42237 .41877 .43058 .43121 .42591 .42393 .41779 Metetra
1 0 0 r
.42393 .41779 .43121 .42591 .4437 .42134 .43645 .41332 Metetra
1 0 0 r
.43645 .41332 .4437 .42134 .45624 .41689 .44903 .40898 Metetra
1 0 0 r
.44903 .40898 .45624 .41689 .46884 .41256 .46166 .40479 Metetra
1 0 0 r
.46166 .40479 .46884 .41256 .48149 .40837 .47434 .40076 Metetra
1 0 0 r
.47434 .40076 .48149 .40837 .49419 .40436 .48709 .39691 Metetra
1 0 0 r
.48709 .39691 .49419 .40436 .50696 .40052 .49989 .39325 Metetra
1 0 0 r
.49989 .39325 .50696 .40052 .51979 .39689 .51276 .38982 Metetra
1 0 0 r
.51276 .38982 .51979 .39689 .53269 .39347 .5257 .38663 Metetra
1 0 0 r
.5257 .38663 .53269 .39347 .54565 .3903 .53871 .38369 Metetra
1 0 0 r
.53871 .38369 .54565 .3903 .55869 .3874 .55179 .38104 Metetra
1 0 0 r
.55179 .38104 .55869 .3874 .57181 .38478 .56495 .37869 Metetra
1 0 0 r
.56495 .37869 .57181 .38478 .585 .38247 .5782 .37667 Metetra
1 0 0 r
.5782 .37667 .585 .38247 .59829 .38049 .59154 .375 Metetra
1 0 0 r
.59154 .375 .59829 .38049 .61167 .37887 .60498 .37371 Metetra
1 0 0 r
.60498 .37371 .61167 .37887 .62515 .37763 .61852 .37283 Metetra
1 0 0 r
.61852 .37283 .62515 .37763 .63873 .3768 .63217 .37238 Metetra
1 0 0 r
.63217 .37238 .63873 .3768 .65243 .37642 .64594 .37239 Metetra
1 0 0 r
.64594 .37239 .65243 .37642 .66625 .37651 .65983 .3729 Metetra
1 0 0 r
.65983 .3729 .66625 .37651 .68021 .3771 .67387 .37394 Metetra
1 0 0 r
.67387 .37394 .68021 .3771 .6943 .37823 .68804 .37554 Metetra
1 0 0 r
.68804 .37554 .6943 .37823 .70855 .37993 .70238 .37773 Metetra
1 0 0 r
.70238 .37773 .70855 .37993 .72295 .38225 .71688 .38057 Metetra
1 0 0 r
.71688 .38057 .72295 .38225 .73754 .38521 .73157 .3841 Metetra
1 0 0 r
.73157 .3841 .73754 .38521 .75231 .38887 .74645 .38834 Metetra
1 0 0 r
.74645 .38834 .75231 .38887 .76728 .39328 .76155 .39336 Metetra
1 0 0 r
.76155 .39336 .76728 .39328 .78248 .39847 .77687 .39921 Metetra
1 0 0 r
.77687 .39921 .78248 .39847 .79791 .4045 .79244 .40594 Metetra
1 0 0 r
.79244 .40594 .79791 .4045 .81359 .41143 .80827 .4136 Metetra
1 0 0 r
.80827 .4136 .81359 .41143 .82955 .41932 .82439 .42226 Metetra
1 0 0 r
.82439 .42226 .82955 .41932 .84581 .42823 .84082 .432 Metetra
1 0 0 r
.18739 .49964 .19536 .50705 .20692 .50292 .19898 .49534 Metetra
1 0 0 r
.19898 .49534 .20692 .50292 .21853 .49865 .21064 .49092 Metetra
1 0 0 r
.21064 .49092 .21853 .49865 .23021 .49427 .22235 .48639 Metetra
1 0 0 r
.22235 .48639 .23021 .49427 .24194 .48977 .23412 .48177 Metetra
1 0 0 r
.23412 .48177 .24194 .48977 .25372 .48517 .24595 .47707 Metetra
1 0 0 r
.24595 .47707 .25372 .48517 .26556 .48049 .25782 .47229 Metetra
1 0 0 r
.25782 .47229 .26556 .48049 .27745 .47573 .26974 .46746 Metetra
1 0 0 r
.26974 .46746 .27745 .47573 .2894 .47092 .28172 .46258 Metetra
1 0 0 r
.28172 .46258 .2894 .47092 .30139 .46605 .29374 .45766 Metetra
1 0 0 r
.29374 .45766 .30139 .46605 .31343 .46115 .30581 .45273 Metetra
1 0 0 r
.30581 .45273 .31343 .46115 .32551 .45623 .31793 .44779 Metetra
1 0 0 r
.31793 .44779 .32551 .45623 .33765 .45131 .3301 .44286 Metetra
1 0 0 r
.3301 .44286 .33765 .45131 .34983 .44638 .34231 .43795 Metetra
1 0 0 r
.34231 .43795 .34983 .44638 .36206 .44148 .35457 .43308 Metetra
1 0 0 r
.35457 .43308 .36206 .44148 .37434 .43662 .36688 .42825 Metetra
1 0 0 r
.36688 .42825 .37434 .43662 .38667 .4318 .37923 .42349 Metetra
1 0 0 r
.37923 .42349 .38667 .4318 .39904 .42704 .39164 .41881 Metetra
1 0 0 r
.39164 .41881 .39904 .42704 .41146 .42237 .40409 .41422 Metetra
1 0 0 r
.40409 .41422 .41146 .42237 .42393 .41779 .41659 .40975 Metetra
1 0 0 r
.41659 .40975 .42393 .41779 .43645 .41332 .42915 .4054 Metetra
1 0 0 r
.42915 .4054 .43645 .41332 .44903 .40898 .44175 .40119 Metetra
1 0 0 r
.44175 .40119 .44903 .40898 .46166 .40479 .45441 .39715 Metetra
1 0 0 r
.45441 .39715 .46166 .40479 .47434 .40076 .46713 .39328 Metetra
1 0 0 r
.46713 .39328 .47434 .40076 .48709 .39691 .47991 .38962 Metetra
1 0 0 r
.47991 .38962 .48709 .39691 .49989 .39325 .49276 .38616 Metetra
1 0 0 r
.49276 .38616 .49989 .39325 .51276 .38982 .50566 .38295 Metetra
1 0 0 r
.50566 .38295 .51276 .38982 .5257 .38663 .51864 .37999 Metetra
1 0 0 r
.51864 .37999 .5257 .38663 .53871 .38369 .53169 .37731 Metetra
1 0 0 r
.53169 .37731 .53871 .38369 .55179 .38104 .54482 .37493 Metetra
1 0 0 r
.54482 .37493 .55179 .38104 .56495 .37869 .55804 .37287 Metetra
1 0 0 r
.55804 .37287 .56495 .37869 .5782 .37667 .57134 .37116 Metetra
1 0 0 r
.57134 .37116 .5782 .37667 .59154 .375 .58473 .36982 Metetra
1 0 0 r
.58473 .36982 .59154 .375 .60498 .37371 .59823 .36889 Metetra
1 0 0 r
.59823 .36889 .60498 .37371 .61852 .37283 .61183 .36837 Metetra
1 0 0 r
.61183 .36837 .61852 .37283 .63217 .37238 .62554 .36832 Metetra
1 0 0 r
.62554 .36832 .63217 .37238 .64594 .37239 .63938 .36875 Metetra
1 0 0 r
.63938 .36875 .64594 .37239 .65983 .3729 .65335 .3697 Metetra
1 0 0 r
.65335 .3697 .65983 .3729 .67387 .37394 .66747 .3712 Metetra
1 0 0 r
.66747 .3712 .67387 .37394 .68804 .37554 .68173 .3733 Metetra
1 0 0 r
.68173 .3733 .68804 .37554 .70238 .37773 .69616 .37602 Metetra
1 0 0 r
.69616 .37602 .70238 .37773 .71688 .38057 .71076 .37941 Metetra
1 0 0 r
.71076 .37941 .71688 .38057 .73157 .3841 .72555 .38351 Metetra
1 0 0 r
.72555 .38351 .73157 .3841 .74645 .38834 .74055 .38837 Metetra
1 0 0 r
.74055 .38837 .74645 .38834 .76155 .39336 .75577 .39405 Metetra
1 0 0 r
.75577 .39405 .76155 .39336 .77687 .39921 .77122 .40058 Metetra
1 0 0 r
.77122 .40058 .77687 .39921 .79244 .40594 .78693 .40803 Metetra
1 0 0 r
.78693 .40803 .79244 .40594 .80827 .4136 .80291 .41646 Metetra
1 0 0 r
.80291 .41646 .80827 .4136 .82439 .42226 .8192 .42594 Metetra
1 0 0 r
.8192 .42594 .82439 .42226 .84082 .432 .83486 .42662 Metetra
1 0 0 r
.17936 .492 .18739 .49964 .19898 .49534 .191 .48755 Metetra
1 0 0 r
.191 .48755 .19898 .49534 .21064 .49092 .2027 .483 Metetra
1 0 0 r
.2027 .483 .21064 .49092 .22235 .48639 .21445 .47835 Metetra
1 0 0 r
.21445 .47835 .22235 .48639 .23412 .48177 .22626 .47362 Metetra
1 0 0 r
.22626 .47362 .23412 .48177 .24595 .47707 .23811 .46883 Metetra
1 0 0 r
.23811 .46883 .24595 .47707 .25782 .47229 .25002 .46397 Metetra
1 0 0 r
.25002 .46397 .25782 .47229 .26974 .46746 .26198 .45908 Metetra
1 0 0 r
.26198 .45908 .26974 .46746 .28172 .46258 .27399 .45415 Metetra
1 0 0 r
.27399 .45415 .28172 .46258 .29374 .45766 .28604 .44921 Metetra
1 0 0 r
.28604 .44921 .29374 .45766 .30581 .45273 .29814 .44426 Metetra
1 0 0 r
.29814 .44426 .30581 .45273 .31793 .44779 .31029 .43932 Metetra
1 0 0 r
.31029 .43932 .31793 .44779 .3301 .44286 .32249 .4344 Metetra
1 0 0 r
.32249 .4344 .3301 .44286 .34231 .43795 .33473 .42952 Metetra
1 0 0 r
.33473 .42952 .34231 .43795 .35457 .43308 .34702 .42469 Metetra
1 0 0 r
.34702 .42469 .35457 .43308 .36688 .42825 .35935 .41992 Metetra
1 0 0 r
.35935 .41992 .36688 .42825 .37923 .42349 .37174 .41523 Metetra
1 0 0 r
.37174 .41523 .37923 .42349 .39164 .41881 .38417 .41064 Metetra
1 0 0 r
.38417 .41064 .39164 .41881 .40409 .41422 .39665 .40615 Metetra
1 0 0 r
.39665 .40615 .40409 .41422 .41659 .40975 .40918 .4018 Metetra
1 0 0 r
.40918 .4018 .41659 .40975 .42915 .4054 .42177 .39758 Metetra
1 0 0 r
.42177 .39758 .42915 .4054 .44175 .40119 .43441 .39353 Metetra
1 0 0 r
.43441 .39353 .44175 .40119 .45441 .39715 .4471 .38966 Metetra
1 0 0 r
.4471 .38966 .45441 .39715 .46713 .39328 .45986 .38597 Metetra
1 0 0 r
.45986 .38597 .46713 .39328 .47991 .38962 .47267 .38251 Metetra
1 0 0 r
.47267 .38251 .47991 .38962 .49276 .38616 .48555 .37927 Metetra
1 0 0 r
.48555 .37927 .49276 .38616 .50566 .38295 .4985 .37629 Metetra
1 0 0 r
.4985 .37629 .50566 .38295 .51864 .37999 .51152 .37359 Metetra
1 0 0 r
.51152 .37359 .51864 .37999 .53169 .37731 .52461 .37118 Metetra
1 0 0 r
.52461 .37118 .53169 .37731 .54482 .37493 .53779 .36909 Metetra
1 0 0 r
.53779 .36909 .54482 .37493 .55804 .37287 .55105 .36734 Metetra
1 0 0 r
.55105 .36734 .55804 .37287 .57134 .37116 .5644 .36596 Metetra
1 0 0 r
.5644 .36596 .57134 .37116 .58473 .36982 .57785 .36497 Metetra
1 0 0 r
.57785 .36497 .58473 .36982 .59823 .36889 .59141 .36441 Metetra
1 0 0 r
.59141 .36441 .59823 .36889 .61183 .36837 .60507 .36429 Metetra
1 0 0 r
.60507 .36429 .61183 .36837 .62554 .36832 .61885 .36465 Metetra
1 0 0 r
.61885 .36465 .62554 .36832 .63938 .36875 .63276 .36552 Metetra
1 0 0 r
.63276 .36552 .63938 .36875 .65335 .3697 .64681 .36693 Metetra
1 0 0 r
.64681 .36693 .65335 .3697 .66747 .3712 .66101 .36893 Metetra
1 0 0 r
.66101 .36893 .66747 .3712 .68173 .3733 .67536 .37154 Metetra
1 0 0 r
.67536 .37154 .68173 .3733 .69616 .37602 .68988 .37481 Metetra
1 0 0 r
.68988 .37481 .69616 .37602 .71076 .37941 .70459 .37878 Metetra
1 0 0 r
.70459 .37878 .71076 .37941 .72555 .38351 .71949 .38349 Metetra
1 0 0 r
.71949 .38349 .72555 .38351 .74055 .38837 .7346 .389 Metetra
1 0 0 r
.7346 .389 .74055 .38837 .75577 .39405 .74994 .39536 Metetra
1 0 0 r
.74994 .39536 .75577 .39405 .77122 .40058 .76553 .40261 Metetra
1 0 0 r
.76553 .40261 .77122 .40058 .78693 .40803 .78139 .41082 Metetra
1 0 0 r
.78139 .41082 .78693 .40803 .80291 .41646 .79753 .42006 Metetra
1 0 0 r
.79753 .42006 .80291 .41646 .8192 .42594 .81329 .42264 Metetra
1 0 0 r
.81329 .42264 .8192 .42594 .83486 .42662 .82852 .41792 Metetra
1 0 0 r
.17129 .48416 .17936 .492 .191 .48755 .18297 .47957 Metetra
1 0 0 r
.18297 .47957 .191 .48755 .2027 .483 .1947 .4749 Metetra
1 0 0 r
.1947 .4749 .2027 .483 .21445 .47835 .20649 .47015 Metetra
1 0 0 r
.20649 .47015 .21445 .47835 .22626 .47362 .21833 .46534 Metetra
1 0 0 r
.21833 .46534 .22626 .47362 .23811 .46883 .23022 .46047 Metetra
1 0 0 r
.23022 .46047 .23811 .46883 .25002 .46397 .24216 .45556 Metetra
1 0 0 r
.24216 .45556 .25002 .46397 .26198 .45908 .25415 .45062 Metetra
1 0 0 r
.25415 .45062 .26198 .45908 .27399 .45415 .26619 .44566 Metetra
1 0 0 r
.26619 .44566 .27399 .45415 .28604 .44921 .27828 .4407 Metetra
1 0 0 r
.27828 .4407 .28604 .44921 .29814 .44426 .29041 .43575 Metetra
1 0 0 r
.29041 .43575 .29814 .44426 .31029 .43932 .30258 .43083 Metetra
1 0 0 r
.30258 .43083 .31029 .43932 .32249 .4344 .31481 .42594 Metetra
1 0 0 r
.31481 .42594 .32249 .4344 .33473 .42952 .32708 .4211 Metetra
1 0 0 r
.32708 .4211 .33473 .42952 .34702 .42469 .3394 .41633 Metetra
1 0 0 r
.3394 .41633 .34702 .42469 .35935 .41992 .35176 .41163 Metetra
1 0 0 r
.35176 .41163 .35935 .41992 .37174 .41523 .36417 .40704 Metetra
1 0 0 r
.36417 .40704 .37174 .41523 .38417 .41064 .37663 .40255 Metetra
1 0 0 r
.37663 .40255 .38417 .41064 .39665 .40615 .38914 .39819 Metetra
1 0 0 r
.38914 .39819 .39665 .40615 .40918 .4018 .4017 .39397 Metetra
1 0 0 r
.4017 .39397 .40918 .4018 .42177 .39758 .41432 .38991 Metetra
1 0 0 r
.41432 .38991 .42177 .39758 .43441 .39353 .42699 .38602 Metetra
1 0 0 r
.42699 .38602 .43441 .39353 .4471 .38966 .43972 .38233 Metetra
1 0 0 r
.43972 .38233 .4471 .38966 .45986 .38597 .45251 .37885 Metetra
1 0 0 r
.45251 .37885 .45986 .38597 .47267 .38251 .46536 .3756 Metetra
1 0 0 r
.46536 .3756 .47267 .38251 .48555 .37927 .47827 .3726 Metetra
1 0 0 r
.47827 .3726 .48555 .37927 .4985 .37629 .49126 .36988 Metetra
1 0 0 r
.49126 .36988 .4985 .37629 .51152 .37359 .50432 .36744 Metetra
1 0 0 r
.50432 .36744 .51152 .37359 .52461 .37118 .51746 .36532 Metetra
1 0 0 r
.51746 .36532 .52461 .37118 .53779 .36909 .53068 .36354 Metetra
1 0 0 r
.53068 .36354 .53779 .36909 .55105 .36734 .54399 .36212 Metetra
1 0 0 r
.54399 .36212 .55105 .36734 .5644 .36596 .5574 .36109 Metetra
1 0 0 r
.5574 .36109 .5644 .36596 .57785 .36497 .5709 .36047 Metetra
1 0 0 r
.5709 .36047 .57785 .36497 .59141 .36441 .58452 .3603 Metetra
1 0 0 r
.58452 .3603 .59141 .36441 .60507 .36429 .59824 .3606 Metetra
1 0 0 r
.59824 .3606 .60507 .36429 .61885 .36465 .6121 .36139 Metetra
1 0 0 r
.6121 .36139 .61885 .36465 .63276 .36552 .62608 .36273 Metetra
1 0 0 r
.62608 .36273 .63276 .36552 .64681 .36693 .6402 .36463 Metetra
1 0 0 r
.6402 .36463 .64681 .36693 .66101 .36893 .65448 .36714 Metetra
1 0 0 r
.65448 .36714 .66101 .36893 .67536 .37154 .66892 .3703 Metetra
1 0 0 r
.66892 .3703 .67536 .37154 .68988 .37481 .68354 .37415 Metetra
1 0 0 r
.68354 .37415 .68988 .37481 .70459 .37878 .69835 .37872 Metetra
1 0 0 r
.69835 .37872 .70459 .37878 .71949 .38349 .71336 .38408 Metetra
1 0 0 r
.71336 .38408 .71949 .38349 .7346 .389 .7286 .39026 Metetra
1 0 0 r
.7286 .39026 .7346 .389 .74994 .39536 .74407 .39733 Metetra
1 0 0 r
.74407 .39733 .74994 .39536 .76553 .40261 .7598 .40534 Metetra
1 0 0 r
.7598 .40534 .76553 .40261 .78139 .41082 .7758 .41436 Metetra
1 0 0 r
.7758 .41436 .78139 .41082 .79753 .42006 .79163 .41864 Metetra
1 0 0 r
.79163 .41864 .79753 .42006 .81329 .42264 .80684 .4139 Metetra
1 0 0 r
.80684 .4139 .81329 .42264 .82852 .41792 .82213 .40913 Metetra
1 0 0 r
.16317 .47613 .17129 .48416 .18297 .47957 .17489 .47143 Metetra
1 0 0 r
.17489 .47143 .18297 .47957 .1947 .4749 .18666 .46666 Metetra
1 0 0 r
.18666 .46666 .1947 .4749 .20649 .47015 .19848 .46182 Metetra
1 0 0 r
.19848 .46182 .20649 .47015 .21833 .46534 .21035 .45694 Metetra
1 0 0 r
.21035 .45694 .21833 .46534 .23022 .46047 .22228 .45201 Metetra
1 0 0 r
.22228 .45201 .23022 .46047 .24216 .45556 .23425 .44706 Metetra
1 0 0 r
.23425 .44706 .24216 .45556 .25415 .45062 .24627 .44209 Metetra
1 0 0 r
.24627 .44209 .25415 .45062 .26619 .44566 .25833 .43712 Metetra
1 0 0 r
.25833 .43712 .26619 .44566 .27828 .4407 .27045 .43216 Metetra
1 0 0 r
.27045 .43216 .27828 .4407 .29041 .43575 .28261 .42723 Metetra
1 0 0 r
.28261 .42723 .29041 .43575 .30258 .43083 .29481 .42234 Metetra
1 0 0 r
.29481 .42234 .30258 .43083 .31481 .42594 .30706 .41749 Metetra
1 0 0 r
.30706 .41749 .31481 .42594 .32708 .4211 .31936 .41272 Metetra
1 0 0 r
.31936 .41272 .32708 .4211 .3394 .41633 .3317 .40802 Metetra
1 0 0 r
.3317 .40802 .3394 .41633 .35176 .41163 .34409 .40342 Metetra
1 0 0 r
.34409 .40342 .35176 .41163 .36417 .40704 .35653 .39893 Metetra
1 0 0 r
.35653 .39893 .36417 .40704 .37663 .40255 .36902 .39456 Metetra
1 0 0 r
.36902 .39456 .37663 .40255 .38914 .39819 .38156 .39034 Metetra
1 0 0 r
.38156 .39034 .38914 .39819 .4017 .39397 .39415 .38627 Metetra
1 0 0 r
.39415 .38627 .4017 .39397 .41432 .38991 .4068 .38238 Metetra
1 0 0 r
.4068 .38238 .41432 .38991 .42699 .38602 .4195 .37868 Metetra
1 0 0 r
.4195 .37868 .42699 .38602 .43972 .38233 .43226 .37519 Metetra
1 0 0 r
.43226 .37519 .43972 .38233 .45251 .37885 .44508 .37193 Metetra
1 0 0 r
.44508 .37193 .45251 .37885 .46536 .3756 .45797 .36892 Metetra
1 0 0 r
.45797 .36892 .46536 .3756 .47827 .3726 .47092 .36617 Metetra
1 0 0 r
.47092 .36617 .47827 .3726 .49126 .36988 .48395 .36372 Metetra
1 0 0 r
.48395 .36372 .49126 .36988 .50432 .36744 .49705 .36157 Metetra
1 0 0 r
.49705 .36157 .50432 .36744 .51746 .36532 .51023 .35976 Metetra
1 0 0 r
.51023 .35976 .51746 .36532 .53068 .36354 .5235 .35831 Metetra
1 0 0 r
.5235 .35831 .53068 .36354 .54399 .36212 .53686 .35724 Metetra
1 0 0 r
.53686 .35724 .54399 .36212 .5574 .36109 .55032 .35658 Metetra
1 0 0 r
.55032 .35658 .5574 .36109 .5709 .36047 .56388 .35635 Metetra
1 0 0 r
.56388 .35635 .5709 .36047 .58452 .3603 .57755 .35659 Metetra
1 0 0 r
.57755 .35659 .58452 .3603 .59824 .3606 .59134 .35732 Metetra
1 0 0 r
.59134 .35732 .59824 .3606 .6121 .36139 .60527 .35858 Metetra
1 0 0 r
.60527 .35858 .6121 .36139 .62608 .36273 .61932 .36041 Metetra
1 0 0 r
.61932 .36041 .62608 .36273 .6402 .36463 .63353 .36282 Metetra
1 0 0 r
.63353 .36282 .6402 .36463 .65448 .36714 .64789 .36588 Metetra
1 0 0 r
.64789 .36588 .65448 .36714 .66892 .3703 .66243 .36961 Metetra
1 0 0 r
.66243 .36961 .66892 .3703 .68354 .37415 .67714 .37406 Metetra
1 0 0 r
.67714 .37406 .68354 .37415 .69835 .37872 .69206 .37927 Metetra
1 0 0 r
.69206 .37927 .69835 .37872 .71336 .38408 .70719 .3853 Metetra
1 0 0 r
.70719 .3853 .71336 .38408 .7286 .39026 .72254 .39219 Metetra
1 0 0 r
.72254 .39219 .7286 .39026 .74407 .39733 .73815 .40001 Metetra
1 0 0 r
.73815 .40001 .74407 .39733 .7598 .40534 .75402 .40882 Metetra
1 0 0 r
.75402 .40882 .7598 .40534 .7758 .41436 .76987 .41463 Metetra
1 0 0 r
.76987 .41463 .7758 .41436 .79163 .41864 .78506 .40986 Metetra
1 0 0 r
.78506 .40986 .79163 .41864 .80684 .4139 .80032 .40507 Metetra
1 0 0 r
.80032 .40507 .80684 .4139 .82213 .40913 .81567 .40026 Metetra
1 0 0 r
.15499 .46794 .16317 .47613 .17489 .47143 .16675 .46314 Metetra
1 0 0 r
.16675 .46314 .17489 .47143 .18666 .46666 .17855 .45829 Metetra
1 0 0 r
.17855 .45829 .18666 .46666 .19848 .46182 .19041 .45338 Metetra
1 0 0 r
.19041 .45338 .19848 .46182 .21035 .45694 .20231 .44844 Metetra
1 0 0 r
.20231 .44844 .21035 .45694 .22228 .45201 .21427 .44347 Metetra
1 0 0 r
.21427 .44347 .22228 .45201 .23425 .44706 .22627 .4385 Metetra
1 0 0 r
.22627 .4385 .23425 .44706 .24627 .44209 .23832 .43352 Metetra
1 0 0 r
.23832 .43352 .24627 .44209 .25833 .43712 .25041 .42855 Metetra
1 0 0 r
.25041 .42855 .25833 .43712 .27045 .43216 .26255 .42361 Metetra
1 0 0 r
.26255 .42361 .27045 .43216 .28261 .42723 .27474 .41871 Metetra
1 0 0 r
.27474 .41871 .28261 .42723 .29481 .42234 .28697 .41387 Metetra
1 0 0 r
.28697 .41387 .29481 .42234 .30706 .41749 .29925 .40909 Metetra
1 0 0 r
.29925 .40909 .30706 .41749 .31936 .41272 .31157 .40439 Metetra
1 0 0 r
.31157 .40439 .31936 .41272 .3317 .40802 .32394 .39979 Metetra
1 0 0 r
.32394 .39979 .3317 .40802 .34409 .40342 .33636 .39529 Metetra
1 0 0 r
.33636 .39529 .34409 .40342 .35653 .39893 .34882 .39093 Metetra
1 0 0 r
.34882 .39093 .35653 .39893 .36902 .39456 .36134 .3867 Metetra
1 0 0 r
.36134 .3867 .36902 .39456 .38156 .39034 .3739 .38263 Metetra
1 0 0 r
.3739 .38263 .38156 .39034 .39415 .38627 .38652 .37873 Metetra
1 0 0 r
.38652 .37873 .39415 .38627 .4068 .38238 .3992 .37503 Metetra
1 0 0 r
.3992 .37503 .4068 .38238 .4195 .37868 .41193 .37153 Metetra
1 0 0 r
.41193 .37153 .4195 .37868 .43226 .37519 .42472 .36826 Metetra
1 0 0 r
.42472 .36826 .43226 .37519 .44508 .37193 .43758 .36524 Metetra
1 0 0 r
.43758 .36524 .44508 .37193 .45797 .36892 .4505 .36248 Metetra
1 0 0 r
.4505 .36248 .45797 .36892 .47092 .36617 .46349 .36001 Metetra
1 0 0 r
.46349 .36001 .47092 .36617 .48395 .36372 .47655 .35784 Metetra
1 0 0 r
.47655 .35784 .48395 .36372 .49705 .36157 .4897 .35601 Metetra
1 0 0 r
.4897 .35601 .49705 .36157 .51023 .35976 .50292 .35453 Metetra
1 0 0 r
.50292 .35453 .51023 .35976 .5235 .35831 .51624 .35342 Metetra
1 0 0 r
.51624 .35342 .5235 .35831 .53686 .35724 .52965 .35272 Metetra
1 0 0 r
.52965 .35272 .53686 .35724 .55032 .35658 .54316 .35245 Metetra
1 0 0 r
.54316 .35245 .55032 .35658 .56388 .35635 .55678 .35263 Metetra
1 0 0 r
.55678 .35263 .56388 .35635 .57755 .35659 .57051 .35331 Metetra
1 0 0 r
.57051 .35331 .57755 .35659 .59134 .35732 .58437 .3545 Metetra
1 0 0 r
.58437 .3545 .59134 .35732 .60527 .35858 .59836 .35625 Metetra
1 0 0 r
.59836 .35625 .60527 .35858 .61932 .36041 .61249 .35858 Metetra
1 0 0 r
.61249 .35858 .61932 .36041 .63353 .36282 .62678 .36154 Metetra
1 0 0 r
.62678 .36154 .63353 .36282 .64789 .36588 .64123 .36516 Metetra
1 0 0 r
.64123 .36516 .64789 .36588 .66243 .36961 .65586 .36949 Metetra
1 0 0 r
.65586 .36949 .66243 .36961 .67714 .37406 .67068 .37458 Metetra
1 0 0 r
.67068 .37458 .67714 .37406 .69206 .37927 .6857 .38046 Metetra
1 0 0 r
.6857 .38046 .69206 .37927 .70719 .3853 .70094 .38719 Metetra
1 0 0 r
.70094 .38719 .70719 .3853 .72254 .39219 .71643 .39484 Metetra
1 0 0 r
.71643 .39484 .72254 .39219 .73815 .40001 .73217 .40344 Metetra
1 0 0 r
.73217 .40344 .73815 .40001 .75402 .40882 .74802 .4106 Metetra
1 0 0 r
.74802 .4106 .75402 .40882 .76987 .41463 .76318 .40581 Metetra
1 0 0 r
.76318 .40581 .76987 .41463 .78506 .40986 .77842 .401 Metetra
1 0 0 r
.77842 .401 .78506 .40986 .80032 .40507 .79374 .39616 Metetra
1 0 0 r
.79374 .39616 .80032 .40507 .81567 .40026 .80915 .3913 Metetra
1 0 0 r
.14676 .4596 .15499 .46794 .16675 .46314 .15855 .45472 Metetra
1 0 0 r
.15855 .45472 .16675 .46314 .17855 .45829 .17039 .4498 Metetra
1 0 0 r
.17039 .4498 .17855 .45829 .19041 .45338 .18228 .44485 Metetra
1 0 0 r
.18228 .44485 .19041 .45338 .20231 .44844 .19421 .43987 Metetra
1 0 0 r
.19421 .43987 .20231 .44844 .21427 .44347 .2062 .43488 Metetra
1 0 0 r
.2062 .43488 .21427 .44347 .22627 .4385 .21823 .42989 Metetra
1 0 0 r
.21823 .42989 .22627 .4385 .23832 .43352 .2303 .42492 Metetra
1 0 0 r
.2303 .42492 .23832 .43352 .25041 .42855 .24242 .41998 Metetra
1 0 0 r
.24242 .41998 .25041 .42855 .26255 .42361 .25459 .41507 Metetra
1 0 0 r
.25459 .41507 .26255 .42361 .27474 .41871 .2668 .41022 Metetra
1 0 0 r
.2668 .41022 .27474 .41871 .28697 .41387 .27906 .40544 Metetra
1 0 0 r
.27906 .40544 .28697 .41387 .29925 .40909 .29136 .40074 Metetra
1 0 0 r
.29136 .40074 .29925 .40909 .31157 .40439 .30371 .39614 Metetra
1 0 0 r
.30371 .39614 .31157 .40439 .32394 .39979 .3161 .39164 Metetra
1 0 0 r
.3161 .39164 .32394 .39979 .33636 .39529 .32854 .38728 Metetra
1 0 0 r
.32854 .38728 .33636 .39529 .34882 .39093 .34103 .38305 Metetra
1 0 0 r
.34103 .38305 .34882 .39093 .36134 .3867 .35357 .37898 Metetra
1 0 0 r
.35357 .37898 .36134 .3867 .3739 .38263 .36617 .37508 Metetra
1 0 0 r
.36617 .37508 .3739 .38263 .38652 .37873 .37881 .37137 Metetra
1 0 0 r
.37881 .37137 .38652 .37873 .3992 .37503 .39152 .36787 Metetra
1 0 0 r
.39152 .36787 .3992 .37503 .41193 .37153 .40428 .3646 Metetra
1 0 0 r
.40428 .3646 .41193 .37153 .42472 .36826 .4171 .36156 Metetra
1 0 0 r
.4171 .36156 .42472 .36826 .43758 .36524 .42999 .35879 Metetra
1 0 0 r
.42999 .35879 .43758 .36524 .4505 .36248 .44294 .35631 Metetra
1 0 0 r
.44294 .35631 .4505 .36248 .46349 .36001 .45597 .35413 Metetra
1 0 0 r
.45597 .35413 .46349 .36001 .47655 .35784 .46908 .35227 Metetra
1 0 0 r
.46908 .35227 .47655 .35784 .4897 .35601 .48226 .35076 Metetra
1 0 0 r
.48226 .35076 .4897 .35601 .50292 .35453 .49553 .34963 Metetra
1 0 0 r
.49553 .34963 .50292 .35453 .51624 .35342 .50889 .3489 Metetra
1 0 0 r
.50889 .3489 .51624 .35342 .52965 .35272 .52235 .34858 Metetra
1 0 0 r
.52235 .34858 .52965 .35272 .54316 .35245 .53592 .34872 Metetra
1 0 0 r
.53592 .34872 .54316 .35245 .55678 .35263 .54959 .34935 Metetra
1 0 0 r
.54959 .34935 .55678 .35263 .57051 .35331 .56339 .35048 Metetra
1 0 0 r
.56339 .35048 .57051 .35331 .58437 .3545 .57731 .35216 Metetra
1 0 0 r
.57731 .35216 .58437 .3545 .59836 .35625 .59137 .35441 Metetra
1 0 0 r
.59137 .35441 .59836 .35625 .61249 .35858 .60558 .35729 Metetra
1 0 0 r
.60558 .35729 .61249 .35858 .62678 .36154 .61995 .36081 Metetra
1 0 0 r
.61995 .36081 .62678 .36154 .64123 .36516 .63449 .36503 Metetra
1 0 0 r
.63449 .36503 .64123 .36516 .65586 .36949 .64922 .37 Metetra
1 0 0 r
.64922 .37 .65586 .36949 .67068 .37458 .66414 .37574 Metetra
1 0 0 r
.66414 .37574 .67068 .37458 .6857 .38046 .67927 .38233 Metetra
1 0 0 r
.67927 .38233 .6857 .38046 .70094 .38719 .69464 .38981 Metetra
1 0 0 r
.69464 .38981 .70094 .38719 .71643 .39484 .71025 .39823 Metetra
1 0 0 r
.71025 .39823 .71643 .39484 .73217 .40344 .72606 .40655 Metetra
1 0 0 r
.72606 .40655 .73217 .40344 .74802 .4106 .7412 .40174 Metetra
1 0 0 r
.7412 .40174 .74802 .4106 .76318 .40581 .75642 .39691 Metetra
1 0 0 r
.75642 .39691 .76318 .40581 .77842 .401 .77172 .39205 Metetra
1 0 0 r
.77172 .39205 .77842 .401 .79374 .39616 .7871 .38716 Metetra
1 0 0 r
.7871 .38716 .79374 .39616 .80915 .3913 .80256 .38225 Metetra
1 0 0 r
.13848 .45114 .14676 .4596 .15855 .45472 .1503 .4462 Metetra
1 0 0 r
.1503 .4462 .15855 .45472 .17039 .4498 .16217 .44123 Metetra
1 0 0 r
.16217 .44123 .17039 .4498 .18228 .44485 .17408 .43624 Metetra
1 0 0 r
.17408 .43624 .18228 .44485 .19421 .43987 .18605 .43124 Metetra
1 0 0 r
.18605 .43124 .19421 .43987 .2062 .43488 .19806 .42624 Metetra
1 0 0 r
.19806 .42624 .2062 .43488 .21823 .42989 .21011 .42127 Metetra
1 0 0 r
.21011 .42127 .21823 .42989 .2303 .42492 .22221 .41632 Metetra
1 0 0 r
.22221 .41632 .2303 .42492 .24242 .41998 .23436 .41141 Metetra
1 0 0 r
.23436 .41141 .24242 .41998 .25459 .41507 .24655 .40656 Metetra
1 0 0 r
.24655 .40656 .25459 .41507 .2668 .41022 .25879 .40178 Metetra
1 0 0 r
.25879 .40178 .2668 .41022 .27906 .40544 .27107 .39708 Metetra
1 0 0 r
.27107 .39708 .27906 .40544 .29136 .40074 .28339 .39248 Metetra
1 0 0 r
.28339 .39248 .29136 .40074 .30371 .39614 .29576 .38798 Metetra
1 0 0 r
.29576 .38798 .30371 .39614 .3161 .39164 .30818 .38362 Metetra
1 0 0 r
.30818 .38362 .3161 .39164 .32854 .38728 .32065 .37939 Metetra
1 0 0 r
.32065 .37939 .32854 .38728 .34103 .38305 .33316 .37532 Metetra
1 0 0 r
.33316 .37532 .34103 .38305 .35357 .37898 .34573 .37143 Metetra
1 0 0 r
.34573 .37143 .35357 .37898 .36617 .37508 .35835 .36772 Metetra
1 0 0 r
.35835 .36772 .36617 .37508 .37881 .37137 .37102 .36421 Metetra
1 0 0 r
.37102 .36421 .37881 .37137 .39152 .36787 .38375 .36093 Metetra
1 0 0 r
.38375 .36093 .39152 .36787 .40428 .3646 .39654 .3579 Metetra
1 0 0 r
.39654 .3579 .40428 .3646 .4171 .36156 .4094 .35512 Metetra
1 0 0 r
.4094 .35512 .4171 .36156 .42999 .35879 .42231 .35262 Metetra
1 0 0 r
.42231 .35262 .42999 .35879 .44294 .35631 .4353 .35043 Metetra
1 0 0 r
.4353 .35043 .44294 .35631 .45597 .35413 .44837 .34856 Metetra
1 0 0 r
.44837 .34856 .45597 .35413 .46908 .35227 .46151 .34703 Metetra
1 0 0 r
.46151 .34703 .46908 .35227 .48226 .35076 .47473 .34587 Metetra
1 0 0 r
.47473 .34587 .48226 .35076 .49553 .34963 .48805 .34511 Metetra
1 0 0 r
.48805 .34511 .49553 .34963 .50889 .3489 .50146 .34476 Metetra
1 0 0 r
.50146 .34476 .50889 .3489 .52235 .34858 .51497 .34486 Metetra
1 0 0 r
.51497 .34486 .52235 .34858 .53592 .34872 .52859 .34544 Metetra
1 0 0 r
.52859 .34544 .53592 .34872 .54959 .34935 .54232 .34652 Metetra
1 0 0 r
.54232 .34652 .54959 .34935 .56339 .35048 .55618 .34813 Metetra
1 0 0 r
.55618 .34813 .56339 .35048 .57731 .35216 .57017 .35032 Metetra
1 0 0 r
.57017 .35032 .57731 .35216 .59137 .35441 .5843 .35311 Metetra
1 0 0 r
.5843 .35311 .59137 .35441 .60558 .35729 .59859 .35655 Metetra
1 0 0 r
.59859 .35655 .60558 .35729 .61995 .36081 .61304 .36068 Metetra
1 0 0 r
.61304 .36068 .61995 .36081 .63449 .36503 .62767 .36553 Metetra
1 0 0 r
.62767 .36553 .63449 .36503 .64922 .37 .6425 .37115 Metetra
1 0 0 r
.6425 .37115 .64922 .37 .66414 .37574 .65752 .3776 Metetra
1 0 0 r
.65752 .3776 .66414 .37574 .67927 .38233 .67277 .38492 Metetra
1 0 0 r
.67277 .38492 .67927 .38233 .69464 .38981 .68826 .39318 Metetra
1 0 0 r
.68826 .39318 .69464 .38981 .71025 .39823 .70401 .40243 Metetra
1 0 0 r
.70401 .40243 .71025 .39823 .72606 .40655 .71912 .39765 Metetra
1 0 0 r
.71912 .39765 .72606 .40655 .7412 .40174 .73432 .3928 Metetra
1 0 0 r
.73432 .3928 .7412 .40174 .75642 .39691 .74959 .38791 Metetra
1 0 0 r
.74959 .38791 .75642 .39691 .77172 .39205 .76495 .383 Metetra
1 0 0 r
.76495 .383 .77172 .39205 .7871 .38716 .78039 .37807 Metetra
1 0 0 r
.78039 .37807 .7871 .38716 .80256 .38225 .79591 .37311 Metetra
1 0 0 r
.13013 .44257 .13848 .45114 .1503 .4462 .14198 .43758 Metetra
1 0 0 r
.14198 .43758 .1503 .4462 .16217 .44123 .15388 .43258 Metetra
1 0 0 r
.15388 .43258 .16217 .44123 .17408 .43624 .16582 .42757 Metetra
1 0 0 r
.16582 .42757 .17408 .43624 .18605 .43124 .17781 .42257 Metetra
1 0 0 r
.17781 .42257 .18605 .43124 .19806 .42624 .18985 .41759 Metetra
1 0 0 r
.18985 .41759 .19806 .42624 .21011 .42127 .20193 .41264 Metetra
1 0 0 r
.20193 .41264 .21011 .42127 .22221 .41632 .21406 .40773 Metetra
1 0 0 r
.21406 .40773 .22221 .41632 .23436 .41141 .22622 .40288 Metetra
1 0 0 r
.22622 .40288 .23436 .41141 .24655 .40656 .23844 .3981 Metetra
1 0 0 r
.23844 .3981 .24655 .40656 .25879 .40178 .2507 .3934 Metetra
1 0 0 r
.2507 .3934 .25879 .40178 .27107 .39708 .263 .3888 Metetra
1 0 0 r
.263 .3888 .27107 .39708 .28339 .39248 .27535 .38431 Metetra
1 0 0 r
.27535 .38431 .28339 .39248 .29576 .38798 .28774 .37995 Metetra
1 0 0 r
.28774 .37995 .29576 .38798 .30818 .38362 .30018 .37573 Metetra
1 0 0 r
.30018 .37573 .30818 .38362 .32065 .37939 .31267 .37166 Metetra
1 0 0 r
.31267 .37166 .32065 .37939 .33316 .37532 .32521 .36777 Metetra
1 0 0 r
.32521 .36777 .33316 .37532 .34573 .37143 .3378 .36406 Metetra
1 0 0 r
.3378 .36406 .34573 .37143 .35835 .36772 .35044 .36056 Metetra
1 0 0 r
.35044 .36056 .35835 .36772 .37102 .36421 .36314 .35728 Metetra
1 0 0 r
.36314 .35728 .37102 .36421 .38375 .36093 .3759 .35424 Metetra
1 0 0 r
.3759 .35424 .38375 .36093 .39654 .3579 .38872 .35146 Metetra
1 0 0 r
.38872 .35146 .39654 .3579 .4094 .35512 .4016 .34895 Metetra
1 0 0 r
.4016 .34895 .4094 .35512 .42231 .35262 .41455 .34675 Metetra
1 0 0 r
.41455 .34675 .42231 .35262 .4353 .35043 .42757 .34487 Metetra
1 0 0 r
.42757 .34487 .4353 .35043 .44837 .34856 .44067 .34332 Metetra
1 0 0 r
.44067 .34332 .44837 .34856 .46151 .34703 .45385 .34215 Metetra
1 0 0 r
.45385 .34215 .46151 .34703 .47473 .34587 .46712 .34136 Metetra
1 0 0 r
.46712 .34136 .47473 .34587 .48805 .34511 .48047 .34098 Metetra
1 0 0 r
.48047 .34098 .48805 .34511 .50146 .34476 .49393 .34105 Metetra
1 0 0 r
.49393 .34105 .50146 .34476 .51497 .34486 .50749 .34158 Metetra
1 0 0 r
.50749 .34158 .51497 .34486 .52859 .34544 .52116 .34262 Metetra
1 0 0 r
.52116 .34262 .52859 .34544 .54232 .34652 .53496 .34418 Metetra
1 0 0 r
.53496 .34418 .54232 .34652 .55618 .34813 .54888 .3463 Metetra
1 0 0 r
.54888 .3463 .55618 .34813 .57017 .35032 .56294 .34903 Metetra
1 0 0 r
.56294 .34903 .57017 .35032 .5843 .35311 .57714 .35239 Metetra
1 0 0 r
.57714 .35239 .5843 .35311 .59859 .35655 .59151 .35642 Metetra
1 0 0 r
.59151 .35642 .59859 .35655 .61304 .36068 .60605 .36117 Metetra
1 0 0 r
.60605 .36117 .61304 .36068 .62767 .36553 .62077 .36668 Metetra
1 0 0 r
.62077 .36668 .62767 .36553 .6425 .37115 .63569 .373 Metetra
1 0 0 r
.63569 .373 .6425 .37115 .65752 .3776 .65083 .38018 Metetra
1 0 0 r
.65083 .38018 .65752 .3776 .67277 .38492 .66619 .38828 Metetra
1 0 0 r
.66619 .38828 .67277 .38492 .68826 .39318 .68181 .39736 Metetra
1 0 0 r
.68181 .39736 .68826 .39318 .70401 .40243 .69695 .39354 Metetra
1 0 0 r
.69695 .39354 .70401 .40243 .71912 .39765 .71211 .38867 Metetra
1 0 0 r
.71211 .38867 .71912 .39765 .73432 .3928 .72736 .38376 Metetra
1 0 0 r
.72736 .38376 .73432 .3928 .74959 .38791 .7427 .37883 Metetra
1 0 0 r
.7427 .37883 .74959 .38791 .76495 .383 .75811 .37387 Metetra
1 0 0 r
.75811 .37387 .76495 .383 .78039 .37807 .77361 .36889 Metetra
1 0 0 r
.77361 .36889 .78039 .37807 .79591 .37311 .78919 .36388 Metetra
1 0 0 r
.12172 .43392 .13013 .44257 .14198 .43758 .1336 .4289 Metetra
1 0 0 r
.1336 .4289 .14198 .43758 .15388 .43258 .14552 .42389 Metetra
1 0 0 r
.14552 .42389 .15388 .43258 .16582 .42757 .15749 .41888 Metetra
1 0 0 r
.15749 .41888 .16582 .42757 .17781 .42257 .16951 .41389 Metetra
1 0 0 r
.16951 .41389 .17781 .42257 .18985 .41759 .18157 .40894 Metetra
1 0 0 r
.18157 .40894 .18985 .41759 .20193 .41264 .19367 .40403 Metetra
1 0 0 r
.19367 .40403 .20193 .41264 .21406 .40773 .20582 .39918 Metetra
1 0 0 r
.20582 .39918 .21406 .40773 .22622 .40288 .21801 .3944 Metetra
1 0 0 r
.21801 .3944 .22622 .40288 .23844 .3981 .23024 .38971 Metetra
1 0 0 r
.23024 .38971 .23844 .3981 .2507 .3934 .24252 .38511 Metetra
1 0 0 r
.24252 .38511 .2507 .3934 .263 .3888 .25485 .38063 Metetra
1 0 0 r
.25485 .38063 .263 .3888 .27535 .38431 .26721 .37627 Metetra
1 0 0 r
.26721 .37627 .27535 .38431 .28774 .37995 .27963 .37205 Metetra
1 0 0 r
.27963 .37205 .28774 .37995 .30018 .37573 .29209 .36799 Metetra
1 0 0 r
.29209 .36799 .30018 .37573 .31267 .37166 .3046 .3641 Metetra
1 0 0 r
.3046 .3641 .31267 .37166 .32521 .36777 .31716 .3604 Metetra
1 0 0 r
.31716 .3604 .32521 .36777 .3378 .36406 .32977 .3569 Metetra
1 0 0 r
.32977 .3569 .3378 .36406 .35044 .36056 .34244 .35363 Metetra
1 0 0 r
.34244 .35363 .35044 .36056 .36314 .35728 .35516 .35059 Metetra
1 0 0 r
.35516 .35059 .36314 .35728 .3759 .35424 .36795 .34781 Metetra
1 0 0 r
.36795 .34781 .3759 .35424 .38872 .35146 .38079 .3453 Metetra
1 0 0 r
.38079 .3453 .38872 .35146 .4016 .34895 .39371 .34309 Metetra
1 0 0 r
.39371 .34309 .4016 .34895 .41455 .34675 .40669 .3412 Metetra
1 0 0 r
.40669 .3412 .41455 .34675 .42757 .34487 .41974 .33965 Metetra
1 0 0 r
.41974 .33965 .42757 .34487 .44067 .34332 .43288 .33845 Metetra
1 0 0 r
.43288 .33845 .44067 .34332 .45385 .34215 .44609 .33764 Metetra
1 0 0 r
.44609 .33764 .45385 .34215 .46712 .34136 .4594 .33725 Metetra
1 0 0 r
.4594 .33725 .46712 .34136 .48047 .34098 .4728 .33728 Metetra
1 0 0 r
.4728 .33728 .48047 .34098 .49393 .34105 .4863 .33778 Metetra
1 0 0 r
.4863 .33778 .49393 .34105 .50749 .34158 .49992 .33878 Metetra
1 0 0 r
.49992 .33878 .50749 .34158 .52116 .34262 .51364 .34029 Metetra
1 0 0 r
.51364 .34029 .52116 .34262 .53496 .34418 .52749 .34236 Metetra
1 0 0 r
.52749 .34236 .53496 .34418 .54888 .3463 .54148 .34502 Metetra
1 0 0 r
.54148 .34502 .54888 .3463 .56294 .34903 .55561 .34831 Metetra
1 0 0 r
.55561 .34831 .56294 .34903 .57714 .35239 .56989 .35226 Metetra
1 0 0 r
.56989 .35226 .57714 .35239 .59151 .35642 .58433 .35692 Metetra
1 0 0 r
.58433 .35692 .59151 .35642 .60605 .36117 .59896 .36233 Metetra
1 0 0 r
.59896 .36233 .60605 .36117 .62077 .36668 .61378 .36853 Metetra
1 0 0 r
.61378 .36853 .62077 .36668 .63569 .373 .6288 .37559 Metetra
1 0 0 r
.6288 .37559 .63569 .373 .65083 .38018 .64404 .38354 Metetra
1 0 0 r
.64404 .38354 .65083 .38018 .66619 .38828 .65953 .39246 Metetra
1 0 0 r
.65953 .39246 .66619 .38828 .68181 .39736 .67467 .38942 Metetra
1 0 0 r
.67467 .38942 .68181 .39736 .69695 .39354 .68981 .38452 Metetra
1 0 0 r
.68981 .38452 .69695 .39354 .71211 .38867 .70504 .37959 Metetra
1 0 0 r
.70504 .37959 .71211 .38867 .72736 .38376 .72034 .37464 Metetra
1 0 0 r
.72034 .37464 .72736 .38376 .7427 .37883 .73573 .36966 Metetra
1 0 0 r
.73573 .36966 .7427 .37883 .75811 .37387 .75121 .36465 Metetra
1 0 0 r
.75121 .36465 .75811 .37387 .77361 .36889 .76676 .35961 Metetra
1 0 0 r
.76676 .35961 .77361 .36889 .78919 .36388 .7824 .35455 Metetra
1 0 0 r
.11324 .4252 .12172 .43392 .1336 .4289 .12514 .42018 Metetra
1 0 0 r
.12514 .42018 .1336 .4289 .14552 .42389 .1371 .41516 Metetra
1 0 0 r
.1371 .41516 .14552 .42389 .15749 .41888 .14909 .41017 Metetra
1 0 0 r
.14909 .41017 .15749 .41888 .16951 .41389 .16113 .40522 Metetra
1 0 0 r
.16113 .40522 .16951 .41389 .18157 .40894 .17321 .40031 Metetra
1 0 0 r
.17321 .40031 .18157 .40894 .19367 .40403 .18533 .39546 Metetra
1 0 0 r
.18533 .39546 .19367 .40403 .20582 .39918 .1975 .39069 Metetra
1 0 0 r
.1975 .39069 .20582 .39918 .21801 .3944 .20971 .386 Metetra
1 0 0 r
.20971 .386 .21801 .3944 .23024 .38971 .22197 .38141 Metetra
1 0 0 r
.22197 .38141 .23024 .38971 .24252 .38511 .23426 .37693 Metetra
1 0 0 r
.23426 .37693 .24252 .38511 .25485 .38063 .24661 .37258 Metetra
1 0 0 r
.24661 .37258 .25485 .38063 .26721 .37627 .25899 .36837 Metetra
1 0 0 r
.25899 .36837 .26721 .37627 .27963 .37205 .27143 .36432 Metetra
1 0 0 r
.27143 .36432 .27963 .37205 .29209 .36799 .28391 .36044 Metetra
1 0 0 r
.28391 .36044 .29209 .36799 .3046 .3641 .29644 .35674 Metetra
1 0 0 r
.29644 .35674 .3046 .3641 .31716 .3604 .30902 .35325 Metetra
1 0 0 r
.30902 .35325 .31716 .3604 .32977 .3569 .32165 .34998 Metetra
1 0 0 r
.32165 .34998 .32977 .3569 .34244 .35363 .33434 .34695 Metetra
1 0 0 r
.33434 .34695 .34244 .35363 .35516 .35059 .34709 .34417 Metetra
1 0 0 r
.34709 .34417 .35516 .35059 .36795 .34781 .3599 .34166 Metetra
1 0 0 r
.3599 .34166 .36795 .34781 .38079 .3453 .37277 .33945 Metetra
1 0 0 r
.37277 .33945 .38079 .3453 .39371 .34309 .38571 .33756 Metetra
1 0 0 r
.38571 .33756 .39371 .34309 .40669 .3412 .39872 .336 Metetra
1 0 0 r
.39872 .336 .40669 .3412 .41974 .33965 .41181 .33479 Metetra
1 0 0 r
.41181 .33479 .41974 .33965 .43288 .33845 .42498 .33397 Metetra
1 0 0 r
.42498 .33397 .43288 .33845 .44609 .33764 .43823 .33355 Metetra
1 0 0 r
.43823 .33355 .44609 .33764 .4594 .33725 .45158 .33357 Metetra
1 0 0 r
.45158 .33357 .4594 .33725 .4728 .33728 .46503 .33404 Metetra
1 0 0 r
.46503 .33404 .4728 .33728 .4863 .33778 .47857 .335 Metetra
1 0 0 r
.47857 .335 .4863 .33778 .49992 .33878 .49224 .33647 Metetra
1 0 0 r
.49224 .33647 .49992 .33878 .51364 .34029 .50602 .3385 Metetra
1 0 0 r
.50602 .3385 .51364 .34029 .52749 .34236 .51993 .3411 Metetra
1 0 0 r
.51993 .3411 .52749 .34236 .54148 .34502 .53398 .34433 Metetra
1 0 0 r
.53398 .34433 .54148 .34502 .55561 .34831 .54817 .3482 Metetra
1 0 0 r
.54817 .3482 .55561 .34831 .56989 .35226 .56253 .35278 Metetra
1 0 0 r
.56253 .35278 .56989 .35226 .58433 .35692 .57706 .35809 Metetra
1 0 0 r
.57706 .35809 .58433 .35692 .59896 .36233 .59177 .36419 Metetra
1 0 0 r
.59177 .36419 .59896 .36233 .61378 .36853 .60668 .37113 Metetra
1 0 0 r
.60668 .37113 .61378 .36853 .6288 .37559 .62181 .37895 Metetra
1 0 0 r
.62181 .37895 .6288 .37559 .64404 .38354 .63717 .38772 Metetra
1 0 0 r
.63717 .38772 .64404 .38354 .65953 .39246 .65229 .38527 Metetra
1 0 0 r
.65229 .38527 .65953 .39246 .67467 .38942 .66741 .38035 Metetra
1 0 0 r
.66741 .38035 .67467 .38942 .68981 .38452 .68261 .3754 Metetra
1 0 0 r
.68261 .3754 .68981 .38452 .70504 .37959 .69789 .37042 Metetra
1 0 0 r
.69789 .37042 .70504 .37959 .72034 .37464 .71325 .36542 Metetra
1 0 0 r
.71325 .36542 .72034 .37464 .73573 .36966 .7287 .36039 Metetra
1 0 0 r
.7287 .36039 .73573 .36966 .75121 .36465 .74423 .35533 Metetra
1 0 0 r
.74423 .35533 .75121 .36465 .76676 .35961 .75985 .35025 Metetra
1 0 0 r
.75985 .35025 .76676 .35961 .7824 .35455 .77555 .34514 Metetra
1 0 0 r
.10469 .41645 .11324 .4252 .12514 .42018 .11662 .41143 Metetra
1 0 0 r
.11662 .41143 .12514 .42018 .1371 .41516 .12859 .40644 Metetra
1 0 0 r
.12859 .40644 .1371 .41516 .14909 .41017 .14061 .40148 Metetra
1 0 0 r
.14061 .40148 .14909 .41017 .16113 .40522 .15267 .39658 Metetra
1 0 0 r
.15267 .39658 .16113 .40522 .17321 .40031 .16477 .39173 Metetra
1 0 0 r
.16477 .39173 .17321 .40031 .18533 .39546 .17691 .38696 Metetra
1 0 0 r
.17691 .38696 .18533 .39546 .1975 .39069 .1891 .38228 Metetra
1 0 0 r
.1891 .38228 .1975 .39069 .20971 .386 .20133 .3777 Metetra
1 0 0 r
.20133 .3777 .20971 .386 .22197 .38141 .2136 .37323 Metetra
1 0 0 r
.2136 .37323 .22197 .38141 .23426 .37693 .22592 .36889 Metetra
1 0 0 r
.22592 .36889 .23426 .37693 .24661 .37258 .23827 .36469 Metetra
1 0 0 r
.23827 .36469 .24661 .37258 .25899 .36837 .25068 .36064 Metetra
1 0 0 r
.25068 .36064 .25899 .36837 .27143 .36432 .26313 .35677 Metetra
1 0 0 r
.26313 .35677 .27143 .36432 .28391 .36044 .27563 .35309 Metetra
1 0 0 r
.27563 .35309 .28391 .36044 .29644 .35674 .28818 .34961 Metetra
1 0 0 r
.28818 .34961 .29644 .35674 .30902 .35325 .30078 .34634 Metetra
1 0 0 r
.30078 .34634 .30902 .35325 .32165 .34998 .31343 .34332 Metetra
1 0 0 r
.31343 .34332 .32165 .34998 .33434 .34695 .32614 .34054 Metetra
1 0 0 r
.32614 .34054 .33434 .34695 .34709 .34417 .33891 .33804 Metetra
1 0 0 r
.33891 .33804 .34709 .34417 .3599 .34166 .35175 .33584 Metetra
1 0 0 r
.35175 .33584 .3599 .34166 .37277 .33945 .36464 .33394 Metetra
1 0 0 r
.36464 .33394 .37277 .33945 .38571 .33756 .37761 .33238 Metetra
1 0 0 r
.37761 .33238 .38571 .33756 .39872 .336 .39065 .33117 Metetra
1 0 0 r
.39065 .33117 .39872 .336 .41181 .33479 .40377 .33034 Metetra
1 0 0 r
.40377 .33034 .41181 .33479 .42498 .33397 .41697 .32991 Metetra
1 0 0 r
.41697 .32991 .42498 .33397 .43823 .33355 .43026 .3299 Metetra
1 0 0 r
.43026 .3299 .43823 .33355 .45158 .33357 .44365 .33035 Metetra
1 0 0 r
.44365 .33035 .45158 .33357 .46503 .33404 .45714 .33128 Metetra
1 0 0 r
.45714 .33128 .46503 .33404 .47857 .335 .47073 .33272 Metetra
1 0 0 r
.47073 .33272 .47857 .335 .49224 .33647 .48445 .33471 Metetra
1 0 0 r
.48445 .33471 .49224 .33647 .50602 .3385 .49828 .33727 Metetra
1 0 0 r
.49828 .33727 .50602 .3385 .51993 .3411 .51225 .34043 Metetra
1 0 0 r
.51225 .34043 .51993 .3411 .53398 .34433 .52636 .34425 Metetra
1 0 0 r
.52636 .34425 .53398 .34433 .54817 .3482 .54063 .34875 Metetra
1 0 0 r
.54063 .34875 .54817 .3482 .56253 .35278 .55506 .35398 Metetra
1 0 0 r
.55506 .35398 .56253 .35278 .57706 .35809 .56967 .35999 Metetra
1 0 0 r
.56967 .35999 .57706 .35809 .59177 .36419 .58448 .36682 Metetra
1 0 0 r
.58448 .36682 .59177 .36419 .60668 .37113 .59949 .37452 Metetra
1 0 0 r
.59949 .37452 .60668 .37113 .62181 .37895 .61472 .38316 Metetra
1 0 0 r
.61472 .38316 .62181 .37895 .63717 .38772 .62981 .38111 Metetra
1 0 0 r
.62981 .38111 .63717 .38772 .65229 .38527 .6449 .37616 Metetra
1 0 0 r
.6449 .37616 .65229 .38527 .66741 .38035 .66007 .37119 Metetra
1 0 0 r
.66007 .37119 .66741 .38035 .68261 .3754 .67533 .36619 Metetra
1 0 0 r
.67533 .36619 .68261 .3754 .69789 .37042 .69067 .36117 Metetra
1 0 0 r
.69067 .36117 .69789 .37042 .71325 .36542 .70609 .35611 Metetra
1 0 0 r
.70609 .35611 .71325 .36542 .7287 .36039 .7216 .35103 Metetra
1 0 0 r
.7216 .35103 .7287 .36039 .74423 .35533 .73719 .34592 Metetra
1 0 0 r
.73719 .34592 .74423 .35533 .75985 .35025 .75286 .34079 Metetra
1 0 0 r
.75286 .34079 .75985 .35025 .77555 .34514 .76862 .33562 Metetra
1 0 0 r
.09607 .40767 .10469 .41645 .11662 .41143 .10802 .40268 Metetra
1 0 0 r
.10802 .40268 .11662 .41143 .12859 .40644 .12001 .39772 Metetra
1 0 0 r
.12001 .39772 .12859 .40644 .14061 .40148 .13205 .39282 Metetra
1 0 0 r
.13205 .39282 .14061 .40148 .15267 .39658 .14413 .38798 Metetra
1 0 0 r
.14413 .38798 .15267 .39658 .16477 .39173 .15624 .38322 Metetra
1 0 0 r
.15624 .38322 .16477 .39173 .17691 .38696 .16841 .37855 Metetra
1 0 0 r
.16841 .37855 .17691 .38696 .1891 .38228 .18061 .37397 Metetra
1 0 0 r
.18061 .37397 .1891 .38228 .20133 .3777 .19285 .36951 Metetra
1 0 0 r
.19285 .36951 .20133 .3777 .2136 .37323 .20514 .36518 Metetra
1 0 0 r
.20514 .36518 .2136 .37323 .22592 .36889 .21747 .361 Metetra
1 0 0 r
.21747 .361 .22592 .36889 .23827 .36469 .22985 .35697 Metetra
1 0 0 r
.22985 .35697 .23827 .36469 .25068 .36064 .24227 .35311 Metetra
1 0 0 r
.24227 .35311 .25068 .36064 .26313 .35677 .25473 .34944 Metetra
1 0 0 r
.25473 .34944 .26313 .35677 .27563 .35309 .26725 .34597 Metetra
1 0 0 r
.26725 .34597 .27563 .35309 .28818 .34961 .27982 .34271 Metetra
1 0 0 r
.27982 .34271 .28818 .34961 .30078 .34634 .29243 .3397 Metetra
1 0 0 r
.29243 .3397 .30078 .34634 .31343 .34332 .30511 .33694 Metetra
1 0 0 r
.30511 .33694 .31343 .34332 .32614 .34054 .31784 .33445 Metetra
1 0 0 r
.31784 .33445 .32614 .34054 .33891 .33804 .33063 .33224 Metetra
1 0 0 r
.33063 .33224 .33891 .33804 .35175 .33584 .34348 .33035 Metetra
1 0 0 r
.34348 .33035 .35175 .33584 .36464 .33394 .3564 .32879 Metetra
1 0 0 r
.3564 .32879 .36464 .33394 .37761 .33238 .3694 .32758 Metetra
1 0 0 r
.3694 .32758 .37761 .33238 .39065 .33117 .38247 .32674 Metetra
1 0 0 r
.38247 .32674 .39065 .33117 .40377 .33034 .39562 .32631 Metetra
1 0 0 r
.39562 .32631 .40377 .33034 .41697 .32991 .40885 .32629 Metetra
1 0 0 r
.40885 .32629 .41697 .32991 .43026 .3299 .42218 .32672 Metetra
1 0 0 r
.42218 .32672 .43026 .3299 .44365 .33035 .4356 .32763 Metetra
1 0 0 r
.4356 .32763 .44365 .33035 .45714 .33128 .44913 .32905 Metetra
1 0 0 r
.44913 .32905 .45714 .33128 .47073 .33272 .46278 .331 Metetra
1 0 0 r
.46278 .331 .47073 .33272 .48445 .33471 .47654 .33351 Metetra
1 0 0 r
.47654 .33351 .48445 .33471 .49828 .33727 .49043 .33663 Metetra
1 0 0 r
.49043 .33663 .49828 .33727 .51225 .34043 .50446 .34039 Metetra
1 0 0 r
.50446 .34039 .51225 .34043 .52636 .34425 .51863 .34483 Metetra
1 0 0 r
.51863 .34483 .52636 .34425 .54063 .34875 .53297 .34999 Metetra
1 0 0 r
.53297 .34999 .54063 .34875 .55506 .35398 .54748 .35591 Metetra
1 0 0 r
.54748 .35591 .55506 .35398 .56967 .35999 .56218 .36264 Metetra
1 0 0 r
.56218 .36264 .56967 .35999 .58448 .36682 .57707 .37024 Metetra
1 0 0 r
.57707 .37024 .58448 .36682 .59949 .37452 .59218 .37875 Metetra
1 0 0 r
.59218 .37875 .59949 .37452 .61472 .38316 .60723 .37693 Metetra
1 0 0 r
.60723 .37693 .61472 .38316 .62981 .38111 .62229 .37196 Metetra
1 0 0 r
.62229 .37196 .62981 .38111 .6449 .37616 .63744 .36696 Metetra
1 0 0 r
.63744 .36696 .6449 .37616 .66007 .37119 .65267 .36194 Metetra
1 0 0 r
.65267 .36194 .66007 .37119 .67533 .36619 .66798 .35689 Metetra
1 0 0 r
.66798 .35689 .67533 .36619 .69067 .36117 .68338 .35182 Metetra
1 0 0 r
.68338 .35182 .69067 .36117 .70609 .35611 .69886 .34671 Metetra
1 0 0 r
.69886 .34671 .70609 .35611 .7216 .35103 .71442 .34158 Metetra
1 0 0 r
.71442 .34158 .7216 .35103 .73719 .34592 .73007 .33642 Metetra
1 0 0 r
.73007 .33642 .73719 .34592 .75286 .34079 .74581 .33123 Metetra
1 0 0 r
.74581 .33123 .75286 .34079 .76862 .33562 .76163 .32601 Metetra
1 0 0 r
.08737 .3989 .09607 .40767 .10802 .40268 .09934 .39395 Metetra
1 0 0 r
.09934 .39395 .10802 .40268 .12001 .39772 .11135 .38905 Metetra
1 0 0 r
.11135 .38905 .12001 .39772 .13205 .39282 .1234 .38422 Metetra
1 0 0 r
.1234 .38422 .13205 .39282 .14413 .38798 .13549 .37946 Metetra
1 0 0 r
.13549 .37946 .14413 .38798 .15624 .38322 .14763 .3748 Metetra
1 0 0 r
.14763 .3748 .15624 .38322 .16841 .37855 .1598 .37024 Metetra
1 0 0 r
.1598 .37024 .16841 .37855 .18061 .37397 .17202 .36579 Metetra
1 0 0 r
.17202 .36579 .18061 .37397 .19285 .36951 .18428 .36148 Metetra
1 0 0 r
.18428 .36148 .19285 .36951 .20514 .36518 .19658 .3573 Metetra
1 0 0 r
.19658 .3573 .20514 .36518 .21747 .361 .20893 .35329 Metetra
1 0 0 r
.20893 .35329 .21747 .361 .22985 .35697 .22131 .34945 Metetra
1 0 0 r
.22131 .34945 .22985 .35697 .24227 .35311 .23375 .34579 Metetra
1 0 0 r
.23375 .34579 .24227 .35311 .25473 .34944 .24623 .34233 Metetra
1 0 0 r
.24623 .34233 .25473 .34944 .26725 .34597 .25876 .3391 Metetra
1 0 0 r
.25876 .3391 .26725 .34597 .27982 .34271 .27134 .3361 Metetra
1 0 0 r
.27134 .3361 .27982 .34271 .29243 .3397 .28398 .33335 Metetra
1 0 0 r
.28398 .33335 .29243 .3397 .30511 .33694 .29667 .33087 Metetra
1 0 0 r
.29667 .33087 .30511 .33694 .31784 .33445 .30941 .32868 Metetra
1 0 0 r
.30941 .32868 .31784 .33445 .33063 .33224 .32223 .32679 Metetra
1 0 0 r
.32223 .32679 .33063 .33224 .34348 .33035 .3351 .32524 Metetra
1 0 0 r
.3351 .32524 .34348 .33035 .3564 .32879 .34805 .32403 Metetra
1 0 0 r
.34805 .32403 .3564 .32879 .3694 .32758 .36106 .32319 Metetra
1 0 0 r
.36106 .32319 .3694 .32758 .38247 .32674 .37416 .32275 Metetra
1 0 0 r
.37416 .32275 .38247 .32674 .39562 .32631 .38734 .32273 Metetra
1 0 0 r
.38734 .32273 .39562 .32631 .40885 .32629 .40061 .32315 Metetra
1 0 0 r
.40061 .32315 .40885 .32629 .42218 .32672 .41397 .32405 Metetra
1 0 0 r
.41397 .32405 .42218 .32672 .4356 .32763 .42743 .32544 Metetra
1 0 0 r
.42743 .32544 .4356 .32763 .44913 .32905 .441 .32736 Metetra
1 0 0 r
.441 .32736 .44913 .32905 .46278 .331 .45469 .32985 Metetra
1 0 0 r
.45469 .32985 .46278 .331 .47654 .33351 .4685 .33293 Metetra
1 0 0 r
.4685 .33293 .47654 .33351 .49043 .33663 .48245 .33664 Metetra
1 0 0 r
.48245 .33664 .49043 .33663 .50446 .34039 .49654 .34102 Metetra
1 0 0 r
.49654 .34102 .50446 .34039 .51863 .34483 .51078 .34612 Metetra
1 0 0 r
.51078 .34612 .51863 .34483 .53297 .34999 .52519 .35196 Metetra
1 0 0 r
.52519 .35196 .53297 .34999 .54748 .35591 .53978 .35861 Metetra
1 0 0 r
.53978 .35861 .54748 .35591 .56218 .36264 .55455 .36611 Metetra
1 0 0 r
.55455 .36611 .56218 .36264 .57707 .37024 .56954 .37451 Metetra
1 0 0 r
.56954 .37451 .57707 .37024 .59218 .37875 .58454 .37272 Metetra
1 0 0 r
.58454 .37272 .59218 .37875 .60723 .37693 .59958 .36773 Metetra
1 0 0 r
.59958 .36773 .60723 .37693 .62229 .37196 .6147 .36272 Metetra
1 0 0 r
.6147 .36272 .62229 .37196 .63744 .36696 .6299 .35767 Metetra
1 0 0 r
.6299 .35767 .63744 .36696 .65267 .36194 .64519 .3526 Metetra
1 0 0 r
.64519 .3526 .65267 .36194 .66798 .35689 .66056 .3475 Metetra
1 0 0 r
.66056 .3475 .66798 .35689 .68338 .35182 .67601 .34237 Metetra
1 0 0 r
.67601 .34237 .68338 .35182 .69886 .34671 .69155 .33721 Metetra
1 0 0 r
.69155 .33721 .69886 .34671 .71442 .34158 .70717 .33203 Metetra
1 0 0 r
.70717 .33203 .71442 .34158 .73007 .33642 .72288 .32682 Metetra
1 0 0 r
.72288 .32682 .73007 .33642 .74581 .33123 .73868 .32157 Metetra
1 0 0 r
.73868 .32157 .74581 .33123 .76163 .32601 .75456 .3163 Metetra
1 0 0 r
.07858 .39016 .08737 .3989 .09934 .39395 .09057 .38527 Metetra
1 0 0 r
.09057 .38527 .09934 .39395 .11135 .38905 .10259 .38044 Metetra
1 0 0 r
.10259 .38044 .11135 .38905 .1234 .38422 .11466 .3757 Metetra
1 0 0 r
.11466 .3757 .1234 .38422 .13549 .37946 .12677 .37105 Metetra
1 0 0 r
.12677 .37105 .13549 .37946 .14763 .3748 .13892 .3665 Metetra
1 0 0 r
.13892 .3665 .14763 .3748 .1598 .37024 .1511 .36207 Metetra
1 0 0 r
.1511 .36207 .1598 .37024 .17202 .36579 .16333 .35777 Metetra
1 0 0 r
.16333 .35777 .17202 .36579 .18428 .36148 .1756 .35361 Metetra
1 0 0 r
.1756 .35361 .18428 .36148 .19658 .3573 .18792 .34961 Metetra
1 0 0 r
.18792 .34961 .19658 .3573 .20893 .35329 .20027 .34579 Metetra
1 0 0 r
.20027 .34579 .20893 .35329 .22131 .34945 .21267 .34215 Metetra
1 0 0 r
.21267 .34215 .22131 .34945 .23375 .34579 .22512 .33871 Metetra
1 0 0 r
.22512 .33871 .23375 .34579 .24623 .34233 .23761 .33549 Metetra
1 0 0 r
.23761 .33549 .24623 .34233 .25876 .3391 .25016 .33251 Metetra
1 0 0 r
.25016 .33251 .25876 .3391 .27134 .3361 .26275 .32977 Metetra
1 0 0 r
.26275 .32977 .27134 .3361 .28398 .33335 .2754 .32731 Metetra
1 0 0 r
.2754 .32731 .28398 .33335 .29667 .33087 .28811 .32513 Metetra
1 0 0 r
.28811 .32513 .29667 .33087 .30941 .32868 .30087 .32326 Metetra
1 0 0 r
.30087 .32326 .30941 .32868 .32223 .32679 .3137 .32172 Metetra
1 0 0 r
.3137 .32172 .32223 .32679 .3351 .32524 .3266 .32052 Metetra
1 0 0 r
.3266 .32052 .3351 .32524 .34805 .32403 .33956 .31969 Metetra
1 0 0 r
.33956 .31969 .34805 .32403 .36106 .32319 .3526 .31925 Metetra
1 0 0 r
.3526 .31925 .36106 .32319 .37416 .32275 .36573 .31923 Metetra
1 0 0 r
.36573 .31923 .37416 .32275 .38734 .32273 .37893 .31964 Metetra
1 0 0 r
.37893 .31964 .38734 .32273 .40061 .32315 .39223 .32053 Metetra
1 0 0 r
.39223 .32053 .40061 .32315 .41397 .32405 .40563 .32191 Metetra
1 0 0 r
.40563 .32191 .41397 .32405 .42743 .32544 .41913 .32381 Metetra
1 0 0 r
.41913 .32381 .42743 .32544 .441 .32736 .43274 .32627 Metetra
1 0 0 r
.43274 .32627 .441 .32736 .45469 .32985 .44648 .32932 Metetra
1 0 0 r
.44648 .32932 .45469 .32985 .4685 .33293 .46034 .33299 Metetra
1 0 0 r
.46034 .33299 .4685 .33293 .48245 .33664 .47434 .33733 Metetra
1 0 0 r
.47434 .33733 .48245 .33664 .49654 .34102 .48848 .34237 Metetra
1 0 0 r
.48848 .34237 .49654 .34102 .51078 .34612 .50279 .34815 Metetra
1 0 0 r
.50279 .34815 .51078 .34612 .52519 .35196 .51727 .35472 Metetra
1 0 0 r
.51727 .35472 .52519 .35196 .53978 .35861 .53194 .36214 Metetra
1 0 0 r
.53194 .36214 .53978 .35861 .55455 .36611 .5468 .37044 Metetra
1 0 0 r
.5468 .37044 .55455 .36611 .56954 .37451 .56175 .3685 Metetra
1 0 0 r
.56175 .3685 .56954 .37451 .58454 .37272 .57676 .36349 Metetra
1 0 0 r
.57676 .36349 .58454 .37272 .59958 .36773 .59186 .35845 Metetra
1 0 0 r
.59186 .35845 .59958 .36773 .6147 .36272 .60703 .35338 Metetra
1 0 0 r
.60703 .35338 .6147 .36272 .6299 .35767 .62229 .34828 Metetra
1 0 0 r
.62229 .34828 .6299 .35767 .64519 .3526 .63763 .34316 Metetra
1 0 0 r
.63763 .34316 .64519 .3526 .66056 .3475 .65306 .33801 Metetra
1 0 0 r
.65306 .33801 .66056 .3475 .67601 .34237 .66857 .33283 Metetra
1 0 0 r
.66857 .33283 .67601 .34237 .69155 .33721 .68416 .32762 Metetra
1 0 0 r
.68416 .32762 .69155 .33721 .70717 .33203 .69985 .32238 Metetra
1 0 0 r
.69985 .32238 .70717 .33203 .72288 .32682 .71562 .31711 Metetra
1 0 0 r
.71562 .31711 .72288 .32682 .73868 .32157 .73148 .31182 Metetra
1 0 0 r
.73148 .31182 .73868 .32157 .75456 .3163 .74742 .30649 Metetra
1 0 0 r
.0697 .38147 .07858 .39016 .09057 .38527 .0817 .37665 Metetra
1 0 0 r
.0817 .37665 .09057 .38527 .10259 .38044 .09374 .37192 Metetra
1 0 0 r
.09374 .37192 .10259 .38044 .11466 .3757 .10582 .36728 Metetra
1 0 0 r
.10582 .36728 .11466 .3757 .12677 .37105 .11794 .36275 Metetra
1 0 0 r
.11794 .36275 .12677 .37105 .13892 .3665 .1301 .35833 Metetra
1 0 0 r
.1301 .35833 .13892 .3665 .1511 .36207 .1423 .35405 Metetra
1 0 0 r
.1423 .35405 .1511 .36207 .16333 .35777 .15454 .34992 Metetra
1 0 0 r
.15454 .34992 .16333 .35777 .1756 .35361 .16682 .34594 Metetra
1 0 0 r
.16682 .34594 .1756 .35361 .18792 .34961 .17914 .34213 Metetra
1 0 0 r
.17914 .34213 .18792 .34961 .20027 .34579 .19151 .33851 Metetra
1 0 0 r
.19151 .33851 .20027 .34579 .21267 .34215 .20392 .3351 Metetra
1 0 0 r
.20392 .3351 .21267 .34215 .22512 .33871 .21637 .3319 Metetra
1 0 0 r
.21637 .3319 .22512 .33871 .23761 .33549 .22888 .32894 Metetra
1 0 0 r
.22888 .32894 .23761 .33549 .25016 .33251 .24143 .32622 Metetra
1 0 0 r
.24143 .32622 .25016 .33251 .26275 .32977 .25404 .32378 Metetra
1 0 0 r
.25404 .32378 .26275 .32977 .2754 .32731 .2667 .32162 Metetra
1 0 0 r
.2667 .32162 .2754 .32731 .28811 .32513 .27942 .31977 Metetra
1 0 0 r
.27942 .31977 .28811 .32513 .30087 .32326 .2922 .31824 Metetra
1 0 0 r
.2922 .31824 .30087 .32326 .3137 .32172 .30504 .31705 Metetra
1 0 0 r
.30504 .31705 .3137 .32172 .3266 .32052 .31796 .31623 Metetra
1 0 0 r
.31796 .31623 .3266 .32052 .33956 .31969 .33095 .3158 Metetra
1 0 0 r
.33095 .3158 .33956 .31969 .3526 .31925 .34401 .31578 Metetra
1 0 0 r
.34401 .31578 .3526 .31925 .36573 .31923 .35716 .3162 Metetra
1 0 0 r
.35716 .3162 .36573 .31923 .37893 .31964 .37039 .31708 Metetra
1 0 0 r
.37039 .31708 .37893 .31964 .39223 .32053 .38372 .31845 Metetra
1 0 0 r
.38372 .31845 .39223 .32053 .40563 .32191 .39715 .32034 Metetra
1 0 0 r
.39715 .32034 .40563 .32191 .41913 .32381 .41069 .32278 Metetra
1 0 0 r
.41069 .32278 .41913 .32381 .43274 .32627 .42434 .32581 Metetra
1 0 0 r
.42434 .32581 .43274 .32627 .44648 .32932 .43812 .32945 Metetra
1 0 0 r
.43812 .32945 .44648 .32932 .46034 .33299 .45203 .33375 Metetra
1 0 0 r
.45203 .33375 .46034 .33299 .47434 .33733 .46608 .33874 Metetra
1 0 0 r
.46608 .33874 .47434 .33733 .48848 .34237 .48029 .34447 Metetra
1 0 0 r
.48029 .34447 .48848 .34237 .50279 .34815 .49466 .35098 Metetra
1 0 0 r
.49466 .35098 .50279 .34815 .51727 .35472 .50921 .35832 Metetra
1 0 0 r
.50921 .35832 .51727 .35472 .53194 .36214 .52396 .36654 Metetra
1 0 0 r
.52396 .36654 .53194 .36214 .5468 .37044 .53886 .36426 Metetra
1 0 0 r
.53886 .36426 .5468 .37044 .56175 .3685 .55384 .35923 Metetra
1 0 0 r
.55384 .35923 .56175 .3685 .57676 .36349 .56891 .35416 Metetra
1 0 0 r
.56891 .35416 .57676 .36349 .59186 .35845 .58406 .34907 Metetra
1 0 0 r
.58406 .34907 .59186 .35845 .60703 .35338 .59929 .34395 Metetra
1 0 0 r
.59929 .34395 .60703 .35338 .62229 .34828 .6146 .3388 Metetra
1 0 0 r
.6146 .3388 .62229 .34828 .63763 .34316 .63 .33363 Metetra
1 0 0 r
.63 .33363 .63763 .34316 .65306 .33801 .64548 .32842 Metetra
1 0 0 r
.64548 .32842 .65306 .33801 .66857 .33283 .66105 .32319 Metetra
1 0 0 r
.66105 .32319 .66857 .33283 .68416 .32762 .67671 .31793 Metetra
1 0 0 r
.67671 .31793 .68416 .32762 .69985 .32238 .69245 .31263 Metetra
1 0 0 r
.69245 .31263 .69985 .32238 .71562 .31711 .70828 .30731 Metetra
1 0 0 r
.70828 .30731 .71562 .31711 .73148 .31182 .7242 .30196 Metetra
1 0 0 r
.7242 .30196 .73148 .31182 .74742 .30649 .74021 .29658 Metetra
1 0 0 r
.06073 .37285 .0697 .38147 .0817 .37665 .07275 .36813 Metetra
1 0 0 r
.07275 .36813 .0817 .37665 .09374 .37192 .0848 .36351 Metetra
1 0 0 r
.0848 .36351 .09374 .37192 .10582 .36728 .09688 .35899 Metetra
1 0 0 r
.09688 .35899 .10582 .36728 .11794 .36275 .10901 .3546 Metetra
1 0 0 r
.10901 .3546 .11794 .36275 .1301 .35833 .12118 .35034 Metetra
1 0 0 r
.12118 .35034 .1301 .35833 .1423 .35405 .13339 .34622 Metetra
1 0 0 r
.13339 .34622 .1423 .35405 .15454 .34992 .14563 .34227 Metetra
1 0 0 r
.14563 .34227 .15454 .34992 .16682 .34594 .15792 .33849 Metetra
1 0 0 r
.15792 .33849 .16682 .34594 .17914 .34213 .17025 .33489 Metetra
1 0 0 r
.17025 .33489 .17914 .34213 .19151 .33851 .18262 .3315 Metetra
1 0 0 r
.18262 .3315 .19151 .33851 .20392 .3351 .19504 .32833 Metetra
1 0 0 r
.19504 .32833 .20392 .3351 .21637 .3319 .2075 .32539 Metetra
1 0 0 r
.2075 .32539 .21637 .3319 .22888 .32894 .22001 .3227 Metetra
1 0 0 r
.22001 .3227 .22888 .32894 .24143 .32622 .23258 .32028 Metetra
1 0 0 r
.23258 .32028 .24143 .32622 .25404 .32378 .24519 .31814 Metetra
1 0 0 r
.24519 .31814 .25404 .32378 .2667 .32162 .25787 .31631 Metetra
1 0 0 r
.25787 .31631 .2667 .32162 .27942 .31977 .2706 .31479 Metetra
1 0 0 r
.2706 .31479 .27942 .31977 .2922 .31824 .28339 .31363 Metetra
1 0 0 r
.28339 .31363 .2922 .31824 .30504 .31705 .29625 .31282 Metetra
1 0 0 r
.29625 .31282 .30504 .31705 .31796 .31623 .30918 .3124 Metetra
1 0 0 r
.30918 .3124 .31796 .31623 .33095 .3158 .32219 .31239 Metetra
1 0 0 r
.32219 .31239 .33095 .3158 .34401 .31578 .33527 .31282 Metetra
1 0 0 r
.33527 .31282 .34401 .31578 .35716 .3162 .34844 .3137 Metetra
1 0 0 r
.34844 .3137 .35716 .3162 .37039 .31708 .3617 .31507 Metetra
1 0 0 r
.3617 .31507 .37039 .31708 .38372 .31845 .37506 .31696 Metetra
1 0 0 r
.37506 .31696 .38372 .31845 .39715 .32034 .38852 .31939 Metetra
1 0 0 r
.38852 .31939 .39715 .32034 .41069 .32278 .40209 .3224 Metetra
1 0 0 r
.40209 .3224 .41069 .32278 .42434 .32581 .41579 .32602 Metetra
1 0 0 r
.41579 .32602 .42434 .32581 .43812 .32945 .42961 .33029 Metetra
1 0 0 r
.42961 .33029 .43812 .32945 .45203 .33375 .44357 .33524 Metetra
1 0 0 r
.44357 .33524 .45203 .33375 .46608 .33874 .45767 .34092 Metetra
1 0 0 r
.45767 .34092 .46608 .33874 .48029 .34447 .47194 .34738 Metetra
1 0 0 r
.47194 .34738 .48029 .34447 .49466 .35098 .48638 .35465 Metetra
1 0 0 r
.48638 .35465 .49466 .35098 .50921 .35832 .501 .3628 Metetra
1 0 0 r
.501 .3628 .50921 .35832 .52396 .36654 .51586 .36 Metetra
1 0 0 r
.51586 .36 .52396 .36654 .53886 .36426 .53082 .35494 Metetra
1 0 0 r
.53082 .35494 .53886 .36426 .55384 .35923 .54585 .34986 Metetra
1 0 0 r
.54585 .34986 .55384 .35923 .56891 .35416 .56097 .34474 Metetra
1 0 0 r
.56097 .34474 .56891 .35416 .58406 .34907 .57617 .3396 Metetra
1 0 0 r
.57617 .3396 .58406 .34907 .59929 .34395 .59146 .33443 Metetra
1 0 0 r
.59146 .33443 .59929 .34395 .6146 .3388 .60683 .32923 Metetra
1 0 0 r
.60683 .32923 .6146 .3388 .63 .33363 .62229 .324 Metetra
1 0 0 r
.62229 .324 .63 .33363 .64548 .32842 .63783 .31874 Metetra
1 0 0 r
.63783 .31874 .64548 .32842 .66105 .32319 .65346 .31345 Metetra
1 0 0 r
.65346 .31345 .66105 .32319 .67671 .31793 .66917 .30813 Metetra
1 0 0 r
.66917 .30813 .67671 .31793 .69245 .31263 .68497 .30279 Metetra
1 0 0 r
.68497 .30279 .69245 .31263 .70828 .30731 .70087 .29741 Metetra
1 0 0 r
.70087 .29741 .70828 .30731 .7242 .30196 .71685 .292 Metetra
1 0 0 r
.71685 .292 .7242 .30196 .74021 .29658 .73292 .28657 Metetra
1 0 0 r
.05166 .36434 .06073 .37285 .07275 .36813 .06368 .35973 Metetra
1 0 0 r
.06368 .35973 .07275 .36813 .0848 .36351 .07574 .35524 Metetra
1 0 0 r
.07574 .35524 .0848 .36351 .09688 .35899 .08784 .35086 Metetra
1 0 0 r
.08784 .35086 .09688 .35899 .10901 .3546 .09997 .34662 Metetra
1 0 0 r
.09997 .34662 .10901 .3546 .12118 .35034 .11214 .34253 Metetra
1 0 0 r
.11214 .34253 .12118 .35034 .13339 .34622 .12435 .3386 Metetra
1 0 0 r
.12435 .3386 .13339 .34622 .14563 .34227 .1366 .33485 Metetra
1 0 0 r
.1366 .33485 .14563 .34227 .15792 .33849 .1489 .33128 Metetra
1 0 0 r
.1489 .33128 .15792 .33849 .17025 .33489 .16123 .32792 Metetra
1 0 0 r
.16123 .32792 .17025 .33489 .18262 .3315 .17361 .32477 Metetra
1 0 0 r
.17361 .32477 .18262 .3315 .19504 .32833 .18603 .32186 Metetra
1 0 0 r
.18603 .32186 .19504 .32833 .2075 .32539 .1985 .3192 Metetra
1 0 0 r
.1985 .3192 .2075 .32539 .22001 .3227 .21102 .3168 Metetra
1 0 0 r
.21102 .3168 .22001 .3227 .23258 .32028 .22359 .31469 Metetra
1 0 0 r
.22359 .31469 .23258 .32028 .24519 .31814 .23621 .31288 Metetra
1 0 0 r
.23621 .31288 .24519 .31814 .25787 .31631 .24889 .31139 Metetra
1 0 0 r
.24889 .31139 .25787 .31631 .2706 .31479 .26163 .31025 Metetra
1 0 0 r
.26163 .31025 .2706 .31479 .28339 .31363 .27444 .30946 Metetra
1 0 0 r
.27444 .30946 .28339 .31363 .29625 .31282 .28731 .30906 Metetra
1 0 0 r
.28731 .30906 .29625 .31282 .30918 .3124 .30026 .30907 Metetra
1 0 0 r
.30026 .30907 .30918 .3124 .32219 .31239 .31328 .30951 Metetra
1 0 0 r
.31328 .30951 .32219 .31239 .33527 .31282 .32638 .3104 Metetra
1 0 0 r
.32638 .3104 .33527 .31282 .34844 .3137 .33957 .31178 Metetra
1 0 0 r
.33957 .31178 .34844 .3137 .3617 .31507 .35286 .31366 Metetra
1 0 0 r
.35286 .31366 .3617 .31507 .37506 .31696 .36624 .31609 Metetra
1 0 0 r
.36624 .31609 .37506 .31696 .38852 .31939 .37973 .31909 Metetra
1 0 0 r
.37973 .31909 .38852 .31939 .40209 .3224 .39334 .32269 Metetra
1 0 0 r
.39334 .32269 .40209 .3224 .41579 .32602 .40707 .32694 Metetra
1 0 0 r
.40707 .32694 .41579 .32602 .42961 .33029 .42094 .33187 Metetra
1 0 0 r
.42094 .33187 .42961 .33029 .44357 .33524 .43494 .33752 Metetra
1 0 0 r
.43494 .33752 .44357 .33524 .45767 .34092 .4491 .34393 Metetra
1 0 0 r
.4491 .34393 .45767 .34092 .47194 .34738 .46343 .35115 Metetra
1 0 0 r
.46343 .35115 .47194 .34738 .48638 .35465 .47793 .35923 Metetra
1 0 0 r
.47793 .35923 .48638 .35465 .501 .3628 .49276 .35572 Metetra
1 0 0 r
.49276 .35572 .501 .3628 .51586 .36 .50768 .35064 Metetra
1 0 0 r
.50768 .35064 .51586 .36 .53082 .35494 .52269 .34553 Metetra
1 0 0 r
.52269 .34553 .53082 .35494 .54585 .34986 .53778 .34039 Metetra
1 0 0 r
.53778 .34039 .54585 .34986 .56097 .34474 .55296 .33522 Metetra
1 0 0 r
.55296 .33522 .56097 .34474 .57617 .3396 .56821 .33003 Metetra
1 0 0 r
.56821 .33003 .57617 .3396 .59146 .33443 .58356 .3248 Metetra
1 0 0 r
.58356 .3248 .59146 .33443 .60683 .32923 .59898 .31955 Metetra
1 0 0 r
.59898 .31955 .60683 .32923 .62229 .324 .6145 .31427 Metetra
1 0 0 r
.6145 .31427 .62229 .324 .63783 .31874 .6301 .30895 Metetra
1 0 0 r
.6301 .30895 .63783 .31874 .65346 .31345 .64578 .30361 Metetra
1 0 0 r
.64578 .30361 .65346 .31345 .66917 .30813 .66156 .29824 Metetra
1 0 0 r
.66156 .29824 .66917 .30813 .68497 .30279 .67742 .29284 Metetra
1 0 0 r
.67742 .29284 .68497 .30279 .70087 .29741 .69337 .2874 Metetra
1 0 0 r
.69337 .2874 .70087 .29741 .71685 .292 .70942 .28194 Metetra
1 0 0 r
.70942 .28194 .71685 .292 .73292 .28657 .72555 .27645 Metetra
1 0 0 r
.04248 .35595 .05166 .36434 .06368 .35973 .05451 .35148 Metetra
1 0 0 r
.05451 .35148 .06368 .35973 .07574 .35524 .06657 .34713 Metetra
1 0 0 r
.06657 .34713 .07574 .35524 .08784 .35086 .07867 .34291 Metetra
1 0 0 r
.07867 .34291 .08784 .35086 .09997 .34662 .09081 .33885 Metetra
1 0 0 r
.09081 .33885 .09997 .34662 .11214 .34253 .10298 .33495 Metetra
1 0 0 r
.10298 .33495 .11214 .34253 .12435 .3386 .11519 .33122 Metetra
1 0 0 r
.11519 .33122 .12435 .3386 .1366 .33485 .12745 .32768 Metetra
1 0 0 r
.12745 .32768 .1366 .33485 .1489 .33128 .13974 .32435 Metetra
1 0 0 r
.13974 .32435 .1489 .33128 .16123 .32792 .15208 .32124 Metetra
1 0 0 r
.15208 .32124 .16123 .32792 .17361 .32477 .16446 .31836 Metetra
1 0 0 r
.16446 .31836 .17361 .32477 .18603 .32186 .17688 .31572 Metetra
1 0 0 r
.17688 .31572 .18603 .32186 .1985 .3192 .18935 .31336 Metetra
1 0 0 r
.18935 .31336 .1985 .3192 .21102 .3168 .20188 .31128 Metetra
1 0 0 r
.20188 .31128 .21102 .3168 .22359 .31469 .21445 .3095 Metetra
1 0 0 r
.21445 .3095 .22359 .31469 .23621 .31288 .22708 .30804 Metetra
1 0 0 r
.22708 .30804 .23621 .31288 .24889 .31139 .23977 .30692 Metetra
1 0 0 r
.23977 .30692 .24889 .31139 .26163 .31025 .25251 .30616 Metetra
1 0 0 r
.25251 .30616 .26163 .31025 .27444 .30946 .26533 .30579 Metetra
1 0 0 r
.26533 .30579 .27444 .30946 .28731 .30906 .27821 .30581 Metetra
1 0 0 r
.27821 .30581 .28731 .30906 .30026 .30907 .29117 .30627 Metetra
1 0 0 r
.29117 .30627 .30026 .30907 .31328 .30951 .30421 .30717 Metetra
1 0 0 r
.30421 .30717 .31328 .30951 .32638 .3104 .31733 .30856 Metetra
1 0 0 r
.31733 .30856 .32638 .3104 .33957 .31178 .33054 .31046 Metetra
1 0 0 r
.33054 .31046 .33957 .31178 .35286 .31366 .34385 .31289 Metetra
1 0 0 r
.34385 .31289 .35286 .31366 .36624 .31609 .35726 .31588 Metetra
1 0 0 r
.35726 .31588 .36624 .31609 .37973 .31909 .37078 .31948 Metetra
1 0 0 r
.37078 .31948 .37973 .31909 .39334 .32269 .38442 .32372 Metetra
1 0 0 r
.38442 .32372 .39334 .32269 .40707 .32694 .39819 .32863 Metetra
1 0 0 r
.39819 .32863 .40707 .32694 .42094 .33187 .41209 .33425 Metetra
1 0 0 r
.41209 .33425 .42094 .33187 .43494 .33752 .42615 .34062 Metetra
1 0 0 r
.42615 .34062 .43494 .33752 .4491 .34393 .44036 .3478 Metetra
1 0 0 r
.44036 .3478 .4491 .34393 .46343 .35115 .45474 .35583 Metetra
1 0 0 r
.45474 .35583 .46343 .35115 .47793 .35923 .46954 .35142 Metetra
1 0 0 r
.46954 .35142 .47793 .35923 .49276 .35572 .48444 .34632 Metetra
1 0 0 r
.48444 .34632 .49276 .35572 .50768 .35064 .49942 .34118 Metetra
1 0 0 r
.49942 .34118 .50768 .35064 .52269 .34553 .51448 .33602 Metetra
1 0 0 r
.51448 .33602 .52269 .34553 .53778 .34039 .52963 .33083 Metetra
1 0 0 r
.52963 .33083 .53778 .34039 .55296 .33522 .54486 .32561 Metetra
1 0 0 r
.54486 .32561 .55296 .33522 .56821 .33003 .56017 .32036 Metetra
1 0 0 r
.56017 .32036 .56821 .33003 .58356 .3248 .57557 .31508 Metetra
1 0 0 r
.57557 .31508 .58356 .3248 .59898 .31955 .59105 .30977 Metetra
1 0 0 r
.59105 .30977 .59898 .31955 .6145 .31427 .60662 .30444 Metetra
1 0 0 r
.60662 .30444 .6145 .31427 .6301 .30895 .62228 .29907 Metetra
1 0 0 r
.62228 .29907 .6301 .30895 .64578 .30361 .63803 .29367 Metetra
1 0 0 r
.63803 .29367 .64578 .30361 .66156 .29824 .65386 .28824 Metetra
1 0 0 r
.65386 .28824 .66156 .29824 .67742 .29284 .66979 .28278 Metetra
1 0 0 r
.66979 .28278 .67742 .29284 .69337 .2874 .6858 .27729 Metetra
1 0 0 r
.6858 .27729 .69337 .2874 .70942 .28194 .70191 .27177 Metetra
1 0 0 r
.70191 .27177 .70942 .28194 .72555 .27645 .71811 .26622 Metetra
1 0 0 r
.03318 .34772 .04248 .35595 .05451 .35148 .04521 .34339 Metetra
1 0 0 r
.04521 .34339 .05451 .35148 .06657 .34713 .05728 .33921 Metetra
1 0 0 r
.05728 .33921 .06657 .34713 .07867 .34291 .06938 .33517 Metetra
1 0 0 r
.06938 .33517 .07867 .34291 .09081 .33885 .08152 .3313 Metetra
1 0 0 r
.08152 .3313 .09081 .33885 .10298 .33495 .09369 .32761 Metetra
1 0 0 r
.09369 .32761 .10298 .33495 .11519 .33122 .1059 .3241 Metetra
1 0 0 r
.1059 .3241 .11519 .33122 .12745 .32768 .11816 .32081 Metetra
1 0 0 r
.11816 .32081 .12745 .32768 .13974 .32435 .13045 .31772 Metetra
1 0 0 r
.13045 .31772 .13974 .32435 .15208 .32124 .14278 .31488 Metetra
1 0 0 r
.14278 .31488 .15208 .32124 .16446 .31836 .15516 .31228 Metetra
1 0 0 r
.15516 .31228 .16446 .31836 .17688 .31572 .16759 .30995 Metetra
1 0 0 r
.16759 .30995 .17688 .31572 .18935 .31336 .18006 .30791 Metetra
1 0 0 r
.18006 .30791 .18935 .31336 .20188 .31128 .19258 .30616 Metetra
1 0 0 r
.19258 .30616 .20188 .31128 .21445 .3095 .20516 .30473 Metetra
1 0 0 r
.20516 .30473 .21445 .3095 .22708 .30804 .21779 .30365 Metetra
1 0 0 r
.21779 .30365 .22708 .30804 .23977 .30692 .23048 .30292 Metetra
1 0 0 r
.23048 .30292 .23977 .30692 .25251 .30616 .24324 .30257 Metetra
1 0 0 r
.24324 .30257 .25251 .30616 .26533 .30579 .25606 .30262 Metetra
1 0 0 r
.25606 .30262 .26533 .30579 .27821 .30581 .26895 .3031 Metetra
1 0 0 r
.26895 .3031 .27821 .30581 .29117 .30627 .28192 .30403 Metetra
1 0 0 r
.28192 .30403 .29117 .30627 .30421 .30717 .29497 .30544 Metetra
1 0 0 r
.29497 .30544 .30421 .30717 .31733 .30856 .3081 .30734 Metetra
1 0 0 r
.3081 .30734 .31733 .30856 .33054 .31046 .32133 .30978 Metetra
1 0 0 r
.32133 .30978 .33054 .31046 .34385 .31289 .33466 .31279 Metetra
1 0 0 r
.33466 .31279 .34385 .31289 .35726 .31588 .34809 .31639 Metetra
1 0 0 r
.34809 .31639 .35726 .31588 .37078 .31948 .36164 .32062 Metetra
1 0 0 r
.36164 .32062 .37078 .31948 .38442 .32372 .37531 .32552 Metetra
1 0 0 r
.37531 .32552 .38442 .32372 .39819 .32863 .38912 .33112 Metetra
1 0 0 r
.38912 .33112 .39819 .32863 .41209 .33425 .40306 .33747 Metetra
1 0 0 r
.40306 .33747 .41209 .33425 .42615 .34062 .41716 .34462 Metetra
1 0 0 r
.41716 .34462 .42615 .34062 .44036 .3478 .43144 .35221 Metetra
1 0 0 r
.43144 .35221 .44036 .3478 .45474 .35583 .44623 .3471 Metetra
1 0 0 r
.44623 .3471 .45474 .35583 .46954 .35142 .46109 .34197 Metetra
1 0 0 r
.46109 .34197 .46954 .35142 .48444 .34632 .47604 .33682 Metetra
1 0 0 r
.47604 .33682 .48444 .34632 .49942 .34118 .49108 .33163 Metetra
1 0 0 r
.49108 .33163 .49942 .34118 .51448 .33602 .50619 .32641 Metetra
1 0 0 r
.50619 .32641 .51448 .33602 .52963 .33083 .52139 .32117 Metetra
1 0 0 r
.52139 .32117 .52963 .33083 .54486 .32561 .53668 .31589 Metetra
1 0 0 r
.53668 .31589 .54486 .32561 .56017 .32036 .55205 .31059 Metetra
1 0 0 r
.55205 .31059 .56017 .32036 .57557 .31508 .5675 .30526 Metetra
1 0 0 r
.5675 .30526 .57557 .31508 .59105 .30977 .58304 .2999 Metetra
1 0 0 r
.58304 .2999 .59105 .30977 .60662 .30444 .59867 .2945 Metetra
1 0 0 r
.59867 .2945 .60662 .30444 .62228 .29907 .61439 .28908 Metetra
1 0 0 r
.61439 .28908 .62228 .29907 .63803 .29367 .6302 .28362 Metetra
1 0 0 r
.6302 .28362 .63803 .29367 .65386 .28824 .64609 .27814 Metetra
1 0 0 r
.64609 .27814 .65386 .28824 .66979 .28278 .66208 .27262 Metetra
1 0 0 r
.66208 .27262 .66979 .28278 .6858 .27729 .67815 .26708 Metetra
1 0 0 r
.67815 .26708 .6858 .27729 .70191 .27177 .69432 .2615 Metetra
1 0 0 r
.69432 .2615 .70191 .27177 .71811 .26622 .71059 .25589 Metetra
1 0 0 r
.02377 .33966 .03318 .34772 .04521 .34339 .03579 .33551 Metetra
1 0 0 r
.03579 .33551 .04521 .34339 .05728 .33921 .04786 .33151 Metetra
1 0 0 r
.04786 .33151 .05728 .33921 .06938 .33517 .05995 .32767 Metetra
1 0 0 r
.05995 .32767 .06938 .33517 .08152 .3313 .07209 .32401 Metetra
1 0 0 r
.07209 .32401 .08152 .3313 .09369 .32761 .08426 .32054 Metetra
1 0 0 r
.08426 .32054 .09369 .32761 .1059 .3241 .09647 .31728 Metetra
1 0 0 r
.09647 .31728 .1059 .3241 .11816 .32081 .10872 .31424 Metetra
1 0 0 r
.10872 .31424 .11816 .32081 .13045 .31772 .12101 .31143 Metetra
1 0 0 r
.12101 .31143 .13045 .31772 .14278 .31488 .13334 .30888 Metetra
1 0 0 r
.13334 .30888 .14278 .31488 .15516 .31228 .14571 .30658 Metetra
1 0 0 r
.14571 .30658 .15516 .31228 .16759 .30995 .15814 .30458 Metetra
1 0 0 r
.15814 .30458 .16759 .30995 .18006 .30791 .17061 .30287 Metetra
1 0 0 r
.17061 .30287 .18006 .30791 .19258 .30616 .18313 .30148 Metetra
1 0 0 r
.18313 .30148 .19258 .30616 .20516 .30473 .1957 .30043 Metetra
1 0 0 r
.1957 .30043 .20516 .30473 .21779 .30365 .20833 .29974 Metetra
1 0 0 r
.20833 .29974 .21779 .30365 .23048 .30292 .22103 .29942 Metetra
1 0 0 r
.22103 .29942 .23048 .30292 .24324 .30257 .23378 .29951 Metetra
1 0 0 r
.23378 .29951 .24324 .30257 .25606 .30262 .24661 .30001 Metetra
1 0 0 r
.24661 .30001 .25606 .30262 .26895 .3031 .25951 .30097 Metetra
1 0 0 r
.25951 .30097 .26895 .3031 .28192 .30403 .27248 .3024 Metetra
1 0 0 r
.27248 .3024 .28192 .30403 .29497 .30544 .28554 .30433 Metetra
1 0 0 r
.28554 .30433 .29497 .30544 .3081 .30734 .29869 .30679 Metetra
1 0 0 r
.29869 .30679 .3081 .30734 .32133 .30978 .31193 .30981 Metetra
1 0 0 r
.31193 .30981 .32133 .30978 .33466 .31279 .32528 .31341 Metetra
1 0 0 r
.32528 .31341 .33466 .31279 .34809 .31639 .33874 .31765 Metetra
1 0 0 r
.33874 .31765 .34809 .31639 .36164 .32062 .35231 .32255 Metetra
1 0 0 r
.35231 .32255 .36164 .32062 .37531 .32552 .36601 .32814 Metetra
1 0 0 r
.36601 .32814 .37531 .32552 .38912 .33112 .37985 .33448 Metetra
1 0 0 r
.37985 .33448 .38912 .33112 .40306 .33747 .39384 .34161 Metetra
1 0 0 r
.39384 .34161 .40306 .33747 .41716 .34462 .40804 .34789 Metetra
1 0 0 r
.40804 .34789 .41716 .34462 .43144 .35221 .4228 .34277 Metetra
1 0 0 r
.4228 .34277 .43144 .35221 .44623 .3471 .43764 .33761 Metetra
1 0 0 r
.43764 .33761 .44623 .3471 .46109 .34197 .45256 .33243 Metetra
1 0 0 r
.45256 .33243 .46109 .34197 .47604 .33682 .46756 .32722 Metetra
1 0 0 r
.46756 .32722 .47604 .33682 .49108 .33163 .48265 .32198 Metetra
1 0 0 r
.48265 .32198 .49108 .33163 .50619 .32641 .49782 .31671 Metetra
1 0 0 r
.49782 .31671 .50619 .32641 .52139 .32117 .51307 .31141 Metetra
1 0 0 r
.51307 .31141 .52139 .32117 .53668 .31589 .52841 .30608 Metetra
1 0 0 r
.52841 .30608 .53668 .31589 .55205 .31059 .54384 .30072 Metetra
1 0 0 r
.54384 .30072 .55205 .31059 .5675 .30526 .55935 .29533 Metetra
1 0 0 r
.55935 .29533 .5675 .30526 .58304 .2999 .57495 .28992 Metetra
1 0 0 r
.57495 .28992 .58304 .2999 .59867 .2945 .59064 .28447 Metetra
1 0 0 r
.59064 .28447 .59867 .2945 .61439 .28908 .60641 .27899 Metetra
1 0 0 r
.60641 .27899 .61439 .28908 .6302 .28362 .62228 .27347 Metetra
1 0 0 r
.62228 .27347 .6302 .28362 .64609 .27814 .63824 .26793 Metetra
1 0 0 r
.63824 .26793 .64609 .27814 .66208 .27262 .65428 .26236 Metetra
1 0 0 r
.65428 .26236 .66208 .27262 .67815 .26708 .67042 .25675 Metetra
1 0 0 r
.67042 .25675 .67815 .26708 .69432 .2615 .68666 .25111 Metetra
1 0 0 r
.68666 .25111 .69432 .2615 .71059 .25589 .70298 .24544 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.01)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.02)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.03)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.04)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.05)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06033 .24606 m
.06319 .24877 L
s
.08372 .23691 m
.08655 .23964 L
s
.10732 .22766 m
.11013 .23042 L
s
.13115 .21833 m
.13394 .22111 L
s
.17948 .19941 m
.18222 .20223 L
s
.20399 .18981 m
.2067 .19266 L
s
.22873 .18012 m
.23142 .183 L
s
.25371 .17034 m
.25638 .17324 L
s
.3044 .15049 m
.30701 .15344 L
s
.33011 .14043 m
.3327 .14339 L
s
.35608 .13026 m
.35864 .13325 L
s
.3823 .11999 m
.38483 .12301 L
s
.43553 .09915 m
.43799 .10222 L
s
.46254 .08857 m
.46497 .09167 L
s
.48982 .07789 m
.49222 .08101 L
s
.51738 .0671 m
.51975 .07024 L
s
.57333 .04519 m
.57563 .04838 L
s
.60174 .03407 m
.60401 .03728 L
s
.63044 .02283 m
.63267 .02607 L
s
.65944 .01147 m
.66163 .01474 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00[oooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000?ooooo0ol0001Mooooo`00[_ooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`1Jooooo`00
[_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool0F_ooool00:kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo05[ooooo002^ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
oooooooooooo0000ooooo`04o`0005gooooo002^ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool0000=ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o
00000oooool3o`0003oooooo002_ooooo`;o00002_ooool2o`0000;ooooo1Ol00008ooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
oooo03cooooo0035ooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool0??ooool00<cooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03cooooo003<ooooo`04o`000?oo
ooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0003oooooo003<ooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00012ooooo`00`Oooool2o`00
00[ooooo0_l0000:ooooo`;o00000_ooool5o`0003kooooo002nooooo`?o000000?oooooo`000?l0
0000G?ooool00;cooooo0_l00004ooooo`;o0000G?ooool008Wooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`?o00006oooool4o`0000Gooooo00?o0000ooooool00000Fooo
ool008Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo01Oooooo0ol00009ooooo`03o`000?oooooo000005_ooooo0028ooooo`04o`000?oo
ooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`05o`0001Kooooo0_l0000<ooooo`03
o`000?oooooooooo00;o0000FOooool008Sooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool04_ooool4o`0000gooooo00Go0000
ooooooooooooooooo`00001Iooooo`00R?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooool000004_ooool2o`00017ooooo00Go0000oooooooooooo
ooooo`00001Iooooo`00R?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00?ooooo0_l0000?ooooo`?o00004oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05Kooooo0029ooooo`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool02oooool2o`000003
ooooool0003ooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Eooooo`00
Yoooool3o`0001Wooooo00?o0000ooooooooool00_ooool2o`0005Kooooo002Uooooo`;o00007?oo
ool00ol0003oooooooooo`02ooooo`;o0000E_ooool00:;ooooo0ol000000ooooooo0000ooooo`0K
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Doooool009oooooo0ol0000Qoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Doooool009gooooo0_l0000Tooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0D_ooool009[ooooo0ol00002ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool01_ooool2o`0005;ooooo002Hooooo`;o0000:Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo057ooooo001Vooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`;o00000oooool3o`0001_ooooo1?l0000Zooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0D?ooool006Gooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool05_ooool2o`0002kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1?ooooo`00IOooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool04oooool3o`00033o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1?ooooo`00IOooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000Cooooo`?o000000?oooooo`00
0?ooool0<?ooool00ol0003oooooooooo`09ooooo`;o00003Oooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0ol0000]ooooo`00IOooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool03_ooool2o`0003Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0/ooooo`00IOooool01?l0003ooooooooo
ool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0;oooo
o`?o0000>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo1Ol00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`05o`0002gooooo001V
ooooo`;o00002_ooool2o`0000?ooooo0ol0000<ooooo`;o00000_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`0/ooooo`00
Poooool3o`0003kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00000^oooo
o`00POooool2o`00047ooooo00?o0000ooooooooool02oooool2o`0000Wooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00003ooooo`;o0000;_ooool007kooooo0ol00002oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool02oooool2o`0000[ooooo0_l0000:oooo
o`;o00001Oooool00ol0003oooooooooo`0/ooooo`00O?ooool2o`0004Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`1:ooooo`00NOooool4o`0004Oooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`19ooooo`00M_ooool3o`0000Cooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Sooooo0014ooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`;o00000_ooool5o`0001_ooooo0_l0001>ooooo`03o`000?oooooo
oooo00kooooo0_l00019ooooo`00@oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00006?ooool3o`0000;ooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`0>ooooo`;o0000BOooool004?ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Kooooo0_l0001Cooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0A_ooool004?ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01;ooooo1?l0001Doooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0A_ooool004?ooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool03ooo
ool2o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`15ooooo`00@oooool0
1?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooooooo`0<ooooo`?o0000F_ooool00ol0003oooooooooo`0Aooooo`;o0000A_ooool004Cooooo
0_l0000:ooooo`;o00000oooool3o`0000cooooo0ol000000ooooooo0000ooooo`1Jooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0A?ooool006;ooooo0_l0001Pooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0@oooool005oooooo1?l0001Qooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0@_ooool005gooooo0_l0001Uooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0@_ooool005[ooooo0ol0001Xooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0@Oooool005Sooooo0_l00002ooooo`03o`000?oooooooooo06Kooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`10ooooo`008oooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000?ooooo0ol0000Nooooo`?o0000KOooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo043ooooo000Rooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`0Kooooo`?o0000Koooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00gooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`?o00007_ooool002;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo01Sooooo0ol0001booooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool02oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`0Kooooo`008_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool05Oooool3o`0007Gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`Go00000_ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool06oooool002;o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo01?ooooo0_l00002ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool2o`0001kooooo000Rooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000_ooool2o`0001;ooooo0ol0001jooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool06oooool002?ooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`0>oooo
o`Co0000Noooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
6oooool004?ooooo0ol0001oooooo`03o`000?oooooooooo01Wooooo0_l0000;ooooo`;o00002_oo
ool2o`0000?ooooo0ol0000Nooooo`00@Oooool2o`0008;ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0jooooo`00?_ooool3o`000003ooooool0003ooooo087ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0jooooo`00>oooool3o`0008Oooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0iooooo`00>Oooool2o`000003ooooool0003ooooo08Oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0hooooo`005oooool2o`0001gooooo0ol0
0004ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool07?ooool2o`0003[ooooo000F
ooooo`04o`000?ooooooooooo`0001[ooooo0ol0002?ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0=oooool001Kooooo00Co0000oooooooooooo00005oooool3o`0000;ooooo00?o
0000ooooooooool0SOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Oooooo000F
ooooo`04o`000?ooooooooooo`0001Gooooo0_l0002Eooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0=_ooool001Kooooo00Co0000oooooooooooo00004_ooool3o`000003ooooool0
003ooooo09Cooooo00?o0000ooooooooool07_ooool2o`0003Oooooo000Fooooo`04o`000?oooooo
ooooo`00013ooooo0_l0002Jooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0=Ooo
ool001Oooooo0_l0000>ooooo`Co0000Voooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo03Cooooo000Tooooo`?o0000Woooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
03?ooooo000Rooooo`?o0000Woooool3o`0002?ooooo0_l0000dooooo`007oooool3o`0000;ooooo
00?o0000ooooooooool0V_ooool4o`000003ool00?l0003o000002?ooooo00?o0000ooooooooool0
<_ooool001kooooo0_l0002Oooooo`Co00001?oo0002o`0002?ooooo00?o0000ooooooooool0<Ooo
ool001kooooo0ol0002Kooooo`?o00001?oo00001_l0003oo`00o`000?l0003oo`00o`0002?ooooo
00?o0000ooooooooool03Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo
1Ol0000?ooooo`007_ooool01?l0003oooooooooool0002Fooooo`Co00000ooo00000ol0003oo`00
ool00003o`0000Coo`0000?o0000ooooooooool08Oooool2o`0000cooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo000Noooo
o`05o`000?ooooooooooooooool00000T_ooool4o`000003ool00?l0003oo`0000?oo`000ol00003
ool00003o`000?oo003oo`0000?o00008oooool00ol0003oooooooooo`03ooooo`Go00000_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
3oooool001gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2=ooooo`Co00001?oo
00001_l0003oo`00o`000?l0003oo`00o`0000Coo`000ol00002ool00003o`000?oooooooooo027o
oooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`29ooooo`?o00001?oo00000ol0003oo`00ool00003o`0000Coo`0000Ko0000ool0
0?l0003o0000ool00?l00004ool00003o`000?oooooooooo027ooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`0=ooooo`007Oooool2o`0000Kooooo00?o0000ooooooooool0QOooool3o`0000?o
o`0000?o0000ool00?oo00001?l00003ool00003o`000?oo003oo`0000?o00001?oo00000ol0003o
o`00ool00003o`0002?ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0=ooooo`007Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo087ooooo0ol000000ooo003o0000ool00003
ool000?o00000ooo00000ol0003oo`00ool00004o`0000?oo`0000?o0000ool00?oo00001?l00002
ool000;o00008Oooool2o`0000_ooooo0_l0000:ooooo`;o00000oooool3o`00013ooooo0009oooo
o`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0OOooool4o`0000Coo`0000Ko0000ool00?l0003o0000ool00?l00004ool000?o00000_oo
00000ol0003oo`00ool00002ool000?o00000_oo00001?l0003oo`00ool00?oo0003o`0002;ooooo
00?o0000ooooooooool0;?ooool000[ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1iooooo`Co00000ooo00000ol0003oo`00ool00003o`0000Coo`0000Ko0000ool00?l0
003o0000ool00?l00004ool00006o`000?oo003o0000o`000?oo003o00000ooo0004o`0000;oo`00
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0[ooooo`000_ooool5o`0000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo0_l0000;ooooo`03o`000?oooooooooo07Gooooo0ol00003ool00003o`000?oo003oo`0000Co
00000ooo00000ol0003oo`00ool00003o`0000Coo`0000?o0000ool00?oo00000ol00004ool000?o
000000?oo`00o`000?oo00000ooo0002o`0002;ooooo0_l0000/ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo3_l00019ooooo`Co00001?oo0003o`00
00;oo`0000?o0000ool00?oo00000_oo0003o`0000?oo`0000?o0000ool00?oo00001?l00002ool0
0003o`000?oo003oo`0000?o00001?oo00000ol0003oo`00ool00003o`0002;ooooo0_l0000/oooo
o`002_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo2_l00002
ool001Go0000?Oooool3o`0000Coo`0000Ko0000ool00?l0003o0000ool00?l00004ool00006o`00
0?oo003o0000o`000?oo003o00001?oo0003o`0000;oo`0000?o0000ool00?oo00001?l00003ool0
0003o`000?oo003oo`0000Co00000ooo00000ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
02Wooooo0009ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000?ooooo0_l0000>ooooo`03o`000?oooooooooo00Wooooo1ol00002ool000[o00000_oo000H
o`0003?ooooo1?l00003ool00003o`000?oo003oo`0000?o00001?oo00000ol0003oo`00ool00003
o`0000Coo`0000Ko0000ool00?l0003o0000ool00?l00003ool000?o00000_oo00000ol0003oo`00
ool00002ool000?o00000ooo00000ol0003oo`00ool00003o`0002;ooooo00?o0000ooooooooool0
:Oooool000[ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`03o`000?oo
oooooooo00kooooo0_l00003ooooo`Oo00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o
0000ool00?oo00001ol00002ool00003o`000?oo003oo`0001_o0000:?ooool4o`0000;oo`0000?o
0000ool00?oo00001?l00003ool00003o`000?oo003oo`0000Co00000ooo00000ol0003oo`00ool0
0003o`0000Coo`000ol000000ooo003o0000ool00003ool00006o`000?oo003o0000o`000?oo003o
00001?oo0003o`0000;oo`0000?o0000ooooooooool08Oooool2o`0002Wooooo000Looooo`03o`00
0?oooooooooo013ooooo0ol00002ool00003o`000?oo003oo`0000Oo00000_oo0007o`0000;oo`00
00?o0000ool00?oo00001_l00003ool00003o`000?oo003oo`0001_o00008?ooool4o`0000Coo`00
0ol00002ool00003o`000?oo003oo`0000;oo`000ol00003ool00003o`000?oo003oo`0000Co0000
0ooo00000ol0003oo`00ool00002o`0000Coo`0000?o0000ool00?oo00000ol00004ool00006o`00
0?oo003o0000o`000?oo003o00001?oo00000ol0003oooooooooo`0Pooooo`;o0000:Oooool001_o
oooo0_l0000?ooooo`?o00000_oo00000ol0003oo`00ool00003o`0000?oo`0000?o0000ool00?oo
00000ol00002ool00003o`000?oo003oo`0000Oo00000_oo00000ol0003oo`00ool00007o`0000;o
o`003Ol00002ool000Ko00000_oo0009o`0001Kooooo0ol00004ool00006o`000?oo003o0000o`00
0?oo003o00001?oo00001_l0003oo`00o`000?l0003oo`00o`0000Coo`000ol00002ool00003o`00
0?oo003oo`0000;oo`000ol00002ool00003o`000?oo003oo`0000Co00000ooo00000ol0003oo`00
ool00003o`0000Coo`0000?o0000ool00?oo00000ol0000Rooooo`03o`000?oooooooooo02Oooooo
000Kooooo`03o`000?oooooooooo00_ooooo0ol00002ool00003o`000?oo003oo`0000Co00000_oo
00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00003ool00003o`000?oo
003oo`0000Ko00000_oo0007o`0000;oo`0000?o0000ool00?oo00002_l00002ool00003o`000?oo
003o000000Go00000_oo000<o`0000cooooo0ol00003ool00003o`000?oo003oo`0000?o00001?oo
00000ol0003oo`00ool00003o`0000Coo`0000Ko0000ool00?l0003o0000ool00?l00004ool00006
o`000?oo003o0000o`000?oo003o00000ooo0003o`0000?oo`0000?o0000ool00?oo00001?l00003
ool00003o`000?oo003oo`0000Co00000_oo0002o`0002;ooooo00?o0000ooooooooool09_ooool0
01_ooooo00?o0000ooooooooool01Oooool6o`0000;oo`001ol00002ool000Ko00000_oo0007o`00
00;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000ooo00000ol0
003oo`00ool00006o`0000?oo`0000?o0000ool00?oo00002Ol000001?oo003o0000o`000?oo0004
o`0000;oo`0000?o0000ool00?l000003?l00003ooooo`?o00000_oo00000ol0003oo`00ool00004
o`0000?oo`0000?o0000ool00?oo00001?l00003ool00003o`000?oo003oo`0000?o00001?oo0000
0ol0003oo`00ool00003o`0000Coo`000ol000000ooo003o0000ool00003ool000?o00000_oo0000
0ol0003oo`00ool00002ool000?o00000ooo00000ol0003oo`00ool00003o`0002;ooooo00?o0000
ooooooooool09Oooool001_ooooo00?o0000ooooooooool00_ooool3o`0000;oo`0000?o0000ool0
0?oo00000ol00002ool00003o`000?oo003oo`0000Co00000_oo00000ol0003oo`00ool00003o`00
00;oo`0000?o0000ool00?oo00001ol00002ool00003o`000?oo003oo`0000?o00000ooo00000ol0
003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00001ol00002ool00003o`000?oo003oo`00
00[o00000_oo0006o`0000;oo`003?l000000ooo003o0000ool00002ool000?o00000_oo00000ol0
003oo`00ool00002ool000?o00000ooo00000ol0003oo`00ool00004o`0000?oo`0000?o0000ool0
0?oo00001?l00003ool00003o`000?oo003oo`0000;o00001?oo00001_l0003oo`00o`000?l0003o
o`00o`0000Coo`0000Ko0000ool00?l0003o0000ool00?l00004ool000?o00000_oo0002o`00023o
oooo0_l0000Wooooo`006oooool5o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`00
0?oo003oo`0000?o00000ooo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo0000
0ol00003ool00003o`000?oo003oo`0000Ko00000_oo0007o`0000;oo`0000?o0000ool00?oo0000
0ol00003ool00003o`000?oo003oo`0000Ko00000_oo000:o`0000?oo`0000?o0000ool00?oo0000
0ol00002ool00003o`000?oo003o000000Co00001?oo00000ol0003oo`00o`000002ool00006o`00
0?oo003oo`00ool00?l0003oo`000_l000000ooo003o0000ool00003ool000?o00000ooo00000ol0
003oo`00ool00004o`0000?oo`0000?o0000ool00?oo00001?l00002ool00003o`000?oo003oo`00
00?o00001?oo00000ol0003oo`00ool00003o`0000Coo`0000Ko0000ool00?l0003o0000ool00?l0
0004ool000;o00008Oooool00ol0003oooooooooo`0Tooooo`006_ooool2o`0000?oo`0000?o0000
ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000ooo00000ol0003oo`00ool00003
o`0000;oo`0000?o0000ool00?oo00000ol00003ool00003o`000?oo003oo`0000?o00000_oo0000
0ol0003oo`00ool00003o`0000?oo`0000?o0000ool00?oo00001_l00002ool000Oo00000_oo0000
0ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00001ol000001?oo003o0000o`000?l0
0003ool00003o`000?oo003o000000?o00000ooo00000ol0003oo`00ool00003o`0000Coo`0000?o
0000ool00?oo00000_l00004ool00006o`000?oo003o0000o`000?oo003o00001?oo0003o`0000;o
o`0000?o0000ool00?oo00000_oo0003o`0000;oo`0000?o0000ool00?oo00001?l00003ool00003
o`000?oo003oo`0000Co00000ooo00000ol0003oo`00ool00003o`0000Coo`0000?o0000ool00?l0
00000ol0000Rooooo`03o`000?oooooooooo00cooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo0_l00003ooooo`?o00000oooool001[ooooo00?o0000ooooool000000_oo0003o`0000;oo`00
00?o0000ool00?oo00000ol00003ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00
ool00003o`0000?oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o0000
0_oo00000ol0003oo`00ool00004o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`00
0?oo003oo`0000Oo00000_oo00000ol0003oo`00ool00003o`0000?oo`0000?o0000ool00?oo0000
0ol00002ool000Go00000ooo00000ol0003oo`00ool00004o`0000?oo`0000?o0000ool00?oo0000
1?l00002ool00003o`000?oo003oo`0000?o00001?oo00001_l0003oo`00o`000?l0003oo`00o`00
00Coo`0000Ko0000ool00?l0003o0000ool00?l00003ool000?o00000ooo00000ol0003oo`00ool0
0004o`0000?oo`0000?o0000ool00?oo00001?l00003ool00003o`000?oo003oo`0000?o00000ooo
0002o`00027ooooo0_l0000<ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`02ooooo`006_ooool5o`0000;oo`0000?o0000ool00?oo0000
0ol00003ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`00
00?o0000ool00?oo00001?l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00
ool00003o`0000?oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o0000
0ooo00000ol0003oo`00ool00006o`0000;oo`0000?o0000ool00?oo00001?l00002ool000;o0000
00?oo`00o`000?l000000_l00004ool000?o00000ooo00000ol0003oo`00ool00004o`0000?oo`00
00?o0000ool00?oo00000ol00003ool00003o`000?oo003oo`0000?o00001?oo00000ol0003oo`00
ool00003o`0000Coo`0000Go0000ool00?l0003oo`00o`000004ool000?o00000_oo00000ol0003o
o`00ool00002ool000?o00000ooo00000ol0003oo`00ool00004o`0000;oo`0000?o0000ool00?oo
00000ol0000Rooooo`03o`000?oooooooooo00?ooooo1Ol00002ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`004oooool2o`00
00Gooooo00Co0000oooooooooooo00000ooo0003o`0000?oo`0000?o0000ool00?oo00000ol00002
ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000?oo`0000?o0000
ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000ooo00000ol0003oo`00ool00003
o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000Co00000_oo0000
0ol0003oo`00ool00006o`0000;oo`002?l000001Ooo003o0000ool00?l0003oo`0000Co00001?oo
0003o`0000;oo`0000?o0000ool00?oo00000_oo0003o`0000?oo`0000?o0000ool00?oo00000ol0
0003ool00003o`000?oo003oo`0000Co00000ooo00000ol0003oo`00ool00003o`0000?oo`0000Ko
0000ool00?l0003o0000ool00?l00004ool00006o`000?oo003o0000o`000?oo003o00001?oo0003
o`0000;oo`0000?o0000ool00?oo00001?l00003ool00003o`000?oooooooooo023ooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_ooool001;ooooo00Co0000oooooooooooo00001?ooool01ol0003ooooo
oooooooooooo0000ool00?l000000_oo00001?l0003oo`00ool00?oo0003o`0000;oo`0000?o0000
ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000ooo00000ol0003oo`00ool00003
o`0000;oo`0000?o0000ool00?oo00000ol00003ool00003o`000?oo003oo`0000?o00000_oo0000
0ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00003ool00003o`000?oo003o
o`0000?o00000_oo00000ol0003oo`00ool00003o`000004ool00?l0003o0000o`0000;oo`002Ol0
0002ool00003o`000?oo003o000000Co00000ooo00001_l0003oo`00o`000?l0003oo`00o`0000Co
o`000ol00002ool00003o`000?oo003oo`0000Co00000ooo00000ol0003oo`00ool00004o`0000?o
o`0000?o0000ool00?oo00000_l00004ool00003o`000?oo003oo`0000?o00001?oo00001_l0003o
o`00o`000?l0003oo`00o`0000?oo`000ol00003ool00003o`000?oo003oo`0000?o00008Oooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`02ooooo`004_ooool01?l0003oooooooooool00004ooooo`;o0000
0oooool2o`0000?oo`0000?o0000ool00?l000000_oo00000ol0003oo`00ool00003o`0000;oo`00
00?o0000ool00?oo00000ol00003ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00
ool00003o`0000;oo`0000?o0000ool00?oo00001?l00002ool00003o`000?oo003oo`0000?o0000
0_oo00000ol0003oo`00ool00003o`0000?oo`0000?o0000ool00?oo00000ol00002ool00003o`00
0?oo003oo`0000?o000000Goo`00o`000?l0003o0000ool00004o`0000;oo`0000?o0000ool00?oo
00001_l000000ooo003o0000o`000002ool000So00000ooo00001_l0003oo`00o`000?l0003oo`00
o`0000?oo`000ol00003ool00003o`000?oo003oo`0000Co00000ooo00000ol0003oo`00ool00004
o`0000;oo`0000?o0000ool00?oo00001?l00003ool00003o`000?oo003oo`0000?o00001?oo0003
o`000003ool00?l0003oo`0000?oo`000ol00002ool00003o`000?oooooooooo01oooooo0_l0000:
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Cooooo
000Booooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oo`00
ool00002o`0000?oo`000ol00002ool00003o`000?oo003oo`0000?o00000ooo00000ol0003oo`00
ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o0000
0ooo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`00
0?oo003oo`0000Co00000_oo00000ol0003oo`00ool00003o`000005ool00?l0003o0000o`000?oo
00000ol00003ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00006o`0000?o
o`0000?o0000ool00?oo00002?l00003ool00005o`000?oo003o0000ool00?l000001?oo0003o`00
00;oo`0000?o0000ool00?oo00000_oo0003o`0000;oo`0000?o0000ool00?oo00001?l00003ool0
0003o`000?oo003oo`0000Co00000ooo00000ol0003oo`00ool00002o`0000Coo`0000Ko0000ool0
0?l0003o0000ool00?l00004ool00003o`000?oooooooooo01oooooo00?o0000ooooooooool02Ooo
ool2o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo000Booooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool01_ooool2o`0000;oo`0000Go0000ool00?l0003oo`00
o`000003ool000?o00000_oo00000ol0003oo`00ool00004o`0000;oo`0000?o0000ool00?oo0000
0ol00002ool00003o`000?oo003oo`0000?o00000ooo00000ol0003oo`00ool00003o`0000;oo`00
00?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000ooo00000ol0003oo`00
ool00003o`000005ool00?l0003o0000o`000?oo00000ol00002ool00003o`000?oo003oo`0000Co
00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00001ol00002ool000co
00000_oo00001_l0003oo`00o`000?l0003oo`00o`0000Coo`0000Ko0000ool00?l0003o0000ool0
0?l00003ool000?o00000ooo00000ol0003oo`00ool00004o`0000?oo`0000?o0000ool00?oo0000
1?l00002ool00003o`000?oo003oo`0000?o00001?oo00000ol0003oo`00ool00003o`00027ooooo
00?o0000ooooooooool07oooool001;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oo003oo`0000;o00000ooo00001Ol0003oo`00o`000?oo003o000000?o
o`000ol00003ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;o
o`0000?o0000ool00?oo00001?l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003o
o`00ool00003o`0000;oo`0000?o0000ool00?oo00001?l000000ooo003o0000o`000005o`0000;o
o`001_l00002ool00003o`000?oo003oo`0000Co00000_oo00000ol0003oo`00ool00003o`0000;o
o`0000?o0000ool00?oo00001?l00002ool00003o`000?oo003oo`0000Ko000000?oo`00o`000?l0
00000ol00003ool00003o`000?oo003oo`0000?o00001?oo00001Ol0003oo`00o`000?oo003o0000
00Coo`000ol00003ool00003o`000?oo003oo`0000Co00000_oo00000ol0003oo`00ool00004o`00
00?oo`0000?o0000ool00?oo00001?l00002ool00003o`000?oooooooooo023ooooo00?o0000oooo
ooooool07_ooool001?ooooo0_l00004ooooo`;o00002Oooool2o`0000;oo`0000?o0000ool00?oo
00000_l00003ool00003o`000?oo003o000000;oo`0000Co0000ool00?oo003oo`000ol00002ool0
0003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000?oo`0000?o0000ool0
0?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`00
00;oo`001?l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00006o`00
00;oo`001ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00004o`00
00;oo`0000?o0000ool00?oo00001_l000000ooo003o0000o`000004o`0000?oo`0000?o0000ool0
0?oo00000ol00003ool00006o`000?oo003o0000o`000?oo003o00001?oo0003o`0000;oo`0000Co
0000ool00?oo003oo`000ol00003ool00003o`000?oo003oo`0000Co00000ooo00000ol0003oo`00
ool00002o`00027ooooo0_l0000Oooooo`006Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000?oo`0000?o0000ool00?l000000_oo
00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00003ool00003o`000?oo
003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol0
0002ool000?o00000ooo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol0
0002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00007o`0000;oo`001_l0
0002ool00003o`000?oo003oo`0000Co00000_oo00000ol0003oo`00ool00006o`0000;oo`001_l0
0002ool00003o`000?oo003oo`0000?o00001?oo00001_l0003oo`00o`000?l0003oo`00o`0000Co
o`000ol000000ooo003o0000ool00003ool000?o00000ooo00000ol0003oo`00ool00004o`0000;o
o`0000?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`006Oooool00ol0003ooooo
ooooo`0:ooooo`;o00000_oo00000ol0003oo`00ool00003o`0000?oo`0000?o0000ool00?oo0000
0_l00003ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo0000
1?l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`00
0ol00002ool00003o`000?oo003oo`0000Co00000_oo00000ol0003oo`00ool00003o`0000;oo`00
00?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000ooo00000ol0003oo`00
ool00003o`0000;oo`0000?o0000ool00?oo00001_l00002ool00003o`000?oo003oo`0000Co0000
0_oo00000ol0003oo`00ool00007o`0000;oo`001Ol00003ool00003o`000?oo003oo`0000?o0000
1?oo00000ol0003oo`00ool00002o`0000Coo`0000Ko0000ool00?l0003o0000ool00?l00004ool0
00?o00000_oo00000ol0003oo`00ool00003o`00027ooooo00?o0000ooooooooool07?ooool001So
oooo0_l0000=ooooo`03o`000?oo003oo`0000?o00000ooo00000ol0003oo`00ool00003o`0000;o
o`0000Go0000ool00?l0003oo`00o`000003ool000?o00000_oo00000ol0003oo`00ool00003o`00
00?oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo0005o`00
00?oo`000ol00003ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`00
00;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000Co00000_oo00000ol0
003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00001_l00003ool00003o`000?oo003oo`00
00?o00000_oo00000ol0003oo`00ool00007o`000004ool00?l0003oo`00ool000Co00000ooo0000
0ol0003oo`00ool00004o`0000;oo`0000?o0000ool00?oo00000ol00004ool00006o`000?oo003o
0000o`000?oo003o00000ooo0003o`0000;oo`000_l0000Pooooo`;o00007Oooool001Sooooo00?o
0000ooooooooool03Oooool2o`0000?oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo
003oo`0000;o00000ooo00001Ol0003oo`00o`000?oo003o000000?oo`000ol00003ool00003o`00
0?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`001_l00002ool00005o`00
0?oo003o0000ool00?l000001?oo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003
o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo
00001?l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00007o`000003
ool00?l0003o000000Go00000_oo00000ol0003oo`00ool00007o`000003ool00?l0003o000000;o
o`001?l00002ool00003o`000?oo003oo`0000Co00000ooo00000ol0003oo`00ool00003o`0000Co
o`000ol000000ooo003o0000ool00003ool000;o00007oooool2o`0001gooooo000Hooooo`03o`00
0?oooooooooo00oooooo00?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o0000
0_oo00000ol0003oo`00ool00002o`0000?oo`0000?o0000ool00?l000000_oo00000ol0003oo`00
ool00004o`0000;oo`0000?o0000ool00?oo00000ol00002ool000Ko00000_oo00000ol0003oo`00
ool00002o`0000?oo`0000Ko0000ool00?l0003o0000ool00?l00002ool000Co00000_oo00000ol0
003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`00
00?o00000_oo00000ol0003oo`00ool00004o`0000;oo`0000?o0000ool00?oo00000ol00002ool0
0003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00007o`0000;oo`0000?o0000ool0
0?oo00001ol00002ool000;o00000_oo0003o`0000?oo`0000?o0000ool00?oo00001?l00002ool0
0003o`000?oo003oo`0000?o00001?oo00001_l0003oo`00o`000?l0003oo`00o`00027ooooo00?o
0000ooooooooool06_ooool001Sooooo00?o0000ooooooooool04?ooool2o`0000;oo`0000?o0000
ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00002
o`0000?oo`000ol00003ool00003o`000?oo003oo`0000?o00000_oo0006o`0000;oo`0000?o0000
ool00?oo00000ol00002ool00003o`000?oo003oo`0000;o00000ooo0003o`0000?oo`0000?o0000
ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003
o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000Co00000_oo0000
0ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003o
o`0000Oo00000_oo00000ol0003oo`00ool00008o`000003ool00?l0003o000000;oo`001?l00003
ool00003o`000?oo003oo`0000?o00000ooo00000ol0003oo`00ool00003o`0000?oo`000_l0000P
ooooo`03o`000?oooooooooo01[ooooo000Hooooo`;o00004Oooool01?l0003oo`00ool00?oo0003
o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo0000
0ol0003oo`00o`000002ool00004o`000?oo003oo`00ool000?o00000_oo0006o`0000;oo`0000?o
0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00o`00
0002ool00003o`000?oo003oo`0000Co00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o
0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool0
0003o`0000;oo`0000?o0000ool00?oo00001?l00002ool00003o`000?oo003oo`0000?o00000_oo
00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00001ol00002ool00003o`000?oo
003oo`0000So000000Coo`00o`000?l0003o00000_oo0004o`0000;oo`0000?o0000ool00?oo0000
1?l00003ool00003o`000?oo003oo`0000?o00008?ooool2o`0001[ooooo000Hooooo`03o`000?oo
oooooooo017ooooo00Go0000ool00?l0003oo`00o`000003ool000?o00000_oo00000ol0003oo`00
ool00003o`0000;oo`0000?o0000ool00?oo00000_l00004ool00006o`000?oo003o0000ool00?l0
003oo`001Ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`00
00;oo`0000?o0000ool00?oo00000_l00003ool000?o00000_oo00000ol0003oo`00ool00004o`00
00;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0
003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`00
00Co00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool0
0003o`000?oo003oo`0000Oo00000_oo00000ol0003oo`00ool0000<o`0000;oo`001?l00003ool0
0003o`000?oo003oo`0000Co00000_oo0005o`0001gooooo00?o0000ooooooooool06?ooool001Oo
oooo00?o0000ooooooooool04oooool02Ol0003oo`00ool00?oo003o0000ool00?l0003oo`00o`00
0003ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol0
00002?oo003o0000o`000?l0003oo`00o`000?oo003o00000ooo0003o`0000;oo`0000?o0000ool0
0?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00001Ol0003oo`00o`000?oo003o
000000?oo`000ol00003ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003
o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo0000
0ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00001?l00002ool00003o`000?oo003o
o`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00001ol00002
ool00003o`000?oo003oo`0000go00000_oo0004o`0000;oo`0000?o0000ool00?oo00002ol0000H
ooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`005oooool3o`0001Cooooo00?o0000ool0
0?oo00000_l00003ool00003o`000?oo003o000000;oo`0000?o0000ool00?oo00000ol00002ool0
0003o`000?oo003oo`0000?o000000Coo`00o`000?l0003o00000_oo0002o`0000?oo`0000?o0000
ool00?l000000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002
ool00003o`000?oo003oo`0000;o00000ooo00000ol0003oo`00o`000002ool00003o`000?oo003o
o`0000Co00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002
ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000
ool00?oo00000ol00002ool000Oo000000?oo`00o`000?l000001Ol00002ool00003o`000?oo003o
o`0000?o00000_oo00000ol0003oo`00ool00007o`000003ool00?l0003o000000So000000?oo`00
o`000?l000001?l00002ool000Co00000_oo000<o`0001Kooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool0000?ooooo`000oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool0
0ol0003oooooooooo`0Eooooo`;o00000_oo00000ol0003oo`00ool00002o`0000?oo`000ol00002
ool00003o`000?oo003oo`0000?o000000Coo`00o`000?l0003o00000_oo0003o`0000;oo`0000?o
0000ool00?oo00000_l00003ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o
0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000;o00000ooo0003o`0000;oo`0000?o
0000ool00?oo00001?l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool0
0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo
0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000Oo00000_oo
00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo
003oo`0000[o000000Coo`00o`000?l0003o00000ooo00000ol0003oo`00ool0000?o`0001?ooooo
0_l00005ooooo`04o`000?ooooooooooo`0000oooooo0004ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
01Kooooo00?o0000ool00?oo00000ol00002ool00005o`000?oo003o0000ool00?l000000ooo0003
o`000005ool00?l0003o0000o`000?oo00001?l00002ool00003o`000?oo003oo`0000?o00000_oo
00001Ol0003oo`00o`000?oo003o000000?oo`000ol00002ool00003o`000?oo003oo`0000?o0000
0_oo00000ol0003oo`00ool00003o`0000;oo`0000Go0000ool00?l0003oo`00o`000003ool000?o
00000_oo00000ol0003oo`00ool00004o`000004ool00?l0003oo`00ool000Co00000_oo00000ol0
003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool000?o00000_oo00000ol0
003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`00
00Oo000000?oo`00o`000?l000001Ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0
003oo`00ool0000?o`0000;oo`000_l000001?oo003o0000o`000?oo000:o`00017ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool0000?ooooo`001?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0Gooooo`;o00000_oo00000ol0003oo`00ool00002o`0000?oo`0000Co0000ool00?l0003o
o`000ol000001?oo003o0000o`000?l00003ool00003o`000?oo003oo`0000?o00000_oo00000ol0
003oo`00ool00002o`0000?oo`0000?o0000ool00?l000000_oo00000ol0003oo`00ool00003o`00
00;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000;o00000ooo00000ol0
003oo`00o`000002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`00
00;oo`0000?o0000ool00?oo00001?l00002ool00003o`000?oo003oo`0000?o00000_oo0003o`00
00;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0
003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`00
00Oo00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00004?l000001?oo
003o0000ool00?l00002ool000So00004?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000oooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`;o00006Oooool00ol0003oo`00ool00003o`0000;oo`00
00?o0000ool00?oo00001?l000001?oo003o0000ool00?l00002ool00004o`000?oo003oo`00ool0
00?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000_l00003ool0
00?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool0
0003o`000?oo003oo`0000;o00000ooo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool0
0003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00004o`000003ool00?l0003oo`00
00;o000000Coo`00o`000?oo003oo`001?l000001?oo003o0000ool00?oo0004o`0000;oo`0000?o
0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool0
0003o`0000;oo`0000?o0000ool00?oo00001ol000001?oo003o0000ool00?oo0004o`0000;oo`00
00?o0000ool00?oo00002_l000000ooo003o0000o`00000>o`0000gooooo0ol00003ooooo`04o`00
0?ooooooooooo`0000oooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01[ooooo0_l00002ool0
0003o`000?oo003oo`0000Co000000Coo`00o`000?oo003oo`000ol00003ool00003o`000?oo003o
000000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo0000
1Ol0003oo`00o`000?oo003o000000?oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo
00000ol0003oo`00ool00003o`0000;oo`0000Go0000ool00?l0003oo`00o`000003ool000?o0000
0_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`00
0?oo003oo`0000;o00000ooo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`00
0?oo003oo`0000Co000000Coo`00o`000?oo003oo`001?l000001?oo003o0000ool00?oo0004o`00
00;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000Ko00000_oo0007o`00
0004ool00?l0003oo`00ool001So00002Oooool3o`000003ooooool0003o000000Cooooo0_l0000@
ooooo`000oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo01_ooooo00?o0000ool00?oo00001?l000001?oo003o0000ool0
0?oo0003o`0000?oo`0000?o0000ool00?oo00000_l00003ool000?o00000_oo00000ol0003oo`00
ool00003o`0000;oo`0000?o0000ool00?oo00000_l00003ool00005o`000?oo003o0000ool00?l0
00000ooo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000;o
00000ooo00000ol0003oo`00o`000002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003o
o`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003o000000;o
o`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003o
o`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000Co
000000Coo`00o`000?oo003oo`001?l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0
003oo`00ool00006o`0000;oo`0000?o0000ool00?oo00005Ol00004ooooo`?o00001Oooool00ol0
003oooooooooo`0Dooooo`001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Co
oooo0_l0000Mooooo`?o000000Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`00
00Co00000_oo00001Ol0003oo`00o`000?oo003o000000?oo`000ol00002ool00003o`000?oo003o
o`0000?o00000_oo00000ol0003oo`00ool00002o`0000?oo`0000?o0000ool00?l000000_oo0000
0ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003o
o`0000;o00000ooo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003o
o`0000?o00000_oo00000ol0003oo`00ool00002o`0000?oo`000ol00002ool00003o`000?oo003o
o`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002
ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000
ool00?oo00001?l000001?oo003o0000ool00?oo0004o`000004ool00?l0003oo`00ool000Oo0000
00?oo`00o`000?l000000_oo000Do`0000Sooooo00?o0000ooooooooool05?ooool001Kooooo00?o
0000ooooooooool06_ooool3o`0000?oo`000ol00002ool00003o`000?oo003oo`0000?o00000ooo
00000ol0003oo`00ool00002o`0000?oo`0000?o0000ool00?l000000_oo00000ol0003oo`00ool0
0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000;o00000ooo
0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo
00000ol0003oo`00o`000002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool0
0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003o000000;oo`0000?o
0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool0
0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo
00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo
003oo`0000?o00000_oo00000ol0003oo`00ool00007o`0000;oo`0000?o0000ool00?oo00003Ol0
000:ooooo`03o`000?oooooooooo01Cooooo000Fooooo`03o`000?oooooooooo01Oooooo0ol00003
ooooo`03o`000?oo003o000000;oo`0000Co0000ool00?oo003oo`000_l00003ool00003o`000?oo
003oo`0000?o00000_oo00000ol0003oo`00ool00002o`0000?oo`000ol00002ool00003o`000?oo
003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000Go0000ool00?l0003oo`00
o`000003ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo0000
0_l00003ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo0000
0ol00002ool00003o`000?oo003oo`0000;o00000ooo0003o`0000;oo`0000?o0000ool00?oo0000
0ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`00
00?o0000ool00?oo00000ol000000ooo003o0000o`000005o`000003ool00?l0003o000000Go0000
00?oo`00o`000?l000001Ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00
ool00007o`000004ool00?l0003oo`00ool000[o00002_ooool00ol0003oooooooooo`0Cooooo`00
5_ooool00ol0003oooooooooo`0Dooooo`?o00001oooool2o`0000?oo`0000?o0000ool00?l00000
0_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00005o`00
0?oo003o0000ool00?l000000ooo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003
o`000?oo003oo`0000;o00000ooo00000ol0003oo`00o`000002ool00003o`000?oo003oo`0000?o
00000_oo00000ol0003oo`00ool00003o`0000;oo`0000Go0000ool00?l0003oo`00o`000003ool0
00?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool0
0005o`000?oo003o0000ool00?l000000_oo0004o`000004ool00?l0003oo`00ool000Co000000Co
o`00o`000?oo003oo`001?l000001?oo003o0000ool00?oo0004o`000004ool00?l0003o0000o`00
00;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0
003oo`00ool00007o`0000;oo`0000?o0000ool00?oo00000ol000000ooo003o0000o`000002ool0
00Ko00000_oo00000ol0003oo`00ool00006o`0000Wooooo00?o0000ooooooooool04oooool001Go
oooo0ol0000Booooo`?o00003?ooool00ol0003oo`00ool00002o`0000?oo`000ol00002ool00003
o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00002o`0000?oo`0000?o0000ool00?l0
00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003
o`000?oo003oo`0000;o00000ooo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003
o`000?oo003oo`0000;o00000ooo00001Ol0003oo`00o`000?oo003o000000;oo`001?l000001?oo
003o0000ool00?oo0004o`000004ool00?l0003oo`00ool000?o00000_oo0003o`0000;oo`0000?o
0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool0
0003o`0000;oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool0
0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000Oo000000?o
o`00o`000?l000001Ol000001?oo003o0000ool00?oo0007o`0000;oo`0000?o0000ool00?oo0000
0_l00008ooooo`03o`000?oooooooooo01?ooooo000Eooooo`03o`000?oooooooooo00oooooo0ol0
000@ooooo`;o00000_oo00001Ol0003oo`00o`000?oo003o000000?oo`000ol00002ool00003o`00
0?oo003oo`0000?o00000_oo00000ol0003oo`00ool00002o`0000?oo`000ol00002ool00003o`00
0?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000Go0000ool00?l0003o
o`00o`000003ool000?o000000Coo`00o`000?oo003oo`001?l000001?oo003o0000ool00?oo0003
o`0000;oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003
o`0000;oo`0000?o0000ool00?l000000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000
ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00o`000002
ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000
ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003
o`0000;oo`0000?o0000ool00?l000001_l00002ool00003o`000?oo003oo`0000Oo00000_oo0000
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo000Eooooo`03o`000?oooooooooo
00cooooo0ol0000Dooooo`03o`000?oo003oo`0000;o00000ooo00000ol0003oo`00o`000002ool0
0003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000Go0000ool0
0?l0003oo`00o`000003ool000?o00000_oo00000ol0003oo`00ool00003o`000004ool00?l0003o
o`00ool000?o00000ooo0003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00
ool00003o`0000;oo`0000?o0000ool00?l000000_oo00000ol0003oo`00ool00003o`0000;oo`00
00?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000;o00000ooo0003o`0000;oo`00
00?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00
ool00002o`0000;oo`001?l000001?oo003o0000ool00?oo0004o`000004ool00?l0003oo`00ool0
00Co000000Coo`00o`000?oo003oo`001?l000001?oo003o0000ool00?oo0004o`000004ool00?l0
003oo`00ool000Ko00000_oo0007o`0000;oo`0000?o0000ool00?oo00001_l00006ooooo`03o`00
0?oooooooooo01?ooooo000Eooooo`;o00002_ooool3o`0001Sooooo0_l00002ool00003o`000?oo
003oo`0000;o00000ooo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo
003oo`0000;o00000ooo00001Ol0003oo`00o`000?oo003o000000;oo`001?l000001?oo003o0000
ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000_l00003ool000?o00000_oo00000ol0003o
o`00ool00003o`0000;oo`0000?o0000ool00?oo00000_l00003ool000?o00000_oo00000ol0003o
o`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003o000000;o
o`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003o
o`00ool00003o`000004ool00?l0003o0000o`0000;oo`0000?o0000ool00?oo00000ol00002ool0
0003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool0
0?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00o`000003o`00
00;oo`0000?o0000ool00?oo00001ol000001?oo003o0000ool00?oo0003o`0000Gooooo00?o0000
ooooooooool04oooool001Gooooo00?o0000ooooooooool01_ooool3o`0001cooooo00?o0000ool0
0?oo00000ol00002ool00003o`000?oo003o000000;oo`0000?o0000ool00?oo00000ol00002ool0
0003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00002o`0000;oo`000ol00002ool0
0003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool0
0?l000000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool0
0005o`000?oo003o0000ool00?l000000ooo0003o`0000;oo`0000?o0000ool00?oo00000ol00002
ool00003o`000?oo003oo`0000;o00000ooo0003o`000004ool00?l0003oo`00ool000Co000000Co
o`00o`000?oo003oo`001?l000001?oo003o0000ool00?l00002ool00003o`000?oo003oo`0000?o
00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003
o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo
00001?l000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00001_l00002ool0
0003o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool001Gooooo00?o0000oooooooo
ool00oooool3o`00023ooooo0_l00002ool00003o`000?oo003oo`0000;o00000ooo0003o`0000;o
o`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o000000Koo`00o`000?oo
003o0000ool00?l00003ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000
ool00?oo00000_l00003ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000
ool00?oo00000_l00003ool00003o`000?oo003o000000;oo`0000?o0000ool00?oo00000ol00002
ool00003o`000?oo003oo`0000?o00000_oo00001Ol0003oo`00o`000?oo003o000000;oo`000ol0
0002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00002o`0000?oo`000ol0
0002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`000004ool00?l0
003oo`00ool000Co000000Coo`00o`000?oo003oo`001?l000000ooo003o0000o`000005o`000003
ool00?l0003o000000Go000000?oo`00o`000?l000001Ol000001?oo003o0000ool00?oo0006o`00
00Gooooo00?o0000ooooooooool04_ooool001Cooooo00Co0000oooooooooooooooo0ol0000Toooo
o`03o`000?oo003oo`0000?o00000_oo00001Ol0003oo`00o`000?oo003o000000?oo`000ol00002
ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`000_l00003ool00003o`000?oo
003o000000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo
00001Ol0003oo`00o`000?oo003o000000?oo`000ol00002ool00003o`000?oo003oo`0000?o0000
0_oo00000ol0003oo`00ool00002o`0000?oo`000ol000001?oo003o0000ool00?oo0004o`000004
ool00?l0003oo`00ool000?o00000_oo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool0
0003o`000?oo003oo`0000?o00000_oo00001Ol0003oo`00o`000?oo003o000000;oo`001?l00000
1?oo003o0000ool00?oo0004o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00
ool00003o`0000;oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00
o`000003o`000004ool00?l0003oo`00ool000Oo00000_oo00000ol0003oo`00ool00002o`0000Co
oooo00?o0000ooooooooool04_ooool001Cooooo1?l0000Xooooo`;o00000_oo00000ol0003oo`00
ool00002o`0000?oo`0000?o0000ool00?l000000_oo00000ol0003oo`00ool00003o`000004ool0
0?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00002o`0000?oo`000ol00002ool00003
o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00002o`0000?oo`0000?o0000ool00?l0
00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00005
o`000?oo003o0000ool00?l000000_oo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool0
0003o`000?oo003o000000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`00
00?o00000_oo00000ol0003oo`00ool00002o`0000;oo`000ol00002ool00003o`000?oo003oo`00
00?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool0
00?o000000Coo`00o`000?oo003oo`001?l000001?oo003o0000ool00?oo0004o`000004ool00?l0
003oo`00ool000?o00000_oo00000ol0003oo`00ool00007o`000003ool00?l0003ooooo00?ooooo
00?o0000ooooooooool04_ooool000Go00000oooool2o`0000Cooooo0_l00004ooooo`;o0000:ooo
ool00ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool000?o000000Co
o`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00
o`000002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`00
00?o0000ool00?oo00000_l00003ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`00
00?o0000ool00?oo00000_l00002ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`00
00?o0000ool00?oo00000_l00003ool000?o00000_oo00000ol0003oo`00ool00003o`000004ool0
0?l0003oo`00ool000Co000000Coo`00o`000?oo003o00000_oo00000ol0003oo`00ool00003o`00
00;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o000000?oo`00o`00
0?l000000_l000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000ol00002
ool00003o`000?oo003o000000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000
ool00?oo00001_l00002ooooo`03o`000?oooooooooo01;ooooo00001Ooooooo0000oooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo02Wooooo0_l00002ool00003o`000?oo003oo`0000?o00000_oo0003o`0000;oo`00
00?o0000ool00?l000000_l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00
ool00002o`0000?oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00
ool00003o`0000;oo`0000?o0000ool00?l000000_oo00000ol0003oo`00ool00003o`000004ool0
0?l0003oo`00ool000Co000000Coo`00o`000?oo003o00000_oo00000ol0003oo`00ool00003o`00
00;oo`0000?o0000ool00?oo00000ol00002ool00005o`000?oo003o0000ool00?l000000_oo0004
o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00002o`0000?oo`000ol0
0002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`001?l000001?oo003o0000
o`000?l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;o
o`0000?o0000ool00?oo00001Ol00002ool000Co000000Coo`00o`000?oo003oo`001?l000001?oo
003o0000ool00?oo0003o`000003ooooool0003ooooo01?ooooo0002ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ool00?oo00000ol00002ool00003o`000?oo003o000000;oo`0000?o
0000ool00?oo00000_l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool0
0003o`0000;oo`0000?o0000ool00?l000000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o
0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000;o00000ooo0003o`000004ool00?l0
003oo`00ool000?o00000_oo00000ol0003oo`00ool00002o`0000?oo`000ol00002ool00003o`00
0?oo003oo`0000?o00000_oo00000ol0003oo`00ool00002o`0000;oo`000ol00002ool00003o`00
0?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000Go0000ool00?l0003o
o`00o`000002ool000Co000000Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003o0000
00;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o000000Coo`00o`00
0?oo003oo`001?l000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000ol0
0002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oooooo`00000Dooooo`000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Wooooo0_l00002ool00003o`000?oo003oo`0000;o0000
0ooo0003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00003o`0000;o
o`0000?o0000ool00?oo00000_l00003ool000?o00000_oo00000ol0003oo`00ool00003o`0000;o
o`0000?o0000ool00?oo00000ol00002ool00005o`000?oo003o0000ool00?l000000_oo0003o`00
00;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003o000000;oo`0000?o0000ool0
0?oo00000ol00002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003o00000_oo0000
0ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003o
o`0000;o00000_oo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003o
o`0000;o00000ooo0003o`000004ool00?l0003oo`00ool000Co000000Coo`00o`000?oo003oo`00
0ol00002ool00003o`000?oo003oo`0000_o000000?oo`00o`000?l000001Ol000000ooo003o0000
o`000005o`0001Cooooo00001Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00008ooooo`;o0000:_ooool00ol0003oo`00ool00003o`00
00;oo`0000?o0000ool00?l000000_oo00000ol0003oo`00o`000002o`0000;oo`0000?o0000ool0
0?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00o`000002ool0
0003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`000004ool00?l0003oo`00
ool000?o00000_oo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003o
o`0000;o00000ooo0003o`000004ool00?l0003oo`00ool000Co000000Coo`00o`000?oo003oo`00
0_l00003ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo0000
0ol000001?oo003o0000o`000?l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003o
o`00ool00003o`0000;oo`0000Go0000ool00?l0003oo`00o`000002ool000?o00000_oo00000ol0
003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol000000ooo003o0000o`000002o`00
0004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000
ool00?oo00000ol0000Cooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Xooooo`;o0000
0_oo00000ol0003oo`00ool00003o`0000;oo`000_l00002ool00003o`000?oo003oo`0000?o0000
0_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool000?o0000
0_oo00000ol0003oo`00ool00003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003o
o`00o`000002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;o
o`0000Go0000ool00?l0003oo`00o`000002ool000?o00000_oo00000ol0003oo`00ool00003o`00
00;oo`0000?o0000ool00?l000000_oo00000ol0003oo`00ool00003o`000004ool00?l0003oo`00
ool000Co000000Coo`00o`000?oo003o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o
0000ool00?oo00000ol000001?oo003o0000ool00?oo0003o`0000;oo`000ol00002ool00003o`00
0?oo003oo`0000?o000000Coo`00o`000?oo003oo`001?l000001?oo003o0000ool00?l00002ool0
0003o`000?oo003o000000?o00000_oo00000ol0003oo`00ool00003o`000004ool00?l0003oo`00
ool000Co000000?oo`00o`000?l000004oooool00004ooooool0003o0000o`0000Cooooo0_l00004
ooooo`;o00003?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo003oo`0000?o00000_oo0003
o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o
0000ool00?oo00000ol00002ool000?o00000_oo00000ol0003oo`00ool00003o`000004ool00?l0
003oo`00ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`000ol00002ool00003o`00
0?oo003oo`0000?o00000_oo00000ol0003oo`00ool00002o`0000;oo`000ol00002ool00003o`00
0?oo003oo`0000?o00000_oo00000ol0003oo`00ool00002o`0000?oo`000ol000001?oo003o0000
ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000_l00003ool000?o000000Coo`00o`000?oo
003oo`001?l000001?oo003o0000ool00?oo0003o`0000;oo`000ol00002ool00003o`000?oo003o
o`0000?o000000Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo
0003o`000004ool00?l0003oo`00ool000Co000000Coo`00o`000?oo003oo`000ol00002ool00003
o`000?oo003oo`0000;o00004oooool001gooooo00?o0000ooooooooool0:?ooool2o`0000;oo`00
0ol00002ool00003o`000?oo003o000000;o00000_oo00000ol0003oo`00ool00003o`0000;oo`00
00?o0000ool00?oo00000ol00002ool00003o`000?oo003o000000;oo`0000?o0000ool00?oo0000
0ol000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool000?o
00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol000001?oo003o
0000ool00?l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`00
00;oo`0000Go0000ool00?l0003oo`00o`000002ool000?o00000_oo00000ol0003oo`00ool00003
o`0000;oo`0000Go0000ool00?l0003oo`00o`000002ool000?o00000_oo00000ol0003oo`00ool0
0003o`0000;oo`0000Go0000ool00?l0003oo`00o`000002ool000Co000000Coo`00o`000?oo003o
o`000ol00002ool00003o`000?oo003oo`0000?o000000?oo`00o`000?l000000_l000000ooo003o
0000ool00004o`0000;oo`0000?o0000ool00?oo00000ol000001?oo003o0000ool00?oo0004o`00
0003ooooool0003ooooo01;ooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l00002ool00003
o`000?oo003oo`0000;o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo
00000ol00002ool00003o`000?oo003oo`0000?o00000_oo0003o`000004ool00?l0003oo`00ool0
00?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?l000000_oo00000ol0
003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol000001?oo003o0000ool00?oo0002
o`0000?oo`000ol00002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`000ol0
0002ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000_l0
0002ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000_l0
0002ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol0
00001?oo003o0000o`000?l00002ool00003o`000?oo003oo`0000Co000000Coo`00o`000?oo003o
o`000ol000001?oo003o0000ool00?oo0003o`0000Gooooo00?o0000ooooooooool04Oooool001oo
oooo0_l0000Zooooo`03o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`000ol00002ool0
0003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`000ol00002ool0
0003o`000?oo003o000000;o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool0
0?oo00000ol00002ool000?o000000Coo`00o`000?oo003oo`001?l000001?oo003o0000ool00?oo
0003o`0000;oo`0000?o0000ool00?l000000_oo00000ol0003oo`00ool00003o`000004ool00?l0
003oo`00ool000?o00000_oo00000ol0003oo`00o`000002ool00003o`000?oo003oo`0000?o0000
00Coo`00o`000?oo003oo`001?l000001?oo003o0000ool00?l00002ool00003o`000?oo003oo`00
00?o000000Coo`00o`000?oo003oo`001?l000001?oo003o0000ool00?l00002ool00003o`000?oo
003oo`0000?o000000Coo`00o`000?oo003oo`001?l000001?oo003o0000ool00?l00002ool00003
o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`001?l000001?oo003o0000ool00?oo0003
o`0000Sooooo00?o0000ooooooooool04Oooool0027ooooo00?o0000ooooooooool0:?ooool2o`00
00;oo`0000?o0000ool00?l000000_l00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0
003oo`00ool00003o`0000;oo`000ol00002ool00003o`000?oo003oo`0000;o00000_oo00000ol0
003oo`00ool00003o`0000;oo`0000?o0000ool00?oo00000ol00002ool000?o000000Coo`00o`00
0?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003
o`0000;oo`000ol000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000_l0
0003ool000?o000000Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000;o0000
0ooo0003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00003o`0000;o
o`000ol000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000_l00002ool0
00Co000000Coo`00o`000?oo003oo`001?l000001?oo003o0000ool00?oo0003o`0000_ooooo00?o
0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0:?ooool00ol0003oo`00ool00003
o`000004ool00?l0003oo`00ool000?o00000_oo0006o`0000;oo`000ol00002ool00003o`000?oo
003oo`0000?o000000Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o0000
0_oo0003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00003o`0000;o
o`0000?o0000ool00?oo00000ol00002ool000?o000000Coo`00o`000?oo003oo`000ol00002ool0
0003o`000?oo003oo`0000?o00000_oo00001Ol0003oo`00o`000?oo003o000000;oo`000ol00002
ool00003o`000?oo003oo`0000?o00000_oo00001Ol0003oo`00o`000?oo003o000000;oo`000ol0
0002ool00003o`000?oo003oo`0000?o00000_oo0003o`000004ool00?l0003oo`00ool000?o0000
0_oo00000ol0003oo`00ool00003o`000004ool00?l0003o0000o`0000;oo`0000?o0000ool00?oo
00000ol00002ool00003o`000?oo003o000000?o00003oooool00ol0003oooooooooo`0@ooooo`00
8oooool00ol0003oooooooooo`0Xooooo`;o00000_oo0005o`0000;oo`000ol00002ool00003o`00
0?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`000004ool00?l0003oo`00ool000?o
00000_oo00000ol0003oo`00ool00003o`0000;oo`000ol000001?oo003o0000ool00?oo0003o`00
00;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o00000_oo00001Ol0
003oo`00o`000?oo003o000000;oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo0000
0ol0003oo`00ool00002o`0000;oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo0000
0ol0003oo`00ool00002o`0000;oo`000ol00002ool00003o`000?oo003oo`0000?o000000?oo`00
o`000?oo00000_l000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000ol0
00001?oo003o0000ool00?l00002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003o
o`001Ol0000Aooooo`03o`000?oooooooooo013ooooo000Tooooo`;o0000:_ooool2o`000004ool0
0?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000ool00?oo
00000ol000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool0
00?o00000_oo00000ol0003oo`00o`000002o`0000;oo`0000?o0000ool00?oo00000ol00002ool0
0003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00002o`0000;oo`000ol00002ool0
0003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`000004ool00?l0003o0000
o`0000;oo`0000?o0000ool00?oo00000ol000001?oo003o0000ool00?oo0004o`000004ool00?l0
003o0000o`0000;oo`0000?o0000ool00?oo00000ol000001?oo003o0000ool00?oo0002o`0000?o
o`000ol000001?oo003o0000ool00?oo0004o`000004ool00?l0003oo`00ool000?o00000_oo0003
o`000004ool00?l0003oo`00ool000?o00001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo013ooooo000Vooooo`03o`000?oooooooooo02Sooooo00?o0000ool00?l000000_l00002
ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000
ool00?l000000_l00002ool000Ko00000_oo0003o`0000;oo`0000?o0000ool00?oo00000_l00002
ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o0000
ool00?oo00000ol000001?oo003o0000o`000?l00002ool00003o`000?oo003oo`0000?o000000Co
o`00o`000?oo003oo`001?l000001?oo003o0000ool00?l00002ool00003o`000?oo003oo`0000?o
000000Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003o000000;oo`0000?o0000ool0
0?oo00000ol000001?oo003o0000ool00?oo0003o`0000;oo`0000Go0000ool00?l0003oo`00o`00
0002ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`000ol000001?oo003o0000ool0
0?oo0003o`0000Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`009ooo
ool00ol0003oooooooooo`0Xooooo`;o000000?oo`00o`000?l000001?l00002ool000Ko00000_oo
0005o`0000;oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00ool0
0003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`00
00?o0000ool00?oo00000ol000001?oo003o0000o`000?l00002ool00003o`000?oo003oo`0000?o
000000Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo0003o`00
0004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00003o`0000;oo`000ol00000
1?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000_l00002ool000?o00000_oo
00000ol0003oo`00ool00003o`000003ool00?l0003oo`0000;o000000Coo`00o`000?oo003oo`00
0ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool002Sooooo00?o
0000ooooooooool0:Oooool2o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00
ool00003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00003o`0000;o
o`0000?o0000ool00?oo00000ol000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool0
0?oo00000ol00002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?l0003o00000_oo0000
0ol0003oo`00ool00003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool0
0003o`0000;oo`000ol000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo0000
0ol00002ool000?o000000Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o
000000Coo`00o`000?l0003o00000_oo00000ol0003oo`00ool00003o`000004ool00?l0003oo`00
ool000?o00000_oo0003o`00013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@
ooooo`00:Oooool2o`0002_ooooo1?l00002ool000Ko00000_oo0005o`0000;oo`0000?o0000ool0
0?oo00000ol00002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`000ol00002
ool000Ko00000_oo0006o`000004ool00?l0003o0000o`0000;oo`0000?o0000ool00?oo00000ol0
00001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000ol00002ool000?o0000
00Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o000000?oo`00o`000?oo
00000_l000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000ol000001?oo
003o0000ool00?l00002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`000ol0
0002ool000?o00004oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo000[
ooooo`03o`000?oooooooooo02Wooooo1Ol00002ool00003o`000?oo003oo`0000?o000000Coo`00
o`000?oo003oo`001_l00002ool000Ko000000?oo`00o`000?l000001?l00002ool000?o00000_oo
00000ol0003oo`00ool00003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00
ool00003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00003o`0000;o
o`000ol000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00000ol000001?oo
003o0000ool00?oo0003o`0000;oo`000ol000001?oo003o0000ool00?oo0004o`000004ool00?l0
003oo`00ool000?o00000_oo0003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003o
o`00o`00000Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool002cooooo
00?o0000ooooooooool0:_ooool8o`0000;oo`001Ol00002ool000Ko00000_oo00000ol0003oo`00
ool00002o`0000;oo`0000?o0000ool00?oo00000ol00002ool00003o`000?oo003oo`0000?o0000
00Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo
003oo`000ol00002ool00003o`000?oo003oo`0000?o00000_oo0003o`000004ool00?l0003oo`00
ool000?o00000_oo00000ol0003oo`00ool00003o`000004ool00?l0003oo`00ool000?o00000_oo
0003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00003o`000003ool0
0?l0003o000000;o000000Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000;o
00006Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo000]ooooo`03o`00
0?oooooooooo02_ooooo2?l000000ooo003o0000o`000004o`0000;oo`0000?o0000ool00?oo0000
1_l000000ooo003o0000o`000004o`0000;oo`001_l000000ooo003o0000o`000004o`0000;oo`00
00?o0000ool00?oo00000ol000000ooo003o0000o`000004o`0000;oo`001_l00002ool000?o0000
00Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo
003oo`000ol00002ool000?o000000Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003o
o`0000?o000000Coo`00o`000?l0003o00000_oo00000ol0003oo`00ool00003o`000004ool00?l0
003oo`00ool000Co00007?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo
000^ooooo`03o`000?oooooooooo02cooooo2?l000000ooo003o0000o`000007o`0000;oo`001Ol0
0002ool00003o`000?oo003oo`0000?o00000_oo00000ol0003oo`00o`000002o`0000;oo`0000?o
0000ool00?oo00001_l00002ool000;o00000_oo00000ol0003oo`00ool00003o`0000;oo`0000?o
0000ool00?oo00000ol000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo0000
0ol000001?oo003o0000ool00?oo0003o`0000;oo`000ol000001?oo003o0000ool00?oo0003o`00
00;oo`0000?o0000ool00?oo00000ol000001?oo003o0000ool00?l00002ool00003o`000?oo003o
o`0000?o000000Coo`00o`000?oo003oo`000ol0000Pooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03oooool002oooooo0_l0000^ooooo`Oo00000_oo0009o`000003ool00?l0003o
000000Oo00000_oo0005o`0000;oo`001_l00002ool00003o`000?oo003oo`0000?o000000Coo`00
o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`00
0ol00002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`000ol00002ool000?o
000000Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o000000Coo`00o`00
0?oo003oo`000ol00002ool000?o000000Coo`00o`000?oo003oo`000ol0000Tooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03oooool0037ooooo00?o0000ooooooooool0;OoooolA
o`0000;oo`002Ol000000ooo003o0000o`000004o`0000;oo`0000?o0000ool00?oo00001_l00000
0ooo003o0000o`000004o`0000;oo`001_l000000ooo003o0000o`000004o`0000;oo`001_l00000
0ooo003o0000o`000004o`0000;oo`000ol000001?oo003o0000ool00?oo0003o`0000;oo`0000?o
0000ool00?oo00000ol000001?oo003o0000ool00?oo0003o`0000;oo`000ol000001?oo003o0000
ool00?oo0003o`0002Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`00
<_ooool00ol0003oooooooooo`0`oooooaWo00000_oo00000ol0003oo`00ool00006o`000003ool0
0?l0003o000000Co00000_oo00000ol0003oo`00ool00003o`000004ool00?l0003oo`00ool000?o
00000_oo00000ol0003oo`00ool00003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0
003oo`00ool00003o`000004ool00?l0003oo`00ool000?o00000_oo00000ol0003oo`00ool00003
o`000004ool00?l0003oo`00ool000?o00000_oo0003o`000004ool00?l0003oo`00ool000?o0000
;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo000cooooo`03o`000?oo
oooooooo03Oooooo7Ol00002ool00003o`000?oo003oo`0000Ko000000?oo`00o`000?l000001?l0
0002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`000ol00002ool00003o`00
0?oo003oo`0000?o000000Coo`00o`000?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o
000000?oo`00o`000?l000001?l00002ool000?o000000Coo`00o`000?oo003oo`000ol0000_oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool003Cooooo0_l0000noooooa_o
00000_oo0005o`0000;oo`0000?o0000ool00?oo00001_l000000ooo003o0000o`000004o`0000;o
o`001_l000000ooo003o0000o`000004o`0000;oo`001_l000001?oo003o0000o`000?l00002ool0
0003o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`000ol0000cooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03_ooool003Kooooo00?o0000ooooooooool0@OoooolGo`00
0003ool00?l0003o000000Oo000000?oo`00o`000?l000001?l00002ool000Ko000000Coo`00o`00
0?oo003oo`000ol00002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`000ol0
0002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003oo`000ol0000gooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool03_ooool003Oooooo00?o0000ooooooooool0@Ooo
ool2o`0000Oooooo6?l00002ool000Ko000000Coo`00o`000?oo003oo`001_l00002ool000Ko0000
00?oo`00o`000?l000001?l00002ool00003o`000?oo003oo`0000?o000000Coo`00o`000?oo003o
o`000ol0000jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool003Sooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0<oooooaCo00000_oo0008o`0000;oo`00
1_l000001?oo003o0000ool00?oo0003o`0000;oo`0000?o0000ool00?oo00001_l000000ooo003o
0000o`000004o`0003kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`00
>Oooool2o`00043ooooo00?o0000ooooooooool04ooooolIo`000004ool00?l0003oo`00ool000Ko
00000_oo0006o`000004ool00?l0003oo`00ool000?o0000AOooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00kooooo000kooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool06OoooolGo`0000;oo`001_l000001?oo003o0000ool00?oo0006o`0004Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0>ooooo`00??ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo023ooooo7?l0001?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03Oooool003gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Yooooo`Oo0000
G?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo000nooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00gooooo000oooooo`;o0000>_ooool00ol0003oooooooooo`2>ooooo`05o`000?oooooo
ooooooooool000003oooool0047ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2>
ooooo`05o`000?ooooooooooooooool000003oooool004;ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`2?ooooo`04o`000?ooooooooooo`0000oooooo0013ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0T?ooool00ol0003oooooo`00000?ooooo`00A?ooool2o`00
03Gooooo00?o0000ooooooooool0T?ooool01?l0003oooooooooool0000>ooooo`00A_ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo097ooooo00?o0000ooooool000003_ooool004Oo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`;o00003_ooool004Sooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Booooo`?o00003_ooool004Wooooo0_l0
000_ooooo`03o`000?oooooooooo08kooooo1?l0000Aooooo`00Boooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo08[ooooo1?l0000Eooooo`00C?ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo08Oooooo0ol0000Iooooo`00COooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo08?ooooo1?l0000Looooo`00C_ooool2o`0002[ooooo00?o0000ooooooooool0
Ooooool4o`00023ooooo001@ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Nooo
ool4o`0002Cooooo001Aooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Moooool4
o`0002Sooooo001Booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool3o`00
02cooooo001Cooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L?ooool4o`0002oo
oooo001Dooooo`;o00009?ooool00ol0003oooooooooo`1/ooooo`Co0000<oooool005Kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1Xooooo`Co0000=oooool005Oooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1Tooooo`Co0000>oooool005Sooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1Qooooo`?o0000?oooool005Wooooo0_l0000Oooooo`03
o`000?oooooooooo05gooooo1?l00012ooooo`00Foooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo05Wooooo1?l00016ooooo`00G?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo05Gooooo1?l0001:ooooo`00GOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo057ooooo1?l0001>ooooo`00G_ooool2o`0001[ooooo00?o0000ooooooooool0C_ooool3o`00
05;ooooo001Pooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B_ooool4o`0005Go
oooo001Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`0005Wooooo
001Rooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool4o`0005gooooo001S
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool4o`00067ooooo001Toooo
o`;o00005?ooool00ol0003oooooooooo`0kooooo`?o0000IOooool006Kooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0gooooo`Co0000J?ooool006Oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0cooooo`Co0000K?ooool006Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0_ooooo`Co0000L?ooool006Wooooo0_l0000>ooooo`03o`000?oooooo
oooo02cooooo1?l0001dooooo`00Joooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Wooooo0ol0001hooooo`00K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Go
oooo1?l0001kooooo`00KOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo
1?l0001oooooo`00K_ooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`0008?ooooo001`
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool4o`0008Oooooo001aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool3o`0008_ooooo001booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`0008kooooo001cooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`0009;ooooo001dooooo`;o00000ooo
ool00ol0003oooooooooo`0:ooooo`Co0000U_ooool007Kooooo00Co0000oooooooooooo00002?oo
ool4o`0009[ooooo001gooooo`03o`000?oooooo000000Gooooo0ol0002Nooooo`00N?ooool2o`00
0003ooooool0003o000000;o0000XOooool007Wooooo0_l0002Uooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0790949, -0.00981192, \
0.00377261, 0.00377261}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -23.848 -9 ]
[.14598 .19958 .15205 0 ]
[.27013 .15073 -22.8472 -9 ]
[.27013 .15073 1.15281 0 ]
[.40046 .09948 -21.8464 -9 ]
[.40046 .09948 2.15358 0 ]
[.53743 .04564 -20.8457 -9 ]
[.53743 .04564 3.15434 0 ]
[.68156 -0.01098 -19.8449 -9 ]
[.68156 -0.01098 4.1551 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 30 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 30 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 30 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 30 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 30 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02456 .26232 -24 -2.73996 ]
[.02456 .26232 0 6.26004 ]
[.01424 .32699 -24 -2.79465 ]
[.01424 .32699 0 6.20535 ]
[.00348 .39443 -6 -2.85193 ]
[.00348 .39443 0 6.14807 ]
[-0.00775 .46484 -18 -2.91198 ]
[-0.00775 .46484 0 6.08802 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.01)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.02)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.03)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.04)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.05)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06033 .24606 m
.06319 .24877 L
s
.08372 .23691 m
.08655 .23964 L
s
.10732 .22766 m
.11013 .23042 L
s
.13115 .21833 m
.13394 .22111 L
s
.17948 .19941 m
.18222 .20223 L
s
.20399 .18981 m
.2067 .19266 L
s
.22873 .18012 m
.23142 .183 L
s
.25371 .17034 m
.25638 .17324 L
s
.3044 .15049 m
.30701 .15344 L
s
.33011 .14043 m
.3327 .14339 L
s
.35608 .13026 m
.35864 .13325 L
s
.3823 .11999 m
.38483 .12301 L
s
.43553 .09915 m
.43799 .10222 L
s
.46254 .08857 m
.46497 .09167 L
s
.48982 .07789 m
.49222 .08101 L
s
.51738 .0671 m
.51975 .07024 L
s
.57333 .04519 m
.57563 .04838 L
s
.60174 .03407 m
.60401 .03728 L
s
.63044 .02283 m
.63267 .02607 L
s
.65944 .01147 m
.66163 .01474 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-0.05)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(-0.04)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(-0.03)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(-0.02)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(-0.01)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70252 .02109 m
.69885 .02251 L
s
.71605 .04178 m
.71237 .04318 L
s
.72932 .06208 m
.72564 .06347 L
s
.74235 .08201 m
.73866 .08339 L
s
.7677 .12078 m
.764 .12213 L
s
.78003 .13965 m
.77633 .14098 L
s
.79214 .15817 m
.78843 .1595 L
s
.80404 .17637 m
.80033 .17768 L
s
.82721 .21182 m
.82349 .21311 L
s
.8385 .22909 m
.83478 .23037 L
s
.8496 .24606 m
.84587 .24733 L
s
.86051 .26275 m
.85677 .264 L
s
.88178 .29529 m
.87804 .29651 L
s
.89215 .31115 m
.88841 .31237 L
s
.90235 .32676 m
.89861 .32797 L
s
.91239 .34211 m
.90864 .34331 L
s
.93198 .37208 m
.92823 .37326 L
s
.94155 .38671 m
.93779 .38788 L
s
.95096 .40111 m
.9472 .40226 L
s
.96022 .41528 m
.95646 .41643 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03678 .25754 m
.04289 .25515 L
s
[(-200)] .02456 .26232 1 -0.39112 Mshowa
.02651 .32234 m
.03265 .32001 L
s
[(-100)] .01424 .32699 1 -0.37897 Mshowa
.0158 .38992 m
.02196 .38766 L
s
[(0)] .00348 .39443 1 -0.36624 Mshowa
.00462 .46047 m
.01081 .45829 L
s
[(100)] -0.00775 .46484 1 -0.35289 Mshowa
.125 Mabswid
.03476 .27029 m
.03843 .26886 L
s
.03272 .28314 m
.0364 .28172 L
s
.03067 .29609 m
.03434 .29468 L
s
.0286 .30916 m
.03228 .30776 L
s
.0244 .33563 m
.02809 .33424 L
s
.02228 .34903 m
.02597 .34765 L
s
.02014 .36254 m
.02383 .36117 L
s
.01798 .37617 m
.02167 .37481 L
s
.0136 .40379 m
.0173 .40244 L
s
.01139 .41777 m
.01509 .41644 L
s
.00915 .43188 m
.01286 .43055 L
s
.0069 .44611 m
.0106 .4448 L
s
.00233 .47496 m
.00604 .47365 L
s
1e-05 .48957 m
.00373 .48828 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 1 0 r
.39124 .80577 .39787 .81114 .40894 .80824 .40234 .80285 Metetra
0 1 0 r
.40234 .80285 .40894 .80824 .42006 .80533 .41349 .79992 Metetra
0 1 0 r
.41349 .79992 .42006 .80533 .43123 .8024 .42468 .79698 Metetra
0 1 0 r
.42468 .79698 .43123 .8024 .44244 .79947 .43592 .79402 Metetra
0 1 0 r
.43592 .79402 .44244 .79947 .4537 .79652 .44741 .78167 Metetra
0 1 0 r
.44741 .78167 .4537 .79652 .46516 .78409 .45888 .76941 Metetra
0 1 0 r
.45888 .76941 .46516 .78409 .4766 .77184 .47034 .7578 Metetra
0 1 0 r
.47034 .7578 .4766 .77184 .48803 .76025 .48178 .74682 Metetra
0 1 0 r
.48178 .74682 .48803 .76025 .49945 .74928 .49321 .73644 Metetra
0 1 0 r
.49321 .73644 .49945 .74928 .51086 .73891 .50464 .72662 Metetra
0 1 0 r
.50464 .72662 .51086 .73891 .52227 .72912 .51607 .71735 Metetra
0 1 0 r
.51607 .71735 .52227 .72912 .53369 .71986 .52751 .70859 Metetra
0 1 0 r
.52751 .70859 .53369 .71986 .54512 .71113 .53896 .70032 Metetra
0 1 0 r
.53896 .70032 .54512 .71113 .55656 .70288 .55043 .69252 Metetra
0 1 0 r
.55043 .69252 .55656 .70288 .56802 .69511 .56193 .68517 Metetra
0 1 0 r
.56193 .68517 .56802 .69511 .57951 .68778 .57345 .67823 Metetra
0 1 0 r
.57345 .67823 .57951 .68778 .59103 .68087 .585 .67169 Metetra
0 1 0 r
.585 .67169 .59103 .68087 .60258 .67436 .59658 .66553 Metetra
0 1 0 r
.59658 .66553 .60258 .67436 .61417 .66822 .60821 .65973 Metetra
0 1 0 r
.60821 .65973 .61417 .66822 .62579 .66245 .61987 .65426 Metetra
0 1 0 r
.61987 .65426 .62579 .66245 .63746 .65701 .63158 .64911 Metetra
0 1 0 r
.63158 .64911 .63746 .65701 .64918 .65188 .64333 .64425 Metetra
0 1 0 r
.64333 .64425 .64918 .65188 .66094 .64706 .65514 .63967 Metetra
0 1 0 r
.65514 .63967 .66094 .64706 .67276 .6425 .667 .63535 Metetra
0 1 0 r
.667 .63535 .67276 .6425 .68463 .63821 .67891 .63127 Metetra
0 1 0 r
.67891 .63127 .68463 .63821 .69656 .63415 .69088 .6274 Metetra
0 1 0 r
.69088 .6274 .69656 .63415 .70854 .63032 .70291 .62374 Metetra
0 1 0 r
.70291 .62374 .70854 .63032 .72059 .62668 .715 .62026 Metetra
0 1 0 r
.715 .62026 .72059 .62668 .73269 .62322 .72715 .61694 Metetra
0 1 0 r
.72715 .61694 .73269 .62322 .74486 .61993 .73937 .61377 Metetra
0 1 0 r
.73937 .61377 .74486 .61993 .75709 .61678 .75164 .61072 Metetra
0 1 0 r
.75164 .61072 .75709 .61678 .76939 .61375 .76398 .60778 Metetra
0 1 0 r
.76398 .60778 .76939 .61375 .78175 .61083 .77639 .60493 Metetra
0 1 0 r
.77639 .60493 .78175 .61083 .79417 .608 .78886 .60215 Metetra
0 1 0 r
.78886 .60215 .79417 .608 .80666 .60523 .80139 .59942 Metetra
0 1 0 r
.80139 .59942 .80666 .60523 .81922 .60252 .81399 .59673 Metetra
0 1 0 r
.81399 .59673 .81922 .60252 .83183 .59983 .82665 .59404 Metetra
0 1 0 r
.82665 .59404 .83183 .59983 .84451 .59716 .83937 .59135 Metetra
0 1 0 r
.83937 .59135 .84451 .59716 .85726 .59447 .85216 .58863 Metetra
0 1 0 r
.85216 .58863 .85726 .59447 .87006 .59176 .865 .58587 Metetra
0 1 0 r
.865 .58587 .87006 .59176 .88292 .58899 .8779 .58304 Metetra
0 1 0 r
.8779 .58304 .88292 .58899 .89584 .58616 .89085 .58013 Metetra
0 1 0 r
.89085 .58013 .89584 .58616 .90881 .58324 .90386 .5771 Metetra
0 1 0 r
.90386 .5771 .90881 .58324 .92183 .5802 .91691 .57396 Metetra
0 1 0 r
.91691 .57396 .92183 .5802 .9349 .57704 .93002 .57066 Metetra
0 1 0 r
.93002 .57066 .9349 .57704 .94802 .57372 .94316 .56719 Metetra
0 1 0 r
.94316 .56719 .94802 .57372 .96117 .57023 .95634 .56354 Metetra
0 1 0 r
.95634 .56354 .96117 .57023 .97436 .56654 .96955 .55967 Metetra
0 1 0 r
.96955 .55967 .97436 .56654 .98758 .56264 .9828 .55556 Metetra
0 1 0 r
.38455 .80037 .39124 .80577 .40234 .80285 .39568 .79743 Metetra
0 1 0 r
.39568 .79743 .40234 .80285 .41349 .79992 .40686 .79447 Metetra
0 1 0 r
.40686 .79447 .41349 .79992 .42468 .79698 .41808 .79151 Metetra
0 1 0 r
.41808 .79151 .42468 .79698 .43592 .79402 .4296 .77918 Metetra
0 1 0 r
.4296 .77918 .43592 .79402 .44741 .78167 .4411 .76691 Metetra
0 1 0 r
.4411 .76691 .44741 .78167 .45888 .76941 .45258 .7553 Metetra
0 1 0 r
.45258 .7553 .45888 .76941 .47034 .7578 .46405 .7443 Metetra
0 1 0 r
.46405 .7443 .47034 .7578 .48178 .74682 .4755 .73391 Metetra
0 1 0 r
.4755 .73391 .48178 .74682 .49321 .73644 .48694 .72407 Metetra
0 1 0 r
.48694 .72407 .49321 .73644 .50464 .72662 .49839 .71478 Metetra
0 1 0 r
.49839 .71478 .50464 .72662 .51607 .71735 .50984 .70601 Metetra
0 1 0 r
.50984 .70601 .51607 .71735 .52751 .70859 .5213 .69772 Metetra
0 1 0 r
.5213 .69772 .52751 .70859 .53896 .70032 .53278 .6899 Metetra
0 1 0 r
.53278 .6899 .53896 .70032 .55043 .69252 .54428 .68252 Metetra
0 1 0 r
.54428 .68252 .55043 .69252 .56193 .68517 .5558 .67556 Metetra
0 1 0 r
.5558 .67556 .56193 .68517 .57345 .67823 .56735 .66899 Metetra
0 1 0 r
.56735 .66899 .57345 .67823 .585 .67169 .57893 .66281 Metetra
0 1 0 r
.57893 .66281 .585 .67169 .59658 .66553 .59055 .65698 Metetra
0 1 0 r
.59055 .65698 .59658 .66553 .60821 .65973 .60221 .65149 Metetra
0 1 0 r
.60221 .65149 .60821 .65973 .61987 .65426 .61391 .64631 Metetra
0 1 0 r
.61391 .64631 .61987 .65426 .63158 .64911 .62566 .64143 Metetra
0 1 0 r
.62566 .64143 .63158 .64911 .64333 .64425 .63746 .63682 Metetra
0 1 0 r
.63746 .63682 .64333 .64425 .65514 .63967 .64931 .63247 Metetra
0 1 0 r
.64931 .63247 .65514 .63967 .667 .63535 .66121 .62837 Metetra
0 1 0 r
.66121 .62837 .667 .63535 .67891 .63127 .67316 .62448 Metetra
0 1 0 r
.67316 .62448 .67891 .63127 .69088 .6274 .68518 .62079 Metetra
0 1 0 r
.68518 .62079 .69088 .6274 .70291 .62374 .69725 .61728 Metetra
0 1 0 r
.69725 .61728 .70291 .62374 .715 .62026 .70938 .61394 Metetra
0 1 0 r
.70938 .61394 .715 .62026 .72715 .61694 .72158 .61075 Metetra
0 1 0 r
.72158 .61075 .72715 .61694 .73937 .61377 .73384 .60768 Metetra
0 1 0 r
.73384 .60768 .73937 .61377 .75164 .61072 .74616 .60473 Metetra
0 1 0 r
.74616 .60473 .75164 .61072 .76398 .60778 .75854 .60186 Metetra
0 1 0 r
.75854 .60186 .76398 .60778 .77639 .60493 .77099 .59906 Metetra
0 1 0 r
.77099 .59906 .77639 .60493 .78886 .60215 .7835 .59632 Metetra
0 1 0 r
.7835 .59632 .78886 .60215 .80139 .59942 .79608 .59361 Metetra
0 1 0 r
.79608 .59361 .80139 .59942 .81399 .59673 .80872 .59092 Metetra
0 1 0 r
.80872 .59092 .81399 .59673 .82665 .59404 .82143 .58822 Metetra
0 1 0 r
.82143 .58822 .82665 .59404 .83937 .59135 .83419 .5855 Metetra
0 1 0 r
.83419 .5855 .83937 .59135 .85216 .58863 .84701 .58274 Metetra
0 1 0 r
.84701 .58274 .85216 .58863 .865 .58587 .85989 .57991 Metetra
0 1 0 r
.85989 .57991 .865 .58587 .8779 .58304 .87283 .57701 Metetra
0 1 0 r
.87283 .57701 .8779 .58304 .89085 .58013 .88582 .57399 Metetra
0 1 0 r
.88582 .57399 .89085 .58013 .90386 .5771 .89886 .57086 Metetra
0 1 0 r
.89886 .57086 .90386 .5771 .91691 .57396 .91195 .56758 Metetra
0 1 0 r
.91195 .56758 .91691 .57396 .93002 .57066 .92508 .56413 Metetra
0 1 0 r
.92508 .56413 .93002 .57066 .94316 .56719 .93825 .5605 Metetra
0 1 0 r
.93825 .5605 .94316 .56719 .95634 .56354 .95145 .55667 Metetra
0 1 0 r
.95145 .55667 .95634 .56354 .96955 .55967 .96469 .5526 Metetra
0 1 0 r
.96469 .5526 .96955 .55967 .9828 .55556 .97795 .54829 Metetra
0 1 0 r
.37782 .79493 .38455 .80037 .39568 .79743 .38897 .79196 Metetra
0 1 0 r
.38897 .79196 .39568 .79743 .40686 .79447 .40018 .78898 Metetra
0 1 0 r
.40018 .78898 .40686 .79447 .41808 .79151 .41173 .77662 Metetra
0 1 0 r
.41173 .77662 .41808 .79151 .4296 .77918 .42326 .76435 Metetra
0 1 0 r
.42326 .76435 .4296 .77918 .4411 .76691 .43477 .75273 Metetra
0 1 0 r
.43477 .75273 .4411 .76691 .45258 .7553 .44625 .74173 Metetra
0 1 0 r
.44625 .74173 .45258 .7553 .46405 .7443 .45772 .73132 Metetra
0 1 0 r
.45772 .73132 .46405 .7443 .4755 .73391 .46918 .72147 Metetra
0 1 0 r
.46918 .72147 .4755 .73391 .48694 .72407 .48064 .71217 Metetra
0 1 0 r
.48064 .71217 .48694 .72407 .49839 .71478 .49211 .70337 Metetra
0 1 0 r
.49211 .70337 .49839 .71478 .50984 .70601 .50358 .69507 Metetra
0 1 0 r
.50358 .69507 .50984 .70601 .5213 .69772 .51506 .68723 Metetra
0 1 0 r
.51506 .68723 .5213 .69772 .53278 .6899 .52657 .67983 Metetra
0 1 0 r
.52657 .67983 .53278 .6899 .54428 .68252 .53809 .67285 Metetra
0 1 0 r
.53809 .67285 .54428 .68252 .5558 .67556 .54964 .66627 Metetra
0 1 0 r
.54964 .66627 .5558 .67556 .56735 .66899 .56122 .66006 Metetra
0 1 0 r
.56122 .66006 .56735 .66899 .57893 .66281 .57284 .65421 Metetra
0 1 0 r
.57284 .65421 .57893 .66281 .59055 .65698 .58449 .64869 Metetra
0 1 0 r
.58449 .64869 .59055 .65698 .60221 .65149 .59619 .64349 Metetra
0 1 0 r
.59619 .64349 .60221 .65149 .61391 .64631 .60793 .63858 Metetra
0 1 0 r
.60793 .63858 .61391 .64631 .62566 .64143 .61971 .63395 Metetra
0 1 0 r
.61971 .63395 .62566 .64143 .63746 .63682 .63155 .62958 Metetra
0 1 0 r
.63155 .62958 .63746 .63682 .64931 .63247 .64344 .62545 Metetra
0 1 0 r
.64344 .62545 .64931 .63247 .66121 .62837 .65538 .62154 Metetra
0 1 0 r
.65538 .62154 .66121 .62837 .67316 .62448 .66738 .61783 Metetra
0 1 0 r
.66738 .61783 .67316 .62448 .68518 .62079 .67943 .6143 Metetra
0 1 0 r
.67943 .6143 .68518 .62079 .69725 .61728 .69155 .61094 Metetra
0 1 0 r
.69155 .61094 .69725 .61728 .70938 .61394 .70372 .60772 Metetra
0 1 0 r
.70372 .60772 .70938 .61394 .72158 .61075 .71596 .60464 Metetra
0 1 0 r
.71596 .60464 .72158 .61075 .73384 .60768 .72827 .60166 Metetra
0 1 0 r
.72827 .60166 .73384 .60768 .74616 .60473 .74063 .59878 Metetra
0 1 0 r
.74063 .59878 .74616 .60473 .75854 .60186 .75306 .59597 Metetra
0 1 0 r
.75306 .59597 .75854 .60186 .77099 .59906 .76555 .59321 Metetra
0 1 0 r
.76555 .59321 .77099 .59906 .7835 .59632 .77811 .5905 Metetra
0 1 0 r
.77811 .5905 .7835 .59632 .79608 .59361 .79073 .58779 Metetra
0 1 0 r
.79073 .58779 .79608 .59361 .80872 .59092 .80341 .58509 Metetra
0 1 0 r
.80341 .58509 .80872 .59092 .82143 .58822 .81616 .58237 Metetra
0 1 0 r
.81616 .58237 .82143 .58822 .83419 .5855 .82896 .5796 Metetra
0 1 0 r
.82896 .5796 .83419 .5855 .84701 .58274 .84182 .57678 Metetra
0 1 0 r
.84182 .57678 .84701 .58274 .85989 .57991 .85474 .57387 Metetra
0 1 0 r
.85474 .57387 .85989 .57991 .87283 .57701 .86771 .57087 Metetra
0 1 0 r
.86771 .57087 .87283 .57701 .88582 .57399 .88074 .56775 Metetra
0 1 0 r
.88074 .56775 .88582 .57399 .89886 .57086 .89381 .56448 Metetra
0 1 0 r
.89381 .56448 .89886 .57086 .91195 .56758 .90693 .56106 Metetra
0 1 0 r
.90693 .56106 .91195 .56758 .92508 .56413 .92009 .55746 Metetra
0 1 0 r
.92009 .55746 .92508 .56413 .93825 .5605 .93328 .55365 Metetra
0 1 0 r
.93328 .55365 .93825 .5605 .95145 .55667 .94651 .54961 Metetra
0 1 0 r
.94651 .54961 .95145 .55667 .96469 .5526 .95977 .54534 Metetra
0 1 0 r
.95977 .54534 .96469 .5526 .97795 .54829 .97305 .54079 Metetra
0 1 0 r
.37103 .78944 .37782 .79493 .38897 .79196 .38221 .78645 Metetra
0 1 0 r
.38221 .78645 .38897 .79196 .40018 .78898 .39379 .77399 Metetra
0 1 0 r
.39379 .77399 .40018 .78898 .41173 .77662 .40536 .76172 Metetra
0 1 0 r
.40536 .76172 .41173 .77662 .42326 .76435 .41689 .75009 Metetra
0 1 0 r
.41689 .75009 .42326 .76435 .43477 .75273 .42839 .73908 Metetra
0 1 0 r
.42839 .73908 .43477 .75273 .44625 .74173 .43988 .72867 Metetra
0 1 0 r
.43988 .72867 .44625 .74173 .45772 .73132 .45136 .71882 Metetra
0 1 0 r
.45136 .71882 .45772 .73132 .46918 .72147 .46284 .7095 Metetra
0 1 0 r
.46284 .7095 .46918 .72147 .48064 .71217 .47431 .70069 Metetra
0 1 0 r
.47431 .70069 .48064 .71217 .49211 .70337 .48579 .69238 Metetra
0 1 0 r
.48579 .69238 .49211 .70337 .50358 .69507 .49728 .68452 Metetra
0 1 0 r
.49728 .68452 .50358 .69507 .51506 .68723 .50879 .6771 Metetra
0 1 0 r
.50879 .6771 .51506 .68723 .52657 .67983 .52032 .67011 Metetra
0 1 0 r
.52032 .67011 .52657 .67983 .53809 .67285 .53187 .6635 Metetra
0 1 0 r
.53187 .6635 .53809 .67285 .54964 .66627 .54345 .65728 Metetra
0 1 0 r
.54345 .65728 .54964 .66627 .56122 .66006 .55506 .6514 Metetra
0 1 0 r
.55506 .6514 .56122 .66006 .57284 .65421 .56671 .64587 Metetra
0 1 0 r
.56671 .64587 .57284 .65421 .58449 .64869 .5784 .64064 Metetra
0 1 0 r
.5784 .64064 .58449 .64869 .59619 .64349 .59013 .63572 Metetra
0 1 0 r
.59013 .63572 .59619 .64349 .60793 .63858 .6019 .63107 Metetra
0 1 0 r
.6019 .63107 .60793 .63858 .61971 .63395 .61373 .62667 Metetra
0 1 0 r
.61373 .62667 .61971 .63395 .63155 .62958 .6256 .62252 Metetra
0 1 0 r
.6256 .62252 .63155 .62958 .64344 .62545 .63753 .61858 Metetra
0 1 0 r
.63753 .61858 .64344 .62545 .65538 .62154 .64951 .61485 Metetra
0 1 0 r
.64951 .61485 .65538 .62154 .66738 .61783 .66155 .6113 Metetra
0 1 0 r
.66155 .6113 .66738 .61783 .67943 .6143 .67365 .60792 Metetra
0 1 0 r
.67365 .60792 .67943 .6143 .69155 .61094 .68581 .60469 Metetra
0 1 0 r
.68581 .60469 .69155 .61094 .70372 .60772 .69803 .60158 Metetra
0 1 0 r
.69803 .60158 .70372 .60772 .71596 .60464 .71031 .59859 Metetra
0 1 0 r
.71031 .59859 .71596 .60464 .72827 .60166 .72266 .59569 Metetra
0 1 0 r
.72266 .59569 .72827 .60166 .74063 .59878 .73507 .59287 Metetra
0 1 0 r
.73507 .59287 .74063 .59878 .75306 .59597 .74754 .5901 Metetra
0 1 0 r
.74754 .5901 .75306 .59597 .76555 .59321 .76007 .58737 Metetra
0 1 0 r
.76007 .58737 .76555 .59321 .77811 .5905 .77267 .58466 Metetra
0 1 0 r
.77267 .58466 .77811 .5905 .79073 .58779 .78533 .58195 Metetra
0 1 0 r
.78533 .58195 .79073 .58779 .80341 .58509 .79806 .57922 Metetra
0 1 0 r
.79806 .57922 .80341 .58509 .81616 .58237 .81084 .57646 Metetra
0 1 0 r
.81084 .57646 .81616 .58237 .82896 .5796 .82369 .57363 Metetra
0 1 0 r
.82369 .57363 .82896 .5796 .84182 .57678 .83659 .57073 Metetra
0 1 0 r
.83659 .57073 .84182 .57678 .85474 .57387 .84954 .56774 Metetra
0 1 0 r
.84954 .56774 .85474 .57387 .86771 .57087 .86255 .56463 Metetra
0 1 0 r
.86255 .56463 .86771 .57087 .88074 .56775 .87561 .56138 Metetra
0 1 0 r
.87561 .56138 .88074 .56775 .89381 .56448 .88871 .55797 Metetra
0 1 0 r
.88871 .55797 .89381 .56448 .90693 .56106 .90186 .55439 Metetra
0 1 0 r
.90186 .55439 .90693 .56106 .92009 .55746 .91504 .5506 Metetra
0 1 0 r
.91504 .5506 .92009 .55746 .93328 .55365 .92826 .5466 Metetra
0 1 0 r
.92826 .5466 .93328 .55365 .94651 .54961 .94151 .54236 Metetra
0 1 0 r
.94151 .54236 .94651 .54961 .95977 .54534 .95479 .53786 Metetra
0 1 0 r
.95479 .53786 .95977 .54534 .97305 .54079 .96808 .53307 Metetra
0 1 0 r
.36419 .78392 .37103 .78944 .38221 .78645 .3758 .77128 Metetra
0 1 0 r
.3758 .77128 .38221 .78645 .39379 .77399 .38739 .75901 Metetra
0 1 0 r
.38739 .75901 .39379 .77399 .40536 .76172 .39895 .74739 Metetra
0 1 0 r
.39895 .74739 .40536 .76172 .41689 .75009 .41048 .73638 Metetra
0 1 0 r
.41048 .73638 .41689 .75009 .42839 .73908 .42199 .72596 Metetra
0 1 0 r
.42199 .72596 .42839 .73908 .43988 .72867 .43348 .7161 Metetra
0 1 0 r
.43348 .7161 .43988 .72867 .45136 .71882 .44497 .70678 Metetra
0 1 0 r
.44497 .70678 .45136 .71882 .46284 .7095 .45645 .69797 Metetra
0 1 0 r
.45645 .69797 .46284 .7095 .47431 .70069 .46794 .68964 Metetra
0 1 0 r
.46794 .68964 .47431 .70069 .48579 .69238 .47944 .68177 Metetra
0 1 0 r
.47944 .68177 .48579 .69238 .49728 .68452 .49095 .67434 Metetra
0 1 0 r
.49095 .67434 .49728 .68452 .50879 .6771 .50248 .66733 Metetra
0 1 0 r
.50248 .66733 .50879 .6771 .52032 .67011 .51403 .66071 Metetra
0 1 0 r
.51403 .66071 .52032 .67011 .53187 .6635 .52561 .65446 Metetra
0 1 0 r
.52561 .65446 .53187 .6635 .54345 .65728 .53722 .64857 Metetra
0 1 0 r
.53722 .64857 .54345 .65728 .55506 .6514 .54886 .64302 Metetra
0 1 0 r
.54886 .64302 .55506 .6514 .56671 .64587 .56054 .63778 Metetra
0 1 0 r
.56054 .63778 .56671 .64587 .5784 .64064 .57226 .63283 Metetra
0 1 0 r
.57226 .63283 .5784 .64064 .59013 .63572 .58403 .62816 Metetra
0 1 0 r
.58403 .62816 .59013 .63572 .6019 .63107 .59584 .62374 Metetra
0 1 0 r
.59584 .62374 .6019 .63107 .61373 .62667 .6077 .61957 Metetra
0 1 0 r
.6077 .61957 .61373 .62667 .6256 .62252 .61962 .61562 Metetra
0 1 0 r
.61962 .61562 .6256 .62252 .63753 .61858 .63158 .61186 Metetra
0 1 0 r
.63158 .61186 .63753 .61858 .64951 .61485 .64361 .6083 Metetra
0 1 0 r
.64361 .6083 .64951 .61485 .66155 .6113 .65569 .6049 Metetra
0 1 0 r
.65569 .6049 .66155 .6113 .67365 .60792 .66783 .60164 Metetra
0 1 0 r
.66783 .60164 .67365 .60792 .68581 .60469 .68003 .59852 Metetra
0 1 0 r
.68003 .59852 .68581 .60469 .69803 .60158 .69229 .59551 Metetra
0 1 0 r
.69229 .59551 .69803 .60158 .71031 .59859 .70462 .5926 Metetra
0 1 0 r
.70462 .5926 .71031 .59859 .72266 .59569 .71701 .58976 Metetra
0 1 0 r
.71701 .58976 .72266 .59569 .73507 .59287 .72946 .58698 Metetra
0 1 0 r
.72946 .58698 .73507 .59287 .74754 .5901 .74197 .58424 Metetra
0 1 0 r
.74197 .58424 .74754 .5901 .76007 .58737 .75455 .58152 Metetra
0 1 0 r
.75455 .58152 .76007 .58737 .77267 .58466 .76719 .5788 Metetra
0 1 0 r
.76719 .5788 .77267 .58466 .78533 .58195 .77989 .57607 Metetra
0 1 0 r
.77989 .57607 .78533 .58195 .79806 .57922 .79266 .5733 Metetra
0 1 0 r
.79266 .5733 .79806 .57922 .81084 .57646 .80548 .57048 Metetra
0 1 0 r
.80548 .57048 .81084 .57646 .82369 .57363 .81836 .56758 Metetra
0 1 0 r
.81836 .56758 .82369 .57363 .83659 .57073 .8313 .56459 Metetra
0 1 0 r
.8313 .56459 .83659 .57073 .84954 .56774 .84429 .56149 Metetra
0 1 0 r
.84429 .56149 .84954 .56774 .86255 .56463 .85733 .55825 Metetra
0 1 0 r
.85733 .55825 .86255 .56463 .87561 .56138 .87042 .55486 Metetra
0 1 0 r
.87042 .55486 .87561 .56138 .88871 .55797 .88355 .5513 Metetra
0 1 0 r
.88355 .5513 .88871 .55797 .90186 .55439 .89673 .54754 Metetra
0 1 0 r
.89673 .54754 .90186 .55439 .91504 .5506 .90994 .54357 Metetra
0 1 0 r
.90994 .54357 .91504 .5506 .92826 .5466 .92318 .53936 Metetra
0 1 0 r
.92318 .53936 .92826 .5466 .94151 .54236 .93645 .53489 Metetra
0 1 0 r
.93645 .53489 .94151 .54236 .95479 .53786 .94975 .53015 Metetra
0 1 0 r
.94975 .53015 .95479 .53786 .96808 .53307 .96305 .5251 Metetra
0 1 0 r
.35775 .7685 .36419 .78392 .3758 .77128 .36937 .75624 Metetra
0 1 0 r
.36937 .75624 .3758 .77128 .38739 .75901 .38095 .74462 Metetra
0 1 0 r
.38095 .74462 .38739 .75901 .39895 .74739 .3925 .73362 Metetra
0 1 0 r
.3925 .73362 .39895 .74739 .41048 .73638 .40403 .7232 Metetra
0 1 0 r
.40403 .7232 .41048 .73638 .42199 .72596 .41554 .71334 Metetra
0 1 0 r
.41554 .71334 .42199 .72596 .43348 .7161 .42704 .70401 Metetra
0 1 0 r
.42704 .70401 .43348 .7161 .44497 .70678 .43853 .69519 Metetra
0 1 0 r
.43853 .69519 .44497 .70678 .45645 .69797 .45003 .68685 Metetra
0 1 0 r
.45003 .68685 .45645 .69797 .46794 .68964 .46154 .67897 Metetra
0 1 0 r
.46154 .67897 .46794 .68964 .47944 .68177 .47305 .67153 Metetra
0 1 0 r
.47305 .67153 .47944 .68177 .49095 .67434 .48458 .66451 Metetra
0 1 0 r
.48458 .66451 .49095 .67434 .50248 .66733 .49613 .65788 Metetra
0 1 0 r
.49613 .65788 .50248 .66733 .51403 .66071 .50771 .65162 Metetra
0 1 0 r
.50771 .65162 .51403 .66071 .52561 .65446 .51932 .64571 Metetra
0 1 0 r
.51932 .64571 .52561 .65446 .53722 .64857 .53095 .64014 Metetra
0 1 0 r
.53095 .64014 .53722 .64857 .54886 .64302 .54263 .63488 Metetra
0 1 0 r
.54263 .63488 .54886 .64302 .56054 .63778 .55434 .62992 Metetra
0 1 0 r
.55434 .62992 .56054 .63778 .57226 .63283 .56609 .62523 Metetra
0 1 0 r
.56609 .62523 .57226 .63283 .58403 .62816 .57789 .6208 Metetra
0 1 0 r
.57789 .6208 .58403 .62816 .59584 .62374 .58974 .61661 Metetra
0 1 0 r
.58974 .61661 .59584 .62374 .6077 .61957 .60164 .61263 Metetra
0 1 0 r
.60164 .61263 .6077 .61957 .61962 .61562 .61359 .60886 Metetra
0 1 0 r
.61359 .60886 .61962 .61562 .63158 .61186 .6256 .60528 Metetra
0 1 0 r
.6256 .60528 .63158 .61186 .64361 .6083 .63766 .60186 Metetra
0 1 0 r
.63766 .60186 .64361 .6083 .65569 .6049 .64978 .59859 Metetra
0 1 0 r
.64978 .59859 .65569 .6049 .66783 .60164 .66197 .59545 Metetra
0 1 0 r
.66197 .59545 .66783 .60164 .68003 .59852 .67421 .59243 Metetra
0 1 0 r
.67421 .59243 .68003 .59852 .69229 .59551 .68651 .5895 Metetra
0 1 0 r
.68651 .5895 .69229 .59551 .70462 .5926 .69888 .58665 Metetra
0 1 0 r
.69888 .58665 .70462 .5926 .71701 .58976 .71131 .58386 Metetra
0 1 0 r
.71131 .58386 .71701 .58976 .72946 .58698 .7238 .58111 Metetra
0 1 0 r
.7238 .58111 .72946 .58698 .74197 .58424 .73636 .57838 Metetra
0 1 0 r
.73636 .57838 .74197 .58424 .75455 .58152 .74898 .57565 Metetra
0 1 0 r
.74898 .57565 .75455 .58152 .76719 .5788 .76166 .57292 Metetra
0 1 0 r
.76166 .57292 .76719 .5788 .77989 .57607 .77441 .57014 Metetra
0 1 0 r
.77441 .57014 .77989 .57607 .79266 .5733 .78721 .56732 Metetra
0 1 0 r
.78721 .56732 .79266 .5733 .80548 .57048 .80007 .56443 Metetra
0 1 0 r
.80007 .56443 .80548 .57048 .81836 .56758 .81299 .56144 Metetra
0 1 0 r
.81299 .56144 .81836 .56758 .8313 .56459 .82596 .55835 Metetra
0 1 0 r
.82596 .55835 .8313 .56459 .84429 .56149 .83899 .55512 Metetra
0 1 0 r
.83899 .55512 .84429 .56149 .85733 .55825 .85206 .55174 Metetra
0 1 0 r
.85206 .55174 .85733 .55825 .87042 .55486 .86518 .5482 Metetra
0 1 0 r
.86518 .5482 .87042 .55486 .88355 .5513 .87834 .54446 Metetra
0 1 0 r
.87834 .54446 .88355 .5513 .89673 .54754 .89154 .54051 Metetra
0 1 0 r
.89154 .54051 .89673 .54754 .90994 .54357 .90478 .53633 Metetra
0 1 0 r
.90478 .53633 .90994 .54357 .92318 .53936 .91804 .5319 Metetra
0 1 0 r
.91804 .5319 .92318 .53936 .93645 .53489 .93133 .52719 Metetra
0 1 0 r
.93133 .52719 .93645 .53489 .94975 .53015 .94464 .52219 Metetra
0 1 0 r
.94464 .52219 .94975 .53015 .96305 .5251 .95796 .51687 Metetra
0 1 0 r
.35128 .7534 .35775 .7685 .36937 .75624 .36289 .74179 Metetra
0 1 0 r
.36289 .74179 .36937 .75624 .38095 .74462 .37446 .73079 Metetra
0 1 0 r
.37446 .73079 .38095 .74462 .3925 .73362 .386 .72037 Metetra
0 1 0 r
.386 .72037 .3925 .73362 .40403 .7232 .39753 .71051 Metetra
0 1 0 r
.39753 .71051 .40403 .7232 .41554 .71334 .40905 .70119 Metetra
0 1 0 r
.40905 .70119 .41554 .71334 .42704 .70401 .42055 .69236 Metetra
0 1 0 r
.42055 .69236 .42704 .70401 .43853 .69519 .43206 .68402 Metetra
0 1 0 r
.43206 .68402 .43853 .69519 .45003 .68685 .44357 .67614 Metetra
0 1 0 r
.44357 .67614 .45003 .68685 .46154 .67897 .45509 .66869 Metetra
0 1 0 r
.45509 .66869 .46154 .67897 .47305 .67153 .46662 .66165 Metetra
0 1 0 r
.46662 .66165 .47305 .67153 .48458 .66451 .47817 .65501 Metetra
0 1 0 r
.47817 .65501 .48458 .66451 .49613 .65788 .48975 .64874 Metetra
0 1 0 r
.48975 .64874 .49613 .65788 .50771 .65162 .50135 .64282 Metetra
0 1 0 r
.50135 .64282 .50771 .65162 .51932 .64571 .51298 .63724 Metetra
0 1 0 r
.51298 .63724 .51932 .64571 .53095 .64014 .52464 .63197 Metetra
0 1 0 r
.52464 .63197 .53095 .64014 .54263 .63488 .53635 .62699 Metetra
0 1 0 r
.53635 .62699 .54263 .63488 .55434 .62992 .54809 .62228 Metetra
0 1 0 r
.54809 .62228 .55434 .62992 .56609 .62523 .55988 .61783 Metetra
0 1 0 r
.55988 .61783 .56609 .62523 .57789 .6208 .57171 .61362 Metetra
0 1 0 r
.57171 .61362 .57789 .6208 .58974 .61661 .5836 .60964 Metetra
0 1 0 r
.5836 .60964 .58974 .61661 .60164 .61263 .59553 .60585 Metetra
0 1 0 r
.59553 .60585 .60164 .61263 .61359 .60886 .60752 .60225 Metetra
0 1 0 r
.60752 .60225 .61359 .60886 .6256 .60528 .61957 .59881 Metetra
0 1 0 r
.61957 .59881 .6256 .60528 .63766 .60186 .63167 .59553 Metetra
0 1 0 r
.63167 .59553 .63766 .60186 .64978 .59859 .64384 .59238 Metetra
0 1 0 r
.64384 .59238 .64978 .59859 .66197 .59545 .65606 .58934 Metetra
0 1 0 r
.65606 .58934 .66197 .59545 .67421 .59243 .66834 .58639 Metetra
0 1 0 r
.66834 .58639 .67421 .59243 .68651 .5895 .68069 .58353 Metetra
0 1 0 r
.68069 .58353 .68651 .5895 .69888 .58665 .6931 .58073 Metetra
0 1 0 r
.6931 .58073 .69888 .58665 .71131 .58386 .70557 .57796 Metetra
0 1 0 r
.70557 .57796 .71131 .58386 .7238 .58111 .71811 .57523 Metetra
0 1 0 r
.71811 .57523 .7238 .58111 .73636 .57838 .73071 .5725 Metetra
0 1 0 r
.73071 .5725 .73636 .57838 .74898 .57565 .74337 .56975 Metetra
0 1 0 r
.74337 .56975 .74898 .57565 .76166 .57292 .75609 .56698 Metetra
0 1 0 r
.75609 .56698 .76166 .57292 .77441 .57014 .76887 .56415 Metetra
0 1 0 r
.76887 .56415 .77441 .57014 .78721 .56732 .78171 .56126 Metetra
0 1 0 r
.78171 .56126 .78721 .56732 .80007 .56443 .79461 .55828 Metetra
0 1 0 r
.79461 .55828 .80007 .56443 .81299 .56144 .80757 .55519 Metetra
0 1 0 r
.80757 .55519 .81299 .56144 .82596 .55835 .82057 .55197 Metetra
0 1 0 r
.82057 .55197 .82596 .55835 .83899 .55512 .83363 .54861 Metetra
0 1 0 r
.83363 .54861 .83899 .55512 .85206 .55174 .84674 .54508 Metetra
0 1 0 r
.84674 .54508 .85206 .55174 .86518 .5482 .85989 .54136 Metetra
0 1 0 r
.85989 .54136 .86518 .5482 .87834 .54446 .87308 .53744 Metetra
0 1 0 r
.87308 .53744 .87834 .54446 .89154 .54051 .8863 .53328 Metetra
0 1 0 r
.8863 .53328 .89154 .54051 .90478 .53633 .89956 .52888 Metetra
0 1 0 r
.89956 .52888 .90478 .53633 .91804 .5319 .91284 .52421 Metetra
0 1 0 r
.91284 .52421 .91804 .5319 .93133 .52719 .92615 .51925 Metetra
0 1 0 r
.92615 .51925 .93133 .52719 .94464 .52219 .93947 .51397 Metetra
0 1 0 r
.93947 .51397 .94464 .52219 .95796 .51687 .9528 .50836 Metetra
0 1 0 r
.34477 .73889 .35128 .7534 .36289 .74179 .35636 .7279 Metetra
0 1 0 r
.35636 .7279 .36289 .74179 .37446 .73079 .36792 .71749 Metetra
0 1 0 r
.36792 .71749 .37446 .73079 .386 .72037 .37947 .70764 Metetra
0 1 0 r
.37947 .70764 .386 .72037 .39753 .71051 .39099 .69831 Metetra
0 1 0 r
.39099 .69831 .39753 .71051 .40905 .70119 .40251 .68949 Metetra
0 1 0 r
.40251 .68949 .40905 .70119 .42055 .69236 .41402 .68114 Metetra
0 1 0 r
.41402 .68114 .42055 .69236 .43206 .68402 .42554 .67326 Metetra
0 1 0 r
.42554 .67326 .43206 .68402 .44357 .67614 .43706 .6658 Metetra
0 1 0 r
.43706 .6658 .44357 .67614 .45509 .66869 .4486 .65876 Metetra
0 1 0 r
.4486 .65876 .45509 .66869 .46662 .66165 .46015 .65211 Metetra
0 1 0 r
.46015 .65211 .46662 .66165 .47817 .65501 .47172 .64583 Metetra
0 1 0 r
.47172 .64583 .47817 .65501 .48975 .64874 .48331 .63991 Metetra
0 1 0 r
.48331 .63991 .48975 .64874 .50135 .64282 .49494 .63431 Metetra
0 1 0 r
.49494 .63431 .50135 .64282 .51298 .63724 .5066 .62902 Metetra
0 1 0 r
.5066 .62902 .51298 .63724 .52464 .63197 .51829 .62403 Metetra
0 1 0 r
.51829 .62403 .52464 .63197 .53635 .62699 .53003 .61931 Metetra
0 1 0 r
.53003 .61931 .53635 .62699 .54809 .62228 .5418 .61485 Metetra
0 1 0 r
.5418 .61485 .54809 .62228 .55988 .61783 .55362 .61063 Metetra
0 1 0 r
.55362 .61063 .55988 .61783 .57171 .61362 .56549 .60662 Metetra
0 1 0 r
.56549 .60662 .57171 .61362 .5836 .60964 .57741 .60282 Metetra
0 1 0 r
.57741 .60282 .5836 .60964 .59553 .60585 .58939 .59921 Metetra
0 1 0 r
.58939 .59921 .59553 .60585 .60752 .60225 .60141 .59576 Metetra
0 1 0 r
.60141 .59576 .60752 .60225 .61957 .59881 .6135 .59246 Metetra
0 1 0 r
.6135 .59246 .61957 .59881 .63167 .59553 .62564 .58929 Metetra
0 1 0 r
.62564 .58929 .63167 .59553 .64384 .59238 .63784 .58624 Metetra
0 1 0 r
.63784 .58624 .64384 .59238 .65606 .58934 .65011 .58328 Metetra
0 1 0 r
.65011 .58328 .65606 .58934 .66834 .58639 .66243 .5804 Metetra
0 1 0 r
.66243 .5804 .66834 .58639 .68069 .58353 .67482 .57759 Metetra
0 1 0 r
.67482 .57759 .68069 .58353 .6931 .58073 .68727 .57482 Metetra
0 1 0 r
.68727 .57482 .6931 .58073 .70557 .57796 .69979 .57207 Metetra
0 1 0 r
.69979 .57207 .70557 .57796 .71811 .57523 .71236 .56933 Metetra
0 1 0 r
.71236 .56933 .71811 .57523 .73071 .5725 .725 .56658 Metetra
0 1 0 r
.725 .56658 .73071 .5725 .74337 .56975 .7377 .56381 Metetra
0 1 0 r
.7377 .56381 .74337 .56975 .75609 .56698 .75046 .56098 Metetra
0 1 0 r
.75046 .56098 .75609 .56698 .76887 .56415 .76328 .55809 Metetra
0 1 0 r
.76328 .55809 .76887 .56415 .78171 .56126 .77616 .55511 Metetra
0 1 0 r
.77616 .55511 .78171 .56126 .79461 .55828 .7891 .55202 Metetra
0 1 0 r
.7891 .55202 .79461 .55828 .80757 .55519 .80209 .54882 Metetra
0 1 0 r
.80209 .54882 .80757 .55519 .82057 .55197 .81513 .54546 Metetra
0 1 0 r
.81513 .54546 .82057 .55197 .83363 .54861 .82822 .54195 Metetra
0 1 0 r
.82822 .54195 .83363 .54861 .84674 .54508 .84136 .53825 Metetra
0 1 0 r
.84136 .53825 .84674 .54508 .85989 .54136 .85453 .53434 Metetra
0 1 0 r
.85453 .53434 .85989 .54136 .87308 .53744 .86775 .53021 Metetra
0 1 0 r
.86775 .53021 .87308 .53744 .8863 .53328 .881 .52584 Metetra
0 1 0 r
.881 .52584 .8863 .53328 .89956 .52888 .89428 .5212 Metetra
0 1 0 r
.89428 .5212 .89956 .52888 .91284 .52421 .90758 .51627 Metetra
0 1 0 r
.90758 .51627 .91284 .52421 .92615 .51925 .9209 .51104 Metetra
0 1 0 r
.9209 .51104 .92615 .51925 .93947 .51397 .93423 .50547 Metetra
0 1 0 r
.93423 .50547 .93947 .51397 .9528 .50836 .94757 .49956 Metetra
0 1 0 r
.3382 .72494 .34477 .73889 .35636 .7279 .34978 .71455 Metetra
0 1 0 r
.34978 .71455 .35636 .7279 .36792 .71749 .36134 .7047 Metetra
0 1 0 r
.36134 .7047 .36792 .71749 .37947 .70764 .37288 .69538 Metetra
0 1 0 r
.37288 .69538 .37947 .70764 .39099 .69831 .38441 .68656 Metetra
0 1 0 r
.38441 .68656 .39099 .69831 .40251 .68949 .39593 .67822 Metetra
0 1 0 r
.39593 .67822 .40251 .68949 .41402 .68114 .40745 .67033 Metetra
0 1 0 r
.40745 .67033 .41402 .68114 .42554 .67326 .41897 .66288 Metetra
0 1 0 r
.41897 .66288 .42554 .67326 .43706 .6658 .43051 .65583 Metetra
0 1 0 r
.43051 .65583 .43706 .6658 .4486 .65876 .44206 .64918 Metetra
0 1 0 r
.44206 .64918 .4486 .65876 .46015 .65211 .45363 .64289 Metetra
0 1 0 r
.45363 .64289 .46015 .65211 .47172 .64583 .46522 .63696 Metetra
0 1 0 r
.46522 .63696 .47172 .64583 .48331 .63991 .47684 .63135 Metetra
0 1 0 r
.47684 .63135 .48331 .63991 .49494 .63431 .48849 .62606 Metetra
0 1 0 r
.48849 .62606 .49494 .63431 .5066 .62902 .50017 .62105 Metetra
0 1 0 r
.50017 .62105 .5066 .62902 .51829 .62403 .5119 .61632 Metetra
0 1 0 r
.5119 .61632 .51829 .62403 .53003 .61931 .52366 .61185 Metetra
0 1 0 r
.52366 .61185 .53003 .61931 .5418 .61485 .53547 .60761 Metetra
0 1 0 r
.53547 .60761 .5418 .61485 .55362 .61063 .54732 .6036 Metetra
0 1 0 r
.54732 .6036 .55362 .61063 .56549 .60662 .55923 .59978 Metetra
0 1 0 r
.55923 .59978 .56549 .60662 .57741 .60282 .57118 .59615 Metetra
0 1 0 r
.57118 .59615 .57741 .60282 .58939 .59921 .58319 .59269 Metetra
0 1 0 r
.58319 .59269 .58939 .59921 .60141 .59576 .59526 .58938 Metetra
0 1 0 r
.59526 .58938 .60141 .59576 .6135 .59246 .60738 .5862 Metetra
0 1 0 r
.60738 .5862 .6135 .59246 .62564 .58929 .61956 .58313 Metetra
0 1 0 r
.61956 .58313 .62564 .58929 .63784 .58624 .63181 .58016 Metetra
0 1 0 r
.63181 .58016 .63784 .58624 .65011 .58328 .64411 .57727 Metetra
0 1 0 r
.64411 .57727 .65011 .58328 .66243 .5804 .65648 .57445 Metetra
0 1 0 r
.65648 .57445 .66243 .5804 .67482 .57759 .66891 .57167 Metetra
0 1 0 r
.66891 .57167 .67482 .57759 .68727 .57482 .6814 .56891 Metetra
0 1 0 r
.6814 .56891 .68727 .57482 .69979 .57207 .69395 .56617 Metetra
0 1 0 r
.69395 .56617 .69979 .57207 .71236 .56933 .70657 .56341 Metetra
0 1 0 r
.70657 .56341 .71236 .56933 .725 .56658 .71925 .56063 Metetra
0 1 0 r
.71925 .56063 .725 .56658 .7377 .56381 .73199 .5578 Metetra
0 1 0 r
.73199 .5578 .7377 .56381 .75046 .56098 .74479 .55491 Metetra
0 1 0 r
.74479 .55491 .75046 .56098 .76328 .55809 .75765 .55193 Metetra
0 1 0 r
.75765 .55193 .76328 .55809 .77616 .55511 .77056 .54885 Metetra
0 1 0 r
.77056 .54885 .77616 .55511 .7891 .55202 .78354 .54565 Metetra
0 1 0 r
.78354 .54565 .7891 .55202 .80209 .54882 .79656 .5423 Metetra
0 1 0 r
.79656 .5423 .80209 .54882 .81513 .54546 .80963 .5388 Metetra
0 1 0 r
.80963 .5388 .81513 .54546 .82822 .54195 .82275 .53511 Metetra
0 1 0 r
.82275 .53511 .82822 .54195 .84136 .53825 .83592 .53123 Metetra
0 1 0 r
.83592 .53123 .84136 .53825 .85453 .53434 .84912 .52712 Metetra
0 1 0 r
.84912 .52712 .85453 .53434 .86775 .53021 .86236 .52277 Metetra
0 1 0 r
.86236 .52277 .86775 .53021 .881 .52584 .87563 .51816 Metetra
0 1 0 r
.87563 .51816 .881 .52584 .89428 .5212 .88893 .51326 Metetra
0 1 0 r
.88893 .51326 .89428 .5212 .90758 .51627 .90225 .50807 Metetra
0 1 0 r
.90225 .50807 .90758 .51627 .9209 .51104 .91558 .50255 Metetra
0 1 0 r
.91558 .50255 .9209 .51104 .93423 .50547 .92892 .49668 Metetra
0 1 0 r
.92892 .49668 .93423 .50547 .94757 .49956 .94227 .49045 Metetra
0 1 0 r
.33158 .71154 .3382 .72494 .34978 .71455 .34315 .70171 Metetra
0 1 0 r
.34315 .70171 .34978 .71455 .36134 .7047 .3547 .6924 Metetra
0 1 0 r
.3547 .6924 .36134 .7047 .37288 .69538 .36624 .68358 Metetra
0 1 0 r
.36624 .68358 .37288 .69538 .38441 .68656 .37777 .67525 Metetra
0 1 0 r
.37777 .67525 .38441 .68656 .39593 .67822 .3893 .66736 Metetra
0 1 0 r
.3893 .66736 .39593 .67822 .40745 .67033 .40082 .65991 Metetra
0 1 0 r
.40082 .65991 .40745 .67033 .41897 .66288 .41236 .65286 Metetra
0 1 0 r
.41236 .65286 .41897 .66288 .43051 .65583 .42391 .64621 Metetra
0 1 0 r
.42391 .64621 .43051 .65583 .44206 .64918 .43547 .63992 Metetra
0 1 0 r
.43547 .63992 .44206 .64918 .45363 .64289 .44706 .63398 Metetra
0 1 0 r
.44706 .63398 .45363 .64289 .46522 .63696 .45867 .62837 Metetra
0 1 0 r
.45867 .62837 .46522 .63696 .47684 .63135 .47031 .62306 Metetra
0 1 0 r
.47031 .62306 .47684 .63135 .48849 .62606 .48199 .61805 Metetra
0 1 0 r
.48199 .61805 .48849 .62606 .50017 .62105 .4937 .61331 Metetra
0 1 0 r
.4937 .61331 .50017 .62105 .5119 .61632 .50545 .60883 Metetra
0 1 0 r
.50545 .60883 .5119 .61632 .52366 .61185 .51725 .60458 Metetra
0 1 0 r
.51725 .60458 .52366 .61185 .53547 .60761 .52909 .60055 Metetra
0 1 0 r
.52909 .60055 .53547 .60761 .54732 .6036 .54097 .59673 Metetra
0 1 0 r
.54097 .59673 .54732 .6036 .55923 .59978 .55291 .59309 Metetra
0 1 0 r
.55291 .59309 .55923 .59978 .57118 .59615 .5649 .58961 Metetra
0 1 0 r
.5649 .58961 .57118 .59615 .58319 .59269 .57695 .58629 Metetra
0 1 0 r
.57695 .58629 .58319 .59269 .59526 .58938 .58905 .58309 Metetra
0 1 0 r
.58905 .58309 .59526 .58938 .60738 .5862 .60122 .58002 Metetra
0 1 0 r
.60122 .58002 .60738 .5862 .61956 .58313 .61344 .57704 Metetra
0 1 0 r
.61344 .57704 .61956 .58313 .63181 .58016 .62572 .57414 Metetra
0 1 0 r
.62572 .57414 .63181 .58016 .64411 .57727 .63807 .5713 Metetra
0 1 0 r
.63807 .5713 .64411 .57727 .65648 .57445 .65047 .56851 Metetra
0 1 0 r
.65047 .56851 .65648 .57445 .66891 .57167 .66294 .56575 Metetra
0 1 0 r
.66294 .56575 .66891 .57167 .6814 .56891 .67547 .56299 Metetra
0 1 0 r
.67547 .56299 .6814 .56891 .69395 .56617 .68807 .56023 Metetra
0 1 0 r
.68807 .56023 .69395 .56617 .70657 .56341 .70073 .55745 Metetra
0 1 0 r
.70073 .55745 .70657 .56341 .71925 .56063 .71344 .55461 Metetra
0 1 0 r
.71344 .55461 .71925 .56063 .73199 .5578 .72622 .55172 Metetra
0 1 0 r
.72622 .55172 .73199 .5578 .74479 .55491 .73906 .54874 Metetra
0 1 0 r
.73906 .54874 .74479 .55491 .75765 .55193 .75196 .54566 Metetra
0 1 0 r
.75196 .54566 .75765 .55193 .77056 .54885 .76491 .54247 Metetra
0 1 0 r
.76491 .54247 .77056 .54885 .78354 .54565 .77792 .53913 Metetra
0 1 0 r
.77792 .53913 .78354 .54565 .79656 .5423 .79097 .53564 Metetra
0 1 0 r
.79097 .53564 .79656 .5423 .80963 .5388 .80408 .53196 Metetra
0 1 0 r
.80408 .53196 .80963 .5388 .82275 .53511 .81723 .52809 Metetra
0 1 0 r
.81723 .52809 .82275 .53511 .83592 .53123 .83042 .52401 Metetra
0 1 0 r
.83042 .52401 .83592 .53123 .84912 .52712 .84365 .51968 Metetra
0 1 0 r
.84365 .51968 .84912 .52712 .86236 .52277 .85691 .51509 Metetra
0 1 0 r
.85691 .51509 .86236 .52277 .87563 .51816 .8702 .51023 Metetra
0 1 0 r
.8702 .51023 .87563 .51816 .88893 .51326 .88352 .50507 Metetra
0 1 0 r
.88352 .50507 .88893 .51326 .90225 .50807 .89685 .49958 Metetra
0 1 0 r
.89685 .49958 .90225 .50807 .91558 .50255 .9102 .49376 Metetra
0 1 0 r
.9102 .49376 .91558 .50255 .92892 .49668 .92355 .48758 Metetra
0 1 0 r
.92355 .48758 .92892 .49668 .94227 .49045 .93689 .48101 Metetra
0 1 0 r
.32491 .69866 .33158 .71154 .34315 .70171 .33647 .68936 Metetra
0 1 0 r
.33647 .68936 .34315 .70171 .3547 .6924 .34802 .68056 Metetra
0 1 0 r
.34802 .68056 .3547 .6924 .36624 .68358 .35955 .67223 Metetra
0 1 0 r
.35955 .67223 .36624 .68358 .37777 .67525 .37108 .66435 Metetra
0 1 0 r
.37108 .66435 .37777 .67525 .3893 .66736 .38261 .6569 Metetra
0 1 0 r
.38261 .6569 .3893 .66736 .40082 .65991 .39415 .64986 Metetra
0 1 0 r
.39415 .64986 .40082 .65991 .41236 .65286 .40569 .6432 Metetra
0 1 0 r
.40569 .6432 .41236 .65286 .42391 .64621 .41726 .63691 Metetra
0 1 0 r
.41726 .63691 .42391 .64621 .43547 .63992 .42884 .63097 Metetra
0 1 0 r
.42884 .63097 .43547 .63992 .44706 .63398 .44044 .62535 Metetra
0 1 0 r
.44044 .62535 .44706 .63398 .45867 .62837 .45208 .62004 Metetra
0 1 0 r
.45208 .62004 .45867 .62837 .47031 .62306 .46374 .61503 Metetra
0 1 0 r
.46374 .61503 .47031 .62306 .48199 .61805 .47544 .61028 Metetra
0 1 0 r
.47544 .61028 .48199 .61805 .4937 .61331 .48718 .60579 Metetra
0 1 0 r
.48718 .60579 .4937 .61331 .50545 .60883 .49896 .60153 Metetra
0 1 0 r
.49896 .60153 .50545 .60883 .51725 .60458 .51078 .5975 Metetra
0 1 0 r
.51078 .5975 .51725 .60458 .52909 .60055 .52266 .59366 Metetra
0 1 0 r
.52266 .59366 .52909 .60055 .54097 .59673 .53458 .59001 Metetra
0 1 0 r
.53458 .59001 .54097 .59673 .55291 .59309 .54655 .58652 Metetra
0 1 0 r
.54655 .58652 .55291 .59309 .5649 .58961 .55858 .58319 Metetra
0 1 0 r
.55858 .58319 .5649 .58961 .57695 .58629 .57066 .57998 Metetra
0 1 0 r
.57066 .57998 .57695 .58629 .58905 .58309 .5828 .57689 Metetra
0 1 0 r
.5828 .57689 .58905 .58309 .60122 .58002 .595 .5739 Metetra
0 1 0 r
.595 .5739 .60122 .58002 .61344 .57704 .60726 .57099 Metetra
0 1 0 r
.60726 .57099 .61344 .57704 .62572 .57414 .61959 .56815 Metetra
0 1 0 r
.61959 .56815 .62572 .57414 .63807 .5713 .63197 .56535 Metetra
0 1 0 r
.63197 .56535 .63807 .5713 .65047 .56851 .64442 .56258 Metetra
0 1 0 r
.64442 .56258 .65047 .56851 .66294 .56575 .65693 .55982 Metetra
0 1 0 r
.65693 .55982 .66294 .56575 .67547 .56299 .6695 .55705 Metetra
0 1 0 r
.6695 .55705 .67547 .56299 .68807 .56023 .68213 .55426 Metetra
0 1 0 r
.68213 .55426 .68807 .56023 .70073 .55745 .69483 .55142 Metetra
0 1 0 r
.69483 .55142 .70073 .55745 .71344 .55461 .70759 .54853 Metetra
0 1 0 r
.70759 .54853 .71344 .55461 .72622 .55172 .72041 .54555 Metetra
0 1 0 r
.72041 .54555 .72622 .55172 .73906 .54874 .73328 .54247 Metetra
0 1 0 r
.73328 .54247 .73906 .54874 .75196 .54566 .74621 .53928 Metetra
0 1 0 r
.74621 .53928 .75196 .54566 .76491 .54247 .7592 .53595 Metetra
0 1 0 r
.7592 .53595 .76491 .54247 .77792 .53913 .77224 .53246 Metetra
0 1 0 r
.77224 .53246 .77792 .53913 .79097 .53564 .78533 .5288 Metetra
0 1 0 r
.78533 .5288 .79097 .53564 .80408 .53196 .79847 .52494 Metetra
0 1 0 r
.79847 .52494 .80408 .53196 .81723 .52809 .81165 .52087 Metetra
0 1 0 r
.81165 .52087 .81723 .52809 .83042 .52401 .82486 .51657 Metetra
0 1 0 r
.82486 .51657 .83042 .52401 .84365 .51968 .83812 .512 Metetra
0 1 0 r
.83812 .512 .84365 .51968 .85691 .51509 .8514 .50717 Metetra
0 1 0 r
.8514 .50717 .85691 .51509 .8702 .51023 .86471 .50204 Metetra
0 1 0 r
.86471 .50204 .8702 .51023 .88352 .50507 .87804 .49659 Metetra
0 1 0 r
.87804 .49659 .88352 .50507 .89685 .49958 .89139 .4908 Metetra
0 1 0 r
.89139 .4908 .89685 .49958 .9102 .49376 .90474 .48466 Metetra
0 1 0 r
.90474 .48466 .9102 .49376 .92355 .48758 .9181 .47814 Metetra
0 1 0 r
.9181 .47814 .92355 .48758 .93689 .48101 .93145 .47123 Metetra
0 1 0 r
.31818 .68627 .32491 .69866 .33647 .68936 .32973 .67748 Metetra
0 1 0 r
.32973 .67748 .33647 .68936 .34802 .68056 .34127 .66916 Metetra
0 1 0 r
.34127 .66916 .34802 .68056 .35955 .67223 .3528 .66129 Metetra
0 1 0 r
.3528 .66129 .35955 .67223 .37108 .66435 .36434 .65385 Metetra
0 1 0 r
.36434 .65385 .37108 .66435 .38261 .6569 .37587 .64681 Metetra
0 1 0 r
.37587 .64681 .38261 .6569 .39415 .64986 .38742 .64016 Metetra
0 1 0 r
.38742 .64016 .39415 .64986 .40569 .6432 .39898 .63387 Metetra
0 1 0 r
.39898 .63387 .40569 .6432 .41726 .63691 .41055 .62793 Metetra
0 1 0 r
.41055 .62793 .41726 .63691 .42884 .63097 .42215 .62231 Metetra
0 1 0 r
.42215 .62231 .42884 .63097 .44044 .62535 .43377 .617 Metetra
0 1 0 r
.43377 .617 .44044 .62535 .45208 .62004 .44543 .61198 Metetra
0 1 0 r
.44543 .61198 .45208 .62004 .46374 .61503 .45712 .60723 Metetra
0 1 0 r
.45712 .60723 .46374 .61503 .47544 .61028 .46884 .60273 Metetra
0 1 0 r
.46884 .60273 .47544 .61028 .48718 .60579 .48061 .59847 Metetra
0 1 0 r
.48061 .59847 .48718 .60579 .49896 .60153 .49242 .59442 Metetra
0 1 0 r
.49242 .59442 .49896 .60153 .51078 .5975 .50427 .59058 Metetra
0 1 0 r
.50427 .59058 .51078 .5975 .52266 .59366 .51617 .58692 Metetra
0 1 0 r
.51617 .58692 .52266 .59366 .53458 .59001 .52813 .58342 Metetra
0 1 0 r
.52813 .58342 .53458 .59001 .54655 .58652 .54014 .58008 Metetra
0 1 0 r
.54014 .58008 .54655 .58652 .55858 .58319 .5522 .57686 Metetra
0 1 0 r
.5522 .57686 .55858 .58319 .57066 .57998 .56432 .57377 Metetra
0 1 0 r
.56432 .57377 .57066 .57998 .5828 .57689 .5765 .57077 Metetra
0 1 0 r
.5765 .57077 .5828 .57689 .595 .5739 .58874 .56785 Metetra
0 1 0 r
.58874 .56785 .595 .5739 .60726 .57099 .60104 .56499 Metetra
0 1 0 r
.60104 .56499 .60726 .57099 .61959 .56815 .6134 .56218 Metetra
0 1 0 r
.6134 .56218 .61959 .56815 .63197 .56535 .62582 .5594 Metetra
0 1 0 r
.62582 .5594 .63197 .56535 .64442 .56258 .63831 .55664 Metetra
0 1 0 r
.63831 .55664 .64442 .56258 .65693 .55982 .65086 .55386 Metetra
0 1 0 r
.65086 .55386 .65693 .55982 .6695 .55705 .66347 .55107 Metetra
0 1 0 r
.66347 .55107 .6695 .55705 .68213 .55426 .67615 .54823 Metetra
0 1 0 r
.67615 .54823 .68213 .55426 .69483 .55142 .68888 .54533 Metetra
0 1 0 r
.68888 .54533 .69483 .55142 .70759 .54853 .70168 .54235 Metetra
0 1 0 r
.70168 .54235 .70759 .54853 .72041 .54555 .71453 .53927 Metetra
0 1 0 r
.71453 .53927 .72041 .54555 .73328 .54247 .72745 .53608 Metetra
0 1 0 r
.72745 .53608 .73328 .54247 .74621 .53928 .74042 .53276 Metetra
0 1 0 r
.74042 .53276 .74621 .53928 .7592 .53595 .75344 .52928 Metetra
0 1 0 r
.75344 .52928 .7592 .53595 .77224 .53246 .76651 .52562 Metetra
0 1 0 r
.76651 .52562 .77224 .53246 .78533 .5288 .77963 .52178 Metetra
0 1 0 r
.77963 .52178 .78533 .5288 .79847 .52494 .7928 .51772 Metetra
0 1 0 r
.7928 .51772 .79847 .52494 .81165 .52087 .806 .51343 Metetra
0 1 0 r
.806 .51343 .81165 .52087 .82486 .51657 .81925 .50889 Metetra
0 1 0 r
.81925 .50889 .82486 .51657 .83812 .512 .83252 .50408 Metetra
0 1 0 r
.83252 .50408 .83812 .512 .8514 .50717 .84583 .49897 Metetra
0 1 0 r
.84583 .49897 .8514 .50717 .86471 .50204 .85915 .49356 Metetra
0 1 0 r
.85915 .49356 .86471 .50204 .87804 .49659 .8725 .48781 Metetra
0 1 0 r
.8725 .48781 .87804 .49659 .89139 .4908 .88585 .4817 Metetra
0 1 0 r
.88585 .4817 .89139 .4908 .90474 .48466 .89922 .47523 Metetra
0 1 0 r
.89922 .47523 .90474 .48466 .9181 .47814 .91258 .46836 Metetra
0 1 0 r
.91258 .46836 .9181 .47814 .93145 .47123 .92593 .46108 Metetra
0 1 0 r
.31138 .67435 .31818 .68627 .32973 .67748 .32293 .66605 Metetra
0 1 0 r
.32293 .66605 .32973 .67748 .34127 .66916 .33447 .65819 Metetra
0 1 0 r
.33447 .65819 .34127 .66916 .3528 .66129 .346 .65076 Metetra
0 1 0 r
.346 .65076 .3528 .66129 .36434 .65385 .35754 .64373 Metetra
0 1 0 r
.35754 .64373 .36434 .65385 .37587 .64681 .36908 .63708 Metetra
0 1 0 r
.36908 .63708 .37587 .64681 .38742 .64016 .38063 .6308 Metetra
0 1 0 r
.38063 .6308 .38742 .64016 .39898 .63387 .3922 .62486 Metetra
0 1 0 r
.3922 .62486 .39898 .63387 .41055 .62793 .40379 .61924 Metetra
0 1 0 r
.40379 .61924 .41055 .62793 .42215 .62231 .41541 .61393 Metetra
0 1 0 r
.41541 .61393 .42215 .62231 .43377 .617 .42705 .60891 Metetra
0 1 0 r
.42705 .60891 .43377 .617 .44543 .61198 .43873 .60415 Metetra
0 1 0 r
.43873 .60415 .44543 .61198 .45712 .60723 .45044 .59965 Metetra
0 1 0 r
.45044 .59965 .45712 .60723 .46884 .60273 .46219 .59538 Metetra
0 1 0 r
.46219 .59538 .46884 .60273 .48061 .59847 .47398 .59133 Metetra
0 1 0 r
.47398 .59133 .48061 .59847 .49242 .59442 .48582 .58748 Metetra
0 1 0 r
.48582 .58748 .49242 .59442 .50427 .59058 .49771 .58381 Metetra
0 1 0 r
.49771 .58381 .50427 .59058 .51617 .58692 .50964 .58031 Metetra
0 1 0 r
.50964 .58031 .51617 .58692 .52813 .58342 .52163 .57696 Metetra
0 1 0 r
.52163 .57696 .52813 .58342 .54014 .58008 .53367 .57374 Metetra
0 1 0 r
.53367 .57374 .54014 .58008 .5522 .57686 .54577 .57063 Metetra
0 1 0 r
.54577 .57063 .5522 .57686 .56432 .57377 .55793 .56762 Metetra
0 1 0 r
.55793 .56762 .56432 .57377 .5765 .57077 .57015 .56469 Metetra
0 1 0 r
.57015 .56469 .5765 .57077 .58874 .56785 .58242 .56183 Metetra
0 1 0 r
.58242 .56183 .58874 .56785 .60104 .56499 .59476 .55901 Metetra
0 1 0 r
.59476 .55901 .60104 .56499 .6134 .56218 .60716 .55623 Metetra
0 1 0 r
.60716 .55623 .6134 .56218 .62582 .5594 .61963 .55345 Metetra
0 1 0 r
.61963 .55345 .62582 .5594 .63831 .55664 .63215 .55067 Metetra
0 1 0 r
.63215 .55067 .63831 .55664 .65086 .55386 .64474 .54787 Metetra
0 1 0 r
.64474 .54787 .65086 .55386 .66347 .55107 .65739 .54502 Metetra
0 1 0 r
.65739 .54502 .66347 .55107 .67615 .54823 .67011 .54212 Metetra
0 1 0 r
.67011 .54212 .67615 .54823 .68888 .54533 .68288 .53914 Metetra
0 1 0 r
.68288 .53914 .68888 .54533 .70168 .54235 .69572 .53607 Metetra
0 1 0 r
.69572 .53607 .70168 .54235 .71453 .53927 .70861 .53288 Metetra
0 1 0 r
.70861 .53288 .71453 .53927 .72745 .53608 .72156 .52955 Metetra
0 1 0 r
.72156 .52955 .72745 .53608 .74042 .53276 .73456 .52608 Metetra
0 1 0 r
.73456 .52608 .74042 .53276 .75344 .52928 .74762 .52243 Metetra
0 1 0 r
.74762 .52243 .75344 .52928 .76651 .52562 .76072 .5186 Metetra
0 1 0 r
.76072 .5186 .76651 .52562 .77963 .52178 .77387 .51455 Metetra
0 1 0 r
.77387 .51455 .77963 .52178 .7928 .51772 .78706 .51028 Metetra
0 1 0 r
.78706 .51028 .7928 .51772 .806 .51343 .8003 .50576 Metetra
0 1 0 r
.8003 .50576 .806 .51343 .81925 .50889 .81356 .50096 Metetra
0 1 0 r
.81356 .50096 .81925 .50889 .83252 .50408 .82686 .49588 Metetra
0 1 0 r
.82686 .49588 .83252 .50408 .84583 .49897 .84019 .49049 Metetra
0 1 0 r
.84019 .49049 .84583 .49897 .85915 .49356 .85353 .48477 Metetra
0 1 0 r
.85353 .48477 .85915 .49356 .8725 .48781 .86689 .4787 Metetra
0 1 0 r
.86689 .4787 .8725 .48781 .88585 .4817 .88025 .47227 Metetra
0 1 0 r
.88025 .47227 .88585 .4817 .89922 .47523 .89362 .46544 Metetra
0 1 0 r
.89362 .46544 .89922 .47523 .91258 .46836 .90698 .45821 Metetra
0 1 0 r
.90698 .45821 .91258 .46836 .92593 .46108 .92033 .45054 Metetra
0 1 0 r
.30453 .66289 .31138 .67435 .32293 .66605 .31607 .65504 Metetra
0 1 0 r
.31607 .65504 .32293 .66605 .33447 .65819 .3276 .64763 Metetra
0 1 0 r
.3276 .64763 .33447 .65819 .346 .65076 .33914 .64061 Metetra
0 1 0 r
.33914 .64061 .346 .65076 .35754 .64373 .35068 .63397 Metetra
0 1 0 r
.35068 .63397 .35754 .64373 .36908 .63708 .36222 .62769 Metetra
0 1 0 r
.36222 .62769 .36908 .63708 .38063 .6308 .37379 .62176 Metetra
0 1 0 r
.37379 .62176 .38063 .6308 .3922 .62486 .38537 .61614 Metetra
0 1 0 r
.38537 .61614 .3922 .62486 .40379 .61924 .39698 .61084 Metetra
0 1 0 r
.39698 .61084 .40379 .61924 .41541 .61393 .40861 .60581 Metetra
0 1 0 r
.40861 .60581 .41541 .61393 .42705 .60891 .42027 .60106 Metetra
0 1 0 r
.42027 .60106 .42705 .60891 .43873 .60415 .43197 .59656 Metetra
0 1 0 r
.43197 .59656 .43873 .60415 .45044 .59965 .44371 .59228 Metetra
0 1 0 r
.44371 .59228 .45044 .59965 .46219 .59538 .45548 .58823 Metetra
0 1 0 r
.45548 .58823 .46219 .59538 .47398 .59133 .4673 .58437 Metetra
0 1 0 r
.4673 .58437 .47398 .59133 .48582 .58748 .47917 .5807 Metetra
0 1 0 r
.47917 .5807 .48582 .58748 .49771 .58381 .49109 .57719 Metetra
0 1 0 r
.49109 .57719 .49771 .58381 .50964 .58031 .50306 .57383 Metetra
0 1 0 r
.50306 .57383 .50964 .58031 .52163 .57696 .51508 .5706 Metetra
0 1 0 r
.51508 .5706 .52163 .57696 .53367 .57374 .52716 .56749 Metetra
0 1 0 r
.52716 .56749 .53367 .57374 .54577 .57063 .53929 .56447 Metetra
0 1 0 r
.53929 .56447 .54577 .57063 .55793 .56762 .55149 .56154 Metetra
0 1 0 r
.55149 .56154 .55793 .56762 .57015 .56469 .56374 .55866 Metetra
0 1 0 r
.56374 .55866 .57015 .56469 .58242 .56183 .57605 .55584 Metetra
0 1 0 r
.57605 .55584 .58242 .56183 .59476 .55901 .58843 .55305 Metetra
0 1 0 r
.58843 .55305 .59476 .55901 .60716 .55623 .60087 .55026 Metetra
0 1 0 r
.60087 .55026 .60716 .55623 .61963 .55345 .61337 .54748 Metetra
0 1 0 r
.61337 .54748 .61963 .55345 .63215 .55067 .62594 .54467 Metetra
0 1 0 r
.62594 .54467 .63215 .55067 .64474 .54787 .63857 .54182 Metetra
0 1 0 r
.63857 .54182 .64474 .54787 .65739 .54502 .65126 .53891 Metetra
0 1 0 r
.65126 .53891 .65739 .54502 .67011 .54212 .66401 .53593 Metetra
0 1 0 r
.66401 .53593 .67011 .54212 .68288 .53914 .67682 .53285 Metetra
0 1 0 r
.67682 .53285 .68288 .53914 .69572 .53607 .6897 .52966 Metetra
0 1 0 r
.6897 .52966 .69572 .53607 .70861 .53288 .70262 .52634 Metetra
0 1 0 r
.70262 .52634 .70861 .53288 .72156 .52955 .71561 .52287 Metetra
0 1 0 r
.71561 .52287 .72156 .52955 .73456 .52608 .72865 .51923 Metetra
0 1 0 r
.72865 .51923 .73456 .52608 .74762 .52243 .74173 .5154 Metetra
0 1 0 r
.74173 .5154 .74762 .52243 .76072 .5186 .75487 .51137 Metetra
0 1 0 r
.75487 .51137 .76072 .5186 .77387 .51455 .76805 .50711 Metetra
0 1 0 r
.76805 .50711 .77387 .51455 .78706 .51028 .78127 .5026 Metetra
0 1 0 r
.78127 .5026 .78706 .51028 .8003 .50576 .79453 .49782 Metetra
0 1 0 r
.79453 .49782 .8003 .50576 .81356 .50096 .80782 .49276 Metetra
0 1 0 r
.80782 .49276 .81356 .50096 .82686 .49588 .82114 .4874 Metetra
0 1 0 r
.82114 .4874 .82686 .49588 .84019 .49049 .83448 .4817 Metetra
0 1 0 r
.83448 .4817 .84019 .49049 .85353 .48477 .84783 .47567 Metetra
0 1 0 r
.84783 .47567 .85353 .48477 .86689 .4787 .8612 .46926 Metetra
0 1 0 r
.8612 .46926 .86689 .4787 .88025 .47227 .87457 .46248 Metetra
0 1 0 r
.87457 .46248 .88025 .47227 .89362 .46544 .88795 .45528 Metetra
0 1 0 r
.88795 .45528 .89362 .46544 .90698 .45821 .90131 .44767 Metetra
0 1 0 r
.90131 .44767 .90698 .45821 .92033 .45054 .91465 .4396 Metetra
0 1 0 r
.29761 .65185 .30453 .66289 .31607 .65504 .30914 .64445 Metetra
0 1 0 r
.30914 .64445 .31607 .65504 .3276 .64763 .32068 .63745 Metetra
0 1 0 r
.32068 .63745 .3276 .64763 .33914 .64061 .33221 .63082 Metetra
0 1 0 r
.33221 .63082 .33914 .64061 .35068 .63397 .34375 .62455 Metetra
0 1 0 r
.34375 .62455 .35068 .63397 .36222 .62769 .35531 .61863 Metetra
0 1 0 r
.35531 .61863 .36222 .62769 .37379 .62176 .36688 .61302 Metetra
0 1 0 r
.36688 .61302 .37379 .62176 .38537 .61614 .37848 .60771 Metetra
0 1 0 r
.37848 .60771 .38537 .61614 .39698 .61084 .3901 .6027 Metetra
0 1 0 r
.3901 .6027 .39698 .61084 .40861 .60581 .40175 .59794 Metetra
0 1 0 r
.40175 .59794 .40861 .60581 .42027 .60106 .41343 .59344 Metetra
0 1 0 r
.41343 .59344 .42027 .60106 .43197 .59656 .42516 .58917 Metetra
0 1 0 r
.42516 .58917 .43197 .59656 .44371 .59228 .43692 .58511 Metetra
0 1 0 r
.43692 .58511 .44371 .59228 .45548 .58823 .44872 .58125 Metetra
0 1 0 r
.44872 .58125 .45548 .58823 .4673 .58437 .46057 .57757 Metetra
0 1 0 r
.46057 .57757 .4673 .58437 .47917 .5807 .47246 .57406 Metetra
0 1 0 r
.47246 .57406 .47917 .5807 .49109 .57719 .48441 .57069 Metetra
0 1 0 r
.48441 .57069 .49109 .57719 .50306 .57383 .49641 .56746 Metetra
0 1 0 r
.49641 .56746 .50306 .57383 .51508 .5706 .50847 .56434 Metetra
0 1 0 r
.50847 .56434 .51508 .5706 .52716 .56749 .52058 .56132 Metetra
0 1 0 r
.52058 .56132 .52716 .56749 .53929 .56447 .53275 .55837 Metetra
0 1 0 r
.53275 .55837 .53929 .56447 .55149 .56154 .54499 .55549 Metetra
0 1 0 r
.54499 .55549 .55149 .56154 .56374 .55866 .55728 .55266 Metetra
0 1 0 r
.55728 .55266 .56374 .55866 .57605 .55584 .56963 .54986 Metetra
0 1 0 r
.56963 .54986 .57605 .55584 .58843 .55305 .58205 .54707 Metetra
0 1 0 r
.58205 .54707 .58843 .55305 .60087 .55026 .59453 .54428 Metetra
0 1 0 r
.59453 .54428 .60087 .55026 .61337 .54748 .60707 .54146 Metetra
0 1 0 r
.60707 .54146 .61337 .54748 .62594 .54467 .61967 .53861 Metetra
0 1 0 r
.61967 .53861 .62594 .54467 .63857 .54182 .63234 .5357 Metetra
0 1 0 r
.63234 .5357 .63857 .54182 .65126 .53891 .64507 .53271 Metetra
0 1 0 r
.64507 .53271 .65126 .53891 .66401 .53593 .65786 .52963 Metetra
0 1 0 r
.65786 .52963 .66401 .53593 .67682 .53285 .67071 .52644 Metetra
0 1 0 r
.67071 .52644 .67682 .53285 .6897 .52966 .68362 .52312 Metetra
0 1 0 r
.68362 .52312 .6897 .52966 .70262 .52634 .69658 .51965 Metetra
0 1 0 r
.69658 .51965 .70262 .52634 .71561 .52287 .7096 .51602 Metetra
0 1 0 r
.7096 .51602 .71561 .52287 .72865 .51923 .72267 .51219 Metetra
0 1 0 r
.72267 .51219 .72865 .51923 .74173 .5154 .73579 .50817 Metetra
0 1 0 r
.73579 .50817 .74173 .5154 .75487 .51137 .74896 .50391 Metetra
0 1 0 r
.74896 .50391 .75487 .51137 .76805 .50711 .76217 .49942 Metetra
0 1 0 r
.76217 .49942 .76805 .50711 .78127 .5026 .77542 .49466 Metetra
0 1 0 r
.77542 .49466 .78127 .5026 .79453 .49782 .7887 .48962 Metetra
0 1 0 r
.7887 .48962 .79453 .49782 .80782 .49276 .80201 .48427 Metetra
0 1 0 r
.80201 .48427 .80782 .49276 .82114 .4874 .81534 .4786 Metetra
0 1 0 r
.81534 .4786 .82114 .4874 .83448 .4817 .8287 .47259 Metetra
0 1 0 r
.8287 .47259 .83448 .4817 .84783 .47567 .84207 .46622 Metetra
0 1 0 r
.84207 .46622 .84783 .47567 .8612 .46926 .85545 .45946 Metetra
0 1 0 r
.85545 .45946 .8612 .46926 .87457 .46248 .86883 .45231 Metetra
0 1 0 r
.86883 .45231 .87457 .46248 .88795 .45528 .8822 .44473 Metetra
0 1 0 r
.8822 .44473 .88795 .45528 .90131 .44767 .89556 .43672 Metetra
0 1 0 r
.89556 .43672 .90131 .44767 .91465 .4396 .9089 .42824 Metetra
0 1 0 r
.29062 .64123 .29761 .65185 .30914 .64445 .30215 .63425 Metetra
0 1 0 r
.30215 .63425 .30914 .64445 .32068 .63745 .31368 .62763 Metetra
0 1 0 r
.31368 .62763 .32068 .63745 .33221 .63082 .32522 .62138 Metetra
0 1 0 r
.32522 .62138 .33221 .63082 .34375 .62455 .33677 .61546 Metetra
0 1 0 r
.33677 .61546 .34375 .62455 .35531 .61863 .34833 .60987 Metetra
0 1 0 r
.34833 .60987 .35531 .61863 .36688 .61302 .35992 .60457 Metetra
0 1 0 r
.35992 .60457 .36688 .61302 .37848 .60771 .37153 .59955 Metetra
0 1 0 r
.37153 .59955 .37848 .60771 .3901 .6027 .38316 .59481 Metetra
0 1 0 r
.38316 .59481 .3901 .6027 .40175 .59794 .39483 .5903 Metetra
0 1 0 r
.39483 .5903 .40175 .59794 .41343 .59344 .40654 .58603 Metetra
0 1 0 r
.40654 .58603 .41343 .59344 .42516 .58917 .41828 .58198 Metetra
0 1 0 r
.41828 .58198 .42516 .58917 .43692 .58511 .43007 .57812 Metetra
0 1 0 r
.43007 .57812 .43692 .58511 .44872 .58125 .4419 .57444 Metetra
0 1 0 r
.4419 .57444 .44872 .58125 .46057 .57757 .45377 .57092 Metetra
0 1 0 r
.45377 .57092 .46057 .57757 .47246 .57406 .4657 .56755 Metetra
0 1 0 r
.4657 .56755 .47246 .57406 .48441 .57069 .47768 .56431 Metetra
0 1 0 r
.47768 .56431 .48441 .57069 .49641 .56746 .48972 .56118 Metetra
0 1 0 r
.48972 .56118 .49641 .56746 .50847 .56434 .50181 .55815 Metetra
0 1 0 r
.50181 .55815 .50847 .56434 .52058 .56132 .51395 .5552 Metetra
0 1 0 r
.51395 .5552 .52058 .56132 .53275 .55837 .52616 .55232 Metetra
0 1 0 r
.52616 .55232 .53275 .55837 .54499 .55549 .53843 .54948 Metetra
0 1 0 r
.53843 .54948 .54499 .55549 .55728 .55266 .55076 .54667 Metetra
0 1 0 r
.55076 .54667 .55728 .55266 .56963 .54986 .56315 .54388 Metetra
0 1 0 r
.56315 .54388 .56963 .54986 .58205 .54707 .57561 .54108 Metetra
0 1 0 r
.57561 .54108 .58205 .54707 .59453 .54428 .58812 .53826 Metetra
0 1 0 r
.58812 .53826 .59453 .54428 .60707 .54146 .60071 .5354 Metetra
0 1 0 r
.60071 .5354 .60707 .54146 .61967 .53861 .61335 .53248 Metetra
0 1 0 r
.61335 .53248 .61967 .53861 .63234 .5357 .62606 .52949 Metetra
0 1 0 r
.62606 .52949 .63234 .5357 .64507 .53271 .63882 .52641 Metetra
0 1 0 r
.63882 .52641 .64507 .53271 .65786 .52963 .65165 .52321 Metetra
0 1 0 r
.65165 .52321 .65786 .52963 .67071 .52644 .66454 .51989 Metetra
0 1 0 r
.66454 .51989 .67071 .52644 .68362 .52312 .67748 .51642 Metetra
0 1 0 r
.67748 .51642 .68362 .52312 .69658 .51965 .69048 .51279 Metetra
0 1 0 r
.69048 .51279 .69658 .51965 .7096 .51602 .70354 .50897 Metetra
0 1 0 r
.70354 .50897 .7096 .51602 .72267 .51219 .71664 .50495 Metetra
0 1 0 r
.71664 .50495 .72267 .51219 .73579 .50817 .72979 .5007 Metetra
0 1 0 r
.72979 .5007 .73579 .50817 .74896 .50391 .74299 .49622 Metetra
0 1 0 r
.74299 .49622 .74896 .50391 .76217 .49942 .75622 .49147 Metetra
0 1 0 r
.75622 .49147 .76217 .49942 .77542 .49466 .7695 .48644 Metetra
0 1 0 r
.7695 .48644 .77542 .49466 .7887 .48962 .7828 .48111 Metetra
0 1 0 r
.7828 .48111 .7887 .48962 .80201 .48427 .79613 .47547 Metetra
0 1 0 r
.79613 .47547 .80201 .48427 .81534 .4786 .80948 .46948 Metetra
0 1 0 r
.80948 .46948 .81534 .4786 .8287 .47259 .82285 .46313 Metetra
0 1 0 r
.82285 .46313 .8287 .47259 .84207 .46622 .83623 .45641 Metetra
0 1 0 r
.83623 .45641 .84207 .46622 .85545 .45946 .84962 .44929 Metetra
0 1 0 r
.84962 .44929 .85545 .45946 .86883 .45231 .863 .44175 Metetra
0 1 0 r
.863 .44175 .86883 .45231 .8822 .44473 .87637 .43377 Metetra
0 1 0 r
.87637 .43377 .8822 .44473 .89556 .43672 .88973 .42534 Metetra
0 1 0 r
.88973 .42534 .89556 .43672 .9089 .42824 .90306 .41644 Metetra
0 1 0 r
.28357 .63101 .29062 .64123 .30215 .63425 .29509 .62441 Metetra
0 1 0 r
.29509 .62441 .30215 .63425 .31368 .62763 .30662 .61818 Metetra
0 1 0 r
.30662 .61818 .31368 .62763 .32522 .62138 .31816 .61227 Metetra
0 1 0 r
.31816 .61227 .32522 .62138 .33677 .61546 .32972 .60669 Metetra
0 1 0 r
.32972 .60669 .33677 .61546 .34833 .60987 .34129 .6014 Metetra
0 1 0 r
.34129 .6014 .34833 .60987 .35992 .60457 .35289 .59639 Metetra
0 1 0 r
.35289 .59639 .35992 .60457 .37153 .59955 .36451 .59165 Metetra
0 1 0 r
.36451 .59165 .37153 .59955 .38316 .59481 .37617 .58715 Metetra
0 1 0 r
.37617 .58715 .38316 .59481 .39483 .5903 .38785 .58288 Metetra
0 1 0 r
.38785 .58288 .39483 .5903 .40654 .58603 .39958 .57883 Metetra
0 1 0 r
.39958 .57883 .40654 .58603 .41828 .58198 .41135 .57497 Metetra
0 1 0 r
.41135 .57497 .41828 .58198 .43007 .57812 .42316 .57129 Metetra
0 1 0 r
.42316 .57129 .43007 .57812 .4419 .57444 .43501 .56777 Metetra
0 1 0 r
.43501 .56777 .4419 .57444 .45377 .57092 .44692 .5644 Metetra
0 1 0 r
.44692 .5644 .45377 .57092 .4657 .56755 .45888 .56115 Metetra
0 1 0 r
.45888 .56115 .4657 .56755 .47768 .56431 .47089 .55802 Metetra
0 1 0 r
.47089 .55802 .47768 .56431 .48972 .56118 .48296 .55499 Metetra
0 1 0 r
.48296 .55499 .48972 .56118 .50181 .55815 .49508 .55203 Metetra
0 1 0 r
.49508 .55203 .50181 .55815 .51395 .5552 .50727 .54914 Metetra
0 1 0 r
.50727 .54914 .51395 .5552 .52616 .55232 .51951 .5463 Metetra
0 1 0 r
.51951 .5463 .52616 .55232 .53843 .54948 .53182 .54348 Metetra
0 1 0 r
.53182 .54348 .53843 .54948 .55076 .54667 .54418 .54068 Metetra
0 1 0 r
.54418 .54068 .55076 .54667 .56315 .54388 .55661 .53787 Metetra
0 1 0 r
.55661 .53787 .56315 .54388 .57561 .54108 .56911 .53504 Metetra
0 1 0 r
.56911 .53504 .57561 .54108 .58812 .53826 .58167 .53218 Metetra
0 1 0 r
.58167 .53218 .58812 .53826 .60071 .5354 .59429 .52926 Metetra
0 1 0 r
.59429 .52926 .60071 .5354 .61335 .53248 .60697 .52626 Metetra
0 1 0 r
.60697 .52626 .61335 .53248 .62606 .52949 .61971 .52317 Metetra
0 1 0 r
.61971 .52317 .62606 .52949 .63882 .52641 .63252 .51998 Metetra
0 1 0 r
.63252 .51998 .63882 .52641 .65165 .52321 .64539 .51665 Metetra
0 1 0 r
.64539 .51665 .65165 .52321 .66454 .51989 .65831 .51318 Metetra
0 1 0 r
.65831 .51318 .66454 .51989 .67748 .51642 .67129 .50955 Metetra
0 1 0 r
.67129 .50955 .67748 .51642 .69048 .51279 .68433 .50573 Metetra
0 1 0 r
.68433 .50573 .69048 .51279 .70354 .50897 .69741 .50171 Metetra
0 1 0 r
.69741 .50171 .70354 .50897 .71664 .50495 .71055 .49748 Metetra
0 1 0 r
.71055 .49748 .71664 .50495 .72979 .5007 .72373 .493 Metetra
0 1 0 r
.72373 .493 .72979 .5007 .74299 .49622 .73695 .48826 Metetra
0 1 0 r
.73695 .48826 .74299 .49622 .75622 .49147 .75021 .48324 Metetra
0 1 0 r
.75021 .48324 .75622 .49147 .7695 .48644 .76351 .47793 Metetra
0 1 0 r
.76351 .47793 .7695 .48644 .7828 .48111 .77684 .4723 Metetra
0 1 0 r
.77684 .4723 .7828 .48111 .79613 .47547 .79019 .46633 Metetra
0 1 0 r
.79019 .46633 .79613 .47547 .80948 .46948 .80356 .46001 Metetra
0 1 0 r
.80356 .46001 .80948 .46948 .82285 .46313 .81694 .45331 Metetra
0 1 0 r
.81694 .45331 .82285 .46313 .83623 .45641 .83033 .44621 Metetra
0 1 0 r
.83033 .44621 .83623 .45641 .84962 .44929 .84372 .43871 Metetra
0 1 0 r
.84372 .43871 .84962 .44929 .863 .44175 .8571 .43077 Metetra
0 1 0 r
.8571 .43077 .863 .44175 .87637 .43377 .87047 .42238 Metetra
0 1 0 r
.87047 .42238 .87637 .43377 .88973 .42534 .88382 .41352 Metetra
0 1 0 r
.88382 .41352 .88973 .42534 .90306 .41644 .89714 .40417 Metetra
0 1 0 r
.27644 .62116 .28357 .63101 .29509 .62441 .28796 .61494 Metetra
0 1 0 r
.28796 .61494 .29509 .62441 .30662 .61818 .2995 .60905 Metetra
0 1 0 r
.2995 .60905 .30662 .61818 .31816 .61227 .31104 .60348 Metetra
0 1 0 r
.31104 .60348 .31816 .61227 .32972 .60669 .3226 .5982 Metetra
0 1 0 r
.3226 .5982 .32972 .60669 .34129 .6014 .33418 .59321 Metetra
0 1 0 r
.33418 .59321 .34129 .6014 .35289 .59639 .34579 .58847 Metetra
0 1 0 r
.34579 .58847 .35289 .59639 .36451 .59165 .35743 .58398 Metetra
0 1 0 r
.35743 .58398 .36451 .59165 .37617 .58715 .3691 .57972 Metetra
0 1 0 r
.3691 .57972 .37617 .58715 .38785 .58288 .38081 .57567 Metetra
0 1 0 r
.38081 .57567 .38785 .58288 .39958 .57883 .39256 .57181 Metetra
0 1 0 r
.39256 .57181 .39958 .57883 .41135 .57497 .40435 .56813 Metetra
0 1 0 r
.40435 .56813 .41135 .57497 .42316 .57129 .41619 .56461 Metetra
0 1 0 r
.41619 .56461 .42316 .57129 .43501 .56777 .42807 .56123 Metetra
0 1 0 r
.42807 .56123 .43501 .56777 .44692 .5644 .44001 .55799 Metetra
0 1 0 r
.44001 .55799 .44692 .5644 .45888 .56115 .452 .55485 Metetra
0 1 0 r
.452 .55485 .45888 .56115 .47089 .55802 .46404 .55182 Metetra
0 1 0 r
.46404 .55182 .47089 .55802 .48296 .55499 .47614 .54886 Metetra
0 1 0 r
.47614 .54886 .48296 .55499 .49508 .55203 .4883 .54596 Metetra
0 1 0 r
.4883 .54596 .49508 .55203 .50727 .54914 .50052 .54311 Metetra
0 1 0 r
.50052 .54311 .50727 .54914 .51951 .5463 .5128 .54029 Metetra
0 1 0 r
.5128 .54029 .51951 .5463 .53182 .54348 .52514 .53748 Metetra
0 1 0 r
.52514 .53748 .53182 .54348 .54418 .54068 .53755 .53467 Metetra
0 1 0 r
.53755 .53467 .54418 .54068 .55661 .53787 .55002 .53183 Metetra
0 1 0 r
.55002 .53183 .55661 .53787 .56911 .53504 .56255 .52896 Metetra
0 1 0 r
.56255 .52896 .56911 .53504 .58167 .53218 .57515 .52603 Metetra
0 1 0 r
.57515 .52603 .58167 .53218 .59429 .52926 .58781 .52303 Metetra
0 1 0 r
.58781 .52303 .59429 .52926 .60697 .52626 .60053 .51994 Metetra
0 1 0 r
.60053 .51994 .60697 .52626 .61971 .52317 .61331 .51674 Metetra
0 1 0 r
.61331 .51674 .61971 .52317 .63252 .51998 .62616 .51341 Metetra
0 1 0 r
.62616 .51341 .63252 .51998 .64539 .51665 .63906 .50994 Metetra
0 1 0 r
.63906 .50994 .64539 .51665 .65831 .51318 .65202 .5063 Metetra
0 1 0 r
.65202 .5063 .65831 .51318 .67129 .50955 .66504 .50248 Metetra
0 1 0 r
.66504 .50248 .67129 .50955 .68433 .50573 .67811 .49847 Metetra
0 1 0 r
.67811 .49847 .68433 .50573 .69741 .50171 .69123 .49423 Metetra
0 1 0 r
.69123 .49423 .69741 .50171 .71055 .49748 .70439 .48976 Metetra
0 1 0 r
.70439 .48976 .71055 .49748 .72373 .493 .7176 .48502 Metetra
0 1 0 r
.7176 .48502 .72373 .493 .73695 .48826 .73085 .48002 Metetra
0 1 0 r
.73085 .48002 .73695 .48826 .75021 .48324 .74414 .47471 Metetra
0 1 0 r
.74414 .47471 .75021 .48324 .76351 .47793 .75746 .46909 Metetra
0 1 0 r
.75746 .46909 .76351 .47793 .77684 .4723 .77081 .46314 Metetra
0 1 0 r
.77081 .46314 .77684 .4723 .79019 .46633 .78417 .45684 Metetra
0 1 0 r
.78417 .45684 .79019 .46633 .80356 .46001 .79756 .45016 Metetra
0 1 0 r
.79756 .45016 .80356 .46001 .81694 .45331 .81095 .44309 Metetra
0 1 0 r
.81095 .44309 .81694 .45331 .83033 .44621 .82435 .43561 Metetra
0 1 0 r
.82435 .43561 .83033 .44621 .84372 .43871 .83774 .42771 Metetra
0 1 0 r
.83774 .42771 .84372 .43871 .8571 .43077 .85113 .41935 Metetra
0 1 0 r
.85113 .41935 .8571 .43077 .87047 .42238 .86449 .41053 Metetra
0 1 0 r
.86449 .41053 .87047 .42238 .88382 .41352 .87784 .40122 Metetra
0 1 0 r
.87784 .40122 .88382 .41352 .89714 .40417 .89114 .39141 Metetra
0 1 0 r
.26924 .61167 .27644 .62116 .28796 .61494 .28076 .6058 Metetra
0 1 0 r
.28076 .6058 .28796 .61494 .2995 .60905 .2923 .60024 Metetra
0 1 0 r
.2923 .60024 .2995 .60905 .31104 .60348 .30385 .59498 Metetra
0 1 0 r
.30385 .59498 .31104 .60348 .3226 .5982 .31541 .59 Metetra
0 1 0 r
.31541 .59 .3226 .5982 .33418 .59321 .32701 .58527 Metetra
0 1 0 r
.32701 .58527 .33418 .59321 .34579 .58847 .33863 .58079 Metetra
0 1 0 r
.33863 .58079 .34579 .58847 .35743 .58398 .35028 .57654 Metetra
0 1 0 r
.35028 .57654 .35743 .58398 .3691 .57972 .36197 .57249 Metetra
0 1 0 r
.36197 .57249 .3691 .57972 .38081 .57567 .3737 .56864 Metetra
0 1 0 r
.3737 .56864 .38081 .57567 .39256 .57181 .38547 .56496 Metetra
0 1 0 r
.38547 .56496 .39256 .57181 .40435 .56813 .39729 .56144 Metetra
0 1 0 r
.39729 .56144 .40435 .56813 .41619 .56461 .40915 .55806 Metetra
0 1 0 r
.40915 .55806 .41619 .56461 .42807 .56123 .42107 .55482 Metetra
0 1 0 r
.42107 .55482 .42807 .56123 .44001 .55799 .43303 .55168 Metetra
0 1 0 r
.43303 .55168 .44001 .55799 .452 .55485 .44505 .54864 Metetra
0 1 0 r
.44505 .54864 .452 .55485 .46404 .55182 .45713 .54568 Metetra
0 1 0 r
.45713 .54568 .46404 .55182 .47614 .54886 .46926 .54277 Metetra
0 1 0 r
.46926 .54277 .47614 .54886 .4883 .54596 .48146 .53992 Metetra
0 1 0 r
.48146 .53992 .4883 .54596 .50052 .54311 .49371 .53709 Metetra
0 1 0 r
.49371 .53709 .50052 .54311 .5128 .54029 .50603 .53428 Metetra
0 1 0 r
.50603 .53428 .5128 .54029 .52514 .53748 .51841 .53146 Metetra
0 1 0 r
.51841 .53146 .52514 .53748 .53755 .53467 .53086 .52862 Metetra
0 1 0 r
.53086 .52862 .53755 .53467 .55002 .53183 .54337 .52574 Metetra
0 1 0 r
.54337 .52574 .55002 .53183 .56255 .52896 .55594 .5228 Metetra
0 1 0 r
.55594 .5228 .56255 .52896 .57515 .52603 .56857 .51979 Metetra
0 1 0 r
.56857 .51979 .57515 .52603 .58781 .52303 .58127 .5167 Metetra
0 1 0 r
.58127 .5167 .58781 .52303 .60053 .51994 .59403 .51349 Metetra
0 1 0 r
.59403 .51349 .60053 .51994 .61331 .51674 .60685 .51016 Metetra
0 1 0 r
.60685 .51016 .61331 .51674 .62616 .51341 .61973 .50668 Metetra
0 1 0 r
.61973 .50668 .62616 .51341 .63906 .50994 .63268 .50304 Metetra
0 1 0 r
.63268 .50304 .63906 .50994 .65202 .5063 .64567 .49922 Metetra
0 1 0 r
.64567 .49922 .65202 .5063 .66504 .50248 .65872 .4952 Metetra
0 1 0 r
.65872 .4952 .66504 .50248 .67811 .49847 .67183 .49097 Metetra
0 1 0 r
.67183 .49097 .67811 .49847 .69123 .49423 .68498 .4865 Metetra
0 1 0 r
.68498 .4865 .69123 .49423 .70439 .48976 .69817 .48177 Metetra
0 1 0 r
.69817 .48177 .70439 .48976 .7176 .48502 .71141 .47677 Metetra
0 1 0 r
.71141 .47677 .7176 .48502 .73085 .48002 .72469 .47147 Metetra
0 1 0 r
.72469 .47147 .73085 .48002 .74414 .47471 .738 .46586 Metetra
0 1 0 r
.738 .46586 .74414 .47471 .75746 .46909 .75134 .45992 Metetra
0 1 0 r
.75134 .45992 .75746 .46909 .77081 .46314 .76471 .45363 Metetra
0 1 0 r
.76471 .45363 .77081 .46314 .78417 .45684 .77809 .44697 Metetra
0 1 0 r
.77809 .44697 .78417 .45684 .79756 .45016 .79149 .43992 Metetra
0 1 0 r
.79149 .43992 .79756 .45016 .81095 .44309 .80489 .43247 Metetra
0 1 0 r
.80489 .43247 .81095 .44309 .82435 .43561 .81829 .42459 Metetra
0 1 0 r
.81829 .42459 .82435 .43561 .83774 .42771 .83169 .41626 Metetra
0 1 0 r
.83169 .41626 .83774 .42771 .85113 .41935 .84507 .40747 Metetra
0 1 0 r
.84507 .40747 .85113 .41935 .86449 .41053 .85843 .3982 Metetra
0 1 0 r
.85843 .3982 .86449 .41053 .87784 .40122 .87177 .38843 Metetra
0 1 0 r
.87177 .38843 .87784 .40122 .89114 .39141 .88506 .37815 Metetra
0 1 0 r
.26197 .60252 .26924 .61167 .28076 .6058 .27349 .59698 Metetra
0 1 0 r
.27349 .59698 .28076 .6058 .2923 .60024 .28502 .59174 Metetra
0 1 0 r
.28502 .59174 .2923 .60024 .30385 .59498 .29658 .58677 Metetra
0 1 0 r
.29658 .58677 .30385 .59498 .31541 .59 .30816 .58206 Metetra
0 1 0 r
.30816 .58206 .31541 .59 .32701 .58527 .31976 .57758 Metetra
0 1 0 r
.31976 .57758 .32701 .58527 .33863 .58079 .3314 .57334 Metetra
0 1 0 r
.3314 .57334 .33863 .58079 .35028 .57654 .34307 .5693 Metetra
0 1 0 r
.34307 .5693 .35028 .57654 .36197 .57249 .35478 .56545 Metetra
0 1 0 r
.35478 .56545 .36197 .57249 .3737 .56864 .36653 .56178 Metetra
0 1 0 r
.36653 .56178 .3737 .56864 .38547 .56496 .37832 .55826 Metetra
0 1 0 r
.37832 .55826 .38547 .56496 .39729 .56144 .39016 .55489 Metetra
0 1 0 r
.39016 .55489 .39729 .56144 .40915 .55806 .40205 .55164 Metetra
0 1 0 r
.40205 .55164 .40915 .55806 .42107 .55482 .414 .5485 Metetra
0 1 0 r
.414 .5485 .42107 .55482 .43303 .55168 .42599 .54546 Metetra
0 1 0 r
.42599 .54546 .43303 .55168 .44505 .54864 .43804 .54249 Metetra
0 1 0 r
.43804 .54249 .44505 .54864 .45713 .54568 .45015 .53959 Metetra
0 1 0 r
.45015 .53959 .45713 .54568 .46926 .54277 .46232 .53672 Metetra
0 1 0 r
.46232 .53672 .46926 .54277 .48146 .53992 .47456 .53389 Metetra
0 1 0 r
.47456 .53389 .48146 .53992 .49371 .53709 .48685 .53107 Metetra
0 1 0 r
.48685 .53107 .49371 .53709 .50603 .53428 .4992 .52825 Metetra
0 1 0 r
.4992 .52825 .50603 .53428 .51841 .53146 .51162 .5254 Metetra
0 1 0 r
.51162 .5254 .51841 .53146 .53086 .52862 .5241 .52251 Metetra
0 1 0 r
.5241 .52251 .53086 .52862 .54337 .52574 .53665 .51957 Metetra
0 1 0 r
.53665 .51957 .54337 .52574 .55594 .5228 .54926 .51656 Metetra
0 1 0 r
.54926 .51656 .55594 .5228 .56857 .51979 .56194 .51345 Metetra
0 1 0 r
.56194 .51345 .56857 .51979 .58127 .5167 .57467 .51024 Metetra
0 1 0 r
.57467 .51024 .58127 .5167 .59403 .51349 .58747 .5069 Metetra
0 1 0 r
.58747 .5069 .59403 .51349 .60685 .51016 .60033 .50342 Metetra
0 1 0 r
.60033 .50342 .60685 .51016 .61973 .50668 .61325 .49977 Metetra
0 1 0 r
.61325 .49977 .61973 .50668 .63268 .50304 .62623 .49595 Metetra
0 1 0 r
.62623 .49595 .63268 .50304 .64567 .49922 .63926 .49193 Metetra
0 1 0 r
.63926 .49193 .64567 .49922 .65872 .4952 .65235 .48769 Metetra
0 1 0 r
.65235 .48769 .65872 .4952 .67183 .49097 .66548 .48322 Metetra
0 1 0 r
.66548 .48322 .67183 .49097 .68498 .4865 .67867 .47849 Metetra
0 1 0 r
.67867 .47849 .68498 .4865 .69817 .48177 .69189 .47349 Metetra
0 1 0 r
.69189 .47349 .69817 .48177 .71141 .47677 .70516 .4682 Metetra
0 1 0 r
.70516 .4682 .71141 .47677 .72469 .47147 .71846 .4626 Metetra
0 1 0 r
.71846 .4626 .72469 .47147 .738 .46586 .7318 .45667 Metetra
0 1 0 r
.7318 .45667 .738 .46586 .75134 .45992 .74516 .45039 Metetra
0 1 0 r
.74516 .45039 .75134 .45992 .76471 .45363 .75854 .44374 Metetra
0 1 0 r
.75854 .44374 .76471 .45363 .77809 .44697 .77194 .43671 Metetra
0 1 0 r
.77194 .43671 .77809 .44697 .79149 .43992 .78535 .42927 Metetra
0 1 0 r
.78535 .42927 .79149 .43992 .80489 .43247 .79876 .42141 Metetra
0 1 0 r
.79876 .42141 .80489 .43247 .81829 .42459 .81216 .41311 Metetra
0 1 0 r
.81216 .41311 .81829 .42459 .83169 .41626 .82556 .40435 Metetra
0 1 0 r
.82556 .40435 .83169 .41626 .84507 .40747 .83894 .39511 Metetra
0 1 0 r
.83894 .39511 .84507 .40747 .85843 .3982 .85229 .38538 Metetra
0 1 0 r
.85229 .38538 .85843 .3982 .87177 .38843 .86561 .37513 Metetra
0 1 0 r
.86561 .37513 .87177 .38843 .88506 .37815 .87889 .36436 Metetra
0 1 0 r
.25461 .59369 .26197 .60252 .27349 .59698 .26614 .58847 Metetra
0 1 0 r
.26614 .58847 .27349 .59698 .28502 .59174 .27768 .58352 Metetra
0 1 0 r
.27768 .58352 .28502 .59174 .29658 .58677 .28924 .57882 Metetra
0 1 0 r
.28924 .57882 .29658 .58677 .30816 .58206 .30083 .57436 Metetra
0 1 0 r
.30083 .57436 .30816 .58206 .31976 .57758 .31244 .57012 Metetra
0 1 0 r
.31244 .57012 .31976 .57758 .3314 .57334 .32409 .56609 Metetra
0 1 0 r
.32409 .56609 .3314 .57334 .34307 .5693 .33578 .56225 Metetra
0 1 0 r
.33578 .56225 .34307 .5693 .35478 .56545 .34751 .55859 Metetra
0 1 0 r
.34751 .55859 .35478 .56545 .36653 .56178 .35928 .55507 Metetra
0 1 0 r
.35928 .55507 .36653 .56178 .37832 .55826 .3711 .5517 Metetra
0 1 0 r
.3711 .5517 .37832 .55826 .39016 .55489 .38297 .54846 Metetra
0 1 0 r
.38297 .54846 .39016 .55489 .40205 .55164 .39489 .54532 Metetra
0 1 0 r
.39489 .54532 .40205 .55164 .414 .5485 .40686 .54227 Metetra
0 1 0 r
.40686 .54227 .414 .5485 .42599 .54546 .41889 .5393 Metetra
0 1 0 r
.41889 .5393 .42599 .54546 .43804 .54249 .43097 .5364 Metetra
0 1 0 r
.43097 .5364 .43804 .54249 .45015 .53959 .44312 .53353 Metetra
0 1 0 r
.44312 .53353 .45015 .53959 .46232 .53672 .45532 .53069 Metetra
0 1 0 r
.45532 .53069 .46232 .53672 .47456 .53389 .46759 .52787 Metetra
0 1 0 r
.46759 .52787 .47456 .53389 .48685 .53107 .47992 .52503 Metetra
0 1 0 r
.47992 .52503 .48685 .53107 .4992 .52825 .49231 .52218 Metetra
0 1 0 r
.49231 .52218 .4992 .52825 .51162 .5254 .50477 .51928 Metetra
0 1 0 r
.50477 .51928 .51162 .5254 .5241 .52251 .51729 .51634 Metetra
0 1 0 r
.51729 .51634 .5241 .52251 .53665 .51957 .52988 .51331 Metetra
0 1 0 r
.52988 .51331 .53665 .51957 .54926 .51656 .54253 .5102 Metetra
0 1 0 r
.54253 .5102 .54926 .51656 .56194 .51345 .55524 .50698 Metetra
0 1 0 r
.55524 .50698 .56194 .51345 .57467 .51024 .56802 .50363 Metetra
0 1 0 r
.56802 .50363 .57467 .51024 .58747 .5069 .58085 .50014 Metetra
0 1 0 r
.58085 .50014 .58747 .5069 .60033 .50342 .59375 .49649 Metetra
0 1 0 r
.59375 .49649 .60033 .50342 .61325 .49977 .60671 .49267 Metetra
0 1 0 r
.60671 .49267 .61325 .49977 .62623 .49595 .61972 .48864 Metetra
0 1 0 r
.61972 .48864 .62623 .49595 .63926 .49193 .63279 .4844 Metetra
0 1 0 r
.63279 .4844 .63926 .49193 .65235 .48769 .64591 .47992 Metetra
0 1 0 r
.64591 .47992 .65235 .48769 .66548 .48322 .65908 .47519 Metetra
0 1 0 r
.65908 .47519 .66548 .48322 .67867 .47849 .67229 .47019 Metetra
0 1 0 r
.67229 .47019 .67867 .47849 .69189 .47349 .68555 .4649 Metetra
0 1 0 r
.68555 .4649 .69189 .47349 .70516 .4682 .69884 .4593 Metetra
0 1 0 r
.69884 .4593 .70516 .4682 .71846 .4626 .71217 .45338 Metetra
0 1 0 r
.71217 .45338 .71846 .4626 .7318 .45667 .72553 .4471 Metetra
0 1 0 r
.72553 .4471 .7318 .45667 .74516 .45039 .73891 .44047 Metetra
0 1 0 r
.73891 .44047 .74516 .45039 .75854 .44374 .75231 .43344 Metetra
0 1 0 r
.75231 .43344 .75854 .44374 .77194 .43671 .76572 .42602 Metetra
0 1 0 r
.76572 .42602 .77194 .43671 .78535 .42927 .77913 .41818 Metetra
0 1 0 r
.77913 .41818 .78535 .42927 .79876 .42141 .79255 .4099 Metetra
0 1 0 r
.79255 .4099 .79876 .42141 .81216 .41311 .80596 .40116 Metetra
0 1 0 r
.80596 .40116 .81216 .41311 .82556 .40435 .81936 .39194 Metetra
0 1 0 r
.81936 .39194 .82556 .40435 .83894 .39511 .83273 .38224 Metetra
0 1 0 r
.83273 .38224 .83894 .39511 .85229 .38538 .84607 .37203 Metetra
0 1 0 r
.84607 .37203 .85229 .38538 .86561 .37513 .85938 .36129 Metetra
0 1 0 r
.85938 .36129 .86561 .37513 .87889 .36436 .87264 .35002 Metetra
0 1 0 r
.24718 .58518 .25461 .59369 .26614 .58847 .25871 .58024 Metetra
0 1 0 r
.25871 .58024 .26614 .58847 .27768 .58352 .27025 .57556 Metetra
0 1 0 r
.27025 .57556 .27768 .58352 .28924 .57882 .28182 .57112 Metetra
0 1 0 r
.28182 .57112 .28924 .57882 .30083 .57436 .29342 .5669 Metetra
0 1 0 r
.29342 .5669 .30083 .57436 .31244 .57012 .30505 .56288 Metetra
0 1 0 r
.30505 .56288 .31244 .57012 .32409 .56609 .31672 .55905 Metetra
0 1 0 r
.31672 .55905 .32409 .56609 .33578 .56225 .32843 .55538 Metetra
0 1 0 r
.32843 .55538 .33578 .56225 .34751 .55859 .34018 .55188 Metetra
0 1 0 r
.34018 .55188 .34751 .55859 .35928 .55507 .35197 .54851 Metetra
0 1 0 r
.35197 .54851 .35928 .55507 .3711 .5517 .36381 .54527 Metetra
0 1 0 r
.36381 .54527 .3711 .5517 .38297 .54846 .37571 .54213 Metetra
0 1 0 r
.37571 .54213 .38297 .54846 .39489 .54532 .38765 .53909 Metetra
0 1 0 r
.38765 .53909 .39489 .54532 .40686 .54227 .39966 .53611 Metetra
0 1 0 r
.39966 .53611 .40686 .54227 .41889 .5393 .41172 .5332 Metetra
0 1 0 r
.41172 .5332 .41889 .5393 .43097 .5364 .42384 .53033 Metetra
0 1 0 r
.42384 .53033 .43097 .5364 .44312 .53353 .43601 .52749 Metetra
0 1 0 r
.43601 .52749 .44312 .53353 .45532 .53069 .44826 .52466 Metetra
0 1 0 r
.44826 .52466 .45532 .53069 .46759 .52787 .46056 .52182 Metetra
0 1 0 r
.46056 .52182 .46759 .52787 .47992 .52503 .47293 .51896 Metetra
0 1 0 r
.47293 .51896 .47992 .52503 .49231 .52218 .48536 .51606 Metetra
0 1 0 r
.48536 .51606 .49231 .52218 .50477 .51928 .49785 .5131 Metetra
0 1 0 r
.49785 .5131 .50477 .51928 .51729 .51634 .51041 .51007 Metetra
0 1 0 r
.51041 .51007 .51729 .51634 .52988 .51331 .52304 .50695 Metetra
0 1 0 r
.52304 .50695 .52988 .51331 .54253 .5102 .53573 .50372 Metetra
0 1 0 r
.53573 .50372 .54253 .5102 .55524 .50698 .54848 .50036 Metetra
0 1 0 r
.54848 .50036 .55524 .50698 .56802 .50363 .5613 .49686 Metetra
0 1 0 r
.5613 .49686 .56802 .50363 .58085 .50014 .57417 .49321 Metetra
0 1 0 r
.57417 .49321 .58085 .50014 .59375 .49649 .58711 .48937 Metetra
0 1 0 r
.58711 .48937 .59375 .49649 .60671 .49267 .60011 .48534 Metetra
0 1 0 r
.60011 .48534 .60671 .49267 .61972 .48864 .61316 .48109 Metetra
0 1 0 r
.61316 .48109 .61972 .48864 .63279 .4844 .62626 .4766 Metetra
0 1 0 r
.62626 .4766 .63279 .4844 .64591 .47992 .63941 .47187 Metetra
0 1 0 r
.63941 .47187 .64591 .47992 .65908 .47519 .65261 .46687 Metetra
0 1 0 r
.65261 .46687 .65908 .47519 .67229 .47019 .66586 .46158 Metetra
0 1 0 r
.66586 .46158 .67229 .47019 .68555 .4649 .67914 .45598 Metetra
0 1 0 r
.67914 .45598 .68555 .4649 .69884 .4593 .69246 .45005 Metetra
0 1 0 r
.69246 .45005 .69884 .4593 .71217 .45338 .70581 .44378 Metetra
0 1 0 r
.70581 .44378 .71217 .45338 .72553 .4471 .71919 .43715 Metetra
0 1 0 r
.71919 .43715 .72553 .4471 .73891 .44047 .73259 .43013 Metetra
0 1 0 r
.73259 .43013 .73891 .44047 .75231 .43344 .746 .42272 Metetra
0 1 0 r
.746 .42272 .75231 .43344 .76572 .42602 .75942 .41489 Metetra
0 1 0 r
.75942 .41489 .76572 .42602 .77913 .41818 .77285 .40662 Metetra
0 1 0 r
.77285 .40662 .77913 .41818 .79255 .4099 .78627 .3979 Metetra
0 1 0 r
.78627 .3979 .79255 .4099 .80596 .40116 .79968 .38871 Metetra
0 1 0 r
.79968 .38871 .80596 .40116 .81936 .39194 .81307 .37903 Metetra
0 1 0 r
.81307 .37903 .81936 .39194 .83273 .38224 .82644 .36884 Metetra
0 1 0 r
.82644 .36884 .83273 .38224 .84607 .37203 .83977 .35814 Metetra
0 1 0 r
.83977 .35814 .84607 .37203 .85938 .36129 .85306 .34689 Metetra
0 1 0 r
.85306 .34689 .85938 .36129 .87264 .35002 .8663 .3351 Metetra
0 1 0 r
.23967 .57695 .24718 .58518 .25871 .58024 .2512 .57229 Metetra
0 1 0 r
.2512 .57229 .25871 .58024 .27025 .57556 .26275 .56786 Metetra
0 1 0 r
.26275 .56786 .27025 .57556 .28182 .57112 .27433 .56366 Metetra
0 1 0 r
.27433 .56366 .28182 .57112 .29342 .5669 .28594 .55965 Metetra
0 1 0 r
.28594 .55965 .29342 .5669 .30505 .56288 .29758 .55583 Metetra
0 1 0 r
.29758 .55583 .30505 .56288 .31672 .55905 .30927 .55218 Metetra
0 1 0 r
.30927 .55218 .31672 .55905 .32843 .55538 .321 .54868 Metetra
0 1 0 r
.321 .54868 .32843 .55538 .34018 .55188 .33277 .54532 Metetra
0 1 0 r
.33277 .54532 .34018 .55188 .35197 .54851 .34459 .54207 Metetra
0 1 0 r
.34459 .54207 .35197 .54851 .36381 .54527 .35645 .53894 Metetra
0 1 0 r
.35645 .53894 .36381 .54527 .37571 .54213 .36838 .53589 Metetra
0 1 0 r
.36838 .53589 .37571 .54213 .38765 .53909 .38035 .53292 Metetra
0 1 0 r
.38035 .53292 .38765 .53909 .39966 .53611 .39239 .53001 Metetra
0 1 0 r
.39239 .53001 .39966 .53611 .41172 .5332 .40448 .52714 Metetra
0 1 0 r
.40448 .52714 .41172 .5332 .42384 .53033 .41663 .52429 Metetra
0 1 0 r
.41663 .52429 .42384 .53033 .43601 .52749 .42885 .52145 Metetra
0 1 0 r
.42885 .52145 .43601 .52749 .44826 .52466 .44112 .5186 Metetra
0 1 0 r
.44112 .5186 .44826 .52466 .46056 .52182 .45347 .51574 Metetra
0 1 0 r
.45347 .51574 .46056 .52182 .47293 .51896 .46587 .51283 Metetra
0 1 0 r
.46587 .51283 .47293 .51896 .48536 .51606 .47834 .50986 Metetra
0 1 0 r
.47834 .50986 .48536 .51606 .49785 .5131 .49088 .50682 Metetra
0 1 0 r
.49088 .50682 .49785 .5131 .51041 .51007 .50348 .50369 Metetra
0 1 0 r
.50348 .50369 .51041 .51007 .52304 .50695 .51614 .50045 Metetra
0 1 0 r
.51614 .50045 .52304 .50695 .53573 .50372 .52887 .49708 Metetra
0 1 0 r
.52887 .49708 .53573 .50372 .54848 .50036 .54166 .49358 Metetra
0 1 0 r
.54166 .49358 .54848 .50036 .5613 .49686 .55452 .48991 Metetra
0 1 0 r
.55452 .48991 .5613 .49686 .57417 .49321 .56743 .48606 Metetra
0 1 0 r
.56743 .48606 .57417 .49321 .58711 .48937 .58041 .48202 Metetra
0 1 0 r
.58041 .48202 .58711 .48937 .60011 .48534 .59344 .47776 Metetra
0 1 0 r
.59344 .47776 .60011 .48534 .61316 .48109 .60653 .47327 Metetra
0 1 0 r
.60653 .47327 .61316 .48109 .62626 .4766 .61966 .46853 Metetra
0 1 0 r
.61966 .46853 .62626 .4766 .63941 .47187 .63285 .46352 Metetra
0 1 0 r
.63285 .46352 .63941 .47187 .65261 .46687 .64608 .45822 Metetra
0 1 0 r
.64608 .45822 .65261 .46687 .66586 .46158 .65936 .45262 Metetra
0 1 0 r
.65936 .45262 .66586 .46158 .67914 .45598 .67267 .44669 Metetra
0 1 0 r
.67267 .44669 .67914 .45598 .69246 .45005 .68601 .44042 Metetra
0 1 0 r
.68601 .44042 .69246 .45005 .70581 .44378 .69939 .43379 Metetra
0 1 0 r
.69939 .43379 .70581 .44378 .71919 .43715 .71278 .42678 Metetra
0 1 0 r
.71278 .42678 .71919 .43715 .73259 .43013 .7262 .41937 Metetra
0 1 0 r
.7262 .41937 .73259 .43013 .746 .42272 .73963 .41154 Metetra
0 1 0 r
.73963 .41154 .746 .42272 .75942 .41489 .75306 .40329 Metetra
0 1 0 r
.75306 .40329 .75942 .41489 .77285 .40662 .76649 .39458 Metetra
0 1 0 r
.76649 .39458 .77285 .40662 .78627 .3979 .77992 .3854 Metetra
0 1 0 r
.77992 .3854 .78627 .3979 .79968 .38871 .79333 .37574 Metetra
0 1 0 r
.79333 .37574 .79968 .38871 .81307 .37903 .80671 .36557 Metetra
0 1 0 r
.80671 .36557 .81307 .37903 .82644 .36884 .82007 .35489 Metetra
0 1 0 r
.82007 .35489 .82644 .36884 .83977 .35814 .83339 .34368 Metetra
0 1 0 r
.83339 .34368 .83977 .35814 .85306 .34689 .84666 .33191 Metetra
0 1 0 r
.84666 .33191 .85306 .34689 .8663 .3351 .85987 .31959 Metetra
0 1 0 r
.23208 .569 .23967 .57695 .2512 .57229 .24361 .56459 Metetra
0 1 0 r
.24361 .56459 .2512 .57229 .26275 .56786 .25517 .5604 Metetra
0 1 0 r
.25517 .5604 .26275 .56786 .27433 .56366 .26676 .55641 Metetra
0 1 0 r
.26676 .55641 .27433 .56366 .28594 .55965 .27838 .5526 Metetra
0 1 0 r
.27838 .5526 .28594 .55965 .29758 .55583 .29004 .54896 Metetra
0 1 0 r
.29004 .54896 .29758 .55583 .30927 .55218 .30174 .54547 Metetra
0 1 0 r
.30174 .54547 .30927 .55218 .321 .54868 .31349 .54211 Metetra
0 1 0 r
.31349 .54211 .321 .54868 .33277 .54532 .32528 .53888 Metetra
0 1 0 r
.32528 .53888 .33277 .54532 .34459 .54207 .33713 .53575 Metetra
0 1 0 r
.33713 .53575 .34459 .54207 .35645 .53894 .34903 .5327 Metetra
0 1 0 r
.34903 .5327 .35645 .53894 .36838 .53589 .36098 .52973 Metetra
0 1 0 r
.36098 .52973 .36838 .53589 .38035 .53292 .37298 .52681 Metetra
0 1 0 r
.37298 .52681 .38035 .53292 .39239 .53001 .38505 .52394 Metetra
0 1 0 r
.38505 .52394 .39239 .53001 .40448 .52714 .39718 .52109 Metetra
0 1 0 r
.39718 .52109 .40448 .52714 .41663 .52429 .40936 .51824 Metetra
0 1 0 r
.40936 .51824 .41663 .52429 .42885 .52145 .42161 .51539 Metetra
0 1 0 r
.42161 .51539 .42885 .52145 .44112 .5186 .43393 .51251 Metetra
0 1 0 r
.43393 .51251 .44112 .5186 .45347 .51574 .44631 .5096 Metetra
0 1 0 r
.44631 .5096 .45347 .51574 .46587 .51283 .45875 .50662 Metetra
0 1 0 r
.45875 .50662 .46587 .51283 .47834 .50986 .47126 .50357 Metetra
0 1 0 r
.47126 .50357 .47834 .50986 .49088 .50682 .48384 .50043 Metetra
0 1 0 r
.48384 .50043 .49088 .50682 .50348 .50369 .49648 .49718 Metetra
0 1 0 r
.49648 .49718 .50348 .50369 .51614 .50045 .50918 .4938 Metetra
0 1 0 r
.50918 .4938 .51614 .50045 .52887 .49708 .52195 .49028 Metetra
0 1 0 r
.52195 .49028 .52887 .49708 .54166 .49358 .53478 .4866 Metetra
0 1 0 r
.53478 .4866 .54166 .49358 .55452 .48991 .54768 .48274 Metetra
0 1 0 r
.54768 .48274 .55452 .48991 .56743 .48606 .56063 .47869 Metetra
0 1 0 r
.56063 .47869 .56743 .48606 .58041 .48202 .57364 .47442 Metetra
0 1 0 r
.57364 .47442 .58041 .48202 .59344 .47776 .58671 .46992 Metetra
0 1 0 r
.58671 .46992 .59344 .47776 .60653 .47327 .59983 .46517 Metetra
0 1 0 r
.59983 .46517 .60653 .47327 .61966 .46853 .61301 .46015 Metetra
0 1 0 r
.61301 .46015 .61966 .46853 .63285 .46352 .62623 .45484 Metetra
0 1 0 r
.62623 .45484 .63285 .46352 .64608 .45822 .63949 .44923 Metetra
0 1 0 r
.63949 .44923 .64608 .45822 .65936 .45262 .65279 .4433 Metetra
0 1 0 r
.65279 .4433 .65936 .45262 .67267 .44669 .66613 .43702 Metetra
0 1 0 r
.66613 .43702 .67267 .44669 .68601 .44042 .6795 .43039 Metetra
0 1 0 r
.6795 .43039 .68601 .44042 .69939 .43379 .6929 .42338 Metetra
0 1 0 r
.6929 .42338 .69939 .43379 .71278 .42678 .70631 .41597 Metetra
0 1 0 r
.70631 .41597 .71278 .42678 .7262 .41937 .71974 .40814 Metetra
0 1 0 r
.71974 .40814 .7262 .41937 .73963 .41154 .73318 .39989 Metetra
0 1 0 r
.73318 .39989 .73963 .41154 .75306 .40329 .74662 .39119 Metetra
0 1 0 r
.74662 .39119 .75306 .40329 .76649 .39458 .76006 .38202 Metetra
0 1 0 r
.76006 .38202 .76649 .39458 .77992 .3854 .77349 .37237 Metetra
0 1 0 r
.77349 .37237 .77992 .3854 .79333 .37574 .7869 .36222 Metetra
0 1 0 r
.7869 .36222 .79333 .37574 .80671 .36557 .80028 .35156 Metetra
0 1 0 r
.80028 .35156 .80671 .36557 .82007 .35489 .81362 .34036 Metetra
0 1 0 r
.81362 .34036 .82007 .35489 .83339 .34368 .82693 .32862 Metetra
0 1 0 r
.82693 .32862 .83339 .34368 .84666 .33191 .84018 .31633 Metetra
0 1 0 r
.84018 .31633 .84666 .33191 .85987 .31959 .85336 .30345 Metetra
0 1 0 r
.2244 .56131 .23208 .569 .24361 .56459 .23594 .55713 Metetra
0 1 0 r
.23594 .55713 .24361 .56459 .25517 .5604 .2475 .55316 Metetra
0 1 0 r
.2475 .55316 .25517 .5604 .26676 .55641 .2591 .54936 Metetra
0 1 0 r
.2591 .54936 .26676 .55641 .27838 .5526 .27074 .54573 Metetra
0 1 0 r
.27074 .54573 .27838 .5526 .29004 .54896 .28242 .54225 Metetra
0 1 0 r
.28242 .54225 .29004 .54896 .30174 .54547 .29414 .53891 Metetra
0 1 0 r
.29414 .53891 .30174 .54547 .31349 .54211 .30591 .53568 Metetra
0 1 0 r
.30591 .53568 .31349 .54211 .32528 .53888 .31773 .53255 Metetra
0 1 0 r
.31773 .53255 .32528 .53888 .33713 .53575 .3296 .52951 Metetra
0 1 0 r
.3296 .52951 .33713 .53575 .34903 .5327 .34152 .52653 Metetra
0 1 0 r
.34152 .52653 .34903 .5327 .36098 .52973 .3535 .52362 Metetra
0 1 0 r
.3535 .52362 .36098 .52973 .37298 .52681 .36554 .52074 Metetra
0 1 0 r
.36554 .52074 .37298 .52681 .38505 .52394 .37764 .51788 Metetra
0 1 0 r
.37764 .51788 .38505 .52394 .39718 .52109 .3898 .51503 Metetra
0 1 0 r
.3898 .51503 .39718 .52109 .40936 .51824 .40203 .51218 Metetra
0 1 0 r
.40203 .51218 .40936 .51824 .42161 .51539 .41431 .50929 Metetra
0 1 0 r
.41431 .50929 .42161 .51539 .43393 .51251 .42667 .50636 Metetra
0 1 0 r
.42667 .50636 .43393 .51251 .44631 .5096 .43908 .50338 Metetra
0 1 0 r
.43908 .50338 .44631 .5096 .45875 .50662 .45157 .50032 Metetra
0 1 0 r
.45157 .50032 .45875 .50662 .47126 .50357 .46412 .49716 Metetra
0 1 0 r
.46412 .49716 .47126 .50357 .48384 .50043 .47673 .4939 Metetra
0 1 0 r
.47673 .4939 .48384 .50043 .49648 .49718 .48941 .49051 Metetra
0 1 0 r
.48941 .49051 .49648 .49718 .50918 .4938 .50216 .48698 Metetra
0 1 0 r
.50216 .48698 .50918 .4938 .52195 .49028 .51497 .48329 Metetra
0 1 0 r
.51497 .48329 .52195 .49028 .53478 .4866 .52784 .47941 Metetra
0 1 0 r
.52784 .47941 .53478 .4866 .54768 .48274 .54078 .47535 Metetra
0 1 0 r
.54078 .47535 .54768 .48274 .56063 .47869 .55377 .47106 Metetra
0 1 0 r
.55377 .47106 .56063 .47869 .57364 .47442 .56682 .46655 Metetra
0 1 0 r
.56682 .46655 .57364 .47442 .58671 .46992 .57992 .46179 Metetra
0 1 0 r
.57992 .46179 .58671 .46992 .59983 .46517 .59308 .45675 Metetra
0 1 0 r
.59308 .45675 .59983 .46517 .61301 .46015 .60629 .45144 Metetra
0 1 0 r
.60629 .45144 .61301 .46015 .62623 .45484 .61954 .44581 Metetra
0 1 0 r
.61954 .44581 .62623 .45484 .63949 .44923 .63283 .43987 Metetra
0 1 0 r
.63283 .43987 .63949 .44923 .65279 .4433 .64616 .43359 Metetra
0 1 0 r
.64616 .43359 .65279 .4433 .66613 .43702 .65953 .42694 Metetra
0 1 0 r
.65953 .42694 .66613 .43702 .6795 .43039 .67292 .41993 Metetra
0 1 0 r
.67292 .41993 .6795 .43039 .6929 .42338 .68634 .41251 Metetra
0 1 0 r
.68634 .41251 .6929 .42338 .70631 .41597 .69977 .40469 Metetra
0 1 0 r
.69977 .40469 .70631 .41597 .71974 .40814 .71322 .39643 Metetra
0 1 0 r
.71322 .39643 .71974 .40814 .73318 .39989 .72667 .38773 Metetra
0 1 0 r
.72667 .38773 .73318 .39989 .74662 .39119 .74012 .37857 Metetra
0 1 0 r
.74012 .37857 .74662 .39119 .76006 .38202 .75356 .36893 Metetra
0 1 0 r
.75356 .36893 .76006 .38202 .77349 .37237 .76699 .35879 Metetra
0 1 0 r
.76699 .35879 .77349 .37237 .7869 .36222 .78039 .34813 Metetra
0 1 0 r
.78039 .34813 .7869 .36222 .80028 .35156 .79376 .33695 Metetra
0 1 0 r
.79376 .33695 .80028 .35156 .81362 .34036 .80709 .32523 Metetra
0 1 0 r
.80709 .32523 .81362 .34036 .82693 .32862 .82038 .31296 Metetra
0 1 0 r
.82038 .31296 .82693 .32862 .84018 .31633 .83361 .30011 Metetra
0 1 0 r
.83361 .30011 .84018 .31633 .85336 .30345 .84677 .28668 Metetra
0 1 0 r
.21663 .55386 .2244 .56131 .23594 .55713 .22818 .5499 Metetra
0 1 0 r
.22818 .5499 .23594 .55713 .2475 .55316 .23976 .54612 Metetra
0 1 0 r
.23976 .54612 .2475 .55316 .2591 .54936 .25137 .5425 Metetra
0 1 0 r
.25137 .5425 .2591 .54936 .27074 .54573 .26302 .53903 Metetra
0 1 0 r
.26302 .53903 .27074 .54573 .28242 .54225 .27472 .53569 Metetra
0 1 0 r
.27472 .53569 .28242 .54225 .29414 .53891 .28646 .53247 Metetra
0 1 0 r
.28646 .53247 .29414 .53891 .30591 .53568 .29825 .52935 Metetra
0 1 0 r
.29825 .52935 .30591 .53568 .31773 .53255 .3101 .52631 Metetra
0 1 0 r
.3101 .52631 .31773 .53255 .3296 .52951 .322 .52334 Metetra
0 1 0 r
.322 .52334 .3296 .52951 .34152 .52653 .33395 .52042 Metetra
0 1 0 r
.33395 .52042 .34152 .52653 .3535 .52362 .34596 .51754 Metetra
0 1 0 r
.34596 .51754 .3535 .52362 .36554 .52074 .35803 .51468 Metetra
0 1 0 r
.35803 .51468 .36554 .52074 .37764 .51788 .37016 .51183 Metetra
0 1 0 r
.37016 .51183 .37764 .51788 .3898 .51503 .38236 .50896 Metetra
0 1 0 r
.38236 .50896 .3898 .51503 .40203 .51218 .39462 .50607 Metetra
0 1 0 r
.39462 .50607 .40203 .51218 .41431 .50929 .40695 .50313 Metetra
0 1 0 r
.40695 .50313 .41431 .50929 .42667 .50636 .41934 .50014 Metetra
0 1 0 r
.41934 .50014 .42667 .50636 .43908 .50338 .4318 .49706 Metetra
0 1 0 r
.4318 .49706 .43908 .50338 .45157 .50032 .44432 .4939 Metetra
0 1 0 r
.44432 .4939 .45157 .50032 .46412 .49716 .45691 .49062 Metetra
0 1 0 r
.45691 .49062 .46412 .49716 .47673 .4939 .46957 .48722 Metetra
0 1 0 r
.46957 .48722 .47673 .4939 .48941 .49051 .48229 .48367 Metetra
0 1 0 r
.48229 .48367 .48941 .49051 .50216 .48698 .49508 .47996 Metetra
0 1 0 r
.49508 .47996 .50216 .48698 .51497 .48329 .50793 .47607 Metetra
0 1 0 r
.50793 .47607 .51497 .48329 .52784 .47941 .52084 .47199 Metetra
0 1 0 r
.52084 .47199 .52784 .47941 .54078 .47535 .53381 .46769 Metetra
0 1 0 r
.53381 .46769 .54078 .47535 .55377 .47106 .54684 .46316 Metetra
0 1 0 r
.54684 .46316 .55377 .47106 .56682 .46655 .55993 .45838 Metetra
0 1 0 r
.55993 .45838 .56682 .46655 .57992 .46179 .57307 .45333 Metetra
0 1 0 r
.57307 .45333 .57992 .46179 .59308 .45675 .58627 .448 Metetra
0 1 0 r
.58627 .448 .59308 .45675 .60629 .45144 .59951 .44237 Metetra
0 1 0 r
.59951 .44237 .60629 .45144 .61954 .44581 .61279 .43641 Metetra
0 1 0 r
.61279 .43641 .61954 .44581 .63283 .43987 .62611 .43011 Metetra
0 1 0 r
.62611 .43011 .63283 .43987 .64616 .43359 .63947 .42346 Metetra
0 1 0 r
.63947 .42346 .64616 .43359 .65953 .42694 .65286 .41643 Metetra
0 1 0 r
.65286 .41643 .65953 .42694 .67292 .41993 .66628 .40901 Metetra
0 1 0 r
.66628 .40901 .67292 .41993 .68634 .41251 .67971 .40118 Metetra
0 1 0 r
.67971 .40118 .68634 .41251 .69977 .40469 .69317 .39292 Metetra
0 1 0 r
.69317 .39292 .69977 .40469 .71322 .39643 .70662 .38421 Metetra
0 1 0 r
.70662 .38421 .71322 .39643 .72667 .38773 .72009 .37505 Metetra
0 1 0 r
.72009 .37505 .72667 .38773 .74012 .37857 .73354 .3654 Metetra
0 1 0 r
.73354 .3654 .74012 .37857 .75356 .36893 .74699 .35527 Metetra
0 1 0 r
.74699 .35527 .75356 .36893 .76699 .35879 .76041 .34462 Metetra
0 1 0 r
.76041 .34462 .76699 .35879 .78039 .34813 .77381 .33345 Metetra
0 1 0 r
.77381 .33345 .78039 .34813 .79376 .33695 .78717 .32174 Metetra
0 1 0 r
.78717 .32174 .79376 .33695 .80709 .32523 .80049 .30948 Metetra
0 1 0 r
.80049 .30948 .80709 .32523 .82038 .31296 .81375 .29665 Metetra
0 1 0 r
.81375 .29665 .82038 .31296 .83361 .30011 .82695 .28324 Metetra
0 1 0 r
.82695 .28324 .83361 .30011 .84677 .28668 .84008 .26924 Metetra
0 1 0 r
.20878 .54663 .21663 .55386 .22818 .5499 .22034 .54287 Metetra
0 1 0 r
.22034 .54287 .22818 .5499 .23976 .54612 .23193 .53926 Metetra
0 1 0 r
.23193 .53926 .23976 .54612 .25137 .5425 .24355 .53581 Metetra
0 1 0 r
.24355 .53581 .25137 .5425 .26302 .53903 .25522 .53248 Metetra
0 1 0 r
.25522 .53248 .26302 .53903 .27472 .53569 .26694 .52926 Metetra
0 1 0 r
.26694 .52926 .27472 .53569 .28646 .53247 .27871 .52615 Metetra
0 1 0 r
.27871 .52615 .28646 .53247 .29825 .52935 .29052 .52311 Metetra
0 1 0 r
.29052 .52311 .29825 .52935 .3101 .52631 .30239 .52014 Metetra
0 1 0 r
.30239 .52014 .3101 .52631 .322 .52334 .31432 .51723 Metetra
0 1 0 r
.31432 .51723 .322 .52334 .33395 .52042 .3263 .51434 Metetra
0 1 0 r
.3263 .51434 .33395 .52042 .34596 .51754 .33834 .51148 Metetra
0 1 0 r
.33834 .51148 .34596 .51754 .35803 .51468 .35045 .50862 Metetra
0 1 0 r
.35045 .50862 .35803 .51468 .37016 .51183 .36262 .50575 Metetra
0 1 0 r
.36262 .50575 .37016 .51183 .38236 .50896 .37485 .50285 Metetra
0 1 0 r
.37485 .50285 .38236 .50896 .39462 .50607 .38715 .4999 Metetra
0 1 0 r
.38715 .4999 .39462 .50607 .40695 .50313 .39951 .49689 Metetra
0 1 0 r
.39951 .49689 .40695 .50313 .41934 .50014 .41194 .49381 Metetra
0 1 0 r
.41194 .49381 .41934 .50014 .4318 .49706 .42444 .49063 Metetra
0 1 0 r
.42444 .49063 .4318 .49706 .44432 .4939 .43701 .48734 Metetra
0 1 0 r
.43701 .48734 .44432 .4939 .45691 .49062 .44964 .48392 Metetra
0 1 0 r
.44964 .48392 .45691 .49062 .46957 .48722 .46234 .48035 Metetra
0 1 0 r
.46234 .48035 .46957 .48722 .48229 .48367 .4751 .47663 Metetra
0 1 0 r
.4751 .47663 .48229 .48367 .49508 .47996 .48793 .47272 Metetra
0 1 0 r
.48793 .47272 .49508 .47996 .50793 .47607 .50082 .46862 Metetra
0 1 0 r
.50082 .46862 .50793 .47607 .52084 .47199 .51377 .4643 Metetra
0 1 0 r
.51377 .4643 .52084 .47199 .53381 .46769 .52679 .45975 Metetra
0 1 0 r
.52679 .45975 .53381 .46769 .54684 .46316 .53986 .45496 Metetra
0 1 0 r
.53986 .45496 .54684 .46316 .55993 .45838 .55299 .44989 Metetra
0 1 0 r
.55299 .44989 .55993 .45838 .57307 .45333 .56616 .44454 Metetra
0 1 0 r
.56616 .44454 .57307 .45333 .58627 .448 .57939 .43889 Metetra
0 1 0 r
.57939 .43889 .58627 .448 .59951 .44237 .59267 .43291 Metetra
0 1 0 r
.59267 .43291 .59951 .44237 .61279 .43641 .60598 .4266 Metetra
0 1 0 r
.60598 .4266 .61279 .43641 .62611 .43011 .61933 .41993 Metetra
0 1 0 r
.61933 .41993 .62611 .43011 .63947 .42346 .63272 .41288 Metetra
0 1 0 r
.63272 .41288 .63947 .42346 .65286 .41643 .64613 .40545 Metetra
0 1 0 r
.64613 .40545 .65286 .41643 .66628 .40901 .65957 .39761 Metetra
0 1 0 r
.65957 .39761 .66628 .40901 .67971 .40118 .67303 .38934 Metetra
0 1 0 r
.67303 .38934 .67971 .40118 .69317 .39292 .68649 .38062 Metetra
0 1 0 r
.68649 .38062 .69317 .39292 .70662 .38421 .69996 .37145 Metetra
0 1 0 r
.69996 .37145 .70662 .38421 .72009 .37505 .71343 .3618 Metetra
0 1 0 r
.71343 .3618 .72009 .37505 .73354 .3654 .72689 .35166 Metetra
0 1 0 r
.72689 .35166 .73354 .3654 .74699 .35527 .74034 .34102 Metetra
0 1 0 r
.74034 .34102 .74699 .35527 .76041 .34462 .75376 .32985 Metetra
0 1 0 r
.75376 .32985 .76041 .34462 .77381 .33345 .76715 .31814 Metetra
0 1 0 r
.76715 .31814 .77381 .33345 .78717 .32174 .7805 .30589 Metetra
0 1 0 r
.7805 .30589 .78717 .32174 .80049 .30948 .7938 .29307 Metetra
0 1 0 r
.7938 .29307 .80049 .30948 .81375 .29665 .80704 .27967 Metetra
0 1 0 r
.80704 .27967 .81375 .29665 .82695 .28324 .82022 .26569 Metetra
0 1 0 r
.82022 .26569 .82695 .28324 .84008 .26924 .83332 .25111 Metetra
0 1 0 r
.20084 .53961 .20878 .54663 .22034 .54287 .21241 .53602 Metetra
0 1 0 r
.21241 .53602 .22034 .54287 .23193 .53926 .22401 .53258 Metetra
0 1 0 r
.22401 .53258 .23193 .53926 .24355 .53581 .23565 .52926 Metetra
0 1 0 r
.23565 .52926 .24355 .53581 .25522 .53248 .24734 .52606 Metetra
0 1 0 r
.24734 .52606 .25522 .53248 .26694 .52926 .25908 .52295 Metetra
0 1 0 r
.25908 .52295 .26694 .52926 .27871 .52615 .27087 .51991 Metetra
0 1 0 r
.27087 .51991 .27871 .52615 .29052 .52311 .28271 .51695 Metetra
0 1 0 r
.28271 .51695 .29052 .52311 .30239 .52014 .29461 .51403 Metetra
0 1 0 r
.29461 .51403 .30239 .52014 .31432 .51723 .30656 .51115 Metetra
0 1 0 r
.30656 .51115 .31432 .51723 .3263 .51434 .31858 .50828 Metetra
0 1 0 r
.31858 .50828 .3263 .51434 .33834 .51148 .33066 .50541 Metetra
0 1 0 r
.33066 .50541 .33834 .51148 .35045 .50862 .3428 .50253 Metetra
0 1 0 r
.3428 .50253 .35045 .50862 .36262 .50575 .355 .49962 Metetra
0 1 0 r
.355 .49962 .36262 .50575 .37485 .50285 .36727 .49667 Metetra
0 1 0 r
.36727 .49667 .37485 .50285 .38715 .4999 .37961 .49365 Metetra
0 1 0 r
.37961 .49365 .38715 .4999 .39951 .49689 .39201 .49055 Metetra
0 1 0 r
.39201 .49055 .39951 .49689 .41194 .49381 .40448 .48735 Metetra
0 1 0 r
.40448 .48735 .41194 .49381 .42444 .49063 .41702 .48405 Metetra
0 1 0 r
.41702 .48405 .42444 .49063 .43701 .48734 .42963 .48061 Metetra
0 1 0 r
.42963 .48061 .43701 .48734 .44964 .48392 .4423 .47703 Metetra
0 1 0 r
.4423 .47703 .44964 .48392 .46234 .48035 .45504 .47328 Metetra
0 1 0 r
.45504 .47328 .46234 .48035 .4751 .47663 .46785 .46936 Metetra
0 1 0 r
.46785 .46936 .4751 .47663 .48793 .47272 .48072 .46524 Metetra
0 1 0 r
.48072 .46524 .48793 .47272 .50082 .46862 .49366 .4609 Metetra
0 1 0 r
.49366 .4609 .50082 .46862 .51377 .4643 .50665 .45633 Metetra
0 1 0 r
.50665 .45633 .51377 .4643 .52679 .45975 .5197 .45151 Metetra
0 1 0 r
.5197 .45151 .52679 .45975 .53986 .45496 .53281 .44642 Metetra
0 1 0 r
.53281 .44642 .53986 .45496 .55299 .44989 .54598 .44105 Metetra
0 1 0 r
.54598 .44105 .55299 .44989 .56616 .44454 .55919 .43537 Metetra
0 1 0 r
.55919 .43537 .56616 .44454 .57939 .43889 .57246 .42938 Metetra
0 1 0 r
.57246 .42938 .57939 .43889 .59267 .43291 .58576 .42304 Metetra
0 1 0 r
.58576 .42304 .59267 .43291 .60598 .4266 .59911 .41635 Metetra
0 1 0 r
.59911 .41635 .60598 .4266 .61933 .41993 .61249 .40929 Metetra
0 1 0 r
.61249 .40929 .61933 .41993 .63272 .41288 .62591 .40184 Metetra
0 1 0 r
.62591 .40184 .63272 .41288 .64613 .40545 .63934 .39398 Metetra
0 1 0 r
.63934 .39398 .64613 .40545 .65957 .39761 .6528 .38569 Metetra
0 1 0 r
.6528 .38569 .65957 .39761 .67303 .38934 .66627 .37696 Metetra
0 1 0 r
.66627 .37696 .67303 .38934 .68649 .38062 .67976 .36778 Metetra
0 1 0 r
.67976 .36778 .68649 .38062 .69996 .37145 .69324 .35812 Metetra
0 1 0 r
.69324 .35812 .69996 .37145 .71343 .3618 .70671 .34797 Metetra
0 1 0 r
.70671 .34797 .71343 .3618 .72689 .35166 .72018 .33732 Metetra
0 1 0 r
.72018 .33732 .72689 .35166 .74034 .34102 .73362 .32615 Metetra
0 1 0 r
.73362 .32615 .74034 .34102 .75376 .32985 .74704 .31444 Metetra
0 1 0 r
.74704 .31444 .75376 .32985 .76715 .31814 .76042 .30219 Metetra
0 1 0 r
.76042 .30219 .76715 .31814 .7805 .30589 .77375 .28937 Metetra
0 1 0 r
.77375 .28937 .7805 .30589 .7938 .29307 .78703 .27599 Metetra
0 1 0 r
.78703 .27599 .7938 .29307 .80704 .27967 .80025 .26201 Metetra
0 1 0 r
.80025 .26201 .80704 .27967 .82022 .26569 .8134 .24745 Metetra
0 1 0 r
.8134 .24745 .82022 .26569 .83332 .25111 .82647 .23228 Metetra
0 1 0 r
.19281 .53277 .20084 .53961 .21241 .53602 .20439 .52935 Metetra
0 1 0 r
.20439 .52935 .21241 .53602 .22401 .53258 .21601 .52604 Metetra
0 1 0 r
.21601 .52604 .22401 .53258 .23565 .52926 .22767 .52285 Metetra
0 1 0 r
.22767 .52285 .23565 .52926 .24734 .52606 .23938 .51974 Metetra
0 1 0 r
.23938 .51974 .24734 .52606 .25908 .52295 .25114 .51672 Metetra
0 1 0 r
.25114 .51672 .25908 .52295 .27087 .51991 .26295 .51375 Metetra
0 1 0 r
.26295 .51375 .27087 .51991 .28271 .51695 .27482 .51084 Metetra
0 1 0 r
.27482 .51084 .28271 .51695 .29461 .51403 .28675 .50795 Metetra
0 1 0 r
.28675 .50795 .29461 .51403 .30656 .51115 .29873 .50508 Metetra
0 1 0 r
.29873 .50508 .30656 .51115 .31858 .50828 .31078 .50221 Metetra
0 1 0 r
.31078 .50221 .31858 .50828 .33066 .50541 .32289 .49932 Metetra
0 1 0 r
.32289 .49932 .33066 .50541 .3428 .50253 .33507 .4964 Metetra
0 1 0 r
.33507 .4964 .3428 .50253 .355 .49962 .34731 .49343 Metetra
0 1 0 r
.34731 .49343 .355 .49962 .36727 .49667 .35962 .4904 Metetra
0 1 0 r
.35962 .4904 .36727 .49667 .37961 .49365 .372 .48729 Metetra
0 1 0 r
.372 .48729 .37961 .49365 .39201 .49055 .38445 .48408 Metetra
0 1 0 r
.38445 .48408 .39201 .49055 .40448 .48735 .39696 .48075 Metetra
0 1 0 r
.39696 .48075 .40448 .48735 .41702 .48405 .40954 .4773 Metetra
0 1 0 r
.40954 .4773 .41702 .48405 .42963 .48061 .42219 .4737 Metetra
0 1 0 r
.42219 .4737 .42963 .48061 .4423 .47703 .43491 .46993 Metetra
0 1 0 r
.43491 .46993 .4423 .47703 .45504 .47328 .44769 .46598 Metetra
0 1 0 r
.44769 .46598 .45504 .47328 .46785 .46936 .46054 .46184 Metetra
0 1 0 r
.46054 .46184 .46785 .46936 .48072 .46524 .47345 .45748 Metetra
0 1 0 r
.47345 .45748 .48072 .46524 .49366 .4609 .48643 .45288 Metetra
0 1 0 r
.48643 .45288 .49366 .4609 .50665 .45633 .49947 .44804 Metetra
0 1 0 r
.49947 .44804 .50665 .45633 .5197 .45151 .51256 .44293 Metetra
0 1 0 r
.51256 .44293 .5197 .45151 .53281 .44642 .52571 .43753 Metetra
0 1 0 r
.52571 .43753 .53281 .44642 .54598 .44105 .53891 .43183 Metetra
0 1 0 r
.53891 .43183 .54598 .44105 .55919 .43537 .55217 .42581 Metetra
0 1 0 r
.55217 .42581 .55919 .43537 .57246 .42938 .56546 .41945 Metetra
0 1 0 r
.56546 .41945 .57246 .42938 .58576 .42304 .5788 .41274 Metetra
0 1 0 r
.5788 .41274 .58576 .42304 .59911 .41635 .59218 .40565 Metetra
0 1 0 r
.59218 .40565 .59911 .41635 .61249 .40929 .60559 .39817 Metetra
0 1 0 r
.60559 .39817 .61249 .40929 .62591 .40184 .61903 .39029 Metetra
0 1 0 r
.61903 .39029 .62591 .40184 .63934 .39398 .63249 .38198 Metetra
0 1 0 r
.63249 .38198 .63934 .39398 .6528 .38569 .64597 .37324 Metetra
0 1 0 r
.64597 .37324 .6528 .38569 .66627 .37696 .65946 .36403 Metetra
0 1 0 r
.65946 .36403 .66627 .37696 .67976 .36778 .67295 .35436 Metetra
0 1 0 r
.67295 .35436 .67976 .36778 .69324 .35812 .68644 .3442 Metetra
0 1 0 r
.68644 .3442 .69324 .35812 .70671 .34797 .69993 .33353 Metetra
0 1 0 r
.69993 .33353 .70671 .34797 .72018 .33732 .71339 .32235 Metetra
0 1 0 r
.71339 .32235 .72018 .33732 .73362 .32615 .72684 .31063 Metetra
0 1 0 r
.72684 .31063 .73362 .32615 .74704 .31444 .74024 .29837 Metetra
0 1 0 r
.74024 .29837 .74704 .31444 .76042 .30219 .75361 .28556 Metetra
0 1 0 r
.75361 .28556 .76042 .30219 .77375 .28937 .76693 .27217 Metetra
0 1 0 r
.76693 .27217 .77375 .28937 .78703 .27599 .78019 .2582 Metetra
0 1 0 r
.78019 .2582 .78703 .27599 .80025 .26201 .79339 .24364 Metetra
0 1 0 r
.79339 .24364 .80025 .26201 .8134 .24745 .8065 .22848 Metetra
0 1 0 r
.8065 .22848 .8134 .24745 .82647 .23228 .81953 .21271 Metetra
0 1 0 r
.1847 .52611 .19281 .53277 .20439 .52935 .19628 .52282 Metetra
0 1 0 r
.19628 .52282 .20439 .52935 .21601 .52604 .20792 .51964 Metetra
0 1 0 r
.20792 .51964 .21601 .52604 .22767 .52285 .2196 .51654 Metetra
0 1 0 r
.2196 .51654 .22767 .52285 .23938 .51974 .23133 .51352 Metetra
0 1 0 r
.23133 .51352 .23938 .51974 .25114 .51672 .24311 .51056 Metetra
0 1 0 r
.24311 .51056 .25114 .51672 .26295 .51375 .25495 .50765 Metetra
0 1 0 r
.25495 .50765 .26295 .51375 .27482 .51084 .26685 .50476 Metetra
0 1 0 r
.26685 .50476 .27482 .51084 .28675 .50795 .27881 .50189 Metetra
0 1 0 r
.27881 .50189 .28675 .50795 .29873 .50508 .29083 .49901 Metetra
0 1 0 r
.29083 .49901 .29873 .50508 .31078 .50221 .30291 .49611 Metetra
0 1 0 r
.30291 .49611 .31078 .50221 .32289 .49932 .31506 .49318 Metetra
0 1 0 r
.31506 .49318 .32289 .49932 .33507 .4964 .32728 .4902 Metetra
0 1 0 r
.32728 .4902 .33507 .4964 .34731 .49343 .33956 .48716 Metetra
0 1 0 r
.33956 .48716 .34731 .49343 .35962 .4904 .35191 .48403 Metetra
0 1 0 r
.35191 .48403 .35962 .4904 .372 .48729 .36433 .4808 Metetra
0 1 0 r
.36433 .4808 .372 .48729 .38445 .48408 .37681 .47746 Metetra
0 1 0 r
.37681 .47746 .38445 .48408 .39696 .48075 .38937 .47398 Metetra
0 1 0 r
.38937 .47398 .39696 .48075 .40954 .4773 .40199 .47036 Metetra
0 1 0 r
.40199 .47036 .40954 .4773 .42219 .4737 .41469 .46657 Metetra
0 1 0 r
.41469 .46657 .42219 .4737 .43491 .46993 .42745 .4626 Metetra
0 1 0 r
.42745 .4626 .43491 .46993 .44769 .46598 .44028 .45843 Metetra
0 1 0 r
.44028 .45843 .44769 .46598 .46054 .46184 .45317 .45404 Metetra
0 1 0 r
.45317 .45404 .46054 .46184 .47345 .45748 .46613 .44942 Metetra
0 1 0 r
.46613 .44942 .47345 .45748 .48643 .45288 .47914 .44455 Metetra
0 1 0 r
.47914 .44455 .48643 .45288 .49947 .44804 .49222 .43941 Metetra
0 1 0 r
.49222 .43941 .49947 .44804 .51256 .44293 .50536 .43398 Metetra
0 1 0 r
.50536 .43398 .51256 .44293 .52571 .43753 .51855 .42825 Metetra
0 1 0 r
.51855 .42825 .52571 .43753 .53891 .43183 .53179 .4222 Metetra
0 1 0 r
.53179 .4222 .53891 .43183 .55217 .42581 .54508 .41581 Metetra
0 1 0 r
.54508 .41581 .55217 .42581 .56546 .41945 .55841 .40907 Metetra
0 1 0 r
.55841 .40907 .56546 .41945 .5788 .41274 .57178 .40196 Metetra
0 1 0 r
.57178 .40196 .5788 .41274 .59218 .40565 .58519 .39445 Metetra
0 1 0 r
.58519 .39445 .59218 .40565 .60559 .39817 .59863 .38654 Metetra
0 1 0 r
.59863 .38654 .60559 .39817 .61903 .39029 .6121 .37821 Metetra
0 1 0 r
.6121 .37821 .61903 .39029 .63249 .38198 .62558 .36944 Metetra
0 1 0 r
.62558 .36944 .63249 .38198 .64597 .37324 .63908 .36021 Metetra
0 1 0 r
.63908 .36021 .64597 .37324 .65946 .36403 .65258 .35052 Metetra
0 1 0 r
.65258 .35052 .65946 .36403 .67295 .35436 .66609 .34033 Metetra
0 1 0 r
.66609 .34033 .67295 .35436 .68644 .3442 .67959 .32965 Metetra
0 1 0 r
.67959 .32965 .68644 .3442 .69993 .33353 .69308 .31845 Metetra
0 1 0 r
.69308 .31845 .69993 .33353 .71339 .32235 .70654 .30672 Metetra
0 1 0 r
.70654 .30672 .71339 .32235 .72684 .31063 .71998 .29445 Metetra
0 1 0 r
.71998 .29445 .72684 .31063 .74024 .29837 .73338 .28162 Metetra
0 1 0 r
.73338 .28162 .74024 .29837 .75361 .28556 .74674 .26823 Metetra
0 1 0 r
.74674 .26823 .75361 .28556 .76693 .27217 .76004 .25426 Metetra
0 1 0 r
.76004 .25426 .76693 .27217 .78019 .2582 .77327 .2397 Metetra
0 1 0 r
.77327 .2397 .78019 .2582 .79339 .24364 .78644 .22454 Metetra
0 1 0 r
.78644 .22454 .79339 .24364 .8065 .22848 .79952 .20877 Metetra
0 1 0 r
.79952 .20877 .8065 .22848 .81953 .21271 .81251 .19239 Metetra
0 1 0 r
.17648 .5196 .1847 .52611 .19628 .52282 .18809 .51643 Metetra
0 1 0 r
.18809 .51643 .19628 .52282 .20792 .51964 .19974 .51334 Metetra
0 1 0 r
.19974 .51334 .20792 .51964 .2196 .51654 .21144 .51033 Metetra
0 1 0 r
.21144 .51033 .2196 .51654 .23133 .51352 .2232 .50737 Metetra
0 1 0 r
.2232 .50737 .23133 .51352 .24311 .51056 .23501 .50446 Metetra
0 1 0 r
.23501 .50446 .24311 .51056 .25495 .50765 .24688 .50157 Metetra
0 1 0 r
.24688 .50157 .25495 .50765 .26685 .50476 .25881 .49869 Metetra
0 1 0 r
.25881 .49869 .26685 .50476 .27881 .50189 .2708 .49581 Metetra
0 1 0 r
.2708 .49581 .27881 .50189 .29083 .49901 .28285 .49291 Metetra
0 1 0 r
.28285 .49291 .29083 .49901 .30291 .49611 .29497 .48997 Metetra
0 1 0 r
.29497 .48997 .30291 .49611 .31506 .49318 .30716 .48697 Metetra
0 1 0 r
.30716 .48697 .31506 .49318 .32728 .4902 .31941 .48391 Metetra
0 1 0 r
.31941 .48391 .32728 .4902 .33956 .48716 .33173 .48077 Metetra
0 1 0 r
.33173 .48077 .33956 .48716 .35191 .48403 .34412 .47752 Metetra
0 1 0 r
.34412 .47752 .35191 .48403 .36433 .4808 .35658 .47416 Metetra
0 1 0 r
.35658 .47416 .36433 .4808 .37681 .47746 .36911 .47066 Metetra
0 1 0 r
.36911 .47066 .37681 .47746 .38937 .47398 .38172 .46701 Metetra
0 1 0 r
.38172 .46701 .38937 .47398 .40199 .47036 .39438 .4632 Metetra
0 1 0 r
.39438 .4632 .40199 .47036 .41469 .46657 .40712 .4592 Metetra
0 1 0 r
.40712 .4592 .41469 .46657 .42745 .4626 .41993 .455 Metetra
0 1 0 r
.41993 .455 .42745 .4626 .44028 .45843 .4328 .45058 Metetra
0 1 0 r
.4328 .45058 .44028 .45843 .45317 .45404 .44574 .44593 Metetra
0 1 0 r
.44574 .44593 .45317 .45404 .46613 .44942 .45874 .44103 Metetra
0 1 0 r
.45874 .44103 .46613 .44942 .47914 .44455 .4718 .43586 Metetra
0 1 0 r
.4718 .43586 .47914 .44455 .49222 .43941 .48492 .4304 Metetra
0 1 0 r
.48492 .4304 .49222 .43941 .50536 .43398 .4981 .42464 Metetra
0 1 0 r
.4981 .42464 .50536 .43398 .51855 .42825 .51133 .41856 Metetra
0 1 0 r
.51133 .41856 .51855 .42825 .53179 .4222 .52461 .41214 Metetra
0 1 0 r
.52461 .41214 .53179 .4222 .54508 .41581 .53794 .40536 Metetra
0 1 0 r
.53794 .40536 .54508 .41581 .55841 .40907 .5513 .39821 Metetra
0 1 0 r
.5513 .39821 .55841 .40907 .57178 .40196 .56471 .39068 Metetra
0 1 0 r
.56471 .39068 .57178 .40196 .58519 .39445 .57815 .38273 Metetra
0 1 0 r
.57815 .38273 .58519 .39445 .59863 .38654 .59161 .37437 Metetra
0 1 0 r
.59161 .37437 .59863 .38654 .6121 .37821 .6051 .36557 Metetra
0 1 0 r
.6051 .36557 .6121 .37821 .62558 .36944 .61861 .35631 Metetra
0 1 0 r
.61861 .35631 .62558 .36944 .63908 .36021 .63212 .34659 Metetra
0 1 0 r
.63212 .34659 .63908 .36021 .65258 .35052 .64564 .33638 Metetra
0 1 0 r
.64564 .33638 .65258 .35052 .66609 .34033 .65916 .32567 Metetra
0 1 0 r
.65916 .32567 .66609 .34033 .67959 .32965 .67267 .31445 Metetra
0 1 0 r
.67267 .31445 .67959 .32965 .69308 .31845 .68616 .3027 Metetra
0 1 0 r
.68616 .3027 .69308 .31845 .70654 .30672 .69962 .29041 Metetra
0 1 0 r
.69962 .29041 .70654 .30672 .71998 .29445 .71306 .27756 Metetra
0 1 0 r
.71306 .27756 .71998 .29445 .73338 .28162 .72645 .26415 Metetra
0 1 0 r
.72645 .26415 .73338 .28162 .74674 .26823 .73979 .25017 Metetra
0 1 0 r
.73979 .25017 .74674 .26823 .76004 .25426 .75307 .2356 Metetra
0 1 0 r
.75307 .2356 .76004 .25426 .77327 .2397 .76628 .22044 Metetra
0 1 0 r
.76628 .22044 .77327 .2397 .78644 .22454 .77942 .20467 Metetra
0 1 0 r
.77942 .20467 .78644 .22454 .79952 .20877 .79247 .1883 Metetra
0 1 0 r
.79247 .1883 .79952 .20877 .81251 .19239 .8062 .17968 Metetra
0 1 0 r
.16818 .51322 .17648 .5196 .18809 .51643 .1798 .51014 Metetra
0 1 0 r
.1798 .51014 .18809 .51643 .19974 .51334 .19148 .50714 Metetra
0 1 0 r
.19148 .50714 .19974 .51334 .21144 .51033 .2032 .50419 Metetra
0 1 0 r
.2032 .50419 .21144 .51033 .2232 .50737 .21498 .50127 Metetra
0 1 0 r
.21498 .50127 .2232 .50737 .23501 .50446 .22682 .49838 Metetra
0 1 0 r
.22682 .49838 .23501 .50446 .24688 .50157 .23872 .4955 Metetra
0 1 0 r
.23872 .4955 .24688 .50157 .25881 .49869 .25068 .49261 Metetra
0 1 0 r
.25068 .49261 .25881 .49869 .2708 .49581 .26271 .4897 Metetra
0 1 0 r
.26271 .4897 .2708 .49581 .28285 .49291 .2748 .48675 Metetra
0 1 0 r
.2748 .48675 .28285 .49291 .29497 .48997 .28695 .48374 Metetra
0 1 0 r
.28695 .48374 .29497 .48997 .30716 .48697 .29918 .48067 Metetra
0 1 0 r
.29918 .48067 .30716 .48697 .31941 .48391 .31147 .4775 Metetra
0 1 0 r
.31147 .4775 .31941 .48391 .33173 .48077 .32384 .47424 Metetra
0 1 0 r
.32384 .47424 .33173 .48077 .34412 .47752 .33627 .47085 Metetra
0 1 0 r
.33627 .47085 .34412 .47752 .35658 .47416 .34878 .46733 Metetra
0 1 0 r
.34878 .46733 .35658 .47416 .36911 .47066 .36135 .46366 Metetra
0 1 0 r
.36135 .46366 .36911 .47066 .38172 .46701 .374 .45982 Metetra
0 1 0 r
.374 .45982 .38172 .46701 .39438 .4632 .38671 .45579 Metetra
0 1 0 r
.38671 .45579 .39438 .4632 .40712 .4592 .3995 .45156 Metetra
0 1 0 r
.3995 .45156 .40712 .4592 .41993 .455 .41235 .44711 Metetra
0 1 0 r
.41235 .44711 .41993 .455 .4328 .45058 .42527 .44243 Metetra
0 1 0 r
.42527 .44243 .4328 .45058 .44574 .44593 .43825 .43749 Metetra
0 1 0 r
.43825 .43749 .44574 .44593 .45874 .44103 .4513 .43228 Metetra
0 1 0 r
.4513 .43228 .45874 .44103 .4718 .43586 .4644 .42679 Metetra
0 1 0 r
.4644 .42679 .4718 .43586 .48492 .4304 .47757 .42099 Metetra
0 1 0 r
.47757 .42099 .48492 .4304 .4981 .42464 .49079 .41487 Metetra
0 1 0 r
.49079 .41487 .4981 .42464 .51133 .41856 .50406 .40841 Metetra
0 1 0 r
.50406 .40841 .51133 .41856 .52461 .41214 .51738 .4016 Metetra
0 1 0 r
.51738 .4016 .52461 .41214 .53794 .40536 .53074 .39442 Metetra
0 1 0 r
.53074 .39442 .53794 .40536 .5513 .39821 .54414 .38684 Metetra
0 1 0 r
.54414 .38684 .5513 .39821 .56471 .39068 .55758 .37886 Metetra
0 1 0 r
.55758 .37886 .56471 .39068 .57815 .38273 .57105 .37046 Metetra
0 1 0 r
.57105 .37046 .57815 .38273 .59161 .37437 .58454 .36162 Metetra
0 1 0 r
.58454 .36162 .59161 .37437 .6051 .36557 .59805 .35233 Metetra
0 1 0 r
.59805 .35233 .6051 .36557 .61861 .35631 .61158 .34257 Metetra
0 1 0 r
.61158 .34257 .61861 .35631 .63212 .34659 .62511 .33233 Metetra
0 1 0 r
.62511 .33233 .63212 .34659 .64564 .33638 .63865 .32159 Metetra
0 1 0 r
.63865 .32159 .64564 .33638 .65916 .32567 .65217 .31034 Metetra
0 1 0 r
.65217 .31034 .65916 .32567 .67267 .31445 .66569 .29856 Metetra
0 1 0 r
.66569 .29856 .67267 .31445 .68616 .3027 .67918 .28625 Metetra
0 1 0 r
.67918 .28625 .68616 .3027 .69962 .29041 .69264 .27338 Metetra
0 1 0 r
.69264 .27338 .69962 .29041 .71306 .27756 .70607 .25995 Metetra
0 1 0 r
.70607 .25995 .71306 .27756 .72645 .26415 .71945 .24595 Metetra
0 1 0 r
.71945 .24595 .72645 .26415 .73979 .25017 .73277 .23136 Metetra
0 1 0 r
.73277 .23136 .73979 .25017 .75307 .2356 .74603 .21619 Metetra
0 1 0 r
.74603 .21619 .75307 .2356 .76628 .22044 .75922 .20041 Metetra
0 1 0 r
.75922 .20041 .76628 .22044 .77942 .20467 .77232 .18403 Metetra
0 1 0 r
.77232 .18403 .77942 .20467 .79247 .1883 .78607 .17547 Metetra
0 1 0 r
.78607 .17547 .79247 .1883 .8062 .17968 .80018 .17047 Metetra
0 1 0 r
.15979 .50695 .16818 .51322 .1798 .51014 .17143 .50395 Metetra
0 1 0 r
.17143 .50395 .1798 .51014 .19148 .50714 .18312 .501 Metetra
0 1 0 r
.18312 .501 .19148 .50714 .2032 .50419 .19487 .49809 Metetra
0 1 0 r
.19487 .49809 .2032 .50419 .21498 .50127 .20668 .4952 Metetra
0 1 0 r
.20668 .4952 .21498 .50127 .22682 .49838 .21855 .49232 Metetra
0 1 0 r
.21855 .49232 .22682 .49838 .23872 .4955 .23048 .48942 Metetra
0 1 0 r
.23048 .48942 .23872 .4955 .25068 .49261 .24248 .4865 Metetra
0 1 0 r
.24248 .4865 .25068 .49261 .26271 .4897 .25454 .48354 Metetra
0 1 0 r
.25454 .48354 .26271 .4897 .2748 .48675 .26667 .48051 Metetra
0 1 0 r
.26667 .48051 .2748 .48675 .28695 .48374 .27886 .47742 Metetra
0 1 0 r
.27886 .47742 .28695 .48374 .29918 .48067 .29113 .47424 Metetra
0 1 0 r
.29113 .47424 .29918 .48067 .31147 .4775 .30347 .47095 Metetra
0 1 0 r
.30347 .47095 .31147 .4775 .32384 .47424 .31588 .46754 Metetra
0 1 0 r
.31588 .46754 .32384 .47424 .33627 .47085 .32836 .46399 Metetra
0 1 0 r
.32836 .46399 .33627 .47085 .34878 .46733 .34091 .46029 Metetra
0 1 0 r
.34091 .46029 .34878 .46733 .36135 .46366 .35353 .45642 Metetra
0 1 0 r
.35353 .45642 .36135 .46366 .374 .45982 .36622 .45236 Metetra
0 1 0 r
.36622 .45236 .374 .45982 .38671 .45579 .37898 .4481 Metetra
0 1 0 r
.37898 .4481 .38671 .45579 .3995 .45156 .39182 .44362 Metetra
0 1 0 r
.39182 .44362 .3995 .45156 .41235 .44711 .40471 .4389 Metetra
0 1 0 r
.40471 .4389 .41235 .44711 .42527 .44243 .41768 .43392 Metetra
0 1 0 r
.41768 .43392 .42527 .44243 .43825 .43749 .43071 .42868 Metetra
0 1 0 r
.43071 .42868 .43825 .43749 .4513 .43228 .4438 .42315 Metetra
0 1 0 r
.4438 .42315 .4513 .43228 .4644 .42679 .45695 .41731 Metetra
0 1 0 r
.45695 .41731 .4644 .42679 .47757 .42099 .47016 .41115 Metetra
0 1 0 r
.47016 .41115 .47757 .42099 .49079 .41487 .48342 .40465 Metetra
0 1 0 r
.48342 .40465 .49079 .41487 .50406 .40841 .49673 .39779 Metetra
0 1 0 r
.49673 .39779 .50406 .40841 .51738 .4016 .51009 .39056 Metetra
0 1 0 r
.51009 .39056 .51738 .4016 .53074 .39442 .52349 .38295 Metetra
0 1 0 r
.52349 .38295 .53074 .39442 .54414 .38684 .53693 .37493 Metetra
0 1 0 r
.53693 .37493 .54414 .38684 .55758 .37886 .5504 .36648 Metetra
0 1 0 r
.5504 .36648 .55758 .37886 .57105 .37046 .56389 .3576 Metetra
0 1 0 r
.56389 .3576 .57105 .37046 .58454 .36162 .57741 .34827 Metetra
0 1 0 r
.57741 .34827 .58454 .36162 .59805 .35233 .59095 .33847 Metetra
0 1 0 r
.59095 .33847 .59805 .35233 .61158 .34257 .6045 .32819 Metetra
0 1 0 r
.6045 .32819 .61158 .34257 .62511 .33233 .61805 .31741 Metetra
0 1 0 r
.61805 .31741 .62511 .33233 .63865 .32159 .63159 .30613 Metetra
0 1 0 r
.63159 .30613 .63865 .32159 .65217 .31034 .64513 .29431 Metetra
0 1 0 r
.64513 .29431 .65217 .31034 .66569 .29856 .65865 .28196 Metetra
0 1 0 r
.65865 .28196 .66569 .29856 .67918 .28625 .67214 .26907 Metetra
0 1 0 r
.67214 .26907 .67918 .28625 .69264 .27338 .6856 .25561 Metetra
0 1 0 r
.6856 .25561 .69264 .27338 .70607 .25995 .69902 .24158 Metetra
0 1 0 r
.69902 .24158 .70607 .25995 .71945 .24595 .71238 .22698 Metetra
0 1 0 r
.71238 .22698 .71945 .24595 .73277 .23136 .72569 .21178 Metetra
0 1 0 r
.72569 .21178 .73277 .23136 .74603 .21619 .73893 .19599 Metetra
0 1 0 r
.73893 .19599 .74603 .21619 .75922 .20041 .75208 .17959 Metetra
0 1 0 r
.75208 .17959 .75922 .20041 .77232 .18403 .76585 .17124 Metetra
0 1 0 r
.76585 .17124 .77232 .18403 .78607 .17547 .77994 .16621 Metetra
0 1 0 r
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Metetra
0 1 0 r
.1513 .50077 .15979 .50695 .17143 .50395 .16297 .49783 Metetra
0 1 0 r
.16297 .49783 .17143 .50395 .18312 .501 .17469 .49492 Metetra
0 1 0 r
.17469 .49492 .18312 .501 .19487 .49809 .18646 .49202 Metetra
0 1 0 r
.18646 .49202 .19487 .49809 .20668 .4952 .1983 .48913 Metetra
0 1 0 r
.1983 .48913 .20668 .4952 .21855 .49232 .2102 .48623 Metetra
0 1 0 r
.2102 .48623 .21855 .49232 .23048 .48942 .22217 .4833 Metetra
0 1 0 r
.22217 .4833 .23048 .48942 .24248 .4865 .2342 .48032 Metetra
0 1 0 r
.2342 .48032 .24248 .4865 .25454 .48354 .2463 .47729 Metetra
0 1 0 r
.2463 .47729 .25454 .48354 .26667 .48051 .25847 .47418 Metetra
0 1 0 r
.25847 .47418 .26667 .48051 .27886 .47742 .27071 .47097 Metetra
0 1 0 r
.27071 .47097 .27886 .47742 .29113 .47424 .28302 .46766 Metetra
0 1 0 r
.28302 .46766 .29113 .47424 .30347 .47095 .2954 .46423 Metetra
0 1 0 r
.2954 .46423 .30347 .47095 .31588 .46754 .30785 .46065 Metetra
0 1 0 r
.30785 .46065 .31588 .46754 .32836 .46399 .32038 .45692 Metetra
0 1 0 r
.32038 .45692 .32836 .46399 .34091 .46029 .33297 .45302 Metetra
0 1 0 r
.33297 .45302 .34091 .46029 .35353 .45642 .34564 .44893 Metetra
0 1 0 r
.34564 .44893 .35353 .45642 .36622 .45236 .35839 .44463 Metetra
0 1 0 r
.35839 .44463 .36622 .45236 .37898 .4481 .3712 .44011 Metetra
0 1 0 r
.3712 .44011 .37898 .4481 .39182 .44362 .38408 .43535 Metetra
0 1 0 r
.38408 .43535 .39182 .44362 .40471 .4389 .39702 .43033 Metetra
0 1 0 r
.39702 .43033 .40471 .4389 .41768 .43392 .41004 .42504 Metetra
0 1 0 r
.41004 .42504 .41768 .43392 .43071 .42868 .42311 .41947 Metetra
0 1 0 r
.42311 .41947 .43071 .42868 .4438 .42315 .43625 .41358 Metetra
0 1 0 r
.43625 .41358 .4438 .42315 .45695 .41731 .44945 .40738 Metetra
0 1 0 r
.44945 .40738 .45695 .41731 .47016 .41115 .4627 .40083 Metetra
0 1 0 r
.4627 .40083 .47016 .41115 .48342 .40465 .476 .39393 Metetra
0 1 0 r
.476 .39393 .48342 .40465 .49673 .39779 .48936 .38665 Metetra
0 1 0 r
.48936 .38665 .49673 .39779 .51009 .39056 .50275 .37899 Metetra
0 1 0 r
.50275 .37899 .51009 .39056 .52349 .38295 .51619 .37092 Metetra
0 1 0 r
.51619 .37092 .52349 .38295 .53693 .37493 .52966 .36243 Metetra
0 1 0 r
.52966 .36243 .53693 .37493 .5504 .36648 .54316 .35351 Metetra
0 1 0 r
.54316 .35351 .5504 .36648 .56389 .3576 .55669 .34413 Metetra
0 1 0 r
.55669 .34413 .56389 .3576 .57741 .34827 .57024 .33428 Metetra
0 1 0 r
.57024 .33428 .57741 .34827 .59095 .33847 .5838 .32396 Metetra
0 1 0 r
.5838 .32396 .59095 .33847 .6045 .32819 .59736 .31313 Metetra
0 1 0 r
.59736 .31313 .6045 .32819 .61805 .31741 .61093 .3018 Metetra
0 1 0 r
.61093 .3018 .61805 .31741 .63159 .30613 .62449 .28995 Metetra
0 1 0 r
.62449 .28995 .63159 .30613 .64513 .29431 .63803 .27756 Metetra
0 1 0 r
.63803 .27756 .64513 .29431 .65865 .28196 .65155 .26463 Metetra
0 1 0 r
.65155 .26463 .65865 .28196 .67214 .26907 .66505 .25113 Metetra
0 1 0 r
.66505 .25113 .67214 .26907 .6856 .25561 .6785 .23707 Metetra
0 1 0 r
.6785 .23707 .6856 .25561 .69902 .24158 .69191 .22244 Metetra
0 1 0 r
.69191 .22244 .69902 .24158 .71238 .22698 .70526 .20721 Metetra
0 1 0 r
.70526 .20721 .71238 .22698 .72569 .21178 .71854 .19139 Metetra
0 1 0 r
.71854 .19139 .72569 .21178 .73893 .19599 .73175 .17498 Metetra
0 1 0 r
.73175 .17498 .73893 .19599 .75208 .17959 .74555 .16699 Metetra
0 1 0 r
.74555 .16699 .75208 .17959 .76585 .17124 .75962 .16195 Metetra
0 1 0 r
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Metetra
0 1 0 r
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15178 Metetra
0 1 0 r
.14273 .49465 .1513 .50077 .16297 .49783 .15441 .49175 Metetra
0 1 0 r
.15441 .49175 .16297 .49783 .17469 .49492 .16616 .48885 Metetra
0 1 0 r
.16616 .48885 .17469 .49492 .18646 .49202 .17797 .48596 Metetra
0 1 0 r
.17797 .48596 .18646 .49202 .1983 .48913 .18984 .48305 Metetra
0 1 0 r
.18984 .48305 .1983 .48913 .2102 .48623 .20177 .4801 Metetra
0 1 0 r
.20177 .4801 .2102 .48623 .22217 .4833 .21377 .47711 Metetra
0 1 0 r
.21377 .47711 .22217 .4833 .2342 .48032 .22584 .47406 Metetra
0 1 0 r
.22584 .47406 .2342 .48032 .2463 .47729 .23798 .47093 Metetra
0 1 0 r
.23798 .47093 .2463 .47729 .25847 .47418 .25019 .4677 Metetra
0 1 0 r
.25019 .4677 .25847 .47418 .27071 .47097 .26248 .46437 Metetra
0 1 0 r
.26248 .46437 .27071 .47097 .28302 .46766 .27483 .46091 Metetra
0 1 0 r
.27483 .46091 .28302 .46766 .2954 .46423 .28726 .4573 Metetra
0 1 0 r
.28726 .4573 .2954 .46423 .30785 .46065 .29976 .45354 Metetra
0 1 0 r
.29976 .45354 .30785 .46065 .32038 .45692 .31234 .4496 Metetra
0 1 0 r
.31234 .4496 .32038 .45692 .33297 .45302 .32498 .44547 Metetra
0 1 0 r
.32498 .44547 .33297 .45302 .34564 .44893 .3377 .44113 Metetra
0 1 0 r
.3377 .44113 .34564 .44893 .35839 .44463 .35049 .43657 Metetra
0 1 0 r
.35049 .43657 .35839 .44463 .3712 .44011 .36335 .43177 Metetra
0 1 0 r
.36335 .43177 .3712 .44011 .38408 .43535 .37628 .42671 Metetra
0 1 0 r
.37628 .42671 .38408 .43535 .39702 .43033 .38928 .42138 Metetra
0 1 0 r
.38928 .42138 .39702 .43033 .41004 .42504 .40234 .41575 Metetra
0 1 0 r
.40234 .41575 .41004 .42504 .42311 .41947 .41547 .40982 Metetra
0 1 0 r
.41547 .40982 .42311 .41947 .43625 .41358 .42865 .40356 Metetra
0 1 0 r
.42865 .40356 .43625 .41358 .44945 .40738 .4419 .39697 Metetra
0 1 0 r
.4419 .39697 .44945 .40738 .4627 .40083 .45519 .39001 Metetra
0 1 0 r
.45519 .39001 .4627 .40083 .476 .39393 .46854 .38269 Metetra
0 1 0 r
.46854 .38269 .476 .39393 .48936 .38665 .48193 .37497 Metetra
0 1 0 r
.48193 .37497 .48936 .38665 .50275 .37899 .49537 .36685 Metetra
0 1 0 r
.49537 .36685 .50275 .37899 .51619 .37092 .50884 .35831 Metetra
0 1 0 r
.50884 .35831 .51619 .37092 .52966 .36243 .52235 .34933 Metetra
0 1 0 r
.52235 .34933 .52966 .36243 .54316 .35351 .53589 .33989 Metetra
0 1 0 r
.53589 .33989 .54316 .35351 .55669 .34413 .54944 .33 Metetra
0 1 0 r
.54944 .33 .55669 .34413 .57024 .33428 .56301 .31962 Metetra
0 1 0 r
.56301 .31962 .57024 .33428 .5838 .32396 .5766 .30875 Metetra
0 1 0 r
.5766 .30875 .5838 .32396 .59736 .31313 .59018 .29737 Metetra
0 1 0 r
.59018 .29737 .59736 .31313 .61093 .3018 .60376 .28546 Metetra
0 1 0 r
.60376 .28546 .61093 .3018 .62449 .28995 .61733 .27303 Metetra
0 1 0 r
.61733 .27303 .62449 .28995 .63803 .27756 .63088 .26005 Metetra
0 1 0 r
.63088 .26005 .63803 .27756 .65155 .26463 .64441 .24652 Metetra
0 1 0 r
.64441 .24652 .65155 .26463 .66505 .25113 .6579 .23242 Metetra
0 1 0 r
.6579 .23242 .66505 .25113 .6785 .23707 .67134 .21774 Metetra
0 1 0 r
.67134 .21774 .6785 .23707 .69191 .22244 .68474 .20248 Metetra
0 1 0 r
.68474 .20248 .69191 .22244 .70526 .20721 .69807 .18663 Metetra
0 1 0 r
.69807 .18663 .70526 .20721 .71854 .19139 .71134 .17018 Metetra
0 1 0 r
.71134 .17018 .71854 .19139 .73175 .17498 .72516 .16272 Metetra
0 1 0 r
.72516 .16272 .73175 .17498 .74555 .16699 .73921 .15766 Metetra
0 1 0 r
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Metetra
0 1 0 r
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Metetra
0 1 0 r
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14231 Metetra
0 1 0 r
.13406 .48858 .14273 .49465 .15441 .49175 .14577 .48569 Metetra
0 1 0 r
.14577 .48569 .15441 .49175 .16616 .48885 .15755 .48279 Metetra
0 1 0 r
.15755 .48279 .16616 .48885 .17797 .48596 .16939 .47987 Metetra
0 1 0 r
.16939 .47987 .17797 .48596 .18984 .48305 .18129 .47691 Metetra
0 1 0 r
.18129 .47691 .18984 .48305 .20177 .4801 .19326 .47391 Metetra
0 1 0 r
.19326 .47391 .20177 .4801 .21377 .47711 .2053 .47084 Metetra
0 1 0 r
.2053 .47084 .21377 .47711 .22584 .47406 .21741 .46768 Metetra
0 1 0 r
.21741 .46768 .22584 .47406 .23798 .47093 .2296 .46443 Metetra
0 1 0 r
.2296 .46443 .23798 .47093 .25019 .4677 .24185 .46107 Metetra
0 1 0 r
.24185 .46107 .25019 .4677 .26248 .46437 .25418 .45758 Metetra
0 1 0 r
.25418 .45758 .26248 .46437 .27483 .46091 .26658 .45394 Metetra
0 1 0 r
.26658 .45394 .27483 .46091 .28726 .4573 .27906 .45015 Metetra
0 1 0 r
.27906 .45015 .28726 .4573 .29976 .45354 .29161 .44617 Metetra
0 1 0 r
.29161 .44617 .29976 .45354 .31234 .4496 .30424 .442 Metetra
0 1 0 r
.30424 .442 .31234 .4496 .32498 .44547 .31693 .43762 Metetra
0 1 0 r
.31693 .43762 .32498 .44547 .3377 .44113 .3297 .43302 Metetra
0 1 0 r
.3297 .43302 .3377 .44113 .35049 .43657 .34255 .42817 Metetra
0 1 0 r
.34255 .42817 .35049 .43657 .36335 .43177 .35546 .42306 Metetra
0 1 0 r
.35546 .42306 .36335 .43177 .37628 .42671 .36844 .41768 Metetra
0 1 0 r
.36844 .41768 .37628 .42671 .38928 .42138 .38149 .412 Metetra
0 1 0 r
.38149 .412 .38928 .42138 .40234 .41575 .3946 .40602 Metetra
0 1 0 r
.3946 .40602 .40234 .41575 .41547 .40982 .40777 .3997 Metetra
0 1 0 r
.40777 .3997 .41547 .40982 .42865 .40356 .42101 .39305 Metetra
0 1 0 r
.42101 .39305 .42865 .40356 .4419 .39697 .4343 .38604 Metetra
0 1 0 r
.4343 .38604 .4419 .39697 .45519 .39001 .44764 .37866 Metetra
0 1 0 r
.44764 .37866 .45519 .39001 .46854 .38269 .46103 .37088 Metetra
0 1 0 r
.46103 .37088 .46854 .38269 .48193 .37497 .47447 .3627 Metetra
0 1 0 r
.47447 .3627 .48193 .37497 .49537 .36685 .48794 .3541 Metetra
0 1 0 r
.48794 .3541 .49537 .36685 .50884 .35831 .50146 .34506 Metetra
0 1 0 r
.50146 .34506 .50884 .35831 .52235 .34933 .515 .33557 Metetra
0 1 0 r
.515 .33557 .52235 .34933 .53589 .33989 .52856 .32562 Metetra
0 1 0 r
.52856 .32562 .53589 .33989 .54944 .33 .54215 .31518 Metetra
0 1 0 r
.54215 .31518 .54944 .33 .56301 .31962 .55575 .30425 Metetra
0 1 0 r
.55575 .30425 .56301 .31962 .5766 .30875 .56935 .29281 Metetra
0 1 0 r
.56935 .29281 .5766 .30875 .59018 .29737 .58295 .28086 Metetra
0 1 0 r
.58295 .28086 .59018 .29737 .60376 .28546 .59655 .26837 Metetra
0 1 0 r
.59655 .26837 .60376 .28546 .61733 .27303 .61013 .25534 Metetra
0 1 0 r
.61013 .25534 .61733 .27303 .63088 .26005 .62368 .24175 Metetra
0 1 0 r
.62368 .24175 .63088 .26005 .64441 .24652 .63721 .22761 Metetra
0 1 0 r
.63721 .22761 .64441 .24652 .6579 .23242 .6507 .21289 Metetra
0 1 0 r
.6507 .21289 .6579 .23242 .67134 .21774 .66413 .19758 Metetra
0 1 0 r
.66413 .19758 .67134 .21774 .68474 .20248 .67752 .18169 Metetra
0 1 0 r
.67752 .18169 .68474 .20248 .69807 .18663 .69083 .16521 Metetra
0 1 0 r
.69083 .16521 .69807 .18663 .71134 .17018 .70469 .15844 Metetra
0 1 0 r
.70469 .15844 .71134 .17018 .72516 .16272 .71872 .15335 Metetra
0 1 0 r
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Metetra
0 1 0 r
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Metetra
0 1 0 r
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Metetra
0 1 0 r
.76122 .13794 .76752 .14745 .78177 .14231 .77553 .13276 Metetra
0 1 0 r
.1253 .48252 .13406 .48858 .14577 .48569 .13704 .47962 Metetra
0 1 0 r
.13704 .47962 .14577 .48569 .15755 .48279 .14885 .47669 Metetra
0 1 0 r
.14885 .47669 .15755 .48279 .16939 .47987 .16072 .47372 Metetra
0 1 0 r
.16072 .47372 .16939 .47987 .18129 .47691 .17267 .4707 Metetra
0 1 0 r
.17267 .4707 .18129 .47691 .19326 .47391 .18468 .46761 Metetra
0 1 0 r
.18468 .46761 .19326 .47391 .2053 .47084 .19676 .46444 Metetra
0 1 0 r
.19676 .46444 .2053 .47084 .21741 .46768 .20891 .46116 Metetra
0 1 0 r
.20891 .46116 .21741 .46768 .2296 .46443 .22114 .45777 Metetra
0 1 0 r
.22114 .45777 .2296 .46443 .24185 .46107 .23344 .45425 Metetra
0 1 0 r
.23344 .45425 .24185 .46107 .25418 .45758 .24582 .45058 Metetra
0 1 0 r
.24582 .45058 .25418 .45758 .26658 .45394 .25827 .44674 Metetra
0 1 0 r
.25827 .44674 .26658 .45394 .27906 .45015 .2708 .44273 Metetra
0 1 0 r
.2708 .44273 .27906 .45015 .29161 .44617 .2834 .43851 Metetra
0 1 0 r
.2834 .43851 .29161 .44617 .30424 .442 .29608 .43409 Metetra
0 1 0 r
.29608 .43409 .30424 .442 .31693 .43762 .30883 .42944 Metetra
0 1 0 r
.30883 .42944 .31693 .43762 .3297 .43302 .32165 .42454 Metetra
0 1 0 r
.32165 .42454 .3297 .43302 .34255 .42817 .33455 .41938 Metetra
0 1 0 r
.33455 .41938 .34255 .42817 .35546 .42306 .34751 .41394 Metetra
0 1 0 r
.34751 .41394 .35546 .42306 .36844 .41768 .36055 .40821 Metetra
0 1 0 r
.36055 .40821 .36844 .41768 .38149 .412 .37365 .40217 Metetra
0 1 0 r
.37365 .40217 .38149 .412 .3946 .40602 .38681 .3958 Metetra
0 1 0 r
.38681 .3958 .3946 .40602 .40777 .3997 .40004 .38908 Metetra
0 1 0 r
.40004 .38908 .40777 .3997 .42101 .39305 .41332 .38201 Metetra
0 1 0 r
.41332 .38201 .42101 .39305 .4343 .38604 .42666 .37456 Metetra
0 1 0 r
.42666 .37456 .4343 .38604 .44764 .37866 .44005 .36673 Metetra
0 1 0 r
.44005 .36673 .44764 .37866 .46103 .37088 .45348 .35848 Metetra
0 1 0 r
.45348 .35848 .46103 .37088 .47447 .3627 .46696 .34981 Metetra
0 1 0 r
.46696 .34981 .47447 .3627 .48794 .3541 .48048 .34071 Metetra
0 1 0 r
.48048 .34071 .48794 .3541 .50146 .34506 .49403 .33116 Metetra
0 1 0 r
.49403 .33116 .50146 .34506 .515 .33557 .5076 .32114 Metetra
0 1 0 r
.5076 .32114 .515 .33557 .52856 .32562 .5212 .31064 Metetra
0 1 0 r
.5212 .31064 .52856 .32562 .54215 .31518 .53481 .29964 Metetra
0 1 0 r
.53481 .29964 .54215 .31518 .55575 .30425 .54844 .28814 Metetra
0 1 0 r
.54844 .28814 .55575 .30425 .56935 .29281 .56206 .27612 Metetra
0 1 0 r
.56206 .27612 .56935 .29281 .58295 .28086 .57568 .26357 Metetra
0 1 0 r
.57568 .26357 .58295 .28086 .59655 .26837 .58929 .25049 Metetra
0 1 0 r
.58929 .25049 .59655 .26837 .61013 .25534 .60288 .23684 Metetra
0 1 0 r
.60288 .23684 .61013 .25534 .62368 .24175 .61644 .22264 Metetra
0 1 0 r
.61644 .22264 .62368 .24175 .63721 .22761 .62997 .20787 Metetra
0 1 0 r
.62997 .20787 .63721 .22761 .6507 .21289 .64345 .19251 Metetra
0 1 0 r
.64345 .19251 .6507 .21289 .66413 .19758 .65688 .17658 Metetra
0 1 0 r
.65688 .17658 .66413 .19758 .67752 .18169 .67024 .16005 Metetra
0 1 0 r
.67024 .16005 .67752 .18169 .69083 .16521 .68414 .15414 Metetra
0 1 0 r
.68414 .15414 .69083 .16521 .70469 .15844 .69814 .14903 Metetra
0 1 0 r
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Metetra
0 1 0 r
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Metetra
0 1 0 r
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Metetra
0 1 0 r
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Metetra
0 1 0 r
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Metetra
0 1 0 r
.11645 .47646 .1253 .48252 .13704 .47962 .12823 .47352 Metetra
0 1 0 r
.12823 .47352 .13704 .47962 .14885 .47669 .14007 .47054 Metetra
0 1 0 r
.14007 .47054 .14885 .47669 .16072 .47372 .15198 .4675 Metetra
0 1 0 r
.15198 .4675 .16072 .47372 .17267 .4707 .16396 .46439 Metetra
0 1 0 r
.16396 .46439 .17267 .4707 .18468 .46761 .17602 .46119 Metetra
0 1 0 r
.17602 .46119 .18468 .46761 .19676 .46444 .18814 .45789 Metetra
0 1 0 r
.18814 .45789 .19676 .46444 .20891 .46116 .20034 .45446 Metetra
0 1 0 r
.20034 .45446 .20891 .46116 .22114 .45777 .21262 .45091 Metetra
0 1 0 r
.21262 .45091 .22114 .45777 .23344 .45425 .22497 .4472 Metetra
0 1 0 r
.22497 .4472 .23344 .45425 .24582 .45058 .2374 .44332 Metetra
0 1 0 r
.2374 .44332 .24582 .45058 .25827 .44674 .2499 .43927 Metetra
0 1 0 r
.2499 .43927 .25827 .44674 .2708 .44273 .26248 .43501 Metetra
0 1 0 r
.26248 .43501 .2708 .44273 .2834 .43851 .27514 .43054 Metetra
0 1 0 r
.27514 .43054 .2834 .43851 .29608 .43409 .28787 .42583 Metetra
0 1 0 r
.28787 .42583 .29608 .43409 .30883 .42944 .30068 .42088 Metetra
0 1 0 r
.30068 .42088 .30883 .42944 .32165 .42454 .31355 .41566 Metetra
0 1 0 r
.31355 .41566 .32165 .42454 .33455 .41938 .3265 .41017 Metetra
0 1 0 r
.3265 .41017 .33455 .41938 .34751 .41394 .33953 .40438 Metetra
0 1 0 r
.33953 .40438 .34751 .41394 .36055 .40821 .35261 .39827 Metetra
0 1 0 r
.35261 .39827 .36055 .40821 .37365 .40217 .36577 .39184 Metetra
0 1 0 r
.36577 .39184 .37365 .40217 .38681 .3958 .37899 .38506 Metetra
0 1 0 r
.37899 .38506 .38681 .3958 .40004 .38908 .39226 .37792 Metetra
0 1 0 r
.39226 .37792 .40004 .38908 .41332 .38201 .4056 .3704 Metetra
0 1 0 r
.4056 .3704 .41332 .38201 .42666 .37456 .41898 .3625 Metetra
0 1 0 r
.41898 .3625 .42666 .37456 .44005 .36673 .43242 .35418 Metetra
0 1 0 r
.43242 .35418 .44005 .36673 .45348 .35848 .4459 .34544 Metetra
0 1 0 r
.4459 .34544 .45348 .35848 .46696 .34981 .45942 .33627 Metetra
0 1 0 r
.45942 .33627 .46696 .34981 .48048 .34071 .47298 .32664 Metetra
0 1 0 r
.47298 .32664 .48048 .34071 .49403 .33116 .48656 .31655 Metetra
0 1 0 r
.48656 .31655 .49403 .33116 .5076 .32114 .50017 .30598 Metetra
0 1 0 r
.50017 .30598 .5076 .32114 .5212 .31064 .5138 .29492 Metetra
0 1 0 r
.5138 .29492 .5212 .31064 .53481 .29964 .52745 .28335 Metetra
0 1 0 r
.52745 .28335 .53481 .29964 .54844 .28814 .54109 .27126 Metetra
0 1 0 r
.54109 .27126 .54844 .28814 .56206 .27612 .55474 .25864 Metetra
0 1 0 r
.55474 .25864 .56206 .27612 .57568 .26357 .56837 .24549 Metetra
0 1 0 r
.56837 .24549 .57568 .26357 .58929 .25049 .58199 .23178 Metetra
0 1 0 r
.58199 .23178 .58929 .25049 .60288 .23684 .59559 .21751 Metetra
0 1 0 r
.59559 .21751 .60288 .23684 .61644 .22264 .60916 .20268 Metetra
0 1 0 r
.60916 .20268 .61644 .22264 .62997 .20787 .62268 .18727 Metetra
0 1 0 r
.62268 .18727 .62997 .20787 .64345 .19251 .63615 .17128 Metetra
0 1 0 r
.63615 .17128 .64345 .19251 .65688 .17658 .64958 .15492 Metetra
0 1 0 r
.64958 .15492 .65688 .17658 .67024 .16005 .6635 .14982 Metetra
0 1 0 r
.6635 .14982 .67024 .16005 .68414 .15414 .67748 .14469 Metetra
0 1 0 r
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Metetra
0 1 0 r
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Metetra
0 1 0 r
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Metetra
0 1 0 r
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Metetra
0 1 0 r
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Metetra
0 1 0 r
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Metetra
0 1 0 r
.10752 .47035 .11645 .47646 .12823 .47352 .11933 .46736 Metetra
0 1 0 r
.11933 .46736 .12823 .47352 .14007 .47054 .13121 .4643 Metetra
0 1 0 r
.13121 .4643 .14007 .47054 .15198 .4675 .14316 .46117 Metetra
0 1 0 r
.14316 .46117 .15198 .4675 .16396 .46439 .15519 .45794 Metetra
0 1 0 r
.15519 .45794 .16396 .46439 .17602 .46119 .16729 .45461 Metetra
0 1 0 r
.16729 .45461 .17602 .46119 .18814 .45789 .17946 .45115 Metetra
0 1 0 r
.17946 .45115 .18814 .45789 .20034 .45446 .19171 .44756 Metetra
0 1 0 r
.19171 .44756 .20034 .45446 .21262 .45091 .20403 .44381 Metetra
0 1 0 r
.20403 .44381 .21262 .45091 .22497 .4472 .21644 .43989 Metetra
0 1 0 r
.21644 .43989 .22497 .4472 .2374 .44332 .22892 .43579 Metetra
0 1 0 r
.22892 .43579 .2374 .44332 .2499 .43927 .24148 .43148 Metetra
0 1 0 r
.24148 .43148 .2499 .43927 .26248 .43501 .25411 .42696 Metetra
0 1 0 r
.25411 .42696 .26248 .43501 .27514 .43054 .26682 .4222 Metetra
0 1 0 r
.26682 .4222 .27514 .43054 .28787 .42583 .27961 .41719 Metetra
0 1 0 r
.27961 .41719 .28787 .42583 .30068 .42088 .29247 .41191 Metetra
0 1 0 r
.29247 .41191 .30068 .42088 .31355 .41566 .30541 .40635 Metetra
0 1 0 r
.30541 .40635 .31355 .41566 .3265 .41017 .31842 .4005 Metetra
0 1 0 r
.31842 .4005 .3265 .41017 .33953 .40438 .3315 .39432 Metetra
0 1 0 r
.3315 .39432 .33953 .40438 .35261 .39827 .34464 .38782 Metetra
0 1 0 r
.34464 .38782 .35261 .39827 .36577 .39184 .35785 .38097 Metetra
0 1 0 r
.35785 .38097 .36577 .39184 .37899 .38506 .37112 .37376 Metetra
0 1 0 r
.37112 .37376 .37899 .38506 .39226 .37792 .38445 .36617 Metetra
0 1 0 r
.38445 .36617 .39226 .37792 .4056 .3704 .39784 .35819 Metetra
0 1 0 r
.39784 .35819 .4056 .3704 .41898 .3625 .41127 .3498 Metetra
0 1 0 r
.41127 .3498 .41898 .3625 .43242 .35418 .42476 .34099 Metetra
0 1 0 r
.42476 .34099 .43242 .35418 .4459 .34544 .43828 .33173 Metetra
0 1 0 r
.43828 .33173 .4459 .34544 .45942 .33627 .45185 .32203 Metetra
0 1 0 r
.45185 .32203 .45942 .33627 .47298 .32664 .46545 .31186 Metetra
0 1 0 r
.46545 .31186 .47298 .32664 .48656 .31655 .47907 .30121 Metetra
0 1 0 r
.47907 .30121 .48656 .31655 .50017 .30598 .49272 .29007 Metetra
0 1 0 r
.49272 .29007 .50017 .30598 .5138 .29492 .50638 .27842 Metetra
0 1 0 r
.50638 .27842 .5138 .29492 .52745 .28335 .52005 .26626 Metetra
0 1 0 r
.52005 .26626 .52745 .28335 .54109 .27126 .53372 .25357 Metetra
0 1 0 r
.53372 .25357 .54109 .27126 .55474 .25864 .54738 .24034 Metetra
0 1 0 r
.54738 .24034 .55474 .25864 .56837 .24549 .56103 .22656 Metetra
0 1 0 r
.56103 .22656 .56837 .24549 .58199 .23178 .57467 .21222 Metetra
0 1 0 r
.57467 .21222 .58199 .23178 .59559 .21751 .58827 .19732 Metetra
0 1 0 r
.58827 .19732 .59559 .21751 .60916 .20268 .60183 .18184 Metetra
0 1 0 r
.60183 .18184 .60916 .20268 .62268 .18727 .61536 .16579 Metetra
0 1 0 r
.61536 .16579 .62268 .18727 .63615 .17128 .62887 .1506 Metetra
0 1 0 r
.62887 .1506 .63615 .17128 .64958 .15492 .64277 .14548 Metetra
0 1 0 r
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Metetra
0 1 0 r
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Metetra
0 1 0 r
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Metetra
0 1 0 r
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Metetra
0 1 0 r
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Metetra
0 1 0 r
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Metetra
0 1 0 r
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Metetra
0 1 0 r
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Metetra
0 1 0 r
.0985 .46418 .10752 .47035 .11933 .46736 .11035 .4611 Metetra
0 1 0 r
.11035 .4611 .11933 .46736 .13121 .4643 .12227 .45794 Metetra
0 1 0 r
.12227 .45794 .13121 .4643 .14316 .46117 .13427 .45469 Metetra
0 1 0 r
.13427 .45469 .14316 .46117 .15519 .45794 .14634 .45132 Metetra
0 1 0 r
.14634 .45132 .15519 .45794 .16729 .45461 .15848 .44783 Metetra
0 1 0 r
.15848 .44783 .16729 .45461 .17946 .45115 .17071 .4442 Metetra
0 1 0 r
.17071 .4442 .17946 .45115 .19171 .44756 .18301 .44041 Metetra
0 1 0 r
.18301 .44041 .19171 .44756 .20403 .44381 .19539 .43645 Metetra
0 1 0 r
.19539 .43645 .20403 .44381 .21644 .43989 .20785 .43229 Metetra
0 1 0 r
.20785 .43229 .21644 .43989 .22892 .43579 .22038 .42793 Metetra
0 1 0 r
.22038 .42793 .22892 .43579 .24148 .43148 .233 .42335 Metetra
0 1 0 r
.233 .42335 .24148 .43148 .25411 .42696 .24569 .41853 Metetra
0 1 0 r
.24569 .41853 .25411 .42696 .26682 .4222 .25846 .41346 Metetra
0 1 0 r
.25846 .41346 .26682 .4222 .27961 .41719 .27131 .40812 Metetra
0 1 0 r
.27131 .40812 .27961 .41719 .29247 .41191 .28423 .4025 Metetra
0 1 0 r
.28423 .4025 .29247 .41191 .30541 .40635 .29723 .39657 Metetra
0 1 0 r
.29723 .39657 .30541 .40635 .31842 .4005 .31029 .39033 Metetra
0 1 0 r
.31029 .39033 .31842 .4005 .3315 .39432 .32343 .38375 Metetra
0 1 0 r
.32343 .38375 .3315 .39432 .34464 .38782 .33663 .37683 Metetra
0 1 0 r
.33663 .37683 .34464 .38782 .35785 .38097 .3499 .36954 Metetra
0 1 0 r
.3499 .36954 .35785 .38097 .37112 .37376 .36323 .36187 Metetra
0 1 0 r
.36323 .36187 .37112 .37376 .38445 .36617 .37661 .3538 Metetra
0 1 0 r
.37661 .3538 .38445 .36617 .39784 .35819 .39005 .34533 Metetra
0 1 0 r
.39005 .34533 .39784 .35819 .41127 .3498 .40354 .33643 Metetra
0 1 0 r
.40354 .33643 .41127 .3498 .42476 .34099 .41707 .3271 Metetra
0 1 0 r
.41707 .3271 .42476 .34099 .43828 .33173 .43064 .31731 Metetra
0 1 0 r
.43064 .31731 .43828 .33173 .45185 .32203 .44425 .30705 Metetra
0 1 0 r
.44425 .30705 .45185 .32203 .46545 .31186 .45789 .29632 Metetra
0 1 0 r
.45789 .29632 .46545 .31186 .47907 .30121 .47155 .28509 Metetra
0 1 0 r
.47155 .28509 .47907 .30121 .49272 .29007 .48523 .27336 Metetra
0 1 0 r
.48523 .27336 .49272 .29007 .50638 .27842 .49892 .26112 Metetra
0 1 0 r
.49892 .26112 .50638 .27842 .52005 .26626 .51262 .24834 Metetra
0 1 0 r
.51262 .24834 .52005 .26626 .53372 .25357 .52631 .23503 Metetra
0 1 0 r
.52631 .23503 .53372 .25357 .54738 .24034 .54 .22117 Metetra
0 1 0 r
.54 .22117 .54738 .24034 .56103 .22656 .55366 .20676 Metetra
0 1 0 r
.55366 .20676 .56103 .22656 .57467 .21222 .56731 .19178 Metetra
0 1 0 r
.56731 .19178 .57467 .21222 .58827 .19732 .58092 .17623 Metetra
0 1 0 r
.58092 .17623 .58827 .19732 .60183 .18184 .59448 .1601 Metetra
0 1 0 r
.59448 .1601 .60183 .18184 .61536 .16579 .60808 .14627 Metetra
0 1 0 r
.60808 .14627 .61536 .16579 .62887 .1506 .62195 .14112 Metetra
0 1 0 r
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Metetra
0 1 0 r
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Metetra
0 1 0 r
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Metetra
0 1 0 r
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Metetra
0 1 0 r
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Metetra
0 1 0 r
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Metetra
0 1 0 r
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Metetra
0 1 0 r
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Metetra
0 1 0 r
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Metetra
0 1 0 r
.0894 .4579 .0985 .46418 .11035 .4611 .10129 .45472 Metetra
0 1 0 r
.10129 .45472 .11035 .4611 .12227 .45794 .11326 .45144 Metetra
0 1 0 r
.11326 .45144 .12227 .45794 .13427 .45469 .1253 .44804 Metetra
0 1 0 r
.1253 .44804 .13427 .45469 .14634 .45132 .13742 .44451 Metetra
0 1 0 r
.13742 .44451 .14634 .45132 .15848 .44783 .14962 .44083 Metetra
0 1 0 r
.14962 .44083 .15848 .44783 .17071 .4442 .1619 .437 Metetra
0 1 0 r
.1619 .437 .17071 .4442 .18301 .44041 .17425 .43298 Metetra
0 1 0 r
.17425 .43298 .18301 .44041 .19539 .43645 .18669 .42878 Metetra
0 1 0 r
.18669 .42878 .19539 .43645 .20785 .43229 .1992 .42436 Metetra
0 1 0 r
.1992 .42436 .20785 .43229 .22038 .42793 .2118 .41972 Metetra
0 1 0 r
.2118 .41972 .22038 .42793 .233 .42335 .22448 .41484 Metetra
0 1 0 r
.22448 .41484 .233 .42335 .24569 .41853 .23723 .4097 Metetra
0 1 0 r
.23723 .4097 .24569 .41853 .25846 .41346 .25006 .40429 Metetra
0 1 0 r
.25006 .40429 .25846 .41346 .27131 .40812 .26297 .3986 Metetra
0 1 0 r
.26297 .3986 .27131 .40812 .28423 .4025 .27595 .39259 Metetra
0 1 0 r
.27595 .39259 .28423 .4025 .29723 .39657 .28901 .38627 Metetra
0 1 0 r
.28901 .38627 .29723 .39657 .31029 .39033 .30214 .37962 Metetra
0 1 0 r
.30214 .37962 .31029 .39033 .32343 .38375 .31533 .37261 Metetra
0 1 0 r
.31533 .37261 .32343 .38375 .33663 .37683 .3286 .36524 Metetra
0 1 0 r
.3286 .36524 .33663 .37683 .3499 .36954 .34192 .35748 Metetra
0 1 0 r
.34192 .35748 .3499 .36954 .36323 .36187 .35531 .34933 Metetra
0 1 0 r
.35531 .34933 .36323 .36187 .37661 .3538 .36875 .34077 Metetra
0 1 0 r
.36875 .34077 .37661 .3538 .39005 .34533 .38224 .33179 Metetra
0 1 0 r
.38224 .33179 .39005 .34533 .40354 .33643 .39578 .32236 Metetra
0 1 0 r
.39578 .32236 .40354 .33643 .41707 .3271 .40936 .31248 Metetra
0 1 0 r
.40936 .31248 .41707 .3271 .43064 .31731 .42298 .30213 Metetra
0 1 0 r
.42298 .30213 .43064 .31731 .44425 .30705 .43663 .29131 Metetra
0 1 0 r
.43663 .29131 .44425 .30705 .45789 .29632 .45031 .27999 Metetra
0 1 0 r
.45031 .27999 .45789 .29632 .47155 .28509 .46401 .26817 Metetra
0 1 0 r
.46401 .26817 .47155 .28509 .48523 .27336 .47773 .25583 Metetra
0 1 0 r
.47773 .25583 .48523 .27336 .49892 .26112 .49145 .24296 Metetra
0 1 0 r
.49145 .24296 .49892 .26112 .51262 .24834 .50517 .22956 Metetra
0 1 0 r
.50517 .22956 .51262 .24834 .52631 .23503 .51889 .21562 Metetra
0 1 0 r
.51889 .21562 .52631 .23503 .54 .22117 .53259 .20112 Metetra
0 1 0 r
.53259 .20112 .54 .22117 .55366 .20676 .54627 .18605 Metetra
0 1 0 r
.54627 .18605 .55366 .20676 .56731 .19178 .55993 .17042 Metetra
0 1 0 r
.55993 .17042 .56731 .19178 .58092 .17623 .57354 .15422 Metetra
0 1 0 r
.57354 .15422 .58092 .17623 .59448 .1601 .5872 .14192 Metetra
0 1 0 r
.5872 .14192 .59448 .1601 .60808 .14627 .60105 .13675 Metetra
0 1 0 r
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Metetra
0 1 0 r
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Metetra
0 1 0 r
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Metetra
0 1 0 r
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Metetra
0 1 0 r
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Metetra
0 1 0 r
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Metetra
0 1 0 r
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Metetra
0 1 0 r
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Metetra
0 1 0 r
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Metetra
0 1 0 r
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Metetra
0 1 0 r
.08022 .45149 .0894 .4579 .10129 .45472 .09216 .44818 Metetra
0 1 0 r
.09216 .44818 .10129 .45472 .11326 .45144 .10418 .44474 Metetra
0 1 0 r
.10418 .44474 .11326 .45144 .1253 .44804 .11627 .44117 Metetra
0 1 0 r
.11627 .44117 .1253 .44804 .13742 .44451 .12844 .43745 Metetra
0 1 0 r
.12844 .43745 .13742 .44451 .14962 .44083 .14069 .43357 Metetra
0 1 0 r
.14069 .43357 .14962 .44083 .1619 .437 .15303 .4295 Metetra
0 1 0 r
.15303 .4295 .1619 .437 .17425 .43298 .16544 .42524 Metetra
0 1 0 r
.16544 .42524 .17425 .43298 .18669 .42878 .17794 .42076 Metetra
0 1 0 r
.17794 .42076 .18669 .42878 .1992 .42436 .19052 .41606 Metetra
0 1 0 r
.19052 .41606 .1992 .42436 .2118 .41972 .20317 .41111 Metetra
0 1 0 r
.20317 .41111 .2118 .41972 .22448 .41484 .21591 .4059 Metetra
0 1 0 r
.21591 .4059 .22448 .41484 .23723 .4097 .22873 .40042 Metetra
0 1 0 r
.22873 .40042 .23723 .4097 .25006 .40429 .24162 .39464 Metetra
0 1 0 r
.24162 .39464 .25006 .40429 .26297 .3986 .2546 .38856 Metetra
0 1 0 r
.2546 .38856 .26297 .3986 .27595 .39259 .26764 .38216 Metetra
0 1 0 r
.26764 .38216 .27595 .39259 .28901 .38627 .28076 .37542 Metetra
0 1 0 r
.28076 .37542 .28901 .38627 .30214 .37962 .29396 .36833 Metetra
0 1 0 r
.29396 .36833 .30214 .37962 .31533 .37261 .30721 .36086 Metetra
0 1 0 r
.30721 .36086 .31533 .37261 .3286 .36524 .32054 .35302 Metetra
0 1 0 r
.32054 .35302 .3286 .36524 .34192 .35748 .33392 .34477 Metetra
0 1 0 r
.33392 .34477 .34192 .35748 .35531 .34933 .34737 .33612 Metetra
0 1 0 r
.34737 .33612 .35531 .34933 .36875 .34077 .36086 .32704 Metetra
0 1 0 r
.36086 .32704 .36875 .34077 .38224 .33179 .37441 .31751 Metetra
0 1 0 r
.37441 .31751 .38224 .33179 .39578 .32236 .388 .30753 Metetra
0 1 0 r
.388 .30753 .39578 .32236 .40936 .31248 .40164 .29709 Metetra
0 1 0 r
.40164 .29709 .40936 .31248 .42298 .30213 .41531 .28616 Metetra
0 1 0 r
.41531 .28616 .42298 .30213 .43663 .29131 .429 .27475 Metetra
0 1 0 r
.429 .27475 .43663 .29131 .45031 .27999 .44272 .26282 Metetra
0 1 0 r
.44272 .26282 .45031 .27999 .46401 .26817 .45646 .25039 Metetra
0 1 0 r
.45646 .25039 .46401 .26817 .47773 .25583 .47021 .23743 Metetra
0 1 0 r
.47021 .23743 .47773 .25583 .49145 .24296 .48396 .22393 Metetra
0 1 0 r
.48396 .22393 .49145 .24296 .50517 .22956 .49771 .20989 Metetra
0 1 0 r
.49771 .20989 .50517 .22956 .51889 .21562 .51145 .19529 Metetra
0 1 0 r
.51145 .19529 .51889 .21562 .53259 .20112 .52517 .18014 Metetra
0 1 0 r
.52517 .18014 .53259 .20112 .54627 .18605 .53887 .16442 Metetra
0 1 0 r
.53887 .16442 .54627 .18605 .55993 .17042 .55253 .14812 Metetra
0 1 0 r
.55253 .14812 .55993 .17042 .57354 .15422 .56623 .13755 Metetra
0 1 0 r
.56623 .13755 .57354 .15422 .5872 .14192 .58006 .13236 Metetra
0 1 0 r
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Metetra
0 1 0 r
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Metetra
0 1 0 r
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Metetra
0 1 0 r
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Metetra
0 1 0 r
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Metetra
0 1 0 r
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Metetra
0 1 0 r
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Metetra
0 1 0 r
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Metetra
0 1 0 r
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Metetra
0 1 0 r
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Metetra
0 1 0 r
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Metetra
0 1 0 r
.07097 .44492 .08022 .45149 .09216 .44818 .08296 .44144 Metetra
0 1 0 r
.08296 .44144 .09216 .44818 .10418 .44474 .09503 .43783 Metetra
0 1 0 r
.09503 .43783 .10418 .44474 .11627 .44117 .10718 .43406 Metetra
0 1 0 r
.10718 .43406 .11627 .44117 .12844 .43745 .1194 .43012 Metetra
0 1 0 r
.1194 .43012 .12844 .43745 .14069 .43357 .13172 .426 Metetra
0 1 0 r
.13172 .426 .14069 .43357 .15303 .4295 .14411 .42167 Metetra
0 1 0 r
.14411 .42167 .15303 .4295 .16544 .42524 .15658 .41713 Metetra
0 1 0 r
.15658 .41713 .16544 .42524 .17794 .42076 .16914 .41236 Metetra
0 1 0 r
.16914 .41236 .17794 .42076 .19052 .41606 .18178 .40734 Metetra
0 1 0 r
.18178 .40734 .19052 .41606 .20317 .41111 .19451 .40206 Metetra
0 1 0 r
.19451 .40206 .20317 .41111 .21591 .4059 .20731 .3965 Metetra
0 1 0 r
.20731 .3965 .21591 .4059 .22873 .40042 .2202 .39064 Metetra
0 1 0 r
.2202 .39064 .22873 .40042 .24162 .39464 .23316 .38448 Metetra
0 1 0 r
.23316 .38448 .24162 .39464 .2546 .38856 .2462 .37798 Metetra
0 1 0 r
.2462 .37798 .2546 .38856 .26764 .38216 .25931 .37115 Metetra
0 1 0 r
.25931 .37115 .26764 .38216 .28076 .37542 .2725 .36397 Metetra
0 1 0 r
.2725 .36397 .28076 .37542 .29396 .36833 .28575 .35641 Metetra
0 1 0 r
.28575 .35641 .29396 .36833 .30721 .36086 .29908 .34846 Metetra
0 1 0 r
.29908 .34846 .30721 .36086 .32054 .35302 .31246 .34012 Metetra
0 1 0 r
.31246 .34012 .32054 .35302 .33392 .34477 .32591 .33136 Metetra
0 1 0 r
.32591 .33136 .33392 .34477 .34737 .33612 .33942 .32218 Metetra
0 1 0 r
.33942 .32218 .34737 .33612 .36086 .32704 .35297 .31255 Metetra
0 1 0 r
.35297 .31255 .36086 .32704 .37441 .31751 .36658 .30247 Metetra
0 1 0 r
.36658 .30247 .37441 .31751 .388 .30753 .38022 .29192 Metetra
0 1 0 r
.38022 .29192 .388 .30753 .40164 .29709 .39391 .28088 Metetra
0 1 0 r
.39391 .28088 .40164 .29709 .41531 .28616 .40762 .26936 Metetra
0 1 0 r
.40762 .26936 .41531 .28616 .429 .27475 .42136 .25733 Metetra
0 1 0 r
.42136 .25733 .429 .27475 .44272 .26282 .43513 .24479 Metetra
0 1 0 r
.43513 .24479 .44272 .26282 .45646 .25039 .4489 .23172 Metetra
0 1 0 r
.4489 .23172 .45646 .25039 .47021 .23743 .46269 .21812 Metetra
0 1 0 r
.46269 .21812 .47021 .23743 .48396 .22393 .47647 .20398 Metetra
0 1 0 r
.47647 .20398 .48396 .22393 .49771 .20989 .49025 .18928 Metetra
0 1 0 r
.49025 .18928 .49771 .20989 .51145 .19529 .50401 .17403 Metetra
0 1 0 r
.50401 .17403 .51145 .19529 .52517 .18014 .51774 .15821 Metetra
0 1 0 r
.51774 .15821 .52517 .18014 .53887 .16442 .53145 .14182 Metetra
0 1 0 r
.53145 .14182 .53887 .16442 .55253 .14812 .54517 .13316 Metetra
0 1 0 r
.54517 .13316 .55253 .14812 .56623 .13755 .55897 .12795 Metetra
0 1 0 r
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Metetra
0 1 0 r
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Metetra
0 1 0 r
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Metetra
0 1 0 r
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Metetra
0 1 0 r
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Metetra
0 1 0 r
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Metetra
0 1 0 r
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Metetra
0 1 0 r
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Metetra
0 1 0 r
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Metetra
0 1 0 r
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Metetra
0 1 0 r
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Metetra
0 1 0 r
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Metetra
0 1 0 r
.06165 .43813 .07097 .44492 .08296 .44144 .0737 .43447 Metetra
0 1 0 r
.0737 .43447 .08296 .44144 .09503 .43783 .08582 .43065 Metetra
0 1 0 r
.08582 .43065 .09503 .43783 .10718 .43406 .09802 .42665 Metetra
0 1 0 r
.09802 .42665 .10718 .43406 .1194 .43012 .11031 .42247 Metetra
0 1 0 r
.11031 .42247 .1194 .43012 .13172 .426 .12269 .41808 Metetra
0 1 0 r
.12269 .41808 .13172 .426 .14411 .42167 .13514 .41347 Metetra
0 1 0 r
.13514 .41347 .14411 .42167 .15658 .41713 .14769 .40863 Metetra
0 1 0 r
.14769 .40863 .15658 .41713 .16914 .41236 .16031 .40353 Metetra
0 1 0 r
.16031 .40353 .16914 .41236 .18178 .40734 .17302 .39817 Metetra
0 1 0 r
.17302 .39817 .18178 .40734 .19451 .40206 .18581 .39252 Metetra
0 1 0 r
.18581 .39252 .19451 .40206 .20731 .3965 .19868 .38658 Metetra
0 1 0 r
.19868 .38658 .20731 .3965 .2202 .39064 .21164 .38032 Metetra
0 1 0 r
.21164 .38032 .2202 .39064 .23316 .38448 .22467 .37374 Metetra
0 1 0 r
.22467 .37374 .23316 .38448 .2462 .37798 .23778 .36681 Metetra
0 1 0 r
.23778 .36681 .2462 .37798 .25931 .37115 .25096 .35952 Metetra
0 1 0 r
.25096 .35952 .25931 .37115 .2725 .36397 .26422 .35186 Metetra
0 1 0 r
.26422 .35186 .2725 .36397 .28575 .35641 .27754 .34382 Metetra
0 1 0 r
.27754 .34382 .28575 .35641 .29908 .34846 .29093 .33537 Metetra
0 1 0 r
.29093 .33537 .29908 .34846 .31246 .34012 .30438 .3265 Metetra
0 1 0 r
.30438 .3265 .31246 .34012 .32591 .33136 .31789 .31721 Metetra
0 1 0 r
.31789 .31721 .32591 .33136 .33942 .32218 .33146 .30747 Metetra
0 1 0 r
.33146 .30747 .33942 .32218 .35297 .31255 .34508 .29727 Metetra
0 1 0 r
.34508 .29727 .35297 .31255 .36658 .30247 .35874 .28661 Metetra
0 1 0 r
.35874 .28661 .36658 .30247 .38022 .29192 .37244 .27546 Metetra
0 1 0 r
.37244 .27546 .38022 .29192 .39391 .28088 .38617 .26382 Metetra
0 1 0 r
.38617 .26382 .39391 .28088 .40762 .26936 .39994 .25168 Metetra
0 1 0 r
.39994 .25168 .40762 .26936 .42136 .25733 .41373 .23902 Metetra
0 1 0 r
.41373 .23902 .42136 .25733 .43513 .24479 .42753 .22584 Metetra
0 1 0 r
.42753 .22584 .43513 .24479 .4489 .23172 .44135 .21213 Metetra
0 1 0 r
.44135 .21213 .4489 .23172 .46269 .21812 .45516 .19787 Metetra
0 1 0 r
.45516 .19787 .46269 .21812 .47647 .20398 .46898 .18307 Metetra
0 1 0 r
.46898 .18307 .47647 .20398 .49025 .18928 .48278 .16771 Metetra
0 1 0 r
.48278 .16771 .49025 .18928 .50401 .17403 .49656 .15178 Metetra
0 1 0 r
.49656 .15178 .50401 .17403 .51774 .15821 .51031 .13529 Metetra
0 1 0 r
.51031 .13529 .51774 .15821 .53145 .14182 .52403 .12875 Metetra
0 1 0 r
.52403 .12875 .53145 .14182 .54517 .13316 .5378 .12352 Metetra
0 1 0 r
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Metetra
0 1 0 r
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Metetra
0 1 0 r
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Metetra
0 1 0 r
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Metetra
0 1 0 r
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Metetra
0 1 0 r
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Metetra
0 1 0 r
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Metetra
0 1 0 r
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Metetra
0 1 0 r
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Metetra
0 1 0 r
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Metetra
0 1 0 r
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Metetra
0 1 0 r
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Metetra
0 1 0 r
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Metetra
0 1 0 r
.05227 .4311 .06165 .43813 .0737 .43447 .06437 .42722 Metetra
0 1 0 r
.06437 .42722 .0737 .43447 .08582 .43065 .07656 .42317 Metetra
0 1 0 r
.07656 .42317 .08582 .43065 .09802 .42665 .08882 .41892 Metetra
0 1 0 r
.08882 .41892 .09802 .42665 .11031 .42247 .10118 .41446 Metetra
0 1 0 r
.10118 .41446 .11031 .42247 .12269 .41808 .11362 .40978 Metetra
0 1 0 r
.11362 .40978 .12269 .41808 .13514 .41347 .12614 .40486 Metetra
0 1 0 r
.12614 .40486 .13514 .41347 .14769 .40863 .13875 .39968 Metetra
0 1 0 r
.13875 .39968 .14769 .40863 .16031 .40353 .15145 .39423 Metetra
0 1 0 r
.15145 .39423 .16031 .40353 .17302 .39817 .16423 .3885 Metetra
0 1 0 r
.16423 .3885 .17302 .39817 .18581 .39252 .17709 .38246 Metetra
0 1 0 r
.17709 .38246 .18581 .39252 .19868 .38658 .19004 .37611 Metetra
0 1 0 r
.19004 .37611 .19868 .38658 .21164 .38032 .20306 .36942 Metetra
0 1 0 r
.20306 .36942 .21164 .38032 .22467 .37374 .21617 .36239 Metetra
0 1 0 r
.21617 .36239 .22467 .37374 .23778 .36681 .22935 .355 Metetra
0 1 0 r
.22935 .355 .23778 .36681 .25096 .35952 .2426 .34723 Metetra
0 1 0 r
.2426 .34723 .25096 .35952 .26422 .35186 .25593 .33907 Metetra
0 1 0 r
.25593 .33907 .26422 .35186 .27754 .34382 .26932 .33051 Metetra
0 1 0 r
.26932 .33051 .27754 .34382 .29093 .33537 .28278 .32153 Metetra
0 1 0 r
.28278 .32153 .29093 .33537 .30438 .3265 .2963 .31212 Metetra
0 1 0 r
.2963 .31212 .30438 .3265 .31789 .31721 .30988 .30226 Metetra
0 1 0 r
.30988 .30226 .31789 .31721 .33146 .30747 .32351 .29194 Metetra
0 1 0 r
.32351 .29194 .33146 .30747 .34508 .29727 .33719 .28116 Metetra
0 1 0 r
.33719 .28116 .34508 .29727 .35874 .28661 .35091 .26989 Metetra
0 1 0 r
.35091 .26989 .35874 .28661 .37244 .27546 .36466 .25813 Metetra
0 1 0 r
.36466 .25813 .37244 .27546 .38617 .26382 .37845 .24587 Metetra
0 1 0 r
.37845 .24587 .38617 .26382 .39994 .25168 .39227 .23309 Metetra
0 1 0 r
.39227 .23309 .39994 .25168 .41373 .23902 .4061 .21978 Metetra
0 1 0 r
.4061 .21978 .41373 .23902 .42753 .22584 .41995 .20595 Metetra
0 1 0 r
.41995 .20595 .42753 .22584 .44135 .21213 .4338 .19158 Metetra
0 1 0 r
.4338 .19158 .44135 .21213 .45516 .19787 .44765 .17665 Metetra
0 1 0 r
.44765 .17665 .45516 .19787 .46898 .18307 .46149 .16117 Metetra
0 1 0 r
.46149 .16117 .46898 .18307 .48278 .16771 .47532 .14514 Metetra
0 1 0 r
.47532 .14514 .48278 .16771 .49656 .15178 .48911 .12955 Metetra
0 1 0 r
.48911 .12955 .49656 .15178 .51031 .13529 .50279 .12432 Metetra
0 1 0 r
.50279 .12432 .51031 .13529 .52403 .12875 .51654 .11907 Metetra
0 1 0 r
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Metetra
0 1 0 r
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Metetra
0 1 0 r
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Metetra
0 1 0 r
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Metetra
0 1 0 r
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Metetra
0 1 0 r
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Metetra
0 1 0 r
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Metetra
0 1 0 r
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Metetra
0 1 0 r
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Metetra
0 1 0 r
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Metetra
0 1 0 r
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Metetra
0 1 0 r
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Metetra
0 1 0 r
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Metetra
0 1 0 r
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Metetra
0 1 0 r
.04283 .42377 .05227 .4311 .06437 .42722 .055 .41965 Metetra
0 1 0 r
.055 .41965 .06437 .42722 .07656 .42317 .06724 .41534 Metetra
0 1 0 r
.06724 .41534 .07656 .42317 .08882 .41892 .07958 .41081 Metetra
0 1 0 r
.07958 .41081 .08882 .41892 .10118 .41446 .092 .40605 Metetra
0 1 0 r
.092 .40605 .10118 .41446 .11362 .40978 .10451 .40104 Metetra
0 1 0 r
.10451 .40104 .11362 .40978 .12614 .40486 .11711 .39578 Metetra
0 1 0 r
.11711 .39578 .12614 .40486 .13875 .39968 .12979 .39024 Metetra
0 1 0 r
.12979 .39024 .13875 .39968 .15145 .39423 .14256 .38441 Metetra
0 1 0 r
.14256 .38441 .15145 .39423 .16423 .3885 .15542 .37827 Metetra
0 1 0 r
.15542 .37827 .16423 .3885 .17709 .38246 .16836 .37182 Metetra
0 1 0 r
.16836 .37182 .17709 .38246 .19004 .37611 .18138 .36503 Metetra
0 1 0 r
.18138 .36503 .19004 .37611 .20306 .36942 .19448 .35789 Metetra
0 1 0 r
.19448 .35789 .20306 .36942 .21617 .36239 .20766 .35038 Metetra
0 1 0 r
.20766 .35038 .21617 .36239 .22935 .355 .22092 .3425 Metetra
0 1 0 r
.22092 .3425 .22935 .355 .2426 .34723 .23425 .33422 Metetra
0 1 0 r
.23425 .33422 .2426 .34723 .25593 .33907 .24765 .32554 Metetra
0 1 0 r
.24765 .32554 .25593 .33907 .26932 .33051 .26111 .31644 Metetra
0 1 0 r
.26111 .31644 .26932 .33051 .28278 .32153 .27464 .3069 Metetra
0 1 0 r
.27464 .3069 .28278 .32153 .2963 .31212 .28823 .29691 Metetra
0 1 0 r
.28823 .29691 .2963 .31212 .30988 .30226 .30188 .28647 Metetra
0 1 0 r
.30188 .28647 .30988 .30226 .32351 .29194 .31557 .27556 Metetra
0 1 0 r
.31557 .27556 .32351 .29194 .33719 .28116 .32931 .26416 Metetra
0 1 0 r
.32931 .26416 .33719 .28116 .35091 .26989 .34309 .25227 Metetra
0 1 0 r
.34309 .25227 .35091 .26989 .36466 .25813 .3569 .23988 Metetra
0 1 0 r
.3569 .23988 .36466 .25813 .37845 .24587 .37075 .22697 Metetra
0 1 0 r
.37075 .22697 .37845 .24587 .39227 .23309 .38461 .21354 Metetra
0 1 0 r
.38461 .21354 .39227 .23309 .4061 .21978 .39849 .19957 Metetra
0 1 0 r
.39849 .19957 .4061 .21978 .41995 .20595 .41238 .18507 Metetra
0 1 0 r
.41238 .18507 .41995 .20595 .4338 .19158 .42627 .17002 Metetra
0 1 0 r
.42627 .17002 .4338 .19158 .44765 .17665 .44015 .15442 Metetra
0 1 0 r
.44015 .15442 .44765 .17665 .46149 .16117 .45403 .13826 Metetra
0 1 0 r
.45403 .13826 .46149 .16117 .47532 .14514 .46781 .12513 Metetra
0 1 0 r
.46781 .12513 .47532 .14514 .48911 .12955 .48147 .11988 Metetra
0 1 0 r
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Metetra
0 1 0 r
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Metetra
0 1 0 r
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Metetra
0 1 0 r
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Metetra
0 1 0 r
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Metetra
0 1 0 r
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Metetra
0 1 0 r
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Metetra
0 1 0 r
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Metetra
0 1 0 r
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Metetra
0 1 0 r
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Metetra
0 1 0 r
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Metetra
0 1 0 r
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Metetra
0 1 0 r
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Metetra
0 1 0 r
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Metetra
0 1 0 r
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03781 Metetra
0 1 0 r
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Metetra
0 1 0 r
.03335 .41611 .04283 .42377 .055 .41965 .04558 .41172 Metetra
0 1 0 r
.04558 .41172 .055 .41965 .06724 .41534 .0579 .40711 Metetra
0 1 0 r
.0579 .40711 .06724 .41534 .07958 .41081 .0703 .40227 Metetra
0 1 0 r
.0703 .40227 .07958 .41081 .092 .40605 .0828 .39718 Metetra
0 1 0 r
.0828 .39718 .092 .40605 .10451 .40104 .09538 .39182 Metetra
0 1 0 r
.09538 .39182 .10451 .40104 .11711 .39578 .10805 .38618 Metetra
0 1 0 r
.10805 .38618 .11711 .39578 .12979 .39024 .12082 .38025 Metetra
0 1 0 r
.12082 .38025 .12979 .39024 .14256 .38441 .13366 .37401 Metetra
0 1 0 r
.13366 .37401 .14256 .38441 .15542 .37827 .1466 .36745 Metetra
0 1 0 r
.1466 .36745 .15542 .37827 .16836 .37182 .15962 .36055 Metetra
0 1 0 r
.15962 .36055 .16836 .37182 .18138 .36503 .17272 .35329 Metetra
0 1 0 r
.17272 .35329 .18138 .36503 .19448 .35789 .1859 .34567 Metetra
0 1 0 r
.1859 .34567 .19448 .35789 .20766 .35038 .19916 .33766 Metetra
0 1 0 r
.19916 .33766 .20766 .35038 .22092 .3425 .21249 .32926 Metetra
0 1 0 r
.21249 .32926 .22092 .3425 .23425 .33422 .2259 .32045 Metetra
0 1 0 r
.2259 .32045 .23425 .33422 .24765 .32554 .23937 .31122 Metetra
0 1 0 r
.23937 .31122 .24765 .32554 .26111 .31644 .25292 .30155 Metetra
0 1 0 r
.25292 .30155 .26111 .31644 .27464 .3069 .26652 .29143 Metetra
0 1 0 r
.26652 .29143 .27464 .3069 .28823 .29691 .28018 .28085 Metetra
0 1 0 r
.28018 .28085 .28823 .29691 .30188 .28647 .29389 .2698 Metetra
0 1 0 r
.29389 .2698 .30188 .28647 .31557 .27556 .30766 .25827 Metetra
0 1 0 r
.30766 .25827 .31557 .27556 .32931 .26416 .32146 .24624 Metetra
0 1 0 r
.32146 .24624 .32931 .26416 .34309 .25227 .3353 .2337 Metetra
0 1 0 r
.3353 .2337 .34309 .25227 .3569 .23988 .34917 .22066 Metetra
0 1 0 r
.34917 .22066 .3569 .23988 .37075 .22697 .36307 .20709 Metetra
0 1 0 r
.36307 .20709 .37075 .22697 .38461 .21354 .37698 .19299 Metetra
0 1 0 r
.37698 .19299 .38461 .21354 .39849 .19957 .39091 .17835 Metetra
0 1 0 r
.39091 .17835 .39849 .19957 .41238 .18507 .40484 .16317 Metetra
0 1 0 r
.40484 .16317 .41238 .18507 .42627 .17002 .41877 .14743 Metetra
0 1 0 r
.41877 .14743 .42627 .17002 .44015 .15442 .43269 .13114 Metetra
0 1 0 r
.43269 .13114 .44015 .15442 .45403 .13826 .44641 .12069 Metetra
0 1 0 r
.44641 .12069 .45403 .13826 .46781 .12513 .46005 .11541 Metetra
0 1 0 r
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Metetra
0 1 0 r
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Metetra
0 1 0 r
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Metetra
0 1 0 r
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Metetra
0 1 0 r
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Metetra
0 1 0 r
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Metetra
0 1 0 r
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Metetra
0 1 0 r
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Metetra
0 1 0 r
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Metetra
0 1 0 r
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Metetra
0 1 0 r
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Metetra
0 1 0 r
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Metetra
0 1 0 r
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Metetra
0 1 0 r
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Metetra
0 1 0 r
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .03299 Metetra
0 1 0 r
.67312 .03299 .68016 .04348 .69491 .03781 .68792 .02727 Metetra
0 1 0 r
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Metetra
0 1 0 r
.02382 .40807 .03335 .41611 .04558 .41172 .03612 .40338 Metetra
0 1 0 r
.03612 .40338 .04558 .41172 .0579 .40711 .04852 .39845 Metetra
0 1 0 r
.04852 .39845 .0579 .40711 .0703 .40227 .061 .39326 Metetra
0 1 0 r
.061 .39326 .0703 .40227 .0828 .39718 .07357 .38781 Metetra
0 1 0 r
.07357 .38781 .0828 .39718 .09538 .39182 .08624 .38207 Metetra
0 1 0 r
.08624 .38207 .09538 .39182 .10805 .38618 .09899 .37603 Metetra
0 1 0 r
.09899 .37603 .10805 .38618 .12082 .38025 .11183 .36968 Metetra
0 1 0 r
.11183 .36968 .12082 .38025 .13366 .37401 .12476 .363 Metetra
0 1 0 r
.12476 .363 .13366 .37401 .1466 .36745 .13778 .35598 Metetra
0 1 0 r
.13778 .35598 .1466 .36745 .15962 .36055 .15088 .3486 Metetra
0 1 0 r
.15088 .3486 .15962 .36055 .17272 .35329 .16406 .34085 Metetra
0 1 0 r
.16406 .34085 .17272 .35329 .1859 .34567 .17733 .33271 Metetra
0 1 0 r
.17733 .33271 .1859 .34567 .19916 .33766 .19067 .32418 Metetra
0 1 0 r
.19067 .32418 .19916 .33766 .21249 .32926 .20408 .31523 Metetra
0 1 0 r
.20408 .31523 .21249 .32926 .2259 .32045 .21757 .30586 Metetra
0 1 0 r
.21757 .30586 .2259 .32045 .23937 .31122 .23113 .29605 Metetra
0 1 0 r
.23113 .29605 .23937 .31122 .25292 .30155 .24475 .28579 Metetra
0 1 0 r
.24475 .28579 .25292 .30155 .26652 .29143 .25843 .27507 Metetra
0 1 0 r
.25843 .27507 .26652 .29143 .28018 .28085 .27216 .26388 Metetra
0 1 0 r
.27216 .26388 .28018 .28085 .29389 .2698 .28594 .2522 Metetra
0 1 0 r
.28594 .2522 .29389 .2698 .30766 .25827 .29977 .24002 Metetra
0 1 0 r
.29977 .24002 .30766 .25827 .32146 .24624 .31364 .22734 Metetra
0 1 0 r
.31364 .22734 .32146 .24624 .3353 .2337 .32754 .21415 Metetra
0 1 0 r
.32754 .21415 .3353 .2337 .34917 .22066 .34147 .20043 Metetra
0 1 0 r
.34147 .20043 .34917 .22066 .36307 .20709 .35543 .18619 Metetra
0 1 0 r
.35543 .18619 .36307 .20709 .37698 .19299 .36939 .17141 Metetra
0 1 0 r
.36939 .17141 .37698 .19299 .39091 .17835 .38336 .15608 Metetra
0 1 0 r
.38336 .15608 .39091 .17835 .40484 .16317 .39734 .1402 Metetra
0 1 0 r
.39734 .1402 .40484 .16317 .41877 .14743 .4113 .12377 Metetra
0 1 0 r
.4113 .12377 .41877 .14743 .43269 .13114 .42493 .11623 Metetra
0 1 0 r
.42493 .11623 .43269 .13114 .44641 .12069 .43854 .11093 Metetra
0 1 0 r
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Metetra
0 1 0 r
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Metetra
0 1 0 r
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Metetra
0 1 0 r
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08947 Metetra
0 1 0 r
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Metetra
0 1 0 r
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Metetra
0 1 0 r
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Metetra
0 1 0 r
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Metetra
0 1 0 r
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Metetra
0 1 0 r
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Metetra
0 1 0 r
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Metetra
0 1 0 r
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Metetra
0 1 0 r
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Metetra
0 1 0 r
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Metetra
0 1 0 r
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Metetra
0 1 0 r
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Metetra
0 1 0 r
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Metetra
0 1 0 r
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Metetra
0 1 0 r
.01427 .3996 .02382 .40807 .03612 .40338 .02665 .39458 Metetra
0 1 0 r
.02665 .39458 .03612 .40338 .04852 .39845 .03912 .38929 Metetra
0 1 0 r
.03912 .38929 .04852 .39845 .061 .39326 .05168 .38373 Metetra
0 1 0 r
.05168 .38373 .061 .39326 .07357 .38781 .06434 .37788 Metetra
0 1 0 r
.06434 .37788 .07357 .38781 .08624 .38207 .07708 .37173 Metetra
0 1 0 r
.07708 .37173 .08624 .38207 .09899 .37603 .08992 .36526 Metetra
0 1 0 r
.08992 .36526 .09899 .37603 .11183 .36968 .10285 .35846 Metetra
0 1 0 r
.10285 .35846 .11183 .36968 .12476 .363 .11587 .35131 Metetra
0 1 0 r
.11587 .35131 .12476 .363 .13778 .35598 .12897 .3438 Metetra
0 1 0 r
.12897 .3438 .13778 .35598 .15088 .3486 .14216 .33592 Metetra
0 1 0 r
.14216 .33592 .15088 .3486 .16406 .34085 .15543 .32765 Metetra
0 1 0 r
.15543 .32765 .16406 .34085 .17733 .33271 .16878 .31897 Metetra
0 1 0 r
.16878 .31897 .17733 .33271 .19067 .32418 .18221 .30988 Metetra
0 1 0 r
.18221 .30988 .19067 .32418 .20408 .31523 .19571 .30037 Metetra
0 1 0 r
.19571 .30037 .20408 .31523 .21757 .30586 .20928 .29041 Metetra
0 1 0 r
.20928 .29041 .21757 .30586 .23113 .29605 .22292 .28 Metetra
0 1 0 r
.22292 .28 .23113 .29605 .24475 .28579 .23662 .26913 Metetra
0 1 0 r
.23662 .26913 .24475 .28579 .25843 .27507 .25037 .25778 Metetra
0 1 0 r
.25037 .25778 .25843 .27507 .27216 .26388 .26418 .24594 Metetra
0 1 0 r
.26418 .24594 .27216 .26388 .28594 .2522 .27804 .23361 Metetra
0 1 0 r
.27804 .23361 .28594 .2522 .29977 .24002 .29194 .22078 Metetra
0 1 0 r
.29194 .22078 .29977 .24002 .31364 .22734 .30587 .20743 Metetra
0 1 0 r
.30587 .20743 .31364 .22734 .32754 .21415 .31984 .19356 Metetra
0 1 0 r
.31984 .19356 .32754 .21415 .34147 .20043 .33383 .17916 Metetra
0 1 0 r
.33383 .17916 .34147 .20043 .35543 .18619 .34783 .16423 Metetra
0 1 0 r
.34783 .16423 .35543 .18619 .36939 .17141 .36185 .14875 Metetra
0 1 0 r
.36185 .14875 .36939 .17141 .38336 .15608 .37587 .13272 Metetra
0 1 0 r
.37587 .13272 .38336 .15608 .39734 .1402 .38984 .11704 Metetra
0 1 0 r
.38984 .11704 .39734 .1402 .4113 .12377 .40336 .11175 Metetra
0 1 0 r
.40336 .11175 .4113 .12377 .42493 .11623 .41694 .10643 Metetra
0 1 0 r
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Metetra
0 1 0 r
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Metetra
0 1 0 r
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Metetra
0 1 0 r
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Metetra
0 1 0 r
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Metetra
0 1 0 r
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Metetra
0 1 0 r
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Metetra
0 1 0 r
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Metetra
0 1 0 r
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Metetra
0 1 0 r
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Metetra
0 1 0 r
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Metetra
0 1 0 r
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Metetra
0 1 0 r
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Metetra
0 1 0 r
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Metetra
0 1 0 r
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Metetra
0 1 0 r
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Metetra
0 1 0 r
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Metetra
0 1 0 r
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Metetra
0 1 0 r
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.01)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.02)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.03)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.04)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.05)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06033 .24606 m
.06319 .24877 L
s
.08372 .23691 m
.08655 .23964 L
s
.10732 .22766 m
.11013 .23042 L
s
.13115 .21833 m
.13394 .22111 L
s
.17948 .19941 m
.18222 .20223 L
s
.20399 .18981 m
.2067 .19266 L
s
.22873 .18012 m
.23142 .183 L
s
.25371 .17034 m
.25638 .17324 L
s
.3044 .15049 m
.30701 .15344 L
s
.33011 .14043 m
.3327 .14339 L
s
.35608 .13026 m
.35864 .13325 L
s
.3823 .11999 m
.38483 .12301 L
s
.43553 .09915 m
.43799 .10222 L
s
.46254 .08857 m
.46497 .09167 L
s
.48982 .07789 m
.49222 .08101 L
s
.51738 .0671 m
.51975 .07024 L
s
.57333 .04519 m
.57563 .04838 L
s
.60174 .03407 m
.60401 .03728 L
s
.63044 .02283 m
.63267 .02607 L
s
.65944 .01147 m
.66163 .01474 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00[oooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000?ooooo0ol0001Mooooo`00[_ooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`1Jooooo`00
[_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool0F_ooool00:kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo05[ooooo002^ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
oooooooooooo0000ooooo`04o`0005gooooo002^ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool0000=ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o
00000oooool3o`0003oooooo002_ooooo`;o00002_ooool2o`0000;ooooo1Ol00008ooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
oooo03cooooo0035ooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool0??ooool00<cooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03cooooo003<ooooo`04o`000?oo
ooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0003oooooo0031ooooo`;o0000
2Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000@_ooool0
0;kooooo0ol000000ol0o`3o0000ooooo`09ooooo`;o00002_ooool2o`0000;ooooo1Ol0000noooo
o`00_?ooool3o`0000?o0?l00_l0001Looooo`00^Oooool4o`000003o`3o0?l0003o0?l000;o0?l0
0ol0001Kooooo`00ROooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol0
000Iooooo`?o000000?o0?l0o`000?l0o`000_l0o`001_l0003o0?l0o`000?l0003o0?l0o`0005_o
oooo0028ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0Eooooo`Co00001?l0o`000ol0003o0?l0o`000002o`000005o`3o0?l0003o0?l0
o`3o0?l00000F_ooool008Sooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0
003ooooo00Go00004oooool4o`0000;o0?l000Co0000o`3o0?l0o`3o0?l00ol00003o`3o00;o0000
00Co0?l0o`000?l0003o0000FOooool008Sooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool04?ooool3o`000003o`3o0?l0003o
000000?o0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o00?o00000_l0o`000ol0003ooooooooo
o`1Gooooo`00R?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000003oooool4o`0000Co0?l000?o0000o`3o0?l0o`000ol00003o`3o0006o`00
0?l0o`3o0000o`000?l0o`3o00001?l0o`000ol0003oooooooooo`1Fooooo`00R?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000=ooooo`Co00000_l0o`00
0ol0003o0?l0o`3o0004o`0000?o0?l000?o0000o`3o0?l0o`000_l00004o`3o0003o`000?l0o`3o
0?l000?o0000Eoooool008Wooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`08oooo
o`Co000000?o0?l0o`000?l000000_l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000_l0o`03o`00
00;o0?l000?o0000o`3o0?l0o`001?l00002o`3o0003o`000?oooooooooo05Gooooo002Uooooo`Co
00001?l0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l000Ko0000o`3o0?l0003o0000o`3o0?l0
0003o`3o00?o000000?o0?l0o`000?l000000ol0o`02o`0005Kooooo002Rooooo`Co00000ol0o`00
0ol0003o0?l0o`3o0003o`0000?o0?l000?o0000o`3o0?l0o`000ol00004o`3o00?o000000_o0?l0
o`000?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l0003o0?l0o`00001Fooooo`00X?ooool3o`000004
o`3o0?l0003o0?l0o`0000;o0?l00ol00002o`3o0004o`000?l0o`3o0?l0o`3o00?o00000ol0o`00
0ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l000000ol00003o`3o0003o`000?oooooo
oooo05?ooooo002Mooooo`Go00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000Co0?l00ol0
00000ol0o`3o0000o`3o0003o`3o00?o000000?o0?l0o`000?l0o`000ol0o`03o`0000;o0?l000?o
0000o`3o0?l0o`000ol0001Dooooo`00Voooool4o`0000?o0?l000?o0000o`3o0?l0o`000_l00004
o`3o0003o`000?l0o`3o0?l000;o00001?l0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l0
00Go0000o`3o0?l0003o0000o`3o0002o`0000;o0?l00ol00002o`3o00;o0000Doooool009Sooooo
1?l000001?l0o`3o0000o`3o0?l00002o`3o00?o00000_l0o`000ol0003o0?l0o`3o0004o`0000;o
0?l000?o0000o`3o0?l0o`000ol00004o`3o0003o`000?l0o`3o000000;o00001?l0o`001Ol0003o
0?l0o`000?l0o`3o000000Co0?l00_l0001Booooo`00U_ooool3o`000003o`3o0?l0003o0?l000;o
0?l000Ko0000o`3o0?l0003o0000o`3o0?l00003o`3o00?o00000_l0o`001?l0003o0?l0o`3o0?l0
o`03o`0000?o0?l000?o0000o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o0?l000?o00000ol0
o`001_l0003o0?l0o`000?l0003o0?l0o`0005;ooooo001Uooooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`;o00000oooool3o`0001[ooooo1Ol00003o`3o0003o`000?l0o`3o0?l000;o0000
1?l0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o
00?o00000_l0o`000ol0003o0?l0o`3o0004o`000003o`3o0?l0003o000000;o0?l00ol00003o`3o
00;o0000DOooool006Cooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool05?ooool4o`0000?o0?l000?o0000o`3o0?l0o`001?l0
0002o`3o0003o`000?l0o`3o0?l000?o00000ol0o`000ol0003o0?l0o`3o0003o`0000?o0?l000Ko
0000o`3o0?l0003o0000o`3o0?l00003o`3o00?o00000_l0o`000ol0003o0?l0o`3o0004o`0000?o
0?l000?o0000o`3o0?l0o`000_l0001Aooooo`00I?ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool04_ooool3o`000003o`3o0?l0003o0?l0
00?o0?l00ol00002o`3o0004o`000?l0o`3o0?l0o`3o00?o00000_l0o`000ol0003o0?l0o`3o0004
o`0000?o0?l000?o0000o`3o0?l0o`000_l00004o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0
o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l00ol000000ol0o`3o0000o`00001@ooooo`00I?oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000Booooo`Ko
00000_l0o`001_l0003o0?l0o`000?l0003o0?l0o`0000Co0?l00ol000000ol0o`3o0000o`3o0002
o`3o00?o00000ol0o`000ol0003o0?l0o`3o0004o`0000;o0?l000?o0000o`3o0?l0o`000ol00003
o`3o0003o`000?l0o`3o0?l000Co00000_l0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l0
0_l0000=ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool3o`0002gooooo
001Tooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`0=ooooo`Co00000ol0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l0
o`000_l00004o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`03o`0000;o0?l000Co0000o`3o
0?l0o`3o0?l00ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`02o`000004o`3o0?l0003o
0000o`0000Co0?l000?o0000o`3o0?l000000_l0000<ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0/ooooo`00I?ooool01?l0003ooooo
ooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0:
ooooo`Co00000_l0o`000ol0003o0?l0o`3o0004o`0000;o0?l000?o0000o`3o0?l0o`001?l00002
o`3o0003o`000?l0o`3o0?l000?o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000Co0?l0
0ol000000ol0o`3o0000o`3o0002o`3o00?o00000_l0o`001?l0003o0?l0o`3o0?l0o`03o`0000?o
0?l000?o0000o`3o0?l0o`000ol00003o`3o0003o`000?oooooooooo00;ooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`05o`0002gooooo001Uoooo
o`;o00002_ooool2o`0000?ooooo0ol0000;ooooo`?o000000Go0?l0o`000?l0o`3o0000o`3o0003
o`0000;o0?l000Co0000o`3o0?l0o`3o0?l00ol00003o`3o0003o`000?l0o`3o0?l000?o00000ol0
o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l0o`000_l00004o`3o0005o`000?l0
o`3o0000o`3o0?l000001?l0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l00ol000000ol0o`3o
0000o`3o0003o`3o00;o00002_ooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000_ooool00ol0003oooooooooo`0/ooooo`00POooool4o`0000Co0?l000Go0000
o`3o0?l0003o0?l0o`000004o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`03o`000003o`3o
0?l0003o0?l000?o0?l00ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`000ol0003o0?l0
o`3o0003o`0000?o0?l000?o0000o`3o0?l0o`000ol00003o`3o0006o`000?l0o`3o0000o`000?l0
o`3o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000[ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000002kooooo001oooooo`Go0000
00Co0?l0o`000?l0o`3o0?l00ol00003o`3o0003o`000?l0o`3o0?l000?o00000ol0o`001_l0003o
0?l0o`000?l0003o0?l0o`0000?o0?l000Ko0000o`3o0?l0003o0000o`3o0?l00003o`3o00?o0000
0ol0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`001?l00002o`3o0003o`00
0?l0o`3o0?l000?o00001?l0o`000ol0003o0?l0o`000002o`0000Co0?l000?o0000ooooooooool0
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000^oooo
o`00O?ooool3o`0000;o0?l000Co0000o`3o0?l0o`3o0?l00ol00003o`3o0003o`000?l0o`3o0?l0
00?o00000ol0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l0o`000_l00004o`3o
0005o`000?l0o`3o0000o`3o0?l000001?l0o`03o`000003o`3o0?l0003o0?l000;o0?l00ol00003
o`3o0003o`000?l0o`3o0?l000?o000000Co0?l0o`000?l0o`3o00000_l0o`03o`0000?o0?l000?o
0000o`3o0?l0o`000_l0000:ooooo`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool0;?oo
ool007[ooooo0_l000000ol0o`3o0000o`3o0003o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0
o`03o`0000;o0?l000?o0000o`3o0?l0o`001?l00002o`3o0003o`000?l0o`3o0?l000Co00000_l0
o`000ol0003o0?l0o`3o0003o`0000?o0?l000Ko0000o`3o0?l0003o0000o`3o0?l00003o`3o0005
o`000?l0o`3o0000o`3o0?l000001?l0o`03o`000006o`3o0?l0003o0?l0o`3o0?l0003o0?l00ol0
0002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`000ol0003oooooooooo`19ooooo`00Moooool4
o`000004o`3o0?l0003o0?l0o`0000;o0?l00ol00003o`3o0006o`000?l0o`3o0000o`000?l0o`3o
00000ol0o`03o`0000;o0?l000Co0000o`3o0?l0o`3o0?l00ol00003o`3o0003o`000?l0o`3o0?l0
00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000Co0?l000?o0000o`3o0?l000000_l00003o`3o
0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o
0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o0000B_ooool007Gooooo1?l000000ol0o`3o0000
o`3o0002o`3o00?o00000ol0o`000ol0003o0?l0o`3o0002o`0000Co0?l000Go0000o`3o0?l0003o
0?l0o`000004o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`03o`000003o`3o0?l0003o0?l0
00;o0?l00ol00003o`3o0003o`000?l0o`3o0?l000?o00000ol0o`000ol0003o0?l0o`3o0002o`00
00Co0?l000?o0000o`3o0?l0o`000ol00003o`3o00?o000000?o0?l0o`000?l0o`000_l0o`03o`00
00;o0?l000?o0000ooooooooool0B?ooool004?ooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo0_l00002ooooo`Go00006_ooool6o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o
00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l000?o0000o`3o0?l0o`000ol00003o`3o
0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l0
0ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`000ol0003o0?l0o`3o0004o`0000;o0?l0
00?o0000o`3o0?l0o`000_l00004o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`000ol0003o
ooooooooo`17ooooo`00@_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00005oooool3o`0000?ooooo00?o0000o`3o0?l000001?l0o`00
1Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000?o0000o`3o0?l000001?l0o`02o`0000?o0?l000?o
0000o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0o`00
0002o`0000?o0?l000Ko0000o`3o0?l0003o0000o`3o0?l00003o`3o00?o00000_l0o`001?l0003o
0?l0o`3o0?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`001?l00002o`3o0003o`000?l0o`3o0?l0
00?o00000ol0o`000ol0003o0?l0o`3o0003o`0004Sooooo0012ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Eooooo`;o00001Oooool0
1?l0003o0?l0o`3o0?l00003o`3o00;o00000ol0o`000ol0003o0?l0o`000003o`3o0003o`000?l0
o`3o0?l000;o00001Ol0o`02o`000003o`3o0?l0003o0?l000?o0?l00ol00002o`3o0003o`000?l0
o`3o0?l000?o00000ol0o`000ol0003o0?l0o`3o0002o`0000Co0?l000Go0000o`3o0?l0003o0?l0
o`000004o`3o00?o000000?o0?l0o`000?l0o`000_l0o`03o`000004o`3o0?l0003o0?l0o`0000;o
0?l00ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`000ol0003oooooooooo`16ooooo`00
@_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool04Oooool3o`0000;ooooo00Go0000ooooooooooooooooo`000004o`3o0003o`000?l0o`3o
000000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000004o`3o0003o`000?l0o`3o000000;o0?l000Co
0000o`3o0?l0o`3o0?l00_l00003o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`03o`00
00;o0?l000?o0000o`3o0?l0o`001?l00002o`3o0003o`000?l0o`3o0?l000?o00000ol0o`000ol0
003o0?l0o`3o0002o`0000Co0?l000Go0000o`3o0?l0003o0?l0o`000002o`3o0003o`000?l0o`3o
000000;o000000?o0?l0o`000?l0o`000_l0o`03o`0000?o0?l000?o0000o`3o0?l0o`000_l00017
ooooo`00@_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0>ooooo`;o00002?ooool2o`0000Co0?l00_l00003o`3o0005o`00
0?l0o`3o0?l0o`3o0?l000001Ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000Co0000o`3o
0?l0o`3o00000ol0o`000ol0003o0?l0o`3o0002o`3o00?o000000?o0?l0o`000?l0o`000ol0o`02
o`0000?o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`00
0ol0003o0?l0o`3o0003o`0000?o0?l000Ko0000o`3o0?l0003o0000o`3o0?l00003o`3o0005o`00
0?l0o`3o0000o`3o0?l000001?l0o`03o`000003o`3o0?l0003o000004Kooooo0012ooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
oooo00_ooooo0ol00009ooooo`04o`000?l0o`3o0?l0o`0000?o0?l000?o0000o`3o0?l0o`000_l0
o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o
000000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000004o`3o0003o`000?l0o`3o0?l000;o0?l000?o
0000o`3o0?l0o`000_l00004o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l000?o
0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000Co00000ol0o`000ol0003o0?l0o`00
0002o`0000?o0?l000Ko0000o`3o0?l0003o0000o`3o0?l00003o`3o00;o0000AOooool004?ooooo
0_l0000:ooooo`;o00000oooool3o`0000cooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo
00Go0000o`3o0?l0o`3o0?l0o`000003o`3o0003o`000?l0o`3o0?l000?o0?l00_l00002o`3o0007
o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000003o`3o0003o`000?l0o`3o0?l000;o0?l000Ko0000
o`3o0?l0o`3o0000o`3o0?l00003o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l00000
0_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co0?l00_l000000ol0o`3o0000o`3o0003o`3o
00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l000?o0000o`3o0?l0o`000ol00002o`3o
0003o`000?l0o`3o0?l000?o00001?l0o`03o`000003o`3o0?l0003ooooo04Cooooo001Pooooo`?o
00003?ooool00ol0003o0?l0o`3o0002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00001?l0o`00
1Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o00000ol0o`000ol0003o0?l0
o`3o0003o`3o00;o00000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co0?l000Oo0000o`3o
0?l0o`3o0?l0o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o0?l00_l00003o`3o0006o`00
0?l0o`3o0000o`000?l0o`3o00000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`001?l00002o`3o
0003o`000?l0o`3o0?l000?o00000ol0o`000ol0003o0?l0o`3o0002o`0000?o0?l00_l00014oooo
o`00G_ooool2o`000003ooooool0003o000000cooooo00?o0000o`3o0?l0o`000ol0o`02o`0000;o
0?l000Co0000o`3o0?l0o`3o0?l00_l00004o`3o00;o00000ol0o`001_l0003o0?l0o`3o0?l0003o
0?l0o`0000Co0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0
o`3o0?l00_l00004o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l000000_l0o`001Ol0
003o0?l0o`3o0?l0o`3o000000Co0?l00ol000000ol0o`3o0000o`3o0002o`3o00?o000000?o0?l0
o`000?l000000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`001?l00002o`3o0003o`000?l0o`3o
0?l000;o0000A?ooool005_ooooo0ol0000@ooooo`03o`000?l0o`3o000000Co0?l000Go0000o`3o
0?l0o`3o0?l0o`000002o`3o0004o`000?l0o`3o0?l0o`0000?o0?l000?o0000o`3o0?l0o`000ol0
o`02o`0000;o0?l000Co0000o`3o0?l0o`3o0?l00_l00004o`3o0005o`000?l0o`3o0?l0o`3o0?l0
00000_l0o`001?l0003o0?l0o`3o0?l00003o`3o0003o`000?l0o`3o0?l000;o0?l00_l00003o`3o
0003o`000?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0o`3o0002o`3o0005o`000?l0o`3o0000
o`3o0?l000000ol0o`04o`000003o`3o0?l0003o0?l000;o0?l00ol00002o`3o0003o`000?l0o`3o
0?l000Co00000_l0o`000ol0003oooooooooo`11ooooo`00FOooool3o`00017ooooo00Co0000o`3o
0?l0o`3o00000ol0o`02o`0000Co0?l00_l00003o`3o0003o`000?l0o`3o0?l000;o00001Ol0o`00
1Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000?o0000o`3o0?l000001?l0o`000ol0003o0?l0o`3o
0002o`3o00;o00000ol0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o0000o`3o0?l0
o`000_l0o`000ol0003o0?l0o`000002o`3o0005o`000?l0o`3o0?l0o`3o0?l000001Ol0o`001Ol0
003o0?l0o`3o0?l0o`3o000000;o0?l00_l00004o`3o00?o000000?o0?l0o`000?l0o`000_l0o`03
o`0000;o0?l000Co0000o`3o0?l0o`3o0?l00_l00012ooooo`00E_ooool3o`0000?ooooo00?o0000
ooooooooool03Oooool01Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o0000
0ol0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o
0?l00_l00004o`3o00;o00000_l0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000ol0o`00
0ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0?l0o`00
0005o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`000ol0003o0?l0o`000003o`3o00;o0000
1?l0o`04o`0000?o0?l00_l00004o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`03o`000003
o`3o0?l0003ooooo047ooooo000Sooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o0000
0oooool3o`0001gooooo0_l0000Eooooo`;o00001?l0o`02o`0000?o0?l000Go0000o`3o0?l0o`3o
0?l0o`000005o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l00003
o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l000000_l0o`001Ol0003o0?l0o`3o0?l0
o`3o000000Go0?l00_l00002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`02o`0000?o
0?l000?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l00_l00000
2?l0o`3o0000o`3o0?l0003o0?l0o`000?l0o`3o00001?l0o`02o`0000?o0?l000?o0000o`3o0?l0
o`000_l00004o`3o0003o`000?oooooooooo03oooooo000Rooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Iooooo`Go00005?ooool01?l0
003o0?l0o`3o0?l00003o`3o0003o`000?l0o`3o0?l000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o
0?l00003o`3o00;o00000ol0o`000ol0003o0?l0o`000003o`3o0005o`000?l0o`3o0?l0o`3o0?l0
00001?l0o`02o`0000?o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00004o`3o0003o`000?l0o`3o
0?l000;o0?l00_l00002o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000Go0000o`3o0?l0o`3o0?l0
o`000003o`3o0003o`000?l0o`3o000000?o0?l000?o0000o`3o0?l000000_l0o`02o`0000;o0?l0
00Ko0000o`3o0?l0o`3o0?l0o`000?l0o`02o`000003o`3o0?l0003o0?l000;o0?l00ol00002o`3o
0003o`000?l0o`3o0?l000;o00003oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`00
00?ooooo0ol0000Nooooo`008_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool05_ooool3o`0001Sooooo00Go0000o`3o0?l0o`3o0?l0o`00
0003o`3o0003o`000?l0o`3o0?l000?o0?l00_l00002o`3o0004o`000?l0o`3o0?l0o`0000;o0?l0
00Go0000o`3o0?l0o`3o0?l0o`000004o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`00
0ol0003o0?l0o`3o0003o`3o00;o00000_l0o`001?l0003o0?l0o`3o0?l0o`02o`0000Co0?l000Oo
0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000004o`3o
0003o`000?l0o`3o0?l000;o0?l00_l00003o`3o00;o00000_l0o`000ol0003o0?l0o`3o0002o`3o
0003o`000?l0o`3o0?l000;o0?l00ol000000ol0o`3o0000o`3o0002o`3o00?o00000_l0o`000ol0
003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooooooo01_ooooo000Rooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Dooooo`?o00006Oooool00ol0003o
0?l0o`3o0002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`02o`0000?o0?l000?o0000
o`3o0?l000000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000Go0?l00_l00002o`3o0003o`000?l0
o`3o0?l000;o00001Ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000?o0000o`3o0?l00000
0ol0o`02o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`00
00?o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0002o`3o00;o000000Co0?l0o`00
0?l0o`3o00000ol0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000;o0?l00ol00000
0ol0o`3o0000o`3o0002o`3o00;o00001Oooool5o`0000;ooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01_ooooo000Rooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Aooooo`?o
00000_ooool00ol0003oooooooooo`0Fooooo`;o00001Ol0o`02o`0000;o0?l000Ko0000o`3o0?l0
o`3o0000o`3o0?l00004o`3o0003o`000?l0o`3o0?l000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o
0?l00004o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000002o`3o0004o`000?l0o`3o0?l0
o`3o00;o00001?l0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`001Ol0003o0?l0o`3o0?l0
o`3o000000Go0?l00_l00002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`000ol0003o
0?l0o`3o0003o`3o00;o00000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o0000
o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0002o`3o00?o000000?o0?l0o`000?ooool02oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000Nooooo`008_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0_l0000Aooooo`;o
00007Oooool01?l0003o0?l0o`3o0?l00003o`3o00;o00000ol0o`000ol0003o0?l0o`000003o`3o
0005o`000?l0o`3o0?l0o`3o0?l000001Ol0o`02o`0000;o0?l000Co0000o`3o0?l0o`3o0?l00_l0
0004o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l00003o`3o0003
o`000?l0o`3o0?l000;o0?l00_l00003o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00001?l0o`00
1ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`00
00Co0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000;o0?l000Ko0000o`3o0?l0o`3o0000
o`3o0?l00003o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o
ooooooooo`09ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`0Kooooo`008oooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo
00cooooo0ol000000ooooooo0000ooooo`0Kooooo`05o`000?l0o`3o0?l0o`3o0?l000000_l0o`00
0ol0003o0?l0o`000004o`3o0003o`000?l0o`3o0?l000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o
0?l00004o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`000ol0003o0?l0o`000003o`3o00;o
00000ol0o`000ol0003o0?l0o`000003o`3o0003o`000?l0o`3o0?l000;o00001?l0o`000ol0003o
0?l0o`3o0002o`3o0003o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o0?l00_l00004o`3o
0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000002o`3o0004o`000?l0o`3o0?l0o`3o00;o0000
1?l0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o
0?l0o`0000?o0?l000?o0000o`3o0?l0o`000ol0o`000ol0003oooooooooo`08ooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
01_ooooo0012ooooo`;o00008?ooool2o`0000?o0?l000?o0000o`3o0?l000000ol0o`001Ol0003o
0?l0o`3o0?l0o`3o000000Co0?l000?o0000o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l0o`02
o`0000Co0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0?l0o`00
0004o`3o0003o`000?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000005o`3o0005o`00
0?l0o`3o0?l0o`3o0?l000000_l0o`000ol0003o0?l0o`000003o`3o00;o00001?l0o`001Ol0003o
0?l0o`3o0?l0o`3o000000;o0?l000?o0000o`3o0?l000000ol0o`02o`0000Co0?l000Oo0000o`3o
0?l0o`3o0?l0o`000?l0o`3o000000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o00;o
00002oooool2o`0000[ooooo0_l00003ooooo`?o00007_ooool003oooooo0ol0000Qooooo`04o`00
0?l0o`3o0?l0o`0000?o0?l000?o0000o`3o0?l0o`000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0
o`0000Co0?l000Go0000o`3o0?l0o`3o0?l0o`000002o`3o0004o`000?l0o`3o0?l0o`0000?o0?l0
00?o0000o`3o0?l0o`000_l0o`02o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000005o`3o0005
o`000?l0o`3o0?l0o`3o0?l000000_l0o`000ol0003o0?l0o`000003o`3o00;o00001?l0o`02o`00
00?o0?l000?o0000o`3o0?l000000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000Co0?l00_l00002
o`3o00;o000000Go0?l0o`000?l0o`3o0?l0o`000003o`3o0003o`000?l0o`3o0?l000;o0?l000Oo
0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0000o`3o0002o`00
03cooooo000mooooo`;o00000oooool00ol0003oooooooooo`0Mooooo`05o`000?l0o`3o0?l0o`3o
0?l000000ol0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o000000;o0?l000Co0000o`3o
0?l0o`3o0?l00_l00004o`3o00;o00000ol0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000
o`3o0?l0o`000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l00_l00003o`3o0003o`00
0?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o00000_l0o`001Ol0003o0?l0o`3o0?l0o`3o0000
00Co0?l00_l00003o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`001?l0003o0?l0o`3o
0?l0o`03o`0000?o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o0003o`000?l0o`3o0?l0
00;o0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000?o0?l00_l0000kooooo`00>_ooool3
o`0002Cooooo00?o0000o`3o0?l0o`000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l0
0_l00003o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000004o`3o
0003o`000?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000005o`3o00;o00000_l0o`00
1?l0003o0?l0o`3o0?l00002o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`000ol0003o0?l0
o`000003o`3o0005o`000?l0o`3o0?l0o`3o0?l000001?l0o`000ol0003o0?l0o`3o0002o`3o0003
o`000?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o00;o00001?l0o`000ol0
003o0?l0o`000002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`000ol0003o0?l0o`3o
0002o`3o0003o`000?l0o`3o0?l000;o0?l00_l0000kooooo`00>?ooool2o`000003ooooool0003o
oooo02?ooooo0_l00005o`3o00;o00000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co0?l0
0_l00003o`3o0003o`000?l0o`3o0?l000;o00001Ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o
0?l000?o0000o`3o0?l000000ol0o`02o`0000?o0?l000?o0000o`3o0?l000000ol0o`000ol0003o
0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0
o`0000?o0?l000?o0000o`3o0?l0o`000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000?o
0000o`3o0?l000000_l0o`02o`0000Go0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000;o
0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o0003o`000?l0o`3o0?l000;o0?l00ol0000j
ooooo`005oooool2o`0001cooooo0ol00004ooooo`03o`000?oooooooooo023ooooo00Co0000o`3o
0?l0o`3o00000ol0o`02o`0000?o0?l000?o0000o`3o0?l000000ol0o`001Ol0003o0?l0o`3o0?l0
o`3o000000Co0?l000?o0000o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l0o`02o`0000?o0?l0
00?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co0?l000?o0000o`3o
0?l0o`000_l0o`000ol0003o0?l0o`000002o`3o0005o`000?l0o`3o0?l0o`3o0?l000001Ol0o`02
o`0000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o00;o00001?l0o`02o`0000;o0?l0
00Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o00;o00001?l0o`001ol0003o0?l0o`3o0?l0o`3o
0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l000Co0000oooooooo
oooo0000>Oooool001Kooooo00Co0000oooooooooooo00006Oooool4o`0002Oooooo00Go0000o`3o
0?l0o`3o0?l0o`000002o`3o0003o`000?l0o`3o000000Co0?l000?o0000o`3o0?l0o`000_l0o`00
0ol0003o0?l0o`3o0002o`0000Co0?l00_l00003o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000Go
0000o`3o0?l0o`3o0?l0o`000003o`3o0003o`000?l0o`3o000000?o0?l000Go0000o`3o0?l0o`3o
0?l0o`000005o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`000ol0003o0?l0o`000003o`3o
00;o00000ol0o`000ol0003o0?l0o`000002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0
o`02o`0000?o0?l000Co0000o`3o0?l0003o0?l00_l00002o`3o0003o`000?l0o`3o000000?o0?l0
0_l00004o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000002o`3o0008o`000?l0o`3o0?l0
o`000?l0o`3o0000ooooool0000iooooo`005_ooool01?l0003oooooooooool0000Fooooo`?o0000
:_ooool2o`0000?o0?l000?o0000o`3o0?l000000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000Co
0?l000?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o0000
o`3o0?l000000ol0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`00
1_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l0
00Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o00;o00000ol0o`000ol0003o0?l0o`000003o`3o
0005o`000?l0o`3o0000o`3o0?l000001?l0o`000ol0003o0?l0o`3o0002o`000003o`3o0?l0003o
0?l000;o0?l000?o0000o`3o0?l000000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000Co0?l000Oo
0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000;o0?l000Co0000oooooooooooo0000>?ooool001Ko
oooo00Co0000oooooooooooo00004oooool3o`0002cooooo00Co0000o`3o0?l0o`3o00000ol0o`00
0ol0003o0?l0o`3o0002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`02o`0000?o0?l0
00?o0000o`3o0?l000000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000Co0?l000?o0000o`3o0?l0
00000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000Co0?l000?o0000o`3o0?l000000_l0o`001_l0
003o0?l0o`3o0?l0003o0?l0o`0000?o0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l000Ko
0000o`3o0?l0o`3o0000o`3o0?l00004o`3o0003o`000?l0o`3o0?l000;o0?l00_l00003o`3o0003
o`000?l0o`3o0?l000;o00000_l0o`000ol0003o0?l0o`000004o`3o00;o00000ol0o`001_l0003o
0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o0000o`3o0?l0o`000_l0o`001Ol0003o0?l0o`3o0?l0
o`3o000000;ooooo0_l0000gooooo`005_ooool01?l0003oooooooooool0000Aooooo`;o00000ooo
ool00ol0003oooooooooo`0Xooooo`05o`000?l0o`3o0?l0o`3o0?l000000_l0o`02o`0000Co0?l0
00?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co0?l000?o0000o`3o
0?l0o`000_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l00_l00003o`3o0006o`000?l0o`3o0?l0
o`000?l0o`3o00000ol0o`02o`0000?o0?l000?o0000o`3o0?l000000ol0o`001Ol0003o0?l0o`00
0?l0o`3o000000Co0?l000?o0000o`3o0?l0o`000_l0o`02o`0000?o0?l000Go0000o`3o0?l0o`3o
0?l0o`000004o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l000000_l0o`001Ol0003o
0?l0o`000?l0o`3o000000Co0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`000002o`3o
0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`000ol0003o0?l0o`3o0002o`3o0004o`000?oo
oooo0000o`0003Oooooo000Fooooo`04o`000?ooooooooooo`0000kooooo0ol0000_ooooo`03o`00
0?l0o`3o0?l000;o0?l000?o0000o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l0o`02o`0000?o
0?l000?o0000o`3o0?l000000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000Co0?l000?o0000o`3o
0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o0000o`3o0?l000000_l0
o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`02o`0000?o
0?l000Go0000o`3o0?l0o`3o0?l0o`000004o`3o0003o`000?l0o`3o0?l000;o0?l000Ko0000o`3o
0?l0o`3o0000o`3o0?l00003o`3o0003o`000?l0o`3o0?l000?o0?l000Ko0000o`3o0?l0o`3o0?l0
o`000?l0o`02o`000003o`3o0?l0003o0?l000;o0?l000?o0000o`3o0?l0o`000ol0o`001ol0003o
0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l0
00Go0000ooooooooooooooooo`00000fooooo`005oooool2o`0000gooooo0_l00002ooooo`03o`00
0?oooooooooo02cooooo0_l00004o`3o00;o00000ol0o`001_l0003o0?l0o`3o0?l0003o0?l0o`00
00Co0?l000?o0000o`3o0?l0o`000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l00_l0
0003o`3o0003o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o0?l00_l00003o`3o0003o`00
0?l0o`3o000000?o0?l000?o0000o`3o0?l0o`000_l00004o`3o0003o`000?l0o`3o0?l000;o0?l0
00Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o
0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l00_l00003o`3o0003o`000?l0
o`3o000000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o00;o00001?l0o`001ol0003o
0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000;ooooo
00?o0000ooooooooool0=?ooool002?ooooo0ol0000booooo`04o`000?l0o`3o0?l0o`0000;o0?l0
00?o0000o`3o0?l000000ol0o`000ol0003o0?l0o`000003o`3o0003o`000?l0o`3o0?l000;o0000
1?l0o`000ol0003o0?l0o`000002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00001?l0o`000ol0
003o0?l0o`3o0002o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`000ol0003o0?l0o`3o0002
o`3o0003o`000?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000004o`3o0003o`000?l0
o`3o000000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o00;o00000ol0o`000ol0003o
0?l0o`000002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`03o`0000;o0?l000?o0000
o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l00_l00004o`3o0007o`00
0?l0o`3o0?l0o`3o0?l0003o0?l0o`000002o`3o0005o`000?ooooooooooooooool00000=Oooool0
027ooooo1?l0000aooooo`;o00000ol0o`000ol0003o0?l0o`000003o`3o0005o`000?l0o`3o0?l0
o`3o0?l000001?l0o`000ol0003o0?l0o`000002o`3o0004o`000?l0o`3o0?l0o`3o00;o00000ol0
o`000ol0003o0?l0o`000003o`3o0005o`000?l0o`3o0?l0o`3o0?l000001?l0o`02o`0000?o0?l0
00?o0000o`3o0?l0o`000_l00005o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`000ol0003o
0?l0o`000003o`3o00;o00000ol0o`000ol0003o0?l0o`000002o`3o0006o`000?l0o`3o0?l0o`00
0?l0o`3o00001?l0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000ol0o`001?l0003o0?l0
o`000?l0o`02o`0000?o0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000?o0?l000Go0000
o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?ooooo
0_l0000dooooo`007_ooool3o`0003Cooooo00?o0000o`3o0?l000001?l0o`000ol0003o0?l0o`3o
0002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`02o`0000?o0?l000Ko0000o`3o0?l0o`3o0000
o`3o0?l00004o`3o0003o`000?l0o`3o0?l000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003
o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l0
o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co
0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000?o0?l000?o0000o`3o0?l0o`000_l00004
o`3o0003o`000?l0o`3o0?l000;o0?l01?l000001?l0o`3o0000o`3o0?l0o`02o`0000Co0?l000?o
0000o`3o0?l0o`000_l0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o0000
1?l0o`001Ol0003ooooooooooooooooo000003Cooooo000Mooooo`?o0000=?ooool01Ol0003o0?l0
o`3o0?l0o`3o000000;o0?l00_l00004o`3o0003o`000?l0o`3o000000;o0?l000Ko0000o`3o0?l0
o`3o0000o`3o0?l00003o`3o0003o`000?l0o`3o000000?o0?l000?o0000o`3o0?l0o`000_l00004
o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000_l00004o`3o00;o00000ol0o`00
1?l0003o0?l0o`3o0?l00002o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`000ol0003o0?l0
o`000003o`3o0003o`000?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0o`3o0002o`3o0003o`00
0?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000_l00002o`3o00?o00001?l0o`03o`0000;o0?l0
00?o0000o`3o0?l0o`000_l00004o`3o0003o`000?l0o`3o0?l000;o0?l00_l00003o`3o0003o`00
0?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000004ooooo`03o`000?oooooooooo037o
oooo000Mooooo`03o`000?oooooo000003?ooooo00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0
o`000002o`3o0004o`000?l0o`3o0?l0o`3o00;o00000ol0o`000ol0003o0?l0o`000003o`3o0005
o`000?l0o`3o0?l0o`3o0?l000001?l0o`000ol0003o0?l0o`000002o`3o0004o`000?l0o`3o0?l0
o`3o00;o00000ol0o`000ol0003o0?l0o`000002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o0000
0ol0o`000ol0003o0?l0o`000003o`3o0003o`000?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0
o`3o0002o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000_l00005o`3o0008o`00
0?l0o`3o0?l0o`3o0?l0003o0?l0o`000?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol0o`02
o`0000;o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000
o`3o0?l0o`000_l0o`02o`0000?o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00004ooooo`03o`00
0?oooooooooo00cooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go0000
3oooool000Sooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00Co0000oooooooooooo0000
<Oooool2o`0000Co0?l00_l00003o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00001?l0o`000ol0
003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`02o`0000?o0?l000Ko0000o`3o
0?l0o`3o0000o`3o0?l00003o`3o00;o00000ol0o`000ol0003o0?l0o`000003o`3o0005o`000?l0
o`3o0?l0o`3o0?l000001?l0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o0000
1?l0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l0o`02o`0000Co
0?l00ol000001ol0o`3o0000o`3o0?l0o`3o0000o`3o0?l000000ol0o`02o`000005o`3o0?l0003o
0?l0o`3o0?l000000ol0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o00001?l0
o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o000000;o0?l000?o0000ooooooooool00_oo
ool2o`0000cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000oooooo0009ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool00000
;oooool01?l0003o0?l0o`3o0?l00002o`3o0003o`000?l0o`3o000000?o0?l000?o0000o`3o0?l0
00000ol0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l000000_l0o`001_l0003o
0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0
003o0?l0o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l0
0_l00003o`3o0003o`000?l0o`3o000000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00004o`3o
0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`001?l0003o0?l0o`000?l0o`04o`0000?o0?l000?o
0000o`3o0?l000000_l0o`002Ol0003o0?l0o`3o0?l0003o0?l0o`000?l0o`3o0000o`3o0002o`00
00Co0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000_l0
0004o`3o00;o00000ol0o`000ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0?ooooo`000_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo0ol00003ooooo`03o`000?oooooooooo
02[ooooo0_l00003o`3o0003o`000?l0o`3o000000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000004
o`3o0003o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o0?l00_l00003o`3o0003o`000?l0
o`3o000000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000004o`3o00;o00000ol0o`000ol0003o0?l0
o`3o0002o`0000Co0?l000?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`00
00?o0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o0?l00_l00003
o`3o0004o`000?l0o`3o0000o`3o00?o000000Go0?l0o`000?l0o`3o0?l0o`000003o`3o0007o`00
0?l0o`3o0?l0o`3o0?l0003o0?l0o`000003o`3o0003o`000?l0o`3o000000;o0?l000Go0000o`3o
0?l0o`3o0?l0o`000004o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000002o`3o0006o`00
0?l0o`3o0?l0o`000?l0o`3o00000ol0o`02o`0000Gooooo00?o0000ooooooooool02Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03_oo
ool000_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02Oooooo0_l000000ol0o`3o
0000o`3o0003o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l0o`000_l00004o`3o00;o
00000ol0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`00
0ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`000002
o`3o0004o`000?l0o`3o0?l0o`3o00;o00000ol0o`000ol0003o0?l0o`000002o`3o0006o`000?l0
o`3o0?l0o`000?l0o`3o00001?l0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o000000;o
0?l000Co0000o`3o0?l0o`3o0?l00ol00002o`3o00;o00000ol0o`000ol0003o0?l0o`3o0002o`00
00Co0?l000?o0000o`3o0?l0o`000_l0o`02o`000004o`3o0?l0003o0?l0o`0000;o0?l000?o0000
o`3o0?l000000ol0o`000ol0003o0?l0o`3o0002o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0
o`000002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00001Oooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00gooooo0008ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Uooooo`03o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l0o`000_l00004o`3o
0003o`000?l0o`3o000000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o0003o`000?l0
o`3o000000?o0?l000?o0000o`3o0?l0o`000_l00004o`3o0003o`000?l0o`3o000000;o0?l000?o
0000o`3o0?l0o`000_l00004o`3o00;o00000ol0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co
0?l000?o0000o`3o0?l0o`000_l0o`02o`0000?o0?l000?o0000o`3o0?l0o`000_l00004o`3o00;o
00000ol0o`05o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`000002o`3o0003
o`000?l0o`3o0?l000;o00001?l0o`002?l0003o0?l0o`3o0?l0003o0?l0o`000?l0o`3o00000_l0
o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o
0?l0o`3o0002o`3o00;o00000_l0o`000ol0003oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool03Oooool000Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool2o`0000Oooooo00?o0000oooooooo
ool08oooool2o`0000Co0?l000?o0000o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l0o`02o`00
00?o0?l000?o0000o`3o0?l000000ol0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o
0?l000000_l0o`001?l0003o0?l0o`3o0?l0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`00
1_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o0000o`3o0?l000000ol0o`000ol0003o0?l0
o`3o0002o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`000002o`3o0005o`00
0?l0o`3o0?l0o`3o0?l000000_l0o`03o`000005o`3o0?l0003o0?l0o`3o0?l000000_l0o`02o`00
00Co0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000_l00003o`3o
00?o00000ol0o`000ol0003o0?l0o`000002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0
o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000ooooooooool00_oo
ool00ol0003oooooo`00000:ooooo`;o00002_ooool2o`0000?ooooo0ol0000@ooooo`002Oooool3
o`0000Cooooo0_l00004ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo027ooooo00Co0000o`3o0?l0o`3o00000ol0o`02o`0000?o0?l000Ko0000o`3o0?l0003o0000
o`3o0?l00004o`3o0003o`000?l0o`3o0?l000;o0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o
00;o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000Co0?l000Oo0000o`3o0?l0o`3o0?l0
o`000?l0o`3o000000?o0?l000?o0000o`3o0?l0o`000_l00004o`3o0003o`000?l0o`3o000000;o
0?l000?o0000o`3o0?l0o`000_l00004o`3o00;o00000ol0o`000ol0003o0?l0o`3o0004o`0000;o
0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003
o`3o00;o00000ol0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000?o00000ol0o`02
o`0000?o0?l000?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l0
00?o0000o`3o0?l0o`000_l0o`000ol0003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo
000Looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool2o`0000?o0?l000Ko
0000o`3o0?l0003o0000o`3o0?l00004o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l0
o`000_l00004o`3o00;o00000ol0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co0?l000?o0000
o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`00
1Ol0003o0?l0o`000?l0o`3o000000Co0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l000Ko
0000o`3o0?l0o`3o0000o`3o0?l00003o`3o00Co000000Oo0?l0o`000?l0o`3o0?l0o`000?l0o`3o
000000Co0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000;o0?l000Ko0000o`3o0?l0o`3o
0000o`3o0?l00004o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000002o`3o0006o`000?l0
o`3o0?l0o`000?l0o`3o00000ol0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`001_l0003o
0?l0o`3o0?l0003o0?l0o`0000;o0?l00_l00007ooooo`03o`000?oooooooooo02_ooooo000Loooo
o`;o00002_ooool00ol0003oooooooooo`0Kooooo`;o000000?o0?l0o`000?l0o`000ol0o`000ol0
003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0o`000002o`3o
0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`000ol0003o0?l0o`000003o`3o0003o`000?l0
o`3o0?l000;o00001?l0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o00001?l0
o`02o`0000?o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o00;o00000ol0o`000ol0003o
0?l0o`000003o`3o0003o`000?l0o`3o000000;o00000ol0o`000ol0003o0?l0o`000003o`3o0003
o`000?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0o`3o0002o`3o00;o00000ol0o`000ol0003o
0?l0o`3o0002o`0000Co0?l000Co0000o`3o0?l0o`3o0?l00ol00002o`3o0006o`000?l0o`3o0?l0
o`000?l0o`3o00000ol0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`00
0002o`3o0003o`000?oooooooooo00Gooooo00?o0000ooooooooool0:_ooool001_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Iooooo`03o`000?l0o`3o0?l000;o0?l000?o0000
o`3o0?l0o`000_l00004o`3o0003o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o0?l00_l0
0003o`3o0003o`000?l0o`3o000000?o0?l000?o0000o`3o0?l0o`000_l00004o`3o0003o`000?l0
o`3o000000;o0?l000Co0000o`3o0?l0o`3o0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l0
00Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o0003o`000?l0o`3o000000;o0?l000Ko0000o`3o
0?l0o`3o0000o`3o0?l00004o`3o0004o`000?l0o`3o0?l0o`3o00Co000000?o0?l0o`000?l0o`00
0ol0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`00
0_l00004o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0
o`3o0002o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`02o`0000;o0?l000Ko0000o`3o0?l0o`3o
0000o`3o0?l00004o`3o0003o`000?l0o`3o0?l000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000006
ooooo`;o0000;?ooool001_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Goooo
o`;o00001?l0o`000ol0003o0?l0o`000002o`3o0004o`000?l0o`3o0?l0o`3o00;o00000ol0o`00
1_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l00_l00004o`3o0005o`000?l0o`3o0000o`3o0?l0
00001?l0o`02o`0000?o0?l000Ko0000o`3o0?l0003o0000o`3o0?l00004o`3o0007o`000?l0o`3o
0?l0o`3o0?l0003o0?l0o`000003o`3o0003o`000?l0o`3o0?l000;o00001?l0o`02o`0000?o0?l0
00?o0000o`3o0?l0o`001Ol000000ol0o`3o0000o`000003o`3o0003o`000?l0o`3o0?l000;o0000
1?l0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l0
0_l00003o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000ol00003o`3o0003o`00
0?l0o`3o0?l000;o0?l00_l00003o`3o0003o`000?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0
o`3o0002o`3o0003o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool001_ooooo0_l0
000>ooooo`03o`000?oooooooooo01Gooooo00Co0000o`3o0?l0o`3o00000ol0o`02o`0000?o0?l0
00Ko0000o`3o0?l0003o0000o`3o0?l00004o`3o0003o`000?l0o`3o0?l000;o0?l000Go0000o`3o
0?l0003o0?l0o`000004o`3o00;o00000ol0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co0?l0
00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l0o`00
0_l0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o
0?l0o`000003o`0000;o0?l000?o0000o`3o0?l000000ol0o`000ol0003o0?l0o`000002o`3o0006
o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`00
1_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l0
0_l000000ol0o`3o0000o`000004o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l00000
0_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Yooooo`006oooool00ol0003oooooooooo`0>ooooo`;o00004oooool2o`0000Co
0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o
0?l0o`000_l00004o`3o00;o00000ol0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o
0000o`3o0?l000000ol0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l000000_l0
o`000ol0003o0?l0o`3o0002o`0000Co0?l00_l00003o`3o0003o`000?l0o`3o0?l000;o00000ol0
o`03o`0000?o0?l000?o0000o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l0o`02o`0000?o0?l0
00?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000Co0?l000Oo0000o`3o
0?l0o`3o0?l0o`000?l0o`3o000000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o00;o
00000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`000_l00004o`3o00;o00000ol0o`000ol0003o
0?l0o`000002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00001oooool2o`0002Wooooo000Koooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003o0?l0o`000004o`3o
00;o00000ol0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l000000_l0o`001_l0
003o0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o0000o`3o0?l000000ol0o`000ol0003o0?l0o`3o
0002o`0000Co0?l000?o0000o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l0o`02o`0000?o0?l0
00?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o0000o`3o
0?l000000_l0o`04o`000003o`3o0?l0003o0?l000?o0?l000?o0000o`3o0?l0o`000_l0o`03o`00
0003o`3o0?l0003o0?l000;o0?l00_l00004o`3o00;o00000ol0o`000ol0003o0?l0o`3o0002o`00
00Co0?l000?o0000o`3o0?l0o`000_l0o`02o`0000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l0
0004o`3o00;o00000_l0o`000ol0003o0?l0o`000002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o
00000ol0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`000ol0003oooooooooo`05ooooo`;o
0000:Oooool001_ooooo0_l0000Booooo`03o`000?oooooooooo00cooooo0_l00003o`3o0006o`00
0?l0o`3o0?l0o`000?l0o`3o00000ol0o`000ol0003o0?l0o`000002o`3o0004o`000?l0o`3o0?l0
o`3o00;o00000ol0o`000ol0003o0?l0o`000003o`3o0003o`000?l0o`3o0?l000;o00001?l0o`00
1Ol0003o0?l0o`000?l0o`3o000000Co0?l00_l00003o`3o0006o`000?l0o`3o0000o`000?l0o`3o
00000ol0o`02o`0000?o0?l000?o0000o`3o0?l000000ol0o`000ol0003o0?l0o`3o0006o`000003
o`3o0?l0003o0?l000;o0?l000?o0000o`3o0?l0o`000_l00004o`3o0003o`000?l0o`3o0?l000;o
0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o
0?l000000_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`02o`00
00?o0?l000?o0000o`3o0?l0o`000_l000001Ol0o`3o0000o`3o0?l0o`3o000000?o0?l000?o0000
o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l00_l00003o`3o00;o0000
1oooool00ol0003oooooooooo`0Wooooo`006_ooool2o`0001Cooooo00?o0000ooooooooool02Ooo
ool2o`000003o`3o0?l0003o0?l000;o0?l000?o0000o`3o0?l000000ol0o`000ol0003o0?l0o`3o
0002o`0000Co0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`001Ol0003o0?l0
o`000?l0o`3o000000Co0?l00_l00003o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`02
o`0000Co0?l00ol000000ol0o`3o0000o`3o0002o`3o00;o00001?l0o`000ol0003o0?l0o`000002
o`0000?o0?l00_l00004o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000_l00004
o`3o00;o00000ol0o`000ol0003o0?l0o`3o0002o`0000Co0?l00_l00003o`3o0003o`000?l0o`3o
000000;o0?l000?o0000o`3o0?l0o`000_l00004o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000
o`3o0?l000000_l0o`02o`000003o`3o0?l0003o000000Co0?l000?o0000o`3o0?l0o`000_l0o`02
o`0000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00002o`3o0003o`000?l0o`3o000000Sooooo
00?o0000ooooooooool09_ooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`;o00001?l0o`000ol0003o0?l0o`3o
0002o`0000Co0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o00;o00000ol0o`000ol0003o0?l0
o`000002o`3o0004o`000?l0o`3o0?l0o`3o00;o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0
o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l000?o
0000o`3o0?l0o`000_l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00ol00003o`3o0005o`00
0?l0o`3o0000o`3o0?l000001?l0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`001_l0003o
0?l0o`3o0?l0003o0?l0o`0000?o0?l000?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0
003o0?l0o`0000?o0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`00
0_l00004o`3o00;o00000ol0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o0000
1?l0o`000ol0003o0?l0o`3o0002o`3o00;o00000ol0o`02o`0000;o0?l000?o0000ooooooooool0
1_ooool2o`0002Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool01?ooool00ol0003o0?l0o`000004o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`02o`00
00?o0?l000Ko0000o`3o0?l0003o0000o`3o0?l00003o`3o00;o00001?l0o`001Ol0003o0?l0o`00
0?l0o`3o000000Co0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l0
0_l00003o`3o0003o`000?l0o`3o0?l000;o00001?l0o`02o`0000?o0?l01?l000000ol0o`3o0000
o`3o0003o`3o0006o`000?l0o`3o0?l0o`3o0?l0003o0?l00_l000000ol0o`3o0000o`3o0002o`3o
00;o00000ol0o`000ol0003o0?l0o`000002o`3o0004o`000?l0o`3o0?l0o`3o00;o00000ol0o`00
0ol0003o0?l0o`000002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`02o`0000?o0?l0
00?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l00_l000001_l0
o`3o0000o`3o0?l0003o0?l0o`0000;o0?l000?o0000o`3o0?l0o`000_l00004o`3o0003o`000?l0
o`3o0?l000;o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Gooooo0005o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000Gooooo`04o`000?ooooooooooooooo`;o
00000ol0o`001?l0003o0?l0o`3o0?l0o`02o`0000?o0?l000Ko0000o`3o0?l0003o0000o`3o0?l0
0003o`3o00;o00001?l0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l00_l00003o`3o0003o`00
0?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0o`000002o`3o0006o`000?l0o`3o0?l0o`000?l0
o`3o00000ol0o`000ol0003o0?l0o`000002o`3o0005o`000?l0o`3o0?l0o`000?l0o`001Ol00000
0ol0o`3o0000o`3o0002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0o`3o0002
o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`000ol0003o0?l0o`3o0002o`3o00?o000000?o
0?l0o`000?l0o`000_l0o`02o`0000Co0?l00_l00002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o
00001?l0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0
003o0?l0o`0000;o0?l00ol00003o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`00
0_l00003o`3o00;o00001?l0o`000ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo
0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo01Oooooo00Go0000ooooool0003o0?l0o`000003o`3o
0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`02o`0000Co0?l000Go0000o`3o0?l0003o0?l0
o`000004o`3o00;o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l000?o0000o`3o
0?l000000_l0o`001?l0003o0?l0o`3o0?l0o`02o`0000?o0?l000?o0000o`3o0?l000000ol0o`00
0ol0003o0?l0o`3o0002o`0000?o0?l000?o0000o`3o0?l000001?l00002o`3o00;o00001?l0o`00
0ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`02o`0000?o0?l000?o0000
o`3o0?l0o`000_l00004o`3o0003o`000?l0o`3o0?l000;o0?l000Go0000o`3o0?l0003o0?l0o`00
0003o`3o00;o00001?l0o`02o`0000?o0?l000?o0000o`3o0?l0o`000_l00004o`3o0003o`000?l0
o`3o0?l000;o0?l00_l00002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`02o`0000?o
0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o
00002_ooool00ol0003oooooooooo`0<ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o
00000oooool3o`0000?ooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Oooooo0_l00003o`3o
0003o`000?l0o`3o0?l000;o00001?l0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l00_l00003
o`3o0006o`000?l0o`3o0000o`000?l0o`3o00001?l0o`000ol0003o0?l0o`3o0002o`3o0003o`00
0?l0o`3o0?l000;o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l00_l00004o`3o
0005o`000?l0o`3o0000o`3o0?l000000ol0o`03o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`00
0004o`3o00;o00000ol0o`000ol0003o0?l0o`000002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o
00000ol0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`02o`0000?o
0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`000ol0003o0?l0o`000002o`3o
0003o`000?l0o`3o0?l000;o00000ol0o`02o`0000Co0?l00_l000000ol0o`3o0000o`000002o`3o
0003o`000?l0o`3o000000?o0?l00_l00003o`3o00;o00000ol0o`000ol0003o0?l0o`000002o`3o
0003o`000?oooooooooo00Oooooo0_l0000<ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`001oooool2o`0000Cooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Gooooo
0_l000000ol0o`3o0000o`3o0002o`3o0003o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o
0?l00_l00003o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`02o`0000Co0?l000?o0000
o`3o0?l0o`000_l00004o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000Co0?l000Go
0000o`3o0?l0003o0?l0o`000004o`3o00;o00000ol0o`05o`0000Co0?l00_l00003o`3o0006o`00
0?l0o`3o0000o`000?l0o`3o00000ol0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`001?l0
003o0?l0o`3o0?l0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0
003o0?l0o`0000?o0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`02o`0000?o
0?l000?o0000o`3o0?l000000_l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l00003o`3o
00?o00000ol0o`03o`000007o`3o0?l0003o0?l0o`3o0?l0003o0?l0o`000003o`3o00;o00000ol0
o`000ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`00
2?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000?ooooo0_l0000Eooooo`;o0000
1?l0o`000ol0003o0?l0o`3o0002o`0000Co0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o
00001?l0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l000?o0000o`3o0?l000000_l0o`001?l0
003o0?l0o`3o0?l0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o00;o00000ol0
o`001ol0003o0?l0o`000?l0003o0?l0o`000?l0o`001?l00003o`3o0006o`000?l0o`3o0000o`00
0?l0o`3o00000ol0o`02o`0000Co0?l00ol000000ol0o`3o0000o`3o0002o`3o00;o00001?l0o`03
o`000003o`3o0?l0003o0?l000;o0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l000Ko0000
o`3o0?l0o`3o0000o`3o0?l00004o`3o0006o`000?l0o`3o0?l0o`3o0?l0003o0?l00_l000000ol0
o`3o0000o`3o0002o`3o00;o00000ol0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000003
o`3o00;o00001?l0o`000ol0003o0?l0o`3o0002o`3o00;o00000_l0o`001_l0003o0?l0o`3o0?l0
003o0?l0o`0000?o0?l00_l0000:ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo000Iooooo`03
o`000?oooooooooo01?ooooo00?o0000o`3o0?l000001?l0o`001Ol0003o0?l0o`000?l0o`3o0000
00Co0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o0?l00_l00003
o`3o0003o`000?l0o`3o0?l000?o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l0
0_l00003o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`02o`0000;o0?l00ol000001?l0
o`3o0000o`3o0?l00003o`3o00;o00001?l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l0
0004o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000Co0?l000Go0000o`3o0?l0003o
0?l0o`000003o`3o00;o00001?l0o`02o`0000?o0?l000?o0000o`3o0?l0o`000_l00004o`3o0003
o`000?l0o`3o0?l000;o0?l00ol000001ol0o`3o0000o`3o0?l0o`3o0000o`3o0?l000001?l0o`00
2Ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`000ol0003o
0?l0o`3o0002o`3o00;o00000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000[ooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_ooool001Wooooo00?o0000ooooooooool04Oooool2o`0000?o0?l000?o
0000o`3o0?l0o`000ol00003o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`02o`0000Co
0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00?o00000_l0o`001?l0003o0?l0o`3o0?l0o`02
o`0000Co0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`001?l0003o0?l0o`00
0?l0o`03o`0000;o0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`02o`0000?o
0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o00;o00000ol0o`001Ol0003o0?l0o`000?l0o`3o
000000Co0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000Co0?l000?o
0000o`3o0?l000000_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l000?o0000o`3o0?l0o`000_l0
o`02o`0000?o0?l000?o0000o`3o0?l0o`000_l00004o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o
0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0o`3o0002o`3o00;o
00000_l0o`000ol0003oooooooooo`08ooooo`;o00002_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo0_l00004ooooo`006Oooool2o`00017ooooo00?o0000o`3o
0?l000000ol0o`03o`0000?o0?l000?o0000o`3o0?l0o`000_l00004o`3o0005o`000?l0o`3o0000
o`3o0?l000001?l0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`002Ol0003o0?l0o`3o0?l0
o`3o0000o`3o0?l0003o0?l0o`000004o`3o00;o00000ol0o`001Ol0003o0?l0o`000?l0o`3o0000
00Co0?l01?l000000ol0o`3o0000o`3o0002o`000003o`3o0?l0003o0?l000;o0?l00_l00003o`3o
0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`02o`0000?o0?l000Ko0000o`3o0?l0003o0000
o`3o0?l00003o`3o00;o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l00_l00003
o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0
o`000ol0003o0?l0o`3o0002o`0000?o0?l00_l00004o`3o0003o`000?l0o`3o000000;o0?l000?o
0000o`3o0?l0o`000_l00004o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000002o`3o0003
o`000?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0o`3o0002o`3o0003o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo000Iooooo`03o`000?oooooooooo00kooooo0_l00003o`3o0003o`000?l0o`3o000000;o0?l0
00Co0000o`3o0?l0o`3o0?l00ol00002o`3o0004o`000?l0o`3o0?l0o`3o00;o00000ol0o`001_l0
003o0?l0o`000?l0003o0?l0o`0000?o0?l00_l00004o`3o0003o`000?l0o`3o0?l000;o00000ol0
o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l00_l00003o`3o0003o`000?l0o`3o000000?o
00000ol0o`02o`0000Co0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`001Ol0
003o0?l0o`000?l0o`3o000000?o0?l00_l00004o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0
o`02o`0000Co0?l00ol000000ol0o`3o0000o`3o0002o`3o00;o00000ol0o`001_l0003o0?l0o`00
0?l0003o0?l0o`0000?o0?l00_l00003o`3o0003o`000?l0o`3o000000;o0?l000Go0000o`3o0?l0
003o0?l0o`000004o`3o00;o00000ol0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l0
00;o00001?l0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`000ol0003o0?l0o`3o
0002o`0000?o0?l00_l0000;ooooo`03o`000?oooooooooo01oooooo000Iooooo`03o`000?oooooo
oooo00cooooo0_l000000ol0o`3o0000o`3o0002o`3o00;o00001?l0o`001Ol0003o0?l0o`000?l0
o`3o000000Co0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`001Ol0003o0?l0
o`000?l0o`3o000000Co0?l00ol00002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`001Ol0003o
0?l0o`000?l0o`3o000000;o0?l00ol00004o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`02
o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o00;o00000ol0o`001Ol0003o0?l0o`00
0?l0o`3o000000Co0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000Co
0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`03o`000003o`3o0?l0003o0?l0
00;o0?l00_l00004o`3o0006o`000?l0o`3o0?l0o`3o0?l0003o0?l00_l000000ol0o`3o0000o`3o
0002o`3o00;o00000ol0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o00000ol0
o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`001Ol0003o0?l0o`000?l0o`3o000000cooooo
00?o0000ooooooooool07_ooool001Sooooo0_l0000<ooooo`?o00000ol0o`001Ol0003o0?l0o`00
0?l0o`3o000000Co0?l00_l00003o`3o0003o`000?l0o`3o0?l000?o00000ol0o`001Ol0003o0?l0
o`000?l0o`3o000000Co0?l00_l00003o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`03
o`000003o`3o0?l0003o0?l000?o0?l00_l00002o`3o00Co000000?o0?l0o`000?l0o`000ol0o`02
o`0000?o0?l000Ko0000o`3o0?l0003o0000o`3o0?l00003o`3o00;o00000ol0o`001_l0003o0?l0
o`000?l0003o0?l0o`0000?o0?l00_l00003o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000ol0
o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o00;o00000ol0o`001Ol0003o0?l0
o`000?l0o`3o000000?o0?l00_l00004o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`00
00Co0?l000?o0000o`3o0?l0o`000_l0o`03o`000003o`3o0?l0003o0?l000;o0?l00_l00003o`3o
00?o00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l00004o`3o0005o`000?l0o`3o
0?l0o`3o0?l000002oooool2o`0001oooooo000Hooooo`03o`000?oooooooooo00Sooooo0ol00003
o`3o0003o`000?l0o`3o0?l000;o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l0
0ol00003o`3o0003o`000?l0o`3o0?l000;o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`00
00?o0?l00_l00004o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`001Ol0003o0?l0o`000?l0
003o0?l000?o000000?o0?l0o`000?l000000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o
0?l00_l00004o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000Co0?l00ol000000ol0
o`3o0000o`3o0002o`3o00;o00001?l0o`03o`000003o`3o0?l0003o0?l000;o0?l00_l00003o`3o
0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0
o`000004o`3o00;o00000ol0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o0000
1?l0o`000ol0003o0?l0o`3o0002o`3o00?o000000?o0?l0o`000?l0o`000_l0o`03o`0000;o0?l0
0_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000Co0?l000?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Mooooo`006?ooool00ol0003oooooooooo`07ooooo`04o`00
0?l0o`3o0?l0o`0000?o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o00000ol0o`001Ol0003o
0?l0o`000?l0o`3o000000Co0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o00000ol0o`001Ol0
003o0?l0o`000?l0o`3o000000Co0?l00_l00003o`3o0003o`000?l0o`3o0?l000Go000000Ko0?l0
o`000?l0o`3o0000o`3o0?l00003o`3o00;o00001?l0o`001Ol0003o0?l0o`000?l0o`3o000000Co
0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000Co0?l000Go0000o`3o
0?l0003o0?l0o`000003o`3o00;o00001?l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l0
0004o`3o00?o000000?o0?l0o`000?l0o`000_l0o`02o`0000?o0?l000Ko0000o`3o0?l0003o0000
o`3o0?l00003o`3o00;o00000ol0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o
00000ol0o`02o`0000Co0?l00ol000001ol0o`3o0000o`000?l0o`3o0000o`3o0?l000000ol0o`02
o`0000?o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`3o0002o`0000cooooo00?o0000
ooooooooool07?ooool001Sooooo00?o0000ooooooooool01Oooool2o`0000Co0?l000Go0000o`3o
0?l0003o0?l0o`000003o`3o00?o00000ol0o`000ol0003o0?l0o`3o0002o`0000?o0?l000Ko0000
o`3o0?l0003o0000o`3o0?l00003o`3o00?o00000ol0o`000ol0003o0?l0o`3o0002o`0000?o0?l0
00Ko0000o`3o0?l0003o0000o`3o0?l00003o`3o00Ko00000_l0o`03o`0000?o0?l000Go0000o`3o
0?l0003o0?l0o`000004o`3o00;o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l0
0_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`02o`0000?o0?l000Go0000o`3o0?l0
003o0?l0o`000004o`3o00;o00000ol0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l00004
o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000Co0?l00ol000000ol0o`3o0000o`3o
0002o`3o00;o00000ol0o`000ol0003o0?l0o`000002o`3o0005o`000?l0o`3o0000o`3o0?l00000
0ol0o`02o`0000Co0?l00_l00002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`02o`00
00?o0?l000Go0000o`3o0?l0003o0?l0o`00000=ooooo`03o`000?oooooooooo01_ooooo000Hoooo
o`;o00000oooool3o`0000;o0?l000?o0000o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o0000
00;o0?l000Co0000o`3o0?l0o`3o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o00000ol0o`00
1Ol0003o0?l0o`000?l0o`3o000000Co0?l00ol00002o`3o0003o`000?l0o`3o0?l000;o00001?l0
o`000ol0003o0?l0o`000002o`0000?o0?l00ol00003o`3o0003o`000?l0o`3o0?l000;o00000ol0
o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l00_l00004o`3o00?o000000?o0?l0o`000?l0
o`000_l0o`02o`0000?o0?l000Ko0000o`3o0?l0003o0000o`3o0?l00003o`3o00;o00000ol0o`00
1_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l0
00001?l0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`03o`00
0003o`3o0?l0003o0?l000;o0?l00_l00003o`3o00;o00000ol0o`001Ol0003o0?l0o`000?l0o`3o
000000?o0?l00_l000001?l0o`3o0000o`3o0?l0o`02o`0000?o0?l00ol000000ol0o`3o0000o`3o
0002o`3o00;o00000ol0o`000ol0003oooooooooo`09ooooo`;o00007Oooool0017ooooo0_l00005
ooooo`03o`000?oooooo000000;o00000_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l000?o0000
o`3o0?l0o`000_l00004o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`03o`0000?o0?l000?o
0000o`3o0?l0o`000_l00003o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`03o`0000;o
0?l000?o0000o`3o0?l0o`000ol00003o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`03o`00
00;o0?l000?o0000o`3o0?l0o`000_l00004o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02
o`0000Co0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`001Ol0003o0?l0o`00
0?l0o`3o000000?o0?l00_l00004o`3o00?o000000?o0?l0o`000?l0o`000_l0o`02o`0000?o0?l0
00Ko0000o`3o0?l0003o0000o`3o0?l00003o`3o00;o00000ol0o`001Ol0003o0?l0o`000?l0o`3o
000000?o0?l00_l00004o`3o00?o000000Oo0?l0o`000?l0o`3o0?l0o`000?l0o`3o000000Co0?l0
00Wo0000o`3o0?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l000000_l0o`03o`0000Co0?l000?o0000
o`3o0?l0o`000_l0o`03o`000004o`3o0?l0003o0?l0o`3o00;o00003Oooool00ol0003ooooooooo
o`0Jooooo`004?ooool01?l0003oooooooooool00004ooooo`;o000000?o0?l0o`000?l0o`000_l0
o`03o`0000?o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000ol0
o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o0000
0ol0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l01?l00002o`3o0003o`000?l0o`3o0?l000;o
00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l00ol00002o`3o0003o`000?l0o`3o
0?l000?o00000ol0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l00_l00003o`3o0005o`000?l0
o`3o0000o`3o0?l000001?l0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o
00001?l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l00004o`3o00?o000000?o0?l0o`00
0?l0o`000_l0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`02
o`0000?o0?l000?o0000o`3o0?l0o`000_l00003o`3o00;o00000ol0o`001Ol0003o0?l0o`000?l0
o`3o000000?o0?l00_l00004o`3o0003o`000?l0o`3o0?l000;o0?l00_l000000ol0o`3o0000oooo
o`0<ooooo`03o`000?oooooooooo01[ooooo000@ooooo`04o`000?ooooooooooo`0000?ooooo0_l0
0003o`3o0003o`000?l0o`3o000000?o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0
o`3o0?l000?o00000ol0o`000ol0003o0?l0o`3o0002o`0000?o0?l000Ko0000o`3o0?l0003o0000
o`3o0?l00003o`3o00?o00000ol0o`000ol0003o0?l0o`3o0002o`0000?o0?l01?l000000ol0o`3o
0000o`3o0002o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l000Go0000o`3o0?l0
003o0?l0o`000003o`3o00?o00000ol0o`000ol0003o0?l0o`3o0002o`0000?o0?l000Ko0000o`3o
0?l0003o0000o`3o0?l00003o`3o00;o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o
0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`02o`0000?o0?l000Go0000o`3o
0?l0003o0?l0o`000003o`3o00;o00001?l0o`03o`000003o`3o0?l0003o0?l000;o0?l00_l00003
o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000Co0?l000?o0000o`3o0?l000000_l0
o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l000001_l0o`3o0000o`3o0?l0003o0?l0o`00
00;o0?l000?o0000o`3o0?l0o`000_l00003o`3o00;o00000ol0o`000ol0003oooooooooo`0;oooo
o`;o00006_ooool0013ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000002o`3o
00;o00001?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o0?l0
00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000004
o`3o00?o00000_l0o`05o`0000Co0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00?o00000ol0
o`000ol0003o0?l0o`3o0002o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o00?o0000
0_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o
00001?l0o`03o`000003o`3o0?l0003o0?l000;o0?l00_l00003o`3o0006o`000?l0o`3o0000o`00
0?l0o`3o00000ol0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0
o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l0
00001?l0o`02o`0000?o0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0o`03o`00
00?o0?l000?o0000o`3o0?l000000_l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l0000=
ooooo`03o`000?oooooooooo01Sooooo000@ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00_l00002o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`03o`0000?o0?l0
00?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000ol0o`000ol0003o0?l0
o`3o0002o`0000?o0?l000Co0000o`3o0?l0003o00000_l0o`06o`0000;o0?l000?o0000o`3o0?l0
o`000ol00003o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`03o`0000;o0?l000?o0000o`3o
0?l0o`000_l00003o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`03o`0000;o0?l000?o
0000o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000_l0
0004o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000Co0?l00ol000000ol0o`3o0000
o`3o0002o`3o00;o00000ol0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l00_l00003o`3o0005
o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000?o0?l000Oo0000o`3o0?l0003o0000o`3o0?l0
003o0?l000;o000000?o0?l0o`000?l0o`000_l0o`02o`0000?o0?l00ol000000ol0o`3o0000o`3o
0002o`3o00;o00000ol0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`00000=ooooo`03o`00
0?oooooooooo00Kooooo0_l0000@ooooo`004?ooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000_l0o`03o`0000?o0?l000?o0000o`3o0?l000000_l0o`000ol0003o
0?l0o`3o0004o`0000;o0?l000?o0000o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o0?l000?o
00000_l0o`000ol0003o0?l0o`3o0003o`000003o`3o0?l0003o000000?o00000_l0o`000ol0003o
0?l0o`3o0003o`0000?o0?l000?o0000o`3o0?l0o`000_l00003o`3o0006o`000?l0o`3o0000o`00
0?l0o`3o00000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`000_l00004o`3o0005o`000?l0o`3o
0000o`3o0?l000000ol0o`03o`0000?o0?l000?o0000o`3o0?l0o`000_l00003o`3o00?o00000_l0
o`000ol0003o0?l0o`3o0003o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o0000
1?l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l00003o`3o0006o`000?l0o`3o0000o`00
0?l0o`3o00000ol0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00000ol0
o`02o`0000Co0?l00ol000001?l0o`3o0000o`3o0?l0o`02o`0000;o0?l000?o0000o`3o0?l00000
0_l000001ol0o`3o0000o`3o0?l0o`3o0000o`3o0?l000000ol0o`02o`0000?o0?l000?o0000oooo
ooooool02oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000oooooo000Aoooo
o`;o00001?ooool2o`0000?ooooo0_l00003o`3o0003o`000?l0o`3o0?l000;o00000ol0o`03o`00
00?o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`000ol0
003o0?l0o`3o0003o`000008o`3o0?l0003o0000o`000?l0o`3o0000o`3o0?l00003o`3o00?o0000
0_l0o`000ol0003o0?l0o`3o0004o`0000;o0?l000?o0000o`3o0?l0o`000_l00004o`3o0005o`00
0?l0o`3o0000o`3o0?l000000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00003o`3o0005
o`000?l0o`3o0000o`3o0?l000001?l0o`03o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`000003
o`3o00?o00000ol0o`000ol0003o0?l0o`3o0002o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`00
0004o`3o00;o00000ol0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l00004o`3o00?o0000
00?o0?l0o`000?l0o`000_l0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`001Ol0003o0?l0
o`000?l0o`3o000000?o0?l00_l00004o`3o00;o000000?o0?l0o`000?l0o`000_l0o`02o`0000Co
0?l00_l00003o`3o00?o000000Co0?l0o`000?l0o`3o0?l00_l0000=ooooo`;o00001Oooool01?l0
003oooooooooool0000?ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?l0o`3o0?l0
00?o00000_l0o`000ol0003o0?l0o`000003o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0
003o0?l0o`3o0003o`0000?o0?l000?o0000o`3o0?l0o`000ol000001Ol0o`3o0000o`000?l0003o
0?l000?o00000ol0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00ol00003o`3o0003o`000?l0
o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l000?o0000o`3o0?l000000_l0
o`000ol0003o0?l0o`3o0003o`0000?o0?l000?o0000o`3o0?l0o`000_l00003o`3o0006o`000?l0
o`3o0000o`000?l0o`3o00000_l0o`03o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o
00?o00000_l0o`000ol0003o0?l0o`3o0002o`0000?o0?l000Ko0000o`3o0?l0003o0000o`3o0?l0
0002o`3o00?o00000ol0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l00004o`3o00?o0000
00Co0?l0o`000?l0o`3o0?l00ol00003o`3o00;o00000ol0o`001Ol0003o0?l0o`000?l0o`3o0000
00?o0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000?o0?l00_l00004
o`3o00;o000000?o0?l0o`000?ooool03Oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000oooooo000Gooooo`03o`000?oooooooooo00Gooooo0_l00002o`3o0003o`000?l0o`3o
0?l000Co00000_l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o
0?l000?o000000Go0?l0o`000?l0003o0000o`3o0003o`0000?o0?l000?o0000o`3o0?l0o`000_l0
0003o`3o0003o`000?l0o`3o000000?o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0
o`3o0?l000?o00000ol0o`000ol0003o0?l0o`3o0002o`0000?o0?l00ol00002o`3o0003o`000?l0
o`3o0?l000Co00000_l0o`000ol0003o0?l0o`3o0002o`0000?o0?l00ol00003o`3o0003o`000?l0
o`3o0?l000;o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l00ol00002o`3o0003
o`000?l0o`3o0?l000;o00000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00003o`3o0003
o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000_l00003o`3o00?o00000_l0o`001_l0003o
0?l0o`000?l0003o0?l0o`0000?o0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0
o`02o`0000;o0?l00_l000002Ol0o`3o0000o`3o0?l0o`3o0000o`3o0?l0003o0?l0o`000003o`3o
00;o00000ol0o`000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00003oooool001Kooooo0_l00008ooooo`03o`000?l0o`3o0?l000Co00000_l0o`03o`00
00;o0?l000?o0000o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o0?l000?o000000Go0?l0o`00
0?l0003o0000o`3o0003o`0000?o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o
0?l000;o00001?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o
0?l000Co00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00ol00003o`3o0003o`000?l0
o`3o0?l000?o00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l00ol00002o`3o0003o`00
0?l0o`3o0?l000;o00001?l0o`03o`000003o`3o0?l0003o0?l000;o0?l00ol00002o`3o0005o`00
0?l0o`3o0000o`3o0?l000000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00003o`3o00?o
00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l00004o`3o00?o000000?o0?l0o`00
0?l0o`000_l0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00000ol0o`02
o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00003?ooool3o`0000?ooooo00Co
0000oooooooooooo00003oooool001Kooooo00?o0000ooooooooool02?ooool3o`0000;o0?l00ol0
0002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0004o`000005o`3o0?l0
003o0000o`000?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`000ol0003o0?l0
o`3o0003o`0000;o0?l000Co0000o`3o0?l0003o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o
0?l000?o0000o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o0?l000;o00000ol0o`001Ol0003o
0?l0o`000?l0o`3o000000Co0?l00ol00002o`3o0003o`000?l0o`3o0?l000;o00000ol0o`001_l0
003o0?l0o`000?l0003o0?l0o`0000?o0?l00ol00002o`3o0003o`000?l0o`3o0?l000;o00001?l0
o`03o`000003o`3o0?l0003o0?l000;o0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l00000
0ol0o`03o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00000ol0o`001Ol0003o
0?l0o`000?l0o`3o000000?o0?l00_l00004o`3o00?o000000?o0?l0o`000?l0o`000_l0o`02o`00
00?o0?l000Ko0000o`3o0?l0003o0?l0o`000?l0o`02o`000003o`3o0?l0003o0?l000;o0?l00_l0
0003o`3o0005o`000?l0o`3o0000o`3o0?l000002Oooool3o`000003ooooool0003o000000Cooooo
0_l0000@ooooo`005_ooool00ol0003oooooooooo`0;ooooo`;o00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o00?o000000Co0?l0o`000?l0003o0000
0_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`00
0?l0o`3o0?l000;o00001?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`00
0?l0o`3o0?l000Co00000_l0o`000ol0003o0?l0o`3o0002o`0000?o0?l000Co0000o`3o0?l0003o
00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000_l00004o`3o00?o
000000?o0?l0o`000?l0o`000_l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000_l00004o`3o0003
o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000_l00003o`3o0005o`000?l0o`3o0000o`3o
0?l000001?l0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00000ol0o`00
1Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l00004o`3o00?o000000?o0?l0o`000?l0o`000_l0
o`02o`0000;o0?l00_l00004o`3o00?o000000?o0?l0o`000?l0o`000_l0o`02o`0000?o0?l000?o
0000ooooooooool00oooool3o`0000Gooooo00?o0000ooooooooool05?ooool001Kooooo00?o0000
ooooooooool03?ooool00ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00003
o`3o00;o000000Co0?l0o`000?l0003o00000_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l000?o
0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`001?l0003o0?l0o`00
0?l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l0
00?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`03o`0000;o0?l0
00?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0
o`000002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l0
0ol00002o`3o0003o`000?l0o`3o0?l000;o00000ol0o`001_l0003o0?l0o`000?l0003o0?l0o`00
00?o0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000?o0?l000Go0000
o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`03o`000006o`3o0?l0003o0?l0o`000?l0o`3o
00000ol0o`02o`0000Co0?l00ol000001?l0o`3o0000o`3o0?l0o`02o`000003ooooool0003o0000
00;o00002?ooool00ol0003oooooooooo`0Dooooo`005_ooool2o`0000kooooo0_l00002o`3o0003
o`000?l0o`3o0?l000?o00000ol0o`06o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003
o`000?l0o`3o0?l000Co00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0
o`001?l00002o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0
o`001?l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`001_l0003o0?l0o`000?l0003o0?l0
o`0000;o0?l01?l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003
o`0000?o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`001_l0003o0?l0o`000?l0
003o0?l0o`0000?o0?l00ol00002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`03o`000004o`3o
0?l0003o0?l0o`3o00?o00000ol0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o
00000ol0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o00000ol0o`02o`0000?o
0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00001?l0o`02o`0000;o0?l000?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Dooooo`005_ooool00ol0003oooooooooo`0>ooooo`03
o`000?l0o`3o0?l000?o00000ol0o`06o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003
o`000?l0o`3o0?l000Co00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l01_l00002o`3o00Co
00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00003o`3o0003
o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0002o`0000?o0?l00ol00003o`3o0003
o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000Ko0000o`3o0?l0
003o0000o`3o0?l00003o`3o00?o00000_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l00ol00000
0ol0o`3o0000o`3o0002o`3o00?o00000_l0o`000ol0003o0?l0o`3o0002o`0000?o0?l00ol00002
o`3o0003o`000?l0o`3o0?l000?o00000ol0o`03o`000004o`3o0?l0003o0?l0o`3o00?o00000ol0
o`03o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00000ol0o`001Ol0003o0?l0
o`000?l0o`3o000000?o0?l00_l00003o`3o00;o00003?ooool00ol0003oooooooooo`0Cooooo`00
5Oooool00ol0003oooooooooo`0@ooooo`?o00000_l0o`06o`0000;o0?l000?o0000o`3o0?l0o`00
0ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`06o`0000;o0?l00ol00002o`3o0003o`00
0?l0o`3o0?l000?o00000ol0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`00
0ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l0
00?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`3o0004o`0000;o0?l000?o0000o`3o0?l0o`00
0ol00002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`000ol0003o0?l0o`000002o`3o0003o`00
0?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l00ol000001?l0o`3o0000
o`3o0?l0o`04o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00?o00000_l0o`001_l0
003o0?l0o`000?l0003o0?l0o`0000;o0?l00ol00002o`3o0006o`000?l0o`3o0000o`000?l0o`3o
00000ol0o`02o`0000?o0?l000Co0000o`3o0?l0003o0?l00_l00002o`3o00;o00000ol0o`001_l0
003o0?l0o`000?l0o`3o0000o`3o00;o000000?o0?l0o`000?ooool02oooool00ol0003ooooooooo
o`0Cooooo`005Oooool3o`0001;ooooo1_l00002o`3o00Ko00000_l0o`06o`0000;o0?l01?l00002
o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000
o`3o0?l0o`001?l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003
o`0000?o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000;o00000ol0o`03
o`0000;o0?l000?o0000o`3o0?l0o`001?l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`00
0ol0003o0?l0o`3o0003o`0000?o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`00
0ol0003o0?l0o`3o0002o`0000?o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o00000ol0o`00
1Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l00004o`3o00;o000000?o0?l0o`000?l0o`000_l0
o`02o`0000Co0?l00ol000000ol0o`3o0000o`3o0002o`3o00;o00000ol0o`03o`000003o`3o0?l0
003o0?l000;o0?l00_l00002o`3o00;o00001?l0o`000ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01?ooooo000Eooooo`03o`000?oooooooooo00oooooo0ol00002ooooo`03o`000?l0o`3o
0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00003
o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000
o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003
o`0000;o0?l000?o0000o`3o0?l0o`001?l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`00
0ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000?o00000ol0o`000ol0003o0?l0o`3o0003
o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0006o`000?l0o`3o0000o`000?l0o`3o0000
0ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0005o`000?l0o`3o0000o`3o0?l0
00000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o000000;o
0?l000?o0000o`3o0?l0o`000_l00003o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0
o`000_l00004o`3o00?o000000Co0?l0o`000?l0o`3o0?l00ol00003o`3o00?o000000Ko0?l0o`00
0?l0o`3o0000o`3o0?l00003o`3o00;o00002oooool00ol0003oooooooooo`0Cooooo`0000Cooooo
o`000?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00cooooo0ol0
0006ooooo`;o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol0
0003o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o
0000o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00003o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`000ol0003o0?l0o`3o0003o`0000;o0?l00ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0
o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000_l00004o`3o00?o000000Co
0?l0o`000?l0o`3o0?l01?l00002o`3o0003o`000?l0o`3o0?l000;o00000ol0o`000ol0003o0?l0
o`000002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l0
0ol00002o`3o0003o`000?l0o`3o0?l000;o00000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`00
0_l00003o`3o00?o00000_l0o`02o`000003o`3o0?l0003o000000?o0?l00_l00003o`3o0005o`00
0?l0o`3o0000o`3o0?l000002oooool00ol0003oooooooooo`0Cooooo`000_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`09ooooo`?o00002_ooool00ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o
0?l0o`001?l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`00
00;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`000ol0
003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l0
00Co00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l00ol00002o`3o0003o`000?l0o`3o0?l0
00?o00000_l0o`000ol0003o0?l0o`3o0004o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o
0003o`000?l0o`3o0?l000;o00000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`001?l00002o`3o
0003o`000?l0o`3o0?l000;o00000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o
0006o`000?l0o`3o0000o`000?l0o`3o00000ol0o`03o`0000;o0?l000Go0000o`3o0?l0003o0?l0
o`000003o`3o00?o00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00ol00002o`3o0005
o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000?o0?l000?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Cooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`06ooooo`?o00003_ooool2
o`0000;o0?l01ol00002o`3o00Ko00000_l0o`06o`0000;o0?l01_l00002o`3o00Ko00000_l0o`07
o`0000;o0?l01_l00002o`3o00Ko00000_l0o`07o`0000;o0?l00ol00002o`3o0003o`000?l0o`3o
0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`001?l00002
o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o
0?l000?o00000_l0o`000ol0003o0?l0o`3o0004o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`00
0003o`3o00?o00000_l0o`000ol0003o0?l0o`3o0002o`0000Co0?l00ol000001?l0o`3o0000o`3o
0?l0o`03o`0000?o0?l00ol000000ol0o`3o0000o`3o0002o`3o00;o00000ol0o`03o`000003o`3o
0?l0003o000000;o0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0o`03o`0000Wo
oooo00?o0000ooooooooool04oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo0_l00005ooooo`?o00004oooool2o`00
00?o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0
003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l0
00?o00000ol0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o
0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0004o`0000;o0?l000?o0000o`3o
0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`00
00?o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`03o`00
00;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000ol0o`000ol0
003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0002o`00
00?o0?l00ol00002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`03o`000004o`3o0?l0003o0?l0
o`3o00;o00001?l0o`03o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`03o`0000;o0?l000?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`000_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooooooool3o`0001Sooooo00?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o
00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003
o`000?l0o`3o0?l000?o00000ol0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0
o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o
0?l000?o0000o`3o0?l0o`001?l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o
0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`001?l00002o`3o0003o`000?l0o`3o0?l000?o
00000_l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o
00000_l0o`000ol0003o0?l0o`3o0003o`0000?o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o
00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00ol00002o`3o0003o`000?l0o`3o0?l0
00;o00000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`000_l000000ol0o`3o0000o`3o0003o`00
00;o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00002Oooool00ol0003oooooooooo`0B
ooooo`0000?oooooo`000?l000001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000?ooooo1?l0000Looooo`;o00000_l0o`06o`0000;o0?l01_l00002o`3o0003o`000?l0
o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`001?l0
0002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o
0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000ol0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`000ol0003o0?l0o`3o0004o`000003o`3o0?l0003o000000;o00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`001_l0003o0?l0o`000?l0003o0?l0o`0000;o0?l01?l000001?l0o`3o0000o`3o0?l0o`03o`00
00?o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000Go0000o`3o
0?l0003o0?l0o`000003o`3o00?o00000_l0o`03o`000003o`3o0?l0003o0?l000;o0?l00_l00003
o`3o0005o`000?l0o`3o0000o`3o0?l000002Oooool00ol0003oooooooooo`0Booooo`000_ooool0
0ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l0000Pooooo`;o00000_l0o`00
0ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`001_l00002o`3o00Ko00000_l0o`06
o`0000;o0?l01ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003
o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`00
0ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o
0?l000?o00000_l0o`03o`0000;o0?l000?o0000o`3o0?l0o`001?l000001?l0o`3o0000o`3o0?l0
o`04o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000;o00000ol0
o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000ol0
o`03o`000004o`3o0?l0003o0?l0o`3o00?o00000ol0o`001Ol0003o0?l0o`000?l0o`3o000000;o
0?l01?l00002o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0o`03o`0000?o0?l000?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Booooo`005_ooool00ol0003oooooooooo`0Nooooo`03
o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0
o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000?o
0?l000?o0000o`3o0?l0o`001_l00002o`3o00Ko00000_l0o`06o`0000;o0?l01_l00002o`3o00Oo
000000?o0?l0o`000?l000001Ol00002o`3o00Ko00000_l0o`03o`0000;o0?l000?o0000o`3o0?l0
o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0004o`0000;o
0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0
o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`001_l0003o0?l0o`000?l0003o0?l0
o`0000;o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`03o`0000;o0?l000?o0000
o`3o0?l000000ol00002o`3o00?o00000_l0o`000ol0003o0?l0o`3o0002o`0000Sooooo00?o0000
ooooooooool04_ooool001Oooooo00?o0000ooooooooool07_ooool2o`0000;o0?l01_l00002o`3o
0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o
0?l0o`000ol00003o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`00
00;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0
003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l0
00Co00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o
0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o
0?l0o`001?l00002o`3o0003o`000?l0o`3o0?l000;o00000_l0o`04o`0000;o0?l000?o0000o`3o
0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000;o00000ol0o`03o`0000;o0?l000?o0000o`3o
0?l0o`000ol00002o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`04o`000006o`3o0?l0003o
0?l0o`000?l0o`3o00000ol0o`03o`0000;o0?l000?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Booooo`006?ooool00ol0003oooooooooo`0Oooooo`;o00000_l0o`000ol0003o0?l0o`3o
0006o`0000;o0?l01_l00002o`3o00Ko00000_l0o`07o`0000;o0?l000?o0000o`3o0?l0o`000ol0
0002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o
0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`001?l000001?l0o`3o0000o`3o0?l0o`04o`0000;o0?l0
00?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0
o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`001?l000001?l0o`3o0000o`000?l00002o`3o0003
o`000?l0o`3o0?l000Co000000Co0?l0o`000?l0o`3o0?l01?l00002o`3o0005o`000?l0o`3o0000
o`3o0?l000000_l0o`04o`0000;o0?l000?o0000o`3o0?l0o`000_l00003o`3o0003o`000?l0o`3o
000000;o0?l00_l000000ol0o`3o0000o`000003o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0
o`03o`0000Kooooo00?o0000ooooooooool04_ooool001Wooooo0_l0000Pooooo`03o`000?l0o`3o
0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002
o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0007o`0000;o0?l01_l00002
o`3o00Ko00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002
o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000
o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000Co00000_l0o`000ol0003o0?l0o`3o0003
o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`03
o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`00
0ol0003o0?l0o`3o0003o`0000;o0?l00ol00002o`3o0003o`000?l0o`3o0?l000Co000000Co0?l0
o`000?l0o`3o0?l00ol00003o`3o00?o000000Co0?l0o`000?l0o`3o0?l00ol00002o`3o00?o0000
0_l0o`000ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Kooooo`03o`000?oo
oooooooo01kooooo0_l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`000ol0003o0?l0o`3o0004o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0
o`3o0?l000Ko00000_l0o`06o`0000;o0?l01_l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0
o`3o0?l000Co000000Co0?l0o`000?l0o`3o0?l01?l00002o`3o0003o`000?l0o`3o0?l000?o0000
0_l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o0000
0_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0
o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0007o`000?l0o`3o0000o`000?l0
o`3o0000o`3o0004o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00001_ooool0
0ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`0Oooooo`Ko000000?o0?l0o`00
0?l000001?l00002o`3o00Ko00000_l0o`06o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o
0003o`000?l0o`3o0?l000Co00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o
0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0006o`00
00;o0?l01_l00002o`3o00Ko00000_l0o`06o`0000;o0?l01_l00002o`3o00Oo000000?o0?l0o`00
0?l000000_l000001?l0o`3o0000o`3o0?l0o`04o`0000;o0?l000?o0000o`3o0?l0o`000ol00002
o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l00ol00002
o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0002o`0000?o0?l00ol00002
o`3o0003o`000?l0o`3o0?l000;o00000ol0o`001Ol0003o0?l0o`000?l0o`3o000000Kooooo00?o
0000ooooooooool04Oooool001gooooo00?o0000ooooooooool08?ooool00ol0003o0?l0o`3o0002
o`0000?o0?l000?o0000o`3o0?l000000_l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`00
0ol0003o0?l0o`3o0006o`0000;o0?l01_l00002o`3o00Oo000000Co0?l0o`000?l0o`3o0?l01?l0
0002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o
0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0
o`3o0?l000Co000000Co0?l0o`000?l0o`3o0?l01?l000001?l0o`3o0000o`3o0?l0o`04o`0000;o
0?l00ol000001?l0o`3o0000o`3o0?l0o`04o`000004o`3o0?l0003o0?l0o`3o00Co00000_l0o`00
1_l0003o0?l0o`000?l0o`3o0000o`3o00Go000000Co0?l0o`000?l0o`3o0?l00ol00002o`3o00;o
00001Oooool00ol0003oooooooooo`0Aooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000
0_l0o`000ol0003o0?l0o`3o0002o`0000?o0?l000?o0000o`3o0?l000000_l00002o`3o0003o`00
0?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`00
0ol00002o`3o0003o`000?l0o`3o0?l000Ko00000_l0o`07o`000003o`3o0?l0003o000000Go0000
00Co0?l0o`000?l0o`3o0?l01?l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o
0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o
00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003
o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0
o`000ol00002o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000_l0o`03o`0000;o0?l000?o0000
o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`04o`000004o`3o0?l0003o
0?l0o`3o00?o00000_l0o`000ol0003o0?l0o`000002o`3o0003o`000?oooooooooo00;ooooo00?o
0000ooooooooool04Oooool001oooooo0_l0000Qooooo`03o`000?l0o`3o0?l000?o00000_l0o`00
0ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l000000_l00002o`3o0003o`000?l0o`3o
0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002
o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000
o`3o0?l0o`001_l00002o`3o00Oo000000?o0?l0o`000?l000001Ol000001?l0o`3o0000o`3o0?l0
o`04o`000004o`3o0?l0003o0?l0o`3o00Co00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l0
00?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0
o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o00Ko00000_l0o`03o`0000;o0?l0
00?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0
o`000002o`3o0003o`000?l0o`3o000000?o00000_l0o`000ol0003o0?l0o`3o0002o`0000?o0?l0
0_l00003ooooo`03o`000?oooooooooo017ooooo000Qooooo`03o`000?oooooooooo01oooooo0_l0
0002o`3o00Ko00000_l0o`05o`0000;o0?l01_l00002o`3o00Ko00000_l0o`06o`0000;o0?l000?o
0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`000ol0003o0?l0o`3o0006o`0000;o0?l01_l00002o`3o00Oo000000?o0?l0o`000?l000001Ol0
00001?l0o`3o0000o`3o0?l0o`04o`000004o`3o0?l0003o0?l0o`3o00Co000000?o0?l0o`000?l0
00001Ol000000ol0o`3o0000o`000002o`000004o`3o0?l0003o0?l0o`3o00Co000000Co0?l0o`00
0?l0o`3o0?l01?l000001?l0o`3o0000o`3o0?l0o`04o`0000;o0?l000?o0000o`3o0?l0o`000_l0
0002o`3o00Co000000Co0?l0o`000?l0o`3o0?l01?l000000ol0o`3o0000o`3o0002o`000003o`3o
0?l0003ooooo00;ooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool08?oo
ool2o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o000000;o00000_l0
o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0
o`3o0?l000Ko00000_l0o`06o`0000;o0?l01_l00002o`3o00Ko00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0
o`3o0?l000Ko00000_l0o`06o`0000;o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0
o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0004o`000004o`3o0?l0003o0000o`0000;o0?l0
00?o0000o`3o0?l000000ol00002o`3o0003o`000?l0o`3o0?l000;o00000ol0o`02o`0000?ooooo
00?o0000ooooooooool04?ooool002?ooooo00?o0000ooooooooool08?ooool00ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000_l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0
o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol0
0002o`3o0003o`000?l0o`3o0?l000Ko00000_l0o`06o`0000;o0?l01_l00002o`3o0003o`000?l0
o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol0
0002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o
0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`03o`0000;o0?l000?o0000o`3o0?l0o`001?l000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l0
00Go0000o`3o0?l0003o0?l0o`000003ooooo`03o`000?oooooooooo013ooooo000Tooooo`;o0000
8Oooool2o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o000000;o0000
0_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`00
0?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`00
0ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l0
00?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000Ko000000?o0?l0o`000?l00000
1Ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l0
00?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o000000Co0?l0o`000?l0o`3o
0?l01?l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o
0?l000?o0000o`3o0?l0o`000ol000000ol0o`3o0000o`000002o`000004o`3o0?l0003o0?l0o`3o
00Co000000Co0?l0o`000?l0o`3o0?l01?l000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l00_l0
0002ooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo01oooooo00?o0000
o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000;o00000_l0o`000ol0003o0?l0o`3o0003
o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o00Ko00000_l0o`06o`0000;o0?l01_l00002
o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o
0?l0o`3o00Co000000Co0?l0o`000?l0o`3o0?l01?l000001?l0o`3o0000o`3o0?l0o`03o`0000;o
0?l000?o0000o`3o0?l0o`001ol000000ol0o`3o0000o`000005o`000003o`3o0?l0003o000000Go
000000?o0?l0o`000?l000001Ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l000?o0000o`3o
0?l0o`001?l000001?l0o`3o0000o`3o0?l0o`04o`000004o`3o0?l0003o0?l0o`3o00Co000000Co
0?l0o`000?l0003o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`00
1?l000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l00ol000001Ol0o`3o0000oooooooooooo0000
01;ooooo000Wooooo`03o`000?oooooooooo01oooooo0_l00002o`3o0003o`000?l0o`3o0?l000?o
000000Co0?l0o`000?l0o`3o0?l00ol00002o`3o00Ko00000_l0o`03o`0000;o0?l000?o0000o`3o
0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0006o`00
00;o0?l01_l000000ol0o`3o0000o`000004o`0000;o0?l01_l00002o`3o0003o`000?l0o`3o0?l0
00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o
0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o
0?l0o`001_l00002o`3o00Ko00000_l0o`06o`0000;o0?l01_l00002o`3o00?o00000_l0o`000ol0
003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0000
00?o000000?o0?l0o`000?l0o`000_l000001?l0o`3o0000o`3o0?l0o`02o`000003ooooool0003o
oooo017ooooo000Xooooo`03o`000?oooooooooo01oooooo00?o0000o`3o0?l0o`000ol00002o`3o
00Go00000_l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l0
00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol000001?l0
o`3o0000o`3o0?l0o`04o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`001_l00002o`3o00Ko00000_l0o`06o`0000;o0?l000?o
0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o
0003o`000004o`3o0?l0003o0?l0o`3o00Co000000Co0?l0o`000?l0o`3o0?l01?l000001?l0o`3o
0000o`3o0?l0o`04o`000004o`3o0?l0003o0?l0o`3o00Co000000Co0?l0o`000?l0o`3o0?l01?l0
00001?l0o`3o0000o`3o0?l0o`04o`000004o`3o0?l0003o0?l0o`3o00Ko00000_l0o`03o`0000;o
0?l00ol00002o`3o00;o00004_ooool002Wooooo0_l0000Pooooo`;o00000_l0o`03o`000004o`3o
0?l0003o0?l0o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0
o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`000004
o`3o0?l0003o0?l0o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o
0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`00
00;o0?l000?o0000o`3o0?l0o`000ol000001?l0o`3o0000o`3o0?l0o`07o`000003o`3o0?l0003o
000000Go000000?o0?l0o`000?l000001Ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l000?o
0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l000000ol000000ol0o`3o0000o`00
0002o`000004o`3o0?l0003o0?l0o`3o00?o00004_ooool002_ooooo00?o0000ooooooooool07_oo
ool00ol0003o0?l0o`000002o`3o0003o`000?l0o`3o000000;o00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`000ol0003o0?l0
o`3o0003o`0000;o0?l01_l00002o`3o00Ko00000_l0o`000ol0003o0?l0o`3o0003o`000004o`3o
0?l0003o0?l0o`3o00Co000000Co0?l0o`000?l0o`3o0?l00ol00002o`3o0003o`000?l0o`3o0?l0
00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`001_l00002o`3o
00Ko00000_l0o`06o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l0
00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol000000ol0
o`3o0000o`000009o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o00;o00004Oooool002co
oooo00?o0000ooooooooool07_ooool2o`0000;o0?l00_l00002o`3o0003o`000?l0o`3o0?l000?o
00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003
o`000?l0o`3o0?l000?o000000?o0?l0o`000?l000001?l00002o`3o00Ko00000_l0o`03o`0000;o
0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000Ko000000?o0?l0o`000?l0
00001?l00002o`3o00Ko00000_l0o`06o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003
o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`3o
00Co000000Co0?l0o`000?l0o`3o0?l01ol000000ol0o`3o0000o`000005o`000003o`3o0?l0003o
000000Go000000?o0?l0o`000?l000001Ol000001?l0o`3o0000o`000?l00002o`3o0003o`000?l0
o`3o0?l000Co000000Co0?l0o`000?l0o`3o0?l00ol00002o`3o0003o`000?l0o`3o0?l000;o0000
4Oooool002gooooo00?o0000ooooooooool07oooool2o`000004o`3o0?l0003o0?l0o`3o00?o0000
0_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`00
0?l0o`3o0?l000?o000000Co0?l0o`000?l0003o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o
0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o
0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`00
00;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000Ko000000?o0?l0o`00
0?l000001Ol000000ol0o`3o0000o`000005o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`00
0ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o
0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00000
1?l0o`3o0000o`3o0?l0o`04o`000004o`3o0?l0003o0?l0o`3o00Co000000Co0?l0o`000?l0o`3o
0?l01?l000000ooooooo0000ooooo`0@ooooo`00;_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?l0o`3o000000;o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`00
0ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`02o`0000;o0?l000?o0000o`3o0?l0o`00
0ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`000004o`3o
0?l0003o0?l0o`3o00Co000000Co0?l0o`000?l0o`3o0?l00ol00002o`3o0003o`000?l0o`3o0?l0
00?o00000_l0o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`3o00Co000000Co0?l0
o`000?l0o`3o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o
0006o`0000;o0?l01_l000000ol0o`3o0000o`000005o`0000;o0?l000?o0000o`3o0?l0o`000ol0
00001?l0o`3o0000o`3o0?l0o`04o`000004o`3o0?l0003o0?l0o`3o00Co000000Co0?l0o`000?l0
o`3o0?l00ol00002o`3o0003o`000?l0o`3o0?l000Co000000Co0?l0o`000?l0o`3o0?l00ol00005
ooooo`03o`000?oooooooooo00oooooo000_ooooo`;o00008?ooool01?l0003o0?l0o`3o0?l00002
o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002
o`3o00?o000000Co0?l0o`000?l0o`3o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0
o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`000ol0003o0?l0
o`3o0003o`0000;o0?l01_l00002o`3o00Ko000000?o0?l0o`000?l000001?l00002o`3o0003o`00
0?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`00
0ol000001?l0o`3o0000o`3o0?l0o`04o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`000ol0
003o0?l0o`3o0007o`000003o`3o0?l0003o000000Co00000_l0o`06o`0000;o0?l01_l00002o`3o
0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`000003o`0000Sooooo00?o0000oooo
ooooool03oooool0037ooooo00?o0000ooooooooool07Oooool00ol0003o0?l0o`3o0003o`0000;o
0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`03o`000004
o`3o0?l0003o0?l0o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o
0?l0o`000ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l01_l00002o`3o00?o00000_l0o`00
0ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`000ol0003o0?l0o`3o
0006o`0000;o0?l01_l000000ol0o`3o0000o`000005o`000003o`3o0?l0003o000000Co00000_l0
o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0
o`3o0?l000?o000000Co0?l0o`000?l0o`3o0?l01?l000001?l0o`3o0000o`3o0?l0o`04o`000004
o`3o0?l0003o0?l0o`3o00Oo000000?o0?l0o`000?l000001_l0000:ooooo`03o`000?oooooooooo
00oooooo000booooo`03o`000?oooooooooo01gooooo0_l00002o`3o0003o`000?l0o`3o0?l000?o
00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`000002o`3o
00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol000001?l0
o`3o0000o`3o0?l0o`03o`0000;o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`00
0ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`000ol0003o0?l0o`3o
0003o`0000;o0?l000?o0000o`3o0?l0o`000ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l0
00?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000Ko00000_l0o`06o`000003o`3o
0?l0003o000000Go000000Co0?l0o`000?l0o`3o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o
00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol00008ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool003?ooooo00?o0000ooooooooool0
7?ooool01?l0003o0?l0o`3o0?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003
o`000?l0o`3o0?l000;o00000_l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003
o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`000002o`0000;o0?l00ol00002o`3o0003
o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`3o
00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol000001?l0
o`3o0000o`3o0?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o
0?l000?o000000Co0?l0o`000?l0o`3o0?l01?l000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l0
00?o0000o`3o0?l0o`001_l00002o`3o00Ko000000?o0?l0o`000?l000001Ol000001?l0o`3o0000
o`3o0?l0o`04o`0000_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`00
=?ooool2o`0001gooooo00Go0000o`3o0?l0003o0?l0o`000003o`3o00?o00000_l0o`000ol0003o
0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o
0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0002o`0000;o0?l00ol00002o`3o
0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0
o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`000003o`3o0?l0003o000000Go000000?o0?l0
o`000?l000001?l00002o`3o00Ko000000?o0?l0o`000?l000001Ol000000ol0o`3o0000o`000004
o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o000000Co0?l0
o`000?l0o`3o0?l01?l000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`00
1_l0000@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool003Kooooo00?o
0000ooooooooool06oooool01ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`000ol0003o
0?l0o`3o0003o`0000;o0?l000Co0000o`3o0?l0003o00000ol0o`03o`0000;o0?l000?o0000o`3o
0?l0o`000ol00002o`3o0003o`000?l0o`3o0?l000?o000000Co0?l0o`000?l0003o00000_l0o`00
0ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol000001?l0o`3o0000o`3o0?l0
o`03o`0000;o0?l01_l000001?l0o`3o0000o`000?l00002o`3o0003o`000?l0o`3o0?l000?o0000
0_l0o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`000ol0003o
0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`001_l000000ol0o`3o0000o`000005o`000003
o`3o0?l0003o000000Co00000_l0o`06o`0000;o0?l000?o0000o`3o0?l0o`000ol0000Gooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool003Oooooo00?o0000ooooooooool0
6oooool00ol0003o0?l0o`3o0002o`0000?o0?l00ol00002o`3o0003o`000?l0o`3o0?l000;o0000
0_l0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0
o`3o0003o`000004o`3o0?l0003o0?l0o`0000;o0?l000?o0000o`3o0?l0o`000ol00002o`3o0003
o`000?l0o`3o0?l000?o000000Co0?l0o`000?l0o`3o0?l00ol00002o`3o00?o000000Co0?l0o`00
0?l0o`3o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003
o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o
0000o`3o0?l0o`000ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`00
0ol00002o`3o0003o`000?l0o`3o0?l000?o000000Co0?l0o`000?l0o`3o0?l01ol0000Jooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool003Sooooo00?o0000ooooooooool0
6oooool2o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00?o000000Co0?l0o`000?l0
o`3o0?l00_l00003o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0
o`3o00;o00000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol000001?l0o`3o0000o`3o0?l0
o`03o`0000;o0?l00ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`00
0ol00002o`3o0003o`000?l0o`3o0?l000?o000000Co0?l0o`000?l0o`3o0?l00ol00002o`3o0003
o`000?l0o`3o0?l000?o000000Co0?l0o`000?l0o`3o0?l01?l000000ol0o`3o0000o`000004o`00
00;o0?l000?o0000o`3o0?l0o`000ol000001?l0o`3o0000o`3o0?l0o`04o`000004o`3o0?l0003o
0?l0o`3o00?o00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo000i
ooooo`;o00007?ooool00ol0003o0?l0o`3o0002o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`00
0002o`3o00?o00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00ol000001?l0o`3o0000
o`3o0?l0o`03o`0000;o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`3o0003o`000004
o`3o0?l0003o0?l0o`3o00?o00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000;o0?l00ol00002
o`3o0003o`000?l0o`3o0?l000?o00000_l0o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o
0?l0o`3o00?o00000_l0o`06o`000003o`3o0?l0003o000000Co00000_l0o`03o`0000;o0?l000?o
0000o`3o0?l0o`001_l000000ol0o`3o0000o`000004o`0000;o0?l01_l0000Vooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03_ooool003_ooooo00?o0000ooooooooool06_ooool2
o`0000;o0?l000?o0000o`3o0?l0o`000_l00003o`3o00;o00000_l0o`000ol0003o0?l0o`3o0002
o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000002o`3o00?o00000_l0o`000ol0003o0?l0o`3o
0002o`0000?o0?l00ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`00
0_l00002o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`00
0ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l00ol000001?l0o`3o0000o`3o0?l0o`03o`00
00;o0?l000?o0000o`3o0?l0o`000ol000001?l0o`3o0000o`3o0?l0o`04o`000004o`3o0?l0003o
0?l0o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`0002gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0>ooooo`00??ooool00ol0003oooooooooo`0Iooooo`04o`000?l0o`3o
0?l0o`3o00?o00000_l0o`001?l0003o0?l0o`000?l00003o`3o00?o00000_l0o`000ol0003o0?l0
o`3o0002o`0000?o0?l00_l00002o`3o0003o`000?l0o`3o0?l000?o00000_l0o`001Ol0003o0?l0
o`000?l0o`3o000000;o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o000000Co0?l0o`000?l0
003o00000_l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol000001?l0
o`3o0000o`3o0?l0o`03o`0000;o0?l00ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l000?o
0000o`3o0?l0o`000ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`00
0ol00002o`3o0003o`000?l0o`3o0?l000?o0000<?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo000mooooo`03o`000?oooooooooo01Wooooo00?o0000o`3o0?l000000_l0
o`000ol0003o0?l0o`3o0002o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00?o0000
0_l0o`001?l0003o0?l0o`000?l00003o`3o00?o00000_l0o`000ol0003o0?l0o`3o0002o`0000;o
0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o000000Co0?l0o`000?l0o`3o00000_l0o`000ol0
003o0?l0o`3o0003o`0000;o0?l000?o0000o`3o0?l0o`000ol000001?l0o`3o0000o`3o0?l0o`03
o`0000;o0?l00ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000ol0
00001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l01_l000000ol0o`3o0000o`000005o`0003Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`00?_ooool00ol0003ooooooooo
o`0Iooooo`04o`000?l0o`3o0?l0o`3o00?o000000Co0?l0o`000?l0o`3o0?l00_l00003o`3o0003
o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000_l00002o`3o0003o`000?l0o`3o000000;o
0?l000?o0000o`3o0?l0o`000ol000001?l0o`3o0000o`3o0?l00002o`3o0003o`000?l0o`3o0?l0
00?o00000_l0o`001?l0003o0?l0o`000?l00003o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003
o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`03o`000004o`3o0?l0003o0?l0o`3o00?o0000
0_l0o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`03o`000004
o`3o0?l0003o0?l0o`3o00?o0000??ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00gooooo000oooooo`;o00006_ooool01Ol0003o0?l0o`000?l0o`3o000000;o0?l00ol00002o`3o
0003o`000?l0o`3o0?l000;o00000ol0o`03o`000004o`3o0?l0003o0?l0o`3o00;o00000ol0o`03
o`000004o`3o0?l0003o0?l0o`3o00;o00000ol0o`03o`0000;o0?l000?o0000o`3o0?l0o`000_l0
0002o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000ol000001?l0o`3o0000o`3o
0?l0o`03o`0000;o0?l00ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l000?o0000o`3o0?l0
o`000ol000000ol0o`3o0000o`000004o`0000;o0?l00ol000001?l0o`3o0000o`3o0?l0o`03o`00
043ooooo00Go0000ooooooooooooooooo`00000?ooooo`00@Oooool00ol0003oooooooooo`0Hoooo
o`04o`000?l0o`3o0?l0o`3o00;o000000?o0?l0o`000?l0o`000_l0o`03o`0000;o0?l000Go0000
o`3o0?l0003o0?l0o`000002o`3o00?o00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l0
0_l00002o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`03o`000004o`3o0?l0003o0?l0o`3o
00;o00000ol0o`03o`000004o`3o0?l0003o0?l0o`3o00?o00000_l0o`001Ol0003o0?l0o`000?l0
o`3o000000;o0?l00ol00002o`3o0003o`000?l0o`3o0?l000?o000000Co0?l0o`000?l0o`3o0000
0_l0o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`3o00?o0000@oooool01Ol0003o
oooooooooooooooo000000oooooo0012ooooo`03o`000?oooooooooo01Oooooo00?o0000o`3o0?l0
o`000_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000?o0?l00_l00002o`3o
0003o`000?l0o`3o0?l000;o00000ol0o`001Ol0003o0?l0o`000?l0o`3o000000;o0?l00_l00003
o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0o`03o`0000;o0?l000Go0000o`3o0?l0003o0?l0
o`000002o`3o00?o00000_l0o`000ol0003o0?l0o`3o0002o`0000;o0?l00ol00002o`3o0003o`00
0?l0o`3o0?l000?o000000Co0?l0o`000?l0o`3o0?l00ol00002o`3o00?o000000Co0?l0o`000?l0
o`3o0?l00ol00017ooooo`04o`000?ooooooooooo`0000oooooo0013ooooo`03o`000?oooooooooo
01Oooooo0_l000000ol0o`3o0000o`3o0002o`3o00;o00000ol0o`001Ol0003o0?l0o`000?l0o`3o
000000;o0?l00_l00003o`3o00?o00000_l0o`000ol0003o0?l0o`3o0002o`0000;o0?l00ol00002
o`3o0003o`000?l0o`3o0?l000;o00000_l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000_l00002
o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`0000;o0?l000?o
0000o`3o0?l0o`000ol000001?l0o`3o0000o`3o0?l0o`03o`0000;o0?l00ol000001?l0o`3o0000
o`3o0?l0o`03o`0004_ooooo00?o0000ooooool000003oooool004Cooooo0_l0000Gooooo`07o`00
0?l0o`3o0?l0o`3o0?l0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o00000_l0o`03o`00
00;o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00?o000000Ko0?l0o`000?l0o`3o0000o`3o
0?l00003o`3o00?o000000Ko0?l0o`000?l0o`3o0000o`3o0?l00003o`3o00?o000000Ko0?l0o`00
0?l0o`3o0000o`3o0?l00003o`3o00?o000000Co0?l0o`000?l0o`3o0?l00_l00003o`3o00?o0000
00Co0?l0o`000?l0o`3o0?l00ol00002o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0o`03o`00
04kooooo00Co0000oooooooooooo00003_ooool004Kooooo00?o0000ooooooooool05Oooool00ol0
003o0?l0o`3o0002o`0000?o0?l00ol000001_l0o`3o0000o`3o0?l0003o0?l0o`0000?o0?l00_l0
0003o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0o`02o`0000?o0?l000Go0000o`3o0?l0003o
0?l0o`000002o`3o00;o00000ol0o`001Ol0003o0?l0o`000?l0o`3o000000;o0?l00_l00003o`3o
0005o`000?l0o`3o0000o`3o0?l000000_l0o`03o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`00
0002o`3o00?o00000_l0o`000ol0003o0?l0o`3o0002o`0000;o0?l00ol0001Booooo`03o`000?oo
oooo000000kooooo0017ooooo`03o`000?oooooooooo01Gooooo0_l00002o`3o0005o`000?l0o`3o
0000o`3o0?l000000ol0o`002Ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l0003o0?l0o`000003o`3o
00;o00000ol0o`02o`0000;o0?l000?o0000o`3o0?l0o`000_l00003o`3o00;o00000_l0o`000ol0
003o0?l0o`3o0002o`0000;o0?l00ol00002o`3o0003o`000?l0o`3o0?l000;o00000_l0o`03o`00
00;o0?l000?o0000o`3o0?l0o`000_l00002o`3o00?o00000_l0o`000ol0003o0?l0o`3o0003o`00
0004o`3o0?l0003o0000o`0005Kooooo0_l0000>ooooo`00B?ooool00ol0003oooooooooo`0Doooo
o`04o`000?l0o`3o0?l0o`3o00;o00000ol0o`001?l0003o0?l0o`000?l00003o`3o00;o00000ol0
o`001Ol0003o0?l0o`000?l0o`3o000000;o0?l00_l00003o`3o00?o000000Co0?l0o`000?l0o`3o
0?l00_l00003o`3o00?o000000Ko0?l0o`000?l0o`3o0000o`3o0?l00003o`3o00?o000000Ko0?l0
o`000?l0o`3o0000o`3o0?l00003o`3o00?o000000Co0?l0o`000?l0o`3o00000_l0o`000ol0003o
0?l0o`3o0003o`000004o`3o0?l0003o0?l0o`0005Sooooo0ol0000>ooooo`00BOooool2o`0001Go
oooo00Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00000_l0o`001Ol0003o0?l0o`000?l0o`3o
000000?o0?l00_l00002o`3o00?o00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l00_l0
0002o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o
0?l000000_l0o`001?l0003o0?l0o`000?l00003o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0
o`02o`0000?o0?l00ol000001?l0o`3o0000o`3o0?l0o`02o`0005Gooooo1?l0000Aooooo`00Booo
ool00ol0003oooooooooo`0Cooooo`09o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000?l0o`3o0000
00;o0?l00_l00003o`3o0009o`000?l0o`3o0000o`3o0?l0003o0?l0o`000?l0o`3o000000?o0?l0
0_l00003o`3o0004o`000?l0o`3o0000o`0000?o0?l00_l00003o`3o0005o`000?l0o`3o0000o`3o
0?l000000_l0o`02o`0000?o0?l00_l00002o`3o0003o`000?l0o`3o0?l000;o00000ol0o`02o`00
00;o0?l000Go0000o`3o0?l0003o0?l0o`000002o`3o00?o0000Doooool4o`0001Gooooo001<oooo
o`03o`000?oooooooooo01;ooooo00Co0000o`3o0?l0o`3o0?l00_l00003o`3o00;o000000?o0?l0
o`000?l0o`000_l0o`02o`0000?o0?l000Wo0000o`3o0?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l0
00000ol0o`02o`0000;o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`3o0002o`0000;o
0?l00ol00002o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0o`03o`0000;o0?l000Go0000o`3o
0?l0003o0?l0o`000002o`3o00;o00000ol0o`02o`0005?ooooo0ol0000Iooooo`00COooool00ol0
003oooooooooo`0Booooo`05o`000?l0o`3o0000o`3o0?l000000_l0o`02o`0000?o0?l000?o0000
o`3o0?l000000_l0o`001?l0003o0?l0o`000?l00003o`3o00;o00000ol0o`001Ol0003o0?l0o`00
0?l0o`3o000000;o0?l00_l00003o`3o00?o000000Ko0?l0o`000?l0o`3o0000o`3o0?l00003o`3o
00;o00000ol0o`02o`0000;o0?l000?o0000o`3o0?l0o`000_l00002o`3o00?o000000Co0?l0o`00
0?l0o`3o0?l00_l0001@ooooo`Co00007?ooool004kooooo0_l0000Cooooo`04o`000?l0o`3o0?l0
o`3o00;o000000?o0?l0o`000?l0o`000_l0o`02o`0000?o0?l00_l00002o`3o0005o`000?l0o`3o
0000o`3o0?l000000ol0o`02o`0000?o0?l00_l00002o`3o0005o`000?l0o`3o0000o`3o0?l00000
0_l0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`000002o`3o00;o00000ol0o`03o`000006
o`3o0?l0003o0?l0o`000?l0o`3o00000_l0o`03o`0004kooooo1?l0000Pooooo`00D?ooool00ol0
003oooooooooo`0@ooooo`03o`000?l0o`3o0?l000;o00000ol0o`000ol0003o0?l0o`000002o`3o
0005o`000?l0o`3o0000o`3o0?l000000_l0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0o`00
0002o`3o00;o00000ol0o`02o`0000?o0?l00_l000000ol0o`3o0000o`3o0002o`3o00;o00000ol0
o`02o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`000002o`3o00;o00000ol0o`02o`0004gooooo
1?l0000Tooooo`00DOooool00ol0003oooooooooo`0@ooooo`;o000000?o0?l0o`000?l0o`000_l0
o`02o`0000Co0?l000Co0000o`3o0?l0o`3o0?l00_l000000ol0o`3o0000o`3o0002o`3o00;o0000
0ol0o`02o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`000002o`3o00;o00000ol0o`001Ol0003o
0?l0o`000?l0o`3o000000;o0?l00_l00003o`3o00;o00000ol0o`02o`000003o`3o0?l0003o0?l0
00;o0?l000?o0000ooooooooool0B?ooool4o`0002Sooooo001Booooo`03o`000?oooooooooo00oo
oooo00Wo0000o`3o0?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000;o0?l00_l0
0003o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0o`02o`0000?o0?l00_l00003o`3o00;o0000
00?o0?l0o`000?l0o`000_l0o`02o`0000;o0?l00ol00002o`3o0005o`000?l0o`3o0000o`3o0?l0
00000_l0o`02o`0000?o0?l000?o0000o`3o0?l00000B?ooool3o`0002cooooo001Cooooo`03o`00
0?oooooooooo00kooooo00Co0000o`3o0?l0o`3o0?l00_l00003o`3o0003o`000?l0o`3o000000;o
0?l00_l000000ol0o`3o0000o`3o0002o`3o00;o00000ol0o`02o`0000;o0?l000Go0000o`3o0?l0
003o0?l0o`000002o`3o00;o00000ol0o`002Ol0003o0?l0o`000?l0o`3o0000o`3o0?l0003o0?l0
o`000003o`3o00;o00000ol0o`02o`0000;o0?l000?o0000o`3o0?l0o`000_l00015ooooo`Co0000
;oooool005Cooooo0_l0000?ooooo`05o`000?l0o`3o0000o`3o0?l000000ol0o`02o`0000?o0?l0
00Wo0000o`3o0?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l000000_l0o`02o`0000Co0?l000Co0000
o`3o0?l0o`3o0?l00_l000000ol0o`3o0000o`3o0002o`3o00;o00000_l0o`02o`0000?o0?l000Go
0000o`3o0?l0003o0?l0o`000002o`3o00;o00000ol0o`03o`0004?ooooo1?l0000cooooo`00E_oo
ool00ol0003oooooooooo`0=ooooo`09o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000?l0o`3o0000
00;o0?l00_l00004o`3o0004o`000?l0o`3o0?l0o`3o00;o000000?o0?l0o`000?l0o`000_l0o`02
o`0000?o0?l000go0000o`3o0?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l0003o0?l0o`000?l0o`3o
000000?o0?l00_l00003o`3o00;o00000_l0o`000ol0003o0?l0o`000012ooooo`Co0000=oooool0
05Oooooo00?o0000ooooooooool03?ooool00ol0003o0?l0o`3o0002o`3o0004o`000?l0o`3o0?l0
o`3o00;o00000_l0o`000ol0003o0?l0o`3o0002o`0000?o0?l000Oo0000o`3o0?l0o`3o0?l0o`00
0?l0o`3o000000;o0?l000Co0000o`3o0?l0003o00000ol0o`02o`0000?o0?l000Wo0000o`3o0?l0
o`3o0?l0o`000?l0o`3o0000o`3o0?l000000_l0o`02o`0000?o0?l00_l0000oooooo`Co0000>ooo
ool005Sooooo00?o0000ooooooooool03?ooool00ol0003o0?l0o`3o0002o`0000;o0?l00_l00003
o`3o0003o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0003o00000ol0o`02o`0000Co0?l000So
0000o`3o0?l0o`3o0000o`3o0?l0003o0?l0o`0000?o0?l000Co0000o`3o0?l0o`3o0?l00_l00003
o`3o00;o00000_l0o`000ol0003o0?l0o`00000nooooo`?o0000?oooool005Wooooo0_l0000<oooo
o`03o`000?l0o`3o000000;o0?l00_l000000ol0o`3o0000o`3o0002o`3o00;o00001?l0o`002?l0
003o0?l0o`3o0?l0003o0?l0o`000?l0o`3o00000ol0o`02o`0000;o0?l00_l00003o`3o0009o`00
0?l0o`3o0000o`3o0?l0003o0?l0o`000?l0o`3o000000?o0?l000?o0000o`3o0?l0o`000_l0o`00
0ol0003oooooooooo`0iooooo`Co0000@_ooool005_ooooo00?o0000ooooooooool02_ooool01Ol0
003o0?l0o`3o0?l0o`3o000000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o00;o00000ol0
o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`02o`000003o`3o0?l0003o0?l000;o
0?l00_l00003o`3o0006o`000?l0o`3o0?l0o`3o0?l0003o0?l00_l00003o`3o0003o`000?oooooo
oooo03Kooooo1?l00016ooooo`00G?ooool00ol0003oooooooooo`09ooooo`05o`000?l0o`3o0?l0
o`3o0?l000001?l0o`002Ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l0003o0?l0o`000002o`3o00;o
00000ol0o`02o`0000?o0?l000Wo0000o`3o0?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l000000_l0
o`02o`0000?o0?l00_l00002o`3o0003o`000?l0o`3o000003Gooooo1?l0001:ooooo`00GOooool0
0ol0003oooooooooo`09ooooo`05o`000?l0o`3o0000o`3o0?l000000_l0o`02o`0000?o0?l00_l0
0003o`3o00;o00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000;o0?l00_l00004o`3o0004o`00
0?l0o`3o0?l0o`3o00;o00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000;o0?l00_l0000boooo
o`Co0000C_ooool005kooooo0_l0000:ooooo`06o`000?l0o`3o0?l0o`000?l0o`3o00000_l0o`00
1Ol0003o0?l0o`000?l0o`3o000000;o0?l00_l00004o`3o0004o`000?l0o`3o0?l0o`3o00;o0000
0_l0o`000ol0003o0?l0o`3o0002o`0000;o0?l00_l00004o`3o0004o`000?l0o`3o0?l0o`3o00;o
0000<Oooool3o`0005;ooooo001Pooooo`03o`000?oooooooooo00Oooooo00?o0000o`3o0?l0o`00
0_l00004o`3o0004o`000?l0o`3o0?l0o`3o00;o000000?o0?l0o`000?l0o`000_l0o`02o`0000?o
0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000;o0?l00_l000000ol0o`3o0000o`3o0002
o`3o00;o00000_l0o`02o`0002kooooo1?l0001Eooooo`00HOooool00ol0003oooooooooo`07oooo
o`;o000000?o0?l0o`000?l0o`000_l0o`02o`0000?o0?l000Wo0000o`3o0?l0o`3o0?l0o`000?l0
o`3o0000o`3o0?l000000_l0o`02o`0000?o0?l00_l00003o`3o0007o`000?l0o`3o0?l0o`3o0?l0
003o0?l0o`000002o`3o00;o0000;?ooool4o`0005Wooooo001Rooooo`03o`000?oooooooooo00Ko
oooo00Wo0000o`3o0?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l000000_l0o`02o`0000Co0?l000Co
0000o`3o0?l0o`3o0?l00_l00002o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0o`02o`0000?o
0?l00_l00003o`3o0003o`000?oooooooooo02Oooooo1?l0001Mooooo`00Hoooool00ol0003ooooo
ooooo`05ooooo`03o`000?l0o`3o0?l000;o0?l000Co0000o`3o0?l0o`3o0?l00_l00002o`3o0003
o`000?l0o`3o0?l000;o00000_l0o`02o`0000Co0?l000Co0000o`3o0?l0o`3o0?l00_l00002o`3o
0005o`000?l0o`3o0000o`3o0?l000000_l0o`000ol0003oooooooooo`0Tooooo`Co0000HOooool0
06Cooooo0_l00006ooooo`03o`000?l0o`3o0?l000;o00000ol0o`001ol0003o0?l0o`3o0?l0o`3o
0000o`3o0?l000000_l0o`02o`000003o`3o0?l0003o0?l000;o0?l00_l00003o`3o0003o`000?l0
o`3o0?l000;o0?l000Co0000o`3o0?l0o`3o0?l00_l0000Tooooo`?o0000IOooool006Kooooo00?o
0000ooooooooool00oooool01Ol0003o0?l0o`000?l0o`3o000000;o0?l00_l00004o`3o0005o`00
0?l0o`3o0?l0o`3o0?l000000ol0o`001Ol0003o0?l0o`000?l0o`3o000000;o0?l00_l00003o`3o
00;o00000ol0o`000ol0003oooooooooo`0Oooooo`Co0000J?ooool006Oooooo00?o0000oooooooo
ool00oooool01?l0003o0?l0o`3o0?l0o`02o`0000;o0?l000?o0000o`3o0?l0o`000_l00002o`3o
00;o00001?l0o`001?l0003o0?l0o`3o0?l0o`02o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`00
0002o`3o0003o`000?oooooooooo01cooooo1?l0001/ooooo`00J?ooool00ol0003oooooooooo`02
ooooo`05o`000?l0o`3o0?l0o`3o0?l000000ol0o`000ol0003o0?l0o`000002o`3o00;o00000_l0
o`000ol0003o0?l0o`3o0002o`0000?o0?l000?o0000o`3o0?l0o`000_l0o`001?l0003o0?l0o`3o
0?l0o`02o`0001_ooooo1?l0001`ooooo`00JOooool2o`0000;ooooo00?o0000o`3o0?l0o`000_l0
0004o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`000ol0003o0?l0o`000002o`3o0004o`00
0?l0o`3o0?l0o`0000?o0?l00_l00003o`3o0003o`000?oooooooooo01Kooooo1?l0001dooooo`00
Joooool00ol0003oooooooooo`02o`0000;o0?l000?o0000o`3o0?l0o`000_l00003o`3o0003o`00
0?l0o`3o0?l000;o0?l000_o0000o`3o0?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l0003o0?l0o`00
0002o`3o0004o`000?l0o`3o0?l0o`0001Gooooo0ol0001hooooo`00K?ooool00ol0003oooooo`00
0003o`3o0003o`000?l0o`3o000000;o0?l000Go0000o`3o0?l0003o0?l0o`000002o`3o00;o0000
1?l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l000?o0000o`3o0?l000004_ooool4o`0007_o
oooo001]ooooo`;o00001?l0o`000ol0003o0?l0o`3o0002o`3o0006o`000?l0o`3o0?l0o`000?l0
o`3o00000_l0o`000ol0003o0?l0o`3o0002o`0000;o0?l00_l00004o`3o0003o`000?oooooooooo
00gooooo1?l0001oooooo`00K_ooool2o`0000;o0?l00_l00004o`3o0005o`000?l0o`3o0?l0o`3o
0?l000000ol0o`000ol0003o0?l0o`000002o`3o00;o00000_l0o`001?l0003o0?l0o`3o0?l0000<
ooooo`Co0000Poooool006oooooo00?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`3o0002o`00
00;o0?l00_l00004o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`000ol0003o0?l0o`000009
ooooo`Co0000Qoooool0073ooooo0_l00002o`3o0003o`000?l0o`3o000000;o0?l00_l00002o`3o
0003o`000?l0o`3o0?l000;o00000_l0o`02o`0000Co0?l000?o0000ooooooooool01Oooool3o`00
08_ooooo001booooo`Co00000_l0o`02o`0000?o0?l000?o0000o`3o0?l000000_l0o`02o`0000;o
0?l000Co0000o`3o0?l0o`3o00001?ooool4o`0008kooooo001cooooo`03o`000?l0o`3o000000;o
00000_l0o`000ol0003o0?l0o`3o0002o`0000;o0?l00_l00003o`3o0004o`000?l0o`3o0000oooo
o`Co0000T_ooool007Cooooo00?o0000o`3o0?l0o`001_l000001?l0o`3o0000o`000?l00002o`3o
0003o`000?l0o`3o0?l000Co0000U_ooool007Gooooo0_l00002o`3o0003o`000?l0o`3o0?l000;o
00000_l0o`000ol0003o0?l0o`3o0003o`0009[ooooo001gooooo`Go000000?o0?l0o`000?l00000
1?l0002Mooooo`00N?ooool00ol0003o0?l0o`000004o`000:7ooooo001iooooo`;o0000YOooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0767646, -0.00871667, \
0.00376354, 0.00376354}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -23.848 -9 ]
[.14598 .19958 .15205 0 ]
[.27013 .15073 -22.8472 -9 ]
[.27013 .15073 1.15281 0 ]
[.40046 .09948 -21.8464 -9 ]
[.40046 .09948 2.15358 0 ]
[.53743 .04564 -20.8457 -9 ]
[.53743 .04564 3.15434 0 ]
[.68156 -0.01098 -19.8449 -9 ]
[.68156 -0.01098 4.1551 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 30 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 30 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 30 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 30 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 30 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02411 .26511 -12 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -18 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.01)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.02)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.03)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.04)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.05)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06033 .24606 m
.06319 .24877 L
s
.08372 .23691 m
.08655 .23964 L
s
.10732 .22766 m
.11013 .23042 L
s
.13115 .21833 m
.13394 .22111 L
s
.17948 .19941 m
.18222 .20223 L
s
.20399 .18981 m
.2067 .19266 L
s
.22873 .18012 m
.23142 .183 L
s
.25371 .17034 m
.25638 .17324 L
s
.3044 .15049 m
.30701 .15344 L
s
.33011 .14043 m
.3327 .14339 L
s
.35608 .13026 m
.35864 .13325 L
s
.3823 .11999 m
.38483 .12301 L
s
.43553 .09915 m
.43799 .10222 L
s
.46254 .08857 m
.46497 .09167 L
s
.48982 .07789 m
.49222 .08101 L
s
.51738 .0671 m
.51975 .07024 L
s
.57333 .04519 m
.57563 .04838 L
s
.60174 .03407 m
.60401 .03728 L
s
.63044 .02283 m
.63267 .02607 L
s
.65944 .01147 m
.66163 .01474 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-0.05)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(-0.04)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(-0.03)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(-0.02)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(-0.01)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70252 .02109 m
.69885 .02251 L
s
.71605 .04178 m
.71237 .04318 L
s
.72932 .06208 m
.72564 .06347 L
s
.74235 .08201 m
.73866 .08339 L
s
.7677 .12078 m
.764 .12213 L
s
.78003 .13965 m
.77633 .14098 L
s
.79214 .15817 m
.78843 .1595 L
s
.80404 .17637 m
.80033 .17768 L
s
.82721 .21182 m
.82349 .21311 L
s
.8385 .22909 m
.83478 .23037 L
s
.8496 .24606 m
.84587 .24733 L
s
.86051 .26275 m
.85677 .264 L
s
.88178 .29529 m
.87804 .29651 L
s
.89215 .31115 m
.88841 .31237 L
s
.90235 .32676 m
.89861 .32797 L
s
.91239 .34211 m
.90864 .34331 L
s
.93198 .37208 m
.92823 .37326 L
s
.94155 .38671 m
.93779 .38788 L
s
.95096 .40111 m
.9472 .40226 L
s
.96022 .41528 m
.95646 .41643 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(-1)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(-0.5)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.5)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 0 1 r
.39527 .69625 .40169 .70185 .41244 .69882 .40605 .6932 Metetra
0 0 1 r
.40605 .6932 .41244 .69882 .42323 .69578 .41686 .69013 Metetra
0 0 1 r
.41686 .69013 .42323 .69578 .43406 .69273 .42772 .68705 Metetra
0 0 1 r
.42772 .68705 .43406 .69273 .44494 .68966 .43863 .68397 Metetra
0 0 1 r
.43863 .68397 .44494 .68966 .45586 .68658 .44958 .68086 Metetra
0 0 1 r
.44958 .68086 .45586 .68658 .46682 .68349 .46057 .67775 Metetra
0 0 1 r
.46057 .67775 .46682 .68349 .47783 .68039 .47161 .67462 Metetra
0 0 1 r
.47161 .67462 .47783 .68039 .48889 .67727 .48269 .67148 Metetra
0 0 1 r
.48269 .67148 .48889 .67727 .49998 .67414 .49382 .66833 Metetra
0 0 1 r
.49382 .66833 .49998 .67414 .51113 .671 .50499 .66516 Metetra
0 0 1 r
.50499 .66516 .51113 .671 .52232 .66784 .51621 .66199 Metetra
0 0 1 r
.51621 .66199 .52232 .66784 .53355 .66468 .52747 .65879 Metetra
0 0 1 r
.52747 .65879 .53355 .66468 .54483 .6615 .53878 .65559 Metetra
0 0 1 r
.53878 .65559 .54483 .6615 .55616 .6583 .55014 .65237 Metetra
0 0 1 r
.55014 .65237 .55616 .6583 .56753 .65509 .56155 .64914 Metetra
0 0 1 r
.56155 .64914 .56753 .65509 .57895 .65188 .573 .6459 Metetra
0 0 1 r
.573 .6459 .57895 .65188 .59042 .64864 .5845 .64264 Metetra
0 0 1 r
.5845 .64264 .59042 .64864 .60194 .6454 .59604 .63937 Metetra
0 0 1 r
.59604 .63937 .60194 .6454 .6135 .64214 .60764 .63608 Metetra
0 0 1 r
.60764 .63608 .6135 .64214 .62511 .63886 .61928 .63278 Metetra
0 0 1 r
.61928 .63278 .62511 .63886 .63677 .63557 .63097 .62947 Metetra
0 0 1 r
.63097 .62947 .63677 .63557 .64848 .63227 .64272 .62614 Metetra
0 0 1 r
.64272 .62614 .64848 .63227 .66023 .62896 .65451 .6228 Metetra
0 0 1 r
.65451 .6228 .66023 .62896 .67204 .62563 .66635 .61945 Metetra
0 0 1 r
.66635 .61945 .67204 .62563 .6839 .62229 .67824 .61608 Metetra
0 0 1 r
.67824 .61608 .6839 .62229 .6958 .61893 .69018 .6127 Metetra
0 0 1 r
.69018 .6127 .6958 .61893 .70776 .61556 .70217 .6093 Metetra
0 0 1 r
.70217 .6093 .70776 .61556 .71976 .61218 .71421 .60589 Metetra
0 0 1 r
.71421 .60589 .71976 .61218 .73182 .60878 .7263 .60246 Metetra
0 0 1 r
.7263 .60246 .73182 .60878 .74393 .60536 .73845 .59902 Metetra
0 0 1 r
.73845 .59902 .74393 .60536 .75609 .60193 .75064 .59557 Metetra
0 0 1 r
.75064 .59557 .75609 .60193 .7683 .59849 .76289 .5921 Metetra
0 0 1 r
.76289 .5921 .7683 .59849 .78057 .59503 .77519 .58861 Metetra
0 0 1 r
.77519 .58861 .78057 .59503 .79288 .59156 .78754 .58511 Metetra
0 0 1 r
.78754 .58511 .79288 .59156 .80525 .58807 .79995 .5816 Metetra
0 0 1 r
.79995 .5816 .80525 .58807 .81767 .58457 .81241 .57807 Metetra
0 0 1 r
.81241 .57807 .81767 .58457 .83015 .58105 .82493 .57452 Metetra
0 0 1 r
.82493 .57452 .83015 .58105 .84268 .57752 .83749 .57096 Metetra
0 0 1 r
.83749 .57096 .84268 .57752 .85526 .57397 .85012 .56738 Metetra
0 0 1 r
.85012 .56738 .85526 .57397 .8679 .57041 .8628 .56379 Metetra
0 0 1 r
.8628 .56379 .8679 .57041 .8806 .56683 .87553 .56018 Metetra
0 0 1 r
.87553 .56018 .8806 .56683 .89334 .56324 .88832 .55656 Metetra
0 0 1 r
.88832 .55656 .89334 .56324 .90615 .55963 .90116 .55292 Metetra
0 0 1 r
.90116 .55292 .90615 .55963 .91901 .556 .91407 .54927 Metetra
0 0 1 r
.91407 .54927 .91901 .556 .93193 .55236 .92702 .54559 Metetra
0 0 1 r
.92702 .54559 .93193 .55236 .9449 .5487 .94004 .54191 Metetra
0 0 1 r
.94004 .54191 .9449 .5487 .95793 .54503 .95311 .5382 Metetra
0 0 1 r
.95311 .5382 .95793 .54503 .97102 .54134 .96624 .53448 Metetra
0 0 1 r
.96624 .53448 .97102 .54134 .98416 .53763 .97943 .53075 Metetra
0 0 1 r
.3888 .6906 .39527 .69625 .40605 .6932 .3996 .68753 Metetra
0 0 1 r
.3996 .68753 .40605 .6932 .41686 .69013 .41045 .68444 Metetra
0 0 1 r
.41045 .68444 .41686 .69013 .42772 .68705 .42134 .68134 Metetra
0 0 1 r
.42134 .68134 .42772 .68705 .43863 .68397 .43227 .67823 Metetra
0 0 1 r
.43227 .67823 .43863 .68397 .44958 .68086 .44325 .6751 Metetra
0 0 1 r
.44325 .6751 .44958 .68086 .46057 .67775 .45427 .67197 Metetra
0 0 1 r
.45427 .67197 .46057 .67775 .47161 .67462 .46533 .66882 Metetra
0 0 1 r
.46533 .66882 .47161 .67462 .48269 .67148 .47644 .66565 Metetra
0 0 1 r
.47644 .66565 .48269 .67148 .49382 .66833 .4876 .66248 Metetra
0 0 1 r
.4876 .66248 .49382 .66833 .50499 .66516 .4988 .65929 Metetra
0 0 1 r
.4988 .65929 .50499 .66516 .51621 .66199 .51005 .65608 Metetra
0 0 1 r
.51005 .65608 .51621 .66199 .52747 .65879 .52135 .65287 Metetra
0 0 1 r
.52135 .65287 .52747 .65879 .53878 .65559 .53269 .64964 Metetra
0 0 1 r
.53269 .64964 .53878 .65559 .55014 .65237 .54408 .6464 Metetra
0 0 1 r
.54408 .6464 .55014 .65237 .56155 .64914 .55551 .64314 Metetra
0 0 1 r
.55551 .64314 .56155 .64914 .573 .6459 .567 .63987 Metetra
0 0 1 r
.567 .63987 .573 .6459 .5845 .64264 .57853 .63659 Metetra
0 0 1 r
.57853 .63659 .5845 .64264 .59604 .63937 .59011 .63329 Metetra
0 0 1 r
.59011 .63329 .59604 .63937 .60764 .63608 .60173 .62998 Metetra
0 0 1 r
.60173 .62998 .60764 .63608 .61928 .63278 .61341 .62666 Metetra
0 0 1 r
.61341 .62666 .61928 .63278 .63097 .62947 .62514 .62332 Metetra
0 0 1 r
.62514 .62332 .63097 .62947 .64272 .62614 .63691 .61997 Metetra
0 0 1 r
.63691 .61997 .64272 .62614 .65451 .6228 .64873 .6166 Metetra
0 0 1 r
.64873 .6166 .65451 .6228 .66635 .61945 .66061 .61322 Metetra
0 0 1 r
.66061 .61322 .66635 .61945 .67824 .61608 .67253 .60982 Metetra
0 0 1 r
.67253 .60982 .67824 .61608 .69018 .6127 .68451 .60641 Metetra
0 0 1 r
.68451 .60641 .69018 .6127 .70217 .6093 .69653 .60299 Metetra
0 0 1 r
.69653 .60299 .70217 .6093 .71421 .60589 .70861 .59955 Metetra
0 0 1 r
.70861 .59955 .71421 .60589 .7263 .60246 .72074 .5961 Metetra
0 0 1 r
.72074 .5961 .7263 .60246 .73845 .59902 .73292 .59263 Metetra
0 0 1 r
.73292 .59263 .73845 .59902 .75064 .59557 .74515 .58915 Metetra
0 0 1 r
.74515 .58915 .75064 .59557 .76289 .5921 .75744 .58565 Metetra
0 0 1 r
.75744 .58565 .76289 .5921 .77519 .58861 .76977 .58214 Metetra
0 0 1 r
.76977 .58214 .77519 .58861 .78754 .58511 .78216 .57861 Metetra
0 0 1 r
.78216 .57861 .78754 .58511 .79995 .5816 .79461 .57507 Metetra
0 0 1 r
.79461 .57507 .79995 .5816 .81241 .57807 .80711 .57151 Metetra
0 0 1 r
.80711 .57151 .81241 .57807 .82493 .57452 .81966 .56793 Metetra
0 0 1 r
.81966 .56793 .82493 .57452 .83749 .57096 .83227 .56434 Metetra
0 0 1 r
.83227 .56434 .83749 .57096 .85012 .56738 .84493 .56074 Metetra
0 0 1 r
.84493 .56074 .85012 .56738 .8628 .56379 .85765 .55712 Metetra
0 0 1 r
.85765 .55712 .8628 .56379 .87553 .56018 .87042 .55348 Metetra
0 0 1 r
.87042 .55348 .87553 .56018 .88832 .55656 .88325 .54983 Metetra
0 0 1 r
.88325 .54983 .88832 .55656 .90116 .55292 .89614 .54616 Metetra
0 0 1 r
.89614 .54616 .90116 .55292 .91407 .54927 .90908 .54247 Metetra
0 0 1 r
.90908 .54247 .91407 .54927 .92702 .54559 .92208 .53877 Metetra
0 0 1 r
.92208 .53877 .92702 .54559 .94004 .54191 .93514 .53506 Metetra
0 0 1 r
.93514 .53506 .94004 .54191 .95311 .5382 .94826 .53132 Metetra
0 0 1 r
.94826 .53132 .95311 .5382 .96624 .53448 .96143 .52757 Metetra
0 0 1 r
.96143 .52757 .96624 .53448 .97943 .53075 .97466 .5238 Metetra
0 0 1 r
.38229 .68492 .3888 .6906 .3996 .68753 .39312 .68182 Metetra
0 0 1 r
.39312 .68182 .3996 .68753 .41045 .68444 .40399 .67871 Metetra
0 0 1 r
.40399 .67871 .41045 .68444 .42134 .68134 .4149 .67559 Metetra
0 0 1 r
.4149 .67559 .42134 .68134 .43227 .67823 .42586 .67245 Metetra
0 0 1 r
.42586 .67245 .43227 .67823 .44325 .6751 .43687 .6693 Metetra
0 0 1 r
.43687 .6693 .44325 .6751 .45427 .67197 .44792 .66614 Metetra
0 0 1 r
.44792 .66614 .45427 .67197 .46533 .66882 .45901 .66296 Metetra
0 0 1 r
.45901 .66296 .46533 .66882 .47644 .66565 .47015 .65978 Metetra
0 0 1 r
.47015 .65978 .47644 .66565 .4876 .66248 .48134 .65658 Metetra
0 0 1 r
.48134 .65658 .4876 .66248 .4988 .65929 .49257 .65336 Metetra
0 0 1 r
.49257 .65336 .4988 .65929 .51005 .65608 .50385 .65014 Metetra
0 0 1 r
.50385 .65014 .51005 .65608 .52135 .65287 .51518 .6469 Metetra
0 0 1 r
.51518 .6469 .52135 .65287 .53269 .64964 .52655 .64364 Metetra
0 0 1 r
.52655 .64364 .53269 .64964 .54408 .6464 .53797 .64037 Metetra
0 0 1 r
.53797 .64037 .54408 .6464 .55551 .64314 .54943 .63709 Metetra
0 0 1 r
.54943 .63709 .55551 .64314 .567 .63987 .56095 .6338 Metetra
0 0 1 r
.56095 .6338 .567 .63987 .57853 .63659 .57251 .63049 Metetra
0 0 1 r
.57251 .63049 .57853 .63659 .59011 .63329 .58412 .62717 Metetra
0 0 1 r
.58412 .62717 .59011 .63329 .60173 .62998 .59578 .62383 Metetra
0 0 1 r
.59578 .62383 .60173 .62998 .61341 .62666 .60749 .62048 Metetra
0 0 1 r
.60749 .62048 .61341 .62666 .62514 .62332 .61925 .61712 Metetra
0 0 1 r
.61925 .61712 .62514 .62332 .63691 .61997 .63106 .61374 Metetra
0 0 1 r
.63106 .61374 .63691 .61997 .64873 .6166 .64292 .61035 Metetra
0 0 1 r
.64292 .61035 .64873 .6166 .66061 .61322 .65482 .60694 Metetra
0 0 1 r
.65482 .60694 .66061 .61322 .67253 .60982 .66678 .60352 Metetra
0 0 1 r
.66678 .60352 .67253 .60982 .68451 .60641 .67879 .60008 Metetra
0 0 1 r
.67879 .60008 .68451 .60641 .69653 .60299 .69085 .59663 Metetra
0 0 1 r
.69085 .59663 .69653 .60299 .70861 .59955 .70297 .59317 Metetra
0 0 1 r
.70297 .59317 .70861 .59955 .72074 .5961 .71513 .58968 Metetra
0 0 1 r
.71513 .58968 .72074 .5961 .73292 .59263 .72735 .58619 Metetra
0 0 1 r
.72735 .58619 .73292 .59263 .74515 .58915 .73962 .58268 Metetra
0 0 1 r
.73962 .58268 .74515 .58915 .75744 .58565 .75194 .57915 Metetra
0 0 1 r
.75194 .57915 .75744 .58565 .76977 .58214 .76431 .57561 Metetra
0 0 1 r
.76431 .57561 .76977 .58214 .78216 .57861 .77674 .57206 Metetra
0 0 1 r
.77674 .57206 .78216 .57861 .79461 .57507 .78922 .56848 Metetra
0 0 1 r
.78922 .56848 .79461 .57507 .80711 .57151 .80176 .5649 Metetra
0 0 1 r
.80176 .5649 .80711 .57151 .81966 .56793 .81435 .56129 Metetra
0 0 1 r
.81435 .56129 .81966 .56793 .83227 .56434 .827 .55768 Metetra
0 0 1 r
.827 .55768 .83227 .56434 .84493 .56074 .8397 .55404 Metetra
0 0 1 r
.8397 .55404 .84493 .56074 .85765 .55712 .85246 .55039 Metetra
0 0 1 r
.85246 .55039 .85765 .55712 .87042 .55348 .86527 .54673 Metetra
0 0 1 r
.86527 .54673 .87042 .55348 .88325 .54983 .87815 .54304 Metetra
0 0 1 r
.87815 .54304 .88325 .54983 .89614 .54616 .89107 .53934 Metetra
0 0 1 r
.89107 .53934 .89614 .54616 .90908 .54247 .90406 .53563 Metetra
0 0 1 r
.90406 .53563 .90908 .54247 .92208 .53877 .9171 .5319 Metetra
0 0 1 r
.9171 .5319 .92208 .53877 .93514 .53506 .9302 .52815 Metetra
0 0 1 r
.9302 .52815 .93514 .53506 .94826 .53132 .94336 .52438 Metetra
0 0 1 r
.94336 .52438 .94826 .53132 .96143 .52757 .95658 .5206 Metetra
0 0 1 r
.95658 .5206 .96143 .52757 .97466 .5238 .96985 .5168 Metetra
0 0 1 r
.37572 .67919 .38229 .68492 .39312 .68182 .38658 .67607 Metetra
0 0 1 r
.38658 .67607 .39312 .68182 .40399 .67871 .39748 .67293 Metetra
0 0 1 r
.39748 .67293 .40399 .67871 .4149 .67559 .40842 .66979 Metetra
0 0 1 r
.40842 .66979 .4149 .67559 .42586 .67245 .41941 .66663 Metetra
0 0 1 r
.41941 .66663 .42586 .67245 .43687 .6693 .43044 .66345 Metetra
0 0 1 r
.43044 .66345 .43687 .6693 .44792 .66614 .44152 .66027 Metetra
0 0 1 r
.44152 .66027 .44792 .66614 .45901 .66296 .45265 .65707 Metetra
0 0 1 r
.45265 .65707 .45901 .66296 .47015 .65978 .46381 .65386 Metetra
0 0 1 r
.46381 .65386 .47015 .65978 .48134 .65658 .47503 .65063 Metetra
0 0 1 r
.47503 .65063 .48134 .65658 .49257 .65336 .48629 .64739 Metetra
0 0 1 r
.48629 .64739 .49257 .65336 .50385 .65014 .4976 .64414 Metetra
0 0 1 r
.4976 .64414 .50385 .65014 .51518 .6469 .50896 .64088 Metetra
0 0 1 r
.50896 .64088 .51518 .6469 .52655 .64364 .52036 .6376 Metetra
0 0 1 r
.52036 .6376 .52655 .64364 .53797 .64037 .53181 .63431 Metetra
0 0 1 r
.53181 .63431 .53797 .64037 .54943 .63709 .54331 .631 Metetra
0 0 1 r
.54331 .631 .54943 .63709 .56095 .6338 .55486 .62768 Metetra
0 0 1 r
.55486 .62768 .56095 .6338 .57251 .63049 .56645 .62435 Metetra
0 0 1 r
.56645 .62435 .57251 .63049 .58412 .62717 .57809 .621 Metetra
0 0 1 r
.57809 .621 .58412 .62717 .59578 .62383 .58979 .61764 Metetra
0 0 1 r
.58979 .61764 .59578 .62383 .60749 .62048 .60153 .61426 Metetra
0 0 1 r
.60153 .61426 .60749 .62048 .61925 .61712 .61332 .61087 Metetra
0 0 1 r
.61332 .61087 .61925 .61712 .63106 .61374 .62516 .60746 Metetra
0 0 1 r
.62516 .60746 .63106 .61374 .64292 .61035 .63705 .60405 Metetra
0 0 1 r
.63705 .60405 .64292 .61035 .65482 .60694 .649 .60061 Metetra
0 0 1 r
.649 .60061 .65482 .60694 .66678 .60352 .66099 .59716 Metetra
0 0 1 r
.66099 .59716 .66678 .60352 .67879 .60008 .67303 .5937 Metetra
0 0 1 r
.67303 .5937 .67879 .60008 .69085 .59663 .68513 .59022 Metetra
0 0 1 r
.68513 .59022 .69085 .59663 .70297 .59317 .69728 .58673 Metetra
0 0 1 r
.69728 .58673 .70297 .59317 .71513 .58968 .70948 .58322 Metetra
0 0 1 r
.70948 .58322 .71513 .58968 .72735 .58619 .72173 .5797 Metetra
0 0 1 r
.72173 .5797 .72735 .58619 .73962 .58268 .73404 .57616 Metetra
0 0 1 r
.73404 .57616 .73962 .58268 .75194 .57915 .7464 .5726 Metetra
0 0 1 r
.7464 .5726 .75194 .57915 .76431 .57561 .75881 .56904 Metetra
0 0 1 r
.75881 .56904 .76431 .57561 .77674 .57206 .77128 .56545 Metetra
0 0 1 r
.77128 .56545 .77674 .57206 .78922 .56848 .7838 .56185 Metetra
0 0 1 r
.7838 .56185 .78922 .56848 .80176 .5649 .79637 .55823 Metetra
0 0 1 r
.79637 .55823 .80176 .5649 .81435 .56129 .809 .5546 Metetra
0 0 1 r
.809 .5546 .81435 .56129 .827 .55768 .82169 .55095 Metetra
0 0 1 r
.82169 .55095 .827 .55768 .8397 .55404 .83443 .54729 Metetra
0 0 1 r
.83443 .54729 .8397 .55404 .85246 .55039 .84723 .54361 Metetra
0 0 1 r
.84723 .54361 .85246 .55039 .86527 .54673 .86008 .53991 Metetra
0 0 1 r
.86008 .53991 .86527 .54673 .87815 .54304 .873 .5362 Metetra
0 0 1 r
.873 .5362 .87815 .54304 .89107 .53934 .88597 .53247 Metetra
0 0 1 r
.88597 .53247 .89107 .53934 .90406 .53563 .89899 .52873 Metetra
0 0 1 r
.89899 .52873 .90406 .53563 .9171 .5319 .91208 .52496 Metetra
0 0 1 r
.91208 .52496 .9171 .5319 .9302 .52815 .92522 .52119 Metetra
0 0 1 r
.92522 .52119 .9302 .52815 .94336 .52438 .93842 .51739 Metetra
0 0 1 r
.93842 .51739 .94336 .52438 .95658 .5206 .95168 .51358 Metetra
0 0 1 r
.95168 .51358 .95658 .5206 .96985 .5168 .965 .50975 Metetra
0 0 1 r
.36911 .67342 .37572 .67919 .38658 .67607 .37999 .67027 Metetra
0 0 1 r
.37999 .67027 .38658 .67607 .39748 .67293 .39092 .66711 Metetra
0 0 1 r
.39092 .66711 .39748 .67293 .40842 .66979 .40189 .66394 Metetra
0 0 1 r
.40189 .66394 .40842 .66979 .41941 .66663 .41291 .66076 Metetra
0 0 1 r
.41291 .66076 .41941 .66663 .43044 .66345 .42397 .65756 Metetra
0 0 1 r
.42397 .65756 .43044 .66345 .44152 .66027 .43508 .65435 Metetra
0 0 1 r
.43508 .65435 .44152 .66027 .45265 .65707 .44623 .65113 Metetra
0 0 1 r
.44623 .65113 .45265 .65707 .46381 .65386 .45743 .64789 Metetra
0 0 1 r
.45743 .64789 .46381 .65386 .47503 .65063 .46867 .64464 Metetra
0 0 1 r
.46867 .64464 .47503 .65063 .48629 .64739 .47997 .64138 Metetra
0 0 1 r
.47997 .64138 .48629 .64739 .4976 .64414 .4913 .6381 Metetra
0 0 1 r
.4913 .6381 .4976 .64414 .50896 .64088 .50269 .63481 Metetra
0 0 1 r
.50269 .63481 .50896 .64088 .52036 .6376 .51412 .63151 Metetra
0 0 1 r
.51412 .63151 .52036 .6376 .53181 .63431 .52561 .62819 Metetra
0 0 1 r
.52561 .62819 .53181 .63431 .54331 .631 .53714 .62486 Metetra
0 0 1 r
.53714 .62486 .54331 .631 .55486 .62768 .54871 .62151 Metetra
0 0 1 r
.54871 .62151 .55486 .62768 .56645 .62435 .56034 .61815 Metetra
0 0 1 r
.56034 .61815 .56645 .62435 .57809 .621 .57202 .61478 Metetra
0 0 1 r
.57202 .61478 .57809 .621 .58979 .61764 .58374 .61139 Metetra
0 0 1 r
.58374 .61139 .58979 .61764 .60153 .61426 .59552 .60799 Metetra
0 0 1 r
.59552 .60799 .60153 .61426 .61332 .61087 .60734 .60457 Metetra
0 0 1 r
.60734 .60457 .61332 .61087 .62516 .60746 .61922 .60114 Metetra
0 0 1 r
.61922 .60114 .62516 .60746 .63705 .60405 .63114 .59769 Metetra
0 0 1 r
.63114 .59769 .63705 .60405 .649 .60061 .64312 .59423 Metetra
0 0 1 r
.64312 .59423 .649 .60061 .66099 .59716 .65515 .59076 Metetra
0 0 1 r
.65515 .59076 .66099 .59716 .67303 .5937 .66723 .58727 Metetra
0 0 1 r
.66723 .58727 .67303 .5937 .68513 .59022 .67936 .58376 Metetra
0 0 1 r
.67936 .58376 .68513 .59022 .69728 .58673 .69154 .58024 Metetra
0 0 1 r
.69154 .58024 .69728 .58673 .70948 .58322 .70378 .5767 Metetra
0 0 1 r
.70378 .5767 .70948 .58322 .72173 .5797 .71607 .57315 Metetra
0 0 1 r
.71607 .57315 .72173 .5797 .73404 .57616 .72841 .56959 Metetra
0 0 1 r
.72841 .56959 .73404 .57616 .7464 .5726 .74081 .566 Metetra
0 0 1 r
.74081 .566 .7464 .5726 .75881 .56904 .75326 .56241 Metetra
0 0 1 r
.75326 .56241 .75881 .56904 .77128 .56545 .76577 .55879 Metetra
0 0 1 r
.76577 .55879 .77128 .56545 .7838 .56185 .77832 .55516 Metetra
0 0 1 r
.77832 .55516 .7838 .56185 .79637 .55823 .79094 .55152 Metetra
0 0 1 r
.79094 .55152 .79637 .55823 .809 .5546 .80361 .54786 Metetra
0 0 1 r
.80361 .54786 .809 .5546 .82169 .55095 .81634 .54418 Metetra
0 0 1 r
.81634 .54418 .82169 .55095 .83443 .54729 .82912 .54048 Metetra
0 0 1 r
.82912 .54048 .83443 .54729 .84723 .54361 .84196 .53677 Metetra
0 0 1 r
.84196 .53677 .84723 .54361 .86008 .53991 .85485 .53305 Metetra
0 0 1 r
.85485 .53305 .86008 .53991 .873 .5362 .86781 .5293 Metetra
0 0 1 r
.86781 .5293 .873 .5362 .88597 .53247 .88082 .52554 Metetra
0 0 1 r
.88082 .52554 .88597 .53247 .89899 .52873 .89388 .52177 Metetra
0 0 1 r
.89388 .52177 .89899 .52873 .91208 .52496 .90701 .51797 Metetra
0 0 1 r
.90701 .51797 .91208 .52496 .92522 .52119 .9202 .51416 Metetra
0 0 1 r
.9202 .51416 .92522 .52119 .93842 .51739 .93344 .51034 Metetra
0 0 1 r
.93344 .51034 .93842 .51739 .95168 .51358 .94675 .50649 Metetra
0 0 1 r
.94675 .50649 .95168 .51358 .965 .50975 .96011 .50263 Metetra
0 0 1 r
.36245 .6676 .36911 .67342 .37999 .67027 .37336 .66443 Metetra
0 0 1 r
.37336 .66443 .37999 .67027 .39092 .66711 .38431 .66125 Metetra
0 0 1 r
.38431 .66125 .39092 .66711 .40189 .66394 .39531 .65806 Metetra
0 0 1 r
.39531 .65806 .40189 .66394 .41291 .66076 .40635 .65485 Metetra
0 0 1 r
.40635 .65485 .41291 .66076 .42397 .65756 .41745 .65163 Metetra
0 0 1 r
.41745 .65163 .42397 .65756 .43508 .65435 .42858 .64839 Metetra
0 0 1 r
.42858 .64839 .43508 .65435 .44623 .65113 .43976 .64515 Metetra
0 0 1 r
.43976 .64515 .44623 .65113 .45743 .64789 .45099 .64188 Metetra
0 0 1 r
.45099 .64188 .45743 .64789 .46867 .64464 .46227 .63861 Metetra
0 0 1 r
.46227 .63861 .46867 .64464 .47997 .64138 .47359 .63532 Metetra
0 0 1 r
.47359 .63532 .47997 .64138 .4913 .6381 .48496 .63202 Metetra
0 0 1 r
.48496 .63202 .4913 .6381 .50269 .63481 .49638 .6287 Metetra
0 0 1 r
.49638 .6287 .50269 .63481 .51412 .63151 .50784 .62537 Metetra
0 0 1 r
.50784 .62537 .51412 .63151 .52561 .62819 .51935 .62203 Metetra
0 0 1 r
.51935 .62203 .52561 .62819 .53714 .62486 .53091 .61867 Metetra
0 0 1 r
.53091 .61867 .53714 .62486 .54871 .62151 .54252 .6153 Metetra
0 0 1 r
.54252 .6153 .54871 .62151 .56034 .61815 .55418 .61191 Metetra
0 0 1 r
.55418 .61191 .56034 .61815 .57202 .61478 .56589 .60851 Metetra
0 0 1 r
.56589 .60851 .57202 .61478 .58374 .61139 .57765 .6051 Metetra
0 0 1 r
.57765 .6051 .58374 .61139 .59552 .60799 .58946 .60167 Metetra
0 0 1 r
.58946 .60167 .59552 .60799 .60734 .60457 .60132 .59823 Metetra
0 0 1 r
.60132 .59823 .60734 .60457 .61922 .60114 .61323 .59477 Metetra
0 0 1 r
.61323 .59477 .61922 .60114 .63114 .59769 .62519 .59129 Metetra
0 0 1 r
.62519 .59129 .63114 .59769 .64312 .59423 .6372 .5878 Metetra
0 0 1 r
.6372 .5878 .64312 .59423 .65515 .59076 .64926 .5843 Metetra
0 0 1 r
.64926 .5843 .65515 .59076 .66723 .58727 .66138 .58078 Metetra
0 0 1 r
.66138 .58078 .66723 .58727 .67936 .58376 .67354 .57725 Metetra
0 0 1 r
.67354 .57725 .67936 .58376 .69154 .58024 .68576 .5737 Metetra
0 0 1 r
.68576 .5737 .69154 .58024 .70378 .5767 .69804 .57014 Metetra
0 0 1 r
.69804 .57014 .70378 .5767 .71607 .57315 .71036 .56656 Metetra
0 0 1 r
.71036 .56656 .71607 .57315 .72841 .56959 .72274 .56296 Metetra
0 0 1 r
.72274 .56296 .72841 .56959 .74081 .566 .73518 .55935 Metetra
0 0 1 r
.73518 .55935 .74081 .566 .75326 .56241 .74767 .55572 Metetra
0 0 1 r
.74767 .55572 .75326 .56241 .76577 .55879 .76021 .55208 Metetra
0 0 1 r
.76021 .55208 .76577 .55879 .77832 .55516 .77281 .54842 Metetra
0 0 1 r
.77281 .54842 .77832 .55516 .79094 .55152 .78546 .54474 Metetra
0 0 1 r
.78546 .54474 .79094 .55152 .80361 .54786 .79817 .54105 Metetra
0 0 1 r
.79817 .54105 .80361 .54786 .81634 .54418 .81094 .53735 Metetra
0 0 1 r
.81094 .53735 .81634 .54418 .82912 .54048 .82376 .53362 Metetra
0 0 1 r
.82376 .53362 .82912 .54048 .84196 .53677 .83664 .52988 Metetra
0 0 1 r
.83664 .52988 .84196 .53677 .85485 .53305 .84958 .52612 Metetra
0 0 1 r
.84958 .52612 .85485 .53305 .86781 .5293 .86257 .52235 Metetra
0 0 1 r
.86257 .52235 .86781 .5293 .88082 .52554 .87562 .51856 Metetra
0 0 1 r
.87562 .51856 .88082 .52554 .89388 .52177 .88874 .51475 Metetra
0 0 1 r
.88874 .51475 .89388 .52177 .90701 .51797 .90191 .51093 Metetra
0 0 1 r
.90191 .51093 .90701 .51797 .9202 .51416 .91513 .50708 Metetra
0 0 1 r
.91513 .50708 .9202 .51416 .93344 .51034 .92842 .50322 Metetra
0 0 1 r
.92842 .50322 .93344 .51034 .94675 .50649 .94177 .49935 Metetra
0 0 1 r
.94177 .49935 .94675 .50649 .96011 .50263 .95518 .49545 Metetra
0 0 1 r
.35573 .66174 .36245 .6676 .37336 .66443 .36667 .65855 Metetra
0 0 1 r
.36667 .65855 .37336 .66443 .38431 .66125 .37765 .65534 Metetra
0 0 1 r
.37765 .65534 .38431 .66125 .39531 .65806 .38868 .65212 Metetra
0 0 1 r
.38868 .65212 .39531 .65806 .40635 .65485 .39975 .64889 Metetra
0 0 1 r
.39975 .64889 .40635 .65485 .41745 .65163 .41087 .64565 Metetra
0 0 1 r
.41087 .64565 .41745 .65163 .42858 .64839 .42204 .64239 Metetra
0 0 1 r
.42204 .64239 .42858 .64839 .43976 .64515 .43325 .63911 Metetra
0 0 1 r
.43325 .63911 .43976 .64515 .45099 .64188 .44451 .63583 Metetra
0 0 1 r
.44451 .63583 .45099 .64188 .46227 .63861 .45581 .63253 Metetra
0 0 1 r
.45581 .63253 .46227 .63861 .47359 .63532 .46716 .62921 Metetra
0 0 1 r
.46716 .62921 .47359 .63532 .48496 .63202 .47856 .62589 Metetra
0 0 1 r
.47856 .62589 .48496 .63202 .49638 .6287 .49001 .62255 Metetra
0 0 1 r
.49001 .62255 .49638 .6287 .50784 .62537 .50151 .61919 Metetra
0 0 1 r
.50151 .61919 .50784 .62537 .51935 .62203 .51305 .61582 Metetra
0 0 1 r
.51305 .61582 .51935 .62203 .53091 .61867 .52464 .61244 Metetra
0 0 1 r
.52464 .61244 .53091 .61867 .54252 .6153 .53629 .60904 Metetra
0 0 1 r
.53629 .60904 .54252 .6153 .55418 .61191 .54798 .60563 Metetra
0 0 1 r
.54798 .60563 .55418 .61191 .56589 .60851 .55972 .6022 Metetra
0 0 1 r
.55972 .6022 .56589 .60851 .57765 .6051 .57151 .59876 Metetra
0 0 1 r
.57151 .59876 .57765 .6051 .58946 .60167 .58335 .5953 Metetra
0 0 1 r
.58335 .5953 .58946 .60167 .60132 .59823 .59525 .59183 Metetra
0 0 1 r
.59525 .59183 .60132 .59823 .61323 .59477 .60719 .58834 Metetra
0 0 1 r
.60719 .58834 .61323 .59477 .62519 .59129 .61918 .58484 Metetra
0 0 1 r
.61918 .58484 .62519 .59129 .6372 .5878 .63123 .58132 Metetra
0 0 1 r
.63123 .58132 .6372 .5878 .64926 .5843 .64333 .57779 Metetra
0 0 1 r
.64333 .57779 .64926 .5843 .66138 .58078 .65548 .57425 Metetra
0 0 1 r
.65548 .57425 .66138 .58078 .67354 .57725 .66768 .57068 Metetra
0 0 1 r
.66768 .57068 .67354 .57725 .68576 .5737 .67994 .56711 Metetra
0 0 1 r
.67994 .56711 .68576 .5737 .69804 .57014 .69225 .56351 Metetra
0 0 1 r
.69225 .56351 .69804 .57014 .71036 .56656 .70461 .55991 Metetra
0 0 1 r
.70461 .55991 .71036 .56656 .72274 .56296 .71703 .55628 Metetra
0 0 1 r
.71703 .55628 .72274 .56296 .73518 .55935 .7295 .55264 Metetra
0 0 1 r
.7295 .55264 .73518 .55935 .74767 .55572 .74203 .54898 Metetra
0 0 1 r
.74203 .54898 .74767 .55572 .76021 .55208 .75461 .54531 Metetra
0 0 1 r
.75461 .54531 .76021 .55208 .77281 .54842 .76725 .54162 Metetra
0 0 1 r
.76725 .54162 .77281 .54842 .78546 .54474 .77994 .53792 Metetra
0 0 1 r
.77994 .53792 .78546 .54474 .79817 .54105 .79269 .5342 Metetra
0 0 1 r
.79269 .5342 .79817 .54105 .81094 .53735 .8055 .53046 Metetra
0 0 1 r
.8055 .53046 .81094 .53735 .82376 .53362 .81836 .5267 Metetra
0 0 1 r
.81836 .5267 .82376 .53362 .83664 .52988 .83128 .52293 Metetra
0 0 1 r
.83128 .52293 .83664 .52988 .84958 .52612 .84426 .51914 Metetra
0 0 1 r
.84426 .51914 .84958 .52612 .86257 .52235 .85729 .51534 Metetra
0 0 1 r
.85729 .51534 .86257 .52235 .87562 .51856 .87039 .51152 Metetra
0 0 1 r
.87039 .51152 .87562 .51856 .88874 .51475 .88354 .50768 Metetra
0 0 1 r
.88354 .50768 .88874 .51475 .90191 .51093 .89676 .50382 Metetra
0 0 1 r
.89676 .50382 .90191 .51093 .91513 .50708 .91003 .49995 Metetra
0 0 1 r
.91003 .49995 .91513 .50708 .92842 .50322 .92336 .49605 Metetra
0 0 1 r
.92336 .49605 .92842 .50322 .94177 .49935 .93676 .49214 Metetra
0 0 1 r
.93676 .49214 .94177 .49935 .95518 .49545 .95021 .48822 Metetra
0 0 1 r
.34897 .65584 .35573 .66174 .36667 .65855 .35993 .65262 Metetra
0 0 1 r
.35993 .65262 .36667 .65855 .37765 .65534 .37094 .64939 Metetra
0 0 1 r
.37094 .64939 .37765 .65534 .38868 .65212 .382 .64615 Metetra
0 0 1 r
.382 .64615 .38868 .65212 .39975 .64889 .3931 .64289 Metetra
0 0 1 r
.3931 .64289 .39975 .64889 .41087 .64565 .40425 .63962 Metetra
0 0 1 r
.40425 .63962 .41087 .64565 .42204 .64239 .41544 .63633 Metetra
0 0 1 r
.41544 .63633 .42204 .64239 .43325 .63911 .42668 .63304 Metetra
0 0 1 r
.42668 .63304 .43325 .63911 .44451 .63583 .43797 .62973 Metetra
0 0 1 r
.43797 .62973 .44451 .63583 .45581 .63253 .44931 .6264 Metetra
0 0 1 r
.44931 .6264 .45581 .63253 .46716 .62921 .46069 .62306 Metetra
0 0 1 r
.46069 .62306 .46716 .62921 .47856 .62589 .47212 .61971 Metetra
0 0 1 r
.47212 .61971 .47856 .62589 .49001 .62255 .4836 .61634 Metetra
0 0 1 r
.4836 .61634 .49001 .62255 .50151 .61919 .49513 .61296 Metetra
0 0 1 r
.49513 .61296 .50151 .61919 .51305 .61582 .5067 .60956 Metetra
0 0 1 r
.5067 .60956 .51305 .61582 .52464 .61244 .51833 .60615 Metetra
0 0 1 r
.51833 .60615 .52464 .61244 .53629 .60904 .53 .60273 Metetra
0 0 1 r
.53 .60273 .53629 .60904 .54798 .60563 .54172 .59929 Metetra
0 0 1 r
.54172 .59929 .54798 .60563 .55972 .6022 .5535 .59583 Metetra
0 0 1 r
.5535 .59583 .55972 .6022 .57151 .59876 .56532 .59236 Metetra
0 0 1 r
.56532 .59236 .57151 .59876 .58335 .5953 .5772 .58888 Metetra
0 0 1 r
.5772 .58888 .58335 .5953 .59525 .59183 .58913 .58538 Metetra
0 0 1 r
.58913 .58538 .59525 .59183 .60719 .58834 .6011 .58187 Metetra
0 0 1 r
.6011 .58187 .60719 .58834 .61918 .58484 .61313 .57834 Metetra
0 0 1 r
.61313 .57834 .61918 .58484 .63123 .58132 .62521 .57479 Metetra
0 0 1 r
.62521 .57479 .63123 .58132 .64333 .57779 .63735 .57123 Metetra
0 0 1 r
.63735 .57123 .64333 .57779 .65548 .57425 .64953 .56766 Metetra
0 0 1 r
.64953 .56766 .65548 .57425 .66768 .57068 .66177 .56407 Metetra
0 0 1 r
.66177 .56407 .66768 .57068 .67994 .56711 .67407 .56046 Metetra
0 0 1 r
.67407 .56046 .67994 .56711 .69225 .56351 .68641 .55684 Metetra
0 0 1 r
.68641 .55684 .69225 .56351 .70461 .55991 .69881 .5532 Metetra
0 0 1 r
.69881 .5532 .70461 .55991 .71703 .55628 .71127 .54955 Metetra
0 0 1 r
.71127 .54955 .71703 .55628 .7295 .55264 .72378 .54588 Metetra
0 0 1 r
.72378 .54588 .7295 .55264 .74203 .54898 .73634 .54219 Metetra
0 0 1 r
.73634 .54219 .74203 .54898 .75461 .54531 .74896 .53849 Metetra
0 0 1 r
.74896 .53849 .75461 .54531 .76725 .54162 .76164 .53477 Metetra
0 0 1 r
.76164 .53477 .76725 .54162 .77994 .53792 .77437 .53103 Metetra
0 0 1 r
.77437 .53103 .77994 .53792 .79269 .5342 .78716 .52728 Metetra
0 0 1 r
.78716 .52728 .79269 .5342 .8055 .53046 .80001 .52351 Metetra
0 0 1 r
.80001 .52351 .8055 .53046 .81836 .5267 .81291 .51973 Metetra
0 0 1 r
.81291 .51973 .81836 .5267 .83128 .52293 .82587 .51592 Metetra
0 0 1 r
.82587 .51592 .83128 .52293 .84426 .51914 .83889 .51211 Metetra
0 0 1 r
.83889 .51211 .84426 .51914 .85729 .51534 .85197 .50827 Metetra
0 0 1 r
.85197 .50827 .85729 .51534 .87039 .51152 .86511 .50441 Metetra
0 0 1 r
.86511 .50441 .87039 .51152 .88354 .50768 .87831 .50054 Metetra
0 0 1 r
.87831 .50054 .88354 .50768 .89676 .50382 .89156 .49665 Metetra
0 0 1 r
.89156 .49665 .89676 .50382 .91003 .49995 .90488 .49275 Metetra
0 0 1 r
.90488 .49275 .91003 .49995 .92336 .49605 .91826 .48882 Metetra
0 0 1 r
.91826 .48882 .92336 .49605 .93676 .49214 .9317 .48488 Metetra
0 0 1 r
.9317 .48488 .93676 .49214 .95021 .48822 .9452 .48092 Metetra
0 0 1 r
.34215 .64989 .34897 .65584 .35993 .65262 .35314 .64665 Metetra
0 0 1 r
.35314 .64665 .35993 .65262 .37094 .64939 .36418 .64339 Metetra
0 0 1 r
.36418 .64339 .37094 .64939 .382 .64615 .37527 .64012 Metetra
0 0 1 r
.37527 .64012 .382 .64615 .3931 .64289 .3864 .63684 Metetra
0 0 1 r
.3864 .63684 .3931 .64289 .40425 .63962 .39757 .63354 Metetra
0 0 1 r
.39757 .63354 .40425 .63962 .41544 .63633 .4088 .63024 Metetra
0 0 1 r
.4088 .63024 .41544 .63633 .42668 .63304 .42007 .62691 Metetra
0 0 1 r
.42007 .62691 .42668 .63304 .43797 .62973 .43138 .62357 Metetra
0 0 1 r
.43138 .62357 .43797 .62973 .44931 .6264 .44275 .62022 Metetra
0 0 1 r
.44275 .62022 .44931 .6264 .46069 .62306 .45416 .61686 Metetra
0 0 1 r
.45416 .61686 .46069 .62306 .47212 .61971 .46562 .61348 Metetra
0 0 1 r
.46562 .61348 .47212 .61971 .4836 .61634 .47713 .61008 Metetra
0 0 1 r
.47713 .61008 .4836 .61634 .49513 .61296 .48869 .60668 Metetra
0 0 1 r
.48869 .60668 .49513 .61296 .5067 .60956 .5003 .60325 Metetra
0 0 1 r
.5003 .60325 .5067 .60956 .51833 .60615 .51196 .59982 Metetra
0 0 1 r
.51196 .59982 .51833 .60615 .53 .60273 .52366 .59636 Metetra
0 0 1 r
.52366 .59636 .53 .60273 .54172 .59929 .53542 .5929 Metetra
0 0 1 r
.53542 .5929 .54172 .59929 .5535 .59583 .54723 .58942 Metetra
0 0 1 r
.54723 .58942 .5535 .59583 .56532 .59236 .55909 .58592 Metetra
0 0 1 r
.55909 .58592 .56532 .59236 .5772 .58888 .571 .58241 Metetra
0 0 1 r
.571 .58241 .5772 .58888 .58913 .58538 .58296 .57888 Metetra
0 0 1 r
.58296 .57888 .58913 .58538 .6011 .58187 .59497 .57534 Metetra
0 0 1 r
.59497 .57534 .6011 .58187 .61313 .57834 .60703 .57178 Metetra
0 0 1 r
.60703 .57178 .61313 .57834 .62521 .57479 .61915 .56821 Metetra
0 0 1 r
.61915 .56821 .62521 .57479 .63735 .57123 .63132 .56462 Metetra
0 0 1 r
.63132 .56462 .63735 .57123 .64953 .56766 .64354 .56102 Metetra
0 0 1 r
.64354 .56102 .64953 .56766 .66177 .56407 .65582 .5574 Metetra
0 0 1 r
.65582 .5574 .66177 .56407 .67407 .56046 .66815 .55376 Metetra
0 0 1 r
.66815 .55376 .67407 .56046 .68641 .55684 .68053 .55011 Metetra
0 0 1 r
.68053 .55011 .68641 .55684 .69881 .5532 .69297 .54644 Metetra
0 0 1 r
.69297 .54644 .69881 .5532 .71127 .54955 .70546 .54276 Metetra
0 0 1 r
.70546 .54276 .71127 .54955 .72378 .54588 .71801 .53906 Metetra
0 0 1 r
.71801 .53906 .72378 .54588 .73634 .54219 .73061 .53534 Metetra
0 0 1 r
.73061 .53534 .73634 .54219 .74896 .53849 .74327 .53161 Metetra
0 0 1 r
.74327 .53161 .74896 .53849 .76164 .53477 .75599 .52786 Metetra
0 0 1 r
.75599 .52786 .76164 .53477 .77437 .53103 .76876 .52409 Metetra
0 0 1 r
.76876 .52409 .77437 .53103 .78716 .52728 .78159 .52031 Metetra
0 0 1 r
.78159 .52031 .78716 .52728 .80001 .52351 .79448 .51651 Metetra
0 0 1 r
.79448 .51651 .80001 .52351 .81291 .51973 .80742 .51269 Metetra
0 0 1 r
.80742 .51269 .81291 .51973 .82587 .51592 .82043 .50886 Metetra
0 0 1 r
.82043 .50886 .82587 .51592 .83889 .51211 .83349 .50501 Metetra
0 0 1 r
.83349 .50501 .83889 .51211 .85197 .50827 .84661 .50114 Metetra
0 0 1 r
.84661 .50114 .85197 .50827 .86511 .50441 .85979 .49725 Metetra
0 0 1 r
.85979 .49725 .86511 .50441 .87831 .50054 .87303 .49335 Metetra
0 0 1 r
.87303 .49335 .87831 .50054 .89156 .49665 .88633 .48943 Metetra
0 0 1 r
.88633 .48943 .89156 .49665 .90488 .49275 .89969 .48549 Metetra
0 0 1 r
.89969 .48549 .90488 .49275 .91826 .48882 .91311 .48153 Metetra
0 0 1 r
.91311 .48153 .91826 .48882 .9317 .48488 .92659 .47755 Metetra
0 0 1 r
.92659 .47755 .9317 .48488 .9452 .48092 .94014 .47356 Metetra
0 0 1 r
.33528 .64389 .34215 .64989 .35314 .64665 .3463 .64063 Metetra
0 0 1 r
.3463 .64063 .35314 .64665 .36418 .64339 .35737 .63735 Metetra
0 0 1 r
.35737 .63735 .36418 .64339 .37527 .64012 .36848 .63405 Metetra
0 0 1 r
.36848 .63405 .37527 .64012 .3864 .63684 .37964 .63075 Metetra
0 0 1 r
.37964 .63075 .3864 .63684 .39757 .63354 .39085 .62742 Metetra
0 0 1 r
.39085 .62742 .39757 .63354 .4088 .63024 .4021 .62409 Metetra
0 0 1 r
.4021 .62409 .4088 .63024 .42007 .62691 .4134 .62074 Metetra
0 0 1 r
.4134 .62074 .42007 .62691 .43138 .62357 .42475 .61738 Metetra
0 0 1 r
.42475 .61738 .43138 .62357 .44275 .62022 .43614 .614 Metetra
0 0 1 r
.43614 .614 .44275 .62022 .45416 .61686 .44759 .61061 Metetra
0 0 1 r
.44759 .61061 .45416 .61686 .46562 .61348 .45908 .6072 Metetra
0 0 1 r
.45908 .6072 .46562 .61348 .47713 .61008 .47062 .60378 Metetra
0 0 1 r
.47062 .60378 .47713 .61008 .48869 .60668 .48221 .60035 Metetra
0 0 1 r
.48221 .60035 .48869 .60668 .5003 .60325 .49385 .5969 Metetra
0 0 1 r
.49385 .5969 .5003 .60325 .51196 .59982 .50554 .59343 Metetra
0 0 1 r
.50554 .59343 .51196 .59982 .52366 .59636 .51728 .58995 Metetra
0 0 1 r
.51728 .58995 .52366 .59636 .53542 .5929 .52907 .58646 Metetra
0 0 1 r
.52907 .58646 .53542 .5929 .54723 .58942 .54091 .58295 Metetra
0 0 1 r
.54091 .58295 .54723 .58942 .55909 .58592 .5528 .57943 Metetra
0 0 1 r
.5528 .57943 .55909 .58592 .571 .58241 .56474 .57589 Metetra
0 0 1 r
.56474 .57589 .571 .58241 .58296 .57888 .57674 .57233 Metetra
0 0 1 r
.57674 .57233 .58296 .57888 .59497 .57534 .58878 .56876 Metetra
0 0 1 r
.58878 .56876 .59497 .57534 .60703 .57178 .60088 .56517 Metetra
0 0 1 r
.60088 .56517 .60703 .57178 .61915 .56821 .61304 .56157 Metetra
0 0 1 r
.61304 .56157 .61915 .56821 .63132 .56462 .62524 .55796 Metetra
0 0 1 r
.62524 .55796 .63132 .56462 .64354 .56102 .6375 .55432 Metetra
0 0 1 r
.6375 .55432 .64354 .56102 .65582 .5574 .64981 .55067 Metetra
0 0 1 r
.64981 .55067 .65582 .5574 .66815 .55376 .66218 .54701 Metetra
0 0 1 r
.66218 .54701 .66815 .55376 .68053 .55011 .6746 .54333 Metetra
0 0 1 r
.6746 .54333 .68053 .55011 .69297 .54644 .68707 .53963 Metetra
0 0 1 r
.68707 .53963 .69297 .54644 .70546 .54276 .69961 .53592 Metetra
0 0 1 r
.69961 .53592 .70546 .54276 .71801 .53906 .71219 .53219 Metetra
0 0 1 r
.71219 .53219 .71801 .53906 .73061 .53534 .72483 .52844 Metetra
0 0 1 r
.72483 .52844 .73061 .53534 .74327 .53161 .73753 .52467 Metetra
0 0 1 r
.73753 .52467 .74327 .53161 .75599 .52786 .75029 .52089 Metetra
0 0 1 r
.75029 .52089 .75599 .52786 .76876 .52409 .7631 .5171 Metetra
0 0 1 r
.7631 .5171 .76876 .52409 .78159 .52031 .77597 .51328 Metetra
0 0 1 r
.77597 .51328 .78159 .52031 .79448 .51651 .7889 .50945 Metetra
0 0 1 r
.7889 .50945 .79448 .51651 .80742 .51269 .80189 .5056 Metetra
0 0 1 r
.80189 .5056 .80742 .51269 .82043 .50886 .81493 .50174 Metetra
0 0 1 r
.81493 .50174 .82043 .50886 .83349 .50501 .82803 .49785 Metetra
0 0 1 r
.82803 .49785 .83349 .50501 .84661 .50114 .8412 .49395 Metetra
0 0 1 r
.8412 .49395 .84661 .50114 .85979 .49725 .85442 .49003 Metetra
0 0 1 r
.85442 .49003 .85979 .49725 .87303 .49335 .8677 .48609 Metetra
0 0 1 r
.8677 .48609 .87303 .49335 .88633 .48943 .88105 .48214 Metetra
0 0 1 r
.88105 .48214 .88633 .48943 .89969 .48549 .89445 .47817 Metetra
0 0 1 r
.89445 .47817 .89969 .48549 .91311 .48153 .90792 .47418 Metetra
0 0 1 r
.90792 .47418 .91311 .48153 .92659 .47755 .92145 .47017 Metetra
0 0 1 r
.92145 .47017 .92659 .47755 .94014 .47356 .93504 .46614 Metetra
0 0 1 r
.32836 .63785 .33528 .64389 .3463 .64063 .33941 .63456 Metetra
0 0 1 r
.33941 .63456 .3463 .64063 .35737 .63735 .3505 .63126 Metetra
0 0 1 r
.3505 .63126 .35737 .63735 .36848 .63405 .36165 .62794 Metetra
0 0 1 r
.36165 .62794 .36848 .63405 .37964 .63075 .37283 .6246 Metetra
0 0 1 r
.37283 .6246 .37964 .63075 .39085 .62742 .38407 .62126 Metetra
0 0 1 r
.38407 .62126 .39085 .62742 .4021 .62409 .39535 .6179 Metetra
0 0 1 r
.39535 .6179 .4021 .62409 .4134 .62074 .40668 .61452 Metetra
0 0 1 r
.40668 .61452 .4134 .62074 .42475 .61738 .41806 .61113 Metetra
0 0 1 r
.41806 .61113 .42475 .61738 .43614 .614 .42948 .60773 Metetra
0 0 1 r
.42948 .60773 .43614 .614 .44759 .61061 .44096 .60431 Metetra
0 0 1 r
.44096 .60431 .44759 .61061 .45908 .6072 .45248 .60088 Metetra
0 0 1 r
.45248 .60088 .45908 .6072 .47062 .60378 .46405 .59743 Metetra
0 0 1 r
.46405 .59743 .47062 .60378 .48221 .60035 .47568 .59397 Metetra
0 0 1 r
.47568 .59397 .48221 .60035 .49385 .5969 .48735 .59049 Metetra
0 0 1 r
.48735 .59049 .49385 .5969 .50554 .59343 .49907 .587 Metetra
0 0 1 r
.49907 .587 .50554 .59343 .51728 .58995 .51084 .58349 Metetra
0 0 1 r
.51084 .58349 .51728 .58995 .52907 .58646 .52266 .57997 Metetra
0 0 1 r
.52266 .57997 .52907 .58646 .54091 .58295 .53454 .57643 Metetra
0 0 1 r
.53454 .57643 .54091 .58295 .5528 .57943 .54646 .57288 Metetra
0 0 1 r
.54646 .57288 .5528 .57943 .56474 .57589 .55844 .56931 Metetra
0 0 1 r
.55844 .56931 .56474 .57589 .57674 .57233 .57047 .56573 Metetra
0 0 1 r
.57047 .56573 .57674 .57233 .58878 .56876 .58255 .56213 Metetra
0 0 1 r
.58255 .56213 .58878 .56876 .60088 .56517 .59469 .55851 Metetra
0 0 1 r
.59469 .55851 .60088 .56517 .61304 .56157 .60687 .55488 Metetra
0 0 1 r
.60687 .55488 .61304 .56157 .62524 .55796 .61911 .55124 Metetra
0 0 1 r
.61911 .55124 .62524 .55796 .6375 .55432 .63141 .54757 Metetra
0 0 1 r
.63141 .54757 .6375 .55432 .64981 .55067 .64376 .54389 Metetra
0 0 1 r
.64376 .54389 .64981 .55067 .66218 .54701 .65616 .5402 Metetra
0 0 1 r
.65616 .5402 .66218 .54701 .6746 .54333 .66862 .53649 Metetra
0 0 1 r
.66862 .53649 .6746 .54333 .68707 .53963 .68113 .53276 Metetra
0 0 1 r
.68113 .53276 .68707 .53963 .69961 .53592 .6937 .52902 Metetra
0 0 1 r
.6937 .52902 .69961 .53592 .71219 .53219 .70633 .52525 Metetra
0 0 1 r
.70633 .52525 .71219 .53219 .72483 .52844 .71901 .52148 Metetra
0 0 1 r
.71901 .52148 .72483 .52844 .73753 .52467 .73175 .51768 Metetra
0 0 1 r
.73175 .51768 .73753 .52467 .75029 .52089 .74454 .51387 Metetra
0 0 1 r
.74454 .51387 .75029 .52089 .7631 .5171 .75739 .51004 Metetra
0 0 1 r
.75739 .51004 .7631 .5171 .77597 .51328 .77031 .5062 Metetra
0 0 1 r
.77031 .5062 .77597 .51328 .7889 .50945 .78327 .50233 Metetra
0 0 1 r
.78327 .50233 .7889 .50945 .80189 .5056 .7963 .49845 Metetra
0 0 1 r
.7963 .49845 .80189 .5056 .81493 .50174 .80939 .49455 Metetra
0 0 1 r
.80939 .49455 .81493 .50174 .82803 .49785 .82254 .49064 Metetra
0 0 1 r
.82254 .49064 .82803 .49785 .8412 .49395 .83574 .4867 Metetra
0 0 1 r
.83574 .4867 .8412 .49395 .85442 .49003 .84901 .48275 Metetra
0 0 1 r
.84901 .48275 .85442 .49003 .8677 .48609 .86234 .47878 Metetra
0 0 1 r
.86234 .47878 .8677 .48609 .88105 .48214 .87572 .47479 Metetra
0 0 1 r
.87572 .47479 .88105 .48214 .89445 .47817 .88917 .47078 Metetra
0 0 1 r
.88917 .47078 .89445 .47817 .90792 .47418 .90269 .46676 Metetra
0 0 1 r
.90269 .46676 .90792 .47418 .92145 .47017 .91626 .46272 Metetra
0 0 1 r
.91626 .46272 .92145 .47017 .93504 .46614 .9299 .45865 Metetra
0 0 1 r
.32139 .63176 .32836 .63785 .33941 .63456 .33246 .62845 Metetra
0 0 1 r
.33246 .62845 .33941 .63456 .3505 .63126 .34359 .62512 Metetra
0 0 1 r
.34359 .62512 .3505 .63126 .36165 .62794 .35476 .62177 Metetra
0 0 1 r
.35476 .62177 .36165 .62794 .37283 .6246 .36597 .61841 Metetra
0 0 1 r
.36597 .61841 .37283 .6246 .38407 .62126 .37724 .61504 Metetra
0 0 1 r
.37724 .61504 .38407 .62126 .39535 .6179 .38855 .61165 Metetra
0 0 1 r
.38855 .61165 .39535 .6179 .40668 .61452 .39991 .60825 Metetra
0 0 1 r
.39991 .60825 .40668 .61452 .41806 .61113 .41132 .60484 Metetra
0 0 1 r
.41132 .60484 .41806 .61113 .42948 .60773 .42277 .6014 Metetra
0 0 1 r
.42277 .6014 .42948 .60773 .44096 .60431 .43428 .59796 Metetra
0 0 1 r
.43428 .59796 .44096 .60431 .45248 .60088 .44583 .5945 Metetra
0 0 1 r
.44583 .5945 .45248 .60088 .46405 .59743 .45744 .59103 Metetra
0 0 1 r
.45744 .59103 .46405 .59743 .47568 .59397 .46909 .58754 Metetra
0 0 1 r
.46909 .58754 .47568 .59397 .48735 .59049 .48079 .58403 Metetra
0 0 1 r
.48079 .58403 .48735 .59049 .49907 .587 .49255 .58051 Metetra
0 0 1 r
.49255 .58051 .49907 .587 .51084 .58349 .50435 .57698 Metetra
0 0 1 r
.50435 .57698 .51084 .58349 .52266 .57997 .51621 .57343 Metetra
0 0 1 r
.51621 .57343 .52266 .57997 .53454 .57643 .52812 .56986 Metetra
0 0 1 r
.52812 .56986 .53454 .57643 .54646 .57288 .54008 .56628 Metetra
0 0 1 r
.54008 .56628 .54646 .57288 .55844 .56931 .55209 .56268 Metetra
0 0 1 r
.55209 .56268 .55844 .56931 .57047 .56573 .56415 .55907 Metetra
0 0 1 r
.56415 .55907 .57047 .56573 .58255 .56213 .57627 .55544 Metetra
0 0 1 r
.57627 .55544 .58255 .56213 .59469 .55851 .58844 .5518 Metetra
0 0 1 r
.58844 .5518 .59469 .55851 .60687 .55488 .60066 .54814 Metetra
0 0 1 r
.60066 .54814 .60687 .55488 .61911 .55124 .61294 .54446 Metetra
0 0 1 r
.61294 .54446 .61911 .55124 .63141 .54757 .62527 .54077 Metetra
0 0 1 r
.62527 .54077 .63141 .54757 .64376 .54389 .63765 .53706 Metetra
0 0 1 r
.63765 .53706 .64376 .54389 .65616 .5402 .65009 .53333 Metetra
0 0 1 r
.65009 .53333 .65616 .5402 .66862 .53649 .66259 .52959 Metetra
0 0 1 r
.66259 .52959 .66862 .53649 .68113 .53276 .67514 .52583 Metetra
0 0 1 r
.67514 .52583 .68113 .53276 .6937 .52902 .68775 .52206 Metetra
0 0 1 r
.68775 .52206 .6937 .52902 .70633 .52525 .70041 .51827 Metetra
0 0 1 r
.70041 .51827 .70633 .52525 .71901 .52148 .71313 .51446 Metetra
0 0 1 r
.71313 .51446 .71901 .52148 .73175 .51768 .72591 .51063 Metetra
0 0 1 r
.72591 .51063 .73175 .51768 .74454 .51387 .73875 .50679 Metetra
0 0 1 r
.73875 .50679 .74454 .51387 .75739 .51004 .75164 .50293 Metetra
0 0 1 r
.75164 .50293 .75739 .51004 .77031 .5062 .76459 .49905 Metetra
0 0 1 r
.76459 .49905 .77031 .5062 .78327 .50233 .7776 .49515 Metetra
0 0 1 r
.7776 .49515 .78327 .50233 .7963 .49845 .79067 .49124 Metetra
0 0 1 r
.79067 .49124 .7963 .49845 .80939 .49455 .8038 .48731 Metetra
0 0 1 r
.8038 .48731 .80939 .49455 .82254 .49064 .81699 .48336 Metetra
0 0 1 r
.81699 .48336 .82254 .49064 .83574 .4867 .83024 .47939 Metetra
0 0 1 r
.83024 .47939 .83574 .4867 .84901 .48275 .84355 .47541 Metetra
0 0 1 r
.84355 .47541 .84901 .48275 .86234 .47878 .85692 .4714 Metetra
0 0 1 r
.85692 .4714 .86234 .47878 .87572 .47479 .87035 .46738 Metetra
0 0 1 r
.87035 .46738 .87572 .47479 .88917 .47078 .88385 .46334 Metetra
0 0 1 r
.88385 .46334 .88917 .47078 .90269 .46676 .89741 .45928 Metetra
0 0 1 r
.89741 .45928 .90269 .46676 .91626 .46272 .91103 .4552 Metetra
0 0 1 r
.91103 .4552 .91626 .46272 .9299 .45865 .92471 .4511 Metetra
0 0 1 r
.31436 .62563 .32139 .63176 .33246 .62845 .32546 .62229 Metetra
0 0 1 r
.32546 .62229 .33246 .62845 .34359 .62512 .33661 .61893 Metetra
0 0 1 r
.33661 .61893 .34359 .62512 .35476 .62177 .34781 .61556 Metetra
0 0 1 r
.34781 .61556 .35476 .62177 .36597 .61841 .35906 .61218 Metetra
0 0 1 r
.35906 .61218 .36597 .61841 .37724 .61504 .37035 .60878 Metetra
0 0 1 r
.37035 .60878 .37724 .61504 .38855 .61165 .38169 .60536 Metetra
0 0 1 r
.38169 .60536 .38855 .61165 .39991 .60825 .39308 .60193 Metetra
0 0 1 r
.39308 .60193 .39991 .60825 .41132 .60484 .40452 .59849 Metetra
0 0 1 r
.40452 .59849 .41132 .60484 .42277 .6014 .41601 .59503 Metetra
0 0 1 r
.41601 .59503 .42277 .6014 .43428 .59796 .42755 .59156 Metetra
0 0 1 r
.42755 .59156 .43428 .59796 .44583 .5945 .43913 .58807 Metetra
0 0 1 r
.43913 .58807 .44583 .5945 .45744 .59103 .45077 .58457 Metetra
0 0 1 r
.45077 .58457 .45744 .59103 .46909 .58754 .46245 .58105 Metetra
0 0 1 r
.46245 .58105 .46909 .58754 .48079 .58403 .47419 .57752 Metetra
0 0 1 r
.47419 .57752 .48079 .58403 .49255 .58051 .48598 .57397 Metetra
0 0 1 r
.48598 .57397 .49255 .58051 .50435 .57698 .49781 .57041 Metetra
0 0 1 r
.49781 .57041 .50435 .57698 .51621 .57343 .5097 .56683 Metetra
0 0 1 r
.5097 .56683 .51621 .57343 .52812 .56986 .52164 .56324 Metetra
0 0 1 r
.52164 .56324 .52812 .56986 .54008 .56628 .53364 .55963 Metetra
0 0 1 r
.53364 .55963 .54008 .56628 .55209 .56268 .54568 .556 Metetra
0 0 1 r
.54568 .556 .55209 .56268 .56415 .55907 .55778 .55236 Metetra
0 0 1 r
.55778 .55236 .56415 .55907 .57627 .55544 .56993 .5487 Metetra
0 0 1 r
.56993 .5487 .57627 .55544 .58844 .5518 .58214 .54503 Metetra
0 0 1 r
.58214 .54503 .58844 .5518 .60066 .54814 .5944 .54134 Metetra
0 0 1 r
.5944 .54134 .60066 .54814 .61294 .54446 .60671 .53763 Metetra
0 0 1 r
.60671 .53763 .61294 .54446 .62527 .54077 .61908 .53391 Metetra
0 0 1 r
.61908 .53391 .62527 .54077 .63765 .53706 .6315 .53017 Metetra
0 0 1 r
.6315 .53017 .63765 .53706 .65009 .53333 .64398 .52641 Metetra
0 0 1 r
.64398 .52641 .65009 .53333 .66259 .52959 .65651 .52264 Metetra
0 0 1 r
.65651 .52264 .66259 .52959 .67514 .52583 .6691 .51885 Metetra
0 0 1 r
.6691 .51885 .67514 .52583 .68775 .52206 .68175 .51504 Metetra
0 0 1 r
.68175 .51504 .68775 .52206 .70041 .51827 .69445 .51122 Metetra
0 0 1 r
.69445 .51122 .70041 .51827 .71313 .51446 .70721 .50738 Metetra
0 0 1 r
.70721 .50738 .71313 .51446 .72591 .51063 .72003 .50352 Metetra
0 0 1 r
.72003 .50352 .72591 .51063 .73875 .50679 .7329 .49965 Metetra
0 0 1 r
.7329 .49965 .73875 .50679 .75164 .50293 .74584 .49575 Metetra
0 0 1 r
.74584 .49575 .75164 .50293 .76459 .49905 .75883 .49184 Metetra
0 0 1 r
.75883 .49184 .76459 .49905 .7776 .49515 .77188 .48791 Metetra
0 0 1 r
.77188 .48791 .7776 .49515 .79067 .49124 .785 .48397 Metetra
0 0 1 r
.785 .48397 .79067 .49124 .8038 .48731 .79817 .48 Metetra
0 0 1 r
.79817 .48 .8038 .48731 .81699 .48336 .8114 .47602 Metetra
0 0 1 r
.8114 .47602 .81699 .48336 .83024 .47939 .82469 .47202 Metetra
0 0 1 r
.82469 .47202 .83024 .47939 .84355 .47541 .83804 .468 Metetra
0 0 1 r
.83804 .468 .84355 .47541 .85692 .4714 .85146 .46396 Metetra
0 0 1 r
.85146 .46396 .85692 .4714 .87035 .46738 .86494 .4599 Metetra
0 0 1 r
.86494 .4599 .87035 .46738 .88385 .46334 .87848 .45583 Metetra
0 0 1 r
.87848 .45583 .88385 .46334 .89741 .45928 .89208 .45173 Metetra
0 0 1 r
.89208 .45173 .89741 .45928 .91103 .4552 .90575 .44762 Metetra
0 0 1 r
.90575 .44762 .91103 .4552 .92471 .4511 .91948 .44349 Metetra
0 0 1 r
.30728 .61945 .31436 .62563 .32546 .62229 .31841 .61608 Metetra
0 0 1 r
.31841 .61608 .32546 .62229 .33661 .61893 .32959 .6127 Metetra
0 0 1 r
.32959 .6127 .33661 .61893 .34781 .61556 .34082 .6093 Metetra
0 0 1 r
.34082 .6093 .34781 .61556 .35906 .61218 .35209 .60589 Metetra
0 0 1 r
.35209 .60589 .35906 .61218 .37035 .60878 .36341 .60246 Metetra
0 0 1 r
.36341 .60246 .37035 .60878 .38169 .60536 .37479 .59902 Metetra
0 0 1 r
.37479 .59902 .38169 .60536 .39308 .60193 .38621 .59557 Metetra
0 0 1 r
.38621 .59557 .39308 .60193 .40452 .59849 .39767 .5921 Metetra
0 0 1 r
.39767 .5921 .40452 .59849 .41601 .59503 .40919 .58861 Metetra
0 0 1 r
.40919 .58861 .41601 .59503 .42755 .59156 .42076 .58511 Metetra
0 0 1 r
.42076 .58511 .42755 .59156 .43913 .58807 .43238 .5816 Metetra
0 0 1 r
.43238 .5816 .43913 .58807 .45077 .58457 .44404 .57807 Metetra
0 0 1 r
.44404 .57807 .45077 .58457 .46245 .58105 .45576 .57452 Metetra
0 0 1 r
.45576 .57452 .46245 .58105 .47419 .57752 .46753 .57096 Metetra
0 0 1 r
.46753 .57096 .47419 .57752 .48598 .57397 .47935 .56738 Metetra
0 0 1 r
.47935 .56738 .48598 .57397 .49781 .57041 .49122 .56379 Metetra
0 0 1 r
.49122 .56379 .49781 .57041 .5097 .56683 .50314 .56018 Metetra
0 0 1 r
.50314 .56018 .5097 .56683 .52164 .56324 .51512 .55656 Metetra
0 0 1 r
.51512 .55656 .52164 .56324 .53364 .55963 .52715 .55292 Metetra
0 0 1 r
.52715 .55292 .53364 .55963 .54568 .556 .53923 .54927 Metetra
0 0 1 r
.53923 .54927 .54568 .556 .55778 .55236 .55136 .54559 Metetra
0 0 1 r
.55136 .54559 .55778 .55236 .56993 .5487 .56355 .54191 Metetra
0 0 1 r
.56355 .54191 .56993 .5487 .58214 .54503 .57579 .5382 Metetra
0 0 1 r
.57579 .5382 .58214 .54503 .5944 .54134 .58808 .53448 Metetra
0 0 1 r
.58808 .53448 .5944 .54134 .60671 .53763 .60043 .53075 Metetra
0 0 1 r
.60043 .53075 .60671 .53763 .61908 .53391 .61284 .52699 Metetra
0 0 1 r
.61284 .52699 .61908 .53391 .6315 .53017 .6253 .52322 Metetra
0 0 1 r
.6253 .52322 .6315 .53017 .64398 .52641 .63781 .51944 Metetra
0 0 1 r
.63781 .51944 .64398 .52641 .65651 .52264 .65038 .51563 Metetra
0 0 1 r
.65038 .51563 .65651 .52264 .6691 .51885 .66301 .51181 Metetra
0 0 1 r
.66301 .51181 .6691 .51885 .68175 .51504 .6757 .50797 Metetra
0 0 1 r
.6757 .50797 .68175 .51504 .69445 .51122 .68844 .50412 Metetra
0 0 1 r
.68844 .50412 .69445 .51122 .70721 .50738 .70124 .50024 Metetra
0 0 1 r
.70124 .50024 .70721 .50738 .72003 .50352 .7141 .49635 Metetra
0 0 1 r
.7141 .49635 .72003 .50352 .7329 .49965 .72701 .49245 Metetra
0 0 1 r
.72701 .49245 .7329 .49965 .74584 .49575 .73999 .48852 Metetra
0 0 1 r
.73999 .48852 .74584 .49575 .75883 .49184 .75302 .48458 Metetra
0 0 1 r
.75302 .48458 .75883 .49184 .77188 .48791 .76612 .48061 Metetra
0 0 1 r
.76612 .48061 .77188 .48791 .785 .48397 .77927 .47663 Metetra
0 0 1 r
.77927 .47663 .785 .48397 .79817 .48 .79248 .47264 Metetra
0 0 1 r
.79248 .47264 .79817 .48 .8114 .47602 .80576 .46862 Metetra
0 0 1 r
.80576 .46862 .8114 .47602 .82469 .47202 .81909 .46458 Metetra
0 0 1 r
.81909 .46458 .82469 .47202 .83804 .468 .83249 .46053 Metetra
0 0 1 r
.83249 .46053 .83804 .468 .85146 .46396 .84595 .45646 Metetra
0 0 1 r
.84595 .45646 .85146 .46396 .86494 .4599 .85948 .45237 Metetra
0 0 1 r
.85948 .45237 .86494 .4599 .87848 .45583 .87306 .44826 Metetra
0 0 1 r
.87306 .44826 .87848 .45583 .89208 .45173 .88671 .44413 Metetra
0 0 1 r
.88671 .44413 .89208 .45173 .90575 .44762 .90042 .43998 Metetra
0 0 1 r
.90042 .43998 .90575 .44762 .91948 .44349 .9142 .43581 Metetra
0 0 1 r
.30014 .61322 .30728 .61945 .31841 .61608 .3113 .60982 Metetra
0 0 1 r
.3113 .60982 .31841 .61608 .32959 .6127 .32251 .60641 Metetra
0 0 1 r
.32251 .60641 .32959 .6127 .34082 .6093 .33376 .60299 Metetra
0 0 1 r
.33376 .60299 .34082 .6093 .35209 .60589 .34507 .59955 Metetra
0 0 1 r
.34507 .59955 .35209 .60589 .36341 .60246 .35642 .5961 Metetra
0 0 1 r
.35642 .5961 .36341 .60246 .37479 .59902 .36782 .59263 Metetra
0 0 1 r
.36782 .59263 .37479 .59902 .38621 .59557 .37927 .58915 Metetra
0 0 1 r
.37927 .58915 .38621 .59557 .39767 .5921 .39077 .58565 Metetra
0 0 1 r
.39077 .58565 .39767 .5921 .40919 .58861 .40232 .58214 Metetra
0 0 1 r
.40232 .58214 .40919 .58861 .42076 .58511 .41392 .57861 Metetra
0 0 1 r
.41392 .57861 .42076 .58511 .43238 .5816 .42557 .57507 Metetra
0 0 1 r
.42557 .57507 .43238 .5816 .44404 .57807 .43727 .57151 Metetra
0 0 1 r
.43727 .57151 .44404 .57807 .45576 .57452 .44902 .56793 Metetra
0 0 1 r
.44902 .56793 .45576 .57452 .46753 .57096 .46082 .56434 Metetra
0 0 1 r
.46082 .56434 .46753 .57096 .47935 .56738 .47267 .56074 Metetra
0 0 1 r
.47267 .56074 .47935 .56738 .49122 .56379 .48457 .55712 Metetra
0 0 1 r
.48457 .55712 .49122 .56379 .50314 .56018 .49653 .55348 Metetra
0 0 1 r
.49653 .55348 .50314 .56018 .51512 .55656 .50854 .54983 Metetra
0 0 1 r
.50854 .54983 .51512 .55656 .52715 .55292 .5206 .54616 Metetra
0 0 1 r
.5206 .54616 .52715 .55292 .53923 .54927 .53272 .54247 Metetra
0 0 1 r
.53272 .54247 .53923 .54927 .55136 .54559 .54489 .53877 Metetra
0 0 1 r
.54489 .53877 .55136 .54559 .56355 .54191 .55711 .53506 Metetra
0 0 1 r
.55711 .53506 .56355 .54191 .57579 .5382 .56939 .53132 Metetra
0 0 1 r
.56939 .53132 .57579 .5382 .58808 .53448 .58172 .52757 Metetra
0 0 1 r
.58172 .52757 .58808 .53448 .60043 .53075 .5941 .5238 Metetra
0 0 1 r
.5941 .5238 .60043 .53075 .61284 .52699 .60654 .52002 Metetra
0 0 1 r
.60654 .52002 .61284 .52699 .6253 .52322 .61904 .51622 Metetra
0 0 1 r
.61904 .51622 .6253 .52322 .63781 .51944 .6316 .5124 Metetra
0 0 1 r
.6316 .5124 .63781 .51944 .65038 .51563 .64421 .50856 Metetra
0 0 1 r
.64421 .50856 .65038 .51563 .66301 .51181 .65687 .50471 Metetra
0 0 1 r
.65687 .50471 .66301 .51181 .6757 .50797 .6696 .50084 Metetra
0 0 1 r
.6696 .50084 .6757 .50797 .68844 .50412 .68238 .49695 Metetra
0 0 1 r
.68238 .49695 .68844 .50412 .70124 .50024 .69522 .49305 Metetra
0 0 1 r
.69522 .49305 .70124 .50024 .7141 .49635 .70812 .48912 Metetra
0 0 1 r
.70812 .48912 .7141 .49635 .72701 .49245 .72107 .48518 Metetra
0 0 1 r
.72107 .48518 .72701 .49245 .73999 .48852 .73409 .48122 Metetra
0 0 1 r
.73409 .48122 .73999 .48852 .75302 .48458 .74716 .47725 Metetra
0 0 1 r
.74716 .47725 .75302 .48458 .76612 .48061 .7603 .47325 Metetra
0 0 1 r
.7603 .47325 .76612 .48061 .77927 .47663 .7735 .46924 Metetra
0 0 1 r
.7735 .46924 .77927 .47663 .79248 .47264 .78675 .46521 Metetra
0 0 1 r
.78675 .46521 .79248 .47264 .80576 .46862 .80007 .46115 Metetra
0 0 1 r
.80007 .46115 .80576 .46862 .81909 .46458 .81345 .45709 Metetra
0 0 1 r
.81345 .45709 .81909 .46458 .83249 .46053 .82689 .453 Metetra
0 0 1 r
.82689 .453 .83249 .46053 .84595 .45646 .8404 .44889 Metetra
0 0 1 r
.8404 .44889 .84595 .45646 .85948 .45237 .85397 .44476 Metetra
0 0 1 r
.85397 .44476 .85948 .45237 .87306 .44826 .8676 .44062 Metetra
0 0 1 r
.8676 .44062 .87306 .44826 .88671 .44413 .88129 .43645 Metetra
0 0 1 r
.88129 .43645 .88671 .44413 .90042 .43998 .89505 .43226 Metetra
0 0 1 r
.89505 .43226 .90042 .43998 .9142 .43581 .90888 .42806 Metetra
0 0 1 r
.29294 .60694 .30014 .61322 .3113 .60982 .30413 .60352 Metetra
0 0 1 r
.30413 .60352 .3113 .60982 .32251 .60641 .31537 .60008 Metetra
0 0 1 r
.31537 .60008 .32251 .60641 .33376 .60299 .32666 .59663 Metetra
0 0 1 r
.32666 .59663 .33376 .60299 .34507 .59955 .33799 .59317 Metetra
0 0 1 r
.33799 .59317 .34507 .59955 .35642 .5961 .34937 .58968 Metetra
0 0 1 r
.34937 .58968 .35642 .5961 .36782 .59263 .3608 .58619 Metetra
0 0 1 r
.3608 .58619 .36782 .59263 .37927 .58915 .37228 .58268 Metetra
0 0 1 r
.37228 .58268 .37927 .58915 .39077 .58565 .38381 .57915 Metetra
0 0 1 r
.38381 .57915 .39077 .58565 .40232 .58214 .39539 .57561 Metetra
0 0 1 r
.39539 .57561 .40232 .58214 .41392 .57861 .40702 .57206 Metetra
0 0 1 r
.40702 .57206 .41392 .57861 .42557 .57507 .4187 .56848 Metetra
0 0 1 r
.4187 .56848 .42557 .57507 .43727 .57151 .43044 .5649 Metetra
0 0 1 r
.43044 .5649 .43727 .57151 .44902 .56793 .44222 .56129 Metetra
0 0 1 r
.44222 .56129 .44902 .56793 .46082 .56434 .45405 .55768 Metetra
0 0 1 r
.45405 .55768 .46082 .56434 .47267 .56074 .46594 .55404 Metetra
0 0 1 r
.46594 .55404 .47267 .56074 .48457 .55712 .47788 .55039 Metetra
0 0 1 r
.47788 .55039 .48457 .55712 .49653 .55348 .48987 .54673 Metetra
0 0 1 r
.48987 .54673 .49653 .55348 .50854 .54983 .50191 .54304 Metetra
0 0 1 r
.50191 .54304 .50854 .54983 .5206 .54616 .51401 .53934 Metetra
0 0 1 r
.51401 .53934 .5206 .54616 .53272 .54247 .52616 .53563 Metetra
0 0 1 r
.52616 .53563 .53272 .54247 .54489 .53877 .53836 .5319 Metetra
0 0 1 r
.53836 .5319 .54489 .53877 .55711 .53506 .55062 .52815 Metetra
0 0 1 r
.55062 .52815 .55711 .53506 .56939 .53132 .56293 .52438 Metetra
0 0 1 r
.56293 .52438 .56939 .53132 .58172 .52757 .5753 .5206 Metetra
0 0 1 r
.5753 .5206 .58172 .52757 .5941 .5238 .58772 .5168 Metetra
0 0 1 r
.58772 .5168 .5941 .5238 .60654 .52002 .6002 .51299 Metetra
0 0 1 r
.6002 .51299 .60654 .52002 .61904 .51622 .61273 .50916 Metetra
0 0 1 r
.61273 .50916 .61904 .51622 .6316 .5124 .62533 .50531 Metetra
0 0 1 r
.62533 .50531 .6316 .5124 .64421 .50856 .63797 .50144 Metetra
0 0 1 r
.63797 .50144 .64421 .50856 .65687 .50471 .65068 .49755 Metetra
0 0 1 r
.65068 .49755 .65687 .50471 .6696 .50084 .66344 .49365 Metetra
0 0 1 r
.66344 .49365 .6696 .50084 .68238 .49695 .67626 .48973 Metetra
0 0 1 r
.67626 .48973 .68238 .49695 .69522 .49305 .68914 .48579 Metetra
0 0 1 r
.68914 .48579 .69522 .49305 .70812 .48912 .70208 .48183 Metetra
0 0 1 r
.70208 .48183 .70812 .48912 .72107 .48518 .71508 .47786 Metetra
0 0 1 r
.71508 .47786 .72107 .48518 .73409 .48122 .72814 .47387 Metetra
0 0 1 r
.72814 .47387 .73409 .48122 .74716 .47725 .74126 .46986 Metetra
0 0 1 r
.74126 .46986 .74716 .47725 .7603 .47325 .75443 .46583 Metetra
0 0 1 r
.75443 .46583 .7603 .47325 .7735 .46924 .76767 .46178 Metetra
0 0 1 r
.76767 .46178 .7735 .46924 .78675 .46521 .78097 .45771 Metetra
0 0 1 r
.78097 .45771 .78675 .46521 .80007 .46115 .79433 .45363 Metetra
0 0 1 r
.79433 .45363 .80007 .46115 .81345 .45709 .80776 .44952 Metetra
0 0 1 r
.80776 .44952 .81345 .45709 .82689 .453 .82125 .4454 Metetra
0 0 1 r
.82125 .4454 .82689 .453 .8404 .44889 .8348 .44125 Metetra
0 0 1 r
.8348 .44125 .8404 .44889 .85397 .44476 .84841 .43709 Metetra
0 0 1 r
.84841 .43709 .85397 .44476 .8676 .44062 .86209 .43291 Metetra
0 0 1 r
.86209 .43291 .8676 .44062 .88129 .43645 .87583 .42871 Metetra
0 0 1 r
.87583 .42871 .88129 .43645 .89505 .43226 .88963 .42449 Metetra
0 0 1 r
.88963 .42449 .89505 .43226 .90888 .42806 .90351 .42024 Metetra
0 0 1 r
.28569 .60061 .29294 .60694 .30413 .60352 .29691 .59716 Metetra
0 0 1 r
.29691 .59716 .30413 .60352 .31537 .60008 .30818 .5937 Metetra
0 0 1 r
.30818 .5937 .31537 .60008 .32666 .59663 .31949 .59022 Metetra
0 0 1 r
.31949 .59022 .32666 .59663 .33799 .59317 .33086 .58673 Metetra
0 0 1 r
.33086 .58673 .33799 .59317 .34937 .58968 .34227 .58322 Metetra
0 0 1 r
.34227 .58322 .34937 .58968 .3608 .58619 .35373 .5797 Metetra
0 0 1 r
.35373 .5797 .3608 .58619 .37228 .58268 .36524 .57616 Metetra
0 0 1 r
.36524 .57616 .37228 .58268 .38381 .57915 .3768 .5726 Metetra
0 0 1 r
.3768 .5726 .38381 .57915 .39539 .57561 .38841 .56904 Metetra
0 0 1 r
.38841 .56904 .39539 .57561 .40702 .57206 .40007 .56545 Metetra
0 0 1 r
.40007 .56545 .40702 .57206 .4187 .56848 .41179 .56185 Metetra
0 0 1 r
.41179 .56185 .4187 .56848 .43044 .5649 .42355 .55823 Metetra
0 0 1 r
.42355 .55823 .43044 .5649 .44222 .56129 .43536 .5546 Metetra
0 0 1 r
.43536 .5546 .44222 .56129 .45405 .55768 .44723 .55095 Metetra
0 0 1 r
.44723 .55095 .45405 .55768 .46594 .55404 .45915 .54729 Metetra
0 0 1 r
.45915 .54729 .46594 .55404 .47788 .55039 .47112 .54361 Metetra
0 0 1 r
.47112 .54361 .47788 .55039 .48987 .54673 .48315 .53991 Metetra
0 0 1 r
.48315 .53991 .48987 .54673 .50191 .54304 .49522 .5362 Metetra
0 0 1 r
.49522 .5362 .50191 .54304 .51401 .53934 .50735 .53247 Metetra
0 0 1 r
.50735 .53247 .51401 .53934 .52616 .53563 .51954 .52873 Metetra
0 0 1 r
.51954 .52873 .52616 .53563 .53836 .5319 .53178 .52496 Metetra
0 0 1 r
.53178 .52496 .53836 .5319 .55062 .52815 .54407 .52119 Metetra
0 0 1 r
.54407 .52119 .55062 .52815 .56293 .52438 .55642 .51739 Metetra
0 0 1 r
.55642 .51739 .56293 .52438 .5753 .5206 .56883 .51358 Metetra
0 0 1 r
.56883 .51358 .5753 .5206 .58772 .5168 .58129 .50975 Metetra
0 0 1 r
.58129 .50975 .58772 .5168 .6002 .51299 .5938 .5059 Metetra
0 0 1 r
.5938 .5059 .6002 .51299 .61273 .50916 .60637 .50203 Metetra
0 0 1 r
.60637 .50203 .61273 .50916 .62533 .50531 .619 .49815 Metetra
0 0 1 r
.619 .49815 .62533 .50531 .63797 .50144 .63169 .49425 Metetra
0 0 1 r
.63169 .49425 .63797 .50144 .65068 .49755 .64444 .49033 Metetra
0 0 1 r
.64444 .49033 .65068 .49755 .66344 .49365 .65724 .4864 Metetra
0 0 1 r
.65724 .4864 .66344 .49365 .67626 .48973 .6701 .48244 Metetra
0 0 1 r
.6701 .48244 .67626 .48973 .68914 .48579 .68302 .47847 Metetra
0 0 1 r
.68302 .47847 .68914 .48579 .70208 .48183 .696 .47448 Metetra
0 0 1 r
.696 .47448 .70208 .48183 .71508 .47786 .70904 .47048 Metetra
0 0 1 r
.70904 .47048 .71508 .47786 .72814 .47387 .72214 .46645 Metetra
0 0 1 r
.72214 .46645 .72814 .47387 .74126 .46986 .7353 .4624 Metetra
0 0 1 r
.7353 .4624 .74126 .46986 .75443 .46583 .74852 .45834 Metetra
0 0 1 r
.74852 .45834 .75443 .46583 .76767 .46178 .7618 .45426 Metetra
0 0 1 r
.7618 .45426 .76767 .46178 .78097 .45771 .77514 .45015 Metetra
0 0 1 r
.77514 .45015 .78097 .45771 .79433 .45363 .78855 .44603 Metetra
0 0 1 r
.78855 .44603 .79433 .45363 .80776 .44952 .80202 .44189 Metetra
0 0 1 r
.80202 .44189 .80776 .44952 .82125 .4454 .81555 .43773 Metetra
0 0 1 r
.81555 .43773 .82125 .4454 .8348 .44125 .82914 .43355 Metetra
0 0 1 r
.82914 .43355 .8348 .44125 .84841 .43709 .8428 .42936 Metetra
0 0 1 r
.8428 .42936 .84841 .43709 .86209 .43291 .85653 .42514 Metetra
0 0 1 r
.85653 .42514 .86209 .43291 .87583 .42871 .87032 .4209 Metetra
0 0 1 r
.87032 .4209 .87583 .42871 .88963 .42449 .88417 .41664 Metetra
0 0 1 r
.88417 .41664 .88963 .42449 .90351 .42024 .89809 .41236 Metetra
0 0 1 r
.27838 .59423 .28569 .60061 .29691 .59716 .28963 .59076 Metetra
0 0 1 r
.28963 .59076 .29691 .59716 .30818 .5937 .30093 .58727 Metetra
0 0 1 r
.30093 .58727 .30818 .5937 .31949 .59022 .31227 .58376 Metetra
0 0 1 r
.31227 .58376 .31949 .59022 .33086 .58673 .32366 .58024 Metetra
0 0 1 r
.32366 .58024 .33086 .58673 .34227 .58322 .33511 .5767 Metetra
0 0 1 r
.33511 .5767 .34227 .58322 .35373 .5797 .3466 .57315 Metetra
0 0 1 r
.3466 .57315 .35373 .5797 .36524 .57616 .35814 .56959 Metetra
0 0 1 r
.35814 .56959 .36524 .57616 .3768 .5726 .36973 .566 Metetra
0 0 1 r
.36973 .566 .3768 .5726 .38841 .56904 .38137 .56241 Metetra
0 0 1 r
.38137 .56241 .38841 .56904 .40007 .56545 .39307 .55879 Metetra
0 0 1 r
.39307 .55879 .40007 .56545 .41179 .56185 .40481 .55516 Metetra
0 0 1 r
.40481 .55516 .41179 .56185 .42355 .55823 .41661 .55152 Metetra
0 0 1 r
.41661 .55152 .42355 .55823 .43536 .5546 .42845 .54786 Metetra
0 0 1 r
.42845 .54786 .43536 .5546 .44723 .55095 .44035 .54418 Metetra
0 0 1 r
.44035 .54418 .44723 .55095 .45915 .54729 .45231 .54048 Metetra
0 0 1 r
.45231 .54048 .45915 .54729 .47112 .54361 .46431 .53677 Metetra
0 0 1 r
.46431 .53677 .47112 .54361 .48315 .53991 .47637 .53305 Metetra
0 0 1 r
.47637 .53305 .48315 .53991 .49522 .5362 .48848 .5293 Metetra
0 0 1 r
.48848 .5293 .49522 .5362 .50735 .53247 .50065 .52554 Metetra
0 0 1 r
.50065 .52554 .50735 .53247 .51954 .52873 .51287 .52177 Metetra
0 0 1 r
.51287 .52177 .51954 .52873 .53178 .52496 .52514 .51797 Metetra
0 0 1 r
.52514 .51797 .53178 .52496 .54407 .52119 .53747 .51416 Metetra
0 0 1 r
.53747 .51416 .54407 .52119 .55642 .51739 .54986 .51034 Metetra
0 0 1 r
.54986 .51034 .55642 .51739 .56883 .51358 .5623 .50649 Metetra
0 0 1 r
.5623 .50649 .56883 .51358 .58129 .50975 .5748 .50263 Metetra
0 0 1 r
.5748 .50263 .58129 .50975 .5938 .5059 .58735 .49875 Metetra
0 0 1 r
.58735 .49875 .5938 .5059 .60637 .50203 .59996 .49485 Metetra
0 0 1 r
.59996 .49485 .60637 .50203 .619 .49815 .61263 .49094 Metetra
0 0 1 r
.61263 .49094 .619 .49815 .63169 .49425 .62536 .487 Metetra
0 0 1 r
.62536 .487 .63169 .49425 .64444 .49033 .63814 .48305 Metetra
0 0 1 r
.63814 .48305 .64444 .49033 .65724 .4864 .65098 .47909 Metetra
0 0 1 r
.65098 .47909 .65724 .4864 .6701 .48244 .66388 .4751 Metetra
0 0 1 r
.66388 .4751 .6701 .48244 .68302 .47847 .67684 .47109 Metetra
0 0 1 r
.67684 .47109 .68302 .47847 .696 .47448 .68986 .46707 Metetra
0 0 1 r
.68986 .46707 .696 .47448 .70904 .47048 .70294 .46303 Metetra
0 0 1 r
.70294 .46303 .70904 .47048 .72214 .46645 .71609 .45897 Metetra
0 0 1 r
.71609 .45897 .72214 .46645 .7353 .4624 .72929 .45489 Metetra
0 0 1 r
.72929 .45489 .7353 .4624 .74852 .45834 .74255 .45079 Metetra
0 0 1 r
.74255 .45079 .74852 .45834 .7618 .45426 .75588 .44667 Metetra
0 0 1 r
.75588 .44667 .7618 .45426 .77514 .45015 .76926 .44253 Metetra
0 0 1 r
.76926 .44253 .77514 .45015 .78855 .44603 .78271 .43838 Metetra
0 0 1 r
.78271 .43838 .78855 .44603 .80202 .44189 .79623 .4342 Metetra
0 0 1 r
.79623 .4342 .80202 .44189 .81555 .43773 .8098 .43 Metetra
0 0 1 r
.8098 .43 .81555 .43773 .82914 .43355 .82344 .42579 Metetra
0 0 1 r
.82344 .42579 .82914 .43355 .8428 .42936 .83715 .42155 Metetra
0 0 1 r
.83715 .42155 .8428 .42936 .85653 .42514 .85092 .4173 Metetra
0 0 1 r
.85092 .4173 .85653 .42514 .87032 .4209 .86476 .41302 Metetra
0 0 1 r
.86476 .41302 .87032 .4209 .88417 .41664 .87866 .40872 Metetra
0 0 1 r
.87866 .40872 .88417 .41664 .89809 .41236 .89262 .40441 Metetra
0 0 1 r
.27102 .5878 .27838 .59423 .28963 .59076 .28229 .5843 Metetra
0 0 1 r
.28229 .5843 .28963 .59076 .30093 .58727 .29362 .58078 Metetra
0 0 1 r
.29362 .58078 .30093 .58727 .31227 .58376 .30499 .57725 Metetra
0 0 1 r
.30499 .57725 .31227 .58376 .32366 .58024 .31642 .5737 Metetra
0 0 1 r
.31642 .5737 .32366 .58024 .33511 .5767 .32789 .57014 Metetra
0 0 1 r
.32789 .57014 .33511 .5767 .3466 .57315 .33941 .56656 Metetra
0 0 1 r
.33941 .56656 .3466 .57315 .35814 .56959 .35098 .56296 Metetra
0 0 1 r
.35098 .56296 .35814 .56959 .36973 .566 .3626 .55935 Metetra
0 0 1 r
.3626 .55935 .36973 .566 .38137 .56241 .37428 .55572 Metetra
0 0 1 r
.37428 .55572 .38137 .56241 .39307 .55879 .386 .55208 Metetra
0 0 1 r
.386 .55208 .39307 .55879 .40481 .55516 .39778 .54842 Metetra
0 0 1 r
.39778 .54842 .40481 .55516 .41661 .55152 .40961 .54474 Metetra
0 0 1 r
.40961 .54474 .41661 .55152 .42845 .54786 .42149 .54105 Metetra
0 0 1 r
.42149 .54105 .42845 .54786 .44035 .54418 .43342 .53735 Metetra
0 0 1 r
.43342 .53735 .44035 .54418 .45231 .54048 .44541 .53362 Metetra
0 0 1 r
.44541 .53362 .45231 .54048 .46431 .53677 .45745 .52988 Metetra
0 0 1 r
.45745 .52988 .46431 .53677 .47637 .53305 .46954 .52612 Metetra
0 0 1 r
.46954 .52612 .47637 .53305 .48848 .5293 .48169 .52235 Metetra
0 0 1 r
.48169 .52235 .48848 .5293 .50065 .52554 .49389 .51856 Metetra
0 0 1 r
.49389 .51856 .50065 .52554 .51287 .52177 .50614 .51475 Metetra
0 0 1 r
.50614 .51475 .51287 .52177 .52514 .51797 .51845 .51093 Metetra
0 0 1 r
.51845 .51093 .52514 .51797 .53747 .51416 .53082 .50708 Metetra
0 0 1 r
.53082 .50708 .53747 .51416 .54986 .51034 .54324 .50322 Metetra
0 0 1 r
.54324 .50322 .54986 .51034 .5623 .50649 .55572 .49935 Metetra
0 0 1 r
.55572 .49935 .5623 .50649 .5748 .50263 .56825 .49545 Metetra
0 0 1 r
.56825 .49545 .5748 .50263 .58735 .49875 .58085 .49154 Metetra
0 0 1 r
.58085 .49154 .58735 .49875 .59996 .49485 .59349 .48761 Metetra
0 0 1 r
.59349 .48761 .59996 .49485 .61263 .49094 .6062 .48366 Metetra
0 0 1 r
.6062 .48366 .61263 .49094 .62536 .487 .61897 .4797 Metetra
0 0 1 r
.61897 .4797 .62536 .487 .63814 .48305 .63179 .47571 Metetra
0 0 1 r
.63179 .47571 .63814 .48305 .65098 .47909 .64467 .47171 Metetra
0 0 1 r
.64467 .47171 .65098 .47909 .66388 .4751 .65761 .46769 Metetra
0 0 1 r
.65761 .46769 .66388 .4751 .67684 .47109 .67061 .46365 Metetra
0 0 1 r
.67061 .46365 .67684 .47109 .68986 .46707 .68368 .45959 Metetra
0 0 1 r
.68368 .45959 .68986 .46707 .70294 .46303 .6968 .45551 Metetra
0 0 1 r
.6968 .45551 .70294 .46303 .71609 .45897 .70998 .45142 Metetra
0 0 1 r
.70998 .45142 .71609 .45897 .72929 .45489 .72323 .4473 Metetra
0 0 1 r
.72323 .4473 .72929 .45489 .74255 .45079 .73653 .44317 Metetra
0 0 1 r
.73653 .44317 .74255 .45079 .75588 .44667 .7499 .43902 Metetra
0 0 1 r
.7499 .43902 .75588 .44667 .76926 .44253 .76333 .43484 Metetra
0 0 1 r
.76333 .43484 .76926 .44253 .78271 .43838 .77683 .43065 Metetra
0 0 1 r
.77683 .43065 .78271 .43838 .79623 .4342 .79038 .42644 Metetra
0 0 1 r
.79038 .42644 .79623 .4342 .8098 .43 .80401 .4222 Metetra
0 0 1 r
.80401 .4222 .8098 .43 .82344 .42579 .81769 .41795 Metetra
0 0 1 r
.81769 .41795 .82344 .42579 .83715 .42155 .83145 .41368 Metetra
0 0 1 r
.83145 .41368 .83715 .42155 .85092 .4173 .84526 .40939 Metetra
0 0 1 r
.84526 .40939 .85092 .4173 .86476 .41302 .85915 .40507 Metetra
0 0 1 r
.85915 .40507 .86476 .41302 .87866 .40872 .8731 .40074 Metetra
0 0 1 r
.8731 .40074 .87866 .40872 .89262 .40441 .88711 .39638 Metetra
0 0 1 r
.26359 .58132 .27102 .5878 .28229 .5843 .2749 .57779 Metetra
0 0 1 r
.2749 .57779 .28229 .5843 .29362 .58078 .28625 .57425 Metetra
0 0 1 r
.28625 .57425 .29362 .58078 .30499 .57725 .29766 .57068 Metetra
0 0 1 r
.29766 .57068 .30499 .57725 .31642 .5737 .30911 .56711 Metetra
0 0 1 r
.30911 .56711 .31642 .5737 .32789 .57014 .32061 .56351 Metetra
0 0 1 r
.32061 .56351 .32789 .57014 .33941 .56656 .33216 .55991 Metetra
0 0 1 r
.33216 .55991 .33941 .56656 .35098 .56296 .34377 .55628 Metetra
0 0 1 r
.34377 .55628 .35098 .56296 .3626 .55935 .35542 .55264 Metetra
0 0 1 r
.35542 .55264 .3626 .55935 .37428 .55572 .36713 .54898 Metetra
0 0 1 r
.36713 .54898 .37428 .55572 .386 .55208 .37888 .54531 Metetra
0 0 1 r
.37888 .54531 .386 .55208 .39778 .54842 .39069 .54162 Metetra
0 0 1 r
.39069 .54162 .39778 .54842 .40961 .54474 .40255 .53792 Metetra
0 0 1 r
.40255 .53792 .40961 .54474 .42149 .54105 .41447 .5342 Metetra
0 0 1 r
.41447 .5342 .42149 .54105 .43342 .53735 .42643 .53046 Metetra
0 0 1 r
.42643 .53046 .43342 .53735 .44541 .53362 .43845 .5267 Metetra
0 0 1 r
.43845 .5267 .44541 .53362 .45745 .52988 .45052 .52293 Metetra
0 0 1 r
.45052 .52293 .45745 .52988 .46954 .52612 .46265 .51914 Metetra
0 0 1 r
.46265 .51914 .46954 .52612 .48169 .52235 .47483 .51534 Metetra
0 0 1 r
.47483 .51534 .48169 .52235 .49389 .51856 .48707 .51152 Metetra
0 0 1 r
.48707 .51152 .49389 .51856 .50614 .51475 .49936 .50768 Metetra
0 0 1 r
.49936 .50768 .50614 .51475 .51845 .51093 .51171 .50382 Metetra
0 0 1 r
.51171 .50382 .51845 .51093 .53082 .50708 .52411 .49995 Metetra
0 0 1 r
.52411 .49995 .53082 .50708 .54324 .50322 .53657 .49605 Metetra
0 0 1 r
.53657 .49605 .54324 .50322 .55572 .49935 .54908 .49214 Metetra
0 0 1 r
.54908 .49214 .55572 .49935 .56825 .49545 .56166 .48822 Metetra
0 0 1 r
.56166 .48822 .56825 .49545 .58085 .49154 .57429 .48427 Metetra
0 0 1 r
.57429 .48427 .58085 .49154 .59349 .48761 .58697 .48031 Metetra
0 0 1 r
.58697 .48031 .59349 .48761 .6062 .48366 .59972 .47633 Metetra
0 0 1 r
.59972 .47633 .6062 .48366 .61897 .4797 .61252 .47233 Metetra
0 0 1 r
.61252 .47233 .61897 .4797 .63179 .47571 .62539 .46831 Metetra
0 0 1 r
.62539 .46831 .63179 .47571 .64467 .47171 .63831 .46427 Metetra
0 0 1 r
.63831 .46427 .64467 .47171 .65761 .46769 .65129 .46022 Metetra
0 0 1 r
.65129 .46022 .65761 .46769 .67061 .46365 .66433 .45614 Metetra
0 0 1 r
.66433 .45614 .67061 .46365 .68368 .45959 .67744 .45205 Metetra
0 0 1 r
.67744 .45205 .68368 .45959 .6968 .45551 .6906 .44794 Metetra
0 0 1 r
.6906 .44794 .6968 .45551 .70998 .45142 .70382 .44381 Metetra
0 0 1 r
.70382 .44381 .70998 .45142 .72323 .4473 .71711 .43966 Metetra
0 0 1 r
.71711 .43966 .72323 .4473 .73653 .44317 .73046 .43549 Metetra
0 0 1 r
.73046 .43549 .73653 .44317 .7499 .43902 .74387 .4313 Metetra
0 0 1 r
.74387 .4313 .7499 .43902 .76333 .43484 .75735 .42709 Metetra
0 0 1 r
.75735 .42709 .76333 .43484 .77683 .43065 .77089 .42286 Metetra
0 0 1 r
.77089 .42286 .77683 .43065 .79038 .42644 .78449 .41861 Metetra
0 0 1 r
.78449 .41861 .79038 .42644 .80401 .4222 .79816 .41434 Metetra
0 0 1 r
.79816 .41434 .80401 .4222 .81769 .41795 .81189 .41005 Metetra
0 0 1 r
.81189 .41005 .81769 .41795 .83145 .41368 .82569 .40574 Metetra
0 0 1 r
.82569 .40574 .83145 .41368 .84526 .40939 .83956 .40141 Metetra
0 0 1 r
.83956 .40141 .84526 .40939 .85915 .40507 .85349 .39706 Metetra
0 0 1 r
.85349 .39706 .85915 .40507 .8731 .40074 .86748 .39268 Metetra
0 0 1 r
.86748 .39268 .8731 .40074 .88711 .39638 .88155 .38829 Metetra
0 0 1 r
.25611 .57479 .26359 .58132 .2749 .57779 .26744 .57123 Metetra
0 0 1 r
.26744 .57123 .2749 .57779 .28625 .57425 .27883 .56766 Metetra
0 0 1 r
.27883 .56766 .28625 .57425 .29766 .57068 .29026 .56407 Metetra
0 0 1 r
.29026 .56407 .29766 .57068 .30911 .56711 .30174 .56046 Metetra
0 0 1 r
.30174 .56046 .30911 .56711 .32061 .56351 .31328 .55684 Metetra
0 0 1 r
.31328 .55684 .32061 .56351 .33216 .55991 .32486 .5532 Metetra
0 0 1 r
.32486 .5532 .33216 .55991 .34377 .55628 .33649 .54955 Metetra
0 0 1 r
.33649 .54955 .34377 .55628 .35542 .55264 .34818 .54588 Metetra
0 0 1 r
.34818 .54588 .35542 .55264 .36713 .54898 .35992 .54219 Metetra
0 0 1 r
.35992 .54219 .36713 .54898 .37888 .54531 .3717 .53849 Metetra
0 0 1 r
.3717 .53849 .37888 .54531 .39069 .54162 .38355 .53477 Metetra
0 0 1 r
.38355 .53477 .39069 .54162 .40255 .53792 .39544 .53103 Metetra
0 0 1 r
.39544 .53103 .40255 .53792 .41447 .5342 .40739 .52728 Metetra
0 0 1 r
.40739 .52728 .41447 .5342 .42643 .53046 .41938 .52351 Metetra
0 0 1 r
.41938 .52351 .42643 .53046 .43845 .5267 .43144 .51973 Metetra
0 0 1 r
.43144 .51973 .43845 .5267 .45052 .52293 .44355 .51592 Metetra
0 0 1 r
.44355 .51592 .45052 .52293 .46265 .51914 .45571 .51211 Metetra
0 0 1 r
.45571 .51211 .46265 .51914 .47483 .51534 .46792 .50827 Metetra
0 0 1 r
.46792 .50827 .47483 .51534 .48707 .51152 .4802 .50441 Metetra
0 0 1 r
.4802 .50441 .48707 .51152 .49936 .50768 .49252 .50054 Metetra
0 0 1 r
.49252 .50054 .49936 .50768 .51171 .50382 .50491 .49665 Metetra
0 0 1 r
.50491 .49665 .51171 .50382 .52411 .49995 .51734 .49275 Metetra
0 0 1 r
.51734 .49275 .52411 .49995 .53657 .49605 .52984 .48882 Metetra
0 0 1 r
.52984 .48882 .53657 .49605 .54908 .49214 .54239 .48488 Metetra
0 0 1 r
.54239 .48488 .54908 .49214 .56166 .48822 .555 .48092 Metetra
0 0 1 r
.555 .48092 .56166 .48822 .57429 .48427 .56767 .47694 Metetra
0 0 1 r
.56767 .47694 .57429 .48427 .58697 .48031 .5804 .47294 Metetra
0 0 1 r
.5804 .47294 .58697 .48031 .59972 .47633 .59318 .46893 Metetra
0 0 1 r
.59318 .46893 .59972 .47633 .61252 .47233 .60602 .46489 Metetra
0 0 1 r
.60602 .46489 .61252 .47233 .62539 .46831 .61893 .46084 Metetra
0 0 1 r
.61893 .46084 .62539 .46831 .63831 .46427 .63189 .45677 Metetra
0 0 1 r
.63189 .45677 .63831 .46427 .65129 .46022 .64491 .45268 Metetra
0 0 1 r
.64491 .45268 .65129 .46022 .66433 .45614 .658 .44857 Metetra
0 0 1 r
.658 .44857 .66433 .45614 .67744 .45205 .67114 .44444 Metetra
0 0 1 r
.67114 .44444 .67744 .45205 .6906 .44794 .68435 .4403 Metetra
0 0 1 r
.68435 .4403 .6906 .44794 .70382 .44381 .69761 .43613 Metetra
0 0 1 r
.69761 .43613 .70382 .44381 .71711 .43966 .71095 .43194 Metetra
0 0 1 r
.71095 .43194 .71711 .43966 .73046 .43549 .72434 .42774 Metetra
0 0 1 r
.72434 .42774 .73046 .43549 .74387 .4313 .73779 .42351 Metetra
0 0 1 r
.73779 .42351 .74387 .4313 .75735 .42709 .75131 .41926 Metetra
0 0 1 r
.75131 .41926 .75735 .42709 .77089 .42286 .7649 .415 Metetra
0 0 1 r
.7649 .415 .77089 .42286 .78449 .41861 .77855 .41071 Metetra
0 0 1 r
.77855 .41071 .78449 .41861 .79816 .41434 .79226 .4064 Metetra
0 0 1 r
.79226 .4064 .79816 .41434 .81189 .41005 .80604 .40207 Metetra
0 0 1 r
.80604 .40207 .81189 .41005 .82569 .40574 .81989 .39773 Metetra
0 0 1 r
.81989 .39773 .82569 .40574 .83956 .40141 .8338 .39336 Metetra
0 0 1 r
.8338 .39336 .83956 .40141 .85349 .39706 .84778 .38897 Metetra
0 0 1 r
.84778 .38897 .85349 .39706 .86748 .39268 .86182 .38456 Metetra
0 0 1 r
.86182 .38456 .86748 .39268 .88155 .38829 .87594 .38012 Metetra
0 0 1 r
.24857 .56821 .25611 .57479 .26744 .57123 .25993 .56462 Metetra
0 0 1 r
.25993 .56462 .26744 .57123 .27883 .56766 .27134 .56102 Metetra
0 0 1 r
.27134 .56102 .27883 .56766 .29026 .56407 .2828 .5574 Metetra
0 0 1 r
.2828 .5574 .29026 .56407 .30174 .56046 .29432 .55376 Metetra
0 0 1 r
.29432 .55376 .30174 .56046 .31328 .55684 .30588 .55011 Metetra
0 0 1 r
.30588 .55011 .31328 .55684 .32486 .5532 .31749 .54644 Metetra
0 0 1 r
.31749 .54644 .32486 .5532 .33649 .54955 .32916 .54276 Metetra
0 0 1 r
.32916 .54276 .33649 .54955 .34818 .54588 .34088 .53906 Metetra
0 0 1 r
.34088 .53906 .34818 .54588 .35992 .54219 .35265 .53534 Metetra
0 0 1 r
.35265 .53534 .35992 .54219 .3717 .53849 .36447 .53161 Metetra
0 0 1 r
.36447 .53161 .3717 .53849 .38355 .53477 .37634 .52786 Metetra
0 0 1 r
.37634 .52786 .38355 .53477 .39544 .53103 .38827 .52409 Metetra
0 0 1 r
.38827 .52409 .39544 .53103 .40739 .52728 .40025 .52031 Metetra
0 0 1 r
.40025 .52031 .40739 .52728 .41938 .52351 .41228 .51651 Metetra
0 0 1 r
.41228 .51651 .41938 .52351 .43144 .51973 .42437 .51269 Metetra
0 0 1 r
.42437 .51269 .43144 .51973 .44355 .51592 .43651 .50886 Metetra
0 0 1 r
.43651 .50886 .44355 .51592 .45571 .51211 .44871 .50501 Metetra
0 0 1 r
.44871 .50501 .45571 .51211 .46792 .50827 .46096 .50114 Metetra
0 0 1 r
.46096 .50114 .46792 .50827 .4802 .50441 .47326 .49725 Metetra
0 0 1 r
.47326 .49725 .4802 .50441 .49252 .50054 .48563 .49335 Metetra
0 0 1 r
.48563 .49335 .49252 .50054 .50491 .49665 .49805 .48943 Metetra
0 0 1 r
.49805 .48943 .50491 .49665 .51734 .49275 .51052 .48549 Metetra
0 0 1 r
.51052 .48549 .51734 .49275 .52984 .48882 .52305 .48153 Metetra
0 0 1 r
.52305 .48153 .52984 .48882 .54239 .48488 .53564 .47755 Metetra
0 0 1 r
.53564 .47755 .54239 .48488 .555 .48092 .54829 .47356 Metetra
0 0 1 r
.54829 .47356 .555 .48092 .56767 .47694 .561 .46955 Metetra
0 0 1 r
.561 .46955 .56767 .47694 .5804 .47294 .57376 .46552 Metetra
0 0 1 r
.57376 .46552 .5804 .47294 .59318 .46893 .58659 .46147 Metetra
0 0 1 r
.58659 .46147 .59318 .46893 .60602 .46489 .59947 .4574 Metetra
0 0 1 r
.59947 .4574 .60602 .46489 .61893 .46084 .61241 .45331 Metetra
0 0 1 r
.61241 .45331 .61893 .46084 .63189 .45677 .62542 .44921 Metetra
0 0 1 r
.62542 .44921 .63189 .45677 .64491 .45268 .63848 .44508 Metetra
0 0 1 r
.63848 .44508 .64491 .45268 .658 .44857 .65161 .44094 Metetra
0 0 1 r
.65161 .44094 .658 .44857 .67114 .44444 .66479 .43677 Metetra
0 0 1 r
.66479 .43677 .67114 .44444 .68435 .4403 .67804 .43259 Metetra
0 0 1 r
.67804 .43259 .68435 .4403 .69761 .43613 .69135 .42838 Metetra
0 0 1 r
.69135 .42838 .69761 .43613 .71095 .43194 .70472 .42416 Metetra
0 0 1 r
.70472 .42416 .71095 .43194 .72434 .42774 .71816 .41992 Metetra
0 0 1 r
.71816 .41992 .72434 .42774 .73779 .42351 .73166 .41565 Metetra
0 0 1 r
.73166 .41565 .73779 .42351 .75131 .41926 .74523 .41137 Metetra
0 0 1 r
.74523 .41137 .75131 .41926 .7649 .415 .75886 .40707 Metetra
0 0 1 r
.75886 .40707 .7649 .415 .77855 .41071 .77255 .40274 Metetra
0 0 1 r
.77255 .40274 .77855 .41071 .79226 .4064 .78631 .3984 Metetra
0 0 1 r
.78631 .3984 .79226 .4064 .80604 .40207 .80014 .39403 Metetra
0 0 1 r
.80014 .39403 .80604 .40207 .81989 .39773 .81403 .38964 Metetra
0 0 1 r
.81403 .38964 .81989 .39773 .8338 .39336 .82799 .38524 Metetra
0 0 1 r
.82799 .38524 .8338 .39336 .84778 .38897 .84202 .38081 Metetra
0 0 1 r
.84202 .38081 .84778 .38897 .86182 .38456 .85611 .37635 Metetra
0 0 1 r
.85611 .37635 .86182 .38456 .87594 .38012 .87028 .37188 Metetra
0 0 1 r
.24096 .56157 .24857 .56821 .25993 .56462 .25235 .55796 Metetra
0 0 1 r
.25235 .55796 .25993 .56462 .27134 .56102 .2638 .55432 Metetra
0 0 1 r
.2638 .55432 .27134 .56102 .2828 .5574 .27529 .55067 Metetra
0 0 1 r
.27529 .55067 .2828 .5574 .29432 .55376 .28683 .54701 Metetra
0 0 1 r
.28683 .54701 .29432 .55376 .30588 .55011 .29843 .54333 Metetra
0 0 1 r
.29843 .54333 .30588 .55011 .31749 .54644 .31007 .53963 Metetra
0 0 1 r
.31007 .53963 .31749 .54644 .32916 .54276 .32177 .53592 Metetra
0 0 1 r
.32177 .53592 .32916 .54276 .34088 .53906 .33352 .53219 Metetra
0 0 1 r
.33352 .53219 .34088 .53906 .35265 .53534 .34532 .52844 Metetra
0 0 1 r
.34532 .52844 .35265 .53534 .36447 .53161 .35717 .52467 Metetra
0 0 1 r
.35717 .52467 .36447 .53161 .37634 .52786 .36908 .52089 Metetra
0 0 1 r
.36908 .52089 .37634 .52786 .38827 .52409 .38104 .5171 Metetra
0 0 1 r
.38104 .5171 .38827 .52409 .40025 .52031 .39305 .51328 Metetra
0 0 1 r
.39305 .51328 .40025 .52031 .41228 .51651 .40512 .50945 Metetra
0 0 1 r
.40512 .50945 .41228 .51651 .42437 .51269 .41724 .5056 Metetra
0 0 1 r
.41724 .5056 .42437 .51269 .43651 .50886 .42941 .50174 Metetra
0 0 1 r
.42941 .50174 .43651 .50886 .44871 .50501 .44164 .49785 Metetra
0 0 1 r
.44164 .49785 .44871 .50501 .46096 .50114 .45393 .49395 Metetra
0 0 1 r
.45393 .49395 .46096 .50114 .47326 .49725 .46627 .49003 Metetra
0 0 1 r
.46627 .49003 .47326 .49725 .48563 .49335 .47867 .48609 Metetra
0 0 1 r
.47867 .48609 .48563 .49335 .49805 .48943 .49113 .48214 Metetra
0 0 1 r
.49113 .48214 .49805 .48943 .51052 .48549 .50364 .47817 Metetra
0 0 1 r
.50364 .47817 .51052 .48549 .52305 .48153 .51621 .47418 Metetra
0 0 1 r
.51621 .47418 .52305 .48153 .53564 .47755 .52884 .47017 Metetra
0 0 1 r
.52884 .47017 .53564 .47755 .54829 .47356 .54153 .46614 Metetra
0 0 1 r
.54153 .46614 .54829 .47356 .561 .46955 .55427 .46209 Metetra
0 0 1 r
.55427 .46209 .561 .46955 .57376 .46552 .56707 .45803 Metetra
0 0 1 r
.56707 .45803 .57376 .46552 .58659 .46147 .57994 .45394 Metetra
0 0 1 r
.57994 .45394 .58659 .46147 .59947 .4574 .59286 .44984 Metetra
0 0 1 r
.59286 .44984 .59947 .4574 .61241 .45331 .60584 .44572 Metetra
0 0 1 r
.60584 .44572 .61241 .45331 .62542 .44921 .61889 .44157 Metetra
0 0 1 r
.61889 .44157 .62542 .44921 .63848 .44508 .63199 .43741 Metetra
0 0 1 r
.63199 .43741 .63848 .44508 .65161 .44094 .64516 .43323 Metetra
0 0 1 r
.64516 .43323 .65161 .44094 .66479 .43677 .65839 .42903 Metetra
0 0 1 r
.65839 .42903 .66479 .43677 .67804 .43259 .67168 .42481 Metetra
0 0 1 r
.67168 .42481 .67804 .43259 .69135 .42838 .68503 .42057 Metetra
0 0 1 r
.68503 .42057 .69135 .42838 .70472 .42416 .69845 .41631 Metetra
0 0 1 r
.69845 .41631 .70472 .42416 .71816 .41992 .71193 .41203 Metetra
0 0 1 r
.71193 .41203 .71816 .41992 .73166 .41565 .72548 .40773 Metetra
0 0 1 r
.72548 .40773 .73166 .41565 .74523 .41137 .73909 .40341 Metetra
0 0 1 r
.73909 .40341 .74523 .41137 .75886 .40707 .75276 .39907 Metetra
0 0 1 r
.75276 .39907 .75886 .40707 .77255 .40274 .7665 .3947 Metetra
0 0 1 r
.7665 .3947 .77255 .40274 .78631 .3984 .78031 .39032 Metetra
0 0 1 r
.78031 .39032 .78631 .3984 .80014 .39403 .79418 .38591 Metetra
0 0 1 r
.79418 .38591 .80014 .39403 .81403 .38964 .80812 .38149 Metetra
0 0 1 r
.80812 .38149 .81403 .38964 .82799 .38524 .82213 .37704 Metetra
0 0 1 r
.82213 .37704 .82799 .38524 .84202 .38081 .83621 .37257 Metetra
0 0 1 r
.83621 .37257 .84202 .38081 .85611 .37635 .85035 .36808 Metetra
0 0 1 r
.85035 .36808 .85611 .37635 .87028 .37188 .86456 .36357 Metetra
0 0 1 r
.2333 .55488 .24096 .56157 .25235 .55796 .24472 .55124 Metetra
0 0 1 r
.24472 .55124 .25235 .55796 .2638 .55432 .25619 .54757 Metetra
0 0 1 r
.25619 .54757 .2638 .55432 .27529 .55067 .26771 .54389 Metetra
0 0 1 r
.26771 .54389 .27529 .55067 .28683 .54701 .27929 .5402 Metetra
0 0 1 r
.27929 .5402 .28683 .54701 .29843 .54333 .29091 .53649 Metetra
0 0 1 r
.29091 .53649 .29843 .54333 .31007 .53963 .30259 .53276 Metetra
0 0 1 r
.30259 .53276 .31007 .53963 .32177 .53592 .31431 .52902 Metetra
0 0 1 r
.31431 .52902 .32177 .53592 .33352 .53219 .32609 .52525 Metetra
0 0 1 r
.32609 .52525 .33352 .53219 .34532 .52844 .33793 .52148 Metetra
0 0 1 r
.33793 .52148 .34532 .52844 .35717 .52467 .34981 .51768 Metetra
0 0 1 r
.34981 .51768 .35717 .52467 .36908 .52089 .36175 .51387 Metetra
0 0 1 r
.36175 .51387 .36908 .52089 .38104 .5171 .37374 .51004 Metetra
0 0 1 r
.37374 .51004 .38104 .5171 .39305 .51328 .38579 .5062 Metetra
0 0 1 r
.38579 .5062 .39305 .51328 .40512 .50945 .39789 .50233 Metetra
0 0 1 r
.39789 .50233 .40512 .50945 .41724 .5056 .41005 .49845 Metetra
0 0 1 r
.41005 .49845 .41724 .5056 .42941 .50174 .42226 .49455 Metetra
0 0 1 r
.42226 .49455 .42941 .50174 .44164 .49785 .43452 .49064 Metetra
0 0 1 r
.43452 .49064 .44164 .49785 .45393 .49395 .44685 .4867 Metetra
0 0 1 r
.44685 .4867 .45393 .49395 .46627 .49003 .45923 .48275 Metetra
0 0 1 r
.45923 .48275 .46627 .49003 .47867 .48609 .47166 .47878 Metetra
0 0 1 r
.47166 .47878 .47867 .48609 .49113 .48214 .48415 .47479 Metetra
0 0 1 r
.48415 .47479 .49113 .48214 .50364 .47817 .4967 .47078 Metetra
0 0 1 r
.4967 .47078 .50364 .47817 .51621 .47418 .50931 .46676 Metetra
0 0 1 r
.50931 .46676 .51621 .47418 .52884 .47017 .52198 .46272 Metetra
0 0 1 r
.52198 .46272 .52884 .47017 .54153 .46614 .5347 .45865 Metetra
0 0 1 r
.5347 .45865 .54153 .46614 .55427 .46209 .54748 .45457 Metetra
0 0 1 r
.54748 .45457 .55427 .46209 .56707 .45803 .56033 .45047 Metetra
0 0 1 r
.56033 .45047 .56707 .45803 .57994 .45394 .57323 .44635 Metetra
0 0 1 r
.57323 .44635 .57994 .45394 .59286 .44984 .58619 .44221 Metetra
0 0 1 r
.58619 .44221 .59286 .44984 .60584 .44572 .59922 .43805 Metetra
0 0 1 r
.59922 .43805 .60584 .44572 .61889 .44157 .6123 .43388 Metetra
0 0 1 r
.6123 .43388 .61889 .44157 .63199 .43741 .62545 .42968 Metetra
0 0 1 r
.62545 .42968 .63199 .43741 .64516 .43323 .63866 .42546 Metetra
0 0 1 r
.63866 .42546 .64516 .43323 .65839 .42903 .65193 .42123 Metetra
0 0 1 r
.65193 .42123 .65839 .42903 .67168 .42481 .66526 .41697 Metetra
0 0 1 r
.66526 .41697 .67168 .42481 .68503 .42057 .67866 .41269 Metetra
0 0 1 r
.67866 .41269 .68503 .42057 .69845 .41631 .69212 .40839 Metetra
0 0 1 r
.69212 .40839 .69845 .41631 .71193 .41203 .70564 .40407 Metetra
0 0 1 r
.70564 .40407 .71193 .41203 .72548 .40773 .71923 .39974 Metetra
0 0 1 r
.71923 .39974 .72548 .40773 .73909 .40341 .73289 .39538 Metetra
0 0 1 r
.73289 .39538 .73909 .40341 .75276 .39907 .74661 .391 Metetra
0 0 1 r
.74661 .391 .75276 .39907 .7665 .3947 .7604 .38659 Metetra
0 0 1 r
.7604 .38659 .7665 .3947 .78031 .39032 .77425 .38217 Metetra
0 0 1 r
.77425 .38217 .78031 .39032 .79418 .38591 .78817 .37773 Metetra
0 0 1 r
.78817 .37773 .79418 .38591 .80812 .38149 .80216 .37326 Metetra
0 0 1 r
.80216 .37326 .80812 .38149 .82213 .37704 .81622 .36877 Metetra
0 0 1 r
.81622 .36877 .82213 .37704 .83621 .37257 .83034 .36426 Metetra
0 0 1 r
.83034 .36426 .83621 .37257 .85035 .36808 .84454 .35973 Metetra
0 0 1 r
.84454 .35973 .85035 .36808 .86456 .36357 .8588 .35518 Metetra
0 0 1 r
.22557 .54814 .2333 .55488 .24472 .55124 .23702 .54446 Metetra
0 0 1 r
.23702 .54446 .24472 .55124 .25619 .54757 .24852 .54077 Metetra
0 0 1 r
.24852 .54077 .25619 .54757 .26771 .54389 .26007 .53706 Metetra
0 0 1 r
.26007 .53706 .26771 .54389 .27929 .5402 .27168 .53333 Metetra
0 0 1 r
.27168 .53333 .27929 .5402 .29091 .53649 .28333 .52959 Metetra
0 0 1 r
.28333 .52959 .29091 .53649 .30259 .53276 .29504 .52583 Metetra
0 0 1 r
.29504 .52583 .30259 .53276 .31431 .52902 .3068 .52206 Metetra
0 0 1 r
.3068 .52206 .31431 .52902 .32609 .52525 .31861 .51827 Metetra
0 0 1 r
.31861 .51827 .32609 .52525 .33793 .52148 .33048 .51446 Metetra
0 0 1 r
.33048 .51446 .33793 .52148 .34981 .51768 .34239 .51063 Metetra
0 0 1 r
.34239 .51063 .34981 .51768 .36175 .51387 .35437 .50679 Metetra
0 0 1 r
.35437 .50679 .36175 .51387 .37374 .51004 .36639 .50293 Metetra
0 0 1 r
.36639 .50293 .37374 .51004 .38579 .5062 .37847 .49905 Metetra
0 0 1 r
.37847 .49905 .38579 .5062 .39789 .50233 .39061 .49515 Metetra
0 0 1 r
.39061 .49515 .39789 .50233 .41005 .49845 .4028 .49124 Metetra
0 0 1 r
.4028 .49124 .41005 .49845 .42226 .49455 .41504 .48731 Metetra
0 0 1 r
.41504 .48731 .42226 .49455 .43452 .49064 .42734 .48336 Metetra
0 0 1 r
.42734 .48336 .43452 .49064 .44685 .4867 .4397 .47939 Metetra
0 0 1 r
.4397 .47939 .44685 .4867 .45923 .48275 .45212 .47541 Metetra
0 0 1 r
.45212 .47541 .45923 .48275 .47166 .47878 .46459 .4714 Metetra
0 0 1 r
.46459 .4714 .47166 .47878 .48415 .47479 .47712 .46738 Metetra
0 0 1 r
.47712 .46738 .48415 .47479 .4967 .47078 .4897 .46334 Metetra
0 0 1 r
.4897 .46334 .4967 .47078 .50931 .46676 .50235 .45928 Metetra
0 0 1 r
.50235 .45928 .50931 .46676 .52198 .46272 .51505 .4552 Metetra
0 0 1 r
.51505 .4552 .52198 .46272 .5347 .45865 .52782 .4511 Metetra
0 0 1 r
.52782 .4511 .5347 .45865 .54748 .45457 .54064 .44699 Metetra
0 0 1 r
.54064 .44699 .54748 .45457 .56033 .45047 .55352 .44285 Metetra
0 0 1 r
.55352 .44285 .56033 .45047 .57323 .44635 .56646 .4387 Metetra
0 0 1 r
.56646 .4387 .57323 .44635 .58619 .44221 .57947 .43452 Metetra
0 0 1 r
.57947 .43452 .58619 .44221 .59922 .43805 .59253 .43033 Metetra
0 0 1 r
.59253 .43033 .59922 .43805 .6123 .43388 .60566 .42611 Metetra
0 0 1 r
.60566 .42611 .6123 .43388 .62545 .42968 .61885 .42188 Metetra
0 0 1 r
.61885 .42188 .62545 .42968 .63866 .42546 .6321 .41762 Metetra
0 0 1 r
.6321 .41762 .63866 .42546 .65193 .42123 .64541 .41335 Metetra
0 0 1 r
.64541 .41335 .65193 .42123 .66526 .41697 .65879 .40906 Metetra
0 0 1 r
.65879 .40906 .66526 .41697 .67866 .41269 .67223 .40474 Metetra
0 0 1 r
.67223 .40474 .67866 .41269 .69212 .40839 .68573 .4004 Metetra
0 0 1 r
.68573 .4004 .69212 .40839 .70564 .40407 .6993 .39605 Metetra
0 0 1 r
.6993 .39605 .70564 .40407 .71923 .39974 .71294 .39167 Metetra
0 0 1 r
.71294 .39167 .71923 .39974 .73289 .39538 .72664 .38727 Metetra
0 0 1 r
.72664 .38727 .73289 .39538 .74661 .391 .74041 .38285 Metetra
0 0 1 r
.74041 .38285 .74661 .391 .7604 .38659 .75424 .37841 Metetra
0 0 1 r
.75424 .37841 .7604 .38659 .77425 .38217 .76814 .37395 Metetra
0 0 1 r
.76814 .37395 .77425 .38217 .78817 .37773 .78211 .36946 Metetra
0 0 1 r
.78211 .36946 .78817 .37773 .80216 .37326 .79614 .36496 Metetra
0 0 1 r
.79614 .36496 .80216 .37326 .81622 .36877 .81025 .36043 Metetra
0 0 1 r
.81025 .36043 .81622 .36877 .83034 .36426 .82442 .35588 Metetra
0 0 1 r
.82442 .35588 .83034 .36426 .84454 .35973 .83867 .35131 Metetra
0 0 1 r
.83867 .35131 .84454 .35973 .8588 .35518 .85298 .34671 Metetra
0 0 1 r
.21778 .54134 .22557 .54814 .23702 .54446 .22926 .53763 Metetra
0 0 1 r
.22926 .53763 .23702 .54446 .24852 .54077 .24079 .53391 Metetra
0 0 1 r
.24079 .53391 .24852 .54077 .26007 .53706 .25237 .53017 Metetra
0 0 1 r
.25237 .53017 .26007 .53706 .27168 .53333 .26401 .52641 Metetra
0 0 1 r
.26401 .52641 .27168 .53333 .28333 .52959 .27569 .52264 Metetra
0 0 1 r
.27569 .52264 .28333 .52959 .29504 .52583 .28743 .51885 Metetra
0 0 1 r
.28743 .51885 .29504 .52583 .3068 .52206 .29922 .51504 Metetra
0 0 1 r
.29922 .51504 .3068 .52206 .31861 .51827 .31107 .51122 Metetra
0 0 1 r
.31107 .51122 .31861 .51827 .33048 .51446 .32296 .50738 Metetra
0 0 1 r
.32296 .50738 .33048 .51446 .34239 .51063 .33491 .50352 Metetra
0 0 1 r
.33491 .50352 .34239 .51063 .35437 .50679 .34692 .49965 Metetra
0 0 1 r
.34692 .49965 .35437 .50679 .36639 .50293 .35898 .49575 Metetra
0 0 1 r
.35898 .49575 .36639 .50293 .37847 .49905 .37109 .49184 Metetra
0 0 1 r
.37109 .49184 .37847 .49905 .39061 .49515 .38326 .48791 Metetra
0 0 1 r
.38326 .48791 .39061 .49515 .4028 .49124 .39549 .48397 Metetra
0 0 1 r
.39549 .48397 .4028 .49124 .41504 .48731 .40777 .48 Metetra
0 0 1 r
.40777 .48 .41504 .48731 .42734 .48336 .4201 .47602 Metetra
0 0 1 r
.4201 .47602 .42734 .48336 .4397 .47939 .4325 .47202 Metetra
0 0 1 r
.4325 .47202 .4397 .47939 .45212 .47541 .44495 .468 Metetra
0 0 1 r
.44495 .468 .45212 .47541 .46459 .4714 .45746 .46396 Metetra
0 0 1 r
.45746 .46396 .46459 .4714 .47712 .46738 .47002 .4599 Metetra
0 0 1 r
.47002 .4599 .47712 .46738 .4897 .46334 .48265 .45583 Metetra
0 0 1 r
.48265 .45583 .4897 .46334 .50235 .45928 .49533 .45173 Metetra
0 0 1 r
.49533 .45173 .50235 .45928 .51505 .4552 .50807 .44762 Metetra
0 0 1 r
.50807 .44762 .51505 .4552 .52782 .4511 .52087 .44349 Metetra
0 0 1 r
.52087 .44349 .52782 .4511 .54064 .44699 .53374 .43934 Metetra
0 0 1 r
.53374 .43934 .54064 .44699 .55352 .44285 .54666 .43516 Metetra
0 0 1 r
.54666 .43516 .55352 .44285 .56646 .4387 .55964 .43097 Metetra
0 0 1 r
.55964 .43097 .56646 .4387 .57947 .43452 .57268 .42676 Metetra
0 0 1 r
.57268 .42676 .57947 .43452 .59253 .43033 .58579 .42253 Metetra
0 0 1 r
.58579 .42253 .59253 .43033 .60566 .42611 .59896 .41828 Metetra
0 0 1 r
.59896 .41828 .60566 .42611 .61885 .42188 .61219 .41401 Metetra
0 0 1 r
.61219 .41401 .61885 .42188 .6321 .41762 .62548 .40972 Metetra
0 0 1 r
.62548 .40972 .6321 .41762 .64541 .41335 .63884 .40541 Metetra
0 0 1 r
.63884 .40541 .64541 .41335 .65879 .40906 .65226 .40107 Metetra
0 0 1 r
.65226 .40107 .65879 .40906 .67223 .40474 .66574 .39672 Metetra
0 0 1 r
.66574 .39672 .67223 .40474 .68573 .4004 .67929 .39235 Metetra
0 0 1 r
.67929 .39235 .68573 .4004 .6993 .39605 .69291 .38795 Metetra
0 0 1 r
.69291 .38795 .6993 .39605 .71294 .39167 .70659 .38353 Metetra
0 0 1 r
.70659 .38353 .71294 .39167 .72664 .38727 .72033 .3791 Metetra
0 0 1 r
.72033 .3791 .72664 .38727 .74041 .38285 .73415 .37464 Metetra
0 0 1 r
.73415 .37464 .74041 .38285 .75424 .37841 .74803 .37016 Metetra
0 0 1 r
.74803 .37016 .75424 .37841 .76814 .37395 .76197 .36565 Metetra
0 0 1 r
.76197 .36565 .76814 .37395 .78211 .36946 .77599 .36113 Metetra
0 0 1 r
.77599 .36113 .78211 .36946 .79614 .36496 .79008 .35658 Metetra
0 0 1 r
.79008 .35658 .79614 .36496 .81025 .36043 .80423 .35201 Metetra
0 0 1 r
.80423 .35201 .81025 .36043 .82442 .35588 .81845 .34742 Metetra
0 0 1 r
.81845 .34742 .82442 .35588 .83867 .35131 .83275 .34281 Metetra
0 0 1 r
.83275 .34281 .83867 .35131 .85298 .34671 .84711 .33817 Metetra
0 0 1 r
.20992 .53448 .21778 .54134 .22926 .53763 .22143 .53075 Metetra
0 0 1 r
.22143 .53075 .22926 .53763 .24079 .53391 .23299 .52699 Metetra
0 0 1 r
.23299 .52699 .24079 .53391 .25237 .53017 .24461 .52322 Metetra
0 0 1 r
.24461 .52322 .25237 .53017 .26401 .52641 .25627 .51944 Metetra
0 0 1 r
.25627 .51944 .26401 .52641 .27569 .52264 .26799 .51563 Metetra
0 0 1 r
.26799 .51563 .27569 .52264 .28743 .51885 .27976 .51181 Metetra
0 0 1 r
.27976 .51181 .28743 .51885 .29922 .51504 .29158 .50797 Metetra
0 0 1 r
.29158 .50797 .29922 .51504 .31107 .51122 .30346 .50412 Metetra
0 0 1 r
.30346 .50412 .31107 .51122 .32296 .50738 .31539 .50024 Metetra
0 0 1 r
.31539 .50024 .32296 .50738 .33491 .50352 .32737 .49635 Metetra
0 0 1 r
.32737 .49635 .33491 .50352 .34692 .49965 .33941 .49245 Metetra
0 0 1 r
.33941 .49245 .34692 .49965 .35898 .49575 .3515 .48852 Metetra
0 0 1 r
.3515 .48852 .35898 .49575 .37109 .49184 .36365 .48458 Metetra
0 0 1 r
.36365 .48458 .37109 .49184 .38326 .48791 .37585 .48061 Metetra
0 0 1 r
.37585 .48061 .38326 .48791 .39549 .48397 .38811 .47663 Metetra
0 0 1 r
.38811 .47663 .39549 .48397 .40777 .48 .40043 .47264 Metetra
0 0 1 r
.40043 .47264 .40777 .48 .4201 .47602 .4128 .46862 Metetra
0 0 1 r
.4128 .46862 .4201 .47602 .4325 .47202 .42523 .46458 Metetra
0 0 1 r
.42523 .46458 .4325 .47202 .44495 .468 .43772 .46053 Metetra
0 0 1 r
.43772 .46053 .44495 .468 .45746 .46396 .45026 .45646 Metetra
0 0 1 r
.45026 .45646 .45746 .46396 .47002 .4599 .46287 .45237 Metetra
0 0 1 r
.46287 .45237 .47002 .4599 .48265 .45583 .47553 .44826 Metetra
0 0 1 r
.47553 .44826 .48265 .45583 .49533 .45173 .48825 .44413 Metetra
0 0 1 r
.48825 .44413 .49533 .45173 .50807 .44762 .50103 .43998 Metetra
0 0 1 r
.50103 .43998 .50807 .44762 .52087 .44349 .51387 .43581 Metetra
0 0 1 r
.51387 .43581 .52087 .44349 .53374 .43934 .52677 .43162 Metetra
0 0 1 r
.52677 .43162 .53374 .43934 .54666 .43516 .53973 .42741 Metetra
0 0 1 r
.53973 .42741 .54666 .43516 .55964 .43097 .55276 .42318 Metetra
0 0 1 r
.55276 .42318 .55964 .43097 .57268 .42676 .56584 .41894 Metetra
0 0 1 r
.56584 .41894 .57268 .42676 .58579 .42253 .57899 .41467 Metetra
0 0 1 r
.57899 .41467 .58579 .42253 .59896 .41828 .5922 .41038 Metetra
0 0 1 r
.5922 .41038 .59896 .41828 .61219 .41401 .60547 .40607 Metetra
0 0 1 r
.60547 .40607 .61219 .41401 .62548 .40972 .6188 .40174 Metetra
0 0 1 r
.6188 .40174 .62548 .40972 .63884 .40541 .6322 .39739 Metetra
0 0 1 r
.6322 .39739 .63884 .40541 .65226 .40107 .64567 .39302 Metetra
0 0 1 r
.64567 .39302 .65226 .40107 .66574 .39672 .6592 .38863 Metetra
0 0 1 r
.6592 .38863 .66574 .39672 .67929 .39235 .67279 .38421 Metetra
0 0 1 r
.67279 .38421 .67929 .39235 .69291 .38795 .68645 .37978 Metetra
0 0 1 r
.68645 .37978 .69291 .38795 .70659 .38353 .70018 .37532 Metetra
0 0 1 r
.70018 .37532 .70659 .38353 .72033 .3791 .71397 .37085 Metetra
0 0 1 r
.71397 .37085 .72033 .3791 .73415 .37464 .72783 .36635 Metetra
0 0 1 r
.72783 .36635 .73415 .37464 .74803 .37016 .74176 .36183 Metetra
0 0 1 r
.74176 .36183 .74803 .37016 .76197 .36565 .75575 .35728 Metetra
0 0 1 r
.75575 .35728 .76197 .36565 .77599 .36113 .76982 .35272 Metetra
0 0 1 r
.76982 .35272 .77599 .36113 .79008 .35658 .78395 .34813 Metetra
0 0 1 r
.78395 .34813 .79008 .35658 .80423 .35201 .79815 .34352 Metetra
0 0 1 r
.79815 .34352 .80423 .35201 .81845 .34742 .81243 .33888 Metetra
0 0 1 r
.81243 .33888 .81845 .34742 .83275 .34281 .82677 .33423 Metetra
0 0 1 r
.82677 .33423 .83275 .34281 .84711 .33817 .84119 .32955 Metetra
0 0 1 r
.202 .52757 .20992 .53448 .22143 .53075 .21354 .5238 Metetra
0 0 1 r
.21354 .5238 .22143 .53075 .23299 .52699 .22514 .52002 Metetra
0 0 1 r
.22514 .52002 .23299 .52699 .24461 .52322 .23678 .51622 Metetra
0 0 1 r
.23678 .51622 .24461 .52322 .25627 .51944 .24847 .5124 Metetra
0 0 1 r
.24847 .5124 .25627 .51944 .26799 .51563 .26022 .50856 Metetra
0 0 1 r
.26022 .50856 .26799 .51563 .27976 .51181 .27202 .50471 Metetra
0 0 1 r
.27202 .50471 .27976 .51181 .29158 .50797 .28388 .50084 Metetra
0 0 1 r
.28388 .50084 .29158 .50797 .30346 .50412 .29579 .49695 Metetra
0 0 1 r
.29579 .49695 .30346 .50412 .31539 .50024 .30775 .49305 Metetra
0 0 1 r
.30775 .49305 .31539 .50024 .32737 .49635 .31977 .48912 Metetra
0 0 1 r
.31977 .48912 .32737 .49635 .33941 .49245 .33184 .48518 Metetra
0 0 1 r
.33184 .48518 .33941 .49245 .3515 .48852 .34396 .48122 Metetra
0 0 1 r
.34396 .48122 .3515 .48852 .36365 .48458 .35615 .47725 Metetra
0 0 1 r
.35615 .47725 .36365 .48458 .37585 .48061 .36838 .47325 Metetra
0 0 1 r
.36838 .47325 .37585 .48061 .38811 .47663 .38068 .46924 Metetra
0 0 1 r
.38068 .46924 .38811 .47663 .40043 .47264 .39303 .46521 Metetra
0 0 1 r
.39303 .46521 .40043 .47264 .4128 .46862 .40544 .46115 Metetra
0 0 1 r
.40544 .46115 .4128 .46862 .42523 .46458 .4179 .45709 Metetra
0 0 1 r
.4179 .45709 .42523 .46458 .43772 .46053 .43043 .453 Metetra
0 0 1 r
.43043 .453 .43772 .46053 .45026 .45646 .44301 .44889 Metetra
0 0 1 r
.44301 .44889 .45026 .45646 .46287 .45237 .45565 .44476 Metetra
0 0 1 r
.45565 .44476 .46287 .45237 .47553 .44826 .46835 .44062 Metetra
0 0 1 r
.46835 .44062 .47553 .44826 .48825 .44413 .48111 .43645 Metetra
0 0 1 r
.48111 .43645 .48825 .44413 .50103 .43998 .49393 .43226 Metetra
0 0 1 r
.49393 .43226 .50103 .43998 .51387 .43581 .50681 .42806 Metetra
0 0 1 r
.50681 .42806 .51387 .43581 .52677 .43162 .51975 .42384 Metetra
0 0 1 r
.51975 .42384 .52677 .43162 .53973 .42741 .53275 .41959 Metetra
0 0 1 r
.53275 .41959 .53973 .42741 .55276 .42318 .54581 .41533 Metetra
0 0 1 r
.54581 .41533 .55276 .42318 .56584 .41894 .55894 .41104 Metetra
0 0 1 r
.55894 .41104 .56584 .41894 .57899 .41467 .57213 .40673 Metetra
0 0 1 r
.57213 .40673 .57899 .41467 .5922 .41038 .58538 .40241 Metetra
0 0 1 r
.58538 .40241 .5922 .41038 .60547 .40607 .59869 .39806 Metetra
0 0 1 r
.59869 .39806 .60547 .40607 .6188 .40174 .61207 .39369 Metetra
0 0 1 r
.61207 .39369 .6188 .40174 .6322 .39739 .62551 .38931 Metetra
0 0 1 r
.62551 .38931 .6322 .39739 .64567 .39302 .63902 .3849 Metetra
0 0 1 r
.63902 .3849 .64567 .39302 .6592 .38863 .65259 .38046 Metetra
0 0 1 r
.65259 .38046 .6592 .38863 .67279 .38421 .66623 .37601 Metetra
0 0 1 r
.66623 .37601 .67279 .38421 .68645 .37978 .67994 .37154 Metetra
0 0 1 r
.67994 .37154 .68645 .37978 .70018 .37532 .69371 .36704 Metetra
0 0 1 r
.69371 .36704 .70018 .37532 .71397 .37085 .70755 .36252 Metetra
0 0 1 r
.70755 .36252 .71397 .37085 .72783 .36635 .72146 .35798 Metetra
0 0 1 r
.72146 .35798 .72783 .36635 .74176 .36183 .73543 .35342 Metetra
0 0 1 r
.73543 .35342 .74176 .36183 .75575 .35728 .74947 .34884 Metetra
0 0 1 r
.74947 .34884 .75575 .35728 .76982 .35272 .76359 .34423 Metetra
0 0 1 r
.76359 .34423 .76982 .35272 .78395 .34813 .77777 .3396 Metetra
0 0 1 r
.77777 .3396 .78395 .34813 .79815 .34352 .79202 .33494 Metetra
0 0 1 r
.79202 .33494 .79815 .34352 .81243 .33888 .80635 .33027 Metetra
0 0 1 r
.80635 .33027 .81243 .33888 .82677 .33423 .82074 .32557 Metetra
0 0 1 r
.82074 .32557 .82677 .33423 .84119 .32955 .83521 .32084 Metetra
0 0 1 r
.19402 .5206 .202 .52757 .21354 .5238 .20559 .5168 Metetra
0 0 1 r
.20559 .5168 .21354 .5238 .22514 .52002 .21721 .51299 Metetra
0 0 1 r
.21721 .51299 .22514 .52002 .23678 .51622 .22888 .50916 Metetra
0 0 1 r
.22888 .50916 .23678 .51622 .24847 .5124 .24061 .50531 Metetra
0 0 1 r
.24061 .50531 .24847 .5124 .26022 .50856 .25239 .50144 Metetra
0 0 1 r
.25239 .50144 .26022 .50856 .27202 .50471 .26422 .49755 Metetra
0 0 1 r
.26422 .49755 .27202 .50471 .28388 .50084 .27611 .49365 Metetra
0 0 1 r
.27611 .49365 .28388 .50084 .29579 .49695 .28805 .48973 Metetra
0 0 1 r
.28805 .48973 .29579 .49695 .30775 .49305 .30005 .48579 Metetra
0 0 1 r
.30005 .48579 .30775 .49305 .31977 .48912 .31209 .48183 Metetra
0 0 1 r
.31209 .48183 .31977 .48912 .33184 .48518 .3242 .47786 Metetra
0 0 1 r
.3242 .47786 .33184 .48518 .34396 .48122 .33636 .47387 Metetra
0 0 1 r
.33636 .47387 .34396 .48122 .35615 .47725 .34858 .46986 Metetra
0 0 1 r
.34858 .46986 .35615 .47725 .36838 .47325 .36085 .46583 Metetra
0 0 1 r
.36085 .46583 .36838 .47325 .38068 .46924 .37318 .46178 Metetra
0 0 1 r
.37318 .46178 .38068 .46924 .39303 .46521 .38557 .45771 Metetra
0 0 1 r
.38557 .45771 .39303 .46521 .40544 .46115 .39801 .45363 Metetra
0 0 1 r
.39801 .45363 .40544 .46115 .4179 .45709 .41051 .44952 Metetra
0 0 1 r
.41051 .44952 .4179 .45709 .43043 .453 .42307 .4454 Metetra
0 0 1 r
.42307 .4454 .43043 .453 .44301 .44889 .43569 .44125 Metetra
0 0 1 r
.43569 .44125 .44301 .44889 .45565 .44476 .44837 .43709 Metetra
0 0 1 r
.44837 .43709 .45565 .44476 .46835 .44062 .46111 .43291 Metetra
0 0 1 r
.46111 .43291 .46835 .44062 .48111 .43645 .4739 .42871 Metetra
0 0 1 r
.4739 .42871 .48111 .43645 .49393 .43226 .48676 .42449 Metetra
0 0 1 r
.48676 .42449 .49393 .43226 .50681 .42806 .49968 .42024 Metetra
0 0 1 r
.49968 .42024 .50681 .42806 .51975 .42384 .51266 .41598 Metetra
0 0 1 r
.51266 .41598 .51975 .42384 .53275 .41959 .5257 .4117 Metetra
0 0 1 r
.5257 .4117 .53275 .41959 .54581 .41533 .53881 .4074 Metetra
0 0 1 r
.53881 .4074 .54581 .41533 .55894 .41104 .55197 .40308 Metetra
0 0 1 r
.55197 .40308 .55894 .41104 .57213 .40673 .5652 .39873 Metetra
0 0 1 r
.5652 .39873 .57213 .40673 .58538 .40241 .5785 .39437 Metetra
0 0 1 r
.5785 .39437 .58538 .40241 .59869 .39806 .59185 .38998 Metetra
0 0 1 r
.59185 .38998 .59869 .39806 .61207 .39369 .60528 .38558 Metetra
0 0 1 r
.60528 .38558 .61207 .39369 .62551 .38931 .61876 .38115 Metetra
0 0 1 r
.61876 .38115 .62551 .38931 .63902 .3849 .63231 .3767 Metetra
0 0 1 r
.63231 .3767 .63902 .3849 .65259 .38046 .64593 .37223 Metetra
0 0 1 r
.64593 .37223 .65259 .38046 .66623 .37601 .65962 .36773 Metetra
0 0 1 r
.65962 .36773 .66623 .37601 .67994 .37154 .67337 .36322 Metetra
0 0 1 r
.67337 .36322 .67994 .37154 .69371 .36704 .68718 .35868 Metetra
0 0 1 r
.68718 .35868 .69371 .36704 .70755 .36252 .70107 .35412 Metetra
0 0 1 r
.70107 .35412 .70755 .36252 .72146 .35798 .71502 .34954 Metetra
0 0 1 r
.71502 .34954 .72146 .35798 .73543 .35342 .72905 .34494 Metetra
0 0 1 r
.72905 .34494 .73543 .35342 .74947 .34884 .74314 .34031 Metetra
0 0 1 r
.74314 .34031 .74947 .34884 .76359 .34423 .7573 .33566 Metetra
0 0 1 r
.7573 .33566 .76359 .34423 .77777 .3396 .77153 .33099 Metetra
0 0 1 r
.77153 .33099 .77777 .3396 .79202 .33494 .78584 .32629 Metetra
0 0 1 r
.78584 .32629 .79202 .33494 .80635 .33027 .80021 .32157 Metetra
0 0 1 r
.80021 .32157 .80635 .33027 .82074 .32557 .81466 .31683 Metetra
0 0 1 r
.81466 .31683 .82074 .32557 .83521 .32084 .82917 .31206 Metetra
0 0 1 r
.18597 .51358 .19402 .5206 .20559 .5168 .19757 .50975 Metetra
0 0 1 r
.19757 .50975 .20559 .5168 .21721 .51299 .20922 .5059 Metetra
0 0 1 r
.20922 .5059 .21721 .51299 .22888 .50916 .22092 .50203 Metetra
0 0 1 r
.22092 .50203 .22888 .50916 .24061 .50531 .23268 .49815 Metetra
0 0 1 r
.23268 .49815 .24061 .50531 .25239 .50144 .24449 .49425 Metetra
0 0 1 r
.24449 .49425 .25239 .50144 .26422 .49755 .25636 .49033 Metetra
0 0 1 r
.25636 .49033 .26422 .49755 .27611 .49365 .26828 .4864 Metetra
0 0 1 r
.26828 .4864 .27611 .49365 .28805 .48973 .28025 .48244 Metetra
0 0 1 r
.28025 .48244 .28805 .48973 .30005 .48579 .29228 .47847 Metetra
0 0 1 r
.29228 .47847 .30005 .48579 .31209 .48183 .30436 .47448 Metetra
0 0 1 r
.30436 .47448 .31209 .48183 .3242 .47786 .3165 .47048 Metetra
0 0 1 r
.3165 .47048 .3242 .47786 .33636 .47387 .32869 .46645 Metetra
0 0 1 r
.32869 .46645 .33636 .47387 .34858 .46986 .34094 .4624 Metetra
0 0 1 r
.34094 .4624 .34858 .46986 .36085 .46583 .35325 .45834 Metetra
0 0 1 r
.35325 .45834 .36085 .46583 .37318 .46178 .36562 .45426 Metetra
0 0 1 r
.36562 .45426 .37318 .46178 .38557 .45771 .37804 .45015 Metetra
0 0 1 r
.37804 .45015 .38557 .45771 .39801 .45363 .39052 .44603 Metetra
0 0 1 r
.39052 .44603 .39801 .45363 .41051 .44952 .40306 .44189 Metetra
0 0 1 r
.40306 .44189 .41051 .44952 .42307 .4454 .41565 .43773 Metetra
0 0 1 r
.41565 .43773 .42307 .4454 .43569 .44125 .42831 .43355 Metetra
0 0 1 r
.42831 .43355 .43569 .44125 .44837 .43709 .44103 .42936 Metetra
0 0 1 r
.44103 .42936 .44837 .43709 .46111 .43291 .4538 .42514 Metetra
0 0 1 r
.4538 .42514 .46111 .43291 .4739 .42871 .46664 .4209 Metetra
0 0 1 r
.46664 .4209 .4739 .42871 .48676 .42449 .47954 .41664 Metetra
0 0 1 r
.47954 .41664 .48676 .42449 .49968 .42024 .49249 .41236 Metetra
0 0 1 r
.49249 .41236 .49968 .42024 .51266 .41598 .50551 .40806 Metetra
0 0 1 r
.50551 .40806 .51266 .41598 .5257 .4117 .5186 .40374 Metetra
0 0 1 r
.5186 .40374 .5257 .4117 .53881 .4074 .53174 .3994 Metetra
0 0 1 r
.53174 .3994 .53881 .4074 .55197 .40308 .54495 .39504 Metetra
0 0 1 r
.54495 .39504 .55197 .40308 .5652 .39873 .55822 .39066 Metetra
0 0 1 r
.55822 .39066 .5652 .39873 .5785 .39437 .57156 .38625 Metetra
0 0 1 r
.57156 .38625 .5785 .39437 .59185 .38998 .58496 .38183 Metetra
0 0 1 r
.58496 .38183 .59185 .38998 .60528 .38558 .59842 .37738 Metetra
0 0 1 r
.59842 .37738 .60528 .38558 .61876 .38115 .61195 .37292 Metetra
0 0 1 r
.61195 .37292 .61876 .38115 .63231 .3767 .62555 .36843 Metetra
0 0 1 r
.62555 .36843 .63231 .3767 .64593 .37223 .63921 .36392 Metetra
0 0 1 r
.63921 .36392 .64593 .37223 .65962 .36773 .65294 .35938 Metetra
0 0 1 r
.65294 .35938 .65962 .36773 .67337 .36322 .66673 .35483 Metetra
0 0 1 r
.66673 .35483 .67337 .36322 .68718 .35868 .6806 .35025 Metetra
0 0 1 r
.6806 .35025 .68718 .35868 .70107 .35412 .69453 .34565 Metetra
0 0 1 r
.69453 .34565 .70107 .35412 .71502 .34954 .70853 .34102 Metetra
0 0 1 r
.70853 .34102 .71502 .34954 .72905 .34494 .7226 .33638 Metetra
0 0 1 r
.7226 .33638 .72905 .34494 .74314 .34031 .73674 .33171 Metetra
0 0 1 r
.73674 .33171 .74314 .34031 .7573 .33566 .75096 .32702 Metetra
0 0 1 r
.75096 .32702 .7573 .33566 .77153 .33099 .76524 .3223 Metetra
0 0 1 r
.76524 .3223 .77153 .33099 .78584 .32629 .77959 .31756 Metetra
0 0 1 r
.77959 .31756 .78584 .32629 .80021 .32157 .79402 .3128 Metetra
0 0 1 r
.79402 .3128 .80021 .32157 .81466 .31683 .80851 .30801 Metetra
0 0 1 r
.80851 .30801 .81466 .31683 .82917 .31206 .82308 .3032 Metetra
0 0 1 r
.17785 .50649 .18597 .51358 .19757 .50975 .18948 .50263 Metetra
0 0 1 r
.18948 .50263 .19757 .50975 .20922 .5059 .20116 .49875 Metetra
0 0 1 r
.20116 .49875 .20922 .5059 .22092 .50203 .2129 .49485 Metetra
0 0 1 r
.2129 .49485 .22092 .50203 .23268 .49815 .22469 .49094 Metetra
0 0 1 r
.22469 .49094 .23268 .49815 .24449 .49425 .23653 .487 Metetra
0 0 1 r
.23653 .487 .24449 .49425 .25636 .49033 .24843 .48305 Metetra
0 0 1 r
.24843 .48305 .25636 .49033 .26828 .4864 .26038 .47909 Metetra
0 0 1 r
.26038 .47909 .26828 .4864 .28025 .48244 .27238 .4751 Metetra
0 0 1 r
.27238 .4751 .28025 .48244 .29228 .47847 .28444 .47109 Metetra
0 0 1 r
.28444 .47109 .29228 .47847 .30436 .47448 .29656 .46707 Metetra
0 0 1 r
.29656 .46707 .30436 .47448 .3165 .47048 .30873 .46303 Metetra
0 0 1 r
.30873 .46303 .3165 .47048 .32869 .46645 .32096 .45897 Metetra
0 0 1 r
.32096 .45897 .32869 .46645 .34094 .4624 .33324 .45489 Metetra
0 0 1 r
.33324 .45489 .34094 .4624 .35325 .45834 .34559 .45079 Metetra
0 0 1 r
.34559 .45079 .35325 .45834 .36562 .45426 .35799 .44667 Metetra
0 0 1 r
.35799 .44667 .36562 .45426 .37804 .45015 .37045 .44253 Metetra
0 0 1 r
.37045 .44253 .37804 .45015 .39052 .44603 .38296 .43838 Metetra
0 0 1 r
.38296 .43838 .39052 .44603 .40306 .44189 .39554 .4342 Metetra
0 0 1 r
.39554 .4342 .40306 .44189 .41565 .43773 .40817 .43 Metetra
0 0 1 r
.40817 .43 .41565 .43773 .42831 .43355 .42086 .42579 Metetra
0 0 1 r
.42086 .42579 .42831 .43355 .44103 .42936 .43362 .42155 Metetra
0 0 1 r
.43362 .42155 .44103 .42936 .4538 .42514 .44643 .4173 Metetra
0 0 1 r
.44643 .4173 .4538 .42514 .46664 .4209 .45931 .41302 Metetra
0 0 1 r
.45931 .41302 .46664 .4209 .47954 .41664 .47224 .40872 Metetra
0 0 1 r
.47224 .40872 .47954 .41664 .49249 .41236 .48524 .40441 Metetra
0 0 1 r
.48524 .40441 .49249 .41236 .50551 .40806 .4983 .40007 Metetra
0 0 1 r
.4983 .40007 .50551 .40806 .5186 .40374 .51143 .39571 Metetra
0 0 1 r
.51143 .39571 .5186 .40374 .53174 .3994 .52461 .39133 Metetra
0 0 1 r
.52461 .39133 .53174 .3994 .54495 .39504 .53786 .38693 Metetra
0 0 1 r
.53786 .38693 .54495 .39504 .55822 .39066 .55117 .38251 Metetra
0 0 1 r
.55117 .38251 .55822 .39066 .57156 .38625 .56455 .37807 Metetra
0 0 1 r
.56455 .37807 .57156 .38625 .58496 .38183 .578 .3736 Metetra
0 0 1 r
.578 .3736 .58496 .38183 .59842 .37738 .5915 .36912 Metetra
0 0 1 r
.5915 .36912 .59842 .37738 .61195 .37292 .60508 .36461 Metetra
0 0 1 r
.60508 .36461 .61195 .37292 .62555 .36843 .61872 .36008 Metetra
0 0 1 r
.61872 .36008 .62555 .36843 .63921 .36392 .63243 .35553 Metetra
0 0 1 r
.63243 .35553 .63921 .36392 .65294 .35938 .6462 .35095 Metetra
0 0 1 r
.6462 .35095 .65294 .35938 .66673 .35483 .66004 .34636 Metetra
0 0 1 r
.66004 .34636 .66673 .35483 .6806 .35025 .67395 .34174 Metetra
0 0 1 r
.67395 .34174 .6806 .35025 .69453 .34565 .68793 .33709 Metetra
0 0 1 r
.68793 .33709 .69453 .34565 .70853 .34102 .70198 .33243 Metetra
0 0 1 r
.70198 .33243 .70853 .34102 .7226 .33638 .7161 .32774 Metetra
0 0 1 r
.7161 .32774 .7226 .33638 .73674 .33171 .73029 .32303 Metetra
0 0 1 r
.73029 .32303 .73674 .33171 .75096 .32702 .74455 .31829 Metetra
0 0 1 r
.74455 .31829 .75096 .32702 .76524 .3223 .75888 .31353 Metetra
0 0 1 r
.75888 .31353 .76524 .3223 .77959 .31756 .77329 .30875 Metetra
0 0 1 r
.77329 .30875 .77959 .31756 .79402 .3128 .78776 .30394 Metetra
0 0 1 r
.78776 .30394 .79402 .3128 .80851 .30801 .80231 .29911 Metetra
0 0 1 r
.80231 .29911 .80851 .30801 .82308 .3032 .81694 .29425 Metetra
0 0 1 r
.16967 .49935 .17785 .50649 .18948 .50263 .18133 .49545 Metetra
0 0 1 r
.18133 .49545 .18948 .50263 .20116 .49875 .19304 .49154 Metetra
0 0 1 r
.19304 .49154 .20116 .49875 .2129 .49485 .2048 .48761 Metetra
0 0 1 r
.2048 .48761 .2129 .49485 .22469 .49094 .21662 .48366 Metetra
0 0 1 r
.21662 .48366 .22469 .49094 .23653 .487 .2285 .4797 Metetra
0 0 1 r
.2285 .4797 .23653 .487 .24843 .48305 .24043 .47571 Metetra
0 0 1 r
.24043 .47571 .24843 .48305 .26038 .47909 .25241 .47171 Metetra
0 0 1 r
.25241 .47171 .26038 .47909 .27238 .4751 .26445 .46769 Metetra
0 0 1 r
.26445 .46769 .27238 .4751 .28444 .47109 .27654 .46365 Metetra
0 0 1 r
.27654 .46365 .28444 .47109 .29656 .46707 .28869 .45959 Metetra
0 0 1 r
.28869 .45959 .29656 .46707 .30873 .46303 .3009 .45551 Metetra
0 0 1 r
.3009 .45551 .30873 .46303 .32096 .45897 .31316 .45142 Metetra
0 0 1 r
.31316 .45142 .32096 .45897 .33324 .45489 .32548 .4473 Metetra
0 0 1 r
.32548 .4473 .33324 .45489 .34559 .45079 .33786 .44317 Metetra
0 0 1 r
.33786 .44317 .34559 .45079 .35799 .44667 .35029 .43902 Metetra
0 0 1 r
.35029 .43902 .35799 .44667 .37045 .44253 .36279 .43484 Metetra
0 0 1 r
.36279 .43484 .37045 .44253 .38296 .43838 .37534 .43065 Metetra
0 0 1 r
.37534 .43065 .38296 .43838 .39554 .4342 .38795 .42644 Metetra
0 0 1 r
.38795 .42644 .39554 .4342 .40817 .43 .40062 .4222 Metetra
0 0 1 r
.40062 .4222 .40817 .43 .42086 .42579 .41335 .41795 Metetra
0 0 1 r
.41335 .41795 .42086 .42579 .43362 .42155 .42615 .41368 Metetra
0 0 1 r
.42615 .41368 .43362 .42155 .44643 .4173 .439 .40939 Metetra
0 0 1 r
.439 .40939 .44643 .4173 .45931 .41302 .45191 .40507 Metetra
0 0 1 r
.45191 .40507 .45931 .41302 .47224 .40872 .46489 .40074 Metetra
0 0 1 r
.46489 .40074 .47224 .40872 .48524 .40441 .47793 .39638 Metetra
0 0 1 r
.47793 .39638 .48524 .40441 .4983 .40007 .49103 .39201 Metetra
0 0 1 r
.49103 .39201 .4983 .40007 .51143 .39571 .50419 .38761 Metetra
0 0 1 r
.50419 .38761 .51143 .39571 .52461 .39133 .51742 .38319 Metetra
0 0 1 r
.51742 .38319 .52461 .39133 .53786 .38693 .53071 .37875 Metetra
0 0 1 r
.53071 .37875 .53786 .38693 .55117 .38251 .54407 .37429 Metetra
0 0 1 r
.54407 .37429 .55117 .38251 .56455 .37807 .55749 .36981 Metetra
0 0 1 r
.55749 .36981 .56455 .37807 .578 .3736 .57097 .36531 Metetra
0 0 1 r
.57097 .36531 .578 .3736 .5915 .36912 .58452 .36078 Metetra
0 0 1 r
.58452 .36078 .5915 .36912 .60508 .36461 .59814 .35623 Metetra
0 0 1 r
.59814 .35623 .60508 .36461 .61872 .36008 .61183 .35166 Metetra
0 0 1 r
.61183 .35166 .61872 .36008 .63243 .35553 .62558 .34707 Metetra
0 0 1 r
.62558 .34707 .63243 .35553 .6462 .35095 .6394 .34245 Metetra
0 0 1 r
.6394 .34245 .6462 .35095 .66004 .34636 .65329 .33781 Metetra
0 0 1 r
.65329 .33781 .66004 .34636 .67395 .34174 .66725 .33315 Metetra
0 0 1 r
.66725 .33315 .67395 .34174 .68793 .33709 .68128 .32846 Metetra
0 0 1 r
.68128 .32846 .68793 .33709 .70198 .33243 .69537 .32375 Metetra
0 0 1 r
.69537 .32375 .70198 .33243 .7161 .32774 .70954 .31902 Metetra
0 0 1 r
.70954 .31902 .7161 .32774 .73029 .32303 .72378 .31427 Metetra
0 0 1 r
.72378 .31427 .73029 .32303 .74455 .31829 .73809 .30949 Metetra
0 0 1 r
.73809 .30949 .74455 .31829 .75888 .31353 .75247 .30468 Metetra
0 0 1 r
.75247 .30468 .75888 .31353 .77329 .30875 .76693 .29985 Metetra
0 0 1 r
.76693 .29985 .77329 .30875 .78776 .30394 .78145 .295 Metetra
0 0 1 r
.78145 .295 .78776 .30394 .80231 .29911 .79606 .29012 Metetra
0 0 1 r
.79606 .29012 .80231 .29911 .81694 .29425 .81073 .28522 Metetra
0 0 1 r
.16141 .49214 .16967 .49935 .18133 .49545 .1731 .48822 Metetra
0 0 1 r
.1731 .48822 .18133 .49545 .19304 .49154 .18485 .48427 Metetra
0 0 1 r
.18485 .48427 .19304 .49154 .2048 .48761 .19664 .48031 Metetra
0 0 1 r
.19664 .48031 .2048 .48761 .21662 .48366 .20849 .47633 Metetra
0 0 1 r
.20849 .47633 .21662 .48366 .2285 .4797 .2204 .47233 Metetra
0 0 1 r
.2204 .47233 .2285 .4797 .24043 .47571 .23236 .46831 Metetra
0 0 1 r
.23236 .46831 .24043 .47571 .25241 .47171 .24437 .46427 Metetra
0 0 1 r
.24437 .46427 .25241 .47171 .26445 .46769 .25645 .46022 Metetra
0 0 1 r
.25645 .46022 .26445 .46769 .27654 .46365 .26857 .45614 Metetra
0 0 1 r
.26857 .45614 .27654 .46365 .28869 .45959 .28076 .45205 Metetra
0 0 1 r
.28076 .45205 .28869 .45959 .3009 .45551 .293 .44794 Metetra
0 0 1 r
.293 .44794 .3009 .45551 .31316 .45142 .30529 .44381 Metetra
0 0 1 r
.30529 .44381 .31316 .45142 .32548 .4473 .31765 .43966 Metetra
0 0 1 r
.31765 .43966 .32548 .4473 .33786 .44317 .33006 .43549 Metetra
0 0 1 r
.33006 .43549 .33786 .44317 .35029 .43902 .34253 .4313 Metetra
0 0 1 r
.34253 .4313 .35029 .43902 .36279 .43484 .35506 .42709 Metetra
0 0 1 r
.35506 .42709 .36279 .43484 .37534 .43065 .36765 .42286 Metetra
0 0 1 r
.36765 .42286 .37534 .43065 .38795 .42644 .3803 .41861 Metetra
0 0 1 r
.3803 .41861 .38795 .42644 .40062 .4222 .39301 .41434 Metetra
0 0 1 r
.39301 .41434 .40062 .4222 .41335 .41795 .40578 .41005 Metetra
0 0 1 r
.40578 .41005 .41335 .41795 .42615 .41368 .41861 .40574 Metetra
0 0 1 r
.41861 .40574 .42615 .41368 .439 .40939 .4315 .40141 Metetra
0 0 1 r
.4315 .40141 .439 .40939 .45191 .40507 .44445 .39706 Metetra
0 0 1 r
.44445 .39706 .45191 .40507 .46489 .40074 .45747 .39268 Metetra
0 0 1 r
.45747 .39268 .46489 .40074 .47793 .39638 .47055 .38829 Metetra
0 0 1 r
.47055 .38829 .47793 .39638 .49103 .39201 .48369 .38387 Metetra
0 0 1 r
.48369 .38387 .49103 .39201 .50419 .38761 .49689 .37944 Metetra
0 0 1 r
.49689 .37944 .50419 .38761 .51742 .38319 .51016 .37498 Metetra
0 0 1 r
.51016 .37498 .51742 .38319 .53071 .37875 .52349 .3705 Metetra
0 0 1 r
.52349 .3705 .53071 .37875 .54407 .37429 .53689 .366 Metetra
0 0 1 r
.53689 .366 .54407 .37429 .55749 .36981 .55036 .36148 Metetra
0 0 1 r
.55036 .36148 .55749 .36981 .57097 .36531 .56389 .35693 Metetra
0 0 1 r
.56389 .35693 .57097 .36531 .58452 .36078 .57748 .35236 Metetra
0 0 1 r
.57748 .35236 .58452 .36078 .59814 .35623 .59115 .34777 Metetra
0 0 1 r
.59115 .34777 .59814 .35623 .61183 .35166 .60488 .34316 Metetra
0 0 1 r
.60488 .34316 .61183 .35166 .62558 .34707 .61867 .33853 Metetra
0 0 1 r
.61867 .33853 .62558 .34707 .6394 .34245 .63254 .33387 Metetra
0 0 1 r
.63254 .33387 .6394 .34245 .65329 .33781 .64648 .32918 Metetra
0 0 1 r
.64648 .32918 .65329 .33781 .66725 .33315 .66048 .32448 Metetra
0 0 1 r
.66048 .32448 .66725 .33315 .68128 .32846 .67456 .31975 Metetra
0 0 1 r
.67456 .31975 .68128 .32846 .69537 .32375 .6887 .315 Metetra
0 0 1 r
.6887 .315 .69537 .32375 .70954 .31902 .70292 .31022 Metetra
0 0 1 r
.70292 .31022 .70954 .31902 .72378 .31427 .71721 .30542 Metetra
0 0 1 r
.71721 .30542 .72378 .31427 .73809 .30949 .73157 .3006 Metetra
0 0 1 r
.73157 .3006 .73809 .30949 .75247 .30468 .746 .29575 Metetra
0 0 1 r
.746 .29575 .75247 .30468 .76693 .29985 .76051 .29088 Metetra
0 0 1 r
.76051 .29088 .76693 .29985 .78145 .295 .77509 .28598 Metetra
0 0 1 r
.77509 .28598 .78145 .295 .79606 .29012 .78974 .28106 Metetra
0 0 1 r
.78974 .28106 .79606 .29012 .81073 .28522 .80447 .27611 Metetra
0 0 1 r
.15309 .48488 .16141 .49214 .1731 .48822 .16481 .48092 Metetra
0 0 1 r
.16481 .48092 .1731 .48822 .18485 .48427 .17658 .47694 Metetra
0 0 1 r
.17658 .47694 .18485 .48427 .19664 .48031 .18841 .47294 Metetra
0 0 1 r
.18841 .47294 .19664 .48031 .20849 .47633 .20029 .46893 Metetra
0 0 1 r
.20029 .46893 .20849 .47633 .2204 .47233 .21223 .46489 Metetra
0 0 1 r
.21223 .46489 .2204 .47233 .23236 .46831 .22422 .46084 Metetra
0 0 1 r
.22422 .46084 .23236 .46831 .24437 .46427 .23627 .45677 Metetra
0 0 1 r
.23627 .45677 .24437 .46427 .25645 .46022 .24838 .45268 Metetra
0 0 1 r
.24838 .45268 .25645 .46022 .26857 .45614 .26054 .44857 Metetra
0 0 1 r
.26054 .44857 .26857 .45614 .28076 .45205 .27275 .44444 Metetra
0 0 1 r
.27275 .44444 .28076 .45205 .293 .44794 .28503 .4403 Metetra
0 0 1 r
.28503 .4403 .293 .44794 .30529 .44381 .29736 .43613 Metetra
0 0 1 r
.29736 .43613 .30529 .44381 .31765 .43966 .30975 .43194 Metetra
0 0 1 r
.30975 .43194 .31765 .43966 .33006 .43549 .3222 .42774 Metetra
0 0 1 r
.3222 .42774 .33006 .43549 .34253 .4313 .3347 .42351 Metetra
0 0 1 r
.3347 .42351 .34253 .4313 .35506 .42709 .34727 .41926 Metetra
0 0 1 r
.34727 .41926 .35506 .42709 .36765 .42286 .3599 .415 Metetra
0 0 1 r
.3599 .415 .36765 .42286 .3803 .41861 .37258 .41071 Metetra
0 0 1 r
.37258 .41071 .3803 .41861 .39301 .41434 .38533 .4064 Metetra
0 0 1 r
.38533 .4064 .39301 .41434 .40578 .41005 .39813 .40207 Metetra
0 0 1 r
.39813 .40207 .40578 .41005 .41861 .40574 .411 .39773 Metetra
0 0 1 r
.411 .39773 .41861 .40574 .4315 .40141 .42393 .39336 Metetra
0 0 1 r
.42393 .39336 .4315 .40141 .44445 .39706 .43693 .38897 Metetra
0 0 1 r
.43693 .38897 .44445 .39706 .45747 .39268 .44998 .38456 Metetra
0 0 1 r
.44998 .38456 .45747 .39268 .47055 .38829 .4631 .38012 Metetra
0 0 1 r
.4631 .38012 .47055 .38829 .48369 .38387 .47628 .37567 Metetra
0 0 1 r
.47628 .37567 .48369 .38387 .49689 .37944 .48953 .37119 Metetra
0 0 1 r
.48953 .37119 .49689 .37944 .51016 .37498 .50284 .36669 Metetra
0 0 1 r
.50284 .36669 .51016 .37498 .52349 .3705 .51621 .36217 Metetra
0 0 1 r
.51621 .36217 .52349 .3705 .53689 .366 .52965 .35763 Metetra
0 0 1 r
.52965 .35763 .53689 .366 .55036 .36148 .54316 .35307 Metetra
0 0 1 r
.54316 .35307 .55036 .36148 .56389 .35693 .55674 .34848 Metetra
0 0 1 r
.55674 .34848 .56389 .35693 .57748 .35236 .57038 .34387 Metetra
0 0 1 r
.57038 .34387 .57748 .35236 .59115 .34777 .58408 .33924 Metetra
0 0 1 r
.58408 .33924 .59115 .34777 .60488 .34316 .59786 .33458 Metetra
0 0 1 r
.59786 .33458 .60488 .34316 .61867 .33853 .6117 .32991 Metetra
0 0 1 r
.6117 .32991 .61867 .33853 .63254 .33387 .62562 .32521 Metetra
0 0 1 r
.62562 .32521 .63254 .33387 .64648 .32918 .6396 .32048 Metetra
0 0 1 r
.6396 .32048 .64648 .32918 .66048 .32448 .65365 .31573 Metetra
0 0 1 r
.65365 .31573 .66048 .32448 .67456 .31975 .66777 .31096 Metetra
0 0 1 r
.66777 .31096 .67456 .31975 .6887 .315 .68197 .30616 Metetra
0 0 1 r
.68197 .30616 .6887 .315 .70292 .31022 .69623 .30134 Metetra
0 0 1 r
.69623 .30134 .70292 .31022 .71721 .30542 .71057 .2965 Metetra
0 0 1 r
.71057 .2965 .71721 .30542 .73157 .3006 .72498 .29163 Metetra
0 0 1 r
.72498 .29163 .73157 .3006 .746 .29575 .73947 .28673 Metetra
0 0 1 r
.73947 .28673 .746 .29575 .76051 .29088 .75403 .28181 Metetra
0 0 1 r
.75403 .28181 .76051 .29088 .77509 .28598 .76866 .27687 Metetra
0 0 1 r
.76866 .27687 .77509 .28598 .78974 .28106 .78336 .2719 Metetra
0 0 1 r
.78336 .2719 .78974 .28106 .80447 .27611 .79815 .2669 Metetra
0 0 1 r
.1447 .47755 .15309 .48488 .16481 .48092 .15645 .47356 Metetra
0 0 1 r
.15645 .47356 .16481 .48092 .17658 .47694 .16825 .46955 Metetra
0 0 1 r
.16825 .46955 .17658 .47694 .18841 .47294 .18011 .46552 Metetra
0 0 1 r
.18011 .46552 .18841 .47294 .20029 .46893 .19202 .46147 Metetra
0 0 1 r
.19202 .46147 .20029 .46893 .21223 .46489 .20399 .4574 Metetra
0 0 1 r
.20399 .4574 .21223 .46489 .22422 .46084 .21602 .45331 Metetra
0 0 1 r
.21602 .45331 .22422 .46084 .23627 .45677 .2281 .44921 Metetra
0 0 1 r
.2281 .44921 .23627 .45677 .24838 .45268 .24024 .44508 Metetra
0 0 1 r
.24024 .44508 .24838 .45268 .26054 .44857 .25243 .44094 Metetra
0 0 1 r
.25243 .44094 .26054 .44857 .27275 .44444 .26468 .43677 Metetra
0 0 1 r
.26468 .43677 .27275 .44444 .28503 .4403 .27699 .43259 Metetra
0 0 1 r
.27699 .43259 .28503 .4403 .29736 .43613 .28935 .42838 Metetra
0 0 1 r
.28935 .42838 .29736 .43613 .30975 .43194 .30178 .42416 Metetra
0 0 1 r
.30178 .42416 .30975 .43194 .3222 .42774 .31426 .41992 Metetra
0 0 1 r
.31426 .41992 .3222 .42774 .3347 .42351 .32681 .41565 Metetra
0 0 1 r
.32681 .41565 .3347 .42351 .34727 .41926 .33941 .41137 Metetra
0 0 1 r
.33941 .41137 .34727 .41926 .3599 .415 .35207 .40707 Metetra
0 0 1 r
.35207 .40707 .3599 .415 .37258 .41071 .36479 .40274 Metetra
0 0 1 r
.36479 .40274 .37258 .41071 .38533 .4064 .37758 .3984 Metetra
0 0 1 r
.37758 .3984 .38533 .4064 .39813 .40207 .39042 .39403 Metetra
0 0 1 r
.39042 .39403 .39813 .40207 .411 .39773 .40333 .38964 Metetra
0 0 1 r
.40333 .38964 .411 .39773 .42393 .39336 .4163 .38524 Metetra
0 0 1 r
.4163 .38524 .42393 .39336 .43693 .38897 .42933 .38081 Metetra
0 0 1 r
.42933 .38081 .43693 .38897 .44998 .38456 .44243 .37635 Metetra
0 0 1 r
.44243 .37635 .44998 .38456 .4631 .38012 .45559 .37188 Metetra
0 0 1 r
.45559 .37188 .4631 .38012 .47628 .37567 .46881 .36739 Metetra
0 0 1 r
.46881 .36739 .47628 .37567 .48953 .37119 .4821 .36287 Metetra
0 0 1 r
.4821 .36287 .48953 .37119 .50284 .36669 .49545 .35833 Metetra
0 0 1 r
.49545 .35833 .50284 .36669 .51621 .36217 .50887 .35377 Metetra
0 0 1 r
.50887 .35377 .51621 .36217 .52965 .35763 .52235 .34919 Metetra
0 0 1 r
.52235 .34919 .52965 .35763 .54316 .35307 .5359 .34458 Metetra
0 0 1 r
.5359 .34458 .54316 .35307 .55674 .34848 .54952 .33995 Metetra
0 0 1 r
.54952 .33995 .55674 .34848 .57038 .34387 .5632 .3353 Metetra
0 0 1 r
.5632 .3353 .57038 .34387 .58408 .33924 .57696 .33063 Metetra
0 0 1 r
.57696 .33063 .58408 .33924 .59786 .33458 .59078 .32593 Metetra
0 0 1 r
.59078 .32593 .59786 .33458 .6117 .32991 .60467 .32121 Metetra
0 0 1 r
.60467 .32121 .6117 .32991 .62562 .32521 .61863 .31646 Metetra
0 0 1 r
.61863 .31646 .62562 .32521 .6396 .32048 .63266 .3117 Metetra
0 0 1 r
.63266 .3117 .6396 .32048 .65365 .31573 .64676 .3069 Metetra
0 0 1 r
.64676 .3069 .65365 .31573 .66777 .31096 .66093 .30209 Metetra
0 0 1 r
.66093 .30209 .66777 .31096 .68197 .30616 .67517 .29724 Metetra
0 0 1 r
.67517 .29724 .68197 .30616 .69623 .30134 .68949 .29238 Metetra
0 0 1 r
.68949 .29238 .69623 .30134 .71057 .2965 .70388 .28749 Metetra
0 0 1 r
.70388 .28749 .71057 .2965 .72498 .29163 .71834 .28257 Metetra
0 0 1 r
.71834 .28257 .72498 .29163 .73947 .28673 .73287 .27763 Metetra
0 0 1 r
.73287 .27763 .73947 .28673 .75403 .28181 .74748 .27267 Metetra
0 0 1 r
.74748 .27267 .75403 .28181 .76866 .27687 .76217 .26767 Metetra
0 0 1 r
.76217 .26767 .76866 .27687 .78336 .2719 .77693 .26266 Metetra
0 0 1 r
.77693 .26266 .78336 .2719 .79815 .2669 .79176 .25762 Metetra
0 0 1 r
.13623 .47017 .1447 .47755 .15645 .47356 .14801 .46614 Metetra
0 0 1 r
.14801 .46614 .15645 .47356 .16825 .46955 .15985 .46209 Metetra
0 0 1 r
.15985 .46209 .16825 .46955 .18011 .46552 .17174 .45803 Metetra
0 0 1 r
.17174 .45803 .18011 .46552 .19202 .46147 .18368 .45394 Metetra
0 0 1 r
.18368 .45394 .19202 .46147 .20399 .4574 .19568 .44984 Metetra
0 0 1 r
.19568 .44984 .20399 .4574 .21602 .45331 .20774 .44572 Metetra
0 0 1 r
.20774 .44572 .21602 .45331 .2281 .44921 .21985 .44157 Metetra
0 0 1 r
.21985 .44157 .2281 .44921 .24024 .44508 .23202 .43741 Metetra
0 0 1 r
.23202 .43741 .24024 .44508 .25243 .44094 .24425 .43323 Metetra
0 0 1 r
.24425 .43323 .25243 .44094 .26468 .43677 .25654 .42903 Metetra
0 0 1 r
.25654 .42903 .26468 .43677 .27699 .43259 .26888 .42481 Metetra
0 0 1 r
.26888 .42481 .27699 .43259 .28935 .42838 .28128 .42057 Metetra
0 0 1 r
.28128 .42057 .28935 .42838 .30178 .42416 .29374 .41631 Metetra
0 0 1 r
.29374 .41631 .30178 .42416 .31426 .41992 .30626 .41203 Metetra
0 0 1 r
.30626 .41203 .31426 .41992 .32681 .41565 .31884 .40773 Metetra
0 0 1 r
.31884 .40773 .32681 .41565 .33941 .41137 .33148 .40341 Metetra
0 0 1 r
.33148 .40341 .33941 .41137 .35207 .40707 .34418 .39907 Metetra
0 0 1 r
.34418 .39907 .35207 .40707 .36479 .40274 .35694 .3947 Metetra
0 0 1 r
.35694 .3947 .36479 .40274 .37758 .3984 .36976 .39032 Metetra
0 0 1 r
.36976 .39032 .37758 .3984 .39042 .39403 .38264 .38591 Metetra
0 0 1 r
.38264 .38591 .39042 .39403 .40333 .38964 .39559 .38149 Metetra
0 0 1 r
.39559 .38149 .40333 .38964 .4163 .38524 .4086 .37704 Metetra
0 0 1 r
.4086 .37704 .4163 .38524 .42933 .38081 .42167 .37257 Metetra
0 0 1 r
.42167 .37257 .42933 .38081 .44243 .37635 .43481 .36808 Metetra
0 0 1 r
.43481 .36808 .44243 .37635 .45559 .37188 .44801 .36357 Metetra
0 0 1 r
.44801 .36357 .45559 .37188 .46881 .36739 .46127 .35903 Metetra
0 0 1 r
.46127 .35903 .46881 .36739 .4821 .36287 .4746 .35447 Metetra
0 0 1 r
.4746 .35447 .4821 .36287 .49545 .35833 .48799 .3499 Metetra
0 0 1 r
.48799 .3499 .49545 .35833 .50887 .35377 .50145 .34529 Metetra
0 0 1 r
.50145 .34529 .50887 .35377 .52235 .34919 .51498 .34067 Metetra
0 0 1 r
.51498 .34067 .52235 .34919 .5359 .34458 .52858 .33602 Metetra
0 0 1 r
.52858 .33602 .5359 .34458 .54952 .33995 .54224 .33135 Metetra
0 0 1 r
.54224 .33135 .54952 .33995 .5632 .3353 .55597 .32665 Metetra
0 0 1 r
.55597 .32665 .5632 .3353 .57696 .33063 .56976 .32194 Metetra
0 0 1 r
.56976 .32194 .57696 .33063 .59078 .32593 .58363 .3172 Metetra
0 0 1 r
.58363 .3172 .59078 .32593 .60467 .32121 .59757 .31243 Metetra
0 0 1 r
.59757 .31243 .60467 .32121 .61863 .31646 .61158 .30764 Metetra
0 0 1 r
.61158 .30764 .61863 .31646 .63266 .3117 .62565 .30283 Metetra
0 0 1 r
.62565 .30283 .63266 .3117 .64676 .3069 .6398 .29799 Metetra
0 0 1 r
.6398 .29799 .64676 .3069 .66093 .30209 .65402 .29313 Metetra
0 0 1 r
.65402 .29313 .66093 .30209 .67517 .29724 .66831 .28824 Metetra
0 0 1 r
.66831 .28824 .67517 .29724 .68949 .29238 .68268 .28333 Metetra
0 0 1 r
.68268 .28333 .68949 .29238 .70388 .28749 .69712 .27839 Metetra
0 0 1 r
.69712 .27839 .70388 .28749 .71834 .28257 .71163 .27343 Metetra
0 0 1 r
.71163 .27343 .71834 .28257 .73287 .27763 .72622 .26844 Metetra
0 0 1 r
.72622 .26844 .73287 .27763 .74748 .27267 .74088 .26343 Metetra
0 0 1 r
.74088 .26343 .74748 .27267 .76217 .26767 .75562 .25839 Metetra
0 0 1 r
.75562 .25839 .76217 .26767 .77693 .26266 .77043 .25333 Metetra
0 0 1 r
.77043 .25333 .77693 .26266 .79176 .25762 .78532 .24824 Metetra
0 0 1 r
.12769 .46272 .13623 .47017 .14801 .46614 .1395 .45865 Metetra
0 0 1 r
.1395 .45865 .14801 .46614 .15985 .46209 .15137 .45457 Metetra
0 0 1 r
.15137 .45457 .15985 .46209 .17174 .45803 .16329 .45047 Metetra
0 0 1 r
.16329 .45047 .17174 .45803 .18368 .45394 .17527 .44635 Metetra
0 0 1 r
.17527 .44635 .18368 .45394 .19568 .44984 .1873 .44221 Metetra
0 0 1 r
.1873 .44221 .19568 .44984 .20774 .44572 .19939 .43805 Metetra
0 0 1 r
.19939 .43805 .20774 .44572 .21985 .44157 .21154 .43388 Metetra
0 0 1 r
.21154 .43388 .21985 .44157 .23202 .43741 .22374 .42968 Metetra
0 0 1 r
.22374 .42968 .23202 .43741 .24425 .43323 .236 .42546 Metetra
0 0 1 r
.236 .42546 .24425 .43323 .25654 .42903 .24832 .42123 Metetra
0 0 1 r
.24832 .42123 .25654 .42903 .26888 .42481 .2607 .41697 Metetra
0 0 1 r
.2607 .41697 .26888 .42481 .28128 .42057 .27314 .41269 Metetra
0 0 1 r
.27314 .41269 .28128 .42057 .29374 .41631 .28563 .40839 Metetra
0 0 1 r
.28563 .40839 .29374 .41631 .30626 .41203 .29819 .40407 Metetra
0 0 1 r
.29819 .40407 .30626 .41203 .31884 .40773 .3108 .39974 Metetra
0 0 1 r
.3108 .39974 .31884 .40773 .33148 .40341 .32348 .39538 Metetra
0 0 1 r
.32348 .39538 .33148 .40341 .34418 .39907 .33621 .391 Metetra
0 0 1 r
.33621 .391 .34418 .39907 .35694 .3947 .34901 .38659 Metetra
0 0 1 r
.34901 .38659 .35694 .3947 .36976 .39032 .36187 .38217 Metetra
0 0 1 r
.36187 .38217 .36976 .39032 .38264 .38591 .3748 .37773 Metetra
0 0 1 r
.3748 .37773 .38264 .38591 .39559 .38149 .38778 .37326 Metetra
0 0 1 r
.38778 .37326 .39559 .38149 .4086 .37704 .40083 .36877 Metetra
0 0 1 r
.40083 .36877 .4086 .37704 .42167 .37257 .41394 .36426 Metetra
0 0 1 r
.41394 .36426 .42167 .37257 .43481 .36808 .42712 .35973 Metetra
0 0 1 r
.42712 .35973 .43481 .36808 .44801 .36357 .44036 .35518 Metetra
0 0 1 r
.44036 .35518 .44801 .36357 .46127 .35903 .45366 .3506 Metetra
0 0 1 r
.45366 .3506 .46127 .35903 .4746 .35447 .46703 .346 Metetra
0 0 1 r
.46703 .346 .4746 .35447 .48799 .3499 .48047 .34138 Metetra
0 0 1 r
.48047 .34138 .48799 .3499 .50145 .34529 .49397 .33674 Metetra
0 0 1 r
.49397 .33674 .50145 .34529 .51498 .34067 .50754 .33207 Metetra
0 0 1 r
.50754 .33207 .51498 .34067 .52858 .33602 .52118 .32738 Metetra
0 0 1 r
.52118 .32738 .52858 .33602 .54224 .33135 .53489 .32266 Metetra
0 0 1 r
.53489 .32266 .54224 .33135 .55597 .32665 .54866 .31793 Metetra
0 0 1 r
.54866 .31793 .55597 .32665 .56976 .32194 .56251 .31316 Metetra
0 0 1 r
.56251 .31316 .56976 .32194 .58363 .3172 .57642 .30838 Metetra
0 0 1 r
.57642 .30838 .58363 .3172 .59757 .31243 .5904 .30357 Metetra
0 0 1 r
.5904 .30357 .59757 .31243 .61158 .30764 .60446 .29874 Metetra
0 0 1 r
.60446 .29874 .61158 .30764 .62565 .30283 .61858 .29388 Metetra
0 0 1 r
.61858 .29388 .62565 .30283 .6398 .29799 .63278 .289 Metetra
0 0 1 r
.63278 .289 .6398 .29799 .65402 .29313 .64705 .28409 Metetra
0 0 1 r
.64705 .28409 .65402 .29313 .66831 .28824 .66139 .27915 Metetra
0 0 1 r
.66139 .27915 .66831 .28824 .68268 .28333 .6758 .2742 Metetra
0 0 1 r
.6758 .2742 .68268 .28333 .69712 .27839 .69029 .26921 Metetra
0 0 1 r
.69029 .26921 .69712 .27839 .71163 .27343 .70486 .2642 Metetra
0 0 1 r
.70486 .2642 .71163 .27343 .72622 .26844 .7195 .25917 Metetra
0 0 1 r
.7195 .25917 .72622 .26844 .74088 .26343 .73421 .25411 Metetra
0 0 1 r
.73421 .25411 .74088 .26343 .75562 .25839 .749 .24902 Metetra
0 0 1 r
.749 .24902 .75562 .25839 .77043 .25333 .76387 .24391 Metetra
0 0 1 r
.76387 .24391 .77043 .25333 .78532 .24824 .77881 .23877 Metetra
0 0 1 r
.11908 .4552 .12769 .46272 .1395 .45865 .13092 .4511 Metetra
0 0 1 r
.13092 .4511 .1395 .45865 .15137 .45457 .14282 .44699 Metetra
0 0 1 r
.14282 .44699 .15137 .45457 .16329 .45047 .15478 .44285 Metetra
0 0 1 r
.15478 .44285 .16329 .45047 .17527 .44635 .16678 .4387 Metetra
0 0 1 r
.16678 .4387 .17527 .44635 .1873 .44221 .17885 .43452 Metetra
0 0 1 r
.17885 .43452 .1873 .44221 .19939 .43805 .19097 .43033 Metetra
0 0 1 r
.19097 .43033 .19939 .43805 .21154 .43388 .20315 .42611 Metetra
0 0 1 r
.20315 .42611 .21154 .43388 .22374 .42968 .21539 .42188 Metetra
0 0 1 r
.21539 .42188 .22374 .42968 .236 .42546 .22768 .41762 Metetra
0 0 1 r
.22768 .41762 .236 .42546 .24832 .42123 .24004 .41335 Metetra
0 0 1 r
.24004 .41335 .24832 .42123 .2607 .41697 .25245 .40906 Metetra
0 0 1 r
.25245 .40906 .2607 .41697 .27314 .41269 .26492 .40474 Metetra
0 0 1 r
.26492 .40474 .27314 .41269 .28563 .40839 .27745 .4004 Metetra
0 0 1 r
.27745 .4004 .28563 .40839 .29819 .40407 .29004 .39605 Metetra
0 0 1 r
.29004 .39605 .29819 .40407 .3108 .39974 .30269 .39167 Metetra
0 0 1 r
.30269 .39167 .3108 .39974 .32348 .39538 .31541 .38727 Metetra
0 0 1 r
.31541 .38727 .32348 .39538 .33621 .391 .32818 .38285 Metetra
0 0 1 r
.32818 .38285 .33621 .391 .34901 .38659 .34102 .37841 Metetra
0 0 1 r
.34102 .37841 .34901 .38659 .36187 .38217 .35391 .37395 Metetra
0 0 1 r
.35391 .37395 .36187 .38217 .3748 .37773 .36688 .36946 Metetra
0 0 1 r
.36688 .36946 .3748 .37773 .38778 .37326 .3799 .36496 Metetra
0 0 1 r
.3799 .36496 .38778 .37326 .40083 .36877 .39299 .36043 Metetra
0 0 1 r
.39299 .36043 .40083 .36877 .41394 .36426 .40614 .35588 Metetra
0 0 1 r
.40614 .35588 .41394 .36426 .42712 .35973 .41936 .35131 Metetra
0 0 1 r
.41936 .35131 .42712 .35973 .44036 .35518 .43264 .34671 Metetra
0 0 1 r
.43264 .34671 .44036 .35518 .45366 .3506 .44598 .34209 Metetra
0 0 1 r
.44598 .34209 .45366 .3506 .46703 .346 .4594 .33745 Metetra
0 0 1 r
.4594 .33745 .46703 .346 .48047 .34138 .47288 .33279 Metetra
0 0 1 r
.47288 .33279 .48047 .34138 .49397 .33674 .48642 .3281 Metetra
0 0 1 r
.48642 .3281 .49397 .33674 .50754 .33207 .50004 .32339 Metetra
0 0 1 r
.50004 .32339 .50754 .33207 .52118 .32738 .51372 .31866 Metetra
0 0 1 r
.51372 .31866 .52118 .32738 .53489 .32266 .52747 .3139 Metetra
0 0 1 r
.52747 .3139 .53489 .32266 .54866 .31793 .54129 .30912 Metetra
0 0 1 r
.54129 .30912 .54866 .31793 .56251 .31316 .55518 .30431 Metetra
0 0 1 r
.55518 .30431 .56251 .31316 .57642 .30838 .56914 .29948 Metetra
0 0 1 r
.56914 .29948 .57642 .30838 .5904 .30357 .58317 .29463 Metetra
0 0 1 r
.58317 .29463 .5904 .30357 .60446 .29874 .59727 .28975 Metetra
0 0 1 r
.59727 .28975 .60446 .29874 .61858 .29388 .61144 .28484 Metetra
0 0 1 r
.61144 .28484 .61858 .29388 .63278 .289 .62569 .27992 Metetra
0 0 1 r
.62569 .27992 .63278 .289 .64705 .28409 .64001 .27496 Metetra
0 0 1 r
.64001 .27496 .64705 .28409 .66139 .27915 .6544 .26998 Metetra
0 0 1 r
.6544 .26998 .66139 .27915 .6758 .2742 .66887 .26498 Metetra
0 0 1 r
.66887 .26498 .6758 .2742 .69029 .26921 .68341 .25995 Metetra
0 0 1 r
.68341 .25995 .69029 .26921 .70486 .2642 .69802 .25489 Metetra
0 0 1 r
.69802 .25489 .70486 .2642 .7195 .25917 .71271 .24981 Metetra
0 0 1 r
.71271 .24981 .7195 .25917 .73421 .25411 .72748 .2447 Metetra
0 0 1 r
.72748 .2447 .73421 .25411 .749 .24902 .74232 .23956 Metetra
0 0 1 r
.74232 .23956 .749 .24902 .76387 .24391 .75724 .2344 Metetra
0 0 1 r
.75724 .2344 .76387 .24391 .77881 .23877 .77224 .22921 Metetra
0 0 1 r
.1104 .44762 .11908 .4552 .13092 .4511 .12227 .44349 Metetra
0 0 1 r
.12227 .44349 .13092 .4511 .14282 .44699 .1342 .43934 Metetra
0 0 1 r
.1342 .43934 .14282 .44699 .15478 .44285 .14618 .43516 Metetra
0 0 1 r
.14618 .43516 .15478 .44285 .16678 .4387 .15823 .43097 Metetra
0 0 1 r
.15823 .43097 .16678 .4387 .17885 .43452 .17032 .42676 Metetra
0 0 1 r
.17032 .42676 .17885 .43452 .19097 .43033 .18248 .42253 Metetra
0 0 1 r
.18248 .42253 .19097 .43033 .20315 .42611 .19469 .41828 Metetra
0 0 1 r
.19469 .41828 .20315 .42611 .21539 .42188 .20696 .41401 Metetra
0 0 1 r
.20696 .41401 .21539 .42188 .22768 .41762 .21929 .40972 Metetra
0 0 1 r
.21929 .40972 .22768 .41762 .24004 .41335 .23168 .40541 Metetra
0 0 1 r
.23168 .40541 .24004 .41335 .25245 .40906 .24413 .40107 Metetra
0 0 1 r
.24413 .40107 .25245 .40906 .26492 .40474 .25663 .39672 Metetra
0 0 1 r
.25663 .39672 .26492 .40474 .27745 .4004 .2692 .39235 Metetra
0 0 1 r
.2692 .39235 .27745 .4004 .29004 .39605 .28183 .38795 Metetra
0 0 1 r
.28183 .38795 .29004 .39605 .30269 .39167 .29451 .38353 Metetra
0 0 1 r
.29451 .38353 .30269 .39167 .31541 .38727 .30726 .3791 Metetra
0 0 1 r
.30726 .3791 .31541 .38727 .32818 .38285 .32007 .37464 Metetra
0 0 1 r
.32007 .37464 .32818 .38285 .34102 .37841 .33295 .37016 Metetra
0 0 1 r
.33295 .37016 .34102 .37841 .35391 .37395 .34588 .36565 Metetra
0 0 1 r
.34588 .36565 .35391 .37395 .36688 .36946 .35888 .36113 Metetra
0 0 1 r
.35888 .36113 .36688 .36946 .3799 .36496 .37195 .35658 Metetra
0 0 1 r
.37195 .35658 .3799 .36496 .39299 .36043 .38508 .35201 Metetra
0 0 1 r
.38508 .35201 .39299 .36043 .40614 .35588 .39827 .34742 Metetra
0 0 1 r
.39827 .34742 .40614 .35588 .41936 .35131 .41152 .34281 Metetra
0 0 1 r
.41152 .34281 .41936 .35131 .43264 .34671 .42485 .33817 Metetra
0 0 1 r
.42485 .33817 .43264 .34671 .44598 .34209 .43824 .33351 Metetra
0 0 1 r
.43824 .33351 .44598 .34209 .4594 .33745 .45169 .32882 Metetra
0 0 1 r
.45169 .32882 .4594 .33745 .47288 .33279 .46521 .32412 Metetra
0 0 1 r
.46521 .32412 .47288 .33279 .48642 .3281 .4788 .31939 Metetra
0 0 1 r
.4788 .31939 .48642 .3281 .50004 .32339 .49246 .31463 Metetra
0 0 1 r
.49246 .31463 .50004 .32339 .51372 .31866 .50619 .30985 Metetra
0 0 1 r
.50619 .30985 .51372 .31866 .52747 .3139 .51998 .30505 Metetra
0 0 1 r
.51998 .30505 .52747 .3139 .54129 .30912 .53385 .30023 Metetra
0 0 1 r
.53385 .30023 .54129 .30912 .55518 .30431 .54779 .29538 Metetra
0 0 1 r
.54779 .29538 .55518 .30431 .56914 .29948 .56179 .2905 Metetra
0 0 1 r
.56179 .2905 .56914 .29948 .58317 .29463 .57587 .2856 Metetra
0 0 1 r
.57587 .2856 .58317 .29463 .59727 .28975 .59002 .28068 Metetra
0 0 1 r
.59002 .28068 .59727 .28975 .61144 .28484 .60424 .27573 Metetra
0 0 1 r
.60424 .27573 .61144 .28484 .62569 .27992 .61853 .27075 Metetra
0 0 1 r
.61853 .27075 .62569 .27992 .64001 .27496 .6329 .26575 Metetra
0 0 1 r
.6329 .26575 .64001 .27496 .6544 .26998 .64734 .26072 Metetra
0 0 1 r
.64734 .26072 .6544 .26998 .66887 .26498 .66186 .25567 Metetra
0 0 1 r
.66186 .25567 .66887 .26498 .68341 .25995 .67645 .25059 Metetra
0 0 1 r
.67645 .25059 .68341 .25995 .69802 .25489 .69112 .24548 Metetra
0 0 1 r
.69112 .24548 .69802 .25489 .71271 .24981 .70586 .24035 Metetra
0 0 1 r
.70586 .24035 .71271 .24981 .72748 .2447 .72068 .23519 Metetra
0 0 1 r
.72068 .23519 .72748 .2447 .74232 .23956 .73558 .23001 Metetra
0 0 1 r
.73558 .23001 .74232 .23956 .75724 .2344 .75056 .22479 Metetra
0 0 1 r
.75056 .22479 .75724 .2344 .77224 .22921 .76561 .21955 Metetra
0 0 1 r
.10164 .43998 .1104 .44762 .12227 .44349 .11354 .43581 Metetra
0 0 1 r
.11354 .43581 .12227 .44349 .1342 .43934 .1255 .43162 Metetra
0 0 1 r
.1255 .43162 .1342 .43934 .14618 .43516 .13752 .42741 Metetra
0 0 1 r
.13752 .42741 .14618 .43516 .15823 .43097 .14959 .42318 Metetra
0 0 1 r
.14959 .42318 .15823 .43097 .17032 .42676 .16172 .41894 Metetra
0 0 1 r
.16172 .41894 .17032 .42676 .18248 .42253 .17391 .41467 Metetra
0 0 1 r
.17391 .41467 .18248 .42253 .19469 .41828 .18616 .41038 Metetra
0 0 1 r
.18616 .41038 .19469 .41828 .20696 .41401 .19846 .40607 Metetra
0 0 1 r
.19846 .40607 .20696 .41401 .21929 .40972 .21082 .40174 Metetra
0 0 1 r
.21082 .40174 .21929 .40972 .23168 .40541 .22325 .39739 Metetra
0 0 1 r
.22325 .39739 .23168 .40541 .24413 .40107 .23573 .39302 Metetra
0 0 1 r
.23573 .39302 .24413 .40107 .25663 .39672 .24827 .38863 Metetra
0 0 1 r
.24827 .38863 .25663 .39672 .2692 .39235 .26087 .38421 Metetra
0 0 1 r
.26087 .38421 .2692 .39235 .28183 .38795 .27354 .37978 Metetra
0 0 1 r
.27354 .37978 .28183 .38795 .29451 .38353 .28626 .37532 Metetra
0 0 1 r
.28626 .37532 .29451 .38353 .30726 .3791 .29905 .37085 Metetra
0 0 1 r
.29905 .37085 .30726 .3791 .32007 .37464 .3119 .36635 Metetra
0 0 1 r
.3119 .36635 .32007 .37464 .33295 .37016 .32481 .36183 Metetra
0 0 1 r
.32481 .36183 .33295 .37016 .34588 .36565 .33778 .35728 Metetra
0 0 1 r
.33778 .35728 .34588 .36565 .35888 .36113 .35082 .35272 Metetra
0 0 1 r
.35082 .35272 .35888 .36113 .37195 .35658 .36392 .34813 Metetra
0 0 1 r
.36392 .34813 .37195 .35658 .38508 .35201 .37709 .34352 Metetra
0 0 1 r
.37709 .34352 .38508 .35201 .39827 .34742 .39032 .33888 Metetra
0 0 1 r
.39032 .33888 .39827 .34742 .41152 .34281 .40362 .33423 Metetra
0 0 1 r
.40362 .33423 .41152 .34281 .42485 .33817 .41699 .32955 Metetra
0 0 1 r
.41699 .32955 .42485 .33817 .43824 .33351 .43042 .32484 Metetra
0 0 1 r
.43042 .32484 .43824 .33351 .45169 .32882 .44391 .32012 Metetra
0 0 1 r
.44391 .32012 .45169 .32882 .46521 .32412 .45748 .31537 Metetra
0 0 1 r
.45748 .31537 .46521 .32412 .4788 .31939 .47111 .31059 Metetra
0 0 1 r
.47111 .31059 .4788 .31939 .49246 .31463 .48482 .30579 Metetra
0 0 1 r
.48482 .30579 .49246 .31463 .50619 .30985 .49859 .30097 Metetra
0 0 1 r
.49859 .30097 .50619 .30985 .51998 .30505 .51243 .29612 Metetra
0 0 1 r
.51243 .29612 .51998 .30505 .53385 .30023 .52634 .29125 Metetra
0 0 1 r
.52634 .29125 .53385 .30023 .54779 .29538 .54032 .28636 Metetra
0 0 1 r
.54032 .28636 .54779 .29538 .56179 .2905 .55437 .28143 Metetra
0 0 1 r
.55437 .28143 .56179 .2905 .57587 .2856 .5685 .27649 Metetra
0 0 1 r
.5685 .27649 .57587 .2856 .59002 .28068 .5827 .27152 Metetra
0 0 1 r
.5827 .27152 .59002 .28068 .60424 .27573 .59697 .26652 Metetra
0 0 1 r
.59697 .26652 .60424 .27573 .61853 .27075 .61131 .2615 Metetra
0 0 1 r
.61131 .2615 .61853 .27075 .6329 .26575 .62573 .25645 Metetra
0 0 1 r
.62573 .25645 .6329 .26575 .64734 .26072 .64022 .25137 Metetra
0 0 1 r
.64022 .25137 .64734 .26072 .66186 .25567 .65479 .24627 Metetra
0 0 1 r
.65479 .24627 .66186 .25567 .67645 .25059 .66943 .24114 Metetra
0 0 1 r
.66943 .24114 .67645 .25059 .69112 .24548 .68415 .23599 Metetra
0 0 1 r
.68415 .23599 .69112 .24548 .70586 .24035 .69895 .23081 Metetra
0 0 1 r
.69895 .23081 .70586 .24035 .72068 .23519 .71382 .2256 Metetra
0 0 1 r
.71382 .2256 .72068 .23519 .73558 .23001 .72877 .22036 Metetra
0 0 1 r
.72877 .22036 .73558 .23001 .75056 .22479 .7438 .2151 Metetra
0 0 1 r
.7438 .2151 .75056 .22479 .76561 .21955 .75891 .20981 Metetra
0 0 1 r
.0928 .43226 .10164 .43998 .11354 .43581 .10474 .42806 Metetra
0 0 1 r
.10474 .42806 .11354 .43581 .1255 .43162 .11673 .42384 Metetra
0 0 1 r
.11673 .42384 .1255 .43162 .13752 .42741 .12878 .41959 Metetra
0 0 1 r
.12878 .41959 .13752 .42741 .14959 .42318 .14088 .41533 Metetra
0 0 1 r
.14088 .41533 .14959 .42318 .16172 .41894 .15305 .41104 Metetra
0 0 1 r
.15305 .41104 .16172 .41894 .17391 .41467 .16527 .40673 Metetra
0 0 1 r
.16527 .40673 .17391 .41467 .18616 .41038 .17755 .40241 Metetra
0 0 1 r
.17755 .40241 .18616 .41038 .19846 .40607 .18988 .39806 Metetra
0 0 1 r
.18988 .39806 .19846 .40607 .21082 .40174 .20228 .39369 Metetra
0 0 1 r
.20228 .39369 .21082 .40174 .22325 .39739 .21474 .38931 Metetra
0 0 1 r
.21474 .38931 .22325 .39739 .23573 .39302 .22725 .3849 Metetra
0 0 1 r
.22725 .3849 .23573 .39302 .24827 .38863 .23983 .38046 Metetra
0 0 1 r
.23983 .38046 .24827 .38863 .26087 .38421 .25247 .37601 Metetra
0 0 1 r
.25247 .37601 .26087 .38421 .27354 .37978 .26517 .37154 Metetra
0 0 1 r
.26517 .37154 .27354 .37978 .28626 .37532 .27793 .36704 Metetra
0 0 1 r
.27793 .36704 .28626 .37532 .29905 .37085 .29076 .36252 Metetra
0 0 1 r
.29076 .36252 .29905 .37085 .3119 .36635 .30364 .35798 Metetra
0 0 1 r
.30364 .35798 .3119 .36635 .32481 .36183 .31659 .35342 Metetra
0 0 1 r
.31659 .35342 .32481 .36183 .33778 .35728 .32961 .34884 Metetra
0 0 1 r
.32961 .34884 .33778 .35728 .35082 .35272 .34268 .34423 Metetra
0 0 1 r
.34268 .34423 .35082 .35272 .36392 .34813 .35583 .3396 Metetra
0 0 1 r
.35583 .3396 .36392 .34813 .37709 .34352 .36903 .33494 Metetra
0 0 1 r
.36903 .33494 .37709 .34352 .39032 .33888 .38231 .33027 Metetra
0 0 1 r
.38231 .33027 .39032 .33888 .40362 .33423 .39565 .32557 Metetra
0 0 1 r
.39565 .32557 .40362 .33423 .41699 .32955 .40905 .32084 Metetra
0 0 1 r
.40905 .32084 .41699 .32955 .43042 .32484 .42253 .3161 Metetra
0 0 1 r
.42253 .3161 .43042 .32484 .44391 .32012 .43607 .31133 Metetra
0 0 1 r
.43607 .31133 .44391 .32012 .45748 .31537 .44967 .30653 Metetra
0 0 1 r
.44967 .30653 .45748 .31537 .47111 .31059 .46335 .30171 Metetra
0 0 1 r
.46335 .30171 .47111 .31059 .48482 .30579 .4771 .29687 Metetra
0 0 1 r
.4771 .29687 .48482 .30579 .49859 .30097 .49091 .292 Metetra
0 0 1 r
.49091 .292 .49859 .30097 .51243 .29612 .5048 .28711 Metetra
0 0 1 r
.5048 .28711 .51243 .29612 .52634 .29125 .51876 .28219 Metetra
0 0 1 r
.51876 .28219 .52634 .29125 .54032 .28636 .53279 .27725 Metetra
0 0 1 r
.53279 .27725 .54032 .28636 .55437 .28143 .54689 .27228 Metetra
0 0 1 r
.54689 .27228 .55437 .28143 .5685 .27649 .56106 .26729 Metetra
0 0 1 r
.56106 .26729 .5685 .27649 .5827 .27152 .5753 .26227 Metetra
0 0 1 r
.5753 .26227 .5827 .27152 .59697 .26652 .58962 .25723 Metetra
0 0 1 r
.58962 .25723 .59697 .26652 .61131 .2615 .60402 .25216 Metetra
0 0 1 r
.60402 .25216 .61131 .2615 .62573 .25645 .61848 .24706 Metetra
0 0 1 r
.61848 .24706 .62573 .25645 .64022 .25137 .63303 .24193 Metetra
0 0 1 r
.63303 .24193 .64022 .25137 .65479 .24627 .64765 .23678 Metetra
0 0 1 r
.64765 .23678 .65479 .24627 .66943 .24114 .66234 .23161 Metetra
0 0 1 r
.66234 .23161 .66943 .24114 .68415 .23599 .67711 .2264 Metetra
0 0 1 r
.67711 .2264 .68415 .23599 .69895 .23081 .69196 .22117 Metetra
0 0 1 r
.69196 .22117 .69895 .23081 .71382 .2256 .70689 .21591 Metetra
0 0 1 r
.70689 .21591 .71382 .2256 .72877 .22036 .7219 .21062 Metetra
0 0 1 r
.7219 .21062 .72877 .22036 .7438 .2151 .73699 .20531 Metetra
0 0 1 r
.73699 .20531 .7438 .2151 .75891 .20981 .75215 .19996 Metetra
0 0 1 r
.08389 .42449 .0928 .43226 .10474 .42806 .09586 .42024 Metetra
0 0 1 r
.09586 .42024 .10474 .42806 .11673 .42384 .10788 .41598 Metetra
0 0 1 r
.10788 .41598 .11673 .42384 .12878 .41959 .11996 .4117 Metetra
0 0 1 r
.11996 .4117 .12878 .41959 .14088 .41533 .1321 .4074 Metetra
0 0 1 r
.1321 .4074 .14088 .41533 .15305 .41104 .14429 .40308 Metetra
0 0 1 r
.14429 .40308 .15305 .41104 .16527 .40673 .15655 .39873 Metetra
0 0 1 r
.15655 .39873 .16527 .40673 .17755 .40241 .16886 .39437 Metetra
0 0 1 r
.16886 .39437 .17755 .40241 .18988 .39806 .18123 .38998 Metetra
0 0 1 r
.18123 .38998 .18988 .39806 .20228 .39369 .19366 .38558 Metetra
0 0 1 r
.19366 .38558 .20228 .39369 .21474 .38931 .20615 .38115 Metetra
0 0 1 r
.20615 .38115 .21474 .38931 .22725 .3849 .21871 .3767 Metetra
0 0 1 r
.21871 .3767 .22725 .3849 .23983 .38046 .23132 .37223 Metetra
0 0 1 r
.23132 .37223 .23983 .38046 .25247 .37601 .24399 .36773 Metetra
0 0 1 r
.24399 .36773 .25247 .37601 .26517 .37154 .25673 .36322 Metetra
0 0 1 r
.25673 .36322 .26517 .37154 .27793 .36704 .26953 .35868 Metetra
0 0 1 r
.26953 .35868 .27793 .36704 .29076 .36252 .28239 .35412 Metetra
0 0 1 r
.28239 .35412 .29076 .36252 .30364 .35798 .29531 .34954 Metetra
0 0 1 r
.29531 .34954 .30364 .35798 .31659 .35342 .3083 .34494 Metetra
0 0 1 r
.3083 .34494 .31659 .35342 .32961 .34884 .32136 .34031 Metetra
0 0 1 r
.32136 .34031 .32961 .34884 .34268 .34423 .33447 .33566 Metetra
0 0 1 r
.33447 .33566 .34268 .34423 .35583 .3396 .34766 .33099 Metetra
0 0 1 r
.34766 .33099 .35583 .3396 .36903 .33494 .3609 .32629 Metetra
0 0 1 r
.3609 .32629 .36903 .33494 .38231 .33027 .37422 .32157 Metetra
0 0 1 r
.37422 .32157 .38231 .33027 .39565 .32557 .3876 .31683 Metetra
0 0 1 r
.3876 .31683 .39565 .32557 .40905 .32084 .40105 .31206 Metetra
0 0 1 r
.40105 .31206 .40905 .32084 .42253 .3161 .41456 .30727 Metetra
0 0 1 r
.41456 .30727 .42253 .3161 .43607 .31133 .42814 .30246 Metetra
0 0 1 r
.42814 .30246 .43607 .31133 .44967 .30653 .4418 .29762 Metetra
0 0 1 r
.4418 .29762 .44967 .30653 .46335 .30171 .45552 .29275 Metetra
0 0 1 r
.45552 .29275 .46335 .30171 .4771 .29687 .46931 .28786 Metetra
0 0 1 r
.46931 .28786 .4771 .29687 .49091 .292 .48317 .28295 Metetra
0 0 1 r
.48317 .28295 .49091 .292 .5048 .28711 .4971 .27801 Metetra
0 0 1 r
.4971 .27801 .5048 .28711 .51876 .28219 .51111 .27305 Metetra
0 0 1 r
.51111 .27305 .51876 .28219 .53279 .27725 .52518 .26806 Metetra
0 0 1 r
.52518 .26806 .53279 .27725 .54689 .27228 .53933 .26304 Metetra
0 0 1 r
.53933 .26304 .54689 .27228 .56106 .26729 .55355 .258 Metetra
0 0 1 r
.55355 .258 .56106 .26729 .5753 .26227 .56784 .25294 Metetra
0 0 1 r
.56784 .25294 .5753 .26227 .58962 .25723 .58221 .24784 Metetra
0 0 1 r
.58221 .24784 .58962 .25723 .60402 .25216 .59665 .24272 Metetra
0 0 1 r
.59665 .24272 .60402 .25216 .61848 .24706 .61117 .23758 Metetra
0 0 1 r
.61117 .23758 .61848 .24706 .63303 .24193 .62577 .2324 Metetra
0 0 1 r
.62577 .2324 .63303 .24193 .64765 .23678 .64044 .2272 Metetra
0 0 1 r
.64044 .2272 .64765 .23678 .66234 .23161 .65518 .22198 Metetra
0 0 1 r
.65518 .22198 .66234 .23161 .67711 .2264 .67001 .21672 Metetra
0 0 1 r
.67001 .21672 .67711 .2264 .69196 .22117 .68491 .21144 Metetra
0 0 1 r
.68491 .21144 .69196 .22117 .70689 .21591 .6999 .20613 Metetra
0 0 1 r
.6999 .20613 .70689 .21591 .7219 .21062 .71496 .20079 Metetra
0 0 1 r
.71496 .20079 .7219 .21062 .73699 .20531 .7301 .19542 Metetra
0 0 1 r
.7301 .19542 .73699 .20531 .75215 .19996 .74532 .19002 Metetra
0 0 1 r
.0749 .41664 .08389 .42449 .09586 .42024 .0869 .41236 Metetra
0 0 1 r
.0869 .41236 .09586 .42024 .10788 .41598 .09895 .40806 Metetra
0 0 1 r
.09895 .40806 .10788 .41598 .11996 .4117 .11106 .40374 Metetra
0 0 1 r
.11106 .40374 .11996 .4117 .1321 .4074 .12323 .3994 Metetra
0 0 1 r
.12323 .3994 .1321 .4074 .14429 .40308 .13546 .39504 Metetra
0 0 1 r
.13546 .39504 .14429 .40308 .15655 .39873 .14775 .39066 Metetra
0 0 1 r
.14775 .39066 .15655 .39873 .16886 .39437 .16009 .38625 Metetra
0 0 1 r
.16009 .38625 .16886 .39437 .18123 .38998 .1725 .38183 Metetra
0 0 1 r
.1725 .38183 .18123 .38998 .19366 .38558 .18497 .37738 Metetra
0 0 1 r
.18497 .37738 .19366 .38558 .20615 .38115 .19749 .37292 Metetra
0 0 1 r
.19749 .37292 .20615 .38115 .21871 .3767 .21008 .36843 Metetra
0 0 1 r
.21008 .36843 .21871 .3767 .23132 .37223 .22273 .36392 Metetra
0 0 1 r
.22273 .36392 .23132 .37223 .24399 .36773 .23544 .35938 Metetra
0 0 1 r
.23544 .35938 .24399 .36773 .25673 .36322 .24821 .35483 Metetra
0 0 1 r
.24821 .35483 .25673 .36322 .26953 .35868 .26105 .35025 Metetra
0 0 1 r
.26105 .35025 .26953 .35868 .28239 .35412 .27395 .34565 Metetra
0 0 1 r
.27395 .34565 .28239 .35412 .29531 .34954 .28691 .34102 Metetra
0 0 1 r
.28691 .34102 .29531 .34954 .3083 .34494 .29994 .33638 Metetra
0 0 1 r
.29994 .33638 .3083 .34494 .32136 .34031 .31303 .33171 Metetra
0 0 1 r
.31303 .33171 .32136 .34031 .33447 .33566 .32619 .32702 Metetra
0 0 1 r
.32619 .32702 .33447 .33566 .34766 .33099 .33941 .3223 Metetra
0 0 1 r
.33941 .3223 .34766 .33099 .3609 .32629 .3527 .31756 Metetra
0 0 1 r
.3527 .31756 .3609 .32629 .37422 .32157 .36605 .3128 Metetra
0 0 1 r
.36605 .3128 .37422 .32157 .3876 .31683 .37947 .30801 Metetra
0 0 1 r
.37947 .30801 .3876 .31683 .40105 .31206 .39296 .3032 Metetra
0 0 1 r
.39296 .3032 .40105 .31206 .41456 .30727 .40652 .29836 Metetra
0 0 1 r
.40652 .29836 .41456 .30727 .42814 .30246 .42015 .2935 Metetra
0 0 1 r
.42015 .2935 .42814 .30246 .4418 .29762 .43384 .28862 Metetra
0 0 1 r
.43384 .28862 .4418 .29762 .45552 .29275 .44761 .28371 Metetra
0 0 1 r
.44761 .28371 .45552 .29275 .46931 .28786 .46145 .27877 Metetra
0 0 1 r
.46145 .27877 .46931 .28786 .48317 .28295 .47535 .27381 Metetra
0 0 1 r
.47535 .27381 .48317 .28295 .4971 .27801 .48933 .26883 Metetra
0 0 1 r
.48933 .26883 .4971 .27801 .51111 .27305 .50338 .26382 Metetra
0 0 1 r
.50338 .26382 .51111 .27305 .52518 .26806 .5175 .25878 Metetra
0 0 1 r
.5175 .25878 .52518 .26806 .53933 .26304 .5317 .25372 Metetra
0 0 1 r
.5317 .25372 .53933 .26304 .55355 .258 .54597 .24863 Metetra
0 0 1 r
.54597 .24863 .55355 .258 .56784 .25294 .56031 .24351 Metetra
0 0 1 r
.56031 .24351 .56784 .25294 .58221 .24784 .57473 .23837 Metetra
0 0 1 r
.57473 .23837 .58221 .24784 .59665 .24272 .58922 .2332 Metetra
0 0 1 r
.58922 .2332 .59665 .24272 .61117 .23758 .60379 .22801 Metetra
0 0 1 r
.60379 .22801 .61117 .23758 .62577 .2324 .61843 .22278 Metetra
0 0 1 r
.61843 .22278 .62577 .2324 .64044 .2272 .63316 .21753 Metetra
0 0 1 r
.63316 .21753 .64044 .2272 .65518 .22198 .64796 .21225 Metetra
0 0 1 r
.64796 .21225 .65518 .22198 .67001 .21672 .66284 .20695 Metetra
0 0 1 r
.66284 .20695 .67001 .21672 .68491 .21144 .67779 .20161 Metetra
0 0 1 r
.67779 .20161 .68491 .21144 .6999 .20613 .69283 .19625 Metetra
0 0 1 r
.69283 .19625 .6999 .20613 .71496 .20079 .70795 .19086 Metetra
0 0 1 r
.70795 .19086 .71496 .20079 .7301 .19542 .72315 .18544 Metetra
0 0 1 r
.72315 .18544 .7301 .19542 .74532 .19002 .73843 .17999 Metetra
0 0 1 r
.06583 .40872 .0749 .41664 .0869 .41236 .07786 .40441 Metetra
0 0 1 r
.07786 .40441 .0869 .41236 .09895 .40806 .08995 .40007 Metetra
0 0 1 r
.08995 .40007 .09895 .40806 .11106 .40374 .10209 .39571 Metetra
0 0 1 r
.10209 .39571 .11106 .40374 .12323 .3994 .11429 .39133 Metetra
0 0 1 r
.11429 .39133 .12323 .3994 .13546 .39504 .12655 .38693 Metetra
0 0 1 r
.12655 .38693 .13546 .39504 .14775 .39066 .13887 .38251 Metetra
0 0 1 r
.13887 .38251 .14775 .39066 .16009 .38625 .15125 .37807 Metetra
0 0 1 r
.15125 .37807 .16009 .38625 .1725 .38183 .16369 .3736 Metetra
0 0 1 r
.16369 .3736 .1725 .38183 .18497 .37738 .17619 .36912 Metetra
0 0 1 r
.17619 .36912 .18497 .37738 .19749 .37292 .18875 .36461 Metetra
0 0 1 r
.18875 .36461 .19749 .37292 .21008 .36843 .20138 .36008 Metetra
0 0 1 r
.20138 .36008 .21008 .36843 .22273 .36392 .21406 .35553 Metetra
0 0 1 r
.21406 .35553 .22273 .36392 .23544 .35938 .22681 .35095 Metetra
0 0 1 r
.22681 .35095 .23544 .35938 .24821 .35483 .23962 .34636 Metetra
0 0 1 r
.23962 .34636 .24821 .35483 .26105 .35025 .25249 .34174 Metetra
0 0 1 r
.25249 .34174 .26105 .35025 .27395 .34565 .26543 .33709 Metetra
0 0 1 r
.26543 .33709 .27395 .34565 .28691 .34102 .27843 .33243 Metetra
0 0 1 r
.27843 .33243 .28691 .34102 .29994 .33638 .2915 .32774 Metetra
0 0 1 r
.2915 .32774 .29994 .33638 .31303 .33171 .30463 .32303 Metetra
0 0 1 r
.30463 .32303 .31303 .33171 .32619 .32702 .31782 .31829 Metetra
0 0 1 r
.31782 .31829 .32619 .32702 .33941 .3223 .33109 .31353 Metetra
0 0 1 r
.33109 .31353 .33941 .3223 .3527 .31756 .34441 .30875 Metetra
0 0 1 r
.34441 .30875 .3527 .31756 .36605 .3128 .35781 .30394 Metetra
0 0 1 r
.35781 .30394 .36605 .3128 .37947 .30801 .37127 .29911 Metetra
0 0 1 r
.37127 .29911 .37947 .30801 .39296 .3032 .38481 .29425 Metetra
0 0 1 r
.38481 .29425 .39296 .3032 .40652 .29836 .39841 .28937 Metetra
0 0 1 r
.39841 .28937 .40652 .29836 .42015 .2935 .41208 .28447 Metetra
0 0 1 r
.41208 .28447 .42015 .2935 .43384 .28862 .42582 .27954 Metetra
0 0 1 r
.42582 .27954 .43384 .28862 .44761 .28371 .43963 .27458 Metetra
0 0 1 r
.43963 .27458 .44761 .28371 .46145 .27877 .45351 .2696 Metetra
0 0 1 r
.45351 .2696 .46145 .27877 .47535 .27381 .46746 .26459 Metetra
0 0 1 r
.46746 .26459 .47535 .27381 .48933 .26883 .48148 .25956 Metetra
0 0 1 r
.48148 .25956 .48933 .26883 .50338 .26382 .49558 .2545 Metetra
0 0 1 r
.49558 .2545 .50338 .26382 .5175 .25878 .50975 .24941 Metetra
0 0 1 r
.50975 .24941 .5175 .25878 .5317 .25372 .52399 .2443 Metetra
0 0 1 r
.52399 .2443 .5317 .25372 .54597 .24863 .53831 .23916 Metetra
0 0 1 r
.53831 .23916 .54597 .24863 .56031 .24351 .5527 .234 Metetra
0 0 1 r
.5527 .234 .56031 .24351 .57473 .23837 .56717 .22881 Metetra
0 0 1 r
.56717 .22881 .57473 .23837 .58922 .2332 .58171 .22359 Metetra
0 0 1 r
.58171 .22359 .58922 .2332 .60379 .22801 .59633 .21834 Metetra
0 0 1 r
.59633 .21834 .60379 .22801 .61843 .22278 .61103 .21307 Metetra
0 0 1 r
.61103 .21307 .61843 .22278 .63316 .21753 .62581 .20776 Metetra
0 0 1 r
.62581 .20776 .63316 .21753 .64796 .21225 .64066 .20243 Metetra
0 0 1 r
.64066 .20243 .64796 .21225 .66284 .20695 .65559 .19708 Metetra
0 0 1 r
.65559 .19708 .66284 .20695 .67779 .20161 .6706 .19169 Metetra
0 0 1 r
.6706 .19169 .67779 .20161 .69283 .19625 .6857 .18627 Metetra
0 0 1 r
.6857 .18627 .69283 .19625 .70795 .19086 .70087 .18083 Metetra
0 0 1 r
.70087 .18083 .70795 .19086 .72315 .18544 .71612 .17535 Metetra
0 0 1 r
.71612 .17535 .72315 .18544 .73843 .17999 .73146 .16985 Metetra
0 0 1 r
.05668 .40074 .06583 .40872 .07786 .40441 .06874 .39638 Metetra
0 0 1 r
.06874 .39638 .07786 .40441 .08995 .40007 .08086 .39201 Metetra
0 0 1 r
.08086 .39201 .08995 .40007 .10209 .39571 .09304 .38761 Metetra
0 0 1 r
.09304 .38761 .10209 .39571 .11429 .39133 .10527 .38319 Metetra
0 0 1 r
.10527 .38319 .11429 .39133 .12655 .38693 .11756 .37875 Metetra
0 0 1 r
.11756 .37875 .12655 .38693 .13887 .38251 .12992 .37429 Metetra
0 0 1 r
.12992 .37429 .13887 .38251 .15125 .37807 .14233 .36981 Metetra
0 0 1 r
.14233 .36981 .15125 .37807 .16369 .3736 .15481 .36531 Metetra
0 0 1 r
.15481 .36531 .16369 .3736 .17619 .36912 .16734 .36078 Metetra
0 0 1 r
.16734 .36078 .17619 .36912 .18875 .36461 .17994 .35623 Metetra
0 0 1 r
.17994 .35623 .18875 .36461 .20138 .36008 .1926 .35166 Metetra
0 0 1 r
.1926 .35166 .20138 .36008 .21406 .35553 .20532 .34707 Metetra
0 0 1 r
.20532 .34707 .21406 .35553 .22681 .35095 .2181 .34245 Metetra
0 0 1 r
.2181 .34245 .22681 .35095 .23962 .34636 .23095 .33781 Metetra
0 0 1 r
.23095 .33781 .23962 .34636 .25249 .34174 .24386 .33315 Metetra
0 0 1 r
.24386 .33315 .25249 .34174 .26543 .33709 .25683 .32846 Metetra
0 0 1 r
.25683 .32846 .26543 .33709 .27843 .33243 .26987 .32375 Metetra
0 0 1 r
.26987 .32375 .27843 .33243 .2915 .32774 .28298 .31902 Metetra
0 0 1 r
.28298 .31902 .2915 .32774 .30463 .32303 .29615 .31427 Metetra
0 0 1 r
.29615 .31427 .30463 .32303 .31782 .31829 .30938 .30949 Metetra
0 0 1 r
.30938 .30949 .31782 .31829 .33109 .31353 .32269 .30468 Metetra
0 0 1 r
.32269 .30468 .33109 .31353 .34441 .30875 .33606 .29985 Metetra
0 0 1 r
.33606 .29985 .34441 .30875 .35781 .30394 .34949 .295 Metetra
0 0 1 r
.34949 .295 .35781 .30394 .37127 .29911 .363 .29012 Metetra
0 0 1 r
.363 .29012 .37127 .29911 .38481 .29425 .37657 .28522 Metetra
0 0 1 r
.37657 .28522 .38481 .29425 .39841 .28937 .39022 .2803 Metetra
0 0 1 r
.39022 .2803 .39841 .28937 .41208 .28447 .40393 .27534 Metetra
0 0 1 r
.40393 .27534 .41208 .28447 .42582 .27954 .41771 .27037 Metetra
0 0 1 r
.41771 .27037 .42582 .27954 .43963 .27458 .43157 .26536 Metetra
0 0 1 r
.43157 .26536 .43963 .27458 .45351 .2696 .4455 .26033 Metetra
0 0 1 r
.4455 .26033 .45351 .2696 .46746 .26459 .45949 .25528 Metetra
0 0 1 r
.45949 .25528 .46746 .26459 .48148 .25956 .47356 .2502 Metetra
0 0 1 r
.47356 .2502 .48148 .25956 .49558 .2545 .48771 .24509 Metetra
0 0 1 r
.48771 .24509 .49558 .2545 .50975 .24941 .50192 .23996 Metetra
0 0 1 r
.50192 .23996 .50975 .24941 .52399 .2443 .51622 .2348 Metetra
0 0 1 r
.51622 .2348 .52399 .2443 .53831 .23916 .53058 .22961 Metetra
0 0 1 r
.53058 .22961 .53831 .23916 .5527 .234 .54502 .22439 Metetra
0 0 1 r
.54502 .22439 .5527 .234 .56717 .22881 .55954 .21915 Metetra
0 0 1 r
.55954 .21915 .56717 .22881 .58171 .22359 .57414 .21388 Metetra
0 0 1 r
.57414 .21388 .58171 .22359 .59633 .21834 .58881 .20858 Metetra
0 0 1 r
.58881 .20858 .59633 .21834 .61103 .21307 .60356 .20326 Metetra
0 0 1 r
.60356 .20326 .61103 .21307 .62581 .20776 .61838 .1979 Metetra
0 0 1 r
.61838 .1979 .62581 .20776 .64066 .20243 .63329 .19252 Metetra
0 0 1 r
.63329 .19252 .64066 .20243 .65559 .19708 .64828 .18711 Metetra
0 0 1 r
.64828 .18711 .65559 .19708 .6706 .19169 .66334 .18167 Metetra
0 0 1 r
.66334 .18167 .6706 .19169 .6857 .18627 .67849 .1762 Metetra
0 0 1 r
.67849 .1762 .6857 .18627 .70087 .18083 .69372 .1707 Metetra
0 0 1 r
.69372 .1707 .70087 .18083 .71612 .17535 .70903 .16517 Metetra
0 0 1 r
.70903 .16517 .71612 .17535 .73146 .16985 .72442 .15961 Metetra
0 0 1 r
.04745 .39268 .05668 .40074 .06874 .39638 .05954 .38829 Metetra
0 0 1 r
.05954 .38829 .06874 .39638 .08086 .39201 .07169 .38387 Metetra
0 0 1 r
.07169 .38387 .08086 .39201 .09304 .38761 .0839 .37944 Metetra
0 0 1 r
.0839 .37944 .09304 .38761 .10527 .38319 .09617 .37498 Metetra
0 0 1 r
.09617 .37498 .10527 .38319 .11756 .37875 .10849 .3705 Metetra
0 0 1 r
.10849 .3705 .11756 .37875 .12992 .37429 .12088 .366 Metetra
0 0 1 r
.12088 .366 .12992 .37429 .14233 .36981 .13333 .36148 Metetra
0 0 1 r
.13333 .36148 .14233 .36981 .15481 .36531 .14584 .35693 Metetra
0 0 1 r
.14584 .35693 .15481 .36531 .16734 .36078 .15841 .35236 Metetra
0 0 1 r
.15841 .35236 .16734 .36078 .17994 .35623 .17104 .34777 Metetra
0 0 1 r
.17104 .34777 .17994 .35623 .1926 .35166 .18373 .34316 Metetra
0 0 1 r
.18373 .34316 .1926 .35166 .20532 .34707 .19649 .33853 Metetra
0 0 1 r
.19649 .33853 .20532 .34707 .2181 .34245 .20931 .33387 Metetra
0 0 1 r
.20931 .33387 .2181 .34245 .23095 .33781 .22219 .32918 Metetra
0 0 1 r
.22219 .32918 .23095 .33781 .24386 .33315 .23514 .32448 Metetra
0 0 1 r
.23514 .32448 .24386 .33315 .25683 .32846 .24816 .31975 Metetra
0 0 1 r
.24816 .31975 .25683 .32846 .26987 .32375 .26123 .315 Metetra
0 0 1 r
.26123 .315 .26987 .32375 .28298 .31902 .27438 .31022 Metetra
0 0 1 r
.27438 .31022 .28298 .31902 .29615 .31427 .28759 .30542 Metetra
0 0 1 r
.28759 .30542 .29615 .31427 .30938 .30949 .30086 .3006 Metetra
0 0 1 r
.30086 .3006 .30938 .30949 .32269 .30468 .31421 .29575 Metetra
0 0 1 r
.31421 .29575 .32269 .30468 .33606 .29985 .32762 .29088 Metetra
0 0 1 r
.32762 .29088 .33606 .29985 .34949 .295 .3411 .28598 Metetra
0 0 1 r
.3411 .28598 .34949 .295 .363 .29012 .35464 .28106 Metetra
0 0 1 r
.35464 .28106 .363 .29012 .37657 .28522 .36826 .27611 Metetra
0 0 1 r
.36826 .27611 .37657 .28522 .39022 .2803 .38195 .27113 Metetra
0 0 1 r
.38195 .27113 .39022 .2803 .40393 .27534 .39571 .26613 Metetra
0 0 1 r
.39571 .26613 .40393 .27534 .41771 .27037 .40953 .26111 Metetra
0 0 1 r
.40953 .26111 .41771 .27037 .43157 .26536 .42343 .25606 Metetra
0 0 1 r
.42343 .25606 .43157 .26536 .4455 .26033 .43741 .25098 Metetra
0 0 1 r
.43741 .25098 .4455 .26033 .45949 .25528 .45145 .24588 Metetra
0 0 1 r
.45145 .24588 .45949 .25528 .47356 .2502 .46557 .24075 Metetra
0 0 1 r
.46557 .24075 .47356 .2502 .48771 .24509 .47976 .23559 Metetra
0 0 1 r
.47976 .23559 .48771 .24509 .50192 .23996 .49402 .23041 Metetra
0 0 1 r
.49402 .23041 .50192 .23996 .51622 .2348 .50836 .2252 Metetra
0 0 1 r
.50836 .2252 .51622 .2348 .53058 .22961 .52278 .21996 Metetra
0 0 1 r
.52278 .21996 .53058 .22961 .54502 .22439 .53727 .21469 Metetra
0 0 1 r
.53727 .21469 .54502 .22439 .55954 .21915 .55184 .2094 Metetra
0 0 1 r
.55184 .2094 .55954 .21915 .57414 .21388 .56648 .20408 Metetra
0 0 1 r
.56648 .20408 .57414 .21388 .58881 .20858 .58121 .19873 Metetra
0 0 1 r
.58121 .19873 .58881 .20858 .60356 .20326 .59601 .19335 Metetra
0 0 1 r
.59601 .19335 .60356 .20326 .61838 .1979 .61089 .18794 Metetra
0 0 1 r
.61089 .18794 .61838 .1979 .63329 .19252 .62585 .18251 Metetra
0 0 1 r
.62585 .18251 .63329 .19252 .64828 .18711 .64089 .17704 Metetra
0 0 1 r
.64089 .17704 .64828 .18711 .66334 .18167 .65601 .17155 Metetra
0 0 1 r
.65601 .17155 .66334 .18167 .67849 .1762 .67121 .16602 Metetra
0 0 1 r
.67121 .16602 .67849 .1762 .69372 .1707 .6865 .16047 Metetra
0 0 1 r
.6865 .16047 .69372 .1707 .70903 .16517 .70187 .15488 Metetra
0 0 1 r
.70187 .15488 .70903 .16517 .72442 .15961 .71732 .14927 Metetra
0 0 1 r
.03814 .38456 .04745 .39268 .05954 .38829 .05026 .38012 Metetra
0 0 1 r
.05026 .38012 .05954 .38829 .07169 .38387 .06244 .37567 Metetra
0 0 1 r
.06244 .37567 .07169 .38387 .0839 .37944 .07468 .37119 Metetra
0 0 1 r
.07468 .37119 .0839 .37944 .09617 .37498 .08698 .36669 Metetra
0 0 1 r
.08698 .36669 .09617 .37498 .10849 .3705 .09934 .36217 Metetra
0 0 1 r
.09934 .36217 .10849 .3705 .12088 .366 .11176 .35763 Metetra
0 0 1 r
.11176 .35763 .12088 .366 .13333 .36148 .12425 .35307 Metetra
0 0 1 r
.12425 .35307 .13333 .36148 .14584 .35693 .13679 .34848 Metetra
0 0 1 r
.13679 .34848 .14584 .35693 .15841 .35236 .14939 .34387 Metetra
0 0 1 r
.14939 .34387 .15841 .35236 .17104 .34777 .16206 .33924 Metetra
0 0 1 r
.16206 .33924 .17104 .34777 .18373 .34316 .17479 .33458 Metetra
0 0 1 r
.17479 .33458 .18373 .34316 .19649 .33853 .18758 .32991 Metetra
0 0 1 r
.18758 .32991 .19649 .33853 .20931 .33387 .20044 .32521 Metetra
0 0 1 r
.20044 .32521 .20931 .33387 .22219 .32918 .21336 .32048 Metetra
0 0 1 r
.21336 .32048 .22219 .32918 .23514 .32448 .22635 .31573 Metetra
0 0 1 r
.22635 .31573 .23514 .32448 .24816 .31975 .2394 .31096 Metetra
0 0 1 r
.2394 .31096 .24816 .31975 .26123 .315 .25251 .30616 Metetra
0 0 1 r
.25251 .30616 .26123 .315 .27438 .31022 .2657 .30134 Metetra
0 0 1 r
.2657 .30134 .27438 .31022 .28759 .30542 .27895 .2965 Metetra
0 0 1 r
.27895 .2965 .28759 .30542 .30086 .3006 .29226 .29163 Metetra
0 0 1 r
.29226 .29163 .30086 .3006 .31421 .29575 .30565 .28673 Metetra
0 0 1 r
.30565 .28673 .31421 .29575 .32762 .29088 .3191 .28181 Metetra
0 0 1 r
.3191 .28181 .32762 .29088 .3411 .28598 .33262 .27687 Metetra
0 0 1 r
.33262 .27687 .3411 .28598 .35464 .28106 .34621 .2719 Metetra
0 0 1 r
.34621 .2719 .35464 .28106 .36826 .27611 .35987 .2669 Metetra
0 0 1 r
.35987 .2669 .36826 .27611 .38195 .27113 .3736 .26188 Metetra
0 0 1 r
.3736 .26188 .38195 .27113 .39571 .26613 .3874 .25684 Metetra
0 0 1 r
.3874 .25684 .39571 .26613 .40953 .26111 .40128 .25176 Metetra
0 0 1 r
.40128 .25176 .40953 .26111 .42343 .25606 .41522 .24666 Metetra
0 0 1 r
.41522 .24666 .42343 .25606 .43741 .25098 .42924 .24154 Metetra
0 0 1 r
.42924 .24154 .43741 .25098 .45145 .24588 .44333 .23639 Metetra
0 0 1 r
.44333 .23639 .45145 .24588 .46557 .24075 .45749 .23121 Metetra
0 0 1 r
.45749 .23121 .46557 .24075 .47976 .23559 .47173 .226 Metetra
0 0 1 r
.47173 .226 .47976 .23559 .49402 .23041 .48604 .22077 Metetra
0 0 1 r
.48604 .22077 .49402 .23041 .50836 .2252 .50043 .2155 Metetra
0 0 1 r
.50043 .2155 .50836 .2252 .52278 .21996 .5149 .21022 Metetra
0 0 1 r
.5149 .21022 .52278 .21996 .53727 .21469 .52944 .2049 Metetra
0 0 1 r
.52944 .2049 .53727 .21469 .55184 .2094 .54406 .19955 Metetra
0 0 1 r
.54406 .19955 .55184 .2094 .56648 .20408 .55875 .19418 Metetra
0 0 1 r
.55875 .19418 .56648 .20408 .58121 .19873 .57353 .18878 Metetra
0 0 1 r
.57353 .18878 .58121 .19873 .59601 .19335 .58838 .18334 Metetra
0 0 1 r
.58838 .18334 .59601 .19335 .61089 .18794 .60332 .17788 Metetra
0 0 1 r
.60332 .17788 .61089 .18794 .62585 .18251 .61833 .17239 Metetra
0 0 1 r
.61833 .17239 .62585 .18251 .64089 .17704 .63343 .16687 Metetra
0 0 1 r
.63343 .16687 .64089 .17704 .65601 .17155 .6486 .16132 Metetra
0 0 1 r
.6486 .16132 .65601 .17155 .67121 .16602 .66386 .15574 Metetra
0 0 1 r
.66386 .15574 .67121 .16602 .6865 .16047 .6792 .15013 Metetra
0 0 1 r
.6792 .15013 .6865 .16047 .70187 .15488 .69463 .14449 Metetra
0 0 1 r
.69463 .14449 .70187 .15488 .71732 .14927 .71014 .13882 Metetra
0 0 1 r
.02874 .37635 .03814 .38456 .05026 .38012 .0409 .37188 Metetra
0 0 1 r
.0409 .37188 .05026 .38012 .06244 .37567 .05311 .36739 Metetra
0 0 1 r
.05311 .36739 .06244 .37567 .07468 .37119 .06538 .36287 Metetra
0 0 1 r
.06538 .36287 .07468 .37119 .08698 .36669 .07772 .35833 Metetra
0 0 1 r
.07772 .35833 .08698 .36669 .09934 .36217 .09011 .35377 Metetra
0 0 1 r
.09011 .35377 .09934 .36217 .11176 .35763 .10256 .34919 Metetra
0 0 1 r
.10256 .34919 .11176 .35763 .12425 .35307 .11508 .34458 Metetra
0 0 1 r
.11508 .34458 .12425 .35307 .13679 .34848 .12766 .33995 Metetra
0 0 1 r
.12766 .33995 .13679 .34848 .14939 .34387 .1403 .3353 Metetra
0 0 1 r
.1403 .3353 .14939 .34387 .16206 .33924 .153 .33063 Metetra
0 0 1 r
.153 .33063 .16206 .33924 .17479 .33458 .16576 .32593 Metetra
0 0 1 r
.16576 .32593 .17479 .33458 .18758 .32991 .17859 .32121 Metetra
0 0 1 r
.17859 .32121 .18758 .32991 .20044 .32521 .19149 .31646 Metetra
0 0 1 r
.19149 .31646 .20044 .32521 .21336 .32048 .20445 .3117 Metetra
0 0 1 r
.20445 .3117 .21336 .32048 .22635 .31573 .21747 .3069 Metetra
0 0 1 r
.21747 .3069 .22635 .31573 .2394 .31096 .23056 .30209 Metetra
0 0 1 r
.23056 .30209 .2394 .31096 .25251 .30616 .24372 .29724 Metetra
0 0 1 r
.24372 .29724 .25251 .30616 .2657 .30134 .25694 .29238 Metetra
0 0 1 r
.25694 .29238 .2657 .30134 .27895 .2965 .27023 .28749 Metetra
0 0 1 r
.27023 .28749 .27895 .2965 .29226 .29163 .28358 .28257 Metetra
0 0 1 r
.28358 .28257 .29226 .29163 .30565 .28673 .29701 .27763 Metetra
0 0 1 r
.29701 .27763 .30565 .28673 .3191 .28181 .3105 .27267 Metetra
0 0 1 r
.3105 .27267 .3191 .28181 .33262 .27687 .32407 .26767 Metetra
0 0 1 r
.32407 .26767 .33262 .27687 .34621 .2719 .3377 .26266 Metetra
0 0 1 r
.3377 .26266 .34621 .2719 .35987 .2669 .3514 .25762 Metetra
0 0 1 r
.3514 .25762 .35987 .2669 .3736 .26188 .36518 .25255 Metetra
0 0 1 r
.36518 .25255 .3736 .26188 .3874 .25684 .37902 .24745 Metetra
0 0 1 r
.37902 .24745 .3874 .25684 .40128 .25176 .39294 .24233 Metetra
0 0 1 r
.39294 .24233 .40128 .25176 .41522 .24666 .40693 .23718 Metetra
0 0 1 r
.40693 .23718 .41522 .24666 .42924 .24154 .42099 .23201 Metetra
0 0 1 r
.42099 .23201 .42924 .24154 .44333 .23639 .43513 .2268 Metetra
0 0 1 r
.43513 .2268 .44333 .23639 .45749 .23121 .44934 .22157 Metetra
0 0 1 r
.44934 .22157 .45749 .23121 .47173 .226 .46363 .21632 Metetra
0 0 1 r
.46363 .21632 .47173 .226 .48604 .22077 .47799 .21103 Metetra
0 0 1 r
.47799 .21103 .48604 .22077 .50043 .2155 .49243 .20572 Metetra
0 0 1 r
.49243 .20572 .50043 .2155 .5149 .21022 .50694 .20038 Metetra
0 0 1 r
.50694 .20038 .5149 .21022 .52944 .2049 .52153 .19501 Metetra
0 0 1 r
.52153 .19501 .52944 .2049 .54406 .19955 .5362 .18961 Metetra
0 0 1 r
.5362 .18961 .54406 .19955 .55875 .19418 .55095 .18418 Metetra
0 0 1 r
.55095 .18418 .55875 .19418 .57353 .18878 .56578 .17873 Metetra
0 0 1 r
.56578 .17873 .57353 .18878 .58838 .18334 .58068 .17324 Metetra
0 0 1 r
.58068 .17324 .58838 .18334 .60332 .17788 .59567 .16772 Metetra
0 0 1 r
.59567 .16772 .60332 .17788 .61833 .17239 .61074 .16218 Metetra
0 0 1 r
.61074 .16218 .61833 .17239 .63343 .16687 .62589 .1566 Metetra
0 0 1 r
.62589 .1566 .63343 .16687 .6486 .16132 .64112 .151 Metetra
0 0 1 r
.64112 .151 .6486 .16132 .66386 .15574 .65644 .14536 Metetra
0 0 1 r
.65644 .14536 .66386 .15574 .6792 .15013 .67184 .13969 Metetra
0 0 1 r
.67184 .13969 .6792 .15013 .69463 .14449 .68732 .134 Metetra
0 0 1 r
.68732 .134 .69463 .14449 .71014 .13882 .70289 .12827 Metetra
0 0 1 r
.01926 .36808 .02874 .37635 .0409 .37188 .03145 .36357 Metetra
0 0 1 r
.03145 .36357 .0409 .37188 .05311 .36739 .04369 .35903 Metetra
0 0 1 r
.04369 .35903 .05311 .36739 .06538 .36287 .056 .35447 Metetra
0 0 1 r
.056 .35447 .06538 .36287 .07772 .35833 .06836 .3499 Metetra
0 0 1 r
.06836 .3499 .07772 .35833 .09011 .35377 .08079 .34529 Metetra
0 0 1 r
.08079 .34529 .09011 .35377 .10256 .34919 .09328 .34067 Metetra
0 0 1 r
.09328 .34067 .10256 .34919 .11508 .34458 .10583 .33602 Metetra
0 0 1 r
.10583 .33602 .11508 .34458 .12766 .33995 .11844 .33135 Metetra
0 0 1 r
.11844 .33135 .12766 .33995 .1403 .3353 .13112 .32665 Metetra
0 0 1 r
.13112 .32665 .1403 .3353 .153 .33063 .14385 .32194 Metetra
0 0 1 r
.14385 .32194 .153 .33063 .16576 .32593 .15666 .3172 Metetra
0 0 1 r
.15666 .3172 .16576 .32593 .17859 .32121 .16952 .31243 Metetra
0 0 1 r
.16952 .31243 .17859 .32121 .19149 .31646 .18245 .30764 Metetra
0 0 1 r
.18245 .30764 .19149 .31646 .20445 .3117 .19545 .30283 Metetra
0 0 1 r
.19545 .30283 .20445 .3117 .21747 .3069 .20851 .29799 Metetra
0 0 1 r
.20851 .29799 .21747 .3069 .23056 .30209 .22164 .29313 Metetra
0 0 1 r
.22164 .29313 .23056 .30209 .24372 .29724 .23483 .28824 Metetra
0 0 1 r
.23483 .28824 .24372 .29724 .25694 .29238 .24809 .28333 Metetra
0 0 1 r
.24809 .28333 .25694 .29238 .27023 .28749 .26142 .27839 Metetra
0 0 1 r
.26142 .27839 .27023 .28749 .28358 .28257 .27482 .27343 Metetra
0 0 1 r
.27482 .27343 .28358 .28257 .29701 .27763 .28829 .26844 Metetra
0 0 1 r
.28829 .26844 .29701 .27763 .3105 .27267 .30182 .26343 Metetra
0 0 1 r
.30182 .26343 .3105 .27267 .32407 .26767 .31543 .25839 Metetra
0 0 1 r
.31543 .25839 .32407 .26767 .3377 .26266 .3291 .25333 Metetra
0 0 1 r
.3291 .25333 .3377 .26266 .3514 .25762 .34285 .24824 Metetra
0 0 1 r
.34285 .24824 .3514 .25762 .36518 .25255 .35667 .24312 Metetra
0 0 1 r
.35667 .24312 .36518 .25255 .37902 .24745 .37056 .23797 Metetra
0 0 1 r
.37056 .23797 .37902 .24745 .39294 .24233 .38452 .2328 Metetra
0 0 1 r
.38452 .2328 .39294 .24233 .40693 .23718 .39856 .22761 Metetra
0 0 1 r
.39856 .22761 .40693 .23718 .42099 .23201 .41267 .22238 Metetra
0 0 1 r
.41267 .22238 .42099 .23201 .43513 .2268 .42685 .21713 Metetra
0 0 1 r
.42685 .21713 .43513 .2268 .44934 .22157 .44111 .21185 Metetra
0 0 1 r
.44111 .21185 .44934 .22157 .46363 .21632 .45544 .20654 Metetra
0 0 1 r
.45544 .20654 .46363 .21632 .47799 .21103 .46985 .2012 Metetra
0 0 1 r
.46985 .2012 .47799 .21103 .49243 .20572 .48434 .19583 Metetra
0 0 1 r
.48434 .19583 .49243 .20572 .50694 .20038 .4989 .19044 Metetra
0 0 1 r
.4989 .19044 .50694 .20038 .52153 .19501 .51355 .18502 Metetra
0 0 1 r
.51355 .18502 .52153 .19501 .5362 .18961 .52827 .17957 Metetra
0 0 1 r
.52827 .17957 .5362 .18961 .55095 .18418 .54307 .17409 Metetra
0 0 1 r
.54307 .17409 .55095 .18418 .56578 .17873 .55795 .16857 Metetra
0 0 1 r
.55795 .16857 .56578 .17873 .58068 .17324 .57291 .16303 Metetra
0 0 1 r
.57291 .16303 .58068 .17324 .59567 .16772 .58795 .15746 Metetra
0 0 1 r
.58795 .15746 .59567 .16772 .61074 .16218 .60307 .15186 Metetra
0 0 1 r
.60307 .15186 .61074 .16218 .62589 .1566 .61828 .14623 Metetra
0 0 1 r
.61828 .14623 .62589 .1566 .64112 .151 .63356 .14057 Metetra
0 0 1 r
.63356 .14057 .64112 .151 .65644 .14536 .64894 .13488 Metetra
0 0 1 r
.64894 .13488 .65644 .14536 .67184 .13969 .66439 .12915 Metetra
0 0 1 r
.66439 .12915 .67184 .13969 .68732 .134 .67994 .12339 Metetra
0 0 1 r
.67994 .12339 .68732 .134 .70289 .12827 .69556 .11761 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.01)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.02)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.03)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.04)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.05)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06033 .24606 m
.06319 .24877 L
s
.08372 .23691 m
.08655 .23964 L
s
.10732 .22766 m
.11013 .23042 L
s
.13115 .21833 m
.13394 .22111 L
s
.17948 .19941 m
.18222 .20223 L
s
.20399 .18981 m
.2067 .19266 L
s
.22873 .18012 m
.23142 .183 L
s
.25371 .17034 m
.25638 .17324 L
s
.3044 .15049 m
.30701 .15344 L
s
.33011 .14043 m
.3327 .14339 L
s
.35608 .13026 m
.35864 .13325 L
s
.3823 .11999 m
.38483 .12301 L
s
.43553 .09915 m
.43799 .10222 L
s
.46254 .08857 m
.46497 .09167 L
s
.48982 .07789 m
.49222 .08101 L
s
.51738 .0671 m
.51975 .07024 L
s
.57333 .04519 m
.57563 .04838 L
s
.60174 .03407 m
.60401 .03728 L
s
.63044 .02283 m
.63267 .02607 L
s
.65944 .01147 m
.66163 .01474 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00[_ooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000?ooooo0ol0001Nooooo`00[Oooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`1Kooooo`00
[Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool0Foooool00:gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo05_ooooo002]ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
oooooooooooo0000ooooo`04o`0000_ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0
0003ooooo`?o0000?oooool00:gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool0??ooool00:kooooo0_l0000:ooooo`;o00000_ooool5
o`0000;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`0looooo`00c?ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool0??ooool00<cooooo00Co0000oooooooooooo
00002?ooool01Ol0003oooooooooool0003ooooo00Co0000?oooool00<cooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0004;ooooo0031ooooo`;o00002_ooool2
o`0000[ooooo0_l00002ooooo`Go0000?_ooool00;kooooo1Ol0001Mooooo`00_?ooool2o`0000Co
oooo0_l0001Looooo`00^Oooool3o`0000Kooooo00?o0000ooooool00000Foooool008Wooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`?o00006Oooool2o`0000;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooo`00001Kooooo`00R?ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05Oooool3o`0000_ooooo
00Co0000oooooooooooo0000F_ooool008Sooooo00Co0000oooooooooooo00002?ooool01Ol0003o
ooooooooool0003ooooo00Go00004oooool3o`0000kooooo00?o0000ooooooooool00_l0001Ioooo
o`00R?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool00ol0003oooooooooo`0@ooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`05o`000?oo
ooooooooooooool00000FOooool008Sooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooo000000oooooo0ol0000Cooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0E_ooool008Sooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00003ooooo`;o00003Oooool3o`0001Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Eooooo`00ROooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo00So
oooo0ol00003ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Eooooo`00YOooool2o`0001cooooo00?o0000ooooooooool00_ooool2o`0005Kooooo
002Rooooo`Co00007Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Cooooo002P
ooooo`;o00000oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Doooool009gooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0D_ooool009_ooooo0_l000000ooooooo0000ooooo`0Sooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0D_ooool009Sooooo0ol00004ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool01Oooool2o`0005?ooooo002Fooooo`;o0000:oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo053ooooo001Uooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00000oooool3o`0001[ooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0D?ooool006Cooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool05?ooool3o`00033ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1?ooooo`00I?ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool04_ooool3o`0003;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool3o`0002gooooo001Tooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool2o`0001;ooooo0ol00002ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool02Oooool2o`0000cooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo02cooooo001Tooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0=ooooo`;o0000
>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo1Ol00002ooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`05o`0002gooooo001Tooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00[ooooo1?l0000iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0
003oooooooooo`0/ooooo`00IOooool2o`0000[ooooo0_l00003ooooo`?o00002oooool2o`0000?o
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
000002kooooo0021ooooo`?o0000@?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`;o0000;_oo
ool007oooooo0_l00002ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02oooool2
o`0000[ooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`0/ooooo`00O?ooool3o`00
04Gooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00001<ooooo`00N_ooool2o`0004So
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`19ooooo`00Moooool3o`0000;ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Sooooo
001eooooo`;o0000C?ooool2o`00013ooooo00?o0000ooooooooool0B?ooool004?ooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00006_ooool4o`0004_ooooo0_l00000
0ol00?oo0000ooooo`0?ooooo`;o0000BOooool004;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Oooooo0ol0001<ooooo`?o0000
0ol00?l2o`00017ooooo00?o0000ooooooooool0A_ooool004;ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Gooooo0_l0001;ooooo`Co
00000ol00?l00ol0003o003oo`00o`03o`00013ooooo00?o0000ooooooooool0A_ooool004;ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
017ooooo0ol000000ooooooo0000ooooo`17ooooo`?o00000_l00?l00ol0003o003oo`00o`02o`00
o`Co00000_l00?l00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Gooooo0012ooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00kooooo0_l0001;ooooo`;o000000?o003oo`000?l00?l00ol00?l02?l0003o003oo`00
0?l0003o003oo`000?l00?oo00000_l00?l2o`0000oooooo00?o0000ooooooooool0AOooool004;o
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool02oooool3o`0004[ooooo0ol00004o`00o`03o`000?l00?oo003o00?o00001?l0
0?l4o`000003o`00ool0003ooooo00kooooo0_l00016ooooo`00@oooool2o`0000[ooooo0_l00003
ooooo`?o00003?ooool2o`0000?ooooo00?o0000ooooooooool0A?ooool3o`0000;o003o00?o0000
o`00ool00?l00_l00?l3o`0000?o003o00?o0000o`00ool00?l00ol00004o`00o`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0@oooool0063ooooo0ol0001:ooooo`;o000000?o003oo`00
0?l00?l00ol00?l01_l0003o003oo`000?l0003o003oo`0000Co003o0ol00002o`00o`04o`000?l0
0?oo003oo`00o`;o00004?ooool00ol0003oooooooooo`13ooooo`00G_ooool2o`000003ooooool0
003ooooo04Sooooo0_l00004o`00o`03o`000?l00?oo003o00?o00001?l00?l01_l0003o003oo`00
0?l0003o003oo`0000?o003o1?l000000ol00?oo0000ooooo`0@ooooo`03o`000?oooooooooo04;o
oooo001Kooooo`?o0000B_ooool3o`0000;o003o00?o0000o`00ool00?l01?l00003o`00o`03o`00
0?l00?oo003o00?o00001?l00?l00ol0003o003oo`00o`02o`0000Co003o00?o0000ooooooooool0
3oooool00ol0003oooooooooo`11ooooo`00FOooool2o`0004_ooooo0_l000000ol00?oo0000o`00
o`02o`00o`?o00000_l00?l00ol0003o003oo`00o`02o`00o`?o00000ol00?l00ol0003o003oo`00
o`04o`000003o`00ool0003o000000;o003o0ol0000?ooooo`;o0000@oooool005Kooooo0ol00002
ooooo`03o`000?oooooooooo04Gooooo0ol00004o`00o`05o`000?l00?oo0000o`00ool000001?l0
0?l01_l0003o003oo`000?l0003o003oo`0000Co003o0ol00002o`00o`03o`000?l00?oo003o00Co
00000ol00?l00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo043ooooo000Sooooo`;o0000
1?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0001gooooo0_l00019ooooo`Co0000
0ol00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00004o`00o`06o`00
0?l00?oo0000o`000?l00?oo00001?l00?l3o`000003o`00ool0003o003o00?o003o0_l0000@oooo
o`03o`000?oooooooooo03oooooo000Rooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`0Iooooo`?o000000?oooooo`000?ooool0AOooool3
o`0000;o003o00?o0000o`00ool00?l00_l00?l3o`0000;o003o00?o0000o`00ool00?l01?l00003
o`00o`03o`000?l00?oo003o00?o00001?l00?l00ol0003o003oo`00o`02o`000006o`00ool0003o
003oo`00ool0003o003o0_l000000ol00?oo0000ooooo`0?ooooo`03o`000?oooooooooo00cooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00007oooool002;ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Ko
oooo0ol00019ooooo`;o000000?o003oo`000?l00?l00ol00?l01_l0003o003oo`000?l0003o003o
o`0000?o003o0ol00002o`00o`03o`000?l00?oo003o00;o003o0ol00003o`00o`03o`000?l00?oo
003o00Co00000_l00?l2o`000004o`00ool0003o0000o`0000Co003o00?o0000ooooooooool03Ooo
ool2o`0000cooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool07?ooool002;ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo01Cooooo0ol00019ooooo`;o00001?l00?l0
0ol0003o003oo`00o`03o`0000Co003o00Go0000o`00ool0003o003oo`000004o`00o`06o`000?l0
0?oo0000o`000?l00?oo00001?l00?l3o`0000;o003o00Co0000o`00ool00?oo003o0ol00003o`00
o`03o`000?l00?oo003o00?o00004?ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool07?oo
ool002;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo017ooooo0ol00002ooooo`03o`000?oooooooooo04Cooooo0ol00002o`00o`03o`00
0?l00?oo003o00Co00000ol00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l0
0ol00004o`00o`06o`000?l00?oo0000o`000?l00?oo00001?l00?l3o`000003o`00ool0003o003o
00?o003o0ol00002o`00o`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000Oooooo`008_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0_l0000Aooooo`;o0000
B_ooool2o`000003o`00ool0003o003o00;o003o0ol00002o`00o`03o`000?l00?oo003o00;o003o
0ol00003o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000Co003o
00?o0000o`00ool00?l00_l00003o`00o`;o000000Go003oo`000?l0003o003oo`000003o`00o`;o
00004?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`0Looooo`008oooool2o`0000[ooooo0_l00004oooo
o`03o`000?oooooooooo00cooooo0ol000000ooooooo0000ooooo`16ooooo`?o00001?l00?l01Ol0
003o003oo`000?l00?oo000000Co003o00Ko0000o`00ool0003o0000o`00ool00004o`00o`?o0000
0_l00?l00ol0003o003oo`00o`04o`0000?o003o00?o0000o`00ool00?l01?l00002o`00o`03o`00
0?l00?oo003o00?o00001?l00?l01Ol0003o003oo`000?l00?oo0000017ooooo00?o0000oooooooo
ool01oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooooooo`0Looooo`00@_ooool2o`0004Wooooo0ol00003o`00o`03o`000?l00?oo
003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000Co003o00Ko0000o`00ool0003o0000o`00
ool00003o`00o`?o00000_l00?l00ol0003o003oo`00o`02o`00o`?o00000_l00?l00ol0003o003o
o`00o`05o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?oooooooooo00gooooo
0_l0000:ooooo`;o00002_ooool2o`0000?ooooo0ol0000Oooooo`00?oooool3o`0004Sooooo0ol0
0002o`00o`03o`000?l00?oo003o00Co00000ol00?l00ol0003o003oo`00o`03o`0000?o003o00?o
0000o`00ool00?l00ol00004o`00o`05o`000?l00?oo0000o`00ool000001?l00?l01_l0003o003o
o`000?l0003o003oo`0000?o003o0ol00002o`00o`03o`000?l00?oo000000;o003o0ol00002o`00
o`03o`000?l00?oo003o00?o00004?ooool00ol0003oooooooooo`0jooooo`00?Oooool2o`0000?o
oooo00?o0000ooooooooool0@oooool2o`000003o`00ool0003o003o00;o003o0ol00002o`00o`03
o`000?l00?oo003o00;o003o0ol00002o`00o`03o`000?l00?oo003o00Co00000ol00?l00ol0003o
003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00004o`00o`05o`000?l00?oo0000o`00
ool000001?l00?l4o`000003o`00ool0003o003o00;o003o0ol00003o`00o`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0>Oooool003[ooooo0ol00018ooooo`?o00001?l00?l01Ol0003o
003oo`000?l00?oo000000Co003o00Ko0000o`00ool0003o0000o`00ool00003o`00o`?o00000_l0
0?l00ol0003o003oo`00o`02o`00o`?o00000_l00?l00ol0003o003oo`00o`04o`0000?o003o00?o
0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o00001?l00?l01Ol0003o003oo`00
0?l00?oo000000Co003o0_l0000?ooooo`03o`000?oooooooooo03Wooooo000hooooo`;o00000_oo
ool00ol0003oooooooooo`13ooooo`?o00000ol00?l00ol0003o003oo`00o`03o`0000?o003o00?o
0000o`00ool00?l00ol00004o`00o`05o`000?l00?oo0000o`00ool000001?l00?l01_l0003o003o
o`000?l0003o003oo`0000?o003o0ol00003o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0
003o003oo`00o`04o`0000;o003o0_l00002o`00o`?o00000ol00?l01_l0003o003oo`000?l0003o
003oo`0000oooooo0_l0000jooooo`005oooool2o`0001cooooo0ol00017ooooo`?o00000_l00?l0
0ol0003o003oo`00o`04o`0000?o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo
003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000Co003o00Go0000o`00ool0003o003oo`00
0004o`00o`?o00000_l00?l01?l0003o003oo`00ool00?l3o`0000?o003o00?o0000o`00ool00?l0
1?l00002o`00o`03o`000?l00?oo003o00?o00001?l00?l00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo03Oooooo000Fooooo`04o`000?ooooooooooo`0001Wooooo0ol00017ooooo`;o0000
00?o003oo`000?l00?l00_l00?l3o`0000;o003o00?o0000o`00ool00?l00_l00?l3o`0000;o003o
00?o0000o`00ool00?l01?l00003o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003o
o`00o`03o`0000?o003o00Ko0000o`00ool0003o0000o`00ool00004o`00o`05o`000?l00?oo0000
o`00ool000001?l00?l3o`000003o`00ool0003o000000;o003o1?l00003o`00o`03o`000?l00?oo
003o00?o00003oooool00ol0003oooooooooo`0gooooo`005_ooool01?l0003oooooooooool0000F
ooooo`?o0000B?ooool2o`0000Co003o00?o0000o`00ool000000_l00?l01_l0003o003oo`00ool0
0?oo0000o`00o`;o000000?o003oo`000?l00?l00_l00?l3o`0000;o003o00?o0000o`00ool00?l0
0_l00?l3o`0000;o003o00?o0000o`00ool00?l01?l00003o`00o`03o`000?l00?oo003o00;o0000
1?l00?l00ol0003o003oo`00o`03o`0000?o003o00Ko0000o`00ool0003o0000o`00ool00002o`00
o`Co00000_l00?l00ol0003o003oo`00o`02o`00o`?o00000_l00?l00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo03Kooooo000Fooooo`04o`000?ooooooooooo`0001?ooooo0ol00017oooo
o`Co00000_l00?l00ol0003o003oo`00o`03o`0000Co003o00?o0000o`00ool00?l00_l00004o`00
o`05o`000?l00?oo0000o`00ool000001?l00?l01_l0003o003oo`000?l0003o003oo`0000?o003o
0ol00003o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`04o`0000;o003o
00?o0000o`00ool00?l00ol00004o`00o`05o`000?l00?oo0000o`00ool000001?l00?l01_l0003o
003oo`000?l0003o003oo`0000?o003o0_l0000?ooooo`;o0000=oooool001Kooooo00Co0000oooo
oooooooo00004Oooool2o`0000;ooooo00?o0000ooooooooool0@_ooool3o`0000?o003o00?o0000
o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03
o`0000?o003o00?o0000o`00ool00?l00ol00004o`00o`05o`000?l00?oo0000o`00ool000001?l0
0?l3o`0000;o003o00Co0000o`00ool00?oo003o0ol00003o`00o`03o`000?l00?oo003o00?o0000
0ol00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00004o`00o`?o0000
00?o003oo`000?ooool03_ooool2o`0003Oooooo000Fooooo`04o`000?ooooooooooo`0000kooooo
0ol00017ooooo`;o000000?o003oo`000?l00?l00ol00?l3o`000003o`00ool0003o003o00?o003o
0ol00003o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000?o003o
00?o0000o`00ool00?l00ol00003o`00o`06o`000?l00?oo0000o`000?l00?oo00001?l00?l3o`00
0003o`00ool0003o003o00?o003o0ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l2o`00
0003o`00ool0003o000000;o00000ol00?l00ol0003o003oo`00o`02o`0000Co003o00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0dooooo`005oooool2o`0000gooooo0_l000000ooooooo
0000ooooo`15ooooo`?o00000ol00?l01_l0003o003oo`000?l0003o003oo`0000?o003o00Ko0000
o`00ool0003o0000o`00ool00004o`00o`?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o
00?o0000o`00ool00?l01?l00003o`00o`03o`000?l00?oo003o00;o00001?l00?l00ol0003o003o
o`00o`02o`0000Co003o00Ko0000o`00ool0003o0000o`00ool00003o`00o`?o00000_l00?l01?l0
003o003oo`00ool00?l3o`0000?o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo
003o00?o00003oooool00ol0003oooooooooo`0dooooo`008oooool3o`0004Kooooo1?l00003o`00
o`03o`000?l00?oo003o00;o00001?l00?l00ol0003o003oo`00o`02o`0000Co003o00Ko0000o`00
ool0003o0000o`00ool00003o`00o`?o00000_l00?l01?l0003o003oo`00ool00?l3o`0000?o003o
00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003o
o`00o`03o`0000Co003o00Go0000o`00ool0003o003oo`000004o`00o`05o`000?l00?oo0000o`00
ool000001?l00?l3o`0000;o003o00?o0000o`00ool00?l01?l00003o`00o`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0<oooool0027ooooo1?l00014ooooo`?o00000ol00?l00ol0003o
003oo`00o`04o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o
00001?l00?l01Ol0003o003oo`000?l00?oo000000Co003o00Go0000o`00ool0003o003oo`000004
o`00o`?o00000_l00?l00ol0003o003oo`00o`04o`0000?o003o00?o0000o`00ool00?l00ol00003
o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`03o`000005o`00ool0003o
0000o`000?l00?l00_l000000ol00?oo0000o`00o`02o`00o`?o00000_l00?l00ol0003o003oo`00
o`02o`00o`;o00003_ooool2o`0003Cooooo000Nooooo`?o0000Aoooool01?l0003o003oo`00ool0
0003o`00o`?o00000ol00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol0
0003o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000?o003o00Ko
0000o`00ool0003o0000o`00ool00003o`00o`?o00000_l00?l00ol0003o003oo`00o`02o`00o`?o
00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l01?l000001Ol00?oo
0000o`000?l0003o003o00?o00001?l00?l01Ol0003o003oo`000?l00?oo000000Co003o00Ko0000
o`00ool0003o0000o`00ool0000?ooooo`03o`000?oooooooooo03;ooooo000Mooooo`;o0000A_oo
ool3o`0000Co003o00Go0000o`00ool0003o003oo`000004o`00o`?o00000_l00?l00ol0003o003o
o`00o`04o`0000;o003o00?o0000o`00ool00?l01?l00003o`00o`03o`000?l00?oo003o00?o0000
0ol00?l00ol0003o003oo`00o`02o`0000Co003o00Go0000o`00ool0003o003oo`000004o`00o`06
o`000?l00?oo0000o`000?l00?oo00000ol00?l3o`0000?o003o00?o0000o`00ool00?l00ol00002
o`00o`?o000000So003oo`000?l0003o0000o`00ool0003o003oo`0000;o003o0ol00003o`00o`03
o`000?l00?oo003o00?o00001?l00?l00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo037o
oooo000Mooooo`?o0000@_ooool3o`0000?o003o00?o0000o`00ool00?l00ol00003o`00o`06o`00
0?l00?oo0000o`000?l00?oo00000ol00?l3o`0000;o003o00Co0000o`00ool00?oo003o0ol00003
o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000
o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o00001?l00?l3o`000003o`00ool0003o
003o00?o003o0ol00002o`00o`Oo00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000
o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o00004?ooool00ol0003oooooooooo`0<
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000oooooo000Eoooo
o`?o00001Oooool01?l0003oooooooooool0000nooooo`?o00000ol00?l00ol0003o003oo`00o`03
o`0000?o003o00?o0000o`00ool00?l00_l00004o`00o`05o`000?l00?oo0000o`00ool000001?l0
0?l01Ol0003o003oo`000?l00?oo000000Co003o0ol00003o`00o`03o`000?l00?oo003o00?o0000
0ol00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00003o`00o`03o`00
0?l00?oo003o00;o00001?l00?l01Ol0003o003oo`000?l0003o003o00Oo00000_l00?l01?l0003o
003oo`00ool00?l3o`000004o`00ool0003o003oo`0000;o003o0ol00003o`00o`03o`000?l00?oo
003o00?o00000ol00?l00ol0003oooooooooo`0=ooooo`;o00003?ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00003oooool001Kooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000003[ooooo0ol00002o`00o`03
o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool0
0?l00ol00003o`00o`03o`000?l00?oo003o00?o00000ol00?l01_l0003o003oo`000?l0003o003o
o`0000Co003o0ol000000ol00?oo0000o`00o`03o`00o`?o00000_l00?l00ol0003o003oo`00o`04
o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o000000?o003o
o`000?l000001?l000000ol00?oo0000o`00o`03o`00o`05o`000?l00?oo0000o`00ool000000_l0
0?l00ol0003o003oo`000002o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l0
0?oo003o00?o00003oooool00ol0003oooooooooo`03ooooo`Go00000_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03oooool000kooooo
1Ol00003ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo03Gooooo
0_l000000ol00?oo0000o`00o`02o`00o`?o00000ol00?l00ol0003o003oo`00o`03o`0000?o003o
00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003o
o`00o`03o`0000?o003o00Ko0000o`00ool0003o0000o`00ool00003o`00o`06o`000?l00?oo0000
o`000?l00?oo00000ol00?l3o`0000?o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l0
0?oo003o00?o000000Co003oo`000?l0003o00000_l00?l2o`0000Co003o00?o0000o`00ool00?l0
0ol00003o`00o`06o`000?l00?oo0000o`000?l00?oo00000ol00?l3o`0000;o003o00?o0000o`00
ool00?l01?l00002o`00o`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03_oo
ool001Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03;ooooo0_l00004o`00o`05o`000?l00?oo0000o`00ool000001?l00?l3o`000003o`00ool0
003o003o00?o003o0ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00
o`04o`0000?o003o00?o0000o`00ool00?l00_l00004o`00o`03o`000?l00?oo003o00;o00001?l0
0?l01Ol0003o003oo`000?l00?oo000000Co003o0ol00002o`00o`03o`000?l00?oo003o00Co0000
00Go003oo`000?l0003o0000o`00o`04o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03
o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`000002o`000003o`00ool0003o003o00;o
003o0ol00002o`00o`04o`000?l00?oo003oo`00o`;o00003oooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00gooooo000Fooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`03o`000?oo
oooooooo02gooooo1?l00002o`00o`03o`000?l00?oo003o00?o00000ol00?l01_l0003o003oo`00
0?l0003o003oo`0000?o003o00Ko0000o`00ool0003o0000o`00ool00003o`00o`?o00000ol00?l0
0ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo
003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00Ko0000o`00ool0003o0000o`00
ool00003o`00o`?o00000_l00?l3o`000004o`00ool0003o0000o`0000?o003o00?o0000o`00ool0
0?l00ol00003o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`000002o`0000Co
003o00Go0000o`00ool0003o003oo`000004o`00o`05o`000?l00?oo0000o`00ool000004?ooool0
0ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00gooooo000Eooooo`;o00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02Wooooo0ol00003o`00o`03o`000?l00?oo003o00?o0000
0ol00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00003o`00o`03o`00
0?l00?oo000000;o003o00Co0000o`00ool00?oo003o0ol00003o`00o`03o`000?l00?oo003o00?o
00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00003o`00o`03
o`000?l00?oo003o00;o00001?l00?l01?l0003o003oo`000?l00?l4o`000006o`00ool0003o003o
o`000?l00?oo00001?l00?l3o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l0
0?oo003o00Go000000Co003oo`000?l00?oo003o0ol00003o`00o`03o`000?l00?oo003o00?o0000
0ol00?l00ol0003oooooooooo`0<ooooo`03o`000?oooooo000000[ooooo0_l0000:ooooo`;o0000
0oooool3o`00013ooooo000Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Uooooo`?o00000ol00?l00ol0003o003oo`00o`03o`0000?o003o00?o
0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00
o`02o`0000Co003o00Go0000o`00ool0003o003oo`000004o`00o`?o000000?o003oo`000?l00?l0
0ol00?l3o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00Co0000
0_l00?l00ol0003o003oo`00o`07o`0000;o003o0ol00003o`00o`06o`000?l00?oo0000o`000?l0
0?oo00000ol00?l3o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o
00Co00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol0000?oooo
o`03o`000?oooooooooo02cooooo000Kooooo`;o00002_ooool00ol0003oooooooooo`0Sooooo`03
o`000?l00?oo000000Co003o0ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o
003oo`00o`04o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o
00000ol00?l01_l0003o003oo`000?l0003o003oo`0000?o003o00Ko0000o`00ool0003o0000o`00
ool00003o`00o`?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l0
1ol00002o`00o`Co00000_l00?l00ol0003o003oo`00o`03o`0000Co003o0ol000000ol00?oo0000
o`00o`02o`00o`?o00000ol00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`0000;o
003o0ol00003o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02_ooooo000Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
7oooool3o`0000?o003o00Ko0000o`00ool0003o0000o`00ool00003o`00o`?o00000ol00?l00ol0
003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o
00?o00000ol00?l00ol0003o003oo`00o`02o`0000Co003o00?o0000o`00ool00?l00_l00004o`00
o`?o000000?o003oo`000?l00?l00_l00?l3o`0000?o003o00?o0000o`00ool00?l00ol00002o`00
o`;o00000_l00?l3o`0000?o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o
00;o00001?l00?l01Ol0003o003oo`000?l00?oo000000Co003o0ol00002o`00o`03o`000?l00?oo
000000Co00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol0000>
ooooo`;o0000;?ooool001_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Koooo
o`?o00000ol00?l00ol0003o003oo`00o`03o`0000?o003o00Go0000o`00ool0003o003oo`000004
o`00o`?o000000?o003oo`000?l00?l00ol00?l3o`0000;o003o00?o0000o`00ool00?l01?l00002
o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000
o`00ool00?l00_l00004o`00o`05o`000?l00?oo0000o`00ool000001?l00?l3o`0000;o003o1ol0
0002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o
0000o`00ool00?l00ol00003o`00o`06o`000?l00?oo0000o`000?l00?oo00000ol00?l4o`000003
o`00ool0003o003o00;o003o0ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02[ooooo000Kooooo`;o00003Oooool00ol0003ooooo
ooooo`0Gooooo`?o00000ol00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l0
0_l00003o`00o`06o`000?l00?oo0000o`000?l00?oo00000ol00?l01_l0003o003oo`000?l0003o
003oo`0000?o003o0ol00003o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00
o`03o`0000?o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000ol0
0?l01Ol0003o003oo`000?l0003o003o00Oo00000ol00?l00ol0003o003oo`00o`03o`0000?o003o
00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003o
o`00o`03o`0000Co003o0ol000001_l00?oo0000o`00ool00?oo0000o`00o`?o000000?o003oo`00
0?l00?l00_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol0000?ooooo`03o`000?oooooooooo
02Wooooo000Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool3o`0000;o
003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o
003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00_l00004o`00o`05o`000?l00?oo0000o`00
ool000001?l00?l3o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o
00Co00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00_l000000ol0
0?oo0000o`000002o`000004o`00ool0003o003oo`0000Co003o0ol00002o`00o`03o`000?l00?oo
003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00003
o`00o`03o`000?l00?oo003o00;o00001?l00?l00ol0003o003oo`00o`02o`0000Co003o00Go0000
o`00ool0003o003oo`000003o`00o`?o00000ol00?l00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02Wooooo000Kooooo`;o00003oooool2o`00013ooooo0ol000000ol00?oo0000o`00o`02
o`00o`?o00000ol00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00003
o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00Ko0000
o`00ool0003o0000o`00ool00003o`00o`?o00000ol00?l00ol0003o003oo`00o`03o`0000?o003o
00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Oo00000_l00?l3o`0000?o003o
00Ko0000o`00ool0003o0000o`00ool00003o`00o`?o00000_l00?l01?l0003o003oo`00ool00?l3
o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00Co00000_l00?l0
0ol0003o003oo`00o`05o`000004o`00ool0003o003oo`00o`?o00000ol00?l01Ol0003o003oo`00
0?l00?oo000000Co003o0_l0000>ooooo`;o0000:Oooool001_ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0;ooooo`;o000000?o003oo`000?l00?l00_l00?l00ol0003o003oo`00
0002o`00o`04o`000?l00?oo003oo`00o`?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o
00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003o
o`00o`02o`0000Co003o00Go0000o`00ool0003o003oo`000004o`00o`?o00000_l00?l00ol0003o
003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol000001?l00?oo0000o`000?l00002o`00
o`?o00000ol00?l00ol0003o003oo`00o`02o`0000Co003o0ol000000ol00?oo0000o`00o`03o`00
o`?o000000?o003oo`000?l00?l00_l00?l3o`0000?o003o00?o0000o`00ool00?l00ol00002o`00
o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00
ool00?l00ol00003o`00o`06o`000?l00?oo0000o`000?l00?oo00003oooool00ol0003ooooooooo
o`0Wooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`08ooooo`?o00000ol00?l00ol0003o003oo`00o`02
o`0000Co003o00Go0000o`00ool0003o003oo`000003o`00o`?o00000ol00?l00ol0003o003oo`00
o`03o`0000?o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o00000_l0
0?l00ol0003o003oo`00o`03o`0000?o003o00Ko0000o`00ool0003o0000o`00ool00003o`00o`?o
00000_l00?l00ol0003o003oo`00o`04o`000005o`00ool0003o0000o`000?l00?l01?l00002o`00
o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`02o`0000Co003o00?o0000o`00
ool00?l00_l00004o`00o`05o`000?l00?oo0000o`00ool000001?l00?l3o`0000;o003o00?o0000
o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo00000_l0
0?l3o`0000;o003o00?o0000o`00ool00?l00ol00004o`00o`03o`000?oooooooooo00cooooo00?o
0000ooooooooool09oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000?ooooo0_l0000Dooooo`03o`000?oooooooooo00Cooooo0ol00003o`00o`03o`00
0?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00000
0_l00?l01?l0003o003oo`00ool00?l3o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03
o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool0
0?l00_l00004o`00o`05o`000?l00?oo0000o`00ool000000ol00?l3o`0000;o003o0ol000001?l0
0?oo0000o`000?l00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04
o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o00000ol00?l0
1_l0003o003oo`000?l0003o003oo`0000?o003o0ol00002o`00o`03o`000?l00?oo003o00Co0000
0_l00?l00ol0003o003oo`000004o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`00
0?l00?oo003o00;o00003oooool00ol0003oooooooooo`0Vooooo`001Ol00002ooooo`04o`000?oo
ooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00?o
00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03
o`000?l00?oo003o00;o00001?l00?l01Ol0003o003oo`000?l00?oo000000?o003o0ol00003o`00
o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00
ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o00000ol00?l01?l0003o003oo`000?l00?l4
o`000004o`00ool0003o0000o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l0
0?oo003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00?o00001?l00?l3o`000003o`00ool0003o003o00;o003o0ol0
0002o`00o`03o`000?l00?oo003o00Go000000Co003oo`000?l00?oo003o1?l00002o`00o`03o`00
0?l00?oo003o00Co00000_l00?l00ol0003oooooooooo`0<ooooo`;o00009oooool000Oooooo00Co
0000oooooooooooo00002oooool01Ol0003ooooooooooooooooo000001Gooooo1?l00002o`00o`03
o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool0
0?l00ol00002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`000002o`00o`04
o`000?l00?oo003oo`00o`?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00
ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`06o`00
0005o`00ool0003o0000o`00ool000000ol00?l3o`0000?o003o00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000
o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00;o00001?l00?l3o`000003o`00ool0003o
003o00;o003o0ol00003o`00o`03o`000?l00?oo000000?o00000_l00?l00ol0003o003oo`00o`04
o`0000;o003o00?o0000o`00ool00?l00ol0000>ooooo`03o`000?oooooooooo02Gooooo0007oooo
o`04o`000?ooooooooooo`0000Oooooo1?l00004ooooo`;o00004Oooool3o`0000?o003o00?o0000
o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04
o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00;o00001?l00?l0
1Ol0003o003oo`000?l00?oo000000?o003o0ol00003o`00o`03o`000?l00?oo003o00?o00000_l0
0?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l01ol00002o`00o`;o00001?l0
0?l01Ol0003o003oo`000?l00?oo000000Co003o0ol00002o`00o`03o`000?l00?oo003o00?o0000
0ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`00
0?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`02o`0000Co003o00Go0000o`00ool0003o
003oo`000004o`00o`Co000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o
00Co00000_l00?l00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Cooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?oooo
o`04o`000?l00?oo003oo`0000?o003o0ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l0
0ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo
003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00Go0000o`00ool0003o003oo`00
0004o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l01ol0
0002o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00Ko0000o`00ool0003o0000
o`00ool00003o`00o`?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool0
0?l00ol00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o
003o00?o0000o`00ool00?l00ol00003o`00o`09o`000?l00?oo0000o`000?l00?oo0000o`00ool0
003o003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00_l0
000?ooooo`03o`000?oooooooooo00cooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0
0003ooooo`?o00000oooool000Sooooo0_l00008ooooo`Go00000oooool00ol0003oooooooooo`0=
ooooo`?o00000ol00?l01Ol0003o003oo`000?l00?oo000000?o003o0ol00003o`00o`03o`000?l0
0?oo003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l0
0002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`02o`0000?o003o00Ko
0000o`00ool0003o0000o`00ool00003o`00o`?o00000_l00?l00ol0003o003oo`00o`04o`000003
o`00ool0003o000000;o003o1?l00002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o
003oo`00o`02o`0000Co003o0ol000000ol00?oo0000o`00o`02o`00o`?o00000_l00?l00ol0003o
003oo`00o`04o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o
00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00004o`00o`?o
000000?o003oo`000?l00?l00_l00?l3o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03
o`000?oooooooooo00cooooo0_l0000<ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`02ooooo`006Oooool2o`0000cooooo0ol00003o`00
o`03o`000?l00?oo003o00;o00000ol00?l00ol0003o003oo`000002o`00o`04o`000?l00?oo003o
o`00o`?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00003
o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000
o`00ool00?l00_l00004o`00o`05o`000?l00?oo0000o`00ool000000ol00?l3o`0000;o003o0ol0
00001?l00?oo0000o`000?l00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003o
o`00o`04o`0000;o003o00?o0000o`00ool00?l00_l00004o`00o`05o`000?l00?oo0000o`00ool0
00000ol00?l3o`0000?o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co
00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03
o`000?l00?oo003o00;o00000_l00?l00ol0003o003oo`000002o`000003o`00ool0003o003o00;o
003o0ol00002o`00o`03o`000?l00?oo003o00?o00003_ooool00ol0003oooooooooo`03ooooo`Go
00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00_ooool001Wooooo00?o0000ooooooooool02?ooool3o`0000;o003o00?o0000o`00
ool00?l01?l00002o`00o`03o`000?l00?oo003o00;o00001?l00?l01Ol0003o003oo`000?l00?oo
000000?o003o0ol00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04
o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o00000_l00?l0
0ol0003o003oo`00o`03o`0000?o003o00Co0000o`00ool0003o003o1?l000001?l00?oo0000o`00
0?l00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000?o003o
00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000ol00?l01Ol0003o003o
o`000?l00?oo000000Co003o0ol00002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o
003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00Co
00000_l00?l00ol0003o003oo`00o`02o`0000Co003o0ol000000ol00?oo0000o`00o`02o`00o`?o
00000_l00?l00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo000Ioooo
o`;o00001_ooool3o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o
00?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool000000_l00?l01?l0
003o003oo`00ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo
003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00003
o`00o`03o`000?l00?oo003o00Ko000000?o003oo`000?l000000_l00?l00ol0003o003oo`00o`03
o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00Co00000_l00?l0
0ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`06o`000?l00?oo
0000o`000?l00?oo00000ol00?l3o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`00
0?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l0
1Ol000001?l00?oo0000o`00ool00?l2o`0000Co003o00?o0000o`00ool000000_l00?l00ol0003o
003oo`00o`02o`0000kooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool001Wooooo00?o0000oooo
ooooool00_ooool3o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o
00?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00_l00004o`00
o`05o`000?l00?oo0000o`00ool000000ol00?l3o`0000?o003o00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000
o`00ool00?l01_l00002o`00o`;o00001?l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00003
o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000
o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00;o00001?l00?l3o`000003o`00ool0003o
003o00;o003o0ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03
o`0000?o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l0
0ol0003o003oo`00o`03o`0000?o003o0ol00002o`00o`03o`000?oooooooooo00_ooooo0_l0000:
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Cooooo
000Iooooo`03o`000?oooooo000000;o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00
o`03o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`05o`000?l00?oo0000o`00ool00000
1?l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`00o`07o`0000;o003o0ol00002o`00o`06o`000?l00?oo0000o`000?l0
0?oo00000ol00?l3o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o
00?o00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00
o`03o`000?l00?oo003o00;o00001?l00?l01Ol0003o003oo`000?l00?oo000000?o003o0ol00002
o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000
o`00ool00?l00ol000000ol00?oo0000o`000002o`00o`Co00000_l00?l01_l0003o003oo`000?l0
003o003oo`0000?o003o0_l0000>ooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`006Oooool2o`000003o`00ool0003o003o00;o003o0ol0
0002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00
o`02o`0000?o003o00Co0000o`00ool0003o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00Oo00000_l00?l3o`0000;o003o
00?o0000o`00ool00?l00_l00004o`00o`05o`000?l00?oo0000o`00ool000000ol00?l3o`0000?o
003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o
003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o
00000ol00?l00ol0003o003oo`000002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o
003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo000000?o
00000_l00?l00ol0003o003oo`00o`03o`0000Co003o0ol000000ol00?oo0000ooooo`0=ooooo`03
o`000?oooooooooo01oooooo000Aooooo`;o00001Oooool2o`0000?o003o00Go0000o`00ool0003o
003oo`000003o`00o`?o00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool0
0?l01?l00002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000;o
003o00?o0000o`00ool00?l00ol00003o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000?o
003o00?o0000o`00ool00?l01_l00002o`00o`Co00000_l00?l00ol0003o003oo`00o`03o`0000;o
003o00?o0000o`00ool00?l00ol00003o`00o`05o`000?l00?oo0000o`00ool000001?l00?l3o`00
00;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0
003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o
00?o00000ol00?l3o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o
00?o00000_l00?l00ol0003o003oo`00o`05o`000004o`00ool0003o003oo`00o`?o00000ol00?l0
0ol0003o003oo`00o`02o`0000Co003o00?o0000ooooooooool03?ooool00ol0003oooooooooo`0N
ooooo`004?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000;o003o0_l00003
o`00o`03o`000?l00?oo000000?o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo
003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002
o`00o`03o`000?l00?oo003o00?o00000ol00?l01Ol0003o003oo`000?l00?oo000000?o003o0ol0
0002o`00o`03o`000?l00?oo003o00Oo00000_l00?l3o`0000?o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`02o`0000?o003o00Ko
0000o`00ool0003o0000o`00ool00002o`00o`Co00000_l00?l00ol0003o003oo`00o`03o`0000?o
003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o
003oo`00o`03o`0000;o003o00Ko0000o`00ool0003o0000o`00ool00003o`00o`?o00000_l00?l0
0ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo
003o00Co00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00_l0000>
ooooo`;o00007oooool0013ooooo00Co0000oooooooooooo00001?ooool2o`000003ooooool0003o
000000;o003o00?o0000o`00ool00?l00ol00003o`00o`?o00000_l00?l00ol0003o003oo`00o`03
o`0000?o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000ol00?l0
0ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`05o`000?l00?oo
0000o`00ool000000ol00?l3o`000004o`00ool0003o0000o`0000;o003o0ol00002o`00o`03o`00
0?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l0
1?l00002o`00o`03o`000?l00?oo003o00;o00000ol00?l3o`0000?o003o00?o0000o`00ool00?l0
0ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00;o00001?l00?l01Ol0003o003o
o`000?l00?oo000000?o003o0ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o
003oo`00o`03o`000003o`00ool0003o000000;o003o1?l00002o`00o`03o`000?l00?oo003o00Co
00000_l00?l00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo000@ooooo`04o`00
0?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000002o`00o`?o00000ol00?l01Ol0
003o003oo`000?l00?oo000000?o003o0ol00003o`00o`03o`000?l00?oo003o00?o00000_l00?l0
0ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo
003o00?o00000ol00?l00ol0003o003oo`00o`02o`0000?o003o00Co0000o`00ool0003o003o0ol0
00000ol00?oo0000o`000002o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l0
0?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol0
0002o`00o`05o`000?l00?oo0000o`00ool000001?l00?l3o`0000;o003o00?o0000o`00ool00?l0
0ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000?o003o
00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003o
o`000002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o
00?o0000o`00ool000000ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003o
o`00o`03o`0000kooooo00?o0000ooooooooool07?ooool0013ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`02ooooo`;o00000ol00?l00ol0003o003oo`00o`02o`0000?o003o
00?o0000o`00ool000000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l0
0ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00Co000000Co003oo`000?l0003o
00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03
o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool0
0?l00_l00003o`00o`04o`000?l00?oo0000o`0000;o003o00?o0000o`00ool00?l00ol00002o`00
o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00
ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`00
00?o003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`05o`00
0004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Kooooo`004?ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Cooooo00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo
003o00;o00001?l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo
003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00003
o`00o`03o`000?l00?oo003o00Co000000Co003oo`000?l00?oo00000_l00?l01?l0003o003oo`00
ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`00
0?l00?oo003o00;o00001?l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`00
0?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l0
1?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l01_l0003o003oo`000?l0003o003oo`00
00?o003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`00
00;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00003Oooool2o`00
01gooooo000Aooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`;o00000_l00?l00ol0003o
003oo`00o`03o`0000;o003o00Ko0000o`00ool0003o0000o`00ool00003o`00o`?o00000_l00?l0
0ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo
003o00?o00000ol00?l00ol0003o003oo`00o`04o`000004o`00ool0003o003oo`00o`;o00001?l0
0?l00ol0003o003oo`000002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`04o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000ol0
0?l00ol0003o003oo`00o`03o`0000;o003o00Ko0000o`00ool0003o0000o`00ool00003o`00o`?o
00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03
o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool0
0?l00_l00004o`00o`?o000000Co003oo`000?l00?oo003o1?l00002o`00o`03o`000?l00?oo003o
00?o000000?o003oo`000?l000000_l00?l4o`0000;o003o00?o0000o`00ool00?l00ol00002o`00
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool001Sooooo00?o0000oooooooo
ool01_ooool00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03
o`000?l00?oo000000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o
00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01ol00002o`00o`?o
00000_l00?l00ol0003o003oo`00o`03o`0000?o003o0ol00002o`00o`03o`000?l00?oo003o00?o
00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03
o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`02o`0000Co003o0ol000001?l00?oo
0000o`00ool00?l4o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o
00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00
o`03o`000?l00?oo003o00;o00000ol00?l3o`0000;o003o00?o0000o`00ool00?l01?l00002o`00
o`03o`000?l00?oo000000?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00
ool00?l00_l0000>ooooo`03o`000?oooooooooo01[ooooo000Gooooo`;o00002Oooool2o`0000;o
003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00;o00000ol00?l3o`0000;o
003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o
003oo`00o`07o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o
003oo`000002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000?o
003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o
003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00_l00003o`00o`?o00000ol00?l00ol0003o
003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co
00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03
o`000?l00?oo000000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Go
000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0
003oooooooooo`0<ooooo`;o00006_ooool001Oooooo00?o0000ooooooooool02Oooool00ol0003o
003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo000000;o
003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o
003oo`00o`07o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o
003oo`00o`03o`0000?o003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o
003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co
00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool000000_l00?l00ol0003o
003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o
00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03
o`000?l00?oo003o00?o00000ol00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03
o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool0
0?l00ol0000>ooooo`03o`000?oooooooooo01Sooooo000Gooooo`03o`000?oooooooooo00[ooooo
0_l00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`02o`0000?o003o
0ol00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`06o`0000;o003o
1?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o
00?o0000o`00ool000000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l0
0ol00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00;o00000ol00?l3o`0000;o003o
00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003o
o`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o0000
0_l00?l01_l0003o003oo`000?l0003o003oo`0000;o003o1?l00002o`00o`03o`000?l00?oo003o
00Co000000Co003oo`000?l00?oo003o1?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`005oooool2o`00
00gooooo00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0
003o003oo`000003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`06o`00
00;o003o0ol00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`00
00;o003o00?o0000o`00ool00?l00ol00003o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`00
00;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0
003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo0000
00;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0
003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o
00?o00000_l00?l00ol0003o003oo`00o`02o`0000?o003o0ol00002o`00o`03o`000?l00?oo003o
00Co00000_l00?l00ol0003o003oo`000003o`0000;o003o00?o0000o`00ool00?l01?l00002o`00
o`03o`000?l00?oo003o00;o00003_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`0000oooooo000Gooooo`03o`000?oooooooooo00gooooo0_l00002o`00o`03o`000?l00?oo003o
00?o00000_l00?l00ol0003o003oo`00o`02o`0000Co003o0ol00002o`00o`03o`000?l00?oo003o
00Ko00000_l00?l3o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o
00?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool000000_l00?l00ol0
003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o
00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00003o`00
o`03o`000?l00?oo003o00;o00000ol00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00
o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00
ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`000002o`00
o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`05o`000004o`00ool0003o003o
o`00o`?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000ooooooooool02oooool2
o`0000Gooooo00Co0000oooooooooooo00003oooool001Oooooo0_l0000?ooooo`03o`000?l00?oo
003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00Co0000o`00ool0003o00000_l0
0?l00ol0003o003oo`00o`06o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00?o00000ol0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l0
0?oo003o00?o00000ol00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l0
0?oo003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`000002o`00o`03o`000?l0
0?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o
0000o`00ool00?l00_l00003o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`0000gooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000?ooooo`005_oo
ool2o`00017ooooo0_l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`0000?o003o1_l00002o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`0000?o003o00?o0000o`00ool000000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000ol0
0?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l0
0?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l0
0?oo003o00Co00000_l00?l01Ol0003o003oo`000?l00?oo000000;o003o1?l00002o`00o`03o`00
0?l00?oo003o00Co000000Co003oo`000?l00?oo003o1?l00002o`00o`03o`000?l00?oo003o00?o
00000_l00?l00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00003oooool000?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo017ooooo00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o
00000ol00?l00ol0003o003oo`000003o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00?o
00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03
o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o0ol00002o`00o`03
o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool0
0?l01?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o
003o00Ko0000o`00ool0003o0000o`00ool00002o`00o`Co00000_l00?l00ol0003o003oo`00o`03
o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l0
0ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`?o00000_l00?l0
0ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool000000ol00002o`00o`03o`000?l00?oo
003o00Co000000Co003oo`000?l00?oo003o0ol0000<ooooo`?o00000oooool01?l0003ooooooooo
ool0000?ooooo`000_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0Booooo`;o00000_l00?l00ol0003o003oo`00o`03o`0000?o
003o00?o0000o`00ool00?l00ol00002o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o
003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o
003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`04o`000?l00?oo0000o`00
00;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0
003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo003o
00?o00000_l00?l00ol0003o003oo`00o`02o`0000?o003o0ol00002o`00o`03o`000?l00?oo003o
00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00
o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00
ool000000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01Ol000001?l0
0?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?oooooo
oooo00Oooooo0ol000000ooooooo0000o`000004ooooo`;o00004?ooool000;ooooo00Co0000oooo
oooooooo00002oooool00ol0003oooooooooo`02ooooo`;o00005?ooool00ol0003o003oo`00o`03
o`0000?o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo000000;o003o00?o0000
o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`03
o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l0
0ol0003o003oo`00o`03o`0000;o003o1?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l0
0ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo
003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool000000_l00?l0
0ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo
003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002
o`00o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo003o00Co000000Co003oo`000?l00?oo003o1?l00002o`00o`03o`000?l0
0?oo003o00;o00001Oooool3o`0000Gooooo00?o0000ooooooooool05?ooool000;ooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo0_l0
0003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o0ol0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o0ol00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`?o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l0
0?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l0
0002o`00o`?o000000Co003oo`000?l00?oo003o1?l00002o`00o`03o`000?l00?oo003o00Co0000
00Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l5o`0000So
oooo00?o0000ooooooooool05?ooool000;ooooo00Co0000oooooooooooo00001oooool4o`0000Go
oooo00?o0000ooooooooool05_ooool00ol0003o003oo`00o`04o`000004o`00ool0003o003oo`00
o`?o00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o
00?o00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00
o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`000002o`00o`03o`000?l00?oo003o
00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00
o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00
ool00?l00ol00002o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00
ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`00
00;o003o00?o0000o`00ool00?l00ol00002o`00o`06o`000?l00?oo0000o`000?l00?oo00000_l0
0?l3o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`000?l00?oo000000?o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol0000;ooooo`03o`000?oo
oooooooo01Cooooo0002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Ooo
ool2o`0001Wooooo0ol000001?l00?oo0000o`00ool00?l3o`0000;o003o0ol00002o`00o`03o`00
0?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l0
1?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
00?o0000o`00ool00?l00ol00002o`00o`?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o
00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003o
o`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`?o00000_l00?l00ol0003o003o
o`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`00
0?l00?oo003o00?o00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`00
0?l00?oo003o00Ko00000_l00?l4o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04oooool000?ooooo0_l00008ooooo`Go00000ooo
ool00ol0003oooooooooo`0Eooooo`?o000000Coooooo`000?l00?oo003o0ol00002o`00o`03o`00
0?l00?oo000000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00002o`00o`03o`00
0?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o0ol00002o`00o`03o`00
0?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l0
0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
00Ko0000o`00ool0003o0000o`00ool00002o`00o`Co000000Co003oo`000?l00?oo003o1?l00002
o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000
o`00ool00?l01?l000001?l00?oo0000o`00ool00?l4o`000003o`00ool0003o000000;o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l0
0?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`000004o`00ool0003o003oo`00o`?o0000
2oooool00ol0003oooooooooo`0Cooooo`005Oooool00ol0003oooooooooo`0Booooo`?o00001Ooo
ool2o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`?o00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l00?oo003o00?o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`?o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l0
0?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o003o00?o
0000o`00ool00?l01?l000001?l00?oo0000o`00ool00?l4o`0000;o003o00?o0000o`00ool00?l0
1?l000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool001Gooooo0_l0000@ooooo`?o0000
2Oooool00ol0003o003oo`00o`03o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l00002o`00o`03o`00
0?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00000
0_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`00
0?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l0
0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o003o00?o0000o`00ool00?l0
0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o
00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003o
o`000002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
00?o0000o`00ool00?l01?l000001?l00?oo0000o`00ool00?l4o`0000;o003o00?o0000o`00ool0
0?l00ol00002o`00o`03o`000?l00?oo003o00?o00002Oooool00ol0003oooooooooo`0Cooooo`00
5Oooool00ol0003oooooooooo`0<ooooo`?o00003Oooool2o`0000;o003o0ol00002o`00o`03o`00
0?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l0
0ol00003o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
00?o0000o`00ool00?l00ol00002o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003o
o`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`?o00000_l00?l00ol0003o003o
o`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`00o`04o`000004o`00ool0003o003oo`00o`Co00000_l00?l00ol0003o
003oo`00o`02o`0000;o003o1?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o
003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol000000ol00?oo0000o`000002o`00o`Co
000000Co003oo`000?l00?oo003o1?l000001?l00?oo0000o`000?l00008ooooo`03o`000?oooooo
oooo01?ooooo000Eooooo`03o`000?oooooooooo00Wooooo0ol0000Booooo`;o00000_l00?l00ol0
003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o
00?o00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00
o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00
o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00
ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co00000_l00?l3o`0000;o003o00?o0000o`00
ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`00
00;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0
003o003oo`00o`04o`000004o`00ool0003o0000o`0000;o003o00?o0000o`00ool00?l01?l00000
1?l00?oo0000o`00ool00?l4o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l0
0?oo000000?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o0ol00002o`00o`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool04oooool001Cooooo0_l00008ooooo`?o00005_ooool0
0ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo
003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000
o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l01_l0003o003oo`000?l0
003o003oo`0000;o003o1?l000001?l00?oo0000o`00ool00?l4o`0000;o003o00?o0000o`00ool0
0?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o
003o00?o0000o`00ool00?l00ol00002o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o
003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co000000Co003oo`000?l0
0?oo003o1Ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00Go0000o`00ool0003o003oo`00
0002o`00o`?o00001oooool00ol0003oooooooooo`0Cooooo`005Oooool00ol0003oooooooooo`03
ooooo`?o00006_ooool2o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo
003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000?o003o00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000
o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03
o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04
o`000004o`00ool0003o003oo`00o`Co00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o00?o0000o`00ool00?l01?l000001?l00?oo0000o`00ool00?l3o`0000;o003o
0ol00002o`00o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool001Cooooo0_l0
0002ooooo`?o00007_ooool00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00?o00000ol00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l0
0?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l01?l000001?l00?oo0000o`00
ool00?l4o`000003o`00ool0003o000000;o000000Co003oo`000?l00?oo003o1?l000001?l00?oo
0000o`00ool00?l4o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o
00?o00000_l00?l00ol0003o003oo`00o`03o`000003o`00ool0003o000000;o003o0ol00002o`00
o`?o00000_l00?l00ol0003o003oo`00o`02o`0000Oooooo00?o0000ooooooooool04_ooool000co
oooo0ol00005ooooo`Co00008_ooool2o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03
o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`04o`0000;o003o00?o0000o`00ool0
0?l00ol00002o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool0
0?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o
003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o
003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o
003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o
00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o
00000_l00?l00ol0003o003oo`00o`04o`000004o`00ool0003o003oo`00o`Co000000Co003oo`00
0?l00?oo003o1?l000001?l00?oo0000o`00ool00?l4o`000003o`00ool0003o000000;o000000Co
003oo`000?l00?oo003o1?l000000ol00?oo0000ooooo`06ooooo`03o`000?oooooooooo01;ooooo
000=ooooo`03o`000?oooooooooo00Cooooo0_l0000Uooooo`03o`000?l00?oo003o00?o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00003o`00o`03o`000?l0
0?oo003o00?o00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l0
0?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o0ol0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol000000ol00?oo0000o`00
0002o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00;o00001_oo
ool00ol0003oooooooooo`0Booooo`003Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02?ooooo0_l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03
o`0000?o003o00?o0000o`00ool00?l00ol00002o`00o`?o00000_l00?l00ol0003o003oo`00o`03
o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l0
0ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo
003o00?o00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo
003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo003o00?o000000?o003oo`000?l000000_l00002o`00o`03o`000?l00?oo
003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000
o`00ool00?l00ol000000ol00?oo0000o`000003o`000004o`00ool0003o003oo`00o`?o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Booooo`003Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000
o`00ool000000_l00003o`00o`03o`000?l00?oo000000;o00000ol00?l00ol0003o003oo`00o`03
o`0000;o003o0ol000001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o003oo`00o`Co0000
00Co003oo`000?l00?oo003o1?l000001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o003o
o`00o`Co000000Co003oo`000?l00?oo003o1?l000000ol00?oo0000o`000002o`000004o`00ool0
003o003oo`00o`Co000000Co003oo`000?l00?oo003o1?l000001?l00?oo0000o`00ool00?l4o`00
0004o`00ool0003o003oo`00o`Co000000Co003oo`000?l00?oo003o1?l000001?l00?oo0000o`00
0?l00002o`00o`03o`000?l00?oo003o00Co000000Co003oo`000?l00?oo003o1?l000001?l00?oo
0000o`00ool00?l4o`000004o`00ool0003o003oo`00o`Co000000Co003oo`000?l00?oo003o1?l0
00001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o0000o`0000;o003o00?o0000o`00ool0
0?l01?l000001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o003oo`00o`?o00001?ooool0
0ol0003oooooooooo`0Booooo`003Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02Cooooo00Go0000o`00ool00?oo003oo`000002o`00o`;o00000ol00?l00ol0003o003oo`00o`03
o`0000;o003o0ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`Ko00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l0
0?l6o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00Co000000Co003oo`000?l00?oo003o
0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01;ooooo000<ooooo`;o00002oooool00ol0003oooooooooo`0Tooooo`03o`000?l0
0?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o0ol000001?l00?oo0000o`00
ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`?o0000
0_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`00
0?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l0
0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o003o00?o0000o`00ool00?l0
0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o003o
00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003o
o`000003o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00;o0000
1?ooool00ol0003oooooooooo`0Aooooo`003Oooool00ol0003oooooooooo`0:ooooo`;o00009Ooo
ool2o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`?o00000_l00?l00ol0003o003oo`00
0002o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`?o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l0
0?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o000000?o003oo`000?l000000_l0
00001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o003oo`00o`Co000000Co003oo`000?l0
0?oo003o1_l00002o`00o`Co000000Co003oo`000?l00?oo003o1?l000000ol00?oo0000ooooo`03
ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo02Cooooo1Ol00002o`00
o`?o00000_l00?l00ol0003o003oo`00o`02o`0000;o003o00?o0000o`00ool00?l00ol00002o`00
o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00
ool00?l00ol00002o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00
ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`00
00;o003o00?o0000o`00ool00?l00ol00002o`00o`Ko00000_l00?l3o`000004o`00ool0003o003o
o`00o`Co000000Co003oo`000?l00?oo003o1?l000001?l00?oo0000o`00ool00?l4o`000004o`00
ool0003o003oo`00o`Co000000Co003oo`000?l00?oo003o1?l000001?l00?oo0000o`000?l00002
o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000
o`00ool00?l00ol00002o`00o`03o`000?l00?oo000000?o00000_l00?l00ol0003o003oo`00o`03
o`000003o`00ool0003o000000Co00000oooool00ol0003oooooooooo`0Aooooo`007Oooool00ol0
003oooooooooo`0Tooooo`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`00
0004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000
o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l3o`0000;o003o00?o0000
o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03
o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o000000?o003o
o`000?l000000_l000001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o003oo`00o`?o0000
0_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`00
0?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o0ol00002o`00o`03o`00
0?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l0
0ol00002o`00o`03o`000?l00?oo003o00Go00000_l00?l4o`000004o`00ool0003o0000o`0000;o
003o00?o0000o`00ool00?l00_l00002ooooo`03o`000?oooooooooo017ooooo000Nooooo`03o`00
0?oooooooooo02Cooooo0_l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003o
o`000002o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o0000
0_l00?l6o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003o
o`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o0000o`0000;o003o00?o0000o`00ool0
0?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o
003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l6o`000003
o`00ool0003o000000;o000000Co003oo`000?l00?oo003o1?l000001?l00?oo0000o`00ool00?l4
o`000004o`00ool0003o003oo`00o`Co000000Co003oo`000?l00?oo003o1?l000001?l00?oo0000
o`00ool00?l3o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o
ooooo`00000Cooooo`007oooool2o`0002Gooooo00?o0000o`00ool00?l00ol00002o`00o`03o`00
0?l00?oo003o00;o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l0
0ol00002o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l0
0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
00?o0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o0000o`00
00;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0
003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o
00?o000000?o003oo`000?l000000_l000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000
o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03
o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o000000?o003o
o`000?l000000_l000001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o003oo`00o`Co0000
4oooool0027ooooo00?o0000ooooooooool08oooool2o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo000000;o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o0ol0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o
1?l000000ol00?oo0000o`000004o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`00
0?l00?oo003o00?o000000Co003oo`000?l00?oo003o1?l000001?l00?oo0000o`000?l00002o`00
o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00
ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`00
0003o`00ool0003o000000Go000000?o003oo`000?l000000_l000001?l00?oo0000o`00ool00?l3
o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`;o00004oooool002;ooooo00?o0000oooo
ooooool08oooool00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00_l00002o`00
o`Ko00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o
00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol000001?l0
0?oo0000o`00ool00?l3o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l0
0ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo
003o00?o000000Co003oo`000?l00?oo003o1?l000000ol00?oo0000o`000004o`0000;o003o0ol0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o003oo`00o`Co
000000Co003oo`000?l0003o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00
ool000000ol00002o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o1?l0000B
ooooo`008oooool00ol0003oooooooooo`0Sooooo`;o00000_l00?l00ol0003o003oo`00o`03o`00
0004o`00ool0003o0000o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo
003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002o`00o`?o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l0
0?oo003o00?o000000Co003oo`000?l00?oo003o1?l000001?l00?oo0000o`00ool00?l3o`0000;o
003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o
003o00?o0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o003o
o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o0ol00002o`00o`03o`000?l00?oo
003o00?o000000Co003oo`000?l00?oo003o1_l00002o`00o`Co000000Co003oo`000?l00?oo003o
0ol00002o`00o`;o00004_ooool002Cooooo00?o0000ooooooooool08oooool00ol0003o003oo`00
o`03o`0000;o003o0_l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l0
0?l00ol0003o003oo`00o`03o`000003o`00ool0003o000000Co00000_l00?l3o`0000;o003o00?o
0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`000004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`000004o`00
ool0003o003oo`00o`Co000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o
00?o00000_l00?l6o`000003o`00ool0003o000000;o000000Co003oo`000?l00?oo003o1?l00000
1?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l0
0?oo003o00?o00000_l00?l00ol0003o003oo`00o`02o`0001;ooooo000Uooooo`;o00009?ooool2
o`0000;o003o0ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol000001?l00?oo0000o`000?l00002o`00o`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`00
0?l00?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002o`00o`Ko00000_l00?l3o`0000;o
003o00?o0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o003o
o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00000
0ol00?oo0000o`000002o`000004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00Co000000Co
003oo`000?l00?oo003o0ol000000ol00?oo0000o`000005o`000003ooooool0003ooooo017ooooo
000Wooooo`03o`000?oooooooooo02?ooooo0_l00002o`00o`03o`000?l00?oo000000;o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l0
0?oo003o00?o00000_l00?l6o`000004o`00ool0003o0000o`0000;o003o00?o0000o`00ool00?l0
0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`000004o`00
ool0003o003oo`00o`Co000000Co003oo`000?l00?oo003o0ol00002o`00o`?o00000_l00?l00ol0
003o003oo`00o`03o`000004o`00ool0003o003oo`00o`Co000000Co003oo`000?l00?oo003o0ol0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`000003o`00ool0
003o000000Go000000Co003oo`000?l0003o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o
00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo
003o1?l000001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o0000o`0000Sooooo00?o0000
ooooooooool04?ooool002Sooooo00?o0000ooooooooool08oooool00ol0003o003oo`00o`02o`00
00;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0
003o003oo`00o`03o`0000;o003o0ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000
o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03
o`000004o`00ool0003o003oo`00o`?o00000_l00?l6o`0000;o003o0ol00002o`00o`03o`000?l0
0?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol000001?l00?oo0000
o`000?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`0000;o
003o00?o0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l4o`000004o`00ool0003o003o
o`00o`?o00000_l00?l6o`000003o`00ool0003o000000;o00002oooool00ol0003oooooooooo`0@
ooooo`00:Oooool00ol0003oooooooooo`0Sooooo`;o00000_l00?l00ol0003o003oo`000002o`00
00;o003o00?o0000o`00ool00?l00ol00002o`00o`Ko00000_l00?l3o`000004o`00ool0003o003o
o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002o`00o`?o00000_l0
0?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol000001?l00?oo0000o`00
ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o0000
00?o003oo`000?l000001Ol000001?l00?oo0000o`000?l00002o`00o`03o`000?l00?oo003o00?o
00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`Co000000Co003oo`00
0?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o00?o000000?o003oo`000?l000000_l00000
1?l00?oo0000o`00ool00?l4o`0000kooooo00?o0000ooooooooool04?ooool002[ooooo0_l0000T
ooooo`03o`000?l00?oo003o00;o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o0ol00002
o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`000002o`0000;o003o00?o0000
o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03
o`000003o`00ool0003o000000Co00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00000
1?l00?oo0000o`00ool00?l4o`000004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o003o
o`00o`03o`0000;o003o00?o0000o`00ool00?l00ol000001?l00?oo0000o`000?l00002o`00o`03
o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00
o`Co000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l6
o`000004o`00ool0003o0000o`0000;o003o00?o0000o`00ool00?l00ol00004ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03oooool002cooooo00?o0000ooooooooool08_ooool2
o`000003o`00ool0003o000000Co00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo003o00;o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000
o`00ool00?l00ol00002o`00o`Ko000000Co003oo`000?l0003o00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o00?o0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l3o`0000;o003o
00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o000000?o003oo`000?l00000
1Ol000001?l00?oo0000o`000?l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o
003oo`00o`03o`000004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o003oo`00o`03o`00
00;o003o1_l000000ol00?oo0000o`000002o`000004o`00ool0003o003oo`00o`?o00000_l00?l0
0ol0003o003oo`00o`03o`0000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?
ooooo`00;Oooool00ol0003oooooooooo`0Sooooo`04o`000?l00?oo003oo`0000;o003o0ol00002
o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o
003oo`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o0ol000001?l00?oo0000o`00
ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o0000
00Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l6o`000004
o`00ool0003o0000o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o
00?o000000Co003oo`000?l00?oo003o1?l000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o
0000o`00ool00?l00ol000000ol00?oo0000o`000002o`000004o`00ool0003o003oo`00o`?o0000
0_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol0000<ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03oooool002kooooo00?o0000ooooooooool08_oo
ool00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l0
0?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002o`00o`Ko00000_l00?l3o`000004o`00
ool0003o003oo`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool0
0?l00ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00
o`?o000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l00?l0
0ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o003oo`00
o`03o`0000;o003o1_l000001?l00?oo0000o`000?l00002o`00o`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`Co00003oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00oooooo000_ooooo`03o`000?oooooooooo02;ooooo
0_l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`000003o`00
ool0003o000000Co00000_l00?l3o`0000;o003o00?o0000o`00ool00?l00ol000001?l00?oo0000
o`00ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o
000000Co003oo`000?l00?oo003o0ol00002o`00o`Ko00000_l00?l3o`000004o`00ool0003o003o
o`00o`?o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol00000
1?l00?oo0000o`00ool00?l3o`0000;o003o1_l000000ol00?oo0000o`000002o`000004o`00ool0
003o003oo`00o`?o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`Co
000000Co003oo`000?l00?oo003o0ol0000Dooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03oooool0033ooooo0_l0000Sooooo`03o`000?l00?oo003o00?o00000_l00?l00ol0003o
003oo`00o`03o`0000;o003o0_l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o
003oo`00o`03o`0000;o003o00?o0000o`00ool000000_l00002o`00o`03o`000?l00?oo003o00?o
00000_l00?l00ol0003o003oo`00o`03o`000003o`00ool0003o000000Co00000_l00?l3o`0000;o
003o00?o0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00
ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002
o`00o`?o000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o00?o00000_l0
0?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o003o
o`00o`03o`0001Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`00<_oo
ool00ol0003oooooooooo`0Qooooo`;o00000_l00?l6o`0000;o003o0ol000001?l00?oo0000o`00
ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00;o0000
0_l00?l00ol0003o003oo`00o`03o`0000;o003o1_l000001?l00?oo0000o`000?l00002o`00o`03
o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00
o`?o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`Co000000?o003o
o`000?l000001?l00002o`00o`?o000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l0
0?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`?o0000
0_l00?l6o`0001cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`00<ooo
ool00ol0003oooooooooo`0Rooooo`;o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool000000_l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`000004o`00ool0003o003oo`00o`?o00000_l00?l3o`000004o`00ool0003o003oo`00o`?o
00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol000001?l00?oo
0000o`00ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol000000ol00?oo0000o`000004o`00
00;o003o0ol00002o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002
o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o1?l000001?l00?oo0000o`00
ool00?l3o`0000;o003o0ol0000Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3_ooool003Cooooo00?o0000ooooooooool08_ooool00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00_l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00
o`03o`000003o`00ool0003o000000Co00000_l00?l3o`0000;o003o00?o0000o`00ool000000_l0
0002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0
003o003oo`00o`?o00000_l00?l6o`000004o`00ool0003o0000o`0000;o003o00?o0000o`00ool0
0?l00ol00002o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002o`00
o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002o`00o`Ko000000?o003o
o`000?l000000_l0000Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool0
03Gooooo0_l0000Sooooo`;o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003o
o`00o`?o00000_l00?l6o`000004o`00ool0003o0000o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00;o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o
0000o`00ool00?l00ol000000ol00?oo0000o`000004o`0000;o003o0ol000001?l00?oo0000o`00
ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`03o`000?l00?oo003o00?o0000
00Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o00?o000000?o003oo`000?l0
00001?l00002o`00o`?o000000Co003oo`000?l00?oo003o0ol0000[ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03_ooool003Oooooo00?o0000ooooooooool08Oooool00ol0003o
003oo`00o`03o`000003o`00ool0003o000000Co00000_l00?l3o`0000;o003o00?o0000o`00ool0
0?l00_l00002o`00o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`00o`03o`000004
o`00ool0003o003oo`00o`?o00000_l00?l6o`000004o`00ool0003o0000o`0000;o003o00?o0000
o`00ool00?l00ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol0
0002o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002o`00o`Ko0000
00Co003oo`000?l0003o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00
o`?o0000;_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo000hooooo`03
o`000?oooooooooo027ooooo0_l00002o`00o`;o00000_l00?l00ol0003o003oo`00o`03o`0000;o
003o00?o0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00
ool00?l00ol000000ol00?oo0000o`000004o`0000;o003o0ol000001?l00?oo0000o`00ool00?l3
o`0000;o003o00?o0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o
0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l4o`000003o`00ool0003o000000Co0000
0_l00?l3o`000004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o003oo`00o`03o`000004
o`00ool0003o003oo`00o`?o0000<_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00kooooo000iooooo`03o`000?oooooooooo02;ooooo0_l000001?l00?oo0000o`00ool00?l3o`00
00;o003o00?o0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l3o`0000;o003o1_l00000
1?l00?oo0000o`000?l00002o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o
0ol00002o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002o`00o`03
o`000?l00?oo003o00?o000000?o003oo`000?l000001?l00002o`00o`?o00000_l00?l00ol0003o
003oo`00o`03o`000004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o003oo`00o`03o`00
0004o`00ool0003o003oo`00o`?o0000=_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00kooooo000jooooo`03o`000?oooooooooo02;ooooo00?o0000o`00ool000000_l00002o`00
o`03o`000?l00?oo003o00?o00000_l00?l5o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o
00;o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool000000_l00002o`00
o`03o`000?l00?oo003o00?o00000_l00?l00ol0003o003oo`000002o`0000;o003o1_l00002o`00
o`;o00000_l00?l00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool00?l00ol000001?l0
0?oo0000o`00ool00?l3o`000004o`00ool0003o003oo`00o`Co000000?o003oo`000?l000001?l0
000jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool003_ooooo0_l0000S
ooooo`03o`000?l00?oo003o00Ko00000_l00?l3o`000004o`00ool0003o003oo`00o`?o00000_l0
0?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o003o
o`00o`02o`0000;o003o00?o0000o`00ool00?l00ol00002o`00o`Go00000_l00?l3o`0000;o003o
00?o0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool0
0?l00ol000001?l00?oo0000o`00ool00?l3o`000003o`00ool0003o000000Co00000_l00?l3o`00
043ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`00?Oooool00ol0003o
ooooooooo`0Qooooo`;o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00
o`?o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`?o00000_l00?l0
0ol0003o003oo`00o`03o`000003o`00ool0003o000000Co00000_l00?l3o`000004o`00ool0003o
003oo`00o`?o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`?o0000
0_l00?l00ol0003o003oo`00o`03o`000003o`00ool0003o000000Co000000Co003oo`000?l0003o
00000_l00?l00ol0003o003oo`00o`03o`0004Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`00?_ooool00ol0003oooooooooo`0Qooooo`03o`000?l00?oo003o00?o0000
0_l00?l00ol0003o003oo`000002o`0000;o003o00?o0000o`00ool00?l00ol000001?l00?oo0000
o`00ool00?l3o`0000;o003o1_l000001?l00?oo0000o`000?l00002o`00o`03o`000?l00?oo003o
00?o000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o00?o000000Co003o
o`000?l00?oo003o0ol00002o`00o`Ko000000Ko003oo`000?l0003o0000o`00ool00002o`00o`?o
00000_l00?l00ol0003o003oo`00o`03o`0004Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0=ooooo`00?oooool00ol0003oooooooooo`0Qooooo`;o00000_l00?l00ol0003o003o
o`00o`02o`0000;o003o1_l00002o`00o`Go00000_l00?l3o`0000;o003o00?o0000o`00ool00000
0_l00002o`00o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002o`00o`03
o`000?l00?oo003o00?o000000?o003oo`000?l000001?l00002o`00o`?o000000Co003oo`000?l0
0?oo003o0ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool00?l00ol0001<
ooooo`05o`000?ooooooooooooooool000003oooool0043ooooo0_l0000Sooooo`Go000000Co003o
o`000?l0003o00000_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`?o0000
0_l00?l00ol0003o003oo`00o`02o`0000;o003o00?o0000o`00ool00?l00ol000001?l00?oo0000
o`00ool00?l3o`0000;o003o1_l000001?l00?oo0000o`000?l00002o`00o`03o`000?l00?oo003o
00?o000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo000000;o00000_l00?l0
0ol0003o003oo`00o`03o`0004oooooo00Go0000ooooooooooooooooo`00000?ooooo`00@_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?l00?oo003o00;o00000_l00?l00ol0003o003oo`00o`03
o`000004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o003oo`00o`03o`000003o`00ool0
003o000000Co00000_l00?l5o`0000;o003o0ol000001?l00?oo0000o`00ool00?l3o`0000;o003o
00?o0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool0
0?l00_l00002o`00o`Ko0000Doooool01?l0003oooooooooool0000?ooooo`00@oooool00ol0003o
ooooooooo`0Qooooo`;o000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo0000
00;o00000_l00?l6o`000004o`00ool0003o0000o`0000;o003o00?o0000o`00ool00?l00ol00000
1?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool000000_l00002o`00o`03o`000?l0
0?oo003o00?o000000Co003oo`000?l00?oo003o0ol00002o`00o`Ko000000Co003oo`000?l0003o
0000F_ooool00ol0003oooooo`00000?ooooo`00A?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?l00?oo000000;o00000_l00?l5o`0000;o003o0ol00002o`00o`03o`000?l00?oo003o00;o0000
0_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`?o00000_l00?l00ol0003o
003oo`00o`02o`0000;o003o1_l000000ol00?oo0000o`000004o`0000;o003o0ol000001?l00?oo
0000o`00ool00?l3o`0005gooooo00Co0000oooooooooooo00003_ooool004Gooooo00?o0000oooo
ooooool08Oooool00ol0003o003oo`00o`03o`0000;o003o00?o0000o`00ool000000_l00002o`00
o`03o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o0ol000001?l00?oo0000o`00ool0
0?l3o`0000;o003o1_l000001?l00?oo0000o`000?l00002o`00o`03o`000?l00?oo000000;o0000
0_l00?l00ol0003o003oo`00o`03o`000004o`00ool0003o003oo`00o`?o0000HOooool00ol0003o
ooooo`00000>ooooo`00A_ooool2o`0002;ooooo0_l00002o`00o`03o`000?l00?oo003o00;o0000
0_l00?l00ol0003o003oo`00o`03o`000003o`00ool0003o000000Co00000_l00?l5o`0000;o003o
0ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool00?l00_l00002o`00o`03
o`000?l00?oo003o00?o000000Co003oo`000?l00?oo003o0ol0001Uooooo`;o00003_ooool004So
oooo00?o0000ooooooooool08?ooool00ol0003o003oo`00o`03o`000003o`00ool0003o000000Co
00000_l00?l2o`0000;o003o00?o0000o`00ool00?l00ol000001?l00?oo0000o`00ool00?l3o`00
00;o003o00?o0000o`00ool000000_l00002o`00o`03o`000?l00?oo003o00?o000000?o003oo`00
0?l000001?l000000ol00?oo0000o`000004o`0006Oooooo0ol0000>ooooo`00BOooool00ol0003o
ooooooooo`0Pooooo`;o000000Co003oo`000?l0003o00000_l00?l00ol0003o003oo`00o`03o`00
0004o`00ool0003o003oo`00o`?o000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l0
0?oo003o00;o00000_l00?l6o`000004o`00ool0003o0000o`0000;o003o00?o0000o`00ool00?l0
0_l0001Yooooo`Co00004Oooool004[ooooo00?o0000ooooooooool08Oooool01?l0003o003oo`00
ool00002o`00o`?o000000Co003oo`000?l00?oo003o0ol00002o`00o`Go00000_l00?l6o`000004
o`00ool0003o0000o`0000;o003o00?o0000o`00ool000000_l00002o`00o`03o`000?l00?oo003o
00?o0000Ioooool4o`0001Gooooo001;ooooo`03o`000?oooooooooo023ooooo00?o0000o`00ool0
0?l00ol00002o`00o`Go00000_l00?l3o`000004o`00ool0003o003oo`00o`?o000000Co003oo`00
0?l00?oo003o0ol00002o`00o`03o`000?l00?oo003o00;o00000_l00?l00ol0003o003oo`00o`03
o`0006Oooooo0ol0000Iooooo`00C?ooool2o`00027ooooo0_l00002o`00o`?o000000Co003oo`00
0?l00?oo003o0ol000001?l00?oo0000o`00ool00?l3o`0000;o003o00?o0000o`00ool000000_l0
0002o`00o`03o`000?l00?oo003o00?o000000?o003oo`000?l000001?l0001Vooooo`Co00007?oo
ool004kooooo00?o0000ooooooooool08?ooool2o`0000;o003o00?o0000o`00ool000000_l00002
o`00o`03o`000?l00?oo000000;o00000_l00?l5o`0000;o003o1_l000001?l00?oo0000o`000?l0
001Xooooo`Co00008?ooool004oooooo00?o0000ooooooooool08Oooool4o`0000;o003o1Ol00002
o`00o`?o000000Co003oo`000?l00?oo003o0ol00002o`00o`03o`000?l00?oo000000;o0000Iooo
ool4o`0002Cooooo001@ooooo`03o`000?oooooooooo023ooooo00?o0000o`00ool00?l00ol00002
o`00o`03o`000?l00?oo000000;o00000_l00?l00ol0003o003oo`000002o`0000;o003o00?o0000
o`00ool00?l00_l0001Vooooo`Co0000:?ooool0057ooooo0_l0000Qooooo`;o00000_l00?l00ol0
003o003oo`00o`02o`0000;o003o1Ol00002o`00o`Ko0000I?ooool4o`0002cooooo001Cooooo`03
o`000?oooooooooo023ooooo1Ol000001?l00?oo0000o`000?l00002o`00o`03o`000?l00?oo0000
00;o0000Ioooool3o`00033ooooo001Dooooo`03o`000?oooooooooo023ooooo00?o0000o`00ool0
00000_l00002o`00o`03o`000?l00?oo003o00;o0000I_ooool4o`0003?ooooo001Eooooo`03o`00
0?oooooooooo023ooooo00?o0000o`00ool00?l01_l0001Tooooo`Co0000=oooool005Kooooo00?o
0000ooooooooool08?ooool2o`0006Kooooo1?l0000kooooo`00Eoooool2o`00023ooooo00?o0000
ooooooooool0HOooool4o`0003oooooo001Iooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0G_ooool3o`0004?ooooo001Jooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0F_ooool4o`0004Kooooo001Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
E_ooool4o`0004[ooooo001Looooo`;o00006oooool00ol0003oooooooooo`1Booooo`Co0000C_oo
ool005kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1>ooooo`Co0000D_ooool0
05oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1:ooooo`Co0000E_ooool0063o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`?o0000F_ooool0067ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`13ooooo`Co0000GOooool006;ooooo0_l0
000Eooooo`03o`000?oooooooooo03oooooo1?l0001Qooooo`00I?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo03_ooooo1?l0001Uooooo`00IOooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo03Oooooo1?l0001Yooooo`00I_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03?ooooo1?l0001]ooooo`00Ioooool2o`00013ooooo00?o0000ooooooooool0
<?ooool3o`00077ooooo001Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;Ooo
ool4o`0007Cooooo001Zooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool4
o`0007Sooooo001[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool4o`00
07cooooo001/ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`00083o
oooo001]ooooo`;o00002Oooool00ol0003oooooooooo`0Nooooo`?o0000Q?ooool006oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`Co0000Qoooool0073ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000Roooool0077ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000Soooool007;ooooo0_l00004ooooo`03
o`000?oooooooooo00kooooo1?l0002Cooooo`00M?ooool01Ol0003ooooooooooooooooo000000co
oooo1?l0002Gooooo`00MOooool01?l0003oooooooooool00009ooooo`?o0000Voooool007Kooooo
00?o0000ooooool000001Oooool4o`0009kooooo001gooooo`;o000000?oooooo`000?l000000_l0
002Rooooo`00N?ooool2o`000:Kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0752515, -0.0080056, \
0.00375766, 0.00375766}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .88452 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0307278 1.03073 -0.0281325 1.03073 [
[.39879 -0.00173 -0.78433 -9 ]
[.39879 -0.00173 5.21567 0 ]
[.63635 .1302 -1.66299 -9 ]
[.63635 .1302 22.337 0 ]
[.85291 .25054 -0.18866 -9 ]
[.85291 .25054 23.8113 0 ]
[.28132 .10737 -30 -6.85877 ]
[.28132 .10737 0 2.14123 ]
[.14899 .28856 -30 -6.6491 ]
[.14899 .28856 0 2.3509 ]
[.03303 .44736 -6 -6.47367 ]
[.03303 .44736 0 2.52633 ]
[.96679 .31495 0 -8.76934 ]
[.96679 .31495 18 .23066 ]
[.97689 .36034 0 -8.67737 ]
[.97689 .36034 18 .32263 ]
[.98742 .4077 0 -8.58216 ]
[.98742 .4077 6 .41784 ]
[.99841 .45714 0 -8.48352 ]
[.99841 .45714 12 .51648 ]
[ 0 0 0 0 ]
[ 1 .88452 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.37558 0 m
.95717 .32255 L
s
.39114 .00863 m
.38731 .01381 L
s
[(0)] .39879 -0.00173 -0.73856 1 Mshowa
.62794 .13996 m
.62374 .14484 L
s
[(0.02)] .63635 .1302 -0.86142 1 Mshowa
.84387 .25972 m
.83935 .26431 L
s
[(0.04)] .85291 .25054 -0.98428 1 Mshowa
.125 Mabswid
.45246 .04264 m
.4501 .0457 L
s
.51234 .07585 m
.50992 .07887 L
s
.57081 .10828 m
.56834 .11125 L
s
.68377 .17093 m
.6812 .17381 L
s
.73834 .20119 m
.73572 .20403 L
s
.79169 .23078 m
.78903 .23358 L
s
.89491 .28802 m
.89216 .29074 L
s
.94485 .31572 m
.94206 .31839 L
s
.25 Mabswid
.37558 0 m
.03807 .46179 L
s
.29273 .11335 m
.29844 .11634 L
s
[(-0.04)] .28132 .10737 1 .52417 Mshowa
.16061 .29412 m
.16643 .29689 L
s
[(-0.02)] .14899 .28856 1 .47758 Mshowa
.04483 .45253 m
.05073 .45512 L
s
[(0)] .03303 .44736 1 .43859 Mshowa
.125 Mabswid
.25799 .16089 m
.26143 .16265 L
s
.22442 .20681 m
.22788 .20854 L
s
.19198 .2512 m
.19546 .25289 L
s
.13026 .33565 m
.13376 .33728 L
s
.10088 .37585 m
.10439 .37746 L
s
.07241 .4148 m
.07594 .41637 L
s
.32873 .0641 m
.33213 .06593 L
s
.36604 .01305 m
.36942 .01492 L
s
.25 Mabswid
.95717 .32255 m
1 .51659 L
s
.95745 .32382 m
.95277 .32826 L
s
[(-40)] .96679 .31495 -1 .94874 Mshowa
.96744 .36911 m
.96272 .37349 L
s
[(-20)] .97689 .36034 -1 .92831 Mshowa
.97787 .41635 m
.9731 .42068 L
s
[(0)] .98742 .4077 -1 .90715 Mshowa
.98876 .46568 m
.98394 .46995 L
s
[(20)] .99841 .45714 -1 .88523 Mshowa
.125 Mabswid
.95991 .33497 m
.9571 .33762 L
s
.96239 .34623 m
.95957 .34887 L
s
.9649 .35761 m
.96208 .36025 L
s
.97001 .38073 m
.96717 .38335 L
s
.9726 .39248 m
.96975 .39509 L
s
.97522 .40435 m
.97237 .40696 L
s
.98055 .42848 m
.97768 .43107 L
s
.98326 .44075 m
.98038 .44333 L
s
.98599 .45315 m
.98311 .45572 L
s
.99156 .47836 m
.98866 .48091 L
s
.99439 .49117 m
.99148 .49372 L
s
.99725 .50413 m
.99433 .50667 L
s
.25 Mabswid
.37558 0 m
.3643 .18795 L
s
.3643 .18795 m
0 .65613 L
s
0 .65613 m
.03807 .46179 L
s
.03807 .46179 m
.37558 0 L
s
.95717 .32255 m
.56725 .69271 L
s
.56725 .69271 m
.57356 .88452 L
s
.57356 .88452 m
1 .51659 L
s
1 .51659 m
.95717 .32255 L
s
.37558 0 m
.3643 .18795 L
s
.3643 .18795 m
1 .51659 L
s
1 .51659 m
.95717 .32255 L
s
.95717 .32255 m
.37558 0 L
s
.03807 .46179 m
.56725 .69271 L
s
.56725 .69271 m
.57356 .88452 L
s
.57356 .88452 m
0 .65613 L
s
0 .65613 m
.03807 .46179 L
s
0 0 m
1 0 L
1 .88452 L
0 .88452 L
closepath
clip
newpath
.5 Mabswid
.57284 .74795 m .56607 .75266 L .55639 .74727 L p 1 0 0 r
F P
0 g
s
.55639 .74727 m .56311 .74176 L .57284 .74795 L p 1 0 0 r
F P
0 g
s
.56311 .74176 m .55639 .74727 L .54671 .74281 L p 1 0 0 r
F P
0 g
s
.54671 .74281 m .55339 .73657 L .56311 .74176 L p 1 0 0 r
F P
0 g
s
.55339 .73657 m .54671 .74281 L .53701 .73916 L p 1 0 0 r
F P
0 g
s
.57967 .74386 m .57284 .74795 L .56311 .74176 L p 1 0 0 r
F P
0 g
s
.56311 .74176 m .56989 .7368 L .57967 .74386 L p 1 0 0 r
F P
0 g
s
.56989 .7368 m .56311 .74176 L .55339 .73657 L p 1 0 0 r
F P
0 g
s
.53701 .73916 m .54366 .73227 L .55339 .73657 L p 1 0 0 r
F P
0 g
s
.54366 .73227 m .53701 .73916 L .52729 .73623 L p 1 0 0 r
F P
0 g
s
.55339 .73657 m .56013 .73082 L .56989 .7368 L p 1 0 0 r
F P
0 g
s
.56013 .73082 m .55339 .73657 L .54366 .73227 L p 1 0 0 r
F P
0 g
s
.58659 .74043 m .57967 .74386 L .56989 .7368 L p 1 0 0 r
F P
0 g
s
.52729 .73623 m .53391 .72875 L .54366 .73227 L p 1 0 0 r
F P
0 g
s
.53391 .72875 m .52729 .73623 L .51752 .73391 L p 1 0 0 r
F P
0 g
s
.54366 .73227 m .55036 .72581 L .56013 .73082 L p 1 0 0 r
F P
0 g
s
.55036 .72581 m .54366 .73227 L .53391 .72875 L p 1 0 0 r
F P
0 g
s
.57351 .7674 m .56673 .77359 L .55702 .7695 L p 0 0 1 r
F P
0 g
s
.56989 .7368 m .57674 .73245 L .58659 .74043 L p 1 0 0 r
F P
0 g
s
.57674 .73245 m .56989 .7368 L .56013 .73082 L p 1 0 0 r
F P
0 g
s
.56013 .73082 m .56692 .72563 L .57674 .73245 L p 1 0 0 r
F P
0 g
s
.56692 .72563 m .56013 .73082 L .55036 .72581 L p 1 0 0 r
F P
0 g
s
.55702 .7695 m .56377 .76329 L .57351 .7674 L p 0 0 1 r
F P
0 g
s
.56377 .76329 m .55702 .7695 L .54726 .76541 L p 0 0 1 r
F P
0 g
s
.51752 .73391 m .52413 .72592 L .53391 .72875 L p 1 0 0 r
F P
0 g
s
.53391 .72875 m .54059 .72166 L .55036 .72581 L p 1 0 0 r
F P
0 g
s
.54059 .72166 m .53391 .72875 L .52413 .72592 L p 1 0 0 r
F P
0 g
s
.52413 .72592 m .51752 .73391 L .5077 .7321 L p 1 0 0 r
F P
0 g
s
.55036 .72581 m .55712 .71985 L .56692 .72563 L p 1 0 0 r
F P
0 g
s
.55712 .71985 m .55036 .72581 L .54059 .72166 L p 1 0 0 r
F P
0 g
s
.58032 .76117 m .57351 .7674 L .56377 .76329 L p 0 0 1 r
F P
0 g
s
.5936 .73773 m .58659 .74043 L .57674 .73245 L p 1 0 0 r
F P
0 g
s
.57674 .73245 m .58367 .72877 L .5936 .73773 L p 1 0 0 r
F P
0 g
s
.58367 .72877 m .57674 .73245 L .56692 .72563 L p 1 0 0 r
F P
0 g
s
.54726 .76541 m .554 .75917 L .56377 .76329 L p 0 0 1 r
F P
0 g
s
.554 .75917 m .54726 .76541 L .53747 .76129 L p 0 0 1 r
F P
0 g
s
.56692 .72563 m .57379 .72104 L .58367 .72877 L p 1 0 0 r
F P
0 g
s
.57379 .72104 m .56692 .72563 L .55712 .71985 L p 1 0 0 r
F P
0 g
s
.5077 .7321 m .51431 .72368 L .52413 .72592 L p 1 0 0 r
F P
0 g
s
.52413 .72592 m .53078 .71827 L .54059 .72166 L p 1 0 0 r
F P
0 g
s
.53078 .71827 m .52413 .72592 L .51431 .72368 L p 1 0 0 r
F P
0 g
s
.54059 .72166 m .54731 .71501 L .55712 .71985 L p 1 0 0 r
F P
0 g
s
.54731 .71501 m .54059 .72166 L .53078 .71827 L p 1 0 0 r
F P
0 g
s
.56377 .76329 m .57057 .75704 L .58032 .76117 L p 0 0 1 r
F P
0 g
s
.57057 .75704 m .56377 .76329 L .554 .75917 L p 0 0 1 r
F P
0 g
s
.51431 .72368 m .5077 .7321 L .49783 .73072 L p 1 0 0 r
F P
0 g
s
.57399 .78155 m .56721 .78862 L .55746 .78536 L p 0 1 0 r
F P
0 g
s
.53747 .76129 m .54419 .75503 L .554 .75917 L p 0 0 1 r
F P
0 g
s
.54419 .75503 m .53747 .76129 L .52763 .75716 L p 0 0 1 r
F P
0 g
s
.58717 .75491 m .58032 .76117 L .57057 .75704 L p 0 0 1 r
F P
0 g
s
.55712 .71985 m .56393 .71443 L .57379 .72104 L p 1 0 0 r
F P
0 g
s
.56393 .71443 m .55712 .71985 L .54731 .71501 L p 1 0 0 r
F P
0 g
s
.554 .75917 m .56078 .75289 L .57057 .75704 L p 0 0 1 r
F P
0 g
s
.56078 .75289 m .554 .75917 L .54419 .75503 L p 0 0 1 r
F P
0 g
s
.51431 .72368 m .52095 .71553 L .53078 .71827 L p 1 0 0 r
F P
0 g
s
.53078 .71827 m .53748 .71099 L .54731 .71501 L p 1 0 0 r
F P
0 g
s
.53748 .71099 m .53078 .71827 L .52095 .71553 L p 1 0 0 r
F P
0 g
s
.49783 .73072 m .50443 .72192 L .51431 .72368 L p 1 0 0 r
F P
0 g
s
.52095 .71553 m .51431 .72368 L .50443 .72192 L p 1 0 0 r
F P
0 g
s
.6007 .73581 m .5936 .73773 L .58367 .72877 L p 1 0 0 r
F P
0 g
s
.54731 .71501 m .55408 .70884 L .56393 .71443 L p 1 0 0 r
F P
0 g
s
.55408 .70884 m .54731 .71501 L .53748 .71099 L p 1 0 0 r
F P
0 g
s
.58367 .72877 m .59069 .72579 L .6007 .73581 L p 1 0 0 r
F P
0 g
s
.59069 .72579 m .58367 .72877 L .57379 .72104 L p 1 0 0 r
F P
0 g
s
.52763 .75716 m .53434 .75088 L .54419 .75503 L p 0 0 1 r
F P
0 g
s
.53434 .75088 m .52763 .75716 L .51776 .75302 L p 0 0 1 r
F P
0 g
s
.57057 .75704 m .5774 .75075 L .58717 .75491 L p 0 0 1 r
F P
0 g
s
.5774 .75075 m .57057 .75704 L .56078 .75289 L p 0 0 1 r
F P
0 g
s
.55746 .78536 m .56425 .77889 L .57399 .78155 L p 0 1 0 r
F P
0 g
s
.56425 .77889 m .55746 .78536 L .54765 .78136 L p 0 1 0 r
F P
0 g
s
.50443 .72192 m .49783 .73072 L .4879 .72966 L p 1 0 0 r
F P
0 g
s
.57379 .72104 m .58073 .7171 L .59069 .72579 L p 1 0 0 r
F P
0 g
s
.58073 .7171 m .57379 .72104 L .56393 .71443 L p 1 0 0 r
F P
0 g
s
.58079 .77392 m .57399 .78155 L .56425 .77889 L p 0 1 0 r
F P
0 g
s
.54419 .75503 m .55096 .74873 L .56078 .75289 L p 0 0 1 r
F P
0 g
s
.55096 .74873 m .54419 .75503 L .53434 .75088 L p 0 0 1 r
F P
0 g
s
.59406 .74861 m .58717 .75491 L .5774 .75075 L p 0 0 1 r
F P
0 g
s
.56393 .71443 m .57081 .70961 L .58073 .7171 L p 1 0 0 r
F P
0 g
s
.57081 .70961 m .56393 .71443 L .55408 .70884 L p 1 0 0 r
F P
0 g
s
.50443 .72192 m .51107 .71335 L .52095 .71553 L p 1 0 0 r
F P
0 g
s
.52095 .71553 m .52762 .7077 L .53748 .71099 L p 1 0 0 r
F P
0 g
s
.52762 .7077 m .52095 .71553 L .51107 .71335 L p 1 0 0 r
F P
0 g
s
.53748 .71099 m .54422 .70414 L .55408 .70884 L p 1 0 0 r
F P
0 g
s
.54422 .70414 m .53748 .71099 L .52762 .7077 L p 1 0 0 r
F P
0 g
s
.51776 .75302 m .52445 .7467 L .53434 .75088 L p 0 0 1 r
F P
0 g
s
.52445 .7467 m .51776 .75302 L .50785 .74885 L p 0 0 1 r
F P
0 g
s
.56078 .75289 m .5676 .74658 L .5774 .75075 L p 0 0 1 r
F P
0 g
s
.5676 .74658 m .56078 .75289 L .55096 .74873 L p 0 0 1 r
F P
0 g
s
.54765 .78136 m .55444 .77542 L .56425 .77889 L p 0 1 0 r
F P
0 g
s
.55444 .77542 m .54765 .78136 L .53778 .77668 L p 0 1 0 r
F P
0 g
s
.4879 .72966 m .4945 .72057 L .50443 .72192 L p 1 0 0 r
F P
0 g
s
.51107 .71335 m .50443 .72192 L .4945 .72057 L p 1 0 0 r
F P
0 g
s
.55408 .70884 m .56091 .7032 L .57081 .70961 L p 1 0 0 r
F P
0 g
s
.56091 .7032 m .55408 .70884 L .54422 .70414 L p 1 0 0 r
F P
0 g
s
.53434 .75088 m .54109 .74455 L .55096 .74873 L p 0 0 1 r
F P
0 g
s
.54109 .74455 m .53434 .75088 L .52445 .7467 L p 0 0 1 r
F P
0 g
s
.56425 .77889 m .57106 .7719 L .58079 .77392 L p 0 1 0 r
F P
0 g
s
.5876 .76569 m .58079 .77392 L .57106 .7719 L p 0 1 0 r
F P
0 g
s
.5774 .75075 m .58428 .74443 L .59406 .74861 L p 0 0 1 r
F P
0 g
s
.58428 .74443 m .5774 .75075 L .5676 .74658 L p 0 0 1 r
F P
0 g
s
.57106 .7719 m .56425 .77889 L .55444 .77542 L p 0 1 0 r
F P
0 g
s
.67558 .56969 m .67609 .57274 L p .66481 .59391 L 0 1 0 r
F P
0 g
s
.67609 .57274 m .67328 .58276 L .66481 .59391 L p 0 1 0 r
F P
0 g
s
.4945 .72057 m .4879 .72966 L .4779 .72885 L p 1 0 0 r
F P
0 g
s
.50785 .74885 m .51453 .74252 L .52445 .7467 L p 0 0 1 r
F P
0 g
s
.51453 .74252 m .50785 .74885 L .4979 .74468 L p 0 0 1 r
F P
0 g
s
.53778 .77668 m .54457 .77122 L .55444 .77542 L p 0 1 0 r
F P
0 g
s
.54457 .77122 m .53778 .77668 L .52787 .77141 L p 0 1 0 r
F P
0 g
s
.55096 .74873 m .55776 .74239 L .5676 .74658 L p 0 0 1 r
F P
0 g
s
.55776 .74239 m .55096 .74873 L .54109 .74455 L p 0 0 1 r
F P
0 g
s
.601 .74227 m .59406 .74861 L .58428 .74443 L p 0 0 1 r
F P
0 g
s
.60792 .73473 m .6007 .73581 L .59069 .72579 L p 1 0 0 r
F P
0 g
s
.59069 .72579 m .5978 .72359 L .60792 .73473 L p 1 0 0 r
F P
0 g
s
.5978 .72359 m .59069 .72579 L .58073 .7171 L p 1 0 0 r
F P
0 g
s
.51107 .71335 m .51773 .70504 L .52762 .7077 L p 1 0 0 r
F P
0 g
s
.52762 .7077 m .53434 .70024 L .54422 .70414 L p 1 0 0 r
F P
0 g
s
.53434 .70024 m .52762 .7077 L .51773 .70504 L p 1 0 0 r
F P
0 g
s
.58073 .7171 m .58776 .71386 L .5978 .72359 L p 1 0 0 r
F P
0 g
s
.58776 .71386 m .58073 .7171 L .57081 .70961 L p 1 0 0 r
F P
0 g
s
.4945 .72057 m .50113 .71164 L .51107 .71335 L p 1 0 0 r
F P
0 g
s
.51773 .70504 m .51107 .71335 L .50113 .71164 L p 1 0 0 r
F P
0 g
s
.54422 .70414 m .55101 .69777 L .56091 .7032 L p 1 0 0 r
F P
0 g
s
.55101 .69777 m .54422 .70414 L .53434 .70024 L p 1 0 0 r
F P
0 g
s
.67099 .57367 m .67548 .56701 L .67558 .56969 L p 0 1 0 r
F P
0 g
s
.66481 .59391 m .67099 .57367 L p .67558 .56969 L 0 1 0 r
F P
0 g
s
.52445 .7467 m .53119 .74035 L .54109 .74455 L p 0 0 1 r
F P
0 g
s
.53119 .74035 m .52445 .7467 L .51453 .74252 L p 0 0 1 r
F P
0 g
s
.5676 .74658 m .57446 .74023 L .58428 .74443 L p 0 0 1 r
F P
0 g
s
.57446 .74023 m .5676 .74658 L .55776 .74239 L p 0 0 1 r
F P
0 g
s
.67328 .58276 m .66715 .60295 L .65852 .61297 L p 0 1 0 r
F P
0 g
s
.65852 .61297 m .66481 .59391 L .67328 .58276 L p 0 1 0 r
F P
0 g
s
.57081 .70961 m .57777 .70542 L .58776 .71386 L p 1 0 0 r
F P
0 g
s
.57777 .70542 m .57081 .70961 L .56091 .7032 L p 1 0 0 r
F P
0 g
s
.57106 .7719 m .5779 .76435 L .5876 .76569 L p 0 1 0 r
F P
0 g
s
.59441 .7568 m .5876 .76569 L .5779 .76435 L p 0 1 0 r
F P
0 g
s
.55444 .77542 m .56126 .76901 L .57106 .7719 L p 0 1 0 r
F P
0 g
s
.56126 .76901 m .55444 .77542 L .54457 .77122 L p 0 1 0 r
F P
0 g
s
.52787 .77141 m .53464 .76636 L .54457 .77122 L p 0 1 0 r
F P
0 g
s
.53464 .76636 m .52787 .77141 L .51793 .76562 L p 0 1 0 r
F P
0 g
s
.4779 .72885 m .48451 .71952 L .4945 .72057 L p 1 0 0 r
F P
0 g
s
.50113 .71164 m .4945 .72057 L .48451 .71952 L p 1 0 0 r
F P
0 g
s
.5779 .76435 m .57106 .7719 L .56126 .76901 L p 0 1 0 r
F P
0 g
s
.4979 .74468 m .50456 .73831 L .51453 .74252 L p 0 0 1 r
F P
0 g
s
.50456 .73831 m .4979 .74468 L .48791 .74048 L p 0 0 1 r
F P
0 g
s
.54109 .74455 m .54788 .73819 L .55776 .74239 L p 0 0 1 r
F P
0 g
s
.54788 .73819 m .54109 .74455 L .53119 .74035 L p 0 0 1 r
F P
0 g
s
.58428 .74443 m .5912 .73806 L .601 .74227 L p 0 0 1 r
F P
0 g
s
.5912 .73806 m .58428 .74443 L .57446 .74023 L p 0 0 1 r
F P
0 g
s
.67495 .5639 m .67548 .56701 L .67099 .57367 L p 0 1 0 r
F P
0 g
s
.56091 .7032 m .56781 .69815 L .57777 .70542 L p 1 0 0 r
F P
0 g
s
.56781 .69815 m .56091 .7032 L .55101 .69777 L p 1 0 0 r
F P
0 g
s
.51793 .76562 m .52468 .76092 L .53464 .76636 L p 0 1 0 r
F P
0 g
s
.52468 .76092 m .51793 .76562 L .50795 .75938 L p 0 1 0 r
F P
0 g
s
.51773 .70504 m .52443 .69704 L .53434 .70024 L p 1 0 0 r
F P
0 g
s
.53434 .70024 m .5411 .6932 L .55101 .69777 L p 1 0 0 r
F P
0 g
s
.5411 .6932 m .53434 .70024 L .52443 .69704 L p 1 0 0 r
F P
0 g
s
.50113 .71164 m .50779 .70291 L .51773 .70504 L p 1 0 0 r
F P
0 g
s
.52443 .69704 m .51773 .70504 L .50779 .70291 L p 1 0 0 r
F P
0 g
s
.51453 .74252 m .52124 .73614 L .53119 .74035 L p 0 0 1 r
F P
0 g
s
.52124 .73614 m .51453 .74252 L .50456 .73831 L p 0 0 1 r
F P
0 g
s
.48451 .71952 m .4779 .72885 L .46784 .72818 L p 1 0 0 r
F P
0 g
s
.55776 .74239 m .56461 .73602 L .57446 .74023 L p 0 0 1 r
F P
0 g
s
.56461 .73602 m .55776 .74239 L .54788 .73819 L p 0 0 1 r
F P
0 g
s
.60797 .73589 m .601 .74227 L .5912 .73806 L p 0 0 1 r
F P
0 g
s
.5779 .76435 m .58474 .75619 L .59441 .7568 L p 0 1 0 r
F P
0 g
s
.60122 .74722 m .59441 .7568 L .58474 .75619 L p 0 1 0 r
F P
0 g
s
.54457 .77122 m .55138 .76533 L .56126 .76901 L p 0 1 0 r
F P
0 g
s
.55138 .76533 m .54457 .77122 L .53464 .76636 L p 0 1 0 r
F P
0 g
s
.67099 .57367 m .67477 .56022 L .67495 .5639 L p 0 1 0 r
F P
0 g
s
.66715 .60295 m .6609 .62198 L .65211 .63088 L p 0 1 0 r
F P
0 g
s
.65211 .63088 m .65852 .61297 L .66715 .60295 L p 0 1 0 r
F P
0 g
s
.48451 .71952 m .49114 .7103 L .50113 .71164 L p 1 0 0 r
F P
0 g
s
.50779 .70291 m .50113 .71164 L .49114 .7103 L p 1 0 0 r
F P
0 g
s
.55101 .69777 m .55786 .69192 L .56781 .69815 L p 1 0 0 r
F P
0 g
s
.55786 .69192 m .55101 .69777 L .5411 .6932 L p 1 0 0 r
F P
0 g
s
.48791 .74048 m .49456 .73409 L .50456 .73831 L p 0 0 1 r
F P
0 g
s
.49456 .73409 m .48791 .74048 L .47789 .73627 L p 0 0 1 r
F P
0 g
s
.53119 .74035 m .53796 .73397 L .54788 .73819 L p 0 0 1 r
F P
0 g
s
.53796 .73397 m .53119 .74035 L .52124 .73614 L p 0 0 1 r
F P
0 g
s
.57446 .74023 m .58137 .73384 L .5912 .73806 L p 0 0 1 r
F P
0 g
s
.58137 .73384 m .57446 .74023 L .56461 .73602 L p 0 0 1 r
F P
0 g
s
.50795 .75938 m .51467 .75498 L .52468 .76092 L p 0 1 0 r
F P
0 g
s
.51467 .75498 m .50795 .75938 L .49795 .75277 L p 0 1 0 r
F P
0 g
s
.56126 .76901 m .5681 .76209 L .5779 .76435 L p 0 1 0 r
F P
0 g
s
.5681 .76209 m .56126 .76901 L .55138 .76533 L p 0 1 0 r
F P
0 g
s
.58474 .75619 m .5779 .76435 L .5681 .76209 L p 0 1 0 r
F P
0 g
s
.60502 .72222 m .5978 .72359 L .58776 .71386 L p 1 0 0 r
F P
0 g
s
.58776 .71386 m .59488 .71139 L .60502 .72222 L p 1 0 0 r
F P
0 g
s
.59488 .71139 m .58776 .71386 L .57777 .70542 L p 1 0 0 r
F P
0 g
s
.46784 .72818 m .47445 .7187 L .48451 .71952 L p 1 0 0 r
F P
0 g
s
.49114 .7103 m .48451 .71952 L .47445 .7187 L p 1 0 0 r
F P
0 g
s
.60792 .73473 m .5978 .72359 L p .60851 .73032 L 1 0 0 r
F P
0 g
s
.60851 .73032 m .60862 .73095 L .60792 .73473 L 1 0 0 r
F
.60928 .7347 m .60883 .73471 L p .60862 .73095 L F P
0 g
s
.60883 .73471 m .60792 .73473 L p .60862 .73095 L 1 0 0 r
F P
0 g
s
.60797 .73589 m .59816 .73166 L p .60851 .73032 L 0 0 1 r
F P
0 g
s
.5978 .72359 m .60502 .72222 L .60867 .72661 L p 1 0 0 r
F P
0 g
s
.60867 .72661 m .60883 .7268 L p .60866 .72676 L 1 0 0 r
F P
0 g
s
.5978 .72359 m .60867 .72661 L .60866 .72676 L 1 0 0 r
F
.60502 .72222 m .59488 .71139 L p .60818 .71926 L F P
0 g
s
.60818 .71926 m .60828 .71977 L .60502 .72222 L 1 0 0 r
F
.6121 .71656 m .62156 .71381 L p .60892 .72453 L 0 1 0 r
F P
0 g
s
.60891 .72441 m .6121 .71656 L .60892 .72453 L 0 1 0 r
F
.6083 .71987 m .60836 .71924 L .60869 .72198 L 0 0 1 r
F
.60818 .71926 m .60836 .71924 L .6083 .71987 L F
.60836 .71924 m .60877 .72137 L .60869 .72198 L F
.60864 .72477 m .60909 .72144 L .60883 .7246 L 0 1 0 r
F
.60885 .72183 m .60909 .72144 L p .60864 .72477 L F P
0 g
s
.60883 .7246 m .60891 .72441 L .60892 .72453 L 0 1 0 r
F
.60909 .72144 m .6121 .71656 L p .60883 .7246 L F P
0 g
s
.62156 .71381 m .6148 .72577 L .60903 .72689 L p 0 1 0 r
F P
0 g
s
.60864 .72477 m .62156 .71381 L .60903 .72689 L 0 1 0 r
F
.61221 .71874 m .62205 .72302 L p .60864 .72477 L 0 0 1 r
F P
0 g
s
.60883 .7268 m .60903 .72689 L p .60851 .73032 L 0 0 1 r
F P
0 g
s
.60903 .72689 m .6148 .72577 L p .60869 .73029 L 0 1 0 r
F P
0 g
s
.60851 .73032 m .60869 .73029 L .60928 .7347 L 0 0 1 r
F
.60928 .7347 m .60797 .73589 L p .60851 .73032 L F P
0 g
s
.60851 .73032 m .60859 .73037 L .60928 .7347 L 1 0 0 r
F
.60859 .73037 m .60869 .73029 L .60865 .73069 L 0 1 0 r
F
.6148 .72577 m .60946 .73453 L p .60869 .73029 L F P
0 g
s
.60936 .7347 m .60928 .7347 L p .60859 .73037 L 1 0 0 r
F P
0 g
s
.60946 .73453 m .60928 .7347 L p .60869 .73029 L 0 0 1 r
F P
0 g
s
.60946 .73453 m .60802 .73689 L p .60869 .73029 L 0 1 0 r
F P
0 g
s
.61499 .72947 m .60946 .73453 L p .60869 .73029 L 0 0 1 r
F P
0 g
s
.61525 .73455 m .60936 .7347 L p .60859 .73037 L 1 0 0 r
F P
0 g
s
.5912 .73806 m .59816 .73166 L .60797 .73589 L p 0 0 1 r
F P
0 g
s
.60802 .73689 m .59844 .73788 L p .60859 .73037 L 0 1 0 r
F P
0 g
s
.60859 .73037 m .60865 .73069 L .60802 .73689 L 0 1 0 r
F
.60903 .72689 m .61499 .72947 L p .60869 .73029 L 0 0 1 r
F P
0 g
s
.60851 .73032 m .60903 .72689 L .60869 .73029 L 0 0 1 r
F
.60883 .7268 m .60502 .72222 L p .60849 .72479 L 1 0 0 r
F P
0 g
s
.62205 .72302 m .61499 .72947 L .60836 .7266 L p 0 0 1 r
F P
0 g
s
.60836 .7266 m .60517 .72522 L p .60849 .72479 L 0 0 1 r
F P
0 g
s
.60849 .72479 m .62205 .72302 L .60836 .7266 L 0 0 1 r
F
.60903 .72689 m .60892 .72691 L p .60864 .72477 L 0 1 0 r
F P
0 g
s
.60856 .72484 m .60864 .72477 L .60892 .72691 L 0 1 0 r
F
.61236 .72174 m .62272 .73533 L p .60856 .72484 L 1 0 0 r
F P
0 g
s
.60849 .72479 m .60855 .72473 L .60856 .72484 L 1 0 0 r
F
.60502 .72222 m .60869 .72198 L p .60849 .72479 L F P
0 g
s
.60849 .72479 m .60822 .72241 L .60864 .72477 L 0 0 1 r
F
.60822 .72241 m .61221 .71874 L p .60864 .72477 L F P
0 g
s
.60856 .72484 m .60885 .72183 L .60864 .72477 L 0 1 0 r
F
.60855 .72473 m .60857 .72473 L .60856 .72484 L 1 0 0 r
F
.60876 .72197 m .60885 .72183 L p .60856 .72484 L 0 1 0 r
F P
0 g
s
.60869 .72198 m .61236 .72174 L p .60849 .72479 L 1 0 0 r
F P
0 g
s
.60517 .72522 m .60811 .72251 L p .60849 .72479 L 0 0 1 r
F P
0 g
s
.60811 .72251 m .60822 .72241 L p .60849 .72479 L 0 0 1 r
F P
0 g
s
.5978 .72359 m .60883 .7268 L .60882 .72688 L 1 0 0 r
F
.5978 .72359 m .60892 .72691 L .60859 .73037 L F
.59816 .73166 m .60517 .72522 L .60883 .7268 L p 0 0 1 r
F P
0 g
s
.60528 .72762 m .60876 .72197 L p .60856 .72484 L 0 1 0 r
F P
0 g
s
.60857 .72473 m .61236 .72174 L .60856 .72484 L 1 0 0 r
F
.60891 .72685 m .60891 .72686 L .60892 .72691 L F
.60859 .73037 m .60903 .72689 L .60869 .73029 L 0 1 0 r
F
.60891 .72686 m .62272 .73533 L .60892 .72691 L 1 0 0 r
F
.60892 .72691 m .60903 .72689 L p .60895 .72748 L 0 1 0 r
F P
0 g
s
.60859 .73037 m .60892 .72691 L .60895 .72748 L 0 1 0 r
F
.60892 .72691 m .60883 .7268 L p .60891 .72685 L 1 0 0 r
F P
0 g
s
.60849 .72479 m .62272 .73533 L .60883 .7268 L 1 0 0 r
F
.59816 .73166 m .60883 .7268 L .60851 .73032 L 0 0 1 r
F
.60883 .7268 m .60892 .72691 L p .60882 .72688 L 1 0 0 r
F P
0 g
s
.60892 .72691 m .60528 .72762 L p .60856 .72484 L 0 1 0 r
F P
0 g
s
.62272 .73533 m .61525 .73455 L .60892 .72691 L p 1 0 0 r
F P
0 g
s
.60885 .72183 m .60876 .72197 L p .60836 .71924 L 0 1 0 r
F P
0 g
s
.60876 .72197 m .60869 .72198 L p .60868 .7215 L 1 0 0 r
F P
0 g
s
.60869 .72198 m .60502 .72222 L p .60828 .71977 L 1 0 0 r
F P
0 g
s
.60869 .72198 m .60517 .72522 L p .60818 .71926 L 0 0 1 r
F P
0 g
s
.60876 .72197 m .60528 .72762 L p .60829 .71944 L 0 1 0 r
F P
0 g
s
.60836 .71924 m .60876 .72197 L .60829 .71944 L 0 1 0 r
F
.60861 .71952 m .60876 .72197 L .60868 .7215 L 1 0 0 r
F
.60861 .71952 m .60869 .72198 L .60828 .71977 L F
.60517 .72522 m .5953 .72095 L p .60818 .71926 L 0 0 1 r
F P
0 g
s
.60517 .72522 m .59816 .73166 L .58831 .72741 L p 0 0 1 r
F P
0 g
s
.59488 .71139 m .60211 .70974 L .60804 .71668 L p 1 0 0 r
F P
0 g
s
.60804 .71668 m .60837 .71707 L p .60802 .71692 L 1 0 0 r
F P
0 g
s
.59488 .71139 m .60804 .71668 L .60802 .71692 L 1 0 0 r
F
.60211 .70974 m .59194 .69921 L p .60788 .70809 L F P
0 g
s
.60788 .70809 m .60791 .70826 L .60211 .70974 L 1 0 0 r
F
.60937 .70716 m .6189 .70466 L p .60857 .71316 L 0 1 0 r
F P
0 g
s
.60843 .71328 m .60853 .71264 L .60857 .71316 L 0 1 0 r
F
.60853 .71264 m .60937 .70716 L .60857 .71316 L F
.608 .70871 m .60806 .70807 L .60808 .70912 L 0 0 1 r
F
.60788 .70809 m .60806 .70807 L .608 .70871 L F
.57777 .70542 m .58481 .70194 L .59488 .71139 L p 1 0 0 r
F P
0 g
s
.60211 .70974 m .59488 .71139 L .58481 .70194 L p 1 0 0 r
F P
0 g
s
.58481 .70194 m .59194 .69921 L .60211 .70974 L p 1 0 0 r
F P
0 g
s
.60813 .70734 m .60937 .70716 L p .60806 .70807 L 0 1 0 r
F P
0 g
s
.60937 .70716 m .60824 .70897 L p .60806 .70807 L 0 1 0 r
F P
0 g
s
.6084 .71279 m .60937 .70716 L .60843 .71328 L 0 1 0 r
F
.6087 .70824 m .60937 .70716 L p .6083 .71339 L F P
0 g
s
.60794 .70726 m .60813 .70734 L p .6081 .70806 L 0 0 1 r
F P
0 g
s
.60813 .70734 m .6094 .70789 L p .60827 .70804 L 0 0 1 r
F P
0 g
s
.6081 .70806 m .60813 .70734 L .60827 .70804 L 0 0 1 r
F
.6162 .69531 m .60937 .70716 L .60813 .70734 L p 0 1 0 r
F P
0 g
s
.60788 .70809 m .60794 .70726 L .6081 .70806 L 0 0 1 r
F
.59194 .69921 m .60794 .70726 L .60794 .70731 L 1 0 0 r
F
.60802 .70742 m .60803 .70735 L .60803 .70741 L 0 1 0 r
F
.60788 .70809 m .60803 .70735 L .60796 .70814 L 1 0 0 r
F
.59194 .69921 m .60794 .70731 L .60788 .70809 L F
.60794 .70731 m .60803 .70735 L .60788 .70809 L F
.60717 .70254 m .6162 .69531 L .60813 .70734 L 0 1 0 r
F
.62566 .69187 m .6189 .70466 L .60937 .70716 L p F P
0 g
s
.60937 .70716 m .6162 .69531 L .62566 .69187 L p 0 1 0 r
F P
0 g
s
.61652 .70131 m .6094 .70789 L .60794 .70726 L p 0 0 1 r
F P
0 g
s
.59194 .69921 m .59918 .69729 L .60794 .70726 L p 1 0 0 r
F P
0 g
s
.59918 .69729 m .60705 .70255 L .60714 .70303 L 1 0 0 r
F
.60794 .70726 m .60743 .70667 L p .60714 .70303 L F P
0 g
s
.60743 .70667 m .59918 .69729 L p .60714 .70303 L 1 0 0 r
F P
0 g
s
.60794 .70726 m .60689 .7068 L p .60834 .70238 L 0 0 1 r
F P
0 g
s
.59918 .69729 m .60653 .69625 L .60737 .69729 L p 1 0 0 r
F P
0 g
s
.60689 .7068 m .6068 .70675 L p .60717 .70254 L 0 0 1 r
F P
0 g
s
.60705 .70255 m .60717 .70254 L .6068 .70675 L 0 0 1 r
F
.60717 .70254 m .60834 .70238 L .60689 .7068 L F
.59918 .69729 m .60737 .69729 L .60705 .70255 L 1 0 0 r
F
.60753 .69735 m .6162 .69531 L p .60791 .70195 L 0 1 0 r
F P
0 g
s
.60717 .70254 m .60753 .69735 L .60791 .70195 L 0 1 0 r
F
.59946 .70355 m .60656 .69694 L .60737 .69729 L p 0 0 1 r
F P
0 g
s
.60752 .69735 m .60753 .69735 L p .60749 .69796 L 0 1 0 r
F P
0 g
s
.60748 .6979 m .60752 .69735 L .60749 .69796 L 0 1 0 r
F
.62301 .68257 m .6162 .69531 L .60752 .69735 L p F P
0 g
s
.60741 .69682 m .62301 .68257 L .60752 .69735 L 0 1 0 r
F
.62368 .69468 m .61652 .70131 L .60737 .69729 L p 0 0 1 r
F P
0 g
s
.60737 .69729 m .60656 .69694 L p .60729 .69684 L 0 0 1 r
F P
0 g
s
.61348 .68576 m .62301 .68257 L p .60741 .69682 L 0 1 0 r
F P
0 g
s
.60737 .69729 m .60653 .69625 L p .60729 .69684 L 1 0 0 r
F P
0 g
s
.60741 .69682 m .62368 .69468 L .60739 .69729 L 0 0 1 r
F
.60752 .69735 m .61652 .70131 L p .60851 .70236 L F P
0 g
s
.60834 .70238 m .61652 .70131 L .60794 .70726 L 0 0 1 r
F
.62827 .70097 m .62156 .71381 L .6121 .71656 L p 0 1 0 r
F P
0 g
s
.6121 .71656 m .6189 .70466 L .62827 .70097 L p 0 1 0 r
F P
0 g
s
.63494 .6872 m .62827 .70097 L .6189 .70466 L p 0 1 0 r
F P
0 g
s
.6189 .70466 m .62566 .69187 L .63494 .6872 L p 0 1 0 r
F P
0 g
s
.59488 .71139 m .60837 .71707 L .60837 .71713 L 1 0 0 r
F
.6189 .70466 m .6121 .71656 L .60857 .71715 L p 0 1 0 r
F P
0 g
s
.60837 .71707 m .60857 .71715 L p .60848 .71764 L 0 0 1 r
F P
0 g
s
.60818 .71926 m .60837 .71707 L .60848 .71764 L 0 0 1 r
F
.60211 .70974 m .60777 .71373 L .60787 .71427 L 1 0 0 r
F
.60837 .71707 m .60804 .71668 L p .60787 .71427 L F P
0 g
s
.60804 .71668 m .60211 .70974 L p .60787 .71427 L 1 0 0 r
F P
0 g
s
.60791 .71371 m .6189 .70466 L .60857 .71715 L 0 1 0 r
F
.60857 .71715 m .6121 .71656 L p .60836 .71924 L F P
0 g
s
.6121 .71656 m .60885 .72183 L p .60836 .71924 L 0 1 0 r
F P
0 g
s
.6193 .71222 m .61221 .71874 L .6077 .71677 L p 0 0 1 r
F P
0 g
s
.6077 .71677 m .60758 .71672 L p .60791 .71371 L 0 0 1 r
F P
0 g
s
.60777 .71373 m .60791 .71371 L .60758 .71672 L 0 0 1 r
F
.60791 .71371 m .6193 .71222 L .6077 .71677 L F
.60791 .71371 m .6087 .70824 L .6083 .71339 L 0 1 0 r
F
.60211 .70974 m .60808 .70912 L p .60777 .71373 L 1 0 0 r
F P
0 g
s
.60796 .71295 m .6087 .70824 L .60791 .71371 L 0 1 0 r
F
.6083 .71339 m .6084 .71279 L .60843 .71328 L F
.6094 .70789 m .6193 .71222 L p .60791 .71371 L 0 0 1 r
F P
0 g
s
.60827 .70894 m .60808 .70912 L p .6081 .70806 L 0 0 1 r
F P
0 g
s
.60824 .70897 m .60815 .70911 L p .60806 .70807 L 0 1 0 r
F P
0 g
s
.60815 .70911 m .60808 .70912 L p .60808 .70877 L 1 0 0 r
F P
0 g
s
.60808 .70912 m .60211 .70974 L p .60791 .70826 L 1 0 0 r
F P
0 g
s
.60806 .70807 m .60809 .70825 L .60808 .70912 L 0 0 1 r
F
.60806 .70807 m .60815 .70911 L .60797 .70822 L 0 1 0 r
F
.60809 .70821 m .60808 .70912 L .60791 .70826 L 1 0 0 r
F
.60233 .71444 m .60808 .70912 L p .60791 .71371 L 0 0 1 r
F P
0 g
s
.60808 .70912 m .60819 .70968 L .60791 .71371 L 0 0 1 r
F
.60808 .70912 m .60824 .70897 L p .60819 .70968 L F P
0 g
s
.60824 .70897 m .6087 .70824 L p .60796 .71295 L 0 1 0 r
F P
0 g
s
.60824 .70897 m .6094 .70789 L p .60791 .71371 L 0 0 1 r
F P
0 g
s
.60808 .70912 m .60815 .70911 L p .60777 .71373 L 1 0 0 r
F P
0 g
s
.60815 .70911 m .60824 .70897 L p .60784 .71377 L 0 1 0 r
F P
0 g
s
.60824 .70897 m .60796 .71295 L .60784 .71377 L 0 1 0 r
F
.60815 .70911 m .60946 .70897 L p .60785 .7135 L 1 0 0 r
F P
0 g
s
.60815 .70911 m .60785 .7135 L .60777 .71373 L 1 0 0 r
F
.60784 .71377 m .60796 .71295 L .60791 .71371 L 0 1 0 r
F
.60857 .71715 m .60846 .71717 L p .60791 .71371 L F P
0 g
s
.60784 .71377 m .60791 .71371 L .60846 .71717 L 0 1 0 r
F
.62916 .71653 m .62205 .72302 L .61221 .71874 L p 0 0 1 r
F P
0 g
s
.61221 .71874 m .6193 .71222 L .62916 .71653 L p 0 0 1 r
F P
0 g
s
.60946 .70897 m .61983 .72221 L p .60784 .71377 L 1 0 0 r
F P
0 g
s
.60777 .71373 m .60785 .7135 L .60784 .71377 L 1 0 0 r
F
.60785 .7135 m .60946 .70897 L .60784 .71377 L F
.60757 .71004 m .60815 .70911 L p .60784 .71377 L 0 1 0 r
F P
0 g
s
.60758 .71672 m .60233 .71444 L p .60777 .71373 L 0 0 1 r
F P
0 g
s
.59488 .71139 m .60408 .7153 L .60344 .71646 L 1 0 0 r
F
.60408 .7153 m .60846 .71717 L .60344 .71646 L F
.60344 .71646 m .60846 .71717 L .60826 .71931 L F
.5953 .72095 m .60233 .71444 L .60837 .71707 L p 0 0 1 r
F P
0 g
s
.60429 .71529 m .6025 .71816 L p .60412 .71522 L 0 1 0 r
F P
0 g
s
.60808 .70912 m .60233 .71444 L p .60788 .70809 L 0 0 1 r
F P
0 g
s
.60797 .70822 m .60429 .71529 L .60412 .71522 L 0 1 0 r
F
.60815 .70911 m .60429 .71529 L p .60797 .70822 L F P
0 g
s
.60809 .70821 m .60815 .70911 L .60808 .70877 L 1 0 0 r
F
.60857 .71715 m .61221 .71874 L p .60895 .71916 L 0 0 1 r
F P
0 g
s
.60777 .71373 m .60824 .71406 L .60837 .71707 L 1 0 0 r
F
.61221 .71874 m .60885 .72183 L p .60905 .71915 L 0 0 1 r
F P
0 g
s
.60824 .71406 m .61983 .72221 L .60845 .7171 L 1 0 0 r
F
.60824 .71406 m .60845 .7171 L .60837 .71707 L F
.5953 .72095 m .60837 .71707 L .60818 .71926 L 0 0 1 r
F
.58831 .72741 m .5953 .72095 L .60517 .72522 L p F P
0 g
s
.59562 .72835 m .60846 .71724 L .60836 .71924 L 0 1 0 r
F
.60846 .71724 m .60857 .71715 L .6085 .71779 L F
.60818 .71926 m .60857 .71715 L .60895 .71916 L 0 0 1 r
F
.60846 .71724 m .6085 .71779 L .60836 .71924 L 0 1 0 r
F
.6025 .71816 m .60757 .71004 L p .60784 .71377 L F P
0 g
s
.60846 .71717 m .60837 .71707 L p .60845 .7171 L 1 0 0 r
F P
0 g
s
.60837 .71707 m .60846 .71717 L p .60837 .71713 L 1 0 0 r
F P
0 g
s
.60846 .71717 m .6025 .71816 L p .60784 .71377 L 0 1 0 r
F P
0 g
s
.60846 .71717 m .60857 .71715 L p .60845 .71725 L 0 1 0 r
F P
0 g
s
.61983 .72221 m .61236 .72174 L .60846 .71717 L p 1 0 0 r
F P
0 g
s
.60845 .7171 m .61983 .72221 L .60846 .71717 L 1 0 0 r
F
.6193 .71222 m .62643 .70566 L .63631 .70999 L p 0 0 1 r
F P
0 g
s
.62643 .70566 m .6193 .71222 L .6094 .70789 L p 0 0 1 r
F P
0 g
s
.6094 .70789 m .61652 .70131 L .62643 .70566 L p 0 0 1 r
F P
0 g
s
.63361 .69906 m .62643 .70566 L .61652 .70131 L p 0 0 1 r
F P
0 g
s
.61652 .70131 m .62368 .69468 L .63361 .69906 L p 0 0 1 r
F P
0 g
s
.61401 .69615 m .62455 .71036 L p .60734 .69689 L 1 0 0 r
F P
0 g
s
.60744 .69612 m .61348 .68576 L p .60741 .69682 L 0 1 0 r
F P
0 g
s
.63237 .67814 m .62566 .69187 L .6162 .69531 L p 0 1 0 r
F P
0 g
s
.6162 .69531 m .62301 .68257 L .63237 .67814 L p 0 1 0 r
F P
0 g
s
.61371 .69028 m .62368 .69468 L p .60729 .69684 L 0 0 1 r
F P
0 g
s
.60656 .69694 m .60731 .69624 L p .60729 .69684 L 0 0 1 r
F P
0 g
s
.60731 .69624 m .60744 .69612 L p .60741 .69672 L 0 0 1 r
F P
0 g
s
.60744 .69612 m .61371 .69028 L p .60754 .69659 L 0 0 1 r
F P
0 g
s
.60744 .69612 m .60754 .69659 L .60741 .69672 L 0 0 1 r
F
.60653 .69625 m .59623 .68486 L p .60631 .69126 L 1 0 0 r
F P
0 g
s
.60653 .69625 m .59918 .69729 L .58898 .68703 L p 1 0 0 r
F P
0 g
s
.58898 .68703 m .59623 .68486 L .60653 .69625 L p 1 0 0 r
F P
0 g
s
.59657 .69255 m .60631 .69126 L .60636 .69231 L 0 0 1 r
F
.60608 .69672 m .59657 .69255 L p .60636 .69231 L F P
0 g
s
.59918 .69729 m .59194 .69921 L .58183 .69 L p 1 0 0 r
F P
0 g
s
.58183 .69 m .58898 .68703 L .59918 .69729 L p 1 0 0 r
F P
0 g
s
.59194 .69921 m .58481 .70194 L .57478 .69373 L p 1 0 0 r
F P
0 g
s
.57478 .69373 m .58183 .69 L .59194 .69921 L p 1 0 0 r
F P
0 g
s
.60656 .69694 m .59946 .70355 L .58949 .69919 L p 0 0 1 r
F P
0 g
s
.58949 .69919 m .59657 .69255 L .60656 .69694 L p 0 0 1 r
F P
0 g
s
.60359 .68355 m .59325 .67242 L p .60529 .6797 L 1 0 0 r
F P
0 g
s
.60529 .6797 m .60555 .67985 L .60534 .68024 L 1 0 0 r
F
.60529 .6797 m .60534 .68024 L .60359 .68355 L F
.60062 .67088 m .59025 .65999 L p .60476 .66833 L F P
0 g
s
.60476 .66833 m .60483 .66865 L .60062 .67088 L 1 0 0 r
F
.60791 .66607 m .6176 .66332 L p .60561 .67375 L 0 1 0 r
F P
0 g
s
.60549 .67257 m .60791 .66607 L .60561 .67375 L 0 1 0 r
F
.60484 .6687 m .60486 .66831 L .60524 .67049 L 0 0 1 r
F
.60476 .66833 m .60486 .66831 L .60484 .6687 L F
.60486 .66831 m .60527 .67011 L .60524 .67049 L F
.60534 .6704 m .60791 .66607 L p .60525 .67323 L 0 1 0 r
F P
0 g
s
.60522 .6741 m .60549 .67257 L .60561 .67375 L 0 1 0 r
F
.62712 .65937 m .62032 .67305 L .61071 .67601 L p F P
0 g
s
.61071 .67601 m .6176 .66332 L .62712 .65937 L p 0 1 0 r
F P
0 g
s
.59325 .67242 m .60062 .67088 L .6057 .67685 L p 1 0 0 r
F P
0 g
s
.6057 .67685 m .60583 .67691 L p .60572 .67696 L 0 0 1 r
F P
0 g
s
.60569 .67697 m .6057 .67685 L .60572 .67696 L 0 0 1 r
F
.61071 .67601 m .62032 .67305 L p .60653 .68534 L 0 1 0 r
F P
0 g
s
.60653 .68528 m .61071 .67601 L .60653 .68534 L 0 1 0 r
F
.60659 .68302 m .61071 .67601 L p .60648 .68539 L F P
0 g
s
.61071 .67601 m .60641 .68332 L p .60566 .67984 L 0 1 0 r
F P
0 g
s
.59325 .67242 m .6054 .6768 L .60557 .67944 L 1 0 0 r
F
.60555 .67985 m .60557 .67944 L .60566 .67984 L 0 0 1 r
F
.60555 .67985 m .60557 .67944 L .6056 .67988 L 1 0 0 r
F
.59325 .67242 m .60557 .67944 L .60555 .67985 L F
.60359 .68355 m .59623 .68486 L .58599 .67484 L p F P
0 g
s
.58599 .67484 m .59325 .67242 L .60359 .68355 L p 1 0 0 r
F P
0 g
s
.59364 .68144 m .60508 .67719 L .60557 .67944 L 0 0 1 r
F
.59364 .68144 m .60557 .67944 L .60555 .67985 L F
.60557 .67944 m .60583 .67691 L .60566 .67984 L F
.60569 .67697 m .60583 .67691 L .60557 .67944 L F
.60557 .67944 m .60576 .67693 L .6056 .67988 L 1 0 0 r
F
.6054 .6768 m .60569 .6769 L .60557 .67944 L F
.60569 .6769 m .60576 .67693 L .60557 .67944 L F
.60508 .67719 m .60569 .67697 L .60557 .67944 L 0 0 1 r
F
.60583 .67691 m .61071 .67601 L p .60566 .67984 L 0 1 0 r
F P
0 g
s
.60555 .67985 m .60571 .68063 L .60359 .68355 L 1 0 0 r
F
.60563 .68025 m .60653 .68006 L .60631 .68342 L 0 0 1 r
F
.60633 .68552 m .60659 .68302 L .60648 .68539 L 0 1 0 r
F
.60641 .68332 m .60659 .68302 L p .60633 .68552 L F P
0 g
s
.61087 .67915 m .60641 .68332 L p .60653 .68006 L 0 0 1 r
F P
0 g
s
.60641 .68332 m .60631 .68342 L p .60653 .68006 L 0 0 1 r
F P
0 g
s
.59623 .68486 m .60359 .68355 L .60641 .68697 L p 1 0 0 r
F P
0 g
s
.59623 .68486 m .60641 .68697 L .6064 .68715 L 1 0 0 r
F
.61348 .68576 m .60744 .69612 L p .60642 .69125 L 0 1 0 r
F P
0 g
s
.61371 .69028 m .60731 .69624 L p .60631 .69126 L 0 0 1 r
F P
0 g
s
.60668 .68718 m .61348 .68576 L p .60694 .69084 L 0 1 0 r
F P
0 g
s
.60642 .69125 m .60665 .68769 L .60694 .69084 L 0 1 0 r
F
.60665 .68769 m .60668 .68718 L .60694 .69084 L F
.62032 .67305 m .61348 .68576 L .60668 .68718 L p F P
0 g
s
.60654 .68712 m .60668 .68718 L p .60732 .69113 L 0 0 1 r
F P
0 g
s
.60631 .69126 m .60654 .68712 L .60732 .69113 L 0 0 1 r
F
.60633 .68552 m .62032 .67305 L .60668 .68718 L 0 1 0 r
F
.62976 .66887 m .62301 .68257 L .61348 .68576 L p F P
0 g
s
.61348 .68576 m .62032 .67305 L .62976 .66887 L p 0 1 0 r
F P
0 g
s
.6209 .68359 m .61371 .69028 L .60654 .68712 L p 0 0 1 r
F P
0 g
s
.60654 .68712 m .60641 .68697 L p .60632 .68599 L 1 0 0 r
F P
0 g
s
.60641 .68697 m .60359 .68355 L p .60623 .68553 L 1 0 0 r
F P
0 g
s
.60648 .68539 m .60653 .68528 L .60653 .68534 L 0 1 0 r
F
.61087 .67915 m .6209 .68359 L p .60623 .68553 L 0 0 1 r
F P
0 g
s
.60359 .68355 m .60631 .68342 L p .60623 .68553 L 1 0 0 r
F P
0 g
s
.6037 .68587 m .60631 .68342 L p .60623 .68553 L 0 0 1 r
F P
0 g
s
.60631 .68342 m .61087 .67915 L p .60623 .68553 L 0 0 1 r
F P
0 g
s
.60623 .68553 m .6209 .68359 L .60654 .68712 L 0 0 1 r
F
.60628 .68557 m .60641 .68332 L .60633 .68552 L 0 1 0 r
F
.60611 .68383 m .60636 .68342 L p .60628 .68557 L F P
0 g
s
.60636 .68342 m .60641 .68332 L p .60628 .68557 L 0 1 0 r
F P
0 g
s
.60668 .68718 m .6066 .6872 L p .60633 .68552 L 0 1 0 r
F P
0 g
s
.60628 .68557 m .60633 .68552 L .6066 .6872 L 0 1 0 r
F
.60668 .68718 m .61371 .69028 L p .6075 .6911 L 0 0 1 r
F P
0 g
s
.64155 .67245 m .63494 .6872 L .62566 .69187 L p 0 1 0 r
F P
0 g
s
.62566 .69187 m .63237 .67814 L .64155 .67245 L p 0 1 0 r
F P
0 g
s
.63088 .68801 m .62368 .69468 L .61371 .69028 L p 0 0 1 r
F P
0 g
s
.61371 .69028 m .6209 .68359 L .63088 .68801 L p 0 0 1 r
F P
0 g
s
.61107 .68319 m .62163 .69707 L p .60628 .68557 L 1 0 0 r
F P
0 g
s
.60623 .68553 m .60628 .68551 L .60628 .68557 L 1 0 0 r
F
.60628 .68551 m .61107 .68319 L .60628 .68557 L F
.60636 .68342 m .60631 .68342 L p .60628 .68305 L F P
0 g
s
.60605 .68016 m .60636 .68342 L .60628 .68305 L 1 0 0 r
F
.60566 .67984 m .61087 .67915 L .60563 .68025 L 0 0 1 r
F
.60566 .67984 m .60632 .68291 L .60627 .68302 L 0 1 0 r
F
.60631 .68342 m .60359 .68355 L p .60571 .68063 L 1 0 0 r
F P
0 g
s
.60566 .67984 m .60627 .68302 L .60562 .67999 L 0 1 0 r
F
.60575 .68058 m .60631 .68342 L .60571 .68063 L 1 0 0 r
F
.60605 .68016 m .60628 .68305 L .60575 .68058 L F
.60628 .68305 m .60631 .68342 L .60575 .68058 L F
.60623 .68553 m .60632 .68599 L .60641 .68697 L F
.60654 .68712 m .6037 .68587 L p .60623 .68553 L 0 0 1 r
F P
0 g
s
.59623 .68486 m .60653 .68718 L .60631 .69126 L 1 0 0 r
F
.60641 .68697 m .6066 .6872 L p .6064 .68715 L F P
0 g
s
.59657 .69255 m .6037 .68587 L .60654 .68712 L p 0 0 1 r
F P
0 g
s
.60631 .68342 m .6037 .68587 L p .60555 .67985 L 0 0 1 r
F P
0 g
s
.60636 .68342 m .60379 .68779 L p .60627 .68302 L 0 1 0 r
F P
0 g
s
.60632 .68291 m .60636 .68342 L .60627 .68302 L 0 1 0 r
F
.60562 .67999 m .60627 .68302 L .60379 .68779 L F
.60641 .68332 m .60636 .68342 L p .60632 .68291 L F P
0 g
s
.60631 .68342 m .60636 .68342 L p .60623 .68553 L 1 0 0 r
F P
0 g
s
.60636 .68342 m .61107 .68319 L p .60648 .68541 L 1 0 0 r
F P
0 g
s
.60636 .68342 m .60648 .68541 L .60623 .68553 L 1 0 0 r
F
.6037 .68587 m .59364 .68144 L p .60513 .67991 L 0 0 1 r
F P
0 g
s
.60513 .67991 m .60555 .67985 L .60529 .6807 L 0 0 1 r
F
.60513 .67991 m .60529 .6807 L .6037 .68587 L F
.60623 .68553 m .60628 .68557 L .60632 .68599 L 1 0 0 r
F
.6066 .6872 m .60654 .68712 L p .60628 .68557 L F P
0 g
s
.60632 .68599 m .60628 .68557 L .60654 .68712 L 1 0 0 r
F
.60379 .68779 m .60611 .68383 L p .60628 .68557 L 0 1 0 r
F P
0 g
s
.60628 .68557 m .60646 .68571 L .6066 .6872 L 1 0 0 r
F
.59657 .69255 m .60654 .68712 L .60631 .69126 L 0 0 1 r
F
.6066 .6872 m .60379 .68779 L p .60628 .68557 L 0 1 0 r
F P
0 g
s
.60732 .69113 m .60668 .68718 L .6075 .6911 L 0 0 1 r
F
.6066 .6872 m .60668 .68718 L p .6066 .68728 L 0 1 0 r
F P
0 g
s
.60631 .69126 m .6066 .6872 L .60636 .69129 L 1 0 0 r
F
.60653 .68718 m .6066 .6872 L .60631 .69126 L F
.60631 .69126 m .60637 .69157 L .60653 .69625 L F
.60636 .69129 m .60684 .69364 L .60653 .69625 L F
.60731 .69624 m .60653 .69625 L p .60682 .6938 L F P
0 g
s
.60653 .69625 m .60731 .69624 L p .60729 .69684 L 1 0 0 r
F P
0 g
s
.60731 .69624 m .60656 .69694 L p .60631 .69126 L 0 0 1 r
F P
0 g
s
.59684 .69869 m .60668 .68718 L .60642 .69125 L 0 1 0 r
F
.62163 .69707 m .61401 .69615 L .6066 .6872 L p 1 0 0 r
F P
0 g
s
.60646 .68571 m .62163 .69707 L .6066 .6872 L 1 0 0 r
F
.6037 .68587 m .59657 .69255 L .58653 .68814 L p 0 0 1 r
F P
0 g
s
.58898 .68703 m .58183 .69 L .57177 .68201 L p 1 0 0 r
F P
0 g
s
.57177 .68201 m .57883 .67805 L .58898 .68703 L p 1 0 0 r
F P
0 g
s
.59623 .68486 m .58898 .68703 L .57883 .67805 L p 1 0 0 r
F P
0 g
s
.57883 .67805 m .58599 .67484 L .59623 .68486 L p 1 0 0 r
F P
0 g
s
.58653 .68814 m .59364 .68144 L .6037 .68587 L p 0 0 1 r
F P
0 g
s
.59396 .68869 m .60576 .67698 L .60566 .67984 L 0 1 0 r
F
.60576 .67698 m .60583 .67691 L .6058 .67738 L F
.60576 .67698 m .6058 .67738 L .60566 .67984 L F
.6176 .66332 m .61071 .67601 L .60583 .67691 L p F P
0 g
s
.61808 .67238 m .61087 .67915 L .60583 .67691 L p 0 0 1 r
F P
0 g
s
.6057 .67685 m .60062 .67088 L p .60513 .67411 L 1 0 0 r
F P
0 g
s
.60583 .67691 m .60506 .67657 L p .60522 .6741 L 0 0 1 r
F P
0 g
s
.60513 .67411 m .60522 .6741 L .60506 .67657 L 0 0 1 r
F
.60522 .6741 m .60553 .67383 L .60572 .67639 L 0 1 0 r
F
.60582 .67686 m .6176 .66332 L .60583 .67691 L F
.60553 .67383 m .6176 .66332 L .60576 .67693 L F
.60522 .6741 m .61808 .67238 L .60583 .67691 L 0 0 1 r
F
.60517 .67414 m .60522 .6741 L .60576 .67693 L 0 1 0 r
F
.60522 .6741 m .60572 .67639 L .60576 .67693 L F
.608 .66789 m .61808 .67238 L p .60645 .67393 L 0 0 1 r
F P
0 g
s
.60522 .6741 m .60607 .6722 L .60645 .67393 L 0 0 1 r
F
.60607 .6722 m .608 .66789 L .60645 .67393 L F
.60525 .67323 m .60549 .67257 L .60522 .6741 L 0 1 0 r
F
.60534 .6704 m .608 .66789 L p .60522 .6741 L 0 0 1 r
F P
0 g
s
.59325 .67242 m .6057 .67685 L .60569 .6769 L 1 0 0 r
F
.60062 .67088 m .60524 .67049 L p .60513 .67411 L F P
0 g
s
.60524 .67049 m .60062 .67088 L p .60483 .66865 L 1 0 0 r
F P
0 g
s
.57581 .66607 m .58298 .66263 L .59325 .67242 L p 1 0 0 r
F P
0 g
s
.60062 .67088 m .59325 .67242 L .58298 .66263 L p 1 0 0 r
F P
0 g
s
.58298 .66263 m .59025 .65999 L .60062 .67088 L p 1 0 0 r
F P
0 g
s
.6008 .67469 m .59069 .67021 L p .60476 .66833 L 0 0 1 r
F P
0 g
s
.6008 .67469 m .59364 .68144 L .58355 .67698 L p 0 0 1 r
F P
0 g
s
.60439 .66633 m .60484 .66649 L .60484 .66653 L 1 0 0 r
F
.59025 .65999 m .60439 .66629 L .60439 .66633 L F
.60439 .66629 m .60484 .66649 L .60439 .66633 L F
.59764 .6582 m .58723 .64754 L p .60393 .65668 L F P
0 g
s
.60393 .65668 m .60396 .65679 L .59764 .6582 L 1 0 0 r
F
.60507 .65592 m .61484 .65338 L p .60477 .66196 L 0 1 0 r
F P
0 g
s
.60465 .66206 m .6047 .66137 L .60477 .66196 L 0 1 0 r
F
.6047 .66137 m .60507 .65592 L .60477 .66196 L F
.62444 .64965 m .6176 .66332 L .60791 .66607 L p F P
0 g
s
.60791 .66607 m .61484 .65338 L .62444 .64965 L p 0 1 0 r
F P
0 g
s
.61484 .65338 m .60791 .66607 L .60496 .66654 L p 0 1 0 r
F P
0 g
s
.60496 .66654 m .60791 .66607 L p .60486 .66831 L 0 1 0 r
F P
0 g
s
.60791 .66607 m .60534 .6704 L p .60486 .66831 L 0 1 0 r
F P
0 g
s
.60484 .66649 m .608 .66789 L p .60476 .66833 L 0 0 1 r
F P
0 g
s
.59025 .65999 m .6049 .66655 L .60481 .66835 L 1 0 0 r
F
.59069 .67021 m .59787 .66339 L .60484 .66649 L p 0 0 1 r
F P
0 g
s
.59069 .67021 m .60484 .66649 L .60476 .66833 L 0 0 1 r
F
.59025 .65999 m .59764 .6582 L .60484 .66649 L p 1 0 0 r
F P
0 g
s
.60484 .66649 m .6049 .66655 L p .60484 .66653 L 1 0 0 r
F P
0 g
s
.6049 .66655 m .60484 .66649 L p .60489 .66651 L 1 0 0 r
F P
0 g
s
.60406 .66256 m .61484 .65338 L .60496 .66654 L 0 1 0 r
F
.60484 .66649 m .59764 .6582 L p .60399 .66257 L 1 0 0 r
F P
0 g
s
.61524 .66106 m .608 .66789 L .60397 .6661 L p 0 0 1 r
F P
0 g
s
.60397 .6661 m .60391 .66607 L p .60406 .66256 L 0 0 1 r
F P
0 g
s
.60399 .66257 m .60406 .66256 L .60391 .66607 L 0 0 1 r
F
.60406 .66256 m .61524 .66106 L .60397 .6661 L F
.60406 .66256 m .60474 .65649 L .60454 .66216 L 0 1 0 r
F
.60421 .65737 m .60474 .65649 L p .60406 .66256 L F P
0 g
s
.60454 .66216 m .60459 .6615 L .60465 .66206 L 0 1 0 r
F
.60459 .6615 m .60507 .65592 L .60465 .66206 L F
.60474 .65649 m .60507 .65592 L p .60454 .66216 L F P
0 g
s
.60406 .66256 m .60411 .65746 L .60527 .6624 L 0 0 1 r
F
.59764 .6582 m .60411 .65746 L p .60399 .66257 L 1 0 0 r
F P
0 g
s
.59787 .66339 m .60312 .6584 L p .60406 .66256 L 0 0 1 r
F P
0 g
s
.60411 .65746 m .60421 .65737 L p .60527 .6624 L 0 0 1 r
F P
0 g
s
.60421 .65737 m .6051 .65652 L p .60525 .66182 L 0 0 1 r
F P
0 g
s
.60421 .65737 m .60525 .66182 L .60527 .6624 L 0 0 1 r
F
.60391 .66607 m .59787 .66339 L p .60399 .66257 L F P
0 g
s
.57276 .65406 m .57995 .6504 L .59025 .65999 L p 1 0 0 r
F P
0 g
s
.59764 .6582 m .59025 .65999 L .57995 .6504 L p 1 0 0 r
F P
0 g
s
.57995 .6504 m .58723 .64754 L .59764 .6582 L p 1 0 0 r
F P
0 g
s
.60407 .65606 m .60507 .65592 L p .60404 .65667 L 0 1 0 r
F P
0 g
s
.60396 .65601 m .60407 .65606 L p .6041 .65666 L 0 0 1 r
F P
0 g
s
.60507 .65592 m .60421 .65737 L p .60404 .65667 L 0 1 0 r
F P
0 g
s
.60407 .65606 m .6051 .65652 L p .60421 .65664 L 0 0 1 r
F P
0 g
s
.6041 .65666 m .60407 .65606 L .60421 .65664 L 0 0 1 r
F
.61204 .64324 m .60507 .65592 L .60407 .65606 L p 0 1 0 r
F P
0 g
s
.60393 .65668 m .60396 .65601 L .6041 .65666 L 0 0 1 r
F
.58723 .64754 m .60396 .65601 L .60396 .65605 L 1 0 0 r
F
.60401 .65611 m .60401 .65607 L .60401 .65611 L 0 1 0 r
F
.60393 .65668 m .60401 .65607 L .60398 .65671 L 1 0 0 r
F
.58723 .64754 m .60396 .65605 L .60393 .65668 L F
.60396 .65605 m .60401 .65607 L .60393 .65668 L F
.60286 .6509 m .61204 .64324 L .60407 .65606 L 0 1 0 r
F
.62173 .63972 m .61484 .65338 L .60507 .65592 L p F P
0 g
s
.60507 .65592 m .61204 .64324 L .62173 .63972 L p 0 1 0 r
F P
0 g
s
.61237 .64962 m .6051 .65652 L .60396 .65601 L p 0 0 1 r
F P
0 g
s
.58723 .64754 m .59463 .64553 L .60396 .65601 L p 1 0 0 r
F P
0 g
s
.59463 .64553 m .6028 .65091 L .60285 .65114 L 1 0 0 r
F
.60396 .65601 m .60335 .65533 L p .60285 .65114 L F P
0 g
s
.60335 .65533 m .59463 .64553 L p .60285 .65114 L 1 0 0 r
F P
0 g
s
.60396 .65601 m .60275 .65548 L p .60416 .65073 L 0 0 1 r
F P
0 g
s
.60214 .64444 m .5916 .63284 L p .60155 .63913 L 1 0 0 r
F P
0 g
s
.59463 .64553 m .60214 .64444 L .60289 .64535 L p 1 0 0 r
F P
0 g
s
.60214 .64444 m .59463 .64553 L .58419 .63506 L p 1 0 0 r
F P
0 g
s
.58419 .63506 m .5916 .63284 L .60214 .64444 L p 1 0 0 r
F P
0 g
s
.59193 .64044 m .60155 .63913 L .60159 .6395 L 0 0 1 r
F
.60149 .64473 m .59193 .64044 L p .60159 .6395 L F P
0 g
s
.59463 .64553 m .58723 .64754 L .57689 .63813 L p 1 0 0 r
F P
0 g
s
.57689 .63813 m .58419 .63506 L .59463 .64553 L p 1 0 0 r
F P
0 g
s
.59463 .64553 m .60289 .64535 L .60289 .64536 L 1 0 0 r
F
.59463 .64553 m .6029 .64536 L .6028 .65091 L F
.58723 .64754 m .57995 .6504 L .56968 .642 L p F P
0 g
s
.56968 .642 m .57689 .63813 L .58723 .64754 L p 1 0 0 r
F P
0 g
s
.60217 .64504 m .59492 .65197 L .58469 .6474 L p 0 0 1 r
F P
0 g
s
.58469 .6474 m .59193 .64044 L .60217 .64504 L p 0 0 1 r
F P
0 g
s
.59912 .63154 m .58854 .62013 L p .60023 .62724 L 1 0 0 r
F P
0 g
s
.60023 .62724 m .60026 .62737 L .59912 .63154 L 1 0 0 r
F
.60026 .62737 m .60049 .62827 L .60041 .62845 L F
.60026 .62737 m .60041 .62845 L .59912 .63154 L F
.60634 .62236 m .61618 .61921 L p .6015 .63298 L 0 1 0 r
F P
0 g
s
.6015 .63295 m .60634 .62236 L .6015 .63298 L 0 1 0 r
F
.60133 .63314 m .60147 .63113 L .60147 .63301 L F
.5916 .63284 m .59912 .63154 L .60147 .63435 L p 1 0 0 r
F P
0 g
s
.5916 .63284 m .60147 .63435 L .60147 .63452 L 1 0 0 r
F
.60921 .6329 m .61897 .62957 L p .6029 .64492 L 0 1 0 r
F P
0 g
s
.6029 .64491 m .60921 .6329 L .6029 .64492 L 0 1 0 r
F
.60289 .64433 m .60921 .6329 L p .60289 .64493 L F P
0 g
s
.60155 .63913 m .60159 .63913 L .60281 .64443 L 0 0 1 r
F
.60921 .6329 m .60287 .64437 L p .60159 .63913 L 0 1 0 r
F P
0 g
s
.60947 .63806 m .60287 .64437 L p .60159 .63913 L 0 0 1 r
F P
0 g
s
.60287 .64437 m .60281 .64443 L p .60159 .63913 L 0 0 1 r
F P
0 g
s
.60217 .64504 m .60149 .64473 L p .60159 .6395 L 0 0 1 r
F P
0 g
s
.60155 .63913 m .60219 .64183 L .60214 .64444 L 1 0 0 r
F
.60298 .6454 m .61204 .64324 L p .60355 .65032 L 0 1 0 r
F P
0 g
s
.60286 .6509 m .60298 .64572 L .60355 .65032 L 0 1 0 r
F
.60298 .64572 m .60298 .6454 L .60355 .65032 L F
.59492 .65197 m .60217 .64504 L .6029 .64536 L p 0 0 1 r
F P
0 g
s
.61897 .62957 m .61204 .64324 L .60298 .6454 L p 0 1 0 r
F P
0 g
s
.60287 .64494 m .61897 .62957 L .60298 .6454 L 0 1 0 r
F
.6029 .64536 m .60214 .64444 L p .60281 .64495 L 1 0 0 r
F P
0 g
s
.60289 .64535 m .6029 .64536 L p .60289 .64536 L 1 0 0 r
F P
0 g
s
.61969 .64267 m .61237 .64962 L .60288 .64535 L p 0 0 1 r
F P
0 g
s
.60287 .64494 m .61969 .64267 L .60288 .64535 L 0 0 1 r
F
.60298 .6454 m .61237 .64962 L p .60423 .65072 L F P
0 g
s
.60416 .65073 m .61237 .64962 L .60396 .65601 L 0 0 1 r
F
.6176 .66332 m .62444 .64965 L .63387 .64469 L p 0 1 0 r
F P
0 g
s
.63123 .63497 m .62444 .64965 L .61484 .65338 L p 0 1 0 r
F P
0 g
s
.61484 .65338 m .62173 .63972 L .63123 .63497 L p 0 1 0 r
F P
0 g
s
.6431 .63844 m .63646 .65417 L .62712 .65937 L p 0 1 0 r
F P
0 g
s
.62712 .65937 m .63387 .64469 L .6431 .63844 L p 0 1 0 r
F P
0 g
s
.63646 .65417 m .62976 .66887 L .62032 .67305 L p 0 1 0 r
F P
0 g
s
.62032 .67305 m .62712 .65937 L .63646 .65417 L p 0 1 0 r
F P
0 g
s
.63387 .64469 m .62712 .65937 L .6176 .66332 L p 0 1 0 r
F P
0 g
s
.61524 .66106 m .62253 .65418 L .63265 .65873 L p 0 0 1 r
F P
0 g
s
.62253 .65418 m .61524 .66106 L .6051 .65652 L p 0 0 1 r
F P
0 g
s
.6051 .65652 m .61237 .64962 L .62253 .65418 L p 0 0 1 r
F P
0 g
s
.64054 .62895 m .63387 .64469 L .62444 .64965 L p 0 1 0 r
F P
0 g
s
.62444 .64965 m .63123 .63497 L .64054 .62895 L p 0 1 0 r
F P
0 g
s
.62987 .64726 m .62253 .65418 L .61237 .64962 L p 0 0 1 r
F P
0 g
s
.61237 .64962 m .61969 .64267 L .62987 .64726 L p 0 0 1 r
F P
0 g
s
.60979 .64435 m .62057 .6587 L p .60281 .64495 L 1 0 0 r
F P
0 g
s
.60214 .64444 m .60281 .64443 L p .60281 .64495 L 1 0 0 r
F P
0 g
s
.60287 .64494 m .60289 .64433 L .60289 .64493 L 0 1 0 r
F
.60287 .64437 m .60289 .64433 L p .60287 .64494 L F P
0 g
s
.62856 .62502 m .62173 .63972 L .61204 .64324 L p 0 1 0 r
F P
0 g
s
.61204 .64324 m .61897 .62957 L .62856 .62502 L p 0 1 0 r
F P
0 g
s
.60947 .63806 m .61969 .64267 L p .60292 .64494 L 0 0 1 r
F P
0 g
s
.60281 .64443 m .60947 .63806 L p .60292 .64494 L 0 0 1 r
F P
0 g
s
.60289 .64493 m .6029 .64491 L .6029 .64492 L 0 1 0 r
F
.60281 .64443 m .60979 .64435 L p .60281 .64495 L 1 0 0 r
F P
0 g
s
.60288 .64535 m .6028 .64532 L p .60287 .64494 L 0 0 1 r
F P
0 g
s
.6028 .64532 m .60217 .64504 L p .60281 .64495 L 0 0 1 r
F P
0 g
s
.60281 .64495 m .60287 .64494 L .6028 .64532 L 0 0 1 r
F
.60217 .64504 m .60281 .64443 L p .60292 .64494 L F P
0 g
s
.6022 .64559 m .60287 .64437 L p .60287 .64494 L 0 1 0 r
F P
0 g
s
.60294 .64541 m .6029 .64536 L p .60289 .64522 L 1 0 0 r
F P
0 g
s
.60284 .64498 m .60287 .64494 L .60294 .64541 L 0 1 0 r
F
.60289 .64522 m .60289 .64501 L .60294 .64541 L 1 0 0 r
F
.60298 .6454 m .60294 .64541 L p .60287 .64494 L 0 1 0 r
F P
0 g
s
.60281 .64495 m .60289 .64501 L .6029 .64536 L 1 0 0 r
F
.60294 .64541 m .6022 .64559 L p .60284 .64498 L 0 1 0 r
F P
0 g
s
.6029 .64536 m .60298 .6454 L p .60408 .65074 L 0 0 1 r
F P
0 g
s
.60408 .65074 m .60298 .6454 L .60423 .65072 L 0 0 1 r
F
.59492 .65197 m .6029 .64536 L .60408 .65074 L F
.6029 .64536 m .60294 .64541 L p .6028 .65091 L 1 0 0 r
F P
0 g
s
.6028 .65091 m .60294 .64541 L .60283 .65093 L 1 0 0 r
F
.6022 .64559 m .60294 .64541 L p .60283 .65093 L 0 1 0 r
F P
0 g
s
.60294 .64541 m .60298 .6454 L p .60283 .65093 L 0 1 0 r
F P
0 g
s
.60275 .65548 m .60272 .65546 L p .60286 .6509 L 0 0 1 r
F P
0 g
s
.6028 .65091 m .60286 .6509 L .60272 .65546 L 0 0 1 r
F
.60286 .6509 m .60416 .65073 L .60275 .65548 L F
.60283 .65093 m .60298 .6454 L .60286 .6509 L 0 1 0 r
F
.60272 .65546 m .59492 .65197 L p .6028 .65091 L 0 0 1 r
F P
0 g
s
.5877 .65886 m .59492 .65197 L .60396 .65601 L p 0 0 1 r
F P
0 g
s
.60391 .65565 m .60286 .6509 L .60397 .65564 L 0 1 0 r
F
.60283 .65093 m .60286 .6509 L .60391 .65565 L F
.6028 .65091 m .60283 .65093 L .60396 .65601 L 1 0 0 r
F
.60283 .65093 m .60346 .65134 L .60392 .65569 L F
.60283 .65093 m .60392 .65569 L .60396 .65601 L F
.60401 .65607 m .60396 .65601 L p .60392 .65569 L F P
0 g
s
.5877 .65886 m .60396 .65601 L .60393 .65668 L 0 0 1 r
F
.60396 .65601 m .60401 .65607 L p .60396 .65605 L 1 0 0 r
F P
0 g
s
.60401 .65607 m .59515 .65732 L p .60391 .65565 L 0 1 0 r
F P
0 g
s
.60391 .65565 m .60397 .65564 L .60401 .65607 L 0 1 0 r
F
.59515 .65732 m .60283 .65093 L .60391 .65565 L F
.60392 .65569 m .60346 .65134 L .60401 .65607 L 1 0 0 r
F
.60294 .64541 m .61278 .65748 L p .60283 .65093 L F P
0 g
s
.62057 .6587 m .61278 .65748 L .60294 .64541 L p 1 0 0 r
F P
0 g
s
.60289 .64501 m .62057 .6587 L .60294 .64541 L 1 0 0 r
F
.60284 .64443 m .60281 .64443 L p .60219 .64173 L F P
0 g
s
.60281 .64443 m .60214 .64444 L p .60219 .64183 L 1 0 0 r
F P
0 g
s
.60219 .64173 m .60281 .64443 L .60219 .64183 L 1 0 0 r
F
.60287 .64437 m .60284 .64443 L p .60159 .63913 L 0 1 0 r
F P
0 g
s
.60223 .63956 m .60284 .64443 L .60219 .64173 L 1 0 0 r
F
.60155 .63913 m .60163 .63945 L .60195 .64295 L 0 0 1 r
F
.60163 .63945 m .60281 .64443 L .60195 .64295 L F
.60281 .64443 m .60217 .64504 L p .60195 .64295 L F P
0 g
s
.60284 .64443 m .6022 .64559 L p .60161 .63932 L 0 1 0 r
F P
0 g
s
.60159 .63913 m .60284 .64443 L .60161 .63932 L 0 1 0 r
F
.60168 .63454 m .60921 .6329 L p .60218 .63865 L F P
0 g
s
.60159 .63913 m .60167 .63482 L .60218 .63865 L 0 1 0 r
F
.60167 .63482 m .60168 .63454 L .60218 .63865 L F
.61618 .61921 m .60921 .6329 L .60168 .63454 L p F P
0 g
s
.6016 .6345 m .60168 .63454 L p .60263 .63899 L 0 0 1 r
F P
0 g
s
.60155 .63913 m .6016 .6345 L .60263 .63899 L 0 0 1 r
F
.60133 .63314 m .61618 .61921 L .60168 .63454 L 0 1 0 r
F
.62585 .61485 m .61897 .62957 L .60921 .6329 L p F P
0 g
s
.60921 .6329 m .61618 .61921 L .62585 .61485 L p 0 1 0 r
F P
0 g
s
.61682 .63104 m .60947 .63806 L .6016 .6345 L p 0 0 1 r
F P
0 g
s
.6016 .6345 m .60147 .63435 L p .60134 .63337 L 1 0 0 r
F P
0 g
s
.60147 .63435 m .59912 .63154 L p .60128 .63315 L 1 0 0 r
F P
0 g
s
.60026 .62737 m .6003 .62737 L .60127 .63145 L 0 0 1 r
F
.60634 .62236 m .60132 .6314 L p .60027 .62723 L 0 1 0 r
F P
0 g
s
.6003 .62737 m .60129 .62721 L .60127 .63122 L 0 0 1 r
F
.6003 .62737 m .60127 .63122 L .60127 .63145 L F
.60127 .63145 m .59912 .63154 L p .60049 .62827 L 1 0 0 r
F P
0 g
s
.59912 .63154 m .5916 .63284 L .58112 .62255 L p 1 0 0 r
F P
0 g
s
.58112 .62255 m .58854 .62013 L .59912 .63154 L p 1 0 0 r
F P
0 g
s
.60128 .63315 m .61682 .63104 L .6016 .6345 L 0 0 1 r
F
.60168 .63454 m .60947 .63806 L p .60276 .63897 L F P
0 g
s
.63795 .61922 m .63123 .63497 L .62173 .63972 L p 0 1 0 r
F P
0 g
s
.62173 .63972 m .62856 .62502 L .63795 .61922 L p 0 1 0 r
F P
0 g
s
.62706 .63568 m .61969 .64267 L .60947 .63806 L p 0 0 1 r
F P
0 g
s
.60947 .63806 m .61682 .63104 L .62706 .63568 L p 0 0 1 r
F P
0 g
s
.60147 .63301 m .6015 .63295 L .6015 .63298 L 0 1 0 r
F
.60147 .63113 m .60634 .62236 L p .60147 .63301 L F P
0 g
s
.60654 .62638 m .61682 .63104 L p .60128 .63315 L 0 0 1 r
F P
0 g
s
.59912 .63154 m .60127 .63145 L p .60128 .63315 L 1 0 0 r
F P
0 g
s
.59921 .63343 m .60127 .63145 L p .60128 .63315 L 0 0 1 r
F P
0 g
s
.60132 .6314 m .60147 .63113 L p .60133 .63314 L 0 1 0 r
F P
0 g
s
.60127 .63145 m .60654 .62638 L p .60128 .63315 L 0 0 1 r
F P
0 g
s
.60131 .63317 m .60132 .6314 L .60133 .63314 L 0 1 0 r
F
.60128 .63315 m .6013 .63145 L .60148 .6333 L 1 0 0 r
F
.60127 .63145 m .6013 .63145 L p .60128 .63315 L F P
0 g
s
.60679 .63122 m .61759 .64532 L p .60148 .6333 L 1 0 0 r
F P
0 g
s
.6013 .63145 m .60679 .63122 L p .60148 .6333 L 1 0 0 r
F P
0 g
s
.6005 .62824 m .60127 .63145 L .60049 .62827 L 1 0 0 r
F
.60027 .62723 m .60654 .62638 L .60026 .62737 L 0 0 1 r
F
.60027 .62723 m .60127 .63121 L .60125 .63125 L 0 1 0 r
F
.60027 .62723 m .60125 .63125 L .60026 .62729 L F
.60078 .62757 m .60125 .63126 L .6005 .62824 L 1 0 0 r
F
.60125 .63126 m .60127 .63145 L .6005 .62824 L F
.60128 .63315 m .60134 .63337 L .60147 .63435 L F
.6016 .6345 m .59921 .63343 L p .60128 .63315 L 0 0 1 r
F P
0 g
s
.5916 .63284 m .6016 .63454 L .60155 .63913 L 1 0 0 r
F
.60147 .63435 m .60163 .63455 L p .60147 .63452 L F P
0 g
s
.59193 .64044 m .59921 .63343 L .6016 .6345 L p 0 0 1 r
F P
0 g
s
.60127 .63145 m .59921 .63343 L p .60023 .62724 L 0 0 1 r
F P
0 g
s
.60026 .62729 m .60125 .63125 L .59929 .63506 L 0 1 0 r
F
.60132 .6314 m .60127 .63145 L p .60129 .62721 L 0 0 1 r
F P
0 g
s
.60132 .6314 m .6013 .63145 L p .60127 .63121 L 0 1 0 r
F P
0 g
s
.6013 .63145 m .59929 .63506 L p .60127 .63121 L 0 1 0 r
F P
0 g
s
.59921 .63343 m .58891 .62878 L p .59993 .62728 L 0 0 1 r
F P
0 g
s
.59993 .62728 m .60023 .62724 L .6001 .62802 L 0 0 1 r
F
.59993 .62728 m .6001 .62802 L .59921 .63343 L F
.60023 .62724 m .60027 .62723 L .60026 .62737 L F
.58419 .63506 m .57689 .63813 L .56658 .62989 L p 1 0 0 r
F P
0 g
s
.59921 .63343 m .59193 .64044 L .58164 .63582 L p 0 0 1 r
F P
0 g
s
.58854 .62013 m .59608 .61862 L .5998 .62299 L p 1 0 0 r
F P
0 g
s
.60654 .62638 m .60132 .6314 L p .60129 .62721 L 0 0 1 r
F P
0 g
s
.60031 .62355 m .60634 .62236 L p .60074 .62685 L 0 1 0 r
F P
0 g
s
.60027 .62723 m .60031 .62379 L .60074 .62685 L 0 1 0 r
F
.60031 .62379 m .60031 .62355 L .60074 .62685 L F
.61336 .60863 m .60634 .62236 L .60031 .62355 L p F P
0 g
s
.60024 .62352 m .60031 .62355 L p .60111 .62712 L 0 0 1 r
F P
0 g
s
.60023 .62724 m .60024 .62352 L .60111 .62712 L 0 0 1 r
F
.59972 .62122 m .60003 .62094 L .60031 .62355 L 0 1 0 r
F
.60003 .62094 m .61336 .60863 L .60061 .62321 L F
.60003 .62094 m .60061 .62321 L .60031 .62355 L F
.59301 .60569 m .58235 .59462 L p .59686 .60281 L 1 0 0 r
F P
0 g
s
.59686 .60281 m .59735 .60309 L .59694 .60333 L 1 0 0 r
F
.59686 .60281 m .59694 .60333 L .59301 .60569 L F
.58992 .59273 m .57921 .5818 L p .59577 .59083 L F P
0 g
s
.59577 .59083 m .59578 .59088 L .58992 .59273 L 1 0 0 r
F
.59578 .59088 m .59581 .59096 L .5958 .59096 L F
.59578 .59088 m .5958 .59096 L .58992 .59273 L F
.59751 .5895 m .60759 .58683 L p .59682 .59651 L 0 1 0 r
F P
0 g
s
.59652 .59461 m .59751 .5895 L .59682 .59651 L 0 1 0 r
F
.59577 .59083 m .59578 .59083 L .5961 .59202 L 0 0 1 r
F
.61749 .58297 m .61049 .59784 L .60049 .60066 L p 0 1 0 r
F P
0 g
s
.60049 .60066 m .60759 .58683 L .61749 .58297 L p 0 1 0 r
F P
0 g
s
.60759 .58683 m .60049 .60066 L .59737 .60117 L p 0 1 0 r
F P
0 g
s
.58235 .59462 m .58992 .59273 L .59733 .60115 L p 1 0 0 r
F P
0 g
s
.58235 .59462 m .59733 .60115 L .59733 .60116 L 1 0 0 r
F
.60049 .60066 m .61049 .59784 L p .59847 .60878 L 0 1 0 r
F P
0 g
s
.59829 .60758 m .60049 .60066 L .59847 .60878 L 0 1 0 r
F
.60344 .61161 m .61336 .60863 L p .60003 .62094 L F P
0 g
s
.59972 .62122 m .59997 .62057 L .60003 .62094 L 0 1 0 r
F
.59997 .62057 m .60344 .61161 L .60003 .62094 L F
.59852 .61504 m .59883 .61522 L .5989 .61563 L 1 0 0 r
F
.5992 .61771 m .5989 .61563 L .59938 .6184 L F
.59852 .61504 m .5989 .61563 L .5992 .61771 L F
.59608 .61862 m .58546 .60739 L p .59848 .61502 L F P
0 g
s
.59848 .61502 m .59849 .61507 L .59608 .61862 L 1 0 0 r
F
.59938 .6184 m .59608 .61862 L p .59852 .61504 L F P
0 g
s
.59999 .62322 m .59608 .61862 L p .59969 .62122 L 1 0 0 r
F P
0 g
s
.59608 .61862 m .58854 .62013 L .57802 .61001 L p 1 0 0 r
F P
0 g
s
.57802 .61001 m .58546 .60739 L .59608 .61862 L p 1 0 0 r
F P
0 g
s
.6231 .60445 m .61618 .61921 L .60634 .62236 L p 0 1 0 r
F P
0 g
s
.60634 .62236 m .61336 .60863 L .6231 .60445 L p 0 1 0 r
F P
0 g
s
.61392 .61928 m .60654 .62638 L .60024 .62352 L p 0 0 1 r
F P
0 g
s
.60016 .62318 m .61392 .61928 L .60024 .62352 L 0 0 1 r
F
.58854 .62013 m .5998 .62299 L .60025 .62725 L 1 0 0 r
F
.59975 .6233 m .59622 .6217 L p .59972 .62122 L 0 0 1 r
F P
0 g
s
.59969 .62122 m .59972 .62137 L .59999 .62322 L 1 0 0 r
F
.60024 .62352 m .59999 .62322 L p .59972 .62137 L F P
0 g
s
.5998 .62299 m .60024 .62352 L p .60023 .6271 L 1 0 0 r
F P
0 g
s
.59972 .62122 m .61392 .61928 L .59975 .6233 L 0 0 1 r
F
.59608 .61862 m .59965 .61838 L p .59969 .62122 L 1 0 0 r
F P
0 g
s
.60358 .61457 m .61392 .61928 L p .60036 .62113 L 0 0 1 r
F P
0 g
s
.59972 .62119 m .60344 .61161 L .59972 .62122 L 0 1 0 r
F
.59622 .6217 m .59968 .61851 L .59972 .62122 L 0 0 1 r
F
.59937 .61891 m .59968 .61835 L p .5997 .62124 L 0 1 0 r
F P
0 g
s
.59968 .61835 m .60344 .61161 L p .59972 .62119 L 0 1 0 r
F P
0 g
s
.59968 .61835 m .59972 .62119 L .5997 .62124 L 0 1 0 r
F
.59622 .6217 m .59965 .61838 L p .59968 .61851 L 0 0 1 r
F P
0 g
s
.59972 .62122 m .59968 .61851 L .60036 .62113 L 0 0 1 r
F
.59622 .6217 m .58586 .617 L p .59826 .6153 L F P
0 g
s
.59826 .6153 m .59883 .61522 L .59846 .61614 L 0 0 1 r
F
.59826 .6153 m .59846 .61614 L .59622 .6217 L F
.60344 .61161 m .59968 .61835 L p .59886 .61522 L 0 1 0 r
F P
0 g
s
.60358 .61457 m .59965 .61838 L p .59883 .61522 L 0 0 1 r
F P
0 g
s
.59965 .61838 m .59938 .6184 L p .59932 .61711 L 1 0 0 r
F P
0 g
s
.59883 .61522 m .59932 .61711 L .59938 .6184 L 1 0 0 r
F
.59965 .61838 m .59622 .6217 L p .59883 .61522 L 0 0 1 r
F P
0 g
s
.59883 .61522 m .59885 .61523 L .59932 .61711 L 1 0 0 r
F
.59885 .61523 m .59925 .61547 L .59932 .61705 L F
.59885 .61523 m .59932 .61705 L .59932 .61711 L F
.58891 .62878 m .59622 .6217 L .60024 .62352 L p 0 0 1 r
F P
0 g
s
.5738 .62583 m .58112 .62255 L .5916 .63284 L p 1 0 0 r
F P
0 g
s
.59622 .6217 m .58891 .62878 L .57856 .62411 L p 0 0 1 r
F P
0 g
s
.58112 .62255 m .5738 .62583 L .56344 .61772 L p 1 0 0 r
F P
0 g
s
.56344 .61772 m .57068 .61347 L .58112 .62255 L p 1 0 0 r
F P
0 g
s
.58854 .62013 m .58112 .62255 L .57068 .61347 L p 1 0 0 r
F P
0 g
s
.57068 .61347 m .57802 .61001 L .58854 .62013 L p 1 0 0 r
F P
0 g
s
.57856 .62411 m .58586 .617 L .59622 .6217 L p 0 0 1 r
F P
0 g
s
.59634 .62434 m .5862 .62521 L p .59885 .61523 L 0 1 0 r
F P
0 g
s
.59885 .61523 m .59886 .61522 L .59885 .61525 L 0 1 0 r
F
.59885 .61523 m .59885 .61525 L .59634 .62434 L F
.59965 .61838 m .59968 .61835 L p .60036 .62113 L 0 0 1 r
F P
0 g
s
.59965 .61838 m .59966 .61838 L p .59969 .62122 L 1 0 0 r
F P
0 g
s
.59968 .61835 m .60358 .61457 L p .60039 .62107 L 0 0 1 r
F P
0 g
s
.59968 .61835 m .60039 .62107 L .60036 .62113 L 0 0 1 r
F
.59966 .61838 m .60376 .6181 L p .59995 .62102 L 1 0 0 r
F P
0 g
s
.59966 .61838 m .59995 .62102 L .59969 .62122 L 1 0 0 r
F
.58546 .60739 m .59301 .60569 L .59848 .61201 L p F P
0 g
s
.59848 .61201 m .59882 .6124 L p .59883 .61512 L 1 0 0 r
F P
0 g
s
.58546 .60739 m .59848 .61201 L .59883 .61512 L 1 0 0 r
F
.58546 .60739 m .59883 .61512 L .59883 .61522 L F
.59848 .61502 m .59852 .61504 L .59849 .61507 L F
.58586 .617 m .59883 .61245 L .59886 .61522 L 0 0 1 r
F
.59883 .61245 m .59888 .61243 L .59888 .61263 L F
.59883 .61245 m .59888 .61263 L .59886 .61522 L F
.59888 .61243 m .60344 .61161 L p .59886 .61522 L 0 1 0 r
F P
0 g
s
.59888 .61243 m .60358 .61457 L p .59886 .61522 L 0 0 1 r
F P
0 g
s
.59885 .61244 m .59888 .61243 L p .59888 .61262 L 0 1 0 r
F P
0 g
s
.59885 .61523 m .59885 .61244 L .59888 .61262 L 0 1 0 r
F
.59885 .61523 m .59888 .61243 L .59886 .61522 L F
.61158 .61865 m .60376 .6181 L .59885 .61244 L p 1 0 0 r
F P
0 g
s
.59882 .6124 m .59888 .61243 L p .59882 .61245 L 0 0 1 r
F P
0 g
s
.61049 .59784 m .60344 .61161 L .59888 .61243 L p 0 1 0 r
F P
0 g
s
.62032 .59382 m .61336 .60863 L .60344 .61161 L p 0 1 0 r
F P
0 g
s
.60344 .61161 m .61049 .59784 L .62032 .59382 L p 0 1 0 r
F P
0 g
s
.61099 .6074 m .60358 .61457 L .59888 .61243 L p 0 0 1 r
F P
0 g
s
.59888 .61243 m .59882 .6124 L p .59887 .61239 L 0 0 1 r
F P
0 g
s
.59887 .61241 m .61049 .59784 L .59888 .61243 L 0 1 0 r
F
.59803 .60918 m .61049 .59784 L .59887 .61241 L F
.59882 .6124 m .59301 .60569 L p .59801 .60918 L 1 0 0 r
F P
0 g
s
.59803 .60918 m .61099 .6074 L .59809 .61207 L 0 0 1 r
F
.59802 .60919 m .59803 .60918 L .59885 .61244 L 0 1 0 r
F
.59882 .61221 m .59887 .61239 L .59882 .6124 L 0 0 1 r
F
.59803 .60918 m .59887 .61241 L .59885 .61244 L 0 1 0 r
F
.59882 .6118 m .61099 .6074 L .59887 .61239 L 0 0 1 r
F
.59882 .6118 m .59887 .61239 L .59882 .61221 L F
.59887 .61239 m .61099 .6074 L .59888 .61243 L F
.59888 .61243 m .59885 .61244 L p .59887 .61241 L 0 1 0 r
F P
0 g
s
.59885 .61244 m .59882 .6124 L p .59885 .61242 L 1 0 0 r
F P
0 g
s
.59809 .61207 m .59808 .61206 L p .59803 .60918 L 0 0 1 r
F P
0 g
s
.59808 .61206 m .5932 .60984 L p .59801 .60918 L 0 0 1 r
F P
0 g
s
.59801 .60918 m .59803 .60918 L .59808 .61206 L 0 0 1 r
F
.59803 .60918 m .59829 .60758 L .59847 .60878 L 0 1 0 r
F
.61618 .61921 m .6231 .60445 L .63266 .59903 L p F P
0 g
s
.62135 .61214 m .61392 .61928 L .60358 .61457 L p 0 0 1 r
F P
0 g
s
.62995 .58858 m .6231 .60445 L .61336 .60863 L p 0 1 0 r
F P
0 g
s
.61336 .60863 m .62032 .59382 L .62995 .58858 L p 0 1 0 r
F P
0 g
s
.60358 .61457 m .61099 .6074 L .62135 .61214 L p 0 0 1 r
F P
0 g
s
.59301 .60569 m .59793 .60524 L p .59801 .60918 L 1 0 0 r
F P
0 g
s
.59801 .60844 m .59829 .60758 L .59803 .60918 L 0 1 0 r
F
.59795 .60522 m .60049 .60066 L p .59801 .60844 L F P
0 g
s
.60059 .60264 m .61099 .6074 L p .59938 .60899 L 0 0 1 r
F P
0 g
s
.59917 .60819 m .60059 .60264 L .59938 .60899 L 0 0 1 r
F
.59793 .60524 m .59795 .60522 L p .59895 .60905 L F P
0 g
s
.59795 .60522 m .60059 .60264 L p .59897 .60899 L 0 0 1 r
F P
0 g
s
.59795 .60522 m .59897 .60899 L .59895 .60905 L 0 0 1 r
F
.5932 .60984 m .59793 .60524 L p .59895 .60905 L F P
0 g
s
.59793 .60524 m .59769 .60526 L p .59742 .60336 L 1 0 0 r
F P
0 g
s
.59769 .60526 m .59301 .60569 L p .5974 .60337 L 1 0 0 r
F P
0 g
s
.59742 .60336 m .59769 .60526 L .5974 .60337 L 1 0 0 r
F
.59762 .60289 m .59737 .60132 L .60049 .60066 L 0 1 0 r
F
.59733 .60115 m .59737 .60117 L p .59735 .60309 L 0 0 1 r
F P
0 g
s
.59735 .60117 m .59737 .60117 L p .59737 .60132 L 0 1 0 r
F P
0 g
s
.59737 .60117 m .60049 .60066 L p .59737 .60132 L 0 1 0 r
F P
0 g
s
.59735 .60309 m .59737 .60117 L .59737 .60308 L 0 0 1 r
F
.59736 .60309 m .59735 .60117 L .59762 .60289 L 0 1 0 r
F
.60049 .60066 m .59795 .60522 L p .59737 .60308 L F P
0 g
s
.59737 .60117 m .60059 .60264 L p .59737 .60308 L 0 0 1 r
F P
0 g
s
.59735 .60309 m .59735 .60117 L .59736 .60309 L 1 0 0 r
F
.58235 .59462 m .59733 .60116 L .59735 .60309 L F
.59733 .60116 m .59735 .60117 L .59735 .60309 L F
.56754 .60106 m .57489 .59741 L .58546 .60739 L p F P
0 g
s
.59301 .60569 m .58546 .60739 L .57489 .59741 L p 1 0 0 r
F P
0 g
s
.57489 .59741 m .58235 .59462 L .59301 .60569 L p 1 0 0 r
F P
0 g
s
.58277 .60509 m .59733 .60115 L .59735 .60309 L 0 0 1 r
F
.59708 .60122 m .59735 .60117 L p .59736 .60309 L 0 1 0 r
F P
0 g
s
.60059 .60264 m .59795 .60522 L p .5979 .60301 L 0 0 1 r
F P
0 g
s
.61845 .60018 m .61099 .6074 L .60059 .60264 L p 0 0 1 r
F P
0 g
s
.62721 .57788 m .62032 .59382 L .61049 .59784 L p 0 1 0 r
F P
0 g
s
.61049 .59784 m .61749 .58297 L .62721 .57788 L p 0 1 0 r
F P
0 g
s
.60059 .60264 m .60803 .59539 L .61845 .60018 L p 0 0 1 r
F P
0 g
s
.59625 .59702 m .59652 .59461 L .59682 .59651 L 0 1 0 r
F
.59733 .60115 m .59682 .60057 L p .59625 .59702 L 1 0 0 r
F P
0 g
s
.59682 .60057 m .58992 .59273 L p .59625 .59702 L 1 0 0 r
F P
0 g
s
.59625 .59702 m .5963 .59722 L .59733 .60115 L 1 0 0 r
F
.5963 .59722 m .60759 .58683 L .59737 .60117 L 0 1 0 r
F
.59625 .59702 m .59625 .59702 L .5963 .59722 L F
.59625 .59702 m .60759 .58683 L .5963 .59722 L F
.60803 .59539 m .60059 .60264 L .59636 .60071 L p 0 0 1 r
F P
0 g
s
.59636 .60071 m .59635 .6007 L p .59636 .60069 L 0 0 1 r
F P
0 g
s
.59636 .60069 m .60803 .59539 L .59636 .60071 L 0 0 1 r
F
.59625 .59702 m .59625 .59702 L .5963 .59722 L 1 0 0 r
F
.59625 .59702 m .60803 .59539 L .59635 .6007 L 0 0 1 r
F
.58992 .59273 m .5961 .59202 L p .59623 .59633 L 1 0 0 r
F P
0 g
s
.58992 .59273 m .59623 .59633 L .59625 .59702 L 1 0 0 r
F
.59625 .59702 m .5961 .59202 L .59612 .59207 L 0 0 1 r
F
.59625 .59701 m .59625 .597 L .59625 .59702 L 0 1 0 r
F
.59625 .597 m .59652 .59461 L .59625 .59702 L F
.59622 .59612 m .59652 .59461 L .59625 .59701 L F
.59625 .59702 m .59623 .59633 L .59625 .59702 L 1 0 0 r
F
.59625 .59702 m .59625 .59701 L .59625 .59702 L 0 1 0 r
F
.59611 .59201 m .59751 .5895 L p .59622 .59612 L F P
0 g
s
.59625 .59702 m .59612 .59207 L .59745 .59685 L 0 0 1 r
F
.59756 .59058 m .60803 .59539 L p .59767 .59682 L F P
0 g
s
.59745 .59685 m .59746 .59606 L .59767 .59682 L 0 0 1 r
F
.59746 .59606 m .59756 .59058 L .59767 .59682 L F
.5961 .59202 m .59756 .59058 L p .59745 .59685 L F P
0 g
s
.59751 .5895 m .59611 .59201 L p .59578 .59083 L 0 1 0 r
F P
0 g
s
.59756 .59058 m .59611 .59201 L p .59608 .59079 L 0 0 1 r
F P
0 g
s
.59592 .59072 m .59578 .58986 L .59751 .5895 L 0 1 0 r
F
.57921 .5818 m .5868 .57975 L .59511 .58903 L p 1 0 0 r
F P
0 g
s
.57921 .5818 m .59511 .58903 L .59512 .58945 L 1 0 0 r
F
.57921 .5818 m .59575 .58975 L .59577 .59083 L F
.56437 .58858 m .57174 .58477 L .58235 .59462 L p F P
0 g
s
.58992 .59273 m .58235 .59462 L .57174 .58477 L p 1 0 0 r
F P
0 g
s
.57174 .58477 m .57921 .5818 L .58992 .59273 L p 1 0 0 r
F P
0 g
s
.57966 .59306 m .58706 .58575 L .59578 .58976 L p 0 0 1 r
F P
0 g
s
.60465 .57561 m .59751 .5895 L .59578 .58976 L p 0 1 0 r
F P
0 g
s
.59578 .58976 m .59751 .5895 L p .59578 .58986 L 0 1 0 r
F P
0 g
s
.61463 .57189 m .60759 .58683 L .59751 .5895 L p 0 1 0 r
F P
0 g
s
.59751 .5895 m .60465 .57561 L .61463 .57189 L p 0 1 0 r
F P
0 g
s
.60503 .58326 m .59756 .59058 L .59578 .58976 L p 0 0 1 r
F P
0 g
s
.59575 .58975 m .59511 .58903 L p .5944 .5848 L 1 0 0 r
F P
0 g
s
.5944 .5848 m .59496 .58685 L .59575 .58975 L 1 0 0 r
F
.59511 .58903 m .5868 .57975 L p .59438 .58473 L F P
0 g
s
.59438 .58473 m .59439 .58473 L .59511 .58903 L 1 0 0 r
F
.59452 .58918 m .58706 .58575 L p .59437 .58474 L 0 0 1 r
F P
0 g
s
.59578 .58975 m .60465 .57561 L .59578 .58976 L 0 1 0 r
F
.59511 .58903 m .59575 .58975 L p .59512 .58945 L 1 0 0 r
F P
0 g
s
.59578 .58976 m .59452 .58918 L p .59437 .58474 L 0 0 1 r
F P
0 g
s
.59577 .58976 m .59575 .58975 L p .59576 .58975 L 1 0 0 r
F P
0 g
s
.59438 .58473 m .60465 .57561 L .59578 .58975 L 0 1 0 r
F
.59496 .58685 m .59578 .58975 L .59577 .58976 L F
.59438 .58473 m .59578 .58975 L .59496 .58685 L F
.59496 .58685 m .60503 .58326 L .59578 .58976 L 0 0 1 r
F
.59441 .58481 m .60503 .58326 L .59496 .58685 L F
.59439 .58473 m .60503 .58326 L .59439 .58481 L F
.61551 .5881 m .60803 .59539 L .59756 .59058 L p F P
0 g
s
.62443 .56695 m .61749 .58297 L .60759 .58683 L p 0 1 0 r
F P
0 g
s
.60759 .58683 m .61463 .57189 L .62443 .56695 L p 0 1 0 r
F P
0 g
s
.59756 .59058 m .60503 .58326 L .61551 .5881 L p 0 0 1 r
F P
0 g
s
.59439 .58473 m .60547 .59202 L .59575 .58975 L 1 0 0 r
F
.59577 .58976 m .58728 .59104 L p .59437 .58474 L 0 1 0 r
F P
0 g
s
.59437 .58474 m .59438 .58473 L .59496 .58685 L 0 1 0 r
F
.59437 .58474 m .59496 .58685 L .59577 .58976 L F
.5868 .57975 m .59416 .57873 L p .59423 .5804 L 1 0 0 r
F P
0 g
s
.5868 .57975 m .59423 .5804 L .59438 .58473 L 1 0 0 r
F
.59301 .57987 m .59417 .57873 L p .59437 .58474 L 0 0 1 r
F P
0 g
s
.59423 .5804 m .59423 .57909 L .59438 .58473 L 0 1 0 r
F
.59419 .57916 m .59423 .57909 L .59423 .5804 L F
.59423 .57909 m .59426 .57904 L .59461 .58137 L F
.59426 .57904 m .59483 .57806 L .59462 .58113 L F
.59426 .57904 m .59462 .58113 L .59461 .58137 L F
.59423 .57909 m .59461 .58137 L .59438 .58473 L F
.59437 .58474 m .59437 .58466 L .59438 .58473 L F
.59438 .58473 m .59483 .57806 L .59499 .58419 L F
.58706 .58575 m .59301 .57987 L p .59437 .58474 L 0 0 1 r
F P
0 g
s
.5868 .57975 m .57605 .56893 L p .59408 .57845 L 1 0 0 r
F P
0 g
s
.59408 .57845 m .59409 .57845 L .5941 .57851 L 0 0 1 r
F
.5945 .57815 m .59417 .57873 L p .59409 .57845 L 0 1 0 r
F P
0 g
s
.59409 .57845 m .59416 .57844 L .59411 .5785 L 0 0 1 r
F
.59409 .57845 m .59411 .5785 L .5941 .57851 L F
.59408 .57845 m .59409 .57848 L .5868 .57975 L 1 0 0 r
F
.59417 .57873 m .59416 .57873 L p .59416 .57844 L 0 0 1 r
F P
0 g
s
.59409 .57848 m .59409 .57848 L .5868 .57975 L 1 0 0 r
F
.59416 .57873 m .59413 .57874 L p .59409 .57848 L F P
0 g
s
.59413 .57874 m .5868 .57975 L p .59409 .57848 L 1 0 0 r
F P
0 g
s
.57921 .5818 m .57174 .58477 L .56116 .57604 L p 1 0 0 r
F P
0 g
s
.56116 .57604 m .56855 .57206 L .57921 .5818 L p 1 0 0 r
F P
0 g
s
.5868 .57975 m .57921 .5818 L .56855 .57206 L p 1 0 0 r
F P
0 g
s
.58186 .58336 m .57651 .5809 L p .584 .57986 L 0 0 1 r
F P
0 g
s
.56855 .57206 m .57605 .56893 L .5868 .57975 L p 1 0 0 r
F P
0 g
s
.584 .57986 m .59408 .57845 L .58186 .58336 L 0 0 1 r
F
.58706 .58575 m .58186 .58336 L p .59408 .57845 L F P
0 g
s
.58706 .58575 m .57966 .59306 L .56912 .58824 L p 0 0 1 r
F P
0 g
s
.57605 .56893 m .59408 .5782 L .59408 .5782 L 1 0 0 r
F
.59408 .5782 m .59409 .5782 L p .59408 .57845 L 0 0 1 r
F P
0 g
s
.59409 .5782 m .5945 .57815 L p .59409 .57845 L 0 1 0 r
F P
0 g
s
.59409 .5782 m .59451 .57839 L p .59409 .57845 L 0 0 1 r
F P
0 g
s
.59408 .57845 m .59409 .5782 L .59409 .57845 L 0 0 1 r
F
.59408 .5782 m .59409 .5782 L p .59409 .57845 L 0 1 0 r
F P
0 g
s
.59409 .57845 m .59409 .5782 L .59409 .57845 L 0 1 0 r
F
.59408 .57845 m .59408 .5782 L .59409 .57845 L 1 0 0 r
F
.57605 .56893 m .59408 .5782 L .59408 .57845 L F
.59408 .5782 m .59408 .5782 L .59408 .57845 L F
.59483 .57806 m .60465 .57561 L p .59499 .58419 L 0 1 0 r
F P
0 g
s
.61173 .56058 m .60465 .57561 L .5945 .57815 L p 0 1 0 r
F P
0 g
s
.5945 .57815 m .60167 .56417 L .61173 .56058 L p 0 1 0 r
F P
0 g
s
.60167 .56417 m .5945 .57815 L .59409 .5782 L p 0 1 0 r
F P
0 g
s
.59409 .5782 m .59408 .5782 L p .59409 .57819 L 0 0 1 r
F P
0 g
s
.57605 .56893 m .58365 .56672 L .59408 .5782 L p 1 0 0 r
F P
0 g
s
.59139 .5655 m .58048 .55365 L p .59033 .55978 L 1 0 0 r
F P
0 g
s
.59865 .55251 m .592 .56549 L p .59033 .55978 L 0 1 0 r
F P
0 g
s
.59033 .55978 m .59035 .55979 L .59038 .55997 L 1 0 0 r
F
.59033 .55978 m .59038 .55997 L .59139 .5655 L F
.58365 .56672 m .59139 .5655 L .5921 .56635 L p F P
0 g
s
.59139 .5655 m .58365 .56672 L .57285 .55601 L p 1 0 0 r
F P
0 g
s
.57285 .55601 m .58048 .55365 L .59139 .5655 L p 1 0 0 r
F P
0 g
s
.59058 .56569 m .58078 .56114 L p .5903 .5598 L 0 0 1 r
F P
0 g
s
.58365 .56672 m .57605 .56893 L .56534 .55929 L p 1 0 0 r
F P
0 g
s
.56534 .55929 m .57285 .55601 L .58365 .56672 L p 1 0 0 r
F P
0 g
s
.58365 .56672 m .5921 .56635 L .59211 .56642 L 1 0 0 r
F
.58365 .56672 m .59216 .56642 L .59241 .57232 L F
.59331 .57735 m .58365 .56672 L p .59241 .57232 L F P
0 g
s
.57605 .56893 m .56855 .57206 L .55793 .56342 L p 1 0 0 r
F P
0 g
s
.55793 .56342 m .56534 .55929 L .57605 .56893 L p 1 0 0 r
F P
0 g
s
.59142 .56607 m .58394 .57351 L .57332 .56861 L p 0 0 1 r
F P
0 g
s
.57332 .56861 m .58078 .56114 L .59142 .56607 L p 0 0 1 r
F P
0 g
s
.58823 .55228 m .57727 .54052 L p .58812 .54712 L 1 0 0 r
F P
0 g
s
.5956 .54064 m .58967 .55223 L p .58812 .54712 L 0 1 0 r
F P
0 g
s
.58812 .54712 m .58815 .54714 L .58816 .54723 L 1 0 0 r
F
.58812 .54712 m .58816 .54723 L .58823 .55228 L F
.58048 .55365 m .58823 .55228 L .58993 .55429 L p F P
0 g
s
.58823 .55228 m .58048 .55365 L .56963 .54302 L p 1 0 0 r
F P
0 g
s
.56963 .54302 m .57727 .54052 L .58823 .55228 L p 1 0 0 r
F P
0 g
s
.59005 .55444 m .59865 .55251 L p .59033 .55978 L 0 1 0 r
F P
0 g
s
.59865 .55251 m .60879 .54904 L p .59209 .56593 L 0 1 0 r
F P
0 g
s
.59208 .56593 m .59865 .55251 L .59209 .56593 L 0 1 0 r
F
.59205 .56539 m .59865 .55251 L p .59208 .56594 L F P
0 g
s
.59894 .55859 m .59201 .56549 L p .59035 .55979 L 0 0 1 r
F P
0 g
s
.59216 .56642 m .60167 .56417 L p .59313 .57169 L 0 1 0 r
F P
0 g
s
.59241 .57232 m .59216 .56642 L .59313 .57169 L 0 1 0 r
F
.59241 .57232 m .59369 .5768 L .59408 .5782 L 1 0 0 r
F
.59369 .5768 m .60167 .56417 L .59409 .5782 L 0 1 0 r
F
.59408 .5782 m .59331 .57735 L p .59241 .57232 L 1 0 0 r
F P
0 g
s
.59239 .57233 m .59241 .57232 L .59369 .5768 L 0 1 0 r
F
.59241 .57232 m .60167 .56417 L .59369 .5768 L F
.59243 .57233 m .59392 .57212 L .59408 .5782 L 0 0 1 r
F
.602 .57099 m .59451 .57839 L .59409 .5782 L p F P
0 g
s
.59409 .57819 m .602 .57099 L .59409 .5782 L 0 0 1 r
F
.59392 .57212 m .602 .57099 L .59408 .5782 L F
.59412 .57824 m .59408 .5782 L p .59317 .5728 L 1 0 0 r
F P
0 g
s
.59408 .5782 m .59408 .5782 L p .59407 .57816 L 1 0 0 r
F P
0 g
s
.59407 .57816 m .59317 .5728 L .59408 .5782 L 1 0 0 r
F
.63402 .56076 m .62721 .57788 L .61749 .58297 L p 0 1 0 r
F P
0 g
s
.61749 .58297 m .62443 .56695 L .63402 .56076 L p 0 1 0 r
F P
0 g
s
.60503 .58326 m .61255 .57588 L .62305 .58076 L p 0 0 1 r
F P
0 g
s
.5945 .57815 m .59483 .57806 L p .59419 .57916 L 0 1 0 r
F P
0 g
s
.61255 .57588 m .60503 .58326 L .59451 .57839 L p 0 0 1 r
F P
0 g
s
.62161 .55578 m .61463 .57189 L .60465 .57561 L p 0 1 0 r
F P
0 g
s
.60465 .57561 m .61173 .56058 L .62161 .55578 L p 0 1 0 r
F P
0 g
s
.59451 .57839 m .602 .57099 L .61255 .57588 L p 0 0 1 r
F P
0 g
s
.59241 .57232 m .59239 .57218 L .59216 .56642 L 0 1 0 r
F
.58394 .57351 m .59142 .56607 L .59215 .56642 L p 0 0 1 r
F P
0 g
s
.58394 .57351 m .59215 .56642 L .59215 .56642 L 0 0 1 r
F
.59215 .56642 m .59216 .56642 L p .59239 .57218 L 0 1 0 r
F P
0 g
s
.59243 .57233 m .59216 .56642 L .59373 .57214 L 0 0 1 r
F
.59216 .56642 m .59216 .56642 L p .59241 .57232 L 1 0 0 r
F P
0 g
s
.59241 .57232 m .59216 .56642 L .59243 .57233 L 1 0 0 r
F
.58394 .57351 m .59215 .56642 L .59239 .57233 L 0 0 1 r
F
.59241 .57232 m .59243 .57233 L .59369 .5768 L 1 0 0 r
F
.59408 .5782 m .58394 .57351 L p .59243 .57233 L 0 0 1 r
F P
0 g
s
.57651 .5809 m .58394 .57351 L .59408 .5782 L p 0 0 1 r
F P
0 g
s
.58419 .57955 m .5914 .56665 L p .59239 .57219 L 0 1 0 r
F P
0 g
s
.59239 .57233 m .59239 .57219 L .59241 .57232 L 0 1 0 r
F
.58419 .57955 m .59239 .57219 L .59239 .57233 L F
.59239 .57233 m .59216 .56642 L .59243 .57233 L 0 0 1 r
F
.59215 .56642 m .59216 .56642 L .59239 .57233 L F
.59216 .56642 m .602 .57099 L p .59373 .57214 L F P
0 g
s
.59216 .56642 m .60238 .57869 L p .59243 .57233 L 1 0 0 r
F P
0 g
s
.59144 .56658 m .59215 .56642 L p .59239 .57218 L 0 1 0 r
F P
0 g
s
.59215 .56642 m .59216 .56642 L p .59215 .56642 L 0 0 1 r
F P
0 g
s
.61041 .57985 m .60238 .57869 L .59216 .56642 L p 1 0 0 r
F P
0 g
s
.59203 .56598 m .59205 .56539 L .59208 .56594 L 0 1 0 r
F
.5921 .56635 m .59139 .5655 L p .59203 .56598 L 1 0 0 r
F P
0 g
s
.60955 .56353 m .602 .57099 L .5923 .56648 L p 0 0 1 r
F P
0 g
s
.5923 .56648 m .59216 .56642 L p .59227 .5664 L 0 0 1 r
F P
0 g
s
.59227 .5664 m .60955 .56353 L .5923 .56648 L 0 0 1 r
F
.60879 .54904 m .60167 .56417 L .59215 .56642 L p 0 1 0 r
F P
0 g
s
.5921 .56635 m .59216 .56642 L p .59211 .56642 L 1 0 0 r
F P
0 g
s
.59215 .56642 m .59206 .56637 L p .59214 .56636 L 0 0 1 r
F P
0 g
s
.59215 .56642 m .59144 .56658 L p .59203 .56599 L 0 1 0 r
F P
0 g
s
.59216 .56642 m .5921 .56635 L p .59209 .56619 L 1 0 0 r
F P
0 g
s
.59203 .56598 m .60879 .54904 L .59216 .56642 L 0 1 0 r
F
.59203 .56599 m .59204 .56599 L .59206 .56637 L 0 0 1 r
F
.59204 .56599 m .60955 .56353 L .59214 .56636 L F
.59209 .56619 m .59209 .56619 L .59216 .56642 L 1 0 0 r
F
.59209 .56619 m .59215 .56641 L .59216 .56642 L F
.59203 .56598 m .59208 .56602 L .5921 .56635 L F
.59203 .56599 m .59203 .56598 L .59215 .56642 L 0 1 0 r
F
.59203 .56598 m .59216 .56642 L .59215 .56642 L F
.59204 .56599 m .59214 .56636 L .59206 .56637 L 0 0 1 r
F
.59209 .56619 m .59208 .56602 L .59215 .56641 L 1 0 0 r
F
.59215 .56641 m .59216 .56642 L .59216 .56642 L F
.59216 .56642 m .59215 .56642 L p .59214 .56636 L 0 0 1 r
F P
0 g
s
.59214 .56636 m .59214 .56636 L .59215 .56642 L 0 0 1 r
F
.59214 .56636 m .60955 .56353 L .59216 .56642 L F
.61875 .54436 m .61173 .56058 L .60167 .56417 L p 0 1 0 r
F P
0 g
s
.60167 .56417 m .60879 .54904 L .61875 .54436 L p 0 1 0 r
F P
0 g
s
.59894 .55859 m .60955 .56353 L p .59204 .56599 L 0 0 1 r
F P
0 g
s
.592 .56549 m .59205 .56539 L p .59203 .56598 L 0 1 0 r
F P
0 g
s
.59203 .56598 m .59201 .56549 L .59204 .56599 L 1 0 0 r
F
.59139 .5655 m .592 .56549 L p .59203 .56598 L F P
0 g
s
.592 .56549 m .59201 .56549 L p .59203 .56598 L 1 0 0 r
F P
0 g
s
.59142 .56607 m .592 .5655 L p .59203 .56599 L 0 0 1 r
F P
0 g
s
.59196 .56557 m .592 .56549 L p .59203 .56598 L 0 1 0 r
F P
0 g
s
.59203 .56599 m .59203 .56595 L .59203 .56598 L 0 1 0 r
F
.59203 .56599 m .59201 .56549 L .59204 .56599 L 0 0 1 r
F
.592 .5655 m .59201 .56549 L p .59203 .56599 L F P
0 g
s
.59208 .56594 m .59208 .56593 L .59209 .56593 L 0 1 0 r
F
.59201 .56549 m .59894 .55859 L p .59204 .56599 L 0 0 1 r
F P
0 g
s
.63128 .54973 m .62443 .56695 L .61463 .57189 L p 0 1 0 r
F P
0 g
s
.61463 .57189 m .62161 .55578 L .63128 .54973 L p 0 1 0 r
F P
0 g
s
.62011 .56846 m .61255 .57588 L .602 .57099 L p 0 0 1 r
F P
0 g
s
.602 .57099 m .60955 .56353 L .62011 .56846 L p 0 0 1 r
F P
0 g
s
.59927 .56535 m .61041 .57985 L p .59204 .56599 L 1 0 0 r
F P
0 g
s
.59201 .56549 m .59927 .56535 L p .59204 .56599 L 1 0 0 r
F P
0 g
s
.59927 .56535 m .59201 .56549 L p .59102 .56021 L 1 0 0 r
F P
0 g
s
.59201 .56549 m .592 .56549 L p .59199 .56544 L 1 0 0 r
F P
0 g
s
.59102 .56021 m .59201 .56549 L .59199 .56544 L 1 0 0 r
F
.59208 .56602 m .61041 .57985 L .59216 .56642 L F
.59208 .56602 m .59216 .56642 L .59215 .56641 L F
.59206 .56637 m .59142 .56607 L p .59203 .56599 L 0 0 1 r
F P
0 g
s
.59144 .56658 m .59196 .56557 L p .59203 .56595 L 0 1 0 r
F P
0 g
s
.59144 .56658 m .59203 .56595 L .59203 .56599 L 0 1 0 r
F
.58048 .55365 m .58993 .55429 L .58994 .55443 L 1 0 0 r
F
.59005 .55444 m .59006 .55444 L p .59033 .55978 L F P
0 g
s
.58048 .55365 m .59005 .55444 L .59033 .55978 L 1 0 0 r
F
.59005 .55444 m .59005 .55444 L p .5903 .5598 L 0 1 0 r
F P
0 g
s
.5903 .5598 m .59005 .55444 L .59033 .55978 L 0 1 0 r
F
.59005 .55444 m .58993 .55429 L p .58975 .5534 L 1 0 0 r
F P
0 g
s
.58993 .55429 m .58823 .55228 L p .58975 .5534 L 1 0 0 r
F P
0 g
s
.58975 .5534 m .58978 .55201 L .58986 .55329 L 0 1 0 r
F
.58078 .56114 m .58829 .55362 L .59005 .55444 L p 0 0 1 r
F P
0 g
s
.58978 .55353 m .60581 .53727 L .59005 .55444 L 0 1 0 r
F
.58975 .5534 m .60581 .53727 L .58978 .55353 L F
.60652 .55105 m .59894 .55859 L .59005 .55444 L p 0 0 1 r
F P
0 g
s
.60581 .53727 m .59865 .55251 L .59005 .55444 L p 0 1 0 r
F P
0 g
s
.58993 .55429 m .59005 .55444 L p .58994 .55443 L 1 0 0 r
F P
0 g
s
.59005 .55444 m .59005 .55444 L p .59005 .55443 L 0 1 0 r
F P
0 g
s
.59005 .55443 m .60581 .53727 L .59005 .55444 L 0 1 0 r
F
.59 .55429 m .60652 .55105 L .59005 .55444 L 0 0 1 r
F
.58974 .55342 m .58975 .5534 L .58978 .55353 L 0 1 0 r
F
.58974 .55342 m .58977 .55341 L .58981 .55433 L 0 0 1 r
F
.59006 .55444 m .59005 .55444 L p .58977 .55341 L 1 0 0 r
F P
0 g
s
.58975 .5534 m .58977 .55341 L .59005 .55444 L 1 0 0 r
F
.61585 .53271 m .60879 .54904 L .59865 .55251 L p 0 1 0 r
F P
0 g
s
.59865 .55251 m .60581 .53727 L .61585 .53271 L p 0 1 0 r
F P
0 g
s
.58977 .55341 m .60652 .55105 L .58983 .55432 L 0 0 1 r
F
.58977 .55341 m .58983 .55432 L .58981 .55433 L F
.59006 .55444 m .59894 .55859 L p .59035 .55979 L F P
0 g
s
.6285 .53845 m .62161 .55578 L .61173 .56058 L p 0 1 0 r
F P
0 g
s
.61173 .56058 m .61875 .54436 L .6285 .53845 L p 0 1 0 r
F P
0 g
s
.61715 .55603 m .60955 .56353 L .59894 .55859 L p 0 0 1 r
F P
0 g
s
.59894 .55859 m .60652 .55105 L .61715 .55603 L p 0 0 1 r
F P
0 g
s
.58975 .5534 m .58977 .5534 L .58977 .55341 L 1 0 0 r
F
.58823 .55228 m .58956 .55223 L p .58975 .5534 L F P
0 g
s
.5956 .54064 m .60581 .53727 L p .58987 .55328 L 0 1 0 r
F P
0 g
s
.59585 .54605 m .60652 .55105 L p .59003 .55337 L 0 0 1 r
F P
0 g
s
.58997 .55317 m .59585 .54605 L .59003 .55337 L 0 0 1 r
F
.58986 .55329 m .58987 .55327 L .58987 .55328 L 0 1 0 r
F
.58987 .55327 m .5956 .54064 L .58987 .55328 L F
.58978 .55201 m .5956 .54064 L p .58986 .55329 L F P
0 g
s
.58968 .55223 m .59585 .54605 L p .58977 .55341 L 0 0 1 r
F P
0 g
s
.58973 .55329 m .58978 .55201 L .58975 .5534 L 0 1 0 r
F
.58956 .55223 m .58968 .55223 L p .58975 .5534 L 1 0 0 r
F P
0 g
s
.58829 .55362 m .58966 .55225 L p .58974 .55342 L 0 0 1 r
F P
0 g
s
.58956 .55243 m .58966 .55225 L p .58973 .55329 L 0 1 0 r
F P
0 g
s
.58966 .55225 m .58978 .55201 L p .58973 .55329 L 0 1 0 r
F P
0 g
s
.58968 .55223 m .58977 .5534 L .58975 .5534 L 1 0 0 r
F
.58974 .55342 m .58973 .55329 L .58975 .5534 L 0 1 0 r
F
.58974 .55342 m .58968 .55223 L .58977 .55341 L 0 0 1 r
F
.58966 .55225 m .58968 .55223 L p .58974 .55342 L F P
0 g
s
.59585 .54605 m .58968 .55223 L p .58815 .54714 L 0 0 1 r
F P
0 g
s
.59613 .55199 m .58968 .55223 L p .58875 .5475 L 1 0 0 r
F P
0 g
s
.58968 .55223 m .58967 .55223 L p .58964 .5521 L 1 0 0 r
F P
0 g
s
.58875 .5475 m .58968 .55223 L .58964 .5521 L 1 0 0 r
F
.58977 .55341 m .58997 .55317 L .59003 .55337 L 0 0 1 r
F
.58968 .55223 m .59613 .55199 L p .58977 .5534 L 1 0 0 r
F P
0 g
s
.59613 .55199 m .60731 .56636 L p .58977 .55341 L 1 0 0 r
F P
0 g
s
.58977 .5534 m .59613 .55199 L .58977 .55341 L 1 0 0 r
F
.59005 .55444 m .58981 .55433 L p .59 .55429 L 0 0 1 r
F P
0 g
s
.58981 .55433 m .58829 .55362 L p .58974 .55342 L 0 0 1 r
F P
0 g
s
.58834 .55482 m .58956 .55243 L p .58973 .55329 L 0 1 0 r
F P
0 g
s
.58834 .55482 m .58973 .55329 L .58974 .55342 L 0 1 0 r
F
.59005 .55444 m .58834 .55482 L p .58974 .55342 L F P
0 g
s
.59005 .55444 m .59006 .55444 L p .59005 .55445 L 0 0 1 r
F P
0 g
s
.58078 .56114 m .59005 .55444 L .59005 .55445 L 0 0 1 r
F
.59033 .55978 m .59006 .55444 L .59035 .55979 L 1 0 0 r
F
.592 .56549 m .59139 .5655 L p .59102 .56021 L F P
0 g
s
.592 .56549 m .592 .5655 L p .59033 .55978 L 0 1 0 r
F P
0 g
s
.59142 .56607 m .59058 .56569 L p .5903 .5598 L 0 0 1 r
F P
0 g
s
.5903 .5598 m .59042 .56018 L .59142 .56607 L 0 0 1 r
F
.59035 .55979 m .5912 .5627 L .59139 .5655 L 1 0 0 r
F
.59033 .55978 m .592 .5655 L .59036 .56001 L 0 1 0 r
F
.59201 .56549 m .59142 .56607 L p .59035 .55979 L 0 0 1 r
F P
0 g
s
.592 .5655 m .59144 .56658 L p .59036 .56001 L 0 1 0 r
F P
0 g
s
.5903 .5598 m .59006 .55444 L .59035 .55979 L 0 0 1 r
F
.58078 .56114 m .58895 .55525 L .5903 .5598 L F
.58895 .55525 m .59006 .55444 L .5903 .5598 L F
.59006 .55444 m .59927 .56535 L p .59035 .55979 L 1 0 0 r
F P
0 g
s
.60731 .56636 m .59927 .56535 L .59006 .55444 L p 1 0 0 r
F P
0 g
s
.58977 .55341 m .60731 .56636 L .59006 .55444 L 1 0 0 r
F
.58829 .55362 m .57759 .54863 L p .58799 .54716 L 0 0 1 r
F P
0 g
s
.58799 .54716 m .58809 .54715 L .5881 .54758 L 0 0 1 r
F
.58799 .54716 m .5881 .54758 L .58829 .55362 L F
.58809 .54715 m .58812 .54712 L .58813 .54727 L 0 1 0 r
F
.58967 .55223 m .58823 .55228 L p .58875 .5475 L 1 0 0 r
F P
0 g
s
.58967 .55223 m .58966 .55225 L p .58812 .54712 L 0 1 0 r
F P
0 g
s
.58815 .54714 m .58862 .54869 L .58823 .55228 L 1 0 0 r
F
.58966 .55225 m .58829 .55362 L p .58816 .54737 L 0 0 1 r
F P
0 g
s
.58966 .55225 m .58834 .55482 L p .58813 .54727 L 0 1 0 r
F P
0 g
s
.58812 .54712 m .58966 .55225 L .58813 .54727 L 0 1 0 r
F
.58968 .55223 m .58966 .55225 L p .58815 .54714 L 0 0 1 r
F P
0 g
s
.58815 .54714 m .58966 .55225 L .58816 .54737 L 0 0 1 r
F
.58809 .54715 m .58815 .54714 L .58816 .54737 L F
.58809 .54715 m .58816 .54737 L .58829 .55362 L F
.57285 .55601 m .56534 .55929 L .55466 .55072 L p 1 0 0 r
F P
0 g
s
.55466 .55072 m .56209 .54644 L .57285 .55601 L p 1 0 0 r
F P
0 g
s
.58048 .55365 m .57285 .55601 L .56209 .54644 L p 1 0 0 r
F P
0 g
s
.58829 .55362 m .58078 .56114 L .5701 .55618 L p 0 0 1 r
F P
0 g
s
.56209 .54644 m .56963 .54302 L .58048 .55365 L p 1 0 0 r
F P
0 g
s
.5701 .55618 m .57759 .54863 L .58829 .55362 L p 0 0 1 r
F P
0 g
s
.58834 .55482 m .57788 .556 L p .58809 .54715 L 0 1 0 r
F P
0 g
s
.58809 .54715 m .58813 .54727 L .58834 .55482 L 0 1 0 r
F
.58815 .54714 m .58875 .5475 L .58862 .54869 L 1 0 0 r
F
.58105 .56787 m .58834 .55482 L .59005 .55444 L p 0 1 0 r
F P
0 g
s
.58105 .56787 m .59005 .55444 L .5903 .5598 L 0 1 0 r
F
.5903 .5598 m .59033 .55978 L .59036 .56001 L F
.5903 .5598 m .59035 .55979 L .59042 .56018 L 0 0 1 r
F
.59144 .56658 m .58105 .56787 L p .5903 .5598 L 0 1 0 r
F P
0 g
s
.5903 .5598 m .59036 .56001 L .59144 .56658 L 0 1 0 r
F
.59035 .55979 m .59102 .56021 L .5912 .5627 L 1 0 0 r
F
.5914 .56665 m .59144 .56658 L p .59241 .57232 L 0 1 0 r
F P
0 g
s
.58419 .57955 m .59239 .57233 L .59369 .5768 L 0 1 0 r
F
.59409 .5782 m .59408 .5782 L p .59369 .5768 L F P
0 g
s
.59408 .5782 m .59408 .5782 L p .59408 .5782 L 1 0 0 r
F P
0 g
s
.59408 .5782 m .58419 .57955 L p .59369 .5768 L 0 1 0 r
F P
0 g
s
.59243 .57233 m .59317 .5728 L .59408 .5782 L 1 0 0 r
F
.57651 .5809 m .59408 .5782 L .59408 .57845 L 0 0 1 r
F
.59409 .57845 m .59409 .57845 L .59409 .57846 L 0 1 0 r
F
.59451 .57839 m .59417 .57873 L p .59416 .57844 L 0 0 1 r
F P
0 g
s
.59408 .5782 m .59452 .57868 L p .59409 .57845 L 1 0 0 r
F P
0 g
s
.59405 .57821 m .59408 .5782 L p .59409 .57845 L 0 1 0 r
F P
0 g
s
.56912 .58824 m .57651 .5809 L .58706 .58575 L p 0 0 1 r
F P
0 g
s
.57691 .59148 m .58419 .57955 L .59405 .57821 L p 0 1 0 r
F P
0 g
s
.59408 .57845 m .5941 .57851 L .58706 .58575 L 0 0 1 r
F
.57691 .59148 m .59405 .57821 L .59409 .57845 L 0 1 0 r
F
.59416 .57873 m .58706 .58575 L p .5941 .57851 L 0 0 1 r
F P
0 g
s
.59416 .57844 m .59416 .57873 L .5941 .57851 L 0 0 1 r
F
.59417 .57873 m .59416 .57873 L p .5941 .57848 L 1 0 0 r
F P
0 g
s
.5941 .57848 m .59416 .57873 L .59409 .57848 L 1 0 0 r
F
.59412 .57847 m .59417 .57873 L .5941 .57848 L F
.58728 .59104 m .57691 .59148 L p .59409 .57845 L 0 1 0 r
F P
0 g
s
.59409 .57845 m .59409 .57846 L .58728 .59104 L 0 1 0 r
F
.59417 .57873 m .58728 .59104 L p .59409 .57845 L F P
0 g
s
.59408 .57845 m .59412 .57847 L .59409 .57848 L 1 0 0 r
F
.59418 .57917 m .59419 .57916 L .59419 .57916 L 0 1 0 r
F
.59419 .57916 m .5945 .57815 L .59419 .57916 L F
.58728 .59104 m .59417 .57873 L p .59418 .57917 L F P
0 g
s
.59417 .57873 m .5945 .57815 L p .59418 .57917 L 0 1 0 r
F P
0 g
s
.59438 .58473 m .59423 .5804 L .59439 .58473 L 1 0 0 r
F
.59417 .57873 m .59451 .57839 L p .59437 .58474 L 0 0 1 r
F P
0 g
s
.59423 .5804 m .59452 .57868 L .59439 .58473 L 1 0 0 r
F
.59416 .57873 m .59417 .57873 L p .59423 .5804 L F P
0 g
s
.59418 .57917 m .59419 .57916 L .59423 .5804 L 0 1 0 r
F
.59417 .57873 m .59452 .57868 L p .59423 .5804 L 1 0 0 r
F P
0 g
s
.59451 .57839 m .60503 .58326 L p .59437 .58474 L 0 0 1 r
F P
0 g
s
.60238 .57869 m .59452 .57868 L .59412 .57824 L p 1 0 0 r
F P
0 g
s
.59317 .5728 m .60238 .57869 L .59412 .57824 L 1 0 0 r
F
.59452 .57868 m .59417 .57873 L p .59412 .57847 L F P
0 g
s
.59361 .58016 m .59418 .57917 L .59438 .58473 L 0 1 0 r
F
.5944 .5848 m .59439 .58473 L .59496 .58685 L 1 0 0 r
F
.59439 .58481 m .59441 .58481 L .59496 .58685 L 0 0 1 r
F
.59452 .57868 m .60547 .59202 L p .59439 .58473 L 1 0 0 r
F P
0 g
s
.59437 .58474 m .59439 .58473 L .59439 .58481 L 0 0 1 r
F
.58728 .59104 m .59361 .58016 L .59437 .58466 L 0 1 0 r
F
.58728 .59104 m .59437 .58466 L .59437 .58474 L F
.59578 .58976 m .59577 .58976 L p .59578 .58975 L F P
0 g
s
.59577 .59083 m .59578 .58976 L .59578 .59083 L 0 0 1 r
F
.59575 .58977 m .59578 .58976 L .59577 .59083 L F
.59577 .58976 m .59578 .58976 L p .59578 .58986 L 0 1 0 r
F P
0 g
s
.59578 .59083 m .59577 .58976 L .59592 .59072 L 0 1 0 r
F
.59578 .58976 m .59756 .59058 L p .59578 .59083 L 0 0 1 r
F P
0 g
s
.59578 .59083 m .59578 .59083 L .59578 .59084 L 0 1 0 r
F
.59575 .58975 m .59762 .59184 L p .59577 .59083 L 1 0 0 r
F P
0 g
s
.57966 .59306 m .59575 .58977 L .59577 .59083 L 0 0 1 r
F
.59561 .58979 m .59577 .58976 L p .59578 .59083 L 0 1 0 r
F P
0 g
s
.60547 .59202 m .59762 .59184 L .59577 .58976 L p 1 0 0 r
F P
0 g
s
.59576 .58975 m .60547 .59202 L .59577 .58976 L 1 0 0 r
F
.59623 .59633 m .59762 .59184 L .59625 .59702 L F
.5961 .59202 m .59611 .59202 L p .59623 .59633 L F P
0 g
s
.59611 .59202 m .59611 .59201 L p .59611 .59214 L 0 1 0 r
F P
0 g
s
.59611 .59202 m .59762 .59184 L p .59623 .59633 L 1 0 0 r
F P
0 g
s
.59515 .59295 m .5961 .59202 L p .59625 .59702 L 0 0 1 r
F P
0 g
s
.59616 .59645 m .59622 .59612 L .59625 .59701 L 0 1 0 r
F
.59635 .6007 m .59014 .59786 L p .59625 .59702 L 0 0 1 r
F P
0 g
s
.59014 .59786 m .59515 .59295 L p .59625 .59702 L 0 0 1 r
F P
0 g
s
.5954 .59329 m .59611 .59202 L p .59601 .59724 L 0 1 0 r
F P
0 g
s
.59611 .59202 m .59611 .59214 L .59601 .59724 L 0 1 0 r
F
.59762 .59184 m .60854 .60533 L p .59625 .59702 L 1 0 0 r
F P
0 g
s
.59731 .60101 m .5963 .59722 L .59733 .601 L 0 1 0 r
F
.59737 .60117 m .59735 .60117 L p .59733 .601 L F P
0 g
s
.5963 .59722 m .59735 .60116 L .59733 .60115 L 1 0 0 r
F
.59735 .60117 m .59733 .60115 L p .59735 .60116 L F P
0 g
s
.58277 .60509 m .59014 .59786 L .59733 .60115 L p 0 0 1 r
F P
0 g
s
.59733 .60115 m .59735 .60117 L p .59733 .60116 L 1 0 0 r
F P
0 g
s
.59735 .60117 m .59034 .60233 L p .59731 .60101 L 0 1 0 r
F P
0 g
s
.59731 .60101 m .59733 .601 L .59735 .60117 L 0 1 0 r
F
.59735 .60116 m .59735 .60116 L .59735 .60117 L 1 0 0 r
F
.59625 .59702 m .60854 .60533 L .59735 .60116 L F
.59625 .59702 m .59735 .60116 L .5963 .59722 L F
.59601 .59724 m .59616 .59645 L .59625 .59701 L 0 1 0 r
F
.59601 .59724 m .59625 .59701 L .59625 .59702 L F
.59034 .60233 m .59625 .59702 L .5963 .59722 L F
.59034 .60233 m .5963 .59722 L .59731 .60101 L F
.60854 .60533 m .6007 .60498 L .59735 .60117 L p 1 0 0 r
F P
0 g
s
.59735 .60116 m .60854 .60533 L .59735 .60117 L 1 0 0 r
F
.59736 .60309 m .59735 .60117 L .59762 .60324 L F
.59735 .60309 m .59742 .60336 L .59301 .60569 L F
.5932 .60984 m .58277 .60509 L p .59735 .60309 L 0 0 1 r
F P
0 g
s
.5932 .60984 m .58586 .617 L .57545 .61228 L p 0 0 1 r
F P
0 g
s
.57802 .61001 m .57068 .61347 L .56028 .60548 L p 1 0 0 r
F P
0 g
s
.56028 .60548 m .56754 .60106 L .57802 .61001 L p 1 0 0 r
F P
0 g
s
.58546 .60739 m .57802 .61001 L .56754 .60106 L p 1 0 0 r
F P
0 g
s
.57545 .61228 m .58277 .60509 L .5932 .60984 L p 0 0 1 r
F P
0 g
s
.58314 .61415 m .59034 .60233 L .59708 .60122 L p 0 1 0 r
F P
0 g
s
.59793 .60524 m .5932 .60984 L p .59735 .60309 L 0 0 1 r
F P
0 g
s
.58314 .61415 m .59708 .60122 L .59736 .60309 L 0 1 0 r
F
.58586 .617 m .5932 .60984 L .59882 .6124 L p 0 0 1 r
F P
0 g
s
.59735 .60309 m .5979 .60301 L .59793 .60524 L 0 0 1 r
F
.59336 .61343 m .58314 .61415 L p .59737 .60308 L 0 1 0 r
F P
0 g
s
.59793 .60524 m .59794 .60523 L p .59801 .60918 L 1 0 0 r
F P
0 g
s
.59794 .60523 m .6007 .60498 L p .59834 .60867 L 1 0 0 r
F P
0 g
s
.59794 .60523 m .59834 .60867 L .59801 .60918 L 1 0 0 r
F
.59737 .60308 m .59793 .60513 L .59336 .61343 L 0 1 0 r
F
.59795 .60522 m .59793 .60524 L p .5979 .60301 L 0 0 1 r
F P
0 g
s
.59795 .60522 m .59794 .60523 L p .59793 .60513 L 0 1 0 r
F P
0 g
s
.59794 .60523 m .59336 .61343 L p .59793 .60513 L 0 1 0 r
F P
0 g
s
.59895 .60905 m .59917 .60819 L .59938 .60899 L 0 0 1 r
F
.59794 .60523 m .59793 .60524 L p .59764 .60325 L 1 0 0 r
F P
0 g
s
.59764 .60325 m .59793 .60524 L .59742 .60336 L 1 0 0 r
F
.6007 .60498 m .61158 .61865 L p .59801 .60918 L F P
0 g
s
.59801 .60918 m .61158 .61865 L .59882 .6124 L 1 0 0 r
F
.58586 .617 m .59882 .6124 L .59882 .61245 L 0 0 1 r
F
.59882 .6124 m .59809 .61207 L p .59882 .6118 L F P
0 g
s
.59885 .61244 m .59336 .61343 L p .59802 .60919 L 0 1 0 r
F P
0 g
s
.59885 .61242 m .59885 .61242 L .59885 .61244 L 1 0 0 r
F
.59885 .61242 m .61158 .61865 L .59885 .61244 L F
.59883 .61522 m .59883 .61512 L .59885 .61523 L F
.59885 .61523 m .59883 .61512 L .59885 .61244 L F
.59882 .6124 m .59885 .61244 L p .59883 .61512 L F P
0 g
s
.59846 .61251 m .59885 .61244 L p .59885 .61523 L 0 1 0 r
F P
0 g
s
.59885 .61244 m .60376 .6181 L p .59885 .61523 L 1 0 0 r
F P
0 g
s
.59886 .61522 m .59965 .61822 L .59927 .61892 L 0 1 0 r
F
.59885 .61526 m .59927 .61892 L .59634 .62434 L F
.59886 .61522 m .59927 .61892 L .59885 .61526 L F
.59968 .61835 m .59966 .61838 L p .59965 .61822 L F P
0 g
s
.59966 .61838 m .59634 .62434 L p .59965 .61822 L 0 1 0 r
F P
0 g
s
.59966 .61838 m .59965 .61838 L p .59925 .61547 L 1 0 0 r
F P
0 g
s
.59925 .61547 m .59965 .61838 L .59932 .61711 L 1 0 0 r
F
.5997 .62124 m .59972 .62119 L .59972 .62122 L 0 1 0 r
F
.60031 .62355 m .60028 .62356 L p .59972 .62122 L F P
0 g
s
.5997 .62124 m .59972 .62122 L .60028 .62356 L 0 1 0 r
F
.63532 .60924 m .62856 .62502 L .61897 .62957 L p F P
0 g
s
.61897 .62957 m .62585 .61485 L .63532 .60924 L p 0 1 0 r
F P
0 g
s
.62422 .62397 m .61682 .63104 L .60654 .62638 L p 0 0 1 r
F P
0 g
s
.60654 .62638 m .61392 .61928 L .62422 .62397 L p 0 0 1 r
F P
0 g
s
.60376 .6181 m .6146 .63198 L p .59969 .62122 L 1 0 0 r
F P
0 g
s
.59969 .62122 m .5997 .62124 L .59972 .62137 L 1 0 0 r
F
.5862 .62521 m .59336 .61343 L .59846 .61251 L p 0 1 0 r
F P
0 g
s
.5862 .62521 m .59846 .61251 L .59885 .61523 L 0 1 0 r
F
.60376 .6181 m .59966 .61838 L p .59925 .61547 L 1 0 0 r
F P
0 g
s
.59768 .6095 m .59801 .60844 L .59803 .60918 L 0 1 0 r
F
.59724 .60649 m .59795 .60522 L p .59768 .6095 L F P
0 g
s
.59795 .60522 m .59801 .60844 L .59768 .6095 L 0 1 0 r
F
.59735 .60117 m .6007 .60498 L p .59762 .60324 L 1 0 0 r
F P
0 g
s
.59611 .59202 m .5961 .59202 L p .59581 .59096 L 1 0 0 r
F P
0 g
s
.5961 .59202 m .58992 .59273 L p .59581 .59096 L 1 0 0 r
F P
0 g
s
.59581 .59096 m .5961 .59202 L .59581 .59096 L 1 0 0 r
F
.59578 .59083 m .59608 .59079 L .5961 .59196 L 0 0 1 r
F
.59578 .59083 m .5961 .59196 L .5961 .59202 L F
.59593 .59092 m .59611 .59202 L .59581 .59096 L 1 0 0 r
F
.59014 .59786 m .58793 .59685 L p .59575 .59085 L 0 0 1 r
F P
0 g
s
.58793 .59685 m .57966 .59306 L p .59575 .59085 L 0 0 1 r
F P
0 g
s
.57966 .59306 m .59577 .59083 L .59575 .59085 L 0 0 1 r
F
.5961 .59202 m .59014 .59786 L p .59577 .59083 L F P
0 g
s
.59014 .59786 m .58277 .60509 L .5723 .60032 L p 0 0 1 r
F P
0 g
s
.58235 .59462 m .57489 .59741 L .56437 .58858 L p 1 0 0 r
F P
0 g
s
.5723 .60032 m .57966 .59306 L .59014 .59786 L p 0 0 1 r
F P
0 g
s
.59034 .60233 m .58004 .6029 L p .59578 .59083 L 0 1 0 r
F P
0 g
s
.59578 .59083 m .59578 .59084 L .59034 .60233 L 0 1 0 r
F
.59611 .59201 m .59034 .60233 L p .59578 .59083 L F P
0 g
s
.59611 .59201 m .5961 .59202 L p .59608 .59079 L 0 0 1 r
F P
0 g
s
.59611 .59201 m .59622 .59612 L .59601 .59724 L 0 1 0 r
F
.58004 .6029 m .58728 .59104 L .59561 .58979 L p F P
0 g
s
.58004 .6029 m .59561 .58979 L .59578 .59083 L 0 1 0 r
F
.59577 .59083 m .59593 .59092 L .59581 .59096 L 1 0 0 r
F
.59762 .59184 m .59611 .59202 L p .59593 .59092 L F P
0 g
s
.59034 .60233 m .5954 .59329 L p .59601 .59724 L 0 1 0 r
F P
0 g
s
.59735 .60309 m .59764 .60325 L .59742 .60336 L 1 0 0 r
F
.6007 .60498 m .59794 .60523 L p .59764 .60325 L F P
0 g
s
.59336 .61343 m .59724 .60649 L p .59768 .6095 L 0 1 0 r
F P
0 g
s
.60028 .62356 m .60024 .62352 L p .5997 .62124 L 1 0 0 r
F P
0 g
s
.59972 .62137 m .5997 .62124 L .60024 .62352 L 1 0 0 r
F
.60024 .62352 m .59975 .6233 L p .60016 .62318 L 0 0 1 r
F P
0 g
s
.59634 .62434 m .59937 .61891 L p .5997 .62124 L 0 1 0 r
F P
0 g
s
.5997 .62124 m .59997 .62143 L .60028 .62356 L 1 0 0 r
F
.60024 .62352 m .60028 .62356 L p .60023 .6271 L F P
0 g
s
.58891 .62878 m .60024 .62352 L .60023 .62724 L 0 0 1 r
F
.60028 .62356 m .59634 .62434 L p .5997 .62124 L 0 1 0 r
F P
0 g
s
.60031 .62355 m .60654 .62638 L p .60121 .6271 L 0 0 1 r
F P
0 g
s
.60111 .62712 m .60031 .62355 L .60121 .6271 L 0 0 1 r
F
.60028 .62356 m .60031 .62355 L p .60025 .62725 L 0 1 0 r
F P
0 g
s
.60025 .62725 m .60031 .62355 L .60027 .62723 L 0 1 0 r
F
.6146 .63198 m .60679 .63122 L .60028 .62356 L p 1 0 0 r
F P
0 g
s
.59997 .62143 m .6146 .63198 L .60028 .62356 L 1 0 0 r
F
.60025 .62725 m .60023 .6271 L .60028 .62356 L F
.59976 .62366 m .60028 .62356 L p .60025 .62725 L 0 1 0 r
F P
0 g
s
.60028 .62356 m .60679 .63122 L p .60025 .62725 L 1 0 0 r
F P
0 g
s
.56658 .62989 m .5738 .62583 L .58419 .63506 L p 1 0 0 r
F P
0 g
s
.5916 .63284 m .58419 .63506 L .5738 .62583 L p 1 0 0 r
F P
0 g
s
.58164 .63582 m .58891 .62878 L .59921 .63343 L p 0 0 1 r
F P
0 g
s
.59929 .63506 m .58922 .6361 L p .60025 .62725 L 0 1 0 r
F P
0 g
s
.60023 .62724 m .60025 .62725 L .60049 .62827 L 1 0 0 r
F
.60025 .62725 m .60027 .62723 L .60026 .62729 L 0 1 0 r
F
.60025 .62725 m .60078 .62757 L .6005 .62824 L 1 0 0 r
F
.60025 .62725 m .6005 .62824 L .60049 .62827 L F
.60025 .62725 m .60026 .62729 L .60025 .62732 L 0 1 0 r
F
.60025 .62725 m .60025 .62732 L .59929 .63506 L F
.6013 .63145 m .60127 .63145 L p .60078 .62757 L 1 0 0 r
F P
0 g
s
.60128 .63315 m .60131 .63317 L .60134 .63337 L 1 0 0 r
F
.60163 .63455 m .6016 .6345 L p .60131 .63317 L F P
0 g
s
.60134 .63337 m .60131 .63317 L .6016 .6345 L 1 0 0 r
F
.59929 .63506 m .60112 .63177 L p .60131 .63317 L 0 1 0 r
F P
0 g
s
.60112 .63177 m .60132 .6314 L p .60131 .63317 L 0 1 0 r
F P
0 g
s
.60168 .63454 m .60163 .63455 L p .60133 .63314 L 0 1 0 r
F P
0 g
s
.60131 .63317 m .60133 .63314 L .60163 .63455 L 0 1 0 r
F
.60131 .63317 m .60147 .63328 L .60163 .63455 L 1 0 0 r
F
.59193 .64044 m .6016 .6345 L .60155 .63913 L 0 0 1 r
F
.60163 .63455 m .59929 .63506 L p .60131 .63317 L 0 1 0 r
F P
0 g
s
.60263 .63899 m .60168 .63454 L .60276 .63897 L 0 0 1 r
F
.60157 .63915 m .60168 .63454 L .60159 .63913 L 0 1 0 r
F
.60155 .63913 m .60163 .63455 L .60157 .63915 L 1 0 0 r
F
.6016 .63454 m .60163 .63455 L .60155 .63913 L F
.60108 .63531 m .60168 .63454 L .60157 .63915 L 0 1 0 r
F
.60163 .63455 m .60168 .63454 L p .60163 .6346 L F P
0 g
s
.61759 .64532 m .60979 .64435 L .60163 .63455 L p 1 0 0 r
F P
0 g
s
.60147 .63328 m .61759 .64532 L .60163 .63455 L 1 0 0 r
F
.59221 .6468 m .60108 .63531 L .60157 .63915 L 0 1 0 r
F
.60159 .63931 m .60157 .63915 L .60219 .64183 L 1 0 0 r
F
.60155 .63913 m .60157 .63915 L .60159 .63931 L F
.60157 .63915 m .60159 .63913 L .60161 .63932 L 0 1 0 r
F
.60157 .63915 m .60223 .63956 L .60219 .64173 L 1 0 0 r
F
.60157 .63915 m .60219 .64173 L .60219 .64183 L F
.6022 .64559 m .59221 .6468 L p .60157 .63915 L 0 1 0 r
F P
0 g
s
.60157 .63915 m .60161 .63932 L .6022 .64559 L 0 1 0 r
F
.58922 .6361 m .59634 .62434 L .59976 .62366 L p F P
0 g
s
.58922 .6361 m .59976 .62366 L .60025 .62725 L 0 1 0 r
F
.60679 .63122 m .6013 .63145 L p .60078 .62757 L 1 0 0 r
F P
0 g
s
.60163 .63455 m .60979 .64435 L p .60157 .63915 L 1 0 0 r
F P
0 g
s
.59221 .6468 m .59929 .63506 L .60163 .63455 L p 0 1 0 r
F P
0 g
s
.59221 .6468 m .60163 .63455 L .60163 .6346 L 0 1 0 r
F
.60979 .64435 m .60284 .64443 L p .60223 .63956 L 1 0 0 r
F P
0 g
s
.59515 .65732 m .60219 .64559 L p .60283 .65093 L 0 1 0 r
F P
0 g
s
.60219 .64559 m .6022 .64559 L p .60283 .65093 L 0 1 0 r
F P
0 g
s
.60411 .65746 m .59764 .6582 L p .60396 .65679 L 1 0 0 r
F P
0 g
s
.59025 .65999 m .58298 .66263 L .57276 .65406 L p 1 0 0 r
F P
0 g
s
.59787 .66339 m .5877 .65886 L p .60393 .65668 L 0 0 1 r
F P
0 g
s
.60411 .65746 m .59787 .66339 L p .60393 .65668 L 0 0 1 r
F P
0 g
s
.59787 .66339 m .59069 .67021 L .58054 .66571 L p 0 0 1 r
F P
0 g
s
.58054 .66571 m .5877 .65886 L .59787 .66339 L p 0 0 1 r
F P
0 g
s
.58809 .66816 m .60407 .65606 L .60404 .65667 L 0 1 0 r
F
.60398 .65671 m .60401 .65607 L .60407 .65676 L 1 0 0 r
F
.58809 .66816 m .60401 .65607 L .60401 .65611 L 0 1 0 r
F
.6051 .65652 m .60421 .65737 L p .60404 .65667 L 0 0 1 r
F P
0 g
s
.60401 .65607 m .60514 .65734 L p .60407 .65676 L 1 0 0 r
F P
0 g
s
.60407 .65606 m .60401 .65607 L p .60397 .65564 L 0 1 0 r
F P
0 g
s
.60401 .65607 m .60407 .65606 L p .60401 .65611 L 0 1 0 r
F P
0 g
s
.6041 .65618 m .60401 .65607 L p .60355 .6514 L 1 0 0 r
F P
0 g
s
.60346 .65134 m .60355 .6514 L .60401 .65607 L 1 0 0 r
F
.58809 .66816 m .59515 .65732 L .60401 .65607 L p 0 1 0 r
F P
0 g
s
.60402 .65706 m .60404 .65667 L .60411 .65746 L 0 0 1 r
F
.60393 .65668 m .60404 .65667 L .60402 .65706 L F
.60421 .65737 m .60411 .65746 L p .60404 .65667 L F P
0 g
s
.60393 .65668 m .60398 .65671 L .60396 .65679 L 1 0 0 r
F
.60312 .6584 m .60411 .65746 L p .60406 .66256 L 0 0 1 r
F P
0 g
s
.604 .65678 m .60411 .65746 L .60396 .65679 L 1 0 0 r
F
.60404 .65667 m .60412 .65703 L .60408 .65711 L 0 1 0 r
F
.60404 .65667 m .60408 .65711 L .60399 .65675 L F
.60408 .65676 m .6041 .65723 L .604 .65678 L 1 0 0 r
F
.6041 .65723 m .60411 .65746 L .604 .65678 L F
.60399 .65675 m .60408 .65711 L .59807 .66766 L 0 1 0 r
F
.60421 .65737 m .60416 .65746 L p .60412 .65703 L F P
0 g
s
.60411 .65746 m .60416 .65746 L p .60399 .66257 L 1 0 0 r
F P
0 g
s
.60416 .65746 m .60411 .65746 L p .6041 .65723 L 1 0 0 r
F P
0 g
s
.60412 .65703 m .60416 .65746 L .60408 .65711 L 0 1 0 r
F
.60408 .65676 m .60416 .65746 L .6041 .65723 L 1 0 0 r
F
.60416 .65746 m .59807 .66766 L p .60408 .65711 L 0 1 0 r
F P
0 g
s
.60416 .65746 m .60514 .65734 L p .6044 .6607 L 1 0 0 r
F P
0 g
s
.60403 .66259 m .60421 .65737 L .60406 .66256 L 0 1 0 r
F
.60416 .65746 m .60421 .65737 L p .60403 .66259 L F P
0 g
s
.60416 .65746 m .6044 .6607 L .60399 .66257 L 1 0 0 r
F
.60398 .65671 m .60408 .65676 L .604 .65678 L F
.60398 .65671 m .604 .65678 L .60396 .65679 L F
.59807 .66766 m .58809 .66816 L p .60398 .65671 L 0 1 0 r
F P
0 g
s
.60398 .65671 m .60404 .65667 L .60399 .65675 L 0 1 0 r
F
.60398 .65671 m .60399 .65675 L .59807 .66766 L F
.60399 .66257 m .60403 .66239 L .60403 .66259 L 1 0 0 r
F
.60496 .66654 m .6049 .66655 L p .60406 .66256 L 0 1 0 r
F P
0 g
s
.60406 .66286 m .60409 .66288 L .60484 .66649 L 1 0 0 r
F
.60403 .66259 m .60406 .66256 L .6049 .66655 L 0 1 0 r
F
.62535 .66558 m .61808 .67238 L .608 .66789 L p 0 0 1 r
F P
0 g
s
.608 .66789 m .61524 .66106 L .62535 .66558 L p 0 0 1 r
F P
0 g
s
.60409 .66288 m .61575 .67064 L .60489 .66651 L 1 0 0 r
F
.60409 .66288 m .60489 .66651 L .60484 .66649 L F
.60399 .66257 m .60403 .66259 L .60406 .66286 L F
.60403 .66259 m .61575 .67064 L .60406 .66286 L F
.59807 .66766 m .60357 .65845 L p .60403 .66259 L 0 1 0 r
F P
0 g
s
.60357 .65845 m .60416 .65746 L p .60403 .66259 L 0 1 0 r
F P
0 g
s
.60527 .6624 m .60513 .65741 L .60879 .66192 L 0 0 1 r
F
.60513 .65741 m .6051 .65652 L .60879 .66192 L F
.6051 .65652 m .61524 .66106 L p .60879 .66192 L F P
0 g
s
.60514 .65734 m .61575 .67064 L p .60403 .66259 L 1 0 0 r
F P
0 g
s
.60403 .66239 m .60514 .65734 L .60403 .66259 L 1 0 0 r
F
.60489 .66651 m .60489 .66651 L .6049 .66655 L F
.6049 .66655 m .59807 .66766 L p .60403 .66259 L 0 1 0 r
F P
0 g
s
.61278 .65748 m .60514 .65734 L .6041 .65618 L p 1 0 0 r
F P
0 g
s
.60355 .6514 m .61278 .65748 L .6041 .65618 L 1 0 0 r
F
.60514 .65734 m .60416 .65746 L p .60408 .65676 L F P
0 g
s
.60489 .6666 m .6049 .66655 L .6049 .6666 L 0 1 0 r
F
.60524 .67049 m .6008 .67469 L p .60476 .66833 L 0 0 1 r
F P
0 g
s
.58599 .67484 m .57883 .67805 L .56873 .67025 L p 1 0 0 r
F P
0 g
s
.56873 .67025 m .57581 .66607 L .58599 .67484 L p 1 0 0 r
F P
0 g
s
.59325 .67242 m .58599 .67484 L .57581 .66607 L p 1 0 0 r
F P
0 g
s
.58355 .67698 m .59069 .67021 L .6008 .67469 L p 0 0 1 r
F P
0 g
s
.59104 .67851 m .60496 .66654 L .60486 .66831 L 0 1 0 r
F
.60506 .67657 m .6008 .67469 L p .60513 .67411 L 0 0 1 r
F P
0 g
s
.59364 .68144 m .6008 .67469 L .6057 .67685 L p 0 0 1 r
F P
0 g
s
.6008 .67469 m .60534 .6704 L p .60522 .6741 L 0 0 1 r
F P
0 g
s
.60095 .67782 m .59104 .67851 L p .60486 .66831 L 0 1 0 r
F P
0 g
s
.60486 .66831 m .60541 .66824 L .60527 .67011 L 0 0 1 r
F
.608 .66789 m .60534 .6704 L p .60541 .66824 L F P
0 g
s
.60534 .6704 m .60524 .67049 L p .60541 .66824 L 0 0 1 r
F P
0 g
s
.6049 .66655 m .60812 .67026 L p .60481 .66835 L 1 0 0 r
F P
0 g
s
.59104 .67851 m .6049 .66655 L .60489 .6666 L 0 1 0 r
F
.59104 .67851 m .59807 .66766 L .6049 .66655 L p F P
0 g
s
.6049 .66655 m .60496 .66654 L p .6049 .6666 L 0 1 0 r
F P
0 g
s
.61575 .67064 m .60812 .67026 L .6049 .66655 L p 1 0 0 r
F P
0 g
s
.60489 .66651 m .61575 .67064 L .6049 .66655 L 1 0 0 r
F
.63902 .66343 m .63237 .67814 L .62301 .68257 L p 0 1 0 r
F P
0 g
s
.62301 .68257 m .62976 .66887 L .63902 .66343 L p 0 1 0 r
F P
0 g
s
.62813 .67685 m .6209 .68359 L .61087 .67915 L p 0 0 1 r
F P
0 g
s
.61087 .67915 m .61808 .67238 L .62813 .67685 L p 0 0 1 r
F P
0 g
s
.60812 .67026 m .6187 .68383 L p .60513 .67411 L 1 0 0 r
F P
0 g
s
.60453 .67178 m .60529 .67049 L p .60479 .67447 L 0 1 0 r
F P
0 g
s
.60529 .67049 m .60534 .6704 L p .60527 .67087 L 0 1 0 r
F P
0 g
s
.60529 .67049 m .60527 .67087 L .60479 .67447 L 0 1 0 r
F
.60524 .67049 m .60529 .67049 L p .60513 .67411 L 1 0 0 r
F P
0 g
s
.60529 .67049 m .60518 .67405 L .60513 .67411 L 1 0 0 r
F
.60534 .6704 m .60525 .67323 L .60479 .67447 L 0 1 0 r
F
.60529 .67049 m .60812 .67026 L p .60518 .67405 L 1 0 0 r
F P
0 g
s
.60513 .67411 m .60517 .67414 L .6057 .67685 L 1 0 0 r
F
.60517 .67414 m .60567 .6765 L .6057 .67685 L F
.60576 .67693 m .6057 .67685 L p .60575 .67689 L F P
0 g
s
.6057 .67685 m .60576 .67693 L p .60569 .6769 L 1 0 0 r
F P
0 g
s
.59364 .68144 m .6057 .67685 L .60569 .67697 L 0 0 1 r
F
.60576 .67693 m .60095 .67782 L p .60517 .67414 L 0 1 0 r
F P
0 g
s
.60517 .67414 m .6055 .67437 L .60567 .6765 L 1 0 0 r
F
.60629 .67975 m .60583 .67691 L .60644 .67973 L 0 0 1 r
F
.60566 .67984 m .6058 .67738 L .60629 .67975 L F
.6058 .67738 m .60583 .67691 L .60629 .67975 L F
.60644 .67973 m .60583 .67693 L .61014 .67924 L F
.60583 .67693 m .60583 .67691 L .61014 .67924 L F
.60583 .67691 m .61087 .67915 L p .61014 .67924 L F P
0 g
s
.60583 .67691 m .60576 .67693 L p .60582 .67686 L 0 1 0 r
F P
0 g
s
.6055 .67437 m .6187 .68383 L .60575 .67689 L 1 0 0 r
F
.6055 .67437 m .60575 .67689 L .6057 .67685 L F
.6187 .68383 m .61107 .68319 L .60576 .67693 L p F P
0 g
s
.60576 .67693 m .60583 .67691 L p .60576 .67698 L 0 1 0 r
F P
0 g
s
.60575 .67689 m .6187 .68383 L .60576 .67693 L 1 0 0 r
F
.59396 .68869 m .60095 .67782 L .60576 .67693 L p 0 1 0 r
F P
0 g
s
.59396 .68869 m .60576 .67693 L .60576 .67698 L 0 1 0 r
F
.60555 .67985 m .60566 .67984 L .60563 .68025 L 0 0 1 r
F
.6056 .67988 m .60576 .67693 L .606 .68012 L 1 0 0 r
F
.60379 .68779 m .59396 .68869 L p .6056 .67988 L 0 1 0 r
F P
0 g
s
.60555 .67985 m .6056 .67988 L .60571 .68063 L 1 0 0 r
F
.6056 .67988 m .60566 .67984 L .60562 .67999 L 0 1 0 r
F
.6056 .67988 m .60605 .68016 L .60575 .68058 L 1 0 0 r
F
.6056 .67988 m .60575 .68058 L .60571 .68063 L F
.6056 .67988 m .60562 .67999 L .60561 .68004 L 0 1 0 r
F
.6056 .67988 m .60561 .68004 L .60379 .68779 L F
.60576 .67693 m .61107 .68319 L p .606 .68012 L 1 0 0 r
F P
0 g
s
.60479 .67447 m .60525 .67323 L .60522 .6741 L 0 1 0 r
F
.60534 .6704 m .60529 .67049 L p .60486 .66831 L F P
0 g
s
.60529 .67049 m .60524 .67049 L p .60522 .67019 L 1 0 0 r
F P
0 g
s
.60529 .67049 m .60095 .67782 L p .60482 .66842 L 0 1 0 r
F P
0 g
s
.60486 .66831 m .60529 .67049 L .60482 .66842 L 0 1 0 r
F
.60509 .66852 m .60529 .67049 L .60522 .67019 L 1 0 0 r
F
.60509 .66852 m .60524 .67049 L .60483 .66865 L F
.60476 .66833 m .60509 .66852 L .60483 .66865 L F
.60812 .67026 m .60529 .67049 L p .60509 .66852 L F P
0 g
s
.60095 .67782 m .60453 .67178 L p .60479 .67447 L 0 1 0 r
F P
0 g
s
.61107 .68319 m .60636 .68342 L p .60605 .68016 L 1 0 0 r
F P
0 g
s
.60744 .69612 m .60737 .69624 L p .60642 .69125 L 0 1 0 r
F P
0 g
s
.60737 .69624 m .60731 .69624 L p .60729 .69584 L 1 0 0 r
F P
0 g
s
.60737 .69624 m .60659 .69757 L p .60643 .69165 L 0 1 0 r
F P
0 g
s
.60642 .69125 m .60737 .69624 L .60643 .69165 L 0 1 0 r
F
.60743 .69624 m .60737 .69624 L p .60706 .69174 L 1 0 0 r
F P
0 g
s
.60706 .69174 m .60737 .69624 L .60729 .69584 L 1 0 0 r
F
.6066 .6872 m .61401 .69615 L p .60636 .69129 L F P
0 g
s
.59684 .69869 m .60379 .68779 L .6066 .6872 L p 0 1 0 r
F P
0 g
s
.59684 .69869 m .6066 .6872 L .6066 .68728 L 0 1 0 r
F
.60656 .69694 m .60608 .69672 L p .60636 .69231 L 0 0 1 r
F P
0 g
s
.60631 .69126 m .60636 .69129 L .60637 .69157 L 1 0 0 r
F
.60636 .69129 m .60642 .69125 L .60643 .69165 L 0 1 0 r
F
.60636 .69129 m .60706 .69174 L .60684 .69364 L 1 0 0 r
F
.60659 .69757 m .59684 .69869 L p .60636 .69129 L 0 1 0 r
F P
0 g
s
.60636 .69129 m .60643 .69165 L .60659 .69757 L 0 1 0 r
F
.60706 .69174 m .60731 .69624 L .60682 .6938 L 1 0 0 r
F
.60731 .69624 m .60741 .69672 L .60729 .69684 L 0 0 1 r
F
.60729 .69684 m .60737 .69624 L .60734 .69689 L 1 0 0 r
F
.60731 .69624 m .60737 .69624 L p .60729 .69684 L F P
0 g
s
.60734 .69689 m .60744 .69612 L .60741 .69682 L 0 1 0 r
F
.60737 .69624 m .60744 .69612 L p .60734 .69689 L F P
0 g
s
.60737 .69624 m .61401 .69615 L p .60734 .69689 L 1 0 0 r
F P
0 g
s
.60659 .69757 m .60737 .69624 L p .60734 .69689 L 0 1 0 r
F P
0 g
s
.60729 .69684 m .60741 .69682 L .60737 .69729 L 0 0 1 r
F
.60741 .69682 m .60739 .69729 L .60737 .69729 L F
.60752 .69735 m .60744 .69737 L p .60741 .69682 L 0 1 0 r
F P
0 g
s
.60744 .69737 m .60737 .69729 L p .60738 .6971 L 1 0 0 r
F P
0 g
s
.60729 .69684 m .6074 .69693 L .60737 .69729 L 1 0 0 r
F
.60744 .69737 m .60659 .69757 L p .60734 .69689 L 0 1 0 r
F P
0 g
s
.60734 .69689 m .60741 .69682 L .60744 .69737 L 0 1 0 r
F
.60738 .6971 m .6074 .69693 L .60744 .69737 L 1 0 0 r
F
.60737 .69729 m .60752 .69735 L p .60831 .70239 L 0 0 1 r
F P
0 g
s
.60831 .70239 m .60752 .69735 L .60851 .70236 L 0 0 1 r
F
.60717 .70254 m .60748 .6979 L .60749 .69796 L 0 1 0 r
F
.59946 .70355 m .60737 .69729 L .60831 .70239 L 0 0 1 r
F
.60744 .69737 m .60752 .69735 L p .60711 .70259 L 0 1 0 r
F P
0 g
s
.60711 .70259 m .60752 .69735 L .60717 .70254 L 0 1 0 r
F
.62455 .71036 m .61693 .70916 L .60744 .69737 L p 1 0 0 r
F P
0 g
s
.6074 .69693 m .62455 .71036 L .60744 .69737 L 1 0 0 r
F
.61401 .69615 m .60743 .69624 L p .60706 .69174 L F P
0 g
s
.60737 .69729 m .60744 .69737 L p .60705 .70255 L 1 0 0 r
F P
0 g
s
.60705 .70255 m .60744 .69737 L .60711 .70259 L 1 0 0 r
F
.60671 .69754 m .60744 .69737 L p .60711 .70259 L 0 1 0 r
F P
0 g
s
.6068 .70675 m .59946 .70355 L p .60705 .70255 L 0 0 1 r
F P
0 g
s
.59241 .71012 m .59946 .70355 L .60794 .70726 L p 0 0 1 r
F P
0 g
s
.6079 .70667 m .60717 .70254 L .60799 .70665 L 0 1 0 r
F
.60711 .70259 m .60717 .70254 L .6079 .70667 L F
.60705 .70255 m .60711 .70259 L .60794 .70726 L 1 0 0 r
F
.60711 .70259 m .60769 .70298 L .60792 .70677 L F
.60711 .70259 m .60792 .70677 L .60794 .70726 L F
.60803 .70735 m .60794 .70726 L p .60792 .70677 L F P
0 g
s
.59241 .71012 m .60794 .70726 L .60788 .70809 L 0 0 1 r
F
.60794 .70726 m .60803 .70735 L p .60794 .70731 L 1 0 0 r
F P
0 g
s
.60803 .70735 m .59969 .70852 L p .6079 .70667 L 0 1 0 r
F P
0 g
s
.6079 .70667 m .60799 .70665 L .60803 .70735 L 0 1 0 r
F
.59969 .70852 m .60711 .70259 L .6079 .70667 L F
.60792 .70677 m .60769 .70298 L .60803 .70735 L 1 0 0 r
F
.60744 .69737 m .61693 .70916 L p .60711 .70259 L F P
0 g
s
.59969 .70852 m .60659 .69757 L .60671 .69754 L p 0 1 0 r
F P
0 g
s
.59969 .70852 m .60671 .69754 L .60711 .70259 L 0 1 0 r
F
.60233 .71444 m .59241 .71012 L p .60788 .70809 L 0 0 1 r
F P
0 g
s
.60233 .71444 m .5953 .72095 L .58539 .71665 L p 0 0 1 r
F P
0 g
s
.58539 .71665 m .59241 .71012 L .60233 .71444 L p 0 0 1 r
F P
0 g
s
.59277 .71866 m .60813 .70734 L .60806 .70807 L 0 1 0 r
F
.60796 .70814 m .60803 .70735 L .60807 .7082 L 1 0 0 r
F
.59277 .71866 m .60803 .70735 L .60802 .70742 L 0 1 0 r
F
.60806 .70807 m .6081 .70806 L .60809 .70825 L 0 0 1 r
F
.6094 .70789 m .60827 .70894 L p .6081 .70806 L F P
0 g
s
.60803 .70735 m .60946 .70897 L p .60807 .7082 L 1 0 0 r
F P
0 g
s
.60813 .70734 m .60803 .70735 L p .60799 .70665 L 0 1 0 r
F P
0 g
s
.60803 .70735 m .60813 .70734 L p .60803 .70741 L 0 1 0 r
F P
0 g
s
.60814 .70748 m .60803 .70735 L p .60781 .70306 L 1 0 0 r
F P
0 g
s
.60769 .70298 m .60781 .70306 L .60803 .70735 L 1 0 0 r
F
.59277 .71866 m .59969 .70852 L .60803 .70735 L p 0 1 0 r
F P
0 g
s
.60788 .70809 m .60796 .70814 L .60791 .70826 L 1 0 0 r
F
.60796 .70814 m .60809 .70821 L .60798 .70824 L F
.60796 .70814 m .60798 .70824 L .60791 .70826 L F
.6025 .71816 m .59277 .71866 L p .60796 .70814 L 0 1 0 r
F P
0 g
s
.60796 .70814 m .60806 .70807 L .60797 .70822 L 0 1 0 r
F
.60796 .70814 m .60797 .70822 L .6025 .71816 L F
.61693 .70916 m .60946 .70897 L .60814 .70748 L p 1 0 0 r
F P
0 g
s
.60781 .70306 m .61693 .70916 L .60814 .70748 L 1 0 0 r
F
.60946 .70897 m .60815 .70911 L p .60809 .70821 L F P
0 g
s
.60528 .72762 m .59562 .72835 L p .60836 .71924 L 0 1 0 r
F P
0 g
s
.60836 .71924 m .60905 .71915 L .60877 .72137 L 0 0 1 r
F
.60885 .72183 m .60869 .72198 L p .60905 .71915 L F P
0 g
s
.60846 .71717 m .61236 .72174 L p .60826 .71931 L 1 0 0 r
F P
0 g
s
.59562 .72835 m .6025 .71816 L .60846 .71717 L p 0 1 0 r
F P
0 g
s
.59562 .72835 m .60846 .71717 L .60845 .71725 L 0 1 0 r
F
.60818 .71926 m .60861 .71952 L .60828 .71977 L 1 0 0 r
F
.61236 .72174 m .60876 .72197 L p .60861 .71952 L F P
0 g
s
.60892 .72691 m .61525 .73455 L p .60859 .73037 L 1 0 0 r
F P
0 g
s
.6084 .72701 m .60892 .72691 L p .60859 .73037 L 0 1 0 r
F P
0 g
s
.59844 .73788 m .60528 .72762 L .6084 .72701 L p 0 1 0 r
F P
0 g
s
.59844 .73788 m .6084 .72701 L .60859 .73037 L 0 1 0 r
F
.50456 .73831 m .51126 .73191 L .52124 .73614 L p 0 0 1 r
F P
0 g
s
.51126 .73191 m .50456 .73831 L .49456 .73409 L p 0 0 1 r
F P
0 g
s
.54788 .73819 m .55471 .73179 L .56461 .73602 L p 0 0 1 r
F P
0 g
s
.55471 .73179 m .54788 .73819 L .53796 .73397 L p 0 0 1 r
F P
0 g
s
.53464 .76636 m .54145 .76094 L .55138 .76533 L p 0 1 0 r
F P
0 g
s
.54145 .76094 m .53464 .76636 L .52468 .76092 L p 0 1 0 r
F P
0 g
s
.58474 .75619 m .59159 .74738 L .60122 .74722 L p 0 1 0 r
F P
0 g
s
.60802 .73689 m .60122 .74722 L .59159 .74738 L p 0 1 0 r
F P
0 g
s
.67439 .55807 m .67477 .56022 L p .66244 .58459 L 0 1 0 r
F P
0 g
s
.67477 .56022 m .67099 .57367 L .66244 .58459 L p 0 1 0 r
F P
0 g
s
.59816 .73166 m .5912 .73806 L .58137 .73384 L p 0 0 1 r
F P
0 g
s
.58481 .70194 m .57777 .70542 L .56781 .69815 L p 1 0 0 r
F P
0 g
s
.49795 .75277 m .50464 .74861 L .51467 .75498 L p 0 1 0 r
F P
0 g
s
.50464 .74861 m .49795 .75277 L .48792 .74587 L p 0 1 0 r
F P
0 g
s
.50779 .70291 m .51448 .69445 L .52443 .69704 L p 1 0 0 r
F P
0 g
s
.52443 .69704 m .53117 .68941 L .5411 .6932 L p 1 0 0 r
F P
0 g
s
.53117 .68941 m .52443 .69704 L .51448 .69445 L p 1 0 0 r
F P
0 g
s
.6609 .62198 m .65454 .63988 L .64561 .64769 L p 0 1 0 r
F P
0 g
s
.64561 .64769 m .65211 .63088 L .6609 .62198 L p 0 1 0 r
F P
0 g
s
.5411 .6932 m .54792 .68663 L .55786 .69192 L p 1 0 0 r
F P
0 g
s
.54792 .68663 m .5411 .6932 L .53117 .68941 L p 1 0 0 r
F P
0 g
s
.49114 .7103 m .4978 .70124 L .50779 .70291 L p 1 0 0 r
F P
0 g
s
.51448 .69445 m .50779 .70291 L .4978 .70124 L p 1 0 0 r
F P
0 g
s
.56781 .69815 m .57478 .69373 L .58481 .70194 L p 1 0 0 r
F P
0 g
s
.57478 .69373 m .56781 .69815 L .55786 .69192 L p 1 0 0 r
F P
0 g
s
.47789 .73627 m .48451 .72985 L .49456 .73409 L p 0 0 1 r
F P
0 g
s
.48451 .72985 m .47789 .73627 L .46968 .73282 L p 0 0 1 r
F P
0 g
s
.46968 .73282 m .46963 .7328 L p .46967 .73279 L 0 0 1 r
F P
0 g
s
.46967 .73279 m .48451 .72985 L .46968 .73282 L 0 0 1 r
F
.46945 .73182 m .48451 .72985 L .46963 .7328 L F
.46782 .73149 m .46919 .7307 L p .46945 .73182 L 0 1 0 r
F P
0 g
s
.46963 .7328 m .46782 .73149 L p .46945 .73182 L 0 1 0 r
F P
0 g
s
.47445 .7187 m .46784 .72818 L .46287 .72788 L p 1 0 0 r
F P
0 g
s
.46782 .73149 m .46286 .72788 L p .46837 .72639 L 0 1 0 r
F P
0 g
s
.46286 .72788 m .45775 .72416 L p .46233 .72512 L 0 1 0 r
F P
0 g
s
.46287 .72788 m .46286 .72788 L p .46233 .72512 L 1 0 0 r
F P
0 g
s
.46233 .72512 m .47445 .7187 L .46287 .72788 L 1 0 0 r
F
.46233 .72512 m .46837 .72639 L .46286 .72788 L 0 1 0 r
F
.46286 .72788 m .45771 .72757 L p .46233 .72512 L 1 0 0 r
F P
0 g
s
.46432 .71801 m .47445 .7187 L p .46233 .72512 L 1 0 0 r
F P
0 g
s
.46199 .72355 m .46165 .72188 L .462 .72355 L 0 1 0 r
F
.45775 .72416 m .46165 .72188 L p .46199 .72355 L F P
0 g
s
.46165 .72188 m .46432 .71801 L p .46233 .72512 L 1 0 0 r
F P
0 g
s
.45775 .72416 m .46762 .72273 L .46837 .72639 L 0 1 0 r
F
.45775 .72416 m .44765 .71683 L p .4612 .71967 L F P
0 g
s
.46432 .71801 m .46165 .72188 L p .4612 .71967 L 1 0 0 r
F P
0 g
s
.4643 .72032 m .46165 .72188 L p .4612 .71967 L 0 1 0 r
F P
0 g
s
.46165 .72188 m .45775 .72416 L p .4612 .71967 L 0 1 0 r
F P
0 g
s
.46119 .71967 m .4612 .71967 L .46165 .72188 L 1 0 0 r
F
.45771 .72757 m .4571 .72754 L p .46119 .71967 L F P
0 g
s
.46165 .72188 m .45771 .72757 L p .46119 .71967 L 1 0 0 r
F P
0 g
s
.45771 .72757 m .46165 .72188 L p .46233 .72512 L 1 0 0 r
F P
0 g
s
.462 .72355 m .46169 .72185 L .46202 .72354 L 0 1 0 r
F
.46165 .72188 m .46169 .72185 L p .462 .72355 L F P
0 g
s
.4643 .72032 m .46762 .72273 L p .46202 .72354 L 0 1 0 r
F P
0 g
s
.46169 .72185 m .4643 .72032 L p .46202 .72354 L 0 1 0 r
F P
0 g
s
.4643 .72133 m .45771 .72779 L .4571 .72754 L p 0 0 1 r
F P
0 g
s
.45705 .72752 m .44756 .72353 L p .45603 .72241 L 0 0 1 r
F P
0 g
s
.44765 .71683 m .45418 .71292 L .46084 .71779 L p 0 1 0 r
F P
0 g
s
.46084 .71779 m .46432 .71801 L p .46121 .71966 L 1 0 0 r
F P
0 g
s
.4612 .71967 m .46084 .71779 L .46121 .71966 L 1 0 0 r
F
.48108 .70926 m .47445 .7187 L .46432 .71801 L p F P
0 g
s
.46432 .71801 m .47096 .70842 L .48108 .70926 L p 1 0 0 r
F P
0 g
s
.47096 .70842 m .46432 .71801 L .46085 .71779 L p 1 0 0 r
F P
0 g
s
.46085 .71778 m .47096 .70842 L .46085 .71779 L 1 0 0 r
F
.46012 .71418 m .47096 .70842 L .46084 .71779 L F
.47445 .7187 m .48108 .70926 L .49114 .7103 L p F P
0 g
s
.47442 .7256 m .48451 .72985 L p .46948 .73182 L 0 0 1 r
F P
0 g
s
.46946 .73176 m .47442 .7256 L .46948 .73182 L 0 0 1 r
F
.46919 .7307 m .47442 .7256 L p .46941 .73183 L F P
0 g
s
.46919 .7307 m .46782 .73149 L p .46837 .72639 L 0 1 0 r
F P
0 g
s
.47442 .7256 m .46782 .73204 L .45771 .72779 L p 0 0 1 r
F P
0 g
s
.49117 .7234 m .48451 .72985 L .47442 .7256 L p 0 0 1 r
F P
0 g
s
.45771 .72779 m .4643 .72133 L .47442 .7256 L p 0 0 1 r
F P
0 g
s
.47442 .7256 m .48107 .71912 L .49117 .7234 L p 0 0 1 r
F P
0 g
s
.46762 .72273 m .4643 .72032 L p .46728 .72094 L 0 1 0 r
F P
0 g
s
.48107 .71912 m .47442 .7256 L .4677 .72277 L p 0 0 1 r
F P
0 g
s
.4677 .72277 m .4643 .72133 L p .46728 .72094 L 0 0 1 r
F P
0 g
s
.46728 .72094 m .48107 .71912 L .4677 .72277 L 0 0 1 r
F
.47093 .71482 m .48107 .71912 L p .46728 .72094 L F P
0 g
s
.47092 .71648 m .48106 .72378 L p .46728 .72094 L 0 1 0 r
F P
0 g
s
.4643 .72032 m .4668 .71887 L p .46728 .72094 L 0 1 0 r
F P
0 g
s
.46728 .72091 m .47093 .71482 L .46728 .72094 L 0 0 1 r
F
.46682 .71885 m .47093 .71482 L p .46726 .72094 L F P
0 g
s
.4668 .71887 m .47092 .71648 L p .46728 .72094 L 0 1 0 r
F P
0 g
s
.48106 .72378 m .47441 .72766 L .46762 .72273 L p 0 1 0 r
F P
0 g
s
.46728 .72094 m .48106 .72378 L .46762 .72273 L 0 1 0 r
F
.46726 .72094 m .46728 .72091 L .46728 .72094 L 0 0 1 r
F
.4643 .72133 m .46682 .71885 L p .46726 .72094 L F P
0 g
s
.45418 .71292 m .44404 .70553 L p .45894 .70867 L 0 1 0 r
F P
0 g
s
.46077 .7077 m .47096 .70842 L p .46012 .71418 L 1 0 0 r
F P
0 g
s
.46012 .71416 m .46077 .7077 L .46012 .71418 L 1 0 0 r
F
.45922 .70996 m .46077 .7077 L p .46012 .71418 L F P
0 g
s
.45922 .70996 m .45418 .71292 L p .45894 .70867 L 0 1 0 r
F P
0 g
s
.45418 .71292 m .45922 .70996 L p .46012 .71418 L 0 1 0 r
F P
0 g
s
.46084 .71779 m .45418 .71292 L p .46012 .71418 L 0 1 0 r
F P
0 g
s
.44765 .71683 m .46084 .71779 L .4612 .71967 L 0 1 0 r
F
.45418 .71292 m .44765 .71683 L .43755 .70957 L p F P
0 g
s
.43755 .70957 m .44404 .70553 L .45418 .71292 L p 0 1 0 r
F P
0 g
s
.46084 .71779 m .45504 .71742 L p .46012 .71418 L 1 0 0 r
F P
0 g
s
.45494 .71693 m .46012 .71418 L .45504 .71742 L 1 0 0 r
F
.46085 .71779 m .46084 .71779 L p .46085 .71778 L F P
0 g
s
.46012 .71418 m .46012 .71418 L .46084 .71779 L 0 1 0 r
F
.4643 .72032 m .46084 .71779 L p .46644 .71706 L F P
0 g
s
.47093 .71482 m .4668 .71887 L p .46615 .71561 L 0 0 1 r
F P
0 g
s
.47092 .71648 m .4668 .71887 L p .46644 .71706 L 0 1 0 r
F P
0 g
s
.4668 .71887 m .4643 .72032 L p .46644 .71706 L 0 1 0 r
F P
0 g
s
.46012 .71418 m .46612 .71546 L .46084 .71779 L 0 1 0 r
F
.46612 .71546 m .47093 .71482 L .46615 .71561 L 0 0 1 r
F
.46612 .71546 m .47092 .71648 L .46644 .71706 L 0 1 0 r
F
.46612 .71546 m .46644 .71706 L .46084 .71779 L F
.45494 .71693 m .46612 .71546 L .45504 .71742 L 0 0 1 r
F
.46612 .71546 m .46615 .71561 L .45504 .71742 L F
.46084 .71779 m .4643 .72032 L p .4612 .71967 L 0 1 0 r
F P
0 g
s
.45504 .71742 m .46084 .71779 L p .45603 .72241 L 1 0 0 r
F P
0 g
s
.45603 .72241 m .46084 .71779 L .4612 .71967 L 1 0 0 r
F
.45603 .72241 m .46119 .71967 L .4571 .72754 L F
.4643 .72133 m .45504 .71742 L p .46615 .71561 L 0 0 1 r
F P
0 g
s
.4668 .71887 m .4643 .72133 L p .46615 .71561 L 0 0 1 r
F P
0 g
s
.45504 .71742 m .45413 .71704 L p .45494 .71693 L 0 0 1 r
F P
0 g
s
.44756 .72353 m .45413 .71704 L .45504 .71742 L p 0 0 1 r
F P
0 g
s
.45413 .71704 m .44756 .72353 L .43737 .71925 L p 0 0 1 r
F P
0 g
s
.43737 .71925 m .44392 .71273 L .45413 .71704 L p 0 0 1 r
F P
0 g
s
.45374 .71143 m .45894 .70867 L .45478 .71619 L 1 0 0 r
F
.45494 .71693 m .45922 .70996 L .46012 .71418 L F
.45481 .71636 m .45922 .70996 L p .45494 .71693 L F P
0 g
s
.45413 .71704 m .44392 .71273 L p .45374 .71143 L 0 0 1 r
F P
0 g
s
.45894 .70867 m .45894 .70867 L .45922 .70996 L 0 1 0 r
F
.45922 .70996 m .45481 .71636 L p .45894 .70867 L 1 0 0 r
F P
0 g
s
.45894 .70867 m .45481 .71636 L .45478 .71619 L 1 0 0 r
F
.45922 .70996 m .45925 .70994 L p .46012 .71418 L 0 1 0 r
F P
0 g
s
.46012 .71418 m .46012 .71416 L .46012 .71418 L 1 0 0 r
F
.46075 .70906 m .46551 .71253 L p .46012 .71418 L 0 1 0 r
F P
0 g
s
.45925 .70994 m .46075 .70906 L p .46012 .71418 L 0 1 0 r
F P
0 g
s
.46074 .71051 m .45481 .71636 L p .45374 .71143 L 0 0 1 r
F P
0 g
s
.45481 .71636 m .45413 .71704 L p .45374 .71143 L 0 0 1 r
F P
0 g
s
.46012 .71418 m .46551 .71253 L .46612 .71546 L 0 1 0 r
F
.45413 .71704 m .46074 .71051 L .46551 .71253 L p 0 0 1 r
F P
0 g
s
.46551 .71253 m .47093 .71482 L p .46609 .71546 L 0 0 1 r
F P
0 g
s
.45413 .71704 m .46551 .71253 L .46609 .71546 L 0 0 1 r
F
.48776 .7126 m .48107 .71912 L .47093 .71482 L p F P
0 g
s
.48774 .69992 m .48108 .70926 L .47096 .70842 L p 1 0 0 r
F P
0 g
s
.47093 .71482 m .4776 .70828 L .48776 .7126 L p 0 0 1 r
F P
0 g
s
.46551 .71253 m .46075 .70906 L p .465 .70995 L 0 1 0 r
F P
0 g
s
.4776 .70828 m .47093 .71482 L .46561 .71257 L p 0 0 1 r
F P
0 g
s
.46561 .71257 m .46074 .71051 L p .465 .70995 L 0 0 1 r
F P
0 g
s
.465 .70995 m .4776 .70828 L .46561 .71257 L 0 0 1 r
F
.47096 .70842 m .47762 .69887 L .48774 .69992 L p 1 0 0 r
F P
0 g
s
.47762 .69887 m .47096 .70842 L .46077 .7077 L p 1 0 0 r
F P
0 g
s
.46075 .70906 m .4643 .70699 L p .465 .70995 L 0 1 0 r
F P
0 g
s
.46077 .7077 m .46743 .69802 L .47762 .69887 L p 1 0 0 r
F P
0 g
s
.46743 .69802 m .46077 .7077 L .45873 .70757 L p 1 0 0 r
F P
0 g
s
.46077 .7077 m .45922 .70996 L p .45894 .70867 L 1 0 0 r
F P
0 g
s
.44404 .70553 m .45873 .70757 L .45894 .70867 L 0 1 0 r
F
.44404 .70553 m .45058 .70158 L .45873 .70757 L p F P
0 g
s
.44392 .71273 m .45051 .70618 L .45287 .70718 L p 0 0 1 r
F P
0 g
s
.45287 .70718 m .45873 .70757 L p .4536 .71071 L 1 0 0 r
F P
0 g
s
.44392 .71273 m .45287 .70718 L .45374 .71143 L 0 0 1 r
F
.45374 .71143 m .45873 .70757 L .45894 .70867 L 1 0 0 r
F
.44386 .71668 m .4536 .71071 L .45374 .71143 L F
.4536 .71071 m .45873 .70757 L .45374 .71143 L F
.45873 .70757 m .46077 .7077 L p .45894 .70867 L F P
0 g
s
.45873 .70757 m .46075 .70906 L p .45894 .70867 L 0 1 0 r
F P
0 g
s
.46075 .70906 m .45873 .70757 L p .46377 .70442 L 0 1 0 r
F P
0 g
s
.45873 .70757 m .45058 .70158 L p .4578 .70314 L 0 1 0 r
F P
0 g
s
.45873 .70757 m .45873 .70757 L p .4578 .70314 L 1 0 0 r
F P
0 g
s
.4578 .70314 m .46743 .69802 L .45873 .70757 L 1 0 0 r
F
.4578 .70314 m .46377 .70442 L .45873 .70757 L 0 1 0 r
F
.45873 .70757 m .45287 .70718 L p .4578 .70314 L 1 0 0 r
F P
0 g
s
.45287 .70718 m .45051 .70618 L p .45261 .7059 L 0 0 1 r
F P
0 g
s
.45287 .70718 m .4505 .70702 L p .45261 .7059 L 1 0 0 r
F P
0 g
s
.45261 .7059 m .4578 .70314 L .45287 .70718 L 1 0 0 r
F
.45261 .7059 m .45261 .7059 L .45287 .70718 L 0 0 1 r
F
.4643 .70699 m .46075 .70906 L p .46377 .70442 L 0 1 0 r
F P
0 g
s
.46075 .70906 m .45922 .70996 L p .45894 .70867 L 0 1 0 r
F P
0 g
s
.46739 .70394 m .46074 .71051 L .45287 .70718 L p 0 0 1 r
F P
0 g
s
.45261 .7059 m .46739 .70394 L .45287 .70718 L 0 0 1 r
F
.45287 .70718 m .46074 .71051 L p .45374 .71143 L F P
0 g
s
.44386 .71668 m .4505 .70702 L .45287 .70718 L p 1 0 0 r
F P
0 g
s
.44386 .71668 m .45287 .70718 L .4536 .71071 L 1 0 0 r
F
.45717 .69726 m .46743 .69802 L p .4578 .70314 L F P
0 g
s
.45058 .70158 m .45668 .69799 L p .45754 .70192 L 0 1 0 r
F P
0 g
s
.45668 .69799 m .45717 .69726 L p .45778 .70298 L 1 0 0 r
F P
0 g
s
.45668 .69799 m .45778 .70298 L .4578 .70314 L 1 0 0 r
F
.45058 .70158 m .44038 .69413 L p .45659 .69757 L 0 1 0 r
F P
0 g
s
.45668 .69799 m .45058 .70158 L p .45659 .69757 L 0 1 0 r
F P
0 g
s
.45781 .70314 m .46329 .70219 L .46377 .70442 L 0 1 0 r
F
.45058 .70158 m .45754 .70192 L .45781 .70314 L F
.45754 .70192 m .46329 .70219 L .45781 .70314 L F
.44404 .70553 m .43755 .70957 L .42742 .70246 L p F P
0 g
s
.42742 .70246 m .43388 .69822 L .44404 .70553 L p 0 1 0 r
F P
0 g
s
.45058 .70158 m .44404 .70553 L .43388 .69822 L p 0 1 0 r
F P
0 g
s
.43388 .69822 m .44038 .69413 L .45058 .70158 L p 0 1 0 r
F P
0 g
s
.45051 .70618 m .44392 .71273 L .43367 .70841 L p 0 0 1 r
F P
0 g
s
.43367 .70841 m .44025 .70183 L .45051 .70618 L p 0 0 1 r
F P
0 g
s
.45261 .7059 m .45668 .69799 L .4578 .70314 L 1 0 0 r
F
.45051 .70618 m .45228 .70442 L p .45261 .7059 L 0 0 1 r
F P
0 g
s
.4505 .70702 m .45228 .70442 L p .45261 .7059 L 1 0 0 r
F P
0 g
s
.45228 .70442 m .45668 .69799 L p .45261 .7059 L 1 0 0 r
F P
0 g
s
.45261 .7059 m .45228 .70442 L .45261 .7059 L 0 0 1 r
F
.45754 .70192 m .45671 .69797 L .45755 .70192 L 0 1 0 r
F
.45668 .69799 m .45671 .69797 L p .45754 .70192 L F P
0 g
s
.45717 .6977 m .46329 .70219 L p .45755 .70192 L 0 1 0 r
F P
0 g
s
.45671 .69797 m .45717 .6977 L p .45755 .70192 L 0 1 0 r
F P
0 g
s
.46329 .70219 m .46739 .70394 L p .46376 .70442 L 0 0 1 r
F P
0 g
s
.46739 .70394 m .4776 .70828 L p .46494 .70995 L 0 0 1 r
F P
0 g
s
.46493 .70993 m .46739 .70394 L .46494 .70995 L 0 0 1 r
F
.4643 .70699 m .46739 .70394 L p .46492 .70996 L F P
0 g
s
.48431 .7017 m .4776 .70828 L .46739 .70394 L p 0 0 1 r
F P
0 g
s
.49443 .69072 m .48774 .69992 L .47762 .69887 L p 1 0 0 r
F P
0 g
s
.47762 .69887 m .48431 .68941 L .49443 .69072 L p 1 0 0 r
F P
0 g
s
.48431 .68941 m .47762 .69887 L .46743 .69802 L p 1 0 0 r
F P
0 g
s
.46739 .70394 m .47409 .69733 L .48431 .7017 L p 0 0 1 r
F P
0 g
s
.46329 .70219 m .45717 .6977 L p .4626 .69885 L 0 1 0 r
F P
0 g
s
.47409 .69733 m .46739 .70394 L .46341 .70224 L p 0 0 1 r
F P
0 g
s
.46341 .70224 m .45715 .69958 L p .4626 .69885 L 0 0 1 r
F P
0 g
s
.4626 .69885 m .47409 .69733 L .46341 .70224 L 0 0 1 r
F
.46743 .69802 m .47412 .68836 L .48431 .68941 L p 1 0 0 r
F P
0 g
s
.47412 .68836 m .46743 .69802 L .45717 .69726 L p 1 0 0 r
F P
0 g
s
.45717 .6977 m .4617 .69506 L p .4626 .69885 L 0 1 0 r
F P
0 g
s
.45717 .69726 m .46387 .68747 L .47412 .68836 L p 1 0 0 r
F P
0 g
s
.46382 .69294 m .47409 .69733 L p .46252 .69886 L 0 0 1 r
F P
0 g
s
.45715 .69958 m .4617 .69506 L p .46252 .69886 L 0 0 1 r
F P
0 g
s
.4617 .69506 m .46382 .69294 L p .46252 .69886 L 0 0 1 r
F P
0 g
s
.45717 .69726 m .45668 .69799 L p .45659 .69757 L 1 0 0 r
F P
0 g
s
.45652 .69722 m .45717 .69726 L p .45659 .69757 L 1 0 0 r
F P
0 g
s
.44038 .69413 m .44694 .69016 L .45652 .69722 L p 0 1 0 r
F P
0 g
s
.45659 .69757 m .45652 .69722 L .45659 .69757 L 1 0 0 r
F
.45652 .69722 m .45717 .6977 L p .45659 .69757 L 0 1 0 r
F P
0 g
s
.44038 .69413 m .45652 .69722 L .45659 .69757 L 0 1 0 r
F
.45051 .70618 m .44025 .70183 L p .45136 .70035 L 0 0 1 r
F P
0 g
s
.45136 .70035 m .45659 .69757 L .45225 .70431 L 1 0 0 r
F
.45668 .69799 m .45228 .70442 L p .45659 .69757 L F P
0 g
s
.45228 .70442 m .45222 .70448 L p .45136 .70035 L 0 0 1 r
F P
0 g
s
.45222 .70448 m .45051 .70618 L p .45136 .70035 L 0 0 1 r
F P
0 g
s
.45228 .70442 m .4505 .70702 L p .45225 .70431 L 1 0 0 r
F P
0 g
s
.45659 .69757 m .45228 .70442 L .45225 .70431 L 1 0 0 r
F
.45715 .69958 m .45228 .70442 L p .45136 .70035 L 0 0 1 r
F P
0 g
s
.45136 .70035 m .45652 .69722 L .45659 .69757 L 1 0 0 r
F
.45131 .70011 m .45652 .69722 L .45136 .70035 L F
.44025 .70183 m .44686 .6952 L .45062 .6968 L p 0 0 1 r
F P
0 g
s
.45062 .6968 m .45652 .69722 L p .45131 .70011 L 1 0 0 r
F P
0 g
s
.45062 .6968 m .45715 .69958 L p .45136 .70035 L 0 0 1 r
F P
0 g
s
.44025 .70183 m .45062 .6968 L .45136 .70035 L 0 0 1 r
F
.44017 .70628 m .44684 .69653 L .45062 .6968 L p 1 0 0 r
F P
0 g
s
.44017 .70628 m .45062 .6968 L .45131 .70011 L 1 0 0 r
F
.44017 .70628 m .45131 .70011 L .45136 .70035 L F
.46387 .68747 m .45717 .69726 L .45652 .69722 L p F P
0 g
s
.45652 .69722 m .44694 .69016 L p .45538 .69199 L 0 1 0 r
F P
0 g
s
.45652 .69722 m .45062 .6968 L p .45538 .69199 L 1 0 0 r
F P
0 g
s
.45538 .69199 m .46387 .68747 L .45652 .69722 L 1 0 0 r
F
.45538 .69199 m .45541 .692 L .45652 .69722 L 0 1 0 r
F
.45717 .6977 m .45652 .69722 L p .46131 .69328 L F P
0 g
s
.45541 .692 m .46131 .69328 L .45652 .69722 L 0 1 0 r
F
.4617 .69506 m .45717 .6977 L p .46131 .69328 L F P
0 g
s
.45717 .6977 m .45668 .69799 L p .45659 .69757 L 0 1 0 r
F P
0 g
s
.44694 .69016 m .45355 .68624 L .45422 .68674 L p 0 1 0 r
F P
0 g
s
.44694 .69016 m .45422 .68674 L .45518 .69108 L 0 1 0 r
F
.45422 .68674 m .46387 .68747 L p .45538 .69199 L 1 0 0 r
F P
0 g
s
.45538 .69199 m .45422 .68674 L .45538 .69199 L 1 0 0 r
F
.46382 .69294 m .46169 .69506 L p .46139 .69365 L 0 0 1 r
F P
0 g
s
.45017 .69476 m .45538 .69199 L .45062 .6968 L 1 0 0 r
F
.45017 .69476 m .46382 .69294 L .45062 .6968 L 0 0 1 r
F
.48082 .69068 m .47409 .69733 L .46382 .69294 L p F P
0 g
s
.44694 .69016 m .45141 .69066 L .45102 .69104 L 0 1 0 r
F
.45778 .69251 m .46097 .69172 L .46131 .69328 L F
.45354 .68668 m .45422 .68674 L p .44971 .69273 L 1 0 0 r
F P
0 g
s
.44686 .6952 m .44964 .69242 L p .45009 .69441 L 0 0 1 r
F P
0 g
s
.45017 .69476 m .46097 .69172 L .46131 .69328 L 0 0 1 r
F
.44686 .6952 m .45009 .69441 L .45017 .69476 L F
.45017 .69476 m .45422 .68674 L .45538 .69199 L 1 0 0 r
F
.44971 .69273 m .45422 .68674 L .45017 .69476 L F
.45009 .69441 m .46097 .69172 L .45017 .69476 L 0 0 1 r
F
.45062 .6968 m .44686 .6952 L p .45017 .69476 L F P
0 g
s
.44684 .69653 m .44971 .69273 L .45017 .69476 L 1 0 0 r
F
.44684 .69653 m .44964 .69242 L p .44971 .69273 L F P
0 g
s
.44964 .69242 m .45354 .68668 L p .44971 .69273 L 1 0 0 r
F P
0 g
s
.45422 .68674 m .46097 .69172 L p .45518 .69108 L 0 1 0 r
F P
0 g
s
.45352 .68854 m .46097 .69172 L p .45009 .69441 L 0 0 1 r
F P
0 g
s
.44964 .69242 m .45352 .68854 L p .45009 .69441 L 0 0 1 r
F P
0 g
s
.46097 .69172 m .46382 .69294 L p .46131 .69328 L 0 0 1 r
F P
0 g
s
.49102 .68008 m .48431 .68941 L .47412 .68836 L p 1 0 0 r
F P
0 g
s
.47412 .68836 m .48084 .67877 L .49102 .68008 L p 1 0 0 r
F P
0 g
s
.48084 .67877 m .47412 .68836 L .46387 .68747 L p 1 0 0 r
F P
0 g
s
.46382 .69294 m .47054 .68626 L .48082 .69068 L p 0 0 1 r
F P
0 g
s
.46097 .69172 m .45422 .68674 L p .46014 .68789 L 0 1 0 r
F P
0 g
s
.47054 .68626 m .46382 .69294 L .46109 .69177 L p 0 0 1 r
F P
0 g
s
.46107 .69167 m .47054 .68626 L .46109 .69177 L 0 0 1 r
F
.46387 .68747 m .47059 .6777 L .48084 .67877 L p 1 0 0 r
F P
0 g
s
.47059 .6777 m .46387 .68747 L .45422 .68674 L p 1 0 0 r
F P
0 g
s
.45422 .68674 m .45354 .68668 L p .45414 .68637 L 1 0 0 r
F P
0 g
s
.45414 .68637 m .47059 .6777 L .45422 .68674 L 1 0 0 r
F
.46027 .67679 m .47059 .6777 L p .45414 .68637 L F P
0 g
s
.45413 .68637 m .45404 .68596 L .45414 .68637 L 0 1 0 r
F
.45355 .68624 m .45404 .68596 L p .45413 .68637 L F P
0 g
s
.45355 .68624 m .44694 .69016 L .43669 .68265 L p 0 1 0 r
F P
0 g
s
.43669 .68265 m .44327 .67864 L .45355 .68624 L p 0 1 0 r
F P
0 g
s
.44694 .69016 m .44038 .69413 L .43017 .68678 L p 0 1 0 r
F P
0 g
s
.43017 .68678 m .43669 .68265 L .44694 .69016 L p 0 1 0 r
F P
0 g
s
.43654 .69081 m .44317 .68412 L .44826 .68629 L p 0 0 1 r
F P
0 g
s
.44038 .69413 m .43388 .69822 L .4237 .69106 L p 0 1 0 r
F P
0 g
s
.4237 .69106 m .43017 .68678 L .44038 .69413 L p 0 1 0 r
F P
0 g
s
.43388 .69822 m .42742 .70246 L .41727 .69556 L p 0 1 0 r
F P
0 g
s
.41727 .69556 m .4237 .69106 L .43388 .69822 L p 0 1 0 r
F P
0 g
s
.44686 .6952 m .44025 .70183 L .42994 .69746 L p 0 0 1 r
F P
0 g
s
.42994 .69746 m .43654 .69081 L .44686 .6952 L p 0 0 1 r
F P
0 g
s
.45354 .68668 m .44964 .69242 L p .44887 .68916 L 1 0 0 r
F P
0 g
s
.44686 .6952 m .43654 .69081 L p .44887 .68916 L 0 0 1 r
F P
0 g
s
.45352 .68854 m .44958 .69248 L p .44887 .68916 L 0 0 1 r
F P
0 g
s
.44958 .69248 m .44686 .6952 L p .44887 .68916 L 0 0 1 r
F P
0 g
s
.43654 .69081 m .4482 .68631 L .44887 .68916 L 0 0 1 r
F
.4482 .68631 m .44826 .68629 L .44887 .68916 L F
.43644 .69574 m .44315 .68591 L .44826 .68629 L p 1 0 0 r
F P
0 g
s
.44826 .68629 m .45354 .68668 L p .44887 .68916 L 1 0 0 r
F P
0 g
s
.43644 .69574 m .44826 .68629 L .44887 .68916 L 1 0 0 r
F
.44684 .69653 m .43644 .69574 L p .44887 .68916 L F P
0 g
s
.44964 .69242 m .44684 .69653 L p .44887 .68916 L 1 0 0 r
F P
0 g
s
.44887 .68916 m .44826 .68629 L .44891 .68915 L 0 0 1 r
F
.44826 .68629 m .45352 .68854 L p .44891 .68915 L F P
0 g
s
.45355 .68624 m .44327 .67864 L p .45286 .68074 L 0 1 0 r
F P
0 g
s
.46027 .67679 m .45404 .68596 L p .45286 .68074 L 1 0 0 r
F P
0 g
s
.45404 .68596 m .46027 .67679 L p .45414 .68637 L 1 0 0 r
F P
0 g
s
.45414 .68637 m .45898 .68307 L .46009 .68766 L 0 1 0 r
F
.45413 .68637 m .46009 .68766 L .45422 .68674 L F
.46009 .68766 m .46014 .68789 L .45422 .68674 L F
.46022 .68183 m .47054 .68626 L p .46002 .68767 L 0 0 1 r
F P
0 g
s
.45352 .68854 m .45898 .68307 L p .46002 .68767 L 0 0 1 r
F P
0 g
s
.45898 .68307 m .46022 .68183 L p .46002 .68767 L 0 0 1 r
F P
0 g
s
.45286 .68074 m .45874 .68203 L .45404 .68596 L 0 1 0 r
F
.45898 .68307 m .45404 .68596 L p .45874 .68203 L F P
0 g
s
.45404 .68596 m .45355 .68624 L p .45286 .68074 L 0 1 0 r
F P
0 g
s
.45282 .68076 m .45286 .68074 L .45404 .68596 L 1 0 0 r
F
.45354 .68668 m .44826 .68629 L p .45282 .68076 L F P
0 g
s
.44763 .68352 m .45282 .68076 L .44826 .68629 L 1 0 0 r
F
.45404 .68596 m .45354 .68668 L p .45282 .68076 L F P
0 g
s
.45422 .68674 m .45355 .68624 L p .45413 .68637 L 0 1 0 r
F P
0 g
s
.45354 .68668 m .45404 .68596 L p .45414 .68637 L 1 0 0 r
F P
0 g
s
.45404 .68596 m .45404 .68596 L p .45414 .68637 L 0 1 0 r
F P
0 g
s
.45404 .68596 m .45898 .68307 L p .45414 .68637 L 0 1 0 r
F P
0 g
s
.44327 .67864 m .44989 .6747 L .45181 .67612 L p 0 1 0 r
F P
0 g
s
.45181 .67612 m .46027 .67679 L p .45287 .68073 L 1 0 0 r
F P
0 g
s
.45286 .68074 m .45181 .67612 L .45287 .68073 L 1 0 0 r
F
.46022 .68183 m .45898 .68308 L p .45874 .68203 L 0 0 1 r
F P
0 g
s
.4773 .67954 m .47054 .68626 L .46022 .68183 L p 0 0 1 r
F P
0 g
s
.45181 .67612 m .45854 .68111 L p .45273 .68017 L 0 1 0 r
F P
0 g
s
.44327 .67864 m .45181 .67612 L .45273 .68017 L 0 1 0 r
F
.44327 .67864 m .45854 .68111 L .45874 .68203 L F
.44987 .67597 m .45181 .67612 L p .44763 .68352 L 1 0 0 r
F P
0 g
s
.44763 .68352 m .45181 .67612 L .45286 .68074 L 1 0 0 r
F
.4469 .68036 m .44987 .67597 L p .44763 .68352 L F P
0 g
s
.44317 .68412 m .4469 .68036 L p .4476 .68325 L 0 0 1 r
F P
0 g
s
.44317 .68412 m .45854 .68111 L .45875 .68203 L 0 0 1 r
F
.44828 .6863 m .44317 .68412 L p .44763 .68352 L F P
0 g
s
.43669 .68265 m .43017 .68678 L .41994 .67958 L p 0 1 0 r
F P
0 g
s
.43017 .68678 m .4237 .69106 L .41349 .68413 L p 0 1 0 r
F P
0 g
s
.41349 .68413 m .41994 .67958 L .43017 .68678 L p 0 1 0 r
F P
0 g
s
.44317 .68412 m .43654 .69081 L .42617 .68639 L p 0 0 1 r
F P
0 g
s
.41994 .67958 m .42643 .67524 L .43669 .68265 L p 0 1 0 r
F P
0 g
s
.44327 .67864 m .43669 .68265 L .42643 .67524 L p 0 1 0 r
F P
0 g
s
.42617 .68639 m .43279 .67968 L .44317 .68412 L p 0 0 1 r
F P
0 g
s
.44987 .67597 m .4469 .68036 L p .44629 .67786 L 1 0 0 r
F P
0 g
s
.42643 .67524 m .43297 .67107 L .44327 .67864 L p 0 1 0 r
F P
0 g
s
.44989 .6747 m .44327 .67864 L .43297 .67107 L p 0 1 0 r
F P
0 g
s
.44317 .68412 m .43279 .67968 L p .44629 .67786 L 0 0 1 r
F P
0 g
s
.44985 .67738 m .44685 .68042 L p .44629 .67786 L 0 0 1 r
F P
0 g
s
.44685 .68042 m .44317 .68412 L p .44629 .67786 L 0 0 1 r
F P
0 g
s
.4458 .67564 m .44987 .67597 L p .44629 .67786 L 1 0 0 r
F P
0 g
s
.43279 .67968 m .43945 .67292 L .4458 .67564 L p 0 0 1 r
F P
0 g
s
.4458 .67564 m .44985 .67738 L p .44632 .67786 L 0 0 1 r
F P
0 g
s
.43279 .67968 m .4458 .67564 L .44632 .67786 L 0 0 1 r
F
.45181 .67612 m .44989 .6747 L p .45157 .67507 L 0 1 0 r
F P
0 g
s
.43297 .67107 m .43956 .66702 L .44989 .6747 L p 0 1 0 r
F P
0 g
s
.47733 .668 m .47059 .6777 L .46027 .67679 L p 1 0 0 r
F P
0 g
s
.46027 .67679 m .46702 .66692 L .47733 .668 L p 1 0 0 r
F P
0 g
s
.46702 .66692 m .46027 .67679 L .45182 .67612 L p 1 0 0 r
F P
0 g
s
.45182 .67612 m .44987 .67597 L p .45158 .67507 L 1 0 0 r
F P
0 g
s
.45158 .67507 m .46702 .66692 L .45182 .67612 L 1 0 0 r
F
.45663 .66598 m .46702 .66692 L p .45158 .67507 L F P
0 g
s
.45157 .67507 m .45157 .67506 L .45158 .67507 L 0 1 0 r
F
.44989 .6747 m .45128 .67389 L p .45157 .67507 L F P
0 g
s
.44987 .67597 m .45128 .67389 L p .45158 .67507 L 1 0 0 r
F P
0 g
s
.45128 .67389 m .45663 .66598 L p .45158 .67507 L 1 0 0 r
F P
0 g
s
.45157 .67506 m .45157 .67506 L .45158 .67507 L 0 1 0 r
F
.48758 .66932 m .48084 .67877 L .47059 .6777 L p 1 0 0 r
F P
0 g
s
.47059 .6777 m .47733 .668 L .48758 .66932 L p 1 0 0 r
F P
0 g
s
.46022 .68183 m .46696 .67508 L .4773 .67954 L p 0 0 1 r
F P
0 g
s
.46696 .67508 m .46022 .68183 L .45866 .68116 L p 0 0 1 r
F P
0 g
s
.45854 .68111 m .45181 .67612 L p .45762 .67701 L 0 1 0 r
F P
0 g
s
.45157 .67507 m .45747 .67636 L .45181 .67612 L 0 1 0 r
F
.45866 .68116 m .45854 .68111 L p .45747 .67636 L 0 0 1 r
F P
0 g
s
.45747 .67636 m .46696 .67508 L .45866 .68116 L 0 0 1 r
F
.45747 .67636 m .46694 .67843 L .45762 .67701 L 0 1 0 r
F
.45747 .67636 m .45762 .67701 L .45181 .67612 L F
.45854 .68111 m .44985 .67738 L p .45747 .67636 L 0 0 1 r
F P
0 g
s
.45158 .67507 m .45618 .67112 L .45747 .67636 L 0 1 0 r
F
.45658 .67061 m .46696 .67508 L p .45747 .67636 L 0 0 1 r
F P
0 g
s
.45157 .67506 m .45618 .67112 L .45158 .67507 L 0 1 0 r
F
.45618 .67112 m .45618 .67112 L .45158 .67507 L F
.45616 .67103 m .45658 .67061 L p .45747 .67636 L 0 0 1 r
F P
0 g
s
.45128 .67389 m .45616 .67103 L p .45157 .67507 L 0 1 0 r
F P
0 g
s
.45616 .67103 m .45657 .67079 L p .45618 .67112 L 0 1 0 r
F P
0 g
s
.45616 .67103 m .45618 .67112 L .45157 .67507 L 0 1 0 r
F
.45023 .66938 m .45126 .67381 L .44989 .6747 L F
.45663 .66598 m .45128 .67389 L p .45067 .67129 L 1 0 0 r
F P
0 g
s
.45616 .67103 m .44989 .6747 L p .45607 .67068 L 0 1 0 r
F P
0 g
s
.45066 .67131 m .45067 .67129 L .45128 .67389 L 1 0 0 r
F
.44989 .6747 m .43956 .66702 L p .45023 .66938 L 0 1 0 r
F P
0 g
s
.44499 .67217 m .45023 .66938 L .4458 .67564 L 1 0 0 r
F
.45023 .66938 m .45663 .66598 L .45067 .6713 L F
.45023 .66938 m .45067 .6713 L .4458 .67564 L F
.43956 .66702 m .4462 .66306 L .4493 .66536 L p 0 1 0 r
F P
0 g
s
.43956 .66702 m .4493 .66536 L .4493 .66537 L 0 1 0 r
F
.43956 .66702 m .4493 .66537 L .45023 .66938 L F
.45023 .66938 m .45607 .67068 L .45126 .67381 L F
.44987 .67597 m .44582 .67565 L p .45029 .67348 L 1 0 0 r
F P
0 g
s
.44582 .67565 m .4458 .67564 L p .45029 .67348 L 1 0 0 r
F P
0 g
s
.4458 .67564 m .45066 .67131 L .45029 .67348 L 1 0 0 r
F
.45128 .67389 m .44987 .67597 L p .45066 .67131 L F P
0 g
s
.44985 .67738 m .44582 .67565 L p .45607 .67068 L 0 0 1 r
F P
0 g
s
.44582 .67565 m .43945 .67292 L p .44499 .67217 L 0 0 1 r
F P
0 g
s
.44499 .67217 m .45607 .67068 L .44582 .67565 L 0 0 1 r
F
.44617 .6651 m .4493 .66536 L p .4445 .67011 L 1 0 0 r
F P
0 g
s
.44405 .66824 m .44617 .6651 L p .4445 .67011 L 1 0 0 r
F P
0 g
s
.4493 .66536 m .45663 .66598 L p .45024 .66937 L 1 0 0 r
F P
0 g
s
.45023 .66938 m .4493 .66536 L .45024 .66937 L 1 0 0 r
F
.44499 .67217 m .4493 .66536 L .45023 .66938 L F
.43945 .67292 m .44405 .66824 L p .44496 .67206 L 0 0 1 r
F P
0 g
s
.4445 .67011 m .4493 .66536 L .44499 .67217 L 1 0 0 r
F
.45607 .67068 m .456 .67036 L .45608 .67068 L 0 0 1 r
F
.45023 .66938 m .456 .67036 L .45607 .67068 L 0 1 0 r
F
.43945 .67292 m .44501 .67206 L .44504 .67216 L 0 0 1 r
F
.42643 .67524 m .41994 .67958 L .40968 .67261 L p 0 1 0 r
F P
0 g
s
.40968 .67261 m .41614 .668 L .42643 .67524 L p 0 1 0 r
F P
0 g
s
.43297 .67107 m .42643 .67524 L .41614 .668 L p 0 1 0 r
F P
0 g
s
.43945 .67292 m .43279 .67968 L .42236 .67522 L p 0 0 1 r
F P
0 g
s
.41614 .668 m .42265 .66361 L .43297 .67107 L p 0 1 0 r
F P
0 g
s
.43956 .66702 m .43297 .67107 L .42265 .66361 L p 0 1 0 r
F P
0 g
s
.42236 .67522 m .429 .66843 L .43945 .67292 L p 0 0 1 r
F P
0 g
s
.44617 .6651 m .44405 .66824 L p .4436 .66646 L 1 0 0 r
F P
0 g
s
.42265 .66361 m .4292 .65939 L .43956 .66702 L p 0 1 0 r
F P
0 g
s
.4462 .66306 m .43956 .66702 L .4292 .65939 L p 0 1 0 r
F P
0 g
s
.43945 .67292 m .429 .66843 L p .4436 .66646 L 0 0 1 r
F P
0 g
s
.44615 .66611 m .44401 .66828 L p .4436 .66646 L 0 0 1 r
F P
0 g
s
.44401 .66828 m .43945 .67292 L p .4436 .66646 L 0 0 1 r
F P
0 g
s
.44325 .66486 m .44617 .6651 L p .4436 .66646 L 1 0 0 r
F P
0 g
s
.4292 .65939 m .43581 .65531 L .4462 .66306 L p 0 1 0 r
F P
0 g
s
.4462 .66306 m .43581 .65531 L p .44749 .65792 L 0 1 0 r
F P
0 g
s
.44842 .66176 m .4462 .66306 L p .44749 .65792 L 0 1 0 r
F P
0 g
s
.4493 .66536 m .4462 .66306 L p .44889 .66366 L 0 1 0 r
F P
0 g
s
.47379 .6571 m .46702 .66692 L .45663 .66598 L p 1 0 0 r
F P
0 g
s
.45663 .66598 m .46341 .65599 L .47379 .6571 L p 1 0 0 r
F P
0 g
s
.46341 .65599 m .45663 .66598 L .44931 .66537 L p 1 0 0 r
F P
0 g
s
.44931 .66537 m .44617 .6651 L p .4489 .66366 L 1 0 0 r
F P
0 g
s
.4489 .66366 m .46341 .65599 L .44931 .66537 L 1 0 0 r
F
.45295 .65501 m .46341 .65599 L p .4489 .66366 L F P
0 g
s
.44889 .66365 m .4489 .66364 L .4489 .66366 L 0 1 0 r
F
.4462 .66306 m .44842 .66175 L p .44889 .66365 L F P
0 g
s
.44617 .6651 m .44842 .66175 L p .4489 .66366 L 1 0 0 r
F P
0 g
s
.44842 .66175 m .45295 .65501 L p .4489 .66366 L 1 0 0 r
F P
0 g
s
.4489 .66364 m .4489 .66364 L .4489 .66366 L 0 1 0 r
F
.4841 .65842 m .47733 .668 L .46702 .66692 L p 1 0 0 r
F P
0 g
s
.46702 .66692 m .47379 .6571 L .4841 .65842 L p 1 0 0 r
F P
0 g
s
.45658 .67061 m .46334 .66379 L .47374 .6683 L p 0 0 1 r
F P
0 g
s
.46334 .66379 m .45658 .67061 L .45612 .67041 L p 0 0 1 r
F P
0 g
s
.4493 .66537 m .456 .67036 L p .45023 .66938 L 0 1 0 r
F P
0 g
s
.456 .67036 m .4493 .66536 L p .45498 .66597 L 0 1 0 r
F P
0 g
s
.44889 .66366 m .45474 .66495 L .4493 .66536 L 0 1 0 r
F
.45612 .67041 m .456 .67036 L p .45474 .66495 L 0 0 1 r
F P
0 g
s
.45474 .66495 m .46334 .66379 L .45612 .67041 L 0 0 1 r
F
.45474 .66495 m .46331 .66685 L .45498 .66597 L 0 1 0 r
F
.45474 .66495 m .45498 .66597 L .4493 .66536 L F
.456 .67036 m .44615 .66611 L p .45474 .66495 L 0 0 1 r
F P
0 g
s
.4529 .65913 m .45336 .65947 L p .4489 .66366 L 0 1 0 r
F P
0 g
s
.4489 .66366 m .45336 .65947 L .45474 .66495 L 0 1 0 r
F
.4489 .66364 m .4529 .65913 L .4489 .66366 L F
.44842 .66175 m .4529 .65913 L p .44889 .66365 L F P
0 g
s
.4493 .66536 m .4493 .66537 L p .4493 .66537 L 0 1 0 r
F P
0 g
s
.44615 .66611 m .4529 .65927 L .45336 .65947 L p 0 0 1 r
F P
0 g
s
.45336 .65947 m .46334 .66379 L p .45464 .66497 L 0 0 1 r
F P
0 g
s
.44615 .66611 m .45336 .65947 L .45464 .66497 L 0 0 1 r
F
.48057 .66146 m .47374 .6683 L .46334 .66379 L p F P
0 g
s
.46334 .66379 m .47015 .65693 L .48057 .66146 L p 0 0 1 r
F P
0 g
s
.45336 .65947 m .4529 .65913 L p .4533 .65921 L 0 1 0 r
F P
0 g
s
.47015 .65693 m .46334 .66379 L .45337 .65947 L p 0 0 1 r
F P
0 g
s
.45337 .65947 m .4529 .65927 L p .4533 .65921 L 0 0 1 r
F P
0 g
s
.4533 .65921 m .47015 .65693 L .45337 .65947 L 0 0 1 r
F
.47021 .64606 m .46341 .65599 L .45295 .65501 L p 1 0 0 r
F P
0 g
s
.4529 .65913 m .45322 .65894 L p .4533 .65921 L 0 1 0 r
F P
0 g
s
.48059 .6474 m .47379 .6571 L .46341 .65599 L p 1 0 0 r
F P
0 g
s
.46341 .65599 m .47021 .64606 L .48059 .6474 L p 1 0 0 r
F P
0 g
s
.44923 .6439 m .45976 .64492 L p .44611 .65214 L 1 0 0 r
F P
0 g
s
.44561 .65021 m .44545 .64957 L .44561 .6502 L 0 1 0 r
F
.44247 .65132 m .44545 .64957 L p .44561 .65021 L F P
0 g
s
.44545 .64957 m .44923 .6439 L p .44611 .65214 L 1 0 0 r
F P
0 g
s
.45976 .64492 m .45295 .65501 L .44669 .65447 L p 1 0 0 r
F P
0 g
s
.44611 .65214 m .45976 .64492 L .44669 .65447 L 1 0 0 r
F
.44611 .65214 m .45061 .64843 L .45189 .65344 L 0 1 0 r
F
.44247 .65132 m .44564 .6502 L .44611 .65214 L F
.44564 .6502 m .45061 .64843 L .44611 .65214 L F
.45295 .65501 m .44842 .66175 L p .448 .66004 L 1 0 0 r
F P
0 g
s
.43581 .65531 m .44247 .65132 L .44667 .65447 L p 0 1 0 r
F P
0 g
s
.43581 .65531 m .44667 .65447 L .44749 .65792 L 0 1 0 r
F
.44665 .65446 m .44667 .65447 L p .44749 .65792 L 1 0 0 r
F P
0 g
s
.44667 .65447 m .45295 .65501 L p .44749 .65792 L 1 0 0 r
F P
0 g
s
.44842 .66175 m .44842 .66176 L p .44749 .65792 L 0 1 0 r
F P
0 g
s
.44224 .66071 m .45295 .65501 L .44325 .66486 L 1 0 0 r
F
.44667 .65447 m .4529 .65913 L p .44749 .65792 L 0 1 0 r
F P
0 g
s
.4529 .65913 m .44667 .65447 L p .45189 .65344 L 0 1 0 r
F P
0 g
s
.44667 .65447 m .44247 .65132 L p .44611 .65214 L 0 1 0 r
F P
0 g
s
.44669 .65447 m .44667 .65447 L p .44611 .65214 L 1 0 0 r
F P
0 g
s
.44611 .65214 m .45189 .65344 L .44667 .65447 L 0 1 0 r
F
.44667 .65447 m .44242 .6541 L p .44611 .65214 L 1 0 0 r
F P
0 g
s
.41883 .65188 m .4254 .64762 L .43581 .65531 L p 0 1 0 r
F P
0 g
s
.44247 .65132 m .43581 .65531 L .4254 .64762 L p 0 1 0 r
F P
0 g
s
.4254 .64762 m .43202 .64351 L .44247 .65132 L p 0 1 0 r
F P
0 g
s
.44247 .65132 m .43202 .64351 L p .44464 .64635 L 0 1 0 r
F P
0 g
s
.44923 .6439 m .44545 .64957 L p .44464 .64635 L 1 0 0 r
F P
0 g
s
.44918 .64737 m .44545 .64957 L p .44464 .64635 L 0 1 0 r
F P
0 g
s
.44545 .64957 m .44247 .65132 L p .44464 .64635 L 0 1 0 r
F P
0 g
s
.44463 .64635 m .44464 .64635 L .44545 .64957 L 1 0 0 r
F
.4123 .65632 m .41883 .65188 L .4292 .65939 L p 0 1 0 r
F P
0 g
s
.43581 .65531 m .4292 .65939 L .41883 .65188 L p 0 1 0 r
F P
0 g
s
.43202 .64351 m .4387 .63949 L .44393 .64342 L p 0 1 0 r
F P
0 g
s
.44393 .64342 m .44923 .6439 L p .44466 .64634 L 1 0 0 r
F P
0 g
s
.44464 .64635 m .44393 .64342 L .44466 .64634 L 1 0 0 r
F
.46659 .63487 m .45976 .64492 L .44923 .6439 L p F P
0 g
s
.44923 .6439 m .45607 .6337 L .46659 .63487 L p 1 0 0 r
F P
0 g
s
.44393 .64342 m .4387 .63949 L p .44321 .64051 L 0 1 0 r
F P
0 g
s
.45607 .6337 m .44923 .6439 L .44393 .64342 L p 1 0 0 r
F P
0 g
s
.44321 .64051 m .44321 .64051 L .44393 .64342 L 0 1 0 r
F
.44393 .64342 m .43863 .64294 L p .44321 .64051 L 1 0 0 r
F P
0 g
s
.44321 .64051 m .45607 .6337 L .44395 .64341 L 1 0 0 r
F
.45295 .65501 m .45976 .64492 L .47021 .64606 L p F P
0 g
s
.47704 .63624 m .47021 .64606 L .45976 .64492 L p 1 0 0 r
F P
0 g
s
.45976 .64492 m .46659 .63487 L .47704 .63624 L p 1 0 0 r
F P
0 g
s
.45599 .64085 m .46651 .64545 L p .45046 .64763 L 0 0 1 r
F P
0 g
s
.45968 .65238 m .47015 .65693 L p .45337 .6592 L 0 0 1 r
F P
0 g
s
.45336 .65914 m .45968 .65238 L .45337 .6592 L 0 0 1 r
F
.45322 .65894 m .45968 .65238 L p .45329 .65921 L F P
0 g
s
.45322 .65894 m .4529 .65913 L p .45189 .65344 L 0 1 0 r
F P
0 g
s
.4529 .65913 m .44842 .66175 L p .44749 .65792 L 0 1 0 r
F P
0 g
s
.44242 .6541 m .44665 .65446 L p .44224 .66071 L 1 0 0 r
F P
0 g
s
.44224 .66071 m .44665 .65446 L .44749 .65792 L 1 0 0 r
F
.45968 .65238 m .4529 .65927 L .44241 .65472 L p 0 0 1 r
F P
0 g
s
.47699 .65003 m .47015 .65693 L .45968 .65238 L p 0 0 1 r
F P
0 g
s
.44242 .6541 m .44545 .64957 L p .44611 .65214 L 1 0 0 r
F P
0 g
s
.44918 .64737 m .45061 .64843 L p .44561 .6502 L 0 1 0 r
F P
0 g
s
.44241 .65472 m .44918 .64781 L .45968 .65238 L p 0 0 1 r
F P
0 g
s
.45968 .65238 m .46651 .64545 L .47699 .65003 L p 0 0 1 r
F P
0 g
s
.45061 .64843 m .44918 .64737 L p .45042 .64764 L 0 1 0 r
F P
0 g
s
.46651 .64545 m .45968 .65238 L .45065 .64845 L p 0 0 1 r
F P
0 g
s
.45065 .64845 m .44918 .64781 L p .45042 .64764 L 0 0 1 r
F P
0 g
s
.45042 .64764 m .46651 .64545 L .45065 .64845 L 0 0 1 r
F
.45022 .64674 m .45599 .64085 L p .45046 .64763 L F P
0 g
s
.45596 .64341 m .46647 .65117 L p .45042 .64764 L 0 1 0 r
F P
0 g
s
.44918 .64737 m .45017 .64679 L p .45042 .64764 L 0 1 0 r
F P
0 g
s
.45042 .64764 m .45022 .64674 L .45046 .64763 L 0 0 1 r
F
.4502 .64676 m .45022 .64674 L p .45042 .64764 L F P
0 g
s
.45017 .64679 m .45596 .64341 L p .45042 .64764 L 0 1 0 r
F P
0 g
s
.46647 .65117 m .45966 .65518 L .45061 .64843 L p 0 1 0 r
F P
0 g
s
.45042 .64764 m .46647 .65117 L .45061 .64843 L 0 1 0 r
F
.44918 .64781 m .4502 .64676 L p .45042 .64764 L 0 0 1 r
F P
0 g
s
.44548 .63265 m .45607 .6337 L p .44321 .64051 L 1 0 0 r
F P
0 g
s
.4432 .64051 m .44237 .63732 L .44321 .64051 L 0 1 0 r
F
.4387 .63949 m .44237 .63732 L p .4432 .64051 L F P
0 g
s
.41497 .64005 m .42156 .63576 L .43202 .64351 L p 0 1 0 r
F P
0 g
s
.4387 .63949 m .43202 .64351 L .42156 .63576 L p 0 1 0 r
F P
0 g
s
.42156 .63576 m .4282 .63161 L .4387 .63949 L p 0 1 0 r
F P
0 g
s
.4387 .63949 m .4282 .63161 L p .44168 .63466 L 0 1 0 r
F P
0 g
s
.44548 .63265 m .44237 .63732 L p .44168 .63466 L 1 0 0 r
F P
0 g
s
.44237 .63732 m .44548 .63265 L p .44321 .64051 L 1 0 0 r
F P
0 g
s
.44543 .63552 m .44237 .63732 L p .44168 .63466 L 0 1 0 r
F P
0 g
s
.44237 .63732 m .4387 .63949 L p .44168 .63466 L 0 1 0 r
F P
0 g
s
.44167 .63467 m .44168 .63466 L .44237 .63732 L 1 0 0 r
F
.43202 .64351 m .44393 .64342 L .44464 .64635 L 0 1 0 r
F
.40843 .64454 m .41497 .64005 L .4254 .64762 L p F P
0 g
s
.43202 .64351 m .4254 .64762 L .41497 .64005 L p 0 1 0 r
F P
0 g
s
.4213 .64558 m .42803 .63861 L .43778 .64285 L p 0 0 1 r
F P
0 g
s
.4282 .63161 m .43489 .62756 L .44107 .63223 L p 0 1 0 r
F P
0 g
s
.44107 .63223 m .44548 .63265 L p .4417 .63465 L 1 0 0 r
F P
0 g
s
.44168 .63466 m .44107 .63223 L .4417 .63465 L 1 0 0 r
F
.46293 .62355 m .45607 .6337 L .44548 .63265 L p F P
0 g
s
.44548 .63265 m .45235 .62234 L .46293 .62355 L p 1 0 0 r
F P
0 g
s
.44107 .63223 m .43489 .62756 L p .44019 .62878 L 0 1 0 r
F P
0 g
s
.45235 .62234 m .44548 .63265 L .44107 .63223 L p 1 0 0 r
F P
0 g
s
.44019 .62878 m .44019 .62878 L .44107 .63223 L 0 1 0 r
F
.4282 .63161 m .44107 .63223 L .44168 .63466 L F
.42803 .63861 m .43481 .63159 L .43493 .63164 L p 0 0 1 r
F P
0 g
s
.44107 .63223 m .44543 .63552 L p .44168 .63466 L 0 1 0 r
F P
0 g
s
.43493 .63164 m .44107 .63223 L p .43641 .63746 L 1 0 0 r
F P
0 g
s
.43641 .63746 m .44107 .63223 L .44168 .63466 L 1 0 0 r
F
.43863 .64294 m .43781 .64286 L p .44167 .63467 L F P
0 g
s
.43641 .63746 m .44167 .63467 L .43781 .64286 L 1 0 0 r
F
.44237 .63732 m .43863 .64294 L p .44167 .63467 L F P
0 g
s
.44543 .63552 m .44773 .63724 L p .44321 .64051 L 0 1 0 r
F P
0 g
s
.4424 .63731 m .44543 .63552 L p .44321 .64051 L 0 1 0 r
F P
0 g
s
.43493 .63164 m .44542 .63623 L p .4364 .63746 L 0 0 1 r
F P
0 g
s
.42803 .63861 m .43493 .63164 L .4364 .63746 L 0 0 1 r
F
.44107 .63223 m .43493 .63164 L p .44019 .62878 L 1 0 0 r
F P
0 g
s
.43491 .63158 m .44019 .62878 L .43493 .63164 L 1 0 0 r
F
.44019 .62878 m .45235 .62234 L .44109 .63222 L F
.44019 .62878 m .44109 .63222 L .44107 .63223 L F
.45225 .6292 m .44705 .63455 L p .44585 .63007 L 0 0 1 r
F P
0 g
s
.44019 .62878 m .44585 .63007 L .44107 .63223 L 0 1 0 r
F
.44705 .63455 m .44701 .63459 L p .44585 .63007 L 0 0 1 r
F P
0 g
s
.47345 .62493 m .46659 .63487 L .45607 .6337 L p 1 0 0 r
F P
0 g
s
.45607 .6337 m .46293 .62355 L .47345 .62493 L p 1 0 0 r
F P
0 g
s
.44321 .64051 m .44395 .64341 L .44393 .64342 L 1 0 0 r
F
.44321 .64051 m .44893 .64181 L .44393 .64342 L 0 1 0 r
F
.44893 .64181 m .44933 .64341 L .44393 .64342 L F
.45599 .64085 m .45017 .64679 L p .44893 .64181 L 0 0 1 r
F P
0 g
s
.45596 .64341 m .44918 .64737 L .44393 .64342 L p 0 1 0 r
F P
0 g
s
.44393 .64342 m .44918 .64737 L p .44464 .64635 L 0 1 0 r
F P
0 g
s
.43863 .64294 m .44393 .64342 L p .43938 .64914 L 1 0 0 r
F P
0 g
s
.43938 .64914 m .44393 .64342 L .44464 .64635 L 1 0 0 r
F
.43805 .64381 m .43863 .64294 L p .43938 .64914 L F P
0 g
s
.44545 .64957 m .44918 .64737 L p .44561 .6502 L 0 1 0 r
F P
0 g
s
.44918 .64781 m .43863 .64322 L p .44893 .64181 L 0 0 1 r
F P
0 g
s
.45017 .64679 m .44918 .64781 L p .44893 .64181 L 0 0 1 r
F P
0 g
s
.44893 .64181 m .45596 .64341 L .44933 .64341 L 0 1 0 r
F
.47339 .63847 m .46651 .64545 L .45599 .64085 L p 0 0 1 r
F P
0 g
s
.43863 .64294 m .44237 .63732 L p .44321 .64051 L 1 0 0 r
F P
0 g
s
.44237 .63732 m .4424 .63731 L p .44321 .64051 L 0 1 0 r
F P
0 g
s
.44321 .64051 m .44773 .63724 L .44893 .64181 L 0 1 0 r
F
.43863 .64322 m .44542 .63623 L .45599 .64085 L p 0 0 1 r
F P
0 g
s
.45599 .64085 m .46284 .63384 L .47339 .63847 L p 0 0 1 r
F P
0 g
s
.44773 .63724 m .44543 .63552 L p .44741 .63596 L 0 1 0 r
F P
0 g
s
.46284 .63384 m .45599 .64085 L .44779 .63726 L p 0 0 1 r
F P
0 g
s
.44779 .63726 m .44542 .63623 L p .44741 .63596 L 0 0 1 r
F P
0 g
s
.44741 .63596 m .46284 .63384 L .44779 .63726 L 0 0 1 r
F
.45225 .6292 m .46284 .63384 L p .44741 .63596 L F P
0 g
s
.45222 .63154 m .46279 .63938 L p .44741 .63596 L 0 1 0 r
F P
0 g
s
.44543 .63552 m .44701 .63459 L p .44741 .63596 L 0 1 0 r
F P
0 g
s
.4474 .63592 m .45225 .6292 L .44741 .63596 L 0 0 1 r
F
.44701 .63459 m .45225 .6292 L p .44737 .63596 L F P
0 g
s
.44701 .63459 m .45222 .63154 L p .44741 .63596 L 0 1 0 r
F P
0 g
s
.46279 .63938 m .45596 .64341 L .44773 .63724 L p 0 1 0 r
F P
0 g
s
.44741 .63596 m .46279 .63938 L .44773 .63724 L 0 1 0 r
F
.44737 .63596 m .4474 .63592 L .44741 .63596 L 0 0 1 r
F
.44542 .63623 m .44701 .63459 L p .44737 .63596 L F P
0 g
s
.44543 .63552 m .44107 .63223 L p .44632 .6319 L 0 1 0 r
F P
0 g
s
.45222 .63154 m .44701 .63459 L p .44632 .6319 L 0 1 0 r
F P
0 g
s
.44701 .63459 m .44543 .63552 L p .44632 .6319 L 0 1 0 r
F P
0 g
s
.44585 .63007 m .45222 .63154 L .44632 .6319 L 0 1 0 r
F
.44585 .63007 m .44632 .6319 L .44107 .63223 L F
.44701 .63459 m .44542 .63623 L p .44585 .63007 L 0 0 1 r
F P
0 g
s
.43489 .62756 m .43918 .62502 L p .44018 .62878 L 0 1 0 r
F P
0 g
s
.41107 .62813 m .41768 .62379 L .4282 .63161 L p 0 1 0 r
F P
0 g
s
.43489 .62756 m .4282 .63161 L .41768 .62379 L p 0 1 0 r
F P
0 g
s
.41768 .62379 m .42433 .61961 L .43489 .62756 L p 0 1 0 r
F P
0 g
s
.42156 .63576 m .41497 .64005 L .40452 .63267 L p 0 1 0 r
F P
0 g
s
.40452 .63267 m .41107 .62813 L .42156 .63576 L p 0 1 0 r
F P
0 g
s
.4282 .63161 m .42156 .63576 L .41107 .62813 L p 0 1 0 r
F P
0 g
s
.43481 .63159 m .42803 .63861 L .4174 .63398 L p 0 0 1 r
F P
0 g
s
.43489 .62756 m .42433 .61961 L p .4386 .62287 L 0 1 0 r
F P
0 g
s
.44168 .62124 m .43918 .62502 L p .4386 .62287 L 1 0 0 r
F P
0 g
s
.44168 .62124 m .45235 .62234 L p .44019 .62878 L 1 0 0 r
F P
0 g
s
.43919 .62505 m .44168 .62124 L .44019 .62878 L 1 0 0 r
F
.44018 .62878 m .43918 .62502 L .44019 .62878 L 0 1 0 r
F
.43489 .6315 m .43916 .62505 L p .43491 .63158 L 1 0 0 r
F P
0 g
s
.43916 .62505 m .44168 .62124 L p .43917 .62507 L 1 0 0 r
F P
0 g
s
.43916 .62505 m .43917 .62507 L .43491 .63158 L 1 0 0 r
F
.42433 .61961 m .43104 .61554 L .43808 .62087 L p 0 1 0 r
F P
0 g
s
.43808 .62087 m .4381 .62088 L p .4386 .62287 L 0 1 0 r
F P
0 g
s
.42433 .61961 m .43808 .62087 L .4386 .62287 L 0 1 0 r
F
.4174 .63398 m .42415 .62693 L .43481 .63159 L p 0 0 1 r
F P
0 g
s
.43481 .63159 m .42415 .62693 L p .43333 .62567 L 0 0 1 r
F P
0 g
s
.44164 .62356 m .43918 .62502 L p .4386 .62287 L 0 1 0 r
F P
0 g
s
.43918 .62502 m .43489 .62756 L p .4386 .62287 L 0 1 0 r
F P
0 g
s
.4386 .62287 m .4386 .62287 L .43918 .62502 L 1 0 0 r
F
.43481 .63163 m .42406 .63059 L p .43333 .62567 L F P
0 g
s
.43333 .62567 m .4386 .62287 L .43488 .63146 L 1 0 0 r
F
.43489 .6315 m .43486 .63154 L p .43333 .62567 L 0 0 1 r
F P
0 g
s
.43486 .63154 m .43481 .63159 L p .43333 .62567 L 0 0 1 r
F P
0 g
s
.43333 .62567 m .43488 .63146 L .43481 .63163 L 1 0 0 r
F
.43918 .62502 m .43489 .6315 L p .4386 .62287 L F P
0 g
s
.43489 .6315 m .43481 .63163 L p .43488 .63146 L 1 0 0 r
F P
0 g
s
.4386 .62287 m .43489 .6315 L .43488 .63146 L 1 0 0 r
F
.43918 .62502 m .43921 .625 L p .44019 .62878 L 0 1 0 r
F P
0 g
s
.43491 .63158 m .43919 .62505 L .44019 .62878 L 1 0 0 r
F
.44164 .62356 m .44473 .62589 L p .44019 .62878 L 0 1 0 r
F P
0 g
s
.44019 .62878 m .44473 .62589 L .44585 .63007 L 0 1 0 r
F
.43921 .625 m .44164 .62356 L p .44019 .62878 L F P
0 g
s
.44473 .62589 m .45225 .6292 L p .44581 .63008 L 0 0 1 r
F P
0 g
s
.46974 .62679 m .46284 .63384 L .45225 .6292 L p 0 0 1 r
F P
0 g
s
.46982 .61349 m .46293 .62355 L .45235 .62234 L p 1 0 0 r
F P
0 g
s
.45225 .6292 m .45913 .62212 L .46974 .62679 L p 0 0 1 r
F P
0 g
s
.44473 .62589 m .44164 .62356 L p .44428 .62416 L 0 1 0 r
F P
0 g
s
.45913 .62212 m .45225 .6292 L .4448 .62592 L p 0 0 1 r
F P
0 g
s
.4448 .62592 m .44162 .62453 L p .44428 .62416 L 0 0 1 r
F P
0 g
s
.44428 .62416 m .45913 .62212 L .4448 .62592 L 0 0 1 r
F
.45924 .61207 m .45235 .62234 L .44168 .62124 L p 1 0 0 r
F P
0 g
s
.44164 .62356 m .44374 .62233 L p .44428 .62416 L 0 1 0 r
F P
0 g
s
.45235 .62234 m .45924 .61207 L .46982 .61349 L p 1 0 0 r
F P
0 g
s
.44168 .62124 m .44858 .61082 L .45924 .61207 L p 1 0 0 r
F P
0 g
s
.43104 .61554 m .42043 .60752 L p .43541 .61096 L 0 1 0 r
F P
0 g
s
.43784 .60968 m .44858 .61082 L p .43706 .61693 L 1 0 0 r
F P
0 g
s
.43706 .61692 m .43784 .60968 L .43706 .61693 L 1 0 0 r
F
.43588 .61266 m .43784 .60968 L p .43706 .61693 L F P
0 g
s
.43541 .61096 m .43552 .61135 L .43104 .61554 L 0 1 0 r
F
.43588 .61266 m .43587 .61267 L p .43552 .61135 L F P
0 g
s
.43587 .61267 m .43104 .61554 L p .43552 .61135 L 0 1 0 r
F P
0 g
s
.42433 .61961 m .41768 .62379 L .40714 .61611 L p 0 1 0 r
F P
0 g
s
.40714 .61611 m .41375 .61173 L .42433 .61961 L p 0 1 0 r
F P
0 g
s
.43104 .61554 m .42433 .61961 L .41375 .61173 L p 0 1 0 r
F P
0 g
s
.41375 .61173 m .42043 .60752 L .43104 .61554 L p 0 1 0 r
F P
0 g
s
.40056 .6207 m .40714 .61611 L .41768 .62379 L p 0 1 0 r
F P
0 g
s
.41345 .62226 m .42022 .61513 L .43095 .61984 L p 0 0 1 r
F P
0 g
s
.42043 .60752 m .42715 .60341 L .435 .60938 L p 0 1 0 r
F P
0 g
s
.435 .60938 m .43784 .60968 L p .43543 .61096 L 1 0 0 r
F P
0 g
s
.43541 .61097 m .435 .60938 L .43543 .61096 L 1 0 0 r
F
.43784 .60968 m .43588 .61266 L p .43541 .61097 L F P
0 g
s
.4555 .60044 m .44858 .61082 L .43784 .60968 L p 1 0 0 r
F P
0 g
s
.43784 .60968 m .44477 .59915 L .4555 .60044 L p 1 0 0 r
F P
0 g
s
.44477 .59915 m .43784 .60968 L .43501 .60938 L p 1 0 0 r
F P
0 g
s
.43501 .60937 m .44477 .59915 L .43501 .60938 L 1 0 0 r
F
.4338 .60497 m .44477 .59915 L .435 .60938 L F
.46615 .6019 m .45924 .61207 L .44858 .61082 L p F P
0 g
s
.44858 .61082 m .44168 .62124 L .43812 .62088 L p 1 0 0 r
F P
0 g
s
.4381 .62088 m .44168 .62124 L p .4386 .62287 L 1 0 0 r
F P
0 g
s
.44164 .62356 m .4381 .62088 L p .44265 .61823 L 0 1 0 r
F P
0 g
s
.4381 .62088 m .43104 .61554 L p .43706 .61693 L 0 1 0 r
F P
0 g
s
.43812 .62088 m .4381 .62088 L p .43706 .61693 L 1 0 0 r
F P
0 g
s
.43706 .61693 m .44858 .61082 L .43812 .62088 L 1 0 0 r
F
.43706 .61693 m .44265 .61823 L .4381 .62088 L 0 1 0 r
F
.42415 .62693 m .43095 .61984 L .43192 .62027 L p 0 0 1 r
F P
0 g
s
.43192 .62027 m .4381 .62088 L p .433 .62441 L 1 0 0 r
F P
0 g
s
.4386 .62287 m .4381 .62088 L .4386 .62287 L 0 1 0 r
F
.43333 .62567 m .4381 .62088 L .4386 .62287 L 1 0 0 r
F
.42415 .62693 m .43192 .62027 L .43333 .62567 L 0 0 1 r
F
.42406 .63059 m .433 .62441 L .43333 .62567 L 1 0 0 r
F
.433 .62441 m .4381 .62088 L .43333 .62567 L F
.43333 .62567 m .43192 .62027 L .43333 .62567 L 0 0 1 r
F
.43192 .62027 m .44162 .62453 L p .43333 .62567 L F P
0 g
s
.4381 .62088 m .43192 .62027 L p .43706 .61693 L 1 0 0 r
F P
0 g
s
.43178 .61973 m .43706 .61693 L .43192 .62027 L 1 0 0 r
F
.44374 .62233 m .44164 .62356 L p .44265 .61823 L 0 1 0 r
F P
0 g
s
.4381 .62088 m .44164 .62356 L p .4386 .62287 L 0 1 0 r
F P
0 g
s
.44848 .61742 m .44162 .62453 L .43193 .62027 L p 0 0 1 r
F P
0 g
s
.43193 .62027 m .43095 .61984 L p .43178 .61973 L 0 0 1 r
F P
0 g
s
.43178 .61973 m .44848 .61742 L .43193 .62027 L 0 0 1 r
F
.41768 .62379 m .41107 .62813 L .40056 .6207 L p 0 1 0 r
F P
0 g
s
.43095 .61984 m .42415 .62693 L .41345 .62226 L p 0 0 1 r
F P
0 g
s
.43104 .61554 m .43652 .61494 L .43706 .61693 L 0 1 0 r
F
.43104 .61554 m .43588 .61266 L p .43651 .61494 L F P
0 g
s
.43013 .61376 m .43541 .61097 L .43155 .6189 L 1 0 0 r
F
.43095 .61984 m .42022 .61513 L p .43013 .61376 L 0 0 1 r
F P
0 g
s
.43541 .61096 m .43541 .61097 L .43588 .61266 L 0 1 0 r
F
.43588 .61266 m .43162 .61914 L p .43541 .61097 L 1 0 0 r
F P
0 g
s
.43706 .61693 m .4416 .61438 L .44265 .61823 L 0 1 0 r
F
.43706 .61693 m .43706 .61692 L .43706 .61693 L 1 0 0 r
F
.43652 .61494 m .4416 .61438 L .43706 .61693 L 0 1 0 r
F
.43178 .61973 m .43588 .61266 L .43706 .61693 L 1 0 0 r
F
.43781 .61152 m .4416 .61438 L p .43651 .61494 L 0 1 0 r
F P
0 g
s
.43588 .61266 m .43781 .61152 L p .43651 .61494 L 0 1 0 r
F P
0 g
s
.4416 .61438 m .44848 .61742 L p .44262 .61823 L 0 0 1 r
F P
0 g
s
.44848 .61742 m .45913 .62212 L p .44427 .62416 L 0 0 1 r
F P
0 g
s
.44426 .62412 m .44848 .61742 L .44427 .62416 L 0 0 1 r
F
.44374 .62233 m .44848 .61742 L p .44423 .62417 L F P
0 g
s
.46605 .61499 m .45913 .62212 L .44848 .61742 L p 0 0 1 r
F P
0 g
s
.47673 .60359 m .46982 .61349 L .45924 .61207 L p 1 0 0 r
F P
0 g
s
.45924 .61207 m .46615 .6019 L .47673 .60359 L p 1 0 0 r
F P
0 g
s
.44848 .61742 m .45538 .61027 L .46605 .61499 L p 0 0 1 r
F P
0 g
s
.4416 .61438 m .43781 .61152 L p .44103 .61225 L 0 1 0 r
F P
0 g
s
.45538 .61027 m .44848 .61742 L .44168 .61442 L p 0 0 1 r
F P
0 g
s
.44168 .61442 m .43778 .6127 L p .44103 .61225 L 0 0 1 r
F P
0 g
s
.44103 .61225 m .45538 .61027 L .44168 .61442 L 0 0 1 r
F
.44858 .61082 m .4555 .60044 L .46615 .6019 L p 1 0 0 r
F P
0 g
s
.44467 .60552 m .45538 .61027 L p .44101 .61226 L 0 0 1 r
F P
0 g
s
.44464 .6075 m .45532 .61552 L p .44103 .61225 L 0 1 0 r
F P
0 g
s
.43781 .61152 m .44036 .61002 L p .44103 .61225 L 0 1 0 r
F P
0 g
s
.44037 .61 m .44467 .60552 L p .44101 .61226 L 0 0 1 r
F P
0 g
s
.44036 .61002 m .44464 .6075 L p .44103 .61225 L 0 1 0 r
F P
0 g
s
.45532 .61552 m .44845 .61957 L .4416 .61438 L p 0 1 0 r
F P
0 g
s
.44103 .61225 m .45532 .61552 L .4416 .61438 L 0 1 0 r
F
.43778 .6127 m .4416 .61438 L p .43178 .61973 L 0 0 1 r
F P
0 g
s
.43178 .61973 m .4416 .61438 L .44262 .61823 L 0 0 1 r
F
.43095 .61984 m .43162 .61914 L p .43178 .61973 L F P
0 g
s
.43162 .61914 m .43588 .61266 L p .43178 .61973 L 1 0 0 r
F P
0 g
s
.43162 .61914 m .43778 .6127 L p .43178 .61973 L 0 0 1 r
F P
0 g
s
.43094 .62017 m .43162 .61914 L p .43178 .61973 L 1 0 0 r
F P
0 g
s
.43162 .61914 m .43094 .62017 L p .43155 .6189 L 1 0 0 r
F P
0 g
s
.43541 .61097 m .43162 .61914 L .43155 .6189 L 1 0 0 r
F
.43778 .6127 m .43162 .61914 L p .43013 .61376 L 0 0 1 r
F P
0 g
s
.43162 .61914 m .43158 .61918 L p .43013 .61376 L 0 0 1 r
F P
0 g
s
.43158 .61918 m .43095 .61984 L p .43013 .61376 L 0 0 1 r
F P
0 g
s
.42043 .60752 m .435 .60938 L .43541 .61097 L 0 1 0 r
F
.4288 .60874 m .43498 .60938 L p .42986 .61272 L 1 0 0 r
F P
0 g
s
.42022 .61513 m .42704 .60797 L .4288 .60874 L p 0 0 1 r
F P
0 g
s
.43013 .61376 m .43498 .60938 L .43541 .61097 L 1 0 0 r
F
.42022 .61513 m .4288 .60874 L .43013 .61376 L 0 0 1 r
F
.42012 .61907 m .42986 .61272 L .43013 .61376 L 1 0 0 r
F
.42986 .61272 m .43498 .60938 L .43013 .61376 L F
.43013 .61376 m .4288 .60874 L .43014 .61376 L 0 0 1 r
F
.43781 .61152 m .43588 .61266 L p .43541 .61097 L 0 1 0 r
F P
0 g
s
.4288 .60874 m .43778 .6127 L p .43014 .61376 L 0 0 1 r
F P
0 g
s
.435 .60938 m .42715 .60341 L p .4338 .60497 L 0 1 0 r
F P
0 g
s
.435 .60938 m .4288 .60874 L p .4338 .60497 L 1 0 0 r
F P
0 g
s
.42853 .60776 m .4338 .60497 L .4288 .60874 L 1 0 0 r
F
.43501 .60938 m .435 .60938 L p .43501 .60937 L F P
0 g
s
.4338 .60497 m .43381 .60497 L .435 .60938 L 0 1 0 r
F
.43781 .61152 m .435 .60938 L p .43992 .60842 L F P
0 g
s
.44036 .61002 m .43781 .61152 L p .43992 .60842 L 0 1 0 r
F P
0 g
s
.44467 .60552 m .44036 .61002 L p .43933 .60626 L 0 0 1 r
F P
0 g
s
.43381 .60497 m .43933 .60626 L .435 .60938 L 0 1 0 r
F
.43933 .60626 m .44464 .6075 L .43992 .60842 L F
.43933 .60626 m .43992 .60842 L .435 .60938 L F
.42715 .60341 m .43247 .60024 L p .4338 .60497 L F P
0 g
s
.42841 .60733 m .42824 .60671 L .42841 .60733 L 0 0 1 r
F
.42704 .60797 m .42824 .60671 L p .42841 .60733 L F P
0 g
s
.42043 .60752 m .41375 .61173 L .40316 .60399 L p 0 1 0 r
F P
0 g
s
.40316 .60399 m .40979 .59957 L .42043 .60752 L p 0 1 0 r
F P
0 g
s
.42715 .60341 m .42043 .60752 L .40979 .59957 L p 0 1 0 r
F P
0 g
s
.40979 .59957 m .41648 .59532 L .42715 .60341 L p 0 1 0 r
F P
0 g
s
.41375 .61173 m .40714 .61611 L .39657 .60862 L p 0 1 0 r
F P
0 g
s
.39657 .60862 m .40316 .60399 L .41375 .61173 L p 0 1 0 r
F P
0 g
s
.42704 .60797 m .42022 .61513 L .40946 .61041 L p 0 0 1 r
F P
0 g
s
.42715 .60341 m .41648 .59532 L p .4321 .59894 L 0 1 0 r
F P
0 g
s
.4321 .59894 m .4321 .59894 L .4321 .59895 L 1 0 0 r
F
.43396 .59796 m .43247 .60024 L p .4321 .59894 L F P
0 g
s
.43255 .60052 m .43396 .59796 L .4338 .60497 L 1 0 0 r
F
.4338 .60497 m .43247 .60024 L .4338 .60497 L 0 1 0 r
F
.42824 .60671 m .43246 .60026 L p .42853 .60776 L 1 0 0 r
F P
0 g
s
.43246 .60026 m .43396 .59796 L p .43253 .60054 L 1 0 0 r
F P
0 g
s
.43246 .60026 m .43253 .60054 L .42853 .60776 L 1 0 0 r
F
.41648 .59532 m .42322 .59119 L .43177 .59771 L p 0 1 0 r
F P
0 g
s
.41648 .59532 m .43177 .59771 L .4321 .59894 L 0 1 0 r
F
.40946 .61041 m .41626 .60321 L .42704 .60797 L p 0 0 1 r
F P
0 g
s
.42704 .60797 m .41626 .60321 L p .42682 .60174 L 0 0 1 r
F P
0 g
s
.43247 .60024 m .42715 .60341 L p .4321 .59894 L 0 1 0 r
F P
0 g
s
.42682 .60174 m .4321 .59894 L .42815 .60642 L 1 0 0 r
F
.4321 .59894 m .4321 .59895 L .42815 .60642 L F
.43247 .60024 m .42824 .60671 L p .4321 .59894 L F P
0 g
s
.42824 .60671 m .42819 .60676 L p .42682 .60174 L 0 0 1 r
F P
0 g
s
.42819 .60676 m .42704 .60797 L p .42682 .60174 L 0 0 1 r
F P
0 g
s
.43247 .60024 m .4325 .60022 L p .4338 .60497 L 0 1 0 r
F P
0 g
s
.43396 .59796 m .44477 .59915 L p .4338 .60497 L 1 0 0 r
F P
0 g
s
.42853 .60776 m .43255 .60052 L .4338 .60497 L 1 0 0 r
F
.43394 .59937 m .43834 .60271 L p .4338 .60497 L 0 1 0 r
F P
0 g
s
.4338 .60497 m .43834 .60271 L .43933 .60626 L 0 1 0 r
F
.4325 .60022 m .43394 .59937 L p .4338 .60497 L F P
0 g
s
.42704 .60797 m .43834 .60273 L .43933 .60626 L 0 0 1 r
F
.43834 .60273 m .43836 .60272 L .43933 .60626 L F
.435 .60938 m .43781 .61152 L p .43541 .61097 L 0 1 0 r
F P
0 g
s
.43498 .60938 m .435 .60938 L p .43541 .61097 L 1 0 0 r
F P
0 g
s
.43778 .6127 m .42704 .60797 L p .43933 .60626 L 0 0 1 r
F P
0 g
s
.42824 .60671 m .42703 .60856 L p .42815 .60642 L 1 0 0 r
F P
0 g
s
.4321 .59894 m .42824 .60671 L .42815 .60642 L 1 0 0 r
F
.43391 .60075 m .42824 .60671 L p .42682 .60174 L 0 0 1 r
F P
0 g
s
.42555 .59705 m .43178 .59772 L p .4266 .60092 L 1 0 0 r
F P
0 g
s
.41626 .60321 m .4231 .59596 L .42555 .59705 L p 0 0 1 r
F P
0 g
s
.43177 .59771 m .43178 .59772 L p .4321 .59894 L 0 1 0 r
F P
0 g
s
.4321 .59894 m .43178 .59772 L .4321 .59894 L 0 1 0 r
F
.42682 .60174 m .43178 .59772 L .4321 .59894 L 1 0 0 r
F
.4266 .60092 m .43178 .59772 L .42682 .60174 L F
.43394 .59937 m .43247 .60024 L p .4321 .59894 L 0 1 0 r
F P
0 g
s
.42555 .59705 m .43391 .60075 L p .42682 .60174 L 0 0 1 r
F P
0 g
s
.41626 .60321 m .42555 .59705 L .42682 .60174 L 0 0 1 r
F
.41614 .6074 m .4266 .60092 L .42682 .60174 L 1 0 0 r
F
.41614 .6074 m .42308 .59678 L .42555 .59705 L p F P
0 g
s
.41614 .6074 m .42555 .59705 L .4266 .60092 L 1 0 0 r
F
.43178 .59772 m .43396 .59796 L p .43211 .59894 L F P
0 g
s
.45173 .58867 m .44477 .59915 L .43396 .59796 L p 1 0 0 r
F P
0 g
s
.43396 .59796 m .44093 .58733 L .45173 .58867 L p 1 0 0 r
F P
0 g
s
.44093 .58733 m .43396 .59796 L .43179 .59772 L p 1 0 0 r
F P
0 g
s
.43178 .59771 m .44093 .58733 L .43179 .59772 L 1 0 0 r
F
.43043 .59289 m .44093 .58733 L .43178 .59772 L F
.46245 .59016 m .4555 .60044 L .44477 .59915 L p F P
0 g
s
.44477 .59915 m .45173 .58867 L .46245 .59016 L p 1 0 0 r
F P
0 g
s
.43391 .60075 m .43836 .60272 L p .42841 .60733 L 0 0 1 r
F P
0 g
s
.43836 .60272 m .44467 .60552 L p .43933 .60626 L 0 0 1 r
F P
0 g
s
.46233 .60307 m .45538 .61027 L .44467 .60552 L p 0 0 1 r
F P
0 g
s
.4731 .59188 m .46615 .6019 L .4555 .60044 L p 1 0 0 r
F P
0 g
s
.4555 .60044 m .46245 .59016 L .4731 .59188 L p 1 0 0 r
F P
0 g
s
.44467 .60552 m .4516 .59829 L .46233 .60307 L p 0 0 1 r
F P
0 g
s
.43834 .60271 m .43394 .59937 L p .43765 .60023 L 0 1 0 r
F P
0 g
s
.4516 .59829 m .44467 .60552 L .43843 .60276 L p 0 0 1 r
F P
0 g
s
.43843 .60276 m .43391 .60075 L p .43765 .60023 L 0 0 1 r
F P
0 g
s
.43765 .60023 m .4516 .59829 L .43843 .60276 L 0 0 1 r
F
.44081 .59349 m .4516 .59829 L p .43765 .60023 L F P
0 g
s
.44078 .59534 m .45152 .60344 L p .43765 .60023 L 0 1 0 r
F P
0 g
s
.43394 .59937 m .43686 .59765 L p .43765 .60023 L 0 1 0 r
F P
0 g
s
.43764 .60018 m .44081 .59349 L .43765 .60023 L 0 0 1 r
F
.43687 .59763 m .44081 .59349 L p .43762 .60024 L F P
0 g
s
.43686 .59765 m .44078 .59534 L p .43765 .60023 L 0 1 0 r
F P
0 g
s
.45152 .60344 m .44464 .6075 L .43834 .60271 L p 0 1 0 r
F P
0 g
s
.43765 .60023 m .45152 .60344 L .43834 .60271 L 0 1 0 r
F
.43762 .60024 m .43764 .60018 L .43765 .60023 L 0 0 1 r
F
.43391 .60075 m .43687 .59763 L p .43762 .60024 L F P
0 g
s
.43005 .58608 m .44093 .58733 L p .43043 .59289 L 1 0 0 r
F P
0 g
s
.42322 .59119 m .42895 .58777 L p .43043 .59289 L 0 1 0 r
F P
0 g
s
.43178 .59772 m .42322 .59119 L p .43043 .59289 L 0 1 0 r
F P
0 g
s
.43179 .59772 m .43178 .59772 L p .43178 .59771 L 1 0 0 r
F P
0 g
s
.43178 .59772 m .42555 .59705 L p .43043 .59289 L 1 0 0 r
F P
0 g
s
.42555 .59705 m .4231 .59596 L p .42517 .59568 L 0 0 1 r
F P
0 g
s
.42555 .59705 m .42308 .59678 L p .42517 .59568 L 1 0 0 r
F P
0 g
s
.42517 .59568 m .43043 .59289 L .42555 .59705 L 1 0 0 r
F
.42557 .59706 m .42555 .59705 L p .42517 .59568 L 0 0 1 r
F P
0 g
s
.43043 .59289 m .43043 .59289 L .43178 .59772 L 0 1 0 r
F
.43394 .59937 m .43178 .59772 L p .43653 .59646 L F P
0 g
s
.44081 .59349 m .43686 .59765 L p .43601 .59462 L 0 0 1 r
F P
0 g
s
.44078 .59534 m .43686 .59765 L p .43653 .59646 L 0 1 0 r
F P
0 g
s
.43686 .59765 m .43394 .59937 L p .43653 .59646 L 0 1 0 r
F P
0 g
s
.43043 .59289 m .43588 .59418 L .43178 .59772 L 0 1 0 r
F
.43588 .59418 m .44081 .59349 L .43601 .59462 L 0 0 1 r
F
.43588 .59418 m .44078 .59534 L .43653 .59646 L 0 1 0 r
F
.43588 .59418 m .43653 .59646 L .43178 .59772 L F
.42517 .59568 m .43588 .59418 L .42557 .59706 L 0 0 1 r
F
.43588 .59418 m .43601 .59462 L .42557 .59706 L F
.4321 .59894 m .43178 .59772 L .43211 .59894 L 1 0 0 r
F
.43178 .59772 m .43394 .59937 L p .4321 .59894 L 0 1 0 r
F P
0 g
s
.43391 .60075 m .42557 .59706 L p .43601 .59462 L 0 0 1 r
F P
0 g
s
.43686 .59765 m .43391 .60075 L p .43601 .59462 L 0 0 1 r
F P
0 g
s
.42517 .59568 m .42895 .58777 L .43043 .59289 L 1 0 0 r
F
.42475 .59422 m .42895 .58777 L p .42517 .59568 L F P
0 g
s
.42895 .58777 m .43005 .58608 L p .43042 .59284 L 1 0 0 r
F P
0 g
s
.42895 .58777 m .43042 .59284 L .43043 .59289 L 1 0 0 r
F
.42322 .59119 m .41249 .58303 L p .42867 .58681 L 0 1 0 r
F P
0 g
s
.42895 .58777 m .42322 .59119 L p .42867 .58681 L 0 1 0 r
F P
0 g
s
.42895 .58777 m .42898 .58775 L p .43043 .59289 L 0 1 0 r
F P
0 g
s
.43002 .58712 m .43494 .59088 L p .43043 .59289 L 0 1 0 r
F P
0 g
s
.43043 .59289 m .43494 .59088 L .43588 .59418 L 0 1 0 r
F
.42898 .58775 m .43002 .58712 L p .43043 .59289 L F P
0 g
s
.43494 .59088 m .44081 .59349 L p .43587 .59418 L 0 0 1 r
F P
0 g
s
.45857 .59101 m .4516 .59829 L .44081 .59349 L p 0 0 1 r
F P
0 g
s
.46942 .58002 m .46245 .59016 L .45173 .58867 L p 1 0 0 r
F P
0 g
s
.45173 .58867 m .4587 .57826 L .46942 .58002 L p 1 0 0 r
F P
0 g
s
.4587 .57826 m .45173 .58867 L .44093 .58733 L p 1 0 0 r
F P
0 g
s
.44081 .59349 m .44777 .58618 L .45857 .59101 L p 0 0 1 r
F P
0 g
s
.43494 .59088 m .43002 .58712 L p .43415 .58809 L 0 1 0 r
F P
0 g
s
.44093 .58733 m .44791 .57673 L .4587 .57826 L p 1 0 0 r
F P
0 g
s
.44791 .57673 m .44093 .58733 L .43005 .58608 L p 1 0 0 r
F P
0 g
s
.44777 .58618 m .44081 .59349 L .43504 .59092 L p 0 0 1 r
F P
0 g
s
.43504 .59092 m .42999 .58867 L p .43415 .58809 L 0 0 1 r
F P
0 g
s
.43415 .58809 m .44777 .58618 L .43504 .59092 L 0 0 1 r
F
.43002 .58712 m .43325 .58522 L p .43415 .58809 L 0 1 0 r
F P
0 g
s
.43005 .58608 m .43704 .57534 L .44791 .57673 L p 1 0 0 r
F P
0 g
s
.43704 .57534 m .43005 .58608 L .42843 .5859 L p 1 0 0 r
F P
0 g
s
.43005 .58608 m .42895 .58777 L p .42867 .58681 L 1 0 0 r
F P
0 g
s
.41648 .59532 m .40979 .59957 L .39914 .59176 L p 0 1 0 r
F P
0 g
s
.39914 .59176 m .40579 .58731 L .41648 .59532 L p 0 1 0 r
F P
0 g
s
.42322 .59119 m .41648 .59532 L .40579 .58731 L p 0 1 0 r
F P
0 g
s
.40579 .58731 m .41249 .58303 L .42322 .59119 L p 0 1 0 r
F P
0 g
s
.41249 .58303 m .42842 .5859 L .42867 .58681 L 0 1 0 r
F
.39253 .59644 m .39914 .59176 L .40979 .59957 L p F P
0 g
s
.40542 .59843 m .41225 .59116 L .4231 .59596 L p 0 0 1 r
F P
0 g
s
.4231 .59596 m .41225 .59116 L p .4234 .5896 L 0 0 1 r
F P
0 g
s
.4234 .5896 m .42867 .58681 L .42467 .59395 L 1 0 0 r
F
.42895 .58777 m .42475 .59422 L p .42867 .58681 L F P
0 g
s
.42475 .59422 m .4247 .59427 L p .4234 .5896 L 0 0 1 r
F P
0 g
s
.4247 .59427 m .4231 .59596 L p .4234 .5896 L 0 0 1 r
F P
0 g
s
.4231 .59596 m .42475 .59422 L p .42517 .59568 L 0 0 1 r
F P
0 g
s
.42475 .59422 m .42308 .59678 L p .42467 .59395 L 1 0 0 r
F P
0 g
s
.42867 .58681 m .42475 .59422 L .42467 .59395 L 1 0 0 r
F
.42999 .58867 m .42475 .59422 L p .4234 .5896 L 0 0 1 r
F P
0 g
s
.42217 .58519 m .42842 .5859 L p .42322 .58898 L 1 0 0 r
F P
0 g
s
.41249 .58303 m .41925 .57887 L .42842 .5859 L p 0 1 0 r
F P
0 g
s
.41225 .59116 m .41911 .58383 L .42217 .58519 L p 0 0 1 r
F P
0 g
s
.4234 .5896 m .42842 .5859 L .42867 .58681 L 1 0 0 r
F
.42322 .58898 m .42842 .5859 L .4234 .5896 L F
.42217 .58519 m .42999 .58867 L p .4234 .5896 L 0 0 1 r
F P
0 g
s
.41225 .59116 m .42217 .58519 L .4234 .5896 L 0 0 1 r
F
.41211 .59556 m .42322 .58898 L .4234 .5896 L 1 0 0 r
F
.41211 .59556 m .41909 .58485 L .42217 .58519 L p F P
0 g
s
.41211 .59556 m .42217 .58519 L .42322 .58898 L 1 0 0 r
F
.42842 .5859 m .43005 .58608 L p .42867 .58681 L F P
0 g
s
.42842 .5859 m .43002 .58712 L p .42867 .58681 L 0 1 0 r
F P
0 g
s
.43002 .58712 m .42842 .5859 L p .43231 .58198 L 0 1 0 r
F P
0 g
s
.42842 .5859 m .41925 .57887 L p .42693 .5807 L 0 1 0 r
F P
0 g
s
.42843 .5859 m .42842 .5859 L p .42693 .5807 L 1 0 0 r
F P
0 g
s
.42693 .5807 m .43704 .57534 L .42843 .5859 L 1 0 0 r
F
.42693 .5807 m .43231 .58198 L .42842 .5859 L 0 1 0 r
F
.42842 .5859 m .42217 .58519 L p .42693 .5807 L 1 0 0 r
F P
0 g
s
.43325 .58522 m .43002 .58712 L p .43231 .58198 L 0 1 0 r
F P
0 g
s
.43002 .58712 m .42895 .58777 L p .42867 .58681 L 0 1 0 r
F P
0 g
s
.43692 .58133 m .42999 .58867 L .42217 .58519 L p 0 0 1 r
F P
0 g
s
.42217 .58519 m .41911 .58383 L p .42168 .58347 L 0 0 1 r
F P
0 g
s
.42168 .58347 m .42693 .5807 L .42217 .58519 L 1 0 0 r
F
.42168 .58347 m .43692 .58133 L .42217 .58519 L 0 0 1 r
F
.42217 .58519 m .41909 .58485 L p .42168 .58347 L 1 0 0 r
F P
0 g
s
.42608 .57404 m .43704 .57534 L p .42693 .5807 L 1 0 0 r
F P
0 g
s
.41925 .57887 m .42531 .57523 L p .42639 .57887 L 0 1 0 r
F P
0 g
s
.42531 .57523 m .42608 .57404 L p .42691 .5806 L 1 0 0 r
F P
0 g
s
.42531 .57523 m .42691 .5806 L .42693 .5807 L 1 0 0 r
F
.41925 .57887 m .40846 .57063 L p .42511 .57455 L 0 1 0 r
F P
0 g
s
.42531 .57523 m .41925 .57887 L p .42511 .57455 L 0 1 0 r
F P
0 g
s
.42693 .5807 m .4314 .57887 L .43231 .58198 L 0 1 0 r
F
.41925 .57887 m .42639 .57887 L .42693 .5807 L F
.42639 .57887 m .4314 .57887 L .42693 .5807 L F
.41249 .58303 m .40579 .58731 L .39508 .57943 L p F P
0 g
s
.39508 .57943 m .40174 .57494 L .41249 .58303 L p 0 1 0 r
F P
0 g
s
.41925 .57887 m .41249 .58303 L .40174 .57494 L p 0 1 0 r
F P
0 g
s
.40174 .57494 m .40846 .57063 L .41925 .57887 L p 0 1 0 r
F P
0 g
s
.40579 .58731 m .39914 .59176 L .38846 .58416 L p 0 1 0 r
F P
0 g
s
.38846 .58416 m .39508 .57943 L .40579 .58731 L p 0 1 0 r
F P
0 g
s
.41911 .58383 m .41225 .59116 L .40135 .58633 L p 0 0 1 r
F P
0 g
s
.40135 .58633 m .40819 .57897 L .41911 .58383 L p 0 0 1 r
F P
0 g
s
.42168 .58347 m .42531 .57523 L .42693 .5807 L 1 0 0 r
F
.41911 .58383 m .42114 .58167 L p .42168 .58347 L 0 0 1 r
F P
0 g
s
.41909 .58485 m .42114 .58167 L p .42168 .58347 L 1 0 0 r
F P
0 g
s
.42114 .58167 m .42531 .57523 L p .42168 .58347 L 1 0 0 r
F P
0 g
s
.42168 .58347 m .42114 .58167 L .42168 .58347 L 0 0 1 r
F
.42639 .57887 m .42534 .57521 L .4264 .57887 L 0 1 0 r
F
.42531 .57523 m .42534 .57521 L p .42639 .57887 L F P
0 g
s
.42607 .57478 m .4314 .57887 L p .4264 .57887 L 0 1 0 r
F P
0 g
s
.42534 .57521 m .42607 .57478 L p .4264 .57887 L 0 1 0 r
F P
0 g
s
.4314 .57887 m .43692 .58133 L p .4323 .58198 L 0 0 1 r
F P
0 g
s
.43692 .58133 m .44777 .58618 L p .4341 .5881 L 0 0 1 r
F P
0 g
s
.4341 .58808 m .43692 .58133 L .4341 .5881 L 0 0 1 r
F
.43325 .58522 m .43692 .58133 L p .43409 .5881 L F P
0 g
s
.45476 .57883 m .44777 .58618 L .43692 .58133 L p 0 0 1 r
F P
0 g
s
.46571 .56801 m .4587 .57826 L .44791 .57673 L p 1 0 0 r
F P
0 g
s
.44791 .57673 m .45492 .56621 L .46571 .56801 L p 1 0 0 r
F P
0 g
s
.45492 .56621 m .44791 .57673 L .43704 .57534 L p 1 0 0 r
F P
0 g
s
.43692 .58133 m .44389 .57395 L .45476 .57883 L p 0 0 1 r
F P
0 g
s
.4314 .57887 m .42607 .57478 L p .43052 .57583 L 0 1 0 r
F P
0 g
s
.43704 .57534 m .44405 .56463 L .45492 .56621 L p 1 0 0 r
F P
0 g
s
.44405 .56463 m .43704 .57534 L .42608 .57404 L p 1 0 0 r
F P
0 g
s
.44389 .57395 m .43692 .58133 L .4315 .57891 L p 0 0 1 r
F P
0 g
s
.4315 .57891 m .42602 .57646 L p .43052 .57583 L 0 0 1 r
F P
0 g
s
.43052 .57583 m .44389 .57395 L .4315 .57891 L 0 0 1 r
F
.42607 .57478 m .42953 .57273 L p .43052 .57583 L 0 1 0 r
F P
0 g
s
.42608 .57404 m .43311 .5632 L .44405 .56463 L p 1 0 0 r
F P
0 g
s
.43311 .5632 m .42608 .57404 L .42493 .57391 L p 1 0 0 r
F P
0 g
s
.40846 .57063 m .42493 .5739 L .42511 .57455 L 0 1 0 r
F
.41911 .58383 m .40819 .57897 L p .41985 .57733 L 0 0 1 r
F P
0 g
s
.41985 .57733 m .42511 .57455 L .42108 .58144 L 1 0 0 r
F
.42531 .57523 m .42114 .58167 L p .42511 .57455 L F P
0 g
s
.42114 .58167 m .4211 .58172 L p .41985 .57733 L 0 0 1 r
F P
0 g
s
.4211 .58172 m .41911 .58383 L p .41985 .57733 L 0 0 1 r
F P
0 g
s
.42114 .58167 m .41909 .58485 L p .42108 .58144 L 1 0 0 r
F P
0 g
s
.42511 .57455 m .42114 .58167 L .42108 .58144 L 1 0 0 r
F
.42602 .57646 m .42114 .58167 L p .41985 .57733 L 0 0 1 r
F P
0 g
s
.41866 .57317 m .42493 .5739 L p .41972 .57689 L 1 0 0 r
F P
0 g
s
.40846 .57063 m .41523 .56644 L .42493 .5739 L p 0 1 0 r
F P
0 g
s
.40819 .57897 m .41508 .57157 L .41866 .57317 L p 0 0 1 r
F P
0 g
s
.41985 .57733 m .42493 .5739 L .42511 .57455 L 1 0 0 r
F
.41972 .57689 m .42493 .5739 L .41985 .57733 L F
.41866 .57317 m .42602 .57646 L p .41985 .57733 L 0 0 1 r
F P
0 g
s
.40819 .57897 m .41866 .57317 L .41985 .57733 L 0 0 1 r
F
.40805 .58357 m .41972 .57689 L .41985 .57733 L 1 0 0 r
F
.40805 .58357 m .41505 .57275 L .41866 .57317 L p F P
0 g
s
.40805 .58357 m .41866 .57317 L .41972 .57689 L 1 0 0 r
F
.42493 .5739 m .42608 .57404 L p .42511 .57455 L F P
0 g
s
.42608 .57404 m .42531 .57523 L p .42511 .57455 L 1 0 0 r
F P
0 g
s
.42493 .5739 m .42607 .57478 L p .42511 .57455 L 0 1 0 r
F P
0 g
s
.42607 .57478 m .42493 .5739 L p .42861 .56966 L 0 1 0 r
F P
0 g
s
.42493 .5739 m .41523 .56644 L p .4233 .56838 L 0 1 0 r
F P
0 g
s
.42493 .57391 m .42493 .5739 L p .4233 .56838 L 1 0 0 r
F P
0 g
s
.4233 .56838 m .43311 .5632 L .42493 .57391 L 1 0 0 r
F
.4233 .56838 m .42861 .56966 L .42493 .5739 L 0 1 0 r
F
.42493 .5739 m .41866 .57317 L p .4233 .56838 L 1 0 0 r
F P
0 g
s
.42953 .57273 m .42607 .57478 L p .42861 .56966 L 0 1 0 r
F P
0 g
s
.42607 .57478 m .42531 .57523 L p .42511 .57455 L 0 1 0 r
F P
0 g
s
.43298 .56905 m .42602 .57646 L .41866 .57317 L p 0 0 1 r
F P
0 g
s
.41866 .57317 m .41508 .57157 L p .41807 .57115 L 0 0 1 r
F P
0 g
s
.41807 .57115 m .4233 .56838 L .41866 .57317 L 1 0 0 r
F
.41807 .57115 m .43298 .56905 L .41866 .57317 L 0 0 1 r
F
.41866 .57317 m .41505 .57275 L p .41807 .57115 L 1 0 0 r
F P
0 g
s
.42208 .56184 m .43311 .5632 L p .4233 .56838 L 1 0 0 r
F P
0 g
s
.41523 .56644 m .42157 .56263 L p .42276 .56659 L 0 1 0 r
F P
0 g
s
.42157 .56263 m .42208 .56184 L p .42327 .5682 L 1 0 0 r
F P
0 g
s
.42157 .56263 m .42327 .5682 L .4233 .56838 L 1 0 0 r
F
.41523 .56644 m .40438 .55813 L p .42143 .56218 L 0 1 0 r
F P
0 g
s
.42157 .56263 m .41523 .56644 L p .42143 .56218 L 0 1 0 r
F P
0 g
s
.42331 .56839 m .42772 .56668 L .42861 .56966 L 0 1 0 r
F
.41523 .56644 m .42276 .56659 L .42331 .56839 L F
.42276 .56659 m .42772 .56668 L .42331 .56839 L F
.40846 .57063 m .40174 .57494 L .39097 .567 L p F P
0 g
s
.39097 .567 m .39765 .56247 L .40846 .57063 L p 0 1 0 r
F P
0 g
s
.41523 .56644 m .40846 .57063 L .39765 .56247 L p 0 1 0 r
F P
0 g
s
.39765 .56247 m .40438 .55813 L .41523 .56644 L p 0 1 0 r
F P
0 g
s
.40174 .57494 m .39508 .57943 L .38434 .57177 L p 0 1 0 r
F P
0 g
s
.38434 .57177 m .39097 .567 L .40174 .57494 L p 0 1 0 r
F P
0 g
s
.41508 .57157 m .40819 .57897 L .39723 .57409 L p 0 0 1 r
F P
0 g
s
.39723 .57409 m .4041 .56666 L .41508 .57157 L p 0 0 1 r
F P
0 g
s
.41807 .57115 m .42157 .56263 L .4233 .56838 L 1 0 0 r
F
.41508 .57157 m .41743 .56905 L p .41807 .57115 L 0 0 1 r
F P
0 g
s
.41505 .57275 m .41743 .56905 L p .41807 .57115 L 1 0 0 r
F P
0 g
s
.41743 .56905 m .42157 .56263 L p .41807 .57115 L 1 0 0 r
F P
0 g
s
.41807 .57115 m .41743 .56905 L .41808 .57115 L 0 0 1 r
F
.42276 .56659 m .42159 .56262 L .42277 .56659 L 0 1 0 r
F
.42157 .56263 m .42159 .56262 L p .42276 .56659 L F P
0 g
s
.42207 .56233 m .42772 .56668 L p .42277 .56659 L 0 1 0 r
F P
0 g
s
.42159 .56262 m .42207 .56233 L p .42277 .56659 L 0 1 0 r
F P
0 g
s
.42772 .56668 m .43298 .56905 L p .42861 .56966 L 0 0 1 r
F P
0 g
s
.43298 .56905 m .44389 .57395 L p .43046 .57584 L 0 0 1 r
F P
0 g
s
.43046 .57583 m .43298 .56905 L .43046 .57584 L 0 0 1 r
F
.42953 .57273 m .43298 .56905 L p .43046 .57584 L F P
0 g
s
.45092 .56651 m .44389 .57395 L .43298 .56905 L p 0 0 1 r
F P
0 g
s
.46195 .55584 m .45492 .56621 L .44405 .56463 L p 1 0 0 r
F P
0 g
s
.44405 .56463 m .45109 .55401 L .46195 .55584 L p 1 0 0 r
F P
0 g
s
.45109 .55401 m .44405 .56463 L .43311 .5632 L p 1 0 0 r
F P
0 g
s
.43298 .56905 m .43998 .56158 L .45092 .56651 L p 0 0 1 r
F P
0 g
s
.42772 .56668 m .42207 .56233 L p .42676 .56345 L 0 1 0 r
F P
0 g
s
.43311 .5632 m .44015 .55238 L .45109 .55401 L p 1 0 0 r
F P
0 g
s
.44015 .55238 m .43311 .5632 L .42208 .56184 L p 1 0 0 r
F P
0 g
s
.43998 .56158 m .43298 .56905 L .42783 .56673 L p 0 0 1 r
F P
0 g
s
.42783 .56673 m .42202 .56412 L p .42676 .56345 L 0 0 1 r
F P
0 g
s
.42676 .56345 m .43998 .56158 L .42783 .56673 L 0 0 1 r
F
.42207 .56233 m .42569 .56018 L p .42676 .56345 L 0 1 0 r
F P
0 g
s
.42208 .56184 m .42913 .55088 L .44015 .55238 L p 1 0 0 r
F P
0 g
s
.42913 .55088 m .42208 .56184 L .4213 .56174 L p 1 0 0 r
F P
0 g
s
.40438 .55813 m .4213 .56174 L .42143 .56218 L 0 1 0 r
F
.41508 .57157 m .4041 .56666 L p .41617 .56495 L 0 0 1 r
F P
0 g
s
.41617 .56495 m .42143 .56218 L .41738 .56888 L 1 0 0 r
F
.42157 .56263 m .41743 .56905 L p .42143 .56218 L F P
0 g
s
.41743 .56905 m .41739 .5691 L p .41617 .56495 L 0 0 1 r
F P
0 g
s
.41739 .5691 m .41508 .57157 L p .41617 .56495 L 0 0 1 r
F P
0 g
s
.41743 .56905 m .41505 .57275 L p .41738 .56888 L 1 0 0 r
F P
0 g
s
.42143 .56218 m .41743 .56905 L .41738 .56888 L 1 0 0 r
F
.42202 .56412 m .41743 .56905 L p .41617 .56495 L 0 0 1 r
F P
0 g
s
.41501 .56098 m .4213 .56174 L p .41608 .56464 L 1 0 0 r
F P
0 g
s
.40438 .55813 m .41117 .55392 L .4213 .56174 L p 0 1 0 r
F P
0 g
s
.4041 .56666 m .41101 .55918 L .41501 .56098 L p 0 0 1 r
F P
0 g
s
.41617 .56495 m .4213 .56174 L .42143 .56218 L 1 0 0 r
F
.41608 .56464 m .4213 .56174 L .41617 .56495 L F
.41501 .56098 m .42202 .56412 L p .41617 .56495 L 0 0 1 r
F P
0 g
s
.4041 .56666 m .41501 .56098 L .41617 .56495 L 0 0 1 r
F
.40394 .57141 m .41608 .56464 L .41617 .56495 L 1 0 0 r
F
.40394 .57141 m .41097 .56049 L .41501 .56098 L p F P
0 g
s
.40394 .57141 m .41501 .56098 L .41608 .56464 L 1 0 0 r
F
.4213 .56174 m .42208 .56184 L p .42143 .56218 L F P
0 g
s
.42208 .56184 m .42157 .56263 L p .42143 .56218 L 1 0 0 r
F P
0 g
s
.4213 .56174 m .42207 .56233 L p .42143 .56218 L 0 1 0 r
F P
0 g
s
.42207 .56233 m .4213 .56174 L p .42478 .55722 L 0 1 0 r
F P
0 g
s
.4213 .56174 m .41117 .55392 L p .41955 .55595 L 0 1 0 r
F P
0 g
s
.4213 .56174 m .4213 .56174 L p .41955 .55595 L 1 0 0 r
F P
0 g
s
.41955 .55595 m .42913 .55088 L .4213 .56174 L 1 0 0 r
F
.41955 .55595 m .42478 .55722 L .4213 .56174 L 0 1 0 r
F
.4213 .56174 m .41501 .56098 L p .41955 .55595 L 1 0 0 r
F P
0 g
s
.42569 .56018 m .42207 .56233 L p .42478 .55722 L 0 1 0 r
F P
0 g
s
.42207 .56233 m .42157 .56263 L p .42143 .56218 L 0 1 0 r
F P
0 g
s
.429 .55662 m .42202 .56412 L .41501 .56098 L p 0 0 1 r
F P
0 g
s
.41501 .56098 m .41101 .55918 L p .41434 .55871 L 0 0 1 r
F P
0 g
s
.41434 .55871 m .41955 .55595 L .41501 .56098 L 1 0 0 r
F
.41434 .55871 m .429 .55662 L .41501 .56098 L 0 0 1 r
F
.41501 .56098 m .41097 .56049 L p .41434 .55871 L 1 0 0 r
F P
0 g
s
.41803 .54946 m .42913 .55088 L p .41955 .55595 L 1 0 0 r
F P
0 g
s
.41117 .55392 m .4177 .54998 L p .419 .55417 L 0 1 0 r
F P
0 g
s
.4177 .54998 m .41803 .54946 L p .41955 .55595 L 1 0 0 r
F P
0 g
s
.41956 .55595 m .42389 .55432 L .42478 .55722 L 0 1 0 r
F
.41117 .55392 m .419 .55417 L .41956 .55595 L F
.419 .55417 m .42389 .55432 L .41956 .55595 L F
.40438 .55813 m .39765 .56247 L .38682 .55447 L p F P
0 g
s
.38682 .55447 m .39352 .5499 L .40438 .55813 L p 0 1 0 r
F P
0 g
s
.41117 .55392 m .40438 .55813 L .39352 .5499 L p 0 1 0 r
F P
0 g
s
.39352 .5499 m .40026 .54553 L .41117 .55392 L p 0 1 0 r
F P
0 g
s
.39765 .56247 m .39097 .567 L .38017 .55927 L p 0 1 0 r
F P
0 g
s
.38017 .55927 m .38682 .55447 L .39765 .56247 L p 0 1 0 r
F P
0 g
s
.41101 .55918 m .4041 .56666 L .39306 .56173 L p 0 0 1 r
F P
0 g
s
.41117 .55392 m .40026 .54553 L p .41761 .54968 L 0 1 0 r
F P
0 g
s
.41803 .54946 m .4177 .54998 L p .41761 .54968 L 1 0 0 r
F P
0 g
s
.41802 .54978 m .4177 .54998 L p .41761 .54968 L 0 1 0 r
F P
0 g
s
.4177 .54998 m .41117 .55392 L p .41761 .54968 L 0 1 0 r
F P
0 g
s
.39306 .56173 m .39995 .55421 L .41101 .55918 L p 0 0 1 r
F P
0 g
s
.41434 .55871 m .4177 .54998 L .41955 .55595 L 1 0 0 r
F
.41101 .55918 m .41361 .55637 L p .41434 .55871 L 0 0 1 r
F P
0 g
s
.41097 .56049 m .41361 .55637 L p .41434 .55871 L 1 0 0 r
F P
0 g
s
.41361 .55637 m .4177 .54998 L p .41434 .55871 L 1 0 0 r
F P
0 g
s
.41434 .55871 m .41361 .55637 L .41434 .55871 L 0 0 1 r
F
.419 .55417 m .41773 .54996 L .41901 .55417 L 0 1 0 r
F
.4177 .54998 m .41773 .54996 L p .419 .55417 L F P
0 g
s
.41802 .54978 m .42389 .55432 L p .41901 .55417 L 0 1 0 r
F P
0 g
s
.41773 .54996 m .41802 .54978 L p .41901 .55417 L 0 1 0 r
F P
0 g
s
.42389 .55432 m .429 .55662 L p .42478 .55722 L 0 0 1 r
F P
0 g
s
.429 .55662 m .43998 .56158 L p .4267 .56346 L 0 0 1 r
F P
0 g
s
.4267 .56346 m .429 .55662 L .4267 .56346 L 0 0 1 r
F
.42569 .56018 m .429 .55662 L p .42669 .56346 L F P
0 g
s
.44703 .55406 m .43998 .56158 L .429 .55662 L p 0 0 1 r
F P
0 g
s
.45816 .54352 m .45109 .55401 L .44015 .55238 L p 1 0 0 r
F P
0 g
s
.44015 .55238 m .44723 .54164 L .45816 .54352 L p 1 0 0 r
F P
0 g
s
.44723 .54164 m .44015 .55238 L .42913 .55088 L p 1 0 0 r
F P
0 g
s
.429 .55662 m .43603 .54908 L .44703 .55406 L p 0 0 1 r
F P
0 g
s
.42389 .55432 m .41802 .54978 L p .42286 .55095 L 0 1 0 r
F P
0 g
s
.42913 .55088 m .43621 .53995 L .44723 .54164 L p 1 0 0 r
F P
0 g
s
.43621 .53995 m .42913 .55088 L .41803 .54946 L p 1 0 0 r
F P
0 g
s
.43603 .54908 m .429 .55662 L .424 .55437 L p 0 0 1 r
F P
0 g
s
.424 .55437 m .41797 .55165 L p .42286 .55095 L 0 0 1 r
F P
0 g
s
.42286 .55095 m .43603 .54908 L .424 .55437 L 0 0 1 r
F
.41803 .54946 m .42512 .5384 L .43621 .53995 L p 1 0 0 r
F P
0 g
s
.41802 .54978 m .42174 .54757 L p .42286 .55095 L 0 1 0 r
F P
0 g
s
.42512 .5384 m .41803 .54946 L .41753 .5494 L p 1 0 0 r
F P
0 g
s
.40026 .54553 m .41753 .5494 L .41761 .54968 L 0 1 0 r
F
.41101 .55918 m .39995 .55421 L p .41238 .55244 L 0 0 1 r
F P
0 g
s
.41238 .55244 m .41761 .54968 L .41357 .55625 L 1 0 0 r
F
.4177 .54998 m .41361 .55637 L p .41761 .54968 L F P
0 g
s
.41361 .55637 m .41356 .55642 L p .41238 .55244 L 0 0 1 r
F P
0 g
s
.41356 .55642 m .41101 .55918 L p .41238 .55244 L 0 0 1 r
F P
0 g
s
.41361 .55637 m .41097 .56049 L p .41357 .55625 L 1 0 0 r
F P
0 g
s
.41761 .54968 m .41361 .55637 L .41357 .55625 L 1 0 0 r
F
.41797 .55165 m .41361 .55637 L p .41238 .55244 L 0 0 1 r
F P
0 g
s
.41123 .54861 m .41753 .5494 L p .41232 .55224 L 1 0 0 r
F P
0 g
s
.40026 .54553 m .40707 .54129 L .41753 .5494 L p 0 1 0 r
F P
0 g
s
.39995 .55421 m .40689 .54665 L .41123 .54861 L p 0 0 1 r
F P
0 g
s
.41238 .55244 m .41753 .5494 L .41761 .54968 L 1 0 0 r
F
.41232 .55224 m .41753 .5494 L .41238 .55244 L F
.41123 .54861 m .41797 .55165 L p .41238 .55244 L 0 0 1 r
F P
0 g
s
.39995 .55421 m .41123 .54861 L .41238 .55244 L 0 0 1 r
F
.39978 .55908 m .41232 .55224 L .41238 .55244 L 1 0 0 r
F
.39978 .55908 m .40685 .54805 L .41123 .54861 L p F P
0 g
s
.39978 .55908 m .41123 .54861 L .41232 .55224 L 1 0 0 r
F
.41753 .5494 m .41803 .54946 L p .41761 .54968 L F P
0 g
s
.41753 .5494 m .41802 .54978 L p .41761 .54968 L 0 1 0 r
F P
0 g
s
.41802 .54978 m .41753 .5494 L p .42082 .54466 L 0 1 0 r
F P
0 g
s
.41753 .5494 m .40707 .54129 L p .41566 .5434 L 0 1 0 r
F P
0 g
s
.41753 .5494 m .41753 .5494 L p .41566 .5434 L 1 0 0 r
F P
0 g
s
.41566 .5434 m .42512 .5384 L .41753 .5494 L 1 0 0 r
F
.41566 .5434 m .42082 .54466 L .41753 .5494 L 0 1 0 r
F
.41753 .5494 m .41123 .54861 L p .41566 .5434 L 1 0 0 r
F P
0 g
s
.42174 .54757 m .41802 .54978 L p .42082 .54466 L 0 1 0 r
F P
0 g
s
.42498 .54407 m .41797 .55165 L .41123 .54861 L p 0 0 1 r
F P
0 g
s
.41123 .54861 m .40689 .54665 L p .41047 .54614 L 0 0 1 r
F P
0 g
s
.41047 .54614 m .41566 .5434 L .41123 .54861 L 1 0 0 r
F
.41047 .54614 m .42498 .54407 L .41123 .54861 L 0 0 1 r
F
.41123 .54861 m .40685 .54805 L p .41047 .54614 L 1 0 0 r
F P
0 g
s
.41394 .53692 m .42512 .5384 L p .41566 .5434 L 1 0 0 r
F P
0 g
s
.40707 .54129 m .41373 .53726 L p .41509 .54159 L 0 1 0 r
F P
0 g
s
.41373 .53726 m .41394 .53692 L p .41566 .5434 L 1 0 0 r
F P
0 g
s
.41568 .5434 m .41992 .54177 L .42082 .54466 L 0 1 0 r
F
.40707 .54129 m .4151 .54159 L .41568 .5434 L F
.4151 .54159 m .41992 .54177 L .41568 .5434 L F
.40026 .54553 m .39352 .5499 L .38262 .54182 L p F P
0 g
s
.38262 .54182 m .38934 .53723 L .40026 .54553 L p 0 1 0 r
F P
0 g
s
.40707 .54129 m .40026 .54553 L .38934 .53723 L p 0 1 0 r
F P
0 g
s
.38934 .53723 m .3961 .53282 L .40707 .54129 L p 0 1 0 r
F P
0 g
s
.39352 .5499 m .38682 .55447 L .37596 .54666 L p 0 1 0 r
F P
0 g
s
.37596 .54666 m .38262 .54182 L .39352 .5499 L p 0 1 0 r
F P
0 g
s
.40689 .54665 m .39995 .55421 L .38885 .54923 L p 0 0 1 r
F P
0 g
s
.40707 .54129 m .3961 .53282 L p .41367 .53707 L 0 1 0 r
F P
0 g
s
.41394 .53692 m .41373 .53726 L p .41367 .53707 L 1 0 0 r
F P
0 g
s
.41393 .53713 m .41373 .53726 L p .41367 .53707 L 0 1 0 r
F P
0 g
s
.41373 .53726 m .40707 .54129 L p .41367 .53707 L 0 1 0 r
F P
0 g
s
.38885 .54923 m .39577 .54163 L .40689 .54665 L p 0 0 1 r
F P
0 g
s
.41047 .54614 m .41373 .53726 L .41566 .5434 L 1 0 0 r
F
.40689 .54665 m .40967 .54362 L p .41047 .54614 L 0 0 1 r
F P
0 g
s
.40685 .54805 m .40967 .54362 L p .41047 .54614 L 1 0 0 r
F P
0 g
s
.40967 .54362 m .41373 .53726 L p .41047 .54614 L 1 0 0 r
F P
0 g
s
.41047 .54614 m .40967 .54362 L .41048 .54614 L 0 0 1 r
F
.41509 .54159 m .41375 .53724 L .4151 .54159 L 0 1 0 r
F
.41373 .53726 m .41375 .53724 L p .41509 .54159 L F P
0 g
s
.41393 .53713 m .41992 .54177 L p .4151 .54159 L 0 1 0 r
F P
0 g
s
.41375 .53724 m .41393 .53713 L p .4151 .54159 L 0 1 0 r
F P
0 g
s
.41992 .54177 m .42498 .54407 L p .42082 .54466 L 0 0 1 r
F P
0 g
s
.42498 .54407 m .43603 .54908 L p .4228 .55096 L 0 0 1 r
F P
0 g
s
.42174 .54757 m .42498 .54407 L p .4228 .55096 L 0 0 1 r
F P
0 g
s
.4431 .54148 m .43603 .54908 L .42498 .54407 L p 0 0 1 r
F P
0 g
s
.45432 .53104 m .44723 .54164 L .43621 .53995 L p 1 0 0 r
F P
0 g
s
.43621 .53995 m .44332 .5291 L .45432 .53104 L p 1 0 0 r
F P
0 g
s
.44332 .5291 m .43621 .53995 L .42512 .5384 L p 1 0 0 r
F P
0 g
s
.42498 .54407 m .43203 .53644 L .4431 .54148 L p 0 0 1 r
F P
0 g
s
.41992 .54177 m .41393 .53713 L p .41883 .53833 L 0 1 0 r
F P
0 g
s
.42512 .5384 m .43223 .52736 L .44332 .5291 L p 1 0 0 r
F P
0 g
s
.43223 .52736 m .42512 .5384 L .41394 .53692 L p 1 0 0 r
F P
0 g
s
.43203 .53644 m .42498 .54407 L .42002 .54182 L p 0 0 1 r
F P
0 g
s
.42002 .54182 m .41388 .53904 L p .41883 .53833 L 0 0 1 r
F P
0 g
s
.41883 .53833 m .43203 .53644 L .42002 .54182 L 0 0 1 r
F
.41394 .53692 m .42106 .52575 L .43223 .52736 L p 1 0 0 r
F P
0 g
s
.41393 .53713 m .41767 .5349 L p .41883 .53833 L 0 1 0 r
F P
0 g
s
.42091 .53137 m .43203 .53644 L p .41877 .53833 L 0 0 1 r
F P
0 g
s
.41388 .53904 m .41767 .5349 L p .41877 .53833 L 0 0 1 r
F P
0 g
s
.41767 .5349 m .42091 .53137 L p .41877 .53833 L 0 0 1 r
F P
0 g
s
.3961 .53282 m .40292 .52856 L .41361 .53688 L p 0 1 0 r
F P
0 g
s
.41367 .53707 m .41361 .53688 L .41367 .53707 L 1 0 0 r
F
.41361 .53688 m .41394 .53692 L p .41367 .53707 L F P
0 g
s
.41361 .53688 m .41393 .53713 L p .41367 .53707 L 0 1 0 r
F P
0 g
s
.3961 .53282 m .41361 .53688 L .41367 .53707 L 0 1 0 r
F
.40689 .54665 m .39577 .54163 L p .40845 .53981 L 0 0 1 r
F P
0 g
s
.40845 .53981 m .41367 .53707 L .40965 .54354 L 1 0 0 r
F
.41373 .53726 m .40967 .54362 L p .41367 .53707 L F P
0 g
s
.40967 .54362 m .40963 .54367 L p .40845 .53981 L 0 0 1 r
F P
0 g
s
.40963 .54367 m .40689 .54665 L p .40845 .53981 L 0 0 1 r
F P
0 g
s
.40967 .54362 m .40685 .54805 L p .40965 .54354 L 1 0 0 r
F P
0 g
s
.41367 .53707 m .40967 .54362 L .40965 .54354 L 1 0 0 r
F
.41388 .53904 m .40967 .54362 L p .40845 .53981 L 0 0 1 r
F P
0 g
s
.40845 .53981 m .41361 .53688 L .41367 .53707 L 1 0 0 r
F
.40841 .53968 m .41361 .53688 L .40845 .53981 L F
.39577 .54163 m .40273 .53398 L .4073 .53605 L p 0 0 1 r
F P
0 g
s
.4073 .53605 m .41361 .53688 L p .40841 .53968 L 1 0 0 r
F P
0 g
s
.4073 .53605 m .41388 .53904 L p .40845 .53981 L 0 0 1 r
F P
0 g
s
.39577 .54163 m .4073 .53605 L .40845 .53981 L 0 0 1 r
F
.39558 .54658 m .40268 .53545 L .4073 .53605 L p 1 0 0 r
F P
0 g
s
.39558 .54658 m .4073 .53605 L .40841 .53968 L 1 0 0 r
F
.39558 .54658 m .40841 .53968 L .40845 .53981 L F
.42106 .52575 m .41394 .53692 L .41361 .53688 L p F P
0 g
s
.41361 .53688 m .40292 .52856 L p .41165 .53072 L 0 1 0 r
F P
0 g
s
.41361 .53688 m .4073 .53605 L p .41165 .53072 L 1 0 0 r
F P
0 g
s
.41165 .53072 m .42106 .52575 L .41361 .53688 L 1 0 0 r
F
.41165 .53072 m .41167 .53072 L .41361 .53688 L 0 1 0 r
F
.41393 .53713 m .41361 .53688 L p .41673 .53197 L F P
0 g
s
.41167 .53072 m .41673 .53197 L .41361 .53688 L 0 1 0 r
F
.41767 .5349 m .41393 .53713 L p .41673 .53197 L F P
0 g
s
.40981 .52421 m .42106 .52575 L p .41165 .53072 L 1 0 0 r
F P
0 g
s
.40292 .52856 m .40964 .52448 L p .41105 .52886 L 0 1 0 r
F P
0 g
s
.40964 .52448 m .40981 .52421 L p .41165 .53072 L 1 0 0 r
F P
0 g
s
.41166 .53072 m .41578 .52904 L .41673 .53197 L 0 1 0 r
F
.40292 .52856 m .41106 .52886 L .41166 .53072 L F
.41106 .52886 m .41578 .52904 L .41166 .53072 L F
.4073 .53605 m .40273 .53398 L p .40648 .53344 L 0 0 1 r
F P
0 g
s
.3961 .53282 m .38934 .53723 L .37838 .52907 L p 0 1 0 r
F P
0 g
s
.37838 .52907 m .38511 .52444 L .3961 .53282 L p 0 1 0 r
F P
0 g
s
.40292 .52856 m .3961 .53282 L .38511 .52444 L p 0 1 0 r
F P
0 g
s
.38511 .52444 m .39189 .52001 L .40292 .52856 L p 0 1 0 r
F P
0 g
s
.38934 .53723 m .38262 .54182 L .3717 .53395 L p 0 1 0 r
F P
0 g
s
.3717 .53395 m .37838 .52907 L .38934 .53723 L p 0 1 0 r
F P
0 g
s
.40273 .53398 m .39577 .54163 L .38459 .53659 L p 0 0 1 r
F P
0 g
s
.40292 .52856 m .39189 .52001 L p .40958 .52433 L 0 1 0 r
F P
0 g
s
.40981 .52421 m .40964 .52448 L p .40959 .52433 L 1 0 0 r
F P
0 g
s
.4098 .52438 m .40964 .52448 L p .40958 .52433 L 0 1 0 r
F P
0 g
s
.40964 .52448 m .40292 .52856 L p .40958 .52433 L 0 1 0 r
F P
0 g
s
.38459 .53659 m .39153 .52891 L .40273 .53398 L p 0 0 1 r
F P
0 g
s
.40648 .53344 m .40964 .52448 L .41165 .53072 L 1 0 0 r
F
.40273 .53398 m .40562 .5308 L p .40648 .53344 L 0 0 1 r
F P
0 g
s
.40268 .53545 m .40562 .5308 L p .40648 .53344 L 1 0 0 r
F P
0 g
s
.40562 .5308 m .40964 .52448 L p .40648 .53344 L 1 0 0 r
F P
0 g
s
.40648 .53344 m .40562 .5308 L .40649 .53344 L 0 0 1 r
F
.4098 .52438 m .41578 .52904 L p .41105 .52886 L 0 1 0 r
F P
0 g
s
.40964 .52448 m .4098 .52438 L p .41105 .52886 L 0 1 0 r
F P
0 g
s
.40648 .53344 m .41165 .53072 L .4073 .53605 L 1 0 0 r
F
.41578 .52904 m .42091 .53137 L p .41673 .53197 L 0 0 1 r
F P
0 g
s
.42091 .53137 m .41767 .5349 L p .41697 .53273 L 0 0 1 r
F P
0 g
s
.40648 .53344 m .42091 .53137 L .4073 .53605 L 0 0 1 r
F
.43913 .52876 m .43203 .53644 L .42091 .53137 L p F P
0 g
s
.45045 .5184 m .44332 .5291 L .43223 .52736 L p 1 0 0 r
F P
0 g
s
.43223 .52736 m .43937 .5164 L .45045 .5184 L p 1 0 0 r
F P
0 g
s
.43937 .5164 m .43223 .52736 L .42106 .52575 L p 1 0 0 r
F P
0 g
s
.42091 .53137 m .42799 .52366 L .43913 .52876 L p 0 0 1 r
F P
0 g
s
.41578 .52904 m .4098 .52438 L p .41467 .52558 L 0 1 0 r
F P
0 g
s
.42106 .52575 m .4282 .5146 L .43937 .5164 L p 1 0 0 r
F P
0 g
s
.4282 .5146 m .42106 .52575 L .40981 .52421 L p 1 0 0 r
F P
0 g
s
.42799 .52366 m .42091 .53137 L .41589 .52908 L p 0 0 1 r
F P
0 g
s
.41589 .52908 m .40974 .52628 L p .41467 .52558 L 0 0 1 r
F P
0 g
s
.41467 .52558 m .42799 .52366 L .41589 .52908 L 0 0 1 r
F
.40981 .52421 m .41696 .51293 L .4282 .5146 L p 1 0 0 r
F P
0 g
s
.4098 .52438 m .41348 .52217 L p .41467 .52558 L 0 1 0 r
F P
0 g
s
.4168 .51854 m .42799 .52366 L p .41461 .52558 L 0 0 1 r
F P
0 g
s
.40974 .52628 m .41348 .52217 L p .41461 .52558 L 0 0 1 r
F P
0 g
s
.41348 .52217 m .4168 .51854 L p .41461 .52558 L 0 0 1 r
F P
0 g
s
.39189 .52001 m .39872 .51573 L .40954 .52417 L p 0 1 0 r
F P
0 g
s
.40958 .52433 m .40954 .52417 L .40959 .52433 L 1 0 0 r
F
.40954 .52417 m .40981 .52421 L p .40959 .52433 L F P
0 g
s
.40954 .52417 m .4098 .52438 L p .40958 .52433 L 0 1 0 r
F P
0 g
s
.39189 .52001 m .40954 .52417 L .40958 .52433 L 0 1 0 r
F
.40273 .53398 m .39153 .52891 L p .40439 .52705 L 0 0 1 r
F P
0 g
s
.40439 .52705 m .40958 .52433 L .4056 .53074 L 1 0 0 r
F
.40964 .52448 m .40562 .5308 L p .40959 .52433 L F P
0 g
s
.40562 .5308 m .40558 .53085 L p .40439 .52705 L 0 0 1 r
F P
0 g
s
.40558 .53085 m .40273 .53398 L p .40439 .52705 L 0 0 1 r
F P
0 g
s
.40562 .5308 m .40268 .53545 L p .4056 .53074 L 1 0 0 r
F P
0 g
s
.40959 .52433 m .40562 .5308 L .4056 .53074 L 1 0 0 r
F
.40974 .52628 m .40562 .5308 L p .40439 .52705 L 0 0 1 r
F P
0 g
s
.40439 .52705 m .40954 .52417 L .40958 .52433 L 1 0 0 r
F
.40436 .52695 m .40954 .52417 L .40439 .52705 L F
.39153 .52891 m .39852 .52118 L .40322 .52332 L p 0 0 1 r
F P
0 g
s
.40322 .52332 m .40954 .52417 L p .40436 .52695 L 1 0 0 r
F P
0 g
s
.40322 .52332 m .40974 .52628 L p .40439 .52705 L 0 0 1 r
F P
0 g
s
.39153 .52891 m .40322 .52332 L .40439 .52705 L 0 0 1 r
F
.39134 .53392 m .39847 .52267 L .40322 .52332 L p 1 0 0 r
F P
0 g
s
.39134 .53392 m .40322 .52332 L .40436 .52695 L 1 0 0 r
F
.39134 .53392 m .40436 .52695 L .40439 .52705 L F
.41696 .51293 m .40981 .52421 L .40954 .52417 L p F P
0 g
s
.40954 .52417 m .39872 .51573 L p .4075 .51791 L 0 1 0 r
F P
0 g
s
.40954 .52417 m .40322 .52332 L p .4075 .51791 L 1 0 0 r
F P
0 g
s
.4075 .51791 m .41696 .51293 L .40954 .52417 L 1 0 0 r
F
.4075 .51791 m .40752 .51792 L .40954 .52417 L 0 1 0 r
F
.4098 .52438 m .40954 .52417 L p .41249 .51916 L F P
0 g
s
.40752 .51792 m .41249 .51916 L .40954 .52417 L 0 1 0 r
F
.41348 .52217 m .4098 .52438 L p .41249 .51916 L F P
0 g
s
.40563 .51132 m .41696 .51293 L p .4075 .51791 L 1 0 0 r
F P
0 g
s
.39872 .51573 m .40543 .51164 L p .40686 .51597 L 0 1 0 r
F P
0 g
s
.40543 .51164 m .40563 .51132 L p .4075 .51791 L 1 0 0 r
F P
0 g
s
.40751 .51792 m .41149 .51611 L .41249 .51916 L 0 1 0 r
F
.39872 .51573 m .40686 .51597 L .40751 .51792 L F
.40686 .51597 m .41149 .51611 L .40751 .51792 L F
.40322 .52332 m .39852 .52118 L p .40236 .52062 L 0 0 1 r
F P
0 g
s
.39189 .52001 m .38511 .52444 L .3741 .51621 L p 0 1 0 r
F P
0 g
s
.3741 .51621 m .38084 .51155 L .39189 .52001 L p 0 1 0 r
F P
0 g
s
.39872 .51573 m .39189 .52001 L .38084 .51155 L p 0 1 0 r
F P
0 g
s
.38084 .51155 m .38763 .5071 L .39872 .51573 L p 0 1 0 r
F P
0 g
s
.38511 .52444 m .37838 .52907 L .3674 .52112 L p 0 1 0 r
F P
0 g
s
.3674 .52112 m .3741 .51621 L .38511 .52444 L p 0 1 0 r
F P
0 g
s
.39852 .52118 m .39153 .52891 L .38029 .52381 L p 0 0 1 r
F P
0 g
s
.39872 .51573 m .38763 .5071 L p .40537 .51146 L 0 1 0 r
F P
0 g
s
.40563 .51132 m .40543 .51164 L p .40537 .51146 L 1 0 0 r
F P
0 g
s
.40562 .51152 m .40543 .51164 L p .40537 .51146 L 0 1 0 r
F P
0 g
s
.40543 .51164 m .39872 .51573 L p .40537 .51146 L 0 1 0 r
F P
0 g
s
.38029 .52381 m .38726 .51604 L .39852 .52118 L p 0 0 1 r
F P
0 g
s
.40236 .52062 m .40543 .51164 L .4075 .51791 L 1 0 0 r
F
.39852 .52118 m .40146 .51792 L p .40236 .52062 L 0 0 1 r
F P
0 g
s
.39847 .52267 m .40146 .51792 L p .40236 .52062 L 1 0 0 r
F P
0 g
s
.40146 .51792 m .40543 .51164 L p .40236 .52062 L 1 0 0 r
F P
0 g
s
.40236 .52062 m .40146 .51792 L .40237 .52062 L 0 0 1 r
F
.40562 .51152 m .41149 .51611 L p .40686 .51597 L 0 1 0 r
F P
0 g
s
.40543 .51164 m .40562 .51152 L p .40686 .51597 L 0 1 0 r
F P
0 g
s
.40236 .52062 m .4075 .51791 L .40322 .52332 L 1 0 0 r
F
.41149 .51611 m .4168 .51854 L p .41249 .51916 L 0 0 1 r
F P
0 g
s
.4168 .51854 m .41348 .52217 L p .41275 .51996 L 0 0 1 r
F P
0 g
s
.40236 .52062 m .4168 .51854 L .40322 .52332 L 0 0 1 r
F
.43511 .51589 m .42799 .52366 L .4168 .51854 L p F P
0 g
s
.44653 .50558 m .43937 .5164 L .4282 .5146 L p 1 0 0 r
F P
0 g
s
.4282 .5146 m .43537 .50353 L .44653 .50558 L p 1 0 0 r
F P
0 g
s
.43537 .50353 m .4282 .5146 L .41696 .51293 L p 1 0 0 r
F P
0 g
s
.4168 .51854 m .4239 .51074 L .43511 .51589 L p 0 0 1 r
F P
0 g
s
.41149 .51611 m .40562 .51152 L p .41036 .5127 L 0 1 0 r
F P
0 g
s
.41696 .51293 m .42413 .50167 L .43537 .50353 L p 1 0 0 r
F P
0 g
s
.42413 .50167 m .41696 .51293 L .40563 .51132 L p 1 0 0 r
F P
0 g
s
.4239 .51074 m .4168 .51854 L .41159 .51615 L p 0 0 1 r
F P
0 g
s
.41159 .51615 m .40556 .51339 L p .41036 .5127 L 0 0 1 r
F P
0 g
s
.41036 .5127 m .4239 .51074 L .41159 .51615 L 0 0 1 r
F
.40563 .51132 m .41281 .49993 L .42413 .50167 L p 1 0 0 r
F P
0 g
s
.40562 .51152 m .40918 .50938 L p .41036 .5127 L 0 1 0 r
F P
0 g
s
.41281 .49993 m .40563 .51132 L .40531 .51128 L p 1 0 0 r
F P
0 g
s
.40321 .50498 m .41281 .49993 L .40531 .51128 L 1 0 0 r
F
.40562 .51152 m .40531 .51128 L p .40812 .50621 L 0 1 0 r
F P
0 g
s
.40531 .51128 m .39448 .50279 L p .40321 .50498 L 0 1 0 r
F P
0 g
s
.40531 .51128 m .40531 .51128 L p .40321 .50498 L 1 0 0 r
F P
0 g
s
.40321 .50498 m .40812 .50621 L .40531 .51128 L 0 1 0 r
F
.38763 .5071 m .39448 .50279 L .40531 .51128 L p F P
0 g
s
.38763 .5071 m .40531 .51128 L .40537 .51146 L 0 1 0 r
F
.39852 .52118 m .38726 .51604 L p .4002 .51417 L 0 0 1 r
F P
0 g
s
.40542 .51164 m .40146 .51792 L p .40537 .51146 L 1 0 0 r
F P
0 g
s
.40146 .51792 m .40142 .51797 L p .4002 .51417 L 0 0 1 r
F P
0 g
s
.40142 .51797 m .39852 .52118 L p .4002 .51417 L 0 0 1 r
F P
0 g
s
.40146 .51792 m .39847 .52267 L p .40144 .51784 L 1 0 0 r
F P
0 g
s
.40537 .51146 m .40146 .51792 L .40144 .51784 L 1 0 0 r
F
.4002 .51417 m .40537 .51146 L .40144 .51784 L F
.40556 .51339 m .40146 .51792 L p .4002 .51417 L 0 0 1 r
F P
0 g
s
.39899 .51039 m .40531 .51128 L p .40016 .51404 L 1 0 0 r
F P
0 g
s
.38726 .51604 m .39427 .50823 L .39899 .51039 L p 0 0 1 r
F P
0 g
s
.40531 .51128 m .40531 .51128 L p .40537 .51146 L 0 1 0 r
F P
0 g
s
.4002 .51417 m .40531 .51128 L .40537 .51146 L 1 0 0 r
F
.40016 .51404 m .40531 .51128 L .4002 .51417 L F
.39899 .51039 m .40556 .51339 L p .4002 .51417 L 0 0 1 r
F P
0 g
s
.38726 .51604 m .39899 .51039 L .4002 .51417 L 0 0 1 r
F
.38705 .52107 m .40016 .51404 L .4002 .51417 L 1 0 0 r
F
.38705 .52107 m .39421 .50972 L .39899 .51039 L p F P
0 g
s
.38705 .52107 m .39899 .51039 L .40016 .51404 L 1 0 0 r
F
.40531 .51128 m .40563 .51132 L p .40537 .51146 L F P
0 g
s
.40531 .51128 m .40562 .51152 L p .40537 .51146 L 0 1 0 r
F P
0 g
s
.40543 .51164 m .40542 .51164 L p .40537 .51146 L 1 0 0 r
F P
0 g
s
.40537 .51146 m .40542 .51164 L .40537 .51146 L 1 0 0 r
F
.40531 .51128 m .39899 .51039 L p .40321 .50498 L F P
0 g
s
.40918 .50938 m .40562 .51152 L p .40812 .50621 L 0 1 0 r
F P
0 g
s
.41264 .50556 m .40556 .51339 L .39899 .51039 L p 0 0 1 r
F P
0 g
s
.39899 .51039 m .39427 .50823 L p .3981 .50767 L 0 0 1 r
F P
0 g
s
.3981 .50767 m .40321 .50498 L .39899 .51039 L 1 0 0 r
F
.3981 .50767 m .41264 .50556 L .39899 .51039 L 0 0 1 r
F
.39899 .51039 m .39421 .50972 L p .3981 .50767 L 1 0 0 r
F P
0 g
s
.4014 .49826 m .41281 .49993 L p .40321 .50498 L 1 0 0 r
F P
0 g
s
.39448 .50279 m .4011 .49873 L p .40251 .50291 L 0 1 0 r
F P
0 g
s
.4011 .49873 m .4014 .49826 L p .40321 .50498 L 1 0 0 r
F P
0 g
s
.40322 .50498 m .40703 .50298 L .40812 .50621 L 0 1 0 r
F
.39448 .50279 m .40252 .50291 L .40322 .50498 L F
.40252 .50291 m .40703 .50298 L .40322 .50498 L F
.38763 .5071 m .38084 .51155 L .36976 .50324 L p F P
0 g
s
.36976 .50324 m .37651 .49855 L .38763 .5071 L p 0 1 0 r
F P
0 g
s
.39448 .50279 m .38763 .5071 L .37651 .49855 L p 0 1 0 r
F P
0 g
s
.37651 .49855 m .38332 .49407 L .39448 .50279 L p 0 1 0 r
F P
0 g
s
.38084 .51155 m .3741 .51621 L .36305 .50818 L p 0 1 0 r
F P
0 g
s
.36305 .50818 m .36976 .50324 L .38084 .51155 L p 0 1 0 r
F P
0 g
s
.39427 .50823 m .38726 .51604 L .37594 .51089 L p 0 0 1 r
F P
0 g
s
.39448 .50279 m .38332 .49407 L p .40101 .49846 L 0 1 0 r
F P
0 g
s
.4014 .49826 m .4011 .49873 L p .40101 .49846 L 1 0 0 r
F P
0 g
s
.40139 .49856 m .4011 .49873 L p .40101 .49846 L 0 1 0 r
F P
0 g
s
.4011 .49873 m .39448 .50279 L p .40101 .49846 L 0 1 0 r
F P
0 g
s
.37594 .51089 m .38293 .50304 L .39427 .50823 L p 0 0 1 r
F P
0 g
s
.3981 .50767 m .4011 .49873 L .40321 .50498 L 1 0 0 r
F
.39427 .50823 m .39719 .50497 L p .3981 .50767 L 0 0 1 r
F P
0 g
s
.39421 .50972 m .39719 .50497 L p .3981 .50767 L 1 0 0 r
F P
0 g
s
.39719 .50497 m .4011 .49873 L p .3981 .50767 L 1 0 0 r
F P
0 g
s
.3981 .50767 m .39719 .50497 L .39811 .50767 L 0 0 1 r
F
.40251 .50291 m .40112 .49872 L .40252 .50291 L 0 1 0 r
F
.4011 .49873 m .40112 .49872 L p .40251 .50291 L F P
0 g
s
.40139 .49856 m .40703 .50298 L p .40252 .50291 L 0 1 0 r
F P
0 g
s
.40112 .49872 m .40139 .49856 L p .40252 .50291 L 0 1 0 r
F P
0 g
s
.40703 .50298 m .41264 .50556 L p .40812 .50621 L 0 0 1 r
F P
0 g
s
.41264 .50556 m .4239 .51074 L p .41031 .5127 L 0 0 1 r
F P
0 g
s
.40918 .50938 m .41264 .50556 L p .4103 .51271 L 0 0 1 r
F P
0 g
s
.43105 .50288 m .4239 .51074 L .41264 .50556 L p 0 0 1 r
F P
0 g
s
.44256 .49261 m .43537 .50353 L .42413 .50167 L p 1 0 0 r
F P
0 g
s
.42413 .50167 m .43133 .49049 L .44256 .49261 L p 1 0 0 r
F P
0 g
s
.43133 .49049 m .42413 .50167 L .41281 .49993 L p 1 0 0 r
F P
0 g
s
.41264 .50556 m .41977 .49767 L .43105 .50288 L p 0 0 1 r
F P
0 g
s
.40703 .50298 m .40139 .49856 L p .40592 .49969 L 0 1 0 r
F P
0 g
s
.41281 .49993 m .42002 .48856 L .43133 .49049 L p 1 0 0 r
F P
0 g
s
.42002 .48856 m .41281 .49993 L .4014 .49826 L p 1 0 0 r
F P
0 g
s
.41977 .49767 m .41264 .50556 L .40713 .50303 L p 0 0 1 r
F P
0 g
s
.40713 .50303 m .40133 .50036 L p .40592 .49969 L 0 0 1 r
F P
0 g
s
.40592 .49969 m .41977 .49767 L .40713 .50303 L 0 0 1 r
F
.4014 .49826 m .40862 .48675 L .42002 .48856 L p 1 0 0 r
F P
0 g
s
.40139 .49856 m .40477 .49652 L p .40592 .49969 L 0 1 0 r
F P
0 g
s
.39713 .48501 m .40862 .48675 L p .39878 .49192 L 1 0 0 r
F P
0 g
s
.39019 .48974 m .39666 .48577 L p .39801 .48968 L 0 1 0 r
F P
0 g
s
.39666 .48577 m .39713 .48501 L p .39873 .4917 L 1 0 0 r
F P
0 g
s
.39666 .48577 m .39873 .4917 L .39878 .49192 L 1 0 0 r
F
.39019 .48974 m .37896 .48094 L p .39651 .48534 L 0 1 0 r
F P
0 g
s
.39666 .48577 m .39019 .48974 L p .39651 .48534 L 0 1 0 r
F P
0 g
s
.40862 .48675 m .4014 .49826 L .40092 .49819 L p 1 0 0 r
F P
0 g
s
.39878 .49192 m .40862 .48675 L .40092 .49819 L 1 0 0 r
F
.38332 .49407 m .40092 .49818 L .40101 .49846 L 0 1 0 r
F
.39427 .50823 m .38293 .50304 L p .39588 .50115 L 0 0 1 r
F P
0 g
s
.39588 .50115 m .40101 .49846 L .39715 .50486 L 1 0 0 r
F
.4011 .49873 m .39719 .50497 L p .40101 .49846 L F P
0 g
s
.39719 .50497 m .39714 .50502 L p .39588 .50115 L 0 0 1 r
F P
0 g
s
.39714 .50502 m .39427 .50823 L p .39588 .50115 L 0 0 1 r
F P
0 g
s
.39719 .50497 m .39421 .50972 L p .39715 .50486 L 1 0 0 r
F P
0 g
s
.40101 .49846 m .39719 .50497 L .39715 .50486 L 1 0 0 r
F
.40133 .50036 m .39719 .50497 L p .39588 .50115 L 0 0 1 r
F P
0 g
s
.3946 .49727 m .40092 .49818 L p .39581 .50095 L 1 0 0 r
F P
0 g
s
.38332 .49407 m .39019 .48974 L .40092 .49818 L p 0 1 0 r
F P
0 g
s
.38293 .50304 m .38996 .49513 L .3946 .49727 L p 0 0 1 r
F P
0 g
s
.39588 .50115 m .40092 .49818 L .40101 .49846 L 1 0 0 r
F
.39581 .50095 m .40092 .49818 L .39588 .50115 L F
.3946 .49727 m .40133 .50036 L p .39588 .50115 L 0 0 1 r
F P
0 g
s
.38293 .50304 m .3946 .49727 L .39588 .50115 L 0 0 1 r
F
.38271 .50806 m .39581 .50095 L .39588 .50115 L 1 0 0 r
F
.38271 .50806 m .3899 .49658 L .3946 .49727 L p F P
0 g
s
.38271 .50806 m .3946 .49727 L .39581 .50095 L 1 0 0 r
F
.40092 .49818 m .4014 .49826 L p .40101 .49846 L F P
0 g
s
.40092 .49818 m .40139 .49856 L p .40101 .49846 L 0 1 0 r
F P
0 g
s
.40139 .49856 m .40092 .49818 L p .4036 .49314 L 0 1 0 r
F P
0 g
s
.40092 .49818 m .39019 .48974 L p .39878 .49192 L 0 1 0 r
F P
0 g
s
.40092 .49819 m .40092 .49818 L p .39878 .49192 L 1 0 0 r
F P
0 g
s
.39878 .49192 m .4036 .49314 L .40092 .49818 L 0 1 0 r
F
.40092 .49818 m .3946 .49727 L p .39878 .49192 L 1 0 0 r
F P
0 g
s
.40477 .49652 m .40139 .49856 L p .4036 .49314 L 0 1 0 r
F P
0 g
s
.40843 .49244 m .40133 .50036 L .3946 .49727 L p 0 0 1 r
F P
0 g
s
.3946 .49727 m .38996 .49513 L p .3937 .49459 L 0 0 1 r
F P
0 g
s
.3937 .49459 m .39878 .49192 L .3946 .49727 L 1 0 0 r
F
.3937 .49459 m .40843 .49244 L .3946 .49727 L 0 0 1 r
F
.3946 .49727 m .3899 .49658 L p .3937 .49459 L 1 0 0 r
F P
0 g
s
.39019 .48974 m .39802 .48968 L .39829 .49047 L 0 1 0 r
F
.39878 .49192 m .39829 .49047 L .39879 .49192 L F
.39019 .48974 m .39829 .49047 L .39878 .49192 L F
.39879 .49192 m .4024 .48965 L .4036 .49314 L F
.39802 .48968 m .4024 .48965 L .39879 .49192 L F
.38332 .49407 m .37651 .49855 L .36538 .49016 L p F P
0 g
s
.36538 .49016 m .37214 .48545 L .38332 .49407 L p 0 1 0 r
F P
0 g
s
.39019 .48974 m .38332 .49407 L .37214 .48545 L p 0 1 0 r
F P
0 g
s
.37214 .48545 m .37896 .48094 L .39019 .48974 L p 0 1 0 r
F P
0 g
s
.37651 .49855 m .36976 .50324 L .35865 .49513 L p 0 1 0 r
F P
0 g
s
.35865 .49513 m .36538 .49016 L .37651 .49855 L p 0 1 0 r
F P
0 g
s
.38996 .49513 m .38293 .50304 L .37154 .49783 L p 0 0 1 r
F P
0 g
s
.37154 .49783 m .37855 .48989 L .38996 .49513 L p 0 0 1 r
F P
0 g
s
.3937 .49459 m .39666 .48577 L .39878 .49192 L 1 0 0 r
F
.38996 .49513 m .39279 .49196 L p .3937 .49459 L 0 0 1 r
F P
0 g
s
.3899 .49658 m .39279 .49196 L p .3937 .49459 L 1 0 0 r
F P
0 g
s
.39279 .49196 m .39666 .48577 L p .3937 .49459 L 1 0 0 r
F P
0 g
s
.3937 .49459 m .39279 .49196 L .39371 .49459 L 0 0 1 r
F
.39711 .48549 m .4024 .48965 L p .39801 .48968 L 0 1 0 r
F P
0 g
s
.39666 .48577 m .39711 .48549 L p .39801 .48968 L 0 1 0 r
F P
0 g
s
.4024 .48965 m .40843 .49244 L p .4036 .49314 L 0 0 1 r
F P
0 g
s
.40843 .49244 m .41977 .49767 L p .40586 .4997 L 0 0 1 r
F P
0 g
s
.40586 .49969 m .40843 .49244 L .40586 .4997 L 0 0 1 r
F
.40477 .49652 m .40843 .49244 L p .40586 .4997 L F P
0 g
s
.43856 .47946 m .43133 .49049 L .42002 .48856 L p 1 0 0 r
F P
0 g
s
.42694 .48973 m .41977 .49767 L .40843 .49244 L p 0 0 1 r
F P
0 g
s
.42002 .48856 m .42725 .47727 L .43856 .47946 L p 1 0 0 r
F P
0 g
s
.42725 .47727 m .42002 .48856 L .40862 .48675 L p 1 0 0 r
F P
0 g
s
.40843 .49244 m .41559 .48446 L .42694 .48973 L p 0 0 1 r
F P
0 g
s
.4024 .48965 m .39711 .48549 L p .40133 .48655 L 0 1 0 r
F P
0 g
s
.40862 .48675 m .41586 .47527 L .42725 .47727 L p 1 0 0 r
F P
0 g
s
.41586 .47527 m .40862 .48675 L .39713 .48501 L p 1 0 0 r
F P
0 g
s
.41559 .48446 m .40843 .49244 L .40249 .48969 L p 0 0 1 r
F P
0 g
s
.40249 .48969 m .39705 .48718 L p .40133 .48655 L 0 0 1 r
F P
0 g
s
.40133 .48655 m .41559 .48446 L .40249 .48969 L 0 0 1 r
F
.39713 .48501 m .40438 .47339 L .41586 .47527 L p 1 0 0 r
F P
0 g
s
.39711 .48549 m .40023 .4836 L p .40133 .48655 L 0 1 0 r
F P
0 g
s
.39281 .47158 m .40438 .47339 L p .39422 .47873 L 1 0 0 r
F P
0 g
s
.38584 .47658 m .3921 .47273 L p .39335 .47628 L 0 1 0 r
F P
0 g
s
.3921 .47273 m .39281 .47158 L p .39419 .4786 L 1 0 0 r
F P
0 g
s
.3921 .47273 m .39419 .4786 L .39422 .47873 L 1 0 0 r
F
.38584 .47658 m .37456 .4677 L p .39186 .47208 L 0 1 0 r
F P
0 g
s
.3921 .47273 m .38584 .47658 L p .39186 .47208 L 0 1 0 r
F P
0 g
s
.40438 .47339 m .39713 .48501 L .39637 .48489 L p 1 0 0 r
F P
0 g
s
.39422 .47873 m .40438 .47339 L .39637 .48489 L 1 0 0 r
F
.37896 .48094 m .39636 .48489 L .39651 .48534 L 0 1 0 r
F
.38996 .49513 m .37855 .48989 L p .39141 .488 L 0 0 1 r
F P
0 g
s
.39141 .488 m .39651 .48534 L .39273 .49177 L 1 0 0 r
F
.39666 .48577 m .39279 .49196 L p .39651 .48534 L F P
0 g
s
.39279 .49196 m .39275 .492 L p .39141 .488 L 0 0 1 r
F P
0 g
s
.39275 .492 m .38996 .49513 L p .39141 .488 L 0 0 1 r
F P
0 g
s
.39279 .49196 m .3899 .49658 L p .39273 .49177 L 1 0 0 r
F P
0 g
s
.39651 .48534 m .39279 .49196 L .39273 .49177 L 1 0 0 r
F
.39705 .48718 m .39279 .49196 L p .39141 .488 L 0 0 1 r
F P
0 g
s
.39005 .48394 m .39636 .48489 L p .39131 .48768 L 1 0 0 r
F P
0 g
s
.37896 .48094 m .38584 .47658 L .39636 .48489 L p 0 1 0 r
F P
0 g
s
.37855 .48989 m .38561 .48189 L .39005 .48394 L p 0 0 1 r
F P
0 g
s
.39141 .488 m .39636 .48489 L .39651 .48534 L 1 0 0 r
F
.39131 .48768 m .39636 .48489 L .39141 .488 L F
.39005 .48394 m .39705 .48718 L p .39141 .488 L 0 0 1 r
F P
0 g
s
.37855 .48989 m .39005 .48394 L .39141 .488 L 0 0 1 r
F
.37832 .49486 m .39131 .48768 L .39141 .488 L 1 0 0 r
F
.37832 .49486 m .38555 .48327 L .39005 .48394 L p F P
0 g
s
.37832 .49486 m .39005 .48394 L .39131 .48768 L 1 0 0 r
F
.39636 .48489 m .39713 .48501 L p .39651 .48534 L F P
0 g
s
.39713 .48501 m .39666 .48577 L p .39651 .48534 L 1 0 0 r
F P
0 g
s
.39636 .48489 m .39711 .48549 L p .39651 .48534 L 0 1 0 r
F P
0 g
s
.39711 .48549 m .39636 .48489 L p .39894 .47994 L 0 1 0 r
F P
0 g
s
.39636 .48489 m .38584 .47658 L p .39422 .47873 L 0 1 0 r
F P
0 g
s
.39637 .48489 m .39636 .48489 L p .39422 .47873 L 1 0 0 r
F P
0 g
s
.39422 .47873 m .39894 .47994 L .39636 .48489 L 0 1 0 r
F
.39636 .48489 m .39005 .48394 L p .39422 .47873 L 1 0 0 r
F P
0 g
s
.40023 .4836 m .39711 .48549 L p .39894 .47994 L 0 1 0 r
F P
0 g
s
.39711 .48549 m .39666 .48577 L p .39651 .48534 L 0 1 0 r
F P
0 g
s
.40418 .47917 m .39705 .48718 L .39005 .48394 L p 0 0 1 r
F P
0 g
s
.39005 .48394 m .38561 .48189 L p .38917 .48137 L 0 0 1 r
F P
0 g
s
.38917 .48137 m .39422 .47873 L .39005 .48394 L 1 0 0 r
F
.38917 .48137 m .40418 .47917 L .39005 .48394 L 0 0 1 r
F
.39005 .48394 m .38555 .48327 L p .38917 .48137 L 1 0 0 r
F P
0 g
s
.38584 .47658 m .39335 .47628 L .39384 .47764 L 0 1 0 r
F
.39422 .47873 m .39384 .47764 L .39422 .47873 L F
.38584 .47658 m .39384 .47764 L .39422 .47873 L F
.39422 .47873 m .39759 .47611 L .39894 .47994 L F
.39335 .47628 m .39759 .47611 L .39422 .47873 L F
.37896 .48094 m .37214 .48545 L .36094 .47696 L p F P
0 g
s
.36094 .47696 m .36772 .47223 L .37896 .48094 L p 0 1 0 r
F P
0 g
s
.38584 .47658 m .37896 .48094 L .36772 .47223 L p 0 1 0 r
F P
0 g
s
.36772 .47223 m .37456 .4677 L .38584 .47658 L p 0 1 0 r
F P
0 g
s
.37214 .48545 m .36538 .49016 L .35421 .48196 L p 0 1 0 r
F P
0 g
s
.35421 .48196 m .36094 .47696 L .37214 .48545 L p 0 1 0 r
F P
0 g
s
.38561 .48189 m .37855 .48989 L .36709 .48462 L p 0 0 1 r
F P
0 g
s
.36709 .48462 m .37413 .47659 L .38561 .48189 L p 0 0 1 r
F P
0 g
s
.38917 .48137 m .3921 .47273 L .39422 .47873 L 1 0 0 r
F
.38561 .48189 m .38829 .47887 L p .38917 .48137 L 0 0 1 r
F P
0 g
s
.38555 .48327 m .38829 .47887 L p .38917 .48137 L 1 0 0 r
F P
0 g
s
.38829 .47887 m .3921 .47273 L p .38917 .48137 L 1 0 0 r
F P
0 g
s
.38917 .48137 m .38829 .47887 L .38918 .48137 L 0 0 1 r
F
.39278 .47231 m .39759 .47611 L p .39335 .47628 L 0 1 0 r
F P
0 g
s
.3921 .47273 m .39278 .47231 L p .39335 .47628 L 0 1 0 r
F P
0 g
s
.39759 .47611 m .40418 .47917 L p .39894 .47994 L 0 0 1 r
F P
0 g
s
.40418 .47917 m .41559 .48446 L p .40128 .48656 L 0 0 1 r
F P
0 g
s
.40128 .48654 m .40418 .47917 L .40128 .48656 L 0 0 1 r
F
.40023 .4836 m .40418 .47917 L p .40127 .48656 L F P
0 g
s
.43451 .46613 m .42725 .47727 L .41586 .47527 L p 1 0 0 r
F P
0 g
s
.42279 .47643 m .41559 .48446 L .40418 .47917 L p 0 0 1 r
F P
0 g
s
.41586 .47527 m .42313 .46388 L .43451 .46613 L p 1 0 0 r
F P
0 g
s
.42313 .46388 m .41586 .47527 L .40438 .47339 L p 1 0 0 r
F P
0 g
s
.40418 .47917 m .41136 .4711 L .42279 .47643 L p 0 0 1 r
F P
0 g
s
.39759 .47611 m .39278 .47231 L p .39659 .47328 L 0 1 0 r
F P
0 g
s
.40438 .47339 m .41166 .4618 L .42313 .46388 L p 1 0 0 r
F P
0 g
s
.41166 .4618 m .40438 .47339 L .39281 .47158 L p 1 0 0 r
F P
0 g
s
.41136 .4711 m .40418 .47917 L .39768 .47615 L p 0 0 1 r
F P
0 g
s
.39768 .47615 m .39272 .47385 L p .39659 .47328 L 0 0 1 r
F P
0 g
s
.39659 .47328 m .41136 .4711 L .39768 .47615 L 0 0 1 r
F
.39278 .47231 m .39558 .47061 L p .39659 .47328 L 0 1 0 r
F P
0 g
s
.39281 .47158 m .4001 .45985 L .41166 .4618 L p 1 0 0 r
F P
0 g
s
.38845 .45796 m .4001 .45985 L p .3895 .4654 L 1 0 0 r
F P
0 g
s
.38145 .46332 m .38742 .45963 L p .38853 .46271 L 0 1 0 r
F P
0 g
s
.38742 .45963 m .38845 .45796 L p .38949 .46533 L 1 0 0 r
F P
0 g
s
.38742 .45963 m .38949 .46533 L .3895 .4654 L 1 0 0 r
F
.38145 .46332 m .3701 .45435 L p .38707 .45868 L 0 1 0 r
F P
0 g
s
.38742 .45963 m .38145 .46332 L p .38707 .45868 L 0 1 0 r
F P
0 g
s
.4001 .45985 m .39281 .47158 L .39164 .4714 L p 1 0 0 r
F P
0 g
s
.39164 .4714 m .39163 .47139 L p .3895 .4654 L 1 0 0 r
F P
0 g
s
.3895 .4654 m .4001 .45985 L .39164 .4714 L 1 0 0 r
F
.37456 .4677 m .39163 .47139 L .39186 .47208 L 0 1 0 r
F
.38561 .48189 m .37413 .47659 L p .38681 .47472 L 0 0 1 r
F P
0 g
s
.38681 .47472 m .39186 .47208 L .38819 .47859 L 1 0 0 r
F
.3921 .47273 m .38829 .47887 L p .39186 .47208 L F P
0 g
s
.38829 .47887 m .38825 .47891 L p .38681 .47472 L 0 0 1 r
F P
0 g
s
.38825 .47891 m .38561 .48189 L p .38681 .47472 L 0 0 1 r
F P
0 g
s
.38829 .47887 m .38555 .48327 L p .38819 .47859 L 1 0 0 r
F P
0 g
s
.39186 .47208 m .38829 .47887 L .38819 .47859 L 1 0 0 r
F
.39272 .47385 m .38829 .47887 L p .38681 .47472 L 0 0 1 r
F P
0 g
s
.38533 .47042 m .39163 .47139 L p .38664 .47423 L 1 0 0 r
F P
0 g
s
.37456 .4677 m .38145 .46332 L .39163 .47139 L p 0 1 0 r
F P
0 g
s
.37413 .47659 m .38121 .46851 L .38533 .47042 L p 0 0 1 r
F P
0 g
s
.38681 .47472 m .39163 .47139 L .39186 .47208 L 1 0 0 r
F
.38664 .47423 m .39163 .47139 L .38681 .47472 L F
.38533 .47042 m .39272 .47385 L p .38681 .47472 L 0 0 1 r
F P
0 g
s
.37413 .47659 m .38533 .47042 L .38681 .47472 L 0 0 1 r
F
.37389 .48147 m .38664 .47423 L .38681 .47472 L 1 0 0 r
F
.37389 .48147 m .38116 .46977 L .38533 .47042 L p F P
0 g
s
.37389 .48147 m .38533 .47042 L .38664 .47423 L 1 0 0 r
F
.39163 .47139 m .39281 .47158 L p .39186 .47208 L F P
0 g
s
.39281 .47158 m .3921 .47273 L p .39186 .47208 L 1 0 0 r
F P
0 g
s
.39163 .47139 m .39278 .47231 L p .39186 .47208 L 0 1 0 r
F P
0 g
s
.39278 .47231 m .39163 .47139 L p .39414 .46659 L 0 1 0 r
F P
0 g
s
.39163 .47139 m .38145 .46332 L p .3895 .4654 L 0 1 0 r
F P
0 g
s
.3895 .4654 m .39414 .46659 L .39163 .47139 L 0 1 0 r
F
.39163 .47139 m .38533 .47042 L p .3895 .4654 L 1 0 0 r
F P
0 g
s
.39558 .47061 m .39278 .47231 L p .39414 .46659 L 0 1 0 r
F P
0 g
s
.39278 .47231 m .3921 .47273 L p .39186 .47208 L 0 1 0 r
F P
0 g
s
.39988 .46575 m .39272 .47385 L .38533 .47042 L p 0 0 1 r
F P
0 g
s
.38533 .47042 m .38121 .46851 L p .38449 .46802 L 0 0 1 r
F P
0 g
s
.38449 .46802 m .3895 .4654 L .38533 .47042 L 1 0 0 r
F
.38449 .46802 m .39988 .46575 L .38533 .47042 L 0 0 1 r
F
.38533 .47042 m .38116 .46977 L p .38449 .46802 L 1 0 0 r
F P
0 g
s
.38145 .46332 m .38853 .46271 L .38928 .46477 L 0 1 0 r
F
.3895 .4654 m .38928 .46477 L .38951 .4654 L F
.38145 .46332 m .38928 .46477 L .3895 .4654 L F
.38951 .4654 m .3926 .46235 L .39414 .46659 L F
.38853 .46271 m .3926 .46235 L .38951 .4654 L F
.37456 .4677 m .36772 .47223 L .35646 .46366 L p F P
0 g
s
.35646 .46366 m .36325 .4589 L .37456 .4677 L p 0 1 0 r
F P
0 g
s
.38145 .46332 m .37456 .4677 L .36325 .4589 L p 0 1 0 r
F P
0 g
s
.36325 .4589 m .3701 .45435 L .38145 .46332 L p 0 1 0 r
F P
0 g
s
.36772 .47223 m .36094 .47696 L .34971 .46868 L p 0 1 0 r
F P
0 g
s
.34971 .46868 m .35646 .46366 L .36772 .47223 L p 0 1 0 r
F P
0 g
s
.38121 .46851 m .37413 .47659 L .36259 .47126 L p 0 0 1 r
F P
0 g
s
.36259 .47126 m .36965 .46314 L .38121 .46851 L p 0 0 1 r
F P
0 g
s
.38449 .46802 m .38742 .45963 L .3895 .4654 L 1 0 0 r
F
.38121 .46851 m .38366 .46571 L p .38449 .46802 L 0 0 1 r
F P
0 g
s
.38116 .46977 m .38366 .46571 L p .38449 .46802 L 1 0 0 r
F P
0 g
s
.38366 .46571 m .38742 .45963 L p .38449 .46802 L 1 0 0 r
F P
0 g
s
.38449 .46802 m .38366 .46571 L .3845 .46802 L 0 0 1 r
F
.3884 .45902 m .3926 .46235 L p .38853 .46271 L 0 1 0 r
F P
0 g
s
.38742 .45963 m .3884 .45902 L p .38853 .46271 L 0 1 0 r
F P
0 g
s
.3926 .46235 m .39988 .46575 L p .39413 .4666 L 0 0 1 r
F P
0 g
s
.39988 .46575 m .41136 .4711 L p .39656 .47328 L 0 0 1 r
F P
0 g
s
.39655 .47326 m .39988 .46575 L .39656 .47328 L 0 0 1 r
F
.39558 .47061 m .39988 .46575 L p .39654 .47328 L F P
0 g
s
.43042 .45263 m .42313 .46388 L .41166 .4618 L p 1 0 0 r
F P
0 g
s
.41859 .46298 m .41136 .4711 L .39988 .46575 L p 0 0 1 r
F P
0 g
s
.41166 .4618 m .41896 .4503 L .43042 .45263 L p 1 0 0 r
F P
0 g
s
.41896 .4503 m .41166 .4618 L .4001 .45985 L p 1 0 0 r
F P
0 g
s
.39988 .46575 m .40709 .45759 L .41859 .46298 L p 0 0 1 r
F P
0 g
s
.3926 .46235 m .3884 .45902 L p .39171 .45987 L 0 1 0 r
F P
0 g
s
.4001 .45985 m .40741 .44815 L .41896 .4503 L p 1 0 0 r
F P
0 g
s
.40741 .44815 m .4001 .45985 L .38845 .45796 L p 1 0 0 r
F P
0 g
s
.40709 .45759 m .39988 .46575 L .39269 .46239 L p 0 0 1 r
F P
0 g
s
.39269 .46239 m .38835 .46037 L p .39171 .45987 L 0 0 1 r
F P
0 g
s
.39171 .45987 m .40709 .45759 L .39269 .46239 L 0 0 1 r
F
.3884 .45902 m .39081 .45756 L p .39171 .45987 L 0 1 0 r
F P
0 g
s
.38845 .45796 m .39577 .44612 L .40741 .44815 L p 1 0 0 r
F P
0 g
s
.38404 .44416 m .39577 .44612 L p .38464 .45194 L 1 0 0 r
F P
0 g
s
.377 .44995 m .38262 .44647 L p .38354 .44896 L 0 1 0 r
F P
0 g
s
.38262 .44647 m .38404 .44416 L p .38464 .4519 L 1 0 0 r
F P
0 g
s
.38262 .44647 m .38464 .4519 L .38464 .45194 L 1 0 0 r
F
.377 .44995 m .36558 .44089 L p .38213 .44515 L 0 1 0 r
F P
0 g
s
.38262 .44647 m .377 .44995 L p .38213 .44515 L 0 1 0 r
F P
0 g
s
.39577 .44612 m .38845 .45796 L .38674 .45769 L p 1 0 0 r
F P
0 g
s
.38674 .45769 m .38672 .45769 L p .38464 .45194 L 1 0 0 r
F P
0 g
s
.38464 .45194 m .39577 .44612 L .38674 .45769 L 1 0 0 r
F
.38845 .45796 m .38742 .45963 L p .38707 .45868 L F P
0 g
s
.3701 .45435 m .38672 .45769 L .38707 .45868 L 0 1 0 r
F
.38121 .46851 m .36965 .46314 L p .38206 .4613 L 0 0 1 r
F P
0 g
s
.38206 .4613 m .38707 .45868 L .38352 .46533 L 1 0 0 r
F
.38742 .45963 m .38366 .46571 L p .38707 .45868 L F P
0 g
s
.38366 .46571 m .38362 .46575 L p .38206 .4613 L 0 0 1 r
F P
0 g
s
.38362 .46575 m .38121 .46851 L p .38206 .4613 L 0 0 1 r
F P
0 g
s
.38366 .46571 m .38116 .46977 L p .38352 .46533 L 1 0 0 r
F P
0 g
s
.38707 .45868 m .38366 .46571 L .38352 .46533 L 1 0 0 r
F
.38835 .46037 m .38366 .46571 L p .38206 .4613 L 0 0 1 r
F P
0 g
s
.38044 .45668 m .38672 .45769 L p .38181 .46059 L 1 0 0 r
F P
0 g
s
.3701 .45435 m .377 .44995 L .38672 .45769 L p 0 1 0 r
F P
0 g
s
.36965 .46314 m .37676 .45496 L .38044 .45668 L p 0 0 1 r
F P
0 g
s
.38206 .4613 m .38672 .45769 L .38707 .45868 L 1 0 0 r
F
.38181 .46059 m .38672 .45769 L .38206 .4613 L F
.38044 .45668 m .38835 .46037 L p .38206 .4613 L 0 0 1 r
F P
0 g
s
.36965 .46314 m .38044 .45668 L .38206 .4613 L 0 0 1 r
F
.36941 .46791 m .38181 .46059 L .38206 .4613 L 1 0 0 r
F
.36941 .46791 m .37671 .45608 L .38044 .45668 L p F P
0 g
s
.36941 .46791 m .38044 .45668 L .38181 .46059 L 1 0 0 r
F
.38672 .45769 m .38845 .45796 L p .38707 .45868 L F P
0 g
s
.38672 .45769 m .3884 .45902 L p .38707 .45868 L 0 1 0 r
F P
0 g
s
.3884 .45902 m .38672 .45769 L p .38918 .45312 L 0 1 0 r
F P
0 g
s
.38672 .45769 m .377 .44995 L p .38464 .45194 L 0 1 0 r
F P
0 g
s
.38464 .45194 m .38918 .45312 L .38672 .45769 L 0 1 0 r
F
.38672 .45769 m .38044 .45668 L p .38464 .45194 L 1 0 0 r
F P
0 g
s
.39081 .45756 m .3884 .45902 L p .38918 .45312 L 0 1 0 r
F P
0 g
s
.3884 .45902 m .38742 .45963 L p .38707 .45868 L 0 1 0 r
F P
0 g
s
.39553 .45217 m .38835 .46037 L .38044 .45668 L p 0 0 1 r
F P
0 g
s
.38044 .45668 m .37676 .45496 L p .37967 .45453 L 0 0 1 r
F P
0 g
s
.37967 .45453 m .38464 .45194 L .38044 .45668 L 1 0 0 r
F
.37967 .45453 m .39553 .45217 L .38044 .45668 L 0 0 1 r
F
.38044 .45668 m .37671 .45608 L p .37967 .45453 L 1 0 0 r
F P
0 g
s
.377 .44995 m .38354 .44896 L .3846 .45183 L 0 1 0 r
F
.38464 .45194 m .3846 .45183 L .38464 .45194 L F
.377 .44995 m .3846 .45183 L .38464 .45194 L F
.38464 .45194 m .38742 .44837 L .38918 .45312 L F
.38354 .44896 m .38742 .44837 L .38464 .45194 L F
.3701 .45435 m .36325 .4589 L .35192 .45024 L p F P
0 g
s
.35192 .45024 m .35872 .44546 L .3701 .45435 L p 0 1 0 r
F P
0 g
s
.377 .44995 m .3701 .45435 L .35872 .44546 L p 0 1 0 r
F P
0 g
s
.35872 .44546 m .36558 .44089 L .377 .44995 L p 0 1 0 r
F P
0 g
s
.36325 .4589 m .35646 .46366 L .34516 .45529 L p 0 1 0 r
F P
0 g
s
.34516 .45529 m .35192 .45024 L .36325 .4589 L p 0 1 0 r
F P
0 g
s
.37676 .45496 m .36965 .46314 L .35804 .45775 L p 0 0 1 r
F P
0 g
s
.35804 .45775 m .36513 .44954 L .37676 .45496 L p 0 0 1 r
F P
0 g
s
.37967 .45453 m .38262 .44647 L .38464 .45194 L 1 0 0 r
F
.37676 .45496 m .37892 .45249 L p .37967 .45453 L 0 0 1 r
F P
0 g
s
.37671 .45608 m .37892 .45249 L p .37967 .45453 L 1 0 0 r
F P
0 g
s
.37892 .45249 m .38262 .44647 L p .37967 .45453 L 1 0 0 r
F P
0 g
s
.37967 .45453 m .37892 .45249 L .37967 .45453 L 0 0 1 r
F
.38397 .44563 m .38742 .44837 L p .38354 .44896 L 0 1 0 r
F P
0 g
s
.38262 .44647 m .38397 .44563 L p .38354 .44896 L 0 1 0 r
F P
0 g
s
.38742 .44837 m .39553 .45217 L p .38917 .45312 L 0 0 1 r
F P
0 g
s
.39553 .45217 m .40709 .45759 L p .39169 .45987 L 0 0 1 r
F P
0 g
s
.39168 .45985 m .39553 .45217 L .39169 .45987 L 0 0 1 r
F
.39081 .45756 m .39553 .45217 L p .39166 .45988 L F P
0 g
s
.42628 .43895 m .41896 .4503 L .40741 .44815 L p 1 0 0 r
F P
0 g
s
.41434 .44938 m .40709 .45759 L .39553 .45217 L p 0 0 1 r
F P
0 g
s
.40741 .44815 m .41474 .43654 L .42628 .43895 L p 1 0 0 r
F P
0 g
s
.41474 .43654 m .40741 .44815 L .39577 .44612 L p 1 0 0 r
F P
0 g
s
.39553 .45217 m .40276 .44392 L .41434 .44938 L p 0 0 1 r
F P
0 g
s
.38742 .44837 m .38397 .44563 L p .38667 .44632 L 0 1 0 r
F P
0 g
s
.39577 .44612 m .40311 .43431 L .41474 .43654 L p 1 0 0 r
F P
0 g
s
.40311 .43431 m .39577 .44612 L .38404 .44416 L p 1 0 0 r
F P
0 g
s
.40276 .44392 m .39553 .45217 L .3875 .44841 L p 0 0 1 r
F P
0 g
s
.3875 .44841 m .38392 .44673 L p .38667 .44632 L 0 0 1 r
F P
0 g
s
.38667 .44632 m .40276 .44392 L .3875 .44841 L 0 0 1 r
F
.38397 .44563 m .38592 .44443 L p .38667 .44632 L 0 1 0 r
F P
0 g
s
.38404 .44416 m .39139 .4322 L .40311 .43431 L p 1 0 0 r
F P
0 g
s
.37958 .43016 m .39139 .4322 L p .37963 .43834 L 1 0 0 r
F P
0 g
s
.37839 .43505 m .3777 .43323 L .37839 .43505 L 0 1 0 r
F
.3725 .43647 m .3777 .43323 L p .37839 .43505 L F P
0 g
s
.3777 .43323 m .37958 .43016 L p .37963 .43832 L 1 0 0 r
F P
0 g
s
.3777 .43323 m .37963 .43832 L .37963 .43834 L 1 0 0 r
F
.3725 .43647 m .36102 .42732 L p .37704 .43148 L 0 1 0 r
F P
0 g
s
.37958 .43016 m .3777 .43323 L p .37704 .43148 L 1 0 0 r
F P
0 g
s
.37949 .43212 m .3777 .43323 L p .37704 .43148 L 0 1 0 r
F P
0 g
s
.3777 .43323 m .3725 .43647 L p .37704 .43148 L 0 1 0 r
F P
0 g
s
.37963 .43834 m .39139 .4322 L .38165 .44376 L 1 0 0 r
F
.37963 .43834 m .38206 .43417 L .38408 .4395 L 0 1 0 r
F
.3725 .43647 m .37841 .43505 L .37963 .43834 L F
.37841 .43505 m .38206 .43417 L .37963 .43834 L F
.39139 .4322 m .38404 .44416 L .38165 .44376 L p 1 0 0 r
F P
0 g
s
.38165 .44376 m .38163 .44376 L p .37963 .43834 L 1 0 0 r
F P
0 g
s
.38404 .44416 m .38262 .44647 L p .38213 .44515 L 1 0 0 r
F P
0 g
s
.36558 .44089 m .38163 .44376 L .38213 .44515 L 0 1 0 r
F
.37676 .45496 m .36513 .44954 L p .37717 .44774 L 0 0 1 r
F P
0 g
s
.37717 .44774 m .38213 .44515 L .37874 .45199 L 1 0 0 r
F
.38262 .44647 m .37892 .45249 L p .38213 .44515 L F P
0 g
s
.37892 .45249 m .37889 .45253 L p .37717 .44774 L 0 0 1 r
F P
0 g
s
.37889 .45253 m .37676 .45496 L p .37717 .44774 L 0 0 1 r
F P
0 g
s
.37892 .45249 m .37671 .45608 L p .37874 .45199 L 1 0 0 r
F P
0 g
s
.38213 .44515 m .37892 .45249 L .37874 .45199 L 1 0 0 r
F
.38392 .44673 m .37892 .45249 L p .37717 .44774 L 0 0 1 r
F P
0 g
s
.37536 .44272 m .38163 .44376 L p .37681 .44675 L 1 0 0 r
F P
0 g
s
.36558 .44089 m .3725 .43647 L .38163 .44376 L p 0 1 0 r
F P
0 g
s
.36513 .44954 m .37226 .44127 L .37536 .44272 L p 0 0 1 r
F P
0 g
s
.37717 .44774 m .38163 .44376 L .38213 .44515 L 1 0 0 r
F
.37681 .44675 m .38163 .44376 L .37717 .44774 L F
.38397 .44563 m .38262 .44647 L p .38213 .44515 L 0 1 0 r
F P
0 g
s
.37536 .44272 m .38392 .44673 L p .37717 .44774 L 0 0 1 r
F P
0 g
s
.36513 .44954 m .37536 .44272 L .37717 .44774 L 0 0 1 r
F
.36488 .45415 m .37681 .44675 L .37717 .44774 L 1 0 0 r
F
.36488 .45415 m .37222 .4422 L .37536 .44272 L p F P
0 g
s
.36488 .45415 m .37536 .44272 L .37681 .44675 L 1 0 0 r
F
.38163 .44376 m .38404 .44416 L p .38213 .44515 L F P
0 g
s
.38163 .44376 m .38397 .44563 L p .38213 .44515 L 0 1 0 r
F P
0 g
s
.38397 .44563 m .38163 .44376 L p .38408 .4395 L 0 1 0 r
F P
0 g
s
.38163 .44376 m .3725 .43647 L p .37963 .43834 L 0 1 0 r
F P
0 g
s
.37963 .43834 m .38408 .4395 L .38163 .44376 L 0 1 0 r
F
.38163 .44376 m .37536 .44272 L p .37963 .43834 L 1 0 0 r
F P
0 g
s
.38592 .44443 m .38397 .44563 L p .38408 .4395 L 0 1 0 r
F P
0 g
s
.39113 .43845 m .38392 .44673 L .37536 .44272 L p 0 0 1 r
F P
0 g
s
.37536 .44272 m .37226 .44127 L p .37471 .4409 L 0 0 1 r
F P
0 g
s
.37471 .4409 m .37963 .43834 L .37536 .44272 L 1 0 0 r
F
.37471 .4409 m .39113 .43845 L .37536 .44272 L 0 0 1 r
F
.37536 .44272 m .37222 .4422 L p .37471 .4409 L 1 0 0 r
F P
0 g
s
.36558 .44089 m .35872 .44546 L .34733 .4367 L p 0 1 0 r
F P
0 g
s
.34733 .4367 m .35415 .43191 L .36558 .44089 L p 0 1 0 r
F P
0 g
s
.3725 .43647 m .36558 .44089 L .35415 .43191 L p 0 1 0 r
F P
0 g
s
.35415 .43191 m .36102 .42732 L .3725 .43647 L p 0 1 0 r
F P
0 g
s
.35872 .44546 m .35192 .45024 L .34056 .44177 L p 0 1 0 r
F P
0 g
s
.34056 .44177 m .34733 .4367 L .35872 .44546 L p 0 1 0 r
F P
0 g
s
.37226 .44127 m .36513 .44954 L .35344 .44409 L p 0 0 1 r
F P
0 g
s
.36102 .42732 m .36795 .42287 L .37634 .4296 L p 0 1 0 r
F P
0 g
s
.36102 .42732 m .37634 .4296 L .37704 .43149 L 0 1 0 r
F
.35344 .44409 m .36055 .43578 L .37226 .44127 L p 0 0 1 r
F P
0 g
s
.37226 .44127 m .36055 .43578 L p .37213 .43404 L 0 0 1 r
F P
0 g
s
.37222 .4422 m .36031 .4402 L p .37213 .43404 L 1 0 0 r
F P
0 g
s
.37213 .43404 m .37704 .43149 L .37384 .4386 L 1 0 0 r
F
.37406 .43919 m .37403 .43922 L p .37213 .43404 L 0 0 1 r
F P
0 g
s
.37403 .43922 m .37226 .44127 L p .37213 .43404 L 0 0 1 r
F P
0 g
s
.37471 .4409 m .3777 .43323 L .37963 .43834 L 1 0 0 r
F
.3747 .4409 m .37471 .4409 L .37471 .4409 L 0 0 1 r
F
.37226 .44127 m .37406 .43919 L p .3747 .4409 L F P
0 g
s
.37222 .4422 m .37406 .43919 L p .37471 .4409 L 1 0 0 r
F P
0 g
s
.37406 .43919 m .3777 .43323 L p .37471 .4409 L 1 0 0 r
F P
0 g
s
.37949 .43212 m .38206 .43417 L p .37839 .43505 L 0 1 0 r
F P
0 g
s
.3777 .43323 m .37949 .43212 L p .37839 .43505 L 0 1 0 r
F P
0 g
s
.38206 .43417 m .39113 .43845 L p .38405 .43951 L 0 0 1 r
F P
0 g
s
.39113 .43845 m .40276 .44392 L p .38667 .44632 L 0 0 1 r
F P
0 g
s
.38665 .44629 m .39113 .43845 L .38667 .44632 L 0 0 1 r
F
.38592 .44443 m .39113 .43845 L p .38663 .44633 L F P
0 g
s
.42209 .42509 m .41474 .43654 L .40311 .43431 L p 1 0 0 r
F P
0 g
s
.41004 .43562 m .40276 .44392 L .39113 .43845 L p 0 0 1 r
F P
0 g
s
.40311 .43431 m .41048 .4226 L .42209 .42509 L p 1 0 0 r
F P
0 g
s
.41048 .4226 m .40311 .43431 L .39139 .4322 L p 1 0 0 r
F P
0 g
s
.39113 .43845 m .39839 .4301 L .41004 .43562 L p 0 0 1 r
F P
0 g
s
.38206 .43417 m .37949 .43212 L p .38148 .43264 L 0 1 0 r
F P
0 g
s
.39139 .4322 m .39877 .42028 L .41048 .4226 L p 1 0 0 r
F P
0 g
s
.39877 .42028 m .39139 .4322 L .37958 .43016 L p 1 0 0 r
F P
0 g
s
.39839 .4301 m .39113 .43845 L .38211 .4342 L p 0 0 1 r
F P
0 g
s
.38211 .4342 m .37945 .43294 L p .38148 .43264 L 0 0 1 r
F P
0 g
s
.38148 .43264 m .39839 .4301 L .38211 .4342 L 0 0 1 r
F
.37949 .43212 m .38092 .43124 L p .38148 .43264 L 0 1 0 r
F P
0 g
s
.37958 .43016 m .38697 .41809 L .39877 .42028 L p 1 0 0 r
F P
0 g
s
.36795 .42287 m .35639 .41363 L p .37179 .41767 L 0 1 0 r
F P
0 g
s
.37507 .41597 m .38697 .41809 L p .37447 .4246 L 1 0 0 r
F P
0 g
s
.37266 .41993 m .37507 .41597 L p .37447 .4246 L 1 0 0 r
F P
0 g
s
.37179 .41767 m .37206 .41838 L .36795 .42287 L 0 1 0 r
F
.37266 .41993 m .37266 .41993 L p .37206 .41838 L F P
0 g
s
.37266 .41993 m .36795 .42287 L p .37206 .41838 L 0 1 0 r
F P
0 g
s
.34268 .42305 m .34951 .41824 L .36102 .42732 L p 0 1 0 r
F P
0 g
s
.36795 .42287 m .36102 .42732 L .34951 .41824 L p 0 1 0 r
F P
0 g
s
.34951 .41824 m .35639 .41363 L .36795 .42287 L p 0 1 0 r
F P
0 g
s
.35639 .41363 m .36334 .40917 L .37088 .41523 L p 0 1 0 r
F P
0 g
s
.37088 .41523 m .37507 .41597 L p .37181 .41766 L 1 0 0 r
F P
0 g
s
.37179 .41768 m .37088 .41523 L .37181 .41766 L 1 0 0 r
F
.37507 .41597 m .37266 .41993 L p .37179 .41768 L F P
0 g
s
.39438 .40607 m .38697 .41809 L .37507 .41597 L p 1 0 0 r
F P
0 g
s
.37507 .41597 m .38249 .40379 L .39438 .40607 L p 1 0 0 r
F P
0 g
s
.37088 .41523 m .36334 .40917 L p .36915 .41071 L 0 1 0 r
F P
0 g
s
.38249 .40379 m .37507 .41597 L .37091 .41524 L p 1 0 0 r
F P
0 g
s
.3709 .41522 m .38249 .40379 L .37091 .41524 L 1 0 0 r
F
.36915 .41071 m .38249 .40379 L .37088 .41523 L F
.40617 .40847 m .39877 .42028 L .38697 .41809 L p F P
0 g
s
.38697 .41809 m .39438 .40607 L .40617 .40847 L p 1 0 0 r
F P
0 g
s
.38218 .41052 m .39397 .41612 L p .37617 .41881 L 0 0 1 r
F P
0 g
s
.38668 .42456 m .39839 .4301 L p .38149 .43264 L 0 0 1 r
F P
0 g
s
.38148 .4326 m .38668 .42456 L .38149 .43264 L 0 0 1 r
F
.38092 .43124 m .38668 .42456 L p .38145 .43264 L F P
0 g
s
.38697 .41809 m .37958 .43016 L .37638 .42961 L p 1 0 0 r
F P
0 g
s
.37638 .42961 m .37635 .42961 L p .37447 .4246 L 1 0 0 r
F P
0 g
s
.37447 .4246 m .38697 .41809 L .37638 .42961 L 1 0 0 r
F
.37635 .42961 m .37958 .43016 L p .37704 .43149 L F P
0 g
s
.37949 .43212 m .37635 .42961 L p .37882 .42575 L 0 1 0 r
F P
0 g
s
.37635 .42961 m .36795 .42287 L p .37447 .4246 L 0 1 0 r
F P
0 g
s
.37447 .4246 m .37882 .42575 L .37635 .42961 L 0 1 0 r
F
.36055 .43578 m .36771 .42742 L .37011 .42855 L p 0 0 1 r
F P
0 g
s
.37704 .43149 m .37704 .43149 L .37384 .4386 L 1 0 0 r
F
.37704 .43149 m .37384 .4386 L .37384 .4386 L F
.37011 .42855 m .37635 .42961 L p .37164 .43272 L F P
0 g
s
.37634 .4296 m .37635 .42961 L p .37704 .43149 L 0 1 0 r
F P
0 g
s
.37213 .43404 m .37635 .42961 L .37704 .43149 L 1 0 0 r
F
.36055 .43578 m .37011 .42855 L .37213 .43404 L 0 0 1 r
F
.36031 .4402 m .37164 .43272 L .37213 .43404 L 1 0 0 r
F
.37164 .43272 m .37635 .42961 L .37213 .43404 L F
.37213 .43404 m .37011 .42855 L .37213 .43404 L 0 0 1 r
F
.3777 .43323 m .37222 .4422 L p .37704 .43148 L 1 0 0 r
F P
0 g
s
.37011 .42855 m .37945 .43294 L p .37213 .43404 L 0 0 1 r
F P
0 g
s
.37635 .42961 m .37011 .42855 L p .37447 .4246 L 1 0 0 r
F P
0 g
s
.36959 .42713 m .37447 .4246 L .37011 .42855 L 1 0 0 r
F
.38092 .43124 m .37949 .43212 L p .37882 .42575 L 0 1 0 r
F P
0 g
s
.37635 .42961 m .37949 .43212 L p .37704 .43149 L 0 1 0 r
F P
0 g
s
.37704 .43149 m .37704 .43148 L .37704 .43149 L 1 0 0 r
F
.38668 .42456 m .37945 .43294 L .37013 .42855 L p 0 0 1 r
F P
0 g
s
.37013 .42855 m .36771 .42742 L p .36958 .42714 L 0 0 1 r
F P
0 g
s
.36958 .42714 m .38668 .42456 L .37013 .42855 L 0 0 1 r
F
.35415 .43191 m .34733 .4367 L .3359 .42814 L p 0 1 0 r
F P
0 g
s
.3359 .42814 m .34268 .42305 L .35415 .43191 L p 0 1 0 r
F P
0 g
s
.36102 .42732 m .35415 .43191 L .34268 .42305 L p 0 1 0 r
F P
0 g
s
.36771 .42742 m .36055 .43578 L .34878 .43027 L p 0 0 1 r
F P
0 g
s
.34878 .43027 m .35592 .42186 L .36771 .42742 L p 0 0 1 r
F P
0 g
s
.36795 .42287 m .37309 .42098 L .37447 .4246 L 0 1 0 r
F
.36795 .42287 m .37266 .41993 L p .37307 .42099 L F P
0 g
s
.36693 .4202 m .37179 .41768 L .36884 .42518 L 1 0 0 r
F
.37309 .42098 m .37648 .41974 L .37447 .4246 L 0 1 0 r
F
.36771 .42742 m .35592 .42186 L p .36693 .4202 L 0 0 1 r
F P
0 g
s
.37179 .41767 m .37179 .41768 L .37266 .41993 L 0 1 0 r
F
.37266 .41993 m .36908 .42582 L p .37179 .41768 L 1 0 0 r
F P
0 g
s
.36908 .42582 m .36905 .42585 L p .36693 .4202 L 0 0 1 r
F P
0 g
s
.36905 .42585 m .36771 .42742 L p .36693 .4202 L 0 0 1 r
F P
0 g
s
.37447 .4246 m .37648 .41974 L .37882 .42575 L 0 1 0 r
F
.36959 .42713 m .37266 .41993 L .37447 .4246 L 1 0 0 r
F
.37495 .4185 m .37648 .41974 L p .37307 .42099 L 0 1 0 r
F P
0 g
s
.37492 .419 m .38668 .42456 L p .36959 .42713 L 0 0 1 r
F P
0 g
s
.36771 .42742 m .36908 .42582 L p .36959 .42713 L 0 0 1 r
F P
0 g
s
.36908 .42582 m .37266 .41993 L p .36959 .42713 L 1 0 0 r
F P
0 g
s
.36908 .42582 m .37492 .419 L p .36959 .42713 L 0 0 1 r
F P
0 g
s
.36767 .42813 m .36908 .42582 L p .36959 .42713 L 1 0 0 r
F P
0 g
s
.36908 .42582 m .36767 .42813 L p .36884 .42518 L 1 0 0 r
F P
0 g
s
.37179 .41768 m .36908 .42582 L .36884 .42518 L 1 0 0 r
F
.37495 .4185 m .37266 .41993 L p .37179 .41768 L 0 1 0 r
F P
0 g
s
.37266 .41993 m .37495 .4185 L p .37307 .42099 L 0 1 0 r
F P
0 g
s
.37492 .419 m .36908 .42582 L p .36693 .4202 L 0 0 1 r
F P
0 g
s
.35639 .41363 m .37088 .41523 L .37179 .41768 L 0 1 0 r
F
.36693 .4202 m .37085 .41523 L .37179 .41768 L 1 0 0 r
F
.36629 .41849 m .37085 .41523 L .36693 .4202 L F
.35592 .42186 m .36311 .41341 L .36466 .41414 L p 0 0 1 r
F P
0 g
s
.37088 .41523 m .37495 .4185 L p .37179 .41768 L 0 1 0 r
F P
0 g
s
.37085 .41523 m .37088 .41523 L p .37179 .41768 L 1 0 0 r
F P
0 g
s
.35592 .42186 m .36466 .41414 L .36693 .4202 L 0 0 1 r
F
.35568 .42606 m .36308 .41386 L .36466 .41414 L p 1 0 0 r
F P
0 g
s
.36466 .41414 m .37085 .41523 L p .36629 .41849 L 1 0 0 r
F P
0 g
s
.36693 .4202 m .36466 .41414 L .36693 .4202 L 0 0 1 r
F
.35568 .42606 m .36466 .41414 L .36629 .41849 L 1 0 0 r
F
.36466 .41414 m .37492 .419 L p .36693 .4202 L 0 0 1 r
F P
0 g
s
.36915 .41071 m .36915 .41071 L .37088 .41523 L 0 1 0 r
F
.37088 .41523 m .36466 .41414 L p .36915 .41071 L 1 0 0 r
F P
0 g
s
.36431 .41322 m .36915 .41071 L .36466 .41414 L 1 0 0 r
F
.37648 .41974 m .37495 .4185 L p .37613 .41881 L 0 1 0 r
F P
0 g
s
.37091 .41524 m .37088 .41523 L p .3709 .41522 L 1 0 0 r
F P
0 g
s
.36915 .41071 m .3734 .41185 L .37088 .41523 L 0 1 0 r
F
.3734 .41185 m .37458 .41487 L .37088 .41523 L F
.38218 .41052 m .37579 .41798 L p .3734 .41185 L 0 0 1 r
F P
0 g
s
.37583 .41794 m .38218 .41052 L p .37617 .41881 L 0 0 1 r
F P
0 g
s
.38202 .41414 m .37495 .4185 L .37088 .41523 L p 0 1 0 r
F P
0 g
s
.36334 .40917 m .3675 .40656 L p .36914 .41071 L 0 1 0 r
F P
0 g
s
.36468 .41415 m .36311 .41341 L p .36431 .41322 L 0 0 1 r
F P
0 g
s
.33798 .40928 m .34482 .40445 L .35639 .41363 L p 0 1 0 r
F P
0 g
s
.36334 .40917 m .35639 .41363 L .34482 .40445 L p 0 1 0 r
F P
0 g
s
.34482 .40445 m .35171 .39983 L .36334 .40917 L p 0 1 0 r
F P
0 g
s
.34951 .41824 m .34268 .42305 L .33119 .41439 L p 0 1 0 r
F P
0 g
s
.33119 .41439 m .33798 .40928 L .34951 .41824 L p 0 1 0 r
F P
0 g
s
.35639 .41363 m .34951 .41824 L .33798 .40928 L p 0 1 0 r
F P
0 g
s
.36311 .41341 m .35592 .42186 L .34408 .41629 L p 0 0 1 r
F P
0 g
s
.36334 .40917 m .35171 .39983 L p .36639 .40372 L 0 1 0 r
F P
0 g
s
.37051 .40158 m .3675 .40656 L p .36639 .40372 L 1 0 0 r
F P
0 g
s
.37051 .40158 m .38249 .40379 L p .36915 .41071 L 1 0 0 r
F P
0 g
s
.36766 .40694 m .37051 .40158 L .36915 .41071 L 1 0 0 r
F
.36914 .41071 m .3675 .40656 L .36915 .41071 L 0 1 0 r
F
.36398 .41238 m .36749 .40658 L p .36431 .41322 L 1 0 0 r
F P
0 g
s
.36749 .40658 m .37051 .40158 L p .36764 .40698 L 1 0 0 r
F P
0 g
s
.36749 .40658 m .36764 .40698 L .36431 .41322 L 1 0 0 r
F
.35171 .39983 m .35867 .39535 L .36518 .4006 L p 0 1 0 r
F P
0 g
s
.36518 .4006 m .36521 .40062 L p .36638 .40372 L 0 1 0 r
F P
0 g
s
.35171 .39983 m .36518 .4006 L .36638 .40372 L 0 1 0 r
F
.34408 .41629 m .35124 .40779 L .36311 .41341 L p 0 0 1 r
F P
0 g
s
.36311 .41341 m .35124 .40779 L p .36159 .40622 L 0 0 1 r
F P
0 g
s
.37035 .40477 m .3675 .40656 L p .36639 .40372 L 0 1 0 r
F P
0 g
s
.3675 .40656 m .36334 .40917 L p .36639 .40372 L 0 1 0 r
F P
0 g
s
.36639 .40372 m .36639 .40372 L .3675 .40656 L 1 0 0 r
F
.36308 .41386 m .351 .41171 L p .36159 .40622 L F P
0 g
s
.36159 .40622 m .36639 .40372 L .36376 .41179 L 1 0 0 r
F
.36398 .41238 m .36396 .4124 L p .36159 .40622 L 0 0 1 r
F P
0 g
s
.36396 .4124 m .36311 .41341 L p .36159 .40622 L 0 0 1 r
F P
0 g
s
.3675 .40656 m .36753 .40654 L p .36915 .41071 L 0 1 0 r
F P
0 g
s
.36431 .41322 m .36766 .40694 L .36915 .41071 L 1 0 0 r
F
.37035 .40477 m .37071 .40506 L p .36915 .41071 L 0 1 0 r
F P
0 g
s
.36915 .41071 m .37071 .40506 L .3734 .41185 L 0 1 0 r
F
.36753 .40654 m .37035 .40477 L p .36915 .41071 L F P
0 g
s
.37071 .40506 m .38218 .41052 L p .37335 .41185 L 0 0 1 r
F P
0 g
s
.4013 .40762 m .39397 .41612 L .38218 .41052 L p 0 0 1 r
F P
0 g
s
.41358 .39681 m .40617 .40847 L .39438 .40607 L p 1 0 0 r
F P
0 g
s
.39438 .40607 m .40181 .39414 L .41358 .39681 L p 1 0 0 r
F P
0 g
s
.40181 .39414 m .39438 .40607 L .38249 .40379 L p 1 0 0 r
F P
0 g
s
.38218 .41052 m .38949 .40198 L .4013 .40762 L p 0 0 1 r
F P
0 g
s
.37071 .40506 m .37035 .40477 L p .37062 .40484 L 0 1 0 r
F P
0 g
s
.38249 .40379 m .38994 .39165 L .40181 .39414 L p 1 0 0 r
F P
0 g
s
.38994 .39165 m .38249 .40379 L .37051 .40158 L p 1 0 0 r
F P
0 g
s
.38949 .40198 m .38218 .41052 L .37072 .40506 L p 0 0 1 r
F P
0 g
s
.37072 .40506 m .37034 .40489 L p .37062 .40484 L 0 0 1 r
F P
0 g
s
.37062 .40484 m .38949 .40198 L .37072 .40506 L 0 0 1 r
F
.37035 .40477 m .37054 .40465 L p .37062 .40484 L 0 1 0 r
F P
0 g
s
.37051 .40158 m .37797 .38929 L .38994 .39165 L p 1 0 0 r
F P
0 g
s
.37763 .39631 m .38949 .40198 L p .37069 .40483 L 0 0 1 r
F P
0 g
s
.37067 .40478 m .37763 .39631 L .37069 .40483 L 0 0 1 r
F
.37054 .40465 m .37763 .39631 L p .37062 .40484 L F P
0 g
s
.37797 .38929 m .37051 .40158 L .36523 .40063 L p 1 0 0 r
F P
0 g
s
.36523 .40063 m .36521 .40062 L p .36367 .39669 L 1 0 0 r
F P
0 g
s
.36367 .39669 m .37797 .38929 L .36523 .40063 L 1 0 0 r
F
.36521 .40062 m .37051 .40158 L p .36639 .40372 L F P
0 g
s
.37035 .40477 m .36521 .40062 L p .36783 .3978 L 0 1 0 r
F P
0 g
s
.36521 .40062 m .35867 .39535 L p .36367 .39669 L 0 1 0 r
F P
0 g
s
.36367 .39669 m .36783 .3978 L .36521 .40062 L 0 1 0 r
F
.35124 .40779 m .35845 .39923 L .35901 .3995 L p 0 0 1 r
F P
0 g
s
.3675 .40656 m .36398 .41238 L p .36639 .40372 L 1 0 0 r
F P
0 g
s
.36639 .40372 m .36398 .41238 L .36376 .41179 L 1 0 0 r
F
.36638 .40372 m .36521 .40062 L .36639 .40372 L 0 1 0 r
F
.36159 .40622 m .36521 .40062 L .36639 .40372 L 1 0 0 r
F
.36077 .40408 m .36521 .40062 L .36159 .40622 L F
.35124 .40779 m .35901 .3995 L .36157 .40622 L 0 0 1 r
F
.351 .41171 m .35844 .39939 L .35901 .3995 L p 1 0 0 r
F P
0 g
s
.35901 .3995 m .36521 .40062 L p .36077 .40408 L 1 0 0 r
F P
0 g
s
.36157 .40622 m .35901 .3995 L .36159 .40622 L 0 0 1 r
F
.351 .41171 m .35901 .3995 L .36077 .40408 L 1 0 0 r
F
.36521 .40062 m .37035 .40477 L p .36639 .40372 L 0 1 0 r
F P
0 g
s
.35901 .3995 m .37034 .40489 L p .36159 .40622 L 0 0 1 r
F P
0 g
s
.36521 .40062 m .35901 .3995 L p .36367 .39669 L 1 0 0 r
F P
0 g
s
.35888 .39916 m .36367 .39669 L .35901 .3995 L 1 0 0 r
F
.37054 .40465 m .37035 .40477 L p .36783 .3978 L 0 1 0 r
F P
0 g
s
.37763 .39631 m .37034 .40489 L .35902 .3995 L p 0 0 1 r
F P
0 g
s
.35902 .3995 m .35845 .39923 L p .35888 .39916 L 0 0 1 r
F P
0 g
s
.35888 .39916 m .37763 .39631 L .35902 .3995 L 0 0 1 r
F
.35867 .39535 m .36222 .39311 L p .36366 .39668 L 0 1 0 r
F P
0 g
s
.33322 .3954 m .34007 .39056 L .35171 .39983 L p 0 1 0 r
F P
0 g
s
.35867 .39535 m .35171 .39983 L .34007 .39056 L p 0 1 0 r
F P
0 g
s
.34007 .39056 m .34698 .38592 L .35867 .39535 L p 0 1 0 r
F P
0 g
s
.34482 .40445 m .33798 .40928 L .32642 .40051 L p 0 1 0 r
F P
0 g
s
.32642 .40051 m .33322 .3954 L .34482 .40445 L p 0 1 0 r
F P
0 g
s
.35171 .39983 m .34482 .40445 L .33322 .3954 L p 0 1 0 r
F P
0 g
s
.35845 .39923 m .35124 .40779 L .33931 .40215 L p 0 0 1 r
F P
0 g
s
.35867 .39535 m .34698 .38592 L p .36083 .38962 L 0 1 0 r
F P
0 g
s
.3659 .38699 m .36222 .39311 L p .36083 .38962 L 1 0 0 r
F P
0 g
s
.3659 .38699 m .37797 .38929 L p .36367 .39669 L 1 0 0 r
F P
0 g
s
.36229 .39326 m .3659 .38699 L .36367 .39669 L 1 0 0 r
F
.36366 .39668 m .36222 .39311 L .36367 .39669 L 0 1 0 r
F
.35876 .39886 m .36221 .39313 L p .35888 .39916 L 1 0 0 r
F P
0 g
s
.36221 .39313 m .3659 .38699 L p .36227 .39329 L 1 0 0 r
F P
0 g
s
.36221 .39313 m .36227 .39329 L .35888 .39916 L 1 0 0 r
F
.34698 .38592 m .35394 .38141 L .35929 .38574 L p 0 1 0 r
F P
0 g
s
.36367 .39669 m .36517 .39125 L .36783 .3978 L 0 1 0 r
F
.36571 .39061 m .37763 .39631 L p .36773 .39782 L 0 0 1 r
F P
0 g
s
.33931 .40215 m .3465 .39355 L .35845 .39923 L p 0 0 1 r
F P
0 g
s
.36222 .39311 m .35867 .39535 L p .36083 .38962 L 0 1 0 r
F P
0 g
s
.35609 .39208 m .36083 .38963 L .35864 .39856 L 1 0 0 r
F
.36083 .38962 m .36496 .39073 L .36222 .39311 L 0 1 0 r
F
.36517 .39125 m .36222 .39311 L p .36496 .39073 L F P
0 g
s
.36083 .38963 m .36083 .38962 L .36222 .39311 L 1 0 0 r
F
.36222 .39311 m .35876 .39886 L p .36083 .38963 L F P
0 g
s
.35609 .39208 m .35875 .39883 L .35845 .39923 L 0 0 1 r
F
.35876 .39886 m .35844 .39939 L p .35864 .39856 L 1 0 0 r
F P
0 g
s
.36083 .38963 m .35876 .39886 L .35864 .39856 L 1 0 0 r
F
.35845 .39923 m .3465 .39355 L p .35609 .39208 L 0 0 1 r
F P
0 g
s
.36222 .39311 m .36225 .39309 L p .36367 .39669 L 0 1 0 r
F P
0 g
s
.35888 .39916 m .36229 .39326 L .36367 .39669 L 1 0 0 r
F
.36225 .39309 m .36517 .39125 L p .36367 .39669 L 0 1 0 r
F P
0 g
s
.35609 .39208 m .36496 .39073 L .35875 .39883 L 0 0 1 r
F
.36571 .39061 m .36517 .39125 L p .36496 .39073 L F P
0 g
s
.36517 .39125 m .35845 .39923 L p .36496 .39073 L 0 0 1 r
F P
0 g
s
.36569 .39092 m .36517 .39125 L p .36496 .39073 L 0 1 0 r
F P
0 g
s
.35844 .39939 m .34627 .39717 L p .35609 .39208 L 1 0 0 r
F P
0 g
s
.35609 .39208 m .35864 .39856 L .35844 .39939 L 1 0 0 r
F
.35888 .39916 m .36516 .39126 L .36773 .39782 L 0 0 1 r
F
.35845 .39923 m .35876 .39886 L p .35888 .39916 L F P
0 g
s
.35876 .39886 m .36516 .39126 L p .35888 .39916 L 0 0 1 r
F P
0 g
s
.36516 .39126 m .36571 .39061 L p .36773 .39782 L 0 0 1 r
F P
0 g
s
.35929 .38574 m .35932 .38577 L p .36082 .38962 L 0 1 0 r
F P
0 g
s
.34698 .38592 m .35929 .38574 L .36082 .38962 L 0 1 0 r
F
.35375 .38472 m .35932 .38577 L p .35507 .38948 L 1 0 0 r
F P
0 g
s
.35342 .38527 m .35375 .38472 L p .35507 .38948 L 1 0 0 r
F P
0 g
s
.35932 .38577 m .3659 .38699 L p .36086 .38961 L 1 0 0 r
F P
0 g
s
.36083 .38962 m .35932 .38577 L .36086 .38961 L 1 0 0 r
F
.3465 .39355 m .35342 .38527 L p .35609 .39208 L 0 0 1 r
F P
0 g
s
.36082 .38962 m .35932 .38577 L .36083 .38962 L 0 1 0 r
F
.34627 .39717 m .35932 .38577 L .36083 .38962 L 1 0 0 r
F
.35932 .38577 m .36473 .39014 L p .36083 .38962 L 0 1 0 r
F P
0 g
s
.36082 .38962 m .36473 .39014 L .36496 .39073 L 0 1 0 r
F
.35374 .38489 m .36473 .39014 L p .35609 .39208 L 0 0 1 r
F P
0 g
s
.36473 .39014 m .36571 .39061 L p .36496 .39073 L 0 0 1 r
F P
0 g
s
.35609 .39208 m .36473 .39014 L .36496 .39073 L 0 0 1 r
F
.38545 .37704 m .37797 .38929 L .3659 .38699 L p 1 0 0 r
F P
0 g
s
.3974 .37963 m .38994 .39165 L .37797 .38929 L p 1 0 0 r
F P
0 g
s
.37797 .38929 m .38545 .37704 L .3974 .37963 L p 1 0 0 r
F P
0 g
s
.38497 .38767 m .37763 .39631 L .36571 .39061 L p 0 0 1 r
F P
0 g
s
.3659 .38699 m .3734 .37458 L .38545 .37704 L p 1 0 0 r
F P
0 g
s
.36571 .39061 m .37302 .38193 L .38497 .38767 L p 0 0 1 r
F P
0 g
s
.35932 .38577 m .35394 .38141 L p .35803 .38251 L 0 1 0 r
F P
0 g
s
.3734 .37458 m .3659 .38699 L .35932 .38577 L p 1 0 0 r
F P
0 g
s
.35803 .38251 m .35803 .38251 L .35932 .38577 L 0 1 0 r
F
.35932 .38577 m .35375 .38472 L p .35803 .38251 L 1 0 0 r
F P
0 g
s
.35803 .38251 m .3734 .37458 L .35934 .38575 L 1 0 0 r
F
.37302 .38193 m .36571 .39061 L .36484 .3902 L p 0 0 1 r
F P
0 g
s
.35803 .38251 m .35934 .38575 L .35932 .38577 L 1 0 0 r
F
.35803 .38251 m .3621 .38361 L .35932 .38577 L 0 1 0 r
F
.36484 .3902 m .36473 .39014 L p .3621 .38361 L 0 0 1 r
F P
0 g
s
.3621 .38361 m .37302 .38193 L .36484 .3902 L 0 0 1 r
F
.3621 .38361 m .37279 .38649 L .36305 .38597 L 0 1 0 r
F
.3621 .38361 m .36305 .38597 L .35932 .38577 L F
.36473 .39014 m .35932 .38577 L p .36305 .38597 L F P
0 g
s
.36473 .39014 m .35374 .38489 L p .3621 .38361 L 0 0 1 r
F P
0 g
s
.36125 .3722 m .3734 .37458 L p .35803 .38251 L 1 0 0 r
F P
0 g
s
.35802 .38251 m .35682 .37959 L .35803 .38251 L 0 1 0 r
F
.35394 .38141 m .35682 .37959 L p .35802 .38251 L F P
0 g
s
.32841 .3814 m .33526 .37654 L .34698 .38592 L p 0 1 0 r
F P
0 g
s
.35394 .38141 m .34698 .38592 L .33526 .37654 L p 0 1 0 r
F P
0 g
s
.33526 .37654 m .34218 .37188 L .35394 .38141 L p 0 1 0 r
F P
0 g
s
.35394 .38141 m .34218 .37188 L p .35511 .37538 L 0 1 0 r
F P
0 g
s
.36125 .3722 m .35682 .37959 L p .35511 .37538 L 1 0 0 r
F P
0 g
s
.35682 .37959 m .36125 .3722 L p .35803 .38251 L 1 0 0 r
F P
0 g
s
.35803 .38251 m .36006 .3787 L .3621 .38361 L 0 1 0 r
F
.36102 .37617 m .37302 .38193 L p .36206 .38361 L 0 0 1 r
F P
0 g
s
.35375 .38472 m .35682 .37959 L p .35803 .38251 L 1 0 0 r
F P
0 g
s
.35682 .37959 m .35684 .37957 L p .35803 .38251 L 0 1 0 r
F P
0 g
s
.35684 .37957 m .35967 .37779 L p .35803 .38251 L 0 1 0 r
F P
0 g
s
.35967 .37779 m .36102 .37617 L p .36204 .38347 L 0 0 1 r
F P
0 g
s
.35967 .37779 m .36098 .37696 L p .36006 .3787 L 0 1 0 r
F P
0 g
s
.35967 .37779 m .36006 .3787 L .35803 .38251 L 0 1 0 r
F
.35967 .37779 m .36204 .38347 L .36206 .38361 L 0 0 1 r
F
.35374 .38489 m .35967 .37779 L p .36206 .38361 L F P
0 g
s
.35511 .37538 m .35913 .37646 L .35682 .37959 L 0 1 0 r
F
.35967 .37779 m .35682 .37959 L p .35913 .37646 L F P
0 g
s
.35682 .37959 m .35394 .38141 L p .35511 .37538 L 0 1 0 r
F P
0 g
s
.3551 .37538 m .35511 .37538 L .35682 .37959 L 1 0 0 r
F
.35375 .38472 m .35316 .38461 L p .3551 .37538 L F P
0 g
s
.35682 .37959 m .35375 .38472 L p .3551 .37538 L 1 0 0 r
F P
0 g
s
.34218 .37188 m .34916 .36736 L .35323 .37066 L p 0 1 0 r
F P
0 g
s
.34218 .37188 m .35323 .37066 L .35466 .37424 L 0 1 0 r
F
.35323 .37066 m .36125 .3722 L p .35514 .37537 L 1 0 0 r
F P
0 g
s
.35511 .37538 m .35323 .37066 L .35514 .37537 L 1 0 0 r
F
.36102 .37617 m .35967 .3778 L p .35962 .37768 L 0 0 1 r
F P
0 g
s
.35043 .3778 m .3551 .37538 L .35316 .38461 L 1 0 0 r
F
.35043 .3778 m .36102 .37617 L .35316 .38461 L 0 0 1 r
F
.38091 .36223 m .3734 .37458 L .36125 .3722 L p 1 0 0 r
F P
0 g
s
.36125 .3722 m .36877 .35968 L .38091 .36223 L p 1 0 0 r
F P
0 g
s
.39295 .36492 m .38545 .37704 L .3734 .37458 L p 1 0 0 r
F P
0 g
s
.3734 .37458 m .38091 .36223 L .39295 .36492 L p 1 0 0 r
F P
0 g
s
.38039 .37319 m .37302 .38193 L .36102 .37617 L p 0 0 1 r
F P
0 g
s
.35323 .37066 m .34916 .36736 L p .35222 .36819 L 0 1 0 r
F P
0 g
s
.36877 .35968 m .36125 .3722 L .35323 .37066 L p 1 0 0 r
F P
0 g
s
.35222 .36819 m .35223 .36819 L .35323 .37066 L 0 1 0 r
F
.35323 .37066 m .349 .36985 L p .35223 .36819 L 1 0 0 r
F P
0 g
s
.35223 .36819 m .36877 .35968 L .35324 .37065 L 1 0 0 r
F
.35654 .35721 m .36877 .35968 L p .35223 .36819 L F P
0 g
s
.35222 .36819 m .3513 .36599 L .35223 .36819 L 0 1 0 r
F
.34916 .36736 m .3513 .36599 L p .35222 .36819 L F P
0 g
s
.32353 .36727 m .3304 .36241 L .34218 .37188 L p 0 1 0 r
F P
0 g
s
.34916 .36736 m .34218 .37188 L .3304 .36241 L p 0 1 0 r
F P
0 g
s
.3304 .36241 m .33732 .35773 L .34916 .36736 L p 0 1 0 r
F P
0 g
s
.34916 .36736 m .33732 .35773 L p .34923 .36098 L 0 1 0 r
F P
0 g
s
.35654 .35721 m .3513 .36599 L p .34923 .36098 L 1 0 0 r
F P
0 g
s
.3513 .36599 m .35654 .35721 L p .35223 .36819 L 1 0 0 r
F P
0 g
s
.35628 .36156 m .36836 .36739 L p .3562 .36927 L 0 0 1 r
F P
0 g
s
.35616 .36917 m .35628 .36156 L .3562 .36927 L 0 0 1 r
F
.35223 .36819 m .35447 .3652 L .3562 .36927 L 0 1 0 r
F
.35406 .36424 m .35628 .36156 L p .35616 .36917 L 0 0 1 r
F P
0 g
s
.35223 .36819 m .35324 .37065 L .35323 .37066 L 1 0 0 r
F
.36102 .37617 m .36836 .36739 L .38039 .37319 L p 0 0 1 r
F P
0 g
s
.35223 .36819 m .3562 .36927 L .35323 .37066 L 0 1 0 r
F
.36836 .36739 m .36102 .37617 L .35854 .37498 L p 0 0 1 r
F P
0 g
s
.3562 .36927 m .36836 .36739 L .35854 .37498 L 0 0 1 r
F
.3562 .36927 m .36809 .37249 L .35696 .37112 L 0 1 0 r
F
.3562 .36927 m .35696 .37112 L .35323 .37066 L F
.35854 .37498 m .36102 .37617 L p .35915 .37646 L 0 0 1 r
F P
0 g
s
.36809 .37249 m .36098 .37696 L .35854 .37498 L p 0 1 0 r
F P
0 g
s
.35854 .37498 m .35323 .37066 L p .35696 .37112 L 0 1 0 r
F P
0 g
s
.35696 .37112 m .36809 .37249 L .35854 .37498 L 0 1 0 r
F
.34218 .37188 m .34697 .37279 L .34671 .37311 L F
.35598 .37561 m .35854 .37498 L .35913 .37646 L F
.349 .36985 m .35323 .37066 L p .34919 .37471 L 1 0 0 r
F P
0 g
s
.34171 .37914 m .34795 .37161 L p .35013 .37706 L 0 0 1 r
F P
0 g
s
.35043 .3778 m .35854 .37498 L .35915 .37646 L 0 0 1 r
F
.34171 .37914 m .35013 .37706 L .35043 .3778 L F
.35043 .3778 m .35323 .37066 L .35511 .37538 L 1 0 0 r
F
.34919 .37471 m .35323 .37066 L .35043 .3778 L F
.35013 .37706 m .35854 .37498 L .35043 .3778 L 0 0 1 r
F
.35316 .38461 m .34171 .37914 L p .35043 .3778 L F P
0 g
s
.32159 .38652 m .32841 .3814 L .34007 .39056 L p 0 1 0 r
F P
0 g
s
.34698 .38592 m .34007 .39056 L .32841 .3814 L p 0 1 0 r
F P
0 g
s
.33449 .38784 m .34171 .37914 L .35315 .38461 L p 0 0 1 r
F P
0 g
s
.33449 .38784 m .35315 .38461 L .35329 .38496 L 0 0 1 r
F
.34007 .39056 m .33322 .3954 L .32159 .38652 L p 0 1 0 r
F P
0 g
s
.33322 .3954 m .32642 .40051 L .31482 .39198 L p 0 1 0 r
F P
0 g
s
.31482 .39198 m .32159 .38652 L .33322 .3954 L p 0 1 0 r
F P
0 g
s
.32733 .39648 m .33449 .38784 L .3465 .39355 L p 0 0 1 r
F P
0 g
s
.35375 .38472 m .35342 .38527 L p .35329 .38496 L 1 0 0 r
F P
0 g
s
.35374 .38489 m .3465 .39355 L .33449 .38784 L p 0 0 1 r
F P
0 g
s
.33402 .39486 m .34149 .38242 L .35316 .38461 L p 1 0 0 r
F P
0 g
s
.35316 .38461 m .35375 .38472 L p .35329 .38496 L 1 0 0 r
F P
0 g
s
.35315 .38461 m .35316 .38461 L p .35329 .38496 L 0 0 1 r
F P
0 g
s
.33402 .39486 m .35316 .38461 L .35329 .38496 L 1 0 0 r
F
.35316 .38461 m .35374 .38489 L p .35329 .38496 L 0 0 1 r
F P
0 g
s
.3465 .39355 m .33931 .40215 L .32733 .39648 L p 0 0 1 r
F P
0 g
s
.34627 .39717 m .33402 .39486 L p .35329 .38496 L 1 0 0 r
F P
0 g
s
.35342 .38527 m .34627 .39717 L p .35329 .38496 L 1 0 0 r
F P
0 g
s
.34149 .38242 m .34919 .37471 L .35043 .3778 L 1 0 0 r
F
.34149 .38242 m .34795 .37161 L p .34919 .37471 L F P
0 g
s
.34795 .37161 m .349 .36985 L p .34919 .37471 L 1 0 0 r
F P
0 g
s
.35323 .37066 m .35854 .37498 L p .35466 .37424 L 0 1 0 r
F P
0 g
s
.34897 .37038 m .35854 .37498 L p .35013 .37706 L 0 0 1 r
F P
0 g
s
.34795 .37161 m .34897 .37038 L p .35013 .37706 L 0 0 1 r
F P
0 g
s
.35854 .37498 m .34897 .37038 L p .3562 .36927 L 0 0 1 r
F P
0 g
s
.35406 .36424 m .35616 .36917 L .35615 .36927 L 0 0 1 r
F
.35132 .36598 m .35406 .36424 L p .35223 .36819 L 0 1 0 r
F P
0 g
s
.35406 .36424 m .3562 .36288 L p .35447 .3652 L 0 1 0 r
F P
0 g
s
.35406 .36424 m .35447 .3652 L .35223 .36819 L 0 1 0 r
F
.3562 .36288 m .36809 .37249 L p .3562 .36927 L F P
0 g
s
.35447 .3652 m .3562 .36288 L .3562 .36927 L 0 1 0 r
F
.35615 .36927 m .35616 .36917 L .3562 .36927 L 0 0 1 r
F
.349 .36985 m .3513 .36599 L p .35223 .36819 L 1 0 0 r
F P
0 g
s
.3513 .36599 m .35132 .36598 L p .35223 .36819 L 0 1 0 r
F P
0 g
s
.34897 .37038 m .35406 .36424 L p .35615 .36927 L 0 0 1 r
F P
0 g
s
.34923 .36098 m .35315 .36205 L .3513 .36599 L 0 1 0 r
F
.35406 .36424 m .3513 .36599 L p .35315 .36205 L F P
0 g
s
.3513 .36599 m .34916 .36736 L p .34923 .36098 L 0 1 0 r
F P
0 g
s
.34921 .36099 m .34923 .36098 L .3513 .36599 L 1 0 0 r
F
.349 .36985 m .34709 .36948 L p .34921 .36099 L F P
0 g
s
.3513 .36599 m .349 .36985 L p .34921 .36099 L 1 0 0 r
F P
0 g
s
.33526 .37654 m .32841 .3814 L .31671 .37241 L p 0 1 0 r
F P
0 g
s
.32841 .3814 m .32159 .38652 L .30993 .37788 L p 0 1 0 r
F P
0 g
s
.30993 .37788 m .31671 .37241 L .32841 .3814 L p 0 1 0 r
F P
0 g
s
.34171 .37914 m .33449 .38784 L .32243 .38211 L p 0 0 1 r
F P
0 g
s
.31671 .37241 m .32353 .36727 L .33526 .37654 L p 0 1 0 r
F P
0 g
s
.34218 .37188 m .33526 .37654 L .32353 .36727 L p 0 1 0 r
F P
0 g
s
.32243 .38211 m .32962 .37337 L .34171 .37914 L p 0 0 1 r
F P
0 g
s
.34171 .37914 m .32962 .37337 L p .34753 .3706 L 0 0 1 r
F P
0 g
s
.34795 .37161 m .34171 .37914 L p .34753 .3706 L 0 0 1 r
F P
0 g
s
.34149 .38242 m .32915 .38004 L p .34753 .3706 L 1 0 0 r
F P
0 g
s
.349 .36985 m .34795 .37161 L p .34753 .3706 L 1 0 0 r
F P
0 g
s
.34795 .37161 m .34149 .38242 L p .34753 .3706 L 1 0 0 r
F P
0 g
s
.34897 .37038 m .34795 .37161 L p .34753 .3706 L 0 0 1 r
F P
0 g
s
.33732 .35773 m .34431 .35318 L .34691 .3553 L p 0 1 0 r
F P
0 g
s
.33732 .35773 m .34691 .3553 L .34846 .3591 L 0 1 0 r
F
.34691 .3553 m .35654 .35721 L p .34925 .36097 L 1 0 0 r
F P
0 g
s
.34923 .36098 m .34691 .3553 L .34925 .36097 L 1 0 0 r
F
.35628 .36156 m .35405 .36425 L p .35382 .36368 L 0 0 1 r
F P
0 g
s
.34461 .36337 m .34921 .36099 L .34709 .36948 L 1 0 0 r
F
.34461 .36337 m .35628 .36156 L .34709 .36948 L 0 0 1 r
F
.37632 .34722 m .36877 .35968 L .35654 .35721 L p 1 0 0 r
F P
0 g
s
.35654 .35721 m .3641 .34457 L .37632 .34722 L p 1 0 0 r
F P
0 g
s
.38844 .35001 m .38091 .36223 L .36877 .35968 L p 1 0 0 r
F P
0 g
s
.36877 .35968 m .37632 .34722 L .38844 .35001 L p 1 0 0 r
F P
0 g
s
.37575 .35855 m .36836 .36739 L .35628 .36156 L p 0 0 1 r
F P
0 g
s
.34691 .3553 m .34431 .35318 L p .34625 .35371 L 0 1 0 r
F P
0 g
s
.3641 .34457 m .35654 .35721 L .34691 .3553 L p 1 0 0 r
F P
0 g
s
.34625 .35371 m .34626 .35372 L .34691 .3553 L 0 1 0 r
F
.34691 .3553 m .3442 .35477 L p .34626 .35372 L 1 0 0 r
F P
0 g
s
.34626 .35372 m .3641 .34457 L .34692 .35529 L 1 0 0 r
F
.35178 .342 m .3641 .34457 L p .34626 .35372 L F P
0 g
s
.34625 .35371 m .34565 .35232 L .34626 .35372 L 0 1 0 r
F
.34431 .35318 m .34565 .35232 L p .34625 .35371 L F P
0 g
s
.34431 .35318 m .33732 .35773 L .32546 .34815 L p 0 1 0 r
F P
0 g
s
.32546 .34815 m .3324 .34346 L .34431 .35318 L p 0 1 0 r
F P
0 g
s
.31176 .35817 m .31859 .35303 L .3304 .36241 L p 0 1 0 r
F P
0 g
s
.33732 .35773 m .3304 .36241 L .31859 .35303 L p 0 1 0 r
F P
0 g
s
.31859 .35303 m .32546 .34815 L .33732 .35773 L p 0 1 0 r
F P
0 g
s
.32469 .35872 m .33195 .34982 L .34081 .3541 L p 0 0 1 r
F P
0 g
s
.34923 .36098 m .35212 .35955 L .35315 .36205 L 0 1 0 r
F
.33732 .35773 m .34846 .3591 L .34923 .36098 L F
.34846 .3591 m .35212 .35955 L .34923 .36098 L F
.34709 .36948 m .33686 .36457 L p .34461 .36337 L 0 0 1 r
F P
0 g
s
.32962 .37337 m .33686 .36457 L .34709 .36948 L p 0 0 1 r
F P
0 g
s
.32962 .37337 m .34709 .36948 L .3471 .3695 L 0 0 1 r
F
.32962 .37337 m .34712 .36949 L .34757 .3706 L F
.32915 .38004 m .33666 .36747 L .34709 .36948 L p 1 0 0 r
F P
0 g
s
.34709 .36948 m .349 .36985 L p .34753 .3706 L 1 0 0 r
F P
0 g
s
.32915 .38004 m .34709 .36948 L .34753 .3706 L 1 0 0 r
F
.34709 .36948 m .34712 .36949 L p .3471 .3695 L 0 0 1 r
F P
0 g
s
.34712 .36949 m .34897 .37038 L p .34757 .3706 L 0 0 1 r
F P
0 g
s
.34461 .36337 m .34691 .3553 L .34923 .36098 L 1 0 0 r
F
.34314 .35977 m .34691 .3553 L .34461 .36337 L F
.3442 .35477 m .34691 .3553 L p .34314 .35977 L F P
0 g
s
.35212 .35955 m .35628 .36156 L p .35316 .36204 L 0 0 1 r
F P
0 g
s
.35628 .36156 m .36365 .35268 L .37575 .35855 L p 0 0 1 r
F P
0 g
s
.35212 .35955 m .34691 .3553 L p .35064 .356 L 0 1 0 r
F P
0 g
s
.36365 .35268 m .35628 .36156 L .35224 .35961 L p 0 0 1 r
F P
0 g
s
.34626 .35372 m .34692 .35529 L .34691 .3553 L 1 0 0 r
F
.34626 .35372 m .35013 .35477 L .34691 .3553 L 0 1 0 r
F
.35224 .35961 m .35212 .35955 L p .35013 .35477 L 0 0 1 r
F P
0 g
s
.35013 .35477 m .36365 .35268 L .35224 .35961 L 0 0 1 r
F
.35013 .35477 m .36333 .35837 L .35064 .356 L 0 1 0 r
F
.35013 .35477 m .35064 .356 L .34691 .3553 L F
.34691 .3553 m .35212 .35955 L p .34846 .3591 L F P
0 g
s
.35212 .35955 m .34414 .3557 L p .35013 .35477 L 0 0 1 r
F P
0 g
s
.34626 .35372 m .34865 .35136 L .35013 .35477 L 0 1 0 r
F
.3442 .35477 m .34565 .35232 L p .34626 .35372 L 1 0 0 r
F P
0 g
s
.34565 .35232 m .35178 .342 L p .34626 .35372 L 1 0 0 r
F P
0 g
s
.34565 .35232 m .34567 .35232 L p .34626 .35372 L 0 1 0 r
F P
0 g
s
.35148 .34678 m .36365 .35268 L p .35013 .35477 L 0 0 1 r
F P
0 g
s
.34567 .35232 m .34832 .35062 L p .34626 .35372 L 0 1 0 r
F P
0 g
s
.34832 .35062 m .34865 .35136 L .34626 .35372 L 0 1 0 r
F
.34414 .3557 m .34832 .35062 L p .35013 .35477 L 0 0 1 r
F P
0 g
s
.34832 .35062 m .35148 .34678 L p .35013 .35477 L 0 0 1 r
F P
0 g
s
.34832 .35062 m .35137 .34868 L p .34865 .35136 L 0 1 0 r
F P
0 g
s
.35137 .34868 m .36333 .35837 L p .35013 .35477 L 0 1 0 r
F P
0 g
s
.34865 .35136 m .35137 .34868 L .35013 .35477 L 0 1 0 r
F
.36333 .35837 m .3562 .36288 L .35212 .35955 L p F P
0 g
s
.35064 .356 m .36333 .35837 L .35212 .35955 L 0 1 0 r
F
.34414 .3557 m .35212 .35955 L p .34461 .36337 L 0 0 1 r
F P
0 g
s
.34461 .36337 m .35212 .35955 L .35316 .36204 L 0 0 1 r
F
.33686 .36457 m .34236 .35787 L p .34461 .36337 L F P
0 g
s
.34236 .35787 m .3442 .35477 L p .34314 .35977 L 1 0 0 r
F P
0 g
s
.34236 .35787 m .34414 .3557 L p .34461 .36337 L 0 0 1 r
F P
0 g
s
.33666 .36747 m .34236 .35787 L p .34314 .35977 L 1 0 0 r
F P
0 g
s
.33666 .36747 m .34314 .35977 L .34461 .36337 L 1 0 0 r
F
.3304 .36241 m .32353 .36727 L .31176 .35817 L p 0 1 0 r
F P
0 g
s
.32353 .36727 m .31671 .37241 L .30497 .36365 L p 0 1 0 r
F P
0 g
s
.30497 .36365 m .31176 .35817 L .32353 .36727 L p 0 1 0 r
F P
0 g
s
.33686 .36457 m .32962 .37337 L .31748 .36756 L p 0 0 1 r
F P
0 g
s
.31748 .36756 m .32469 .35872 L .33686 .36457 L p 0 0 1 r
F P
0 g
s
.3442 .35477 m .34236 .35787 L p .34162 .35609 L 1 0 0 r
F P
0 g
s
.33686 .36457 m .32469 .35872 L p .34162 .35609 L 0 0 1 r
F P
0 g
s
.34414 .3557 m .34234 .3579 L p .34162 .35609 L 0 0 1 r
F P
0 g
s
.34234 .3579 m .33686 .36457 L p .34162 .35609 L 0 0 1 r
F P
0 g
s
.32469 .35872 m .34078 .35411 L .34162 .35609 L 0 0 1 r
F
.34078 .35411 m .34081 .3541 L .34162 .35609 L F
.32422 .36502 m .33177 .35231 L .34081 .3541 L p 1 0 0 r
F P
0 g
s
.34081 .3541 m .3442 .35477 L p .34162 .35609 L 1 0 0 r
F P
0 g
s
.32422 .36502 m .34081 .3541 L .34162 .35609 L 1 0 0 r
F
.33666 .36747 m .32422 .36502 L p .34162 .35609 L F P
0 g
s
.34236 .35787 m .33666 .36747 L p .34162 .35609 L 1 0 0 r
F P
0 g
s
.34162 .35609 m .34081 .3541 L .34164 .35609 L 0 0 1 r
F
.34081 .3541 m .34414 .3557 L p .34164 .35609 L F P
0 g
s
.34431 .35318 m .3324 .34346 L p .34319 .34643 L 0 1 0 r
F P
0 g
s
.35178 .342 m .34565 .35232 L p .34319 .34643 L 1 0 0 r
F P
0 g
s
.34319 .34643 m .34699 .34747 L .34565 .35232 L 0 1 0 r
F
.34565 .35232 m .34431 .35318 L p .34319 .34643 L F P
0 g
s
.34315 .34645 m .34319 .34643 L .34565 .35232 L 1 0 0 r
F
.3442 .35477 m .34081 .3541 L p .34315 .34645 L F P
0 g
s
.33862 .34878 m .34315 .34645 L .34081 .3541 L 1 0 0 r
F
.34565 .35232 m .3442 .35477 L p .34315 .34645 L F P
0 g
s
.3324 .34346 m .33939 .33889 L .34035 .33968 L p 0 1 0 r
F P
0 g
s
.34035 .33968 m .35178 .342 L p .3432 .34642 L 1 0 0 r
F P
0 g
s
.34319 .34643 m .34035 .33968 L .3432 .34642 L 1 0 0 r
F
.35148 .34678 m .34832 .35062 L p .34699 .34747 L 0 0 1 r
F P
0 g
s
.38389 .3349 m .37632 .34722 L .3641 .34457 L p 1 0 0 r
F P
0 g
s
.37107 .34373 m .36365 .35268 L .35148 .34678 L p 0 0 1 r
F P
0 g
s
.34548 .34386 m .35148 .34678 L p .34701 .34747 L 0 0 1 r
F P
0 g
s
.34035 .33968 m .34548 .34386 L p .34319 .34643 L 0 1 0 r
F P
0 g
s
.34699 .34747 m .34548 .34386 L .34701 .34747 L 0 0 1 r
F
.34548 .34386 m .35137 .34868 L p .34699 .34747 L 0 1 0 r
F P
0 g
s
.34319 .34643 m .34548 .34386 L .34699 .34747 L 0 1 0 r
F
.3324 .34346 m .34035 .33968 L .34319 .34643 L F
.33936 .33947 m .34035 .33968 L p .33862 .34878 L 1 0 0 r
F P
0 g
s
.33862 .34878 m .34035 .33968 L .34319 .34643 L 1 0 0 r
F
.33665 .34405 m .33936 .33947 L p .33862 .34878 L F P
0 g
s
.33195 .34982 m .33797 .34717 L .33865 .34877 L 0 0 1 r
F
.33195 .34982 m .33926 .34085 L .34548 .34386 L p F P
0 g
s
.34086 .35412 m .33195 .34982 L p .33862 .34878 L 0 0 1 r
F P
0 g
s
.32546 .34815 m .31859 .35303 L .30675 .34381 L p 0 1 0 r
F P
0 g
s
.30675 .34381 m .31359 .33867 L .32546 .34815 L p 0 1 0 r
F P
0 g
s
.3324 .34346 m .32546 .34815 L .31359 .33867 L p 0 1 0 r
F P
0 g
s
.31359 .33867 m .32047 .33378 L .3324 .34346 L p 0 1 0 r
F P
0 g
s
.31859 .35303 m .31176 .35817 L .29996 .34929 L p 0 1 0 r
F P
0 g
s
.29996 .34929 m .30675 .34381 L .31859 .35303 L p 0 1 0 r
F P
0 g
s
.33195 .34982 m .32469 .35872 L .31246 .35285 L p 0 0 1 r
F P
0 g
s
.33939 .33889 m .3324 .34346 L .32047 .33378 L p 0 1 0 r
F P
0 g
s
.31246 .35285 m .3197 .3439 L .33195 .34982 L p 0 0 1 r
F P
0 g
s
.33936 .33947 m .33665 .34405 L p .33553 .34143 L 1 0 0 r
F P
0 g
s
.33195 .34982 m .3197 .3439 L p .33553 .34143 L 0 0 1 r
F P
0 g
s
.33926 .34085 m .33662 .34409 L p .33553 .34143 L 0 0 1 r
F P
0 g
s
.33662 .34409 m .33195 .34982 L p .33553 .34143 L 0 0 1 r
F P
0 g
s
.33431 .33845 m .33936 .33947 L p .33553 .34143 L 1 0 0 r
F P
0 g
s
.32047 .33378 m .32741 .32908 L .33939 .33889 L p 0 1 0 r
F P
0 g
s
.3197 .3439 m .32698 .33489 L .33431 .33845 L p 0 0 1 r
F P
0 g
s
.33431 .33845 m .33926 .34085 L p .33556 .34143 L 0 0 1 r
F P
0 g
s
.3197 .3439 m .33431 .33845 L .33556 .34143 L 0 0 1 r
F
.34035 .33968 m .33939 .33889 L p .34011 .33909 L 0 1 0 r
F P
0 g
s
.37168 .33201 m .3641 .34457 L .35178 .342 L p 1 0 0 r
F P
0 g
s
.35178 .342 m .35937 .32925 L .37168 .33201 L p 1 0 0 r
F P
0 g
s
.35937 .32925 m .35178 .342 L .34036 .33968 L p 1 0 0 r
F P
0 g
s
.34036 .33968 m .33936 .33947 L p .34011 .33909 L 1 0 0 r
F P
0 g
s
.34011 .33909 m .35937 .32925 L .34036 .33968 L 1 0 0 r
F
.34696 .32659 m .35937 .32925 L p .34011 .33909 L F P
0 g
s
.34011 .33909 m .34011 .33908 L .34011 .33909 L 0 1 0 r
F
.33939 .33889 m .33988 .33858 L p .34011 .33909 L F P
0 g
s
.33936 .33947 m .33988 .33858 L p .34011 .33909 L 1 0 0 r
F P
0 g
s
.33989 .33859 m .34696 .32659 L .34011 .33909 L 1 0 0 r
F
.33988 .33858 m .34696 .32659 L p .33989 .33859 L F P
0 g
s
.33988 .33858 m .33939 .33889 L p .33697 .33172 L 0 1 0 r
F P
0 g
s
.33823 .33477 m .33826 .33475 L .33988 .33858 L 1 0 0 r
F
.34696 .32659 m .33988 .33858 L p .33826 .33475 L F P
0 g
s
.33939 .33889 m .32741 .32908 L p .33697 .33172 L 0 1 0 r
F P
0 g
s
.33247 .33403 m .33697 .33172 L .33431 .33845 L 1 0 0 r
F
.33697 .33172 m .34696 .32659 L .33826 .33475 L F
.33697 .33172 m .33826 .33475 L .33431 .33845 L F
.34663 .33182 m .35888 .33779 L p .34389 .34012 L 0 0 1 r
F P
0 g
s
.3641 .34457 m .37168 .33201 L .38389 .3349 L p 1 0 0 r
F P
0 g
s
.35148 .34678 m .35888 .33779 L .37107 .34373 L p 0 0 1 r
F P
0 g
s
.34548 .34386 m .34035 .33968 L p .34409 .34059 L 0 1 0 r
F P
0 g
s
.35888 .33779 m .35148 .34678 L .34548 .34386 L p 0 0 1 r
F P
0 g
s
.34389 .34012 m .34409 .34059 L .34035 .33968 L 0 1 0 r
F
.34548 .34386 m .33926 .34085 L p .34389 .34012 L 0 0 1 r
F P
0 g
s
.34389 .34012 m .35888 .33779 L .34548 .34386 L 0 0 1 r
F
.34011 .33909 m .34389 .34012 L .34035 .33968 L 0 1 0 r
F
.34389 .34012 m .35851 .34413 L .34409 .34059 L F
.34647 .33435 m .35851 .34413 L p .34389 .34012 L F P
0 g
s
.34011 .33909 m .3426 .33723 L .34389 .34012 L 0 1 0 r
F
.34387 .34007 m .34663 .33182 L .34389 .34012 L 0 0 1 r
F
.34247 .33692 m .34663 .33182 L p .34387 .34007 L F P
0 g
s
.34247 .33692 m .34387 .34007 L .34247 .33693 L 0 0 1 r
F
.33988 .33858 m .33988 .33858 L p .33989 .33859 L 1 0 0 r
F P
0 g
s
.33988 .33858 m .34247 .33692 L p .34011 .33909 L 0 1 0 r
F P
0 g
s
.34247 .33692 m .34647 .33435 L p .3426 .33723 L 0 1 0 r
F P
0 g
s
.34247 .33692 m .3426 .33723 L .34011 .33909 L 0 1 0 r
F
.34011 .33908 m .3426 .33723 L .34011 .33909 L F
.3426 .33723 m .3426 .33723 L .34011 .33909 L F
.33926 .34085 m .34247 .33692 L p .34385 .34013 L 0 0 1 r
F P
0 g
s
.34247 .33693 m .34387 .34007 L .34385 .34013 L 0 0 1 r
F
.3426 .33723 m .34647 .33435 L .3426 .33723 L 0 1 0 r
F
.3426 .33723 m .34647 .33435 L .34389 .34012 L F
.34385 .34013 m .34387 .34007 L .34389 .34012 L 0 0 1 r
F
.33445 .32396 m .34696 .32659 L p .33697 .33172 L 1 0 0 r
F P
0 g
s
.33692 .33171 m .33672 .33115 L .33697 .33172 L 0 1 0 r
F
.32741 .32908 m .33393 .3248 L p .33692 .33171 L F P
0 g
s
.33398 .32476 m .33445 .32396 L p .33688 .33146 L 1 0 0 r
F P
0 g
s
.33398 .32476 m .33688 .33146 L .33697 .33172 L 1 0 0 r
F
.32741 .32908 m .31541 .31928 L p .33379 .3243 L 0 1 0 r
F P
0 g
s
.33398 .32476 m .32741 .32908 L p .33379 .32431 L 0 1 0 r
F P
0 g
s
.32047 .33378 m .31359 .33867 L .30168 .32933 L p 0 1 0 r
F P
0 g
s
.30168 .32933 m .30852 .32418 L .32047 .33378 L p 0 1 0 r
F P
0 g
s
.32741 .32908 m .32047 .33378 L .30852 .32418 L p 0 1 0 r
F P
0 g
s
.30852 .32418 m .31541 .31928 L .32741 .32908 L p 0 1 0 r
F P
0 g
s
.31359 .33867 m .30675 .34381 L .29488 .33481 L p 0 1 0 r
F P
0 g
s
.29488 .33481 m .30168 .32933 L .31359 .33867 L p 0 1 0 r
F P
0 g
s
.32698 .33489 m .3197 .3439 L .30739 .33796 L p 0 0 1 r
F P
0 g
s
.33697 .33172 m .34067 .33275 L .33988 .33858 L 0 1 0 r
F
.34663 .33182 m .34247 .33692 L p .34148 .33463 L 0 0 1 r
F P
0 g
s
.34247 .33692 m .33988 .33858 L p .34067 .33275 L 0 1 0 r
F P
0 g
s
.33936 .33947 m .33431 .33845 L p .33823 .33477 L 1 0 0 r
F P
0 g
s
.33988 .33858 m .33936 .33947 L p .33823 .33477 L 1 0 0 r
F P
0 g
s
.33248 .33403 m .34663 .33182 L .3344 .33849 L 0 0 1 r
F
.34647 .33435 m .34247 .33692 L p .34067 .33275 L 0 1 0 r
F P
0 g
s
.33926 .34085 m .3344 .33849 L p .34148 .33463 L 0 0 1 r
F P
0 g
s
.34247 .33692 m .33926 .34085 L p .34148 .33463 L 0 0 1 r
F P
0 g
s
.33393 .3248 m .33398 .32476 L p .33692 .33171 L 0 1 0 r
F P
0 g
s
.33398 .32476 m .33442 .32448 L p .33672 .33115 L 0 1 0 r
F P
0 g
s
.33398 .32476 m .33672 .33115 L .33692 .33171 L 0 1 0 r
F
.33247 .33403 m .33398 .32476 L .33697 .33172 L 1 0 0 r
F
.33436 .33847 m .32698 .33489 L p .33247 .33403 L 0 0 1 r
F P
0 g
s
.33081 .33016 m .33398 .32476 L p .33247 .33403 L 1 0 0 r
F P
0 g
s
.33672 .33115 m .33672 .33113 L .33697 .33172 L 0 1 0 r
F
.33442 .32448 m .33859 .3279 L p .33697 .33172 L F P
0 g
s
.33697 .33172 m .33859 .3279 L .34067 .33275 L 0 1 0 r
F
.33672 .33113 m .33442 .32448 L .33697 .33172 L F
.33859 .3279 m .34663 .33182 L p .34068 .33275 L 0 0 1 r
F P
0 g
s
.37928 .31959 m .37168 .33201 L .35937 .32925 L p 1 0 0 r
F P
0 g
s
.36632 .32873 m .35888 .33779 L .34663 .33182 L p 0 0 1 r
F P
0 g
s
.35937 .32925 m .36699 .31659 L .37928 .31959 L p 1 0 0 r
F P
0 g
s
.36699 .31659 m .35937 .32925 L .34696 .32659 L p 1 0 0 r
F P
0 g
s
.34696 .32659 m .3546 .31373 L .36699 .31659 L p 1 0 0 r
F P
0 g
s
.34663 .33182 m .35405 .32272 L .36632 .32873 L p 0 0 1 r
F P
0 g
s
.33859 .3279 m .33442 .32448 L p .33748 .32532 L 0 1 0 r
F P
0 g
s
.3546 .31373 m .34696 .32659 L .33445 .32396 L p 1 0 0 r
F P
0 g
s
.35405 .32272 m .34663 .33182 L .33867 .32794 L p 0 0 1 r
F P
0 g
s
.33867 .32794 m .33432 .32582 L p .33748 .32532 L 0 0 1 r
F P
0 g
s
.33748 .32532 m .35405 .32272 L .33867 .32794 L 0 0 1 r
F
.33445 .32396 m .3421 .31096 L .3546 .31373 L p 1 0 0 r
F P
0 g
s
.33442 .32448 m .33649 .32314 L p .33748 .32532 L 0 1 0 r
F P
0 g
s
.3295 .30824 m .3421 .31096 L p .33058 .31686 L 1 0 0 r
F P
0 g
s
.32236 .31456 m .32796 .31087 L p .32868 .31253 L 0 1 0 r
F P
0 g
s
.32796 .31087 m .3295 .30824 L p .33058 .31682 L 1 0 0 r
F P
0 g
s
.32796 .31087 m .33058 .31682 L .33058 .31686 L 1 0 0 r
F
.32236 .31456 m .31028 .30467 L p .32729 .30936 L 0 1 0 r
F P
0 g
s
.32796 .31087 m .32236 .31456 L p .32729 .30936 L 0 1 0 r
F P
0 g
s
.3421 .31096 m .33445 .32396 L .33358 .32378 L p 1 0 0 r
F P
0 g
s
.33358 .32378 m .33357 .32378 L p .33058 .31686 L 1 0 0 r
F P
0 g
s
.33058 .31686 m .3421 .31096 L .33358 .32378 L 1 0 0 r
F
.33445 .32396 m .33398 .32476 L p .33379 .3243 L F P
0 g
s
.31541 .31928 m .33357 .32378 L .33379 .3243 L 0 1 0 r
F
.30739 .33796 m .31465 .32891 L .32698 .33489 L p 0 0 1 r
F P
0 g
s
.32698 .33489 m .31465 .32891 L p .32929 .32661 L 0 0 1 r
F P
0 g
s
.33398 .32476 m .33081 .33016 L p .33379 .3243 L 1 0 0 r
F P
0 g
s
.33379 .3243 m .33081 .33016 L .3307 .3299 L 1 0 0 r
F
.32929 .32661 m .33379 .3243 L .3307 .3299 L F
.33432 .32582 m .33079 .33019 L p .32929 .32661 L 0 0 1 r
F P
0 g
s
.33079 .33019 m .32698 .33489 L p .32929 .32661 L 0 0 1 r
F P
0 g
s
.32758 .32253 m .33357 .32378 L p .32912 .3262 L 1 0 0 r
F P
0 g
s
.31541 .31928 m .32236 .31456 L .33357 .32378 L p 0 1 0 r
F P
0 g
s
.31465 .32891 m .32196 .31979 L .32758 .32253 L p 0 0 1 r
F P
0 g
s
.32929 .32661 m .33357 .32378 L .33379 .3243 L 1 0 0 r
F
.32912 .3262 m .33357 .32378 L .32929 .32661 L F
.32758 .32253 m .33432 .32582 L p .32929 .32661 L 0 0 1 r
F P
0 g
s
.31465 .32891 m .32758 .32253 L .32929 .32661 L 0 0 1 r
F
.31422 .33432 m .32912 .3262 L .32929 .32661 L 1 0 0 r
F
.31422 .33432 m .32184 .32133 L .32758 .32253 L p F P
0 g
s
.31422 .33432 m .32758 .32253 L .32912 .3262 L 1 0 0 r
F
.33357 .32378 m .33445 .32396 L p .33379 .3243 L F P
0 g
s
.33357 .32378 m .33442 .32448 L p .33379 .3243 L 0 1 0 r
F P
0 g
s
.33442 .32448 m .33357 .32378 L p .33418 .31786 L 0 1 0 r
F P
0 g
s
.33357 .32378 m .32236 .31456 L p .33058 .31686 L 0 1 0 r
F P
0 g
s
.33058 .31686 m .33418 .31786 L .33357 .32378 L 0 1 0 r
F
.33357 .32378 m .32758 .32253 L p .33058 .31686 L 1 0 0 r
F P
0 g
s
.33649 .32314 m .33442 .32448 L p .33418 .31786 L 0 1 0 r
F P
0 g
s
.33442 .32448 m .33398 .32476 L p .33379 .32431 L 0 1 0 r
F P
0 g
s
.34172 .31668 m .33432 .32582 L .32758 .32253 L p 0 0 1 r
F P
0 g
s
.32758 .32253 m .32196 .31979 L p .32614 .31913 L 0 0 1 r
F P
0 g
s
.32614 .31913 m .33058 .31686 L .32758 .32253 L 1 0 0 r
F
.32614 .31913 m .34172 .31668 L .32758 .32253 L 0 0 1 r
F
.32758 .32253 m .32184 .32133 L p .32614 .31913 L 1 0 0 r
F P
0 g
s
.32236 .31456 m .32869 .31253 L .33052 .31672 L 0 1 0 r
F
.33058 .31686 m .33052 .31672 L .33058 .31686 L F
.32236 .31456 m .33052 .31672 L .33058 .31686 L F
.33058 .31686 m .33145 .31165 L .33418 .31786 L F
.32869 .31253 m .33145 .31165 L .33058 .31686 L F
.31541 .31928 m .30852 .32418 L .29654 .31472 L p F P
0 g
s
.29654 .31472 m .30339 .30957 L .31541 .31928 L p 0 1 0 r
F P
0 g
s
.32236 .31456 m .31541 .31928 L .30339 .30957 L p 0 1 0 r
F P
0 g
s
.30339 .30957 m .31028 .30467 L .32236 .31456 L p 0 1 0 r
F P
0 g
s
.30852 .32418 m .30168 .32933 L .28973 .3202 L p 0 1 0 r
F P
0 g
s
.28973 .3202 m .29654 .31472 L .30852 .32418 L p 0 1 0 r
F P
0 g
s
.32196 .31979 m .31465 .32891 L .30225 .3229 L p 0 0 1 r
F P
0 g
s
.30225 .3229 m .30954 .31373 L .32196 .31979 L p 0 0 1 r
F P
0 g
s
.32614 .31913 m .32796 .31087 L .33058 .31686 L 1 0 0 r
F
.32196 .31979 m .32486 .31618 L p .32614 .31913 L 0 0 1 r
F P
0 g
s
.32184 .32133 m .32486 .31618 L p .32614 .31913 L 1 0 0 r
F P
0 g
s
.32486 .31618 m .32796 .31087 L p .32614 .31913 L 1 0 0 r
F P
0 g
s
.32614 .31913 m .32486 .31618 L .32614 .31913 L 0 0 1 r
F
.32937 .30994 m .33145 .31165 L p .32868 .31253 L 0 1 0 r
F P
0 g
s
.32796 .31087 m .32937 .30994 L p .32868 .31253 L 0 1 0 r
F P
0 g
s
.33145 .31165 m .34172 .31668 L p .33417 .31787 L 0 0 1 r
F P
0 g
s
.34172 .31668 m .35405 .32272 L p .33747 .32532 L 0 0 1 r
F P
0 g
s
.33746 .3253 m .34172 .31668 L .33747 .32532 L 0 0 1 r
F
.33649 .32314 m .34172 .31668 L p .33744 .32533 L F P
0 g
s
.37463 .30408 m .36699 .31659 L .3546 .31373 L p 1 0 0 r
F P
0 g
s
.36152 .31355 m .35405 .32272 L .34172 .31668 L p 0 0 1 r
F P
0 g
s
.3546 .31373 m .36225 .30096 L .37463 .30408 L p 1 0 0 r
F P
0 g
s
.36225 .30096 m .3546 .31373 L .3421 .31096 L p 1 0 0 r
F P
0 g
s
.34172 .31668 m .34916 .30747 L .36152 .31355 L p 0 0 1 r
F P
0 g
s
.33145 .31165 m .32937 .30994 L p .33089 .31036 L 0 1 0 r
F P
0 g
s
.3421 .31096 m .34977 .29799 L .36225 .30096 L p 1 0 0 r
F P
0 g
s
.34977 .29799 m .3421 .31096 L .3295 .30824 L p 1 0 0 r
F P
0 g
s
.34916 .30747 m .34172 .31668 L .3315 .31167 L p 0 0 1 r
F P
0 g
s
.3315 .31167 m .32932 .3106 L p .33089 .31036 L 0 0 1 r
F P
0 g
s
.33089 .31036 m .34916 .30747 L .3315 .31167 L 0 0 1 r
F
.32937 .30994 m .33039 .30928 L p .33089 .31036 L 0 1 0 r
F P
0 g
s
.3295 .30824 m .33718 .29511 L .34977 .29799 L p 1 0 0 r
F P
0 g
s
.33674 .30135 m .34916 .30747 L p .33091 .31035 L 0 0 1 r
F P
0 g
s
.3309 .31031 m .33674 .30135 L .33091 .31035 L 0 0 1 r
F
.33039 .30928 m .33674 .30135 L p .33086 .31036 L F P
0 g
s
.33718 .29511 m .3295 .30824 L .32657 .30761 L p 1 0 0 r
F P
0 g
s
.32657 .30761 m .32654 .30761 L p .32402 .30183 L 1 0 0 r
F P
0 g
s
.32402 .30183 m .33718 .29511 L .32657 .30761 L 1 0 0 r
F
.3295 .30824 m .32796 .31087 L p .32729 .30936 L F P
0 g
s
.31028 .30467 m .31723 .29993 L .32654 .30761 L p 0 1 0 r
F P
0 g
s
.31028 .30467 m .32654 .30761 L .32729 .30936 L 0 1 0 r
F
.32196 .31979 m .30954 .31373 L p .32287 .31163 L 0 0 1 r
F P
0 g
s
.32287 .31163 m .32729 .30936 L .32453 .31543 L 1 0 0 r
F
.32796 .31087 m .32486 .31618 L p .32729 .30936 L F P
0 g
s
.32486 .31618 m .32483 .31621 L p .32287 .31163 L 0 0 1 r
F P
0 g
s
.32483 .31621 m .32196 .31979 L p .32287 .31163 L 0 0 1 r
F P
0 g
s
.32486 .31618 m .32184 .32133 L p .32453 .31543 L 1 0 0 r
F P
0 g
s
.32729 .30936 m .32486 .31618 L .32453 .31543 L 1 0 0 r
F
.32937 .30994 m .32796 .31087 L p .32729 .30936 L 0 1 0 r
F P
0 g
s
.32932 .3106 m .32486 .31618 L p .32287 .31163 L 0 0 1 r
F P
0 g
s
.32061 .30634 m .32654 .30761 L p .3223 .3103 L 1 0 0 r
F P
0 g
s
.30954 .31373 m .31687 .3045 L .32061 .30634 L p 0 0 1 r
F P
0 g
s
.32287 .31163 m .32654 .30761 L .32729 .30936 L 1 0 0 r
F
.3223 .3103 m .32654 .30761 L .32287 .31163 L F
.32061 .30634 m .32932 .3106 L p .32287 .31163 L 0 0 1 r
F P
0 g
s
.30954 .31373 m .32061 .30634 L .32287 .31163 L 0 0 1 r
F
.30913 .31865 m .3223 .3103 L .32287 .31163 L 1 0 0 r
F
.30913 .31865 m .31679 .30552 L .32061 .30634 L p F P
0 g
s
.30913 .31865 m .32061 .30634 L .3223 .3103 L 1 0 0 r
F
.32654 .30761 m .3295 .30824 L p .32729 .30936 L F P
0 g
s
.32654 .30761 m .32937 .30994 L p .32729 .30936 L 0 1 0 r
F P
0 g
s
.32937 .30994 m .32654 .30761 L p .32752 .30282 L 0 1 0 r
F P
0 g
s
.32654 .30761 m .31723 .29993 L p .32402 .30183 L 0 1 0 r
F P
0 g
s
.32402 .30183 m .32752 .30282 L .32654 .30761 L 0 1 0 r
F
.32654 .30761 m .32061 .30634 L p .32402 .30183 L 1 0 0 r
F P
0 g
s
.33039 .30928 m .32937 .30994 L p .32752 .30282 L 0 1 0 r
F P
0 g
s
.33674 .30135 m .32932 .3106 L .32061 .30634 L p 0 0 1 r
F P
0 g
s
.32061 .30634 m .31687 .3045 L p .31964 .30407 L 0 0 1 r
F P
0 g
s
.31964 .30407 m .32402 .30183 L .32061 .30634 L 1 0 0 r
F
.31964 .30407 m .33674 .30135 L .32061 .30634 L 0 0 1 r
F
.32061 .30634 m .31679 .30552 L p .31964 .30407 L 1 0 0 r
F P
0 g
s
.32449 .29229 m .33718 .29511 L p .32402 .30183 L 1 0 0 r
F P
0 g
s
.32401 .30183 m .32181 .2969 L .32402 .30183 L 0 1 0 r
F
.31723 .29993 m .32181 .2969 L p .32401 .30183 L F P
0 g
s
.29133 .29999 m .29818 .29484 L .31028 .30467 L p 0 1 0 r
F P
0 g
s
.31723 .29993 m .31028 .30467 L .29818 .29484 L p 0 1 0 r
F P
0 g
s
.29818 .29484 m .30508 .28992 L .31723 .29993 L p 0 1 0 r
F P
0 g
s
.30339 .30957 m .29654 .31472 L .28452 .30546 L p 0 1 0 r
F P
0 g
s
.28452 .30546 m .29133 .29999 L .30339 .30957 L p 0 1 0 r
F P
0 g
s
.31028 .30467 m .30339 .30957 L .29133 .29999 L p 0 1 0 r
F P
0 g
s
.31687 .3045 m .30954 .31373 L .29705 .30765 L p 0 0 1 r
F P
0 g
s
.31723 .29993 m .30508 .28992 L p .32063 .29426 L 0 1 0 r
F P
0 g
s
.32449 .29229 m .32181 .2969 L p .32063 .29426 L 1 0 0 r
F P
0 g
s
.32181 .2969 m .32449 .29229 L p .32402 .30183 L 1 0 0 r
F P
0 g
s
.32426 .29521 m .33674 .30135 L p .32752 .30282 L 0 0 1 r
F P
0 g
s
.29705 .30765 m .30436 .29838 L .31687 .3045 L p 0 0 1 r
F P
0 g
s
.32181 .2969 m .31723 .29993 L p .32063 .29426 L 0 1 0 r
F P
0 g
s
.31628 .29648 m .32063 .29426 L .31831 .30107 L 1 0 0 r
F
.32063 .29426 m .32411 .29523 L .32181 .2969 L 0 1 0 r
F
.32416 .29534 m .32181 .2969 L p .32411 .29523 L F P
0 g
s
.32063 .29426 m .32063 .29426 L .32181 .2969 L 1 0 0 r
F
.31687 .3045 m .30436 .29838 L p .31628 .29648 L 0 0 1 r
F P
0 g
s
.32181 .2969 m .31877 .30212 L p .32063 .29426 L 1 0 0 r
F P
0 g
s
.32063 .29426 m .31877 .30212 L .31831 .30107 L 1 0 0 r
F
.31964 .30407 m .32181 .2969 L .32402 .30183 L F
.31963 .30407 m .31963 .30406 L .31964 .30407 L 0 0 1 r
F
.31687 .3045 m .31877 .30212 L p .31963 .30407 L F P
0 g
s
.31679 .30552 m .31877 .30212 L p .31964 .30407 L 1 0 0 r
F P
0 g
s
.31877 .30212 m .32181 .2969 L p .31964 .30407 L 1 0 0 r
F P
0 g
s
.32181 .2969 m .32183 .29689 L p .32402 .30183 L 0 1 0 r
F P
0 g
s
.32402 .30183 m .32416 .29534 L .32752 .30282 L 0 1 0 r
F
.32183 .29689 m .32416 .29534 L p .32402 .30183 L F P
0 g
s
.31964 .30407 m .32416 .29534 L .32752 .30282 L 0 0 1 r
F
.31963 .30406 m .32416 .29534 L .31964 .30407 L F
.30508 .28992 m .31204 .28517 L .31927 .29115 L p 0 1 0 r
F P
0 g
s
.30508 .28992 m .31927 .29115 L .32058 .29416 L 0 1 0 r
F
.31927 .29115 m .32449 .29229 L p .32065 .29425 L 1 0 0 r
F P
0 g
s
.32063 .29426 m .31927 .29115 L .32065 .29425 L 1 0 0 r
F
.32416 .29534 m .32426 .29521 L p .32752 .30282 L 0 0 1 r
F P
0 g
s
.34488 .28203 m .33718 .29511 L .32449 .29229 L p 1 0 0 r
F P
0 g
s
.32449 .29229 m .3322 .27905 L .34488 .28203 L p 1 0 0 r
F P
0 g
s
.35745 .28512 m .34977 .29799 L .33718 .29511 L p 1 0 0 r
F P
0 g
s
.33718 .29511 m .34488 .28203 L .35745 .28512 L p 1 0 0 r
F P
0 g
s
.34422 .29203 m .33674 .30135 L .32426 .29521 L p 0 0 1 r
F P
0 g
s
.31927 .29115 m .31204 .28517 L p .31727 .28664 L 0 1 0 r
F P
0 g
s
.3322 .27905 m .32449 .29229 L .31927 .29115 L p 1 0 0 r
F P
0 g
s
.31727 .28664 m .31727 .28664 L .31927 .29115 L 0 1 0 r
F
.30508 .28992 m .30997 .29126 L .30995 .29128 L F
.30997 .29126 m .32405 .2951 L .30995 .29128 L F
.30995 .29128 m .32405 .2951 L .32411 .29523 L F
.30436 .29838 m .31173 .28903 L .31339 .28985 L p 0 0 1 r
F P
0 g
s
.32426 .29521 m .33171 .28584 L .34422 .29203 L p 0 0 1 r
F P
0 g
s
.32405 .2951 m .31927 .29115 L p .32222 .29102 L 0 1 0 r
F P
0 g
s
.31927 .29115 m .31339 .28985 L p .31727 .28664 L 1 0 0 r
F P
0 g
s
.31295 .28884 m .31727 .28664 L .31339 .28985 L 1 0 0 r
F
.31727 .28664 m .3322 .27905 L .31929 .29113 L F
.31727 .28664 m .31929 .29113 L .31927 .29115 L F
.33171 .28584 m .32426 .29521 L .32416 .29516 L p 0 0 1 r
F P
0 g
s
.31727 .28664 m .32068 .2876 L .31927 .29115 L 0 1 0 r
F
.32416 .29516 m .32405 .2951 L p .32068 .2876 L 0 0 1 r
F P
0 g
s
.32068 .2876 m .33171 .28584 L .32416 .29516 L 0 0 1 r
F
.32068 .2876 m .33136 .29062 L .32222 .29102 L 0 1 0 r
F
.32068 .2876 m .32222 .29102 L .31927 .29115 L F
.30436 .29838 m .31339 .28985 L .31627 .29648 L 0 0 1 r
F
.30399 .30275 m .31169 .28948 L .31339 .28985 L p 1 0 0 r
F P
0 g
s
.31339 .28985 m .31927 .29115 L p .31528 .29418 L 1 0 0 r
F P
0 g
s
.31628 .29648 m .31927 .29115 L .32063 .29426 L 1 0 0 r
F
.31528 .29418 m .31927 .29115 L .31628 .29648 L F
.31927 .29115 m .32405 .2951 L p .32058 .29416 L 0 1 0 r
F P
0 g
s
.31339 .28985 m .32405 .2951 L p .31628 .29648 L 0 0 1 r
F P
0 g
s
.31627 .29648 m .31339 .28985 L .31628 .29648 L 0 0 1 r
F
.30399 .30275 m .31528 .29418 L .31628 .29648 L 1 0 0 r
F
.30399 .30275 m .31339 .28985 L .31528 .29418 L F
.32405 .2951 m .31339 .28985 L p .32068 .2876 L 0 0 1 r
F P
0 g
s
.31339 .28985 m .31173 .28903 L p .31295 .28884 L 0 0 1 r
F P
0 g
s
.31295 .28884 m .32068 .2876 L .31339 .28985 L 0 0 1 r
F
.31942 .27613 m .3322 .27905 L p .31727 .28664 L 1 0 0 r
F P
0 g
s
.31726 .28664 m .31553 .28284 L .31727 .28664 L 0 1 0 r
F
.31204 .28517 m .31553 .28284 L p .31726 .28664 L F P
0 g
s
.28606 .28513 m .29291 .27998 L .30508 .28992 L p 0 1 0 r
F P
0 g
s
.31204 .28517 m .30508 .28992 L .29291 .27998 L p 0 1 0 r
F P
0 g
s
.29291 .27998 m .29981 .27506 L .31204 .28517 L p 0 1 0 r
F P
0 g
s
.29818 .29484 m .29133 .29999 L .27925 .2906 L p 0 1 0 r
F P
0 g
s
.27925 .2906 m .28606 .28513 L .29818 .29484 L p 0 1 0 r
F P
0 g
s
.30508 .28992 m .29818 .29484 L .28606 .28513 L p 0 1 0 r
F P
0 g
s
.31173 .28903 m .30436 .29838 L .29179 .29222 L p 0 0 1 r
F P
0 g
s
.31204 .28517 m .29981 .27506 L p .31379 .27899 L 0 1 0 r
F P
0 g
s
.31942 .27613 m .31553 .28284 L p .31379 .27899 L 1 0 0 r
F P
0 g
s
.31553 .28284 m .31942 .27613 L p .31727 .28664 L 1 0 0 r
F P
0 g
s
.31727 .28664 m .31842 .28271 L .32068 .2876 L 0 1 0 r
F
.31914 .27962 m .33171 .28584 L p .32065 .28761 L 0 0 1 r
F P
0 g
s
.29179 .29222 m .29913 .28283 L .31173 .28903 L p 0 0 1 r
F P
0 g
s
.31553 .28284 m .31204 .28517 L p .31379 .27899 L 0 1 0 r
F P
0 g
s
.30952 .28117 m .31378 .279 L .31217 .28709 L 1 0 0 r
F
.31379 .27899 m .31716 .27994 L .31553 .28284 L 0 1 0 r
F
.31779 .28134 m .31553 .28284 L p .31716 .27994 L F P
0 g
s
.31378 .279 m .31379 .27899 L .31553 .28284 L 1 0 0 r
F
.31173 .28903 m .29913 .28283 L p .30952 .28117 L 0 0 1 r
F P
0 g
s
.31553 .28284 m .31256 .28798 L p .31378 .279 L 1 0 0 r
F P
0 g
s
.31378 .279 m .31256 .28798 L .31217 .28709 L 1 0 0 r
F
.31295 .28884 m .31553 .28284 L .31727 .28664 L F
.31294 .28884 m .31295 .28883 L .31295 .28884 L 0 0 1 r
F
.31173 .28903 m .31256 .28798 L p .31294 .28884 L F P
0 g
s
.31169 .28948 m .31256 .28798 L p .31295 .28884 L 1 0 0 r
F P
0 g
s
.31256 .28798 m .31553 .28284 L p .31295 .28884 L 1 0 0 r
F P
0 g
s
.31553 .28284 m .31555 .28283 L p .31727 .28664 L 0 1 0 r
F P
0 g
s
.31555 .28283 m .31779 .28134 L p .31727 .28664 L 0 1 0 r
F P
0 g
s
.31779 .28134 m .31914 .27962 L p .32065 .28761 L 0 0 1 r
F P
0 g
s
.31779 .28134 m .31908 .28048 L p .31842 .28271 L 0 1 0 r
F P
0 g
s
.31779 .28134 m .31842 .28271 L .31727 .28664 L 0 1 0 r
F
.30952 .28117 m .31715 .27994 L .31256 .28798 L 0 0 1 r
F
.29981 .27506 m .30678 .27028 L .31174 .27439 L p 0 1 0 r
F P
0 g
s
.29981 .27506 m .31174 .27439 L .31319 .27765 L 0 1 0 r
F
.31174 .27439 m .31942 .27613 L p .31381 .27898 L 1 0 0 r
F P
0 g
s
.31379 .27899 m .31174 .27439 L .31381 .27898 L 1 0 0 r
F
.31914 .27962 m .31779 .28134 L p .31736 .28039 L 0 0 1 r
F P
0 g
s
.31716 .27994 m .31914 .27962 L .31736 .28039 L 0 0 1 r
F
.33994 .26586 m .3322 .27905 L .31942 .27613 L p 1 0 0 r
F P
0 g
s
.31942 .27613 m .32717 .26277 L .33994 .26586 L p 1 0 0 r
F P
0 g
s
.3526 .26907 m .34488 .28203 L .3322 .27905 L p 1 0 0 r
F P
0 g
s
.3322 .27905 m .33994 .26586 L .3526 .26907 L p 1 0 0 r
F P
0 g
s
.33921 .27641 m .33171 .28584 L .31914 .27962 L p 0 0 1 r
F P
0 g
s
.31174 .27439 m .30678 .27028 L p .31033 .27129 L 0 1 0 r
F P
0 g
s
.32717 .26277 m .31942 .27613 L .31174 .27439 L p 1 0 0 r
F P
0 g
s
.31033 .27129 m .31034 .27129 L .31174 .27439 L 0 1 0 r
F
.31174 .27439 m .30653 .27322 L p .31034 .27129 L 1 0 0 r
F P
0 g
s
.31034 .27129 m .32717 .26277 L .31176 .27438 L 1 0 0 r
F
.31914 .27962 m .32662 .27015 L .33921 .27641 L p 0 0 1 r
F P
0 g
s
.32662 .27015 m .31914 .27962 L .31653 .27833 L p 0 0 1 r
F P
0 g
s
.31034 .27129 m .31176 .27438 L .31174 .27439 L 1 0 0 r
F
.31034 .27129 m .31366 .27223 L .31174 .27439 L 0 1 0 r
F
.31653 .27833 m .31641 .27827 L p .31366 .27223 L 0 0 1 r
F P
0 g
s
.31366 .27223 m .32662 .27015 L .31653 .27833 L 0 0 1 r
F
.31366 .27223 m .32619 .27578 L .31478 .27468 L 0 1 0 r
F
.31366 .27223 m .31478 .27468 L .31174 .27439 L F
.31641 .27827 m .31914 .27962 L p .31717 .27994 L 0 0 1 r
F P
0 g
s
.32619 .27578 m .31908 .28048 L .31641 .27827 L p 0 1 0 r
F P
0 g
s
.31641 .27827 m .31174 .27439 L p .31478 .27468 L 0 1 0 r
F P
0 g
s
.31478 .27468 m .32619 .27578 L .31641 .27827 L 0 1 0 r
F
.29981 .27506 m .30449 .27596 L .30423 .2763 L F
.31374 .27898 m .31641 .27827 L .31716 .27994 L F
.30653 .27322 m .31174 .27439 L p .30805 .27787 L 1 0 0 r
F P
0 g
s
.29913 .28283 m .30622 .27376 L p .30909 .2802 L 0 0 1 r
F P
0 g
s
.30952 .28117 m .31641 .27827 L .31717 .27994 L 0 0 1 r
F
.29913 .28283 m .30909 .2802 L .30952 .28117 L F
.30952 .28117 m .31174 .27439 L .31379 .27899 L 1 0 0 r
F
.30805 .27787 m .31174 .27439 L .30952 .28117 L F
.30909 .2802 m .31641 .27827 L .30952 .28117 L 0 0 1 r
F
.29879 .28663 m .30805 .27787 L .30952 .28117 L 1 0 0 r
F
.29879 .28663 m .30622 .27376 L p .30805 .27787 L F P
0 g
s
.30622 .27376 m .30653 .27322 L p .30805 .27787 L 1 0 0 r
F P
0 g
s
.31174 .27439 m .31641 .27827 L p .31319 .27765 L 0 1 0 r
F P
0 g
s
.30652 .27338 m .31641 .27827 L p .30909 .2802 L 0 0 1 r
F P
0 g
s
.30622 .27376 m .30652 .27338 L p .30909 .2802 L 0 0 1 r
F P
0 g
s
.31641 .27827 m .30652 .27338 L p .31366 .27223 L 0 0 1 r
F P
0 g
s
.3143 .25973 m .32717 .26277 L p .31034 .27129 L 1 0 0 r
F P
0 g
s
.31033 .27128 m .30913 .2687 L .31034 .27129 L 0 1 0 r
F
.30678 .27028 m .30913 .2687 L p .31033 .27128 L F P
0 g
s
.28071 .27015 m .28756 .26499 L .29981 .27506 L p 0 1 0 r
F P
0 g
s
.30678 .27028 m .29981 .27506 L .28756 .26499 L p 0 1 0 r
F P
0 g
s
.28756 .26499 m .29447 .26006 L .30678 .27028 L p 0 1 0 r
F P
0 g
s
.30678 .27028 m .29447 .26006 L p .30677 .26356 L 0 1 0 r
F P
0 g
s
.3143 .25973 m .30913 .2687 L p .30677 .26356 L 1 0 0 r
F P
0 g
s
.30913 .2687 m .3143 .25973 L p .31034 .27129 L 1 0 0 r
F P
0 g
s
.31034 .27129 m .31196 .26862 L .31366 .27223 L 0 1 0 r
F
.31396 .26385 m .32662 .27015 L p .31362 .27223 L 0 0 1 r
F P
0 g
s
.30653 .27322 m .30913 .2687 L p .31034 .27129 L 1 0 0 r
F P
0 g
s
.30913 .2687 m .30915 .26869 L p .31034 .27129 L 0 1 0 r
F P
0 g
s
.30915 .26869 m .31131 .26724 L p .31034 .27129 L 0 1 0 r
F P
0 g
s
.31131 .26724 m .31396 .26385 L p .31362 .27215 L 0 0 1 r
F P
0 g
s
.31131 .26724 m .31382 .26556 L p .31196 .26862 L 0 1 0 r
F P
0 g
s
.31131 .26724 m .31196 .26862 L .31034 .27129 L 0 1 0 r
F
.31131 .26724 m .31362 .27215 L .31362 .27223 L 0 0 1 r
F
.30652 .27338 m .31131 .26724 L p .31362 .27223 L F P
0 g
s
.30677 .26356 m .31003 .26448 L .30913 .2687 L 0 1 0 r
F
.31131 .26724 m .30913 .2687 L p .31003 .26448 L F P
0 g
s
.30913 .2687 m .30678 .27028 L p .30677 .26356 L 0 1 0 r
F P
0 g
s
.30675 .26357 m .30677 .26356 L .30913 .2687 L 1 0 0 r
F
.30653 .27322 m .30591 .27308 L p .30675 .26357 L F P
0 g
s
.30913 .2687 m .30653 .27322 L p .30675 .26357 L 1 0 0 r
F P
0 g
s
.29291 .27998 m .28606 .28513 L .2739 .27561 L p 0 1 0 r
F P
0 g
s
.28606 .28513 m .27925 .2906 L .26711 .28145 L p 0 1 0 r
F P
0 g
s
.26711 .28145 m .2739 .27561 L .28606 .28513 L p 0 1 0 r
F P
0 g
s
.29913 .28283 m .29179 .29222 L .27916 .28603 L p 0 0 1 r
F P
0 g
s
.2739 .27561 m .28071 .27015 L .29291 .27998 L p 0 1 0 r
F P
0 g
s
.29981 .27506 m .29291 .27998 L .28071 .27015 L p 0 1 0 r
F P
0 g
s
.27916 .28603 m .28647 .2766 L .29913 .28283 L p 0 0 1 r
F P
0 g
s
.29913 .28283 m .28647 .2766 L p .30607 .27345 L 0 0 1 r
F P
0 g
s
.30622 .27376 m .29913 .28283 L p .30607 .27345 L 0 0 1 r
F P
0 g
s
.29879 .28663 m .2858 .28369 L p .30607 .27345 L 1 0 0 r
F P
0 g
s
.30653 .27322 m .30622 .27376 L p .30607 .27345 L 1 0 0 r
F P
0 g
s
.30622 .27376 m .29879 .28663 L p .30607 .27345 L 1 0 0 r
F P
0 g
s
.30652 .27338 m .30622 .27376 L p .30607 .27345 L 0 0 1 r
F P
0 g
s
.29447 .26006 m .30144 .25526 L .30393 .25733 L p 0 1 0 r
F P
0 g
s
.29447 .26006 m .30393 .25733 L .30556 .26091 L 0 1 0 r
F
.30393 .25733 m .3143 .25973 L p .30679 .26355 L 1 0 0 r
F P
0 g
s
.30677 .26356 m .30393 .25733 L .30679 .26355 L 1 0 0 r
F
.31396 .26385 m .3113 .26726 L p .31119 .26702 L 0 0 1 r
F P
0 g
s
.30257 .26569 m .30675 .26357 L .30591 .27308 L 1 0 0 r
F
.30257 .26569 m .31396 .26385 L .30591 .27308 L 0 0 1 r
F
.33495 .24947 m .32717 .26277 L .3143 .25973 L p 1 0 0 r
F P
0 g
s
.3143 .25973 m .32209 .24626 L .33495 .24947 L p 1 0 0 r
F P
0 g
s
.3477 .25281 m .33994 .26586 L .32717 .26277 L p 1 0 0 r
F P
0 g
s
.32717 .26277 m .33495 .24947 L .3477 .25281 L p 1 0 0 r
F P
0 g
s
.33414 .2606 m .32662 .27015 L .31396 .26385 L p 0 0 1 r
F P
0 g
s
.30393 .25733 m .30144 .25526 L p .30321 .25576 L 0 1 0 r
F P
0 g
s
.32209 .24626 m .3143 .25973 L .30393 .25733 L p 1 0 0 r
F P
0 g
s
.30321 .25576 m .30322 .25576 L .30393 .25733 L 0 1 0 r
F
.30393 .25733 m .30131 .25672 L p .30322 .25576 L 1 0 0 r
F P
0 g
s
.30322 .25576 m .32209 .24626 L .30395 .25732 L 1 0 0 r
F
.30912 .24311 m .32209 .24626 L p .30322 .25576 L F P
0 g
s
.30321 .25576 m .3026 .25448 L .30322 .25576 L 0 1 0 r
F
.30144 .25526 m .3026 .25448 L p .30321 .25576 L F P
0 g
s
.30144 .25526 m .29447 .26006 L .28214 .24988 L p 0 1 0 r
F P
0 g
s
.28214 .24988 m .28905 .24493 L .30144 .25526 L p 0 1 0 r
F P
0 g
s
.26848 .26049 m .27529 .25504 L .28756 .26499 L p 0 1 0 r
F P
0 g
s
.29447 .26006 m .28756 .26499 L .27529 .25504 L p 0 1 0 r
F P
0 g
s
.27529 .25504 m .28214 .24988 L .29447 .26006 L p 0 1 0 r
F P
0 g
s
.28108 .26079 m .28846 .25117 L .29817 .25599 L p 0 0 1 r
F P
0 g
s
.30677 .26356 m .3085 .26114 L .31003 .26448 L 0 1 0 r
F
.29447 .26006 m .30556 .26091 L .30677 .26356 L F
.30556 .26091 m .3085 .26114 L .30677 .26356 L F
.30591 .27308 m .29383 .2671 L p .30257 .26569 L 0 0 1 r
F P
0 g
s
.28647 .2766 m .29383 .2671 L .30591 .27308 L p 0 0 1 r
F P
0 g
s
.30591 .27308 m .30653 .27322 L p .30607 .27345 L 1 0 0 r
F P
0 g
s
.30591 .27308 m .30652 .27338 L p .30607 .27345 L 0 0 1 r
F P
0 g
s
.28647 .2766 m .30591 .27308 L .30607 .27345 L 0 0 1 r
F
.2858 .28369 m .29354 .27027 L .30591 .27308 L p 1 0 0 r
F P
0 g
s
.2858 .28369 m .30591 .27308 L .30607 .27345 L 1 0 0 r
F
.30131 .25672 m .30393 .25733 L p .30064 .26143 L F P
0 g
s
.3085 .26114 m .31396 .26385 L p .31005 .26448 L 0 0 1 r
F P
0 g
s
.31396 .26385 m .32146 .25426 L .33414 .2606 L p 0 0 1 r
F P
0 g
s
.3085 .26114 m .30393 .25733 L p .30704 .25797 L 0 1 0 r
F P
0 g
s
.32146 .25426 m .31396 .26385 L .30862 .26119 L p 0 0 1 r
F P
0 g
s
.30322 .25576 m .30395 .25732 L .30393 .25733 L 1 0 0 r
F
.30322 .25576 m .30645 .25668 L .30393 .25733 L 0 1 0 r
F
.30862 .26119 m .3085 .26114 L p .30645 .25668 L 0 0 1 r
F P
0 g
s
.30645 .25668 m .32146 .25426 L .30862 .26119 L 0 0 1 r
F
.30645 .25668 m .32094 .26081 L .30704 .25797 L 0 1 0 r
F
.30645 .25668 m .30704 .25797 L .30393 .25733 L F
.29383 .2671 m .29974 .25946 L p .30257 .26569 L 0 0 1 r
F P
0 g
s
.29354 .27027 m .30393 .25733 L .30677 .26356 L 1 0 0 r
F
.30393 .25733 m .3085 .26114 L p .30556 .26091 L 0 1 0 r
F P
0 g
s
.3085 .26114 m .30124 .25752 L p .30645 .25668 L 0 0 1 r
F P
0 g
s
.30322 .25576 m .3051 .25389 L .30645 .25668 L 0 1 0 r
F
.30131 .25672 m .3026 .25448 L p .30322 .25576 L 1 0 0 r
F P
0 g
s
.3026 .25448 m .30912 .24311 L p .30322 .25576 L 1 0 0 r
F P
0 g
s
.3026 .25448 m .30261 .25447 L p .30322 .25576 L 0 1 0 r
F P
0 g
s
.30871 .24788 m .32146 .25426 L p .30645 .25668 L 0 0 1 r
F P
0 g
s
.30261 .25447 m .3047 .25306 L p .30322 .25576 L 0 1 0 r
F P
0 g
s
.3047 .25306 m .3051 .25389 L .30322 .25576 L 0 1 0 r
F
.30124 .25752 m .3047 .25306 L p .30645 .25668 L 0 0 1 r
F P
0 g
s
.3047 .25306 m .30871 .24788 L p .30645 .25668 L 0 0 1 r
F P
0 g
s
.3047 .25306 m .30849 .2505 L p .3051 .25389 L 0 1 0 r
F P
0 g
s
.30849 .2505 m .32094 .26081 L p .30645 .25668 L 0 1 0 r
F P
0 g
s
.3051 .25389 m .30849 .2505 L .30645 .25668 L 0 1 0 r
F
.32094 .26081 m .31382 .26556 L .3085 .26114 L p F P
0 g
s
.30704 .25797 m .32094 .26081 L .3085 .26114 L 0 1 0 r
F
.30124 .25752 m .3085 .26114 L p .30257 .26569 L 0 0 1 r
F P
0 g
s
.30257 .26569 m .3085 .26114 L .31005 .26448 L 0 0 1 r
F
.29974 .25946 m .30131 .25672 L p .30064 .26143 L 1 0 0 r
F P
0 g
s
.29974 .25946 m .30124 .25752 L p .30257 .26569 L 0 0 1 r
F P
0 g
s
.29354 .27027 m .29974 .25946 L p .30064 .26143 L 1 0 0 r
F P
0 g
s
.28756 .26499 m .28071 .27015 L .26848 .26049 L p 0 1 0 r
F P
0 g
s
.28071 .27015 m .2739 .27561 L .26169 .26631 L p 0 1 0 r
F P
0 g
s
.26169 .26631 m .26848 .26049 L .28071 .27015 L p 0 1 0 r
F P
0 g
s
.29383 .2671 m .28647 .2766 L .27375 .27033 L p 0 0 1 r
F P
0 g
s
.27375 .27033 m .28108 .26079 L .29383 .2671 L p 0 0 1 r
F P
0 g
s
.30131 .25672 m .29974 .25946 L p .29901 .25789 L 1 0 0 r
F P
0 g
s
.29383 .2671 m .28108 .26079 L p .29901 .25789 L 0 0 1 r
F P
0 g
s
.30124 .25752 m .29973 .25948 L p .29901 .25789 L 0 0 1 r
F P
0 g
s
.29973 .25948 m .29383 .2671 L p .29901 .25789 L 0 0 1 r
F P
0 g
s
.28108 .26079 m .29814 .256 L .29901 .25789 L 0 0 1 r
F
.29814 .256 m .29817 .25599 L .29901 .25789 L F
.28044 .26726 m .28822 .25369 L .29817 .25599 L p 1 0 0 r
F P
0 g
s
.29817 .25599 m .30131 .25672 L p .29901 .25789 L 1 0 0 r
F P
0 g
s
.28044 .26726 m .29817 .25599 L .29901 .25789 L 1 0 0 r
F
.29354 .27027 m .28044 .26726 L p .29901 .25789 L F P
0 g
s
.29974 .25946 m .29354 .27027 L p .29901 .25789 L 1 0 0 r
F P
0 g
s
.29901 .25789 m .29817 .25599 L .29903 .25788 L 0 0 1 r
F
.29817 .25599 m .30124 .25752 L p .29903 .25788 L F P
0 g
s
.30144 .25526 m .28905 .24493 L p .29957 .24795 L 0 1 0 r
F P
0 g
s
.30912 .24311 m .3026 .25448 L p .29957 .24795 L 1 0 0 r
F P
0 g
s
.29957 .24795 m .30273 .24885 L .3026 .25448 L 0 1 0 r
F
.3026 .25448 m .30144 .25526 L p .29957 .24795 L F P
0 g
s
.29952 .24797 m .29957 .24795 L .3026 .25448 L 1 0 0 r
F
.30131 .25672 m .29817 .25599 L p .29952 .24797 L F P
0 g
s
.29545 .25003 m .29952 .24797 L .29817 .25599 L 1 0 0 r
F
.3026 .25448 m .30131 .25672 L p .29952 .24797 L F P
0 g
s
.29604 .24 m .30912 .24311 L p .29957 .24795 L 1 0 0 r
F P
0 g
s
.29602 .24033 m .29604 .24 L .29957 .24795 L 1 0 0 r
F
.28905 .24493 m .29594 .24017 L p .29957 .24795 L 0 1 0 r
F P
0 g
s
.29314 .24507 m .29594 .24017 L p .29545 .25003 L 1 0 0 r
F P
0 g
s
.29594 .24017 m .29604 .24 L p .29602 .24033 L 1 0 0 r
F P
0 g
s
.29594 .24017 m .29602 .24033 L .29545 .25003 L 1 0 0 r
F
.28905 .24493 m .27665 .23464 L p .2959 .24007 L 0 1 0 r
F P
0 g
s
.29594 .24017 m .28905 .24493 L p .2959 .24007 L 0 1 0 r
F P
0 g
s
.29823 .25602 m .28846 .25117 L p .29545 .25003 L 0 0 1 r
F P
0 g
s
.28214 .24988 m .27529 .25504 L .26298 .24524 L p 0 1 0 r
F P
0 g
s
.26298 .24524 m .26979 .23979 L .28214 .24988 L p 0 1 0 r
F P
0 g
s
.28905 .24493 m .28214 .24988 L .26979 .23979 L p 0 1 0 r
F P
0 g
s
.26979 .23979 m .27665 .23464 L .28905 .24493 L p 0 1 0 r
F P
0 g
s
.27529 .25504 m .26848 .26049 L .2562 .25104 L p 0 1 0 r
F P
0 g
s
.2562 .25104 m .26298 .24524 L .27529 .25504 L p 0 1 0 r
F P
0 g
s
.28846 .25117 m .28108 .26079 L .26826 .25444 L p 0 0 1 r
F P
0 g
s
.26826 .25444 m .27562 .24478 L .28846 .25117 L p 0 0 1 r
F P
0 g
s
.29603 .24011 m .30031 .24368 L p .29957 .24795 L 0 1 0 r
F P
0 g
s
.30031 .24368 m .30871 .24788 L p .30273 .24885 L 0 0 1 r
F P
0 g
s
.30273 .24885 m .30031 .24368 L .30273 .24885 L 0 0 1 r
F
.30871 .24788 m .3047 .25306 L p .30273 .24885 L F P
0 g
s
.34274 .23633 m .33495 .24947 L .32209 .24626 L p 1 0 0 r
F P
0 g
s
.32209 .24626 m .3299 .23286 L .34274 .23633 L p 1 0 0 r
F P
0 g
s
.3299 .23286 m .32209 .24626 L .30912 .24311 L p 1 0 0 r
F P
0 g
s
.32901 .24459 m .32146 .25426 L .30871 .24788 L p 0 0 1 r
F P
0 g
s
.30912 .24311 m .31695 .22952 L .3299 .23286 L p 1 0 0 r
F P
0 g
s
.30871 .24788 m .31624 .23817 L .32901 .24459 L p 0 0 1 r
F P
0 g
s
.30031 .24368 m .29603 .24011 L p .29904 .24097 L 0 1 0 r
F P
0 g
s
.29594 .24017 m .29603 .24011 L p .29957 .24795 L 0 1 0 r
F P
0 g
s
.29545 .25003 m .29602 .24033 L .29957 .24795 L 1 0 0 r
F
.31695 .22952 m .30912 .24311 L .29604 .24 L p F P
0 g
s
.31624 .23817 m .30871 .24788 L .3004 .24373 L p 0 0 1 r
F P
0 g
s
.3004 .24373 m .2959 .24148 L p .29904 .24097 L 0 0 1 r
F P
0 g
s
.29904 .24097 m .31624 .23817 L .3004 .24373 L 0 0 1 r
F
.29604 .24 m .30388 .22626 L .31695 .22952 L p 1 0 0 r
F P
0 g
s
.29603 .24011 m .29797 .23879 L p .29904 .24097 L 0 1 0 r
F P
0 g
s
.29071 .22304 m .30388 .22626 L p .29218 .23216 L 1 0 0 r
F P
0 g
s
.28356 .22968 m .28914 .22579 L p .28967 .22688 L 0 1 0 r
F P
0 g
s
.28914 .22579 m .29071 .22304 L p .29218 .23216 L 1 0 0 r
F P
0 g
s
.29218 .23216 m .30388 .22626 L .29586 .23996 L 1 0 0 r
F
.29218 .23216 m .29182 .2259 L .29524 .23305 L 0 1 0 r
F
.28356 .22968 m .28968 .22688 L .29218 .23216 L F
.28968 .22688 m .29182 .2259 L .29218 .23216 L F
.30388 .22626 m .29604 .24 L .29586 .23996 L p 1 0 0 r
F P
0 g
s
.29586 .23996 m .29584 .23995 L p .29218 .23216 L 1 0 0 r
F P
0 g
s
.27665 .23464 m .29584 .23995 L .2959 .24007 L 0 1 0 r
F
.28846 .25117 m .27562 .24478 L p .29177 .24215 L 0 0 1 r
F P
0 g
s
.29177 .24215 m .2959 .24007 L .29311 .24501 L 1 0 0 r
F
.29594 .24017 m .29314 .24507 L p .2959 .24007 L F P
0 g
s
.29314 .24507 m .29312 .2451 L p .29177 .24215 L 0 0 1 r
F P
0 g
s
.29312 .2451 m .28846 .25117 L p .29177 .24215 L 0 0 1 r
F P
0 g
s
.28846 .25117 m .29314 .24507 L p .29547 .25003 L 0 0 1 r
F P
0 g
s
.29314 .24507 m .28822 .25369 L p .29311 .24501 L 1 0 0 r
F P
0 g
s
.2959 .24007 m .29314 .24507 L .29311 .24501 L 1 0 0 r
F
.2959 .24148 m .29314 .24507 L p .29177 .24215 L 0 0 1 r
F P
0 g
s
.29015 .2386 m .29584 .23995 L p .29173 .24206 L 1 0 0 r
F P
0 g
s
.27665 .23464 m .28356 .22968 L .29584 .23995 L p 0 1 0 r
F P
0 g
s
.27562 .24478 m .28303 .23504 L .29015 .2386 L p 0 0 1 r
F P
0 g
s
.29177 .24215 m .29584 .23995 L .2959 .24007 L 1 0 0 r
F
.29173 .24206 m .29584 .23995 L .29177 .24215 L F
.29015 .2386 m .2959 .24148 L p .29177 .24215 L 0 0 1 r
F P
0 g
s
.27562 .24478 m .29015 .2386 L .29177 .24215 L 0 0 1 r
F
.27503 .25059 m .29173 .24206 L .29177 .24215 L 1 0 0 r
F
.27503 .25059 m .28285 .23687 L .29015 .2386 L p F P
0 g
s
.27503 .25059 m .29015 .2386 L .29173 .24206 L 1 0 0 r
F
.29584 .23995 m .29604 .24 L p .2959 .24007 L F P
0 g
s
.29604 .24 m .29594 .24017 L p .2959 .24007 L 1 0 0 r
F P
0 g
s
.29584 .23995 m .29603 .24011 L p .2959 .24007 L 0 1 0 r
F P
0 g
s
.29603 .24011 m .29584 .23995 L p .29524 .23305 L 0 1 0 r
F P
0 g
s
.29584 .23995 m .28356 .22968 L p .29218 .23216 L 0 1 0 r
F P
0 g
s
.29218 .23216 m .29524 .23305 L .29584 .23995 L 0 1 0 r
F
.29584 .23995 m .29015 .2386 L p .29218 .23216 L 1 0 0 r
F P
0 g
s
.29797 .23879 m .29603 .24011 L p .29524 .23305 L 0 1 0 r
F P
0 g
s
.29603 .24011 m .29594 .24017 L p .2959 .24007 L 0 1 0 r
F P
0 g
s
.3034 .23172 m .2959 .24148 L .29015 .2386 L p 0 0 1 r
F P
0 g
s
.29015 .2386 m .28303 .23504 L p .28813 .23421 L 0 0 1 r
F P
0 g
s
.28813 .23421 m .29218 .23216 L .29015 .2386 L 1 0 0 r
F
.28813 .23421 m .3034 .23172 L .29015 .2386 L 0 0 1 r
F
.29015 .2386 m .28285 .23687 L p .28813 .23421 L 1 0 0 r
F P
0 g
s
.28813 .23421 m .28914 .22579 L .29218 .23216 L 1 0 0 r
F
.29054 .22482 m .29182 .2259 L p .28967 .22688 L 0 1 0 r
F P
0 g
s
.29182 .2259 m .3034 .23172 L p .29522 .23305 L 0 0 1 r
F P
0 g
s
.3034 .23172 m .31624 .23817 L p .29903 .24097 L 0 0 1 r
F P
0 g
s
.29902 .24094 m .3034 .23172 L .29903 .24097 L 0 0 1 r
F
.29797 .23879 m .3034 .23172 L p .299 .24097 L F P
0 g
s
.33772 .21963 m .3299 .23286 L .31695 .22952 L p 1 0 0 r
F P
0 g
s
.31695 .22952 m .32479 .21603 L .33772 .21963 L p 1 0 0 r
F P
0 g
s
.32479 .21603 m .31695 .22952 L .30388 .22626 L p 1 0 0 r
F P
0 g
s
.32382 .22838 m .31624 .23817 L .3034 .23172 L p 0 0 1 r
F P
0 g
s
.30388 .22626 m .31175 .21256 L .32479 .21603 L p 1 0 0 r
F P
0 g
s
.3034 .23172 m .31095 .22188 L .32382 .22838 L p 0 0 1 r
F P
0 g
s
.29182 .2259 m .29054 .22482 L p .29143 .22508 L 0 1 0 r
F P
0 g
s
.31175 .21256 m .30388 .22626 L .29071 .22304 L p 1 0 0 r
F P
0 g
s
.31095 .22188 m .3034 .23172 L .29186 .22591 L p 0 0 1 r
F P
0 g
s
.29186 .22591 m .2905 .22523 L p .29143 .22508 L 0 0 1 r
F P
0 g
s
.29143 .22508 m .31095 .22188 L .29186 .22591 L 0 0 1 r
F
.29054 .22482 m .29111 .22443 L p .29143 .22508 L 0 1 0 r
F P
0 g
s
.29071 .22304 m .29859 .20918 L .31175 .21256 L p 1 0 0 r
F P
0 g
s
.2905 .22523 m .29802 .21535 L .31095 .22188 L p 0 0 1 r
F P
0 g
s
.2976 .21997 m .31022 .23044 L p .29143 .22508 L 0 1 0 r
F P
0 g
s
.29111 .22443 m .2976 .21997 L p .29143 .22508 L 0 1 0 r
F P
0 g
s
.31022 .23044 m .30308 .23531 L .29182 .2259 L p 0 1 0 r
F P
0 g
s
.29143 .22508 m .31022 .23044 L .29182 .2259 L 0 1 0 r
F
.2905 .22523 m .29182 .2259 L p .28813 .23421 L 0 0 1 r
F P
0 g
s
.28813 .23421 m .29182 .2259 L .29522 .23305 L 0 0 1 r
F
.28303 .23504 m .28642 .2306 L p .28813 .23421 L F P
0 g
s
.28642 .2306 m .28914 .22579 L p .28813 .23421 L 1 0 0 r
F P
0 g
s
.28914 .22579 m .29054 .22482 L p .28967 .22688 L 0 1 0 r
F P
0 g
s
.28642 .2306 m .2905 .22523 L p .28813 .23421 L 0 0 1 r
F P
0 g
s
.28285 .23687 m .28642 .2306 L p .28813 .23421 L 1 0 0 r
F P
0 g
s
.29182 .2259 m .30308 .23531 L p .29524 .23305 L 0 1 0 r
F P
0 g
s
.299 .24097 m .29902 .24094 L .29903 .24097 L 0 0 1 r
F
.2959 .24148 m .29797 .23879 L p .299 .24097 L F P
0 g
s
.30308 .23531 m .29797 .23879 L p .29524 .23305 L 0 1 0 r
F P
0 g
s
.30308 .23531 m .31562 .24569 L p .29904 .24097 L 0 1 0 r
F P
0 g
s
.29797 .23879 m .30308 .23531 L p .29904 .24097 L 0 1 0 r
F P
0 g
s
.31562 .24569 m .30849 .2505 L .30031 .24368 L p 0 1 0 r
F P
0 g
s
.29904 .24097 m .31562 .24569 L .30031 .24368 L 0 1 0 r
F
.30031 .24368 m .30849 .2505 L p .30273 .24885 L F P
0 g
s
.29957 .24795 m .30031 .24368 L .30273 .24885 L 0 1 0 r
F
.2959 .24148 m .30031 .24368 L p .29547 .25003 L 0 0 1 r
F P
0 g
s
.29547 .25003 m .30031 .24368 L .30273 .24885 L 0 0 1 r
F
.29314 .24507 m .2959 .24148 L p .29547 .25003 L F P
0 g
s
.28822 .25369 m .27503 .25059 L p .29177 .24215 L 1 0 0 r
F P
0 g
s
.29177 .24215 m .29311 .24501 L .28822 .25369 L 1 0 0 r
F
.28822 .25369 m .29314 .24507 L p .29545 .25003 L F P
0 g
s
.30124 .25752 m .29823 .25602 L p .30273 .24885 L 0 0 1 r
F P
0 g
s
.29545 .25003 m .30273 .24885 L .29823 .25602 L 0 0 1 r
F
.3047 .25306 m .3026 .25448 L p .30273 .24885 L 0 1 0 r
F P
0 g
s
.3047 .25306 m .30124 .25752 L p .30273 .24885 L 0 0 1 r
F P
0 g
s
.30849 .2505 m .3047 .25306 L p .30273 .24885 L 0 1 0 r
F P
0 g
s
.29817 .25599 m .28822 .25369 L p .29545 .25003 L 1 0 0 r
F P
0 g
s
.3085 .26114 m .31382 .26556 L p .31003 .26448 L 0 1 0 r
F P
0 g
s
.30652 .27338 m .30591 .27308 L p .31119 .26702 L 0 0 1 r
F P
0 g
s
.3113 .26726 m .30652 .27338 L p .31119 .26702 L 0 0 1 r
F P
0 g
s
.30591 .27308 m .29354 .27027 L p .30257 .26569 L 1 0 0 r
F P
0 g
s
.31382 .26556 m .31131 .26724 L p .31003 .26448 L 0 1 0 r
F P
0 g
s
.31382 .26556 m .32619 .27578 L p .31366 .27223 L 0 1 0 r
F P
0 g
s
.31196 .26862 m .31382 .26556 L .31366 .27223 L 0 1 0 r
F
.31641 .27827 m .31908 .28048 L p .31716 .27994 L F P
0 g
s
.31715 .27994 m .31716 .27994 L .31736 .28039 L 0 0 1 r
F
.31779 .28134 m .31256 .28798 L p .31715 .27994 L F P
0 g
s
.31295 .28884 m .31779 .28134 L .32065 .28761 L 0 0 1 r
F
.31295 .28883 m .31779 .28134 L .31295 .28884 L F
.31256 .28798 m .31173 .28903 L p .30952 .28117 L F P
0 g
s
.31256 .28798 m .31169 .28948 L p .31217 .28709 L 1 0 0 r
F P
0 g
s
.31169 .28948 m .29879 .28663 L p .30952 .28117 L 1 0 0 r
F P
0 g
s
.30952 .28117 m .31217 .28709 L .31169 .28948 L 1 0 0 r
F
.31256 .28798 m .31779 .28134 L p .31294 .28884 L 0 0 1 r
F P
0 g
s
.31908 .28048 m .31779 .28134 L p .31716 .27994 L 0 1 0 r
F P
0 g
s
.31908 .28048 m .33136 .29062 L p .32068 .2876 L 0 1 0 r
F P
0 g
s
.31842 .28271 m .31908 .28048 L .32068 .2876 L 0 1 0 r
F
.33136 .29062 m .32426 .29528 L .32405 .2951 L p F P
0 g
s
.32222 .29102 m .33136 .29062 L .32405 .2951 L 0 1 0 r
F
.32405 .2951 m .32426 .29521 L p .32411 .29523 L 0 0 1 r
F P
0 g
s
.31627 .29648 m .32405 .2951 L .32411 .29523 L 0 0 1 r
F
.31339 .28985 m .31169 .28948 L p .31295 .28884 L 1 0 0 r
F P
0 g
s
.32405 .2951 m .32426 .29528 L p .32411 .29523 L 0 1 0 r
F P
0 g
s
.31628 .29648 m .32411 .29523 L .31877 .30212 L 0 0 1 r
F
.32426 .29521 m .32416 .29534 L p .32411 .29523 L F P
0 g
s
.32416 .29534 m .31877 .30212 L p .32411 .29523 L 0 0 1 r
F P
0 g
s
.31877 .30212 m .31687 .3045 L p .31628 .29648 L 0 0 1 r
F P
0 g
s
.31877 .30212 m .31679 .30552 L p .31831 .30107 L 1 0 0 r
F P
0 g
s
.31679 .30552 m .30399 .30275 L p .31628 .29648 L 1 0 0 r
F P
0 g
s
.31628 .29648 m .31831 .30107 L .31679 .30552 L 1 0 0 r
F
.31877 .30212 m .32416 .29534 L p .31963 .30407 L 0 0 1 r
F P
0 g
s
.32426 .29528 m .32416 .29534 L p .32411 .29523 L 0 1 0 r
F P
0 g
s
.32426 .29528 m .33647 .30533 L p .32752 .30282 L 0 1 0 r
F P
0 g
s
.32416 .29534 m .32426 .29528 L p .32752 .30282 L 0 1 0 r
F P
0 g
s
.33086 .31036 m .3309 .31031 L .33091 .31035 L 0 0 1 r
F
.32932 .3106 m .33039 .30928 L p .33086 .31036 L F P
0 g
s
.33647 .30533 m .33039 .30928 L p .32752 .30282 L 0 1 0 r
F P
0 g
s
.33647 .30533 m .34866 .31526 L p .33089 .31036 L 0 1 0 r
F P
0 g
s
.33039 .30928 m .33647 .30533 L p .33089 .31036 L 0 1 0 r
F P
0 g
s
.34866 .31526 m .3415 .3199 L .33145 .31165 L p 0 1 0 r
F P
0 g
s
.33089 .31036 m .34866 .31526 L .33145 .31165 L 0 1 0 r
F
.32932 .3106 m .33145 .31165 L p .32614 .31913 L 0 0 1 r
F P
0 g
s
.32614 .31913 m .33145 .31165 L .33417 .31787 L 0 0 1 r
F
.32486 .31618 m .32932 .3106 L p .32614 .31913 L F P
0 g
s
.32184 .32133 m .30913 .31865 L p .32287 .31163 L 1 0 0 r
F P
0 g
s
.32287 .31163 m .32453 .31543 L .32184 .32133 L 1 0 0 r
F
.33145 .31165 m .3415 .3199 L p .33418 .31786 L 0 1 0 r
F P
0 g
s
.33744 .32533 m .33746 .3253 L .33747 .32532 L 0 0 1 r
F
.33432 .32582 m .33649 .32314 L p .33744 .32533 L F P
0 g
s
.3415 .3199 m .33649 .32314 L p .33418 .31786 L 0 1 0 r
F P
0 g
s
.3415 .3199 m .35362 .32976 L p .33748 .32532 L 0 1 0 r
F P
0 g
s
.33649 .32314 m .3415 .3199 L p .33748 .32532 L 0 1 0 r
F P
0 g
s
.35362 .32976 m .34647 .33435 L .33859 .3279 L p 0 1 0 r
F P
0 g
s
.33748 .32532 m .35362 .32976 L .33859 .3279 L 0 1 0 r
F
.33432 .32582 m .33859 .3279 L p .33248 .33403 L 0 0 1 r
F P
0 g
s
.33248 .33403 m .33859 .3279 L .34068 .33275 L 0 0 1 r
F
.32698 .33489 m .33081 .33016 L p .33248 .33403 L F P
0 g
s
.33081 .33016 m .33432 .32582 L p .33248 .33403 L 0 0 1 r
F P
0 g
s
.33081 .33016 m .32683 .33693 L p .3307 .3299 L 1 0 0 r
F P
0 g
s
.32683 .33693 m .33081 .33016 L p .33247 .33403 L 1 0 0 r
F P
0 g
s
.3344 .33849 m .33436 .33847 L p .33248 .33403 L 0 0 1 r
F P
0 g
s
.33247 .33403 m .33248 .33403 L .33436 .33847 L 0 0 1 r
F
.32683 .33693 m .31422 .33432 L p .32929 .32661 L 1 0 0 r
F P
0 g
s
.32929 .32661 m .3307 .3299 L .32683 .33693 L 1 0 0 r
F
.33859 .3279 m .34647 .33435 L p .34067 .33275 L 0 1 0 r
F P
0 g
s
.33431 .33845 m .32683 .33693 L p .33247 .33403 L 1 0 0 r
F P
0 g
s
.31925 .34978 m .32683 .33693 L .33431 .33845 L p 1 0 0 r
F P
0 g
s
.31925 .34978 m .33431 .33845 L .33553 .34143 L 1 0 0 r
F
.33177 .35231 m .31925 .34978 L p .33553 .34143 L F P
0 g
s
.33665 .34405 m .33177 .35231 L p .33553 .34143 L 1 0 0 r
F P
0 g
s
.33865 .34877 m .34548 .34386 L .34699 .34747 L 0 0 1 r
F
.33797 .34717 m .34548 .34386 L .33865 .34877 L F
.35851 .34413 m .35137 .34868 L .34548 .34386 L p 0 1 0 r
F P
0 g
s
.34409 .34059 m .35851 .34413 L .34548 .34386 L 0 1 0 r
F
.33177 .35231 m .33665 .34405 L p .33862 .34878 L 1 0 0 r
F P
0 g
s
.34414 .3557 m .34086 .35412 L p .34699 .34747 L 0 0 1 r
F P
0 g
s
.33862 .34878 m .34699 .34747 L .34086 .35412 L 0 0 1 r
F
.34832 .35062 m .34565 .35232 L p .34699 .34747 L 0 1 0 r
F P
0 g
s
.34832 .35062 m .34414 .3557 L p .34699 .34747 L 0 0 1 r
F P
0 g
s
.35137 .34868 m .34832 .35062 L p .34699 .34747 L 0 1 0 r
F P
0 g
s
.34081 .3541 m .33177 .35231 L p .33862 .34878 L 1 0 0 r
F P
0 g
s
.35212 .35955 m .3562 .36288 L p .35315 .36205 L 0 1 0 r
F P
0 g
s
.34897 .37038 m .34709 .36948 L p .35382 .36368 L 0 0 1 r
F P
0 g
s
.35405 .36425 m .34897 .37038 L p .35382 .36368 L 0 0 1 r
F P
0 g
s
.34709 .36948 m .33666 .36747 L p .34461 .36337 L 1 0 0 r
F P
0 g
s
.3562 .36288 m .35406 .36424 L p .35315 .36205 L 0 1 0 r
F P
0 g
s
.35854 .37498 m .36098 .37696 L p .35913 .37646 L 0 1 0 r
F P
0 g
s
.35374 .38489 m .35316 .38461 L p .35962 .37768 L 0 0 1 r
F P
0 g
s
.35967 .3778 m .35374 .38489 L p .35962 .37768 L 0 0 1 r
F P
0 g
s
.35316 .38461 m .34149 .38242 L p .35043 .3778 L 1 0 0 r
F P
0 g
s
.36098 .37696 m .35967 .37779 L p .35913 .37646 L 0 1 0 r
F P
0 g
s
.36098 .37696 m .37279 .38649 L p .3621 .38361 L 0 1 0 r
F P
0 g
s
.36006 .3787 m .36098 .37696 L .3621 .38361 L 0 1 0 r
F
.37279 .38649 m .36569 .39092 L .36473 .39014 L p F P
0 g
s
.36305 .38597 m .37279 .38649 L .36473 .39014 L 0 1 0 r
F
.35342 .38527 m .35374 .38489 L p .35609 .39208 L 0 0 1 r
F P
0 g
s
.34627 .39717 m .35342 .38527 L p .35507 .38948 L 1 0 0 r
F P
0 g
s
.36473 .39014 m .36569 .39092 L p .36496 .39073 L 0 1 0 r
F P
0 g
s
.35844 .39939 m .35876 .39886 L p .35888 .39916 L 1 0 0 r
F P
0 g
s
.35901 .3995 m .35844 .39939 L p .35888 .39916 L 1 0 0 r
F P
0 g
s
.36569 .39092 m .37743 .40037 L p .36783 .3978 L 0 1 0 r
F P
0 g
s
.36517 .39125 m .36569 .39092 L p .36783 .3978 L 0 1 0 r
F P
0 g
s
.37062 .40484 m .37067 .40478 L .37069 .40483 L 0 0 1 r
F
.37034 .40489 m .37054 .40465 L p .37062 .40484 L F P
0 g
s
.37743 .40037 m .37054 .40465 L p .36783 .3978 L 0 1 0 r
F P
0 g
s
.37743 .40037 m .38916 .4097 L p .37062 .40484 L 0 1 0 r
F P
0 g
s
.37054 .40465 m .37743 .40037 L p .37062 .40484 L 0 1 0 r
F P
0 g
s
.38916 .4097 m .38202 .41414 L .37071 .40506 L p 0 1 0 r
F P
0 g
s
.37062 .40484 m .38916 .4097 L .37071 .40506 L 0 1 0 r
F
.37034 .40489 m .37071 .40506 L p .36431 .41322 L 0 0 1 r
F P
0 g
s
.36431 .41322 m .37071 .40506 L .37335 .41185 L 0 0 1 r
F
.36311 .41341 m .36398 .41238 L p .36431 .41322 L F P
0 g
s
.36398 .41238 m .37034 .40489 L p .36431 .41322 L 0 0 1 r
F P
0 g
s
.36398 .41238 m .36308 .41386 L p .36376 .41179 L 1 0 0 r
F P
0 g
s
.36159 .40622 m .36376 .41179 L .36308 .41386 L 1 0 0 r
F
.37034 .40489 m .36398 .41238 L p .36159 .40622 L 0 0 1 r
F P
0 g
s
.351 .41171 m .36077 .40408 L .36159 .40622 L 1 0 0 r
F
.36308 .41386 m .36398 .41238 L p .36431 .41322 L F P
0 g
s
.37492 .419 m .36468 .41415 L p .3734 .41185 L 0 0 1 r
F P
0 g
s
.36431 .41322 m .3734 .41185 L .36468 .41415 L 0 0 1 r
F
.41786 .41104 m .41048 .4226 L .39877 .42028 L p 1 0 0 r
F P
0 g
s
.39877 .42028 m .40617 .40847 L .41786 .41104 L p 1 0 0 r
F P
0 g
s
.38668 .42456 m .39397 .41612 L .4057 .4217 L p 0 0 1 r
F P
0 g
s
.39397 .41612 m .38668 .42456 L .37492 .419 L p 0 0 1 r
F P
0 g
s
.38202 .41414 m .39367 .42338 L p .37613 .41881 L 0 1 0 r
F P
0 g
s
.37495 .4185 m .37579 .41798 L p .37613 .41881 L 0 1 0 r
F P
0 g
s
.37613 .41881 m .37583 .41794 L .37617 .41881 L 0 0 1 r
F
.37581 .41796 m .37583 .41794 L p .37613 .41881 L F P
0 g
s
.37579 .41798 m .38202 .41414 L p .37613 .41881 L 0 1 0 r
F P
0 g
s
.37579 .41798 m .37492 .419 L p .37357 .41263 L 0 0 1 r
F P
0 g
s
.3734 .41185 m .37579 .41798 L .37357 .41263 L 0 0 1 r
F
.3734 .41185 m .38202 .41414 L .37458 .41487 L 0 1 0 r
F
.36466 .41414 m .36308 .41386 L p .36431 .41322 L 1 0 0 r
F P
0 g
s
.35568 .42606 m .36629 .41849 L .36693 .4202 L 1 0 0 r
F
.36767 .42813 m .35568 .42606 L p .36693 .4202 L F P
0 g
s
.36693 .4202 m .36884 .42518 L .36767 .42813 L 1 0 0 r
F
.37011 .42855 m .36767 .42813 L p .36959 .42713 L F P
0 g
s
.4057 .4217 m .39839 .4301 L .38668 .42456 L p 0 0 1 r
F P
0 g
s
.39367 .42338 m .38654 .42779 L .37648 .41974 L p 0 1 0 r
F P
0 g
s
.37613 .41881 m .39367 .42338 L .37648 .41974 L 0 1 0 r
F
.37492 .419 m .37581 .41796 L p .37613 .41881 L 0 0 1 r
F P
0 g
s
.37071 .40506 m .38202 .41414 L p .3734 .41185 L 0 1 0 r
F P
0 g
s
.37648 .41974 m .38654 .42779 L p .37882 .42575 L 0 1 0 r
F P
0 g
s
.38145 .43264 m .38148 .4326 L .38149 .43264 L 0 0 1 r
F
.37945 .43294 m .38092 .43124 L p .38145 .43264 L F P
0 g
s
.38654 .42779 m .38092 .43124 L p .37882 .42575 L 0 1 0 r
F P
0 g
s
.38654 .42779 m .39813 .43695 L p .38148 .43264 L 0 1 0 r
F P
0 g
s
.38092 .43124 m .38654 .42779 L p .38148 .43264 L 0 1 0 r
F P
0 g
s
.39813 .43695 m .39101 .44132 L .38206 .43417 L p 0 1 0 r
F P
0 g
s
.38148 .43264 m .39813 .43695 L .38206 .43417 L 0 1 0 r
F
.37945 .43294 m .38206 .43417 L p .37471 .4409 L 0 0 1 r
F P
0 g
s
.37471 .4409 m .38206 .43417 L .38405 .43951 L 0 0 1 r
F
.37471 .4409 m .37945 .43294 L .37471 .4409 L F
.37406 .43919 m .37945 .43294 L p .3747 .4409 L F P
0 g
s
.37384 .4386 m .37384 .4386 L .37222 .4422 L 1 0 0 r
F
.37213 .43404 m .37384 .4386 L .37222 .4422 L F
.37945 .43294 m .37406 .43919 L p .37213 .43404 L 0 0 1 r
F P
0 g
s
.36031 .4402 m .36767 .42813 L .37011 .42855 L p 1 0 0 r
F P
0 g
s
.36031 .4402 m .37011 .42855 L .37164 .43272 L 1 0 0 r
F
.38206 .43417 m .39101 .44132 L p .38408 .4395 L 0 1 0 r
F P
0 g
s
.38663 .44633 m .38665 .44629 L .38667 .44632 L 0 0 1 r
F
.38392 .44673 m .38592 .44443 L p .38663 .44633 L F P
0 g
s
.39101 .44132 m .38592 .44443 L p .38408 .4395 L 0 1 0 r
F P
0 g
s
.39101 .44132 m .40253 .45041 L p .38667 .44632 L 0 1 0 r
F P
0 g
s
.38592 .44443 m .39101 .44132 L p .38667 .44632 L 0 1 0 r
F P
0 g
s
.40253 .45041 m .39543 .45474 L .38742 .44837 L p 0 1 0 r
F P
0 g
s
.38667 .44632 m .40253 .45041 L .38742 .44837 L 0 1 0 r
F
.38392 .44673 m .38742 .44837 L p .37967 .45453 L 0 0 1 r
F P
0 g
s
.37967 .45453 m .38742 .44837 L .38917 .45312 L 0 0 1 r
F
.37892 .45249 m .38392 .44673 L p .37967 .45453 L F P
0 g
s
.37671 .45608 m .36488 .45415 L p .37717 .44774 L 1 0 0 r
F P
0 g
s
.37717 .44774 m .37874 .45199 L .37671 .45608 L 1 0 0 r
F
.38742 .44837 m .39543 .45474 L p .38918 .45312 L 0 1 0 r
F P
0 g
s
.39166 .45988 m .39168 .45985 L .39169 .45987 L 0 0 1 r
F
.38835 .46037 m .39081 .45756 L p .39166 .45988 L F P
0 g
s
.39543 .45474 m .39081 .45756 L p .38918 .45312 L 0 1 0 r
F P
0 g
s
.39543 .45474 m .40688 .46375 L p .39171 .45987 L 0 1 0 r
F P
0 g
s
.39081 .45756 m .39543 .45474 L p .39171 .45987 L 0 1 0 r
F P
0 g
s
.40688 .46375 m .39979 .46805 L .3926 .46235 L p 0 1 0 r
F P
0 g
s
.39171 .45987 m .40688 .46375 L .3926 .46235 L 0 1 0 r
F
.38835 .46037 m .3926 .46235 L p .3845 .46802 L 0 0 1 r
F P
0 g
s
.3845 .46802 m .3926 .46235 L .39413 .4666 L 0 0 1 r
F
.38366 .46571 m .38835 .46037 L p .3845 .46802 L F P
0 g
s
.38116 .46977 m .36941 .46791 L p .38206 .4613 L 1 0 0 r
F P
0 g
s
.38206 .4613 m .38352 .46533 L .38116 .46977 L 1 0 0 r
F
.3926 .46235 m .39979 .46805 L p .39414 .46659 L 0 1 0 r
F P
0 g
s
.39654 .47328 m .39655 .47326 L .39656 .47328 L 0 0 1 r
F
.39272 .47385 m .39558 .47061 L p .39654 .47328 L F P
0 g
s
.39979 .46805 m .39558 .47061 L p .39414 .46659 L 0 1 0 r
F P
0 g
s
.39979 .46805 m .41117 .47698 L p .39659 .47328 L 0 1 0 r
F P
0 g
s
.39558 .47061 m .39979 .46805 L p .39659 .47328 L 0 1 0 r
F P
0 g
s
.41117 .47698 m .40411 .48126 L .39759 .47611 L p 0 1 0 r
F P
0 g
s
.39659 .47328 m .41117 .47698 L .39759 .47611 L 0 1 0 r
F
.39272 .47385 m .39759 .47611 L p .38918 .48137 L 0 0 1 r
F P
0 g
s
.38918 .48137 m .39759 .47611 L .39894 .47994 L 0 0 1 r
F
.38829 .47887 m .39272 .47385 L p .38918 .48137 L F P
0 g
s
.38555 .48327 m .37389 .48147 L p .38681 .47472 L 1 0 0 r
F P
0 g
s
.38681 .47472 m .38819 .47859 L .38555 .48327 L 1 0 0 r
F
.39759 .47611 m .40411 .48126 L p .39894 .47994 L 0 1 0 r
F P
0 g
s
.40127 .48656 m .40128 .48654 L .40128 .48656 L 0 0 1 r
F
.39705 .48718 m .40023 .4836 L p .40127 .48656 L F P
0 g
s
.40411 .48126 m .40023 .4836 L p .39894 .47994 L 0 1 0 r
F P
0 g
s
.40411 .48126 m .41542 .4901 L p .40133 .48655 L 0 1 0 r
F P
0 g
s
.40023 .4836 m .40411 .48126 L p .40133 .48655 L 0 1 0 r
F P
0 g
s
.41542 .4901 m .40837 .49435 L .4024 .48965 L p 0 1 0 r
F P
0 g
s
.40133 .48655 m .41542 .4901 L .4024 .48965 L 0 1 0 r
F
.39705 .48718 m .4024 .48965 L p .39371 .49459 L 0 0 1 r
F P
0 g
s
.39371 .49459 m .4024 .48965 L .4036 .49314 L 0 0 1 r
F
.39279 .49196 m .39705 .48718 L p .39371 .49459 L F P
0 g
s
.3899 .49658 m .37832 .49486 L p .39141 .488 L 1 0 0 r
F P
0 g
s
.39141 .488 m .39273 .49177 L .3899 .49658 L 1 0 0 r
F
.4024 .48965 m .40837 .49435 L p .4036 .49314 L 0 1 0 r
F P
0 g
s
.40586 .4997 m .40586 .49969 L .40586 .4997 L 0 0 1 r
F
.40133 .50036 m .40477 .49652 L p .40586 .4997 L F P
0 g
s
.40837 .49435 m .40477 .49652 L p .4036 .49314 L 0 1 0 r
F P
0 g
s
.40837 .49435 m .41961 .50311 L p .40592 .49969 L 0 1 0 r
F P
0 g
s
.40477 .49652 m .40837 .49435 L p .40592 .49969 L 0 1 0 r
F P
0 g
s
.41961 .50311 m .41258 .50734 L .40703 .50298 L p 0 1 0 r
F P
0 g
s
.40592 .49969 m .41961 .50311 L .40703 .50298 L 0 1 0 r
F
.40133 .50036 m .40703 .50298 L p .39811 .50767 L 0 0 1 r
F P
0 g
s
.39811 .50767 m .40703 .50298 L .40812 .50621 L 0 0 1 r
F
.39719 .50497 m .40133 .50036 L p .39811 .50767 L F P
0 g
s
.39421 .50972 m .38271 .50806 L p .39588 .50115 L 1 0 0 r
F P
0 g
s
.39588 .50115 m .39715 .50486 L .39421 .50972 L 1 0 0 r
F
.40703 .50298 m .41258 .50734 L p .40812 .50621 L 0 1 0 r
F P
0 g
s
.40556 .51339 m .40918 .50938 L p .4103 .51271 L 0 0 1 r
F P
0 g
s
.41258 .50734 m .40918 .50938 L p .40812 .50621 L 0 1 0 r
F P
0 g
s
.41258 .50734 m .42376 .51602 L p .41036 .5127 L 0 1 0 r
F P
0 g
s
.40918 .50938 m .41258 .50734 L p .41036 .5127 L 0 1 0 r
F P
0 g
s
.42376 .51602 m .41675 .52022 L .41149 .51611 L p 0 1 0 r
F P
0 g
s
.41036 .5127 m .42376 .51602 L .41149 .51611 L 0 1 0 r
F
.40556 .51339 m .41149 .51611 L p .40237 .52062 L 0 0 1 r
F P
0 g
s
.40237 .52062 m .41149 .51611 L .41249 .51916 L 0 0 1 r
F
.40146 .51792 m .40556 .51339 L p .40237 .52062 L F P
0 g
s
.39847 .52267 m .38705 .52107 L p .4002 .51417 L 1 0 0 r
F P
0 g
s
.4002 .51417 m .40144 .51784 L .39847 .52267 L 1 0 0 r
F
.41149 .51611 m .41675 .52022 L p .41249 .51916 L 0 1 0 r
F P
0 g
s
.40974 .52628 m .40322 .52332 L p .41275 .51996 L 0 0 1 r
F P
0 g
s
.41348 .52217 m .40974 .52628 L p .41275 .51996 L 0 0 1 r
F P
0 g
s
.40322 .52332 m .39847 .52267 L p .40236 .52062 L 1 0 0 r
F P
0 g
s
.41675 .52022 m .41348 .52217 L p .41249 .51916 L 0 1 0 r
F P
0 g
s
.41675 .52022 m .42786 .52882 L p .41467 .52558 L 0 1 0 r
F P
0 g
s
.41348 .52217 m .41675 .52022 L p .41467 .52558 L 0 1 0 r
F P
0 g
s
.42786 .52882 m .42086 .533 L .41578 .52904 L p 0 1 0 r
F P
0 g
s
.41467 .52558 m .42786 .52882 L .41578 .52904 L 0 1 0 r
F
.40974 .52628 m .41578 .52904 L p .40649 .53344 L 0 0 1 r
F P
0 g
s
.40649 .53344 m .41578 .52904 L .41673 .53197 L 0 0 1 r
F
.40562 .5308 m .40974 .52628 L p .40649 .53344 L F P
0 g
s
.40268 .53545 m .39134 .53392 L p .40439 .52705 L 1 0 0 r
F P
0 g
s
.40439 .52705 m .4056 .53074 L .40268 .53545 L 1 0 0 r
F
.41578 .52904 m .42086 .533 L p .41673 .53197 L 0 1 0 r
F P
0 g
s
.41388 .53904 m .4073 .53605 L p .41697 .53273 L 0 0 1 r
F P
0 g
s
.41767 .5349 m .41388 .53904 L p .41697 .53273 L 0 0 1 r
F P
0 g
s
.4073 .53605 m .40268 .53545 L p .40648 .53344 L 1 0 0 r
F P
0 g
s
.42086 .533 m .41767 .5349 L p .41673 .53197 L 0 1 0 r
F P
0 g
s
.42086 .533 m .43191 .54151 L p .41883 .53833 L 0 1 0 r
F P
0 g
s
.41767 .5349 m .42086 .533 L p .41883 .53833 L 0 1 0 r
F P
0 g
s
.43191 .54151 m .42494 .54567 L .41992 .54177 L p 0 1 0 r
F P
0 g
s
.41883 .53833 m .43191 .54151 L .41992 .54177 L 0 1 0 r
F
.41388 .53904 m .41992 .54177 L p .41048 .54614 L 0 0 1 r
F P
0 g
s
.41048 .54614 m .41992 .54177 L .42082 .54466 L 0 0 1 r
F
.40967 .54362 m .41388 .53904 L p .41048 .54614 L F P
0 g
s
.40685 .54805 m .39558 .54658 L p .40845 .53981 L 1 0 0 r
F P
0 g
s
.40845 .53981 m .40965 .54354 L .40685 .54805 L 1 0 0 r
F
.41992 .54177 m .42494 .54567 L p .42082 .54466 L 0 1 0 r
F P
0 g
s
.41797 .55165 m .42174 .54757 L p .4228 .55096 L 0 0 1 r
F P
0 g
s
.42494 .54567 m .42174 .54757 L p .42082 .54466 L 0 1 0 r
F P
0 g
s
.42494 .54567 m .43592 .5541 L p .42286 .55095 L 0 1 0 r
F P
0 g
s
.42174 .54757 m .42494 .54567 L p .42286 .55095 L 0 1 0 r
F P
0 g
s
.43592 .5541 m .42896 .55824 L .42389 .55432 L p 0 1 0 r
F P
0 g
s
.42286 .55095 m .43592 .5541 L .42389 .55432 L 0 1 0 r
F
.41797 .55165 m .42389 .55432 L p .41434 .55871 L 0 0 1 r
F P
0 g
s
.41434 .55871 m .42389 .55432 L .42478 .55722 L 0 0 1 r
F
.41361 .55637 m .41797 .55165 L p .41434 .55871 L F P
0 g
s
.41097 .56049 m .39978 .55908 L p .41238 .55244 L 1 0 0 r
F P
0 g
s
.41238 .55244 m .41357 .55625 L .41097 .56049 L 1 0 0 r
F
.42389 .55432 m .42896 .55824 L p .42478 .55722 L 0 1 0 r
F P
0 g
s
.42669 .56346 m .4267 .56346 L .4267 .56346 L 0 0 1 r
F
.42202 .56412 m .42569 .56018 L p .42669 .56346 L F P
0 g
s
.42896 .55824 m .42569 .56018 L p .42478 .55722 L 0 1 0 r
F P
0 g
s
.42896 .55824 m .43989 .56659 L p .42676 .56345 L 0 1 0 r
F P
0 g
s
.42569 .56018 m .42896 .55824 L p .42676 .56345 L 0 1 0 r
F P
0 g
s
.43989 .56659 m .43294 .5707 L .42772 .56668 L p 0 1 0 r
F P
0 g
s
.42676 .56345 m .43989 .56659 L .42772 .56668 L 0 1 0 r
F
.42202 .56412 m .42772 .56668 L p .41808 .57115 L 0 0 1 r
F P
0 g
s
.41808 .57115 m .42772 .56668 L .42861 .56966 L 0 0 1 r
F
.41743 .56905 m .42202 .56412 L p .41808 .57115 L F P
0 g
s
.41505 .57275 m .40394 .57141 L p .41617 .56495 L 1 0 0 r
F P
0 g
s
.41617 .56495 m .41738 .56888 L .41505 .57275 L 1 0 0 r
F
.42772 .56668 m .43294 .5707 L p .42861 .56966 L 0 1 0 r
F P
0 g
s
.43046 .57584 m .43046 .57583 L .43046 .57584 L 0 0 1 r
F
.42602 .57646 m .42953 .57273 L p .43046 .57584 L F P
0 g
s
.43294 .5707 m .42953 .57273 L p .42861 .56966 L 0 1 0 r
F P
0 g
s
.43294 .5707 m .44381 .57897 L p .43052 .57583 L 0 1 0 r
F P
0 g
s
.42953 .57273 m .43294 .5707 L p .43052 .57583 L 0 1 0 r
F P
0 g
s
.44381 .57897 m .43688 .58307 L .4314 .57887 L p 0 1 0 r
F P
0 g
s
.43052 .57583 m .44381 .57897 L .4314 .57887 L 0 1 0 r
F
.42602 .57646 m .4314 .57887 L p .42168 .58347 L 0 0 1 r
F P
0 g
s
.42168 .58347 m .4314 .57887 L .4323 .58198 L 0 0 1 r
F
.42114 .58167 m .42602 .57646 L p .42168 .58347 L F P
0 g
s
.41909 .58485 m .40805 .58357 L p .41985 .57733 L 1 0 0 r
F P
0 g
s
.41985 .57733 m .42108 .58144 L .41909 .58485 L 1 0 0 r
F
.4314 .57887 m .43688 .58307 L p .43231 .58198 L 0 1 0 r
F P
0 g
s
.43409 .5881 m .4341 .58808 L .4341 .5881 L 0 0 1 r
F
.42999 .58867 m .43325 .58522 L p .43409 .5881 L F P
0 g
s
.43688 .58307 m .43325 .58522 L p .43231 .58198 L 0 1 0 r
F P
0 g
s
.43688 .58307 m .44769 .59126 L p .43415 .58809 L 0 1 0 r
F P
0 g
s
.43325 .58522 m .43688 .58307 L p .43415 .58809 L 0 1 0 r
F P
0 g
s
.44769 .59126 m .44078 .59534 L .43494 .59088 L p 0 1 0 r
F P
0 g
s
.43415 .58809 m .44769 .59126 L .43494 .59088 L 0 1 0 r
F
.42999 .58867 m .43494 .59088 L p .42517 .59568 L 0 0 1 r
F P
0 g
s
.42517 .59568 m .43494 .59088 L .43587 .59418 L 0 0 1 r
F
.42475 .59422 m .42999 .58867 L p .42517 .59568 L F P
0 g
s
.40979 .59957 m .40316 .60399 L .39253 .59644 L p 0 1 0 r
F P
0 g
s
.4231 .59596 m .41626 .60321 L .40542 .59843 L p 0 0 1 r
F P
0 g
s
.42308 .59678 m .41211 .59556 L p .4234 .5896 L 1 0 0 r
F P
0 g
s
.4234 .5896 m .42467 .59395 L .42308 .59678 L 1 0 0 r
F
.42308 .59678 m .42475 .59422 L p .42517 .59568 L F P
0 g
s
.43494 .59088 m .44078 .59534 L p .43588 .59418 L 0 1 0 r
F P
0 g
s
.42703 .60856 m .41614 .6074 L p .42682 .60174 L 1 0 0 r
F P
0 g
s
.42682 .60174 m .42815 .60642 L .42703 .60856 L 1 0 0 r
F
.42703 .60856 m .42824 .60671 L p .42853 .60776 L F P
0 g
s
.42824 .60671 m .43391 .60075 L p .42841 .60733 L 0 0 1 r
F P
0 g
s
.44036 .61002 m .43778 .6127 L p .43933 .60626 L 0 0 1 r
F P
0 g
s
.44464 .6075 m .44036 .61002 L p .43992 .60842 L 0 1 0 r
F P
0 g
s
.4288 .60874 m .42703 .60856 L p .42853 .60776 L 1 0 0 r
F P
0 g
s
.42012 .61907 m .42703 .60856 L .4288 .60874 L p 1 0 0 r
F P
0 g
s
.42012 .61907 m .4288 .60874 L .42986 .61272 L 1 0 0 r
F
.43094 .62017 m .42012 .61907 L p .43013 .61376 L F P
0 g
s
.43013 .61376 m .43155 .6189 L .43094 .62017 L 1 0 0 r
F
.43192 .62027 m .43094 .62017 L p .43178 .61973 L F P
0 g
s
.43778 .6127 m .44037 .61 L p .44101 .61226 L 0 0 1 r
F P
0 g
s
.43834 .60271 m .44464 .6075 L p .43933 .60626 L 0 1 0 r
F P
0 g
s
.4416 .61438 m .44845 .61957 L p .44265 .61823 L 0 1 0 r
F P
0 g
s
.44423 .62417 m .44426 .62412 L .44427 .62416 L 0 0 1 r
F
.44162 .62453 m .44374 .62233 L p .44423 .62417 L F P
0 g
s
.44845 .61957 m .44374 .62233 L p .44265 .61823 L 0 1 0 r
F P
0 g
s
.44845 .61957 m .45908 .6275 L p .44428 .62416 L 0 1 0 r
F P
0 g
s
.44374 .62233 m .44845 .61957 L p .44428 .62416 L 0 1 0 r
F P
0 g
s
.45908 .6275 m .45222 .63154 L .44473 .62589 L p 0 1 0 r
F P
0 g
s
.44428 .62416 m .45908 .6275 L .44473 .62589 L 0 1 0 r
F
.44162 .62453 m .44473 .62589 L p .43491 .63158 L 0 0 1 r
F P
0 g
s
.43491 .63158 m .44473 .62589 L .44581 .63008 L 0 0 1 r
F
.43481 .63159 m .43489 .6315 L p .43491 .63158 L F P
0 g
s
.43489 .6315 m .44162 .62453 L p .43491 .63158 L 0 0 1 r
F P
0 g
s
.44162 .62453 m .43489 .6315 L p .43333 .62567 L 0 0 1 r
F P
0 g
s
.42406 .63059 m .43094 .62017 L .43192 .62027 L p 1 0 0 r
F P
0 g
s
.42406 .63059 m .43192 .62027 L .433 .62441 L 1 0 0 r
F
.43481 .63163 m .43489 .6315 L p .43491 .63158 L F P
0 g
s
.44542 .63623 m .43493 .63165 L p .44585 .63007 L 0 0 1 r
F P
0 g
s
.43493 .63165 m .43481 .63159 L p .43491 .63158 L 0 0 1 r
F P
0 g
s
.43491 .63158 m .44585 .63007 L .43493 .63165 L 0 0 1 r
F
.44473 .62589 m .45222 .63154 L p .44585 .63007 L 0 1 0 r
F P
0 g
s
.43493 .63164 m .43481 .63163 L p .43491 .63158 L 1 0 0 r
F P
0 g
s
.4213 .64558 m .43778 .64285 L .43778 .64287 L 0 0 1 r
F
.4213 .64558 m .43781 .64286 L .43793 .64331 L F
.4254 .64762 m .41883 .65188 L .40843 .64454 L p 0 1 0 r
F P
0 g
s
.41883 .65188 m .4123 .65632 L .40194 .64927 L p 0 1 0 r
F P
0 g
s
.43188 .65016 m .42517 .65707 L .41462 .65251 L p 0 0 1 r
F P
0 g
s
.40194 .64927 m .40843 .64454 L .41883 .65188 L p 0 1 0 r
F P
0 g
s
.41462 .65251 m .4213 .64558 L .43188 .65016 L p 0 0 1 r
F P
0 g
s
.43863 .64294 m .43805 .64381 L p .43792 .64332 L 1 0 0 r
F P
0 g
s
.43863 .64322 m .43188 .65016 L .4213 .64558 L p 0 0 1 r
F P
0 g
s
.42114 .65214 m .42796 .64195 L .43781 .64286 L p 1 0 0 r
F P
0 g
s
.43781 .64286 m .43863 .64294 L p .43792 .64332 L 1 0 0 r
F P
0 g
s
.42114 .65214 m .43781 .64286 L .43792 .64332 L 1 0 0 r
F
.44542 .63623 m .43863 .64322 L .43781 .64286 L p 0 0 1 r
F P
0 g
s
.43781 .64286 m .4378 .64286 L p .43781 .64285 L 0 0 1 r
F P
0 g
s
.43781 .64285 m .44542 .63623 L .43781 .64286 L 0 0 1 r
F
.4378 .64286 m .42803 .63861 L p .43635 .63747 L F P
0 g
s
.43635 .63747 m .44542 .63623 L .4378 .64286 L 0 0 1 r
F
.42517 .65707 m .43188 .65016 L .44057 .65393 L p F P
0 g
s
.44242 .6541 m .44058 .65393 L p .44463 .64635 L 1 0 0 r
F P
0 g
s
.43938 .64914 m .44463 .64635 L .44058 .65393 L 1 0 0 r
F
.44545 .64957 m .44242 .6541 L p .44463 .64635 L F P
0 g
s
.44111 .65606 m .44242 .6541 L p .44224 .66071 L 1 0 0 r
F P
0 g
s
.44242 .6541 m .44111 .65606 L p .44081 .65494 L 1 0 0 r
F P
0 g
s
.42517 .65707 m .44057 .65393 L .44057 .65394 L 0 0 1 r
F
.42517 .65707 m .44058 .65393 L .44084 .65494 L F
.4292 .65939 m .42265 .66361 L .4123 .65632 L p 0 1 0 r
F P
0 g
s
.42265 .66361 m .41614 .668 L .40583 .66099 L p 0 1 0 r
F P
0 g
s
.40583 .66099 m .4123 .65632 L .42265 .66361 L p 0 1 0 r
F P
0 g
s
.43568 .6616 m .429 .66843 L .41851 .66393 L p 0 0 1 r
F P
0 g
s
.41851 .66393 m .42517 .65707 L .43568 .6616 L p 0 0 1 r
F P
0 g
s
.44241 .65472 m .43568 .6616 L .42517 .65707 L p 0 0 1 r
F P
0 g
s
.42502 .66326 m .43181 .65316 L .44058 .65393 L p 1 0 0 r
F P
0 g
s
.44058 .65393 m .44242 .6541 L p .44081 .65494 L 1 0 0 r
F P
0 g
s
.42502 .66326 m .44058 .65393 L .44081 .65494 L 1 0 0 r
F
.44918 .64781 m .44241 .65472 L .44058 .65393 L p 0 0 1 r
F P
0 g
s
.44058 .65393 m .44055 .65392 L p .44058 .6539 L 0 0 1 r
F P
0 g
s
.44058 .6539 m .44918 .64781 L .44058 .65393 L 0 0 1 r
F
.44055 .65392 m .43188 .65016 L p .43931 .64915 L F P
0 g
s
.43931 .64915 m .44918 .64781 L .44055 .65392 L 0 0 1 r
F
.429 .66843 m .43568 .6616 L .44325 .66486 L p F P
0 g
s
.44617 .6651 m .44325 .66486 L p .44799 .66004 L 1 0 0 r
F P
0 g
s
.44799 .66004 m .448 .66004 L .448 .66005 L 1 0 0 r
F
.44799 .66004 m .448 .66005 L .44617 .6651 L F
.44842 .66175 m .44617 .6651 L p .448 .66004 L F P
0 g
s
.4529 .65927 m .44615 .66611 L .43568 .6616 L p 0 0 1 r
F P
0 g
s
.43568 .6616 m .44241 .65472 L .4529 .65927 L p 0 0 1 r
F P
0 g
s
.43563 .66422 m .42502 .66326 L p .44081 .65494 L 1 0 0 r
F P
0 g
s
.44111 .65606 m .43563 .66422 L p .44081 .65494 L 1 0 0 r
F P
0 g
s
.43188 .65016 m .43863 .64322 L .44918 .64781 L p 0 0 1 r
F P
0 g
s
.43181 .65316 m .42114 .65214 L p .43792 .64332 L 1 0 0 r
F P
0 g
s
.43805 .64381 m .43181 .65316 L p .43792 .64332 L 1 0 0 r
F P
0 g
s
.42796 .64195 m .43481 .63163 L .43493 .63164 L p 1 0 0 r
F P
0 g
s
.42796 .64195 m .43493 .63164 L .43641 .63746 L 1 0 0 r
F
.43778 .64285 m .43781 .64286 L p .43778 .64287 L 0 0 1 r
F P
0 g
s
.43781 .64286 m .43863 .64322 L p .43793 .64331 L 0 0 1 r
F P
0 g
s
.43781 .64286 m .42796 .64195 L p .43641 .63746 L 1 0 0 r
F P
0 g
s
.44773 .63724 m .45596 .64341 L p .44893 .64181 L 0 1 0 r
F P
0 g
s
.43181 .65316 m .43805 .64381 L p .43938 .64914 L 1 0 0 r
F P
0 g
s
.44057 .65393 m .44058 .65393 L p .44057 .65394 L 0 0 1 r
F P
0 g
s
.44058 .65393 m .44241 .65472 L p .44084 .65494 L 0 0 1 r
F P
0 g
s
.44058 .65393 m .43181 .65316 L p .43938 .64914 L 1 0 0 r
F P
0 g
s
.45061 .64843 m .45966 .65518 L p .45189 .65344 L 0 1 0 r
F P
0 g
s
.45329 .65921 m .45336 .65914 L .45337 .6592 L 0 0 1 r
F
.4529 .65927 m .45322 .65894 L p .45329 .65921 L F P
0 g
s
.45966 .65518 m .45322 .65894 L p .45189 .65344 L 0 1 0 r
F P
0 g
s
.45966 .65518 m .47011 .66285 L p .4533 .65921 L 0 1 0 r
F P
0 g
s
.45322 .65894 m .45966 .65518 L p .4533 .65921 L 0 1 0 r
F P
0 g
s
.47011 .66285 m .46331 .66685 L .45336 .65947 L p 0 1 0 r
F P
0 g
s
.4533 .65921 m .47011 .66285 L .45336 .65947 L 0 1 0 r
F
.45336 .65947 m .46331 .66685 L p .45474 .66495 L F P
0 g
s
.43563 .66422 m .44111 .65606 L p .44224 .66071 L 1 0 0 r
F P
0 g
s
.44325 .66486 m .44615 .66611 L p .44363 .66645 L 0 0 1 r
F P
0 g
s
.429 .66843 m .44325 .66486 L .44363 .66645 L 0 0 1 r
F
.44325 .66486 m .43563 .66422 L p .44224 .66071 L 1 0 0 r
F P
0 g
s
.42887 .67423 m .43563 .66422 L .44325 .66486 L p 1 0 0 r
F P
0 g
s
.42887 .67423 m .44325 .66486 L .4436 .66646 L 1 0 0 r
F
.43941 .67514 m .42887 .67423 L p .4436 .66646 L F P
0 g
s
.44405 .66824 m .43941 .67514 L p .4436 .66646 L 1 0 0 r
F P
0 g
s
.44504 .67216 m .456 .67036 L .45607 .67068 L 0 0 1 r
F
.44501 .67206 m .456 .67036 L .44504 .67216 L F
.456 .67036 m .45658 .67061 L p .45608 .67068 L F P
0 g
s
.456 .67036 m .45657 .67079 L p .45607 .67068 L 0 1 0 r
F P
0 g
s
.43941 .67514 m .4445 .67011 L .44499 .67217 L 1 0 0 r
F
.44615 .66611 m .456 .67036 L p .44496 .67206 L 0 0 1 r
F P
0 g
s
.44405 .66824 m .44615 .66611 L p .44496 .67206 L 0 0 1 r
F P
0 g
s
.47374 .6683 m .46696 .67508 L .45658 .67061 L p 0 0 1 r
F P
0 g
s
.46331 .66685 m .45657 .67079 L .456 .67036 L p 0 1 0 r
F P
0 g
s
.45498 .66597 m .46331 .66685 L .456 .67036 L 0 1 0 r
F
.43941 .67514 m .44405 .66824 L p .4445 .67011 L 1 0 0 r
F P
0 g
s
.45658 .67061 m .45616 .67103 L p .45607 .67068 L 0 0 1 r
F P
0 g
s
.45657 .67079 m .45616 .67103 L p .45607 .67068 L 0 1 0 r
F P
0 g
s
.45607 .67068 m .45607 .67068 L .45616 .67103 L 0 0 1 r
F
.45616 .67103 m .44985 .67738 L p .45607 .67068 L F P
0 g
s
.44985 .67738 m .45616 .67103 L p .45747 .67636 L 0 0 1 r
F P
0 g
s
.45618 .67112 m .45657 .67079 L .45618 .67112 L 0 1 0 r
F
.45657 .67079 m .46694 .67843 L p .45747 .67636 L F P
0 g
s
.45618 .67112 m .45657 .67079 L .45747 .67636 L 0 1 0 r
F
.4458 .67564 m .43941 .67514 L p .44499 .67217 L 1 0 0 r
F P
0 g
s
.43268 .68506 m .43941 .67514 L .4458 .67564 L p 1 0 0 r
F P
0 g
s
.43268 .68506 m .4458 .67564 L .44629 .67786 L 1 0 0 r
F
.44315 .68591 m .43268 .68506 L p .44629 .67786 L F P
0 g
s
.4469 .68036 m .44315 .68591 L p .44629 .67786 L 1 0 0 r
F P
0 g
s
.44985 .67738 m .45854 .68111 L p .4476 .68325 L 0 0 1 r
F P
0 g
s
.4469 .68036 m .44985 .67738 L p .4476 .68325 L 0 0 1 r
F P
0 g
s
.45854 .68111 m .46022 .68183 L p .45875 .68203 L 0 0 1 r
F P
0 g
s
.46694 .67843 m .46021 .68235 L .45854 .68111 L p 0 1 0 r
F P
0 g
s
.45762 .67701 m .46694 .67843 L .45854 .68111 L 0 1 0 r
F
.44315 .68591 m .4469 .68036 L p .44763 .68352 L 1 0 0 r
F P
0 g
s
.45352 .68854 m .44828 .6863 L p .45874 .68203 L 0 0 1 r
F P
0 g
s
.44763 .68352 m .45874 .68203 L .44828 .6863 L 0 0 1 r
F
.45898 .68308 m .45352 .68854 L p .45874 .68203 L F P
0 g
s
.45854 .68111 m .46021 .68235 L p .45874 .68203 L 0 1 0 r
F P
0 g
s
.46021 .68235 m .45898 .68307 L p .45874 .68203 L 0 1 0 r
F P
0 g
s
.44826 .68629 m .44315 .68591 L p .44763 .68352 L 1 0 0 r
F P
0 g
s
.46009 .68766 m .47054 .68626 L .46097 .69172 L 0 0 1 r
F
.46021 .68235 m .47052 .68991 L p .46009 .68766 L 0 1 0 r
F P
0 g
s
.45898 .68307 m .46021 .68235 L p .46009 .68766 L 0 1 0 r
F P
0 g
s
.46109 .69177 m .46097 .69172 L p .46107 .69167 L 0 0 1 r
F P
0 g
s
.46097 .69172 m .45352 .68854 L p .46009 .68766 L 0 0 1 r
F P
0 g
s
.46009 .68766 m .47052 .68991 L .46014 .68789 L 0 1 0 r
F
.47052 .68991 m .46382 .69382 L .46097 .69172 L p F P
0 g
s
.46014 .68789 m .47052 .68991 L .46097 .69172 L 0 1 0 r
F
.46097 .69172 m .46382 .69382 L p .46131 .69328 L F P
0 g
s
.45715 .69958 m .45062 .6968 L p .46139 .69365 L 0 0 1 r
F P
0 g
s
.46169 .69506 m .45715 .69958 L p .46139 .69365 L 0 0 1 r
F P
0 g
s
.45062 .6968 m .44684 .69653 L p .45017 .69476 L 1 0 0 r
F P
0 g
s
.46382 .69382 m .4617 .69506 L p .46131 .69328 L 0 1 0 r
F P
0 g
s
.46382 .69382 m .47407 .7013 L p .4626 .69885 L 0 1 0 r
F P
0 g
s
.4617 .69506 m .46382 .69382 L p .4626 .69885 L 0 1 0 r
F P
0 g
s
.47407 .7013 m .46738 .7052 L .46329 .70219 L p 0 1 0 r
F P
0 g
s
.4626 .69885 m .47407 .7013 L .46329 .70219 L 0 1 0 r
F
.45715 .69958 m .46329 .70219 L p .45261 .7059 L 0 0 1 r
F P
0 g
s
.45261 .7059 m .46329 .70219 L .46376 .70442 L 0 0 1 r
F
.45228 .70442 m .45715 .69958 L p .45261 .7059 L F P
0 g
s
.4505 .70702 m .44017 .70628 L p .45136 .70035 L 1 0 0 r
F P
0 g
s
.45136 .70035 m .45225 .70431 L .4505 .70702 L 1 0 0 r
F
.46329 .70219 m .46738 .7052 L p .46377 .70442 L 0 1 0 r
F P
0 g
s
.46492 .70996 m .46493 .70993 L .46494 .70995 L 0 0 1 r
F
.46074 .71051 m .4643 .70699 L p .46492 .70996 L F P
0 g
s
.46738 .7052 m .4643 .70699 L p .46377 .70442 L 0 1 0 r
F P
0 g
s
.46738 .7052 m .47758 .71259 L p .465 .70995 L 0 1 0 r
F P
0 g
s
.4643 .70699 m .46738 .7052 L p .465 .70995 L 0 1 0 r
F P
0 g
s
.47758 .71259 m .47092 .71648 L .46551 .71253 L p 0 1 0 r
F P
0 g
s
.465 .70995 m .47758 .71259 L .46551 .71253 L 0 1 0 r
F
.45481 .71636 m .45412 .71736 L p .45478 .71619 L 1 0 0 r
F P
0 g
s
.45412 .71736 m .44386 .71668 L p .45374 .71143 L 1 0 0 r
F P
0 g
s
.45374 .71143 m .45478 .71619 L .45412 .71736 L 1 0 0 r
F
.45504 .71742 m .45412 .71736 L p .45494 .71693 L F P
0 g
s
.45504 .71742 m .45505 .71743 L p .45504 .71743 L 0 0 1 r
F P
0 g
s
.44756 .72353 m .45504 .71742 L .45504 .71743 L 0 0 1 r
F
.45505 .71743 m .4643 .72133 L p .45614 .7224 L F P
0 g
s
.44756 .72353 m .45505 .71743 L .45614 .7224 L 0 0 1 r
F
.45412 .71736 m .45481 .71636 L p .45494 .71693 L 1 0 0 r
F P
0 g
s
.46551 .71253 m .47092 .71648 L p .46612 .71546 L 0 1 0 r
F P
0 g
s
.44751 .72695 m .45412 .71736 L .45504 .71742 L p 1 0 0 r
F P
0 g
s
.44751 .72695 m .45504 .71742 L .45603 .72241 L 1 0 0 r
F
.4571 .72754 m .45705 .72752 L p .45603 .72241 L 0 0 1 r
F P
0 g
s
.45603 .72241 m .4643 .72133 L .4571 .72754 L 0 0 1 r
F
.4571 .72754 m .44751 .72695 L p .45603 .72241 L 1 0 0 r
F P
0 g
s
.46762 .72273 m .47441 .72766 L p .46837 .72639 L 0 1 0 r
F P
0 g
s
.46941 .73183 m .46946 .73176 L .46948 .73182 L 0 0 1 r
F
.46782 .73204 m .46919 .7307 L p .46941 .73183 L F P
0 g
s
.47441 .72766 m .46919 .7307 L p .46837 .72639 L 0 1 0 r
F P
0 g
s
.47441 .72766 m .48451 .73487 L p .46945 .73182 L 0 1 0 r
F P
0 g
s
.46919 .7307 m .47441 .72766 L p .46945 .73182 L 0 1 0 r
F P
0 g
s
.48451 .73487 m .47788 .73876 L .46963 .7328 L p 0 1 0 r
F P
0 g
s
.46945 .73182 m .48451 .73487 L .46963 .7328 L 0 1 0 r
F
.46963 .7328 m .46782 .73204 L p .46945 .73182 L 0 0 1 r
F P
0 g
s
.52124 .73614 m .528 .72973 L .53796 .73397 L p 0 0 1 r
F P
0 g
s
.528 .72973 m .52124 .73614 L .51126 .73191 L p 0 0 1 r
F P
0 g
s
.66866 .56429 m .67431 .55614 L .67439 .55807 L p 0 1 0 r
F P
0 g
s
.66244 .58459 m .66866 .56429 L p .67439 .55807 L 0 1 0 r
F P
0 g
s
.48792 .74587 m .49459 .74188 L .50464 .74861 L p 0 1 0 r
F P
0 g
s
.49459 .74188 m .48792 .74587 L .47788 .73876 L p 0 1 0 r
F P
0 g
s
.56461 .73602 m .57149 .7296 L .58137 .73384 L p 0 0 1 r
F P
0 g
s
.57149 .7296 m .56461 .73602 L .55471 .73179 L p 0 0 1 r
F P
0 g
s
.55138 .76533 m .55823 .75899 L .5681 .76209 L p 0 1 0 r
F P
0 g
s
.55823 .75899 m .55138 .76533 L .54145 .76094 L p 0 1 0 r
F P
0 g
s
.59159 .74738 m .59844 .73788 L .60802 .73689 L p 0 1 0 r
F P
0 g
s
.52468 .76092 m .53147 .75591 L .54145 .76094 L p 0 1 0 r
F P
0 g
s
.53147 .75591 m .52468 .76092 L .51467 .75498 L p 0 1 0 r
F P
0 g
s
.5681 .76209 m .57497 .75461 L .58474 .75619 L p 0 1 0 r
F P
0 g
s
.59159 .74738 m .58474 .75619 L .57497 .75461 L p 0 1 0 r
F P
0 g
s
.4978 .70124 m .49114 .7103 L .48108 .70926 L p 1 0 0 r
F P
0 g
s
.6736 .55224 m .67431 .55614 L .66866 .56429 L p 0 1 0 r
F P
0 g
s
.47788 .73876 m .48451 .73487 L .49459 .74188 L p 0 1 0 r
F P
0 g
s
.49456 .73409 m .50124 .72767 L .51126 .73191 L p 0 0 1 r
F P
0 g
s
.50124 .72767 m .49456 .73409 L .48451 .72985 L p 0 0 1 r
F P
0 g
s
.53796 .73397 m .54477 .72754 L .55471 .73179 L p 0 0 1 r
F P
0 g
s
.54477 .72754 m .53796 .73397 L .528 .72973 L p 0 0 1 r
F P
0 g
s
.67099 .57367 m .66481 .59391 L .6561 .60369 L p 0 1 0 r
F P
0 g
s
.6561 .60369 m .66244 .58459 L .67099 .57367 L p 0 1 0 r
F P
0 g
s
.58137 .73384 m .58831 .72741 L .59816 .73166 L p 0 0 1 r
F P
0 g
s
.58831 .72741 m .58137 .73384 L .57149 .7296 L p 0 0 1 r
F P
0 g
s
.57497 .75461 m .5681 .76209 L .55823 .75899 L p 0 1 0 r
F P
0 g
s
.55786 .69192 m .56478 .68665 L .57478 .69373 L p 1 0 0 r
F P
0 g
s
.56478 .68665 m .55786 .69192 L .54792 .68663 L p 1 0 0 r
F P
0 g
s
.65454 .63988 m .64808 .6567 L .63902 .66343 L p 0 1 0 r
F P
0 g
s
.63902 .66343 m .64561 .64769 L .65454 .63988 L p 0 1 0 r
F P
0 g
s
.51467 .75498 m .52145 .75032 L .53147 .75591 L p 0 1 0 r
F P
0 g
s
.52145 .75032 m .51467 .75498 L .50464 .74861 L p 0 1 0 r
F P
0 g
s
.51448 .69445 m .52121 .68629 L .53117 .68941 L p 1 0 0 r
F P
0 g
s
.53117 .68941 m .53796 .68219 L .54792 .68663 L p 1 0 0 r
F P
0 g
s
.53796 .68219 m .53117 .68941 L .52121 .68629 L p 1 0 0 r
F P
0 g
s
.51126 .73191 m .518 .72547 L .528 .72973 L p 0 0 1 r
F P
0 g
s
.518 .72547 m .51126 .73191 L .50124 .72767 L p 0 0 1 r
F P
0 g
s
.4978 .70124 m .50448 .69237 L .51448 .69445 L p 1 0 0 r
F P
0 g
s
.52121 .68629 m .51448 .69445 L .50448 .69237 L p 1 0 0 r
F P
0 g
s
.55471 .73179 m .56158 .72535 L .57149 .7296 L p 0 0 1 r
F P
0 g
s
.56158 .72535 m .55471 .73179 L .54477 .72754 L p 0 0 1 r
F P
0 g
s
.64808 .6567 m .64155 .67245 L .63237 .67814 L p 0 1 0 r
F P
0 g
s
.63237 .67814 m .63902 .66343 L .64808 .6567 L p 0 1 0 r
F P
0 g
s
.54145 .76094 m .5483 .75512 L .55823 .75899 L p 0 1 0 r
F P
0 g
s
.5483 .75512 m .54145 .76094 L .53147 .75591 L p 0 1 0 r
F P
0 g
s
.66866 .56429 m .67336 .54766 L .6736 .55224 L p 0 1 0 r
F P
0 g
s
.57497 .75461 m .58185 .74653 L .59159 .74738 L p 0 1 0 r
F P
0 g
s
.59844 .73788 m .59159 .74738 L .58185 .74653 L p 0 1 0 r
F P
0 g
s
.54792 .68663 m .55479 .68058 L .56478 .68665 L p 1 0 0 r
F P
0 g
s
.55479 .68058 m .54792 .68663 L .53796 .68219 L p 1 0 0 r
F P
0 g
s
.48108 .70926 m .48774 .69992 L .4978 .70124 L p 1 0 0 r
F P
0 g
s
.50448 .69237 m .4978 .70124 L .48774 .69992 L p 1 0 0 r
F P
0 g
s
.48451 .72985 m .49117 .7234 L .50124 .72767 L p 0 0 1 r
F P
0 g
s
.50464 .74861 m .51139 .74423 L .52145 .75032 L p 0 1 0 r
F P
0 g
s
.51139 .74423 m .50464 .74861 L .49459 .74188 L p 0 1 0 r
F P
0 g
s
.528 .72973 m .5348 .72327 L .54477 .72754 L p 0 0 1 r
F P
0 g
s
.5348 .72327 m .528 .72973 L .518 .72547 L p 0 0 1 r
F P
0 g
s
.57149 .7296 m .57842 .72315 L .58831 .72741 L p 0 0 1 r
F P
0 g
s
.57842 .72315 m .57149 .7296 L .56158 .72535 L p 0 0 1 r
F P
0 g
s
.55823 .75899 m .56511 .75214 L .57497 .75461 L p 0 1 0 r
F P
0 g
s
.56511 .75214 m .55823 .75899 L .5483 .75512 L p 0 1 0 r
F P
0 g
s
.66481 .59391 m .65852 .61297 L .64964 .62163 L p 0 1 0 r
F P
0 g
s
.64964 .62163 m .6561 .60369 L .66481 .59391 L p 0 1 0 r
F P
0 g
s
.58185 .74653 m .57497 .75461 L .56511 .75214 L p 0 1 0 r
F P
0 g
s
.58183 .69 m .57478 .69373 L .56478 .68665 L p 1 0 0 r
F P
0 g
s
.50124 .72767 m .50796 .7212 L .518 .72547 L p 0 0 1 r
F P
0 g
s
.50796 .7212 m .50124 .72767 L .49117 .7234 L p 0 0 1 r
F P
0 g
s
.49459 .74188 m .5013 .73773 L .51139 .74423 L p 0 1 0 r
F P
0 g
s
.5013 .73773 m .49459 .74188 L .48451 .73487 L p 0 1 0 r
F P
0 g
s
.54477 .72754 m .55163 .72107 L .56158 .72535 L p 0 0 1 r
F P
0 g
s
.55163 .72107 m .54477 .72754 L .5348 .72327 L p 0 0 1 r
F P
0 g
s
.53147 .75591 m .5383 .75054 L .5483 .75512 L p 0 1 0 r
F P
0 g
s
.5383 .75054 m .53147 .75591 L .52145 .75032 L p 0 1 0 r
F P
0 g
s
.5953 .72095 m .58831 .72741 L .57842 .72315 L p 0 0 1 r
F P
0 g
s
.50448 .69237 m .5112 .68376 L .52121 .68629 L p 1 0 0 r
F P
0 g
s
.52121 .68629 m .52797 .67849 L .53796 .68219 L p 1 0 0 r
F P
0 g
s
.52797 .67849 m .52121 .68629 L .5112 .68376 L p 1 0 0 r
F P
0 g
s
.67311 .54633 m .67336 .54766 L p .66002 .57498 L 0 1 0 r
F P
0 g
s
.67336 .54766 m .66866 .56429 L .66002 .57498 L p 0 1 0 r
F P
0 g
s
.58185 .74653 m .58873 .7378 L .59844 .73788 L p 0 1 0 r
F P
0 g
s
.60528 .72762 m .59844 .73788 L .58873 .7378 L p 0 1 0 r
F P
0 g
s
.56478 .68665 m .57177 .68201 L .58183 .69 L p 1 0 0 r
F P
0 g
s
.57177 .68201 m .56478 .68665 L .55479 .68058 L p 1 0 0 r
F P
0 g
s
.53796 .68219 m .54479 .67543 L .55479 .68058 L p 1 0 0 r
F P
0 g
s
.54479 .67543 m .53796 .68219 L .52797 .67849 L p 1 0 0 r
F P
0 g
s
.48774 .69992 m .49443 .69072 L .50448 .69237 L p 1 0 0 r
F P
0 g
s
.5112 .68376 m .50448 .69237 L .49443 .69072 L p 1 0 0 r
F P
0 g
s
.48451 .73487 m .49119 .73089 L .5013 .73773 L p 0 1 0 r
F P
0 g
s
.49119 .73089 m .48451 .73487 L .47441 .72766 L p 0 1 0 r
F P
0 g
s
.518 .72547 m .52478 .71899 L .5348 .72327 L p 0 0 1 r
F P
0 g
s
.52478 .71899 m .518 .72547 L .50796 .7212 L p 0 0 1 r
F P
0 g
s
.56158 .72535 m .56849 .71887 L .57842 .72315 L p 0 0 1 r
F P
0 g
s
.56849 .71887 m .56158 .72535 L .55163 .72107 L p 0 0 1 r
F P
0 g
s
.66629 .55461 m .67305 .54514 L .67311 .54633 L p 0 1 0 r
F P
0 g
s
.66002 .57498 m .66629 .55461 L p .67311 .54633 L 0 1 0 r
F P
0 g
s
.52145 .75032 m .52826 .74535 L .5383 .75054 L p 0 1 0 r
F P
0 g
s
.52826 .74535 m .52145 .75032 L .51139 .74423 L p 0 1 0 r
F P
0 g
s
.65852 .61297 m .65211 .63088 L .6431 .63844 L p 0 1 0 r
F P
0 g
s
.6431 .63844 m .64964 .62163 L .65852 .61297 L p 0 1 0 r
F P
0 g
s
.5483 .75512 m .55518 .74883 L .56511 .75214 L p 0 1 0 r
F P
0 g
s
.55518 .74883 m .5483 .75512 L .5383 .75054 L p 0 1 0 r
F P
0 g
s
.67216 .54046 m .67305 .54514 L .66629 .55461 L p 0 1 0 r
F P
0 g
s
.47441 .72766 m .48106 .72378 L .49119 .73089 L p 0 1 0 r
F P
0 g
s
.4237 .69106 m .41727 .69556 L .40709 .68894 L p 0 1 0 r
F P
0 g
s
.49117 .7234 m .49788 .71691 L .50796 .7212 L p 0 0 1 r
F P
0 g
s
.49788 .71691 m .49117 .7234 L .48107 .71912 L p 0 0 1 r
F P
0 g
s
.55479 .68058 m .56172 .6751 L .57177 .68201 L p 1 0 0 r
F P
0 g
s
.56172 .6751 m .55479 .68058 L .54479 .67543 L p 1 0 0 r
F P
0 g
s
.56511 .75214 m .57201 .74473 L .58185 .74653 L p 0 1 0 r
F P
0 g
s
.58873 .7378 m .58185 .74653 L .57201 .74473 L p 0 1 0 r
F P
0 g
s
.5348 .72327 m .54163 .71678 L .55163 .72107 L p 0 0 1 r
F P
0 g
s
.54163 .71678 m .5348 .72327 L .52478 .71899 L p 0 0 1 r
F P
0 g
s
.58873 .7378 m .59562 .72835 L .60528 .72762 L p 0 1 0 r
F P
0 g
s
.57842 .72315 m .58539 .71665 L .5953 .72095 L p 0 0 1 r
F P
0 g
s
.58539 .71665 m .57842 .72315 L .56849 .71887 L p 0 0 1 r
F P
0 g
s
.57201 .74473 m .56511 .75214 L .55518 .74883 L p 0 1 0 r
F P
0 g
s
.51139 .74423 m .51818 .7396 L .52826 .74535 L p 0 1 0 r
F P
0 g
s
.51818 .7396 m .51139 .74423 L .5013 .73773 L p 0 1 0 r
F P
0 g
s
.66866 .56429 m .66244 .58459 L .65363 .59414 L p 0 1 0 r
F P
0 g
s
.65363 .59414 m .66002 .57498 L .66866 .56429 L p 0 1 0 r
F P
0 g
s
.5112 .68376 m .51795 .67544 L .52797 .67849 L p 1 0 0 r
F P
0 g
s
.52797 .67849 m .53478 .67109 L .54479 .67543 L p 1 0 0 r
F P
0 g
s
.53478 .67109 m .52797 .67849 L .51795 .67544 L p 1 0 0 r
F P
0 g
s
.50796 .7212 m .51472 .7147 L .52478 .71899 L p 0 0 1 r
F P
0 g
s
.51472 .7147 m .50796 .7212 L .49788 .71691 L p 0 0 1 r
F P
0 g
s
.40709 .68894 m .41349 .68413 L .4237 .69106 L p 0 1 0 r
F P
0 g
s
.41349 .68413 m .40709 .68894 L .39687 .68268 L p 0 1 0 r
F P
0 g
s
.55163 .72107 m .55852 .71457 L .56849 .71887 L p 0 0 1 r
F P
0 g
s
.55852 .71457 m .55163 .72107 L .54163 .71678 L p 0 0 1 r
F P
0 g
s
.65211 .63088 m .64561 .64769 L .63646 .65417 L p 0 1 0 r
F P
0 g
s
.63646 .65417 m .6431 .63844 L .65211 .63088 L p 0 1 0 r
F P
0 g
s
.49443 .69072 m .50114 .68171 L .5112 .68376 L p 1 0 0 r
F P
0 g
s
.51795 .67544 m .5112 .68376 L .50114 .68171 L p 1 0 0 r
F P
0 g
s
.45412 .71736 m .44751 .72695 L .43724 .72621 L p 1 0 0 r
F P
0 g
s
.5383 .75054 m .54518 .74477 L .55518 .74883 L p 0 1 0 r
F P
0 g
s
.54518 .74477 m .5383 .75054 L .52826 .74535 L p 0 1 0 r
F P
0 g
s
.66629 .55461 m .67183 .53506 L .67216 .54046 L p 0 1 0 r
F P
0 g
s
.54479 .67543 m .55168 .66919 L .56172 .6751 L p 1 0 0 r
F P
0 g
s
.55168 .66919 m .54479 .67543 L .53478 .67109 L p 1 0 0 r
F P
0 g
s
.44392 .71273 m .43737 .71925 L .42714 .71495 L p 0 0 1 r
F P
0 g
s
.5013 .73773 m .50807 .73337 L .51818 .7396 L p 0 1 0 r
F P
0 g
s
.50807 .73337 m .5013 .73773 L .49119 .73089 L p 0 1 0 r
F P
0 g
s
.48107 .71912 m .48776 .7126 L .49788 .71691 L p 0 0 1 r
F P
0 g
s
.50114 .68171 m .49443 .69072 L .48431 .68941 L p 1 0 0 r
F P
0 g
s
.52478 .71899 m .5316 .71248 L .54163 .71678 L p 0 0 1 r
F P
0 g
s
.5316 .71248 m .52478 .71899 L .51472 .7147 L p 0 0 1 r
F P
0 g
s
.56849 .71887 m .57545 .71235 L .58539 .71665 L p 0 0 1 r
F P
0 g
s
.57545 .71235 m .56849 .71887 L .55852 .71457 L p 0 0 1 r
F P
0 g
s
.57201 .74473 m .57892 .73671 L .58873 .7378 L p 0 1 0 r
F P
0 g
s
.59562 .72835 m .58873 .7378 L .57892 .73671 L p 0 1 0 r
F P
0 g
s
.64561 .64769 m .63902 .66343 L .62976 .66887 L p 0 1 0 r
F P
0 g
s
.62976 .66887 m .63646 .65417 L .64561 .64769 L p 0 1 0 r
F P
0 g
s
.39687 .68268 m .40326 .67749 L .41349 .68413 L p 0 1 0 r
F P
0 g
s
.40326 .67749 m .39687 .68268 L .38661 .67683 L p 0 1 0 r
F P
0 g
s
.57883 .67805 m .57177 .68201 L .56172 .6751 L p 1 0 0 r
F P
0 g
s
.55518 .74883 m .56208 .74204 L .57201 .74473 L p 0 1 0 r
F P
0 g
s
.56208 .74204 m .55518 .74883 L .54518 .74477 L p 0 1 0 r
F P
0 g
s
.49119 .73089 m .49793 .72675 L .50807 .73337 L p 0 1 0 r
F P
0 g
s
.49793 .72675 m .49119 .73089 L .48106 .72378 L p 0 1 0 r
F P
0 g
s
.57892 .73671 m .57201 .74473 L .56208 .74204 L p 0 1 0 r
F P
0 g
s
.49788 .71691 m .50462 .71038 L .51472 .7147 L p 0 0 1 r
F P
0 g
s
.50462 .71038 m .49788 .71691 L .48776 .7126 L p 0 0 1 r
F P
0 g
s
.54163 .71678 m .54851 .71025 L .55852 .71457 L p 0 0 1 r
F P
0 g
s
.54851 .71025 m .54163 .71678 L .5316 .71248 L p 0 0 1 r
F P
0 g
s
.43724 .72621 m .44386 .71668 L .45412 .71736 L p 1 0 0 r
F P
0 g
s
.52826 .74535 m .53513 .74002 L .54518 .74477 L p 0 1 0 r
F P
0 g
s
.53513 .74002 m .52826 .74535 L .51818 .7396 L p 0 1 0 r
F P
0 g
s
.59241 .71012 m .58539 .71665 L .57545 .71235 L p 0 0 1 r
F P
0 g
s
.63631 .70999 m .62916 .71653 L .6193 .71222 L p 0 0 1 r
F P
0 g
s
.63033 .73716 m .62272 .73533 L .61236 .72174 L p 1 0 0 r
F P
0 g
s
.61236 .72174 m .61983 .72221 L .63033 .73716 L p 1 0 0 r
F P
0 g
s
.66244 .58459 m .6561 .60369 L .64714 .61211 L p 0 1 0 r
F P
0 g
s
.64714 .61211 m .65363 .59414 L .66244 .58459 L p 0 1 0 r
F P
0 g
s
.56172 .6751 m .56873 .67025 L .57883 .67805 L p 1 0 0 r
F P
0 g
s
.56873 .67025 m .56172 .6751 L .55168 .66919 L p 1 0 0 r
F P
0 g
s
.50114 .68171 m .50788 .67295 L .51795 .67544 L p 1 0 0 r
F P
0 g
s
.51795 .67544 m .52474 .66747 L .53478 .67109 L p 1 0 0 r
F P
0 g
s
.52474 .66747 m .51795 .67544 L .50788 .67295 L p 1 0 0 r
F P
0 g
s
.53478 .67109 m .54164 .66415 L .55168 .66919 L p 1 0 0 r
F P
0 g
s
.54164 .66415 m .53478 .67109 L .52474 .66747 L p 1 0 0 r
F P
0 g
s
.38661 .67683 m .39298 .67121 L .40326 .67749 L p 0 1 0 r
F P
0 g
s
.39298 .67121 m .38661 .67683 L .3763 .67148 L p 0 1 0 r
F P
0 g
s
.48106 .72378 m .48777 .7198 L .49793 .72675 L p 0 1 0 r
F P
0 g
s
.48777 .7198 m .48106 .72378 L .47092 .71648 L p 0 1 0 r
F P
0 g
s
.42714 .71495 m .43367 .70841 L .44392 .71273 L p 0 0 1 r
F P
0 g
s
.43367 .70841 m .42714 .71495 L .41686 .71064 L p 0 0 1 r
F P
0 g
s
.67172 .53449 m .67183 .53506 L p .65757 .5651 L 0 1 0 r
F P
0 g
s
.67183 .53506 m .66629 .55461 L .65757 .5651 L p 0 1 0 r
F P
0 g
s
.57892 .73671 m .58585 .72804 L .59562 .72835 L p 0 1 0 r
F P
0 g
s
.6025 .71816 m .59562 .72835 L .58585 .72804 L p 0 1 0 r
F P
0 g
s
.51472 .7147 m .52153 .70815 L .5316 .71248 L p 0 0 1 r
F P
0 g
s
.52153 .70815 m .51472 .7147 L .50462 .71038 L p 0 0 1 r
F P
0 g
s
.48431 .68941 m .49102 .68008 L .50114 .68171 L p 1 0 0 r
F P
0 g
s
.50788 .67295 m .50114 .68171 L .49102 .68008 L p 1 0 0 r
F P
0 g
s
.55852 .71457 m .56546 .70802 L .57545 .71235 L p 0 0 1 r
F P
0 g
s
.56546 .70802 m .55852 .71457 L .54851 .71025 L p 0 0 1 r
F P
0 g
s
.66387 .54464 m .67169 .53398 L .67172 .53449 L p 0 1 0 r
F P
0 g
s
.65757 .5651 m .66387 .54464 L p .67172 .53449 L 0 1 0 r
F P
0 g
s
.67062 .52858 m .67169 .53398 L .66387 .54464 L p 0 1 0 r
F P
0 g
s
.51818 .7396 m .52503 .73466 L .53513 .74002 L p 0 1 0 r
F P
0 g
s
.52503 .73466 m .51818 .7396 L .50807 .73337 L p 0 1 0 r
F P
0 g
s
.47092 .71648 m .47758 .71259 L .48777 .7198 L p 0 1 0 r
F P
0 g
s
.44386 .71668 m .43724 .72621 L .4269 .72528 L p 1 0 0 r
F P
0 g
s
.54518 .74477 m .55209 .73853 L .56208 .74204 L p 0 1 0 r
F P
0 g
s
.55209 .73853 m .54518 .74477 L .53513 .74002 L p 0 1 0 r
F P
0 g
s
.41994 .67958 m .41349 .68413 L .40326 .67749 L p 0 1 0 r
F P
0 g
s
.55168 .66919 m .55864 .6635 L .56873 .67025 L p 1 0 0 r
F P
0 g
s
.55864 .6635 m .55168 .66919 L .54164 .66415 L p 1 0 0 r
F P
0 g
s
.48776 .7126 m .49449 .70605 L .50462 .71038 L p 0 0 1 r
F P
0 g
s
.49449 .70605 m .48776 .7126 L .4776 .70828 L p 0 0 1 r
F P
0 g
s
.5316 .71248 m .53846 .70592 L .54851 .71025 L p 0 0 1 r
F P
0 g
s
.53846 .70592 m .5316 .71248 L .52153 .70815 L p 0 0 1 r
F P
0 g
s
.57545 .71235 m .58244 .70579 L .59241 .71012 L p 0 0 1 r
F P
0 g
s
.58244 .70579 m .57545 .71235 L .56546 .70802 L p 0 0 1 r
F P
0 g
s
.3763 .67148 m .38267 .66535 L .39298 .67121 L p 0 1 0 r
F P
0 g
s
.38267 .66535 m .3763 .67148 L .36593 .6667 L p 0 1 0 r
F P
0 g
s
.56208 .74204 m .56902 .73469 L .57892 .73671 L p 0 1 0 r
F P
0 g
s
.58585 .72804 m .57892 .73671 L .56902 .73469 L p 0 1 0 r
F P
0 g
s
.6561 .60369 m .64964 .62163 L .64054 .62895 L p 0 1 0 r
F P
0 g
s
.64054 .62895 m .64714 .61211 L .6561 .60369 L p 0 1 0 r
F P
0 g
s
.56902 .73469 m .56208 .74204 L .55209 .73853 L p 0 1 0 r
F P
0 g
s
.58585 .72804 m .59277 .71866 L .6025 .71816 L p 0 1 0 r
F P
0 g
s
.50807 .73337 m .51489 .72877 L .52503 .73466 L p 0 1 0 r
F P
0 g
s
.51489 .72877 m .50807 .73337 L .49793 .72675 L p 0 1 0 r
F P
0 g
s
.40326 .67749 m .40968 .67261 L .41994 .67958 L p 0 1 0 r
F P
0 g
s
.40968 .67261 m .40326 .67749 L .39298 .67121 L p 0 1 0 r
F P
0 g
s
.41686 .71064 m .42338 .70407 L .43367 .70841 L p 0 0 1 r
F P
0 g
s
.42338 .70407 m .41686 .71064 L .40655 .70631 L p 0 0 1 r
F P
0 g
s
.50788 .67295 m .51466 .66448 L .52474 .66747 L p 1 0 0 r
F P
0 g
s
.52474 .66747 m .53157 .65991 L .54164 .66415 L p 1 0 0 r
F P
0 g
s
.53157 .65991 m .52474 .66747 L .51466 .66448 L p 1 0 0 r
F P
0 g
s
.50462 .71038 m .51141 .70381 L .52153 .70815 L p 0 0 1 r
F P
0 g
s
.51141 .70381 m .50462 .71038 L .49449 .70605 L p 0 0 1 r
F P
0 g
s
.54851 .71025 m .55543 .70368 L .56546 .70802 L p 0 0 1 r
F P
0 g
s
.55543 .70368 m .54851 .71025 L .53846 .70592 L p 0 0 1 r
F P
0 g
s
.59946 .70355 m .59241 .71012 L .58244 .70579 L p 0 0 1 r
F P
0 g
s
.6435 .70342 m .63631 .70999 L .62643 .70566 L p 0 0 1 r
F P
0 g
s
.49102 .68008 m .49776 .67094 L .50788 .67295 L p 1 0 0 r
F P
0 g
s
.51466 .66448 m .50788 .67295 L .49776 .67094 L p 1 0 0 r
F P
0 g
s
.4269 .72528 m .43352 .71589 L .44386 .71668 L p 1 0 0 r
F P
0 g
s
.4505 .70702 m .44386 .71668 L .43352 .71589 L p 1 0 0 r
F P
0 g
s
.53513 .74002 m .54203 .73429 L .55209 .73853 L p 0 1 0 r
F P
0 g
s
.54203 .73429 m .53513 .74002 L .52503 .73466 L p 0 1 0 r
F P
0 g
s
.54164 .66415 m .54855 .65772 L .55864 .6635 L p 1 0 0 r
F P
0 g
s
.54855 .65772 m .54164 .66415 L .53157 .65991 L p 1 0 0 r
F P
0 g
s
.67004 .52292 m .6702 .52267 L .67062 .52858 L p 0 1 0 r
F P
0 g
s
.66387 .54464 m .67004 .52292 L p .67062 .52858 L 0 1 0 r
F P
0 g
s
.66629 .55461 m .66002 .57498 L .65113 .58432 L p 0 1 0 r
F P
0 g
s
.65113 .58432 m .65757 .5651 L .66629 .55461 L p 0 1 0 r
F P
0 g
s
.49793 .72675 m .50472 .72241 L .51489 .72877 L p 0 1 0 r
F P
0 g
s
.50472 .72241 m .49793 .72675 L .48777 .7198 L p 0 1 0 r
F P
0 g
s
.44025 .70183 m .43367 .70841 L .42338 .70407 L p 0 0 1 r
F P
0 g
s
.64964 .62163 m .6431 .63844 L .63387 .64469 L p 0 1 0 r
F P
0 g
s
.63387 .64469 m .64054 .62895 L .64964 .62163 L p 0 1 0 r
F P
0 g
s
.4776 .70828 m .48431 .7017 L .49449 .70605 L p 0 0 1 r
F P
0 g
s
.52153 .70815 m .52837 .70157 L .53846 .70592 L p 0 0 1 r
F P
0 g
s
.52837 .70157 m .52153 .70815 L .51141 .70381 L p 0 0 1 r
F P
0 g
s
.56546 .70802 m .57244 .70144 L .58244 .70579 L p 0 0 1 r
F P
0 g
s
.57244 .70144 m .56546 .70802 L .55543 .70368 L p 0 0 1 r
F P
0 g
s
.39298 .67121 m .39939 .66594 L .40968 .67261 L p 0 1 0 r
F P
0 g
s
.39939 .66594 m .39298 .67121 L .38267 .66535 L p 0 1 0 r
F P
0 g
s
.49776 .67094 m .49102 .68008 L .48084 .67877 L p 1 0 0 r
F P
0 g
s
.36593 .6667 m .3723 .65999 L .38267 .66535 L p 0 1 0 r
F P
0 g
s
.3723 .65999 m .36593 .6667 L .35548 .66254 L p 0 1 0 r
F P
0 g
s
.57581 .66607 m .56873 .67025 L .55864 .6635 L p 1 0 0 r
F P
0 g
s
.56902 .73469 m .57596 .72673 L .58585 .72804 L p 0 1 0 r
F P
0 g
s
.59277 .71866 m .58585 .72804 L .57596 .72673 L p 0 1 0 r
F P
0 g
s
.62745 .72372 m .61983 .72221 L .60946 .70897 L p 1 0 0 r
F P
0 g
s
.60946 .70897 m .61693 .70916 L .62745 .72372 L p 1 0 0 r
F P
0 g
s
.48777 .7198 m .49452 .71567 L .50472 .72241 L p 0 1 0 r
F P
0 g
s
.49452 .71567 m .48777 .7198 L .47758 .71259 L p 0 1 0 r
F P
0 g
s
.55209 .73853 m .55903 .7318 L .56902 .73469 L p 0 1 0 r
F P
0 g
s
.55903 .7318 m .55209 .73853 L .54203 .73429 L p 0 1 0 r
F P
0 g
s
.40655 .70631 m .41305 .69971 L .42338 .70407 L p 0 0 1 r
F P
0 g
s
.41305 .69971 m .40655 .70631 L .39619 .70196 L p 0 0 1 r
F P
0 g
s
.43352 .71589 m .4269 .72528 L .4165 .72408 L p 1 0 0 r
F P
0 g
s
.49449 .70605 m .50126 .69945 L .51141 .70381 L p 0 0 1 r
F P
0 g
s
.50126 .69945 m .49449 .70605 L .48431 .7017 L p 0 0 1 r
F P
0 g
s
.53846 .70592 m .54537 .69932 L .55543 .70368 L p 0 0 1 r
F P
0 g
s
.54537 .69932 m .53846 .70592 L .52837 .70157 L p 0 0 1 r
F P
0 g
s
.52503 .73466 m .53191 .72937 L .54203 .73429 L p 0 1 0 r
F P
0 g
s
.53191 .72937 m .52503 .73466 L .51489 .72877 L p 0 1 0 r
F P
0 g
s
.58244 .70579 m .58949 .69919 L .59946 .70355 L p 0 0 1 r
F P
0 g
s
.58949 .69919 m .58244 .70579 L .57244 .70144 L p 0 0 1 r
F P
0 g
s
.2127 .5312 m .21031 .52511 L .2088 .52077 L p 1 0 0 r
F P
0 g
s
.62643 .70566 m .63361 .69906 L .6435 .70342 L p 0 0 1 r
F P
0 g
s
.57596 .72673 m .56902 .73469 L .55903 .7318 L p 0 1 0 r
F P
0 g
s
.55864 .6635 m .56566 .65844 L .57581 .66607 L p 1 0 0 r
F P
0 g
s
.56566 .65844 m .55864 .6635 L .54855 .65772 L p 1 0 0 r
F P
0 g
s
.43352 .71589 m .44017 .70628 L .4505 .70702 L p 1 0 0 r
F P
0 g
s
.49776 .67094 m .50453 .66204 L .51466 .66448 L p 1 0 0 r
F P
0 g
s
.51466 .66448 m .52147 .65636 L .53157 .65991 L p 1 0 0 r
F P
0 g
s
.52147 .65636 m .51466 .66448 L .50453 .66204 L p 1 0 0 r
F P
0 g
s
.38267 .66535 m .38906 .65963 L .39939 .66594 L p 0 1 0 r
F P
0 g
s
.38906 .65963 m .38267 .66535 L .3723 .65999 L p 0 1 0 r
F P
0 g
s
.53157 .65991 m .53845 .65279 L .54855 .65772 L p 1 0 0 r
F P
0 g
s
.53845 .65279 m .53157 .65991 L .52147 .65636 L p 1 0 0 r
F P
0 g
s
.47758 .71259 m .48431 .7086 L .49452 .71567 L p 0 1 0 r
F P
0 g
s
.48431 .7086 m .47758 .71259 L .46738 .7052 L p 0 1 0 r
F P
0 g
s
.42338 .70407 m .42994 .69746 L .44025 .70183 L p 0 0 1 r
F P
0 g
s
.42994 .69746 m .42338 .70407 L .41305 .69971 L p 0 0 1 r
F P
0 g
s
.51141 .70381 m .51824 .6972 L .52837 .70157 L p 0 0 1 r
F P
0 g
s
.51824 .6972 m .51141 .70381 L .50126 .69945 L p 0 0 1 r
F P
0 g
s
.63811 .74009 m .63033 .73716 L .61983 .72221 L p 1 0 0 r
F P
0 g
s
.61983 .72221 m .62745 .72372 L .63811 .74009 L p 1 0 0 r
F P
0 g
s
.55543 .70368 m .5624 .69707 L .57244 .70144 L p 0 0 1 r
F P
0 g
s
.5624 .69707 m .55543 .70368 L .54537 .69932 L p 0 0 1 r
F P
0 g
s
.48084 .67877 m .48758 .66932 L .49776 .67094 L p 1 0 0 r
F P
0 g
s
.50453 .66204 m .49776 .67094 L .48758 .66932 L p 1 0 0 r
F P
0 g
s
.67018 .52255 m .6702 .52267 L .67004 .52292 L p 0 1 0 r
F P
0 g
s
.65073 .69681 m .6435 .70342 L .63361 .69906 L p 0 0 1 r
F P
0 g
s
.35548 .66254 m .36187 .6552 L .3723 .65999 L p 0 1 0 r
F P
0 g
s
.36187 .6552 m .35548 .66254 L .34495 .65909 L p 0 1 0 r
F P
0 g
s
.66002 .57498 m .65363 .59414 L .64459 .60235 L p 0 1 0 r
F P
0 g
s
.64459 .60235 m .65113 .58432 L .66002 .57498 L p 0 1 0 r
F P
0 g
s
.67004 .52292 m .67017 .52242 L .67018 .52255 L p 0 1 0 r
F P
0 g
s
.66896 .5166 m .67017 .52242 L p .66142 .53438 L 0 1 0 r
F P
0 g
s
.67017 .52242 m .67004 .52292 L .66142 .53438 L p 0 1 0 r
F P
0 g
s
.67004 .52292 m .66387 .54464 L .65507 .55494 L p 0 1 0 r
F P
0 g
s
.65507 .55494 m .66142 .53438 L .67004 .52292 L p 0 1 0 r
F P
0 g
s
.57596 .72673 m .58292 .71811 L .59277 .71866 L p 0 1 0 r
F P
0 g
s
.59969 .70852 m .59277 .71866 L .58292 .71811 L p 0 1 0 r
F P
0 g
s
.46738 .7052 m .47407 .7013 L .48431 .7086 L p 0 1 0 r
F P
0 g
s
.51489 .72877 m .52176 .72386 L .53191 .72937 L p 0 1 0 r
F P
0 g
s
.52176 .72386 m .51489 .72877 L .50472 .72241 L p 0 1 0 r
F P
0 g
s
.41614 .668 m .40968 .67261 L .39939 .66594 L p 0 1 0 r
F P
0 g
s
.22164 .55196 m .2127 .5312 L p .21963 .54605 L 1 0 0 r
F P
0 g
s
.22599 .55967 m .22397 .55608 L p .21963 .54605 L 1 0 0 r
F P
0 g
s
.22397 .55608 m .22164 .55196 L p .21963 .54605 L 1 0 0 r
F P
0 g
s
.2127 .5312 m .21677 .54029 L .22599 .55967 L p 1 0 0 r
F P
0 g
s
.21677 .54029 m .2127 .5312 L p .20961 .52293 L 1 0 0 r
F P
0 g
s
.2088 .52077 m .21046 .52483 L .20961 .52293 L 1 0 0 r
F
.21046 .52483 m .21677 .54029 L .20961 .52293 L F
.20671 .51656 m .21677 .54029 L .21033 .52451 L F
.20671 .51656 m .20779 .51957 L .21677 .54029 L p F P
0 g
s
.21677 .54029 m .20779 .51957 L p .21475 .53443 L 1 0 0 r
F P
0 g
s
.2211 .54797 m .2191 .54442 L p .21475 .53443 L 1 0 0 r
F P
0 g
s
.2191 .54442 m .21677 .54029 L p .21475 .53443 L 1 0 0 r
F P
0 g
s
.20779 .51957 m .21183 .52862 L .21664 .53865 L p 1 0 0 r
F P
0 g
s
.20779 .51957 m .21664 .53865 L .21461 .53412 L 1 0 0 r
F
.2081 .51935 m .20671 .51656 L p .21033 .52451 L F P
0 g
s
.20779 .51957 m .20671 .51656 L .20611 .51485 L p 1 0 0 r
F P
0 g
s
.20611 .51485 m .20526 .51314 L .20779 .51957 L p 1 0 0 r
F P
0 g
s
.20779 .51957 m .20526 .51314 L .20374 .50885 L p 1 0 0 r
F P
0 g
s
.21183 .52862 m .20779 .51957 L p .20464 .51124 L 1 0 0 r
F P
0 g
s
.20374 .50885 m .20554 .51325 L .20464 .51124 L 1 0 0 r
F
.20554 .51325 m .21183 .52862 L .20464 .51124 L F
.20168 .50472 m .21183 .52862 L .20537 .51283 L F
.2088 .52077 m .2081 .51935 L p .21033 .52451 L F P
0 g
s
.20168 .50472 m .20282 .50794 L .21183 .52862 L p 1 0 0 r
F P
0 g
s
.21183 .52862 m .20282 .50794 L p .20981 .52279 L 1 0 0 r
F P
0 g
s
.21614 .53624 m .21416 .53274 L p .20981 .52279 L 1 0 0 r
F P
0 g
s
.21416 .53274 m .21183 .52862 L p .20981 .52279 L 1 0 0 r
F P
0 g
s
.20282 .50794 m .20683 .51693 L .21163 .52688 L p 1 0 0 r
F P
0 g
s
.20282 .50794 m .21163 .52688 L .20962 .52239 L 1 0 0 r
F
.20298 .50733 m .20168 .50472 L p .20537 .51283 L F P
0 g
s
.20282 .50794 m .20168 .50472 L .20101 .50287 L p 1 0 0 r
F P
0 g
s
.20101 .50287 m .20007 .501 L .20282 .50794 L p 1 0 0 r
F P
0 g
s
.20282 .50794 m .20007 .501 L .19857 .49682 L p 1 0 0 r
F P
0 g
s
.20683 .51693 m .20282 .50794 L p .1996 .49951 L 1 0 0 r
F P
0 g
s
.19857 .49682 m .20056 .50167 L .1996 .49951 L 1 0 0 r
F
.20056 .50167 m .20683 .51693 L .1996 .49951 L F
.19655 .49282 m .20683 .51693 L .20035 .50115 L F
.20374 .50885 m .20298 .50733 L p .20537 .51283 L F P
0 g
s
.19655 .49282 m .19779 .4963 L .20683 .51693 L p 1 0 0 r
F P
0 g
s
.20683 .51693 m .19779 .4963 L p .2048 .51114 L 1 0 0 r
F P
0 g
s
.21111 .52449 m .20916 .52105 L p .2048 .51114 L 1 0 0 r
F P
0 g
s
.20916 .52105 m .20683 .51693 L p .2048 .51114 L 1 0 0 r
F P
0 g
s
.19779 .4963 m .20177 .50522 L .20655 .51509 L p 1 0 0 r
F P
0 g
s
.19779 .4963 m .20655 .51509 L .20457 .51065 L 1 0 0 r
F
.19772 .49514 m .19655 .49282 L p .20035 .50115 L F P
0 g
s
.19779 .4963 m .19655 .49282 L .1958 .49078 L p 1 0 0 r
F P
0 g
s
.1958 .49078 m .19475 .4887 L .19779 .4963 L p 1 0 0 r
F P
0 g
s
.19779 .4963 m .19475 .4887 L .19328 .48467 L p 1 0 0 r
F P
0 g
s
.20177 .50522 m .19779 .4963 L p .19448 .48776 L 1 0 0 r
F P
0 g
s
.19328 .48467 m .19551 .49008 L .19448 .48776 L 1 0 0 r
F
.19551 .49008 m .20177 .50522 L .19448 .48776 L F
.19133 .48084 m .20177 .50522 L .19526 .48946 L F
.19857 .49682 m .19772 .49514 L p .20035 .50115 L F P
0 g
s
.19133 .48084 m .19268 .48465 L .20177 .50522 L p 1 0 0 r
F P
0 g
s
.20177 .50522 m .19268 .48465 L p .19973 .49947 L 1 0 0 r
F P
0 g
s
.20602 .51271 m .20409 .50932 L p .19973 .49947 L 1 0 0 r
F P
0 g
s
.20409 .50932 m .20177 .50522 L p .19973 .49947 L 1 0 0 r
F P
0 g
s
.19268 .48465 m .19663 .4935 L .20141 .50328 L p 1 0 0 r
F P
0 g
s
.19268 .48465 m .20141 .50328 L .19945 .49889 L 1 0 0 r
F
.19233 .4828 m .19133 .48084 L p .19526 .48946 L F P
0 g
s
.19268 .48465 m .19133 .48084 L .19048 .47857 L p 1 0 0 r
F P
0 g
s
.19048 .47857 m .18929 .47624 L .19268 .48465 L p 1 0 0 r
F P
0 g
s
.19268 .48465 m .18929 .47624 L .18787 .4724 L p 1 0 0 r
F P
0 g
s
.19663 .4935 m .19268 .48465 L p .18928 .47598 L 1 0 0 r
F P
0 g
s
.18787 .4724 m .19039 .47847 L .18928 .47598 L 1 0 0 r
F
.19039 .47847 m .19663 .4935 L .18928 .47598 L F
.18601 .46879 m .19663 .4935 L .1901 .47776 L F
.18601 .46879 m .1875 .47299 L .19663 .4935 L p F P
0 g
s
.19328 .48467 m .19233 .4828 L p .19526 .48946 L 1 0 0 r
F P
0 g
s
.19663 .4935 m .1875 .47299 L p .19458 .48778 L 1 0 0 r
F P
0 g
s
.20086 .5009 m .19896 .49757 L p .19458 .48778 L 1 0 0 r
F P
0 g
s
.19896 .49757 m .19663 .4935 L p .19458 .48778 L 1 0 0 r
F P
0 g
s
.1875 .47299 m .19142 .48175 L .19619 .49144 L p 1 0 0 r
F P
0 g
s
.1875 .47299 m .19619 .49144 L .19426 .48711 L 1 0 0 r
F
.1875 .47299 m .18601 .46879 L .18505 .46624 L p F P
0 g
s
.18505 .46624 m .18369 .4636 L .1875 .47299 L p 1 0 0 r
F P
0 g
s
.1875 .47299 m .18369 .4636 L .18235 .46002 L p 1 0 0 r
F P
0 g
s
.19142 .48175 m .1875 .47299 L p .184 .46418 L 1 0 0 r
F P
0 g
s
.18235 .46002 m .1852 .46686 L .184 .46418 L 1 0 0 r
F
.1852 .46686 m .19142 .48175 L .184 .46418 L F
.1806 .45667 m .19142 .48175 L .18486 .46605 L F
.1806 .45667 m .18225 .46132 L .19142 .48175 L p F P
0 g
s
.18787 .4724 m .18678 .47029 L p .1901 .47776 L 1 0 0 r
F P
0 g
s
.18678 .47029 m .18601 .46879 L p .1901 .47776 L 1 0 0 r
F P
0 g
s
.19142 .48175 m .18225 .46132 L p .18936 .47606 L 1 0 0 r
F P
0 g
s
.19563 .48906 m .19375 .4858 L p .18936 .47606 L 1 0 0 r
F P
0 g
s
.19375 .4858 m .19142 .48175 L p .18936 .47606 L 1 0 0 r
F P
0 g
s
.18225 .46132 m .18614 .46998 L .19091 .47957 L p 1 0 0 r
F P
0 g
s
.18225 .46132 m .19091 .47957 L .189 .47531 L 1 0 0 r
F
.18225 .46132 m .1806 .45667 L .1795 .45379 L p F P
0 g
s
.1795 .45379 m .17794 .45079 L .18225 .46132 L p 1 0 0 r
F P
0 g
s
.18225 .46132 m .17794 .45079 L .1767 .44752 L p 1 0 0 r
F P
0 g
s
.18614 .46998 m .18225 .46132 L p .17865 .45237 L 1 0 0 r
F P
0 g
s
.1767 .44752 m .17994 .45523 L .17865 .45237 L 1 0 0 r
F
.17994 .45523 m .18614 .46998 L .17865 .45237 L F
.1751 .44448 m .18614 .46998 L .17956 .45432 L F
.1751 .44448 m .17693 .44963 L .18614 .46998 L p F P
0 g
s
.18235 .46002 m .18109 .45761 L p .18486 .46605 L 1 0 0 r
F P
0 g
s
.18109 .45761 m .1806 .45667 L p .18486 .46605 L 1 0 0 r
F P
0 g
s
.18614 .46998 m .17693 .44963 L p .18407 .46431 L 1 0 0 r
F P
0 g
s
.19033 .47718 m .18847 .47399 L p .18407 .46431 L 1 0 0 r
F P
0 g
s
.18847 .47399 m .18614 .46998 L p .18407 .46431 L 1 0 0 r
F P
0 g
s
.17092 .4349 m .16949 .43221 L p .17028 .43401 L 1 0 0 r
F P
0 g
s
.17693 .44963 m .18079 .45818 L .18555 .46766 L p 1 0 0 r
F P
0 g
s
.17693 .44963 m .18555 .46766 L .18366 .46347 L 1 0 0 r
F
.17693 .44963 m .1751 .44448 L .17383 .44122 L p F P
0 g
s
.17383 .44122 m .17204 .4378 L .17693 .44963 L p 1 0 0 r
F P
0 g
s
.17693 .44963 m .17204 .4378 L .17092 .4349 L p 1 0 0 r
F P
0 g
s
.18079 .45818 m .17693 .44963 L p .17322 .44054 L 1 0 0 r
F P
0 g
s
.17092 .4349 m .1746 .44357 L .17322 .44054 L 1 0 0 r
F
.1746 .44357 m .18079 .45818 L .17322 .44054 L F
.17028 .43401 m .18079 .45818 L .17418 .44258 L F
.16949 .43221 m .17152 .43791 L .18079 .45818 L p F P
0 g
s
.1767 .44752 m .17524 .44476 L p .17956 .45432 L 1 0 0 r
F P
0 g
s
.17524 .44476 m .1751 .44448 L p .17956 .45432 L 1 0 0 r
F P
0 g
s
.18079 .45818 m .17152 .43791 L p .1787 .45254 L 1 0 0 r
F P
0 g
s
.18495 .46526 m .18312 .46214 L p .1787 .45254 L 1 0 0 r
F P
0 g
s
.18312 .46214 m .18079 .45818 L p .1787 .45254 L 1 0 0 r
F P
0 g
s
.16501 .42215 m .16379 .41988 L p .16578 .42441 L 1 0 0 r
F P
0 g
s
.17152 .43791 m .17536 .44634 L .18011 .45572 L p 1 0 0 r
F P
0 g
s
.17152 .43791 m .18011 .45572 L .17825 .45161 L 1 0 0 r
F
.17152 .43791 m .16949 .43221 L .16805 .42853 L p F P
0 g
s
.16805 .42853 m .16598 .42463 L .17152 .43791 L p 1 0 0 r
F P
0 g
s
.17152 .43791 m .16598 .42463 L .16501 .42215 L p 1 0 0 r
F P
0 g
s
.17536 .44634 m .17152 .43791 L p .16771 .42869 L 1 0 0 r
F P
0 g
s
.16501 .42215 m .16918 .43189 L .16771 .42869 L 1 0 0 r
F
.16918 .43189 m .17536 .44634 L .16771 .42869 L F
.16578 .42441 m .17536 .44634 L .16872 .43081 L F
.16379 .41988 m .16604 .42617 L .17536 .44634 L p F P
0 g
s
.17028 .43401 m .17418 .44258 L .17092 .4349 L 1 0 0 r
F
.17536 .44634 m .16604 .42617 L p .17326 .44072 L F P
0 g
s
.1795 .4533 m .17769 .45025 L p .17326 .44072 L 1 0 0 r
F P
0 g
s
.17769 .45025 m .17536 .44634 L p .17326 .44072 L 1 0 0 r
F P
0 g
s
.15897 .40928 m .15799 .40747 L p .16109 .41452 L 1 0 0 r
F P
0 g
s
.16604 .42617 m .16985 .43446 L .1746 .44373 L p 1 0 0 r
F P
0 g
s
.16604 .42617 m .1746 .44373 L .17276 .43971 L 1 0 0 r
F
.16604 .42617 m .16379 .41988 L .16214 .41571 L p F P
0 g
s
.16214 .41571 m .15976 .41127 L .16604 .42617 L p 1 0 0 r
F P
0 g
s
.16604 .42617 m .15976 .41127 L .15897 .40928 L p 1 0 0 r
F P
0 g
s
.16985 .43446 m .16604 .42617 L p .16213 .41683 L 1 0 0 r
F P
0 g
s
.15897 .40928 m .16368 .42018 L .16213 .41683 L 1 0 0 r
F
.16368 .42018 m .16985 .43446 L .16213 .41683 L F
.16109 .41452 m .16985 .43446 L .16318 .41901 L F
.15799 .40747 m .16048 .4144 L .16985 .43446 L p F P
0 g
s
.16985 .43446 m .16048 .4144 L p .16774 .42886 L 1 0 0 r
F P
0 g
s
.17397 .44128 m .17218 .43831 L p .16774 .42886 L 1 0 0 r
F P
0 g
s
.17218 .43831 m .16985 .43446 L p .16774 .42886 L 1 0 0 r
F P
0 g
s
.1561 .40277 m .15337 .39772 L .16048 .4144 L p 1 0 0 r
F P
0 g
s
.16048 .4144 m .15337 .39772 L .15279 .39629 L p 1 0 0 r
F P
0 g
s
.15279 .39629 m .15209 .39499 L p .15622 .40435 L 1 0 0 r
F P
0 g
s
.16048 .4144 m .16427 .42255 L .16901 .4317 L p 1 0 0 r
F P
0 g
s
.16048 .4144 m .16901 .4317 L .16719 .42777 L 1 0 0 r
F
.16048 .4144 m .15799 .40747 L .1561 .40277 L p F P
0 g
s
.16427 .42255 m .16048 .4144 L p .15648 .40497 L 1 0 0 r
F P
0 g
s
.15279 .39629 m .15811 .40844 L .15648 .40497 L 1 0 0 r
F
.15811 .40844 m .16427 .42255 L .15648 .40497 L F
.15622 .40435 m .16427 .42255 L .15756 .40718 L F
.15209 .39499 m .15484 .40259 L .16427 .42255 L p F P
0 g
s
.16109 .41452 m .16318 .41901 L .15897 .40928 L 1 0 0 r
F
.16578 .42441 m .16872 .43081 L .16501 .42215 L F
.16427 .42255 m .15484 .40259 L p .16214 .41695 L F P
0 g
s
.16837 .42921 m .1666 .42633 L p .16214 .41695 L 1 0 0 r
F P
0 g
s
.1666 .42633 m .16427 .42255 L p .16214 .41695 L 1 0 0 r
F P
0 g
s
.14993 .3897 m .14681 .38397 L .15484 .40259 L p 1 0 0 r
F P
0 g
s
.15484 .40259 m .14681 .38397 L .14648 .38316 L p 1 0 0 r
F P
0 g
s
.15484 .40259 m .1586 .41058 L .16334 .41962 L p 1 0 0 r
F P
0 g
s
.15484 .40259 m .16334 .41962 L .16155 .41579 L 1 0 0 r
F
.15484 .40259 m .15209 .39499 L .14993 .3897 L p F P
0 g
s
.1586 .41058 m .15484 .40259 L p .15075 .39308 L 1 0 0 r
F P
0 g
s
.14648 .38316 m .15244 .39666 L .15075 .39308 L 1 0 0 r
F
.15244 .39666 m .1586 .41058 L .15075 .39308 L F
.15119 .39392 m .1586 .41058 L .15185 .39532 L F
.14608 .38244 m .14911 .39075 L .1586 .41058 L p F P
0 g
s
.15622 .40435 m .15756 .40718 L .15279 .39629 L 1 0 0 r
F
.1586 .41058 m .14911 .39075 L p .15646 .405 L F P
0 g
s
.16268 .41708 m .16093 .41429 L p .15646 .405 L 1 0 0 r
F P
0 g
s
.16093 .41429 m .1586 .41058 L p .15646 .405 L 1 0 0 r
F P
0 g
s
.14362 .3765 m .14006 .37001 L .14911 .39075 L p 1 0 0 r
F P
0 g
s
.14911 .39075 m .15285 .39856 L .15759 .40749 L p 1 0 0 r
F P
0 g
s
.14911 .39075 m .15759 .40749 L .15582 .40376 L 1 0 0 r
F
.14911 .39075 m .14608 .38244 L .14362 .3765 L p F P
0 g
s
.15285 .39856 m .14911 .39075 L p .14494 .38118 L 1 0 0 r
F P
0 g
s
.14002 .36991 m .1467 .38483 L .14494 .38118 L 1 0 0 r
F
.1467 .38483 m .15285 .39856 L .14494 .38118 L F
.14599 .38326 m .15285 .39856 L .14606 .38341 L F
.14911 .39075 m .14006 .37001 L .14002 .36991 L p F P
0 g
s
.13997 .36983 m .1433 .37885 L .15285 .39856 L p 1 0 0 r
F P
0 g
s
.15119 .39392 m .15185 .39532 L .14648 .38316 L 1 0 0 r
F
.15285 .39856 m .1433 .37885 L p .15069 .39299 L F P
0 g
s
.15691 .40489 m .15518 .40219 L p .15069 .39299 L 1 0 0 r
F P
0 g
s
.15518 .40219 m .15285 .39856 L p .15069 .39299 L 1 0 0 r
F P
0 g
s
.1433 .37885 m .14701 .38649 L .15175 .39529 L p 1 0 0 r
F P
0 g
s
.1433 .37885 m .15175 .39529 L .15 .39167 L 1 0 0 r
F
.1433 .37885 m .13997 .36983 L .13718 .36317 L p F P
0 g
s
.13718 .36317 m .1338 .35707 L p .1433 .37885 L 1 0 0 r
F P
0 g
s
.1338 .35707 m .13405 .35795 L .1433 .37885 L p 1 0 0 r
F P
0 g
s
.14701 .38649 m .1433 .37885 L .13912 .3694 L p 1 0 0 r
F P
0 g
s
.13912 .3694 m .13405 .35795 L p .14087 .37296 L 1 0 0 r
F P
0 g
s
.14087 .37296 m .14701 .38649 L .13912 .3694 L 1 0 0 r
F
.1374 .36691 m .14701 .38649 L p .14019 .37146 L F P
0 g
s
.14002 .36991 m .13997 .36983 L p .14599 .38326 L 1 0 0 r
F P
0 g
s
.14599 .38326 m .14606 .38341 L .14002 .36991 L 1 0 0 r
F
.14648 .38316 m .14608 .38244 L p .15119 .39392 L F P
0 g
s
.15106 .39262 m .14701 .38649 L .1427 .3777 L p 1 0 0 r
F P
0 g
s
.1427 .3777 m .1374 .36691 L p .14461 .38048 L 1 0 0 r
F P
0 g
s
.14461 .38048 m .15106 .39262 L .1427 .3777 L 1 0 0 r
F
.1374 .36691 m .14109 .37435 L .14583 .38303 L p F P
0 g
s
.1374 .36691 m .14583 .38303 L .1441 .37953 L 1 0 0 r
F
.14109 .37435 m .14512 .38028 L .15 .38832 L p F P
0 g
s
.15 .38832 m .15543 .39727 L p .14812 .38559 L 1 0 0 r
F P
0 g
s
.14109 .37435 m .15 .38832 L .14812 .38559 L 1 0 0 r
F
.14583 .38303 m .15106 .39262 L p .1441 .37953 L F P
0 g
s
.13405 .35795 m .13553 .36192 L p .14019 .37146 L 1 0 0 r
F P
0 g
s
.13553 .36192 m .1374 .36691 L p .14019 .37146 L 1 0 0 r
F P
0 g
s
.15175 .39529 m .15691 .40489 L p .15 .39167 L 1 0 0 r
F P
0 g
s
.15759 .40749 m .16268 .41708 L p .15582 .40376 L 1 0 0 r
F P
0 g
s
.16334 .41962 m .16837 .42921 L p .16155 .41579 L 1 0 0 r
F P
0 g
s
.16901 .4317 m .17397 .44128 L p .16719 .42777 L 1 0 0 r
F P
0 g
s
.1746 .44373 m .1795 .4533 L p .17276 .43971 L 1 0 0 r
F P
0 g
s
.18011 .45572 m .18495 .46526 L p .17825 .45161 L 1 0 0 r
F P
0 g
s
.18555 .46766 m .19033 .47718 L p .18366 .46347 L 1 0 0 r
F P
0 g
s
.19091 .47957 m .19563 .48906 L p .189 .47531 L 1 0 0 r
F P
0 g
s
.19619 .49144 m .20086 .5009 L p .19426 .48711 L 1 0 0 r
F P
0 g
s
.20141 .50328 m .20602 .51271 L p .19945 .49889 L 1 0 0 r
F P
0 g
s
.20655 .51509 m .21111 .52449 L p .20457 .51065 L 1 0 0 r
F P
0 g
s
.21163 .52688 m .21614 .53624 L p .20962 .52239 L 1 0 0 r
F P
0 g
s
.21664 .53865 m .2211 .54797 L p .21461 .53412 L 1 0 0 r
F P
0 g
s
.54855 .65772 m .55552 .65185 L .56566 .65844 L p 1 0 0 r
F P
0 g
s
.55552 .65185 m .54855 .65772 L .53845 .65279 L p 1 0 0 r
F P
0 g
s
.4165 .72408 m .42312 .71488 L .43352 .71589 L p 1 0 0 r
F P
0 g
s
.44017 .70628 m .43352 .71589 L .42312 .71488 L p 1 0 0 r
F P
0 g
s
.54203 .73429 m .54896 .7281 L .55903 .7318 L p 0 1 0 r
F P
0 g
s
.54896 .7281 m .54203 .73429 L .53191 .72937 L p 0 1 0 r
F P
0 g
s
.39619 .70196 m .40267 .69533 L .41305 .69971 L p 0 0 1 r
F P
0 g
s
.40267 .69533 m .39619 .70196 L .38579 .69759 L p 0 0 1 r
F P
0 g
s
.48431 .7017 m .49106 .69507 L .50126 .69945 L p 0 0 1 r
F P
0 g
s
.49106 .69507 m .48431 .7017 L .47409 .69733 L p 0 0 1 r
F P
0 g
s
.52837 .70157 m .53526 .69494 L .54537 .69932 L p 0 0 1 r
F P
0 g
s
.53526 .69494 m .52837 .70157 L .51824 .6972 L p 0 0 1 r
F P
0 g
s
.57244 .70144 m .57947 .69481 L .58949 .69919 L p 0 0 1 r
F P
0 g
s
.57947 .69481 m .57244 .70144 L .5624 .69707 L p 0 0 1 r
F P
0 g
s
.3723 .65999 m .37868 .65376 L .38906 .65963 L p 0 1 0 r
F P
0 g
s
.37868 .65376 m .3723 .65999 L .36187 .6552 L p 0 1 0 r
F P
0 g
s
.50472 .72241 m .51156 .71783 L .52176 .72386 L p 0 1 0 r
F P
0 g
s
.51156 .71783 m .50472 .72241 L .49452 .71567 L p 0 1 0 r
F P
0 g
s
.55903 .7318 m .56599 .7245 L .57596 .72673 L p 0 1 0 r
F P
0 g
s
.58292 .71811 m .57596 .72673 L .56599 .7245 L p 0 1 0 r
F P
0 g
s
.39939 .66594 m .40583 .66099 L .41614 .668 L p 0 1 0 r
F P
0 g
s
.40583 .66099 m .39939 .66594 L .38906 .65963 L p 0 1 0 r
F P
0 g
s
.56599 .7245 m .55903 .7318 L .54896 .7281 L p 0 1 0 r
F P
0 g
s
.41305 .69971 m .41959 .69307 L .42994 .69746 L p 0 0 1 r
F P
0 g
s
.41959 .69307 m .41305 .69971 L .40267 .69533 L p 0 0 1 r
F P
0 g
s
.50453 .66204 m .51133 .65342 L .52147 .65636 L p 1 0 0 r
F P
0 g
s
.52147 .65636 m .52833 .64863 L .53845 .65279 L p 1 0 0 r
F P
0 g
s
.52833 .64863 m .52147 .65636 L .51133 .65342 L p 1 0 0 r
F P
0 g
s
.50126 .69945 m .50807 .69281 L .51824 .6972 L p 0 0 1 r
F P
0 g
s
.50807 .69281 m .50126 .69945 L .49106 .69507 L p 0 0 1 r
F P
0 g
s
.54537 .69932 m .55232 .69268 L .5624 .69707 L p 0 0 1 r
F P
0 g
s
.55232 .69268 m .54537 .69932 L .53526 .69494 L p 0 0 1 r
F P
0 g
s
.58292 .71811 m .58989 .70879 L .59969 .70852 L p 0 1 0 r
F P
0 g
s
.60659 .69757 m .59969 .70852 L .58989 .70879 L p 0 1 0 r
F P
0 g
s
.42312 .71488 m .4165 .72408 L .40605 .72252 L p 1 0 0 r
F P
0 g
s
.59657 .69255 m .58949 .69919 L .57947 .69481 L p 0 0 1 r
F P
0 g
s
.63361 .69906 m .64083 .69242 L .65073 .69681 L p 0 0 1 r
F P
0 g
s
.64083 .69242 m .63361 .69906 L .62368 .69468 L p 0 0 1 r
F P
0 g
s
.58298 .66263 m .57581 .66607 L .56566 .65844 L p 1 0 0 r
F P
0 g
s
.65363 .59414 m .64714 .61211 L .63795 .61922 L p 0 1 0 r
F P
0 g
s
.63795 .61922 m .64459 .60235 L .65363 .59414 L p 0 1 0 r
F P
0 g
s
.48758 .66932 m .49435 .66004 L .50453 .66204 L p 1 0 0 r
F P
0 g
s
.51133 .65342 m .50453 .66204 L .49435 .66004 L p 1 0 0 r
F P
0 g
s
.53845 .65279 m .54538 .64618 L .55552 .65185 L p 1 0 0 r
F P
0 g
s
.54538 .64618 m .53845 .65279 L .52833 .64863 L p 1 0 0 r
F P
0 g
s
.53191 .72937 m .53884 .72368 L .54896 .7281 L p 0 1 0 r
F P
0 g
s
.53884 .72368 m .53191 .72937 L .52176 .72386 L p 0 1 0 r
F P
0 g
s
.34495 .65909 m .35136 .65104 L .36187 .6552 L p 0 1 0 r
F P
0 g
s
.35136 .65104 m .34495 .65909 L .33433 .65641 L p 0 1 0 r
F P
0 g
s
.42312 .71488 m .42976 .70542 L .44017 .70628 L p 1 0 0 r
F P
0 g
s
.44684 .69653 m .44017 .70628 L .42976 .70542 L p 1 0 0 r
F P
0 g
s
.49452 .71567 m .50133 .71134 L .51156 .71783 L p 0 1 0 r
F P
0 g
s
.50133 .71134 m .49452 .71567 L .48431 .7086 L p 0 1 0 r
F P
0 g
s
.66763 .51253 m .66854 .51116 L .66896 .5166 L p 0 1 0 r
F P
0 g
s
.66142 .53438 m .66763 .51253 L p .66896 .5166 L 0 1 0 r
F P
0 g
s
.38579 .69759 m .39226 .69094 L .40267 .69533 L p 0 0 1 r
F P
0 g
s
.39226 .69094 m .38579 .69759 L .37535 .6932 L p 0 0 1 r
F P
0 g
s
.43654 .69081 m .42994 .69746 L .41959 .69307 L p 0 0 1 r
F P
0 g
s
.56566 .65844 m .57276 .65406 L .58298 .66263 L p 1 0 0 r
F P
0 g
s
.57276 .65406 m .56566 .65844 L .55552 .65185 L p 1 0 0 r
F P
0 g
s
.38906 .65963 m .39548 .65429 L .40583 .66099 L p 0 1 0 r
F P
0 g
s
.39548 .65429 m .38906 .65963 L .37868 .65376 L p 0 1 0 r
F P
0 g
s
.47409 .69733 m .48082 .69068 L .49106 .69507 L p 0 0 1 r
F P
0 g
s
.36187 .6552 m .36826 .64839 L .37868 .65376 L p 0 1 0 r
F P
0 g
s
.36826 .64839 m .36187 .6552 L .35136 .65104 L p 0 1 0 r
F P
0 g
s
.51824 .6972 m .52511 .69055 L .53526 .69494 L p 0 0 1 r
F P
0 g
s
.52511 .69055 m .51824 .6972 L .50807 .69281 L p 0 0 1 r
F P
0 g
s
.5624 .69707 m .56941 .69041 L .57947 .69481 L p 0 0 1 r
F P
0 g
s
.56941 .69041 m .5624 .69707 L .55232 .69268 L p 0 0 1 r
F P
0 g
s
.65801 .69015 m .65073 .69681 L .64083 .69242 L p 0 0 1 r
F P
0 g
s
.49435 .66004 m .48758 .66932 L .47733 .668 L p 1 0 0 r
F P
0 g
s
.58989 .70879 m .59684 .69869 L .60659 .69757 L p 0 1 0 r
F P
0 g
s
.66387 .54464 m .65757 .5651 L .64859 .57424 L p 0 1 0 r
F P
0 g
s
.64859 .57424 m .65507 .55494 L .66387 .54464 L p 0 1 0 r
F P
0 g
s
.48431 .7086 m .49108 .70448 L .50133 .71134 L p 0 1 0 r
F P
0 g
s
.49108 .70448 m .48431 .7086 L .47407 .7013 L p 0 1 0 r
F P
0 g
s
.64714 .61211 m .64054 .62895 L .63123 .63497 L p 0 1 0 r
F P
0 g
s
.63123 .63497 m .63795 .61922 L .64714 .61211 L p 0 1 0 r
F P
0 g
s
.40267 .69533 m .40919 .68867 L .41959 .69307 L p 0 0 1 r
F P
0 g
s
.40919 .68867 m .40267 .69533 L .39226 .69094 L p 0 0 1 r
F P
0 g
s
.56599 .7245 m .57297 .71659 L .58292 .71811 L p 0 1 0 r
F P
0 g
s
.58989 .70879 m .58292 .71811 L .57297 .71659 L p 0 1 0 r
F P
0 g
s
.54896 .7281 m .55593 .72141 L .56599 .7245 L p 0 1 0 r
F P
0 g
s
.55593 .72141 m .54896 .7281 L .53884 .72368 L p 0 1 0 r
F P
0 g
s
.49106 .69507 m .49785 .68841 L .50807 .69281 L p 0 0 1 r
F P
0 g
s
.49785 .68841 m .49106 .69507 L .48082 .69068 L p 0 0 1 r
F P
0 g
s
.53526 .69494 m .54219 .68827 L .55232 .69268 L p 0 0 1 r
F P
0 g
s
.54219 .68827 m .53526 .69494 L .52511 .69055 L p 0 0 1 r
F P
0 g
s
.55552 .65185 m .56256 .64659 L .57276 .65406 L p 1 0 0 r
F P
0 g
s
.56256 .64659 m .55552 .65185 L .54538 .64618 L p 1 0 0 r
F P
0 g
s
.40605 .72252 m .41265 .7136 L .42312 .71488 L p 1 0 0 r
F P
0 g
s
.42976 .70542 m .42312 .71488 L .41265 .7136 L p 1 0 0 r
F P
0 g
s
.57947 .69481 m .58653 .68814 L .59657 .69255 L p 0 0 1 r
F P
0 g
s
.58653 .68814 m .57947 .69481 L .56941 .69041 L p 0 0 1 r
F P
0 g
s
.52176 .72386 m .52867 .71861 L .53884 .72368 L p 0 1 0 r
F P
0 g
s
.52867 .71861 m .52176 .72386 L .51156 .71783 L p 0 1 0 r
F P
0 g
s
.62368 .69468 m .63088 .68801 L .64083 .69242 L p 0 0 1 r
F P
0 g
s
.63522 .72632 m .62745 .72372 L .61693 .70916 L p 1 0 0 r
F P
0 g
s
.61693 .70916 m .62455 .71036 L .63522 .72632 L p 1 0 0 r
F P
0 g
s
.37868 .65376 m .38509 .64796 L .39548 .65429 L p 0 1 0 r
F P
0 g
s
.38509 .64796 m .37868 .65376 L .36826 .64839 L p 0 1 0 r
F P
0 g
s
.42976 .70542 m .43644 .69574 L .44684 .69653 L p 1 0 0 r
F P
0 g
s
.57297 .71659 m .56599 .7245 L .55593 .72141 L p 0 1 0 r
F P
0 g
s
.47407 .7013 m .48081 .69731 L .49108 .70448 L p 0 1 0 r
F P
0 g
s
.48081 .69731 m .47407 .7013 L .46382 .69382 L p 0 1 0 r
F P
0 g
s
.49435 .66004 m .50115 .651 L .51133 .65342 L p 1 0 0 r
F P
0 g
s
.51133 .65342 m .51817 .64514 L .52833 .64863 L p 1 0 0 r
F P
0 g
s
.51817 .64514 m .51133 .65342 L .50115 .651 L p 1 0 0 r
F P
0 g
s
.52833 .64863 m .53523 .64134 L .54538 .64618 L p 1 0 0 r
F P
0 g
s
.53523 .64134 m .52833 .64863 L .51817 .64514 L p 1 0 0 r
F P
0 g
s
.37535 .6932 m .3818 .68653 L .39226 .69094 L p 0 0 1 r
F P
0 g
s
.3818 .68653 m .37535 .6932 L .36487 .6888 L p 0 0 1 r
F P
0 g
s
.41959 .69307 m .42617 .68639 L .43654 .69081 L p 0 0 1 r
F P
0 g
s
.42617 .68639 m .41959 .69307 L .40919 .68867 L p 0 0 1 r
F P
0 g
s
.50807 .69281 m .51492 .68613 L .52511 .69055 L p 0 0 1 r
F P
0 g
s
.51492 .68613 m .50807 .69281 L .49785 .68841 L p 0 0 1 r
F P
0 g
s
.6684 .51052 m .66854 .51116 L .66763 .51253 L p 0 1 0 r
F P
0 g
s
.55232 .69268 m .55931 .686 L .56941 .69041 L p 0 0 1 r
F P
0 g
s
.55931 .686 m .55232 .69268 L .54219 .68827 L p 0 0 1 r
F P
0 g
s
.33433 .65641 m .34076 .6476 L .35136 .65104 L p 0 1 0 r
F P
0 g
s
.35136 .65104 m .35776 .64359 L .36826 .64839 L p 0 1 0 r
F P
0 g
s
.35776 .64359 m .35136 .65104 L .34076 .6476 L p 0 1 0 r
F P
0 g
s
.41265 .7136 m .40605 .72252 L .39554 .72052 L p 1 0 0 r
F P
0 g
s
.64083 .69242 m .64809 .68574 L .65801 .69015 L p 0 0 1 r
F P
0 g
s
.64809 .68574 m .64083 .69242 L .63088 .68801 L p 0 0 1 r
F P
0 g
s
.47733 .668 m .4841 .65842 L .49435 .66004 L p 1 0 0 r
F P
0 g
s
.50115 .651 m .49435 .66004 L .4841 .65842 L p 1 0 0 r
F P
0 g
s
.66763 .51253 m .66834 .5098 L .6684 .51052 L p 0 1 0 r
F P
0 g
s
.46382 .69382 m .47052 .68991 L .48081 .69731 L p 0 1 0 r
F P
0 g
s
.34076 .6476 m .33433 .65641 L .32358 .65459 L p 0 1 0 r
F P
0 g
s
.23546 .5777 m .23083 .57135 L .22164 .55196 L p 1 0 0 r
F P
0 g
s
.22164 .55196 m .22599 .55967 L .23546 .5777 L p 1 0 0 r
F P
0 g
s
.4123 .65632 m .40583 .66099 L .39548 .65429 L p 0 1 0 r
F P
0 g
s
.51156 .71783 m .51845 .71295 L .52867 .71861 L p 0 1 0 r
F P
0 g
s
.51845 .71295 m .51156 .71783 L .50133 .71134 L p 0 1 0 r
F P
0 g
s
.54538 .64618 m .55238 .64012 L .56256 .64659 L p 1 0 0 r
F P
0 g
s
.55238 .64012 m .54538 .64618 L .53523 .64134 L p 1 0 0 r
F P
0 g
s
.66719 .5045 m .66834 .5098 L p .65892 .52382 L 0 1 0 r
F P
0 g
s
.66834 .5098 m .66763 .51253 L .65892 .52382 L p 0 1 0 r
F P
0 g
s
.57297 .71659 m .57997 .70803 L .58989 .70879 L p 0 1 0 r
F P
0 g
s
.59684 .69869 m .58989 .70879 L .57997 .70803 L p 0 1 0 r
F P
0 g
s
.39226 .69094 m .39876 .68425 L .40919 .68867 L p 0 0 1 r
F P
0 g
s
.39876 .68425 m .39226 .69094 L .3818 .68653 L p 0 0 1 r
F P
0 g
s
.53884 .72368 m .54581 .71754 L .55593 .72141 L p 0 1 0 r
F P
0 g
s
.54581 .71754 m .53884 .72368 L .52867 .71861 L p 0 1 0 r
F P
0 g
s
.65757 .5651 m .65113 .58432 L .64201 .59233 L p 0 1 0 r
F P
0 g
s
.64201 .59233 m .64859 .57424 L .65757 .5651 L p 0 1 0 r
F P
0 g
s
.48082 .69068 m .4876 .68398 L .49785 .68841 L p 0 0 1 r
F P
0 g
s
.4876 .68398 m .48082 .69068 L .47054 .68626 L p 0 0 1 r
F P
0 g
s
.41265 .7136 m .41929 .70435 L .42976 .70542 L p 1 0 0 r
F P
0 g
s
.43644 .69574 m .42976 .70542 L .41929 .70435 L p 1 0 0 r
F P
0 g
s
.36826 .64839 m .37466 .64207 L .38509 .64796 L p 0 1 0 r
F P
0 g
s
.37466 .64207 m .36826 .64839 L .35776 .64359 L p 0 1 0 r
F P
0 g
s
.66763 .51253 m .66142 .53438 L .65253 .5445 L p 0 1 0 r
F P
0 g
s
.65253 .5445 m .65892 .52382 L .66763 .51253 L p 0 1 0 r
F P
0 g
s
.52511 .69055 m .53202 .68385 L .54219 .68827 L p 0 0 1 r
F P
0 g
s
.53202 .68385 m .52511 .69055 L .51492 .68613 L p 0 0 1 r
F P
0 g
s
.56941 .69041 m .57646 .68372 L .58653 .68814 L p 0 0 1 r
F P
0 g
s
.57646 .68372 m .56941 .69041 L .55931 .686 L p 0 0 1 r
F P
0 g
s
.64607 .74422 m .63811 .74009 L .62745 .72372 L p 1 0 0 r
F P
0 g
s
.62745 .72372 m .63522 .72632 L .64607 .74422 L p 1 0 0 r
F P
0 g
s
.66534 .68346 m .65801 .69015 L .64809 .68574 L p 0 0 1 r
F P
0 g
s
.39548 .65429 m .40194 .64927 L .4123 .65632 L p 0 1 0 r
F P
0 g
s
.40194 .64927 m .39548 .65429 L .38509 .64796 L p 0 1 0 r
F P
0 g
s
.50133 .71134 m .5082 .70678 L .51845 .71295 L p 0 1 0 r
F P
0 g
s
.5082 .70678 m .50133 .71134 L .49108 .70448 L p 0 1 0 r
F P
0 g
s
.36487 .6888 m .3713 .6821 L .3818 .68653 L p 0 0 1 r
F P
0 g
s
.3713 .6821 m .36487 .6888 L .35435 .68438 L p 0 0 1 r
F P
0 g
s
.57995 .6504 m .57276 .65406 L .56256 .64659 L p 1 0 0 r
F P
0 g
s
.40919 .68867 m .41575 .68196 L .42617 .68639 L p 0 0 1 r
F P
0 g
s
.41575 .68196 m .40919 .68867 L .39876 .68425 L p 0 0 1 r
F P
0 g
s
.55593 .72141 m .56293 .71417 L .57297 .71659 L p 0 1 0 r
F P
0 g
s
.56293 .71417 m .55593 .72141 L .54581 .71754 L p 0 1 0 r
F P
0 g
s
.57997 .70803 m .57297 .71659 L .56293 .71417 L p 0 1 0 r
F P
0 g
s
.50115 .651 m .50798 .64224 L .51817 .64514 L p 1 0 0 r
F P
0 g
s
.51817 .64514 m .52506 .63725 L .53523 .64134 L p 1 0 0 r
F P
0 g
s
.52506 .63725 m .51817 .64514 L .50798 .64224 L p 1 0 0 r
F P
0 g
s
.49785 .68841 m .50469 .6817 L .51492 .68613 L p 0 0 1 r
F P
0 g
s
.50469 .6817 m .49785 .68841 L .4876 .68398 L p 0 0 1 r
F P
0 g
s
.54219 .68827 m .54916 .68157 L .55931 .686 L p 0 0 1 r
F P
0 g
s
.54916 .68157 m .54219 .68827 L .53202 .68385 L p 0 0 1 r
F P
0 g
s
.59364 .68144 m .58653 .68814 L .57646 .68372 L p 0 0 1 r
F P
0 g
s
.63088 .68801 m .63813 .6813 L .64809 .68574 L p 0 0 1 r
F P
0 g
s
.63813 .6813 m .63088 .68801 L .6209 .68359 L p 0 0 1 r
F P
0 g
s
.39554 .72052 m .40213 .71195 L .41265 .7136 L p 1 0 0 r
F P
0 g
s
.41929 .70435 m .41265 .7136 L .40213 .71195 L p 1 0 0 r
F P
0 g
s
.4841 .65842 m .4909 .64902 L .50115 .651 L p 1 0 0 r
F P
0 g
s
.50798 .64224 m .50115 .651 L .4909 .64902 L p 1 0 0 r
F P
0 g
s
.53523 .64134 m .54219 .63455 L .55238 .64012 L p 1 0 0 r
F P
0 g
s
.54219 .63455 m .53523 .64134 L .52506 .63725 L p 1 0 0 r
F P
0 g
s
.32358 .65459 m .33007 .64493 L .34076 .6476 L p 0 1 0 r
F P
0 g
s
.34076 .6476 m .34719 .63943 L .35776 .64359 L p 0 1 0 r
F P
0 g
s
.34719 .63943 m .34076 .6476 L .33007 .64493 L p 0 1 0 r
F P
0 g
s
.57997 .70803 m .58696 .69874 L .59684 .69869 L p 0 1 0 r
F P
0 g
s
.60379 .68779 m .59684 .69869 L .58696 .69874 L p 0 1 0 r
F P
0 g
s
.52867 .71861 m .53562 .71295 L .54581 .71754 L p 0 1 0 r
F P
0 g
s
.53562 .71295 m .52867 .71861 L .51845 .71295 L p 0 1 0 r
F P
0 g
s
.49108 .70448 m .49792 .70017 L .5082 .70678 L p 0 1 0 r
F P
0 g
s
.49792 .70017 m .49108 .70448 L .48081 .69731 L p 0 1 0 r
F P
0 g
s
.56256 .64659 m .56968 .642 L .57995 .6504 L p 1 0 0 r
F P
0 g
s
.56968 .642 m .56256 .64659 L .55238 .64012 L p 1 0 0 r
F P
0 g
s
.38509 .64796 m .39153 .64254 L .40194 .64927 L p 0 1 0 r
F P
0 g
s
.39153 .64254 m .38509 .64796 L .37466 .64207 L p 0 1 0 r
F P
0 g
s
.66517 .50183 m .66676 .49949 L .66719 .5045 L p 0 1 0 r
F P
0 g
s
.65892 .52382 m .66517 .50183 L p .66719 .5045 L 0 1 0 r
F P
0 g
s
.41929 .70435 m .42597 .69482 L .43644 .69574 L p 1 0 0 r
F P
0 g
s
.44315 .68591 m .43644 .69574 L .42597 .69482 L p 1 0 0 r
F P
0 g
s
.3818 .68653 m .38828 .67981 L .39876 .68425 L p 0 0 1 r
F P
0 g
s
.38828 .67981 m .3818 .68653 L .3713 .6821 L p 0 0 1 r
F P
0 g
s
.35776 .64359 m .36417 .63668 L .37466 .64207 L p 0 1 0 r
F P
0 g
s
.36417 .63668 m .35776 .64359 L .34719 .63943 L p 0 1 0 r
F P
0 g
s
.43279 .67968 m .42617 .68639 L .41575 .68196 L p 0 0 1 r
F P
0 g
s
.65113 .58432 m .64459 .60235 L .63532 .60924 L p 0 1 0 r
F P
0 g
s
.63532 .60924 m .64201 .59233 L .65113 .58432 L p 0 1 0 r
F P
0 g
s
.47054 .68626 m .4773 .67954 L .4876 .68398 L p 0 0 1 r
F P
0 g
s
.51492 .68613 m .52182 .67941 L .53202 .68385 L p 0 0 1 r
F P
0 g
s
.52182 .67941 m .51492 .68613 L .50469 .6817 L p 0 0 1 r
F P
0 g
s
.40213 .71195 m .39554 .72052 L .38499 .718 L p 1 0 0 r
F P
0 g
s
.55931 .686 m .56634 .67928 L .57646 .68372 L p 0 0 1 r
F P
0 g
s
.56634 .67928 m .55931 .686 L .54916 .68157 L p 0 0 1 r
F P
0 g
s
.64809 .68574 m .6554 .67901 L .66534 .68346 L p 0 0 1 r
F P
0 g
s
.6554 .67901 m .64809 .68574 L .63813 .6813 L p 0 0 1 r
F P
0 g
s
.33007 .64493 m .32358 .65459 L .3127 .6537 L p 0 1 0 r
F P
0 g
s
.4909 .64902 m .4841 .65842 L .47379 .6571 L p 1 0 0 r
F P
0 g
s
.63232 .71265 m .62455 .71036 L .61401 .69615 L p 1 0 0 r
F P
0 g
s
.61401 .69615 m .62163 .69707 L .63232 .71265 L p 1 0 0 r
F P
0 g
s
.48081 .69731 m .48761 .69319 L .49792 .70017 L p 0 1 0 r
F P
0 g
s
.48761 .69319 m .48081 .69731 L .47052 .68991 L p 0 1 0 r
F P
0 g
s
.35435 .68438 m .36075 .67765 L .3713 .6821 L p 0 0 1 r
F P
0 g
s
.36075 .67765 m .35435 .68438 L .34378 .67994 L p 0 0 1 r
F P
0 g
s
.39876 .68425 m .4053 .67752 L .41575 .68196 L p 0 0 1 r
F P
0 g
s
.4053 .67752 m .39876 .68425 L .38828 .67981 L p 0 0 1 r
F P
0 g
s
.55238 .64012 m .55944 .63467 L .56968 .642 L p 1 0 0 r
F P
0 g
s
.55944 .63467 m .55238 .64012 L .54219 .63455 L p 1 0 0 r
F P
0 g
s
.58696 .69874 m .59396 .68869 L .60379 .68779 L p 0 1 0 r
F P
0 g
s
.4876 .68398 m .49442 .67725 L .50469 .6817 L p 0 0 1 r
F P
0 g
s
.49442 .67725 m .4876 .68398 L .4773 .67954 L p 0 0 1 r
F P
0 g
s
.53202 .68385 m .53898 .67712 L .54916 .68157 L p 0 0 1 r
F P
0 g
s
.53898 .67712 m .53202 .68385 L .52182 .67941 L p 0 0 1 r
F P
0 g
s
.57646 .68372 m .58355 .67698 L .59364 .68144 L p 0 0 1 r
F P
0 g
s
.58355 .67698 m .57646 .68372 L .56634 .67928 L p 0 0 1 r
F P
0 g
s
.66142 .53438 m .65507 .55494 L .64601 .5639 L p 0 1 0 r
F P
0 g
s
.64601 .5639 m .65253 .5445 L .66142 .53438 L p 0 1 0 r
F P
0 g
s
.54581 .71754 m .55281 .71089 L .56293 .71417 L p 0 1 0 r
F P
0 g
s
.55281 .71089 m .54581 .71754 L .53562 .71295 L p 0 1 0 r
F P
0 g
s
.51845 .71295 m .52539 .70772 L .53562 .71295 L p 0 1 0 r
F P
0 g
s
.52539 .70772 m .51845 .71295 L .5082 .70678 L p 0 1 0 r
F P
0 g
s
.6209 .68359 m .62813 .67685 L .63813 .6813 L p 0 0 1 r
F P
0 g
s
.37466 .64207 m .38109 .63618 L .39153 .64254 L p 0 1 0 r
F P
0 g
s
.38109 .63618 m .37466 .64207 L .36417 .63668 L p 0 1 0 r
F P
0 g
s
.67271 .67672 m .66534 .68346 L .6554 .67901 L p 0 0 1 r
F P
0 g
s
.56293 .71417 m .56994 .70631 L .57997 .70803 L p 0 1 0 r
F P
0 g
s
.58696 .69874 m .57997 .70803 L .56994 .70631 L p 0 1 0 r
F P
0 g
s
.40213 .71195 m .40876 .70298 L .41929 .70435 L p 1 0 0 r
F P
0 g
s
.42597 .69482 m .41929 .70435 L .40876 .70298 L p 1 0 0 r
F P
0 g
s
.24513 .5944 m .24025 .58939 L .23083 .57135 L p 1 0 0 r
F P
0 g
s
.23083 .57135 m .23546 .5777 L .24513 .5944 L p 1 0 0 r
F P
0 g
s
.64459 .60235 m .63795 .61922 L .62856 .62502 L p 0 1 0 r
F P
0 g
s
.62856 .62502 m .63532 .60924 L .64459 .60235 L p 0 1 0 r
F P
0 g
s
.47052 .68991 m .47728 .68592 L .48761 .69319 L p 0 1 0 r
F P
0 g
s
.47728 .68592 m .47052 .68991 L .46021 .68235 L p 0 1 0 r
F P
0 g
s
.50798 .64224 m .51484 .63381 L .52506 .63725 L p 1 0 0 r
F P
0 g
s
.52506 .63725 m .53198 .6298 L .54219 .63455 L p 1 0 0 r
F P
0 g
s
.53198 .6298 m .52506 .63725 L .51484 .63381 L p 1 0 0 r
F P
0 g
s
.4909 .64902 m .49772 .63984 L .50798 .64224 L p 1 0 0 r
F P
0 g
s
.51484 .63381 m .50798 .64224 L .49772 .63984 L p 1 0 0 r
F P
0 g
s
.42597 .69482 m .43268 .68506 L .44315 .68591 L p 1 0 0 r
F P
0 g
s
.56994 .70631 m .56293 .71417 L .55281 .71089 L p 0 1 0 r
F P
0 g
s
.3713 .6821 m .37776 .67535 L .38828 .67981 L p 0 0 1 r
F P
0 g
s
.37776 .67535 m .3713 .6821 L .36075 .67765 L p 0 0 1 r
F P
0 g
s
.66651 .49837 m .66676 .49949 L .66517 .50183 L p 0 1 0 r
F P
0 g
s
.41575 .68196 m .42236 .67522 L .43279 .67968 L p 0 0 1 r
F P
0 g
s
.42236 .67522 m .41575 .68196 L .4053 .67752 L p 0 0 1 r
F P
0 g
s
.33007 .64493 m .33653 .63598 L .34719 .63943 L p 0 1 0 r
F P
0 g
s
.34719 .63943 m .35362 .63186 L .36417 .63668 L p 0 1 0 r
F P
0 g
s
.35362 .63186 m .34719 .63943 L .33653 .63598 L p 0 1 0 r
F P
0 g
s
.50469 .6817 m .51157 .67495 L .52182 .67941 L p 0 0 1 r
F P
0 g
s
.51157 .67495 m .50469 .6817 L .49442 .67725 L p 0 0 1 r
F P
0 g
s
.54916 .68157 m .55618 .67482 L .56634 .67928 L p 0 0 1 r
F P
0 g
s
.55618 .67482 m .54916 .68157 L .53898 .67712 L p 0 0 1 r
F P
0 g
s
.46021 .68235 m .46694 .67843 L .47728 .68592 L p 0 1 0 r
F P
0 g
s
.63813 .6813 m .64542 .67455 L .6554 .67901 L p 0 0 1 r
F P
0 g
s
.64542 .67455 m .63813 .6813 L .62813 .67685 L p 0 0 1 r
F P
0 g
s
.3127 .6537 m .31925 .64312 L .33007 .64493 L p 0 1 0 r
F P
0 g
s
.33653 .63598 m .33007 .64493 L .31925 .64312 L p 0 1 0 r
F P
0 g
s
.40843 .64454 m .40194 .64927 L .39153 .64254 L p 0 1 0 r
F P
0 g
s
.64317 .73011 m .63522 .72632 L .62455 .71036 L p 1 0 0 r
F P
0 g
s
.62455 .71036 m .63232 .71265 L .64317 .73011 L p 1 0 0 r
F P
0 g
s
.38499 .718 m .39156 .70986 L .40213 .71195 L p 1 0 0 r
F P
0 g
s
.40876 .70298 m .40213 .71195 L .39156 .70986 L p 1 0 0 r
F P
0 g
s
.66517 .50183 m .66639 .49713 L .66651 .49837 L p 0 1 0 r
F P
0 g
s
.47379 .6571 m .48059 .6474 L .4909 .64902 L p 1 0 0 r
F P
0 g
s
.49772 .63984 m .4909 .64902 L .48059 .6474 L p 1 0 0 r
F P
0 g
s
.2306 .56598 m .22599 .55967 L .21677 .54029 L p 1 0 0 r
F P
0 g
s
.21677 .54029 m .2211 .54797 L .2306 .56598 L p 1 0 0 r
F P
0 g
s
.5082 .70678 m .51511 .70192 L .52539 .70772 L p 0 1 0 r
F P
0 g
s
.51511 .70192 m .5082 .70678 L .49792 .70017 L p 0 1 0 r
F P
0 g
s
.54219 .63455 m .5492 .62832 L .55944 .63467 L p 1 0 0 r
F P
0 g
s
.5492 .62832 m .54219 .63455 L .53198 .6298 L p 1 0 0 r
F P
0 g
s
.39156 .70986 m .38499 .718 L .37441 .71489 L p 1 0 0 r
F P
0 g
s
.34378 .67994 m .35016 .67318 L .36075 .67765 L p 0 0 1 r
F P
0 g
s
.35016 .67318 m .34378 .67994 L .33317 .67548 L p 0 0 1 r
F P
0 g
s
.66531 .49229 m .66639 .49713 L p .65638 .51296 L 0 1 0 r
F P
0 g
s
.66639 .49713 m .66517 .50183 L .65638 .51296 L p 0 1 0 r
F P
0 g
s
.36417 .63668 m .3706 .63026 L .38109 .63618 L p 0 1 0 r
F P
0 g
s
.3706 .63026 m .36417 .63668 L .35362 .63186 L p 0 1 0 r
F P
0 g
s
.38828 .67981 m .3948 .67305 L .4053 .67752 L p 0 0 1 r
F P
0 g
s
.3948 .67305 m .38828 .67981 L .37776 .67535 L p 0 0 1 r
F P
0 g
s
.4773 .67954 m .4841 .67278 L .49442 .67725 L p 0 0 1 r
F P
0 g
s
.4841 .67278 m .4773 .67954 L .46696 .67508 L p 0 0 1 r
F P
0 g
s
.53562 .71295 m .54262 .70685 L .55281 .71089 L p 0 1 0 r
F P
0 g
s
.54262 .70685 m .53562 .71295 L .52539 .70772 L p 0 1 0 r
F P
0 g
s
.52182 .67941 m .52876 .67265 L .53898 .67712 L p 0 0 1 r
F P
0 g
s
.52876 .67265 m .52182 .67941 L .51157 .67495 L p 0 0 1 r
F P
0 g
s
.56634 .67928 m .57342 .67252 L .58355 .67698 L p 0 0 1 r
F P
0 g
s
.57342 .67252 m .56634 .67928 L .55618 .67482 L p 0 0 1 r
F P
0 g
s
.40876 .70298 m .41543 .69367 L .42597 .69482 L p 1 0 0 r
F P
0 g
s
.43268 .68506 m .42597 .69482 L .41543 .69367 L p 1 0 0 r
F P
0 g
s
.6554 .67901 m .66276 .67225 L .67271 .67672 L p 0 0 1 r
F P
0 g
s
.66276 .67225 m .6554 .67901 L .64542 .67455 L p 0 0 1 r
F P
0 g
s
.56994 .70631 m .57697 .69778 L .58696 .69874 L p 0 1 0 r
F P
0 g
s
.59396 .68869 m .58696 .69874 L .57697 .69778 L p 0 1 0 r
F P
0 g
s
.39153 .64254 m .39801 .63746 L .40843 .64454 L p 0 1 0 r
F P
0 g
s
.39801 .63746 m .39153 .64254 L .38109 .63618 L p 0 1 0 r
F P
0 g
s
.49792 .70017 m .5048 .69562 L .51511 .70192 L p 0 1 0 r
F P
0 g
s
.5048 .69562 m .49792 .70017 L .48761 .69319 L p 0 1 0 r
F P
0 g
s
.57689 .63813 m .56968 .642 L .55944 .63467 L p 1 0 0 r
F P
0 g
s
.66517 .50183 m .65892 .52382 L .64995 .53377 L p 0 1 0 r
F P
0 g
s
.64995 .53377 m .65638 .51296 L .66517 .50183 L p 0 1 0 r
F P
0 g
s
.65507 .55494 m .64859 .57424 L .63938 .58206 L p 0 1 0 r
F P
0 g
s
.63938 .58206 m .64601 .5639 L .65507 .55494 L p 0 1 0 r
F P
0 g
s
.31925 .64312 m .3127 .6537 L .30168 .65383 L p 0 1 0 r
F P
0 g
s
.36075 .67765 m .36719 .67088 L .37776 .67535 L p 0 0 1 r
F P
0 g
s
.36719 .67088 m .36075 .67765 L .35016 .67318 L p 0 0 1 r
F P
0 g
s
.4053 .67752 m .41188 .67074 L .42236 .67522 L p 0 0 1 r
F P
0 g
s
.41188 .67074 m .4053 .67752 L .3948 .67305 L p 0 0 1 r
F P
0 g
s
.49442 .67725 m .50128 .67047 L .51157 .67495 L p 0 0 1 r
F P
0 g
s
.50128 .67047 m .49442 .67725 L .4841 .67278 L p 0 0 1 r
F P
0 g
s
.49772 .63984 m .50458 .63094 L .51484 .63381 L p 1 0 0 r
F P
0 g
s
.51484 .63381 m .52175 .62576 L .53198 .6298 L p 1 0 0 r
F P
0 g
s
.52175 .62576 m .51484 .63381 L .50458 .63094 L p 1 0 0 r
F P
0 g
s
.53898 .67712 m .54598 .67034 L .55618 .67482 L p 0 0 1 r
F P
0 g
s
.54598 .67034 m .53898 .67712 L .52876 .67265 L p 0 0 1 r
F P
0 g
s
.59069 .67021 m .58355 .67698 L .57342 .67252 L p 0 0 1 r
F P
0 g
s
.55281 .71089 m .55983 .70369 L .56994 .70631 L p 0 1 0 r
F P
0 g
s
.55983 .70369 m .55281 .71089 L .54262 .70685 L p 0 1 0 r
F P
0 g
s
.62813 .67685 m .63541 .67007 L .64542 .67455 L p 0 0 1 r
F P
0 g
s
.63541 .67007 m .62813 .67685 L .61808 .67238 L p 0 0 1 r
F P
0 g
s
.68013 .66994 m .67271 .67672 L .66276 .67225 L p 0 0 1 r
F P
0 g
s
.57697 .69778 m .56994 .70631 L .55983 .70369 L p 0 1 0 r
F P
0 g
s
.53198 .6298 m .53896 .62284 L .5492 .62832 L p 1 0 0 r
F P
0 g
s
.53896 .62284 m .53198 .6298 L .52175 .62576 L p 1 0 0 r
F P
0 g
s
.31925 .64312 m .32576 .63331 L .33653 .63598 L p 0 1 0 r
F P
0 g
s
.33653 .63598 m .34298 .62769 L .35362 .63186 L p 0 1 0 r
F P
0 g
s
.34298 .62769 m .33653 .63598 L .32576 .63331 L p 0 1 0 r
F P
0 g
s
.39156 .70986 m .39817 .70125 L .40876 .70298 L p 1 0 0 r
F P
0 g
s
.41543 .69367 m .40876 .70298 L .39817 .70125 L p 1 0 0 r
F P
0 g
s
.48059 .6474 m .48741 .63787 L .49772 .63984 L p 1 0 0 r
F P
0 g
s
.50458 .63094 m .49772 .63984 L .48741 .63787 L p 1 0 0 r
F P
0 g
s
.55944 .63467 m .56658 .62989 L .57689 .63813 L p 1 0 0 r
F P
0 g
s
.56658 .62989 m .55944 .63467 L .5492 .62832 L p 1 0 0 r
F P
0 g
s
.48761 .69319 m .49446 .68889 L .5048 .69562 L p 0 1 0 r
F P
0 g
s
.49446 .68889 m .48761 .69319 L .47728 .68592 L p 0 1 0 r
F P
0 g
s
.38109 .63618 m .38755 .63069 L .39801 .63746 L p 0 1 0 r
F P
0 g
s
.38755 .63069 m .38109 .63618 L .3706 .63026 L p 0 1 0 r
F P
0 g
s
.52539 .70772 m .53237 .7021 L .54262 .70685 L p 0 1 0 r
F P
0 g
s
.53237 .7021 m .52539 .70772 L .51511 .70192 L p 0 1 0 r
F P
0 g
s
.65422 .74962 m .64607 .74422 L .63522 .72632 L p 1 0 0 r
F P
0 g
s
.63522 .72632 m .64317 .73011 L .65422 .74962 L p 1 0 0 r
F P
0 g
s
.62941 .69907 m .62163 .69707 L .61107 .68319 L p 1 0 0 r
F P
0 g
s
.61107 .68319 m .6187 .68383 L .62941 .69907 L p 1 0 0 r
F P
0 g
s
.35362 .63186 m .36005 .62485 L .3706 .63026 L p 0 1 0 r
F P
0 g
s
.36005 .62485 m .35362 .63186 L .34298 .62769 L p 0 1 0 r
F P
0 g
s
.33317 .67548 m .33953 .6687 L .35016 .67318 L p 0 0 1 r
F P
0 g
s
.33953 .6687 m .33317 .67548 L .32251 .67101 L p 0 0 1 r
F P
0 g
s
.255 .60979 m .24989 .60608 L .24025 .58939 L p 1 0 0 r
F P
0 g
s
.24025 .58939 m .24513 .5944 L .255 .60979 L p 1 0 0 r
F P
0 g
s
.66267 .49082 m .66487 .48766 L .66531 .49229 L p 0 1 0 r
F P
0 g
s
.65638 .51296 m .66267 .49082 L p .66531 .49229 L 0 1 0 r
F P
0 g
s
.37776 .67535 m .38426 .66856 L .3948 .67305 L p 0 0 1 r
F P
0 g
s
.38426 .66856 m .37776 .67535 L .36719 .67088 L p 0 0 1 r
F P
0 g
s
.429 .66843 m .42236 .67522 L .41188 .67074 L p 0 0 1 r
F P
0 g
s
.57697 .69778 m .58401 .68853 L .59396 .68869 L p 0 1 0 r
F P
0 g
s
.60095 .67782 m .59396 .68869 L .58401 .68853 L p 0 1 0 r
F P
0 g
s
.46696 .67508 m .47374 .6683 L .4841 .67278 L p 0 0 1 r
F P
0 g
s
.41543 .69367 m .42214 .68407 L .43268 .68506 L p 1 0 0 r
F P
0 g
s
.43941 .67514 m .43268 .68506 L .42214 .68407 L p 1 0 0 r
F P
0 g
s
.51157 .67495 m .51849 .66816 L .52876 .67265 L p 0 0 1 r
F P
0 g
s
.51849 .66816 m .51157 .67495 L .50128 .67047 L p 0 0 1 r
F P
0 g
s
.55618 .67482 m .56324 .66803 L .57342 .67252 L p 0 0 1 r
F P
0 g
s
.56324 .66803 m .55618 .67482 L .54598 .67034 L p 0 0 1 r
F P
0 g
s
.37441 .71489 m .38095 .70725 L .39156 .70986 L p 1 0 0 r
F P
0 g
s
.39817 .70125 m .39156 .70986 L .38095 .70725 L p 1 0 0 r
F P
0 g
s
.64542 .67455 m .65276 .66776 L .66276 .67225 L p 0 0 1 r
F P
0 g
s
.65276 .66776 m .64542 .67455 L .63541 .67007 L p 0 0 1 r
F P
0 g
s
.38095 .70725 m .37441 .71489 L .36381 .71111 L p 1 0 0 r
F P
0 g
s
.30168 .65383 m .3083 .64224 L .31925 .64312 L p 0 1 0 r
F P
0 g
s
.32576 .63331 m .31925 .64312 L .3083 .64224 L p 0 1 0 r
F P
0 g
s
.47728 .68592 m .4841 .68181 L .49446 .68889 L p 0 1 0 r
F P
0 g
s
.4841 .68181 m .47728 .68592 L .46694 .67843 L p 0 1 0 r
F P
0 g
s
.48741 .63787 m .48059 .6474 L .47021 .64606 L p 1 0 0 r
F P
0 g
s
.64859 .57424 m .64201 .59233 L .63266 .59903 L p 0 1 0 r
F P
0 g
s
.63266 .59903 m .63938 .58206 L .64859 .57424 L p 0 1 0 r
F P
0 g
s
.5492 .62832 m .55629 .62269 L .56658 .62989 L p 1 0 0 r
F P
0 g
s
.55629 .62269 m .5492 .62832 L .53896 .62284 L p 1 0 0 r
F P
0 g
s
.35016 .67318 m .35659 .66638 L .36719 .67088 L p 0 0 1 r
F P
0 g
s
.35659 .66638 m .35016 .67318 L .33953 .6687 L p 0 0 1 r
F P
0 g
s
.3948 .67305 m .40137 .66625 L .41188 .67074 L p 0 0 1 r
F P
0 g
s
.40137 .66625 m .3948 .67305 L .38426 .66856 L p 0 0 1 r
F P
0 g
s
.4841 .67278 m .49094 .66598 L .50128 .67047 L p 0 0 1 r
F P
0 g
s
.49094 .66598 m .4841 .67278 L .47374 .6683 L p 0 0 1 r
F P
0 g
s
.52876 .67265 m .53574 .66584 L .54598 .67034 L p 0 0 1 r
F P
0 g
s
.53574 .66584 m .52876 .67265 L .51849 .66816 L p 0 0 1 r
F P
0 g
s
.3706 .63026 m .37705 .62429 L .38755 .63069 L p 0 1 0 r
F P
0 g
s
.37705 .62429 m .3706 .63026 L .36005 .62485 L p 0 1 0 r
F P
0 g
s
.41497 .64005 m .40843 .64454 L .39801 .63746 L p 0 1 0 r
F P
0 g
s
.57342 .67252 m .58054 .66571 L .59069 .67021 L p 0 0 1 r
F P
0 g
s
.58054 .66571 m .57342 .67252 L .56324 .66803 L p 0 0 1 r
F P
0 g
s
.51511 .70192 m .52207 .69672 L .53237 .7021 L p 0 1 0 r
F P
0 g
s
.52207 .69672 m .51511 .70192 L .5048 .69562 L p 0 1 0 r
F P
0 g
s
.61808 .67238 m .62535 .66558 L .63541 .67007 L p 0 0 1 r
F P
0 g
s
.66276 .67225 m .67016 .66544 L .68013 .66994 L p 0 0 1 r
F P
0 g
s
.67016 .66544 m .66276 .67225 L .65276 .66776 L p 0 0 1 r
F P
0 g
s
.54262 .70685 m .54965 .70024 L .55983 .70369 L p 0 1 0 r
F P
0 g
s
.54965 .70024 m .54262 .70685 L .53237 .7021 L p 0 1 0 r
F P
0 g
s
.46694 .67843 m .47371 .67444 L .4841 .68181 L p 0 1 0 r
F P
0 g
s
.47371 .67444 m .46694 .67843 L .45657 .67079 L p 0 1 0 r
F P
0 g
s
.58401 .68853 m .59104 .67851 L .60095 .67782 L p 0 1 0 r
F P
0 g
s
.64027 .71613 m .63232 .71265 L .62163 .69707 L p 1 0 0 r
F P
0 g
s
.62163 .69707 m .62941 .69907 L .64027 .71613 L p 1 0 0 r
F P
0 g
s
.24032 .58268 m .23546 .5777 L .22599 .55967 L p 1 0 0 r
F P
0 g
s
.22599 .55967 m .2306 .56598 L .24032 .58268 L p 1 0 0 r
F P
0 g
s
.39817 .70125 m .40483 .69223 L .41543 .69367 L p 1 0 0 r
F P
0 g
s
.42214 .68407 m .41543 .69367 L .40483 .69223 L p 1 0 0 r
F P
0 g
s
.55983 .70369 m .56688 .69586 L .57697 .69778 L p 0 1 0 r
F P
0 g
s
.58401 .68853 m .57697 .69778 L .56688 .69586 L p 0 1 0 r
F P
0 g
s
.50458 .63094 m .51147 .62236 L .52175 .62576 L p 1 0 0 r
F P
0 g
s
.52175 .62576 m .5287 .61815 L .53896 .62284 L p 1 0 0 r
F P
0 g
s
.5287 .61815 m .52175 .62576 L .51147 .62236 L p 1 0 0 r
F P
0 g
s
.48741 .63787 m .49427 .62855 L .50458 .63094 L p 1 0 0 r
F P
0 g
s
.51147 .62236 m .50458 .63094 L .49427 .62855 L p 1 0 0 r
F P
0 g
s
.65892 .52382 m .65253 .5445 L .64339 .55328 L p 0 1 0 r
F P
0 g
s
.64339 .55328 m .64995 .53377 L .65892 .52382 L p 0 1 0 r
F P
0 g
s
.66451 .48611 m .66487 .48766 L .66267 .49082 L p 0 1 0 r
F P
0 g
s
.32251 .67101 m .32886 .66419 L .33953 .6687 L p 0 0 1 r
F P
0 g
s
.32886 .66419 m .32251 .67101 L .31181 .66652 L p 0 0 1 r
F P
0 g
s
.42214 .68407 m .42887 .67423 L .43941 .67514 L p 1 0 0 r
F P
0 g
s
.36719 .67088 m .37368 .66406 L .38426 .66856 L p 0 0 1 r
F P
0 g
s
.37368 .66406 m .36719 .67088 L .35659 .66638 L p 0 0 1 r
F P
0 g
s
.32576 .63331 m .33225 .62423 L .34298 .62769 L p 0 1 0 r
F P
0 g
s
.34298 .62769 m .34943 .62002 L .36005 .62485 L p 0 1 0 r
F P
0 g
s
.34943 .62002 m .34298 .62769 L .33225 .62423 L p 0 1 0 r
F P
0 g
s
.41188 .67074 m .41851 .66393 L .429 .66843 L p 0 0 1 r
F P
0 g
s
.41851 .66393 m .41188 .67074 L .40137 .66625 L p 0 0 1 r
F P
0 g
s
.56688 .69586 m .55983 .70369 L .54965 .70024 L p 0 1 0 r
F P
0 g
s
.50128 .67047 m .50818 .66366 L .51849 .66816 L p 0 0 1 r
F P
0 g
s
.50818 .66366 m .50128 .67047 L .49094 .66598 L p 0 0 1 r
F P
0 g
s
.45657 .67079 m .46331 .66685 L .47371 .67444 L p 0 1 0 r
F P
0 g
s
.64201 .59233 m .63532 .60924 L .62585 .61485 L p 0 1 0 r
F P
0 g
s
.62585 .61485 m .63266 .59903 L .64201 .59233 L p 0 1 0 r
F P
0 g
s
.39801 .63746 m .40452 .63267 L .41497 .64005 L p 0 1 0 r
F P
0 g
s
.40452 .63267 m .39801 .63746 L .38755 .63069 L p 0 1 0 r
F P
0 g
s
.54598 .67034 m .55302 .66352 L .56324 .66803 L p 0 0 1 r
F P
0 g
s
.55302 .66352 m .54598 .67034 L .53574 .66584 L p 0 0 1 r
F P
0 g
s
.3083 .64224 m .31488 .6315 L .32576 .63331 L p 0 1 0 r
F P
0 g
s
.33225 .62423 m .32576 .63331 L .31488 .6315 L p 0 1 0 r
F P
0 g
s
.63541 .67007 m .64273 .66325 L .65276 .66776 L p 0 0 1 r
F P
0 g
s
.64273 .66325 m .63541 .67007 L .62535 .66558 L p 0 0 1 r
F P
0 g
s
.68759 .66312 m .68013 .66994 L .67016 .66544 L p 0 0 1 r
F P
0 g
s
.66267 .49082 m .66433 .48443 L .66451 .48611 L p 0 1 0 r
F P
0 g
s
.53896 .62284 m .546 .61643 L .55629 .62269 L p 1 0 0 r
F P
0 g
s
.546 .61643 m .53896 .62284 L .5287 .61815 L p 1 0 0 r
F P
0 g
s
.5048 .69562 m .51174 .69078 L .52207 .69672 L p 0 1 0 r
F P
0 g
s
.51174 .69078 m .5048 .69562 L .49446 .68889 L p 0 1 0 r
F P
0 g
s
.36381 .71111 m .3703 .70404 L .38095 .70725 L p 1 0 0 r
F P
0 g
s
.3703 .70404 m .36381 .71111 L .35319 .70658 L p 1 0 0 r
F P
0 g
s
.38095 .70725 m .38754 .69907 L .39817 .70125 L p 1 0 0 r
F P
0 g
s
.40483 .69223 m .39817 .70125 L .38754 .69907 L p 1 0 0 r
F P
0 g
s
.47021 .64606 m .47704 .63624 L .48741 .63787 L p 1 0 0 r
F P
0 g
s
.49427 .62855 m .48741 .63787 L .47704 .63624 L p 1 0 0 r
F P
0 g
s
.22568 .55423 m .2211 .54797 L .21183 .52862 L p 1 0 0 r
F P
0 g
s
.21183 .52862 m .21614 .53624 L .22568 .55423 L p 1 0 0 r
F P
0 g
s
.3083 .64224 m .30168 .65383 L .29047 .65505 L p 0 1 0 r
F P
0 g
s
.26503 .6239 m .25971 .62145 L .24989 .60608 L p 1 0 0 r
F P
0 g
s
.24989 .60608 m .255 .60979 L .26503 .6239 L p 1 0 0 r
F P
0 g
s
.36005 .62485 m .36649 .61834 L .37705 .62429 L p 0 1 0 r
F P
0 g
s
.36649 .61834 m .36005 .62485 L .34943 .62002 L p 0 1 0 r
F P
0 g
s
.33953 .6687 m .34594 .66187 L .35659 .66638 L p 0 0 1 r
F P
0 g
s
.34594 .66187 m .33953 .6687 L .32886 .66419 L p 0 0 1 r
F P
0 g
s
.38754 .69907 m .38095 .70725 L .3703 .70404 L p 1 0 0 r
F P
0 g
s
.38426 .66856 m .39081 .66173 L .40137 .66625 L p 0 0 1 r
F P
0 g
s
.39081 .66173 m .38426 .66856 L .37368 .66406 L p 0 0 1 r
F P
0 g
s
.47374 .6683 m .48057 .66146 L .49094 .66598 L p 0 0 1 r
F P
0 g
s
.51849 .66816 m .52545 .66133 L .53574 .66584 L p 0 0 1 r
F P
0 g
s
.52545 .66133 m .51849 .66816 L .50818 .66366 L p 0 0 1 r
F P
0 g
s
.66329 .47996 m .66433 .48443 L p .6538 .50181 L 0 1 0 r
F P
0 g
s
.66433 .48443 m .66267 .49082 L .6538 .50181 L p 0 1 0 r
F P
0 g
s
.56324 .66803 m .57035 .66119 L .58054 .66571 L p 0 0 1 r
F P
0 g
s
.57035 .66119 m .56324 .66803 L .55302 .66352 L p 0 0 1 r
F P
0 g
s
.53237 .7021 m .53939 .69603 L .54965 .70024 L p 0 1 0 r
F P
0 g
s
.53939 .69603 m .53237 .7021 L .52207 .69672 L p 0 1 0 r
F P
0 g
s
.38755 .63069 m .39404 .62554 L .40452 .63267 L p 0 1 0 r
F P
0 g
s
.39404 .62554 m .38755 .63069 L .37705 .62429 L p 0 1 0 r
F P
0 g
s
.65276 .66776 m .66015 .66092 L .67016 .66544 L p 0 0 1 r
F P
0 g
s
.66015 .66092 m .65276 .66776 L .64273 .66325 L p 0 0 1 r
F P
0 g
s
.5738 .62583 m .56658 .62989 L .55629 .62269 L p 1 0 0 r
F P
0 g
s
.40483 .69223 m .41153 .68285 L .42214 .68407 L p 1 0 0 r
F P
0 g
s
.42887 .67423 m .42214 .68407 L .41153 .68285 L p 1 0 0 r
F P
0 g
s
.49446 .68889 m .50137 .68436 L .51174 .69078 L p 0 1 0 r
F P
0 g
s
.50137 .68436 m .49446 .68889 L .4841 .68181 L p 0 1 0 r
F P
0 g
s
.56688 .69586 m .57395 .68737 L .58401 .68853 L p 0 1 0 r
F P
0 g
s
.59104 .67851 m .58401 .68853 L .57395 .68737 L p 0 1 0 r
F P
0 g
s
.65132 .73518 m .64317 .73011 L .63232 .71265 L p 1 0 0 r
F P
0 g
s
.63232 .71265 m .64027 .71613 L .65132 .73518 L p 1 0 0 r
F P
0 g
s
.29047 .65505 m .29719 .64237 L .3083 .64224 L p 0 1 0 r
F P
0 g
s
.31488 .6315 m .3083 .64224 L .29719 .64237 L p 0 1 0 r
F P
0 g
s
.31181 .66652 m .31814 .65967 L .32886 .66419 L p 0 0 1 r
F P
0 g
s
.31814 .65967 m .31181 .66652 L .30107 .662 L p 0 0 1 r
F P
0 g
s
.35659 .66638 m .36305 .65954 L .37368 .66406 L p 0 0 1 r
F P
0 g
s
.36305 .65954 m .35659 .66638 L .34594 .66187 L p 0 0 1 r
F P
0 g
s
.40137 .66625 m .40797 .6594 L .41851 .66393 L p 0 0 1 r
F P
0 g
s
.40797 .6594 m .40137 .66625 L .39081 .66173 L p 0 0 1 r
F P
0 g
s
.49094 .66598 m .49783 .65913 L .50818 .66366 L p 0 0 1 r
F P
0 g
s
.49783 .65913 m .49094 .66598 L .48057 .66146 L p 0 0 1 r
F P
0 g
s
.49427 .62855 m .50115 .61951 L .51147 .62236 L p 1 0 0 r
F P
0 g
s
.51147 .62236 m .51841 .61417 L .5287 .61815 L p 1 0 0 r
F P
0 g
s
.51841 .61417 m .51147 .62236 L .50115 .61951 L p 1 0 0 r
F P
0 g
s
.53574 .66584 m .54276 .659 L .55302 .66352 L p 0 0 1 r
F P
0 g
s
.54276 .659 m .53574 .66584 L .52545 .66133 L p 0 0 1 r
F P
0 g
s
.66267 .49082 m .65638 .51296 L .64733 .52277 L p 0 1 0 r
F P
0 g
s
.64733 .52277 m .6538 .50181 L .66267 .49082 L p 0 1 0 r
F P
0 g
s
.62648 .68556 m .6187 .68383 L .60812 .67026 L p 1 0 0 r
F P
0 g
s
.60812 .67026 m .61575 .67064 L .62648 .68556 L p 1 0 0 r
F P
0 g
s
.5877 .65886 m .58054 .66571 L .57035 .66119 L p 0 0 1 r
F P
0 g
s
.62535 .66558 m .63265 .65873 L .64273 .66325 L p 0 0 1 r
F P
0 g
s
.63265 .65873 m .62535 .66558 L .61524 .66106 L p 0 0 1 r
F P
0 g
s
.65253 .5445 m .64601 .5639 L .63672 .57154 L p 0 1 0 r
F P
0 g
s
.63672 .57154 m .64339 .55328 L .65253 .5445 L p 0 1 0 r
F P
0 g
s
.67016 .66544 m .67761 .65859 L .68759 .66312 L p 0 0 1 r
F P
0 g
s
.67761 .65859 m .67016 .66544 L .66015 .66092 L p 0 0 1 r
F P
0 g
s
.55629 .62269 m .56344 .61772 L .5738 .62583 L p 1 0 0 r
F P
0 g
s
.56344 .61772 m .55629 .62269 L .546 .61643 L p 1 0 0 r
F P
0 g
s
.54965 .70024 m .5567 .69306 L .56688 .69586 L p 0 1 0 r
F P
0 g
s
.5567 .69306 m .54965 .70024 L .53939 .69603 L p 0 1 0 r
F P
0 g
s
.31488 .6315 m .32142 .62155 L .33225 .62423 L p 0 1 0 r
F P
0 g
s
.33225 .62423 m .33873 .61583 L .34943 .62002 L p 0 1 0 r
F P
0 g
s
.33873 .61583 m .33225 .62423 L .32142 .62155 L p 0 1 0 r
F P
0 g
s
.5287 .61815 m .5357 .61104 L .546 .61643 L p 1 0 0 r
F P
0 g
s
.5357 .61104 m .5287 .61815 L .51841 .61417 L p 1 0 0 r
F P
0 g
s
.35319 .70658 m .35963 .70016 L .3703 .70404 L p 1 0 0 r
F P
0 g
s
.35963 .70016 m .35319 .70658 L .34258 .70123 L p 1 0 0 r
F P
0 g
s
.37705 .62429 m .38352 .61873 L .39404 .62554 L p 0 1 0 r
F P
0 g
s
.38352 .61873 m .37705 .62429 L .36649 .61834 L p 0 1 0 r
F P
0 g
s
.4841 .68181 m .49097 .67751 L .50137 .68436 L p 0 1 0 r
F P
0 g
s
.49097 .67751 m .4841 .68181 L .47371 .67444 L p 0 1 0 r
F P
0 g
s
.57395 .68737 m .56688 .69586 L .5567 .69306 L p 0 1 0 r
F P
0 g
s
.47704 .63624 m .48389 .62658 L .49427 .62855 L p 1 0 0 r
F P
0 g
s
.50115 .61951 m .49427 .62855 L .48389 .62658 L p 1 0 0 r
F P
0 g
s
.38754 .69907 m .39418 .69041 L .40483 .69223 L p 1 0 0 r
F P
0 g
s
.41153 .68285 m .40483 .69223 L .39418 .69041 L p 1 0 0 r
F P
0 g
s
.34943 .62002 m .35588 .61291 L .36649 .61834 L p 0 1 0 r
F P
0 g
s
.35588 .61291 m .34943 .62002 L .33873 .61583 L p 0 1 0 r
F P
0 g
s
.52207 .69672 m .52908 .69113 L .53939 .69603 L p 0 1 0 r
F P
0 g
s
.52908 .69113 m .52207 .69672 L .51174 .69078 L p 0 1 0 r
F P
0 g
s
.32886 .66419 m .33524 .65734 L .34594 .66187 L p 0 0 1 r
F P
0 g
s
.33524 .65734 m .32886 .66419 L .31814 .65967 L p 0 0 1 r
F P
0 g
s
.25023 .59809 m .24513 .5944 L .23546 .5777 L p 1 0 0 r
F P
0 g
s
.23546 .5777 m .24032 .58268 L .25023 .59809 L p 1 0 0 r
F P
0 g
s
.37368 .66406 m .3802 .6572 L .39081 .66173 L p 0 0 1 r
F P
0 g
s
.3802 .6572 m .37368 .66406 L .36305 .65954 L p 0 0 1 r
F P
0 g
s
.66013 .47949 m .66285 .47566 L .66329 .47996 L p 0 1 0 r
F P
0 g
s
.6538 .50181 m .66013 .47949 L p .66329 .47996 L 0 1 0 r
F P
0 g
s
.42517 .65707 m .41851 .66393 L .40797 .6594 L p 0 0 1 r
F P
0 g
s
.27521 .63675 m .2697 .63553 L .25971 .62145 L p 1 0 0 r
F P
0 g
s
.25971 .62145 m .26503 .6239 L .27521 .63675 L p 1 0 0 r
F P
0 g
s
.50818 .66366 m .51513 .6568 L .52545 .66133 L p 0 0 1 r
F P
0 g
s
.51513 .6568 m .50818 .66366 L .49783 .65913 L p 0 0 1 r
F P
0 g
s
.55302 .66352 m .56011 .65666 L .57035 .66119 L p 0 0 1 r
F P
0 g
s
.56011 .65666 m .55302 .66352 L .54276 .659 L p 0 0 1 r
F P
0 g
s
.41153 .68285 m .41826 .67317 L .42887 .67423 L p 1 0 0 r
F P
0 g
s
.43563 .66422 m .42887 .67423 L .41826 .67317 L p 1 0 0 r
F P
0 g
s
.64273 .66325 m .6501 .65639 L .66015 .66092 L p 0 0 1 r
F P
0 g
s
.6501 .65639 m .64273 .66325 L .63265 .65873 L p 0 0 1 r
F P
0 g
s
.29719 .64237 m .30385 .63062 L .31488 .6315 L p 0 1 0 r
F P
0 g
s
.32142 .62155 m .31488 .6315 L .30385 .63062 L p 0 1 0 r
F P
0 g
s
.6951 .65625 m .68759 .66312 L .67761 .65859 L p 0 0 1 r
F P
0 g
s
.3703 .70404 m .37686 .69637 L .38754 .69907 L p 1 0 0 r
F P
0 g
s
.39418 .69041 m .38754 .69907 L .37686 .69637 L p 1 0 0 r
F P
0 g
s
.37686 .69637 m .3703 .70404 L .35963 .70016 L p 1 0 0 r
F P
0 g
s
.57395 .68737 m .58102 .67816 L .59104 .67851 L p 0 1 0 r
F P
0 g
s
.59807 .66766 m .59104 .67851 L .58102 .67816 L p 0 1 0 r
F P
0 g
s
.47371 .67444 m .48055 .67032 L .49097 .67751 L p 0 1 0 r
F P
0 g
s
.48055 .67032 m .47371 .67444 L .46331 .66685 L p 0 1 0 r
F P
0 g
s
.48389 .62658 m .47704 .63624 L .46659 .63487 L p 1 0 0 r
F P
0 g
s
.63735 .70224 m .62941 .69907 L .6187 .68383 L p 1 0 0 r
F P
0 g
s
.6187 .68383 m .62648 .68556 L .63735 .70224 L p 1 0 0 r
F P
0 g
s
.546 .61643 m .5531 .61063 L .56344 .61772 L p 1 0 0 r
F P
0 g
s
.5531 .61063 m .546 .61643 L .5357 .61104 L p 1 0 0 r
F P
0 g
s
.30107 .662 m .30737 .65513 L .31814 .65967 L p 0 0 1 r
F P
0 g
s
.30737 .65513 m .30107 .662 L .29028 .65747 L p 0 0 1 r
F P
0 g
s
.34594 .66187 m .35238 .655 L .36305 .65954 L p 0 0 1 r
F P
0 g
s
.35238 .655 m .34594 .66187 L .33524 .65734 L p 0 0 1 r
F P
0 g
s
.39081 .66173 m .39739 .65486 L .40797 .6594 L p 0 0 1 r
F P
0 g
s
.39739 .65486 m .39081 .66173 L .3802 .6572 L p 0 0 1 r
F P
0 g
s
.36649 .61834 m .37296 .6123 L .38352 .61873 L p 0 1 0 r
F P
0 g
s
.37296 .6123 m .36649 .61834 L .35588 .61291 L p 0 1 0 r
F P
0 g
s
.41107 .62813 m .40452 .63267 L .39404 .62554 L p 0 1 0 r
F P
0 g
s
.48057 .66146 m .48743 .65459 L .49783 .65913 L p 0 0 1 r
F P
0 g
s
.48743 .65459 m .48057 .66146 L .47015 .65693 L p 0 0 1 r
F P
0 g
s
.34258 .70123 m .34896 .69554 L .35963 .70016 L p 1 0 0 r
F P
0 g
s
.34896 .69554 m .34258 .70123 L .33198 .695 L p 1 0 0 r
F P
0 g
s
.52545 .66133 m .53246 .65445 L .54276 .659 L p 0 0 1 r
F P
0 g
s
.53246 .65445 m .52545 .66133 L .51513 .6568 L p 0 0 1 r
F P
0 g
s
.57035 .66119 m .57749 .65432 L .5877 .65886 L p 0 0 1 r
F P
0 g
s
.57749 .65432 m .57035 .66119 L .56011 .65666 L p 0 0 1 r
F P
0 g
s
.51174 .69078 m .51873 .6856 L .52908 .69113 L p 0 1 0 r
F P
0 g
s
.51873 .6856 m .51174 .69078 L .50137 .68436 L p 0 1 0 r
F P
0 g
s
.46331 .66685 m .47011 .66285 L .48055 .67032 L p 0 1 0 r
F P
0 g
s
.64601 .5639 m .63938 .58206 L .62995 .58858 L p 0 1 0 r
F P
0 g
s
.62995 .58858 m .63672 .57154 L .64601 .5639 L p 0 1 0 r
F P
0 g
s
.66015 .66092 m .66758 .65405 L .67761 .65859 L p 0 0 1 r
F P
0 g
s
.66758 .65405 m .66015 .66092 L .6501 .65639 L p 0 0 1 r
F P
0 g
s
.53939 .69603 m .54645 .68945 L .5567 .69306 L p 0 1 0 r
F P
0 g
s
.54645 .68945 m .53939 .69603 L .52908 .69113 L p 0 1 0 r
F P
0 g
s
.23544 .57092 m .2306 .56598 L .2211 .54797 L p 1 0 0 r
F P
0 g
s
.2211 .54797 m .22568 .55423 L .23544 .57092 L p 1 0 0 r
F P
0 g
s
.50115 .61951 m .50807 .6108 L .51841 .61417 L p 1 0 0 r
F P
0 g
s
.51841 .61417 m .52538 .60641 L .5357 .61104 L p 1 0 0 r
F P
0 g
s
.52538 .60641 m .51841 .61417 L .50807 .6108 L p 1 0 0 r
F P
0 g
s
.39418 .69041 m .40086 .68133 L .41153 .68285 L p 1 0 0 r
F P
0 g
s
.41826 .67317 m .41153 .68285 L .40086 .68133 L p 1 0 0 r
F P
0 g
s
.66239 .47374 m .66285 .47566 L .66013 .47949 L p 0 1 0 r
F P
0 g
s
.66259 .75641 m .65422 .74962 L .64317 .73011 L p 1 0 0 r
F P
0 g
s
.64317 .73011 m .65132 .73518 L .66259 .75641 L p 1 0 0 r
F P
0 g
s
.2697 .63553 m .27521 .63675 L .28169 .64407 L p 1 0 0 r
F P
0 g
s
.28518 .65069 m .2859 .64361 L .2858 .65187 L 0 1 0 r
F
.29719 .64237 m .29047 .65505 L .28652 .65589 L p F P
0 g
s
.28652 .65589 m .27983 .64834 L p .28555 .65208 L 1 0 0 r
F P
0 g
s
.28555 .65208 m .28639 .65537 L .28652 .65589 L 1 0 0 r
F
.28639 .65537 m .29719 .64237 L .28652 .65589 L 0 1 0 r
F
.28553 .65209 m .28555 .65208 L .28639 .65537 L F
.28555 .65208 m .29719 .64237 L .28639 .65537 L F
.28652 .65589 m .28652 .65589 L p .28639 .65537 L 0 0 1 r
F P
0 g
s
.28652 .65589 m .28652 .65589 L p .28639 .65537 L 0 1 0 r
F P
0 g
s
.28555 .65208 m .28556 .65208 L .28639 .65537 L 1 0 0 r
F
.28788 .65646 m .28652 .65589 L p .28553 .65209 L 0 0 1 r
F P
0 g
s
.29657 .65057 m .29028 .65747 L .28793 .65648 L p 0 0 1 r
F P
0 g
s
.28791 .65644 m .29657 .65057 L .28793 .65648 L 0 0 1 r
F
.28553 .65209 m .29657 .65057 L .28788 .65646 L F
.29028 .65747 m .29657 .65057 L .30737 .65513 L p F P
0 g
s
.28556 .65208 m .29593 .65887 L .28652 .65589 L 1 0 0 r
F
.28639 .65537 m .28652 .65589 L .28652 .65589 L F
.28556 .65208 m .28652 .65589 L .28639 .65537 L F
.27945 .65292 m .28553 .65209 L .28639 .65537 L 0 0 1 r
F
.28652 .65589 m .27945 .65292 L p .28639 .65537 L F P
0 g
s
.27907 .65747 m .28553 .65209 L .28639 .65537 L 0 1 0 r
F
.28652 .65589 m .27907 .65747 L p .28639 .65537 L F P
0 g
s
.28793 .65648 m .28788 .65646 L p .28791 .65644 L 0 0 1 r
F P
0 g
s
.29593 .65887 m .29009 .65993 L .28652 .65589 L p 1 0 0 r
F P
0 g
s
.2859 .64361 m .29719 .64237 L p .2858 .65187 L 0 1 0 r
F P
0 g
s
.28555 .65208 m .28555 .65206 L .28556 .65208 L 1 0 0 r
F
.28506 .65176 m .28356 .64838 L .28555 .65208 L F
.27983 .64834 m .28356 .64838 L p .28506 .65176 L F P
0 g
s
.28356 .64838 m .2859 .64361 L p .28512 .65128 L 0 1 0 r
F P
0 g
s
.28553 .65209 m .28518 .65069 L .2858 .65187 L 0 1 0 r
F
.28458 .65222 m .28484 .65079 L .28553 .65209 L 0 0 1 r
F
.28499 .65254 m .28511 .6513 L .28553 .65209 L 0 1 0 r
F
.28511 .6513 m .28518 .65069 L .28553 .65209 L F
.28553 .65209 m .28485 .65076 L .28556 .65208 L 0 0 1 r
F
.28356 .64838 m .28555 .65206 L .28555 .65208 L 1 0 0 r
F
.28356 .64838 m .28512 .65128 L .28511 .6513 L 0 1 0 r
F
.28484 .65079 m .28485 .65076 L .28553 .65209 L 0 0 1 r
F
.28356 .64838 m .28356 .64838 L p .28555 .65208 L 1 0 0 r
F P
0 g
s
.28485 .65076 m .28497 .65008 L .28556 .65208 L 0 0 1 r
F
.28497 .65008 m .28571 .64599 L .28558 .65125 L F
.28497 .65008 m .28558 .65125 L .28556 .65208 L F
.28169 .64407 m .28201 .64443 L p .28281 .64619 L 1 0 0 r
F P
0 g
s
.28356 .64838 m .28511 .6513 L .28357 .64842 L 0 1 0 r
F
.28355 .64838 m .28356 .64838 L p .28357 .64842 L F P
0 g
s
.28281 .64619 m .28302 .64636 L .28356 .64838 L 1 0 0 r
F
.28356 .64838 m .27983 .64834 L p .28281 .64619 L F P
0 g
s
.27983 .64834 m .2697 .63553 L p .28281 .64619 L 1 0 0 r
F P
0 g
s
.27945 .65292 m .26857 .64835 L p .28301 .64637 L 0 0 1 r
F P
0 g
s
.28354 .64834 m .28302 .64636 L .28356 .64838 L 0 1 0 r
F
.28301 .64637 m .28302 .64636 L .28354 .64834 L F
.2859 .64361 m .28356 .64838 L p .28302 .64636 L F P
0 g
s
.28302 .64636 m .28302 .64636 L .28356 .64838 L 1 0 0 r
F
.28356 .64838 m .28356 .64838 L p .28302 .64636 L F P
0 g
s
.28571 .64599 m .28355 .64838 L p .28301 .64637 L 0 0 1 r
F P
0 g
s
.28355 .64838 m .27945 .65292 L p .28301 .64637 L 0 0 1 r
F P
0 g
s
.28277 .6466 m .28301 .64637 L .28354 .64834 L 0 1 0 r
F
.28357 .64842 m .28571 .64599 L .28484 .65079 L 0 0 1 r
F
.28356 .64838 m .28571 .64599 L p .28357 .64842 L F P
0 g
s
.28552 .6484 m .28356 .64838 L p .28302 .64636 L 1 0 0 r
F P
0 g
s
.28355 .64838 m .28356 .64838 L p .28357 .64842 L 0 0 1 r
F P
0 g
s
.28355 .64838 m .28484 .65079 L .28458 .65222 L 0 0 1 r
F
.27945 .65292 m .28355 .64838 L p .28458 .65222 L F P
0 g
s
.27907 .65747 m .28355 .64838 L p .28499 .65254 L 0 1 0 r
F P
0 g
s
.28355 .64838 m .28357 .64842 L .28499 .65254 L 0 1 0 r
F
.28281 .64619 m .28201 .64443 L .28222 .64483 L 1 0 0 r
F
.2697 .63553 m .28169 .64407 L .28281 .64619 L F
.28201 .64443 m .28201 .64443 L p .28201 .64443 L 0 0 1 r
F P
0 g
s
.28302 .64636 m .28222 .64483 L .28288 .64461 L 0 1 0 r
F
.28354 .64586 m .28288 .64461 L .2859 .64361 L F
.28302 .64636 m .28288 .64461 L .28354 .64586 L F
.28201 .64443 m .2859 .64361 L p .28222 .64483 L F P
0 g
s
.30385 .63062 m .29719 .64237 L .2859 .64361 L p 0 1 0 r
F P
0 g
s
.2859 .64361 m .29266 .63076 L .30385 .63062 L p 0 1 0 r
F P
0 g
s
.30289 .64363 m .29657 .65057 L .28571 .64599 L p 0 0 1 r
F P
0 g
s
.29266 .63076 m .2859 .64361 L .2827 .64429 L p 0 1 0 r
F P
0 g
s
.28201 .64443 m .27521 .63675 L p .28099 .64053 L 1 0 0 r
F P
0 g
s
.2827 .64429 m .28201 .64443 L p .28099 .64053 L 0 1 0 r
F P
0 g
s
.28201 .64443 m .27481 .6414 L p .28098 .64055 L 0 0 1 r
F P
0 g
s
.28201 .64443 m .28201 .64443 L p .28188 .64395 L 0 1 0 r
F P
0 g
s
.28188 .64395 m .28099 .64053 L .28201 .64443 L 0 1 0 r
F
.28099 .64053 m .29266 .63076 L .2827 .64429 L F
.29201 .63902 m .28571 .64599 L .28345 .64504 L p 0 0 1 r
F P
0 g
s
.28287 .64397 m .29201 .63902 L .28345 .64504 L 0 0 1 r
F
.28099 .64053 m .281 .64054 L .28188 .64395 L 1 0 0 r
F
.28099 .64053 m .28188 .64395 L .28201 .64443 L F
.26857 .64835 m .27481 .6414 L .28201 .64443 L p 0 0 1 r
F P
0 g
s
.28201 .64443 m .27442 .64604 L p .28098 .64055 L 0 1 0 r
F P
0 g
s
.28098 .64055 m .28099 .64053 L .28188 .64395 L 0 1 0 r
F
.28098 .64055 m .28188 .64395 L .28201 .64443 L F
.28099 .64053 m .28099 .64052 L .281 .64054 L 1 0 0 r
F
.28129 .632 m .29266 .63076 L p .28098 .64055 L 0 1 0 r
F P
0 g
s
.28053 .64023 m .28059 .63966 L .28099 .64053 L 1 0 0 r
F
.27521 .63675 m .27868 .63678 L p .28053 .64023 L F P
0 g
s
.2804 .63999 m .27895 .63678 L .28053 .64023 L 1 0 0 r
F
.27868 .63678 m .27895 .63678 L p .2804 .63999 L F P
0 g
s
.27895 .63678 m .28058 .63978 L .28053 .64023 L 1 0 0 r
F
.28002 .64068 m .27895 .63679 L .28098 .64055 L 0 0 1 r
F
.27481 .6414 m .27895 .63679 L p .28002 .64068 L F P
0 g
s
.28809 .61898 m .28129 .632 L .27807 .63268 L p 0 1 0 r
F P
0 g
s
.27795 .63242 m .28809 .61898 L .27807 .63268 L 0 1 0 r
F
.27521 .63675 m .26503 .6239 L p .2782 .6346 L 1 0 0 r
F P
0 g
s
.2777 .63276 m .27738 .63282 L p .27658 .62867 L 0 1 0 r
F P
0 g
s
.28129 .632 m .27914 .63639 L p .2784 .63476 L 0 1 0 r
F P
0 g
s
.27914 .63639 m .27895 .63678 L p .2784 .63476 L 0 1 0 r
F P
0 g
s
.26503 .6239 m .27054 .62511 L .27737 .63282 L p 1 0 0 r
F P
0 g
s
.27895 .63678 m .28129 .632 L p .28098 .64051 L 0 1 0 r
F P
0 g
s
.27738 .63282 m .28129 .632 L p .2784 .63476 L 0 1 0 r
F P
0 g
s
.2782 .6346 m .27765 .63313 L .2784 .63476 L 1 0 0 r
F
.27839 .63477 m .27757 .63318 L .2784 .63476 L 0 1 0 r
F
.27757 .63318 m .27738 .63282 L .2784 .63476 L F
.2784 .63477 m .27757 .63318 L .28109 .6344 L 0 0 1 r
F
.27757 .63318 m .27738 .63282 L .27792 .63386 L 1 0 0 r
F
.27737 .63282 m .27738 .63282 L p .27757 .63318 L 0 0 1 r
F P
0 g
s
.27738 .63283 m .27738 .63282 L .27757 .63318 L 1 0 0 r
F
.27738 .63282 m .28109 .6344 L p .27757 .63318 L 0 0 1 r
F P
0 g
s
.26503 .6239 m .27737 .63282 L .27738 .63282 L 1 0 0 r
F
.26503 .6239 m .27738 .63282 L .2782 .6346 L F
.26387 .63678 m .27013 .62975 L .27737 .63282 L p 0 0 1 r
F P
0 g
s
.2782 .6346 m .27738 .63283 L .27757 .63318 L 1 0 0 r
F
.27793 .63387 m .27757 .63318 L .27792 .63386 L F
.2782 .6346 m .27757 .63318 L .27793 .63387 L F
.26387 .63678 m .27737 .63282 L .27757 .63318 L 0 0 1 r
F
.27839 .63477 m .27757 .63318 L .2784 .63477 L F
.2782 .6346 m .2784 .63476 L .27827 .63485 L 1 0 0 r
F
.2782 .6346 m .27827 .63485 L .27521 .63675 L F
.26387 .63678 m .27757 .63318 L .27839 .63477 L 0 0 1 r
F
.27895 .63678 m .27521 .63675 L p .2784 .63476 L 1 0 0 r
F P
0 g
s
.27481 .6414 m .26857 .64835 L .25765 .64377 L p 0 0 1 r
F P
0 g
s
.25765 .64377 m .26387 .63678 L .27481 .6414 L p 0 0 1 r
F P
0 g
s
.27893 .63674 m .2784 .63476 L .27895 .63678 L 0 1 0 r
F
.27481 .6414 m .26387 .63678 L p .27839 .63477 L 0 0 1 r
F P
0 g
s
.27839 .63477 m .2784 .63478 L .27481 .6414 L 0 0 1 r
F
.27839 .63477 m .2784 .63476 L .27893 .63674 L 0 1 0 r
F
.27895 .63678 m .27895 .63679 L p .27893 .63674 L F P
0 g
s
.2784 .63476 m .2784 .63477 L .27895 .63678 L 1 0 0 r
F
.27928 .63642 m .27896 .63678 L p .2784 .63477 L 0 0 1 r
F P
0 g
s
.28109 .6344 m .27928 .63642 L p .2784 .63477 L 0 0 1 r
F P
0 g
s
.27895 .63679 m .27895 .63678 L p .28098 .64055 L 0 1 0 r
F P
0 g
s
.27895 .63679 m .27896 .63678 L p .28098 .64055 L 0 0 1 r
F P
0 g
s
.27896 .63678 m .27974 .63591 L p .28095 .64045 L 0 0 1 r
F P
0 g
s
.27895 .63678 m .27896 .63678 L p .28058 .63978 L 1 0 0 r
F P
0 g
s
.27896 .63678 m .28058 .63977 L .28058 .63978 L 1 0 0 r
F
.27895 .63678 m .28098 .64051 L .28098 .64055 L 0 1 0 r
F
.27896 .63678 m .28095 .64045 L .28098 .64055 L 0 0 1 r
F
.27974 .63591 m .28109 .6344 L p .28098 .6405 L F P
0 g
s
.28095 .64045 m .28099 .64052 L .28099 .64053 L 1 0 0 r
F
.28095 .64045 m .28098 .6405 L .28098 .64055 L 0 0 1 r
F
.27974 .63591 m .28098 .6405 L .28095 .64045 L F
.28059 .63966 m .2809 .63679 L .28099 .64052 L 1 0 0 r
F
.28059 .63966 m .28099 .64052 L .28095 .64045 L F
.27896 .63678 m .2809 .63679 L p .28058 .63977 L F P
0 g
s
.2809 .63679 m .27896 .63678 L p .2784 .63477 L 1 0 0 r
F P
0 g
s
.27896 .63678 m .27895 .63678 L p .2784 .63477 L 1 0 0 r
F P
0 g
s
.27896 .63678 m .27895 .63679 L p .2784 .63477 L 0 0 1 r
F P
0 g
s
.27895 .63679 m .27481 .6414 L p .2784 .63478 L 0 0 1 r
F P
0 g
s
.2784 .63477 m .27895 .63679 L .2784 .63478 L 0 0 1 r
F
.27815 .635 m .27893 .63674 L .27442 .64604 L 0 1 0 r
F
.27895 .63679 m .27442 .64604 L p .27893 .63674 L F P
0 g
s
.27815 .635 m .27839 .63477 L .27893 .63674 L 0 1 0 r
F
.27839 .63477 m .2784 .63477 L .2784 .63478 L 0 0 1 r
F
.27765 .63313 m .2809 .63679 L p .2784 .63477 L 1 0 0 r
F P
0 g
s
.2784 .63476 m .27838 .63472 L .2784 .63477 L 1 0 0 r
F
.27838 .63472 m .27765 .63313 L .2784 .63477 L F
.2627 .64976 m .27738 .63282 L .27839 .63477 L 0 1 0 r
F
.27738 .63282 m .27738 .63282 L .27757 .63318 L F
.27738 .63282 m .27757 .63318 L .27839 .63477 L F
.27738 .63282 m .27738 .63282 L p .27738 .63282 L F P
0 g
s
.29935 .61885 m .29266 .63076 L .28129 .632 L p 0 1 0 r
F P
0 g
s
.28129 .632 m .28809 .61898 L .29935 .61885 L p 0 1 0 r
F P
0 g
s
.28741 .62735 m .2814 .63405 L p .27899 .63332 L 0 0 1 r
F P
0 g
s
.2814 .63405 m .28109 .6344 L p .27899 .63332 L 0 0 1 r
F P
0 g
s
.28109 .6344 m .27882 .63343 L p .27899 .63332 L 0 0 1 r
F P
0 g
s
.27807 .63268 m .2777 .63276 L p .27795 .63242 L 0 1 0 r
F P
0 g
s
.27882 .63343 m .27738 .63282 L p .27823 .63236 L 0 0 1 r
F P
0 g
s
.27823 .63236 m .28741 .62735 L .27882 .63343 L 0 0 1 r
F
.28109 .6344 m .29201 .63902 L p .28098 .64055 L F P
0 g
s
.29835 .63201 m .29201 .63902 L .28109 .6344 L p 0 0 1 r
F P
0 g
s
.31046 .61974 m .30385 .63062 L .29266 .63076 L p 0 1 0 r
F P
0 g
s
.29266 .63076 m .29935 .61885 L .31046 .61974 L p 0 1 0 r
F P
0 g
s
.28109 .6344 m .28741 .62735 L .29835 .63201 L p 0 0 1 r
F P
0 g
s
.28674 .63569 m .2809 .63679 L .27738 .63282 L p 1 0 0 r
F P
0 g
s
.27737 .6328 m .27658 .62867 L .27738 .63282 L 0 1 0 r
F
.27054 .62511 m .27586 .62858 L .27737 .63281 L 1 0 0 r
F
.27586 .62858 m .27632 .62888 L .27737 .63281 L F
.27632 .62888 m .27726 .63238 L .27737 .63281 L F
.27737 .63282 m .2763 .62889 L .27726 .63238 L 0 0 1 r
F
.27738 .63282 m .27737 .63282 L p .27726 .63238 L F P
0 g
s
.27738 .63282 m .27737 .63282 L p .27737 .63281 L 1 0 0 r
F P
0 g
s
.27537 .62902 m .2763 .62889 L .27737 .63282 L 0 0 1 r
F
.27577 .62935 m .27632 .62888 L .27738 .63282 L 0 1 0 r
F
.27632 .62888 m .27658 .62867 L .27738 .63282 L F
.27632 .62888 m .27633 .62889 L .27726 .63238 L 1 0 0 r
F
.27658 .62867 m .28809 .61898 L .2777 .63276 L 0 1 0 r
F
.2763 .62889 m .28741 .62735 L .27738 .63282 L 0 0 1 r
F
.27738 .63282 m .27738 .63282 L p .27737 .6328 L 0 1 0 r
F P
0 g
s
.27737 .63281 m .28674 .63569 L .27738 .63282 L 1 0 0 r
F
.27633 .62889 m .28674 .63569 L .27737 .63281 L F
.27054 .62511 m .27425 .62511 L p .27583 .62856 L F P
0 g
s
.27583 .62856 m .27425 .62511 L .27632 .62888 L 1 0 0 r
F
.27535 .62903 m .27425 .62512 L .2763 .62889 L 0 0 1 r
F
.27737 .63282 m .27054 .62511 L p .27737 .63281 L 1 0 0 r
F P
0 g
s
.27013 .62975 m .27425 .62512 L p .27535 .62903 L 0 0 1 r
F P
0 g
s
.27737 .63282 m .27013 .62975 L p .27537 .62902 L 0 0 1 r
F P
0 g
s
.28347 .60704 m .27664 .62022 L .2733 .62091 L p 0 1 0 r
F P
0 g
s
.27318 .62066 m .28347 .60704 L .2733 .62091 L 0 1 0 r
F
.27054 .62511 m .26031 .61222 L p .27347 .62289 L 1 0 0 r
F P
0 g
s
.27054 .62511 m .26503 .6239 L .255 .60979 L p 1 0 0 r
F P
0 g
s
.255 .60979 m .26031 .61222 L .27054 .62511 L p 1 0 0 r
F P
0 g
s
.27294 .62099 m .27261 .62105 L p .27179 .61689 L 0 1 0 r
F P
0 g
s
.27664 .62022 m .27445 .62472 L p .27368 .62305 L 0 1 0 r
F P
0 g
s
.27445 .62472 m .27425 .62511 L p .27368 .62305 L 0 1 0 r
F P
0 g
s
.26031 .61222 m .26581 .61339 L .27261 .62105 L p 1 0 0 r
F P
0 g
s
.27425 .62512 m .27664 .62022 L p .2763 .62889 L 0 1 0 r
F P
0 g
s
.27261 .62105 m .27664 .62022 L p .27368 .62305 L 0 1 0 r
F P
0 g
s
.27347 .62289 m .2729 .62137 L .27368 .62305 L 1 0 0 r
F
.27367 .62306 m .27279 .62139 L .27368 .62305 L 0 1 0 r
F
.27279 .62139 m .27261 .62105 L .27368 .62305 L F
.27368 .62306 m .27279 .62139 L .27643 .62268 L 0 0 1 r
F
.27279 .62139 m .27261 .62105 L .27318 .62212 L 1 0 0 r
F
.27261 .62105 m .27261 .62105 L p .27279 .62139 L 0 0 1 r
F P
0 g
s
.27262 .62106 m .27261 .62105 L .27279 .62139 L 1 0 0 r
F
.27261 .62105 m .27643 .62268 L p .27279 .62139 L 0 0 1 r
F P
0 g
s
.26031 .61222 m .27261 .62105 L .27261 .62105 L 1 0 0 r
F
.26031 .61222 m .27261 .62105 L .27347 .62289 L F
.25912 .62509 m .26539 .61798 L .27261 .62105 L p 0 0 1 r
F P
0 g
s
.27347 .62289 m .27262 .62106 L .27279 .62139 L 1 0 0 r
F
.27318 .62213 m .27279 .62139 L .27318 .62212 L F
.27347 .62289 m .27279 .62139 L .27318 .62213 L F
.25912 .62509 m .27261 .62105 L .27279 .62139 L 0 0 1 r
F
.27367 .62306 m .27279 .62139 L .27368 .62306 L F
.27347 .62289 m .27368 .62305 L .27354 .62314 L 1 0 0 r
F
.27347 .62289 m .27354 .62314 L .27054 .62511 L F
.25912 .62509 m .27279 .62139 L .27367 .62306 L 0 0 1 r
F
.27425 .62511 m .27054 .62511 L p .27368 .62305 L 1 0 0 r
F P
0 g
s
.26387 .63678 m .25765 .64377 L .24668 .63916 L p 0 0 1 r
F P
0 g
s
.24668 .63916 m .25288 .63214 L .26387 .63678 L p 0 0 1 r
F P
0 g
s
.27013 .62975 m .26387 .63678 L .25288 .63214 L p 0 0 1 r
F P
0 g
s
.25288 .63214 m .25912 .62509 L .27013 .62975 L p 0 0 1 r
F P
0 g
s
.27424 .62507 m .27368 .62305 L .27425 .62511 L 0 1 0 r
F
.27013 .62975 m .25912 .62509 L p .27367 .62306 L 0 0 1 r
F P
0 g
s
.27367 .62306 m .27367 .62307 L .27013 .62975 L 0 0 1 r
F
.27367 .62306 m .27368 .62305 L .27424 .62507 L 0 1 0 r
F
.27425 .62511 m .27425 .62512 L p .27424 .62507 L F P
0 g
s
.27458 .62475 m .27013 .62975 L p .27368 .62306 L 0 0 1 r
F P
0 g
s
.27342 .62329 m .27367 .62306 L .27424 .62507 L 0 1 0 r
F
.27367 .62306 m .27368 .62306 L .27367 .62307 L 0 0 1 r
F
.27643 .62268 m .27458 .62475 L p .27368 .62306 L F P
0 g
s
.27664 .62022 m .28809 .61898 L p .27632 .62888 L 0 1 0 r
F P
0 g
s
.27508 .62419 m .27643 .62268 L p .27633 .62889 L 0 0 1 r
F P
0 g
s
.2729 .62137 m .27622 .62511 L p .27368 .62306 L 1 0 0 r
F P
0 g
s
.27368 .62305 m .27365 .62301 L .27368 .62306 L 1 0 0 r
F
.27365 .62301 m .2729 .62137 L .27368 .62306 L F
.25791 .63815 m .27261 .62105 L .27367 .62306 L 0 1 0 r
F
.27261 .62105 m .27261 .62105 L .27279 .62139 L F
.27261 .62105 m .27279 .62139 L .27367 .62306 L F
.27261 .62105 m .27261 .62105 L p .27261 .62105 L F P
0 g
s
.27631 .62886 m .27664 .62022 L .27632 .62888 L 0 1 0 r
F
.29482 .60693 m .28809 .61898 L .27664 .62022 L p F P
0 g
s
.27664 .62022 m .28347 .60704 L .29482 .60693 L p 0 1 0 r
F P
0 g
s
.28277 .61556 m .27674 .62233 L p .27422 .62155 L 0 0 1 r
F P
0 g
s
.27674 .62233 m .27643 .62268 L p .27422 .62155 L 0 0 1 r
F P
0 g
s
.27643 .62268 m .27405 .62167 L p .27422 .62155 L 0 0 1 r
F P
0 g
s
.2733 .62091 m .27294 .62099 L p .27318 .62066 L 0 1 0 r
F P
0 g
s
.27405 .62167 m .27261 .62105 L p .27346 .62059 L 0 0 1 r
F P
0 g
s
.27346 .62059 m .28277 .61556 L .27405 .62167 L 0 0 1 r
F
.27643 .62268 m .28741 .62735 L p .27633 .62889 L F P
0 g
s
.29377 .62026 m .28741 .62735 L .27643 .62268 L p 0 0 1 r
F P
0 g
s
.306 .60783 m .29935 .61885 L .28809 .61898 L p 0 1 0 r
F P
0 g
s
.28809 .61898 m .29482 .60693 L .306 .60783 L p 0 1 0 r
F P
0 g
s
.27643 .62268 m .28277 .61556 L .29377 .62026 L p 0 0 1 r
F P
0 g
s
.28207 .62398 m .27622 .62511 L .27261 .62105 L p 1 0 0 r
F P
0 g
s
.27261 .62103 m .27179 .61689 L .27261 .62105 L 0 1 0 r
F
.26581 .61339 m .27107 .61682 L .27261 .62104 L 1 0 0 r
F
.27107 .61682 m .27153 .61711 L .27261 .62104 L F
.27153 .61711 m .2725 .62065 L .27261 .62104 L F
.27261 .62105 m .27151 .61713 L .2725 .62065 L 0 0 1 r
F
.27261 .62105 m .27261 .62105 L p .2725 .62065 L F P
0 g
s
.27261 .62105 m .27261 .62104 L .27261 .62105 L 1 0 0 r
F
.27261 .62105 m .27261 .62105 L p .27261 .62105 L F P
0 g
s
.27058 .61726 m .27151 .61713 L .27261 .62105 L 0 0 1 r
F
.27098 .61758 m .27153 .61711 L .27261 .62105 L 0 1 0 r
F
.27153 .61711 m .27179 .61689 L .27261 .62105 L F
.27153 .61711 m .27154 .61712 L .2725 .62065 L 1 0 0 r
F
.27179 .61689 m .28347 .60704 L .27294 .62099 L 0 1 0 r
F
.27151 .61713 m .28277 .61556 L .27261 .62105 L 0 0 1 r
F
.27261 .62105 m .27261 .62105 L p .27261 .62103 L 0 1 0 r
F P
0 g
s
.27261 .62104 m .28207 .62398 L .27261 .62105 L 1 0 0 r
F
.27154 .61712 m .28207 .62398 L .27261 .62104 L F
.26581 .61339 m .26946 .61337 L p .27105 .6168 L F P
0 g
s
.27105 .6168 m .26946 .61337 L .27153 .61711 L 1 0 0 r
F
.27057 .61726 m .26946 .61338 L .27151 .61713 L 0 0 1 r
F
.27261 .62105 m .26581 .61339 L p .27261 .62104 L 1 0 0 r
F P
0 g
s
.26539 .61798 m .26946 .61338 L p .27057 .61726 L 0 0 1 r
F P
0 g
s
.27261 .62105 m .26539 .61798 L p .27058 .61726 L 0 0 1 r
F P
0 g
s
.27881 .59494 m .27194 .60826 L .26839 .60899 L p 0 1 0 r
F P
0 g
s
.26828 .60876 m .27881 .59494 L .26839 .60899 L 0 1 0 r
F
.26581 .61339 m .25553 .60047 L p .26863 .61106 L 1 0 0 r
F P
0 g
s
.26581 .61339 m .26031 .61222 L .25023 .59809 L p 1 0 0 r
F P
0 g
s
.25023 .59809 m .25553 .60047 L .26581 .61339 L p 1 0 0 r
F P
0 g
s
.26806 .60905 m .26772 .60912 L p .26689 .605 L 0 1 0 r
F P
0 g
s
.27194 .60826 m .26966 .61296 L p .26884 .61123 L 0 1 0 r
F P
0 g
s
.26966 .61296 m .26946 .61337 L p .26884 .61123 L 0 1 0 r
F P
0 g
s
.25553 .60047 m .26102 .60161 L .26771 .60912 L p 1 0 0 r
F P
0 g
s
.26946 .61338 m .27194 .60826 L p .27151 .61713 L 0 1 0 r
F P
0 g
s
.26772 .60912 m .27194 .60826 L p .26884 .61123 L 0 1 0 r
F P
0 g
s
.26863 .61106 m .26801 .60946 L .26884 .61123 L 1 0 0 r
F
.26884 .61123 m .26788 .60943 L .26884 .61123 L 0 1 0 r
F
.26788 .60943 m .26772 .60912 L .26884 .61123 L F
.26885 .61123 m .26788 .60943 L .27171 .61083 L 0 0 1 r
F
.26788 .60943 m .26771 .60912 L .26832 .61025 L 1 0 0 r
F
.26771 .60912 m .26772 .60912 L p .26788 .60943 L 0 0 1 r
F P
0 g
s
.26772 .60913 m .26771 .60912 L .26788 .60943 L 1 0 0 r
F
.26772 .60912 m .27171 .61083 L p .26788 .60943 L 0 0 1 r
F P
0 g
s
.25553 .60047 m .26771 .60912 L .26863 .61106 L 1 0 0 r
F
.26031 .61222 m .255 .60979 L .24513 .5944 L p F P
0 g
s
.24513 .5944 m .25023 .59809 L .26031 .61222 L p 1 0 0 r
F P
0 g
s
.25431 .61327 m .26061 .60609 L .26771 .60912 L p 0 0 1 r
F P
0 g
s
.26863 .61106 m .26772 .60913 L .26788 .60943 L 1 0 0 r
F
.26832 .61026 m .26788 .60943 L .26832 .61025 L F
.26863 .61106 m .26788 .60943 L .26832 .61026 L F
.25431 .61327 m .26771 .60912 L .26788 .60943 L 0 0 1 r
F
.26884 .61123 m .26788 .60943 L .26885 .61123 L F
.26863 .61106 m .26884 .61123 L .26871 .61132 L 1 0 0 r
F
.26863 .61106 m .26871 .61132 L .26581 .61339 L F
.25431 .61327 m .26788 .60943 L .26884 .61123 L 0 0 1 r
F
.26946 .61337 m .26581 .61339 L p .26884 .61123 L 1 0 0 r
F P
0 g
s
.25912 .62509 m .25288 .63214 L .24185 .62749 L p 0 0 1 r
F P
0 g
s
.24185 .62749 m .24806 .6204 L .25912 .62509 L p 0 0 1 r
F P
0 g
s
.26539 .61798 m .25912 .62509 L .24806 .6204 L p 0 0 1 r
F P
0 g
s
.24806 .6204 m .25431 .61327 L .26539 .61798 L p 0 0 1 r
F P
0 g
s
.26944 .61333 m .26884 .61123 L .26946 .61337 L 0 1 0 r
F
.26539 .61798 m .25431 .61327 L p .26884 .61123 L 0 0 1 r
F P
0 g
s
.26884 .61123 m .26884 .61125 L .26539 .61798 L 0 0 1 r
F
.26884 .61123 m .26884 .61123 L .26944 .61333 L 0 1 0 r
F
.26946 .61337 m .26946 .61338 L p .26944 .61333 L F P
0 g
s
.2698 .61299 m .26539 .61798 L p .26885 .61123 L 0 0 1 r
F P
0 g
s
.26858 .61148 m .26884 .61123 L .26944 .61333 L 0 1 0 r
F
.26884 .61123 m .26885 .61123 L .26884 .61125 L 0 0 1 r
F
.27171 .61083 m .2698 .61299 L p .26885 .61123 L F P
0 g
s
.27194 .60826 m .28347 .60704 L p .27153 .61711 L 0 1 0 r
F P
0 g
s
.27027 .61246 m .27171 .61083 L p .27154 .61712 L 0 0 1 r
F P
0 g
s
.26801 .60946 m .27149 .61336 L p .26885 .61123 L 1 0 0 r
F P
0 g
s
.26884 .61123 m .26882 .61118 L .26885 .61123 L 1 0 0 r
F
.26882 .61118 m .26801 .60946 L .26885 .61123 L F
.25308 .62635 m .26771 .60913 L .26884 .61123 L 0 1 0 r
F
.26771 .60913 m .26772 .60912 L .26788 .60943 L F
.26771 .60913 m .26788 .60943 L .26884 .61123 L F
.25308 .62635 m .26019 .61066 L .26772 .60912 L p F P
0 g
s
.27152 .61709 m .27194 .60826 L .27153 .61711 L 0 1 0 r
F
.29024 .59484 m .28347 .60704 L .27194 .60826 L p F P
0 g
s
.27194 .60826 m .27881 .59494 L .29024 .59484 L p 0 1 0 r
F P
0 g
s
.27807 .60364 m .27201 .61049 L p .26929 .60962 L 0 0 1 r
F P
0 g
s
.27201 .61049 m .27171 .61083 L p .26929 .60962 L 0 0 1 r
F P
0 g
s
.27171 .61083 m .26914 .60973 L p .26929 .60962 L 0 0 1 r
F P
0 g
s
.26839 .60899 m .26806 .60905 L p .26828 .60876 L 0 1 0 r
F P
0 g
s
.26914 .60973 m .26772 .60912 L p .26855 .60868 L 0 0 1 r
F P
0 g
s
.26855 .60868 m .27807 .60364 L .26914 .60973 L 0 0 1 r
F
.27171 .61083 m .28277 .61556 L p .27154 .61712 L F P
0 g
s
.28914 .60839 m .28277 .61556 L .27171 .61083 L p 0 0 1 r
F P
0 g
s
.30149 .59577 m .29482 .60693 L .28347 .60704 L p 0 1 0 r
F P
0 g
s
.28347 .60704 m .29024 .59484 L .30149 .59577 L p 0 1 0 r
F P
0 g
s
.27171 .61083 m .27807 .60364 L .28914 .60839 L p 0 0 1 r
F P
0 g
s
.27734 .61218 m .27149 .61336 L .26771 .60912 L p 1 0 0 r
F P
0 g
s
.26771 .60912 m .26102 .60161 L p .26662 .60523 L 1 0 0 r
F P
0 g
s
.26662 .60523 m .26761 .60876 L .26771 .60912 L 1 0 0 r
F
.26771 .60912 m .2666 .60524 L .26761 .60876 L 0 0 1 r
F
.26569 .60537 m .2666 .60524 L .26771 .60912 L F
.2666 .60524 m .26662 .60523 L .26761 .60876 L 0 1 0 r
F
.26772 .60912 m .26771 .60912 L p .26761 .60876 L 0 0 1 r
F P
0 g
s
.26662 .60523 m .26689 .605 L .26771 .60912 L 0 1 0 r
F
.26662 .60523 m .26663 .60524 L .26761 .60876 L 1 0 0 r
F
.26662 .60523 m .26662 .60522 L .26663 .60524 L F
.26771 .6091 m .26689 .605 L .26772 .60912 L 0 1 0 r
F
.26719 .59613 m .27881 .59494 L p .26662 .60523 L F P
0 g
s
.26615 .60493 m .26457 .60156 L .26662 .60523 L 1 0 0 r
F
.26102 .60161 m .26457 .60156 L p .26615 .60493 L F P
0 g
s
.2666 .60524 m .26457 .60156 L .26662 .60523 L 0 1 0 r
F
.26569 .60537 m .26552 .60329 L .2666 .60524 L 0 0 1 r
F
.26061 .60609 m .26457 .60157 L p .26569 .60537 L F P
0 g
s
.26457 .60157 m .26457 .60156 L p .2666 .60524 L 0 1 0 r
F P
0 g
s
.26457 .60156 m .26478 .60113 L p .26662 .60523 L 0 1 0 r
F P
0 g
s
.26478 .60113 m .26719 .59613 L p .26666 .60457 L 0 1 0 r
F P
0 g
s
.26478 .60113 m .26666 .60457 L .26662 .60523 L 0 1 0 r
F
.25069 .58868 m .25618 .58976 L .26232 .59662 L p 1 0 0 r
F P
0 g
s
.26719 .59613 m .26478 .60113 L p .2639 .59928 L 0 1 0 r
F P
0 g
s
.26478 .60113 m .26457 .60156 L p .2639 .59928 L 0 1 0 r
F P
0 g
s
.26457 .60157 m .26458 .60156 L p .26569 .60537 L 0 0 1 r
F P
0 g
s
.26457 .60156 m .26458 .60156 L p .26662 .60523 L 1 0 0 r
F P
0 g
s
.26458 .60156 m .26657 .60514 L .26662 .60523 L 1 0 0 r
F
.26458 .60156 m .26531 .60073 L p .26551 .60324 L 0 0 1 r
F P
0 g
s
.26552 .60329 m .26531 .60073 L .2666 .60524 L 0 0 1 r
F
.26657 .60514 m .26662 .60522 L .26662 .60523 L 1 0 0 r
F
.26531 .60073 m .26694 .59886 L p .26665 .60433 L 0 0 1 r
F P
0 g
s
.266 .60313 m .26665 .60433 L .2666 .60524 L 0 0 1 r
F
.26531 .60073 m .26665 .60433 L .266 .60313 L F
.2741 .58266 m .26719 .59613 L .26334 .5969 L p 0 1 0 r
F P
0 g
s
.26324 .5967 m .2741 .58266 L .26334 .5969 L 0 1 0 r
F
.26102 .60161 m .25069 .58868 L p .26368 .5991 L 1 0 0 r
F P
0 g
s
.26304 .59696 m .26268 .59703 L p .26188 .59299 L 0 1 0 r
F P
0 g
s
.26304 .59696 m .26719 .59613 L p .2639 .59928 L 0 1 0 r
F P
0 g
s
.28561 .5826 m .27881 .59494 L .26719 .59613 L p 0 1 0 r
F P
0 g
s
.26719 .59613 m .2741 .58266 L .28561 .5826 L p 0 1 0 r
F P
0 g
s
.27332 .59159 m .26694 .59886 L .26407 .59762 L p 0 0 1 r
F P
0 g
s
.2635 .59661 m .27332 .59159 L .26407 .59762 L 0 0 1 r
F
.26268 .59701 m .26188 .59299 L .26268 .59703 L 0 1 0 r
F
.26334 .5969 m .26304 .59696 L p .26324 .5967 L F P
0 g
s
.26232 .59662 m .26268 .59703 L p .26367 .59909 L 1 0 0 r
F P
0 g
s
.26368 .5991 m .26376 .59939 L .26102 .60161 L 1 0 0 r
F
.2639 .59928 m .2639 .59929 L .26102 .60161 L F
.26458 .60156 m .26102 .60161 L p .26391 .59929 L F P
0 g
s
.25553 .60047 m .25023 .59809 L .24032 .58268 L p 1 0 0 r
F P
0 g
s
.24032 .58268 m .2454 .58633 L .25553 .60047 L p 1 0 0 r
F P
0 g
s
.26102 .60161 m .25553 .60047 L .2454 .58633 L p 1 0 0 r
F P
0 g
s
.2454 .58633 m .25069 .58868 L .26102 .60161 L p 1 0 0 r
F P
0 g
s
.26061 .60609 m .24946 .60132 L p .26389 .59929 L 0 0 1 r
F P
0 g
s
.26694 .59886 m .26491 .60118 L p .26389 .59929 L 0 0 1 r
F P
0 g
s
.26455 .60151 m .2639 .59928 L .26457 .60156 L 0 1 0 r
F
.26457 .60157 m .26061 .60609 L p .26389 .59929 L 0 0 1 r
F P
0 g
s
.26363 .59954 m .26389 .59929 L .26455 .60151 L 0 1 0 r
F
.26389 .59929 m .2639 .59928 L .26455 .60151 L F
.26457 .60156 m .26457 .60157 L p .26455 .60151 L F P
0 g
s
.26491 .60118 m .26457 .60157 L p .26389 .59929 L 0 0 1 r
F P
0 g
s
.25069 .58868 m .26232 .59662 L .26367 .59909 L 1 0 0 r
F
.25431 .61327 m .24806 .6204 L .23696 .6157 L p 0 0 1 r
F P
0 g
s
.23696 .6157 m .24319 .60853 L .25431 .61327 L p 0 0 1 r
F P
0 g
s
.26061 .60609 m .25431 .61327 L .24319 .60853 L p 0 0 1 r
F P
0 g
s
.24319 .60853 m .24946 .60132 L .26061 .60609 L p 0 0 1 r
F P
0 g
s
.24946 .60132 m .25577 .59406 L .26268 .59703 L p 0 0 1 r
F P
0 g
s
.26364 .59903 m .26268 .59704 L .26283 .59732 L 1 0 0 r
F
.26364 .59903 m .26283 .59732 L .26333 .59822 L F
.26367 .59909 m .26268 .59703 L .26268 .59704 L F
.26367 .59909 m .26268 .59704 L .26364 .59903 L F
.26368 .5991 m .2639 .59928 L .26376 .59939 L F
.24946 .60132 m .26268 .59703 L .26389 .59929 L 0 0 1 r
F
.26268 .59703 m .26268 .59703 L .26283 .59732 L F
.26268 .59703 m .26283 .59732 L .26389 .59929 L F
.26367 .59909 m .263 .59739 L .2639 .59928 L 1 0 0 r
F
.24819 .61435 m .2628 .59725 L .2639 .59928 L 0 1 0 r
F
.2628 .59725 m .26304 .59696 L .2639 .59928 L F
.26333 .59822 m .26283 .59732 L .26332 .59821 L 1 0 0 r
F
.26268 .59703 m .26694 .59886 L p .26391 .59929 L 0 0 1 r
F P
0 g
s
.26283 .59732 m .26268 .59703 L .26391 .59929 L 0 0 1 r
F
.26268 .59703 m .263 .59739 L p .26332 .59821 L 1 0 0 r
F P
0 g
s
.26268 .59704 m .26268 .59703 L .26332 .59821 L 1 0 0 r
F
.2639 .59928 m .26391 .59929 L .2639 .59929 L F
.2639 .59928 m .26387 .59923 L .26391 .59929 L F
.26389 .59929 m .26283 .59732 L .26391 .59929 L 0 0 1 r
F
.26268 .59703 m .26268 .59703 L p .26268 .59704 L 1 0 0 r
F P
0 g
s
.26268 .59703 m .26268 .59703 L p .26277 .59728 L 0 1 0 r
F P
0 g
s
.26268 .59703 m .26304 .59696 L p .2628 .59725 L 0 1 0 r
F P
0 g
s
.26277 .59728 m .26268 .59703 L .2628 .59725 L 0 1 0 r
F
.24819 .61435 m .25535 .5985 L .26268 .59703 L p F P
0 g
s
.24819 .61435 m .26268 .59703 L .26277 .59728 L 0 1 0 r
F
.26407 .59762 m .26269 .59703 L p .26397 .59746 L 0 0 1 r
F P
0 g
s
.26269 .59703 m .26268 .59703 L p .26397 .59746 L 0 0 1 r
F P
0 g
s
.26268 .59703 m .2635 .59661 L .26397 .59746 L 0 0 1 r
F
.26689 .605 m .27881 .59494 L .26806 .60905 L 0 1 0 r
F
.26694 .59886 m .27807 .60364 L p .26663 .60524 L 0 0 1 r
F P
0 g
s
.26661 .6052 m .26694 .59886 L .26663 .60524 L 0 0 1 r
F
.28446 .59639 m .27807 .60364 L .26694 .59886 L p F P
0 g
s
.29694 .58355 m .29024 .59484 L .27881 .59494 L p 0 1 0 r
F P
0 g
s
.27881 .59494 m .28561 .5826 L .29694 .58355 L p 0 1 0 r
F P
0 g
s
.26694 .59886 m .27332 .59159 L .28446 .59639 L p 0 0 1 r
F P
0 g
s
.27256 .60029 m .2667 .60153 L .26268 .59703 L p 1 0 0 r
F P
0 g
s
.26268 .59703 m .26268 .59703 L p .26268 .59703 L 1 0 0 r
F P
0 g
s
.26268 .59703 m .27256 .60029 L .26268 .59703 L 1 0 0 r
F
.26268 .59703 m .25618 .58976 L p .26158 .59323 L F P
0 g
s
.26158 .59323 m .26258 .5967 L .26268 .59703 L 1 0 0 r
F
.26268 .59703 m .26157 .59325 L .26258 .5967 L 0 0 1 r
F
.26069 .59337 m .26157 .59325 L .26268 .59703 L F
.26157 .59325 m .26158 .59323 L .26258 .5967 L 0 1 0 r
F
.26268 .59703 m .26268 .59703 L p .26258 .5967 L 0 0 1 r
F P
0 g
s
.26158 .59323 m .26188 .59299 L .26268 .59703 L 0 1 0 r
F
.26158 .59323 m .2616 .59324 L .26258 .5967 L 1 0 0 r
F
.26158 .59323 m .26159 .59322 L .2616 .59324 L F
.2624 .58381 m .2741 .58266 L p .26158 .59323 L 0 1 0 r
F P
0 g
s
.26113 .59294 m .25958 .58968 L .26158 .59323 L 1 0 0 r
F
.25618 .58976 m .25958 .58968 L p .26113 .59294 L F P
0 g
s
.26157 .59325 m .25958 .58968 L .26158 .59323 L 0 1 0 r
F
.26069 .59337 m .26051 .59135 L .26157 .59325 L 0 0 1 r
F
.25577 .59406 m .25958 .58969 L p .26069 .59337 L F P
0 g
s
.25958 .58969 m .25958 .58968 L p .26157 .59325 L 0 1 0 r
F P
0 g
s
.25958 .58968 m .25981 .58922 L p .26158 .59323 L 0 1 0 r
F P
0 g
s
.25981 .58922 m .2624 .58381 L p .26164 .59255 L 0 1 0 r
F P
0 g
s
.25981 .58922 m .26164 .59255 L .26158 .59323 L 0 1 0 r
F
.24579 .57681 m .25128 .57784 L .25711 .58433 L p 1 0 0 r
F P
0 g
s
.2624 .58381 m .25981 .58922 L p .25884 .58722 L 0 1 0 r
F P
0 g
s
.25981 .58922 m .25958 .58968 L p .25884 .58722 L 0 1 0 r
F P
0 g
s
.25958 .58969 m .25959 .58968 L p .26069 .59337 L 0 0 1 r
F P
0 g
s
.25958 .58968 m .25959 .58968 L p .26158 .59323 L 1 0 0 r
F P
0 g
s
.25959 .58968 m .26154 .59314 L .26158 .59323 L 1 0 0 r
F
.25959 .58968 m .26029 .58887 L p .2605 .5913 L 0 0 1 r
F P
0 g
s
.26051 .59135 m .26029 .58887 L .26157 .59325 L 0 0 1 r
F
.26154 .59314 m .26159 .59322 L .26158 .59323 L 1 0 0 r
F
.26029 .58887 m .26213 .58676 L p .26165 .59232 L 0 0 1 r
F P
0 g
s
.2609 .59095 m .26165 .59232 L .26157 .59325 L 0 0 1 r
F
.26029 .58887 m .26165 .59232 L .2609 .59095 L F
.26935 .5702 m .2624 .58381 L .25813 .58464 L p 0 1 0 r
F P
0 g
s
.25806 .58449 m .26935 .5702 L .25813 .58464 L 0 1 0 r
F
.25618 .58976 m .24579 .57681 L p .2586 .58702 L 1 0 0 r
F P
0 g
s
.2579 .58469 m .2575 .58477 L p .25675 .58085 L 0 1 0 r
F P
0 g
s
.2579 .58469 m .2624 .58381 L p .25884 .58722 L 0 1 0 r
F P
0 g
s
.28094 .57019 m .2741 .58266 L .2624 .58381 L p 0 1 0 r
F P
0 g
s
.2624 .58381 m .26935 .5702 L .28094 .57019 L p 0 1 0 r
F P
0 g
s
.26852 .57941 m .26213 .58676 L .25884 .58534 L p 0 0 1 r
F P
0 g
s
.25829 .58438 m .26852 .57941 L .25884 .58534 L 0 0 1 r
F
.2575 .58475 m .25675 .58085 L .2575 .58477 L 0 1 0 r
F
.25813 .58464 m .2579 .58469 L p .25806 .58449 L F P
0 g
s
.25711 .58433 m .2575 .58477 L p .25859 .58702 L 1 0 0 r
F P
0 g
s
.2586 .58702 m .2587 .58736 L .25618 .58976 L 1 0 0 r
F
.25884 .58722 m .25885 .58723 L .25618 .58976 L F
.25959 .58968 m .25618 .58976 L p .25885 .58722 L F P
0 g
s
.25069 .58868 m .2454 .58633 L .23544 .57092 L p 1 0 0 r
F P
0 g
s
.23544 .57092 m .24051 .57452 L .25069 .58868 L p 1 0 0 r
F P
0 g
s
.25618 .58976 m .25069 .58868 L .24051 .57452 L p 1 0 0 r
F P
0 g
s
.24051 .57452 m .24579 .57681 L .25618 .58976 L p 1 0 0 r
F P
0 g
s
.25577 .59406 m .24455 .58925 L p .25884 .58723 L 0 0 1 r
F P
0 g
s
.26213 .58676 m .25994 .58927 L p .25884 .58723 L 0 0 1 r
F P
0 g
s
.25956 .58963 m .25884 .58722 L .25958 .58968 L 0 1 0 r
F
.25958 .58969 m .25577 .59406 L p .25884 .58723 L 0 0 1 r
F P
0 g
s
.25855 .5875 m .25884 .58723 L .25956 .58963 L 0 1 0 r
F
.25884 .58723 m .25884 .58722 L .25956 .58963 L F
.25958 .58968 m .25958 .58969 L p .25956 .58963 L F P
0 g
s
.25994 .58927 m .25958 .58969 L p .25884 .58723 L 0 0 1 r
F P
0 g
s
.24579 .57681 m .25711 .58433 L .25859 .58702 L 1 0 0 r
F
.23202 .60378 m .23826 .59654 L .24946 .60132 L p 0 0 1 r
F P
0 g
s
.25577 .59406 m .24946 .60132 L .23826 .59654 L p 0 0 1 r
F P
0 g
s
.23826 .59654 m .24455 .58925 L .25577 .59406 L p 0 0 1 r
F P
0 g
s
.24455 .58925 m .25088 .58191 L .2575 .58477 L p 0 0 1 r
F P
0 g
s
.25857 .58696 m .25751 .58478 L .25765 .58504 L 1 0 0 r
F
.25857 .58696 m .25765 .58504 L .25822 .58607 L F
.25859 .58702 m .2575 .58477 L .25751 .58478 L F
.25859 .58702 m .25751 .58478 L .25857 .58696 L F
.2586 .58702 m .25884 .58722 L .2587 .58736 L F
.24455 .58925 m .2575 .58477 L .25884 .58723 L 0 0 1 r
F
.2575 .58477 m .2575 .58477 L .25765 .58504 L F
.2575 .58477 m .25765 .58504 L .25884 .58723 L F
.25859 .58702 m .25785 .58516 L .25884 .58722 L 1 0 0 r
F
.24327 .60216 m .25763 .58501 L .25884 .58722 L 0 1 0 r
F
.25763 .58501 m .2579 .58469 L .25884 .58722 L F
.25822 .58607 m .25765 .58504 L .25821 .58606 L 1 0 0 r
F
.2575 .58477 m .26213 .58676 L p .25885 .58722 L 0 0 1 r
F P
0 g
s
.25765 .58504 m .2575 .58477 L .25885 .58722 L 0 0 1 r
F
.2575 .58477 m .25785 .58516 L p .25821 .58606 L 1 0 0 r
F P
0 g
s
.25751 .58478 m .2575 .58477 L .25821 .58606 L 1 0 0 r
F
.25884 .58722 m .25885 .58722 L .25885 .58723 L F
.25884 .58722 m .25881 .58716 L .25885 .58722 L F
.25884 .58723 m .25765 .58504 L .25885 .58722 L 0 0 1 r
F
.2575 .58477 m .2575 .58477 L p .25751 .58478 L 1 0 0 r
F P
0 g
s
.2575 .58477 m .2575 .58477 L p .25761 .58504 L 0 1 0 r
F P
0 g
s
.2575 .58477 m .2579 .58469 L p .25763 .58501 L 0 1 0 r
F P
0 g
s
.25761 .58504 m .2575 .58477 L .25763 .58501 L 0 1 0 r
F
.24327 .60216 m .25047 .58615 L .2575 .58477 L p F P
0 g
s
.24327 .60216 m .2575 .58477 L .25761 .58504 L 0 1 0 r
F
.25884 .58534 m .25751 .58477 L p .25876 .5852 L 0 0 1 r
F P
0 g
s
.25751 .58477 m .2575 .58477 L p .25876 .5852 L 0 0 1 r
F P
0 g
s
.2575 .58477 m .25829 .58438 L .25876 .5852 L 0 0 1 r
F
.26188 .59299 m .2741 .58266 L .26304 .59696 L 0 1 0 r
F
.26213 .58676 m .27332 .59159 L p .2616 .59324 L 0 0 1 r
F P
0 g
s
.26157 .5932 m .26213 .58676 L .2616 .59324 L 0 0 1 r
F
.27974 .58427 m .27332 .59159 L .26213 .58676 L p F P
0 g
s
.29235 .57118 m .28561 .5826 L .2741 .58266 L p 0 1 0 r
F P
0 g
s
.2741 .58266 m .28094 .57019 L .29235 .57118 L p 0 1 0 r
F P
0 g
s
.26213 .58676 m .26852 .57941 L .27974 .58427 L p 0 0 1 r
F P
0 g
s
.26772 .58832 m .26186 .58962 L .2575 .58477 L p 1 0 0 r
F P
0 g
s
.2575 .58477 m .2575 .58477 L p .2575 .58477 L 1 0 0 r
F P
0 g
s
.2575 .58477 m .26772 .58832 L .2575 .58477 L 1 0 0 r
F
.2575 .58477 m .25128 .57784 L p .25643 .58112 L F P
0 g
s
.25643 .58112 m .25742 .58447 L .2575 .58477 L 1 0 0 r
F
.2575 .58477 m .25641 .58113 L .25742 .58447 L 0 0 1 r
F
.25557 .58125 m .25641 .58113 L .2575 .58477 L F
.25641 .58113 m .25643 .58112 L .25742 .58447 L 0 1 0 r
F
.2575 .58477 m .2575 .58477 L p .25742 .58447 L 0 0 1 r
F P
0 g
s
.25643 .58112 m .25675 .58085 L .2575 .58477 L 0 1 0 r
F
.25643 .58112 m .25644 .58112 L .25742 .58447 L 1 0 0 r
F
.25643 .58112 m .25643 .58111 L .25644 .58112 L F
.24084 .56489 m .24632 .56584 L .25175 .57186 L p F P
0 g
s
.25651 .5804 m .25756 .57131 L .25675 .58084 L 0 1 0 r
F
.2545 .57772 m .25756 .57131 L p .25643 .58112 L F P
0 g
s
.25756 .57131 m .26935 .5702 L p .25675 .58084 L 0 1 0 r
F P
0 g
s
.25675 .58085 m .26935 .5702 L .2579 .58469 L 0 1 0 r
F
.25726 .57453 m .26852 .57941 L p .25701 .58104 L 0 0 1 r
F P
0 g
s
.25643 .58112 m .25651 .5804 L .25675 .58084 L 0 1 0 r
F
.25644 .58112 m .25655 .58022 L .25701 .58104 L 0 0 1 r
F
.25655 .58022 m .25726 .57453 L .25701 .58104 L F
.25175 .57186 m .25218 .57233 L p .2534 .57482 L 1 0 0 r
F P
0 g
s
.25642 .58109 m .25726 .57453 L .25644 .58112 L 0 0 1 r
F
.256 .58084 m .2545 .57772 L .25643 .58112 L 1 0 0 r
F
.25128 .57784 m .2545 .57772 L p .256 .58084 L F P
0 g
s
.25641 .58113 m .2545 .57772 L .25643 .58112 L 0 1 0 r
F
.25558 .58125 m .25539 .57932 L .25641 .58113 L 0 0 1 r
F
.25088 .58191 m .25449 .57773 L p .25558 .58125 L F P
0 g
s
.25449 .57773 m .2545 .57772 L p .25641 .58113 L 0 1 0 r
F P
0 g
s
.2545 .57772 m .2545 .57772 L p .25643 .58112 L 1 0 0 r
F P
0 g
s
.2545 .57772 m .25638 .58102 L .25643 .58112 L 1 0 0 r
F
.25449 .57773 m .2545 .57772 L p .25558 .58125 L 0 0 1 r
F P
0 g
s
.2545 .57772 m .25516 .57696 L p .25538 .57927 L 0 0 1 r
F P
0 g
s
.2545 .57772 m .25538 .57927 L .25558 .58125 L 0 0 1 r
F
.25539 .57932 m .25516 .57696 L .25641 .58113 L F
.25516 .57696 m .25726 .57453 L p .25642 .58109 L F P
0 g
s
.25638 .58102 m .25643 .58111 L .25643 .58112 L 1 0 0 r
F
.25638 .58102 m .25642 .58109 L .25641 .58113 L 0 0 1 r
F
.25516 .57696 m .25642 .58109 L .25638 .58102 L F
.25478 .57771 m .25696 .57763 L p .25643 .58111 L 1 0 0 r
F P
0 g
s
.25478 .57771 m .25643 .58111 L .25638 .58102 L 1 0 0 r
F
.2575 .58477 m .25088 .58191 L p .25557 .58125 L 0 0 1 r
F P
0 g
s
.25047 .58615 m .25449 .57773 L p .25641 .58113 L 0 1 0 r
F P
0 g
s
.26455 .55757 m .25756 .57131 L .25278 .57222 L p 0 1 0 r
F P
0 g
s
.25273 .57212 m .26455 .55757 L .25278 .57222 L 0 1 0 r
F
.25128 .57784 m .24084 .56489 L p .2534 .57482 L 1 0 0 r
F P
0 g
s
.24084 .56489 m .25175 .57186 L .2534 .57482 L 1 0 0 r
F
.25128 .57784 m .24579 .57681 L .23556 .56266 L p F P
0 g
s
.23556 .56266 m .24084 .56489 L .25128 .57784 L p 1 0 0 r
F P
0 g
s
.25262 .57225 m .25218 .57233 L p .25149 .56858 L 0 1 0 r
F P
0 g
s
.24579 .57681 m .24051 .57452 L .23051 .55912 L p 1 0 0 r
F P
0 g
s
.23051 .55912 m .23556 .56266 L .24579 .57681 L p 1 0 0 r
F P
0 g
s
.2396 .57705 m .24594 .56963 L .25218 .57233 L p 0 0 1 r
F P
0 g
s
.25218 .57233 m .25218 .57233 L p .25218 .57233 L 0 0 1 r
F P
0 g
s
.2396 .57705 m .25218 .57233 L .25218 .57233 L 0 0 1 r
F
.2534 .57482 m .25367 .57503 L .25352 .57521 L 1 0 0 r
F
.2534 .57482 m .25352 .57521 L .25128 .57784 L F
.25756 .57131 m .2545 .57772 L p .25367 .57503 L 0 1 0 r
F P
0 g
s
.2534 .57482 m .25218 .57233 L .25232 .57259 L 1 0 0 r
F
.25367 .57503 m .25232 .57259 L .25756 .57131 L 0 1 0 r
F
.25218 .57233 m .25756 .57131 L p .25232 .57259 L F P
0 g
s
.25367 .57503 m .25232 .57259 L .25368 .57504 L 1 0 0 r
F
.25218 .57233 m .25726 .57453 L p .25366 .57504 L 0 0 1 r
F P
0 g
s
.2534 .57482 m .25232 .57259 L .25367 .57503 L 1 0 0 r
F
.25304 .57513 m .25218 .57233 L .25366 .57504 L 0 0 1 r
F
.25218 .57233 m .25218 .57233 L p .25232 .57259 L 0 1 0 r
F P
0 g
s
.2396 .57705 m .25218 .57233 L .25304 .57513 L 0 0 1 r
F
.2454 .58633 m .24032 .58268 L .2306 .56598 L p 1 0 0 r
F P
0 g
s
.2306 .56598 m .23544 .57092 L .2454 .58633 L p 1 0 0 r
F P
0 g
s
.22702 .59173 m .23329 .58441 L .24455 .58925 L p 0 0 1 r
F P
0 g
s
.25088 .58191 m .24455 .58925 L .23329 .58441 L p 0 0 1 r
F P
0 g
s
.23329 .58441 m .2396 .57705 L .25088 .58191 L p 0 0 1 r
F P
0 g
s
.2545 .57772 m .25128 .57784 L p .25367 .57503 L 1 0 0 r
F P
0 g
s
.25088 .58191 m .2396 .57705 L p .25366 .57504 L 0 0 1 r
F P
0 g
s
.25367 .57503 m .25368 .57504 L .2545 .57772 L 1 0 0 r
F
.25726 .57453 m .25489 .57728 L p .2537 .57512 L 0 0 1 r
F P
0 g
s
.25368 .57504 m .25726 .57453 L .2537 .57512 L 0 0 1 r
F
.25696 .57763 m .2545 .57772 L p .25368 .57504 L 1 0 0 r
F P
0 g
s
.2545 .57772 m .2545 .57772 L p .25368 .57504 L 1 0 0 r
F P
0 g
s
.25366 .57504 m .25368 .57504 L .2537 .57512 L 0 0 1 r
F
.25447 .57767 m .25367 .57503 L .2545 .57772 L 0 1 0 r
F
.25449 .57773 m .25088 .58191 L p .25366 .57504 L 0 0 1 r
F P
0 g
s
.25335 .57534 m .25366 .57504 L .25447 .57767 L 0 1 0 r
F
.25366 .57504 m .25367 .57503 L .25447 .57767 L F
.2545 .57772 m .25449 .57773 L p .25447 .57767 L F P
0 g
s
.25489 .57728 m .25449 .57773 L p .25366 .57504 L 0 0 1 r
F P
0 g
s
.23829 .58976 m .25218 .57233 L .25232 .57259 L 0 1 0 r
F
.25366 .57504 m .25232 .57259 L .25367 .57503 L F
.23829 .58976 m .25232 .57259 L .25366 .57504 L F
.23829 .58976 m .24555 .5736 L .25218 .57233 L p F P
0 g
s
.27496 .57201 m .26852 .57941 L .25726 .57453 L p 0 0 1 r
F P
0 g
s
.28771 .55865 m .28094 .57019 L .26935 .5702 L p 0 1 0 r
F P
0 g
s
.26935 .5702 m .27622 .55761 L .28771 .55865 L p 0 1 0 r
F P
0 g
s
.27622 .55761 m .26935 .5702 L .25756 .57131 L p 0 1 0 r
F P
0 g
s
.25726 .57453 m .26367 .5671 L .27496 .57201 L p 0 0 1 r
F P
0 g
s
.25218 .57233 m .24632 .56584 L p .25114 .56888 L 1 0 0 r
F P
0 g
s
.25114 .56888 m .2521 .57207 L .25218 .57233 L 1 0 0 r
F
.2521 .57207 m .25149 .56858 L .25218 .57233 L 0 1 0 r
F
.25113 .56889 m .25114 .56888 L .2521 .57207 L F
.25114 .56888 m .25149 .56858 L .2521 .57207 L F
.25756 .57131 m .26455 .55757 L .27622 .55761 L p F P
0 g
s
.26367 .5671 m .25726 .57453 L .25344 .57288 L p 0 0 1 r
F P
0 g
s
.25293 .57199 m .26367 .5671 L .25344 .57288 L 0 0 1 r
F
.25114 .56888 m .25115 .56889 L .2521 .57207 L 1 0 0 r
F
.25149 .56858 m .26455 .55757 L .25262 .57225 L 0 1 0 r
F
.25113 .56889 m .26367 .5671 L .25218 .57233 L 0 0 1 r
F
.25218 .57233 m .24594 .56963 L p .25113 .56889 L F P
0 g
s
.23582 .5529 m .2413 .55377 L .24623 .55919 L p 1 0 0 r
F P
0 g
s
.25268 .55862 m .26455 .55757 L p .2515 .56857 L 0 1 0 r
F P
0 g
s
.25125 .56813 m .25268 .55862 L .2515 .56857 L 0 1 0 r
F
.24931 .56569 m .25268 .55862 L p .25114 .56888 L F P
0 g
s
.25233 .56217 m .26367 .5671 L p .25179 .5688 L 0 0 1 r
F P
0 g
s
.25114 .56888 m .25125 .56813 L .2515 .56857 L 0 1 0 r
F
.25074 .56863 m .24931 .56569 L .25114 .56888 L 1 0 0 r
F
.24632 .56584 m .24931 .56569 L p .25074 .56863 L F P
0 g
s
.25034 .569 m .24931 .5657 L .25113 .56889 L 0 0 1 r
F
.24594 .56963 m .24931 .5657 L p .25034 .569 L F P
0 g
s
.25971 .54476 m .25268 .55862 L .24726 .55962 L p 0 1 0 r
F P
0 g
s
.24724 .55958 m .25971 .54476 L .24726 .55962 L 0 1 0 r
F
.24632 .56584 m .23582 .5529 L p .24809 .56249 L 1 0 0 r
F P
0 g
s
.24623 .55919 m .2467 .55972 L p .24808 .56249 L 1 0 0 r
F P
0 g
s
.23582 .5529 m .24623 .55919 L .24808 .56249 L 1 0 0 r
F
.24632 .56584 m .24084 .56489 L .23055 .55075 L p F P
0 g
s
.23055 .55075 m .23582 .5529 L .24632 .56584 L p 1 0 0 r
F P
0 g
s
.24719 .55963 m .24671 .55972 L p .24611 .55619 L 0 1 0 r
F P
0 g
s
.24084 .56489 m .23556 .56266 L .22551 .54728 L p 1 0 0 r
F P
0 g
s
.22551 .54728 m .23055 .55075 L .24084 .56489 L p 1 0 0 r
F P
0 g
s
.23458 .56471 m .24095 .55722 L .2467 .55972 L p 0 0 1 r
F P
0 g
s
.2467 .55972 m .24671 .55972 L p .2467 .55972 L 0 0 1 r
F P
0 g
s
.23458 .56471 m .2467 .55972 L .2467 .55972 L 0 0 1 r
F
.24809 .56249 m .24838 .56273 L .24823 .56296 L 1 0 0 r
F
.24809 .56249 m .24823 .56296 L .24632 .56584 L F
.25268 .55862 m .24931 .56569 L p .24838 .56273 L 0 1 0 r
F P
0 g
s
.24808 .56249 m .2467 .55972 L .24684 .55996 L 1 0 0 r
F
.24838 .56273 m .24684 .55996 L .25268 .55862 L 0 1 0 r
F
.24671 .55972 m .25268 .55862 L p .24684 .55996 L F P
0 g
s
.24838 .56273 m .24684 .55996 L .24839 .56273 L 1 0 0 r
F
.24671 .55972 m .25233 .56217 L p .24837 .56274 L 0 0 1 r
F P
0 g
s
.24808 .56249 m .24684 .55996 L .24838 .56273 L 1 0 0 r
F
.24768 .56284 m .24671 .55972 L .24837 .56274 L 0 0 1 r
F
.24671 .55972 m .24671 .55972 L p .24684 .55996 L 0 1 0 r
F P
0 g
s
.23458 .56471 m .24671 .55972 L .24768 .56284 L 0 0 1 r
F
.24051 .57452 m .23544 .57092 L .22568 .55423 L p 1 0 0 r
F P
0 g
s
.22568 .55423 m .23051 .55912 L .24051 .57452 L p 1 0 0 r
F P
0 g
s
.22197 .57955 m .22826 .57216 L .2396 .57705 L p 0 0 1 r
F P
0 g
s
.24594 .56963 m .2396 .57705 L .22826 .57216 L p 0 0 1 r
F P
0 g
s
.22826 .57216 m .23458 .56471 L .24594 .56963 L p 0 0 1 r
F P
0 g
s
.24931 .56569 m .24632 .56584 L p .24838 .56273 L 1 0 0 r
F P
0 g
s
.24594 .56963 m .23458 .56471 L p .24837 .56274 L 0 0 1 r
F P
0 g
s
.24838 .56273 m .24839 .56273 L .24931 .56569 L 1 0 0 r
F
.25233 .56217 m .24974 .5652 L p .24842 .56282 L 0 0 1 r
F P
0 g
s
.24839 .56273 m .25233 .56217 L .24842 .56282 L 0 0 1 r
F
.25114 .56888 m .25114 .56887 L .25115 .56889 L 1 0 0 r
F
.25115 .56889 m .24976 .56518 L .25179 .5688 L 0 0 1 r
F
.2511 .56879 m .25114 .56887 L .25114 .56888 L 1 0 0 r
F
.25113 .56889 m .24931 .56569 L .25114 .56888 L 0 1 0 r
F
.25113 .56889 m .25108 .56876 L .25115 .56889 L 0 0 1 r
F
.25108 .56876 m .24976 .56518 L .25115 .56889 L F
.24931 .5657 m .24931 .56569 L p .25113 .56889 L 0 1 0 r
F P
0 g
s
.24931 .5657 m .24932 .56569 L p .25113 .56889 L 0 0 1 r
F P
0 g
s
.24932 .56569 m .24976 .56518 L p .25108 .56876 L 0 0 1 r
F P
0 g
s
.24931 .56569 m .24932 .56569 L p .25114 .56888 L 1 0 0 r
F P
0 g
s
.24932 .56569 m .2511 .56879 L .25114 .56888 L 1 0 0 r
F
.24932 .56569 m .25108 .56876 L .25113 .56889 L 0 0 1 r
F
.24932 .56569 m .24957 .56568 L p .2511 .56879 L 1 0 0 r
F P
0 g
s
.24976 .56518 m .25233 .56217 L p .25179 .5688 L 0 0 1 r
F P
0 g
s
.24957 .56568 m .252 .56556 L p .25114 .56887 L 1 0 0 r
F P
0 g
s
.24957 .56568 m .25114 .56887 L .2511 .56879 L 1 0 0 r
F
.252 .56556 m .24932 .56569 L p .24839 .56273 L F P
0 g
s
.24932 .56569 m .24931 .56569 L p .24839 .56273 L 1 0 0 r
F P
0 g
s
.24837 .56274 m .24839 .56273 L .24842 .56282 L 0 0 1 r
F
.24928 .56563 m .24838 .56273 L .24931 .56569 L 0 1 0 r
F
.24931 .5657 m .24594 .56963 L p .24837 .56274 L 0 0 1 r
F P
0 g
s
.24803 .56306 m .24837 .56274 L .24928 .56563 L 0 1 0 r
F
.24837 .56274 m .24838 .56273 L .24928 .56563 L F
.24931 .56569 m .24931 .5657 L p .24928 .56563 L F P
0 g
s
.24974 .5652 m .24931 .5657 L p .24837 .56274 L 0 0 1 r
F P
0 g
s
.23328 .57715 m .24671 .55972 L .24684 .55996 L 0 1 0 r
F
.24837 .56274 m .24684 .55996 L .24838 .56273 L F
.23328 .57715 m .24684 .55996 L .24837 .56274 L F
.23328 .57715 m .24058 .56085 L .24671 .55972 L p F P
0 g
s
.27012 .55962 m .26367 .5671 L .25233 .56217 L p 0 0 1 r
F P
0 g
s
.28302 .54596 m .27622 .55761 L .26455 .55757 L p 0 1 0 r
F P
0 g
s
.26455 .55757 m .27145 .54486 L .28302 .54596 L p 0 1 0 r
F P
0 g
s
.27145 .54486 m .26455 .55757 L .25268 .55862 L p 0 1 0 r
F P
0 g
s
.25233 .56217 m .25876 .55466 L .27012 .55962 L p 0 0 1 r
F P
0 g
s
.2467 .55972 m .2413 .55377 L p .24572 .55652 L 1 0 0 r
F P
0 g
s
.24572 .55652 m .24663 .55948 L .2467 .55972 L 1 0 0 r
F
.24663 .55948 m .24611 .55619 L .24671 .55972 L 0 1 0 r
F
.24571 .55653 m .24572 .55652 L .24663 .55948 L F
.24572 .55652 m .24611 .55619 L .24663 .55948 L F
.25268 .55862 m .25971 .54476 L .27145 .54486 L p F P
0 g
s
.25876 .55466 m .25233 .56217 L .24788 .56023 L p 0 0 1 r
F P
0 g
s
.24741 .55942 m .25876 .55466 L .24788 .56023 L 0 0 1 r
F
.24572 .55652 m .24573 .55653 L .24663 .55948 L 1 0 0 r
F
.24611 .55619 m .25971 .54476 L .24719 .55963 L 0 1 0 r
F
.24571 .55653 m .25876 .55466 L .24671 .55972 L 0 0 1 r
F
.24671 .55972 m .24095 .55722 L p .24571 .55653 L F P
0 g
s
.23074 .54084 m .23622 .54162 L .24054 .54634 L p 1 0 0 r
F P
0 g
s
.24775 .54575 m .25971 .54476 L p .24613 .55618 L 0 1 0 r
F P
0 g
s
.24587 .55573 m .24775 .54575 L .24613 .55618 L 0 1 0 r
F
.24402 .55359 m .24775 .54575 L p .24572 .55652 L F P
0 g
s
.24736 .54967 m .25876 .55466 L p .24644 .55643 L 0 0 1 r
F P
0 g
s
.24572 .55652 m .24587 .55573 L .24613 .55618 L 0 1 0 r
F
.24535 .55629 m .24402 .55359 L .24572 .55652 L 1 0 0 r
F
.2413 .55377 m .24402 .55359 L p .24535 .55629 L F P
0 g
s
.24499 .55664 m .24402 .5536 L .24571 .55653 L 0 0 1 r
F
.24095 .55722 m .24402 .5536 L p .24499 .55664 L F P
0 g
s
.25482 .53177 m .24775 .54575 L .24162 .54683 L p 0 1 0 r
F P
0 g
s
.2413 .55377 m .23074 .54084 L p .24264 .55004 L 1 0 0 r
F P
0 g
s
.24054 .54634 m .24107 .54693 L p .24264 .55004 L 1 0 0 r
F P
0 g
s
.23074 .54084 m .24054 .54634 L .24264 .55004 L 1 0 0 r
F
.22548 .53878 m .23074 .54084 L .2413 .55377 L p F P
0 g
s
.23582 .5529 m .23055 .55075 L .22045 .53539 L p 1 0 0 r
F P
0 g
s
.22045 .53539 m .22548 .53878 L .23582 .5529 L p 1 0 0 r
F P
0 g
s
.2413 .55377 m .23582 .5529 L .22548 .53878 L p 1 0 0 r
F P
0 g
s
.24107 .54693 m .24107 .54693 L p .24107 .54693 L 0 0 1 r
F P
0 g
s
.24264 .55004 m .24297 .55029 L .24282 .55061 L 1 0 0 r
F
.24264 .55004 m .24282 .55061 L .2413 .55377 L F
.24775 .54575 m .24402 .55359 L p .24297 .55029 L 0 1 0 r
F P
0 g
s
.24264 .55004 m .24107 .54693 L .2412 .54715 L 1 0 0 r
F
.24297 .55029 m .2412 .54715 L .24169 .54705 L 0 1 0 r
F
.24335 .54993 m .24169 .54705 L .24775 .54575 L F
.24297 .55029 m .24169 .54705 L .24335 .54993 L F
.24107 .54693 m .24775 .54575 L p .2412 .54715 L F P
0 g
s
.24162 .54683 m .24157 .54684 L p .24061 .54367 L 0 1 0 r
F P
0 g
s
.24157 .54684 m .24107 .54693 L p .24086 .54542 L 0 1 0 r
F P
0 g
s
.24086 .54542 m .24061 .54367 L .24157 .54684 L 0 1 0 r
F
.24101 .54672 m .24061 .54367 L .24107 .54693 L F
.24107 .54693 m .23622 .54162 L p .24017 .54404 L 1 0 0 r
F P
0 g
s
.24017 .54404 m .24061 .54367 L .24101 .54672 L 0 1 0 r
F
.24017 .54404 m .24018 .54405 L .24101 .54672 L 1 0 0 r
F
.24017 .54404 m .24101 .54672 L .24107 .54693 L F
.22952 .55224 m .2359 .54467 L .24107 .54693 L p 0 0 1 r
F P
0 g
s
.24016 .54405 m .24017 .54404 L .24101 .54672 L 0 1 0 r
F
.26664 .53194 m .25971 .54476 L .24775 .54575 L p F P
0 g
s
.24775 .54575 m .25482 .53177 L .26664 .53194 L p 0 1 0 r
F P
0 g
s
.25381 .54208 m .24736 .54967 L .24213 .54739 L p 0 0 1 r
F P
0 g
s
.24061 .54367 m .25482 .53177 L .24162 .54683 L 0 1 0 r
F
.24209 .54737 m .2359 .54467 L p .24016 .54405 L 0 0 1 r
F P
0 g
s
.23622 .54162 m .23845 .54143 L p .23984 .54384 L 1 0 0 r
F P
0 g
s
.23051 .55912 m .22568 .55423 L .21614 .53624 L p 1 0 0 r
F P
0 g
s
.21614 .53624 m .2207 .54245 L .23051 .55912 L p 1 0 0 r
F P
0 g
s
.23556 .56266 m .23051 .55912 L .2207 .54245 L p 1 0 0 r
F P
0 g
s
.2207 .54245 m .22551 .54728 L .23556 .56266 L p 1 0 0 r
F P
0 g
s
.23055 .55075 m .22551 .54728 L .21565 .53064 L p 1 0 0 r
F P
0 g
s
.21565 .53064 m .22045 .53539 L .23055 .55075 L p 1 0 0 r
F P
0 g
s
.23622 .54162 m .23074 .54084 L .22034 .52675 L p 1 0 0 r
F P
0 g
s
.22034 .52675 m .2256 .52871 L .23622 .54162 L p 1 0 0 r
F P
0 g
s
.21171 .55481 m .21803 .54725 L .22952 .55224 L p 0 0 1 r
F P
0 g
s
.22551 .54728 m .2207 .54245 L .21111 .52449 L p 1 0 0 r
F P
0 g
s
.21111 .52449 m .21565 .53064 L .22551 .54728 L p 1 0 0 r
F P
0 g
s
.2359 .54467 m .22952 .55224 L .21803 .54725 L p 0 0 1 r
F P
0 g
s
.24988 .5186 m .24277 .53268 L .23589 .53384 L p 0 1 0 r
F P
0 g
s
.23622 .54162 m .2256 .52871 L p .23706 .53745 L 1 0 0 r
F P
0 g
s
.23589 .53384 m .23571 .53387 L p .23497 .53102 L 0 1 0 r
F P
0 g
s
.23515 .53278 m .23497 .53102 L .23571 .53387 L 0 1 0 r
F
.23527 .53394 m .23497 .53102 L .23528 .53394 L F
.24277 .53268 m .23895 .54075 L p .23744 .53774 L F P
0 g
s
.23895 .54075 m .23863 .54142 L p .23744 .53774 L 0 1 0 r
F P
0 g
s
.2256 .52871 m .23527 .53394 L .23706 .53745 L 1 0 0 r
F
.23744 .53774 m .23539 .53415 L .24277 .53268 L 0 1 0 r
F
.24277 .53268 m .25482 .53177 L p .24017 .54404 L F P
0 g
s
.24016 .54403 m .24277 .53268 L .24017 .54404 L 0 1 0 r
F
.23863 .54143 m .24277 .53268 L p .24016 .54405 L F P
0 g
s
.23745 .53775 m .23539 .53415 L .24233 .53704 L 0 0 1 r
F
.23527 .53394 m .23528 .53394 L p .23539 .53415 L F P
0 g
s
.23528 .53394 m .24277 .53268 L p .23539 .53415 L 0 1 0 r
F P
0 g
s
.23528 .53394 m .24233 .53704 L p .23539 .53415 L 0 0 1 r
F P
0 g
s
.23528 .53394 m .23528 .53394 L p .23539 .53415 L 0 1 0 r
F P
0 g
s
.23527 .53394 m .23528 .53394 L .23528 .53395 L 1 0 0 r
F
.23527 .53394 m .23528 .53395 L .23706 .53745 L F
.22548 .53878 m .22045 .53539 L .21054 .51878 L p F P
0 g
s
.21054 .51878 m .21532 .52345 L .22548 .53878 L p 1 0 0 r
F P
0 g
s
.23074 .54084 m .22548 .53878 L .21532 .52345 L p 1 0 0 r
F P
0 g
s
.21532 .52345 m .22034 .52675 L .23074 .54084 L p 1 0 0 r
F P
0 g
s
.22439 .53964 m .2308 .53198 L .23527 .53394 L p 0 0 1 r
F P
0 g
s
.23706 .53745 m .23528 .53394 L .23644 .53599 L 1 0 0 r
F
.22439 .53964 m .23527 .53394 L .23539 .53415 L 0 0 1 r
F
.23706 .53745 m .23744 .53774 L .2373 .53818 L 1 0 0 r
F
.23706 .53745 m .2373 .53818 L .23622 .54162 L F
.22439 .53964 m .23539 .53415 L .23742 .53775 L 0 0 1 r
F
.21803 .54725 m .22439 .53964 L .2359 .54467 L p F P
0 g
s
.24233 .53704 m .23918 .54078 L p .23745 .53775 L 0 0 1 r
F P
0 g
s
.23744 .53774 m .23745 .53775 L .23863 .54142 L 1 0 0 r
F
.23983 .54382 m .23863 .54142 L .23984 .54384 L F
.23845 .54143 m .23863 .54142 L p .23983 .54382 L F P
0 g
s
.24233 .53704 m .25381 .54208 L p .24018 .54405 L 0 0 1 r
F P
0 g
s
.24016 .54405 m .24016 .54403 L .24017 .54404 L 0 1 0 r
F
.24017 .54404 m .24017 .54403 L .24018 .54405 L 1 0 0 r
F
.23984 .54384 m .23998 .54366 L .24017 .54404 L F
.23952 .54414 m .23981 .54342 L .24018 .54405 L 0 0 1 r
F
.23981 .54342 m .24233 .53704 L .24018 .54405 L F
.23863 .54142 m .23864 .54142 L p .23996 .54368 L 1 0 0 r
F P
0 g
s
.23864 .54142 m .23996 .54368 L .23996 .54368 L 1 0 0 r
F
.23863 .54142 m .23996 .54368 L .23984 .54384 L F
.23864 .54142 m .24233 .53704 L p .23952 .54414 L 0 0 1 r
F P
0 g
s
.23864 .54142 m .2419 .54114 L p .23996 .54368 L 1 0 0 r
F P
0 g
s
.2419 .54114 m .23864 .54142 L p .23745 .53775 L 1 0 0 r
F P
0 g
s
.23864 .54142 m .23863 .54142 L p .23745 .53775 L 1 0 0 r
F P
0 g
s
.2359 .54467 m .23863 .54143 L p .23951 .54414 L 0 0 1 r
F P
0 g
s
.23863 .54142 m .23622 .54162 L p .23744 .53774 L 1 0 0 r
F P
0 g
s
.2359 .54467 m .22439 .53964 L p .23742 .53775 L 0 0 1 r
F P
0 g
s
.23742 .53775 m .23744 .53774 L .2386 .54136 L 0 1 0 r
F
.23742 .53775 m .23745 .53775 L .23744 .53779 L 0 0 1 r
F
.23742 .53775 m .23744 .53779 L .2359 .54467 L F
.2386 .54136 m .23744 .53774 L .23863 .54142 L 0 1 0 r
F
.23863 .54142 m .23863 .54143 L p .2386 .54136 L F P
0 g
s
.23918 .54078 m .2359 .54467 L p .23745 .53775 L 0 0 1 r
F P
0 g
s
.23701 .53814 m .23742 .53775 L .2386 .54136 L 0 1 0 r
F
.23701 .53814 m .2386 .54136 L .23556 .5479 L F
.23863 .54143 m .23556 .5479 L p .2386 .54136 L F P
0 g
s
.23951 .54414 m .23864 .54142 L .23952 .54414 L 0 0 1 r
F
.23863 .54143 m .23864 .54142 L p .23951 .54414 L F P
0 g
s
.23583 .53454 m .2419 .54114 L p .23745 .53775 L 1 0 0 r
F P
0 g
s
.23744 .53774 m .23739 .53765 L .23745 .53775 L 1 0 0 r
F
.23739 .53765 m .23583 .53454 L .23745 .53775 L F
.2231 .55132 m .23528 .53394 L .23539 .53415 L 0 1 0 r
F
.23706 .53745 m .23583 .53454 L .23744 .53774 L 1 0 0 r
F
.23742 .53775 m .23539 .53415 L .23744 .53774 L 0 1 0 r
F
.2231 .55132 m .23539 .53415 L .23742 .53775 L F
.23742 .53775 m .23539 .53415 L .23745 .53775 L 0 0 1 r
F
.2231 .55132 m .2305 .53475 L .23528 .53394 L p 0 1 0 r
F P
0 g
s
.23528 .53394 m .23583 .53454 L p .23644 .53599 L 1 0 0 r
F P
0 g
s
.26179 .51885 m .25482 .53177 L .24277 .53268 L p 0 1 0 r
F P
0 g
s
.24277 .53268 m .24988 .5186 L .26179 .51885 L p 0 1 0 r
F P
0 g
s
.2488 .52936 m .24233 .53704 L .2362 .53435 L p 0 0 1 r
F P
0 g
s
.2362 .53435 m .23528 .53394 L p .23585 .53375 L 0 0 1 r
F P
0 g
s
.23497 .53102 m .24988 .5186 L .23589 .53384 L 0 1 0 r
F
.23585 .53375 m .2488 .52936 L .2362 .53435 L 0 0 1 r
F
.23571 .53387 m .23528 .53394 L p .23515 .53278 L 0 1 0 r
F P
0 g
s
.23528 .53394 m .2488 .52936 L .23528 .53394 L 0 0 1 r
F
.24778 .53947 m .2419 .54114 L .23527 .53394 L p 1 0 0 r
F P
0 g
s
.23527 .53394 m .23108 .52938 L p .23447 .53143 L 1 0 0 r
F P
0 g
s
.23446 .53144 m .23528 .53394 L .23527 .53394 L 0 0 1 r
F
.23446 .53144 m .23522 .53377 L .23528 .53394 L 0 1 0 r
F
.23522 .53377 m .23527 .53394 L .23528 .53394 L F
.23447 .53143 m .23522 .53377 L .23527 .53394 L 1 0 0 r
F
.23522 .53377 m .23497 .53102 L .23527 .53394 L 0 1 0 r
F
.23446 .53144 m .23447 .53143 L .23522 .53377 L F
.23447 .53143 m .23497 .53102 L .23522 .53377 L F
.23522 .53377 m .2488 .52936 L .23528 .53394 L 0 0 1 r
F
.23448 .53144 m .2488 .52936 L .23522 .53377 L F
.23528 .53394 m .23528 .53394 L p .23527 .53394 L 0 1 0 r
F P
0 g
s
.23528 .53394 m .23527 .53394 L p .23528 .53394 L 0 0 1 r
F P
0 g
s
.2603 .53443 m .25381 .54208 L .24233 .53704 L p 0 0 1 r
F P
0 g
s
.24233 .53704 m .2488 .52936 L .2603 .53443 L p 0 0 1 r
F P
0 g
s
.23448 .53144 m .24778 .53947 L .23528 .53394 L 1 0 0 r
F
.23522 .53377 m .23528 .53394 L .23527 .53394 L F
.23448 .53144 m .23528 .53394 L .23522 .53377 L F
.23447 .53143 m .23448 .53144 L .23522 .53377 L F
.23446 .53144 m .23448 .53144 L .23522 .53377 L 0 0 1 r
F
.23389 .53153 m .23446 .53144 L .23527 .53394 L F
.23414 .53171 m .23446 .53144 L .23528 .53394 L 0 1 0 r
F
.22039 .51651 m .22587 .51706 L .22863 .52003 L p 1 0 0 r
F P
0 g
s
.23775 .51942 m .24988 .5186 L p .23499 .53101 L 0 1 0 r
F P
0 g
s
.23472 .53054 m .23775 .51942 L .23499 .53101 L 0 1 0 r
F
.23314 .52917 m .23775 .51942 L p .23447 .53143 L F P
0 g
s
.23724 .52427 m .2488 .52936 L p .23539 .53131 L 0 0 1 r
F P
0 g
s
.23447 .53143 m .23472 .53054 L .23499 .53101 L 0 1 0 r
F
.23419 .53126 m .23314 .52917 L .23447 .53143 L 1 0 0 r
F
.23108 .52938 m .23314 .52917 L p .23419 .53126 L F P
0 g
s
.2256 .52871 m .23108 .52938 L .23527 .53394 L p 1 0 0 r
F P
0 g
s
.2207 .54245 m .21614 .53624 L .20683 .51693 L p 1 0 0 r
F P
0 g
s
.20683 .51693 m .21111 .52449 L .2207 .54245 L p 1 0 0 r
F P
0 g
s
.23108 .52938 m .2256 .52871 L .21514 .51465 L p 1 0 0 r
F P
0 g
s
.21514 .51465 m .22039 .51651 L .23108 .52938 L p 1 0 0 r
F P
0 g
s
.2065 .54223 m .21284 .53459 L .22439 .53964 L p 0 0 1 r
F P
0 g
s
.22045 .53539 m .21565 .53064 L .20602 .51271 L p 1 0 0 r
F P
0 g
s
.20602 .51271 m .21054 .51878 L .22045 .53539 L p 1 0 0 r
F P
0 g
s
.2308 .53198 m .22439 .53964 L .21284 .53459 L p 0 0 1 r
F P
0 g
s
.24489 .50523 m .23775 .51942 L .23 .52066 L p 0 1 0 r
F P
0 g
s
.23108 .52938 m .22039 .51651 L p .23135 .52473 L 1 0 0 r
F P
0 g
s
.22863 .52003 m .22931 .52077 L p .22962 .52138 L 1 0 0 r
F P
0 g
s
.23135 .52474 m .23133 .52471 L .22962 .52138 L 1 0 0 r
F
.23133 .52471 m .22863 .52003 L .22962 .52138 L F
.23 .52066 m .22966 .52071 L p .2292 .51824 L 0 1 0 r
F P
0 g
s
.22966 .52071 m .22931 .52077 L p .22927 .51995 L 0 1 0 r
F P
0 g
s
.22927 .51995 m .2292 .51824 L .22966 .52071 L 0 1 0 r
F
.23775 .51942 m .23314 .52917 L p .23177 .52505 L F P
0 g
s
.25688 .50558 m .24988 .5186 L .23775 .51942 L p 0 1 0 r
F P
0 g
s
.23775 .51942 m .24489 .50523 L .25688 .50558 L p 0 1 0 r
F P
0 g
s
.23135 .52473 m .23177 .52505 L .23167 .5257 L 1 0 0 r
F
.23135 .52473 m .23167 .5257 L .23108 .52938 L F
.22039 .51651 m .22863 .52003 L .23135 .52474 L F
.2256 .52871 m .22034 .52675 L .21013 .51145 L p F P
0 g
s
.21013 .51145 m .21514 .51465 L .2256 .52871 L p 1 0 0 r
F P
0 g
s
.21284 .53459 m .21921 .52689 L .2308 .53198 L p 0 0 1 r
F P
0 g
s
.23314 .52917 m .23108 .52938 L p .23177 .52505 L 1 0 0 r
F P
0 g
s
.22034 .52675 m .21532 .52345 L .20536 .50688 L p 1 0 0 r
F P
0 g
s
.20536 .50688 m .21013 .51145 L .22034 .52675 L p 1 0 0 r
F P
0 g
s
.2308 .53198 m .21921 .52689 L p .23176 .52506 L 0 0 1 r
F P
0 g
s
.23177 .52505 m .23178 .52506 L .23314 .52917 L 1 0 0 r
F
.23724 .52427 m .23371 .52849 L p .23182 .52517 L 0 0 1 r
F P
0 g
s
.23178 .52506 m .23724 .52427 L .23182 .52517 L 0 0 1 r
F
.23447 .53143 m .23448 .53143 L .23448 .53144 L 1 0 0 r
F
.23448 .53144 m .23374 .52845 L .23539 .53131 L 0 0 1 r
F
.23444 .53136 m .23448 .53143 L .23447 .53143 L 1 0 0 r
F
.23446 .53144 m .23314 .52917 L .23447 .53143 L 0 1 0 r
F
.23446 .53144 m .23445 .53138 L .23448 .53144 L 0 0 1 r
F
.23445 .53138 m .23374 .52845 L .23448 .53144 L F
.23313 .52918 m .23314 .52917 L p .23446 .53144 L 0 1 0 r
F P
0 g
s
.23313 .52918 m .23314 .52917 L p .23446 .53144 L 0 0 1 r
F P
0 g
s
.23314 .52917 m .23374 .52845 L p .23445 .53138 L 0 0 1 r
F P
0 g
s
.23314 .52917 m .23314 .52917 L p .23447 .53143 L 1 0 0 r
F P
0 g
s
.23314 .52917 m .23444 .53136 L .23447 .53143 L 1 0 0 r
F
.23314 .52917 m .23445 .53138 L .23446 .53144 L 0 0 1 r
F
.23314 .52917 m .23332 .52915 L p .23444 .53136 L 1 0 0 r
F P
0 g
s
.23374 .52845 m .23724 .52427 L p .23539 .53131 L 0 0 1 r
F P
0 g
s
.23332 .52915 m .23676 .5288 L p .23448 .53143 L 1 0 0 r
F P
0 g
s
.23332 .52915 m .23448 .53143 L .23444 .53136 L 1 0 0 r
F
.23676 .5288 m .23314 .52917 L p .23178 .52506 L F P
0 g
s
.23314 .52917 m .23314 .52917 L p .23178 .52506 L 1 0 0 r
F P
0 g
s
.23176 .52506 m .23178 .52506 L .23182 .52517 L 0 0 1 r
F
.23311 .52911 m .23177 .52505 L .23314 .52917 L 0 1 0 r
F
.23313 .52918 m .2308 .53198 L p .23176 .52506 L 0 0 1 r
F P
0 g
s
.23129 .5255 m .23176 .52506 L .23311 .52911 L 0 1 0 r
F
.23176 .52506 m .23177 .52505 L .23311 .52911 L F
.23371 .52849 m .23313 .52918 L p .23176 .52506 L 0 0 1 r
F P
0 g
s
.23135 .52474 m .22931 .52077 L .23178 .52506 L 1 0 0 r
F
.23176 .52506 m .22941 .52095 L .23177 .52505 L 0 1 0 r
F
.22931 .52077 m .22931 .52077 L p .22931 .52077 L 0 0 1 r
F P
0 g
s
.23177 .52505 m .22941 .52095 L .23775 .51942 L 0 1 0 r
F
.22931 .52077 m .23775 .51942 L p .22941 .52095 L F P
0 g
s
.22931 .52077 m .23724 .52427 L p .23176 .52506 L 0 0 1 r
F P
0 g
s
.24264 .52701 m .23676 .5288 L .22931 .52077 L p 1 0 0 r
F P
0 g
s
.21511 .50422 m .22059 .50465 L .22239 .50657 L p 1 0 0 r
F P
0 g
s
.23268 .50596 m .24489 .50523 L p .22921 .51822 L 0 1 0 r
F P
0 g
s
.22894 .51775 m .23268 .50596 L .22921 .51822 L 0 1 0 r
F
.22771 .51647 m .23268 .50596 L p .22863 .5187 L F P
0 g
s
.2292 .51824 m .24489 .50523 L .23 .52066 L 0 1 0 r
F
.2321 .51135 m .24373 .5165 L p .22966 .51856 L 0 0 1 r
F P
0 g
s
.22863 .5187 m .22894 .51775 L .22921 .51822 L 0 1 0 r
F
.22863 .51871 m .22771 .51647 L .22863 .5187 L F
.22931 .52077 m .22587 .51706 L p .22863 .5187 L 1 0 0 r
F P
0 g
s
.21514 .51465 m .21013 .51145 L .20011 .49494 L p 1 0 0 r
F P
0 g
s
.20011 .49494 m .20486 .4994 L .21514 .51465 L p 1 0 0 r
F P
0 g
s
.22039 .51651 m .21514 .51465 L .20486 .4994 L p 1 0 0 r
F P
0 g
s
.20486 .4994 m .20987 .50249 L .22039 .51651 L p 1 0 0 r
F P
0 g
s
.22587 .51706 m .22039 .51651 L .20987 .50249 L p 1 0 0 r
F P
0 g
s
.20987 .50249 m .21511 .50422 L .22587 .51706 L p 1 0 0 r
F P
0 g
s
.22587 .51706 m .21511 .50422 L p .22597 .51224 L 1 0 0 r
F P
0 g
s
.23268 .50596 m .22792 .51602 L p .22597 .51224 L 0 1 0 r
F P
0 g
s
.22792 .51602 m .22753 .51685 L p .22597 .51224 L 0 1 0 r
F P
0 g
s
.2169 .5153 m .21398 .51401 L p .21772 .51346 L 0 0 1 r
F P
0 g
s
.21772 .51346 m .22488 .51241 L .2169 .5153 L 0 0 1 r
F
.22563 .51915 m .2169 .5153 L p .22488 .51241 L F P
0 g
s
.22239 .50657 m .22316 .50739 L p .22329 .50765 L 1 0 0 r
F P
0 g
s
.2255 .51189 m .22546 .51182 L .22329 .50765 L 1 0 0 r
F
.22546 .51182 m .22239 .50657 L .22329 .50765 L F
.21511 .50422 m .22239 .50657 L .2255 .51189 L F
.22316 .50739 m .22316 .50739 L p .22316 .50739 L 0 0 1 r
F P
0 g
s
.22597 .51224 m .22325 .50755 L .22352 .5075 L 0 1 0 r
F
.2262 .51202 m .22352 .5075 L .23268 .50596 L F
.22597 .51224 m .22352 .5075 L .2262 .51202 L F
.22316 .50739 m .23268 .50596 L p .22325 .50755 L F P
0 g
s
.23986 .49168 m .23268 .50596 L .22316 .50739 L p 0 1 0 r
F P
0 g
s
.22316 .50739 m .22059 .50465 L p .22264 .50584 L 1 0 0 r
F P
0 g
s
.22264 .50584 m .22335 .50721 L .22316 .50739 L 0 1 0 r
F
.22316 .50739 m .22042 .50618 L p .22264 .50585 L 0 0 1 r
F P
0 g
s
.22312 .50728 m .22316 .50739 L .22316 .50739 L 0 1 0 r
F
.22264 .50584 m .22316 .50739 L .22312 .50728 L F
.25193 .49213 m .24489 .50523 L .23268 .50596 L p F P
0 g
s
.23268 .50596 m .23986 .49168 L .25193 .49213 L p 0 1 0 r
F P
0 g
s
.2386 .5035 m .2321 .51135 L .22374 .50765 L p 0 0 1 r
F P
0 g
s
.22353 .5073 m .2386 .5035 L .22374 .50765 L 0 0 1 r
F
.22264 .50584 m .22265 .50585 L .22267 .5059 L 1 0 0 r
F
.22264 .50584 m .22267 .5059 L .22316 .50739 L F
.22264 .50584 m .2233 .50531 L .22335 .50721 L 0 1 0 r
F
.2233 .50531 m .23986 .49168 L .22398 .50662 L F
.2233 .50531 m .22398 .50662 L .22335 .50721 L F
.20977 .49185 m .21682 .49381 L .21727 .49467 L 1 0 0 r
F
.20977 .49185 m .21525 .49215 L .21682 .49381 L p F P
0 g
s
.20435 .4794 m .21028 .48001 L .2108 .48097 L 1 0 0 r
F
.20435 .4794 m .20983 .47954 L .21028 .48001 L p F P
0 g
s
.2047 .46586 m .21718 .46439 L p .20857 .47225 L 0 1 0 r
F P
0 g
s
.22446 .44989 m .21718 .46439 L .20447 .46588 L p 0 1 0 r
F P
0 g
s
.20447 .46588 m .21192 .45012 L .22446 .44989 L p 0 1 0 r
F P
0 g
s
.20447 .46588 m .2047 .46586 L p .20774 .473 L 0 1 0 r
F P
0 g
s
.20774 .473 m .2047 .46586 L .20857 .47225 L 0 1 0 r
F
.20404 .46684 m .20407 .46677 L p .20774 .473 L F P
0 g
s
.20407 .46677 m .20447 .46588 L p .20768 .47287 L 0 1 0 r
F P
0 g
s
.20407 .46677 m .20768 .47287 L .20774 .473 L 0 1 0 r
F
.18807 .45307 m .19331 .45421 L .20361 .46599 L p 1 0 0 r
F P
0 g
s
.21028 .48001 m .2098 .4798 L p .21013 .47975 L 0 0 1 r
F P
0 g
s
.21396 .48622 m .21032 .48007 L .2224 .47844 L 0 1 0 r
F
.2224 .47844 m .23477 .47794 L p .2165 .49286 L F P
0 g
s
.23477 .47794 m .22756 .4923 L .21797 .49365 L p 0 1 0 r
F P
0 g
s
.21797 .49365 m .21699 .49379 L p .21766 .49307 L 0 1 0 r
F P
0 g
s
.21699 .49379 m .21682 .49381 L p .21694 .4937 L 0 1 0 r
F P
0 g
s
.21694 .4937 m .21766 .49307 L .21699 .49379 L 0 1 0 r
F
.22004 .49929 m .21689 .49392 L .22756 .4923 L F
.21682 .49381 m .21682 .49381 L p .21689 .49392 L 0 0 1 r
F P
0 g
s
.21682 .49381 m .21682 .49381 L p .21689 .49392 L 0 1 0 r
F P
0 g
s
.21682 .49381 m .22756 .4923 L p .21689 .49392 L 0 1 0 r
F P
0 g
s
.22756 .4923 m .23986 .49168 L p .22264 .50584 L 0 1 0 r
F P
0 g
s
.22195 .50419 m .22756 .4923 L p .22264 .50584 L 0 1 0 r
F P
0 g
s
.21398 .51401 m .22042 .50618 L .22316 .50739 L p 0 0 1 r
F P
0 g
s
.20086 .5009 m .20536 .50688 L .21532 .52345 L p 1 0 0 r
F P
0 g
s
.21013 .51145 m .20536 .50688 L .19563 .48906 L p 1 0 0 r
F P
0 g
s
.19563 .48906 m .20011 .49494 L .21013 .51145 L p 1 0 0 r
F P
0 g
s
.21511 .50422 m .20987 .50249 L .19953 .48729 L p 1 0 0 r
F P
0 g
s
.19953 .48729 m .20453 .49025 L .21511 .50422 L p 1 0 0 r
F P
0 g
s
.22059 .50465 m .21511 .50422 L .20453 .49025 L p 1 0 0 r
F P
0 g
s
.20453 .49025 m .20977 .49185 L .22059 .50465 L p 1 0 0 r
F P
0 g
s
.21565 .53064 m .21111 .52449 L .20177 .50522 L p 1 0 0 r
F P
0 g
s
.20177 .50522 m .20602 .51271 L .21565 .53064 L p 1 0 0 r
F P
0 g
s
.21054 .51878 m .20602 .51271 L .19663 .4935 L p 1 0 0 r
F P
0 g
s
.19663 .4935 m .20086 .5009 L .21054 .51878 L p 1 0 0 r
F P
0 g
s
.21532 .52345 m .21054 .51878 L .20086 .5009 L p 1 0 0 r
F P
0 g
s
.22042 .50618 m .21398 .51401 L .20227 .50884 L p 0 0 1 r
F P
0 g
s
.22059 .50465 m .20977 .49185 L p .22004 .49929 L 1 0 0 r
F P
0 g
s
.22756 .4923 m .22225 .50355 L p .22004 .49929 L 0 1 0 r
F P
0 g
s
.22225 .50355 m .22182 .50447 L p .22004 .49929 L 0 1 0 r
F P
0 g
s
.22005 .4993 m .21998 .49918 L .2269 .49829 L 0 0 1 r
F
.21998 .49918 m .21689 .49392 L .21839 .49458 L F
.21998 .49918 m .21839 .49458 L .2269 .49829 L F
.2269 .49829 m .22256 .50357 L p .22005 .4993 L F P
0 g
s
.22172 .50448 m .22182 .50447 L p .22247 .50574 L 1 0 0 r
F P
0 g
s
.22261 .50579 m .22195 .50419 L .22264 .50584 L 0 1 0 r
F
.22181 .50448 m .22195 .50419 L p .22264 .50585 L F P
0 g
s
.2269 .49829 m .2386 .5035 L p .22265 .50585 L 0 0 1 r
F P
0 g
s
.22182 .50447 m .22182 .50447 L p .22256 .5057 L 1 0 0 r
F P
0 g
s
.22182 .50447 m .22256 .5057 L .22256 .5057 L 1 0 0 r
F
.22182 .50447 m .22256 .5057 L .22247 .50574 L F
.22247 .50574 m .22257 .50569 L .22264 .50584 L F
.22264 .50585 m .22261 .50579 L .22264 .50584 L 0 1 0 r
F
.22264 .50584 m .22265 .50584 L .22265 .50585 L 1 0 0 r
F
.22059 .50465 m .22172 .50448 L p .22247 .50574 L F P
0 g
s
.22042 .50618 m .22182 .50447 L p .22265 .50585 L 0 0 1 r
F P
0 g
s
.22182 .50447 m .2269 .49829 L p .22265 .50585 L 0 0 1 r
F P
0 g
s
.22182 .50447 m .22628 .50381 L p .22256 .5057 L 1 0 0 r
F P
0 g
s
.22023 .50783 m .22181 .50448 L p .22264 .50585 L 0 1 0 r
F P
0 g
s
.22004 .49929 m .22005 .4993 L .22182 .50447 L 1 0 0 r
F
.22256 .50357 m .22182 .50447 L p .22005 .4993 L 0 0 1 r
F P
0 g
s
.22628 .50381 m .22182 .50447 L p .22005 .4993 L 1 0 0 r
F P
0 g
s
.22182 .50447 m .22182 .50447 L p .22005 .4993 L 1 0 0 r
F P
0 g
s
.22182 .50447 m .22181 .50448 L p .22005 .4993 L 0 0 1 r
F P
0 g
s
.22182 .50447 m .22059 .50465 L p .22004 .49929 L 1 0 0 r
F P
0 g
s
.22181 .50448 m .22042 .50618 L p .22018 .50177 L 0 0 1 r
F P
0 g
s
.22003 .49931 m .22004 .49929 L .22181 .50448 L 0 1 0 r
F
.22182 .50447 m .22181 .50448 L p .22004 .49929 L F P
0 g
s
.22005 .4993 m .22181 .50448 L .22018 .50177 L 0 0 1 r
F
.20987 .50249 m .20486 .4994 L .19479 .48295 L p 1 0 0 r
F P
0 g
s
.19479 .48295 m .19953 .48729 L .20987 .50249 L p 1 0 0 r
F P
0 g
s
.22042 .50618 m .20868 .50098 L p .22003 .49931 L 0 0 1 r
F P
0 g
s
.20977 .49185 m .21772 .49484 L .22004 .49929 L 1 0 0 r
F
.21682 .49381 m .21689 .49392 L .21734 .49469 L F
.22003 .49931 m .21689 .49392 L .22004 .49929 L 0 1 0 r
F
.22004 .49929 m .22 .49921 L .22005 .4993 L 1 0 0 r
F
.21727 .49467 m .21682 .49381 L .21734 .49469 L F
.20868 .50098 m .21682 .49381 L .22005 .4993 L 0 0 1 r
F
.21682 .49381 m .21682 .49381 L .21689 .49392 L 1 0 0 r
F
.20536 .50688 m .20086 .5009 L .19142 .48175 L p F P
0 g
s
.19142 .48175 m .19563 .48906 L .20536 .50688 L p 1 0 0 r
F P
0 g
s
.20227 .50884 m .20868 .50098 L .22042 .50618 L p 0 0 1 r
F P
0 g
s
.2075 .51095 m .21682 .49381 L .21689 .49392 L 0 1 0 r
F
.2075 .51095 m .21689 .49392 L .22003 .49931 L F
.22003 .49931 m .22005 .4993 L .22006 .49936 L 0 0 1 r
F
.22003 .49931 m .22006 .49936 L .22042 .50618 L F
.22005 .4993 m .21783 .49488 L .22021 .49941 L 1 0 0 r
F
.22 .49921 m .21783 .49488 L .22005 .4993 L F
.21772 .49484 m .21783 .49488 L .22004 .49929 L F
.22023 .50783 m .2075 .51095 L p .22003 .49931 L 0 1 0 r
F P
0 g
s
.22181 .50448 m .22023 .50783 L p .22003 .49931 L 0 1 0 r
F P
0 g
s
.21682 .49381 m .2269 .49829 L p .21689 .49392 L 0 0 1 r
F P
0 g
s
.24693 .4785 m .23986 .49168 L .22756 .4923 L p 0 1 0 r
F P
0 g
s
.22756 .4923 m .23477 .47794 L .24693 .4785 L p 0 1 0 r
F P
0 g
s
.23342 .49036 m .2269 .49829 L .21718 .49397 L p 0 0 1 r
F P
0 g
s
.21718 .49397 m .21682 .49381 L p .21705 .49376 L 0 0 1 r
F P
0 g
s
.21766 .49307 m .23477 .47794 L .21797 .49365 L 0 1 0 r
F
.21705 .49376 m .23342 .49036 L .21718 .49397 L 0 0 1 r
F
.21682 .49381 m .21525 .49215 L p .21652 .49289 L 1 0 0 r
F P
0 g
s
.21628 .49289 m .21649 .49286 L .21682 .49381 L 0 0 1 r
F
.21649 .49286 m .2165 .49286 L .2168 .49374 L 0 1 0 r
F
.2165 .49286 m .23477 .47794 L .21682 .49381 L F
.2168 .49374 m .21682 .49381 L .21682 .49381 L 0 0 1 r
F
.2168 .49374 m .21682 .49381 L .21682 .49381 L 0 1 0 r
F
.2165 .49286 m .21682 .49381 L .2168 .49374 L F
.2165 .49286 m .23342 .49036 L .21682 .49381 L 0 0 1 r
F
.2165 .49286 m .21682 .49381 L .2168 .49374 L F
.21651 .49289 m .2165 .49286 L .21652 .49289 L 1 0 0 r
F
.21649 .49286 m .2165 .49286 L .2168 .49374 L 0 0 1 r
F
.21649 .49286 m .2168 .49374 L .21682 .49381 L F
.21637 .49296 m .21649 .49286 L .21682 .49381 L 0 1 0 r
F
.21649 .49286 m .2168 .49374 L .21682 .49381 L F
.21525 .49215 m .2165 .49286 L .21651 .49289 L 1 0 0 r
F
.21697 .49397 m .21682 .49381 L p .21652 .49289 L F P
0 g
s
.24515 .4956 m .2386 .5035 L .2269 .49829 L p 0 0 1 r
F P
0 g
s
.2269 .49829 m .23342 .49036 L .24515 .4956 L p 0 0 1 r
F P
0 g
s
.2165 .49286 m .2165 .49286 L .2165 .49286 L 1 0 0 r
F
.22164 .48509 m .23342 .49036 L p .2165 .49286 L 0 0 1 r
F P
0 g
s
.20868 .50098 m .21514 .49306 L .21682 .49381 L p 0 0 1 r
F P
0 g
s
.20486 .4994 m .20011 .49494 L .19033 .47718 L p 1 0 0 r
F P
0 g
s
.19033 .47718 m .19479 .48295 L .20486 .4994 L p 1 0 0 r
F P
0 g
s
.20977 .49185 m .20453 .49025 L .19413 .47512 L p 1 0 0 r
F P
0 g
s
.19413 .47512 m .19911 .47794 L .20977 .49185 L p 1 0 0 r
F P
0 g
s
.21525 .49215 m .20977 .49185 L .19911 .47794 L p 1 0 0 r
F P
0 g
s
.19911 .47794 m .20435 .4794 L .21525 .49215 L p 1 0 0 r
F P
0 g
s
.21514 .49306 m .20868 .50098 L .1969 .49576 L p 0 0 1 r
F P
0 g
s
.21525 .49215 m .20435 .4794 L p .21396 .48622 L 1 0 0 r
F P
0 g
s
.2224 .47844 m .21647 .49099 L p .21396 .48622 L 0 1 0 r
F P
0 g
s
.21647 .49099 m .21599 .49202 L p .21396 .48622 L 0 1 0 r
F P
0 g
s
.21607 .49185 m .2224 .47844 L p .2165 .49286 L 0 1 0 r
F P
0 g
s
.21398 .48623 m .21032 .48007 L .22164 .48509 L 0 0 1 r
F
.22164 .48509 m .21682 .491 L p .21398 .48623 L F P
0 g
s
.21599 .49202 m .21607 .49185 L p .2165 .49286 L 0 1 0 r
F P
0 g
s
.21599 .49202 m .22164 .48509 L p .2165 .49286 L 0 0 1 r
F P
0 g
s
.22095 .49117 m .21599 .49202 L p .21396 .48622 L 1 0 0 r
F P
0 g
s
.21599 .49202 m .21525 .49215 L p .21396 .48622 L 1 0 0 r
F P
0 g
s
.21597 .49199 m .21396 .48622 L .21599 .49202 L 0 1 0 r
F
.21514 .49306 m .20333 .4878 L p .21395 .48623 L 0 0 1 r
F P
0 g
s
.21395 .48623 m .21401 .4864 L .21514 .49306 L 0 0 1 r
F
.21395 .48623 m .21396 .48622 L .21597 .49199 L 0 1 0 r
F
.21599 .49202 m .21599 .49202 L p .21597 .49199 L F P
0 g
s
.21682 .491 m .21599 .49202 L p .21398 .48623 L 0 0 1 r
F P
0 g
s
.21599 .49202 m .21514 .49306 L p .21401 .4864 L 0 0 1 r
F P
0 g
s
.21398 .48623 m .21599 .49202 L .21401 .4864 L 0 0 1 r
F
.21525 .49215 m .21599 .49202 L p .21639 .4928 L 1 0 0 r
F P
0 g
s
.21639 .4928 m .21599 .49202 L .2165 .49286 L 1 0 0 r
F
.21599 .49202 m .21599 .49202 L p .2165 .49286 L F P
0 g
s
.21649 .49286 m .21599 .49202 L .2165 .49286 L 0 1 0 r
F
.21599 .49202 m .21648 .49282 L .2165 .49286 L 1 0 0 r
F
.21649 .49286 m .21599 .49202 L .2165 .49286 L 0 0 1 r
F
.21514 .49306 m .21599 .49202 L p .21649 .49286 L F P
0 g
s
.21599 .49202 m .21599 .49202 L p .21649 .49286 L 0 1 0 r
F P
0 g
s
.21599 .49202 m .21599 .49202 L p .21649 .49286 L 0 0 1 r
F P
0 g
s
.21552 .493 m .21628 .49289 L .21634 .49299 L 0 0 1 r
F
.21552 .493 m .21634 .49299 L .21682 .49381 L F
.21682 .49381 m .21514 .49306 L p .21552 .493 L F P
0 g
s
.21502 .49406 m .21599 .49202 L p .21649 .49286 L 0 1 0 r
F P
0 g
s
.20011 .49494 m .19563 .48906 L .18614 .46998 L p 1 0 0 r
F P
0 g
s
.18614 .46998 m .19033 .47718 L .20011 .49494 L p 1 0 0 r
F P
0 g
s
.20453 .49025 m .19953 .48729 L .1894 .4709 L p 1 0 0 r
F P
0 g
s
.1894 .4709 m .19413 .47512 L .20453 .49025 L p 1 0 0 r
F P
0 g
s
.1969 .49576 m .20333 .4878 L .21514 .49306 L p 0 0 1 r
F P
0 g
s
.21329 .48683 m .21597 .49199 L .21502 .49406 L 0 1 0 r
F
.21599 .49202 m .21502 .49406 L p .21597 .49199 L F P
0 g
s
.21329 .48683 m .21395 .48623 L .21597 .49199 L 0 1 0 r
F
.21395 .48623 m .21398 .48623 L .21401 .4864 L 0 0 1 r
F
.21398 .48623 m .21133 .4811 L .21408 .48629 L 1 0 0 r
F
.21396 .48622 m .21391 .48611 L .21398 .48623 L F
.21391 .48611 m .21133 .4811 L .21398 .48623 L F
.20435 .4794 m .21127 .48109 L .21396 .48622 L F
.21127 .48109 m .21133 .4811 L .21396 .48622 L F
.21502 .49406 m .2022 .49705 L p .21329 .48683 L 0 1 0 r
F P
0 g
s
.21599 .49202 m .21605 .49201 L p .21648 .49282 L 1 0 0 r
F P
0 g
s
.22095 .49117 m .23218 .50176 L p .2165 .49286 L 1 0 0 r
F P
0 g
s
.2165 .49286 m .22095 .49117 L .2165 .49286 L 1 0 0 r
F
.21605 .49201 m .22095 .49117 L p .2165 .49286 L F P
0 g
s
.23218 .50176 m .22628 .50381 L .21697 .49397 L p 1 0 0 r
F P
0 g
s
.2165 .49286 m .23218 .50176 L .21697 .49397 L 1 0 0 r
F
.21028 .48001 m .21028 .48001 L p .21032 .48007 L 0 0 1 r
F P
0 g
s
.21028 .48001 m .21033 .48001 L p .21032 .48007 L 0 1 0 r
F P
0 g
s
.21033 .48001 m .2224 .47844 L p .21037 .48006 L 0 1 0 r
F P
0 g
s
.21032 .48007 m .21033 .48001 L .21037 .48006 L 0 1 0 r
F
.21028 .48001 m .22164 .48509 L p .21032 .48007 L 0 0 1 r
F P
0 g
s
.21718 .46439 m .22964 .46401 L p .21019 .47974 L 0 1 0 r
F P
0 g
s
.21019 .47974 m .21718 .46439 L .21019 .47974 L 0 1 0 r
F
.21004 .4795 m .21718 .46439 L p .21019 .47974 L F P
0 g
s
.22964 .46401 m .2224 .47844 L .21144 .47986 L p 0 1 0 r
F P
0 g
s
.21144 .47986 m .21028 .48001 L p .21114 .4793 L 0 1 0 r
F P
0 g
s
.21114 .4793 m .22964 .46401 L .21144 .47986 L 0 1 0 r
F
.21019 .47974 m .22964 .46401 L .21032 .47998 L F
.24187 .46469 m .23477 .47794 L .2224 .47844 L p F P
0 g
s
.2224 .47844 m .22964 .46401 L .24187 .46469 L p 0 1 0 r
F P
0 g
s
.21632 .47174 m .22818 .47706 L p .21019 .47974 L 0 0 1 r
F P
0 g
s
.21003 .4795 m .21004 .4795 L p .21016 .47972 L 1 0 0 r
F P
0 g
s
.21004 .4795 m .21011 .47961 L .21016 .47972 L 1 0 0 r
F
.21006 .4795 m .21018 .47972 L .21016 .47972 L F
.21004 .4795 m .21004 .4795 L p .21019 .47974 L 0 1 0 r
F P
0 g
s
.21004 .4795 m .21019 .47974 L .21019 .47974 L 0 1 0 r
F
.21016 .47972 m .21018 .47972 L .21019 .47974 L 1 0 0 r
F
.20983 .47954 m .21003 .4795 L p .21016 .47972 L F P
0 g
s
.21019 .47974 m .21032 .47998 L .21028 .48001 L 0 1 0 r
F
.20983 .47954 m .21019 .47974 L .2102 .47975 L 1 0 0 r
F
.21027 .47998 m .21028 .48001 L .21028 .48001 L 0 0 1 r
F
.21027 .47998 m .21028 .48001 L .21028 .48001 L 0 1 0 r
F
.21019 .47974 m .21028 .48001 L .21027 .47998 L F
.21027 .47998 m .21035 .48 L .21028 .48001 L 0 0 1 r
F
.21028 .48001 m .20983 .47954 L p .2102 .47975 L 1 0 0 r
F P
0 g
s
.21019 .47974 m .21027 .47998 L .21028 .48001 L 0 0 1 r
F
.21013 .47975 m .21019 .47974 L .21028 .48001 L F
.21015 .47977 m .21019 .47974 L .21028 .48001 L 0 1 0 r
F
.21019 .47974 m .2102 .47975 L .21027 .47998 L 0 0 1 r
F
.2102 .47975 m .21035 .48 L .21027 .47998 L F
.21019 .47974 m .21019 .47974 L .2102 .47975 L 1 0 0 r
F
.21019 .47974 m .21019 .47974 L .21035 .48 L 0 0 1 r
F
.21019 .47974 m .22818 .47706 L .21035 .48 L F
.21019 .47974 m .21035 .48 L .21035 .48 L F
.22818 .47706 m .22164 .48509 L .21028 .48001 L p F P
0 g
s
.23999 .48237 m .23342 .49036 L .22164 .48509 L p 0 0 1 r
F P
0 g
s
.22164 .48509 m .22818 .47706 L .23999 .48237 L p 0 0 1 r
F P
0 g
s
.21554 .47841 m .22685 .48897 L p .21019 .47974 L 1 0 0 r
F P
0 g
s
.2102 .47975 m .22685 .48897 L .21033 .48006 L 1 0 0 r
F
.21019 .47974 m .22685 .48897 L .2102 .47975 L F
.21033 .48006 m .21028 .48001 L p .2102 .47975 L F P
0 g
s
.21019 .47974 m .21019 .47974 L .21019 .47974 L 0 1 0 r
F
.2098 .4798 m .21004 .4795 L p .21019 .47974 L 0 0 1 r
F P
0 g
s
.21004 .4795 m .21632 .47174 L p .21019 .47974 L 0 0 1 r
F P
0 g
s
.21004 .4795 m .21006 .4795 L p .21011 .47961 L 1 0 0 r
F P
0 g
s
.21006 .4795 m .21554 .47841 L p .21018 .47972 L 1 0 0 r
F P
0 g
s
.21018 .47972 m .21554 .47841 L .21019 .47974 L 1 0 0 r
F
.21028 .48001 m .21028 .48001 L p .21032 .48007 L 0 1 0 r
F P
0 g
s
.22685 .48897 m .22095 .49117 L .21033 .48006 L p 1 0 0 r
F P
0 g
s
.20977 .48008 m .21004 .4795 L p .21019 .47974 L 0 1 0 r
F P
0 g
s
.20333 .4878 m .2098 .4798 L .21028 .48001 L p 0 0 1 r
F P
0 g
s
.20435 .4794 m .19911 .47794 L .18865 .46287 L p 1 0 0 r
F P
0 g
s
.18865 .46287 m .19363 .46555 L .20435 .4794 L p 1 0 0 r
F P
0 g
s
.20983 .47954 m .20435 .4794 L .19363 .46555 L p 1 0 0 r
F P
0 g
s
.19363 .46555 m .19887 .46685 L .20983 .47954 L p 1 0 0 r
F P
0 g
s
.19479 .48295 m .19033 .47718 L .18079 .45818 L p 1 0 0 r
F P
0 g
s
.18079 .45818 m .18495 .46526 L .19479 .48295 L p 1 0 0 r
F P
0 g
s
.19953 .48729 m .19479 .48295 L .18495 .46526 L p 1 0 0 r
F P
0 g
s
.18495 .46526 m .1894 .4709 L .19953 .48729 L p 1 0 0 r
F P
0 g
s
.2098 .4798 m .20333 .4878 L .19147 .48253 L p 0 0 1 r
F P
0 g
s
.19911 .47794 m .19413 .47512 L .18393 .4588 L p 1 0 0 r
F P
0 g
s
.18393 .4588 m .18865 .46287 L .19911 .47794 L p 1 0 0 r
F P
0 g
s
.19147 .48253 m .19792 .47448 L .2098 .4798 L p 0 0 1 r
F P
0 g
s
.20983 .47954 m .19887 .46685 L p .20774 .473 L 1 0 0 r
F P
0 g
s
.21718 .46439 m .21059 .47835 L p .20774 .473 L 0 1 0 r
F P
0 g
s
.21059 .47835 m .21004 .4795 L p .20774 .473 L 0 1 0 r
F P
0 g
s
.20409 .46678 m .20441 .46638 L p .20777 .47301 L 0 0 1 r
F P
0 g
s
.21632 .47174 m .21097 .47836 L p .20776 .47301 L 0 0 1 r
F P
0 g
s
.20774 .473 m .20776 .47301 L .21004 .4795 L 1 0 0 r
F
.21097 .47836 m .21004 .4795 L p .20776 .47301 L 0 0 1 r
F P
0 g
s
.21554 .47841 m .21004 .4795 L p .20776 .47301 L 1 0 0 r
F P
0 g
s
.21004 .4795 m .21004 .4795 L p .20776 .47301 L 1 0 0 r
F P
0 g
s
.21004 .4795 m .20983 .47954 L p .20774 .473 L 1 0 0 r
F P
0 g
s
.20773 .47302 m .20774 .473 L .21004 .4795 L 0 1 0 r
F
.21004 .4795 m .21004 .4795 L p .20774 .473 L F P
0 g
s
.21004 .4795 m .2098 .4798 L p .20776 .47301 L 0 0 1 r
F P
0 g
s
.19887 .46685 m .2042 .46709 L .20774 .473 L 1 0 0 r
F
.20776 .47301 m .20409 .46678 L .20777 .47301 L 0 0 1 r
F
.20405 .46684 m .20409 .46678 L p .20776 .47301 L F P
0 g
s
.2042 .46709 m .20461 .46711 L .20768 .47288 L 1 0 0 r
F
.2042 .46709 m .20768 .47288 L .20774 .473 L F
.20773 .47302 m .20404 .46684 L .20774 .473 L 0 1 0 r
F
.20404 .46684 m .20404 .46684 L p .20773 .47302 L F P
0 g
s
.20774 .473 m .20768 .47288 L .20776 .47301 L 1 0 0 r
F
.20418 .46709 m .20404 .46684 L .2042 .46709 L F
.19887 .46685 m .20402 .46684 L p .20415 .46709 L F P
0 g
s
.18807 .45307 m .20361 .46599 L .20386 .46641 L 1 0 0 r
F
.20387 .46643 m .20386 .46641 L .20387 .46643 L F
.18807 .45307 m .20386 .46641 L .20387 .46643 L F
.1894 .4709 m .18495 .46526 L .17536 .44634 L p F P
0 g
s
.17536 .44634 m .1795 .4533 L .1894 .4709 L p 1 0 0 r
F P
0 g
s
.19413 .47512 m .1894 .4709 L .1795 .4533 L p 1 0 0 r
F P
0 g
s
.1795 .4533 m .18393 .4588 L .19413 .47512 L p 1 0 0 r
F P
0 g
s
.19363 .46555 m .18865 .46287 L .17839 .44664 L p 1 0 0 r
F P
0 g
s
.17839 .44664 m .18309 .45056 L .19363 .46555 L p 1 0 0 r
F P
0 g
s
.19887 .46685 m .19363 .46555 L .18309 .45056 L p 1 0 0 r
F P
0 g
s
.18309 .45056 m .18807 .45307 L .19887 .46685 L p 1 0 0 r
F P
0 g
s
.19887 .46685 m .18807 .45307 L p .20391 .46646 L 1 0 0 r
F P
0 g
s
.20391 .46646 m .20391 .46646 L .19887 .46685 L 1 0 0 r
F
.20405 .46684 m .19887 .46685 L p .20391 .46646 L F P
0 g
s
.20382 .46647 m .20367 .46605 L .20382 .46647 L 0 0 1 r
F
.18597 .46914 m .20367 .46605 L .20382 .46647 L F
.20367 .46605 m .20367 .46605 L .20382 .46647 L F
.19147 .48253 m .18506 .49051 L .17317 .48525 L p F P
0 g
s
.17317 .48525 m .17955 .47722 L .19147 .48253 L p 0 0 1 r
F P
0 g
s
.19792 .47448 m .19147 .48253 L .17955 .47722 L p 0 0 1 r
F P
0 g
s
.17955 .47722 m .18597 .46914 L .19792 .47448 L p 0 0 1 r
F P
0 g
s
.19792 .47448 m .18597 .46914 L p .2039 .46646 L 0 0 1 r
F P
0 g
s
.20404 .46682 m .20391 .46646 L .20404 .46684 L 0 1 0 r
F
.2039 .46646 m .20391 .46646 L .20404 .46682 L F
.20407 .46677 m .20404 .46684 L p .20391 .46646 L F P
0 g
s
.20409 .46678 m .20404 .46684 L p .2039 .46646 L 0 0 1 r
F P
0 g
s
.20404 .46684 m .19792 .47448 L p .2039 .46646 L 0 0 1 r
F P
0 g
s
.20387 .4665 m .2039 .46646 L .20404 .46682 L 0 1 0 r
F
.20447 .46588 m .20407 .46677 L p .20391 .46646 L F P
0 g
s
.20441 .46638 m .20409 .46678 L p .2039 .46646 L 0 0 1 r
F P
0 g
s
.20391 .46646 m .2039 .46645 L .20435 .46684 L 1 0 0 r
F
.20369 .46608 m .20373 .46604 L .2039 .46645 L 0 1 0 r
F
.20369 .46608 m .2039 .46645 L .2037 .4661 L F
.20387 .46643 m .20367 .46605 L .2037 .4661 L 1 0 0 r
F
.20391 .46646 m .2037 .4661 L .20391 .46646 L F
.20387 .46643 m .2037 .4661 L .20391 .46646 L F
.20361 .46599 m .20367 .46605 L p .20369 .4661 L F P
0 g
s
.20387 .46643 m .20386 .46641 L .20369 .4661 L 1 0 0 r
F
.20386 .46641 m .20361 .46599 L .20369 .4661 L F
.20367 .46605 m .20373 .46604 L p .20369 .46608 L 0 1 0 r
F P
0 g
s
.20373 .46604 m .20447 .46588 L p .20391 .46646 L 0 1 0 r
F P
0 g
s
.21192 .45012 m .20447 .46588 L .20367 .46605 L p 0 1 0 r
F P
0 g
s
.21095 .45823 m .20501 .46564 L p .20463 .46502 L 0 0 1 r
F P
0 g
s
.20367 .46605 m .19331 .45421 L p .20137 .45966 L 1 0 0 r
F P
0 g
s
.20137 .45966 m .21192 .45012 L .20363 .46596 L 0 1 0 r
F
.20137 .45966 m .20138 .45967 L .20363 .46596 L 1 0 0 r
F
.20137 .45966 m .20363 .46596 L .20367 .46605 L F
.20363 .46596 m .21192 .45012 L .20364 .46599 L 0 1 0 r
F
.20135 .45967 m .20137 .45966 L .20363 .46596 L F
.20007 .45986 m .20135 .45967 L .20367 .46605 L 0 0 1 r
F
.20364 .46599 m .21192 .45012 L .20367 .46605 L 0 1 0 r
F
.20135 .45967 m .21095 .45823 L .20367 .46605 L 0 0 1 r
F
.20059 .46036 m .20135 .45967 L .20364 .466 L 0 1 0 r
F
.20135 .45967 m .20364 .46599 L .20364 .466 L F
.23677 .45069 m .22964 .46401 L .21718 .46439 L p F P
0 g
s
.22289 .46362 m .21632 .47174 L .20585 .46703 L p 0 0 1 r
F P
0 g
s
.20585 .46703 m .20441 .46638 L p .20537 .46624 L 0 0 1 r
F P
0 g
s
.20537 .46624 m .22289 .46362 L .20585 .46703 L 0 0 1 r
F
.19912 .45148 m .21192 .45012 L p .20137 .45966 L 0 1 0 r
F P
0 g
s
.20067 .45919 m .20006 .45751 L .20137 .45966 L 1 0 0 r
F
.20367 .46605 m .19244 .46101 L p .20007 .45986 L 0 0 1 r
F P
0 g
s
.18597 .46914 m .19244 .46101 L .20367 .46605 L p 0 0 1 r
F P
0 g
s
.19797 .45405 m .19805 .45387 L p .20137 .45966 L 0 1 0 r
F P
0 g
s
.19805 .45387 m .19912 .45148 L p .20125 .45923 L 0 1 0 r
F P
0 g
s
.19805 .45387 m .20125 .45923 L .20137 .45966 L 0 1 0 r
F
.18244 .4405 m .18768 .44147 L .19676 .45173 L p 1 0 0 r
F P
0 g
s
.19895 .45282 m .21095 .45823 L p .20154 .45964 L 0 0 1 r
F P
0 g
s
.19758 .45407 m .19797 .45405 L p .20067 .45919 L 1 0 0 r
F P
0 g
s
.19797 .45405 m .19797 .45405 L p .19815 .45439 L 1 0 0 r
F P
0 g
s
.19797 .45405 m .19815 .45439 L .20067 .45919 L 1 0 0 r
F
.19797 .45405 m .20005 .45748 L .20067 .45919 L F
.20135 .45967 m .19797 .45405 L .20137 .45966 L 0 1 0 r
F
.19797 .45406 m .19797 .45405 L p .20135 .45967 L F P
0 g
s
.20137 .45966 m .20005 .45748 L .20138 .45967 L 1 0 0 r
F
.20006 .45751 m .20005 .45748 L .20137 .45966 L F
.19331 .45421 m .19758 .45407 L p .20067 .45919 L F P
0 g
s
.20011 .45986 m .19797 .45405 L .20138 .45967 L 0 0 1 r
F
.19244 .46101 m .19797 .45406 L p .20011 .45986 L F P
0 g
s
.19797 .45406 m .19797 .45405 L p .20011 .45986 L 0 0 1 r
F P
0 g
s
.20661 .43566 m .19912 .45148 L .19784 .45173 L p 0 1 0 r
F P
0 g
s
.19752 .45114 m .20661 .43566 L .19784 .45173 L 0 1 0 r
F
.19331 .45421 m .18244 .4405 L p .19749 .45294 L 1 0 0 r
F P
0 g
s
.19709 .45187 m .19692 .45191 L p .19495 .44607 L 0 1 0 r
F P
0 g
s
.21923 .43557 m .21192 .45012 L .19912 .45148 L p 0 1 0 r
F P
0 g
s
.19912 .45148 m .20661 .43566 L .21923 .43557 L p 0 1 0 r
F P
0 g
s
.20551 .44457 m .19895 .45282 L .19891 .4528 L p 0 0 1 r
F P
0 g
s
.19912 .45148 m .19797 .45405 L p .19759 .45302 L 0 1 0 r
F P
0 g
s
.19676 .45173 m .19692 .4519 L p .19697 .45198 L 1 0 0 r
F P
0 g
s
.19749 .45294 m .19746 .45289 L .19697 .45198 L 1 0 0 r
F
.19746 .45289 m .19676 .45173 L .19697 .45198 L F
.19749 .45294 m .19759 .45302 L .19752 .45304 L F
.19749 .45294 m .19752 .45304 L .19331 .45421 L F
.19797 .45405 m .19331 .45421 L p .19759 .45302 L F P
0 g
s
.18244 .4405 m .19676 .45173 L .19749 .45294 L 1 0 0 r
F
.18865 .46287 m .18393 .4588 L .17397 .44128 L p F P
0 g
s
.17397 .44128 m .17839 .44664 L .18865 .46287 L p 1 0 0 r
F P
0 g
s
.19331 .45421 m .18807 .45307 L .17747 .43816 L p 1 0 0 r
F P
0 g
s
.17747 .43816 m .18244 .4405 L .19331 .45421 L p 1 0 0 r
F P
0 g
s
.18597 .46914 m .17955 .47722 L .16758 .4719 L p 0 0 1 r
F P
0 g
s
.16758 .4719 m .17398 .46378 L .18597 .46914 L p 0 0 1 r
F P
0 g
s
.19244 .46101 m .18597 .46914 L .17398 .46378 L p 0 0 1 r
F P
0 g
s
.18393 .4588 m .1795 .4533 L .16985 .43446 L p 1 0 0 r
F P
0 g
s
.16985 .43446 m .17397 .44128 L .18393 .4588 L p 1 0 0 r
F P
0 g
s
.17398 .46378 m .18042 .45561 L .19244 .46101 L p 0 0 1 r
F P
0 g
s
.19244 .46101 m .18042 .45561 L p .19758 .45303 L 0 0 1 r
F P
0 g
s
.19759 .45302 m .19759 .45302 L .19797 .45405 L 1 0 0 r
F
.19895 .45282 m .1981 .4539 L p .19761 .45306 L 0 0 1 r
F P
0 g
s
.1988 .45402 m .19797 .45405 L p .19759 .45302 L 1 0 0 r
F P
0 g
s
.19797 .45405 m .19797 .45405 L p .19759 .45302 L 1 0 0 r
F P
0 g
s
.19795 .45402 m .19759 .45302 L .19797 .45405 L 0 1 0 r
F
.19797 .45406 m .19244 .46101 L p .19758 .45303 L 0 0 1 r
F P
0 g
s
.19748 .45313 m .19758 .45303 L .19795 .45402 L 0 1 0 r
F
.19758 .45303 m .19759 .45302 L .19795 .45402 L F
.19797 .45405 m .19797 .45406 L p .19795 .45402 L F P
0 g
s
.1981 .4539 m .19797 .45406 L p .19758 .45303 L 0 0 1 r
F P
0 g
s
.19758 .45303 m .19759 .45302 L .19761 .45306 L 0 0 1 r
F
.19759 .45302 m .19895 .45282 L .19761 .45306 L F
.19749 .45294 m .19692 .4519 L .19759 .45302 L 1 0 0 r
F
.19758 .45303 m .19698 .452 L .19759 .45302 L 0 1 0 r
F
.18807 .45307 m .18309 .45056 L .17277 .43441 L p 1 0 0 r
F P
0 g
s
.17277 .43441 m .17747 .43816 L .18807 .45307 L p 1 0 0 r
F P
0 g
s
.19759 .45302 m .19698 .452 L .19912 .45148 L 0 1 0 r
F
.19692 .45191 m .19895 .45282 L p .19758 .45303 L 0 0 1 r
F P
0 g
s
.19692 .45191 m .19912 .45148 L p .19698 .452 L 0 1 0 r
F P
0 g
s
.19844 .45203 m .19945 .45212 L .19891 .4528 L 0 0 1 r
F
.19786 .4511 m .19945 .45212 L .19844 .45203 L F
.19786 .4511 m .20551 .44457 L .19945 .45212 L F
.19784 .45173 m .19709 .45187 L p .19752 .45114 L 0 1 0 r
F P
0 g
s
.19891 .4528 m .19692 .45191 L p .19786 .4511 L 0 0 1 r
F P
0 g
s
.1981 .45389 m .19895 .45282 L p .20154 .45964 L 0 0 1 r
F P
0 g
s
.21753 .45002 m .21095 .45823 L .19895 .45282 L p 0 0 1 r
F P
0 g
s
.23162 .43652 m .22446 .44989 L .21192 .45012 L p 0 1 0 r
F P
0 g
s
.21192 .45012 m .21923 .43557 L .23162 .43652 L p 0 1 0 r
F P
0 g
s
.19895 .45282 m .20551 .44457 L .21753 .45002 L p 0 0 1 r
F P
0 g
s
.20452 .45255 m .1988 .45402 L .19692 .4519 L p 1 0 0 r
F P
0 g
s
.19692 .4519 m .18768 .44147 L p .19483 .44617 L 1 0 0 r
F P
0 g
s
.19483 .44617 m .19687 .45175 L .19692 .4519 L 1 0 0 r
F
.19692 .45191 m .1869 .44738 L p .19481 .44619 L 0 0 1 r
F P
0 g
s
.19481 .44619 m .19483 .44617 L .19687 .45175 L 0 1 0 r
F
.19483 .44617 m .19495 .44607 L .19692 .45191 L F
.19483 .44617 m .19485 .44618 L .19687 .45175 L 1 0 0 r
F
.18768 .44147 m .19178 .44119 L p .19426 .4458 L F P
0 g
s
.19426 .4458 m .19178 .44119 L .19483 .44617 L 1 0 0 r
F
.19371 .44636 m .19177 .4412 L .19481 .44619 L 0 0 1 r
F
.1869 .44738 m .19177 .4412 L p .19371 .44636 L F P
0 g
s
.18042 .45561 m .1869 .44738 L .19692 .4519 L p 0 0 1 r
F P
0 g
s
.20124 .42099 m .19372 .43685 L .19078 .43739 L p 0 1 0 r
F P
0 g
s
.19057 .43702 m .20124 .42099 L .19078 .43739 L 0 1 0 r
F
.18768 .44147 m .17673 .42784 L p .19095 .43931 L 1 0 0 r
F P
0 g
s
.18244 .4405 m .17747 .43816 L .16707 .42211 L p 1 0 0 r
F P
0 g
s
.16707 .42211 m .17176 .42568 L .18244 .4405 L p 1 0 0 r
F P
0 g
s
.18768 .44147 m .18244 .4405 L .17176 .42568 L p 1 0 0 r
F P
0 g
s
.17176 .42568 m .17673 .42784 L .18768 .44147 L p 1 0 0 r
F P
0 g
s
.19026 .43748 m .18997 .43753 L p .18834 .43236 L 0 1 0 r
F P
0 g
s
.19372 .43685 m .19191 .44089 L p .19112 .43944 L 0 1 0 r
F P
0 g
s
.19191 .44089 m .19178 .44119 L p .19112 .43944 L 0 1 0 r
F P
0 g
s
.17673 .42784 m .18997 .43753 L .19095 .43931 L 1 0 0 r
F
.19177 .4412 m .19372 .43685 L p .19481 .44619 L 0 1 0 r
F P
0 g
s
.18997 .43753 m .19372 .43685 L p .19112 .43944 L 0 1 0 r
F P
0 g
s
.19095 .43931 m .19024 .43783 L .19112 .43944 L 1 0 0 r
F
.19111 .43945 m .19006 .43767 L .19112 .43944 L 0 1 0 r
F
.19006 .43767 m .18997 .43753 L .19112 .43944 L F
.19113 .43945 m .19006 .43767 L .19343 .4391 L 0 0 1 r
F
.19006 .43767 m .18997 .43753 L .19059 .43855 L 1 0 0 r
F
.18997 .43753 m .18997 .43753 L p .19006 .43767 L 0 0 1 r
F P
0 g
s
.18998 .43754 m .18997 .43753 L .19006 .43767 L 1 0 0 r
F
.18997 .43753 m .19343 .4391 L p .19006 .43767 L 0 0 1 r
F P
0 g
s
.17839 .44664 m .17397 .44128 L .16427 .42255 L p 1 0 0 r
F P
0 g
s
.16427 .42255 m .16837 .42921 L .17839 .44664 L p 1 0 0 r
F P
0 g
s
.18309 .45056 m .17839 .44664 L .16837 .42921 L p 1 0 0 r
F P
0 g
s
.16837 .42921 m .17277 .43441 L .18309 .45056 L p 1 0 0 r
F P
0 g
s
.1748 .44192 m .1813 .4336 L .18997 .43753 L p 0 0 1 r
F P
0 g
s
.18997 .43753 m .18998 .43754 L .19095 .43931 L 1 0 0 r
F
.19095 .43931 m .18998 .43754 L .19006 .43767 L F
.19059 .43856 m .19006 .43767 L .19059 .43855 L F
.19095 .43931 m .19006 .43767 L .19059 .43856 L F
.1748 .44192 m .18997 .43753 L .19006 .43767 L 0 0 1 r
F
.19111 .43945 m .19006 .43767 L .19113 .43945 L F
.19095 .43931 m .19112 .43944 L .19102 .4395 L 1 0 0 r
F
.19095 .43931 m .19102 .4395 L .18768 .44147 L F
.1748 .44192 m .19006 .43767 L .19111 .43945 L 0 0 1 r
F
.18997 .43753 m .18997 .43753 L .18998 .43754 L 1 0 0 r
F
.19178 .44119 m .18768 .44147 L p .19112 .43944 L F P
0 g
s
.18042 .45561 m .17398 .46378 L .16193 .45839 L p 0 0 1 r
F P
0 g
s
.16193 .45839 m .16834 .45019 L .18042 .45561 L p 0 0 1 r
F P
0 g
s
.1869 .44738 m .18042 .45561 L .16834 .45019 L p 0 0 1 r
F P
0 g
s
.16834 .45019 m .1748 .44192 L .1869 .44738 L p 0 0 1 r
F P
0 g
s
.19175 .44114 m .19112 .43944 L .19178 .44119 L 0 1 0 r
F
.1869 .44738 m .1748 .44192 L p .19111 .43945 L 0 0 1 r
F P
0 g
s
.19111 .43945 m .19112 .43946 L .1869 .44738 L 0 0 1 r
F
.19111 .43945 m .19112 .43944 L .19175 .44114 L 0 1 0 r
F
.19178 .44119 m .19177 .4412 L p .19175 .44114 L F P
0 g
s
.19201 .44091 m .1869 .44738 L p .19113 .43945 L 0 0 1 r
F P
0 g
s
.19094 .43963 m .19111 .43945 L .19175 .44114 L 0 1 0 r
F
.19111 .43945 m .19113 .43945 L .19112 .43946 L 0 0 1 r
F
.19343 .4391 m .19201 .44091 L p .19113 .43945 L F P
0 g
s
.19178 .44119 m .19178 .44119 L p .19483 .44617 L 1 0 0 r
F P
0 g
s
.19182 .44125 m .19259 .44017 L .19476 .44605 L 0 0 1 r
F
.19178 .44119 m .19212 .44117 L p .19476 .44605 L 1 0 0 r
F P
0 g
s
.19178 .44119 m .19476 .44605 L .19483 .44617 L 1 0 0 r
F
.19181 .44126 m .19182 .44125 L .19481 .44619 L 0 0 1 r
F
.19182 .44125 m .19476 .44605 L .19481 .44619 L F
.19177 .4412 m .19178 .44119 L p .19181 .44126 L F P
0 g
s
.19178 .44119 m .19259 .44017 L p .19181 .44126 L 0 0 1 r
F P
0 g
s
.19112 .43944 m .19113 .43945 L .19178 .44119 L 1 0 0 r
F
.19259 .44017 m .19343 .4391 L p .1948 .44611 L 0 0 1 r
F P
0 g
s
.19476 .44605 m .1948 .44611 L .19481 .44619 L 0 0 1 r
F
.19259 .44017 m .1948 .44611 L .19476 .44605 L F
.19476 .44605 m .19482 .44614 L .19483 .44617 L 1 0 0 r
F
.19372 .43685 m .20661 .43566 L p .19483 .44617 L 0 1 0 r
F P
0 g
s
.19481 .44619 m .19481 .44614 L .19483 .44617 L 0 1 0 r
F
.19481 .44614 m .19372 .43685 L .19483 .44617 L F
.19483 .44617 m .19482 .44614 L .19485 .44618 L 1 0 0 r
F
.19692 .45188 m .19495 .44607 L .19692 .45191 L 0 1 0 r
F
.19495 .44607 m .20661 .43566 L .19709 .45187 L F
.19343 .4391 m .20551 .44457 L p .19485 .44618 L 0 0 1 r
F P
0 g
s
.19481 .44619 m .1948 .44611 L .19485 .44618 L 0 0 1 r
F
.1948 .44611 m .19343 .4391 L .19485 .44618 L F
.19212 .44117 m .19317 .4411 L p .19482 .44614 L 1 0 0 r
F P
0 g
s
.19212 .44117 m .19482 .44614 L .19476 .44605 L 1 0 0 r
F
.19317 .4411 m .19178 .44119 L p .19113 .43945 L F P
0 g
s
.19178 .44119 m .19178 .44119 L p .19113 .43945 L 1 0 0 r
F P
0 g
s
.19024 .43783 m .19317 .4411 L p .19113 .43945 L 1 0 0 r
F P
0 g
s
.19112 .43944 m .19109 .43939 L .19113 .43945 L 1 0 0 r
F
.19109 .43939 m .19024 .43783 L .19113 .43945 L F
.17261 .45789 m .18997 .43753 L .19111 .43945 L 0 1 0 r
F
.18997 .43753 m .18997 .43753 L .19006 .43767 L F
.18997 .43753 m .19006 .43767 L .19111 .43945 L F
.21395 .42106 m .20661 .43566 L .19372 .43685 L p F P
0 g
s
.19372 .43685 m .20124 .42099 L .21395 .42106 L p 0 1 0 r
F P
0 g
s
.20001 .43076 m .19399 .43839 L p .19209 .43798 L 0 0 1 r
F P
0 g
s
.19399 .43839 m .19343 .4391 L p .19209 .43798 L 0 0 1 r
F P
0 g
s
.19343 .4391 m .19172 .43832 L p .19209 .43798 L 0 0 1 r
F P
0 g
s
.19078 .43739 m .19026 .43748 L p .19057 .43702 L 0 1 0 r
F P
0 g
s
.19172 .43832 m .18997 .43753 L p .19086 .43694 L 0 0 1 r
F P
0 g
s
.19086 .43694 m .20001 .43076 L .19172 .43832 L 0 0 1 r
F
.21211 .43627 m .20551 .44457 L .19343 .4391 L p F P
0 g
s
.22642 .42215 m .21923 .43557 L .20661 .43566 L p 0 1 0 r
F P
0 g
s
.20661 .43566 m .21395 .42106 L .22642 .42215 L p 0 1 0 r
F P
0 g
s
.19343 .4391 m .20001 .43076 L .21211 .43627 L p 0 0 1 r
F P
0 g
s
.19891 .43944 m .19317 .4411 L .18997 .43753 L p 1 0 0 r
F P
0 g
s
.18997 .43752 m .18834 .43236 L .18997 .43753 L 0 1 0 r
F
.18197 .42862 m .18761 .43222 L .18997 .43753 L 1 0 0 r
F
.18761 .43222 m .18813 .43255 L .18997 .43753 L F
.18813 .43255 m .18991 .43735 L .18997 .43753 L F
.18997 .43753 m .18811 .43257 L .18991 .43735 L 0 0 1 r
F
.18997 .43753 m .18997 .43753 L p .18991 .43735 L F P
0 g
s
.18997 .43753 m .18997 .43753 L .18997 .43753 L 1 0 0 r
F
.18813 .43255 m .18834 .43236 L .18997 .43753 L 0 1 0 r
F
.18813 .43255 m .18813 .43253 L .18814 .43256 L 1 0 0 r
F
.18827 .42202 m .20124 .42099 L p .18813 .43255 L 0 1 0 r
F P
0 g
s
.18764 .43224 m .18547 .42826 L .18813 .43255 L 1 0 0 r
F
.18197 .42862 m .18547 .42826 L p .18764 .43224 L F P
0 g
s
.18811 .43257 m .18547 .42826 L .18813 .43255 L 0 1 0 r
F
.18716 .43271 m .18671 .43029 L .18811 .43257 L 0 0 1 r
F
.18997 .43753 m .18197 .42862 L p .18997 .43753 L 1 0 0 r
F P
0 g
s
.17673 .42784 m .18197 .42862 L .18997 .43753 L p 1 0 0 r
F P
0 g
s
.1813 .4336 m .18546 .42827 L p .18716 .43271 L 0 0 1 r
F P
0 g
s
.18546 .42827 m .18547 .42826 L p .18811 .43257 L 0 1 0 r
F P
0 g
s
.18547 .42826 m .18566 .42783 L p .18813 .43255 L 0 1 0 r
F P
0 g
s
.18566 .42783 m .18827 .42202 L p .18814 .43188 L 0 1 0 r
F P
0 g
s
.18566 .42783 m .18814 .43188 L .18813 .43255 L 0 1 0 r
F
.17094 .41508 m .17619 .41566 L .1824 .42248 L p 1 0 0 r
F P
0 g
s
.18827 .42202 m .18566 .42783 L p .1845 .42572 L 0 1 0 r
F P
0 g
s
.18566 .42783 m .18547 .42826 L p .1845 .42572 L 0 1 0 r
F P
0 g
s
.18546 .42827 m .18548 .42826 L p .18716 .43271 L 0 0 1 r
F P
0 g
s
.18547 .42826 m .18548 .42826 L p .18813 .43255 L 1 0 0 r
F P
0 g
s
.18548 .42826 m .18806 .43243 L .18813 .43255 L 1 0 0 r
F
.18548 .42826 m .18617 .42738 L p .1867 .43023 L 0 0 1 r
F P
0 g
s
.18671 .43029 m .18617 .42738 L .18811 .43257 L 0 0 1 r
F
.18807 .43244 m .18621 .42732 L .18814 .43256 L F
.18617 .42738 m .18621 .42732 L p .18811 .43257 L F P
0 g
s
.18621 .42732 m .18785 .42522 L p .18811 .43163 L 0 0 1 r
F P
0 g
s
.18734 .43037 m .18811 .43163 L .18814 .43256 L 0 0 1 r
F
.18621 .42732 m .18811 .43163 L .18734 .43037 L F
.19583 .40612 m .18827 .42202 L .18348 .42281 L p 0 1 0 r
F P
0 g
s
.18339 .42265 m .19583 .40612 L .18348 .42281 L 0 1 0 r
F
.18197 .42862 m .17094 .41508 L p .18425 .42553 L 1 0 0 r
F P
0 g
s
.18323 .42285 m .18281 .42293 L p .18158 .41851 L 0 1 0 r
F P
0 g
s
.18323 .42285 m .18827 .42202 L p .1845 .42572 L 0 1 0 r
F P
0 g
s
.20861 .40636 m .20124 .42099 L .18827 .42202 L p 0 1 0 r
F P
0 g
s
.18827 .42202 m .19583 .40612 L .20861 .40636 L p 0 1 0 r
F P
0 g
s
.19444 .41679 m .18785 .42522 L .18427 .42359 L p 0 0 1 r
F P
0 g
s
.18359 .42251 m .19444 .41679 L .18427 .42359 L 0 0 1 r
F
.1828 .42292 m .18158 .41851 L .18281 .42293 L 0 1 0 r
F
.18348 .42281 m .18323 .42285 L p .18339 .42265 L F P
0 g
s
.1824 .42248 m .1828 .42293 L p .18417 .42537 L 1 0 0 r
F P
0 g
s
.18425 .42553 m .18438 .42587 L .18197 .42862 L 1 0 0 r
F
.1845 .42572 m .18451 .42574 L .18197 .42862 L F
.18548 .42826 m .18197 .42862 L p .18451 .42573 L F P
0 g
s
.17747 .43816 m .17277 .43441 L .16268 .41708 L p 1 0 0 r
F P
0 g
s
.16268 .41708 m .16707 .42211 L .17747 .43816 L p 1 0 0 r
F P
0 g
s
.17673 .42784 m .17176 .42568 L .16129 .40973 L p 1 0 0 r
F P
0 g
s
.16129 .40973 m .16597 .41312 L .17673 .42784 L p 1 0 0 r
F P
0 g
s
.18197 .42862 m .17673 .42784 L .16597 .41312 L p 1 0 0 r
F P
0 g
s
.16597 .41312 m .17094 .41508 L .18197 .42862 L p 1 0 0 r
F P
0 g
s
.1813 .4336 m .16912 .42808 L p .18449 .42573 L 0 0 1 r
F P
0 g
s
.18785 .42522 m .18578 .42787 L p .18449 .42573 L 0 0 1 r
F P
0 g
s
.18543 .42819 m .1845 .42572 L .18547 .42826 L 0 1 0 r
F
.18546 .42827 m .1813 .4336 L p .18449 .42573 L 0 0 1 r
F P
0 g
s
.18423 .42599 m .18449 .42573 L .18543 .42819 L 0 1 0 r
F
.18449 .42573 m .1845 .42572 L .18543 .42819 L F
.18547 .42826 m .18546 .42827 L p .18543 .42819 L F P
0 g
s
.18578 .42787 m .18546 .42827 L p .18449 .42573 L 0 0 1 r
F P
0 g
s
.17094 .41508 m .1824 .42248 L .18427 .42554 L 1 0 0 r
F
.17277 .43441 m .16837 .42921 L .1586 .41058 L p F P
0 g
s
.1586 .41058 m .16268 .41708 L .17277 .43441 L p 1 0 0 r
F P
0 g
s
.15621 .44474 m .16264 .43644 L .1748 .44192 L p 0 0 1 r
F P
0 g
s
.1813 .4336 m .1748 .44192 L .16264 .43644 L p 0 0 1 r
F P
0 g
s
.16264 .43644 m .16912 .42808 L .1813 .4336 L p 0 0 1 r
F P
0 g
s
.17176 .42568 m .16707 .42211 L .15691 .40489 L p 1 0 0 r
F P
0 g
s
.15691 .40489 m .16129 .40973 L .17176 .42568 L p 1 0 0 r
F P
0 g
s
.16912 .42808 m .17564 .41966 L .18281 .42293 L p 0 0 1 r
F P
0 g
s
.18417 .42537 m .18281 .42293 L .1829 .42309 L 1 0 0 r
F
.18417 .42537 m .1829 .42309 L .18369 .42439 L F
.18417 .42537 m .1828 .42293 L .18281 .42293 L F
.18427 .42554 m .18417 .42537 L .18369 .42437 L F
.18427 .42554 m .18369 .42437 L .18374 .42446 L F
.18425 .42553 m .1845 .42572 L .18438 .42587 L F
.16912 .42808 m .1828 .42293 L .18449 .42573 L 0 0 1 r
F
.1828 .42293 m .18281 .42293 L .1829 .42309 L F
.1828 .42293 m .1829 .42309 L .18449 .42573 L F
.18296 .42319 m .18323 .42285 L .1845 .42572 L 0 1 0 r
F
.18281 .42293 m .18785 .42522 L p .18451 .42573 L 0 0 1 r
F P
0 g
s
.18374 .42445 m .18368 .42437 L .1832 .42336 L 1 0 0 r
F
.1829 .42309 m .18281 .42293 L .18451 .42573 L 0 0 1 r
F
.18374 .42446 m .18368 .42437 L .18374 .42445 L 1 0 0 r
F
.18374 .42446 m .18369 .42437 L .18368 .42437 L F
.16703 .44292 m .18296 .42319 L .1845 .42572 L 0 1 0 r
F
.18369 .42439 m .1829 .42309 L .18369 .42437 L 1 0 0 r
F
.18281 .42293 m .1832 .42336 L p .18369 .42437 L F P
0 g
s
.18281 .42293 m .18281 .42293 L .18369 .42437 L 1 0 0 r
F
.1845 .42572 m .18451 .42573 L .18451 .42574 L F
.1845 .42572 m .18446 .42565 L .18451 .42573 L F
.18427 .42554 m .1832 .42336 L .1845 .42572 L F
.18449 .42573 m .1829 .42309 L .18451 .42573 L 0 0 1 r
F
.1828 .42293 m .18281 .42293 L p .18281 .42293 L 1 0 0 r
F P
0 g
s
.18281 .42293 m .18281 .42293 L p .18294 .42322 L 0 1 0 r
F P
0 g
s
.18281 .42293 m .18323 .42285 L p .18296 .42319 L 0 1 0 r
F P
0 g
s
.18294 .42322 m .18281 .42293 L .18296 .42319 L 0 1 0 r
F
.16703 .44292 m .17501 .42422 L .18281 .42293 L p F P
0 g
s
.16703 .44292 m .18281 .42293 L .18294 .42322 L 0 1 0 r
F
.18427 .42359 m .18281 .42293 L p .18411 .42334 L 0 0 1 r
F P
0 g
s
.18281 .42293 m .18281 .42293 L p .18411 .42334 L 0 0 1 r
F P
0 g
s
.18281 .42293 m .18359 .42251 L .18411 .42334 L 0 0 1 r
F
.18834 .43236 m .20124 .42099 L .19026 .43748 L 0 1 0 r
F
.18785 .42522 m .20001 .43076 L p .18814 .43256 L 0 0 1 r
F P
0 g
s
.20663 .42236 m .20001 .43076 L .18785 .42522 L p 0 0 1 r
F P
0 g
s
.22116 .4076 m .21395 .42106 L .20124 .42099 L p 0 1 0 r
F P
0 g
s
.20124 .42099 m .20861 .40636 L .22116 .4076 L p 0 1 0 r
F P
0 g
s
.18785 .42522 m .19444 .41679 L .20663 .42236 L p 0 0 1 r
F P
0 g
s
.19322 .4262 m .18747 .42806 L .18281 .42293 L p 1 0 0 r
F P
0 g
s
.1828 .42293 m .17619 .41566 L p .18125 .41879 L 1 0 0 r
F P
0 g
s
.18125 .41879 m .18274 .42275 L .1828 .42293 L 1 0 0 r
F
.1828 .42293 m .18124 .4188 L .18274 .42275 L 0 0 1 r
F
.18038 .41894 m .18124 .4188 L .1828 .42293 L F
.18124 .4188 m .18125 .41879 L .18274 .42275 L 0 1 0 r
F
.18281 .42293 m .1828 .42293 L p .18274 .42275 L 0 0 1 r
F P
0 g
s
.18125 .41879 m .18158 .41851 L .18281 .42293 L 0 1 0 r
F
.18125 .41879 m .18127 .4188 L .18274 .42275 L 1 0 0 r
F
.18125 .41879 m .18125 .41878 L .18127 .4188 L F
.18278 .40696 m .19583 .40612 L p .18125 .41879 L 0 1 0 r
F P
0 g
s
.18084 .41854 m .17904 .41526 L .18125 .41879 L 1 0 0 r
F
.17619 .41566 m .17904 .41526 L p .18084 .41854 L F P
0 g
s
.18124 .4188 m .17904 .41526 L .18125 .41879 L 0 1 0 r
F
.18045 .41893 m .18007 .41693 L .18124 .4188 L 0 0 1 r
F
.17564 .41966 m .17903 .41528 L p .18045 .41893 L F P
0 g
s
.17903 .41528 m .17904 .41526 L p .18124 .4188 L 0 1 0 r
F P
0 g
s
.17904 .41526 m .1793 .41468 L p .18125 .41879 L 0 1 0 r
F P
0 g
s
.1793 .41468 m .18278 .40696 L p .18135 .41801 L 0 1 0 r
F P
0 g
s
.1793 .41468 m .18135 .41801 L .18125 .41879 L 0 1 0 r
F
.16507 .40222 m .17033 .40258 L .17485 .40748 L p 1 0 0 r
F P
0 g
s
.18278 .40696 m .1793 .41468 L p .17773 .41186 L 0 1 0 r
F P
0 g
s
.1793 .41468 m .17904 .41526 L p .17773 .41186 L 0 1 0 r
F P
0 g
s
.17903 .41528 m .17905 .41526 L p .18045 .41893 L 0 0 1 r
F P
0 g
s
.17904 .41526 m .17905 .41526 L p .18125 .41879 L 1 0 0 r
F P
0 g
s
.17905 .41526 m .18119 .41868 L .18125 .41879 L 1 0 0 r
F
.17905 .41526 m .17961 .41453 L p .18006 .41687 L 0 0 1 r
F P
0 g
s
.18007 .41693 m .17961 .41453 L .18124 .4188 L 0 0 1 r
F
.18119 .41868 m .18125 .41878 L .18125 .41879 L 1 0 0 r
F
.17961 .41453 m .1822 .41119 L p .18137 .41777 L 0 0 1 r
F P
0 g
s
.17999 .41554 m .18137 .41777 L .18124 .4188 L 0 0 1 r
F
.17961 .41453 m .18137 .41777 L .17999 .41554 L F
.19036 .39104 m .18278 .40696 L .17599 .40799 L p 0 1 0 r
F P
0 g
s
.17619 .41566 m .16507 .40222 L p .17738 .4116 L 1 0 0 r
F P
0 g
s
.17741 .41162 m .17725 .41137 L .17662 .41005 L 1 0 0 r
F
.17741 .41162 m .17662 .41005 L .1767 .41018 L F
.17485 .40748 m .1754 .40807 L p .17725 .41137 L F P
0 g
s
.17564 .40846 m .17599 .40799 L .17773 .41186 L 0 1 0 r
F
.17599 .40799 m .18278 .40696 L p .17811 .41149 L F P
0 g
s
.17773 .41186 m .17616 .40837 L .17811 .41149 L 0 1 0 r
F
.17616 .40837 m .17599 .40799 L .17811 .41149 L F
.17599 .40799 m .17593 .408 L p .17464 .4045 L F P
0 g
s
.17593 .408 m .17541 .40808 L p .17506 .40644 L 0 1 0 r
F P
0 g
s
.17506 .40644 m .17464 .4045 L .17593 .408 L 0 1 0 r
F
.20323 .39145 m .19583 .40612 L .18278 .40696 L p F P
0 g
s
.18278 .40696 m .19036 .39104 L .20323 .39145 L p 0 1 0 r
F P
0 g
s
.18881 .40265 m .1822 .41119 L .17655 .4086 L p 0 0 1 r
F P
0 g
s
.17464 .4045 m .19036 .39104 L .17599 .40799 L 0 1 0 r
F
.17605 .40781 m .18881 .40265 L .17655 .4086 L 0 0 1 r
F
.1754 .40807 m .17506 .40644 L .17541 .40808 L 0 1 0 r
F
.17419 .40489 m .17464 .4045 L .1754 .40807 L F
.17033 .40258 m .17419 .40489 L .17535 .40793 L 1 0 0 r
F
.1754 .40807 m .17033 .40258 L p .17535 .40793 L F P
0 g
s
.16507 .40222 m .17485 .40748 L .17741 .41162 L 1 0 0 r
F
.17541 .40808 m .16991 .40556 L p .17418 .4049 L 0 0 1 r
F P
0 g
s
.17535 .40793 m .1754 .40807 L .1754 .40808 L 0 1 0 r
F
.17419 .40489 m .1754 .40807 L .17535 .40793 L F
.1754 .40808 m .1754 .40807 L p .17535 .40793 L 1 0 0 r
F P
0 g
s
.1738 .40522 m .17419 .40489 L .1754 .40808 L 0 1 0 r
F
.17535 .40793 m .18881 .40265 L .17541 .40808 L 0 0 1 r
F
.17541 .40808 m .17599 .40799 L p .17564 .40846 L 0 1 0 r
F P
0 g
s
.17655 .4086 m .17541 .40808 L p .17605 .40781 L 0 0 1 r
F P
0 g
s
.17541 .40808 m .1754 .40808 L p .1754 .40807 L 0 1 0 r
F P
0 g
s
.16597 .41312 m .16129 .40973 L .15106 .39262 L p 1 0 0 r
F P
0 g
s
.15106 .39262 m .15543 .39727 L .16597 .41312 L p 1 0 0 r
F P
0 g
s
.17094 .41508 m .16597 .41312 L .15543 .39727 L p 1 0 0 r
F P
0 g
s
.15543 .39727 m .1601 .40046 L .17094 .41508 L p 1 0 0 r
F P
0 g
s
.17619 .41566 m .17094 .41508 L .1601 .40046 L p 1 0 0 r
F P
0 g
s
.1601 .40046 m .16507 .40222 L .17619 .41566 L p 1 0 0 r
F P
0 g
s
.16337 .41407 m .16991 .40556 L .1754 .40807 L p 0 0 1 r
F P
0 g
s
.17725 .41137 m .1754 .40807 L .17541 .40808 L 1 0 0 r
F
.17774 .41187 m .1755 .40824 L .1822 .41119 L 0 0 1 r
F
.1754 .40807 m .17541 .40808 L p .1755 .40824 L F P
0 g
s
.1754 .40808 m .17541 .40808 L .1755 .40824 L 0 1 0 r
F
.1754 .40808 m .17595 .40866 L p .17662 .41005 L 1 0 0 r
F P
0 g
s
.17725 .41137 m .1754 .40808 L .17662 .41005 L 1 0 0 r
F
.16337 .41407 m .1754 .40807 L .1755 .40824 L 0 0 1 r
F
.17738 .4116 m .17773 .41186 L .1776 .41217 L 1 0 0 r
F
.17738 .4116 m .1776 .41217 L .17619 .41566 L F
.16337 .41407 m .1755 .40824 L .17772 .41187 L 0 0 1 r
F
.1754 .40807 m .1754 .40808 L p .17541 .40808 L 1 0 0 r
F P
0 g
s
.17773 .41186 m .17774 .41188 L .17619 .41566 L 1 0 0 r
F
.17905 .41526 m .17619 .41566 L p .17774 .41187 L F P
0 g
s
.17564 .41966 m .16337 .41407 L p .17772 .41187 L 0 0 1 r
F P
0 g
s
.1822 .41119 m .17945 .41473 L p .17772 .41187 L 0 0 1 r
F P
0 g
s
.179 .41518 m .17773 .41186 L .17904 .41526 L 0 1 0 r
F
.17903 .41528 m .17564 .41966 L p .17772 .41187 L 0 0 1 r
F P
0 g
s
.17736 .41221 m .17772 .41187 L .179 .41518 L 0 1 0 r
F
.17772 .41187 m .17773 .41186 L .179 .41518 L F
.17904 .41526 m .17903 .41528 L p .179 .41518 L F P
0 g
s
.17945 .41473 m .17903 .41528 L p .17772 .41187 L 0 0 1 r
F P
0 g
s
.16707 .42211 m .16268 .41708 L .15285 .39856 L p 1 0 0 r
F P
0 g
s
.15285 .39856 m .15691 .40489 L .16707 .42211 L p 1 0 0 r
F P
0 g
s
.15043 .43092 m .15688 .42253 L .16912 .42808 L p 0 0 1 r
F P
0 g
s
.17564 .41966 m .16912 .42808 L .15688 .42253 L p 0 0 1 r
F P
0 g
s
.15688 .42253 m .16337 .41407 L .17564 .41966 L p 0 0 1 r
F P
0 g
s
.16141 .42771 m .1754 .40808 L .17564 .40846 L 0 1 0 r
F
.1754 .40808 m .1755 .40824 L .17564 .40846 L F
.17741 .41162 m .17595 .40866 L .17773 .41186 L 1 0 0 r
F
.17772 .41187 m .17564 .40846 L .17773 .41186 L 0 1 0 r
F
.17564 .40846 m .17564 .40846 L .17772 .41187 L F
.17773 .41186 m .17774 .41187 L .17774 .41188 L 1 0 0 r
F
.17773 .41186 m .17767 .41176 L .17774 .41187 L F
.17772 .41187 m .1755 .40824 L .17774 .41187 L 0 0 1 r
F
.16141 .42771 m .17564 .40846 L .17772 .41187 L 0 1 0 r
F
.16141 .42771 m .16942 .40898 L .17541 .40808 L p F P
0 g
s
.18158 .41851 m .19583 .40612 L .18323 .42285 L 0 1 0 r
F
.20108 .40829 m .19444 .41679 L .1822 .41119 L p 0 0 1 r
F P
0 g
s
.21585 .39287 m .20861 .40636 L .19583 .40612 L p 0 1 0 r
F P
0 g
s
.19583 .40612 m .20323 .39145 L .21585 .39287 L p 0 1 0 r
F P
0 g
s
.1822 .41119 m .18881 .40265 L .20108 .40829 L p 0 0 1 r
F P
0 g
s
.17535 .40793 m .18746 .41282 L .1754 .40808 L 1 0 0 r
F
.17419 .40489 m .1742 .4049 L .17535 .40793 L F
.1742 .4049 m .18881 .40265 L .17535 .40793 L 0 0 1 r
F
.1742 .4049 m .18746 .41282 L .17535 .40793 L 1 0 0 r
F
.17231 .40223 m .17248 .40219 L p .17386 .40469 L F P
0 g
s
.17723 .39169 m .19036 .39104 L p .17469 .40447 L 0 1 0 r
F P
0 g
s
.17419 .40489 m .1744 .404 L .17469 .40447 L 0 1 0 r
F
.1744 .404 m .17723 .39169 L .17469 .40447 L F
.15913 .38924 m .16439 .38938 L .16704 .3922 L p 1 0 0 r
F P
0 g
s
.17418 .40488 m .17723 .39169 L .17419 .40489 L 0 1 0 r
F
.17252 .40228 m .17723 .39169 L .17418 .4049 L F
.17248 .40221 m .17248 .40219 L p .17252 .40228 L F P
0 g
s
.17248 .40219 m .17723 .39169 L p .17252 .40228 L 0 1 0 r
F P
0 g
s
.18484 .37575 m .17723 .39169 L .16852 .39287 L p 0 1 0 r
F P
0 g
s
.17033 .40258 m .15913 .38924 L p .17034 .39752 L 1 0 0 r
F P
0 g
s
.17649 .39699 m .18881 .40265 L p .17509 .40476 L 0 0 1 r
F P
0 g
s
.1742 .4049 m .17451 .40383 L .17509 .40476 L 0 0 1 r
F
.17451 .40383 m .17649 .39699 L .17509 .40476 L F
.16704 .3922 m .16776 .39297 L p .17015 .39719 L 1 0 0 r
F P
0 g
s
.17079 .39785 m .16784 .3931 L .16819 .39304 L 0 1 0 r
F
.17106 .39759 m .16819 .39304 L .17723 .39169 L F
.17079 .39785 m .16819 .39304 L .17106 .39759 L F
.16776 .39297 m .17723 .39169 L p .16784 .3931 L F P
0 g
s
.16852 .39287 m .16776 .39297 L p .16753 .39035 L 0 1 0 r
F P
0 g
s
.15913 .38924 m .16704 .3922 L .17037 .39755 L 1 0 0 r
F
.16776 .39297 m .16439 .38938 L p .16694 .39085 L F P
0 g
s
.16694 .39085 m .16772 .39287 L .16776 .39297 L 1 0 0 r
F
.16411 .39129 m .16693 .39086 L .16772 .39287 L 0 0 1 r
F
.16776 .39297 m .16776 .39297 L p .16772 .39287 L F P
0 g
s
.16694 .39085 m .16753 .39035 L .16769 .39218 L 0 1 0 r
F
.16694 .39085 m .16769 .39218 L .16776 .39297 L F
.17162 .3762 m .18484 .37575 L p .16694 .39085 L F P
0 g
s
.16776 .39297 m .16753 .39035 L .16776 .39297 L 0 1 0 r
F
.16753 .39035 m .18484 .37575 L .16852 .39287 L F
.19779 .37635 m .19036 .39104 L .17723 .39169 L p F P
0 g
s
.17723 .39169 m .18484 .37575 L .19779 .37635 L p 0 1 0 r
F P
0 g
s
.17071 .38262 m .18312 .38835 L p .16695 .39085 L 0 0 1 r
F P
0 g
s
.16694 .39085 m .16694 .39085 L .16695 .39085 L 1 0 0 r
F
.16693 .39086 m .16694 .39085 L .16772 .39287 L 0 1 0 r
F
.16693 .39086 m .16694 .39084 L .16695 .39085 L 0 0 1 r
F
.16694 .39084 m .17071 .38262 L .16695 .39085 L F
.17723 .39169 m .17281 .40146 L p .17079 .39785 L 0 1 0 r
F P
0 g
s
.17037 .39755 m .17079 .39785 L .17248 .40219 L 1 0 0 r
F
.17281 .40146 m .17248 .40219 L p .17079 .39785 L 0 1 0 r
F P
0 g
s
.17248 .40219 m .17249 .40219 L p .17396 .40453 L 1 0 0 r
F P
0 g
s
.17253 .40227 m .17292 .40164 L .17414 .40479 L 0 0 1 r
F
.17419 .40486 m .17649 .39699 L .1742 .4049 L F
.17292 .40164 m .17649 .39699 L p .17419 .40487 L F P
0 g
s
.17414 .40479 m .1742 .40488 L .17419 .40489 L 1 0 0 r
F
.17386 .40469 m .17398 .4045 L .17419 .40489 L F
.17414 .40479 m .17419 .40487 L .17418 .4049 L 0 0 1 r
F
.17292 .40164 m .17419 .40487 L .17414 .40479 L F
.17398 .4045 m .17585 .40159 L .1742 .40488 L 1 0 0 r
F
.17398 .4045 m .1742 .40488 L .17414 .40479 L F
.17249 .40219 m .17585 .40159 L p .17396 .40452 L F P
0 g
s
.17249 .40219 m .17396 .40452 L .17396 .40453 L 1 0 0 r
F
.17248 .40219 m .17396 .40453 L .17386 .40469 L F
.17252 .40228 m .17253 .40227 L .17418 .4049 L 0 0 1 r
F
.17253 .40227 m .17414 .40479 L .17418 .4049 L F
.17248 .40221 m .17249 .40219 L p .17252 .40228 L F P
0 g
s
.17249 .40219 m .17292 .40164 L p .17252 .40228 L 0 0 1 r
F P
0 g
s
.17079 .39785 m .1708 .39786 L .17248 .40219 L 1 0 0 r
F
.17249 .40219 m .17248 .40219 L p .1708 .39786 L F P
0 g
s
.17248 .40219 m .17248 .40221 L p .17079 .39785 L 0 1 0 r
F P
0 g
s
.17077 .39787 m .17079 .39785 L .17248 .40221 L 0 1 0 r
F
.17034 .39752 m .17037 .39761 L .17033 .40258 L 1 0 0 r
F
.17248 .40219 m .17033 .40258 L p .17037 .39755 L F P
0 g
s
.1601 .40046 m .15543 .39727 L .14512 .38028 L p 1 0 0 r
F P
0 g
s
.14512 .38028 m .14948 .38472 L .1601 .40046 L p 1 0 0 r
F P
0 g
s
.16507 .40222 m .1601 .40046 L .14948 .38472 L p 1 0 0 r
F P
0 g
s
.14948 .38472 m .15415 .3877 L .16507 .40222 L p 1 0 0 r
F P
0 g
s
.17033 .40258 m .16507 .40222 L .15415 .3877 L p 1 0 0 r
F P
0 g
s
.15415 .3877 m .15913 .38924 L .17033 .40258 L p 1 0 0 r
F P
0 g
s
.16991 .40556 m .15755 .39991 L p .17077 .39787 L 0 0 1 r
F P
0 g
s
.17649 .39699 m .17301 .40151 L p .17077 .39787 L 0 0 1 r
F P
0 g
s
.17033 .40258 m .17231 .40223 L p .17386 .40469 L 1 0 0 r
F P
0 g
s
.17301 .40151 m .16991 .40556 L p .17077 .39787 L 0 0 1 r
F P
0 g
s
.1708 .39786 m .16784 .3931 L .17649 .39699 L 0 0 1 r
F
.16776 .39297 m .16776 .39297 L p .16784 .3931 L F P
0 g
s
.16776 .39297 m .16776 .39297 L p .16784 .3931 L 0 1 0 r
F P
0 g
s
.16776 .39297 m .16847 .39373 L p .17015 .39719 L 1 0 0 r
F P
0 g
s
.16776 .39297 m .16776 .39297 L p .16776 .39297 L 1 0 0 r
F P
0 g
s
.17015 .39719 m .16776 .39297 L .16776 .39297 L 1 0 0 r
F
.17015 .39719 m .16847 .39373 L .17062 .39755 L F
.17077 .39787 m .16784 .3931 L .17079 .39785 L 0 1 0 r
F
.17037 .39755 m .17015 .39719 L .17058 .39752 L 1 0 0 r
F
.17059 .39753 m .17058 .39752 L .17059 .39753 L F
.17037 .39755 m .17058 .39752 L .17059 .39753 L F
.17037 .39755 m .17059 .39753 L .1708 .39786 L F
.17034 .39752 m .17037 .39755 L .17037 .39761 L F
.15755 .39991 m .16776 .39297 L .1708 .39786 L 0 0 1 r
F
.16129 .40973 m .15691 .40489 L .14701 .38649 L p 1 0 0 r
F P
0 g
s
.14701 .38649 m .15106 .39262 L .16129 .40973 L p 1 0 0 r
F P
0 g
s
.14458 .41695 m .15104 .40846 L .16337 .41407 L p 0 0 1 r
F P
0 g
s
.16991 .40556 m .16337 .41407 L .15104 .40846 L p 0 0 1 r
F P
0 g
s
.15104 .40846 m .15755 .39991 L .16991 .40556 L p 0 0 1 r
F P
0 g
s
.15573 .41226 m .16776 .39297 L .16784 .3931 L 0 1 0 r
F
.15573 .41226 m .16784 .3931 L .17077 .39787 L F
.17585 .40159 m .17249 .40219 L p .1708 .39786 L 1 0 0 r
F P
0 g
s
.16847 .39373 m .17585 .40159 L p .17062 .39755 L 1 0 0 r
F P
0 g
s
.18312 .38835 m .17649 .39699 L .16909 .39358 L p 0 0 1 r
F P
0 g
s
.16909 .39358 m .16776 .39297 L p .16873 .39268 L 0 0 1 r
F P
0 g
s
.16873 .39268 m .18312 .38835 L .16909 .39358 L 0 0 1 r
F
.16942 .40898 m .15573 .41226 L p .17077 .39787 L 0 1 0 r
F P
0 g
s
.16991 .40556 m .17248 .40221 L p .17418 .4049 L 0 0 1 r
F P
0 g
s
.17248 .40221 m .16942 .40898 L p .17077 .39787 L 0 1 0 r
F P
0 g
s
.16694 .39085 m .16698 .39093 L .16772 .39287 L 1 0 0 r
F
.16694 .39085 m .16695 .39085 L .16698 .39093 L F
.16693 .39086 m .18312 .38835 L .16776 .39297 L 0 0 1 r
F
.19547 .39406 m .18881 .40265 L .17649 .39699 L p F P
0 g
s
.17649 .39699 m .18312 .38835 L .19547 .39406 L p 0 0 1 r
F P
0 g
s
.16992 .38816 m .18162 .39931 L p .16695 .39085 L 1 0 0 r
F P
0 g
s
.16694 .39085 m .16992 .38816 L .16695 .39085 L 1 0 0 r
F
.16671 .39072 m .16681 .39064 L .16694 .39085 L F
.1658 .38907 m .16595 .38873 L p .16694 .39085 L 0 1 0 r
F P
0 g
s
.16681 .39064 m .16681 .39064 L .16694 .39085 L 1 0 0 r
F
.16439 .38938 m .16568 .38909 L p .16671 .39072 L F P
0 g
s
.1658 .38907 m .16608 .3887 L p .1669 .39078 L 0 0 1 r
F P
0 g
s
.16568 .38909 m .1658 .38907 L p .16671 .39072 L 1 0 0 r
F P
0 g
s
.16595 .38873 m .17162 .3762 L p .16694 .39085 L 0 1 0 r
F P
0 g
s
.16608 .3887 m .17071 .38262 L p .16694 .39084 L 0 0 1 r
F P
0 g
s
.16608 .3887 m .16694 .39084 L .1669 .39078 L 0 0 1 r
F
.1658 .38907 m .16992 .38816 L p .16681 .39064 L 1 0 0 r
F P
0 g
s
.1658 .38907 m .16681 .39064 L .16671 .39072 L 1 0 0 r
F
.16693 .39086 m .1658 .38907 L .16694 .39085 L 0 1 0 r
F
.1669 .39078 m .16694 .39084 L .16693 .39086 L 0 0 1 r
F
.16411 .39129 m .16579 .38908 L p .16693 .39086 L F P
0 g
s
.16579 .38908 m .1658 .38907 L p .16693 .39086 L 0 1 0 r
F P
0 g
s
.16579 .38908 m .1658 .38907 L p .16693 .39086 L 0 0 1 r
F P
0 g
s
.16776 .39297 m .16411 .39129 L p .16772 .39287 L 0 0 1 r
F P
0 g
s
.15755 .39991 m .16411 .39129 L .16776 .39297 L p 0 0 1 r
F P
0 g
s
.16379 .39351 m .16579 .38908 L p .16693 .39086 L 0 1 0 r
F P
0 g
s
.16681 .39064 m .1669 .39078 L .16694 .39085 L 1 0 0 r
F
.1658 .38907 m .1669 .39078 L .16693 .39086 L 0 0 1 r
F
.16681 .39064 m .16682 .39063 L .1669 .39078 L 1 0 0 r
F
.16682 .39063 m .16992 .38816 L .16694 .39085 L F
.16668 .39107 m .16693 .39086 L .16776 .39297 L 0 1 0 r
F
.16693 .39086 m .16772 .39287 L .16776 .39297 L F
.16776 .39297 m .17649 .39699 L p .16784 .3931 L 0 0 1 r
F P
0 g
s
.18162 .39931 m .17585 .40159 L .16776 .39297 L p 1 0 0 r
F P
0 g
s
.16776 .39297 m .16776 .39297 L p .16776 .39297 L 0 1 0 r
F P
0 g
s
.16695 .39085 m .18162 .39931 L .16776 .39297 L 1 0 0 r
F
.15573 .41226 m .16379 .39351 L .16776 .39297 L p 0 1 0 r
F P
0 g
s
.1708 .39786 m .17059 .39753 L .17585 .40159 L 1 0 0 r
F
.16776 .39297 m .16379 .39351 L p .16668 .39107 L 0 1 0 r
F P
0 g
s
.17418 .4049 m .17418 .40488 L .17419 .40489 L 0 1 0 r
F
.16942 .40898 m .17248 .40221 L p .17418 .4049 L F P
0 g
s
.17419 .40489 m .1742 .40488 L .1742 .4049 L 1 0 0 r
F
.17418 .4049 m .17419 .40486 L .1742 .4049 L 0 0 1 r
F
.17418 .4049 m .1742 .4049 L .17535 .40793 L F
.17541 .40808 m .1822 .41119 L p .1755 .40824 L F P
0 g
s
.1822 .41119 m .19444 .41679 L p .18127 .4188 L 0 0 1 r
F P
0 g
s
.18124 .41876 m .1822 .41119 L .18127 .4188 L 0 0 1 r
F
.18746 .41282 m .1817 .41489 L .1754 .40808 L p 1 0 0 r
F P
0 g
s
.17585 .40159 m .18746 .41282 L p .1742 .4049 L 1 0 0 r
F P
0 g
s
.1742 .40488 m .17585 .40159 L .1742 .4049 L 1 0 0 r
F
.1767 .41018 m .17662 .41005 L .17595 .40866 L F
.1754 .40808 m .16942 .40898 L p .1738 .40522 L 0 1 0 r
F P
0 g
s
.17595 .40866 m .1817 .41489 L p .17774 .41187 L 1 0 0 r
F P
0 g
s
.17767 .41176 m .17595 .40866 L .17774 .41187 L 1 0 0 r
F
.17928 .41523 m .1817 .41489 L p .18125 .41878 L F P
0 g
s
.17928 .41523 m .18125 .41878 L .18119 .41868 L 1 0 0 r
F
.17905 .41526 m .18006 .41687 L .18044 .41886 L 0 0 1 r
F
.17905 .41526 m .18044 .41886 L .18045 .41893 L F
.1817 .41489 m .17905 .41526 L p .17774 .41187 L 1 0 0 r
F P
0 g
s
.1828 .42293 m .17564 .41966 L p .18038 .41894 L 0 0 1 r
F P
0 g
s
.17501 .42422 m .17903 .41528 L p .18124 .4188 L 0 1 0 r
F P
0 g
s
.17736 .41221 m .179 .41518 L .17501 .42422 L 0 1 0 r
F
.17903 .41528 m .17501 .42422 L p .179 .41518 L F P
0 g
s
.17501 .42422 m .16141 .42771 L p .17736 .41221 L 0 1 0 r
F P
0 g
s
.17905 .41526 m .17928 .41523 L p .18119 .41868 L 1 0 0 r
F P
0 g
s
.18124 .4188 m .18124 .41876 L .18127 .4188 L 0 0 1 r
F
.18075 .41923 m .18124 .4188 L .18281 .42293 L 0 1 0 r
F
.18124 .4188 m .18274 .42275 L .18281 .42293 L F
.18274 .42275 m .19444 .41679 L .18281 .42293 L 0 0 1 r
F
.18124 .4188 m .18127 .4188 L .18274 .42275 L F
.18127 .4188 m .19444 .41679 L .18274 .42275 L F
.18281 .42293 m .18281 .42293 L p .1828 .42292 L 0 1 0 r
F P
0 g
s
.18127 .4188 m .19322 .4262 L .1828 .42293 L 1 0 0 r
F
.1817 .41489 m .19322 .4262 L p .18127 .4188 L F P
0 g
s
.18125 .41878 m .1817 .41489 L .18127 .4188 L 1 0 0 r
F
.18281 .42293 m .17501 .42422 L p .18075 .41923 L 0 1 0 r
F P
0 g
s
.1832 .42336 m .18747 .42806 L p .18451 .42573 L 1 0 0 r
F P
0 g
s
.18446 .42565 m .1832 .42336 L .18451 .42573 L 1 0 0 r
F
.18576 .42823 m .18747 .42806 L p .18813 .43253 L F P
0 g
s
.18806 .43243 m .18813 .43253 L .18813 .43255 L 1 0 0 r
F
.18576 .42823 m .18813 .43253 L .18806 .43243 L F
.18548 .42826 m .1867 .43023 L .18715 .43265 L 0 0 1 r
F
.18548 .42826 m .18715 .43265 L .18716 .43271 L F
.18747 .42806 m .18548 .42826 L p .18451 .42573 L 1 0 0 r
F P
0 g
s
.18997 .43753 m .1813 .4336 L p .18708 .43272 L 0 0 1 r
F P
0 g
s
.18708 .43272 m .18811 .43257 L .18997 .43753 L 0 0 1 r
F
.18054 .43924 m .18546 .42827 L p .18811 .43257 L 0 1 0 r
F P
0 g
s
.18423 .42599 m .18543 .42819 L .18054 .43924 L 0 1 0 r
F
.18546 .42827 m .18054 .43924 L p .18543 .42819 L F P
0 g
s
.18054 .43924 m .16703 .44292 L p .18423 .42599 L 0 1 0 r
F P
0 g
s
.18548 .42826 m .18576 .42823 L p .18806 .43243 L 1 0 0 r
F P
0 g
s
.18811 .43257 m .18807 .43244 L .18814 .43256 L 0 0 1 r
F
.18752 .43309 m .18811 .43257 L .18997 .43753 L 0 1 0 r
F
.18811 .43257 m .18813 .43255 L .18991 .43735 L F
.18811 .43257 m .18991 .43735 L .18997 .43753 L F
.18813 .43255 m .18814 .43256 L .18991 .43735 L 1 0 0 r
F
.18811 .43257 m .20001 .43076 L .18997 .43753 L 0 0 1 r
F
.18997 .43753 m .18997 .43753 L p .18997 .43752 L 0 1 0 r
F P
0 g
s
.18997 .43753 m .19891 .43944 L .18997 .43753 L 1 0 0 r
F
.18814 .43256 m .19891 .43944 L .18997 .43753 L F
.17261 .45789 m .18054 .43924 L .18997 .43753 L p 0 1 0 r
F P
0 g
s
.18997 .43753 m .19024 .43783 L p .19059 .43855 L 1 0 0 r
F P
0 g
s
.18747 .42806 m .19891 .43944 L p .18814 .43256 L 1 0 0 r
F P
0 g
s
.18813 .43253 m .18747 .42806 L .18814 .43256 L 1 0 0 r
F
.18997 .43753 m .18054 .43924 L p .18752 .43309 L 0 1 0 r
F P
0 g
s
.19094 .43963 m .19175 .44114 L .18603 .45403 L 0 1 0 r
F
.19177 .4412 m .18603 .45403 L p .19175 .44114 L F P
0 g
s
.18042 .45561 m .19692 .45191 L .19758 .45303 L 0 0 1 r
F
.18603 .45403 m .17261 .45789 L p .19094 .43963 L 0 1 0 r
F P
0 g
s
.18603 .45403 m .19177 .4412 L p .19481 .44619 L 0 1 0 r
F P
0 g
s
.19414 .44679 m .19481 .44619 L .19692 .45191 L 0 1 0 r
F
.19481 .44619 m .19687 .45175 L .19692 .45191 L F
.19481 .44619 m .20551 .44457 L .19692 .45191 L 0 0 1 r
F
.19692 .45191 m .19692 .45191 L p .19692 .45188 L 0 1 0 r
F P
0 g
s
.19485 .44618 m .20452 .45255 L .19692 .4519 L 1 0 0 r
F
.19692 .45191 m .19692 .45191 L p .19698 .452 L 0 1 0 r
F P
0 g
s
.19692 .4519 m .19692 .45191 L p .19698 .452 L 1 0 0 r
F P
0 g
s
.17814 .47262 m .19692 .45191 L .19698 .452 L 0 1 0 r
F
.17814 .47262 m .19698 .452 L .19758 .45303 L F
.17814 .47262 m .18603 .45403 L .19692 .45191 L p F P
0 g
s
.19759 .45302 m .19698 .452 L .1988 .45402 L 1 0 0 r
F
.19692 .45191 m .1988 .45402 L p .19698 .452 L F P
0 g
s
.19317 .4411 m .20452 .45255 L p .19485 .44618 L 1 0 0 r
F P
0 g
s
.19482 .44614 m .19317 .4411 L .19485 .44618 L 1 0 0 r
F
.19692 .45191 m .18603 .45403 L p .19414 .44679 L 0 1 0 r
F P
0 g
s
.19748 .45313 m .19795 .45402 L .19147 .4686 L 0 1 0 r
F
.19797 .45406 m .19147 .4686 L p .19795 .45402 L F P
0 g
s
.19147 .4686 m .17814 .47262 L p .19748 .45313 L 0 1 0 r
F P
0 g
s
.20138 .45967 m .1981 .45389 L .20154 .45964 L 0 0 1 r
F
.19797 .45405 m .1981 .45389 L p .20138 .45967 L F P
0 g
s
.19797 .45405 m .1988 .45402 L p .20005 .45748 L 1 0 0 r
F P
0 g
s
.19147 .4686 m .19797 .45406 L p .20135 .45967 L 0 1 0 r
F P
0 g
s
.21718 .46439 m .22446 .44989 L .23677 .45069 L p 0 1 0 r
F P
0 g
s
.20441 .46638 m .21095 .45823 L .22289 .46362 L p 0 0 1 r
F P
0 g
s
.1988 .45402 m .21007 .46554 L p .20138 .45967 L 1 0 0 r
F P
0 g
s
.20005 .45748 m .1988 .45402 L .20138 .45967 L 1 0 0 r
F
.20441 .46638 m .20367 .46605 L p .20463 .46502 L 0 0 1 r
F P
0 g
s
.20501 .46564 m .20441 .46638 L p .20463 .46502 L 0 0 1 r
F P
0 g
s
.20367 .46605 m .20378 .4661 L p .2038 .46628 L 0 0 1 r
F P
0 g
s
.20382 .46647 m .20367 .46605 L .2038 .46628 L 0 0 1 r
F
.20367 .46605 m .20367 .46605 L p .20368 .46609 L 0 1 0 r
F P
0 g
s
.20367 .46605 m .20367 .46605 L p .2037 .4661 L 1 0 0 r
F P
0 g
s
.20368 .46609 m .20367 .46605 L .20369 .46608 L 0 1 0 r
F
.20367 .46605 m .20367 .46605 L p .20364 .46599 L F P
0 g
s
.20367 .46605 m .20361 .46606 L p .20364 .466 L 0 1 0 r
F P
0 g
s
.20364 .466 m .20364 .46599 L .20367 .46605 L 0 1 0 r
F
.2037 .4661 m .2039 .46645 L .2039 .46646 L F
.2039 .46646 m .20373 .46604 L .20391 .46646 L F
.20391 .46646 m .20391 .46646 L .20391 .46646 L 1 0 0 r
F
.20382 .46647 m .20378 .4661 L .20391 .46646 L 0 0 1 r
F
.18363 .48712 m .20369 .46608 L .2039 .46646 L 0 1 0 r
F
.20369 .46608 m .20369 .46608 L .2037 .4661 L F
.20369 .46608 m .2037 .4661 L .2039 .46646 L F
.2039 .46645 m .2037 .4661 L .20372 .46612 L 1 0 0 r
F
.20367 .46605 m .20372 .46612 L p .2037 .4661 L F P
0 g
s
.20372 .46612 m .20435 .46684 L p .2039 .46645 L 1 0 0 r
F P
0 g
s
.18363 .48712 m .19147 .4686 L .20367 .46605 L p 0 1 0 r
F P
0 g
s
.18363 .48712 m .20367 .46605 L .20368 .46609 L 0 1 0 r
F
.20378 .4661 m .20441 .46638 L p .20391 .46646 L 0 0 1 r
F P
0 g
s
.20441 .46638 m .20554 .46689 L p .2076 .47267 L 0 0 1 r
F P
0 g
s
.21007 .46554 m .20435 .46684 L .20367 .46605 L p 1 0 0 r
F P
0 g
s
.20138 .45967 m .21007 .46554 L .20367 .46605 L 1 0 0 r
F
.20435 .46684 m .20405 .46684 L p .20391 .46646 L F P
0 g
s
.20057 .46038 m .20059 .46036 L .20361 .46606 L 0 1 0 r
F
.20059 .46036 m .20364 .466 L .20361 .46606 L F
.20361 .46606 m .19147 .4686 L p .20057 .46038 L F P
0 g
s
.20415 .46709 m .20404 .46684 L .20418 .46709 L 1 0 0 r
F
.20402 .46684 m .20404 .46684 L p .20415 .46709 L F P
0 g
s
.20637 .47322 m .20405 .46684 L .20776 .47301 L 0 0 1 r
F
.19792 .47448 m .20404 .46684 L p .20637 .47322 L F P
0 g
s
.20404 .46684 m .20405 .46684 L p .20637 .47322 L 0 0 1 r
F P
0 g
s
.2098 .4798 m .19792 .47448 L p .20773 .47302 L 0 0 1 r
F P
0 g
s
.20387 .4665 m .20404 .46682 L .19686 .48294 L 0 1 0 r
F
.20404 .46684 m .20404 .46684 L p .20404 .46682 L F P
0 g
s
.20404 .46684 m .19686 .48294 L p .20404 .46682 L 0 1 0 r
F P
0 g
s
.18506 .49051 m .19147 .48253 L .20333 .4878 L p 0 0 1 r
F P
0 g
s
.19686 .48294 m .18363 .48712 L p .20387 .4665 L 0 1 0 r
F P
0 g
s
.19686 .48294 m .20404 .46684 L p .20773 .47302 L 0 1 0 r
F P
0 g
s
.20773 .47302 m .20776 .47301 L .20779 .47313 L 0 0 1 r
F
.20773 .47302 m .20779 .47313 L .2098 .4798 L F
.20776 .47301 m .20462 .46711 L .20779 .47304 L 1 0 0 r
F
.20768 .47288 m .20462 .46711 L .20776 .47301 L F
.20461 .46711 m .20462 .46711 L .20774 .473 L F
.20977 .48008 m .19686 .48294 L p .20773 .47302 L 0 1 0 r
F P
0 g
s
.21004 .4795 m .20977 .48008 L p .20773 .47302 L 0 1 0 r
F P
0 g
s
.20777 .47301 m .2076 .47267 L .21632 .47174 L 0 0 1 r
F
.20554 .46689 m .21632 .47174 L p .2076 .47267 L F P
0 g
s
.20435 .46684 m .20462 .46711 L p .2042 .46709 L 1 0 0 r
F P
0 g
s
.20404 .46684 m .20435 .46684 L p .2042 .46709 L 1 0 0 r
F P
0 g
s
.20462 .46711 m .21554 .47841 L p .20779 .47304 L 1 0 0 r
F P
0 g
s
.2108 .48097 m .21028 .48001 L .21086 .48099 L 1 0 0 r
F
.21028 .48001 m .21032 .48007 L .21086 .48099 L F
.20333 .4878 m .21028 .48001 L .21032 .48007 L 0 0 1 r
F
.20333 .4878 m .21032 .48007 L .21395 .48623 L F
.21028 .48001 m .21028 .48001 L .21032 .48007 L 1 0 0 r
F
.2022 .49705 m .21028 .48001 L .21032 .48007 L 0 1 0 r
F
.21395 .48623 m .21032 .48007 L .21396 .48622 L F
.2022 .49705 m .21032 .48007 L .21395 .48623 L F
.21395 .48623 m .21032 .48007 L .21398 .48623 L 0 0 1 r
F
.21028 .48001 m .20977 .48008 L p .21015 .47977 L 0 1 0 r
F P
0 g
s
.2022 .49705 m .20977 .48008 L .21028 .48001 L p 0 1 0 r
F P
0 g
s
.21028 .48001 m .21133 .4811 L p .21086 .48099 L 1 0 0 r
F P
0 g
s
.21133 .4811 m .22095 .49117 L p .21408 .48629 L 1 0 0 r
F P
0 g
s
.21682 .49381 m .21502 .49406 L p .21637 .49296 L 0 1 0 r
F P
0 g
s
.2075 .51095 m .21502 .49406 L .21682 .49381 L p 0 1 0 r
F P
0 g
s
.21682 .49381 m .21783 .49488 L p .21734 .49469 L 1 0 0 r
F P
0 g
s
.21783 .49488 m .22628 .50381 L p .22021 .49941 L 1 0 0 r
F P
0 g
s
.22264 .50585 m .2386 .5035 L .22316 .50739 L 0 0 1 r
F
.25026 .50869 m .24373 .5165 L .2321 .51135 L p F P
0 g
s
.2321 .51135 m .2386 .5035 L .25026 .50869 L p 0 0 1 r
F P
0 g
s
.22628 .50381 m .23744 .51444 L p .22265 .50585 L 1 0 0 r
F P
0 g
s
.22265 .50584 m .22628 .50381 L .22265 .50585 L 1 0 0 r
F
.22374 .50765 m .22316 .50739 L p .22353 .5073 L 0 0 1 r
F P
0 g
s
.22244 .50601 m .22264 .50584 L .22316 .50739 L 0 1 0 r
F
.22257 .50569 m .22628 .50381 L .22264 .50584 L 1 0 0 r
F
.22591 .51213 m .22325 .50755 L .22592 .51213 L F
.22597 .51224 m .22592 .51213 L .22599 .51225 L F
.22597 .51224 m .22599 .51225 L .22753 .51685 L F
.22754 .51685 m .22753 .51685 L p .22599 .51225 L F P
0 g
s
.22753 .51685 m .22587 .51706 L p .22597 .51224 L 1 0 0 r
F P
0 g
s
.2275 .5168 m .22597 .51224 L .22753 .51685 L 0 1 0 r
F
.22488 .51241 m .22596 .51225 L .2275 .5168 L 0 0 1 r
F
.22544 .51274 m .22596 .51225 L .2275 .5168 L 0 1 0 r
F
.22596 .51225 m .22597 .51224 L .2275 .5168 L F
.2275 .5168 m .22596 .51225 L .22754 .51685 L 0 0 1 r
F
.2321 .51135 m .22817 .51609 L p .22596 .51225 L F P
0 g
s
.22817 .51609 m .22754 .51685 L p .22596 .51225 L 0 0 1 r
F P
0 g
s
.2255 .51189 m .22316 .50739 L .22325 .50755 L 1 0 0 r
F
.2255 .51189 m .22325 .50755 L .22591 .51213 L F
.2255 .51189 m .22592 .51213 L .22597 .51224 L F
.22485 .51241 m .22316 .50739 L .22596 .51225 L 0 0 1 r
F
.21398 .51401 m .22316 .50739 L .22485 .51241 L F
.20123 .52951 m .20758 .52179 L .21921 .52689 L p F P
0 g
s
.22563 .51915 m .21921 .52689 L .20758 .52179 L p 0 0 1 r
F P
0 g
s
.20758 .52179 m .21398 .51401 L .22563 .51915 L p 0 0 1 r
F P
0 g
s
.21275 .52462 m .22316 .50739 L .22325 .50755 L 0 1 0 r
F
.22596 .51225 m .22325 .50755 L .22597 .51224 L F
.22587 .51706 m .22753 .51685 L p .2284 .51856 L 1 0 0 r
F P
0 g
s
.22488 .51241 m .2275 .5168 L .22563 .51915 L 0 0 1 r
F
.22753 .51685 m .22753 .51687 L p .2275 .5168 L 0 1 0 r
F P
0 g
s
.22754 .51685 m .22753 .51687 L p .2275 .5168 L 0 0 1 r
F P
0 g
s
.22753 .51687 m .22563 .51915 L p .2275 .5168 L 0 0 1 r
F P
0 g
s
.2284 .51856 m .22754 .51685 L .22863 .5187 L 1 0 0 r
F
.22753 .51685 m .22754 .51685 L p .2284 .51856 L F P
0 g
s
.22817 .51878 m .22753 .51687 L .22863 .51871 L 0 0 1 r
F
.22563 .51915 m .22753 .51687 L p .22817 .51878 L F P
0 g
s
.21921 .52689 m .22563 .51915 L .22931 .52077 L p 0 0 1 r
F P
0 g
s
.22931 .52077 m .22563 .51915 L p .22863 .51871 L 0 0 1 r
F P
0 g
s
.22544 .51274 m .2275 .5168 L .22539 .52139 L 0 1 0 r
F
.22753 .51687 m .22539 .52139 L p .2275 .5168 L F P
0 g
s
.21275 .52462 m .22325 .50755 L .22596 .51225 L 0 1 0 r
F
.22753 .51687 m .22771 .51647 L p .22863 .51871 L F P
0 g
s
.22863 .5187 m .22926 .52062 L .22931 .52077 L 1 0 0 r
F
.22836 .51893 m .22863 .5187 L .22931 .52077 L 0 1 0 r
F
.22863 .5187 m .2292 .51824 L .22931 .52077 L F
.22863 .5187 m .22867 .51878 L .22926 .52062 L 1 0 0 r
F
.22863 .5187 m .22864 .5187 L .22864 .51871 L F
.22864 .51871 m .2282 .51605 L .22966 .51856 L 0 0 1 r
F
.2286 .51864 m .22864 .5187 L .22863 .5187 L 1 0 0 r
F
.22863 .51871 m .22862 .51867 L .22864 .51871 L 0 0 1 r
F
.22862 .51867 m .2282 .51605 L .22864 .51871 L F
.22754 .51685 m .2286 .51864 L .22863 .5187 L 1 0 0 r
F
.22753 .51687 m .2282 .51605 L p .22863 .51871 L 0 0 1 r
F P
0 g
s
.2282 .51605 m .2321 .51135 L p .22966 .51856 L 0 0 1 r
F P
0 g
s
.22768 .51684 m .23156 .51636 L p .22864 .5187 L 1 0 0 r
F P
0 g
s
.22768 .51684 m .22864 .5187 L .2286 .51864 L 1 0 0 r
F
.23156 .51636 m .22754 .51685 L p .22599 .51225 L F P
0 g
s
.22316 .50739 m .22456 .50801 L p .22596 .51225 L 0 0 1 r
F P
0 g
s
.22456 .50801 m .2321 .51135 L p .22599 .51225 L 0 0 1 r
F P
0 g
s
.22596 .51225 m .22456 .50801 L .22599 .51225 L 0 0 1 r
F
.22316 .50739 m .22316 .50739 L p .22325 .50755 L 0 1 0 r
F P
0 g
s
.23744 .51444 m .23156 .51636 L .22316 .50739 L p 1 0 0 r
F P
0 g
s
.22265 .50585 m .23744 .51444 L .22316 .50739 L 1 0 0 r
F
.21398 .51401 m .22316 .50739 L .22316 .50739 L 0 0 1 r
F
.22316 .50739 m .22023 .50783 L p .22244 .50601 L 0 1 0 r
F P
0 g
s
.21275 .52462 m .22023 .50783 L .22316 .50739 L p 0 1 0 r
F P
0 g
s
.22539 .52139 m .21275 .52462 L p .22544 .51274 L 0 1 0 r
F P
0 g
s
.22754 .51685 m .22768 .51684 L p .2286 .51864 L 1 0 0 r
F P
0 g
s
.22539 .52139 m .22753 .51687 L p .22863 .51871 L 0 1 0 r
F P
0 g
s
.22316 .50739 m .23156 .51636 L p .22599 .51225 L 1 0 0 r
F P
0 g
s
.22863 .5187 m .22864 .51871 L .22867 .51878 L 1 0 0 r
F
.24373 .5165 m .23724 .52427 L .23007 .52111 L p 0 0 1 r
F P
0 g
s
.23007 .52111 m .22931 .52077 L p .22979 .52063 L 0 0 1 r
F P
0 g
s
.22979 .52063 m .24373 .5165 L .23007 .52111 L 0 0 1 r
F
.22931 .52076 m .2292 .51824 L .22931 .52077 L 0 1 0 r
F
.22863 .51871 m .24373 .5165 L .22931 .52077 L 0 0 1 r
F
.22931 .52077 m .22931 .52077 L p .22931 .52076 L 0 1 0 r
F P
0 g
s
.25531 .52163 m .2488 .52936 L .23724 .52427 L p 0 0 1 r
F P
0 g
s
.23724 .52427 m .24373 .5165 L .25531 .52163 L p 0 0 1 r
F P
0 g
s
.22864 .51871 m .24264 .52701 L .22931 .52077 L 1 0 0 r
F
.21921 .52689 m .22931 .52077 L .22931 .52077 L 0 0 1 r
F
.21921 .52689 m .22931 .52077 L .23176 .52506 L F
.22931 .52077 m .22931 .52077 L p .22941 .52095 L 0 1 0 r
F P
0 g
s
.22931 .52077 m .22931 .52077 L p .22941 .52095 L 1 0 0 r
F P
0 g
s
.21795 .53808 m .22931 .52077 L .22941 .52095 L 0 1 0 r
F
.21795 .53808 m .22941 .52095 L .23176 .52506 L F
.21795 .53808 m .22539 .52139 L .22931 .52077 L p F P
0 g
s
.23178 .52506 m .22941 .52095 L .23676 .5288 L 1 0 0 r
F
.22931 .52077 m .23676 .5288 L p .22941 .52095 L F P
0 g
s
.23156 .51636 m .24264 .52701 L p .22864 .51871 L 1 0 0 r
F P
0 g
s
.22864 .5187 m .23156 .51636 L .22864 .51871 L 1 0 0 r
F
.22931 .52077 m .22539 .52139 L p .22836 .51893 L 0 1 0 r
F P
0 g
s
.2305 .53475 m .21795 .53808 L p .23129 .5255 L 0 1 0 r
F P
0 g
s
.23391 .53152 m .23313 .52918 L .23446 .53144 L 0 0 1 r
F
.2308 .53198 m .23313 .52918 L p .23391 .53152 L F P
0 g
s
.23527 .53394 m .2308 .53198 L p .23389 .53153 L 0 0 1 r
F P
0 g
s
.23129 .5255 m .23311 .52911 L .2305 .53475 L 0 1 0 r
F
.23314 .52917 m .23313 .52918 L p .23311 .52911 L F P
0 g
s
.23313 .52918 m .2305 .53475 L p .23311 .52911 L 0 1 0 r
F P
0 g
s
.2305 .53475 m .23313 .52918 L p .23446 .53144 L 0 1 0 r
F P
0 g
s
.23676 .5288 m .24778 .53947 L p .23448 .53144 L 1 0 0 r
F P
0 g
s
.23448 .53143 m .23676 .5288 L .23448 .53144 L 1 0 0 r
F
.23528 .53394 m .2305 .53475 L p .23414 .53171 L 0 1 0 r
F P
0 g
s
.23556 .5479 m .2231 .55132 L p .23701 .53814 L 0 1 0 r
F P
0 g
s
.23556 .5479 m .23863 .54143 L p .24016 .54405 L 0 1 0 r
F P
0 g
s
.24213 .54739 m .24209 .54737 L p .24018 .54405 L 0 0 1 r
F P
0 g
s
.24016 .54405 m .24018 .54405 L .24209 .54737 L 0 0 1 r
F
.24018 .54405 m .25381 .54208 L .24213 .54739 L F
.26524 .5471 m .25876 .55466 L .24736 .54967 L p F P
0 g
s
.27829 .53311 m .27145 .54486 L .25971 .54476 L p 0 1 0 r
F P
0 g
s
.25971 .54476 m .26664 .53194 L .27829 .53311 L p 0 1 0 r
F P
0 g
s
.24736 .54967 m .25381 .54208 L .26524 .5471 L p 0 0 1 r
F P
0 g
s
.2419 .54114 m .25285 .55183 L p .24018 .54405 L 1 0 0 r
F P
0 g
s
.24017 .54403 m .2419 .54114 L .24018 .54405 L 1 0 0 r
F
.23556 .5479 m .24016 .54405 L .24101 .54672 L 0 1 0 r
F
.24107 .54693 m .24107 .54693 L p .24101 .54672 L F P
0 g
s
.24101 .54672 m .24107 .54693 L .24107 .54693 L 1 0 0 r
F
.24107 .54693 m .23556 .5479 L p .24101 .54672 L 0 1 0 r
F P
0 g
s
.24018 .54405 m .25285 .55183 L .24107 .54693 L 1 0 0 r
F
.24018 .54405 m .24107 .54693 L .24101 .54672 L F
.23998 .54366 m .2419 .54114 L .24017 .54404 L F
.24297 .55029 m .2412 .54715 L .24298 .5503 L F
.24107 .54693 m .24736 .54967 L p .24296 .55031 L 0 0 1 r
F P
0 g
s
.24264 .55004 m .2412 .54715 L .24297 .55029 L 1 0 0 r
F
.24219 .55042 m .24107 .54693 L .24296 .55031 L 0 0 1 r
F
.24107 .54693 m .24107 .54693 L p .2412 .54715 L 0 1 0 r
F P
0 g
s
.22952 .55224 m .24107 .54693 L .24107 .54693 L 0 0 1 r
F
.22952 .55224 m .24107 .54693 L .24219 .55042 L F
.21687 .56725 m .22317 .55977 L .23458 .56471 L p F P
0 g
s
.24095 .55722 m .23458 .56471 L .22317 .55977 L p 0 0 1 r
F P
0 g
s
.22317 .55977 m .22952 .55224 L .24095 .55722 L p 0 0 1 r
F P
0 g
s
.24402 .55359 m .2413 .55377 L p .24297 .55029 L 1 0 0 r
F P
0 g
s
.24095 .55722 m .22952 .55224 L p .24296 .55031 L 0 0 1 r
F P
0 g
s
.24297 .55029 m .24298 .5503 L .24402 .55359 L 1 0 0 r
F
.24736 .54967 m .24449 .55305 L p .24301 .5504 L 0 0 1 r
F P
0 g
s
.24298 .5503 m .24736 .54967 L .24301 .5504 L 0 0 1 r
F
.24572 .55652 m .24572 .55651 L .24573 .55653 L 1 0 0 r
F
.24573 .55653 m .24452 .55302 L .24644 .55643 L 0 0 1 r
F
.24568 .55643 m .24572 .55651 L .24572 .55652 L 1 0 0 r
F
.24571 .55653 m .24402 .55359 L .24572 .55652 L 0 1 0 r
F
.24571 .55653 m .24567 .55642 L .24573 .55653 L 0 0 1 r
F
.24567 .55642 m .24452 .55302 L .24573 .55653 L F
.24402 .5536 m .24402 .55359 L p .24571 .55653 L 0 1 0 r
F P
0 g
s
.24402 .5536 m .24403 .55359 L p .24571 .55653 L 0 0 1 r
F P
0 g
s
.24403 .55359 m .24452 .55302 L p .24567 .55642 L 0 0 1 r
F P
0 g
s
.24402 .55359 m .24403 .55359 L p .24572 .55652 L 1 0 0 r
F P
0 g
s
.24403 .55359 m .24568 .55643 L .24572 .55652 L 1 0 0 r
F
.24403 .55359 m .24567 .55642 L .24571 .55653 L 0 0 1 r
F
.24403 .55359 m .24426 .55357 L p .24568 .55643 L 1 0 0 r
F P
0 g
s
.24452 .55302 m .24736 .54967 L p .24644 .55643 L 0 0 1 r
F P
0 g
s
.24426 .55357 m .24698 .5534 L p .24572 .55651 L 1 0 0 r
F P
0 g
s
.24426 .55357 m .24572 .55651 L .24568 .55643 L 1 0 0 r
F
.24698 .5534 m .24403 .55359 L p .24298 .5503 L F P
0 g
s
.24403 .55359 m .24402 .55359 L p .24298 .5503 L 1 0 0 r
F P
0 g
s
.24296 .55031 m .24298 .5503 L .24301 .5504 L 0 0 1 r
F
.244 .55353 m .24297 .55029 L .24402 .55359 L 0 1 0 r
F
.24402 .5536 m .24095 .55722 L p .24296 .55031 L 0 0 1 r
F P
0 g
s
.24259 .55066 m .24296 .55031 L .244 .55353 L 0 1 0 r
F
.24296 .55031 m .24297 .55029 L .244 .55353 L F
.24402 .55359 m .24402 .5536 L p .244 .55353 L F P
0 g
s
.24449 .55305 m .24402 .5536 L p .24296 .55031 L 0 0 1 r
F P
0 g
s
.22821 .56434 m .24107 .54693 L .2412 .54715 L 0 1 0 r
F
.24296 .55031 m .2412 .54715 L .24297 .55029 L F
.22821 .56434 m .2412 .54715 L .24296 .55031 L F
.22821 .56434 m .23556 .5479 L .24107 .54693 L p F P
0 g
s
.25285 .55183 m .24698 .5534 L .24107 .54693 L p 1 0 0 r
F P
0 g
s
.24259 .55066 m .244 .55353 L .24058 .56085 L 0 1 0 r
F
.24402 .5536 m .24058 .56085 L p .244 .55353 L F P
0 g
s
.24058 .56085 m .22821 .56434 L p .24259 .55066 L 0 1 0 r
F P
0 g
s
.24058 .56085 m .24402 .5536 L p .24571 .55653 L 0 1 0 r
F P
0 g
s
.24107 .54693 m .24698 .5534 L p .24298 .5503 L 1 0 0 r
F P
0 g
s
.24698 .5534 m .25787 .56409 L p .24573 .55653 L 1 0 0 r
F P
0 g
s
.24572 .55651 m .24698 .5534 L .24573 .55653 L 1 0 0 r
F
.24726 .55962 m .24719 .55963 L p .24724 .55958 L 0 1 0 r
F P
0 g
s
.24788 .56023 m .24671 .55972 L p .24741 .55942 L 0 0 1 r
F P
0 g
s
.24671 .55972 m .24671 .55972 L p .24663 .55948 L 0 1 0 r
F P
0 g
s
.24573 .55653 m .25787 .56409 L .2467 .55972 L 1 0 0 r
F
.24663 .55948 m .2467 .55972 L .2467 .55972 L F
.24573 .55653 m .2467 .55972 L .24663 .55948 L F
.24058 .56085 m .24571 .55653 L .24663 .55948 L 0 1 0 r
F
.24671 .55972 m .24058 .56085 L p .24663 .55948 L F P
0 g
s
.25787 .56409 m .252 .56556 L .2467 .55972 L p 1 0 0 r
F P
0 g
s
.24803 .56306 m .24928 .56563 L .24555 .5736 L 0 1 0 r
F
.24931 .5657 m .24555 .5736 L p .24928 .56563 L F P
0 g
s
.24555 .5736 m .23328 .57715 L p .24803 .56306 L 0 1 0 r
F P
0 g
s
.24555 .5736 m .24931 .5657 L p .25113 .56889 L 0 1 0 r
F P
0 g
s
.2467 .55972 m .252 .56556 L p .24839 .56273 L 1 0 0 r
F P
0 g
s
.252 .56556 m .26282 .57625 L p .25115 .56889 L 1 0 0 r
F P
0 g
s
.25114 .56887 m .252 .56556 L .25115 .56889 L 1 0 0 r
F
.25278 .57222 m .25262 .57225 L p .25273 .57212 L 0 1 0 r
F P
0 g
s
.25344 .57288 m .25218 .57233 L p .25293 .57199 L 0 0 1 r
F P
0 g
s
.25218 .57233 m .25218 .57233 L p .2521 .57207 L 0 1 0 r
F P
0 g
s
.25115 .56889 m .26282 .57625 L .25218 .57233 L 1 0 0 r
F
.2521 .57207 m .25218 .57233 L .25218 .57233 L F
.25115 .56889 m .25218 .57233 L .2521 .57207 L F
.24555 .5736 m .25113 .56889 L .2521 .57207 L 0 1 0 r
F
.25218 .57233 m .24555 .5736 L p .2521 .57207 L F P
0 g
s
.26282 .57625 m .25696 .57763 L .25218 .57233 L p 1 0 0 r
F P
0 g
s
.25335 .57534 m .25447 .57767 L .25047 .58615 L 0 1 0 r
F
.25449 .57773 m .25047 .58615 L p .25447 .57767 L F P
0 g
s
.25047 .58615 m .23829 .58976 L p .25335 .57534 L 0 1 0 r
F P
0 g
s
.25218 .57233 m .25696 .57763 L p .25368 .57504 L 1 0 0 r
F P
0 g
s
.2545 .57772 m .25478 .57771 L p .25638 .58102 L 1 0 0 r
F P
0 g
s
.25641 .58113 m .25642 .58109 L .25644 .58112 L 0 0 1 r
F
.25593 .58154 m .25641 .58113 L .2575 .58477 L 0 1 0 r
F
.25641 .58113 m .25742 .58447 L .2575 .58477 L F
.25742 .58447 m .26852 .57941 L .2575 .58477 L 0 0 1 r
F
.25641 .58113 m .25644 .58112 L .25742 .58447 L F
.25644 .58112 m .26852 .57941 L .25742 .58447 L F
.2575 .58477 m .2575 .58477 L p .2575 .58475 L 0 1 0 r
F P
0 g
s
.25644 .58112 m .26772 .58832 L .2575 .58477 L 1 0 0 r
F
.25696 .57763 m .26772 .58832 L p .25644 .58112 L F P
0 g
s
.25643 .58111 m .25696 .57763 L .25644 .58112 L 1 0 0 r
F
.2575 .58477 m .25047 .58615 L p .25593 .58154 L 0 1 0 r
F P
0 g
s
.25785 .58516 m .26186 .58962 L p .25885 .58722 L 1 0 0 r
F P
0 g
s
.25881 .58716 m .25785 .58516 L .25885 .58722 L 1 0 0 r
F
.25988 .58967 m .26186 .58962 L p .26159 .59322 L F P
0 g
s
.25988 .58967 m .26159 .59322 L .26154 .59314 L 1 0 0 r
F
.25959 .58968 m .2605 .5913 L .26069 .59333 L 0 0 1 r
F
.25959 .58968 m .26069 .59333 L .26069 .59337 L F
.26186 .58962 m .25959 .58968 L p .25885 .58722 L 1 0 0 r
F P
0 g
s
.26268 .59703 m .25577 .59406 L p .26069 .59337 L 0 0 1 r
F P
0 g
s
.25535 .5985 m .25958 .58969 L p .26157 .59325 L 0 1 0 r
F P
0 g
s
.25855 .5875 m .25956 .58963 L .25535 .5985 L 0 1 0 r
F
.25958 .58969 m .25535 .5985 L p .25956 .58963 L F P
0 g
s
.25535 .5985 m .24327 .60216 L p .25855 .5875 L 0 1 0 r
F P
0 g
s
.25959 .58968 m .25988 .58967 L p .26154 .59314 L 1 0 0 r
F P
0 g
s
.26157 .59325 m .26157 .5932 L .2616 .59324 L 0 0 1 r
F
.26107 .59367 m .26157 .59325 L .26268 .59703 L 0 1 0 r
F
.26157 .59325 m .26258 .5967 L .26268 .59703 L F
.26258 .5967 m .27332 .59159 L .26268 .59703 L 0 0 1 r
F
.26157 .59325 m .2616 .59324 L .26258 .5967 L F
.2616 .59324 m .27332 .59159 L .26258 .5967 L F
.26268 .59703 m .26268 .59703 L p .26268 .59701 L 0 1 0 r
F P
0 g
s
.2616 .59324 m .27256 .60029 L .26268 .59703 L 1 0 0 r
F
.26186 .58962 m .27256 .60029 L p .2616 .59324 L F P
0 g
s
.26159 .59322 m .26186 .58962 L .2616 .59324 L 1 0 0 r
F
.26268 .59703 m .25535 .5985 L p .26107 .59367 L 0 1 0 r
F P
0 g
s
.263 .59739 m .2667 .60153 L p .26391 .59929 L 1 0 0 r
F P
0 g
s
.26387 .59923 m .263 .59739 L .26391 .59929 L 1 0 0 r
F
.26488 .60156 m .2667 .60153 L p .26662 .60522 L F P
0 g
s
.26488 .60156 m .26662 .60522 L .26657 .60514 L 1 0 0 r
F
.26458 .60156 m .26551 .60324 L .26568 .60533 L 0 0 1 r
F
.26458 .60156 m .26568 .60533 L .26569 .60537 L F
.2667 .60153 m .26458 .60156 L p .26391 .59929 L 1 0 0 r
F P
0 g
s
.26771 .60912 m .26061 .60609 L p .26569 .60537 L 0 0 1 r
F P
0 g
s
.26019 .61066 m .26457 .60157 L p .2666 .60524 L 0 1 0 r
F P
0 g
s
.26363 .59954 m .26455 .60151 L .26019 .61066 L 0 1 0 r
F
.26457 .60157 m .26019 .61066 L p .26455 .60151 L F P
0 g
s
.26019 .61066 m .24819 .61435 L p .26363 .59954 L 0 1 0 r
F P
0 g
s
.26458 .60156 m .26488 .60156 L p .26657 .60514 L 1 0 0 r
F P
0 g
s
.2666 .60524 m .26661 .6052 L .26663 .60524 L 0 0 1 r
F
.26608 .60569 m .2666 .60524 L .26771 .60912 L 0 1 0 r
F
.2666 .60524 m .26761 .60876 L .26771 .60912 L F
.2666 .60524 m .27807 .60364 L .26772 .60912 L 0 0 1 r
F
.26772 .60912 m .26771 .60912 L p .26771 .6091 L 0 1 0 r
F P
0 g
s
.26663 .60524 m .27734 .61218 L .26771 .60912 L 1 0 0 r
F
.26771 .60912 m .26801 .60946 L p .26832 .61025 L F P
0 g
s
.2667 .60153 m .27734 .61218 L p .26663 .60524 L 1 0 0 r
F P
0 g
s
.26662 .60522 m .2667 .60153 L .26663 .60524 L 1 0 0 r
F
.26771 .60912 m .26019 .61066 L p .26608 .60569 L 0 1 0 r
F P
0 g
s
.27151 .61713 m .27152 .61709 L .27153 .61711 L 0 1 0 r
F
.27153 .61711 m .27153 .6171 L .27154 .61712 L 1 0 0 r
F
.27149 .61702 m .27153 .6171 L .27153 .61711 L F
.27151 .61713 m .27149 .61703 L .27154 .61712 L 0 0 1 r
F
.27149 .61703 m .27027 .61246 L .27154 .61712 L F
.26946 .61337 m .26947 .61337 L p .27153 .61711 L 1 0 0 r
F P
0 g
s
.26949 .61342 m .27027 .61246 L .27149 .61703 L 0 0 1 r
F
.26947 .61337 m .26978 .61337 L p .27149 .61702 L 1 0 0 r
F P
0 g
s
.26947 .61337 m .27149 .61702 L .27153 .61711 L 1 0 0 r
F
.26948 .61343 m .26949 .61342 L .27151 .61713 L 0 0 1 r
F
.26949 .61342 m .27149 .61703 L .27151 .61713 L F
.26946 .61338 m .26947 .61337 L p .26948 .61343 L F P
0 g
s
.26947 .61337 m .27027 .61246 L p .26948 .61343 L 0 0 1 r
F P
0 g
s
.26884 .61123 m .26885 .61123 L .26946 .61337 L 1 0 0 r
F
.27149 .61336 m .26947 .61337 L p .26885 .61123 L F P
0 g
s
.26947 .61337 m .26946 .61337 L p .26885 .61123 L 1 0 0 r
F P
0 g
s
.26978 .61337 m .27149 .61336 L p .27153 .6171 L 1 0 0 r
F P
0 g
s
.26978 .61337 m .27153 .6171 L .27149 .61702 L 1 0 0 r
F
.26858 .61148 m .26944 .61333 L .26497 .62264 L 0 1 0 r
F
.26946 .61338 m .26497 .62264 L p .26944 .61333 L F P
0 g
s
.26497 .62264 m .25308 .62635 L p .26858 .61148 L 0 1 0 r
F P
0 g
s
.26497 .62264 m .26946 .61338 L p .27151 .61713 L 0 1 0 r
F P
0 g
s
.25791 .63815 m .26497 .62264 L .27261 .62105 L p 0 1 0 r
F P
0 g
s
.25791 .63815 m .27261 .62105 L .27261 .62105 L 0 1 0 r
F
.27261 .62105 m .27261 .62105 L p .27261 .62105 L 1 0 0 r
F P
0 g
s
.27261 .62105 m .2729 .62137 L p .27318 .62212 L 1 0 0 r
F P
0 g
s
.27149 .61336 m .28207 .62398 L p .27154 .61712 L 1 0 0 r
F P
0 g
s
.27153 .6171 m .27149 .61336 L .27154 .61712 L 1 0 0 r
F
.27261 .62105 m .26497 .62264 L p .27098 .61758 L 0 1 0 r
F P
0 g
s
.2763 .62889 m .27631 .62886 L .27632 .62888 L 0 1 0 r
F
.27632 .62888 m .27632 .62887 L .27633 .62889 L 1 0 0 r
F
.27628 .62879 m .27632 .62887 L .27632 .62888 L F
.2763 .62889 m .27628 .6288 L .27633 .62889 L 0 0 1 r
F
.27628 .6288 m .27508 .62419 L .27633 .62889 L F
.27425 .62511 m .27426 .62511 L p .27632 .62888 L 1 0 0 r
F P
0 g
s
.27428 .62515 m .27508 .62419 L .27628 .6288 L 0 0 1 r
F
.27426 .62511 m .27458 .62511 L p .27628 .62879 L 1 0 0 r
F P
0 g
s
.27426 .62511 m .27628 .62879 L .27632 .62888 L 1 0 0 r
F
.27427 .62516 m .27428 .62515 L .2763 .62889 L 0 0 1 r
F
.27428 .62515 m .27628 .6288 L .2763 .62889 L F
.27425 .62512 m .27426 .62511 L p .27427 .62516 L F P
0 g
s
.27426 .62511 m .27508 .62419 L p .27427 .62516 L 0 0 1 r
F P
0 g
s
.27368 .62305 m .27368 .62306 L .27425 .62511 L 1 0 0 r
F
.27622 .62511 m .27426 .62511 L p .27368 .62306 L F P
0 g
s
.27426 .62511 m .27425 .62511 L p .27368 .62306 L 1 0 0 r
F P
0 g
s
.27458 .62511 m .27622 .62511 L p .27632 .62887 L 1 0 0 r
F P
0 g
s
.27458 .62511 m .27632 .62887 L .27628 .62879 L 1 0 0 r
F
.27342 .62329 m .27424 .62507 L .26972 .63443 L 0 1 0 r
F
.27425 .62512 m .26972 .63443 L p .27424 .62507 L F P
0 g
s
.26972 .63443 m .25791 .63815 L p .27342 .62329 L 0 1 0 r
F P
0 g
s
.26972 .63443 m .27425 .62512 L p .2763 .62889 L 0 1 0 r
F P
0 g
s
.2627 .64976 m .26972 .63443 L .27738 .63282 L p 0 1 0 r
F P
0 g
s
.2627 .64976 m .27738 .63282 L .27738 .63282 L 0 1 0 r
F
.27737 .63282 m .27738 .63282 L p .27738 .63282 L 1 0 0 r
F P
0 g
s
.27738 .63282 m .27765 .63313 L p .27792 .63386 L 1 0 0 r
F P
0 g
s
.27622 .62511 m .28674 .63569 L p .27633 .62889 L 1 0 0 r
F P
0 g
s
.27632 .62887 m .27622 .62511 L .27633 .62889 L 1 0 0 r
F
.27738 .63282 m .26972 .63443 L p .27577 .62935 L 0 1 0 r
F P
0 g
s
.27442 .64604 m .2627 .64976 L p .27815 .635 L 0 1 0 r
F P
0 g
s
.27442 .64604 m .27895 .63679 L p .28098 .64055 L 0 1 0 r
F P
0 g
s
.28098 .64055 m .29201 .63902 L .28201 .64443 L 0 0 1 r
F
.28571 .64599 m .29201 .63902 L .30289 .64363 L p F P
0 g
s
.2809 .63679 m .29136 .64732 L p .281 .64054 L 1 0 0 r
F P
0 g
s
.28099 .64052 m .2809 .63679 L .281 .64054 L 1 0 0 r
F
.28345 .64504 m .28201 .64443 L p .28287 .64397 L 0 0 1 r
F P
0 g
s
.28302 .64636 m .28222 .64483 L .28302 .64636 L 1 0 0 r
F
.28201 .64443 m .28571 .64599 L p .28301 .64637 L 0 0 1 r
F P
0 g
s
.28571 .64599 m .29657 .65057 L p .28556 .65208 L 0 0 1 r
F P
0 g
s
.29136 .64732 m .28552 .6484 L .28201 .64443 L p 1 0 0 r
F P
0 g
s
.281 .64054 m .29136 .64732 L .28201 .64443 L 1 0 0 r
F
.26857 .64835 m .28201 .64443 L .28201 .64443 L 0 0 1 r
F
.28281 .64619 m .28222 .64483 L .28302 .64636 L 1 0 0 r
F
.26857 .64835 m .28201 .64443 L .28301 .64637 L 0 0 1 r
F
.28201 .64443 m .28201 .64443 L p .28222 .64483 L 0 1 0 r
F P
0 g
s
.26745 .66118 m .27442 .64604 L .28201 .64443 L p 0 1 0 r
F P
0 g
s
.26745 .66118 m .28201 .64443 L .28302 .64636 L 0 1 0 r
F
.28201 .64443 m .28552 .6484 L p .28302 .64636 L 1 0 0 r
F P
0 g
s
.28356 .64838 m .28552 .6484 L p .28555 .65206 L 1 0 0 r
F P
0 g
s
.27907 .65747 m .26745 .66118 L p .28277 .6466 L 0 1 0 r
F P
0 g
s
.28356 .64838 m .27907 .65747 L p .28277 .6466 L 0 1 0 r
F P
0 g
s
.28552 .6484 m .29593 .65887 L p .28556 .65208 L 1 0 0 r
F P
0 g
s
.28555 .65206 m .28552 .6484 L .28556 .65208 L 1 0 0 r
F
.28357 .64842 m .28511 .6513 L .28499 .65254 L 0 1 0 r
F
.48389 .62658 m .49077 .61714 L .50115 .61951 L p 1 0 0 r
F P
0 g
s
.50807 .6108 m .50115 .61951 L .49077 .61714 L p 1 0 0 r
F P
0 g
s
.32142 .62155 m .32794 .61235 L .33873 .61583 L p 0 1 0 r
F P
0 g
s
.33873 .61583 m .3452 .60805 L .35588 .61291 L p 0 1 0 r
F P
0 g
s
.3452 .60805 m .33873 .61583 L .32794 .61235 L p 0 1 0 r
F P
0 g
s
.31814 .65967 m .3245 .65279 L .33524 .65734 L p 0 0 1 r
F P
0 g
s
.3245 .65279 m .31814 .65967 L .30737 .65513 L p 0 0 1 r
F P
0 g
s
.58102 .67816 m .58809 .66816 L .59807 .66766 L p 0 1 0 r
F P
0 g
s
.36305 .65954 m .36956 .65265 L .3802 .6572 L p 0 0 1 r
F P
0 g
s
.36956 .65265 m .36305 .65954 L .35238 .655 L p 0 0 1 r
F P
0 g
s
.5567 .69306 m .56379 .68527 L .57395 .68737 L p 0 1 0 r
F P
0 g
s
.58102 .67816 m .57395 .68737 L .56379 .68527 L p 0 1 0 r
F P
0 g
s
.40797 .6594 m .41462 .65251 L .42517 .65707 L p 0 0 1 r
F P
0 g
s
.41462 .65251 m .40797 .6594 L .39739 .65486 L p 0 0 1 r
F P
0 g
s
.39404 .62554 m .40056 .6207 L .41107 .62813 L p 0 1 0 r
F P
0 g
s
.40056 .6207 m .39404 .62554 L .38352 .61873 L p 0 1 0 r
F P
0 g
s
.41826 .67317 m .42502 .66326 L .43563 .66422 L p 1 0 0 r
F P
0 g
s
.49783 .65913 m .50476 .65224 L .51513 .6568 L p 0 0 1 r
F P
0 g
s
.50476 .65224 m .49783 .65913 L .48743 .65459 L p 0 0 1 r
F P
0 g
s
.30385 .63062 m .31046 .61974 L .32142 .62155 L p 0 1 0 r
F P
0 g
s
.32794 .61235 m .32142 .62155 L .31046 .61974 L p 0 1 0 r
F P
0 g
s
.54276 .659 m .54983 .65211 L .56011 .65666 L p 0 0 1 r
F P
0 g
s
.54983 .65211 m .54276 .659 L .53246 .65445 L p 0 0 1 r
F P
0 g
s
.59492 .65197 m .5877 .65886 L .57749 .65432 L p 0 0 1 r
F P
0 g
s
.56379 .68527 m .5567 .69306 L .54645 .68945 L p 0 1 0 r
F P
0 g
s
.63265 .65873 m .64 .65184 L .6501 .65639 L p 0 0 1 r
F P
0 g
s
.64 .65184 m .63265 .65873 L .62253 .65418 L p 0 0 1 r
F P
0 g
s
.65638 .51296 m .64995 .53377 L .64073 .5424 L p 0 1 0 r
F P
0 g
s
.64073 .5424 m .64733 .52277 L .65638 .51296 L p 0 1 0 r
F P
0 g
s
.67761 .65859 m .6851 .6517 L .6951 .65625 L p 0 0 1 r
F P
0 g
s
.6851 .6517 m .67761 .65859 L .66758 .65405 L p 0 0 1 r
F P
0 g
s
.5357 .61104 m .54276 .60446 L .5531 .61063 L p 1 0 0 r
F P
0 g
s
.54276 .60446 m .5357 .61104 L .52538 .60641 L p 1 0 0 r
F P
0 g
s
.33198 .695 m .33828 .6901 L .34896 .69554 L p 1 0 0 r
F P
0 g
s
.33828 .6901 m .33198 .695 L .32142 .68781 L p 1 0 0 r
F P
0 g
s
.66013 .47949 m .66216 .47167 L .66239 .47374 L p 0 1 0 r
F P
0 g
s
.50137 .68436 m .50833 .67953 L .51873 .6856 L p 0 1 0 r
F P
0 g
s
.50833 .67953 m .50137 .68436 L .49097 .67751 L p 0 1 0 r
F P
0 g
s
.35963 .70016 m .36615 .69307 L .37686 .69637 L p 1 0 0 r
F P
0 g
s
.36615 .69307 m .35963 .70016 L .34896 .69554 L p 1 0 0 r
F P
0 g
s
.46659 .63487 m .47345 .62493 L .48389 .62658 L p 1 0 0 r
F P
0 g
s
.49077 .61714 m .48389 .62658 L .47345 .62493 L p 1 0 0 r
F P
0 g
s
.35588 .61291 m .36235 .60631 L .37296 .6123 L p 0 1 0 r
F P
0 g
s
.36235 .60631 m .35588 .61291 L .3452 .60805 L p 0 1 0 r
F P
0 g
s
.37686 .69637 m .38347 .68815 L .39418 .69041 L p 1 0 0 r
F P
0 g
s
.40086 .68133 m .39418 .69041 L .38347 .68815 L p 1 0 0 r
F P
0 g
s
.63938 .58206 m .63266 .59903 L .6231 .60445 L p 0 1 0 r
F P
0 g
s
.6231 .60445 m .62995 .58858 L .63938 .58206 L p 0 1 0 r
F P
0 g
s
.64841 .72086 m .64027 .71613 L .62941 .69907 L p 1 0 0 r
F P
0 g
s
.62941 .69907 m .63735 .70224 L .64841 .72086 L p 1 0 0 r
F P
0 g
s
.33524 .65734 m .34166 .65044 L .35238 .655 L p 0 0 1 r
F P
0 g
s
.34166 .65044 m .33524 .65734 L .3245 .65279 L p 0 0 1 r
F P
0 g
s
.3802 .6572 m .38677 .6503 L .39739 .65486 L p 0 0 1 r
F P
0 g
s
.38677 .6503 m .3802 .6572 L .36956 .65265 L p 0 0 1 r
F P
0 g
s
.38347 .68815 m .37686 .69637 L .36615 .69307 L p 1 0 0 r
F P
0 g
s
.47015 .65693 m .47699 .65003 L .48743 .65459 L p 0 0 1 r
F P
0 g
s
.38352 .61873 m .39003 .61352 L .40056 .6207 L p 0 1 0 r
F P
0 g
s
.39003 .61352 m .38352 .61873 L .37296 .6123 L p 0 1 0 r
F P
0 g
s
.51513 .6568 m .52212 .64989 L .53246 .65445 L p 0 0 1 r
F P
0 g
s
.52212 .64989 m .51513 .6568 L .50476 .65224 L p 0 0 1 r
F P
0 g
s
.57068 .61347 m .56344 .61772 L .5531 .61063 L p 1 0 0 r
F P
0 g
s
.56011 .65666 m .56724 .64976 L .57749 .65432 L p 0 0 1 r
F P
0 g
s
.56724 .64976 m .56011 .65666 L .54983 .65211 L p 0 0 1 r
F P
0 g
s
.52908 .69113 m .53613 .68508 L .54645 .68945 L p 0 1 0 r
F P
0 g
s
.53613 .68508 m .52908 .69113 L .51873 .6856 L p 0 1 0 r
F P
0 g
s
.6501 .65639 m .65751 .64948 L .66758 .65405 L p 0 0 1 r
F P
0 g
s
.65751 .64948 m .6501 .65639 L .64 .65184 L p 0 0 1 r
F P
0 g
s
.66115 .46753 m .66216 .47167 L p .65118 .49035 L 0 1 0 r
F P
0 g
s
.66216 .47167 m .66013 .47949 L .65118 .49035 L p 0 1 0 r
F P
0 g
s
.70266 .64935 m .6951 .65625 L .6851 .6517 L p 0 0 1 r
F P
0 g
s
.32142 .68781 m .32763 .68377 L .33828 .6901 L p 1 0 0 r
F P
0 g
s
.32763 .68377 m .32142 .68781 L .3109 .67961 L p 1 0 0 r
F P
0 g
s
.49097 .67751 m .4979 .67298 L .50833 .67953 L p 0 1 0 r
F P
0 g
s
.4979 .67298 m .49097 .67751 L .48055 .67032 L p 0 1 0 r
F P
0 g
s
.62353 .6721 m .61575 .67064 L .60514 .65734 L p 1 0 0 r
F P
0 g
s
.60514 .65734 m .61278 .65748 L .62353 .6721 L p 1 0 0 r
F P
0 g
s
.40086 .68133 m .40758 .67188 L .41826 .67317 L p 1 0 0 r
F P
0 g
s
.42502 .66326 m .41826 .67317 L .40758 .67188 L p 1 0 0 r
F P
0 g
s
.63266 .59903 m .62585 .61485 L .61618 .61921 L p 0 1 0 r
F P
0 g
s
.30644 .66822 m .30045 .67033 L .29009 .65993 L p 1 0 0 r
F P
0 g
s
.29009 .65993 m .29593 .65887 L .30644 .66822 L p 1 0 0 r
F P
0 g
s
.30737 .65513 m .31372 .64822 L .3245 .65279 L p 0 0 1 r
F P
0 g
s
.31372 .64822 m .30737 .65513 L .29657 .65057 L p 0 0 1 r
F P
0 g
s
.35238 .655 m .35886 .64808 L .36956 .65265 L p 0 0 1 r
F P
0 g
s
.35886 .64808 m .35238 .655 L .34166 .65044 L p 0 0 1 r
F P
0 g
s
.3109 .67961 m .31701 .6765 L .32763 .68377 L p 1 0 0 r
F P
0 g
s
.31701 .6765 m .3109 .67961 L .30045 .67033 L p 1 0 0 r
F P
0 g
s
.39739 .65486 m .40402 .64794 L .41462 .65251 L p 0 0 1 r
F P
0 g
s
.40402 .64794 m .39739 .65486 L .38677 .6503 L p 0 0 1 r
F P
0 g
s
.56379 .68527 m .57089 .67681 L .58102 .67816 L p 0 1 0 r
F P
0 g
s
.58809 .66816 m .58102 .67816 L .57089 .67681 L p 0 1 0 r
F P
0 g
s
.30045 .67033 m .30644 .66822 L .31701 .6765 L p 1 0 0 r
F P
0 g
s
.48743 .65459 m .49434 .64767 L .50476 .65224 L p 0 0 1 r
F P
0 g
s
.49434 .64767 m .48743 .65459 L .47699 .65003 L p 0 0 1 r
F P
0 g
s
.49077 .61714 m .49769 .60796 L .50807 .6108 L p 1 0 0 r
F P
0 g
s
.50807 .6108 m .51503 .60246 L .52538 .60641 L p 1 0 0 r
F P
0 g
s
.51503 .60246 m .50807 .6108 L .49769 .60796 L p 1 0 0 r
F P
0 g
s
.53246 .65445 m .53951 .64754 L .54983 .65211 L p 0 0 1 r
F P
0 g
s
.53951 .64754 m .53246 .65445 L .52212 .64989 L p 0 0 1 r
F P
0 g
s
.5531 .61063 m .56028 .60548 L .57068 .61347 L p 1 0 0 r
F P
0 g
s
.56028 .60548 m .5531 .61063 L .54276 .60446 L p 1 0 0 r
F P
0 g
s
.57749 .65432 m .58469 .6474 L .59492 .65197 L p 0 0 1 r
F P
0 g
s
.58469 .6474 m .57749 .65432 L .56724 .64976 L p 0 0 1 r
F P
0 g
s
.62253 .65418 m .62987 .64726 L .64 .65184 L p 0 0 1 r
F P
0 g
s
.31046 .61974 m .31703 .60966 L .32794 .61235 L p 0 1 0 r
F P
0 g
s
.32794 .61235 m .33444 .60383 L .3452 .60805 L p 0 1 0 r
F P
0 g
s
.33444 .60383 m .32794 .61235 L .31703 .60966 L p 0 1 0 r
F P
0 g
s
.66758 .65405 m .67506 .64713 L .6851 .6517 L p 0 0 1 r
F P
0 g
s
.67506 .64713 m .66758 .65405 L .65751 .64948 L p 0 0 1 r
F P
0 g
s
.52538 .60641 m .53241 .59913 L .54276 .60446 L p 1 0 0 r
F P
0 g
s
.53241 .59913 m .52538 .60641 L .51503 .60246 L p 1 0 0 r
F P
0 g
s
.37296 .6123 m .37945 .60666 L .39003 .61352 L p 0 1 0 r
F P
0 g
s
.37945 .60666 m .37296 .6123 L .36235 .60631 L p 0 1 0 r
F P
0 g
s
.48055 .67032 m .48745 .66602 L .4979 .67298 L p 0 1 0 r
F P
0 g
s
.48745 .66602 m .48055 .67032 L .47011 .66285 L p 0 1 0 r
F P
0 g
s
.34896 .69554 m .35542 .68909 L .36615 .69307 L p 1 0 0 r
F P
0 g
s
.35542 .68909 m .34896 .69554 L .33828 .6901 L p 1 0 0 r
F P
0 g
s
.54645 .68945 m .55354 .6823 L .56379 .68527 L p 0 1 0 r
F P
0 g
s
.55354 .6823 m .54645 .68945 L .53613 .68508 L p 0 1 0 r
F P
0 g
s
.3452 .60805 m .35168 .60084 L .36235 .60631 L p 0 1 0 r
F P
0 g
s
.35168 .60084 m .3452 .60805 L .33444 .60383 L p 0 1 0 r
F P
0 g
s
.66013 .47949 m .6538 .50181 L .64467 .51148 L p 0 1 0 r
F P
0 g
s
.64467 .51148 m .65118 .49035 L .66013 .47949 L p 0 1 0 r
F P
0 g
s
.47345 .62493 m .48033 .61515 L .49077 .61714 L p 1 0 0 r
F P
0 g
s
.49769 .60796 m .49077 .61714 L .48033 .61515 L p 1 0 0 r
F P
0 g
s
.38347 .68815 m .39014 .67943 L .40086 .68133 L p 1 0 0 r
F P
0 g
s
.40758 .67188 m .40086 .68133 L .39014 .67943 L p 1 0 0 r
F P
0 g
s
.64995 .53377 m .64339 .55328 L .63402 .56076 L p 0 1 0 r
F P
0 g
s
.63402 .56076 m .64073 .5424 L .64995 .53377 L p 0 1 0 r
F P
0 g
s
.57089 .67681 m .56379 .68527 L .55354 .6823 L p 0 1 0 r
F P
0 g
s
.51873 .6856 m .52576 .68003 L .53613 .68508 L p 0 1 0 r
F P
0 g
s
.52576 .68003 m .51873 .6856 L .50833 .67953 L p 0 1 0 r
F P
0 g
s
.3245 .65279 m .3309 .64586 L .34166 .65044 L p 0 0 1 r
F P
0 g
s
.3309 .64586 m .3245 .65279 L .31372 .64822 L p 0 0 1 r
F P
0 g
s
.36956 .65265 m .3761 .64572 L .38677 .6503 L p 0 0 1 r
F P
0 g
s
.3761 .64572 m .36956 .65265 L .35886 .64808 L p 0 0 1 r
F P
0 g
s
.63443 .68844 m .62648 .68556 L .61575 .67064 L p 1 0 0 r
F P
0 g
s
.61575 .67064 m .62353 .6721 L .63443 .68844 L p 1 0 0 r
F P
0 g
s
.65754 .46785 m .6607 .46348 L .66115 .46753 L p 0 1 0 r
F P
0 g
s
.65118 .49035 m .65754 .46785 L p .66115 .46753 L 0 1 0 r
F P
0 g
s
.4213 .64558 m .41462 .65251 L .40402 .64794 L p 0 0 1 r
F P
0 g
s
.50476 .65224 m .51173 .64531 L .52212 .64989 L p 0 0 1 r
F P
0 g
s
.51173 .64531 m .50476 .65224 L .49434 .64767 L p 0 0 1 r
F P
0 g
s
.54983 .65211 m .55695 .64517 L .56724 .64976 L p 0 0 1 r
F P
0 g
s
.55695 .64517 m .54983 .65211 L .53951 .64754 L p 0 0 1 r
F P
0 g
s
.31703 .60966 m .31046 .61974 L .29935 .61885 L p 0 1 0 r
F P
0 g
s
.64 .65184 m .6474 .6449 L .65751 .64948 L p 0 0 1 r
F P
0 g
s
.6474 .6449 m .64 .65184 L .62987 .64726 L p 0 0 1 r
F P
0 g
s
.6851 .6517 m .69264 .64476 L .70266 .64935 L p 0 0 1 r
F P
0 g
s
.69264 .64476 m .6851 .6517 L .67506 .64713 L p 0 0 1 r
F P
0 g
s
.47011 .66285 m .47697 .65873 L .48745 .66602 L p 0 1 0 r
F P
0 g
s
.47697 .65873 m .47011 .66285 L .45966 .65518 L p 0 1 0 r
F P
0 g
s
.40758 .67188 m .41434 .66213 L .42502 .66326 L p 1 0 0 r
F P
0 g
s
.43181 .65316 m .42502 .66326 L .41434 .66213 L p 1 0 0 r
F P
0 g
s
.36615 .69307 m .37273 .68535 L .38347 .68815 L p 1 0 0 r
F P
0 g
s
.37273 .68535 m .36615 .69307 L .35542 .68909 L p 1 0 0 r
F P
0 g
s
.39014 .67943 m .38347 .68815 L .37273 .68535 L p 1 0 0 r
F P
0 g
s
.54276 .60446 m .54989 .59849 L .56028 .60548 L p 1 0 0 r
F P
0 g
s
.54989 .59849 m .54276 .60446 L .53241 .59913 L p 1 0 0 r
F P
0 g
s
.65968 .74161 m .65132 .73518 L .64027 .71613 L p 1 0 0 r
F P
0 g
s
.64027 .71613 m .64841 .72086 L .65968 .74161 L p 1 0 0 r
F P
0 g
s
.48033 .61515 m .47345 .62493 L .46293 .62355 L p 1 0 0 r
F P
0 g
s
.57089 .67681 m .57799 .66762 L .58809 .66816 L p 0 1 0 r
F P
0 g
s
.59515 .65732 m .58809 .66816 L .57799 .66762 L p 0 1 0 r
F P
0 g
s
.29657 .65057 m .30289 .64363 L .31372 .64822 L p 0 0 1 r
F P
0 g
s
.36235 .60631 m .36883 .60019 L .37945 .60666 L p 0 1 0 r
F P
0 g
s
.36883 .60019 m .36235 .60631 L .35168 .60084 L p 0 1 0 r
F P
0 g
s
.40714 .61611 m .40056 .6207 L .39003 .61352 L p 0 1 0 r
F P
0 g
s
.34166 .65044 m .34813 .64349 L .35886 .64808 L p 0 0 1 r
F P
0 g
s
.34813 .64349 m .34166 .65044 L .3309 .64586 L p 0 0 1 r
F P
0 g
s
.38677 .6503 m .39338 .64336 L .40402 .64794 L p 0 0 1 r
F P
0 g
s
.39338 .64336 m .38677 .6503 L .3761 .64572 L p 0 0 1 r
F P
0 g
s
.47699 .65003 m .48389 .64308 L .49434 .64767 L p 0 0 1 r
F P
0 g
s
.48389 .64308 m .47699 .65003 L .46651 .64545 L p 0 0 1 r
F P
0 g
s
.52212 .64989 m .52915 .64294 L .53951 .64754 L p 0 0 1 r
F P
0 g
s
.52915 .64294 m .52212 .64989 L .51173 .64531 L p 0 0 1 r
F P
0 g
s
.45966 .65518 m .46647 .65117 L .47697 .65873 L p 0 1 0 r
F P
0 g
s
.33828 .6901 m .34468 .68438 L .35542 .68909 L p 1 0 0 r
F P
0 g
s
.34468 .68438 m .33828 .6901 L .32763 .68377 L p 1 0 0 r
F P
0 g
s
.56724 .64976 m .57442 .64281 L .58469 .6474 L p 0 0 1 r
F P
0 g
s
.57442 .64281 m .56724 .64976 L .55695 .64517 L p 0 0 1 r
F P
0 g
s
.50833 .67953 m .51534 .67437 L .52576 .68003 L p 0 1 0 r
F P
0 g
s
.51534 .67437 m .50833 .67953 L .4979 .67298 L p 0 1 0 r
F P
0 g
s
.65751 .64948 m .66497 .64253 L .67506 .64713 L p 0 0 1 r
F P
0 g
s
.66497 .64253 m .65751 .64948 L .6474 .6449 L p 0 0 1 r
F P
0 g
s
.71026 .6424 m .70266 .64935 L .69264 .64476 L p 0 0 1 r
F P
0 g
s
.53613 .68508 m .54322 .67852 L .55354 .6823 L p 0 1 0 r
F P
0 g
s
.54322 .67852 m .53613 .68508 L .52576 .68003 L p 0 1 0 r
F P
0 g
s
.66015 .46125 m .6607 .46348 L .65754 .46785 L p 0 1 0 r
F P
0 g
s
.49769 .60796 m .50463 .59911 L .51503 .60246 L p 1 0 0 r
F P
0 g
s
.51503 .60246 m .52203 .59455 L .53241 .59913 L p 1 0 0 r
F P
0 g
s
.52203 .59455 m .51503 .60246 L .50463 .59911 L p 1 0 0 r
F P
0 g
s
.31703 .60966 m .32357 .60033 L .33444 .60383 L p 0 1 0 r
F P
0 g
s
.33444 .60383 m .34093 .59595 L .35168 .60084 L p 0 1 0 r
F P
0 g
s
.34093 .59595 m .33444 .60383 L .32357 .60033 L p 0 1 0 r
F P
0 g
s
.64339 .55328 m .63672 .57154 L .62721 .57788 L p 0 1 0 r
F P
0 g
s
.62721 .57788 m .63402 .56076 L .64339 .55328 L p 0 1 0 r
F P
0 g
s
.39014 .67943 m .39685 .67029 L .40758 .67188 L p 1 0 0 r
F P
0 g
s
.41434 .66213 m .40758 .67188 L .39685 .67029 L p 1 0 0 r
F P
0 g
s
.39003 .61352 m .39657 .60862 L .40714 .61611 L p 0 1 0 r
F P
0 g
s
.39657 .60862 m .39003 .61352 L .37945 .60666 L p 0 1 0 r
F P
0 g
s
.48033 .61515 m .48724 .60558 L .49769 .60796 L p 1 0 0 r
F P
0 g
s
.50463 .59911 m .49769 .60796 L .48724 .60558 L p 1 0 0 r
F P
0 g
s
.31372 .64822 m .3201 .64126 L .3309 .64586 L p 0 0 1 r
F P
0 g
s
.3201 .64126 m .31372 .64822 L .30289 .64363 L p 0 0 1 r
F P
0 g
s
.35886 .64808 m .36539 .64112 L .3761 .64572 L p 0 0 1 r
F P
0 g
s
.36539 .64112 m .35886 .64808 L .34813 .64349 L p 0 0 1 r
F P
0 g
s
.64549 .70667 m .63735 .70224 L .62648 .68556 L p 1 0 0 r
F P
0 g
s
.62648 .68556 m .63443 .68844 L .64549 .70667 L p 1 0 0 r
F P
0 g
s
.40402 .64794 m .41069 .64099 L .4213 .64558 L p 0 0 1 r
F P
0 g
s
.41069 .64099 m .40402 .64794 L .39338 .64336 L p 0 0 1 r
F P
0 g
s
.29935 .61885 m .306 .60783 L .31703 .60966 L p 0 1 0 r
F P
0 g
s
.32357 .60033 m .31703 .60966 L .306 .60783 L p 0 1 0 r
F P
0 g
s
.49434 .64767 m .5013 .64071 L .51173 .64531 L p 0 0 1 r
F P
0 g
s
.5013 .64071 m .49434 .64767 L .48389 .64308 L p 0 0 1 r
F P
0 g
s
.53951 .64754 m .54661 .64057 L .55695 .64517 L p 0 0 1 r
F P
0 g
s
.54661 .64057 m .53951 .64754 L .52915 .64294 L p 0 0 1 r
F P
0 g
s
.41434 .66213 m .42114 .65214 L .43181 .65316 L p 1 0 0 r
F P
0 g
s
.59193 .64044 m .58469 .6474 L .57442 .64281 L p 0 0 1 r
F P
0 g
s
.55354 .6823 m .56066 .67454 L .57089 .67681 L p 0 1 0 r
F P
0 g
s
.57799 .66762 m .57089 .67681 L .56066 .67454 L p 0 1 0 r
F P
0 g
s
.62987 .64726 m .63725 .6403 L .6474 .6449 L p 0 0 1 r
F P
0 g
s
.63725 .6403 m .62987 .64726 L .61969 .64267 L p 0 0 1 r
F P
0 g
s
.53241 .59913 m .5395 .5924 L .54989 .59849 L p 1 0 0 r
F P
0 g
s
.5395 .5924 m .53241 .59913 L .52203 .59455 L p 1 0 0 r
F P
0 g
s
.57799 .66762 m .5851 .65763 L .59515 .65732 L p 0 1 0 r
F P
0 g
s
.6022 .64559 m .59515 .65732 L .5851 .65763 L p 0 1 0 r
F P
0 g
s
.67506 .64713 m .68258 .64016 L .69264 .64476 L p 0 0 1 r
F P
0 g
s
.68258 .64016 m .67506 .64713 L .66497 .64253 L p 0 0 1 r
F P
0 g
s
.56066 .67454 m .55354 .6823 L .54322 .67852 L p 0 1 0 r
F P
0 g
s
.32763 .68377 m .33394 .67885 L .34468 .68438 L p 1 0 0 r
F P
0 g
s
.33394 .67885 m .32763 .68377 L .31701 .6765 L p 1 0 0 r
F P
0 g
s
.4979 .67298 m .50488 .66817 L .51534 .67437 L p 0 1 0 r
F P
0 g
s
.50488 .66817 m .4979 .67298 L .48745 .66602 L p 0 1 0 r
F P
0 g
s
.65754 .46785 m .65986 .45888 L .66015 .46125 L p 0 1 0 r
F P
0 g
s
.35168 .60084 m .35816 .59417 L .36883 .60019 L p 0 1 0 r
F P
0 g
s
.35816 .59417 m .35168 .60084 L .34093 .59595 L p 0 1 0 r
F P
0 g
s
.35542 .68909 m .36195 .68196 L .37273 .68535 L p 1 0 0 r
F P
0 g
s
.36195 .68196 m .35542 .68909 L .34468 .68438 L p 1 0 0 r
F P
0 g
s
.46293 .62355 m .46982 .61349 L .48033 .61515 L p 1 0 0 r
F P
0 g
s
.48724 .60558 m .48033 .61515 L .46982 .61349 L p 1 0 0 r
F P
0 g
s
.6538 .50181 m .64733 .52277 L .63803 .53125 L p 0 1 0 r
F P
0 g
s
.63803 .53125 m .64467 .51148 L .6538 .50181 L p 0 1 0 r
F P
0 g
s
.37273 .68535 m .37936 .67708 L .39014 .67943 L p 1 0 0 r
F P
0 g
s
.39685 .67029 m .39014 .67943 L .37936 .67708 L p 1 0 0 r
F P
0 g
s
.3309 .64586 m .33735 .63888 L .34813 .64349 L p 0 0 1 r
F P
0 g
s
.33735 .63888 m .3309 .64586 L .3201 .64126 L p 0 0 1 r
F P
0 g
s
.3761 .64572 m .38269 .63875 L .39338 .64336 L p 0 0 1 r
F P
0 g
s
.38269 .63875 m .3761 .64572 L .36539 .64112 L p 0 0 1 r
F P
0 g
s
.56754 .60106 m .56028 .60548 L .54989 .59849 L p 1 0 0 r
F P
0 g
s
.37945 .60666 m .38597 .60139 L .39657 .60862 L p 0 1 0 r
F P
0 g
s
.38597 .60139 m .37945 .60666 L .36883 .60019 L p 0 1 0 r
F P
0 g
s
.42803 .63861 m .4213 .64558 L .41069 .64099 L p 0 0 1 r
F P
0 g
s
.46651 .64545 m .47339 .63847 L .48389 .64308 L p 0 0 1 r
F P
0 g
s
.51173 .64531 m .51874 .63833 L .52915 .64294 L p 0 0 1 r
F P
0 g
s
.51874 .63833 m .51173 .64531 L .5013 .64071 L p 0 0 1 r
F P
0 g
s
.37936 .67708 m .37273 .68535 L .36195 .68196 L p 1 0 0 r
F P
0 g
s
.55695 .64517 m .56411 .6382 L .57442 .64281 L p 0 0 1 r
F P
0 g
s
.56411 .6382 m .55695 .64517 L .54661 .64057 L p 0 0 1 r
F P
0 g
s
.63672 .57154 m .62995 .58858 L .62032 .59382 L p 0 1 0 r
F P
0 g
s
.62032 .59382 m .62721 .57788 L .63672 .57154 L p 0 1 0 r
F P
0 g
s
.6474 .6449 m .65485 .63792 L .66497 .64253 L p 0 0 1 r
F P
0 g
s
.65485 .63792 m .6474 .6449 L .63725 .6403 L p 0 0 1 r
F P
0 g
s
.52576 .68003 m .53284 .674 L .54322 .67852 L p 0 1 0 r
F P
0 g
s
.53284 .674 m .52576 .68003 L .51534 .67437 L p 0 1 0 r
F P
0 g
s
.69264 .64476 m .70023 .63778 L .71026 .6424 L p 0 0 1 r
F P
0 g
s
.70023 .63778 m .69264 .64476 L .68258 .64016 L p 0 0 1 r
F P
0 g
s
.31701 .6765 m .32323 .67244 L .33394 .67885 L p 1 0 0 r
F P
0 g
s
.32323 .67244 m .31701 .6765 L .30644 .66822 L p 1 0 0 r
F P
0 g
s
.65888 .45498 m .65986 .45888 L p .64852 .47859 L 0 1 0 r
F P
0 g
s
.65986 .45888 m .65754 .46785 L .64852 .47859 L p 0 1 0 r
F P
0 g
s
.5851 .65763 m .59221 .6468 L .6022 .64559 L p 0 1 0 r
F P
0 g
s
.48745 .66602 m .4944 .6615 L .50488 .66817 L p 0 1 0 r
F P
0 g
s
.4944 .6615 m .48745 .66602 L .47697 .65873 L p 0 1 0 r
F P
0 g
s
.39685 .67029 m .4036 .66077 L .41434 .66213 L p 1 0 0 r
F P
0 g
s
.42114 .65214 m .41434 .66213 L .4036 .66077 L p 1 0 0 r
F P
0 g
s
.30192 .65673 m .29593 .65887 L .28552 .6484 L p 1 0 0 r
F P
0 g
s
.28552 .6484 m .29136 .64732 L .30192 .65673 L p 1 0 0 r
F P
0 g
s
.30289 .64363 m .30925 .63664 L .3201 .64126 L p 0 0 1 r
F P
0 g
s
.30925 .63664 m .30289 .64363 L .29201 .63902 L p 0 0 1 r
F P
0 g
s
.34813 .64349 m .35463 .6365 L .36539 .64112 L p 0 0 1 r
F P
0 g
s
.35463 .6365 m .34813 .64349 L .33735 .63888 L p 0 0 1 r
F P
0 g
s
.30644 .66822 m .31255 .66509 L .32323 .67244 L p 1 0 0 r
F P
0 g
s
.31255 .66509 m .30644 .66822 L .29593 .65887 L p 1 0 0 r
F P
0 g
s
.39338 .64336 m .40002 .63637 L .41069 .64099 L p 0 0 1 r
F P
0 g
s
.40002 .63637 m .39338 .64336 L .38269 .63875 L p 0 0 1 r
F P
0 g
s
.54989 .59849 m .55709 .59318 L .56754 .60106 L p 1 0 0 r
F P
0 g
s
.55709 .59318 m .54989 .59849 L .5395 .5924 L p 1 0 0 r
F P
0 g
s
.29593 .65887 m .30192 .65673 L .31255 .66509 L p 1 0 0 r
F P
0 g
s
.48389 .64308 m .49082 .63609 L .5013 .64071 L p 0 0 1 r
F P
0 g
s
.49082 .63609 m .48389 .64308 L .47339 .63847 L p 0 0 1 r
F P
0 g
s
.52915 .64294 m .53623 .63595 L .54661 .64057 L p 0 0 1 r
F P
0 g
s
.53623 .63595 m .52915 .64294 L .51874 .63833 L p 0 0 1 r
F P
0 g
s
.48724 .60558 m .49418 .59628 L .50463 .59911 L p 1 0 0 r
F P
0 g
s
.50463 .59911 m .51162 .59063 L .52203 .59455 L p 1 0 0 r
F P
0 g
s
.51162 .59063 m .50463 .59911 L .49418 .59628 L p 1 0 0 r
F P
0 g
s
.67121 .76468 m .66259 .75641 L .65132 .73518 L p 1 0 0 r
F P
0 g
s
.65132 .73518 m .65968 .74161 L .67121 .76468 L p 1 0 0 r
F P
0 g
s
.306 .60783 m .3126 .59762 L .32357 .60033 L p 0 1 0 r
F P
0 g
s
.32357 .60033 m .3301 .59171 L .34093 .59595 L p 0 1 0 r
F P
0 g
s
.3301 .59171 m .32357 .60033 L .3126 .59762 L p 0 1 0 r
F P
0 g
s
.57442 .64281 m .58164 .63582 L .59193 .64044 L p 0 0 1 r
F P
0 g
s
.58164 .63582 m .57442 .64281 L .56411 .6382 L p 0 0 1 r
F P
0 g
s
.36883 .60019 m .37534 .59449 L .38597 .60139 L p 0 1 0 r
F P
0 g
s
.37534 .59449 m .36883 .60019 L .35816 .59417 L p 0 1 0 r
F P
0 g
s
.61969 .64267 m .62706 .63568 L .63725 .6403 L p 0 0 1 r
F P
0 g
s
.63149 .67472 m .62353 .6721 L .61278 .65748 L p 1 0 0 r
F P
0 g
s
.61278 .65748 m .62057 .6587 L .63149 .67472 L p 1 0 0 r
F P
0 g
s
.66497 .64253 m .67248 .63554 L .68258 .64016 L p 0 0 1 r
F P
0 g
s
.67248 .63554 m .66497 .64253 L .65485 .63792 L p 0 0 1 r
F P
0 g
s
.52203 .59455 m .52909 .58712 L .5395 .5924 L p 1 0 0 r
F P
0 g
s
.52909 .58712 m .52203 .59455 L .51162 .59063 L p 1 0 0 r
F P
0 g
s
.56066 .67454 m .56779 .66609 L .57799 .66762 L p 0 1 0 r
F P
0 g
s
.5851 .65763 m .57799 .66762 L .56779 .66609 L p 0 1 0 r
F P
0 g
s
.71791 .6354 m .71026 .6424 L .70023 .63778 L p 0 0 1 r
F P
0 g
s
.34093 .59595 m .34743 .58866 L .35816 .59417 L p 0 1 0 r
F P
0 g
s
.34743 .58866 m .34093 .59595 L .3301 .59171 L p 0 1 0 r
F P
0 g
s
.47697 .65873 m .48388 .65444 L .4944 .6615 L p 0 1 0 r
F P
0 g
s
.48388 .65444 m .47697 .65873 L .46647 .65117 L p 0 1 0 r
F P
0 g
s
.34468 .68438 m .35115 .6779 L .36195 .68196 L p 1 0 0 r
F P
0 g
s
.35115 .6779 m .34468 .68438 L .33394 .67885 L p 1 0 0 r
F P
0 g
s
.65677 .72696 m .64841 .72086 L .63735 .70224 L p 1 0 0 r
F P
0 g
s
.63735 .70224 m .64549 .70667 L .65677 .72696 L p 1 0 0 r
F P
0 g
s
.54322 .67852 m .55034 .6714 L .56066 .67454 L p 0 1 0 r
F P
0 g
s
.55034 .6714 m .54322 .67852 L .53284 .674 L p 0 1 0 r
F P
0 g
s
.46982 .61349 m .47673 .60359 L .48724 .60558 L p 1 0 0 r
F P
0 g
s
.49418 .59628 m .48724 .60558 L .47673 .60359 L p 1 0 0 r
F P
0 g
s
.3201 .64126 m .32652 .63426 L .33735 .63888 L p 0 0 1 r
F P
0 g
s
.32652 .63426 m .3201 .64126 L .30925 .63664 L p 0 0 1 r
F P
0 g
s
.65754 .46785 m .65118 .49035 L .64197 .4999 L p 0 1 0 r
F P
0 g
s
.64197 .4999 m .64852 .47859 L .65754 .46785 L p 0 1 0 r
F P
0 g
s
.51534 .67437 m .5224 .66881 L .53284 .674 L p 0 1 0 r
F P
0 g
s
.5224 .66881 m .51534 .67437 L .50488 .66817 L p 0 1 0 r
F P
0 g
s
.37936 .67708 m .38605 .66831 L .39685 .67029 L p 1 0 0 r
F P
0 g
s
.4036 .66077 m .39685 .67029 L .38605 .66831 L p 1 0 0 r
F P
0 g
s
.36539 .64112 m .37196 .63412 L .38269 .63875 L p 0 0 1 r
F P
0 g
s
.37196 .63412 m .36539 .64112 L .35463 .6365 L p 0 0 1 r
F P
0 g
s
.41069 .64099 m .4174 .63398 L .42803 .63861 L p 0 0 1 r
F P
0 g
s
.4174 .63398 m .41069 .64099 L .40002 .63637 L p 0 0 1 r
F P
0 g
s
.65491 .45588 m .65842 .45112 L .65888 .45498 L p 0 1 0 r
F P
0 g
s
.64852 .47859 m .65491 .45588 L p .65888 .45498 L 0 1 0 r
F P
0 g
s
.56779 .66609 m .56066 .67454 L .55034 .6714 L p 0 1 0 r
F P
0 g
s
.5013 .64071 m .50829 .63371 L .51874 .63833 L p 0 0 1 r
F P
0 g
s
.50829 .63371 m .5013 .64071 L .49082 .63609 L p 0 0 1 r
F P
0 g
s
.3126 .59762 m .306 .60783 L .29482 .60693 L p 0 1 0 r
F P
0 g
s
.54661 .64057 m .55375 .63357 L .56411 .6382 L p 0 0 1 r
F P
0 g
s
.55375 .63357 m .54661 .64057 L .53623 .63595 L p 0 0 1 r
F P
0 g
s
.46647 .65117 m .47335 .64704 L .48388 .65444 L p 0 1 0 r
F P
0 g
s
.47335 .64704 m .46647 .65117 L .45596 .64341 L p 0 1 0 r
F P
0 g
s
.63725 .6403 m .64468 .63329 L .65485 .63792 L p 0 0 1 r
F P
0 g
s
.64468 .63329 m .63725 .6403 L .62706 .63568 L p 0 0 1 r
F P
0 g
s
.64733 .52277 m .64073 .5424 L .63128 .54973 L p 0 1 0 r
F P
0 g
s
.63128 .54973 m .63803 .53125 L .64733 .52277 L p 0 1 0 r
F P
0 g
s
.68258 .64016 m .69015 .63315 L .70023 .63778 L p 0 0 1 r
F P
0 g
s
.69015 .63315 m .68258 .64016 L .67248 .63554 L p 0 0 1 r
F P
0 g
s
.5395 .5924 m .54664 .58627 L .55709 .59318 L p 1 0 0 r
F P
0 g
s
.54664 .58627 m .5395 .5924 L .52909 .58712 L p 1 0 0 r
F P
0 g
s
.4036 .66077 m .41039 .65095 L .42114 .65214 L p 1 0 0 r
F P
0 g
s
.42796 .64195 m .42114 .65214 L .41039 .65095 L p 1 0 0 r
F P
0 g
s
.36195 .68196 m .36855 .67421 L .37936 .67708 L p 1 0 0 r
F P
0 g
s
.36855 .67421 m .36195 .68196 L .35115 .6779 L p 1 0 0 r
F P
0 g
s
.38605 .66831 m .37936 .67708 L .36855 .67421 L p 1 0 0 r
F P
0 g
s
.35816 .59417 m .36466 .58797 L .37534 .59449 L p 0 1 0 r
F P
0 g
s
.36466 .58797 m .35816 .59417 L .34743 .58866 L p 0 1 0 r
F P
0 g
s
.40316 .60399 m .39657 .60862 L .38597 .60139 L p 0 1 0 r
F P
0 g
s
.25288 .63214 m .24668 .63916 L .23567 .63453 L p 0 0 1 r
F P
0 g
s
.29201 .63902 m .29835 .63201 L .30925 .63664 L p 0 0 1 r
F P
0 g
s
.33735 .63888 m .34383 .63187 L .35463 .6365 L p 0 0 1 r
F P
0 g
s
.34383 .63187 m .33735 .63888 L .32652 .63426 L p 0 0 1 r
F P
0 g
s
.38269 .63875 m .38932 .63173 L .40002 .63637 L p 0 0 1 r
F P
0 g
s
.38932 .63173 m .38269 .63875 L .37196 .63412 L p 0 0 1 r
F P
0 g
s
.45596 .64341 m .46279 .63938 L .47335 .64704 L p 0 1 0 r
F P
0 g
s
.47339 .63847 m .4803 .63145 L .49082 .63609 L p 0 0 1 r
F P
0 g
s
.4803 .63145 m .47339 .63847 L .46284 .63384 L p 0 0 1 r
F P
0 g
s
.51874 .63833 m .5258 .63131 L .53623 .63595 L p 0 0 1 r
F P
0 g
s
.5258 .63131 m .51874 .63833 L .50829 .63371 L p 0 0 1 r
F P
0 g
s
.56779 .66609 m .57493 .65691 L .5851 .65763 L p 0 1 0 r
F P
0 g
s
.59221 .6468 m .5851 .65763 L .57493 .65691 L p 0 1 0 r
F P
0 g
s
.33394 .67885 m .34035 .6731 L .35115 .6779 L p 1 0 0 r
F P
0 g
s
.34035 .6731 m .33394 .67885 L .32323 .67244 L p 1 0 0 r
F P
0 g
s
.64257 .69258 m .63443 .68844 L .62353 .6721 L p 1 0 0 r
F P
0 g
s
.62353 .6721 m .63149 .67472 L .64257 .69258 L p 1 0 0 r
F P
0 g
s
.56411 .6382 m .57131 .63118 L .58164 .63582 L p 0 0 1 r
F P
0 g
s
.57131 .63118 m .56411 .6382 L .55375 .63357 L p 0 0 1 r
F P
0 g
s
.50488 .66817 m .51192 .66302 L .5224 .66881 L p 0 1 0 r
F P
0 g
s
.51192 .66302 m .50488 .66817 L .4944 .6615 L p 0 1 0 r
F P
0 g
s
.65485 .63792 m .66234 .6309 L .67248 .63554 L p 0 0 1 r
F P
0 g
s
.66234 .6309 m .65485 .63792 L .64468 .63329 L p 0 0 1 r
F P
0 g
s
.70023 .63778 m .70786 .63076 L .71791 .6354 L p 0 0 1 r
F P
0 g
s
.70786 .63076 m .70023 .63778 L .69015 .63315 L p 0 0 1 r
F P
0 g
s
.65779 .44864 m .65842 .45112 L .65491 .45588 L p 0 1 0 r
F P
0 g
s
.3126 .59762 m .31917 .58818 L .3301 .59171 L p 0 1 0 r
F P
0 g
s
.3301 .59171 m .33662 .58373 L .34743 .58866 L p 0 1 0 r
F P
0 g
s
.33662 .58373 m .3301 .59171 L .31917 .58818 L p 0 1 0 r
F P
0 g
s
.27442 .64604 m .26745 .66118 L .25558 .66627 L p 0 1 0 r
F P
0 g
s
.25558 .66627 m .2627 .64976 L .27442 .64604 L p 0 1 0 r
F P
0 g
s
.49418 .59628 m .50116 .58729 L .51162 .59063 L p 1 0 0 r
F P
0 g
s
.51162 .59063 m .51865 .58257 L .52909 .58712 L p 1 0 0 r
F P
0 g
s
.51865 .58257 m .51162 .59063 L .50116 .58729 L p 1 0 0 r
F P
0 g
s
.53284 .674 m .53996 .66746 L .55034 .6714 L p 0 1 0 r
F P
0 g
s
.53996 .66746 m .53284 .674 L .5224 .66881 L p 0 1 0 r
F P
0 g
s
.38597 .60139 m .39253 .59644 L .40316 .60399 L p 0 1 0 r
F P
0 g
s
.39253 .59644 m .38597 .60139 L .37534 .59449 L p 0 1 0 r
F P
0 g
s
.30925 .63664 m .31565 .62961 L .32652 .63426 L p 0 0 1 r
F P
0 g
s
.31565 .62961 m .30925 .63664 L .29835 .63201 L p 0 0 1 r
F P
0 g
s
.47673 .60359 m .48367 .59389 L .49418 .59628 L p 1 0 0 r
F P
0 g
s
.50116 .58729 m .49418 .59628 L .48367 .59389 L p 1 0 0 r
F P
0 g
s
.35463 .6365 m .36118 .62947 L .37196 .63412 L p 0 0 1 r
F P
0 g
s
.36118 .62947 m .35463 .6365 L .34383 .63187 L p 0 0 1 r
F P
0 g
s
.38605 .66831 m .39279 .6591 L .4036 .66077 L p 1 0 0 r
F P
0 g
s
.41039 .65095 m .4036 .66077 L .39279 .6591 L p 1 0 0 r
F P
0 g
s
.29482 .60693 m .30149 .59577 L .3126 .59762 L p 0 1 0 r
F P
0 g
s
.31917 .58818 m .3126 .59762 L .30149 .59577 L p 0 1 0 r
F P
0 g
s
.40002 .63637 m .40671 .62933 L .4174 .63398 L p 0 0 1 r
F P
0 g
s
.40671 .62933 m .40002 .63637 L .38932 .63173 L p 0 0 1 r
F P
0 g
s
.57489 .59741 m .56754 .60106 L .55709 .59318 L p 1 0 0 r
F P
0 g
s
.49082 .63609 m .4978 .62906 L .50829 .63371 L p 0 0 1 r
F P
0 g
s
.4978 .62906 m .49082 .63609 L .4803 .63145 L p 0 0 1 r
F P
0 g
s
.53623 .63595 m .54335 .62892 L .55375 .63357 L p 0 0 1 r
F P
0 g
s
.54335 .62892 m .53623 .63595 L .5258 .63131 L p 0 0 1 r
F P
0 g
s
.58891 .62878 m .58164 .63582 L .57131 .63118 L p 0 0 1 r
F P
0 g
s
.52909 .58712 m .53619 .58024 L .54664 .58627 L p 1 0 0 r
F P
0 g
s
.53619 .58024 m .52909 .58712 L .51865 .58257 L p 1 0 0 r
F P
0 g
s
.62706 .63568 m .63447 .62864 L .64468 .63329 L p 0 0 1 r
F P
0 g
s
.63447 .62864 m .62706 .63568 L .61682 .63104 L p 0 0 1 r
F P
0 g
s
.64073 .5424 m .63402 .56076 L .62443 .56695 L p 0 1 0 r
F P
0 g
s
.62443 .56695 m .63128 .54973 L .64073 .5424 L p 0 1 0 r
F P
0 g
s
.41039 .65095 m .41721 .64087 L .42796 .64195 L p 1 0 0 r
F P
0 g
s
.43481 .63163 m .42796 .64195 L .41721 .64087 L p 1 0 0 r
F P
0 g
s
.67248 .63554 m .68004 .6285 L .69015 .63315 L p 0 0 1 r
F P
0 g
s
.68004 .6285 m .67248 .63554 L .66234 .6309 L p 0 0 1 r
F P
0 g
s
.34743 .58866 m .35393 .5819 L .36466 .58797 L p 0 1 0 r
F P
0 g
s
.35393 .5819 m .34743 .58866 L .33662 .58373 L p 0 1 0 r
F P
0 g
s
.72561 .62836 m .71791 .6354 L .70786 .63076 L p 0 0 1 r
F P
0 g
s
.4944 .6615 m .5014 .6567 L .51192 .66302 L p 0 1 0 r
F P
0 g
s
.5014 .6567 m .4944 .6615 L .48388 .65444 L p 0 1 0 r
F P
0 g
s
.32323 .67244 m .32955 .66749 L .34035 .6731 L p 1 0 0 r
F P
0 g
s
.32955 .66749 m .32323 .67244 L .31255 .66509 L p 1 0 0 r
F P
0 g
s
.55034 .6714 m .55749 .66365 L .56779 .66609 L p 0 1 0 r
F P
0 g
s
.57493 .65691 m .56779 .66609 L .55749 .66365 L p 0 1 0 r
F P
0 g
s
.65491 .45588 m .65745 .44605 L .65779 .44864 L p 0 1 0 r
F P
0 g
s
.55749 .66365 m .55034 .6714 L .53996 .66746 L p 0 1 0 r
F P
0 g
s
.57493 .65691 m .58208 .64693 L .59221 .6468 L p 0 1 0 r
F P
0 g
s
.59929 .63506 m .59221 .6468 L .58208 .64693 L p 0 1 0 r
F P
0 g
s
.35115 .6779 m .35771 .67073 L .36855 .67421 L p 1 0 0 r
F P
0 g
s
.35771 .67073 m .35115 .6779 L .34035 .6731 L p 1 0 0 r
F P
0 g
s
.55709 .59318 m .56437 .58858 L .57489 .59741 L p 1 0 0 r
F P
0 g
s
.56437 .58858 m .55709 .59318 L .54664 .58627 L p 1 0 0 r
F P
0 g
s
.23567 .63453 m .24185 .62749 L .25288 .63214 L p 0 0 1 r
F P
0 g
s
.24185 .62749 m .23567 .63453 L .22461 .62989 L p 0 0 1 r
F P
0 g
s
.48367 .59389 m .47673 .60359 L .46615 .6019 L p 1 0 0 r
F P
0 g
s
.37534 .59449 m .38188 .58916 L .39253 .59644 L p 0 1 0 r
F P
0 g
s
.38188 .58916 m .37534 .59449 L .36466 .58797 L p 0 1 0 r
F P
0 g
s
.32652 .63426 m .33299 .62721 L .34383 .63187 L p 0 0 1 r
F P
0 g
s
.33299 .62721 m .32652 .63426 L .31565 .62961 L p 0 0 1 r
F P
0 g
s
.36855 .67421 m .37521 .66588 L .38605 .66831 L p 1 0 0 r
F P
0 g
s
.39279 .6591 m .38605 .66831 L .37521 .66588 L p 1 0 0 r
F P
0 g
s
.37196 .63412 m .37857 .62707 L .38932 .63173 L p 0 0 1 r
F P
0 g
s
.37857 .62707 m .37196 .63412 L .36118 .62947 L p 0 0 1 r
F P
0 g
s
.66828 .74951 m .65968 .74161 L .64841 .72086 L p 1 0 0 r
F P
0 g
s
.64841 .72086 m .65677 .72696 L .66828 .74951 L p 1 0 0 r
F P
0 g
s
.42415 .62693 m .4174 .63398 L .40671 .62933 L p 0 0 1 r
F P
0 g
s
.46284 .63384 m .46974 .62679 L .4803 .63145 L p 0 0 1 r
F P
0 g
s
.65118 .49035 m .64467 .51148 L .63529 .51983 L p 0 1 0 r
F P
0 g
s
.63529 .51983 m .64197 .4999 L .65118 .49035 L p 0 1 0 r
F P
0 g
s
.50829 .63371 m .51534 .62666 L .5258 .63131 L p 0 0 1 r
F P
0 g
s
.51534 .62666 m .50829 .63371 L .4978 .62906 L p 0 0 1 r
F P
0 g
s
.55375 .63357 m .56094 .62652 L .57131 .63118 L p 0 0 1 r
F P
0 g
s
.56094 .62652 m .55375 .63357 L .54335 .62892 L p 0 0 1 r
F P
0 g
s
.37521 .66588 m .36855 .67421 L .35771 .67073 L p 1 0 0 r
F P
0 g
s
.64468 .63329 m .65216 .62624 L .66234 .6309 L p 0 0 1 r
F P
0 g
s
.65216 .62624 m .64468 .63329 L .63447 .62864 L p 0 0 1 r
F P
0 g
s
.69015 .63315 m .69778 .6261 L .70786 .63076 L p 0 0 1 r
F P
0 g
s
.69778 .6261 m .69015 .63315 L .68004 .6285 L p 0 0 1 r
F P
0 g
s
.31255 .66509 m .31878 .661 L .32955 .66749 L p 1 0 0 r
F P
0 g
s
.31878 .661 m .31255 .66509 L .30192 .65673 L p 1 0 0 r
F P
0 g
s
.5224 .66881 m .52951 .6628 L .53996 .66746 L p 0 1 0 r
F P
0 g
s
.52951 .6628 m .5224 .66881 L .51192 .66302 L p 0 1 0 r
F P
0 g
s
.48388 .65444 m .49086 .64992 L .5014 .6567 L p 0 1 0 r
F P
0 g
s
.49086 .64992 m .48388 .65444 L .47335 .64704 L p 0 1 0 r
F P
0 g
s
.65647 .44231 m .65745 .44605 L p .64581 .46652 L 0 1 0 r
F P
0 g
s
.65745 .44605 m .65491 .45588 L .64581 .46652 L p 0 1 0 r
F P
0 g
s
.62853 .66106 m .62057 .6587 L .60979 .64435 L p 1 0 0 r
F P
0 g
s
.60979 .64435 m .61759 .64532 L .62853 .66106 L p 1 0 0 r
F P
0 g
s
.65385 .71245 m .64549 .70667 L .63443 .68844 L p 1 0 0 r
F P
0 g
s
.63443 .68844 m .64257 .69258 L .65385 .71245 L p 1 0 0 r
F P
0 g
s
.29735 .64516 m .29136 .64732 L .2809 .63679 L p 1 0 0 r
F P
0 g
s
.2809 .63679 m .28674 .63569 L .29735 .64516 L p 1 0 0 r
F P
0 g
s
.39279 .6591 m .39957 .64952 L .41039 .65095 L p 1 0 0 r
F P
0 g
s
.41721 .64087 m .41039 .65095 L .39957 .64952 L p 1 0 0 r
F P
0 g
s
.29835 .63201 m .30474 .62495 L .31565 .62961 L p 0 0 1 r
F P
0 g
s
.30474 .62495 m .29835 .63201 L .28741 .62735 L p 0 0 1 r
F P
0 g
s
.58208 .64693 m .58922 .6361 L .59929 .63506 L p 0 1 0 r
F P
0 g
s
.54664 .58627 m .55386 .58079 L .56437 .58858 L p 1 0 0 r
F P
0 g
s
.55386 .58079 m .54664 .58627 L .53619 .58024 L p 1 0 0 r
F P
0 g
s
.34383 .63187 m .35036 .62481 L .36118 .62947 L p 0 0 1 r
F P
0 g
s
.35036 .62481 m .34383 .63187 L .33299 .62721 L p 0 0 1 r
F P
0 g
s
.30192 .65673 m .30804 .65358 L .31878 .661 L p 1 0 0 r
F P
0 g
s
.30804 .65358 m .30192 .65673 L .29136 .64732 L p 1 0 0 r
F P
0 g
s
.38932 .63173 m .39599 .62467 L .40671 .62933 L p 0 0 1 r
F P
0 g
s
.39599 .62467 m .38932 .63173 L .37857 .62707 L p 0 0 1 r
F P
0 g
s
.41721 .64087 m .42406 .63059 L .43481 .63163 L p 1 0 0 r
F P
0 g
s
.29136 .64732 m .29735 .64516 L .30804 .65358 L p 1 0 0 r
F P
0 g
s
.30149 .59577 m .30812 .58544 L .31917 .58818 L p 0 1 0 r
F P
0 g
s
.31917 .58818 m .32572 .57945 L .33662 .58373 L p 0 1 0 r
F P
0 g
s
.32572 .57945 m .31917 .58818 L .30812 .58544 L p 0 1 0 r
F P
0 g
s
.4803 .63145 m .48726 .62439 L .4978 .62906 L p 0 0 1 r
F P
0 g
s
.48726 .62439 m .4803 .63145 L .46974 .62679 L p 0 0 1 r
F P
0 g
s
.36466 .58797 m .37119 .5822 L .38188 .58916 L p 0 1 0 r
F P
0 g
s
.37119 .5822 m .36466 .58797 L .35393 .5819 L p 0 1 0 r
F P
0 g
s
.5258 .63131 m .53291 .62425 L .54335 .62892 L p 0 0 1 r
F P
0 g
s
.53291 .62425 m .5258 .63131 L .51534 .62666 L p 0 0 1 r
F P
0 g
s
.48367 .59389 m .49064 .58446 L .50116 .58729 L p 1 0 0 r
F P
0 g
s
.50116 .58729 m .50817 .57867 L .51865 .58257 L p 1 0 0 r
F P
0 g
s
.50817 .57867 m .50116 .58729 L .49064 .58446 L p 1 0 0 r
F P
0 g
s
.57131 .63118 m .57856 .62411 L .58891 .62878 L p 0 0 1 r
F P
0 g
s
.57856 .62411 m .57131 .63118 L .56094 .62652 L p 0 0 1 r
F P
0 g
s
.61682 .63104 m .62422 .62397 L .63447 .62864 L p 0 0 1 r
F P
0 g
s
.33662 .58373 m .34313 .57635 L .35393 .5819 L p 0 1 0 r
F P
0 g
s
.34313 .57635 m .33662 .58373 L .32572 .57945 L p 0 1 0 r
F P
0 g
s
.51865 .58257 m .52573 .57501 L .53619 .58024 L p 1 0 0 r
F P
0 g
s
.52573 .57501 m .51865 .58257 L .50817 .57867 L p 1 0 0 r
F P
0 g
s
.66234 .6309 m .66988 .62383 L .68004 .6285 L p 0 0 1 r
F P
0 g
s
.66988 .62383 m .66234 .6309 L .65216 .62624 L p 0 0 1 r
F P
0 g
s
.70786 .63076 m .71555 .62369 L .72561 .62836 L p 0 0 1 r
F P
0 g
s
.71555 .62369 m .70786 .63076 L .69778 .6261 L p 0 0 1 r
F P
0 g
s
.47335 .64704 m .48028 .64275 L .49086 .64992 L p 0 1 0 r
F P
0 g
s
.48028 .64275 m .47335 .64704 L .46279 .63938 L p 0 1 0 r
F P
0 g
s
.34035 .6731 m .34685 .66659 L .35771 .67073 L p 1 0 0 r
F P
0 g
s
.34685 .66659 m .34035 .6731 L .32955 .66749 L p 1 0 0 r
F P
0 g
s
.55749 .66365 m .56466 .65522 L .57493 .65691 L p 0 1 0 r
F P
0 g
s
.58208 .64693 m .57493 .65691 L .56466 .65522 L p 0 1 0 r
F P
0 g
s
.22461 .62989 m .23076 .62282 L .24185 .62749 L p 0 0 1 r
F P
0 g
s
.23076 .62282 m .22461 .62989 L .21351 .62522 L p 0 0 1 r
F P
0 g
s
.46615 .6019 m .4731 .59188 L .48367 .59389 L p 1 0 0 r
F P
0 g
s
.49064 .58446 m .48367 .59389 L .4731 .59188 L p 1 0 0 r
F P
0 g
s
.53996 .66746 m .54711 .66036 L .55749 .66365 L p 0 1 0 r
F P
0 g
s
.54711 .66036 m .53996 .66746 L .52951 .6628 L p 0 1 0 r
F P
0 g
s
.31565 .62961 m .32209 .62254 L .33299 .62721 L p 0 0 1 r
F P
0 g
s
.32209 .62254 m .31565 .62961 L .30474 .62495 L p 0 0 1 r
F P
0 g
s
.36118 .62947 m .36777 .6224 L .37857 .62707 L p 0 0 1 r
F P
0 g
s
.36777 .6224 m .36118 .62947 L .35036 .62481 L p 0 0 1 r
F P
0 g
s
.51192 .66302 m .51901 .65747 L .52951 .6628 L p 0 1 0 r
F P
0 g
s
.51901 .65747 m .51192 .66302 L .5014 .6567 L p 0 1 0 r
F P
0 g
s
.40671 .62933 m .41345 .62226 L .42415 .62693 L p 0 0 1 r
F P
0 g
s
.41345 .62226 m .40671 .62933 L .39599 .62467 L p 0 0 1 r
F P
0 g
s
.65224 .44358 m .656 .43858 L .65647 .44231 L p 0 1 0 r
F P
0 g
s
.64581 .46652 m .65224 .44358 L p .65647 .44231 L 0 1 0 r
F P
0 g
s
.37521 .66588 m .38193 .65705 L .39279 .6591 L p 1 0 0 r
F P
0 g
s
.39957 .64952 m .39279 .6591 L .38193 .65705 L p 1 0 0 r
F P
0 g
s
.30812 .58544 m .30149 .59577 L .29024 .59484 L p 0 1 0 r
F P
0 g
s
.4978 .62906 m .50482 .62198 L .51534 .62666 L p 0 0 1 r
F P
0 g
s
.50482 .62198 m .4978 .62906 L .48726 .62439 L p 0 0 1 r
F P
0 g
s
.65491 .45588 m .64852 .47859 L .63923 .48803 L p 0 1 0 r
F P
0 g
s
.63923 .48803 m .64581 .46652 L .65491 .45588 L p 0 1 0 r
F P
0 g
s
.54335 .62892 m .55052 .62184 L .56094 .62652 L p 0 0 1 r
F P
0 g
s
.55052 .62184 m .54335 .62892 L .53291 .62425 L p 0 0 1 r
F P
0 g
s
.46279 .63938 m .46969 .63525 L .48028 .64275 L p 0 1 0 r
F P
0 g
s
.46969 .63525 m .46279 .63938 L .45222 .63154 L p 0 1 0 r
F P
0 g
s
.63447 .62864 m .64193 .62156 L .65216 .62624 L p 0 0 1 r
F P
0 g
s
.64193 .62156 m .63447 .62864 L .62422 .62397 L p 0 0 1 r
F P
0 g
s
.56466 .65522 m .55749 .66365 L .54711 .66036 L p 0 1 0 r
F P
0 g
s
.68004 .6285 m .68764 .62142 L .69778 .6261 L p 0 0 1 r
F P
0 g
s
.68764 .62142 m .68004 .6285 L .66988 .62383 L p 0 0 1 r
F P
0 g
s
.53619 .58024 m .54337 .57396 L .55386 .58079 L p 1 0 0 r
F P
0 g
s
.54337 .57396 m .53619 .58024 L .52573 .57501 L p 1 0 0 r
F P
0 g
s
.73336 .62128 m .72561 .62836 L .71555 .62369 L p 0 0 1 r
F P
0 g
s
.63963 .67859 m .63149 .67472 L .62057 .6587 L p 1 0 0 r
F P
0 g
s
.62057 .6587 m .62853 .66106 L .63963 .67859 L p 1 0 0 r
F P
0 g
s
.35393 .5819 m .36045 .57563 L .37119 .5822 L p 0 1 0 r
F P
0 g
s
.36045 .57563 m .35393 .5819 L .34313 .57635 L p 0 1 0 r
F P
0 g
s
.39914 .59176 m .39253 .59644 L .38188 .58916 L p 0 1 0 r
F P
0 g
s
.35771 .67073 m .36433 .66292 L .37521 .66588 L p 1 0 0 r
F P
0 g
s
.36433 .66292 m .35771 .67073 L .34685 .66659 L p 1 0 0 r
F P
0 g
s
.39957 .64952 m .40639 .63961 L .41721 .64087 L p 1 0 0 r
F P
0 g
s
.42406 .63059 m .41721 .64087 L .40639 .63961 L p 1 0 0 r
F P
0 g
s
.64467 .51148 m .63803 .53125 L .6285 .53845 L p 0 1 0 r
F P
0 g
s
.6285 .53845 m .63529 .51983 L .64467 .51148 L p 0 1 0 r
F P
0 g
s
.38193 .65705 m .37521 .66588 L .36433 .66292 L p 1 0 0 r
F P
0 g
s
.24806 .6204 m .24185 .62749 L .23076 .62282 L p 0 0 1 r
F P
0 g
s
.28741 .62735 m .29377 .62026 L .30474 .62495 L p 0 0 1 r
F P
0 g
s
.33299 .62721 m .33949 .62012 L .35036 .62481 L p 0 0 1 r
F P
0 g
s
.33949 .62012 m .33299 .62721 L .32209 .62254 L p 0 0 1 r
F P
0 g
s
.37857 .62707 m .38522 .61998 L .39599 .62467 L p 0 0 1 r
F P
0 g
s
.38522 .61998 m .37857 .62707 L .36777 .6224 L p 0 0 1 r
F P
0 g
s
.45222 .63154 m .45908 .6275 L .46969 .63525 L p 0 1 0 r
F P
0 g
s
.46974 .62679 m .47668 .6197 L .48726 .62439 L p 0 0 1 r
F P
0 g
s
.47668 .6197 m .46974 .62679 L .45913 .62212 L p 0 0 1 r
F P
0 g
s
.51534 .62666 m .52242 .61956 L .53291 .62425 L p 0 0 1 r
F P
0 g
s
.52242 .61956 m .51534 .62666 L .50482 .62198 L p 0 0 1 r
F P
0 g
s
.56094 .62652 m .56817 .61942 L .57856 .62411 L p 0 0 1 r
F P
0 g
s
.56817 .61942 m .56094 .62652 L .55052 .62184 L p 0 0 1 r
F P
0 g
s
.32955 .66749 m .33598 .6617 L .34685 .66659 L p 1 0 0 r
F P
0 g
s
.33598 .6617 m .32955 .66749 L .31878 .661 L p 1 0 0 r
F P
0 g
s
.5014 .6567 m .50847 .65156 L .51901 .65747 L p 0 1 0 r
F P
0 g
s
.50847 .65156 m .5014 .6567 L .49086 .64992 L p 0 1 0 r
F P
0 g
s
.65216 .62624 m .65968 .61914 L .66988 .62383 L p 0 0 1 r
F P
0 g
s
.65968 .61914 m .65216 .62624 L .64193 .62156 L p 0 0 1 r
F P
0 g
s
.69778 .6261 m .70544 .619 L .71555 .62369 L p 0 0 1 r
F P
0 g
s
.70544 .619 m .69778 .6261 L .68764 .62142 L p 0 0 1 r
F P
0 g
s
.30812 .58544 m .31472 .57589 L .32572 .57945 L p 0 1 0 r
F P
0 g
s
.32572 .57945 m .33226 .57138 L .34313 .57635 L p 0 1 0 r
F P
0 g
s
.33226 .57138 m .32572 .57945 L .31472 .57589 L p 0 1 0 r
F P
0 g
s
.65529 .43592 m .656 .43858 L .65224 .44358 L p 0 1 0 r
F P
0 g
s
.56466 .65522 m .57184 .64605 L .58208 .64693 L p 0 1 0 r
F P
0 g
s
.58922 .6361 m .58208 .64693 L .57184 .64605 L p 0 1 0 r
F P
0 g
s
.38188 .58916 m .38846 .58416 L .39914 .59176 L p 0 1 0 r
F P
0 g
s
.38846 .58416 m .38188 .58916 L .37119 .5822 L p 0 1 0 r
F P
0 g
s
.49064 .58446 m .49765 .57534 L .50817 .57867 L p 1 0 0 r
F P
0 g
s
.50817 .57867 m .51523 .57048 L .52573 .57501 L p 1 0 0 r
F P
0 g
s
.51523 .57048 m .50817 .57867 L .49765 .57534 L p 1 0 0 r
F P
0 g
s
.26972 .63443 m .2627 .64976 L .25073 .65487 L p 0 1 0 r
F P
0 g
s
.25073 .65487 m .25791 .63815 L .26972 .63443 L p 0 1 0 r
F P
0 g
s
.21351 .62522 m .21964 .61812 L .23076 .62282 L p 0 0 1 r
F P
0 g
s
.21964 .61812 m .21351 .62522 L .20235 .62054 L p 0 0 1 r
F P
0 g
s
.57174 .58477 m .56437 .58858 L .55386 .58079 L p 1 0 0 r
F P
0 g
s
.52951 .6628 m .53666 .65628 L .54711 .66036 L p 0 1 0 r
F P
0 g
s
.53666 .65628 m .52951 .6628 L .51901 .65747 L p 0 1 0 r
F P
0 g
s
.2627 .64976 m .25558 .66627 L .24342 .67288 L p 0 1 0 r
F P
0 g
s
.24342 .67288 m .25073 .65487 L .2627 .64976 L p 0 1 0 r
F P
0 g
s
.29024 .59484 m .29694 .58355 L .30812 .58544 L p 0 1 0 r
F P
0 g
s
.31472 .57589 m .30812 .58544 L .29694 .58355 L p 0 1 0 r
F P
0 g
s
.30474 .62495 m .31116 .61784 L .32209 .62254 L p 0 0 1 r
F P
0 g
s
.31116 .61784 m .30474 .62495 L .29377 .62026 L p 0 0 1 r
F P
0 g
s
.66536 .73452 m .65677 .72696 L .64549 .70667 L p 1 0 0 r
F P
0 g
s
.64549 .70667 m .65385 .71245 L .66536 .73452 L p 1 0 0 r
F P
0 g
s
.4731 .59188 m .48007 .58206 L .49064 .58446 L p 1 0 0 r
F P
0 g
s
.49765 .57534 m .49064 .58446 L .48007 .58206 L p 1 0 0 r
F P
0 g
s
.35036 .62481 m .35693 .6177 L .36777 .6224 L p 0 0 1 r
F P
0 g
s
.35693 .6177 m .35036 .62481 L .33949 .62012 L p 0 0 1 r
F P
0 g
s
.39599 .62467 m .4027 .61756 L .41345 .62226 L p 0 0 1 r
F P
0 g
s
.4027 .61756 m .39599 .62467 L .38522 .61998 L p 0 0 1 r
F P
0 g
s
.38193 .65705 m .38869 .64777 L .39957 .64952 L p 1 0 0 r
F P
0 g
s
.40639 .63961 m .39957 .64952 L .38869 .64777 L p 1 0 0 r
F P
0 g
s
.68008 .77454 m .67121 .76468 L .65968 .74161 L p 1 0 0 r
F P
0 g
s
.65968 .74161 m .66828 .74951 L .68008 .77454 L p 1 0 0 r
F P
0 g
s
.48726 .62439 m .49427 .61728 L .50482 .62198 L p 0 0 1 r
F P
0 g
s
.49427 .61728 m .48726 .62439 L .47668 .6197 L p 0 0 1 r
F P
0 g
s
.53291 .62425 m .54006 .61714 L .55052 .62184 L p 0 0 1 r
F P
0 g
s
.54006 .61714 m .53291 .62425 L .52242 .61956 L p 0 0 1 r
F P
0 g
s
.52573 .57501 m .53286 .56798 L .54337 .57396 L p 1 0 0 r
F P
0 g
s
.53286 .56798 m .52573 .57501 L .51523 .57048 L p 1 0 0 r
F P
0 g
s
.58586 .617 m .57856 .62411 L .56817 .61942 L p 0 0 1 r
F P
0 g
s
.34313 .57635 m .34965 .56952 L .36045 .57563 L p 0 1 0 r
F P
0 g
s
.34965 .56952 m .34313 .57635 L .33226 .57138 L p 0 1 0 r
F P
0 g
s
.62422 .62397 m .63166 .61686 L .64193 .62156 L p 0 0 1 r
F P
0 g
s
.63166 .61686 m .62422 .62397 L .61392 .61928 L p 0 0 1 r
F P
0 g
s
.66988 .62383 m .67747 .61672 L .68764 .62142 L p 0 0 1 r
F P
0 g
s
.67747 .61672 m .66988 .62383 L .65968 .61914 L p 0 0 1 r
F P
0 g
s
.71555 .62369 m .72328 .61658 L .73336 .62128 L p 0 0 1 r
F P
0 g
s
.72328 .61658 m .71555 .62369 L .70544 .619 L p 0 0 1 r
F P
0 g
s
.40639 .63961 m .41324 .62944 L .42406 .63059 L p 1 0 0 r
F P
0 g
s
.43094 .62017 m .42406 .63059 L .41324 .62944 L p 1 0 0 r
F P
0 g
s
.49086 .64992 m .49789 .64512 L .50847 .65156 L p 0 1 0 r
F P
0 g
s
.49789 .64512 m .49086 .64992 L .48028 .64275 L p 0 1 0 r
F P
0 g
s
.31878 .661 m .32512 .65602 L .33598 .6617 L p 1 0 0 r
F P
0 g
s
.32512 .65602 m .31878 .661 L .30804 .65358 L p 1 0 0 r
F P
0 g
s
.65224 .44358 m .65491 .43318 L .65529 .43592 L p 0 1 0 r
F P
0 g
s
.55386 .58079 m .56116 .57604 L .57174 .58477 L p 1 0 0 r
F P
0 g
s
.56116 .57604 m .55386 .58079 L .54337 .57396 L p 1 0 0 r
F P
0 g
s
.37119 .5822 m .37774 .57682 L .38846 .58416 L p 0 1 0 r
F P
0 g
s
.37774 .57682 m .37119 .5822 L .36045 .57563 L p 0 1 0 r
F P
0 g
s
.63803 .53125 m .63128 .54973 L .62161 .55578 L p 0 1 0 r
F P
0 g
s
.62161 .55578 m .6285 .53845 L .63803 .53125 L p 0 1 0 r
F P
0 g
s
.54711 .66036 m .55429 .65262 L .56466 .65522 L p 0 1 0 r
F P
0 g
s
.57184 .64605 m .56466 .65522 L .55429 .65262 L p 0 1 0 r
F P
0 g
s
.23076 .62282 m .23696 .6157 L .24806 .6204 L p 0 0 1 r
F P
0 g
s
.23696 .6157 m .23076 .62282 L .21964 .61812 L p 0 0 1 r
F P
0 g
s
.55429 .65262 m .54711 .66036 L .53666 .65628 L p 0 1 0 r
F P
0 g
s
.34685 .66659 m .35342 .65937 L .36433 .66292 L p 1 0 0 r
F P
0 g
s
.35342 .65937 m .34685 .66659 L .33598 .6617 L p 1 0 0 r
F P
0 g
s
.65092 .69807 m .64257 .69258 L .63149 .67472 L p 1 0 0 r
F P
0 g
s
.63149 .67472 m .63963 .67859 L .65092 .69807 L p 1 0 0 r
F P
0 g
s
.48007 .58206 m .4731 .59188 L .46245 .59016 L p 1 0 0 r
F P
0 g
s
.32209 .62254 m .32858 .61542 L .33949 .62012 L p 0 0 1 r
F P
0 g
s
.32858 .61542 m .32209 .62254 L .31116 .61784 L p 0 0 1 r
F P
0 g
s
.36777 .6224 m .3744 .61527 L .38522 .61998 L p 0 0 1 r
F P
0 g
s
.3744 .61527 m .36777 .6224 L .35693 .6177 L p 0 0 1 r
F P
0 g
s
.42022 .61513 m .41345 .62226 L .4027 .61756 L p 0 0 1 r
F P
0 g
s
.36433 .66292 m .37102 .65454 L .38193 .65705 L p 1 0 0 r
F P
0 g
s
.38869 .64777 m .38193 .65705 L .37102 .65454 L p 1 0 0 r
F P
0 g
s
.45913 .62212 m .46605 .61499 L .47668 .6197 L p 0 0 1 r
F P
0 g
s
.57184 .64605 m .57902 .63606 L .58922 .6361 L p 0 1 0 r
F P
0 g
s
.59634 .62434 m .58922 .6361 L .57902 .63606 L p 0 1 0 r
F P
0 g
s
.50482 .62198 m .51189 .61485 L .52242 .61956 L p 0 0 1 r
F P
0 g
s
.51189 .61485 m .50482 .62198 L .49427 .61728 L p 0 0 1 r
F P
0 g
s
.62556 .64745 m .61759 .64532 L .60679 .63122 L p 1 0 0 r
F P
0 g
s
.60679 .63122 m .6146 .63198 L .62556 .64745 L p 1 0 0 r
F P
0 g
s
.55052 .62184 m .55773 .61471 L .56817 .61942 L p 0 0 1 r
F P
0 g
s
.55773 .61471 m .55052 .62184 L .54006 .61714 L p 0 0 1 r
F P
0 g
s
.64193 .62156 m .64944 .61443 L .65968 .61914 L p 0 0 1 r
F P
0 g
s
.64944 .61443 m .64193 .62156 L .63166 .61686 L p 0 0 1 r
F P
0 g
s
.37102 .65454 m .36433 .66292 L .35342 .65937 L p 1 0 0 r
F P
0 g
s
.68764 .62142 m .6953 .61429 L .70544 .619 L p 0 0 1 r
F P
0 g
s
.6953 .61429 m .68764 .62142 L .67747 .61672 L p 0 0 1 r
F P
0 g
s
.30804 .65358 m .31428 .64946 L .32512 .65602 L p 1 0 0 r
F P
0 g
s
.31428 .64946 m .30804 .65358 L .29735 .64516 L p 1 0 0 r
F P
0 g
s
.64852 .47859 m .64197 .4999 L .63251 .50814 L p 0 1 0 r
F P
0 g
s
.63251 .50814 m .63923 .48803 L .64852 .47859 L p 0 1 0 r
F P
0 g
s
.74116 .61415 m .73336 .62128 L .72328 .61658 L p 0 0 1 r
F P
0 g
s
.48028 .64275 m .48728 .63823 L .49789 .64512 L p 0 1 0 r
F P
0 g
s
.48728 .63823 m .48028 .64275 L .46969 .63525 L p 0 1 0 r
F P
0 g
s
.51901 .65747 m .52614 .65147 L .53666 .65628 L p 0 1 0 r
F P
0 g
s
.52614 .65147 m .51901 .65747 L .50847 .65156 L p 0 1 0 r
F P
0 g
s
.65393 .42953 m .65491 .43318 L p .64306 .45414 L 0 1 0 r
F P
0 g
s
.65491 .43318 m .65224 .44358 L .64306 .45414 L p 0 1 0 r
F P
0 g
s
.20235 .62054 m .20846 .61341 L .21964 .61812 L p 0 0 1 r
F P
0 g
s
.20846 .61341 m .20235 .62054 L .19115 .61584 L p 0 0 1 r
F P
0 g
s
.54337 .57396 m .55061 .56833 L .56116 .57604 L p 1 0 0 r
F P
0 g
s
.55061 .56833 m .54337 .57396 L .53286 .56798 L p 1 0 0 r
F P
0 g
s
.29274 .6335 m .28674 .63569 L .27622 .62511 L p 1 0 0 r
F P
0 g
s
.27622 .62511 m .28207 .62398 L .29274 .6335 L p 1 0 0 r
F P
0 g
s
.29377 .62026 m .30017 .61313 L .31116 .61784 L p 0 0 1 r
F P
0 g
s
.30017 .61313 m .29377 .62026 L .28277 .61556 L p 0 0 1 r
F P
0 g
s
.33949 .62012 m .34604 .61298 L .35693 .6177 L p 0 0 1 r
F P
0 g
s
.34604 .61298 m .33949 .62012 L .32858 .61542 L p 0 0 1 r
F P
0 g
s
.29735 .64516 m .30348 .64197 L .31428 .64946 L p 1 0 0 r
F P
0 g
s
.30348 .64197 m .29735 .64516 L .28674 .63569 L p 1 0 0 r
F P
0 g
s
.29694 .58355 m .3036 .57311 L .31472 .57589 L p 0 1 0 r
F P
0 g
s
.31472 .57589 m .32129 .56706 L .33226 .57138 L p 0 1 0 r
F P
0 g
s
.32129 .56706 m .31472 .57589 L .3036 .57311 L p 0 1 0 r
F P
0 g
s
.36045 .57563 m .36699 .5698 L .37774 .57682 L p 0 1 0 r
F P
0 g
s
.36699 .5698 m .36045 .57563 L .34965 .56952 L p 0 1 0 r
F P
0 g
s
.38869 .64777 m .3955 .63811 L .40639 .63961 L p 1 0 0 r
F P
0 g
s
.41324 .62944 m .40639 .63961 L .3955 .63811 L p 1 0 0 r
F P
0 g
s
.38522 .61998 m .39191 .61284 L .4027 .61756 L p 0 0 1 r
F P
0 g
s
.39191 .61284 m .38522 .61998 L .3744 .61527 L p 0 0 1 r
F P
0 g
s
.28674 .63569 m .29274 .6335 L .30348 .64197 L p 1 0 0 r
F P
0 g
s
.47668 .6197 m .48367 .61256 L .49427 .61728 L p 0 0 1 r
F P
0 g
s
.48367 .61256 m .47668 .6197 L .46605 .61499 L p 0 0 1 r
F P
0 g
s
.52242 .61956 m .52955 .61242 L .54006 .61714 L p 0 0 1 r
F P
0 g
s
.52955 .61242 m .52242 .61956 L .51189 .61485 L p 0 0 1 r
F P
0 g
s
.41324 .62944 m .42012 .61907 L .43094 .62017 L p 1 0 0 r
F P
0 g
s
.33226 .57138 m .33879 .56392 L .34965 .56952 L p 0 1 0 r
F P
0 g
s
.33879 .56392 m .33226 .57138 L .32129 .56706 L p 0 1 0 r
F P
0 g
s
.48007 .58206 m .48707 .5725 L .49765 .57534 L p 1 0 0 r
F P
0 g
s
.49765 .57534 m .50469 .56659 L .51523 .57048 L p 1 0 0 r
F P
0 g
s
.50469 .56659 m .49765 .57534 L .48707 .5725 L p 1 0 0 r
F P
0 g
s
.56817 .61942 m .57545 .61228 L .58586 .617 L p 0 0 1 r
F P
0 g
s
.57545 .61228 m .56817 .61942 L .55773 .61471 L p 0 0 1 r
F P
0 g
s
.51523 .57048 m .52233 .56278 L .53286 .56798 L p 1 0 0 r
F P
0 g
s
.52233 .56278 m .51523 .57048 L .50469 .56659 L p 1 0 0 r
F P
0 g
s
.61392 .61928 m .62135 .61214 L .63166 .61686 L p 0 0 1 r
F P
0 g
s
.57902 .63606 m .5862 .62521 L .59634 .62434 L p 0 1 0 r
F P
0 g
s
.65968 .61914 m .66725 .612 L .67747 .61672 L p 0 0 1 r
F P
0 g
s
.66725 .612 m .65968 .61914 L .64944 .61443 L p 0 0 1 r
F P
0 g
s
.46969 .63525 m .47664 .63095 L .48728 .63823 L p 0 1 0 r
F P
0 g
s
.47664 .63095 m .46969 .63525 L .45908 .6275 L p 0 1 0 r
F P
0 g
s
.70544 .619 m .71316 .61186 L .72328 .61658 L p 0 0 1 r
F P
0 g
s
.71316 .61186 m .70544 .619 L .6953 .61429 L p 0 0 1 r
F P
0 g
s
.33598 .6617 m .3425 .65515 L .35342 .65937 L p 1 0 0 r
F P
0 g
s
.3425 .65515 m .33598 .6617 L .32512 .65602 L p 1 0 0 r
F P
0 g
s
.21964 .61812 m .22581 .61097 L .23696 .6157 L p 0 0 1 r
F P
0 g
s
.22581 .61097 m .21964 .61812 L .20846 .61341 L p 0 0 1 r
F P
0 g
s
.63668 .66467 m .62853 .66106 L .61759 .64532 L p 1 0 0 r
F P
0 g
s
.61759 .64532 m .62556 .64745 L .63668 .66467 L p 1 0 0 r
F P
0 g
s
.46245 .59016 m .46942 .58002 L .48007 .58206 L p 1 0 0 r
F P
0 g
s
.48707 .5725 m .48007 .58206 L .46942 .58002 L p 1 0 0 r
F P
0 g
s
.31116 .61784 m .31762 .61069 L .32858 .61542 L p 0 0 1 r
F P
0 g
s
.31762 .61069 m .31116 .61784 L .30017 .61313 L p 0 0 1 r
F P
0 g
s
.35693 .6177 m .36354 .61055 L .3744 .61527 L p 0 0 1 r
F P
0 g
s
.36354 .61055 m .35693 .6177 L .34604 .61298 L p 0 0 1 r
F P
0 g
s
.55429 .65262 m .56149 .6442 L .57184 .64605 L p 0 1 0 r
F P
0 g
s
.57902 .63606 m .57184 .64605 L .56149 .6442 L p 0 1 0 r
F P
0 g
s
.3036 .57311 m .29694 .58355 L .28561 .5826 L p 0 1 0 r
F P
0 g
s
.53666 .65628 m .54384 .64918 L .55429 .65262 L p 0 1 0 r
F P
0 g
s
.54384 .64918 m .53666 .65628 L .52614 .65147 L p 0 1 0 r
F P
0 g
s
.4027 .61756 m .40946 .61041 L .42022 .61513 L p 0 0 1 r
F P
0 g
s
.40946 .61041 m .4027 .61756 L .39191 .61284 L p 0 0 1 r
F P
0 g
s
.50847 .65156 m .51558 .64602 L .52614 .65147 L p 0 1 0 r
F P
0 g
s
.51558 .64602 m .50847 .65156 L .49789 .64512 L p 0 1 0 r
F P
0 g
s
.64952 .43096 m .65342 .42584 L .65393 .42953 L p 0 1 0 r
F P
0 g
s
.64306 .45414 m .64952 .43096 L p .65393 .42953 L 0 1 0 r
F P
0 g
s
.49427 .61728 m .50132 .61013 L .51189 .61485 L p 0 0 1 r
F P
0 g
s
.50132 .61013 m .49427 .61728 L .48367 .61256 L p 0 0 1 r
F P
0 g
s
.45908 .6275 m .46599 .62336 L .47664 .63095 L p 0 1 0 r
F P
0 g
s
.46599 .62336 m .45908 .6275 L .44845 .61957 L p 0 1 0 r
F P
0 g
s
.37102 .65454 m .37776 .64564 L .38869 .64777 L p 1 0 0 r
F P
0 g
s
.3955 .63811 m .38869 .64777 L .37776 .64564 L p 1 0 0 r
F P
0 g
s
.54006 .61714 m .54726 .60998 L .55773 .61471 L p 0 0 1 r
F P
0 g
s
.54726 .60998 m .54006 .61714 L .52955 .61242 L p 0 0 1 r
F P
0 g
s
.53286 .56798 m .54005 .56155 L .55061 .56833 L p 1 0 0 r
F P
0 g
s
.54005 .56155 m .53286 .56798 L .52233 .56278 L p 1 0 0 r
F P
0 g
s
.63166 .61686 m .63915 .6097 L .64944 .61443 L p 0 0 1 r
F P
0 g
s
.63915 .6097 m .63166 .61686 L .62135 .61214 L p 0 0 1 r
F P
0 g
s
.65224 .44358 m .64581 .46652 L .63644 .47586 L p 0 1 0 r
F P
0 g
s
.63644 .47586 m .64306 .45414 L .65224 .44358 L p 0 1 0 r
F P
0 g
s
.67747 .61672 m .68511 .60956 L .6953 .61429 L p 0 0 1 r
F P
0 g
s
.68511 .60956 m .67747 .61672 L .66725 .612 L p 0 0 1 r
F P
0 g
s
.72328 .61658 m .73107 .60942 L .74116 .61415 L p 0 0 1 r
F P
0 g
s
.73107 .60942 m .72328 .61658 L .71316 .61186 L p 0 0 1 r
F P
0 g
s
.34965 .56952 m .35619 .56318 L .36699 .5698 L p 0 1 0 r
F P
0 g
s
.35619 .56318 m .34965 .56952 L .33879 .56392 L p 0 1 0 r
F P
0 g
s
.39508 .57943 m .38846 .58416 L .37774 .57682 L p 0 1 0 r
F P
0 g
s
.56149 .6442 m .55429 .65262 L .54384 .64918 L p 0 1 0 r
F P
0 g
s
.19115 .61584 m .19724 .60867 L .20846 .61341 L p 0 0 1 r
F P
0 g
s
.19724 .60867 m .19115 .61584 L .17991 .61111 L p 0 0 1 r
F P
0 g
s
.35342 .65937 m .36007 .65151 L .37102 .65454 L p 1 0 0 r
F P
0 g
s
.36007 .65151 m .35342 .65937 L .3425 .65515 L p 1 0 0 r
F P
0 g
s
.24319 .60853 m .23696 .6157 L .22581 .61097 L p 0 0 1 r
F P
0 g
s
.3955 .63811 m .40235 .62812 L .41324 .62944 L p 1 0 0 r
F P
0 g
s
.42012 .61907 m .41324 .62944 L .40235 .62812 L p 1 0 0 r
F P
0 g
s
.67715 .75899 m .66828 .74951 L .65677 .72696 L p 1 0 0 r
F P
0 g
s
.65677 .72696 m .66536 .73452 L .67715 .75899 L p 1 0 0 r
F P
0 g
s
.37776 .64564 m .37102 .65454 L .36007 .65151 L p 1 0 0 r
F P
0 g
s
.28277 .61556 m .28914 .60839 L .30017 .61313 L p 0 0 1 r
F P
0 g
s
.66243 .71968 m .65385 .71245 L .64257 .69258 L p 1 0 0 r
F P
0 g
s
.64257 .69258 m .65092 .69807 L .66243 .71968 L p 1 0 0 r
F P
0 g
s
.44845 .61957 m .45532 .61552 L .46599 .62336 L p 0 1 0 r
F P
0 g
s
.32858 .61542 m .3351 .60825 L .34604 .61298 L p 0 0 1 r
F P
0 g
s
.3351 .60825 m .32858 .61542 L .31762 .61069 L p 0 0 1 r
F P
0 g
s
.3744 .61527 m .38107 .60811 L .39191 .61284 L p 0 0 1 r
F P
0 g
s
.38107 .60811 m .3744 .61527 L .36354 .61055 L p 0 0 1 r
F P
0 g
s
.64197 .4999 m .63529 .51983 L .62568 .5269 L p 0 1 0 r
F P
0 g
s
.62568 .5269 m .63251 .50814 L .64197 .4999 L p 0 1 0 r
F P
0 g
s
.46605 .61499 m .47302 .60782 L .48367 .61256 L p 0 0 1 r
F P
0 g
s
.47302 .60782 m .46605 .61499 L .45538 .61027 L p 0 0 1 r
F P
0 g
s
.51189 .61485 m .51901 .60768 L .52955 .61242 L p 0 0 1 r
F P
0 g
s
.51901 .60768 m .51189 .61485 L .50132 .61013 L p 0 0 1 r
F P
0 g
s
.55773 .61471 m .56499 .60754 L .57545 .61228 L p 0 0 1 r
F P
0 g
s
.56499 .60754 m .55773 .61471 L .54726 .60998 L p 0 0 1 r
F P
0 g
s
.32512 .65602 m .33156 .65019 L .3425 .65515 L p 1 0 0 r
F P
0 g
s
.33156 .65019 m .32512 .65602 L .31428 .64946 L p 1 0 0 r
F P
0 g
s
.49789 .64512 m .50497 .63998 L .51558 .64602 L p 0 1 0 r
F P
0 g
s
.50497 .63998 m .49789 .64512 L .48728 .63823 L p 0 1 0 r
F P
0 g
s
.64944 .61443 m .65699 .60726 L .66725 .612 L p 0 0 1 r
F P
0 g
s
.65699 .60726 m .64944 .61443 L .63915 .6097 L p 0 0 1 r
F P
0 g
s
.3036 .57311 m .31022 .56345 L .32129 .56706 L p 0 1 0 r
F P
0 g
s
.32129 .56706 m .32785 .5589 L .33879 .56392 L p 0 1 0 r
F P
0 g
s
.32785 .5589 m .32129 .56706 L .31022 .56345 L p 0 1 0 r
F P
0 g
s
.6953 .61429 m .703 .60712 L .71316 .61186 L p 0 0 1 r
F P
0 g
s
.703 .60712 m .6953 .61429 L .68511 .60956 L p 0 0 1 r
F P
0 g
s
.37774 .57682 m .38434 .57177 L .39508 .57943 L p 0 1 0 r
F P
0 g
s
.38434 .57177 m .37774 .57682 L .36699 .5698 L p 0 1 0 r
F P
0 g
s
.74901 .60698 m .74116 .61415 L .73107 .60942 L p 0 0 1 r
F P
0 g
s
.65267 .42308 m .65342 .42584 L .64952 .43096 L p 0 1 0 r
F P
0 g
s
.56855 .57206 m .56116 .57604 L .55061 .56833 L p 1 0 0 r
F P
0 g
s
.48707 .5725 m .4941 .56325 L .50469 .56659 L p 1 0 0 r
F P
0 g
s
.50469 .56659 m .51177 .55827 L .52233 .56278 L p 1 0 0 r
F P
0 g
s
.51177 .55827 m .50469 .56659 L .4941 .56325 L p 1 0 0 r
F P
0 g
s
.26497 .62264 m .25791 .63815 L .24584 .64326 L p 0 1 0 r
F P
0 g
s
.24584 .64326 m .25308 .62635 L .26497 .62264 L p 0 1 0 r
F P
0 g
s
.28561 .5826 m .29235 .57118 L .3036 .57311 L p 0 1 0 r
F P
0 g
s
.31022 .56345 m .3036 .57311 L .29235 .57118 L p 0 1 0 r
F P
0 g
s
.20846 .61341 m .21461 .60623 L .22581 .61097 L p 0 0 1 r
F P
0 g
s
.21461 .60623 m .20846 .61341 L .19724 .60867 L p 0 0 1 r
F P
0 g
s
.56149 .6442 m .5687 .63502 L .57902 .63606 L p 0 1 0 r
F P
0 g
s
.5862 .62521 m .57902 .63606 L .5687 .63502 L p 0 1 0 r
F P
0 g
s
.25791 .63815 m .25073 .65487 L .23847 .66148 L p 0 1 0 r
F P
0 g
s
.23847 .66148 m .24584 .64326 L .25791 .63815 L p 0 1 0 r
F P
0 g
s
.30017 .61313 m .30662 .60594 L .31762 .61069 L p 0 0 1 r
F P
0 g
s
.30662 .60594 m .30017 .61313 L .28914 .60839 L p 0 0 1 r
F P
0 g
s
.52614 .65147 m .53332 .64496 L .54384 .64918 L p 0 1 0 r
F P
0 g
s
.53332 .64496 m .52614 .65147 L .51558 .64602 L p 0 1 0 r
F P
0 g
s
.34604 .61298 m .35263 .6058 L .36354 .61055 L p 0 0 1 r
F P
0 g
s
.35263 .6058 m .34604 .61298 L .3351 .60825 L p 0 0 1 r
F P
0 g
s
.46942 .58002 m .47642 .57008 L .48707 .5725 L p 1 0 0 r
F P
0 g
s
.4941 .56325 m .48707 .5725 L .47642 .57008 L p 1 0 0 r
F P
0 g
s
.39191 .61284 m .39864 .60566 L .40946 .61041 L p 0 0 1 r
F P
0 g
s
.39864 .60566 m .39191 .61284 L .38107 .60811 L p 0 0 1 r
F P
0 g
s
.64798 .68379 m .63963 .67859 L .62853 .66106 L p 1 0 0 r
F P
0 g
s
.62853 .66106 m .63668 .66467 L .64798 .68379 L p 1 0 0 r
F P
0 g
s
.48367 .61256 m .4907 .60538 L .50132 .61013 L p 0 0 1 r
F P
0 g
s
.4907 .60538 m .48367 .61256 L .47302 .60782 L p 0 0 1 r
F P
0 g
s
.33879 .56392 m .34533 .55701 L .35619 .56318 L p 0 1 0 r
F P
0 g
s
.34533 .55701 m .33879 .56392 L .32785 .5589 L p 0 1 0 r
F P
0 g
s
.52233 .56278 m .52949 .55561 L .54005 .56155 L p 1 0 0 r
F P
0 g
s
.52949 .55561 m .52233 .56278 L .51177 .55827 L p 1 0 0 r
F P
0 g
s
.52955 .61242 m .53673 .60524 L .54726 .60998 L p 0 0 1 r
F P
0 g
s
.53673 .60524 m .52955 .61242 L .51901 .60768 L p 0 0 1 r
F P
0 g
s
.37776 .64564 m .38455 .63629 L .3955 .63811 L p 1 0 0 r
F P
0 g
s
.40235 .62812 m .3955 .63811 L .38455 .63629 L p 1 0 0 r
F P
0 g
s
.58277 .60509 m .57545 .61228 L .56499 .60754 L p 0 0 1 r
F P
0 g
s
.62135 .61214 m .62882 .60495 L .63915 .6097 L p 0 0 1 r
F P
0 g
s
.62882 .60495 m .62135 .61214 L .61099 .6074 L p 0 0 1 r
F P
0 g
s
.66725 .612 m .67487 .60481 L .68511 .60956 L p 0 0 1 r
F P
0 g
s
.67487 .60481 m .66725 .612 L .65699 .60726 L p 0 0 1 r
F P
0 g
s
.71316 .61186 m .72093 .60467 L .73107 .60942 L p 0 0 1 r
F P
0 g
s
.72093 .60467 m .71316 .61186 L .703 .60712 L p 0 0 1 r
F P
0 g
s
.55061 .56833 m .55793 .56342 L .56855 .57206 L p 1 0 0 r
F P
0 g
s
.55793 .56342 m .55061 .56833 L .54005 .56155 L p 1 0 0 r
F P
0 g
s
.48728 .63823 m .49433 .63343 L .50497 .63998 L p 0 1 0 r
F P
0 g
s
.49433 .63343 m .48728 .63823 L .47664 .63095 L p 0 1 0 r
F P
0 g
s
.31428 .64946 m .32064 .64443 L .33156 .65019 L p 1 0 0 r
F P
0 g
s
.32064 .64443 m .31428 .64946 L .30348 .64197 L p 1 0 0 r
F P
0 g
s
.64952 .43096 m .65225 .42026 L .65267 .42308 L p 0 1 0 r
F P
0 g
s
.25073 .65487 m .24342 .67288 L .23094 .6811 L p 0 1 0 r
F P
0 g
s
.23094 .6811 m .23847 .66148 L .25073 .65487 L p 0 1 0 r
F P
0 g
s
.36699 .5698 m .37356 .56437 L .38434 .57177 L p 0 1 0 r
F P
0 g
s
.37356 .56437 m .36699 .5698 L .35619 .56318 L p 0 1 0 r
F P
0 g
s
.40235 .62812 m .40923 .61786 L .42012 .61907 L p 1 0 0 r
F P
0 g
s
.42703 .60856 m .42012 .61907 L .40923 .61786 L p 1 0 0 r
F P
0 g
s
.62257 .63389 m .6146 .63198 L .60376 .6181 L p 1 0 0 r
F P
0 g
s
.60376 .6181 m .61158 .61865 L .62257 .63389 L p 1 0 0 r
F P
0 g
s
.17991 .61111 m .18597 .60392 L .19724 .60867 L p 0 0 1 r
F P
0 g
s
.18597 .60392 m .17991 .61111 L .16861 .60637 L p 0 0 1 r
F P
0 g
s
.22581 .61097 m .23202 .60378 L .24319 .60853 L p 0 0 1 r
F P
0 g
s
.23202 .60378 m .22581 .61097 L .21461 .60623 L p 0 0 1 r
F P
0 g
s
.3425 .65515 m .34909 .64788 L .36007 .65151 L p 1 0 0 r
F P
0 g
s
.34909 .64788 m .3425 .65515 L .33156 .65019 L p 1 0 0 r
F P
0 g
s
.31762 .61069 m .32412 .60349 L .3351 .60825 L p 0 0 1 r
F P
0 g
s
.32412 .60349 m .31762 .61069 L .30662 .60594 L p 0 0 1 r
F P
0 g
s
.47642 .57008 m .46942 .58002 L .4587 .57826 L p 1 0 0 r
F P
0 g
s
.36354 .61055 m .37019 .60335 L .38107 .60811 L p 0 0 1 r
F P
0 g
s
.37019 .60335 m .36354 .61055 L .35263 .6058 L p 0 0 1 r
F P
0 g
s
.54384 .64918 m .55105 .64145 L .56149 .6442 L p 0 1 0 r
F P
0 g
s
.55105 .64145 m .54384 .64918 L .53332 .64496 L p 0 1 0 r
F P
0 g
s
.41626 .60321 m .40946 .61041 L .39864 .60566 L p 0 0 1 r
F P
0 g
s
.5687 .63502 m .56149 .6442 L .55105 .64145 L p 0 1 0 r
F P
0 g
s
.45538 .61027 m .46233 .60307 L .47302 .60782 L p 0 0 1 r
F P
0 g
s
.63529 .51983 m .6285 .53845 L .61875 .54436 L p 0 1 0 r
F P
0 g
s
.61875 .54436 m .62568 .5269 L .63529 .51983 L p 0 1 0 r
F P
0 g
s
.36007 .65151 m .36678 .64306 L .37776 .64564 L p 1 0 0 r
F P
0 g
s
.38455 .63629 m .37776 .64564 L .36678 .64306 L p 1 0 0 r
F P
0 g
s
.50132 .61013 m .50841 .60293 L .51901 .60768 L p 0 0 1 r
F P
0 g
s
.50841 .60293 m .50132 .61013 L .4907 .60538 L p 0 0 1 r
F P
0 g
s
.54726 .60998 m .5545 .60278 L .56499 .60754 L p 0 0 1 r
F P
0 g
s
.5545 .60278 m .54726 .60998 L .53673 .60524 L p 0 0 1 r
F P
0 g
s
.63915 .6097 m .64669 .6025 L .65699 .60726 L p 0 0 1 r
F P
0 g
s
.64669 .6025 m .63915 .6097 L .62882 .60495 L p 0 0 1 r
F P
0 g
s
.68511 .60956 m .69279 .60236 L .703 .60712 L p 0 0 1 r
F P
0 g
s
.69279 .60236 m .68511 .60956 L .67487 .60481 L p 0 0 1 r
F P
0 g
s
.5687 .63502 m .57592 .62502 L .5862 .62521 L p 0 1 0 r
F P
0 g
s
.59336 .61343 m .5862 .62521 L .57592 .62502 L p 0 1 0 r
F P
0 g
s
.36678 .64306 m .36007 .65151 L .34909 .64788 L p 1 0 0 r
F P
0 g
s
.73107 .60942 m .7389 .60221 L .74901 .60698 L p 0 0 1 r
F P
0 g
s
.7389 .60221 m .73107 .60942 L .72093 .60467 L p 0 0 1 r
F P
0 g
s
.30348 .64197 m .30974 .63781 L .32064 .64443 L p 1 0 0 r
F P
0 g
s
.30974 .63781 m .30348 .64197 L .29274 .6335 L p 1 0 0 r
F P
0 g
s
.47664 .63095 m .48366 .62643 L .49433 .63343 L p 0 1 0 r
F P
0 g
s
.48366 .62643 m .47664 .63095 L .46599 .62336 L p 0 1 0 r
F P
0 g
s
.51558 .64602 m .52274 .64002 L .53332 .64496 L p 0 1 0 r
F P
0 g
s
.52274 .64002 m .51558 .64602 L .50497 .63998 L p 0 1 0 r
F P
0 g
s
.65124 .41662 m .65225 .42026 L p .64027 .44144 L 0 1 0 r
F P
0 g
s
.65225 .42026 m .64952 .43096 L .64027 .44144 L p 0 1 0 r
F P
0 g
s
.54005 .56155 m .54732 .55577 L .55793 .56342 L p 1 0 0 r
F P
0 g
s
.54732 .55577 m .54005 .56155 L .52949 .55561 L p 1 0 0 r
F P
0 g
s
.64581 .46652 m .63923 .48803 L .62969 .49617 L p 0 1 0 r
F P
0 g
s
.62969 .49617 m .63644 .47586 L .64581 .46652 L p 0 1 0 r
F P
0 g
s
.19724 .60867 m .20336 .60146 L .21461 .60623 L p 0 0 1 r
F P
0 g
s
.20336 .60146 m .19724 .60867 L .18597 .60392 L p 0 0 1 r
F P
0 g
s
.24946 .60132 m .24319 .60853 L .23202 .60378 L p 0 0 1 r
F P
0 g
s
.28807 .62174 m .28207 .62398 L .27149 .61336 L p 1 0 0 r
F P
0 g
s
.27149 .61336 m .27734 .61218 L .28807 .62174 L p 1 0 0 r
F P
0 g
s
.29235 .57118 m .29903 .56063 L .31022 .56345 L p 0 1 0 r
F P
0 g
s
.31022 .56345 m .31682 .55453 L .32785 .5589 L p 0 1 0 r
F P
0 g
s
.31682 .55453 m .31022 .56345 L .29903 .56063 L p 0 1 0 r
F P
0 g
s
.35619 .56318 m .36275 .55729 L .37356 .56437 L p 0 1 0 r
F P
0 g
s
.36275 .55729 m .35619 .56318 L .34533 .55701 L p 0 1 0 r
F P
0 g
s
.28914 .60839 m .29556 .60118 L .30662 .60594 L p 0 0 1 r
F P
0 g
s
.29556 .60118 m .28914 .60839 L .27807 .60364 L p 0 0 1 r
F P
0 g
s
.3351 .60825 m .34167 .60104 L .35263 .6058 L p 0 0 1 r
F P
0 g
s
.34167 .60104 m .3351 .60825 L .32412 .60349 L p 0 0 1 r
F P
0 g
s
.29274 .6335 m .29887 .63026 L .30974 .63781 L p 1 0 0 r
F P
0 g
s
.29887 .63026 m .29274 .6335 L .28207 .62398 L p 1 0 0 r
F P
0 g
s
.38107 .60811 m .38779 .60089 L .39864 .60566 L p 0 0 1 r
F P
0 g
s
.38779 .60089 m .38107 .60811 L .37019 .60335 L p 0 0 1 r
F P
0 g
s
.32785 .5589 m .33441 .55136 L .34533 .55701 L p 0 1 0 r
F P
0 g
s
.33441 .55136 m .32785 .5589 L .31682 .55453 L p 0 1 0 r
F P
0 g
s
.38455 .63629 m .39139 .62655 L .40235 .62812 L p 1 0 0 r
F P
0 g
s
.40923 .61786 m .40235 .62812 L .39139 .62655 L p 1 0 0 r
F P
0 g
s
.47302 .60782 m .48003 .60061 L .4907 .60538 L p 0 0 1 r
F P
0 g
s
.48003 .60061 m .47302 .60782 L .46233 .60307 L p 0 0 1 r
F P
0 g
s
.28207 .62398 m .28807 .62174 L .29887 .63026 L p 1 0 0 r
F P
0 g
s
.51901 .60768 m .52616 .60047 L .53673 .60524 L p 0 0 1 r
F P
0 g
s
.52616 .60047 m .51901 .60768 L .50841 .60293 L p 0 0 1 r
F P
0 g
s
.63371 .65082 m .62556 .64745 L .6146 .63198 L p 1 0 0 r
F P
0 g
s
.6146 .63198 m .62257 .63389 L .63371 .65082 L p 1 0 0 r
F P
0 g
s
.47642 .57008 m .48345 .5604 L .4941 .56325 L p 1 0 0 r
F P
0 g
s
.4941 .56325 m .50117 .55438 L .51177 .55827 L p 1 0 0 r
F P
0 g
s
.50117 .55438 m .4941 .56325 L .48345 .5604 L p 1 0 0 r
F P
0 g
s
.56499 .60754 m .5723 .60032 L .58277 .60509 L p 0 0 1 r
F P
0 g
s
.5723 .60032 m .56499 .60754 L .5545 .60278 L p 0 0 1 r
F P
0 g
s
.51177 .55827 m .5189 .55043 L .52949 .55561 L p 1 0 0 r
F P
0 g
s
.5189 .55043 m .51177 .55827 L .50117 .55438 L p 1 0 0 r
F P
0 g
s
.40923 .61786 m .41614 .6074 L .42703 .60856 L p 1 0 0 r
F P
0 g
s
.61099 .6074 m .61845 .60018 L .62882 .60495 L p 0 0 1 r
F P
0 g
s
.46599 .62336 m .47297 .61905 L .48366 .62643 L p 0 1 0 r
F P
0 g
s
.47297 .61905 m .46599 .62336 L .45532 .61552 L p 0 1 0 r
F P
0 g
s
.65699 .60726 m .66459 .60004 L .67487 .60481 L p 0 0 1 r
F P
0 g
s
.66459 .60004 m .65699 .60726 L .64669 .6025 L p 0 0 1 r
F P
0 g
s
.703 .60712 m .71075 .5999 L .72093 .60467 L p 0 0 1 r
F P
0 g
s
.71075 .5999 m .703 .60712 L .69279 .60236 L p 0 0 1 r
F P
0 g
s
.75691 .59976 m .74901 .60698 L .7389 .60221 L p 0 0 1 r
F P
0 g
s
.67421 .74365 m .66536 .73452 L .65385 .71245 L p 1 0 0 r
F P
0 g
s
.65385 .71245 m .66243 .71968 L .67421 .74365 L p 1 0 0 r
F P
0 g
s
.57592 .62502 m .58314 .61415 L .59336 .61343 L p 0 1 0 r
F P
0 g
s
.16861 .60637 m .17465 .59915 L .18597 .60392 L p 0 0 1 r
F P
0 g
s
.17465 .59915 m .16861 .60637 L .15727 .60161 L p 0 0 1 r
F P
0 g
s
.33156 .65019 m .3381 .64358 L .34909 .64788 L p 1 0 0 r
F P
0 g
s
.3381 .64358 m .33156 .65019 L .32064 .64443 L p 1 0 0 r
F P
0 g
s
.21461 .60623 m .2208 .599 L .23202 .60378 L p 0 0 1 r
F P
0 g
s
.2208 .599 m .21461 .60623 L .20336 .60146 L p 0 0 1 r
F P
0 g
s
.29903 .56063 m .29235 .57118 L .28094 .57019 L p 0 1 0 r
F P
0 g
s
.30662 .60594 m .3131 .59872 L .32412 .60349 L p 0 0 1 r
F P
0 g
s
.3131 .59872 m .30662 .60594 L .29556 .60118 L p 0 0 1 r
F P
0 g
s
.4587 .57826 m .46571 .56801 L .47642 .57008 L p 1 0 0 r
F P
0 g
s
.48345 .5604 m .47642 .57008 L .46571 .56801 L p 1 0 0 r
F P
0 g
s
.35263 .6058 m .35926 .59857 L .37019 .60335 L p 0 0 1 r
F P
0 g
s
.35926 .59857 m .35263 .6058 L .34167 .60104 L p 0 0 1 r
F P
0 g
s
.6595 .705 m .65092 .69807 L .63963 .67859 L p 1 0 0 r
F P
0 g
s
.63963 .67859 m .64798 .68379 L .6595 .705 L p 1 0 0 r
F P
0 g
s
.39864 .60566 m .40542 .59843 L .41626 .60321 L p 0 0 1 r
F P
0 g
s
.40542 .59843 m .39864 .60566 L .38779 .60089 L p 0 0 1 r
F P
0 g
s
.64676 .41799 m .65069 .4129 L .65124 .41662 L p 0 1 0 r
F P
0 g
s
.64027 .44144 m .64676 .41799 L p .65124 .41662 L 0 1 0 r
F P
0 g
s
.50497 .63998 m .51211 .63444 L .52274 .64002 L p 0 1 0 r
F P
0 g
s
.51211 .63444 m .50497 .63998 L .49433 .63343 L p 0 1 0 r
F P
0 g
s
.45532 .61552 m .46225 .61137 L .47297 .61905 L p 0 1 0 r
F P
0 g
s
.46225 .61137 m .45532 .61552 L .44464 .6075 L p 0 1 0 r
F P
0 g
s
.4907 .60538 m .49777 .59815 L .50841 .60293 L p 0 0 1 r
F P
0 g
s
.49777 .59815 m .4907 .60538 L .48003 .60061 L p 0 0 1 r
F P
0 g
s
.53332 .64496 m .54053 .63786 L .55105 .64145 L p 0 1 0 r
F P
0 g
s
.54053 .63786 m .53332 .64496 L .52274 .64002 L p 0 1 0 r
F P
0 g
s
.53673 .60524 m .54396 .598 L .5545 .60278 L p 0 0 1 r
F P
0 g
s
.54396 .598 m .53673 .60524 L .52616 .60047 L p 0 0 1 r
F P
0 g
s
.52949 .55561 m .53671 .54904 L .54732 .55577 L p 1 0 0 r
F P
0 g
s
.53671 .54904 m .52949 .55561 L .5189 .55043 L p 1 0 0 r
F P
0 g
s
.55105 .64145 m .55828 .63302 L .5687 .63502 L p 0 1 0 r
F P
0 g
s
.57592 .62502 m .5687 .63502 L .55828 .63302 L p 0 1 0 r
F P
0 g
s
.36678 .64306 m .37355 .63409 L .38455 .63629 L p 1 0 0 r
F P
0 g
s
.39139 .62655 m .38455 .63629 L .37355 .63409 L p 1 0 0 r
F P
0 g
s
.34533 .55701 m .35189 .55061 L .36275 .55729 L p 0 1 0 r
F P
0 g
s
.35189 .55061 m .34533 .55701 L .33441 .55136 L p 0 1 0 r
F P
0 g
s
.62882 .60495 m .63634 .59772 L .64669 .6025 L p 0 0 1 r
F P
0 g
s
.63634 .59772 m .62882 .60495 L .61845 .60018 L p 0 0 1 r
F P
0 g
s
.39097 .567 m .38434 .57177 L .37356 .56437 L p 0 1 0 r
F P
0 g
s
.67487 .60481 m .68254 .59758 L .69279 .60236 L p 0 0 1 r
F P
0 g
s
.68254 .59758 m .67487 .60481 L .66459 .60004 L p 0 0 1 r
F P
0 g
s
.64952 .43096 m .64306 .45414 L .63362 .4634 L p 0 1 0 r
F P
0 g
s
.63362 .4634 m .64027 .44144 L .64952 .43096 L p 0 1 0 r
F P
0 g
s
.72093 .60467 m .72875 .59743 L .7389 .60221 L p 0 0 1 r
F P
0 g
s
.72875 .59743 m .72093 .60467 L .71075 .5999 L p 0 0 1 r
F P
0 g
s
.68029 .77047 m .68093 .7756 L p .66828 .74951 L 1 0 0 r
F P
0 g
s
.68093 .7756 m .68008 .77454 L .66828 .74951 L p 1 0 0 r
F P
0 g
s
.66828 .74951 m .67715 .75899 L p .68029 .77047 L 1 0 0 r
F P
0 g
s
.18597 .60392 m .19207 .59668 L .20336 .60146 L p 0 0 1 r
F P
0 g
s
.19207 .59668 m .18597 .60392 L .17465 .59915 L p 0 0 1 r
F P
0 g
s
.55828 .63302 m .55105 .64145 L .54053 .63786 L p 0 1 0 r
F P
0 g
s
.23826 .59654 m .23202 .60378 L .2208 .599 L p 0 0 1 r
F P
0 g
s
.34909 .64788 m .35576 .63995 L .36678 .64306 L p 1 0 0 r
F P
0 g
s
.35576 .63995 m .34909 .64788 L .3381 .64358 L p 1 0 0 r
F P
0 g
s
.44464 .6075 m .45152 .60344 L .46225 .61137 L p 0 1 0 r
F P
0 g
s
.27807 .60364 m .28446 .59639 L .29556 .60118 L p 0 0 1 r
F P
0 g
s
.39139 .62655 m .39826 .61647 L .40923 .61786 L p 1 0 0 r
F P
0 g
s
.41614 .6074 m .40923 .61786 L .39826 .61647 L p 1 0 0 r
F P
0 g
s
.32412 .60349 m .33067 .59625 L .34167 .60104 L p 0 0 1 r
F P
0 g
s
.33067 .59625 m .32412 .60349 L .3131 .59872 L p 0 0 1 r
F P
0 g
s
.37355 .63409 m .36678 .64306 L .35576 .63995 L p 1 0 0 r
F P
0 g
s
.37019 .60335 m .37688 .59611 L .38779 .60089 L p 0 0 1 r
F P
0 g
s
.37688 .59611 m .37019 .60335 L .35926 .59857 L p 0 0 1 r
F P
0 g
s
.46233 .60307 m .46932 .59582 L .48003 .60061 L p 0 0 1 r
F P
0 g
s
.46932 .59582 m .46233 .60307 L .4516 .59829 L p 0 0 1 r
F P
0 g
s
.50841 .60293 m .51555 .59568 L .52616 .60047 L p 0 0 1 r
F P
0 g
s
.51555 .59568 m .50841 .60293 L .49777 .59815 L p 0 0 1 r
F P
0 g
s
.5545 .60278 m .56179 .59554 L .5723 .60032 L p 0 0 1 r
F P
0 g
s
.56179 .59554 m .5545 .60278 L .54396 .598 L p 0 0 1 r
F P
0 g
s
.29903 .56063 m .30568 .55087 L .31682 .55453 L p 0 1 0 r
F P
0 g
s
.31682 .55453 m .3234 .54629 L .33441 .55136 L p 0 1 0 r
F P
0 g
s
.3234 .54629 m .31682 .55453 L .30568 .55087 L p 0 1 0 r
F P
0 g
s
.37356 .56437 m .38017 .55927 L .39097 .567 L p 0 1 0 r
F P
0 g
s
.38017 .55927 m .37356 .56437 L .36275 .55729 L p 0 1 0 r
F P
0 g
s
.64503 .66962 m .63668 .66467 L .62556 .64745 L p 1 0 0 r
F P
0 g
s
.62556 .64745 m .63371 .65082 L .64503 .66962 L p 1 0 0 r
F P
0 g
s
.64669 .6025 m .65427 .59525 L .66459 .60004 L p 0 0 1 r
F P
0 g
s
.65427 .59525 m .64669 .6025 L .63634 .59772 L p 0 0 1 r
F P
0 g
s
.32064 .64443 m .3271 .63855 L .3381 .64358 L p 1 0 0 r
F P
0 g
s
.3271 .63855 m .32064 .64443 L .30974 .63781 L p 1 0 0 r
F P
0 g
s
.63923 .48803 m .63251 .50814 L .62282 .5151 L p 0 1 0 r
F P
0 g
s
.62282 .5151 m .62969 .49617 L .63923 .48803 L p 0 1 0 r
F P
0 g
s
.49433 .63343 m .50144 .62829 L .51211 .63444 L p 0 1 0 r
F P
0 g
s
.50144 .62829 m .49433 .63343 L .48366 .62643 L p 0 1 0 r
F P
0 g
s
.69279 .60236 m .70053 .59511 L .71075 .5999 L p 0 0 1 r
F P
0 g
s
.70053 .59511 m .69279 .60236 L .68254 .59758 L p 0 0 1 r
F P
0 g
s
.56534 .55929 m .55793 .56342 L .54732 .55577 L p 1 0 0 r
F P
0 g
s
.7389 .60221 m .74678 .59496 L .75691 .59976 L p 0 0 1 r
F P
0 g
s
.74678 .59496 m .7389 .60221 L .72875 .59743 L p 0 0 1 r
F P
0 g
s
.64991 .41011 m .65069 .4129 L .64676 .41799 L p 0 1 0 r
F P
0 g
s
.26019 .61066 m .25308 .62635 L .24091 .63144 L p 0 1 0 r
F P
0 g
s
.24091 .63144 m .24819 .61435 L .26019 .61066 L p 0 1 0 r
F P
0 g
s
.28094 .57019 m .28771 .55865 L .29903 .56063 L p 0 1 0 r
F P
0 g
s
.30568 .55087 m .29903 .56063 L .28771 .55865 L p 0 1 0 r
F P
0 g
s
.48345 .5604 m .49051 .55103 L .50117 .55438 L p 1 0 0 r
F P
0 g
s
.50117 .55438 m .50828 .54592 L .5189 .55043 L p 1 0 0 r
F P
0 g
s
.50828 .54592 m .50117 .55438 L .49051 .55103 L p 1 0 0 r
F P
0 g
s
.15727 .60161 m .16329 .59435 L .17465 .59915 L p 0 0 1 r
F P
0 g
s
.16329 .59435 m .15727 .60161 L .14588 .59682 L p 0 0 1 r
F P
0 g
s
.20336 .60146 m .20953 .59421 L .2208 .599 L p 0 0 1 r
F P
0 g
s
.20953 .59421 m .20336 .60146 L .19207 .59668 L p 0 0 1 r
F P
0 g
s
.25308 .62635 m .24584 .64326 L .23348 .64987 L p 0 1 0 r
F P
0 g
s
.23348 .64987 m .24091 .63144 L .25308 .62635 L p 0 1 0 r
F P
0 g
s
.29556 .60118 m .30202 .59392 L .3131 .59872 L p 0 0 1 r
F P
0 g
s
.30202 .59392 m .29556 .60118 L .28446 .59639 L p 0 0 1 r
F P
0 g
s
.34167 .60104 m .34828 .59378 L .35926 .59857 L p 0 0 1 r
F P
0 g
s
.34828 .59378 m .34167 .60104 L .33067 .59625 L p 0 0 1 r
F P
0 g
s
.33441 .55136 m .34097 .54438 L .35189 .55061 L p 0 1 0 r
F P
0 g
s
.34097 .54438 m .33441 .55136 L .3234 .54629 L p 0 1 0 r
F P
0 g
s
.46571 .56801 m .47274 .55795 L .48345 .5604 L p 1 0 0 r
F P
0 g
s
.49051 .55103 m .48345 .5604 L .47274 .55795 L p 1 0 0 r
F P
0 g
s
.38779 .60089 m .39454 .59363 L .40542 .59843 L p 0 0 1 r
F P
0 g
s
.39454 .59363 m .38779 .60089 L .37688 .59611 L p 0 0 1 r
F P
0 g
s
.52274 .64002 m .52994 .63351 L .54053 .63786 L p 0 1 0 r
F P
0 g
s
.52994 .63351 m .52274 .64002 L .51211 .63444 L p 0 1 0 r
F P
0 g
s
.5189 .55043 m .52608 .54313 L .53671 .54904 L p 1 0 0 r
F P
0 g
s
.52608 .54313 m .5189 .55043 L .50828 .54592 L p 1 0 0 r
F P
0 g
s
.48003 .60061 m .48709 .59335 L .49777 .59815 L p 0 0 1 r
F P
0 g
s
.48709 .59335 m .48003 .60061 L .46932 .59582 L p 0 0 1 r
F P
0 g
s
.55828 .63302 m .56553 .62383 L .57592 .62502 L p 0 1 0 r
F P
0 g
s
.58314 .61415 m .57592 .62502 L .56553 .62383 L p 0 1 0 r
F P
0 g
s
.52616 .60047 m .53337 .5932 L .54396 .598 L p 0 0 1 r
F P
0 g
s
.53337 .5932 m .52616 .60047 L .51555 .59568 L p 0 0 1 r
F P
0 g
s
.61956 .62035 m .61158 .61865 L .6007 .60498 L p 1 0 0 r
F P
0 g
s
.6007 .60498 m .60854 .60533 L .61956 .62035 L p 1 0 0 r
F P
0 g
s
.57966 .59306 m .5723 .60032 L .56179 .59554 L p 0 0 1 r
F P
0 g
s
.37355 .63409 m .38036 .62466 L .39139 .62655 L p 1 0 0 r
F P
0 g
s
.39826 .61647 m .39139 .62655 L .38036 .62466 L p 1 0 0 r
F P
0 g
s
.61845 .60018 m .62595 .59292 L .63634 .59772 L p 0 0 1 r
F P
0 g
s
.62595 .59292 m .61845 .60018 L .60803 .59539 L p 0 0 1 r
F P
0 g
s
.54732 .55577 m .55466 .55072 L .56534 .55929 L p 1 0 0 r
F P
0 g
s
.55466 .55072 m .54732 .55577 L .53671 .54904 L p 1 0 0 r
F P
0 g
s
.66459 .60004 m .67225 .59277 L .68254 .59758 L p 0 0 1 r
F P
0 g
s
.67225 .59277 m .66459 .60004 L .65427 .59525 L p 0 0 1 r
F P
0 g
s
.71075 .5999 m .71855 .59263 L .72875 .59743 L p 0 0 1 r
F P
0 g
s
.71855 .59263 m .71075 .5999 L .70053 .59511 L p 0 0 1 r
F P
0 g
s
.36275 .55729 m .36934 .5518 L .38017 .55927 L p 0 1 0 r
F P
0 g
s
.36934 .5518 m .36275 .55729 L .35189 .55061 L p 0 1 0 r
F P
0 g
s
.48366 .62643 m .49074 .62163 L .50144 .62829 L p 0 1 0 r
F P
0 g
s
.49074 .62163 m .48366 .62643 L .47297 .61905 L p 0 1 0 r
F P
0 g
s
.76486 .59249 m .75691 .59976 L .74678 .59496 L p 0 0 1 r
F P
0 g
s
.64676 .41799 m .64946 .40731 L .64991 .41011 L p 0 1 0 r
F P
0 g
s
.30974 .63781 m .3161 .63273 L .3271 .63855 L p 1 0 0 r
F P
0 g
s
.3161 .63273 m .30974 .63781 L .29887 .63026 L p 1 0 0 r
F P
0 g
s
.24584 .64326 m .23847 .66148 L .22589 .66971 L p 0 1 0 r
F P
0 g
s
.22589 .66971 m .23348 .64987 L .24584 .64326 L p 0 1 0 r
F P
0 g
s
.39826 .61647 m .40517 .60612 L .41614 .6074 L p 1 0 0 r
F P
0 g
s
.42308 .59678 m .41614 .6074 L .40517 .60612 L p 1 0 0 r
F P
0 g
s
.17465 .59915 m .18073 .59187 L .19207 .59668 L p 0 0 1 r
F P
0 g
s
.18073 .59187 m .17465 .59915 L .16329 .59435 L p 0 0 1 r
F P
0 g
s
.2208 .599 m .22702 .59173 L .23826 .59654 L p 0 0 1 r
F P
0 g
s
.22702 .59173 m .2208 .599 L .20953 .59421 L p 0 0 1 r
F P
0 g
s
.3131 .59872 m .31962 .59144 L .33067 .59625 L p 0 0 1 r
F P
0 g
s
.31962 .59144 m .3131 .59872 L .30202 .59392 L p 0 0 1 r
F P
0 g
s
.3381 .64358 m .34471 .63625 L .35576 .63995 L p 1 0 0 r
F P
0 g
s
.34471 .63625 m .3381 .64358 L .3271 .63855 L p 1 0 0 r
F P
0 g
s
.35926 .59857 m .36593 .5913 L .37688 .59611 L p 0 0 1 r
F P
0 g
s
.36593 .5913 m .35926 .59857 L .34828 .59378 L p 0 0 1 r
F P
0 g
s
.47274 .55795 m .46571 .56801 L .45492 .56621 L p 1 0 0 r
F P
0 g
s
.41225 .59116 m .40542 .59843 L .39454 .59363 L p 0 0 1 r
F P
0 g
s
.4516 .59829 m .45857 .59101 L .46932 .59582 L p 0 0 1 r
F P
0 g
s
.49777 .59815 m .50489 .59087 L .51555 .59568 L p 0 0 1 r
F P
0 g
s
.50489 .59087 m .49777 .59815 L .48709 .59335 L p 0 0 1 r
F P
0 g
s
.54053 .63786 m .54777 .63013 L .55828 .63302 L p 0 1 0 r
F P
0 g
s
.54777 .63013 m .54053 .63786 L .52994 .63351 L p 0 1 0 r
F P
0 g
s
.54396 .598 m .55123 .59073 L .56179 .59554 L p 0 0 1 r
F P
0 g
s
.55123 .59073 m .54396 .598 L .53337 .5932 L p 0 0 1 r
F P
0 g
s
.35576 .63995 m .36249 .63144 L .37355 .63409 L p 1 0 0 r
F P
0 g
s
.38036 .62466 m .37355 .63409 L .36249 .63144 L p 1 0 0 r
F P
0 g
s
.56553 .62383 m .55828 .63302 L .54777 .63013 L p 0 1 0 r
F P
0 g
s
.63634 .59772 m .64391 .59044 L .65427 .59525 L p 0 0 1 r
F P
0 g
s
.64391 .59044 m .63634 .59772 L .62595 .59292 L p 0 0 1 r
F P
0 g
s
.68254 .59758 m .69026 .59029 L .70053 .59511 L p 0 0 1 r
F P
0 g
s
.69026 .59029 m .68254 .59758 L .67225 .59277 L p 0 0 1 r
F P
0 g
s
.63251 .50814 m .62568 .5269 L .61585 .53271 L p 0 1 0 r
F P
0 g
s
.61585 .53271 m .62282 .5151 L .63251 .50814 L p 0 1 0 r
F P
0 g
s
.72875 .59743 m .73661 .59015 L .74678 .59496 L p 0 0 1 r
F P
0 g
s
.73661 .59015 m .72875 .59743 L .71855 .59263 L p 0 0 1 r
F P
0 g
s
.47297 .61905 m .48001 .61452 L .49074 .62163 L p 0 1 0 r
F P
0 g
s
.48001 .61452 m .47297 .61905 L .46225 .61137 L p 0 1 0 r
F P
0 g
s
.29887 .63026 m .30514 .62605 L .3161 .63273 L p 1 0 0 r
F P
0 g
s
.30514 .62605 m .29887 .63026 L .28807 .62174 L p 1 0 0 r
F P
0 g
s
.36249 .63144 m .35576 .63995 L .34471 .63625 L p 1 0 0 r
F P
0 g
s
.53671 .54904 m .544 .54312 L .55466 .55072 L p 1 0 0 r
F P
0 g
s
.544 .54312 m .53671 .54904 L .52608 .54313 L p 1 0 0 r
F P
0 g
s
.67127 .72849 m .66243 .71968 L .65092 .69807 L p 1 0 0 r
F P
0 g
s
.65092 .69807 m .6595 .705 L .67127 .72849 L p 1 0 0 r
F P
0 g
s
.6484 .4036 m .64946 .40731 L p .63743 .42842 L 0 1 0 r
F P
0 g
s
.64946 .40731 m .64676 .41799 L .63743 .42842 L p 0 1 0 r
F P
0 g
s
.63073 .63703 m .62257 .63389 L .61158 .61865 L p 1 0 0 r
F P
0 g
s
.61158 .61865 m .61956 .62035 L .63073 .63703 L p 1 0 0 r
F P
0 g
s
.14588 .59682 m .15187 .58954 L .16329 .59435 L p 0 0 1 r
F P
0 g
s
.15187 .58954 m .14588 .59682 L .13444 .59202 L p 0 0 1 r
F P
0 g
s
.28771 .55865 m .29442 .54799 L .30568 .55087 L p 0 1 0 r
F P
0 g
s
.30568 .55087 m .3123 .54186 L .3234 .54629 L p 0 1 0 r
F P
0 g
s
.3123 .54186 m .30568 .55087 L .29442 .54799 L p 0 1 0 r
F P
0 g
s
.51211 .63444 m .5193 .62845 L .52994 .63351 L p 0 1 0 r
F P
0 g
s
.5193 .62845 m .51211 .63444 L .50144 .62829 L p 0 1 0 r
F P
0 g
s
.35189 .55061 m .35846 .54467 L .36934 .5518 L p 0 1 0 r
F P
0 g
s
.35846 .54467 m .35189 .55061 L .34097 .54438 L p 0 1 0 r
F P
0 g
s
.56553 .62383 m .57279 .61381 L .58314 .61415 L p 0 1 0 r
F P
0 g
s
.59034 .60233 m .58314 .61415 L .57279 .61381 L p 0 1 0 r
F P
0 g
s
.19207 .59668 m .19821 .58939 L .20953 .59421 L p 0 0 1 r
F P
0 g
s
.19821 .58939 m .19207 .59668 L .18073 .59187 L p 0 0 1 r
F P
0 g
s
.64306 .45414 m .63644 .47586 L .62683 .48392 L p 0 1 0 r
F P
0 g
s
.62683 .48392 m .63362 .4634 L .64306 .45414 L p 0 1 0 r
F P
0 g
s
.24455 .58925 m .23826 .59654 L .22702 .59173 L p 0 0 1 r
F P
0 g
s
.23847 .66148 m .23094 .6811 L .21811 .69109 L p 0 1 0 r
F P
0 g
s
.21811 .69109 m .22589 .66971 L .23847 .66148 L p 0 1 0 r
F P
0 g
s
.28446 .59639 m .2909 .5891 L .30202 .59392 L p 0 0 1 r
F P
0 g
s
.2909 .5891 m .28446 .59639 L .27332 .59159 L p 0 0 1 r
F P
0 g
s
.28335 .60989 m .27734 .61218 L .2667 .60153 L p 1 0 0 r
F P
0 g
s
.2667 .60153 m .27256 .60029 L .28335 .60989 L p 1 0 0 r
F P
0 g
s
.3234 .54629 m .32998 .53867 L .34097 .54438 L p 0 1 0 r
F P
0 g
s
.32998 .53867 m .3234 .54629 L .3123 .54186 L p 0 1 0 r
F P
0 g
s
.33067 .59625 m .33726 .58896 L .34828 .59378 L p 0 0 1 r
F P
0 g
s
.33726 .58896 m .33067 .59625 L .31962 .59144 L p 0 0 1 r
F P
0 g
s
.37688 .59611 m .38362 .58882 L .39454 .59363 L p 0 0 1 r
F P
0 g
s
.38362 .58882 m .37688 .59611 L .36593 .5913 L p 0 0 1 r
F P
0 g
s
.28807 .62174 m .29421 .61846 L .30514 .62605 L p 1 0 0 r
F P
0 g
s
.29421 .61846 m .28807 .62174 L .27734 .61218 L p 1 0 0 r
F P
0 g
s
.65656 .69044 m .64798 .68379 L .63668 .66467 L p 1 0 0 r
F P
0 g
s
.63668 .66467 m .64503 .66962 L .65656 .69044 L p 1 0 0 r
F P
0 g
s
.46932 .59582 m .47636 .58853 L .48709 .59335 L p 0 0 1 r
F P
0 g
s
.47636 .58853 m .46932 .59582 L .45857 .59101 L p 0 0 1 r
F P
0 g
s
.6797 .75895 m .68021 .76274 L p .66536 .73452 L 1 0 0 r
F P
0 g
s
.68021 .76274 m .67715 .75899 L .66536 .73452 L p 1 0 0 r
F P
0 g
s
.66536 .73452 m .67421 .74365 L p .6797 .75895 L 1 0 0 r
F P
0 g
s
.27734 .61218 m .28335 .60989 L .29421 .61846 L p 1 0 0 r
F P
0 g
s
.51555 .59568 m .52274 .58839 L .53337 .5932 L p 0 0 1 r
F P
0 g
s
.52274 .58839 m .51555 .59568 L .50489 .59087 L p 0 0 1 r
F P
0 g
s
.38036 .62466 m .38723 .61484 L .39826 .61647 L p 1 0 0 r
F P
0 g
s
.40517 .60612 m .39826 .61647 L .38723 .61484 L p 1 0 0 r
F P
0 g
s
.47274 .55795 m .4798 .54815 L .49051 .55103 L p 1 0 0 r
F P
0 g
s
.49051 .55103 m .49761 .54203 L .50828 .54592 L p 1 0 0 r
F P
0 g
s
.49761 .54203 m .49051 .55103 L .4798 .54815 L p 1 0 0 r
F P
0 g
s
.56179 .59554 m .56912 .58824 L .57966 .59306 L p 0 0 1 r
F P
0 g
s
.56912 .58824 m .56179 .59554 L .55123 .59073 L p 0 0 1 r
F P
0 g
s
.50828 .54592 m .51544 .53796 L .52608 .54313 L p 1 0 0 r
F P
0 g
s
.51544 .53796 m .50828 .54592 L .49761 .54203 L p 1 0 0 r
F P
0 g
s
.60803 .59539 m .61551 .5881 L .62595 .59292 L p 0 0 1 r
F P
0 g
s
.46225 .61137 m .46925 .60705 L .48001 .61452 L p 0 1 0 r
F P
0 g
s
.46925 .60705 m .46225 .61137 L .45152 .60344 L p 0 1 0 r
F P
0 g
s
.65427 .59525 m .66191 .58795 L .67225 .59277 L p 0 0 1 r
F P
0 g
s
.66191 .58795 m .65427 .59525 L .64391 .59044 L p 0 0 1 r
F P
0 g
s
.40517 .60612 m .41211 .59556 L .42308 .59678 L p 1 0 0 r
F P
0 g
s
.70053 .59511 m .70831 .58781 L .71855 .59263 L p 0 0 1 r
F P
0 g
s
.70831 .58781 m .70053 .59511 L .69026 .59029 L p 0 0 1 r
F P
0 g
s
.74678 .59496 m .75472 .58767 L .76486 .59249 L p 0 0 1 r
F P
0 g
s
.75472 .58767 m .74678 .59496 L .73661 .59015 L p 0 0 1 r
F P
0 g
s
.16329 .59435 m .16934 .58705 L .18073 .59187 L p 0 0 1 r
F P
0 g
s
.16934 .58705 m .16329 .59435 L .15187 .58954 L p 0 0 1 r
F P
0 g
s
.29442 .54799 m .28771 .55865 L .27622 .55761 L p 0 1 0 r
F P
0 g
s
.20953 .59421 m .21573 .5869 L .22702 .59173 L p 0 0 1 r
F P
0 g
s
.21573 .5869 m .20953 .59421 L .19821 .58939 L p 0 0 1 r
F P
0 g
s
.3271 .63855 m .33365 .63189 L .34471 .63625 L p 1 0 0 r
F P
0 g
s
.33365 .63189 m .3271 .63855 L .3161 .63273 L p 1 0 0 r
F P
0 g
s
.30202 .59392 m .30853 .58662 L .31962 .59144 L p 0 0 1 r
F P
0 g
s
.30853 .58662 m .30202 .59392 L .2909 .5891 L p 0 0 1 r
F P
0 g
s
.62568 .5269 m .61875 .54436 L .60879 .54904 L p 0 1 0 r
F P
0 g
s
.60879 .54904 m .61585 .53271 L .62568 .5269 L p 0 1 0 r
F P
0 g
s
.45492 .56621 m .46195 .55584 L .47274 .55795 L p 1 0 0 r
F P
0 g
s
.4798 .54815 m .47274 .55795 L .46195 .55584 L p 1 0 0 r
F P
0 g
s
.34828 .59378 m .35493 .58647 L .36593 .5913 L p 0 0 1 r
F P
0 g
s
.35493 .58647 m .34828 .59378 L .33726 .58896 L p 0 0 1 r
F P
0 g
s
.57279 .61381 m .58004 .6029 L .59034 .60233 L p 0 1 0 r
F P
0 g
s
.39454 .59363 m .40135 .58633 L .41225 .59116 L p 0 0 1 r
F P
0 g
s
.40135 .58633 m .39454 .59363 L .38362 .58882 L p 0 0 1 r
F P
0 g
s
.64396 .40468 m .64781 .39976 L .6484 .4036 L p 0 1 0 r
F P
0 g
s
.63743 .42842 m .64396 .40468 L p .6484 .4036 L 0 1 0 r
F P
0 g
s
.45152 .60344 m .45848 .59927 L .46925 .60705 L p 0 1 0 r
F P
0 g
s
.45848 .59927 m .45152 .60344 L .44078 .59534 L p 0 1 0 r
F P
0 g
s
.48709 .59335 m .49419 .58604 L .50489 .59087 L p 0 0 1 r
F P
0 g
s
.49419 .58604 m .48709 .59335 L .47636 .58853 L p 0 0 1 r
F P
0 g
s
.52608 .54313 m .53333 .53642 L .544 .54312 L p 1 0 0 r
F P
0 g
s
.53333 .53642 m .52608 .54313 L .51544 .53796 L p 1 0 0 r
F P
0 g
s
.50144 .62829 m .50861 .62275 L .5193 .62845 L p 0 1 0 r
F P
0 g
s
.50861 .62275 m .50144 .62829 L .49074 .62163 L p 0 1 0 r
F P
0 g
s
.34097 .54438 m .34754 .53792 L .35846 .54467 L p 0 1 0 r
F P
0 g
s
.34754 .53792 m .34097 .54438 L .32998 .53867 L p 0 1 0 r
F P
0 g
s
.53337 .5932 m .54062 .5859 L .55123 .59073 L p 0 0 1 r
F P
0 g
s
.54062 .5859 m .53337 .5932 L .52274 .58839 L p 0 0 1 r
F P
0 g
s
.38682 .55447 m .38017 .55927 L .36934 .5518 L p 0 1 0 r
F P
0 g
s
.52994 .63351 m .53719 .62641 L .54777 .63013 L p 0 1 0 r
F P
0 g
s
.53719 .62641 m .52994 .63351 L .5193 .62845 L p 0 1 0 r
F P
0 g
s
.62595 .59292 m .6335 .58561 L .64391 .59044 L p 0 0 1 r
F P
0 g
s
.6335 .58561 m .62595 .59292 L .61551 .5881 L p 0 0 1 r
F P
0 g
s
.67225 .59277 m .67995 .58546 L .69026 .59029 L p 0 0 1 r
F P
0 g
s
.67995 .58546 m .67225 .59277 L .66191 .58795 L p 0 0 1 r
F P
0 g
s
.36249 .63144 m .36929 .62239 L .38036 .62466 L p 1 0 0 r
F P
0 g
s
.38723 .61484 m .38036 .62466 L .36929 .62239 L p 1 0 0 r
F P
0 g
s
.64676 .41799 m .64027 .44144 L .63075 .45064 L p 0 1 0 r
F P
0 g
s
.63075 .45064 m .63743 .42842 L .64676 .41799 L p 0 1 0 r
F P
0 g
s
.71855 .59263 m .7264 .58532 L .73661 .59015 L p 0 0 1 r
F P
0 g
s
.7264 .58532 m .71855 .59263 L .70831 .58781 L p 0 0 1 r
F P
0 g
s
.77286 .58517 m .76486 .59249 L .75472 .58767 L p 0 0 1 r
F P
0 g
s
.54777 .63013 m .55504 .62169 L .56553 .62383 L p 0 1 0 r
F P
0 g
s
.57279 .61381 m .56553 .62383 L .55504 .62169 L p 0 1 0 r
F P
0 g
s
.64207 .65553 m .63371 .65082 L .62257 .63389 L p 1 0 0 r
F P
0 g
s
.62257 .63389 m .63073 .63703 L .64207 .65553 L p 1 0 0 r
F P
0 g
s
.13444 .59202 m .14041 .5847 L .15187 .58954 L p 0 0 1 r
F P
0 g
s
.14041 .5847 m .13444 .59202 L .12296 .58719 L p 0 0 1 r
F P
0 g
s
.18073 .59187 m .18685 .58456 L .19821 .58939 L p 0 0 1 r
F P
0 g
s
.18685 .58456 m .18073 .59187 L .16934 .58705 L p 0 0 1 r
F P
0 g
s
.44078 .59534 m .44769 .59126 L .45848 .59927 L p 0 1 0 r
F P
0 g
s
.23329 .58441 m .22702 .59173 L .21573 .5869 L p 0 0 1 r
F P
0 g
s
.27332 .59159 m .27974 .58427 L .2909 .5891 L p 0 0 1 r
F P
0 g
s
.34471 .63625 m .3514 .62826 L .36249 .63144 L p 1 0 0 r
F P
0 g
s
.3514 .62826 m .34471 .63625 L .33365 .63189 L p 1 0 0 r
F P
0 g
s
.31962 .59144 m .32619 .58412 L .33726 .58896 L p 0 0 1 r
F P
0 g
s
.32619 .58412 m .31962 .59144 L .30853 .58662 L p 0 0 1 r
F P
0 g
s
.55504 .62169 m .54777 .63013 L .53719 .62641 L p 0 1 0 r
F P
0 g
s
.36593 .5913 m .37265 .58398 L .38362 .58882 L p 0 0 1 r
F P
0 g
s
.37265 .58398 m .36593 .5913 L .35493 .58647 L p 0 0 1 r
F P
0 g
s
.38723 .61484 m .39413 .60467 L .40517 .60612 L p 1 0 0 r
F P
0 g
s
.41211 .59556 m .40517 .60612 L .39413 .60467 L p 1 0 0 r
F P
0 g
s
.36929 .62239 m .36249 .63144 L .3514 .62826 L p 1 0 0 r
F P
0 g
s
.29442 .54799 m .3011 .53814 L .3123 .54186 L p 0 1 0 r
F P
0 g
s
.3123 .54186 m .31891 .53354 L .32998 .53867 L p 0 1 0 r
F P
0 g
s
.31891 .53354 m .3123 .54186 L .3011 .53814 L p 0 1 0 r
F P
0 g
s
.45857 .59101 m .46558 .58369 L .47636 .58853 L p 0 0 1 r
F P
0 g
s
.46558 .58369 m .45857 .59101 L .44777 .58618 L p 0 0 1 r
F P
0 g
s
.50489 .59087 m .51206 .58355 L .52274 .58839 L p 0 0 1 r
F P
0 g
s
.51206 .58355 m .50489 .59087 L .49419 .58604 L p 0 0 1 r
F P
0 g
s
.36934 .5518 m .37596 .54666 L .38682 .55447 L p 0 1 0 r
F P
0 g
s
.37596 .54666 m .36934 .5518 L .35846 .54467 L p 0 1 0 r
F P
0 g
s
.55123 .59073 m .55854 .5834 L .56912 .58824 L p 0 0 1 r
F P
0 g
s
.55854 .5834 m .55123 .59073 L .54062 .5859 L p 0 0 1 r
F P
0 g
s
.56209 .54644 m .55466 .55072 L .544 .54312 L p 1 0 0 r
F P
0 g
s
.64391 .59044 m .65153 .58311 L .66191 .58795 L p 0 0 1 r
F P
0 g
s
.65153 .58311 m .64391 .59044 L .6335 .58561 L p 0 0 1 r
F P
0 g
s
.3161 .63273 m .32258 .62679 L .33365 .63189 L p 1 0 0 r
F P
0 g
s
.32258 .62679 m .3161 .63273 L .30514 .62605 L p 1 0 0 r
F P
0 g
s
.69026 .59029 m .69803 .58297 L .70831 .58781 L p 0 0 1 r
F P
0 g
s
.69803 .58297 m .69026 .59029 L .67995 .58546 L p 0 0 1 r
F P
0 g
s
.49074 .62163 m .49787 .61648 L .50861 .62275 L p 0 1 0 r
F P
0 g
s
.49787 .61648 m .49074 .62163 L .48001 .61452 L p 0 1 0 r
F P
0 g
s
.73661 .59015 m .74453 .58282 L .75472 .58767 L p 0 0 1 r
F P
0 g
s
.74453 .58282 m .73661 .59015 L .7264 .58532 L p 0 0 1 r
F P
0 g
s
.27622 .55761 m .28302 .54596 L .29442 .54799 L p 0 1 0 r
F P
0 g
s
.3011 .53814 m .29442 .54799 L .28302 .54596 L p 0 1 0 r
F P
0 g
s
.64701 .39703 m .64781 .39976 L .64396 .40468 L p 0 1 0 r
F P
0 g
s
.63644 .47586 m .62969 .49617 L .61992 .50303 L p 0 1 0 r
F P
0 g
s
.61992 .50303 m .62683 .48392 L .63644 .47586 L p 0 1 0 r
F P
0 g
s
.25535 .5985 m .24819 .61435 L .23593 .61942 L p 0 1 0 r
F P
0 g
s
.23593 .61942 m .24327 .60216 L .25535 .5985 L p 0 1 0 r
F P
0 g
s
.4798 .54815 m .48689 .53866 L .49761 .54203 L p 1 0 0 r
F P
0 g
s
.49761 .54203 m .50475 .53345 L .51544 .53796 L p 1 0 0 r
F P
0 g
s
.50475 .53345 m .49761 .54203 L .48689 .53866 L p 1 0 0 r
F P
0 g
s
.15187 .58954 m .1579 .5822 L .16934 .58705 L p 0 0 1 r
F P
0 g
s
.1579 .5822 m .15187 .58954 L .14041 .5847 L p 0 0 1 r
F P
0 g
s
.61653 .60684 m .60854 .60533 L .59762 .59184 L p 1 0 0 r
F P
0 g
s
.59762 .59184 m .60547 .59202 L .61653 .60684 L p 1 0 0 r
F P
0 g
s
.19821 .58939 m .20439 .58206 L .21573 .5869 L p 0 0 1 r
F P
0 g
s
.20439 .58206 m .19821 .58939 L .18685 .58456 L p 0 0 1 r
F P
0 g
s
.32998 .53867 m .33656 .53163 L .34754 .53792 L p 0 1 0 r
F P
0 g
s
.33656 .53163 m .32998 .53867 L .31891 .53354 L p 0 1 0 r
F P
0 g
s
.24819 .61435 m .24091 .63144 L .22844 .63804 L p 0 1 0 r
F P
0 g
s
.22844 .63804 m .23593 .61942 L .24819 .61435 L p 0 1 0 r
F P
0 g
s
.2909 .5891 m .29738 .58177 L .30853 .58662 L p 0 0 1 r
F P
0 g
s
.29738 .58177 m .2909 .5891 L .27974 .58427 L p 0 0 1 r
F P
0 g
s
.33726 .58896 m .34389 .58162 L .35493 .58647 L p 0 0 1 r
F P
0 g
s
.34389 .58162 m .33726 .58896 L .32619 .58412 L p 0 0 1 r
F P
0 g
s
.38362 .58882 m .3904 .58148 L .40135 .58633 L p 0 0 1 r
F P
0 g
s
.3904 .58148 m .38362 .58882 L .37265 .58398 L p 0 0 1 r
F P
0 g
s
.46195 .55584 m .46901 .54567 L .4798 .54815 L p 1 0 0 r
F P
0 g
s
.48689 .53866 m .4798 .54815 L .46901 .54567 L p 1 0 0 r
F P
0 g
s
.51544 .53796 m .52264 .53053 L .53333 .53642 L p 1 0 0 r
F P
0 g
s
.52264 .53053 m .51544 .53796 L .50475 .53345 L p 1 0 0 r
F P
0 g
s
.47636 .58853 m .48344 .58119 L .49419 .58604 L p 0 0 1 r
F P
0 g
s
.48344 .58119 m .47636 .58853 L .46558 .58369 L p 0 0 1 r
F P
0 g
s
.5193 .62845 m .52653 .62193 L .53719 .62641 L p 0 1 0 r
F P
0 g
s
.52653 .62193 m .5193 .62845 L .50861 .62275 L p 0 1 0 r
F P
0 g
s
.544 .54312 m .55136 .53793 L .56209 .54644 L p 1 0 0 r
F P
0 g
s
.55136 .53793 m .544 .54312 L .53333 .53642 L p 1 0 0 r
F P
0 g
s
.52274 .58839 m .52997 .58104 L .54062 .5859 L p 0 0 1 r
F P
0 g
s
.52997 .58104 m .52274 .58839 L .51206 .58355 L p 0 0 1 r
F P
0 g
s
.57651 .5809 m .56912 .58824 L .55854 .5834 L p 0 0 1 r
F P
0 g
s
.61551 .5881 m .62305 .58076 L .6335 .58561 L p 0 0 1 r
F P
0 g
s
.62305 .58076 m .61551 .5881 L .60503 .58326 L p 0 0 1 r
F P
0 g
s
.35846 .54467 m .36507 .53913 L .37596 .54666 L p 0 1 0 r
F P
0 g
s
.36507 .53913 m .35846 .54467 L .34754 .53792 L p 0 1 0 r
F P
0 g
s
.66191 .58795 m .66959 .58061 L .67995 .58546 L p 0 0 1 r
F P
0 g
s
.66959 .58061 m .66191 .58795 L .65153 .58311 L p 0 0 1 r
F P
0 g
s
.36929 .62239 m .37613 .61288 L .38723 .61484 L p 1 0 0 r
F P
0 g
s
.39413 .60467 m .38723 .61484 L .37613 .61288 L p 1 0 0 r
F P
0 g
s
.70831 .58781 m .71615 .58047 L .7264 .58532 L p 0 0 1 r
F P
0 g
s
.71615 .58047 m .70831 .58781 L .69803 .58297 L p 0 0 1 r
F P
0 g
s
.55504 .62169 m .56233 .61248 L .57279 .61381 L p 0 1 0 r
F P
0 g
s
.58004 .6029 m .57279 .61381 L .56233 .61248 L p 0 1 0 r
F P
0 g
s
.75472 .58767 m .7627 .58032 L .77286 .58517 L p 0 0 1 r
F P
0 g
s
.7627 .58032 m .75472 .58767 L .74453 .58282 L p 0 0 1 r
F P
0 g
s
.48001 .61452 m .48711 .60972 L .49787 .61648 L p 0 1 0 r
F P
0 g
s
.48711 .60972 m .48001 .61452 L .46925 .60705 L p 0 1 0 r
F P
0 g
s
.64396 .40468 m .64656 .39431 L .64701 .39703 L p 0 1 0 r
F P
0 g
s
.66833 .71349 m .6595 .705 L .64798 .68379 L p 1 0 0 r
F P
0 g
s
.64798 .68379 m .65656 .69044 L .66833 .71349 L p 1 0 0 r
F P
0 g
s
.24091 .63144 m .23348 .64987 L .22078 .6581 L p 0 1 0 r
F P
0 g
s
.22078 .6581 m .22844 .63804 L .24091 .63144 L p 0 1 0 r
F P
0 g
s
.30514 .62605 m .31152 .62091 L .32258 .62679 L p 1 0 0 r
F P
0 g
s
.31152 .62091 m .30514 .62605 L .29421 .61846 L p 1 0 0 r
F P
0 g
s
.12296 .58719 m .1289 .57984 L .14041 .5847 L p 0 0 1 r
F P
0 g
s
.1289 .57984 m .12296 .58719 L .11142 .58235 L p 0 0 1 r
F P
0 g
s
.16934 .58705 m .17543 .5797 L .18685 .58456 L p 0 0 1 r
F P
0 g
s
.17543 .5797 m .16934 .58705 L .1579 .5822 L p 0 0 1 r
F P
0 g
s
.39413 .60467 m .40107 .59423 L .41211 .59556 L p 1 0 0 r
F P
0 g
s
.41909 .58485 m .41211 .59556 L .40107 .59423 L p 1 0 0 r
F P
0 g
s
.21573 .5869 m .22197 .57955 L .23329 .58441 L p 0 0 1 r
F P
0 g
s
.22197 .57955 m .21573 .5869 L .20439 .58206 L p 0 0 1 r
F P
0 g
s
.67904 .74732 m .6794 .7498 L p .66243 .71968 L 1 0 0 r
F P
0 g
s
.6794 .7498 m .67421 .74365 L .66243 .71968 L p 1 0 0 r
F P
0 g
s
.66243 .71968 m .67127 .72849 L p .67904 .74732 L 1 0 0 r
F P
0 g
s
.30853 .58662 m .31507 .57926 L .32619 .58412 L p 0 0 1 r
F P
0 g
s
.31507 .57926 m .30853 .58662 L .29738 .58177 L p 0 0 1 r
F P
0 g
s
.35493 .58647 m .36163 .57912 L .37265 .58398 L p 0 0 1 r
F P
0 g
s
.36163 .57912 m .35493 .58647 L .34389 .58162 L p 0 0 1 r
F P
0 g
s
.33365 .63189 m .34029 .62449 L .3514 .62826 L p 1 0 0 r
F P
0 g
s
.34029 .62449 m .33365 .63189 L .32258 .62679 L p 1 0 0 r
F P
0 g
s
.46901 .54567 m .46195 .55584 L .45109 .55401 L p 1 0 0 r
F P
0 g
s
.40819 .57897 m .40135 .58633 L .3904 .58148 L p 0 0 1 r
F P
0 g
s
.44777 .58618 m .45476 .57883 L .46558 .58369 L p 0 0 1 r
F P
0 g
s
.62773 .62329 m .61956 .62035 L .60854 .60533 L p 1 0 0 r
F P
0 g
s
.60854 .60533 m .61653 .60684 L .62773 .62329 L p 1 0 0 r
F P
0 g
s
.49419 .58604 m .50134 .57868 L .51206 .58355 L p 0 0 1 r
F P
0 g
s
.50134 .57868 m .49419 .58604 L .48344 .58119 L p 0 0 1 r
F P
0 g
s
.54062 .5859 m .54792 .57854 L .55854 .5834 L p 0 0 1 r
F P
0 g
s
.54792 .57854 m .54062 .5859 L .52997 .58104 L p 0 0 1 r
F P
0 g
s
.3514 .62826 m .35816 .61967 L .36929 .62239 L p 1 0 0 r
F P
0 g
s
.37613 .61288 m .36929 .62239 L .35816 .61967 L p 1 0 0 r
F P
0 g
s
.65361 .676 m .64503 .66962 L .63371 .65082 L p 1 0 0 r
F P
0 g
s
.63371 .65082 m .64207 .65553 L .65361 .676 L p 1 0 0 r
F P
0 g
s
.6335 .58561 m .6411 .57825 L .65153 .58311 L p 0 0 1 r
F P
0 g
s
.6411 .57825 m .6335 .58561 L .62305 .58076 L p 0 0 1 r
F P
0 g
s
.53719 .62641 m .54446 .61867 L .55504 .62169 L p 0 1 0 r
F P
0 g
s
.54446 .61867 m .53719 .62641 L .52653 .62193 L p 0 1 0 r
F P
0 g
s
.67995 .58546 m .6877 .5781 L .69803 .58297 L p 0 0 1 r
F P
0 g
s
.6877 .5781 m .67995 .58546 L .66959 .58061 L p 0 0 1 r
F P
0 g
s
.7264 .58532 m .7343 .57796 L .74453 .58282 L p 0 0 1 r
F P
0 g
s
.7343 .57796 m .7264 .58532 L .71615 .58047 L p 0 0 1 r
F P
0 g
s
.46925 .60705 m .47631 .60251 L .48711 .60972 L p 0 1 0 r
F P
0 g
s
.47631 .60251 m .46925 .60705 L .45848 .59927 L p 0 1 0 r
F P
0 g
s
.53333 .53642 m .54064 .53038 L .55136 .53793 L p 1 0 0 r
F P
0 g
s
.54064 .53038 m .53333 .53642 L .52264 .53053 L p 1 0 0 r
F P
0 g
s
.56233 .61248 m .55504 .62169 L .54446 .61867 L p 0 1 0 r
F P
0 g
s
.78092 .57781 m .77286 .58517 L .7627 .58032 L p 0 0 1 r
F P
0 g
s
.29421 .61846 m .30049 .61418 L .31152 .62091 L p 1 0 0 r
F P
0 g
s
.30049 .61418 m .29421 .61846 L .28335 .60989 L p 1 0 0 r
F P
0 g
s
.28302 .54596 m .28976 .5352 L .3011 .53814 L p 0 1 0 r
F P
0 g
s
.3011 .53814 m .30774 .52905 L .31891 .53354 L p 0 1 0 r
F P
0 g
s
.30774 .52905 m .3011 .53814 L .28976 .5352 L p 0 1 0 r
F P
0 g
s
.64542 .39045 m .64656 .39431 L p .63455 .41507 L 0 1 0 r
F P
0 g
s
.64656 .39431 m .64396 .40468 L .63455 .41507 L p 0 1 0 r
F P
0 g
s
.34754 .53792 m .35413 .53193 L .36507 .53913 L p 0 1 0 r
F P
0 g
s
.35413 .53193 m .34754 .53792 L .33656 .53163 L p 0 1 0 r
F P
0 g
s
.35816 .61967 m .3514 .62826 L .34029 .62449 L p 1 0 0 r
F P
0 g
s
.62969 .49617 m .62282 .5151 L .61291 .5208 L p 0 1 0 r
F P
0 g
s
.61291 .5208 m .61992 .50303 L .62969 .49617 L p 0 1 0 r
F P
0 g
s
.14041 .5847 m .14642 .57734 L .1579 .5822 L p 0 0 1 r
F P
0 g
s
.14642 .57734 m .14041 .5847 L .1289 .57984 L p 0 0 1 r
F P
0 g
s
.18685 .58456 m .193 .57719 L .20439 .58206 L p 0 0 1 r
F P
0 g
s
.193 .57719 m .18685 .58456 L .17543 .5797 L p 0 0 1 r
F P
0 g
s
.31891 .53354 m .3255 .52585 L .33656 .53163 L p 0 1 0 r
F P
0 g
s
.3255 .52585 m .31891 .53354 L .30774 .52905 L p 0 1 0 r
F P
0 g
s
.50861 .62275 m .51582 .61675 L .52653 .62193 L p 0 1 0 r
F P
0 g
s
.51582 .61675 m .50861 .62275 L .49787 .61648 L p 0 1 0 r
F P
0 g
s
.2396 .57705 m .23329 .58441 L .22197 .57955 L p 0 0 1 r
F P
0 g
s
.27974 .58427 m .28619 .5769 L .29738 .58177 L p 0 0 1 r
F P
0 g
s
.28619 .5769 m .27974 .58427 L .26852 .57941 L p 0 0 1 r
F P
0 g
s
.23348 .64987 m .22589 .66971 L .21294 .67971 L p 0 1 0 r
F P
0 g
s
.21294 .67971 m .22078 .6581 L .23348 .64987 L p 0 1 0 r
F P
0 g
s
.64027 .44144 m .63362 .4634 L .62392 .47138 L p 0 1 0 r
F P
0 g
s
.62392 .47138 m .63075 .45064 L .64027 .44144 L p 0 1 0 r
F P
0 g
s
.32619 .58412 m .3328 .57675 L .34389 .58162 L p 0 0 1 r
F P
0 g
s
.3328 .57675 m .32619 .58412 L .31507 .57926 L p 0 0 1 r
F P
0 g
s
.27857 .59794 m .27256 .60029 L .26186 .58962 L p 1 0 0 r
F P
0 g
s
.26186 .58962 m .26772 .58832 L .27857 .59794 L p 1 0 0 r
F P
0 g
s
.37265 .58398 m .37941 .57661 L .3904 .58148 L p 0 0 1 r
F P
0 g
s
.37941 .57661 m .37265 .58398 L .36163 .57912 L p 0 0 1 r
F P
0 g
s
.56233 .61248 m .56962 .60243 L .58004 .6029 L p 0 1 0 r
F P
0 g
s
.58728 .59104 m .58004 .6029 L .56962 .60243 L p 0 1 0 r
F P
0 g
s
.28335 .60989 m .2895 .60654 L .30049 .61418 L p 1 0 0 r
F P
0 g
s
.2895 .60654 m .28335 .60989 L .27256 .60029 L p 1 0 0 r
F P
0 g
s
.46558 .58369 m .47265 .57632 L .48344 .58119 L p 0 0 1 r
F P
0 g
s
.47265 .57632 m .46558 .58369 L .45476 .57883 L p 0 0 1 r
F P
0 g
s
.51206 .58355 m .51927 .57617 L .52997 .58104 L p 0 0 1 r
F P
0 g
s
.51927 .57617 m .51206 .58355 L .50134 .57868 L p 0 0 1 r
F P
0 g
s
.67715 .75899 m .68038 .76623 L .68029 .77047 L p 1 0 0 r
F P
0 g
s
.48689 .53866 m .49401 .52954 L .50475 .53345 L p 1 0 0 r
F P
0 g
s
.50475 .53345 m .51193 .52536 L .52264 .53053 L p 1 0 0 r
F P
0 g
s
.51193 .52536 m .50475 .53345 L .49401 .52954 L p 1 0 0 r
F P
0 g
s
.27256 .60029 m .27857 .59794 L .2895 .60654 L p 1 0 0 r
F P
0 g
s
.46901 .54567 m .4761 .53575 L .48689 .53866 L p 1 0 0 r
F P
0 g
s
.49401 .52954 m .48689 .53866 L .4761 .53575 L p 1 0 0 r
F P
0 g
s
.55854 .5834 m .56591 .57603 L .57651 .5809 L p 0 0 1 r
F P
0 g
s
.56591 .57603 m .55854 .5834 L .54792 .57854 L p 0 0 1 r
F P
0 g
s
.37613 .61288 m .38303 .60297 L .39413 .60467 L p 1 0 0 r
F P
0 g
s
.40107 .59423 m .39413 .60467 L .38303 .60297 L p 1 0 0 r
F P
0 g
s
.45848 .59927 m .46549 .59495 L .47631 .60251 L p 0 1 0 r
F P
0 g
s
.46549 .59495 m .45848 .59927 L .44769 .59126 L p 0 1 0 r
F P
0 g
s
.65153 .58311 m .65919 .57574 L .66959 .58061 L p 0 0 1 r
F P
0 g
s
.65919 .57574 m .65153 .58311 L .6411 .57825 L p 0 0 1 r
F P
0 g
s
.69803 .58297 m .70585 .57559 L .71615 .58047 L p 0 0 1 r
F P
0 g
s
.70585 .57559 m .69803 .58297 L .6877 .5781 L p 0 0 1 r
F P
0 g
s
.68019 .7647 m .68038 .76623 L .67715 .75899 L p 1 0 0 r
F P
0 g
s
.67715 .75899 m .68021 .76274 L .68019 .7647 L p 1 0 0 r
F P
0 g
s
.40107 .59423 m .40805 .58357 L .41909 .58485 L p 1 0 0 r
F P
0 g
s
.74453 .58282 m .7525 .57545 L .7627 .58032 L p 0 0 1 r
F P
0 g
s
.7525 .57545 m .74453 .58282 L .7343 .57796 L p 0 0 1 r
F P
0 g
s
.28976 .5352 m .28302 .54596 L .27145 .54486 L p 0 1 0 r
F P
0 g
s
.11142 .58235 m .11734 .57497 L .1289 .57984 L p 0 0 1 r
F P
0 g
s
.11734 .57497 m .11142 .58235 L .09984 .57748 L p 0 0 1 r
F P
0 g
s
.1579 .5822 m .16397 .57482 L .17543 .5797 L p 0 0 1 r
F P
0 g
s
.16397 .57482 m .1579 .5822 L .14642 .57734 L p 0 0 1 r
F P
0 g
s
.20439 .58206 m .21061 .57468 L .22197 .57955 L p 0 0 1 r
F P
0 g
s
.21061 .57468 m .20439 .58206 L .193 .57719 L p 0 0 1 r
F P
0 g
s
.32258 .62679 m .32915 .62006 L .34029 .62449 L p 1 0 0 r
F P
0 g
s
.32915 .62006 m .32258 .62679 L .31152 .62091 L p 1 0 0 r
F P
0 g
s
.29738 .58177 m .30391 .57439 L .31507 .57926 L p 0 0 1 r
F P
0 g
s
.30391 .57439 m .29738 .58177 L .28619 .5769 L p 0 0 1 r
F P
0 g
s
.34389 .58162 m .35056 .57424 L .36163 .57912 L p 0 0 1 r
F P
0 g
s
.35056 .57424 m .34389 .58162 L .3328 .57675 L p 0 0 1 r
F P
0 g
s
.45109 .55401 m .45816 .54352 L .46901 .54567 L p 1 0 0 r
F P
0 g
s
.4761 .53575 m .46901 .54567 L .45816 .54352 L p 1 0 0 r
F P
0 g
s
.3904 .58148 m .39723 .57409 L .40819 .57897 L p 0 0 1 r
F P
0 g
s
.39723 .57409 m .3904 .58148 L .37941 .57661 L p 0 0 1 r
F P
0 g
s
.64111 .39102 m .64476 .38641 L .64542 .39045 L p 0 1 0 r
F P
0 g
s
.63455 .41507 m .64111 .39102 L p .64542 .39045 L 0 1 0 r
F P
0 g
s
.33656 .53163 m .34314 .52511 L .35413 .53193 L p 0 1 0 r
F P
0 g
s
.34314 .52511 m .33656 .53163 L .3255 .52585 L p 0 1 0 r
F P
0 g
s
.44769 .59126 m .45466 .58708 L .46549 .59495 L p 0 1 0 r
F P
0 g
s
.45466 .58708 m .44769 .59126 L .43688 .58307 L p 0 1 0 r
F P
0 g
s
.63909 .64151 m .63073 .63703 L .61956 .62035 L p 1 0 0 r
F P
0 g
s
.61956 .62035 m .62773 .62329 L .63909 .64151 L p 1 0 0 r
F P
0 g
s
.52264 .53053 m .52991 .5237 L .54064 .53038 L p 1 0 0 r
F P
0 g
s
.52991 .5237 m .52264 .53053 L .51193 .52536 L p 1 0 0 r
F P
0 g
s
.38262 .54182 m .37596 .54666 L .36507 .53913 L p 0 1 0 r
F P
0 g
s
.48344 .58119 m .49057 .5738 L .50134 .57868 L p 0 0 1 r
F P
0 g
s
.49057 .5738 m .48344 .58119 L .47265 .57632 L p 0 0 1 r
F P
0 g
s
.52997 .58104 m .53725 .57366 L .54792 .57854 L p 0 0 1 r
F P
0 g
s
.53725 .57366 m .52997 .58104 L .51927 .57617 L p 0 0 1 r
F P
0 g
s
.62282 .5151 m .61585 .53271 L .60581 .53727 L p 0 1 0 r
F P
0 g
s
.60581 .53727 m .61291 .5208 L .62282 .5151 L p 0 1 0 r
F P
0 g
s
.49787 .61648 m .50506 .61094 L .51582 .61675 L p 0 1 0 r
F P
0 g
s
.50506 .61094 m .49787 .61648 L .48711 .60972 L p 0 1 0 r
F P
0 g
s
.58394 .57351 m .57651 .5809 L .56591 .57603 L p 0 0 1 r
F P
0 g
s
.56962 .60243 m .57691 .59148 L .58728 .59104 L p 0 1 0 r
F P
0 g
s
.62305 .58076 m .63063 .57337 L .6411 .57825 L p 0 0 1 r
F P
0 g
s
.63063 .57337 m .62305 .58076 L .61255 .57588 L p 0 0 1 r
F P
0 g
s
.64396 .40468 m .63743 .42842 L .62784 .43756 L p 0 1 0 r
F P
0 g
s
.62784 .43756 m .63455 .41507 L .64396 .40468 L p 0 1 0 r
F P
0 g
s
.66959 .58061 m .67733 .57322 L .6877 .5781 L p 0 0 1 r
F P
0 g
s
.67733 .57322 m .66959 .58061 L .65919 .57574 L p 0 0 1 r
F P
0 g
s
.71615 .58047 m .72403 .57307 L .7343 .57796 L p 0 0 1 r
F P
0 g
s
.72403 .57307 m .71615 .58047 L .70585 .57559 L p 0 0 1 r
F P
0 g
s
.52653 .62193 m .53381 .61482 L .54446 .61867 L p 0 1 0 r
F P
0 g
s
.53381 .61482 m .52653 .62193 L .51582 .61675 L p 0 1 0 r
F P
0 g
s
.35816 .61967 m .36498 .61055 L .37613 .61288 L p 1 0 0 r
F P
0 g
s
.38303 .60297 m .37613 .61288 L .36498 .61055 L p 1 0 0 r
F P
0 g
s
.7627 .58032 m .77074 .57293 L .78092 .57781 L p 0 0 1 r
F P
0 g
s
.77074 .57293 m .7627 .58032 L .7525 .57545 L p 0 0 1 r
F P
0 g
s
.56963 .54302 m .56209 .54644 L .55136 .53793 L p 1 0 0 r
F P
0 g
s
.22589 .66971 m .21811 .69109 L .20488 .70298 L p 0 1 0 r
F P
0 g
s
.20488 .70298 m .21294 .67971 L .22589 .66971 L p 0 1 0 r
F P
0 g
s
.1289 .57984 m .13488 .57245 L .14642 .57734 L p 0 0 1 r
F P
0 g
s
.13488 .57245 m .1289 .57984 L .11734 .57497 L p 0 0 1 r
F P
0 g
s
.17543 .5797 m .18157 .5723 L .193 .57719 L p 0 0 1 r
F P
0 g
s
.18157 .5723 m .17543 .5797 L .16397 .57482 L p 0 0 1 r
F P
0 g
s
.43688 .58307 m .44381 .57897 L .45466 .58708 L p 0 1 0 r
F P
0 g
s
.54446 .61867 m .55176 .61021 L .56233 .61248 L p 0 1 0 r
F P
0 g
s
.56962 .60243 m .56233 .61248 L .55176 .61021 L p 0 1 0 r
F P
0 g
s
.22826 .57216 m .22197 .57955 L .21061 .57468 L p 0 0 1 r
F P
0 g
s
.26852 .57941 m .27496 .57201 L .28619 .5769 L p 0 0 1 r
F P
0 g
s
.31507 .57926 m .32166 .57186 L .3328 .57675 L p 0 0 1 r
F P
0 g
s
.32166 .57186 m .31507 .57926 L .30391 .57439 L p 0 0 1 r
F P
0 g
s
.28976 .5352 m .29646 .52526 L .30774 .52905 L p 0 1 0 r
F P
0 g
s
.30774 .52905 m .31436 .52065 L .3255 .52585 L p 0 1 0 r
F P
0 g
s
.31436 .52065 m .30774 .52905 L .29646 .52526 L p 0 1 0 r
F P
0 g
s
.34029 .62449 m .347 .61642 L .35816 .61967 L p 1 0 0 r
F P
0 g
s
.347 .61642 m .34029 .62449 L .32915 .62006 L p 1 0 0 r
F P
0 g
s
.36163 .57912 m .36837 .57172 L .37941 .57661 L p 0 0 1 r
F P
0 g
s
.36837 .57172 m .36163 .57912 L .35056 .57424 L p 0 0 1 r
F P
0 g
s
.38303 .60297 m .38996 .59271 L .40107 .59423 L p 1 0 0 r
F P
0 g
s
.40805 .58357 m .40107 .59423 L .38996 .59271 L p 1 0 0 r
F P
0 g
s
.36498 .61055 m .35816 .61967 L .347 .61642 L p 1 0 0 r
F P
0 g
s
.55136 .53793 m .55882 .53353 L .56963 .54302 L p 1 0 0 r
F P
0 g
s
.55882 .53353 m .55136 .53793 L .54064 .53038 L p 1 0 0 r
F P
0 g
s
.36507 .53913 m .3717 .53395 L .38262 .54182 L p 0 1 0 r
F P
0 g
s
.3717 .53395 m .36507 .53913 L .35413 .53193 L p 0 1 0 r
F P
0 g
s
.45476 .57883 m .4618 .57143 L .47265 .57632 L p 0 0 1 r
F P
0 g
s
.4618 .57143 m .45476 .57883 L .44389 .57395 L p 0 0 1 r
F P
0 g
s
.55176 .61021 m .54446 .61867 L .53381 .61482 L p 0 1 0 r
F P
0 g
s
.50134 .57868 m .50853 .57128 L .51927 .57617 L p 0 0 1 r
F P
0 g
s
.50853 .57128 m .50134 .57868 L .49057 .5738 L p 0 0 1 r
F P
0 g
s
.54792 .57854 m .55527 .57113 L .56591 .57603 L p 0 0 1 r
F P
0 g
s
.55527 .57113 m .54792 .57854 L .53725 .57366 L p 0 0 1 r
F P
0 g
s
.6411 .57825 m .64875 .57084 L .65919 .57574 L p 0 0 1 r
F P
0 g
s
.64875 .57084 m .6411 .57825 L .63063 .57337 L p 0 0 1 r
F P
0 g
s
.27145 .54486 m .27829 .53311 L .28976 .5352 L p 0 1 0 r
F P
0 g
s
.29646 .52526 m .28976 .5352 L .27829 .53311 L p 0 1 0 r
F P
0 g
s
.61348 .59334 m .60547 .59202 L .59452 .57868 L p 1 0 0 r
F P
0 g
s
.59452 .57868 m .60238 .57869 L .61348 .59334 L p 1 0 0 r
F P
0 g
s
.6877 .5781 m .6955 .5707 L .70585 .57559 L p 0 0 1 r
F P
0 g
s
.6955 .5707 m .6877 .5781 L .67733 .57322 L p 0 0 1 r
F P
0 g
s
.48711 .60972 m .49426 .60457 L .50506 .61094 L p 0 1 0 r
F P
0 g
s
.49426 .60457 m .48711 .60972 L .47631 .60251 L p 0 1 0 r
F P
0 g
s
.31152 .62091 m .31801 .61491 L .32915 .62006 L p 1 0 0 r
F P
0 g
s
.31801 .61491 m .31152 .62091 L .30049 .61418 L p 1 0 0 r
F P
0 g
s
.7343 .57796 m .74226 .57055 L .7525 .57545 L p 0 0 1 r
F P
0 g
s
.74226 .57055 m .7343 .57796 L .72403 .57307 L p 0 0 1 r
F P
0 g
s
.25047 .58615 m .24327 .60216 L .2309 .60719 L p 0 1 0 r
F P
0 g
s
.2309 .60719 m .23829 .58976 L .25047 .58615 L p 0 1 0 r
F P
0 g
s
.78902 .5704 m .78092 .57781 L .77074 .57293 L p 0 0 1 r
F P
0 g
s
.64398 .38382 m .64476 .38641 L .64111 .39102 L p 0 1 0 r
F P
0 g
s
.4761 .53575 m .48322 .52614 L .49401 .52954 L p 1 0 0 r
F P
0 g
s
.49401 .52954 m .50118 .52084 L .51193 .52536 L p 1 0 0 r
F P
0 g
s
.50118 .52084 m .49401 .52954 L .48322 .52614 L p 1 0 0 r
F P
0 g
s
.66539 .69865 m .65656 .69044 L .64503 .66962 L p 1 0 0 r
F P
0 g
s
.64503 .66962 m .65361 .676 L .66539 .69865 L p 1 0 0 r
F P
0 g
s
.09984 .57748 m .10573 .57007 L .11734 .57497 L p 0 0 1 r
F P
0 g
s
.10573 .57007 m .09984 .57748 L .0882 .57259 L p 0 0 1 r
F P
0 g
s
.63362 .4634 m .62683 .48392 L .61698 .4907 L p 0 1 0 r
F P
0 g
s
.61698 .4907 m .62392 .47138 L .63362 .4634 L p 0 1 0 r
F P
0 g
s
.14642 .57734 m .15246 .56992 L .16397 .57482 L p 0 0 1 r
F P
0 g
s
.15246 .56992 m .14642 .57734 L .13488 .57245 L p 0 0 1 r
F P
0 g
s
.6783 .73556 m .67848 .73678 L p .6595 .705 L 1 0 0 r
F P
0 g
s
.67848 .73678 m .67127 .72849 L .6595 .705 L p 1 0 0 r
F P
0 g
s
.6595 .705 m .66833 .71349 L p .6783 .73556 L 1 0 0 r
F P
0 g
s
.3255 .52585 m .3321 .51875 L .34314 .52511 L p 0 1 0 r
F P
0 g
s
.3321 .51875 m .3255 .52585 L .31436 .52065 L p 0 1 0 r
F P
0 g
s
.193 .57719 m .1992 .56978 L .21061 .57468 L p 0 0 1 r
F P
0 g
s
.1992 .56978 m .193 .57719 L .18157 .5723 L p 0 0 1 r
F P
0 g
s
.24327 .60216 m .23593 .61942 L .22336 .62599 L p 0 1 0 r
F P
0 g
s
.22336 .62599 m .2309 .60719 L .24327 .60216 L p 0 1 0 r
F P
0 g
s
.28619 .5769 m .29269 .56949 L .30391 .57439 L p 0 0 1 r
F P
0 g
s
.29269 .56949 m .28619 .5769 L .27496 .57201 L p 0 0 1 r
F P
0 g
s
.3328 .57675 m .33945 .56934 L .35056 .57424 L p 0 0 1 r
F P
0 g
s
.33945 .56934 m .3328 .57675 L .32166 .57186 L p 0 0 1 r
F P
0 g
s
.51193 .52536 m .51917 .51781 L .52991 .5237 L p 1 0 0 r
F P
0 g
s
.51917 .51781 m .51193 .52536 L .50118 .52084 L p 1 0 0 r
F P
0 g
s
.37941 .57661 m .38621 .56919 L .39723 .57409 L p 0 0 1 r
F P
0 g
s
.38621 .56919 m .37941 .57661 L .36837 .57172 L p 0 0 1 r
F P
0 g
s
.45816 .54352 m .46525 .53323 L .4761 .53575 L p 1 0 0 r
F P
0 g
s
.48322 .52614 m .4761 .53575 L .46525 .53323 L p 1 0 0 r
F P
0 g
s
.54064 .53038 m .54803 .52506 L .55882 .53353 L p 1 0 0 r
F P
0 g
s
.54803 .52506 m .54064 .53038 L .52991 .5237 L p 1 0 0 r
F P
0 g
s
.47265 .57632 m .47975 .5689 L .49057 .5738 L p 0 0 1 r
F P
0 g
s
.47975 .5689 m .47265 .57632 L .4618 .57143 L p 0 0 1 r
F P
0 g
s
.51927 .57617 m .52653 .56875 L .53725 .57366 L p 0 0 1 r
F P
0 g
s
.52653 .56875 m .51927 .57617 L .50853 .57128 L p 0 0 1 r
F P
0 g
s
.35413 .53193 m .36075 .52634 L .3717 .53395 L p 0 1 0 r
F P
0 g
s
.36075 .52634 m .35413 .53193 L .34314 .52511 L p 0 1 0 r
F P
0 g
s
.56591 .57603 m .57332 .56861 L .58394 .57351 L p 0 0 1 r
F P
0 g
s
.57332 .56861 m .56591 .57603 L .55527 .57113 L p 0 0 1 r
F P
0 g
s
.51582 .61675 m .52308 .61022 L .53381 .61482 L p 0 1 0 r
F P
0 g
s
.52308 .61022 m .51582 .61675 L .50506 .61094 L p 0 1 0 r
F P
0 g
s
.61255 .57588 m .62011 .56846 L .63063 .57337 L p 0 0 1 r
F P
0 g
s
.65919 .57574 m .66691 .56831 L .67733 .57322 L p 0 0 1 r
F P
0 g
s
.66691 .56831 m .65919 .57574 L .64875 .57084 L p 0 0 1 r
F P
0 g
s
.70585 .57559 m .71372 .56817 L .72403 .57307 L p 0 0 1 r
F P
0 g
s
.71372 .56817 m .70585 .57559 L .6955 .5707 L p 0 0 1 r
F P
0 g
s
.36498 .61055 m .37186 .60095 L .38303 .60297 L p 1 0 0 r
F P
0 g
s
.38996 .59271 m .38303 .60297 L .37186 .60095 L p 1 0 0 r
F P
0 g
s
.7525 .57545 m .76053 .56802 L .77074 .57293 L p 0 0 1 r
F P
0 g
s
.76053 .56802 m .7525 .57545 L .74226 .57055 L p 0 0 1 r
F P
0 g
s
.47631 .60251 m .48343 .5977 L .49426 .60457 L p 0 1 0 r
F P
0 g
s
.48343 .5977 m .47631 .60251 L .46549 .59495 L p 0 1 0 r
F P
0 g
s
.64111 .39102 m .64353 .38127 L .64398 .38382 L p 0 1 0 r
F P
0 g
s
.65065 .66167 m .64207 .65553 L .63073 .63703 L p 1 0 0 r
F P
0 g
s
.63073 .63703 m .63909 .64151 L .65065 .66167 L p 1 0 0 r
F P
0 g
s
.23593 .61942 m .22844 .63804 L .21564 .64626 L p 0 1 0 r
F P
0 g
s
.21564 .64626 m .22336 .62599 L .23593 .61942 L p 0 1 0 r
F P
0 g
s
.11734 .57497 m .1233 .56754 L .13488 .57245 L p 0 0 1 r
F P
0 g
s
.1233 .56754 m .11734 .57497 L .10573 .57007 L p 0 0 1 r
F P
0 g
s
.62471 .60958 m .61653 .60684 L .60547 .59202 L p 1 0 0 r
F P
0 g
s
.60547 .59202 m .61348 .59334 L .62471 .60958 L p 1 0 0 r
F P
0 g
s
.30049 .61418 m .30689 .60898 L .31801 .61491 L p 1 0 0 r
F P
0 g
s
.30689 .60898 m .30049 .61418 L .2895 .60654 L p 1 0 0 r
F P
0 g
s
.55176 .61021 m .55908 .60097 L .56962 .60243 L p 0 1 0 r
F P
0 g
s
.57691 .59148 m .56962 .60243 L .55908 .60097 L p 0 1 0 r
F P
0 g
s
.16397 .57482 m .17008 .56739 L .18157 .5723 L p 0 0 1 r
F P
0 g
s
.17008 .56739 m .16397 .57482 L .15246 .56992 L p 0 0 1 r
F P
0 g
s
.21061 .57468 m .21687 .56725 L .22826 .57216 L p 0 0 1 r
F P
0 g
s
.21687 .56725 m .21061 .57468 L .1992 .56978 L p 0 0 1 r
F P
0 g
s
.38996 .59271 m .39693 .58217 L .40805 .58357 L p 1 0 0 r
F P
0 g
s
.41505 .57275 m .40805 .58357 L .39693 .58217 L p 1 0 0 r
F P
0 g
s
.30391 .57439 m .31047 .56695 L .32166 .57186 L p 0 0 1 r
F P
0 g
s
.31047 .56695 m .30391 .57439 L .29269 .56949 L p 0 0 1 r
F P
0 g
s
.35056 .57424 m .35728 .56681 L .36837 .57172 L p 0 0 1 r
F P
0 g
s
.35728 .56681 m .35056 .57424 L .33945 .56934 L p 0 0 1 r
F P
0 g
s
.67421 .74365 m .67974 .75579 L .6797 .75895 L p 1 0 0 r
F P
0 g
s
.67939 .75315 m .67974 .75579 L .67421 .74365 L p 1 0 0 r
F P
0 g
s
.67421 .74365 m .6794 .7498 L .67939 .75315 L p 1 0 0 r
F P
0 g
s
.4041 .56666 m .39723 .57409 L .38621 .56919 L p 0 0 1 r
F P
0 g
s
.46525 .53323 m .45816 .54352 L .44723 .54164 L p 1 0 0 r
F P
0 g
s
.32915 .62006 m .33581 .61259 L .347 .61642 L p 1 0 0 r
F P
0 g
s
.33581 .61259 m .32915 .62006 L .31801 .61491 L p 1 0 0 r
F P
0 g
s
.44389 .57395 m .45092 .56651 L .4618 .57143 L p 0 0 1 r
F P
0 g
s
.49057 .5738 m .49774 .56637 L .50853 .57128 L p 0 0 1 r
F P
0 g
s
.49774 .56637 m .49057 .5738 L .47975 .5689 L p 0 0 1 r
F P
0 g
s
.53725 .57366 m .54458 .56622 L .55527 .57113 L p 0 0 1 r
F P
0 g
s
.54458 .56622 m .53725 .57366 L .52653 .56875 L p 0 0 1 r
F P
0 g
s
.63063 .57337 m .63826 .56593 L .64875 .57084 L p 0 0 1 r
F P
0 g
s
.63826 .56593 m .63063 .57337 L .62011 .56846 L p 0 0 1 r
F P
0 g
s
.52991 .5237 m .53725 .51753 L .54803 .52506 L p 1 0 0 r
F P
0 g
s
.53725 .51753 m .52991 .5237 L .51917 .51781 L p 1 0 0 r
F P
0 g
s
.67733 .57322 m .68511 .56578 L .6955 .5707 L p 0 0 1 r
F P
0 g
s
.68511 .56578 m .67733 .57322 L .66691 .56831 L p 0 0 1 r
F P
0 g
s
.347 .61642 m .35379 .60776 L .36498 .61055 L p 1 0 0 r
F P
0 g
s
.37186 .60095 m .36498 .61055 L .35379 .60776 L p 1 0 0 r
F P
0 g
s
.27829 .53311 m .28506 .52226 L .29646 .52526 L p 0 1 0 r
F P
0 g
s
.29646 .52526 m .30313 .51609 L .31436 .52065 L p 0 1 0 r
F P
0 g
s
.30313 .51609 m .29646 .52526 L .28506 .52226 L p 0 1 0 r
F P
0 g
s
.72403 .57307 m .73197 .56563 L .74226 .57055 L p 0 0 1 r
F P
0 g
s
.73197 .56563 m .72403 .57307 L .71372 .56817 L p 0 0 1 r
F P
0 g
s
.46549 .59495 m .47258 .5904 L .48343 .5977 L p 0 1 0 r
F P
0 g
s
.47258 .5904 m .46549 .59495 L .45466 .58708 L p 0 1 0 r
F P
0 g
s
.34314 .52511 m .34975 .51907 L .36075 .52634 L p 0 1 0 r
F P
0 g
s
.34975 .51907 m .34314 .52511 L .3321 .51875 L p 0 1 0 r
F P
0 g
s
.64229 .37718 m .64353 .38127 L p .63163 .40138 L 0 1 0 r
F P
0 g
s
.64353 .38127 m .64111 .39102 L .63163 .40138 L p 0 1 0 r
F P
0 g
s
.77074 .57293 m .77883 .56549 L .78902 .5704 L p 0 0 1 r
F P
0 g
s
.77883 .56549 m .77074 .57293 L .76053 .56802 L p 0 0 1 r
F P
0 g
s
.53381 .61482 m .54111 .60706 L .55176 .61021 L p 0 1 0 r
F P
0 g
s
.54111 .60706 m .53381 .61482 L .52308 .61022 L p 0 1 0 r
F P
0 g
s
.2895 .60654 m .29579 .6022 L .30689 .60898 L p 1 0 0 r
F P
0 g
s
.29579 .6022 m .2895 .60654 L .27857 .59794 L p 1 0 0 r
F P
0 g
s
.31436 .52065 m .32098 .5129 L .3321 .51875 L p 0 1 0 r
F P
0 g
s
.32098 .5129 m .31436 .52065 L .30313 .51609 L p 0 1 0 r
F P
0 g
s
.0882 .57259 m .09407 .56515 L .10573 .57007 L p 0 0 1 r
F P
0 g
s
.09407 .56515 m .0882 .57259 L .07652 .56769 L p 0 0 1 r
F P
0 g
s
.35379 .60776 m .347 .61642 L .33581 .61259 L p 1 0 0 r
F P
0 g
s
.13488 .57245 m .1409 .565 L .15246 .56992 L p 0 0 1 r
F P
0 g
s
.1409 .565 m .13488 .57245 L .1233 .56754 L p 0 0 1 r
F P
0 g
s
.55908 .60097 m .55176 .61021 L .54111 .60706 L p 0 1 0 r
F P
0 g
s
.18157 .5723 m .18774 .56486 L .1992 .56978 L p 0 0 1 r
F P
0 g
s
.18774 .56486 m .18157 .5723 L .17008 .56739 L p 0 0 1 r
F P
0 g
s
.23458 .56471 m .22826 .57216 L .21687 .56725 L p 0 0 1 r
F P
0 g
s
.62683 .48392 m .61992 .50303 L .60993 .50864 L p 0 1 0 r
F P
0 g
s
.60993 .50864 m .61698 .4907 L .62683 .48392 L p 0 1 0 r
F P
0 g
s
.27496 .57201 m .28143 .56456 L .29269 .56949 L p 0 0 1 r
F P
0 g
s
.28143 .56456 m .27496 .57201 L .26367 .5671 L p 0 0 1 r
F P
0 g
s
.50506 .61094 m .5123 .60493 L .52308 .61022 L p 0 1 0 r
F P
0 g
s
.5123 .60493 m .50506 .61094 L .49426 .60457 L p 0 1 0 r
F P
0 g
s
.63743 .42842 m .63075 .45064 L .62098 .45855 L p 0 1 0 r
F P
0 g
s
.62098 .45855 m .62784 .43756 L .63743 .42842 L p 0 1 0 r
F P
0 g
s
.22844 .63804 m .22078 .6581 L .20772 .66809 L p 0 1 0 r
F P
0 g
s
.20772 .66809 m .21564 .64626 L .22844 .63804 L p 0 1 0 r
F P
0 g
s
.32166 .57186 m .32829 .56442 L .33945 .56934 L p 0 0 1 r
F P
0 g
s
.32829 .56442 m .32166 .57186 L .31047 .56695 L p 0 0 1 r
F P
0 g
s
.36837 .57172 m .37515 .56427 L .38621 .56919 L p 0 0 1 r
F P
0 g
s
.37515 .56427 m .36837 .57172 L .35728 .56681 L p 0 0 1 r
F P
0 g
s
.27374 .58589 m .26772 .58832 L .25696 .57763 L p 1 0 0 r
F P
0 g
s
.25696 .57763 m .26282 .57625 L .27374 .58589 L p 1 0 0 r
F P
0 g
s
.4618 .57143 m .46889 .56398 L .47975 .5689 L p 0 0 1 r
F P
0 g
s
.46889 .56398 m .4618 .57143 L .45092 .56651 L p 0 0 1 r
F P
0 g
s
.27857 .59794 m .28473 .59452 L .29579 .6022 L p 1 0 0 r
F P
0 g
s
.28473 .59452 m .27857 .59794 L .26772 .58832 L p 1 0 0 r
F P
0 g
s
.50853 .57128 m .51577 .56383 L .52653 .56875 L p 0 0 1 r
F P
0 g
s
.51577 .56383 m .50853 .57128 L .49774 .56637 L p 0 0 1 r
F P
0 g
s
.48322 .52614 m .49038 .51691 L .50118 .52084 L p 1 0 0 r
F P
0 g
s
.50118 .52084 m .50839 .51263 L .51917 .51781 L p 1 0 0 r
F P
0 g
s
.50839 .51263 m .50118 .52084 L .49038 .51691 L p 1 0 0 r
F P
0 g
s
.46525 .53323 m .47237 .5232 L .48322 .52614 L p 1 0 0 r
F P
0 g
s
.49038 .51691 m .48322 .52614 L .47237 .5232 L p 1 0 0 r
F P
0 g
s
.55527 .57113 m .56266 .56368 L .57332 .56861 L p 0 0 1 r
F P
0 g
s
.56266 .56368 m .55527 .57113 L .54458 .56622 L p 0 0 1 r
F P
0 g
s
.45466 .58708 m .4617 .58274 L .47258 .5904 L p 0 1 0 r
F P
0 g
s
.4617 .58274 m .45466 .58708 L .44381 .57897 L p 0 1 0 r
F P
0 g
s
.26772 .58832 m .27374 .58589 L .28473 .59452 L p 1 0 0 r
F P
0 g
s
.55908 .60097 m .56641 .59088 L .57691 .59148 L p 0 1 0 r
F P
0 g
s
.58419 .57955 m .57691 .59148 L .56641 .59088 L p 0 1 0 r
F P
0 g
s
.64875 .57084 m .65645 .56339 L .66691 .56831 L p 0 0 1 r
F P
0 g
s
.65645 .56339 m .64875 .57084 L .63826 .56593 L p 0 0 1 r
F P
0 g
s
.37186 .60095 m .37878 .59094 L .38996 .59271 L p 1 0 0 r
F P
0 g
s
.39693 .58217 m .38996 .59271 L .37878 .59094 L p 1 0 0 r
F P
0 g
s
.6955 .5707 m .70335 .56324 L .71372 .56817 L p 0 0 1 r
F P
0 g
s
.70335 .56324 m .6955 .5707 L .68511 .56578 L p 0 0 1 r
F P
0 g
s
.28506 .52226 m .27829 .53311 L .26664 .53194 L p 0 1 0 r
F P
0 g
s
.74226 .57055 m .75026 .56309 L .76053 .56802 L p 0 0 1 r
F P
0 g
s
.75026 .56309 m .74226 .57055 L .73197 .56563 L p 0 0 1 r
F P
0 g
s
.39693 .58217 m .40394 .57141 L .41505 .57275 L p 1 0 0 r
F P
0 g
s
.6361 .62756 m .62773 .62329 L .61653 .60684 L p 1 0 0 r
F P
0 g
s
.61653 .60684 m .62471 .60958 L .6361 .62756 L p 1 0 0 r
F P
0 g
s
.79718 .56295 m .78902 .5704 L .77883 .56549 L p 0 0 1 r
F P
0 g
s
.10573 .57007 m .11166 .56261 L .1233 .56754 L p 0 0 1 r
F P
0 g
s
.11166 .56261 m .10573 .57007 L .09407 .56515 L p 0 0 1 r
F P
0 g
s
.15246 .56992 m .15854 .56246 L .17008 .56739 L p 0 0 1 r
F P
0 g
s
.15854 .56246 m .15246 .56992 L .1409 .565 L p 0 0 1 r
F P
0 g
s
.1992 .56978 m .20544 .56232 L .21687 .56725 L p 0 0 1 r
F P
0 g
s
.20544 .56232 m .1992 .56978 L .18774 .56486 L p 0 0 1 r
F P
0 g
s
.29269 .56949 m .29924 .56202 L .31047 .56695 L p 0 0 1 r
F P
0 g
s
.29924 .56202 m .29269 .56949 L .28143 .56456 L p 0 0 1 r
F P
0 g
s
.3321 .51875 m .3387 .51218 L .34975 .51907 L p 0 1 0 r
F P
0 g
s
.3387 .51218 m .3321 .51875 L .32098 .5129 L p 0 1 0 r
F P
0 g
s
.31801 .61491 m .32461 .6081 L .33581 .61259 L p 1 0 0 r
F P
0 g
s
.32461 .6081 m .31801 .61491 L .30689 .60898 L p 1 0 0 r
F P
0 g
s
.33945 .56934 m .34615 .56187 L .35728 .56681 L p 0 0 1 r
F P
0 g
s
.34615 .56187 m .33945 .56934 L .32829 .56442 L p 0 0 1 r
F P
0 g
s
.44723 .54164 m .45432 .53104 L .46525 .53323 L p 1 0 0 r
F P
0 g
s
.47237 .5232 m .46525 .53323 L .45432 .53104 L p 1 0 0 r
F P
0 g
s
.63821 .37701 m .64154 .37284 L .64229 .37718 L p 0 1 0 r
F P
0 g
s
.63163 .40138 m .63821 .37701 L p .64229 .37718 L 0 1 0 r
F P
0 g
s
.38621 .56919 m .39306 .56173 L .4041 .56666 L p 0 0 1 r
F P
0 g
s
.39306 .56173 m .38621 .56919 L .37515 .56427 L p 0 0 1 r
F P
0 g
s
.51917 .51781 m .52646 .51086 L .53725 .51753 L p 1 0 0 r
F P
0 g
s
.52646 .51086 m .51917 .51781 L .50839 .51263 L p 1 0 0 r
F P
0 g
s
.37838 .52907 m .3717 .53395 L .36075 .52634 L p 0 1 0 r
F P
0 g
s
.44381 .57897 m .4508 .57478 L .4617 .58274 L p 0 1 0 r
F P
0 g
s
.4508 .57478 m .44381 .57897 L .43294 .5707 L p 0 1 0 r
F P
0 g
s
.57727 .54052 m .56963 .54302 L .55882 .53353 L p 1 0 0 r
F P
0 g
s
.47975 .5689 m .48691 .56143 L .49774 .56637 L p 0 0 1 r
F P
0 g
s
.48691 .56143 m .47975 .5689 L .46889 .56398 L p 0 0 1 r
F P
0 g
s
.64111 .39102 m .63455 .41507 L .62488 .42417 L p 0 1 0 r
F P
0 g
s
.62488 .42417 m .63163 .40138 L .64111 .39102 L p 0 1 0 r
F P
0 g
s
.52653 .56875 m .53384 .56128 L .54458 .56622 L p 0 0 1 r
F P
0 g
s
.53384 .56128 m .52653 .56875 L .51577 .56383 L p 0 0 1 r
F P
0 g
s
.58078 .56114 m .57332 .56861 L .56266 .56368 L p 0 0 1 r
F P
0 g
s
.49426 .60457 m .50148 .59901 L .5123 .60493 L p 0 1 0 r
F P
0 g
s
.50148 .59901 m .49426 .60457 L .48343 .5977 L p 0 1 0 r
F P
0 g
s
.62011 .56846 m .62773 .56099 L .63826 .56593 L p 0 0 1 r
F P
0 g
s
.62773 .56099 m .62011 .56846 L .60955 .56353 L p 0 0 1 r
F P
0 g
s
.55882 .53353 m .56637 .52997 L .57727 .54052 L p 1 0 0 r
F P
0 g
s
.56637 .52997 m .55882 .53353 L .54803 .52506 L p 1 0 0 r
F P
0 g
s
.66691 .56831 m .67468 .56084 L .68511 .56578 L p 0 0 1 r
F P
0 g
s
.67468 .56084 m .66691 .56831 L .65645 .56339 L p 0 0 1 r
F P
0 g
s
.61992 .50303 m .61291 .5208 L .6028 .52527 L p 0 1 0 r
F P
0 g
s
.6028 .52527 m .60993 .50864 L .61992 .50303 L p 0 1 0 r
F P
0 g
s
.71372 .56817 m .72164 .5607 L .73197 .56563 L p 0 0 1 r
F P
0 g
s
.72164 .5607 m .71372 .56817 L .70335 .56324 L p 0 0 1 r
F P
0 g
s
.76053 .56802 m .7686 .56055 L .77883 .56549 L p 0 0 1 r
F P
0 g
s
.7686 .56055 m .76053 .56802 L .75026 .56309 L p 0 0 1 r
F P
0 g
s
.35379 .60776 m .36063 .59855 L .37186 .60095 L p 1 0 0 r
F P
0 g
s
.37878 .59094 m .37186 .60095 L .36063 .59855 L p 1 0 0 r
F P
0 g
s
.52308 .61022 m .53039 .6031 L .54111 .60706 L p 0 1 0 r
F P
0 g
s
.53039 .6031 m .52308 .61022 L .5123 .60493 L p 0 1 0 r
F P
0 g
s
.56641 .59088 m .57374 .57987 L .58419 .57955 L p 0 1 0 r
F P
0 g
s
.59144 .56658 m .58419 .57955 L .57374 .57987 L p 0 1 0 r
F P
0 g
s
.07652 .56769 m .08236 .56021 L .09407 .56515 L p 0 0 1 r
F P
0 g
s
.08236 .56021 m .07652 .56769 L .06478 .56276 L p 0 0 1 r
F P
0 g
s
.67746 .72368 m .66833 .71349 L .65656 .69044 L p 1 0 0 r
F P
0 g
s
.65656 .69044 m .66539 .69865 L .67746 .72368 L p 1 0 0 r
F P
0 g
s
.1233 .56754 m .12929 .56006 L .1409 .565 L p 0 0 1 r
F P
0 g
s
.12929 .56006 m .1233 .56754 L .11166 .56261 L p 0 0 1 r
F P
0 g
s
.43294 .5707 m .43989 .56659 L .4508 .57478 L p 0 1 0 r
F P
0 g
s
.22078 .6581 m .21294 .67971 L .19958 .6916 L p 0 1 0 r
F P
0 g
s
.19958 .6916 m .20772 .66809 L .22078 .6581 L p 0 1 0 r
F P
0 g
s
.17008 .56739 m .17623 .55992 L .18774 .56486 L p 0 0 1 r
F P
0 g
s
.17623 .55992 m .17008 .56739 L .15854 .56246 L p 0 0 1 r
F P
0 g
s
.66244 .68395 m .65361 .676 L .64207 .65553 L p 1 0 0 r
F P
0 g
s
.64207 .65553 m .65065 .66167 L .66244 .68395 L p 1 0 0 r
F P
0 g
s
.28506 .52226 m .29178 .51224 L .30313 .51609 L p 0 1 0 r
F P
0 g
s
.30313 .51609 m .30977 .50763 L .32098 .5129 L p 0 1 0 r
F P
0 g
s
.30977 .50763 m .30313 .51609 L .29178 .51224 L p 0 1 0 r
F P
0 g
s
.22317 .55977 m .21687 .56725 L .20544 .56232 L p 0 0 1 r
F P
0 g
s
.26367 .5671 m .27012 .55962 L .28143 .56456 L p 0 0 1 r
F P
0 g
s
.31047 .56695 m .31708 .55947 L .32829 .56442 L p 0 0 1 r
F P
0 g
s
.31708 .55947 m .31047 .56695 L .29924 .56202 L p 0 0 1 r
F P
0 g
s
.54803 .52506 m .55551 .52053 L .56637 .52997 L p 1 0 0 r
F P
0 g
s
.55551 .52053 m .54803 .52506 L .53725 .51753 L p 1 0 0 r
F P
0 g
s
.35728 .56681 m .36404 .55933 L .37515 .56427 L p 0 0 1 r
F P
0 g
s
.36404 .55933 m .35728 .56681 L .34615 .56187 L p 0 0 1 r
F P
0 g
s
.36075 .52634 m .3674 .52112 L .37838 .52907 L p 0 1 0 r
F P
0 g
s
.3674 .52112 m .36075 .52634 L .34975 .51907 L p 0 1 0 r
F P
0 g
s
.54111 .60706 m .54845 .59857 L .55908 .60097 L p 0 1 0 r
F P
0 g
s
.56641 .59088 m .55908 .60097 L .54845 .59857 L p 0 1 0 r
F P
0 g
s
.33581 .61259 m .34255 .60445 L .35379 .60776 L p 1 0 0 r
F P
0 g
s
.34255 .60445 m .33581 .61259 L .32461 .6081 L p 1 0 0 r
F P
0 g
s
.45092 .56651 m .45799 .55903 L .46889 .56398 L p 0 0 1 r
F P
0 g
s
.45799 .55903 m .45092 .56651 L .43998 .56158 L p 0 0 1 r
F P
0 g
s
.37878 .59094 m .38574 .58059 L .39693 .58217 L p 1 0 0 r
F P
0 g
s
.40394 .57141 m .39693 .58217 L .38574 .58059 L p 1 0 0 r
F P
0 g
s
.36063 .59855 m .35379 .60776 L .34255 .60445 L p 1 0 0 r
F P
0 g
s
.49774 .56637 m .50497 .55888 L .51577 .56383 L p 0 0 1 r
F P
0 g
s
.50497 .55888 m .49774 .56637 L .48691 .56143 L p 0 0 1 r
F P
0 g
s
.26664 .53194 m .27351 .52009 L .28506 .52226 L p 0 1 0 r
F P
0 g
s
.29178 .51224 m .28506 .52226 L .27351 .52009 L p 0 1 0 r
F P
0 g
s
.54458 .56622 m .55195 .55874 L .56266 .56368 L p 0 0 1 r
F P
0 g
s
.55195 .55874 m .54458 .56622 L .53384 .56128 L p 0 0 1 r
F P
0 g
s
.63826 .56593 m .64594 .55844 L .65645 .56339 L p 0 0 1 r
F P
0 g
s
.64594 .55844 m .63826 .56593 L .62773 .56099 L p 0 0 1 r
F P
0 g
s
.54845 .59857 m .54111 .60706 L .53039 .6031 L p 0 1 0 r
F P
0 g
s
.24555 .5736 m .23829 .58976 L .22583 .59475 L p 0 1 0 r
F P
0 g
s
.22583 .59475 m .23328 .57715 L .24555 .5736 L p 0 1 0 r
F P
0 g
s
.68511 .56578 m .69295 .55829 L .70335 .56324 L p 0 0 1 r
F P
0 g
s
.69295 .55829 m .68511 .56578 L .67468 .56084 L p 0 0 1 r
F P
0 g
s
.61291 .5208 m .60581 .53727 L .5956 .54064 L p 0 1 0 r
F P
0 g
s
.5956 .54064 m .6028 .52527 L .61291 .5208 L p 0 1 0 r
F P
0 g
s
.73197 .56563 m .73996 .55814 L .75026 .56309 L p 0 0 1 r
F P
0 g
s
.73996 .55814 m .73197 .56563 L .72164 .5607 L p 0 0 1 r
F P
0 g
s
.57374 .57987 m .58105 .56787 L .59144 .56658 L p 0 1 0 r
F P
0 g
s
.48343 .5977 m .49062 .59253 L .50148 .59901 L p 0 1 0 r
F P
0 g
s
.49062 .59253 m .48343 .5977 L .47258 .5904 L p 0 1 0 r
F P
0 g
s
.30689 .60898 m .3134 .6029 L .32461 .6081 L p 1 0 0 r
F P
0 g
s
.3134 .6029 m .30689 .60898 L .29579 .6022 L p 1 0 0 r
F P
0 g
s
.77883 .56549 m .78698 .558 L .79718 .56295 L p 0 0 1 r
F P
0 g
s
.78698 .558 m .77883 .56549 L .7686 .56055 L p 0 0 1 r
F P
0 g
s
.32098 .5129 m .32759 .50574 L .3387 .51218 L p 0 1 0 r
F P
0 g
s
.32759 .50574 m .32098 .5129 L .30977 .50763 L p 0 1 0 r
F P
0 g
s
.47237 .5232 m .47952 .51348 L .49038 .51691 L p 1 0 0 r
F P
0 g
s
.49038 .51691 m .49757 .5081 L .50839 .51263 L p 1 0 0 r
F P
0 g
s
.49757 .5081 m .49038 .51691 L .47952 .51348 L p 1 0 0 r
F P
0 g
s
.64081 .37048 m .64154 .37284 L .63821 .37701 L p 0 1 0 r
F P
0 g
s
.67127 .72849 m .67905 .74522 L .67904 .74732 L p 1 0 0 r
F P
0 g
s
.67851 .74148 m .67905 .74522 L .67127 .72849 L p 1 0 0 r
F P
0 g
s
.67127 .72849 m .67848 .73678 L .67851 .74148 L p 1 0 0 r
F P
0 g
s
.09407 .56515 m .09997 .55766 L .11166 .56261 L p 0 0 1 r
F P
0 g
s
.09997 .55766 m .09407 .56515 L .08236 .56021 L p 0 0 1 r
F P
0 g
s
.1409 .565 m .14696 .55751 L .15854 .56246 L p 0 0 1 r
F P
0 g
s
.14696 .55751 m .1409 .565 L .12929 .56006 L p 0 0 1 r
F P
0 g
s
.23829 .58976 m .2309 .60719 L .21823 .61372 L p 0 1 0 r
F P
0 g
s
.21823 .61372 m .22583 .59475 L .23829 .58976 L p 0 1 0 r
F P
0 g
s
.18774 .56486 m .19395 .55736 L .20544 .56232 L p 0 0 1 r
F P
0 g
s
.19395 .55736 m .18774 .56486 L .17623 .55992 L p 0 0 1 r
F P
0 g
s
.63075 .45064 m .62392 .47138 L .61399 .47809 L p 0 1 0 r
F P
0 g
s
.61399 .47809 m .62098 .45855 L .63075 .45064 L p 0 1 0 r
F P
0 g
s
.28143 .56456 m .28795 .55707 L .29924 .56202 L p 0 0 1 r
F P
0 g
s
.28795 .55707 m .28143 .56456 L .27012 .55962 L p 0 0 1 r
F P
0 g
s
.32829 .56442 m .33496 .55692 L .34615 .56187 L p 0 0 1 r
F P
0 g
s
.33496 .55692 m .32829 .56442 L .31708 .55947 L p 0 0 1 r
F P
0 g
s
.50839 .51263 m .51565 .50497 L .52646 .51086 L p 1 0 0 r
F P
0 g
s
.51565 .50497 m .50839 .51263 L .49757 .5081 L p 1 0 0 r
F P
0 g
s
.64768 .64743 m .63909 .64151 L .62773 .62329 L p 1 0 0 r
F P
0 g
s
.62773 .62329 m .6361 .62756 L .64768 .64743 L p 1 0 0 r
F P
0 g
s
.53725 .51753 m .54466 .51209 L .55551 .52053 L p 1 0 0 r
F P
0 g
s
.54466 .51209 m .53725 .51753 L .52646 .51086 L p 1 0 0 r
F P
0 g
s
.37515 .56427 m .38198 .55677 L .39306 .56173 L p 0 0 1 r
F P
0 g
s
.38198 .55677 m .37515 .56427 L .36404 .55933 L p 0 0 1 r
F P
0 g
s
.45432 .53104 m .46145 .52064 L .47237 .5232 L p 1 0 0 r
F P
0 g
s
.47952 .51348 m .47237 .5232 L .46145 .52064 L p 1 0 0 r
F P
0 g
s
.34975 .51907 m .35639 .51344 L .3674 .52112 L p 0 1 0 r
F P
0 g
s
.35639 .51344 m .34975 .51907 L .3387 .51218 L p 0 1 0 r
F P
0 g
s
.46889 .56398 m .47603 .55648 L .48691 .56143 L p 0 0 1 r
F P
0 g
s
.47603 .55648 m .46889 .56398 L .45799 .55903 L p 0 0 1 r
F P
0 g
s
.51577 .56383 m .52306 .55633 L .53384 .56128 L p 0 0 1 r
F P
0 g
s
.52306 .55633 m .51577 .56383 L .50497 .55888 L p 0 0 1 r
F P
0 g
s
.56266 .56368 m .5701 .55618 L .58078 .56114 L p 0 0 1 r
F P
0 g
s
.5701 .55618 m .56266 .56368 L .55195 .55874 L p 0 0 1 r
F P
0 g
s
.62167 .59591 m .61348 .59334 L .60238 .57869 L p 1 0 0 r
F P
0 g
s
.60238 .57869 m .61041 .57985 L .62167 .59591 L p 1 0 0 r
F P
0 g
s
.60955 .56353 m .61715 .55603 L .62773 .56099 L p 0 0 1 r
F P
0 g
s
.65645 .56339 m .6642 .55588 L .67468 .56084 L p 0 0 1 r
F P
0 g
s
.6642 .55588 m .65645 .56339 L .64594 .55844 L p 0 0 1 r
F P
0 g
s
.5123 .60493 m .5196 .59838 L .53039 .6031 L p 0 1 0 r
F P
0 g
s
.5196 .59838 m .5123 .60493 L .50148 .59901 L p 0 1 0 r
F P
0 g
s
.70335 .56324 m .71126 .55574 L .72164 .5607 L p 0 0 1 r
F P
0 g
s
.71126 .55574 m .70335 .56324 L .69295 .55829 L p 0 0 1 r
F P
0 g
s
.75026 .56309 m .75832 .55559 L .7686 .56055 L p 0 0 1 r
F P
0 g
s
.75832 .55559 m .75026 .56309 L .73996 .55814 L p 0 0 1 r
F P
0 g
s
.63821 .37701 m .64038 .36819 L .64081 .37048 L p 0 1 0 r
F P
0 g
s
.36063 .59855 m .36753 .58886 L .37878 .59094 L p 1 0 0 r
F P
0 g
s
.38574 .58059 m .37878 .59094 L .36753 .58886 L p 1 0 0 r
F P
0 g
s
.80539 .55544 m .79718 .56295 L .78698 .558 L p 0 0 1 r
F P
0 g
s
.47258 .5904 m .47972 .58556 L .49062 .59253 L p 0 1 0 r
F P
0 g
s
.47972 .58556 m .47258 .5904 L .4617 .58274 L p 0 1 0 r
F P
0 g
s
.2309 .60719 m .22336 .62599 L .21044 .63418 L p 0 1 0 r
F P
0 g
s
.21044 .63418 m .21823 .61372 L .2309 .60719 L p 0 1 0 r
F P
0 g
s
.06478 .56276 m .0706 .55525 L .08236 .56021 L p 0 0 1 r
F P
0 g
s
.0706 .55525 m .06478 .56276 L .05299 .55781 L p 0 0 1 r
F P
0 g
s
.11166 .56261 m .11763 .5551 L .12929 .56006 L p 0 0 1 r
F P
0 g
s
.11763 .5551 m .11166 .56261 L .09997 .55766 L p 0 0 1 r
F P
0 g
s
.15854 .56246 m .16467 .55495 L .17623 .55992 L p 0 0 1 r
F P
0 g
s
.16467 .55495 m .15854 .56246 L .14696 .55751 L p 0 0 1 r
F P
0 g
s
.29579 .6022 m .3022 .59692 L .3134 .6029 L p 1 0 0 r
F P
0 g
s
.3022 .59692 m .29579 .6022 L .28473 .59452 L p 1 0 0 r
F P
0 g
s
.20544 .56232 m .21171 .55481 L .22317 .55977 L p 0 0 1 r
F P
0 g
s
.21171 .55481 m .20544 .56232 L .19395 .55736 L p 0 0 1 r
F P
0 g
s
.38574 .58059 m .39274 .56995 L .40394 .57141 L p 1 0 0 r
F P
0 g
s
.41097 .56049 m .40394 .57141 L .39274 .56995 L p 1 0 0 r
F P
0 g
s
.29924 .56202 m .30582 .55451 L .31708 .55947 L p 0 0 1 r
F P
0 g
s
.30582 .55451 m .29924 .56202 L .28795 .55707 L p 0 0 1 r
F P
0 g
s
.27351 .52009 m .26664 .53194 L .25482 .53177 L p 0 1 0 r
F P
0 g
s
.54845 .59857 m .5558 .5893 L .56641 .59088 L p 0 1 0 r
F P
0 g
s
.57374 .57987 m .56641 .59088 L .5558 .5893 L p 0 1 0 r
F P
0 g
s
.34615 .56187 m .35289 .55436 L .36404 .55933 L p 0 0 1 r
F P
0 g
s
.35289 .55436 m .34615 .56187 L .33496 .55692 L p 0 0 1 r
F P
0 g
s
.39995 .55421 m .39306 .56173 L .38198 .55677 L p 0 0 1 r
F P
0 g
s
.46145 .52064 m .45432 .53104 L .44332 .5291 L p 1 0 0 r
F P
0 g
s
.43998 .56158 m .44703 .55406 L .45799 .55903 L p 0 0 1 r
F P
0 g
s
.21294 .67971 m .20488 .70298 L .1912 .71694 L p 0 1 0 r
F P
0 g
s
.1912 .71694 m .19958 .6916 L .21294 .67971 L p 0 1 0 r
F P
0 g
s
.32461 .6081 m .33129 .60055 L .34255 .60445 L p 1 0 0 r
F P
0 g
s
.33129 .60055 m .32461 .6081 L .3134 .6029 L p 1 0 0 r
F P
0 g
s
.48691 .56143 m .49411 .55392 L .50497 .55888 L p 0 0 1 r
F P
0 g
s
.49411 .55392 m .48691 .56143 L .47603 .55648 L p 0 0 1 r
F P
0 g
s
.53384 .56128 m .5412 .55377 L .55195 .55874 L p 0 0 1 r
F P
0 g
s
.5412 .55377 m .53384 .56128 L .52306 .55633 L p 0 0 1 r
F P
0 g
s
.27351 .52009 m .2803 .50915 L .29178 .51224 L p 0 1 0 r
F P
0 g
s
.29178 .51224 m .29847 .50299 L .30977 .50763 L p 0 1 0 r
F P
0 g
s
.29847 .50299 m .29178 .51224 L .2803 .50915 L p 0 1 0 r
F P
0 g
s
.52646 .51086 m .53382 .50458 L .54466 .51209 L p 1 0 0 r
F P
0 g
s
.53382 .50458 m .52646 .51086 L .51565 .50497 L p 1 0 0 r
F P
0 g
s
.62773 .56099 m .63539 .55347 L .64594 .55844 L p 0 0 1 r
F P
0 g
s
.63539 .55347 m .62773 .56099 L .61715 .55603 L p 0 0 1 r
F P
0 g
s
.3387 .51218 m .34533 .50609 L .35639 .51344 L p 0 1 0 r
F P
0 g
s
.34533 .50609 m .3387 .51218 L .32759 .50574 L p 0 1 0 r
F P
0 g
s
.63901 .36379 m .64038 .36819 L p .62866 .38734 L 0 1 0 r
F P
0 g
s
.64038 .36819 m .63821 .37701 L .62866 .38734 L p 0 1 0 r
F P
0 g
s
.67468 .56084 m .6825 .55332 L .69295 .55829 L p 0 0 1 r
F P
0 g
s
.6825 .55332 m .67468 .56084 L .6642 .55588 L p 0 0 1 r
F P
0 g
s
.72164 .5607 m .72961 .55317 L .73996 .55814 L p 0 0 1 r
F P
0 g
s
.72961 .55317 m .72164 .5607 L .71126 .55574 L p 0 0 1 r
F P
0 g
s
.34255 .60445 m .34936 .59569 L .36063 .59855 L p 1 0 0 r
F P
0 g
s
.36753 .58886 m .36063 .59855 L .34936 .59569 L p 1 0 0 r
F P
0 g
s
.4617 .58274 m .4688 .57817 L .47972 .58556 L p 0 1 0 r
F P
0 g
s
.4688 .57817 m .4617 .58274 L .4508 .57478 L p 0 1 0 r
F P
0 g
s
.30977 .50763 m .31641 .49982 L .32759 .50574 L p 0 1 0 r
F P
0 g
s
.31641 .49982 m .30977 .50763 L .29847 .50299 L p 0 1 0 r
F P
0 g
s
.7686 .56055 m .77673 .55303 L .78698 .558 L p 0 0 1 r
F P
0 g
s
.77673 .55303 m .7686 .56055 L .75832 .55559 L p 0 0 1 r
F P
0 g
s
.08236 .56021 m .08824 .55269 L .09997 .55766 L p 0 0 1 r
F P
0 g
s
.08824 .55269 m .08236 .56021 L .0706 .55525 L p 0 0 1 r
F P
0 g
s
.53039 .6031 m .53773 .59531 L .54845 .59857 L p 0 1 0 r
F P
0 g
s
.53773 .59531 m .53039 .6031 L .5196 .59838 L p 0 1 0 r
F P
0 g
s
.28473 .59452 m .29104 .59011 L .3022 .59692 L p 1 0 0 r
F P
0 g
s
.29104 .59011 m .28473 .59452 L .27374 .58589 L p 1 0 0 r
F P
0 g
s
.12929 .56006 m .13532 .55254 L .14696 .55751 L p 0 0 1 r
F P
0 g
s
.13532 .55254 m .12929 .56006 L .11763 .5551 L p 0 0 1 r
F P
0 g
s
.34936 .59569 m .34255 .60445 L .33129 .60055 L p 1 0 0 r
F P
0 g
s
.17623 .55992 m .18242 .55239 L .19395 .55736 L p 0 0 1 r
F P
0 g
s
.18242 .55239 m .17623 .55992 L .16467 .55495 L p 0 0 1 r
F P
0 g
s
.22952 .55224 m .22317 .55977 L .21171 .55481 L p 0 0 1 r
F P
0 g
s
.63455 .41507 m .62784 .43756 L .61799 .44543 L p 0 1 0 r
F P
0 g
s
.61799 .44543 m .62488 .42417 L .63455 .41507 L p 0 1 0 r
F P
0 g
s
.27012 .55962 m .27662 .55209 L .28795 .55707 L p 0 0 1 r
F P
0 g
s
.27662 .55209 m .27012 .55962 L .25876 .55466 L p 0 0 1 r
F P
0 g
s
.22336 .62599 m .21564 .64626 L .20245 .65622 L p 0 1 0 r
F P
0 g
s
.20245 .65622 m .21044 .63418 L .22336 .62599 L p 0 1 0 r
F P
0 g
s
.5558 .5893 m .54845 .59857 L .53773 .59531 L p 0 1 0 r
F P
0 g
s
.31708 .55947 m .32373 .55194 L .33496 .55692 L p 0 0 1 r
F P
0 g
s
.32373 .55194 m .31708 .55947 L .30582 .55451 L p 0 0 1 r
F P
0 g
s
.50148 .59901 m .50875 .59298 L .5196 .59838 L p 0 1 0 r
F P
0 g
s
.50875 .59298 m .50148 .59901 L .49062 .59253 L p 0 1 0 r
F P
0 g
s
.62392 .47138 m .61698 .4907 L .60691 .49623 L p 0 1 0 r
F P
0 g
s
.60691 .49623 m .61399 .47809 L .62392 .47138 L p 0 1 0 r
F P
0 g
s
.36404 .55933 m .37085 .5518 L .38198 .55677 L p 0 0 1 r
F P
0 g
s
.37085 .5518 m .36404 .55933 L .35289 .55436 L p 0 0 1 r
F P
0 g
s
.63309 .61366 m .62471 .60958 L .61348 .59334 L p 1 0 0 r
F P
0 g
s
.61348 .59334 m .62167 .59591 L .63309 .61366 L p 1 0 0 r
F P
0 g
s
.45799 .55903 m .4651 .5515 L .47603 .55648 L p 0 0 1 r
F P
0 g
s
.4651 .5515 m .45799 .55903 L .44703 .55406 L p 0 0 1 r
F P
0 g
s
.47952 .51348 m .4867 .50413 L .49757 .5081 L p 1 0 0 r
F P
0 g
s
.49757 .5081 m .50481 .49977 L .51565 .50497 L p 1 0 0 r
F P
0 g
s
.50481 .49977 m .49757 .5081 L .4867 .50413 L p 1 0 0 r
F P
0 g
s
.26885 .57374 m .26282 .57625 L .252 .56556 L p 1 0 0 r
F P
0 g
s
.252 .56556 m .25787 .56409 L .26885 .57374 L p 1 0 0 r
F P
0 g
s
.50497 .55888 m .51223 .55135 L .52306 .55633 L p 0 0 1 r
F P
0 g
s
.51223 .55135 m .50497 .55888 L .49411 .55392 L p 0 0 1 r
F P
0 g
s
.46145 .52064 m .46859 .51049 L .47952 .51348 L p 1 0 0 r
F P
0 g
s
.4867 .50413 m .47952 .51348 L .46859 .51049 L p 1 0 0 r
F P
0 g
s
.27374 .58589 m .27991 .5824 L .29104 .59011 L p 1 0 0 r
F P
0 g
s
.27991 .5824 m .27374 .58589 L .26282 .57625 L p 1 0 0 r
F P
0 g
s
.55195 .55874 m .55938 .5512 L .5701 .55618 L p 0 0 1 r
F P
0 g
s
.55938 .5512 m .55195 .55874 L .5412 .55377 L p 0 0 1 r
F P
0 g
s
.4508 .57478 m .45786 .57042 L .4688 .57817 L p 0 1 0 r
F P
0 g
s
.45786 .57042 m .4508 .57478 L .43989 .56659 L p 0 1 0 r
F P
0 g
s
.25482 .53177 m .26179 .51885 L .27351 .52009 L p 0 1 0 r
F P
0 g
s
.2803 .50915 m .27351 .52009 L .26179 .51885 L p 0 1 0 r
F P
0 g
s
.64594 .55844 m .65368 .5509 L .6642 .55588 L p 0 0 1 r
F P
0 g
s
.65368 .5509 m .64594 .55844 L .63539 .55347 L p 0 0 1 r
F P
0 g
s
.26282 .57625 m .26885 .57374 L .27991 .5824 L p 1 0 0 r
F P
0 g
s
.69295 .55829 m .70084 .55076 L .71126 .55574 L p 0 0 1 r
F P
0 g
s
.70084 .55076 m .69295 .55829 L .6825 .55332 L p 0 0 1 r
F P
0 g
s
.36753 .58886 m .37449 .57876 L .38574 .58059 L p 1 0 0 r
F P
0 g
s
.39274 .56995 m .38574 .58059 L .37449 .57876 L p 1 0 0 r
F P
0 g
s
.73996 .55814 m .748 .55061 L .75832 .55559 L p 0 0 1 r
F P
0 g
s
.748 .55061 m .73996 .55814 L .72961 .55317 L p 0 0 1 r
F P
0 g
s
.78698 .558 m .79517 .55046 L .80539 .55544 L p 0 0 1 r
F P
0 g
s
.79517 .55046 m .78698 .558 L .77673 .55303 L p 0 0 1 r
F P
0 g
s
.39274 .56995 m .39978 .55908 L .41097 .56049 L p 1 0 0 r
F P
0 g
s
.5558 .5893 m .56317 .57916 L .57374 .57987 L p 0 1 0 r
F P
0 g
s
.58105 .56787 m .57374 .57987 L .56317 .57916 L p 0 1 0 r
F P
0 g
s
.05299 .55781 m .05878 .55027 L .0706 .55525 L p 0 0 1 r
F P
0 g
s
.05878 .55027 m .05299 .55781 L .04116 .55284 L p 0 0 1 r
F P
0 g
s
.67451 .70854 m .66539 .69865 L .65361 .676 L p 1 0 0 r
F P
0 g
s
.65361 .676 m .66244 .68395 L .67451 .70854 L p 1 0 0 r
F P
0 g
s
.09997 .55766 m .10592 .55012 L .11763 .5551 L p 0 0 1 r
F P
0 g
s
.10592 .55012 m .09997 .55766 L .08824 .55269 L p 0 0 1 r
F P
0 g
s
.14696 .55751 m .15306 .54997 L .16467 .55495 L p 0 0 1 r
F P
0 g
s
.15306 .54997 m .14696 .55751 L .13532 .55254 L p 0 0 1 r
F P
0 g
s
.19395 .55736 m .2002 .54982 L .21171 .55481 L p 0 0 1 r
F P
0 g
s
.2002 .54982 m .19395 .55736 L .18242 .55239 L p 0 0 1 r
F P
0 g
s
.32759 .50574 m .33421 .49912 L .34533 .50609 L p 0 1 0 r
F P
0 g
s
.33421 .49912 m .32759 .50574 L .31641 .49982 L p 0 1 0 r
F P
0 g
s
.63821 .37701 m .63163 .40138 L .62188 .41046 L p 0 1 0 r
F P
0 g
s
.62188 .41046 m .62866 .38734 L .63821 .37701 L p 0 1 0 r
F P
0 g
s
.28795 .55707 m .29452 .54952 L .30582 .55451 L p 0 0 1 r
F P
0 g
s
.29452 .54952 m .28795 .55707 L .27662 .55209 L p 0 0 1 r
F P
0 g
s
.58505 .53902 m .57727 .54052 L .56637 .52997 L p 1 0 0 r
F P
0 g
s
.56637 .52997 m .57404 .52735 L .58505 .53902 L p 1 0 0 r
F P
0 g
s
.57404 .52735 m .56637 .52997 L .55551 .52053 L p 1 0 0 r
F P
0 g
s
.3741 .51621 m .3674 .52112 L .35639 .51344 L p 0 1 0 r
F P
0 g
s
.33496 .55692 m .34168 .54937 L .35289 .55436 L p 0 0 1 r
F P
0 g
s
.34168 .54937 m .33496 .55692 L .32373 .55194 L p 0 0 1 r
F P
0 g
s
.51565 .50497 m .52297 .49791 L .53382 .50458 L p 1 0 0 r
F P
0 g
s
.52297 .49791 m .51565 .50497 L .50481 .49977 L p 1 0 0 r
F P
0 g
s
.63527 .36262 m .63814 .35906 L .63901 .36379 L p 0 1 0 r
F P
0 g
s
.62866 .38734 m .63527 .36262 L p .63901 .36379 L 0 1 0 r
F P
0 g
s
.44332 .5291 m .45045 .5184 L .46145 .52064 L p 1 0 0 r
F P
0 g
s
.46859 .51049 m .46145 .52064 L .45045 .5184 L p 1 0 0 r
F P
0 g
s
.3134 .6029 m .32001 .59601 L .33129 .60055 L p 1 0 0 r
F P
0 g
s
.32001 .59601 m .3134 .6029 L .3022 .59692 L p 1 0 0 r
F P
0 g
s
.38198 .55677 m .38885 .54923 L .39995 .55421 L p 0 0 1 r
F P
0 g
s
.38885 .54923 m .38198 .55677 L .37085 .5518 L p 0 0 1 r
F P
0 g
s
.65948 .66937 m .65065 .66167 L .63909 .64151 L p 1 0 0 r
F P
0 g
s
.63909 .64151 m .64768 .64743 L .65948 .66937 L p 1 0 0 r
F P
0 g
s
.43989 .56659 m .4469 .56238 L .45786 .57042 L p 0 1 0 r
F P
0 g
s
.4469 .56238 m .43989 .56659 L .42896 .55824 L p 0 1 0 r
F P
0 g
s
.58505 .53902 m .57404 .52735 L p .5856 .53422 L 1 0 0 r
F P
0 g
s
.6028 .52527 m .5956 .54064 L .58808 .54224 L p 0 1 0 r
F P
0 g
s
.58803 .54207 m .6028 .52527 L .58808 .54224 L 0 1 0 r
F
.58753 .54053 m .6028 .52527 L .58784 .54229 L F
.5925 .52854 m .6028 .52527 L p .58754 .54051 L F P
0 g
s
.57727 .54052 m .58505 .53902 L .58784 .54229 L p 1 0 0 r
F P
0 g
s
.58784 .54229 m .5956 .54064 L p .58871 .54661 L 0 1 0 r
F P
0 g
s
.58812 .54712 m .58784 .54229 L .58871 .54661 L 0 1 0 r
F
.58812 .54712 m .58784 .54229 L .58786 .54241 L 1 0 0 r
F
.58815 .54714 m .58785 .5423 L .58923 .54699 L 0 0 1 r
F
.58815 .54714 m .58786 .54241 L .58875 .5475 L 1 0 0 r
F
.58812 .54712 m .58786 .54241 L .58815 .54714 L F
.57727 .54052 m .58784 .54229 L .58812 .54712 L F
.57759 .54863 m .58782 .54232 L .58809 .54715 L 0 0 1 r
F
.58782 .54229 m .58784 .54229 L p .58782 .54231 L 0 1 0 r
F P
0 g
s
.57759 .54863 m .58513 .54103 L .58782 .54229 L p 0 0 1 r
F P
0 g
s
.58782 .54231 m .58784 .54229 L .58809 .54715 L 0 1 0 r
F
.58782 .54229 m .58785 .5423 L p .58782 .54232 L 0 0 1 r
F P
0 g
s
.57759 .54863 m .58782 .54229 L .58782 .54232 L 0 0 1 r
F
.58809 .54715 m .58784 .54229 L .58812 .54712 L 0 1 0 r
F
.57788 .556 m .58782 .54231 L .58809 .54715 L F
.57788 .556 m .58521 .54284 L .58782 .54229 L p F P
0 g
s
.57788 .556 m .58782 .54229 L .58782 .54231 L 0 1 0 r
F
.58809 .54715 m .58785 .5423 L .58815 .54714 L 0 0 1 r
F
.58782 .54232 m .58785 .5423 L .58809 .54715 L F
.58785 .5423 m .59585 .54605 L p .58923 .54699 L F P
0 g
s
.60419 .55286 m .59613 .55199 L .58785 .5423 L p 1 0 0 r
F P
0 g
s
.58785 .5423 m .58784 .54229 L p .58785 .54229 L 1 0 0 r
F P
0 g
s
.60346 .53843 m .59585 .54605 L .58785 .5423 L p 0 0 1 r
F P
0 g
s
.58784 .54229 m .58764 .54206 L p .58741 .54087 L 1 0 0 r
F P
0 g
s
.58764 .54206 m .58505 .53902 L p .58736 .54069 L 1 0 0 r
F P
0 g
s
.58736 .54069 m .58738 .54071 L .58764 .54206 L 1 0 0 r
F
.58736 .54069 m .58753 .54053 L .58784 .54229 L 0 1 0 r
F
.58741 .54087 m .58738 .54071 L .58784 .54229 L 1 0 0 r
F
.58738 .54071 m .58782 .54218 L .58784 .54229 L F
.58785 .5423 m .58782 .54229 L p .58738 .54071 L 0 0 1 r
F P
0 g
s
.58745 .54212 m .58513 .54103 L p .58734 .54072 L 0 0 1 r
F P
0 g
s
.58736 .54069 m .58722 .53891 L .58754 .54051 L 0 1 0 r
F
.58808 .54224 m .58784 .54229 L p .58803 .54207 L F P
0 g
s
.58738 .54071 m .60346 .53843 L .58785 .5423 L 0 0 1 r
F
.58722 .53891 m .5925 .52854 L p .58754 .54051 L 0 1 0 r
F P
0 g
s
.61415 .54347 m .60652 .55105 L .59585 .54605 L p 0 0 1 r
F P
0 g
s
.59585 .54605 m .60346 .53843 L .61415 .54347 L p 0 0 1 r
F P
0 g
s
.59272 .53338 m .60346 .53843 L p .58778 .54065 L 0 0 1 r
F P
0 g
s
.58738 .54071 m .58768 .54031 L .58778 .54065 L 0 0 1 r
F
.58768 .54031 m .59272 .53338 L .58778 .54065 L F
.58724 .53891 m .59272 .53338 L p .58738 .54071 L F P
0 g
s
.58505 .53902 m .58722 .53891 L p .58738 .54071 L 1 0 0 r
F P
0 g
s
.58722 .53891 m .58724 .53891 L p .58726 .53915 L 1 0 0 r
F P
0 g
s
.58722 .53891 m .58726 .53915 L .58738 .54071 L 1 0 0 r
F
.5856 .53422 m .58579 .53433 L .58609 .53581 L F
.58705 .53892 m .58505 .53902 L p .5856 .53422 L F P
0 g
s
.58513 .54103 m .57437 .53598 L p .58575 .53437 L 0 0 1 r
F P
0 g
s
.58513 .54103 m .57759 .54863 L .56685 .54362 L p 0 0 1 r
F P
0 g
s
.58183 .52572 m .57077 .51411 L p .58332 .52142 L 1 0 0 r
F P
0 g
s
.58937 .51622 m .58464 .52553 L p .58332 .52142 L 0 1 0 r
F P
0 g
s
.58332 .52142 m .58337 .52145 L .58335 .52151 L 1 0 0 r
F
.58332 .52142 m .58335 .52151 L .58183 .52572 L F
.58337 .52145 m .5836 .52218 L .58183 .52572 L F
.58937 .51622 m .59974 .51303 L p .58509 .52762 L 0 1 0 r
F P
0 g
s
.58508 .52761 m .58937 .51622 L .58509 .52762 L 0 1 0 r
F
.5855 .52996 m .5925 .52854 L p .58632 .53388 L F P
0 g
s
.58579 .53433 m .5855 .52996 L .58632 .53388 L 0 1 0 r
F
.5925 .52854 m .58722 .53891 L p .58636 .53384 L F P
0 g
s
.58609 .53581 m .58579 .53433 L .58705 .53892 L 1 0 0 r
F
.58579 .53433 m .58636 .53384 L .58716 .53871 L 0 1 0 r
F
.58579 .53433 m .58583 .53436 L .58686 .53777 L 1 0 0 r
F
.58722 .53891 m .5872 .53895 L p .58636 .53384 L 0 1 0 r
F P
0 g
s
.59272 .53338 m .58724 .53891 L p .58593 .53468 L 0 0 1 r
F P
0 g
s
.58583 .53436 m .58684 .5376 L .58686 .53777 L 1 0 0 r
F
.58579 .53433 m .58686 .53777 L .58705 .53892 L F
.58722 .53891 m .58705 .53892 L p .58636 .53467 L F P
0 g
s
.58575 .53437 m .58579 .53433 L .5872 .53895 L 0 1 0 r
F
.58579 .53433 m .58716 .53871 L .5872 .53895 L F
.58583 .53436 m .59272 .53338 L .58585 .53469 L 0 0 1 r
F
.58583 .53436 m .58636 .53467 L .58684 .5376 L 1 0 0 r
F
.58585 .53469 m .58593 .53468 L .5872 .53895 L 0 0 1 r
F
.58724 .53891 m .58722 .53891 L p .58717 .5387 L 1 0 0 r
F P
0 g
s
.58724 .53891 m .5872 .53895 L p .58593 .53468 L 0 0 1 r
F P
0 g
s
.58575 .53437 m .58583 .53436 L .58585 .53469 L 0 0 1 r
F
.5855 .52996 m .58552 .52999 L p .58579 .53433 L 1 0 0 r
F P
0 g
s
.58579 .53433 m .58552 .52999 L .58583 .53436 L 1 0 0 r
F
.57404 .52735 m .58183 .52572 L .58523 .52965 L p F P
0 g
s
.57404 .52735 m .58523 .52965 L .58525 .5299 L 1 0 0 r
F
.57404 .52735 m .5855 .52996 L .58579 .53433 L F
.58579 .53433 m .58573 .53404 L .5855 .52996 L 0 1 0 r
F
.57437 .53598 m .58194 .5283 L .58547 .52996 L p 0 0 1 r
F P
0 g
s
.57437 .53598 m .58547 .52996 L .58548 .53001 L 0 0 1 r
F
.58547 .52996 m .5855 .52996 L p .58573 .53404 L 0 1 0 r
F P
0 g
s
.58575 .53437 m .58573 .53404 L .58579 .53433 L 0 1 0 r
F
.58575 .53437 m .58552 .52999 L .5868 .53422 L 0 0 1 r
F
.57437 .53598 m .58548 .53001 L .58575 .53437 L F
.58548 .53001 m .58552 .52999 L .58575 .53437 L F
.56685 .54362 m .57437 .53598 L .58513 .54103 L p F P
0 g
s
.57467 .54393 m .58492 .53008 L .58573 .53404 L 0 1 0 r
F
.57467 .54393 m .58573 .53404 L .58575 .53437 L F
.58492 .53008 m .58547 .52996 L p .58573 .53404 L F P
0 g
s
.58547 .52996 m .58552 .52999 L p .58548 .53001 L 0 0 1 r
F P
0 g
s
.58552 .52999 m .59272 .53338 L p .5868 .53422 L 0 0 1 r
F P
0 g
s
.60104 .53935 m .59296 .5386 L .58552 .52999 L p 1 0 0 r
F P
0 g
s
.58552 .52999 m .5855 .52996 L p .58551 .52997 L 1 0 0 r
F P
0 g
s
.60993 .50864 m .6028 .52527 L .5925 .52854 L p 0 1 0 r
F P
0 g
s
.5925 .52854 m .59974 .51303 L .60993 .50864 L p 0 1 0 r
F P
0 g
s
.59974 .51303 m .5925 .52854 L .5855 .52996 L p 0 1 0 r
F P
0 g
s
.58549 .52994 m .59974 .51303 L .5855 .52996 L 0 1 0 r
F
.58485 .52786 m .58544 .52978 L .58523 .52965 L 1 0 0 r
F
.5849 .52817 m .59974 .51303 L .58547 .52996 L 0 1 0 r
F
.58523 .52965 m .58183 .52572 L p .58485 .52786 L 1 0 0 r
F P
0 g
s
.58482 .52789 m .58485 .52786 L .5849 .52817 L 0 1 0 r
F
.58485 .52786 m .59974 .51303 L .5849 .52817 L F
.60036 .52568 m .59272 .53338 L .58552 .52999 L p 0 0 1 r
F P
0 g
s
.58488 .52788 m .60036 .52568 L .58552 .52999 L 0 0 1 r
F
.61112 .53077 m .60346 .53843 L .59272 .53338 L p F P
0 g
s
.59272 .53338 m .60036 .52568 L .61112 .53077 L p 0 0 1 r
F P
0 g
s
.58485 .52786 m .58487 .52509 L .58507 .52764 L 0 1 0 r
F
.58956 .52057 m .60036 .52568 L p .5854 .52781 L 0 0 1 r
F P
0 g
s
.58524 .52731 m .58956 .52057 L .5854 .52781 L 0 0 1 r
F
.58442 .52555 m .58464 .52553 L p .58485 .52786 L 1 0 0 r
F P
0 g
s
.58482 .52773 m .58482 .52757 L .58485 .52786 L 0 1 0 r
F
.58482 .52757 m .58487 .52509 L .58485 .52786 L F
.58461 .52559 m .58487 .52509 L p .58482 .52789 L F P
0 g
s
.58487 .52509 m .58937 .51622 L p .58507 .52764 L 0 1 0 r
F P
0 g
s
.58467 .52553 m .58956 .52057 L p .58488 .52788 L 0 0 1 r
F P
0 g
s
.58464 .52553 m .58467 .52553 L p .58485 .52786 L 1 0 0 r
F P
0 g
s
.58507 .52764 m .58508 .52761 L .58509 .52762 L 0 1 0 r
F
.58488 .52788 m .58524 .52731 L .5854 .52781 L 0 0 1 r
F
.58467 .52553 m .58977 .52518 L p .58488 .52784 L 1 0 0 r
F P
0 g
s
.58467 .52553 m .58488 .52784 L .58485 .52786 L 1 0 0 r
F
.58956 .52057 m .58467 .52553 L p .58337 .52145 L 0 0 1 r
F P
0 g
s
.58383 .52172 m .58675 .52342 L .58467 .52553 L 1 0 0 r
F
.58675 .52342 m .58977 .52518 L .58467 .52553 L F
.58467 .52553 m .58464 .52553 L p .58458 .52524 L F P
0 g
s
.58383 .52172 m .58467 .52553 L .58458 .52524 L 1 0 0 r
F
.58485 .52786 m .58488 .52784 L .58488 .52788 L F
.58183 .52572 m .58442 .52555 L p .58485 .52786 L F P
0 g
s
.58482 .52789 m .58482 .52773 L .58485 .52786 L 0 1 0 r
F
.58464 .52553 m .58183 .52572 L p .58358 .52223 L 1 0 0 r
F P
0 g
s
.58383 .52172 m .58464 .52553 L .58358 .52223 L 1 0 0 r
F
.58464 .52553 m .58461 .52559 L p .58332 .52142 L 0 1 0 r
F P
0 g
s
.58194 .5283 m .58461 .52559 L p .58488 .52788 L 0 0 1 r
F P
0 g
s
.5855 .52996 m .58523 .52965 L p .58546 .52979 L 1 0 0 r
F P
0 g
s
.58523 .52965 m .5855 .52996 L p .58525 .5299 L 1 0 0 r
F P
0 g
s
.58547 .52996 m .58194 .5283 L p .58482 .52789 L 0 0 1 r
F P
0 g
s
.58332 .52142 m .58461 .52559 L .5833 .52155 L 0 1 0 r
F
.58337 .52145 m .58458 .52524 L .58194 .5283 L 0 0 1 r
F
.58461 .52559 m .58194 .5283 L p .58458 .52524 L F P
0 g
s
.58327 .52146 m .58333 .52163 L .58194 .5283 L 0 0 1 r
F
.58461 .52559 m .58204 .53066 L p .5833 .52155 L 0 1 0 r
F P
0 g
s
.58461 .52559 m .58467 .52553 L p .5847 .52587 L 0 0 1 r
F P
0 g
s
.58461 .52559 m .5847 .52587 L .58488 .52788 L 0 0 1 r
F
.58977 .52518 m .60104 .53935 L p .58488 .52788 L 1 0 0 r
F P
0 g
s
.58488 .52784 m .58977 .52518 L .58488 .52788 L 1 0 0 r
F
.58485 .52786 m .60104 .53935 L .58544 .52978 L F
.5855 .52996 m .58547 .52996 L p .58549 .52994 L 0 1 0 r
F P
0 g
s
.58547 .52996 m .58204 .53066 L p .58482 .52789 L 0 1 0 r
F P
0 g
s
.58546 .52979 m .58546 .5298 L .5855 .52996 L 1 0 0 r
F
.58552 .52999 m .58547 .52996 L p .58488 .52788 L 0 0 1 r
F P
0 g
s
.58482 .52789 m .58488 .52788 L .58547 .52996 L 0 0 1 r
F
.58546 .52979 m .58546 .52979 L .58546 .5298 L 1 0 0 r
F
.58551 .52997 m .60104 .53935 L .58552 .52999 L F
.58552 .52999 m .59296 .5386 L p .58583 .53436 L F P
0 g
s
.58546 .52979 m .60104 .53935 L .5855 .52996 L 1 0 0 r
F
.58204 .53066 m .58461 .52559 L p .58482 .52789 L 0 1 0 r
F P
0 g
s
.58467 .52553 m .58461 .52559 L p .58458 .52524 L 0 0 1 r
F P
0 g
s
.58183 .52572 m .57404 .52735 L .56309 .51685 L p 1 0 0 r
F P
0 g
s
.56309 .51685 m .57077 .51411 L .58183 .52572 L p 1 0 0 r
F P
0 g
s
.58194 .5283 m .57111 .5232 L p .58327 .52146 L 0 0 1 r
F P
0 g
s
.58327 .52146 m .58332 .52142 L .5833 .52155 L 0 1 0 r
F
.58327 .52146 m .58337 .52145 L .58333 .52163 L 0 0 1 r
F
.58194 .5283 m .57437 .53598 L .56356 .53092 L p F P
0 g
s
.55551 .52053 m .56309 .51685 L .57404 .52735 L p 1 0 0 r
F P
0 g
s
.56356 .53092 m .57111 .5232 L .58194 .5283 L p 0 0 1 r
F P
0 g
s
.58204 .53066 m .57142 .53166 L p .58327 .52146 L 0 1 0 r
F P
0 g
s
.58327 .52146 m .5833 .52155 L .58204 .53066 L 0 1 0 r
F
.58337 .52145 m .58383 .52172 L .5836 .52218 L 1 0 0 r
F
.57467 .54393 m .58204 .53066 L .58492 .53008 L p 0 1 0 r
F P
0 g
s
.5872 .53895 m .58513 .54103 L p .58575 .53437 L 0 0 1 r
F P
0 g
s
.58734 .54072 m .58732 .5405 L .58736 .54069 L 0 1 0 r
F
.58734 .54072 m .58724 .53891 L .58738 .54071 L 0 0 1 r
F
.58513 .54103 m .5872 .53895 L p .58734 .54072 L F P
0 g
s
.58732 .5405 m .58722 .53891 L .58736 .54069 L 0 1 0 r
F
.5872 .53895 m .58722 .53891 L p .58732 .5405 L F P
0 g
s
.5872 .53895 m .58724 .53891 L p .58734 .54072 L 0 0 1 r
F P
0 g
s
.58706 .53922 m .5872 .53895 L p .58732 .5405 L 0 1 0 r
F P
0 g
s
.58521 .54284 m .57467 .54393 L p .58575 .53437 L 0 1 0 r
F P
0 g
s
.5872 .53895 m .58521 .54284 L p .58575 .53437 L 0 1 0 r
F P
0 g
s
.59296 .5386 m .58724 .53891 L p .58636 .53467 L 1 0 0 r
F P
0 g
s
.58636 .53467 m .58724 .53891 L .58717 .5387 L 1 0 0 r
F
.59296 .5386 m .60419 .55286 L p .58738 .54071 L F P
0 g
s
.58724 .53891 m .59296 .5386 L p .58738 .54071 L 1 0 0 r
F P
0 g
s
.58521 .54284 m .58706 .53922 L p .58732 .5405 L 0 1 0 r
F P
0 g
s
.58521 .54284 m .58732 .5405 L .58734 .54072 L 0 1 0 r
F
.58782 .54229 m .58745 .54212 L p .58734 .54072 L 0 0 1 r
F P
0 g
s
.58784 .54229 m .58782 .54229 L p .58736 .54069 L 0 1 0 r
F P
0 g
s
.58734 .54072 m .58736 .54069 L .58782 .54229 L 0 1 0 r
F
.58734 .54072 m .58738 .54071 L .58782 .54229 L 0 0 1 r
F
.58782 .54229 m .58521 .54284 L p .58734 .54072 L 0 1 0 r
F P
0 g
s
.58738 .54071 m .58754 .54083 L .58782 .54218 L 1 0 0 r
F
.58785 .54229 m .60419 .55286 L .58785 .5423 L F
.58754 .54083 m .60419 .55286 L .58784 .54229 L F
.58784 .54229 m .59613 .55199 L p .58875 .5475 L F P
0 g
s
.47603 .55648 m .48321 .54893 L .49411 .55392 L p 0 0 1 r
F P
0 g
s
.48321 .54893 m .47603 .55648 L .4651 .5515 L p 0 0 1 r
F P
0 g
s
.56309 .51685 m .55551 .52053 L .54466 .51209 L p 1 0 0 r
F P
0 g
s
.52306 .55633 m .5304 .54878 L .5412 .55377 L p 0 0 1 r
F P
0 g
s
.5304 .54878 m .52306 .55633 L .51223 .55135 L p 0 0 1 r
F P
0 g
s
.57759 .54863 m .5701 .55618 L .55938 .5512 L p 0 0 1 r
F P
0 g
s
.61715 .55603 m .62479 .54848 L .63539 .55347 L p 0 0 1 r
F P
0 g
s
.62479 .54848 m .61715 .55603 L .60652 .55105 L p 0 0 1 r
F P
0 g
s
.49062 .59253 m .49786 .58696 L .50875 .59298 L p 0 1 0 r
F P
0 g
s
.49786 .58696 m .49062 .59253 L .47972 .58556 L p 0 1 0 r
F P
0 g
s
.6642 .55588 m .672 .54833 L .6825 .55332 L p 0 0 1 r
F P
0 g
s
.672 .54833 m .6642 .55588 L .65368 .5509 L p 0 0 1 r
F P
0 g
s
.66833 .71349 m .67829 .73452 L .6783 .73556 L p 1 0 0 r
F P
0 g
s
.67754 .72968 m .67829 .73452 L .66833 .71349 L p 1 0 0 r
F P
0 g
s
.66833 .71349 m .67746 .72368 L p .67754 .72968 L 1 0 0 r
F P
0 g
s
.71126 .55574 m .71921 .54818 L .72961 .55317 L p 0 0 1 r
F P
0 g
s
.71921 .54818 m .71126 .55574 L .70084 .55076 L p 0 0 1 r
F P
0 g
s
.75832 .55559 m .76643 .54803 L .77673 .55303 L p 0 0 1 r
F P
0 g
s
.76643 .54803 m .75832 .55559 L .748 .55061 L p 0 0 1 r
F P
0 g
s
.81366 .54788 m .80539 .55544 L .79517 .55046 L p 0 0 1 r
F P
0 g
s
.34936 .59569 m .35623 .58639 L .36753 .58886 L p 1 0 0 r
F P
0 g
s
.37449 .57876 m .36753 .58886 L .35623 .58639 L p 1 0 0 r
F P
0 g
s
.61698 .4907 m .60993 .50864 L .59974 .51303 L p 0 1 0 r
F P
0 g
s
.59974 .51303 m .60691 .49623 L .61698 .4907 L p 0 1 0 r
F P
0 g
s
.0706 .55525 m .07645 .54769 L .08824 .55269 L p 0 0 1 r
F P
0 g
s
.07645 .54769 m .0706 .55525 L .05878 .55027 L p 0 0 1 r
F P
0 g
s
.2803 .50915 m .28705 .49905 L .29847 .50299 L p 0 1 0 r
F P
0 g
s
.29847 .50299 m .30514 .49446 L .31641 .49982 L p 0 1 0 r
F P
0 g
s
.30514 .49446 m .29847 .50299 L .28705 .49905 L p 0 1 0 r
F P
0 g
s
.11763 .5551 m .12364 .54754 L .13532 .55254 L p 0 0 1 r
F P
0 g
s
.12364 .54754 m .11763 .5551 L .10592 .55012 L p 0 0 1 r
F P
0 g
s
.42896 .55824 m .43592 .5541 L .4469 .56238 L p 0 1 0 r
F P
0 g
s
.5196 .59838 m .52693 .59123 L .53773 .59531 L p 0 1 0 r
F P
0 g
s
.52693 .59123 m .5196 .59838 L .50875 .59298 L p 0 1 0 r
F P
0 g
s
.16467 .55495 m .17083 .54739 L .18242 .55239 L p 0 0 1 r
F P
0 g
s
.17083 .54739 m .16467 .55495 L .15306 .54997 L p 0 0 1 r
F P
0 g
s
.21564 .64626 m .20772 .66809 L .19424 .67998 L p 0 1 0 r
F P
0 g
s
.19424 .67998 m .20245 .65622 L .21564 .64626 L p 0 1 0 r
F P
0 g
s
.21803 .54725 m .21171 .55481 L .2002 .54982 L p 0 0 1 r
F P
0 g
s
.54466 .51209 m .55217 .50744 L .56309 .51685 L p 1 0 0 r
F P
0 g
s
.55217 .50744 m .54466 .51209 L .53382 .50458 L p 1 0 0 r
F P
0 g
s
.25876 .55466 m .26524 .5471 L .27662 .55209 L p 0 0 1 r
F P
0 g
s
.56317 .57916 m .57053 .56808 L .58105 .56787 L p 0 1 0 r
F P
0 g
s
.58834 .55482 m .58105 .56787 L .57053 .56808 L p 0 1 0 r
F P
0 g
s
.35639 .51344 m .36305 .50818 L .3741 .51621 L p 0 1 0 r
F P
0 g
s
.36305 .50818 m .35639 .51344 L .34533 .50609 L p 0 1 0 r
F P
0 g
s
.30582 .55451 m .31245 .54695 L .32373 .55194 L p 0 0 1 r
F P
0 g
s
.31245 .54695 m .30582 .55451 L .29452 .54952 L p 0 0 1 r
F P
0 g
s
.35289 .55436 m .35967 .5468 L .37085 .5518 L p 0 0 1 r
F P
0 g
s
.35967 .5468 m .35289 .55436 L .34168 .54937 L p 0 0 1 r
F P
0 g
s
.26179 .51885 m .26868 .50691 L .2803 .50915 L p 0 1 0 r
F P
0 g
s
.28705 .49905 m .2803 .50915 L .26868 .50691 L p 0 1 0 r
F P
0 g
s
.33129 .60055 m .33805 .59233 L .34936 .59569 L p 1 0 0 r
F P
0 g
s
.33805 .59233 m .33129 .60055 L .32001 .59601 L p 1 0 0 r
F P
0 g
s
.44703 .55406 m .45412 .5465 L .4651 .5515 L p 0 0 1 r
F P
0 g
s
.45412 .5465 m .44703 .55406 L .43603 .54908 L p 0 0 1 r
F P
0 g
s
.49411 .55392 m .50136 .54635 L .51223 .55135 L p 0 0 1 r
F P
0 g
s
.50136 .54635 m .49411 .55392 L .48321 .54893 L p 0 0 1 r
F P
0 g
s
.37449 .57876 m .38148 .5683 L .39274 .56995 L p 1 0 0 r
F P
0 g
s
.39978 .55908 m .39274 .56995 L .38148 .5683 L p 1 0 0 r
F P
0 g
s
.35623 .58639 m .34936 .59569 L .33805 .59233 L p 1 0 0 r
F P
0 g
s
.5412 .55377 m .5486 .5462 L .55938 .5512 L p 0 0 1 r
F P
0 g
s
.5486 .5462 m .5412 .55377 L .5304 .54878 L p 0 0 1 r
F P
0 g
s
.53773 .59531 m .54509 .58679 L .5558 .5893 L p 0 1 0 r
F P
0 g
s
.56317 .57916 m .5558 .5893 L .54509 .58679 L p 0 1 0 r
F P
0 g
s
.24058 .56085 m .23328 .57715 L .22072 .58208 L p 0 1 0 r
F P
0 g
s
.22072 .58208 m .22821 .56434 L .24058 .56085 L p 0 1 0 r
F P
0 g
s
.63539 .55347 m .64311 .5459 L .65368 .5509 L p 0 0 1 r
F P
0 g
s
.64311 .5459 m .63539 .55347 L .62479 .54848 L p 0 0 1 r
F P
0 g
s
.64469 .63327 m .6361 .62756 L .62471 .60958 L p 1 0 0 r
F P
0 g
s
.62471 .60958 m .63309 .61366 L .64469 .63327 L p 1 0 0 r
F P
0 g
s
.6825 .55332 m .69037 .54575 L .70084 .55076 L p 0 0 1 r
F P
0 g
s
.69037 .54575 m .6825 .55332 L .672 .54833 L p 0 0 1 r
F P
0 g
s
.31641 .49982 m .32304 .49261 L .33421 .49912 L p 0 1 0 r
F P
0 g
s
.32304 .49261 m .31641 .49982 L .30514 .49446 L p 0 1 0 r
F P
0 g
s
.72961 .55317 m .73763 .5456 L .748 .55061 L p 0 0 1 r
F P
0 g
s
.73763 .5456 m .72961 .55317 L .71921 .54818 L p 0 0 1 r
F P
0 g
s
.77673 .55303 m .78491 .54545 L .79517 .55046 L p 0 0 1 r
F P
0 g
s
.78491 .54545 m .77673 .55303 L .76643 .54803 L p 0 0 1 r
F P
0 g
s
.54509 .58679 m .53773 .59531 L .52693 .59123 L p 0 1 0 r
F P
0 g
s
.47972 .58556 m .48693 .58039 L .49786 .58696 L p 0 1 0 r
F P
0 g
s
.48693 .58039 m .47972 .58556 L .4688 .57817 L p 0 1 0 r
F P
0 g
s
.46859 .51049 m .47577 .50066 L .4867 .50413 L p 1 0 0 r
F P
0 g
s
.4867 .50413 m .49393 .49521 L .50481 .49977 L p 1 0 0 r
F P
0 g
s
.49393 .49521 m .4867 .50413 L .47577 .50066 L p 1 0 0 r
F P
0 g
s
.3022 .59692 m .30873 .59076 L .32001 .59601 L p 1 0 0 r
F P
0 g
s
.30873 .59076 m .3022 .59692 L .29104 .59011 L p 1 0 0 r
F P
0 g
s
.04116 .55284 m .04692 .54526 L .05878 .55027 L p 0 0 1 r
F P
0 g
s
.23328 .57715 m .22583 .59475 L .21306 .60123 L p 0 1 0 r
F P
0 g
s
.21306 .60123 m .22072 .58208 L .23328 .57715 L p 0 1 0 r
F P
0 g
s
.08824 .55269 m .09416 .54511 L .10592 .55012 L p 0 0 1 r
F P
0 g
s
.09416 .54511 m .08824 .55269 L .07645 .54769 L p 0 0 1 r
F P
0 g
s
.13532 .55254 m .1414 .54496 L .15306 .54997 L p 0 0 1 r
F P
0 g
s
.1414 .54496 m .13532 .55254 L .12364 .54754 L p 0 0 1 r
F P
0 g
s
.63749 .35701 m .63814 .35906 L .63527 .36262 L p 0 1 0 r
F P
0 g
s
.57053 .56808 m .57788 .556 L .58834 .55482 L p 0 1 0 r
F P
0 g
s
.18242 .55239 m .18865 .54481 L .2002 .54982 L p 0 0 1 r
F P
0 g
s
.18865 .54481 m .18242 .55239 L .17083 .54739 L p 0 0 1 r
F P
0 g
s
.62784 .43756 m .62098 .45855 L .61097 .46521 L p 0 1 0 r
F P
0 g
s
.61097 .46521 m .61799 .44543 L .62784 .43756 L p 0 1 0 r
F P
0 g
s
.53382 .50458 m .54126 .49902 L .55217 .50744 L p 1 0 0 r
F P
0 g
s
.54126 .49902 m .53382 .50458 L .52297 .49791 L p 1 0 0 r
F P
0 g
s
.27662 .55209 m .28316 .54452 L .29452 .54952 L p 0 0 1 r
F P
0 g
s
.28316 .54452 m .27662 .55209 L .26524 .5471 L p 0 0 1 r
F P
0 g
s
.61861 .58225 m .61041 .57985 L .59927 .56535 L p 1 0 0 r
F P
0 g
s
.59927 .56535 m .60731 .56636 L .61861 .58225 L p 1 0 0 r
F P
0 g
s
.50481 .49977 m .5121 .492 L .52297 .49791 L p 1 0 0 r
F P
0 g
s
.5121 .492 m .50481 .49977 L .49393 .49521 L p 1 0 0 r
F P
0 g
s
.32373 .55194 m .33043 .54437 L .34168 .54937 L p 0 0 1 r
F P
0 g
s
.33043 .54437 m .32373 .55194 L .31245 .54695 L p 0 0 1 r
F P
0 g
s
.34533 .50609 m .35197 .50042 L .36305 .50818 L p 0 1 0 r
F P
0 g
s
.35197 .50042 m .34533 .50609 L .33421 .49912 L p 0 1 0 r
F P
0 g
s
.37085 .5518 m .3777 .54422 L .38885 .54923 L p 0 0 1 r
F P
0 g
s
.3777 .54422 m .37085 .5518 L .35967 .5468 L p 0 0 1 r
F P
0 g
s
.45045 .5184 m .4576 .50788 L .46859 .51049 L p 1 0 0 r
F P
0 g
s
.47577 .50066 m .46859 .51049 L .4576 .50788 L p 1 0 0 r
F P
0 g
s
.4651 .5515 m .47226 .54392 L .48321 .54893 L p 0 0 1 r
F P
0 g
s
.47226 .54392 m .4651 .5515 L .45412 .5465 L p 0 0 1 r
F P
0 g
s
.51223 .55135 m .51955 .54377 L .5304 .54878 L p 0 0 1 r
F P
0 g
s
.51955 .54377 m .51223 .55135 L .50136 .54635 L p 0 0 1 r
F P
0 g
s
.55938 .5512 m .56685 .54362 L .57759 .54863 L p 0 0 1 r
F P
0 g
s
.56685 .54362 m .55938 .5512 L .5486 .5462 L p 0 0 1 r
F P
0 g
s
.60652 .55105 m .61415 .54347 L .62479 .54848 L p 0 0 1 r
F P
0 g
s
.65368 .5509 m .66146 .54332 L .672 .54833 L p 0 0 1 r
F P
0 g
s
.66146 .54332 m .65368 .5509 L .64311 .5459 L p 0 0 1 r
F P
0 g
s
.70084 .55076 m .70877 .54317 L .71921 .54818 L p 0 0 1 r
F P
0 g
s
.70877 .54317 m .70084 .55076 L .69037 .54575 L p 0 0 1 r
F P
0 g
s
.748 .55061 m .7561 .54302 L .76643 .54803 L p 0 0 1 r
F P
0 g
s
.7561 .54302 m .748 .55061 L .73763 .5456 L p 0 0 1 r
F P
0 g
s
.63527 .36262 m .63711 .35506 L .63749 .35701 L p 0 1 0 r
F P
0 g
s
.22583 .59475 m .21823 .61372 L .20521 .62187 L p 0 1 0 r
F P
0 g
s
.20521 .62187 m .21306 .60123 L .22583 .59475 L p 0 1 0 r
F P
0 g
s
.50875 .59298 m .51607 .58641 L .52693 .59123 L p 0 1 0 r
F P
0 g
s
.51607 .58641 m .50875 .59298 L .49786 .58696 L p 0 1 0 r
F P
0 g
s
.79517 .55046 m .80342 .54287 L .81366 .54788 L p 0 0 1 r
F P
0 g
s
.80342 .54287 m .79517 .55046 L .78491 .54545 L p 0 0 1 r
F P
0 g
s
.35623 .58639 m .36317 .57661 L .37449 .57876 L p 1 0 0 r
F P
0 g
s
.38148 .5683 m .37449 .57876 L .36317 .57661 L p 1 0 0 r
F P
0 g
s
.4688 .57817 m .47597 .57332 L .48693 .58039 L p 0 1 0 r
F P
0 g
s
.47597 .57332 m .4688 .57817 L .45786 .57042 L p 0 1 0 r
F P
0 g
s
.05878 .55027 m .06461 .54268 L .07645 .54769 L p 0 0 1 r
F P
0 g
s
.06461 .54268 m .05878 .55027 L .04692 .54526 L p 0 0 1 r
F P
0 g
s
.10592 .55012 m .1119 .54253 L .12364 .54754 L p 0 0 1 r
F P
0 g
s
.1119 .54253 m .10592 .55012 L .09416 .54511 L p 0 0 1 r
F P
0 g
s
.15306 .54997 m .1592 .54238 L .17083 .54739 L p 0 0 1 r
F P
0 g
s
.1592 .54238 m .15306 .54997 L .1414 .54496 L p 0 0 1 r
F P
0 g
s
.26868 .50691 m .26179 .51885 L .24988 .5186 L p 0 1 0 r
F P
0 g
s
.2002 .54982 m .2065 .54223 L .21803 .54725 L p 0 0 1 r
F P
0 g
s
.2065 .54223 m .2002 .54982 L .18865 .54481 L p 0 0 1 r
F P
0 g
s
.29104 .59011 m .29747 .58474 L .30873 .59076 L p 1 0 0 r
F P
0 g
s
.29747 .58474 m .29104 .59011 L .27991 .5824 L p 1 0 0 r
F P
0 g
s
.29452 .54952 m .30112 .54193 L .31245 .54695 L p 0 0 1 r
F P
0 g
s
.30112 .54193 m .29452 .54952 L .28316 .54452 L p 0 0 1 r
F P
0 g
s
.38148 .5683 m .38851 .55756 L .39978 .55908 L p 1 0 0 r
F P
0 g
s
.40685 .54805 m .39978 .55908 L .38851 .55756 L p 1 0 0 r
F P
0 g
s
.34168 .54937 m .34844 .54178 L .35967 .5468 L p 0 0 1 r
F P
0 g
s
.34844 .54178 m .34168 .54937 L .33043 .54437 L p 0 0 1 r
F P
0 g
s
.39577 .54163 m .38885 .54923 L .3777 .54422 L p 0 0 1 r
F P
0 g
s
.4576 .50788 m .45045 .5184 L .43937 .5164 L p 1 0 0 r
F P
0 g
s
.43603 .54908 m .4431 .54148 L .45412 .5465 L p 0 0 1 r
F P
0 g
s
.26868 .50691 m .2755 .49589 L .28705 .49905 L p 0 1 0 r
F P
0 g
s
.28705 .49905 m .29376 .48974 L .30514 .49446 L p 0 1 0 r
F P
0 g
s
.29376 .48974 m .28705 .49905 L .2755 .49589 L p 0 1 0 r
F P
0 g
s
.48321 .54893 m .49044 .54133 L .50136 .54635 L p 0 0 1 r
F P
0 g
s
.49044 .54133 m .48321 .54893 L .47226 .54392 L p 0 0 1 r
F P
0 g
s
.20772 .66809 m .19958 .6916 L .18576 .70557 L p 0 1 0 r
F P
0 g
s
.18576 .70557 m .19424 .67998 L .20772 .66809 L p 0 1 0 r
F P
0 g
s
.63557 .35026 m .63711 .35506 L p .62565 .37296 L 0 1 0 r
F P
0 g
s
.63711 .35506 m .63527 .36262 L .62565 .37296 L p 0 1 0 r
F P
0 g
s
.54509 .58679 m .55248 .57746 L .56317 .57916 L p 0 1 0 r
F P
0 g
s
.57053 .56808 m .56317 .57916 L .55248 .57746 L p 0 1 0 r
F P
0 g
s
.5304 .54878 m .53778 .54118 L .5486 .5462 L p 0 0 1 r
F P
0 g
s
.53778 .54118 m .5304 .54878 L .51955 .54377 L p 0 0 1 r
F P
0 g
s
.32001 .59601 m .32672 .58838 L .33805 .59233 L p 1 0 0 r
F P
0 g
s
.32672 .58838 m .32001 .59601 L .30873 .59076 L p 1 0 0 r
F P
0 g
s
.52297 .49791 m .53036 .49151 L .54126 .49902 L p 1 0 0 r
F P
0 g
s
.53036 .49151 m .52297 .49791 L .5121 .492 L p 1 0 0 r
F P
0 g
s
.33421 .49912 m .34085 .49299 L .35197 .50042 L p 0 1 0 r
F P
0 g
s
.34085 .49299 m .33421 .49912 L .32304 .49261 L p 0 1 0 r
F P
0 g
s
.62479 .54848 m .63249 .54088 L .64311 .5459 L p 0 0 1 r
F P
0 g
s
.63249 .54088 m .62479 .54848 L .61415 .54347 L p 0 0 1 r
F P
0 g
s
.30514 .49446 m .31179 .4866 L .32304 .49261 L p 0 1 0 r
F P
0 g
s
.31179 .4866 m .30514 .49446 L .29376 .48974 L p 0 1 0 r
F P
0 g
s
.672 .54833 m .67985 .54073 L .69037 .54575 L p 0 0 1 r
F P
0 g
s
.67985 .54073 m .672 .54833 L .66146 .54332 L p 0 0 1 r
F P
0 g
s
.71921 .54818 m .72722 .54058 L .73763 .5456 L p 0 0 1 r
F P
0 g
s
.72722 .54058 m .71921 .54818 L .70877 .54317 L p 0 0 1 r
F P
0 g
s
.76643 .54803 m .7746 .54043 L .78491 .54545 L p 0 0 1 r
F P
0 g
s
.7746 .54043 m .76643 .54803 L .7561 .54302 L p 0 0 1 r
F P
0 g
s
.45786 .57042 m .46498 .56584 L .47597 .57332 L p 0 1 0 r
F P
0 g
s
.46498 .56584 m .45786 .57042 L .4469 .56238 L p 0 1 0 r
F P
0 g
s
.33805 .59233 m .34489 .58348 L .35623 .58639 L p 1 0 0 r
F P
0 g
s
.36317 .57661 m .35623 .58639 L .34489 .58348 L p 1 0 0 r
F P
0 g
s
.82198 .54028 m .81366 .54788 L .80342 .54287 L p 0 0 1 r
F P
0 g
s
.63006 .59981 m .62167 .59591 L .61041 .57985 L p 1 0 0 r
F P
0 g
s
.61041 .57985 m .61861 .58225 L .63006 .59981 L p 1 0 0 r
F P
0 g
s
.07645 .54769 m .08234 .54009 L .09416 .54511 L p 0 0 1 r
F P
0 g
s
.08234 .54009 m .07645 .54769 L .06461 .54268 L p 0 0 1 r
F P
0 g
s
.63163 .40138 m .62488 .42417 L .61496 .43201 L p 0 1 0 r
F P
0 g
s
.61496 .43201 m .62188 .41046 L .63163 .40138 L p 0 1 0 r
F P
0 g
s
.12364 .54754 m .12969 .53994 L .1414 .54496 L p 0 0 1 r
F P
0 g
s
.12969 .53994 m .12364 .54754 L .1119 .54253 L p 0 0 1 r
F P
0 g
s
.27991 .5824 m .28623 .57789 L .29747 .58474 L p 1 0 0 r
F P
0 g
s
.28623 .57789 m .27991 .5824 L .26885 .57374 L p 1 0 0 r
F P
0 g
s
.17083 .54739 m .17704 .53979 L .18865 .54481 L p 0 0 1 r
F P
0 g
s
.17704 .53979 m .17083 .54739 L .1592 .54238 L p 0 0 1 r
F P
0 g
s
.67156 .69357 m .66244 .68395 L .65065 .66167 L p 1 0 0 r
F P
0 g
s
.65065 .66167 m .65948 .66937 L .67156 .69357 L p 1 0 0 r
F P
0 g
s
.34489 .58348 m .33805 .59233 L .32672 .58838 L p 1 0 0 r
F P
0 g
s
.22439 .53964 m .21803 .54725 L .2065 .54223 L p 0 0 1 r
F P
0 g
s
.52693 .59123 m .5343 .58341 L .54509 .58679 L p 0 1 0 r
F P
0 g
s
.5343 .58341 m .52693 .59123 L .51607 .58641 L p 0 1 0 r
F P
0 g
s
.21823 .61372 m .21044 .63418 L .19715 .64411 L p 0 1 0 r
F P
0 g
s
.19715 .64411 m .20521 .62187 L .21823 .61372 L p 0 1 0 r
F P
0 g
s
.26524 .5471 m .27175 .53949 L .28316 .54452 L p 0 0 1 r
F P
0 g
s
.27175 .53949 m .26524 .5471 L .25381 .54208 L p 0 0 1 r
F P
0 g
s
.31245 .54695 m .31912 .53934 L .33043 .54437 L p 0 0 1 r
F P
0 g
s
.31912 .53934 m .31245 .54695 L .30112 .54193 L p 0 0 1 r
F P
0 g
s
.35967 .5468 m .3665 .53919 L .3777 .54422 L p 0 0 1 r
F P
0 g
s
.3665 .53919 m .35967 .5468 L .34844 .54178 L p 0 0 1 r
F P
0 g
s
.62098 .45855 m .61399 .47809 L .60385 .48356 L p 0 1 0 r
F P
0 g
s
.60385 .48356 m .61097 .46521 L .62098 .45855 L p 0 1 0 r
F P
0 g
s
.49786 .58696 m .50515 .58091 L .51607 .58641 L p 0 1 0 r
F P
0 g
s
.50515 .58091 m .49786 .58696 L .48693 .58039 L p 0 1 0 r
F P
0 g
s
.47577 .50066 m .48299 .4912 L .49393 .49521 L p 1 0 0 r
F P
0 g
s
.49393 .49521 m .50119 .48678 L .5121 .492 L p 1 0 0 r
F P
0 g
s
.50119 .48678 m .49393 .49521 L .48299 .4912 L p 1 0 0 r
F P
0 g
s
.45412 .5465 m .46126 .53889 L .47226 .54392 L p 0 0 1 r
F P
0 g
s
.46126 .53889 m .45412 .5465 L .4431 .54148 L p 0 0 1 r
F P
0 g
s
.55248 .57746 m .54509 .58679 L .5343 .58341 L p 0 1 0 r
F P
0 g
s
.24988 .5186 m .25688 .50558 L .26868 .50691 L p 0 1 0 r
F P
0 g
s
.2755 .49589 m .26868 .50691 L .25688 .50558 L p 0 1 0 r
F P
0 g
s
.50136 .54635 m .50866 .53873 L .51955 .54377 L p 0 0 1 r
F P
0 g
s
.50866 .53873 m .50136 .54635 L .49044 .54133 L p 0 0 1 r
F P
0 g
s
.4576 .50788 m .46478 .49763 L .47577 .50066 L p 1 0 0 r
F P
0 g
s
.48299 .4912 m .47577 .50066 L .46478 .49763 L p 1 0 0 r
F P
0 g
s
.5486 .5462 m .55606 .53858 L .56685 .54362 L p 0 0 1 r
F P
0 g
s
.55606 .53858 m .5486 .5462 L .53778 .54118 L p 0 0 1 r
F P
0 g
s
.67649 .71777 m .67746 .72368 L p .66539 .69865 L 1 0 0 r
F P
0 g
s
.67746 .72368 m .67746 .72368 L .66539 .69865 L p 1 0 0 r
F P
0 g
s
.66539 .69865 m .67451 .70854 L p .67649 .71777 L 1 0 0 r
F P
0 g
s
.2639 .56149 m .25787 .56409 L .24698 .5534 L p 1 0 0 r
F P
0 g
s
.24698 .5534 m .25285 .55183 L .2639 .56149 L p 1 0 0 r
F P
0 g
s
.4469 .56238 m .45398 .558 L .46498 .56584 L p 0 1 0 r
F P
0 g
s
.45398 .558 m .4469 .56238 L .43592 .5541 L p 0 1 0 r
F P
0 g
s
.26885 .57374 m .27503 .57016 L .28623 .57789 L p 1 0 0 r
F P
0 g
s
.27503 .57016 m .26885 .57374 L .25787 .56409 L p 1 0 0 r
F P
0 g
s
.65652 .6549 m .64768 .64743 L .6361 .62756 L p 1 0 0 r
F P
0 g
s
.6361 .62756 m .64469 .63327 L .65652 .6549 L p 1 0 0 r
F P
0 g
s
.64311 .5459 m .65087 .53828 L .66146 .54332 L p 0 0 1 r
F P
0 g
s
.65087 .53828 m .64311 .5459 L .63249 .54088 L p 0 0 1 r
F P
0 g
s
.69037 .54575 m .69829 .53813 L .70877 .54317 L p 0 0 1 r
F P
0 g
s
.69829 .53813 m .69037 .54575 L .67985 .54073 L p 0 0 1 r
F P
0 g
s
.36317 .57661 m .37015 .56641 L .38148 .5683 L p 1 0 0 r
F P
0 g
s
.38851 .55756 m .38148 .5683 L .37015 .56641 L p 1 0 0 r
F P
0 g
s
.73763 .5456 m .74571 .53798 L .7561 .54302 L p 0 0 1 r
F P
0 g
s
.74571 .53798 m .73763 .5456 L .72722 .54058 L p 0 0 1 r
F P
0 g
s
.25787 .56409 m .2639 .56149 L .27503 .57016 L p 1 0 0 r
F P
0 g
s
.78491 .54545 m .79314 .53783 L .80342 .54287 L p 0 0 1 r
F P
0 g
s
.79314 .53783 m .78491 .54545 L .7746 .54043 L p 0 0 1 r
F P
0 g
s
.63527 .36262 m .62866 .38734 L .61884 .39641 L p 0 1 0 r
F P
0 g
s
.61884 .39641 m .62565 .37296 L .63527 .36262 L p 0 1 0 r
F P
0 g
s
.38851 .55756 m .39558 .54658 L .40685 .54805 L p 1 0 0 r
F P
0 g
s
.04692 .54526 m .05272 .53764 L .06461 .54268 L p 0 0 1 r
F P
0 g
s
.09416 .54511 m .10011 .53749 L .1119 .54253 L p 0 0 1 r
F P
0 g
s
.10011 .53749 m .09416 .54511 L .08234 .54009 L p 0 0 1 r
F P
0 g
s
.32304 .49261 m .32967 .48594 L .34085 .49299 L p 0 1 0 r
F P
0 g
s
.32967 .48594 m .32304 .49261 L .31179 .4866 L p 0 1 0 r
F P
0 g
s
.1414 .54496 m .14751 .53734 L .1592 .54238 L p 0 0 1 r
F P
0 g
s
.14751 .53734 m .1414 .54496 L .12969 .53994 L p 0 0 1 r
F P
0 g
s
.57077 .51411 m .56309 .51685 L .55217 .50744 L p 1 0 0 r
F P
0 g
s
.18865 .54481 m .19492 .53719 L .2065 .54223 L p 0 0 1 r
F P
0 g
s
.19492 .53719 m .18865 .54481 L .17704 .53979 L p 0 0 1 r
F P
0 g
s
.55248 .57746 m .55988 .56726 L .57053 .56808 L p 0 1 0 r
F P
0 g
s
.57788 .556 m .57053 .56808 L .55988 .56726 L p 0 1 0 r
F P
0 g
s
.36976 .50324 m .36305 .50818 L .35197 .50042 L p 0 1 0 r
F P
0 g
s
.28316 .54452 m .28974 .53689 L .30112 .54193 L p 0 0 1 r
F P
0 g
s
.28974 .53689 m .28316 .54452 L .27175 .53949 L p 0 0 1 r
F P
0 g
s
.5121 .492 m .51945 .48483 L .53036 .49151 L p 1 0 0 r
F P
0 g
s
.51945 .48483 m .5121 .492 L .50119 .48678 L p 1 0 0 r
F P
0 g
s
.63229 .34786 m .63457 .34504 L .63557 .35026 L p 0 1 0 r
F P
0 g
s
.62565 .37296 m .63229 .34786 L p .63557 .35026 L 0 1 0 r
F P
0 g
s
.33043 .54437 m .33716 .53674 L .34844 .54178 L p 0 0 1 r
F P
0 g
s
.33716 .53674 m .33043 .54437 L .31912 .53934 L p 0 0 1 r
F P
0 g
s
.43937 .5164 m .44653 .50558 L .4576 .50788 L p 1 0 0 r
F P
0 g
s
.46478 .49763 m .4576 .50788 L .44653 .50558 L p 1 0 0 r
F P
0 g
s
.3777 .54422 m .38459 .53659 L .39577 .54163 L p 0 0 1 r
F P
0 g
s
.38459 .53659 m .3777 .54422 L .3665 .53919 L p 0 0 1 r
F P
0 g
s
.43592 .5541 m .44295 .54987 L .45398 .558 L p 0 1 0 r
F P
0 g
s
.44295 .54987 m .43592 .5541 L .42494 .54567 L p 0 1 0 r
F P
0 g
s
.55217 .50744 m .55976 .50365 L .57077 .51411 L p 1 0 0 r
F P
0 g
s
.55976 .50365 m .55217 .50744 L .54126 .49902 L p 1 0 0 r
F P
0 g
s
.30873 .59076 m .31537 .58379 L .32672 .58838 L p 1 0 0 r
F P
0 g
s
.31537 .58379 m .30873 .59076 L .29747 .58474 L p 1 0 0 r
F P
0 g
s
.47226 .54392 m .47947 .53629 L .49044 .54133 L p 0 0 1 r
F P
0 g
s
.47947 .53629 m .47226 .54392 L .46126 .53889 L p 0 0 1 r
F P
0 g
s
.51955 .54377 m .52692 .53614 L .53778 .54118 L p 0 0 1 r
F P
0 g
s
.52692 .53614 m .51955 .54377 L .50866 .53873 L p 0 0 1 r
F P
0 g
s
.57437 .53598 m .56685 .54362 L .55606 .53858 L p 0 0 1 r
F P
0 g
s
.61415 .54347 m .62183 .53583 L .63249 .54088 L p 0 0 1 r
F P
0 g
s
.62183 .53583 m .61415 .54347 L .60346 .53843 L p 0 0 1 r
F P
0 g
s
.66146 .54332 m .66929 .53568 L .67985 .54073 L p 0 0 1 r
F P
0 g
s
.66929 .53568 m .66146 .54332 L .65087 .53828 L p 0 0 1 r
F P
0 g
s
.70877 .54317 m .71677 .53553 L .72722 .54058 L p 0 0 1 r
F P
0 g
s
.71677 .53553 m .70877 .54317 L .69829 .53813 L p 0 0 1 r
F P
0 g
s
.48693 .58039 m .49419 .57479 L .50515 .58091 L p 0 1 0 r
F P
0 g
s
.49419 .57479 m .48693 .58039 L .47597 .57332 L p 0 1 0 r
F P
0 g
s
.2755 .49589 m .28228 .48572 L .29376 .48974 L p 0 1 0 r
F P
0 g
s
.29376 .48974 m .30045 .48116 L .31179 .4866 L p 0 1 0 r
F P
0 g
s
.30045 .48116 m .29376 .48974 L .28228 .48572 L p 0 1 0 r
F P
0 g
s
.7561 .54302 m .76424 .53538 L .7746 .54043 L p 0 0 1 r
F P
0 g
s
.76424 .53538 m .7561 .54302 L .74571 .53798 L p 0 0 1 r
F P
0 g
s
.80342 .54287 m .81173 .53523 L .82198 .54028 L p 0 0 1 r
F P
0 g
s
.81173 .53523 m .80342 .54287 L .79314 .53783 L p 0 0 1 r
F P
0 g
s
.06461 .54268 m .07048 .53504 L .08234 .54009 L p 0 0 1 r
F P
0 g
s
.07048 .53504 m .06461 .54268 L .05272 .53764 L p 0 0 1 r
F P
0 g
s
.34489 .58348 m .35179 .57408 L .36317 .57661 L p 1 0 0 r
F P
0 g
s
.37015 .56641 m .36317 .57661 L .35179 .57408 L p 1 0 0 r
F P
0 g
s
.1119 .54253 m .11793 .53489 L .12969 .53994 L p 0 0 1 r
F P
0 g
s
.11793 .53489 m .1119 .54253 L .10011 .53749 L p 0 0 1 r
F P
0 g
s
.42494 .54567 m .43191 .54151 L .44295 .54987 L p 0 1 0 r
F P
0 g
s
.61399 .47809 m .60691 .49623 L .59664 .50054 L p 0 1 0 r
F P
0 g
s
.59664 .50054 m .60385 .48356 L .61399 .47809 L p 0 1 0 r
F P
0 g
s
.54126 .49902 m .54879 .49427 L .55976 .50365 L p 1 0 0 r
F P
0 g
s
.54879 .49427 m .54126 .49902 L .53036 .49151 L p 1 0 0 r
F P
0 g
s
.1592 .54238 m .16538 .53474 L .17704 .53979 L p 0 0 1 r
F P
0 g
s
.16538 .53474 m .1592 .54238 L .14751 .53734 L p 0 0 1 r
F P
0 g
s
.21044 .63418 m .20245 .65622 L .18885 .66809 L p 0 1 0 r
F P
0 g
s
.18885 .66809 m .19715 .64411 L .21044 .63418 L p 0 1 0 r
F P
0 g
s
.21284 .53459 m .2065 .54223 L .19492 .53719 L p 0 0 1 r
F P
0 g
s
.35197 .50042 m .35865 .49513 L .36976 .50324 L p 0 1 0 r
F P
0 g
s
.35865 .49513 m .35197 .50042 L .34085 .49299 L p 0 1 0 r
F P
0 g
s
.64169 .61919 m .63309 .61366 L .62167 .59591 L p 1 0 0 r
F P
0 g
s
.62167 .59591 m .63006 .59981 L .64169 .61919 L p 1 0 0 r
F P
0 g
s
.25688 .50558 m .2638 .49355 L .2755 .49589 L p 0 1 0 r
F P
0 g
s
.28228 .48572 m .2755 .49589 L .2638 .49355 L p 0 1 0 r
F P
0 g
s
.51607 .58641 m .52343 .57923 L .5343 .58341 L p 0 1 0 r
F P
0 g
s
.52343 .57923 m .51607 .58641 L .50515 .58091 L p 0 1 0 r
F P
0 g
s
.25381 .54208 m .2603 .53443 L .27175 .53949 L p 0 0 1 r
F P
0 g
s
.30112 .54193 m .30777 .53428 L .31912 .53934 L p 0 0 1 r
F P
0 g
s
.30777 .53428 m .30112 .54193 L .28974 .53689 L p 0 0 1 r
F P
0 g
s
.34844 .54178 m .35525 .53413 L .3665 .53919 L p 0 0 1 r
F P
0 g
s
.35525 .53413 m .34844 .54178 L .33716 .53674 L p 0 0 1 r
F P
0 g
s
.23556 .5479 m .22821 .56434 L .21556 .5692 L p 0 1 0 r
F P
0 g
s
.21556 .5692 m .2231 .55132 L .23556 .5479 L p 0 1 0 r
F P
0 g
s
.4431 .54148 m .45022 .53383 L .46126 .53889 L p 0 0 1 r
F P
0 g
s
.45022 .53383 m .4431 .54148 L .43203 .53644 L p 0 0 1 r
F P
0 g
s
.55988 .56726 m .56728 .55611 L .57788 .556 L p 0 1 0 r
F P
0 g
s
.58521 .54284 m .57788 .556 L .56728 .55611 L p 0 1 0 r
F P
0 g
s
.32672 .58838 m .3335 .58006 L .34489 .58348 L p 1 0 0 r
F P
0 g
s
.3335 .58006 m .32672 .58838 L .31537 .58379 L p 1 0 0 r
F P
0 g
s
.49044 .54133 m .49771 .53368 L .50866 .53873 L p 0 0 1 r
F P
0 g
s
.49771 .53368 m .49044 .54133 L .47947 .53629 L p 0 0 1 r
F P
0 g
s
.19958 .6916 m .1912 .71694 L p .18705 .71467 L 0 1 0 r
F P
0 g
s
.18705 .71467 m .18446 .70968 L p .19958 .6916 L 0 1 0 r
F P
0 g
s
.18446 .70968 m .18576 .70557 L .19958 .6916 L p 0 1 0 r
F P
0 g
s
.53778 .54118 m .54522 .53353 L .55606 .53858 L p 0 0 1 r
F P
0 g
s
.54522 .53353 m .53778 .54118 L .52692 .53614 L p 0 0 1 r
F P
0 g
s
.37015 .56641 m .37717 .55585 L .38851 .55756 L p 1 0 0 r
F P
0 g
s
.39558 .54658 m .38851 .55756 L .37717 .55585 L p 1 0 0 r
F P
0 g
s
.35179 .57408 m .34489 .58348 L .3335 .58006 L p 1 0 0 r
F P
0 g
s
.31179 .4866 m .31843 .47934 L .32967 .48594 L p 0 1 0 r
F P
0 g
s
.31843 .47934 m .31179 .4866 L .30045 .48116 L p 0 1 0 r
F P
0 g
s
.63249 .54088 m .64024 .53323 L .65087 .53828 L p 0 0 1 r
F P
0 g
s
.64024 .53323 m .63249 .54088 L .62183 .53583 L p 0 0 1 r
F P
0 g
s
.67985 .54073 m .68776 .53308 L .69829 .53813 L p 0 0 1 r
F P
0 g
s
.68776 .53308 m .67985 .54073 L .66929 .53568 L p 0 0 1 r
F P
0 g
s
.5343 .58341 m .5417 .57485 L .55248 .57746 L p 0 1 0 r
F P
0 g
s
.55988 .56726 m .55248 .57746 L .5417 .57485 L p 0 1 0 r
F P
0 g
s
.72722 .54058 m .73528 .53293 L .74571 .53798 L p 0 0 1 r
F P
0 g
s
.73528 .53293 m .72722 .54058 L .71677 .53553 L p 0 0 1 r
F P
0 g
s
.22821 .56434 m .22072 .58208 L .20784 .5885 L p 0 1 0 r
F P
0 g
s
.20784 .5885 m .21556 .5692 L .22821 .56434 L p 0 1 0 r
F P
0 g
s
.7746 .54043 m .78282 .53277 L .79314 .53783 L p 0 0 1 r
F P
0 g
s
.78282 .53277 m .7746 .54043 L .76424 .53538 L p 0 0 1 r
F P
0 g
s
.46478 .49763 m .47199 .48769 L .48299 .4912 L p 1 0 0 r
F P
0 g
s
.48299 .4912 m .49024 .48218 L .50119 .48678 L p 1 0 0 r
F P
0 g
s
.49024 .48218 m .48299 .4912 L .47199 .48769 L p 1 0 0 r
F P
0 g
s
.83036 .53262 m .82198 .54028 L .81173 .53523 L p 0 0 1 r
F P
0 g
s
.61553 .56861 m .60731 .56636 L .59613 .55199 L p 1 0 0 r
F P
0 g
s
.59613 .55199 m .60419 .55286 L .61553 .56861 L p 1 0 0 r
F P
0 g
s
.47597 .57332 m .4832 .56812 L .49419 .57479 L p 0 1 0 r
F P
0 g
s
.4832 .56812 m .47597 .57332 L .46498 .56584 L p 0 1 0 r
F P
0 g
s
.29747 .58474 m .30401 .57849 L .31537 .58379 L p 1 0 0 r
F P
0 g
s
.30401 .57849 m .29747 .58474 L .28623 .57789 L p 1 0 0 r
F P
0 g
s
.08234 .54009 m .08828 .53243 L .10011 .53749 L p 0 0 1 r
F P
0 g
s
.08828 .53243 m .08234 .54009 L .07048 .53504 L p 0 0 1 r
F P
0 g
s
.5417 .57485 m .5343 .58341 L .52343 .57923 L p 0 1 0 r
F P
0 g
s
.12969 .53994 m .13578 .53228 L .14751 .53734 L p 0 0 1 r
F P
0 g
s
.13578 .53228 m .12969 .53994 L .11793 .53489 L p 0 0 1 r
F P
0 g
s
.62488 .42417 m .61799 .44543 L .60791 .45205 L p 0 1 0 r
F P
0 g
s
.60791 .45205 m .61496 .43201 L .62488 .42417 L p 0 1 0 r
F P
0 g
s
.17704 .53979 m .18328 .53213 L .19492 .53719 L p 0 0 1 r
F P
0 g
s
.18328 .53213 m .17704 .53979 L .16538 .53474 L p 0 0 1 r
F P
0 g
s
.53036 .49151 m .53783 .48585 L .54879 .49427 L p 1 0 0 r
F P
0 g
s
.53783 .48585 m .53036 .49151 L .51945 .48483 L p 1 0 0 r
F P
0 g
s
.60691 .49623 m .59974 .51303 L .58937 .51622 L p 0 1 0 r
F P
0 g
s
.58937 .51622 m .59664 .50054 L .60691 .49623 L p 0 1 0 r
F P
0 g
s
.63404 .34341 m .63457 .34504 L .63229 .34786 L p 0 1 0 r
F P
0 g
s
.50119 .48678 m .50851 .4789 L .51945 .48483 L p 1 0 0 r
F P
0 g
s
.50851 .4789 m .50119 .48678 L .49024 .48218 L p 1 0 0 r
F P
0 g
s
.27175 .53949 m .27831 .53183 L .28974 .53689 L p 0 0 1 r
F P
0 g
s
.27831 .53183 m .27175 .53949 L .2603 .53443 L p 0 0 1 r
F P
0 g
s
.34085 .49299 m .34751 .48729 L .35865 .49513 L p 0 1 0 r
F P
0 g
s
.34751 .48729 m .34085 .49299 L .32967 .48594 L p 0 1 0 r
F P
0 g
s
.31912 .53934 m .32584 .53167 L .33716 .53674 L p 0 0 1 r
F P
0 g
s
.32584 .53167 m .31912 .53934 L .30777 .53428 L p 0 0 1 r
F P
0 g
s
.56728 .55611 m .57467 .54393 L .58521 .54284 L p 0 1 0 r
F P
0 g
s
.3665 .53919 m .37337 .53152 L .38459 .53659 L p 0 0 1 r
F P
0 g
s
.37337 .53152 m .3665 .53919 L .35525 .53413 L p 0 0 1 r
F P
0 g
s
.44653 .50558 m .45371 .49496 L .46478 .49763 L p 1 0 0 r
F P
0 g
s
.47199 .48769 m .46478 .49763 L .45371 .49496 L p 1 0 0 r
F P
0 g
s
.67746 .72368 m .67746 .72369 L .67754 .72968 L p 1 0 0 r
F P
0 g
s
.46126 .53889 m .46845 .53122 L .47947 .53629 L p 0 0 1 r
F P
0 g
s
.46845 .53122 m .46126 .53889 L .45022 .53383 L p 0 0 1 r
F P
0 g
s
.50866 .53873 m .516 .53107 L .52692 .53614 L p 0 0 1 r
F P
0 g
s
.516 .53107 m .50866 .53873 L .49771 .53368 L p 0 0 1 r
F P
0 g
s
.55606 .53858 m .56356 .53092 L .57437 .53598 L p 0 0 1 r
F P
0 g
s
.56356 .53092 m .55606 .53858 L .54522 .53353 L p 0 0 1 r
F P
0 g
s
.60346 .53843 m .61112 .53077 L .62183 .53583 L p 0 0 1 r
F P
0 g
s
.65087 .53828 m .65869 .53062 L .66929 .53568 L p 0 0 1 r
F P
0 g
s
.65869 .53062 m .65087 .53828 L .64024 .53323 L p 0 0 1 r
F P
0 g
s
.22072 .58208 m .21306 .60123 L .19992 .60931 L p 0 1 0 r
F P
0 g
s
.19992 .60931 m .20784 .5885 L .22072 .58208 L p 0 1 0 r
F P
0 g
s
.69829 .53813 m .70626 .53046 L .71677 .53553 L p 0 0 1 r
F P
0 g
s
.70626 .53046 m .69829 .53813 L .68776 .53308 L p 0 0 1 r
F P
0 g
s
.63229 .34786 m .63373 .34188 L .63404 .34341 L p 0 1 0 r
F P
0 g
s
.74571 .53798 m .75384 .53031 L .76424 .53538 L p 0 0 1 r
F P
0 g
s
.75384 .53031 m .74571 .53798 L .73528 .53293 L p 0 0 1 r
F P
0 g
s
.79314 .53783 m .80143 .53016 L .81173 .53523 L p 0 0 1 r
F P
0 g
s
.80143 .53016 m .79314 .53783 L .78282 .53277 L p 0 0 1 r
F P
0 g
s
.2638 .49355 m .25688 .50558 L .24489 .50523 L p 0 1 0 r
F P
0 g
s
.05272 .53764 m .05856 .52997 L .07048 .53504 L p 0 0 1 r
F P
0 g
s
.50515 .58091 m .5125 .57431 L .52343 .57923 L p 0 1 0 r
F P
0 g
s
.5125 .57431 m .50515 .58091 L .49419 .57479 L p 0 1 0 r
F P
0 g
s
.35179 .57408 m .35875 .5642 L .37015 .56641 L p 1 0 0 r
F P
0 g
s
.37717 .55585 m .37015 .56641 L .35875 .5642 L p 1 0 0 r
F P
0 g
s
.46498 .56584 m .47217 .56097 L .4832 .56812 L p 0 1 0 r
F P
0 g
s
.47217 .56097 m .46498 .56584 L .45398 .558 L p 0 1 0 r
F P
0 g
s
.10011 .53749 m .10611 .52982 L .11793 .53489 L p 0 0 1 r
F P
0 g
s
.10611 .52982 m .10011 .53749 L .08828 .53243 L p 0 0 1 r
F P
0 g
s
.14751 .53734 m .15367 .52966 L .16538 .53474 L p 0 0 1 r
F P
0 g
s
.15367 .52966 m .14751 .53734 L .13578 .53228 L p 0 0 1 r
F P
0 g
s
.19492 .53719 m .20123 .52951 L .21284 .53459 L p 0 0 1 r
F P
0 g
s
.20123 .52951 m .19492 .53719 L .18328 .53213 L p 0 0 1 r
F P
0 g
s
.28623 .57789 m .29268 .57244 L .30401 .57849 L p 1 0 0 r
F P
0 g
s
.29268 .57244 m .28623 .57789 L .27503 .57016 L p 1 0 0 r
F P
0 g
s
.28974 .53689 m .29637 .52921 L .30777 .53428 L p 0 0 1 r
F P
0 g
s
.29637 .52921 m .28974 .53689 L .27831 .53183 L p 0 0 1 r
F P
0 g
s
.2638 .49355 m .27065 .48246 L .28228 .48572 L p 0 1 0 r
F P
0 g
s
.28228 .48572 m .28901 .47634 L .30045 .48116 L p 0 1 0 r
F P
0 g
s
.28901 .47634 m .28228 .48572 L .27065 .48246 L p 0 1 0 r
F P
0 g
s
.6686 .67875 m .65948 .66937 L .64768 .64743 L p 1 0 0 r
F P
0 g
s
.64768 .64743 m .65652 .6549 L .6686 .67875 L p 1 0 0 r
F P
0 g
s
.37717 .55585 m .38424 .545 L .39558 .54658 L p 1 0 0 r
F P
0 g
s
.40268 .53545 m .39558 .54658 L .38424 .545 L p 1 0 0 r
F P
0 g
s
.33716 .53674 m .34395 .52906 L .35525 .53413 L p 0 0 1 r
F P
0 g
s
.34395 .52906 m .33716 .53674 L .32584 .53167 L p 0 0 1 r
F P
0 g
s
.63199 .33661 m .63373 .34188 L p .6226 .35821 L 0 1 0 r
F P
0 g
s
.63373 .34188 m .63229 .34786 L .6226 .35821 L p 0 1 0 r
F P
0 g
s
.39153 .52891 m .38459 .53659 L .37337 .53152 L p 0 0 1 r
F P
0 g
s
.45371 .49496 m .44653 .50558 L .43537 .50353 L p 1 0 0 r
F P
0 g
s
.43203 .53644 m .43913 .52876 L .45022 .53383 L p 0 0 1 r
F P
0 g
s
.32967 .48594 m .33633 .47977 L .34751 .48729 L p 0 1 0 r
F P
0 g
s
.33633 .47977 m .32967 .48594 L .31843 .47934 L p 0 1 0 r
F P
0 g
s
.47947 .53629 m .48673 .5286 L .49771 .53368 L p 0 0 1 r
F P
0 g
s
.48673 .5286 m .47947 .53629 L .46845 .53122 L p 0 0 1 r
F P
0 g
s
.51945 .48483 m .52686 .47834 L .53783 .48585 L p 1 0 0 r
F P
0 g
s
.52686 .47834 m .51945 .48483 L .50851 .4789 L p 1 0 0 r
F P
0 g
s
.30045 .48116 m .30712 .47324 L .31843 .47934 L p 0 1 0 r
F P
0 g
s
.30712 .47324 m .30045 .48116 L .28901 .47634 L p 0 1 0 r
F P
0 g
s
.62702 .586 m .61861 .58225 L .60731 .56636 L p 1 0 0 r
F P
0 g
s
.60731 .56636 m .61553 .56861 L .62702 .586 L p 1 0 0 r
F P
0 g
s
.52692 .53614 m .53433 .52845 L .54522 .53353 L p 0 0 1 r
F P
0 g
s
.53433 .52845 m .52692 .53614 L .516 .53107 L p 0 0 1 r
F P
0 g
s
.67534 .70573 m .67619 .71063 L p .66244 .68395 L 1 0 0 r
F P
0 g
s
.67619 .71063 m .67451 .70854 L .66244 .68395 L p 1 0 0 r
F P
0 g
s
.66244 .68395 m .67156 .69357 L p .67534 .70573 L 1 0 0 r
F P
0 g
s
.20245 .65622 m .19424 .67998 L .18029 .69392 L p 0 1 0 r
F P
0 g
s
.18029 .69392 m .18885 .66809 L .20245 .65622 L p 0 1 0 r
F P
0 g
s
.31537 .58379 m .32209 .57606 L .3335 .58006 L p 1 0 0 r
F P
0 g
s
.32209 .57606 m .31537 .58379 L .30401 .57849 L p 1 0 0 r
F P
0 g
s
.62183 .53583 m .62956 .52815 L .64024 .53323 L p 0 0 1 r
F P
0 g
s
.62956 .52815 m .62183 .53583 L .61112 .53077 L p 0 0 1 r
F P
0 g
s
.66929 .53568 m .67718 .528 L .68776 .53308 L p 0 0 1 r
F P
0 g
s
.67718 .528 m .66929 .53568 L .65869 .53062 L p 0 0 1 r
F P
0 g
s
.62866 .38734 m .62188 .41046 L .61189 .41828 L p 0 1 0 r
F P
0 g
s
.61189 .41828 m .61884 .39641 L .62866 .38734 L p 0 1 0 r
F P
0 g
s
.5417 .57485 m .54912 .56546 L .55988 .56726 L p 0 1 0 r
F P
0 g
s
.56728 .55611 m .55988 .56726 L .54912 .56546 L p 0 1 0 r
F P
0 g
s
.71677 .53553 m .72481 .52785 L .73528 .53293 L p 0 0 1 r
F P
0 g
s
.72481 .52785 m .71677 .53553 L .70626 .53046 L p 0 0 1 r
F P
0 g
s
.76424 .53538 m .77245 .52769 L .78282 .53277 L p 0 0 1 r
F P
0 g
s
.77245 .52769 m .76424 .53538 L .75384 .53031 L p 0 0 1 r
F P
0 g
s
.45398 .558 m .46112 .5534 L .47217 .56097 L p 0 1 0 r
F P
0 g
s
.46112 .5534 m .45398 .558 L .44295 .54987 L p 0 1 0 r
F P
0 g
s
.81173 .53523 m .82009 .52754 L .83036 .53262 L p 0 0 1 r
F P
0 g
s
.82009 .52754 m .81173 .53523 L .80143 .53016 L p 0 0 1 r
F P
0 g
s
.3335 .58006 m .34037 .57111 L .35179 .57408 L p 1 0 0 r
F P
0 g
s
.35875 .5642 m .35179 .57408 L .34037 .57111 L p 1 0 0 r
F P
0 g
s
.07048 .53504 m .07638 .52735 L .08828 .53243 L p 0 0 1 r
F P
0 g
s
.07638 .52735 m .07048 .53504 L .05856 .52997 L p 0 0 1 r
F P
0 g
s
.11793 .53489 m .12399 .5272 L .13578 .53228 L p 0 0 1 r
F P
0 g
s
.12399 .5272 m .11793 .53489 L .10611 .52982 L p 0 0 1 r
F P
0 g
s
.65354 .64054 m .64469 .63327 L .63309 .61366 L p 1 0 0 r
F P
0 g
s
.63309 .61366 m .64169 .61919 L .65354 .64054 L p 1 0 0 r
F P
0 g
s
.16538 .53474 m .1716 .52704 L .18328 .53213 L p 0 0 1 r
F P
0 g
s
.1716 .52704 m .16538 .53474 L .15367 .52966 L p 0 0 1 r
F P
0 g
s
.21306 .60123 m .20521 .62187 L .19179 .63175 L p 0 1 0 r
F P
0 g
s
.19179 .63175 m .19992 .60931 L .21306 .60123 L p 0 1 0 r
F P
0 g
s
.21921 .52689 m .21284 .53459 L .20123 .52951 L p 0 0 1 r
F P
0 g
s
.27503 .57016 m .28137 .56556 L .29268 .57244 L p 1 0 0 r
F P
0 g
s
.28137 .56556 m .27503 .57016 L .2639 .56149 L p 1 0 0 r
F P
0 g
s
.34037 .57111 m .3335 .58006 L .32209 .57606 L p 1 0 0 r
F P
0 g
s
.2603 .53443 m .26684 .52674 L .27831 .53183 L p 0 0 1 r
F P
0 g
s
.26684 .52674 m .2603 .53443 L .2488 .52936 L p 0 0 1 r
F P
0 g
s
.30777 .53428 m .31446 .52659 L .32584 .53167 L p 0 0 1 r
F P
0 g
s
.31446 .52659 m .30777 .53428 L .29637 .52921 L p 0 0 1 r
F P
0 g
s
.24489 .50523 m .25193 .49213 L .2638 .49355 L p 0 1 0 r
F P
0 g
s
.27065 .48246 m .2638 .49355 L .25193 .49213 L p 0 1 0 r
F P
0 g
s
.52343 .57923 m .53084 .57137 L .5417 .57485 L p 0 1 0 r
F P
0 g
s
.53084 .57137 m .52343 .57923 L .5125 .57431 L p 0 1 0 r
F P
0 g
s
.35525 .53413 m .3621 .52644 L .37337 .53152 L p 0 0 1 r
F P
0 g
s
.3621 .52644 m .35525 .53413 L .34395 .52906 L p 0 0 1 r
F P
0 g
s
.61799 .44543 m .61097 .46521 L .60075 .47063 L p 0 1 0 r
F P
0 g
s
.60075 .47063 m .60791 .45205 L .61799 .44543 L p 0 1 0 r
F P
0 g
s
.47199 .48769 m .47923 .47813 L .49024 .48218 L p 1 0 0 r
F P
0 g
s
.49024 .48218 m .49754 .47364 L .50851 .4789 L p 1 0 0 r
F P
0 g
s
.49754 .47364 m .49024 .48218 L .47923 .47813 L p 1 0 0 r
F P
0 g
s
.63229 .34786 m .62565 .37296 L .61576 .38203 L p 0 1 0 r
F P
0 g
s
.61576 .38203 m .6226 .35821 L .63229 .34786 L p 0 1 0 r
F P
0 g
s
.45022 .53383 m .45739 .52613 L .46845 .53122 L p 0 0 1 r
F P
0 g
s
.45739 .52613 m .45022 .53383 L .43913 .52876 L p 0 0 1 r
F P
0 g
s
.49771 .53368 m .50504 .52598 L .516 .53107 L p 0 0 1 r
F P
0 g
s
.50504 .52598 m .49771 .53368 L .48673 .5286 L p 0 0 1 r
F P
0 g
s
.49419 .57479 m .50152 .56871 L .5125 .57431 L p 0 1 0 r
F P
0 g
s
.50152 .56871 m .49419 .57479 L .4832 .56812 L p 0 1 0 r
F P
0 g
s
.45371 .49496 m .46092 .4846 L .47199 .48769 L p 1 0 0 r
F P
0 g
s
.47923 .47813 m .47199 .48769 L .46092 .4846 L p 1 0 0 r
F P
0 g
s
.54522 .53353 m .5527 .52583 L .56356 .53092 L p 0 0 1 r
F P
0 g
s
.5527 .52583 m .54522 .53353 L .53433 .52845 L p 0 0 1 r
F P
0 g
s
.54912 .56546 m .5417 .57485 L .53084 .57137 L p 0 1 0 r
F P
0 g
s
.44295 .54987 m .45005 .54547 L .46112 .5534 L p 0 1 0 r
F P
0 g
s
.45005 .54547 m .44295 .54987 L .43191 .54151 L p 0 1 0 r
F P
0 g
s
.64024 .53323 m .64804 .52553 L .65869 .53062 L p 0 0 1 r
F P
0 g
s
.64804 .52553 m .64024 .53323 L .62956 .52815 L p 0 0 1 r
F P
0 g
s
.68776 .53308 m .69571 .52537 L .70626 .53046 L p 0 0 1 r
F P
0 g
s
.69571 .52537 m .68776 .53308 L .67718 .528 L p 0 0 1 r
F P
0 g
s
.2639 .56149 m .2701 .55781 L .28137 .56556 L p 1 0 0 r
F P
0 g
s
.2701 .55781 m .2639 .56149 L .25285 .55183 L p 1 0 0 r
F P
0 g
s
.2589 .54913 m .25285 .55183 L .2419 .54114 L p 1 0 0 r
F P
0 g
s
.2419 .54114 m .24778 .53947 L .2589 .54913 L p 1 0 0 r
F P
0 g
s
.73528 .53293 m .7434 .52522 L .75384 .53031 L p 0 0 1 r
F P
0 g
s
.7434 .52522 m .73528 .53293 L .72481 .52785 L p 0 0 1 r
F P
0 g
s
.35875 .5642 m .36576 .55389 L .37717 .55585 L p 1 0 0 r
F P
0 g
s
.38424 .545 m .37717 .55585 L .36576 .55389 L p 1 0 0 r
F P
0 g
s
.78282 .53277 m .79109 .52507 L .80143 .53016 L p 0 0 1 r
F P
0 g
s
.79109 .52507 m .78282 .53277 L .77245 .52769 L p 0 0 1 r
F P
0 g
s
.31843 .47934 m .32508 .47263 L .33633 .47977 L p 0 1 0 r
F P
0 g
s
.32508 .47263 m .31843 .47934 L .30712 .47324 L p 0 1 0 r
F P
0 g
s
.83879 .52492 m .83036 .53262 L .82009 .52754 L p 0 0 1 r
F P
0 g
s
.38424 .545 m .39134 .53392 L .40268 .53545 L p 1 0 0 r
F P
0 g
s
.67746 .72369 m .67746 .72369 L .67746 .72368 L p 1 0 0 r
F P
0 g
s
.67746 .72368 m .67746 .72368 L .67746 .72369 L p 1 0 0 r
F P
0 g
s
.57859 .51237 m .57077 .51411 L .55976 .50365 L p 1 0 0 r
F P
0 g
s
.55976 .50365 m .56748 .5008 L .57859 .51237 L p 1 0 0 r
F P
0 g
s
.56748 .5008 m .55976 .50365 L .54879 .49427 L p 1 0 0 r
F P
0 g
s
.25285 .55183 m .2589 .54913 L .2701 .55781 L p 1 0 0 r
F P
0 g
s
.08828 .53243 m .09425 .52472 L .10611 .52982 L p 0 0 1 r
F P
0 g
s
.09425 .52472 m .08828 .53243 L .07638 .52735 L p 0 0 1 r
F P
0 g
s
.13578 .53228 m .1419 .52457 L .15367 .52966 L p 0 0 1 r
F P
0 g
s
.1419 .52457 m .13578 .53228 L .12399 .5272 L p 0 0 1 r
F P
0 g
s
.59664 .50054 m .58937 .51622 L .58302 .51745 L p 0 1 0 r
F P
0 g
s
.57077 .51411 m .57859 .51237 L .5827 .51708 L p 1 0 0 r
F P
0 g
s
.5827 .51708 m .58302 .51745 L p .58272 .51737 L 1 0 0 r
F P
0 g
s
.57077 .51411 m .5827 .51708 L .58272 .51737 L 1 0 0 r
F
.58619 .50367 m .58194 .5121 L p .58071 .50838 L 0 1 0 r
F P
0 g
s
.58619 .50367 m .59664 .50054 L p .58249 .51461 L 0 1 0 r
F P
0 g
s
.58249 .5146 m .58619 .50367 L .58249 .51461 L 0 1 0 r
F
.58221 .51157 m .58619 .50367 L p .58248 .51463 L F P
0 g
s
.60385 .48356 m .59664 .50054 L .58619 .50367 L p 0 1 0 r
F P
0 g
s
.58619 .50367 m .59351 .48782 L .60385 .48356 L p 0 1 0 r
F P
0 g
s
.59351 .48782 m .58619 .50367 L .5804 .50475 L p 0 1 0 r
F P
0 g
s
.56748 .5008 m .57531 .49897 L .5804 .50475 L p 1 0 0 r
F P
0 g
s
.5804 .50475 m .58619 .50367 L p .58115 .50801 L 0 1 0 r
F P
0 g
s
.58071 .50838 m .5804 .50475 L .58115 .50801 L 0 1 0 r
F
.59407 .49974 m .58637 .50761 L .58044 .50479 L p 0 0 1 r
F P
0 g
s
.57975 .5015 m .57976 .50148 L .5804 .50475 L 0 1 0 r
F
.57976 .50148 m .59351 .48782 L .58072 .50434 L F
.57976 .50148 m .58072 .50434 L .5804 .50475 L F
.57531 .49897 m .56415 .48743 L p .57758 .49501 L 1 0 0 r
F P
0 g
s
.58298 .49089 m .59351 .48782 L p .57976 .50148 L 0 1 0 r
F P
0 g
s
.5804 .50475 m .58002 .50432 L p .57991 .50324 L 1 0 0 r
F P
0 g
s
.58002 .50432 m .57531 .49897 L p .57944 .5018 L 1 0 0 r
F P
0 g
s
.56748 .5008 m .5804 .50475 L .5804 .50478 L 1 0 0 r
F
.56748 .5008 m .58044 .50479 L .58076 .50841 L F
.58037 .50457 m .58039 .50419 L .58044 .50479 L 0 0 1 r
F
.57944 .5018 m .57975 .5015 L .5804 .50475 L 0 1 0 r
F
.58039 .50419 m .5821 .50363 L .58044 .50477 L 0 0 1 r
F
.5821 .50363 m .59407 .49974 L .58044 .50477 L F
.58044 .50477 m .59407 .49974 L .58044 .50479 L F
.5804 .50475 m .58036 .50475 L p .57944 .5018 L 0 1 0 r
F P
0 g
s
.57939 .50185 m .57949 .50184 L .57967 .50442 L 0 0 1 r
F
.57949 .50184 m .59407 .49974 L .58026 .50423 L F
.57944 .5018 m .57949 .50184 L .58002 .50432 L 1 0 0 r
F
.57949 .50184 m .57989 .50309 L .58002 .50432 L F
.57939 .50185 m .57944 .5018 L .58036 .50475 L 0 1 0 r
F
.57991 .50324 m .57989 .50309 L .5804 .50475 L 1 0 0 r
F
.57989 .50309 m .57978 .50204 L .58034 .50447 L F
.57989 .50309 m .58034 .50447 L .5804 .50475 L F
.58019 .50425 m .58026 .50423 L .58036 .50475 L 0 0 1 r
F
.58026 .50423 m .58039 .50419 L .58037 .50457 L F
.58026 .50423 m .58037 .50457 L .58036 .50475 L F
.57949 .50184 m .58026 .50423 L .58019 .50425 L F
.57952 .50222 m .58019 .50425 L .57967 .50442 L F
.57949 .50184 m .58019 .50425 L .57952 .50222 L F
.57949 .50184 m .57978 .50204 L .57989 .50309 L 1 0 0 r
F
.58302 .51745 m .5827 .51708 L p .58295 .51722 L F P
0 g
s
.5827 .51708 m .57859 .51237 L p .58221 .5149 L 1 0 0 r
F P
0 g
s
.58221 .5149 m .58248 .51463 L .58302 .51745 L 0 1 0 r
F
.58248 .51463 m .59664 .50054 L .58302 .51745 L F
.60806 .51792 m .60036 .52568 L .58956 .52057 L p 0 0 1 r
F P
0 g
s
.58302 .51745 m .58937 .51622 L p .5838 .52101 L 0 1 0 r
F P
0 g
s
.59723 .51278 m .58956 .52057 L .58305 .51748 L p 0 0 1 r
F P
0 g
s
.58221 .5149 m .58225 .51492 L .5827 .51708 L 1 0 0 r
F
.58225 .51492 m .58259 .51602 L .5827 .51708 L F
.5825 .5151 m .58297 .51724 L .5827 .51708 L F
.58332 .52142 m .58302 .51745 L .5838 .52101 L 0 1 0 r
F
.58332 .52142 m .58302 .51745 L .58307 .5177 L 1 0 0 r
F
.57077 .51411 m .58302 .51745 L .58332 .52142 L F
.58327 .52146 m .58302 .51745 L .58332 .52142 L 0 1 0 r
F
.57111 .5232 m .58299 .51745 L .58299 .51751 L 0 0 1 r
F
.58299 .51748 m .58302 .51745 L .58327 .52146 L 0 1 0 r
F
.58332 .52142 m .58307 .5177 L .58337 .52145 L 1 0 0 r
F
.58305 .51748 m .58956 .52057 L p .58425 .52132 L 0 0 1 r
F P
0 g
s
.58337 .52145 m .58305 .51748 L .58425 .52132 L 0 0 1 r
F
.59786 .52582 m .58977 .52518 L .58305 .51748 L p 1 0 0 r
F P
0 g
s
.58305 .51748 m .58302 .51745 L p .58304 .51746 L 1 0 0 r
F P
0 g
s
.58225 .51492 m .59723 .51278 L .58305 .51748 L 0 0 1 r
F
.58304 .51746 m .59786 .52582 L .58305 .51748 L 1 0 0 r
F
.58302 .51745 m .58977 .52518 L p .58384 .52173 L F P
0 g
s
.57111 .5232 m .58305 .51748 L .58337 .52145 L 0 0 1 r
F
.57142 .53166 m .58299 .51748 L .58327 .52146 L 0 1 0 r
F
.57111 .5232 m .57871 .51543 L .58299 .51745 L p 0 0 1 r
F P
0 g
s
.58299 .51745 m .58302 .51745 L p .58299 .51748 L 0 1 0 r
F P
0 g
s
.58299 .51745 m .58305 .51748 L p .58299 .51751 L 0 0 1 r
F P
0 g
s
.58337 .52145 m .58307 .5177 L .58384 .52173 L 1 0 0 r
F
.57142 .53166 m .57883 .51826 L .58299 .51745 L p 0 1 0 r
F P
0 g
s
.57142 .53166 m .58299 .51745 L .58299 .51748 L 0 1 0 r
F
.58302 .51745 m .58299 .51745 L p .58221 .5149 L F P
0 g
s
.57871 .51543 m .58217 .51494 L .58291 .51721 L 0 0 1 r
F
.58217 .51494 m .58221 .5149 L .58299 .51745 L 0 1 0 r
F
.58299 .51745 m .57871 .51543 L p .58297 .51724 L 0 0 1 r
F P
0 g
s
.58299 .51745 m .57883 .51826 L p .58217 .51494 L 0 1 0 r
F P
0 g
s
.58291 .51721 m .58225 .51492 L .58297 .51724 L 0 0 1 r
F
.58217 .51494 m .58225 .51492 L .58291 .51721 L F
.58295 .51722 m .59786 .52582 L .58302 .51745 L 1 0 0 r
F
.58305 .51748 m .58299 .51745 L p .58297 .51724 L 0 0 1 r
F P
0 g
s
.58225 .51492 m .5825 .5151 L .58259 .51602 L 1 0 0 r
F
.58956 .52057 m .59723 .51278 L .60806 .51792 L p 0 0 1 r
F P
0 g
s
.5825 .5151 m .59786 .52582 L .58297 .51724 L 1 0 0 r
F
.58221 .5149 m .58221 .51157 L .58248 .51463 L 0 1 0 r
F
.58637 .50761 m .59723 .51278 L p .58288 .51483 L 0 0 1 r
F P
0 g
s
.58266 .51419 m .58637 .50761 L .58288 .51483 L 0 0 1 r
F
.58217 .51453 m .58221 .51157 L .58221 .5149 L 0 1 0 r
F
.57859 .51237 m .58194 .5121 L p .58221 .5149 L 1 0 0 r
F P
0 g
s
.5819 .51217 m .58221 .51157 L p .58217 .51494 L 0 1 0 r
F P
0 g
s
.58197 .5121 m .58637 .50761 L p .58225 .51492 L 0 0 1 r
F P
0 g
s
.58637 .50761 m .58197 .5121 L p .58076 .50841 L 0 0 1 r
F P
0 g
s
.58117 .50865 m .58385 .51018 L .58197 .5121 L 1 0 0 r
F
.58385 .51018 m .58655 .51173 L .58197 .5121 L F
.58197 .5121 m .58194 .5121 L p .58186 .51174 L F P
0 g
s
.58117 .50865 m .58197 .5121 L .58186 .51174 L 1 0 0 r
F
.58248 .51463 m .58249 .5146 L .58249 .51461 L 0 1 0 r
F
.58225 .51492 m .58266 .51419 L .58288 .51483 L 0 0 1 r
F
.58221 .5149 m .58224 .51487 L .58225 .51492 L 1 0 0 r
F
.58194 .5121 m .58655 .51173 L p .58221 .5149 L F P
0 g
s
.58217 .51473 m .58217 .51453 L .58221 .5149 L 0 1 0 r
F
.58217 .51494 m .58217 .51473 L .58221 .5149 L F
.57871 .51543 m .5819 .51217 L p .58225 .51492 L 0 0 1 r
F P
0 g
s
.58076 .50841 m .58095 .50897 L .57859 .51237 L 1 0 0 r
F
.58194 .5121 m .57859 .51237 L p .58117 .50865 L F P
0 g
s
.58194 .5121 m .5819 .51217 L p .58071 .50838 L 0 1 0 r
F P
0 g
s
.58076 .50841 m .58186 .51174 L .58178 .51182 L 0 0 1 r
F
.58071 .5086 m .58178 .51182 L .57871 .51543 L F
.58071 .50838 m .58074 .50847 L .57859 .51237 L 1 0 0 r
F
.58071 .50838 m .5819 .51217 L .58068 .50852 L 0 1 0 r
F
.58076 .50841 m .58178 .51182 L .58071 .5086 L 0 0 1 r
F
.5819 .51217 m .57871 .51543 L p .58186 .51174 L F P
0 g
s
.58065 .50843 m .58071 .50838 L .58068 .50852 L 0 1 0 r
F
.57859 .51237 m .56748 .5008 L p .5804 .50821 L 1 0 0 r
F P
0 g
s
.5804 .50821 m .58052 .50873 L .57859 .51237 L 1 0 0 r
F
.57871 .51543 m .56781 .51027 L p .58065 .50843 L 0 0 1 r
F P
0 g
s
.58071 .50838 m .58076 .50841 L .58074 .50847 L 1 0 0 r
F
.58065 .50843 m .58076 .50841 L .58068 .50871 L 0 0 1 r
F
.58065 .50843 m .58068 .50871 L .57871 .51543 L F
.58065 .50843 m .5804 .50475 L .58071 .50838 L 0 1 0 r
F
.5804 .50821 m .58071 .50838 L .58052 .50873 L 1 0 0 r
F
.57871 .51543 m .57111 .5232 L .56023 .51808 L p 0 0 1 r
F P
0 g
s
.56023 .51808 m .56781 .51027 L .57871 .51543 L p 0 0 1 r
F P
0 g
s
.58036 .50479 m .5804 .50475 L .58065 .50843 L 0 1 0 r
F
.56781 .51027 m .57545 .50242 L .58036 .50475 L p 0 0 1 r
F P
0 g
s
.56781 .51027 m .58036 .50475 L .58037 .50483 L 0 0 1 r
F
.56781 .51027 m .58044 .50479 L .58157 .5083 L F
.56813 .51919 m .57557 .50565 L .58036 .50475 L p 0 1 0 r
F P
0 g
s
.58036 .50475 m .5804 .50475 L p .58036 .50479 L 0 1 0 r
F P
0 g
s
.56813 .51919 m .58036 .50475 L .58036 .50479 L 0 1 0 r
F
.58036 .50475 m .58044 .50479 L p .58037 .50483 L 0 0 1 r
F P
0 g
s
.58044 .50479 m .58637 .50761 L p .58157 .5083 L 0 0 1 r
F P
0 g
s
.59466 .51226 m .58655 .51173 L .58044 .50479 L p 1 0 0 r
F P
0 g
s
.58044 .50479 m .5804 .50475 L p .58043 .50476 L 1 0 0 r
F P
0 g
s
.58043 .50476 m .59466 .51226 L .58044 .50479 L 1 0 0 r
F
.56813 .51919 m .58036 .50479 L .58065 .50843 L 0 1 0 r
F
.5819 .51217 m .57883 .51826 L p .58068 .50852 L F P
0 g
s
.57883 .51826 m .56813 .51919 L p .58065 .50843 L 0 1 0 r
F P
0 g
s
.58065 .50843 m .58068 .50852 L .57883 .51826 L 0 1 0 r
F
.5819 .51217 m .58197 .5121 L p .58202 .51253 L 0 0 1 r
F P
0 g
s
.5819 .51217 m .58202 .51253 L .58225 .51492 L 0 0 1 r
F
.58655 .51173 m .59786 .52582 L p .58225 .51492 L 1 0 0 r
F P
0 g
s
.58224 .51487 m .58655 .51173 L .58225 .51492 L 1 0 0 r
F
.57883 .51826 m .5819 .51217 L p .58217 .51494 L 0 1 0 r
F P
0 g
s
.58197 .5121 m .5819 .51217 L p .58186 .51174 L 0 0 1 r
F P
0 g
s
.60496 .50494 m .59723 .51278 L .58637 .50761 L p 0 0 1 r
F P
0 g
s
.58637 .50761 m .59407 .49974 L .60496 .50494 L p 0 0 1 r
F P
0 g
s
.57978 .50204 m .59466 .51226 L .58043 .50476 L 1 0 0 r
F
.58034 .50447 m .58043 .50476 L .5804 .50475 L F
.57978 .50204 m .58043 .50476 L .58034 .50447 L F
.5804 .50478 m .5804 .50475 L .58041 .50478 L F
.5804 .50475 m .58044 .50479 L p .58041 .50478 L F P
0 g
s
.58044 .50479 m .58036 .50475 L p .58037 .50457 L 0 0 1 r
F P
0 g
s
.58036 .50475 m .57967 .50442 L p .58019 .50425 L 0 0 1 r
F P
0 g
s
.57967 .50442 m .57545 .50242 L p .57939 .50185 L 0 0 1 r
F P
0 g
s
.58036 .50475 m .57557 .50565 L p .57939 .50185 L 0 1 0 r
F P
0 g
s
.57944 .5018 m .57966 .50104 L .57976 .50148 L 0 1 0 r
F
.57939 .50185 m .57943 .50174 L .57944 .5018 L F
.57966 .50104 m .58298 .49089 L .57976 .50148 L F
.58313 .49451 m .59407 .49974 L p .5802 .50173 L 0 0 1 r
F P
0 g
s
.57993 .50094 m .58313 .49451 L .5802 .50173 L 0 0 1 r
F
.57943 .50173 m .57966 .50104 L .57944 .5018 L 0 1 0 r
F
.57531 .49897 m .5791 .49862 L p .57944 .5018 L 1 0 0 r
F P
0 g
s
.57934 .50136 m .58298 .49089 L .57939 .50185 L 0 1 0 r
F
.57545 .50242 m .57906 .49871 L p .57939 .50185 L 0 0 1 r
F P
0 g
s
.57851 .4998 m .57906 .49871 L p .57905 .50219 L 0 1 0 r
F P
0 g
s
.57906 .49871 m .58298 .49089 L p .57934 .50136 L 0 1 0 r
F P
0 g
s
.57906 .49871 m .57934 .50136 L .57905 .50219 L 0 1 0 r
F
.57944 .5018 m .57948 .50176 L .57949 .50184 L 1 0 0 r
F
.57915 .49861 m .58313 .49451 L p .57949 .50184 L 0 0 1 r
F P
0 g
s
.5791 .49862 m .57915 .49861 L p .57944 .5018 L 1 0 0 r
F P
0 g
s
.57949 .50184 m .57993 .50094 L .5802 .50173 L 0 0 1 r
F
.57915 .49861 m .58329 .49823 L p .57948 .50176 L 1 0 0 r
F P
0 g
s
.57915 .49861 m .57948 .50176 L .57944 .5018 L 1 0 0 r
F
.57943 .50174 m .57943 .50173 L .57944 .5018 L 0 1 0 r
F
.57939 .50185 m .57915 .49861 L .57949 .50184 L 0 0 1 r
F
.57906 .49871 m .57915 .49861 L p .57939 .50185 L F P
0 g
s
.57758 .49501 m .57795 .49521 L .57858 .49799 L 1 0 0 r
F
.5788 .49864 m .57531 .49897 L p .57758 .49501 L F P
0 g
s
.57531 .49897 m .56748 .5008 L .55641 .49038 L p 1 0 0 r
F P
0 g
s
.55641 .49038 m .56415 .48743 L .57531 .49897 L p 1 0 0 r
F P
0 g
s
.57545 .50242 m .56448 .4972 L p .57788 .49527 L 0 0 1 r
F P
0 g
s
.57545 .50242 m .56781 .51027 L .55687 .50509 L p 0 0 1 r
F P
0 g
s
.57972 .47786 m .57613 .48508 L p .57502 .48191 L 0 1 0 r
F P
0 g
s
.57972 .47786 m .59033 .47484 L p .57688 .48823 L 0 1 0 r
F P
0 g
s
.57688 .48822 m .57972 .47786 L .57688 .48823 L 0 1 0 r
F
.57646 .48441 m .57972 .47786 L p .57687 .48824 L F P
0 g
s
.59761 .45743 m .59033 .47484 L .57972 .47786 L p 0 1 0 r
F P
0 g
s
.57972 .47786 m .58711 .4616 L .59761 .45743 L p 0 1 0 r
F P
0 g
s
.58711 .4616 m .57972 .47786 L .5747 .47874 L p 0 1 0 r
F P
0 g
s
.56078 .47398 m .56866 .47198 L .5747 .47874 L p 1 0 0 r
F P
0 g
s
.5747 .47874 m .57972 .47786 L p .5754 .48159 L 0 1 0 r
F P
0 g
s
.57502 .48191 m .5747 .47874 L .5754 .48159 L 0 1 0 r
F
.58763 .47321 m .57986 .48126 L .57476 .47881 L p 0 0 1 r
F P
0 g
s
.57385 .47486 m .58711 .4616 L .5747 .47874 L 0 1 0 r
F
.57468 .47803 m .58763 .47321 L .57476 .47881 L 0 0 1 r
F
.57763 .49185 m .58298 .49089 L p .57835 .49487 L 0 1 0 r
F P
0 g
s
.57795 .49521 m .57763 .49185 L .57835 .49487 L 0 1 0 r
F
.57812 .49574 m .5786 .49715 L .5788 .49864 L 1 0 0 r
F
.58298 .49089 m .5791 .49862 L p .57795 .49521 L 0 1 0 r
F P
0 g
s
.58313 .49451 m .57915 .49861 L p .57801 .49525 L 0 0 1 r
F P
0 g
s
.5791 .49862 m .5788 .49864 L p .57857 .49691 L 1 0 0 r
F P
0 g
s
.57837 .49545 m .579 .49818 L .57857 .49691 L 1 0 0 r
F
.579 .49818 m .5791 .49862 L .57857 .49691 L F
.57788 .49527 m .57795 .49521 L .57906 .49871 L 0 1 0 r
F
.5791 .49862 m .57906 .49871 L p .57795 .49521 L F P
0 g
s
.57801 .49525 m .57857 .49691 L .5786 .49715 L 1 0 0 r
F
.57801 .49525 m .5786 .49715 L .57812 .49574 L F
.56415 .48743 m .572 .4855 L .57721 .49137 L p F P
0 g
s
.56415 .48743 m .57721 .49137 L .57724 .49172 L 1 0 0 r
F
.57768 .49191 m .58313 .49451 L p .57875 .49514 L 0 0 1 r
F P
0 g
s
.57763 .49185 m .57768 .49191 L p .57795 .49521 L 1 0 0 r
F P
0 g
s
.57801 .49525 m .57768 .49191 L .57875 .49514 L 0 0 1 r
F
.57768 .49191 m .58329 .49823 L p .57801 .49525 L 1 0 0 r
F P
0 g
s
.57795 .49521 m .57768 .49191 L .57801 .49525 L 1 0 0 r
F
.56415 .48743 m .57763 .49185 L .57795 .49521 L F
.57795 .49521 m .57783 .49473 L .57763 .49185 L 0 1 0 r
F
.56448 .4972 m .57759 .49194 L .57788 .49527 L 0 0 1 r
F
.57758 .49186 m .57763 .49185 L p .57783 .49473 L 0 1 0 r
F P
0 g
s
.56448 .4972 m .57215 .48926 L .57758 .49186 L p 0 0 1 r
F P
0 g
s
.57758 .49186 m .57768 .49191 L p .57759 .49194 L 0 0 1 r
F P
0 g
s
.56448 .4972 m .57758 .49186 L .57759 .49194 L 0 0 1 r
F
.54879 .49427 m .55641 .49038 L .56748 .5008 L p 1 0 0 r
F P
0 g
s
.55687 .50509 m .56448 .4972 L .57545 .50242 L p 0 0 1 r
F P
0 g
s
.5648 .50652 m .57719 .49193 L .57783 .49473 L 0 1 0 r
F
.57788 .49527 m .57783 .49473 L .57795 .49521 L F
.5648 .50652 m .57783 .49473 L .57788 .49527 L F
.57719 .49193 m .57758 .49186 L p .57783 .49473 L F P
0 g
s
.57788 .49527 m .57768 .49191 L .57801 .49525 L 0 0 1 r
F
.57759 .49194 m .57768 .49191 L .57788 .49527 L F
.59143 .49868 m .58329 .49823 L .57768 .49191 L p 1 0 0 r
F P
0 g
s
.57768 .49191 m .57763 .49185 L p .57767 .49187 L 1 0 0 r
F P
0 g
s
.57767 .49187 m .59143 .49868 L .57768 .49191 L 1 0 0 r
F
.59033 .47484 m .58298 .49089 L .57763 .49185 L p 0 1 0 r
F P
0 g
s
.57763 .49185 m .57721 .49137 L p .57753 .49153 L 1 0 0 r
F P
0 g
s
.57721 .49137 m .572 .4855 L p .57653 .48858 L 1 0 0 r
F P
0 g
s
.57653 .48858 m .59033 .47484 L .57763 .49185 L 0 1 0 r
F
.60183 .49181 m .59407 .49974 L .58313 .49451 L p 0 0 1 r
F P
0 g
s
.60075 .47063 m .59351 .48782 L .58298 .49089 L p 0 1 0 r
F P
0 g
s
.58313 .49451 m .59087 .48655 L .60183 .49181 L p 0 0 1 r
F P
0 g
s
.57653 .48858 m .57659 .48862 L .57721 .49137 L 1 0 0 r
F
.58298 .49089 m .59033 .47484 L .60075 .47063 L p 0 1 0 r
F P
0 g
s
.59087 .48655 m .58313 .49451 L .57768 .49191 L p 0 0 1 r
F P
0 g
s
.57659 .48862 m .59087 .48655 L .57768 .49191 L 0 0 1 r
F
.57659 .48862 m .59143 .49868 L .57757 .49155 L 1 0 0 r
F
.57659 .48862 m .57757 .49155 L .57721 .49137 L F
.57763 .49185 m .57758 .49186 L p .57653 .48858 L 0 1 0 r
F P
0 g
s
.57721 .49137 m .57763 .49185 L p .57724 .49172 L 1 0 0 r
F P
0 g
s
.57758 .49186 m .57215 .48926 L p .57648 .48863 L 0 0 1 r
F P
0 g
s
.57758 .49186 m .57228 .49281 L p .57648 .48863 L 0 1 0 r
F P
0 g
s
.57648 .48863 m .57653 .48858 L .57758 .49186 L 0 1 0 r
F
.57753 .49153 m .57756 .49155 L .57763 .49185 L 1 0 0 r
F
.57756 .49155 m .59143 .49868 L .57763 .49185 L F
.57768 .49191 m .57758 .49186 L p .57659 .48862 L 0 0 1 r
F P
0 g
s
.57648 .48863 m .57659 .48862 L .57758 .49186 L 0 0 1 r
F
.57653 .48858 m .57646 .48441 L .57687 .48824 L 0 1 0 r
F
.57687 .48824 m .57688 .48822 L .57688 .48823 L F
.57986 .48126 m .59087 .48655 L p .57737 .4885 L 0 0 1 r
F P
0 g
s
.57705 .48758 m .57986 .48126 L .57737 .4885 L 0 0 1 r
F
.57647 .48807 m .57646 .48441 L .57653 .48858 L 0 1 0 r
F
.572 .4855 m .57613 .48508 L p .57653 .48858 L 1 0 0 r
F P
0 g
s
.57608 .48519 m .57646 .48441 L p .57648 .48863 L 0 1 0 r
F P
0 g
s
.57618 .48508 m .57986 .48126 L p .57659 .48862 L 0 0 1 r
F P
0 g
s
.57986 .48126 m .57618 .48508 L p .5751 .48196 L 0 0 1 r
F P
0 g
s
.57542 .48214 m .57776 .48344 L .57618 .48508 L 1 0 0 r
F
.57776 .48344 m .58001 .48469 L .57618 .48508 L F
.57618 .48508 m .57613 .48508 L p .576 .48456 L F P
0 g
s
.57542 .48214 m .57618 .48508 L .576 .48456 L 1 0 0 r
F
.57659 .48862 m .57705 .48758 L .57737 .4885 L 0 0 1 r
F
.57653 .48858 m .57658 .48852 L .57659 .48862 L 1 0 0 r
F
.57613 .48508 m .58001 .48469 L p .57653 .48858 L F P
0 g
s
.57647 .48834 m .57647 .48807 L .57653 .48858 L 0 1 0 r
F
.57648 .48863 m .57647 .48834 L .57653 .48858 L F
.57215 .48926 m .57608 .48519 L p .57659 .48862 L 0 0 1 r
F P
0 g
s
.5751 .48196 m .57523 .48233 L .572 .4855 L 1 0 0 r
F
.57613 .48508 m .572 .4855 L p .57542 .48214 L F P
0 g
s
.57613 .48508 m .57608 .48519 L p .57502 .48191 L 0 1 0 r
F P
0 g
s
.5751 .48196 m .576 .48456 L .5759 .48469 L 0 0 1 r
F
.57502 .48216 m .5759 .48469 L .57215 .48926 L F
.57502 .48191 m .57608 .48519 L .57499 .48207 L 0 1 0 r
F
.5751 .48196 m .5759 .48469 L .57502 .48216 L 0 0 1 r
F
.57608 .48519 m .57215 .48926 L p .576 .48456 L F P
0 g
s
.57502 .48191 m .57506 .482 L .572 .4855 L 1 0 0 r
F
.57495 .48198 m .57502 .48191 L .57499 .48207 L 0 1 0 r
F
.572 .4855 m .56078 .47398 L p .57464 .4817 L 1 0 0 r
F P
0 g
s
.57464 .4817 m .57477 .48222 L .572 .4855 L 1 0 0 r
F
.572 .4855 m .56415 .48743 L .55302 .47701 L p F P
0 g
s
.55302 .47701 m .56078 .47398 L .572 .4855 L p 1 0 0 r
F P
0 g
s
.57215 .48926 m .56111 .48399 L p .57495 .48198 L 0 0 1 r
F P
0 g
s
.57495 .48198 m .5751 .48196 L .57498 .48225 L 0 0 1 r
F
.57495 .48198 m .57498 .48225 L .57215 .48926 L F
.56078 .47398 m .57476 .47881 L .5751 .48196 L 1 0 0 r
F
.57495 .48198 m .5747 .47874 L .57502 .48191 L 0 1 0 r
F
.57464 .4817 m .57502 .48191 L .57477 .48222 L 1 0 0 r
F
.57215 .48926 m .56448 .4972 L .55347 .49197 L p 0 0 1 r
F P
0 g
s
.55641 .49038 m .54879 .49427 L .53783 .48585 L p 1 0 0 r
F P
0 g
s
.53783 .48585 m .54537 .481 L .55641 .49038 L p 1 0 0 r
F P
0 g
s
.56415 .48743 m .55641 .49038 L .54537 .481 L p 1 0 0 r
F P
0 g
s
.54537 .481 m .55302 .47701 L .56415 .48743 L p 1 0 0 r
F P
0 g
s
.55347 .49197 m .56111 .48399 L .57215 .48926 L p 0 0 1 r
F P
0 g
s
.57464 .47881 m .5747 .47874 L .57495 .48198 L 0 1 0 r
F
.56078 .47398 m .5747 .47874 L .5747 .47879 L 1 0 0 r
F
.56111 .48399 m .56881 .47595 L .57464 .47875 L p 0 0 1 r
F P
0 g
s
.56111 .48399 m .57464 .47875 L .57465 .47886 L 0 0 1 r
F
.57502 .48191 m .5751 .48196 L .57506 .482 L 1 0 0 r
F
.56111 .48399 m .57476 .47881 L .5758 .48185 L 0 0 1 r
F
.56143 .49363 m .56895 .47975 L .57464 .47875 L p 0 1 0 r
F P
0 g
s
.57464 .47875 m .5747 .47874 L p .57464 .47881 L 0 1 0 r
F P
0 g
s
.56143 .49363 m .57464 .47875 L .57464 .47881 L 0 1 0 r
F
.57464 .47875 m .57476 .47881 L p .57465 .47886 L 0 0 1 r
F P
0 g
s
.57476 .47881 m .57986 .48126 L p .5758 .48185 L 0 0 1 r
F P
0 g
s
.59351 .48782 m .60075 .47063 L .61097 .46521 L p 0 1 0 r
F P
0 g
s
.59866 .47853 m .59087 .48655 L .57986 .48126 L p 0 0 1 r
F P
0 g
s
.60791 .45205 m .60075 .47063 L .59033 .47484 L p 0 1 0 r
F P
0 g
s
.59033 .47484 m .59761 .45743 L .60791 .45205 L p 0 1 0 r
F P
0 g
s
.57986 .48126 m .58763 .47321 L .59866 .47853 L p 0 0 1 r
F P
0 g
s
.58817 .48507 m .58001 .48469 L .57476 .47881 L p 1 0 0 r
F P
0 g
s
.57476 .47881 m .5747 .47874 L p .57474 .47876 L 1 0 0 r
F P
0 g
s
.57474 .47876 m .58817 .48507 L .57476 .47881 L 1 0 0 r
F
.56143 .49363 m .57464 .47881 L .57495 .48198 L 0 1 0 r
F
.57608 .48519 m .57228 .49281 L p .57499 .48207 L F P
0 g
s
.57228 .49281 m .56143 .49363 L p .57495 .48198 L 0 1 0 r
F P
0 g
s
.57495 .48198 m .57499 .48207 L .57228 .49281 L 0 1 0 r
F
.57608 .48519 m .57618 .48508 L p .57625 .48569 L 0 0 1 r
F P
0 g
s
.57608 .48519 m .57625 .48569 L .57659 .48862 L 0 0 1 r
F
.58001 .48469 m .59143 .49868 L p .57659 .48862 L 1 0 0 r
F P
0 g
s
.57658 .48852 m .58001 .48469 L .57659 .48862 L 1 0 0 r
F
.57228 .49281 m .57608 .48519 L p .57648 .48863 L 0 1 0 r
F P
0 g
s
.57618 .48508 m .57608 .48519 L p .576 .48456 L 0 0 1 r
F P
0 g
s
.5747 .47874 m .57424 .47823 L p .57348 .47522 L 1 0 0 r
F P
0 g
s
.57424 .47823 m .56866 .47198 L p .57348 .47522 L 1 0 0 r
F P
0 g
s
.56529 .45839 m .55395 .44686 L p .56827 .45469 L 1 0 0 r
F P
0 g
s
.56827 .45469 m .56869 .45492 L .56844 .45531 L 1 0 0 r
F
.56869 .45492 m .56873 .45503 L .56844 .45531 L F
.56827 .45469 m .56844 .45531 L .56529 .45839 L F
.57309 .45109 m .56977 .45787 L p .56869 .45492 L 0 1 0 r
F P
0 g
s
.56879 .45497 m .56889 .45527 L .56529 .45839 L 1 0 0 r
F
.57309 .45109 m .58385 .44811 L p .57067 .46134 L 0 1 0 r
F P
0 g
s
.57043 .46042 m .57309 .45109 L .57067 .46134 L 0 1 0 r
F
.56529 .45839 m .56977 .45787 L p .57029 .46172 L 1 0 0 r
F P
0 g
s
.56971 .45801 m .56977 .45787 L p .57016 .46137 L 0 1 0 r
F P
0 g
s
.56977 .45787 m .57309 .45109 L p .57022 .46117 L 0 1 0 r
F P
0 g
s
.56977 .45787 m .57022 .46117 L .57016 .46137 L 0 1 0 r
F
.57643 .4646 m .57302 .4715 L p .57194 .46848 L F P
0 g
s
.57643 .4646 m .58711 .4616 L p .57385 .47485 L 0 1 0 r
F P
0 g
s
.57373 .47434 m .57643 .4646 L .57385 .47485 L 0 1 0 r
F
.56866 .47198 m .57302 .4715 L p .57348 .47522 L 1 0 0 r
F P
0 g
s
.57346 .47513 m .57347 .4751 L .57348 .47522 L 0 1 0 r
F
.57347 .4751 m .57643 .4646 L .57348 .47522 L F
.57348 .47522 m .57385 .47486 L .5747 .47874 L F
.5747 .47874 m .57464 .47875 L p .57348 .47522 L F P
0 g
s
.57342 .47528 m .5736 .47579 L .5738 .47835 L 0 0 1 r
F
.57342 .47528 m .57348 .47522 L .57464 .47875 L 0 1 0 r
F
.57355 .47526 m .58763 .47321 L .57451 .47809 L 0 0 1 r
F
.57348 .47522 m .57355 .47526 L .5747 .47874 L 1 0 0 r
F
.57355 .47526 m .5746 .47833 L .5747 .47874 L F
.57355 .47526 m .57451 .47809 L .57393 .4783 L 0 0 1 r
F
.57355 .47526 m .5739 .47549 L .5746 .47833 L 1 0 0 r
F
.57355 .47526 m .57393 .4783 L .5738 .47835 L 0 0 1 r
F
.5746 .47833 m .57474 .47876 L .5747 .47874 L 1 0 0 r
F
.5747 .47879 m .5747 .47874 L .57471 .4788 L F
.5747 .47874 m .57476 .47881 L p .57471 .4788 L F P
0 g
s
.57476 .47881 m .5738 .47835 L p .57451 .47809 L 0 0 1 r
F P
0 g
s
.57451 .47809 m .57468 .47803 L .57476 .47881 L 0 0 1 r
F
.5739 .47549 m .58817 .48507 L .57474 .47876 L 1 0 0 r
F
.5739 .47549 m .57474 .47876 L .5746 .47833 L F
.5738 .47835 m .56881 .47595 L p .57342 .47528 L 0 0 1 r
F P
0 g
s
.57464 .47875 m .56895 .47975 L p .57342 .47528 L 0 1 0 r
F P
0 g
s
.57342 .47528 m .57355 .47526 L .5736 .47579 L 0 0 1 r
F
.57348 .47522 m .57354 .47515 L .57355 .47526 L 1 0 0 r
F
.57656 .46787 m .58763 .47321 L p .57438 .47514 L 0 0 1 r
F P
0 g
s
.57402 .47412 m .57656 .46787 L .57438 .47514 L 0 0 1 r
F
.57348 .47522 m .57373 .47434 L .57385 .47485 L 0 1 0 r
F
.57336 .47483 m .57643 .4646 L .57342 .47528 L F
.56881 .47595 m .57296 .47162 L p .57342 .47528 L 0 0 1 r
F P
0 g
s
.57244 .47267 m .57296 .47162 L p .57315 .47556 L 0 1 0 r
F P
0 g
s
.57296 .47162 m .57643 .4646 L p .57336 .47483 L 0 1 0 r
F P
0 g
s
.57296 .47162 m .57336 .47483 L .57315 .47556 L 0 1 0 r
F
.57302 .4715 m .57308 .4715 L p .57348 .47522 L 1 0 0 r
F P
0 g
s
.57308 .4715 m .57354 .47515 L .57348 .47522 L 1 0 0 r
F
.57342 .47528 m .57346 .47513 L .57348 .47522 L 0 1 0 r
F
.57342 .47528 m .57308 .4715 L .57355 .47526 L 0 0 1 r
F
.57296 .47162 m .57308 .4715 L p .57342 .47528 L F P
0 g
s
.57308 .4715 m .57656 .46787 L p .57355 .47526 L 0 0 1 r
F P
0 g
s
.57656 .46787 m .57308 .4715 L p .57203 .46853 L 0 0 1 r
F P
0 g
s
.57669 .4711 m .57308 .4715 L p .57232 .46869 L 1 0 0 r
F P
0 g
s
.57308 .4715 m .57302 .4715 L p .57287 .4709 L 1 0 0 r
F P
0 g
s
.57232 .46869 m .57308 .4715 L .57287 .4709 L 1 0 0 r
F
.57355 .47526 m .57402 .47412 L .57438 .47514 L 0 0 1 r
F
.57308 .4715 m .57669 .4711 L p .57354 .47515 L 1 0 0 r
F P
0 g
s
.57669 .4711 m .58817 .48507 L p .57355 .47526 L 1 0 0 r
F P
0 g
s
.57354 .47515 m .57669 .4711 L .57355 .47526 L 1 0 0 r
F
.59443 .44396 m .58711 .4616 L .57643 .4646 L p 0 1 0 r
F P
0 g
s
.57643 .4646 m .58385 .44811 L .59443 .44396 L p 0 1 0 r
F P
0 g
s
.58385 .44811 m .57643 .4646 L .5716 .46543 L p 0 1 0 r
F P
0 g
s
.57158 .46537 m .58385 .44811 L .5716 .46543 L 0 1 0 r
F
.57029 .46172 m .57147 .46505 L .57111 .46488 L 1 0 0 r
F
.55738 .46046 m .5716 .46543 L .57161 .46549 L F
.5716 .46543 m .57643 .4646 L p .57194 .46848 L 0 1 0 r
F P
0 g
s
.55738 .46046 m .57167 .46551 L .57203 .46853 L 1 0 0 r
F
.56866 .47198 m .55738 .46046 L p .57154 .46826 L F P
0 g
s
.57154 .46826 m .57167 .46878 L .56866 .47198 L 1 0 0 r
F
.57194 .46848 m .57198 .46858 L .56866 .47198 L F
.57203 .46853 m .57214 .46885 L .56866 .47198 L F
.57302 .4715 m .56866 .47198 L p .57232 .46869 L F P
0 g
s
.56866 .47198 m .56078 .47398 L .5496 .46357 L p 1 0 0 r
F P
0 g
s
.5496 .46357 m .55738 .46046 L .56866 .47198 L p 1 0 0 r
F P
0 g
s
.56881 .47595 m .55771 .47062 L p .57186 .46855 L 0 0 1 r
F P
0 g
s
.57302 .4715 m .57296 .47162 L p .57194 .46848 L 0 1 0 r
F P
0 g
s
.57186 .46855 m .57193 .46875 L .57189 .46884 L 0 0 1 r
F
.57186 .46855 m .57189 .46884 L .56881 .47595 L F
.57194 .46848 m .57296 .47162 L .5719 .46865 L 0 1 0 r
F
.57308 .4715 m .57296 .47162 L p .57203 .46853 L 0 0 1 r
F P
0 g
s
.57296 .47162 m .56881 .47595 L p .57193 .46875 L 0 0 1 r
F P
0 g
s
.57203 .46853 m .57296 .47162 L .57193 .46875 L 0 0 1 r
F
.56881 .47595 m .56111 .48399 L .55003 .47869 L p F P
0 g
s
.55302 .47701 m .54537 .481 L .53435 .47258 L p 1 0 0 r
F P
0 g
s
.53435 .47258 m .54193 .46763 L .55302 .47701 L p 1 0 0 r
F P
0 g
s
.56078 .47398 m .55302 .47701 L .54193 .46763 L p 1 0 0 r
F P
0 g
s
.54193 .46763 m .5496 .46357 L .56078 .47398 L p 1 0 0 r
F P
0 g
s
.55003 .47869 m .55771 .47062 L .56881 .47595 L p 0 0 1 r
F P
0 g
s
.56895 .47975 m .55802 .48053 L p .57186 .46855 L 0 1 0 r
F P
0 g
s
.57186 .46855 m .57194 .46848 L .5719 .46865 L 0 1 0 r
F
.57186 .46855 m .5719 .46865 L .56895 .47975 L F
.57296 .47162 m .56895 .47975 L p .5719 .46865 L F P
0 g
s
.57186 .46855 m .57203 .46853 L .57193 .46875 L 0 0 1 r
F
.57186 .46855 m .5716 .46543 L .57194 .46848 L 0 1 0 r
F
.57154 .46826 m .57194 .46848 L .57167 .46878 L 1 0 0 r
F
.57153 .4655 m .5716 .46543 L .57186 .46855 L 0 1 0 r
F
.55738 .46046 m .56529 .45839 L .5716 .46543 L p 1 0 0 r
F P
0 g
s
.55771 .47062 m .56543 .4625 L .57153 .46544 L p 0 0 1 r
F P
0 g
s
.57153 .46544 m .5716 .46543 L p .57153 .4655 L 0 1 0 r
F P
0 g
s
.57194 .46848 m .57203 .46853 L .57198 .46858 L 1 0 0 r
F
.57153 .46544 m .57656 .46787 L p .57186 .46855 L 0 0 1 r
F P
0 g
s
.55771 .47062 m .57153 .46544 L .57186 .46855 L 0 0 1 r
F
.55802 .48053 m .56557 .46646 L .57153 .46544 L p 0 1 0 r
F P
0 g
s
.55802 .48053 m .57153 .46544 L .57153 .4655 L 0 1 0 r
F
.55802 .48053 m .57153 .4655 L .57186 .46855 L F
.5716 .46543 m .57167 .46551 L p .57161 .46549 L 1 0 0 r
F P
0 g
s
.57167 .46551 m .57669 .4711 L p .57203 .46853 L 1 0 0 r
F P
0 g
s
.57022 .4618 m .57029 .46172 L .57153 .46544 L 0 1 0 r
F
.57029 .46172 m .58385 .44811 L .57158 .46537 L F
.57029 .46172 m .57158 .46537 L .57153 .46544 L F
.57029 .46172 m .57037 .46178 L .57147 .46505 L 1 0 0 r
F
.57037 .46178 m .57122 .46165 L .57093 .46338 L 0 0 1 r
F
.57122 .46165 m .58436 .45972 L .57157 .46466 L F
.57037 .46178 m .57152 .46508 L .57147 .46505 L 1 0 0 r
F
.57111 .46488 m .56529 .45839 L p .57029 .46172 L F P
0 g
s
.57122 .46165 m .57157 .46466 L .5708 .46496 L 0 0 1 r
F
.57074 .4645 m .5708 .46496 L .57065 .46502 L F
.57122 .46165 m .5708 .46496 L .57074 .4645 L F
.58436 .45972 m .57656 .46787 L .57167 .46551 L p F P
0 g
s
.5714 .46473 m .58436 .45972 L .57167 .46551 L 0 0 1 r
F
.59545 .46511 m .58763 .47321 L .57656 .46787 L p F P
0 g
s
.6048 .4386 m .59761 .45743 L .58711 .4616 L p 0 1 0 r
F P
0 g
s
.58711 .4616 m .59443 .44396 L .6048 .4386 L p 0 1 0 r
F P
0 g
s
.57656 .46787 m .58436 .45972 L .59545 .46511 L p 0 0 1 r
F P
0 g
s
.57029 .46172 m .57035 .46164 L .57037 .46178 L 1 0 0 r
F
.57029 .46172 m .57043 .46042 L .57067 .46134 L 0 1 0 r
F
.57022 .4618 m .57025 .46157 L .57029 .46172 L F
.57025 .46157 m .57043 .46042 L .57029 .46172 L F
.57016 .46137 m .57043 .46042 L .57022 .4618 L F
.57322 .45432 m .58436 .45972 L p .57122 .46165 L 0 0 1 r
F P
0 g
s
.57083 .46057 m .57322 .45432 L .57122 .46165 L 0 0 1 r
F
.56984 .45786 m .57322 .45432 L p .57037 .46178 L F P
0 g
s
.57322 .45432 m .56984 .45786 L p .56959 .45718 L 0 0 1 r
F P
0 g
s
.56879 .45497 m .56929 .4549 L .56959 .45718 L 0 0 1 r
F
.56929 .4549 m .57322 .45432 L .56959 .45718 L F
.57334 .45746 m .56984 .45786 L p .56906 .45512 L 1 0 0 r
F P
0 g
s
.56984 .45786 m .56977 .45787 L p .56959 .45718 L 1 0 0 r
F P
0 g
s
.56906 .45512 m .56984 .45786 L .56959 .45718 L 1 0 0 r
F
.57037 .46178 m .57083 .46057 L .57122 .46165 L 0 0 1 r
F
.56977 .45787 m .56984 .45786 L p .57029 .46172 L 1 0 0 r
F P
0 g
s
.56984 .45786 m .57035 .46164 L .57029 .46172 L 1 0 0 r
F
.56977 .45787 m .56529 .45839 L p .56884 .45532 L F P
0 g
s
.56906 .45512 m .56977 .45787 L .56884 .45532 L 1 0 0 r
F
.56977 .45787 m .56971 .45801 L p .56869 .45492 L 0 1 0 r
F P
0 g
s
.56543 .4625 m .56971 .45801 L p .57037 .46178 L 0 0 1 r
F P
0 g
s
.57065 .46502 m .56543 .4625 L p .57022 .4618 L 0 0 1 r
F P
0 g
s
.5686 .455 m .56868 .45521 L .56543 .4625 L 0 0 1 r
F
.56869 .45492 m .56971 .45801 L .56864 .45511 L 0 1 0 r
F
.56984 .45786 m .56543 .4625 L p .56879 .45497 L 0 0 1 r
F P
0 g
s
.56971 .45801 m .56557 .46646 L p .56864 .45511 L 0 1 0 r
F P
0 g
s
.56971 .45801 m .56984 .45786 L p .56995 .45868 L 0 0 1 r
F P
0 g
s
.56971 .45801 m .56995 .45868 L .57037 .46178 L 0 0 1 r
F
.56984 .45786 m .57334 .45746 L p .57035 .46164 L 1 0 0 r
F P
0 g
s
.57334 .45746 m .58487 .47143 L p .57037 .46178 L 1 0 0 r
F P
0 g
s
.57035 .46164 m .57334 .45746 L .57037 .46178 L 1 0 0 r
F
.57037 .46178 m .58487 .47143 L .57152 .46508 L F
.57022 .4618 m .57037 .46178 L .57065 .46502 L 0 0 1 r
F
.57037 .46178 m .57093 .46338 L .57065 .46502 L F
.57167 .46551 m .5716 .46543 L p .57152 .46508 L 1 0 0 r
F P
0 g
s
.5716 .46543 m .57111 .46488 L p .57147 .46505 L 1 0 0 r
F P
0 g
s
.57147 .46505 m .57152 .46508 L .5716 .46543 L 1 0 0 r
F
.5716 .46543 m .57153 .46544 L p .57158 .46537 L 0 1 0 r
F P
0 g
s
.57153 .46544 m .57065 .46502 L p .57129 .46477 L 0 0 1 r
F P
0 g
s
.57153 .46544 m .56557 .46646 L p .57022 .4618 L 0 1 0 r
F P
0 g
s
.57167 .46551 m .57153 .46544 L p .5714 .46473 L 0 0 1 r
F P
0 g
s
.57129 .46477 m .5714 .46473 L .57153 .46544 L 0 0 1 r
F
.58487 .47143 m .57669 .4711 L .57167 .46551 L p 1 0 0 r
F P
0 g
s
.57152 .46508 m .58487 .47143 L .57167 .46551 L 1 0 0 r
F
.56997 .46205 m .57016 .46137 L .57022 .4618 L 0 1 0 r
F
.5692 .45903 m .56971 .45801 L p .56997 .46205 L F P
0 g
s
.56971 .45801 m .57016 .46137 L .56997 .46205 L 0 1 0 r
F
.56529 .45839 m .55738 .46046 L .54614 .45003 L p 1 0 0 r
F P
0 g
s
.54614 .45003 m .55395 .44686 L .56529 .45839 L p 1 0 0 r
F P
0 g
s
.56543 .4625 m .55426 .45711 L p .5686 .455 L 0 0 1 r
F P
0 g
s
.5686 .455 m .56869 .45492 L .56864 .45511 L 0 1 0 r
F
.5686 .455 m .56879 .45497 L .56868 .45521 L 0 0 1 r
F
.56543 .4625 m .55771 .47062 L .54655 .46527 L p F P
0 g
s
.5496 .46357 m .54193 .46763 L .53084 .4592 L p 1 0 0 r
F P
0 g
s
.53084 .4592 m .53844 .45417 L .5496 .46357 L p 1 0 0 r
F P
0 g
s
.55738 .46046 m .5496 .46357 L .53844 .45417 L p 1 0 0 r
F P
0 g
s
.53844 .45417 m .54614 .45003 L .55738 .46046 L p 1 0 0 r
F P
0 g
s
.54655 .46527 m .55426 .45711 L .56543 .4625 L p 0 0 1 r
F P
0 g
s
.56557 .46646 m .55457 .46721 L p .5686 .455 L 0 1 0 r
F P
0 g
s
.5686 .455 m .56864 .45511 L .56557 .46646 L 0 1 0 r
F
.56869 .45492 m .56879 .45497 L .56873 .45503 L 1 0 0 r
F
.56188 .44474 m .55047 .43318 L p .56485 .44099 L F P
0 g
s
.56485 .44099 m .56527 .44122 L .56503 .44162 L 1 0 0 r
F
.56527 .44122 m .56531 .44134 L .56503 .44162 L F
.56485 .44099 m .56503 .44162 L .56188 .44474 L F
.56971 .43732 m .56638 .44419 L p .56527 .44122 L 0 1 0 r
F P
0 g
s
.56538 .44128 m .56548 .44156 L .56188 .44474 L 1 0 0 r
F
.56971 .43732 m .58055 .43435 L p .56732 .44771 L 0 1 0 r
F P
0 g
s
.56708 .44679 m .56971 .43732 L .56732 .44771 L 0 1 0 r
F
.56188 .44474 m .56638 .44419 L p .56695 .44809 L 1 0 0 r
F P
0 g
s
.56631 .44435 m .56638 .44419 L p .56681 .44778 L 0 1 0 r
F P
0 g
s
.56638 .44419 m .56971 .43732 L p .56687 .44755 L 0 1 0 r
F P
0 g
s
.56638 .44419 m .56687 .44755 L .56681 .44778 L 0 1 0 r
F
.5912 .4302 m .58385 .44811 L .57309 .45109 L p F P
0 g
s
.57309 .45109 m .58055 .43435 L .5912 .4302 L p 0 1 0 r
F P
0 g
s
.5683 .45182 m .58055 .43435 L .56832 .45189 L 0 1 0 r
F
.55395 .44686 m .56188 .44474 L .56832 .45189 L p 1 0 0 r
F P
0 g
s
.56832 .45189 m .57309 .45109 L p .56904 .45461 L 0 1 0 r
F P
0 g
s
.56869 .45492 m .56832 .45189 L .56904 .45461 L 0 1 0 r
F
.56695 .44809 m .56762 .44994 L .56782 .45133 L 1 0 0 r
F
.56695 .44809 m .58055 .43435 L .5683 .45182 L 0 1 0 r
F
.58055 .43435 m .57309 .45109 L .56832 .45189 L p F P
0 g
s
.56811 .45116 m .58105 .44608 L .56841 .45199 L 0 0 1 r
F
.56758 .44966 m .56822 .45152 L .56782 .45133 L 1 0 0 r
F
.56704 .44815 m .58105 .44608 L .56811 .45116 L 0 0 1 r
F
.56739 .44838 m .56817 .45132 L .56758 .44966 L 1 0 0 r
F
.56817 .45132 m .56822 .45152 L .56758 .44966 L F
.55395 .44686 m .56832 .45189 L .56869 .45492 L F
.56686 .44818 m .56695 .44809 L .56824 .45191 L 0 1 0 r
F
.56782 .45133 m .56188 .44474 L p .56695 .44809 L 1 0 0 r
F P
0 g
s
.56686 .44818 m .56704 .44815 L .56734 .45147 L 0 0 1 r
F
.56695 .44809 m .5683 .45182 L .56824 .45191 L 0 1 0 r
F
.56704 .44815 m .56811 .45116 L .56734 .45147 L 0 0 1 r
F
.56695 .44809 m .56708 .44679 L .56732 .44771 L 0 1 0 r
F
.56983 .44062 m .58105 .44608 L p .5679 .44802 L 0 0 1 r
F P
0 g
s
.56749 .44693 m .56983 .44062 L .5679 .44802 L 0 0 1 r
F
.5669 .44793 m .56708 .44679 L .56695 .44809 L 0 1 0 r
F
.56681 .44778 m .56708 .44679 L .56686 .44818 L F
.56646 .44418 m .56983 .44062 L p .56704 .44815 L 0 0 1 r
F P
0 g
s
.56704 .44815 m .56749 .44693 L .5679 .44802 L 0 0 1 r
F
.56638 .44419 m .56995 .44376 L p .56695 .44809 L 1 0 0 r
F P
0 g
s
.56638 .44419 m .56188 .44474 L p .56542 .44162 L 1 0 0 r
F P
0 g
s
.56538 .44128 m .56586 .4412 L .56617 .44341 L 0 0 1 r
F
.56564 .44142 m .56638 .44419 L .56542 .44162 L 1 0 0 r
F
.56638 .44419 m .56631 .44435 L p .56527 .44122 L 0 1 0 r
F P
0 g
s
.56585 .44484 m .56631 .44435 L p .56704 .44815 L 0 0 1 r
F P
0 g
s
.56695 .44809 m .56701 .44799 L .56704 .44815 L 1 0 0 r
F
.56695 .44809 m .56704 .44815 L .56762 .44994 L F
.56686 .44818 m .5669 .44793 L .56695 .44809 L 0 1 0 r
F
.56202 .44889 m .56585 .44484 L p .56704 .44815 L 0 0 1 r
F P
0 g
s
.56734 .45147 m .56202 .44889 L p .56686 .44818 L 0 0 1 r
F P
0 g
s
.56517 .44131 m .56526 .44155 L .56202 .44889 L 0 0 1 r
F
.56527 .44122 m .56631 .44435 L .56521 .44143 L 0 1 0 r
F
.56646 .44418 m .56638 .44419 L p .56617 .44341 L 1 0 0 r
F P
0 g
s
.56646 .44418 m .56202 .44889 L p .56538 .44128 L 0 0 1 r
F P
0 g
s
.56832 .45189 m .56841 .45199 L p .56869 .45492 L 1 0 0 r
F P
0 g
s
.56824 .45191 m .56832 .45189 L p .5686 .455 L 0 1 0 r
F P
0 g
s
.5686 .455 m .56832 .45189 L .56869 .45492 L 0 1 0 r
F
.55426 .45711 m .56202 .44889 L .56841 .45199 L p 0 0 1 r
F P
0 g
s
.56841 .45199 m .57322 .45432 L p .56879 .45497 L 0 0 1 r
F P
0 g
s
.56869 .45492 m .56841 .45199 L .56879 .45497 L 1 0 0 r
F
.55426 .45711 m .56841 .45199 L .56879 .45497 L 0 0 1 r
F
.56841 .45199 m .57334 .45746 L p .56879 .45497 L 1 0 0 r
F P
0 g
s
.56631 .44435 m .56216 .45293 L p .56521 .44143 L 0 1 0 r
F P
0 g
s
.56631 .44435 m .56646 .44418 L p .5666 .44511 L 0 0 1 r
F P
0 g
s
.56631 .44435 m .5666 .44511 L .56704 .44815 L 0 0 1 r
F
.58105 .44608 m .57322 .45432 L .56841 .45199 L p F P
0 g
s
.59222 .45153 m .58436 .45972 L .57322 .45432 L p 0 0 1 r
F P
0 g
s
.60166 .42485 m .59443 .44396 L .58385 .44811 L p 0 1 0 r
F P
0 g
s
.58385 .44811 m .5912 .4302 L .60166 .42485 L p 0 1 0 r
F P
0 g
s
.57322 .45432 m .58105 .44608 L .59222 .45153 L p 0 0 1 r
F P
0 g
s
.56995 .44376 m .58155 .45774 L p .56704 .44815 L 1 0 0 r
F P
0 g
s
.56701 .44799 m .56995 .44376 L .56704 .44815 L 1 0 0 r
F
.56983 .44062 m .56646 .44418 L p .56617 .44341 L 0 0 1 r
F P
0 g
s
.56586 .4412 m .56983 .44062 L .56617 .44341 L 0 0 1 r
F
.56995 .44376 m .56646 .44418 L p .56564 .44142 L 1 0 0 r
F P
0 g
s
.56564 .44142 m .56646 .44418 L .56617 .44341 L 1 0 0 r
F
.56704 .44815 m .56739 .44838 L .56758 .44966 L F
.56704 .44815 m .56758 .44966 L .56762 .44994 L F
.56739 .44838 m .58155 .45774 L .56822 .45152 L F
.55457 .46721 m .56216 .45293 L .56824 .45191 L p 0 1 0 r
F P
0 g
s
.55457 .46721 m .56824 .45191 L .5686 .455 L 0 1 0 r
F
.56824 .45191 m .56811 .45116 L .56817 .45132 L 0 0 1 r
F
.56841 .45199 m .56832 .45189 L p .56825 .45153 L 1 0 0 r
F P
0 g
s
.56818 .4515 m .56825 .45153 L .56832 .45189 L 1 0 0 r
F
.56832 .45189 m .56824 .45191 L p .5683 .45182 L 0 1 0 r
F P
0 g
s
.56841 .45199 m .56824 .45191 L p .56817 .45132 L 0 0 1 r
F P
0 g
s
.56832 .45189 m .56782 .45133 L p .56818 .4515 L 1 0 0 r
F P
0 g
s
.56824 .45191 m .56734 .45147 L p .56798 .45122 L 0 0 1 r
F P
0 g
s
.56824 .45191 m .56216 .45293 L p .56686 .44818 L 0 1 0 r
F P
0 g
s
.56798 .45122 m .56811 .45116 L .56824 .45191 L 0 0 1 r
F
.58155 .45774 m .57334 .45746 L .56841 .45199 L p 1 0 0 r
F P
0 g
s
.56825 .45153 m .58155 .45774 L .56841 .45199 L 1 0 0 r
F
.56663 .44841 m .56681 .44778 L .56686 .44818 L 0 1 0 r
F
.56583 .44535 m .56631 .44435 L p .56663 .44841 L F P
0 g
s
.56631 .44435 m .56681 .44778 L .56663 .44841 L 0 1 0 r
F
.56188 .44474 m .55395 .44686 L .54264 .4364 L p 1 0 0 r
F P
0 g
s
.54264 .4364 m .55047 .43318 L .56188 .44474 L p 1 0 0 r
F P
0 g
s
.56202 .44889 m .55077 .44343 L p .56517 .44131 L 0 0 1 r
F P
0 g
s
.56517 .44131 m .56527 .44122 L .56521 .44143 L 0 1 0 r
F
.56517 .44131 m .56538 .44128 L .56526 .44155 L 0 0 1 r
F
.54614 .45003 m .53844 .45417 L .52729 .4457 L p 1 0 0 r
F P
0 g
s
.56202 .44889 m .55426 .45711 L .54303 .45169 L p 0 0 1 r
F P
0 g
s
.52729 .4457 m .53492 .4406 L .54614 .45003 L p 1 0 0 r
F P
0 g
s
.55395 .44686 m .54614 .45003 L .53492 .4406 L p 1 0 0 r
F P
0 g
s
.53492 .4406 m .54264 .4364 L .55395 .44686 L p 1 0 0 r
F P
0 g
s
.54303 .45169 m .55077 .44343 L .56202 .44889 L p 0 0 1 r
F P
0 g
s
.56216 .45293 m .55107 .45367 L p .56517 .44131 L 0 1 0 r
F P
0 g
s
.56517 .44131 m .56521 .44143 L .56216 .45293 L 0 1 0 r
F
.56527 .44122 m .56538 .44128 L .56531 .44134 L 1 0 0 r
F
.55843 .43102 m .54696 .41941 L p .56127 .42716 L F P
0 g
s
.56127 .42716 m .56167 .42738 L .56145 .42781 L 1 0 0 r
F
.56167 .42738 m .56173 .42752 L .56145 .42781 L F
.56127 .42716 m .56145 .42781 L .55843 .43102 L F
.56629 .42329 m .56286 .43047 L p .56167 .42738 L 0 1 0 r
F P
0 g
s
.56179 .42744 m .5619 .42773 L .55843 .43102 L 1 0 0 r
F
.56629 .42329 m .57721 .42031 L p .56382 .43394 L 0 1 0 r
F P
0 g
s
.56357 .43306 m .56629 .42329 L .56382 .43394 L 0 1 0 r
F
.58794 .41615 m .58055 .43435 L .56971 .43732 L p F P
0 g
s
.56971 .43732 m .57721 .42031 L .58794 .41615 L p 0 1 0 r
F P
0 g
s
.57721 .42031 m .56971 .43732 L .56486 .43813 L p 0 1 0 r
F P
0 g
s
.55047 .43318 m .55843 .43102 L .56486 .43813 L p 1 0 0 r
F P
0 g
s
.56486 .43813 m .56971 .43732 L p .56563 .4409 L 0 1 0 r
F P
0 g
s
.56527 .44122 m .56486 .43813 L .56563 .4409 L 0 1 0 r
F
.5777 .43229 m .56983 .44062 L .56496 .43824 L p 0 0 1 r
F P
0 g
s
.56383 .43394 m .57721 .42031 L .56486 .43813 L 0 1 0 r
F
.56484 .43733 m .5777 .43229 L .56496 .43824 L 0 0 1 r
F
.58894 .43779 m .58105 .44608 L .56983 .44062 L p F P
0 g
s
.55047 .43318 m .56486 .43813 L .56487 .43821 L 1 0 0 r
F
.55047 .43318 m .56496 .43824 L .56538 .44128 L F
.55077 .44343 m .55857 .43512 L .56477 .43815 L p 0 0 1 r
F P
0 g
s
.55077 .44343 m .56477 .43815 L .56479 .43831 L 0 0 1 r
F
.56517 .44131 m .56486 .43813 L .56527 .44122 L 0 1 0 r
F
.56517 .44131 m .56496 .43824 L .56604 .44118 L 0 0 1 r
F
.55077 .44343 m .56479 .43831 L .56517 .44131 L F
.56478 .43823 m .56486 .43813 L .56517 .44131 L 0 1 0 r
F
.56479 .43831 m .56496 .43824 L .56517 .44131 L 0 0 1 r
F
.55107 .45367 m .56478 .43823 L .56517 .44131 L 0 1 0 r
F
.55107 .45367 m .5587 .43916 L .56477 .43815 L p F P
0 g
s
.56477 .43815 m .56486 .43813 L p .56478 .43823 L 0 1 0 r
F P
0 g
s
.55107 .45367 m .56477 .43815 L .56478 .43823 L 0 1 0 r
F
.56477 .43815 m .56496 .43824 L p .56479 .43831 L 0 0 1 r
F P
0 g
s
.56496 .43824 m .56983 .44062 L p .56604 .44118 L 0 0 1 r
F P
0 g
s
.59847 .4108 m .5912 .4302 L .58055 .43435 L p 0 1 0 r
F P
0 g
s
.58055 .43435 m .58794 .41615 L .59847 .4108 L p 0 1 0 r
F P
0 g
s
.56983 .44062 m .5777 .43229 L .58894 .43779 L p 0 0 1 r
F P
0 g
s
.57819 .44402 m .56995 .44376 L .56496 .43824 L p 1 0 0 r
F P
0 g
s
.56496 .43824 m .56486 .43813 L p .56493 .43816 L 1 0 0 r
F P
0 g
s
.56493 .43816 m .57819 .44402 L .56496 .43824 L 1 0 0 r
F
.56486 .43813 m .55843 .43102 L p .56345 .43432 L F P
0 g
s
.5648 .43779 m .56484 .43733 L .56496 .43824 L 0 0 1 r
F
.56345 .43432 m .56383 .43394 L .56486 .43813 L 0 1 0 r
F
.56486 .43813 m .56477 .43815 L p .56345 .43432 L F P
0 g
s
.56336 .43441 m .56345 .43432 L .56477 .43815 L 0 1 0 r
F
.56336 .43441 m .56355 .43439 L .56387 .43771 L 0 0 1 r
F
.56355 .43439 m .5777 .43229 L .56465 .4374 L F
.56345 .43432 m .56355 .43439 L .56486 .43813 L 1 0 0 r
F
.56355 .43439 m .56468 .43747 L .56486 .43813 L F
.56355 .43439 m .56465 .4374 L .56387 .43771 L 0 0 1 r
F
.56355 .43439 m .56389 .43461 L .56468 .43747 L 1 0 0 r
F
.56389 .43461 m .57819 .44402 L .56493 .43816 L F
.56468 .43747 m .56493 .43816 L .56486 .43813 L F
.56389 .43461 m .56493 .43816 L .56468 .43747 L F
.56487 .43821 m .56486 .43813 L .56488 .43821 L F
.56486 .43813 m .56496 .43824 L p .56488 .43821 L F P
0 g
s
.56496 .43824 m .56477 .43815 L p .5648 .43779 L 0 0 1 r
F P
0 g
s
.56477 .43815 m .56387 .43771 L p .56451 .43746 L 0 0 1 r
F P
0 g
s
.56451 .43746 m .56484 .43733 L .56477 .43815 L 0 0 1 r
F
.56387 .43771 m .55857 .43512 L p .56336 .43441 L F P
0 g
s
.56477 .43815 m .5587 .43916 L p .56336 .43441 L 0 1 0 r
F P
0 g
s
.56496 .43824 m .56995 .44376 L p .56538 .44128 L 1 0 0 r
F P
0 g
s
.56345 .43432 m .56357 .43306 L .56382 .43394 L 0 1 0 r
F
.56641 .42676 m .5777 .43229 L p .5644 .43426 L 0 0 1 r
F P
0 g
s
.56399 .4332 m .56641 .42676 L .5644 .43426 L 0 0 1 r
F
.56341 .43407 m .56357 .43306 L .56345 .43432 L 0 1 0 r
F
.55843 .43102 m .56286 .43047 L p .56345 .43432 L 1 0 0 r
F P
0 g
s
.56277 .43064 m .56629 .42329 L p .5633 .43404 L 0 1 0 r
F P
0 g
s
.56294 .43046 m .56641 .42676 L p .56355 .43439 L 0 0 1 r
F P
0 g
s
.56641 .42676 m .56294 .43046 L p .56179 .42744 L 0 0 1 r
F P
0 g
s
.56206 .42759 m .56443 .42887 L .56294 .43046 L 1 0 0 r
F
.56443 .42887 m .56653 .43001 L .56294 .43046 L F
.56294 .43046 m .56286 .43047 L p .56261 .42958 L F P
0 g
s
.56206 .42759 m .56294 .43046 L .56261 .42958 L 1 0 0 r
F
.56355 .43439 m .56399 .4332 L .5644 .43426 L 0 0 1 r
F
.56345 .43432 m .56352 .43422 L .56355 .43439 L 1 0 0 r
F
.5633 .43404 m .56357 .43306 L .56336 .43441 L 0 1 0 r
F
.56286 .43047 m .56653 .43001 L p .56345 .43432 L 1 0 0 r
F P
0 g
s
.56336 .43441 m .56341 .43407 L .56345 .43432 L 0 1 0 r
F
.56286 .43047 m .55843 .43102 L p .56183 .4278 L 1 0 0 r
F P
0 g
s
.56206 .42759 m .56286 .43047 L .56183 .4278 L 1 0 0 r
F
.56286 .43047 m .56277 .43064 L p .56167 .42738 L 0 1 0 r
F P
0 g
s
.55857 .43512 m .56277 .43064 L p .56355 .43439 L 0 0 1 r
F P
0 g
s
.56167 .42738 m .56277 .43064 L .56161 .42762 L 0 1 0 r
F
.56179 .42744 m .56261 .42958 L .55857 .43512 L 0 0 1 r
F
.56277 .43064 m .55857 .43512 L p .56261 .42958 L F P
0 g
s
.56156 .42748 m .56166 .42775 L .55857 .43512 L 0 0 1 r
F
.56277 .43064 m .5587 .43916 L p .56161 .42762 L 0 1 0 r
F P
0 g
s
.56277 .43064 m .56294 .43046 L p .56311 .4315 L 0 0 1 r
F P
0 g
s
.56277 .43064 m .56311 .4315 L .56355 .43439 L 0 0 1 r
F
.56653 .43001 m .57819 .44402 L p .56355 .43439 L 1 0 0 r
F P
0 g
s
.56352 .43422 m .56653 .43001 L .56355 .43439 L 1 0 0 r
F
.56313 .43465 m .5633 .43404 L .56336 .43441 L 0 1 0 r
F
.56231 .43162 m .56277 .43064 L p .56313 .43465 L F P
0 g
s
.56277 .43064 m .5633 .43404 L .56313 .43465 L 0 1 0 r
F
.56294 .43046 m .56277 .43064 L p .56261 .42958 L 0 0 1 r
F P
0 g
s
.55843 .43102 m .55047 .43318 L .53911 .42268 L p 1 0 0 r
F P
0 g
s
.53911 .42268 m .54696 .41941 L .55843 .43102 L p 1 0 0 r
F P
0 g
s
.55857 .43512 m .54725 .42961 L p .56156 .42748 L 0 0 1 r
F P
0 g
s
.56156 .42748 m .56167 .42738 L .56161 .42762 L 0 1 0 r
F
.56156 .42748 m .56179 .42744 L .56166 .42775 L 0 0 1 r
F
.54264 .4364 m .53492 .4406 L .5237 .4321 L p 1 0 0 r
F P
0 g
s
.55857 .43512 m .55077 .44343 L .53948 .43796 L p 0 0 1 r
F P
0 g
s
.5237 .4321 m .53136 .42693 L .54264 .4364 L p 1 0 0 r
F P
0 g
s
.55047 .43318 m .54264 .4364 L .53136 .42693 L p 1 0 0 r
F P
0 g
s
.53136 .42693 m .53911 .42268 L .55047 .43318 L p 1 0 0 r
F P
0 g
s
.53948 .43796 m .54725 .42961 L .55857 .43512 L p 0 0 1 r
F P
0 g
s
.5587 .43916 m .54754 .4399 L p .56156 .42748 L 0 1 0 r
F P
0 g
s
.56156 .42748 m .56161 .42762 L .5587 .43916 L 0 1 0 r
F
.56167 .42738 m .56179 .42744 L .56173 .42752 L 1 0 0 r
F
.58463 .40181 m .57721 .42031 L .56629 .42329 L p 0 1 0 r
F P
0 g
s
.56629 .42329 m .57382 .40599 L .58463 .40181 L p 0 1 0 r
F P
0 g
s
.57382 .40599 m .56629 .42329 L .56121 .42414 L p 0 1 0 r
F P
0 g
s
.54696 .41941 m .55495 .41722 L .56121 .42414 L p 1 0 0 r
F P
0 g
s
.56121 .42414 m .56629 .42329 L p .56204 .42705 L 0 1 0 r
F P
0 g
s
.56167 .42738 m .56121 .42414 L .56204 .42705 L 0 1 0 r
F
.57431 .41833 m .56641 .42676 L .56133 .42427 L p 0 0 1 r
F P
0 g
s
.56016 .42003 m .57382 .40599 L .56121 .42414 L 0 1 0 r
F
.5612 .42335 m .57431 .41833 L .56133 .42427 L 0 0 1 r
F
.58562 .4239 m .5777 .43229 L .56641 .42676 L p F P
0 g
s
.54696 .41941 m .56121 .42414 L .56123 .42423 L 1 0 0 r
F
.54696 .41941 m .56133 .42427 L .56179 .42744 L F
.54725 .42961 m .55507 .4212 L .5611 .42415 L p 0 0 1 r
F P
0 g
s
.54725 .42961 m .5611 .42415 L .56113 .42434 L 0 0 1 r
F
.56156 .42748 m .56121 .42414 L .56167 .42738 L 0 1 0 r
F
.56156 .42748 m .56133 .42427 L .56248 .42734 L 0 0 1 r
F
.54725 .42961 m .56113 .42434 L .56156 .42748 L F
.56111 .42425 m .56121 .42414 L .56156 .42748 L 0 1 0 r
F
.56113 .42434 m .56133 .42427 L .56156 .42748 L 0 0 1 r
F
.54754 .4399 m .56111 .42425 L .56156 .42748 L 0 1 0 r
F
.54754 .4399 m .5552 .42514 L .5611 .42415 L p F P
0 g
s
.5611 .42415 m .56121 .42414 L p .56111 .42425 L 0 1 0 r
F P
0 g
s
.54754 .4399 m .5611 .42415 L .56111 .42425 L 0 1 0 r
F
.5611 .42415 m .56133 .42427 L p .56113 .42434 L 0 0 1 r
F P
0 g
s
.56133 .42427 m .56641 .42676 L p .56248 .42734 L 0 0 1 r
F P
0 g
s
.59523 .39644 m .58794 .41615 L .57721 .42031 L p 0 1 0 r
F P
0 g
s
.57721 .42031 m .58463 .40181 L .59523 .39644 L p 0 1 0 r
F P
0 g
s
.56641 .42676 m .57431 .41833 L .58562 .4239 L p 0 0 1 r
F P
0 g
s
.57479 .43025 m .56653 .43001 L .56133 .42427 L p 1 0 0 r
F P
0 g
s
.56133 .42427 m .56121 .42414 L p .56129 .42417 L 1 0 0 r
F P
0 g
s
.56129 .42417 m .57479 .43025 L .56133 .42427 L 1 0 0 r
F
.56121 .42414 m .56071 .42359 L p .5598 .42041 L F P
0 g
s
.56071 .42359 m .55495 .41722 L p .5598 .42041 L 1 0 0 r
F P
0 g
s
.55495 .41722 m .54342 .40556 L p .55752 .4132 L 1 0 0 r
F P
0 g
s
.55752 .4132 m .5579 .4134 L .55772 .41386 L 1 0 0 r
F
.55752 .4132 m .55772 .41386 L .55495 .41722 L F
.56282 .40899 m .55919 .41669 L p .5579 .4134 L 0 1 0 r
F P
0 g
s
.55804 .41347 m .55816 .41378 L .55495 .41722 L 1 0 0 r
F
.56282 .40899 m .57382 .40599 L p .56015 .42005 L 0 1 0 r
F P
0 g
s
.56002 .41958 m .56282 .40899 L .56015 .42005 L 0 1 0 r
F
.55495 .41722 m .55919 .41669 L p .5598 .42041 L 1 0 0 r
F P
0 g
s
.55976 .42028 m .55977 .42024 L .5598 .42041 L 0 1 0 r
F
.55977 .42024 m .56282 .40899 L .5598 .42041 L F
.5598 .42041 m .56016 .42003 L .56121 .42414 L F
.56121 .42414 m .5611 .42415 L p .5598 .42041 L F P
0 g
s
.5597 .42051 m .55999 .42126 L .56023 .42373 L 0 0 1 r
F
.5597 .42051 m .5598 .42041 L .5611 .42415 L 0 1 0 r
F
.55991 .42048 m .57431 .41833 L .56101 .42342 L 0 0 1 r
F
.5598 .42041 m .55991 .42048 L .56121 .42414 L 1 0 0 r
F
.55991 .42048 m .561 .42338 L .56121 .42414 L F
.55991 .42048 m .56101 .42342 L .56043 .42365 L 0 0 1 r
F
.55991 .42048 m .56023 .42069 L .561 .42338 L 1 0 0 r
F
.55991 .42048 m .56043 .42365 L .56023 .42373 L 0 0 1 r
F
.561 .42338 m .56129 .42417 L .56121 .42414 L 1 0 0 r
F
.56123 .42423 m .56121 .42414 L .56124 .42423 L F
.56121 .42414 m .56133 .42427 L p .56124 .42423 L F P
0 g
s
.56133 .42427 m .56023 .42373 L p .56101 .42342 L 0 0 1 r
F P
0 g
s
.56101 .42342 m .5612 .42335 L .56133 .42427 L 0 0 1 r
F
.56023 .42069 m .57479 .43025 L .56129 .42417 L 1 0 0 r
F
.56023 .42069 m .56129 .42417 L .561 .42338 L F
.56023 .42373 m .55507 .4212 L p .5597 .42051 L 0 0 1 r
F P
0 g
s
.5611 .42415 m .5552 .42514 L p .5597 .42051 L 0 1 0 r
F P
0 g
s
.5597 .42051 m .55991 .42048 L .55999 .42126 L 0 0 1 r
F
.5598 .42041 m .55988 .4203 L .55991 .42048 L 1 0 0 r
F
.56295 .41274 m .57431 .41833 L p .56072 .42036 L 0 0 1 r
F P
0 g
s
.56034 .41938 m .56295 .41274 L .56072 .42036 L 0 0 1 r
F
.5598 .42041 m .56002 .41958 L .56015 .42005 L 0 1 0 r
F
.55964 .42015 m .56282 .40899 L .5597 .42051 L F
.55507 .4212 m .5591 .41688 L p .5597 .42051 L 0 0 1 r
F P
0 g
s
.55865 .41783 m .5591 .41688 L p .55947 .42075 L 0 1 0 r
F P
0 g
s
.5591 .41688 m .56282 .40899 L p .55964 .42015 L 0 1 0 r
F P
0 g
s
.5591 .41688 m .55964 .42015 L .55947 .42075 L 0 1 0 r
F
.55919 .41669 m .55929 .41668 L p .5598 .42041 L 1 0 0 r
F P
0 g
s
.55929 .41668 m .55988 .4203 L .5598 .42041 L 1 0 0 r
F
.5597 .42051 m .55976 .42028 L .5598 .42041 L 0 1 0 r
F
.5597 .42051 m .55929 .41668 L .55991 .42048 L 0 0 1 r
F
.5591 .41688 m .55929 .41668 L p .5597 .42051 L F P
0 g
s
.55929 .41668 m .56295 .41274 L p .55991 .42048 L 0 0 1 r
F P
0 g
s
.56295 .41274 m .55929 .41668 L p .55804 .41347 L 0 0 1 r
F P
0 g
s
.55831 .41362 m .56085 .415 L .55929 .41668 L 1 0 0 r
F
.56085 .415 m .56308 .4162 L .55929 .41668 L F
.55929 .41668 m .55919 .41669 L p .5589 .41569 L F P
0 g
s
.55831 .41362 m .55929 .41668 L .5589 .41569 L 1 0 0 r
F
.55991 .42048 m .56034 .41938 L .56072 .42036 L 0 0 1 r
F
.55929 .41668 m .56308 .4162 L p .55988 .4203 L 1 0 0 r
F P
0 g
s
.56308 .4162 m .57479 .43025 L p .55991 .42048 L 1 0 0 r
F P
0 g
s
.55988 .4203 m .56308 .4162 L .55991 .42048 L 1 0 0 r
F
.55919 .41669 m .55495 .41722 L p .55831 .41362 L F P
0 g
s
.55495 .41722 m .54696 .41941 L .53553 .40886 L p 1 0 0 r
F P
0 g
s
.53553 .40886 m .54342 .40556 L .55495 .41722 L p 1 0 0 r
F P
0 g
s
.55507 .4212 m .54368 .41562 L p .55777 .41351 L 0 0 1 r
F P
0 g
s
.55777 .41351 m .5579 .4134 L .55784 .41367 L 0 1 0 r
F
.55777 .41351 m .5579 .41383 L .55507 .4212 L 0 0 1 r
F
.5579 .4134 m .55796 .41356 L .55772 .41386 L 1 0 0 r
F
.55919 .41669 m .5591 .41688 L p .5579 .4134 L 0 1 0 r
F P
0 g
s
.5591 .41688 m .55507 .4212 L p .5579 .41383 L 0 0 1 r
F P
0 g
s
.5591 .41688 m .5552 .42514 L p .55784 .41367 L 0 1 0 r
F P
0 g
s
.5579 .4134 m .5591 .41688 L .55784 .41367 L 0 1 0 r
F
.55929 .41668 m .5591 .41688 L p .55804 .41347 L 0 0 1 r
F P
0 g
s
.55804 .41347 m .5591 .41688 L .5579 .41383 L 0 0 1 r
F
.55777 .41351 m .55804 .41347 L .5579 .41383 L F
.53911 .42268 m .53136 .42693 L .52008 .41837 L p 1 0 0 r
F P
0 g
s
.55507 .4212 m .54725 .42961 L .53588 .42407 L p 0 0 1 r
F P
0 g
s
.52008 .41837 m .52776 .41315 L .53911 .42268 L p 1 0 0 r
F P
0 g
s
.54696 .41941 m .53911 .42268 L .52776 .41315 L p 1 0 0 r
F P
0 g
s
.52776 .41315 m .53553 .40886 L .54696 .41941 L p 1 0 0 r
F P
0 g
s
.53588 .42407 m .54368 .41562 L .55507 .4212 L p 0 0 1 r
F P
0 g
s
.5552 .42514 m .54395 .42589 L p .55777 .41351 L 0 1 0 r
F P
0 g
s
.55777 .41351 m .55784 .41367 L .5552 .42514 L 0 1 0 r
F
.5579 .4134 m .55804 .41347 L .55796 .41356 L 1 0 0 r
F
.58128 .38716 m .57382 .40599 L .56282 .40899 L p 0 1 0 r
F P
0 g
s
.56282 .40899 m .57039 .39137 L .58128 .38716 L p 0 1 0 r
F P
0 g
s
.57039 .39137 m .56282 .40899 L .55737 .4099 L p 0 1 0 r
F P
0 g
s
.54342 .40556 m .55143 .40336 L .55737 .4099 L p 1 0 0 r
F P
0 g
s
.55737 .4099 m .56282 .40899 L p .55829 .41305 L 0 1 0 r
F P
0 g
s
.5579 .4134 m .55737 .4099 L .55829 .41305 L 0 1 0 r
F
.57089 .40421 m .56295 .41274 L .5575 .41005 L p 0 0 1 r
F P
0 g
s
.55633 .406 m .57039 .39137 L .55737 .4099 L 0 1 0 r
F
.55736 .40917 m .57089 .40421 L .5575 .41005 L 0 0 1 r
F
.58227 .40985 m .57431 .41833 L .56295 .41274 L p F P
0 g
s
.54342 .40556 m .55737 .4099 L .55738 .41001 L 1 0 0 r
F
.54342 .40556 m .5575 .41005 L .55804 .41347 L F
.54368 .41562 m .55154 .40712 L .55724 .40992 L p 0 0 1 r
F P
0 g
s
.54368 .41562 m .55724 .40992 L .55727 .41014 L 0 0 1 r
F
.55777 .41351 m .55737 .4099 L .5579 .4134 L 0 1 0 r
F
.55777 .41351 m .5575 .41005 L .55877 .41336 L 0 0 1 r
F
.54368 .41562 m .55727 .41014 L .55777 .41351 L F
.55726 .41003 m .55737 .4099 L .55777 .41351 L 0 1 0 r
F
.55727 .41014 m .5575 .41005 L .55777 .41351 L 0 0 1 r
F
.54395 .42589 m .55726 .41003 L .55777 .41351 L 0 1 0 r
F
.54395 .42589 m .55165 .41086 L .55724 .40992 L p F P
0 g
s
.55724 .40992 m .55737 .4099 L p .55726 .41003 L 0 1 0 r
F P
0 g
s
.54395 .42589 m .55724 .40992 L .55726 .41003 L 0 1 0 r
F
.55724 .40992 m .5575 .41005 L p .55727 .41014 L 0 0 1 r
F P
0 g
s
.5575 .41005 m .56295 .41274 L p .55877 .41336 L 0 0 1 r
F P
0 g
s
.59196 .38176 m .58463 .40181 L .57382 .40599 L p 0 1 0 r
F P
0 g
s
.57382 .40599 m .58128 .38716 L .59196 .38176 L p 0 1 0 r
F P
0 g
s
.56295 .41274 m .57089 .40421 L .58227 .40985 L p 0 0 1 r
F P
0 g
s
.57136 .41645 m .56308 .4162 L .5575 .41005 L p 1 0 0 r
F P
0 g
s
.5575 .41005 m .55737 .4099 L p .55746 .40995 L 1 0 0 r
F P
0 g
s
.55746 .40995 m .57136 .41645 L .5575 .41005 L 1 0 0 r
F
.55737 .4099 m .55689 .40938 L p .55599 .40635 L F P
0 g
s
.55689 .40938 m .55143 .40336 L p .55599 .40635 L 1 0 0 r
F P
0 g
s
.55143 .40336 m .53983 .39162 L p .55361 .3991 L 1 0 0 r
F P
0 g
s
.55361 .3991 m .55395 .39928 L .55382 .39978 L 1 0 0 r
F
.55361 .3991 m .55382 .39978 L .55143 .40336 L F
.55931 .39441 m .55538 .40286 L p .55395 .39928 L 0 1 0 r
F P
0 g
s
.5541 .39936 m .55424 .39971 L .55143 .40336 L 1 0 0 r
F
.55931 .39441 m .57039 .39137 L p .55631 .40601 L 0 1 0 r
F P
0 g
s
.55619 .40561 m .55931 .39441 L .55631 .40601 L 0 1 0 r
F
.55143 .40336 m .55538 .40286 L p .55599 .40635 L 1 0 0 r
F P
0 g
s
.55595 .40622 m .55596 .40618 L .55599 .40635 L 0 1 0 r
F
.55596 .40618 m .55931 .39441 L .55599 .40635 L F
.55599 .40635 m .55633 .406 L .55737 .4099 L F
.55737 .4099 m .55724 .40992 L p .55599 .40635 L F P
0 g
s
.55588 .40647 m .55619 .40727 L .55641 .40952 L 0 0 1 r
F
.55588 .40647 m .55599 .40635 L .55724 .40992 L 0 1 0 r
F
.55611 .40643 m .57089 .40421 L .55719 .40923 L 0 0 1 r
F
.55599 .40635 m .55611 .40643 L .55737 .4099 L 1 0 0 r
F
.55611 .40643 m .55711 .40904 L .55737 .4099 L F
.55611 .40643 m .55719 .40923 L .55663 .40943 L 0 0 1 r
F
.55611 .40643 m .5564 .40662 L .55711 .40904 L 1 0 0 r
F
.55611 .40643 m .55663 .40943 L .55641 .40952 L 0 0 1 r
F
.55711 .40904 m .55746 .40995 L .55737 .4099 L 1 0 0 r
F
.55738 .41001 m .55737 .4099 L .5574 .41002 L F
.55737 .4099 m .5575 .41005 L p .5574 .41002 L F P
0 g
s
.5575 .41005 m .55641 .40952 L p .55719 .40923 L 0 0 1 r
F P
0 g
s
.55719 .40923 m .55736 .40917 L .5575 .41005 L 0 0 1 r
F
.5564 .40662 m .57136 .41645 L .55746 .40995 L 1 0 0 r
F
.5564 .40662 m .55746 .40995 L .55711 .40904 L F
.55641 .40952 m .55154 .40712 L p .55588 .40647 L 0 0 1 r
F P
0 g
s
.55724 .40992 m .55165 .41086 L p .55588 .40647 L 0 1 0 r
F P
0 g
s
.55588 .40647 m .55611 .40643 L .55619 .40727 L 0 0 1 r
F
.55599 .40635 m .55608 .40625 L .55611 .40643 L 1 0 0 r
F
.55945 .39855 m .57089 .40421 L p .55687 .40632 L 0 0 1 r
F P
0 g
s
.55653 .40545 m .55945 .39855 L .55687 .40632 L 0 0 1 r
F
.55599 .40635 m .55619 .40561 L .55631 .40601 L 0 1 0 r
F
.55582 .40612 m .55931 .39441 L .55588 .40647 L F
.55154 .40712 m .55528 .40307 L p .55588 .40647 L 0 0 1 r
F P
0 g
s
.55485 .404 m .55528 .40307 L p .55564 .40671 L 0 1 0 r
F P
0 g
s
.55528 .40307 m .55931 .39441 L p .55582 .40612 L 0 1 0 r
F P
0 g
s
.55528 .40307 m .55582 .40612 L .55564 .40671 L 0 1 0 r
F
.55538 .40286 m .55549 .40285 L p .55599 .40635 L 1 0 0 r
F P
0 g
s
.55549 .40285 m .55608 .40625 L .55599 .40635 L 1 0 0 r
F
.55588 .40647 m .55595 .40622 L .55599 .40635 L 0 1 0 r
F
.55588 .40647 m .55549 .40285 L .55611 .40643 L 0 0 1 r
F
.55528 .40307 m .55549 .40285 L p .55588 .40647 L F P
0 g
s
.55549 .40285 m .55945 .39855 L p .55611 .40643 L 0 0 1 r
F P
0 g
s
.55945 .39855 m .55549 .40285 L p .5541 .39936 L 0 0 1 r
F P
0 g
s
.55439 .39952 m .55717 .40103 L .55549 .40285 L 1 0 0 r
F
.55717 .40103 m .55958 .40233 L .55549 .40285 L F
.55549 .40285 m .55538 .40286 L p .55505 .40175 L F P
0 g
s
.55439 .39952 m .55549 .40285 L .55505 .40175 L 1 0 0 r
F
.55611 .40643 m .55653 .40545 L .55687 .40632 L 0 0 1 r
F
.55549 .40285 m .55958 .40233 L p .55608 .40625 L 1 0 0 r
F P
0 g
s
.55958 .40233 m .57136 .41645 L p .55611 .40643 L 1 0 0 r
F P
0 g
s
.55608 .40625 m .55958 .40233 L .55611 .40643 L 1 0 0 r
F
.55538 .40286 m .55143 .40336 L p .55439 .39952 L F P
0 g
s
.55143 .40336 m .54342 .40556 L .53192 .39494 L p 1 0 0 r
F P
0 g
s
.53192 .39494 m .53983 .39162 L .55143 .40336 L p 1 0 0 r
F P
0 g
s
.55154 .40712 m .54008 .40147 L p .55381 .3994 L 0 0 1 r
F P
0 g
s
.55381 .3994 m .55395 .39928 L .55389 .39959 L 0 1 0 r
F
.55381 .3994 m .55396 .39978 L .55154 .40712 L 0 0 1 r
F
.55395 .39928 m .55402 .39947 L .55382 .39978 L 1 0 0 r
F
.55538 .40286 m .55528 .40307 L p .55395 .39928 L 0 1 0 r
F P
0 g
s
.55528 .40307 m .55154 .40712 L p .55396 .39978 L 0 0 1 r
F P
0 g
s
.55528 .40307 m .55165 .41086 L p .55389 .39959 L 0 1 0 r
F P
0 g
s
.55395 .39928 m .55528 .40307 L .55389 .39959 L 0 1 0 r
F
.55549 .40285 m .55528 .40307 L p .5541 .39936 L 0 0 1 r
F P
0 g
s
.5541 .39936 m .55528 .40307 L .55396 .39978 L 0 0 1 r
F
.55381 .3994 m .5541 .39936 L .55396 .39978 L F
.53553 .40886 m .52776 .41315 L .51641 .40453 L p 1 0 0 r
F P
0 g
s
.55154 .40712 m .54368 .41562 L .53224 .41001 L p 0 0 1 r
F P
0 g
s
.51641 .40453 m .52411 .39927 L .53553 .40886 L p 1 0 0 r
F P
0 g
s
.54342 .40556 m .53553 .40886 L .52411 .39927 L p 1 0 0 r
F P
0 g
s
.52411 .39927 m .53192 .39494 L .54342 .40556 L p 1 0 0 r
F P
0 g
s
.53224 .41001 m .54008 .40147 L .55154 .40712 L p 0 0 1 r
F P
0 g
s
.55165 .41086 m .54033 .41163 L p .55381 .3994 L 0 1 0 r
F P
0 g
s
.55381 .3994 m .55389 .39959 L .55165 .41086 L 0 1 0 r
F
.55395 .39928 m .5541 .39936 L .55402 .39947 L 1 0 0 r
F
.57788 .3722 m .57039 .39137 L .55931 .39441 L p 0 1 0 r
F P
0 g
s
.55931 .39441 m .56692 .37645 L .57788 .3722 L p 0 1 0 r
F P
0 g
s
.56692 .37645 m .55931 .39441 L .55332 .39543 L p 0 1 0 r
F P
0 g
s
.53983 .39162 m .54787 .38942 L .55332 .39543 L p 1 0 0 r
F P
0 g
s
.55332 .39543 m .55931 .39441 L p .55437 .39889 L 0 1 0 r
F P
0 g
s
.55395 .39928 m .55332 .39543 L .55437 .39889 L 0 1 0 r
F
.56742 .38993 m .55945 .39855 L .55347 .39559 L p 0 0 1 r
F P
0 g
s
.55233 .39182 m .56692 .37645 L .5536 .39503 L 0 1 0 r
F
.55239 .39203 m .5536 .39503 L .55332 .39543 L F
.55233 .39182 m .5536 .39503 L .55239 .39203 L F
.54787 .38942 m .5362 .3776 L p .54947 .38482 L 1 0 0 r
F P
0 g
s
.55576 .37954 m .56692 .37645 L p .55231 .39184 L 0 1 0 r
F P
0 g
s
.55332 .39543 m .55288 .39494 L p .55265 .39375 L 1 0 0 r
F P
0 g
s
.55288 .39494 m .54787 .38942 L p .55202 .39215 L 1 0 0 r
F P
0 g
s
.53983 .39162 m .55332 .39543 L .55334 .39556 L 1 0 0 r
F
.53983 .39162 m .55347 .39559 L .5541 .39936 L F
.55326 .39507 m .55333 .39476 L .55347 .39559 L 0 0 1 r
F
.55202 .39215 m .55233 .39182 L .55332 .39543 L 0 1 0 r
F
.55333 .39476 m .55508 .39416 L .55345 .39549 L 0 0 1 r
F
.55508 .39416 m .56742 .38993 L .55345 .39549 L F
.55345 .39549 m .56742 .38993 L .55347 .39559 L F
.55302 .39445 m .55343 .39548 L .55332 .39543 L 1 0 0 r
F
.55332 .39543 m .55318 .39545 L p .55202 .39215 L 0 1 0 r
F P
0 g
s
.5519 .39228 m .55202 .39215 L .55318 .39545 L 0 1 0 r
F
.5519 .39228 m .55216 .39224 L .55242 .39507 L 0 0 1 r
F
.55216 .39224 m .56742 .38993 L .55317 .39482 L F
.55265 .39375 m .55257 .39329 L .55332 .39543 L 1 0 0 r
F
.55257 .39329 m .55302 .39445 L .55332 .39543 L F
.55202 .39215 m .55216 .39224 L .55288 .39494 L F
.55216 .39224 m .5524 .3924 L .55257 .39329 L F
.55216 .39224 m .55257 .39329 L .55288 .39494 L F
.55591 .38421 m .56742 .38993 L p .55284 .39213 L 0 0 1 r
F P
0 g
s
.55255 .3914 m .55591 .38421 L .55284 .39213 L 0 0 1 r
F
.55202 .39215 m .55217 .39138 L .55231 .39184 L 0 1 0 r
F
.54787 .38942 m .55143 .38898 L p .55202 .39215 L 1 0 0 r
F P
0 g
s
.55198 .39201 m .55199 .39198 L .55202 .39215 L 0 1 0 r
F
.55199 .39198 m .55217 .39138 L .55202 .39215 L F
.55217 .39138 m .55576 .37954 L .55231 .39184 L F
.55184 .39194 m .55576 .37954 L .5519 .39228 L F
.55108 .38948 m .55133 .3892 L p .55166 .39096 L 0 0 1 r
F P
0 g
s
.55133 .3892 m .55576 .37954 L p .55184 .39194 L 0 1 0 r
F P
0 g
s
.55143 .38898 m .55155 .38896 L p .55202 .39215 L 1 0 0 r
F P
0 g
s
.55155 .38896 m .55591 .38421 L p .55382 .38868 L 0 0 1 r
F P
0 g
s
.55212 .39205 m .55233 .39186 L p .55216 .39224 L 0 0 1 r
F P
0 g
s
.55216 .39224 m .55255 .3914 L .55284 .39213 L 0 0 1 r
F
.55155 .38896 m .55605 .38841 L p .55212 .39205 L 1 0 0 r
F P
0 g
s
.55155 .38896 m .55212 .39205 L .55202 .39215 L 1 0 0 r
F
.55202 .39215 m .55212 .39205 L .55216 .39224 L F
.5519 .39228 m .55198 .39201 L .55202 .39215 L 0 1 0 r
F
.54797 .39287 m .55108 .38948 L p .55216 .39224 L 0 0 1 r
F P
0 g
s
.55242 .39507 m .54797 .39287 L p .5519 .39228 L 0 0 1 r
F P
0 g
s
.55091 .39011 m .55133 .3892 L p .55165 .39254 L 0 1 0 r
F P
0 g
s
.55133 .3892 m .55184 .39194 L .55165 .39254 L 0 1 0 r
F
.55166 .39096 m .55155 .38896 L .55216 .39224 L 0 0 1 r
F
.55133 .3892 m .55155 .38896 L p .55166 .39096 L F P
0 g
s
.57888 .39563 m .57089 .40421 L .55945 .39855 L p 0 0 1 r
F P
0 g
s
.55945 .39855 m .56742 .38993 L .57888 .39563 L p 0 0 1 r
F P
0 g
s
.55605 .38841 m .5679 .4026 L p .55216 .39224 L 1 0 0 r
F P
0 g
s
.55212 .39205 m .55605 .38841 L .55216 .39224 L 1 0 0 r
F
.55066 .38777 m .54982 .38501 L .55116 .38901 L F
.54947 .38482 m .54982 .38501 L .55066 .38777 L F
.55116 .38901 m .54787 .38942 L p .54947 .38482 L F P
0 g
s
.54787 .38942 m .53983 .39162 L .52826 .38092 L p 1 0 0 r
F P
0 g
s
.52826 .38092 m .5362 .3776 L .54787 .38942 L p 1 0 0 r
F P
0 g
s
.54797 .39287 m .53643 .38716 L p .54967 .38515 L 0 0 1 r
F P
0 g
s
.53983 .39162 m .53192 .39494 L .52043 .38527 L p 1 0 0 r
F P
0 g
s
.52043 .38527 m .52826 .38092 L .53983 .39162 L p 1 0 0 r
F P
0 g
s
.53192 .39494 m .52411 .39927 L .5127 .39057 L p 1 0 0 r
F P
0 g
s
.54797 .39287 m .54008 .40147 L .52856 .3958 L p 0 0 1 r
F P
0 g
s
.55217 .36438 m .5634 .36123 L p .54816 .37751 L 0 1 0 r
F P
0 g
s
.5362 .3776 m .54427 .3754 L .54868 .38027 L p 1 0 0 r
F P
0 g
s
.5362 .3776 m .54868 .38027 L .54874 .38062 L 1 0 0 r
F
.5362 .3776 m .54907 .3807 L .54982 .38501 L F
.54907 .3807 m .55576 .37954 L p .55029 .38458 L 0 1 0 r
F P
0 g
s
.54982 .38501 m .54907 .3807 L .55029 .38458 L 0 1 0 r
F
.55576 .37954 m .55143 .38898 L p .54982 .38501 L F P
0 g
s
.54924 .38089 m .55591 .38421 L p .55087 .38497 L 0 0 1 r
F P
0 g
s
.54999 .3851 m .54924 .38089 L .55087 .38497 L 0 0 1 r
F
.55591 .38421 m .55155 .38896 L p .54999 .3851 L F P
0 g
s
.56439 .3887 m .55605 .38841 L .54924 .38089 L p 1 0 0 r
F P
0 g
s
.54924 .38089 m .54907 .3807 L p .54919 .38076 L 1 0 0 r
F P
0 g
s
.57444 .35691 m .56692 .37645 L .55576 .37954 L p 0 1 0 r
F P
0 g
s
.55576 .37954 m .5634 .36123 L .57444 .35691 L p 0 1 0 r
F P
0 g
s
.54427 .3754 m .53253 .36349 L p .54551 .3706 L 1 0 0 r
F P
0 g
s
.55217 .36438 m .54735 .37503 L p .54551 .3706 L 0 1 0 r
F P
0 g
s
.54551 .3706 m .54569 .3707 L .54563 .3709 L 1 0 0 r
F
.54551 .3706 m .54563 .3709 L .54427 .3754 L F
.54569 .3707 m .54592 .37123 L .54427 .3754 L F
.54814 .37753 m .5476 .37449 L .54816 .37751 L 0 1 0 r
F
.54776 .37633 m .5476 .37449 L .54814 .37753 L F
.54427 .3754 m .54735 .37503 L p .5479 .3778 L 1 0 0 r
F P
0 g
s
.54735 .37503 m .54427 .3754 L p .54592 .37123 L 1 0 0 r
F P
0 g
s
.54735 .37503 m .5476 .37449 L p .5479 .3778 L 0 1 0 r
F P
0 g
s
.5476 .37449 m .55217 .36438 L p .54816 .37751 L 0 1 0 r
F P
0 g
s
.55233 .36969 m .54748 .37502 L p .54569 .3707 L 0 0 1 r
F P
0 g
s
.54605 .3709 m .54693 .37367 L .54592 .37123 L 1 0 0 r
F
.54693 .37367 m .54735 .37503 L .54592 .37123 L F
.54735 .37503 m .54724 .37528 L p .54551 .3706 L 0 1 0 r
F P
0 g
s
.54868 .38027 m .54427 .3754 L p .5479 .3778 L 1 0 0 r
F P
0 g
s
.54559 .37133 m .54672 .37404 L .54435 .37845 L 0 0 1 r
F
.54551 .3706 m .54724 .37528 L .54547 .37104 L 0 1 0 r
F
.54724 .37528 m .54435 .37845 L p .54693 .37367 L 0 0 1 r
F P
0 g
s
.54535 .37075 m .54559 .37133 L .54435 .37845 L 0 0 1 r
F
.54868 .38027 m .54907 .3807 L p .54874 .38062 L 1 0 0 r
F P
0 g
s
.54891 .38072 m .54825 .38039 L p .54777 .37794 L 0 0 1 r
F P
0 g
s
.54825 .38039 m .54435 .37845 L p .54777 .37794 L 0 0 1 r
F P
0 g
s
.54911 .38095 m .54924 .38089 L p .54982 .38501 L 1 0 0 r
F P
0 g
s
.54909 .38081 m .54907 .3807 L .54924 .38089 L 1 0 0 r
F
.54982 .38501 m .54942 .38372 L .54907 .3807 L 0 1 0 r
F
.53643 .38716 m .54435 .37845 L .54891 .38072 L p 0 0 1 r
F P
0 g
s
.53643 .38716 m .54891 .38072 L .54896 .38102 L 0 0 1 r
F
.54891 .38072 m .54907 .3807 L p .54942 .38372 L 0 1 0 r
F P
0 g
s
.54982 .38501 m .54924 .38089 L .54999 .3851 L 1 0 0 r
F
.54967 .38515 m .54942 .38372 L .54982 .38501 L 0 1 0 r
F
.54967 .38515 m .54924 .38089 L .54999 .3851 L 0 0 1 r
F
.53643 .38716 m .54896 .38102 L .54967 .38515 L F
.54896 .38102 m .54924 .38089 L .54967 .38515 L F
.5127 .39057 m .52043 .38527 L .53192 .39494 L p 1 0 0 r
F P
0 g
s
.52856 .3958 m .53643 .38716 L .54797 .39287 L p 0 0 1 r
F P
0 g
s
.53666 .39712 m .54853 .38079 L .54942 .38372 L 0 1 0 r
F
.53666 .39712 m .54942 .38372 L .54967 .38515 L F
.54853 .38079 m .54891 .38072 L p .54942 .38372 L F P
0 g
s
.54891 .38072 m .54924 .38089 L p .54896 .38102 L 0 0 1 r
F P
0 g
s
.54777 .37794 m .54748 .37649 L .5479 .3778 L 0 1 0 r
F
.54748 .37649 m .54735 .37503 L .5479 .3778 L F
.54724 .37528 m .54735 .37503 L p .54748 .37649 L F P
0 g
s
.5634 .36123 m .55576 .37954 L .54907 .3807 L p 0 1 0 r
F P
0 g
s
.54902 .38058 m .5634 .36123 L .54907 .3807 L 0 1 0 r
F
.54907 .3807 m .54868 .38027 L p .5479 .3778 L 1 0 0 r
F P
0 g
s
.54777 .37794 m .5634 .36123 L .54891 .38072 L 0 1 0 r
F
.55233 .36969 m .56392 .37548 L p .54864 .3778 L 0 0 1 r
F P
0 g
s
.54839 .37722 m .55233 .36969 L .54864 .3778 L 0 0 1 r
F
.5479 .3778 m .54776 .37633 L .54814 .37753 L 0 1 0 r
F
.54748 .37502 m .55233 .36969 L p .54804 .37789 L 0 0 1 r
F P
0 g
s
.55248 .37442 m .54748 .37502 L p .54605 .3709 L 1 0 0 r
F P
0 g
s
.54748 .37502 m .54735 .37503 L p .54693 .37367 L 1 0 0 r
F P
0 g
s
.54605 .3709 m .54748 .37502 L .54693 .37367 L 1 0 0 r
F
.54804 .37789 m .54839 .37722 L .54864 .3778 L 0 0 1 r
F
.5479 .3778 m .54801 .37772 L .54804 .37789 L 1 0 0 r
F
.54735 .37503 m .55248 .37442 L p .5479 .3778 L F P
0 g
s
.5479 .3778 m .54804 .37789 L .54907 .3807 L 1 0 0 r
F
.54435 .37845 m .54748 .37502 L p .54804 .37789 L 0 0 1 r
F P
0 g
s
.56392 .37548 m .55591 .38421 L .54924 .38089 L p 0 0 1 r
F P
0 g
s
.54804 .37789 m .56392 .37548 L .54924 .38089 L 0 0 1 r
F
.57039 .39137 m .57788 .3722 L .58864 .36675 L p 0 1 0 r
F P
0 g
s
.57545 .38125 m .56742 .38993 L .55591 .38421 L p 0 0 1 r
F P
0 g
s
.55591 .38421 m .56392 .37548 L .57545 .38125 L p 0 0 1 r
F P
0 g
s
.55248 .37442 m .56439 .3887 L p .54804 .37789 L 1 0 0 r
F P
0 g
s
.54801 .37772 m .55248 .37442 L .54804 .37789 L 1 0 0 r
F
.54443 .3815 m .54716 .37547 L p .54748 .37649 L 0 1 0 r
F P
0 g
s
.54443 .3815 m .54748 .37649 L .54777 .37794 L 0 1 0 r
F
.54724 .37528 m .54443 .3815 L p .54547 .37104 L F P
0 g
s
.54569 .3707 m .54693 .37367 L .54672 .37404 L 0 0 1 r
F
.54569 .3707 m .54672 .37404 L .54559 .37133 L F
.54748 .37502 m .54724 .37528 L p .54693 .37367 L F P
0 g
s
.54716 .37547 m .54724 .37528 L p .54748 .37649 L 0 1 0 r
F P
0 g
s
.54427 .3754 m .5362 .3776 L .52456 .3668 L p 1 0 0 r
F P
0 g
s
.52456 .3668 m .53253 .36349 L .54427 .3754 L p 1 0 0 r
F P
0 g
s
.54435 .37845 m .53273 .37268 L p .54535 .37075 L 0 0 1 r
F P
0 g
s
.54535 .37075 m .54551 .3706 L .54547 .37104 L 0 1 0 r
F
.54535 .37075 m .54569 .3707 L .54559 .37133 L 0 0 1 r
F
.52826 .38092 m .52043 .38527 L .50895 .37649 L p 1 0 0 r
F P
0 g
s
.50895 .37649 m .51671 .37117 L .52826 .38092 L p 1 0 0 r
F P
0 g
s
.5362 .3776 m .52826 .38092 L .51671 .37117 L p 1 0 0 r
F P
0 g
s
.54435 .37845 m .53643 .38716 L .52483 .38142 L p 0 0 1 r
F P
0 g
s
.51671 .37117 m .52456 .3668 L .5362 .3776 L p 1 0 0 r
F P
0 g
s
.52483 .38142 m .53273 .37268 L .54435 .37845 L p 0 0 1 r
F P
0 g
s
.54443 .3815 m .53295 .38235 L p .54535 .37075 L 0 1 0 r
F P
0 g
s
.54535 .37075 m .54547 .37104 L .54443 .3815 L 0 1 0 r
F
.54569 .3707 m .54605 .3709 L .54592 .37123 L 1 0 0 r
F
.54907 .3807 m .54891 .38072 L p .54902 .38058 L 0 1 0 r
F P
0 g
s
.54891 .38072 m .54443 .3815 L p .54777 .37794 L 0 1 0 r
F P
0 g
s
.54804 .37789 m .54872 .37959 L .54907 .3807 L 1 0 0 r
F
.54823 .37802 m .56439 .3887 L .54907 .3807 L F
.54924 .38089 m .54891 .38072 L p .54804 .37789 L 0 0 1 r
F P
0 g
s
.54777 .37794 m .54804 .37789 L .54891 .38072 L 0 0 1 r
F
.54804 .37789 m .54823 .37802 L .54872 .37959 L 1 0 0 r
F
.54919 .38076 m .56439 .3887 L .54924 .38089 L F
.54924 .38089 m .55605 .38841 L p .54999 .3851 L F P
0 g
s
.53666 .39712 m .54443 .3815 L .54853 .38079 L p 0 1 0 r
F P
0 g
s
.54982 .38501 m .55035 .38633 L .55116 .38901 L 1 0 0 r
F
.54967 .38515 m .54982 .38501 L .55133 .3892 L 0 1 0 r
F
.54999 .3851 m .55063 .38669 L .55116 .38901 L 1 0 0 r
F
.55143 .38898 m .55116 .38901 L p .5503 .38528 L F P
0 g
s
.55143 .38898 m .55133 .3892 L p .54982 .38501 L 0 1 0 r
F P
0 g
s
.54982 .38501 m .54999 .3851 L .55035 .38633 L 1 0 0 r
F
.54999 .3851 m .5503 .38528 L .55063 .38669 L F
.54967 .38515 m .54999 .3851 L .55133 .3892 L 0 0 1 r
F
.55155 .38896 m .55143 .38898 L p .55106 .38774 L 1 0 0 r
F P
0 g
s
.55155 .38896 m .55133 .3892 L p .54999 .3851 L 0 0 1 r
F P
0 g
s
.55133 .3892 m .54797 .39287 L p .54967 .38515 L 0 0 1 r
F P
0 g
s
.54008 .40147 m .54797 .39287 L .55318 .39545 L p 0 0 1 r
F P
0 g
s
.54008 .40147 m .55318 .39545 L .55322 .3957 L 0 0 1 r
F
.55381 .3994 m .55332 .39543 L .55395 .39928 L 0 1 0 r
F
.55381 .3994 m .55347 .39559 L .5549 .39924 L 0 0 1 r
F
.54008 .40147 m .55322 .3957 L .55381 .3994 L F
.5532 .39557 m .55332 .39543 L .55381 .3994 L 0 1 0 r
F
.55322 .3957 m .55347 .39559 L .55381 .3994 L 0 0 1 r
F
.54033 .41163 m .5532 .39557 L .55381 .3994 L 0 1 0 r
F
.54033 .41163 m .54807 .39632 L .55318 .39545 L p F P
0 g
s
.55318 .39545 m .55332 .39543 L p .5532 .39557 L 0 1 0 r
F P
0 g
s
.54033 .41163 m .55318 .39545 L .5532 .39557 L 0 1 0 r
F
.55318 .39545 m .55347 .39559 L p .55322 .3957 L 0 0 1 r
F P
0 g
s
.55347 .39559 m .55945 .39855 L p .5549 .39924 L 0 0 1 r
F P
0 g
s
.5679 .4026 m .55958 .40233 L .55347 .39559 L p 1 0 0 r
F P
0 g
s
.55347 .39559 m .55332 .39543 L p .55343 .39548 L 1 0 0 r
F P
0 g
s
.55343 .39548 m .5679 .4026 L .55347 .39559 L 1 0 0 r
F
.54807 .39632 m .53666 .39712 L p .54967 .38515 L 0 1 0 r
F P
0 g
s
.55133 .3892 m .54807 .39632 L p .54967 .38515 L 0 1 0 r
F P
0 g
s
.55605 .38841 m .55155 .38896 L p .5503 .38528 L 1 0 0 r
F P
0 g
s
.5503 .38528 m .55155 .38896 L .55106 .38774 L 1 0 0 r
F
.55216 .39224 m .55317 .39482 L .55242 .39507 L 0 0 1 r
F
.55257 .39329 m .5524 .3924 L .55302 .39445 L 1 0 0 r
F
.5524 .3924 m .5679 .4026 L .55343 .39548 L F
.5524 .3924 m .55343 .39548 L .55302 .39445 L F
.55334 .39556 m .55332 .39543 L .55336 .39556 L F
.55332 .39543 m .55347 .39559 L p .55336 .39556 L F P
0 g
s
.55347 .39559 m .55318 .39545 L p .55326 .39507 L 0 0 1 r
F P
0 g
s
.55318 .39545 m .55242 .39507 L p .55296 .39489 L 0 0 1 r
F P
0 g
s
.55296 .39489 m .55333 .39476 L .55318 .39545 L 0 0 1 r
F
.55318 .39545 m .54807 .39632 L p .5519 .39228 L 0 1 0 r
F P
0 g
s
.55347 .39559 m .55958 .40233 L p .5541 .39936 L 1 0 0 r
F P
0 g
s
.55165 .39254 m .55184 .39194 L .5519 .39228 L 0 1 0 r
F
.54807 .39632 m .55091 .39011 L p .55165 .39254 L F P
0 g
s
.5541 .39936 m .55439 .39952 L .55424 .39971 L 1 0 0 r
F
.5575 .41005 m .56308 .4162 L p .55804 .41347 L F P
0 g
s
.55564 .40671 m .55582 .40612 L .55588 .40647 L 0 1 0 r
F
.55165 .41086 m .55485 .404 L p .55564 .40671 L F P
0 g
s
.55804 .41347 m .55831 .41362 L .55816 .41378 L 1 0 0 r
F
.56133 .42427 m .56653 .43001 L p .56179 .42744 L F P
0 g
s
.55947 .42075 m .55964 .42015 L .5597 .42051 L 0 1 0 r
F
.5552 .42514 m .55865 .41783 L p .55947 .42075 L F P
0 g
s
.56179 .42744 m .56206 .42759 L .5619 .42773 L 1 0 0 r
F
.5587 .43916 m .56231 .43162 L p .56313 .43465 L 0 1 0 r
F P
0 g
s
.56538 .44128 m .56564 .44142 L .56548 .44156 L 1 0 0 r
F
.56216 .45293 m .56583 .44535 L p .56663 .44841 L 0 1 0 r
F P
0 g
s
.56879 .45497 m .56906 .45512 L .56889 .45527 L 1 0 0 r
F
.56557 .46646 m .5692 .45903 L p .56997 .46205 L 0 1 0 r
F P
0 g
s
.57203 .46853 m .57232 .46869 L .57214 .46885 L 1 0 0 r
F
.57476 .47881 m .58001 .48469 L p .5751 .48196 L F P
0 g
s
.57315 .47556 m .57336 .47483 L .57342 .47528 L 0 1 0 r
F
.56895 .47975 m .57244 .47267 L p .57315 .47556 L F P
0 g
s
.5751 .48196 m .57542 .48214 L .57523 .48233 L 1 0 0 r
F
.5648 .50652 m .57228 .49281 L .57719 .49193 L p 0 1 0 r
F P
0 g
s
.57858 .49799 m .57801 .49525 L .5788 .49864 L 1 0 0 r
F
.57795 .49521 m .57801 .49525 L .57858 .49799 L F
.57801 .49525 m .57837 .49545 L .57857 .49691 L F
.57788 .49527 m .57801 .49525 L .57906 .49871 L 0 0 1 r
F
.57915 .49861 m .5791 .49862 L p .579 .49818 L 1 0 0 r
F P
0 g
s
.57915 .49861 m .57906 .49871 L p .57801 .49525 L 0 0 1 r
F P
0 g
s
.57906 .49871 m .57545 .50242 L p .57788 .49527 L 0 0 1 r
F P
0 g
s
.57557 .50565 m .5648 .50652 L p .57788 .49527 L 0 1 0 r
F P
0 g
s
.57906 .49871 m .57557 .50565 L p .57788 .49527 L 0 1 0 r
F P
0 g
s
.58329 .49823 m .57915 .49861 L p .57837 .49545 L 1 0 0 r
F P
0 g
s
.57837 .49545 m .57915 .49861 L .579 .49818 L 1 0 0 r
F
.58329 .49823 m .59466 .51226 L p .57949 .50184 L F P
0 g
s
.57948 .50176 m .58329 .49823 L .57949 .50184 L 1 0 0 r
F
.58044 .50479 m .58655 .51173 L p .58076 .50841 L F P
0 g
s
.57905 .50219 m .57934 .50136 L .57939 .50185 L 0 1 0 r
F
.57557 .50565 m .57851 .4998 L p .57905 .50219 L F P
0 g
s
.58076 .50841 m .58117 .50865 L .58095 .50897 L 1 0 0 r
F
.1912 .71694 m .18884 .71963 L .18705 .71467 L p 0 1 0 r
F P
0 g
s
.18328 .53213 m .18957 .52442 L .20123 .52951 L p 0 0 1 r
F P
0 g
s
.18957 .52442 m .18328 .53213 L .1716 .52704 L p 0 0 1 r
F P
0 g
s
.36538 .49016 m .35865 .49513 L .34751 .48729 L p 0 1 0 r
F P
0 g
s
.50851 .4789 m .51589 .47163 L .52686 .47834 L p 1 0 0 r
F P
0 g
s
.51589 .47163 m .50851 .4789 L .49754 .47364 L p 1 0 0 r
F P
0 g
s
.27831 .53183 m .28492 .52411 L .29637 .52921 L p 0 0 1 r
F P
0 g
s
.28492 .52411 m .27831 .53183 L .26684 .52674 L p 0 0 1 r
F P
0 g
s
.62926 .33272 m .63082 .3308 L .63199 .33661 L p 0 1 0 r
F P
0 g
s
.6226 .35821 m .62926 .33272 L p .63199 .33661 L 0 1 0 r
F P
0 g
s
.32584 .53167 m .3326 .52396 L .34395 .52906 L p 0 0 1 r
F P
0 g
s
.3326 .52396 m .32584 .53167 L .31446 .52659 L p 0 0 1 r
F P
0 g
s
.43537 .50353 m .44256 .49261 L .45371 .49496 L p 1 0 0 r
F P
0 g
s
.46092 .4846 m .45371 .49496 L .44256 .49261 L p 1 0 0 r
F P
0 g
s
.37337 .53152 m .38029 .52381 L .39153 .52891 L p 0 0 1 r
F P
0 g
s
.38029 .52381 m .37337 .53152 L .3621 .52644 L p 0 0 1 r
F P
0 g
s
.43191 .54151 m .43896 .53726 L .45005 .54547 L p 0 1 0 r
F P
0 g
s
.43896 .53726 m .43191 .54151 L .42086 .533 L p 0 1 0 r
F P
0 g
s
.54912 .56546 m .55656 .55519 L .56728 .55611 L p 0 1 0 r
F P
0 g
s
.57467 .54393 m .56728 .55611 L .55656 .55519 L p 0 1 0 r
F P
0 g
s
.30401 .57849 m .31067 .57142 L .32209 .57606 L p 1 0 0 r
F P
0 g
s
.31067 .57142 m .30401 .57849 L .29268 .57244 L p 1 0 0 r
F P
0 g
s
.46845 .53122 m .47569 .5235 L .48673 .5286 L p 0 0 1 r
F P
0 g
s
.47569 .5235 m .46845 .53122 L .45739 .52613 L p 0 0 1 r
F P
0 g
s
.516 .53107 m .5234 .52335 L .53433 .52845 L p 0 0 1 r
F P
0 g
s
.5234 .52335 m .516 .53107 L .50504 .52598 L p 0 0 1 r
F P
0 g
s
.57111 .5232 m .56356 .53092 L .5527 .52583 L p 0 0 1 r
F P
0 g
s
.61112 .53077 m .61883 .52305 L .62956 .52815 L p 0 0 1 r
F P
0 g
s
.61883 .52305 m .61112 .53077 L .60036 .52568 L p 0 0 1 r
F P
0 g
s
.27065 .48246 m .27745 .47223 L .28901 .47634 L p 0 1 0 r
F P
0 g
s
.28901 .47634 m .29571 .46771 L .30712 .47324 L p 0 1 0 r
F P
0 g
s
.29571 .46771 m .28901 .47634 L .27745 .47223 L p 0 1 0 r
F P
0 g
s
.63868 .60516 m .63006 .59981 L .61861 .58225 L p 1 0 0 r
F P
0 g
s
.61861 .58225 m .62702 .586 L .63868 .60516 L p 1 0 0 r
F P
0 g
s
.65869 .53062 m .66656 .5229 L .67718 .528 L p 0 0 1 r
F P
0 g
s
.66656 .5229 m .65869 .53062 L .64804 .52553 L p 0 0 1 r
F P
0 g
s
.70626 .53046 m .71429 .52274 L .72481 .52785 L p 0 0 1 r
F P
0 g
s
.71429 .52274 m .70626 .53046 L .69571 .52537 L p 0 0 1 r
F P
0 g
s
.75384 .53031 m .76203 .52259 L .77245 .52769 L p 0 0 1 r
F P
0 g
s
.76203 .52259 m .75384 .53031 L .7434 .52522 L p 0 0 1 r
F P
0 g
s
.4832 .56812 m .49049 .5625 L .50152 .56871 L p 0 1 0 r
F P
0 g
s
.49049 .5625 m .4832 .56812 L .47217 .56097 L p 0 1 0 r
F P
0 g
s
.80143 .53016 m .80978 .52244 L .82009 .52754 L p 0 0 1 r
F P
0 g
s
.80978 .52244 m .80143 .53016 L .79109 .52507 L p 0 0 1 r
F P
0 g
s
.05856 .52997 m .06444 .52224 L .07638 .52735 L p 0 0 1 r
F P
0 g
s
.54537 .481 m .53783 .48585 L .52686 .47834 L p 1 0 0 r
F P
0 g
s
.25193 .49213 m .25888 .48003 L .27065 .48246 L p 0 1 0 r
F P
0 g
s
.27745 .47223 m .27065 .48246 L .25888 .48003 L p 0 1 0 r
F P
0 g
s
.10611 .52982 m .11215 .52209 L .12399 .5272 L p 0 0 1 r
F P
0 g
s
.11215 .52209 m .10611 .52982 L .09425 .52472 L p 0 0 1 r
F P
0 g
s
.34037 .57111 m .3473 .56162 L .35875 .5642 L p 1 0 0 r
F P
0 g
s
.36576 .55389 m .35875 .5642 L .3473 .56162 L p 1 0 0 r
F P
0 g
s
.42086 .533 m .42786 .52882 L .43896 .53726 L p 0 1 0 r
F P
0 g
s
.34751 .48729 m .35421 .48196 L .36538 .49016 L p 0 1 0 r
F P
0 g
s
.35421 .48196 m .34751 .48729 L .33633 .47977 L p 0 1 0 r
F P
0 g
s
.20521 .62187 m .19715 .64411 L .18342 .65594 L p 0 1 0 r
F P
0 g
s
.18342 .65594 m .19179 .63175 L .20521 .62187 L p 0 1 0 r
F P
0 g
s
.15367 .52966 m .15986 .52194 L .1716 .52704 L p 0 0 1 r
F P
0 g
s
.15986 .52194 m .15367 .52966 L .1419 .52457 L p 0 0 1 r
F P
0 g
s
.20758 .52179 m .20123 .52951 L .18957 .52442 L p 0 0 1 r
F P
0 g
s
.61097 .46521 m .60385 .48356 L .59351 .48782 L p 0 1 0 r
F P
0 g
s
.2488 .52936 m .25531 .52163 L .26684 .52674 L p 0 0 1 r
F P
0 g
s
.2305 .53475 m .2231 .55132 L .21035 .55609 L p 0 1 0 r
F P
0 g
s
.21035 .55609 m .21795 .53808 L .2305 .53475 L p 0 1 0 r
F P
0 g
s
.29637 .52921 m .30304 .52148 L .31446 .52659 L p 0 0 1 r
F P
0 g
s
.30304 .52148 m .29637 .52921 L .28492 .52411 L p 0 0 1 r
F P
0 g
s
.34395 .52906 m .35078 .52133 L .3621 .52644 L p 0 0 1 r
F P
0 g
s
.35078 .52133 m .34395 .52906 L .3326 .52396 L p 0 0 1 r
F P
0 g
s
.5125 .57431 m .5199 .56709 L .53084 .57137 L p 0 1 0 r
F P
0 g
s
.5199 .56709 m .5125 .57431 L .50152 .56871 L p 0 1 0 r
F P
0 g
s
.43913 .52876 m .44627 .52102 L .45739 .52613 L p 0 0 1 r
F P
0 g
s
.44627 .52102 m .43913 .52876 L .42799 .52366 L p 0 0 1 r
F P
0 g
s
.48673 .5286 m .49403 .52087 L .50504 .52598 L p 0 0 1 r
F P
0 g
s
.49403 .52087 m .48673 .5286 L .47569 .5235 L p 0 0 1 r
F P
0 g
s
.30712 .47324 m .31378 .46594 L .32508 .47263 L p 0 1 0 r
F P
0 g
s
.31378 .46594 m .30712 .47324 L .29571 .46771 L p 0 1 0 r
F P
0 g
s
.32209 .57606 m .32891 .56764 L .34037 .57111 L p 1 0 0 r
F P
0 g
s
.32891 .56764 m .32209 .57606 L .31067 .57142 L p 1 0 0 r
F P
0 g
s
.53433 .52845 m .54179 .52072 L .5527 .52583 L p 0 0 1 r
F P
0 g
s
.54179 .52072 m .53433 .52845 L .5234 .52335 L p 0 0 1 r
F P
0 g
s
.36576 .55389 m .37282 .54323 L .38424 .545 L p 1 0 0 r
F P
0 g
s
.39134 .53392 m .38424 .545 L .37282 .54323 L p 1 0 0 r
F P
0 g
s
.19424 .67998 m .18576 .70557 L p .1818 .70278 L 0 1 0 r
F P
0 g
s
.1818 .70278 m .17911 .69764 L p .19424 .67998 L 0 1 0 r
F P
0 g
s
.17911 .69764 m .18029 .69392 L .19424 .67998 L p 0 1 0 r
F P
0 g
s
.61242 .55498 m .60419 .55286 L .59296 .5386 L p 1 0 0 r
F P
0 g
s
.59296 .5386 m .60104 .53935 L .61242 .55498 L p 1 0 0 r
F P
0 g
s
.3473 .56162 m .34037 .57111 L .32891 .56764 L p 1 0 0 r
F P
0 g
s
.2231 .55132 m .21556 .5692 L .20257 .57554 L p 0 1 0 r
F P
0 g
s
.20257 .57554 m .21035 .55609 L .2231 .55132 L p 0 1 0 r
F P
0 g
s
.55656 .55519 m .564 .54395 L .57467 .54393 L p 0 1 0 r
F P
0 g
s
.58204 .53066 m .57467 .54393 L .564 .54395 L p 0 1 0 r
F P
0 g
s
.62956 .52815 m .63734 .52041 L .64804 .52553 L p 0 0 1 r
F P
0 g
s
.63734 .52041 m .62956 .52815 L .61883 .52305 L p 0 0 1 r
F P
0 g
s
.67718 .528 m .68512 .52026 L .69571 .52537 L p 0 0 1 r
F P
0 g
s
.68512 .52026 m .67718 .528 L .66656 .5229 L p 0 0 1 r
F P
0 g
s
.72481 .52785 m .73291 .52011 L .7434 .52522 L p 0 0 1 r
F P
0 g
s
.73291 .52011 m .72481 .52785 L .71429 .52274 L p 0 0 1 r
F P
0 g
s
.77245 .52769 m .7807 .51995 L .79109 .52507 L p 0 0 1 r
F P
0 g
s
.7807 .51995 m .77245 .52769 L .76203 .52259 L p 0 0 1 r
F P
0 g
s
.46092 .4846 m .46816 .47456 L .47923 .47813 L p 1 0 0 r
F P
0 g
s
.47923 .47813 m .48651 .469 L .49754 .47364 L p 1 0 0 r
F P
0 g
s
.48651 .469 m .47923 .47813 L .46816 .47456 L p 1 0 0 r
F P
0 g
s
.62188 .41046 m .61496 .43201 L .6048 .4386 L p 0 1 0 r
F P
0 g
s
.6048 .4386 m .61189 .41828 L .62188 .41046 L p 0 1 0 r
F P
0 g
s
.82009 .52754 m .8285 .5198 L .83879 .52492 L p 0 0 1 r
F P
0 g
s
.8285 .5198 m .82009 .52754 L .80978 .52244 L p 0 0 1 r
F P
0 g
s
.53084 .57137 m .53827 .56275 L .54912 .56546 L p 0 1 0 r
F P
0 g
s
.55656 .55519 m .54912 .56546 L .53827 .56275 L p 0 1 0 r
F P
0 g
s
.07638 .52735 m .08233 .51961 L .09425 .52472 L p 0 0 1 r
F P
0 g
s
.08233 .51961 m .07638 .52735 L .06444 .52224 L p 0 0 1 r
F P
0 g
s
.47217 .56097 m .47943 .55574 L .49049 .5625 L p 0 1 0 r
F P
0 g
s
.47943 .55574 m .47217 .56097 L .46112 .5534 L p 0 1 0 r
F P
0 g
s
.12399 .5272 m .13009 .51945 L .1419 .52457 L p 0 0 1 r
F P
0 g
s
.13009 .51945 m .12399 .5272 L .11215 .52209 L p 0 0 1 r
F P
0 g
s
.29268 .57244 m .29924 .56609 L .31067 .57142 L p 1 0 0 r
F P
0 g
s
.29924 .56609 m .29268 .57244 L .28137 .56556 L p 1 0 0 r
F P
0 g
s
.52686 .47834 m .53435 .47258 L .54537 .481 L p 1 0 0 r
F P
0 g
s
.53435 .47258 m .52686 .47834 L .51589 .47163 L p 1 0 0 r
F P
0 g
s
.1716 .52704 m .17786 .5193 L .18957 .52442 L p 0 0 1 r
F P
0 g
s
.17786 .5193 m .1716 .52704 L .15986 .52194 L p 0 0 1 r
F P
0 g
s
.33633 .47977 m .343 .47404 L .35421 .48196 L p 0 1 0 r
F P
0 g
s
.343 .47404 m .33633 .47977 L .32508 .47263 L p 0 1 0 r
F P
0 g
s
.49754 .47364 m .50488 .46566 L .51589 .47163 L p 1 0 0 r
F P
0 g
s
.50488 .46566 m .49754 .47364 L .48651 .469 L p 1 0 0 r
F P
0 g
s
.53827 .56275 m .53084 .57137 L .5199 .56709 L p 0 1 0 r
F P
0 g
s
.26684 .52674 m .27342 .51899 L .28492 .52411 L p 0 0 1 r
F P
0 g
s
.27342 .51899 m .26684 .52674 L .25531 .52163 L p 0 0 1 r
F P
0 g
s
.31446 .52659 m .3212 .51884 L .3326 .52396 L p 0 0 1 r
F P
0 g
s
.3212 .51884 m .31446 .52659 L .30304 .52148 L p 0 0 1 r
F P
0 g
s
.44256 .49261 m .44978 .48188 L .46092 .4846 L p 1 0 0 r
F P
0 g
s
.46816 .47456 m .46092 .4846 L .44978 .48188 L p 1 0 0 r
F P
0 g
s
.3621 .52644 m .369 .51869 L .38029 .52381 L p 0 0 1 r
F P
0 g
s
.369 .51869 m .3621 .52644 L .35078 .52133 L p 0 0 1 r
F P
0 g
s
.63044 .32968 m .63082 .3308 L .62926 .33272 L p 0 1 0 r
F P
0 g
s
.45739 .52613 m .4646 .51838 L .47569 .5235 L p 0 0 1 r
F P
0 g
s
.4646 .51838 m .45739 .52613 L .44627 .52102 L p 0 0 1 r
F P
0 g
s
.67451 .70854 m .67637 .71263 L .67649 .71777 L p 1 0 0 r
F P
0 g
s
.50504 .52598 m .51241 .51823 L .5234 .52335 L p 0 0 1 r
F P
0 g
s
.51241 .51823 m .50504 .52598 L .49403 .52087 L p 0 0 1 r
F P
0 g
s
.564 .54395 m .57142 .53166 L .58204 .53066 L p 0 1 0 r
F P
0 g
s
.66563 .66406 m .65652 .6549 L .64469 .63327 L p 1 0 0 r
F P
0 g
s
.64469 .63327 m .65354 .64054 L .66563 .66406 L p 1 0 0 r
F P
0 g
s
.5527 .52583 m .56023 .51808 L .57111 .5232 L p 0 0 1 r
F P
0 g
s
.56023 .51808 m .5527 .52583 L .54179 .52072 L p 0 0 1 r
F P
0 g
s
.21556 .5692 m .20784 .5885 L .1946 .59651 L p 0 1 0 r
F P
0 g
s
.1946 .59651 m .20257 .57554 L .21556 .5692 L p 0 1 0 r
F P
0 g
s
.67408 .69357 m .6748 .69752 L p .65948 .66937 L 1 0 0 r
F P
0 g
s
.6748 .69752 m .67156 .69357 L .65948 .66937 L p 1 0 0 r
F P
0 g
s
.65948 .66937 m .6686 .67875 L p .67408 .69357 L 1 0 0 r
F P
0 g
s
.60036 .52568 m .60806 .51792 L .61883 .52305 L p 0 0 1 r
F P
0 g
s
.64804 .52553 m .65589 .51777 L .66656 .5229 L p 0 0 1 r
F P
0 g
s
.65589 .51777 m .64804 .52553 L .63734 .52041 L p 0 0 1 r
F P
0 g
s
.25888 .48003 m .25193 .49213 L .23986 .49168 L p 0 1 0 r
F P
0 g
s
.62926 .33272 m .63022 .32865 L .63044 .32968 L p 0 1 0 r
F P
0 g
s
.69571 .52537 m .70372 .51762 L .71429 .52274 L p 0 0 1 r
F P
0 g
s
.70372 .51762 m .69571 .52537 L .68512 .52026 L p 0 0 1 r
F P
0 g
s
.7434 .52522 m .75157 .51747 L .76203 .52259 L p 0 0 1 r
F P
0 g
s
.75157 .51747 m .7434 .52522 L .73291 .52011 L p 0 0 1 r
F P
0 g
s
.79109 .52507 m .79942 .51731 L .80978 .52244 L p 0 0 1 r
F P
0 g
s
.79942 .51731 m .79109 .52507 L .7807 .51995 L p 0 0 1 r
F P
0 g
s
.84727 .51716 m .83879 .52492 L .8285 .5198 L p 0 0 1 r
F P
0 g
s
.3473 .56162 m .35429 .55163 L .36576 .55389 L p 1 0 0 r
F P
0 g
s
.37282 .54323 m .36576 .55389 L .35429 .55163 L p 1 0 0 r
F P
0 g
s
.09425 .52472 m .10026 .51696 L .11215 .52209 L p 0 0 1 r
F P
0 g
s
.10026 .51696 m .09425 .52472 L .08233 .51961 L p 0 0 1 r
F P
0 g
s
.46112 .5534 m .46833 .5485 L .47943 .55574 L p 0 1 0 r
F P
0 g
s
.46833 .5485 m .46112 .5534 L .45005 .54547 L p 0 1 0 r
F P
0 g
s
.1419 .52457 m .14807 .51681 L .15986 .52194 L p 0 0 1 r
F P
0 g
s
.14807 .51681 m .1419 .52457 L .13009 .51945 L p 0 0 1 r
F P
0 g
s
.25888 .48003 m .26575 .46886 L .27745 .47223 L p 0 1 0 r
F P
0 g
s
.27745 .47223 m .2842 .4628 L .29571 .46771 L p 0 1 0 r
F P
0 g
s
.2842 .4628 m .27745 .47223 L .26575 .46886 L p 0 1 0 r
F P
0 g
s
.50152 .56871 m .50889 .56208 L .5199 .56709 L p 0 1 0 r
F P
0 g
s
.50889 .56208 m .50152 .56871 L .49049 .5625 L p 0 1 0 r
F P
0 g
s
.62825 .32282 m .63022 .32865 L p .6195 .34309 L 0 1 0 r
F P
0 g
s
.63022 .32865 m .62926 .33272 L .6195 .34309 L p 0 1 0 r
F P
0 g
s
.18957 .52442 m .1959 .51666 L .20758 .52179 L p 0 0 1 r
F P
0 g
s
.1959 .51666 m .18957 .52442 L .17786 .5193 L p 0 0 1 r
F P
0 g
s
.62395 .57222 m .61553 .56861 L .60419 .55286 L p 1 0 0 r
F P
0 g
s
.60419 .55286 m .61242 .55498 L .62395 .57222 L p 1 0 0 r
F P
0 g
s
.28492 .52411 m .29156 .51635 L .30304 .52148 L p 0 0 1 r
F P
0 g
s
.29156 .51635 m .28492 .52411 L .27342 .51899 L p 0 0 1 r
F P
0 g
s
.3326 .52396 m .33941 .5162 L .35078 .52133 L p 0 0 1 r
F P
0 g
s
.33941 .5162 m .3326 .52396 L .3212 .51884 L p 0 0 1 r
F P
0 g
s
.37282 .54323 m .37991 .53227 L .39134 .53392 L p 1 0 0 r
F P
0 g
s
.39847 .52267 m .39134 .53392 L .37991 .53227 L p 1 0 0 r
F P
0 g
s
.28137 .56556 m .28783 .56 L .29924 .56609 L p 1 0 0 r
F P
0 g
s
.28783 .56 m .28137 .56556 L .2701 .55781 L p 1 0 0 r
F P
0 g
s
.38726 .51604 m .38029 .52381 L .369 .51869 L p 0 0 1 r
F P
0 g
s
.32508 .47263 m .33175 .46643 L .343 .47404 L p 0 1 0 r
F P
0 g
s
.33175 .46643 m .32508 .47263 L .31378 .46594 L p 0 1 0 r
F P
0 g
s
.29571 .46771 m .3024 .45975 L .31378 .46594 L p 0 1 0 r
F P
0 g
s
.3024 .45975 m .29571 .46771 L .2842 .4628 L p 0 1 0 r
F P
0 g
s
.44978 .48188 m .44256 .49261 L .43133 .49049 L p 1 0 0 r
F P
0 g
s
.42799 .52366 m .43511 .51589 L .44627 .52102 L p 0 0 1 r
F P
0 g
s
.62565 .37296 m .61884 .39641 L .60877 .40423 L p 0 1 0 r
F P
0 g
s
.60877 .40423 m .61576 .38203 L .62565 .37296 L p 0 1 0 r
F P
0 g
s
.51589 .47163 m .52333 .46504 L .53435 .47258 L p 1 0 0 r
F P
0 g
s
.52333 .46504 m .51589 .47163 L .50488 .46566 L p 1 0 0 r
F P
0 g
s
.65055 .62627 m .64169 .61919 L .63006 .59981 L p 1 0 0 r
F P
0 g
s
.63006 .59981 m .63868 .60516 L .65055 .62627 L p 1 0 0 r
F P
0 g
s
.47569 .5235 m .48297 .51574 L .49403 .52087 L p 0 0 1 r
F P
0 g
s
.48297 .51574 m .47569 .5235 L .4646 .51838 L p 0 0 1 r
F P
0 g
s
.5234 .52335 m .53084 .51558 L .54179 .52072 L p 0 0 1 r
F P
0 g
s
.53084 .51558 m .5234 .52335 L .51241 .51823 L p 0 0 1 r
F P
0 g
s
.19715 .64411 m .18885 .66809 L .17477 .68201 L p 0 1 0 r
F P
0 g
s
.17477 .68201 m .18342 .65594 L .19715 .64411 L p 0 1 0 r
F P
0 g
s
.61883 .52305 m .62659 .51528 L .63734 .52041 L p 0 0 1 r
F P
0 g
s
.62659 .51528 m .61883 .52305 L .60806 .51792 L p 0 0 1 r
F P
0 g
s
.31067 .57142 m .31742 .56359 L .32891 .56764 L p 1 0 0 r
F P
0 g
s
.31742 .56359 m .31067 .57142 L .29924 .56609 L p 1 0 0 r
F P
0 g
s
.66656 .5229 m .67448 .51512 L .68512 .52026 L p 0 0 1 r
F P
0 g
s
.67448 .51512 m .66656 .5229 L .65589 .51777 L p 0 0 1 r
F P
0 g
s
.67622 .71173 m .67637 .71263 L .67451 .70854 L p 1 0 0 r
F P
0 g
s
.67451 .70854 m .67619 .71063 L .67622 .71173 L p 1 0 0 r
F P
0 g
s
.71429 .52274 m .72237 .51497 L .73291 .52011 L p 0 0 1 r
F P
0 g
s
.72237 .51497 m .71429 .52274 L .70372 .51762 L p 0 0 1 r
F P
0 g
s
.76203 .52259 m .77027 .51482 L .7807 .51995 L p 0 0 1 r
F P
0 g
s
.77027 .51482 m .76203 .52259 L .75157 .51747 L p 0 0 1 r
F P
0 g
s
.62926 .33272 m .6226 .35821 L .61263 .3673 L p 0 1 0 r
F P
0 g
s
.61263 .3673 m .6195 .34309 L .62926 .33272 L p 0 1 0 r
F P
0 g
s
.80978 .52244 m .81817 .51466 L .8285 .5198 L p 0 0 1 r
F P
0 g
s
.81817 .51466 m .80978 .52244 L .79942 .51731 L p 0 0 1 r
F P
0 g
s
.45005 .54547 m .45722 .54085 L .46833 .5485 L p 0 1 0 r
F P
0 g
s
.45722 .54085 m .45005 .54547 L .43896 .53726 L p 0 1 0 r
F P
0 g
s
.32891 .56764 m .3358 .55859 L .3473 .56162 L p 1 0 0 r
F P
0 g
s
.35429 .55163 m .3473 .56162 L .3358 .55859 L p 1 0 0 r
F P
0 g
s
.53827 .56275 m .54573 .5533 L .55656 .55519 L p 0 1 0 r
F P
0 g
s
.564 .54395 m .55656 .55519 L .54573 .5533 L p 0 1 0 r
F P
0 g
s
.06444 .52224 m .07036 .51447 L .08233 .51961 L p 0 0 1 r
F P
0 g
s
.20784 .5885 m .19992 .60931 L .18639 .61913 L p 0 1 0 r
F P
0 g
s
.18639 .61913 m .1946 .59651 L .20784 .5885 L p 0 1 0 r
F P
0 g
s
.11215 .52209 m .11823 .51431 L .13009 .51945 L p 0 0 1 r
F P
0 g
s
.11823 .51431 m .11215 .52209 L .10026 .51696 L p 0 0 1 r
F P
0 g
s
.23986 .49168 m .24693 .4785 L .25888 .48003 L p 0 1 0 r
F P
0 g
s
.26575 .46886 m .25888 .48003 L .24693 .4785 L p 0 1 0 r
F P
0 g
s
.15986 .52194 m .1661 .51416 L .17786 .5193 L p 0 0 1 r
F P
0 g
s
.1661 .51416 m .15986 .52194 L .14807 .51681 L p 0 0 1 r
F P
0 g
s
.21398 .51401 m .20758 .52179 L .1959 .51666 L p 0 0 1 r
F P
0 g
s
.25531 .52163 m .26186 .51385 L .27342 .51899 L p 0 0 1 r
F P
0 g
s
.26186 .51385 m .25531 .52163 L .24373 .5165 L p 0 0 1 r
F P
0 g
s
.3358 .55859 m .32891 .56764 L .31742 .56359 L p 1 0 0 r
F P
0 g
s
.30304 .52148 m .30975 .5137 L .3212 .51884 L p 0 0 1 r
F P
0 g
s
.30975 .5137 m .30304 .52148 L .29156 .51635 L p 0 0 1 r
F P
0 g
s
.2701 .55781 m .27645 .5531 L .28783 .56 L p 1 0 0 r
F P
0 g
s
.27645 .5531 m .2701 .55781 L .2589 .54913 L p 1 0 0 r
F P
0 g
s
.35078 .52133 m .35765 .51355 L .369 .51869 L p 0 0 1 r
F P
0 g
s
.35765 .51355 m .35078 .52133 L .33941 .5162 L p 0 0 1 r
F P
0 g
s
.61496 .43201 m .60791 .45205 L .59761 .45743 L p 0 1 0 r
F P
0 g
s
.59761 .45743 m .6048 .4386 L .61496 .43201 L p 0 1 0 r
F P
0 g
s
.46816 .47456 m .47544 .46489 L .48651 .469 L p 1 0 0 r
F P
0 g
s
.48651 .469 m .49384 .46037 L .50488 .46566 L p 1 0 0 r
F P
0 g
s
.49384 .46037 m .48651 .469 L .47544 .46489 L p 1 0 0 r
F P
0 g
s
.44627 .52102 m .45347 .51324 L .4646 .51838 L p 0 0 1 r
F P
0 g
s
.45347 .51324 m .44627 .52102 L .43511 .51589 L p 0 0 1 r
F P
0 g
s
.5199 .56709 m .52733 .55918 L .53827 .56275 L p 0 1 0 r
F P
0 g
s
.52733 .55918 m .5199 .56709 L .50889 .56208 L p 0 1 0 r
F P
0 g
s
.44978 .48188 m .45702 .47141 L .46816 .47456 L p 1 0 0 r
F P
0 g
s
.47544 .46489 m .46816 .47456 L .45702 .47141 L p 1 0 0 r
F P
0 g
s
.49403 .52087 m .50138 .51309 L .51241 .51823 L p 0 0 1 r
F P
0 g
s
.50138 .51309 m .49403 .52087 L .48297 .51574 L p 0 0 1 r
F P
0 g
s
.54179 .52072 m .54931 .51293 L .56023 .51808 L p 0 0 1 r
F P
0 g
s
.54931 .51293 m .54179 .52072 L .53084 .51558 L p 0 0 1 r
F P
0 g
s
.49049 .5625 m .49784 .55639 L .50889 .56208 L p 0 1 0 r
F P
0 g
s
.49784 .55639 m .49049 .5625 L .47943 .55574 L p 0 1 0 r
F P
0 g
s
.63734 .52041 m .64517 .51262 L .65589 .51777 L p 0 0 1 r
F P
0 g
s
.64517 .51262 m .63734 .52041 L .62659 .51528 L p 0 0 1 r
F P
0 g
s
.43896 .53726 m .44608 .53284 L .45722 .54085 L p 0 1 0 r
F P
0 g
s
.44608 .53284 m .43896 .53726 L .42786 .52882 L p 0 1 0 r
F P
0 g
s
.68512 .52026 m .69311 .51247 L .70372 .51762 L p 0 0 1 r
F P
0 g
s
.69311 .51247 m .68512 .52026 L .67448 .51512 L p 0 0 1 r
F P
0 g
s
.31378 .46594 m .32044 .4592 L .33175 .46643 L p 0 1 0 r
F P
0 g
s
.32044 .4592 m .31378 .46594 L .3024 .45975 L p 0 1 0 r
F P
0 g
s
.73291 .52011 m .74106 .51232 L .75157 .51747 L p 0 0 1 r
F P
0 g
s
.74106 .51232 m .73291 .52011 L .72237 .51497 L p 0 0 1 r
F P
0 g
s
.54573 .5533 m .53827 .56275 L .52733 .55918 L p 0 1 0 r
F P
0 g
s
.7807 .51995 m .78901 .51216 L .79942 .51731 L p 0 0 1 r
F P
0 g
s
.78901 .51216 m .7807 .51995 L .77027 .51482 L p 0 0 1 r
F P
0 g
s
.35429 .55163 m .36133 .54121 L .37282 .54323 L p 1 0 0 r
F P
0 g
s
.37991 .53227 m .37282 .54323 L .36133 .54121 L p 1 0 0 r
F P
0 g
s
.2589 .54913 m .26511 .54534 L .27645 .5531 L p 1 0 0 r
F P
0 g
s
.26511 .54534 m .2589 .54913 L .24778 .53947 L p 1 0 0 r
F P
0 g
s
.8285 .5198 m .83697 .51201 L .84727 .51716 L p 0 0 1 r
F P
0 g
s
.83697 .51201 m .8285 .5198 L .81817 .51466 L p 0 0 1 r
F P
0 g
s
.25383 .53666 m .24778 .53947 L .23676 .5288 L p 1 0 0 r
F P
0 g
s
.23676 .5288 m .24264 .52701 L .25383 .53666 L p 1 0 0 r
F P
0 g
s
.37991 .53227 m .38705 .52107 L .39847 .52267 L p 1 0 0 r
F P
0 g
s
.08233 .51961 m .08831 .51181 L .10026 .51696 L p 0 0 1 r
F P
0 g
s
.08831 .51181 m .08233 .51961 L .07036 .51447 L p 0 0 1 r
F P
0 g
s
.13009 .51945 m .13624 .51166 L .14807 .51681 L p 0 0 1 r
F P
0 g
s
.13624 .51166 m .13009 .51945 L .11823 .51431 L p 0 0 1 r
F P
0 g
s
.36094 .47696 m .35421 .48196 L .343 .47404 L p 0 1 0 r
F P
0 g
s
.24778 .53947 m .25383 .53666 L .26511 .54534 L p 1 0 0 r
F P
0 g
s
.17786 .5193 m .18416 .51151 L .1959 .51666 L p 0 0 1 r
F P
0 g
s
.18416 .51151 m .17786 .5193 L .1661 .51416 L p 0 0 1 r
F P
0 g
s
.50488 .46566 m .51228 .4583 L .52333 .46504 L p 1 0 0 r
F P
0 g
s
.51228 .4583 m .50488 .46566 L .49384 .46037 L p 1 0 0 r
F P
0 g
s
.62618 .31717 m .62688 .31632 L .62825 .32282 L p 0 1 0 r
F P
0 g
s
.6195 .34309 m .62618 .31717 L p .62825 .32282 L 0 1 0 r
F P
0 g
s
.27342 .51899 m .28004 .5112 L .29156 .51635 L p 0 0 1 r
F P
0 g
s
.28004 .5112 m .27342 .51899 L .26186 .51385 L p 0 0 1 r
F P
0 g
s
.18576 .70557 m .18446 .70968 L .18413 .70878 L p 0 1 0 r
F P
0 g
s
.18413 .70878 m .18368 .70792 L .18576 .70557 L p 0 1 0 r
F P
0 g
s
.18576 .70557 m .18368 .70792 L .1818 .70278 L p 0 1 0 r
F P
0 g
s
.3212 .51884 m .32799 .51104 L .33941 .5162 L p 0 0 1 r
F P
0 g
s
.32799 .51104 m .3212 .51884 L .30975 .5137 L p 0 0 1 r
F P
0 g
s
.63564 .5912 m .62702 .586 L .61553 .56861 L p 1 0 0 r
F P
0 g
s
.61553 .56861 m .62395 .57222 L .63564 .5912 L p 1 0 0 r
F P
0 g
s
.43133 .49049 m .43856 .47946 L .44978 .48188 L p 1 0 0 r
F P
0 g
s
.45702 .47141 m .44978 .48188 L .43856 .47946 L p 1 0 0 r
F P
0 g
s
.369 .51869 m .37594 .51089 L .38726 .51604 L p 0 0 1 r
F P
0 g
s
.37594 .51089 m .369 .51869 L .35765 .51355 L p 0 0 1 r
F P
0 g
s
.42786 .52882 m .43493 .52454 L .44608 .53284 L p 0 1 0 r
F P
0 g
s
.43493 .52454 m .42786 .52882 L .41675 .52022 L p 0 1 0 r
F P
0 g
s
.4646 .51838 m .47186 .51058 L .48297 .51574 L p 0 0 1 r
F P
0 g
s
.47186 .51058 m .4646 .51838 L .45347 .51324 L p 0 0 1 r
F P
0 g
s
.26575 .46886 m .27257 .45858 L .2842 .4628 L p 0 1 0 r
F P
0 g
s
.2842 .4628 m .29092 .45411 L .3024 .45975 L p 0 1 0 r
F P
0 g
s
.29092 .45411 m .2842 .4628 L .27257 .45858 L p 0 1 0 r
F P
0 g
s
.51241 .51823 m .51984 .51043 L .53084 .51558 L p 0 0 1 r
F P
0 g
s
.51984 .51043 m .51241 .51823 L .50138 .51309 L p 0 0 1 r
F P
0 g
s
.29924 .56609 m .30592 .55892 L .31742 .56359 L p 1 0 0 r
F P
0 g
s
.30592 .55892 m .29924 .56609 L .28783 .56 L p 1 0 0 r
F P
0 g
s
.56781 .51027 m .56023 .51808 L .54931 .51293 L p 0 0 1 r
F P
0 g
s
.54573 .5533 m .5532 .54294 L .564 .54395 L p 0 1 0 r
F P
0 g
s
.57142 .53166 m .564 .54395 L .5532 .54294 L p 0 1 0 r
F P
0 g
s
.60806 .51792 m .6158 .51012 L .62659 .51528 L p 0 0 1 r
F P
0 g
s
.6158 .51012 m .60806 .51792 L .59723 .51278 L p 0 0 1 r
F P
0 g
s
.65589 .51777 m .66379 .50997 L .67448 .51512 L p 0 0 1 r
F P
0 g
s
.66379 .50997 m .65589 .51777 L .64517 .51262 L p 0 0 1 r
F P
0 g
s
.70372 .51762 m .71179 .50981 L .72237 .51497 L p 0 0 1 r
F P
0 g
s
.71179 .50981 m .70372 .51762 L .69311 .51247 L p 0 0 1 r
F P
0 g
s
.24693 .4785 m .2539 .46633 L .26575 .46886 L p 0 1 0 r
F P
0 g
s
.27257 .45858 m .26575 .46886 L .2539 .46633 L p 0 1 0 r
F P
0 g
s
.75157 .51747 m .75979 .50966 L .77027 .51482 L p 0 0 1 r
F P
0 g
s
.75979 .50966 m .75157 .51747 L .74106 .51232 L p 0 0 1 r
F P
0 g
s
.79942 .51731 m .8078 .5095 L .81817 .51466 L p 0 0 1 r
F P
0 g
s
.8078 .5095 m .79942 .51731 L .78901 .51216 L p 0 0 1 r
F P
0 g
s
.54193 .46763 m .53435 .47258 L .52333 .46504 L p 1 0 0 r
F P
0 g
s
.85582 .50935 m .84727 .51716 L .83697 .51201 L p 0 0 1 r
F P
0 g
s
.47943 .55574 m .48674 .55009 L .49784 .55639 L p 0 1 0 r
F P
0 g
s
.48674 .55009 m .47943 .55574 L .46833 .5485 L p 0 1 0 r
F P
0 g
s
.19992 .60931 m .19179 .63175 L .17794 .64352 L p 0 1 0 r
F P
0 g
s
.17794 .64352 m .18639 .61913 L .19992 .60931 L p 0 1 0 r
F P
0 g
s
.343 .47404 m .34971 .46868 L .36094 .47696 L p 0 1 0 r
F P
0 g
s
.34971 .46868 m .343 .47404 L .33175 .46643 L p 0 1 0 r
F P
0 g
s
.10026 .51696 m .10631 .50915 L .11823 .51431 L p 0 0 1 r
F P
0 g
s
.10631 .50915 m .10026 .51696 L .08831 .51181 L p 0 0 1 r
F P
0 g
s
.22539 .52139 m .21795 .53808 L .2051 .54276 L p 0 1 0 r
F P
0 g
s
.2051 .54276 m .21275 .52462 L .22539 .52139 L p 0 1 0 r
F P
0 g
s
.3358 .55859 m .34275 .54899 L .35429 .55163 L p 1 0 0 r
F P
0 g
s
.36133 .54121 m .35429 .55163 L .34275 .54899 L p 1 0 0 r
F P
0 g
s
.41675 .52022 m .42376 .51602 L .43493 .52454 L p 0 1 0 r
F P
0 g
s
.14807 .51681 m .15429 .509 L .1661 .51416 L p 0 0 1 r
F P
0 g
s
.15429 .509 m .14807 .51681 L .13624 .51166 L p 0 0 1 r
F P
0 g
s
.1959 .51666 m .20227 .50884 L .21398 .51401 L p 0 0 1 r
F P
0 g
s
.20227 .50884 m .1959 .51666 L .18416 .51151 L p 0 0 1 r
F P
0 g
s
.24373 .5165 m .25026 .50869 L .26186 .51385 L p 0 0 1 r
F P
0 g
s
.29156 .51635 m .29826 .50854 L .30975 .5137 L p 0 0 1 r
F P
0 g
s
.29826 .50854 m .29156 .51635 L .28004 .5112 L p 0 0 1 r
F P
0 g
s
.33941 .5162 m .34626 .50838 L .35765 .51355 L p 0 0 1 r
F P
0 g
s
.34626 .50838 m .33941 .5162 L .32799 .51104 L p 0 0 1 r
F P
0 g
s
.3024 .45975 m .30907 .45241 L .32044 .4592 L p 0 1 0 r
F P
0 g
s
.30907 .45241 m .3024 .45975 L .29092 .45411 L p 0 1 0 r
F P
0 g
s
.60929 .54135 m .60104 .53935 L .58977 .52518 L p 1 0 0 r
F P
0 g
s
.58977 .52518 m .59786 .52582 L .60929 .54135 L p 1 0 0 r
F P
0 g
s
.43511 .51589 m .44228 .50807 L .45347 .51324 L p 0 0 1 r
F P
0 g
s
.44228 .50807 m .43511 .51589 L .4239 .51074 L p 0 0 1 r
F P
0 g
s
.21795 .53808 m .21035 .55609 L .19727 .56234 L p 0 1 0 r
F P
0 g
s
.19727 .56234 m .2051 .54276 L .21795 .53808 L p 0 1 0 r
F P
0 g
s
.50889 .56208 m .51632 .55482 L .52733 .55918 L p 0 1 0 r
F P
0 g
s
.51632 .55482 m .50889 .56208 L .49784 .55639 L p 0 1 0 r
F P
0 g
s
.48297 .51574 m .4903 .50792 L .50138 .51309 L p 0 0 1 r
F P
0 g
s
.4903 .50792 m .48297 .51574 L .47186 .51058 L p 0 0 1 r
F P
0 g
s
.53084 .51558 m .53833 .50776 L .54931 .51293 L p 0 0 1 r
F P
0 g
s
.53833 .50776 m .53084 .51558 L .51984 .51043 L p 0 0 1 r
F P
0 g
s
.31742 .56359 m .32426 .55507 L .3358 .55859 L p 1 0 0 r
F P
0 g
s
.32426 .55507 m .31742 .56359 L .30592 .55892 L p 1 0 0 r
F P
0 g
s
.36133 .54121 m .36841 .53043 L .37991 .53227 L p 1 0 0 r
F P
0 g
s
.38705 .52107 m .37991 .53227 L .36841 .53043 L p 1 0 0 r
F P
0 g
s
.62659 .51528 m .63441 .50746 L .64517 .51262 L p 0 0 1 r
F P
0 g
s
.63441 .50746 m .62659 .51528 L .6158 .51012 L p 0 0 1 r
F P
0 g
s
.18885 .66809 m .18029 .69392 L p .17642 .69076 L 0 1 0 r
F P
0 g
s
.17642 .69076 m .17365 .68552 L p .18885 .66809 L 0 1 0 r
F P
0 g
s
.17365 .68552 m .17477 .68201 L .18885 .66809 L p 0 1 0 r
F P
0 g
s
.61884 .39641 m .61189 .41828 L .60166 .42485 L p 0 1 0 r
F P
0 g
s
.60166 .42485 m .60877 .40423 L .61884 .39641 L p 0 1 0 r
F P
0 g
s
.34275 .54899 m .3358 .55859 L .32426 .55507 L p 1 0 0 r
F P
0 g
s
.67271 .68128 m .6733 .68433 L p .65652 .6549 L 1 0 0 r
F P
0 g
s
.6733 .68433 m .6686 .67875 L .65652 .6549 L p 1 0 0 r
F P
0 g
s
.65652 .6549 m .66563 .66406 L p .67271 .68128 L 1 0 0 r
F P
0 g
s
.67448 .51512 m .68245 .5073 L .69311 .51247 L p 0 0 1 r
F P
0 g
s
.68245 .5073 m .67448 .51512 L .66379 .50997 L p 0 0 1 r
F P
0 g
s
.72237 .51497 m .73051 .50715 L .74106 .51232 L p 0 0 1 r
F P
0 g
s
.73051 .50715 m .72237 .51497 L .71179 .50981 L p 0 0 1 r
F P
0 g
s
.45702 .47141 m .46429 .46127 L .47544 .46489 L p 1 0 0 r
F P
0 g
s
.47544 .46489 m .48275 .45567 L .49384 .46037 L p 1 0 0 r
F P
0 g
s
.48275 .45567 m .47544 .46489 L .46429 .46127 L p 1 0 0 r
F P
0 g
s
.77027 .51482 m .77856 .50699 L .78901 .51216 L p 0 0 1 r
F P
0 g
s
.77856 .50699 m .77027 .51482 L .75979 .50966 L p 0 0 1 r
F P
0 g
s
.5532 .54294 m .56067 .5316 L .57142 .53166 L p 0 1 0 r
F P
0 g
s
.57883 .51826 m .57142 .53166 L .56067 .5316 L p 0 1 0 r
F P
0 g
s
.66266 .64949 m .65354 .64054 L .64169 .61919 L p 1 0 0 r
F P
0 g
s
.64169 .61919 m .65055 .62627 L .66266 .64949 L p 1 0 0 r
F P
0 g
s
.81817 .51466 m .82663 .50684 L .83697 .51201 L p 0 0 1 r
F P
0 g
s
.82663 .50684 m .81817 .51466 L .8078 .5095 L p 0 0 1 r
F P
0 g
s
.07036 .51447 m .07632 .50664 L .08831 .51181 L p 0 0 1 r
F P
0 g
s
.52333 .46504 m .53084 .4592 L .54193 .46763 L p 1 0 0 r
F P
0 g
s
.53084 .4592 m .52333 .46504 L .51228 .4583 L p 1 0 0 r
F P
0 g
s
.11823 .51431 m .12434 .50649 L .13624 .51166 L p 0 0 1 r
F P
0 g
s
.12434 .50649 m .11823 .51431 L .10631 .50915 L p 0 0 1 r
F P
0 g
s
.33175 .46643 m .33844 .46066 L .34971 .46868 L p 0 1 0 r
F P
0 g
s
.33844 .46066 m .33175 .46643 L .32044 .4592 L p 0 1 0 r
F P
0 g
s
.1661 .51416 m .17238 .50633 L .18416 .51151 L p 0 0 1 r
F P
0 g
s
.17238 .50633 m .1661 .51416 L .15429 .509 L p 0 0 1 r
F P
0 g
s
.28783 .56 m .29442 .55355 L .30592 .55892 L p 1 0 0 r
F P
0 g
s
.29442 .55355 m .28783 .56 L .27645 .5531 L p 1 0 0 r
F P
0 g
s
.46833 .5485 m .47561 .54325 L .48674 .55009 L p 0 1 0 r
F P
0 g
s
.47561 .54325 m .46833 .5485 L .45722 .54085 L p 0 1 0 r
F P
0 g
s
.49384 .46037 m .50121 .45229 L .51228 .4583 L p 1 0 0 r
F P
0 g
s
.50121 .45229 m .49384 .46037 L .48275 .45567 L p 1 0 0 r
F P
0 g
s
.52733 .55918 m .5348 .5505 L .54573 .5533 L p 0 1 0 r
F P
0 g
s
.5532 .54294 m .54573 .5533 L .5348 .5505 L p 0 1 0 r
F P
0 g
s
.26186 .51385 m .26846 .50602 L .28004 .5112 L p 0 0 1 r
F P
0 g
s
.26846 .50602 m .26186 .51385 L .25026 .50869 L p 0 0 1 r
F P
0 g
s
.30975 .5137 m .31651 .50587 L .32799 .51104 L p 0 0 1 r
F P
0 g
s
.31651 .50587 m .30975 .5137 L .29826 .50854 L p 0 0 1 r
F P
0 g
s
.43856 .47946 m .44581 .46862 L .45702 .47141 L p 1 0 0 r
F P
0 g
s
.46429 .46127 m .45702 .47141 L .44581 .46862 L p 1 0 0 r
F P
0 g
s
.35765 .51355 m .36457 .50571 L .37594 .51089 L p 0 0 1 r
F P
0 g
s
.36457 .50571 m .35765 .51355 L .34626 .50838 L p 0 0 1 r
F P
0 g
s
.5348 .5505 m .52733 .55918 L .51632 .55482 L p 0 1 0 r
F P
0 g
s
.21035 .55609 m .20257 .57554 L .18922 .58347 L p 0 1 0 r
F P
0 g
s
.18922 .58347 m .19727 .56234 L .21035 .55609 L p 0 1 0 r
F P
0 g
s
.45347 .51324 m .46071 .5054 L .47186 .51058 L p 0 0 1 r
F P
0 g
s
.46071 .5054 m .45347 .51324 L .44228 .50807 L p 0 0 1 r
F P
0 g
s
.50138 .51309 m .50878 .50525 L .51984 .51043 L p 0 0 1 r
F P
0 g
s
.50878 .50525 m .50138 .51309 L .4903 .50792 L p 0 0 1 r
F P
0 g
s
.2539 .46633 m .24693 .4785 L .23477 .47794 L p 0 1 0 r
F P
0 g
s
.6267 .31582 m .62688 .31632 L .62618 .31717 L p 0 1 0 r
F P
0 g
s
.67156 .69357 m .6752 .70143 L .67534 .70573 L p 1 0 0 r
F P
0 g
s
.54931 .51293 m .55687 .50509 L .56781 .51027 L p 0 0 1 r
F P
0 g
s
.55687 .50509 m .54931 .51293 L .53833 .50776 L p 0 0 1 r
F P
0 g
s
.59723 .51278 m .60496 .50494 L .6158 .51012 L p 0 0 1 r
F P
0 g
s
.67489 .69965 m .6752 .70143 L .67156 .69357 L p 1 0 0 r
F P
0 g
s
.67156 .69357 m .6748 .69752 L .67489 .69965 L p 1 0 0 r
F P
0 g
s
.64517 .51262 m .65305 .50479 L .66379 .50997 L p 0 0 1 r
F P
0 g
s
.65305 .50479 m .64517 .51262 L .63441 .50746 L p 0 0 1 r
F P
0 g
s
.62618 .31717 m .6266 .31536 L .6267 .31582 L p 0 1 0 r
F P
0 g
s
.56067 .5316 m .56813 .51919 L .57883 .51826 L p 0 1 0 r
F P
0 g
s
.69311 .51247 m .70116 .50463 L .71179 .50981 L p 0 0 1 r
F P
0 g
s
.70116 .50463 m .69311 .51247 L .68245 .5073 L p 0 0 1 r
F P
0 g
s
.74106 .51232 m .74927 .50448 L .75979 .50966 L p 0 0 1 r
F P
0 g
s
.74927 .50448 m .74106 .51232 L .73051 .50715 L p 0 0 1 r
F P
0 g
s
.62435 .3089 m .6266 .31536 L p .61635 .32758 L 0 1 0 r
F P
0 g
s
.6266 .31536 m .62618 .31717 L .61635 .32758 L p 0 1 0 r
F P
0 g
s
.78901 .51216 m .79738 .50432 L .8078 .5095 L p 0 0 1 r
F P
0 g
s
.79738 .50432 m .78901 .51216 L .77856 .50699 L p 0 0 1 r
F P
0 g
s
.62086 .55846 m .61242 .55498 L .60104 .53935 L p 1 0 0 r
F P
0 g
s
.60104 .53935 m .60929 .54135 L .62086 .55846 L p 1 0 0 r
F P
0 g
s
.2539 .46633 m .2608 .45511 L .27257 .45858 L p 0 1 0 r
F P
0 g
s
.27257 .45858 m .27934 .4491 L .29092 .45411 L p 0 1 0 r
F P
0 g
s
.27934 .4491 m .27257 .45858 L .2608 .45511 L p 0 1 0 r
F P
0 g
s
.83697 .51201 m .8455 .50417 L .85582 .50935 L p 0 0 1 r
F P
0 g
s
.8455 .50417 m .83697 .51201 L .82663 .50684 L p 0 0 1 r
F P
0 g
s
.64754 .61208 m .63868 .60516 L .62702 .586 L p 1 0 0 r
F P
0 g
s
.62702 .586 m .63564 .5912 L .64754 .61208 L p 1 0 0 r
F P
0 g
s
.08831 .51181 m .09434 .50397 L .10631 .50915 L p 0 0 1 r
F P
0 g
s
.09434 .50397 m .08831 .51181 L .07632 .50664 L p 0 0 1 r
F P
0 g
s
.6226 .35821 m .61576 .38203 L .60562 .38986 L p 0 1 0 r
F P
0 g
s
.60562 .38986 m .61263 .3673 L .6226 .35821 L p 0 1 0 r
F P
0 g
s
.34275 .54899 m .34977 .53889 L .36133 .54121 L p 1 0 0 r
F P
0 g
s
.36841 .53043 m .36133 .54121 L .34977 .53889 L p 1 0 0 r
F P
0 g
s
.13624 .51166 m .14242 .50381 L .15429 .509 L p 0 0 1 r
F P
0 g
s
.14242 .50381 m .13624 .51166 L .12434 .50649 L p 0 0 1 r
F P
0 g
s
.18416 .51151 m .19051 .50366 L .20227 .50884 L p 0 0 1 r
F P
0 g
s
.19051 .50366 m .18416 .51151 L .17238 .50633 L p 0 0 1 r
F P
0 g
s
.45722 .54085 m .46445 .53592 L .47561 .54325 L p 0 1 0 r
F P
0 g
s
.46445 .53592 m .45722 .54085 L .44608 .53284 L p 0 1 0 r
F P
0 g
s
.62618 .31717 m .6195 .34309 L .60946 .35221 L p 0 1 0 r
F P
0 g
s
.60946 .35221 m .61635 .32758 L .62618 .31717 L p 0 1 0 r
F P
0 g
s
.49784 .55639 m .50525 .54971 L .51632 .55482 L p 0 1 0 r
F P
0 g
s
.50525 .54971 m .49784 .55639 L .48674 .55009 L p 0 1 0 r
F P
0 g
s
.29092 .45411 m .29762 .44611 L .30907 .45241 L p 0 1 0 r
F P
0 g
s
.29762 .44611 m .29092 .45411 L .27934 .4491 L p 0 1 0 r
F P
0 g
s
.28004 .5112 m .28671 .50335 L .29826 .50854 L p 0 0 1 r
F P
0 g
s
.28671 .50335 m .28004 .5112 L .26846 .50602 L p 0 0 1 r
F P
0 g
s
.32044 .4592 m .32712 .45296 L .33844 .46066 L p 0 1 0 r
F P
0 g
s
.32712 .45296 m .32044 .4592 L .30907 .45241 L p 0 1 0 r
F P
0 g
s
.32799 .51104 m .33481 .50319 L .34626 .50838 L p 0 0 1 r
F P
0 g
s
.33481 .50319 m .32799 .51104 L .31651 .50587 L p 0 0 1 r
F P
0 g
s
.36841 .53043 m .37554 .51936 L .38705 .52107 L p 1 0 0 r
F P
0 g
s
.39421 .50972 m .38705 .52107 L .37554 .51936 L p 1 0 0 r
F P
0 g
s
.38293 .50304 m .37594 .51089 L .36457 .50571 L p 0 0 1 r
F P
0 g
s
.44581 .46862 m .43856 .47946 L .42725 .47727 L p 1 0 0 r
F P
0 g
s
.51228 .4583 m .51975 .45163 L .53084 .4592 L p 1 0 0 r
F P
0 g
s
.51975 .45163 m .51228 .4583 L .50121 .45229 L p 1 0 0 r
F P
0 g
s
.27645 .5531 m .28293 .54744 L .29442 .55355 L p 1 0 0 r
F P
0 g
s
.28293 .54744 m .27645 .5531 L .26511 .54534 L p 1 0 0 r
F P
0 g
s
.4239 .51074 m .43105 .50288 L .44228 .50807 L p 0 0 1 r
F P
0 g
s
.47186 .51058 m .47918 .50273 L .4903 .50792 L p 0 0 1 r
F P
0 g
s
.47918 .50273 m .47186 .51058 L .46071 .5054 L p 0 0 1 r
F P
0 g
s
.51984 .51043 m .52731 .50257 L .53833 .50776 L p 0 0 1 r
F P
0 g
s
.52731 .50257 m .51984 .51043 L .50878 .50525 L p 0 0 1 r
F P
0 g
s
.19179 .63175 m .18342 .65594 L .1692 .66982 L p 0 1 0 r
F P
0 g
s
.1692 .66982 m .17794 .64352 L .19179 .63175 L p 0 1 0 r
F P
0 g
s
.6158 .51012 m .62359 .50226 L .63441 .50746 L p 0 0 1 r
F P
0 g
s
.62359 .50226 m .6158 .51012 L .60496 .50494 L p 0 0 1 r
F P
0 g
s
.66379 .50997 m .67175 .50211 L .68245 .5073 L p 0 0 1 r
F P
0 g
s
.67175 .50211 m .66379 .50997 L .65305 .50479 L p 0 0 1 r
F P
0 g
s
.30592 .55892 m .31269 .55098 L .32426 .55507 L p 1 0 0 r
F P
0 g
s
.31269 .55098 m .30592 .55892 L .29442 .55355 L p 1 0 0 r
F P
0 g
s
.71179 .50981 m .7199 .50195 L .73051 .50715 L p 0 0 1 r
F P
0 g
s
.7199 .50195 m .71179 .50981 L .70116 .50463 L p 0 0 1 r
F P
0 g
s
.75979 .50966 m .76807 .5018 L .77856 .50699 L p 0 0 1 r
F P
0 g
s
.76807 .5018 m .75979 .50966 L .74927 .50448 L p 0 0 1 r
F P
0 g
s
.20257 .57554 m .1946 .59651 L .18095 .60626 L p 0 1 0 r
F P
0 g
s
.18095 .60626 m .18922 .58347 L .20257 .57554 L p 0 1 0 r
F P
0 g
s
.23477 .47794 m .24187 .46469 L .2539 .46633 L p 0 1 0 r
F P
0 g
s
.2608 .45511 m .2539 .46633 L .24187 .46469 L p 0 1 0 r
F P
0 g
s
.8078 .5095 m .81624 .50164 L .82663 .50684 L p 0 0 1 r
F P
0 g
s
.81624 .50164 m .8078 .5095 L .79738 .50432 L p 0 0 1 r
F P
0 g
s
.86442 .50149 m .85582 .50935 L .8455 .50417 L p 0 0 1 r
F P
0 g
s
.32426 .55507 m .33118 .54591 L .34275 .54899 L p 1 0 0 r
F P
0 g
s
.34977 .53889 m .34275 .54899 L .33118 .54591 L p 1 0 0 r
F P
0 g
s
.44608 .53284 m .45327 .52818 L .46445 .53592 L p 0 1 0 r
F P
0 g
s
.45327 .52818 m .44608 .53284 L .43493 .52454 L p 0 1 0 r
F P
0 g
s
.10631 .50915 m .1124 .50129 L .12434 .50649 L p 0 0 1 r
F P
0 g
s
.1124 .50129 m .10631 .50915 L .09434 .50397 L p 0 0 1 r
F P
0 g
s
.15429 .509 m .16054 .50113 L .17238 .50633 L p 0 0 1 r
F P
0 g
s
.16054 .50113 m .15429 .509 L .14242 .50381 L p 0 0 1 r
F P
0 g
s
.20868 .50098 m .20227 .50884 L .19051 .50366 L p 0 0 1 r
F P
0 g
s
.5348 .5505 m .54229 .54097 L .5532 .54294 L p 0 1 0 r
F P
0 g
s
.56067 .5316 m .5532 .54294 L .54229 .54097 L p 0 1 0 r
F P
0 g
s
.25026 .50869 m .25683 .50082 L .26846 .50602 L p 0 0 1 r
F P
0 g
s
.25683 .50082 m .25026 .50869 L .2386 .5035 L p 0 0 1 r
F P
0 g
s
.61189 .41828 m .6048 .4386 L .59443 .44396 L p 0 1 0 r
F P
0 g
s
.59443 .44396 m .60166 .42485 L .61189 .41828 L p 0 1 0 r
F P
0 g
s
.29826 .50854 m .30499 .50067 L .31651 .50587 L p 0 0 1 r
F P
0 g
s
.30499 .50067 m .29826 .50854 L .28671 .50335 L p 0 0 1 r
F P
0 g
s
.33118 .54591 m .32426 .55507 L .31269 .55098 L p 1 0 0 r
F P
0 g
s
.34626 .50838 m .35316 .50051 L .36457 .50571 L p 0 0 1 r
F P
0 g
s
.35316 .50051 m .34626 .50838 L .33481 .50319 L p 0 0 1 r
F P
0 g
s
.46429 .46127 m .4716 .4515 L .48275 .45567 L p 1 0 0 r
F P
0 g
s
.48275 .45567 m .4901 .44694 L .50121 .45229 L p 1 0 0 r
F P
0 g
s
.4901 .44694 m .48275 .45567 L .4716 .4515 L p 1 0 0 r
F P
0 g
s
.26511 .54534 m .27147 .54052 L .28293 .54744 L p 1 0 0 r
F P
0 g
s
.27147 .54052 m .26511 .54534 L .25383 .53666 L p 1 0 0 r
F P
0 g
s
.44228 .50807 m .4495 .5002 L .46071 .5054 L p 0 0 1 r
F P
0 g
s
.4495 .5002 m .44228 .50807 L .43105 .50288 L p 0 0 1 r
F P
0 g
s
.44581 .46862 m .45308 .45805 L .46429 .46127 L p 1 0 0 r
F P
0 g
s
.4716 .4515 m .46429 .46127 L .45308 .45805 L p 1 0 0 r
F P
0 g
s
.4903 .50792 m .49768 .50005 L .50878 .50525 L p 0 0 1 r
F P
0 g
s
.49768 .50005 m .4903 .50792 L .47918 .50273 L p 0 0 1 r
F P
0 g
s
.53833 .50776 m .54587 .49989 L .55687 .50509 L p 0 0 1 r
F P
0 g
s
.54587 .49989 m .53833 .50776 L .52731 .50257 L p 0 0 1 r
F P
0 g
s
.51632 .55482 m .52378 .54685 L .5348 .5505 L p 0 1 0 r
F P
0 g
s
.52378 .54685 m .51632 .55482 L .50525 .54971 L p 0 1 0 r
F P
0 g
s
.30907 .45241 m .31575 .44563 L .32712 .45296 L p 0 1 0 r
F P
0 g
s
.31575 .44563 m .30907 .45241 L .29762 .44611 L p 0 1 0 r
F P
0 g
s
.63441 .50746 m .64227 .49958 L .65305 .50479 L p 0 0 1 r
F P
0 g
s
.64227 .49958 m .63441 .50746 L .62359 .50226 L p 0 0 1 r
F P
0 g
s
.68245 .5073 m .69048 .49943 L .70116 .50463 L p 0 0 1 r
F P
0 g
s
.69048 .49943 m .68245 .5073 L .67175 .50211 L p 0 0 1 r
F P
0 g
s
.48674 .55009 m .49412 .54394 L .50525 .54971 L p 0 1 0 r
F P
0 g
s
.49412 .54394 m .48674 .55009 L .47561 .54325 L p 0 1 0 r
F P
0 g
s
.43493 .52454 m .44206 .52009 L .45327 .52818 L p 0 1 0 r
F P
0 g
s
.44206 .52009 m .43493 .52454 L .42376 .51602 L p 0 1 0 r
F P
0 g
s
.73051 .50715 m .73869 .49927 L .74927 .50448 L p 0 0 1 r
F P
0 g
s
.73869 .49927 m .73051 .50715 L .7199 .50195 L p 0 0 1 r
F P
0 g
s
.77856 .50699 m .78692 .49911 L .79738 .50432 L p 0 0 1 r
F P
0 g
s
.78692 .49911 m .77856 .50699 L .76807 .5018 L p 0 0 1 r
F P
0 g
s
.34977 .53889 m .35685 .52836 L .36841 .53043 L p 1 0 0 r
F P
0 g
s
.37554 .51936 m .36841 .53043 L .35685 .52836 L p 1 0 0 r
F P
0 g
s
.82663 .50684 m .83514 .49896 L .8455 .50417 L p 0 0 1 r
F P
0 g
s
.83514 .49896 m .82663 .50684 L .81624 .50164 L p 0 0 1 r
F P
0 g
s
.63259 .57728 m .62395 .57222 L .61242 .55498 L p 1 0 0 r
F P
0 g
s
.61242 .55498 m .62086 .55846 L .63259 .57728 L p 1 0 0 r
F P
0 g
s
.37554 .51936 m .38271 .50806 L .39421 .50972 L p 1 0 0 r
F P
0 g
s
.07632 .50664 m .08231 .49876 L .09434 .50397 L p 0 0 1 r
F P
0 g
s
.25383 .53666 m .26006 .53275 L .27147 .54052 L p 1 0 0 r
F P
0 g
s
.26006 .53275 m .25383 .53666 L .24264 .52701 L p 1 0 0 r
F P
0 g
s
.54229 .54097 m .5348 .5505 L .52378 .54685 L p 0 1 0 r
F P
0 g
s
.35646 .46366 m .34971 .46868 L .33844 .46066 L p 0 1 0 r
F P
0 g
s
.12434 .50649 m .1305 .4986 L .14242 .50381 L p 0 0 1 r
F P
0 g
s
.1305 .4986 m .12434 .50649 L .1124 .50129 L p 0 0 1 r
F P
0 g
s
.50121 .45229 m .50864 .44485 L .51975 .45163 L p 1 0 0 r
F P
0 g
s
.50864 .44485 m .50121 .45229 L .4901 .44694 L p 1 0 0 r
F P
0 g
s
.17238 .50633 m .1787 .49845 L .19051 .50366 L p 0 0 1 r
F P
0 g
s
.1787 .49845 m .17238 .50633 L .16054 .50113 L p 0 0 1 r
F P
0 g
s
.24871 .52408 m .24264 .52701 L .23156 .51636 L p 1 0 0 r
F P
0 g
s
.23156 .51636 m .23744 .51444 L .24871 .52408 L p 1 0 0 r
F P
0 g
s
.61635 .32758 m .62284 .30205 L .62435 .3089 L p 0 1 0 r
F P
0 g
s
.26846 .50602 m .27511 .49814 L .28671 .50335 L p 0 0 1 r
F P
0 g
s
.27511 .49814 m .26846 .50602 L .25683 .50082 L p 0 0 1 r
F P
0 g
s
.24264 .52701 m .24871 .52408 L .26006 .53275 L p 1 0 0 r
F P
0 g
s
.42725 .47727 m .43451 .46613 L .44581 .46862 L p 1 0 0 r
F P
0 g
s
.45308 .45805 m .44581 .46862 L .43451 .46613 L p 1 0 0 r
F P
0 g
s
.31651 .50587 m .32332 .49798 L .33481 .50319 L p 0 0 1 r
F P
0 g
s
.32332 .49798 m .31651 .50587 L .30499 .50067 L p 0 0 1 r
F P
0 g
s
.2608 .45511 m .26764 .44477 L .27934 .4491 L p 0 1 0 r
F P
0 g
s
.27934 .4491 m .28608 .44037 L .29762 .44611 L p 0 1 0 r
F P
0 g
s
.28608 .44037 m .27934 .4491 L .26764 .44477 L p 0 1 0 r
F P
0 g
s
.36457 .50571 m .37154 .49783 L .38293 .50304 L p 0 0 1 r
F P
0 g
s
.37154 .49783 m .36457 .50571 L .35316 .50051 L p 0 0 1 r
F P
0 g
s
.18029 .69392 m .17911 .69764 L .1788 .69683 L p 0 1 0 r
F P
0 g
s
.1788 .69683 m .1784 .69604 L .18029 .69392 L p 0 1 0 r
F P
0 g
s
.18029 .69392 m .1784 .69604 L .17642 .69076 L p 0 1 0 r
F P
0 g
s
.42376 .51602 m .43084 .51172 L .44206 .52009 L p 0 1 0 r
F P
0 g
s
.43084 .51172 m .42376 .51602 L .41258 .50734 L p 0 1 0 r
F P
0 g
s
.46071 .5054 m .468 .49752 L .47918 .50273 L p 0 0 1 r
F P
0 g
s
.468 .49752 m .46071 .5054 L .4495 .5002 L p 0 0 1 r
F P
0 g
s
.50878 .50525 m .51624 .49736 L .52731 .50257 L p 0 0 1 r
F P
0 g
s
.51624 .49736 m .50878 .50525 L .49768 .50005 L p 0 0 1 r
F P
0 g
s
.56448 .4972 m .55687 .50509 L .54587 .49989 L p 0 0 1 r
F P
0 g
s
.29442 .55355 m .30112 .54627 L .31269 .55098 L p 1 0 0 r
F P
0 g
s
.30112 .54627 m .29442 .55355 L .28293 .54744 L p 1 0 0 r
F P
0 g
s
.24187 .46469 m .24888 .45246 L .2608 .45511 L p 0 1 0 r
F P
0 g
s
.26764 .44477 m .2608 .45511 L .24888 .45246 L p 0 1 0 r
F P
0 g
s
.60496 .50494 m .61273 .49705 L .62359 .50226 L p 0 0 1 r
F P
0 g
s
.61273 .49705 m .60496 .50494 L .59407 .49974 L p 0 0 1 r
F P
0 g
s
.65305 .50479 m .66099 .49689 L .67175 .50211 L p 0 0 1 r
F P
0 g
s
.66099 .49689 m .65305 .50479 L .64227 .49958 L p 0 0 1 r
F P
0 g
s
.70116 .50463 m .70926 .49674 L .7199 .50195 L p 0 0 1 r
F P
0 g
s
.70926 .49674 m .70116 .50463 L .69048 .49943 L p 0 0 1 r
F P
0 g
s
.54229 .54097 m .54979 .53052 L .56067 .5316 L p 0 1 0 r
F P
0 g
s
.56813 .51919 m .56067 .5316 L .54979 .53052 L p 0 1 0 r
F P
0 g
s
.22023 .50783 m .21275 .52462 L .1998 .5292 L p 0 1 0 r
F P
0 g
s
.1998 .5292 m .2075 .51095 L .22023 .50783 L p 0 1 0 r
F P
0 g
s
.74927 .50448 m .75753 .49658 L .76807 .5018 L p 0 0 1 r
F P
0 g
s
.75753 .49658 m .74927 .50448 L .73869 .49927 L p 0 0 1 r
F P
0 g
s
.53844 .45417 m .53084 .4592 L .51975 .45163 L p 1 0 0 r
F P
0 g
s
.1946 .59651 m .18639 .61913 L .17242 .63084 L p 0 1 0 r
F P
0 g
s
.17242 .63084 m .18095 .60626 L .1946 .59651 L p 0 1 0 r
F P
0 g
s
.79738 .50432 m .8058 .49643 L .81624 .50164 L p 0 0 1 r
F P
0 g
s
.8058 .49643 m .79738 .50432 L .78692 .49911 L p 0 0 1 r
F P
0 g
s
.8455 .50417 m .85409 .49627 L .86442 .50149 L p 0 0 1 r
F P
0 g
s
.85409 .49627 m .8455 .50417 L .83514 .49896 L p 0 0 1 r
F P
0 g
s
.67122 .66887 m .67167 .67108 L p .65354 .64054 L 1 0 0 r
F P
0 g
s
.67167 .67108 m .66563 .66406 L .65354 .64054 L p 1 0 0 r
F P
0 g
s
.65354 .64054 m .66266 .64949 L p .67122 .66887 L 1 0 0 r
F P
0 g
s
.33844 .46066 m .34516 .45529 L .35646 .46366 L p 0 1 0 r
F P
0 g
s
.34516 .45529 m .33844 .46066 L .32712 .45296 L p 0 1 0 r
F P
0 g
s
.09434 .50397 m .1004 .49607 L .1124 .50129 L p 0 0 1 r
F P
0 g
s
.1004 .49607 m .09434 .50397 L .08231 .49876 L p 0 0 1 r
F P
0 g
s
.47561 .54325 m .48296 .53756 L .49412 .54394 L p 0 1 0 r
F P
0 g
s
.48296 .53756 m .47561 .54325 L .46445 .53592 L p 0 1 0 r
F P
0 g
s
.14242 .50381 m .14865 .49591 L .16054 .50113 L p 0 0 1 r
F P
0 g
s
.14865 .49591 m .14242 .50381 L .1305 .4986 L p 0 0 1 r
F P
0 g
s
.33118 .54591 m .33816 .53619 L .34977 .53889 L p 1 0 0 r
F P
0 g
s
.35685 .52836 m .34977 .53889 L .33816 .53619 L p 1 0 0 r
F P
0 g
s
.41258 .50734 m .41961 .50311 L .43084 .51172 L p 0 1 0 r
F P
0 g
s
.19051 .50366 m .1969 .49576 L .20868 .50098 L p 0 0 1 r
F P
0 g
s
.1969 .49576 m .19051 .50366 L .1787 .49845 L p 0 0 1 r
F P
0 g
s
.2386 .5035 m .24515 .4956 L .25683 .50082 L p 0 0 1 r
F P
0 g
s
.60614 .52772 m .59786 .52582 L .58655 .51173 L p 1 0 0 r
F P
0 g
s
.58655 .51173 m .59466 .51226 L .60614 .52772 L p 1 0 0 r
F P
0 g
s
.28671 .50335 m .29342 .49545 L .30499 .50067 L p 0 0 1 r
F P
0 g
s
.29342 .49545 m .28671 .50335 L .27511 .49814 L p 0 0 1 r
F P
0 g
s
.21275 .52462 m .2051 .54276 L .19191 .5489 L p 0 1 0 r
F P
0 g
s
.19191 .5489 m .1998 .5292 L .21275 .52462 L p 0 1 0 r
F P
0 g
s
.29762 .44611 m .30431 .43874 L .31575 .44563 L p 0 1 0 r
F P
0 g
s
.30431 .43874 m .29762 .44611 L .28608 .44037 L p 0 1 0 r
F P
0 g
s
.65968 .63504 m .65055 .62627 L .63868 .60516 L p 1 0 0 r
F P
0 g
s
.63868 .60516 m .64754 .61208 L .65968 .63504 L p 1 0 0 r
F P
0 g
s
.33481 .50319 m .34169 .49529 L .35316 .50051 L p 0 0 1 r
F P
0 g
s
.34169 .49529 m .33481 .50319 L .32332 .49798 L p 0 0 1 r
F P
0 g
s
.61576 .38203 m .60877 .40423 L .59847 .4108 L p 0 1 0 r
F P
0 g
s
.59847 .4108 m .60562 .38986 L .61576 .38203 L p 0 1 0 r
F P
0 g
s
.43105 .50288 m .43825 .49498 L .4495 .5002 L p 0 0 1 r
F P
0 g
s
.43825 .49498 m .43105 .50288 L .41977 .49767 L p 0 0 1 r
F P
0 g
s
.47918 .50273 m .48654 .49482 L .49768 .50005 L p 0 0 1 r
F P
0 g
s
.48654 .49482 m .47918 .50273 L .468 .49752 L p 0 0 1 r
F P
0 g
s
.52731 .50257 m .53483 .49467 L .54587 .49989 L p 0 0 1 r
F P
0 g
s
.53483 .49467 m .52731 .50257 L .51624 .49736 L p 0 0 1 r
F P
0 g
s
.50525 .54971 m .5127 .5424 L .52378 .54685 L p 0 1 0 r
F P
0 g
s
.5127 .5424 m .50525 .54971 L .49412 .54394 L p 0 1 0 r
F P
0 g
s
.35685 .52836 m .36396 .51747 L .37554 .51936 L p 1 0 0 r
F P
0 g
s
.38271 .50806 m .37554 .51936 L .36396 .51747 L p 1 0 0 r
F P
0 g
s
.31269 .55098 m .31956 .54234 L .33118 .54591 L p 1 0 0 r
F P
0 g
s
.31956 .54234 m .31269 .55098 L .30112 .54627 L p 1 0 0 r
F P
0 g
s
.6686 .67875 m .67393 .69007 L .67408 .69357 L p 1 0 0 r
F P
0 g
s
.67345 .68744 m .67393 .69007 L .6686 .67875 L p 1 0 0 r
F P
0 g
s
.6686 .67875 m .6733 .68433 L .67345 .68744 L p 1 0 0 r
F P
0 g
s
.62359 .50226 m .63144 .49435 L .64227 .49958 L p 0 0 1 r
F P
0 g
s
.63144 .49435 m .62359 .50226 L .61273 .49705 L p 0 0 1 r
F P
0 g
s
.18342 .65594 m .17477 .68201 L p .17092 .67862 L 0 1 0 r
F P
0 g
s
.17092 .67862 m .16809 .67332 L p .18342 .65594 L 0 1 0 r
F P
0 g
s
.16809 .67332 m .1692 .66982 L .18342 .65594 L p 0 1 0 r
F P
0 g
s
.67175 .50211 m .67976 .4942 L .69048 .49943 L p 0 0 1 r
F P
0 g
s
.67976 .4942 m .67175 .50211 L .66099 .49689 L p 0 0 1 r
F P
0 g
s
.33816 .53619 m .33118 .54591 L .31956 .54234 L p 1 0 0 r
F P
0 g
s
.45308 .45805 m .46038 .44781 L .4716 .4515 L p 1 0 0 r
F P
0 g
s
.4716 .4515 m .47894 .44219 L .4901 .44694 L p 1 0 0 r
F P
0 g
s
.47894 .44219 m .4716 .4515 L .46038 .44781 L p 1 0 0 r
F P
0 g
s
.7199 .50195 m .72808 .49404 L .73869 .49927 L p 0 0 1 r
F P
0 g
s
.72808 .49404 m .7199 .50195 L .70926 .49674 L p 0 0 1 r
F P
0 g
s
.76807 .5018 m .7764 .49389 L .78692 .49911 L p 0 0 1 r
F P
0 g
s
.7764 .49389 m .76807 .5018 L .75753 .49658 L p 0 0 1 r
F P
0 g
s
.81624 .50164 m .82474 .49373 L .83514 .49896 L p 0 0 1 r
F P
0 g
s
.82474 .49373 m .81624 .50164 L .8058 .49643 L p 0 0 1 r
F P
0 g
s
.51975 .45163 m .52729 .4457 L .53844 .45417 L p 1 0 0 r
F P
0 g
s
.52729 .4457 m .51975 .45163 L .50864 .44485 L p 1 0 0 r
F P
0 g
s
.87308 .49357 m .86442 .50149 L .85409 .49627 L p 0 0 1 r
F P
0 g
s
.32712 .45296 m .33382 .44717 L .34516 .45529 L p 0 1 0 r
F P
0 g
s
.33382 .44717 m .32712 .45296 L .31575 .44563 L p 0 1 0 r
F P
0 g
s
.1124 .50129 m .11853 .49337 L .1305 .4986 L p 0 0 1 r
F P
0 g
s
.11853 .49337 m .1124 .50129 L .1004 .49607 L p 0 0 1 r
F P
0 g
s
.54979 .53052 m .5573 .51906 L .56813 .51919 L p 0 1 0 r
F P
0 g
s
.57557 .50565 m .56813 .51919 L .5573 .51906 L p 0 1 0 r
F P
0 g
s
.4901 .44694 m .4975 .43879 L .50864 .44485 L p 1 0 0 r
F P
0 g
s
.4975 .43879 m .4901 .44694 L .47894 .44219 L p 1 0 0 r
F P
0 g
s
.16054 .50113 m .16683 .49322 L .1787 .49845 L p 0 0 1 r
F P
0 g
s
.16683 .49322 m .16054 .50113 L .14865 .49591 L p 0 0 1 r
F P
0 g
s
.28293 .54744 m .28954 .54087 L .30112 .54627 L p 1 0 0 r
F P
0 g
s
.28954 .54087 m .28293 .54744 L .27147 .54052 L p 1 0 0 r
F P
0 g
s
.2051 .54276 m .19727 .56234 L .18381 .57017 L p 0 1 0 r
F P
0 g
s
.18381 .57017 m .19191 .5489 L .2051 .54276 L p 0 1 0 r
F P
0 g
s
.46445 .53592 m .47175 .53063 L .48296 .53756 L p 0 1 0 r
F P
0 g
s
.47175 .53063 m .46445 .53592 L .45327 .52818 L p 0 1 0 r
F P
0 g
s
.25683 .50082 m .26345 .4929 L .27511 .49814 L p 0 0 1 r
F P
0 g
s
.26345 .4929 m .25683 .50082 L .24515 .4956 L p 0 0 1 r
F P
0 g
s
.43451 .46613 m .44179 .4552 L .45308 .45805 L p 1 0 0 r
F P
0 g
s
.46038 .44781 m .45308 .45805 L .44179 .4552 L p 1 0 0 r
F P
0 g
s
.30499 .50067 m .31177 .49275 L .32332 .49798 L p 0 0 1 r
F P
0 g
s
.31177 .49275 m .30499 .50067 L .29342 .49545 L p 0 0 1 r
F P
0 g
s
.24888 .45246 m .24187 .46469 L .22964 .46401 L p 0 1 0 r
F P
0 g
s
.35316 .50051 m .3601 .49259 L .37154 .49783 L p 0 0 1 r
F P
0 g
s
.3601 .49259 m .35316 .50051 L .34169 .49529 L p 0 0 1 r
F P
0 g
s
.52378 .54685 m .53128 .53809 L .54229 .54097 L p 0 1 0 r
F P
0 g
s
.54979 .53052 m .54229 .54097 L .53128 .53809 L p 0 1 0 r
F P
0 g
s
.4495 .5002 m .45677 .49228 L .468 .49752 L p 0 0 1 r
F P
0 g
s
.45677 .49228 m .4495 .5002 L .43825 .49498 L p 0 0 1 r
F P
0 g
s
.49768 .50005 m .50512 .49212 L .51624 .49736 L p 0 0 1 r
F P
0 g
s
.50512 .49212 m .49768 .50005 L .48654 .49482 L p 0 0 1 r
F P
0 g
s
.6195 .34309 m .61263 .3673 L .60242 .37515 L p 0 1 0 r
F P
0 g
s
.60242 .37515 m .60946 .35221 L .6195 .34309 L p 0 1 0 r
F P
0 g
s
.64452 .59797 m .63564 .5912 L .62395 .57222 L p 1 0 0 r
F P
0 g
s
.62395 .57222 m .63259 .57728 L .64452 .59797 L p 1 0 0 r
F P
0 g
s
.53128 .53809 m .52378 .54685 L .5127 .5424 L p 0 1 0 r
F P
0 g
s
.54587 .49989 m .55347 .49197 L .56448 .4972 L p 0 0 1 r
F P
0 g
s
.55347 .49197 m .54587 .49989 L .53483 .49467 L p 0 0 1 r
F P
0 g
s
.62277 .30183 m .62284 .30205 L p .60624 .33675 L 0 1 0 r
F P
0 g
s
.62284 .30205 m .61635 .32758 L .60624 .33675 L p 0 1 0 r
F P
0 g
s
.59407 .49974 m .60183 .49181 L .61273 .49705 L p 0 0 1 r
F P
0 g
s
.61316 .31168 m .62271 .30158 L .62277 .30183 L p 0 1 0 r
F P
0 g
s
.60624 .33675 m .61316 .31168 L p .62277 .30183 L 0 1 0 r
F P
0 g
s
.61775 .54472 m .60929 .54135 L .59786 .52582 L p 1 0 0 r
F P
0 g
s
.59786 .52582 m .60614 .52772 L .61775 .54472 L p 1 0 0 r
F P
0 g
s
.64227 .49958 m .65019 .49165 L .66099 .49689 L p 0 0 1 r
F P
0 g
s
.65019 .49165 m .64227 .49958 L .63144 .49435 L p 0 0 1 r
F P
0 g
s
.24888 .45246 m .2558 .44118 L .26764 .44477 L p 0 1 0 r
F P
0 g
s
.26764 .44477 m .27443 .43525 L .28608 .44037 L p 0 1 0 r
F P
0 g
s
.27443 .43525 m .26764 .44477 L .2558 .44118 L p 0 1 0 r
F P
0 g
s
.62031 .29485 m .62271 .30158 L .61316 .31168 L p 0 1 0 r
F P
0 g
s
.69048 .49943 m .69856 .4915 L .70926 .49674 L p 0 0 1 r
F P
0 g
s
.69856 .4915 m .69048 .49943 L .67976 .4942 L p 0 0 1 r
F P
0 g
s
.73869 .49927 m .74694 .49134 L .75753 .49658 L p 0 0 1 r
F P
0 g
s
.74694 .49134 m .73869 .49927 L .72808 .49404 L p 0 0 1 r
F P
0 g
s
.5573 .51906 m .5648 .50652 L .57557 .50565 L p 0 1 0 r
F P
0 g
s
.78692 .49911 m .79532 .49118 L .8058 .49643 L p 0 0 1 r
F P
0 g
s
.79532 .49118 m .78692 .49911 L .7764 .49389 L p 0 0 1 r
F P
0 g
s
.83514 .49896 m .84371 .49103 L .85409 .49627 L p 0 0 1 r
F P
0 g
s
.84371 .49103 m .83514 .49896 L .82474 .49373 L p 0 0 1 r
F P
0 g
s
.08231 .49876 m .08835 .49083 L .1004 .49607 L p 0 0 1 r
F P
0 g
s
.33816 .53619 m .34521 .52598 L .35685 .52836 L p 1 0 0 r
F P
0 g
s
.36396 .51747 m .35685 .52836 L .34521 .52598 L p 1 0 0 r
F P
0 g
s
.1305 .4986 m .1367 .49067 L .14865 .49591 L p 0 0 1 r
F P
0 g
s
.1367 .49067 m .1305 .4986 L .11853 .49337 L p 0 0 1 r
F P
0 g
s
.28608 .44037 m .2928 .43234 L .30431 .43874 L p 0 1 0 r
F P
0 g
s
.2928 .43234 m .28608 .44037 L .27443 .43525 L p 0 1 0 r
F P
0 g
s
.1787 .49845 m .18506 .49051 L .1969 .49576 L p 0 0 1 r
F P
0 g
s
.18506 .49051 m .1787 .49845 L .16683 .49322 L p 0 0 1 r
F P
0 g
s
.31575 .44563 m .32244 .43937 L .33382 .44717 L p 0 1 0 r
F P
0 g
s
.32244 .43937 m .31575 .44563 L .30431 .43874 L p 0 1 0 r
F P
0 g
s
.45327 .52818 m .46052 .52323 L .47175 .53063 L p 0 1 0 r
F P
0 g
s
.46052 .52323 m .45327 .52818 L .44206 .52009 L p 0 1 0 r
F P
0 g
s
.27511 .49814 m .28179 .4902 L .29342 .49545 L p 0 0 1 r
F P
0 g
s
.28179 .4902 m .27511 .49814 L .26345 .4929 L p 0 0 1 r
F P
0 g
s
.32332 .49798 m .33017 .49004 L .34169 .49529 L p 0 0 1 r
F P
0 g
s
.33017 .49004 m .32332 .49798 L .31177 .49275 L p 0 0 1 r
F P
0 g
s
.36396 .51747 m .37113 .50628 L .38271 .50806 L p 1 0 0 r
F P
0 g
s
.3899 .49658 m .38271 .50806 L .37113 .50628 L p 1 0 0 r
F P
0 g
s
.44179 .4552 m .43451 .46613 L .42313 .46388 L p 1 0 0 r
F P
0 g
s
.49412 .54394 m .50156 .53721 L .5127 .5424 L p 0 1 0 r
F P
0 g
s
.50156 .53721 m .49412 .54394 L .48296 .53756 L p 0 1 0 r
F P
0 g
s
.37855 .48989 m .37154 .49783 L .3601 .49259 L p 0 0 1 r
F P
0 g
s
.50864 .44485 m .51614 .43809 L .52729 .4457 L p 1 0 0 r
F P
0 g
s
.51614 .43809 m .50864 .44485 L .4975 .43879 L p 1 0 0 r
F P
0 g
s
.15543 .39727 m .15106 .39262 L .14109 .37435 L p 1 0 0 r
F P
0 g
s
.41977 .49767 m .42694 .48973 L .43825 .49498 L p 0 0 1 r
F P
0 g
s
.18639 .61913 m .17794 .64352 L .16359 .65734 L p 0 1 0 r
F P
0 g
s
.16359 .65734 m .17242 .63084 L .18639 .61913 L p 0 1 0 r
F P
0 g
s
.468 .49752 m .47534 .48957 L .48654 .49482 L p 0 0 1 r
F P
0 g
s
.47534 .48957 m .468 .49752 L .45677 .49228 L p 0 0 1 r
F P
0 g
s
.27147 .54052 m .27797 .53474 L .28954 .54087 L p 1 0 0 r
F P
0 g
s
.27797 .53474 m .27147 .54052 L .26006 .53275 L p 1 0 0 r
F P
0 g
s
.51624 .49736 m .52374 .48942 L .53483 .49467 L p 0 0 1 r
F P
0 g
s
.52374 .48942 m .51624 .49736 L .50512 .49212 L p 0 0 1 r
F P
0 g
s
.22964 .46401 m .23677 .45069 L .24888 .45246 L p 0 1 0 r
F P
0 g
s
.2558 .44118 m .24888 .45246 L .23677 .45069 L p 0 1 0 r
F P
0 g
s
.61273 .49705 m .62056 .4891 L .63144 .49435 L p 0 0 1 r
F P
0 g
s
.62056 .4891 m .61273 .49705 L .60183 .49181 L p 0 0 1 r
F P
0 g
s
.19727 .56234 m .18922 .58347 L .17546 .59312 L p 0 1 0 r
F P
0 g
s
.17546 .59312 m .18381 .57017 L .19727 .56234 L p 0 1 0 r
F P
0 g
s
.66099 .49689 m .66898 .48895 L .67976 .4942 L p 0 0 1 r
F P
0 g
s
.66898 .48895 m .66099 .49689 L .65019 .49165 L p 0 0 1 r
F P
0 g
s
.30112 .54627 m .30792 .53821 L .31956 .54234 L p 1 0 0 r
F P
0 g
s
.30792 .53821 m .30112 .54627 L .28954 .54087 L p 1 0 0 r
F P
0 g
s
.70926 .49674 m .71741 .48879 L .72808 .49404 L p 0 0 1 r
F P
0 g
s
.71741 .48879 m .70926 .49674 L .69856 .4915 L p 0 0 1 r
F P
0 g
s
.75753 .49658 m .76584 .48863 L .7764 .49389 L p 0 0 1 r
F P
0 g
s
.76584 .48863 m .75753 .49658 L .74694 .49134 L p 0 0 1 r
F P
0 g
s
.8058 .49643 m .81428 .48848 L .82474 .49373 L p 0 0 1 r
F P
0 g
s
.81428 .48848 m .8058 .49643 L .79532 .49118 L p 0 0 1 r
F P
0 g
s
.85409 .49627 m .86273 .48832 L .87308 .49357 L p 0 0 1 r
F P
0 g
s
.86273 .48832 m .85409 .49627 L .84371 .49103 L p 0 0 1 r
F P
0 g
s
.31956 .54234 m .3265 .53307 L .33816 .53619 L p 1 0 0 r
F P
0 g
s
.34521 .52598 m .33816 .53619 L .3265 .53307 L p 1 0 0 r
F P
0 g
s
.1004 .49607 m .10651 .48812 L .11853 .49337 L p 0 0 1 r
F P
0 g
s
.10651 .48812 m .1004 .49607 L .08835 .49083 L p 0 0 1 r
F P
0 g
s
.60877 .40423 m .60166 .42485 L .5912 .4302 L p 0 1 0 r
F P
0 g
s
.5912 .4302 m .59847 .4108 L .60877 .40423 L p 0 1 0 r
F P
0 g
s
.44206 .52009 m .44927 .51541 L .46052 .52323 L p 0 1 0 r
F P
0 g
s
.44927 .51541 m .44206 .52009 L .43084 .51172 L p 0 1 0 r
F P
0 g
s
.14865 .49591 m .15492 .48796 L .16683 .49322 L p 0 0 1 r
F P
0 g
s
.15492 .48796 m .14865 .49591 L .1367 .49067 L p 0 0 1 r
F P
0 g
s
.20333 .4878 m .1969 .49576 L .18506 .49051 L p 0 0 1 r
F P
0 g
s
.24515 .4956 m .25175 .48765 L .26345 .4929 L p 0 0 1 r
F P
0 g
s
.25175 .48765 m .24515 .4956 L .23342 .49036 L p 0 0 1 r
F P
0 g
s
.29342 .49545 m .30018 .48749 L .31177 .49275 L p 0 0 1 r
F P
0 g
s
.30018 .48749 m .29342 .49545 L .28179 .4902 L p 0 0 1 r
F P
0 g
s
.46038 .44781 m .46772 .43795 L .47894 .44219 L p 1 0 0 r
F P
0 g
s
.47894 .44219 m .48632 .43338 L .4975 .43879 L p 1 0 0 r
F P
0 g
s
.48632 .43338 m .47894 .44219 L .46772 .43795 L p 1 0 0 r
F P
0 g
s
.3265 .53307 m .31956 .54234 L .30792 .53821 L p 1 0 0 r
F P
0 g
s
.34169 .49529 m .34861 .48733 L .3601 .49259 L p 0 0 1 r
F P
0 g
s
.34861 .48733 m .34169 .49529 L .33017 .49004 L p 0 0 1 r
F P
0 g
s
.53128 .53809 m .53881 .52847 L .54979 .53052 L p 0 1 0 r
F P
0 g
s
.5573 .51906 m .54979 .53052 L .53881 .52847 L p 0 1 0 r
F P
0 g
s
.44179 .4552 m .44909 .44453 L .46038 .44781 L p 1 0 0 r
F P
0 g
s
.46772 .43795 m .46038 .44781 L .44909 .44453 L p 1 0 0 r
F P
0 g
s
.43825 .49498 m .44549 .48702 L .45677 .49228 L p 0 0 1 r
F P
0 g
s
.44549 .48702 m .43825 .49498 L .42694 .48973 L p 0 0 1 r
F P
0 g
s
.26006 .53275 m .26643 .52781 L .27797 .53474 L p 1 0 0 r
F P
0 g
s
.26643 .52781 m .26006 .53275 L .24871 .52408 L p 1 0 0 r
F P
0 g
s
.48654 .49482 m .49395 .48686 L .50512 .49212 L p 0 0 1 r
F P
0 g
s
.49395 .48686 m .48654 .49482 L .47534 .48957 L p 0 0 1 r
F P
0 g
s
.53483 .49467 m .5424 .48671 L .55347 .49197 L p 0 0 1 r
F P
0 g
s
.5424 .48671 m .53483 .49467 L .52374 .48942 L p 0 0 1 r
F P
0 g
s
.30431 .43874 m .31101 .43194 L .32244 .43937 L p 0 1 0 r
F P
0 g
s
.31101 .43194 m .30431 .43874 L .2928 .43234 L p 0 1 0 r
F P
0 g
s
.62952 .5634 m .62086 .55846 L .60929 .54135 L p 1 0 0 r
F P
0 g
s
.60929 .54135 m .61775 .54472 L .62952 .5634 L p 1 0 0 r
F P
0 g
s
.63144 .49435 m .63934 .48639 L .65019 .49165 L p 0 0 1 r
F P
0 g
s
.63934 .48639 m .63144 .49435 L .62056 .4891 L p 0 0 1 r
F P
0 g
s
.67976 .4942 m .68782 .48623 L .69856 .4915 L p 0 0 1 r
F P
0 g
s
.68782 .48623 m .67976 .4942 L .66898 .48895 L p 0 0 1 r
F P
0 g
s
.72808 .49404 m .7363 .48608 L .74694 .49134 L p 0 0 1 r
F P
0 g
s
.7363 .48608 m .72808 .49404 L .71741 .48879 L p 0 0 1 r
F P
0 g
s
.5127 .5424 m .5202 .53436 L .53128 .53809 L p 0 1 0 r
F P
0 g
s
.5202 .53436 m .5127 .5424 L .50156 .53721 L p 0 1 0 r
F P
0 g
s
.43084 .51172 m .438 .50724 L .44927 .51541 L p 0 1 0 r
F P
0 g
s
.438 .50724 m .43084 .51172 L .41961 .50311 L p 0 1 0 r
F P
0 g
s
.7764 .49389 m .78479 .48592 L .79532 .49118 L p 0 0 1 r
F P
0 g
s
.78479 .48592 m .7764 .49389 L .76584 .48863 L p 0 0 1 r
F P
0 g
s
.48296 .53756 m .49036 .53136 L .50156 .53721 L p 0 1 0 r
F P
0 g
s
.49036 .53136 m .48296 .53756 L .47175 .53063 L p 0 1 0 r
F P
0 g
s
.34521 .52598 m .35232 .51533 L .36396 .51747 L p 1 0 0 r
F P
0 g
s
.37113 .50628 m .36396 .51747 L .35232 .51533 L p 1 0 0 r
F P
0 g
s
.82474 .49373 m .83329 .48576 L .84371 .49103 L p 0 0 1 r
F P
0 g
s
.83329 .48576 m .82474 .49373 L .81428 .48848 L p 0 0 1 r
F P
0 g
s
.37113 .50628 m .37832 .49486 L .3899 .49658 L p 1 0 0 r
F P
0 g
s
.88179 .48561 m .87308 .49357 L .86273 .48832 L p 0 0 1 r
F P
0 g
s
.35192 .45024 m .34516 .45529 L .33382 .44717 L p 0 1 0 r
F P
0 g
s
.11853 .49337 m .12471 .4854 L .1367 .49067 L p 0 0 1 r
F P
0 g
s
.12471 .4854 m .11853 .49337 L .10651 .48812 L p 0 0 1 r
F P
0 g
s
.4975 .43879 m .50496 .43126 L .51614 .43809 L p 1 0 0 r
F P
0 g
s
.50496 .43126 m .4975 .43879 L .48632 .43338 L p 1 0 0 r
F P
0 g
s
.61316 .31168 m .61891 .28874 L .62031 .29485 L p 0 1 0 r
F P
0 g
s
.16683 .49322 m .17317 .48525 L .18506 .49051 L p 0 0 1 r
F P
0 g
s
.17317 .48525 m .16683 .49322 L .15492 .48796 L p 0 0 1 r
F P
0 g
s
.24871 .52408 m .25495 .52004 L .26643 .52781 L p 1 0 0 r
F P
0 g
s
.25495 .52004 m .24871 .52408 L .23744 .51444 L p 1 0 0 r
F P
0 g
s
.2558 .44118 m .26266 .4308 L .27443 .43525 L p 0 1 0 r
F P
0 g
s
.27443 .43525 m .28119 .42649 L .2928 .43234 L p 0 1 0 r
F P
0 g
s
.28119 .42649 m .27443 .43525 L .26266 .4308 L p 0 1 0 r
F P
0 g
s
.53881 .52847 m .53128 .53809 L .5202 .53436 L p 0 1 0 r
F P
0 g
s
.42313 .46388 m .43042 .45263 L .44179 .4552 L p 1 0 0 r
F P
0 g
s
.44909 .44453 m .44179 .4552 L .43042 .45263 L p 1 0 0 r
F P
0 g
s
.26345 .4929 m .27012 .48493 L .28179 .4902 L p 0 0 1 r
F P
0 g
s
.27012 .48493 m .26345 .4929 L .25175 .48765 L p 0 0 1 r
F P
0 g
s
.6696 .65633 m .6699 .65777 L p .65055 .62627 L 1 0 0 r
F P
0 g
s
.6699 .65777 m .66266 .64949 L .65055 .62627 L p 1 0 0 r
F P
0 g
s
.65055 .62627 m .65968 .63504 L p .6696 .65633 L 1 0 0 r
F P
0 g
s
.31177 .49275 m .3186 .48477 L .33017 .49004 L p 0 0 1 r
F P
0 g
s
.3186 .48477 m .31177 .49275 L .30018 .48749 L p 0 0 1 r
F P
0 g
s
.24352 .51137 m .23744 .51444 L .22628 .50381 L p 1 0 0 r
F P
0 g
s
.22628 .50381 m .23218 .50176 L .24352 .51137 L p 1 0 0 r
F P
0 g
s
.3601 .49259 m .36709 .48462 L .37855 .48989 L p 0 0 1 r
F P
0 g
s
.36709 .48462 m .3601 .49259 L .34861 .48733 L p 0 0 1 r
F P
0 g
s
.23677 .45069 m .2438 .43841 L .2558 .44118 L p 0 1 0 r
F P
0 g
s
.26266 .4308 m .2558 .44118 L .2438 .43841 L p 0 1 0 r
F P
0 g
s
.23744 .51444 m .24352 .51137 L .25495 .52004 L p 1 0 0 r
F P
0 g
s
.17477 .68201 m .17365 .68552 L .17336 .68475 L p 0 1 0 r
F P
0 g
s
.17336 .68475 m .17296 .684 L .17477 .68201 L p 0 1 0 r
F P
0 g
s
.17477 .68201 m .17296 .684 L .17092 .67862 L p 0 1 0 r
F P
0 g
s
.45677 .49228 m .46409 .4843 L .47534 .48957 L p 0 0 1 r
F P
0 g
s
.46409 .4843 m .45677 .49228 L .44549 .48702 L p 0 0 1 r
F P
0 g
s
.41961 .50311 m .42672 .49878 L .438 .50724 L p 0 1 0 r
F P
0 g
s
.42672 .49878 m .41961 .50311 L .40837 .49435 L p 0 1 0 r
F P
0 g
s
.50512 .49212 m .5126 .48415 L .52374 .48942 L p 0 0 1 r
F P
0 g
s
.5126 .48415 m .50512 .49212 L .49395 .48686 L p 0 0 1 r
F P
0 g
s
.21502 .49406 m .2075 .51095 L .19445 .5154 L p 0 1 0 r
F P
0 g
s
.19445 .5154 m .2022 .49705 L .21502 .49406 L p 0 1 0 r
F P
0 g
s
.56111 .48399 m .55347 .49197 L .5424 .48671 L p 0 0 1 r
F P
0 g
s
.60183 .49181 m .60963 .48383 L .62056 .4891 L p 0 0 1 r
F P
0 g
s
.60963 .48383 m .60183 .49181 L .59087 .48655 L p 0 0 1 r
F P
0 g
s
.28954 .54087 m .29626 .53347 L .30792 .53821 L p 1 0 0 r
F P
0 g
s
.29626 .53347 m .28954 .54087 L .27797 .53474 L p 1 0 0 r
F P
0 g
s
.65019 .49165 m .65816 .48367 L .66898 .48895 L p 0 0 1 r
F P
0 g
s
.65816 .48367 m .65019 .49165 L .63934 .48639 L p 0 0 1 r
F P
0 g
s
.18922 .58347 m .18095 .60626 L .16685 .61788 L p 0 1 0 r
F P
0 g
s
.16685 .61788 m .17546 .59312 L .18922 .58347 L p 0 1 0 r
F P
0 g
s
.66563 .66406 m .67257 .67855 L .67271 .68128 L p 1 0 0 r
F P
0 g
s
.6719 .6751 m .67257 .67855 L .66563 .66406 L p 1 0 0 r
F P
0 g
s
.66563 .66406 m .67167 .67108 L .6719 .6751 L p 1 0 0 r
F P
0 g
s
.69856 .4915 m .7067 .48352 L .71741 .48879 L p 0 0 1 r
F P
0 g
s
.7067 .48352 m .69856 .4915 L .68782 .48623 L p 0 0 1 r
F P
0 g
s
.65669 .62069 m .64754 .61208 L .63564 .5912 L p 1 0 0 r
F P
0 g
s
.63564 .5912 m .64452 .59797 L .65669 .62069 L p 1 0 0 r
F P
0 g
s
.53492 .4406 m .52729 .4457 L .51614 .43809 L p 1 0 0 r
F P
0 g
s
.74694 .49134 m .75524 .48336 L .76584 .48863 L p 0 0 1 r
F P
0 g
s
.75524 .48336 m .74694 .49134 L .7363 .48608 L p 0 0 1 r
F P
0 g
s
.79532 .49118 m .80379 .4832 L .81428 .48848 L p 0 0 1 r
F P
0 g
s
.80379 .4832 m .79532 .49118 L .78479 .48592 L p 0 0 1 r
F P
0 g
s
.33382 .44717 m .34056 .44177 L .35192 .45024 L p 0 1 0 r
F P
0 g
s
.34056 .44177 m .33382 .44717 L .32244 .43937 L p 0 1 0 r
F P
0 g
s
.84371 .49103 m .85234 .48304 L .86273 .48832 L p 0 0 1 r
F P
0 g
s
.85234 .48304 m .84371 .49103 L .83329 .48576 L p 0 0 1 r
F P
0 g
s
.53881 .52847 m .54635 .51791 L .5573 .51906 L p 0 1 0 r
F P
0 g
s
.5648 .50652 m .5573 .51906 L .54635 .51791 L p 0 1 0 r
F P
0 g
s
.2075 .51095 m .1998 .5292 L .18651 .53522 L p 0 1 0 r
F P
0 g
s
.18651 .53522 m .19445 .5154 L .2075 .51095 L p 0 1 0 r
F P
0 g
s
.08835 .49083 m .09443 .48284 L .10651 .48812 L p 0 0 1 r
F P
0 g
s
.61263 .3673 m .60562 .38986 L .59523 .39644 L p 0 1 0 r
F P
0 g
s
.59523 .39644 m .60242 .37515 L .61263 .3673 L p 0 1 0 r
F P
0 g
s
.60296 .51408 m .59466 .51226 L .58329 .49823 L p 1 0 0 r
F P
0 g
s
.58329 .49823 m .59143 .49868 L .60296 .51408 L p 1 0 0 r
F P
0 g
s
.1367 .49067 m .14295 .48268 L .15492 .48796 L p 0 0 1 r
F P
0 g
s
.14295 .48268 m .1367 .49067 L .12471 .4854 L p 0 0 1 r
F P
0 g
s
.3265 .53307 m .33352 .52323 L .34521 .52598 L p 1 0 0 r
F P
0 g
s
.35232 .51533 m .34521 .52598 L .33352 .52323 L p 1 0 0 r
F P
0 g
s
.2928 .43234 m .2995 .42494 L .31101 .43194 L p 0 1 0 r
F P
0 g
s
.2995 .42494 m .2928 .43234 L .28119 .42649 L p 0 1 0 r
F P
0 g
s
.40837 .49435 m .41542 .4901 L .42672 .49878 L p 0 1 0 r
F P
0 g
s
.47175 .53063 m .47912 .5249 L .49036 .53136 L p 0 1 0 r
F P
0 g
s
.47912 .5249 m .47175 .53063 L .46052 .52323 L p 0 1 0 r
F P
0 g
s
.23342 .49036 m .23999 .48237 L .25175 .48765 L p 0 0 1 r
F P
0 g
s
.28179 .4902 m .28853 .48221 L .30018 .48749 L p 0 0 1 r
F P
0 g
s
.28853 .48221 m .28179 .4902 L .27012 .48493 L p 0 0 1 r
F P
0 g
s
.33017 .49004 m .33707 .48205 L .34861 .48733 L p 0 0 1 r
F P
0 g
s
.33707 .48205 m .33017 .49004 L .3186 .48477 L p 0 0 1 r
F P
0 g
s
.42694 .48973 m .43417 .48174 L .44549 .48702 L p 0 0 1 r
F P
0 g
s
.43417 .48174 m .42694 .48973 L .41559 .48446 L p 0 0 1 r
F P
0 g
s
.47534 .48957 m .48273 .48158 L .49395 .48686 L p 0 0 1 r
F P
0 g
s
.48273 .48158 m .47534 .48957 L .46409 .4843 L p 0 0 1 r
F P
0 g
s
.52374 .48942 m .53129 .48142 L .5424 .48671 L p 0 0 1 r
F P
0 g
s
.53129 .48142 m .52374 .48942 L .5126 .48415 L p 0 0 1 r
F P
0 g
s
.35232 .51533 m .35947 .50432 L .37113 .50628 L p 1 0 0 r
F P
0 g
s
.37832 .49486 m .37113 .50628 L .35947 .50432 L p 1 0 0 r
F P
0 g
s
.17794 .64352 m .1692 .66982 L p .16529 .66635 L 0 1 0 r
F P
0 g
s
.16529 .66635 m .16241 .66103 L p .17794 .64352 L 0 1 0 r
F P
0 g
s
.16241 .66103 m .16359 .65734 L .17794 .64352 L p 0 1 0 r
F P
0 g
s
.62056 .4891 m .62844 .48111 L .63934 .48639 L p 0 0 1 r
F P
0 g
s
.62844 .48111 m .62056 .4891 L .60963 .48383 L p 0 0 1 r
F P
0 g
s
.30792 .53821 m .31481 .52946 L .3265 .53307 L p 1 0 0 r
F P
0 g
s
.31481 .52946 m .30792 .53821 L .29626 .53347 L p 1 0 0 r
F P
0 g
s
.66898 .48895 m .67703 .48095 L .68782 .48623 L p 0 0 1 r
F P
0 g
s
.67703 .48095 m .66898 .48895 L .65816 .48367 L p 0 0 1 r
F P
0 g
s
.44909 .44453 m .45643 .43419 L .46772 .43795 L p 1 0 0 r
F P
0 g
s
.46772 .43795 m .47509 .42855 L .48632 .43338 L p 1 0 0 r
F P
0 g
s
.47509 .42855 m .46772 .43795 L .45643 .43419 L p 1 0 0 r
F P
0 g
s
.33352 .52323 m .3265 .53307 L .31481 .52946 L p 1 0 0 r
F P
0 g
s
.50156 .53721 m .50904 .52983 L .5202 .53436 L p 0 1 0 r
F P
0 g
s
.50904 .52983 m .50156 .53721 L .49036 .53136 L p 0 1 0 r
F P
0 g
s
.71741 .48879 m .72562 .48079 L .7363 .48608 L p 0 0 1 r
F P
0 g
s
.72562 .48079 m .71741 .48879 L .7067 .48352 L p 0 0 1 r
F P
0 g
s
.76584 .48863 m .77422 .48063 L .78479 .48592 L p 0 0 1 r
F P
0 g
s
.77422 .48063 m .76584 .48863 L .75524 .48336 L p 0 0 1 r
F P
0 g
s
.81428 .48848 m .82282 .48047 L .83329 .48576 L p 0 0 1 r
F P
0 g
s
.82282 .48047 m .81428 .48848 L .80379 .4832 L p 0 0 1 r
F P
0 g
s
.61635 .32758 m .60946 .35221 L .59917 .3601 L p 0 1 0 r
F P
0 g
s
.59917 .3601 m .60624 .33675 L .61635 .32758 L p 0 1 0 r
F P
0 g
s
.51614 .43809 m .5237 .4321 L .53492 .4406 L p 1 0 0 r
F P
0 g
s
.5237 .4321 m .51614 .43809 L .50496 .43126 L p 1 0 0 r
F P
0 g
s
.32244 .43937 m .32916 .43356 L .34056 .44177 L p 0 1 0 r
F P
0 g
s
.32916 .43356 m .32244 .43937 L .31101 .43194 L p 0 1 0 r
F P
0 g
s
.86273 .48832 m .87143 .48032 L .88179 .48561 L p 0 0 1 r
F P
0 g
s
.87143 .48032 m .86273 .48832 L .85234 .48304 L p 0 0 1 r
F P
0 g
s
.1998 .5292 m .19191 .5489 L .17834 .55662 L p 0 1 0 r
F P
0 g
s
.17834 .55662 m .18651 .53522 L .1998 .5292 L p 0 1 0 r
F P
0 g
s
.10651 .48812 m .11266 .48011 L .12471 .4854 L p 0 0 1 r
F P
0 g
s
.11266 .48011 m .10651 .48812 L .09443 .48284 L p 0 0 1 r
F P
0 g
s
.48632 .43338 m .49375 .42514 L .50496 .43126 L p 1 0 0 r
F P
0 g
s
.49375 .42514 m .48632 .43338 L .47509 .42855 L p 1 0 0 r
F P
0 g
s
.2438 .43841 m .23677 .45069 L .22446 .44989 L p 0 1 0 r
F P
0 g
s
.15492 .48796 m .16123 .47996 L .17317 .48525 L p 0 0 1 r
F P
0 g
s
.16123 .47996 m .15492 .48796 L .14295 .48268 L p 0 0 1 r
F P
0 g
s
.64149 .58392 m .63259 .57728 L .62086 .55846 L p 1 0 0 r
F P
0 g
s
.62086 .55846 m .62952 .5634 L .64149 .58392 L p 1 0 0 r
F P
0 g
s
.54635 .51791 m .5539 .50632 L .5648 .50652 L p 0 1 0 r
F P
0 g
s
.57228 .49281 m .5648 .50652 L .5539 .50632 L p 0 1 0 r
F P
0 g
s
.25175 .48765 m .25839 .47964 L .27012 .48493 L p 0 0 1 r
F P
0 g
s
.25839 .47964 m .25175 .48765 L .23999 .48237 L p 0 0 1 r
F P
0 g
s
.43042 .45263 m .43773 .44159 L .44909 .44453 L p 1 0 0 r
F P
0 g
s
.45643 .43419 m .44909 .44453 L .43773 .44159 L p 1 0 0 r
F P
0 g
s
.61854 .28772 m .61891 .28874 L p .60298 .32091 L 0 1 0 r
F P
0 g
s
.61891 .28874 m .61316 .31168 L .60298 .32091 L p 0 1 0 r
F P
0 g
s
.30018 .48749 m .30698 .47948 L .3186 .48477 L p 0 0 1 r
F P
0 g
s
.30698 .47948 m .30018 .48749 L .28853 .48221 L p 0 0 1 r
F P
0 g
s
.27797 .53474 m .2846 .52805 L .29626 .53347 L p 1 0 0 r
F P
0 g
s
.2846 .52805 m .27797 .53474 L .26643 .52781 L p 1 0 0 r
F P
0 g
s
.46052 .52323 m .46785 .5179 L .47912 .5249 L p 0 1 0 r
F P
0 g
s
.46785 .5179 m .46052 .52323 L .44927 .51541 L p 0 1 0 r
F P
0 g
s
.34861 .48733 m .35558 .47932 L .36709 .48462 L p 0 0 1 r
F P
0 g
s
.35558 .47932 m .34861 .48733 L .33707 .48205 L p 0 0 1 r
F P
0 g
s
.44549 .48702 m .45279 .47901 L .46409 .4843 L p 0 0 1 r
F P
0 g
s
.45279 .47901 m .44549 .48702 L .43417 .48174 L p 0 0 1 r
F P
0 g
s
.61461 .53099 m .60614 .52772 L .59466 .51226 L p 1 0 0 r
F P
0 g
s
.59466 .51226 m .60296 .51408 L .61461 .53099 L p 1 0 0 r
F P
0 g
s
.49395 .48686 m .50141 .47885 L .5126 .48415 L p 0 0 1 r
F P
0 g
s
.50141 .47885 m .49395 .48686 L .48273 .48158 L p 0 0 1 r
F P
0 g
s
.5202 .53436 m .52773 .52552 L .53881 .52847 L p 0 1 0 r
F P
0 g
s
.54635 .51791 m .53881 .52847 L .52773 .52552 L p 0 1 0 r
F P
0 g
s
.2438 .43841 m .25075 .42709 L .26266 .4308 L p 0 1 0 r
F P
0 g
s
.26266 .4308 m .26947 .42124 L .28119 .42649 L p 0 1 0 r
F P
0 g
s
.26947 .42124 m .26266 .4308 L .25075 .42709 L p 0 1 0 r
F P
0 g
s
.5424 .48671 m .55003 .47869 L .56111 .48399 L p 0 0 1 r
F P
0 g
s
.55003 .47869 m .5424 .48671 L .53129 .48142 L p 0 0 1 r
F P
0 g
s
.60992 .29538 m .61827 .28655 L .61854 .28772 L p 0 1 0 r
F P
0 g
s
.60298 .32091 m .60992 .29538 L p .61854 .28772 L 0 1 0 r
F P
0 g
s
.59087 .48655 m .59866 .47853 L .60963 .48383 L p 0 0 1 r
F P
0 g
s
.63934 .48639 m .64729 .47837 L .65816 .48367 L p 0 0 1 r
F P
0 g
s
.64729 .47837 m .63934 .48639 L .62844 .48111 L p 0 0 1 r
F P
0 g
s
.52773 .52552 m .5202 .53436 L .50904 .52983 L p 0 1 0 r
F P
0 g
s
.68782 .48623 m .69594 .47822 L .7067 .48352 L p 0 0 1 r
F P
0 g
s
.69594 .47822 m .68782 .48623 L .67703 .48095 L p 0 0 1 r
F P
0 g
s
.7363 .48608 m .74459 .47806 L .75524 .48336 L p 0 0 1 r
F P
0 g
s
.74459 .47806 m .7363 .48608 L .72562 .48079 L p 0 0 1 r
F P
0 g
s
.78479 .48592 m .79324 .4779 L .80379 .4832 L p 0 0 1 r
F P
0 g
s
.79324 .4779 m .78479 .48592 L .77422 .48063 L p 0 0 1 r
F P
0 g
s
.83329 .48576 m .8419 .47774 L .85234 .48304 L p 0 0 1 r
F P
0 g
s
.8419 .47774 m .83329 .48576 L .82282 .48047 L p 0 0 1 r
F P
0 g
s
.28119 .42649 m .28792 .41842 L .2995 .42494 L p 0 1 0 r
F P
0 g
s
.28792 .41842 m .28119 .42649 L .26947 .42124 L p 0 1 0 r
F P
0 g
s
.5539 .50632 m .56143 .49363 L .57228 .49281 L p 0 1 0 r
F P
0 g
s
.89057 .47758 m .88179 .48561 L .87143 .48032 L p 0 0 1 r
F P
0 g
s
.61612 .28065 m .61827 .28655 L .60992 .29538 L p 0 1 0 r
F P
0 g
s
.33352 .52323 m .3406 .5129 L .35232 .51533 L p 1 0 0 r
F P
0 g
s
.35947 .50432 m .35232 .51533 L .3406 .5129 L p 1 0 0 r
F P
0 g
s
.12471 .4854 m .13092 .47738 L .14295 .48268 L p 0 0 1 r
F P
0 g
s
.13092 .47738 m .12471 .4854 L .11266 .48011 L p 0 0 1 r
F P
0 g
s
.31101 .43194 m .31771 .42565 L .32916 .43356 L p 0 1 0 r
F P
0 g
s
.31771 .42565 m .31101 .43194 L .2995 .42494 L p 0 1 0 r
F P
0 g
s
.17955 .47722 m .17317 .48525 L .16123 .47996 L p 0 0 1 r
F P
0 g
s
.27012 .48493 m .27683 .47691 L .28853 .48221 L p 0 0 1 r
F P
0 g
s
.27683 .47691 m .27012 .48493 L .25839 .47964 L p 0 0 1 r
F P
0 g
s
.35947 .50432 m .36666 .49301 L .37832 .49486 L p 1 0 0 r
F P
0 g
s
.38555 .48327 m .37832 .49486 L .36666 .49301 L p 1 0 0 r
F P
0 g
s
.3186 .48477 m .32547 .47675 L .33707 .48205 L p 0 0 1 r
F P
0 g
s
.32547 .47675 m .3186 .48477 L .30698 .47948 L p 0 0 1 r
F P
0 g
s
.43773 .44159 m .43042 .45263 L .41896 .4503 L p 1 0 0 r
F P
0 g
s
.44927 .51541 m .45655 .51042 L .46785 .5179 L p 0 1 0 r
F P
0 g
s
.45655 .51042 m .44927 .51541 L .438 .50724 L p 0 1 0 r
F P
0 g
s
.18095 .60626 m .17242 .63084 L .15794 .64458 L p 0 1 0 r
F P
0 g
s
.15794 .64458 m .16685 .61788 L .18095 .60626 L p 0 1 0 r
F P
0 g
s
.50496 .43126 m .51248 .42443 L .5237 .4321 L p 1 0 0 r
F P
0 g
s
.51248 .42443 m .50496 .43126 L .49375 .42514 L p 1 0 0 r
F P
0 g
s
.37413 .47659 m .36709 .48462 L .35558 .47932 L p 0 0 1 r
F P
0 g
s
.41559 .48446 m .42279 .47643 L .43417 .48174 L p 0 0 1 r
F P
0 g
s
.22446 .44989 m .23162 .43652 L .2438 .43841 L p 0 1 0 r
F P
0 g
s
.25075 .42709 m .2438 .43841 L .23162 .43652 L p 0 1 0 r
F P
0 g
s
.19191 .5489 m .18381 .57017 L .16993 .57972 L p 0 1 0 r
F P
0 g
s
.16993 .57972 m .17834 .55662 L .19191 .5489 L p 0 1 0 r
F P
0 g
s
.46409 .4843 m .47146 .47627 L .48273 .48158 L p 0 0 1 r
F P
0 g
s
.47146 .47627 m .46409 .4843 L .45279 .47901 L p 0 0 1 r
F P
0 g
s
.49036 .53136 m .49782 .52458 L .50904 .52983 L p 0 1 0 r
F P
0 g
s
.49782 .52458 m .49036 .53136 L .47912 .5249 L p 0 1 0 r
F P
0 g
s
.5126 .48415 m .52013 .47611 L .53129 .48142 L p 0 0 1 r
F P
0 g
s
.52013 .47611 m .5126 .48415 L .50141 .47885 L p 0 0 1 r
F P
0 g
s
.26643 .52781 m .27296 .5219 L .2846 .52805 L p 1 0 0 r
F P
0 g
s
.27296 .5219 m .26643 .52781 L .25495 .52004 L p 1 0 0 r
F P
0 g
s
.60963 .48383 m .6175 .4758 L .62844 .48111 L p 0 0 1 r
F P
0 g
s
.6175 .4758 m .60963 .48383 L .59866 .47853 L p 0 0 1 r
F P
0 g
s
.65816 .48367 m .66619 .47564 L .67703 .48095 L p 0 0 1 r
F P
0 g
s
.66619 .47564 m .65816 .48367 L .64729 .47837 L p 0 0 1 r
F P
0 g
s
.7067 .48352 m .71489 .47548 L .72562 .48079 L p 0 0 1 r
F P
0 g
s
.71489 .47548 m .7067 .48352 L .69594 .47822 L p 0 0 1 r
F P
0 g
s
.60562 .38986 m .59847 .4108 L .58794 .41615 L p 0 1 0 r
F P
0 g
s
.58794 .41615 m .59523 .39644 L .60562 .38986 L p 0 1 0 r
F P
0 g
s
.29626 .53347 m .30308 .52529 L .31481 .52946 L p 1 0 0 r
F P
0 g
s
.30308 .52529 m .29626 .53347 L .2846 .52805 L p 1 0 0 r
F P
0 g
s
.75524 .48336 m .76359 .47532 L .77422 .48063 L p 0 0 1 r
F P
0 g
s
.76359 .47532 m .75524 .48336 L .74459 .47806 L p 0 0 1 r
F P
0 g
s
.80379 .4832 m .81231 .47516 L .82282 .48047 L p 0 0 1 r
F P
0 g
s
.81231 .47516 m .80379 .4832 L .79324 .4779 L p 0 0 1 r
F P
0 g
s
.85234 .48304 m .86103 .475 L .87143 .48032 L p 0 0 1 r
F P
0 g
s
.86103 .475 m .85234 .48304 L .8419 .47774 L p 0 0 1 r
F P
0 g
s
.31481 .52946 m .32178 .52006 L .33352 .52323 L p 1 0 0 r
F P
0 g
s
.3406 .5129 m .33352 .52323 L .32178 .52006 L p 1 0 0 r
F P
0 g
s
.09443 .48284 m .10055 .4748 L .11266 .48011 L p 0 0 1 r
F P
0 g
s
.14295 .48268 m .14923 .47464 L .16123 .47996 L p 0 0 1 r
F P
0 g
s
.14923 .47464 m .14295 .48268 L .13092 .47738 L p 0 0 1 r
F P
0 g
s
.438 .50724 m .44523 .50252 L .45655 .51042 L p 0 1 0 r
F P
0 g
s
.44523 .50252 m .438 .50724 L .42672 .49878 L p 0 1 0 r
F P
0 g
s
.23999 .48237 m .24661 .47432 L .25839 .47964 L p 0 0 1 r
F P
0 g
s
.24661 .47432 m .23999 .48237 L .22818 .47706 L p 0 0 1 r
F P
0 g
s
.45643 .43419 m .46379 .42424 L .47509 .42855 L p 1 0 0 r
F P
0 g
s
.47509 .42855 m .4825 .41966 L .49375 .42514 L p 1 0 0 r
F P
0 g
s
.4825 .41966 m .47509 .42855 L .46379 .42424 L p 1 0 0 r
F P
0 g
s
.28853 .48221 m .29531 .47416 L .30698 .47948 L p 0 0 1 r
F P
0 g
s
.29531 .47416 m .28853 .48221 L .27683 .47691 L p 0 0 1 r
F P
0 g
s
.33707 .48205 m .34401 .47401 L .35558 .47932 L p 0 0 1 r
F P
0 g
s
.34401 .47401 m .33707 .48205 L .32547 .47675 L p 0 0 1 r
F P
0 g
s
.32178 .52006 m .31481 .52946 L .30308 .52529 L p 1 0 0 r
F P
0 g
s
.43773 .44159 m .44506 .43083 L .45643 .43419 L p 1 0 0 r
F P
0 g
s
.46379 .42424 m .45643 .43419 L .44506 .43083 L p 1 0 0 r
F P
0 g
s
.62643 .54956 m .61775 .54472 L .60614 .52772 L p 1 0 0 r
F P
0 g
s
.60614 .52772 m .61461 .53099 L .62643 .54956 L p 1 0 0 r
F P
0 g
s
.43417 .48174 m .44144 .47369 L .45279 .47901 L p 0 0 1 r
F P
0 g
s
.44144 .47369 m .43417 .48174 L .42279 .47643 L p 0 0 1 r
F P
0 g
s
.2995 .42494 m .30621 .41812 L .31771 .42565 L p 0 1 0 r
F P
0 g
s
.30621 .41812 m .2995 .42494 L .28792 .41842 L p 0 1 0 r
F P
0 g
s
.48273 .48158 m .49016 .47353 L .50141 .47885 L p 0 0 1 r
F P
0 g
s
.49016 .47353 m .48273 .48158 L .47146 .47627 L p 0 0 1 r
F P
0 g
s
.52773 .52552 m .53529 .5158 L .54635 .51791 L p 0 1 0 r
F P
0 g
s
.5539 .50632 m .54635 .51791 L .53529 .5158 L p 0 1 0 r
F P
0 g
s
.53129 .48142 m .5389 .47337 L .55003 .47869 L p 0 0 1 r
F P
0 g
s
.5389 .47337 m .53129 .48142 L .52013 .47611 L p 0 0 1 r
F P
0 g
s
.25495 .52004 m .26134 .51497 L .27296 .5219 L p 1 0 0 r
F P
0 g
s
.26134 .51497 m .25495 .52004 L .24352 .51137 L p 1 0 0 r
F P
0 g
s
.66785 .64366 m .66801 .64439 L p .64754 .61208 L 1 0 0 r
F P
0 g
s
.66801 .64439 m .65968 .63504 L .64754 .61208 L p 1 0 0 r
F P
0 g
s
.64754 .61208 m .65669 .62069 L p .66785 .64366 L 1 0 0 r
F P
0 g
s
.62844 .48111 m .63638 .47305 L .64729 .47837 L p 0 0 1 r
F P
0 g
s
.63638 .47305 m .62844 .48111 L .6175 .4758 L p 0 0 1 r
F P
0 g
s
.67703 .48095 m .68513 .47289 L .69594 .47822 L p 0 0 1 r
F P
0 g
s
.68513 .47289 m .67703 .48095 L .66619 .47564 L p 0 0 1 r
F P
0 g
s
.72562 .48079 m .73388 .47274 L .74459 .47806 L p 0 0 1 r
F P
0 g
s
.73388 .47274 m .72562 .48079 L .71489 .47548 L p 0 0 1 r
F P
0 g
s
.77422 .48063 m .78265 .47258 L .79324 .4779 L p 0 0 1 r
F P
0 g
s
.78265 .47258 m .77422 .48063 L .76359 .47532 L p 0 0 1 r
F P
0 g
s
.3406 .5129 m .34774 .50213 L .35947 .50432 L p 1 0 0 r
F P
0 g
s
.36666 .49301 m .35947 .50432 L .34774 .50213 L p 1 0 0 r
F P
0 g
s
.36666 .49301 m .37389 .48147 L .38555 .48327 L p 1 0 0 r
F P
0 g
s
.82282 .48047 m .83142 .47242 L .8419 .47774 L p 0 0 1 r
F P
0 g
s
.83142 .47242 m .82282 .48047 L .81231 .47516 L p 0 0 1 r
F P
0 g
s
.66266 .64949 m .6711 .66687 L .67122 .66887 L p 1 0 0 r
F P
0 g
s
.67024 .66264 m .6711 .66687 L .66266 .64949 L p 1 0 0 r
F P
0 g
s
.66266 .64949 m .6699 .65777 L .67024 .66264 L p 1 0 0 r
F P
0 g
s
.42672 .49878 m .43389 .49428 L .44523 .50252 L p 0 1 0 r
F P
0 g
s
.43389 .49428 m .42672 .49878 L .41542 .4901 L p 0 1 0 r
F P
0 g
s
.50904 .52983 m .51657 .52172 L .52773 .52552 L p 0 1 0 r
F P
0 g
s
.51657 .52172 m .50904 .52983 L .49782 .52458 L p 0 1 0 r
F P
0 g
s
.87143 .48032 m .88019 .47226 L .89057 .47758 L p 0 0 1 r
F P
0 g
s
.88019 .47226 m .87143 .48032 L .86103 .475 L p 0 0 1 r
F P
0 g
s
.34733 .4367 m .34056 .44177 L .32916 .43356 L p 0 1 0 r
F P
0 g
s
.47912 .5249 m .48656 .51865 L .49782 .52458 L p 0 1 0 r
F P
0 g
s
.48656 .51865 m .47912 .5249 L .46785 .5179 L p 0 1 0 r
F P
0 g
s
.25075 .42709 m .25763 .41667 L .26947 .42124 L p 0 1 0 r
F P
0 g
s
.26947 .42124 m .27624 .41245 L .28792 .41842 L p 0 1 0 r
F P
0 g
s
.27624 .41245 m .26947 .42124 L .25763 .41667 L p 0 1 0 r
F P
0 g
s
.49375 .42514 m .50124 .41754 L .51248 .42443 L p 1 0 0 r
F P
0 g
s
.50124 .41754 m .49375 .42514 L .4825 .41966 L p 1 0 0 r
F P
0 g
s
.60992 .29538 m .61485 .27538 L .61612 .28065 L p 0 1 0 r
F P
0 g
s
.11266 .48011 m .11884 .47205 L .13092 .47738 L p 0 0 1 r
F P
0 g
s
.11884 .47205 m .11266 .48011 L .10055 .4748 L p 0 0 1 r
F P
0 g
s
.16123 .47996 m .16758 .4719 L .17955 .47722 L p 0 0 1 r
F P
0 g
s
.16758 .4719 m .16123 .47996 L .14923 .47464 L p 0 0 1 r
F P
0 g
s
.41896 .4503 m .42628 .43895 L .43773 .44159 L p 1 0 0 r
F P
0 g
s
.44506 .43083 m .43773 .44159 L .42628 .43895 L p 1 0 0 r
F P
0 g
s
.23162 .43652 m .23867 .42419 L .25075 .42709 L p 0 1 0 r
F P
0 g
s
.25763 .41667 m .25075 .42709 L .23867 .42419 L p 0 1 0 r
F P
0 g
s
.25839 .47964 m .26507 .47158 L .27683 .47691 L p 0 0 1 r
F P
0 g
s
.26507 .47158 m .25839 .47964 L .24661 .47432 L p 0 0 1 r
F P
0 g
s
.20977 .48008 m .2022 .49705 L .18906 .50138 L p 0 1 0 r
F P
0 g
s
.18906 .50138 m .19686 .48294 L .20977 .48008 L p 0 1 0 r
F P
0 g
s
.24352 .51137 m .24977 .5072 L .26134 .51497 L p 1 0 0 r
F P
0 g
s
.24977 .5072 m .24352 .51137 L .23218 .50176 L p 1 0 0 r
F P
0 g
s
.30698 .47948 m .31383 .47142 L .32547 .47675 L p 0 0 1 r
F P
0 g
s
.31383 .47142 m .30698 .47948 L .29531 .47416 L p 0 0 1 r
F P
0 g
s
.65368 .60644 m .64452 .59797 L .63259 .57728 L p 1 0 0 r
F P
0 g
s
.63259 .57728 m .64149 .58392 L .65368 .60644 L p 1 0 0 r
F P
0 g
s
.35558 .47932 m .36259 .47126 L .37413 .47659 L p 0 0 1 r
F P
0 g
s
.36259 .47126 m .35558 .47932 L .34401 .47401 L p 0 0 1 r
F P
0 g
s
.53529 .5158 m .52773 .52552 L .51657 .52172 L p 0 1 0 r
F P
0 g
s
.1692 .66982 m .16809 .67332 L .16779 .67255 L p 0 1 0 r
F P
0 g
s
.16779 .67255 m .16739 .6718 L .1692 .66982 L p 0 1 0 r
F P
0 g
s
.1692 .66982 m .16739 .6718 L .16529 .66635 L p 0 1 0 r
F P
0 g
s
.45279 .47901 m .46013 .47094 L .47146 .47627 L p 0 0 1 r
F P
0 g
s
.46013 .47094 m .45279 .47901 L .44144 .47369 L p 0 0 1 r
F P
0 g
s
.18381 .57017 m .17546 .59312 L .16124 .60464 L p 0 1 0 r
F P
0 g
s
.16124 .60464 m .16993 .57972 L .18381 .57017 L p 0 1 0 r
F P
0 g
s
.50141 .47885 m .50892 .47078 L .52013 .47611 L p 0 0 1 r
F P
0 g
s
.50892 .47078 m .50141 .47885 L .49016 .47353 L p 0 0 1 r
F P
0 g
s
.23827 .49855 m .23218 .50176 L .22095 .49117 L p 1 0 0 r
F P
0 g
s
.22095 .49117 m .22685 .48897 L .23827 .49855 L p 1 0 0 r
F P
0 g
s
.60946 .35221 m .60242 .37515 L .59196 .38176 L p 0 1 0 r
F P
0 g
s
.59196 .38176 m .59917 .3601 L .60946 .35221 L p 0 1 0 r
F P
0 g
s
.55771 .47062 m .55003 .47869 L .5389 .47337 L p 0 0 1 r
F P
0 g
s
.23218 .50176 m .23827 .49855 L .24977 .5072 L p 1 0 0 r
F P
0 g
s
.41542 .4901 m .42254 .48574 L .43389 .49428 L p 0 1 0 r
F P
0 g
s
.42254 .48574 m .41542 .4901 L .40411 .48126 L p 0 1 0 r
F P
0 g
s
.59866 .47853 m .6065 .47046 L .6175 .4758 L p 0 0 1 r
F P
0 g
s
.6065 .47046 m .59866 .47853 L .58763 .47321 L p 0 0 1 r
F P
0 g
s
.64729 .47837 m .6553 .4703 L .66619 .47564 L p 0 0 1 r
F P
0 g
s
.6553 .4703 m .64729 .47837 L .63638 .47305 L p 0 0 1 r
F P
0 g
s
.2846 .52805 m .29135 .52052 L .30308 .52529 L p 1 0 0 r
F P
0 g
s
.29135 .52052 m .2846 .52805 L .27296 .5219 L p 1 0 0 r
F P
0 g
s
.2022 .49705 m .19445 .5154 L .18106 .5213 L p 0 1 0 r
F P
0 g
s
.18106 .5213 m .18906 .50138 L .2022 .49705 L p 0 1 0 r
F P
0 g
s
.69594 .47822 m .70411 .47014 L .71489 .47548 L p 0 0 1 r
F P
0 g
s
.70411 .47014 m .69594 .47822 L .68513 .47289 L p 0 0 1 r
F P
0 g
s
.53136 .42693 m .5237 .4321 L .51248 .42443 L p 1 0 0 r
F P
0 g
s
.74459 .47806 m .75292 .46999 L .76359 .47532 L p 0 0 1 r
F P
0 g
s
.75292 .46999 m .74459 .47806 L .73388 .47274 L p 0 0 1 r
F P
0 g
s
.32916 .43356 m .3359 .42814 L .34733 .4367 L p 0 1 0 r
F P
0 g
s
.3359 .42814 m .32916 .43356 L .31771 .42565 L p 0 1 0 r
F P
0 g
s
.79324 .4779 m .80174 .46983 L .81231 .47516 L p 0 0 1 r
F P
0 g
s
.80174 .46983 m .79324 .4779 L .78265 .47258 L p 0 0 1 r
F P
0 g
s
.8419 .47774 m .85057 .46967 L .86103 .475 L p 0 0 1 r
F P
0 g
s
.85057 .46967 m .8419 .47774 L .83142 .47242 L p 0 0 1 r
F P
0 g
s
.59975 .50042 m .59143 .49868 L .58001 .48469 L p 1 0 0 r
F P
0 g
s
.58001 .48469 m .58817 .48507 L .59975 .50042 L p 1 0 0 r
F P
0 g
s
.89941 .46951 m .89057 .47758 L .88019 .47226 L p 0 0 1 r
F P
0 g
s
.28792 .41842 m .29464 .411 L .30621 .41812 L p 0 1 0 r
F P
0 g
s
.29464 .411 m .28792 .41842 L .27624 .41245 L p 0 1 0 r
F P
0 g
s
.13092 .47738 m .13718 .4693 L .14923 .47464 L p 0 0 1 r
F P
0 g
s
.13718 .4693 m .13092 .47738 L .11884 .47205 L p 0 0 1 r
F P
0 g
s
.32178 .52006 m .32883 .5101 L .3406 .5129 L p 1 0 0 r
F P
0 g
s
.34774 .50213 m .3406 .5129 L .32883 .5101 L p 1 0 0 r
F P
0 g
s
.53529 .5158 m .54287 .50512 L .5539 .50632 L p 0 1 0 r
F P
0 g
s
.56143 .49363 m .5539 .50632 L .54287 .50512 L p 0 1 0 r
F P
0 g
s
.22818 .47706 m .23477 .46898 L .24661 .47432 L p 0 0 1 r
F P
0 g
s
.23477 .46898 m .22818 .47706 L .21632 .47174 L p 0 0 1 r
F P
0 g
s
.61316 .31168 m .60624 .33675 L .59588 .34469 L p 0 1 0 r
F P
0 g
s
.59588 .34469 m .60298 .32091 L .61316 .31168 L p 0 1 0 r
F P
0 g
s
.40411 .48126 m .41117 .47698 L .42254 .48574 L p 0 1 0 r
F P
0 g
s
.27683 .47691 m .28358 .46882 L .29531 .47416 L p 0 0 1 r
F P
0 g
s
.28358 .46882 m .27683 .47691 L .26507 .47158 L p 0 0 1 r
F P
0 g
s
.32547 .47675 m .33239 .46866 L .34401 .47401 L p 0 0 1 r
F P
0 g
s
.33239 .46866 m .32547 .47675 L .31383 .47142 L p 0 0 1 r
F P
0 g
s
.46785 .5179 m .47525 .51212 L .48656 .51865 L p 0 1 0 r
F P
0 g
s
.47525 .51212 m .46785 .5179 L .45655 .51042 L p 0 1 0 r
F P
0 g
s
.42279 .47643 m .43004 .46835 L .44144 .47369 L p 0 0 1 r
F P
0 g
s
.43004 .46835 m .42279 .47643 L .41136 .4711 L p 0 0 1 r
F P
0 g
s
.47146 .47627 m .47887 .46819 L .49016 .47353 L p 0 0 1 r
F P
0 g
s
.47887 .46819 m .47146 .47627 L .46013 .47094 L p 0 0 1 r
F P
0 g
s
.17242 .63084 m .16359 .65734 L p .15953 .65396 L 0 1 0 r
F P
0 g
s
.15953 .65396 m .15663 .64865 L p .17242 .63084 L 0 1 0 r
F P
0 g
s
.15663 .64865 m .15794 .64458 L .17242 .63084 L p 0 1 0 r
F P
0 g
s
.52013 .47611 m .52771 .46803 L .5389 .47337 L p 0 0 1 r
F P
0 g
s
.52771 .46803 m .52013 .47611 L .50892 .47078 L p 0 0 1 r
F P
0 g
s
.34774 .50213 m .35492 .491 L .36666 .49301 L p 1 0 0 r
F P
0 g
s
.37389 .48147 m .36666 .49301 L .35492 .491 L p 1 0 0 r
F P
0 g
s
.6175 .4758 m .62541 .46771 L .63638 .47305 L p 0 0 1 r
F P
0 g
s
.62541 .46771 m .6175 .4758 L .6065 .47046 L p 0 0 1 r
F P
0 g
s
.44506 .43083 m .45243 .4204 L .46379 .42424 L p 1 0 0 r
F P
0 g
s
.46379 .42424 m .47119 .41475 L .4825 .41966 L p 1 0 0 r
F P
0 g
s
.47119 .41475 m .46379 .42424 L .45243 .4204 L p 1 0 0 r
F P
0 g
s
.19445 .5154 m .18651 .53522 L .17284 .54282 L p 0 1 0 r
F P
0 g
s
.17284 .54282 m .18106 .5213 L .19445 .5154 L p 0 1 0 r
F P
0 g
s
.30308 .52529 m .31 .51641 L .32178 .52006 L p 1 0 0 r
F P
0 g
s
.31 .51641 m .30308 .52529 L .29135 .52052 L p 1 0 0 r
F P
0 g
s
.66619 .47564 m .67427 .46755 L .68513 .47289 L p 0 0 1 r
F P
0 g
s
.67427 .46755 m .66619 .47564 L .6553 .4703 L p 0 0 1 r
F P
0 g
s
.32883 .5101 m .32178 .52006 L .31 .51641 L p 1 0 0 r
F P
0 g
s
.71489 .47548 m .72314 .46739 L .73388 .47274 L p 0 0 1 r
F P
0 g
s
.72314 .46739 m .71489 .47548 L .70411 .47014 L p 0 0 1 r
F P
0 g
s
.23867 .42419 m .23162 .43652 L .21923 .43557 L p 0 1 0 r
F P
0 g
s
.76359 .47532 m .77201 .46723 L .78265 .47258 L p 0 0 1 r
F P
0 g
s
.77201 .46723 m .76359 .47532 L .75292 .46999 L p 0 0 1 r
F P
0 g
s
.61415 .27347 m .61485 .27538 L p .59968 .30468 L 0 1 0 r
F P
0 g
s
.61485 .27538 m .60992 .29538 L .59968 .30468 L p 0 1 0 r
F P
0 g
s
.63843 .56994 m .62952 .5634 L .61775 .54472 L p 1 0 0 r
F P
0 g
s
.61775 .54472 m .62643 .54956 L .63843 .56994 L p 1 0 0 r
F P
0 g
s
.31771 .42565 m .32443 .41982 L .3359 .42814 L p 0 1 0 r
F P
0 g
s
.32443 .41982 m .31771 .42565 L .30621 .41812 L p 0 1 0 r
F P
0 g
s
.51248 .42443 m .52008 .41837 L .53136 .42693 L p 1 0 0 r
F P
0 g
s
.52008 .41837 m .51248 .42443 L .50124 .41754 L p 1 0 0 r
F P
0 g
s
.81231 .47516 m .82089 .46707 L .83142 .47242 L p 0 0 1 r
F P
0 g
s
.82089 .46707 m .81231 .47516 L .80174 .46983 L p 0 0 1 r
F P
0 g
s
.49782 .52458 m .50534 .51712 L .51657 .52172 L p 0 1 0 r
F P
0 g
s
.50534 .51712 m .49782 .52458 L .48656 .51865 L p 0 1 0 r
F P
0 g
s
.86103 .475 m .86977 .46691 L .88019 .47226 L p 0 0 1 r
F P
0 g
s
.86977 .46691 m .86103 .475 L .85057 .46967 L p 0 0 1 r
F P
0 g
s
.4825 .41966 m .48996 .41134 L .50124 .41754 L p 1 0 0 r
F P
0 g
s
.48996 .41134 m .4825 .41966 L .47119 .41475 L p 1 0 0 r
F P
0 g
s
.10055 .4748 m .10671 .4667 L .11884 .47205 L p 0 0 1 r
F P
0 g
s
.14923 .47464 m .15556 .46654 L .16758 .4719 L p 0 0 1 r
F P
0 g
s
.15556 .46654 m .14923 .47464 L .13718 .4693 L p 0 0 1 r
F P
0 g
s
.42628 .43895 m .43362 .42781 L .44506 .43083 L p 1 0 0 r
F P
0 g
s
.45243 .4204 m .44506 .43083 L .43362 .42781 L p 1 0 0 r
F P
0 g
s
.24661 .47432 m .25327 .46623 L .26507 .47158 L p 0 0 1 r
F P
0 g
s
.25327 .46623 m .24661 .47432 L .23477 .46898 L p 0 0 1 r
F P
0 g
s
.29531 .47416 m .30213 .46607 L .31383 .47142 L p 0 0 1 r
F P
0 g
s
.30213 .46607 m .29531 .47416 L .28358 .46882 L p 0 0 1 r
F P
0 g
s
.61145 .51727 m .60296 .51408 L .59143 .49868 L p 1 0 0 r
F P
0 g
s
.59143 .49868 m .59975 .50042 L .61145 .51727 L p 1 0 0 r
F P
0 g
s
.54287 .50512 m .55045 .49339 L .56143 .49363 L p 0 1 0 r
F P
0 g
s
.56895 .47975 m .56143 .49363 L .55045 .49339 L p 0 1 0 r
F P
0 g
s
.34401 .47401 m .351 .46591 L .36259 .47126 L p 0 0 1 r
F P
0 g
s
.351 .46591 m .34401 .47401 L .33239 .46866 L p 0 0 1 r
F P
0 g
s
.23867 .42419 m .24564 .41283 L .25763 .41667 L p 0 1 0 r
F P
0 g
s
.25763 .41667 m .26445 .40709 L .27624 .41245 L p 0 1 0 r
F P
0 g
s
.26445 .40709 m .25763 .41667 L .24564 .41283 L p 0 1 0 r
F P
0 g
s
.27296 .5219 m .27961 .51508 L .29135 .52052 L p 1 0 0 r
F P
0 g
s
.27961 .51508 m .27296 .5219 L .26134 .51497 L p 1 0 0 r
F P
0 g
s
.45655 .51042 m .4639 .50504 L .47525 .51212 L p 0 1 0 r
F P
0 g
s
.4639 .50504 m .45655 .51042 L .44523 .50252 L p 0 1 0 r
F P
0 g
s
.44144 .47369 m .44876 .46559 L .46013 .47094 L p 0 0 1 r
F P
0 g
s
.44876 .46559 m .44144 .47369 L .43004 .46835 L p 0 0 1 r
F P
0 g
s
.49016 .47353 m .49765 .46543 L .50892 .47078 L p 0 0 1 r
F P
0 g
s
.49765 .46543 m .49016 .47353 L .47887 .46819 L p 0 0 1 r
F P
0 g
s
.60664 .27865 m .61362 .27126 L .61415 .27347 L p 0 1 0 r
F P
0 g
s
.59968 .30468 m .60664 .27865 L p .61415 .27347 L 0 1 0 r
F P
0 g
s
.5389 .47337 m .54655 .46527 L .55771 .47062 L p 0 0 1 r
F P
0 g
s
.54655 .46527 m .5389 .47337 L .52771 .46803 L p 0 0 1 r
F P
0 g
s
.58763 .47321 m .59545 .46511 L .6065 .47046 L p 0 0 1 r
F P
0 g
s
.51657 .52172 m .52413 .51279 L .53529 .5158 L p 0 1 0 r
F P
0 g
s
.54287 .50512 m .53529 .5158 L .52413 .51279 L p 0 1 0 r
F P
0 g
s
.63638 .47305 m .64437 .46495 L .6553 .4703 L p 0 0 1 r
F P
0 g
s
.64437 .46495 m .63638 .47305 L .62541 .46771 L p 0 0 1 r
F P
0 g
s
.68513 .47289 m .69328 .46479 L .70411 .47014 L p 0 0 1 r
F P
0 g
s
.69328 .46479 m .68513 .47289 L .67427 .46755 L p 0 0 1 r
F P
0 g
s
.27624 .41245 m .28298 .40437 L .29464 .411 L p 0 1 0 r
F P
0 g
s
.28298 .40437 m .27624 .41245 L .26445 .40709 L p 0 1 0 r
F P
0 g
s
.73388 .47274 m .74221 .46463 L .75292 .46999 L p 0 0 1 r
F P
0 g
s
.74221 .46463 m .73388 .47274 L .72314 .46739 L p 0 0 1 r
F P
0 g
s
.78265 .47258 m .79114 .46447 L .80174 .46983 L p 0 0 1 r
F P
0 g
s
.79114 .46447 m .78265 .47258 L .77201 .46723 L p 0 0 1 r
F P
0 g
s
.52413 .51279 m .51657 .52172 L .50534 .51712 L p 0 1 0 r
F P
0 g
s
.83142 .47242 m .84007 .46431 L .85057 .46967 L p 0 0 1 r
F P
0 g
s
.84007 .46431 m .83142 .47242 L .82089 .46707 L p 0 0 1 r
F P
0 g
s
.88019 .47226 m .88901 .46415 L .89941 .46951 L p 0 0 1 r
F P
0 g
s
.88901 .46415 m .88019 .47226 L .86977 .46691 L p 0 0 1 r
F P
0 g
s
.32883 .5101 m .33594 .49964 L .34774 .50213 L p 1 0 0 r
F P
0 g
s
.35492 .491 m .34774 .50213 L .33594 .49964 L p 1 0 0 r
F P
0 g
s
.30621 .41812 m .31292 .41181 L .32443 .41982 L p 0 1 0 r
F P
0 g
s
.31292 .41181 m .30621 .41812 L .29464 .411 L p 0 1 0 r
F P
0 g
s
.11884 .47205 m .12507 .46394 L .13718 .4693 L p 0 0 1 r
F P
0 g
s
.12507 .46394 m .11884 .47205 L .10671 .4667 L p 0 0 1 r
F P
0 g
s
.55045 .49339 m .55802 .48053 L .56895 .47975 L p 0 1 0 r
F P
0 g
s
.17398 .46378 m .16758 .4719 L .15556 .46654 L p 0 0 1 r
F P
0 g
s
.17546 .59312 m .16685 .61788 L .15224 .63153 L p 0 1 0 r
F P
0 g
s
.15224 .63153 m .16124 .60464 L .17546 .59312 L p 0 1 0 r
F P
0 g
s
.21632 .47174 m .22289 .46362 L .23477 .46898 L p 0 0 1 r
F P
0 g
s
.21923 .43557 m .22642 .42215 L .23867 .42419 L p 0 1 0 r
F P
0 g
s
.24564 .41283 m .23867 .42419 L .22642 .42215 L p 0 1 0 r
F P
0 g
s
.18651 .53522 m .17834 .55662 L .16435 .56605 L p 0 1 0 r
F P
0 g
s
.16435 .56605 m .17284 .54282 L .18651 .53522 L p 0 1 0 r
F P
0 g
s
.26507 .47158 m .2718 .46346 L .28358 .46882 L p 0 0 1 r
F P
0 g
s
.2718 .46346 m .26507 .47158 L .25327 .46623 L p 0 0 1 r
F P
0 g
s
.43362 .42781 m .42628 .43895 L .41474 .43654 L p 1 0 0 r
F P
0 g
s
.35492 .491 m .36215 .47957 L .37389 .48147 L p 1 0 0 r
F P
0 g
s
.38116 .46977 m .37389 .48147 L .36215 .47957 L p 1 0 0 r
F P
0 g
s
.61177 .26631 m .61362 .27126 L .60664 .27865 L p 0 1 0 r
F P
0 g
s
.31383 .47142 m .32072 .4633 L .33239 .46866 L p 0 0 1 r
F P
0 g
s
.32072 .4633 m .31383 .47142 L .30213 .46607 L p 0 0 1 r
F P
0 g
s
.50124 .41754 m .50879 .41064 L .52008 .41837 L p 1 0 0 r
F P
0 g
s
.50879 .41064 m .50124 .41754 L .48996 .41134 L p 1 0 0 r
F P
0 g
s
.36965 .46314 m .36259 .47126 L .351 .46591 L p 0 0 1 r
F P
0 g
s
.41136 .4711 m .41859 .46298 L .43004 .46835 L p 0 0 1 r
F P
0 g
s
.44523 .50252 m .45253 .49749 L .4639 .50504 L p 0 1 0 r
F P
0 g
s
.45253 .49749 m .44523 .50252 L .43389 .49428 L p 0 1 0 r
F P
0 g
s
.60242 .37515 m .59523 .39644 L .58463 .40181 L p 0 1 0 r
F P
0 g
s
.58463 .40181 m .59196 .38176 L .60242 .37515 L p 0 1 0 r
F P
0 g
s
.46013 .47094 m .46753 .46282 L .47887 .46819 L p 0 0 1 r
F P
0 g
s
.46753 .46282 m .46013 .47094 L .44876 .46559 L p 0 0 1 r
F P
0 g
s
.50892 .47078 m .51648 .46266 L .52771 .46803 L p 0 0 1 r
F P
0 g
s
.51648 .46266 m .50892 .47078 L .49765 .46543 L p 0 0 1 r
F P
0 g
s
.48656 .51865 m .49405 .5118 L .50534 .51712 L p 0 1 0 r
F P
0 g
s
.49405 .5118 m .48656 .51865 L .47525 .51212 L p 0 1 0 r
F P
0 g
s
.6065 .47046 m .6144 .46234 L .62541 .46771 L p 0 0 1 r
F P
0 g
s
.6144 .46234 m .6065 .47046 L .59545 .46511 L p 0 0 1 r
F P
0 g
s
.26134 .51497 m .26788 .50892 L .27961 .51508 L p 1 0 0 r
F P
0 g
s
.26788 .50892 m .26134 .51497 L .24977 .5072 L p 1 0 0 r
F P
0 g
s
.6553 .4703 m .66336 .46218 L .67427 .46755 L p 0 0 1 r
F P
0 g
s
.66336 .46218 m .6553 .4703 L .64437 .46495 L p 0 0 1 r
F P
0 g
s
.70411 .47014 m .71234 .46202 L .72314 .46739 L p 0 0 1 r
F P
0 g
s
.71234 .46202 m .70411 .47014 L .69328 .46479 L p 0 0 1 r
F P
0 g
s
.75292 .46999 m .76132 .46186 L .77201 .46723 L p 0 0 1 r
F P
0 g
s
.76132 .46186 m .75292 .46999 L .74221 .46463 L p 0 0 1 r
F P
0 g
s
.29135 .52052 m .2982 .51221 L .31 .51641 L p 1 0 0 r
F P
0 g
s
.2982 .51221 m .29135 .52052 L .27961 .51508 L p 1 0 0 r
F P
0 g
s
.80174 .46983 m .81031 .4617 L .82089 .46707 L p 0 0 1 r
F P
0 g
s
.81031 .4617 m .80174 .46983 L .79114 .46447 L p 0 0 1 r
F P
0 g
s
.85057 .46967 m .8593 .46154 L .86977 .46691 L p 0 0 1 r
F P
0 g
s
.8593 .46154 m .85057 .46967 L .84007 .46431 L p 0 0 1 r
F P
0 g
s
.9083 .46138 m .89941 .46951 L .88901 .46415 L p 0 0 1 r
F P
0 g
s
.31 .51641 m .31701 .50689 L .32883 .5101 L p 1 0 0 r
F P
0 g
s
.33594 .49964 m .32883 .5101 L .31701 .50689 L p 1 0 0 r
F P
0 g
s
.13718 .4693 m .14348 .46117 L .15556 .46654 L p 0 0 1 r
F P
0 g
s
.14348 .46117 m .13718 .4693 L .12507 .46394 L p 0 0 1 r
F P
0 g
s
.66596 .63086 m .66598 .63096 L p .64452 .59797 L 1 0 0 r
F P
0 g
s
.66598 .63096 m .65669 .62069 L .64452 .59797 L p 1 0 0 r
F P
0 g
s
.64452 .59797 m .65368 .60644 L p .66596 .63086 L 1 0 0 r
F P
0 g
s
.62331 .53575 m .61461 .53099 L .60296 .51408 L p 1 0 0 r
F P
0 g
s
.60296 .51408 m .61145 .51727 L .62331 .53575 L p 1 0 0 r
F P
0 g
s
.65968 .63504 m .66951 .65501 L .6696 .65633 L p 1 0 0 r
F P
0 g
s
.66845 .65005 m .66951 .65501 L .65968 .63504 L p 1 0 0 r
F P
0 g
s
.65968 .63504 m .66801 .64439 L .66845 .65005 L p 1 0 0 r
F P
0 g
s
.23477 .46898 m .24141 .46085 L .25327 .46623 L p 0 0 1 r
F P
0 g
s
.24141 .46085 m .23477 .46898 L .22289 .46362 L p 0 0 1 r
F P
0 g
s
.45243 .4204 m .45982 .41037 L .47119 .41475 L p 1 0 0 r
F P
0 g
s
.47119 .41475 m .47863 .40579 L .48996 .41134 L p 1 0 0 r
F P
0 g
s
.47863 .40579 m .47119 .41475 L .45982 .41037 L p 1 0 0 r
F P
0 g
s
.28358 .46882 m .29038 .46069 L .30213 .46607 L p 0 0 1 r
F P
0 g
s
.29038 .46069 m .28358 .46882 L .2718 .46346 L p 0 0 1 r
F P
0 g
s
.43389 .49428 m .44114 .48952 L .45253 .49749 L p 0 1 0 r
F P
0 g
s
.44114 .48952 m .43389 .49428 L .42254 .48574 L p 0 1 0 r
F P
0 g
s
.43362 .42781 m .44099 .41695 L .45243 .4204 L p 1 0 0 r
F P
0 g
s
.45982 .41037 m .45243 .4204 L .44099 .41695 L p 1 0 0 r
F P
0 g
s
.33239 .46866 m .33936 .46053 L .351 .46591 L p 0 0 1 r
F P
0 g
s
.33936 .46053 m .33239 .46866 L .32072 .4633 L p 0 0 1 r
F P
0 g
s
.31701 .50689 m .31 .51641 L .2982 .51221 L p 1 0 0 r
F P
0 g
s
.29464 .411 m .30135 .40416 L .31292 .41181 L p 0 1 0 r
F P
0 g
s
.30135 .40416 m .29464 .411 L .28298 .40437 L p 0 1 0 r
F P
0 g
s
.43004 .46835 m .43734 .46021 L .44876 .46559 L p 0 0 1 r
F P
0 g
s
.43734 .46021 m .43004 .46835 L .41859 .46298 L p 0 0 1 r
F P
0 g
s
.47887 .46819 m .48634 .46005 L .49765 .46543 L p 0 0 1 r
F P
0 g
s
.48634 .46005 m .47887 .46819 L .46753 .46282 L p 0 0 1 r
F P
0 g
s
.52771 .46803 m .53535 .45989 L .54655 .46527 L p 0 0 1 r
F P
0 g
s
.53535 .45989 m .52771 .46803 L .51648 .46266 L p 0 0 1 r
F P
0 g
s
.52413 .51279 m .53173 .50296 L .54287 .50512 L p 0 1 0 r
F P
0 g
s
.55045 .49339 m .54287 .50512 L .53173 .50296 L p 0 1 0 r
F P
0 g
s
.62541 .46771 m .63338 .45956 L .64437 .46495 L p 0 0 1 r
F P
0 g
s
.63338 .45956 m .62541 .46771 L .6144 .46234 L p 0 0 1 r
F P
0 g
s
.24977 .5072 m .25619 .50199 L .26788 .50892 L p 1 0 0 r
F P
0 g
s
.25619 .50199 m .24977 .5072 L .23827 .49855 L p 1 0 0 r
F P
0 g
s
.67427 .46755 m .68241 .4594 L .69328 .46479 L p 0 0 1 r
F P
0 g
s
.68241 .4594 m .67427 .46755 L .66336 .46218 L p 0 0 1 r
F P
0 g
s
.72314 .46739 m .73144 .45924 L .74221 .46463 L p 0 0 1 r
F P
0 g
s
.73144 .45924 m .72314 .46739 L .71234 .46202 L p 0 0 1 r
F P
0 g
s
.24564 .41283 m .25254 .40238 L .26445 .40709 L p 0 1 0 r
F P
0 g
s
.26445 .40709 m .27124 .39827 L .28298 .40437 L p 0 1 0 r
F P
0 g
s
.27124 .39827 m .26445 .40709 L .25254 .40238 L p 0 1 0 r
F P
0 g
s
.33594 .49964 m .34311 .48875 L .35492 .491 L p 1 0 0 r
F P
0 g
s
.36215 .47957 m .35492 .491 L .34311 .48875 L p 1 0 0 r
F P
0 g
s
.77201 .46723 m .78048 .45908 L .79114 .46447 L p 0 0 1 r
F P
0 g
s
.78048 .45908 m .77201 .46723 L .76132 .46186 L p 0 0 1 r
F P
0 g
s
.36215 .47957 m .36941 .46791 L .38116 .46977 L p 1 0 0 r
F P
0 g
s
.82089 .46707 m .82952 .45892 L .84007 .46431 L p 0 0 1 r
F P
0 g
s
.82952 .45892 m .82089 .46707 L .81031 .4617 L p 0 0 1 r
F P
0 g
s
.65066 .59227 m .64149 .58392 L .62952 .5634 L p 1 0 0 r
F P
0 g
s
.62952 .5634 m .63843 .56994 L .65066 .59227 L p 1 0 0 r
F P
0 g
s
.60664 .27865 m .61069 .26196 L .61177 .26631 L p 0 1 0 r
F P
0 g
s
.86977 .46691 m .87858 .45876 L .88901 .46415 L p 0 0 1 r
F P
0 g
s
.87858 .45876 m .86977 .46691 L .8593 .46154 L p 0 0 1 r
F P
0 g
s
.22642 .42215 m .23349 .40978 L .24564 .41283 L p 0 1 0 r
F P
0 g
s
.25254 .40238 m .24564 .41283 L .23349 .40978 L p 0 1 0 r
F P
0 g
s
.34268 .42305 m .3359 .42814 L .32443 .41982 L p 0 1 0 r
F P
0 g
s
.48996 .41134 m .49747 .40368 L .50879 .41064 L p 1 0 0 r
F P
0 g
s
.49747 .40368 m .48996 .41134 L .47863 .40579 L p 1 0 0 r
F P
0 g
s
.42254 .48574 m .42973 .4812 L .44114 .48952 L p 0 1 0 r
F P
0 g
s
.42973 .4812 m .42254 .48574 L .41117 .47698 L p 0 1 0 r
F P
0 g
s
.60624 .33675 m .59917 .3601 L .58864 .36675 L p 0 1 0 r
F P
0 g
s
.58864 .36675 m .59588 .34469 L .60624 .33675 L p 0 1 0 r
F P
0 g
s
.10671 .4667 m .11292 .45855 L .12507 .46394 L p 0 0 1 r
F P
0 g
s
.15556 .46654 m .16193 .45839 L .17398 .46378 L p 0 0 1 r
F P
0 g
s
.16193 .45839 m .15556 .46654 L .14348 .46117 L p 0 0 1 r
F P
0 g
s
.41474 .43654 m .42209 .42509 L .43362 .42781 L p 1 0 0 r
F P
0 g
s
.44099 .41695 m .43362 .42781 L .42209 .42509 L p 1 0 0 r
F P
0 g
s
.50534 .51712 m .5129 .50892 L .52413 .51279 L p 0 1 0 r
F P
0 g
s
.5129 .50892 m .50534 .51712 L .49405 .5118 L p 0 1 0 r
F P
0 g
s
.47525 .51212 m .48271 .50581 L .49405 .5118 L p 0 1 0 r
F P
0 g
s
.48271 .50581 m .47525 .51212 L .4639 .50504 L p 0 1 0 r
F P
0 g
s
.25327 .46623 m .25997 .45807 L .2718 .46346 L p 0 0 1 r
F P
0 g
s
.25997 .45807 m .25327 .46623 L .24141 .46085 L p 0 0 1 r
F P
0 g
s
.17834 .55662 m .16993 .57972 L .15559 .59112 L p 0 1 0 r
F P
0 g
s
.15559 .59112 m .16435 .56605 L .17834 .55662 L p 0 1 0 r
F P
0 g
s
.30213 .46607 m .309 .45791 L .32072 .4633 L p 0 0 1 r
F P
0 g
s
.309 .45791 m .30213 .46607 L .29038 .46069 L p 0 0 1 r
F P
0 g
s
.22146 .47605 m .21554 .47841 L .20435 .46684 L p 1 0 0 r
F P
0 g
s
.20435 .46684 m .21007 .46554 L .22146 .47605 L p 1 0 0 r
F P
0 g
s
.351 .46591 m .35804 .45775 L .36965 .46314 L p 0 0 1 r
F P
0 g
s
.35804 .45775 m .351 .46591 L .33936 .46053 L p 0 0 1 r
F P
0 g
s
.16359 .65734 m .16241 .66103 L .1621 .66022 L p 0 1 0 r
F P
0 g
s
.1621 .66022 m .16167 .65941 L .16359 .65734 L p 0 1 0 r
F P
0 g
s
.16359 .65734 m .16167 .65941 L .15953 .65396 L p 0 1 0 r
F P
0 g
s
.60992 .29538 m .60298 .32091 L .59255 .32892 L p 0 1 0 r
F P
0 g
s
.59255 .32892 m .59968 .30468 L .60992 .29538 L p 0 1 0 r
F P
0 g
s
.19686 .48294 m .18906 .50138 L .17557 .50713 L p 0 1 0 r
F P
0 g
s
.17557 .50713 m .18363 .48712 L .19686 .48294 L p 0 1 0 r
F P
0 g
s
.23827 .49855 m .24454 .49423 L .25619 .50199 L p 1 0 0 r
F P
0 g
s
.24454 .49423 m .23827 .49855 L .22685 .48897 L p 1 0 0 r
F P
0 g
s
.44876 .46559 m .45614 .45743 L .46753 .46282 L p 0 0 1 r
F P
0 g
s
.45614 .45743 m .44876 .46559 L .43734 .46021 L p 0 0 1 r
F P
0 g
s
.53173 .50296 m .52413 .51279 L .5129 .50892 L p 0 1 0 r
F P
0 g
s
.49765 .46543 m .50519 .45727 L .51648 .46266 L p 0 0 1 r
F P
0 g
s
.50519 .45727 m .49765 .46543 L .48634 .46005 L p 0 0 1 r
F P
0 g
s
.55426 .45711 m .54655 .46527 L .53535 .45989 L p 0 0 1 r
F P
0 g
s
.59545 .46511 m .60333 .45694 L .6144 .46234 L p 0 0 1 r
F P
0 g
s
.60333 .45694 m .59545 .46511 L .58436 .45972 L p 0 0 1 r
F P
0 g
s
.41117 .47698 m .41831 .47259 L .42973 .4812 L p 0 1 0 r
F P
0 g
s
.41831 .47259 m .41117 .47698 L .39979 .46805 L p 0 1 0 r
F P
0 g
s
.64437 .46495 m .65241 .45678 L .66336 .46218 L p 0 0 1 r
F P
0 g
s
.65241 .45678 m .64437 .46495 L .63338 .45956 L p 0 0 1 r
F P
0 g
s
.69328 .46479 m .70149 .45662 L .71234 .46202 L p 0 0 1 r
F P
0 g
s
.70149 .45662 m .69328 .46479 L .68241 .4594 L p 0 0 1 r
F P
0 g
s
.23296 .4856 m .22685 .48897 L .21554 .47841 L p 1 0 0 r
F P
0 g
s
.21554 .47841 m .22146 .47605 L .23296 .4856 L p 1 0 0 r
F P
0 g
s
.52776 .41315 m .52008 .41837 L .50879 .41064 L p 1 0 0 r
F P
0 g
s
.22685 .48897 m .23296 .4856 L .24454 .49423 L p 1 0 0 r
F P
0 g
s
.27961 .51508 m .28638 .50742 L .2982 .51221 L p 1 0 0 r
F P
0 g
s
.28638 .50742 m .27961 .51508 L .26788 .50892 L p 1 0 0 r
F P
0 g
s
.74221 .46463 m .75058 .45646 L .76132 .46186 L p 0 0 1 r
F P
0 g
s
.75058 .45646 m .74221 .46463 L .73144 .45924 L p 0 0 1 r
F P
0 g
s
.32443 .41982 m .33119 .41439 L .34268 .42305 L p 0 1 0 r
F P
0 g
s
.33119 .41439 m .32443 .41982 L .31292 .41181 L p 0 1 0 r
F P
0 g
s
.59651 .48675 m .58817 .48507 L .57669 .4711 L p 1 0 0 r
F P
0 g
s
.57669 .4711 m .58487 .47143 L .59651 .48675 L p 1 0 0 r
F P
0 g
s
.79114 .46447 m .79968 .4563 L .81031 .4617 L p 0 0 1 r
F P
0 g
s
.79968 .4563 m .79114 .46447 L .78048 .45908 L p 0 0 1 r
F P
0 g
s
.28298 .40437 m .28971 .39693 L .30135 .40416 L p 0 1 0 r
F P
0 g
s
.28971 .39693 m .28298 .40437 L .27124 .39827 L p 0 1 0 r
F P
0 g
s
.84007 .46431 m .84878 .45614 L .8593 .46154 L p 0 0 1 r
F P
0 g
s
.84878 .45614 m .84007 .46431 L .82952 .45892 L p 0 0 1 r
F P
0 g
s
.88901 .46415 m .8979 .45598 L .9083 .46138 L p 0 0 1 r
F P
0 g
s
.8979 .45598 m .88901 .46415 L .87858 .45876 L p 0 0 1 r
F P
0 g
s
.12507 .46394 m .13135 .45577 L .14348 .46117 L p 0 0 1 r
F P
0 g
s
.13135 .45577 m .12507 .46394 L .11292 .45855 L p 0 0 1 r
F P
0 g
s
.31701 .50689 m .32408 .4968 L .33594 .49964 L p 1 0 0 r
F P
0 g
s
.34311 .48875 m .33594 .49964 L .32408 .4968 L p 1 0 0 r
F P
0 g
s
.22289 .46362 m .22949 .45545 L .24141 .46085 L p 0 0 1 r
F P
0 g
s
.22949 .45545 m .22289 .46362 L .21095 .45823 L p 0 0 1 r
F P
0 g
s
.53173 .50296 m .53934 .49214 L .55045 .49339 L p 0 1 0 r
F P
0 g
s
.55802 .48053 m .55045 .49339 L .53934 .49214 L p 0 1 0 r
F P
0 g
s
.2718 .46346 m .27858 .45529 L .29038 .46069 L p 0 0 1 r
F P
0 g
s
.27858 .45529 m .2718 .46346 L .25997 .45807 L p 0 0 1 r
F P
0 g
s
.39979 .46805 m .40688 .46375 L .41831 .47259 L p 0 1 0 r
F P
0 g
s
.32072 .4633 m .32767 .45513 L .33936 .46053 L p 0 0 1 r
F P
0 g
s
.32767 .45513 m .32072 .4633 L .309 .45791 L p 0 0 1 r
F P
0 g
s
.18906 .50138 m .18106 .5213 L .16729 .52876 L p 0 1 0 r
F P
0 g
s
.16729 .52876 m .17557 .50713 L .18906 .50138 L p 0 1 0 r
F P
0 g
s
.16685 .61788 m .15794 .64458 L p .15363 .64143 L 0 1 0 r
F P
0 g
s
.15363 .64143 m .15074 .63618 L p .16685 .61788 L 0 1 0 r
F P
0 g
s
.15074 .63618 m .15224 .63153 L .16685 .61788 L p 0 1 0 r
F P
0 g
s
.41859 .46298 m .42587 .4548 L .43734 .46021 L p 0 0 1 r
F P
0 g
s
.42587 .4548 m .41859 .46298 L .40709 .45759 L p 0 0 1 r
F P
0 g
s
.4639 .50504 m .47132 .49921 L .48271 .50581 L p 0 1 0 r
F P
0 g
s
.47132 .49921 m .4639 .50504 L .45253 .49749 L p 0 1 0 r
F P
0 g
s
.6096 .25908 m .61069 .26196 L p .59632 .28805 L 0 1 0 r
F P
0 g
s
.61069 .26196 m .60664 .27865 L .59632 .28805 L p 0 1 0 r
F P
0 g
s
.46753 .46282 m .47498 .45464 L .48634 .46005 L p 0 0 1 r
F P
0 g
s
.47498 .45464 m .46753 .46282 L .45614 .45743 L p 0 0 1 r
F P
0 g
s
.23349 .40978 m .22642 .42215 L .21395 .42106 L p 0 1 0 r
F P
0 g
s
.51648 .46266 m .52409 .45448 L .53535 .45989 L p 0 0 1 r
F P
0 g
s
.52409 .45448 m .51648 .46266 L .50519 .45727 L p 0 0 1 r
F P
0 g
s
.34311 .48875 m .35032 .47749 L .36215 .47957 L p 1 0 0 r
F P
0 g
s
.36941 .46791 m .36215 .47957 L .35032 .47749 L p 1 0 0 r
F P
0 g
s
.63535 .55601 m .62643 .54956 L .61461 .53099 L p 1 0 0 r
F P
0 g
s
.61461 .53099 m .62331 .53575 L .63535 .55601 L p 1 0 0 r
F P
0 g
s
.44099 .41695 m .44839 .40644 L .45982 .41037 L p 1 0 0 r
F P
0 g
s
.45982 .41037 m .46725 .4008 L .47863 .40579 L p 1 0 0 r
F P
0 g
s
.46725 .4008 m .45982 .41037 L .44839 .40644 L p 1 0 0 r
F P
0 g
s
.6144 .46234 m .62234 .45416 L .63338 .45956 L p 0 0 1 r
F P
0 g
s
.62234 .45416 m .6144 .46234 L .60333 .45694 L p 0 0 1 r
F P
0 g
s
.66336 .46218 m .67148 .454 L .68241 .4594 L p 0 0 1 r
F P
0 g
s
.67148 .454 m .66336 .46218 L .65241 .45678 L p 0 0 1 r
F P
0 g
s
.2982 .51221 m .30515 .5032 L .31701 .50689 L p 1 0 0 r
F P
0 g
s
.30515 .5032 m .2982 .51221 L .28638 .50742 L p 1 0 0 r
F P
0 g
s
.71234 .46202 m .72062 .45383 L .73144 .45924 L p 0 0 1 r
F P
0 g
s
.72062 .45383 m .71234 .46202 L .70149 .45662 L p 0 0 1 r
F P
0 g
s
.32408 .4968 m .31701 .50689 L .30515 .5032 L p 1 0 0 r
F P
0 g
s
.31292 .41181 m .31966 .40596 L .33119 .41439 L p 0 1 0 r
F P
0 g
s
.31966 .40596 m .31292 .41181 L .30135 .40416 L p 0 1 0 r
F P
0 g
s
.76132 .46186 m .76977 .45367 L .78048 .45908 L p 0 0 1 r
F P
0 g
s
.76977 .45367 m .76132 .46186 L .75058 .45646 L p 0 0 1 r
F P
0 g
s
.50879 .41064 m .51641 .40453 L .52776 .41315 L p 1 0 0 r
F P
0 g
s
.51641 .40453 m .50879 .41064 L .49747 .40368 L p 1 0 0 r
F P
0 g
s
.81031 .4617 m .81893 .45351 L .82952 .45892 L p 0 0 1 r
F P
0 g
s
.81893 .45351 m .81031 .4617 L .79968 .4563 L p 0 0 1 r
F P
0 g
s
.8593 .46154 m .86809 .45335 L .87858 .45876 L p 0 0 1 r
F P
0 g
s
.86809 .45335 m .8593 .46154 L .84878 .45614 L p 0 0 1 r
F P
0 g
s
.47863 .40579 m .48612 .39741 L .49747 .40368 L p 1 0 0 r
F P
0 g
s
.48612 .39741 m .47863 .40579 L .46725 .4008 L p 1 0 0 r
F P
0 g
s
.91726 .45319 m .9083 .46138 L .8979 .45598 L p 0 0 1 r
F P
0 g
s
.49405 .5118 m .50159 .50427 L .5129 .50892 L p 0 1 0 r
F P
0 g
s
.50159 .50427 m .49405 .5118 L .48271 .50581 L p 0 1 0 r
F P
0 g
s
.14348 .46117 m .14982 .45298 L .16193 .45839 L p 0 0 1 r
F P
0 g
s
.14982 .45298 m .14348 .46117 L .13135 .45577 L p 0 0 1 r
F P
0 g
s
.42209 .42509 m .42947 .41386 L .44099 .41695 L p 1 0 0 r
F P
0 g
s
.44839 .40644 m .44099 .41695 L .42947 .41386 L p 1 0 0 r
F P
0 g
s
.23349 .40978 m .24048 .3984 L .25254 .40238 L p 0 1 0 r
F P
0 g
s
.25254 .40238 m .25938 .39277 L .27124 .39827 L p 0 1 0 r
F P
0 g
s
.25938 .39277 m .25254 .40238 L .24048 .3984 L p 0 1 0 r
F P
0 g
s
.60826 .50356 m .59975 .50042 L .58817 .48507 L p 1 0 0 r
F P
0 g
s
.58817 .48507 m .59651 .48675 L .60826 .50356 L p 1 0 0 r
F P
0 g
s
.24141 .46085 m .24809 .45266 L .25997 .45807 L p 0 0 1 r
F P
0 g
s
.24809 .45266 m .24141 .46085 L .22949 .45545 L p 0 0 1 r
F P
0 g
s
.29038 .46069 m .29723 .4525 L .309 .45791 L p 0 0 1 r
F P
0 g
s
.29723 .4525 m .29038 .46069 L .27858 .45529 L p 0 0 1 r
F P
0 g
s
.33936 .46053 m .34638 .45234 L .35804 .45775 L p 0 0 1 r
F P
0 g
s
.34638 .45234 m .33936 .46053 L .32767 .45513 L p 0 0 1 r
F P
0 g
s
.53934 .49214 m .54696 .48026 L .55802 .48053 L p 0 1 0 r
F P
0 g
s
.56557 .46646 m .55802 .48053 L .54696 .48026 L p 0 1 0 r
F P
0 g
s
.6033 .26149 m .60876 .2557 L .6096 .25908 L p 0 1 0 r
F P
0 g
s
.59632 .28805 m .6033 .26149 L p .6096 .25908 L 0 1 0 r
F P
0 g
s
.26788 .50892 m .27456 .50196 L .28638 .50742 L p 1 0 0 r
F P
0 g
s
.27456 .50196 m .26788 .50892 L .25619 .50199 L p 1 0 0 r
F P
0 g
s
.43734 .46021 m .44469 .45201 L .45614 .45743 L p 0 0 1 r
F P
0 g
s
.44469 .45201 m .43734 .46021 L .42587 .4548 L p 0 0 1 r
F P
0 g
s
.48634 .46005 m .49386 .45185 L .50519 .45727 L p 0 0 1 r
F P
0 g
s
.49386 .45185 m .48634 .46005 L .47498 .45464 L p 0 0 1 r
F P
0 g
s
.53535 .45989 m .54303 .45169 L .55426 .45711 L p 0 0 1 r
F P
0 g
s
.54303 .45169 m .53535 .45989 L .52409 .45448 L p 0 0 1 r
F P
0 g
s
.45253 .49749 m .45991 .49207 L .47132 .49921 L p 0 1 0 r
F P
0 g
s
.45991 .49207 m .45253 .49749 L .44114 .48952 L p 0 1 0 r
F P
0 g
s
.58436 .45972 m .59222 .45153 L .60333 .45694 L p 0 0 1 r
F P
0 g
s
.27124 .39827 m .27799 .39017 L .28971 .39693 L p 0 1 0 r
F P
0 g
s
.27799 .39017 m .27124 .39827 L .25938 .39277 L p 0 1 0 r
F P
0 g
s
.63338 .45956 m .6414 .45136 L .65241 .45678 L p 0 0 1 r
F P
0 g
s
.6414 .45136 m .63338 .45956 L .62234 .45416 L p 0 0 1 r
F P
0 g
s
.68241 .4594 m .6906 .4512 L .70149 .45662 L p 0 0 1 r
F P
0 g
s
.6906 .4512 m .68241 .4594 L .67148 .454 L p 0 0 1 r
F P
0 g
s
.73144 .45924 m .7398 .45104 L .75058 .45646 L p 0 0 1 r
F P
0 g
s
.7398 .45104 m .73144 .45924 L .72062 .45383 L p 0 0 1 r
F P
0 g
s
.5129 .50892 m .5205 .49989 L .53173 .50296 L p 0 1 0 r
F P
0 g
s
.53934 .49214 m .53173 .50296 L .5205 .49989 L p 0 1 0 r
F P
0 g
s
.78048 .45908 m .78901 .45088 L .79968 .4563 L p 0 0 1 r
F P
0 g
s
.78901 .45088 m .78048 .45908 L .76977 .45367 L p 0 0 1 r
F P
0 g
s
.18106 .5213 m .17284 .54282 L .15873 .55211 L p 0 1 0 r
F P
0 g
s
.15873 .55211 m .16729 .52876 L .18106 .5213 L p 0 1 0 r
F P
0 g
s
.82952 .45892 m .83822 .45072 L .84878 .45614 L p 0 0 1 r
F P
0 g
s
.83822 .45072 m .82952 .45892 L .81893 .45351 L p 0 0 1 r
F P
0 g
s
.21395 .42106 m .22116 .4076 L .23349 .40978 L p 0 1 0 r
F P
0 g
s
.24048 .3984 m .23349 .40978 L .22116 .4076 L p 0 1 0 r
F P
0 g
s
.16993 .57972 m .16124 .60464 L .1465 .61818 L p 0 1 0 r
F P
0 g
s
.1465 .61818 m .15559 .59112 L .16993 .57972 L p 0 1 0 r
F P
0 g
s
.30135 .40416 m .30808 .39784 L .31966 .40596 L p 0 1 0 r
F P
0 g
s
.30808 .39784 m .30135 .40416 L .28971 .39693 L p 0 1 0 r
F P
0 g
s
.87858 .45876 m .88744 .45056 L .8979 .45598 L p 0 0 1 r
F P
0 g
s
.88744 .45056 m .87858 .45876 L .86809 .45335 L p 0 0 1 r
F P
0 g
s
.32408 .4968 m .33123 .48621 L .34311 .48875 L p 1 0 0 r
F P
0 g
s
.35032 .47749 m .34311 .48875 L .33123 .48621 L p 1 0 0 r
F P
0 g
s
.5205 .49989 m .5129 .50892 L .50159 .50427 L p 0 1 0 r
F P
0 g
s
.11292 .45855 m .11916 .45035 L .13135 .45577 L p 0 0 1 r
F P
0 g
s
.59917 .3601 m .59196 .38176 L .58128 .38716 L p 0 1 0 r
F P
0 g
s
.58128 .38716 m .58864 .36675 L .59917 .3601 L p 0 1 0 r
F P
0 g
s
.16834 .45019 m .16193 .45839 L .14982 .45298 L p 0 0 1 r
F P
0 g
s
.54696 .48026 m .55457 .46721 L .56557 .46646 L p 0 1 0 r
F P
0 g
s
.42947 .41386 m .42209 .42509 L .41048 .4226 L p 1 0 0 r
F P
0 g
s
.21095 .45823 m .21753 .45002 L .22949 .45545 L p 0 0 1 r
F P
0 g
s
.35032 .47749 m .35759 .46593 L .36941 .46791 L p 1 0 0 r
F P
0 g
s
.37671 .45608 m .36941 .46791 L .35759 .46593 L p 1 0 0 r
F P
0 g
s
.25997 .45807 m .26672 .44986 L .27858 .45529 L p 0 0 1 r
F P
0 g
s
.26672 .44986 m .25997 .45807 L .24809 .45266 L p 0 0 1 r
F P
0 g
s
.49747 .40368 m .50505 .39673 L .51641 .40453 L p 1 0 0 r
F P
0 g
s
.50505 .39673 m .49747 .40368 L .48612 .39741 L p 1 0 0 r
F P
0 g
s
.309 .45791 m .31592 .4497 L .32767 .45513 L p 0 0 1 r
F P
0 g
s
.31592 .4497 m .309 .45791 L .29723 .4525 L p 0 0 1 r
F P
0 g
s
.36513 .44954 m .35804 .45775 L .34638 .45234 L p 0 0 1 r
F P
0 g
s
.40709 .45759 m .41434 .44938 L .42587 .4548 L p 0 0 1 r
F P
0 g
s
.45614 .45743 m .46356 .44921 L .47498 .45464 L p 0 0 1 r
F P
0 g
s
.46356 .44921 m .45614 .45743 L .44469 .45201 L p 0 0 1 r
F P
0 g
s
.50519 .45727 m .51279 .44905 L .52409 .45448 L p 0 0 1 r
F P
0 g
s
.51279 .44905 m .50519 .45727 L .49386 .45185 L p 0 0 1 r
F P
0 g
s
.44114 .48952 m .44847 .48444 L .45991 .49207 L p 0 1 0 r
F P
0 g
s
.44847 .48444 m .44114 .48952 L .42973 .4812 L p 0 1 0 r
F P
0 g
s
.65669 .62069 m .6678 .64298 L .66785 .64366 L p 1 0 0 r
F P
0 g
s
.66654 .63733 m .6678 .64298 L .65669 .62069 L p 1 0 0 r
F P
0 g
s
.65669 .62069 m .66598 .63096 L .66654 .63733 L p 1 0 0 r
F P
0 g
s
.60728 .25183 m .60876 .2557 L .6033 .26149 L p 0 1 0 r
F P
0 g
s
.66314 .61675 m .65368 .60644 L .64149 .58392 L p 1 0 0 r
F P
0 g
s
.64149 .58392 m .65066 .59227 L .66314 .61675 L p 1 0 0 r
F P
0 g
s
.60333 .45694 m .61126 .44873 L .62234 .45416 L p 0 0 1 r
F P
0 g
s
.61126 .44873 m .60333 .45694 L .59222 .45153 L p 0 0 1 r
F P
0 g
s
.65241 .45678 m .66051 .44856 L .67148 .454 L p 0 0 1 r
F P
0 g
s
.66051 .44856 m .65241 .45678 L .6414 .45136 L p 0 0 1 r
F P
0 g
s
.70149 .45662 m .70976 .4484 L .72062 .45383 L p 0 0 1 r
F P
0 g
s
.70976 .4484 m .70149 .45662 L .6906 .4512 L p 0 0 1 r
F P
0 g
s
.48271 .50581 m .49023 .49888 L .50159 .50427 L p 0 1 0 r
F P
0 g
s
.49023 .49888 m .48271 .50581 L .47132 .49921 L p 0 1 0 r
F P
0 g
s
.25619 .50199 m .26275 .4958 L .27456 .50196 L p 1 0 0 r
F P
0 g
s
.26275 .4958 m .25619 .50199 L .24454 .49423 L p 1 0 0 r
F P
0 g
s
.75058 .45646 m .75902 .44824 L .76977 .45367 L p 0 0 1 r
F P
0 g
s
.75902 .44824 m .75058 .45646 L .7398 .45104 L p 0 0 1 r
F P
0 g
s
.79968 .4563 m .80828 .44808 L .81893 .45351 L p 0 0 1 r
F P
0 g
s
.80828 .44808 m .79968 .4563 L .78901 .45088 L p 0 0 1 r
F P
0 g
s
.28638 .50742 m .29326 .49897 L .30515 .5032 L p 1 0 0 r
F P
0 g
s
.29326 .49897 m .28638 .50742 L .27456 .50196 L p 1 0 0 r
F P
0 g
s
.84878 .45614 m .85756 .44792 L .86809 .45335 L p 0 0 1 r
F P
0 g
s
.85756 .44792 m .84878 .45614 L .83822 .45072 L p 0 0 1 r
F P
0 g
s
.8979 .45598 m .90684 .44775 L .91726 .45319 L p 0 0 1 r
F P
0 g
s
.90684 .44775 m .8979 .45598 L .88744 .45056 L p 0 0 1 r
F P
0 g
s
.30515 .5032 m .31218 .49354 L .32408 .4968 L p 1 0 0 r
F P
0 g
s
.33123 .48621 m .32408 .4968 L .31218 .49354 L p 1 0 0 r
F P
0 g
s
.62017 .52197 m .61145 .51727 L .59975 .50042 L p 1 0 0 r
F P
0 g
s
.59975 .50042 m .60826 .50356 L .62017 .52197 L p 1 0 0 r
F P
0 g
s
.13135 .45577 m .13766 .44755 L .14982 .45298 L p 0 0 1 r
F P
0 g
s
.13766 .44755 m .13135 .45577 L .11916 .45035 L p 0 0 1 r
F P
0 g
s
.44839 .40644 m .45581 .39633 L .46725 .4008 L p 1 0 0 r
F P
0 g
s
.46725 .4008 m .47473 .39176 L .48612 .39741 L p 1 0 0 r
F P
0 g
s
.47473 .39176 m .46725 .4008 L .45581 .39633 L p 1 0 0 r
F P
0 g
s
.22949 .45545 m .23615 .44722 L .24809 .45266 L p 0 0 1 r
F P
0 g
s
.23615 .44722 m .22949 .45545 L .21753 .45002 L p 0 0 1 r
F P
0 g
s
.42947 .41386 m .43687 .40291 L .44839 .40644 L p 1 0 0 r
F P
0 g
s
.45581 .39633 m .44839 .40644 L .43687 .40291 L p 1 0 0 r
F P
0 g
s
.27858 .45529 m .2854 .44706 L .29723 .4525 L p 0 0 1 r
F P
0 g
s
.2854 .44706 m .27858 .45529 L .26672 .44986 L p 0 0 1 r
F P
0 g
s
.28971 .39693 m .29644 .39007 L .30808 .39784 L p 0 1 0 r
F P
0 g
s
.29644 .39007 m .28971 .39693 L .27799 .39017 L p 0 1 0 r
F P
0 g
s
.32767 .45513 m .33466 .4469 L .34638 .45234 L p 0 0 1 r
F P
0 g
s
.33466 .4469 m .32767 .45513 L .31592 .4497 L p 0 0 1 r
F P
0 g
s
.31218 .49354 m .30515 .5032 L .29326 .49897 L p 1 0 0 r
F P
0 g
s
.42973 .4812 m .437 .4764 L .44847 .48444 L p 0 1 0 r
F P
0 g
s
.437 .4764 m .42973 .4812 L .41831 .47259 L p 0 1 0 r
F P
0 g
s
.60298 .32091 m .59588 .34469 L .58528 .3514 L p 0 1 0 r
F P
0 g
s
.58528 .3514 m .59255 .32892 L .60298 .32091 L p 0 1 0 r
F P
0 g
s
.42587 .4548 m .43319 .44657 L .44469 .45201 L p 0 0 1 r
F P
0 g
s
.43319 .44657 m .42587 .4548 L .41434 .44938 L p 0 0 1 r
F P
0 g
s
.60664 .27865 m .59968 .30468 L .58917 .31277 L p 0 1 0 r
F P
0 g
s
.58917 .31277 m .59632 .28805 L .60664 .27865 L p 0 1 0 r
F P
0 g
s
.47498 .45464 m .48247 .44641 L .49386 .45185 L p 0 0 1 r
F P
0 g
s
.48247 .44641 m .47498 .45464 L .46356 .44921 L p 0 0 1 r
F P
0 g
s
.52409 .45448 m .53176 .44625 L .54303 .45169 L p 0 0 1 r
F P
0 g
s
.53176 .44625 m .52409 .45448 L .51279 .44905 L p 0 0 1 r
F P
0 g
s
.64762 .57819 m .63843 .56994 L .62643 .54956 L p 1 0 0 r
F P
0 g
s
.62643 .54956 m .63535 .55601 L .64762 .57819 L p 1 0 0 r
F P
0 g
s
.24048 .3984 m .2474 .38793 L .25938 .39277 L p 0 1 0 r
F P
0 g
s
.25938 .39277 m .26618 .38394 L .27799 .39017 L p 0 1 0 r
F P
0 g
s
.26618 .38394 m .25938 .39277 L .2474 .38793 L p 0 1 0 r
F P
0 g
s
.62234 .45416 m .63035 .44592 L .6414 .45136 L p 0 0 1 r
F P
0 g
s
.63035 .44592 m .62234 .45416 L .61126 .44873 L p 0 0 1 r
F P
0 g
s
.67148 .454 m .67965 .44576 L .6906 .4512 L p 0 0 1 r
F P
0 g
s
.67965 .44576 m .67148 .454 L .66051 .44856 L p 0 0 1 r
F P
0 g
s
.22116 .4076 m .22826 .39521 L .24048 .3984 L p 0 1 0 r
F P
0 g
s
.2474 .38793 m .24048 .3984 L .22826 .39521 L p 0 1 0 r
F P
0 g
s
.5205 .49989 m .52813 .48993 L .53934 .49214 L p 0 1 0 r
F P
0 g
s
.54696 .48026 m .53934 .49214 L .52813 .48993 L p 0 1 0 r
F P
0 g
s
.72062 .45383 m .72896 .4456 L .7398 .45104 L p 0 0 1 r
F P
0 g
s
.72896 .4456 m .72062 .45383 L .70976 .4484 L p 0 0 1 r
F P
0 g
s
.35759 .46593 m .36488 .45415 L .37671 .45608 L p 1 0 0 r
F P
0 g
s
.33123 .48621 m .33843 .47518 L .35032 .47749 L p 1 0 0 r
F P
0 g
s
.35759 .46593 m .35032 .47749 L .33843 .47518 L p 1 0 0 r
F P
0 g
s
.76977 .45367 m .77828 .44543 L .78901 .45088 L p 0 0 1 r
F P
0 g
s
.77828 .44543 m .76977 .45367 L .75902 .44824 L p 0 0 1 r
F P
0 g
s
.24454 .49423 m .25097 .48887 L .26275 .4958 L p 1 0 0 r
F P
0 g
s
.25097 .48887 m .24454 .49423 L .23296 .4856 L p 1 0 0 r
F P
0 g
s
.6033 .26149 m .60641 .24848 L .60728 .25183 L p 0 1 0 r
F P
0 g
s
.81893 .45351 m .82761 .44527 L .83822 .45072 L p 0 0 1 r
F P
0 g
s
.82761 .44527 m .81893 .45351 L .80828 .44808 L p 0 0 1 r
F P
0 g
s
.86809 .45335 m .87694 .44511 L .88744 .45056 L p 0 0 1 r
F P
0 g
s
.87694 .44511 m .86809 .45335 L .85756 .44792 L p 0 0 1 r
F P
0 g
s
.48612 .39741 m .49366 .38968 L .50505 .39673 L p 1 0 0 r
F P
0 g
s
.49366 .38968 m .48612 .39741 L .47473 .39176 L p 1 0 0 r
F P
0 g
s
.17284 .54282 m .16435 .56605 L .14989 .57732 L p 0 1 0 r
F P
0 g
s
.14989 .57732 m .15873 .55211 L .17284 .54282 L p 0 1 0 r
F P
0 g
s
.33798 .40928 m .33119 .41439 L .31966 .40596 L p 0 1 0 r
F P
0 g
s
.92628 .44495 m .91726 .45319 L .90684 .44775 L p 0 0 1 r
F P
0 g
s
.41048 .4226 m .41786 .41104 L .42947 .41386 L p 1 0 0 r
F P
0 g
s
.43687 .40291 m .42947 .41386 L .41786 .41104 L p 1 0 0 r
F P
0 g
s
.19147 .4686 m .18363 .48712 L .17004 .49272 L p 0 1 0 r
F P
0 g
s
.17004 .49272 m .17814 .47262 L .19147 .4686 L p 0 1 0 r
F P
0 g
s
.14982 .45298 m .15621 .44474 L .16834 .45019 L p 0 0 1 r
F P
0 g
s
.15621 .44474 m .14982 .45298 L .13766 .44755 L p 0 0 1 r
F P
0 g
s
.41831 .47259 m .42553 .46801 L .437 .4764 L p 0 1 0 r
F P
0 g
s
.42553 .46801 m .41831 .47259 L .40688 .46375 L p 0 1 0 r
F P
0 g
s
.24809 .45266 m .25481 .44441 L .26672 .44986 L p 0 0 1 r
F P
0 g
s
.25481 .44441 m .24809 .45266 L .23615 .44722 L p 0 0 1 r
F P
0 g
s
.50159 .50427 m .50918 .49597 L .5205 .49989 L p 0 1 0 r
F P
0 g
s
.50918 .49597 m .50159 .50427 L .49023 .49888 L p 0 1 0 r
F P
0 g
s
.15794 .64458 m .15663 .64865 L .15628 .64775 L p 0 1 0 r
F P
0 g
s
.15628 .64775 m .15579 .64686 L .15794 .64458 L p 0 1 0 r
F P
0 g
s
.15794 .64458 m .15579 .64686 L .15363 .64143 L p 0 1 0 r
F P
0 g
s
.29723 .4525 m .30412 .44425 L .31592 .4497 L p 0 0 1 r
F P
0 g
s
.30412 .44425 m .29723 .4525 L .2854 .44706 L p 0 0 1 r
F P
0 g
s
.47132 .49921 m .47881 .49283 L .49023 .49888 L p 0 1 0 r
F P
0 g
s
.47881 .49283 m .47132 .49921 L .45991 .49207 L p 0 1 0 r
F P
0 g
s
.34638 .45234 m .35344 .44409 L .36513 .44954 L p 0 0 1 r
F P
0 g
s
.35344 .44409 m .34638 .45234 L .33466 .4469 L p 0 0 1 r
F P
0 g
s
.44469 .45201 m .45209 .44376 L .46356 .44921 L p 0 0 1 r
F P
0 g
s
.45209 .44376 m .44469 .45201 L .43319 .44657 L p 0 0 1 r
F P
0 g
s
.49386 .45185 m .50143 .4436 L .51279 .44905 L p 0 0 1 r
F P
0 g
s
.50143 .4436 m .49386 .45185 L .48247 .44641 L p 0 0 1 r
F P
0 g
s
.55077 .44343 m .54303 .45169 L .53176 .44625 L p 0 0 1 r
F P
0 g
s
.23296 .4856 m .23924 .48113 L .25097 .48887 L p 1 0 0 r
F P
0 g
s
.23924 .48113 m .23296 .4856 L .22146 .47605 L p 1 0 0 r
F P
0 g
s
.216 .46301 m .21007 .46554 L .1988 .45402 L p 1 0 0 r
F P
0 g
s
.1988 .45402 m .20452 .45255 L .216 .46301 L p 1 0 0 r
F P
0 g
s
.59222 .45153 m .60012 .44327 L .61126 .44873 L p 0 0 1 r
F P
0 g
s
.60012 .44327 m .59222 .45153 L .58105 .44608 L p 0 0 1 r
F P
0 g
s
.52813 .48993 m .5205 .49989 L .50918 .49597 L p 0 1 0 r
F P
0 g
s
.6414 .45136 m .64948 .44311 L .66051 .44856 L p 0 0 1 r
F P
0 g
s
.64948 .44311 m .6414 .45136 L .63035 .44592 L p 0 0 1 r
F P
0 g
s
.6906 .4512 m .69884 .44295 L .70976 .4484 L p 0 0 1 r
F P
0 g
s
.69884 .44295 m .6906 .4512 L .67965 .44576 L p 0 0 1 r
F P
0 g
s
.52411 .39927 m .51641 .40453 L .50505 .39673 L p 1 0 0 r
F P
0 g
s
.40688 .46375 m .41403 .45932 L .42553 .46801 L p 0 1 0 r
F P
0 g
s
.41403 .45932 m .40688 .46375 L .39543 .45474 L p 0 1 0 r
F P
0 g
s
.27799 .39017 m .28473 .38272 L .29644 .39007 L p 0 1 0 r
F P
0 g
s
.28473 .38272 m .27799 .39017 L .26618 .38394 L p 0 1 0 r
F P
0 g
s
.7398 .45104 m .74822 .44278 L .75902 .44824 L p 0 0 1 r
F P
0 g
s
.74822 .44278 m .7398 .45104 L .72896 .4456 L p 0 0 1 r
F P
0 g
s
.59324 .47306 m .58487 .47143 L .57334 .45746 L p 1 0 0 r
F P
0 g
s
.57334 .45746 m .58155 .45774 L .59324 .47306 L p 1 0 0 r
F P
0 g
s
.31966 .40596 m .32642 .40051 L .33798 .40928 L p 0 1 0 r
F P
0 g
s
.32642 .40051 m .31966 .40596 L .30808 .39784 L p 0 1 0 r
F P
0 g
s
.27456 .50196 m .28135 .49415 L .29326 .49897 L p 1 0 0 r
F P
0 g
s
.28135 .49415 m .27456 .50196 L .26275 .4958 L p 1 0 0 r
F P
0 g
s
.78901 .45088 m .79759 .44262 L .80828 .44808 L p 0 0 1 r
F P
0 g
s
.79759 .44262 m .78901 .45088 L .77828 .44543 L p 0 0 1 r
F P
0 g
s
.83822 .45072 m .84698 .44246 L .85756 .44792 L p 0 0 1 r
F P
0 g
s
.84698 .44246 m .83822 .45072 L .82761 .44527 L p 0 0 1 r
F P
0 g
s
.22146 .47605 m .22758 .47253 L .23924 .48113 L p 1 0 0 r
F P
0 g
s
.22758 .47253 m .22146 .47605 L .21007 .46554 L p 1 0 0 r
F P
0 g
s
.88744 .45056 m .89637 .44229 L .90684 .44775 L p 0 0 1 r
F P
0 g
s
.89637 .44229 m .88744 .45056 L .87694 .44511 L p 0 0 1 r
F P
0 g
s
.21007 .46554 m .216 .46301 L .22758 .47253 L p 1 0 0 r
F P
0 g
s
.60489 .24455 m .60641 .24848 L p .59293 .27099 L 0 1 0 r
F P
0 g
s
.60641 .24848 m .6033 .26149 L .59293 .27099 L p 0 1 0 r
F P
0 g
s
.18363 .48712 m .17557 .50713 L .16169 .51444 L p 0 1 0 r
F P
0 g
s
.16169 .51444 m .17004 .49272 L .18363 .48712 L p 0 1 0 r
F P
0 g
s
.11916 .45035 m .12545 .44209 L .13766 .44755 L p 0 0 1 r
F P
0 g
s
.31218 .49354 m .31929 .48332 L .33123 .48621 L p 1 0 0 r
F P
0 g
s
.33843 .47518 m .33123 .48621 L .31929 .48332 L p 1 0 0 r
F P
0 g
s
.1748 .44192 m .16834 .45019 L .15621 .44474 L p 0 0 1 r
F P
0 g
s
.21753 .45002 m .22416 .44176 L .23615 .44722 L p 0 0 1 r
F P
0 g
s
.22416 .44176 m .21753 .45002 L .20551 .44457 L p 0 0 1 r
F P
0 g
s
.16124 .60464 m .15224 .63153 L p .1476 .62876 L 0 1 0 r
F P
0 g
s
.1476 .62876 m .14474 .62363 L p .16124 .60464 L 0 1 0 r
F P
0 g
s
.14474 .62363 m .1465 .61818 L .16124 .60464 L p 0 1 0 r
F P
0 g
s
.22826 .39521 m .22116 .4076 L .20861 .40636 L p 0 1 0 r
F P
0 g
s
.26672 .44986 m .27352 .4416 L .2854 .44706 L p 0 0 1 r
F P
0 g
s
.27352 .4416 m .26672 .44986 L .25481 .44441 L p 0 0 1 r
F P
0 g
s
.31592 .4497 m .32289 .44143 L .33466 .4469 L p 0 0 1 r
F P
0 g
s
.32289 .44143 m .31592 .4497 L .30412 .44425 L p 0 0 1 r
F P
0 g
s
.52813 .48993 m .53577 .47897 L .54696 .48026 L p 0 1 0 r
F P
0 g
s
.55457 .46721 m .54696 .48026 L .53577 .47897 L p 0 1 0 r
F P
0 g
s
.39543 .45474 m .40253 .45041 L .41403 .45932 L p 0 1 0 r
F P
0 g
s
.41434 .44938 m .42165 .44111 L .43319 .44657 L p 0 0 1 r
F P
0 g
s
.42165 .44111 m .41434 .44938 L .40276 .44392 L p 0 0 1 r
F P
0 g
s
.63226 .54212 m .62331 .53575 L .61145 .51727 L p 1 0 0 r
F P
0 g
s
.61145 .51727 m .62017 .52197 L .63226 .54212 L p 1 0 0 r
F P
0 g
s
.46356 .44921 m .47104 .44094 L .48247 .44641 L p 0 0 1 r
F P
0 g
s
.47104 .44094 m .46356 .44921 L .45209 .44376 L p 0 0 1 r
F P
0 g
s
.33843 .47518 m .34568 .46379 L .35759 .46593 L p 1 0 0 r
F P
0 g
s
.36488 .45415 m .35759 .46593 L .34568 .46379 L p 1 0 0 r
F P
0 g
s
.51279 .44905 m .52043 .44078 L .53176 .44625 L p 0 0 1 r
F P
0 g
s
.52043 .44078 m .51279 .44905 L .50143 .4436 L p 0 0 1 r
F P
0 g
s
.43687 .40291 m .4443 .3923 L .45581 .39633 L p 1 0 0 r
F P
0 g
s
.45581 .39633 m .46327 .38668 L .47473 .39176 L p 1 0 0 r
F P
0 g
s
.46327 .38668 m .45581 .39633 L .4443 .3923 L p 1 0 0 r
F P
0 g
s
.45991 .49207 m .46736 .48617 L .47881 .49283 L p 0 1 0 r
F P
0 g
s
.46736 .48617 m .45991 .49207 L .44847 .48444 L p 0 1 0 r
F P
0 g
s
.61126 .44873 m .61924 .44045 L .63035 .44592 L p 0 0 1 r
F P
0 g
s
.61924 .44045 m .61126 .44873 L .60012 .44327 L p 0 0 1 r
F P
0 g
s
.66051 .44856 m .66866 .44029 L .67965 .44576 L p 0 0 1 r
F P
0 g
s
.66866 .44029 m .66051 .44856 L .64948 .44311 L p 0 0 1 r
F P
0 g
s
.70976 .4484 m .71808 .44013 L .72896 .4456 L p 0 0 1 r
F P
0 g
s
.71808 .44013 m .70976 .4484 L .69884 .44295 L p 0 0 1 r
F P
0 g
s
.29326 .49897 m .30023 .48982 L .31218 .49354 L p 1 0 0 r
F P
0 g
s
.30023 .48982 m .29326 .49897 L .28135 .49415 L p 1 0 0 r
F P
0 g
s
.31929 .48332 m .31218 .49354 L .30023 .48982 L p 1 0 0 r
F P
0 g
s
.30808 .39784 m .31482 .39198 L .32642 .40051 L p 0 1 0 r
F P
0 g
s
.31482 .39198 m .30808 .39784 L .29644 .39007 L p 0 1 0 r
F P
0 g
s
.75902 .44824 m .76751 .43996 L .77828 .44543 L p 0 0 1 r
F P
0 g
s
.76751 .43996 m .75902 .44824 L .74822 .44278 L p 0 0 1 r
F P
0 g
s
.50505 .39673 m .5127 .39057 L .52411 .39927 L p 1 0 0 r
F P
0 g
s
.5127 .39057 m .50505 .39673 L .49366 .38968 L p 1 0 0 r
F P
0 g
s
.80828 .44808 m .81695 .4398 L .82761 .44527 L p 0 0 1 r
F P
0 g
s
.81695 .4398 m .80828 .44808 L .79759 .44262 L p 0 0 1 r
F P
0 g
s
.47473 .39176 m .48224 .38332 L .49366 .38968 L p 1 0 0 r
F P
0 g
s
.48224 .38332 m .47473 .39176 L .46327 .38668 L p 1 0 0 r
F P
0 g
s
.22826 .39521 m .23527 .3838 L .2474 .38793 L p 0 1 0 r
F P
0 g
s
.2474 .38793 m .25425 .37831 L .26618 .38394 L p 0 1 0 r
F P
0 g
s
.25425 .37831 m .2474 .38793 L .23527 .3838 L p 0 1 0 r
F P
0 g
s
.85756 .44792 m .86639 .43964 L .87694 .44511 L p 0 0 1 r
F P
0 g
s
.86639 .43964 m .85756 .44792 L .84698 .44246 L p 0 0 1 r
F P
0 g
s
.90684 .44775 m .91584 .43947 L .92628 .44495 L p 0 0 1 r
F P
0 g
s
.91584 .43947 m .90684 .44775 L .89637 .44229 L p 0 0 1 r
F P
0 g
s
.41786 .41104 m .42527 .39972 L .43687 .40291 L p 1 0 0 r
F P
0 g
s
.4443 .3923 m .43687 .40291 L .42527 .39972 L p 1 0 0 r
F P
0 g
s
.13766 .44755 m .14402 .43926 L .15621 .44474 L p 0 0 1 r
F P
0 g
s
.14402 .43926 m .13766 .44755 L .12545 .44209 L p 0 0 1 r
F P
0 g
s
.60505 .48984 m .59651 .48675 L .58487 .47143 L p 1 0 0 r
F P
0 g
s
.58487 .47143 m .59324 .47306 L .60505 .48984 L p 1 0 0 r
F P
0 g
s
.23615 .44722 m .24285 .43894 L .25481 .44441 L p 0 0 1 r
F P
0 g
s
.24285 .43894 m .23615 .44722 L .22416 .44176 L p 0 0 1 r
F P
0 g
s
.49023 .49888 m .4978 .49126 L .50918 .49597 L p 0 1 0 r
F P
0 g
s
.4978 .49126 m .49023 .49888 L .47881 .49283 L p 0 1 0 r
F P
0 g
s
.2854 .44706 m .29227 .43877 L .30412 .44425 L p 0 0 1 r
F P
0 g
s
.29227 .43877 m .2854 .44706 L .27352 .4416 L p 0 0 1 r
F P
0 g
s
.33466 .4469 m .3417 .43861 L .35344 .44409 L p 0 0 1 r
F P
0 g
s
.3417 .43861 m .33466 .4469 L .32289 .44143 L p 0 0 1 r
F P
0 g
s
.59993 .24388 m .60369 .23987 L .60489 .24455 L p 0 1 0 r
F P
0 g
s
.59293 .27099 m .59993 .24388 L p .60489 .24455 L 0 1 0 r
F P
0 g
s
.43319 .44657 m .44057 .43828 L .45209 .44376 L p 0 0 1 r
F P
0 g
s
.44057 .43828 m .43319 .44657 L .42165 .44111 L p 0 0 1 r
F P
0 g
s
.53577 .47897 m .54343 .46691 L .55457 .46721 L p 0 1 0 r
F P
0 g
s
.56216 .45293 m .55457 .46721 L .54343 .46691 L p 0 1 0 r
F P
0 g
s
.48247 .44641 m .49002 .43812 L .50143 .4436 L p 0 0 1 r
F P
0 g
s
.49002 .43812 m .48247 .44641 L .47104 .44094 L p 0 0 1 r
F P
0 g
s
.26618 .38394 m .27295 .37583 L .28473 .38272 L p 0 1 0 r
F P
0 g
s
.27295 .37583 m .26618 .38394 L .25425 .37831 L p 0 1 0 r
F P
0 g
s
.26275 .4958 m .26945 .48869 L .28135 .49415 L p 1 0 0 r
F P
0 g
s
.26945 .48869 m .26275 .4958 L .25097 .48887 L p 1 0 0 r
F P
0 g
s
.53176 .44625 m .53948 .43796 L .55077 .44343 L p 0 0 1 r
F P
0 g
s
.53948 .43796 m .53176 .44625 L .52043 .44078 L p 0 0 1 r
F P
0 g
s
.17557 .50713 m .16729 .52876 L .15307 .5379 L p 0 1 0 r
F P
0 g
s
.15307 .5379 m .16169 .51444 L .17557 .50713 L p 0 1 0 r
F P
0 g
s
.59588 .34469 m .58864 .36675 L .57788 .3722 L p 0 1 0 r
F P
0 g
s
.57788 .3722 m .58528 .3514 L .59588 .34469 L p 0 1 0 r
F P
0 g
s
.58105 .44608 m .58894 .43779 L .60012 .44327 L p 0 0 1 r
F P
0 g
s
.20861 .40636 m .21585 .39287 L .22826 .39521 L p 0 1 0 r
F P
0 g
s
.23527 .3838 m .22826 .39521 L .21585 .39287 L p 0 1 0 r
F P
0 g
s
.16435 .56605 m .15559 .59112 L .14072 .60454 L p 0 1 0 r
F P
0 g
s
.14072 .60454 m .14989 .57732 L .16435 .56605 L p 0 1 0 r
F P
0 g
s
.63035 .44592 m .63841 .43763 L .64948 .44311 L p 0 0 1 r
F P
0 g
s
.63841 .43763 m .63035 .44592 L .61924 .44045 L p 0 0 1 r
F P
0 g
s
.44847 .48444 m .45587 .47896 L .46736 .48617 L p 0 1 0 r
F P
0 g
s
.45587 .47896 m .44847 .48444 L .437 .4764 L p 0 1 0 r
F P
0 g
s
.67965 .44576 m .68788 .43746 L .69884 .44295 L p 0 0 1 r
F P
0 g
s
.68788 .43746 m .67965 .44576 L .66866 .44029 L p 0 0 1 r
F P
0 g
s
.72896 .4456 m .73736 .4373 L .74822 .44278 L p 0 0 1 r
F P
0 g
s
.73736 .4373 m .72896 .4456 L .71808 .44013 L p 0 0 1 r
F P
0 g
s
.77828 .44543 m .78685 .43714 L .79759 .44262 L p 0 0 1 r
F P
0 g
s
.78685 .43714 m .77828 .44543 L .76751 .43996 L p 0 0 1 r
F P
0 g
s
.82761 .44527 m .83635 .43697 L .84698 .44246 L p 0 0 1 r
F P
0 g
s
.83635 .43697 m .82761 .44527 L .81695 .4398 L p 0 0 1 r
F P
0 g
s
.29644 .39007 m .30317 .38374 L .31482 .39198 L p 0 1 0 r
F P
0 g
s
.30317 .38374 m .29644 .39007 L .28473 .38272 L p 0 1 0 r
F P
0 g
s
.50918 .49597 m .51682 .48682 L .52813 .48993 L p 0 1 0 r
F P
0 g
s
.53577 .47897 m .52813 .48993 L .51682 .48682 L p 0 1 0 r
F P
0 g
s
.31929 .48332 m .32646 .47259 L .33843 .47518 L p 1 0 0 r
F P
0 g
s
.34568 .46379 m .33843 .47518 L .32646 .47259 L p 1 0 0 r
F P
0 g
s
.87694 .44511 m .88585 .43681 L .89637 .44229 L p 0 0 1 r
F P
0 g
s
.88585 .43681 m .87694 .44511 L .86639 .43964 L p 0 0 1 r
F P
0 g
s
.65368 .60644 m .66595 .63076 L .66596 .63086 L p 1 0 0 r
F P
0 g
s
.66449 .62447 m .66595 .63076 L .65368 .60644 L p 1 0 0 r
F P
0 g
s
.65368 .60644 m .66314 .61675 L p .66449 .62447 L 1 0 0 r
F P
0 g
s
.93536 .43665 m .92628 .44495 L .91584 .43947 L p 0 0 1 r
F P
0 g
s
.42527 .39972 m .41786 .41104 L .40617 .40847 L p 1 0 0 r
F P
0 g
s
.16264 .43644 m .15621 .44474 L .14402 .43926 L p 0 0 1 r
F P
0 g
s
.34568 .46379 m .35297 .45211 L .36488 .45415 L p 1 0 0 r
F P
0 g
s
.37222 .4422 m .36488 .45415 L .35297 .45211 L p 1 0 0 r
F P
0 g
s
.54343 .46691 m .55107 .45367 L .56216 .45293 L p 0 1 0 r
F P
0 g
s
.20551 .44457 m .21211 .43627 L .22416 .44176 L p 0 0 1 r
F P
0 g
s
.51682 .48682 m .50918 .49597 L .4978 .49126 L p 0 1 0 r
F P
0 g
s
.25481 .44441 m .26158 .43611 L .27352 .4416 L p 0 0 1 r
F P
0 g
s
.26158 .43611 m .25481 .44441 L .24285 .43894 L p 0 0 1 r
F P
0 g
s
.66014 .60248 m .65066 .59227 L .63843 .56994 L p 1 0 0 r
F P
0 g
s
.63843 .56994 m .64762 .57819 L .66014 .60248 L p 1 0 0 r
F P
0 g
s
.49366 .38968 m .50127 .38268 L .5127 .39057 L p 1 0 0 r
F P
0 g
s
.50127 .38268 m .49366 .38968 L .48224 .38332 L p 1 0 0 r
F P
0 g
s
.30412 .44425 m .31106 .43594 L .32289 .44143 L p 0 0 1 r
F P
0 g
s
.31106 .43594 m .30412 .44425 L .29227 .43877 L p 0 0 1 r
F P
0 g
s
.36055 .43578 m .35344 .44409 L .3417 .43861 L p 0 0 1 r
F P
0 g
s
.40276 .44392 m .41004 .43562 L .42165 .44111 L p 0 0 1 r
F P
0 g
s
.6033 .26149 m .59632 .28805 L .58575 .29622 L p 0 1 0 r
F P
0 g
s
.58575 .29622 m .59293 .27099 L .6033 .26149 L p 0 1 0 r
F P
0 g
s
.45209 .44376 m .45955 .43545 L .47104 .44094 L p 0 0 1 r
F P
0 g
s
.45955 .43545 m .45209 .44376 L .44057 .43828 L p 0 0 1 r
F P
0 g
s
.50143 .4436 m .50905 .43529 L .52043 .44078 L p 0 0 1 r
F P
0 g
s
.50905 .43529 m .50143 .4436 L .49002 .43812 L p 0 0 1 r
F P
0 g
s
.60012 .44327 m .60809 .43496 L .61924 .44045 L p 0 0 1 r
F P
0 g
s
.60809 .43496 m .60012 .44327 L .58894 .43779 L p 0 0 1 r
F P
0 g
s
.59968 .30468 m .59255 .32892 L .58187 .3357 L p 0 1 0 r
F P
0 g
s
.58187 .3357 m .58917 .31277 L .59968 .30468 L p 0 1 0 r
F P
0 g
s
.437 .4764 m .44435 .47128 L .45587 .47896 L p 0 1 0 r
F P
0 g
s
.44435 .47128 m .437 .4764 L .42553 .46801 L p 0 1 0 r
F P
0 g
s
.64948 .44311 m .65762 .4348 L .66866 .44029 L p 0 0 1 r
F P
0 g
s
.65762 .4348 m .64948 .44311 L .63841 .43763 L p 0 0 1 r
F P
0 g
s
.69884 .44295 m .70715 .43463 L .71808 .44013 L p 0 0 1 r
F P
0 g
s
.70715 .43463 m .69884 .44295 L .68788 .43746 L p 0 0 1 r
F P
0 g
s
.74822 .44278 m .75669 .43447 L .76751 .43996 L p 0 0 1 r
F P
0 g
s
.75669 .43447 m .74822 .44278 L .73736 .4373 L p 0 0 1 r
F P
0 g
s
.79759 .44262 m .80624 .4343 L .81695 .4398 L p 0 0 1 r
F P
0 g
s
.80624 .4343 m .79759 .44262 L .78685 .43714 L p 0 0 1 r
F P
0 g
s
.60264 .2372 m .60369 .23987 L .59993 .24388 L p 0 1 0 r
F P
0 g
s
.25097 .48887 m .25756 .48252 L .26945 .48869 L p 1 0 0 r
F P
0 g
s
.25756 .48252 m .25097 .48887 L .23924 .48113 L p 1 0 0 r
F P
0 g
s
.84698 .44246 m .85579 .43414 L .86639 .43964 L p 0 0 1 r
F P
0 g
s
.85579 .43414 m .84698 .44246 L .83635 .43697 L p 0 0 1 r
F P
0 g
s
.47881 .49283 m .48636 .48582 L .4978 .49126 L p 0 1 0 r
F P
0 g
s
.48636 .48582 m .47881 .49283 L .46736 .48617 L p 0 1 0 r
F P
0 g
s
.61701 .5082 m .60826 .50356 L .59651 .48675 L p 1 0 0 r
F P
0 g
s
.59651 .48675 m .60505 .48984 L .61701 .5082 L p 1 0 0 r
F P
0 g
s
.28135 .49415 m .28826 .48557 L .30023 .48982 L p 1 0 0 r
F P
0 g
s
.28826 .48557 m .28135 .49415 L .26945 .48869 L p 1 0 0 r
F P
0 g
s
.30023 .48982 m .3073 .48002 L .31929 .48332 L p 1 0 0 r
F P
0 g
s
.32646 .47259 m .31929 .48332 L .3073 .48002 L p 1 0 0 r
F P
0 g
s
.89637 .44229 m .90535 .43398 L .91584 .43947 L p 0 0 1 r
F P
0 g
s
.90535 .43398 m .89637 .44229 L .88585 .43681 L p 0 0 1 r
F P
0 g
s
.12545 .44209 m .13178 .43377 L .14402 .43926 L p 0 0 1 r
F P
0 g
s
.4443 .3923 m .45175 .38211 L .46327 .38668 L p 1 0 0 r
F P
0 g
s
.46327 .38668 m .47077 .37758 L .48224 .38332 L p 1 0 0 r
F P
0 g
s
.47077 .37758 m .46327 .38668 L .45175 .38211 L p 1 0 0 r
F P
0 g
s
.42527 .39972 m .4327 .38868 L .4443 .3923 L p 1 0 0 r
F P
0 g
s
.45175 .38211 m .4443 .3923 L .4327 .38868 L p 1 0 0 r
F P
0 g
s
.22416 .44176 m .23083 .43344 L .24285 .43894 L p 0 0 1 r
F P
0 g
s
.23083 .43344 m .22416 .44176 L .21211 .43627 L p 0 0 1 r
F P
0 g
s
.28473 .38272 m .29147 .37586 L .30317 .38374 L p 0 1 0 r
F P
0 g
s
.29147 .37586 m .28473 .38272 L .27295 .37583 L p 0 1 0 r
F P
0 g
s
.27352 .4416 m .28036 .43327 L .29227 .43877 L p 0 0 1 r
F P
0 g
s
.28036 .43327 m .27352 .4416 L .26158 .43611 L p 0 0 1 r
F P
0 g
s
.32289 .44143 m .3299 .43311 L .3417 .43861 L p 0 0 1 r
F P
0 g
s
.3299 .43311 m .32289 .44143 L .31106 .43594 L p 0 0 1 r
F P
0 g
s
.64456 .56418 m .63535 .55601 L .62331 .53575 L p 1 0 0 r
F P
0 g
s
.62331 .53575 m .63226 .54212 L .64456 .56418 L p 1 0 0 r
F P
0 g
s
.3073 .48002 m .30023 .48982 L .28826 .48557 L p 1 0 0 r
F P
0 g
s
.42165 .44111 m .429 .43278 L .44057 .43828 L p 0 0 1 r
F P
0 g
s
.429 .43278 m .42165 .44111 L .41004 .43562 L p 0 0 1 r
F P
0 g
s
.47104 .44094 m .47856 .43262 L .49002 .43812 L p 0 0 1 r
F P
0 g
s
.47856 .43262 m .47104 .44094 L .45955 .43545 L p 0 0 1 r
F P
0 g
s
.23527 .3838 m .2422 .37331 L .25425 .37831 L p 0 1 0 r
F P
0 g
s
.25425 .37831 m .26106 .36947 L .27295 .37583 L p 0 1 0 r
F P
0 g
s
.26106 .36947 m .25425 .37831 L .2422 .37331 L p 0 1 0 r
F P
0 g
s
.21585 .39287 m .22297 .38045 L .23527 .3838 L p 0 1 0 r
F P
0 g
s
.2422 .37331 m .23527 .3838 L .22297 .38045 L p 0 1 0 r
F P
0 g
s
.42553 .46801 m .43282 .46317 L .44435 .47128 L p 0 1 0 r
F P
0 g
s
.43282 .46317 m .42553 .46801 L .41403 .45932 L p 0 1 0 r
F P
0 g
s
.52043 .44078 m .52813 .43245 L .53948 .43796 L p 0 0 1 r
F P
0 g
s
.52813 .43245 m .52043 .44078 L .50905 .43529 L p 0 0 1 r
F P
0 g
s
.61924 .44045 m .62728 .43212 L .63841 .43763 L p 0 0 1 r
F P
0 g
s
.62728 .43212 m .61924 .44045 L .60809 .43496 L p 0 0 1 r
F P
0 g
s
.16729 .52876 m .15873 .55211 L .14415 .56324 L p 0 1 0 r
F P
0 g
s
.14415 .56324 m .15307 .5379 L .16729 .52876 L p 0 1 0 r
F P
0 g
s
.18603 .45403 m .17814 .47262 L .16446 .47806 L p 0 1 0 r
F P
0 g
s
.16446 .47806 m .17261 .45789 L .18603 .45403 L p 0 1 0 r
F P
0 g
s
.66866 .44029 m .67687 .43196 L .68788 .43746 L p 0 0 1 r
F P
0 g
s
.67687 .43196 m .66866 .44029 L .65762 .4348 L p 0 0 1 r
F P
0 g
s
.35297 .45211 m .36031 .4402 L .37222 .4422 L p 1 0 0 r
F P
0 g
s
.32646 .47259 m .3337 .46143 L .34568 .46379 L p 1 0 0 r
F P
0 g
s
.35297 .45211 m .34568 .46379 L .3337 .46143 L p 1 0 0 r
F P
0 g
s
.71808 .44013 m .72646 .43179 L .73736 .4373 L p 0 0 1 r
F P
0 g
s
.72646 .43179 m .71808 .44013 L .70715 .43463 L p 0 0 1 r
F P
0 g
s
.59993 .24388 m .60203 .23492 L .60264 .2372 L p 0 1 0 r
F P
0 g
s
.76751 .43996 m .77606 .43163 L .78685 .43714 L p 0 0 1 r
F P
0 g
s
.77606 .43163 m .76751 .43996 L .75669 .43447 L p 0 0 1 r
F P
0 g
s
.51682 .48682 m .52448 .47673 L .53577 .47897 L p 0 1 0 r
F P
0 g
s
.54343 .46691 m .53577 .47897 L .52448 .47673 L p 0 1 0 r
F P
0 g
s
.81695 .4398 m .82567 .43146 L .83635 .43697 L p 0 0 1 r
F P
0 g
s
.82567 .43146 m .81695 .4398 L .80624 .4343 L p 0 0 1 r
F P
0 g
s
.48224 .38332 m .48981 .37554 L .50127 .38268 L p 1 0 0 r
F P
0 g
s
.48981 .37554 m .48224 .38332 L .47077 .37758 L p 1 0 0 r
F P
0 g
s
.40617 .40847 m .41358 .39681 L .42527 .39972 L p 1 0 0 r
F P
0 g
s
.4327 .38868 m .42527 .39972 L .41358 .39681 L p 1 0 0 r
F P
0 g
s
.86639 .43964 m .87528 .4313 L .88585 .43681 L p 0 0 1 r
F P
0 g
s
.87528 .4313 m .86639 .43964 L .85579 .43414 L p 0 0 1 r
F P
0 g
s
.58864 .36675 m .58128 .38716 L .57039 .39137 L p 0 1 0 r
F P
0 g
s
.23924 .48113 m .2457 .47561 L .25756 .48252 L p 1 0 0 r
F P
0 g
s
.2457 .47561 m .23924 .48113 L .22758 .47253 L p 1 0 0 r
F P
0 g
s
.91584 .43947 m .9249 .43114 L .93536 .43665 L p 0 0 1 r
F P
0 g
s
.9249 .43114 m .91584 .43947 L .90535 .43398 L p 0 0 1 r
F P
0 g
s
.14402 .43926 m .15043 .43092 L .16264 .43644 L p 0 0 1 r
F P
0 g
s
.15043 .43092 m .14402 .43926 L .13178 .43377 L p 0 0 1 r
F P
0 g
s
.15224 .63153 m .15074 .63618 L .15033 .63515 L p 0 1 0 r
F P
0 g
s
.15033 .63515 m .14976 .63412 L .15224 .63153 L p 0 1 0 r
F P
0 g
s
.15224 .63153 m .14976 .63412 L .1476 .62876 L p 0 1 0 r
F P
0 g
s
.24285 .43894 m .24959 .4306 L .26158 .43611 L p 0 0 1 r
F P
0 g
s
.24959 .4306 m .24285 .43894 L .23083 .43344 L p 0 0 1 r
F P
0 g
s
.41403 .45932 m .42127 .45471 L .43282 .46317 L p 0 1 0 r
F P
0 g
s
.42127 .45471 m .41403 .45932 L .40253 .45041 L p 0 1 0 r
F P
0 g
s
.29227 .43877 m .29918 .43043 L .31106 .43594 L p 0 0 1 r
F P
0 g
s
.29918 .43043 m .29227 .43877 L .28036 .43327 L p 0 0 1 r
F P
0 g
s
.3417 .43861 m .34878 .43027 L .36055 .43578 L p 0 0 1 r
F P
0 g
s
.34878 .43027 m .3417 .43861 L .3299 .43311 L p 0 0 1 r
F P
0 g
s
.4978 .49126 m .50543 .48286 L .51682 .48682 L p 0 1 0 r
F P
0 g
s
.50543 .48286 m .4978 .49126 L .48636 .48582 L p 0 1 0 r
F P
0 g
s
.46736 .48617 m .47487 .47971 L .48636 .48582 L p 0 1 0 r
F P
0 g
s
.47487 .47971 m .46736 .48617 L .45587 .47896 L p 0 1 0 r
F P
0 g
s
.44057 .43828 m .448 .42994 L .45955 .43545 L p 0 0 1 r
F P
0 g
s
.448 .42994 m .44057 .43828 L .429 .43278 L p 0 0 1 r
F P
0 g
s
.49002 .43812 m .49762 .42977 L .50905 .43529 L p 0 0 1 r
F P
0 g
s
.49762 .42977 m .49002 .43812 L .47856 .43262 L p 0 0 1 r
F P
0 g
s
.54725 .42961 m .53948 .43796 L .52813 .43245 L p 0 0 1 r
F P
0 g
s
.60003 .22987 m .60203 .23492 L p .58948 .25349 L 0 1 0 r
F P
0 g
s
.60203 .23492 m .59993 .24388 L .58948 .25349 L p 0 1 0 r
F P
0 g
s
.58894 .43779 m .59688 .42944 L .60809 .43496 L p 0 0 1 r
F P
0 g
s
.59688 .42944 m .58894 .43779 L .5777 .43229 L p 0 0 1 r
F P
0 g
s
.17814 .47262 m .17004 .49272 L .15605 .49986 L p 0 1 0 r
F P
0 g
s
.15605 .49986 m .16446 .47806 L .17814 .47262 L p 0 1 0 r
F P
0 g
s
.27295 .37583 m .2797 .36837 L .29147 .37586 L p 0 1 0 r
F P
0 g
s
.2797 .36837 m .27295 .37583 L .26106 .36947 L p 0 1 0 r
F P
0 g
s
.63841 .43763 m .64652 .42928 L .65762 .4348 L p 0 0 1 r
F P
0 g
s
.64652 .42928 m .63841 .43763 L .62728 .43212 L p 0 0 1 r
F P
0 g
s
.68788 .43746 m .69617 .42911 L .70715 .43463 L p 0 0 1 r
F P
0 g
s
.69617 .42911 m .68788 .43746 L .67687 .43196 L p 0 0 1 r
F P
0 g
s
.22758 .47253 m .23388 .46789 L .2457 .47561 L p 1 0 0 r
F P
0 g
s
.23388 .46789 m .22758 .47253 L .216 .46301 L p 1 0 0 r
F P
0 g
s
.52043 .38527 m .5127 .39057 L .50127 .38268 L p 1 0 0 r
F P
0 g
s
.73736 .4373 m .74582 .42895 L .75669 .43447 L p 0 0 1 r
F P
0 g
s
.74582 .42895 m .73736 .4373 L .72646 .43179 L p 0 0 1 r
F P
0 g
s
.52448 .47673 m .51682 .48682 L .50543 .48286 L p 0 1 0 r
F P
0 g
s
.58994 .45935 m .58155 .45774 L .56995 .44376 L p 1 0 0 r
F P
0 g
s
.56995 .44376 m .57819 .44402 L .58994 .45935 L p 1 0 0 r
F P
0 g
s
.32159 .38652 m .31482 .39198 L .30317 .38374 L p 0 1 0 r
F P
0 g
s
.78685 .43714 m .79548 .42878 L .80624 .4343 L p 0 0 1 r
F P
0 g
s
.79548 .42878 m .78685 .43714 L .77606 .43163 L p 0 0 1 r
F P
0 g
s
.40253 .45041 m .4097 .44595 L .42127 .45471 L p 0 1 0 r
F P
0 g
s
.4097 .44595 m .40253 .45041 L .39101 .44132 L p 0 1 0 r
F P
0 g
s
.26945 .48869 m .27627 .48073 L .28826 .48557 L p 1 0 0 r
F P
0 g
s
.27627 .48073 m .26945 .48869 L .25756 .48252 L p 1 0 0 r
F P
0 g
s
.83635 .43697 m .84515 .42862 L .85579 .43414 L p 0 0 1 r
F P
0 g
s
.84515 .42862 m .83635 .43697 L .82567 .43146 L p 0 0 1 r
F P
0 g
s
.21047 .44985 m .20452 .45255 L .19317 .4411 L p 1 0 0 r
F P
0 g
s
.19317 .4411 m .19891 .43944 L .21047 .44985 L p 1 0 0 r
F P
0 g
s
.22297 .38045 m .21585 .39287 L .20323 .39145 L p 0 1 0 r
F P
0 g
s
.15559 .59112 m .1465 .61818 L p .14143 .61596 L 0 1 0 r
F P
0 g
s
.14143 .61596 m .13863 .61099 L p .15559 .59112 L 0 1 0 r
F P
0 g
s
.13863 .61099 m .14072 .60454 L .15559 .59112 L p 0 1 0 r
F P
0 g
s
.88585 .43681 m .89482 .42845 L .90535 .43398 L p 0 0 1 r
F P
0 g
s
.89482 .42845 m .88585 .43681 L .87528 .4313 L p 0 0 1 r
F P
0 g
s
.3073 .48002 m .31444 .46966 L .32646 .47259 L p 1 0 0 r
F P
0 g
s
.3337 .46143 m .32646 .47259 L .31444 .46966 L p 1 0 0 r
F P
0 g
s
.9445 .42829 m .93536 .43665 L .9249 .43114 L p 0 0 1 r
F P
0 g
s
.16912 .42808 m .16264 .43644 L .15043 .43092 L p 0 0 1 r
F P
0 g
s
.21211 .43627 m .21875 .42791 L .23083 .43344 L p 0 0 1 r
F P
0 g
s
.21875 .42791 m .21211 .43627 L .20001 .43076 L p 0 0 1 r
F P
0 g
s
.216 .46301 m .22213 .45931 L .23388 .46789 L p 1 0 0 r
F P
0 g
s
.22213 .45931 m .216 .46301 L .20452 .45255 L p 1 0 0 r
F P
0 g
s
.26158 .43611 m .2684 .42775 L .28036 .43327 L p 0 0 1 r
F P
0 g
s
.2684 .42775 m .26158 .43611 L .24959 .4306 L p 0 0 1 r
F P
0 g
s
.20452 .45255 m .21047 .44985 L .22213 .45931 L p 1 0 0 r
F P
0 g
s
.62914 .52829 m .62017 .52197 L .60826 .50356 L p 1 0 0 r
F P
0 g
s
.60826 .50356 m .61701 .5082 L .62914 .52829 L p 1 0 0 r
F P
0 g
s
.31106 .43594 m .31805 .42758 L .3299 .43311 L p 0 0 1 r
F P
0 g
s
.31805 .42758 m .31106 .43594 L .29918 .43043 L p 0 0 1 r
F P
0 g
s
.41004 .43562 m .41738 .42725 L .429 .43278 L p 0 0 1 r
F P
0 g
s
.41738 .42725 m .41004 .43562 L .39839 .4301 L p 0 0 1 r
F P
0 g
s
.52448 .47673 m .53216 .4656 L .54343 .46691 L p 0 1 0 r
F P
0 g
s
.55107 .45367 m .54343 .46691 L .53216 .4656 L p 0 1 0 r
F P
0 g
s
.3337 .46143 m .34098 .44991 L .35297 .45211 L p 1 0 0 r
F P
0 g
s
.36031 .4402 m .35297 .45211 L .34098 .44991 L p 1 0 0 r
F P
0 g
s
.45955 .43545 m .46705 .42709 L .47856 .43262 L p 0 0 1 r
F P
0 g
s
.46705 .42709 m .45955 .43545 L .448 .42994 L p 0 0 1 r
F P
0 g
s
.39101 .44132 m .39813 .43695 L .4097 .44595 L p 0 1 0 r
F P
0 g
s
.4327 .38868 m .44016 .37799 L .45175 .38211 L p 1 0 0 r
F P
0 g
s
.45175 .38211 m .45924 .37241 L .47077 .37758 L p 1 0 0 r
F P
0 g
s
.45924 .37241 m .45175 .38211 L .44016 .37799 L p 1 0 0 r
F P
0 g
s
.50905 .43529 m .51673 .42692 L .52813 .43245 L p 0 0 1 r
F P
0 g
s
.51673 .42692 m .50905 .43529 L .49762 .42977 L p 0 0 1 r
F P
0 g
s
.60809 .43496 m .61611 .42659 L .62728 .43212 L p 0 0 1 r
F P
0 g
s
.61611 .42659 m .60809 .43496 L .59688 .42944 L p 0 0 1 r
F P
0 g
s
.65762 .4348 m .66581 .42643 L .67687 .43196 L p 0 0 1 r
F P
0 g
s
.66581 .42643 m .65762 .4348 L .64652 .42928 L p 0 0 1 r
F P
0 g
s
.22297 .38045 m .23 .36903 L .2422 .37331 L p 0 1 0 r
F P
0 g
s
.2422 .37331 m .24907 .36368 L .26106 .36947 L p 0 1 0 r
F P
0 g
s
.24907 .36368 m .2422 .37331 L .23 .36903 L p 0 1 0 r
F P
0 g
s
.45587 .47896 m .46334 .473 L .47487 .47971 L p 0 1 0 r
F P
0 g
s
.46334 .473 m .45587 .47896 L .44435 .47128 L p 0 1 0 r
F P
0 g
s
.70715 .43463 m .71551 .42626 L .72646 .43179 L p 0 0 1 r
F P
0 g
s
.71551 .42626 m .70715 .43463 L .69617 .42911 L p 0 0 1 r
F P
0 g
s
.28826 .48557 m .29527 .47627 L .3073 .48002 L p 1 0 0 r
F P
0 g
s
.31444 .46966 m .3073 .48002 L .29527 .47627 L p 1 0 0 r
F P
0 g
s
.30317 .38374 m .30993 .37788 L .32159 .38652 L p 0 1 0 r
F P
0 g
s
.30993 .37788 m .30317 .38374 L .29147 .37586 L p 0 1 0 r
F P
0 g
s
.29527 .47627 m .28826 .48557 L .27627 .48073 L p 1 0 0 r
F P
0 g
s
.75669 .43447 m .76522 .4261 L .77606 .43163 L p 0 0 1 r
F P
0 g
s
.76522 .4261 m .75669 .43447 L .74582 .42895 L p 0 0 1 r
F P
0 g
s
.50127 .38268 m .50895 .37649 L .52043 .38527 L p 1 0 0 r
F P
0 g
s
.50895 .37649 m .50127 .38268 L .48981 .37554 L p 1 0 0 r
F P
0 g
s
.47077 .37758 m .47832 .36909 L .48981 .37554 L p 1 0 0 r
F P
0 g
s
.47832 .36909 m .47077 .37758 L .45924 .37241 L p 1 0 0 r
F P
0 g
s
.80624 .4343 m .81494 .42593 L .82567 .43146 L p 0 0 1 r
F P
0 g
s
.81494 .42593 m .80624 .4343 L .79548 .42878 L p 0 0 1 r
F P
0 g
s
.41358 .39681 m .42103 .38539 L .4327 .38868 L p 1 0 0 r
F P
0 g
s
.44016 .37799 m .4327 .38868 L .42103 .38539 L p 1 0 0 r
F P
0 g
s
.85579 .43414 m .86467 .42577 L .87528 .4313 L p 0 0 1 r
F P
0 g
s
.86467 .42577 m .85579 .43414 L .84515 .42862 L p 0 0 1 r
F P
0 g
s
.59255 .32892 m .58528 .3514 L .57444 .35691 L p 0 1 0 r
F P
0 g
s
.57444 .35691 m .58187 .3357 L .59255 .32892 L p 0 1 0 r
F P
0 g
s
.90535 .43398 m .9144 .4256 L .9249 .43114 L p 0 0 1 r
F P
0 g
s
.9144 .4256 m .90535 .43398 L .89482 .42845 L p 0 0 1 r
F P
0 g
s
.13178 .43377 m .13816 .42539 L .15043 .43092 L p 0 0 1 r
F P
0 g
s
.6018 .47613 m .59324 .47306 L .58155 .45774 L p 1 0 0 r
F P
0 g
s
.58155 .45774 m .58994 .45935 L .6018 .47613 L p 1 0 0 r
F P
0 g
s
.23083 .43344 m .23755 .42506 L .24959 .4306 L p 0 0 1 r
F P
0 g
s
.23755 .42506 m .23083 .43344 L .21875 .42791 L p 0 0 1 r
F P
0 g
s
.17004 .49272 m .16169 .51444 L .14737 .52341 L p 0 1 0 r
F P
0 g
s
.14737 .52341 m .15605 .49986 L .17004 .49272 L p 0 1 0 r
F P
0 g
s
.5965 .22581 m .5984 .22377 L .60003 .22987 L p 0 1 0 r
F P
0 g
s
.58948 .25349 m .5965 .22581 L p .60003 .22987 L 0 1 0 r
F P
0 g
s
.28036 .43327 m .28725 .42489 L .29918 .43043 L p 0 0 1 r
F P
0 g
s
.28725 .42489 m .28036 .43327 L .2684 .42775 L p 0 0 1 r
F P
0 g
s
.59993 .24388 m .59293 .27099 L .58228 .27927 L p 0 1 0 r
F P
0 g
s
.58228 .27927 m .58948 .25349 L .59993 .24388 L p 0 1 0 r
F P
0 g
s
.3299 .43311 m .33696 .42473 L .34878 .43027 L p 0 0 1 r
F P
0 g
s
.33696 .42473 m .3299 .43311 L .31805 .42758 L p 0 0 1 r
F P
0 g
s
.15873 .55211 m .14989 .57732 L .1349 .59059 L p 0 1 0 r
F P
0 g
s
.1349 .59059 m .14415 .56324 L .15873 .55211 L p 0 1 0 r
F P
0 g
s
.48636 .48582 m .49397 .4781 L .50543 .48286 L p 0 1 0 r
F P
0 g
s
.49397 .4781 m .48636 .48582 L .47487 .47971 L p 0 1 0 r
F P
0 g
s
.26106 .36947 m .26784 .36135 L .2797 .36837 L p 0 1 0 r
F P
0 g
s
.26784 .36135 m .26106 .36947 L .24907 .36368 L p 0 1 0 r
F P
0 g
s
.20323 .39145 m .21049 .37795 L .22297 .38045 L p 0 1 0 r
F P
0 g
s
.23 .36903 m .22297 .38045 L .21049 .37795 L p 0 1 0 r
F P
0 g
s
.429 .43278 m .43641 .4244 L .448 .42994 L p 0 0 1 r
F P
0 g
s
.43641 .4244 m .429 .43278 L .41738 .42725 L p 0 0 1 r
F P
0 g
s
.47856 .43262 m .48614 .42423 L .49762 .42977 L p 0 0 1 r
F P
0 g
s
.48614 .42423 m .47856 .43262 L .46705 .42709 L p 0 0 1 r
F P
0 g
s
.6623 .61149 m .66376 .61753 L p .65066 .59227 L 1 0 0 r
F P
0 g
s
.66376 .61753 m .66314 .61675 L .65066 .59227 L p 1 0 0 r
F P
0 g
s
.65066 .59227 m .66014 .60248 L p .6623 .61149 L 1 0 0 r
F P
0 g
s
.53216 .4656 m .53985 .45336 L .55107 .45367 L p 0 1 0 r
F P
0 g
s
.5587 .43916 m .55107 .45367 L .53985 .45336 L p 0 1 0 r
F P
0 g
s
.52813 .43245 m .53588 .42407 L .54725 .42961 L p 0 0 1 r
F P
0 g
s
.53588 .42407 m .52813 .43245 L .51673 .42692 L p 0 0 1 r
F P
0 g
s
.25756 .48252 m .26428 .47526 L .27627 .48073 L p 1 0 0 r
F P
0 g
s
.26428 .47526 m .25756 .48252 L .2457 .47561 L p 1 0 0 r
F P
0 g
s
.5777 .43229 m .58562 .4239 L .59688 .42944 L p 0 0 1 r
F P
0 g
s
.62728 .43212 m .63538 .42373 L .64652 .42928 L p 0 0 1 r
F P
0 g
s
.63538 .42373 m .62728 .43212 L .61611 .42659 L p 0 0 1 r
F P
0 g
s
.67687 .43196 m .68514 .42357 L .69617 .42911 L p 0 0 1 r
F P
0 g
s
.68514 .42357 m .67687 .43196 L .66581 .42643 L p 0 0 1 r
F P
0 g
s
.72646 .43179 m .7349 .4234 L .74582 .42895 L p 0 0 1 r
F P
0 g
s
.7349 .4234 m .72646 .43179 L .71551 .42626 L p 0 0 1 r
F P
0 g
s
.59632 .28805 m .58917 .31277 L .57842 .31964 L p 0 1 0 r
F P
0 g
s
.57842 .31964 m .58575 .29622 L .59632 .28805 L p 0 1 0 r
F P
0 g
s
.77606 .43163 m .78467 .42324 L .79548 .42878 L p 0 0 1 r
F P
0 g
s
.78467 .42324 m .77606 .43163 L .76522 .4261 L p 0 0 1 r
F P
0 g
s
.44435 .47128 m .45178 .46573 L .46334 .473 L p 0 1 0 r
F P
0 g
s
.45178 .46573 m .44435 .47128 L .43282 .46317 L p 0 1 0 r
F P
0 g
s
.29147 .37586 m .29821 .36952 L .30993 .37788 L p 0 1 0 r
F P
0 g
s
.29821 .36952 m .29147 .37586 L .2797 .36837 L p 0 1 0 r
F P
0 g
s
.82567 .43146 m .83445 .42307 L .84515 .42862 L p 0 0 1 r
F P
0 g
s
.83445 .42307 m .82567 .43146 L .81494 .42593 L p 0 0 1 r
F P
0 g
s
.31444 .46966 m .32164 .45879 L .3337 .46143 L p 1 0 0 r
F P
0 g
s
.34098 .44991 m .3337 .46143 L .32164 .45879 L p 1 0 0 r
F P
0 g
s
.65712 .58831 m .64762 .57819 L .63535 .55601 L p 1 0 0 r
F P
0 g
s
.63535 .55601 m .64456 .56418 L .65712 .58831 L p 1 0 0 r
F P
0 g
s
.87528 .4313 m .88424 .42291 L .89482 .42845 L p 0 0 1 r
F P
0 g
s
.88424 .42291 m .87528 .4313 L .86467 .42577 L p 0 0 1 r
F P
0 g
s
.42103 .38539 m .41358 .39681 L .40181 .39414 L p 1 0 0 r
F P
0 g
s
.9249 .43114 m .93403 .42274 L .9445 .42829 L p 0 0 1 r
F P
0 g
s
.93403 .42274 m .9249 .43114 L .9144 .4256 L p 0 0 1 r
F P
0 g
s
.34098 .44991 m .34831 .43809 L .36031 .4402 L p 1 0 0 r
F P
0 g
s
.36767 .42813 m .36031 .4402 L .34831 .43809 L p 1 0 0 r
F P
0 g
s
.50543 .48286 m .51309 .47358 L .52448 .47673 L p 0 1 0 r
F P
0 g
s
.53216 .4656 m .52448 .47673 L .51309 .47358 L p 0 1 0 r
F P
0 g
s
.15688 .42253 m .15043 .43092 L .13816 .42539 L p 0 0 1 r
F P
0 g
s
.53985 .45336 m .54754 .4399 L .5587 .43916 L p 0 1 0 r
F P
0 g
s
.20001 .43076 m .20663 .42236 L .21875 .42791 L p 0 0 1 r
F P
0 g
s
.24959 .4306 m .25638 .4222 L .2684 .42775 L p 0 0 1 r
F P
0 g
s
.25638 .4222 m .24959 .4306 L .23755 .42506 L p 0 0 1 r
F P
0 g
s
.48981 .37554 m .49745 .36851 L .50895 .37649 L p 1 0 0 r
F P
0 g
s
.49745 .36851 m .48981 .37554 L .47832 .36909 L p 1 0 0 r
F P
0 g
s
.29918 .43043 m .30615 .42203 L .31805 .42758 L p 0 0 1 r
F P
0 g
s
.30615 .42203 m .29918 .43043 L .28725 .42489 L p 0 0 1 r
F P
0 g
s
.51309 .47358 m .50543 .48286 L .49397 .4781 L p 0 1 0 r
F P
0 g
s
.35592 .42186 m .34878 .43027 L .33696 .42473 L p 0 0 1 r
F P
0 g
s
.39839 .4301 m .4057 .4217 L .41738 .42725 L p 0 0 1 r
F P
0 g
s
.448 .42994 m .45548 .42153 L .46705 .42709 L p 0 0 1 r
F P
0 g
s
.45548 .42153 m .448 .42994 L .43641 .4244 L p 0 0 1 r
F P
0 g
s
.49762 .42977 m .50528 .42137 L .51673 .42692 L p 0 0 1 r
F P
0 g
s
.50528 .42137 m .49762 .42977 L .48614 .42423 L p 0 0 1 r
F P
0 g
s
.59688 .42944 m .60488 .42104 L .61611 .42659 L p 0 0 1 r
F P
0 g
s
.60488 .42104 m .59688 .42944 L .58562 .4239 L p 0 0 1 r
F P
0 g
s
.64652 .42928 m .65469 .42087 L .66581 .42643 L p 0 0 1 r
F P
0 g
s
.65469 .42087 m .64652 .42928 L .63538 .42373 L p 0 0 1 r
F P
0 g
s
.69617 .42911 m .70451 .4207 L .71551 .42626 L p 0 0 1 r
F P
0 g
s
.70451 .4207 m .69617 .42911 L .68514 .42357 L p 0 0 1 r
F P
0 g
s
.74582 .42895 m .75434 .42054 L .76522 .4261 L p 0 0 1 r
F P
0 g
s
.75434 .42054 m .74582 .42895 L .7349 .4234 L p 0 0 1 r
F P
0 g
s
.43282 .46317 m .44019 .45798 L .45178 .46573 L p 0 1 0 r
F P
0 g
s
.44019 .45798 m .43282 .46317 L .42127 .45471 L p 0 1 0 r
F P
0 g
s
.79548 .42878 m .80417 .42037 L .81494 .42593 L p 0 0 1 r
F P
0 g
s
.80417 .42037 m .79548 .42878 L .78467 .42324 L p 0 0 1 r
F P
0 g
s
.61381 .49446 m .60505 .48984 L .59324 .47306 L p 1 0 0 r
F P
0 g
s
.59324 .47306 m .6018 .47613 L .61381 .49446 L p 1 0 0 r
F P
0 g
s
.84515 .42862 m .85401 .42021 L .86467 .42577 L p 0 0 1 r
F P
0 g
s
.85401 .42021 m .84515 .42862 L .83445 .42307 L p 0 0 1 r
F P
0 g
s
.29527 .47627 m .30236 .46633 L .31444 .46966 L p 1 0 0 r
F P
0 g
s
.32164 .45879 m .31444 .46966 L .30236 .46633 L p 1 0 0 r
F P
0 g
s
.89482 .42845 m .90385 .42004 L .9144 .4256 L p 0 0 1 r
F P
0 g
s
.90385 .42004 m .89482 .42845 L .88424 .42291 L p 0 0 1 r
F P
0 g
s
.27627 .48073 m .28321 .47199 L .29527 .47627 L p 1 0 0 r
F P
0 g
s
.28321 .47199 m .27627 .48073 L .26428 .47526 L p 1 0 0 r
F P
0 g
s
.2457 .47561 m .2523 .4691 L .26428 .47526 L p 1 0 0 r
F P
0 g
s
.2523 .4691 m .2457 .47561 L .23388 .46789 L p 1 0 0 r
F P
0 g
s
.95371 .41987 m .9445 .42829 L .93403 .42274 L p 0 0 1 r
F P
0 g
s
.44016 .37799 m .44765 .36773 L .45924 .37241 L p 1 0 0 r
F P
0 g
s
.45924 .37241 m .46677 .36325 L .47832 .36909 L p 1 0 0 r
F P
0 g
s
.46677 .36325 m .45924 .37241 L .44765 .36773 L p 1 0 0 r
F P
0 g
s
.42103 .38539 m .42849 .37427 L .44016 .37799 L p 1 0 0 r
F P
0 g
s
.44765 .36773 m .44016 .37799 L .42849 .37427 L p 1 0 0 r
F P
0 g
s
.47487 .47971 m .48245 .47262 L .49397 .4781 L p 0 1 0 r
F P
0 g
s
.48245 .47262 m .47487 .47971 L .46334 .473 L p 0 1 0 r
F P
0 g
s
.2797 .36837 m .28644 .3615 L .29821 .36952 L p 0 1 0 r
F P
0 g
s
.28644 .3615 m .2797 .36837 L .26784 .36135 L p 0 1 0 r
F P
0 g
s
.21875 .42791 m .22545 .41949 L .23755 .42506 L p 0 0 1 r
F P
0 g
s
.22545 .41949 m .21875 .42791 L .20663 .42236 L p 0 0 1 r
F P
0 g
s
.64149 .55024 m .63226 .54212 L .62017 .52197 L p 1 0 0 r
F P
0 g
s
.62017 .52197 m .62914 .52829 L .64149 .55024 L p 1 0 0 r
F P
0 g
s
.2684 .42775 m .27527 .41933 L .28725 .42489 L p 0 0 1 r
F P
0 g
s
.27527 .41933 m .2684 .42775 L .25638 .4222 L p 0 0 1 r
F P
0 g
s
.21049 .37795 m .21763 .36552 L .23 .36903 L p 0 1 0 r
F P
0 g
s
.23 .36903 m .23694 .35854 L .24907 .36368 L p 0 1 0 r
F P
0 g
s
.23694 .35854 m .23 .36903 L .21763 .36552 L p 0 1 0 r
F P
0 g
s
.59786 .22242 m .5984 .22377 L .5965 .22581 L p 0 1 0 r
F P
0 g
s
.16169 .51444 m .15307 .5379 L .13837 .54886 L p 0 1 0 r
F P
0 g
s
.13837 .54886 m .14737 .52341 L .16169 .51444 L p 0 1 0 r
F P
0 g
s
.31805 .42758 m .32509 .41916 L .33696 .42473 L p 0 0 1 r
F P
0 g
s
.32509 .41916 m .31805 .42758 L .30615 .42203 L p 0 0 1 r
F P
0 g
s
.18054 .43924 m .17261 .45789 L .15883 .46314 L p 0 1 0 r
F P
0 g
s
.15883 .46314 m .16703 .44292 L .18054 .43924 L p 0 1 0 r
F P
0 g
s
.24907 .36368 m .25589 .35484 L .26784 .36135 L p 0 1 0 r
F P
0 g
s
.25589 .35484 m .24907 .36368 L .23694 .35854 L p 0 1 0 r
F P
0 g
s
.30236 .46633 m .29527 .47627 L .28321 .47199 L p 1 0 0 r
F P
0 g
s
.41738 .42725 m .42476 .41883 L .43641 .4244 L p 0 0 1 r
F P
0 g
s
.42476 .41883 m .41738 .42725 L .4057 .4217 L p 0 0 1 r
F P
0 g
s
.46705 .42709 m .4746 .41866 L .48614 .42423 L p 0 0 1 r
F P
0 g
s
.4746 .41866 m .46705 .42709 L .45548 .42153 L p 0 0 1 r
F P
0 g
s
.51673 .42692 m .52446 .4185 L .53588 .42407 L p 0 0 1 r
F P
0 g
s
.52446 .4185 m .51673 .42692 L .50528 .42137 L p 0 0 1 r
F P
0 g
s
.58528 .3514 m .57788 .3722 L .56692 .37645 L p 0 1 0 r
F P
0 g
s
.56692 .37645 m .57444 .35691 L .58528 .3514 L p 0 1 0 r
F P
0 g
s
.21049 .37795 m .20323 .39145 L .19036 .39104 L p 0 1 0 r
F P
0 g
s
.34831 .43809 m .35568 .42606 L .36767 .42813 L p 1 0 0 r
F P
0 g
s
.61611 .42659 m .62418 .41816 L .63538 .42373 L p 0 0 1 r
F P
0 g
s
.62418 .41816 m .61611 .42659 L .60488 .42104 L p 0 0 1 r
F P
0 g
s
.42127 .45471 m .42858 .44981 L .44019 .45798 L p 0 1 0 r
F P
0 g
s
.42858 .44981 m .42127 .45471 L .4097 .44595 L p 0 1 0 r
F P
0 g
s
.32164 .45879 m .32891 .44749 L .34098 .44991 L p 1 0 0 r
F P
0 g
s
.34831 .43809 m .34098 .44991 L .32891 .44749 L p 1 0 0 r
F P
0 g
s
.66581 .42643 m .67405 .418 L .68514 .42357 L p 0 0 1 r
F P
0 g
s
.67405 .418 m .66581 .42643 L .65469 .42087 L p 0 0 1 r
F P
0 g
s
.5965 .22581 m .59754 .22128 L .59786 .22242 L p 0 1 0 r
F P
0 g
s
.71551 .42626 m .72393 .41783 L .7349 .4234 L p 0 0 1 r
F P
0 g
s
.72393 .41783 m .71551 .42626 L .70451 .4207 L p 0 0 1 r
F P
0 g
s
.76522 .4261 m .77382 .41767 L .78467 .42324 L p 0 0 1 r
F P
0 g
s
.77382 .41767 m .76522 .4261 L .75434 .42054 L p 0 0 1 r
F P
0 g
s
.40181 .39414 m .40926 .38239 L .42103 .38539 L p 1 0 0 r
F P
0 g
s
.42849 .37427 m .42103 .38539 L .40926 .38239 L p 1 0 0 r
F P
0 g
s
.81494 .42593 m .82371 .4175 L .83445 .42307 L p 0 0 1 r
F P
0 g
s
.82371 .4175 m .81494 .42593 L .80417 .42037 L p 0 0 1 r
F P
0 g
s
.1465 .61818 m .14474 .62363 L .14425 .62242 L p 0 1 0 r
F P
0 g
s
.14425 .62242 m .14357 .62119 L .1465 .61818 L p 0 1 0 r
F P
0 g
s
.1465 .61818 m .14357 .62119 L .14143 .61596 L p 0 1 0 r
F P
0 g
s
.47832 .36909 m .48592 .36127 L .49745 .36851 L p 1 0 0 r
F P
0 g
s
.48592 .36127 m .47832 .36909 L .46677 .36325 L p 1 0 0 r
F P
0 g
s
.86467 .42577 m .87361 .41733 L .88424 .42291 L p 0 0 1 r
F P
0 g
s
.87361 .41733 m .86467 .42577 L .85401 .42021 L p 0 0 1 r
F P
0 g
s
.51309 .47358 m .52079 .46333 L .53216 .4656 L p 0 1 0 r
F P
0 g
s
.53985 .45336 m .53216 .4656 L .52079 .46333 L p 0 1 0 r
F P
0 g
s
.9144 .4256 m .92352 .41717 L .93403 .42274 L p 0 0 1 r
F P
0 g
s
.92352 .41717 m .9144 .4256 L .90385 .42004 L p 0 0 1 r
F P
0 g
s
.13816 .42539 m .14458 .41695 L .15688 .42253 L p 0 0 1 r
F P
0 g
s
.59502 .21503 m .59754 .22128 L p .58599 .23555 L 0 1 0 r
F P
0 g
s
.59754 .22128 m .5965 .22581 L .58599 .23555 L p 0 1 0 r
F P
0 g
s
.23388 .46789 m .24036 .46219 L .2523 .4691 L p 1 0 0 r
F P
0 g
s
.24036 .46219 m .23388 .46789 L .22213 .45931 L p 1 0 0 r
F P
0 g
s
.23755 .42506 m .24431 .41662 L .25638 .4222 L p 0 0 1 r
F P
0 g
s
.24431 .41662 m .23755 .42506 L .22545 .41949 L p 0 0 1 r
F P
0 g
s
.28725 .42489 m .29419 .41645 L .30615 .42203 L p 0 0 1 r
F P
0 g
s
.29419 .41645 m .28725 .42489 L .27527 .41933 L p 0 0 1 r
F P
0 g
s
.17261 .45789 m .16446 .47806 L .15036 .48501 L p 0 1 0 r
F P
0 g
s
.15036 .48501 m .15883 .46314 L .17261 .45789 L p 0 1 0 r
F P
0 g
s
.33696 .42473 m .34408 .41629 L .35592 .42186 L p 0 0 1 r
F P
0 g
s
.34408 .41629 m .33696 .42473 L .32509 .41916 L p 0 0 1 r
F P
0 g
s
.4097 .44595 m .41696 .44128 L .42858 .44981 L p 0 1 0 r
F P
0 g
s
.41696 .44128 m .4097 .44595 L .39813 .43695 L p 0 1 0 r
F P
0 g
s
.66314 .61675 m .66389 .61832 L .66449 .62447 L p 1 0 0 r
F P
0 g
s
.43641 .4244 m .44387 .41595 L .45548 .42153 L p 0 0 1 r
F P
0 g
s
.44387 .41595 m .43641 .4244 L .42476 .41883 L p 0 0 1 r
F P
0 g
s
.48614 .42423 m .49377 .41579 L .50528 .42137 L p 0 0 1 r
F P
0 g
s
.49377 .41579 m .48614 .42423 L .4746 .41866 L p 0 0 1 r
F P
0 g
s
.54368 .41562 m .53588 .42407 L .52446 .4185 L p 0 0 1 r
F P
0 g
s
.49397 .4781 m .50162 .46958 L .51309 .47358 L p 0 1 0 r
F P
0 g
s
.50162 .46958 m .49397 .4781 L .48245 .47262 L p 0 1 0 r
F P
0 g
s
.26784 .36135 m .2746 .35389 L .28644 .3615 L p 0 1 0 r
F P
0 g
s
.2746 .35389 m .26784 .36135 L .25589 .35484 L p 0 1 0 r
F P
0 g
s
.46334 .473 m .47088 .46646 L .48245 .47262 L p 0 1 0 r
F P
0 g
s
.47088 .46646 m .46334 .473 L .45178 .46573 L p 0 1 0 r
F P
0 g
s
.58562 .4239 m .5936 .41545 L .60488 .42104 L p 0 0 1 r
F P
0 g
s
.5936 .41545 m .58562 .4239 L .57431 .41833 L p 0 0 1 r
F P
0 g
s
.19036 .39104 m .19779 .37635 L .21049 .37795 L p 0 1 0 r
F P
0 g
s
.21763 .36552 m .21049 .37795 L .19779 .37635 L p 0 1 0 r
F P
0 g
s
.14989 .57732 m .14072 .60454 L p .13511 .60303 L 0 1 0 r
F P
0 g
s
.13511 .60303 m .1324 .59825 L p .14989 .57732 L 0 1 0 r
F P
0 g
s
.1324 .59825 m .1349 .59059 L .14989 .57732 L p 0 1 0 r
F P
0 g
s
.63538 .42373 m .64353 .41529 L .65469 .42087 L p 0 0 1 r
F P
0 g
s
.64353 .41529 m .63538 .42373 L .62418 .41816 L p 0 0 1 r
F P
0 g
s
.68514 .42357 m .69346 .41512 L .70451 .4207 L p 0 0 1 r
F P
0 g
s
.69346 .41512 m .68514 .42357 L .67405 .418 L p 0 0 1 r
F P
0 g
s
.7349 .4234 m .7434 .41495 L .75434 .42054 L p 0 0 1 r
F P
0 g
s
.7434 .41495 m .7349 .4234 L .72393 .41783 L p 0 0 1 r
F P
0 g
s
.51671 .37117 m .50895 .37649 L .49745 .36851 L p 1 0 0 r
F P
0 g
s
.31671 .37241 m .30993 .37788 L .29821 .36952 L p 0 1 0 r
F P
0 g
s
.78467 .42324 m .79334 .41479 L .80417 .42037 L p 0 0 1 r
F P
0 g
s
.79334 .41479 m .78467 .42324 L .77382 .41767 L p 0 0 1 r
F P
0 g
s
.5866 .44562 m .57819 .44402 L .56653 .43001 L p 1 0 0 r
F P
0 g
s
.56653 .43001 m .57479 .43025 L .5866 .44562 L p 1 0 0 r
F P
0 g
s
.83445 .42307 m .8433 .41462 L .85401 .42021 L p 0 0 1 r
F P
0 g
s
.8433 .41462 m .83445 .42307 L .82371 .4175 L p 0 0 1 r
F P
0 g
s
.52079 .46333 m .51309 .47358 L .50162 .46958 L p 0 1 0 r
F P
0 g
s
.22213 .45931 m .22845 .4545 L .24036 .46219 L p 1 0 0 r
F P
0 g
s
.22845 .4545 m .22213 .45931 L .21047 .44985 L p 1 0 0 r
F P
0 g
s
.5965 .22581 m .58948 .25349 L .57877 .2619 L p 0 1 0 r
F P
0 g
s
.57877 .2619 m .58599 .23555 L .5965 .22581 L p 0 1 0 r
F P
0 g
s
.26428 .47526 m .27113 .46714 L .28321 .47199 L p 1 0 0 r
F P
0 g
s
.27113 .46714 m .26428 .47526 L .2523 .4691 L p 1 0 0 r
F P
0 g
s
.88424 .42291 m .89326 .41445 L .90385 .42004 L p 0 0 1 r
F P
0 g
s
.89326 .41445 m .88424 .42291 L .87361 .41733 L p 0 0 1 r
F P
0 g
s
.30236 .46633 m .30953 .45581 L .32164 .45879 L p 1 0 0 r
F P
0 g
s
.32891 .44749 m .32164 .45879 L .30953 .45581 L p 1 0 0 r
F P
0 g
s
.93403 .42274 m .94322 .41429 L .95371 .41987 L p 0 0 1 r
F P
0 g
s
.94322 .41429 m .93403 .42274 L .92352 .41717 L p 0 0 1 r
F P
0 g
s
.39813 .43695 m .40532 .43245 L .41696 .44128 L p 0 1 0 r
F P
0 g
s
.40532 .43245 m .39813 .43695 L .38654 .42779 L p 0 1 0 r
F P
0 g
s
.16337 .41407 m .15688 .42253 L .14458 .41695 L p 0 0 1 r
F P
0 g
s
.40926 .38239 m .40181 .39414 L .38994 .39165 L p 1 0 0 r
F P
0 g
s
.20663 .42236 m .21329 .41391 L .22545 .41949 L p 0 0 1 r
F P
0 g
s
.21329 .41391 m .20663 .42236 L .19444 .41679 L p 0 0 1 r
F P
0 g
s
.626 .51449 m .61701 .5082 L .60505 .48984 L p 1 0 0 r
F P
0 g
s
.60505 .48984 m .61381 .49446 L .626 .51449 L p 1 0 0 r
F P
0 g
s
.25638 .4222 m .26322 .41374 L .27527 .41933 L p 0 0 1 r
F P
0 g
s
.26322 .41374 m .25638 .4222 L .24431 .41662 L p 0 0 1 r
F P
0 g
s
.20487 .43654 m .19891 .43944 L .18747 .42806 L p 1 0 0 r
F P
0 g
s
.18747 .42806 m .19322 .4262 L .20487 .43654 L p 1 0 0 r
F P
0 g
s
.30615 .42203 m .31316 .41357 L .32509 .41916 L p 0 0 1 r
F P
0 g
s
.31316 .41357 m .30615 .42203 L .29419 .41645 L p 0 0 1 r
F P
0 g
s
.58917 .31277 m .58187 .3357 L .57096 .34128 L p 0 1 0 r
F P
0 g
s
.57096 .34128 m .57842 .31964 L .58917 .31277 L p 0 1 0 r
F P
0 g
s
.32891 .44749 m .33623 .43583 L .34831 .43809 L p 1 0 0 r
F P
0 g
s
.35568 .42606 m .34831 .43809 L .33623 .43583 L p 1 0 0 r
F P
0 g
s
.4057 .4217 m .41306 .41324 L .42476 .41883 L p 0 0 1 r
F P
0 g
s
.41306 .41324 m .4057 .4217 L .39397 .41612 L p 0 0 1 r
F P
0 g
s
.21047 .44985 m .21662 .44596 L .22845 .4545 L p 1 0 0 r
F P
0 g
s
.21662 .44596 m .21047 .44985 L .19891 .43944 L p 1 0 0 r
F P
0 g
s
.42849 .37427 m .43598 .36351 L .44765 .36773 L p 1 0 0 r
F P
0 g
s
.44765 .36773 m .45517 .35796 L .46677 .36325 L p 1 0 0 r
F P
0 g
s
.45517 .35796 m .44765 .36773 L .43598 .36351 L p 1 0 0 r
F P
0 g
s
.45548 .42153 m .46302 .41307 L .4746 .41866 L p 0 0 1 r
F P
0 g
s
.46302 .41307 m .45548 .42153 L .44387 .41595 L p 0 0 1 r
F P
0 g
s
.52079 .46333 m .52851 .45203 L .53985 .45336 L p 0 1 0 r
F P
0 g
s
.54754 .4399 m .53985 .45336 L .52851 .45203 L p 0 1 0 r
F P
0 g
s
.19891 .43944 m .20487 .43654 L .21662 .44596 L p 1 0 0 r
F P
0 g
s
.50528 .42137 m .51298 .4129 L .52446 .4185 L p 0 0 1 r
F P
0 g
s
.51298 .4129 m .50528 .42137 L .49377 .41579 L p 0 0 1 r
F P
0 g
s
.21763 .36552 m .22467 .35409 L .23694 .35854 L p 0 1 0 r
F P
0 g
s
.23694 .35854 m .24382 .3489 L .25589 .35484 L p 0 1 0 r
F P
0 g
s
.24382 .3489 m .23694 .35854 L .22467 .35409 L p 0 1 0 r
F P
0 g
s
.38654 .42779 m .39367 .42338 L .40532 .43245 L p 0 1 0 r
F P
0 g
s
.60488 .42104 m .61293 .41257 L .62418 .41816 L p 0 0 1 r
F P
0 g
s
.61293 .41257 m .60488 .42104 L .5936 .41545 L p 0 0 1 r
F P
0 g
s
.65469 .42087 m .66292 .4124 L .67405 .418 L p 0 0 1 r
F P
0 g
s
.66292 .4124 m .65469 .42087 L .64353 .41529 L p 0 0 1 r
F P
0 g
s
.28321 .47199 m .29024 .46254 L .30236 .46633 L p 1 0 0 r
F P
0 g
s
.30953 .45581 m .30236 .46633 L .29024 .46254 L p 1 0 0 r
F P
0 g
s
.70451 .4207 m .71291 .41224 L .72393 .41783 L p 0 0 1 r
F P
0 g
s
.71291 .41224 m .70451 .4207 L .69346 .41512 L p 0 0 1 r
F P
0 g
s
.29821 .36952 m .30497 .36365 L .31671 .37241 L p 0 1 0 r
F P
0 g
s
.30497 .36365 m .29821 .36952 L .28644 .3615 L p 0 1 0 r
F P
0 g
s
.16446 .47806 m .15605 .49986 L .14162 .50865 L p 0 1 0 r
F P
0 g
s
.14162 .50865 m .15036 .48501 L .16446 .47806 L p 0 1 0 r
F P
0 g
s
.75434 .42054 m .76291 .41207 L .77382 .41767 L p 0 0 1 r
F P
0 g
s
.76291 .41207 m .75434 .42054 L .7434 .41495 L p 0 0 1 r
F P
0 g
s
.29024 .46254 m .28321 .47199 L .27113 .46714 L p 1 0 0 r
F P
0 g
s
.46677 .36325 m .47435 .3547 L .48592 .36127 L p 1 0 0 r
F P
0 g
s
.47435 .3547 m .46677 .36325 L .45517 .35796 L p 1 0 0 r
F P
0 g
s
.40926 .38239 m .41673 .37088 L .42849 .37427 L p 1 0 0 r
F P
0 g
s
.43598 .36351 m .42849 .37427 L .41673 .37088 L p 1 0 0 r
F P
0 g
s
.59293 .27099 m .58575 .29622 L .57492 .30319 L p 0 1 0 r
F P
0 g
s
.57492 .30319 m .58228 .27927 L .59293 .27099 L p 0 1 0 r
F P
0 g
s
.49745 .36851 m .50515 .36228 L .51671 .37117 L p 1 0 0 r
F P
0 g
s
.50515 .36228 m .49745 .36851 L .48592 .36127 L p 1 0 0 r
F P
0 g
s
.80417 .42037 m .81292 .4119 L .82371 .4175 L p 0 0 1 r
F P
0 g
s
.81292 .4119 m .80417 .42037 L .79334 .41479 L p 0 0 1 r
F P
0 g
s
.45178 .46573 m .45928 .45969 L .47088 .46646 L p 0 1 0 r
F P
0 g
s
.45928 .45969 m .45178 .46573 L .44019 .45798 L p 0 1 0 r
F P
0 g
s
.85401 .42021 m .86293 .41173 L .87361 .41733 L p 0 0 1 r
F P
0 g
s
.86293 .41173 m .85401 .42021 L .8433 .41462 L p 0 0 1 r
F P
0 g
s
.90385 .42004 m .91295 .41157 L .92352 .41717 L p 0 0 1 r
F P
0 g
s
.91295 .41157 m .90385 .42004 L .89326 .41445 L p 0 0 1 r
F P
0 g
s
.15307 .5379 m .14415 .56324 L .12903 .57635 L p 0 1 0 r
F P
0 g
s
.12903 .57635 m .13837 .54886 L .15307 .5379 L p 0 1 0 r
F P
0 g
s
.19779 .37635 m .20507 .36284 L .21763 .36552 L p 0 1 0 r
F P
0 g
s
.22467 .35409 m .21763 .36552 L .20507 .36284 L p 0 1 0 r
F P
0 g
s
.59853 .4624 m .58994 .45935 L .57819 .44402 L p 1 0 0 r
F P
0 g
s
.57819 .44402 m .5866 .44562 L .59853 .4624 L p 1 0 0 r
F P
0 g
s
.65996 .59836 m .66139 .60404 L p .64762 .57819 L 1 0 0 r
F P
0 g
s
.66139 .60404 m .66014 .60248 L .64762 .57819 L p 1 0 0 r
F P
0 g
s
.64762 .57819 m .65712 .58831 L p .65996 .59836 L 1 0 0 r
F P
0 g
s
.58599 .23555 m .59295 .20757 L .59502 .21503 L p 0 1 0 r
F P
0 g
s
.22545 .41949 m .23219 .41102 L .24431 .41662 L p 0 0 1 r
F P
0 g
s
.23219 .41102 m .22545 .41949 L .21329 .41391 L p 0 0 1 r
F P
0 g
s
.27527 .41933 m .28218 .41085 L .29419 .41645 L p 0 0 1 r
F P
0 g
s
.28218 .41085 m .27527 .41933 L .26322 .41374 L p 0 0 1 r
F P
0 g
s
.25589 .35484 m .26267 .34672 L .2746 .35389 L p 0 1 0 r
F P
0 g
s
.26267 .34672 m .25589 .35484 L .24382 .3489 L p 0 1 0 r
F P
0 g
s
.32509 .41916 m .33218 .41068 L .34408 .41629 L p 0 0 1 r
F P
0 g
s
.33218 .41068 m .32509 .41916 L .31316 .41357 L p 0 0 1 r
F P
0 g
s
.42476 .41883 m .43219 .41035 L .44387 .41595 L p 0 0 1 r
F P
0 g
s
.43219 .41035 m .42476 .41883 L .41306 .41324 L p 0 0 1 r
F P
0 g
s
.4746 .41866 m .48221 .41018 L .49377 .41579 L p 0 0 1 r
F P
0 g
s
.48221 .41018 m .4746 .41866 L .46302 .41307 L p 0 0 1 r
F P
0 g
s
.6638 .61794 m .66389 .61832 L .66314 .61675 L p 1 0 0 r
F P
0 g
s
.66314 .61675 m .66376 .61753 L .6638 .61794 L p 1 0 0 r
F P
0 g
s
.48245 .47262 m .49009 .46479 L .50162 .46958 L p 0 1 0 r
F P
0 g
s
.49009 .46479 m .48245 .47262 L .47088 .46646 L p 0 1 0 r
F P
0 g
s
.52446 .4185 m .53224 .41001 L .54368 .41562 L p 0 0 1 r
F P
0 g
s
.53224 .41001 m .52446 .4185 L .51298 .4129 L p 0 0 1 r
F P
0 g
s
.52851 .45203 m .53623 .43958 L .54754 .4399 L p 0 1 0 r
F P
0 g
s
.5552 .42514 m .54754 .4399 L .53623 .43958 L p 0 1 0 r
F P
0 g
s
.57431 .41833 m .58227 .40985 L .5936 .41545 L p 0 0 1 r
F P
0 g
s
.62418 .41816 m .63231 .40968 L .64353 .41529 L p 0 0 1 r
F P
0 g
s
.63231 .40968 m .62418 .41816 L .61293 .41257 L p 0 0 1 r
F P
0 g
s
.2523 .4691 m .25905 .46167 L .27113 .46714 L p 1 0 0 r
F P
0 g
s
.25905 .46167 m .2523 .4691 L .24036 .46219 L p 1 0 0 r
F P
0 g
s
.65408 .57424 m .64456 .56418 L .63226 .54212 L p 1 0 0 r
F P
0 g
s
.63226 .54212 m .64149 .55024 L .65408 .57424 L p 1 0 0 r
F P
0 g
s
.67405 .418 m .68236 .40951 L .69346 .41512 L p 0 0 1 r
F P
0 g
s
.68236 .40951 m .67405 .418 L .66292 .4124 L p 0 0 1 r
F P
0 g
s
.72393 .41783 m .73241 .40934 L .7434 .41495 L p 0 0 1 r
F P
0 g
s
.73241 .40934 m .72393 .41783 L .71291 .41224 L p 0 0 1 r
F P
0 g
s
.28644 .3615 m .29319 .35516 L .30497 .36365 L p 0 1 0 r
F P
0 g
s
.29319 .35516 m .28644 .3615 L .2746 .35389 L p 0 1 0 r
F P
0 g
s
.77382 .41767 m .78247 .40918 L .79334 .41479 L p 0 0 1 r
F P
0 g
s
.78247 .40918 m .77382 .41767 L .76291 .41207 L p 0 0 1 r
F P
0 g
s
.30953 .45581 m .31677 .4448 L .32891 .44749 L p 1 0 0 r
F P
0 g
s
.33623 .43583 m .32891 .44749 L .31677 .4448 L p 1 0 0 r
F P
0 g
s
.38994 .39165 m .3974 .37963 L .40926 .38239 L p 1 0 0 r
F P
0 g
s
.41673 .37088 m .40926 .38239 L .3974 .37963 L p 1 0 0 r
F P
0 g
s
.82371 .4175 m .83254 .40901 L .8433 .41462 L p 0 0 1 r
F P
0 g
s
.83254 .40901 m .82371 .4175 L .81292 .4119 L p 0 0 1 r
F P
0 g
s
.87361 .41733 m .88261 .40884 L .89326 .41445 L p 0 0 1 r
F P
0 g
s
.88261 .40884 m .87361 .41733 L .86293 .41173 L p 0 0 1 r
F P
0 g
s
.33623 .43583 m .3436 .42388 L .35568 .42606 L p 1 0 0 r
F P
0 g
s
.36308 .41386 m .35568 .42606 L .3436 .42388 L p 1 0 0 r
F P
0 g
s
.92352 .41717 m .93269 .40867 L .94322 .41429 L p 0 0 1 r
F P
0 g
s
.93269 .40867 m .92352 .41717 L .91295 .41157 L p 0 0 1 r
F P
0 g
s
.44019 .45798 m .44764 .45237 L .45928 .45969 L p 0 1 0 r
F P
0 g
s
.44764 .45237 m .44019 .45798 L .42858 .44981 L p 0 1 0 r
F P
0 g
s
.53623 .43958 m .54395 .42589 L .5552 .42514 L p 0 1 0 r
F P
0 g
s
.19444 .41679 m .20108 .40829 L .21329 .41391 L p 0 0 1 r
F P
0 g
s
.50162 .46958 m .50932 .46016 L .52079 .46333 L p 0 1 0 r
F P
0 g
s
.52851 .45203 m .52079 .46333 L .50932 .46016 L p 0 1 0 r
F P
0 g
s
.24431 .41662 m .25113 .40812 L .26322 .41374 L p 0 0 1 r
F P
0 g
s
.25113 .40812 m .24431 .41662 L .23219 .41102 L p 0 0 1 r
F P
0 g
s
.48592 .36127 m .49358 .3542 L .50515 .36228 L p 1 0 0 r
F P
0 g
s
.49358 .3542 m .48592 .36127 L .47435 .3547 L p 1 0 0 r
F P
0 g
s
.29419 .41645 m .30118 .40796 L .31316 .41357 L p 0 0 1 r
F P
0 g
s
.30118 .40796 m .29419 .41645 L .28218 .41085 L p 0 0 1 r
F P
0 g
s
.35124 .40779 m .34408 .41629 L .33218 .41068 L p 0 0 1 r
F P
0 g
s
.39397 .41612 m .4013 .40762 L .41306 .41324 L p 0 0 1 r
F P
0 g
s
.44387 .41595 m .45138 .40745 L .46302 .41307 L p 0 0 1 r
F P
0 g
s
.45138 .40745 m .44387 .41595 L .43219 .41035 L p 0 0 1 r
F P
0 g
s
.50932 .46016 m .50162 .46958 L .49009 .46479 L p 0 1 0 r
F P
0 g
s
.49377 .41579 m .50145 .40729 L .51298 .4129 L p 0 0 1 r
F P
0 g
s
.50145 .40729 m .49377 .41579 L .48221 .41018 L p 0 0 1 r
F P
0 g
s
.5936 .41545 m .60163 .40695 L .61293 .41257 L p 0 0 1 r
F P
0 g
s
.60163 .40695 m .5936 .41545 L .58227 .40985 L p 0 0 1 r
F P
0 g
s
.64353 .41529 m .65173 .40678 L .66292 .4124 L p 0 0 1 r
F P
0 g
s
.65173 .40678 m .64353 .41529 L .63231 .40968 L p 0 0 1 r
F P
0 g
s
.69346 .41512 m .70184 .40661 L .71291 .41224 L p 0 0 1 r
F P
0 g
s
.70184 .40661 m .69346 .41512 L .68236 .40951 L p 0 0 1 r
F P
0 g
s
.7434 .41495 m .75195 .40645 L .76291 .41207 L p 0 0 1 r
F P
0 g
s
.75195 .40645 m .7434 .41495 L .73241 .40934 L p 0 0 1 r
F P
0 g
s
.79334 .41479 m .80208 .40628 L .81292 .4119 L p 0 0 1 r
F P
0 g
s
.80208 .40628 m .79334 .41479 L .78247 .40918 L p 0 0 1 r
F P
0 g
s
.15605 .49986 m .14737 .52341 L .13255 .5342 L p 0 1 0 r
F P
0 g
s
.13255 .5342 m .14162 .50865 L .15605 .49986 L p 0 1 0 r
F P
0 g
s
.17501 .42422 m .16703 .44292 L .15315 .44798 L p 0 1 0 r
F P
0 g
s
.15315 .44798 m .16141 .42771 L .17501 .42422 L p 0 1 0 r
F P
0 g
s
.6106 .48073 m .6018 .47613 L .58994 .45935 L p 1 0 0 r
F P
0 g
s
.58994 .45935 m .59853 .4624 L .6106 .48073 L p 1 0 0 r
F P
0 g
s
.8433 .41462 m .8522 .40611 L .86293 .41173 L p 0 0 1 r
F P
0 g
s
.8522 .40611 m .8433 .41462 L .83254 .40901 L p 0 0 1 r
F P
0 g
s
.29024 .46254 m .29737 .45245 L .30953 .45581 L p 1 0 0 r
F P
0 g
s
.31677 .4448 m .30953 .45581 L .29737 .45245 L p 1 0 0 r
F P
0 g
s
.89326 .41445 m .90234 .40594 L .91295 .41157 L p 0 0 1 r
F P
0 g
s
.90234 .40594 m .89326 .41445 L .88261 .40884 L p 0 0 1 r
F P
0 g
s
.42858 .44981 m .43597 .44457 L .44764 .45237 L p 0 1 0 r
F P
0 g
s
.43597 .44457 m .42858 .44981 L .41696 .44128 L p 0 1 0 r
F P
0 g
s
.43598 .36351 m .4435 .35318 L .45517 .35796 L p 1 0 0 r
F P
0 g
s
.45517 .35796 m .46273 .34875 L .47435 .3547 L p 1 0 0 r
F P
0 g
s
.46273 .34875 m .45517 .35796 L .4435 .35318 L p 1 0 0 r
F P
0 g
s
.41673 .37088 m .42423 .35968 L .43598 .36351 L p 1 0 0 r
F P
0 g
s
.4435 .35318 m .43598 .36351 L .42423 .35968 L p 1 0 0 r
F P
0 g
s
.20507 .36284 m .21223 .3504 L .22467 .35409 L p 0 1 0 r
F P
0 g
s
.22467 .35409 m .23163 .3436 L .24382 .3489 L p 0 1 0 r
F P
0 g
s
.23163 .3436 m .22467 .35409 L .21223 .3504 L p 0 1 0 r
F P
0 g
s
.27113 .46714 m .2781 .45824 L .29024 .46254 L p 1 0 0 r
F P
0 g
s
.2781 .45824 m .27113 .46714 L .25905 .46167 L p 1 0 0 r
F P
0 g
s
.58187 .3357 m .57444 .35691 L .5634 .36123 L p 0 1 0 r
F P
0 g
s
.5634 .36123 m .57096 .34128 L .58187 .3357 L p 0 1 0 r
F P
0 g
s
.2746 .35389 m .28135 .34702 L .29319 .35516 L p 0 1 0 r
F P
0 g
s
.28135 .34702 m .2746 .35389 L .26267 .34672 L p 0 1 0 r
F P
0 g
s
.6384 .53637 m .62914 .52829 L .61701 .5082 L p 1 0 0 r
F P
0 g
s
.61701 .5082 m .626 .51449 L .6384 .53637 L p 1 0 0 r
F P
0 g
s
.24036 .46219 m .24699 .45551 L .25905 .46167 L p 1 0 0 r
F P
0 g
s
.24699 .45551 m .24036 .46219 L .22845 .4545 L p 1 0 0 r
F P
0 g
s
.24382 .3489 m .25065 .34006 L .26267 .34672 L p 0 1 0 r
F P
0 g
s
.25065 .34006 m .24382 .3489 L .23163 .3436 L p 0 1 0 r
F P
0 g
s
.21329 .41391 m .22 .40539 L .23219 .41102 L p 0 0 1 r
F P
0 g
s
.22 .40539 m .21329 .41391 L .20108 .40829 L p 0 0 1 r
F P
0 g
s
.20507 .36284 m .19779 .37635 L .18484 .37575 L p 0 1 0 r
F P
0 g
s
.26322 .41374 m .27011 .40522 L .28218 .41085 L p 0 0 1 r
F P
0 g
s
.27011 .40522 m .26322 .41374 L .25113 .40812 L p 0 0 1 r
F P
0 g
s
.47088 .46646 m .47849 .45926 L .49009 .46479 L p 0 1 0 r
F P
0 g
s
.47849 .45926 m .47088 .46646 L .45928 .45969 L p 0 1 0 r
F P
0 g
s
.31316 .41357 m .32022 .40505 L .33218 .41068 L p 0 0 1 r
F P
0 g
s
.32022 .40505 m .31316 .41357 L .30118 .40796 L p 0 0 1 r
F P
0 g
s
.29737 .45245 m .29024 .46254 L .2781 .45824 L p 1 0 0 r
F P
0 g
s
.41306 .41324 m .42047 .40472 L .43219 .41035 L p 0 0 1 r
F P
0 g
s
.42047 .40472 m .41306 .41324 L .4013 .40762 L p 0 0 1 r
F P
0 g
s
.46302 .41307 m .4706 .40455 L .48221 .41018 L p 0 0 1 r
F P
0 g
s
.4706 .40455 m .46302 .41307 L .45138 .40745 L p 0 0 1 r
F P
0 g
s
.3436 .42388 m .351 .41171 L .36308 .41386 L p 1 0 0 r
F P
0 g
s
.51298 .4129 m .52074 .40438 L .53224 .41001 L p 0 0 1 r
F P
0 g
s
.52074 .40438 m .51298 .4129 L .50145 .40729 L p 0 0 1 r
F P
0 g
s
.59292 .20749 m .59295 .20757 L p .57521 .24409 L 0 1 0 r
F P
0 g
s
.59295 .20757 m .58599 .23555 L .57521 .24409 L p 0 1 0 r
F P
0 g
s
.31677 .4448 m .32408 .43336 L .33623 .43583 L p 1 0 0 r
F P
0 g
s
.3436 .42388 m .33623 .43583 L .32408 .43336 L p 1 0 0 r
F P
0 g
s
.58246 .21713 m .59289 .20738 L .59292 .20749 L p 0 1 0 r
F P
0 g
s
.57521 .24409 m .58246 .21713 L p .59292 .20749 L 0 1 0 r
F P
0 g
s
.14072 .60454 m .13863 .61099 L .13804 .60955 L p 0 1 0 r
F P
0 g
s
.13804 .60955 m .13722 .60808 L .14072 .60454 L p 0 1 0 r
F P
0 g
s
.14072 .60454 m .13722 .60808 L .13511 .60303 L p 0 1 0 r
F P
0 g
s
.61293 .41257 m .62104 .40405 L .63231 .40968 L p 0 0 1 r
F P
0 g
s
.62104 .40405 m .61293 .41257 L .60163 .40695 L p 0 0 1 r
F P
0 g
s
.58986 .20005 m .59289 .20738 L .58246 .21713 L p 0 1 0 r
F P
0 g
s
.66292 .4124 m .6712 .40388 L .68236 .40951 L p 0 0 1 r
F P
0 g
s
.6712 .40388 m .66292 .4124 L .65173 .40678 L p 0 0 1 r
F P
0 g
s
.3974 .37963 m .40489 .36778 L .41673 .37088 L p 1 0 0 r
F P
0 g
s
.42423 .35968 m .41673 .37088 L .40489 .36778 L p 1 0 0 r
F P
0 g
s
.71291 .41224 m .72137 .40371 L .73241 .40934 L p 0 0 1 r
F P
0 g
s
.72137 .40371 m .71291 .41224 L .70184 .40661 L p 0 0 1 r
F P
0 g
s
.41696 .44128 m .42429 .43633 L .43597 .44457 L p 0 1 0 r
F P
0 g
s
.42429 .43633 m .41696 .44128 L .40532 .43245 L p 0 1 0 r
F P
0 g
s
.76291 .41207 m .77155 .40354 L .78247 .40918 L p 0 0 1 r
F P
0 g
s
.77155 .40354 m .76291 .41207 L .75195 .40645 L p 0 0 1 r
F P
0 g
s
.16703 .44292 m .15883 .46314 L .14463 .46991 L p 0 1 0 r
F P
0 g
s
.14463 .46991 m .15315 .44798 L .16703 .44292 L p 0 1 0 r
F P
0 g
s
.81292 .4119 m .82173 .40337 L .83254 .40901 L p 0 0 1 r
F P
0 g
s
.82173 .40337 m .81292 .4119 L .80208 .40628 L p 0 0 1 r
F P
0 g
s
.47435 .3547 m .48198 .34685 L .49358 .3542 L p 1 0 0 r
F P
0 g
s
.48198 .34685 m .47435 .3547 L .46273 .34875 L p 1 0 0 r
F P
0 g
s
.86293 .41173 m .87192 .4032 L .88261 .40884 L p 0 0 1 r
F P
0 g
s
.87192 .4032 m .86293 .41173 L .8522 .40611 L p 0 0 1 r
F P
0 g
s
.91295 .41157 m .92211 .40304 L .93269 .40867 L p 0 0 1 r
F P
0 g
s
.92211 .40304 m .91295 .41157 L .90234 .40594 L p 0 0 1 r
F P
0 g
s
.50932 .46016 m .51705 .44975 L .52851 .45203 L p 0 1 0 r
F P
0 g
s
.53623 .43958 m .52851 .45203 L .51705 .44975 L p 0 1 0 r
F P
0 g
s
.52456 .3668 m .51671 .37117 L .50515 .36228 L p 1 0 0 r
F P
0 g
s
.23219 .41102 m .23897 .40248 L .25113 .40812 L p 0 0 1 r
F P
0 g
s
.23897 .40248 m .23219 .41102 L .22 .40539 L p 0 0 1 r
F P
0 g
s
.28218 .41085 m .28914 .40231 L .30118 .40796 L p 0 0 1 r
F P
0 g
s
.28914 .40231 m .28218 .41085 L .27011 .40522 L p 0 0 1 r
F P
0 g
s
.22845 .4545 m .23495 .44862 L .24699 .45551 L p 1 0 0 r
F P
0 g
s
.23495 .44862 m .22845 .4545 L .21662 .44596 L p 1 0 0 r
F P
0 g
s
.18484 .37575 m .19229 .36106 L .20507 .36284 L p 0 1 0 r
F P
0 g
s
.21223 .3504 m .20507 .36284 L .19229 .36106 L p 0 1 0 r
F P
0 g
s
.33218 .41068 m .33931 .40215 L .35124 .40779 L p 0 0 1 r
F P
0 g
s
.33931 .40215 m .33218 .41068 L .32022 .40505 L p 0 0 1 r
F P
0 g
s
.14415 .56324 m .1349 .59059 L p .12865 .58995 L 0 1 0 r
F P
0 g
s
.12865 .58995 m .12606 .58543 L p .14415 .56324 L 0 1 0 r
F P
0 g
s
.12606 .58543 m .12903 .57635 L .14415 .56324 L p 0 1 0 r
F P
0 g
s
.43219 .41035 m .43968 .40181 L .45138 .40745 L p 0 0 1 r
F P
0 g
s
.43968 .40181 m .43219 .41035 L .42047 .40472 L p 0 0 1 r
F P
0 g
s
.66014 .60248 m .66168 .60568 L .6623 .61149 L p 1 0 0 r
F P
0 g
s
.26267 .34672 m .26944 .33926 L .28135 .34702 L p 0 1 0 r
F P
0 g
s
.26944 .33926 m .26267 .34672 L .25065 .34006 L p 0 1 0 r
F P
0 g
s
.48221 .41018 m .48987 .40164 L .50145 .40729 L p 0 0 1 r
F P
0 g
s
.48987 .40164 m .48221 .41018 L .4706 .40455 L p 0 0 1 r
F P
0 g
s
.54008 .40147 m .53224 .41001 L .52074 .40438 L p 0 0 1 r
F P
0 g
s
.40532 .43245 m .41259 .42774 L .42429 .43633 L p 0 1 0 r
F P
0 g
s
.41259 .42774 m .40532 .43245 L .39367 .42338 L p 0 1 0 r
F P
0 g
s
.58575 .29622 m .57842 .31964 L .56743 .3253 L p 0 1 0 r
F P
0 g
s
.56743 .3253 m .57492 .30319 L .58575 .29622 L p 0 1 0 r
F P
0 g
s
.58227 .40985 m .59028 .4013 L .60163 .40695 L p 0 0 1 r
F P
0 g
s
.59028 .4013 m .58227 .40985 L .57089 .40421 L p 0 0 1 r
F P
0 g
s
.63231 .40968 m .6405 .40113 L .65173 .40678 L p 0 0 1 r
F P
0 g
s
.6405 .40113 m .63231 .40968 L .62104 .40405 L p 0 0 1 r
F P
0 g
s
.49009 .46479 m .49777 .45613 L .50932 .46016 L p 0 1 0 r
F P
0 g
s
.49777 .45613 m .49009 .46479 L .47849 .45926 L p 0 1 0 r
F P
0 g
s
.68236 .40951 m .69072 .40097 L .70184 .40661 L p 0 0 1 r
F P
0 g
s
.69072 .40097 m .68236 .40951 L .6712 .40388 L p 0 0 1 r
F P
0 g
s
.45928 .45969 m .46685 .45306 L .47849 .45926 L p 0 1 0 r
F P
0 g
s
.46685 .45306 m .45928 .45969 L .44764 .45237 L p 0 1 0 r
F P
0 g
s
.73241 .40934 m .74095 .4008 L .75195 .40645 L p 0 0 1 r
F P
0 g
s
.74095 .4008 m .73241 .40934 L .72137 .40371 L p 0 0 1 r
F P
0 g
s
.58948 .25349 m .58228 .27927 L .57138 .28635 L p 0 1 0 r
F P
0 g
s
.57138 .28635 m .57877 .2619 L .58948 .25349 L p 0 1 0 r
F P
0 g
s
.50515 .36228 m .51294 .35695 L .52456 .3668 L p 1 0 0 r
F P
0 g
s
.51294 .35695 m .50515 .36228 L .49358 .3542 L p 1 0 0 r
F P
0 g
s
.78247 .40918 m .79118 .40063 L .80208 .40628 L p 0 0 1 r
F P
0 g
s
.79118 .40063 m .78247 .40918 L .77155 .40354 L p 0 0 1 r
F P
0 g
s
.31176 .35817 m .30497 .36365 L .29319 .35516 L p 0 1 0 r
F P
0 g
s
.83254 .40901 m .84143 .40046 L .8522 .40611 L p 0 0 1 r
F P
0 g
s
.84143 .40046 m .83254 .40901 L .82173 .40337 L p 0 0 1 r
F P
0 g
s
.29737 .45245 m .30458 .44178 L .31677 .4448 L p 1 0 0 r
F P
0 g
s
.32408 .43336 m .31677 .4448 L .30458 .44178 L p 1 0 0 r
F P
0 g
s
.58324 .43186 m .57479 .43025 L .56308 .4162 L p 1 0 0 r
F P
0 g
s
.56308 .4162 m .57136 .41645 L .58324 .43186 L p 1 0 0 r
F P
0 g
s
.88261 .40884 m .89167 .40029 L .90234 .40594 L p 0 0 1 r
F P
0 g
s
.89167 .40029 m .88261 .40884 L .87192 .4032 L p 0 0 1 r
F P
0 g
s
.40489 .36778 m .3974 .37963 L .38545 .37704 L p 1 0 0 r
F P
0 g
s
.25905 .46167 m .26593 .45338 L .2781 .45824 L p 1 0 0 r
F P
0 g
s
.26593 .45338 m .25905 .46167 L .24699 .45551 L p 1 0 0 r
F P
0 g
s
.51705 .44975 m .50932 .46016 L .49777 .45613 L p 0 1 0 r
F P
0 g
s
.21662 .44596 m .22296 .44096 L .23495 .44862 L p 1 0 0 r
F P
0 g
s
.22296 .44096 m .21662 .44596 L .20487 .43654 L p 1 0 0 r
F P
0 g
s
.20108 .40829 m .20777 .39974 L .22 .40539 L p 0 0 1 r
F P
0 g
s
.20777 .39974 m .20108 .40829 L .18881 .40265 L p 0 0 1 r
F P
0 g
s
.62284 .50073 m .61381 .49446 L .6018 .47613 L p 1 0 0 r
F P
0 g
s
.6018 .47613 m .6106 .48073 L .62284 .50073 L p 1 0 0 r
F P
0 g
s
.39367 .42338 m .40088 .41884 L .41259 .42774 L p 0 1 0 r
F P
0 g
s
.40088 .41884 m .39367 .42338 L .38202 .41414 L p 0 1 0 r
F P
0 g
s
.25113 .40812 m .25799 .39957 L .27011 .40522 L p 0 0 1 r
F P
0 g
s
.25799 .39957 m .25113 .40812 L .23897 .40248 L p 0 0 1 r
F P
0 g
s
.32408 .43336 m .33143 .42156 L .3436 .42388 L p 1 0 0 r
F P
0 g
s
.351 .41171 m .3436 .42388 L .33143 .42156 L p 1 0 0 r
F P
0 g
s
.30118 .40796 m .30821 .3994 L .32022 .40505 L p 0 0 1 r
F P
0 g
s
.30821 .3994 m .30118 .40796 L .28914 .40231 L p 0 0 1 r
F P
0 g
s
.21223 .3504 m .21929 .33898 L .23163 .3436 L p 0 1 0 r
F P
0 g
s
.23163 .3436 m .23852 .33397 L .25065 .34006 L p 0 1 0 r
F P
0 g
s
.23852 .33397 m .23163 .3436 L .21929 .33898 L p 0 1 0 r
F P
0 g
s
.15883 .46314 m .15036 .48501 L .13582 .49362 L p 0 1 0 r
F P
0 g
s
.13582 .49362 m .14463 .46991 L .15883 .46314 L p 0 1 0 r
F P
0 g
s
.42423 .35968 m .43175 .34885 L .4435 .35318 L p 1 0 0 r
F P
0 g
s
.4435 .35318 m .45105 .34335 L .46273 .34875 L p 1 0 0 r
F P
0 g
s
.45105 .34335 m .4435 .35318 L .43175 .34885 L p 1 0 0 r
F P
0 g
s
.4013 .40762 m .40869 .39906 L .42047 .40472 L p 0 0 1 r
F P
0 g
s
.40869 .39906 m .4013 .40762 L .38949 .40198 L p 0 0 1 r
F P
0 g
s
.45138 .40745 m .45894 .39889 L .4706 .40455 L p 0 0 1 r
F P
0 g
s
.45894 .39889 m .45138 .40745 L .43968 .40181 L p 0 0 1 r
F P
0 g
s
.50145 .40729 m .50919 .39872 L .52074 .40438 L p 0 0 1 r
F P
0 g
s
.50919 .39872 m .50145 .40729 L .48987 .40164 L p 0 0 1 r
F P
0 g
s
.51705 .44975 m .52481 .43825 L .53623 .43958 L p 0 1 0 r
F P
0 g
s
.54395 .42589 m .53623 .43958 L .52481 .43825 L p 0 1 0 r
F P
0 g
s
.19919 .4231 m .19322 .4262 L .1817 .41489 L p 1 0 0 r
F P
0 g
s
.1817 .41489 m .18746 .41282 L .19919 .4231 L p 1 0 0 r
F P
0 g
s
.14737 .52341 m .13837 .54886 L .12313 .5618 L p 0 1 0 r
F P
0 g
s
.12313 .5618 m .13255 .5342 L .14737 .52341 L p 0 1 0 r
F P
0 g
s
.20487 .43654 m .21104 .43247 L .22296 .44096 L p 1 0 0 r
F P
0 g
s
.21104 .43247 m .20487 .43654 L .19322 .4262 L p 1 0 0 r
F P
0 g
s
.60163 .40695 m .60972 .39839 L .62104 .40405 L p 0 0 1 r
F P
0 g
s
.60972 .39839 m .60163 .40695 L .59028 .4013 L p 0 0 1 r
F P
0 g
s
.65173 .40678 m .66 .39822 L .6712 .40388 L p 0 0 1 r
F P
0 g
s
.66 .39822 m .65173 .40678 L .6405 .40113 L p 0 0 1 r
F P
0 g
s
.2781 .45824 m .28516 .44863 L .29737 .45245 L p 1 0 0 r
F P
0 g
s
.30458 .44178 m .29737 .45245 L .28516 .44863 L p 1 0 0 r
F P
0 g
s
.70184 .40661 m .71028 .39805 L .72137 .40371 L p 0 0 1 r
F P
0 g
s
.71028 .39805 m .70184 .40661 L .69072 .40097 L p 0 0 1 r
F P
0 g
s
.40489 .36778 m .41239 .35618 L .42423 .35968 L p 1 0 0 r
F P
0 g
s
.43175 .34885 m .42423 .35968 L .41239 .35618 L p 1 0 0 r
F P
0 g
s
.38202 .41414 m .38916 .4097 L .40088 .41884 L p 0 1 0 r
F P
0 g
s
.29319 .35516 m .29996 .34929 L .31176 .35817 L p 0 1 0 r
F P
0 g
s
.29996 .34929 m .29319 .35516 L .28135 .34702 L p 0 1 0 r
F P
0 g
s
.19322 .4262 m .19919 .4231 L .21104 .43247 L p 1 0 0 r
F P
0 g
s
.46273 .34875 m .47033 .34017 L .48198 .34685 L p 1 0 0 r
F P
0 g
s
.47033 .34017 m .46273 .34875 L .45105 .34335 L p 1 0 0 r
F P
0 g
s
.75195 .40645 m .76057 .39788 L .77155 .40354 L p 0 0 1 r
F P
0 g
s
.76057 .39788 m .75195 .40645 L .74095 .4008 L p 0 0 1 r
F P
0 g
s
.28516 .44863 m .2781 .45824 L .26593 .45338 L p 1 0 0 r
F P
0 g
s
.19229 .36106 m .19959 .34754 L .21223 .3504 L p 0 1 0 r
F P
0 g
s
.21929 .33898 m .21223 .3504 L .19959 .34754 L p 0 1 0 r
F P
0 g
s
.65748 .5851 m .65889 .59049 L p .64456 .56418 L 1 0 0 r
F P
0 g
s
.65889 .59049 m .65712 .58831 L .64456 .56418 L p 1 0 0 r
F P
0 g
s
.64456 .56418 m .65408 .57424 L p .65748 .5851 L 1 0 0 r
F P
0 g
s
.80208 .40628 m .81087 .39771 L .82173 .40337 L p 0 0 1 r
F P
0 g
s
.81087 .39771 m .80208 .40628 L .79118 .40063 L p 0 0 1 r
F P
0 g
s
.49358 .3542 m .50131 .34795 L .51294 .35695 L p 1 0 0 r
F P
0 g
s
.50131 .34795 m .49358 .3542 L .48198 .34685 L p 1 0 0 r
F P
0 g
s
.8522 .40611 m .86117 .39754 L .87192 .4032 L p 0 0 1 r
F P
0 g
s
.86117 .39754 m .8522 .40611 L .84143 .40046 L p 0 0 1 r
F P
0 g
s
.90234 .40594 m .91148 .39737 L .92211 .40304 L p 0 0 1 r
F P
0 g
s
.91148 .39737 m .90234 .40594 L .89167 .40029 L p 0 0 1 r
F P
0 g
s
.66149 .6049 m .66168 .60568 L .66014 .60248 L p 1 0 0 r
F P
0 g
s
.66014 .60248 m .66139 .60404 L .66149 .6049 L p 1 0 0 r
F P
0 g
s
.58246 .21713 m .58811 .19395 L .58986 .20005 L p 0 1 0 r
F P
0 g
s
.44764 .45237 m .45516 .44624 L .46685 .45306 L p 0 1 0 r
F P
0 g
s
.45516 .44624 m .44764 .45237 L .43597 .44457 L p 0 1 0 r
F P
0 g
s
.25065 .34006 m .25745 .33195 L .26944 .33926 L p 0 1 0 r
F P
0 g
s
.25745 .33195 m .25065 .34006 L .23852 .33397 L p 0 1 0 r
F P
0 g
s
.22 .40539 m .22676 .39682 L .23897 .40248 L p 0 0 1 r
F P
0 g
s
.22676 .39682 m .22 .40539 L .20777 .39974 L p 0 0 1 r
F P
0 g
s
.59522 .44867 m .5866 .44562 L .57479 .43025 L p 1 0 0 r
F P
0 g
s
.57479 .43025 m .58324 .43186 L .59522 .44867 L p 1 0 0 r
F P
0 g
s
.27011 .40522 m .27705 .39665 L .28914 .40231 L p 0 0 1 r
F P
0 g
s
.27705 .39665 m .27011 .40522 L .25799 .39957 L p 0 0 1 r
F P
0 g
s
.32022 .40505 m .32733 .39648 L .33931 .40215 L p 0 0 1 r
F P
0 g
s
.32733 .39648 m .32022 .40505 L .30821 .3994 L p 0 0 1 r
F P
0 g
s
.42047 .40472 m .42793 .39614 L .43968 .40181 L p 0 0 1 r
F P
0 g
s
.42793 .39614 m .42047 .40472 L .40869 .39906 L p 0 0 1 r
F P
0 g
s
.4706 .40455 m .47824 .39597 L .48987 .40164 L p 0 0 1 r
F P
0 g
s
.47824 .39597 m .4706 .40455 L .45894 .39889 L p 0 0 1 r
F P
0 g
s
.52481 .43825 m .53257 .42558 L .54395 .42589 L p 0 1 0 r
F P
0 g
s
.55165 .41086 m .54395 .42589 L .53257 .42558 L p 0 1 0 r
F P
0 g
s
.65103 .56026 m .64149 .55024 L .62914 .52829 L p 1 0 0 r
F P
0 g
s
.62914 .52829 m .6384 .53637 L .65103 .56026 L p 1 0 0 r
F P
0 g
s
.52074 .40438 m .52856 .3958 L .54008 .40147 L p 0 0 1 r
F P
0 g
s
.52856 .3958 m .52074 .40438 L .50919 .39872 L p 0 0 1 r
F P
0 g
s
.57089 .40421 m .57888 .39563 L .59028 .4013 L p 0 0 1 r
F P
0 g
s
.62104 .40405 m .62921 .39546 L .6405 .40113 L p 0 0 1 r
F P
0 g
s
.62921 .39546 m .62104 .40405 L .60972 .39839 L p 0 0 1 r
F P
0 g
s
.47849 .45926 m .48616 .45131 L .49777 .45613 L p 0 1 0 r
F P
0 g
s
.48616 .45131 m .47849 .45926 L .46685 .45306 L p 0 1 0 r
F P
0 g
s
.6712 .40388 m .67955 .39529 L .69072 .40097 L p 0 0 1 r
F P
0 g
s
.67955 .39529 m .6712 .40388 L .66 .39822 L p 0 0 1 r
F P
0 g
s
.38545 .37704 m .39295 .36492 L .40489 .36778 L p 1 0 0 r
F P
0 g
s
.41239 .35618 m .40489 .36778 L .39295 .36492 L p 1 0 0 r
F P
0 g
s
.24699 .45551 m .25376 .44791 L .26593 .45338 L p 1 0 0 r
F P
0 g
s
.25376 .44791 m .24699 .45551 L .23495 .44862 L p 1 0 0 r
F P
0 g
s
.72137 .40371 m .72989 .39512 L .74095 .4008 L p 0 0 1 r
F P
0 g
s
.72989 .39512 m .72137 .40371 L .71028 .39805 L p 0 0 1 r
F P
0 g
s
.30458 .44178 m .31185 .43062 L .32408 .43336 L p 1 0 0 r
F P
0 g
s
.33143 .42156 m .32408 .43336 L .31185 .43062 L p 1 0 0 r
F P
0 g
s
.28135 .34702 m .28811 .34068 L .29996 .34929 L p 0 1 0 r
F P
0 g
s
.28811 .34068 m .28135 .34702 L .26944 .33926 L p 0 1 0 r
F P
0 g
s
.77155 .40354 m .78024 .39495 L .79118 .40063 L p 0 0 1 r
F P
0 g
s
.78024 .39495 m .77155 .40354 L .76057 .39788 L p 0 0 1 r
F P
0 g
s
.33143 .42156 m .33883 .40947 L .351 .41171 L p 1 0 0 r
F P
0 g
s
.35844 .39939 m .351 .41171 L .33883 .40947 L p 1 0 0 r
F P
0 g
s
.82173 .40337 m .8306 .39478 L .84143 .40046 L p 0 0 1 r
F P
0 g
s
.8306 .39478 m .82173 .40337 L .81087 .39771 L p 0 0 1 r
F P
0 g
s
.87192 .4032 m .88096 .39461 L .89167 .40029 L p 0 0 1 r
F P
0 g
s
.88096 .39461 m .87192 .4032 L .86117 .39754 L p 0 0 1 r
F P
0 g
s
.53257 .42558 m .54033 .41163 L .55165 .41086 L p 0 1 0 r
F P
0 g
s
.18881 .40265 m .19547 .39406 L .20777 .39974 L p 0 0 1 r
F P
0 g
s
.43597 .44457 m .44345 .43888 L .45516 .44624 L p 0 1 0 r
F P
0 g
s
.44345 .43888 m .43597 .44457 L .42429 .43633 L p 0 1 0 r
F P
0 g
s
.23897 .40248 m .24581 .39389 L .25799 .39957 L p 0 0 1 r
F P
0 g
s
.24581 .39389 m .23897 .40248 L .22676 .39682 L p 0 0 1 r
F P
0 g
s
.19229 .36106 m .18484 .37575 L .17162 .3762 L p 0 1 0 r
F P
0 g
s
.48198 .34685 m .48967 .33975 L .50131 .34795 L p 1 0 0 r
F P
0 g
s
.48967 .33975 m .48198 .34685 L .47033 .34017 L p 1 0 0 r
F P
0 g
s
.28914 .40231 m .29615 .39372 L .30821 .3994 L p 0 0 1 r
F P
0 g
s
.29615 .39372 m .28914 .40231 L .27705 .39665 L p 0 0 1 r
F P
0 g
s
.49777 .45613 m .50551 .44655 L .51705 .44975 L p 0 1 0 r
F P
0 g
s
.52481 .43825 m .51705 .44975 L .50551 .44655 L p 0 1 0 r
F P
0 g
s
.38949 .40198 m .39686 .39338 L .40869 .39906 L p 0 0 1 r
F P
0 g
s
.39686 .39338 m .38949 .40198 L .37763 .39631 L p 0 0 1 r
F P
0 g
s
.43968 .40181 m .44722 .39321 L .45894 .39889 L p 0 0 1 r
F P
0 g
s
.44722 .39321 m .43968 .40181 L .42793 .39614 L p 0 0 1 r
F P
0 g
s
.15036 .48501 m .14162 .50865 L .12668 .51925 L p 0 1 0 r
F P
0 g
s
.12668 .51925 m .13582 .49362 L .15036 .48501 L p 0 1 0 r
F P
0 g
s
.16942 .40898 m .16141 .42771 L .14743 .43256 L p 0 1 0 r
F P
0 g
s
.14743 .43256 m .15573 .41226 L .16942 .40898 L p 0 1 0 r
F P
0 g
s
.57842 .31964 m .57096 .34128 L .55984 .34567 L p 0 1 0 r
F P
0 g
s
.55984 .34567 m .56743 .3253 L .57842 .31964 L p 0 1 0 r
F P
0 g
s
.48987 .40164 m .49759 .39304 L .50919 .39872 L p 0 0 1 r
F P
0 g
s
.49759 .39304 m .48987 .40164 L .47824 .39597 L p 0 0 1 r
F P
0 g
s
.50551 .44655 m .49777 .45613 L .48616 .45131 L p 0 1 0 r
F P
0 g
s
.59028 .4013 m .59835 .3927 L .60972 .39839 L p 0 0 1 r
F P
0 g
s
.59835 .3927 m .59028 .4013 L .57888 .39563 L p 0 0 1 r
F P
0 g
s
.6405 .40113 m .64874 .39253 L .66 .39822 L p 0 0 1 r
F P
0 g
s
.64874 .39253 m .6405 .40113 L .62921 .39546 L p 0 0 1 r
F P
0 g
s
.69072 .40097 m .69914 .39236 L .71028 .39805 L p 0 0 1 r
F P
0 g
s
.69914 .39236 m .69072 .40097 L .67955 .39529 L p 0 0 1 r
F P
0 g
s
.19959 .34754 m .20677 .33511 L .21929 .33898 L p 0 1 0 r
F P
0 g
s
.21929 .33898 m .22626 .32849 L .23852 .33397 L p 0 1 0 r
F P
0 g
s
.22626 .32849 m .21929 .33898 L .20677 .33511 L p 0 1 0 r
F P
0 g
s
.74095 .4008 m .74955 .39219 L .76057 .39788 L p 0 0 1 r
F P
0 g
s
.74955 .39219 m .74095 .4008 L .72989 .39512 L p 0 0 1 r
F P
0 g
s
.79118 .40063 m .79996 .39202 L .81087 .39771 L p 0 0 1 r
F P
0 g
s
.79996 .39202 m .79118 .40063 L .78024 .39495 L p 0 0 1 r
F P
0 g
s
.17162 .3762 m .17927 .36026 L .19229 .36106 L p 0 1 0 r
F P
0 g
s
.19959 .34754 m .19229 .36106 L .17927 .36026 L p 0 1 0 r
F P
0 g
s
.28516 .44863 m .29232 .43838 L .30458 .44178 L p 1 0 0 r
F P
0 g
s
.31185 .43062 m .30458 .44178 L .29232 .43838 L p 1 0 0 r
F P
0 g
s
.84143 .40046 m .85038 .39185 L .86117 .39754 L p 0 0 1 r
F P
0 g
s
.85038 .39185 m .84143 .40046 L .8306 .39478 L p 0 0 1 r
F P
0 g
s
.41239 .35618 m .41992 .3449 L .43175 .34885 L p 1 0 0 r
F P
0 g
s
.43175 .34885 m .4393 .33846 L .45105 .34335 L p 1 0 0 r
F P
0 g
s
.4393 .33846 m .43175 .34885 L .41992 .3449 L p 1 0 0 r
F P
0 g
s
.45105 .34335 m .45864 .3341 L .47033 .34017 L p 1 0 0 r
F P
0 g
s
.45864 .3341 m .45105 .34335 L .4393 .33846 L p 1 0 0 r
F P
0 g
s
.60735 .46701 m .59853 .4624 L .5866 .44562 L p 1 0 0 r
F P
0 g
s
.5866 .44562 m .59522 .44867 L .60735 .46701 L p 1 0 0 r
F P
0 g
s
.89167 .40029 m .9008 .39168 L .91148 .39737 L p 0 0 1 r
F P
0 g
s
.9008 .39168 m .89167 .40029 L .88096 .39461 L p 0 0 1 r
F P
0 g
s
.23852 .33397 m .24536 .32514 L .25745 .33195 L p 0 1 0 r
F P
0 g
s
.24536 .32514 m .23852 .33397 L .22626 .32849 L p 0 1 0 r
F P
0 g
s
.58749 .19246 m .58811 .19395 L p .5716 .22583 L 0 1 0 r
F P
0 g
s
.58811 .19395 m .58246 .21713 L .5716 .22583 L p 0 1 0 r
F P
0 g
s
.26944 .33926 m .2762 .3324 L .28811 .34068 L p 0 1 0 r
F P
0 g
s
.2762 .3324 m .26944 .33926 L .25745 .33195 L p 0 1 0 r
F P
0 g
s
.63528 .52256 m .626 .51449 L .61381 .49446 L p 1 0 0 r
F P
0 g
s
.61381 .49446 m .62284 .50073 L .63528 .52256 L p 1 0 0 r
F P
0 g
s
.26593 .45338 m .27293 .44432 L .28516 .44863 L p 1 0 0 r
F P
0 g
s
.27293 .44432 m .26593 .45338 L .25376 .44791 L p 1 0 0 r
F P
0 g
s
.42429 .43633 m .43171 .43102 L .44345 .43888 L p 0 1 0 r
F P
0 g
s
.43171 .43102 m .42429 .43633 L .41259 .42774 L p 0 1 0 r
F P
0 g
s
.20777 .39974 m .2145 .39112 L .22676 .39682 L p 0 0 1 r
F P
0 g
s
.2145 .39112 m .20777 .39974 L .19547 .39406 L p 0 0 1 r
F P
0 g
s
.25799 .39957 m .2649 .39095 L .27705 .39665 L p 0 0 1 r
F P
0 g
s
.2649 .39095 m .25799 .39957 L .24581 .39389 L p 0 0 1 r
F P
0 g
s
.23495 .44862 m .24161 .44176 L .25376 .44791 L p 1 0 0 r
F P
0 g
s
.24161 .44176 m .23495 .44862 L .22296 .44096 L p 1 0 0 r
F P
0 g
s
.30821 .3994 m .3153 .39078 L .32733 .39648 L p 0 0 1 r
F P
0 g
s
.3153 .39078 m .30821 .3994 L .29615 .39372 L p 0 0 1 r
F P
0 g
s
.1349 .59059 m .1324 .59825 L .13168 .59654 L p 0 1 0 r
F P
0 g
s
.13168 .59654 m .13069 .59477 L .1349 .59059 L p 0 1 0 r
F P
0 g
s
.1349 .59059 m .13069 .59477 L .12865 .58995 L p 0 1 0 r
F P
0 g
s
.16141 .42771 m .15315 .44798 L .13886 .45453 L p 0 1 0 r
F P
0 g
s
.13886 .45453 m .14743 .43256 L .16141 .42771 L p 0 1 0 r
F P
0 g
s
.29232 .43838 m .28516 .44863 L .27293 .44432 L p 1 0 0 r
F P
0 g
s
.40869 .39906 m .41613 .39044 L .42793 .39614 L p 0 0 1 r
F P
0 g
s
.41613 .39044 m .40869 .39906 L .39686 .39338 L p 0 0 1 r
F P
0 g
s
.33883 .40947 m .34627 .39717 L .35844 .39939 L p 1 0 0 r
F P
0 g
s
.46685 .45306 m .47448 .44575 L .48616 .45131 L p 0 1 0 r
F P
0 g
s
.47448 .44575 m .46685 .45306 L .45516 .44624 L p 0 1 0 r
F P
0 g
s
.45894 .39889 m .46655 .39027 L .47824 .39597 L p 0 0 1 r
F P
0 g
s
.46655 .39027 m .45894 .39889 L .44722 .39321 L p 0 0 1 r
F P
0 g
s
.57888 .19823 m .58696 .1906 L .58749 .19246 L p 0 1 0 r
F P
0 g
s
.5716 .22583 m .57888 .19823 L p .58749 .19246 L 0 1 0 r
F P
0 g
s
.31185 .43062 m .31919 .41903 L .33143 .42156 L p 1 0 0 r
F P
0 g
s
.33883 .40947 m .33143 .42156 L .31919 .41903 L p 1 0 0 r
F P
0 g
s
.50919 .39872 m .51698 .3901 L .52856 .3958 L p 0 0 1 r
F P
0 g
s
.51698 .3901 m .50919 .39872 L .49759 .39304 L p 0 0 1 r
F P
0 g
s
.58599 .23555 m .57877 .2619 L .5678 .26911 L p 0 1 0 r
F P
0 g
s
.5678 .26911 m .57521 .24409 L .58599 .23555 L p 0 1 0 r
F P
0 g
s
.39295 .36492 m .40047 .35298 L .41239 .35618 L p 1 0 0 r
F P
0 g
s
.41992 .3449 m .41239 .35618 L .40047 .35298 L p 1 0 0 r
F P
0 g
s
.60972 .39839 m .61787 .38976 L .62921 .39546 L p 0 0 1 r
F P
0 g
s
.61787 .38976 m .60972 .39839 L .59835 .3927 L p 0 0 1 r
F P
0 g
s
.66 .39822 m .66832 .38959 L .67955 .39529 L p 0 0 1 r
F P
0 g
s
.66832 .38959 m .66 .39822 L .64874 .39253 L p 0 0 1 r
F P
0 g
s
.58228 .27927 m .57492 .30319 L .56386 .30896 L p 0 1 0 r
F P
0 g
s
.56386 .30896 m .57138 .28635 L .58228 .27927 L p 0 1 0 r
F P
0 g
s
.71028 .39805 m .71878 .38942 L .72989 .39512 L p 0 0 1 r
F P
0 g
s
.71878 .38942 m .71028 .39805 L .69914 .39236 L p 0 0 1 r
F P
0 g
s
.76057 .39788 m .76925 .38925 L .78024 .39495 L p 0 0 1 r
F P
0 g
s
.76925 .38925 m .76057 .39788 L .74955 .39219 L p 0 0 1 r
F P
0 g
s
.53253 .36349 m .52456 .3668 L .51294 .35695 L p 1 0 0 r
F P
0 g
s
.81087 .39771 m .81972 .38908 L .8306 .39478 L p 0 0 1 r
F P
0 g
s
.81972 .38908 m .81087 .39771 L .79996 .39202 L p 0 0 1 r
F P
0 g
s
.47033 .34017 m .47799 .33228 L .48967 .33975 L p 1 0 0 r
F P
0 g
s
.47799 .33228 m .47033 .34017 L .45864 .3341 L p 1 0 0 r
F P
0 g
s
.86117 .39754 m .8702 .38891 L .88096 .39461 L p 0 0 1 r
F P
0 g
s
.8702 .38891 m .86117 .39754 L .85038 .39185 L p 0 0 1 r
F P
0 g
s
.13837 .54886 m .12903 .57635 L p .12204 .57673 L 0 1 0 r
F P
0 g
s
.12204 .57673 m .1196 .57251 L p .13837 .54886 L 0 1 0 r
F P
0 g
s
.1196 .57251 m .12313 .5618 L .13837 .54886 L p 0 1 0 r
F P
0 g
s
.17927 .36026 m .18674 .34557 L .19959 .34754 L p 0 1 0 r
F P
0 g
s
.20677 .33511 m .19959 .34754 L .18674 .34557 L p 0 1 0 r
F P
0 g
s
.41259 .42774 m .41995 .42273 L .43171 .43102 L p 0 1 0 r
F P
0 g
s
.41995 .42273 m .41259 .42774 L .40088 .41884 L p 0 1 0 r
F P
0 g
s
.58456 .18491 m .58696 .1906 L .57888 .19823 L p 0 1 0 r
F P
0 g
s
.50551 .44655 m .51327 .43596 L .52481 .43825 L p 0 1 0 r
F P
0 g
s
.53257 .42558 m .52481 .43825 L .51327 .43596 L p 0 1 0 r
F P
0 g
s
.22676 .39682 m .23357 .38818 L .24581 .39389 L p 0 0 1 r
F P
0 g
s
.23357 .38818 m .22676 .39682 L .2145 .39112 L p 0 0 1 r
F P
0 g
s
.51294 .35695 m .52082 .35259 L .53253 .36349 L p 1 0 0 r
F P
0 g
s
.52082 .35259 m .51294 .35695 L .50131 .34795 L p 1 0 0 r
F P
0 g
s
.27705 .39665 m .28403 .38801 L .29615 .39372 L p 0 0 1 r
F P
0 g
s
.28403 .38801 m .27705 .39665 L .2649 .39095 L p 0 0 1 r
F P
0 g
s
.33449 .38784 m .32733 .39648 L .3153 .39078 L p 0 0 1 r
F P
0 g
s
.37763 .39631 m .38497 .38767 L .39686 .39338 L p 0 0 1 r
F P
0 g
s
.25745 .33195 m .26422 .3245 L .2762 .3324 L p 0 1 0 r
F P
0 g
s
.26422 .3245 m .25745 .33195 L .24536 .32514 L p 0 1 0 r
F P
0 g
s
.42793 .39614 m .43545 .3875 L .44722 .39321 L p 0 0 1 r
F P
0 g
s
.43545 .3875 m .42793 .39614 L .41613 .39044 L p 0 0 1 r
F P
0 g
s
.22296 .44096 m .22948 .4349 L .24161 .44176 L p 1 0 0 r
F P
0 g
s
.22948 .4349 m .22296 .44096 L .21104 .43247 L p 1 0 0 r
F P
0 g
s
.47824 .39597 m .48593 .38733 L .49759 .39304 L p 0 0 1 r
F P
0 g
s
.48593 .38733 m .47824 .39597 L .46655 .39027 L p 0 0 1 r
F P
0 g
s
.65712 .58831 m .65932 .59284 L .65996 .59836 L p 1 0 0 r
F P
0 g
s
.53643 .38716 m .52856 .3958 L .51698 .3901 L p 0 0 1 r
F P
0 g
s
.57096 .34128 m .5634 .36123 L .55217 .36438 L p 0 1 0 r
F P
0 g
s
.55217 .36438 m .55984 .34567 L .57096 .34128 L p 0 1 0 r
F P
0 g
s
.57888 .39563 m .58693 .38699 L .59835 .3927 L p 0 0 1 r
F P
0 g
s
.58693 .38699 m .57888 .39563 L .56742 .38993 L p 0 0 1 r
F P
0 g
s
.62921 .39546 m .63743 .38682 L .64874 .39253 L p 0 0 1 r
F P
0 g
s
.63743 .38682 m .62921 .39546 L .61787 .38976 L p 0 0 1 r
F P
0 g
s
.67955 .39529 m .68795 .38665 L .69914 .39236 L p 0 0 1 r
F P
0 g
s
.68795 .38665 m .67955 .39529 L .66832 .38959 L p 0 0 1 r
F P
0 g
s
.40088 .41884 m .40818 .41407 L .41995 .42273 L p 0 1 0 r
F P
0 g
s
.40818 .41407 m .40088 .41884 L .38916 .4097 L p 0 1 0 r
F P
0 g
s
.72989 .39512 m .73847 .38648 L .74955 .39219 L p 0 0 1 r
F P
0 g
s
.73847 .38648 m .72989 .39512 L .71878 .38942 L p 0 0 1 r
F P
0 g
s
.78024 .39495 m .789 .3863 L .79996 .39202 L p 0 0 1 r
F P
0 g
s
.789 .3863 m .78024 .39495 L .76925 .38925 L p 0 0 1 r
F P
0 g
s
.29232 .43838 m .29956 .42756 L .31185 .43062 L p 1 0 0 r
F P
0 g
s
.31919 .41903 m .31185 .43062 L .29956 .42756 L p 1 0 0 r
F P
0 g
s
.15315 .44798 m .14463 .46991 L .12999 .4783 L p 0 1 0 r
F P
0 g
s
.12999 .4783 m .13886 .45453 L .15315 .44798 L p 0 1 0 r
F P
0 g
s
.48616 .45131 m .49388 .44251 L .50551 .44655 L p 0 1 0 r
F P
0 g
s
.49388 .44251 m .48616 .45131 L .47448 .44575 L p 0 1 0 r
F P
0 g
s
.40047 .35298 m .39295 .36492 L .38091 .36223 L p 1 0 0 r
F P
0 g
s
.8306 .39478 m .83953 .38613 L .85038 .39185 L p 0 0 1 r
F P
0 g
s
.83953 .38613 m .8306 .39478 L .81972 .38908 L p 0 0 1 r
F P
0 g
s
.50131 .34795 m .50913 .34261 L .52082 .35259 L p 1 0 0 r
F P
0 g
s
.50913 .34261 m .50131 .34795 L .48967 .33975 L p 1 0 0 r
F P
0 g
s
.30675 .34381 m .29996 .34929 L .28811 .34068 L p 0 1 0 r
F P
0 g
s
.45516 .44624 m .46276 .43951 L .47448 .44575 L p 0 1 0 r
F P
0 g
s
.46276 .43951 m .45516 .44624 L .44345 .43888 L p 0 1 0 r
F P
0 g
s
.88096 .39461 m .89007 .38596 L .9008 .39168 L p 0 0 1 r
F P
0 g
s
.89007 .38596 m .88096 .39461 L .8702 .38891 L p 0 0 1 r
F P
0 g
s
.57983 .41807 m .57136 .41645 L .55958 .40233 L p 1 0 0 r
F P
0 g
s
.55958 .40233 m .5679 .4026 L .57983 .41807 L p 1 0 0 r
F P
0 g
s
.25376 .44791 m .26067 .43945 L .27293 .44432 L p 1 0 0 r
F P
0 g
s
.26067 .43945 m .25376 .44791 L .24161 .44176 L p 1 0 0 r
F P
0 g
s
.20677 .33511 m .21384 .3237 L .22626 .32849 L p 0 1 0 r
F P
0 g
s
.22626 .32849 m .23315 .31888 L .24536 .32514 L p 0 1 0 r
F P
0 g
s
.23315 .31888 m .22626 .32849 L .21384 .3237 L p 0 1 0 r
F P
0 g
s
.19547 .39406 m .20218 .3854 L .2145 .39112 L p 0 0 1 r
F P
0 g
s
.20218 .3854 m .19547 .39406 L .18312 .38835 L p 0 0 1 r
F P
0 g
s
.14162 .50865 m .13255 .5342 L .11718 .54695 L p 0 1 0 r
F P
0 g
s
.11718 .54695 m .12668 .51925 L .14162 .50865 L p 0 1 0 r
F P
0 g
s
.31919 .41903 m .32658 .40709 L .33883 .40947 L p 1 0 0 r
F P
0 g
s
.34627 .39717 m .33883 .40947 L .32658 .40709 L p 1 0 0 r
F P
0 g
s
.51327 .43596 m .50551 .44655 L .49388 .44251 L p 0 1 0 r
F P
0 g
s
.24581 .39389 m .25269 .38523 L .2649 .39095 L p 0 0 1 r
F P
0 g
s
.25269 .38523 m .24581 .39389 L .23357 .38818 L p 0 0 1 r
F P
0 g
s
.61964 .48701 m .6106 .48073 L .59853 .4624 L p 1 0 0 r
F P
0 g
s
.59853 .4624 m .60735 .46701 L .61964 .48701 L p 1 0 0 r
F P
0 g
s
.29615 .39372 m .30321 .38506 L .3153 .39078 L p 0 0 1 r
F P
0 g
s
.30321 .38506 m .29615 .39372 L .28403 .38801 L p 0 0 1 r
F P
0 g
s
.41992 .3449 m .42748 .334 L .4393 .33846 L p 1 0 0 r
F P
0 g
s
.4393 .33846 m .44688 .32858 L .45864 .3341 L p 1 0 0 r
F P
0 g
s
.44688 .32858 m .4393 .33846 L .42748 .334 L p 1 0 0 r
F P
0 g
s
.21104 .43247 m .2174 .42727 L .22948 .4349 L p 1 0 0 r
F P
0 g
s
.2174 .42727 m .21104 .43247 L .19919 .4231 L p 1 0 0 r
F P
0 g
s
.38916 .4097 m .39639 .40511 L .40818 .41407 L p 0 1 0 r
F P
0 g
s
.39639 .40511 m .38916 .4097 L .37743 .40037 L p 0 1 0 r
F P
0 g
s
.39686 .39338 m .40427 .38472 L .41613 .39044 L p 0 0 1 r
F P
0 g
s
.40427 .38472 m .39686 .39338 L .38497 .38767 L p 0 0 1 r
F P
0 g
s
.44722 .39321 m .45481 .38455 L .46655 .39027 L p 0 0 1 r
F P
0 g
s
.45481 .38455 m .44722 .39321 L .43545 .3875 L p 0 0 1 r
F P
0 g
s
.49759 .39304 m .50536 .38438 L .51698 .3901 L p 0 0 1 r
F P
0 g
s
.50536 .38438 m .49759 .39304 L .48593 .38733 L p 0 0 1 r
F P
0 g
s
.18674 .34557 m .19406 .33206 L .20677 .33511 L p 0 1 0 r
F P
0 g
s
.21384 .3237 m .20677 .33511 L .19406 .33206 L p 0 1 0 r
F P
0 g
s
.51327 .43596 m .52107 .42426 L .53257 .42558 L p 0 1 0 r
F P
0 g
s
.54033 .41163 m .53257 .42558 L .52107 .42426 L p 0 1 0 r
F P
0 g
s
.65484 .5717 m .65624 .57689 L p .64149 .55024 L 1 0 0 r
F P
0 g
s
.65624 .57689 m .65408 .57424 L .64149 .55024 L p 1 0 0 r
F P
0 g
s
.64149 .55024 m .65103 .56026 L p .65484 .5717 L 1 0 0 r
F P
0 g
s
.59835 .3927 m .60648 .38404 L .61787 .38976 L p 0 0 1 r
F P
0 g
s
.60648 .38404 m .59835 .3927 L .58693 .38699 L p 0 0 1 r
F P
0 g
s
.65904 .59171 m .65932 .59284 L .65712 .58831 L p 1 0 0 r
F P
0 g
s
.65712 .58831 m .65889 .59049 L .65904 .59171 L p 1 0 0 r
F P
0 g
s
.40047 .35298 m .40801 .3413 L .41992 .3449 L p 1 0 0 r
F P
0 g
s
.42748 .334 m .41992 .3449 L .40801 .3413 L p 1 0 0 r
F P
0 g
s
.64874 .39253 m .65704 .38386 L .66832 .38959 L p 0 0 1 r
F P
0 g
s
.65704 .38386 m .64874 .39253 L .63743 .38682 L p 0 0 1 r
F P
0 g
s
.27293 .44432 m .28003 .43454 L .29232 .43838 L p 1 0 0 r
F P
0 g
s
.29956 .42756 m .29232 .43838 L .28003 .43454 L p 1 0 0 r
F P
0 g
s
.69914 .39236 m .70762 .38369 L .71878 .38942 L p 0 0 1 r
F P
0 g
s
.70762 .38369 m .69914 .39236 L .68795 .38665 L p 0 0 1 r
F P
0 g
s
.45864 .3341 m .46627 .32548 L .47799 .33228 L p 1 0 0 r
F P
0 g
s
.46627 .32548 m .45864 .3341 L .44688 .32858 L p 1 0 0 r
F P
0 g
s
.28811 .34068 m .29488 .33481 L .30675 .34381 L p 0 1 0 r
F P
0 g
s
.29488 .33481 m .28811 .34068 L .2762 .3324 L p 0 1 0 r
F P
0 g
s
.74955 .39219 m .7582 .38352 L .76925 .38925 L p 0 0 1 r
F P
0 g
s
.7582 .38352 m .74955 .39219 L .73847 .38648 L p 0 0 1 r
F P
0 g
s
.28003 .43454 m .27293 .44432 L .26067 .43945 L p 1 0 0 r
F P
0 g
s
.79996 .39202 m .80879 .38335 L .81972 .38908 L p 0 0 1 r
F P
0 g
s
.80879 .38335 m .79996 .39202 L .789 .3863 L p 0 0 1 r
F P
0 g
s
.19919 .4231 m .20538 .41882 L .2174 .42727 L p 1 0 0 r
F P
0 g
s
.20538 .41882 m .19919 .4231 L .18746 .41282 L p 1 0 0 r
F P
0 g
s
.19345 .40951 m .18746 .41282 L .17585 .40159 L p 1 0 0 r
F P
0 g
s
.17585 .40159 m .18162 .39931 L .19345 .40951 L p 1 0 0 r
F P
0 g
s
.85038 .39185 m .85939 .38318 L .8702 .38891 L p 0 0 1 r
F P
0 g
s
.85939 .38318 m .85038 .39185 L .83953 .38613 L p 0 0 1 r
F P
0 g
s
.57888 .19823 m .58317 .18025 L .58456 .18491 L p 0 1 0 r
F P
0 g
s
.48967 .33975 m .49743 .3335 L .50913 .34261 L p 1 0 0 r
F P
0 g
s
.49743 .3335 m .48967 .33975 L .47799 .33228 L p 1 0 0 r
F P
0 g
s
.37743 .40037 m .3846 .3959 L .39639 .40511 L p 0 1 0 r
F P
0 g
s
.3846 .3959 m .37743 .40037 L .36569 .39092 L p 0 1 0 r
F P
0 g
s
.24536 .32514 m .25216 .31704 L .26422 .3245 L p 0 1 0 r
F P
0 g
s
.25216 .31704 m .24536 .32514 L .23315 .31888 L p 0 1 0 r
F P
0 g
s
.18746 .41282 m .19345 .40951 L .20538 .41882 L p 1 0 0 r
F P
0 g
s
.2145 .39112 m .22128 .38245 L .23357 .38818 L p 0 0 1 r
F P
0 g
s
.22128 .38245 m .2145 .39112 L .20218 .3854 L p 0 0 1 r
F P
0 g
s
.2649 .39095 m .27185 .38228 L .28403 .38801 L p 0 0 1 r
F P
0 g
s
.27185 .38228 m .2649 .39095 L .25269 .38523 L p 0 0 1 r
F P
0 g
s
.44345 .43888 m .451 .43266 L .46276 .43951 L p 0 1 0 r
F P
0 g
s
.451 .43266 m .44345 .43888 L .43171 .43102 L p 0 1 0 r
F P
0 g
s
.3153 .39078 m .32243 .38211 L .33449 .38784 L p 0 0 1 r
F P
0 g
s
.32243 .38211 m .3153 .39078 L .30321 .38506 L p 0 0 1 r
F P
0 g
s
.59188 .43493 m .58324 .43186 L .57136 .41645 L p 1 0 0 r
F P
0 g
s
.57136 .41645 m .57983 .41807 L .59188 .43493 L p 1 0 0 r
F P
0 g
s
.41613 .39044 m .42362 .38176 L .43545 .3875 L p 0 0 1 r
F P
0 g
s
.42362 .38176 m .41613 .39044 L .40427 .38472 L p 0 0 1 r
F P
0 g
s
.64797 .54637 m .6384 .53637 L .626 .51449 L p 1 0 0 r
F P
0 g
s
.626 .51449 m .63528 .52256 L .64797 .54637 L p 1 0 0 r
F P
0 g
s
.46655 .39027 m .47422 .38159 L .48593 .38733 L p 0 0 1 r
F P
0 g
s
.47422 .38159 m .46655 .39027 L .45481 .38455 L p 0 0 1 r
F P
0 g
s
.36569 .39092 m .37279 .38649 L .3846 .3959 L p 0 1 0 r
F P
0 g
s
.52107 .42426 m .52886 .41135 L .54033 .41163 L p 0 1 0 r
F P
0 g
s
.54807 .39632 m .54033 .41163 L .52886 .41135 L p 0 1 0 r
F P
0 g
s
.51698 .3901 m .52483 .38142 L .53643 .38716 L p 0 0 1 r
F P
0 g
s
.52483 .38142 m .51698 .3901 L .50536 .38438 L p 0 0 1 r
F P
0 g
s
.56742 .38993 m .57545 .38125 L .58693 .38699 L p 0 0 1 r
F P
0 g
s
.38091 .36223 m .38844 .35001 L .40047 .35298 L p 1 0 0 r
F P
0 g
s
.40801 .3413 m .40047 .35298 L .38844 .35001 L p 1 0 0 r
F P
0 g
s
.61787 .38976 m .62607 .38108 L .63743 .38682 L p 0 0 1 r
F P
0 g
s
.62607 .38108 m .61787 .38976 L .60648 .38404 L p 0 0 1 r
F P
0 g
s
.29956 .42756 m .30687 .41624 L .31919 .41903 L p 1 0 0 r
F P
0 g
s
.32658 .40709 m .31919 .41903 L .30687 .41624 L p 1 0 0 r
F P
0 g
s
.66832 .38959 m .6767 .38091 L .68795 .38665 L p 0 0 1 r
F P
0 g
s
.6767 .38091 m .66832 .38959 L .65704 .38386 L p 0 0 1 r
F P
0 g
s
.32658 .40709 m .33402 .39486 L .34627 .39717 L p 1 0 0 r
F P
0 g
s
.71878 .38942 m .72734 .38073 L .73847 .38648 L p 0 0 1 r
F P
0 g
s
.72734 .38073 m .71878 .38942 L .70762 .38369 L p 0 0 1 r
F P
0 g
s
.57492 .30319 m .56743 .3253 L .55624 .32978 L p 0 1 0 r
F P
0 g
s
.55624 .32978 m .56386 .30896 L .57492 .30319 L p 0 1 0 r
F P
0 g
s
.2762 .3324 m .28296 .32607 L .29488 .33481 L p 0 1 0 r
F P
0 g
s
.28296 .32607 m .2762 .3324 L .26422 .3245 L p 0 1 0 r
F P
0 g
s
.76925 .38925 m .77799 .38056 L .789 .3863 L p 0 0 1 r
F P
0 g
s
.77799 .38056 m .76925 .38925 L .7582 .38352 L p 0 0 1 r
F P
0 g
s
.24161 .44176 m .24841 .43398 L .26067 .43945 L p 1 0 0 r
F P
0 g
s
.24841 .43398 m .24161 .44176 L .22948 .4349 L p 1 0 0 r
F P
0 g
s
.47448 .44575 m .48218 .43766 L .49388 .44251 L p 0 1 0 r
F P
0 g
s
.48218 .43766 m .47448 .44575 L .46276 .43951 L p 0 1 0 r
F P
0 g
s
.81972 .38908 m .82864 .38039 L .83953 .38613 L p 0 0 1 r
F P
0 g
s
.82864 .38039 m .81972 .38908 L .80879 .38335 L p 0 0 1 r
F P
0 g
s
.52886 .41135 m .53666 .39712 L .54807 .39632 L p 0 1 0 r
F P
0 g
s
.8702 .38891 m .8793 .38022 L .89007 .38596 L p 0 0 1 r
F P
0 g
s
.8793 .38022 m .8702 .38891 L .85939 .38318 L p 0 0 1 r
F P
0 g
s
.14463 .46991 m .13582 .49362 L .12078 .504 L p 0 1 0 r
F P
0 g
s
.12078 .504 m .12999 .4783 L .14463 .46991 L p 0 1 0 r
F P
0 g
s
.18312 .38835 m .1898 .37966 L .20218 .3854 L p 0 0 1 r
F P
0 g
s
.1898 .37966 m .18312 .38835 L .17071 .38262 L p 0 0 1 r
F P
0 g
s
.23357 .38818 m .24043 .37949 L .25269 .38523 L p 0 0 1 r
F P
0 g
s
.24043 .37949 m .23357 .38818 L .22128 .38245 L p 0 0 1 r
F P
0 g
s
.28403 .38801 m .29106 .37931 L .30321 .38506 L p 0 0 1 r
F P
0 g
s
.29106 .37931 m .28403 .38801 L .27185 .38228 L p 0 0 1 r
F P
0 g
s
.47799 .33228 m .48571 .32518 L .49743 .3335 L p 1 0 0 r
F P
0 g
s
.48571 .32518 m .47799 .33228 L .46627 .32548 L p 1 0 0 r
F P
0 g
s
.58246 .21713 m .57521 .24409 L .56416 .25144 L p 0 1 0 r
F P
0 g
s
.56416 .25144 m .5716 .22583 L .58246 .21713 L p 0 1 0 r
F P
0 g
s
.38497 .38767 m .39236 .37897 L .40427 .38472 L p 0 0 1 r
F P
0 g
s
.39236 .37897 m .38497 .38767 L .37302 .38193 L p 0 0 1 r
F P
0 g
s
.43171 .43102 m .43921 .42525 L .451 .43266 L p 0 1 0 r
F P
0 g
s
.43921 .42525 m .43171 .43102 L .41995 .42273 L p 0 1 0 r
F P
0 g
s
.49388 .44251 m .50165 .43276 L .51327 .43596 L p 0 1 0 r
F P
0 g
s
.52107 .42426 m .51327 .43596 L .50165 .43276 L p 0 1 0 r
F P
0 g
s
.58191 .17727 m .58317 .18025 L p .56796 .20709 L 0 1 0 r
F P
0 g
s
.58317 .18025 m .57888 .19823 L .56796 .20709 L p 0 1 0 r
F P
0 g
s
.43545 .3875 m .44301 .3788 L .45481 .38455 L p 0 0 1 r
F P
0 g
s
.44301 .3788 m .43545 .3875 L .42362 .38176 L p 0 0 1 r
F P
0 g
s
.48593 .38733 m .49368 .37863 L .50536 .38438 L p 0 0 1 r
F P
0 g
s
.49368 .37863 m .48593 .38733 L .47422 .38159 L p 0 0 1 r
F P
0 g
s
.19406 .33206 m .20125 .31964 L .21384 .3237 L p 0 1 0 r
F P
0 g
s
.21384 .3237 m .22082 .31323 L .23315 .31888 L p 0 1 0 r
F P
0 g
s
.22082 .31323 m .21384 .3237 L .20125 .31964 L p 0 1 0 r
F P
0 g
s
.58693 .38699 m .59503 .37828 L .60648 .38404 L p 0 0 1 r
F P
0 g
s
.59503 .37828 m .58693 .38699 L .57545 .38125 L p 0 0 1 r
F P
0 g
s
.63743 .38682 m .64572 .37811 L .65704 .38386 L p 0 0 1 r
F P
0 g
s
.64572 .37811 m .63743 .38682 L .62607 .38108 L p 0 0 1 r
F P
0 g
s
.68795 .38665 m .69641 .37794 L .70762 .38369 L p 0 0 1 r
F P
0 g
s
.69641 .37794 m .68795 .38665 L .6767 .38091 L p 0 0 1 r
F P
0 g
s
.50165 .43276 m .49388 .44251 L .48218 .43766 L p 0 1 0 r
F P
0 g
s
.57877 .2619 m .57138 .28635 L .56025 .29224 L p 0 1 0 r
F P
0 g
s
.56025 .29224 m .5678 .26911 L .57877 .2619 L p 0 1 0 r
F P
0 g
s
.73847 .38648 m .74711 .37777 L .7582 .38352 L p 0 0 1 r
F P
0 g
s
.74711 .37777 m .73847 .38648 L .72734 .38073 L p 0 0 1 r
F P
0 g
s
.28003 .43454 m .28722 .42412 L .29956 .42756 L p 1 0 0 r
F P
0 g
s
.30687 .41624 m .29956 .42756 L .28722 .42412 L p 1 0 0 r
F P
0 g
s
.40801 .3413 m .41557 .32994 L .42748 .334 L p 1 0 0 r
F P
0 g
s
.42748 .334 m .43506 .32356 L .44688 .32858 L p 1 0 0 r
F P
0 g
s
.43506 .32356 m .42748 .334 L .41557 .32994 L p 1 0 0 r
F P
0 g
s
.23315 .31888 m .24 .31006 L .25216 .31704 L p 0 1 0 r
F P
0 g
s
.24 .31006 m .23315 .31888 L .22082 .31323 L p 0 1 0 r
F P
0 g
s
.789 .3863 m .79782 .3776 L .80879 .38335 L p 0 0 1 r
F P
0 g
s
.79782 .3776 m .789 .3863 L .77799 .38056 L p 0 0 1 r
F P
0 g
s
.44688 .32858 m .4545 .31928 L .46627 .32548 L p 1 0 0 r
F P
0 g
s
.4545 .31928 m .44688 .32858 L .43506 .32356 L p 1 0 0 r
F P
0 g
s
.83953 .38613 m .84853 .37742 L .85939 .38318 L p 0 0 1 r
F P
0 g
s
.84853 .37742 m .83953 .38613 L .82864 .38039 L p 0 0 1 r
F P
0 g
s
.12903 .57635 m .12606 .58543 L .12519 .58338 L p 0 1 0 r
F P
0 g
s
.12519 .58338 m .12398 .58126 L .12903 .57635 L p 0 1 0 r
F P
0 g
s
.12903 .57635 m .12398 .58126 L .12204 .57673 L p 0 1 0 r
F P
0 g
s
.26422 .3245 m .27098 .31765 L .28296 .32607 L p 0 1 0 r
F P
0 g
s
.27098 .31765 m .26422 .3245 L .25216 .31704 L p 0 1 0 r
F P
0 g
s
.63214 .5088 m .62284 .50073 L .6106 .48073 L p 1 0 0 r
F P
0 g
s
.6106 .48073 m .61964 .48701 L .63214 .5088 L p 1 0 0 r
F P
0 g
s
.60407 .45331 m .59522 .44867 L .58324 .43186 L p 1 0 0 r
F P
0 g
s
.58324 .43186 m .59188 .43493 L .60407 .45331 L p 1 0 0 r
F P
0 g
s
.26067 .43945 m .2677 .43021 L .28003 .43454 L p 1 0 0 r
F P
0 g
s
.2677 .43021 m .26067 .43945 L .24841 .43398 L p 1 0 0 r
F P
0 g
s
.20218 .3854 m .20893 .37669 L .22128 .38245 L p 0 0 1 r
F P
0 g
s
.20893 .37669 m .20218 .3854 L .1898 .37966 L p 0 0 1 r
F P
0 g
s
.25269 .38523 m .25962 .37652 L .27185 .38228 L p 0 0 1 r
F P
0 g
s
.25962 .37652 m .25269 .38523 L .24043 .37949 L p 0 0 1 r
F P
0 g
s
.30321 .38506 m .31032 .37634 L .32243 .38211 L p 0 0 1 r
F P
0 g
s
.31032 .37634 m .30321 .38506 L .29106 .37931 L p 0 0 1 r
F P
0 g
s
.28722 .42412 m .28003 .43454 L .2677 .43021 L p 1 0 0 r
F P
0 g
s
.41995 .42273 m .42739 .41734 L .43921 .42525 L p 0 1 0 r
F P
0 g
s
.42739 .41734 m .41995 .42273 L .40818 .41407 L p 0 1 0 r
F P
0 g
s
.22948 .4349 m .23617 .42785 L .24841 .43398 L p 1 0 0 r
F P
0 g
s
.23617 .42785 m .22948 .4349 L .2174 .42727 L p 1 0 0 r
F P
0 g
s
.57525 .17883 m .58081 .17353 L .58191 .17727 L p 0 1 0 r
F P
0 g
s
.56796 .20709 m .57525 .17883 L p .58191 .17727 L 0 1 0 r
F P
0 g
s
.40427 .38472 m .41174 .376 L .42362 .38176 L p 0 0 1 r
F P
0 g
s
.41174 .376 m .40427 .38472 L .39236 .37897 L p 0 0 1 r
F P
0 g
s
.30687 .41624 m .31425 .4045 L .32658 .40709 L p 1 0 0 r
F P
0 g
s
.33402 .39486 m .32658 .40709 L .31425 .4045 L p 1 0 0 r
F P
0 g
s
.45481 .38455 m .46246 .37583 L .47422 .38159 L p 0 0 1 r
F P
0 g
s
.46246 .37583 m .45481 .38455 L .44301 .3788 L p 0 0 1 r
F P
0 g
s
.13255 .5342 m .12313 .5618 L p .11528 .56337 L 0 1 0 r
F P
0 g
s
.11528 .56337 m .11303 .55951 L p .13255 .5342 L 0 1 0 r
F P
0 g
s
.11303 .55951 m .11718 .54695 L .13255 .5342 L p 0 1 0 r
F P
0 g
s
.38844 .35001 m .396 .33798 L .40801 .3413 L p 1 0 0 r
F P
0 g
s
.41557 .32994 m .40801 .3413 L .396 .33798 L p 1 0 0 r
F P
0 g
s
.50536 .38438 m .51318 .37566 L .52483 .38142 L p 0 0 1 r
F P
0 g
s
.51318 .37566 m .50536 .38438 L .49368 .37863 L p 0 0 1 r
F P
0 g
s
.46276 .43951 m .47043 .43208 L .48218 .43766 L p 0 1 0 r
F P
0 g
s
.47043 .43208 m .46276 .43951 L .451 .43266 L p 0 1 0 r
F P
0 g
s
.60648 .38404 m .61466 .37531 L .62607 .38108 L p 0 0 1 r
F P
0 g
s
.61466 .37531 m .60648 .38404 L .59503 .37828 L p 0 0 1 r
F P
0 g
s
.65704 .38386 m .66541 .37514 L .6767 .38091 L p 0 0 1 r
F P
0 g
s
.66541 .37514 m .65704 .38386 L .64572 .37811 L p 0 0 1 r
F P
0 g
s
.70762 .38369 m .71616 .37497 L .72734 .38073 L p 0 0 1 r
F P
0 g
s
.71616 .37497 m .70762 .38369 L .69641 .37794 L p 0 0 1 r
F P
0 g
s
.7582 .38352 m .76692 .37479 L .77799 .38056 L p 0 0 1 r
F P
0 g
s
.76692 .37479 m .7582 .38352 L .74711 .37777 L p 0 0 1 r
F P
0 g
s
.80879 .38335 m .81769 .37462 L .82864 .38039 L p 0 0 1 r
F P
0 g
s
.81769 .37462 m .80879 .38335 L .79782 .3776 L p 0 0 1 r
F P
0 g
s
.46627 .32548 m .47396 .31758 L .48571 .32518 L p 1 0 0 r
F P
0 g
s
.47396 .31758 m .46627 .32548 L .4545 .31928 L p 1 0 0 r
F P
0 g
s
.85939 .38318 m .86847 .37445 L .8793 .38022 L p 0 0 1 r
F P
0 g
s
.86847 .37445 m .85939 .38318 L .84853 .37742 L p 0 0 1 r
F P
0 g
s
.54063 .36131 m .53253 .36349 L .52082 .35259 L p 1 0 0 r
F P
0 g
s
.52082 .35259 m .52882 .34929 L .54063 .36131 L p 1 0 0 r
F P
0 g
s
.52882 .34929 m .52082 .35259 L .50913 .34261 L p 1 0 0 r
F P
0 g
s
.54063 .36131 m .52882 .34929 L p .54079 .35591 L 1 0 0 r
F P
0 g
s
.55984 .34567 m .55217 .36438 L .5449 .36566 L p 0 1 0 r
F P
0 g
s
.54481 .36545 m .55984 .34567 L .5449 .36566 L 0 1 0 r
F
.54383 .36306 m .55984 .34567 L .54461 .36571 L F
.54853 .3489 m .55984 .34567 L p .54381 .36308 L F P
0 g
s
.53253 .36349 m .54063 .36131 L .54461 .36571 L p 1 0 0 r
F P
0 g
s
.54461 .36571 m .55217 .36438 L p .54603 .37012 L 0 1 0 r
F P
0 g
s
.54551 .3706 m .54461 .36571 L .54603 .37012 L 0 1 0 r
F
.54551 .3706 m .54461 .36571 L .54503 .36715 L 1 0 0 r
F
.54569 .3707 m .5448 .36592 L .54668 .37055 L 0 0 1 r
F
.54569 .3707 m .54503 .36715 L .54614 .37094 L 1 0 0 r
F
.54551 .3706 m .54503 .36715 L .54569 .3707 L F
.53253 .36349 m .54461 .36571 L .54551 .3706 L F
.53273 .37268 m .5445 .36609 L .54535 .37075 L 0 0 1 r
F
.54444 .36574 m .54461 .36571 L p .54447 .36591 L 0 1 0 r
F P
0 g
s
.53273 .37268 m .54069 .36387 L .54444 .36574 L p 0 0 1 r
F P
0 g
s
.54447 .36591 m .54461 .36571 L .54535 .37075 L 0 1 0 r
F
.54444 .36574 m .5448 .36592 L p .5445 .36609 L 0 0 1 r
F P
0 g
s
.53273 .37268 m .54444 .36574 L .5445 .36609 L 0 0 1 r
F
.54535 .37075 m .54461 .36571 L .54551 .3706 L 0 1 0 r
F
.53295 .38235 m .54447 .36591 L .54535 .37075 L F
.53295 .38235 m .54076 .36639 L .54444 .36574 L p F P
0 g
s
.53295 .38235 m .54444 .36574 L .54447 .36591 L 0 1 0 r
F
.5448 .36592 m .55233 .36969 L p .54668 .37055 L 0 0 1 r
F P
0 g
s
.54614 .37094 m .54503 .36715 L .55248 .37442 L 1 0 0 r
F
.54461 .36571 m .5448 .36592 L p .54503 .36715 L F P
0 g
s
.5448 .36592 m .55248 .37442 L p .54503 .36715 L 1 0 0 r
F P
0 g
s
.56037 .36086 m .55233 .36969 L .5448 .36592 L p 0 0 1 r
F P
0 g
s
.5448 .36592 m .54461 .36571 L p .54474 .36579 L 1 0 0 r
F P
0 g
s
.54361 .3633 m .54314 .36102 L .54381 .36308 L 0 1 0 r
F
.54428 .36536 m .54063 .36131 L p .54361 .3633 L 1 0 0 r
F P
0 g
s
.54461 .36571 m .54428 .36536 L p .54397 .36417 L 1 0 0 r
F P
0 g
s
.54361 .3633 m .54383 .36306 L .54461 .36571 L 0 1 0 r
F
.54397 .36417 m .54377 .3634 L .54461 .36571 L 1 0 0 r
F
.54361 .3633 m .54377 .3634 L .54428 .36536 L F
.54461 .36571 m .54444 .36574 L p .54361 .3633 L 0 1 0 r
F P
0 g
s
.54377 .3634 m .54421 .36447 L .54461 .36571 L 1 0 0 r
F
.54377 .3634 m .54431 .36332 L .5448 .36592 L 0 0 1 r
F
.5449 .36566 m .54461 .36571 L p .54481 .36545 L 0 1 0 r
F P
0 g
s
.54431 .36332 m .56037 .36086 L .5448 .36592 L 0 0 1 r
F
.57198 .3667 m .56392 .37548 L .55233 .36969 L p F P
0 g
s
.55233 .36969 m .56037 .36086 L .57198 .3667 L p 0 0 1 r
F P
0 g
s
.54388 .36348 m .56085 .37476 L .54461 .36571 L 1 0 0 r
F
.5448 .36592 m .54444 .36574 L p .54377 .3634 L 0 0 1 r
F P
0 g
s
.54444 .36574 m .54389 .36547 L p .54382 .36428 L 0 0 1 r
F P
0 g
s
.54347 .36345 m .54361 .3633 L .54444 .36574 L 0 1 0 r
F
.54382 .36428 m .54377 .3634 L .54444 .36574 L 0 0 1 r
F
.54389 .36547 m .54069 .36387 L p .54347 .36345 L F P
0 g
s
.54347 .36345 m .54377 .3634 L .54389 .36547 L 0 0 1 r
F
.54444 .36574 m .54076 .36639 L p .54347 .36345 L 0 1 0 r
F P
0 g
s
.54314 .36102 m .54853 .3489 L p .54381 .36308 L 0 1 0 r
F P
0 g
s
.54871 .355 m .56037 .36086 L p .54426 .36333 L 0 0 1 r
F P
0 g
s
.54377 .3634 m .54407 .36289 L .54426 .36333 L 0 0 1 r
F
.54407 .36289 m .54871 .355 L .54426 .36333 L F
.54328 .36101 m .54871 .355 L p .54377 .3634 L F P
0 g
s
.54063 .36131 m .54314 .36102 L p .54377 .3634 L 1 0 0 r
F P
0 g
s
.54314 .36102 m .54328 .36101 L p .54363 .3627 L 1 0 0 r
F P
0 g
s
.54314 .36102 m .54363 .3627 L .54377 .3634 L 1 0 0 r
F
.54295 .36105 m .54063 .36131 L p .54079 .35591 L F P
0 g
s
.54069 .36387 m .529 .35802 L p .54085 .35621 L 0 0 1 r
F P
0 g
s
.54069 .36387 m .53273 .37268 L .52106 .36687 L p 0 0 1 r
F P
0 g
s
.54484 .3331 m .55624 .32978 L p .53933 .34846 L 0 1 0 r
F P
0 g
s
.52882 .34929 m .53694 .34715 L .53969 .35019 L p 1 0 0 r
F P
0 g
s
.52882 .34929 m .53969 .35019 L .53974 .35044 L 1 0 0 r
F
.52882 .34929 m .53993 .35046 L .54103 .35604 L F
.53993 .35046 m .54853 .3489 L p .54161 .35549 L 0 1 0 r
F P
0 g
s
.54103 .35604 m .53993 .35046 L .54161 .35549 L 0 1 0 r
F
.54853 .3489 m .54314 .36102 L p .54156 .35553 L F P
0 g
s
.54014 .3507 m .54871 .355 L p .54234 .35598 L 0 0 1 r
F P
0 g
s
.54103 .35604 m .54156 .35553 L .54267 .35992 L 0 1 0 r
F
.54314 .36102 m .54295 .36105 L p .54256 .35964 L 1 0 0 r
F P
0 g
s
.54314 .36102 m .54302 .36129 L p .54267 .35992 L 0 1 0 r
F P
0 g
s
.54156 .35553 m .54314 .36102 L .54267 .35992 L 0 1 0 r
F
.54165 .35795 m .54103 .35604 L .54295 .36105 L 1 0 0 r
F
.54079 .35591 m .54103 .35604 L .54165 .35795 L F
.54103 .35604 m .54256 .35964 L .54295 .36105 L F
.54085 .35621 m .54103 .35604 L .54302 .36129 L 0 1 0 r
F
.54103 .35604 m .54267 .35992 L .54302 .36129 L F
.54085 .35621 m .54123 .35615 L .54302 .36129 L 0 0 1 r
F
.54871 .355 m .54328 .36101 L p .54123 .35615 L F P
0 g
s
.54225 .35858 m .54314 .36102 L .54256 .35964 L 1 0 0 r
F
.54266 .35953 m .54314 .36102 L .54225 .35858 L F
.54103 .35604 m .54123 .35615 L .54256 .35964 L F
.54123 .35615 m .54163 .35637 L .54225 .35858 L F
.54123 .35615 m .54225 .35858 L .54256 .35964 L F
.54103 .35604 m .54089 .35536 L .54093 .35544 L F
.54089 .35536 m .53993 .35046 L .54093 .35544 L F
.53993 .35046 m .54014 .3507 L p .54093 .35544 L F P
0 g
s
.54103 .35604 m .54014 .3507 L .54123 .35615 L 1 0 0 r
F
.54103 .35604 m .54051 .35445 L .53993 .35046 L 0 1 0 r
F
.53975 .3505 m .53993 .35046 L p .54051 .35445 L F P
0 g
s
.54051 .35445 m .54014 .3507 L .54123 .35615 L 0 0 1 r
F
.53919 .35132 m .53982 .35091 L .54051 .35445 L F
.53982 .35091 m .54014 .3507 L .54051 .35445 L F
.529 .35802 m .53919 .35132 L .54051 .35445 L F
.529 .35802 m .54051 .35445 L .54085 .35621 L F
.529 .35802 m .53699 .34911 L .53975 .3505 L p F P
0 g
s
.53975 .3505 m .54014 .3507 L p .5399 .35086 L 0 0 1 r
F P
0 g
s
.529 .35802 m .53975 .3505 L .5399 .35086 L 0 0 1 r
F
.53694 .34715 m .52506 .335 L p .53637 .34132 L 1 0 0 r
F P
0 g
s
.54484 .3331 m .5388 .34695 L p .53637 .34132 L 0 1 0 r
F P
0 g
s
.53637 .34132 m .53659 .34144 L .53661 .34189 L 1 0 0 r
F
.53637 .34132 m .53661 .34189 L .53694 .34715 L F
.53694 .34715 m .52882 .34929 L .51704 .33827 L p F P
0 g
s
.51704 .33827 m .52506 .335 L .53694 .34715 L p 1 0 0 r
F P
0 g
s
.53699 .34911 m .52522 .3432 L p .53618 .34151 L 0 0 1 r
F P
0 g
s
.53618 .34151 m .53637 .34132 L .53642 .34206 L 0 1 0 r
F
.53618 .34151 m .53665 .34258 L .53699 .34911 L 0 0 1 r
F
.53659 .34144 m .53702 .34246 L .53694 .34715 L 1 0 0 r
F
.53931 .34848 m .53894 .34662 L .53933 .34846 L 0 1 0 r
F
.53907 .34775 m .53894 .34662 L .53931 .34848 L F
.53894 .34662 m .54484 .3331 L p .53933 .34846 L F P
0 g
s
.54504 .34014 m .53895 .34693 L p .53659 .34144 L 0 0 1 r
F P
0 g
s
.5388 .34695 m .53694 .34715 L p .53704 .3417 L 1 0 0 r
F P
0 g
s
.53917 .34864 m .53907 .34775 L .53931 .34848 L 0 1 0 r
F
.55624 .32978 m .54853 .3489 L .53993 .35046 L p F P
0 g
s
.53988 .35033 m .55624 .32978 L .53993 .35046 L 0 1 0 r
F
.53993 .35046 m .53969 .35019 L p .53917 .34864 L 1 0 0 r
F P
0 g
s
.53969 .35019 m .53993 .35046 L p .53974 .35044 L 1 0 0 r
F P
0 g
s
.53902 .3488 m .55624 .32978 L .53975 .3505 L 0 1 0 r
F
.56846 .35197 m .56037 .36086 L .54871 .355 L p 0 0 1 r
F P
0 g
s
.56743 .3253 m .55984 .34567 L .54853 .3489 L p 0 1 0 r
F P
0 g
s
.54871 .355 m .55678 .34607 L .56846 .35197 L p 0 0 1 r
F P
0 g
s
.53917 .34864 m .53934 .34875 L .53993 .35046 L 1 0 0 r
F
.53934 .34875 m .53947 .34907 L .53993 .35046 L F
.53993 .35046 m .53975 .3505 L p .53988 .35033 L 0 1 0 r
F P
0 g
s
.54853 .3489 m .55624 .32978 L .56743 .3253 L p 0 1 0 r
F P
0 g
s
.53934 .34875 m .55678 .34607 L .54002 .3504 L 0 0 1 r
F
.53947 .34907 m .54008 .35055 L .53993 .35046 L 1 0 0 r
F
.53934 .34875 m .54002 .3504 L .53971 .35048 L 0 0 1 r
F
.55678 .34607 m .54871 .355 L .54014 .3507 L p F P
0 g
s
.54002 .3504 m .55678 .34607 L .54014 .3507 L 0 0 1 r
F
.53937 .34878 m .55727 .36078 L .54008 .35055 L 1 0 0 r
F
.53937 .34878 m .54008 .35055 L .53947 .34907 L F
.53934 .34875 m .53937 .34878 L .53947 .34907 L F
.54014 .3507 m .53993 .35046 L p .54008 .35055 L F P
0 g
s
.54014 .3507 m .53971 .35048 L p .54002 .3504 L 0 0 1 r
F P
0 g
s
.53694 .34715 m .5388 .34695 L p .53917 .34864 L 1 0 0 r
F P
0 g
s
.53902 .3488 m .53869 .34721 L .53917 .34864 L 0 1 0 r
F
.53969 .35019 m .53694 .34715 L p .53917 .34864 L 1 0 0 r
F P
0 g
s
.53935 .3503 m .53699 .34911 L p .53902 .3488 L 0 0 1 r
F P
0 g
s
.53867 .34724 m .53869 .34721 L p .53902 .3488 L 0 1 0 r
F P
0 g
s
.53917 .34864 m .5393 .34859 L .53934 .34875 L 1 0 0 r
F
.54504 .34014 m .55678 .34607 L p .5397 .3487 L 0 0 1 r
F P
0 g
s
.53957 .3484 m .54504 .34014 L .5397 .3487 L 0 0 1 r
F
.53895 .34693 m .54504 .34014 L p .53934 .34875 L F P
0 g
s
.54521 .34627 m .53895 .34693 L p .53704 .3417 L 1 0 0 r
F P
0 g
s
.53895 .34693 m .5388 .34695 L p .53826 .34533 L 1 0 0 r
F P
0 g
s
.53704 .3417 m .53895 .34693 L .53826 .34533 L 1 0 0 r
F
.53934 .34875 m .53957 .3484 L .5397 .3487 L 0 0 1 r
F
.5388 .34695 m .53894 .34662 L p .53917 .34864 L 0 1 0 r
F P
0 g
s
.5388 .34695 m .53895 .34693 L p .53917 .34864 L 1 0 0 r
F P
0 g
s
.53895 .34693 m .5393 .34859 L .53917 .34864 L 1 0 0 r
F
.53869 .34721 m .5388 .34695 L p .53917 .34864 L 0 1 0 r
F P
0 g
s
.53699 .34911 m .53895 .34693 L p .53934 .34875 L 0 0 1 r
F P
0 g
s
.53895 .34693 m .54521 .34627 L p .5393 .34859 L 1 0 0 r
F P
0 g
s
.53704 .35099 m .53867 .34724 L p .53902 .3488 L 0 1 0 r
F P
0 g
s
.53971 .35048 m .53935 .3503 L p .53934 .34875 L 0 0 1 r
F P
0 g
s
.53902 .3488 m .53934 .34875 L .53935 .3503 L 0 0 1 r
F
.54521 .34627 m .55727 .36078 L p .53934 .34875 L 1 0 0 r
F P
0 g
s
.5393 .34859 m .54521 .34627 L .53934 .34875 L 1 0 0 r
F
.5388 .34695 m .53867 .34724 L p .53637 .34132 L 0 1 0 r
F P
0 g
s
.53867 .34724 m .53699 .34911 L p .53665 .34258 L 0 0 1 r
F P
0 g
s
.53699 .34911 m .529 .35802 L .51725 .35215 L p 0 0 1 r
F P
0 g
s
.50913 .34261 m .51704 .33827 L .52882 .34929 L p 1 0 0 r
F P
0 g
s
.51725 .35215 m .52522 .3432 L .53699 .34911 L p 0 0 1 r
F P
0 g
s
.53867 .34724 m .53704 .35099 L p .53642 .34206 L 0 1 0 r
F P
0 g
s
.53637 .34132 m .53867 .34724 L .53642 .34206 L 0 1 0 r
F
.53895 .34693 m .53867 .34724 L p .53659 .34144 L 0 0 1 r
F P
0 g
s
.53659 .34144 m .53867 .34724 L .53665 .34258 L 0 0 1 r
F
.53618 .34151 m .53659 .34144 L .53665 .34258 L F
.53704 .35099 m .52538 .35198 L p .53618 .34151 L 0 1 0 r
F P
0 g
s
.53618 .34151 m .53642 .34206 L .53704 .35099 L 0 1 0 r
F
.53659 .34144 m .53704 .3417 L .53702 .34246 L 1 0 0 r
F
.53975 .3505 m .53704 .35099 L p .53902 .3488 L 0 1 0 r
F P
0 g
s
.52106 .36687 m .529 .35802 L .54069 .36387 L p 0 0 1 r
F P
0 g
s
.52919 .36731 m .53925 .35059 L .54051 .35445 L 0 1 0 r
F
.54085 .35621 m .54051 .35445 L .54103 .35604 L F
.52919 .36731 m .54051 .35445 L .54085 .35621 L F
.53925 .35059 m .53975 .3505 L p .54051 .35445 L F P
0 g
s
.54085 .35621 m .54051 .35445 L .54123 .35615 L 0 0 1 r
F
.54328 .36101 m .54314 .36102 L p .54266 .35953 L 1 0 0 r
F P
0 g
s
.54328 .36101 m .54302 .36129 L p .54123 .35615 L 0 0 1 r
F P
0 g
s
.54163 .35637 m .54266 .35953 L .54225 .35858 L 1 0 0 r
F
.54123 .35615 m .54014 .3507 L .54234 .35598 L 0 0 1 r
F
.55727 .36078 m .54887 .36037 L .54014 .3507 L p 1 0 0 r
F P
0 g
s
.54008 .35055 m .55727 .36078 L .54014 .3507 L 1 0 0 r
F
.54014 .3507 m .54887 .36037 L p .54123 .35615 L F P
0 g
s
.52919 .36731 m .53704 .35099 L .53925 .35059 L p 0 1 0 r
F P
0 g
s
.54302 .36129 m .54069 .36387 L p .54085 .35621 L 0 0 1 r
F P
0 g
s
.54347 .36345 m .54314 .36186 L .54361 .3633 L 0 1 0 r
F
.54347 .36345 m .54328 .36101 L .54377 .3634 L 0 0 1 r
F
.54069 .36387 m .54302 .36129 L p .54347 .36345 L F P
0 g
s
.54314 .36186 m .54314 .36102 L .54361 .3633 L 0 1 0 r
F
.54302 .36129 m .54314 .36102 L p .54314 .36186 L F P
0 g
s
.54302 .36129 m .54328 .36101 L p .54347 .36345 L 0 0 1 r
F P
0 g
s
.54298 .36138 m .54302 .36129 L p .54314 .36186 L 0 1 0 r
F P
0 g
s
.54076 .36639 m .52919 .36731 L p .54085 .35621 L 0 1 0 r
F P
0 g
s
.54302 .36129 m .54076 .36639 L p .54085 .35621 L 0 1 0 r
F P
0 g
s
.54887 .36037 m .54328 .36101 L p .54163 .35637 L 1 0 0 r
F P
0 g
s
.54163 .35637 m .54328 .36101 L .54266 .35953 L 1 0 0 r
F
.54887 .36037 m .56085 .37476 L p .54377 .3634 L F P
0 g
s
.54328 .36101 m .54887 .36037 L p .54377 .3634 L 1 0 0 r
F P
0 g
s
.54076 .36639 m .54298 .36138 L p .54314 .36186 L 0 1 0 r
F P
0 g
s
.54076 .36639 m .54314 .36186 L .54347 .36345 L 0 1 0 r
F
.54377 .3634 m .54388 .36348 L .54421 .36447 L 1 0 0 r
F
.54535 .37075 m .5448 .36592 L .54569 .3707 L 0 0 1 r
F
.5445 .36609 m .5448 .36592 L .54535 .37075 L F
.56085 .37476 m .55248 .37442 L .5448 .36592 L p 1 0 0 r
F P
0 g
s
.54474 .36579 m .56085 .37476 L .5448 .36592 L 1 0 0 r
F
.17071 .38262 m .17736 .37388 L .1898 .37966 L p 0 0 1 r
F P
0 g
s
.22128 .38245 m .22811 .37371 L .24043 .37949 L p 0 0 1 r
F P
0 g
s
.22811 .37371 m .22128 .38245 L .20893 .37669 L p 0 0 1 r
F P
0 g
s
.50165 .43276 m .50945 .42198 L .52107 .42426 L p 0 1 0 r
F P
0 g
s
.52886 .41135 m .52107 .42426 L .50945 .42198 L p 0 1 0 r
F P
0 g
s
.40818 .41407 m .41555 .409 L .42739 .41734 L p 0 1 0 r
F P
0 g
s
.41555 .409 m .40818 .41407 L .39639 .40511 L p 0 1 0 r
F P
0 g
s
.27185 .38228 m .27886 .37354 L .29106 .37931 L p 0 0 1 r
F P
0 g
s
.27886 .37354 m .27185 .38228 L .25962 .37652 L p 0 0 1 r
F P
0 g
s
.51704 .33827 m .50913 .34261 L .49743 .3335 L p 1 0 0 r
F P
0 g
s
.32962 .37337 m .32243 .38211 L .31032 .37634 L p 0 0 1 r
F P
0 g
s
.25216 .31704 m .25893 .3096 L .27098 .31765 L p 0 1 0 r
F P
0 g
s
.25893 .3096 m .25216 .31704 L .24 .31006 L p 0 1 0 r
F P
0 g
s
.37302 .38193 m .38039 .37319 L .39236 .37897 L p 0 0 1 r
F P
0 g
s
.42362 .38176 m .43116 .37302 L .44301 .3788 L p 0 0 1 r
F P
0 g
s
.43116 .37302 m .42362 .38176 L .41174 .376 L p 0 0 1 r
F P
0 g
s
.47422 .38159 m .48194 .37285 L .49368 .37863 L p 0 0 1 r
F P
0 g
s
.48194 .37285 m .47422 .38159 L .46246 .37583 L p 0 0 1 r
F P
0 g
s
.65408 .57424 m .65681 .5798 L .65748 .5851 L p 1 0 0 r
F P
0 g
s
.53273 .37268 m .52483 .38142 L .51318 .37566 L p 0 0 1 r
F P
0 g
s
.57912 .1696 m .58081 .17353 L .57525 .17883 L p 0 1 0 r
F P
0 g
s
.2174 .42727 m .22395 .42101 L .23617 .42785 L p 1 0 0 r
F P
0 g
s
.22395 .42101 m .2174 .42727 L .20538 .41882 L p 1 0 0 r
F P
0 g
s
.57545 .38125 m .58353 .3725 L .59503 .37828 L p 0 0 1 r
F P
0 g
s
.58353 .3725 m .57545 .38125 L .56392 .37548 L p 0 0 1 r
F P
0 g
s
.62607 .38108 m .63433 .37233 L .64572 .37811 L p 0 0 1 r
F P
0 g
s
.63433 .37233 m .62607 .38108 L .61466 .37531 L p 0 0 1 r
F P
0 g
s
.13582 .49362 m .12668 .51925 L .11119 .53178 L p 0 1 0 r
F P
0 g
s
.11119 .53178 m .12078 .504 L .13582 .49362 L p 0 1 0 r
F P
0 g
s
.6767 .38091 m .68514 .37216 L .69641 .37794 L p 0 0 1 r
F P
0 g
s
.68514 .37216 m .6767 .38091 L .66541 .37514 L p 0 0 1 r
F P
0 g
s
.396 .33798 m .38844 .35001 L .37632 .34722 L p 1 0 0 r
F P
0 g
s
.72734 .38073 m .73596 .37199 L .74711 .37777 L p 0 0 1 r
F P
0 g
s
.73596 .37199 m .72734 .38073 L .71616 .37497 L p 0 0 1 r
F P
0 g
s
.28722 .42412 m .29449 .41314 L .30687 .41624 L p 1 0 0 r
F P
0 g
s
.31425 .4045 m .30687 .41624 L .29449 .41314 L p 1 0 0 r
F P
0 g
s
.77799 .38056 m .78679 .37181 L .79782 .3776 L p 0 0 1 r
F P
0 g
s
.78679 .37181 m .77799 .38056 L .76692 .37479 L p 0 0 1 r
F P
0 g
s
.82864 .38039 m .83762 .37164 L .84853 .37742 L p 0 0 1 r
F P
0 g
s
.83762 .37164 m .82864 .38039 L .81769 .37462 L p 0 0 1 r
F P
0 g
s
.20125 .31964 m .20833 .30825 L .22082 .31323 L p 0 1 0 r
F P
0 g
s
.22082 .31323 m .22773 .30363 L .24 .31006 L p 0 1 0 r
F P
0 g
s
.22773 .30363 m .22082 .31323 L .20833 .30825 L p 0 1 0 r
F P
0 g
s
.39639 .40511 m .4037 .40029 L .41555 .409 L p 0 1 0 r
F P
0 g
s
.4037 .40029 m .39639 .40511 L .3846 .3959 L p 0 1 0 r
F P
0 g
s
.49743 .3335 m .50527 .32817 L .51704 .33827 L p 1 0 0 r
F P
0 g
s
.50527 .32817 m .49743 .3335 L .48571 .32518 L p 1 0 0 r
F P
0 g
s
.30168 .32933 m .29488 .33481 L .28296 .32607 L p 0 1 0 r
F P
0 g
s
.48218 .43766 m .48994 .42871 L .50165 .43276 L p 0 1 0 r
F P
0 g
s
.48994 .42871 m .48218 .43766 L .47043 .43208 L p 0 1 0 r
F P
0 g
s
.31425 .4045 m .32167 .39241 L .33402 .39486 L p 1 0 0 r
F P
0 g
s
.34149 .38242 m .33402 .39486 L .32167 .39241 L p 1 0 0 r
F P
0 g
s
.451 .43266 m .45863 .42581 L .47043 .43208 L p 0 1 0 r
F P
0 g
s
.45863 .42581 m .451 .43266 L .43921 .42525 L p 0 1 0 r
F P
0 g
s
.24841 .43398 m .25535 .42534 L .2677 .43021 L p 1 0 0 r
F P
0 g
s
.25535 .42534 m .24841 .43398 L .23617 .42785 L p 1 0 0 r
F P
0 g
s
.1898 .37966 m .19652 .3709 L .20893 .37669 L p 0 0 1 r
F P
0 g
s
.19652 .3709 m .1898 .37966 L .17736 .37388 L p 0 0 1 r
F P
0 g
s
.5764 .40425 m .5679 .4026 L .55605 .38841 L p 1 0 0 r
F P
0 g
s
.55605 .38841 m .56439 .3887 L .5764 .40425 L p 1 0 0 r
F P
0 g
s
.24043 .37949 m .24733 .37073 L .25962 .37652 L p 0 0 1 r
F P
0 g
s
.24733 .37073 m .24043 .37949 L .22811 .37371 L p 0 0 1 r
F P
0 g
s
.41557 .32994 m .42315 .31898 L .43506 .32356 L p 1 0 0 r
F P
0 g
s
.43506 .32356 m .44267 .31363 L .4545 .31928 L p 1 0 0 r
F P
0 g
s
.44267 .31363 m .43506 .32356 L .42315 .31898 L p 1 0 0 r
F P
0 g
s
.29106 .37931 m .29814 .37055 L .31032 .37634 L p 0 0 1 r
F P
0 g
s
.29814 .37055 m .29106 .37931 L .27886 .37354 L p 0 0 1 r
F P
0 g
s
.50945 .42198 m .50165 .43276 L .48994 .42871 L p 0 1 0 r
F P
0 g
s
.61643 .47332 m .60735 .46701 L .59522 .44867 L p 1 0 0 r
F P
0 g
s
.59522 .44867 m .60407 .45331 L .61643 .47332 L p 1 0 0 r
F P
0 g
s
.65644 .57838 m .65681 .5798 L .65408 .57424 L p 1 0 0 r
F P
0 g
s
.65408 .57424 m .65624 .57689 L .65644 .57838 L p 1 0 0 r
F P
0 g
s
.39236 .37897 m .3998 .37021 L .41174 .376 L p 0 0 1 r
F P
0 g
s
.3998 .37021 m .39236 .37897 L .38039 .37319 L p 0 0 1 r
F P
0 g
s
.44301 .3788 m .45064 .37004 L .46246 .37583 L p 0 0 1 r
F P
0 g
s
.45064 .37004 m .44301 .3788 L .43116 .37302 L p 0 0 1 r
F P
0 g
s
.65204 .55816 m .65346 .56322 L p .6384 .53637 L 1 0 0 r
F P
0 g
s
.65346 .56322 m .65103 .56026 L .6384 .53637 L p 1 0 0 r
F P
0 g
s
.6384 .53637 m .64797 .54637 L p .65204 .55816 L 1 0 0 r
F P
0 g
s
.49368 .37863 m .50148 .36986 L .51318 .37566 L p 0 0 1 r
F P
0 g
s
.50148 .36986 m .49368 .37863 L .48194 .37285 L p 0 0 1 r
F P
0 g
s
.20538 .41882 m .21177 .41341 L .22395 .42101 L p 1 0 0 r
F P
0 g
s
.21177 .41341 m .20538 .41882 L .19345 .40951 L p 1 0 0 r
F P
0 g
s
.396 .33798 m .40357 .32622 L .41557 .32994 L p 1 0 0 r
F P
0 g
s
.42315 .31898 m .41557 .32994 L .40357 .32622 L p 1 0 0 r
F P
0 g
s
.50945 .42198 m .51728 .41004 L .52886 .41135 L p 0 1 0 r
F P
0 g
s
.53666 .39712 m .52886 .41135 L .51728 .41004 L p 0 1 0 r
F P
0 g
s
.3846 .3959 m .39184 .39126 L .4037 .40029 L p 0 1 0 r
F P
0 g
s
.39184 .39126 m .3846 .3959 L .37279 .38649 L p 0 1 0 r
F P
0 g
s
.59503 .37828 m .60319 .36952 L .61466 .37531 L p 0 0 1 r
F P
0 g
s
.60319 .36952 m .59503 .37828 L .58353 .3725 L p 0 0 1 r
F P
0 g
s
.2677 .43021 m .27483 .42026 L .28722 .42412 L p 1 0 0 r
F P
0 g
s
.29449 .41314 m .28722 .42412 L .27483 .42026 L p 1 0 0 r
F P
0 g
s
.64572 .37811 m .65406 .36934 L .66541 .37514 L p 0 0 1 r
F P
0 g
s
.65406 .36934 m .64572 .37811 L .63433 .37233 L p 0 0 1 r
F P
0 g
s
.69641 .37794 m .70493 .36917 L .71616 .37497 L p 0 0 1 r
F P
0 g
s
.70493 .36917 m .69641 .37794 L .68514 .37216 L p 0 0 1 r
F P
0 g
s
.4545 .31928 m .46216 .31064 L .47396 .31758 L p 1 0 0 r
F P
0 g
s
.46216 .31064 m .4545 .31928 L .44267 .31363 L p 1 0 0 r
F P
0 g
s
.74711 .37777 m .75581 .369 L .76692 .37479 L p 0 0 1 r
F P
0 g
s
.75581 .369 m .74711 .37777 L .73596 .37199 L p 0 0 1 r
F P
0 g
s
.57525 .17883 m .57815 .16645 L .57912 .1696 L p 0 1 0 r
F P
0 g
s
.27483 .42026 m .2677 .43021 L .25535 .42534 L p 1 0 0 r
F P
0 g
s
.28296 .32607 m .28973 .3202 L .30168 .32933 L p 0 1 0 r
F P
0 g
s
.28973 .3202 m .28296 .32607 L .27098 .31765 L p 0 1 0 r
F P
0 g
s
.57888 .19823 m .5716 .22583 L .56049 .23333 L p 0 1 0 r
F P
0 g
s
.56049 .23333 m .56796 .20709 L .57888 .19823 L p 0 1 0 r
F P
0 g
s
.79782 .3776 m .8067 .36883 L .81769 .37462 L p 0 0 1 r
F P
0 g
s
.8067 .36883 m .79782 .3776 L .78679 .37181 L p 0 0 1 r
F P
0 g
s
.24 .31006 m .2468 .30198 L .25893 .3096 L p 0 1 0 r
F P
0 g
s
.2468 .30198 m .24 .31006 L .22773 .30363 L p 0 1 0 r
F P
0 g
s
.84853 .37742 m .85759 .36865 L .86847 .37445 L p 0 0 1 r
F P
0 g
s
.85759 .36865 m .84853 .37742 L .83762 .37164 L p 0 0 1 r
F P
0 g
s
.48571 .32518 m .4935 .31893 L .50527 .32817 L p 1 0 0 r
F P
0 g
s
.4935 .31893 m .48571 .32518 L .47396 .31758 L p 1 0 0 r
F P
0 g
s
.57138 .28635 m .56386 .30896 L .55259 .31354 L p 0 1 0 r
F P
0 g
s
.55259 .31354 m .56025 .29224 L .57138 .28635 L p 0 1 0 r
F P
0 g
s
.19345 .40951 m .19966 .40502 L .21177 .41341 L p 1 0 0 r
F P
0 g
s
.19966 .40502 m .19345 .40951 L .18162 .39931 L p 1 0 0 r
F P
0 g
s
.37279 .38649 m .37997 .38197 L .39184 .39126 L p 0 1 0 r
F P
0 g
s
.37997 .38197 m .37279 .38649 L .36098 .37696 L p 0 1 0 r
F P
0 g
s
.20893 .37669 m .21573 .36791 L .22811 .37371 L p 0 0 1 r
F P
0 g
s
.21573 .36791 m .20893 .37669 L .19652 .3709 L p 0 0 1 r
F P
0 g
s
.25962 .37652 m .2666 .36774 L .27886 .37354 L p 0 0 1 r
F P
0 g
s
.2666 .36774 m .25962 .37652 L .24733 .37073 L p 0 0 1 r
F P
0 g
s
.18763 .39578 m .18162 .39931 L .16992 .38816 L p 1 0 0 r
F P
0 g
s
.16992 .38816 m .17571 .38565 L .18763 .39578 L p 1 0 0 r
F P
0 g
s
.31032 .37634 m .31748 .36756 L .32962 .37337 L p 0 0 1 r
F P
0 g
s
.31748 .36756 m .31032 .37634 L .29814 .37055 L p 0 0 1 r
F P
0 g
s
.18162 .39931 m .18763 .39578 L .19966 .40502 L p 1 0 0 r
F P
0 g
s
.41174 .376 m .41926 .36722 L .43116 .37302 L p 0 0 1 r
F P
0 g
s
.41926 .36722 m .41174 .376 L .3998 .37021 L p 0 0 1 r
F P
0 g
s
.51728 .41004 m .52511 .39687 L .53666 .39712 L p 0 1 0 r
F P
0 g
s
.54443 .3815 m .53666 .39712 L .52511 .39687 L p 0 1 0 r
F P
0 g
s
.64488 .53256 m .63528 .52256 L .62284 .50073 L p 1 0 0 r
F P
0 g
s
.62284 .50073 m .63214 .5088 L .64488 .53256 L p 1 0 0 r
F P
0 g
s
.43921 .42525 m .44678 .41893 L .45863 .42581 L p 0 1 0 r
F P
0 g
s
.44678 .41893 m .43921 .42525 L .42739 .41734 L p 0 1 0 r
F P
0 g
s
.46246 .37583 m .47016 .36704 L .48194 .37285 L p 0 0 1 r
F P
0 g
s
.47016 .36704 m .46246 .37583 L .45064 .37004 L p 0 0 1 r
F P
0 g
s
.58851 .42119 m .57983 .41807 L .5679 .4026 L p 1 0 0 r
F P
0 g
s
.5679 .4026 m .5764 .40425 L .58851 .42119 L p 1 0 0 r
F P
0 g
s
.37632 .34722 m .38389 .3349 L .396 .33798 L p 1 0 0 r
F P
0 g
s
.40357 .32622 m .396 .33798 L .38389 .3349 L p 1 0 0 r
F P
0 g
s
.51318 .37566 m .52106 .36687 L .53273 .37268 L p 0 0 1 r
F P
0 g
s
.52106 .36687 m .51318 .37566 L .50148 .36986 L p 0 0 1 r
F P
0 g
s
.56392 .37548 m .57198 .3667 L .58353 .3725 L p 0 0 1 r
F P
0 g
s
.29449 .41314 m .30184 .40166 L .31425 .4045 L p 1 0 0 r
F P
0 g
s
.32167 .39241 m .31425 .4045 L .30184 .40166 L p 1 0 0 r
F P
0 g
s
.32167 .39241 m .32915 .38004 L .34149 .38242 L p 1 0 0 r
F P
0 g
s
.61466 .37531 m .6229 .36652 L .63433 .37233 L p 0 0 1 r
F P
0 g
s
.6229 .36652 m .61466 .37531 L .60319 .36952 L p 0 0 1 r
F P
0 g
s
.36098 .37696 m .36809 .37249 L .37997 .38197 L p 0 1 0 r
F P
0 g
s
.57521 .24409 m .5678 .26911 L .55659 .27513 L p 0 1 0 r
F P
0 g
s
.55659 .27513 m .56416 .25144 L .57521 .24409 L p 0 1 0 r
F P
0 g
s
.66541 .37514 m .67383 .36635 L .68514 .37216 L p 0 0 1 r
F P
0 g
s
.67383 .36635 m .66541 .37514 L .65406 .36934 L p 0 0 1 r
F P
0 g
s
.52511 .39687 m .53295 .38235 L .54443 .3815 L p 0 1 0 r
F P
0 g
s
.71616 .37497 m .72476 .36618 L .73596 .37199 L p 0 0 1 r
F P
0 g
s
.72476 .36618 m .71616 .37497 L .70493 .36917 L p 0 0 1 r
F P
0 g
s
.27098 .31765 m .27774 .31133 L .28973 .3202 L p 0 1 0 r
F P
0 g
s
.27774 .31133 m .27098 .31765 L .25893 .3096 L p 0 1 0 r
F P
0 g
s
.76692 .37479 m .7757 .366 L .78679 .37181 L p 0 0 1 r
F P
0 g
s
.7757 .366 m .76692 .37479 L .75581 .369 L p 0 0 1 r
F P
0 g
s
.57618 .16192 m .57815 .16645 L p .56426 .18786 L 0 1 0 r
F P
0 g
s
.57815 .16645 m .57525 .17883 L .56426 .18786 L p 0 1 0 r
F P
0 g
s
.81769 .37462 m .82665 .36583 L .83762 .37164 L p 0 0 1 r
F P
0 g
s
.82665 .36583 m .81769 .37462 L .8067 .36883 L p 0 0 1 r
F P
0 g
s
.23617 .42785 m .243 .41987 L .25535 .42534 L p 1 0 0 r
F P
0 g
s
.243 .41987 m .23617 .42785 L .22395 .42101 L p 1 0 0 r
F P
0 g
s
.47043 .43208 m .47816 .42385 L .48994 .42871 L p 0 1 0 r
F P
0 g
s
.47816 .42385 m .47043 .43208 L .45863 .42581 L p 0 1 0 r
F P
0 g
s
.17736 .37388 m .18405 .36509 L .19652 .3709 L p 0 0 1 r
F P
0 g
s
.22811 .37371 m .23498 .36491 L .24733 .37073 L p 0 0 1 r
F P
0 g
s
.23498 .36491 m .22811 .37371 L .21573 .36791 L p 0 0 1 r
F P
0 g
s
.27886 .37354 m .28591 .36474 L .29814 .37055 L p 0 0 1 r
F P
0 g
s
.28591 .36474 m .27886 .37354 L .2666 .36774 L p 0 0 1 r
F P
0 g
s
.20833 .30825 m .21532 .2978 L .22773 .30363 L p 0 1 0 r
F P
0 g
s
.47396 .31758 m .4817 .31047 L .4935 .31893 L p 1 0 0 r
F P
0 g
s
.4817 .31047 m .47396 .31758 L .46216 .31064 L p 1 0 0 r
F P
0 g
s
.38039 .37319 m .3878 .36439 L .3998 .37021 L p 0 0 1 r
F P
0 g
s
.3878 .36439 m .38039 .37319 L .36836 .36739 L p 0 0 1 r
F P
0 g
s
.43116 .37302 m .43876 .36422 L .45064 .37004 L p 0 0 1 r
F P
0 g
s
.43876 .36422 m .43116 .37302 L .41926 .36722 L p 0 0 1 r
F P
0 g
s
.48994 .42871 m .49774 .41878 L .50945 .42198 L p 0 1 0 r
F P
0 g
s
.51728 .41004 m .50945 .42198 L .49774 .41878 L p 0 1 0 r
F P
0 g
s
.48194 .37285 m .48972 .36404 L .50148 .36986 L p 0 0 1 r
F P
0 g
s
.48972 .36404 m .48194 .37285 L .47016 .36704 L p 0 0 1 r
F P
0 g
s
.12313 .5618 m .1196 .57251 L .11856 .57008 L p 0 1 0 r
F P
0 g
s
.11856 .57008 m .1171 .56754 L .12313 .5618 L p 0 1 0 r
F P
0 g
s
.12313 .5618 m .1171 .56754 L .11528 .56337 L p 0 1 0 r
F P
0 g
s
.42739 .41734 m .43491 .41148 L .44678 .41893 L p 0 1 0 r
F P
0 g
s
.43491 .41148 m .42739 .41734 L .41555 .409 L p 0 1 0 r
F P
0 g
s
.58353 .3725 m .59167 .3637 L .60319 .36952 L p 0 0 1 r
F P
0 g
s
.59167 .3637 m .58353 .3725 L .57198 .3667 L p 0 0 1 r
F P
0 g
s
.63433 .37233 m .64265 .36352 L .65406 .36934 L p 0 0 1 r
F P
0 g
s
.64265 .36352 m .63433 .37233 L .6229 .36652 L p 0 0 1 r
F P
0 g
s
.22773 .30363 m .23457 .29484 L .2468 .30198 L p 0 1 0 r
F P
0 g
s
.23457 .29484 m .22773 .30363 L .21532 .2978 L p 0 1 0 r
F P
0 g
s
.68514 .37216 m .69364 .36335 L .70493 .36917 L p 0 0 1 r
F P
0 g
s
.69364 .36335 m .68514 .37216 L .67383 .36635 L p 0 0 1 r
F P
0 g
s
.40357 .32622 m .41116 .31479 L .42315 .31898 L p 1 0 0 r
F P
0 g
s
.42315 .31898 m .43076 .30848 L .44267 .31363 L p 1 0 0 r
F P
0 g
s
.43076 .30848 m .42315 .31898 L .41116 .31479 L p 1 0 0 r
F P
0 g
s
.27483 .42026 m .28206 .40967 L .29449 .41314 L p 1 0 0 r
F P
0 g
s
.30184 .40166 m .29449 .41314 L .28206 .40967 L p 1 0 0 r
F P
0 g
s
.73596 .37199 m .74464 .36318 L .75581 .369 L p 0 0 1 r
F P
0 g
s
.74464 .36318 m .73596 .37199 L .72476 .36618 L p 0 0 1 r
F P
0 g
s
.78679 .37181 m .79565 .363 L .8067 .36883 L p 0 0 1 r
F P
0 g
s
.79565 .363 m .78679 .37181 L .7757 .366 L p 0 0 1 r
F P
0 g
s
.44267 .31363 m .45031 .30431 L .46216 .31064 L p 1 0 0 r
F P
0 g
s
.45031 .30431 m .44267 .31363 L .43076 .30848 L p 1 0 0 r
F P
0 g
s
.49774 .41878 m .48994 .42871 L .47816 .42385 L p 0 1 0 r
F P
0 g
s
.83762 .37164 m .84666 .36283 L .85759 .36865 L p 0 0 1 r
F P
0 g
s
.84666 .36283 m .83762 .37164 L .82665 .36583 L p 0 0 1 r
F P
0 g
s
.25893 .3096 m .2657 .30276 L .27774 .31133 L p 0 1 0 r
F P
0 g
s
.2657 .30276 m .25893 .3096 L .2468 .30198 L p 0 1 0 r
F P
0 g
s
.12668 .51925 m .11718 .54695 L p .10836 .54986 L 0 1 0 r
F P
0 g
s
.10836 .54986 m .10633 .54641 L p .12668 .51925 L 0 1 0 r
F P
0 g
s
.10633 .54641 m .11119 .53178 L .12668 .51925 L p 0 1 0 r
F P
0 g
s
.62898 .49511 m .61964 .48701 L .60735 .46701 L p 1 0 0 r
F P
0 g
s
.60735 .46701 m .61643 .47332 L .62898 .49511 L p 1 0 0 r
F P
0 g
s
.25535 .42534 m .26241 .41592 L .27483 .42026 L p 1 0 0 r
F P
0 g
s
.26241 .41592 m .25535 .42534 L .243 .41987 L p 1 0 0 r
F P
0 g
s
.19652 .3709 m .20329 .36208 L .21573 .36791 L p 0 0 1 r
F P
0 g
s
.20329 .36208 m .19652 .3709 L .18405 .36509 L p 0 0 1 r
F P
0 g
s
.24733 .37073 m .25428 .36191 L .2666 .36774 L p 0 0 1 r
F P
0 g
s
.25428 .36191 m .24733 .37073 L .23498 .36491 L p 0 0 1 r
F P
0 g
s
.60076 .43961 m .59188 .43493 L .57983 .41807 L p 1 0 0 r
F P
0 g
s
.57983 .41807 m .58851 .42119 L .60076 .43961 L p 1 0 0 r
F P
0 g
s
.57158 .1589 m .57442 .15615 L .57618 .16192 L p 0 1 0 r
F P
0 g
s
.56426 .18786 m .57158 .1589 L p .57618 .16192 L 0 1 0 r
F P
0 g
s
.29814 .37055 m .30528 .36173 L .31748 .36756 L p 0 0 1 r
F P
0 g
s
.30528 .36173 m .29814 .37055 L .28591 .36474 L p 0 0 1 r
F P
0 g
s
.30184 .40166 m .30925 .38977 L .32167 .39241 L p 1 0 0 r
F P
0 g
s
.32915 .38004 m .32167 .39241 L .30925 .38977 L p 1 0 0 r
F P
0 g
s
.28206 .40967 m .27483 .42026 L .26241 .41592 L p 1 0 0 r
F P
0 g
s
.38389 .3349 m .39147 .32279 L .40357 .32622 L p 1 0 0 r
F P
0 g
s
.41116 .31479 m .40357 .32622 L .39147 .32279 L p 1 0 0 r
F P
0 g
s
.3998 .37021 m .40729 .36139 L .41926 .36722 L p 0 0 1 r
F P
0 g
s
.40729 .36139 m .3998 .37021 L .3878 .36439 L p 0 0 1 r
F P
0 g
s
.45064 .37004 m .45831 .36121 L .47016 .36704 L p 0 0 1 r
F P
0 g
s
.45831 .36121 m .45064 .37004 L .43876 .36422 L p 0 0 1 r
F P
0 g
s
.22395 .42101 m .23066 .41376 L .243 .41987 L p 1 0 0 r
F P
0 g
s
.23066 .41376 m .22395 .42101 L .21177 .41341 L p 1 0 0 r
F P
0 g
s
.56386 .30896 m .55624 .32978 L .54484 .3331 L p 0 1 0 r
F P
0 g
s
.54484 .3331 m .55259 .31354 L .56386 .30896 L p 0 1 0 r
F P
0 g
s
.50148 .36986 m .50934 .36104 L .52106 .36687 L p 0 0 1 r
F P
0 g
s
.50934 .36104 m .50148 .36986 L .48972 .36404 L p 0 0 1 r
F P
0 g
s
.41555 .409 m .42302 .40353 L .43491 .41148 L p 0 1 0 r
F P
0 g
s
.42302 .40353 m .41555 .409 L .4037 .40029 L p 0 1 0 r
F P
0 g
s
.60319 .36952 m .61141 .36069 L .6229 .36652 L p 0 0 1 r
F P
0 g
s
.61141 .36069 m .60319 .36952 L .59167 .3637 L p 0 0 1 r
F P
0 g
s
.65406 .36934 m .66246 .36052 L .67383 .36635 L p 0 0 1 r
F P
0 g
s
.66246 .36052 m .65406 .36934 L .64265 .36352 L p 0 0 1 r
F P
0 g
s
.70493 .36917 m .71351 .36034 L .72476 .36618 L p 0 0 1 r
F P
0 g
s
.71351 .36034 m .70493 .36917 L .69364 .36335 L p 0 0 1 r
F P
0 g
s
.45863 .42581 m .46632 .41825 L .47816 .42385 L p 0 1 0 r
F P
0 g
s
.46632 .41825 m .45863 .42581 L .44678 .41893 L p 0 1 0 r
F P
0 g
s
.75581 .369 m .76457 .36017 L .7757 .366 L p 0 0 1 r
F P
0 g
s
.76457 .36017 m .75581 .369 L .74464 .36318 L p 0 0 1 r
F P
0 g
s
.8067 .36883 m .81564 .35999 L .82665 .36583 L p 0 0 1 r
F P
0 g
s
.81564 .35999 m .8067 .36883 L .79565 .363 L p 0 0 1 r
F P
0 g
s
.46216 .31064 m .46987 .30273 L .4817 .31047 L p 1 0 0 r
F P
0 g
s
.46987 .30273 m .46216 .31064 L .45031 .30431 L p 1 0 0 r
F P
0 g
s
.52506 .335 m .51704 .33827 L .50527 .32817 L p 1 0 0 r
F P
0 g
s
.21573 .36791 m .22257 .35907 L .23498 .36491 L p 0 0 1 r
F P
0 g
s
.22257 .35907 m .21573 .36791 L .20329 .36208 L p 0 0 1 r
F P
0 g
s
.49774 .41878 m .50558 .40778 L .51728 .41004 L p 0 1 0 r
F P
0 g
s
.52511 .39687 m .51728 .41004 L .50558 .40778 L p 0 1 0 r
F P
0 g
s
.2666 .36774 m .27363 .3589 L .28591 .36474 L p 0 0 1 r
F P
0 g
s
.27363 .3589 m .2666 .36774 L .25428 .36191 L p 0 0 1 r
F P
0 g
s
.57525 .17883 m .56796 .20709 L .55677 .21477 L p 0 1 0 r
F P
0 g
s
.55677 .21477 m .56426 .18786 L .57525 .17883 L p 0 1 0 r
F P
0 g
s
.2468 .30198 m .25358 .29456 L .2657 .30276 L p 0 1 0 r
F P
0 g
s
.25358 .29456 m .2468 .30198 L .23457 .29484 L p 0 1 0 r
F P
0 g
s
.32469 .35872 m .31748 .36756 L .30528 .36173 L p 0 0 1 r
F P
0 g
s
.36836 .36739 m .37575 .35855 L .3878 .36439 L p 0 0 1 r
F P
0 g
s
.4037 .40029 m .4111 .39514 L .42302 .40353 L p 0 1 0 r
F P
0 g
s
.4111 .39514 m .4037 .40029 L .39184 .39126 L p 0 1 0 r
F P
0 g
s
.41926 .36722 m .42683 .35837 L .43876 .36422 L p 0 0 1 r
F P
0 g
s
.42683 .35837 m .41926 .36722 L .40729 .36139 L p 0 0 1 r
F P
0 g
s
.50527 .32817 m .51321 .32385 L .52506 .335 L p 1 0 0 r
F P
0 g
s
.51321 .32385 m .50527 .32817 L .4935 .31893 L p 1 0 0 r
F P
0 g
s
.47016 .36704 m .47791 .3582 L .48972 .36404 L p 0 0 1 r
F P
0 g
s
.47791 .3582 m .47016 .36704 L .45831 .36121 L p 0 0 1 r
F P
0 g
s
.65103 .56026 m .65414 .56654 L .65484 .5717 L p 1 0 0 r
F P
0 g
s
.529 .35802 m .52106 .36687 L .50934 .36104 L p 0 0 1 r
F P
0 g
s
.57198 .3667 m .58009 .35785 L .59167 .3637 L p 0 0 1 r
F P
0 g
s
.58009 .35785 m .57198 .3667 L .56037 .36086 L p 0 0 1 r
F P
0 g
s
.39147 .32279 m .38389 .3349 L .37168 .33201 L p 1 0 0 r
F P
0 g
s
.6229 .36652 m .6312 .35767 L .64265 .36352 L p 0 0 1 r
F P
0 g
s
.6312 .35767 m .6229 .36652 L .61141 .36069 L p 0 0 1 r
F P
0 g
s
.28206 .40967 m .28937 .39852 L .30184 .40166 L p 1 0 0 r
F P
0 g
s
.30925 .38977 m .30184 .40166 L .28937 .39852 L p 1 0 0 r
F P
0 g
s
.67383 .36635 m .68231 .3575 L .69364 .36335 L p 0 0 1 r
F P
0 g
s
.68231 .3575 m .67383 .36635 L .66246 .36052 L p 0 0 1 r
F P
0 g
s
.21532 .2978 m .22223 .28823 L .23457 .29484 L p 0 1 0 r
F P
0 g
s
.21177 .41341 m .21835 .40695 L .23066 .41376 L p 1 0 0 r
F P
0 g
s
.21835 .40695 m .21177 .41341 L .19966 .40502 L p 1 0 0 r
F P
0 g
s
.72476 .36618 m .73342 .35733 L .74464 .36318 L p 0 0 1 r
F P
0 g
s
.73342 .35733 m .72476 .36618 L .71351 .36034 L p 0 0 1 r
F P
0 g
s
.7757 .366 m .78455 .35715 L .79565 .363 L p 0 0 1 r
F P
0 g
s
.78455 .35715 m .7757 .366 L .76457 .36017 L p 0 0 1 r
F P
0 g
s
.82665 .36583 m .83568 .35698 L .84666 .36283 L p 0 0 1 r
F P
0 g
s
.83568 .35698 m .82665 .36583 L .81564 .35999 L p 0 0 1 r
F P
0 g
s
.30925 .38977 m .31672 .37753 L .32915 .38004 L p 1 0 0 r
F P
0 g
s
.33666 .36747 m .32915 .38004 L .31672 .37753 L p 1 0 0 r
F P
0 g
s
.29654 .31472 m .28973 .3202 L .27774 .31133 L p 0 1 0 r
F P
0 g
s
.57354 .15414 m .57442 .15615 L .57158 .1589 L p 0 1 0 r
F P
0 g
s
.4935 .31893 m .50137 .31361 L .51321 .32385 L p 1 0 0 r
F P
0 g
s
.50137 .31361 m .4935 .31893 L .4817 .31047 L p 1 0 0 r
F P
0 g
s
.39184 .39126 m .39917 .38637 L .4111 .39514 L p 0 1 0 r
F P
0 g
s
.39917 .38637 m .39184 .39126 L .37997 .38197 L p 0 1 0 r
F P
0 g
s
.6537 .56491 m .65414 .56654 L .65103 .56026 L p 1 0 0 r
F P
0 g
s
.65103 .56026 m .65346 .56322 L .6537 .56491 L p 1 0 0 r
F P
0 g
s
.18405 .36509 m .1908 .35623 L .20329 .36208 L p 0 0 1 r
F P
0 g
s
.41116 .31479 m .41877 .30377 L .43076 .30848 L p 1 0 0 r
F P
0 g
s
.43076 .30848 m .4384 .29852 L .45031 .30431 L p 1 0 0 r
F P
0 g
s
.4384 .29852 m .43076 .30848 L .41877 .30377 L p 1 0 0 r
F P
0 g
s
.5678 .26911 m .56025 .29224 L .54889 .29694 L p 0 1 0 r
F P
0 g
s
.54889 .29694 m .55659 .27513 L .5678 .26911 L p 0 1 0 r
F P
0 g
s
.47816 .42385 m .48595 .41472 L .49774 .41878 L p 0 1 0 r
F P
0 g
s
.48595 .41472 m .47816 .42385 L .46632 .41825 L p 0 1 0 r
F P
0 g
s
.243 .41987 m .24997 .41104 L .26241 .41592 L p 1 0 0 r
F P
0 g
s
.24997 .41104 m .243 .41987 L .23066 .41376 L p 1 0 0 r
F P
0 g
s
.23498 .36491 m .24191 .35605 L .25428 .36191 L p 0 0 1 r
F P
0 g
s
.24191 .35605 m .23498 .36491 L .22257 .35907 L p 0 0 1 r
F P
0 g
s
.28591 .36474 m .29302 .35588 L .30528 .36173 L p 0 0 1 r
F P
0 g
s
.29302 .35588 m .28591 .36474 L .27363 .3589 L p 0 0 1 r
F P
0 g
s
.44678 .41893 m .45444 .41196 L .46632 .41825 L p 0 1 0 r
F P
0 g
s
.45444 .41196 m .44678 .41893 L .43491 .41148 L p 0 1 0 r
F P
0 g
s
.3878 .36439 m .39527 .35553 L .40729 .36139 L p 0 0 1 r
F P
0 g
s
.39527 .35553 m .3878 .36439 L .37575 .35855 L p 0 0 1 r
F P
0 g
s
.50558 .40778 m .49774 .41878 L .48595 .41472 L p 0 1 0 r
F P
0 g
s
.57292 .39041 m .56439 .3887 L .55248 .37442 L p 1 0 0 r
F P
0 g
s
.55248 .37442 m .56085 .37476 L .57292 .39041 L p 1 0 0 r
F P
0 g
s
.64908 .54447 m .65054 .5495 L p .63528 .52256 L 1 0 0 r
F P
0 g
s
.65054 .5495 m .64797 .54637 L .63528 .52256 L p 1 0 0 r
F P
0 g
s
.63528 .52256 m .64488 .53256 L p .64908 .54447 L 1 0 0 r
F P
0 g
s
.39147 .32279 m .39908 .31095 L .41116 .31479 L p 1 0 0 r
F P
0 g
s
.41877 .30377 m .41116 .31479 L .39908 .31095 L p 1 0 0 r
F P
0 g
s
.43876 .36422 m .44641 .35535 L .45831 .36121 L p 0 0 1 r
F P
0 g
s
.44641 .35535 m .43876 .36422 L .42683 .35837 L p 0 0 1 r
F P
0 g
s
.61318 .45966 m .60407 .45331 L .59188 .43493 L p 1 0 0 r
F P
0 g
s
.59188 .43493 m .60076 .43961 L .61318 .45966 L p 1 0 0 r
F P
0 g
s
.5716 .22583 m .56416 .25144 L .55288 .2576 L p 0 1 0 r
F P
0 g
s
.55288 .2576 m .56049 .23333 L .5716 .22583 L p 0 1 0 r
F P
0 g
s
.48972 .36404 m .49756 .35518 L .50934 .36104 L p 0 0 1 r
F P
0 g
s
.49756 .35518 m .48972 .36404 L .47791 .3582 L p 0 0 1 r
F P
0 g
s
.50558 .40778 m .51344 .3956 L .52511 .39687 L p 0 1 0 r
F P
0 g
s
.53295 .38235 m .52511 .39687 L .51344 .3956 L p 0 1 0 r
F P
0 g
s
.26241 .41592 m .26958 .40579 L .28206 .40967 L p 1 0 0 r
F P
0 g
s
.28937 .39852 m .28206 .40967 L .26958 .40579 L p 1 0 0 r
F P
0 g
s
.59167 .3637 m .59987 .35483 L .61141 .36069 L p 0 0 1 r
F P
0 g
s
.59987 .35483 m .59167 .3637 L .58009 .35785 L p 0 0 1 r
F P
0 g
s
.64265 .36352 m .65103 .35465 L .66246 .36052 L p 0 0 1 r
F P
0 g
s
.65103 .35465 m .64265 .36352 L .6312 .35767 L p 0 0 1 r
F P
0 g
s
.57158 .1589 m .57303 .15254 L .57354 .15414 L p 0 1 0 r
F P
0 g
s
.19966 .40502 m .20608 .39939 L .21835 .40695 L p 1 0 0 r
F P
0 g
s
.20608 .39939 m .19966 .40502 L .18763 .39578 L p 1 0 0 r
F P
0 g
s
.45031 .30431 m .458 .29565 L .46987 .30273 L p 1 0 0 r
F P
0 g
s
.458 .29565 m .45031 .30431 L .4384 .29852 L p 1 0 0 r
F P
0 g
s
.69364 .36335 m .7022 .35448 L .71351 .36034 L p 0 0 1 r
F P
0 g
s
.7022 .35448 m .69364 .36335 L .68231 .3575 L p 0 0 1 r
F P
0 g
s
.37997 .38197 m .38723 .37728 L .39917 .38637 L p 0 1 0 r
F P
0 g
s
.38723 .37728 m .37997 .38197 L .36809 .37249 L p 0 1 0 r
F P
0 g
s
.74464 .36318 m .75338 .3543 L .76457 .36017 L p 0 0 1 r
F P
0 g
s
.75338 .3543 m .74464 .36318 L .73342 .35733 L p 0 0 1 r
F P
0 g
s
.23457 .29484 m .24138 .28678 L .25358 .29456 L p 0 1 0 r
F P
0 g
s
.24138 .28678 m .23457 .29484 L .22223 .28823 L p 0 1 0 r
F P
0 g
s
.26958 .40579 m .26241 .41592 L .24997 .41104 L p 1 0 0 r
F P
0 g
s
.79565 .363 m .80457 .35413 L .81564 .35999 L p 0 0 1 r
F P
0 g
s
.80457 .35413 m .79565 .363 L .78455 .35715 L p 0 0 1 r
F P
0 g
s
.27774 .31133 m .28452 .30546 L .29654 .31472 L p 0 1 0 r
F P
0 g
s
.28452 .30546 m .27774 .31133 L .2657 .30276 L p 0 1 0 r
F P
0 g
s
.4817 .31047 m .48952 .30423 L .50137 .31361 L p 1 0 0 r
F P
0 g
s
.48952 .30423 m .4817 .31047 L .46987 .30273 L p 1 0 0 r
F P
0 g
s
.20329 .36208 m .21011 .3532 L .22257 .35907 L p 0 0 1 r
F P
0 g
s
.21011 .3532 m .20329 .36208 L .1908 .35623 L p 0 0 1 r
F P
0 g
s
.57032 .1464 m .57303 .15254 L p .56052 .16812 L 0 1 0 r
F P
0 g
s
.57303 .15254 m .57158 .1589 L .56052 .16812 L p 0 1 0 r
F P
0 g
s
.25428 .36191 m .26128 .35303 L .27363 .3589 L p 0 0 1 r
F P
0 g
s
.26128 .35303 m .25428 .36191 L .24191 .35605 L p 0 0 1 r
F P
0 g
s
.30528 .36173 m .31246 .35285 L .32469 .35872 L p 0 0 1 r
F P
0 g
s
.31246 .35285 m .30528 .36173 L .29302 .35588 L p 0 0 1 r
F P
0 g
s
.51344 .3956 m .52132 .38214 L .53295 .38235 L p 0 1 0 r
F P
0 g
s
.54076 .36639 m .53295 .38235 L .52132 .38214 L p 0 1 0 r
F P
0 g
s
.36809 .37249 m .37529 .36793 L .38723 .37728 L p 0 1 0 r
F P
0 g
s
.37529 .36793 m .36809 .37249 L .3562 .36288 L p 0 1 0 r
F P
0 g
s
.37168 .33201 m .37928 .31959 L .39147 .32279 L p 1 0 0 r
F P
0 g
s
.39908 .31095 m .39147 .32279 L .37928 .31959 L p 1 0 0 r
F P
0 g
s
.18763 .39578 m .19387 .39105 L .20608 .39939 L p 1 0 0 r
F P
0 g
s
.19387 .39105 m .18763 .39578 L .17571 .38565 L p 1 0 0 r
F P
0 g
s
.40729 .36139 m .41484 .3525 L .42683 .35837 L p 0 0 1 r
F P
0 g
s
.41484 .3525 m .40729 .36139 L .39527 .35553 L p 0 0 1 r
F P
0 g
s
.31672 .37753 m .32422 .36502 L .33666 .36747 L p 1 0 0 r
F P
0 g
s
.45831 .36121 m .46604 .35232 L .47791 .3582 L p 0 0 1 r
F P
0 g
s
.46604 .35232 m .45831 .36121 L .44641 .35535 L p 0 0 1 r
F P
0 g
s
.64177 .51884 m .63214 .5088 L .61964 .48701 L p 1 0 0 r
F P
0 g
s
.61964 .48701 m .62898 .49511 L .64177 .51884 L p 1 0 0 r
F P
0 g
s
.28937 .39852 m .29675 .38688 L .30925 .38977 L p 1 0 0 r
F P
0 g
s
.31672 .37753 m .30925 .38977 L .29675 .38688 L p 1 0 0 r
F P
0 g
s
.50934 .36104 m .51725 .35215 L .529 .35802 L p 0 0 1 r
F P
0 g
s
.51725 .35215 m .50934 .36104 L .49756 .35518 L p 0 0 1 r
F P
0 g
s
.52132 .38214 m .52919 .36731 L .54076 .36639 L p 0 1 0 r
F P
0 g
s
.56037 .36086 m .56846 .35197 L .58009 .35785 L p 0 0 1 r
F P
0 g
s
.61141 .36069 m .61969 .3518 L .6312 .35767 L p 0 0 1 r
F P
0 g
s
.61969 .3518 m .61141 .36069 L .59987 .35483 L p 0 0 1 r
F P
0 g
s
.43491 .41148 m .44252 .40505 L .45444 .41196 L p 0 1 0 r
F P
0 g
s
.44252 .40505 m .43491 .41148 L .42302 .40353 L p 0 1 0 r
F P
0 g
s
.17571 .38565 m .18174 .38188 L .19387 .39105 L p 1 0 0 r
F P
0 g
s
.58511 .40743 m .5764 .40425 L .56439 .3887 L p 1 0 0 r
F P
0 g
s
.56439 .3887 m .57292 .39041 L .58511 .40743 L p 1 0 0 r
F P
0 g
s
.66246 .36052 m .67092 .35162 L .68231 .3575 L p 0 0 1 r
F P
0 g
s
.67092 .35162 m .66246 .36052 L .65103 .35465 L p 0 0 1 r
F P
0 g
s
.71351 .36034 m .72215 .35145 L .73342 .35733 L p 0 0 1 r
F P
0 g
s
.72215 .35145 m .71351 .36034 L .7022 .35448 L p 0 0 1 r
F P
0 g
s
.76457 .36017 m .7734 .35127 L .78455 .35715 L p 0 0 1 r
F P
0 g
s
.7734 .35127 m .76457 .36017 L .75338 .3543 L p 0 0 1 r
F P
0 g
s
.2657 .30276 m .27246 .29645 L .28452 .30546 L p 0 1 0 r
F P
0 g
s
.27246 .29645 m .2657 .30276 L .25358 .29456 L p 0 1 0 r
F P
0 g
s
.3562 .36288 m .36333 .35837 L .37529 .36793 L p 0 1 0 r
F P
0 g
s
.81564 .35999 m .82465 .3511 L .83568 .35698 L p 0 0 1 r
F P
0 g
s
.82465 .3511 m .81564 .35999 L .80457 .35413 L p 0 0 1 r
F P
0 g
s
.23066 .41376 m .23753 .40558 L .24997 .41104 L p 1 0 0 r
F P
0 g
s
.23753 .40558 m .23066 .41376 L .21835 .40695 L p 1 0 0 r
F P
0 g
s
.11718 .54695 m .11303 .55951 L .11177 .55664 L p 0 1 0 r
F P
0 g
s
.11177 .55664 m .11002 .55362 L .11718 .54695 L p 0 1 0 r
F P
0 g
s
.11718 .54695 m .11002 .55362 L .10836 .54986 L p 0 1 0 r
F P
0 g
s
.22257 .35907 m .22947 .35017 L .24191 .35605 L p 0 0 1 r
F P
0 g
s
.22947 .35017 m .22257 .35907 L .21011 .3532 L p 0 0 1 r
F P
0 g
s
.46632 .41825 m .47409 .40986 L .48595 .41472 L p 0 1 0 r
F P
0 g
s
.47409 .40986 m .46632 .41825 L .45444 .41196 L p 0 1 0 r
F P
0 g
s
.27363 .3589 m .28071 .34999 L .29302 .35588 L p 0 0 1 r
F P
0 g
s
.28071 .34999 m .27363 .3589 L .26128 .35303 L p 0 0 1 r
F P
0 g
s
.46987 .30273 m .47765 .29562 L .48952 .30423 L p 1 0 0 r
F P
0 g
s
.47765 .29562 m .46987 .30273 L .458 .29565 L p 1 0 0 r
F P
0 g
s
.37575 .35855 m .3832 .34964 L .39527 .35553 L p 0 0 1 r
F P
0 g
s
.3832 .34964 m .37575 .35855 L .36365 .35268 L p 0 0 1 r
F P
0 g
s
.42683 .35837 m .43446 .34947 L .44641 .35535 L p 0 0 1 r
F P
0 g
s
.43446 .34947 m .42683 .35837 L .41484 .3525 L p 0 0 1 r
F P
0 g
s
.47791 .3582 m .48572 .34929 L .49756 .35518 L p 0 0 1 r
F P
0 g
s
.48572 .34929 m .47791 .3582 L .46604 .35232 L p 0 0 1 r
F P
0 g
s
.57158 .1589 m .56426 .18786 L .55301 .19572 L p 0 1 0 r
F P
0 g
s
.55301 .19572 m .56052 .16812 L .57158 .1589 L p 0 1 0 r
F P
0 g
s
.48595 .41472 m .49379 .40459 L .50558 .40778 L p 0 1 0 r
F P
0 g
s
.51344 .3956 m .50558 .40778 L .49379 .40459 L p 0 1 0 r
F P
0 g
s
.22223 .28823 m .22908 .27946 L .24138 .28678 L p 0 1 0 r
F P
0 g
s
.58009 .35785 m .58827 .34894 L .59987 .35483 L p 0 0 1 r
F P
0 g
s
.58827 .34894 m .58009 .35785 L .56846 .35197 L p 0 0 1 r
F P
0 g
s
.39908 .31095 m .4067 .29946 L .41877 .30377 L p 1 0 0 r
F P
0 g
s
.41877 .30377 m .42641 .29323 L .4384 .29852 L p 1 0 0 r
F P
0 g
s
.42641 .29323 m .41877 .30377 L .4067 .29946 L p 1 0 0 r
F P
0 g
s
.6312 .35767 m .63955 .34876 L .65103 .35465 L p 0 0 1 r
F P
0 g
s
.63955 .34876 m .6312 .35767 L .61969 .3518 L p 0 0 1 r
F P
0 g
s
.26958 .40579 m .27684 .39503 L .28937 .39852 L p 1 0 0 r
F P
0 g
s
.29675 .38688 m .28937 .39852 L .27684 .39503 L p 1 0 0 r
F P
0 g
s
.68231 .3575 m .69085 .34859 L .7022 .35448 L p 0 0 1 r
F P
0 g
s
.69085 .34859 m .68231 .3575 L .67092 .35162 L p 0 0 1 r
F P
0 g
s
.73342 .35733 m .74215 .34841 L .75338 .3543 L p 0 0 1 r
F P
0 g
s
.74215 .34841 m .73342 .35733 L .72215 .35145 L p 0 0 1 r
F P
0 g
s
.42302 .40353 m .43056 .39757 L .44252 .40505 L p 0 1 0 r
F P
0 g
s
.43056 .39757 m .42302 .40353 L .4111 .39514 L p 0 1 0 r
F P
0 g
s
.4384 .29852 m .44608 .28917 L .458 .29565 L p 1 0 0 r
F P
0 g
s
.44608 .28917 m .4384 .29852 L .42641 .29323 L p 1 0 0 r
F P
0 g
s
.56025 .29224 m .55259 .31354 L .54111 .31697 L p 0 1 0 r
F P
0 g
s
.54111 .31697 m .54889 .29694 L .56025 .29224 L p 0 1 0 r
F P
0 g
s
.78455 .35715 m .79345 .34823 L .80457 .35413 L p 0 0 1 r
F P
0 g
s
.79345 .34823 m .78455 .35715 L .7734 .35127 L p 0 0 1 r
F P
0 g
s
.25358 .29456 m .26034 .28774 L .27246 .29645 L p 0 1 0 r
F P
0 g
s
.26034 .28774 m .25358 .29456 L .24138 .28678 L p 0 1 0 r
F P
0 g
s
.49379 .40459 m .48595 .41472 L .47409 .40986 L p 0 1 0 r
F P
0 g
s
.56052 .16812 m .56783 .13853 L .57032 .1464 L p 0 1 0 r
F P
0 g
s
.24997 .41104 m .25706 .40143 L .26958 .40579 L p 1 0 0 r
F P
0 g
s
.25706 .40143 m .24997 .41104 L .23753 .40558 L p 1 0 0 r
F P
0 g
s
.1908 .35623 m .19759 .3473 L .21011 .3532 L p 0 0 1 r
F P
0 g
s
.29675 .38688 m .3042 .37483 L .31672 .37753 L p 1 0 0 r
F P
0 g
s
.32422 .36502 m .31672 .37753 L .3042 .37483 L p 1 0 0 r
F P
0 g
s
.24191 .35605 m .24888 .34713 L .26128 .35303 L p 0 0 1 r
F P
0 g
s
.24888 .34713 m .24191 .35605 L .22947 .35017 L p 0 0 1 r
F P
0 g
s
.37928 .31959 m .3869 .30739 L .39908 .31095 L p 1 0 0 r
F P
0 g
s
.4067 .29946 m .39908 .31095 L .3869 .30739 L p 1 0 0 r
F P
0 g
s
.6258 .48147 m .61643 .47332 L .60407 .45331 L p 1 0 0 r
F P
0 g
s
.60407 .45331 m .61318 .45966 L .6258 .48147 L p 1 0 0 r
F P
0 g
s
.29302 .35588 m .30018 .34695 L .31246 .35285 L p 0 0 1 r
F P
0 g
s
.30018 .34695 m .29302 .35588 L .28071 .34999 L p 0 0 1 r
F P
0 g
s
.27684 .39503 m .26958 .40579 L .25706 .40143 L p 1 0 0 r
F P
0 g
s
.39527 .35553 m .4028 .3466 L .41484 .3525 L p 0 0 1 r
F P
0 g
s
.4028 .3466 m .39527 .35553 L .3832 .34964 L p 0 0 1 r
F P
0 g
s
.44641 .35535 m .45412 .34642 L .46604 .35232 L p 0 0 1 r
F P
0 g
s
.45412 .34642 m .44641 .35535 L .43446 .34947 L p 0 0 1 r
F P
0 g
s
.59742 .42593 m .58851 .42119 L .5764 .40425 L p 1 0 0 r
F P
0 g
s
.5764 .40425 m .58511 .40743 L .59742 .42593 L p 1 0 0 r
F P
0 g
s
.49756 .35518 m .50544 .34625 L .51725 .35215 L p 0 0 1 r
F P
0 g
s
.50544 .34625 m .49756 .35518 L .48572 .34929 L p 0 0 1 r
F P
0 g
s
.21835 .40695 m .22509 .39949 L .23753 .40558 L p 1 0 0 r
F P
0 g
s
.22509 .39949 m .21835 .40695 L .20608 .39939 L p 1 0 0 r
F P
0 g
s
.59987 .35483 m .60812 .34589 L .61969 .3518 L p 0 0 1 r
F P
0 g
s
.60812 .34589 m .59987 .35483 L .58827 .34894 L p 0 0 1 r
F P
0 g
s
.65103 .35465 m .65947 .34572 L .67092 .35162 L p 0 0 1 r
F P
0 g
s
.65947 .34572 m .65103 .35465 L .63955 .34876 L p 0 0 1 r
F P
0 g
s
.7022 .35448 m .71083 .34554 L .72215 .35145 L p 0 0 1 r
F P
0 g
s
.71083 .34554 m .7022 .35448 L .69085 .34859 L p 0 0 1 r
F P
0 g
s
.4111 .39514 m .41859 .38958 L .43056 .39757 L p 0 1 0 r
F P
0 g
s
.41859 .38958 m .4111 .39514 L .39917 .38637 L p 0 1 0 r
F P
0 g
s
.75338 .3543 m .76219 .34537 L .7734 .35127 L p 0 0 1 r
F P
0 g
s
.76219 .34537 m .75338 .3543 L .74215 .34841 L p 0 0 1 r
F P
0 g
s
.80457 .35413 m .81356 .34519 L .82465 .3511 L p 0 0 1 r
F P
0 g
s
.81356 .34519 m .80457 .35413 L .79345 .34823 L p 0 0 1 r
F P
0 g
s
.458 .29565 m .46574 .28773 L .47765 .29562 L p 1 0 0 r
F P
0 g
s
.46574 .28773 m .458 .29565 L .44608 .28917 L p 1 0 0 r
F P
0 g
s
.45444 .41196 m .46217 .40425 L .47409 .40986 L p 0 1 0 r
F P
0 g
s
.46217 .40425 m .45444 .41196 L .44252 .40505 L p 0 1 0 r
F P
0 g
s
.56796 .20709 m .56049 .23333 L .54913 .23966 L p 0 1 0 r
F P
0 g
s
.54913 .23966 m .55677 .21477 L .56796 .20709 L p 0 1 0 r
F P
0 g
s
.21011 .3532 m .21698 .34426 L .22947 .35017 L p 0 0 1 r
F P
0 g
s
.21698 .34426 m .21011 .3532 L .19759 .3473 L p 0 0 1 r
F P
0 g
s
.56416 .25144 m .55659 .27513 L .54515 .27996 L p 0 1 0 r
F P
0 g
s
.54515 .27996 m .55288 .2576 L .56416 .25144 L p 0 1 0 r
F P
0 g
s
.49379 .40459 m .50166 .39336 L .51344 .3956 L p 0 1 0 r
F P
0 g
s
.52132 .38214 m .51344 .3956 L .50166 .39336 L p 0 1 0 r
F P
0 g
s
.24138 .28678 m .24816 .27938 L .26034 .28774 L p 0 1 0 r
F P
0 g
s
.24816 .27938 m .24138 .28678 L .22908 .27946 L p 0 1 0 r
F P
0 g
s
.26128 .35303 m .26833 .34408 L .28071 .34999 L p 0 0 1 r
F P
0 g
s
.26833 .34408 m .26128 .35303 L .24888 .34713 L p 0 0 1 r
F P
0 g
s
.53322 .33291 m .52506 .335 L .51321 .32385 L p 1 0 0 r
F P
0 g
s
.51321 .32385 m .52126 .32063 L .53322 .33291 L p 1 0 0 r
F P
0 g
s
.52126 .32063 m .51321 .32385 L .50137 .31361 L p 1 0 0 r
F P
0 g
s
.3197 .3439 m .31246 .35285 L .30018 .34695 L p 0 0 1 r
F P
0 g
s
.53322 .33291 m .52126 .32063 L p .53145 .3264 L 1 0 0 r
F P
0 g
s
.55259 .31354 m .54484 .3331 L .53517 .33492 L p 0 1 0 r
F P
0 g
s
.53514 .33484 m .55259 .31354 L .53517 .33492 L 0 1 0 r
F
.53466 .33372 m .55259 .31354 L .53505 .33495 L F
.54111 .31697 m .55259 .31354 L p .53465 .33373 L F P
0 g
s
.52506 .335 m .53322 .33291 L .53505 .33495 L p 1 0 0 r
F P
0 g
s
.53505 .33495 m .54484 .3331 L p .53702 .34069 L 0 1 0 r
F P
0 g
s
.53637 .34132 m .53505 .33495 L .53702 .34069 L 0 1 0 r
F
.53637 .34132 m .53505 .33495 L .5356 .33672 L 1 0 0 r
F
.53659 .34144 m .53528 .33521 L .53784 .34125 L 0 0 1 r
F
.53659 .34144 m .5356 .33672 L .53717 .34177 L 1 0 0 r
F
.53637 .34132 m .5356 .33672 L .53659 .34144 L F
.52506 .335 m .53505 .33495 L .53637 .34132 L F
.52522 .3432 m .53494 .33548 L .53618 .34151 L 0 0 1 r
F
.53484 .33499 m .53505 .33495 L p .53489 .33523 L 0 1 0 r
F P
0 g
s
.53528 .33521 m .54504 .34014 L p .53784 .34125 L 0 0 1 r
F P
0 g
s
.52522 .3432 m .53324 .33418 L .53461 .33487 L p 0 0 1 r
F P
0 g
s
.53461 .33487 m .53484 .33499 L p .53467 .33513 L 0 0 1 r
F P
0 g
s
.52522 .3432 m .53461 .33487 L .53467 .33513 L 0 0 1 r
F
.53505 .33495 m .53322 .33291 L p .53456 .33383 L 1 0 0 r
F P
0 g
s
.53505 .33495 m .53484 .33499 L p .53456 .33383 L 0 1 0 r
F P
0 g
s
.53456 .33383 m .53466 .33372 L .53505 .33495 L 0 1 0 r
F
.53456 .33383 m .53469 .33391 L .53505 .33495 L 1 0 0 r
F
.53618 .34151 m .53505 .33495 L .53637 .34132 L 0 1 0 r
F
.53489 .33523 m .53505 .33495 L .53618 .34151 L F
.53528 .33521 m .53505 .33495 L p .53522 .33506 L 1 0 0 r
F P
0 g
s
.55315 .3311 m .54504 .34014 L .53528 .33521 L p 0 0 1 r
F P
0 g
s
.53717 .34177 m .5356 .33672 L .54521 .34627 L 1 0 0 r
F
.53505 .33495 m .53528 .33521 L p .5356 .33672 L F P
0 g
s
.53528 .33521 m .54521 .34627 L p .5356 .33672 L 1 0 0 r
F P
0 g
s
.53497 .33496 m .53522 .33491 L .535 .33507 L 0 0 1 r
F
.53522 .33491 m .55315 .3311 L .53524 .33502 L F
.53517 .33492 m .53505 .33495 L p .53514 .33484 L 0 1 0 r
F P
0 g
s
.53475 .33395 m .53522 .33506 L .53505 .33495 L 1 0 0 r
F
.53522 .33491 m .53524 .33502 L .535 .33507 L 0 0 1 r
F
.53528 .33521 m .535 .33507 L p .5352 .33502 L F P
0 g
s
.5352 .33502 m .55315 .3311 L .53528 .33521 L 0 0 1 r
F
.53469 .33391 m .53475 .33395 L .53505 .33495 L 1 0 0 r
F
.53441 .334 m .53456 .33383 L .53484 .33499 L 0 1 0 r
F
.53441 .334 m .55315 .3311 L .53484 .33499 L 0 0 1 r
F
.53475 .33395 m .55365 .34675 L .53522 .33506 L 1 0 0 r
F
.56491 .33708 m .55678 .34607 L .54504 .34014 L p 0 0 1 r
F P
0 g
s
.54504 .34014 m .55315 .3311 L .56491 .33708 L p 0 0 1 r
F P
0 g
s
.53456 .33383 m .53471 .33379 L .53475 .33395 L 1 0 0 r
F
.53322 .33291 m .53433 .3328 L p .53456 .33383 L F P
0 g
s
.54133 .3251 m .55315 .3311 L p .53498 .33391 L 0 0 1 r
F P
0 g
s
.5349 .33374 m .54133 .3251 L .53498 .33391 L 0 0 1 r
F
.53433 .3328 m .54111 .31697 L p .53465 .33373 L 0 1 0 r
F P
0 g
s
.53449 .33279 m .54133 .3251 L p .53475 .33395 L 0 0 1 r
F P
0 g
s
.52522 .3432 m .51339 .33725 L p .53298 .33422 L 0 0 1 r
F P
0 g
s
.53324 .33418 m .53303 .33442 L p .53298 .33422 L 0 0 1 r
F P
0 g
s
.53303 .33442 m .52522 .3432 L p .53298 .33422 L 0 0 1 r
F P
0 g
s
.51339 .33725 m .52139 .32819 L .53324 .33418 L p 0 0 1 r
F P
0 g
s
.53734 .30048 m .54889 .29694 L p .52983 .31882 L 0 1 0 r
F P
0 g
s
.52126 .32063 m .52944 .3186 L .5299 .31911 L p 1 0 0 r
F P
0 g
s
.52126 .32063 m .5299 .31911 L .52991 .31916 L 1 0 0 r
F
.52944 .3186 m .52889 .31803 L p .52654 .31142 L F P
0 g
s
.52889 .31803 m .51742 .30616 L p .52654 .31142 L 1 0 0 r
F P
0 g
s
.5256 .30289 m .53734 .30048 L p .52729 .31066 L 0 1 0 r
F P
0 g
s
.52609 .30737 m .5256 .30289 L .52729 .31066 L 0 1 0 r
F
.52492 .30439 m .5256 .30289 L p .52615 .30787 L F P
0 g
s
.52492 .30439 m .52615 .30787 L .52654 .31142 L 0 1 0 r
F
.52654 .31142 m .52609 .30737 L .52729 .31066 L F
.53734 .30048 m .52974 .31858 L p .52654 .31142 L F P
0 g
s
.52976 .31852 m .53734 .30048 L p .52983 .31882 L 0 1 0 r
F P
0 g
s
.52994 .31916 m .54111 .31697 L p .53226 .32573 L 0 1 0 r
F P
0 g
s
.53154 .32645 m .52994 .31916 L .53226 .32573 L 0 1 0 r
F
.53425 .33281 m .53322 .33291 L p .53145 .3264 L 1 0 0 r
F P
0 g
s
.53134 .32665 m .53154 .32645 L .5342 .33311 L 0 1 0 r
F
.54111 .31697 m .53433 .3328 L p .53154 .32645 L F P
0 g
s
.53145 .3264 m .53154 .32645 L .53425 .33281 L 1 0 0 r
F
.53154 .32645 m .53399 .33203 L .53425 .33281 L F
.53433 .3328 m .53425 .33281 L p .53348 .33049 L F P
0 g
s
.54133 .3251 m .53449 .33279 L p .53177 .32658 L 0 0 1 r
F P
0 g
s
.53228 .32687 m .53373 .33105 L .53348 .33049 L 1 0 0 r
F
.53373 .33105 m .53433 .3328 L .53348 .33049 L F
.53433 .3328 m .5342 .33311 L p .53154 .32645 L 0 1 0 r
F P
0 g
s
.53154 .32645 m .53177 .32658 L .53399 .33203 L 1 0 0 r
F
.53177 .32658 m .53228 .32687 L .53348 .33049 L F
.53177 .32658 m .53348 .33049 L .53399 .33203 L F
.5302 .31945 m .54133 .3251 L p .53318 .32636 L 0 0 1 r
F P
0 g
s
.54998 .33269 m .54151 .3321 L .5302 .31945 L p 1 0 0 r
F P
0 g
s
.5302 .31945 m .52994 .31916 L p .53013 .31929 L 1 0 0 r
F P
0 g
s
.54889 .29694 m .54111 .31697 L .52994 .31916 L p 0 1 0 r
F P
0 g
s
.52994 .31916 m .5299 .31911 L p .52987 .319 L 1 0 0 r
F P
0 g
s
.52981 .31885 m .54889 .29694 L .52994 .31916 L 0 1 0 r
F
.52984 .31887 m .53 .31898 L .52994 .31916 L 1 0 0 r
F
.54947 .31595 m .54133 .3251 L .5302 .31945 L p 0 0 1 r
F P
0 g
s
.53007 .31914 m .53015 .31913 L .5302 .31945 L 0 0 1 r
F
.53015 .31913 m .54947 .31595 L .53029 .31943 L F
.53015 .31913 m .53029 .31943 L .5302 .31945 L F
.53 .31898 m .53013 .31929 L .52994 .31916 L 1 0 0 r
F
.5299 .31911 m .52994 .31916 L p .52991 .31916 L F P
0 g
s
.52994 .31916 m .52972 .3192 L p .52981 .31885 L 0 1 0 r
F P
0 g
s
.52964 .31904 m .52981 .31885 L .52972 .3192 L 0 1 0 r
F
.52987 .319 m .52984 .31887 L .52994 .31916 L 1 0 0 r
F
.53 .31898 m .5301 .31897 L .53001 .31902 L 0 0 1 r
F
.5301 .31897 m .54947 .31595 L .53013 .31913 L F
.56131 .322 m .55315 .3311 L .54133 .3251 L p F P
0 g
s
.54133 .3251 m .54947 .31595 L .56131 .322 L p 0 0 1 r
F P
0 g
s
.53777 .31788 m .54998 .33269 L p .53 .31898 L 1 0 0 r
F P
0 g
s
.52981 .31885 m .52974 .31858 L .52983 .31883 L 0 1 0 r
F
.52983 .31883 m .52976 .31852 L .52983 .31882 L F
.52974 .31858 m .52976 .31852 L p .52983 .31883 L F P
0 g
s
.52944 .3186 m .5299 .31856 L p .53 .31898 L 1 0 0 r
F P
0 g
s
.5299 .31911 m .52944 .3186 L p .52981 .31885 L 1 0 0 r
F P
0 g
s
.52981 .31885 m .52984 .31887 L .5299 .31911 L 1 0 0 r
F
.53757 .30988 m .54947 .31595 L p .52964 .31904 L 0 0 1 r
F P
0 g
s
.52945 .31907 m .52961 .31889 L p .52964 .31904 L 0 0 1 r
F P
0 g
s
.52964 .31904 m .52972 .31862 L .52981 .31885 L 0 1 0 r
F
.52961 .31889 m .52972 .31862 L p .52964 .31904 L F P
0 g
s
.52961 .31889 m .53757 .30988 L p .52964 .31904 L 0 0 1 r
F P
0 g
s
.52972 .3192 m .52945 .31907 L p .52964 .31904 L 0 0 1 r
F P
0 g
s
.52946 .31925 m .52961 .31889 L p .52964 .31904 L 0 1 0 r
F P
0 g
s
.5299 .31856 m .53777 .31788 L p .53 .31898 L 1 0 0 r
F P
0 g
s
.52964 .31904 m .53 .31898 L .52972 .3192 L 0 0 1 r
F
.53 .31898 m .53001 .31902 L .52972 .3192 L F
.5301 .31897 m .53013 .31913 L .52972 .3192 L F
.52994 .31916 m .5302 .31945 L p .53154 .32645 L 1 0 0 r
F P
0 g
s
.53177 .32658 m .5302 .31945 L .53318 .32636 L 0 0 1 r
F
.5302 .31945 m .54151 .3321 L p .53177 .32658 L 1 0 0 r
F P
0 g
s
.53154 .32645 m .5302 .31945 L .53177 .32658 L 1 0 0 r
F
.5299 .31856 m .52974 .31858 L p .52908 .3167 L F P
0 g
s
.52972 .31862 m .52974 .31858 L p .52981 .31885 L 0 1 0 r
F P
0 g
s
.52944 .3186 m .52126 .32063 L .50934 .30933 L p 1 0 0 r
F P
0 g
s
.50934 .30933 m .51742 .30616 L .52944 .3186 L p 1 0 0 r
F P
0 g
s
.52945 .31907 m .52841 .31854 L p .52914 .31785 L 0 0 1 r
F P
0 g
s
.52961 .31889 m .52945 .31907 L p .52914 .31785 L 0 0 1 r
F P
0 g
s
.52654 .31142 m .52875 .31635 L .52944 .3186 L 1 0 0 r
F
.52974 .31858 m .52944 .3186 L p .52835 .31507 L F P
0 g
s
.52908 .3167 m .52974 .31858 L .52835 .31507 L 1 0 0 r
F
.52974 .31858 m .52961 .31889 L p .52654 .31142 L 0 1 0 r
F P
0 g
s
.52654 .31142 m .52961 .31889 L .528 .31534 L 0 1 0 r
F
.52633 .31164 m .52654 .31142 L .528 .31534 L F
.52679 .31156 m .53757 .30988 L .52945 .31755 L 0 0 1 r
F
.52654 .31142 m .52679 .31156 L .52875 .31635 L 1 0 0 r
F
.52679 .31156 m .52835 .31507 L .52875 .31635 L F
.52679 .31156 m .52945 .31755 L .52841 .31854 L 0 0 1 r
F
.52679 .31156 m .52737 .31189 L .52835 .31507 L 1 0 0 r
F
.52737 .31189 m .52908 .3167 L .52835 .31507 L F
.52914 .31785 m .52945 .31755 L .52961 .31889 L 0 0 1 r
F
.53757 .30988 m .5299 .31856 L p .52945 .31755 L F P
0 g
s
.5299 .31856 m .52961 .31889 L p .52945 .31755 L 0 0 1 r
F P
0 g
s
.52126 .32063 m .52994 .31916 L .53154 .32645 L 1 0 0 r
F
.50137 .31361 m .50934 .30933 L .52126 .32063 L p F P
0 g
s
.52945 .31907 m .52139 .32819 L .50949 .32218 L p 0 0 1 r
F P
0 g
s
.50949 .32218 m .51752 .31301 L .52945 .31907 L p 0 0 1 r
F P
0 g
s
.52961 .31889 m .52946 .31925 L p .528 .31534 L 0 1 0 r
F P
0 g
s
.52785 .31825 m .51752 .31301 L p .52633 .31164 L 0 0 1 r
F P
0 g
s
.51742 .30616 m .52486 .3044 L p .52641 .31134 L 1 0 0 r
F P
0 g
s
.51742 .30616 m .50541 .29471 L p .52381 .30337 L 1 0 0 r
F P
0 g
s
.52381 .30337 m .52463 .30375 L .52402 .30395 L 1 0 0 r
F
.52381 .30337 m .52402 .30395 L .51742 .30616 L F
.52463 .30375 m .52465 .30381 L .51742 .30616 L F
.52492 .30439 m .51742 .30616 L p .52465 .30381 L F P
0 g
s
.52486 .3044 m .52492 .30439 L p .52641 .31134 L 1 0 0 r
F P
0 g
s
.52562 .30378 m .53757 .30988 L p .5278 .31141 L 0 0 1 r
F P
0 g
s
.52641 .31134 m .52492 .30439 L .52679 .31156 L 1 0 0 r
F
.52492 .30439 m .5257 .30685 L .52679 .31156 L F
.52633 .31164 m .52579 .3093 L .52654 .31142 L 0 1 0 r
F
.52579 .3093 m .52492 .30439 L .52654 .31142 L F
.51752 .31301 m .52475 .30477 L p .52633 .31164 L 0 0 1 r
F P
0 g
s
.52443 .30547 m .52475 .30477 L p .52579 .3093 L 0 1 0 r
F P
0 g
s
.52475 .30477 m .52492 .30439 L p .52579 .3093 L 0 1 0 r
F P
0 g
s
.52633 .31164 m .52475 .30477 L .5278 .31141 L 0 0 1 r
F
.52492 .30439 m .52512 .30434 L p .5257 .30685 L 1 0 0 r
F P
0 g
s
.52448 .30307 m .52446 .30301 L .52448 .30306 L 0 1 0 r
F
.50541 .29471 m .52446 .30301 L .52451 .30323 L 1 0 0 r
F
.5247 .30369 m .52492 .30439 L .52465 .3038 L 0 1 0 r
F
.52463 .30375 m .5247 .30369 L .52465 .3038 L F
.52463 .30375 m .52454 .303 L .5247 .30369 L F
.5256 .30289 m .52492 .30439 L p .5247 .30369 L F P
0 g
s
.52463 .30375 m .52479 .30336 L .52491 .30389 L 1 0 0 r
F
.50541 .29471 m .52451 .30323 L .52463 .30375 L F
.52448 .30307 m .52454 .303 L .52463 .30375 L 0 1 0 r
F
.52454 .303 m .5256 .30289 L p .5247 .30369 L F P
0 g
s
.52451 .30323 m .52479 .30336 L .52463 .30375 L 1 0 0 r
F
.52441 .30313 m .52448 .30307 L .52463 .30375 L 0 1 0 r
F
.48957 .32528 m .49752 .31613 L .50949 .32218 L p 0 0 1 r
F P
0 g
s
.51752 .31301 m .50949 .32218 L .49752 .31613 L p 0 0 1 r
F P
0 g
s
.50934 .30933 m .50137 .31361 L .48952 .30423 L p 1 0 0 r
F P
0 g
s
.48952 .30423 m .49742 .29895 L .50934 .30933 L p 1 0 0 r
F P
0 g
s
.51742 .30616 m .50934 .30933 L .49742 .29895 L p 1 0 0 r
F P
0 g
s
.49752 .31613 m .50553 .30692 L .51752 .31301 L p 0 0 1 r
F P
0 g
s
.52492 .30439 m .52475 .30477 L p .52465 .3038 L 0 1 0 r
F P
0 g
s
.52465 .3038 m .52475 .30477 L .52448 .30419 L 0 1 0 r
F
.52471 .30379 m .52492 .30439 L .52465 .30381 L 1 0 0 r
F
.49742 .29895 m .50541 .29471 L .51742 .30616 L p F P
0 g
s
.51752 .31301 m .50553 .30692 L p .52438 .30397 L 0 0 1 r
F P
0 g
s
.52438 .30397 m .52463 .30375 L .52446 .30415 L 0 1 0 r
F
.52475 .30477 m .51752 .31301 L p .52438 .30397 L 0 0 1 r
F P
0 g
s
.52463 .30375 m .52465 .30381 L .52465 .30381 L 1 0 0 r
F
.52463 .30375 m .52465 .3038 L .52448 .30419 L 0 1 0 r
F
.52446 .30415 m .52448 .30419 L .51764 .32043 L F
.52463 .30375 m .52448 .30419 L .52446 .30415 L F
.50541 .29471 m .51352 .29162 L .52446 .30301 L p 1 0 0 r
F P
0 g
s
.50553 .30692 m .5136 .29764 L .52388 .30289 L p 0 0 1 r
F P
0 g
s
.52424 .30329 m .52446 .30301 L .52448 .30307 L 0 1 0 r
F
.52388 .30289 m .52418 .30304 L p .52438 .30397 L 0 0 1 r
F P
0 g
s
.50553 .30692 m .52388 .30289 L .52438 .30397 L 0 0 1 r
F
.50567 .32054 m .52422 .30324 L .52424 .30329 L 0 1 0 r
F
.52422 .30324 m .52446 .30301 L .52424 .30329 L F
.52463 .30375 m .52471 .30379 L .52465 .30381 L 1 0 0 r
F
.50567 .32054 m .51369 .30418 L .52418 .30304 L p 0 1 0 r
F P
0 g
s
.52418 .30304 m .52446 .30301 L p .52422 .30324 L 0 1 0 r
F P
0 g
s
.50567 .32054 m .52418 .30304 L .52422 .30324 L 0 1 0 r
F
.52446 .30301 m .52479 .30336 L p .52451 .30323 L 1 0 0 r
F P
0 g
s
.52446 .30301 m .52454 .303 L p .52448 .30306 L 0 1 0 r
F P
0 g
s
.52446 .30301 m .52349 .302 L p .52294 .29965 L 1 0 0 r
F P
0 g
s
.52433 .30273 m .53352 .28364 L .52446 .30301 L 0 1 0 r
F
.52349 .302 m .51352 .29162 L p .52138 .29622 L 1 0 0 r
F P
0 g
s
.52138 .29622 m .52294 .29965 L .52349 .302 L 1 0 0 r
F
.52115 .29646 m .52138 .29622 L .52418 .30304 L 0 1 0 r
F
.52138 .29622 m .53352 .28364 L .52433 .30273 L F
.52138 .29622 m .52433 .30273 L .52418 .30304 L F
.52138 .29622 m .52165 .29638 L .52294 .29965 L 1 0 0 r
F
.52115 .29646 m .52165 .29638 L .52418 .30304 L 0 0 1 r
F
.52165 .29638 m .52273 .29621 L .52376 .30107 L F
.52165 .29638 m .52273 .29879 L .52294 .29965 L 1 0 0 r
F
.52294 .29965 m .52273 .29879 L .52446 .30301 L F
.52273 .29879 m .52235 .29717 L .52376 .30107 L F
.52273 .29879 m .52376 .30107 L .52446 .30301 L F
.53352 .28364 m .5256 .30289 L .52446 .30301 L p 0 1 0 r
F P
0 g
s
.54515 .27996 m .53734 .30048 L .5256 .30289 L p 0 1 0 r
F P
0 g
s
.5256 .30289 m .53352 .28364 L .54515 .27996 L p 0 1 0 r
F P
0 g
s
.52273 .29621 m .53377 .29447 L .52452 .30274 L 0 0 1 r
F
.52455 .3031 m .52446 .30301 L p .52384 .30124 L 1 0 0 r
F P
0 g
s
.52384 .30124 m .52404 .30168 L .52455 .3031 L 1 0 0 r
F
.52376 .30107 m .52452 .30274 L .52418 .30304 L 0 0 1 r
F
.52273 .29621 m .52452 .30274 L .52376 .30107 L F
.52165 .29638 m .52376 .30107 L .52418 .30304 L F
.52165 .29638 m .52225 .29673 L .52273 .29879 L 1 0 0 r
F
.52446 .30301 m .52418 .30304 L p .52433 .30273 L 0 1 0 r
F P
0 g
s
.52418 .30304 m .52254 .30221 L p .52115 .29646 L 0 0 1 r
F P
0 g
s
.52254 .30221 m .5136 .29764 L p .52115 .29646 L 0 0 1 r
F P
0 g
s
.53377 .29447 m .52562 .30378 L .52479 .30336 L p 0 0 1 r
F P
0 g
s
.52452 .30274 m .53377 .29447 L .52479 .30336 L 0 0 1 r
F
.5217 .28618 m .53352 .28364 L p .52191 .29567 L 0 1 0 r
F P
0 g
s
.52138 .29622 m .52144 .29437 L .52191 .29567 L 0 1 0 r
F
.52144 .29437 m .5217 .28618 L .52191 .29567 L F
.50958 .27699 m .49742 .26518 L p .51299 .27286 L 1 0 0 r
F P
0 g
s
.51299 .27286 m .51346 .2731 L .51331 .2737 L 1 0 0 r
F
.51299 .27286 m .51331 .2737 L .50958 .27699 L F
.51775 .2691 m .51479 .2759 L p .51346 .2731 L 0 1 0 r
F P
0 g
s
.5138 .27326 m .51381 .27327 L .50958 .27699 L 1 0 0 r
F
.51479 .2759 m .50958 .27699 L p .51381 .27327 L F P
0 g
s
.54575 .30062 m .53757 .30988 L .52562 .30378 L p 0 0 1 r
F P
0 g
s
.55659 .27513 m .54889 .29694 L .53734 .30048 L p 0 1 0 r
F P
0 g
s
.53734 .30048 m .54515 .27996 L .55659 .27513 L p 0 1 0 r
F P
0 g
s
.52562 .30378 m .53377 .29447 L .54575 .30062 L p 0 0 1 r
F P
0 g
s
.52138 .29622 m .52142 .29546 L .52165 .29638 L 1 0 0 r
F
.52113 .29608 m .51991 .29019 L .52138 .29622 L F
.51352 .29162 m .51975 .29022 L p .52113 .29608 L F P
0 g
s
.51975 .29022 m .51991 .29019 L p .52113 .29608 L 1 0 0 r
F P
0 g
s
.50144 .27999 m .50958 .27699 L .51867 .28654 L p 1 0 0 r
F P
0 g
s
.51888 .28651 m .5217 .28618 L p .51934 .28832 L 0 1 0 r
F P
0 g
s
.51931 .28834 m .51925 .28808 L .51934 .28832 L 0 1 0 r
F
.51925 .28808 m .51888 .28651 L .51934 .28832 L F
.51867 .28654 m .51888 .28651 L p .51871 .28669 L F P
0 g
s
.50144 .27999 m .51867 .28654 L .51913 .28851 L 1 0 0 r
F
.51352 .29162 m .50144 .27999 L p .51848 .28819 L F P
0 g
s
.51913 .28851 m .51888 .28651 L .51931 .28834 L 0 1 0 r
F
.51848 .28819 m .51913 .28851 L .51875 .28892 L 1 0 0 r
F
.51848 .28819 m .51875 .28892 L .51352 .29162 L F
.51991 .29019 m .51352 .29162 L p .51921 .28868 L F P
0 g
s
.5217 .28618 m .51991 .29019 L p .51913 .28851 L 0 1 0 r
F P
0 g
s
.51934 .28861 m .51991 .29019 L .51921 .28868 L 1 0 0 r
F
.51913 .28851 m .5192 .28868 L .51875 .28892 L F
.51887 .28875 m .51913 .28851 L .51973 .2906 L 0 1 0 r
F
.51991 .29019 m .51973 .2906 L p .51913 .28851 L F P
0 g
s
.49742 .29895 m .48952 .30423 L .47765 .29562 L p 1 0 0 r
F P
0 g
s
.5136 .29764 m .50553 .30692 L .49349 .3008 L p 0 0 1 r
F P
0 g
s
.47765 .29562 m .48549 .28941 L .49742 .29895 L p 1 0 0 r
F P
0 g
s
.50541 .29471 m .49742 .29895 L .48549 .28941 L p 1 0 0 r
F P
0 g
s
.48549 .28941 m .49342 .28417 L .50541 .29471 L p 1 0 0 r
F P
0 g
s
.51352 .29162 m .50541 .29471 L .49342 .28417 L p 1 0 0 r
F P
0 g
s
.49349 .3008 m .50153 .29148 L .5136 .29764 L p 0 0 1 r
F P
0 g
s
.49342 .28417 m .50144 .27999 L .51352 .29162 L p 1 0 0 r
F P
0 g
s
.5136 .29764 m .50153 .29148 L p .51887 .28875 L 0 0 1 r
F P
0 g
s
.51854 .28687 m .51888 .28651 L .51913 .28851 L 0 1 0 r
F
.51867 .28654 m .51903 .28691 L p .51913 .28851 L 1 0 0 r
F P
0 g
s
.51934 .28861 m .51944 .28866 L .51991 .29019 L 1 0 0 r
F
.52076 .29485 m .5217 .28618 L .52129 .29632 L 0 1 0 r
F
.51973 .2906 m .5217 .28618 L p .52076 .29485 L F P
0 g
s
.52013 .29014 m .51991 .29019 L p .51944 .28866 L 1 0 0 r
F P
0 g
s
.51944 .28866 m .51976 .28861 L .51981 .28944 L 0 0 1 r
F
.51944 .28866 m .51981 .28944 L .51986 .29045 L F
.5213 .29591 m .5217 .28618 L .52138 .29622 L 0 1 0 r
F
.52173 .2883 m .52013 .29014 L p .51976 .28861 L 0 0 1 r
F P
0 g
s
.52013 .29014 m .51986 .29045 L p .51976 .28861 L 0 0 1 r
F P
0 g
s
.51991 .29019 m .52013 .29014 L p .52138 .29622 L 1 0 0 r
F P
0 g
s
.52168 .29345 m .52173 .2883 L .52295 .29617 L 0 0 1 r
F
.52013 .29014 m .52173 .2883 L p .52165 .29638 L F P
0 g
s
.52013 .29014 m .52176 .28977 L p .52142 .29546 L 1 0 0 r
F P
0 g
s
.52013 .29014 m .52142 .29546 L .52138 .29622 L 1 0 0 r
F
.5213 .29601 m .5213 .29591 L .52138 .29622 L 0 1 0 r
F
.52115 .29646 m .52076 .29485 L .52129 .29632 L F
.52129 .29632 m .5213 .29601 L .52138 .29622 L F
.52115 .29646 m .51973 .2906 L .52165 .29638 L 0 0 1 r
F
.5136 .29764 m .51973 .2906 L p .52115 .29646 L F P
0 g
s
.51946 .29121 m .51973 .2906 L p .52076 .29485 L 0 1 0 r
F P
0 g
s
.51986 .29045 m .51973 .2906 L p .51944 .28866 L 0 0 1 r
F P
0 g
s
.51973 .2906 m .51938 .29101 L p .51942 .28933 L 0 0 1 r
F P
0 g
s
.51944 .28866 m .51973 .2906 L .51942 .28933 L 0 0 1 r
F
.51913 .28851 m .51903 .28691 L .51944 .28866 L 1 0 0 r
F
.51887 .28875 m .51854 .28687 L .51913 .28851 L 0 1 0 r
F
.51846 .28695 m .51854 .28687 L .51887 .28875 L F
.51913 .28851 m .51934 .28861 L .5192 .28868 L 1 0 0 r
F
.50153 .29148 m .50964 .28209 L .51837 .28657 L p 0 0 1 r
F P
0 g
s
.50153 .29148 m .51837 .28657 L .51848 .28705 L 0 0 1 r
F
.51887 .28875 m .51903 .28691 L .51981 .2886 L F
.50153 .29148 m .51848 .28705 L .51887 .28875 L F
.51848 .28705 m .51903 .28691 L .51887 .28875 L F
.51846 .28695 m .51867 .28654 L .51871 .28669 L 0 1 0 r
F
.50164 .3044 m .51842 .2868 L .51846 .28695 L F
.51842 .2868 m .51867 .28654 L .51846 .28695 L F
.50164 .3044 m .5097 .2876 L .51837 .28657 L p F P
0 g
s
.51837 .28657 m .51867 .28654 L p .51842 .2868 L 0 1 0 r
F P
0 g
s
.50164 .3044 m .51837 .28657 L .51842 .2868 L 0 1 0 r
F
.51837 .28657 m .51903 .28691 L p .51848 .28705 L 0 0 1 r
F P
0 g
s
.51903 .28691 m .52173 .2883 L p .51981 .2886 L 0 0 1 r
F P
0 g
s
.52173 .2883 m .53377 .29447 L p .52295 .29617 L 0 0 1 r
F P
0 g
s
.54198 .2851 m .53377 .29447 L .52173 .2883 L p 0 0 1 r
F P
0 g
s
.55288 .2576 m .54515 .27996 L .53352 .28364 L p 0 1 0 r
F P
0 g
s
.53352 .28364 m .54137 .26259 L .55288 .2576 L p 0 1 0 r
F P
0 g
s
.54137 .26259 m .53352 .28364 L .5217 .28618 L p 0 1 0 r
F P
0 g
s
.52173 .2883 m .52992 .27888 L .54198 .2851 L p 0 0 1 r
F P
0 g
s
.51903 .28691 m .51867 .28654 L p .51888 .28659 L 1 0 0 r
F P
0 g
s
.5217 .28618 m .52965 .26641 L .54137 .26259 L p 0 1 0 r
F P
0 g
s
.51605 .28086 m .51611 .27944 L .51648 .28041 L 0 1 0 r
F
.51787 .28569 m .50958 .27699 L p .51605 .28086 L 1 0 0 r
F P
0 g
s
.52965 .26641 m .5217 .28618 L .51867 .28654 L p 0 1 0 r
F P
0 g
s
.51855 .28626 m .52965 .26641 L .51867 .28654 L 0 1 0 r
F
.51867 .28654 m .51787 .28569 L p .51605 .28086 L 1 0 0 r
F P
0 g
s
.51581 .28111 m .52965 .26641 L .51837 .28657 L 0 1 0 r
F
.52992 .27888 m .52173 .2883 L .51903 .28691 L p 0 0 1 r
F P
0 g
s
.51634 .28103 m .52992 .27888 L .51903 .28691 L 0 0 1 r
F
.51775 .2691 m .52965 .26641 L p .51648 .28041 L 0 1 0 r
F P
0 g
s
.51611 .27944 m .51775 .2691 L .51648 .28041 L 0 1 0 r
F
.5178 .27263 m .52992 .27888 L p .5174 .28086 L 0 0 1 r
F P
0 g
s
.51664 .27927 m .5178 .27263 L .5174 .28086 L 0 0 1 r
F
.50958 .27699 m .51479 .2759 L p .51605 .28086 L 1 0 0 r
F P
0 g
s
.51568 .28059 m .51775 .2691 L .51586 .28107 L 0 1 0 r
F
.50964 .28209 m .5146 .27634 L p .51581 .28111 L 0 0 1 r
F P
0 g
s
.51434 .27694 m .5146 .27634 L p .51568 .28059 L 0 1 0 r
F P
0 g
s
.5146 .27634 m .51775 .2691 L p .51568 .28059 L 0 1 0 r
F P
0 g
s
.51605 .28086 m .51619 .28044 L .51634 .28103 L 1 0 0 r
F
.51502 .27585 m .5178 .27263 L p .51634 .28103 L 0 0 1 r
F P
0 g
s
.51479 .2759 m .51502 .27585 L p .51605 .28086 L 1 0 0 r
F P
0 g
s
.51502 .27585 m .51785 .27526 L p .51619 .28044 L 1 0 0 r
F P
0 g
s
.51595 .28047 m .51611 .27944 L .51605 .28086 L 0 1 0 r
F
.51502 .27585 m .51619 .28044 L .51605 .28086 L 1 0 0 r
F
.51594 .28056 m .51595 .28047 L .51605 .28086 L 0 1 0 r
F
.51586 .28107 m .51594 .28056 L .51605 .28086 L F
.51581 .28111 m .51502 .27585 L .51634 .28103 L 0 0 1 r
F
.5146 .27634 m .51502 .27585 L p .51581 .28111 L F P
0 g
s
.5178 .27263 m .51502 .27585 L p .5138 .27326 L 0 0 1 r
F P
0 g
s
.51785 .27526 m .51502 .27585 L p .51381 .27327 L 1 0 0 r
F P
0 g
s
.51502 .27585 m .51479 .2759 L p .51383 .27332 L 1 0 0 r
F P
0 g
s
.51381 .27327 m .51502 .27585 L .51383 .27332 L 1 0 0 r
F
.51634 .28103 m .51664 .27927 L .5174 .28086 L 0 0 1 r
F
.51785 .27526 m .53015 .28929 L p .51634 .28103 L 1 0 0 r
F P
0 g
s
.51619 .28044 m .51785 .27526 L .51634 .28103 L 1 0 0 r
F
.51605 .28086 m .51634 .28103 L .51867 .28654 L F
.51867 .28654 m .51837 .28657 L p .51855 .28626 L 0 1 0 r
F P
0 g
s
.51837 .28657 m .51703 .28588 L p .51581 .28111 L 0 0 1 r
F P
0 g
s
.51703 .28588 m .50964 .28209 L p .51581 .28111 L 0 0 1 r
F P
0 g
s
.5097 .2876 m .51434 .27694 L p .51568 .28059 L 0 1 0 r
F P
0 g
s
.51581 .28111 m .51568 .28059 L .51586 .28107 L 0 1 0 r
F
.5097 .2876 m .51568 .28059 L .51581 .28111 L F
.51837 .28657 m .5097 .2876 L p .51581 .28111 L F P
0 g
s
.51634 .28103 m .51788 .2844 L .51867 .28654 L 1 0 0 r
F
.51671 .28125 m .53015 .28929 L .51867 .28654 L F
.51903 .28691 m .51837 .28657 L p .51634 .28103 L 0 0 1 r
F P
0 g
s
.51581 .28111 m .51634 .28103 L .51837 .28657 L 0 0 1 r
F
.51634 .28103 m .51671 .28125 L .51788 .2844 L 1 0 0 r
F
.53015 .28929 m .52176 .28977 L .51903 .28691 L p F P
0 g
s
.51888 .28659 m .53015 .28929 L .51903 .28691 L 1 0 0 r
F
.51903 .28691 m .52176 .28977 L p .51944 .28866 L F P
0 g
s
.51887 .28875 m .51944 .28866 L .51938 .29101 L 0 0 1 r
F
.51938 .29101 m .5136 .29764 L p .51887 .28875 L F P
0 g
s
.50164 .3044 m .51846 .28695 L .51887 .28875 L 0 1 0 r
F
.51369 .30418 m .50164 .3044 L p .51887 .28875 L F P
0 g
s
.51973 .2906 m .51369 .30418 L p .51887 .28875 L 0 1 0 r
F P
0 g
s
.51973 .2906 m .52013 .29014 L p .5208 .29288 L 0 0 1 r
F P
0 g
s
.51973 .2906 m .5208 .29288 L .52165 .29638 L 0 0 1 r
F
.52176 .28977 m .52013 .29014 L p .51944 .28866 L 1 0 0 r
F P
0 g
s
.52165 .29638 m .52168 .29345 L .52295 .29617 L 0 0 1 r
F
.52176 .28977 m .53398 .30361 L p .52165 .29638 L 1 0 0 r
F P
0 g
s
.52142 .29546 m .52176 .28977 L .52165 .29638 L 1 0 0 r
F
.50958 .27699 m .50144 .27999 L .48937 .26928 L p F P
0 g
s
.48937 .26928 m .49742 .26518 L .50958 .27699 L p 1 0 0 r
F P
0 g
s
.50964 .28209 m .49748 .27585 L p .51318 .27336 L 0 0 1 r
F P
0 g
s
.51318 .27336 m .51346 .2731 L .51332 .27365 L 0 1 0 r
F
.51318 .27336 m .51347 .27397 L .50964 .28209 L 0 0 1 r
F
.51346 .2731 m .51362 .27342 L .51331 .2737 L 1 0 0 r
F
.51479 .2759 m .5146 .27634 L p .51346 .2731 L 0 1 0 r
F P
0 g
s
.5146 .27634 m .50964 .28209 L p .51347 .27397 L 0 0 1 r
F P
0 g
s
.5146 .27634 m .5097 .2876 L p .51332 .27365 L 0 1 0 r
F P
0 g
s
.51346 .2731 m .5146 .27634 L .51332 .27365 L 0 1 0 r
F
.51502 .27585 m .5146 .27634 L p .5138 .27326 L 0 0 1 r
F P
0 g
s
.5138 .27326 m .5146 .27634 L .51347 .27397 L 0 0 1 r
F
.51318 .27336 m .5138 .27326 L .51347 .27397 L F
.49342 .28417 m .48549 .28941 L .47354 .28064 L p 1 0 0 r
F P
0 g
s
.50964 .28209 m .50153 .29148 L .4894 .28529 L p 0 0 1 r
F P
0 g
s
.47354 .28064 m .48141 .27446 L .49342 .28417 L p 1 0 0 r
F P
0 g
s
.50144 .27999 m .49342 .28417 L .48141 .27446 L p 1 0 0 r
F P
0 g
s
.48141 .27446 m .48937 .26928 L .50144 .27999 L p 1 0 0 r
F P
0 g
s
.4894 .28529 m .49748 .27585 L .50964 .28209 L p 0 0 1 r
F P
0 g
s
.5097 .2876 m .49756 .28795 L p .51318 .27336 L 0 1 0 r
F P
0 g
s
.51318 .27336 m .51332 .27365 L .5097 .2876 L 0 1 0 r
F
.51346 .2731 m .5138 .27326 L .51362 .27342 L 1 0 0 r
F
.53754 .2448 m .52965 .26641 L .51775 .2691 L p 0 1 0 r
F P
0 g
s
.51775 .2691 m .52574 .24879 L .53754 .2448 L p 0 1 0 r
F P
0 g
s
.52574 .24879 m .51775 .2691 L .51265 .26976 L p 0 1 0 r
F P
0 g
s
.49742 .26518 m .50558 .26228 L .51265 .26976 L p 1 0 0 r
F P
0 g
s
.51265 .26976 m .51775 .2691 L p .5138 .27278 L 0 1 0 r
F P
0 g
s
.51346 .2731 m .51265 .26976 L .5138 .27278 L 0 1 0 r
F
.52603 .2631 m .5178 .27263 L .51304 .27017 L p 0 0 1 r
F P
0 g
s
.51304 .27017 m .51265 .26976 L p .51289 .26985 L 1 0 0 r
F P
0 g
s
.50558 .26228 m .49335 .25028 L p .50763 .25752 L 1 0 0 r
F P
0 g
s
.51375 .25164 m .50956 .26151 L p .50763 .25752 L 0 1 0 r
F P
0 g
s
.50763 .25752 m .50799 .2577 L .50785 .25797 L 1 0 0 r
F
.50763 .25752 m .50785 .25797 L .50558 .26228 L F
.50799 .2577 m .50807 .25785 L .50558 .26228 L F
.51375 .25164 m .52574 .24879 L p .51089 .26498 L 0 1 0 r
F P
0 g
s
.51074 .26459 m .51375 .25164 L .51089 .26498 L 0 1 0 r
F
.50558 .26228 m .50956 .26151 L p .51057 .26533 L 1 0 0 r
F P
0 g
s
.51046 .26504 m .51048 .26497 L .51057 .26533 L 0 1 0 r
F
.51048 .26497 m .51375 .25164 L .51057 .26533 L F
.51057 .26533 m .51095 .26491 L .51265 .26976 L F
.51095 .26491 m .52574 .24879 L .51265 .26976 L F
.51267 .2687 m .52603 .2631 L .51304 .27017 L 0 0 1 r
F
.51265 .26976 m .51203 .2691 L p .51057 .26533 L 1 0 0 r
F P
0 g
s
.51203 .2691 m .50558 .26228 L p .51057 .26533 L 1 0 0 r
F P
0 g
s
.51057 .26533 m .51087 .26551 L .51265 .26976 L 1 0 0 r
F
.51087 .26551 m .52603 .2631 L .51241 .26881 L 0 0 1 r
F
.51087 .26551 m .51108 .26564 L .51175 .26741 L 1 0 0 r
F
.51087 .26551 m .51175 .26741 L .51265 .26976 L F
.49742 .26518 m .51265 .26976 L .51273 .27007 L F
.51265 .26976 m .51233 .2698 L p .51057 .26533 L 0 1 0 r
F P
0 g
s
.5116 .26828 m .51195 .26901 L .51181 .26907 L 0 0 1 r
F
.51032 .2656 m .51057 .26533 L .51233 .2698 L 0 1 0 r
F
.51032 .2656 m .51087 .26551 L .51131 .26928 L 0 0 1 r
F
.51087 .26551 m .51181 .26907 L .51131 .26928 L F
.51241 .26881 m .51267 .2687 L .51304 .27017 L F
.53817 .2694 m .52992 .27888 L .5178 .27263 L p F P
0 g
s
.54913 .23966 m .54137 .26259 L .52965 .26641 L p 0 1 0 r
F P
0 g
s
.52965 .26641 m .53754 .2448 L .54913 .23966 L p 0 1 0 r
F P
0 g
s
.5178 .27263 m .52603 .2631 L .53817 .2694 L p 0 0 1 r
F P
0 g
s
.51108 .26564 m .52626 .27491 L .51265 .26976 L 1 0 0 r
F
.51273 .27007 m .51265 .26976 L .51276 .27008 L F
.49742 .26518 m .51304 .27017 L .5138 .27326 L F
.51318 .27336 m .51265 .26976 L .51346 .2731 L 0 1 0 r
F
.49748 .27585 m .51233 .2698 L .51318 .27336 L 0 0 1 r
F
.49756 .28795 m .51239 .27007 L .51318 .27336 L 0 1 0 r
F
.51239 .27007 m .51265 .26976 L .51318 .27336 L F
.49748 .27585 m .50562 .26635 L .51233 .2698 L p 0 0 1 r
F P
0 g
s
.51233 .2698 m .51265 .26976 L p .51239 .27007 L 0 1 0 r
F P
0 g
s
.51233 .2698 m .5178 .27263 L p .51318 .27336 L 0 0 1 r
F P
0 g
s
.51265 .26976 m .51304 .27017 L p .51276 .27008 L 1 0 0 r
F P
0 g
s
.51304 .27017 m .51233 .2698 L p .51241 .26881 L 0 0 1 r
F P
0 g
s
.51233 .2698 m .51131 .26928 L p .51212 .26894 L 0 0 1 r
F P
0 g
s
.51212 .26894 m .51241 .26881 L .51233 .2698 L 0 0 1 r
F
.49756 .28795 m .50567 .27067 L .51233 .2698 L p 0 1 0 r
F P
0 g
s
.49756 .28795 m .51233 .2698 L .51239 .27007 L 0 1 0 r
F
.51131 .26928 m .50562 .26635 L p .51032 .2656 L 0 0 1 r
F P
0 g
s
.51233 .2698 m .50567 .27067 L p .51032 .2656 L 0 1 0 r
F P
0 g
s
.51087 .26551 m .51241 .26881 L .51195 .26901 L 0 0 1 r
F
.51087 .26551 m .51195 .26901 L .5116 .26828 L F
.51057 .26533 m .51075 .26507 L .51087 .26551 L 1 0 0 r
F
.51382 .25677 m .52603 .2631 L p .51168 .26538 L 0 0 1 r
F P
0 g
s
.51123 .26445 m .51382 .25677 L .51168 .26538 L 0 0 1 r
F
.51057 .26533 m .51074 .26459 L .51089 .26498 L 0 1 0 r
F
.5103 .26552 m .51375 .25164 L .51032 .2656 L F
.50562 .26635 m .50936 .26199 L p .51032 .2656 L 0 0 1 r
F P
0 g
s
.5091 .26258 m .50936 .26199 L p .51027 .26566 L 0 1 0 r
F P
0 g
s
.50936 .26199 m .51375 .25164 L p .5103 .26552 L 0 1 0 r
F P
0 g
s
.50936 .26199 m .5103 .26552 L .51027 .26566 L 0 1 0 r
F
.50956 .26151 m .5098 .26147 L p .51057 .26533 L 1 0 0 r
F P
0 g
s
.5098 .26147 m .51075 .26507 L .51057 .26533 L 1 0 0 r
F
.51032 .2656 m .51046 .26504 L .51057 .26533 L 0 1 0 r
F
.51032 .2656 m .5098 .26147 L .51087 .26551 L 0 0 1 r
F
.50936 .26199 m .5098 .26147 L p .51032 .2656 L F P
0 g
s
.5098 .26147 m .51382 .25677 L p .51087 .26551 L 0 0 1 r
F P
0 g
s
.51382 .25677 m .5098 .26147 L p .50799 .2577 L 0 0 1 r
F P
0 g
s
.50812 .25776 m .51151 .25948 L .5098 .26147 L 1 0 0 r
F
.51151 .25948 m .51388 .26068 L .5098 .26147 L F
.5098 .26147 m .50956 .26151 L p .50848 .25872 L F P
0 g
s
.50812 .25776 m .5098 .26147 L .50848 .25872 L 1 0 0 r
F
.51087 .26551 m .51123 .26445 L .51168 .26538 L 0 0 1 r
F
.5098 .26147 m .51388 .26068 L p .51075 .26507 L 1 0 0 r
F P
0 g
s
.51388 .26068 m .52626 .27491 L p .51087 .26551 L 1 0 0 r
F P
0 g
s
.51075 .26507 m .51388 .26068 L .51087 .26551 L 1 0 0 r
F
.50956 .26151 m .50558 .26228 L p .50812 .25776 L F P
0 g
s
.50558 .26228 m .49742 .26518 L .48527 .25428 L p 1 0 0 r
F P
0 g
s
.48527 .25428 m .49335 .25028 L .50558 .26228 L p 1 0 0 r
F P
0 g
s
.50562 .26635 m .49339 .26003 L p .50733 .2578 L 0 0 1 r
F P
0 g
s
.50733 .2578 m .50763 .25752 L .50753 .25821 L 0 1 0 r
F
.50733 .2578 m .50774 .25864 L .50562 .26635 L 0 0 1 r
F
.50956 .26151 m .50936 .26199 L p .50763 .25752 L 0 1 0 r
F P
0 g
s
.50936 .26199 m .50562 .26635 L p .50774 .25864 L 0 0 1 r
F P
0 g
s
.50936 .26199 m .50567 .27067 L p .50753 .25821 L 0 1 0 r
F P
0 g
s
.50763 .25752 m .50936 .26199 L .50753 .25821 L 0 1 0 r
F
.5098 .26147 m .50936 .26199 L p .50799 .2577 L 0 0 1 r
F P
0 g
s
.50799 .2577 m .50936 .26199 L .50774 .25864 L 0 0 1 r
F
.50733 .2578 m .50799 .2577 L .50774 .25864 L F
.48937 .26928 m .48141 .27446 L .46939 .26553 L p 1 0 0 r
F P
0 g
s
.46939 .26553 m .47729 .2594 L .48937 .26928 L p 1 0 0 r
F P
0 g
s
.49742 .26518 m .48937 .26928 L .47729 .2594 L p 1 0 0 r
F P
0 g
s
.50562 .26635 m .49748 .27585 L .48527 .26958 L p 0 0 1 r
F P
0 g
s
.47729 .2594 m .48527 .25428 L .49742 .26518 L p 1 0 0 r
F P
0 g
s
.48527 .26958 m .49339 .26003 L .50562 .26635 L p 0 0 1 r
F P
0 g
s
.50567 .27067 m .49343 .27116 L p .50733 .2578 L 0 1 0 r
F P
0 g
s
.50733 .2578 m .50753 .25821 L .50567 .27067 L 0 1 0 r
F
.50799 .2577 m .50812 .25776 L .50807 .25785 L 1 0 0 r
F
.52626 .27491 m .51785 .27526 L .51304 .27017 L p F P
0 g
s
.51289 .26985 m .52626 .27491 L .51304 .27017 L 1 0 0 r
F
.51304 .27017 m .51785 .27526 L p .5138 .27326 L F P
0 g
s
.51027 .26566 m .5103 .26552 L .51032 .2656 L 0 1 0 r
F
.50567 .27067 m .5091 .26258 L p .51027 .26566 L F P
0 g
s
.5138 .27326 m .51381 .27327 L .51381 .27327 L 1 0 0 r
F
.51369 .30418 m .51946 .29121 L p .52076 .29485 L 0 1 0 r
F P
0 g
s
.51369 .30418 m .52076 .29485 L .52115 .29646 L 0 1 0 r
F
.52418 .30304 m .51369 .30418 L p .52115 .29646 L F P
0 g
s
.52384 .30124 m .52225 .29673 L .52404 .30168 L 1 0 0 r
F
.52479 .30336 m .52418 .30304 L p .52452 .30274 L 0 0 1 r
F P
0 g
s
.50567 .32054 m .52441 .30313 L .52463 .30375 L 0 1 0 r
F
.52418 .30304 m .52562 .30378 L p .52438 .30397 L 0 0 1 r
F P
0 g
s
.52471 .30379 m .52491 .30389 L .52492 .30439 L 1 0 0 r
F
.52562 .30378 m .52512 .30434 L p .52491 .30389 L 0 0 1 r
F P
0 g
s
.52563 .30422 m .52512 .30434 L p .52491 .30389 L 1 0 0 r
F P
0 g
s
.52512 .30434 m .52492 .30439 L p .52491 .30389 L 1 0 0 r
F P
0 g
s
.52438 .30397 m .52491 .30389 L .52475 .30477 L 0 0 1 r
F
.52512 .30434 m .52475 .30477 L p .52491 .30389 L F P
0 g
s
.51764 .32043 m .50567 .32054 L p .52438 .30397 L 0 1 0 r
F P
0 g
s
.52438 .30397 m .52446 .30415 L .51764 .32043 L 0 1 0 r
F
.52479 .30336 m .52563 .30422 L p .52491 .30389 L 1 0 0 r
F P
0 g
s
.52546 .30631 m .52562 .30378 L .5278 .31141 L 0 0 1 r
F
.52475 .30477 m .52504 .30444 L p .52546 .30631 L F P
0 g
s
.52504 .30444 m .52562 .30378 L p .52546 .30631 L 0 0 1 r
F P
0 g
s
.52475 .30477 m .51764 .32043 L p .52448 .30419 L 0 1 0 r
F P
0 g
s
.52235 .29717 m .52225 .29673 L .52446 .30301 L 1 0 0 r
F
.51764 .32043 m .52443 .30547 L p .52579 .3093 L 0 1 0 r
F P
0 g
s
.51764 .32043 m .52579 .3093 L .52633 .31164 L 0 1 0 r
F
.52841 .31854 m .52785 .31825 L p .52633 .31164 L 0 0 1 r
F P
0 g
s
.52633 .31164 m .52679 .31156 L .52732 .31383 L 0 0 1 r
F
.52633 .31164 m .52732 .31383 L .52841 .31854 L F
.52946 .31925 m .51764 .32043 L p .52633 .31164 L 0 1 0 r
F P
0 g
s
.52633 .31164 m .528 .31534 L .52946 .31925 L 0 1 0 r
F
.52563 .30422 m .53777 .31788 L p .52679 .31156 L 1 0 0 r
F P
0 g
s
.52512 .30434 m .52563 .30422 L p .52679 .31156 L 1 0 0 r
F P
0 g
s
.53777 .31788 m .5299 .31856 L p .52737 .31189 L 1 0 0 r
F P
0 g
s
.52737 .31189 m .5299 .31856 L .52908 .3167 L 1 0 0 r
F
.53 .31898 m .54998 .33269 L .53013 .31929 L F
.5302 .31945 m .52972 .3192 L p .53007 .31914 L 0 0 1 r
F P
0 g
s
.52972 .3192 m .52994 .31916 L p .53134 .32665 L 0 1 0 r
F P
0 g
s
.53134 .32665 m .52994 .31916 L .53154 .32645 L 0 1 0 r
F
.52945 .31907 m .5302 .31945 L p .53177 .32658 L 0 0 1 r
F P
0 g
s
.52972 .3192 m .52946 .31925 L p .52964 .31904 L 0 1 0 r
F P
0 g
s
.53013 .31929 m .54998 .33269 L .5302 .31945 L 1 0 0 r
F
.52139 .32819 m .52881 .3198 L p .53177 .32658 L 0 0 1 r
F P
0 g
s
.52881 .3198 m .52945 .31907 L p .53177 .32658 L 0 0 1 r
F P
0 g
s
.53324 .33418 m .52139 .32819 L p .53177 .32658 L 0 0 1 r
F P
0 g
s
.53449 .33279 m .53433 .3328 L p .53373 .33105 L 1 0 0 r
F P
0 g
s
.53449 .33279 m .53324 .33418 L p .53177 .32658 L 0 0 1 r
F P
0 g
s
.53398 .30361 m .52563 .30422 L .52455 .3031 L p 1 0 0 r
F P
0 g
s
.52225 .29673 m .53398 .30361 L .52455 .3031 L 1 0 0 r
F
.52153 .33636 m .52946 .31925 L .52972 .3192 L p 0 1 0 r
F P
0 g
s
.52153 .33636 m .52972 .3192 L .53134 .32665 L 0 1 0 r
F
.53327 .33528 m .52153 .33636 L p .53134 .32665 L F P
0 g
s
.53324 .33418 m .5342 .33311 L p .53459 .33397 L 0 0 1 r
F P
0 g
s
.53484 .33499 m .53324 .33418 L p .53441 .334 L 0 0 1 r
F P
0 g
s
.5342 .33311 m .53327 .33528 L p .53134 .32665 L 0 1 0 r
F P
0 g
s
.53449 .33279 m .53471 .33379 L .53456 .33383 L 1 0 0 r
F
.53459 .33397 m .53449 .33279 L .53475 .33395 L 0 0 1 r
F
.53456 .33383 m .53433 .3328 L .53465 .33373 L 0 1 0 r
F
.53433 .3328 m .53449 .33279 L p .53456 .33383 L 1 0 0 r
F P
0 g
s
.53441 .334 m .53433 .3328 L .53456 .33383 L 0 1 0 r
F
.5342 .33311 m .53433 .3328 L p .53441 .334 L F P
0 g
s
.5342 .33311 m .53449 .33279 L p .53459 .33397 L 0 0 1 r
F P
0 g
s
.54151 .3321 m .53449 .33279 L p .53228 .32687 L 1 0 0 r
F P
0 g
s
.53228 .32687 m .53449 .33279 L .53373 .33105 L 1 0 0 r
F
.53475 .33395 m .5349 .33374 L .53498 .33391 L 0 0 1 r
F
.53449 .33279 m .54151 .3321 L p .53471 .33379 L 1 0 0 r
F P
0 g
s
.54151 .3321 m .55365 .34675 L p .53475 .33395 L 1 0 0 r
F P
0 g
s
.53471 .33379 m .54151 .3321 L .53475 .33395 L 1 0 0 r
F
.535 .33507 m .53484 .33499 L p .53497 .33496 L 0 0 1 r
F P
0 g
s
.53484 .33499 m .53327 .33528 L p .53441 .334 L 0 1 0 r
F P
0 g
s
.53327 .33528 m .5342 .33311 L p .53441 .334 L 0 1 0 r
F P
0 g
s
.53484 .33499 m .53528 .33521 L p .53494 .33548 L 0 0 1 r
F P
0 g
s
.52522 .3432 m .53484 .33499 L .53494 .33548 L 0 0 1 r
F
.52538 .35198 m .53489 .33523 L .53618 .34151 L 0 1 0 r
F
.52538 .35198 m .53327 .33528 L .53484 .33499 L p F P
0 g
s
.52538 .35198 m .53484 .33499 L .53489 .33523 L 0 1 0 r
F
.53618 .34151 m .53528 .33521 L .53659 .34144 L 0 0 1 r
F
.53494 .33548 m .53528 .33521 L .53618 .34151 L F
.55365 .34675 m .54521 .34627 L .53528 .33521 L p 1 0 0 r
F P
0 g
s
.53522 .33506 m .55365 .34675 L .53528 .33521 L 1 0 0 r
F
.36365 .35268 m .37107 .34373 L .3832 .34964 L p 0 0 1 r
F P
0 g
s
.41484 .3525 m .42244 .34355 L .43446 .34947 L p 0 0 1 r
F P
0 g
s
.42244 .34355 m .41484 .3525 L .4028 .3466 L p 0 0 1 r
F P
0 g
s
.3869 .30739 m .37928 .31959 L .36699 .31659 L p 1 0 0 r
F P
0 g
s
.46604 .35232 m .47383 .34337 L .48572 .34929 L p 0 0 1 r
F P
0 g
s
.47383 .34337 m .46604 .35232 L .45412 .34642 L p 0 0 1 r
F P
0 g
s
.64797 .54637 m .6513 .55306 L .65204 .55816 L p 1 0 0 r
F P
0 g
s
.52522 .3432 m .51725 .35215 L .50544 .34625 L p 0 0 1 r
F P
0 g
s
.27684 .39503 m .28419 .3837 L .29675 .38688 L p 1 0 0 r
F P
0 g
s
.3042 .37483 m .29675 .38688 L .28419 .3837 L p 1 0 0 r
F P
0 g
s
.56846 .35197 m .57662 .34302 L .58827 .34894 L p 0 0 1 r
F P
0 g
s
.57662 .34302 m .56846 .35197 L .55678 .34607 L p 0 0 1 r
F P
0 g
s
.39917 .38637 m .40659 .38114 L .41859 .38958 L p 0 1 0 r
F P
0 g
s
.40659 .38114 m .39917 .38637 L .38723 .37728 L p 0 1 0 r
F P
0 g
s
.61969 .3518 m .62802 .34284 L .63955 .34876 L p 0 0 1 r
F P
0 g
s
.62802 .34284 m .61969 .3518 L .60812 .34589 L p 0 0 1 r
F P
0 g
s
.67092 .35162 m .67944 .34267 L .69085 .34859 L p 0 0 1 r
F P
0 g
s
.67944 .34267 m .67092 .35162 L .65947 .34572 L p 0 0 1 r
F P
0 g
s
.3042 .37483 m .3117 .36243 L .32422 .36502 L p 1 0 0 r
F P
0 g
s
.33177 .35231 m .32422 .36502 L .3117 .36243 L p 1 0 0 r
F P
0 g
s
.72215 .35145 m .73086 .34249 L .74215 .34841 L p 0 0 1 r
F P
0 g
s
.73086 .34249 m .72215 .35145 L .71083 .34554 L p 0 0 1 r
F P
0 g
s
.7734 .35127 m .78228 .34231 L .79345 .34823 L p 0 0 1 r
F P
0 g
s
.78228 .34231 m .7734 .35127 L .76219 .34537 L p 0 0 1 r
F P
0 g
s
.20608 .39939 m .21268 .39271 L .22509 .39949 L p 1 0 0 r
F P
0 g
s
.21268 .39271 m .20608 .39939 L .19387 .39105 L p 1 0 0 r
F P
0 g
s
.65081 .5513 m .6513 .55306 L .64797 .54637 L p 1 0 0 r
F P
0 g
s
.64797 .54637 m .65054 .5495 L .65081 .5513 L p 1 0 0 r
F P
0 g
s
.4067 .29946 m .41435 .28838 L .42641 .29323 L p 1 0 0 r
F P
0 g
s
.42641 .29323 m .43408 .28324 L .44608 .28917 L p 1 0 0 r
F P
0 g
s
.43408 .28324 m .42641 .29323 L .41435 .28838 L p 1 0 0 r
F P
0 g
s
.29133 .29999 m .28452 .30546 L .27246 .29645 L p 0 1 0 r
F P
0 g
s
.22947 .35017 m .23642 .3412 L .24888 .34713 L p 0 0 1 r
F P
0 g
s
.23642 .3412 m .22947 .35017 L .21698 .34426 L p 0 0 1 r
F P
0 g
s
.23753 .40558 m .24453 .39656 L .25706 .40143 L p 1 0 0 r
F P
0 g
s
.24453 .39656 m .23753 .40558 L .22509 .39949 L p 1 0 0 r
F P
0 g
s
.28071 .34999 m .28784 .34103 L .30018 .34695 L p 0 0 1 r
F P
0 g
s
.28784 .34103 m .28071 .34999 L .26833 .34408 L p 0 0 1 r
F P
0 g
s
.3869 .30739 m .39454 .29548 L .4067 .29946 L p 1 0 0 r
F P
0 g
s
.41435 .28838 m .4067 .29946 L .39454 .29548 L p 1 0 0 r
F P
0 g
s
.47409 .40986 m .48191 .40055 L .49379 .40459 L p 0 1 0 r
F P
0 g
s
.48191 .40055 m .47409 .40986 L .46217 .40425 L p 0 1 0 r
F P
0 g
s
.38723 .37728 m .39458 .37232 L .40659 .38114 L p 0 1 0 r
F P
0 g
s
.39458 .37232 m .38723 .37728 L .37529 .36793 L p 0 1 0 r
F P
0 g
s
.3832 .34964 m .3907 .34067 L .4028 .3466 L p 0 0 1 r
F P
0 g
s
.3907 .34067 m .3832 .34964 L .37107 .34373 L p 0 0 1 r
F P
0 g
s
.64596 .53065 m .64747 .53571 L p .63214 .5088 L 1 0 0 r
F P
0 g
s
.64747 .53571 m .64488 .53256 L .63214 .5088 L p 1 0 0 r
F P
0 g
s
.63214 .5088 m .64177 .51884 L p .64596 .53065 L 1 0 0 r
F P
0 g
s
.43446 .34947 m .44214 .34049 L .45412 .34642 L p 0 0 1 r
F P
0 g
s
.44214 .34049 m .43446 .34947 L .42244 .34355 L p 0 0 1 r
F P
0 g
s
.50166 .39336 m .50956 .38092 L .52132 .38214 L p 0 1 0 r
F P
0 g
s
.52919 .36731 m .52132 .38214 L .50956 .38092 L p 0 1 0 r
F P
0 g
s
.50166 .39336 m .49379 .40459 L .48191 .40055 L p 0 1 0 r
F P
0 g
s
.48572 .34929 m .49358 .34032 L .50544 .34625 L p 0 0 1 r
F P
0 g
s
.49358 .34032 m .48572 .34929 L .47383 .34337 L p 0 0 1 r
F P
0 g
s
.25706 .40143 m .26427 .39112 L .27684 .39503 L p 1 0 0 r
F P
0 g
s
.28419 .3837 m .27684 .39503 L .26427 .39112 L p 1 0 0 r
F P
0 g
s
.44252 .40505 m .4502 .39795 L .46217 .40425 L p 0 1 0 r
F P
0 g
s
.4502 .39795 m .44252 .40505 L .43056 .39757 L p 0 1 0 r
F P
0 g
s
.56782 .1385 m .56783 .13853 L p .5492 .17618 L 0 1 0 r
F P
0 g
s
.56783 .13853 m .56052 .16812 L .5492 .17618 L p 0 1 0 r
F P
0 g
s
.55674 .14785 m .56781 .13847 L .56782 .1385 L p 0 1 0 r
F P
0 g
s
.5492 .17618 m .55674 .14785 L p .56782 .1385 L 0 1 0 r
F P
0 g
s
.56432 .13072 m .56781 .13847 L .55674 .14785 L p 0 1 0 r
F P
0 g
s
.58827 .34894 m .5965 .33996 L .60812 .34589 L p 0 0 1 r
F P
0 g
s
.5965 .33996 m .58827 .34894 L .57662 .34302 L p 0 0 1 r
F P
0 g
s
.56941 .37654 m .56085 .37476 L .54887 .36037 L p 1 0 0 r
F P
0 g
s
.54887 .36037 m .55727 .36078 L .56941 .37654 L p 1 0 0 r
F P
0 g
s
.63955 .34876 m .64797 .33979 L .65947 .34572 L p 0 0 1 r
F P
0 g
s
.64797 .33979 m .63955 .34876 L .62802 .34284 L p 0 0 1 r
F P
0 g
s
.60991 .44604 m .60076 .43961 L .58851 .42119 L p 1 0 0 r
F P
0 g
s
.58851 .42119 m .59742 .42593 L .60991 .44604 L p 1 0 0 r
F P
0 g
s
.22908 .27946 m .23589 .27143 L .24816 .27938 L p 0 1 0 r
F P
0 g
s
.44608 .28917 m .45379 .2805 L .46574 .28773 L p 1 0 0 r
F P
0 g
s
.45379 .2805 m .44608 .28917 L .43408 .28324 L p 1 0 0 r
F P
0 g
s
.69085 .34859 m .69945 .33961 L .71083 .34554 L p 0 0 1 r
F P
0 g
s
.69945 .33961 m .69085 .34859 L .67944 .34267 L p 0 0 1 r
F P
0 g
s
.74215 .34841 m .75093 .33943 L .76219 .34537 L p 0 0 1 r
F P
0 g
s
.75093 .33943 m .74215 .34841 L .73086 .34249 L p 0 0 1 r
F P
0 g
s
.26427 .39112 m .25706 .40143 L .24453 .39656 L p 1 0 0 r
F P
0 g
s
.79345 .34823 m .80242 .33925 L .81356 .34519 L p 0 0 1 r
F P
0 g
s
.80242 .33925 m .79345 .34823 L .78228 .34231 L p 0 0 1 r
F P
0 g
s
.19387 .39105 m .20031 .3852 L .21268 .39271 L p 1 0 0 r
F P
0 g
s
.20031 .3852 m .19387 .39105 L .18174 .38188 L p 1 0 0 r
F P
0 g
s
.27246 .29645 m .27925 .2906 L .29133 .29999 L p 0 1 0 r
F P
0 g
s
.27925 .2906 m .27246 .29645 L .26034 .28774 L p 0 1 0 r
F P
0 g
s
.37529 .36793 m .38257 .36317 L .39458 .37232 L p 0 1 0 r
F P
0 g
s
.38257 .36317 m .37529 .36793 L .36333 .35837 L p 0 1 0 r
F P
0 g
s
.50956 .38092 m .51747 .36716 L .52919 .36731 L p 0 1 0 r
F P
0 g
s
.53704 .35099 m .52919 .36731 L .51747 .36716 L p 0 1 0 r
F P
0 g
s
.19759 .3473 m .20443 .33832 L .21698 .34426 L p 0 0 1 r
F P
0 g
s
.48549 .28941 m .47765 .29562 L .46574 .28773 L p 1 0 0 r
F P
0 g
s
.36699 .31659 m .37463 .30408 L .3869 .30739 L p 1 0 0 r
F P
0 g
s
.39454 .29548 m .3869 .30739 L .37463 .30408 L p 1 0 0 r
F P
0 g
s
.24888 .34713 m .2559 .33814 L .26833 .34408 L p 0 0 1 r
F P
0 g
s
.2559 .33814 m .24888 .34713 L .23642 .3412 L p 0 0 1 r
F P
0 g
s
.30018 .34695 m .30739 .33796 L .3197 .3439 L p 0 0 1 r
F P
0 g
s
.30739 .33796 m .30018 .34695 L .28784 .34103 L p 0 0 1 r
F P
0 g
s
.51747 .36716 m .52538 .35198 L .53704 .35099 L p 0 1 0 r
F P
0 g
s
.3117 .36243 m .31925 .34978 L .33177 .35231 L p 1 0 0 r
F P
0 g
s
.28419 .3837 m .29161 .37189 L .3042 .37483 L p 1 0 0 r
F P
0 g
s
.3117 .36243 m .3042 .37483 L .29161 .37189 L p 1 0 0 r
F P
0 g
s
.4028 .3466 m .41037 .33761 L .42244 .34355 L p 0 0 1 r
F P
0 g
s
.41037 .33761 m .4028 .3466 L .3907 .34067 L p 0 0 1 r
F P
0 g
s
.45412 .34642 m .46188 .33743 L .47383 .34337 L p 0 0 1 r
F P
0 g
s
.46188 .33743 m .45412 .34642 L .44214 .34049 L p 0 0 1 r
F P
0 g
s
.50544 .34625 m .51339 .33725 L .52522 .3432 L p 0 0 1 r
F P
0 g
s
.51339 .33725 m .50544 .34625 L .49358 .34032 L p 0 0 1 r
F P
0 g
s
.36333 .35837 m .37054 .35376 L .38257 .36317 L p 0 1 0 r
F P
0 g
s
.37054 .35376 m .36333 .35837 L .35137 .34868 L p 0 1 0 r
F P
0 g
s
.55678 .34607 m .56491 .33708 L .57662 .34302 L p 0 0 1 r
F P
0 g
s
.63864 .5052 m .62898 .49511 L .61643 .47332 L p 1 0 0 r
F P
0 g
s
.61643 .47332 m .6258 .48147 L .63864 .5052 L p 1 0 0 r
F P
0 g
s
.18174 .38188 m .188 .37692 L .20031 .3852 L p 1 0 0 r
F P
0 g
s
.60812 .34589 m .61644 .3369 L .62802 .34284 L p 0 0 1 r
F P
0 g
s
.61644 .3369 m .60812 .34589 L .5965 .33996 L p 0 0 1 r
F P
0 g
s
.65947 .34572 m .66797 .33672 L .67944 .34267 L p 0 0 1 r
F P
0 g
s
.66797 .33672 m .65947 .34572 L .64797 .33979 L p 0 0 1 r
F P
0 g
s
.71083 .34554 m .71951 .33654 L .73086 .34249 L p 0 0 1 r
F P
0 g
s
.71951 .33654 m .71083 .34554 L .69945 .33961 L p 0 0 1 r
F P
0 g
s
.76219 .34537 m .77106 .33636 L .78228 .34231 L p 0 0 1 r
F P
0 g
s
.77106 .33636 m .76219 .34537 L .75093 .33943 L p 0 0 1 r
F P
0 g
s
.43056 .39757 m .4382 .39101 L .4502 .39795 L p 0 1 0 r
F P
0 g
s
.4382 .39101 m .43056 .39757 L .41859 .38958 L p 0 1 0 r
F P
0 g
s
.26034 .28774 m .26711 .28145 L .27925 .2906 L p 0 1 0 r
F P
0 g
s
.26711 .28145 m .26034 .28774 L .24816 .27938 L p 0 1 0 r
F P
0 g
s
.58167 .39367 m .57292 .39041 L .56085 .37476 L p 1 0 0 r
F P
0 g
s
.56085 .37476 m .56941 .37654 L .58167 .39367 L p 1 0 0 r
F P
0 g
s
.35137 .34868 m .35851 .34413 L .37054 .35376 L p 0 1 0 r
F P
0 g
s
.22509 .39949 m .23198 .39111 L .24453 .39656 L p 1 0 0 r
F P
0 g
s
.23198 .39111 m .22509 .39949 L .21268 .39271 L p 1 0 0 r
F P
0 g
s
.21698 .34426 m .2239 .33525 L .23642 .3412 L p 0 0 1 r
F P
0 g
s
.2239 .33525 m .21698 .34426 L .20443 .33832 L p 0 0 1 r
F P
0 g
s
.26833 .34408 m .27544 .33507 L .28784 .34103 L p 0 0 1 r
F P
0 g
s
.27544 .33507 m .26833 .34408 L .2559 .33814 L p 0 0 1 r
F P
0 g
s
.37107 .34373 m .37854 .33471 L .3907 .34067 L p 0 0 1 r
F P
0 g
s
.37854 .33471 m .37107 .34373 L .35888 .33779 L p 0 0 1 r
F P
0 g
s
.46217 .40425 m .46997 .39569 L .48191 .40055 L p 0 1 0 r
F P
0 g
s
.46997 .39569 m .46217 .40425 L .4502 .39795 L p 0 1 0 r
F P
0 g
s
.46574 .28773 m .47354 .28064 L .48549 .28941 L p 1 0 0 r
F P
0 g
s
.47354 .28064 m .46574 .28773 L .45379 .2805 L p 1 0 0 r
F P
0 g
s
.42244 .34355 m .4301 .33454 L .44214 .34049 L p 0 0 1 r
F P
0 g
s
.4301 .33454 m .42244 .34355 L .41037 .33761 L p 0 0 1 r
F P
0 g
s
.47383 .34337 m .48167 .33436 L .49358 .34032 L p 0 0 1 r
F P
0 g
s
.48167 .33436 m .47383 .34337 L .46188 .33743 L p 0 0 1 r
F P
0 g
s
.39454 .29548 m .40219 .28393 L .41435 .28838 L p 1 0 0 r
F P
0 g
s
.41435 .28838 m .42202 .2778 L .43408 .28324 L p 1 0 0 r
F P
0 g
s
.42202 .2778 m .41435 .28838 L .40219 .28393 L p 1 0 0 r
F P
0 g
s
.48191 .40055 m .48978 .3902 L .50166 .39336 L p 0 1 0 r
F P
0 g
s
.50956 .38092 m .50166 .39336 L .48978 .3902 L p 0 1 0 r
F P
0 g
s
.26427 .39112 m .27157 .38017 L .28419 .3837 L p 1 0 0 r
F P
0 g
s
.29161 .37189 m .28419 .3837 L .27157 .38017 L p 1 0 0 r
F P
0 g
s
.57662 .34302 m .58483 .334 L .5965 .33996 L p 0 0 1 r
F P
0 g
s
.58483 .334 m .57662 .34302 L .56491 .33708 L p 0 0 1 r
F P
0 g
s
.62802 .34284 m .63642 .33383 L .64797 .33979 L p 0 0 1 r
F P
0 g
s
.63642 .33383 m .62802 .34284 L .61644 .3369 L p 0 0 1 r
F P
0 g
s
.56426 .18786 m .55677 .21477 L .54534 .22126 L p 0 1 0 r
F P
0 g
s
.54534 .22126 m .55301 .19572 L .56426 .18786 L p 0 1 0 r
F P
0 g
s
.67944 .34267 m .68802 .33365 L .69945 .33961 L p 0 0 1 r
F P
0 g
s
.68802 .33365 m .67944 .34267 L .66797 .33672 L p 0 0 1 r
F P
0 g
s
.43408 .28324 m .44179 .27387 L .45379 .2805 L p 1 0 0 r
F P
0 g
s
.44179 .27387 m .43408 .28324 L .42202 .2778 L p 1 0 0 r
F P
0 g
s
.73086 .34249 m .73962 .33347 L .75093 .33943 L p 0 0 1 r
F P
0 g
s
.73962 .33347 m .73086 .34249 L .71951 .33654 L p 0 0 1 r
F P
0 g
s
.78228 .34231 m .79123 .33329 L .80242 .33925 L p 0 0 1 r
F P
0 g
s
.79123 .33329 m .78228 .34231 L .77106 .33636 L p 0 0 1 r
F P
0 g
s
.24816 .27938 m .25492 .27259 L .26711 .28145 L p 0 1 0 r
F P
0 g
s
.25492 .27259 m .24816 .27938 L .23589 .27143 L p 0 1 0 r
F P
0 g
s
.55674 .14785 m .56234 .12466 L .56432 .13072 L p 0 1 0 r
F P
0 g
s
.29161 .37189 m .29909 .35968 L .3117 .36243 L p 1 0 0 r
F P
0 g
s
.31925 .34978 m .3117 .36243 L .29909 .35968 L p 1 0 0 r
F P
0 g
s
.41859 .38958 m .42616 .38351 L .4382 .39101 L p 0 1 0 r
F P
0 g
s
.42616 .38351 m .41859 .38958 L .40659 .38114 L p 0 1 0 r
F P
0 g
s
.37463 .30408 m .38228 .2918 L .39454 .29548 L p 1 0 0 r
F P
0 g
s
.40219 .28393 m .39454 .29548 L .38228 .2918 L p 1 0 0 r
F P
0 g
s
.56049 .23333 m .55288 .2576 L .54137 .26259 L p 0 1 0 r
F P
0 g
s
.54137 .26259 m .54913 .23966 L .56049 .23333 L p 0 1 0 r
F P
0 g
s
.48978 .3902 m .48191 .40055 L .46997 .39569 L p 0 1 0 r
F P
0 g
s
.24453 .39656 m .25166 .38675 L .26427 .39112 L p 1 0 0 r
F P
0 g
s
.25166 .38675 m .24453 .39656 L .23198 .39111 L p 1 0 0 r
F P
0 g
s
.23642 .3412 m .24341 .33217 L .2559 .33814 L p 0 0 1 r
F P
0 g
s
.24341 .33217 m .23642 .3412 L .2239 .33525 L p 0 0 1 r
F P
0 g
s
.27157 .38017 m .26427 .39112 L .25166 .38675 L p 1 0 0 r
F P
0 g
s
.28784 .34103 m .29502 .33199 L .30739 .33796 L p 0 0 1 r
F P
0 g
s
.29502 .33199 m .28784 .34103 L .27544 .33507 L p 0 0 1 r
F P
0 g
s
.3907 .34067 m .39825 .33164 L .41037 .33761 L p 0 0 1 r
F P
0 g
s
.39825 .33164 m .3907 .34067 L .37854 .33471 L p 0 0 1 r
F P
0 g
s
.44214 .34049 m .44987 .33146 L .46188 .33743 L p 0 0 1 r
F P
0 g
s
.44987 .33146 m .44214 .34049 L .4301 .33454 L p 0 0 1 r
F P
0 g
s
.62258 .46789 m .61318 .45966 L .60076 .43961 L p 1 0 0 r
F P
0 g
s
.60076 .43961 m .60991 .44604 L .62258 .46789 L p 1 0 0 r
F P
0 g
s
.49358 .34032 m .50151 .33128 L .51339 .33725 L p 0 0 1 r
F P
0 g
s
.50151 .33128 m .49358 .34032 L .48167 .33436 L p 0 0 1 r
F P
0 g
s
.5965 .33996 m .60479 .33092 L .61644 .3369 L p 0 0 1 r
F P
0 g
s
.60479 .33092 m .5965 .33996 L .58483 .334 L p 0 0 1 r
F P
0 g
s
.64797 .33979 m .65645 .33075 L .66797 .33672 L p 0 0 1 r
F P
0 g
s
.65645 .33075 m .64797 .33979 L .63642 .33383 L p 0 0 1 r
F P
0 g
s
.21268 .39271 m .21945 .38504 L .23198 .39111 L p 1 0 0 r
F P
0 g
s
.21945 .38504 m .21268 .39271 L .20031 .3852 L p 1 0 0 r
F P
0 g
s
.59405 .41226 m .58511 .40743 L .57292 .39041 L p 1 0 0 r
F P
0 g
s
.57292 .39041 m .58167 .39367 L .59405 .41226 L p 1 0 0 r
F P
0 g
s
.69945 .33961 m .70811 .33057 L .71951 .33654 L p 0 0 1 r
F P
0 g
s
.70811 .33057 m .69945 .33961 L .68802 .33365 L p 0 0 1 r
F P
0 g
s
.75093 .33943 m .75978 .33039 L .77106 .33636 L p 0 0 1 r
F P
0 g
s
.75978 .33039 m .75093 .33943 L .73962 .33347 L p 0 0 1 r
F P
0 g
s
.45379 .2805 m .46156 .27259 L .47354 .28064 L p 1 0 0 r
F P
0 g
s
.46156 .27259 m .45379 .2805 L .44179 .27387 L p 1 0 0 r
F P
0 g
s
.40659 .38114 m .4141 .37549 L .42616 .38351 L p 0 1 0 r
F P
0 g
s
.4141 .37549 m .40659 .38114 L .39458 .37232 L p 0 1 0 r
F P
0 g
s
.20443 .33832 m .21132 .32927 L .2239 .33525 L p 0 0 1 r
F P
0 g
s
.4502 .39795 m .45796 .39008 L .46997 .39569 L p 0 1 0 r
F P
0 g
s
.45796 .39008 m .4502 .39795 L .4382 .39101 L p 0 1 0 r
F P
0 g
s
.48978 .3902 m .4977 .37872 L .50956 .38092 L p 0 1 0 r
F P
0 g
s
.51747 .36716 m .50956 .38092 L .4977 .37872 L p 0 1 0 r
F P
0 g
s
.23589 .27143 m .24267 .26407 L .25492 .27259 L p 0 1 0 r
F P
0 g
s
.2559 .33814 m .26298 .32909 L .27544 .33507 L p 0 0 1 r
F P
0 g
s
.26298 .32909 m .2559 .33814 L .24341 .33217 L p 0 0 1 r
F P
0 g
s
.38228 .2918 m .37463 .30408 L .36225 .30096 L p 1 0 0 r
F P
0 g
s
.31465 .32891 m .30739 .33796 L .29502 .33199 L p 0 0 1 r
F P
0 g
s
.35888 .33779 m .36632 .32873 L .37854 .33471 L p 0 0 1 r
F P
0 g
s
.41037 .33761 m .41801 .32855 L .4301 .33454 L p 0 0 1 r
F P
0 g
s
.41801 .32855 m .41037 .33761 L .39825 .33164 L p 0 0 1 r
F P
0 g
s
.27157 .38017 m .27895 .36867 L .29161 .37189 L p 1 0 0 r
F P
0 g
s
.29909 .35968 m .29161 .37189 L .27895 .36867 L p 1 0 0 r
F P
0 g
s
.46188 .33743 m .4697 .32837 L .48167 .33436 L p 0 0 1 r
F P
0 g
s
.4697 .32837 m .46188 .33743 L .44987 .33146 L p 0 0 1 r
F P
0 g
s
.52139 .32819 m .51339 .33725 L .50151 .33128 L p 0 0 1 r
F P
0 g
s
.64488 .53256 m .64829 .53935 L .64908 .54447 L p 1 0 0 r
F P
0 g
s
.29909 .35968 m .30663 .34713 L .31925 .34978 L p 1 0 0 r
F P
0 g
s
.32683 .33693 m .31925 .34978 L .30663 .34713 L p 1 0 0 r
F P
0 g
s
.56491 .33708 m .5731 .32802 L .58483 .334 L p 0 0 1 r
F P
0 g
s
.5731 .32802 m .56491 .33708 L .55315 .3311 L p 0 0 1 r
F P
0 g
s
.61644 .3369 m .62481 .32784 L .63642 .33383 L p 0 0 1 r
F P
0 g
s
.62481 .32784 m .61644 .3369 L .60479 .33092 L p 0 0 1 r
F P
0 g
s
.66797 .33672 m .67653 .32766 L .68802 .33365 L p 0 0 1 r
F P
0 g
s
.67653 .32766 m .66797 .33672 L .65645 .33075 L p 0 0 1 r
F P
0 g
s
.71951 .33654 m .72826 .32748 L .73962 .33347 L p 0 0 1 r
F P
0 g
s
.72826 .32748 m .71951 .33654 L .70811 .33057 L p 0 0 1 r
F P
0 g
s
.77106 .33636 m .77999 .3273 L .79123 .33329 L p 0 0 1 r
F P
0 g
s
.77999 .3273 m .77106 .33636 L .75978 .33039 L p 0 0 1 r
F P
0 g
s
.56149 .12278 m .56234 .12466 L p .54535 .15612 L 0 1 0 r
F P
0 g
s
.56234 .12466 m .55674 .14785 L .54535 .15612 L p 0 1 0 r
F P
0 g
s
.39458 .37232 m .40203 .36701 L .4141 .37549 L p 0 1 0 r
F P
0 g
s
.40203 .36701 m .39458 .37232 L .38257 .36317 L p 0 1 0 r
F P
0 g
s
.40219 .28393 m .40987 .27281 L .42202 .2778 L p 1 0 0 r
F P
0 g
s
.42202 .2778 m .42972 .26779 L .44179 .27387 L p 1 0 0 r
F P
0 g
s
.42972 .26779 m .42202 .2778 L .40987 .27281 L p 1 0 0 r
F P
0 g
s
.64777 .53755 m .64829 .53935 L .64488 .53256 L p 1 0 0 r
F P
0 g
s
.64488 .53256 m .64747 .53571 L .64777 .53755 L p 1 0 0 r
F P
0 g
s
.20031 .3852 m .20694 .3783 L .21945 .38504 L p 1 0 0 r
F P
0 g
s
.20694 .3783 m .20031 .3852 L .188 .37692 L p 1 0 0 r
F P
0 g
s
.38228 .2918 m .38995 .27982 L .40219 .28393 L p 1 0 0 r
F P
0 g
s
.40987 .27281 m .40219 .28393 L .38995 .27982 L p 1 0 0 r
F P
0 g
s
.2239 .33525 m .23086 .32618 L .24341 .33217 L p 0 0 1 r
F P
0 g
s
.23086 .32618 m .2239 .33525 L .21132 .32927 L p 0 0 1 r
F P
0 g
s
.27544 .33507 m .28259 .326 L .29502 .33199 L p 0 0 1 r
F P
0 g
s
.28259 .326 m .27544 .33507 L .26298 .32909 L p 0 0 1 r
F P
0 g
s
.23198 .39111 m .23902 .38188 L .25166 .38675 L p 1 0 0 r
F P
0 g
s
.23902 .38188 m .23198 .39111 L .21945 .38504 L p 1 0 0 r
F P
0 g
s
.4977 .37872 m .50563 .36599 L .51747 .36716 L p 0 1 0 r
F P
0 g
s
.52538 .35198 m .51747 .36716 L .50563 .36599 L p 0 1 0 r
F P
0 g
s
.37854 .33471 m .38606 .32564 L .39825 .33164 L p 0 0 1 r
F P
0 g
s
.38606 .32564 m .37854 .33471 L .36632 .32873 L p 0 0 1 r
F P
0 g
s
.4301 .33454 m .43781 .32546 L .44987 .33146 L p 0 0 1 r
F P
0 g
s
.43781 .32546 m .4301 .33454 L .41801 .32855 L p 0 0 1 r
F P
0 g
s
.55292 .12703 m .5607 .12032 L .56149 .12278 L p 0 1 0 r
F P
0 g
s
.54535 .15612 m .55292 .12703 L p .56149 .12278 L 0 1 0 r
F P
0 g
s
.25166 .38675 m .25889 .37625 L .27157 .38017 L p 1 0 0 r
F P
0 g
s
.27895 .36867 m .27157 .38017 L .25889 .37625 L p 1 0 0 r
F P
0 g
s
.46997 .39569 m .47782 .38617 L .48978 .3902 L p 0 1 0 r
F P
0 g
s
.47782 .38617 m .46997 .39569 L .45796 .39008 L p 0 1 0 r
F P
0 g
s
.48167 .33436 m .48957 .32528 L .50151 .33128 L p 0 0 1 r
F P
0 g
s
.48957 .32528 m .48167 .33436 L .4697 .32837 L p 0 0 1 r
F P
0 g
s
.64266 .51667 m .64426 .52187 L p .62898 .49511 L 1 0 0 r
F P
0 g
s
.64426 .52187 m .64177 .51884 L .62898 .49511 L p 1 0 0 r
F P
0 g
s
.62898 .49511 m .63864 .5052 L p .64266 .51667 L 1 0 0 r
F P
0 g
s
.4977 .37872 m .48978 .3902 L .47782 .38617 L p 0 1 0 r
F P
0 g
s
.58483 .334 m .5931 .32492 L .60479 .33092 L p 0 0 1 r
F P
0 g
s
.5931 .32492 m .58483 .334 L .5731 .32802 L p 0 0 1 r
F P
0 g
s
.38257 .36317 m .38994 .35814 L .40203 .36701 L p 0 1 0 r
F P
0 g
s
.38994 .35814 m .38257 .36317 L .37054 .35376 L p 0 1 0 r
F P
0 g
s
.63642 .33383 m .64488 .32474 L .65645 .33075 L p 0 0 1 r
F P
0 g
s
.64488 .32474 m .63642 .33383 L .62481 .32784 L p 0 0 1 r
F P
0 g
s
.44179 .27387 m .44953 .2652 L .46156 .27259 L p 1 0 0 r
F P
0 g
s
.44953 .2652 m .44179 .27387 L .42972 .26779 L p 1 0 0 r
F P
0 g
s
.68802 .33365 m .69666 .32456 L .70811 .33057 L p 0 0 1 r
F P
0 g
s
.69666 .32456 m .68802 .33365 L .67653 .32766 L p 0 0 1 r
F P
0 g
s
.4382 .39101 m .44591 .38377 L .45796 .39008 L p 0 1 0 r
F P
0 g
s
.44591 .38377 m .4382 .39101 L .42616 .38351 L p 0 1 0 r
F P
0 g
s
.25889 .37625 m .25166 .38675 L .23902 .38188 L p 1 0 0 r
F P
0 g
s
.73962 .33347 m .74845 .32438 L .75978 .33039 L p 0 0 1 r
F P
0 g
s
.74845 .32438 m .73962 .33347 L .72826 .32748 L p 0 0 1 r
F P
0 g
s
.56586 .36265 m .55727 .36078 L .54521 .34627 L p 1 0 0 r
F P
0 g
s
.54521 .34627 m .55365 .34675 L .56586 .36265 L p 1 0 0 r
F P
0 g
s
.50563 .36599 m .51359 .3519 L .52538 .35198 L p 0 1 0 r
F P
0 g
s
.53327 .33528 m .52538 .35198 L .51359 .3519 L p 0 1 0 r
F P
0 g
s
.6066 .43244 m .59742 .42593 L .58511 .40743 L p 1 0 0 r
F P
0 g
s
.58511 .40743 m .59405 .41226 L .6066 .43244 L p 1 0 0 r
F P
0 g
s
.51359 .3519 m .52153 .33636 L .53327 .33528 L p 0 1 0 r
F P
0 g
s
.36225 .30096 m .36992 .28836 L .38228 .2918 L p 1 0 0 r
F P
0 g
s
.38995 .27982 m .38228 .2918 L .36992 .28836 L p 1 0 0 r
F P
0 g
s
.2739 .27561 m .26711 .28145 L .25492 .27259 L p 0 1 0 r
F P
0 g
s
.56052 .16812 m .55301 .19572 L .5415 .20241 L p 0 1 0 r
F P
0 g
s
.5415 .20241 m .5492 .17618 L .56052 .16812 L p 0 1 0 r
F P
0 g
s
.30663 .34713 m .31422 .33432 L .32683 .33693 L p 1 0 0 r
F P
0 g
s
.188 .37692 m .19447 .37084 L .20694 .3783 L p 1 0 0 r
F P
0 g
s
.27895 .36867 m .28641 .35669 L .29909 .35968 L p 1 0 0 r
F P
0 g
s
.30663 .34713 m .29909 .35968 L .28641 .35669 L p 1 0 0 r
F P
0 g
s
.24341 .33217 m .25046 .32308 L .26298 .32909 L p 0 0 1 r
F P
0 g
s
.25046 .32308 m .24341 .33217 L .23086 .32618 L p 0 0 1 r
F P
0 g
s
.37054 .35376 m .37784 .34894 L .38994 .35814 L p 0 1 0 r
F P
0 g
s
.37784 .34894 m .37054 .35376 L .35851 .34413 L p 0 1 0 r
F P
0 g
s
.48141 .27446 m .47354 .28064 L .46156 .27259 L p 1 0 0 r
F P
0 g
s
.29502 .33199 m .30225 .3229 L .31465 .32891 L p 0 0 1 r
F P
0 g
s
.30225 .3229 m .29502 .33199 L .28259 .326 L p 0 0 1 r
F P
0 g
s
.39825 .33164 m .40585 .32254 L .41801 .32855 L p 0 0 1 r
F P
0 g
s
.40585 .32254 m .39825 .33164 L .38606 .32564 L p 0 0 1 r
F P
0 g
s
.44987 .33146 m .45767 .32236 L .4697 .32837 L p 0 0 1 r
F P
0 g
s
.45767 .32236 m .44987 .33146 L .43781 .32546 L p 0 0 1 r
F P
0 g
s
.50151 .33128 m .50949 .32218 L .52139 .32819 L p 0 0 1 r
F P
0 g
s
.50949 .32218 m .50151 .33128 L .48957 .32528 L p 0 0 1 r
F P
0 g
s
.55315 .3311 m .56131 .322 L .5731 .32802 L p 0 0 1 r
F P
0 g
s
.60479 .33092 m .61315 .32182 L .62481 .32784 L p 0 0 1 r
F P
0 g
s
.61315 .32182 m .60479 .33092 L .5931 .32492 L p 0 0 1 r
F P
0 g
s
.65645 .33075 m .66499 .32164 L .67653 .32766 L p 0 0 1 r
F P
0 g
s
.66499 .32164 m .65645 .33075 L .64488 .32474 L p 0 0 1 r
F P
0 g
s
.70811 .33057 m .71684 .32146 L .72826 .32748 L p 0 0 1 r
F P
0 g
s
.71684 .32146 m .70811 .33057 L .69666 .32456 L p 0 0 1 r
F P
0 g
s
.63549 .49164 m .6258 .48147 L .61318 .45966 L p 1 0 0 r
F P
0 g
s
.61318 .45966 m .62258 .46789 L .63549 .49164 L p 1 0 0 r
F P
0 g
s
.75978 .33039 m .76869 .32128 L .77999 .3273 L p 0 0 1 r
F P
0 g
s
.76869 .32128 m .75978 .33039 L .74845 .32438 L p 0 0 1 r
F P
0 g
s
.35851 .34413 m .36573 .33946 L .37784 .34894 L p 0 1 0 r
F P
0 g
s
.36573 .33946 m .35851 .34413 L .34647 .33435 L p 0 1 0 r
F P
0 g
s
.55677 .21477 m .54913 .23966 L .53754 .2448 L p 0 1 0 r
F P
0 g
s
.53754 .2448 m .54534 .22126 L .55677 .21477 L p 0 1 0 r
F P
0 g
s
.25492 .27259 m .26169 .26631 L .2739 .27561 L p 0 1 0 r
F P
0 g
s
.26169 .26631 m .25492 .27259 L .24267 .26407 L p 0 1 0 r
F P
0 g
s
.42616 .38351 m .43382 .37682 L .44591 .38377 L p 0 1 0 r
F P
0 g
s
.43382 .37682 m .42616 .38351 L .4141 .37549 L p 0 1 0 r
F P
0 g
s
.21945 .38504 m .22638 .37644 L .23902 .38188 L p 1 0 0 r
F P
0 g
s
.22638 .37644 m .21945 .38504 L .20694 .3783 L p 1 0 0 r
F P
0 g
s
.21132 .32927 m .21826 .32015 L .23086 .32618 L p 0 0 1 r
F P
0 g
s
.26298 .32909 m .2701 .31997 L .28259 .326 L p 0 0 1 r
F P
0 g
s
.2701 .31997 m .26298 .32909 L .25046 .32308 L p 0 0 1 r
F P
0 g
s
.57819 .3799 m .56941 .37654 L .55727 .36078 L p 1 0 0 r
F P
0 g
s
.55727 .36078 m .56586 .36265 L .57819 .3799 L p 1 0 0 r
F P
0 g
s
.34647 .33435 m .35362 .32976 L .36573 .33946 L p 0 1 0 r
F P
0 g
s
.36632 .32873 m .37382 .31961 L .38606 .32564 L p 0 0 1 r
F P
0 g
s
.37382 .31961 m .36632 .32873 L .35405 .32272 L p 0 0 1 r
F P
0 g
s
.36992 .28836 m .36225 .30096 L .34977 .29799 L p 1 0 0 r
F P
0 g
s
.41801 .32855 m .42569 .31943 L .43781 .32546 L p 0 0 1 r
F P
0 g
s
.42569 .31943 m .41801 .32855 L .40585 .32254 L p 0 0 1 r
F P
0 g
s
.38995 .27982 m .39763 .26821 L .40987 .27281 L p 1 0 0 r
F P
0 g
s
.40987 .27281 m .41757 .2622 L .42972 .26779 L p 1 0 0 r
F P
0 g
s
.41757 .2622 m .40987 .27281 L .39763 .26821 L p 1 0 0 r
F P
0 g
s
.25889 .37625 m .26623 .36512 L .27895 .36867 L p 1 0 0 r
F P
0 g
s
.28641 .35669 m .27895 .36867 L .26623 .36512 L p 1 0 0 r
F P
0 g
s
.4697 .32837 m .47757 .31925 L .48957 .32528 L p 0 0 1 r
F P
0 g
s
.47757 .31925 m .4697 .32837 L .45767 .32236 L p 0 0 1 r
F P
0 g
s
.46156 .27259 m .46939 .26553 L .48141 .27446 L p 1 0 0 r
F P
0 g
s
.46939 .26553 m .46156 .27259 L .44953 .2652 L p 1 0 0 r
F P
0 g
s
.45796 .39008 m .46579 .38133 L .47782 .38617 L p 0 1 0 r
F P
0 g
s
.46579 .38133 m .45796 .39008 L .44591 .38377 L p 0 1 0 r
F P
0 g
s
.47782 .38617 m .48573 .37559 L .4977 .37872 L p 0 1 0 r
F P
0 g
s
.50563 .36599 m .4977 .37872 L .48573 .37559 L p 0 1 0 r
F P
0 g
s
.5731 .32802 m .58135 .31889 L .5931 .32492 L p 0 0 1 r
F P
0 g
s
.58135 .31889 m .5731 .32802 L .56131 .322 L p 0 0 1 r
F P
0 g
s
.62481 .32784 m .63325 .31871 L .64488 .32474 L p 0 0 1 r
F P
0 g
s
.63325 .31871 m .62481 .32784 L .61315 .32182 L p 0 0 1 r
F P
0 g
s
.67653 .32766 m .68515 .31853 L .69666 .32456 L p 0 0 1 r
F P
0 g
s
.68515 .31853 m .67653 .32766 L .66499 .32164 L p 0 0 1 r
F P
0 g
s
.42972 .26779 m .43745 .25841 L .44953 .2652 L p 1 0 0 r
F P
0 g
s
.43745 .25841 m .42972 .26779 L .41757 .2622 L p 1 0 0 r
F P
0 g
s
.72826 .32748 m .73707 .31835 L .74845 .32438 L p 0 0 1 r
F P
0 g
s
.73707 .31835 m .72826 .32748 L .71684 .32146 L p 0 0 1 r
F P
0 g
s
.28641 .35669 m .29393 .34431 L .30663 .34713 L p 1 0 0 r
F P
0 g
s
.31422 .33432 m .30663 .34713 L .29393 .34431 L p 1 0 0 r
F P
0 g
s
.36992 .28836 m .3776 .276 L .38995 .27982 L p 1 0 0 r
F P
0 g
s
.39763 .26821 m .38995 .27982 L .3776 .276 L p 1 0 0 r
F P
0 g
s
.24267 .26407 m .24943 .25729 L .26169 .26631 L p 0 1 0 r
F P
0 g
s
.23902 .38188 m .24618 .37187 L .25889 .37625 L p 1 0 0 r
F P
0 g
s
.24618 .37187 m .23902 .38188 L .22638 .37644 L p 1 0 0 r
F P
0 g
s
.26623 .36512 m .25889 .37625 L .24618 .37187 L p 1 0 0 r
F P
0 g
s
.23086 .32618 m .23788 .31704 L .25046 .32308 L p 0 0 1 r
F P
0 g
s
.23788 .31704 m .23086 .32618 L .21826 .32015 L p 0 0 1 r
F P
0 g
s
.48573 .37559 m .47782 .38617 L .46579 .38133 L p 0 1 0 r
F P
0 g
s
.28259 .326 m .28979 .31686 L .30225 .3229 L p 0 0 1 r
F P
0 g
s
.28979 .31686 m .28259 .326 L .2701 .31997 L p 0 0 1 r
F P
0 g
s
.4141 .37549 m .4217 .36929 L .43382 .37682 L p 0 1 0 r
F P
0 g
s
.4217 .36929 m .4141 .37549 L .40203 .36701 L p 0 1 0 r
F P
0 g
s
.38606 .32564 m .39364 .31649 L .40585 .32254 L p 0 0 1 r
F P
0 g
s
.39364 .31649 m .38606 .32564 L .37382 .31961 L p 0 0 1 r
F P
0 g
s
.43781 .32546 m .44558 .31631 L .45767 .32236 L p 0 0 1 r
F P
0 g
s
.44558 .31631 m .43781 .32546 L .42569 .31943 L p 0 0 1 r
F P
0 g
s
.49752 .31613 m .48957 .32528 L .47757 .31925 L p 0 0 1 r
F P
0 g
s
.5931 .32492 m .60143 .31577 L .61315 .32182 L p 0 0 1 r
F P
0 g
s
.60143 .31577 m .5931 .32492 L .58135 .31889 L p 0 0 1 r
F P
0 g
s
.64488 .32474 m .65339 .31559 L .66499 .32164 L p 0 0 1 r
F P
0 g
s
.65339 .31559 m .64488 .32474 L .63325 .31871 L p 0 0 1 r
F P
0 g
s
.69666 .32456 m .70536 .31541 L .71684 .32146 L p 0 0 1 r
F P
0 g
s
.70536 .31541 m .69666 .32456 L .68515 .31853 L p 0 0 1 r
F P
0 g
s
.61934 .45436 m .60991 .44604 L .59742 .42593 L p 1 0 0 r
F P
0 g
s
.59742 .42593 m .6066 .43244 L .61934 .45436 L p 1 0 0 r
F P
0 g
s
.74845 .32438 m .75734 .31523 L .76869 .32128 L p 0 0 1 r
F P
0 g
s
.75734 .31523 m .74845 .32438 L .73707 .31835 L p 0 0 1 r
F P
0 g
s
.20694 .3783 m .21374 .3704 L .22638 .37644 L p 1 0 0 r
F P
0 g
s
.21374 .3704 m .20694 .3783 L .19447 .37084 L p 1 0 0 r
F P
0 g
s
.44953 .2652 m .45733 .25731 L .46939 .26553 L p 1 0 0 r
F P
0 g
s
.45733 .25731 m .44953 .2652 L .43745 .25841 L p 1 0 0 r
F P
0 g
s
.59064 .3986 m .58167 .39367 L .56941 .37654 L p 1 0 0 r
F P
0 g
s
.56941 .37654 m .57819 .3799 L .59064 .3986 L p 1 0 0 r
F P
0 g
s
.34977 .29799 m .35745 .28512 L .36992 .28836 L p 1 0 0 r
F P
0 g
s
.3776 .276 m .36992 .28836 L .35745 .28512 L p 1 0 0 r
F P
0 g
s
.48573 .37559 m .49368 .36384 L .50563 .36599 L p 0 1 0 r
F P
0 g
s
.51359 .3519 m .50563 .36599 L .49368 .36384 L p 0 1 0 r
F P
0 g
s
.25046 .32308 m .25756 .31391 L .2701 .31997 L p 0 0 1 r
F P
0 g
s
.25756 .31391 m .25046 .32308 L .23788 .31704 L p 0 0 1 r
F P
0 g
s
.40203 .36701 m .40956 .36125 L .4217 .36929 L p 0 1 0 r
F P
0 g
s
.40956 .36125 m .40203 .36701 L .38994 .35814 L p 0 1 0 r
F P
0 g
s
.30954 .31373 m .30225 .3229 L .28979 .31686 L p 0 0 1 r
F P
0 g
s
.26623 .36512 m .27365 .35343 L .28641 .35669 L p 1 0 0 r
F P
0 g
s
.29393 .34431 m .28641 .35669 L .27365 .35343 L p 1 0 0 r
F P
0 g
s
.55674 .14785 m .5492 .17618 L .53761 .18307 L p 0 1 0 r
F P
0 g
s
.53761 .18307 m .54535 .15612 L .55674 .14785 L p 0 1 0 r
F P
0 g
s
.35405 .32272 m .36152 .31355 L .37382 .31961 L p 0 0 1 r
F P
0 g
s
.44591 .38377 m .4537 .37573 L .46579 .38133 L p 0 1 0 r
F P
0 g
s
.4537 .37573 m .44591 .38377 L .43382 .37682 L p 0 1 0 r
F P
0 g
s
.40585 .32254 m .41351 .31337 L .42569 .31943 L p 0 0 1 r
F P
0 g
s
.41351 .31337 m .40585 .32254 L .39364 .31649 L p 0 0 1 r
F P
0 g
s
.29393 .34431 m .30151 .3316 L .31422 .33432 L p 1 0 0 r
F P
0 g
s
.32184 .32133 m .31422 .33432 L .30151 .3316 L p 1 0 0 r
F P
0 g
s
.45767 .32236 m .46551 .31319 L .47757 .31925 L p 0 0 1 r
F P
0 g
s
.46551 .31319 m .45767 .32236 L .44558 .31631 L p 0 0 1 r
F P
0 g
s
.64177 .51884 m .64509 .52541 L .64596 .53065 L p 1 0 0 r
F P
0 g
s
.56131 .322 m .56954 .31283 L .58135 .31889 L p 0 0 1 r
F P
0 g
s
.56954 .31283 m .56131 .322 L .54947 .31595 L p 0 0 1 r
F P
0 g
s
.61315 .32182 m .62156 .31265 L .63325 .31871 L p 0 0 1 r
F P
0 g
s
.62156 .31265 m .61315 .32182 L .60143 .31577 L p 0 0 1 r
F P
0 g
s
.66499 .32164 m .67359 .31247 L .68515 .31853 L p 0 0 1 r
F P
0 g
s
.67359 .31247 m .66499 .32164 L .65339 .31559 L p 0 0 1 r
F P
0 g
s
.71684 .32146 m .72563 .31229 L .73707 .31835 L p 0 0 1 r
F P
0 g
s
.72563 .31229 m .71684 .32146 L .70536 .31541 L p 0 0 1 r
F P
0 g
s
.39763 .26821 m .40534 .25705 L .41757 .2622 L p 1 0 0 r
F P
0 g
s
.41757 .2622 m .42529 .25216 L .43745 .25841 L p 1 0 0 r
F P
0 g
s
.42529 .25216 m .41757 .2622 L .40534 .25705 L p 1 0 0 r
F P
0 g
s
.3776 .276 m .3853 .26396 L .39763 .26821 L p 1 0 0 r
F P
0 g
s
.40534 .25705 m .39763 .26821 L .3853 .26396 L p 1 0 0 r
F P
0 g
s
.64456 .52364 m .64509 .52541 L .64177 .51884 L p 1 0 0 r
F P
0 g
s
.64177 .51884 m .64426 .52187 L .64456 .52364 L p 1 0 0 r
F P
0 g
s
.38994 .35814 m .3974 .35274 L .40956 .36125 L p 0 1 0 r
F P
0 g
s
.3974 .35274 m .38994 .35814 L .37784 .34894 L p 0 1 0 r
F P
0 g
s
.21826 .32015 m .22524 .31097 L .23788 .31704 L p 0 0 1 r
F P
0 g
s
.49368 .36384 m .50166 .3508 L .51359 .3519 L p 0 1 0 r
F P
0 g
s
.52153 .33636 m .51359 .3519 L .50166 .3508 L p 0 1 0 r
F P
0 g
s
.19447 .37084 m .20113 .36369 L .21374 .3704 L p 1 0 0 r
F P
0 g
s
.2701 .31997 m .27728 .31079 L .28979 .31686 L p 0 0 1 r
F P
0 g
s
.27728 .31079 m .2701 .31997 L .25756 .31391 L p 0 0 1 r
F P
0 g
s
.22638 .37644 m .23345 .367 L .24618 .37187 L p 1 0 0 r
F P
0 g
s
.23345 .367 m .22638 .37644 L .21374 .3704 L p 1 0 0 r
F P
0 g
s
.24618 .37187 m .25346 .36117 L .26623 .36512 L p 1 0 0 r
F P
0 g
s
.27365 .35343 m .26623 .36512 L .25346 .36117 L p 1 0 0 r
F P
0 g
s
.37382 .31961 m .38137 .31042 L .39364 .31649 L p 0 0 1 r
F P
0 g
s
.38137 .31042 m .37382 .31961 L .36152 .31355 L p 0 0 1 r
F P
0 g
s
.42569 .31943 m .43343 .31024 L .44558 .31631 L p 0 0 1 r
F P
0 g
s
.43343 .31024 m .42569 .31943 L .41351 .31337 L p 0 0 1 r
F P
0 g
s
.47757 .31925 m .4855 .31006 L .49752 .31613 L p 0 0 1 r
F P
0 g
s
.4855 .31006 m .47757 .31925 L .46551 .31319 L p 0 0 1 r
F P
0 g
s
.55301 .19572 m .54534 .22126 L .53367 .22659 L p 0 1 0 r
F P
0 g
s
.53367 .22659 m .5415 .20241 L .55301 .19572 L p 0 1 0 r
F P
0 g
s
.58135 .31889 m .58965 .3097 L .60143 .31577 L p 0 0 1 r
F P
0 g
s
.58965 .3097 m .58135 .31889 L .56954 .31283 L p 0 0 1 r
F P
0 g
s
.46579 .38133 m .47369 .3716 L .48573 .37559 L p 0 1 0 r
F P
0 g
s
.49368 .36384 m .48573 .37559 L .47369 .3716 L p 0 1 0 r
F P
0 g
s
.47369 .3716 m .46579 .38133 L .4537 .37573 L p 0 1 0 r
F P
0 g
s
.52946 .31925 m .52153 .33636 L .50965 .33637 L p 0 1 0 r
F P
0 g
s
.50965 .33637 m .51764 .32043 L .52946 .31925 L p 0 1 0 r
F P
0 g
s
.63325 .31871 m .64174 .30952 L .65339 .31559 L p 0 0 1 r
F P
0 g
s
.64174 .30952 m .63325 .31871 L .62156 .31265 L p 0 0 1 r
F P
0 g
s
.63919 .50254 m .6409 .50796 L p .6258 .48147 L 1 0 0 r
F P
0 g
s
.6409 .50796 m .63864 .5052 L .6258 .48147 L p 1 0 0 r
F P
0 g
s
.6258 .48147 m .63549 .49164 L p .63919 .50254 L 1 0 0 r
F P
0 g
s
.50166 .3508 m .50965 .33637 L .52153 .33636 L p 0 1 0 r
F P
0 g
s
.43745 .25841 m .44522 .24975 L .45733 .25731 L p 1 0 0 r
F P
0 g
s
.44522 .24975 m .43745 .25841 L .42529 .25216 L p 1 0 0 r
F P
0 g
s
.68515 .31853 m .69384 .30933 L .70536 .31541 L p 0 0 1 r
F P
0 g
s
.69384 .30933 m .68515 .31853 L .67359 .31247 L p 0 0 1 r
F P
0 g
s
.25346 .36117 m .24618 .37187 L .23345 .367 L p 1 0 0 r
F P
0 g
s
.73707 .31835 m .74594 .30915 L .75734 .31523 L p 0 0 1 r
F P
0 g
s
.74594 .30915 m .73707 .31835 L .72563 .31229 L p 0 0 1 r
F P
0 g
s
.35745 .28512 m .36515 .27244 L .3776 .276 L p 1 0 0 r
F P
0 g
s
.3853 .26396 m .3776 .276 L .36515 .27244 L p 1 0 0 r
F P
0 g
s
.37784 .34894 m .38523 .34383 L .3974 .35274 L p 0 1 0 r
F P
0 g
s
.38523 .34383 m .37784 .34894 L .36573 .33946 L p 0 1 0 r
F P
0 g
s
.30151 .3316 m .30913 .31865 L .32184 .32133 L p 1 0 0 r
F P
0 g
s
.43382 .37682 m .44157 .36942 L .4537 .37573 L p 0 1 0 r
F P
0 g
s
.44157 .36942 m .43382 .37682 L .4217 .36929 L p 0 1 0 r
F P
0 g
s
.27365 .35343 m .28115 .34128 L .29393 .34431 L p 1 0 0 r
F P
0 g
s
.30151 .3316 m .29393 .34431 L .28115 .34128 L p 1 0 0 r
F P
0 g
s
.26848 .26049 m .26169 .26631 L .24943 .25729 L p 0 1 0 r
F P
0 g
s
.23788 .31704 m .24495 .30783 L .25756 .31391 L p 0 0 1 r
F P
0 g
s
.24495 .30783 m .23788 .31704 L .22524 .31097 L p 0 0 1 r
F P
0 g
s
.28979 .31686 m .29705 .30765 L .30954 .31373 L p 0 0 1 r
F P
0 g
s
.29705 .30765 m .28979 .31686 L .27728 .31079 L p 0 0 1 r
F P
0 g
s
.56227 .34873 m .55365 .34675 L .54151 .3321 L p 1 0 0 r
F P
0 g
s
.54151 .3321 m .54998 .33269 L .56227 .34873 L p 1 0 0 r
F P
0 g
s
.60326 .41888 m .59405 .41226 L .58167 .39367 L p 1 0 0 r
F P
0 g
s
.58167 .39367 m .59064 .3986 L .60326 .41888 L p 1 0 0 r
F P
0 g
s
.39364 .31649 m .40128 .30729 L .41351 .31337 L p 0 0 1 r
F P
0 g
s
.40128 .30729 m .39364 .31649 L .38137 .31042 L p 0 0 1 r
F P
0 g
s
.47729 .2594 m .46939 .26553 L .45733 .25731 L p 1 0 0 r
F P
0 g
s
.44558 .31631 m .4534 .3071 L .46551 .31319 L p 0 0 1 r
F P
0 g
s
.4534 .3071 m .44558 .31631 L .43343 .31024 L p 0 0 1 r
F P
0 g
s
.50553 .30692 m .49752 .31613 L .4855 .31006 L p 0 0 1 r
F P
0 g
s
.36573 .33946 m .37305 .33457 L .38523 .34383 L p 0 1 0 r
F P
0 g
s
.37305 .33457 m .36573 .33946 L .35362 .32976 L p 0 1 0 r
F P
0 g
s
.54947 .31595 m .55767 .30674 L .56954 .31283 L p 0 0 1 r
F P
0 g
s
.55767 .30674 m .54947 .31595 L .53757 .30988 L p 0 0 1 r
F P
0 g
s
.60143 .31577 m .60982 .30656 L .62156 .31265 L p 0 0 1 r
F P
0 g
s
.60982 .30656 m .60143 .31577 L .58965 .3097 L p 0 0 1 r
F P
0 g
s
.65339 .31559 m .66197 .30638 L .67359 .31247 L p 0 0 1 r
F P
0 g
s
.66197 .30638 m .65339 .31559 L .64174 .30952 L p 0 0 1 r
F P
0 g
s
.70536 .31541 m .71413 .30619 L .72563 .31229 L p 0 0 1 r
F P
0 g
s
.71413 .30619 m .70536 .31541 L .69384 .30933 L p 0 0 1 r
F P
0 g
s
.24943 .25729 m .2562 .25104 L .26848 .26049 L p 0 1 0 r
F P
0 g
s
.63232 .47816 m .62258 .46789 L .60991 .44604 L p 1 0 0 r
F P
0 g
s
.60991 .44604 m .61934 .45436 L .63232 .47816 L p 1 0 0 r
F P
0 g
s
.35362 .32976 m .36086 .32503 L .37305 .33457 L p 0 1 0 r
F P
0 g
s
.36086 .32503 m .35362 .32976 L .3415 .3199 L p 0 1 0 r
F P
0 g
s
.36515 .27244 m .35745 .28512 L .34488 .28203 L p 1 0 0 r
F P
0 g
s
.25756 .31391 m .26471 .30469 L .27728 .31079 L p 0 0 1 r
F P
0 g
s
.26471 .30469 m .25756 .31391 L .24495 .30783 L p 0 0 1 r
F P
0 g
s
.21374 .3704 m .22071 .36158 L .23345 .367 L p 1 0 0 r
F P
0 g
s
.22071 .36158 m .21374 .3704 L .20113 .36369 L p 1 0 0 r
F P
0 g
s
.4217 .36929 m .42939 .36247 L .44157 .36942 L p 0 1 0 r
F P
0 g
s
.42939 .36247 m .4217 .36929 L .40956 .36125 L p 0 1 0 r
F P
0 g
s
.3853 .26396 m .39302 .2523 L .40534 .25705 L p 1 0 0 r
F P
0 g
s
.40534 .25705 m .41307 .24641 L .42529 .25216 L p 1 0 0 r
F P
0 g
s
.41307 .24641 m .40534 .25705 L .39302 .2523 L p 1 0 0 r
F P
0 g
s
.25346 .36117 m .26084 .34984 L .27365 .35343 L p 1 0 0 r
F P
0 g
s
.28115 .34128 m .27365 .35343 L .26084 .34984 L p 1 0 0 r
F P
0 g
s
.36152 .31355 m .36905 .30432 L .38137 .31042 L p 0 0 1 r
F P
0 g
s
.36905 .30432 m .36152 .31355 L .34916 .30747 L p 0 0 1 r
F P
0 g
s
.55292 .12703 m .54535 .15612 L .53369 .16322 L p 0 1 0 r
F P
0 g
s
.53369 .16322 m .54145 .13552 L .55292 .12703 L p 0 1 0 r
F P
0 g
s
.41351 .31337 m .42123 .30414 L .43343 .31024 L p 0 0 1 r
F P
0 g
s
.42123 .30414 m .41351 .31337 L .40128 .30729 L p 0 0 1 r
F P
0 g
s
.46551 .31319 m .47342 .30396 L .4855 .31006 L p 0 0 1 r
F P
0 g
s
.47342 .30396 m .46551 .31319 L .4534 .3071 L p 0 0 1 r
F P
0 g
s
.47369 .3716 m .48163 .36076 L .49368 .36384 L p 0 1 0 r
F P
0 g
s
.50166 .3508 m .49368 .36384 L .48163 .36076 L p 0 1 0 r
F P
0 g
s
.45733 .25731 m .46518 .25029 L .47729 .2594 L p 1 0 0 r
F P
0 g
s
.46518 .25029 m .45733 .25731 L .44522 .24975 L p 1 0 0 r
F P
0 g
s
.3415 .3199 m .34866 .31526 L .36086 .32503 L p 0 1 0 r
F P
0 g
s
.56954 .31283 m .57782 .30359 L .58965 .3097 L p 0 0 1 r
F P
0 g
s
.57782 .30359 m .56954 .31283 L .55767 .30674 L p 0 0 1 r
F P
0 g
s
.57467 .36612 m .56586 .36265 L .55365 .34675 L p 1 0 0 r
F P
0 g
s
.55365 .34675 m .56227 .34873 L .57467 .36612 L p 1 0 0 r
F P
0 g
s
.62156 .31265 m .63003 .30341 L .64174 .30952 L p 0 0 1 r
F P
0 g
s
.63003 .30341 m .62156 .31265 L .60982 .30656 L p 0 0 1 r
F P
0 g
s
.28115 .34128 m .28871 .32873 L .30151 .3316 L p 1 0 0 r
F P
0 g
s
.30913 .31865 m .30151 .3316 L .28871 .32873 L p 1 0 0 r
F P
0 g
s
.42529 .25216 m .43305 .24279 L .44522 .24975 L p 1 0 0 r
F P
0 g
s
.43305 .24279 m .42529 .25216 L .41307 .24641 L p 1 0 0 r
F P
0 g
s
.67359 .31247 m .68225 .30323 L .69384 .30933 L p 0 0 1 r
F P
0 g
s
.68225 .30323 m .67359 .31247 L .66197 .30638 L p 0 0 1 r
F P
0 g
s
.4537 .37573 m .46157 .36677 L .47369 .3716 L p 0 1 0 r
F P
0 g
s
.46157 .36677 m .4537 .37573 L .44157 .36942 L p 0 1 0 r
F P
0 g
s
.72563 .31229 m .73448 .30305 L .74594 .30915 L p 0 0 1 r
F P
0 g
s
.73448 .30305 m .72563 .31229 L .71413 .30619 L p 0 0 1 r
F P
0 g
s
.36515 .27244 m .37287 .26 L .3853 .26396 L p 1 0 0 r
F P
0 g
s
.39302 .2523 m .3853 .26396 L .37287 .26 L p 1 0 0 r
F P
0 g
s
.23345 .367 m .24065 .35679 L .25346 .36117 L p 1 0 0 r
F P
0 g
s
.26084 .34984 m .25346 .36117 L .24065 .35679 L p 1 0 0 r
F P
0 g
s
.24065 .35679 m .23345 .367 L .22071 .36158 L p 1 0 0 r
F P
0 g
s
.22524 .31097 m .23228 .30172 L .24495 .30783 L p 0 0 1 r
F P
0 g
s
.27728 .31079 m .28451 .30154 L .29705 .30765 L p 0 0 1 r
F P
0 g
s
.28451 .30154 m .27728 .31079 L .26471 .30469 L p 0 0 1 r
F P
0 g
s
.48163 .36076 m .47369 .3716 L .46157 .36677 L p 0 1 0 r
F P
0 g
s
.38137 .31042 m .38898 .30117 L .40128 .30729 L p 0 0 1 r
F P
0 g
s
.38898 .30117 m .38137 .31042 L .36905 .30432 L p 0 0 1 r
F P
0 g
s
.43343 .31024 m .44123 .30099 L .4534 .3071 L p 0 0 1 r
F P
0 g
s
.44123 .30099 m .43343 .31024 L .42123 .30414 L p 0 0 1 r
F P
0 g
s
.4855 .31006 m .49349 .3008 L .50553 .30692 L p 0 0 1 r
F P
0 g
s
.49349 .3008 m .4855 .31006 L .47342 .30396 L p 0 0 1 r
F P
0 g
s
.40956 .36125 m .41719 .35492 L .42939 .36247 L p 0 1 0 r
F P
0 g
s
.41719 .35492 m .40956 .36125 L .3974 .35274 L p 0 1 0 r
F P
0 g
s
.53757 .30988 m .54575 .30062 L .55767 .30674 L p 0 0 1 r
F P
0 g
s
.58965 .3097 m .59802 .30044 L .60982 .30656 L p 0 0 1 r
F P
0 g
s
.59802 .30044 m .58965 .3097 L .57782 .30359 L p 0 0 1 r
F P
0 g
s
.64174 .30952 m .6503 .30026 L .66197 .30638 L p 0 0 1 r
F P
0 g
s
.6503 .30026 m .64174 .30952 L .63003 .30341 L p 0 0 1 r
F P
0 g
s
.69384 .30933 m .70258 .30007 L .71413 .30619 L p 0 0 1 r
F P
0 g
s
.70258 .30007 m .69384 .30933 L .68225 .30323 L p 0 0 1 r
F P
0 g
s
.34488 .28203 m .3526 .26907 L .36515 .27244 L p 1 0 0 r
F P
0 g
s
.37287 .26 m .36515 .27244 L .3526 .26907 L p 1 0 0 r
F P
0 g
s
.20113 .36369 m .20797 .35556 L .22071 .36158 L p 1 0 0 r
F P
0 g
s
.44522 .24975 m .45304 .24189 L .46518 .25029 L p 1 0 0 r
F P
0 g
s
.45304 .24189 m .44522 .24975 L .43305 .24279 L p 1 0 0 r
F P
0 g
s
.48163 .36076 m .48962 .34872 L .50166 .3508 L p 0 1 0 r
F P
0 g
s
.50965 .33637 m .50166 .3508 L .48962 .34872 L p 0 1 0 r
F P
0 g
s
.61608 .44089 m .6066 .43244 L .59405 .41226 L p 1 0 0 r
F P
0 g
s
.59405 .41226 m .60326 .41888 L .61608 .44089 L p 1 0 0 r
F P
0 g
s
.5492 .17618 m .5415 .20241 L .52975 .20792 L p 0 1 0 r
F P
0 g
s
.52975 .20792 m .53761 .18307 L .5492 .17618 L p 0 1 0 r
F P
0 g
s
.54534 .22126 m .53754 .2448 L .52574 .24879 L p 0 1 0 r
F P
0 g
s
.52574 .24879 m .53367 .22659 L .54534 .22126 L p 0 1 0 r
F P
0 g
s
.26084 .34984 m .2683 .33797 L .28115 .34128 L p 1 0 0 r
F P
0 g
s
.28871 .32873 m .28115 .34128 L .2683 .33797 L p 1 0 0 r
F P
0 g
s
.28871 .32873 m .29633 .31586 L .30913 .31865 L p 1 0 0 r
F P
0 g
s
.31679 .30552 m .30913 .31865 L .29633 .31586 L p 1 0 0 r
F P
0 g
s
.24495 .30783 m .25207 .29856 L .26471 .30469 L p 0 0 1 r
F P
0 g
s
.25207 .29856 m .24495 .30783 L .23228 .30172 L p 0 0 1 r
F P
0 g
s
.30436 .29838 m .29705 .30765 L .28451 .30154 L p 0 0 1 r
F P
0 g
s
.34916 .30747 m .35666 .29819 L .36905 .30432 L p 0 0 1 r
F P
0 g
s
.35666 .29819 m .34916 .30747 L .33674 .30135 L p 0 0 1 r
F P
0 g
s
.40128 .30729 m .40897 .29801 L .42123 .30414 L p 0 0 1 r
F P
0 g
s
.40897 .29801 m .40128 .30729 L .38898 .30117 L p 0 0 1 r
F P
0 g
s
.5872 .38495 m .57819 .3799 L .56586 .36265 L p 1 0 0 r
F P
0 g
s
.56586 .36265 m .57467 .36612 L .5872 .38495 L p 1 0 0 r
F P
0 g
s
.4534 .3071 m .46128 .29783 L .47342 .30396 L p 0 0 1 r
F P
0 g
s
.46128 .29783 m .4534 .3071 L .44123 .30099 L p 0 0 1 r
F P
0 g
s
.63864 .5052 m .64171 .51123 L .64266 .51667 L p 1 0 0 r
F P
0 g
s
.3974 .35274 m .40496 .34686 L .41719 .35492 L p 0 1 0 r
F P
0 g
s
.40496 .34686 m .3974 .35274 L .38523 .34383 L p 0 1 0 r
F P
0 g
s
.44157 .36942 m .44939 .36119 L .46157 .36677 L p 0 1 0 r
F P
0 g
s
.44939 .36119 m .44157 .36942 L .42939 .36247 L p 0 1 0 r
F P
0 g
s
.55767 .30674 m .56593 .29746 L .57782 .30359 L p 0 0 1 r
F P
0 g
s
.56593 .29746 m .55767 .30674 L .54575 .30062 L p 0 0 1 r
F P
0 g
s
.60982 .30656 m .61827 .29728 L .63003 .30341 L p 0 0 1 r
F P
0 g
s
.61827 .29728 m .60982 .30656 L .59802 .30044 L p 0 0 1 r
F P
0 g
s
.66197 .30638 m .67061 .29709 L .68225 .30323 L p 0 0 1 r
F P
0 g
s
.67061 .29709 m .66197 .30638 L .6503 .30026 L p 0 0 1 r
F P
0 g
s
.71413 .30619 m .72297 .29691 L .73448 .30305 L p 0 0 1 r
F P
0 g
s
.72297 .29691 m .71413 .30619 L .70258 .30007 L p 0 0 1 r
F P
0 g
s
.39302 .2523 m .40075 .24111 L .41307 .24641 L p 1 0 0 r
F P
0 g
s
.41307 .24641 m .42082 .23637 L .43305 .24279 L p 1 0 0 r
F P
0 g
s
.42082 .23637 m .41307 .24641 L .40075 .24111 L p 1 0 0 r
F P
0 g
s
.37287 .26 m .3806 .2479 L .39302 .2523 L p 1 0 0 r
F P
0 g
s
.40075 .24111 m .39302 .2523 L .3806 .2479 L p 1 0 0 r
F P
0 g
s
.48962 .34872 m .49764 .33535 L .50965 .33637 L p 0 1 0 r
F P
0 g
s
.51764 .32043 m .50965 .33637 L .49764 .33535 L p 0 1 0 r
F P
0 g
s
.6412 .50959 m .64171 .51123 L .63864 .5052 L p 1 0 0 r
F P
0 g
s
.63864 .5052 m .6409 .50796 L .6412 .50959 L p 1 0 0 r
F P
0 g
s
.26471 .30469 m .27191 .29539 L .28451 .30154 L p 0 0 1 r
F P
0 g
s
.27191 .29539 m .26471 .30469 L .25207 .29856 L p 0 0 1 r
F P
0 g
s
.24065 .35679 m .24797 .34588 L .26084 .34984 L p 1 0 0 r
F P
0 g
s
.2683 .33797 m .26084 .34984 L .24797 .34588 L p 1 0 0 r
F P
0 g
s
.22071 .36158 m .22782 .35192 L .24065 .35679 L p 1 0 0 r
F P
0 g
s
.22782 .35192 m .22071 .36158 L .20797 .35556 L p 1 0 0 r
F P
0 g
s
.36905 .30432 m .37663 .29502 L .38898 .30117 L p 0 0 1 r
F P
0 g
s
.37663 .29502 m .36905 .30432 L .35666 .29819 L p 0 0 1 r
F P
0 g
s
.38523 .34383 m .39271 .33832 L .40496 .34686 L p 0 1 0 r
F P
0 g
s
.39271 .33832 m .38523 .34383 L .37305 .33457 L p 0 1 0 r
F P
0 g
s
.49764 .33535 m .50567 .32054 L .51764 .32043 L p 0 1 0 r
F P
0 g
s
.42123 .30414 m .429 .29484 L .44123 .30099 L p 0 0 1 r
F P
0 g
s
.429 .29484 m .42123 .30414 L .40897 .29801 L p 0 0 1 r
F P
0 g
s
.47342 .30396 m .48138 .29466 L .49349 .3008 L p 0 0 1 r
F P
0 g
s
.48138 .29466 m .47342 .30396 L .46128 .29783 L p 0 0 1 r
F P
0 g
s
.57782 .30359 m .58617 .29429 L .59802 .30044 L p 0 0 1 r
F P
0 g
s
.58617 .29429 m .57782 .30359 L .56593 .29746 L p 0 0 1 r
F P
0 g
s
.46157 .36677 m .4695 .3568 L .48163 .36076 L p 0 1 0 r
F P
0 g
s
.48962 .34872 m .48163 .36076 L .4695 .3568 L p 0 1 0 r
F P
0 g
s
.63003 .30341 m .63857 .29411 L .6503 .30026 L p 0 0 1 r
F P
0 g
s
.63857 .29411 m .63003 .30341 L .61827 .29728 L p 0 0 1 r
F P
0 g
s
.3526 .26907 m .36034 .2563 L .37287 .26 L p 1 0 0 r
F P
0 g
s
.3806 .2479 m .37287 .26 L .36034 .2563 L p 1 0 0 r
F P
0 g
s
.29633 .31586 m .30399 .30275 L .31679 .30552 L p 1 0 0 r
F P
0 g
s
.24797 .34588 m .24065 .35679 L .22782 .35192 L p 1 0 0 r
F P
0 g
s
.48527 .25428 m .47729 .2594 L .46518 .25029 L p 1 0 0 r
F P
0 g
s
.54627 .31859 m .53777 .31788 L .52563 .30422 L p 1 0 0 r
F P
0 g
s
.52563 .30422 m .53398 .30361 L .54627 .31859 L p 1 0 0 r
F P
0 g
s
.68225 .30323 m .69098 .29392 L .70258 .30007 L p 0 0 1 r
F P
0 g
s
.69098 .29392 m .68225 .30323 L .67061 .29709 L p 0 0 1 r
F P
0 g
s
.43305 .24279 m .44085 .23415 L .45304 .24189 L p 1 0 0 r
F P
0 g
s
.44085 .23415 m .43305 .24279 L .42082 .23637 L p 1 0 0 r
F P
0 g
s
.4695 .3568 m .46157 .36677 L .44939 .36119 L p 0 1 0 r
F P
0 g
s
.2683 .33797 m .27583 .32564 L .28871 .32873 L p 1 0 0 r
F P
0 g
s
.29633 .31586 m .28871 .32873 L .27583 .32564 L p 1 0 0 r
F P
0 g
s
.63554 .48826 m .63741 .49399 L p .62258 .46789 L 1 0 0 r
F P
0 g
s
.63741 .49399 m .63549 .49164 L .62258 .46789 L p 1 0 0 r
F P
0 g
s
.62258 .46789 m .63232 .47816 L p .63554 .48826 L 1 0 0 r
F P
0 g
s
.37305 .33457 m .38046 .32937 L .39271 .33832 L p 0 1 0 r
F P
0 g
s
.38046 .32937 m .37305 .33457 L .36086 .32503 L p 0 1 0 r
F P
0 g
s
.42939 .36247 m .43717 .35489 L .44939 .36119 L p 0 1 0 r
F P
0 g
s
.43717 .35489 m .42939 .36247 L .41719 .35492 L p 0 1 0 r
F P
0 g
s
.23228 .30172 m .23937 .2924 L .25207 .29856 L p 0 0 1 r
F P
0 g
s
.28451 .30154 m .29179 .29222 L .30436 .29838 L p 0 0 1 r
F P
0 g
s
.29179 .29222 m .28451 .30154 L .27191 .29539 L p 0 0 1 r
F P
0 g
s
.33674 .30135 m .34422 .29203 L .35666 .29819 L p 0 0 1 r
F P
0 g
s
.38898 .30117 m .39665 .29185 L .40897 .29801 L p 0 0 1 r
F P
0 g
s
.39665 .29185 m .38898 .30117 L .37663 .29502 L p 0 0 1 r
F P
0 g
s
.44123 .30099 m .44909 .29167 L .46128 .29783 L p 0 0 1 r
F P
0 g
s
.44909 .29167 m .44123 .30099 L .429 .29484 L p 0 0 1 r
F P
0 g
s
.50153 .29148 m .49349 .3008 L .48138 .29466 L p 0 0 1 r
F P
0 g
s
.46518 .25029 m .47311 .24421 L .48527 .25428 L p 1 0 0 r
F P
0 g
s
.47311 .24421 m .46518 .25029 L .45304 .24189 L p 1 0 0 r
F P
0 g
s
.54575 .30062 m .55399 .2913 L .56593 .29746 L p 0 0 1 r
F P
0 g
s
.55399 .2913 m .54575 .30062 L .53377 .29447 L p 0 0 1 r
F P
0 g
s
.59802 .30044 m .60645 .29111 L .61827 .29728 L p 0 0 1 r
F P
0 g
s
.60645 .29111 m .59802 .30044 L .58617 .29429 L p 0 0 1 r
F P
0 g
s
.55864 .3348 m .54998 .33269 L .53777 .31788 L p 1 0 0 r
F P
0 g
s
.53777 .31788 m .54627 .31859 L .55864 .3348 L p 1 0 0 r
F P
0 g
s
.6503 .30026 m .65892 .29093 L .67061 .29709 L p 0 0 1 r
F P
0 g
s
.65892 .29093 m .6503 .30026 L .63857 .29411 L p 0 0 1 r
F P
0 g
s
.59989 .40536 m .59064 .3986 L .57819 .3799 L p 1 0 0 r
F P
0 g
s
.57819 .3799 m .5872 .38495 L .59989 .40536 L p 1 0 0 r
F P
0 g
s
.70258 .30007 m .7114 .29074 L .72297 .29691 L p 0 0 1 r
F P
0 g
s
.7114 .29074 m .70258 .30007 L .69098 .29392 L p 0 0 1 r
F P
0 g
s
.36086 .32503 m .36819 .32006 L .38046 .32937 L p 0 1 0 r
F P
0 g
s
.36819 .32006 m .36086 .32503 L .34866 .31526 L p 0 1 0 r
F P
0 g
s
.36034 .2563 m .3526 .26907 L .33994 .26586 L p 1 0 0 r
F P
0 g
s
.24797 .34588 m .25538 .33436 L .2683 .33797 L p 1 0 0 r
F P
0 g
s
.27583 .32564 m .2683 .33797 L .25538 .33436 L p 1 0 0 r
F P
0 g
s
.25207 .29856 m .25924 .28922 L .27191 .29539 L p 0 0 1 r
F P
0 g
s
.25924 .28922 m .25207 .29856 L .23937 .2924 L p 0 0 1 r
F P
0 g
s
.3806 .2479 m .38835 .2362 L .40075 .24111 L p 1 0 0 r
F P
0 g
s
.40075 .24111 m .40851 .23045 L .42082 .23637 L p 1 0 0 r
F P
0 g
s
.40851 .23045 m .40075 .24111 L .38835 .2362 L p 1 0 0 r
F P
0 g
s
.20797 .35556 m .21497 .34651 L .22782 .35192 L p 1 0 0 r
F P
0 g
s
.35666 .29819 m .36422 .28885 L .37663 .29502 L p 0 0 1 r
F P
0 g
s
.36422 .28885 m .35666 .29819 L .34422 .29203 L p 0 0 1 r
F P
0 g
s
.34866 .31526 m .35592 .31047 L .36819 .32006 L p 0 1 0 r
F P
0 g
s
.35592 .31047 m .34866 .31526 L .33647 .30533 L p 0 1 0 r
F P
0 g
s
.40897 .29801 m .41671 .28867 L .429 .29484 L p 0 0 1 r
F P
0 g
s
.41671 .28867 m .40897 .29801 L .39665 .29185 L p 0 0 1 r
F P
0 g
s
.62912 .46476 m .61934 .45436 L .6066 .43244 L p 1 0 0 r
F P
0 g
s
.6066 .43244 m .61608 .44089 L .62912 .46476 L p 1 0 0 r
F P
0 g
s
.46128 .29783 m .46922 .28848 L .48138 .29466 L p 0 0 1 r
F P
0 g
s
.46922 .28848 m .46128 .29783 L .44909 .29167 L p 0 0 1 r
F P
0 g
s
.27583 .32564 m .28343 .31292 L .29633 .31586 L p 1 0 0 r
F P
0 g
s
.30399 .30275 m .29633 .31586 L .28343 .31292 L p 1 0 0 r
F P
0 g
s
.54535 .15612 m .53761 .18307 L .52579 .18879 L p 0 1 0 r
F P
0 g
s
.52579 .18879 m .53369 .16322 L .54535 .15612 L p 0 1 0 r
F P
0 g
s
.4695 .3568 m .47748 .3457 L .48962 .34872 L p 0 1 0 r
F P
0 g
s
.49764 .33535 m .48962 .34872 L .47748 .3457 L p 0 1 0 r
F P
0 g
s
.41719 .35492 m .42491 .34794 L .43717 .35489 L p 0 1 0 r
F P
0 g
s
.42491 .34794 m .41719 .35492 L .40496 .34686 L p 0 1 0 r
F P
0 g
s
.56593 .29746 m .57425 .28811 L .58617 .29429 L p 0 0 1 r
F P
0 g
s
.57425 .28811 m .56593 .29746 L .55399 .2913 L p 0 0 1 r
F P
0 g
s
.36034 .2563 m .36809 .2438 L .3806 .2479 L p 1 0 0 r
F P
0 g
s
.38835 .2362 m .3806 .2479 L .36809 .2438 L p 1 0 0 r
F P
0 g
s
.61827 .29728 m .62678 .28793 L .63857 .29411 L p 0 0 1 r
F P
0 g
s
.62678 .28793 m .61827 .29728 L .60645 .29111 L p 0 0 1 r
F P
0 g
s
.42082 .23637 m .42861 .22701 L .44085 .23415 L p 1 0 0 r
F P
0 g
s
.42861 .22701 m .42082 .23637 L .40851 .23045 L p 1 0 0 r
F P
0 g
s
.45304 .24189 m .46092 .23492 L .47311 .24421 L p 1 0 0 r
F P
0 g
s
.46092 .23492 m .45304 .24189 L .44085 .23415 L p 1 0 0 r
F P
0 g
s
.67061 .29709 m .67932 .28774 L .69098 .29392 L p 0 0 1 r
F P
0 g
s
.67932 .28774 m .67061 .29709 L .65892 .29093 L p 0 0 1 r
F P
0 g
s
.33647 .30533 m .34364 .30063 L .35592 .31047 L p 0 1 0 r
F P
0 g
s
.34364 .30063 m .33647 .30533 L .32426 .29528 L p 0 1 0 r
F P
0 g
s
.44939 .36119 m .45729 .35202 L .4695 .3568 L p 0 1 0 r
F P
0 g
s
.45729 .35202 m .44939 .36119 L .43717 .35489 L p 0 1 0 r
F P
0 g
s
.5415 .20241 m .53367 .22659 L .52179 .23075 L p 0 1 0 r
F P
0 g
s
.52179 .23075 m .52975 .20792 L .5415 .20241 L p 0 1 0 r
F P
0 g
s
.22782 .35192 m .23506 .34149 L .24797 .34588 L p 1 0 0 r
F P
0 g
s
.25538 .33436 m .24797 .34588 L .23506 .34149 L p 1 0 0 r
F P
0 g
s
.57111 .35234 m .56227 .34873 L .54998 .33269 L p 1 0 0 r
F P
0 g
s
.54998 .33269 m .55864 .3348 L .57111 .35234 L p 1 0 0 r
F P
0 g
s
.23506 .34149 m .22782 .35192 L .21497 .34651 L p 1 0 0 r
F P
0 g
s
.27191 .29539 m .27916 .28603 L .29179 .29222 L p 0 0 1 r
F P
0 g
s
.27916 .28603 m .27191 .29539 L .25924 .28922 L p 0 0 1 r
F P
0 g
s
.32426 .29528 m .33136 .29062 L .34364 .30063 L p 0 1 0 r
F P
0 g
s
.37663 .29502 m .38427 .28566 L .39665 .29185 L p 0 0 1 r
F P
0 g
s
.38427 .28566 m .37663 .29502 L .36422 .28885 L p 0 0 1 r
F P
0 g
s
.47748 .3457 m .4695 .3568 L .45729 .35202 L p 0 1 0 r
F P
0 g
s
.429 .29484 m .43683 .28547 L .44909 .29167 L p 0 0 1 r
F P
0 g
s
.43683 .28547 m .429 .29484 L .41671 .28867 L p 0 0 1 r
F P
0 g
s
.48138 .29466 m .4894 .28529 L .50153 .29148 L p 0 0 1 r
F P
0 g
s
.4894 .28529 m .48138 .29466 L .46922 .28848 L p 0 0 1 r
F P
0 g
s
.53377 .29447 m .54198 .2851 L .55399 .2913 L p 0 0 1 r
F P
0 g
s
.58617 .29429 m .59457 .28492 L .60645 .29111 L p 0 0 1 r
F P
0 g
s
.59457 .28492 m .58617 .29429 L .57425 .28811 L p 0 0 1 r
F P
0 g
s
.63857 .29411 m .64717 .28473 L .65892 .29093 L p 0 0 1 r
F P
0 g
s
.64717 .28473 m .63857 .29411 L .62678 .28793 L p 0 0 1 r
F P
0 g
s
.33994 .26586 m .3477 .25281 L .36034 .2563 L p 1 0 0 r
F P
0 g
s
.36809 .2438 m .36034 .2563 L .3477 .25281 L p 1 0 0 r
F P
0 g
s
.69098 .29392 m .69977 .28455 L .7114 .29074 L p 0 0 1 r
F P
0 g
s
.69977 .28455 m .69098 .29392 L .67932 .28774 L p 0 0 1 r
F P
0 g
s
.40496 .34686 m .41261 .34039 L .42491 .34794 L p 0 1 0 r
F P
0 g
s
.41261 .34039 m .40496 .34686 L .39271 .33832 L p 0 1 0 r
F P
0 g
s
.47748 .3457 m .48551 .33334 L .49764 .33535 L p 0 1 0 r
F P
0 g
s
.50567 .32054 m .49764 .33535 L .48551 .33334 L p 0 1 0 r
F P
0 g
s
.28343 .31292 m .29109 .29989 L .30399 .30275 L p 1 0 0 r
F P
0 g
s
.31169 .28948 m .30399 .30275 L .29109 .29989 L p 1 0 0 r
F P
0 g
s
.25538 .33436 m .26288 .3223 L .27583 .32564 L p 1 0 0 r
F P
0 g
s
.28343 .31292 m .27583 .32564 L .26288 .3223 L p 1 0 0 r
F P
0 g
s
.44085 .23415 m .4487 .22633 L .46092 .23492 L p 1 0 0 r
F P
0 g
s
.4487 .22633 m .44085 .23415 L .42861 .22701 L p 1 0 0 r
F P
0 g
s
.23937 .2924 m .24652 .28302 L .25924 .28922 L p 0 0 1 r
F P
0 g
s
.34422 .29203 m .35174 .28265 L .36422 .28885 L p 0 0 1 r
F P
0 g
s
.35174 .28265 m .34422 .29203 L .33171 .28584 L p 0 0 1 r
F P
0 g
s
.39665 .29185 m .40437 .28246 L .41671 .28867 L p 0 0 1 r
F P
0 g
s
.40437 .28246 m .39665 .29185 L .38427 .28566 L p 0 0 1 r
F P
0 g
s
.44909 .29167 m .457 .28227 L .46922 .28848 L p 0 0 1 r
F P
0 g
s
.457 .28227 m .44909 .29167 L .43683 .28547 L p 0 0 1 r
F P
0 g
s
.63549 .49164 m .63812 .4968 L .63919 .50254 L p 1 0 0 r
F P
0 g
s
.61278 .42747 m .60326 .41888 L .59064 .3986 L p 1 0 0 r
F P
0 g
s
.59064 .3986 m .59989 .40536 L .61278 .42747 L p 1 0 0 r
F P
0 g
s
.55399 .2913 m .56229 .2819 L .57425 .28811 L p 0 0 1 r
F P
0 g
s
.56229 .2819 m .55399 .2913 L .54198 .2851 L p 0 0 1 r
F P
0 g
s
.60645 .29111 m .61494 .28172 L .62678 .28793 L p 0 0 1 r
F P
0 g
s
.61494 .28172 m .60645 .29111 L .59457 .28492 L p 0 0 1 r
F P
0 g
s
.65892 .29093 m .6676 .28153 L .67932 .28774 L p 0 0 1 r
F P
0 g
s
.6676 .28153 m .65892 .29093 L .64717 .28473 L p 0 0 1 r
F P
0 g
s
.43717 .35489 m .44503 .34646 L .45729 .35202 L p 0 1 0 r
F P
0 g
s
.44503 .34646 m .43717 .35489 L .42491 .34794 L p 0 1 0 r
F P
0 g
s
.36809 .2438 m .37585 .23165 L .38835 .2362 L p 1 0 0 r
F P
0 g
s
.38835 .2362 m .39611 .22498 L .40851 .23045 L p 1 0 0 r
F P
0 g
s
.39611 .22498 m .38835 .2362 L .37585 .23165 L p 1 0 0 r
F P
0 g
s
.40851 .23045 m .41629 .22041 L .42861 .22701 L p 1 0 0 r
F P
0 g
s
.41629 .22041 m .40851 .23045 L .39611 .22498 L p 1 0 0 r
F P
0 g
s
.48551 .33334 m .49357 .31961 L .50567 .32054 L p 0 1 0 r
F P
0 g
s
.51369 .30418 m .50567 .32054 L .49357 .31961 L p 0 1 0 r
F P
0 g
s
.39271 .33832 m .4003 .33231 L .41261 .34039 L p 0 1 0 r
F P
0 g
s
.4003 .33231 m .39271 .33832 L .38046 .32937 L p 0 1 0 r
F P
0 g
s
.58372 .37133 m .57467 .36612 L .56227 .34873 L p 1 0 0 r
F P
0 g
s
.56227 .34873 m .57111 .35234 L .58372 .37133 L p 1 0 0 r
F P
0 g
s
.49357 .31961 m .50164 .3044 L .51369 .30418 L p 0 1 0 r
F P
0 g
s
.23506 .34149 m .24241 .33037 L .25538 .33436 L p 1 0 0 r
F P
0 g
s
.26288 .3223 m .25538 .33436 L .24241 .33037 L p 1 0 0 r
F P
0 g
s
.25924 .28922 m .26647 .27981 L .27916 .28603 L p 0 0 1 r
F P
0 g
s
.26647 .27981 m .25924 .28922 L .24652 .28302 L p 0 0 1 r
F P
0 g
s
.21497 .34651 m .22212 .33662 L .23506 .34149 L p 1 0 0 r
F P
0 g
s
.36422 .28885 m .37183 .27944 L .38427 .28566 L p 0 0 1 r
F P
0 g
s
.37183 .27944 m .36422 .28885 L .35174 .28265 L p 0 0 1 r
F P
0 g
s
.41671 .28867 m .42452 .27925 L .43683 .28547 L p 0 0 1 r
F P
0 g
s
.42452 .27925 m .41671 .28867 L .40437 .28246 L p 0 0 1 r
F P
0 g
s
.49335 .25028 m .48527 .25428 L .47311 .24421 L p 1 0 0 r
F P
0 g
s
.63767 .49538 m .63812 .4968 L .63549 .49164 L p 1 0 0 r
F P
0 g
s
.63549 .49164 m .63741 .49399 L .63767 .49538 L p 1 0 0 r
F P
0 g
s
.29109 .29989 m .29879 .28663 L .31169 .28948 L p 1 0 0 r
F P
0 g
s
.46922 .28848 m .47722 .27907 L .4894 .28529 L p 0 0 1 r
F P
0 g
s
.47722 .27907 m .46922 .28848 L .457 .28227 L p 0 0 1 r
F P
0 g
s
.3477 .25281 m .35547 .23996 L .36809 .2438 L p 1 0 0 r
F P
0 g
s
.37585 .23165 m .36809 .2438 L .35547 .23996 L p 1 0 0 r
F P
0 g
s
.57425 .28811 m .58264 .2787 L .59457 .28492 L p 0 0 1 r
F P
0 g
s
.58264 .2787 m .57425 .28811 L .56229 .2819 L p 0 0 1 r
F P
0 g
s
.24241 .33037 m .23506 .34149 L .22212 .33662 L p 1 0 0 r
F P
0 g
s
.62678 .28793 m .63536 .27851 L .64717 .28473 L p 0 0 1 r
F P
0 g
s
.63536 .27851 m .62678 .28793 L .61494 .28172 L p 0 0 1 r
F P
0 g
s
.45729 .35202 m .46526 .34179 L .47748 .3457 L p 0 1 0 r
F P
0 g
s
.48551 .33334 m .47748 .3457 L .46526 .34179 L p 0 1 0 r
F P
0 g
s
.26288 .3223 m .27046 .30978 L .28343 .31292 L p 1 0 0 r
F P
0 g
s
.29109 .29989 m .28343 .31292 L .27046 .30978 L p 1 0 0 r
F P
0 g
s
.38046 .32937 m .38796 .32374 L .4003 .33231 L p 0 1 0 r
F P
0 g
s
.38796 .32374 m .38046 .32937 L .36819 .32006 L p 0 1 0 r
F P
0 g
s
.67932 .28774 m .68809 .27832 L .69977 .28455 L p 0 0 1 r
F P
0 g
s
.68809 .27832 m .67932 .28774 L .6676 .28153 L p 0 0 1 r
F P
0 g
s
.42861 .22701 m .43643 .2184 L .4487 .22633 L p 1 0 0 r
F P
0 g
s
.43643 .2184 m .42861 .22701 L .41629 .22041 L p 1 0 0 r
F P
0 g
s
.54145 .13552 m .53369 .16322 L .52179 .16917 L p 0 1 0 r
F P
0 g
s
.52179 .16917 m .52972 .14285 L .54145 .13552 L p 0 1 0 r
F P
0 g
s
.53367 .22659 m .52574 .24879 L .51375 .25164 L p 0 1 0 r
F P
0 g
s
.51375 .25164 m .52179 .23075 L .53367 .22659 L p 0 1 0 r
F P
0 g
s
.46526 .34179 m .45729 .35202 L .44503 .34646 L p 0 1 0 r
F P
0 g
s
.47311 .24421 m .48111 .23918 L .49335 .25028 L p 1 0 0 r
F P
0 g
s
.48111 .23918 m .47311 .24421 L .46092 .23492 L p 1 0 0 r
F P
0 g
s
.54251 .30445 m .53398 .30361 L .52176 .28977 L p 1 0 0 r
F P
0 g
s
.52176 .28977 m .53015 .28929 L .54251 .30445 L p 1 0 0 r
F P
0 g
s
.28647 .2766 m .27916 .28603 L .26647 .27981 L p 0 0 1 r
F P
0 g
s
.63172 .47383 m .63377 .47996 L p .61934 .45436 L 1 0 0 r
F P
0 g
s
.63377 .47996 m .63232 .47816 L .61934 .45436 L p 1 0 0 r
F P
0 g
s
.61934 .45436 m .62912 .46476 L p .63172 .47383 L 1 0 0 r
F P
0 g
s
.33171 .28584 m .33921 .27641 L .35174 .28265 L p 0 0 1 r
F P
0 g
s
.38427 .28566 m .39196 .27622 L .40437 .28246 L p 0 0 1 r
F P
0 g
s
.39196 .27622 m .38427 .28566 L .37183 .27944 L p 0 0 1 r
F P
0 g
s
.42491 .34794 m .43271 .34018 L .44503 .34646 L p 0 1 0 r
F P
0 g
s
.43271 .34018 m .42491 .34794 L .41261 .34039 L p 0 1 0 r
F P
0 g
s
.43683 .28547 m .44472 .27604 L .457 .28227 L p 0 0 1 r
F P
0 g
s
.44472 .27604 m .43683 .28547 L .42452 .27925 L p 0 0 1 r
F P
0 g
s
.36819 .32006 m .37562 .31476 L .38796 .32374 L p 0 1 0 r
F P
0 g
s
.37562 .31476 m .36819 .32006 L .35592 .31047 L p 0 1 0 r
F P
0 g
s
.49748 .27585 m .4894 .28529 L .47722 .27907 L p 0 0 1 r
F P
0 g
s
.54198 .2851 m .55026 .27567 L .56229 .2819 L p 0 0 1 r
F P
0 g
s
.55026 .27567 m .54198 .2851 L .52992 .27888 L p 0 0 1 r
F P
0 g
s
.59457 .28492 m .60304 .27548 L .61494 .28172 L p 0 0 1 r
F P
0 g
s
.60304 .27548 m .59457 .28492 L .58264 .2787 L p 0 0 1 r
F P
0 g
s
.53761 .18307 m .52975 .20792 L .51779 .21228 L p 0 1 0 r
F P
0 g
s
.51779 .21228 m .52579 .18879 L .53761 .18307 L p 0 1 0 r
F P
0 g
s
.64717 .28473 m .65583 .27529 L .6676 .28153 L p 0 0 1 r
F P
0 g
s
.65583 .27529 m .64717 .28473 L .63536 .27851 L p 0 0 1 r
F P
0 g
s
.46092 .23492 m .46887 .22891 L .48111 .23918 L p 1 0 0 r
F P
0 g
s
.46887 .22891 m .46092 .23492 L .4487 .22633 L p 1 0 0 r
F P
0 g
s
.35547 .23996 m .3477 .25281 L .33495 .24947 L p 1 0 0 r
F P
0 g
s
.24241 .33037 m .24986 .31865 L .26288 .3223 L p 1 0 0 r
F P
0 g
s
.27046 .30978 m .26288 .3223 L .24986 .31865 L p 1 0 0 r
F P
0 g
s
.55496 .32084 m .54627 .31859 L .53398 .30361 L p 1 0 0 r
F P
0 g
s
.53398 .30361 m .54251 .30445 L .55496 .32084 L p 1 0 0 r
F P
0 g
s
.35592 .31047 m .36327 .30542 L .37562 .31476 L p 0 1 0 r
F P
0 g
s
.36327 .30542 m .35592 .31047 L .34364 .30063 L p 0 1 0 r
F P
0 g
s
.37585 .23165 m .38363 .21991 L .39611 .22498 L p 1 0 0 r
F P
0 g
s
.39611 .22498 m .4039 .21431 L .41629 .22041 L p 1 0 0 r
F P
0 g
s
.4039 .21431 m .39611 .22498 L .38363 .21991 L p 1 0 0 r
F P
0 g
s
.59649 .39187 m .5872 .38495 L .57467 .36612 L p 1 0 0 r
F P
0 g
s
.57467 .36612 m .58372 .37133 L .59649 .39187 L p 1 0 0 r
F P
0 g
s
.24652 .28302 m .25371 .27356 L .26647 .27981 L p 0 0 1 r
F P
0 g
s
.27046 .30978 m .2781 .29688 L .29109 .29989 L p 1 0 0 r
F P
0 g
s
.29879 .28663 m .29109 .29989 L .2781 .29688 L p 1 0 0 r
F P
0 g
s
.35174 .28265 m .35933 .27319 L .37183 .27944 L p 0 0 1 r
F P
0 g
s
.35933 .27319 m .35174 .28265 L .33921 .27641 L p 0 0 1 r
F P
0 g
s
.40437 .28246 m .41214 .273 L .42452 .27925 L p 0 0 1 r
F P
0 g
s
.41214 .273 m .40437 .28246 L .39196 .27622 L p 0 0 1 r
F P
0 g
s
.457 .28227 m .46497 .27282 L .47722 .27907 L p 0 0 1 r
F P
0 g
s
.46497 .27282 m .457 .28227 L .44472 .27604 L p 0 0 1 r
F P
0 g
s
.35547 .23996 m .36325 .2274 L .37585 .23165 L p 1 0 0 r
F P
0 g
s
.38363 .21991 m .37585 .23165 L .36325 .2274 L p 1 0 0 r
F P
0 g
s
.46526 .34179 m .47328 .33039 L .48551 .33334 L p 0 1 0 r
F P
0 g
s
.49357 .31961 m .48551 .33334 L .47328 .33039 L p 0 1 0 r
F P
0 g
s
.56229 .2819 m .57064 .27244 L .58264 .2787 L p 0 0 1 r
F P
0 g
s
.57064 .27244 m .56229 .2819 L .55026 .27567 L p 0 0 1 r
F P
0 g
s
.41629 .22041 m .4241 .21107 L .43643 .2184 L p 1 0 0 r
F P
0 g
s
.4241 .21107 m .41629 .22041 L .4039 .21431 L p 1 0 0 r
F P
0 g
s
.61494 .28172 m .62349 .27226 L .63536 .27851 L p 0 0 1 r
F P
0 g
s
.62349 .27226 m .61494 .28172 L .60304 .27548 L p 0 0 1 r
F P
0 g
s
.34364 .30063 m .35091 .29577 L .36327 .30542 L p 0 1 0 r
F P
0 g
s
.35091 .29577 m .34364 .30063 L .33136 .29062 L p 0 1 0 r
F P
0 g
s
.6676 .28153 m .67635 .27207 L .68809 .27832 L p 0 0 1 r
F P
0 g
s
.67635 .27207 m .6676 .28153 L .65583 .27529 L p 0 0 1 r
F P
0 g
s
.4487 .22633 m .45661 .21941 L .46887 .22891 L p 1 0 0 r
F P
0 g
s
.45661 .21941 m .4487 .22633 L .43643 .2184 L p 1 0 0 r
F P
0 g
s
.41261 .34039 m .42036 .33324 L .43271 .34018 L p 0 1 0 r
F P
0 g
s
.42036 .33324 m .41261 .34039 L .4003 .33231 L p 0 1 0 r
F P
0 g
s
.62589 .45144 m .61608 .44089 L .60326 .41888 L p 1 0 0 r
F P
0 g
s
.60326 .41888 m .61278 .42747 L .62589 .45144 L p 1 0 0 r
F P
0 g
s
.22212 .33662 m .2294 .32597 L .24241 .33037 L p 1 0 0 r
F P
0 g
s
.24986 .31865 m .24241 .33037 L .2294 .32597 L p 1 0 0 r
F P
0 g
s
.44503 .34646 m .45296 .33705 L .46526 .34179 L p 0 1 0 r
F P
0 g
s
.45296 .33705 m .44503 .34646 L .43271 .34018 L p 0 1 0 r
F P
0 g
s
.33136 .29062 m .33855 .28587 L .35091 .29577 L p 0 1 0 r
F P
0 g
s
.33855 .28587 m .33136 .29062 L .31908 .28048 L p 0 1 0 r
F P
0 g
s
.26647 .27981 m .27375 .27033 L .28647 .2766 L p 0 0 1 r
F P
0 g
s
.27375 .27033 m .26647 .27981 L .25371 .27356 L p 0 0 1 r
F P
0 g
s
.37183 .27944 m .37949 .26996 L .39196 .27622 L p 0 0 1 r
F P
0 g
s
.37949 .26996 m .37183 .27944 L .35933 .27319 L p 0 0 1 r
F P
0 g
s
.42452 .27925 m .43238 .26977 L .44472 .27604 L p 0 0 1 r
F P
0 g
s
.43238 .26977 m .42452 .27925 L .41214 .273 L p 0 0 1 r
F P
0 g
s
.33495 .24947 m .34274 .23633 L .35547 .23996 L p 1 0 0 r
F P
0 g
s
.36325 .2274 m .35547 .23996 L .34274 .23633 L p 1 0 0 r
F P
0 g
s
.47722 .27907 m .48527 .26958 L .49748 .27585 L p 0 0 1 r
F P
0 g
s
.48527 .26958 m .47722 .27907 L .46497 .27282 L p 0 0 1 r
F P
0 g
s
.47328 .33039 m .46526 .34179 L .45296 .33705 L p 0 1 0 r
F P
0 g
s
.56751 .33856 m .55864 .3348 L .54627 .31859 L p 1 0 0 r
F P
0 g
s
.54627 .31859 m .55496 .32084 L .56751 .33856 L p 1 0 0 r
F P
0 g
s
.52992 .27888 m .53817 .2694 L .55026 .27567 L p 0 0 1 r
F P
0 g
s
.58264 .2787 m .59108 .26921 L .60304 .27548 L p 0 0 1 r
F P
0 g
s
.59108 .26921 m .58264 .2787 L .57064 .27244 L p 0 0 1 r
F P
0 g
s
.31908 .28048 m .32619 .27578 L .33855 .28587 L p 0 1 0 r
F P
0 g
s
.63536 .27851 m .644 .26902 L .65583 .27529 L p 0 0 1 r
F P
0 g
s
.644 .26902 m .63536 .27851 L .62349 .27226 L p 0 0 1 r
F P
0 g
s
.2781 .29688 m .2858 .28369 L .29879 .28663 L p 1 0 0 r
F P
0 g
s
.47328 .33039 m .48135 .31769 L .49357 .31961 L p 0 1 0 r
F P
0 g
s
.50164 .3044 m .49357 .31961 L .48135 .31769 L p 0 1 0 r
F P
0 g
s
.24986 .31865 m .25741 .30639 L .27046 .30978 L p 1 0 0 r
F P
0 g
s
.2781 .29688 m .27046 .30978 L .25741 .30639 L p 1 0 0 r
F P
0 g
s
.4003 .33231 m .40798 .32569 L .42036 .33324 L p 0 1 0 r
F P
0 g
s
.40798 .32569 m .4003 .33231 L .38796 .32374 L p 0 1 0 r
F P
0 g
s
.43643 .2184 m .44431 .21063 L .45661 .21941 L p 1 0 0 r
F P
0 g
s
.44431 .21063 m .43643 .2184 L .4241 .21107 L p 1 0 0 r
F P
0 g
s
.33921 .27641 m .34677 .26691 L .35933 .27319 L p 0 0 1 r
F P
0 g
s
.34677 .26691 m .33921 .27641 L .32662 .27015 L p 0 0 1 r
F P
0 g
s
.39196 .27622 m .39971 .26672 L .41214 .273 L p 0 0 1 r
F P
0 g
s
.39971 .26672 m .39196 .27622 L .37949 .26996 L p 0 0 1 r
F P
0 g
s
.44472 .27604 m .45266 .26653 L .46497 .27282 L p 0 0 1 r
F P
0 g
s
.45266 .26653 m .44472 .27604 L .43238 .26977 L p 0 0 1 r
F P
0 g
s
.63232 .47816 m .63434 .48212 L .63554 .48826 L p 1 0 0 r
F P
0 g
s
.48135 .31769 m .48945 .30359 L .50164 .3044 L p 0 1 0 r
F P
0 g
s
.5097 .2876 m .50164 .3044 L .48945 .30359 L p 0 1 0 r
F P
0 g
s
.55026 .27567 m .55859 .26616 L .57064 .27244 L p 0 0 1 r
F P
0 g
s
.55859 .26616 m .55026 .27567 L .53817 .2694 L p 0 0 1 r
F P
0 g
s
.60304 .27548 m .61157 .26597 L .62349 .27226 L p 0 0 1 r
F P
0 g
s
.61157 .26597 m .60304 .27548 L .59108 .26921 L p 0 0 1 r
F P
0 g
s
.36325 .2274 m .37104 .21519 L .38363 .21991 L p 1 0 0 r
F P
0 g
s
.38363 .21991 m .39142 .20867 L .4039 .21431 L p 1 0 0 r
F P
0 g
s
.39142 .20867 m .38363 .21991 L .37104 .21519 L p 1 0 0 r
F P
0 g
s
.48945 .30359 m .49756 .28795 L .5097 .2876 L p 0 1 0 r
F P
0 g
s
.65583 .27529 m .66455 .26578 L .67635 .27207 L p 0 0 1 r
F P
0 g
s
.66455 .26578 m .65583 .27529 L .644 .26902 L p 0 0 1 r
F P
0 g
s
.4039 .21431 m .41171 .20428 L .4241 .21107 L p 1 0 0 r
F P
0 g
s
.41171 .20428 m .4039 .21431 L .39142 .20867 L p 1 0 0 r
F P
0 g
s
.52975 .20792 m .52179 .23075 L .50971 .23378 L p 0 1 0 r
F P
0 g
s
.50971 .23378 m .51779 .21228 L .52975 .20792 L p 0 1 0 r
F P
0 g
s
.43271 .34018 m .44061 .33152 L .45296 .33705 L p 0 1 0 r
F P
0 g
s
.44061 .33152 m .43271 .34018 L .42036 .33324 L p 0 1 0 r
F P
0 g
s
.2294 .32597 m .23679 .31464 L .24986 .31865 L p 1 0 0 r
F P
0 g
s
.25741 .30639 m .24986 .31865 L .23679 .31464 L p 1 0 0 r
F P
0 g
s
.60945 .41412 m .59989 .40536 L .5872 .38495 L p 1 0 0 r
F P
0 g
s
.5872 .38495 m .59649 .39187 L .60945 .41412 L p 1 0 0 r
F P
0 g
s
.38796 .32374 m .39557 .3176 L .40798 .32569 L p 0 1 0 r
F P
0 g
s
.39557 .3176 m .38796 .32374 L .37562 .31476 L p 0 1 0 r
F P
0 g
s
.53369 .16322 m .52579 .18879 L .51375 .19336 L p 0 1 0 r
F P
0 g
s
.51375 .19336 m .52179 .16917 L .53369 .16322 L p 0 1 0 r
F P
0 g
s
.25371 .27356 m .26096 .26404 L .27375 .27033 L p 0 0 1 r
F P
0 g
s
.34274 .23633 m .35054 .2234 L .36325 .2274 L p 1 0 0 r
F P
0 g
s
.37104 .21519 m .36325 .2274 L .35054 .2234 L p 1 0 0 r
F P
0 g
s
.35933 .27319 m .36697 .26366 L .37949 .26996 L p 0 0 1 r
F P
0 g
s
.36697 .26366 m .35933 .27319 L .34677 .26691 L p 0 0 1 r
F P
0 g
s
.5802 .35772 m .57111 .35234 L .55864 .3348 L p 1 0 0 r
F P
0 g
s
.55864 .3348 m .56751 .33856 L .5802 .35772 L p 1 0 0 r
F P
0 g
s
.41214 .273 m .41998 .26347 L .43238 .26977 L p 0 0 1 r
F P
0 g
s
.41998 .26347 m .41214 .273 L .39971 .26672 L p 0 0 1 r
F P
0 g
s
.46497 .27282 m .473 .26329 L .48527 .26958 L p 0 0 1 r
F P
0 g
s
.473 .26329 m .46497 .27282 L .45266 .26653 L p 0 0 1 r
F P
0 g
s
.25741 .30639 m .26502 .29369 L .2781 .29688 L p 1 0 0 r
F P
0 g
s
.2858 .28369 m .2781 .29688 L .26502 .29369 L p 1 0 0 r
F P
0 g
s
.57064 .27244 m .57906 .26291 L .59108 .26921 L p 0 0 1 r
F P
0 g
s
.57906 .26291 m .57064 .27244 L .55859 .26616 L p 0 0 1 r
F P
0 g
s
.62349 .27226 m .63211 .26272 L .644 .26902 L p 0 0 1 r
F P
0 g
s
.63211 .26272 m .62349 .27226 L .61157 .26597 L p 0 0 1 r
F P
0 g
s
.52179 .23075 m .51375 .25164 L .5064 .25269 L p 0 1 0 r
F P
0 g
s
.49335 .25028 m .50154 .2475 L .50597 .25223 L p 1 0 0 r
F P
0 g
s
.50597 .25223 m .5064 .25269 L p .50608 .25263 L 1 0 0 r
F P
0 g
s
.49335 .25028 m .50597 .25223 L .50608 .25263 L 1 0 0 r
F
.50971 .23378 m .52179 .23075 L p .50519 .24934 L 0 1 0 r
F P
0 g
s
.5064 .25269 m .51375 .25164 L p .50811 .25706 L 0 1 0 r
F P
0 g
s
.50763 .25752 m .5064 .25269 L .50811 .25706 L 0 1 0 r
F
.53431 .2535 m .52603 .2631 L .51382 .25677 L p 0 0 1 r
F P
0 g
s
.50763 .25752 m .5064 .25269 L .50747 .25566 L 1 0 0 r
F
.50799 .2577 m .50681 .25313 L .5089 .25755 L 0 0 1 r
F
.50799 .2577 m .50747 .25566 L .50825 .25783 L 1 0 0 r
F
.50763 .25752 m .50747 .25566 L .50799 .2577 L F
.49335 .25028 m .5064 .25269 L .50763 .25752 L F
.49339 .26003 m .50623 .25343 L .50733 .2578 L 0 0 1 r
F
.50605 .25274 m .5064 .25269 L p .50613 .25306 L 0 1 0 r
F P
0 g
s
.5064 .25269 m .50597 .25223 L p .50565 .25111 L 1 0 0 r
F P
0 g
s
.50597 .25223 m .50154 .2475 L p .50494 .24962 L 1 0 0 r
F P
0 g
s
.49339 .26003 m .50156 .25041 L .50537 .25238 L p 0 0 1 r
F P
0 g
s
.50537 .25238 m .50605 .25274 L p .50555 .25302 L 0 0 1 r
F P
0 g
s
.49339 .26003 m .50537 .25238 L .50555 .25302 L 0 0 1 r
F
.50494 .24962 m .50519 .24934 L .5064 .25269 L 0 1 0 r
F
.50494 .24962 m .50525 .24982 L .50597 .25223 L 1 0 0 r
F
.50519 .24934 m .52179 .23075 L .5066 .25239 L 0 1 0 r
F
.50538 .24987 m .5066 .25239 L .5064 .25269 L F
.50519 .24934 m .5066 .25239 L .50538 .24987 L F
.50154 .2475 m .48922 .23528 L p .50138 .24162 L 1 0 0 r
F P
0 g
s
.50515 .24938 m .50443 .24651 L .50519 .24934 L 0 1 0 r
F
.50494 .24962 m .50472 .24831 L .50515 .24938 L F
.50472 .24831 m .50443 .24651 L .50515 .24938 L F
.50154 .2475 m .49335 .25028 L .48111 .23918 L p 1 0 0 r
F P
0 g
s
.48111 .23918 m .48922 .23528 L .50154 .2475 L p 1 0 0 r
F P
0 g
s
.50156 .25041 m .48924 .24402 L p .50133 .24207 L 0 0 1 r
F P
0 g
s
.50251 .24396 m .50165 .24176 L .50402 .24706 L 1 0 0 r
F
.50138 .24162 m .50165 .24176 L .50251 .24396 L F
.50971 .23378 m .50422 .24703 L p .50165 .24176 L 0 1 0 r
F P
0 g
s
.50165 .24176 m .50203 .24196 L .50317 .24487 L 1 0 0 r
F
.50165 .24176 m .50317 .24487 L .50402 .24706 L F
.50156 .25041 m .49339 .26003 L .48109 .25369 L p 0 0 1 r
F P
0 g
s
.48109 .25369 m .48924 .24402 L .50156 .25041 L p 0 0 1 r
F P
0 g
s
.50159 .25337 m .48926 .25402 L p .50133 .24207 L 0 1 0 r
F P
0 g
s
.50402 .24706 m .50154 .2475 L p .50138 .24162 L 1 0 0 r
F P
0 g
s
.50133 .24207 m .50165 .24176 L .50164 .2427 L 0 1 0 r
F
.50133 .24207 m .50195 .24334 L .5019 .24422 L 0 0 1 r
F
.50525 .24982 m .52209 .24712 L .50654 .25256 L F
.5064 .25269 m .50605 .25274 L p .50637 .25262 L 0 1 0 r
F P
0 g
s
.50605 .25274 m .50494 .24962 L .50637 .25262 L 0 1 0 r
F
.50565 .25111 m .50531 .24995 L .5064 .25269 L 1 0 0 r
F
.50531 .24995 m .50528 .24984 L .50538 .25009 L F
.50531 .24995 m .50538 .25009 L .5064 .25269 L F
.52209 .24712 m .51382 .25677 L .50681 .25313 L p 0 0 1 r
F P
0 g
s
.50681 .25313 m .5064 .25269 L p .50667 .25282 L 1 0 0 r
F P
0 g
s
.50681 .25313 m .51382 .25677 L p .5089 .25755 L 0 0 1 r
F P
0 g
s
.5064 .25269 m .51388 .26068 L p .50825 .25783 L 1 0 0 r
F P
0 g
s
.50681 .25313 m .50605 .25274 L p .50654 .25256 L 0 0 1 r
F P
0 g
s
.50654 .25256 m .52209 .24712 L .50681 .25313 L 0 0 1 r
F
.51382 .25677 m .52209 .24712 L .53431 .2535 L p F P
0 g
s
.50494 .24962 m .50447 .24698 L .50525 .24982 L 1 0 0 r
F
.50154 .2475 m .50422 .24703 L p .50494 .24962 L F P
0 g
s
.50456 .24826 m .50443 .24651 L .50494 .24962 L 0 1 0 r
F
.50422 .24703 m .50447 .24698 L p .50494 .24962 L 1 0 0 r
F P
0 g
s
.50459 .24876 m .50456 .24826 L .50494 .24962 L 0 1 0 r
F
.5098 .24071 m .52209 .24712 L p .5058 .24973 L 0 0 1 r
F P
0 g
s
.50551 .24912 m .5098 .24071 L .5058 .24973 L 0 0 1 r
F
.50401 .24752 m .50443 .24651 L p .50468 .24991 L 0 1 0 r
F P
0 g
s
.50443 .24651 m .50971 .23378 L p .50519 .24934 L 0 1 0 r
F P
0 g
s
.50401 .24752 m .5098 .24071 L p .50515 .24983 L 0 0 1 r
F P
0 g
s
.5098 .24071 m .50447 .24698 L p .50203 .24196 L 0 0 1 r
F P
0 g
s
.50986 .24604 m .50447 .24698 L p .50227 .24208 L 1 0 0 r
F P
0 g
s
.50447 .24698 m .50422 .24703 L p .50303 .24403 L 1 0 0 r
F P
0 g
s
.50227 .24208 m .50447 .24698 L .50303 .24403 L 1 0 0 r
F
.50515 .24983 m .50551 .24912 L .5058 .24973 L 0 0 1 r
F
.50468 .24991 m .50494 .24962 L .50605 .25274 L 0 1 0 r
F
.50468 .24991 m .50459 .24876 L .50494 .24962 L F
.50156 .25041 m .50401 .24752 L p .50515 .24983 L 0 0 1 r
F P
0 g
s
.50203 .24196 m .50273 .24341 L .50402 .24706 L 1 0 0 r
F
.50422 .24703 m .50402 .24706 L p .50227 .24208 L F P
0 g
s
.50422 .24703 m .50401 .24752 L p .50165 .24176 L 0 1 0 r
F P
0 g
s
.50164 .24322 m .5019 .24422 L .50161 .24962 L 0 0 1 r
F
.50164 .24322 m .50161 .24962 L .50156 .25041 L F
.50133 .24207 m .50164 .24322 L .50156 .25041 L F
.50165 .24176 m .50401 .24752 L .50164 .2427 L 0 1 0 r
F
.50447 .24698 m .50156 .25041 L p .50203 .24196 L 0 0 1 r
F P
0 g
s
.50605 .25274 m .50156 .25041 L p .50468 .24991 L 0 0 1 r
F P
0 g
s
.50401 .24752 m .50159 .25337 L p .50164 .2427 L 0 1 0 r
F P
0 g
s
.50986 .24604 m .52233 .2605 L p .50525 .24982 L 1 0 0 r
F P
0 g
s
.50447 .24698 m .50986 .24604 L p .50525 .24982 L 1 0 0 r
F P
0 g
s
.50133 .24207 m .50164 .2427 L .50159 .25337 L 0 1 0 r
F
.50133 .24207 m .50203 .24196 L .50195 .24334 L 0 0 1 r
F
.50563 .2155 m .51779 .21228 L p .49928 .23359 L 0 1 0 r
F P
0 g
s
.48922 .23528 m .49744 .23264 L .49969 .23507 L p 1 0 0 r
F P
0 g
s
.48922 .23528 m .49969 .23507 L .49976 .23531 L 1 0 0 r
F
.48922 .23528 m .49991 .23531 L .50165 .24176 L F
.48924 .24402 m .49745 .23427 L .49923 .2352 L p 0 0 1 r
F P
0 g
s
.49991 .23531 m .50971 .23378 L p .50226 .24115 L 0 1 0 r
F P
0 g
s
.50165 .24176 m .49991 .23531 L .50226 .24115 L 0 1 0 r
F
.50036 .23579 m .5098 .24071 L p .50322 .24177 L 0 0 1 r
F P
0 g
s
.50203 .24196 m .50036 .23579 L .50322 .24177 L 0 0 1 r
F
.51834 .24604 m .50986 .24604 L .50036 .23579 L p 1 0 0 r
F P
0 g
s
.50036 .23579 m .49991 .23531 L p .50021 .23548 L 1 0 0 r
F P
0 g
s
.49744 .23264 m .48504 .2202 L p .49539 .22576 L 1 0 0 r
F P
0 g
s
.51779 .21228 m .50971 .23378 L .50007 .23528 L p 0 1 0 r
F P
0 g
s
.50002 .23517 m .51779 .21228 L .50007 .23528 L 0 1 0 r
F
.49915 .23374 m .51779 .21228 L .49991 .23531 L F
.49926 .23362 m .49888 .23217 L .49928 .23359 L F
.49915 .23374 m .49904 .23308 L .49926 .23362 L F
.49904 .23308 m .49888 .23217 L .49926 .23362 L F
.49591 .22682 m .49551 .22583 L .49868 .23245 L 1 0 0 r
F
.49539 .22576 m .49551 .22583 L .49591 .22682 L F
.49328 .2176 m .50563 .2155 L p .49625 .22506 L 0 1 0 r
F P
0 g
s
.49347 .21828 m .49328 .2176 L .49625 .22506 L 0 1 0 r
F
.49323 .21772 m .49328 .2176 L p .49349 .21838 L F P
0 g
s
.49323 .21772 m .49349 .21838 L .49551 .22583 L 0 1 0 r
F
.49551 .22583 m .49347 .21828 L .49625 .22506 L F
.50563 .2155 m .49877 .23243 L p .49551 .22583 L F P
0 g
s
.49888 .23217 m .50563 .2155 L p .49928 .23359 L 0 1 0 r
F P
0 g
s
.49336 .21822 m .49323 .21772 L .49341 .21821 L 1 0 0 r
F
.48504 .2202 m .49322 .21773 L p .49336 .21822 L F P
0 g
s
.49322 .21773 m .49323 .21772 L p .49336 .21822 L 1 0 0 r
F P
0 g
s
.48504 .2202 m .49369 .21815 L .49591 .22604 L 1 0 0 r
F
.48504 .2202 m .47264 .20867 L p .49224 .21725 L F P
0 g
s
.49224 .21725 m .4932 .21767 L .4925 .21789 L 1 0 0 r
F
.49224 .21725 m .4925 .21789 L .48504 .2202 L F
.4932 .21767 m .4932 .21768 L .48504 .2202 L F
.49323 .21772 m .48504 .2202 L p .4932 .21768 L F P
0 g
s
.48922 .23528 m .48111 .23918 L .46887 .22891 L p 1 0 0 r
F P
0 g
s
.46887 .22891 m .47691 .22397 L .48922 .23528 L p 1 0 0 r
F P
0 g
s
.49744 .23264 m .48922 .23528 L .47691 .22397 L p 1 0 0 r
F P
0 g
s
.47691 .22397 m .48504 .2202 L .49744 .23264 L p 1 0 0 r
F P
0 g
s
.49745 .23427 m .48924 .24402 L .47685 .23759 L p 0 0 1 r
F P
0 g
s
.47685 .23759 m .48504 .2278 L .49745 .23427 L p 0 0 1 r
F P
0 g
s
.49745 .23427 m .48504 .2278 L p .49518 .22616 L 0 0 1 r
F P
0 g
s
.49746 .23569 m .48504 .23651 L p .49518 .22616 L 0 1 0 r
F P
0 g
s
.49518 .22616 m .49551 .22583 L .49583 .22747 L 0 1 0 r
F
.49868 .23245 m .49744 .23264 L p .49539 .22576 L 1 0 0 r
F P
0 g
s
.49969 .23507 m .49744 .23264 L p .49915 .23374 L 1 0 0 r
F P
0 g
s
.49915 .23374 m .49903 .23239 L .49948 .23395 L 1 0 0 r
F
.49744 .23264 m .49877 .23243 L p .49915 .23374 L F P
0 g
s
.49888 .2328 m .49888 .23217 L .49915 .23374 L 0 1 0 r
F
.49877 .23243 m .49903 .23239 L p .49915 .23374 L 1 0 0 r
F P
0 g
s
.49888 .23307 m .49888 .2328 L .49915 .23374 L 0 1 0 r
F
.50572 .22446 m .51809 .23094 L p .49977 .2339 L 0 0 1 r
F P
0 g
s
.49889 .23404 m .49888 .23307 L .49915 .23374 L 0 1 0 r
F
.49932 .23385 m .49948 .23395 L .49991 .23531 L 1 0 0 r
F
.51809 .23094 m .5098 .24071 L .50036 .23579 L p 0 0 1 r
F P
0 g
s
.50007 .23528 m .49991 .23531 L p .50002 .23517 L 0 1 0 r
F P
0 g
s
.49948 .23395 m .50021 .23548 L .49991 .23531 L 1 0 0 r
F
.49991 .23531 m .49969 .23507 L p .49952 .2345 L F P
0 g
s
.49969 .23507 m .49991 .23531 L p .49976 .23531 L 1 0 0 r
F P
0 g
s
.49991 .23531 m .49954 .23536 L p .49915 .23374 L 0 1 0 r
F P
0 g
s
.49954 .23536 m .49745 .23427 L p .49889 .23404 L 0 0 1 r
F P
0 g
s
.49991 .23531 m .50036 .23579 L p .50165 .24176 L 1 0 0 r
F P
0 g
s
.49923 .2352 m .49954 .23536 L p .50124 .24209 L 0 0 1 r
F P
0 g
s
.50165 .24176 m .50041 .23863 L .49991 .23531 L 0 1 0 r
F
.49954 .23536 m .49991 .23531 L p .50041 .23863 L F P
0 g
s
.50133 .24207 m .50041 .23863 L .50165 .24176 L 0 1 0 r
F
.49954 .23536 m .50036 .23579 L p .50114 .24135 L 0 0 1 r
F P
0 g
s
.50124 .24209 m .49954 .23536 L .50114 .24135 L 0 0 1 r
F
.49915 .23542 m .49954 .23536 L p .50041 .23863 L 0 1 0 r
F P
0 g
s
.48924 .24402 m .49923 .2352 L .50124 .24209 L 0 0 1 r
F
.49954 .23536 m .49746 .23569 L p .49889 .23404 L 0 1 0 r
F P
0 g
s
.49889 .23404 m .49915 .23374 L .49954 .23536 L 0 1 0 r
F
.49952 .2345 m .49932 .23385 L .49991 .23531 L 1 0 0 r
F
.50036 .23579 m .49954 .23536 L p .49948 .23395 L 0 0 1 r
F P
0 g
s
.49915 .23374 m .49932 .23385 L .49969 .23507 L 1 0 0 r
F
.49889 .23404 m .49948 .23395 L .49954 .23536 L 0 0 1 r
F
.49948 .23395 m .51809 .23094 L .50036 .23579 L F
.53041 .2374 m .52209 .24712 L .5098 .24071 L p F P
0 g
s
.5098 .24071 m .51809 .23094 L .53041 .2374 L p 0 0 1 r
F P
0 g
s
.49948 .23395 m .51834 .24604 L .50021 .23548 L 1 0 0 r
F
.49948 .23395 m .49924 .23281 L .49977 .2339 L 0 0 1 r
F
.49819 .23415 m .49905 .23305 L .49948 .23395 L F
.49905 .23305 m .49924 .23281 L .49948 .23395 L F
.49924 .23281 m .50572 .22446 L .49977 .2339 L F
.49903 .23239 m .49877 .23243 L p .49748 .22924 L 1 0 0 r
F P
0 g
s
.49857 .23294 m .49745 .23427 L p .49518 .22616 L 0 0 1 r
F P
0 g
s
.49551 .22583 m .4983 .23147 L .49868 .23245 L 1 0 0 r
F
.49877 .23243 m .49857 .23294 L p .49551 .22583 L 0 1 0 r
F P
0 g
s
.49551 .22583 m .49857 .23294 L .49583 .22747 L 0 1 0 r
F
.49591 .22604 m .49716 .22584 L .49807 .23043 L 0 0 1 r
F
.49551 .22583 m .49591 .22604 L .4983 .23147 L 1 0 0 r
F
.49591 .22604 m .49627 .22623 L .49725 .22876 L F
.49591 .22604 m .49725 .22876 L .4983 .23147 L F
.49877 .23243 m .49868 .23245 L p .49725 .22876 L F P
0 g
s
.49903 .23239 m .49857 .23294 L p .49807 .23043 L 0 0 1 r
F P
0 g
s
.49716 .22584 m .49903 .23239 L .49807 .23043 L 0 0 1 r
F
.49518 .22616 m .49591 .22604 L .49857 .23294 L F
.49748 .22924 m .49877 .23243 L .49725 .22876 L 1 0 0 r
F
.49591 .22604 m .49807 .23043 L .49857 .23294 L 0 0 1 r
F
.49627 .22623 m .49748 .22924 L .49725 .22876 L 1 0 0 r
F
.49745 .23427 m .49745 .23427 L p .49518 .22616 L 0 0 1 r
F P
0 g
s
.49745 .23427 m .49803 .23358 L p .49819 .23415 L 0 0 1 r
F P
0 g
s
.49857 .23294 m .49746 .23569 L p .49583 .22747 L 0 1 0 r
F P
0 g
s
.50572 .22446 m .49903 .23239 L p .49716 .22584 L 0 0 1 r
F P
0 g
s
.49857 .23294 m .49888 .23217 L p .49889 .23404 L 0 1 0 r
F P
0 g
s
.49803 .23358 m .50572 .22446 L p .49819 .23415 L 0 0 1 r
F P
0 g
s
.50579 .23135 m .49903 .23239 L p .49627 .22623 L 1 0 0 r
F P
0 g
s
.49627 .22623 m .49903 .23239 L .49748 .22924 L 1 0 0 r
F
.50579 .23135 m .51834 .24604 L p .49948 .23395 L F P
0 g
s
.49903 .23239 m .50579 .23135 L p .49948 .23395 L 1 0 0 r
F P
0 g
s
.49518 .22616 m .49583 .22747 L .49746 .23569 L 0 1 0 r
F
.49518 .22616 m .49413 .22243 L .49551 .22583 L F
.49413 .22243 m .49323 .21772 L .49551 .22583 L F
.48504 .2278 m .49297 .21831 L p .49518 .22616 L 0 0 1 r
F P
0 g
s
.49271 .21891 m .49297 .21831 L p .49413 .22243 L 0 1 0 r
F P
0 g
s
.49297 .21831 m .49323 .21772 L p .49413 .22243 L 0 1 0 r
F P
0 g
s
.49518 .22616 m .49297 .21831 L .49682 .2259 L 0 0 1 r
F
.49369 .21815 m .50572 .22446 L p .4974 .2258 L F P
0 g
s
.5143 .23155 m .50579 .23135 L .49369 .21815 L p 1 0 0 r
F P
0 g
s
.49369 .21815 m .49328 .21771 L p .49356 .21789 L 1 0 0 r
F P
0 g
s
.49328 .21771 m .49369 .21815 L p .49341 .21821 L 1 0 0 r
F P
0 g
s
.51405 .21457 m .50572 .22446 L .49375 .21818 L p 0 0 1 r
F P
0 g
s
.49375 .21818 m .49328 .21794 L p .4936 .21789 L 0 0 1 r
F P
0 g
s
.4936 .21789 m .51405 .21457 L .49375 .21818 L 0 0 1 r
F
.49319 .21761 m .49328 .2176 L p .49321 .21767 L 0 1 0 r
F P
0 g
s
.49328 .21771 m .49319 .21762 L p .49345 .21759 L 1 0 0 r
F P
0 g
s
.52579 .18879 m .51779 .21228 L .50563 .2155 L p 0 1 0 r
F P
0 g
s
.50563 .2155 m .51375 .19336 L .52579 .18879 L p 0 1 0 r
F P
0 g
s
.51375 .19336 m .50563 .2155 L .49328 .2176 L p 0 1 0 r
F P
0 g
s
.50159 .208 m .51405 .21457 L p .4936 .21789 L 0 0 1 r
F P
0 g
s
.49328 .21794 m .4935 .21768 L p .4936 .21789 L 0 0 1 r
F P
0 g
s
.4935 .21768 m .50159 .208 L p .4936 .21789 L 0 0 1 r
F P
0 g
s
.49328 .2176 m .5015 .19679 L .51375 .19336 L p 0 1 0 r
F P
0 g
s
.5015 .19679 m .49328 .2176 L .49318 .21761 L p 0 1 0 r
F P
0 g
s
.49318 .21761 m .49201 .21641 L p .49115 .21355 L 1 0 0 r
F P
0 g
s
.49201 .21641 m .4808 .20504 L p .48922 .20971 L 1 0 0 r
F P
0 g
s
.48922 .20971 m .5015 .19679 L .49318 .21761 L 0 1 0 r
F
.48922 .20971 m .48964 .20994 L .49201 .21641 L 1 0 0 r
F
.50159 .208 m .4935 .21768 L p .48964 .20994 L 0 0 1 r
F P
0 g
s
.48964 .20994 m .49015 .21023 L .49071 .21208 L 1 0 0 r
F
.48964 .20994 m .49071 .21208 L .49201 .21641 L F
.4932 .21767 m .49321 .21767 L .4932 .21768 L 0 1 0 r
F
.47264 .20867 m .4808 .20504 L .49318 .21761 L p 1 0 0 r
F P
0 g
s
.49319 .21761 m .49318 .21761 L .49319 .21761 L 0 1 0 r
F
.4932 .21767 m .49319 .21761 L .49321 .21767 L F
.49328 .2176 m .49323 .21772 L p .49321 .21767 L F P
0 g
s
.49318 .21761 m .49328 .21771 L p .4932 .21767 L 1 0 0 r
F P
0 g
s
.47264 .20867 m .49318 .21761 L .4932 .21767 L 1 0 0 r
F
.49318 .21761 m .49273 .21765 L p .48922 .20971 L 0 1 0 r
F P
0 g
s
.49115 .21355 m .49016 .21026 L .49318 .21761 L 1 0 0 r
F
.49273 .21765 m .48964 .20994 L .49214 .21543 L 0 0 1 r
F
.49281 .21795 m .49318 .21761 L .49319 .21761 L 0 1 0 r
F
.45631 .2409 m .46441 .23114 L .47685 .23759 L p 0 0 1 r
F P
0 g
s
.48504 .2278 m .47685 .23759 L .46441 .23114 L p 0 0 1 r
F P
0 g
s
.47691 .22397 m .46887 .22891 L .45661 .21941 L p 1 0 0 r
F P
0 g
s
.45661 .21941 m .46458 .21349 L .47691 .22397 L p 1 0 0 r
F P
0 g
s
.48504 .2202 m .47691 .22397 L .46458 .21349 L p 1 0 0 r
F P
0 g
s
.46441 .23114 m .47257 .2213 L .48504 .2278 L p 0 0 1 r
F P
0 g
s
.46458 .21349 m .47264 .20867 L .48504 .2202 L p 1 0 0 r
F P
0 g
s
.48504 .2278 m .47257 .2213 L p .49283 .21801 L 0 0 1 r
F P
0 g
s
.49297 .21831 m .48504 .2278 L p .49283 .21801 L 0 0 1 r
F P
0 g
s
.48504 .23651 m .47248 .23626 L p .49283 .21801 L 0 1 0 r
F P
0 g
s
.49283 .21801 m .4932 .21767 L .49295 .21826 L 0 1 0 r
F
.49283 .21801 m .49295 .21826 L .48504 .23651 L F
.4932 .21768 m .49297 .21831 L .49295 .21826 L F
.49328 .21794 m .49297 .21831 L p .49283 .21801 L 0 0 1 r
F P
0 g
s
.4932 .21767 m .4932 .21768 L .49295 .21826 L 0 1 0 r
F
.49295 .21826 m .49295 .21826 L .48504 .23651 L F
.4932 .21767 m .49295 .21826 L .49295 .21826 L F
.47257 .2213 m .48078 .21138 L .49261 .21758 L p 0 0 1 r
F P
0 g
s
.49281 .21795 m .49318 .21761 L .49281 .21795 L 0 1 0 r
F
.49323 .21772 m .49297 .21831 L p .4932 .21768 L F P
0 g
s
.47257 .2213 m .49261 .21758 L .49283 .21801 L 0 0 1 r
F
.47248 .23626 m .48077 .21861 L .49273 .21765 L p 0 1 0 r
F P
0 g
s
.49273 .21765 m .49318 .21761 L p .49281 .21795 L 0 1 0 r
F P
0 g
s
.49261 .21758 m .49273 .21765 L p .49283 .21801 L 0 0 1 r
F P
0 g
s
.47248 .23626 m .49273 .21765 L .49281 .21795 L 0 1 0 r
F
.49283 .21801 m .49318 .21762 L .4932 .21767 L F
.47248 .23626 m .49281 .21795 L .49283 .21801 L F
.49281 .21795 m .49318 .21762 L .49283 .21801 L F
.4919 .21447 m .49345 .21759 L .49319 .21762 L 1 0 0 r
F
.4935 .21768 m .49328 .21771 L p .49345 .21759 L F P
0 g
s
.49321 .21767 m .49323 .21772 L .4932 .21768 L 0 1 0 r
F
.4932 .21767 m .49321 .21768 L .4932 .21768 L 1 0 0 r
F
.4932 .21767 m .4932 .21768 L .4932 .21768 L F
.49321 .21768 m .49323 .21772 L .4932 .21768 L F
.49318 .21761 m .49319 .21761 L p .49319 .21761 L 0 1 0 r
F P
0 g
s
.49319 .21762 m .49318 .21761 L p .49015 .21023 L 1 0 0 r
F P
0 g
s
.49016 .21026 m .49015 .21023 L .49318 .21761 L 1 0 0 r
F
.49318 .21762 m .49319 .21761 L .4932 .21767 L 0 1 0 r
F
.49323 .21772 m .49328 .21771 L p .49341 .21821 L 1 0 0 r
F P
0 g
s
.49328 .21771 m .49323 .21772 L p .49321 .21768 L 1 0 0 r
F P
0 g
s
.4935 .21768 m .49328 .21794 L p .49214 .21543 L 0 0 1 r
F P
0 g
s
.48964 .20994 m .49187 .21442 L .49214 .21543 L 0 0 1 r
F
.49187 .21442 m .4935 .21768 L .49214 .21543 L F
.49273 .21765 m .49328 .21794 L p .49283 .21801 L F P
0 g
s
.49328 .21794 m .49273 .21765 L p .49214 .21543 L 0 0 1 r
F P
0 g
s
.47248 .23626 m .49281 .21795 L .49281 .21795 L 0 1 0 r
F
.49273 .21765 m .49082 .21664 L p .48888 .21007 L 0 0 1 r
F P
0 g
s
.49082 .21664 m .48078 .21138 L p .48888 .21007 L 0 0 1 r
F P
0 g
s
.48906 .19909 m .5015 .19679 L p .48922 .20971 L 0 1 0 r
F P
0 g
s
.48919 .20958 m .48906 .19909 L .48922 .20971 L 0 1 0 r
F
.48898 .20957 m .48731 .20321 L .48922 .20971 L 1 0 0 r
F
.4808 .20504 m .48716 .20325 L p .48898 .20957 L F P
0 g
s
.48716 .20325 m .48731 .20321 L p .48898 .20957 L 1 0 0 r
F P
0 g
s
.47264 .20867 m .46458 .21349 L .45224 .20379 L p 1 0 0 r
F P
0 g
s
.45224 .20379 m .46024 .19796 L .47264 .20867 L p 1 0 0 r
F P
0 g
s
.4808 .20504 m .47264 .20867 L .46024 .19796 L p 1 0 0 r
F P
0 g
s
.46024 .19796 m .46832 .19326 L .4808 .20504 L p 1 0 0 r
F P
0 g
s
.46458 .21349 m .45661 .21941 L .44431 .21063 L p 1 0 0 r
F P
0 g
s
.48078 .21138 m .47257 .2213 L .46003 .21476 L p 0 0 1 r
F P
0 g
s
.4765 .18979 m .46394 .17777 L p .47956 .18518 L 1 0 0 r
F P
0 g
s
.47956 .18518 m .47978 .1856 L .4765 .18979 L 1 0 0 r
F
.4848 .18014 m .48131 .18855 L p .47956 .18518 L 0 1 0 r
F P
0 g
s
.48131 .18855 m .4765 .18979 L p .47997 .18537 L 1 0 0 r
F P
0 g
s
.4808 .20504 m .46832 .19326 L p .48577 .20121 L 1 0 0 r
F P
0 g
s
.46832 .19326 m .4765 .18979 L .48585 .1994 L p 1 0 0 r
F P
0 g
s
.48605 .19938 m .48906 .19909 L p .48666 .20132 L 0 1 0 r
F P
0 g
s
.48662 .20136 m .4865 .20095 L .48666 .20132 L 0 1 0 r
F
.4865 .20095 m .48605 .19938 L .48666 .20132 L F
.48585 .1994 m .48605 .19938 L p .48589 .19955 L F P
0 g
s
.46832 .19326 m .48585 .1994 L .48645 .20152 L 1 0 0 r
F
.48577 .20121 m .48645 .20152 L .48601 .20179 L F
.48577 .20121 m .48601 .20179 L .4808 .20504 L F
.48716 .20325 m .4808 .20504 L p .48645 .20152 L F P
0 g
s
.44431 .21063 m .45224 .20379 L .46458 .21349 L p 1 0 0 r
F P
0 g
s
.46003 .21476 m .46822 .2048 L .48078 .21138 L p 0 0 1 r
F P
0 g
s
.48605 .20189 m .48605 .19938 L .48662 .20136 L 0 1 0 r
F
.48078 .21138 m .46822 .2048 L p .48605 .20189 L 0 0 1 r
F P
0 g
s
.48551 .19996 m .48605 .19938 L .48605 .20189 L 0 1 0 r
F
.48775 .20621 m .48906 .19909 L .48919 .20974 L F
.48705 .20383 m .48731 .20321 L p .48775 .20621 L F P
0 g
s
.48731 .20321 m .48906 .19909 L p .488 .20486 L 0 1 0 r
F P
0 g
s
.48731 .20321 m .488 .20486 L .48775 .20621 L 0 1 0 r
F
.48907 .2014 m .50159 .208 L p .49015 .20986 L 0 0 1 r
F P
0 g
s
.48964 .20994 m .48891 .20745 L .49015 .20986 L 0 0 1 r
F
.48731 .20321 m .48764 .20311 L p .48922 .20971 L 1 0 0 r
F P
0 g
s
.48891 .20745 m .48764 .20311 L .49015 .20986 L 0 0 1 r
F
.48764 .20311 m .48907 .2014 L p .48984 .20739 L F P
0 g
s
.48764 .20311 m .48984 .20739 L .49015 .20986 L 0 0 1 r
F
.48764 .20311 m .48907 .20271 L p .48919 .20841 L 1 0 0 r
F P
0 g
s
.48764 .20311 m .48919 .20841 L .48922 .20971 L 1 0 0 r
F
.48705 .20383 m .48764 .20311 L p .48891 .20745 L 0 0 1 r
F P
0 g
s
.48906 .19909 m .48731 .20321 L p .48645 .20152 L 0 1 0 r
F P
0 g
s
.48666 .20161 m .48694 .20174 L .48731 .20321 L 1 0 0 r
F
.48764 .20311 m .48731 .20321 L p .48694 .20174 L F P
0 g
s
.48605 .20189 m .48645 .20152 L .48622 .20221 L 0 1 0 r
F
.48645 .20152 m .4869 .2024 L .48716 .20325 L 1 0 0 r
F
.48731 .20321 m .48716 .20325 L p .48666 .20161 L F P
0 g
s
.48731 .20321 m .48705 .20383 L p .48645 .20152 L 0 1 0 r
F P
0 g
s
.48645 .20152 m .48705 .20383 L .48622 .20221 L 0 1 0 r
F
.48645 .20152 m .48666 .20161 L .4869 .2024 L 1 0 0 r
F
.48585 .1994 m .48644 .20001 L p .48645 .20152 L F P
0 g
s
.48907 .2014 m .48741 .20339 L p .48694 .20174 L 0 0 1 r
F P
0 g
s
.48644 .20001 m .48907 .2014 L p .48729 .20169 L 0 0 1 r
F P
0 g
s
.48644 .20001 m .48907 .20271 L p .48694 .20174 L 1 0 0 r
F P
0 g
s
.48645 .20152 m .48644 .20001 L .48694 .20174 L 1 0 0 r
F
.48605 .20189 m .48694 .20174 L .48705 .20383 L 0 0 1 r
F
.48741 .20339 m .48705 .20383 L p .48694 .20174 L F P
0 g
s
.48705 .20383 m .48671 .20424 L p .48605 .20189 L 0 0 1 r
F P
0 g
s
.48888 .21007 m .48775 .20621 L .48919 .20974 L 0 1 0 r
F
.48078 .21138 m .48705 .20383 L p .48891 .20745 L 0 0 1 r
F P
0 g
s
.48922 .20971 m .48919 .20841 L .48964 .20994 L 1 0 0 r
F
.48919 .20962 m .48919 .20958 L .48922 .20971 L 0 1 0 r
F
.48888 .21007 m .48922 .20971 L .49273 .21765 L F
.48919 .20974 m .48919 .20962 L .48922 .20971 L F
.48078 .21138 m .48891 .20745 L .48964 .20994 L 0 0 1 r
F
.48671 .20424 m .48078 .21138 L p .48605 .20189 L F P
0 g
s
.48705 .20383 m .48077 .21861 L p .48622 .20221 L 0 1 0 r
F P
0 g
s
.48907 .20271 m .48764 .20311 L p .48694 .20174 L 1 0 0 r
F P
0 g
s
.48907 .20271 m .50166 .21661 L p .48964 .20994 L 1 0 0 r
F P
0 g
s
.48919 .20841 m .48907 .20271 L .48964 .20994 L 1 0 0 r
F
.48077 .21861 m .46811 .21855 L p .48605 .20189 L 0 1 0 r
F P
0 g
s
.48605 .20189 m .48622 .20221 L .48077 .21861 L 0 1 0 r
F
.48691 .20415 m .48705 .20383 L p .48775 .20621 L F P
0 g
s
.46822 .2048 m .47648 .19476 L .48537 .19945 L p 0 0 1 r
F P
0 g
s
.46822 .2048 m .48537 .19945 L .48559 .20024 L 0 0 1 r
F
.48605 .20189 m .48644 .20001 L .48729 .20169 L F
.46822 .2048 m .48559 .20024 L .48605 .20189 L F
.48559 .20024 m .48644 .20001 L .48605 .20189 L F
.48551 .19996 m .48558 .19943 L .48571 .19974 L 0 1 0 r
F
.46811 .21855 m .48541 .19961 L .48551 .19996 L F
.48541 .19961 m .48558 .19943 L .48551 .19996 L F
.46811 .21855 m .47646 .2003 L .48537 .19945 L p F P
0 g
s
.48537 .19945 m .48558 .19943 L p .48541 .19961 L 0 1 0 r
F P
0 g
s
.46811 .21855 m .48537 .19945 L .48541 .19961 L 0 1 0 r
F
.48537 .19945 m .48644 .20001 L p .48559 .20024 L 0 0 1 r
F P
0 g
s
.50996 .19798 m .50159 .208 L .48907 .2014 L p 0 0 1 r
F P
0 g
s
.52179 .16917 m .51375 .19336 L .5015 .19679 L p 0 1 0 r
F P
0 g
s
.5015 .19679 m .50966 .17396 L .52179 .16917 L p 0 1 0 r
F P
0 g
s
.50966 .17396 m .5015 .19679 L .48906 .19909 L p 0 1 0 r
F P
0 g
s
.48907 .2014 m .49741 .19133 L .50996 .19798 L p 0 0 1 r
F P
0 g
s
.48644 .20001 m .48585 .1994 L p .48617 .19947 L 1 0 0 r
F P
0 g
s
.48906 .19909 m .49732 .17761 L .50966 .17396 L p 0 1 0 r
F P
0 g
s
.4828 .1934 m .48284 .19215 L .48319 .19298 L 0 1 0 r
F
.48496 .19849 m .4765 .18979 L p .4828 .1934 L 1 0 0 r
F P
0 g
s
.49732 .17761 m .48906 .19909 L .48585 .1994 L p 0 1 0 r
F P
0 g
s
.48563 .19897 m .49732 .17761 L .48585 .1994 L 0 1 0 r
F
.48585 .1994 m .48496 .19849 L p .4828 .1934 L 1 0 0 r
F P
0 g
s
.48245 .19378 m .49732 .17761 L .48537 .19945 L 0 1 0 r
F
.49741 .19133 m .48907 .2014 L .48644 .20001 L p 0 0 1 r
F P
0 g
s
.48324 .19365 m .49741 .19133 L .48644 .20001 L 0 0 1 r
F
.4848 .18014 m .49732 .17761 L p .48319 .19298 L 0 1 0 r
F P
0 g
s
.48284 .19215 m .4848 .18014 L .48319 .19298 L 0 1 0 r
F
.47997 .18537 m .48008 .18542 L .48131 .18855 L 1 0 0 r
F
.4848 .18465 m .49741 .19133 L p .48426 .19349 L 0 0 1 r
F P
0 g
s
.48351 .19205 m .4848 .18465 L .48426 .19349 L 0 0 1 r
F
.4765 .18979 m .48131 .18855 L p .4828 .1934 L 1 0 0 r
F P
0 g
s
.4931 .15795 m .4848 .18014 L .47828 .18087 L p 0 1 0 r
F P
0 g
s
.46394 .17777 m .47214 .17447 L .47771 .18027 L p 1 0 0 r
F P
0 g
s
.47771 .18027 m .47828 .18087 L p .47787 .18078 L 1 0 0 r
F P
0 g
s
.46394 .17777 m .47771 .18027 L .47787 .18078 L 1 0 0 r
F
.48049 .16072 m .4931 .15795 L p .47656 .17655 L 0 1 0 r
F P
0 g
s
.47828 .18087 m .4848 .18014 L p .47997 .18478 L 0 1 0 r
F P
0 g
s
.47956 .18518 m .47828 .18087 L .47997 .18478 L 0 1 0 r
F
.48211 .19246 m .4848 .18014 L .4826 .19362 L F
.48187 .19166 m .4848 .18014 L .48211 .19246 L F
.48104 .18921 m .4848 .18014 L p .48184 .1918 L F P
0 g
s
.48165 .18847 m .48215 .18787 L p .48324 .19365 L 0 0 1 r
F P
0 g
s
.48215 .18787 m .4848 .18465 L p .48371 .19093 L 0 0 1 r
F P
0 g
s
.48215 .18787 m .48371 .19093 L .48324 .19365 L 0 0 1 r
F
.4765 .18979 m .46832 .19326 L .45583 .18233 L p 1 0 0 r
F P
0 g
s
.45583 .18233 m .46394 .17777 L .4765 .18979 L p 1 0 0 r
F P
0 g
s
.47648 .19476 m .46383 .18809 L p .47915 .18557 L 0 0 1 r
F P
0 g
s
.47875 .18136 m .47891 .18153 L p .47997 .18537 L 1 0 0 r
F P
0 g
s
.48165 .18847 m .48131 .18855 L p .48008 .18542 L 1 0 0 r
F P
0 g
s
.48131 .18855 m .48104 .18921 L p .47956 .18518 L 0 1 0 r
F P
0 g
s
.47915 .18557 m .48026 .1877 L .48043 .18995 L 0 0 1 r
F
.47956 .18518 m .48104 .18921 L .47938 .18603 L 0 1 0 r
F
.48117 .18906 m .48043 .18995 L p .48008 .18542 L 0 0 1 r
F P
0 g
s
.48043 .18995 m .47648 .19476 L p .47915 .18557 L 0 0 1 r
F P
0 g
s
.47648 .19476 m .48104 .18921 L p .48245 .19378 L 0 0 1 r
F P
0 g
s
.48537 .19945 m .48396 .19871 L p .48245 .19378 L 0 0 1 r
F P
0 g
s
.48396 .19871 m .47648 .19476 L p .48245 .19378 L 0 0 1 r
F P
0 g
s
.47646 .2003 m .4809 .18955 L p .48184 .1918 L 0 1 0 r
F P
0 g
s
.48245 .19378 m .48184 .1918 L .4826 .19362 L 0 1 0 r
F
.47646 .2003 m .48184 .1918 L .48245 .19378 L F
.48104 .18921 m .47646 .2003 L p .47938 .18603 L F P
0 g
s
.46024 .19796 m .45224 .20379 L .43985 .19479 L p 1 0 0 r
F P
0 g
s
.43985 .19479 m .44781 .18803 L .46024 .19796 L p 1 0 0 r
F P
0 g
s
.46832 .19326 m .46024 .19796 L .44781 .18803 L p 1 0 0 r
F P
0 g
s
.47648 .19476 m .46822 .2048 L .4556 .19818 L p 0 0 1 r
F P
0 g
s
.44781 .18803 m .45583 .18233 L .46832 .19326 L p 1 0 0 r
F P
0 g
s
.4556 .19818 m .46383 .18809 L .47648 .19476 L p 0 0 1 r
F P
0 g
s
.47646 .2003 m .4637 .20044 L p .47915 .18557 L 0 1 0 r
F P
0 g
s
.47915 .18557 m .47956 .18518 L .47938 .18603 L 0 1 0 r
F
.47915 .18557 m .47938 .18603 L .47646 .2003 L F
.46394 .17777 m .47828 .18087 L .4784 .18127 L 1 0 0 r
F
.46394 .17777 m .47875 .18136 L .47997 .18537 L F
.46383 .18809 m .47212 .17793 L .47631 .18015 L p 0 0 1 r
F P
0 g
s
.47997 .18537 m .47891 .18153 L .48008 .18542 L 1 0 0 r
F
.47915 .18557 m .47828 .18087 L .47956 .18518 L 0 1 0 r
F
.47791 .18137 m .47828 .18087 L .47915 .18557 L F
.47631 .18015 m .47778 .18093 L p .47915 .18557 L 0 0 1 r
F P
0 g
s
.46383 .18809 m .47631 .18015 L .47915 .18557 L 0 0 1 r
F
.4637 .20044 m .4721 .18157 L .47778 .18093 L p 0 1 0 r
F P
0 g
s
.47778 .18093 m .47828 .18087 L p .47791 .18137 L 0 1 0 r
F P
0 g
s
.4637 .20044 m .47778 .18093 L .47791 .18137 L 0 1 0 r
F
.47956 .18518 m .47997 .18537 L .47978 .1856 L 1 0 0 r
F
.47778 .18093 m .4848 .18465 L p .47915 .18557 L 0 0 1 r
F P
0 g
s
.47915 .18557 m .48008 .18542 L .48026 .1877 L 0 0 1 r
F
.48008 .18542 m .4807 .18532 L .48117 .18906 L F
.4848 .18465 m .48165 .18847 L p .4807 .18532 L F P
0 g
s
.48165 .18847 m .48117 .18906 L p .4807 .18532 L 0 0 1 r
F P
0 g
s
.48131 .18855 m .48165 .18847 L p .4828 .1934 L 1 0 0 r
F P
0 g
s
.48165 .18847 m .4848 .18766 L p .48299 .19285 L 1 0 0 r
F P
0 g
s
.48269 .19305 m .48284 .19215 L .4828 .1934 L 0 1 0 r
F
.48165 .18847 m .48299 .19285 L .4828 .1934 L 1 0 0 r
F
.47891 .18153 m .4848 .18766 L p .48008 .18542 L F P
0 g
s
.4637 .20044 m .47791 .18137 L .47915 .18557 L 0 1 0 r
F
.50582 .18119 m .49741 .19133 L .4848 .18465 L p 0 0 1 r
F P
0 g
s
.51774 .14903 m .50966 .17396 L .49732 .17761 L p 0 1 0 r
F P
0 g
s
.49732 .17761 m .50553 .15406 L .51774 .14903 L p 0 1 0 r
F P
0 g
s
.50553 .15406 m .49732 .17761 L .4848 .18014 L p 0 1 0 r
F P
0 g
s
.4848 .18465 m .49318 .17445 L .50582 .18119 L p 0 0 1 r
F P
0 g
s
.47891 .18153 m .47828 .18087 L p .47866 .18102 L 1 0 0 r
F P
0 g
s
.47828 .18087 m .47771 .18027 L p .47723 .17883 L 1 0 0 r
F P
0 g
s
.47771 .18027 m .47214 .17447 L p .47624 .17691 L 1 0 0 r
F P
0 g
s
.47624 .17691 m .47656 .17655 L .47828 .18087 L 0 1 0 r
F
.47624 .17691 m .47668 .17717 L .47771 .18027 L 1 0 0 r
F
.47828 .18087 m .47778 .18093 L p .47624 .17691 L 0 1 0 r
F P
0 g
s
.47723 .17883 m .47668 .17717 L .47828 .18087 L 1 0 0 r
F
.47668 .17717 m .47669 .17717 L .47828 .18087 L F
.4848 .18014 m .4931 .15795 L .50553 .15406 L p 0 1 0 r
F P
0 g
s
.49318 .17445 m .4848 .18465 L .47891 .18153 L p 0 0 1 r
F P
0 g
s
.47846 .18064 m .49318 .17445 L .47891 .18153 L 0 0 1 r
F
.47656 .17655 m .4931 .15795 L .47852 .18051 L 0 1 0 r
F
.47691 .17744 m .47852 .18051 L .47828 .18087 L F
.47656 .17655 m .47852 .18051 L .47691 .17744 L F
.47214 .17447 m .45949 .16218 L p .47222 .16848 L 1 0 0 r
F P
0 g
s
.47649 .17663 m .47549 .17312 L .47656 .17655 L 0 1 0 r
F
.47624 .17691 m .47594 .17536 L .47649 .17663 L F
.47594 .17536 m .47549 .17312 L .47649 .17663 L F
.47214 .17447 m .46394 .17777 L .45136 .16658 L p 1 0 0 r
F P
0 g
s
.45136 .16658 m .45949 .16218 L .47214 .17447 L p 1 0 0 r
F P
0 g
s
.47212 .17793 m .45938 .17117 L p .47212 .16907 L 0 0 1 r
F P
0 g
s
.47373 .17136 m .47255 .16864 L .47501 .17381 L 1 0 0 r
F
.47222 .16848 m .47255 .16864 L .47373 .17136 L F
.48049 .16072 m .47524 .17375 L p .47255 .16864 L 0 1 0 r
F P
0 g
s
.47255 .16864 m .47309 .16891 L .47426 .17189 L 1 0 0 r
F
.47255 .16864 m .47426 .17189 L .47501 .17381 L F
.46394 .17777 m .45583 .18233 L .44332 .17216 L p F P
0 g
s
.44332 .17216 m .45136 .16658 L .46394 .17777 L p 1 0 0 r
F P
0 g
s
.45583 .18233 m .44781 .18803 L .43534 .17881 L p 1 0 0 r
F P
0 g
s
.43534 .17881 m .44332 .17216 L .45583 .18233 L p 1 0 0 r
F P
0 g
s
.47212 .17793 m .46383 .18809 L .45111 .18139 L p 0 0 1 r
F P
0 g
s
.45111 .18139 m .45938 .17117 L .47212 .17793 L p 0 0 1 r
F P
0 g
s
.4721 .18157 m .45924 .18192 L p .47212 .16907 L 0 1 0 r
F P
0 g
s
.47501 .17381 m .47214 .17447 L p .47222 .16848 L 1 0 0 r
F P
0 g
s
.47212 .16907 m .47255 .16864 L .47251 .1698 L 0 1 0 r
F
.47212 .16907 m .47291 .17056 L .47283 .17135 L 0 0 1 r
F
.47589 .17731 m .47624 .17691 L .47778 .18093 L 0 1 0 r
F
.47589 .17731 m .47669 .17717 L .47778 .18093 L 0 0 1 r
F
.47669 .17717 m .47866 .18102 L .47828 .18087 L 1 0 0 r
F
.47669 .17717 m .49318 .17445 L .47846 .18064 L 0 0 1 r
F
.47669 .17717 m .47846 .18064 L .47787 .18089 L F
.47669 .17717 m .47787 .18089 L .47778 .18093 L F
.47624 .17691 m .47559 .17367 L .47669 .17717 L 1 0 0 r
F
.47214 .17447 m .47524 .17375 L p .47624 .17691 L F P
0 g
s
.47524 .17375 m .47549 .17312 L p .47624 .17691 L 0 1 0 r
F P
0 g
s
.47524 .17375 m .47559 .17367 L p .47624 .17691 L 1 0 0 r
F P
0 g
s
.47506 .1742 m .47524 .17375 L p .47624 .17691 L 0 1 0 r
F P
0 g
s
.48047 .16768 m .49318 .17445 L p .47736 .17706 L 0 0 1 r
F P
0 g
s
.47688 .17615 m .48047 .16768 L .47736 .17706 L 0 0 1 r
F
.47589 .17731 m .47506 .1742 L .47624 .17691 L 0 1 0 r
F
.47212 .17793 m .47496 .17444 L p .47589 .17731 L 0 0 1 r
F P
0 g
s
.47778 .18093 m .47212 .17793 L p .47589 .17731 L 0 0 1 r
F P
0 g
s
.4721 .18157 m .47496 .17444 L p .47589 .17731 L 0 1 0 r
F P
0 g
s
.47496 .17444 m .47506 .1742 L p .47589 .17731 L 0 1 0 r
F P
0 g
s
.47589 .17731 m .47496 .17444 L .47644 .17722 L 0 0 1 r
F
.47549 .17312 m .48049 .16072 L p .47656 .17655 L 0 1 0 r
F P
0 g
s
.47496 .17444 m .48047 .16768 L p .47644 .17722 L 0 0 1 r
F P
0 g
s
.48047 .16768 m .47559 .17367 L p .47309 .16891 L 0 0 1 r
F P
0 g
s
.48046 .17255 m .47559 .17367 L p .47314 .16893 L 1 0 0 r
F P
0 g
s
.47559 .17367 m .47524 .17375 L p .47335 .1694 L 1 0 0 r
F P
0 g
s
.47314 .16893 m .47559 .17367 L .47335 .1694 L 1 0 0 r
F
.47644 .17722 m .47688 .17615 L .47736 .17706 L 0 0 1 r
F
.47309 .16891 m .47326 .16923 L .47501 .17381 L 1 0 0 r
F
.47524 .17375 m .47501 .17381 L p .47314 .16893 L F P
0 g
s
.47524 .17375 m .47496 .17444 L p .47255 .16864 L 0 1 0 r
F P
0 g
s
.47249 .17027 m .47283 .17135 L .47227 .17649 L 0 0 1 r
F
.47249 .17027 m .47227 .17649 L .47212 .17793 L F
.47212 .16907 m .47249 .17027 L .47212 .17793 L F
.47255 .16864 m .47496 .17444 L .47251 .1698 L 0 1 0 r
F
.47559 .17367 m .47212 .17793 L p .47309 .16891 L 0 0 1 r
F P
0 g
s
.47496 .17444 m .4721 .18157 L p .47251 .1698 L 0 1 0 r
F P
0 g
s
.48046 .17255 m .49323 .187 L p .47669 .17717 L 1 0 0 r
F P
0 g
s
.47559 .17367 m .48046 .17255 L p .47669 .17717 L 1 0 0 r
F P
0 g
s
.47212 .16907 m .47251 .1698 L .4721 .18157 L 0 1 0 r
F
.47212 .16907 m .47309 .16891 L .47291 .17056 L 0 0 1 r
F
.45949 .16218 m .46772 .15908 L .47049 .16202 L p 1 0 0 r
F P
0 g
s
.47049 .16202 m .48049 .16072 L p .47255 .16864 L 0 1 0 r
F P
0 g
s
.47049 .16202 m .47116 .16272 L p .47255 .16864 L 1 0 0 r
F P
0 g
s
.45949 .16218 m .47049 .16202 L .47255 .16864 L 1 0 0 r
F
.47255 .16864 m .47061 .16417 L .47049 .16202 L 0 1 0 r
F
.45938 .17117 m .4677 .16088 L .46996 .16208 L p 0 0 1 r
F P
0 g
s
.45938 .17117 m .46996 .16208 L .47034 .16331 L 0 0 1 r
F
.46996 .16208 m .47049 .16202 L p .47061 .16417 L 0 1 0 r
F P
0 g
s
.47255 .16864 m .47116 .16272 L .47309 .16891 L 1 0 0 r
F
.47212 .16907 m .47061 .16417 L .47255 .16864 L 0 1 0 r
F
.45938 .17117 m .47116 .16272 L .47309 .16891 L 0 0 1 r
F
.46972 .16212 m .46996 .16208 L p .47061 .16417 L 0 1 0 r
F P
0 g
s
.46996 .16208 m .47116 .16272 L p .47034 .16331 L 0 0 1 r
F P
0 g
s
.47116 .16272 m .48047 .16768 L p .47309 .16891 L 0 0 1 r
F P
0 g
s
.47116 .16272 m .48046 .17255 L p .47309 .16891 L 1 0 0 r
F P
0 g
s
.45924 .18192 m .46972 .16212 L .47061 .16417 L 0 1 0 r
F
.45924 .18192 m .47061 .16417 L .47212 .16907 L F
.45924 .18192 m .46769 .16238 L .46972 .16212 L p F P
0 g
s
.47309 .16891 m .47314 .16893 L .47326 .16923 L 1 0 0 r
F
.47669 .17717 m .49323 .187 L .47866 .18102 L F
.4784 .18127 m .47828 .18087 L .47845 .18129 L F
.47828 .18087 m .47875 .18136 L p .47845 .18129 L F P
0 g
s
.47891 .18153 m .47778 .18093 L p .47846 .18064 L 0 0 1 r
F P
0 g
s
.47778 .18093 m .4721 .18157 L p .47589 .17731 L 0 1 0 r
F P
0 g
s
.49323 .187 m .4848 .18766 L .47891 .18153 L p 1 0 0 r
F P
0 g
s
.47866 .18102 m .49323 .187 L .47891 .18153 L 1 0 0 r
F
.48184 .1918 m .48187 .19166 L .48211 .19246 L 0 1 0 r
F
.4809 .18955 m .48104 .18921 L p .48184 .1918 L F P
0 g
s
.4828 .1934 m .48299 .19285 L .48324 .19365 L 1 0 0 r
F
.48268 .19313 m .48269 .19305 L .4828 .1934 L 0 1 0 r
F
.4826 .19362 m .48268 .19313 L .4828 .1934 L F
.4828 .1934 m .48324 .19365 L .48585 .1994 L 1 0 0 r
F
.48245 .19378 m .48165 .18847 L .48324 .19365 L 0 0 1 r
F
.48104 .18921 m .48165 .18847 L p .48245 .19378 L F P
0 g
s
.4848 .18766 m .48165 .18847 L p .48008 .18542 L 1 0 0 r
F P
0 g
s
.48324 .19365 m .48351 .19205 L .48426 .19349 L 0 0 1 r
F
.4848 .18766 m .49748 .20182 L p .48324 .19365 L 1 0 0 r
F P
0 g
s
.48299 .19285 m .4848 .18766 L .48324 .19365 L 1 0 0 r
F
.48585 .1994 m .48537 .19945 L p .48563 .19897 L 0 1 0 r
F P
0 g
s
.48537 .19945 m .47646 .2003 L p .48245 .19378 L 0 1 0 r
F P
0 g
s
.48324 .19365 m .48438 .19593 L .48585 .1994 L 1 0 0 r
F
.48348 .1938 m .49748 .20182 L .48585 .1994 L F
.48558 .19943 m .48585 .1994 L p .48571 .19974 L 0 1 0 r
F P
0 g
s
.48571 .19974 m .48585 .1994 L .48589 .19955 L 0 1 0 r
F
.48644 .20001 m .48537 .19945 L p .48324 .19365 L 0 0 1 r
F P
0 g
s
.48245 .19378 m .48324 .19365 L .48537 .19945 L 0 0 1 r
F
.48324 .19365 m .48348 .1938 L .48438 .19593 L 1 0 0 r
F
.49748 .20182 m .48907 .20271 L .48644 .20001 L p F P
0 g
s
.48617 .19947 m .49748 .20182 L .48644 .20001 L 1 0 0 r
F
.46811 .21855 m .48551 .19996 L .48605 .20189 L 0 1 0 r
F
.48077 .21861 m .48691 .20415 L p .48775 .20621 L F P
0 g
s
.48077 .21861 m .48775 .20621 L .48888 .21007 L 0 1 0 r
F
.49273 .21765 m .48077 .21861 L p .48888 .21007 L F P
0 g
s
.48888 .21007 m .48964 .20994 L .49273 .21765 L 0 0 1 r
F
.49015 .21023 m .50166 .21661 L .49345 .21759 L 1 0 0 r
F
.49015 .21023 m .49345 .21759 L .4919 .21447 L F
.50166 .21661 m .4935 .21768 L p .49345 .21759 L F P
0 g
s
.49356 .21789 m .5143 .23155 L .49369 .21815 L 1 0 0 r
F
.49328 .21794 m .49369 .21815 L p .49682 .2259 L 0 0 1 r
F P
0 g
s
.49682 .2259 m .49369 .21815 L .4974 .2258 L 0 0 1 r
F
.49297 .21831 m .49328 .21794 L p .49682 .2259 L F P
0 g
s
.49297 .21831 m .48504 .23651 L p .49295 .21826 L 0 1 0 r
F P
0 g
s
.48504 .23651 m .49271 .21891 L p .49413 .22243 L 0 1 0 r
F P
0 g
s
.48504 .23651 m .49413 .22243 L .49518 .22616 L 0 1 0 r
F
.49369 .21815 m .50579 .23135 L p .49591 .22604 L 1 0 0 r
F P
0 g
s
.50021 .23548 m .51834 .24604 L .50036 .23579 L 1 0 0 r
F
.50036 .23579 m .50986 .24604 L p .50203 .24196 L F P
0 g
s
.50165 .24176 m .50036 .23579 L .50203 .24196 L 1 0 0 r
F
.50124 .24209 m .50036 .23579 L .50203 .24196 L 0 0 1 r
F
.49746 .23569 m .49857 .23294 L p .49889 .23404 L 0 1 0 r
F P
0 g
s
.48926 .25402 m .49915 .23542 L .50041 .23863 L 0 1 0 r
F
.48926 .25402 m .50041 .23863 L .50133 .24207 L F
.48926 .25402 m .49746 .23569 L .49915 .23542 L p F P
0 g
s
.50203 .24196 m .50227 .24208 L .50273 .24341 L 1 0 0 r
F
.50525 .24982 m .50528 .24984 L .50531 .24995 L F
.50525 .24982 m .50531 .24995 L .50597 .25223 L F
.50468 .24991 m .50525 .24982 L .50605 .25274 L 0 0 1 r
F
.50525 .24982 m .50654 .25256 L .50605 .25274 L F
.50605 .25274 m .50159 .25337 L p .50468 .24991 L 0 1 0 r
F P
0 g
s
.50159 .25337 m .50401 .24752 L p .50468 .24991 L 0 1 0 r
F P
0 g
s
.50613 .25306 m .5064 .25269 L .50733 .2578 L 0 1 0 r
F
.50605 .25274 m .50681 .25313 L p .50623 .25343 L 0 0 1 r
F P
0 g
s
.49339 .26003 m .50605 .25274 L .50623 .25343 L 0 0 1 r
F
.50733 .2578 m .5064 .25269 L .50763 .25752 L 0 1 0 r
F
.49343 .27116 m .50613 .25306 L .50733 .2578 L F
.49343 .27116 m .50159 .25337 L .50605 .25274 L p F P
0 g
s
.49343 .27116 m .50605 .25274 L .50613 .25306 L 0 1 0 r
F
.50733 .2578 m .50681 .25313 L .50799 .2577 L 0 0 1 r
F
.50623 .25343 m .50681 .25313 L .50733 .2578 L F
.52233 .2605 m .51388 .26068 L .50681 .25313 L p 1 0 0 r
F P
0 g
s
.50667 .25282 m .52233 .2605 L .50681 .25313 L 1 0 0 r
F
.50528 .24984 m .52233 .2605 L .5064 .25269 L F
.45296 .33705 m .46097 .32654 L .47328 .33039 L p 0 1 0 r
F P
0 g
s
.48135 .31769 m .47328 .33039 L .46097 .32654 L p 0 1 0 r
F P
0 g
s
.4241 .21107 m .43196 .2025 L .44431 .21063 L p 1 0 0 r
F P
0 g
s
.43196 .2025 m .4241 .21107 L .41171 .20428 L p 1 0 0 r
F P
0 g
s
.63398 .48101 m .63434 .48212 L .63232 .47816 L p 1 0 0 r
F P
0 g
s
.63232 .47816 m .63377 .47996 L .63398 .48101 L p 1 0 0 r
F P
0 g
s
.46097 .32654 m .45296 .33705 L .44061 .33152 L p 0 1 0 r
F P
0 g
s
.37562 .31476 m .38315 .30902 L .39557 .3176 L p 0 1 0 r
F P
0 g
s
.38315 .30902 m .37562 .31476 L .36327 .30542 L p 0 1 0 r
F P
0 g
s
.28108 .26079 m .27375 .27033 L .26096 .26404 L p 0 0 1 r
F P
0 g
s
.32662 .27015 m .33414 .2606 L .34677 .26691 L p 0 0 1 r
F P
0 g
s
.37949 .26996 m .38722 .26041 L .39971 .26672 L p 0 0 1 r
F P
0 g
s
.38722 .26041 m .37949 .26996 L .36697 .26366 L p 0 0 1 r
F P
0 g
s
.43238 .26977 m .4403 .26022 L .45266 .26653 L p 0 0 1 r
F P
0 g
s
.4403 .26022 m .43238 .26977 L .41998 .26347 L p 0 0 1 r
F P
0 g
s
.49339 .26003 m .48527 .26958 L .473 .26329 L p 0 0 1 r
F P
0 g
s
.35054 .2234 m .34274 .23633 L .3299 .23286 L p 1 0 0 r
F P
0 g
s
.53817 .2694 m .54648 .25984 L .55859 .26616 L p 0 0 1 r
F P
0 g
s
.54648 .25984 m .53817 .2694 L .52603 .2631 L p 0 0 1 r
F P
0 g
s
.53871 .29028 m .53015 .28929 L .51785 .27526 L p 1 0 0 r
F P
0 g
s
.51785 .27526 m .52626 .27491 L .53871 .29028 L p 1 0 0 r
F P
0 g
s
.59108 .26921 m .59959 .25965 L .61157 .26597 L p 0 0 1 r
F P
0 g
s
.59959 .25965 m .59108 .26921 L .57906 .26291 L p 0 0 1 r
F P
0 g
s
.42036 .33324 m .4282 .32527 L .44061 .33152 L p 0 1 0 r
F P
0 g
s
.4282 .32527 m .42036 .33324 L .40798 .32569 L p 0 1 0 r
F P
0 g
s
.644 .26902 m .6527 .25947 L .66455 .26578 L p 0 0 1 r
F P
0 g
s
.6527 .25947 m .644 .26902 L .63211 .26272 L p 0 0 1 r
F P
0 g
s
.62772 .45923 m .62999 .46585 L p .61608 .44089 L 1 0 0 r
F P
0 g
s
.62999 .46585 m .62912 .46476 L .61608 .44089 L p 1 0 0 r
F P
0 g
s
.61608 .44089 m .62589 .45144 L p .62772 .45923 L 1 0 0 r
F P
0 g
s
.36327 .30542 m .37072 .30001 L .38315 .30902 L p 0 1 0 r
F P
0 g
s
.37072 .30001 m .36327 .30542 L .35091 .29577 L p 0 1 0 r
F P
0 g
s
.23679 .31464 m .24429 .30271 L .25741 .30639 L p 1 0 0 r
F P
0 g
s
.26502 .29369 m .25741 .30639 L .24429 .30271 L p 1 0 0 r
F P
0 g
s
.26502 .29369 m .27271 .28061 L .2858 .28369 L p 1 0 0 r
F P
0 g
s
.29354 .27027 m .2858 .28369 L .27271 .28061 L p 1 0 0 r
F P
0 g
s
.37104 .21519 m .37885 .20342 L .39142 .20867 L p 1 0 0 r
F P
0 g
s
.39142 .20867 m .39923 .198 L .41171 .20428 L p 1 0 0 r
F P
0 g
s
.39923 .198 m .39142 .20867 L .37885 .20342 L p 1 0 0 r
F P
0 g
s
.35054 .2234 m .35835 .21078 L .37104 .21519 L p 1 0 0 r
F P
0 g
s
.37885 .20342 m .37104 .21519 L .35835 .21078 L p 1 0 0 r
F P
0 g
s
.34677 .26691 m .35438 .25734 L .36697 .26366 L p 0 0 1 r
F P
0 g
s
.35438 .25734 m .34677 .26691 L .33414 .2606 L p 0 0 1 r
F P
0 g
s
.46097 .32654 m .46903 .31482 L .48135 .31769 L p 0 1 0 r
F P
0 g
s
.48945 .30359 m .48135 .31769 L .46903 .31482 L p 0 1 0 r
F P
0 g
s
.39971 .26672 m .40752 .25715 L .41998 .26347 L p 0 0 1 r
F P
0 g
s
.40752 .25715 m .39971 .26672 L .38722 .26041 L p 0 0 1 r
F P
0 g
s
.35091 .29577 m .35828 .29062 L .37072 .30001 L p 0 1 0 r
F P
0 g
s
.35828 .29062 m .35091 .29577 L .33855 .28587 L p 0 1 0 r
F P
0 g
s
.45266 .26653 m .46067 .25696 L .473 .26329 L p 0 0 1 r
F P
0 g
s
.46067 .25696 m .45266 .26653 L .4403 .26022 L p 0 0 1 r
F P
0 g
s
.55859 .26616 m .56699 .25658 L .57906 .26291 L p 0 0 1 r
F P
0 g
s
.56699 .25658 m .55859 .26616 L .54648 .25984 L p 0 0 1 r
F P
0 g
s
.55124 .30687 m .54251 .30445 L .53015 .28929 L p 1 0 0 r
F P
0 g
s
.53015 .28929 m .53871 .29028 L .55124 .30687 L p 1 0 0 r
F P
0 g
s
.41171 .20428 m .41954 .19497 L .43196 .2025 L p 1 0 0 r
F P
0 g
s
.41954 .19497 m .41171 .20428 L .39923 .198 L p 1 0 0 r
F P
0 g
s
.61157 .26597 m .62016 .25639 L .63211 .26272 L p 0 0 1 r
F P
0 g
s
.62016 .25639 m .61157 .26597 L .59959 .25965 L p 0 0 1 r
F P
0 g
s
.59305 .37843 m .58372 .37133 L .57111 .35234 L p 1 0 0 r
F P
0 g
s
.57111 .35234 m .5802 .35772 L .59305 .37843 L p 1 0 0 r
F P
0 g
s
.45224 .20379 m .44431 .21063 L .43196 .2025 L p 1 0 0 r
F P
0 g
s
.33855 .28587 m .34584 .28092 L .35828 .29062 L p 0 1 0 r
F P
0 g
s
.34584 .28092 m .33855 .28587 L .32619 .27578 L p 0 1 0 r
F P
0 g
s
.40798 .32569 m .41576 .31835 L .4282 .32527 L p 0 1 0 r
F P
0 g
s
.41576 .31835 m .40798 .32569 L .39557 .3176 L p 0 1 0 r
F P
0 g
s
.44061 .33152 m .44858 .32186 L .46097 .32654 L p 0 1 0 r
F P
0 g
s
.44858 .32186 m .44061 .33152 L .4282 .32527 L p 0 1 0 r
F P
0 g
s
.26096 .26404 m .26826 .25444 L .28108 .26079 L p 0 0 1 r
F P
0 g
s
.3299 .23286 m .33772 .21963 L .35054 .2234 L p 1 0 0 r
F P
0 g
s
.35835 .21078 m .35054 .2234 L .33772 .21963 L p 1 0 0 r
F P
0 g
s
.62178 .43698 m .62196 .43748 L p .59989 .40536 L 1 0 0 r
F P
0 g
s
.62196 .43748 m .61278 .42747 L .59989 .40536 L p 1 0 0 r
F P
0 g
s
.59989 .40536 m .60945 .41412 L p .62178 .43698 L 1 0 0 r
F P
0 g
s
.36697 .26366 m .37466 .25407 L .38722 .26041 L p 0 0 1 r
F P
0 g
s
.37466 .25407 m .36697 .26366 L .35438 .25734 L p 0 0 1 r
F P
0 g
s
.41998 .26347 m .42787 .25388 L .4403 .26022 L p 0 0 1 r
F P
0 g
s
.42787 .25388 m .41998 .26347 L .40752 .25715 L p 0 0 1 r
F P
0 g
s
.473 .26329 m .48109 .25369 L .49339 .26003 L p 0 0 1 r
F P
0 g
s
.48109 .25369 m .473 .26329 L .46067 .25696 L p 0 0 1 r
F P
0 g
s
.32619 .27578 m .33339 .27097 L .34584 .28092 L p 0 1 0 r
F P
0 g
s
.33339 .27097 m .32619 .27578 L .31382 .26556 L p 0 1 0 r
F P
0 g
s
.27271 .28061 m .28044 .26726 L .29354 .27027 L p 1 0 0 r
F P
0 g
s
.52603 .2631 m .53431 .2535 L .54648 .25984 L p 0 0 1 r
F P
0 g
s
.46903 .31482 m .46097 .32654 L .44858 .32186 L p 0 1 0 r
F P
0 g
s
.52972 .14285 m .52179 .16917 L .50966 .17396 L p 0 1 0 r
F P
0 g
s
.50966 .17396 m .51774 .14903 L .52972 .14285 L p 0 1 0 r
F P
0 g
s
.46903 .31482 m .47714 .30177 L .48945 .30359 L p 0 1 0 r
F P
0 g
s
.49756 .28795 m .48945 .30359 L .47714 .30177 L p 0 1 0 r
F P
0 g
s
.57906 .26291 m .58755 .25331 L .59959 .25965 L p 0 0 1 r
F P
0 g
s
.58755 .25331 m .57906 .26291 L .56699 .25658 L p 0 0 1 r
F P
0 g
s
.24429 .30271 m .25187 .29026 L .26502 .29369 L p 1 0 0 r
F P
0 g
s
.27271 .28061 m .26502 .29369 L .25187 .29026 L p 1 0 0 r
F P
0 g
s
.63211 .26272 m .64079 .25312 L .6527 .25947 L p 0 0 1 r
F P
0 g
s
.64079 .25312 m .63211 .26272 L .62016 .25639 L p 0 0 1 r
F P
0 g
s
.31382 .26556 m .32094 .26081 L .33339 .27097 L p 0 1 0 r
F P
0 g
s
.56387 .32479 m .55496 .32084 L .54251 .30445 L p 1 0 0 r
F P
0 g
s
.54251 .30445 m .55124 .30687 L .56387 .32479 L p 1 0 0 r
F P
0 g
s
.50567 .27067 m .49756 .28795 L .48528 .28725 L p 0 1 0 r
F P
0 g
s
.48528 .28725 m .49343 .27116 L .50567 .27067 L p 0 1 0 r
F P
0 g
s
.47714 .30177 m .48528 .28725 L .49756 .28795 L p 0 1 0 r
F P
0 g
s
.43196 .2025 m .43985 .19479 L .45224 .20379 L p 1 0 0 r
F P
0 g
s
.43985 .19479 m .43196 .2025 L .41954 .19497 L p 1 0 0 r
F P
0 g
s
.33414 .2606 m .34173 .25098 L .35438 .25734 L p 0 0 1 r
F P
0 g
s
.34173 .25098 m .33414 .2606 L .32146 .25426 L p 0 0 1 r
F P
0 g
s
.39557 .3176 m .40328 .31081 L .41576 .31835 L p 0 1 0 r
F P
0 g
s
.40328 .31081 m .39557 .3176 L .38315 .30902 L p 0 1 0 r
F P
0 g
s
.38722 .26041 m .395 .25079 L .40752 .25715 L p 0 0 1 r
F P
0 g
s
.395 .25079 m .38722 .26041 L .37466 .25407 L p 0 0 1 r
F P
0 g
s
.62912 .46476 m .63035 .46717 L .63172 .47383 L p 1 0 0 r
F P
0 g
s
.4403 .26022 m .44828 .2506 L .46067 .25696 L p 0 0 1 r
F P
0 g
s
.44828 .2506 m .4403 .26022 L .42787 .25388 L p 0 0 1 r
F P
0 g
s
.35835 .21078 m .36618 .19853 L .37885 .20342 L p 1 0 0 r
F P
0 g
s
.37885 .20342 m .38667 .19217 L .39923 .198 L p 1 0 0 r
F P
0 g
s
.38667 .19217 m .37885 .20342 L .36618 .19853 L p 1 0 0 r
F P
0 g
s
.54648 .25984 m .55486 .25022 L .56699 .25658 L p 0 0 1 r
F P
0 g
s
.55486 .25022 m .54648 .25984 L .53431 .2535 L p 0 0 1 r
F P
0 g
s
.59959 .25965 m .60816 .25003 L .62016 .25639 L p 0 0 1 r
F P
0 g
s
.60816 .25003 m .59959 .25965 L .58755 .25331 L p 0 0 1 r
F P
0 g
s
.39923 .198 m .40706 .18799 L .41954 .19497 L p 1 0 0 r
F P
0 g
s
.40706 .18799 m .39923 .198 L .38667 .19217 L p 1 0 0 r
F P
0 g
s
.33772 .21963 m .34556 .20664 L .35835 .21078 L p 1 0 0 r
F P
0 g
s
.36618 .19853 m .35835 .21078 L .34556 .20664 L p 1 0 0 r
F P
0 g
s
.4282 .32527 m .43613 .31638 L .44858 .32186 L p 0 1 0 r
F P
0 g
s
.43613 .31638 m .4282 .32527 L .41576 .31835 L p 0 1 0 r
F P
0 g
s
.25187 .29026 m .25953 .27736 L .27271 .28061 L p 1 0 0 r
F P
0 g
s
.28044 .26726 m .27271 .28061 L .25953 .27736 L p 1 0 0 r
F P
0 g
s
.35438 .25734 m .36204 .24769 L .37466 .25407 L p 0 0 1 r
F P
0 g
s
.36204 .24769 m .35438 .25734 L .34173 .25098 L p 0 0 1 r
F P
0 g
s
.40752 .25715 m .41538 .2475 L .42787 .25388 L p 0 0 1 r
F P
0 g
s
.41538 .2475 m .40752 .25715 L .395 .25079 L p 0 0 1 r
F P
0 g
s
.38315 .30902 m .39079 .30272 L .40328 .31081 L p 0 1 0 r
F P
0 g
s
.39079 .30272 m .38315 .30902 L .37072 .30001 L p 0 1 0 r
F P
0 g
s
.46067 .25696 m .46873 .24731 L .48109 .25369 L p 0 0 1 r
F P
0 g
s
.46873 .24731 m .46067 .25696 L .44828 .2506 L p 0 0 1 r
F P
0 g
s
.60608 .40083 m .59649 .39187 L .58372 .37133 L p 1 0 0 r
F P
0 g
s
.58372 .37133 m .59305 .37843 L .60608 .40083 L p 1 0 0 r
F P
0 g
s
.56699 .25658 m .57545 .24693 L .58755 .25331 L p 0 0 1 r
F P
0 g
s
.57545 .24693 m .56699 .25658 L .55486 .25022 L p 0 0 1 r
F P
0 g
s
.62016 .25639 m .62882 .24674 L .64079 .25312 L p 0 0 1 r
F P
0 g
s
.62882 .24674 m .62016 .25639 L .60816 .25003 L p 0 0 1 r
F P
0 g
s
.44858 .32186 m .45662 .31106 L .46903 .31482 L p 0 1 0 r
F P
0 g
s
.47714 .30177 m .46903 .31482 L .45662 .31106 L p 0 1 0 r
F P
0 g
s
.41954 .19497 m .42742 .18645 L .43985 .19479 L p 1 0 0 r
F P
0 g
s
.42742 .18645 m .41954 .19497 L .40706 .18799 L p 1 0 0 r
F P
0 g
s
.57664 .34413 m .56751 .33856 L .55496 .32084 L p 1 0 0 r
F P
0 g
s
.55496 .32084 m .56387 .32479 L .57664 .34413 L p 1 0 0 r
F P
0 g
s
.45662 .31106 m .44858 .32186 L .43613 .31638 L p 0 1 0 r
F P
0 g
s
.63013 .46649 m .63035 .46717 L .62912 .46476 L p 1 0 0 r
F P
0 g
s
.62912 .46476 m .62999 .46585 L .63013 .46649 L p 1 0 0 r
F P
0 g
s
.34556 .20664 m .33772 .21963 L .32479 .21603 L p 1 0 0 r
F P
0 g
s
.32146 .25426 m .32901 .24459 L .34173 .25098 L p 0 0 1 r
F P
0 g
s
.37072 .30001 m .37828 .29413 L .39079 .30272 L p 0 1 0 r
F P
0 g
s
.37828 .29413 m .37072 .30001 L .35828 .29062 L p 0 1 0 r
F P
0 g
s
.37466 .25407 m .38241 .2444 L .395 .25079 L p 0 0 1 r
F P
0 g
s
.38241 .2444 m .37466 .25407 L .36204 .24769 L p 0 0 1 r
F P
0 g
s
.42787 .25388 m .43582 .24421 L .44828 .2506 L p 0 0 1 r
F P
0 g
s
.43582 .24421 m .42787 .25388 L .41538 .2475 L p 0 0 1 r
F P
0 g
s
.48924 .24402 m .48109 .25369 L .46873 .24731 L p 0 0 1 r
F P
0 g
s
.53431 .2535 m .54266 .24382 L .55486 .25022 L p 0 0 1 r
F P
0 g
s
.54266 .24382 m .53431 .2535 L .52209 .24712 L p 0 0 1 r
F P
0 g
s
.58755 .25331 m .59609 .24363 L .60816 .25003 L p 0 0 1 r
F P
0 g
s
.59609 .24363 m .58755 .25331 L .57545 .24693 L p 0 0 1 r
F P
0 g
s
.25953 .27736 m .26725 .26411 L .28044 .26726 L p 1 0 0 r
F P
0 g
s
.28822 .25369 m .28044 .26726 L .26725 .26411 L p 1 0 0 r
F P
0 g
s
.41576 .31835 m .42363 .31017 L .43613 .31638 L p 0 1 0 r
F P
0 g
s
.42363 .31017 m .41576 .31835 L .40328 .31081 L p 0 1 0 r
F P
0 g
s
.36618 .19853 m .37401 .18674 L .38667 .19217 L p 1 0 0 r
F P
0 g
s
.38667 .19217 m .3945 .18151 L .40706 .18799 L p 1 0 0 r
F P
0 g
s
.3945 .18151 m .38667 .19217 L .37401 .18674 L p 1 0 0 r
F P
0 g
s
.53486 .27608 m .52626 .27491 L .51388 .26068 L p 1 0 0 r
F P
0 g
s
.51388 .26068 m .52233 .2605 L .53486 .27608 L p 1 0 0 r
F P
0 g
s
.35828 .29062 m .36575 .28509 L .37828 .29413 L p 0 1 0 r
F P
0 g
s
.36575 .28509 m .35828 .29062 L .34584 .28092 L p 0 1 0 r
F P
0 g
s
.34556 .20664 m .3534 .19396 L .36618 .19853 L p 1 0 0 r
F P
0 g
s
.37401 .18674 m .36618 .19853 L .3534 .19396 L p 1 0 0 r
F P
0 g
s
.62353 .44448 m .62607 .45167 L p .61278 .42747 L 1 0 0 r
F P
0 g
s
.62607 .45167 m .62589 .45144 L .61278 .42747 L p 1 0 0 r
F P
0 g
s
.61278 .42747 m .62196 .43748 L .62353 .44448 L p 1 0 0 r
F P
0 g
s
.45662 .31106 m .46472 .299 L .47714 .30177 L p 0 1 0 r
F P
0 g
s
.48528 .28725 m .47714 .30177 L .46472 .299 L p 0 1 0 r
F P
0 g
s
.34173 .25098 m .34936 .24129 L .36204 .24769 L p 0 0 1 r
F P
0 g
s
.34936 .24129 m .34173 .25098 L .32901 .24459 L p 0 0 1 r
F P
0 g
s
.395 .25079 m .40283 .2411 L .41538 .2475 L p 0 0 1 r
F P
0 g
s
.40283 .2411 m .395 .25079 L .38241 .2444 L p 0 0 1 r
F P
0 g
s
.44828 .2506 m .45631 .2409 L .46873 .24731 L p 0 0 1 r
F P
0 g
s
.45631 .2409 m .44828 .2506 L .43582 .24421 L p 0 0 1 r
F P
0 g
s
.55486 .25022 m .56329 .24052 L .57545 .24693 L p 0 0 1 r
F P
0 g
s
.56329 .24052 m .55486 .25022 L .54266 .24382 L p 0 0 1 r
F P
0 g
s
.60816 .25003 m .61679 .24033 L .62882 .24674 L p 0 0 1 r
F P
0 g
s
.61679 .24033 m .60816 .25003 L .59609 .24363 L p 0 0 1 r
F P
0 g
s
.40706 .18799 m .41493 .17871 L .42742 .18645 L p 1 0 0 r
F P
0 g
s
.41493 .17871 m .40706 .18799 L .3945 .18151 L p 1 0 0 r
F P
0 g
s
.34584 .28092 m .35323 .27568 L .36575 .28509 L p 0 1 0 r
F P
0 g
s
.35323 .27568 m .34584 .28092 L .33339 .27097 L p 0 1 0 r
F P
0 g
s
.32479 .21603 m .33265 .20272 L .34556 .20664 L p 1 0 0 r
F P
0 g
s
.3534 .19396 m .34556 .20664 L .33265 .20272 L p 1 0 0 r
F P
0 g
s
.44781 .18803 m .43985 .19479 L .42742 .18645 L p 1 0 0 r
F P
0 g
s
.54747 .29289 m .53871 .29028 L .52626 .27491 L p 1 0 0 r
F P
0 g
s
.52626 .27491 m .53486 .27608 L .54747 .29289 L p 1 0 0 r
F P
0 g
s
.26725 .26411 m .27503 .25059 L .28822 .25369 L p 1 0 0 r
F P
0 g
s
.58957 .36503 m .5802 .35772 L .56751 .33856 L p 1 0 0 r
F P
0 g
s
.56751 .33856 m .57664 .34413 L .58957 .36503 L p 1 0 0 r
F P
0 g
s
.40328 .31081 m .4111 .30327 L .42363 .31017 L p 0 1 0 r
F P
0 g
s
.4111 .30327 m .40328 .31081 L .39079 .30272 L p 0 1 0 r
F P
0 g
s
.43613 .31638 m .44414 .30644 L .45662 .31106 L p 0 1 0 r
F P
0 g
s
.44414 .30644 m .43613 .31638 L .42363 .31017 L p 0 1 0 r
F P
0 g
s
.36204 .24769 m .36977 .23798 L .38241 .2444 L p 0 0 1 r
F P
0 g
s
.36977 .23798 m .36204 .24769 L .34936 .24129 L p 0 0 1 r
F P
0 g
s
.46472 .299 m .47288 .28555 L .48528 .28725 L p 0 1 0 r
F P
0 g
s
.49343 .27116 m .48528 .28725 L .47288 .28555 L p 0 1 0 r
F P
0 g
s
.33339 .27097 m .34069 .26593 L .35323 .27568 L p 0 1 0 r
F P
0 g
s
.34069 .26593 m .33339 .27097 L .32094 .26081 L p 0 1 0 r
F P
0 g
s
.41538 .2475 m .42331 .23778 L .43582 .24421 L p 0 0 1 r
F P
0 g
s
.42331 .23778 m .41538 .2475 L .40283 .2411 L p 0 0 1 r
F P
0 g
s
.46873 .24731 m .47685 .23759 L .48924 .24402 L p 0 0 1 r
F P
0 g
s
.47685 .23759 m .46873 .24731 L .45631 .2409 L p 0 0 1 r
F P
0 g
s
.52209 .24712 m .53041 .2374 L .54266 .24382 L p 0 0 1 r
F P
0 g
s
.46472 .299 m .45662 .31106 L .44414 .30644 L p 0 1 0 r
F P
0 g
s
.57545 .24693 m .58397 .23721 L .59609 .24363 L p 0 0 1 r
F P
0 g
s
.58397 .23721 m .57545 .24693 L .56329 .24052 L p 0 0 1 r
F P
0 g
s
.50159 .25337 m .49343 .27116 L .48106 .2706 L p 0 1 0 r
F P
0 g
s
.48106 .2706 m .48926 .25402 L .50159 .25337 L p 0 1 0 r
F P
0 g
s
.47288 .28555 m .48106 .2706 L .49343 .27116 L p 0 1 0 r
F P
0 g
s
.32094 .26081 m .32816 .25592 L .34069 .26593 L p 0 1 0 r
F P
0 g
s
.32816 .25592 m .32094 .26081 L .30849 .2505 L p 0 1 0 r
F P
0 g
s
.61723 .422 m .61769 .42324 L p .59649 .39187 L 1 0 0 r
F P
0 g
s
.61769 .42324 m .60945 .41412 L .59649 .39187 L p 1 0 0 r
F P
0 g
s
.59649 .39187 m .60608 .40083 L p .61723 .422 L 1 0 0 r
F P
0 g
s
.32901 .24459 m .33662 .23485 L .34936 .24129 L p 0 0 1 r
F P
0 g
s
.33662 .23485 m .32901 .24459 L .31624 .23817 L p 0 0 1 r
F P
0 g
s
.30849 .2505 m .31562 .24569 L .32816 .25592 L p 0 1 0 r
F P
0 g
s
.38241 .2444 m .39022 .23466 L .40283 .2411 L p 0 0 1 r
F P
0 g
s
.39022 .23466 m .38241 .2444 L .36977 .23798 L p 0 0 1 r
F P
0 g
s
.3534 .19396 m .36125 .18168 L .37401 .18674 L p 1 0 0 r
F P
0 g
s
.37401 .18674 m .38186 .17548 L .3945 .18151 L p 1 0 0 r
F P
0 g
s
.38186 .17548 m .37401 .18674 L .36125 .18168 L p 1 0 0 r
F P
0 g
s
.62589 .45144 m .62615 .45195 L .62772 .45923 L p 1 0 0 r
F P
0 g
s
.42742 .18645 m .43534 .17881 L .44781 .18803 L p 1 0 0 r
F P
0 g
s
.43534 .17881 m .42742 .18645 L .41493 .17871 L p 1 0 0 r
F P
0 g
s
.33265 .20272 m .32479 .21603 L .31175 .21256 L p 1 0 0 r
F P
0 g
s
.43582 .24421 m .44383 .23446 L .45631 .2409 L p 0 0 1 r
F P
0 g
s
.44383 .23446 m .43582 .24421 L .42331 .23778 L p 0 0 1 r
F P
0 g
s
.54266 .24382 m .55107 .23408 L .56329 .24052 L p 0 0 1 r
F P
0 g
s
.55107 .23408 m .54266 .24382 L .53041 .2374 L p 0 0 1 r
F P
0 g
s
.59609 .24363 m .6047 .23389 L .61679 .24033 L p 0 0 1 r
F P
0 g
s
.6047 .23389 m .59609 .24363 L .58397 .23721 L p 0 0 1 r
F P
0 g
s
.39079 .30272 m .39853 .29575 L .4111 .30327 L p 0 1 0 r
F P
0 g
s
.39853 .29575 m .39079 .30272 L .37828 .29413 L p 0 1 0 r
F P
0 g
s
.3945 .18151 m .40236 .17152 L .41493 .17871 L p 1 0 0 r
F P
0 g
s
.40236 .17152 m .3945 .18151 L .38186 .17548 L p 1 0 0 r
F P
0 g
s
.56019 .31102 m .55124 .30687 L .53871 .29028 L p 1 0 0 r
F P
0 g
s
.53871 .29028 m .54747 .29289 L .56019 .31102 L p 1 0 0 r
F P
0 g
s
.33265 .20272 m .34051 .18966 L .3534 .19396 L p 1 0 0 r
F P
0 g
s
.36125 .18168 m .3534 .19396 L .34051 .18966 L p 1 0 0 r
F P
0 g
s
.34936 .24129 m .35706 .23152 L .36977 .23798 L p 0 0 1 r
F P
0 g
s
.35706 .23152 m .34936 .24129 L .33662 .23485 L p 0 0 1 r
F P
0 g
s
.42363 .31017 m .4316 .30102 L .44414 .30644 L p 0 1 0 r
F P
0 g
s
.4316 .30102 m .42363 .31017 L .4111 .30327 L p 0 1 0 r
F P
0 g
s
.40283 .2411 m .41073 .23133 L .42331 .23778 L p 0 0 1 r
F P
0 g
s
.41073 .23133 m .40283 .2411 L .39022 .23466 L p 0 0 1 r
F P
0 g
s
.46441 .23114 m .45631 .2409 L .44383 .23446 L p 0 0 1 r
F P
0 g
s
.56329 .24052 m .57179 .23075 L .58397 .23721 L p 0 0 1 r
F P
0 g
s
.57179 .23075 m .56329 .24052 L .55107 .23408 L p 0 0 1 r
F P
0 g
s
.44414 .30644 m .45222 .29531 L .46472 .299 L p 0 1 0 r
F P
0 g
s
.47288 .28555 m .46472 .299 L .45222 .29531 L p 0 1 0 r
F P
0 g
s
.37828 .29413 m .38594 .28767 L .39853 .29575 L p 0 1 0 r
F P
0 g
s
.38594 .28767 m .37828 .29413 L .36575 .28509 L p 0 1 0 r
F P
0 g
s
.41493 .17871 m .42282 .17025 L .43534 .17881 L p 1 0 0 r
F P
0 g
s
.42282 .17025 m .41493 .17871 L .40236 .17152 L p 1 0 0 r
F P
0 g
s
.31175 .21256 m .31962 .19898 L .33265 .20272 L p 1 0 0 r
F P
0 g
s
.34051 .18966 m .33265 .20272 L .31962 .19898 L p 1 0 0 r
F P
0 g
s
.45222 .29531 m .44414 .30644 L .4316 .30102 L p 0 1 0 r
F P
0 g
s
.60269 .38762 m .59305 .37843 L .5802 .35772 L p 1 0 0 r
F P
0 g
s
.5802 .35772 m .58957 .36503 L .60269 .38762 L p 1 0 0 r
F P
0 g
s
.31624 .23817 m .32382 .22838 L .33662 .23485 L p 0 0 1 r
F P
0 g
s
.36977 .23798 m .37755 .22819 L .39022 .23466 L p 0 0 1 r
F P
0 g
s
.37755 .22819 m .36977 .23798 L .35706 .23152 L p 0 0 1 r
F P
0 g
s
.42331 .23778 m .43129 .22799 L .44383 .23446 L p 0 0 1 r
F P
0 g
s
.43129 .22799 m .42331 .23778 L .41073 .23133 L p 0 0 1 r
F P
0 g
s
.53041 .2374 m .53879 .22761 L .55107 .23408 L p 0 0 1 r
F P
0 g
s
.53879 .22761 m .53041 .2374 L .51809 .23094 L p 0 0 1 r
F P
0 g
s
.58397 .23721 m .59256 .22741 L .6047 .23389 L p 0 0 1 r
F P
0 g
s
.59256 .22741 m .58397 .23721 L .57179 .23075 L p 0 0 1 r
F P
0 g
s
.57304 .33058 m .56387 .32479 L .55124 .30687 L p 1 0 0 r
F P
0 g
s
.55124 .30687 m .56019 .31102 L .57304 .33058 L p 1 0 0 r
F P
0 g
s
.36575 .28509 m .37333 .27907 L .38594 .28767 L p 0 1 0 r
F P
0 g
s
.37333 .27907 m .36575 .28509 L .35323 .27568 L p 0 1 0 r
F P
0 g
s
.6261 .45181 m .62615 .45195 L .62589 .45144 L p 1 0 0 r
F P
0 g
s
.62589 .45144 m .62607 .45167 L .6261 .45181 L p 1 0 0 r
F P
0 g
s
.36125 .18168 m .36911 .16987 L .38186 .17548 L p 1 0 0 r
F P
0 g
s
.38186 .17548 m .38972 .16484 L .40236 .17152 L p 1 0 0 r
F P
0 g
s
.38972 .16484 m .38186 .17548 L .36911 .16987 L p 1 0 0 r
F P
0 g
s
.34051 .18966 m .34839 .17693 L .36125 .18168 L p 1 0 0 r
F P
0 g
s
.36911 .16987 m .36125 .18168 L .34839 .17693 L p 1 0 0 r
F P
0 g
s
.4111 .30327 m .419 .29485 L .4316 .30102 L p 0 1 0 r
F P
0 g
s
.419 .29485 m .4111 .30327 L .39853 .29575 L p 0 1 0 r
F P
0 g
s
.45222 .29531 m .46037 .28289 L .47288 .28555 L p 0 1 0 r
F P
0 g
s
.48106 .2706 m .47288 .28555 L .46037 .28289 L p 0 1 0 r
F P
0 g
s
.33662 .23485 m .34429 .22504 L .35706 .23152 L p 0 0 1 r
F P
0 g
s
.34429 .22504 m .33662 .23485 L .32382 .22838 L p 0 0 1 r
F P
0 g
s
.39022 .23466 m .39809 .22484 L .41073 .23133 L p 0 0 1 r
F P
0 g
s
.39809 .22484 m .39022 .23466 L .37755 .22819 L p 0 0 1 r
F P
0 g
s
.44383 .23446 m .4519 .22465 L .46441 .23114 L p 0 0 1 r
F P
0 g
s
.4519 .22465 m .44383 .23446 L .43129 .22799 L p 0 0 1 r
F P
0 g
s
.35323 .27568 m .36072 .27002 L .37333 .27907 L p 0 1 0 r
F P
0 g
s
.36072 .27002 m .35323 .27568 L .34069 .26593 L p 0 1 0 r
F P
0 g
s
.55107 .23408 m .55954 .22426 L .57179 .23075 L p 0 0 1 r
F P
0 g
s
.55954 .22426 m .55107 .23408 L .53879 .22761 L p 0 0 1 r
F P
0 g
s
.53095 .26186 m .52233 .2605 L .50986 .24604 L p 1 0 0 r
F P
0 g
s
.50986 .24604 m .51834 .24604 L .53095 .26186 L p 1 0 0 r
F P
0 g
s
.31962 .19898 m .31175 .21256 L .29859 .20918 L p 1 0 0 r
F P
0 g
s
.40236 .17152 m .41025 .1623 L .42282 .17025 L p 1 0 0 r
F P
0 g
s
.41025 .1623 m .40236 .17152 L .38972 .16484 L p 1 0 0 r
F P
0 g
s
.31962 .19898 m .32751 .18558 L .34051 .18966 L p 1 0 0 r
F P
0 g
s
.34839 .17693 m .34051 .18966 L .32751 .18558 L p 1 0 0 r
F P
0 g
s
.60945 .41412 m .62165 .43643 L .62178 .43698 L p 1 0 0 r
F P
0 g
s
.61917 .42956 m .62165 .43643 L .60945 .41412 L p 1 0 0 r
F P
0 g
s
.60945 .41412 m .61769 .42324 L .61917 .42956 L p 1 0 0 r
F P
0 g
s
.49746 .23569 m .48926 .25402 L .47679 .25361 L p 0 1 0 r
F P
0 g
s
.47679 .25361 m .48504 .23651 L .49746 .23569 L p 0 1 0 r
F P
0 g
s
.46037 .28289 m .46856 .26903 L .48106 .2706 L p 0 1 0 r
F P
0 g
s
.48926 .25402 m .48106 .2706 L .46856 .26903 L p 0 1 0 r
F P
0 g
s
.34069 .26593 m .3481 .26057 L .36072 .27002 L p 0 1 0 r
F P
0 g
s
.3481 .26057 m .34069 .26593 L .32816 .25592 L p 0 1 0 r
F P
0 g
s
.44332 .17216 m .43534 .17881 L .42282 .17025 L p 1 0 0 r
F P
0 g
s
.35706 .23152 m .36482 .22169 L .37755 .22819 L p 0 0 1 r
F P
0 g
s
.36482 .22169 m .35706 .23152 L .34429 .22504 L p 0 0 1 r
F P
0 g
s
.46856 .26903 m .47679 .25361 L .48926 .25402 L p 0 1 0 r
F P
0 g
s
.41073 .23133 m .41869 .22149 L .43129 .22799 L p 0 0 1 r
F P
0 g
s
.41869 .22149 m .41073 .23133 L .39809 .22484 L p 0 0 1 r
F P
0 g
s
.47257 .2213 m .46441 .23114 L .4519 .22465 L p 0 0 1 r
F P
0 g
s
.4316 .30102 m .43965 .29077 L .45222 .29531 L p 0 1 0 r
F P
0 g
s
.43965 .29077 m .4316 .30102 L .419 .29485 L p 0 1 0 r
F P
0 g
s
.51809 .23094 m .52645 .2211 L .53879 .22761 L p 0 0 1 r
F P
0 g
s
.52645 .2211 m .51809 .23094 L .50572 .22446 L p 0 0 1 r
F P
0 g
s
.46037 .28289 m .45222 .29531 L .43965 .29077 L p 0 1 0 r
F P
0 g
s
.57179 .23075 m .58035 .22091 L .59256 .22741 L p 0 0 1 r
F P
0 g
s
.58035 .22091 m .57179 .23075 L .55954 .22426 L p 0 0 1 r
F P
0 g
s
.39853 .29575 m .40637 .28799 L .419 .29485 L p 0 1 0 r
F P
0 g
s
.40637 .28799 m .39853 .29575 L .38594 .28767 L p 0 1 0 r
F P
0 g
s
.32816 .25592 m .33547 .25079 L .3481 .26057 L p 0 1 0 r
F P
0 g
s
.33547 .25079 m .32816 .25592 L .31562 .24569 L p 0 1 0 r
F P
0 g
s
.54365 .27891 m .53486 .27608 L .52233 .2605 L p 1 0 0 r
F P
0 g
s
.52233 .2605 m .53095 .26186 L .54365 .27891 L p 1 0 0 r
F P
0 g
s
.58605 .35169 m .57664 .34413 L .56387 .32479 L p 1 0 0 r
F P
0 g
s
.56387 .32479 m .57304 .33058 L .58605 .35169 L p 1 0 0 r
F P
0 g
s
.29859 .20918 m .30649 .19537 L .31962 .19898 L p 1 0 0 r
F P
0 g
s
.32751 .18558 m .31962 .19898 L .30649 .19537 L p 1 0 0 r
F P
0 g
s
.34839 .17693 m .35627 .16462 L .36911 .16987 L p 1 0 0 r
F P
0 g
s
.36911 .16987 m .37698 .15862 L .38972 .16484 L p 1 0 0 r
F P
0 g
s
.37698 .15862 m .36911 .16987 L .35627 .16462 L p 1 0 0 r
F P
0 g
s
.31562 .24569 m .32285 .24073 L .33547 .25079 L p 0 1 0 r
F P
0 g
s
.32285 .24073 m .31562 .24569 L .30308 .23531 L p 0 1 0 r
F P
0 g
s
.32382 .22838 m .33146 .21852 L .34429 .22504 L p 0 0 1 r
F P
0 g
s
.33146 .21852 m .32382 .22838 L .31095 .22188 L p 0 0 1 r
F P
0 g
s
.37755 .22819 m .38539 .21833 L .39809 .22484 L p 0 0 1 r
F P
0 g
s
.38539 .21833 m .37755 .22819 L .36482 .22169 L p 0 0 1 r
F P
0 g
s
.43129 .22799 m .43933 .21813 L .4519 .22465 L p 0 0 1 r
F P
0 g
s
.43933 .21813 m .43129 .22799 L .41869 .22149 L p 0 0 1 r
F P
0 g
s
.42282 .17025 m .43077 .16271 L .44332 .17216 L p 1 0 0 r
F P
0 g
s
.43077 .16271 m .42282 .17025 L .41025 .1623 L p 1 0 0 r
F P
0 g
s
.53879 .22761 m .54724 .21774 L .55954 .22426 L p 0 0 1 r
F P
0 g
s
.54724 .21774 m .53879 .22761 L .52645 .2211 L p 0 0 1 r
F P
0 g
s
.61249 .40684 m .61327 .40892 L p .59305 .37843 L 1 0 0 r
F P
0 g
s
.61327 .40892 m .60608 .40083 L .59305 .37843 L p 1 0 0 r
F P
0 g
s
.59305 .37843 m .60269 .38762 L p .61249 .40684 L 1 0 0 r
F P
0 g
s
.38972 .16484 m .3976 .15489 L .41025 .1623 L p 1 0 0 r
F P
0 g
s
.3976 .15489 m .38972 .16484 L .37698 .15862 L p 1 0 0 r
F P
0 g
s
.30308 .23531 m .31022 .23044 L .32285 .24073 L p 0 1 0 r
F P
0 g
s
.32751 .18558 m .33541 .17246 L .34839 .17693 L p 1 0 0 r
F P
0 g
s
.35627 .16462 m .34839 .17693 L .33541 .17246 L p 1 0 0 r
F P
0 g
s
.38594 .28767 m .39371 .2805 L .40637 .28799 L p 0 1 0 r
F P
0 g
s
.39371 .2805 m .38594 .28767 L .37333 .27907 L p 0 1 0 r
F P
0 g
s
.55645 .29727 m .54747 .29289 L .53486 .27608 L p 1 0 0 r
F P
0 g
s
.53486 .27608 m .54365 .27891 L .55645 .29727 L p 1 0 0 r
F P
0 g
s
.34429 .22504 m .35202 .21515 L .36482 .22169 L p 0 0 1 r
F P
0 g
s
.35202 .21515 m .34429 .22504 L .33146 .21852 L p 0 0 1 r
F P
0 g
s
.39809 .22484 m .40602 .21496 L .41869 .22149 L p 0 0 1 r
F P
0 g
s
.40602 .21496 m .39809 .22484 L .38539 .21833 L p 0 0 1 r
F P
0 g
s
.4519 .22465 m .46003 .21476 L .47257 .2213 L p 0 0 1 r
F P
0 g
s
.46003 .21476 m .4519 .22465 L .43933 .21813 L p 0 0 1 r
F P
0 g
s
.43965 .29077 m .44777 .27931 L .46037 .28289 L p 0 1 0 r
F P
0 g
s
.46856 .26903 m .46037 .28289 L .44777 .27931 L p 0 1 0 r
F P
0 g
s
.50572 .22446 m .51405 .21457 L .52645 .2211 L p 0 0 1 r
F P
0 g
s
.419 .29485 m .42701 .28542 L .43965 .29077 L p 0 1 0 r
F P
0 g
s
.42701 .28542 m .419 .29485 L .40637 .28799 L p 0 1 0 r
F P
0 g
s
.55954 .22426 m .56808 .21437 L .58035 .22091 L p 0 0 1 r
F P
0 g
s
.56808 .21437 m .55954 .22426 L .54724 .21774 L p 0 0 1 r
F P
0 g
s
.30649 .19537 m .3144 .18169 L .32751 .18558 L p 1 0 0 r
F P
0 g
s
.33541 .17246 m .32751 .18558 L .3144 .18169 L p 1 0 0 r
F P
0 g
s
.41025 .1623 m .41817 .15392 L .43077 .16271 L p 1 0 0 r
F P
0 g
s
.41817 .15392 m .41025 .1623 L .3976 .15489 L p 1 0 0 r
F P
0 g
s
.37333 .27907 m .38102 .27243 L .39371 .2805 L p 0 1 0 r
F P
0 g
s
.38102 .27243 m .37333 .27907 L .36072 .27002 L p 0 1 0 r
F P
0 g
s
.44777 .27931 m .43965 .29077 L .42701 .28542 L p 0 1 0 r
F P
0 g
s
.31095 .22188 m .31856 .21197 L .33146 .21852 L p 0 0 1 r
F P
0 g
s
.31856 .21197 m .31095 .22188 L .29802 .21535 L p 0 0 1 r
F P
0 g
s
.36482 .22169 m .37263 .21178 L .38539 .21833 L p 0 0 1 r
F P
0 g
s
.37263 .21178 m .36482 .22169 L .35202 .21515 L p 0 0 1 r
F P
0 g
s
.41869 .22149 m .4267 .21158 L .43933 .21813 L p 0 0 1 r
F P
0 g
s
.4267 .21158 m .41869 .22149 L .40602 .21496 L p 0 0 1 r
F P
0 g
s
.52645 .2211 m .53488 .21119 L .54724 .21774 L p 0 0 1 r
F P
0 g
s
.53488 .21119 m .52645 .2211 L .51405 .21457 L p 0 0 1 r
F P
0 g
s
.35627 .16462 m .36415 .15281 L .37698 .15862 L p 1 0 0 r
F P
0 g
s
.37698 .15862 m .38487 .148 L .3976 .15489 L p 1 0 0 r
F P
0 g
s
.38487 .148 m .37698 .15862 L .36415 .15281 L p 1 0 0 r
F P
0 g
s
.33541 .17246 m .34331 .1597 L .35627 .16462 L p 1 0 0 r
F P
0 g
s
.36415 .15281 m .35627 .16462 L .34331 .1597 L p 1 0 0 r
F P
0 g
s
.44777 .27931 m .45596 .26649 L .46856 .26903 L p 0 1 0 r
F P
0 g
s
.47679 .25361 m .46856 .26903 L .45596 .26649 L p 0 1 0 r
F P
0 g
s
.59925 .37447 m .58957 .36503 L .57664 .34413 L p 1 0 0 r
F P
0 g
s
.57664 .34413 m .58605 .35169 L .59925 .37447 L p 1 0 0 r
F P
0 g
s
.36072 .27002 m .36832 .26384 L .38102 .27243 L p 0 1 0 r
F P
0 g
s
.36832 .26384 m .36072 .27002 L .3481 .26057 L p 0 1 0 r
F P
0 g
s
.56939 .31706 m .56019 .31102 L .54747 .29289 L p 1 0 0 r
F P
0 g
s
.54747 .29289 m .55645 .29727 L .56939 .31706 L p 1 0 0 r
F P
0 g
s
.33146 .21852 m .33915 .20859 L .35202 .21515 L p 0 0 1 r
F P
0 g
s
.33915 .20859 m .33146 .21852 L .31856 .21197 L p 0 0 1 r
F P
0 g
s
.40637 .28799 m .41432 .27932 L .42701 .28542 L p 0 1 0 r
F P
0 g
s
.41432 .27932 m .40637 .28799 L .39371 .2805 L p 0 1 0 r
F P
0 g
s
.38539 .21833 m .39329 .20839 L .40602 .21496 L p 0 0 1 r
F P
0 g
s
.39329 .20839 m .38539 .21833 L .37263 .21178 L p 0 0 1 r
F P
0 g
s
.49328 .21771 m .50166 .21661 L .5143 .23155 L p 1 0 0 r
F P
0 g
s
.43933 .21813 m .44744 .20819 L .46003 .21476 L p 0 0 1 r
F P
0 g
s
.44744 .20819 m .43933 .21813 L .4267 .21158 L p 0 0 1 r
F P
0 g
s
.54724 .21774 m .55575 .2078 L .56808 .21437 L p 0 0 1 r
F P
0 g
s
.55575 .2078 m .54724 .21774 L .53488 .21119 L p 0 0 1 r
F P
0 g
s
.3144 .18169 m .32232 .16823 L .33541 .17246 L p 1 0 0 r
F P
0 g
s
.34331 .1597 m .33541 .17246 L .32232 .16823 L p 1 0 0 r
F P
0 g
s
.3976 .15489 m .40551 .14573 L .41817 .15392 L p 1 0 0 r
F P
0 g
s
.40551 .14573 m .3976 .15489 L .38487 .148 L p 1 0 0 r
F P
0 g
s
.45136 .16658 m .44332 .17216 L .43077 .16271 L p 1 0 0 r
F P
0 g
s
.45596 .26649 m .4642 .25218 L .47679 .25361 L p 0 1 0 r
F P
0 g
s
.48504 .23651 m .47679 .25361 L .4642 .25218 L p 0 1 0 r
F P
0 g
s
.3481 .26057 m .35561 .25478 L .36832 .26384 L p 0 1 0 r
F P
0 g
s
.35561 .25478 m .3481 .26057 L .33547 .25079 L p 0 1 0 r
F P
0 g
s
.4642 .25218 m .47248 .23626 L .48504 .23651 L p 0 1 0 r
F P
0 g
s
.527 .24763 m .51834 .24604 L .50579 .23135 L p 1 0 0 r
F P
0 g
s
.50579 .23135 m .5143 .23155 L .527 .24763 L p 1 0 0 r
F P
0 g
s
.29802 .21535 m .3056 .20539 L .31856 .21197 L p 0 0 1 r
F P
0 g
s
.35202 .21515 m .3598 .20519 L .37263 .21178 L p 0 0 1 r
F P
0 g
s
.3598 .20519 m .35202 .21515 L .33915 .20859 L p 0 0 1 r
F P
0 g
s
.40602 .21496 m .41401 .205 L .4267 .21158 L p 0 0 1 r
F P
0 g
s
.41401 .205 m .40602 .21496 L .39329 .20839 L p 0 0 1 r
F P
0 g
s
.46822 .2048 m .46003 .21476 L .44744 .20819 L p 0 0 1 r
F P
0 g
s
.51405 .21457 m .52245 .2046 L .53488 .21119 L p 0 0 1 r
F P
0 g
s
.52245 .2046 m .51405 .21457 L .50159 .208 L p 0 0 1 r
F P
0 g
s
.33547 .25079 m .3429 .24531 L .35561 .25478 L p 0 1 0 r
F P
0 g
s
.3429 .24531 m .33547 .25079 L .32285 .24073 L p 0 1 0 r
F P
0 g
s
.60608 .40083 m .6169 .4206 L .61723 .422 L p 1 0 0 r
F P
0 g
s
.61463 .41448 m .6169 .4206 L .60608 .40083 L p 1 0 0 r
F P
0 g
s
.60608 .40083 m .61327 .40892 L .61463 .41448 L p 1 0 0 r
F P
0 g
s
.42701 .28542 m .4351 .27486 L .44777 .27931 L p 0 1 0 r
F P
0 g
s
.45596 .26649 m .44777 .27931 L .4351 .27486 L p 0 1 0 r
F P
0 g
s
.43077 .16271 m .43877 .15617 L .45136 .16658 L p 1 0 0 r
F P
0 g
s
.43877 .15617 m .43077 .16271 L .41817 .15392 L p 1 0 0 r
F P
0 g
s
.4351 .27486 m .42701 .28542 L .41432 .27932 L p 0 1 0 r
F P
0 g
s
.39371 .2805 m .40159 .27251 L .41432 .27932 L p 0 1 0 r
F P
0 g
s
.40159 .27251 m .39371 .2805 L .38102 .27243 L p 0 1 0 r
F P
0 g
s
.34331 .1597 m .35122 .14737 L .36415 .15281 L p 1 0 0 r
F P
0 g
s
.36415 .15281 m .37205 .14157 L .38487 .148 L p 1 0 0 r
F P
0 g
s
.37205 .14157 m .36415 .15281 L .35122 .14737 L p 1 0 0 r
F P
0 g
s
.32285 .24073 m .33018 .23549 L .3429 .24531 L p 0 1 0 r
F P
0 g
s
.33018 .23549 m .32285 .24073 L .31022 .23044 L p 0 1 0 r
F P
0 g
s
.31856 .21197 m .32623 .20199 L .33915 .20859 L p 0 0 1 r
F P
0 g
s
.32623 .20199 m .31856 .21197 L .3056 .20539 L p 0 0 1 r
F P
0 g
s
.37263 .21178 m .3805 .20179 L .39329 .20839 L p 0 0 1 r
F P
0 g
s
.3805 .20179 m .37263 .21178 L .3598 .20519 L p 0 0 1 r
F P
0 g
s
.53978 .26492 m .53095 .26186 L .51834 .24604 L p 1 0 0 r
F P
0 g
s
.51834 .24604 m .527 .24763 L .53978 .26492 L p 1 0 0 r
F P
0 g
s
.4267 .21158 m .43478 .20159 L .44744 .20819 L p 0 0 1 r
F P
0 g
s
.43478 .20159 m .4267 .21158 L .41401 .205 L p 0 0 1 r
F P
0 g
s
.32232 .16823 m .33025 .15506 L .34331 .1597 L p 1 0 0 r
F P
0 g
s
.35122 .14737 m .34331 .1597 L .33025 .15506 L p 1 0 0 r
F P
0 g
s
.53488 .21119 m .54336 .2012 L .55575 .2078 L p 0 0 1 r
F P
0 g
s
.54336 .2012 m .53488 .21119 L .52245 .2046 L p 0 0 1 r
F P
0 g
s
.38487 .148 m .39277 .1381 L .40551 .14573 L p 1 0 0 r
F P
0 g
s
.39277 .1381 m .38487 .148 L .37205 .14157 L p 1 0 0 r
F P
0 g
s
.31022 .23044 m .31746 .22538 L .33018 .23549 L p 0 1 0 r
F P
0 g
s
.31746 .22538 m .31022 .23044 L .2976 .21997 L p 0 1 0 r
F P
0 g
s
.41817 .15392 m .42613 .14647 L .43877 .15617 L p 1 0 0 r
F P
0 g
s
.42613 .14647 m .41817 .15392 L .40551 .14573 L p 1 0 0 r
F P
0 g
s
.58249 .3384 m .57304 .33058 L .56019 .31102 L p 1 0 0 r
F P
0 g
s
.56019 .31102 m .56939 .31706 L .58249 .3384 L p 1 0 0 r
F P
0 g
s
.2976 .21997 m .30475 .21503 L .31746 .22538 L p 0 1 0 r
F P
0 g
s
.38102 .27243 m .38883 .26505 L .40159 .27251 L p 0 1 0 r
F P
0 g
s
.38883 .26505 m .38102 .27243 L .36832 .26384 L p 0 1 0 r
F P
0 g
s
.33915 .20859 m .34691 .19858 L .3598 .20519 L p 0 0 1 r
F P
0 g
s
.34691 .19858 m .33915 .20859 L .32623 .20199 L p 0 0 1 r
F P
0 g
s
.60755 .39152 m .60871 .39453 L p .58957 .36503 L 1 0 0 r
F P
0 g
s
.60871 .39453 m .60269 .38762 L .58957 .36503 L p 1 0 0 r
F P
0 g
s
.58957 .36503 m .59925 .37447 L p .60755 .39152 L 1 0 0 r
F P
0 g
s
.4351 .27486 m .44326 .26302 L .45596 .26649 L p 0 1 0 r
F P
0 g
s
.4642 .25218 m .45596 .26649 L .44326 .26302 L p 0 1 0 r
F P
0 g
s
.39329 .20839 m .40125 .19838 L .41401 .205 L p 0 0 1 r
F P
0 g
s
.40125 .19838 m .39329 .20839 L .3805 .20179 L p 0 0 1 r
F P
0 g
s
.44744 .20819 m .4556 .19818 L .46822 .2048 L p 0 0 1 r
F P
0 g
s
.4556 .19818 m .44744 .20819 L .43478 .20159 L p 0 0 1 r
F P
0 g
s
.50159 .208 m .50996 .19798 L .52245 .2046 L p 0 0 1 r
F P
0 g
s
.41432 .27932 m .42236 .26959 L .4351 .27486 L p 0 1 0 r
F P
0 g
s
.42236 .26959 m .41432 .27932 L .40159 .27251 L p 0 1 0 r
F P
0 g
s
.55267 .28354 m .54365 .27891 L .53095 .26186 L p 1 0 0 r
F P
0 g
s
.53095 .26186 m .53978 .26492 L .55267 .28354 L p 1 0 0 r
F P
0 g
s
.40551 .14573 m .41345 .13744 L .42613 .14647 L p 1 0 0 r
F P
0 g
s
.41345 .13744 m .40551 .14573 L .39277 .1381 L p 1 0 0 r
F P
0 g
s
.3056 .20539 m .31324 .19536 L .32623 .20199 L p 0 0 1 r
F P
0 g
s
.44326 .26302 m .4351 .27486 L .42236 .26959 L p 0 1 0 r
F P
0 g
s
.3598 .20519 m .36764 .19516 L .3805 .20179 L p 0 0 1 r
F P
0 g
s
.36764 .19516 m .3598 .20519 L .34691 .19858 L p 0 0 1 r
F P
0 g
s
.36832 .26384 m .37604 .257 L .38883 .26505 L p 0 1 0 r
F P
0 g
s
.37604 .257 m .36832 .26384 L .35561 .25478 L p 0 1 0 r
F P
0 g
s
.41401 .205 m .42206 .19496 L .43478 .20159 L p 0 0 1 r
F P
0 g
s
.42206 .19496 m .41401 .205 L .40125 .19838 L p 0 0 1 r
F P
0 g
s
.52245 .2046 m .53091 .19456 L .54336 .2012 L p 0 0 1 r
F P
0 g
s
.53091 .19456 m .52245 .2046 L .50996 .19798 L p 0 0 1 r
F P
0 g
s
.33025 .15506 m .33818 .14226 L .35122 .14737 L p 1 0 0 r
F P
0 g
s
.35122 .14737 m .35914 .13555 L .37205 .14157 L p 1 0 0 r
F P
0 g
s
.35914 .13555 m .35122 .14737 L .33818 .14226 L p 1 0 0 r
F P
0 g
s
.44326 .26302 m .4515 .24978 L .4642 .25218 L p 0 1 0 r
F P
0 g
s
.47248 .23626 m .4642 .25218 L .4515 .24978 L p 0 1 0 r
F P
0 g
s
.37205 .14157 m .37996 .13099 L .39277 .1381 L p 1 0 0 r
F P
0 g
s
.37996 .13099 m .37205 .14157 L .35914 .13555 L p 1 0 0 r
F P
0 g
s
.32623 .20199 m .33395 .19193 L .34691 .19858 L p 0 0 1 r
F P
0 g
s
.33395 .19193 m .32623 .20199 L .31324 .19536 L p 0 0 1 r
F P
0 g
s
.48077 .21861 m .47248 .23626 L .45979 .235 L p 0 1 0 r
F P
0 g
s
.45979 .235 m .46811 .21855 L .48077 .21861 L p 0 1 0 r
F P
0 g
s
.4515 .24978 m .45979 .235 L .47248 .23626 L p 0 1 0 r
F P
0 g
s
.3805 .20179 m .38843 .19173 L .40125 .19838 L p 0 0 1 r
F P
0 g
s
.38843 .19173 m .3805 .20179 L .36764 .19516 L p 0 0 1 r
F P
0 g
s
.35561 .25478 m .36324 .24842 L .37604 .257 L p 0 1 0 r
F P
0 g
s
.36324 .24842 m .35561 .25478 L .3429 .24531 L p 0 1 0 r
F P
0 g
s
.43478 .20159 m .44292 .19153 L .4556 .19818 L p 0 0 1 r
F P
0 g
s
.44292 .19153 m .43478 .20159 L .42206 .19496 L p 0 0 1 r
F P
0 g
s
.45949 .16218 m .45136 .16658 L .43877 .15617 L p 1 0 0 r
F P
0 g
s
.40159 .27251 m .40957 .26355 L .42236 .26959 L p 0 1 0 r
F P
0 g
s
.40957 .26355 m .40159 .27251 L .38883 .26505 L p 0 1 0 r
F P
0 g
s
.59578 .36141 m .58605 .35169 L .57304 .33058 L p 1 0 0 r
F P
0 g
s
.57304 .33058 m .58249 .3384 L .59578 .36141 L p 1 0 0 r
F P
0 g
s
.39277 .1381 m .4007 .12902 L .41345 .13744 L p 1 0 0 r
F P
0 g
s
.4007 .12902 m .39277 .1381 L .37996 .13099 L p 1 0 0 r
F P
0 g
s
.5102 .21703 m .50166 .21661 L .48907 .20271 L p 1 0 0 r
F P
0 g
s
.48907 .20271 m .49748 .20182 L .5102 .21703 L p 1 0 0 r
F P
0 g
s
.43877 .15617 m .44683 .15074 L .45949 .16218 L p 1 0 0 r
F P
0 g
s
.44683 .15074 m .43877 .15617 L .42613 .14647 L p 1 0 0 r
F P
0 g
s
.5657 .30358 m .55645 .29727 L .54365 .27891 L p 1 0 0 r
F P
0 g
s
.54365 .27891 m .55267 .28354 L .5657 .30358 L p 1 0 0 r
F P
0 g
s
.3429 .24531 m .35044 .23936 L .36324 .24842 L p 0 1 0 r
F P
0 g
s
.35044 .23936 m .3429 .24531 L .33018 .23549 L p 0 1 0 r
F P
0 g
s
.34691 .19858 m .35472 .18849 L .36764 .19516 L p 0 0 1 r
F P
0 g
s
.35472 .18849 m .34691 .19858 L .33395 .19193 L p 0 0 1 r
F P
0 g
s
.40125 .19838 m .40927 .18829 L .42206 .19496 L p 0 0 1 r
F P
0 g
s
.40927 .18829 m .40125 .19838 L .38843 .19173 L p 0 0 1 r
F P
0 g
s
.46383 .18809 m .4556 .19818 L .44292 .19153 L p 0 0 1 r
F P
0 g
s
.42236 .26959 m .43049 .25867 L .44326 .26302 L p 0 1 0 r
F P
0 g
s
.4515 .24978 m .44326 .26302 L .43049 .25867 L p 0 1 0 r
F P
0 g
s
.50996 .19798 m .51839 .18789 L .53091 .19456 L p 0 0 1 r
F P
0 g
s
.51839 .18789 m .50996 .19798 L .49741 .19133 L p 0 0 1 r
F P
0 g
s
.43049 .25867 m .42236 .26959 L .40957 .26355 L p 0 1 0 r
F P
0 g
s
.42613 .14647 m .43415 .14007 L .44683 .15074 L p 1 0 0 r
F P
0 g
s
.43415 .14007 m .42613 .14647 L .41345 .13744 L p 1 0 0 r
F P
0 g
s
.52299 .23338 m .5143 .23155 L .50166 .21661 L p 1 0 0 r
F P
0 g
s
.50166 .21661 m .5102 .21703 L .52299 .23338 L p 1 0 0 r
F P
0 g
s
.33018 .23549 m .33763 .22988 L .35044 .23936 L p 0 1 0 r
F P
0 g
s
.33763 .22988 m .33018 .23549 L .31746 .22538 L p 0 1 0 r
F P
0 g
s
.33818 .14226 m .34612 .12991 L .35914 .13555 L p 1 0 0 r
F P
0 g
s
.35914 .13555 m .36705 .12434 L .37996 .13099 L p 1 0 0 r
F P
0 g
s
.36705 .12434 m .35914 .13555 L .34612 .12991 L p 1 0 0 r
F P
0 g
s
.38883 .26505 m .39674 .2568 L .40957 .26355 L p 0 1 0 r
F P
0 g
s
.39674 .2568 m .38883 .26505 L .37604 .257 L p 0 1 0 r
F P
0 g
s
.31324 .19536 m .32093 .18525 L .33395 .19193 L p 0 0 1 r
F P
0 g
s
.60269 .38762 m .6119 .40447 L .61249 .40684 L p 1 0 0 r
F P
0 g
s
.60991 .39922 m .6119 .40447 L .60269 .38762 L p 1 0 0 r
F P
0 g
s
.60269 .38762 m .60871 .39453 L .60991 .39922 L p 1 0 0 r
F P
0 g
s
.36764 .19516 m .37554 .18505 L .38843 .19173 L p 0 0 1 r
F P
0 g
s
.37554 .18505 m .36764 .19516 L .35472 .18849 L p 0 0 1 r
F P
0 g
s
.42206 .19496 m .43017 .18485 L .44292 .19153 L p 0 0 1 r
F P
0 g
s
.43017 .18485 m .42206 .19496 L .40927 .18829 L p 0 0 1 r
F P
0 g
s
.31746 .22538 m .32481 .22003 L .33763 .22988 L p 0 1 0 r
F P
0 g
s
.32481 .22003 m .31746 .22538 L .30475 .21503 L p 0 1 0 r
F P
0 g
s
.37996 .13099 m .38788 .12115 L .4007 .12902 L p 1 0 0 r
F P
0 g
s
.38788 .12115 m .37996 .13099 L .36705 .12434 L p 1 0 0 r
F P
0 g
s
.41345 .13744 m .42143 .13011 L .43415 .14007 L p 1 0 0 r
F P
0 g
s
.42143 .13011 m .41345 .13744 L .4007 .12902 L p 1 0 0 r
F P
0 g
s
.30475 .21503 m .312 .20988 L .32481 .22003 L p 0 1 0 r
F P
0 g
s
.53586 .25095 m .527 .24763 L .5143 .23155 L p 1 0 0 r
F P
0 g
s
.5143 .23155 m .52299 .23338 L .53586 .25095 L p 1 0 0 r
F P
0 g
s
.43049 .25867 m .4387 .24644 L .4515 .24978 L p 0 1 0 r
F P
0 g
s
.45979 .235 m .4515 .24978 L .4387 .24644 L p 0 1 0 r
F P
0 g
s
.33395 .19193 m .34174 .18179 L .35472 .18849 L p 0 0 1 r
F P
0 g
s
.34174 .18179 m .33395 .19193 L .32093 .18525 L p 0 0 1 r
F P
0 g
s
.38843 .19173 m .39642 .18159 L .40927 .18829 L p 0 0 1 r
F P
0 g
s
.39642 .18159 m .38843 .19173 L .37554 .18505 L p 0 0 1 r
F P
0 g
s
.44292 .19153 m .45111 .18139 L .46383 .18809 L p 0 0 1 r
F P
0 g
s
.45111 .18139 m .44292 .19153 L .43017 .18485 L p 0 0 1 r
F P
0 g
s
.49741 .19133 m .50582 .18119 L .51839 .18789 L p 0 0 1 r
F P
0 g
s
.37604 .257 m .38388 .24939 L .39674 .2568 L p 0 1 0 r
F P
0 g
s
.38388 .24939 m .37604 .257 L .36324 .24842 L p 0 1 0 r
F P
0 g
s
.57889 .32517 m .56939 .31706 L .55645 .29727 L p 1 0 0 r
F P
0 g
s
.55645 .29727 m .5657 .30358 L .57889 .32517 L p 1 0 0 r
F P
0 g
s
.40957 .26355 m .41765 .2535 L .43049 .25867 L p 0 1 0 r
F P
0 g
s
.41765 .2535 m .40957 .26355 L .39674 .2568 L p 0 1 0 r
F P
0 g
s
.60243 .37603 m .60402 .38005 L p .58605 .35169 L 1 0 0 r
F P
0 g
s
.60402 .38005 m .59925 .37447 L .58605 .35169 L p 1 0 0 r
F P
0 g
s
.58605 .35169 m .59578 .36141 L p .60243 .37603 L 1 0 0 r
F P
0 g
s
.4007 .12902 m .40866 .12083 L .42143 .13011 L p 1 0 0 r
F P
0 g
s
.40866 .12083 m .4007 .12902 L .38788 .12115 L p 1 0 0 r
F P
0 g
s
.4387 .24644 m .43049 .25867 L .41765 .2535 L p 0 1 0 r
F P
0 g
s
.35472 .18849 m .36259 .17833 L .37554 .18505 L p 0 0 1 r
F P
0 g
s
.36259 .17833 m .35472 .18849 L .34174 .18179 L p 0 0 1 r
F P
0 g
s
.4387 .24644 m .44699 .23274 L .45979 .235 L p 0 1 0 r
F P
0 g
s
.46811 .21855 m .45979 .235 L .44699 .23274 L p 0 1 0 r
F P
0 g
s
.40927 .18829 m .41735 .17813 L .43017 .18485 L p 0 0 1 r
F P
0 g
s
.41735 .17813 m .40927 .18829 L .39642 .18159 L p 0 0 1 r
F P
0 g
s
.34612 .12991 m .35405 .11811 L .36705 .12434 L p 1 0 0 r
F P
0 g
s
.36705 .12434 m .37498 .11381 L .38788 .12115 L p 1 0 0 r
F P
0 g
s
.37498 .11381 m .36705 .12434 L .35405 .11811 L p 1 0 0 r
F P
0 g
s
.47646 .2003 m .46811 .21855 L .45532 .21745 L p 0 1 0 r
F P
0 g
s
.45532 .21745 m .4637 .20044 L .47646 .2003 L p 0 1 0 r
F P
0 g
s
.36324 .24842 m .37099 .24137 L .38388 .24939 L p 0 1 0 r
F P
0 g
s
.37099 .24137 m .36324 .24842 L .35044 .23936 L p 0 1 0 r
F P
0 g
s
.54884 .26983 m .53978 .26492 L .527 .24763 L p 1 0 0 r
F P
0 g
s
.527 .24763 m .53586 .25095 L .54884 .26983 L p 1 0 0 r
F P
0 g
s
.44699 .23274 m .45532 .21745 L .46811 .21855 L p 0 1 0 r
F P
0 g
s
.32093 .18525 m .32868 .17506 L .34174 .18179 L p 0 0 1 r
F P
0 g
s
.37554 .18505 m .38351 .17486 L .39642 .18159 L p 0 0 1 r
F P
0 g
s
.38351 .17486 m .37554 .18505 L .36259 .17833 L p 0 0 1 r
F P
0 g
s
.43017 .18485 m .43834 .17466 L .45111 .18139 L p 0 0 1 r
F P
0 g
s
.43834 .17466 m .43017 .18485 L .41735 .17813 L p 0 0 1 r
F P
0 g
s
.35044 .23936 m .3581 .23281 L .37099 .24137 L p 0 1 0 r
F P
0 g
s
.3581 .23281 m .35044 .23936 L .33763 .22988 L p 0 1 0 r
F P
0 g
s
.39674 .2568 m .40476 .24754 L .41765 .2535 L p 0 1 0 r
F P
0 g
s
.40476 .24754 m .39674 .2568 L .38388 .24939 L p 0 1 0 r
F P
0 g
s
.38788 .12115 m .39583 .11215 L .40866 .12083 L p 1 0 0 r
F P
0 g
s
.39583 .11215 m .38788 .12115 L .37498 .11381 L p 1 0 0 r
F P
0 g
s
.46772 .15908 m .45949 .16218 L .44683 .15074 L p 1 0 0 r
F P
0 g
s
.44683 .15074 m .45498 .14652 L .46772 .15908 L p 1 0 0 r
F P
0 g
s
.45498 .14652 m .44683 .15074 L .43415 .14007 L p 1 0 0 r
F P
0 g
s
.34174 .18179 m .34958 .17158 L .36259 .17833 L p 0 0 1 r
F P
0 g
s
.34958 .17158 m .34174 .18179 L .32868 .17506 L p 0 0 1 r
F P
0 g
s
.39642 .18159 m .40447 .17138 L .41735 .17813 L p 0 0 1 r
F P
0 g
s
.40447 .17138 m .39642 .18159 L .38351 .17486 L p 0 0 1 r
F P
0 g
s
.43415 .14007 m .44224 .1348 L .45498 .14652 L p 1 0 0 r
F P
0 g
s
.44224 .1348 m .43415 .14007 L .42143 .13011 L p 1 0 0 r
F P
0 g
s
.41765 .2535 m .42583 .24221 L .4387 .24644 L p 0 1 0 r
F P
0 g
s
.44699 .23274 m .4387 .24644 L .42583 .24221 L p 0 1 0 r
F P
0 g
s
.45938 .17117 m .45111 .18139 L .43834 .17466 L p 0 0 1 r
F P
0 g
s
.59227 .34843 m .58249 .3384 L .56939 .31706 L p 1 0 0 r
F P
0 g
s
.56939 .31706 m .57889 .32517 L .59227 .34843 L p 1 0 0 r
F P
0 g
s
.33763 .22988 m .34519 .22376 L .3581 .23281 L p 0 1 0 r
F P
0 g
s
.34519 .22376 m .33763 .22988 L .32481 .22003 L p 0 1 0 r
F P
0 g
s
.50604 .20249 m .49748 .20182 L .4848 .18766 L p 1 0 0 r
F P
0 g
s
.4848 .18766 m .49323 .187 L .50604 .20249 L p 1 0 0 r
F P
0 g
s
.42583 .24221 m .41765 .2535 L .40476 .24754 L p 0 1 0 r
F P
0 g
s
.35405 .11811 m .36199 .10693 L .37498 .11381 L p 1 0 0 r
F P
0 g
s
.56196 .29015 m .55267 .28354 L .53978 .26492 L p 1 0 0 r
F P
0 g
s
.53978 .26492 m .54884 .26983 L .56196 .29015 L p 1 0 0 r
F P
0 g
s
.42143 .13011 m .42947 .12385 L .44224 .1348 L p 1 0 0 r
F P
0 g
s
.42947 .12385 m .42143 .13011 L .40866 .12083 L p 1 0 0 r
F P
0 g
s
.36259 .17833 m .37053 .16809 L .38351 .17486 L p 0 0 1 r
F P
0 g
s
.37053 .16809 m .36259 .17833 L .34958 .17158 L p 0 0 1 r
F P
0 g
s
.32481 .22003 m .33228 .21427 L .34519 .22376 L p 0 1 0 r
F P
0 g
s
.33228 .21427 m .32481 .22003 L .312 .20988 L p 0 1 0 r
F P
0 g
s
.41735 .17813 m .4255 .16789 L .43834 .17466 L p 0 0 1 r
F P
0 g
s
.4255 .16789 m .41735 .17813 L .40447 .17138 L p 0 0 1 r
F P
0 g
s
.38388 .24939 m .39183 .24086 L .40476 .24754 L p 0 1 0 r
F P
0 g
s
.39183 .24086 m .38388 .24939 L .37099 .24137 L p 0 1 0 r
F P
0 g
s
.37498 .11381 m .38293 .10405 L .39583 .11215 L p 1 0 0 r
F P
0 g
s
.38293 .10405 m .37498 .11381 L .36199 .10693 L p 1 0 0 r
F P
0 g
s
.51892 .21913 m .5102 .21703 L .49748 .20182 L p 1 0 0 r
F P
0 g
s
.49748 .20182 m .50604 .20249 L .51892 .21913 L p 1 0 0 r
F P
0 g
s
.312 .20988 m .31937 .2044 L .33228 .21427 L p 0 1 0 r
F P
0 g
s
.42583 .24221 m .43409 .22955 L .44699 .23274 L p 0 1 0 r
F P
0 g
s
.45532 .21745 m .44699 .23274 L .43409 .22955 L p 0 1 0 r
F P
0 g
s
.40866 .12083 m .41667 .11363 L .42947 .12385 L p 1 0 0 r
F P
0 g
s
.41667 .11363 m .40866 .12083 L .39583 .11215 L p 1 0 0 r
F P
0 g
s
.59925 .37447 m .60666 .38804 L .60755 .39152 L p 1 0 0 r
F P
0 g
s
.60501 .3838 m .60666 .38804 L .59925 .37447 L p 1 0 0 r
F P
0 g
s
.59925 .37447 m .60402 .38005 L .60501 .3838 L p 1 0 0 r
F P
0 g
s
.32868 .17506 m .3365 .16479 L .34958 .17158 L p 0 0 1 r
F P
0 g
s
.38351 .17486 m .39153 .16459 L .40447 .17138 L p 0 0 1 r
F P
0 g
s
.39153 .16459 m .38351 .17486 L .37053 .16809 L p 0 0 1 r
F P
0 g
s
.43834 .17466 m .44657 .16439 L .45938 .17117 L p 0 0 1 r
F P
0 g
s
.44657 .16439 m .43834 .17466 L .4255 .16789 L p 0 0 1 r
F P
0 g
s
.37099 .24137 m .37886 .23351 L .39183 .24086 L p 0 1 0 r
F P
0 g
s
.37886 .23351 m .37099 .24137 L .3581 .23281 L p 0 1 0 r
F P
0 g
s
.4721 .18157 m .4637 .20044 L .45081 .19954 L p 0 1 0 r
F P
0 g
s
.45081 .19954 m .45924 .18192 L .4721 .18157 L p 0 1 0 r
F P
0 g
s
.53188 .23698 m .52299 .23338 L .5102 .21703 L p 1 0 0 r
F P
0 g
s
.5102 .21703 m .51892 .21913 L .53188 .23698 L p 1 0 0 r
F P
0 g
s
.43409 .22955 m .44242 .21537 L .45532 .21745 L p 0 1 0 r
F P
0 g
s
.4637 .20044 m .45532 .21745 L .44242 .21537 L p 0 1 0 r
F P
0 g
s
.40476 .24754 m .41289 .23714 L .42583 .24221 L p 0 1 0 r
F P
0 g
s
.41289 .23714 m .40476 .24754 L .39183 .24086 L p 0 1 0 r
F P
0 g
s
.44242 .21537 m .45081 .19954 L .4637 .20044 L p 0 1 0 r
F P
0 g
s
.43409 .22955 m .42583 .24221 L .41289 .23714 L p 0 1 0 r
F P
0 g
s
.34958 .17158 m .35748 .16129 L .37053 .16809 L p 0 0 1 r
F P
0 g
s
.35748 .16129 m .34958 .17158 L .3365 .16479 L p 0 0 1 r
F P
0 g
s
.40447 .17138 m .41259 .16108 L .4255 .16789 L p 0 0 1 r
F P
0 g
s
.41259 .16108 m .40447 .17138 L .39153 .16459 L p 0 0 1 r
F P
0 g
s
.39583 .11215 m .40381 .10408 L .41667 .11363 L p 1 0 0 r
F P
0 g
s
.40381 .10408 m .39583 .11215 L .38293 .10405 L p 1 0 0 r
F P
0 g
s
.4677 .16088 m .45938 .17117 L .44657 .16439 L p 0 0 1 r
F P
0 g
s
.57524 .31201 m .5657 .30358 L .55267 .28354 L p 1 0 0 r
F P
0 g
s
.55267 .28354 m .56196 .29015 L .57524 .31201 L p 1 0 0 r
F P
0 g
s
.36199 .10693 m .36994 .09646 L .38293 .10405 L p 1 0 0 r
F P
0 g
s
.3581 .23281 m .36588 .22554 L .37886 .23351 L p 0 1 0 r
F P
0 g
s
.36588 .22554 m .3581 .23281 L .34519 .22376 L p 0 1 0 r
F P
0 g
s
.59712 .36035 m .59919 .3655 L p .58249 .3384 L 1 0 0 r
F P
0 g
s
.59919 .3655 m .59578 .36141 L .58249 .3384 L p 1 0 0 r
F P
0 g
s
.58249 .3384 m .59227 .34843 L p .59712 .36035 L 1 0 0 r
F P
0 g
s
.37053 .16809 m .37852 .15777 L .39153 .16459 L p 0 0 1 r
F P
0 g
s
.37852 .15777 m .37053 .16809 L .35748 .16129 L p 0 0 1 r
F P
0 g
s
.4255 .16789 m .4337 .15757 L .44657 .16439 L p 0 0 1 r
F P
0 g
s
.4337 .15757 m .4255 .16789 L .41259 .16108 L p 0 0 1 r
F P
0 g
s
.54496 .25617 m .53586 .25095 L .52299 .23338 L p 1 0 0 r
F P
0 g
s
.52299 .23338 m .53188 .23698 L .54496 .25617 L p 1 0 0 r
F P
0 g
s
.38293 .10405 m .39089 .09515 L .40381 .10408 L p 1 0 0 r
F P
0 g
s
.39089 .09515 m .38293 .10405 L .36994 .09646 L p 1 0 0 r
F P
0 g
s
.39183 .24086 m .39989 .23128 L .41289 .23714 L p 0 1 0 r
F P
0 g
s
.39989 .23128 m .39183 .24086 L .37886 .23351 L p 0 1 0 r
F P
0 g
s
.34519 .22376 m .35288 .217 L .36588 .22554 L p 0 1 0 r
F P
0 g
s
.35288 .217 m .34519 .22376 L .33228 .21427 L p 0 1 0 r
F P
0 g
s
.41289 .23714 m .42111 .22545 L .43409 .22955 L p 0 1 0 r
F P
0 g
s
.44242 .21537 m .43409 .22955 L .42111 .22545 L p 0 1 0 r
F P
0 g
s
.3365 .16479 m .34437 .15445 L .35748 .16129 L p 0 0 1 r
F P
0 g
s
.39153 .16459 m .39962 .15424 L .41259 .16108 L p 0 0 1 r
F P
0 g
s
.39962 .15424 m .39153 .16459 L .37852 .15777 L p 0 0 1 r
F P
0 g
s
.44657 .16439 m .45487 .15404 L .4677 .16088 L p 0 0 1 r
F P
0 g
s
.45487 .15404 m .44657 .16439 L .4337 .15757 L p 0 0 1 r
F P
0 g
s
.42111 .22545 m .41289 .23714 L .39989 .23128 L p 0 1 0 r
F P
0 g
s
.33228 .21427 m .33987 .20796 L .35288 .217 L p 0 1 0 r
F P
0 g
s
.33987 .20796 m .33228 .21427 L .31937 .2044 L p 0 1 0 r
F P
0 g
s
.35748 .16129 m .36545 .15091 L .37852 .15777 L p 0 0 1 r
F P
0 g
s
.36545 .15091 m .35748 .16129 L .34437 .15445 L p 0 0 1 r
F P
0 g
s
.41259 .16108 m .42076 .15071 L .4337 .15757 L p 0 0 1 r
F P
0 g
s
.42076 .15071 m .41259 .16108 L .39962 .15424 L p 0 0 1 r
F P
0 g
s
.58872 .33555 m .57889 .32517 L .5657 .30358 L p 1 0 0 r
F P
0 g
s
.5657 .30358 m .57524 .31201 L .58872 .33555 L p 1 0 0 r
F P
0 g
s
.36994 .09646 m .3779 .08678 L .39089 .09515 L p 1 0 0 r
F P
0 g
s
.37886 .23351 m .38685 .22468 L .39989 .23128 L p 0 1 0 r
F P
0 g
s
.38685 .22468 m .37886 .23351 L .36588 .22554 L p 0 1 0 r
F P
0 g
s
.42111 .22545 m .42942 .21233 L .44242 .21537 L p 0 1 0 r
F P
0 g
s
.45081 .19954 m .44242 .21537 L .42942 .21233 L p 0 1 0 r
F P
0 g
s
.31937 .2044 m .32685 .19848 L .33987 .20796 L p 0 1 0 r
F P
0 g
s
.55817 .27678 m .54884 .26983 L .53586 .25095 L p 1 0 0 r
F P
0 g
s
.53586 .25095 m .54496 .25617 L .55817 .27678 L p 1 0 0 r
F P
0 g
s
.46769 .16238 m .45924 .18192 L .44625 .18122 L p 0 1 0 r
F P
0 g
s
.44625 .18122 m .45473 .16296 L .46769 .16238 L p 0 1 0 r
F P
0 g
s
.37852 .15777 m .38658 .14737 L .39962 .15424 L p 0 0 1 r
F P
0 g
s
.38658 .14737 m .37852 .15777 L .36545 .15091 L p 0 0 1 r
F P
0 g
s
.4337 .15757 m .44197 .14717 L .45487 .15404 L p 0 0 1 r
F P
0 g
s
.44197 .14717 m .4337 .15757 L .42076 .15071 L p 0 0 1 r
F P
0 g
s
.42942 .21233 m .4378 .19763 L .45081 .19954 L p 0 1 0 r
F P
0 g
s
.45924 .18192 m .45081 .19954 L .4378 .19763 L p 0 1 0 r
F P
0 g
s
.4378 .19763 m .44625 .18122 L .45924 .18192 L p 0 1 0 r
F P
0 g
s
.39989 .23128 m .40806 .2205 L .42111 .22545 L p 0 1 0 r
F P
0 g
s
.40806 .2205 m .39989 .23128 L .38685 .22468 L p 0 1 0 r
F P
0 g
s
.36588 .22554 m .37378 .21739 L .38685 .22468 L p 0 1 0 r
F P
0 g
s
.37378 .21739 m .36588 .22554 L .35288 .217 L p 0 1 0 r
F P
0 g
s
.59578 .36141 m .60116 .37129 L .60243 .37603 L p 1 0 0 r
F P
0 g
s
.59994 .36819 m .60116 .37129 L .59578 .36141 L p 1 0 0 r
F P
0 g
s
.59578 .36141 m .59919 .3655 L .59994 .36819 L p 1 0 0 r
F P
0 g
s
.42942 .21233 m .42111 .22545 L .40806 .2205 L p 0 1 0 r
F P
0 g
s
.34437 .15445 m .3523 .14402 L .36545 .15091 L p 0 0 1 r
F P
0 g
s
.39962 .15424 m .40776 .14382 L .42076 .15071 L p 0 0 1 r
F P
0 g
s
.40776 .14382 m .39962 .15424 L .38658 .14737 L p 0 0 1 r
F P
0 g
s
.36545 .15091 m .37347 .14046 L .38658 .14737 L p 0 0 1 r
F P
0 g
s
.37347 .14046 m .36545 .15091 L .3523 .14402 L p 0 0 1 r
F P
0 g
s
.42076 .15071 m .429 .14026 L .44197 .14717 L p 0 0 1 r
F P
0 g
s
.429 .14026 m .42076 .15071 L .40776 .14382 L p 0 0 1 r
F P
0 g
s
.35288 .217 m .36069 .20948 L .37378 .21739 L p 0 1 0 r
F P
0 g
s
.36069 .20948 m .35288 .217 L .33987 .20796 L p 0 1 0 r
F P
0 g
s
.57155 .29894 m .56196 .29015 L .54884 .26983 L p 1 0 0 r
F P
0 g
s
.54884 .26983 m .55817 .27678 L .57155 .29894 L p 1 0 0 r
F P
0 g
s
.40806 .2205 m .41633 .20838 L .42942 .21233 L p 0 1 0 r
F P
0 g
s
.4378 .19763 m .42942 .21233 L .41633 .20838 L p 0 1 0 r
F P
0 g
s
.59162 .3445 m .59424 .35084 L p .57889 .32517 L 1 0 0 r
F P
0 g
s
.59424 .35084 m .59227 .34843 L .57889 .32517 L p 1 0 0 r
F P
0 g
s
.57889 .32517 m .58872 .33555 L p .59162 .3445 L 1 0 0 r
F P
0 g
s
.38685 .22468 m .39496 .21475 L .40806 .2205 L p 0 1 0 r
F P
0 g
s
.39496 .21475 m .38685 .22468 L .37378 .21739 L p 0 1 0 r
F P
0 g
s
.38658 .14737 m .39469 .13689 L .40776 .14382 L p 0 0 1 r
F P
0 g
s
.39469 .13689 m .38658 .14737 L .37347 .14046 L p 0 0 1 r
F P
0 g
s
.33987 .20796 m .34758 .20098 L .36069 .20948 L p 0 1 0 r
F P
0 g
s
.34758 .20098 m .33987 .20796 L .32685 .19848 L p 0 1 0 r
F P
0 g
s
.41633 .20838 m .40806 .2205 L .39496 .21475 L p 0 1 0 r
F P
0 g
s
.3523 .14402 m .3603 .13352 L .37347 .14046 L p 0 0 1 r
F P
0 g
s
.40776 .14382 m .41597 .13331 L .429 .14026 L p 0 0 1 r
F P
0 g
s
.41597 .13331 m .40776 .14382 L .39469 .13689 L p 0 0 1 r
F P
0 g
s
.41633 .20838 m .42469 .19477 L .4378 .19763 L p 0 1 0 r
F P
0 g
s
.44625 .18122 m .4378 .19763 L .42469 .19477 L p 0 1 0 r
F P
0 g
s
.32685 .19848 m .33447 .19197 L .34758 .20098 L p 0 1 0 r
F P
0 g
s
.37378 .21739 m .38181 .20824 L .39496 .21475 L p 0 1 0 r
F P
0 g
s
.38181 .20824 m .37378 .21739 L .36069 .20948 L p 0 1 0 r
F P
0 g
s
.45473 .16296 m .44625 .18122 L .43313 .17952 L p 0 1 0 r
F P
0 g
s
.43313 .17952 m .44164 .16249 L .45473 .16296 L p 0 1 0 r
F P
0 g
s
.42469 .19477 m .43313 .17952 L .44625 .18122 L p 0 1 0 r
F P
0 g
s
.37347 .14046 m .38156 .12993 L .39469 .13689 L p 0 0 1 r
F P
0 g
s
.38156 .12993 m .37347 .14046 L .3603 .13352 L p 0 0 1 r
F P
0 g
s
.58338 .32032 m .58383 .32136 L p .56196 .29015 L 1 0 0 r
F P
0 g
s
.58383 .32136 m .57524 .31201 L .56196 .29015 L p 1 0 0 r
F P
0 g
s
.56196 .29015 m .57155 .29894 L p .58338 .32032 L 1 0 0 r
F P
0 g
s
.39496 .21475 m .40318 .20356 L .41633 .20838 L p 0 1 0 r
F P
0 g
s
.42469 .19477 m .41633 .20838 L .40318 .20356 L p 0 1 0 r
F P
0 g
s
.40318 .20356 m .39496 .21475 L .38181 .20824 L p 0 1 0 r
F P
0 g
s
.39469 .13689 m .40288 .12633 L .41597 .13331 L p 0 0 1 r
F P
0 g
s
.40288 .12633 m .39469 .13689 L .38156 .12993 L p 0 0 1 r
F P
0 g
s
.59227 .34843 m .59542 .35423 L .59712 .36035 L p 1 0 0 r
F P
0 g
s
.36069 .20948 m .36863 .20104 L .38181 .20824 L p 0 1 0 r
F P
0 g
s
.36863 .20104 m .36069 .20948 L .34758 .20098 L p 0 1 0 r
F P
0 g
s
.59468 .35241 m .59542 .35423 L .59227 .34843 L p 1 0 0 r
F P
0 g
s
.59227 .34843 m .59424 .35084 L .59468 .35241 L p 1 0 0 r
F P
0 g
s
.3603 .13352 m .36836 .12293 L .38156 .12993 L p 0 0 1 r
F P
0 g
s
.34758 .20098 m .35543 .19318 L .36863 .20104 L p 0 1 0 r
F P
0 g
s
.35543 .19318 m .34758 .20098 L .33447 .19197 L p 0 1 0 r
F P
0 g
s
.40318 .20356 m .4115 .19098 L .42469 .19477 L p 0 1 0 r
F P
0 g
s
.43313 .17952 m .42469 .19477 L .4115 .19098 L p 0 1 0 r
F P
0 g
s
.38156 .12993 m .38971 .11932 L .40288 .12633 L p 0 0 1 r
F P
0 g
s
.38971 .11932 m .38156 .12993 L .36836 .12293 L p 0 0 1 r
F P
0 g
s
.38181 .20824 m .38996 .19793 L .40318 .20356 L p 0 1 0 r
F P
0 g
s
.38996 .19793 m .38181 .20824 L .36863 .20104 L p 0 1 0 r
F P
0 g
s
.4115 .19098 m .40318 .20356 L .38996 .19793 L p 0 1 0 r
F P
0 g
s
.33447 .19197 m .34222 .18474 L .35543 .19318 L p 0 1 0 r
F P
0 g
s
.4115 .19098 m .41992 .17684 L .43313 .17952 L p 0 1 0 r
F P
0 g
s
.44164 .16249 m .43313 .17952 L .41992 .17684 L p 0 1 0 r
F P
0 g
s
.58594 .32846 m .58915 .33609 L p .57524 .31201 L 1 0 0 r
F P
0 g
s
.58915 .33609 m .58872 .33555 L .57524 .31201 L p 1 0 0 r
F P
0 g
s
.57524 .31201 m .58383 .32136 L .58594 .32846 L p 1 0 0 r
F P
0 g
s
.41992 .17684 m .42841 .161 L .44164 .16249 L p 0 1 0 r
F P
0 g
s
.36863 .20104 m .37671 .19153 L .38996 .19793 L p 0 1 0 r
F P
0 g
s
.37671 .19153 m .36863 .20104 L .35543 .19318 L p 0 1 0 r
F P
0 g
s
.36836 .12293 m .37648 .11226 L .38971 .11932 L p 0 0 1 r
F P
0 g
s
.38996 .19793 m .39823 .18631 L .4115 .19098 L p 0 1 0 r
F P
0 g
s
.41992 .17684 m .4115 .19098 L .39823 .18631 L p 0 1 0 r
F P
0 g
s
.58872 .33555 m .58942 .33684 L .59162 .3445 L p 1 0 0 r
F P
0 g
s
.39823 .18631 m .38996 .19793 L .37671 .19153 L p 0 1 0 r
F P
0 g
s
.35543 .19318 m .36342 .18442 L .37671 .19153 L p 0 1 0 r
F P
0 g
s
.36342 .18442 m .35543 .19318 L .34222 .18474 L p 0 1 0 r
F P
0 g
s
.39823 .18631 m .40661 .17323 L .41992 .17684 L p 0 1 0 r
F P
0 g
s
.42841 .161 m .41992 .17684 L .40661 .17323 L p 0 1 0 r
F P
0 g
s
.34222 .18474 m .3501 .17665 L .36342 .18442 L p 0 1 0 r
F P
0 g
s
.58925 .33643 m .58942 .33684 L .58872 .33555 L p 1 0 0 r
F P
0 g
s
.58872 .33555 m .58915 .33609 L .58925 .33643 L p 1 0 0 r
F P
0 g
s
.37671 .19153 m .38491 .18082 L .39823 .18631 L p 0 1 0 r
F P
0 g
s
.38491 .18082 m .37671 .19153 L .36342 .18442 L p 0 1 0 r
F P
0 g
s
.40661 .17323 m .41509 .15853 L .42841 .161 L p 0 1 0 r
F P
0 g
s
.40661 .17323 m .39823 .18631 L .38491 .18082 L p 0 1 0 r
F P
0 g
s
.36342 .18442 m .37154 .17454 L .38491 .18082 L p 0 1 0 r
F P
0 g
s
.37154 .17454 m .36342 .18442 L .3501 .17665 L p 0 1 0 r
F P
0 g
s
.57155 .29894 m .583 .31903 L .58338 .32032 L p 1 0 0 r
F P
0 g
s
.38491 .18082 m .39323 .16873 L .40661 .17323 L p 0 1 0 r
F P
0 g
s
.41509 .15853 m .40661 .17323 L .39323 .16873 L p 0 1 0 r
F P
0 g
s
.39323 .16873 m .38491 .18082 L .37154 .17454 L p 0 1 0 r
F P
0 g
s
.3501 .17665 m .35813 .16753 L .37154 .17454 L p 0 1 0 r
F P
0 g
s
.39323 .16873 m .40166 .15511 L .41509 .15853 L p 0 1 0 r
F P
0 g
s
.37154 .17454 m .37979 .16338 L .39323 .16873 L p 0 1 0 r
F P
0 g
s
.37979 .16338 m .37154 .17454 L .35813 .16753 L p 0 1 0 r
F P
0 g
s
.40166 .15511 m .39323 .16873 L .37979 .16338 L p 0 1 0 r
F P
0 g
s
.35813 .16753 m .3663 .15724 L .37979 .16338 L p 0 1 0 r
F P
0 g
s
.37979 .16338 m .38817 .15079 L .40166 .15511 L p 0 1 0 r
F P
0 g
s
.38817 .15079 m .37979 .16338 L .3663 .15724 L p 0 1 0 r
F P
0 g
s
.3663 .15724 m .37461 .14561 L .38817 .15079 L p 0 1 0 r
F P
0 g
s
.25 Mabswid
.37558 0 m
.3643 .18795 L
s
.3643 .18795 m
0 .65613 L
s
0 .65613 m
.03807 .46179 L
s
.03807 .46179 m
.37558 0 L
s
.37558 0 m
.3643 .18795 L
s
.3643 .18795 m
1 .51659 L
s
1 .51659 m
.95717 .32255 L
s
.95717 .32255 m
.37558 0 L
s
.37558 0 m
.95717 .32255 L
s
.39114 .00863 m
.38731 .01381 L
s
[(0)] .39879 -0.00173 -0.73856 1 Mshowa
.62794 .13996 m
.62374 .14484 L
s
[(0.02)] .63635 .1302 -0.86142 1 Mshowa
.84387 .25972 m
.83935 .26431 L
s
[(0.04)] .85291 .25054 -0.98428 1 Mshowa
.125 Mabswid
.45246 .04264 m
.4501 .0457 L
s
.51234 .07585 m
.50992 .07887 L
s
.57081 .10828 m
.56834 .11125 L
s
.68377 .17093 m
.6812 .17381 L
s
.73834 .20119 m
.73572 .20403 L
s
.79169 .23078 m
.78903 .23358 L
s
.89491 .28802 m
.89216 .29074 L
s
.94485 .31572 m
.94206 .31839 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 254.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000oR000`400?l00000o`00003ooooooolQ
ooooo`00Koooool2o`000:oooooo001^ooooo`04o`000?ooooooooooo`000:kooooo001^ooooo`04
o`000?ooooooooooo`000:kooooo001^ooooo`04o`000?ooooooooooo`000:kooooo001^ooooo`04
o`000?ooooooooooo`000:kooooo001^ooooo`04o`000?ooooooooooo`000:kooooo001_ooooo`;o
0000[oooool00?oooooo8Oooool00?oooooo8Oooool006Oooooo0_l0002gooooo`00Ioooool01?l0
003oooooo`000?l0002eooooo`00I_ooool2o`0000?ooooo0_l0002cooooo`00I?ooool2o`000005
ooooool0003oooooooooool000000_ooool00ol0003oooooooooo`2`ooooo`00I?ooool2o`000003
ooooool0003ooooo00Gooooo0_l0002`ooooo`00I?ooool01?l0003oooooooooool00008ooooo`;o
0000[_ooool006?ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o0000[?ooool006;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`;o0000Z_ooool006;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:Oooooo001Q
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool2o`000:Oooooo001Poooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool2o`000:Gooooo001Oooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool2o`000:?ooooo001Oooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04_ooool01?l0003oooooo`000?l0002Qooooo`00
G_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0_l0002Oooooo`00GOoo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0W?oo
ool005cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`;o0000W?ooool0
05cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`;o0000V_ooool005[o
oooo0_l0000:ooooo`03o`000?oooooooooo01gooooo0_l0002Hooooo`00F_ooool2o`0000[ooooo
00?o0000ooooooooool07oooool2o`0009Kooooo001Iooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`2Cooooo`00FOooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02;ooooo0ol0002Booooo`00F?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02?ooooo0ol0002Aooooo`00Eoooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo02Kooooo0_l0002?ooooo`00Eoooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02Sooooo0_l0002=ooooo`00=oooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0ol0000:ooooo`03o`000?oooooooooo00gooooo1?l0000Yooooo`;o0000Rooo
ool003Kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03_ooool01Ol0003oo`00ool00?oo003o000002[o
oooo00?o0000ooooooooool0R?ooool002oooooo1Ol00002ooooo`04o`000?ooooooooooo`0000So
oooo00Go0000oooooooooooo0000ooooo`05o`0000Sooooo00?o0000ooooooooool03_ooool00ol0
003oo`00ool00003ool000;o0000:Oooool2o`0008Sooooo000fooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03_ooool01_l0003oo`00o`000?l0003oo`00o`0000;oo`000_l0000Yooooo`;o
00005Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol0001Looooo`00
=_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`0>ooooo`;o00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo02Sooooo0_l0000Booooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0001Looooo`00=_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l00007ooooo`03o`000?oooooooooo00ko
oooo00?o0000ool00?l000000ooo00001Ol0003oo`00o`000?oo003o000000;oo`0000?o0000oooo
ooooool0:Oooool2o`00013ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo05cooooo000gooooo`;o00002_ooool2o`0000Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`06o`000?oo003o0000o`000?oo003o0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oooooooooo02Sooooo00?o0000ooooool00000
3oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0Foooool0053ooooo0_l0000@ooooo`05o`000?oo003oo`00o`000?oo00000ol00002ool0
0003o`000?oo003o000000?oo`000_l0000[ooooo`;o00003Oooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`1Jooooo`00D?oo
ool00ol0003oooooo`00000>ooooo`04o`000?oo003oo`00ool000;o00000ol00?l3o`0000;oo`00
00?o0000ool00?l000000_oo00000ol0003oooooooooo`0Zooooo`;o00002oooool01?l0003ooooo
ooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`1J
ooooo`00Coooool00ol0003oooooooooo`0?ooooo`03o`000?oo003o000000;o00001Ol00?l00ol0
003o003oo`000002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool08_ooool00ol0
003oooooooooo`06ooooo`;o00002_ooool2o`0000[ooooo0_l00003ooooo`?o0000GOooool004ko
oooo00?o0000ooooooooool03oooool00ol0003oo`00ool00002ool00006o`000?l00?oo0000o`00
0?l00?oo00000ol00?l2o`0000;oo`000_l00002ool00003o`000?oooooooooo023ooooo0_l0000:
ooooo`;o0000NOooool004kooooo00?o0000ooooooooool03_ooool00ol0003oo`00ool00002ool0
00;o00000ol00?l00ol0003o003oo`00o`02o`00o`04o`000?l00?oo0000o`0000;oo`0000Co0000
ool00?oo003o00007oooool2o`000003o`3o0?l0003ooooo00_ooooo0_l0001gooooo`00COooool0
0ol0003oooooooooo`0?ooooo`07o`000?oo003o0000ool00?l0003o003oo`000002o`00o`06o`00
0?l00?oo003oo`000?l00?oo00001?l00?l2o`000005ool00?l0003oo`00ool00?l000007Oooool0
1?l0003o0?l0o`000?l0o`02o`0000gooooo00?o0000ooooooooool0M?ooool004cooooo00?o0000
ooooooooool03oooool01?l0003oo`00ool00?oo0002o`000004o`00ool0003o003oo`0000Co003o
00?o0000o`00ool00?l00ol00?l00ol0003o003oo`000002o`000004ool00?l0003o0000o`0001Wo
oooo0_l00002o`3o0003o`000?l0o`3o000000;o00003Oooool2o`0007Cooooo001<ooooo`03o`00
0?oooooooooo00oooooo00Go0000ool00?oo003oo`00o`000002o`00o`;o00001Ol00?l01_l0003o
003oo`000?l0003o003oo`0000Co003o0_l00003ool00003o`000?oooooooooo01Cooooo0_l00000
1ol0o`3o0000o`3o0?l0003o0?l0o`000?l0o`000_l0000?ooooo`;o0000L_ooool004_ooooo00?o
0000ooooooooool03oooool3o`000003ool00?l0003o003o00;o003o0_l000001Ol00?oo0000o`00
0?l00?oo000000Co003o00?o0000o`00ool00?l00_l00?l00ol0003o003oo`00o`02o`0000;oo`00
00?o0000ooooooooool04Oooool2o`0000Go0?l000Ko0000o`3o0?l0003o0000o`3o0?l0000>oooo
o`03o`000?oooooooooo00;o0000L?ooool004[ooooo00?o0000ooooooooool03oooool01Ol0003o
o`00ool00?oo003o000000;o003o00Co0000o`00ool0003o003o1?l00005o`00o`05o`000?l00?oo
0000o`00ool000001?l00?l2o`000003ool00?l0003o0000017ooooo00?o0000o`3o0?l000000_l0
o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000;o0?l00_l0000Booooo`;o0000K_ooool004Wooooo
00?o0000ooooooooool03oooool01Ol0003oo`00ool00?oo003o000000Co003o0ol00003o`3o00Co
000000?o003oo`000?l00?l00_l00?l00ol0003o003oo`00o`03o`00o`06o`000?l00?oo0000o`00
0?oo003o00003_ooool2o`0000;o0?l000Co0000o`3o0?l0o`3o00000_l0o`03o`000004o`3o0?l0
003o0?l0o`0001Cooooo00?o0000ooooooooool0Joooool004Wooooo00?o0000ooooooooool03_oo
ool01Ol0003oo`00ool00?oo003o000000Go003o0_l00004o`3o0003o`000?l0o`3o0?l000Co0000
0_l00?l01_l0003o003oo`000?l0003o003oo`0000Co003o0ol00009ooooo`Co000000Co0?l0o`00
0?l0o`3o00000_l0o`000ol0003o0?l0o`3o0002o`000006o`3o0?l0003o0?l0o`000?l0o`3o0000
5Oooool2o`0006_ooooo0018ooooo`03o`000?oooooooooo00oooooo00?o0000ool00?l000000_l0
00001?l00?oo0000o`000?l00?l2o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0
o`3o0004o`0000;o003o00?o0000o`00ool00?l00_l00?l00ol0003o003oo`00o`02o`0000Gooooo
0ol00002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000_l0o`001_l0003o0?l0o`000?l0003o
0?l0o`0000;o0?l000Co0000o`3o0?l0003o00005_ooool2o`0006Wooooo0017ooooo`03o`000?oo
oooooooo00oooooo00Go0000ool00?oo003oo`00o`000004o`00o`04o`000?l00?oo0000o`3o00;o
000000?o0?l0o`000?l0o`000_l0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l0017o
000000?o0?l0o`000?l0o`001?l0o`001?l0003o0?l0o`3o0?l00002o`3o00;o000000Co0?l0o`00
0?l0o`3o00000_l0o`04o`0001Sooooo0_l0001Wooooo`00A_ooool00ol0003oooooooooo`0@oooo
o`04o`000?oo003oo`00o`0000Go003o0ol00003o`3o00?o00000_l0o`001Ol0003o0?l0o`3o0?l0
o`3o000000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o0005o`000?l0o`3o0?l0o`000?oo
00000ol000000ol0o`3o0000o`3o0002o`3o0007o`000?l0o`3o0?l0o`000?l0o`3o0000o`3o0002
o`0000?o0?l000Co0000o`3o0?l0003o0?l00_l000001?l0o`3o0000o`3o0?l0000Iooooo`;o0000
IOooool004Kooooo00?o0000ooooooooool03oooool01_l0003oo`00o`000?oo003o0000o`00o`;o
000000Go003oo`000?l0003o0?l0o`000003o`3o0003o`000?l0o`3o0?l000Co000000?o0?l0o`00
0?l0o`000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l000Co0000o`3o0?l0o`3o00000_l0
o`000ooo003o0000o`000002o`0000;o0?l000Co0000o`3o0?l0o`3o0?l01?l000001Ol0o`3o0000
o`3o0?l0o`3o000000;o0?l00ol000001Ol0o`3o0000o`3o0?l0o`3o000001_ooooo0_l0001Soooo
o`00AOooool00ol0003oooooooooo`0@ooooo`04o`000?oo003oo`00o`0000Co003o0_l00002o`3o
00;o000000?o0?l0o`000?l0o`000_l0o`001?l0003o0?l0o`3o0?l0o`03o`0000;o0?l000Go0000
o`3o0?l0o`3o0?l0o`000003o`3o0004o`000?l0o`3o0?l0o`0000;o0?l00ol000001Ol00?oo0000
o`3o0?l0o`3o000000;o0?l00_l000001Ol0o`3o0000o`3o0?l0o`3o000000;o0?l000So0000o`3o
0?l0003o0000o`3o0?l0003o0?l0o`0000;o0?l000?o0000ooooooooool06Oooool3o`0006;ooooo
0014ooooo`03o`000?oooooooooo013ooooo00Co0000ool00?oo003o00001Ol00?l02ol0003o0?l0
o`3o0?l0o`3o0000o`3o0?l0003o0?l0o`000?l0o`3o000000Co0?l000?o0000o`3o0?l0o`001?l0
0002o`3o0004o`000?l0o`3o0?l0o`0000?o0?l000Ko0000o`3o0?l0o`3o0000ool00?l00002o`00
o`Ko00000_l0o`000ol0003o0?l0o`000003o`3o00?o00000_l0o`001?l0003o0?l0o`000?l0o`03
o`0001gooooo0_l0001Pooooo`00@oooool00ol0003oooooooooo`0Aooooo`05o`000?oo003oo`00
o`000?l00?l00_l000001?l00?oo0000o`3o0?l0o`04o`0000?o0?l000?o0000o`3o0?l0o`000_l0
o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000Co000000Go0?l0o`000?l0o`3o0?l0
o`000003o`3o00;o000000?oo`00o`000?l000000_l00?l2o`000004o`3o0?l0003o0?l0o`0000;o
0?l000?o0000o`3o0?l0o`000_l000001?l0o`3o0000o`3o0?l00002o`3o00?o000000?o0?l0o`00
0?ooool07_ooool2o`0005kooooo0013ooooo`03o`000?oooooooooo013ooooo1?l00004o`00o`03
o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`000_l0o`001_l0003o0?l0o`000?l0003o0?l0
o`0000?o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0009o`0000?oo`0000Co0000
o`00ool00?oo003o1Ol00002o`3o0004o`000?l0o`3o0000o`0000;o0?l000Co0000o`3o0?l0003o
0?l00_l000001?l0o`3o0000o`3o0?l0000Qooooo`;o0000G?ooool004;ooooo00?o0000oooooooo
ool04Oooool00ol0003oo`00o`000003o`00o`;o000000?o0?l0o`000?l0o`000_l0o`04o`000003
o`3o0?l0003o0?l000?o0?l00ol00002o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`001Ol0
003o0?l0o`3o0?l0o`3o000000?o0?l000?o0000o`00oooo00000ol000000ol00?oo0000o`00o`03
o`00o`Go000000Co0?l0o`000?l0o`3o00000_l0o`000ol0003o0?l0o`000002o`3o0003o`000?l0
o`3o000002?ooooo0_l0001Jooooo`00@Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo003o
000000?o003o0_l00003o`3o0006o`000?l0o`3o0000o`3o0?l0003o0?l00_l00005o`3o0003o`00
0?l0o`3o0?l000Co000000?o0?l0o`000?l0o`000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o
0?l000?o0000o`3o0?l0o`000_l00002ool00003o`000?l00?oo003o00?o003o00Co0000o`00ool0
003o00001?l0o`000ol0003o0?l0o`3o0003o`000006o`3o0?l0003o0?l0o`000?l0o`3o00009?oo
ool00ol0003oooooooooo`1Gooooo`00@Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo003o
000000Co003o00?o0000o`3o0?l000000ol0o`000ol0003o0?l0o`000003o`3o00Co000000?o0?l0
o`000?l0o`000ol0o`000ol0003o0?l0o`3o0003o`0000;o0?l000Go0000o`3o0?l0o`3o0?l0o`00
0002o`3o0007o`000?l0o`3o0?l0o`3o0?l00?ooo`00o`000002ool000?o000000?o003oo`000?l0
0?l00ol00?l2o`0000;o0?l000Wo0000o`3o0?l0003o0000o`3o0?l0003o0?l0o`000?l0o`000ol0
000Uooooo`;o0000Eoooool0043ooooo00?o0000ooooooooool04Oooool01?l0003oo`00o`000?l0
0?l3o`0000?o0?l000Co0000o`3o0?l0003o0?l00ol000000ol0o`3o0000o`3o0002o`3o00;o0000
1?l0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l01?l00002o`3o0004o`000?l0o`3o0?l0o`00
00?o0?l000Co003oool00?oo003o00000_oo00000ol0003o003oo`000004o`00o`03o`000?l00?oo
003o00;o000000Go0?l0o`000?l0003o0?l0o`000002o`3o0005o`000?l0o`3o0000o`3o0?l00000
9oooool2o`0005Gooooo000oooooo`03o`000?oooooooooo017ooooo00?o0000ool00?l000000_l0
0?l01?l0003o0?l0o`3o0?l00003o`3o0003o`000?l0o`3o000000?o0?l000?o0000o`3o0?l0o`00
0ol0o`04o`000005o`3o0?l0003o0?l0o`3o0?l000001?l0o`000ol0003o0?l0o`3o000Bo`000004
o`00ool0003o003oo`0000Co003o0_l000001?l0o`3o0000o`3o0?l00002o`3o00?o000000?o0?l0
o`000?l00000:?ooool2o`0005?ooooo000nooooo`03o`000?oooooooooo01;ooooo0_l000000ol0
0?oo0000o`000004o`3o0003o`000?l0o`3o000000;o0?l00_l000001?l0o`3o0000o`3o0?l0o`02
o`000003o`3o0?l0003o0?l000;o0?l01?l000000ol0o`3o0000o`3o0002o`3o0003o`000?l0o`3o
0?l000;o0?l000Co0000o`3o0?l0o`3o00000ol0o`000ol0003o0?l0o`3o0002o`000004ool00?l0
003oo`00o`0000?o003o00?o0000o`00ool00?l00ol00?l01ol0003o003oo`000?l0003o0?l0o`00
0?l0o`000_l000000ol0o`3o0000o`3o0003o`0002Kooooo00?o0000ooooooooool00_l0001Aoooo
o`00?Oooool2o`0001?ooooo1?l00003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`001?l0
003o0?l0o`3o0?l00005o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l000001?l00002
o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l0
00Oo0000ool00?l0003oo`00o`000?oo003o000000;o003o00Ko0000o`00ool0003o0000o`00ool0
0004o`00o`Co000000Go0?l0o`000?l0o`3o0000o`3o0002o`0002_ooooo0_l0001?ooooo`00?Ooo
ool00ol0003oooooooooo`0Booooo`?o00000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000;o
0?l00_l000001ol0o`3o0000o`3o0?l0o`3o0000o`3o0?l000000ol0o`000ol0003o0?l0o`000004
o`3o0003o`000?l0o`3o0?l000Co000000?o0?l0o`000?l0o`000_l0o`001?l0003o0?l0o`3o0?l0
0003o`3o00;o000000Ko003oool00?l0003oo`00o`000?oo0002o`0000Co003o00?o0000o`00ool0
0?l00_l00?l00ol0003o003oo`00o`02o`000003o`3o0?l0003o0?l000;o000000?o0?l0o`000?oo
ool0;?ooool00ol0003oooooooooo`1<ooooo`00??ooool00ol0003oooooooooo`0Booooo`?o0000
1?l0o`001?l0003o0?l0o`000?l00002o`3o0004o`000?l0o`3o0?l0o`0000Co0?l000?o0000o`3o
0?l0o`000ol0o`000ol0003o0?l0o`000002o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000_l0
o`07o`000003o`3o0?l0003o0?l000?o0?l00ooo0005o`0000?o003o00Oo0000o`00ool00?oo003o
o`000?l00?oo000000Co003o0ol000001Ol0o`3o0000o`3o0?l0o`3o000002kooooo0_l0001<oooo
o`00>oooool00ol0003oooooooooo`0Cooooo`05o`000?l0o`3o0?l0o`3o0?l000000ol0o`001?l0
003o0?l0o`3o0?l0o`02o`000004o`3o0?l0003o0?l0o`0000?o0?l000Ko0000o`3o0?l0003o0000
o`3o0?l00003o`3o00;o00001?l0o`02o`0000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000002o`3o
00Wo000000Soo`00o`000?oo003o0000ool00?l0003o003oo`0000Go003o00?o0000o`00ool00?l0
0_l00?l01?l0003o003oo`00ool00?l2o`000003o`3o0?l0003o0000033ooooo0_l0001:ooooo`00
>oooool00ol0003oooooooooo`0Booooo`04o`000?l0o`3o0?l0o`0000;o0?l000Go0000o`3o0?l0
003o0?l0o`000002o`3o0003o`000?l0o`3o000000?o0?l000?o0000o`3o0?l000001?l0o`000ol0
003o0?l0o`3o0003o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0o`02o`0000?o0?l000Go0000
o`3o0?l0o`3o0?l0o`000003o`3o0003o`000?l0o`3o0?l000Coo`0000Oo0000ool00?l0003o0000
o`00ool0003o003o00;o000000?o003oo`000?l00?l00_l00?l2o`0000Co003o00Ko0000o`00ool0
003o0000o`3o0?l0000aooooo`;o00005?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000Cooooo0ol0000Oooooo`00>_ooool00ol0003oooooooooo`0Booooo`?o00000_l0o`001?l0
003o0?l0o`000?l00003o`3o00?o00000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000Go0?l000Ko
0000o`3o0?l0003o0000o`3o0?l00003o`3o00?o00000_l0o`03o`000005o`3o0?l0003o0?l0o`3o
0?l000000ol0o`001Ol0003o0?l0o`3o0?l0003o0?l000;oo`0000Co0000ool00?l0003oo`000_l0
0004o`00o`03o`000?l00?oo003o00;o003o00Ko0000o`00ool00?oo0000o`00ool00004o`00o`;o
0000<oooool2o`00017ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo01kooooo000iooooo`03o`000?oooooooooo017ooooo0_l000001Ol0
0?oo0?l0o`3o0?l0003o0?l000;o00000ol0o`001?l0003o0?l0o`000?l00004o`3o0003o`000?l0
o`3o000000;o0?l00_l000000ol0o`3o0000o`3o0003o`3o0003o`000?l0o`3o0?l000;o0?l000?o
0000o`3o0?l0o`001?l000000ol0o`3o0000o`000002o`3o0005o`000?l0o`3o0?l0o`3o0?l00000
0_l0o`001?l0003o0?l0ool00?oo0007o`0000?o003o00Go0000o`00ool0003o003oo`000004o`00
o`03o`000?l00?oo003o00;o003o00Co0000o`00ool00?oo0000=?ooool00ol0003oooooooooo`0>
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`05o`0001oooooo
000hooooo`03o`000?oooooooooo017ooooo0ol00002o`00o`;o0?l000Co0000o`3o0?l0o`3o0000
0ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l000?o0000o`3o0?l0o`000ol0o`000ol0003o
0?l0o`3o0002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00001?l0o`000ol0003o0?l0o`3o0007
o`0000;o0?l000Co0000o`3o0?l0o`3o00000_l0o`001Ol0003oo`00o`000?oo003o000000;oo`00
0_l000000ol00?oo0000o`00o`02o`00o`03o`000?l00?oo003o00?o003o00Go0000o`00ool0003o
003oo`000004o`00o`;o0000<Oooool01?l0003oooooo`000?l0000>ooooo`04o`000?oooooooooo
o`0000Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo01kooooo
000hooooo`03o`000?oooooooooo013ooooo00?o0000o`3o0?l000000ol000001?l00?oo0000o`3o
0?l00002o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000_l0o`000ol0003o0?l0o`000002o`3o
00;o000000Oo0?l0o`000?l0o`3o0?l0o`000?l0o`3o000000Co0?l000?o0000o`3o0?l000000_l0
o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l03Ol000002?oo003o0000ool00?l0003oo`00o`00
0?oo003o00001?l00?l01_l0003o003oo`000?l0003o003oo`0000?o003o00?o0000o`00ool00?l0
0ol00?l00ol0003o003oo`00000dooooo`;o00003?ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooool000008?ooool003Oooooo00?o0000oooooooo
ool03oooool2o`000003o`3o0?l0003o000000;oo`0000?o003oo`000?l0o`000_l0o`000ol0003o
0?l0o`000002o`0000?o0?l000Co0000o`3o0?l0003o00001Ol0o`000ol0003o0?l0o`3o0002o`3o
0003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`000_l000001?l0o`3o0000o`3o0?l00003
o`3o0004o`000?l0o`3o0?l0o`3o00;o00000_l0o`003?l0003o0?l0o`3o0?l0003o0?l0ool00?l0
003oo`00o`000?oo003o0000ool000;o000000Co003oo`000?l00?oo00001?l00?l00ol0003o003o
o`00o`02o`00o`06o`000?l00?oo0000o`000?l00?oo00000ol00?l2o`0003Cooooo0_l0000:oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool2o`00023ooooo000f
ooooo`03o`000?oooooooooo00oooooo00?o0000o`3o0?l0o`000_l00003ool00003o`000?l00?oo
000000?o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o0004o`000?l0o`3o0?l0o`3o00;o0000
00Oo0?l0o`000?l0o`3o0?l0o`000?l0o`3o000000;o0?l00_l000000ol0o`3o0000o`3o0003o`3o
0003o`000?l0o`3o0?l000?o00000_l0o`001_l0003o0?l0o`3o0?l0o`3o0000o`3o00;o00000_l0
o`001?l0003o0?l0o`3o0?oo0006o`000005ool00?l0003o0000o`00ool000001?l00?l01_l0003o
003oo`00ool0003o003oo`0000Co003o00Go0000o`00ool00?oo003oo`000002o`00o`;o0000=?oo
ool2o`0000Wooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`0Nooooo`00=_ooool0
0ol0003oooooooooo`0>ooooo`04o`000?l0o`3o0000o`3o00;o00000ooo00001ol0003o003oo`00
ool0003o0?l0o`000?l0o`000_l00002o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`000ol0
003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l000000_l0o`001Ol0
003o0?l0o`3o0?l0o`3o000000;o0?l01?l000000ol0o`3o0000o`3o0002o`3o00Co00000_l0o`00
1Ol0003oo`00o`000?oo003o000000;oo`000_l000001ooo003o0000o`00ool00?oo0000o`00ool0
00001?l00?l01Ol0003o003oo`00ool00?oo000000Co003o00?o0000o`00ool00?l00ol00?l3o`00
03?ooooo0_l0000kooooo`00=?ooool2o`0000oooooo0ol00002o`3o00So000000Go003oo`000?l0
003o0?l0o`000002o`3o0004o`000?l0o`3o0000o`0000?o0?l000?o0000o`3o0?l000000ol0o`00
0ol0003o0?l0o`000002o`3o00;o000000?o0?l0o`000?l0o`000_l0o`03o`0000;o0?l000?o0000
o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0007o`000003o`3o0?l0003o000000;o00000_oo0000
1_l0003oo`00o`000?oo003o0000ool000?o00000_l00?l00ol0003o003oo`00o`02o`00o`05o`00
0?l00?oo003oo`00ool000001Ol00?l01Ol0003o003oo`000?l00?oo000000Co003o0_l0000coooo
o`03o`000?oooooooooo03Sooooo000dooooo`03o`000?oooooooooo00gooooo00Co0000o`3o0?l0
o`3o0?l01?l00003ool00003o`000?oo003oo`0000;o00000_l0o`02o`0000;o0?l000Go0000o`3o
0?l0o`3o0?l0o`000002o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`000ol0o`00
0ol0003o0?l0o`3o0002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000ol0o`001Ol0003o0?l0
o`3o0?l0o`3o000000?o0?l000?o0000o`3o0?l0o`000_l000002ol0o`3o0000o`000?oo003o0000
ool00?l0003oo`00o`000?oo003o000000?oo`000_l00003o`00o`;o00001?l00?l01_l0003o003o
o`000?l0003o003oo`0000?o003o00?o0000o`00ool00?l00ol00?l00ol0003o003oo`00000coooo
o`;o0000>?ooool003?ooooo00?o0000ooooooooool03Oooool02?l0003o0?l0o`3o0?l0003o0?l0
o`000?l00?oo00000ooo00001?l0003oo`00ool00?oo0002o`000005o`3o0?l0003o0?l0o`3o0?l0
00000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l00_l000001Ol0o`3o0000o`3o0?l0o`3o
000000?o0?l000Go0000o`3o0?l0003o0?l0o`000004o`3o00?o00000_l0o`001?l0003o0?l0o`3o
0?l00003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`001?l0003o0?l0o`000?oo0005o`00
0005ool00?l0003oo`00ool00?l000001?l00?l01_l0003o003oo`00ool0003o003oo`0000Co003o
00?o0000o`00ool00?l00_l00?l01_l0003o003oo`000?l0003o003oo`0000?o003o0_l0000coooo
o`;o0000=_ooool003?ooooo00?o0000ooooooooool03?ooool00ol0003o0?l0o`3o0002o`3o0003
o`000?l00?oo000000;o00000_oo00001_l0003oo`00ool00?oo003o0000o`00o`;o000000Co0?l0
o`000?l0o`3o00000_l0o`000ol0003o0?l0o`000002o`3o0005o`000?l0o`3o0?l0o`3o0?l00000
1?l0o`000ol0003o0?l0o`000003o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`00
1?l000000ol0o`3o0000o`3o0002o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000Co0000o`3o0?l0
o`3o0?l00_l000001?oo003o0000ool00?oo0002o`0000?oo`000_l000000ol00?oo0000o`00o`03
o`00o`03o`000?l00?oo003o00;o003o00Ko0000o`00ool00?oo0000o`00ool00004o`00o`03o`00
0?l00?oo003o00;o003o00?o0000o`00ool00000<Oooool00ol0003oooooooooo`02o`0003Cooooo
000booooo`03o`000?oooooooooo00cooooo00Co0000o`3o0?l0o`3o00000_l0o`000ol0003o003o
o`000002ool000Co000000Goo`00o`000?oo003o0000o`3o0002o`0000?o0?l000Co0000o`3o0?l0
003o00001?l0o`001Ol0003o0?l0o`000?l0o`3o000000Co0?l000?o0000o`3o0?l0o`000_l0o`00
1_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l000Co0000o`3o0?l0o`3o0?l00ol00002o`3o0004
o`000?l0o`3o0?l0o`0000;o0?l000?o0000o`3o0?l0o`000_l000001ooo003o0000o`000?l0003o
o`00o`000?oo00000_l000001?oo003o0000o`00ool00005o`00o`05o`000?l00?oo0000o`00ool0
00001?l00?l00ol0003o003oo`00o`02o`00o`06o`000?l00?oo003oo`000?l00?oo00000ol00?l2
o`0003Cooooo0_l0000booooo`004oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`00
00;ooooo1Ol00009ooooo`03o`000?oooooooooo00cooooo00?o0000o`3o0?l0o`000_l0o`02o`00
0003o`00ool0003oo`0000?oo`0000?o0000ool00?oo00001?l000001?l00?oo0000o`3o0?l00003
o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l0
00000ol0o`000ol0003o0?l0o`000004o`3o0005o`000?l0o`3o0000o`3o0?l000001?l0o`000ol0
003o0?l0o`3o000<o`000003o`00ool0003oo`0000?o000000?oo`00o`000?oo00000_oo0003o`00
0005o`00ool0003o0000o`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`06o`000?l00?oo
003oo`000?l00?oo00001?l00?l01Ol0003o003oo`00ool00?oo000000;o003o0_l0000dooooo`03
o`000?oooooooooo02oooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00gooooo00?o0000
o`3o0?l000000_l0o`001?l0003o003oo`00ool00003ool00006o`000?oo003oo`00ool00?l0003o
o`000ol000001_l00?oo0?l0o`3o0?l0003o0?l0o`0000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o
0?l00002o`3o0004o`000?l0o`3o0?l0o`0000Go0?l000?o0000o`3o0?l0o`000ol0o`001?l0003o
0?l0o`3o0?l00004o`3o0003o`000?l0o`3o0?l000;o0?l000Co0000o`3o0?l0o`3o00000_l0o`00
1ol0003o0?l0o`3o0?l0o`3o0000o`3o0?oo00001ol00003ool00003o`000?l00?oo003o00;o003o
00Go0000o`00ool00?oo003oo`000003o`00o`;o00001?l00?l01Ol0003o003oo`00ool00?oo0000
00Co003o00?o0000o`00ool00?l00ol00?l3o`0003;ooooo0_l0000_ooooo`002oooool5o`0000;o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool02?l0003o0?l0o`3o0?l0o`3o0000o`3o0?l0003o
003o0ol00002ool00006o`000?oo003oo`00o`000?oo003o00000_oo00000ol0003o003oo`00o`03
o`0000Co0?l000Co0000o`3o0?l0003o00001?l0o`001?l0003o0?l0o`3o0?l0o`02o`000004o`3o
0?l0003o0?l0o`3o00;o000000?o0?l0o`000?l0o`000_l0o`001_l0003o0?l0o`000?l0003o0?l0
o`0000?o0?l000Co0000o`3o0?l0o`3o00000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l0
0_l000001?oo003o0000ool00?oo0003o`0000?oo`0000?o0000o`00ool000001?l00?l00ol0003o
003oo`00o`02o`00o`06o`000?l00?oo003oo`000?l00?oo00000ol00?l00ol0003o003oo`00o`03
o`00o`05o`000?l00?oo0000o`00ool000001?l00?l2o`0003;ooooo0_l0000]ooooo`004_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0=ooooo`03o`000?l0o`3o0?l000;o0?l000Co0000o`00ool00?oo
00000_oo0004o`000003ool00?l0003o000000;oo`0000Go0000ool00?l00?oo003oo`000003o`3o
00;o00000_l0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`001Ol0003o0?l0o`3o
0?l0o`3o000000Go0?l00ol000000ol0o`3o0000o`3o0003o`3o00?o000000?o0?l0o`000?l0o`00
0_l0o`001?l0003o0?l0o`3o0?l00003o`3o000:o`000?l0o`3o0?l0o`000?oo003o0000ool00?l0
003oo`00o`0000;oo`001Ol00005o`00o`05o`000?l00?oo0000o`00ool000001?l00?l00ol0003o
003oo`00o`02o`00o`06o`000?l00?oo0000o`000?l00?oo00000ol00?l00ol0003o003oo`00o`03
o`00o`03o`000?l00?oo000003?ooooo0_l0000[ooooo`004_ooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo00Ko0000o`3o0?l0o`3o0000o`3o0?l00002o`00o`05o`000?oo003oo`00
ool00?l000000ooo0003o`0000;oo`0000Co0000ool00?l00?oo003o0_l0o`001Ol0003o0?l0o`3o
0?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000004o`3o0003o`000?l0o`3o000000;o
0?l000?o0000o`3o0?l000001?l0o`000ol0003o0?l0o`3o0003o`3o0003o`000?l0o`3o0?l000Oo
000000?o0?l0o`000?l0o`000_l0o`001?l0003o0?l0o`3o0?l0o`02ool00005o`000?oo003o0000
ool00?l000000ooo0003o`000005o`00ool0003o0000o`00ool000000ol00?l00ol0003o003oo`00
o`02o`00o`06o`000?l00?oo003oo`000?l00?oo00001?l00?l00ol0003o003oo`00o`02o`00o`06
o`000?l00?oo0000o`000?l00?oo00000ol00?l2o`0003?ooooo0_l0000Yooooo`004_ooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000o`3o0?l0o`000_l0o`001Ol0003o003o
o`00ool00?oo000000;oo`0000?o0000ool00?oo00000_oo0002o`000003ool00?l0003o000000Co
000000So003oo`3o0?l0o`3o0000o`3o0?l0003o0?l0o`0000;o0?l000?o0000o`3o0?l000000_l0
o`001Ol0003o0?l0o`3o0?l0o`3o000000Co0?l000?o0000o`3o0?l0o`000ol0o`001_l0003o0?l0
o`000?l0003o0?l0o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000002o`3o00oo000000?oo`00
o`000?oo00000_oo0003o`0000;o003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`000?l0
0?oo000000Co003o00?o0000o`00ool00?l00_l00?l01_l0003o003oo`00ool0003o003oo`0000Co
003o00?o0000o`00ool00?l00_l00?l00ol0003o003oo`00000cooooo`?o00006Oooool3o`0000?o
oooo0_l00006ooooo`004oooool2o`0000[ooooo0_l00003ooooo`?o00001_ooool00ol0003ooooo
ooooo`0=ooooo`05o`000?l0o`3o0000o`3o0?l000000ol00?l4o`000004ool00?l0003oo`00ool0
00;o00000ooo00001?l0003oo`00ool00?l00002o`00o`04o`000?l0o`3o0000o`0000?o0?l000Co
0000o`3o0?l0003o00001?l0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o000000;o0?l0
0_l000000ol0o`3o0000o`3o0003o`3o00?o000000?o0?l0o`000?l0o`000_l0o`001Ol0003o0?l0
o`3o0?l0o`3o000000?o0?l000Co0000o`3o0?l0o`3o00000_l0o`02o`000003ool00?l0003oo`00
00Co00000_oo0004o`0000;o003o00?o0000o`00ool000000ol00?l00ol0003o003oo`00o`02o`00
o`06o`000?l00?oo003oo`000?l00?oo00001?l00?l01Ol0003o003oo`00ool00?oo000000?o003o
00?o0000o`00ool000000ol00?l3o`0002oooooo00Go0000ooooooooooooooooo`00000Iooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03ooooo`00;?ooool2o`0000ko
oooo00Co0000o`3o0?l0o`3o0?l00_l000001?l00?oo0000o`000?l00002ool00003o`000?oo003o
o`0000Co00000_oo00001?l0003oo`00ool00?l00002ool000;o003o00Go0000o`3o0?l0o`3o0?l0
o`000002o`3o0004o`000?l0o`3o0?l0o`3o00;o00000_l0o`000ol0003o0?l0o`3o0002o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`000_l0o`001?l0003o0?l0o`3o0?l0o`03o`00
0003o`3o0?l0003o0?l000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000002o`3o0008o`000?l0o`3o
0?l0o`3o0?l0003oo`00o`000?oo0002o`0000Coo`0000Go0000ool00?oo003o0000o`00o`02o`00
0003o`00ool0003o003o00;o003o00Co0000o`00ool00?oo003o0_l00004o`00o`03o`000?l00?oo
003o00;o003o00Go0000o`00ool00?oo003oo`000005o`00o`05o`000?l00?oo003oo`00ool00000
0ol00?l3o`00037ooooo0_l0000>ooooo`Go000000?oooooo`000?l000000ol00002ooooo`04o`00
0?ooooooooooo`0000Gooooo000[ooooo`03o`000?oooooooooo00gooooo00Co0000o`3o0?l0o`3o
0?l00_l00003o`00o`04o`000?oo003oo`00o`0000Coo`0000?o0000ool00?oo00001?l000002?oo
003o0000ool00?oo003o003oo`000?l0o`3o00000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o
0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000;o0?l00_l000001ol0o`3o0000o`3o0?l0
o`3o0000o`3o0?l000001?l0o`000ol0003o0?l0o`3o0003o`0000;o0?l000Co0000o`3o0?l0o`3o
00000ol0o`001?l0003o0?l0o`3o0?l00003ool00004o`000?oo003o0000o`0000Coo`0000Co0000
ool00?oo003o00000_l00?l2o`0000;o003o00?o0000o`00ool00?l00_l00?l01_l0003o003oo`00
ool0003o003oo`0000?o003o0_l00004o`00o`05o`000?l00?oo0000o`00ool000001?l00?l00ol0
003o003oo`00o`02o`00o`04o`000?l00?oo003oo`0003;ooooo0_l0000Booooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooo00001Oooool002_ooooo00?o0000ooooooooool03?oo
ool01?l0003o0?l0o`3o0?l0o`02o`0000?o003o0ol000000ooo003o0000ool00002ool000;o0000
0ooo00000ol0003oo`00ool00003o`000008ool00?l0003o003oo`00ool0o`3o0000o`3o0?l00002
o`3o0008o`000?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l00003o`3o0003o`000?l0o`3o0?l000?o
0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`000002o`3o0005o`000?l0o`3o0?l0o`3o
0?l000000_l0o`0Eo`0000Coo`0000?o0000ool00?l000000_l00002o`00o`?o000000Co003oo`00
0?l00?oo00001?l00?l00ol0003o003oo`00o`02o`00o`06o`000?l00?oo003oo`000?l00?oo0000
0ol00?l00ol0003o003oo`00o`03o`00o`05o`000?l00?oo0000o`00ool000001?l00?l2o`0003;o
oooo0_l0000Aooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001Oooool002[o
oooo00?o0000ooooooooool03?ooool00ol0003o0?l0o`3o0002o`3o00;o00000_l00?l2o`0000;o
o`000ol00002ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00003o`00
0004o`00ool0o`3o0000o`0000Co0?l000Co0000o`3o0?l0003o00000ol0o`000ol0003o0?l0o`00
0002o`3o00;o000000Oo0?l0o`000?l0o`3o0?l0o`000?l0o`3o000000?o0?l01?l000000ol0o`3o
0000o`3o0003o`3o0004o`000?l0o`3o0?l0o`0000?o0?l000Co0000o`3o0?l0o`3o00000_l0o`00
1ooo003o0000ool00?l0003oo`00o`000?oo00000_l000001_oo003o0000ool00?l0003oo`00o`00
00;o003o00Co0000o`00ool0003o00000_l00?l00ol0003o003oo`00o`03o`00o`05o`000?l00?oo
0000o`00ool000001?l00?l00ol0003o003oo`00o`02o`00o`06o`000?l00?oo0000o`000?l00?oo
00000ol00?l00ol0003o003oo`00o`02o`00o`04o`000?l00?oo003oo`0003?ooooo0_l0000@oooo
o`;o00000oooool01?l0003oooooooooool00005ooooo`00:Oooool00ol0003oooooooooo`0=oooo
o`04o`000?l0o`3o0000o`3o00;o00000ol00?l01Ol0003oo`00ool00?oo003o000000;oo`001?l0
0002ool00004o`000?oo003oo`00o`0000Coo`0000?o0000o`00ool00?l00_l00002o`3o00;o0000
0_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000ol0o`000ol0003o
0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000?o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00002
o`3o0004o`000?l0o`3o0?l0o`0000?o0?l000Co0000o`3o0?l0o`3o00000ol0o`001ol0003oo`00
o`000?oo003o0000ool00?l000000ooo0002o`0000?oo`0000Co0000o`00ool00?oo00000_l00?l3
o`000005o`00ool0003o0000o`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`06o`000?l0
0?oo003oo`000?l00?oo00001?l00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00
ool000001?l00?l3o`0003;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02oooo
o`;o00001_ooool002Sooooo00?o0000ooooooooool03Oooool02?l0003o0?l0o`3o0?l0o`3o0000
o`3o0?l0003o003o1?l000000ooo003o0000ool00002ool000;o00000_oo0004o`000003ool00?l0
003oo`0000;oo`0000Oo0000ool00?oo003o003oo`000?l0o`3o000000?o0?l000Co0000o`3o0?l0
o`3o00000ol0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000ol0o`000ol0003o0?l0o`00
0002o`3o00;o000000?o0?l0o`000?l0o`000_l0o`000ol0003o0?l0o`3o0004o`000005o`3o0?l0
003o0?l0o`3o0?l000000ol0o`001Ol0003o0?l0o`3o0?l0003o0?l000;oo`0000Go0000ool00?l0
003oo`00o`000003ool00003o`000?oo003oo`0000;o000000Ko003oo`000?l00?oo003oo`000?l0
0?l3o`0000;o003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000000Co003o
00Go0000o`00ool00?oo003oo`000004o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool0
0?oo003oo`000004o`00o`;o0000<Oooool2o`0001_ooooo000Xooooo`03o`000?oooooooooo00go
oooo00Co0000o`3o0?l0o`3o0?l00_l00003o`00o`07o`000?oo003oo`00o`000?oo003o0000ool0
0002o`0000?oo`0000Co0000ool00?oo003oo`001ol000002_oo003o0000o`00ool00?oo0?l0o`00
0?l0o`3o0000o`3o0?l00002o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`000ol0003o0?l0
o`3o0003o`3o0003o`000?l0o`3o0?l000?o0?l00ol000000ol0o`3o0000o`3o0003o`3o0003o`00
0?l0o`3o0?l000?o000000?o0?l0o`000?l0o`000_l0o`001Ol0003o0?l0o`3o0?l0003o0?l000Oo
00001?oo0002o`0000;oo`0000?o0000o`00ool00?l00_l00?l01?l0003o003oo`00ool00?l2o`00
00?o003o00?o0000o`00ool00?l00_l00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo003o
o`00ool000001?l00?l01_l0003o003oo`00ool0003o003oo`0000?o003o00?o0000o`00ool00?l0
0ol00?l00ol0003o003oo`00000`ooooo`Co00006Oooool002Oooooo00?o0000ooooooooool03Ooo
ool3o`000003o`3o0?l0003o000000?o003o00Go0000ool00?oo003oo`00o`000002ool000;o0000
00Coo`00o`000?oo003o00001?oo00001Ol0003oo`00ool00?oo003o000000;oo`000ol000001?l0
0?oo0?l0o`000?l00003o`3o0004o`000?l0o`3o0000o`0000?o0?l000?o0000o`3o0?l000000_l0
o`02o`000007o`3o0?l0003o0?l0o`3o0?l0003o0?l0o`000004o`3o0003o`000?l0o`3o0?l000;o
0?l000Go0000o`3o0?l0o`3o0?l0o`000002o`3o00_o00000_oo00001?l0003oo`00o`000?oo0002
o`00000;ool00?l0003oo`00ool00?l0003oo`00o`000?l00?oo0000o`00ool000000ol00?l00ol0
003o003oo`00o`02o`000006o`00ool0003o003oo`000?l00?oo00000ol00?l2o`0000Co003o00Go
0000o`00ool0003o003oo`000004o`00o`03o`000?l00?oo003o00;o003o00Ko0000o`00ool0003o
0000o`00ool00003o`00o`;o0000<Oooool2o`0001Sooooo000Vooooo`03o`000?oooooooooo00ko
oooo00?o0000o`3o0?l0o`000_l00003o`00o`;o00000_oo00001?l0003oo`00ool00?oo0002o`00
00;oo`0000?o0000ool00?l000000_oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000
ool00?l00?l00_l00003o`3o0004o`000?l0o`3o0?l0o`0000?o0?l000Co0000o`3o0?l0o`3o0000
1Ol0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000?o0?l000Go0000o`3o0?l0003o
0?l0o`000003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`001?l0003o0?l0o`3o0?l00002
o`3o0006o`000?oo003oo`00ool00?l0003oo`000_l00002ool000;o00000_oo0002o`0000;o003o
00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`000?l0003o003o00;o00000_l00?l00ol0003o
003oo`00o`02o`00o`06o`000?l00?oo003oo`000?l00?oo00000ol00?l00ol0003o003oo`00o`02
o`00o`06o`000?l00?oo003oo`000?l00?oo00001?l00?l00ol0003o003oo`00o`02o`00o`03o`00
0?l00?oo000002oooooo00?o0000ooooool000006?ooool002Gooooo00?o0000ooooooooool03_oo
ool01Ol0003o0?l0o`3o0?l0o`3o000000Co003o00Go0000ool00?l0003oo`00o`000002ool000;o
00000ooo00000ol0003oo`00ool00004o`0000;oo`0000Co0000ool00?oo003o00000_oo0002o`00
o`;o00000ol0o`001?l0003o0?l0o`3o0?l00003o`3o0004o`000?l0o`3o0?l0o`3o00;o000000Oo
0?l0o`000?l0o`3o0?l0o`000?l0o`3o000000;o0?l00_l000000ol0o`3o0000o`3o0002o`3o00?o
00000_l0o`001?l0003o0?l0o`3o0?l00003o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000So0000
o`3o0?oo003oo`00o`000?oo003o0000ool000;o00000_oo00001?l0003oo`00ool00?oo0002o`00
0006o`00ool0003o003oo`000?l00?oo00001?l00?l00ol0003o003oo`00o`03o`000004o`00ool0
003o003oo`0000Co003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000000Co
003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo000000?o003o0ol0000[oooo
o`04o`000?oooooo0000o`0001Sooooo000Uooooo`03o`000?oooooooooo00gooooo0ol000001ol0
o`3o0000o`000?l00?oo0000o`00ool000000ooo0004o`000005ool00?l0003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00004o`000003ool00?l0003oo`0000;oo`0000So0000o`00ool0o`3o
0000o`3o0?l0003o0?l0o`0000;o0?l000?o0000o`3o0?l000000_l0o`001Ol0003o0?l0o`3o0?l0
o`3o000000Co0?l000?o0000o`3o0?l0o`000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l0
1ol00002o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000?o0000o`3o0?oo00001_l000001?oo003o
0000ool00?oo0002o`0000;oo`000_l00003o`00o`05o`000?l00?oo003oo`00ool000000ol00?l0
0ol0003o003oo`000002o`000003o`00ool0003o003o00;o003o00?o0000o`00ool00?l00_l00?l0
0ol0003o003oo`00o`02o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool00?oo003oo`00
0005o`00o`05o`000?l00?oo003oo`00ool000000ol00?l2o`0002Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`Go00000oooool2o`0000?ooooo000Sooooo`;o00004?oo
ool00ol0003o0?l0o`3o0002o`0000?o003o00?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0004o`000003ool00?l0003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000003ool000Ko0000
00Co0?l0o`00ool0003o00000ol0o`001?l0003o0?l0o`000?l00004o`3o0003o`000?l0o`3o0000
00;o0?l000?o0000o`3o0?l000000_l0o`02o`000003o`3o0?l0003o0?l000;o0?l000?o0000o`3o
0?l0o`000ol0o`001?l0003o0?l0o`3o0?l00002o`3o00co000000Goo`00o`000?oo003o0000ool0
0003o`0000?oo`000_l000001Ooo003o0000o`00ool00?oo000000?o003o00?o0000o`00ool00?l0
0ol00?l01?l0003o003oo`00ool00?l2o`0000;o003o00?o0000o`00ool00?l00ol00?l01Ol0003o
003oo`000?l00?oo000000?o003o0_l00004o`00o`05o`000?l00?oo0000o`00ool000001?l00?l0
0ol0003o003oo`00o`02o`00o`03o`000?l00?oo000002Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool002?ooooo00?o0000ooooooooool03_ooool01Ol0003o0?l0o`3o0?l0o`3o000000?o003o
0_l000001?oo003o0000ool00?l00002ool00003o`000?oo003o000000;oo`000ol00002ool00004
o`000?oo003oo`00o`0000Coo`0000Co0000ool00?oo003o00000_oo0002o`0000?o0?l000Co0000
o`3o0?l0o`3o00000ol0o`02o`0000;o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o
0003o`3o0003o`000?l0o`3o0?l000;o0?l000Ko0000o`3o0?l0003o0000o`3o0?l00002o`3o0003
o`000?l0o`3o0?l000;o0?l000Co0000o`3o0?l0o`3o00000_l0o`002Ol0003o0?l0o`3o0?l0003o
o`00o`000?oo003o0000ool00002o`0000;oo`000_l00002ool00005o`000?oo003o0000o`00ool0
00001?l00?l01Ol0003o003oo`000?l00?oo000000Co003o00?o0000o`00ool00?l00ol000001Ol0
0?oo0000o`000?l00?oo000000?o003o00?o0000o`00ool00?l00_l00?l01_l0003o003oo`00ool0
003o003oo`0000?o003o00?o0000o`00ool00?l00_l00?l01_l0003o003oo`00ool0003o003oo`00
00?o003o0_l0000Sooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`Go00000oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo000Sooooo`03o`000?oooooooooo
00kooooo00Co0000o`3o0?l0o`3o00000ol00?l2o`0000?oo`0000Ko0000ool00?l0003o0000ool0
0?l00003ool00003o`000?oo003oo`0000Go000000Goo`00o`000?oo003oo`00o`000002ool00004
o`000?oo003oo`00ool000;o000000Go003oo`3o0?l0o`3o0?l0o`000003o`3o0005o`000?l0o`3o
0?l0o`3o0?l000000ol0o`000ol0003o0?l0o`000002o`3o00;o000000Oo0?l0o`000?l0o`3o0?l0
o`000?l0o`3o000000Co0?l00ol000000ol0o`3o0000o`3o0002o`3o0004o`000?l0o`3o0?l0o`00
00;o0?l000Go0000o`3o0?l0o`3o0000o`3o0002ool00004o`000?oo003o0000ool000;o00000ooo
00000ol0003oo`00ool00003o`0000;o003o00?o0000o`00ool000000ol00?l00ol0003o003oo`00
o`03o`00o`04o`000?l00?oo0000o`00o`?o00000_l00?l00ol0003o003oo`00o`02o`00o`05o`00
0?l00?oo0000o`00ool000001?l00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo0000o`00
ool000001?l00?l00ol0003o003oo`00o`02o`00o`04o`000?l00?oo0000o`00023ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000000_oo
ool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool03_ooool4o`0000Co003o00?o0000
ool00?oo00000_oo00000ol0003oo`00o`000004o`000003ool00?l0003oo`0000?oo`0000Co0000
ool00?oo003o00000_oo0004o`000003ool00?l0003oo`0000;oo`0000Ko0000o`00ool00?oo0000
o`3o0?l00002o`3o0008o`000?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l00003o`3o0003o`000?l0
o`3o0?l000?o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0002o`3o0004o`000?l0
o`3o0?l0o`3o00?o000000?o0?l0o`000?l0o`000_l0o`001?l0003o0?l0o`3o0?l00002o`3o0003
o`000?l0o`3o0?l000Ko000000?oo`00o`000?oo00001Ooo00000ol0003o003oo`00o`02o`00o`05
o`000?l00?oo003oo`00ool000000_l00?l2o`000003o`00ool0003o003o00;o003o00Co0000o`00
ool00?oo003o0_l00002o`00o`03o`000?l00?oo000000?o003o00Go0000o`00ool00?oo003oo`00
0003o`00o`03o`000?l00?oo000000?o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`00
0?l00?oo000000Co003o0ol0000Looooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`008Oooool00ol0003o
ooooooooo`0?ooooo`07o`000?l0o`3o0?l0o`000?l00?oo0000o`00o`02o`000004ool00?l0003o
o`00o`0000;oo`0000?o0000ool00?l000000_oo00000ol0003oo`00o`000002ool00004o`000?oo
003oo`00o`0000Coo`0000?o0000ool00?oo00000ol000000ooo003o0000ool00002o`00o`;o0000
1?l0o`001?l0003o0?l0o`000?l00003o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l0
00000ol0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o000000Co0?l000?o0000o`3o0?l0
o`001ol000001?l0o`3o0000o`3o0?l0o`04o`000005ool00?l0003oo`00o`000?oo00000ol00006
ool00004o`000?l00?oo003oo`0000?o003o00?o0000o`00ool00?l00ol00?l01Ol0003o003oo`00
ool00?oo000000?o003o00?o0000o`00ool00?l00_l000000ol00?oo0000o`00o`02o`00o`05o`00
0?l00?oo003oo`00ool000001Ol00?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00
ool00?l00ol00?l01Ol0003o003oo`00ool00?oo000000Co003o0_l0000Iooooo`03o`000?oooooo
oooo00Oooooo0_l00009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`008?ooool00ol0003oooooooooo`0?ooooo`04o`000?l0o`3o0?l0o`0000?o003o
0_l00003ool00006o`000?oo003o0000o`000?oo003o00000ooo00000ol0003oo`00ool00004o`00
0003ool00?l0003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000002ool000Co000000Co003o
o`000?l0o`3o0?l00_l00002o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`000ol0003o0?l0
o`3o0002o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0
o`000002o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`000ol0003o0?l0o`3o0005o`000008
o`3o0?l0003oo`00o`000?oo003o0000ool00?l00003ool000;o00001?oo0003o`0000Co003o00Go
0000o`00ool0003o003oo`000004o`00o`03o`000?l00?oo003o00;o003o00Co0000o`00ool0003o
003o0_l00003o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool0003o003oo`000004o`00
o`03o`000?l00?oo003o00;o003o00Ko0000o`00ool0003o0000o`00ool00003o`00o`03o`000?l0
0?oo003o00;o003o00Co0000o`00ool00?oo00005oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo0ol00004ooooo`;o00000oooool0023ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?l0o`3o000000?o003o0_l00003ool00003o`000?oo003oo`0000Go0000
00?oo`00o`000?oo00000ooo00000ol0003oo`00ool00003o`0000;oo`0000Co0000ool00?oo003o
00001?oo00000ol0003oo`00ool00002o`0000Co0?l000Co0000o`3o0?l0o`3o00000ol0o`001ol0
003o0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`02o`000007o`3o0?l0003o0?l0o`3o0?l0003o
0?l0o`000003o`3o00Co000000?o0?l0o`000?l0o`000_l0o`001Ol0003o0?l0o`3o0?l0o`3o0000
00;o0?l000_o0000o`3o0?l0003o0?l0o`00oooo003o0000ool00?l0003oo`00o`000004ool000;o
00000_oo0002o`0000;o003o00?o0000o`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`06
o`000?l00?oo003oo`000?l00?oo00000ol00?l00ol0003o003oo`00o`02o`000006o`00ool0003o
003oo`000?l00?oo00000ol00?l00ol0003o003oo`00o`03o`00o`05o`000?l00?oo0000o`00ool0
00001?l00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo0000o`00ool000001?l00?l2o`00
01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`007oooool00ol0003o
ooooooooo`02ooooo`03ool00?l0003ooooo00[ooooo0ol00003o`00o`;o00000ooo00001?l0003o
o`00ool00?l00002ool00006o`000?oo003oo`00o`000?oo003o00000_oo00001Ol0003oo`00ool0
0?oo003o000000;oo`001Ol000001Ooo003o0000ool00?oo003o000000?oo`0000So0000o`00ool0
003o0000o`3o0?l0003o0?l0o`0000;o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o0003o`00
0?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0003o`3o0003o`00
0?l0o`3o0?l000?o000000?o0?l0o`000?l0o`000_l0o`001?l0003o0?l0o`3o0?l00002o`3o0003
o`000?l0o`3o0?l000So00001?oo00001?l0003oo`00ool00?l00003o`00o`03o`000?l00?oo003o
00;o003o00Go0000o`00ool0003o003oo`000004o`00o`05o`000?l00?oo003oo`00ool000000_l0
0?l2o`000003o`00ool0003o000000;o003o00Go0000o`00ool00?oo003oo`000002o`00o`;o0000
00?o003oo`000?l00?l00_l00?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00ool0
00000ol00?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0:ooooo`;o00005_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`09ooooo`;o00001?l00?l00ol0003oo`00ool00002ool00006o`000?oo003o0000o`00
0?oo003o00000ooo00000ol0003oo`00ool00004o`000003ool00?l0003oo`0000?oo`0000Co0000
ool00?oo003o00000_oo0004o`000003ool00?l0003o003o00;o003o0_l00003o`3o0004o`000?l0
o`3o0000o`0000?o0?l000?o0000o`3o0?l000000_l0o`02o`000007o`3o0?l0003o0?l0o`3o0?l0
003o0?l0o`000002o`3o00;o000000?o0?l0o`000?l0o`000_l0o`000ol0003o0?l0o`3o0007o`00
0005o`3o0?l0003o0?l0o`3o0?l000000_l0o`03o`000003ool00?l0003oo`0000?oo`0000Oo0000
ool00?oo003oo`00o`000?oo003o000000;o003o00Ko0000o`00ool00?oo0000o`00ool00003o`00
o`03o`000?l00?oo003o00;o003o00Go0000o`00ool00?oo003oo`000005o`00o`03o`000?l00?oo
003o00;o00000ol00?l00ol0003o003oo`00o`03o`00o`05o`000?l00?oo003oo`00ool000000ol0
0?l00ol0003o003oo`00o`03o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003o
o`00o`03o`00o`?o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo
000Mooooo`03o`000?oooooooooo00Gooooo0_l00009ooooo`04o`000?l0o`3o0000o`00o`?o0000
0_oo00000ol0003oo`00o`000002ool00003o`000?oo003o000000;o000000?oo`00o`000?oo0000
0ooo00001_l0003oo`00ool00?l0003oo`00o`0000;oo`0000Co0000ool00?oo003o00001?oo0000
0ol0003oo`00ool00004o`000005o`00ool0003o0?l0o`3o0?l000000_l0o`001Ol0003o0?l0o`3o
0?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000ol0o`000ol0003o0?l0o`3o0002o`3o0003o`00
0?l0o`3o0?l000?o0?l00ol000000ol0o`3o0000o`3o0002o`3o0005o`000?l0o`3o0?l0o`3o0?l0
00000_l0o`07o`000006o`00ool0003oo`00o`000?oo003o00001?oo00001_l0003oo`00ool00?oo
003o0000ool000;o00001?l00?l01Ol0003o003oo`00ool00?oo000000?o003o0_l00004o`00o`05
o`000?l00?oo0000o`00ool000001?l00?l02_l0003o003oo`000?l0003o003oo`000?l00?oo0000
o`00ool00004o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool0003o003oo`000004o`00
o`03o`000?l00?oo003o00;o003o00Go0000o`00ool0003o003oo`000004o`00o`;o00002oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo000Mooooo`03o`000?oooooooooo
00Gooooo0_l00009ooooo`;o00000_l00?l2o`0000Coo`0000Ko0000ool00?oo003o0000ool00?l0
0003ool00003o`000?oo003o000000;oo`0000Go0000ool00?oo003oo`00o`000002ool000Co0000
00?oo`00o`000?oo00000_oo00001Ol0003oo`00ool00?oo003o000000;oo`0000?o003oo`000?l0
00000_l0o`02o`0000?o0?l000Co0000o`3o0?l0o`3o00000ol0o`02o`000007o`3o0?l0003o0?l0
o`3o0?l0003o0?l0o`000002o`3o0003o`000?l0o`3o000000Co0?l00ol000000ol0o`3o0000o`3o
0002o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`002ol0003o0?l0o`3o0?l0003o0?l0ool0
0?l0003oo`00o`000?oo003o000000Coo`000_l00003ool00006o`000?l00?oo003oo`000?l00?oo
00000ol00?l00ol0003o003oo`00o`02o`00o`06o`000?l00?oo003oo`000?l00?oo00000ol00?l0
0ol0003o003oo`00o`02o`00o`05o`000?l00?oo003oo`000?l00?l00_l00002o`00o`03o`000?l0
0?oo003o00;o003o00Ko0000o`00ool00?oo0000o`00ool00003o`00o`03o`000?l00?oo003o00;o
003o00Ko0000o`00ool00?oo0000o`00ool00003o`00o`03o`000?l00?oo003o00;o003o00Co0000
o`00ool00?oo00002Oooool00ol0003oooooooooo`0>ooooo`;o00005Oooool001_ooooo0_l00009
ooooo`;o00001oooool2o`0000;o003o00Oo0000ool00?oo003oo`00o`000?oo003o000000;oo`00
0ol00004ool00003o`000?oo003oo`0000Co000000?oo`00o`000?oo00000ooo00000ol0003oo`00
ool00003o`0000;oo`0000Co0000ool00?oo003o00000ooo00000ol0003o003oo`00o`02o`0000;o
0?l000Go0000o`3o0?l0o`3o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o
0?l0o`000_l0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000o`3o
0?l0o`000ol00002o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000Co0000o`3o0?l0o`3o00000_l0
o`08o`000003ool00?l0003oo`0000;oo`0000?o0000ool00?l000000ol00?l00ol0003o003oo`00
o`02o`00o`05o`000?l00?oo0000o`00ool000001?l00?l01Ol0003o003oo`00ool00?oo000000;o
003o00?o0000o`00ool000001?l00?l00ol0003o003oo`00o`02o`0000;o003o00?o0000o`00ool0
00001?l00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00ool000001?l00?l01Ol0
003o003oo`00ool00?oo000000;o003o00?o0000o`00ool000001?l00?l3o`0000Gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`006oooool2o`0000Wooooo0_l00007oooo
o`;o00000_l00?l00ol0003oo`00o`000002ool00004o`000?oo003oo`00o`0000;oo`0000Go0000
ool00?l0003oo`00o`000004ool00006o`000?oo003oo`00o`000?oo003o00000_oo00001Ol0003o
o`00ool00?oo003o000000;oo`001ol000002?oo003o0000ool00?l00?ooo`00o`00ool0o`3o0000
0_l0o`001Ol0003o0?l0o`000?l0o`3o000000;o0?l000?o0000o`3o0?l000000ol0o`000ol0003o
0?l0o`000002o`3o0003o`000?l0o`3o000000;o0?l00_l000000ol0o`3o0000o`3o0002o`3o0003
o`000?l0o`3o0?l000Co000000Go0?l0o`000?l0o`3o0?l0o`000002o`3o0003o`000?l0o`3o0?l0
00?o000000Coo`00o`000?oo003o00000_oo0002o`0000;oo`000_l000001?oo003o0000o`00ool0
0002o`00o`03o`000?l00?oo000000?o003o00Go0000o`00ool00?oo003oo`000004o`00o`03o`00
0?l00?oo003o00;o003o00Go0000o`00ool00?oo003oo`000004o`00o`06o`000?l00?oo0000o`00
0?l00?oo00000ol00?l00ol0003o003oo`00o`02o`00o`03o`000?l00?oo003o00;o003o00Go0000
o`00ool00?oo003oo`000004o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool00?oo003o
o`000004o`00o`;o00000_ooool00ol0003oooooooooo`0Aooooo`;o00001Oooool2o`0000gooooo
000Jooooo`03o`000?oooooooooo00[ooooo0_l00005ooooo`;o000000?o003oo`000?l000000ooo
00001?l0003oo`00o`000?oo0002o`000003ool00?l0003oo`0000;oo`0000?o0000ool00?l00000
0_oo00001Ol0003oo`00ool00?oo003o000000;oo`001?l000000ooo003o0000ool00003ool00004
o`000?oo003oo`00o`0000;oo`001_l00002o`3o0004o`000?l0o`3o0000o`0000?o0?l000Co0000
o`3o0?l0003o00001Ol0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000?o0?l00ol0
00000ol0o`3o0000o`3o0002o`3o0004o`000?l0o`3o0?l0o`3o00[o000000So0?l0o`000?oo003o
0000ool00?l0003oo`00o`0000;oo`0000Ko0000ool00?oo003oo`00o`000?oo0002o`0000Co003o
00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00?o003o00Go0000o`00ool0
003o003oo`000003o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool00?oo0000o`00o`02
o`0000;o003o00?o0000o`00ool00?l00_l00?l01_l0003o003oo`00ool0003o003oo`0000?o003o
00?o0000o`00ool00?l00_l00?l01_l0003o003oo`00ool0003o003oo`0000?o003o00?o0000o`00
ool00?l00_l00?l00ol0003o003oo`00o`02o`0001Cooooo0_l00004ooooo`04o`000?oooooooooo
o`0000cooooo000Jooooo`03o`000?oooooooooo00[ooooo00Coo`00o`000?l0003o00000_ooool4
o`0000?oo`0000Co0000ool00?oo003o00000_oo00000ol0003oo`00o`000003ool00004o`000?oo
003oo`00ool000Co000000?oo`00o`000?oo00000ooo00001_l0003oo`00ool00?l0003oo`00o`00
00;oo`0000Co0000ool00?oo003o00000ooo00001?l0003oo`00ool00?oo0003o`000003o`3o0?l0
003o000000?o0?l000Co0000o`3o0?l0o`3o00000ol0o`02o`000007o`3o0?l0003o0?l0o`3o0?l0
003o0?l0o`000002o`3o00;o000000?o0?l0o`000?l0o`000_l0o`001Ol0003o0?l0o`000?l0o`3o
000000Co0?l000Co0000o`3o0?l0o`3o00000_l0o`003Ol0003o0?l0o`3o0?l0003o0?l0ool00?l0
003oo`00o`000?oo003o0000ool00?l000000_oo0002o`0000;oo`0000Oo0000ool00?l0003o003o
o`000?l00?oo000000?o003o00?o0000o`00ool00?l00_l00?l01_l0003o003oo`000?l0003o003o
o`0000?o003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`000?l00?oo000000Co003o00?o
0000o`00ool00?l00ol000001?l00?oo0000o`00ool00004o`00o`03o`000?l00?oo003o00;o003o
00Go0000o`00ool0003o003oo`000004o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool0
003o003oo`000004o`00o`?o00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000cooooo000Iooooo`03o`000?oooooooooo00cooooo1_l000001?oo003o0000ool00?l00003
ool00007o`000?oo003oo`00ool00?l0003oo`00o`000003ool00003o`000?oo003oo`0000?oo`00
00Ko0000ool00?oo003o0000ool00?l00002ool00005o`000?oo003oo`00ool00?l000000_oo0004
o`000005ool00?l0003oo`00ool00?l000001?oo00001?l0003o003oo`00ool00002o`3o0005o`00
0?l0o`3o0?l0o`3o0?l000000ol0o`02o`0000;o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o
0?l0o`3o0003o`3o0003o`000?l0o`3o0?l000;o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00002
o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000Co0000o`3o0?l0o`3o00000_l0o`09o`0000Coo`00
00Co0000ool00?l0003o00000_l00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo0000o`00
ool000001?l00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00ool000000ol00?l0
1Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00ool000000_l000000ol00?oo0000o`00
o`02o`00o`07o`000?l00?oo003oo`00ool0003o003oo`000003o`00o`05o`000?l00?oo003oo`00
ool000000ol00?l00ol0003o003oo`000003o`00o`05o`000?l00?oo003oo`00ool000001?l00?l0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00003?oo
ool001Sooooo00?o0000ooooooooool03_ooool8o`00000:ool00?l0003oo`00o`000?oo003o0000
ool00?l0003oo`00o`0000Coo`0000Ko0000ool00?l0003o0000ool00?l00003ool00003o`000?oo
003oo`0000Co000000?oo`00o`000?oo00000ooo00000ol0003oo`00ool00006o`0000;oo`0000Ko
0000ool00?l00?oo0000o`3o0?l00002o`3o0003o`000?l0o`3o000000;o0?l000Go0000o`3o0?l0
o`3o0?l0o`000003o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l000000ol0o`000ol0
003o0?l0o`000003o`3o0003o`000?l0o`3o0?l000Co000000Go0?l0o`000?l0o`3o0?l0o`000002
o`3o0003o`000?l0o`3o0?l000;o000000Goo`00o`000?l0003oo`00o`000002ool000;o00000_oo
00000ol0003oo`00ool00002o`0000?o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00
ool00?oo000000Co003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`00ool00?oo000000?o
003o00?o0000o`00ool00?l00ol00?l01?l0003o003oo`00ool00?l2o`0000;o003o00?o0000o`00
ool00?l00ol00?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00ool00?l00ol00?l0
1Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00ool00?l00_l00?l00ol0003o003oo`00
000Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00003?ooool001Sooooo00?o
0000ooooooooool03_ooool5o`000006ool00?l0003oo`00o`000?oo003o00000ooo00000ol0003o
o`00o`000002ool00003o`000?oo003o000000Coo`000ol000000ooo003o0000ool00003ool00006
o`000?oo003oo`00o`000?oo003o00000_oo00001Ol0003oo`00ool00?oo003o000000;oo`0000?o
0000ool00?oo00001Ol00002o`00o`03o`3o0?l0003o0?l000;o00001?l0o`001Ol0003o0?l0o`00
0?l0o`3o000000?o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0003o`3o00?o0000
00?o0?l0o`000?l0o`000_l0o`001?l0003o0?l0o`3o0?l0o`0@o`000003ool00?l0003oo`0000;o
o`0000Ko0000ool00?oo003o0000ool00?l00005o`00o`05o`000?l00?oo003oo`00ool000000ol0
0?l00ol0003o003oo`00o`02o`00o`06o`000?l00?oo003oo`000?l00?oo00000ol00?l00ol0003o
003oo`00o`02o`00o`06o`000?l00?oo0000o`000?l00?oo00000ol00?l00ol0003o003oo`00o`03
o`000004o`00ool0003o003oo`0000Co003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`00
0?l00?oo000000Co003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`000?l00?oo000000?o
003o0_l0000@ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0:oooo
o`005oooool00ol0003oooooooooo`0?ooooo`04ool00?l0003o0000o`0000;o0?l01?l00002ool0
0004o`000?oo003o0000o`0000Coo`0000?o0000ool00?oo00000_oo00001ol0003oo`00ool00?oo
003o0000ool00?l000000_oo00001Ol0003oo`00ool00?oo003o000000;oo`001?l000001Ooo003o
0000ool00?oo003o000000Coo`0000Ko0000ool00?oo003o0000o`00ool00002o`3o0004o`000?l0
o`3o0?l0o`3o00;o00000_l0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`000ol0
003o0?l0o`000002o`3o00;o000000?o0?l0o`000?l0o`000_l0o`001Ol0003o0?l0o`000?l0o`3o
000000Co0?l000Co0000o`3o0?l0o`3o00000_l0o`001Ol0003o0?l0o`3o0?l0003o0?l000;oo`00
1?l000000ooo003o0000ool00005ool000;o000000Go003oo`000?l0003o003oo`000003o`00o`03
o`000?l00?oo003o00;o003o00Go0000o`00ool0003o003oo`000004o`00o`03o`000?l00?oo003o
00;o003o00Go0000o`00ool0003o003oo`000004o`00o`03o`000?l00?oo003o00;o003o00Co0000
o`00ool0003o003o0_l00002o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003o
o`000003o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003oo`000003o`00o`05
o`000?l00?oo003oo`00ool000000_l00?l00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00;ooooo0_l0000=ooooo`005_ooool00ol0003oooooooooo`0Aooooo`;o00000_l0o`02o`000007
ool00?l0003oo`00ool00?l0003oo`00o`000003ool000;o000000Coo`00o`000?oo003oo`000_l0
0004ool00003o`000?oo003oo`0000Co000000?oo`00o`000?oo00000ooo00000ol0003oo`00ool0
0003o`000003ool00?l0003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000002o`00o`;o0000
0_l0o`02o`0000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o
0?l000?o0000o`3o0?l0o`000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l000?o0000o`3o
0?l000000_l0o`001?l0003o0?l0o`3o0?l00002o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000Ko
0000ool00?l0003oo`00o`000?oo0003o`0000Coo`0000Co0000ool00?oo003o00000_l00?l01Ol0
003o003oo`00ool00?oo000000;o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00ool0
0?oo000000?o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo000000?o003o
00?o0000o`00ool000000ol00?l00ol0003o003oo`00o`02o`0000?o003o00?o0000o`00ool00?l0
0ol00?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00ool00?l00ol00?l01Ol0003o
003oo`00ool00?oo000000?o003o00?o0000o`00ool00?l00_l00?l3o`0000cooooo00?o0000oooo
ooooool04Oooool001Gooooo00?o0000ooooooooool04Oooool00ol0003o003oo`000005o`000003
ool00?l0003oo`0000;o00000_oo0002o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00o`000?oo003o000000Coo`0000Ko0000ool00?oo003o0000ool00?l00002ool00005o`000?oo
003oo`00ool00?l000000_oo0007o`000003ool00?l0003oo`0000;o003o00?o0000o`3o0?l00000
0ol0o`001?l0003o0?l0o`3o0?l00003o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000002
o`3o00;o000000?o0?l0o`000?l0o`000_l0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o
0?l000Co000000Go0?l0o`000?l0o`3o0?l0o`000002o`3o0004o`000?l0o`3o0?l0o`0000;oo`00
00Co0000ool00?l0003o00000_oo0002o`0000;oo`0000?o0000ool00?oo00000_l00004o`00o`03
o`000?l00?oo003o00;o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o
00?o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00?o003o00Go0000
o`00ool00?oo003oo`000003o`00o`0:o`000?l00?oo0000o`000?l00?oo0000o`00ool0003o003o
o`0000Co003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`000?l00?oo000000Co003o00Go
0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000000?o003o0_l00009ooooo`;o0000
4oooool001Gooooo00?o0000ooooooooool04?ooool01?l0003o003oo`000?l00002o`3o0005o`00
0?l0o`3oo`00o`000?oo00000_l000000ooo003o0000ool00002ool00007o`000?oo003oo`00ool0
0?l0003oo`00o`000003ool00003o`000?oo003o000000;oo`0000Go0000ool00?oo003oo`00o`00
0002ool000Co000000?oo`00o`000?oo00000_oo00001Ol0003oo`00ool00?oo003o000000;oo`00
0ol000000ooo003o0000o`00o`02o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0o`001Ol0003o
0?l0o`000?l0o`3o000000?o0?l000?o0000o`3o0?l0o`000ol0o`000ol0003o0?l0o`3o0002o`3o
0005o`000?l0o`3o0000o`3o0?l000001?l0o`000ol0003o0?l0o`3o000:o`000006o`3o0?l0003o
0000ool00?l0003oo`000_l00003ool000;o000000Coo`00o`000?oo003o00001?l00?l01_l0003o
003oo`00ool0003o003oo`0000?o003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`000?l0
0?oo000000Co003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`000?l00?oo000000Co003o
00?o0000o`00ool00?l00_l00?l01?l0003o003oo`000?l00?l2o`0000;o003o00?o0000o`00ool0
0?l00_l00?l01_l0003o003oo`00ool0003o003oo`0000?o003o00?o0000o`00ool00?l00_l00?l0
1Ol0003o003oo`000?l00?oo000000Co003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04Oooool001?ooooo0_l0000Booooo`;o000000?o
003oo`000?l0o`001Ol0o`02o`000009ool00?l0003oo`00ool00?l0003oo`00o`000?oo003o0000
00?oo`0000Go0000ool00?oo003oo`00o`000003ool000Co000000?oo`00o`000?oo00000ooo0000
0ol0003oo`00ool00003o`000003ool00?l0003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0002ool000Co00000_l0o`001_l0003o0?l0o`3o0?l0o`3o0000o`3o00;o00000ol0o`000ol0003o
0?l0o`000002o`3o00;o000000Oo0?l0o`000?l0o`3o0?l0o`000?l0o`3o000000?o0?l000?o0000
o`3o0?l000000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o0000
0_l0o`000ol0003o0?l0o`000005o`000003ool00?l0003oo`0000Coo`001Ol000000ol00?oo0000
o`00o`03o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool0003o003oo`000003o`00o`05
o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003oo`000003o`00o`05o`000?l00?oo003o
o`00ool000000ol00?l00ol0003o003oo`000003o`00o`03o`000?l00?oo003o00;o00000_l00?l0
0ol0003o003oo`000004o`00o`05o`000?l00?oo003oo`00ool000000_l00?l00ol0003o003oo`00
0003o`00o`05o`000?l00?oo003oo`00ool000001?l00?l00ol0003o003oo`00o`02o`00o`?o0000
1_ooool2o`0001;ooooo000Cooooo`03o`000?oooooooooo017ooooo00?o0000o`00ool000000ol0
o`002_l0003o0?l0o`3o0?l0o`3o0000ool00?l0003oo`00o`000?oo0002o`0000?oo`0000?o0000
ool00?l000000ooo00000ol0003oo`00ool00003ool00006o`000?oo003oo`00o`000?oo003o0000
0_oo00001Ol0003oo`00ool00?oo003o000000;oo`000ol00002ool00004o`000?oo003oo`00o`00
00?oo`0000Co0000ool00?l00?oo003o0_l00002o`3o0004o`000?l0o`3o0?l0o`0000?o0?l000Co
0000o`3o0?l0o`3o00001Ol0o`000ol0003o0?l0o`3o0002o`3o0005o`000?l0o`3o0?l0o`3o0?l0
00000ol0o`04o`000005o`3o0?l0003o0?l0o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l00002
o`3o0006o`000?oo003o0000ool00?l0003oo`000ol00004ool00006o`000?oo003oo`00o`000?l0
0?oo00000ol00?l01ol0003o003oo`00ool00?oo0000o`00ool000000ol00?l01Ol0003o003oo`00
ool00?oo000000?o003o00?o0000o`00ool00?l00ol00?l01Ol0003o003oo`00ool00?oo000000?o
003o00?o0000o`00ool00?l00ol00?l01Ol0003o003oo`00ool00?oo000000?o003o00Ko0000o`00
ool0003o0000o`00ool00003o`00o`03o`000?l00?oo003o00;o003o00?o0000o`00ool00?l00_l0
0?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00ool00?l00_l00?l01_l0003o003o
o`00ool0003o003oo`0000?o003o00?o0000ooooooooool00_ooool00ol0003oooooo`00000Boooo
o`004_ooool00ol0003oooooooooo`0Aooooo`04o`000?l00?oo003oo`0000?o0?l01_l000001?oo
003o0000ool00?l00003ool00004o`000?oo003oo`00o`0000Coo`0000Ko0000ool00?l0003o0000
ool00?l00003ool00003o`000?oo003oo`0000Co000000?oo`00o`000?oo00000_oo00000ol0003o
o`00ool00007o`000006ool00?l0003oo`00ool00?l00?oo00000_l0o`001?l0003o0?l0o`000?l0
0003o`3o0004o`000?l0o`3o0?l0o`0000?o0?l000?o0000o`3o0?l000000ol0o`000ol0003o0?l0
o`000003o`3o0003o`000?l0o`3o0?l000;o0?l000Co0000o`3o0?l0o`3o0?l01_l000001Ol0o`3o
0000o`3o0?l0o`3o000000;o0?l00_l000000ooo003o0000ool00002o`0000;oo`000_l00003ool0
0004o`000?oo003o0000o`0000?o003o00?o0000o`00ool00?l00ol00?l01Ol0003o003oo`00ool0
0?oo000000?o003o00?o0000o`00ool00?l00_l00?l01_l0003o003oo`000?l0003o003oo`0000?o
003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`000?l00?oo000000Co003o00?o0000o`00
ool00?l00_l00?l01?l0003o003oo`000?l00?l2o`0000;o003o00?o0000o`00ool00?l00_l00?l0
1_l0003o003oo`00ool0003o003oo`0000?o003o00?o0000o`00ool00?l00_l00?l01Ol0003o003o
o`000?l00?oo000000Co003o00?o0000o`00ool00?l00_l00?l00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo013ooooo000Booooo`03o`000?oooooooooo017ooooo00Go0000o`00ool00?oo
0000o`3o0003o`0000;o0?l00_l000001?oo003o0000o`000?l00002ool00004o`000?oo003oo`00
o`0000Coo`000_l00004ool000?o000000?oo`00o`000?oo00000ooo00000ol0003oo`00ool00003
o`000003ool00?l0003oo`0000?oo`0000Co0000ool00?oo003o00000_oo0003o`000005ool00?l0
003o003oo`00ool0o`000_l00002o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`001?l0003o
0?l0o`3o0?l00005o`3o0003o`000?l0o`3o0?l000;o0?l000Go0000o`3o0?l0003o0?l0o`000004
o`3o0004o`000?l0o`3o0?l0o`0000;o0?l01ol000001_l0o`3oo`00o`000?oo003o0000ool000;o
00000ooo0002o`0000;oo`0000?o0000ool00?l000000ol00?l01_l0003o003oo`000?l0003o003o
o`0000?o003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`000?l00?oo000000Co003o00?o
0000o`00ool00?l00_l00?l01Ol0003o003oo`000?l00?oo000000?o003o00Go0000o`00ool00?oo
003oo`000003o`00o`03o`000?l00?oo000000?o003o00?o0000o`00ool00?l00_l00002o`00o`03
o`000?l00?oo000000Co003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo0000
00?o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo000000Oooooo00?o0000
ooooooooool04?ooool000Gooooo0_l0000:ooooo`03o`000?oooooooooo017ooooo00?o0000o`00
ool00?l00ol000000ol0o`3o0000o`3o0002o`3o0004o`000?l0o`3o0?l0o`0000;oo`0000Oo0000
ool00?oo003o0000ool00?l0003oo`0000;o000000Ooo`00o`000?oo003oo`00o`000?oo003o0000
00?oo`0000?o0000ool00?l000000_oo00001Ol0003oo`00ool00?oo003o000000;oo`0000?o0000
ool00?l000000_oo00001?l0003oo`00ool00?l00003ool00003o`000?oo003oo`0000;o00000_l0
0?l01?l0003o0?l0o`3o0?l00002o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`001?l0003o
0?l0o`3o0?l0o`02o`000007o`3o0?l0003o0?l0o`3o0?l0003o0?l0o`000003o`3o0003o`000?l0
o`3o000000;o0?l000Co0000o`3o0?l0o`3o00000ol0o`001?l0003o0?l0o`3o0?l00002o`3o0003
o`000?l0o`3o000000Go000000?oo`00o`000?oo00001?oo00000ol0003oo`00o`000002o`000003
o`00ool0003o003o00?o003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo0000
00?o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo000000?o003o00Go0000
o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00?o003o00Go0000o`00ool00?oo003o
o`000003o`00o`06o`000?l00?oo0000o`000?l00?oo00000ol00?l00ol0003o003oo`00o`02o`00
o`03o`000?l00?oo003o00;o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo
003o00?o003o00?o0000ooooooooool01_ooool2o`0000?ooooo1Ol00003ooooo`;o00001?ooool0
00Cooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0Aooooo`05o`000?l00?oo
003oo`00ool000001_l0o`02o`0000;o0?l000Koo`00o`000?oo003oo`00o`000?oo0002o`0000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000Co
000000?oo`00o`000?oo00000_oo00000ol0003oo`00ool00004o`000005ool00?l0003oo`00ool0
0?l000001?oo00000ol0003o003oo`00o`02o`0000;o0?l000Co0000o`3o0?l0003o00000ol0o`00
0ol0003o0?l0o`000002o`3o00;o00000_l0o`000ol0003o0?l0o`3o0002o`3o0005o`000?l0o`3o
0?l0o`3o0?l000000ol0o`04o`000005o`3o0?l0003o0?l0o`3o0?l000000_l0o`001?l0003o0?l0
o`3o0?l00002o`3o0006o`000?oo003o0000ool00?l0003oo`001?l00003ool00006o`000?oo003o
o`00o`000?l00?oo00000ol00?l00ol0003o003oo`00o`02o`00o`03o`000?l00?oo003o00;o003o
00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00?o003o00Go0000o`00ool0
0?oo003oo`000003o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool0003o003oo`000004
o`00o`05o`000?l00?oo003oo`00ool000000_l00?l01?l0003o003oo`000?l00002o`00o`03o`00
0?l00?oo003o00;o003o00Go0000o`00ool0003o003oo`000004o`00o`03o`000?l00?oo003o00;o
003o00Go0000o`00ool0003o003oo`00000;ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00003ooooo`001?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo017ooooo00Ko0000o`00ool00?oo0000o`00ool00002o`3o0003
o`000?l0o`3o0?l000;o00000_l0o`04o`000003ool00?l0003o000000?oo`0000?o0000ool00?l0
00000_oo00000ol0003oo`00o`000002ool00003o`000?oo003o000000Coo`0000?o0000ool00?oo
00000ol000000ooo003o0000ool00003ool00003o`000?oo003oo`0000Co000000Koo`00o`000?oo
003oo`00o`000?oo0002o`00o`04o`000?l0o`3o0000o`3o00;o00000ol0o`001?l0003o0?l0o`3o
0?l00005o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000003o`3o0005o`000?l0o`3o0?l0
o`3o0?l000001?l0o`06o`00000<o`3o0?l0003o0?l0o`3o0?l0003o0?l0o`000?l0o`3o0000ool0
0?l0003oo`000_l00003ool00004o`000?oo003oo`00ool000;o000000?oo`00o`000?l00?l00_l0
0?l00ol0003o003oo`00o`02o`00o`06o`000?l00?oo003oo`000?l00?oo00000ol00?l00ol0003o
003oo`00o`02o`00o`05o`000?l00?oo0000o`00ool000001?l00?l00ol0003o003oo`00o`02o`00
o`05o`000?l00?oo0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o
0000o`00ool000001?l00?l00ol0003o003oo`00o`02o`0000;o003o00?o0000o`00ool000000ol0
0?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00ool000000ol00?l00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`001?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo013o
oooo00?o0000o`00ool00?l00_l00?l01Ol0003o0?l0o`3o0?l0o`3o000000;o0?l01Ol000001?l0
o`3o0000o`000?l00003ool00004o`000?oo003oo`00o`0000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00o`000002ool00005o`000?oo003oo`00ool00?l000000_oo00000ol0003oo`00
o`000002ool00005o`000?oo003oo`00ool00?l000000_oo00000ol0003oo`00ool00006o`000004
o`00ool0o`3o0?l0o`0000?o0?l000Co0000o`3o0?l0o`3o00000ol0o`02o`000005o`3o0?l0003o
0?l0o`3o0?l000000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l000?o0000o`3o0?l0o`00
0ol0o`001?l0003o0?l0o`3o0?l00002o`3o00Oo000000Ko0?l0o`000?oo003oo`00o`000?oo0002
o`0000?oo`000_l00002ool00003o`000?oo003o000000;o003o00Ko0000o`00ool00?oo0000o`00
ool00004o`00o`05o`000?l00?oo003oo`00ool000000_l00?l00ol0003o003oo`000003o`00o`05
o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003oo`000003o`00o`05o`000?l00?oo003o
o`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo003oo`00ool000001?l0
0?l01_l0003o003oo`000?l0003o003oo`0000?o003o00Go0000o`00ool00?oo003oo`000005o`00
o`05o`000?l00?oo003oo`00ool000003Oooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`01ooooo`001?ooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooooooo017ooooo00Co0000o`00ool0003o003o0_l00002o`3o0003o`00
0?l0o`3o000000;o00000_l0o`002?l0003o0?l0o`3o0?l0003oo`00o`000?oo003o00000_oo0000
1ol0003oo`00ool00?oo003o0000ool00?l000000_oo00000ol0003oo`00o`000003ool000Co0000
00?oo`00o`000?oo00000_oo00000ol0003oo`00ool00004o`000005ool00?l0003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00003o`000004o`00ool0003o0?l0o`0000?o0?l000Co0000o`3o
0?l0o`3o0?l00_l00002o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l0o`000_l0o`00
0ol0003o0?l0o`3o0002o`3o0006o`000?l0o`3o0000o`000?l0o`3o00000_l0o`001Ol0003o0?l0
o`3o0?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0000o`3o0008o`0000Coo`000_l000001Ooo
003o0000o`000?l00?oo000000Co003o00Go0000o`00ool00?oo003oo`000004o`00o`03o`000?l0
0?oo003o00;o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00?o003o
00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool0
003o003oo`000003o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool00?oo0000o`00o`02
o`0000;o003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`000?l00?oo000000Co003o00?o
0000ooooooooool02oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000?ooooo0004ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool04Oooool02?l0003o003oo`00ool00?oo0000o`00ool0003o0?l00ol000001Ol0o`3o0000o`3o
0?l0o`3o000000?o0?l000Ko0000ool00?oo003o0000ool00?l00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000?o000000?o
o`00o`000?oo00000ooo00000ol0003oo`00ool00004o`000005ool00?l0003oo`00ool00?l00000
0_oo00001?l0003oo`00o`00ool00?l2o`0000;o0?l000?o0000o`3o0?l000000_l0o`001Ol0003o
0?l0o`3o0?l0o`3o000000?o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`000002o`3o
0003o`000?l0o`3o000000Co0?l01_l000001Ol0o`3o0000o`3o0?l0o`3o000000;o0?l000_o0000
o`3o0?l0o`3o0000ool00?l0003oo`00o`000?oo003o0000ool00002o`0000?oo`0000[o0000ool0
0?oo003o0000o`00ool0003o003oo`000?l00?oo00000ol00?l00ol0003o003oo`00o`02o`00o`06
o`000?l00?oo003oo`000?l00?oo00000ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo
0000o`00ool000001?l00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00ool00000
0ol00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00ool000001?l00?l00ol0003o
003oo`00o`02o`0000;o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo0000
017ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo007ooooo0005ooooo`;o00001Oooool2o`0001;ooooo00?o0000o`00ool00?l00_l00?l4
o`000004o`3o0?l0003o0?l0o`0000?o0?l000Go0000o`3o0?l0o`3o0000o`3o0004o`0000Coo`00
00?o0000ool00?l000000_oo0002o`000004ool00?l0003oo`00ool000;o00001?oo00001_l0003o
o`00ool00?l0003oo`00o`0000;oo`0000Go0000ool00?oo003oo`00o`000002ool00003o`000?oo
003oo`0000Co000000Goo`00o`000?oo003oo`00o`000002o`00o`04o`000?l0o`3o0000o`0000Co
0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o
0?l0o`000_l0o`000ol0003o0?l0o`3o0002o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`06
o`000003o`3o0?l0003o000000?o000000Koo`00o`000?oo003o0000ool00?l00003ool00003o`00
0?oo003oo`0000;o000000?oo`00o`000?l00?l00_l00?l01Ol0003o003oo`00ool00?oo000000;o
003o00?o0000o`00ool000001?l00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00
ool000000ol00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00ool000001?l00?l0
1Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`00
ool00?oo000000Co003o0ol00002o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0003o
ooooooooo`0@ooooo`04o`000?ooooooooooooooo`?o00001?ooool2o`0000Cooooo000<ooooo`;o
00004_ooool00ol0003o003oo`00o`02o`000003o`00ool0003o0?l000?o0?l00_l00003o`3o00Go
000000Go0?l0o`000?oo003oo`00o`000002ool00003o`000?oo003o000000Goo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00o`000?oo003o000000?oo`0000?o0000ool00?oo00001?l00000
1Ooo003o0000ool00?oo003o000000Coo`0000?o0000ool00?oo00001?l00003o`00o`03o`3o0?l0
003o0?l000;o0?l00_l00002o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000002o`3o0003
o`000?l0o`3o000000;o0?l000?o0000o`3o0?l000000ol0o`04o`000003o`3o0?l0003o0?l000;o
0?l000Co0000o`3o0?l0o`3o00000_l0o`02o`000004o`3o0?l0003o0?l0o`0000;oo`0000Go0000
ool00?l0003oo`00o`000003ool00006o`000?oo003oo`00o`000?oo003o00000_l00?l01Ol0003o
003oo`00ool00?oo000000Co003o00Go0000o`00ool00?oo003oo`000004o`00o`03o`000?l00?oo
003o00;o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00;o003o00Go
0000o`00ool00?oo003oo`000004o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool0003o
003oo`000003o`00o`03o`000?l00?oo003o00;o003o00Co0000o`00ool0003o003o0_l00003o`00
o`03o`000?l00?oo003o00;o003o00?o0000ooooooooool03oooool2o`00013ooooo000;ooooo`03
o`000?oooooooooo017ooooo00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l0o`3o0?l0
00;o000000?o0?l0o`000?l000000ol00002o`3o0003o`000?l0o`3o0?l000;o00000_oo00001?l0
003oo`00o`000?l00002ool000;o000000Ooo`00o`000?oo003oo`00o`000?oo003o000000?oo`00
0ol000000ooo003o0000ool00003ool00003o`000?oo003oo`0000?o000000?oo`00o`000?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000;oo`0000?o0000ool00?l00?l00_l00002o`3o00;o
00000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000_l0o`000ol0
003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000;o0?l000Co0000o`3o0?l0o`3o0?l00ol00000
1Ol0o`3o0000o`3o0?l0o`3o000000?o0?l000?o0000o`3o0?l000000_l0o`08o`0000Coo`000_l0
00001Ooo003o0000o`000?l00?oo000000Co003o00Go0000o`00ool0003o003oo`000003o`00o`03
o`000?l00?oo003o00;o003o00Ko0000o`00ool00?oo0000o`00ool00003o`00o`03o`000?l00?oo
003o00;o003o00Go0000o`00ool0003o003oo`000003o`00o`03o`000?l00?oo003o00;o003o00Ko
0000o`00ool00?oo0000o`00ool00003o`00o`05o`000?l00?oo003oo`00ool000000_l00?l00ol0
003o003oo`000003o`00o`03o`000?l00?oo003o00;o00000ol00?l00ol0003o003oo`00000Coooo
o`03o`000?oooooooooo00kooooo000:ooooo`;o00004_ooool01Ol0003o003oo`00ool00?oo0000
00;o003o00?o0000o`3o0?l0o`001Ol00002o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000Go0000
o`3o0?oo003o0000ool00002o`0000?oo`0000Co0000ool00?oo003o00001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000?o0000ool00?l000000_oo00001Ol0003oo`00ool00?oo003o0000
00;oo`001ol000001Ooo003o0000ool00?oo003o000000;oo`0000?o003oo`000?l00?l00_l00000
0ol0o`3o0000o`000003o`3o0004o`000?l0o`3o0?l0o`0000?o0?l000?o0000o`3o0?l000000_l0
o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o000000Co0?l000?o0000o`3o0?l0o`000ol0
00001Ol0o`3o0000o`3o0?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o00000ooo00001?l0003o
o`00o`000?oo0002o`000006ool00?l0003oo`00ool00?l0003oo`000_l00002o`00o`03o`000?l0
0?oo000000?o003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000000Co003o
00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000000?o003o00Go0000o`00ool0
0?oo003oo`000002o`00o`03o`000?l00?oo000000Co003o00Go0000o`00ool00?oo003oo`000003
o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool00?oo003oo`000003o`00o`04o`000?l0
0?oo0000o`0000;o003o00?o0000ooooooooool04oooool00ol0003oooooooooo`0=ooooo`002_oo
ool01?l0003oooooo`000?l0000?ooooo`03o`000?l00?oo003o00;o003o00Co0000o`00ool0003o
00000_l0o`02o`000003o`3o0?l0003o0?l000Go0?l000?o0000o`3o0?l0o`001Ol00002ool00005
o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00o`000003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00001?l000000ooo003o0000ool00002ool00005o`000?oo003oo`00
ool00?l000000_oo0006o`000005ool00?l0003o003oo`00ool0o`000_l00002o`3o0005o`000?l0
o`3o0?l0o`3o0?l000000ol0o`001?l0003o0?l0o`3o0?l00004o`3o0003o`000?l0o`3o0?l000;o
0?l000?o0000o`3o0?l000000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l03?l00003ool0
0003o`000?oo003o000000?oo`000_l00004ool00005o`000?l00?oo003oo`00ool000000ol00?l0
1Ol0003o003oo`00ool00?oo000000Co003o00Go0000o`00ool00?oo003oo`000004o`00o`03o`00
0?l00?oo003o00;o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00;o
003o00Go0000o`00ool00?oo003oo`000004o`00o`05o`000?l00?oo003oo`00ool000000_l00?l0
0ol0003o003oo`000003o`00o`03o`000?l00?oo003o00;o003o00Co0000o`00ool0003o003o0_l0
000Eooooo`;o00003oooool000[ooooo00Co0000oooooooooooooooo0ol0000;ooooo`06o`000?l0
0?oo003oo`000?l00?oo00000_l00?l00ol0003o0?l0o`000002o`0000Go0?l000Co0000o`3o0?l0
o`3o0?l01?l000000ol0o`3o0000ool00002o`0000;oo`0000Go0000ool00?l0003oo`00o`000003
ool00005o`000?oo003oo`00ool00?l000000_oo00000ol0003oo`00o`000004ool00003o`000?oo
003oo`0000?o000000?oo`00o`000?oo00000_oo00001Ol0003oo`00ool00?oo003o000000;oo`00
00?o0000ool00?oo00000ol000001Ol00?oo0000o`3o0?l0o`3o000000;o0?l000Go0000o`3o0?l0
003o0?l0o`000003o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000002o`3o0003o`000?l0
o`3o000000?o0?l01?l000000ol0o`3o0000o`3o0002o`3o0004o`000?l0o`3o0?l0o`0000;o0?l0
00Ko0000o`3o0?l0o`3o0000o`3o0?oo0005o`000003ool00?l0003oo`0000;oo`0000?o0000ool0
0?oo00000_oo0002o`000003o`00ool0003o003o00;o003o00?o0000o`00ool00?l00_l00?l01Ol0
003o003oo`000?l00?oo000000?o003o00?o0000o`00ool00?l00_l00?l01_l0003o003oo`00ool0
003o003oo`0000?o003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000000?o
003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000000Co003o00Go0000o`00
ool00?oo003oo`000002o`00o`03o`000?l00?oo000000?o003o00?o0000ooooooooool00_l0000B
ooooo`03o`000?oooooo000000oooooo000:ooooo`03o`000?oooooooooo00Cooooo0_l00008oooo
o`03o`000?l00?oo003o00;o003o00Co0000o`00ool00?oo003o0_l000001Ol0o`3o0000o`3o0?l0
o`3o000000?o0?l01Ol000000ol0o`3o0000o`3o0002o`000005o`3o0?oo003o0000o`000?oo0000
0_l00003ool00003o`000?oo003o000000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
o`000002ool00005o`000?oo003oo`00ool00?l000000_oo0007o`000005ool00?l0003oo`00ool0
0?l000000ooo00000ol0003oo`00o`00o`02o`0000?o0?l000Co0000o`3o0?l0003o00000ol0o`00
0ol0003o0?l0o`000002o`3o0004o`000?l0o`3o0?l0o`0000Co0?l000?o0000o`3o0?l0o`000_l0
o`001?l0003o0?l0o`3o0?l0o`03o`000005o`3o0?l0003o0?l0o`3o0?l000000_l0o`001?l0003o
0?l0o`3o0?l00002o`3o00;o00000_oo00001?l0003oo`00o`000?l00004ool00007o`000?oo003o
o`00ool00?l0003o003oo`000003o`00o`06o`000?l00?oo003oo`000?l00?oo00000ol00?l01Ol0
003o003oo`00ool00?oo000000;o003o00?o0000o`00ool000001?l00?l01Ol0003o003oo`00ool0
0?oo000000?o003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`00ool00?oo000000?o003o
00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`00ool00?oo000000Co003o00?o0000o`00ool0
0?l00_l00?l01Ol0003o003oo`00ool00?oo000000Gooooo0_l0000Booooo`03o`000?oooooooooo
00gooooo0009ooooo`03o`000?oooooooooo00Oooooo0_l00006ooooo`06o`000?l00?oo0000o`00
0?l00?oo00000_l00?l00ol0003o0?l0o`3o0002o`0000;o0?l000?o0000o`3o0?l000000_l00002
o`3o0003o`000?l0o`3o000000?o0?l000?o0000o`3o0?oo00000ol00003ool00004o`000?oo003o
o`00o`0000?oo`0000?o0000ool00?oo00000_l000001?oo003o0000ool00?oo0004o`000003ool0
0?l0003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000002ool000?o000000Goo`00o`000?oo
003oo`00o`000002ool00003o`000?l00?oo003o00;o000000?o0?l0o`000?l000000ol0o`001?l0
003o0?l0o`3o0?l00004o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000003o`3o00;o0000
1?l0o`000ol0003o0?l0o`3o0003o`000005o`3o0?l0003o0?l0o`3o0?l000000_l0o`000ol0003o
0?l0o`000003o`0000;oo`000_l000001Ooo003o0000o`000?oo003o000000?oo`0000?o0000ool0
0?l000000ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo003oo`00ool000000ol00?l0
0ol0003o003oo`00o`02o`00o`05o`000?l00?oo003oo`00ool000001?l00?l01Ol0003o003oo`00
ool00?oo000000;o003o00?o0000o`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`05o`00
0?l00?oo0000o`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo0000o`00
ool000001?l00?l00ol0003oooooooooo`06ooooo`;o00004?ooool2o`0000kooooo0009ooooo`03
o`000?oooooooooo00Wooooo0ol00002ooooo`03o`000?l00?oo003o00;o003o00Go0000o`00ool0
0?oo003oo`000002o`3o0003o`000?l0o`3o0?l000?o000000Go0?l0o`000?l0o`3o0?l0o`000002
o`3o00;o00000_l0o`04o`000003ool00?l0003oo`0000;o000000?oo`00o`000?oo00000ooo0000
0ol0003oo`00ool00003ool00005o`000?oo003oo`00ool00?l000000ooo0003o`000003ool00?l0
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000002ool000Ko000000Coo`00o`000?l00?oo
003o0_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0
o`3o000000;o0?l000Co0000o`3o0?l0o`3o00000ol0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o
0?l000000ol0o`000ol0003o0?l0o`3o000:o`000004o`3o0?l0003oo`00o`0000;oo`000ol00002
ool000;o00000_oo00000ol0003oo`00o`000003o`00o`05o`000?l00?oo0000o`00ool000000ol0
0?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo0000o`00ool000000ol00?l01Ol0003o003o
o`00ool00?oo000000;o003o00?o0000o`00ool000001?l00?l01Ol0003o003oo`00ool00?oo0000
00;o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o0000
o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo000000cooooo0_l0000>ooooo`;o00003_oo
ool000Wooooo00?o0000ooooooooool03?ooool3o`0000?o003o00Co0000o`00ool00?oo003o0_l0
00001?l0o`3o0000o`000?l0o`02o`0000Go0?l000Co0000o`3o0?l0o`3o0?l01Ol000000ol0o`3o
0000o`000002ool00004o`000?oo003o0000o`0000;oo`000_l000000ooo003o0000ool00002o`00
0003ool00?l0003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000003ool000Oo000000?oo`00
o`000?oo00000_oo00001?l0003oo`00ool00?l00002ool000?o00000_l00?l00ol0003o0?l0o`00
0003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`000ol0003o0?l0o`3o0002o`3o0003o`00
0?l0o`3o0?l000;o0?l000?o0000o`3o0?l0o`000ol0o`03o`000003o`3o0?l0003o0?l000;o0?l0
00Co0000o`3o0?l0o`3o00000_l0o`001Ol0003o0?l0o`3o0?l0003o0?l000Ko000000?oo`00o`00
0?l000000_oo00000ol0003oo`00ool00004o`000003o`00ool0003o003o00;o003o00Go0000o`00
ool00?oo003oo`000002o`00o`03o`000?l00?oo000000?o003o00Go0000o`00ool00?oo003oo`00
0003o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool00?oo003oo`000004o`00o`03o`00
0?l00?oo003o00;o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00;o
003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?oooooooooo00gooooo0_l0000=oooo
o`03o`000?oooooooooo00cooooo0009ooooo`03o`000?oooooooooo00gooooo00Go0000o`00ool0
0?oo003oo`000003o`00o`;o000000?o0?l0o`000?l0o`000_l000001Ol0o`3o0000o`3o0?l0o`3o
000000;o0?l01Ol00002o`3o0007o`000?l0o`3o0?l0o`3o0?oo003o0000ool00002o`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo
003o00001?oo00001Ol0003oo`00ool00?oo003o000000;oo`000ol000001Ooo003o0000ool00?oo
003o000000Coo`0000?o0000o`00ool00?l00_l00002o`3o0005o`000?l0o`3o0000o`3o0?l00000
0ol0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`000ol0003o0?l0o`000002o`3o
00;o000000?o0?l0o`000?l0o`000_l0o`03o`000005o`3o0?l0003o0?l0o`3o0?l000000_l0o`00
1?l0003o0?l0o`3o0?l00002o`3o00;o00000_oo00000ol0003oo`00o`000003o`0000;oo`0000Go
0000ool00?oo003o0000ool00002o`0000?o003o00Go0000o`00ool00?oo003oo`000004o`00o`05
o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo0000
o`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`06o`000?l00?oo003oo`000?l00?oo0000
0ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo0000o`00ool000000ol00?l00ol0003o
003oo`00o`02o`00o`03o`000?oooooooooo00oooooo0_l0000;ooooo`03o`000?oooooooooo00co
oooo0009ooooo`03o`000?oooooooooo00cooooo00Go0000o`00ool00?oo003oo`000003o`00o`05
o`000?l00?oo0000o`000?l0o`000_l00004o`3o0003o`000?l0o`3o000000;o00000_l0o`001?l0
003o0?l0o`3o0?l00002o`3o0003o`000?l0o`3o0?l000;o00000_oo00001_l0003oo`00ool00?l0
003oo`00o`0000;oo`0000?o0000ool00?l000000_oo00000ol0003oo`00o`000003ool00005o`00
0?oo003o0000ool00?l000000ooo00001Ol0003oo`00ool00?oo003o000000;oo`001?l000001Ooo
003o0000ool00?oo003o000000;oo`0000Go0000o`00ool00?oo0000o`3o0002o`0000?o0?l000Go
0000o`3o0?l0003o0?l0o`000003o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l0o`00
0ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l02Ol000000ol0o`3o0000o`000004o`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000?o00000ol00?l01Ol0003o
003oo`00ool00?oo000000;o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo
000000;o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o
0000o`00ool000001?l00?l01?l0003o003oo`00ool00003o`00o`03o`000?l00?oo000000?o003o
00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000001Cooooo0_l00009ooooo`03
o`000?oooooooooo00cooooo0008ooooo`03o`000?oooooooooo00cooooo00Go0000o`00ool00?oo
003oo`000004o`00o`04o`000?l00?oo0000o`3o00;o00000_l0o`000ol0003o0?l0o`3o0002o`00
0003o`3o0?l0003o0?l000Go0?l02Ol00002ool00004o`000?oo003o0000o`0000Coo`0000?o0000
ool00?oo00000_oo0003o`000003ool00?l0003oo`0000;oo`001ol000000ooo003o0000ool00002
ool00004o`000?oo003oo`00o`0000;oo`001Ol00003o`00o`;o00000ol0o`001?l0003o0?l0o`3o
0?l00003o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0
o`000004o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`001?l0003o0?l0o`3o0?l00002o`3o
00;o000000?o0?l0o`000?l0o`000ol00002ool00003o`000?oo003oo`0000;oo`000_l00002ool0
0005o`000?oo003o0000o`00ool000001?l00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo
003oo`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo003oo`00ool00000
0ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0003o
003oo`00o`03o`00o`04o`000?l00?oo003oo`0000Co003o00?o0000o`00ool00?l00_l00?l00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo0_l0000=ooooo`002?ooool00ol0003o
ooooooooo`0;ooooo`05o`000?l00?oo003oo`00ool000000_l00?l01?l0003o003oo`000?l00?l3
o`000005o`3o0?l0003o0?l0o`000?l0o`000_l00006o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o
0?l0o`000003o`3o0005o`000?oo003o0000o`000?oo00000_l00003ool00003o`000?oo003o0000
00;oo`0000?o0000ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000000_oo0003o`000005ool00?l0003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0005o`0000;o0?l000Co0000o`3o0?l0o`3o00000ol0o`001?l0003o0?l0o`3o0?l00004o`3o0003
o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l0o`000_l0o`001?l0003o0?l0o`3o0?l0o`03o`00
0005o`3o0?l0003o0?l0o`3o0?l000000ol0o`000ol0003o0?l0o`000002o`3o00Oo000000?oo`00
o`000?oo00000_oo00000ol0003oo`00o`000003o`0000Co003o00Go0000o`00ool0003o003oo`00
0004o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool0003o003oo`000003o`00o`03o`00
0?l00?oo003o00;o003o00Go0000o`00ool0003o003oo`000003o`00o`05o`000?l00?oo003oo`00
ool000000_l00?l00ol0003o003oo`000003o`00o`05o`000?l00?oo003oo`00ool000000ol00?l0
0ol0003o003oo`00000Iooooo`;o00001oooool00ol0003oooooooooo`0;ooooo`002?ooool00ol0
003oooooooooo`0;ooooo`04o`000?l00?oo003oo`0000Co003o00Co0000o`00ool00?oo00001Ol0
o`02o`000005o`3o0?l0003o0?l0o`3o0?l000000ol0o`04o`0000Go0?l000?o0000o`3o0?oo0000
0ol00003ool00004o`000?oo003oo`00o`0000Coo`0000Go0000ool00?oo003oo`00o`000003ool0
00Co000000?oo`00o`000?oo00000_oo00000ol0003oo`00ool00004o`000005ool00?l0003oo`00
ool00?l000000_oo00002?l0003oo`00o`00ool00?oo0000o`00ool0003o0?l00_l00003o`3o0004
o`000?l0o`3o0?l0o`0000?o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`000003o`3o
00;o00001?l0o`000ol0003o0?l0o`3o0003o`000005o`3o0?l0003o0?l0o`3o0?l000000_l0o`00
0ol0003o0?l0o`3o0002o`0000;oo`0000Co0000ool00?oo003oo`000_l00003ool00009o`000?oo
003o0000ool00?l0003o003oo`000?l00?oo000000?o003o00Go0000o`00ool00?oo003oo`000003
o`00o`03o`000?l00?oo000000?o003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l0
0?oo000000?o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00;o003o
00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00?o003o00?o0000oooooooo
ool06_ooool2o`0000Gooooo00?o0000ooooooooool02oooool000Sooooo00?o0000ooooooooool0
2_ooool01_l0003o003oo`00ool00?oo0000o`00o`;o000000?o003oo`000?l00?l00_l00002o`3o
0004o`000?l0o`3o0?l0o`0000;o0?l000Go0000o`3o0?l0o`3o0000o`3o0003o`0000;o0?l000?o
0000o`3o0?l000000ol0o`06o`000005ool00?l0003o0000ool00?l000000ooo00000ol0003oo`00
o`000003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ol000000ooo003o0000
ool00002ool00004o`000?oo003oo`00o`0000;oo`001?l000001Ooo003o0000ool00?oo003o0000
00;o003o00Go0?l0o`000?l0o`3o0?l0o`000003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0
o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000?o0?l000Go0000o`3o0?l0003o0?l0
o`000003o`3o0003o`000?l0o`3o0?l000_o000000Goo`00o`000?oo003oo`00o`000003ool00003
o`000?oo003oo`0000Coo`000_l00002o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0
003o003oo`00o`03o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003oo`00o`02
o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l0
0?oo0000o`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo0000o`00ool0
00008?ooool2o`0000;ooooo0_l0000=ooooo`002?ooool00ol0003oooooooooo`09ooooo`03o`00
0?l00?oo003o00;o00001?l00?l01?l0003o003oo`000?l00002o`3o0004o`000?l0o`3o0000o`00
00;o0?l000?o0000o`3o0?l0o`000ol000000ol0o`3o0000o`3o0004o`3o0003o`000?l0o`3o0000
00;o000000Co0?l0o`000?l0003oo`000_l000000ooo003o0000o`000002ool00004o`000?oo003o
o`00o`0000?oo`0000?o0000ool00?oo00000_l000000ooo003o0000ool00002ool00003o`000?oo
003oo`0000?o000000?oo`00o`000?oo00000_oo00001Ol0003oo`00ool00?oo003o000000;oo`00
1Ol00002o`00o`03o`000?l0o`3o000000;o0?l000Go0000o`3o0?l0003o0?l0o`000003o`3o0007
o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000002o`3o00;o000000?o0?l0o`000?l0o`000_l0o`03
o`000003o`3o0?l0003o0?l000;o0?l000Co0000o`3o0?l0o`3o00000_l0o`002?l0003o0?l0o`3o
0?l0003oo`00o`000?oo003o00000_oo00001?l0003oo`00ool00?oo0002o`000008ool00?l0003o
o`00o`000?oo003o0000o`00ool00003o`00o`05o`000?l00?oo003oo`00ool000000_l00?l00ol0
003o003oo`000004o`00o`04o`000?l00?oo003oo`0000?o003o00?o0000o`00ool000000ol00?l0
1Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00
ool00?oo000000;o003o00?o0000o`00ool000000ol00?l00ol0003oooooooooo`0Qooooo`;o0000
00?oooooo`000?ooool03?ooool000Oooooo00?o0000ooooooooool02Oooool00ol0003o003oo`00
o`02o`00o`05o`000?l00?oo003oo`00ool000000_l00?l2o`0000;o0?l00_l000001_l0o`3o0000
o`3o0?l0o`3o0000o`3o00;o00002?l0o`03o`000003o`3o0?l0003o0?l000?o0?l000Co0000ool0
0?l0003o00000_oo00001?l0003oo`00ool00?l00004ool00003o`000?oo003oo`0000?oo`000ol0
00000ooo003o0000ool00002ool00003o`000?oo003oo`0000?o000000?oo`00o`000?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000;oo`0000?o0000ool00?l00?l00_l00002o`3o0004o`00
0?l0o`3o0000o`0000?o0?l000?o0000o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l00005o`3o
0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`03o`000005o`3o0?l0003o0?l0o`3o0?l000000_l0
o`001?l0003o0?l0o`3o0?l00002o`3o00So00001?oo00001?l0003oo`00ool00?oo0002o`0000?o
003o00Go0000o`00ool00?oo003oo`000004o`00o`05o`000?l00?oo003oo`00ool000000ol00?l0
0ol0003o003oo`00o`03o`00o`04o`000?l00?oo003oo`0000Co003o00?o0000o`00ool00?l00_l0
0?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00ool00?l00_l00?l01Ol0003o003o
o`00ool00?oo000002Kooooo0ol0000<ooooo`001oooool00ol0003oooooooooo`08ooooo`06o`00
0?l00?oo003oo`000?l00?oo00000ol00?l00ol0003o003oo`00o`03o`0000;o0?l000Co0000o`3o
0?l0o`3o00000_l0o`02o`000005o`3o0?l0003o0?l0o`3o0?l000000_l0o`04o`0000Go0?l000?o
0000o`3o0?l0o`000_l00002ool00007o`000?oo003oo`00o`000?oo003o0000ool00002o`000003
ool00?l0003oo`0000;o000000?oo`00o`000?oo00000_oo0003o`000003ool00?l0003oo`0000;o
o`0000?o0000ool00?oo00001ol000001Ooo003o0000ool00?oo003o000000;oo`0000Go0000o`00
ool00?oo0000o`3o0002o`0000?o0?l000Co0000o`3o0?l0o`3o00001?l0o`000ol0003o0?l0o`3o
0002o`3o00;o00001?l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l01_l000001?l0o`3o0000
o`3o0?l0o`03o`0000;oo`000_l00004ool000;o00000_oo0002o`0000;oo`0000Go0000o`00ool0
0?oo003oo`000004o`00o`05o`000?l00?oo0000o`00ool000000ol00?l00ol0003o003oo`00o`02
o`00o`05o`000?l00?oo0000o`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l0
0?oo0000o`00ool000001?l00?l01?l0003o003oo`00ool00003o`00o`03o`000?l00?oo000000?o
003o00?o0000ooooooooool09_ooool2o`0000cooooo0007ooooo`03o`000?oooooooooo00Oooooo
00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`00ool00?oo000000;o003o0ol000000ol0o`3o
0000o`000002o`3o0003o`000?l0o`3o0?l000;o00000_l0o`000ol0003o0?l0o`3o0004o`0000;o
0?l000Co0000o`3o0?l0o`3o00000_l0o`06o`0000;oo`0000Co0000ool00?l0003o00001?oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000000ooo0003o`000003ool00?l0
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000002ool000Ko000000Coo`00o`00ool00?oo
003o0_l00003o`3o0004o`000?l0o`3o0?l0o`0000?o0?l000?o0000o`3o0?l000000_l0o`000ol0
003o0?l0o`000002o`3o00;o000000?o0?l0o`000?l0o`000_l0o`001Ol0003o0?l0o`3o0?l0o`3o
000000?o0?l000?o0000o`3o0?l0o`001Ol000001Ol0o`3o0000ool00?l0003oo`0000;o00001Ooo
00001?l0003oo`00ool00?l00003ool00003o`000?l00?oo000000;o003o00?o0000o`00ool00000
0ol00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00ool000000ol00?l01Ol0003o
003oo`00ool00?oo000000;o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo
000000?o003o00?o0000o`00ool00?l00ol00?l01?l0003o003oo`00ool0000Yooooo`03o`000?oo
oooooooo00cooooo0007ooooo`03o`000?oooooooooo00Oooooo00Ko0000o`00ool0003o0000o`00
ool00002o`00o`05o`000?l00?oo003oo`000?l00?l00ol000001_l0o`3o0000o`3o0?l0o`3o0000
o`3o00;o00000_l0o`000ol0003o0?l0o`3o0002o`000003o`3o0?l0003o0?l000Go0?l01?l00002
o`3o0005o`000?oo003o0000o`000?oo00000_l00003ool00003o`000?oo003o000000;oo`0000?o
0000ool00?l000000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?l00000
1?l000000ooo003o0000ool00002ool00004o`000?oo003oo`00o`0000;oo`000ol000001Ol00?oo
0000o`3o0?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000002o`3o0003o`000?l0o`3o
0?l000;o0?l000?o0000o`3o0?l0o`000ol0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o
0?l000?o000000?o0?l0o`000?l0o`000_l0o`001ol0003o0?l0o`3o0?l0003o0?l0o`000?l0o`00
1_l00007ool000?o000000?oo`00o`000?l000001?l00?l01Ol0003o003oo`00ool00?oo000000?o
003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00
ool00?l00_l00?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00ool00?l00_l00?l0
1Ol0003o003oo`000?l00?oo000000?o003o00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0=ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?l00?oo003o00;o003o00Ko0000
o`00ool0003o003oo`000?l00?l3o`000005o`00ool0003o0?l0o`3o0?l000000_l0o`02o`000006
o`3o0?l0003o0?l0o`3o0?l0003o0?l00_l00005o`3o0003o`000?l0o`3o000000;o000000Go0?l0
o`000?l0o`3o0?l0o`000002o`3o00?o00000ooo00001?l0003oo`00ool00?l00004ool00003o`00
0?oo003oo`0000;oo`0000Co0000ool00?oo003o00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?o000000Goo`00o`000?oo003oo`00o`000003ool00003o`000?oo003o003o
00?o000000?o0?l0o`000?l000000ol0o`001?l0003o0?l0o`3o0?l00003o`3o0003o`000?l0o`3o
000000;o0?l00_l000001ol0o`3o0000o`3o0?l0o`3o0000o`3o0?l000000ol0o`000ol0003o0?l0
o`3o0003o`000005o`3o0?l0003o0?l0o`3o0?l000000_l0o`000ol0003o0?l0o`000002o`000003
ool00?l0003oo`0000?o00001?oo00001Ol0003oo`00ool00?oo003o000000;o003o00?o0000o`00
ool000000ol00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00ool000000ol00?l0
1Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00
ool00?oo000000;o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo000002Wo
oooo00?o0000ooooooooool03_ooool000Oooooo00?o0000ooooooooool01_ooool01Ol0003o003o
o`00ool00?oo000000?o003o00Go0000o`00ool00?oo0000o`00o`02o`0000;o0?l000?o0000o`3o
0?l0o`000_l00002o`3o0003o`000?l0o`3o0?l000;o000000Co0?l0o`000?l0o`3o00000ol0o`02
o`000003o`3o0?l0003o0?l000Co0?l000So0000o`3o0?l0o`3o0000ool00?l0003oo`00o`0000;o
o`0000Oo0000ool00?oo003oo`00o`000?oo003o000000;oo`0000?o0000ool00?l000000ooo0000
1_l0003oo`00ool00?l0003oo`00o`0000;oo`0000Go0000ool00?oo003oo`00o`000002ool000Ko
000000Goo`00o`000?oo003oo`00o`000002o`00o`05o`3o0?l0003o0?l0o`3o0?l000000ol0o`00
1Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000?o0000o`3o0?l0o`000ol0o`000ol0003o0?l0o`3o
0002o`3o00?o000000?o0?l0o`000?l0o`000_l0o`000ol0003o0?l0o`3o000;o`000003ool00?l0
003oo`0000;o00000_oo0002o`0000?oo`0000Co0000ool00?oo003o00000ol00?l01Ol0003o003o
o`00ool00?oo000000?o003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`00ool00?oo0000
00?o003o00?o0000o`00ool00?l00_l00?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000
o`00ool00?l00_l00?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0?ooooo`001_ooool00ol0003oooooooooo`06ooooo`05o`000?l00?oo
003oo`00ool000000ol00?l02?l0003o003oo`00ool0003o003oo`000?l00?oo00000_l0o`001?l0
003o0?l0o`000?l00002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`001?l0003o0?l0o`000?l0
0005o`3o0004o`000?l0o`3o0?l0o`3o00Co00000_oo00000ol0003oo`00o`000003ool00004o`00
0?oo003oo`00o`0000Coo`000ol000000ooo003o0000ool00002ool00003o`000?oo003oo`0000Co
000000?oo`00o`000?oo00000_oo00001?l0003oo`00ool00?l00002ool000Ko000000Co003oo`00
0?l0003o00000_l0o`001Ol0003o0?l0o`000?l0o`3o000000?o0?l000Oo0000o`3o0?l0o`3o0?l0
o`000?l0o`3o000000?o0?l000?o0000o`3o0?l000000ol0o`03o`000003o`3o0?l0003o0?l000;o
0?l000Co0000o`3o0?l0o`3o00000_l0o`002Ol0003o0?l0o`3o0?l0003oo`00o`000?oo003o0000
ool00002o`0000?oo`000_l00002ool00006o`000?oo003oo`00o`000?l00?oo00000ol00?l00ol0
003o003oo`00o`02o`00o`05o`000?l00?oo0000o`00ool000000ol00?l01Ol0003o003oo`00ool0
0?oo000000;o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo000000;o003o
00?o0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo000002Wooooo00?o0000oooooooo
ool04?ooool000Kooooo00?o0000ooooooooool01Oooool01Ol0003o003oo`00ool00?oo000000?o
003o00Ko0000o`00ool00?oo0000o`00ool00002o`00o`03o`000?l0o`3o0?l000;o000000Ko0?l0
o`000?l0o`3o0?l0o`000?l0o`02o`0000;o0?l000?o0000o`3o0?l000000_l000001Ol0o`3o0000
o`3o0?l0o`3o000000;o0?l01Ol000001Ol0o`3o0000o`3o0?l0003oo`0000;o00000_oo00001?l0
003oo`00ool00?l00003ool00003o`000?oo003o000000?oo`000ol000000ooo003o0000ool00003
ool00003o`000?oo003oo`0000?o000000Goo`00o`000?oo003oo`00o`000003ool00006o`000?oo
003oo`00o`000?oo003o003o0_l00002o`3o0004o`000?l0o`3o0000o`0000?o0?l000?o0000o`3o
0?l000000_l0o`001?l0003o0?l0o`3o0?l00005o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0
o`03o`000005o`3o0?l0003o0?l0o`3o0?l000000_l0o`001Ol0003o0?l0o`3o0?l0003o0?l000Ko
000000?oo`00o`000?oo00001?oo00001?l0003oo`00ool00?oo0002o`0000?o003o00Ko0000o`00
ool00?oo0000o`00ool00003o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003o
o`00o`02o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`05
o`000?l00?oo003oo`00ool000000ol00?l00ol0003oooooooooo`0Vooooo`;o00004oooool000Ko
oooo00?o0000ooooooooool01?ooool01Ol0003o003oo`00ool00?oo000000Co003o00Go0000o`00
ool0003o003oo`000002o`00o`03o`000?l0o`3o0?l000;o00001Ol0o`02o`000005o`3o0?l0003o
0?l0o`000?l0o`000_l00005o`3o0003o`000?l0o`3o000000;o00000_l0o`000ol0003o0?l0o`00
0002o`3o00;o00000_oo00002?l0003oo`00ool00?l0003oo`00o`000?oo003o00000_oo00001Ol0
003oo`00ool00?oo003o000000?oo`0000?o0000ool00?l000000_oo00001Ol0003oo`00ool00?oo
003o000000;oo`001_l000001Ooo003o0000ool00?oo003o000000;oo`0000?o0000o`00ool00?l0
0_l000000ol0o`3o0000o`3o0002o`3o0004o`000?l0o`3o0?l0o`0000Co0?l000?o0000o`3o0?l0
o`000_l0o`02o`0000Co0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o00oo000000?oo`00o`00
0?oo00000ol00004ool00005o`000?oo003oo`00ool00?l000000ol00?l00ol0003o003oo`00o`02
o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l0
0?oo0000o`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo0000o`00ool0
00000ol00?l01Ol0003o003oo`00ool00?oo000002Sooooo00?o0000ooooooooool04oooool000Ko
oooo00?o0000ooooooooool00oooool00ol0003o003oo`00o`02o`00o`03o`000?l00?oo003o00;o
00000_l00?l2o`0000?o003o00Co0000o`3o0?l0o`3o00000_l0o`000ol0003o0?l0o`3o0002o`00
00Co0?l00_l000001Ol0o`3o0000o`3o0?l0o`3o000000;o0?l00_l000001Ol0o`3o0000o`3o0?l0
o`3o000000;o0?l01_l00002ool00004o`000?oo003o0000o`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000Co000000?oo`00o`000?oo0000
0_oo00001?l0003oo`00ool00?l00002ool000Ko000000Goo`00o`000?l00?oo003oo`3o0002o`00
00;o0?l000Co0000o`3o0?l0o`3o00000ol0o`000ol0003o0?l0o`000002o`3o00;o000000Oo0?l0
o`000?l0o`3o0?l0o`000?l0o`3o000000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o0004
o`000?l0o`3o0?l0o`0000;o0?l000?o0000o`3o0?l0o`000_l000000ooo003o0000ool00002o`00
00;oo`000ol00002ool000;o000000Goo`00o`000?l00?oo003oo`000002o`00o`03o`000?l00?oo
000000?o003o00Co0000o`00ool00?oo00000ol00?l00ol0003o003oo`000003o`00o`04o`000?l0
0?oo003oo`0000?o003o00?o0000o`00ool000000ol00?l01?l0003o003oo`00ool00004o`00o`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool05?ooool000Kooooo00?o0000ooooooooool0
0oooool00ol0003o003oo`00o`02o`0000Co003o00Go0000o`00ool0003o003oo`000002o`00o`;o
000000Go0?l0o`000?l0003o0?l0o`000002o`3o00;o00000_l0o`001?l0003o0?l0o`3o0?l00005
o`3o00?o00001Ol0o`000ol0003o0?l0o`000002o`000004o`3o0?l0003o0?l0ool000;o000000?o
o`00o`000?l000000ooo00001?l0003oo`00o`000?oo0002o`000004ool00?l0003oo`00ool000;o
00000ooo00001?l0003oo`00ool00?oo0003o`000005ool00?l0003oo`00ool00?l000000ooo0000
1?l0003oo`00ool00?l00002ool000Co000000Oo003oo`3o0?l0o`3o0?l0o`000?l0o`3o000000?o
0?l000Co0000o`3o0?l0o`3o00001Ol0o`000ol0003o0?l0o`3o0002o`3o0005o`000?l0o`3o0?l0
o`3o0?l000000ol0o`03o`000005o`3o0?l0003o0?l0o`3o0?l000000_l0o`001Ol0003o0?l0o`3o
0?l0003oo`0000;o000000?oo`00o`000?oo00000_l00003ool000;o00000_oo00000ol0003oo`00
o`000002o`0000Co003o00Co0000o`00ool00?oo00000ol00?l00ol0003o003oo`00o`03o`00o`04
o`000?l00?oo003oo`0000?o003o00?o0000o`00ool00?l00ol00?l01?l0003o003oo`00ool00003
o`00o`03o`000?l00?oo003o00;o003o00?o0000ooooooooool09_ooool00ol0003oooooooooo`0E
ooooo`001Oooool00ol0003oooooooooo`03ooooo`05o`000?l00?oo003oo`00ool000000_l00?l0
1ol0003o003oo`000?l00?oo0000o`00ool000000ol00?l01_l0003o003oo`000?l0o`3o0000o`3o
00?o000000Go0?l0o`000?l0o`3o0000o`3o0002o`0000;o0?l000?o0000o`3o0?l0o`000_l00000
1Ol0o`3o0000o`3o0?l0o`3o000000;o0?l00_l000000ol0o`3o0000o`3o0004o`3o00?o00000ooo
00001?l0003oo`00ool00?l00004ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003o
00000ooo00001?l0003oo`00ool00?oo0006o`000005ool00?l0003oo`00ool00?l000001?oo0000
0ol0003o003oo`000003o`000003o`3o0?l0003o000000;o0?l00_l000000ol0o`3o0000o`3o0002
o`3o00;o000000Oo0?l0o`000?l0o`3o0?l0o`000?l0o`3o000000?o0?l000?o0000o`3o0?l0o`00
0_l0o`000ol0003o0?l0o`3o0006o`000004o`3o0?l0003o0?l0o`3o00[o00000ooo00000ol0003o
o`00o`000003ool00005o`000?l00?oo0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo
000000;o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o
0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00ool00000
:?ooool00ol0003oooooooooo`0Fooooo`001Oooool00ol0003oooooooooo`06ooooo`03o`000?l0
0?oo003o00;o003o00Go0000o`00ool0003o003oo`000003o`00o`03o`000?l00?oo003o00;o0000
0_l0o`000ol0003o0?l0o`3o0003o`3o00;o000000Ko0?l0o`000?l0o`3o0?l0o`000?l0o`02o`00
00Go0?l00ol00005o`3o0004o`000?l0o`3o0?l0o`3o00?o000000Goo`00o`000?oo003oo`00o`00
0003ool00003o`000?oo003o000000;oo`0000?o0000ool00?l000000ooo00001?l0003oo`00ool0
0?l00003ool00005o`000?oo003oo`00ool00?l000000_oo0004o`000007ool00?l0003oo`00ool0
0?l0003oo`00o`000002o`00o`;o0?l000Go0000o`3o0?l0o`3o0?l0o`000002o`3o0003o`000?l0
o`3o0?l000;o00000_l0o`000ol0003o0?l0o`3o0002o`3o0005o`000?l0o`3o0?l0o`3o0?l00000
0_l0o`000ol0003o0?l0o`000003o`3o0004o`000?l0o`3o0?l0o`0000;o0?l01Ol000001_l0o`3o
0000o`000?l0003oo`00o`0000?oo`000_l00002ool000;o00000_oo0002o`0000;o003o00Go0000
o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool00?oo003o
o`000003o`00o`03o`000?l00?oo003o00;o003o00Go0000o`00ool00?oo003oo`000003o`00o`03
o`000?l00?oo003o00;o003o00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Gooooo`00
1Oooool00ol0003oooooooooo`08ooooo`03o`000?l00?oo000000;o003o0_l00003o`00o`08o`00
0?l00?oo003oo`000?l00?oo0000o`3o0?l00003o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000?o
0000o`3o0?l000000_l000001Ol0o`3o0000o`3o0?l0003o0?l000?o000000Go0?l0o`000?l0o`3o
0?l0o`000002o`3o00Ko000000Coo`00o`000?oo003o00000ooo00001?l0003oo`00ool00?l00004
ool000?o000000?oo`00o`000?oo00000_oo00000ol0003oo`00ool00003o`000003ool00?l0003o
o`0000;oo`0000Co0000ool00?oo003o00000_oo0006o`0000;o003o00?o0000o`3o0?l000000ol0
o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o0000
00?o0?l000?o0000o`3o0?l0o`000_l0o`03o`000005o`3o0?l0003o0?l0o`3o0?l000000ol0o`00
1_l0003o0?l0o`3o0?l0003o0?l0o`0000;oo`000_l000000ooo003o0000ool00003ool000;o0000
0_oo0002o`000004ool00?l0003o003oo`0000?o003o00Go0000o`00ool00?oo003oo`000002o`00
o`03o`000?l00?oo000000?o003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo
000000?o003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000002Oooooo0_l0
000Jooooo`001Oooool00ol0003oooooooooo`09ooooo`06o`000?l00?oo003oo`000?l00?oo0000
0_l00?l00ol0003o003oo`00o`02o`00o`;o000000Ko0?l0o`000?l0o`3o0?l0o`000?l0o`02o`00
00;o0?l000Co0000o`3o0?l0o`3o00001Ol0o`02o`000003o`3o0?l0003o0?l000Co0?l01?l00002
o`3o0003o`000?l0o`3oo`0000?o000000?oo`00o`000?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`000ol000000ooo003o0000ool00002ool00003o`000?oo003o
o`0000?o000000Goo`00o`000?oo003oo`00o`000004ool00005o`000?oo003oo`00o`000?l00?l0
0_l00003o`3o0005o`000?l0o`3o0000o`3o0?l000000ol0o`001Ol0003o0?l0o`3o0?l0o`3o0000
00;o0?l000Go0000o`3o0?l0o`3o0?l0o`000002o`3o0003o`000?l0o`3o000000?o0?l01_l00000
1Ol0o`3o0000o`3o0?l0o`3o000000;o0?l000?o0000o`3o0?l000000ol000000ooo003o0000ool0
0003ool000;o00000_oo00001?l0003oo`00o`000?l00003o`00o`05o`000?l00?oo003oo`00ool0
00001?l00?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00ool00?l00_l00?l01Ol0
003o003oo`00ool00?oo000000?o003o00?o0000o`00ool00?l00_l00?l00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01[ooooo0005ooooo`03o`000?oooooooooo00_ooooo0ol000001Ol0
0?oo0000o`00ool0003o003o00;o000000Co003oo`000?l00?oo00000ol0o`02o`000006o`3o0?l0
003o0?l0o`3o0?l0003o0?l00_l00002o`3o0004o`000?l0o`3o0000o`0000Co0?l000?o0000o`3o
0?l000000_l000001Ol0o`3o0000o`3o0?l0o`3o000000;o0?l000Wo0000ool00?l0003oo`00o`00
0?oo003o0000ool00?l000000_oo00000ol0003oo`00o`000002ool00003o`000?oo003o000000?o
o`000ol000000ooo003o0000ool00002ool00003o`000?oo003oo`0000Oo000000Ooo`00o`000?oo
003oo`00o`000?oo003o000000;o003o0_l000000ol0o`3o0000o`000003o`3o0003o`000?l0o`3o
000000;o0?l000Co0000o`3o0?l0o`3o00001?l0o`000ol0003o0?l0o`3o0002o`3o0005o`000?l0
o`3o0?l0o`3o0?l000000ol0o`000ol0003o0?l0o`3o000:o`000003ool00?l0003oo`0000Co0000
0ooo00001ol0003oo`00ool00?oo003o0000ool00?l000000_l00?l01Ol0003o003oo`00ool00?oo
000000;o003o00?o0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o
0000o`00ool000000ol00?l01Ol0003o003oo`00ool00?oo000000;o003o00?o0000o`00ool00000
9oooool00ol0003oooooooooo`0Kooooo`001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00?ooooo00?o0000o`00ool00?l00_l00?l01?l0003o003oo`000?l00003o`3o0004o`00
0?l0o`3o0?l0o`0000;o0?l00_l00003o`3o0004o`000?l0o`3o0000o`0000;o0?l000?o0000o`3o
0?l0o`000_l000000ol0o`3o0000o`3o0004o`3o0003o`000?l0o`3o000000;o000000Koo`00o`00
0?oo003o0000ool00?l00004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000003ool000?o000000?oo`00o`000?oo00000_oo00001Ol0003oo`00ool00?oo003o000000;o
o`001ol00003o`00o`;o00000ol0o`001?l0003o0?l0o`3o0?l00004o`3o0007o`000?l0o`3o0?l0
o`3o0?l0003o0?l0o`000002o`3o0003o`000?l0o`3o000000?o0?l00ol000000ol0o`3o0000o`3o
0002o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000_l0o`02o`0000;oo`000_l000000ooo003o
0000ool00002o`0000;oo`0000Co0000ool00?oo003oo`000_l000000ol00?oo0000o`00o`02o`00
o`03o`000?l00?oo003o00;o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo
003o00;o003o00Go0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00;o003o00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`001?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Kooooo00?o0000o`00ool000000ol00?l2o`000005o`3o0?l0003o
0?l0o`3o0?l000000_l0o`02o`000004o`3o0?l0003o0?l0o`3o00;o000000Co0?l0o`000?l0o`3o
0?l00ol00005o`3o0004o`000?l0o`3o0?l0o`3o00?o000000?o0?l0o`000?oo00001?l00002ool0
0003o`000?oo003o000000;oo`0000?o0000ool00?l000000ooo00001Ol0003oo`00ool00?oo003o
000000?oo`001ol000001Ooo003o0000ool00?oo003o000000?oo`0000Co0000ool00?oo003o0000
0_l00?l01Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o
000000;o0?l000Co0000o`3o0?l0o`3o00001?l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l0
0ol000001ol0o`3o0000o`3o0?l0o`3o0000o`3o0?l000000_l0o`001?l0003o0?l0ool00?l00002
ool000;o000000Goo`00o`000?oo003oo`00o`000004ool00004o`000?oo003o0000o`0000?o003o
00Ko0000o`00ool00?oo0000o`00ool00003o`00o`05o`000?l00?oo003oo`00ool000000_l00?l0
0ol0003o003oo`000003o`00o`05o`000?l00?oo003oo`00ool000000_l00?l00ol0003o003oo`00
000Wooooo`03o`000?oooooooooo01gooooo0004ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01oooool02Ol0003o003oo`00ool00?oo0000o`00ool0003o0?l0o`000002o`3o0007
o`000?l0o`3o0000o`000?l0o`3o0000o`3o0002o`0000Go0?l00_l000001Ol0o`3o0000o`3o0?l0
o`3o000000;o0?l01Ol000001Ol0o`3o0000o`3o0?l0o`3o000000;oo`0000Ko0000ool00?oo003o
0000ool00?l00004ool00005o`000?oo003oo`00ool00?l000000ooo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00001_l000002Ooo003o0000ool00?oo003o0000ool00?l0
0?oo0000o`00o`02o`000003o`3o0?l0003o000000?o0?l000Co0000o`3o0?l0o`3o00001?l0o`00
1ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o
0?l04_l000001?oo003o0000ool00?oo0002o`0000;oo`0000?o0000ool00?l000000ol00?l00ol0
003o003oo`00o`02o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003oo`00o`02
o`00o`05o`000?l00?oo003oo`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07_ooool000Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0;ooooo`05o`000?l00?oo003oo`00ool000000ol0o`02o`000003o`3o0?l0
003o0?l000;o000000Ko0?l0o`000?l0o`3o0?l0o`000?l0o`02o`0000Go0?l01?l00002o`3o0003
o`000?l0o`3o000000;o0?l000?o0000ool00?l000000_oo00001?l0003oo`00o`000?l00002ool0
0003o`000?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001_l0003oo`00ool00?l0003o
o`00o`0000;oo`0000Go0000ool00?oo003oo`00o`000002ool00003o`000?oo003oo`0000Oo0000
0ol00?l00ol0o`3o0000o`3o0002o`3o0004o`000?l0o`3o0?l0o`0000?o0?l000?o0000o`3o0?l0
00000_l0o`001?l0003o0?l0o`3o0?l00003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`00
1ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003oo`00o`00
00Coo`000_l00004ool00003o`000?oo003o000000;o00000ol00?l01Ol0003o003oo`000?l00?oo
000000?o003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000000?o003o00Co
0000o`00ool00?oo00000_l00?l00ol0003o003oo`00000Wooooo`;o00008Oooool000Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`;o00000_l0o`02o`0000Co0?l000Co
0000o`3o0?l0o`3o00000_l0o`02o`000004o`3o0?l0003o0?l0o`0000;o0?l00_l000001Ol0o`3o
0000o`3o0?l0o`3o000000;o0?l01ol000000ooo003o0000o`000003ool00003o`000?oo003o0000
00Coo`0000Go0000ool00?l0003oo`00o`000003ool00003o`000?oo003oo`0000Co000000Goo`00
o`000?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000;oo`000_l00002o`00o`04o`00
0?l0o`3o0?l0o`0000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000002o`3o0003o`000?l0o`3o0?l0
00;o0?l000?o0000o`3o0?l0o`000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l00ol00000
1?l0o`3o0000o`3o0?l00002o`3o0008o`000?l0o`3o0?l0o`000?oo003o0000ool00?l00005ool0
00;o00001Ooo00001Ol0003oo`00o`000?l00?oo000000?o003o00Go0000o`00ool00?oo003oo`00
0003o`00o`03o`000?l00?oo003o00;o003o00Co0000o`00ool00?oo00000ol00?l00ol0003o003o
o`00o`02o`00o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08Oooool000?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`?o00000_l0o`000ol0003o0?l0o`00
0002o`3o0003o`000?l0o`3o0?l000;o00001?l0o`001?l0003o0?l0o`000?l00005o`3o00Co0000
00Co0?l0o`000?l0o`3o0?l00ol00003ool00004o`000?oo003oo`00o`0000?oo`000_l00003ool0
00?o000000?oo`00o`000?oo00000ooo00000ol0003oo`00ool00006o`000005ool00?l0003oo`00
ool00?l000000ooo00000ol0003o003oo`000002o`0000?o0?l000Go0000o`3o0?l0o`3o0?l0o`00
0002o`3o0007o`000?l0o`3o0?l0o`3o0?l0003o0?l0o`000002o`3o0003o`000?l0o`3o000000?o
0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o000=o`000003ool00?l0003oo`0000Ko
o`0000Co0000ool00?oo003oo`001?l00003o`00o`05o`000?l00?oo003oo`00ool000000_l00?l0
1_l0003o003oo`00ool0003o003oo`0000?o003o00Go0000o`00ool00?oo003oo`000002o`00o`03
o`000?l00?oo000002Oooooo00?o0000ooooooooool08_ooool000?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Booooo`03o`000?l0o`3o000000?o0?l00_l00002o`3o0004o`00
0?l0o`3o0000o`0000;o0?l000?o0000o`3o0?l000000_l000001Ol0o`3o0000o`3o0?l0003o0?l0
00?o000000?o0?l0o`000?l0o`001?l0o`001Ol0003oo`00o`000?oo003o000000;oo`0000Oo0000
ool00?oo003oo`00o`000?oo003o000000;oo`0000?o0000ool00?l000000_oo0004o`000005ool0
0?l0003oo`00ool00?l000000ooo00000ol0003oo`00ool00006o`000004ool00?l0003oo`00o`00
00?o003o00Go0000o`3o0?l0003o0?l0o`000003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0
o`000ol0003o0?l0o`3o0002o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`000ol0003o0?l0
o`000002o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000Go0000o`3o0?l0o`3o0000o`3o0008o`00
00Goo`000_l000001?oo003o0000ool00?l00003o`00o`04o`000?l00?oo003oo`0000?o003o00?o
0000o`00ool00?l00_l00?l01Ol0003o003oo`00ool00?oo000000?o003o00?o0000o`00ool00?l0
0_l00?l00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02?ooooo0003ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003o0?l0o`3o0002o`000004o`3o0?l0
003o0?l0o`3o00;o000000Go0?l0o`000?l0o`3o0000o`3o0002o`0000Go0?l00_l000000ol0o`3o
0000o`3o0003o`3o00Ko000000Coo`00o`000?oo003o00000ooo00001?l0003oo`00ool00?l00004
ool00005o`000?oo003oo`00ool00?l000000ooo0006o`000003ool00?l0003oo`0000;oo`0000Co
0000ool00?oo003o00000_oo0004o`0000?o003o0_l00003o`3o0005o`000?l0o`3o0000o`3o0?l0
00000ol0o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000ol0o`000ol0003o0?l0o`3o0002
o`3o00Go000000Go0?l0o`000?l0o`3o0?l0o`000002o`3o0005o`000?l0o`3o0?l0o`000?oo0000
0_l00004ool000;o00001?oo00000ol0003oo`00o`000002o`0000;o003o00Co0000o`00ool00?oo
00000ol00?l01_l0003o003oo`00ool0003o003oo`0000?o003o00Go0000o`00ool00?oo003oo`00
0002o`00o`03o`000?l00?oo000002Oooooo00?o0000ooooooooool09?ooool000?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`06o`000?l0o`3o0?l0o`000?l0o`3o0000
0_l0o`02o`0000Co0?l00_l000001?l0o`3o0000o`3o0?l0o`03o`0000Go0?l01?l00002o`3o0003
o`000?l0o`3o000000?o000000?oo`00o`000?oo00000_oo00001ol0003oo`00ool00?oo003o0000
ool00?l000000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000ol0
00001Ooo003o0000ool00?oo003o000000?oo`0000Oo0000ool00?oo003o0000o`00ool0o`3o0000
00?o0?l000Co0000o`3o0?l0o`3o00000ol0o`000ol0003o0?l0o`000002o`3o0004o`000?l0o`3o
0?l0o`0000?o0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o0003o`000?l0o`3o000000Go
000000?o0?l0o`000?l000000ol000000ooo003o0000o`000005ool000;o00000ooo00001_l0003o
o`00o`000?l0003o003oo`0000;o003o00Go0000o`00ool00?oo003oo`000004o`00o`05o`000?l0
0?oo003oo`00ool000000ol00?l00ol0003o003oo`00o`02o`00o`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool09Oooool000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Gooooo`;o00000_l0o`001?l0003o0?l0o`3o0?l00002o`3o0004o`000?l0o`3o0?l0o`0000Go
0?l000?o0000o`3o0?l000000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000;o0?l000co0000
o`3o0?l0o`3o0000ool00?l0003oo`00o`000?oo003o0000ool00?l00002ool00004o`000?oo003o
o`00o`0000?oo`0000Co0000ool00?oo003oo`000ol000000ooo003o0000ool00002ool00003o`00
0?oo003oo`0000Ko000000Woo`00o`000?oo003oo`00o`000?oo003o003oo`000?l00?l00_l00000
0ol0o`3o0000o`000003o`3o0004o`000?l0o`3o0?l0o`0000Co0?l000?o0000o`3o0?l0o`000_l0
o`000ol0003o0?l0o`3o0002o`3o00?o000000Go0?l0o`000?l0o`3o0?l0o`000002o`3o0003o`00
0?l0o`3o0?l000;o000000?o0?l0o`000?l0o`001Ol00006ool000;o00000_oo0004o`0000;o003o
00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000000?o003o00Go0000o`00ool0
0?oo003oo`000002o`00o`03o`000?l00?oo000002Kooooo0_l0000Xooooo`000oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Sooooo0_l00002o`3o0007o`000?l0o`3o0000o`00
0?l0o`3o0000o`3o0002o`0000;o0?l000Co0000o`3o0?l0003o00001Ol0o`03o`0000Go0?l000?o
0000o`3o0?l0o`000_l000001_oo003o0000ool00?l0003oo`00o`0000Coo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000?oo`000ol000001Ooo003o0000ool00?oo003o
000000?oo`0000?o0000ool00?oo00002Ol00002o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0
o`001ol0003o0?l0o`3o0?l0o`3o0000o`3o0?l000000_l0o`000ol0003o0?l0o`000002o`3o0003
o`000?l0o`3o000000?o0?l00_l000001Ol0o`3o0000o`3o0?l0o`3o000000?o0?l000?o0000o`3o
0?l000000_l0o`02o`000003ool00?l0003oo`0000Co00001?oo0002o`000006ool00?l0003oo`00
o`000?l00?oo00000ol00?l00ol0003o003oo`00o`02o`00o`05o`000?l00?oo003oo`00ool00000
0ol00?l00ol0003o003oo`00o`02o`00o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
:?ooool000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?l0
o`3o0?l000;o00000ol0o`02o`000004o`3o0?l0003o0?l0o`3o00;o000000Co0?l0o`000?l0o`3o
00000_l0o`02o`000004o`3o0?l0003o0?l0o`0000?o0?l00ol000000ol0o`3o0000o`000004o`00
00;oo`0000?o0000ool00?l000000_oo00000ol0003oo`00o`000003ool00005o`000?oo003oo`00
ool00?l000000ooo0006o`000005ool00?l0003oo`00ool00?l000000ooo00001_l0003oo`00ool0
0?l0003o003oo`3o00;o00000_l0o`001?l0003o0?l0o`3o0?l00003o`3o0004o`000?l0o`3o0?l0
o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`001?l0003o0?l0o`3o0?l00003o`3o00Ko000000Ko
0?l0o`000?l0o`3o0?l0o`000?l0o`02o`000003ool00?l0003oo`0000;o00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?o00000ol00?l01_l0003o003oo`00ool0003o003o
o`0000?o003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000002Kooooo00?o
0000ooooooooool0:Oooool000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0J
ooooo`06o`000?l0o`3o0000o`000?l0o`3o00000_l0o`000ol0003o0?l0o`3o0002o`3o00;o0000
1?l0o`001?l0003o0?l0o`000?l00004o`3o00Go000000Go0?l0o`000?l0o`3o0?l0o`000002ool0
0006o`000?oo003oo`00o`000?oo003o00001?oo00001Ol0003oo`00ool00?oo003o000000?oo`00
00Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000Ko000000Woo`00o`000?oo
003oo`00o`000?oo003o003oo`000?l00?l00_l000000ol0o`3o0000o`000003o`3o0004o`000?l0
o`3o0?l0o`0000Co0?l000?o0000o`3o0?l0o`000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o
0?l000Go0000o`3o0?l0o`3o0?l0o`000002o`3o00Oo000000Goo`00o`000?oo003o0000ool00002
o`0000?oo`000_l00002ool000;o00000_oo00001Ol0003o003oo`00ool00?oo000000Co003o00Go
0000o`00ool00?oo003oo`000003o`00o`03o`000?l00?oo003o00;o003o00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Zooooo`000_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01_ooooo00?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`000002o`3o0004o`000?l0
o`3o0000o`0000;o0?l000?o0000o`3o0?l000000_l000000ol0o`3o0000o`3o0004o`0000;o0?l0
00?o0000o`3o0?l000000_l0o`000ol0003oo`00ool00002ool00004o`000?oo003o0000o`0000;o
o`0000?o0000ool00?l000000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
000000?oo`00o`000?oo00000_oo00001?l0003oo`00ool00?l00002ool000So000000Co003oo`3o
0?l0o`3o00000ol0o`001?l0003o0?l0o`3o0?l00003o`3o0003o`000?l0o`3o000000;o0?l000Oo
0000o`3o0?l0003o0?l0o`000?l0o`3o000000?o0?l00ol000001Ol0o`3o0000o`3o0?l0o`3o0000
00?o0?l000Go0000o`3o0?l0o`3o0000o`3o0007o`0000Coo`000_l000001Ooo003o0000ool00?oo
003o000000;o003o00Ko0000o`00ool00?oo0000o`00ool00003o`00o`09o`000?l00?oo003oo`00
ool0003o003oo`000?l00?oo000002Oooooo00?o0000ooooooooool0:oooool000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`05o`000?l0o`3o0?l0o`000?l0o`000_l0
0002o`3o00;o000000Go0?l0o`000?l0o`3o0000o`3o0002o`0000Go0?l000?o0000o`3o0?l00000
0_l0o`000ol0003o0?l0o`3o0006o`000004ool00?l0003o0000o`0000?oo`0000?o0000ool00?l0
00000ooo00001_l0003oo`00ool00?l0003oo`00o`0000?oo`0000?o0000ool00?oo00000ol00000
1Ooo003o0000ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000_oo00001Ol0003o003o
o`000?l00?oo000000;o0?l000Co0000o`3o0?l0o`3o00000ol0o`001?l0003o0?l0o`3o0?l00004
o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`001?l0003o0?l0o`3o0?l0o`06o`000005o`3o
0?l0003o0?l0o`3o0?l000000_l0o`02o`000003ool00?l0003oo`0000;oo`000ol00005ool00005
o`000?oo003o0000o`00ool000001?l00?l01Ol0003o003oo`00ool00?oo000000?o003o00Go0000
o`00ool00?oo003oo`00000Wooooo`03o`000?oooooooooo02cooooo0002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07Oooool00ol0003o0?l0o`3o0002o`000003o`3o0?l0003o
0?l000;o00000_l0o`001_l0003o0?l0o`000?l0003o0?l0o`0000?o0?l00_l00005o`3o00Co0000
00Co0?l0o`000?l0o`3o0?l00_l000001Ooo003o0000ool00?oo003o000000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool000?o000000Goo`00o`000?oo003oo`00o`000003ool000Ko000000Go
o`00o`000?oo003oo`00o`000002ool00004o`000?oo003o003oo`00o`;o00000ol0o`001Ol0003o
0?l0o`3o0?l0o`3o000000;o0?l000_o0000o`3o0?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l0003o
0?l0o`000003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`000ol0003o0?l0o`3o0007o`00
0005ool00?l0003o0000ool00?l000001Ooo00001Ol0003oo`00ool00?oo003o000000;oo`000_l0
0002o`00o`03o`000?l00?oo000000?o003o00Co0000o`00ool00?oo00000_l00?l00ol0003o003o
o`00000Vooooo`;o0000;oooool00003ooooool0003ooooo00?ooooo00?o0000ooooooooool07ooo
ool01Ol0003o0?l0o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o00000_l0o`000ol0003o
0?l0o`3o0002o`3o00;o000000Go0?l0o`000?l0o`3o0000o`3o0003o`000005o`3o0?l0003o0?l0
o`3o0?l000000_l0o`02o`0000;oo`0000Co0000ool00?l0003o00000ooo00001ol0003oo`00o`00
0?oo003o0000ool00?l000000ooo0004o`0000?oo`0000Go0000ool00?oo003oo`00o`000002ool0
00Wo000000Wo003oo`000?l00?oo0?l0o`000?l0o`3o0000o`3o0?l000000ol0o`001Ol0003o0?l0
o`3o0?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o0004o`000?l0o`3o0?l0
o`3o00?o000000Go0?l0o`000?l0o`3o0?l0o`000003o`3o0003o`000?l0o`3o0?l000Go000000?o
o`00o`000?oo00001?oo0002o`0000;oo`0000Co0000ool00?oo003o00000ol00?l01Ol0003o003o
o`00ool00?oo000000;o003o00?o0000o`00ool00?l00_l00?l00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo02oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo027ooooo
00Go0000o`3o0?l0o`3o0000o`3o0002o`0000;o0?l000?o0000o`3o0?l000000_l0o`000ol0003o
0?l0o`000005o`3o00;o000000?o0?l0o`000?l0o`000ol0o`000ol0003o0?l0o`000004o`000003
ool00?l0003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o
000000?oo`0000?o0000ool00?oo00000ol000001Ooo003o0000ool00?oo003o000000?oo`0000Co
0000ool00?oo003o00000_oo0003o`000003o`00ool0003o000000?o0?l000?o0000o`3o0?l00000
0_l0o`001?l0003o0?l0o`3o0?l00004o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`001?l0
003o0?l0o`3o0?l0o`06o`000004o`3o0?l0003o0?l0o`3o00?o000000?oo`00o`000?oo00001?l0
0004ool000;o00000_oo00001_l0003oo`00o`000?l0003o003oo`0000?o003o00Co0000o`00ool0
0?oo00000_l00?l00ol0003o003oo`00000Vooooo`03o`000?oooooooooo033ooooo00001Ooooooo
0000oooooooooooo000002Cooooo00?o0000o`3o0?l0o`000_l000001?l0o`3o0000o`3o0?l0o`03
o`0000;o0?l00ol00002o`3o0003o`000?l0o`3o000000Go0?l000?o0000o`3o0?l000000_l00000
0ol0o`3o0000o`3o0003o`0000?oo`0000Co0000ool00?oo003o00001?oo00001?l0003oo`00ool0
0?oo0003o`000003ool00?l0003oo`0000;oo`0000?o0000ool00?oo00001_l000001Ooo003o0000
ool00?oo003o000000;oo`0000?o0000ool00?l00?l00ol00002o`3o0004o`000?l0o`3o0?l0o`00
00Co0?l000_o0000o`3o0?l0o`3o0?l0o`000?l0o`3o0000o`3o0?l0003o0?l0o`000003o`3o0005
o`000?l0o`3o0?l0o`3o0?l000000ol0o`000ol0003o0?l0o`3o0005o`000004o`3o0?l0003oo`00
ool000;o00000ooo0002o`000005ool00?l0003oo`00o`000?oo00001?l000001Ol00?oo0000o`00
ool00?oo000000?o003o00?o0000o`00ool00?l00_l00?l00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo037ooooo00001?oooooo0000ooooool0000Vooooo`?o000000Co0?l0o`000?l0o`3o
0?l00_l00003o`3o00;o00001?l0o`03o`0000;o0?l000?o0000o`3o0?l0o`000_l000000ol0o`3o
0000o`3o0003o`3o0005o`000?oo003o0000ool00?l000000_oo00001ol0003oo`00ool00?oo003o
0000ool00?l000000_oo00000ol0003oo`00o`000002ool000?o000000?oo`00o`000?oo00000_oo
00001?l0003oo`00ool00?l00002ool000[o00000_l00?l00ol0o`3o0000o`3o0002o`0000?o0?l0
00?o0000o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l00003o`3o0005o`000?l0o`3o0?l0o`3o
0?l000000ol0o`03o`000003o`3o0?l0003o0?l000;o0?l000So0000o`3o0?l0o`3o0000o`3o0?l0
003oo`00o`0000;oo`000_l00004ool000;o00000_oo0002o`000004ool00?l0003o0000o`0000;o
003o00Go0000o`00ool00?oo003oo`000002o`00o`03o`000?l00?oo000002Kooooo00?o0000oooo
ooooool0<_ooool00004ooooool0003oooooo`0002Kooooo0_l00002o`3o0007o`000?l0o`3o0?l0
o`000?l0o`3o0000o`3o0002o`000004o`3o0?l0003o0?l0o`3o00;o00001?l0o`03o`0000Go0?l0
00?o0000o`3o0?l000000_l000001?oo003o0000ool00?l00003ool00004o`000?oo003oo`00o`00
00Coo`0000Go0000ool00?l0003oo`00o`000002ool000So00000ooo00001?l0003oo`00ool00?l0
0002ool00003o`000?oo003oo`0000?o00000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l0
00?o0000o`3o0?l0o`000_l0o`001_l0003o0?l0o`3o0?l0003o0?l0o`0000?o0?l000Go0000o`3o
0?l0o`3o0?l0o`000003o`3o00?o000000Go0?l0o`000?l0o`3o0?l0o`000002o`3o00So00001Ooo
0002o`0000;oo`000ol00002o`00o`05o`000?l00?oo003oo`00ool000001?l00?l00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo03?ooooo00000ol0003oooooo`00000Wooooo`;o00000_l0
o`001Ol0003o0?l0o`000?l0003o0?l000;o000000Go0?l0o`000?l0o`3o0000o`3o0002o`000004
o`3o0?l0003o0?l0o`3o00;o000000Go0?l0o`000?l0o`3o0?l0o`000002o`3o00?o000000?o0?l0
ool00?l000000_l000000ooo003o0000ool00002ool00007o`000?oo003oo`00ool00?l0003oo`00
o`000003ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00007o`0000;o
o`0000Co0000ool00?oo003o00000ol00?l2o`0000;o0?l000Co0000o`3o0?l0o`3o00000ol0o`00
0ol0003o0?l0o`000002o`3o0003o`000?l0o`3o000000?o0?l000Go0000o`3o0?l0o`3o0?l0o`00
0003o`3o0004o`000?l0o`3o0?l0o`3o00Oo000000Co0?l0o`000?l0003o00001?oo0002o`0000Co
o`000_l00002ool000;o000000?o003oo`000?l00?l00_l00?l01Ol0003o003oo`00ool00?oo0000
02Kooooo0_l0000fooooo`000_l0000Yooooo`03o`000?l0o`3o0?l000;o00000_l0o`02o`0000;o
0?l01?l000001Ol0o`3o0000o`3o0?l0003o0?l000;o00001Ol0o`04o`000006o`3o0?l0003o0?l0
o`3o0?oo003o00000ooo00000ol0003oo`00o`000002ool00004o`000?oo003oo`00o`0000?oo`00
00Co0000ool00?oo003oo`000ol000000ooo003o0000ool00002ool00004o`000?oo003oo`00o`00
00;oo`002Ol00002o`00o`03o`3o0?l0003o0?l000;o00000ol0o`001?l0003o0?l0o`3o0?l00004
o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l0
00Co0000o`3o0?l0o`3o00000ol0o`03o`000003ool00?l0003o000000Goo`000_l00003ool00003
o`000?oo003oo`0000?o00000ol00?l01Ol0003o003oo`00ool00?oo000002Kooooo00?o0000oooo
ooooool0=_ooool000;o0000:Oooool02?l0003o0?l0o`000?l0003o0?l0o`000?l0o`3o00000_l0
o`000ol0003o0?l0o`000004o`3o00?o000000Go0?l0o`000?l0o`3o0000o`3o0003o`000004o`3o
0?l0003o0?l0o`0000;o0?l01?l000001?oo003o0000o`000?l00004ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000003ool000?o000000Goo`00o`000?oo003oo`00o`00
0003ool00003o`000?oo003o000000;oo`0000?o0000ool00?oo00000ol000000ol0o`3o0000o`00
0003o`3o0004o`000?l0o`3o0?l0o`0000Co0?l000Ko0000o`3o0?l0o`3o0000o`3o0?l00003o`3o
0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`06o`000003o`3o0?l0003o0?l000;o000000Coo`00
o`000?oo003o00001_oo0002o`0000;oo`0000?o0000ool00?oo00000_l00002o`00o`05o`000?l0
0?oo003oo`00ool000009_ooool00ol0003oooooooooo`0gooooo`000_ooool3o`0002Oooooo0_l0
00000ol0o`3o0000o`3o0002o`0000;o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`00
0005o`3o00;o000000?o0?l0o`000?l0o`000ol0o`03o`0000;ooooo0ol00002ool00005o`000?oo
003o0000ool00?l000000_oo00000ol0003oo`00o`000003ool00005o`000?oo003oo`00ool00?l0
00000ooo0006o`000004ool00?l0003oo`00o`0000;oo`0000Go0000ool00?oo003oo`00o`000002
o`00o`;o00000_l0o`001?l0003o0?l0o`3o0?l00003o`3o0005o`000?l0o`3o0000o`3o0?l00000
0_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o
0003o`000?l0o`3o0?l000Co000000?o0?l0o`000?l000001Ol00006ool00003o`000?oo003oo`00
00;oo`0000?o0000o`00ool000000ol00?l00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
03Sooooo0005ooooo`;o00009Oooool00ol0003o0?l0o`3o0002o`000004o`3o0?l0003o0?l0o`3o
00?o00000_l0o`03o`0000;o0?l00ol00005o`3o00Co00001Oooool00ol0003oo`00o`000002ool0
0003o`000?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00005o`000?oo003o
o`00ool00?l000000ooo00000ol0003oo`00ool00008o`000005ool00?l0003o003oo`00ool00000
0_l0o`001?l0003o0?l0o`000?l00003o`3o0004o`000?l0o`3o0?l0o`0000?o0?l000?o0000o`3o
0?l0o`000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l00ol000001Ol0o`3o0000o`3o0?l0
o`3o000000;o0?l000Co0000o`3o0?l0003oo`000_l000001?oo003o0000ool00?oo0002o`0000Co
o`0000Co0000ool00?oo003oo`000ol00003o`00o`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0>Oooool000Oooooo0ol0000Sooooo`05o`000?l0o`3o0000o`3o0?l000000_l0o`03o`00
00;o0?l00_l00004o`3o0003o`000?l0o`3o000000;o0?l000Co0000o`3o0?l0003o00002Oooool0
1?l0003oo`00o`000?oo0002o`0000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000?oo`000ol000001Ooo003o0000ool00?oo003o000000?oo`0000Go0000ool00?oo
003o0000ool00006o`000003o`3o0?l0003o000000?o0?l000Co0000o`3o0?l0o`3o00000ol0o`00
1ol0003o0?l0o`000?l0o`3o0000o`3o0?l000000ol0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o
0?l01Ol000000ol0o`3o0000o`000003o`000005ool00?l0003o0000ool00?l000000ooo0003o`00
00;oo`000_l000000ooo003o0000o`000003o`00o`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0>_ooool000[ooooo0_l0000Qooooo`;o00000_l0o`001ol0003o0?l0o`000?l0003o0?l0
o`000?l0o`000_l000000ol0o`3o0000o`3o0002o`0000Go0?l000?o0000ooooooooool02oooool3
o`0000?oo`0000Oo0000ool00?l0003oo`00o`000?oo003o000000?oo`0000Go0000ool00?oo003o
o`00o`000003ool000Ko000000Goo`00o`000?oo003oo`00o`000002ool00004o`000?oo003oo`00
o`0000;o003o00Go0000o`3o0?l0o`3o0?l0o`000002o`3o0005o`000?l0o`3o0?l0o`3o0?l00000
0_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o
0006o`000?l0o`3o0?l0o`3o0?l0003o0?l00_l000000ol0o`3o0000o`3o0005o`000003ool00?l0
003oo`0000?oo`000_l00002ool000;o000000Goo`00o`000?l00?oo003oo`00000Uooooo`;o0000
?Oooool000cooooo0ol0000Oooooo`03o`000?l0o`3o0?l000;o000000?o0?l0o`000?l0o`000_l0
00000ol0o`3o0000o`3o0002o`000005o`3o0?l0003o0?l0o`000?l0o`000_l0000?ooooo`04o`00
0?oo003oo`00o`0000;oo`0000Go0000ool00?oo003oo`00o`000003ool00005o`000?oo003oo`00
ool00?l000000ooo00001Ol0003oo`00ool00?oo003o000000;oo`002?l000001Ooo003o0000o`00
ool00?oo000000;o0?l000Co0000o`3o0?l0o`3o00000ol0o`001?l0003o0?l0o`3o0?l00003o`3o
0003o`000?l0o`3o0?l000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o00?o000000Co0?l0
o`000?l0o`3o00000_l0o`000ol0003o0?l0o`3o0002o`000003ool00?l0003oo`0000Co00000ooo
00002Ol0003oo`00ool00?oo003o0000ool00?l0003o003oo`00000Uooooo`03o`000?oooooooooo
03gooooo000?ooooo`;o00007_ooool3o`0000?o0?l00_l00003o`3o00;o00001?l0o`02o`0001;o
oooo00Co0000ool00?l0003o00000_oo00000ol0003oo`00o`000003ool00005o`000?oo003oo`00
ool00?l000000ooo0003o`000005ool00?l0003oo`00ool00?l000000ooo00001Ol0003oo`00ool0
0?l0003oo`0000Ko00000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000Ko0000o`3o0?l0
o`3o0000o`3o0?l00002o`3o0003o`000?l0o`3o000000?o0?l000Go0000o`3o0?l0o`3o0?l0o`00
0003o`3o00[o000000?oo`00o`000?oo00000_l00004ool00003o`000?oo003oo`0000;o00000_oo
00000ol0003oo`00o`00000Uooooo`03o`000?oooooooooo03kooooo000Aooooo`?o00006oooool2
o`0000;o0?l000?o0000o`3o0?l000000_l0o`03o`0000;o0?l000?o0000o`3o0?l000005Oooool0
1ol0003oo`00ool00?oo003o0000ool00?l000000ooo00001Ol0003oo`00ool00?oo003o000000?o
o`0000Co0000ool00?oo003oo`001_l000001Ooo003o0000ool00?oo003o000000;oo`0000Co0000
ool00?oo003o00000_l00?l2o`0000;o0?l000Co0000o`3o0?l0o`3o00000ol0o`000ol0003o0?l0
o`000004o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`001Ol0003o0?l0o`3o0?l0o`3o0000
00;o0?l000Co0000o`3o0?l0o`3o00000_l0o`001_l0003oo`00o`000?oo003o0000ool000;o0000
1?oo0002o`0000;oo`0000?o0000ool00?oo00000_l0000Tooooo`03o`000?oooooooooo03oooooo
000Dooooo`;o00006Oooool01Ol0003o0?l0o`3o0?l0003o0?l000;o000000Go0?l0o`000?l0003o
0?l0o`000002o`3o00;o00006?ooool01?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00
ool00?l000000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00002_l0
0002o`00o`;o00001?l0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o
0?l0o`000004o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`04o`0000;o0?l000Go0000o`3o
0?l0o`3o0000o`3o0008o`0000Coo`000_l00002ool00004o`000?oo003oo`00o`0002?ooooo00?o
0000ooooooooool0@?ooool001Kooooo0ol0000Fooooo`03o`000?l0o`3o0?l000;o000000Co0?l0
o`000?l0o`3o00001?l0o`000ol0003o0?l0ooooo`0Iooooo`07o`000?oo003oo`00ool00?l0003o
o`00o`000002ool00005o`000?oo003oo`00ool00?l000000ooo0003o`000005ool00?l0003oo`00
ool00?l000000ooo00001?l0003oo`00ool00?l00002ool000Co00000_l0o`000ol0003o0?l0o`00
0002o`3o0004o`000?l0o`3o0?l0o`0000;o0?l000?o0000o`3o0?l000000_l0o`000ol0003o0?l0
o`000003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`0;o`000003ool00?l0003oo`0000;o
o`000_l000001?oo003o0000ool00?l00002ool000;o000000?oo`00o`000?ooool08Oooool00ol0
003oooooooooo`11ooooo`006Oooool2o`0001Gooooo00Oo0000o`3o0?l0003o0?l0o`000?l0o`3o
000000;o0?l000Co0000o`3o0?l0003o00007Oooool02?l0003oo`00ool00?l0003oo`00o`000?oo
003o00000_oo00001Ol0003oo`00ool00?oo003o000000?oo`001_l000001Ooo003o0000ool00?oo
003o000000;oo`0000?o0000ool00?l000000_l00?l01?l0003o0?l0o`000?l00004o`3o0007o`00
0?l0o`3o0?l0o`3o0?l0003o0?l0o`000004o`3o0005o`000?l0o`3o0?l0o`3o0?l000000ol0o`00
1Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000Co0000o`3o0?l0o`3o00000_l0o`001_l0003oo`00
o`000?l0003oo`00o`0000Coo`000_l00002ool00006o`000?oo003oo`00o`000?oo003o00008?oo
ool2o`0004Cooooo000Kooooo`?o00004oooool01_l0003o0?l0o`3o0?l0003o0?l0o`0000;o0?l0
0_l0000Pooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?l0003oo`00o`000002ool00005
o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool0000;o`000003o`00ool0003o0000
00?o0?l000?o0000o`3o0?l000000_l0o`001?l0003o0?l0o`3o0?l00003o`3o0003o`000?l0o`3o
0?l000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o00;o000000Go0?l0o`000?l0o`3o0?l0
o`000002o`3o00Ko000000?oo`00o`000?oo00001?oo0002o`0000Coo`000_l0000Oooooo`03o`00
0?oooooooooo04Cooooo000Nooooo`;o00004Oooool00ol0003o0?l0o`3o0003o`000003o`3o0?l0
003o0?l002?ooooo00?o0000ool00?l000000ooo00001?l0003oo`00ool00?l00003ool000?o0000
00Goo`00o`000?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000;oo`0000Co0000o`00
ool0003o00000_l0o`001?l0003o0?l0o`3o0?l00004o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o
00000_l0o`000ol0003o0?l0o`000003o`3o0005o`000?l0o`3o0?l0o`3o0?l000000_l0o`0:o`00
0003ool00?l0003oo`0000Co00001?oo0002o`0000;oo`000ol0000Nooooo`03o`000?oooooooooo
04Gooooo000Pooooo`?o00003oooool4o`0000;o0?l000?o0000ooooooooool08oooool01Ol0003o
o`00ool00?oo003o000000;oo`0000Go0000ool00?oo003oo`00o`000003ool000Ko000000Goo`00
o`000?oo003oo`00o`000002ool00007o`000?oo003o003oo`000?l00?oo0000o`3o0002o`0000?o
0?l000Go0000o`3o0?l0003o0?l0o`000002o`3o0003o`000?l0o`3o0?l000;o0?l000Go0000o`3o
0?l0o`3o0?l0o`000003o`3o0004o`000?l0o`3o0?l0o`0000?o0?l000Co0000o`3o0?l0o`3o0000
0_l0o`000ol0003oo`00ool00002o`0000?oo`000_l00003ool00006o`000?oo003oo`00o`000?oo
003o00007Oooool00ol0003oooooooooo`16ooooo`008oooool2o`0000gooooo0_l000001?l0o`3o
0000o`3o0?l0000Yooooo`05o`000?oo003o0000ool00?l000000_oo00001Ol0003oo`00ool00?oo
003o000000?oo`0000?o0000ool00?oo00002_l00002o`00o`;o00000ol0o`001?l0003o0?l0o`3o
0?l00003o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000o`3o0?l0o`000_l0o`001Ol0003o0?l0
o`3o0?l0o`3o000000;o0?l00ol000001Ol0o`3o0000o`3o0?l0o`3o000000;o0?l000Oo0000ool0
0?l0003oo`00o`000?oo003o000000Coo`000_l00002ool00003o`000?oo003oo`0000;o00007?oo
ool00ol0003oooooooooo`17ooooo`009Oooool3o`0000[ooooo00?o0000o`3o0?l0o`000_l0000]
ooooo`05o`000?oo003o0000ool00?l000000_oo0003o`000005ool00?l0003oo`00ool00?l00000
0_oo00001Ol0003oo`00ool00?oo003o000000;oo`0000Co0000o`00ool0003o003o0_l0o`001?l0
003o0?l0o`3o0?l00004o`3o0006o`000?l0o`3o0?l0o`000?l0o`3o00000_l0o`000ol0003o0?l0
o`000003o`3o0005o`000?l0o`3o0000o`3o0?l000000_l0o`07o`000003o`3o0?l0003o000000Go
00001_oo00001?l0003oo`00ool00?oo0003o`0001Wooooo0_l0001:ooooo`00:?ooool2o`0000Wo
oooo0ol0000aooooo`05o`000?oo003o0000ool00?l000000_oo0009o`000005ool00?l0003oo`00
ool00?l000000_l00?l01?l0003o003oo`000?l0o`02o`0000?o0?l000Go0000o`3o0?l0003o0?l0
o`000002o`3o0003o`000?l0o`3o0?l000;o0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o0004
o`000?l0o`3o0?l0o`0000;o0?l000Ko0000o`3o0?l0o`3o0?l0o`000?l0o`03o`000004ool00?l0
003oo`00ool000;o00001?oo00001ol0003oo`00ool00?oo003o0000ool00?l000006?ooool00ol0
003oooooooooo`1:ooooo`00:_ooool3o`0000Kooooo0_l0000eooooo`04o`000?oo003oo`00o`00
00?oo`0000Co0000ool00?oo003o00000_oo0008o`000003o`00ool0o`3o000000?o0?l000Co0000
o`3o0?l0o`3o00000ol0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000;o0?l000Go
0000o`3o0?l0o`3o0?l0o`000002o`3o00Ko000000?o0?l0o`000?l000000_l000001Ooo003o0000
o`000?oo003o000000?oo`000ol00002ool000;o000000Coo`00o`000?l0003o00005oooool00ol0
003oooooooooo`1;ooooo`00;Oooool2o`0000Gooooo00?o0000ooooooooool0=Oooool3o`000005
ool00?l0003oo`00ool00?l000000_oo00001Ol0003oo`00ool00?oo003o000000;oo`0000Co0000
o`00ool0003o00000_l0o`001?l0003o0?l0o`3o0?l00002o`3o0003o`000?l0o`3o000000;o0?l0
00?o0000o`3o0?l000000_l0o`000ol0003o0?l0o`000003o`3o0004o`000?l0o`3o0?l0o`0000?o
0?l000Oo0000o`3o0?l0o`3o0000o`3o0?l0003o0?l000Go000000?oo`00o`000?oo00000ooo0002
o`0000;oo`0000?o0000ool00?oo00000_l0000Fooooo`03o`000?oooooooooo04cooooo000_oooo
o`?o0000?Oooool9o`000005ool00?l0003oo`00ool00?l000000_l00?l3o`000003o`3o0?l0003o
000000?o0?l000?o0000o`3o0?l000001?l0o`000ol0003o0?l0o`3o0002o`3o0005o`000?l0o`3o
0?l0o`3o0?l000000_l0o`03o`000007o`3o0?l0003o0?l0o`3o0?l0003o0?l0o`000002o`3o00;o
000000?oo`00o`000?oo00000_l00005ool00005o`000?oo003o0000ool00?l000000_oo00000ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo000booooo`;o0000A?ooool7o`000004
o`00ool0o`3o0?l0o`0000?o0?l000Co0000o`3o0?l0o`3o00000ol0o`000ol0003o0?l0o`3o0002
o`3o0003o`000?l0o`3o0?l000;o0?l000Co0000o`3o0?l0o`3o00000ol0o`0:o`000004ool00?l0
003oo`00o`0000;oo`000ol00003ool000;o00000_oo00000ol0003oo`00o`00000Dooooo`03o`00
0?oooooooooo04kooooo000dooooo`?o0000BOooool2o`0000;o0?l000Co0000o`3o0?l0o`3o0000
0_l0o`000ol0003o0?l0o`000002o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l00000
0_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o
0000ool00?l0003oo`00o`000?oo003o0000ool00?l000000_oo0003o`0000;oo`0000?o0000ool0
0?oo00000_l0000Booooo`;o0000DOooool003Oooooo0_l00019ooooo`04o`000?l0o`3o0000o`00
00?o0?l000?o0000o`3o0?l000001?l0o`000ol0003o0?l0o`3o0002o`3o0005o`000?l0o`3o0000
o`3o0?l000000_l0o`06o`000005o`3o0?l0003o0?l0o`000?l0o`001_l00002ool00004o`000?oo
003oo`00ool000;o00000_oo00001?l0003oo`00ool00?l0000Aooooo`03o`000?oooooooooo057o
oooo000iooooo`?o0000Aoooool01Ol0003o0?l0o`3o0?l0o`3o000000;o0?l000Go0000o`3o0?l0
o`3o0?l0o`000004o`3o0003o`000?l0o`3o0?l000;o0?l000Co0000o`3o0?l0o`3o00000ol0o`00
0ol0003o0?l0o`3o0006o`0000Gooooo0_l000000ooo003o0000ool00002ool00007o`000?oo003o
o`00ool00?l0003oo`00o`00000@ooooo`03o`000?oooooooooo05;ooooo000looooo`;o0000Aooo
ool01?l0003o0?l0o`3o0?l00002o`3o0003o`000?l0o`3o000000;o0?l000?o0000o`3o0?l00000
0_l0o`000ol0003o0?l0o`000002o`3o00?o000000Oo0?l0o`000?l0o`3o0?l0o`000?l0o`3o0000
00;o0?l000?o0000ooooooooool01oooool00ol0003oo`00ool00002ool00004o`000?oo003oo`00
ool000;o00003oooool00ol0003oooooooooo`1Cooooo`00?_ooool3o`0004Gooooo00Co0000o`3o
0?l0o`3o00000_l0o`000ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o0?l000;o0?l000Co0000
o`3o0?l0o`3o00000ol0o`09o`0000_ooooo1?l00005ool00003o`000?oooooooooo00cooooo00?o
0000ooooooooool0E?ooool0047ooooo0_l00015ooooo`03o`000?l0o`3o000000Co0?l000?o0000
o`3o0?l0o`000_l0o`001Ol0003o0?l0o`3o0?l0o`3o000000?o0?l000Co0000o`3o0?l0o`3o0000
0_l0o`001?l0003o0?l0o`3o0?l0000>ooooo`Coo`0000Co0000ool00?oo003o00003?ooool00ol0
003oooooooooo`1Eooooo`00@oooool3o`0004?ooooo00Ko0000o`3o0?l0o`3o0000o`3o0?l00002
o`3o0007o`000?l0o`3o0000o`3o0?l0003o0?l0o`000003o`3o00Oo00000_l0o`000ol0003ooooo
ooooo`0>ooooo`;o000000?oo`00o`000?l000000_l0000:ooooo`;o0000F?ooool004Kooooo0_l0
0012ooooo`04o`000?l0o`3o0?l0o`0000Co0?l000Go0000o`3o0?l0o`3o0?l0o`000003o`3o0004
o`000?l0o`3o0?l0o`0000?o0?l00ol0000Booooo`?oo`0000?o0000ool00?l000002Oooool00ol0
003oooooooooo`1Hooooo`00B?ooool3o`00043ooooo00?o0000o`3o0?l0o`000_l0o`000ol0003o
0?l0o`3o0002o`3o0004o`000?l0o`3o0?l0o`3o00Co00000ol0o`000ol0003o0?l0o`00000Doooo
o`03o`000?oo003oo`0000;o00002?ooool00ol0003oooooooooo`1Iooooo`00Boooool2o`00047o
oooo00Oo0000o`3o0?l0o`3o0?l0o`000?l0o`3o000000;o0?l000Go0000o`3o0?l0o`3o0?l0o`00
0003o`3o00?o00005_ooool01?l0003oo`00o`000?l00007ooooo`03o`000?oooooooooo05[ooooo
001=ooooo`?o0000@?ooool01?l0003o0?l0o`3o0?l00002o`3o0005o`000?l0o`3o0?l0o`3o0?l0
00000ol0o`001?l0003o0?l0o`3o0?l0000Gooooo`;oo`0000?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Kooooo`00D?ooool2o`0003oooooo00Go0000o`3o0?l0o`3o0?l0o`000003o`3o
0004o`000?l0o`3o0?l0o`3o00;o000000?o0?l0o`000?ooool06?ooool2o`0000Gooooo00?o0000
ooooooooool0G?ooool005;ooooo0_l00010ooooo`05o`000?l0o`3o0?l0o`3o0?l000000ol0o`00
1?l0003o0?l0o`3o0?l0000Kooooo`04o`000?ooooooooooooooo`;o0000Goooool005Cooooo0ol0
000nooooo`03o`000?l0o`3o000000?o0?l000Go0000o`3o0?l0003o0?l0o`00000Nooooo`03o`00
0?oooooooooo05oooooo001Gooooo`;o0000?Oooool01Ol0003o0?l0o`3o0?l0o`3o000000?o0?l0
00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00FOooool3o`0003gooooo00Go
0000o`3o0?l0o`3o0?l0o`00000Nooooo`03o`000?oooooooooo067ooooo001Looooo`;o0000?_oo
ool2o`0001gooooo00?o0000ooooooooool0H_ooool005kooooo0ol0000looooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Hoooool0067ooooo0_l0000jooooo`03o`000?oooooooooo
01Sooooo0_l0001Vooooo`00Hoooool3o`0003Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1Vooooo`00I_ooool2o`0003Gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`1Wooooo`00J?ooool3o`0003;ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1Xooooo`00Joooool2o`00033ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Y
ooooo`00KOooool3o`0002gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Zoooo
o`00L?ooool2o`0002_ooooo00?o0000ooooooooool04Oooool2o`0006gooooo001booooo`?o0000
:?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06gooooo001eooooo`;o00009_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06kooooo001gooooo`?o00008oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06oooooo001jooooo`;o00008Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo073ooooo001looooo`?o00007_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo077ooooo001oooooo`;o00007?ooool00ol0003ooooo
ooooo`0:ooooo`;o0000M?ooool0087ooooo0ol0000Iooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0M?ooool008Cooooo0_l0000Gooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0MOooool008Kooooo0ol0000Dooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0M_ooool008Wooooo0_l0000Booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Moooool008_ooooo0ol0000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
N?ooool008kooooo0_l0000=ooooo`03o`000?oooooooooo00?ooooo0_l0001kooooo`00T?ooool3
o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1kooooo`00Toooool2o`00
00Sooooo00Go0000ooooooooooooooooo`00001nooooo`00UOooool3o`0000Gooooo00Co0000oooo
oooooooo0000Ooooool009Sooooo0_l00003ooooo`03o`000?oooooo0000083ooooo002Jooooo`Go
0000POooool009gooooo00?o0000ooooooooool0P?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {253.688, 0}} -> {0.0298069, -0.00723774, \
0.00352333, 0.00352333}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["extrema = NSolve[{Dc1==0,Dc2==0},{c1,c2}]", "Input",
  CellLabel->"In[79]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[BoxData[
    \({{c1 \[Rule] \(\(0.3993993359233803`\)\(\[InvisibleSpace]\)\) + 
            0.057970682541888696`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.6925989399955231`\)\(\[InvisibleSpace]\)\) + 
            1.4577257204078429`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.3993993359233803`\)\(\[InvisibleSpace]\)\) - 
            0.057970682541888696`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.6925989399955231`\)\(\[InvisibleSpace]\)\) - 
            1.4577257204078429`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.4603479732771091`, 
        c2 \[Rule] \(-0.734278282169737`\)}, {c1 \[Rule] \
\(\(0.417162657097128`\)\(\[InvisibleSpace]\)\) + 
            0.05416519714235684`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.08589715957703327`\)\(\[InvisibleSpace]\)\) + 
            1.01919693851109`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.417162657097128`\)\(\[InvisibleSpace]\)\) - 
            0.05416519714235684`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.08589715957703327`\)\(\[InvisibleSpace]\)\) - 
            1.01919693851109`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.5468132694060545`, 
        c2 \[Rule] \(-0.42220186660726106`\)}, {c1 \[Rule] \
\(\(0.3012254904119649`\)\(\[InvisibleSpace]\)\) + 
            0.10829343272432351`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.4574253172065374`\) + 
            0.14553713623580852`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.3012254904119649`\)\(\[InvisibleSpace]\)\) - 
            0.10829343272432351`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.4574253172065374`\) - 
            0.14553713623580852`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.2867890762269588`\)\(\[InvisibleSpace]\)\) + 
            0.15693363663121246`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.34991489670325016`\) + 
            0.23313535217182532`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.2867890762269588`\)\(\[InvisibleSpace]\)\) - 
            0.15693363663121246`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.34991489670325016`\) - 
            0.23313535217182532`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.2771046587950033`, 
        c2 \[Rule] \(-0.307059551361547`\)}, {c1 \[Rule] \
\(\(0.16207310029734687`\)\(\[InvisibleSpace]\)\) + 
            0.2242141027674198`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.15014914372042404`\) + 
            
            0.2657975177881783`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.16207310029734687`\)\(\[InvisibleSpace]\)\) - 
            0.2242141027674198`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.15014914372042404`\) - 
            0.2657975177881783`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.143053200696707`\)\(\[InvisibleSpace]\)\) + 
            0.2622275408411306`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.15839497490497534`\) + 
            0.23092678644577286`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.143053200696707`\)\(\[InvisibleSpace]\)\) - 
            0.2622275408411306`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.15839497490497534`\) - 
            0.23092678644577286`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.10417747460195474`\)\(\[InvisibleSpace]\)\) + 
            0.22999666063929367`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.11672519324491887`\) + 
            0.20696461918536077`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.10417747460195474`\)\(\[InvisibleSpace]\)\) - 
            0.22999666063929367`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.11672519324491887`\) - 
            0.20696461918536077`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.06403876414722313`\)\(\[InvisibleSpace]\)\) - 
            0.25529974278927003`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.13598259006235372`\) - 
            0.1805502109448318`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.06403876414722313`\)\(\[InvisibleSpace]\)\) + 
            0.25529974278927003`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.13598259006235372`\) + 
            0.1805502109448318`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.03582992178022279`\) - 0.1506420341658657`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.026303025933264473`\)\(\[InvisibleSpace]\)\) + 
            0.049170606640057846`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.03582992178022279`\) + 0.1506420341658657`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.026303025933264473`\)\(\[InvisibleSpace]\)\) - 
            0.049170606640057846`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.002679298582849403`\) - 0.13848363434786834`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.014699711672058783`\)\(\[InvisibleSpace]\)\) + 
            0.05457049962461041`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.002679298582849403`\) + 0.13848363434786834`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.014699711672058783`\)\(\[InvisibleSpace]\)\) - 
            0.05457049962461041`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.12056955574950942`\)\(\[InvisibleSpace]\)\) + 
            0.09795686888804878`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.04861968854257094`\)\(\[InvisibleSpace]\)\) + 
            0.23490155672413365`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.12056955574950942`\)\(\[InvisibleSpace]\)\) - 
            0.09795686888804878`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.04861968854257094`\)\(\[InvisibleSpace]\)\) - 
            0.23490155672413365`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.08177969006962636`\)\(\[InvisibleSpace]\)\) + 
            0.12684778292665763`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.018231541073786543`\) + 
            0.17853849487054532`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.08177969006962636`\)\(\[InvisibleSpace]\)\) - 
            0.12684778292665763`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.018231541073786543`\) - 
            0.17853849487054532`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.04100961610273617`\)\(\[InvisibleSpace]\)\) - 
            0.18866712850262352`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.07929844314784285`\) - 
            0.14807001674536943`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.04100961610273617`\)\(\[InvisibleSpace]\)\) + 
            0.18866712850262352`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.07929844314784285`\) + 
            0.14807001674536943`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.09285263580162532`\) - 0.22185291859584397`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.11441417513158744`\) - 
            0.07267557843194748`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.09285263580162532`\) + 0.22185291859584397`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.11441417513158744`\) + 
            0.07267557843194748`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.11513833066352906`\)\(\[InvisibleSpace]\)\) + 
            0.09642104795256774`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.05145612228639023`\)\(\[InvisibleSpace]\)\) + 
            0.16756558893240558`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.11513833066352906`\)\(\[InvisibleSpace]\)\) - 
            0.09642104795256774`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.05145612228639023`\)\(\[InvisibleSpace]\)\) - 
            
            0.16756558893240558`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.020942739973460387`\) - 0.1939995685608236`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.09549185242594706`\) - 
            0.09795060352484178`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.020942739973460387`\) + 0.1939995685608236`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.09549185242594706`\) + 
            0.09795060352484178`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.0480754833267823`\)\(\[InvisibleSpace]\)\) + 
            0.13878182665203503`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.04132947537648816`\) + 
            0.13187543879221716`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.0480754833267823`\)\(\[InvisibleSpace]\)\) - 
            0.13878182665203503`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.04132947537648816`\) - 
            0.13187543879221716`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.03685852490639086`\)\(\[InvisibleSpace]\)\) + 
            0.02562883269523909`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.027136569647790116`\) + 
            0.02809861440967344`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.03685852490639086`\)\(\[InvisibleSpace]\)\) - 
            0.02562883269523909`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.027136569647790116`\) - 
            0.02809861440967344`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.037051044875348306`, 
        c2 \[Rule] \(-0.022180318377286498`\)}, {c1 \[Rule] \
\(-0.03811154932119528`\) - 0.03372231274091531`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.0674265889825862`\) - 
            0.01988608246366904`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.03811154932119528`\) + 0.03372231274091531`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.0674265889825862`\) + 
            0.01988608246366904`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.10841041490257902`\) - 0.07019995444975734`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.1104547946383131`\) - 
            0.027370176383079984`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.10841041490257902`\) + 0.07019995444975734`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.1104547946383131`\) + 
            0.027370176383079984`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.003434764080521738`\)\(\[InvisibleSpace]\)\) + 
            0.01051946947762127`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.017987317794990083`\) + 
            
            0.009305962098473067`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.003434764080521738`\)\(\[InvisibleSpace]\)\) - 
            0.01051946947762127`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.017987317794990083`\) - 
            0.009305962098473067`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.0035390080197389385`, 
        c2 \[Rule] \(-0.017555283507059045`\)}, {c1 \[Rule] 
          0.10009364374841606`, 
        c2 \[Rule] 0.09875984579765207`}, {c1 \[Rule] 0.09261627024416218`, 
        c2 \[Rule] 0.06755193023343098`}}\)], "Output",
  CellLabel->"Out[79]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Length[extrema]", "Input",
  CellLabel->"In[80]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[BoxData[
    \(49\)], "Output",
  CellLabel->"Out[80]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell["\<\
D2c1 = D[meritFunction,{c1,2}];
D2c2 = D[meritFunction,{c2,2}];
Dc1c2 = D[meritFunction,c1,c2];\
\>", "Input",
  CellLabel->"In[81]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{

Cell["\<\
finalextrema = 
\tUnion[Select[extrema,
\t\t((\tc1==Re[c1]&&c2==Re[c2]&&
\t\t\tAbs[c1]<.1&&Abs[c2]<.1&&
\t\t\t(D2c1*D2c2-Dc1c2^2)>0&&D2c1>0
\t\t\t)/.#)&]]\
\>", "Input",
  CellLabel->"In[84]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[BoxData[
    \({{c1 \[Rule] 0.0035390080197389385`, 
        c2 \[Rule] \(-0.017555283507059045`\)}, {c1 \[Rule] 
          0.037051044875348306`, 
        c2 \[Rule] \(-0.022180318377286498`\)}}\)], "Output",
  CellLabel->"Out[84]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Map[{#,FindFocusFast[TurboPlot[
\tplot,SymbolicValues->#, PlotType->TopView]]}&,
\tfinalextrema]\
\>", "Input",
  CellLabel->"In[85]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.595238 0.00634921 0.1 0.00634921 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.59777 .00476 m
.64597 .00476 L
.65311 .03651 L
.59636 .03651 L
.59777 .00476 L
F
.59636 .03651 m
.65311 .03651 L
.65733 .06825 L
.59552 .06825 L
.59636 .03651 L
F
.59552 .06825 m
.65733 .06825 L
.65873 .1 L
.59524 .1 L
.59552 .06825 L
F
.59524 .1 m
.65873 .1 L
.65733 .13175 L
.59552 .13175 L
.59524 .1 L
F
.59552 .13175 m
.65733 .13175 L
.65311 .16349 L
.59636 .16349 L
.59552 .13175 L
F
.59636 .16349 m
.65311 .16349 L
.64597 .19524 L
.59777 .19524 L
.59636 .16349 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.59777 .00476 m
.59636 .03651 L
.59552 .06825 L
.59524 .1 L
.59552 .13175 L
.59636 .16349 L
.59777 .19524 L
.64597 .19524 L
.65311 .16349 L
.65733 .13175 L
.65873 .1 L
.65733 .06825 L
.65311 .03651 L
.64597 .00476 L
.59777 .00476 L
s
.5 g
.59777 .1 m
.64597 .1 L
.65311 .1 L
.59636 .1 L
.59777 .1 L
F
.59636 .1 m
.65311 .1 L
.65733 .1 L
.59552 .1 L
.59636 .1 L
F
.59552 .1 m
.65733 .1 L
.65873 .1 L
.59524 .1 L
.59552 .1 L
F
.59524 .1 m
.65873 .1 L
.65733 .1 L
.59552 .1 L
.59524 .1 L
F
.59552 .1 m
.65733 .1 L
.65311 .1 L
.59636 .1 L
.59552 .1 L
F
.59636 .1 m
.65311 .1 L
.64597 .1 L
.59777 .1 L
.59636 .1 L
F
0 g
.59777 .1 m
.59636 .1 L
.59552 .1 L
.59524 .1 L
.59552 .1 L
.59636 .1 L
.59777 .1 L
.64597 .1 L
.65311 .1 L
.65733 .1 L
.65873 .1 L
.65733 .1 L
.65311 .1 L
.64597 .1 L
.59777 .1 L
s
.59777 .19524 m
.64597 .19524 L
.64597 .19199 L
.59777 .19199 L
.59777 .19524 L
s
.59777 .19199 m
.64597 .19199 L
.64597 .18248 L
.59777 .18248 L
.59777 .19199 L
s
.59777 .18248 m
.64597 .18248 L
.64597 .16734 L
.59777 .16734 L
.59777 .18248 L
s
.59777 .16734 m
.64597 .16734 L
.64597 .14762 L
.59777 .14762 L
.59777 .16734 L
s
.59777 .14762 m
.64597 .14762 L
.64597 .12465 L
.59777 .12465 L
.59777 .14762 L
s
.59777 .12465 m
.64597 .12465 L
.64597 .1 L
.59777 .1 L
.59777 .12465 L
s
.59777 .1 m
.64597 .1 L
.64597 .07535 L
.59777 .07535 L
.59777 .1 L
s
.59777 .07535 m
.64597 .07535 L
.64597 .05238 L
.59777 .05238 L
.59777 .07535 L
s
.59777 .05238 m
.64597 .05238 L
.64597 .03266 L
.59777 .03266 L
.59777 .05238 L
s
.59777 .03266 m
.64597 .03266 L
.64597 .01752 L
.59777 .01752 L
.59777 .03266 L
s
.59777 .01752 m
.64597 .01752 L
.64597 .00801 L
.59777 .00801 L
.59777 .01752 L
s
.59777 .00801 m
.64597 .00801 L
.64597 .00476 L
.59777 .00476 L
.59777 .00801 L
s
.59777 .00476 m
.64597 .00476 L
.64597 .00801 L
.59777 .00801 L
.59777 .00476 L
s
.59777 .00801 m
.64597 .00801 L
.64597 .01752 L
.59777 .01752 L
.59777 .00801 L
s
.59777 .01752 m
.64597 .01752 L
.64597 .03266 L
.59777 .03266 L
.59777 .01752 L
s
.59777 .03266 m
.64597 .03266 L
.64597 .05238 L
.59777 .05238 L
.59777 .03266 L
s
.59777 .05238 m
.64597 .05238 L
.64597 .07535 L
.59777 .07535 L
.59777 .05238 L
s
.59777 .07535 m
.64597 .07535 L
.64597 .1 L
.59777 .1 L
.59777 .07535 L
s
.59777 .1 m
.64597 .1 L
.64597 .12465 L
.59777 .12465 L
.59777 .1 L
s
.59777 .12465 m
.64597 .12465 L
.64597 .14762 L
.59777 .14762 L
.59777 .12465 L
s
.59777 .14762 m
.64597 .14762 L
.64597 .16734 L
.59777 .16734 L
.59777 .14762 L
s
.59777 .16734 m
.64597 .16734 L
.64597 .18248 L
.59777 .18248 L
.59777 .16734 L
s
.59777 .18248 m
.64597 .18248 L
.64597 .19199 L
.59777 .19199 L
.59777 .18248 L
s
.59777 .19199 m
.64597 .19199 L
.64597 .19524 L
.59777 .19524 L
.59777 .19199 L
s
.97619 .00476 m
.97619 .03651 L
.97619 .06825 L
.97619 .1 L
.97619 .13175 L
.97619 .16349 L
.97619 .19524 L
.97619 .19524 L
.97619 .16349 L
.97619 .13175 L
.97619 .1 L
.97619 .06825 L
.97619 .03651 L
.97619 .00476 L
.97619 .00476 L
s
.97619 .1 m
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
s
.97619 .19524 m
.97619 .19199 L
.97619 .18248 L
.97619 .16734 L
.97619 .14762 L
.97619 .12465 L
.97619 .1 L
.97619 .07535 L
.97619 .05238 L
.97619 .03266 L
.97619 .01752 L
.97619 .00801 L
.97619 .00476 L
.97619 .00801 L
.97619 .01752 L
.97619 .03266 L
.97619 .05238 L
.97619 .07535 L
.97619 .1 L
.97619 .12465 L
.97619 .14762 L
.97619 .16734 L
.97619 .18248 L
.97619 .19199 L
.97619 .19524 L
s
.039 .916 .04 r
.02381 .1 m
.59594 .15005 L
s
0 0 0 r
2.5 Mabswid
.59594 .15005 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59591 .14905 L
s
0 0 0 r
2.5 Mabswid
.59591 .14905 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59588 .14804 L
s
0 0 0 r
2.5 Mabswid
.59588 .14804 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59585 .14703 L
s
0 0 0 r
2.5 Mabswid
.59585 .14703 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59583 .14602 L
s
0 0 0 r
2.5 Mabswid
.59583 .14602 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5958 .14502 L
s
0 0 0 r
2.5 Mabswid
.5958 .14502 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59578 .14401 L
s
0 0 0 r
2.5 Mabswid
.59578 .14401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59575 .143 L
s
0 0 0 r
2.5 Mabswid
.59575 .143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59573 .142 L
s
0 0 0 r
2.5 Mabswid
.59573 .142 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59571 .14099 L
s
0 0 0 r
2.5 Mabswid
.59571 .14099 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59568 .13999 L
s
0 0 0 r
2.5 Mabswid
.59568 .13999 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59566 .13898 L
s
0 0 0 r
2.5 Mabswid
.59566 .13898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59564 .13798 L
s
0 0 0 r
2.5 Mabswid
.59564 .13798 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59562 .13698 L
s
0 0 0 r
2.5 Mabswid
.59562 .13698 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5956 .13597 L
s
0 0 0 r
2.5 Mabswid
.5956 .13597 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59558 .13497 L
s
0 0 0 r
2.5 Mabswid
.59558 .13497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59556 .13397 L
s
0 0 0 r
2.5 Mabswid
.59556 .13397 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59554 .13297 L
s
0 0 0 r
2.5 Mabswid
.59554 .13297 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59552 .13196 L
s
0 0 0 r
2.5 Mabswid
.59552 .13196 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59551 .13096 L
s
0 0 0 r
2.5 Mabswid
.59551 .13096 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59549 .12996 L
s
0 0 0 r
2.5 Mabswid
.59549 .12996 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59547 .12896 L
s
0 0 0 r
2.5 Mabswid
.59547 .12896 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59546 .12796 L
s
0 0 0 r
2.5 Mabswid
.59546 .12796 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59544 .12696 L
s
0 0 0 r
2.5 Mabswid
.59544 .12696 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59543 .12596 L
s
0 0 0 r
2.5 Mabswid
.59543 .12596 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59541 .12496 L
s
0 0 0 r
2.5 Mabswid
.59541 .12496 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5954 .12396 L
s
0 0 0 r
2.5 Mabswid
.5954 .12396 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59538 .12296 L
s
0 0 0 r
2.5 Mabswid
.59538 .12296 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59537 .12196 L
s
0 0 0 r
2.5 Mabswid
.59537 .12196 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59536 .12096 L
s
0 0 0 r
2.5 Mabswid
.59536 .12096 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59535 .11996 L
s
0 0 0 r
2.5 Mabswid
.59535 .11996 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59534 .11896 L
s
0 0 0 r
2.5 Mabswid
.59534 .11896 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59533 .11796 L
s
0 0 0 r
2.5 Mabswid
.59533 .11796 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59532 .11696 L
s
0 0 0 r
2.5 Mabswid
.59532 .11696 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59531 .11596 L
s
0 0 0 r
2.5 Mabswid
.59531 .11596 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5953 .11497 L
s
0 0 0 r
2.5 Mabswid
.5953 .11497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59529 .11397 L
s
0 0 0 r
2.5 Mabswid
.59529 .11397 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59528 .11297 L
s
0 0 0 r
2.5 Mabswid
.59528 .11297 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59528 .11197 L
s
0 0 0 r
2.5 Mabswid
.59528 .11197 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59527 .11097 L
s
0 0 0 r
2.5 Mabswid
.59527 .11097 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59527 .10997 L
s
0 0 0 r
2.5 Mabswid
.59527 .10997 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59526 .10898 L
s
0 0 0 r
2.5 Mabswid
.59526 .10898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59526 .10798 L
s
0 0 0 r
2.5 Mabswid
.59526 .10798 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59525 .10698 L
s
0 0 0 r
2.5 Mabswid
.59525 .10698 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59525 .10598 L
s
0 0 0 r
2.5 Mabswid
.59525 .10598 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59525 .10499 L
s
0 0 0 r
2.5 Mabswid
.59525 .10499 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .10399 L
s
0 0 0 r
2.5 Mabswid
.59524 .10399 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .10299 L
s
0 0 0 r
2.5 Mabswid
.59524 .10299 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .10199 L
s
0 0 0 r
2.5 Mabswid
.59524 .10199 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .101 L
s
0 0 0 r
2.5 Mabswid
.59524 .101 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .1 L
s
0 0 0 r
2.5 Mabswid
.59524 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .099 L
s
0 0 0 r
2.5 Mabswid
.59524 .099 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .09801 L
s
0 0 0 r
2.5 Mabswid
.59524 .09801 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .09701 L
s
0 0 0 r
2.5 Mabswid
.59524 .09701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .09601 L
s
0 0 0 r
2.5 Mabswid
.59524 .09601 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59525 .09501 L
s
0 0 0 r
2.5 Mabswid
.59525 .09501 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59525 .09402 L
s
0 0 0 r
2.5 Mabswid
.59525 .09402 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59525 .09302 L
s
0 0 0 r
2.5 Mabswid
.59525 .09302 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59526 .09202 L
s
0 0 0 r
2.5 Mabswid
.59526 .09202 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59526 .09102 L
s
0 0 0 r
2.5 Mabswid
.59526 .09102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59527 .09003 L
s
0 0 0 r
2.5 Mabswid
.59527 .09003 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59527 .08903 L
s
0 0 0 r
2.5 Mabswid
.59527 .08903 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59528 .08803 L
s
0 0 0 r
2.5 Mabswid
.59528 .08803 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59528 .08703 L
s
0 0 0 r
2.5 Mabswid
.59528 .08703 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59529 .08603 L
s
0 0 0 r
2.5 Mabswid
.59529 .08603 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5953 .08503 L
s
0 0 0 r
2.5 Mabswid
.5953 .08503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59531 .08404 L
s
0 0 0 r
2.5 Mabswid
.59531 .08404 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59532 .08304 L
s
0 0 0 r
2.5 Mabswid
.59532 .08304 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59533 .08204 L
s
0 0 0 r
2.5 Mabswid
.59533 .08204 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59534 .08104 L
s
0 0 0 r
2.5 Mabswid
.59534 .08104 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59535 .08004 L
s
0 0 0 r
2.5 Mabswid
.59535 .08004 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59536 .07904 L
s
0 0 0 r
2.5 Mabswid
.59536 .07904 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59537 .07804 L
s
0 0 0 r
2.5 Mabswid
.59537 .07804 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59538 .07704 L
s
0 0 0 r
2.5 Mabswid
.59538 .07704 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5954 .07604 L
s
0 0 0 r
2.5 Mabswid
.5954 .07604 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59541 .07504 L
s
0 0 0 r
2.5 Mabswid
.59541 .07504 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59543 .07404 L
s
0 0 0 r
2.5 Mabswid
.59543 .07404 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59544 .07304 L
s
0 0 0 r
2.5 Mabswid
.59544 .07304 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59546 .07204 L
s
0 0 0 r
2.5 Mabswid
.59546 .07204 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59547 .07104 L
s
0 0 0 r
2.5 Mabswid
.59547 .07104 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59549 .07004 L
s
0 0 0 r
2.5 Mabswid
.59549 .07004 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59551 .06904 L
s
0 0 0 r
2.5 Mabswid
.59551 .06904 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59552 .06804 L
s
0 0 0 r
2.5 Mabswid
.59552 .06804 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59554 .06703 L
s
0 0 0 r
2.5 Mabswid
.59554 .06703 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59556 .06603 L
s
0 0 0 r
2.5 Mabswid
.59556 .06603 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59558 .06503 L
s
0 0 0 r
2.5 Mabswid
.59558 .06503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5956 .06403 L
s
0 0 0 r
2.5 Mabswid
.5956 .06403 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59562 .06302 L
s
0 0 0 r
2.5 Mabswid
.59562 .06302 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59564 .06202 L
s
0 0 0 r
2.5 Mabswid
.59564 .06202 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59566 .06102 L
s
0 0 0 r
2.5 Mabswid
.59566 .06102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59568 .06001 L
s
0 0 0 r
2.5 Mabswid
.59568 .06001 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59571 .05901 L
s
0 0 0 r
2.5 Mabswid
.59571 .05901 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59573 .058 L
s
0 0 0 r
2.5 Mabswid
.59573 .058 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59575 .057 L
s
0 0 0 r
2.5 Mabswid
.59575 .057 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59578 .05599 L
s
0 0 0 r
2.5 Mabswid
.59578 .05599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5958 .05498 L
s
0 0 0 r
2.5 Mabswid
.5958 .05498 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59583 .05398 L
s
0 0 0 r
2.5 Mabswid
.59583 .05398 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59585 .05297 L
s
0 0 0 r
2.5 Mabswid
.59585 .05297 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59588 .05196 L
s
0 0 0 r
2.5 Mabswid
.59588 .05196 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59591 .05095 L
s
0 0 0 r
2.5 Mabswid
.59591 .05095 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59594 .04995 L
s
0 0 0 r
2.5 Mabswid
.59594 .04995 Mdot
.039 .916 .04 r
.5 Mabswid
.59594 .15005 m
.65484 .15293 L
s
0 0 0 r
2.5 Mabswid
.65484 .15293 Mdot
.039 .916 .04 r
.5 Mabswid
.59591 .14905 m
.65499 .15187 L
s
0 0 0 r
2.5 Mabswid
.65499 .15187 Mdot
.039 .916 .04 r
.5 Mabswid
.59588 .14804 m
.65514 .15082 L
s
0 0 0 r
2.5 Mabswid
.65514 .15082 Mdot
.039 .916 .04 r
.5 Mabswid
.59585 .14703 m
.65529 .14976 L
s
0 0 0 r
2.5 Mabswid
.65529 .14976 Mdot
.039 .916 .04 r
.5 Mabswid
.59583 .14602 m
.65544 .1487 L
s
0 0 0 r
2.5 Mabswid
.65544 .1487 Mdot
.039 .916 .04 r
.5 Mabswid
.5958 .14502 m
.65558 .14764 L
s
0 0 0 r
2.5 Mabswid
.65558 .14764 Mdot
.039 .916 .04 r
.5 Mabswid
.59578 .14401 m
.65572 .14659 L
s
0 0 0 r
2.5 Mabswid
.65572 .14659 Mdot
.039 .916 .04 r
.5 Mabswid
.59575 .143 m
.65585 .14553 L
s
0 0 0 r
2.5 Mabswid
.65585 .14553 Mdot
.039 .916 .04 r
.5 Mabswid
.59573 .142 m
.65599 .14447 L
s
0 0 0 r
2.5 Mabswid
.65599 .14447 Mdot
.039 .916 .04 r
.5 Mabswid
.59571 .14099 m
.65612 .14341 L
s
0 0 0 r
2.5 Mabswid
.65612 .14341 Mdot
.039 .916 .04 r
.5 Mabswid
.59568 .13999 m
.65624 .14236 L
s
0 0 0 r
2.5 Mabswid
.65624 .14236 Mdot
.039 .916 .04 r
.5 Mabswid
.59566 .13898 m
.65636 .1413 L
s
0 0 0 r
2.5 Mabswid
.65636 .1413 Mdot
.039 .916 .04 r
.5 Mabswid
.59564 .13798 m
.65648 .14024 L
s
0 0 0 r
2.5 Mabswid
.65648 .14024 Mdot
.039 .916 .04 r
.5 Mabswid
.59562 .13698 m
.6566 .13918 L
s
0 0 0 r
2.5 Mabswid
.6566 .13918 Mdot
.039 .916 .04 r
.5 Mabswid
.5956 .13597 m
.65672 .13812 L
s
0 0 0 r
2.5 Mabswid
.65672 .13812 Mdot
.039 .916 .04 r
.5 Mabswid
.59558 .13497 m
.65683 .13707 L
s
0 0 0 r
2.5 Mabswid
.65683 .13707 Mdot
.039 .916 .04 r
.5 Mabswid
.59556 .13397 m
.65693 .13601 L
s
0 0 0 r
2.5 Mabswid
.65693 .13601 Mdot
.039 .916 .04 r
.5 Mabswid
.59554 .13297 m
.65704 .13495 L
s
0 0 0 r
2.5 Mabswid
.65704 .13495 Mdot
.039 .916 .04 r
.5 Mabswid
.59552 .13196 m
.65714 .13389 L
s
0 0 0 r
2.5 Mabswid
.65714 .13389 Mdot
.039 .916 .04 r
.5 Mabswid
.59551 .13096 m
.65724 .13283 L
s
0 0 0 r
2.5 Mabswid
.65724 .13283 Mdot
.039 .916 .04 r
.5 Mabswid
.59549 .12996 m
.65733 .13177 L
s
0 0 0 r
2.5 Mabswid
.65733 .13177 Mdot
.039 .916 .04 r
.5 Mabswid
.59547 .12896 m
.65742 .13072 L
s
0 0 0 r
2.5 Mabswid
.65742 .13072 Mdot
.039 .916 .04 r
.5 Mabswid
.59546 .12796 m
.65751 .12966 L
s
0 0 0 r
2.5 Mabswid
.65751 .12966 Mdot
.039 .916 .04 r
.5 Mabswid
.59544 .12696 m
.6576 .1286 L
s
0 0 0 r
2.5 Mabswid
.6576 .1286 Mdot
.039 .916 .04 r
.5 Mabswid
.59543 .12596 m
.65768 .12754 L
s
0 0 0 r
2.5 Mabswid
.65768 .12754 Mdot
.039 .916 .04 r
.5 Mabswid
.59541 .12496 m
.65776 .12648 L
s
0 0 0 r
2.5 Mabswid
.65776 .12648 Mdot
.039 .916 .04 r
.5 Mabswid
.5954 .12396 m
.65784 .12542 L
s
0 0 0 r
2.5 Mabswid
.65784 .12542 Mdot
.039 .916 .04 r
.5 Mabswid
.59538 .12296 m
.65791 .12436 L
s
0 0 0 r
2.5 Mabswid
.65791 .12436 Mdot
.039 .916 .04 r
.5 Mabswid
.59537 .12196 m
.65798 .1233 L
s
0 0 0 r
2.5 Mabswid
.65798 .1233 Mdot
.039 .916 .04 r
.5 Mabswid
.59536 .12096 m
.65805 .12225 L
s
0 0 0 r
2.5 Mabswid
.65805 .12225 Mdot
.039 .916 .04 r
.5 Mabswid
.59535 .11996 m
.65811 .12119 L
s
0 0 0 r
2.5 Mabswid
.65811 .12119 Mdot
.039 .916 .04 r
.5 Mabswid
.59534 .11896 m
.65817 .12013 L
s
0 0 0 r
2.5 Mabswid
.65817 .12013 Mdot
.039 .916 .04 r
.5 Mabswid
.59533 .11796 m
.65823 .11907 L
s
0 0 0 r
2.5 Mabswid
.65823 .11907 Mdot
.039 .916 .04 r
.5 Mabswid
.59532 .11696 m
.65828 .11801 L
s
0 0 0 r
2.5 Mabswid
.65828 .11801 Mdot
.039 .916 .04 r
.5 Mabswid
.59531 .11596 m
.65833 .11695 L
s
0 0 0 r
2.5 Mabswid
.65833 .11695 Mdot
.039 .916 .04 r
.5 Mabswid
.5953 .11497 m
.65838 .11589 L
s
0 0 0 r
2.5 Mabswid
.65838 .11589 Mdot
.039 .916 .04 r
.5 Mabswid
.59529 .11397 m
.65843 .11483 L
s
0 0 0 r
2.5 Mabswid
.65843 .11483 Mdot
.039 .916 .04 r
.5 Mabswid
.59528 .11297 m
.65847 .11377 L
s
0 0 0 r
2.5 Mabswid
.65847 .11377 Mdot
.039 .916 .04 r
.5 Mabswid
.59528 .11197 m
.65851 .11271 L
s
0 0 0 r
2.5 Mabswid
.65851 .11271 Mdot
.039 .916 .04 r
.5 Mabswid
.59527 .11097 m
.65854 .11165 L
s
0 0 0 r
2.5 Mabswid
.65854 .11165 Mdot
.039 .916 .04 r
.5 Mabswid
.59527 .10997 m
.65857 .11059 L
s
0 0 0 r
2.5 Mabswid
.65857 .11059 Mdot
.039 .916 .04 r
.5 Mabswid
.59526 .10898 m
.6586 .10953 L
s
0 0 0 r
2.5 Mabswid
.6586 .10953 Mdot
.039 .916 .04 r
.5 Mabswid
.59526 .10798 m
.65863 .10848 L
s
0 0 0 r
2.5 Mabswid
.65863 .10848 Mdot
.039 .916 .04 r
.5 Mabswid
.59525 .10698 m
.65865 .10742 L
s
0 0 0 r
2.5 Mabswid
.65865 .10742 Mdot
.039 .916 .04 r
.5 Mabswid
.59525 .10598 m
.65867 .10636 L
s
0 0 0 r
2.5 Mabswid
.65867 .10636 Mdot
.039 .916 .04 r
.5 Mabswid
.59525 .10499 m
.65869 .1053 L
s
0 0 0 r
2.5 Mabswid
.65869 .1053 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .10399 m
.65871 .10424 L
s
0 0 0 r
2.5 Mabswid
.65871 .10424 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .10299 m
.65872 .10318 L
s
0 0 0 r
2.5 Mabswid
.65872 .10318 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .10199 m
.65872 .10212 L
s
0 0 0 r
2.5 Mabswid
.65872 .10212 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .101 m
.65873 .10106 L
s
0 0 0 r
2.5 Mabswid
.65873 .10106 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .1 m
.65873 .1 L
s
0 0 0 r
2.5 Mabswid
.65873 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .099 m
.65873 .09894 L
s
0 0 0 r
2.5 Mabswid
.65873 .09894 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .09801 m
.65872 .09788 L
s
0 0 0 r
2.5 Mabswid
.65872 .09788 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .09701 m
.65872 .09682 L
s
0 0 0 r
2.5 Mabswid
.65872 .09682 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .09601 m
.65871 .09576 L
s
0 0 0 r
2.5 Mabswid
.65871 .09576 Mdot
.039 .916 .04 r
.5 Mabswid
.59525 .09501 m
.65869 .0947 L
s
0 0 0 r
2.5 Mabswid
.65869 .0947 Mdot
.039 .916 .04 r
.5 Mabswid
.59525 .09402 m
.65867 .09364 L
s
0 0 0 r
2.5 Mabswid
.65867 .09364 Mdot
.039 .916 .04 r
.5 Mabswid
.59525 .09302 m
.65865 .09258 L
s
0 0 0 r
2.5 Mabswid
.65865 .09258 Mdot
.039 .916 .04 r
.5 Mabswid
.59526 .09202 m
.65863 .09152 L
s
0 0 0 r
2.5 Mabswid
.65863 .09152 Mdot
.039 .916 .04 r
.5 Mabswid
.59526 .09102 m
.6586 .09047 L
s
0 0 0 r
2.5 Mabswid
.6586 .09047 Mdot
.039 .916 .04 r
.5 Mabswid
.59527 .09003 m
.65857 .08941 L
s
0 0 0 r
2.5 Mabswid
.65857 .08941 Mdot
.039 .916 .04 r
.5 Mabswid
.59527 .08903 m
.65854 .08835 L
s
0 0 0 r
2.5 Mabswid
.65854 .08835 Mdot
.039 .916 .04 r
.5 Mabswid
.59528 .08803 m
.65851 .08729 L
s
0 0 0 r
2.5 Mabswid
.65851 .08729 Mdot
.039 .916 .04 r
.5 Mabswid
.59528 .08703 m
.65847 .08623 L
s
0 0 0 r
2.5 Mabswid
.65847 .08623 Mdot
.039 .916 .04 r
.5 Mabswid
.59529 .08603 m
.65843 .08517 L
s
0 0 0 r
2.5 Mabswid
.65843 .08517 Mdot
.039 .916 .04 r
.5 Mabswid
.5953 .08503 m
.65838 .08411 L
s
0 0 0 r
2.5 Mabswid
.65838 .08411 Mdot
.039 .916 .04 r
.5 Mabswid
.59531 .08404 m
.65833 .08305 L
s
0 0 0 r
2.5 Mabswid
.65833 .08305 Mdot
.039 .916 .04 r
.5 Mabswid
.59532 .08304 m
.65828 .08199 L
s
0 0 0 r
2.5 Mabswid
.65828 .08199 Mdot
.039 .916 .04 r
.5 Mabswid
.59533 .08204 m
.65823 .08093 L
s
0 0 0 r
2.5 Mabswid
.65823 .08093 Mdot
.039 .916 .04 r
.5 Mabswid
.59534 .08104 m
.65817 .07987 L
s
0 0 0 r
2.5 Mabswid
.65817 .07987 Mdot
.039 .916 .04 r
.5 Mabswid
.59535 .08004 m
.65811 .07881 L
s
0 0 0 r
2.5 Mabswid
.65811 .07881 Mdot
.039 .916 .04 r
.5 Mabswid
.59536 .07904 m
.65805 .07775 L
s
0 0 0 r
2.5 Mabswid
.65805 .07775 Mdot
.039 .916 .04 r
.5 Mabswid
.59537 .07804 m
.65798 .0767 L
s
0 0 0 r
2.5 Mabswid
.65798 .0767 Mdot
.039 .916 .04 r
.5 Mabswid
.59538 .07704 m
.65791 .07564 L
s
0 0 0 r
2.5 Mabswid
.65791 .07564 Mdot
.039 .916 .04 r
.5 Mabswid
.5954 .07604 m
.65784 .07458 L
s
0 0 0 r
2.5 Mabswid
.65784 .07458 Mdot
.039 .916 .04 r
.5 Mabswid
.59541 .07504 m
.65776 .07352 L
s
0 0 0 r
2.5 Mabswid
.65776 .07352 Mdot
.039 .916 .04 r
.5 Mabswid
.59543 .07404 m
.65768 .07246 L
s
0 0 0 r
2.5 Mabswid
.65768 .07246 Mdot
.039 .916 .04 r
.5 Mabswid
.59544 .07304 m
.6576 .0714 L
s
0 0 0 r
2.5 Mabswid
.6576 .0714 Mdot
.039 .916 .04 r
.5 Mabswid
.59546 .07204 m
.65751 .07034 L
s
0 0 0 r
2.5 Mabswid
.65751 .07034 Mdot
.039 .916 .04 r
.5 Mabswid
.59547 .07104 m
.65742 .06928 L
s
0 0 0 r
2.5 Mabswid
.65742 .06928 Mdot
.039 .916 .04 r
.5 Mabswid
.59549 .07004 m
.65733 .06823 L
s
0 0 0 r
2.5 Mabswid
.65733 .06823 Mdot
.039 .916 .04 r
.5 Mabswid
.59551 .06904 m
.65724 .06717 L
s
0 0 0 r
2.5 Mabswid
.65724 .06717 Mdot
.039 .916 .04 r
.5 Mabswid
.59552 .06804 m
.65714 .06611 L
s
0 0 0 r
2.5 Mabswid
.65714 .06611 Mdot
.039 .916 .04 r
.5 Mabswid
.59554 .06703 m
.65704 .06505 L
s
0 0 0 r
2.5 Mabswid
.65704 .06505 Mdot
.039 .916 .04 r
.5 Mabswid
.59556 .06603 m
.65693 .06399 L
s
0 0 0 r
2.5 Mabswid
.65693 .06399 Mdot
.039 .916 .04 r
.5 Mabswid
.59558 .06503 m
.65683 .06293 L
s
0 0 0 r
2.5 Mabswid
.65683 .06293 Mdot
.039 .916 .04 r
.5 Mabswid
.5956 .06403 m
.65672 .06188 L
s
0 0 0 r
2.5 Mabswid
.65672 .06188 Mdot
.039 .916 .04 r
.5 Mabswid
.59562 .06302 m
.6566 .06082 L
s
0 0 0 r
2.5 Mabswid
.6566 .06082 Mdot
.039 .916 .04 r
.5 Mabswid
.59564 .06202 m
.65648 .05976 L
s
0 0 0 r
2.5 Mabswid
.65648 .05976 Mdot
.039 .916 .04 r
.5 Mabswid
.59566 .06102 m
.65636 .0587 L
s
0 0 0 r
2.5 Mabswid
.65636 .0587 Mdot
.039 .916 .04 r
.5 Mabswid
.59568 .06001 m
.65624 .05764 L
s
0 0 0 r
2.5 Mabswid
.65624 .05764 Mdot
.039 .916 .04 r
.5 Mabswid
.59571 .05901 m
.65612 .05659 L
s
0 0 0 r
2.5 Mabswid
.65612 .05659 Mdot
.039 .916 .04 r
.5 Mabswid
.59573 .058 m
.65599 .05553 L
s
0 0 0 r
2.5 Mabswid
.65599 .05553 Mdot
.039 .916 .04 r
.5 Mabswid
.59575 .057 m
.65585 .05447 L
s
0 0 0 r
2.5 Mabswid
.65585 .05447 Mdot
.039 .916 .04 r
.5 Mabswid
.59578 .05599 m
.65572 .05341 L
s
0 0 0 r
2.5 Mabswid
.65572 .05341 Mdot
.039 .916 .04 r
.5 Mabswid
.5958 .05498 m
.65558 .05236 L
s
0 0 0 r
2.5 Mabswid
.65558 .05236 Mdot
.039 .916 .04 r
.5 Mabswid
.59583 .05398 m
.65544 .0513 L
s
0 0 0 r
2.5 Mabswid
.65544 .0513 Mdot
.039 .916 .04 r
.5 Mabswid
.59585 .05297 m
.65529 .05024 L
s
0 0 0 r
2.5 Mabswid
.65529 .05024 Mdot
.039 .916 .04 r
.5 Mabswid
.59588 .05196 m
.65514 .04918 L
s
0 0 0 r
2.5 Mabswid
.65514 .04918 Mdot
.039 .916 .04 r
.5 Mabswid
.59591 .05095 m
.65499 .04813 L
s
0 0 0 r
2.5 Mabswid
.65499 .04813 Mdot
.039 .916 .04 r
.5 Mabswid
.59594 .04995 m
.65484 .04707 L
s
0 0 0 r
2.5 Mabswid
.65484 .04707 Mdot
.039 .916 .04 r
.5 Mabswid
.65484 .15293 m
.97619 .15275 L
s
0 0 0 r
2.5 Mabswid
.97619 .15275 Mdot
.039 .916 .04 r
.5 Mabswid
.65499 .15187 m
.97619 .1517 L
s
0 0 0 r
2.5 Mabswid
.97619 .1517 Mdot
.039 .916 .04 r
.5 Mabswid
.65514 .15082 m
.97619 .15066 L
s
0 0 0 r
2.5 Mabswid
.97619 .15066 Mdot
.039 .916 .04 r
.5 Mabswid
.65529 .14976 m
.97619 .14961 L
s
0 0 0 r
2.5 Mabswid
.97619 .14961 Mdot
.039 .916 .04 r
.5 Mabswid
.65544 .1487 m
.97619 .14857 L
s
0 0 0 r
2.5 Mabswid
.97619 .14857 Mdot
.039 .916 .04 r
.5 Mabswid
.65558 .14764 m
.97619 .14752 L
s
0 0 0 r
2.5 Mabswid
.97619 .14752 Mdot
.039 .916 .04 r
.5 Mabswid
.65572 .14659 m
.97619 .14647 L
s
0 0 0 r
2.5 Mabswid
.97619 .14647 Mdot
.039 .916 .04 r
.5 Mabswid
.65585 .14553 m
.97619 .14542 L
s
0 0 0 r
2.5 Mabswid
.97619 .14542 Mdot
.039 .916 .04 r
.5 Mabswid
.65599 .14447 m
.97619 .14438 L
s
0 0 0 r
2.5 Mabswid
.97619 .14438 Mdot
.039 .916 .04 r
.5 Mabswid
.65612 .14341 m
.97619 .14333 L
s
0 0 0 r
2.5 Mabswid
.97619 .14333 Mdot
.039 .916 .04 r
.5 Mabswid
.65624 .14236 m
.97619 .14228 L
s
0 0 0 r
2.5 Mabswid
.97619 .14228 Mdot
.039 .916 .04 r
.5 Mabswid
.65636 .1413 m
.97619 .14123 L
s
0 0 0 r
2.5 Mabswid
.97619 .14123 Mdot
.039 .916 .04 r
.5 Mabswid
.65648 .14024 m
.97619 .14018 L
s
0 0 0 r
2.5 Mabswid
.97619 .14018 Mdot
.039 .916 .04 r
.5 Mabswid
.6566 .13918 m
.97619 .13912 L
s
0 0 0 r
2.5 Mabswid
.97619 .13912 Mdot
.039 .916 .04 r
.5 Mabswid
.65672 .13812 m
.97619 .13807 L
s
0 0 0 r
2.5 Mabswid
.97619 .13807 Mdot
.039 .916 .04 r
.5 Mabswid
.65683 .13707 m
.97619 .13702 L
s
0 0 0 r
2.5 Mabswid
.97619 .13702 Mdot
.039 .916 .04 r
.5 Mabswid
.65693 .13601 m
.97619 .13597 L
s
0 0 0 r
2.5 Mabswid
.97619 .13597 Mdot
.039 .916 .04 r
.5 Mabswid
.65704 .13495 m
.97619 .13491 L
s
0 0 0 r
2.5 Mabswid
.97619 .13491 Mdot
.039 .916 .04 r
.5 Mabswid
.65714 .13389 m
.97619 .13386 L
s
0 0 0 r
2.5 Mabswid
.97619 .13386 Mdot
.039 .916 .04 r
.5 Mabswid
.65724 .13283 m
.97619 .13281 L
s
0 0 0 r
2.5 Mabswid
.97619 .13281 Mdot
.039 .916 .04 r
.5 Mabswid
.65733 .13177 m
.97619 .13175 L
s
0 0 0 r
2.5 Mabswid
.97619 .13175 Mdot
.039 .916 .04 r
.5 Mabswid
.65742 .13072 m
.97619 .1307 L
s
0 0 0 r
2.5 Mabswid
.97619 .1307 Mdot
.039 .916 .04 r
.5 Mabswid
.65751 .12966 m
.97619 .12964 L
s
0 0 0 r
2.5 Mabswid
.97619 .12964 Mdot
.039 .916 .04 r
.5 Mabswid
.6576 .1286 m
.97619 .12859 L
s
0 0 0 r
2.5 Mabswid
.97619 .12859 Mdot
.039 .916 .04 r
.5 Mabswid
.65768 .12754 m
.97619 .12753 L
s
0 0 0 r
2.5 Mabswid
.97619 .12753 Mdot
.039 .916 .04 r
.5 Mabswid
.65776 .12648 m
.97619 .12647 L
s
0 0 0 r
2.5 Mabswid
.97619 .12647 Mdot
.039 .916 .04 r
.5 Mabswid
.65784 .12542 m
.97619 .12542 L
s
0 0 0 r
2.5 Mabswid
.97619 .12542 Mdot
.039 .916 .04 r
.5 Mabswid
.65791 .12436 m
.97619 .12436 L
s
0 0 0 r
2.5 Mabswid
.97619 .12436 Mdot
.039 .916 .04 r
.5 Mabswid
.65798 .1233 m
.97619 .1233 L
s
0 0 0 r
2.5 Mabswid
.97619 .1233 Mdot
.039 .916 .04 r
.5 Mabswid
.65805 .12225 m
.97619 .12225 L
s
0 0 0 r
2.5 Mabswid
.97619 .12225 Mdot
.039 .916 .04 r
.5 Mabswid
.65811 .12119 m
.97619 .12119 L
s
0 0 0 r
2.5 Mabswid
.97619 .12119 Mdot
.039 .916 .04 r
.5 Mabswid
.65817 .12013 m
.97619 .12013 L
s
0 0 0 r
2.5 Mabswid
.97619 .12013 Mdot
.039 .916 .04 r
.5 Mabswid
.65823 .11907 m
.97619 .11907 L
s
0 0 0 r
2.5 Mabswid
.97619 .11907 Mdot
.039 .916 .04 r
.5 Mabswid
.65828 .11801 m
.97619 .11801 L
s
0 0 0 r
2.5 Mabswid
.97619 .11801 Mdot
.039 .916 .04 r
.5 Mabswid
.65833 .11695 m
.97619 .11696 L
s
0 0 0 r
2.5 Mabswid
.97619 .11696 Mdot
.039 .916 .04 r
.5 Mabswid
.65838 .11589 m
.97619 .1159 L
s
0 0 0 r
2.5 Mabswid
.97619 .1159 Mdot
.039 .916 .04 r
.5 Mabswid
.65843 .11483 m
.97619 .11484 L
s
0 0 0 r
2.5 Mabswid
.97619 .11484 Mdot
.039 .916 .04 r
.5 Mabswid
.65847 .11377 m
.97619 .11378 L
s
0 0 0 r
2.5 Mabswid
.97619 .11378 Mdot
.039 .916 .04 r
.5 Mabswid
.65851 .11271 m
.97619 .11272 L
s
0 0 0 r
2.5 Mabswid
.97619 .11272 Mdot
.039 .916 .04 r
.5 Mabswid
.65854 .11165 m
.97619 .11166 L
s
0 0 0 r
2.5 Mabswid
.97619 .11166 Mdot
.039 .916 .04 r
.5 Mabswid
.65857 .11059 m
.97619 .1106 L
s
0 0 0 r
2.5 Mabswid
.97619 .1106 Mdot
.039 .916 .04 r
.5 Mabswid
.6586 .10953 m
.97619 .10954 L
s
0 0 0 r
2.5 Mabswid
.97619 .10954 Mdot
.039 .916 .04 r
.5 Mabswid
.65863 .10848 m
.97619 .10848 L
s
0 0 0 r
2.5 Mabswid
.97619 .10848 Mdot
.039 .916 .04 r
.5 Mabswid
.65865 .10742 m
.97619 .10742 L
s
0 0 0 r
2.5 Mabswid
.97619 .10742 Mdot
.039 .916 .04 r
.5 Mabswid
.65867 .10636 m
.97619 .10636 L
s
0 0 0 r
2.5 Mabswid
.97619 .10636 Mdot
.039 .916 .04 r
.5 Mabswid
.65869 .1053 m
.97619 .1053 L
s
0 0 0 r
2.5 Mabswid
.97619 .1053 Mdot
.039 .916 .04 r
.5 Mabswid
.65871 .10424 m
.97619 .10424 L
s
0 0 0 r
2.5 Mabswid
.97619 .10424 Mdot
.039 .916 .04 r
.5 Mabswid
.65872 .10318 m
.97619 .10318 L
s
0 0 0 r
2.5 Mabswid
.97619 .10318 Mdot
.039 .916 .04 r
.5 Mabswid
.65872 .10212 m
.97619 .10212 L
s
0 0 0 r
2.5 Mabswid
.97619 .10212 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .10106 m
.97619 .10106 L
s
0 0 0 r
2.5 Mabswid
.97619 .10106 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .1 m
.97619 .1 L
s
0 0 0 r
2.5 Mabswid
.97619 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .09894 m
.97619 .09894 L
s
0 0 0 r
2.5 Mabswid
.97619 .09894 Mdot
.039 .916 .04 r
.5 Mabswid
.65872 .09788 m
.97619 .09788 L
s
0 0 0 r
2.5 Mabswid
.97619 .09788 Mdot
.039 .916 .04 r
.5 Mabswid
.65872 .09682 m
.97619 .09682 L
s
0 0 0 r
2.5 Mabswid
.97619 .09682 Mdot
.039 .916 .04 r
.5 Mabswid
.65871 .09576 m
.97619 .09576 L
s
0 0 0 r
2.5 Mabswid
.97619 .09576 Mdot
.039 .916 .04 r
.5 Mabswid
.65869 .0947 m
.97619 .0947 L
s
0 0 0 r
2.5 Mabswid
.97619 .0947 Mdot
.039 .916 .04 r
.5 Mabswid
.65867 .09364 m
.97619 .09364 L
s
0 0 0 r
2.5 Mabswid
.97619 .09364 Mdot
.039 .916 .04 r
.5 Mabswid
.65865 .09258 m
.97619 .09258 L
s
0 0 0 r
2.5 Mabswid
.97619 .09258 Mdot
.039 .916 .04 r
.5 Mabswid
.65863 .09152 m
.97619 .09152 L
s
0 0 0 r
2.5 Mabswid
.97619 .09152 Mdot
.039 .916 .04 r
.5 Mabswid
.6586 .09047 m
.97619 .09046 L
s
0 0 0 r
2.5 Mabswid
.97619 .09046 Mdot
.039 .916 .04 r
.5 Mabswid
.65857 .08941 m
.97619 .0894 L
s
0 0 0 r
2.5 Mabswid
.97619 .0894 Mdot
.039 .916 .04 r
.5 Mabswid
.65854 .08835 m
.97619 .08834 L
s
0 0 0 r
2.5 Mabswid
.97619 .08834 Mdot
.039 .916 .04 r
.5 Mabswid
.65851 .08729 m
.97619 .08728 L
s
0 0 0 r
2.5 Mabswid
.97619 .08728 Mdot
.039 .916 .04 r
.5 Mabswid
.65847 .08623 m
.97619 .08622 L
s
0 0 0 r
2.5 Mabswid
.97619 .08622 Mdot
.039 .916 .04 r
.5 Mabswid
.65843 .08517 m
.97619 .08516 L
s
0 0 0 r
2.5 Mabswid
.97619 .08516 Mdot
.039 .916 .04 r
.5 Mabswid
.65838 .08411 m
.97619 .0841 L
s
0 0 0 r
2.5 Mabswid
.97619 .0841 Mdot
.039 .916 .04 r
.5 Mabswid
.65833 .08305 m
.97619 .08304 L
s
0 0 0 r
2.5 Mabswid
.97619 .08304 Mdot
.039 .916 .04 r
.5 Mabswid
.65828 .08199 m
.97619 .08199 L
s
0 0 0 r
2.5 Mabswid
.97619 .08199 Mdot
.039 .916 .04 r
.5 Mabswid
.65823 .08093 m
.97619 .08093 L
s
0 0 0 r
2.5 Mabswid
.97619 .08093 Mdot
.039 .916 .04 r
.5 Mabswid
.65817 .07987 m
.97619 .07987 L
s
0 0 0 r
2.5 Mabswid
.97619 .07987 Mdot
.039 .916 .04 r
.5 Mabswid
.65811 .07881 m
.97619 .07881 L
s
0 0 0 r
2.5 Mabswid
.97619 .07881 Mdot
.039 .916 .04 r
.5 Mabswid
.65805 .07775 m
.97619 .07775 L
s
0 0 0 r
2.5 Mabswid
.97619 .07775 Mdot
.039 .916 .04 r
.5 Mabswid
.65798 .0767 m
.97619 .0767 L
s
0 0 0 r
2.5 Mabswid
.97619 .0767 Mdot
.039 .916 .04 r
.5 Mabswid
.65791 .07564 m
.97619 .07564 L
s
0 0 0 r
2.5 Mabswid
.97619 .07564 Mdot
.039 .916 .04 r
.5 Mabswid
.65784 .07458 m
.97619 .07458 L
s
0 0 0 r
2.5 Mabswid
.97619 .07458 Mdot
.039 .916 .04 r
.5 Mabswid
.65776 .07352 m
.97619 .07353 L
s
0 0 0 r
2.5 Mabswid
.97619 .07353 Mdot
.039 .916 .04 r
.5 Mabswid
.65768 .07246 m
.97619 .07247 L
s
0 0 0 r
2.5 Mabswid
.97619 .07247 Mdot
.039 .916 .04 r
.5 Mabswid
.6576 .0714 m
.97619 .07141 L
s
0 0 0 r
2.5 Mabswid
.97619 .07141 Mdot
.039 .916 .04 r
.5 Mabswid
.65751 .07034 m
.97619 .07036 L
s
0 0 0 r
2.5 Mabswid
.97619 .07036 Mdot
.039 .916 .04 r
.5 Mabswid
.65742 .06928 m
.97619 .0693 L
s
0 0 0 r
2.5 Mabswid
.97619 .0693 Mdot
.039 .916 .04 r
.5 Mabswid
.65733 .06823 m
.97619 .06825 L
s
0 0 0 r
2.5 Mabswid
.97619 .06825 Mdot
.039 .916 .04 r
.5 Mabswid
.65724 .06717 m
.97619 .06719 L
s
0 0 0 r
2.5 Mabswid
.97619 .06719 Mdot
.039 .916 .04 r
.5 Mabswid
.65714 .06611 m
.97619 .06614 L
s
0 0 0 r
2.5 Mabswid
.97619 .06614 Mdot
.039 .916 .04 r
.5 Mabswid
.65704 .06505 m
.97619 .06509 L
s
0 0 0 r
2.5 Mabswid
.97619 .06509 Mdot
.039 .916 .04 r
.5 Mabswid
.65693 .06399 m
.97619 .06403 L
s
0 0 0 r
2.5 Mabswid
.97619 .06403 Mdot
.039 .916 .04 r
.5 Mabswid
.65683 .06293 m
.97619 .06298 L
s
0 0 0 r
2.5 Mabswid
.97619 .06298 Mdot
.039 .916 .04 r
.5 Mabswid
.65672 .06188 m
.97619 .06193 L
s
0 0 0 r
2.5 Mabswid
.97619 .06193 Mdot
.039 .916 .04 r
.5 Mabswid
.6566 .06082 m
.97619 .06088 L
s
0 0 0 r
2.5 Mabswid
.97619 .06088 Mdot
.039 .916 .04 r
.5 Mabswid
.65648 .05976 m
.97619 .05982 L
s
0 0 0 r
2.5 Mabswid
.97619 .05982 Mdot
.039 .916 .04 r
.5 Mabswid
.65636 .0587 m
.97619 .05877 L
s
0 0 0 r
2.5 Mabswid
.97619 .05877 Mdot
.039 .916 .04 r
.5 Mabswid
.65624 .05764 m
.97619 .05772 L
s
0 0 0 r
2.5 Mabswid
.97619 .05772 Mdot
.039 .916 .04 r
.5 Mabswid
.65612 .05659 m
.97619 .05667 L
s
0 0 0 r
2.5 Mabswid
.97619 .05667 Mdot
.039 .916 .04 r
.5 Mabswid
.65599 .05553 m
.97619 .05562 L
s
0 0 0 r
2.5 Mabswid
.97619 .05562 Mdot
.039 .916 .04 r
.5 Mabswid
.65585 .05447 m
.97619 .05458 L
s
0 0 0 r
2.5 Mabswid
.97619 .05458 Mdot
.039 .916 .04 r
.5 Mabswid
.65572 .05341 m
.97619 .05353 L
s
0 0 0 r
2.5 Mabswid
.97619 .05353 Mdot
.039 .916 .04 r
.5 Mabswid
.65558 .05236 m
.97619 .05248 L
s
0 0 0 r
2.5 Mabswid
.97619 .05248 Mdot
.039 .916 .04 r
.5 Mabswid
.65544 .0513 m
.97619 .05143 L
s
0 0 0 r
2.5 Mabswid
.97619 .05143 Mdot
.039 .916 .04 r
.5 Mabswid
.65529 .05024 m
.97619 .05039 L
s
0 0 0 r
2.5 Mabswid
.97619 .05039 Mdot
.039 .916 .04 r
.5 Mabswid
.65514 .04918 m
.97619 .04934 L
s
0 0 0 r
2.5 Mabswid
.97619 .04934 Mdot
.039 .916 .04 r
.5 Mabswid
.65499 .04813 m
.97619 .0483 L
s
0 0 0 r
2.5 Mabswid
.97619 .0483 Mdot
.039 .916 .04 r
.5 Mabswid
.65484 .04707 m
.97619 .04725 L
s
0 0 0 r
2.5 Mabswid
.97619 .04725 Mdot
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 57.5625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000>B000`400?l00000o`00003ooooooolQ
ooooo`00Zoooool>o`0005gooooo00?o0000ooooooooool01oooool00:_ooooo3_l0001Mooooo`03
o`000?oooooooooo00Oooooo002[ooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`07ooooo`00Zoooool00ol0003oOgmoogmoO`0:ogmoO`;o0000G?oo
ool00ol0003oooooooooo`07ooooo`00Zoooool?o`0005cooooo00?o0000ooooooooool01oooool0
0:[ooooo0_l0000<ogmoO`;o0000G?ooool00ol0003oooooooooo`07ooooo`00Z_ooool2o`0000co
Ogmo0_l0001Looooo`03o`000?oooooooooo00Oooooo002Zooooo`;o00003?moOgl2o`0005cooooo
00?o0000ooooooooool01oooool00:[ooooo3ol000000omoOgoo0000ooooo`1Jooooo`03o`000?oo
oooooooo00Oooooo002Zooooo`;o00003?moOgl00ol0003oOgmoo`00001Kooooo`03o`000?oooooo
oooo00Oooooo002Zooooo`;o00003?moOgl00ol0003oOgmoo`00001Kooooo`03o`000?oooooooooo
00Oooooo002Zooooo`;o00003?moOgl00ol0003oOgmoo`00001Kooooo`03o`000?oooooooooo00Oo
oooo002Zooooo`;o00001omoOgl7o`WZ2P03o`000?l9jP[o2NX:05So2NX:0_l00009ooooo`00Y?oo
ool5o`WZ2P03o`000?l9jP[o2NX:00ko2NX:00?o0000o`WZ2_l9jPX0F?l9jPX2o`0000Wooooo002I
oooooa3o2NX:00?o0000o`WZ2_l9jPX03_l9jPX00ol0003o2NX:o`WZ2P1Ho`WZ2P;o00002Oooool0
08gooooo7?l9jPX00ol0003o2NX:o`WZ2P0>o`WZ2P03o`000?l9jP[o2NX:05So2NX:0_l00009oooo
o`00POoooolXo`WZ2P03o`000?l9jP[o2NX:00ko2NX:00?o0000o`WZ2_l9jPX0F?l9jPX2o`0000Wo
oooo001foooooc?o2NX:00?o0000o`WZ2_l9jPX0JOl9jPX2o`0000Wooooo001Zooooocoo2NX:00?o
0000o`WZ2_l9jPX0JOl9jPX2o`0000Wooooo001Ooooood[o2NX:00?o0000o`WZ2_l9jPX03ol9jPX0
0ol0003o2NX:o`WZ2P1Go`WZ2P;o00002Oooool005?oooooE_l9jPX00ol0003o2NX:o`WZ2P0?o`WZ
2P03o`000?l9jP[o2NX:05Oo2NX:0_l00009ooooo`00B?oooomQo`WZ2P03o`000?l9jP[o2NX:00oo
2NX:00?o0000o`WZ2_l9jPX0Eol9jPX2o`0000Wooooo000looooofgo2NX:00?o0000o`WZ2_l9jPX0
3ol9jPX00ol0003o2NX:o`WZ2P1Go`WZ2P;o00002Oooool0033oooooNOl9jPX00ol0003o2NX:o`WZ
2P0?o`WZ2P03o`000?l9jP[o2NX:05Oo2NX:0_l00009ooooo`009Ooooon4o`WZ2P03o`000?l9jP[o
2NX:00oo2NX:00?o0000o`WZ2_l9jPX0Eol9jPX2o`0000Wooooo000Ioooooi3o2NX:00?o0000o`WZ
2_l9jPX03ol9jPX00ol0003o2NX:o`WZ2P1Go`WZ2P;o00002Oooool000koooooVol9jPX00ol0003o
2NX:o`WZ2P0?o`WZ2P03o`000?l9jP[o2NX:05Oo2NX:0_l00009ooooo`002?oooonQo`WZ2P03o`00
0?l9jP[o2NX:00oo2NX:00?o0000o`WZ2_l9jPX0Eol9jPX2o`0000Wooooo000?oooooi[o2NX:00?o
0000o`WZ2_l9jPX03ol9jPX00ol0003o2NX:o`WZ2P1Go`WZ2P;o00002Oooool001[oooooSol9jPX0
0ol0003o2NX:o`WZ2P0?o`WZ2P03o`000?l9jP[o2NX:05Oo2NX:0_l00009ooooo`009_oooon3o`WZ
2P03o`000?l9jP[o2NX:00oo2NX:00?o0000o`WZ2_l9jPX0Eol9jPX2o`0000Wooooo000booooogOo
2NX:00?o0000o`WZ2_l9jPX03ol9jPX00ol0003o2NX:o`WZ2P1Go`WZ2P;o00002Oooool003gooooo
K?l9jPX00ol0003o2NX:o`WZ2P0?o`WZ2P03o`000?l9jP[o2NX:05Oo2NX:0_l00009ooooo`00BOoo
oomPo`WZ2P03o`000?l9jP[o2NX:00oo2NX:00?o0000o`WZ2_l9jPX0Eol9jPX2o`0000Wooooo001D
oooooeGo2NX:00?o0000o`WZ2_l9jPX03ol9jPX00ol0003o2NX:o`WZ2P1Go`WZ2P;o00002Oooool0
063oooooBOl9jPX00ol0003o2NX:o`WZ2P0?o`WZ2P03o`000?l9jP[o2NX:05Oo2NX:0_l00009oooo
o`00Jooooolno`WZ2P03o`000?l9jP[o2NX:06Wo2NX:0_l00009ooooo`00Mooooolbo`WZ2P03o`00
0?l9jP[o2NX:06Wo2NX:0_l00009ooooo`00PooooolVo`WZ2P03o`000?l9jP[o2NX:06Wo2NX:0_l0
0009ooooo`00S_oooolKo`WZ2P03o`000?l9jP[o2NX:06Wo2NX:0_l00009ooooo`00V_ooool?o`WZ
2P03o`000?l9jP[o2NX:00ko2NX:00?o0000o`WZ2_l9jPX0F?l9jPX2o`0000Wooooo002Uooooo`Co
2NX:00?o0000o`WZ2_l9jPX03_l9jPX00ol0003o2NX:o`WZ2P1Ho`WZ2P;o00002Oooool00:Wooooo
0ol00008ogmoO`Ko2NX:00?o0000o`WZ2_l9jPX0F?l9jPX2o`0000Wooooo002Zooooo`;o00003?mo
Ogl01?l0003oOgmoo`000?l0001Iooooo`;o00002Oooool00:[ooooo0_l0000<ogmoO`03o`000?mo
Ogoo000005_ooooo00?o0000ooooooooool01oooool00:[ooooo0_l0000<ogmoO`03o`000?moOgoo
000005_ooooo00?o0000ooooooooool01oooool00:[ooooo3ol000000omoOgoo0000ooooo`1Joooo
o`03o`000?oooooooooo00Oooooo002Zooooo`;o00003?moOgl00ol0003oOgmoo`00001Kooooo`03
o`000?oooooooooo00Oooooo002Zooooo`;o00003?moOgl2o`0005cooooo00?o0000ooooooooool0
1oooool00:[ooooo0_l0000<ogmoO`;o0000G?ooool00ol0003oooooooooo`07ooooo`00Zoooool0
0ol0003oOgmoogmoO`0:ogmoO`;o0000G?ooool00ol0003oooooooooo`07ooooo`00Zoooool?o`00
05cooooo00?o0000ooooooooool01oooool00:_ooooo00?o0000ogmoOomoOgl02_moOgl2o`0005co
oooo00?o0000ooooooooool01oooool00:_ooooo3_l0001Mooooo`03o`000?oooooooooo00Oooooo
002[ooooo`ko0000GOooool00ol0003oooooooooo`07ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {56.5625, 0}} -> {-94.9167, -15.7501, \
0.556911, 0.556911}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.595238 0.00634921 0.1 0.00634921 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.62414 .00476 m
.64242 .00476 L
.6516 .03651 L
.60743 .03651 L
.62414 .00476 L
F
.60743 .03651 m
.6516 .03651 L
.65696 .06825 L
.5982 .06825 L
.60743 .03651 L
F
.5982 .06825 m
.65696 .06825 L
.65873 .1 L
.59524 .1 L
.5982 .06825 L
F
.59524 .1 m
.65873 .1 L
.65696 .13175 L
.5982 .13175 L
.59524 .1 L
F
.5982 .13175 m
.65696 .13175 L
.6516 .16349 L
.60743 .16349 L
.5982 .13175 L
F
.60743 .16349 m
.6516 .16349 L
.64242 .19524 L
.62414 .19524 L
.60743 .16349 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.62414 .00476 m
.60743 .03651 L
.5982 .06825 L
.59524 .1 L
.5982 .13175 L
.60743 .16349 L
.62414 .19524 L
.64242 .19524 L
.6516 .16349 L
.65696 .13175 L
.65873 .1 L
.65696 .06825 L
.6516 .03651 L
.64242 .00476 L
.62414 .00476 L
s
.5 g
.62414 .1 m
.64242 .1 L
.6516 .1 L
.60743 .1 L
.62414 .1 L
F
.60743 .1 m
.6516 .1 L
.65696 .1 L
.5982 .1 L
.60743 .1 L
F
.5982 .1 m
.65696 .1 L
.65873 .1 L
.59524 .1 L
.5982 .1 L
F
.59524 .1 m
.65873 .1 L
.65696 .1 L
.5982 .1 L
.59524 .1 L
F
.5982 .1 m
.65696 .1 L
.6516 .1 L
.60743 .1 L
.5982 .1 L
F
.60743 .1 m
.6516 .1 L
.64242 .1 L
.62414 .1 L
.60743 .1 L
F
0 g
.62414 .1 m
.60743 .1 L
.5982 .1 L
.59524 .1 L
.5982 .1 L
.60743 .1 L
.62414 .1 L
.64242 .1 L
.6516 .1 L
.65696 .1 L
.65873 .1 L
.65696 .1 L
.6516 .1 L
.64242 .1 L
.62414 .1 L
s
.62414 .19524 m
.64242 .19524 L
.64242 .19199 L
.62414 .19199 L
.62414 .19524 L
s
.62414 .19199 m
.64242 .19199 L
.64242 .18248 L
.62414 .18248 L
.62414 .19199 L
s
.62414 .18248 m
.64242 .18248 L
.64242 .16734 L
.62414 .16734 L
.62414 .18248 L
s
.62414 .16734 m
.64242 .16734 L
.64242 .14762 L
.62414 .14762 L
.62414 .16734 L
s
.62414 .14762 m
.64242 .14762 L
.64242 .12465 L
.62414 .12465 L
.62414 .14762 L
s
.62414 .12465 m
.64242 .12465 L
.64242 .1 L
.62414 .1 L
.62414 .12465 L
s
.62414 .1 m
.64242 .1 L
.64242 .07535 L
.62414 .07535 L
.62414 .1 L
s
.62414 .07535 m
.64242 .07535 L
.64242 .05238 L
.62414 .05238 L
.62414 .07535 L
s
.62414 .05238 m
.64242 .05238 L
.64242 .03266 L
.62414 .03266 L
.62414 .05238 L
s
.62414 .03266 m
.64242 .03266 L
.64242 .01752 L
.62414 .01752 L
.62414 .03266 L
s
.62414 .01752 m
.64242 .01752 L
.64242 .00801 L
.62414 .00801 L
.62414 .01752 L
s
.62414 .00801 m
.64242 .00801 L
.64242 .00476 L
.62414 .00476 L
.62414 .00801 L
s
.62414 .00476 m
.64242 .00476 L
.64242 .00801 L
.62414 .00801 L
.62414 .00476 L
s
.62414 .00801 m
.64242 .00801 L
.64242 .01752 L
.62414 .01752 L
.62414 .00801 L
s
.62414 .01752 m
.64242 .01752 L
.64242 .03266 L
.62414 .03266 L
.62414 .01752 L
s
.62414 .03266 m
.64242 .03266 L
.64242 .05238 L
.62414 .05238 L
.62414 .03266 L
s
.62414 .05238 m
.64242 .05238 L
.64242 .07535 L
.62414 .07535 L
.62414 .05238 L
s
.62414 .07535 m
.64242 .07535 L
.64242 .1 L
.62414 .1 L
.62414 .07535 L
s
.62414 .1 m
.64242 .1 L
.64242 .12465 L
.62414 .12465 L
.62414 .1 L
s
.62414 .12465 m
.64242 .12465 L
.64242 .14762 L
.62414 .14762 L
.62414 .12465 L
s
.62414 .14762 m
.64242 .14762 L
.64242 .16734 L
.62414 .16734 L
.62414 .14762 L
s
.62414 .16734 m
.64242 .16734 L
.64242 .18248 L
.62414 .18248 L
.62414 .16734 L
s
.62414 .18248 m
.64242 .18248 L
.64242 .19199 L
.62414 .19199 L
.62414 .18248 L
s
.62414 .19199 m
.64242 .19199 L
.64242 .19524 L
.62414 .19524 L
.62414 .19199 L
s
.97619 .00476 m
.97619 .03651 L
.97619 .06825 L
.97619 .1 L
.97619 .13175 L
.97619 .16349 L
.97619 .19524 L
.97619 .19524 L
.97619 .16349 L
.97619 .13175 L
.97619 .1 L
.97619 .06825 L
.97619 .03651 L
.97619 .00476 L
.97619 .00476 L
s
.97619 .1 m
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
s
.97619 .19524 m
.97619 .19199 L
.97619 .18248 L
.97619 .16734 L
.97619 .14762 L
.97619 .12465 L
.97619 .1 L
.97619 .07535 L
.97619 .05238 L
.97619 .03266 L
.97619 .01752 L
.97619 .00801 L
.97619 .00476 L
.97619 .00801 L
.97619 .01752 L
.97619 .03266 L
.97619 .05238 L
.97619 .07535 L
.97619 .1 L
.97619 .12465 L
.97619 .14762 L
.97619 .16734 L
.97619 .18248 L
.97619 .19199 L
.97619 .19524 L
s
.039 .916 .04 r
.02381 .1 m
.6029 .15066 L
s
0 0 0 r
2.5 Mabswid
.6029 .15066 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60258 .14962 L
s
0 0 0 r
2.5 Mabswid
.60258 .14962 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60227 .14857 L
s
0 0 0 r
2.5 Mabswid
.60227 .14857 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60196 .14753 L
s
0 0 0 r
2.5 Mabswid
.60196 .14753 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60167 .14649 L
s
0 0 0 r
2.5 Mabswid
.60167 .14649 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60138 .14546 L
s
0 0 0 r
2.5 Mabswid
.60138 .14546 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.6011 .14442 L
s
0 0 0 r
2.5 Mabswid
.6011 .14442 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60082 .14339 L
s
0 0 0 r
2.5 Mabswid
.60082 .14339 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60055 .14235 L
s
0 0 0 r
2.5 Mabswid
.60055 .14235 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.6003 .14132 L
s
0 0 0 r
2.5 Mabswid
.6003 .14132 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60004 .14029 L
s
0 0 0 r
2.5 Mabswid
.60004 .14029 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5998 .13927 L
s
0 0 0 r
2.5 Mabswid
.5998 .13927 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59956 .13824 L
s
0 0 0 r
2.5 Mabswid
.59956 .13824 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59933 .13722 L
s
0 0 0 r
2.5 Mabswid
.59933 .13722 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5991 .13619 L
s
0 0 0 r
2.5 Mabswid
.5991 .13619 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59889 .13517 L
s
0 0 0 r
2.5 Mabswid
.59889 .13517 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59868 .13415 L
s
0 0 0 r
2.5 Mabswid
.59868 .13415 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59847 .13313 L
s
0 0 0 r
2.5 Mabswid
.59847 .13313 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59827 .13212 L
s
0 0 0 r
2.5 Mabswid
.59827 .13212 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59808 .1311 L
s
0 0 0 r
2.5 Mabswid
.59808 .1311 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5979 .13009 L
s
0 0 0 r
2.5 Mabswid
.5979 .13009 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59772 .12907 L
s
0 0 0 r
2.5 Mabswid
.59772 .12907 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59755 .12806 L
s
0 0 0 r
2.5 Mabswid
.59755 .12806 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59739 .12705 L
s
0 0 0 r
2.5 Mabswid
.59739 .12705 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59723 .12604 L
s
0 0 0 r
2.5 Mabswid
.59723 .12604 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59708 .12503 L
s
0 0 0 r
2.5 Mabswid
.59708 .12503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59693 .12402 L
s
0 0 0 r
2.5 Mabswid
.59693 .12402 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59679 .12301 L
s
0 0 0 r
2.5 Mabswid
.59679 .12301 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59666 .12201 L
s
0 0 0 r
2.5 Mabswid
.59666 .12201 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59653 .121 L
s
0 0 0 r
2.5 Mabswid
.59653 .121 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59641 .12 L
s
0 0 0 r
2.5 Mabswid
.59641 .12 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59629 .11899 L
s
0 0 0 r
2.5 Mabswid
.59629 .11899 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59618 .11799 L
s
0 0 0 r
2.5 Mabswid
.59618 .11799 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59608 .11698 L
s
0 0 0 r
2.5 Mabswid
.59608 .11698 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59599 .11598 L
s
0 0 0 r
2.5 Mabswid
.59599 .11598 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59589 .11498 L
s
0 0 0 r
2.5 Mabswid
.59589 .11498 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59581 .11398 L
s
0 0 0 r
2.5 Mabswid
.59581 .11398 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59573 .11298 L
s
0 0 0 r
2.5 Mabswid
.59573 .11298 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59566 .11198 L
s
0 0 0 r
2.5 Mabswid
.59566 .11198 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59559 .11098 L
s
0 0 0 r
2.5 Mabswid
.59559 .11098 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59553 .10998 L
s
0 0 0 r
2.5 Mabswid
.59553 .10998 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59547 .10898 L
s
0 0 0 r
2.5 Mabswid
.59547 .10898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59542 .10798 L
s
0 0 0 r
2.5 Mabswid
.59542 .10798 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59538 .10698 L
s
0 0 0 r
2.5 Mabswid
.59538 .10698 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59534 .10599 L
s
0 0 0 r
2.5 Mabswid
.59534 .10599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59531 .10499 L
s
0 0 0 r
2.5 Mabswid
.59531 .10499 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59528 .10399 L
s
0 0 0 r
2.5 Mabswid
.59528 .10399 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59526 .10299 L
s
0 0 0 r
2.5 Mabswid
.59526 .10299 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59525 .10199 L
s
0 0 0 r
2.5 Mabswid
.59525 .10199 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .101 L
s
0 0 0 r
2.5 Mabswid
.59524 .101 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .1 L
s
0 0 0 r
2.5 Mabswid
.59524 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .099 L
s
0 0 0 r
2.5 Mabswid
.59524 .099 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59525 .09801 L
s
0 0 0 r
2.5 Mabswid
.59525 .09801 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59526 .09701 L
s
0 0 0 r
2.5 Mabswid
.59526 .09701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59528 .09601 L
s
0 0 0 r
2.5 Mabswid
.59528 .09601 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59531 .09501 L
s
0 0 0 r
2.5 Mabswid
.59531 .09501 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59534 .09401 L
s
0 0 0 r
2.5 Mabswid
.59534 .09401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59538 .09302 L
s
0 0 0 r
2.5 Mabswid
.59538 .09302 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59542 .09202 L
s
0 0 0 r
2.5 Mabswid
.59542 .09202 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59547 .09102 L
s
0 0 0 r
2.5 Mabswid
.59547 .09102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59553 .09002 L
s
0 0 0 r
2.5 Mabswid
.59553 .09002 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59559 .08902 L
s
0 0 0 r
2.5 Mabswid
.59559 .08902 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59566 .08802 L
s
0 0 0 r
2.5 Mabswid
.59566 .08802 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59573 .08702 L
s
0 0 0 r
2.5 Mabswid
.59573 .08702 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59581 .08602 L
s
0 0 0 r
2.5 Mabswid
.59581 .08602 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59589 .08502 L
s
0 0 0 r
2.5 Mabswid
.59589 .08502 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59599 .08402 L
s
0 0 0 r
2.5 Mabswid
.59599 .08402 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59608 .08302 L
s
0 0 0 r
2.5 Mabswid
.59608 .08302 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59618 .08201 L
s
0 0 0 r
2.5 Mabswid
.59618 .08201 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59629 .08101 L
s
0 0 0 r
2.5 Mabswid
.59629 .08101 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59641 .08 L
s
0 0 0 r
2.5 Mabswid
.59641 .08 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59653 .079 L
s
0 0 0 r
2.5 Mabswid
.59653 .079 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59666 .07799 L
s
0 0 0 r
2.5 Mabswid
.59666 .07799 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59679 .07699 L
s
0 0 0 r
2.5 Mabswid
.59679 .07699 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59693 .07598 L
s
0 0 0 r
2.5 Mabswid
.59693 .07598 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59708 .07497 L
s
0 0 0 r
2.5 Mabswid
.59708 .07497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59723 .07396 L
s
0 0 0 r
2.5 Mabswid
.59723 .07396 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59739 .07295 L
s
0 0 0 r
2.5 Mabswid
.59739 .07295 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59755 .07194 L
s
0 0 0 r
2.5 Mabswid
.59755 .07194 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59772 .07093 L
s
0 0 0 r
2.5 Mabswid
.59772 .07093 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5979 .06991 L
s
0 0 0 r
2.5 Mabswid
.5979 .06991 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59808 .0689 L
s
0 0 0 r
2.5 Mabswid
.59808 .0689 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59827 .06788 L
s
0 0 0 r
2.5 Mabswid
.59827 .06788 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59847 .06687 L
s
0 0 0 r
2.5 Mabswid
.59847 .06687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59868 .06585 L
s
0 0 0 r
2.5 Mabswid
.59868 .06585 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59889 .06483 L
s
0 0 0 r
2.5 Mabswid
.59889 .06483 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5991 .06381 L
s
0 0 0 r
2.5 Mabswid
.5991 .06381 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59933 .06278 L
s
0 0 0 r
2.5 Mabswid
.59933 .06278 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59956 .06176 L
s
0 0 0 r
2.5 Mabswid
.59956 .06176 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5998 .06073 L
s
0 0 0 r
2.5 Mabswid
.5998 .06073 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60004 .05971 L
s
0 0 0 r
2.5 Mabswid
.60004 .05971 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.6003 .05868 L
s
0 0 0 r
2.5 Mabswid
.6003 .05868 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60055 .05765 L
s
0 0 0 r
2.5 Mabswid
.60055 .05765 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60082 .05661 L
s
0 0 0 r
2.5 Mabswid
.60082 .05661 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.6011 .05558 L
s
0 0 0 r
2.5 Mabswid
.6011 .05558 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60138 .05454 L
s
0 0 0 r
2.5 Mabswid
.60138 .05454 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60167 .05351 L
s
0 0 0 r
2.5 Mabswid
.60167 .05351 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60196 .05247 L
s
0 0 0 r
2.5 Mabswid
.60196 .05247 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60227 .05143 L
s
0 0 0 r
2.5 Mabswid
.60227 .05143 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60258 .05038 L
s
0 0 0 r
2.5 Mabswid
.60258 .05038 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.6029 .04934 L
s
0 0 0 r
2.5 Mabswid
.6029 .04934 Mdot
.039 .916 .04 r
.5 Mabswid
.6029 .15066 m
.65462 .14831 L
s
0 0 0 r
2.5 Mabswid
.65462 .14831 Mdot
.039 .916 .04 r
.5 Mabswid
.60258 .14962 m
.6548 .1473 L
s
0 0 0 r
2.5 Mabswid
.6548 .1473 Mdot
.039 .916 .04 r
.5 Mabswid
.60227 .14857 m
.65496 .1463 L
s
0 0 0 r
2.5 Mabswid
.65496 .1463 Mdot
.039 .916 .04 r
.5 Mabswid
.60196 .14753 m
.65512 .1453 L
s
0 0 0 r
2.5 Mabswid
.65512 .1453 Mdot
.039 .916 .04 r
.5 Mabswid
.60167 .14649 m
.65528 .1443 L
s
0 0 0 r
2.5 Mabswid
.65528 .1443 Mdot
.039 .916 .04 r
.5 Mabswid
.60138 .14546 m
.65544 .14331 L
s
0 0 0 r
2.5 Mabswid
.65544 .14331 Mdot
.039 .916 .04 r
.5 Mabswid
.6011 .14442 m
.65559 .14231 L
s
0 0 0 r
2.5 Mabswid
.65559 .14231 Mdot
.039 .916 .04 r
.5 Mabswid
.60082 .14339 m
.65573 .14132 L
s
0 0 0 r
2.5 Mabswid
.65573 .14132 Mdot
.039 .916 .04 r
.5 Mabswid
.60055 .14235 m
.65587 .14033 L
s
0 0 0 r
2.5 Mabswid
.65587 .14033 Mdot
.039 .916 .04 r
.5 Mabswid
.6003 .14132 m
.65601 .13935 L
s
0 0 0 r
2.5 Mabswid
.65601 .13935 Mdot
.039 .916 .04 r
.5 Mabswid
.60004 .14029 m
.65615 .13836 L
s
0 0 0 r
2.5 Mabswid
.65615 .13836 Mdot
.039 .916 .04 r
.5 Mabswid
.5998 .13927 m
.65628 .13738 L
s
0 0 0 r
2.5 Mabswid
.65628 .13738 Mdot
.039 .916 .04 r
.5 Mabswid
.59956 .13824 m
.65641 .1364 L
s
0 0 0 r
2.5 Mabswid
.65641 .1364 Mdot
.039 .916 .04 r
.5 Mabswid
.59933 .13722 m
.65653 .13542 L
s
0 0 0 r
2.5 Mabswid
.65653 .13542 Mdot
.039 .916 .04 r
.5 Mabswid
.5991 .13619 m
.65665 .13445 L
s
0 0 0 r
2.5 Mabswid
.65665 .13445 Mdot
.039 .916 .04 r
.5 Mabswid
.59889 .13517 m
.65677 .13347 L
s
0 0 0 r
2.5 Mabswid
.65677 .13347 Mdot
.039 .916 .04 r
.5 Mabswid
.59868 .13415 m
.65688 .1325 L
s
0 0 0 r
2.5 Mabswid
.65688 .1325 Mdot
.039 .916 .04 r
.5 Mabswid
.59847 .13313 m
.65699 .13153 L
s
0 0 0 r
2.5 Mabswid
.65699 .13153 Mdot
.039 .916 .04 r
.5 Mabswid
.59827 .13212 m
.65709 .13056 L
s
0 0 0 r
2.5 Mabswid
.65709 .13056 Mdot
.039 .916 .04 r
.5 Mabswid
.59808 .1311 m
.6572 .12959 L
s
0 0 0 r
2.5 Mabswid
.6572 .12959 Mdot
.039 .916 .04 r
.5 Mabswid
.5979 .13009 m
.6573 .12862 L
s
0 0 0 r
2.5 Mabswid
.6573 .12862 Mdot
.039 .916 .04 r
.5 Mabswid
.59772 .12907 m
.65739 .12766 L
s
0 0 0 r
2.5 Mabswid
.65739 .12766 Mdot
.039 .916 .04 r
.5 Mabswid
.59755 .12806 m
.65748 .12669 L
s
0 0 0 r
2.5 Mabswid
.65748 .12669 Mdot
.039 .916 .04 r
.5 Mabswid
.59739 .12705 m
.65757 .12573 L
s
0 0 0 r
2.5 Mabswid
.65757 .12573 Mdot
.039 .916 .04 r
.5 Mabswid
.59723 .12604 m
.65766 .12476 L
s
0 0 0 r
2.5 Mabswid
.65766 .12476 Mdot
.039 .916 .04 r
.5 Mabswid
.59708 .12503 m
.65774 .1238 L
s
0 0 0 r
2.5 Mabswid
.65774 .1238 Mdot
.039 .916 .04 r
.5 Mabswid
.59693 .12402 m
.65782 .12284 L
s
0 0 0 r
2.5 Mabswid
.65782 .12284 Mdot
.039 .916 .04 r
.5 Mabswid
.59679 .12301 m
.65789 .12188 L
s
0 0 0 r
2.5 Mabswid
.65789 .12188 Mdot
.039 .916 .04 r
.5 Mabswid
.59666 .12201 m
.65796 .12093 L
s
0 0 0 r
2.5 Mabswid
.65796 .12093 Mdot
.039 .916 .04 r
.5 Mabswid
.59653 .121 m
.65803 .11997 L
s
0 0 0 r
2.5 Mabswid
.65803 .11997 Mdot
.039 .916 .04 r
.5 Mabswid
.59641 .12 m
.6581 .11901 L
s
0 0 0 r
2.5 Mabswid
.6581 .11901 Mdot
.039 .916 .04 r
.5 Mabswid
.59629 .11899 m
.65816 .11806 L
s
0 0 0 r
2.5 Mabswid
.65816 .11806 Mdot
.039 .916 .04 r
.5 Mabswid
.59618 .11799 m
.65822 .1171 L
s
0 0 0 r
2.5 Mabswid
.65822 .1171 Mdot
.039 .916 .04 r
.5 Mabswid
.59608 .11698 m
.65827 .11615 L
s
0 0 0 r
2.5 Mabswid
.65827 .11615 Mdot
.039 .916 .04 r
.5 Mabswid
.59599 .11598 m
.65833 .1152 L
s
0 0 0 r
2.5 Mabswid
.65833 .1152 Mdot
.039 .916 .04 r
.5 Mabswid
.59589 .11498 m
.65838 .11424 L
s
0 0 0 r
2.5 Mabswid
.65838 .11424 Mdot
.039 .916 .04 r
.5 Mabswid
.59581 .11398 m
.65842 .11329 L
s
0 0 0 r
2.5 Mabswid
.65842 .11329 Mdot
.039 .916 .04 r
.5 Mabswid
.59573 .11298 m
.65846 .11234 L
s
0 0 0 r
2.5 Mabswid
.65846 .11234 Mdot
.039 .916 .04 r
.5 Mabswid
.59566 .11198 m
.6585 .11139 L
s
0 0 0 r
2.5 Mabswid
.6585 .11139 Mdot
.039 .916 .04 r
.5 Mabswid
.59559 .11098 m
.65854 .11044 L
s
0 0 0 r
2.5 Mabswid
.65854 .11044 Mdot
.039 .916 .04 r
.5 Mabswid
.59553 .10998 m
.65857 .10949 L
s
0 0 0 r
2.5 Mabswid
.65857 .10949 Mdot
.039 .916 .04 r
.5 Mabswid
.59547 .10898 m
.6586 .10854 L
s
0 0 0 r
2.5 Mabswid
.6586 .10854 Mdot
.039 .916 .04 r
.5 Mabswid
.59542 .10798 m
.65863 .10759 L
s
0 0 0 r
2.5 Mabswid
.65863 .10759 Mdot
.039 .916 .04 r
.5 Mabswid
.59538 .10698 m
.65865 .10664 L
s
0 0 0 r
2.5 Mabswid
.65865 .10664 Mdot
.039 .916 .04 r
.5 Mabswid
.59534 .10599 m
.65867 .10569 L
s
0 0 0 r
2.5 Mabswid
.65867 .10569 Mdot
.039 .916 .04 r
.5 Mabswid
.59531 .10499 m
.65869 .10474 L
s
0 0 0 r
2.5 Mabswid
.65869 .10474 Mdot
.039 .916 .04 r
.5 Mabswid
.59528 .10399 m
.65871 .10379 L
s
0 0 0 r
2.5 Mabswid
.65871 .10379 Mdot
.039 .916 .04 r
.5 Mabswid
.59526 .10299 m
.65872 .10284 L
s
0 0 0 r
2.5 Mabswid
.65872 .10284 Mdot
.039 .916 .04 r
.5 Mabswid
.59525 .10199 m
.65872 .1019 L
s
0 0 0 r
2.5 Mabswid
.65872 .1019 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .101 m
.65873 .10095 L
s
0 0 0 r
2.5 Mabswid
.65873 .10095 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .1 m
.65873 .1 L
s
0 0 0 r
2.5 Mabswid
.65873 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .099 m
.65873 .09905 L
s
0 0 0 r
2.5 Mabswid
.65873 .09905 Mdot
.039 .916 .04 r
.5 Mabswid
.59525 .09801 m
.65872 .0981 L
s
0 0 0 r
2.5 Mabswid
.65872 .0981 Mdot
.039 .916 .04 r
.5 Mabswid
.59526 .09701 m
.65872 .09716 L
s
0 0 0 r
2.5 Mabswid
.65872 .09716 Mdot
.039 .916 .04 r
.5 Mabswid
.59528 .09601 m
.65871 .09621 L
s
0 0 0 r
2.5 Mabswid
.65871 .09621 Mdot
.039 .916 .04 r
.5 Mabswid
.59531 .09501 m
.65869 .09526 L
s
0 0 0 r
2.5 Mabswid
.65869 .09526 Mdot
.039 .916 .04 r
.5 Mabswid
.59534 .09401 m
.65867 .09431 L
s
0 0 0 r
2.5 Mabswid
.65867 .09431 Mdot
.039 .916 .04 r
.5 Mabswid
.59538 .09302 m
.65865 .09336 L
s
0 0 0 r
2.5 Mabswid
.65865 .09336 Mdot
.039 .916 .04 r
.5 Mabswid
.59542 .09202 m
.65863 .09241 L
s
0 0 0 r
2.5 Mabswid
.65863 .09241 Mdot
.039 .916 .04 r
.5 Mabswid
.59547 .09102 m
.6586 .09146 L
s
0 0 0 r
2.5 Mabswid
.6586 .09146 Mdot
.039 .916 .04 r
.5 Mabswid
.59553 .09002 m
.65857 .09051 L
s
0 0 0 r
2.5 Mabswid
.65857 .09051 Mdot
.039 .916 .04 r
.5 Mabswid
.59559 .08902 m
.65854 .08956 L
s
0 0 0 r
2.5 Mabswid
.65854 .08956 Mdot
.039 .916 .04 r
.5 Mabswid
.59566 .08802 m
.6585 .08861 L
s
0 0 0 r
2.5 Mabswid
.6585 .08861 Mdot
.039 .916 .04 r
.5 Mabswid
.59573 .08702 m
.65846 .08766 L
s
0 0 0 r
2.5 Mabswid
.65846 .08766 Mdot
.039 .916 .04 r
.5 Mabswid
.59581 .08602 m
.65842 .08671 L
s
0 0 0 r
2.5 Mabswid
.65842 .08671 Mdot
.039 .916 .04 r
.5 Mabswid
.59589 .08502 m
.65838 .08576 L
s
0 0 0 r
2.5 Mabswid
.65838 .08576 Mdot
.039 .916 .04 r
.5 Mabswid
.59599 .08402 m
.65833 .0848 L
s
0 0 0 r
2.5 Mabswid
.65833 .0848 Mdot
.039 .916 .04 r
.5 Mabswid
.59608 .08302 m
.65827 .08385 L
s
0 0 0 r
2.5 Mabswid
.65827 .08385 Mdot
.039 .916 .04 r
.5 Mabswid
.59618 .08201 m
.65822 .0829 L
s
0 0 0 r
2.5 Mabswid
.65822 .0829 Mdot
.039 .916 .04 r
.5 Mabswid
.59629 .08101 m
.65816 .08194 L
s
0 0 0 r
2.5 Mabswid
.65816 .08194 Mdot
.039 .916 .04 r
.5 Mabswid
.59641 .08 m
.6581 .08099 L
s
0 0 0 r
2.5 Mabswid
.6581 .08099 Mdot
.039 .916 .04 r
.5 Mabswid
.59653 .079 m
.65803 .08003 L
s
0 0 0 r
2.5 Mabswid
.65803 .08003 Mdot
.039 .916 .04 r
.5 Mabswid
.59666 .07799 m
.65796 .07907 L
s
0 0 0 r
2.5 Mabswid
.65796 .07907 Mdot
.039 .916 .04 r
.5 Mabswid
.59679 .07699 m
.65789 .07812 L
s
0 0 0 r
2.5 Mabswid
.65789 .07812 Mdot
.039 .916 .04 r
.5 Mabswid
.59693 .07598 m
.65782 .07716 L
s
0 0 0 r
2.5 Mabswid
.65782 .07716 Mdot
.039 .916 .04 r
.5 Mabswid
.59708 .07497 m
.65774 .0762 L
s
0 0 0 r
2.5 Mabswid
.65774 .0762 Mdot
.039 .916 .04 r
.5 Mabswid
.59723 .07396 m
.65766 .07524 L
s
0 0 0 r
2.5 Mabswid
.65766 .07524 Mdot
.039 .916 .04 r
.5 Mabswid
.59739 .07295 m
.65757 .07427 L
s
0 0 0 r
2.5 Mabswid
.65757 .07427 Mdot
.039 .916 .04 r
.5 Mabswid
.59755 .07194 m
.65748 .07331 L
s
0 0 0 r
2.5 Mabswid
.65748 .07331 Mdot
.039 .916 .04 r
.5 Mabswid
.59772 .07093 m
.65739 .07234 L
s
0 0 0 r
2.5 Mabswid
.65739 .07234 Mdot
.039 .916 .04 r
.5 Mabswid
.5979 .06991 m
.6573 .07138 L
s
0 0 0 r
2.5 Mabswid
.6573 .07138 Mdot
.039 .916 .04 r
.5 Mabswid
.59808 .0689 m
.6572 .07041 L
s
0 0 0 r
2.5 Mabswid
.6572 .07041 Mdot
.039 .916 .04 r
.5 Mabswid
.59827 .06788 m
.65709 .06944 L
s
0 0 0 r
2.5 Mabswid
.65709 .06944 Mdot
.039 .916 .04 r
.5 Mabswid
.59847 .06687 m
.65699 .06847 L
s
0 0 0 r
2.5 Mabswid
.65699 .06847 Mdot
.039 .916 .04 r
.5 Mabswid
.59868 .06585 m
.65688 .0675 L
s
0 0 0 r
2.5 Mabswid
.65688 .0675 Mdot
.039 .916 .04 r
.5 Mabswid
.59889 .06483 m
.65677 .06653 L
s
0 0 0 r
2.5 Mabswid
.65677 .06653 Mdot
.039 .916 .04 r
.5 Mabswid
.5991 .06381 m
.65665 .06555 L
s
0 0 0 r
2.5 Mabswid
.65665 .06555 Mdot
.039 .916 .04 r
.5 Mabswid
.59933 .06278 m
.65653 .06458 L
s
0 0 0 r
2.5 Mabswid
.65653 .06458 Mdot
.039 .916 .04 r
.5 Mabswid
.59956 .06176 m
.65641 .0636 L
s
0 0 0 r
2.5 Mabswid
.65641 .0636 Mdot
.039 .916 .04 r
.5 Mabswid
.5998 .06073 m
.65628 .06262 L
s
0 0 0 r
2.5 Mabswid
.65628 .06262 Mdot
.039 .916 .04 r
.5 Mabswid
.60004 .05971 m
.65615 .06164 L
s
0 0 0 r
2.5 Mabswid
.65615 .06164 Mdot
.039 .916 .04 r
.5 Mabswid
.6003 .05868 m
.65601 .06065 L
s
0 0 0 r
2.5 Mabswid
.65601 .06065 Mdot
.039 .916 .04 r
.5 Mabswid
.60055 .05765 m
.65587 .05967 L
s
0 0 0 r
2.5 Mabswid
.65587 .05967 Mdot
.039 .916 .04 r
.5 Mabswid
.60082 .05661 m
.65573 .05868 L
s
0 0 0 r
2.5 Mabswid
.65573 .05868 Mdot
.039 .916 .04 r
.5 Mabswid
.6011 .05558 m
.65559 .05769 L
s
0 0 0 r
2.5 Mabswid
.65559 .05769 Mdot
.039 .916 .04 r
.5 Mabswid
.60138 .05454 m
.65544 .05669 L
s
0 0 0 r
2.5 Mabswid
.65544 .05669 Mdot
.039 .916 .04 r
.5 Mabswid
.60167 .05351 m
.65528 .0557 L
s
0 0 0 r
2.5 Mabswid
.65528 .0557 Mdot
.039 .916 .04 r
.5 Mabswid
.60196 .05247 m
.65512 .0547 L
s
0 0 0 r
2.5 Mabswid
.65512 .0547 Mdot
.039 .916 .04 r
.5 Mabswid
.60227 .05143 m
.65496 .0537 L
s
0 0 0 r
2.5 Mabswid
.65496 .0537 Mdot
.039 .916 .04 r
.5 Mabswid
.60258 .05038 m
.6548 .0527 L
s
0 0 0 r
2.5 Mabswid
.6548 .0527 Mdot
.039 .916 .04 r
.5 Mabswid
.6029 .04934 m
.65462 .05169 L
s
0 0 0 r
2.5 Mabswid
.65462 .05169 Mdot
.039 .916 .04 r
.5 Mabswid
.65462 .14831 m
.97619 .09762 L
s
0 0 0 r
2.5 Mabswid
.97619 .09762 Mdot
.039 .916 .04 r
.5 Mabswid
.6548 .1473 m
.97619 .09789 L
s
0 0 0 r
2.5 Mabswid
.97619 .09789 Mdot
.039 .916 .04 r
.5 Mabswid
.65496 .1463 m
.97619 .09814 L
s
0 0 0 r
2.5 Mabswid
.97619 .09814 Mdot
.039 .916 .04 r
.5 Mabswid
.65512 .1453 m
.97619 .09838 L
s
0 0 0 r
2.5 Mabswid
.97619 .09838 Mdot
.039 .916 .04 r
.5 Mabswid
.65528 .1443 m
.97619 .0986 L
s
0 0 0 r
2.5 Mabswid
.97619 .0986 Mdot
.039 .916 .04 r
.5 Mabswid
.65544 .14331 m
.97619 .09881 L
s
0 0 0 r
2.5 Mabswid
.97619 .09881 Mdot
.039 .916 .04 r
.5 Mabswid
.65559 .14231 m
.97619 .099 L
s
0 0 0 r
2.5 Mabswid
.97619 .099 Mdot
.039 .916 .04 r
.5 Mabswid
.65573 .14132 m
.97619 .09919 L
s
0 0 0 r
2.5 Mabswid
.97619 .09919 Mdot
.039 .916 .04 r
.5 Mabswid
.65587 .14033 m
.97619 .09936 L
s
0 0 0 r
2.5 Mabswid
.97619 .09936 Mdot
.039 .916 .04 r
.5 Mabswid
.65601 .13935 m
.97619 .09951 L
s
0 0 0 r
2.5 Mabswid
.97619 .09951 Mdot
.039 .916 .04 r
.5 Mabswid
.65615 .13836 m
.97619 .09966 L
s
0 0 0 r
2.5 Mabswid
.97619 .09966 Mdot
.039 .916 .04 r
.5 Mabswid
.65628 .13738 m
.97619 .0998 L
s
0 0 0 r
2.5 Mabswid
.97619 .0998 Mdot
.039 .916 .04 r
.5 Mabswid
.65641 .1364 m
.97619 .09992 L
s
0 0 0 r
2.5 Mabswid
.97619 .09992 Mdot
.039 .916 .04 r
.5 Mabswid
.65653 .13542 m
.97619 .10004 L
s
0 0 0 r
2.5 Mabswid
.97619 .10004 Mdot
.039 .916 .04 r
.5 Mabswid
.65665 .13445 m
.97619 .10014 L
s
0 0 0 r
2.5 Mabswid
.97619 .10014 Mdot
.039 .916 .04 r
.5 Mabswid
.65677 .13347 m
.97619 .10024 L
s
0 0 0 r
2.5 Mabswid
.97619 .10024 Mdot
.039 .916 .04 r
.5 Mabswid
.65688 .1325 m
.97619 .10032 L
s
0 0 0 r
2.5 Mabswid
.97619 .10032 Mdot
.039 .916 .04 r
.5 Mabswid
.65699 .13153 m
.97619 .1004 L
s
0 0 0 r
2.5 Mabswid
.97619 .1004 Mdot
.039 .916 .04 r
.5 Mabswid
.65709 .13056 m
.97619 .10047 L
s
0 0 0 r
2.5 Mabswid
.97619 .10047 Mdot
.039 .916 .04 r
.5 Mabswid
.6572 .12959 m
.97619 .10053 L
s
0 0 0 r
2.5 Mabswid
.97619 .10053 Mdot
.039 .916 .04 r
.5 Mabswid
.6573 .12862 m
.97619 .10058 L
s
0 0 0 r
2.5 Mabswid
.97619 .10058 Mdot
.039 .916 .04 r
.5 Mabswid
.65739 .12766 m
.97619 .10063 L
s
0 0 0 r
2.5 Mabswid
.97619 .10063 Mdot
.039 .916 .04 r
.5 Mabswid
.65748 .12669 m
.97619 .10067 L
s
0 0 0 r
2.5 Mabswid
.97619 .10067 Mdot
.039 .916 .04 r
.5 Mabswid
.65757 .12573 m
.97619 .1007 L
s
0 0 0 r
2.5 Mabswid
.97619 .1007 Mdot
.039 .916 .04 r
.5 Mabswid
.65766 .12476 m
.97619 .10073 L
s
0 0 0 r
2.5 Mabswid
.97619 .10073 Mdot
.039 .916 .04 r
.5 Mabswid
.65774 .1238 m
.97619 .10075 L
s
0 0 0 r
2.5 Mabswid
.97619 .10075 Mdot
.039 .916 .04 r
.5 Mabswid
.65782 .12284 m
.97619 .10076 L
s
0 0 0 r
2.5 Mabswid
.97619 .10076 Mdot
.039 .916 .04 r
.5 Mabswid
.65789 .12188 m
.97619 .10077 L
s
0 0 0 r
2.5 Mabswid
.97619 .10077 Mdot
.039 .916 .04 r
.5 Mabswid
.65796 .12093 m
.97619 .10077 L
s
0 0 0 r
2.5 Mabswid
.97619 .10077 Mdot
.039 .916 .04 r
.5 Mabswid
.65803 .11997 m
.97619 .10077 L
s
0 0 0 r
2.5 Mabswid
.97619 .10077 Mdot
.039 .916 .04 r
.5 Mabswid
.6581 .11901 m
.97619 .10076 L
s
0 0 0 r
2.5 Mabswid
.97619 .10076 Mdot
.039 .916 .04 r
.5 Mabswid
.65816 .11806 m
.97619 .10075 L
s
0 0 0 r
2.5 Mabswid
.97619 .10075 Mdot
.039 .916 .04 r
.5 Mabswid
.65822 .1171 m
.97619 .10074 L
s
0 0 0 r
2.5 Mabswid
.97619 .10074 Mdot
.039 .916 .04 r
.5 Mabswid
.65827 .11615 m
.97619 .10072 L
s
0 0 0 r
2.5 Mabswid
.97619 .10072 Mdot
.039 .916 .04 r
.5 Mabswid
.65833 .1152 m
.97619 .1007 L
s
0 0 0 r
2.5 Mabswid
.97619 .1007 Mdot
.039 .916 .04 r
.5 Mabswid
.65838 .11424 m
.97619 .10067 L
s
0 0 0 r
2.5 Mabswid
.97619 .10067 Mdot
.039 .916 .04 r
.5 Mabswid
.65842 .11329 m
.97619 .10064 L
s
0 0 0 r
2.5 Mabswid
.97619 .10064 Mdot
.039 .916 .04 r
.5 Mabswid
.65846 .11234 m
.97619 .10061 L
s
0 0 0 r
2.5 Mabswid
.97619 .10061 Mdot
.039 .916 .04 r
.5 Mabswid
.6585 .11139 m
.97619 .10057 L
s
0 0 0 r
2.5 Mabswid
.97619 .10057 Mdot
.039 .916 .04 r
.5 Mabswid
.65854 .11044 m
.97619 .10053 L
s
0 0 0 r
2.5 Mabswid
.97619 .10053 Mdot
.039 .916 .04 r
.5 Mabswid
.65857 .10949 m
.97619 .10049 L
s
0 0 0 r
2.5 Mabswid
.97619 .10049 Mdot
.039 .916 .04 r
.5 Mabswid
.6586 .10854 m
.97619 .10045 L
s
0 0 0 r
2.5 Mabswid
.97619 .10045 Mdot
.039 .916 .04 r
.5 Mabswid
.65863 .10759 m
.97619 .1004 L
s
0 0 0 r
2.5 Mabswid
.97619 .1004 Mdot
.039 .916 .04 r
.5 Mabswid
.65865 .10664 m
.97619 .10036 L
s
0 0 0 r
2.5 Mabswid
.97619 .10036 Mdot
.039 .916 .04 r
.5 Mabswid
.65867 .10569 m
.97619 .10031 L
s
0 0 0 r
2.5 Mabswid
.97619 .10031 Mdot
.039 .916 .04 r
.5 Mabswid
.65869 .10474 m
.97619 .10026 L
s
0 0 0 r
2.5 Mabswid
.97619 .10026 Mdot
.039 .916 .04 r
.5 Mabswid
.65871 .10379 m
.97619 .10021 L
s
0 0 0 r
2.5 Mabswid
.97619 .10021 Mdot
.039 .916 .04 r
.5 Mabswid
.65872 .10284 m
.97619 .10016 L
s
0 0 0 r
2.5 Mabswid
.97619 .10016 Mdot
.039 .916 .04 r
.5 Mabswid
.65872 .1019 m
.97619 .1001 L
s
0 0 0 r
2.5 Mabswid
.97619 .1001 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .10095 m
.97619 .10005 L
s
0 0 0 r
2.5 Mabswid
.97619 .10005 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .1 m
.97619 .1 L
s
0 0 0 r
2.5 Mabswid
.97619 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .09905 m
.97619 .09995 L
s
0 0 0 r
2.5 Mabswid
.97619 .09995 Mdot
.039 .916 .04 r
.5 Mabswid
.65872 .0981 m
.97619 .0999 L
s
0 0 0 r
2.5 Mabswid
.97619 .0999 Mdot
.039 .916 .04 r
.5 Mabswid
.65872 .09716 m
.97619 .09984 L
s
0 0 0 r
2.5 Mabswid
.97619 .09984 Mdot
.039 .916 .04 r
.5 Mabswid
.65871 .09621 m
.97619 .09979 L
s
0 0 0 r
2.5 Mabswid
.97619 .09979 Mdot
.039 .916 .04 r
.5 Mabswid
.65869 .09526 m
.97619 .09974 L
s
0 0 0 r
2.5 Mabswid
.97619 .09974 Mdot
.039 .916 .04 r
.5 Mabswid
.65867 .09431 m
.97619 .09969 L
s
0 0 0 r
2.5 Mabswid
.97619 .09969 Mdot
.039 .916 .04 r
.5 Mabswid
.65865 .09336 m
.97619 .09964 L
s
0 0 0 r
2.5 Mabswid
.97619 .09964 Mdot
.039 .916 .04 r
.5 Mabswid
.65863 .09241 m
.97619 .0996 L
s
0 0 0 r
2.5 Mabswid
.97619 .0996 Mdot
.039 .916 .04 r
.5 Mabswid
.6586 .09146 m
.97619 .09955 L
s
0 0 0 r
2.5 Mabswid
.97619 .09955 Mdot
.039 .916 .04 r
.5 Mabswid
.65857 .09051 m
.97619 .09951 L
s
0 0 0 r
2.5 Mabswid
.97619 .09951 Mdot
.039 .916 .04 r
.5 Mabswid
.65854 .08956 m
.97619 .09947 L
s
0 0 0 r
2.5 Mabswid
.97619 .09947 Mdot
.039 .916 .04 r
.5 Mabswid
.6585 .08861 m
.97619 .09943 L
s
0 0 0 r
2.5 Mabswid
.97619 .09943 Mdot
.039 .916 .04 r
.5 Mabswid
.65846 .08766 m
.97619 .09939 L
s
0 0 0 r
2.5 Mabswid
.97619 .09939 Mdot
.039 .916 .04 r
.5 Mabswid
.65842 .08671 m
.97619 .09936 L
s
0 0 0 r
2.5 Mabswid
.97619 .09936 Mdot
.039 .916 .04 r
.5 Mabswid
.65838 .08576 m
.97619 .09933 L
s
0 0 0 r
2.5 Mabswid
.97619 .09933 Mdot
.039 .916 .04 r
.5 Mabswid
.65833 .0848 m
.97619 .0993 L
s
0 0 0 r
2.5 Mabswid
.97619 .0993 Mdot
.039 .916 .04 r
.5 Mabswid
.65827 .08385 m
.97619 .09928 L
s
0 0 0 r
2.5 Mabswid
.97619 .09928 Mdot
.039 .916 .04 r
.5 Mabswid
.65822 .0829 m
.97619 .09926 L
s
0 0 0 r
2.5 Mabswid
.97619 .09926 Mdot
.039 .916 .04 r
.5 Mabswid
.65816 .08194 m
.97619 .09925 L
s
0 0 0 r
2.5 Mabswid
.97619 .09925 Mdot
.039 .916 .04 r
.5 Mabswid
.6581 .08099 m
.97619 .09924 L
s
0 0 0 r
2.5 Mabswid
.97619 .09924 Mdot
.039 .916 .04 r
.5 Mabswid
.65803 .08003 m
.97619 .09923 L
s
0 0 0 r
2.5 Mabswid
.97619 .09923 Mdot
.039 .916 .04 r
.5 Mabswid
.65796 .07907 m
.97619 .09923 L
s
0 0 0 r
2.5 Mabswid
.97619 .09923 Mdot
.039 .916 .04 r
.5 Mabswid
.65789 .07812 m
.97619 .09923 L
s
0 0 0 r
2.5 Mabswid
.97619 .09923 Mdot
.039 .916 .04 r
.5 Mabswid
.65782 .07716 m
.97619 .09924 L
s
0 0 0 r
2.5 Mabswid
.97619 .09924 Mdot
.039 .916 .04 r
.5 Mabswid
.65774 .0762 m
.97619 .09925 L
s
0 0 0 r
2.5 Mabswid
.97619 .09925 Mdot
.039 .916 .04 r
.5 Mabswid
.65766 .07524 m
.97619 .09927 L
s
0 0 0 r
2.5 Mabswid
.97619 .09927 Mdot
.039 .916 .04 r
.5 Mabswid
.65757 .07427 m
.97619 .0993 L
s
0 0 0 r
2.5 Mabswid
.97619 .0993 Mdot
.039 .916 .04 r
.5 Mabswid
.65748 .07331 m
.97619 .09933 L
s
0 0 0 r
2.5 Mabswid
.97619 .09933 Mdot
.039 .916 .04 r
.5 Mabswid
.65739 .07234 m
.97619 .09937 L
s
0 0 0 r
2.5 Mabswid
.97619 .09937 Mdot
.039 .916 .04 r
.5 Mabswid
.6573 .07138 m
.97619 .09942 L
s
0 0 0 r
2.5 Mabswid
.97619 .09942 Mdot
.039 .916 .04 r
.5 Mabswid
.6572 .07041 m
.97619 .09947 L
s
0 0 0 r
2.5 Mabswid
.97619 .09947 Mdot
.039 .916 .04 r
.5 Mabswid
.65709 .06944 m
.97619 .09953 L
s
0 0 0 r
2.5 Mabswid
.97619 .09953 Mdot
.039 .916 .04 r
.5 Mabswid
.65699 .06847 m
.97619 .0996 L
s
0 0 0 r
2.5 Mabswid
.97619 .0996 Mdot
.039 .916 .04 r
.5 Mabswid
.65688 .0675 m
.97619 .09968 L
s
0 0 0 r
2.5 Mabswid
.97619 .09968 Mdot
.039 .916 .04 r
.5 Mabswid
.65677 .06653 m
.97619 .09976 L
s
0 0 0 r
2.5 Mabswid
.97619 .09976 Mdot
.039 .916 .04 r
.5 Mabswid
.65665 .06555 m
.97619 .09986 L
s
0 0 0 r
2.5 Mabswid
.97619 .09986 Mdot
.039 .916 .04 r
.5 Mabswid
.65653 .06458 m
.97619 .09996 L
s
0 0 0 r
2.5 Mabswid
.97619 .09996 Mdot
.039 .916 .04 r
.5 Mabswid
.65641 .0636 m
.97619 .10008 L
s
0 0 0 r
2.5 Mabswid
.97619 .10008 Mdot
.039 .916 .04 r
.5 Mabswid
.65628 .06262 m
.97619 .1002 L
s
0 0 0 r
2.5 Mabswid
.97619 .1002 Mdot
.039 .916 .04 r
.5 Mabswid
.65615 .06164 m
.97619 .10034 L
s
0 0 0 r
2.5 Mabswid
.97619 .10034 Mdot
.039 .916 .04 r
.5 Mabswid
.65601 .06065 m
.97619 .10049 L
s
0 0 0 r
2.5 Mabswid
.97619 .10049 Mdot
.039 .916 .04 r
.5 Mabswid
.65587 .05967 m
.97619 .10064 L
s
0 0 0 r
2.5 Mabswid
.97619 .10064 Mdot
.039 .916 .04 r
.5 Mabswid
.65573 .05868 m
.97619 .10081 L
s
0 0 0 r
2.5 Mabswid
.97619 .10081 Mdot
.039 .916 .04 r
.5 Mabswid
.65559 .05769 m
.97619 .101 L
s
0 0 0 r
2.5 Mabswid
.97619 .101 Mdot
.039 .916 .04 r
.5 Mabswid
.65544 .05669 m
.97619 .10119 L
s
0 0 0 r
2.5 Mabswid
.97619 .10119 Mdot
.039 .916 .04 r
.5 Mabswid
.65528 .0557 m
.97619 .1014 L
s
0 0 0 r
2.5 Mabswid
.97619 .1014 Mdot
.039 .916 .04 r
.5 Mabswid
.65512 .0547 m
.97619 .10162 L
s
0 0 0 r
2.5 Mabswid
.97619 .10162 Mdot
.039 .916 .04 r
.5 Mabswid
.65496 .0537 m
.97619 .10186 L
s
0 0 0 r
2.5 Mabswid
.97619 .10186 Mdot
.039 .916 .04 r
.5 Mabswid
.6548 .0527 m
.97619 .10211 L
s
0 0 0 r
2.5 Mabswid
.97619 .10211 Mdot
.039 .916 .04 r
.5 Mabswid
.65462 .05169 m
.97619 .10238 L
s
0 0 0 r
2.5 Mabswid
.97619 .10238 Mdot
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 57.5625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000>B000`400?l00000o`00003ooooooolQ
ooooo`00/_ooool6o`0005kooooo00?o0000ooooooooool01oooool00;;ooooo1_l0001Nooooo`03
o`000?oooooooooo00Oooooo002aooooo`;o00001?moOgl2o`0005gooooo00?o0000ooooooooool0
1oooool00;7ooooo0_l00004ogmoO`;o0000GOooool00ol0003oooooooooo`07ooooo`00/?ooool0
0ol0003oOgmoo`000006o`0005gooooo00?o0000ooooooooool01oooool00:oooooo00Co0000ogmo
OomoOgoo00001?moOgl00ol0003oOgmoo`00001Looooo`03o`000?oooooooooo00Oooooo002_oooo
o`04o`000?moOgooOgmoo`0000CoOgmo00?o0000ogmoOol00000G?ooool00ol0003oooooooooo`07
ooooo`00[_ooool01Ol0003oOgmoogmoOomoOgoo000000CoOgmo00?o0000ogmoOol00000G?ooool0
0ol0003oooooooooo`07ooooo`00[_ooool01?l0003oOgmoogmoOomoOgl6o`0000;oOgmo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`07ooooo`00[Oooool00ol0003oOgmoogmoO`02ogmo
O`03o`000?moOgooOgmo00;oOgmo00Co0000ogmoOomoOgoo0000Foooool00ol0003oooooooooo`07
ooooo`00[Oooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00;oOgmo00Co0000ogmo
OomoOgoo0000Foooool00ol0003oooooooooo`07ooooo`00[Oooool00ol0003oOgmoogmoO`02ogmo
O`03o`000?moOgooOgmo00;oOgmo00Co0000ogmoOomoOgoo0000Foooool00ol0003oooooooooo`07
ooooo`00[?ooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00;oOgmo00Co0000ogmo
OomoOgoo0000Foooool00ol0003oooooooooo`07ooooo`00Y_ooool5o`WZ2P03o`000?l9jP[o2NX:
00Oo2NX:0_moOgl00ol0003oOgmoogmoO`02o`0005[ooooo00?o0000ooooooooool01oooool009[o
oooo4Ol9jPX00ol0003o2NX:o`WZ2P0<o`WZ2P03o`000?l9jP[o2NX:00;o2NX:Eoooool00ol0003o
ooooooooo`07ooooo`00Soooool[o`WZ2P03o`000?l9jP[o2NX:00Wo2NX:D?ooool00ol0003ooooo
ooooo`07ooooo`00Pooooolgo`WZ2P03o`000?l9jP[o2NX:00oo2NX:B_ooool00ol0003ooooooooo
o`07ooooo`00Mooooolco`WZ2P03o`000?l9jP[o2NX:00go2NX:00?o0000o`WZ2_l9jPX05_l9jPY3
ooooo`03o`000?oooooooooo00Oooooo001/ooooocko2NX:00?o0000o`WZ2_l9jPX03Ol9jPX00ol0
003o2NX:o`WZ2P0Lo`WZ2Sgooooo00?o0000ooooooooool01oooool0063oooooB_l9jPX00ol0003o
2NX:o`WZ2P0co`WZ2SKooooo00?o0000ooooooooool01oooool005CoooooIol9jPX00ol0003o2NX:
o`WZ2P0Xo`WZ2S3ooooo00?o0000ooooooooool01oooool004SoooooLol9jPX00ol0003o2NX:o`WZ
2P0_o`WZ2RWooooo00?o0000ooooooooool01oooool003goooooO_l9jPX00ol0003o2NX:o`WZ2P0g
o`WZ2R7ooooo00?o0000ooooooooool01oooool0037oooooN?l9jPX00ol0003o2NX:o`WZ2P0?o`WZ
2P03o`000?l9jP[o2NX:03ko2NX:6_ooool00ol0003oooooooooo`07ooooo`009Ooooon4o`WZ2P03
o`000?l9jP[o2NX:00oo2NX:00?o0000o`WZ2_l9jPX0A_l9jPXBooooo`03o`000?oooooooooo00Oo
oooo000Jooooohoo2NX:00?o0000o`WZ2_l9jPX03ol9jPX00ol0003o2NX:o`WZ2P1>o`WZ2P[ooooo
00?o0000ooooooooool01oooool000koooooVol9jPX00ol0003o2NX:o`WZ2P0?o`WZ2P03o`000?l9
jP[o2NX:05Go2NX:0_ooool2o`0000Wooooo0008oooooj7o2NX:00?o0000o`WZ2_l9jPX03ol9jPX0
0ol0003o2NX:o`WZ2P1Go`WZ2P;o00002Oooool000koooooVol9jPX00ol0003o2NX:o`WZ2P0?o`WZ
2P03o`000?l9jP[o2NX:05Go2NX:00Coooooo`WZ2_l0003o00002Oooool001WoooooT?l9jPX00ol0
003o2NX:o`WZ2P0?o`WZ2P03o`000?l9jP[o2NX:04ko2NX:2Oooool2o`0000Wooooo000TooooohGo
2NX:00?o0000o`WZ2_l9jPX03ol9jPX00ol0003o2NX:o`WZ2P18o`WZ2Q3ooooo00?o0000oooooooo
ool01oooool002ooooooN_l9jPX00ol0003o2NX:o`WZ2P0?o`WZ2P03o`000?l9jP[o2NX:047o2NX:
5oooool00ol0003oooooooooo`07ooooo`00>_oooom_o`WZ2P03o`000?l9jP[o2NX:00oo2NX:00?o
0000o`WZ2_l9jPX0>ol9jPXMooooo`03o`000?oooooooooo00Oooooo0015ooooofCo2NX:00?o0000
o`WZ2_l9jPX03ol9jPX00ol0003o2NX:o`WZ2P0do`WZ2RCooooo00?o0000ooooooooool01oooool0
053oooooJol9jPX00ol0003o2NX:o`WZ2P0^o`WZ2R[ooooo00?o0000ooooooooool01oooool005_o
ooooR_l9jPXaooooo`03o`000?oooooooooo00Oooooo001VooooodCo2NX:00?o0000o`WZ2_l9jPX0
<_l9jPXgooooo`03o`000?oooooooooo00Oooooo001aooooocWo2NX:00?o0000o`WZ2_l9jPX0:ol9
jPXnooooo`03o`000?oooooooooo00Oooooo001looooobko2NX:00?o0000o`WZ2_l9jPX03Ol9jPX0
0ol0003o2NX:o`WZ2P0Eo`WZ2TCooooo00?o0000ooooooooool01oooool008Oooooo8ol9jPX00ol0
003o2NX:o`WZ2P0=o`WZ2P03o`000?l9jP[o2NX:00ko2NX:Boooool00ol0003oooooooooo`07oooo
o`00T_oooolIo`WZ2P03o`000?l9jP[o2NX:00co2NX:00?o0000o`WZ2_l9jPX02?l9jPYAooooo`03
o`000?oooooooooo00Oooooo002Mooooo`ko2NX:00?o0000o`WZ2_l9jPX03?l9jPX01?l0003o2NX:
o`WZ2_l9jPYHooooo`03o`000?oooooooooo00Oooooo002Xooooo`?o2NX:00?o0000o`WZ2_l9jPX0
1_l9jPX3ogmoO`03o`000?moOgooOgmo00;o0000F_ooool00ol0003oooooooooo`07ooooo`00[?oo
ool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00;oOgmo00Co0000ogmoOomoOgoo0000
Foooool00ol0003oooooooooo`07ooooo`00[Oooool00ol0003oOgmoogmoO`02ogmoO`03o`000?mo
OgooOgmo00;oOgmo00Co0000ogmoOomoOgoo0000Foooool00ol0003oooooooooo`07ooooo`00[Ooo
ool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00;oOgmo00Co0000ogmoOomoOgoo0000
Foooool00ol0003oooooooooo`07ooooo`00[Oooool00ol0003oOgmoogmoO`02ogmoO`Ko00000_mo
Ogl00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Oooooo002^ooooo`05o`000?moOgoo
OgmoogmoOol000001?moOgl00ol0003oOgmoo`00001Looooo`03o`000?oooooooooo00Oooooo002^
ooooo`05o`000?moOgooOgmoogmoOol000001?moOgl00ol0003oOgmoo`00001Looooo`03o`000?oo
oooooooo00Oooooo002_ooooo`04o`000?moOgooOgmoo`0000CoOgmo00?o0000ogmoOol00000G?oo
ool00ol0003oooooooooo`07ooooo`00/?ooool00ol0003oOgmoo`000004ogmoO`;o0000GOooool0
0ol0003oooooooooo`07ooooo`00/?ooool00ol0003oOgmoo`000006o`0005gooooo00?o0000oooo
ooooool01oooool00;7ooooo0_l00004ogmoO`;o0000GOooool00ol0003oooooooooo`07ooooo`00
/Oooool7o`0005kooooo00?o0000ooooooooool01oooool00;;ooooo1_l0001Nooooo`03o`000?oo
oooooooo00Oooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {56.5625, 0}} -> {-94.9167, -15.7501, \
0.556911, 0.556911}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[BoxData[
    \({{{c1 \[Rule] 0.0035390080197389385`, 
          c2 \[Rule] \(-0.017555283507059045`\)}, {FocalPoint \[Rule] \
{20306.14055595769`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 2.6362188014721197`, 
          SpotSize \[Rule] 2.636218801472113`, 
          BackFocalLength \[Rule] 20296.348775908446`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] TurboRays}}, {{c1 \[Rule] 0.037051044875348306`, 
          c2 \[Rule] \(-0.022180318377286498`\)}, {FocalPoint \[Rule] \
{59.6157174689979`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.12390376152214377`, 
          SpotSize \[Rule] 0.12390376152214376`, 
          BackFocalLength \[Rule] 49.831602467557154`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] TurboRays}}}\)], "Output",
  CellLabel->"Out[85]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell["\<\
basicsystem = {
\tMove[WedgeOfRays[10,NumberOfRays->101, IntrinsicMedium->1],-90],
\tSphericalLens[{1/c1,35},{1/c2,-35},30,10, ComponentMedium->3/2],
\tMove[Screen[30],60]};\
\>", "Input",
  CellLabel->"In[86]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{

Cell["\<\
sol = OptimizeSystem[basicsystem,SymbolicValues->localminimum[[2]],\
SequentialTrace->True]\
\>", "Input",
  CellLabel->"In[87]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[BoxData[
    \({SymbolicValues \[Rule] {c1 \[Rule] 0.0353374598376066`, 
          c2 \[Rule] \(-0.02379138027077596`\)}, NumberOfCycles \[Rule] 253, 
      FinalMerit \[Rule] 0.12268064879178121`}\)], "Output",
  CellLabel->"Out[87]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindFocusFast[TurboPlot[plot, sol, PlotType->TopView]]", "Input",
  CellLabel->"In[88]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.595238 0.00634921 0.1 0.00634921 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.62256 .00476 m
.64116 .00476 L
.65107 .03651 L
.60683 .03651 L
.62256 .00476 L
F
.60683 .03651 m
.65107 .03651 L
.65684 .06825 L
.59806 .06825 L
.60683 .03651 L
F
.59806 .06825 m
.65684 .06825 L
.65873 .1 L
.59524 .1 L
.59806 .06825 L
F
.59524 .1 m
.65873 .1 L
.65684 .13175 L
.59806 .13175 L
.59524 .1 L
F
.59806 .13175 m
.65684 .13175 L
.65107 .16349 L
.60683 .16349 L
.59806 .13175 L
F
.60683 .16349 m
.65107 .16349 L
.64116 .19524 L
.62256 .19524 L
.60683 .16349 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.62256 .00476 m
.60683 .03651 L
.59806 .06825 L
.59524 .1 L
.59806 .13175 L
.60683 .16349 L
.62256 .19524 L
.64116 .19524 L
.65107 .16349 L
.65684 .13175 L
.65873 .1 L
.65684 .06825 L
.65107 .03651 L
.64116 .00476 L
.62256 .00476 L
s
.5 g
.62256 .1 m
.64116 .1 L
.65107 .1 L
.60683 .1 L
.62256 .1 L
F
.60683 .1 m
.65107 .1 L
.65684 .1 L
.59806 .1 L
.60683 .1 L
F
.59806 .1 m
.65684 .1 L
.65873 .1 L
.59524 .1 L
.59806 .1 L
F
.59524 .1 m
.65873 .1 L
.65684 .1 L
.59806 .1 L
.59524 .1 L
F
.59806 .1 m
.65684 .1 L
.65107 .1 L
.60683 .1 L
.59806 .1 L
F
.60683 .1 m
.65107 .1 L
.64116 .1 L
.62256 .1 L
.60683 .1 L
F
0 g
.62256 .1 m
.60683 .1 L
.59806 .1 L
.59524 .1 L
.59806 .1 L
.60683 .1 L
.62256 .1 L
.64116 .1 L
.65107 .1 L
.65684 .1 L
.65873 .1 L
.65684 .1 L
.65107 .1 L
.64116 .1 L
.62256 .1 L
s
.62256 .19524 m
.64116 .19524 L
.64116 .19199 L
.62256 .19199 L
.62256 .19524 L
s
.62256 .19199 m
.64116 .19199 L
.64116 .18248 L
.62256 .18248 L
.62256 .19199 L
s
.62256 .18248 m
.64116 .18248 L
.64116 .16734 L
.62256 .16734 L
.62256 .18248 L
s
.62256 .16734 m
.64116 .16734 L
.64116 .14762 L
.62256 .14762 L
.62256 .16734 L
s
.62256 .14762 m
.64116 .14762 L
.64116 .12465 L
.62256 .12465 L
.62256 .14762 L
s
.62256 .12465 m
.64116 .12465 L
.64116 .1 L
.62256 .1 L
.62256 .12465 L
s
.62256 .1 m
.64116 .1 L
.64116 .07535 L
.62256 .07535 L
.62256 .1 L
s
.62256 .07535 m
.64116 .07535 L
.64116 .05238 L
.62256 .05238 L
.62256 .07535 L
s
.62256 .05238 m
.64116 .05238 L
.64116 .03266 L
.62256 .03266 L
.62256 .05238 L
s
.62256 .03266 m
.64116 .03266 L
.64116 .01752 L
.62256 .01752 L
.62256 .03266 L
s
.62256 .01752 m
.64116 .01752 L
.64116 .00801 L
.62256 .00801 L
.62256 .01752 L
s
.62256 .00801 m
.64116 .00801 L
.64116 .00476 L
.62256 .00476 L
.62256 .00801 L
s
.62256 .00476 m
.64116 .00476 L
.64116 .00801 L
.62256 .00801 L
.62256 .00476 L
s
.62256 .00801 m
.64116 .00801 L
.64116 .01752 L
.62256 .01752 L
.62256 .00801 L
s
.62256 .01752 m
.64116 .01752 L
.64116 .03266 L
.62256 .03266 L
.62256 .01752 L
s
.62256 .03266 m
.64116 .03266 L
.64116 .05238 L
.62256 .05238 L
.62256 .03266 L
s
.62256 .05238 m
.64116 .05238 L
.64116 .07535 L
.62256 .07535 L
.62256 .05238 L
s
.62256 .07535 m
.64116 .07535 L
.64116 .1 L
.62256 .1 L
.62256 .07535 L
s
.62256 .1 m
.64116 .1 L
.64116 .12465 L
.62256 .12465 L
.62256 .1 L
s
.62256 .12465 m
.64116 .12465 L
.64116 .14762 L
.62256 .14762 L
.62256 .12465 L
s
.62256 .14762 m
.64116 .14762 L
.64116 .16734 L
.62256 .16734 L
.62256 .14762 L
s
.62256 .16734 m
.64116 .16734 L
.64116 .18248 L
.62256 .18248 L
.62256 .16734 L
s
.62256 .18248 m
.64116 .18248 L
.64116 .19199 L
.62256 .19199 L
.62256 .18248 L
s
.62256 .19199 m
.64116 .19199 L
.64116 .19524 L
.62256 .19524 L
.62256 .19199 L
s
.97619 .00476 m
.97619 .03651 L
.97619 .06825 L
.97619 .1 L
.97619 .13175 L
.97619 .16349 L
.97619 .19524 L
.97619 .19524 L
.97619 .16349 L
.97619 .13175 L
.97619 .1 L
.97619 .06825 L
.97619 .03651 L
.97619 .00476 L
.97619 .00476 L
s
.97619 .1 m
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
.97619 .1 L
s
.97619 .19524 m
.97619 .19199 L
.97619 .18248 L
.97619 .16734 L
.97619 .14762 L
.97619 .12465 L
.97619 .1 L
.97619 .07535 L
.97619 .05238 L
.97619 .03266 L
.97619 .01752 L
.97619 .00801 L
.97619 .00476 L
.97619 .00801 L
.97619 .01752 L
.97619 .03266 L
.97619 .05238 L
.97619 .07535 L
.97619 .1 L
.97619 .12465 L
.97619 .14762 L
.97619 .16734 L
.97619 .18248 L
.97619 .19199 L
.97619 .19524 L
s
.039 .916 .04 r
.02381 .1 m
.60252 .15063 L
s
0 0 0 r
2.5 Mabswid
.60252 .15063 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60222 .14959 L
s
0 0 0 r
2.5 Mabswid
.60222 .14959 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60192 .14855 L
s
0 0 0 r
2.5 Mabswid
.60192 .14855 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60163 .14751 L
s
0 0 0 r
2.5 Mabswid
.60163 .14751 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60135 .14647 L
s
0 0 0 r
2.5 Mabswid
.60135 .14647 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60108 .14543 L
s
0 0 0 r
2.5 Mabswid
.60108 .14543 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60081 .1444 L
s
0 0 0 r
2.5 Mabswid
.60081 .1444 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60055 .14337 L
s
0 0 0 r
2.5 Mabswid
.60055 .14337 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.6003 .14233 L
s
0 0 0 r
2.5 Mabswid
.6003 .14233 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60005 .14131 L
s
0 0 0 r
2.5 Mabswid
.60005 .14131 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59981 .14028 L
s
0 0 0 r
2.5 Mabswid
.59981 .14028 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59958 .13925 L
s
0 0 0 r
2.5 Mabswid
.59958 .13925 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59935 .13823 L
s
0 0 0 r
2.5 Mabswid
.59935 .13823 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59913 .1372 L
s
0 0 0 r
2.5 Mabswid
.59913 .1372 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59892 .13618 L
s
0 0 0 r
2.5 Mabswid
.59892 .13618 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59871 .13516 L
s
0 0 0 r
2.5 Mabswid
.59871 .13516 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59851 .13414 L
s
0 0 0 r
2.5 Mabswid
.59851 .13414 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59832 .13313 L
s
0 0 0 r
2.5 Mabswid
.59832 .13313 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59813 .13211 L
s
0 0 0 r
2.5 Mabswid
.59813 .13211 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59795 .13109 L
s
0 0 0 r
2.5 Mabswid
.59795 .13109 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59777 .13008 L
s
0 0 0 r
2.5 Mabswid
.59777 .13008 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5976 .12907 L
s
0 0 0 r
2.5 Mabswid
.5976 .12907 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59744 .12806 L
s
0 0 0 r
2.5 Mabswid
.59744 .12806 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59729 .12704 L
s
0 0 0 r
2.5 Mabswid
.59729 .12704 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59713 .12603 L
s
0 0 0 r
2.5 Mabswid
.59713 .12603 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59699 .12503 L
s
0 0 0 r
2.5 Mabswid
.59699 .12503 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59685 .12402 L
s
0 0 0 r
2.5 Mabswid
.59685 .12402 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59672 .12301 L
s
0 0 0 r
2.5 Mabswid
.59672 .12301 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59659 .122 L
s
0 0 0 r
2.5 Mabswid
.59659 .122 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59647 .121 L
s
0 0 0 r
2.5 Mabswid
.59647 .121 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59635 .11999 L
s
0 0 0 r
2.5 Mabswid
.59635 .11999 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59624 .11899 L
s
0 0 0 r
2.5 Mabswid
.59624 .11899 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59614 .11799 L
s
0 0 0 r
2.5 Mabswid
.59614 .11799 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59604 .11698 L
s
0 0 0 r
2.5 Mabswid
.59604 .11698 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59595 .11598 L
s
0 0 0 r
2.5 Mabswid
.59595 .11598 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59586 .11498 L
s
0 0 0 r
2.5 Mabswid
.59586 .11498 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59578 .11398 L
s
0 0 0 r
2.5 Mabswid
.59578 .11398 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59571 .11298 L
s
0 0 0 r
2.5 Mabswid
.59571 .11298 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59564 .11198 L
s
0 0 0 r
2.5 Mabswid
.59564 .11198 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59557 .11098 L
s
0 0 0 r
2.5 Mabswid
.59557 .11098 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59552 .10998 L
s
0 0 0 r
2.5 Mabswid
.59552 .10998 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59546 .10898 L
s
0 0 0 r
2.5 Mabswid
.59546 .10898 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59542 .10798 L
s
0 0 0 r
2.5 Mabswid
.59542 .10798 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59537 .10698 L
s
0 0 0 r
2.5 Mabswid
.59537 .10698 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59534 .10599 L
s
0 0 0 r
2.5 Mabswid
.59534 .10599 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59531 .10499 L
s
0 0 0 r
2.5 Mabswid
.59531 .10499 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59528 .10399 L
s
0 0 0 r
2.5 Mabswid
.59528 .10399 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59526 .10299 L
s
0 0 0 r
2.5 Mabswid
.59526 .10299 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59525 .10199 L
s
0 0 0 r
2.5 Mabswid
.59525 .10199 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .101 L
s
0 0 0 r
2.5 Mabswid
.59524 .101 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .1 L
s
0 0 0 r
2.5 Mabswid
.59524 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59524 .099 L
s
0 0 0 r
2.5 Mabswid
.59524 .099 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59525 .09801 L
s
0 0 0 r
2.5 Mabswid
.59525 .09801 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59526 .09701 L
s
0 0 0 r
2.5 Mabswid
.59526 .09701 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59528 .09601 L
s
0 0 0 r
2.5 Mabswid
.59528 .09601 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59531 .09501 L
s
0 0 0 r
2.5 Mabswid
.59531 .09501 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59534 .09401 L
s
0 0 0 r
2.5 Mabswid
.59534 .09401 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59537 .09302 L
s
0 0 0 r
2.5 Mabswid
.59537 .09302 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59542 .09202 L
s
0 0 0 r
2.5 Mabswid
.59542 .09202 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59546 .09102 L
s
0 0 0 r
2.5 Mabswid
.59546 .09102 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59552 .09002 L
s
0 0 0 r
2.5 Mabswid
.59552 .09002 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59557 .08902 L
s
0 0 0 r
2.5 Mabswid
.59557 .08902 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59564 .08802 L
s
0 0 0 r
2.5 Mabswid
.59564 .08802 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59571 .08702 L
s
0 0 0 r
2.5 Mabswid
.59571 .08702 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59578 .08602 L
s
0 0 0 r
2.5 Mabswid
.59578 .08602 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59586 .08502 L
s
0 0 0 r
2.5 Mabswid
.59586 .08502 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59595 .08402 L
s
0 0 0 r
2.5 Mabswid
.59595 .08402 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59604 .08302 L
s
0 0 0 r
2.5 Mabswid
.59604 .08302 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59614 .08201 L
s
0 0 0 r
2.5 Mabswid
.59614 .08201 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59624 .08101 L
s
0 0 0 r
2.5 Mabswid
.59624 .08101 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59635 .08001 L
s
0 0 0 r
2.5 Mabswid
.59635 .08001 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59647 .079 L
s
0 0 0 r
2.5 Mabswid
.59647 .079 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59659 .078 L
s
0 0 0 r
2.5 Mabswid
.59659 .078 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59672 .07699 L
s
0 0 0 r
2.5 Mabswid
.59672 .07699 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59685 .07598 L
s
0 0 0 r
2.5 Mabswid
.59685 .07598 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59699 .07497 L
s
0 0 0 r
2.5 Mabswid
.59699 .07497 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59713 .07397 L
s
0 0 0 r
2.5 Mabswid
.59713 .07397 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59729 .07296 L
s
0 0 0 r
2.5 Mabswid
.59729 .07296 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59744 .07194 L
s
0 0 0 r
2.5 Mabswid
.59744 .07194 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.5976 .07093 L
s
0 0 0 r
2.5 Mabswid
.5976 .07093 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59777 .06992 L
s
0 0 0 r
2.5 Mabswid
.59777 .06992 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59795 .06891 L
s
0 0 0 r
2.5 Mabswid
.59795 .06891 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59813 .06789 L
s
0 0 0 r
2.5 Mabswid
.59813 .06789 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59832 .06687 L
s
0 0 0 r
2.5 Mabswid
.59832 .06687 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59851 .06586 L
s
0 0 0 r
2.5 Mabswid
.59851 .06586 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59871 .06484 L
s
0 0 0 r
2.5 Mabswid
.59871 .06484 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59892 .06382 L
s
0 0 0 r
2.5 Mabswid
.59892 .06382 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59913 .0628 L
s
0 0 0 r
2.5 Mabswid
.59913 .0628 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59935 .06177 L
s
0 0 0 r
2.5 Mabswid
.59935 .06177 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59958 .06075 L
s
0 0 0 r
2.5 Mabswid
.59958 .06075 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.59981 .05972 L
s
0 0 0 r
2.5 Mabswid
.59981 .05972 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60005 .05869 L
s
0 0 0 r
2.5 Mabswid
.60005 .05869 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.6003 .05767 L
s
0 0 0 r
2.5 Mabswid
.6003 .05767 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60055 .05663 L
s
0 0 0 r
2.5 Mabswid
.60055 .05663 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60081 .0556 L
s
0 0 0 r
2.5 Mabswid
.60081 .0556 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60108 .05457 L
s
0 0 0 r
2.5 Mabswid
.60108 .05457 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60135 .05353 L
s
0 0 0 r
2.5 Mabswid
.60135 .05353 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60163 .05249 L
s
0 0 0 r
2.5 Mabswid
.60163 .05249 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60192 .05145 L
s
0 0 0 r
2.5 Mabswid
.60192 .05145 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60222 .05041 L
s
0 0 0 r
2.5 Mabswid
.60222 .05041 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1 m
.60252 .04937 L
s
0 0 0 r
2.5 Mabswid
.60252 .04937 Mdot
.039 .916 .04 r
.5 Mabswid
.60252 .15063 m
.65428 .14854 L
s
0 0 0 r
2.5 Mabswid
.65428 .14854 Mdot
.039 .916 .04 r
.5 Mabswid
.60222 .14959 m
.65446 .14753 L
s
0 0 0 r
2.5 Mabswid
.65446 .14753 Mdot
.039 .916 .04 r
.5 Mabswid
.60192 .14855 m
.65464 .14653 L
s
0 0 0 r
2.5 Mabswid
.65464 .14653 Mdot
.039 .916 .04 r
.5 Mabswid
.60163 .14751 m
.65482 .14553 L
s
0 0 0 r
2.5 Mabswid
.65482 .14553 Mdot
.039 .916 .04 r
.5 Mabswid
.60135 .14647 m
.65499 .14453 L
s
0 0 0 r
2.5 Mabswid
.65499 .14453 Mdot
.039 .916 .04 r
.5 Mabswid
.60108 .14543 m
.65516 .14353 L
s
0 0 0 r
2.5 Mabswid
.65516 .14353 Mdot
.039 .916 .04 r
.5 Mabswid
.60081 .1444 m
.65532 .14253 L
s
0 0 0 r
2.5 Mabswid
.65532 .14253 Mdot
.039 .916 .04 r
.5 Mabswid
.60055 .14337 m
.65548 .14154 L
s
0 0 0 r
2.5 Mabswid
.65548 .14154 Mdot
.039 .916 .04 r
.5 Mabswid
.6003 .14233 m
.65563 .14055 L
s
0 0 0 r
2.5 Mabswid
.65563 .14055 Mdot
.039 .916 .04 r
.5 Mabswid
.60005 .14131 m
.65578 .13956 L
s
0 0 0 r
2.5 Mabswid
.65578 .13956 Mdot
.039 .916 .04 r
.5 Mabswid
.59981 .14028 m
.65593 .13857 L
s
0 0 0 r
2.5 Mabswid
.65593 .13857 Mdot
.039 .916 .04 r
.5 Mabswid
.59958 .13925 m
.65607 .13758 L
s
0 0 0 r
2.5 Mabswid
.65607 .13758 Mdot
.039 .916 .04 r
.5 Mabswid
.59935 .13823 m
.65621 .1366 L
s
0 0 0 r
2.5 Mabswid
.65621 .1366 Mdot
.039 .916 .04 r
.5 Mabswid
.59913 .1372 m
.65634 .13562 L
s
0 0 0 r
2.5 Mabswid
.65634 .13562 Mdot
.039 .916 .04 r
.5 Mabswid
.59892 .13618 m
.65647 .13464 L
s
0 0 0 r
2.5 Mabswid
.65647 .13464 Mdot
.039 .916 .04 r
.5 Mabswid
.59871 .13516 m
.6566 .13366 L
s
0 0 0 r
2.5 Mabswid
.6566 .13366 Mdot
.039 .916 .04 r
.5 Mabswid
.59851 .13414 m
.65672 .13268 L
s
0 0 0 r
2.5 Mabswid
.65672 .13268 Mdot
.039 .916 .04 r
.5 Mabswid
.59832 .13313 m
.65684 .1317 L
s
0 0 0 r
2.5 Mabswid
.65684 .1317 Mdot
.039 .916 .04 r
.5 Mabswid
.59813 .13211 m
.65696 .13073 L
s
0 0 0 r
2.5 Mabswid
.65696 .13073 Mdot
.039 .916 .04 r
.5 Mabswid
.59795 .13109 m
.65707 .12976 L
s
0 0 0 r
2.5 Mabswid
.65707 .12976 Mdot
.039 .916 .04 r
.5 Mabswid
.59777 .13008 m
.65717 .12878 L
s
0 0 0 r
2.5 Mabswid
.65717 .12878 Mdot
.039 .916 .04 r
.5 Mabswid
.5976 .12907 m
.65728 .12781 L
s
0 0 0 r
2.5 Mabswid
.65728 .12781 Mdot
.039 .916 .04 r
.5 Mabswid
.59744 .12806 m
.65738 .12684 L
s
0 0 0 r
2.5 Mabswid
.65738 .12684 Mdot
.039 .916 .04 r
.5 Mabswid
.59729 .12704 m
.65747 .12587 L
s
0 0 0 r
2.5 Mabswid
.65747 .12587 Mdot
.039 .916 .04 r
.5 Mabswid
.59713 .12603 m
.65757 .12491 L
s
0 0 0 r
2.5 Mabswid
.65757 .12491 Mdot
.039 .916 .04 r
.5 Mabswid
.59699 .12503 m
.65765 .12394 L
s
0 0 0 r
2.5 Mabswid
.65765 .12394 Mdot
.039 .916 .04 r
.5 Mabswid
.59685 .12402 m
.65774 .12298 L
s
0 0 0 r
2.5 Mabswid
.65774 .12298 Mdot
.039 .916 .04 r
.5 Mabswid
.59672 .12301 m
.65782 .12201 L
s
0 0 0 r
2.5 Mabswid
.65782 .12201 Mdot
.039 .916 .04 r
.5 Mabswid
.59659 .122 m
.6579 .12105 L
s
0 0 0 r
2.5 Mabswid
.6579 .12105 Mdot
.039 .916 .04 r
.5 Mabswid
.59647 .121 m
.65797 .12009 L
s
0 0 0 r
2.5 Mabswid
.65797 .12009 Mdot
.039 .916 .04 r
.5 Mabswid
.59635 .11999 m
.65804 .11912 L
s
0 0 0 r
2.5 Mabswid
.65804 .11912 Mdot
.039 .916 .04 r
.5 Mabswid
.59624 .11899 m
.65811 .11816 L
s
0 0 0 r
2.5 Mabswid
.65811 .11816 Mdot
.039 .916 .04 r
.5 Mabswid
.59614 .11799 m
.65818 .1172 L
s
0 0 0 r
2.5 Mabswid
.65818 .1172 Mdot
.039 .916 .04 r
.5 Mabswid
.59604 .11698 m
.65824 .11624 L
s
0 0 0 r
2.5 Mabswid
.65824 .11624 Mdot
.039 .916 .04 r
.5 Mabswid
.59595 .11598 m
.65829 .11528 L
s
0 0 0 r
2.5 Mabswid
.65829 .11528 Mdot
.039 .916 .04 r
.5 Mabswid
.59586 .11498 m
.65835 .11433 L
s
0 0 0 r
2.5 Mabswid
.65835 .11433 Mdot
.039 .916 .04 r
.5 Mabswid
.59578 .11398 m
.6584 .11337 L
s
0 0 0 r
2.5 Mabswid
.6584 .11337 Mdot
.039 .916 .04 r
.5 Mabswid
.59571 .11298 m
.65844 .11241 L
s
0 0 0 r
2.5 Mabswid
.65844 .11241 Mdot
.039 .916 .04 r
.5 Mabswid
.59564 .11198 m
.65848 .11146 L
s
0 0 0 r
2.5 Mabswid
.65848 .11146 Mdot
.039 .916 .04 r
.5 Mabswid
.59557 .11098 m
.65852 .1105 L
s
0 0 0 r
2.5 Mabswid
.65852 .1105 Mdot
.039 .916 .04 r
.5 Mabswid
.59552 .10998 m
.65856 .10954 L
s
0 0 0 r
2.5 Mabswid
.65856 .10954 Mdot
.039 .916 .04 r
.5 Mabswid
.59546 .10898 m
.65859 .10859 L
s
0 0 0 r
2.5 Mabswid
.65859 .10859 Mdot
.039 .916 .04 r
.5 Mabswid
.59542 .10798 m
.65862 .10763 L
s
0 0 0 r
2.5 Mabswid
.65862 .10763 Mdot
.039 .916 .04 r
.5 Mabswid
.59537 .10698 m
.65865 .10668 L
s
0 0 0 r
2.5 Mabswid
.65865 .10668 Mdot
.039 .916 .04 r
.5 Mabswid
.59534 .10599 m
.65867 .10572 L
s
0 0 0 r
2.5 Mabswid
.65867 .10572 Mdot
.039 .916 .04 r
.5 Mabswid
.59531 .10499 m
.65869 .10477 L
s
0 0 0 r
2.5 Mabswid
.65869 .10477 Mdot
.039 .916 .04 r
.5 Mabswid
.59528 .10399 m
.6587 .10382 L
s
0 0 0 r
2.5 Mabswid
.6587 .10382 Mdot
.039 .916 .04 r
.5 Mabswid
.59526 .10299 m
.65871 .10286 L
s
0 0 0 r
2.5 Mabswid
.65871 .10286 Mdot
.039 .916 .04 r
.5 Mabswid
.59525 .10199 m
.65872 .10191 L
s
0 0 0 r
2.5 Mabswid
.65872 .10191 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .101 m
.65873 .10095 L
s
0 0 0 r
2.5 Mabswid
.65873 .10095 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .1 m
.65873 .1 L
s
0 0 0 r
2.5 Mabswid
.65873 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .099 m
.65873 .09905 L
s
0 0 0 r
2.5 Mabswid
.65873 .09905 Mdot
.039 .916 .04 r
.5 Mabswid
.59525 .09801 m
.65872 .09809 L
s
0 0 0 r
2.5 Mabswid
.65872 .09809 Mdot
.039 .916 .04 r
.5 Mabswid
.59526 .09701 m
.65871 .09714 L
s
0 0 0 r
2.5 Mabswid
.65871 .09714 Mdot
.039 .916 .04 r
.5 Mabswid
.59528 .09601 m
.6587 .09618 L
s
0 0 0 r
2.5 Mabswid
.6587 .09618 Mdot
.039 .916 .04 r
.5 Mabswid
.59531 .09501 m
.65869 .09523 L
s
0 0 0 r
2.5 Mabswid
.65869 .09523 Mdot
.039 .916 .04 r
.5 Mabswid
.59534 .09401 m
.65867 .09428 L
s
0 0 0 r
2.5 Mabswid
.65867 .09428 Mdot
.039 .916 .04 r
.5 Mabswid
.59537 .09302 m
.65865 .09332 L
s
0 0 0 r
2.5 Mabswid
.65865 .09332 Mdot
.039 .916 .04 r
.5 Mabswid
.59542 .09202 m
.65862 .09237 L
s
0 0 0 r
2.5 Mabswid
.65862 .09237 Mdot
.039 .916 .04 r
.5 Mabswid
.59546 .09102 m
.65859 .09141 L
s
0 0 0 r
2.5 Mabswid
.65859 .09141 Mdot
.039 .916 .04 r
.5 Mabswid
.59552 .09002 m
.65856 .09046 L
s
0 0 0 r
2.5 Mabswid
.65856 .09046 Mdot
.039 .916 .04 r
.5 Mabswid
.59557 .08902 m
.65852 .0895 L
s
0 0 0 r
2.5 Mabswid
.65852 .0895 Mdot
.039 .916 .04 r
.5 Mabswid
.59564 .08802 m
.65848 .08854 L
s
0 0 0 r
2.5 Mabswid
.65848 .08854 Mdot
.039 .916 .04 r
.5 Mabswid
.59571 .08702 m
.65844 .08759 L
s
0 0 0 r
2.5 Mabswid
.65844 .08759 Mdot
.039 .916 .04 r
.5 Mabswid
.59578 .08602 m
.6584 .08663 L
s
0 0 0 r
2.5 Mabswid
.6584 .08663 Mdot
.039 .916 .04 r
.5 Mabswid
.59586 .08502 m
.65835 .08567 L
s
0 0 0 r
2.5 Mabswid
.65835 .08567 Mdot
.039 .916 .04 r
.5 Mabswid
.59595 .08402 m
.65829 .08472 L
s
0 0 0 r
2.5 Mabswid
.65829 .08472 Mdot
.039 .916 .04 r
.5 Mabswid
.59604 .08302 m
.65824 .08376 L
s
0 0 0 r
2.5 Mabswid
.65824 .08376 Mdot
.039 .916 .04 r
.5 Mabswid
.59614 .08201 m
.65818 .0828 L
s
0 0 0 r
2.5 Mabswid
.65818 .0828 Mdot
.039 .916 .04 r
.5 Mabswid
.59624 .08101 m
.65811 .08184 L
s
0 0 0 r
2.5 Mabswid
.65811 .08184 Mdot
.039 .916 .04 r
.5 Mabswid
.59635 .08001 m
.65804 .08088 L
s
0 0 0 r
2.5 Mabswid
.65804 .08088 Mdot
.039 .916 .04 r
.5 Mabswid
.59647 .079 m
.65797 .07991 L
s
0 0 0 r
2.5 Mabswid
.65797 .07991 Mdot
.039 .916 .04 r
.5 Mabswid
.59659 .078 m
.6579 .07895 L
s
0 0 0 r
2.5 Mabswid
.6579 .07895 Mdot
.039 .916 .04 r
.5 Mabswid
.59672 .07699 m
.65782 .07799 L
s
0 0 0 r
2.5 Mabswid
.65782 .07799 Mdot
.039 .916 .04 r
.5 Mabswid
.59685 .07598 m
.65774 .07702 L
s
0 0 0 r
2.5 Mabswid
.65774 .07702 Mdot
.039 .916 .04 r
.5 Mabswid
.59699 .07497 m
.65765 .07606 L
s
0 0 0 r
2.5 Mabswid
.65765 .07606 Mdot
.039 .916 .04 r
.5 Mabswid
.59713 .07397 m
.65757 .07509 L
s
0 0 0 r
2.5 Mabswid
.65757 .07509 Mdot
.039 .916 .04 r
.5 Mabswid
.59729 .07296 m
.65747 .07413 L
s
0 0 0 r
2.5 Mabswid
.65747 .07413 Mdot
.039 .916 .04 r
.5 Mabswid
.59744 .07194 m
.65738 .07316 L
s
0 0 0 r
2.5 Mabswid
.65738 .07316 Mdot
.039 .916 .04 r
.5 Mabswid
.5976 .07093 m
.65728 .07219 L
s
0 0 0 r
2.5 Mabswid
.65728 .07219 Mdot
.039 .916 .04 r
.5 Mabswid
.59777 .06992 m
.65717 .07122 L
s
0 0 0 r
2.5 Mabswid
.65717 .07122 Mdot
.039 .916 .04 r
.5 Mabswid
.59795 .06891 m
.65707 .07024 L
s
0 0 0 r
2.5 Mabswid
.65707 .07024 Mdot
.039 .916 .04 r
.5 Mabswid
.59813 .06789 m
.65696 .06927 L
s
0 0 0 r
2.5 Mabswid
.65696 .06927 Mdot
.039 .916 .04 r
.5 Mabswid
.59832 .06687 m
.65684 .0683 L
s
0 0 0 r
2.5 Mabswid
.65684 .0683 Mdot
.039 .916 .04 r
.5 Mabswid
.59851 .06586 m
.65672 .06732 L
s
0 0 0 r
2.5 Mabswid
.65672 .06732 Mdot
.039 .916 .04 r
.5 Mabswid
.59871 .06484 m
.6566 .06634 L
s
0 0 0 r
2.5 Mabswid
.6566 .06634 Mdot
.039 .916 .04 r
.5 Mabswid
.59892 .06382 m
.65647 .06536 L
s
0 0 0 r
2.5 Mabswid
.65647 .06536 Mdot
.039 .916 .04 r
.5 Mabswid
.59913 .0628 m
.65634 .06438 L
s
0 0 0 r
2.5 Mabswid
.65634 .06438 Mdot
.039 .916 .04 r
.5 Mabswid
.59935 .06177 m
.65621 .0634 L
s
0 0 0 r
2.5 Mabswid
.65621 .0634 Mdot
.039 .916 .04 r
.5 Mabswid
.59958 .06075 m
.65607 .06242 L
s
0 0 0 r
2.5 Mabswid
.65607 .06242 Mdot
.039 .916 .04 r
.5 Mabswid
.59981 .05972 m
.65593 .06143 L
s
0 0 0 r
2.5 Mabswid
.65593 .06143 Mdot
.039 .916 .04 r
.5 Mabswid
.60005 .05869 m
.65578 .06044 L
s
0 0 0 r
2.5 Mabswid
.65578 .06044 Mdot
.039 .916 .04 r
.5 Mabswid
.6003 .05767 m
.65563 .05945 L
s
0 0 0 r
2.5 Mabswid
.65563 .05945 Mdot
.039 .916 .04 r
.5 Mabswid
.60055 .05663 m
.65548 .05846 L
s
0 0 0 r
2.5 Mabswid
.65548 .05846 Mdot
.039 .916 .04 r
.5 Mabswid
.60081 .0556 m
.65532 .05747 L
s
0 0 0 r
2.5 Mabswid
.65532 .05747 Mdot
.039 .916 .04 r
.5 Mabswid
.60108 .05457 m
.65516 .05647 L
s
0 0 0 r
2.5 Mabswid
.65516 .05647 Mdot
.039 .916 .04 r
.5 Mabswid
.60135 .05353 m
.65499 .05547 L
s
0 0 0 r
2.5 Mabswid
.65499 .05547 Mdot
.039 .916 .04 r
.5 Mabswid
.60163 .05249 m
.65482 .05447 L
s
0 0 0 r
2.5 Mabswid
.65482 .05447 Mdot
.039 .916 .04 r
.5 Mabswid
.60192 .05145 m
.65464 .05347 L
s
0 0 0 r
2.5 Mabswid
.65464 .05347 Mdot
.039 .916 .04 r
.5 Mabswid
.60222 .05041 m
.65446 .05247 L
s
0 0 0 r
2.5 Mabswid
.65446 .05247 Mdot
.039 .916 .04 r
.5 Mabswid
.60252 .04937 m
.65428 .05146 L
s
0 0 0 r
2.5 Mabswid
.65428 .05146 Mdot
.039 .916 .04 r
.5 Mabswid
.65428 .14854 m
.97619 .09805 L
s
0 0 0 r
2.5 Mabswid
.97619 .09805 Mdot
.039 .916 .04 r
.5 Mabswid
.65446 .14753 m
.97619 .09831 L
s
0 0 0 r
2.5 Mabswid
.97619 .09831 Mdot
.039 .916 .04 r
.5 Mabswid
.65464 .14653 m
.97619 .09855 L
s
0 0 0 r
2.5 Mabswid
.97619 .09855 Mdot
.039 .916 .04 r
.5 Mabswid
.65482 .14553 m
.97619 .09877 L
s
0 0 0 r
2.5 Mabswid
.97619 .09877 Mdot
.039 .916 .04 r
.5 Mabswid
.65499 .14453 m
.97619 .09898 L
s
0 0 0 r
2.5 Mabswid
.97619 .09898 Mdot
.039 .916 .04 r
.5 Mabswid
.65516 .14353 m
.97619 .09918 L
s
0 0 0 r
2.5 Mabswid
.97619 .09918 Mdot
.039 .916 .04 r
.5 Mabswid
.65532 .14253 m
.97619 .09936 L
s
0 0 0 r
2.5 Mabswid
.97619 .09936 Mdot
.039 .916 .04 r
.5 Mabswid
.65548 .14154 m
.97619 .09954 L
s
0 0 0 r
2.5 Mabswid
.97619 .09954 Mdot
.039 .916 .04 r
.5 Mabswid
.65563 .14055 m
.97619 .09969 L
s
0 0 0 r
2.5 Mabswid
.97619 .09969 Mdot
.039 .916 .04 r
.5 Mabswid
.65578 .13956 m
.97619 .09984 L
s
0 0 0 r
2.5 Mabswid
.97619 .09984 Mdot
.039 .916 .04 r
.5 Mabswid
.65593 .13857 m
.97619 .09998 L
s
0 0 0 r
2.5 Mabswid
.97619 .09998 Mdot
.039 .916 .04 r
.5 Mabswid
.65607 .13758 m
.97619 .1001 L
s
0 0 0 r
2.5 Mabswid
.97619 .1001 Mdot
.039 .916 .04 r
.5 Mabswid
.65621 .1366 m
.97619 .10022 L
s
0 0 0 r
2.5 Mabswid
.97619 .10022 Mdot
.039 .916 .04 r
.5 Mabswid
.65634 .13562 m
.97619 .10032 L
s
0 0 0 r
2.5 Mabswid
.97619 .10032 Mdot
.039 .916 .04 r
.5 Mabswid
.65647 .13464 m
.97619 .10042 L
s
0 0 0 r
2.5 Mabswid
.97619 .10042 Mdot
.039 .916 .04 r
.5 Mabswid
.6566 .13366 m
.97619 .1005 L
s
0 0 0 r
2.5 Mabswid
.97619 .1005 Mdot
.039 .916 .04 r
.5 Mabswid
.65672 .13268 m
.97619 .10058 L
s
0 0 0 r
2.5 Mabswid
.97619 .10058 Mdot
.039 .916 .04 r
.5 Mabswid
.65684 .1317 m
.97619 .10065 L
s
0 0 0 r
2.5 Mabswid
.97619 .10065 Mdot
.039 .916 .04 r
.5 Mabswid
.65696 .13073 m
.97619 .10071 L
s
0 0 0 r
2.5 Mabswid
.97619 .10071 Mdot
.039 .916 .04 r
.5 Mabswid
.65707 .12976 m
.97619 .10076 L
s
0 0 0 r
2.5 Mabswid
.97619 .10076 Mdot
.039 .916 .04 r
.5 Mabswid
.65717 .12878 m
.97619 .10081 L
s
0 0 0 r
2.5 Mabswid
.97619 .10081 Mdot
.039 .916 .04 r
.5 Mabswid
.65728 .12781 m
.97619 .10084 L
s
0 0 0 r
2.5 Mabswid
.97619 .10084 Mdot
.039 .916 .04 r
.5 Mabswid
.65738 .12684 m
.97619 .10087 L
s
0 0 0 r
2.5 Mabswid
.97619 .10087 Mdot
.039 .916 .04 r
.5 Mabswid
.65747 .12587 m
.97619 .1009 L
s
0 0 0 r
2.5 Mabswid
.97619 .1009 Mdot
.039 .916 .04 r
.5 Mabswid
.65757 .12491 m
.97619 .10092 L
s
0 0 0 r
2.5 Mabswid
.97619 .10092 Mdot
.039 .916 .04 r
.5 Mabswid
.65765 .12394 m
.97619 .10093 L
s
0 0 0 r
2.5 Mabswid
.97619 .10093 Mdot
.039 .916 .04 r
.5 Mabswid
.65774 .12298 m
.97619 .10093 L
s
0 0 0 r
2.5 Mabswid
.97619 .10093 Mdot
.039 .916 .04 r
.5 Mabswid
.65782 .12201 m
.97619 .10093 L
s
0 0 0 r
2.5 Mabswid
.97619 .10093 Mdot
.039 .916 .04 r
.5 Mabswid
.6579 .12105 m
.97619 .10093 L
s
0 0 0 r
2.5 Mabswid
.97619 .10093 Mdot
.039 .916 .04 r
.5 Mabswid
.65797 .12009 m
.97619 .10092 L
s
0 0 0 r
2.5 Mabswid
.97619 .10092 Mdot
.039 .916 .04 r
.5 Mabswid
.65804 .11912 m
.97619 .10091 L
s
0 0 0 r
2.5 Mabswid
.97619 .10091 Mdot
.039 .916 .04 r
.5 Mabswid
.65811 .11816 m
.97619 .10089 L
s
0 0 0 r
2.5 Mabswid
.97619 .10089 Mdot
.039 .916 .04 r
.5 Mabswid
.65818 .1172 m
.97619 .10086 L
s
0 0 0 r
2.5 Mabswid
.97619 .10086 Mdot
.039 .916 .04 r
.5 Mabswid
.65824 .11624 m
.97619 .10084 L
s
0 0 0 r
2.5 Mabswid
.97619 .10084 Mdot
.039 .916 .04 r
.5 Mabswid
.65829 .11528 m
.97619 .10081 L
s
0 0 0 r
2.5 Mabswid
.97619 .10081 Mdot
.039 .916 .04 r
.5 Mabswid
.65835 .11433 m
.97619 .10077 L
s
0 0 0 r
2.5 Mabswid
.97619 .10077 Mdot
.039 .916 .04 r
.5 Mabswid
.6584 .11337 m
.97619 .10074 L
s
0 0 0 r
2.5 Mabswid
.97619 .10074 Mdot
.039 .916 .04 r
.5 Mabswid
.65844 .11241 m
.97619 .1007 L
s
0 0 0 r
2.5 Mabswid
.97619 .1007 Mdot
.039 .916 .04 r
.5 Mabswid
.65848 .11146 m
.97619 .10065 L
s
0 0 0 r
2.5 Mabswid
.97619 .10065 Mdot
.039 .916 .04 r
.5 Mabswid
.65852 .1105 m
.97619 .10061 L
s
0 0 0 r
2.5 Mabswid
.97619 .10061 Mdot
.039 .916 .04 r
.5 Mabswid
.65856 .10954 m
.97619 .10056 L
s
0 0 0 r
2.5 Mabswid
.97619 .10056 Mdot
.039 .916 .04 r
.5 Mabswid
.65859 .10859 m
.97619 .10051 L
s
0 0 0 r
2.5 Mabswid
.97619 .10051 Mdot
.039 .916 .04 r
.5 Mabswid
.65862 .10763 m
.97619 .10046 L
s
0 0 0 r
2.5 Mabswid
.97619 .10046 Mdot
.039 .916 .04 r
.5 Mabswid
.65865 .10668 m
.97619 .1004 L
s
0 0 0 r
2.5 Mabswid
.97619 .1004 Mdot
.039 .916 .04 r
.5 Mabswid
.65867 .10572 m
.97619 .10035 L
s
0 0 0 r
2.5 Mabswid
.97619 .10035 Mdot
.039 .916 .04 r
.5 Mabswid
.65869 .10477 m
.97619 .10029 L
s
0 0 0 r
2.5 Mabswid
.97619 .10029 Mdot
.039 .916 .04 r
.5 Mabswid
.6587 .10382 m
.97619 .10024 L
s
0 0 0 r
2.5 Mabswid
.97619 .10024 Mdot
.039 .916 .04 r
.5 Mabswid
.65871 .10286 m
.97619 .10018 L
s
0 0 0 r
2.5 Mabswid
.97619 .10018 Mdot
.039 .916 .04 r
.5 Mabswid
.65872 .10191 m
.97619 .10012 L
s
0 0 0 r
2.5 Mabswid
.97619 .10012 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .10095 m
.97619 .10006 L
s
0 0 0 r
2.5 Mabswid
.97619 .10006 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .1 m
.97619 .1 L
s
0 0 0 r
2.5 Mabswid
.97619 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.65873 .09905 m
.97619 .09994 L
s
0 0 0 r
2.5 Mabswid
.97619 .09994 Mdot
.039 .916 .04 r
.5 Mabswid
.65872 .09809 m
.97619 .09988 L
s
0 0 0 r
2.5 Mabswid
.97619 .09988 Mdot
.039 .916 .04 r
.5 Mabswid
.65871 .09714 m
.97619 .09982 L
s
0 0 0 r
2.5 Mabswid
.97619 .09982 Mdot
.039 .916 .04 r
.5 Mabswid
.6587 .09618 m
.97619 .09976 L
s
0 0 0 r
2.5 Mabswid
.97619 .09976 Mdot
.039 .916 .04 r
.5 Mabswid
.65869 .09523 m
.97619 .09971 L
s
0 0 0 r
2.5 Mabswid
.97619 .09971 Mdot
.039 .916 .04 r
.5 Mabswid
.65867 .09428 m
.97619 .09965 L
s
0 0 0 r
2.5 Mabswid
.97619 .09965 Mdot
.039 .916 .04 r
.5 Mabswid
.65865 .09332 m
.97619 .0996 L
s
0 0 0 r
2.5 Mabswid
.97619 .0996 Mdot
.039 .916 .04 r
.5 Mabswid
.65862 .09237 m
.97619 .09954 L
s
0 0 0 r
2.5 Mabswid
.97619 .09954 Mdot
.039 .916 .04 r
.5 Mabswid
.65859 .09141 m
.97619 .09949 L
s
0 0 0 r
2.5 Mabswid
.97619 .09949 Mdot
.039 .916 .04 r
.5 Mabswid
.65856 .09046 m
.97619 .09944 L
s
0 0 0 r
2.5 Mabswid
.97619 .09944 Mdot
.039 .916 .04 r
.5 Mabswid
.65852 .0895 m
.97619 .09939 L
s
0 0 0 r
2.5 Mabswid
.97619 .09939 Mdot
.039 .916 .04 r
.5 Mabswid
.65848 .08854 m
.97619 .09935 L
s
0 0 0 r
2.5 Mabswid
.97619 .09935 Mdot
.039 .916 .04 r
.5 Mabswid
.65844 .08759 m
.97619 .0993 L
s
0 0 0 r
2.5 Mabswid
.97619 .0993 Mdot
.039 .916 .04 r
.5 Mabswid
.6584 .08663 m
.97619 .09926 L
s
0 0 0 r
2.5 Mabswid
.97619 .09926 Mdot
.039 .916 .04 r
.5 Mabswid
.65835 .08567 m
.97619 .09923 L
s
0 0 0 r
2.5 Mabswid
.97619 .09923 Mdot
.039 .916 .04 r
.5 Mabswid
.65829 .08472 m
.97619 .09919 L
s
0 0 0 r
2.5 Mabswid
.97619 .09919 Mdot
.039 .916 .04 r
.5 Mabswid
.65824 .08376 m
.97619 .09916 L
s
0 0 0 r
2.5 Mabswid
.97619 .09916 Mdot
.039 .916 .04 r
.5 Mabswid
.65818 .0828 m
.97619 .09914 L
s
0 0 0 r
2.5 Mabswid
.97619 .09914 Mdot
.039 .916 .04 r
.5 Mabswid
.65811 .08184 m
.97619 .09911 L
s
0 0 0 r
2.5 Mabswid
.97619 .09911 Mdot
.039 .916 .04 r
.5 Mabswid
.65804 .08088 m
.97619 .09909 L
s
0 0 0 r
2.5 Mabswid
.97619 .09909 Mdot
.039 .916 .04 r
.5 Mabswid
.65797 .07991 m
.97619 .09908 L
s
0 0 0 r
2.5 Mabswid
.97619 .09908 Mdot
.039 .916 .04 r
.5 Mabswid
.6579 .07895 m
.97619 .09907 L
s
0 0 0 r
2.5 Mabswid
.97619 .09907 Mdot
.039 .916 .04 r
.5 Mabswid
.65782 .07799 m
.97619 .09907 L
s
0 0 0 r
2.5 Mabswid
.97619 .09907 Mdot
.039 .916 .04 r
.5 Mabswid
.65774 .07702 m
.97619 .09907 L
s
0 0 0 r
2.5 Mabswid
.97619 .09907 Mdot
.039 .916 .04 r
.5 Mabswid
.65765 .07606 m
.97619 .09907 L
s
0 0 0 r
2.5 Mabswid
.97619 .09907 Mdot
.039 .916 .04 r
.5 Mabswid
.65757 .07509 m
.97619 .09908 L
s
0 0 0 r
2.5 Mabswid
.97619 .09908 Mdot
.039 .916 .04 r
.5 Mabswid
.65747 .07413 m
.97619 .0991 L
s
0 0 0 r
2.5 Mabswid
.97619 .0991 Mdot
.039 .916 .04 r
.5 Mabswid
.65738 .07316 m
.97619 .09913 L
s
0 0 0 r
2.5 Mabswid
.97619 .09913 Mdot
.039 .916 .04 r
.5 Mabswid
.65728 .07219 m
.97619 .09916 L
s
0 0 0 r
2.5 Mabswid
.97619 .09916 Mdot
.039 .916 .04 r
.5 Mabswid
.65717 .07122 m
.97619 .09919 L
s
0 0 0 r
2.5 Mabswid
.97619 .09919 Mdot
.039 .916 .04 r
.5 Mabswid
.65707 .07024 m
.97619 .09924 L
s
0 0 0 r
2.5 Mabswid
.97619 .09924 Mdot
.039 .916 .04 r
.5 Mabswid
.65696 .06927 m
.97619 .09929 L
s
0 0 0 r
2.5 Mabswid
.97619 .09929 Mdot
.039 .916 .04 r
.5 Mabswid
.65684 .0683 m
.97619 .09935 L
s
0 0 0 r
2.5 Mabswid
.97619 .09935 Mdot
.039 .916 .04 r
.5 Mabswid
.65672 .06732 m
.97619 .09942 L
s
0 0 0 r
2.5 Mabswid
.97619 .09942 Mdot
.039 .916 .04 r
.5 Mabswid
.6566 .06634 m
.97619 .0995 L
s
0 0 0 r
2.5 Mabswid
.97619 .0995 Mdot
.039 .916 .04 r
.5 Mabswid
.65647 .06536 m
.97619 .09958 L
s
0 0 0 r
2.5 Mabswid
.97619 .09958 Mdot
.039 .916 .04 r
.5 Mabswid
.65634 .06438 m
.97619 .09968 L
s
0 0 0 r
2.5 Mabswid
.97619 .09968 Mdot
.039 .916 .04 r
.5 Mabswid
.65621 .0634 m
.97619 .09978 L
s
0 0 0 r
2.5 Mabswid
.97619 .09978 Mdot
.039 .916 .04 r
.5 Mabswid
.65607 .06242 m
.97619 .0999 L
s
0 0 0 r
2.5 Mabswid
.97619 .0999 Mdot
.039 .916 .04 r
.5 Mabswid
.65593 .06143 m
.97619 .10002 L
s
0 0 0 r
2.5 Mabswid
.97619 .10002 Mdot
.039 .916 .04 r
.5 Mabswid
.65578 .06044 m
.97619 .10016 L
s
0 0 0 r
2.5 Mabswid
.97619 .10016 Mdot
.039 .916 .04 r
.5 Mabswid
.65563 .05945 m
.97619 .10031 L
s
0 0 0 r
2.5 Mabswid
.97619 .10031 Mdot
.039 .916 .04 r
.5 Mabswid
.65548 .05846 m
.97619 .10046 L
s
0 0 0 r
2.5 Mabswid
.97619 .10046 Mdot
.039 .916 .04 r
.5 Mabswid
.65532 .05747 m
.97619 .10064 L
s
0 0 0 r
2.5 Mabswid
.97619 .10064 Mdot
.039 .916 .04 r
.5 Mabswid
.65516 .05647 m
.97619 .10082 L
s
0 0 0 r
2.5 Mabswid
.97619 .10082 Mdot
.039 .916 .04 r
.5 Mabswid
.65499 .05547 m
.97619 .10102 L
s
0 0 0 r
2.5 Mabswid
.97619 .10102 Mdot
.039 .916 .04 r
.5 Mabswid
.65482 .05447 m
.97619 .10123 L
s
0 0 0 r
2.5 Mabswid
.97619 .10123 Mdot
.039 .916 .04 r
.5 Mabswid
.65464 .05347 m
.97619 .10145 L
s
0 0 0 r
2.5 Mabswid
.97619 .10145 Mdot
.039 .916 .04 r
.5 Mabswid
.65446 .05247 m
.97619 .10169 L
s
0 0 0 r
2.5 Mabswid
.97619 .10169 Mdot
.039 .916 .04 r
.5 Mabswid
.65428 .05146 m
.97619 .10195 L
s
0 0 0 r
2.5 Mabswid
.97619 .10195 Mdot
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[88]:=",
  ImageSize->{288, 57.5625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000>B000`400?l00000o`00003ooooooolQ
ooooo`00/_ooool6o`0005kooooo00?o0000ooooooooool01oooool00;;ooooo1_l0001Nooooo`03
o`000?oooooooooo00Oooooo002aooooo`;o00001?moOgl2o`0005gooooo00?o0000ooooooooool0
1oooool00;7ooooo0_l00004ogmoO`;o0000GOooool00ol0003oooooooooo`07ooooo`00/?ooool0
0ol0003oOgmoo`000006o`0005gooooo00?o0000ooooooooool01oooool00:oooooo00Co0000ogmo
OomoOgoo00001?moOgl00ol0003oOgmoo`00001Looooo`03o`000?oooooooooo00Oooooo002_oooo
o`04o`000?moOgooOgmoo`0000CoOgmo00?o0000ogmoOol00000G?ooool00ol0003oooooooooo`07
ooooo`00[_ooool01Ol0003oOgmoogmoOomoOgoo000000CoOgmo00?o0000ogmoOol00000G?ooool0
0ol0003oooooooooo`07ooooo`00[_ooool01?l0003oOgmoogmoOomoOgl6o`0000;oOgmo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`07ooooo`00[Oooool00ol0003oOgmoogmoO`02ogmo
O`03o`000?moOgooOgmo00;oOgmo00Co0000ogmoOomoOgoo0000Foooool00ol0003oooooooooo`07
ooooo`00[Oooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00;oOgmo00Co0000ogmo
OomoOgoo0000Foooool00ol0003oooooooooo`07ooooo`00[Oooool00ol0003oOgmoogmoO`02ogmo
O`03o`000?moOgooOgmo00;oOgmo00Co0000ogmoOomoOgoo0000Foooool00ol0003oooooooooo`07
ooooo`00[?ooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00;oOgmo00Co0000ogmo
OomoOgoo0000Foooool00ol0003oooooooooo`07ooooo`00Y_ooool5o`WZ2P03o`000?l9jP[o2NX:
00co2NX:00?o0000o`WZ2_l9jPX00_l9jPYGooooo`03o`000?oooooooooo00Oooooo002Joooooa7o
2NX:00?o0000o`WZ2_l9jPX03?l9jPX00ol0003o2NX:o`WZ2P08o`WZ2U7ooooo00?o0000oooooooo
ool01oooool008oooooo:ol9jPX00ol0003o2NX:o`WZ2P0>o`WZ2T_ooooo00?o0000ooooooooool0
1oooool008?ooooo=ol9jPX00ol0003o2NX:o`WZ2P0Do`WZ2TGooooo00?o0000ooooooooool01ooo
ool007Oooooo<ol9jPX00ol0003o2NX:o`WZ2P0=o`WZ2P03o`000?l9jP[o2NX:01[o2NX:?oooool0
0ol0003oooooooooo`07ooooo`00K?oooolno`WZ2P03o`000?l9jP[o2NX:00go2NX:00?o0000o`WZ
2_l9jPX08?l9jPXiooooo`03o`000?oooooooooo00Oooooo001Poooood[o2NX:00?o0000o`WZ2_l9
jPX0=_l9jPXcooooo`03o`000?oooooooooo00Oooooo001DooooofOo2NX:00?o0000o`WZ2_l9jPX0
;?l9jPX/ooooo`03o`000?oooooooooo00Oooooo0018ooooog?o2NX:00?o0000o`WZ2_l9jPX0<_l9
jPXVooooo`03o`000?oooooooooo00Oooooo000mooooogko2NX:00?o0000o`WZ2_l9jPX0>?l9jPXP
ooooo`03o`000?oooooooooo00Oooooo000aooooogSo2NX:00?o0000o`WZ2_l9jPX03ol9jPX00ol0
003o2NX:o`WZ2P0no`WZ2Q[ooooo00?o0000ooooooooool01oooool002GoooooQ?l9jPX00ol0003o
2NX:o`WZ2P0?o`WZ2P03o`000?l9jP[o2NX:04Ko2NX:4_ooool00ol0003oooooooooo`07ooooo`00
6_oooon?o`WZ2P03o`000?l9jP[o2NX:00oo2NX:00?o0000o`WZ2_l9jPX0C_l9jPX:ooooo`03o`00
0?oooooooooo00Oooooo000>oooooi_o2NX:00?o0000o`WZ2_l9jPX03ol9jPX00ol0003o2NX:o`WZ
2P1Eo`WZ2P;ooooo0_l00009ooooo`002?oooonQo`WZ2P03o`000?l9jP[o2NX:00oo2NX:00?o0000
o`WZ2_l9jPX0Eol9jPX2o`0000Wooooo000>oooooi_o2NX:00?o0000o`WZ2_l9jPX03ol9jPX00ol0
003o2NX:o`WZ2P1Eo`WZ2P04ooooool9jP[o0000o`0000Wooooo000Ioooooi3o2NX:00?o0000o`WZ
2_l9jPX03ol9jPX00ol0003o2NX:o`WZ2P1>o`WZ2PWooooo0_l00009ooooo`009?oooon5o`WZ2P03
o`000?l9jP[o2NX:00oo2NX:00?o0000o`WZ2_l9jPX0B?l9jPX@ooooo`03o`000?oooooooooo00Oo
oooo000_ooooog[o2NX:00?o0000o`WZ2_l9jPX03ol9jPX00ol0003o2NX:o`WZ2P11o`WZ2QOooooo
00?o0000ooooooooool01oooool003[oooooKol9jPX00ol0003o2NX:o`WZ2P0?o`WZ2P03o`000?l9
jP[o2NX:03_o2NX:7Oooool00ol0003oooooooooo`07ooooo`00AOoooomTo`WZ2P03o`000?l9jP[o
2NX:00oo2NX:00?o0000o`WZ2_l9jPX0=?l9jPXTooooo`03o`000?oooooooooo00Oooooo001@oooo
of_o2NX:00?o0000o`WZ2_l9jPX0;_l9jPXZooooo`03o`000?oooooooooo00Oooooo001Koooooh[o
2NX:<Oooool00ol0003oooooooooo`07ooooo`00I_oooom4o`WZ2P03o`000?l9jP[o2NX:03;o2NX:
=oooool00ol0003oooooooooo`07ooooo`00LOoooolio`WZ2P03o`000?l9jP[o2NX:02_o2NX:?_oo
ool00ol0003oooooooooo`07ooooo`00O?ooool^o`WZ2P03o`000?l9jP[o2NX:00go2NX:00?o0000
o`WZ2_l9jPX05Ol9jPY4ooooo`03o`000?oooooooooo00Oooooo0027ooooob?o2NX:00?o0000o`WZ
2_l9jPX03Ol9jPX00ol0003o2NX:o`WZ2P0>o`WZ2T_ooooo00?o0000ooooooooool01oooool009;o
oooo6Ol9jPX00ol0003o2NX:o`WZ2P0<o`WZ2P03o`000?l9jP[o2NX:00So2NX:DOooool00ol0003o
ooooooooo`07ooooo`00WOooool>o`WZ2P03o`000?l9jP[o2NX:00co2NX:00Co0000o`WZ2_l9jP[o
2NX:F?ooool00ol0003oooooooooo`07ooooo`00Z?ooool3o`WZ2P03o`000?l9jP[o2NX:00Ko2NX:
0omoOgl00ol0003oOgmoogmoO`02o`0005[ooooo00?o0000ooooooooool01oooool00:cooooo00?o
0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`02ogmoO`04o`000?moOgooOgmoo`0005_ooooo
00?o0000ooooooooool01oooool00:gooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmo
O`02ogmoO`04o`000?moOgooOgmoo`0005_ooooo00?o0000ooooooooool01oooool00:gooooo00?o
0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`02ogmoO`04o`000?moOgooOgmoo`0005_ooooo
00?o0000ooooooooool01oooool00:gooooo00?o0000ogmoOomoOgl00_moOgl6o`0000;oOgmo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`07ooooo`00[_ooool01Ol0003oOgmoogmoOomo
Ogoo000000CoOgmo00?o0000ogmoOol00000G?ooool00ol0003oooooooooo`07ooooo`00[_ooool0
1Ol0003oOgmoogmoOomoOgoo000000CoOgmo00?o0000ogmoOol00000G?ooool00ol0003ooooooooo
o`07ooooo`00[oooool01?l0003oOgmoogmoOol00004ogmoO`03o`000?moOgoo000005cooooo00?o
0000ooooooooool01oooool00;3ooooo00?o0000ogmoOol000001?moOgl2o`0005gooooo00?o0000
ooooooooool01oooool00;3ooooo00?o0000ogmoOol000001_l0001Mooooo`03o`000?oooooooooo
00Oooooo002aooooo`;o00001?moOgl2o`0005gooooo00?o0000ooooooooool01oooool00;7ooooo
1ol0001Nooooo`03o`000?oooooooooo00Oooooo002booooo`Ko0000G_ooool00ol0003ooooooooo
o`07ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {56.5625, 0}} -> {-94.9167, -15.7501, \
0.556911, 0.556911}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],

Cell[BoxData[
    \({FocalPoint \[Rule] {60.0306512589489`, 0, 0}, 
      FocusType \[Rule] RMSFocus, 
      WeightedSpotSize \[Rule] 0.12265120849007806`, 
      SpotSize \[Rule] 0.12265120849007805`, 
      BackFocalLength \[Rule] 50.26487436000274`, 
      FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
      TurboRays \[Rule] TurboRays}\)], "Output",
  CellLabel->"Out[88]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.2", "AOG2.", "AOG2.2.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Doublet Lens Design", "Subsubsection",
  CellTags->{"AOG0.", "2.2.3", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell["\<\
Now we define a 3 surfaced lens system, using r1 = 100 mm, r2 = -300 mm, and \
r3 = -100 as initial curvature starting points for the lens. Although \
important parameters to optimize, in this example we will fix the spacings \
between the different lens surfaces to be s1 = 15 mm and s2 = 5 mm.\
\>", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(\(optics\  = \ \[IndentingNewLine]{ComponentRendering[{Move[
                SphericalLensSurface[{1/c1, 100}, 50, 
                  ComponentMedium -> BK7], 100], \n\t\tMove[
                SphericalLensSurface[{1/c2, \(-300\)}, 50, 
                  ComponentMedium -> {BK7, SF11}], 115], \n\t\tMove[
                SphericalLensSurface[{1/c3, \(-100\)}, 50, 
                  ComponentMedium -> SF11], 120]}], \n\t\tMove[Screen[50], 
            200]};\)\)], "Input",
  CellLabel->"In[89]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell["\<\
opticalsystem= {Move[LineOfRays[45,NumberOfRays->6],{0,{y,0}}],optics};\
\>", "Input",
  CellLabel->"In[90]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell["Here is a plot of this initial system:", "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnalyzeSystem[opticalsystem, PlotType -> TopView];\)\)], "Input",
  CellLabel->"In[91]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.51512 .03036 m
.56646 .03036 L
.56922 .07004 L
.50666 .07004 L
.51512 .03036 L
F
.50666 .07004 m
.56922 .07004 L
.57088 .10972 L
.50166 .10972 L
.50666 .07004 L
F
.50166 .10972 m
.57088 .10972 L
.57143 .1494 L
.5 .1494 L
.50166 .10972 L
F
.5 .1494 m
.57143 .1494 L
.57088 .18909 L
.50166 .18909 L
.5 .1494 L
F
.50166 .18909 m
.57088 .18909 L
.56922 .22877 L
.50666 .22877 L
.50166 .18909 L
F
.50666 .22877 m
.56922 .22877 L
.56646 .26845 L
.51512 .26845 L
.50666 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.51512 .03036 m
.50666 .07004 L
.50166 .10972 L
.5 .1494 L
.50166 .18909 L
.50666 .22877 L
.51512 .26845 L
.56646 .26845 L
.56922 .22877 L
.57088 .18909 L
.57143 .1494 L
.57088 .10972 L
.56922 .07004 L
.56646 .03036 L
.51512 .03036 L
s
.5 g
.51512 .1494 m
.56646 .1494 L
.56922 .1494 L
.50666 .1494 L
.51512 .1494 L
F
.50666 .1494 m
.56922 .1494 L
.57088 .1494 L
.50166 .1494 L
.50666 .1494 L
F
.50166 .1494 m
.57088 .1494 L
.57143 .1494 L
.5 .1494 L
.50166 .1494 L
F
.5 .1494 m
.57143 .1494 L
.57088 .1494 L
.50166 .1494 L
.5 .1494 L
F
.50166 .1494 m
.57088 .1494 L
.56922 .1494 L
.50666 .1494 L
.50166 .1494 L
F
.50666 .1494 m
.56922 .1494 L
.56646 .1494 L
.51512 .1494 L
.50666 .1494 L
F
0 g
.51512 .1494 m
.50666 .1494 L
.50166 .1494 L
.5 .1494 L
.50166 .1494 L
.50666 .1494 L
.51512 .1494 L
.56646 .1494 L
.56922 .1494 L
.57088 .1494 L
.57143 .1494 L
.57088 .1494 L
.56922 .1494 L
.56646 .1494 L
.51512 .1494 L
s
.5 g
.56646 .03036 m
.58012 .03036 L
.58858 .07004 L
.56922 .07004 L
.56646 .03036 L
F
.56922 .07004 m
.58858 .07004 L
.59358 .10972 L
.57088 .10972 L
.56922 .07004 L
F
.57088 .10972 m
.59358 .10972 L
.59524 .1494 L
.57143 .1494 L
.57088 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59358 .18909 L
.57088 .18909 L
.57143 .1494 L
F
.57088 .18909 m
.59358 .18909 L
.58858 .22877 L
.56922 .22877 L
.57088 .18909 L
F
.56922 .22877 m
.58858 .22877 L
.58012 .26845 L
.56646 .26845 L
.56922 .22877 L
F
0 g
.56646 .03036 m
.56922 .07004 L
.57088 .10972 L
.57143 .1494 L
.57088 .18909 L
.56922 .22877 L
.56646 .26845 L
.58012 .26845 L
.58858 .22877 L
.59358 .18909 L
.59524 .1494 L
.59358 .10972 L
.58858 .07004 L
.58012 .03036 L
.56646 .03036 L
s
.5 g
.56646 .1494 m
.58012 .1494 L
.58858 .1494 L
.56922 .1494 L
.56646 .1494 L
F
.56922 .1494 m
.58858 .1494 L
.59358 .1494 L
.57088 .1494 L
.56922 .1494 L
F
.57088 .1494 m
.59358 .1494 L
.59524 .1494 L
.57143 .1494 L
.57088 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59358 .1494 L
.57088 .1494 L
.57143 .1494 L
F
.57088 .1494 m
.59358 .1494 L
.58858 .1494 L
.56922 .1494 L
.57088 .1494 L
F
.56922 .1494 m
.58858 .1494 L
.58012 .1494 L
.56646 .1494 L
.56922 .1494 L
F
0 g
.56646 .1494 m
.56922 .1494 L
.57088 .1494 L
.57143 .1494 L
.57088 .1494 L
.56922 .1494 L
.56646 .1494 L
.58012 .1494 L
.58858 .1494 L
.59358 .1494 L
.59524 .1494 L
.59358 .1494 L
.58858 .1494 L
.58012 .1494 L
.56646 .1494 L
s
.51512 .26845 m
.56646 .26845 L
.56646 .2644 L
.51512 .2644 L
.51512 .26845 L
s
.51512 .2644 m
.56646 .2644 L
.56646 .2525 L
.51512 .2525 L
.51512 .2644 L
s
.51512 .2525 m
.56646 .2525 L
.56646 .23358 L
.51512 .23358 L
.51512 .2525 L
s
.51512 .23358 m
.56646 .23358 L
.56646 .20893 L
.51512 .20893 L
.51512 .23358 L
s
.51512 .20893 m
.56646 .20893 L
.56646 .18022 L
.51512 .18022 L
.51512 .20893 L
s
.51512 .18022 m
.56646 .18022 L
.56646 .1494 L
.51512 .1494 L
.51512 .18022 L
s
.51512 .1494 m
.56646 .1494 L
.56646 .11859 L
.51512 .11859 L
.51512 .1494 L
s
.51512 .11859 m
.56646 .11859 L
.56646 .08988 L
.51512 .08988 L
.51512 .11859 L
s
.51512 .08988 m
.56646 .08988 L
.56646 .06523 L
.51512 .06523 L
.51512 .08988 L
s
.51512 .06523 m
.56646 .06523 L
.56646 .04631 L
.51512 .04631 L
.51512 .06523 L
s
.51512 .04631 m
.56646 .04631 L
.56646 .03441 L
.51512 .03441 L
.51512 .04631 L
s
.51512 .03441 m
.56646 .03441 L
.56646 .03036 L
.51512 .03036 L
.51512 .03441 L
s
.51512 .03036 m
.56646 .03036 L
.56646 .03441 L
.51512 .03441 L
.51512 .03036 L
s
.51512 .03441 m
.56646 .03441 L
.56646 .04631 L
.51512 .04631 L
.51512 .03441 L
s
.51512 .04631 m
.56646 .04631 L
.56646 .06523 L
.51512 .06523 L
.51512 .04631 L
s
.51512 .06523 m
.56646 .06523 L
.56646 .08988 L
.51512 .08988 L
.51512 .06523 L
s
.51512 .08988 m
.56646 .08988 L
.56646 .11859 L
.51512 .11859 L
.51512 .08988 L
s
.51512 .11859 m
.56646 .11859 L
.56646 .1494 L
.51512 .1494 L
.51512 .11859 L
s
.51512 .1494 m
.56646 .1494 L
.56646 .18022 L
.51512 .18022 L
.51512 .1494 L
s
.51512 .18022 m
.56646 .18022 L
.56646 .20893 L
.51512 .20893 L
.51512 .18022 L
s
.51512 .20893 m
.56646 .20893 L
.56646 .23358 L
.51512 .23358 L
.51512 .20893 L
s
.51512 .23358 m
.56646 .23358 L
.56646 .2525 L
.51512 .2525 L
.51512 .23358 L
s
.51512 .2525 m
.56646 .2525 L
.56646 .2644 L
.51512 .2644 L
.51512 .2525 L
s
.51512 .2644 m
.56646 .2644 L
.56646 .26845 L
.51512 .26845 L
.51512 .2644 L
s
.56646 .26845 m
.58012 .26845 L
.58012 .2644 L
.56646 .2644 L
.56646 .26845 L
s
.56646 .2644 m
.58012 .2644 L
.58012 .2525 L
.56646 .2525 L
.56646 .2644 L
s
.56646 .2525 m
.58012 .2525 L
.58012 .23358 L
.56646 .23358 L
.56646 .2525 L
s
.56646 .23358 m
.58012 .23358 L
.58012 .20893 L
.56646 .20893 L
.56646 .23358 L
s
.56646 .20893 m
.58012 .20893 L
.58012 .18022 L
.56646 .18022 L
.56646 .20893 L
s
.56646 .18022 m
.58012 .18022 L
.58012 .1494 L
.56646 .1494 L
.56646 .18022 L
s
.56646 .1494 m
.58012 .1494 L
.58012 .11859 L
.56646 .11859 L
.56646 .1494 L
s
.56646 .11859 m
.58012 .11859 L
.58012 .08988 L
.56646 .08988 L
.56646 .11859 L
s
.56646 .08988 m
.58012 .08988 L
.58012 .06523 L
.56646 .06523 L
.56646 .08988 L
s
.56646 .06523 m
.58012 .06523 L
.58012 .04631 L
.56646 .04631 L
.56646 .06523 L
s
.56646 .04631 m
.58012 .04631 L
.58012 .03441 L
.56646 .03441 L
.56646 .04631 L
s
.56646 .03441 m
.58012 .03441 L
.58012 .03036 L
.56646 .03036 L
.56646 .03441 L
s
.56646 .03036 m
.58012 .03036 L
.58012 .03441 L
.56646 .03441 L
.56646 .03036 L
s
.56646 .03441 m
.58012 .03441 L
.58012 .04631 L
.56646 .04631 L
.56646 .03441 L
s
.56646 .04631 m
.58012 .04631 L
.58012 .06523 L
.56646 .06523 L
.56646 .04631 L
s
.56646 .06523 m
.58012 .06523 L
.58012 .08988 L
.56646 .08988 L
.56646 .06523 L
s
.56646 .08988 m
.58012 .08988 L
.58012 .11859 L
.56646 .11859 L
.56646 .08988 L
s
.56646 .11859 m
.58012 .11859 L
.58012 .1494 L
.56646 .1494 L
.56646 .11859 L
s
.56646 .1494 m
.58012 .1494 L
.58012 .18022 L
.56646 .18022 L
.56646 .1494 L
s
.56646 .18022 m
.58012 .18022 L
.58012 .20893 L
.56646 .20893 L
.56646 .18022 L
s
.56646 .20893 m
.58012 .20893 L
.58012 .23358 L
.56646 .23358 L
.56646 .20893 L
s
.56646 .23358 m
.58012 .23358 L
.58012 .2525 L
.56646 .2525 L
.56646 .23358 L
s
.56646 .2525 m
.58012 .2525 L
.58012 .2644 L
.56646 .2644 L
.56646 .2525 L
s
.56646 .2644 m
.58012 .2644 L
.58012 .26845 L
.56646 .26845 L
.56646 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .04226 m
.51221 .04226 L
s
% Start of user PostScript
0 -22.5 102.564 -22.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.51221 .04226 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .08512 m
.50436 .08512 L
s
% Start of user PostScript
0 -13.5 100.915 -13.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50436 .08512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .12798 m
.50048 .12798 L
s
% Start of user PostScript
0 -4.5 100.101 -4.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50048 .12798 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17083 m
.50048 .17083 L
s
% Start of user PostScript
0 4.5 100.101 4.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50048 .17083 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .21369 m
.50436 .21369 L
s
% Start of user PostScript
0 13.5 100.915 13.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50436 .21369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25655 m
.51221 .25655 L
s
% Start of user PostScript
0 22.5 102.564 22.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.51221 .25655 Mdot
.039 .916 .04 r
.5 Mabswid
.51221 .04226 m
.56773 .04662 L
s
% Start of user PostScript
102.564 -22.5 114.222 -21.5855 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56773 .04662 Mdot
.039 .916 .04 r
.5 Mabswid
.50436 .08512 m
.57012 .08817 L
s
% Start of user PostScript
100.915 -13.5 114.724 -12.8585 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57012 .08817 Mdot
.039 .916 .04 r
.5 Mabswid
.50048 .12798 m
.57128 .12907 L
s
% Start of user PostScript
100.101 -4.5 114.97 -4.2712 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57128 .12907 Mdot
.039 .916 .04 r
.5 Mabswid
.50048 .17083 m
.57128 .16974 L
s
% Start of user PostScript
100.101 4.5 114.97 4.2712 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57128 .16974 Mdot
.039 .916 .04 r
.5 Mabswid
.50436 .21369 m
.57012 .21064 L
s
% Start of user PostScript
100.915 13.5 114.724 12.8585 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57012 .21064 Mdot
.039 .916 .04 r
.5 Mabswid
.51221 .25655 m
.56773 .25219 L
s
% Start of user PostScript
102.564 22.5 114.222 21.5855 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.56773 .25219 Mdot
.039 .916 .04 r
.5 Mabswid
.56773 .04662 m
.58421 .04753 L
s
% Start of user PostScript
114.222 -21.5855 117.685 -21.3946 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.58421 .04753 Mdot
.039 .916 .04 r
.5 Mabswid
.57012 .08817 m
.59137 .08887 L
s
% Start of user PostScript
114.724 -12.8585 119.189 -12.7124 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59137 .08887 Mdot
.039 .916 .04 r
.5 Mabswid
.57128 .12907 m
.59481 .12932 L
s
% Start of user PostScript
114.97 -4.2712 119.911 -4.21762 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59481 .12932 Mdot
.039 .916 .04 r
.5 Mabswid
.57128 .16974 m
.59481 .16949 L
s
% Start of user PostScript
114.97 4.2712 119.911 4.21762 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59481 .16949 Mdot
.039 .916 .04 r
.5 Mabswid
.57012 .21064 m
.59137 .20994 L
s
% Start of user PostScript
114.724 12.8585 119.189 12.7124 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59137 .20994 Mdot
.039 .916 .04 r
.5 Mabswid
.56773 .25219 m
.58421 .25128 L
s
% Start of user PostScript
114.222 21.5855 117.685 21.3946 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.58421 .25128 Mdot
.039 .916 .04 r
.5 Mabswid
.58421 .04753 m
.97619 .16229 L
s
% Start of user PostScript
117.685 -21.3946 200. 2.70613 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .16229 Mdot
.039 .916 .04 r
.5 Mabswid
.59137 .08887 m
.97619 .15206 L
s
% Start of user PostScript
119.189 -12.7124 200. 0.557059 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .15206 Mdot
.039 .916 .04 r
.5 Mabswid
.59481 .12932 m
.97619 .14958 L
s
% Start of user PostScript
119.911 -4.21762 200. 0.0362076 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .14958 Mdot
.039 .916 .04 r
.5 Mabswid
.59481 .16949 m
.97619 .14923 L
s
% Start of user PostScript
119.911 4.21762 200. -0.0362076 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .14923 Mdot
.039 .916 .04 r
.5 Mabswid
.59137 .20994 m
.97619 .14675 L
s
% Start of user PostScript
119.189 12.7124 200. -0.557059 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .14675 Mdot
.039 .916 .04 r
.5 Mabswid
.58421 .25128 m
.97619 .13652 L
s
% Start of user PostScript
117.685 21.3946 200. -2.70613 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .13652 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool009?ooooo4ol0001Yoooo
o`03o`000?oooooooooo00kooooo002:ooooo`?o2NX:1_ooool6o`0000;o2NX:2ol0001Yooooo`03
o`000?oooooooooo00kooooo002;ooooo`Ko2NX:00?oooooo`000?l000001OmoOgl8o`WZ2P05o`00
0?moOgooOgmoogmoOol00000JOooool00ol0003oooooooooo`0>ooooo`003ooooonFo`WZ2P;o0000
J?ooool00ol0003oooooooooo`0>ooooo`00Roooool5o`WZ2P;ooooo2?l0000;o`WZ2P04o`000?l9
jP[o2NX:o`WZ2VKooooo00?o0000ooooooooool03_ooool008[ooooo0_l9jPX6ooooo`;o00001Omo
Ogl4o`WZ2P;oOgmo1Ol9jPX00omoOgoo0000o`000002ooooo`?o2NX:Hoooool00ol0003ooooooooo
o`0>ooooo`00T_ooool2o`0000[oOgmo0_l9jPX00omoOgoo0000o`000002ogmoO`;o00001Oooool3
o`WZ2V3ooooo00?o0000ooooooooool03_ooool009;ooooo0_l0000=ogmoO`;o00000_moOgl2o`00
00Sooooo1?l9jPYLooooo`03o`000?oooooooooo00kooooo002Aooooo`03o`000?moOgoo000000go
Ogmo0_l00002ogmoO`03o`000?moOgoo000000_ooooo0ol9jPYIooooo`03o`000?oooooooooo00ko
oooo002Aooooo`03o`000?moOgoo000001;o000000?oOgmoo`000?ooool03Oooool4o`WZ2UGooooo
00?o0000ooooooooool03_ooool0097ooooo00?o0000ogmoOol000003OmoOgl2o`0000;oOgmo00?o
0000ogmoOol000004_ooool3o`WZ2U;ooooo00?o0000ooooooooool03_ooool0097ooooo00?o0000
ogmoOol000003OmoOgl2o`0000;oOgmo00?o0000ogmoOol000005Oooool3o`WZ2Toooooo00?o0000
ooooooooool03_ooool008Sooooo0ol9jPX6ooooo`03o`000?moOgoo000000goOgmo0_l00002ogmo
O`03o`000?moOgoo000001Sooooo1?l9jPY;ooooo`03o`000?oooooooooo00kooooo0029ooooo`Ko
2NX:0_ooool00ol0003oOgmoo`000006ogmoO`?o2NX:0omoOgl3o`WZ2P;oOgmo00?o0000ogmoOol0
00007?ooool3o`WZ2TSooooo00?o0000ooooooooool03_ooool000ooooooRol9jPX00omoOgoo2NX:
o`WZ2P0:o`WZ2P03o`000?oooooooooo01gooooo1?l9jPY4ooooo`03o`000?oooooooooo00kooooo
0029ooooo`Go2NX:0_ooool2o`000003ogmoOol0003oOgmo00GoOgmo1ol9jPX00ol0003o2NX:o`WZ
2P03o`WZ2P03o`000?l9jP[o2NX:00;o2NX:7oooool3o`WZ2T7ooooo00?o0000ooooooooool03_oo
ool008Sooooo0_l9jPX6ooooo`03o`000?moOgooOgmo00So00001Ol9jPX00ol0003o2NX:o`WZ2P03
o`WZ2P03ogmoOol0003o000000?ooooo1_l9jPXLooooo`?o2NX:?_ooool00ol0003oooooooooo`0>
ooooo`00T?ooool01?l0003oOgmoogmoOol00006ogmoO`;o2NX:1?moOgl2o`WZ2P04o`000?moOgoo
Ogmoo`0000;oOgmo00?o0000ooooooooool01oooool6o`WZ2QWooooo1?l9jPXjooooo`03o`000?oo
oooooooo00kooooo002@ooooo`04o`000?moOgooOgmoo`0000goOgmo0_l00002ogmoO`04o`000?mo
OgooOgmoo`0000oooooo1_l9jPXGooooo`?o2NX:=oooool00ol0003oooooooooo`0>ooooo`00Sooo
ool01Ol0003oOgmoogmoOomoOgoo000000goOgmo0_l00002ogmoO`04o`000?moOgooOgmoo`0001Go
oooo1_l9jPXDooooo`Co2NX:<oooool00ol0003oooooooooo`0>ooooo`00Soooool01Ol0003oOgmo
ogmoOomoOgoo000000goOgmo0_l00002ogmoO`04o`000?moOgooOgmoo`0001_ooooo1_l9jPXBoooo
o`?o2NX:<?ooool00ol0003oooooooooo`0>ooooo`00Soooool01Ol0003oOgmoogmoOomoOgoo0000
00goOgmo0_l00002ogmoO`04o`000?moOgooOgmoo`00027ooooo1_l9jPX?ooooo`?o2NX:;Oooool0
0ol0003oooooooooo`0>ooooo`00Soooool01Ol0003oOgmoogmoOomoOgoo000000goOgmo0_l00002
ogmoO`04o`000?moOgooOgmoo`0002Oooooo1_l9jPX<ooooo`Co2NX::Oooool00ol0003ooooooooo
o`0>ooooo`00Soooool01?l0003oOgmoogmoOomoOglCo`0000;oOgmo00?o0000ooooooooool0:ooo
ool7o`WZ2PWooooo0ol9jPXVooooo`03o`000?oooooooooo00kooooo0027ooooo`?o2NX:1Oooool0
1Ol0003oOgmoogmoOomoOgoo000000KoOgmo0ol9jPX3ogmoO`?o2NX:0_moOgl01?l0003oOgmoogmo
Ool0000dooooo`Ko2NX:1_ooool3o`WZ2R?ooooo00?o0000ooooooooool03_ooool008Sooooo1_l9
jPX00ooooooo0000o`000002ogmoO`03o`000?moOgooOgmo00GoOgmo3?l9jPX00omoOgoo0000oooo
o`0iooooo`Ko2NX:0oooool4o`WZ2Qoooooo00?o0000ooooooooool03_ooool000ooooooXol9jPXg
ooooo`Ko2NX:00Coooooo`WZ2_l9jP[o2NX:7?ooool00ol0003oooooooooo`0>ooooo`00R?ooool5
o`WZ2P;ooooo00Go0000ogmoOomoOgooOgmoo`000007ogmoO`Go2NX:00?oOgmoo`WZ2_l9jPX00ol9
jPX2ogmoO`;o00002?oooolAo`WZ2Rcooooo2?l9jPXHooooo`03o`000?oooooooooo00kooooo0027
ooooo`;o2NX:1_ooool01Ol0003oOgmoogmoOomoOgoo000000KoOgmo0_l9jPX4ogmoO`;o2NX:00Co
0000ogmoOomoOgoo00000omoOgl00ol0003oooooooooo`0Goooooa7o2NX:8Oooool6o`WZ2Q3ooooo
1?l9jPX2o`0000oooooo002?ooooo`05o`000?moOgooOgmoogmoOol000003OmoOgl2o`0000;oOgmo
00Go0000ogmoOomoOgooOgmoo`00000Zoooooa7o2NX:5Oooool7o`WZ2PKooooo1ol9jPX00ooooooo
0000o`00000?ooooo`00Soooool01Ol0003oOgmoogmoOomoOgoo000000goOgmo0_l00002ogmoO`05
o`000?moOgooOgmoogmoOol00000>ooooolAo`WZ2POooooo3ol9jPX3ooooo`03o`000?oooooooooo
00kooooo002?ooooo`05o`000?moOgooOgmoogmoOol000003OmoOgl2o`0000;oOgmo00Go0000ogmo
OomoOgooOgmoo`00001<oooooaWo2NX:0_l0000?ooooo`00SooooolKo`0005Kooooo0ol9jPX00ooo
oooo2NX:o`WZ2P09o`WZ2P;o00003oooool008oooooo00Go0000ogmoOomoOgooOgmoo`00000=ogmo
O`;o00000_moOgl01Ol0003oOgmoogmoOomoOgoo000004Kooooo5_l9jPX00ooooooo2NX:o`WZ2P04
o`WZ2P;ooooo0_l0000?ooooo`00Soooool01Ol0003oOgmoogmoOomoOgoo000000goOgmo0_l00002
ogmoO`05o`000?moOgooOgmoogmoOol00000<OoooolEo`WZ2PWooooo1ol9jPX7ooooo`So2NX:00?o
0000ooooooooool03_ooool008Oooooo0ol9jPX5ooooo`05o`000?moOgooOgmoogmoOol000001_mo
Ogl3o`WZ2P?oOgmo0ol9jPX2ogmoO`05o`000?moOgooOgmoogmoOol000007OoooolDo`WZ2QWooooo
1_l9jPX=ooooo`So2NX:0_l0000?ooooo`00R?ooool6o`WZ2P03ooooool0003oOgmo00;oOgmo00?o
0000ogmoOomoOgl01OmoOgl<o`WZ2P;oOgmo00?o0000ooooooooool01_oooolEo`WZ2ROooooo2?l9
jPXIooooo`;o00003oooool000ooooooXol9jPXfooooo`Ko2NX:00Coooooo`WZ2_l9jP[o2NX:7Ooo
ool00ol0003oooooooooo`0>ooooo`00R?ooool5o`WZ2P;ooooo0_l00002ogmoO`03o`000?moOgoo
Ogmo00GoOgmo1Ol9jPX00omoOgoo2NX:o`WZ2P03o`WZ2P;oOgmo0_l0000hooooo`Ko2NX:0oooool4
o`WZ2R3ooooo00?o0000ooooooooool03_ooool008Oooooo0_l9jPX6ooooo`05o`000?moOgooOgmo
ogmoOol000001_moOgl2o`WZ2PCoOgmo0_l9jPX01?l0003oOgmoogmoOol00002ogmoO`03o`000?oo
oooooooo033ooooo1ol9jPX6ooooo`?o2NX:9?ooool00ol0003oooooooooo`0>ooooo`00Soooool0
1?l0003oOgmoogmoOomoOglCo`0000;oOgmo00?o0000ooooooooool0:_ooool6o`WZ2P[ooooo0ol9
jPXWooooo`03o`000?oooooooooo00kooooo002?ooooo`05o`000?moOgooOgmoogmoOol000003Omo
Ogl2o`0000;oOgmo00Co0000ogmoOomoOgoo00009_ooool6o`WZ2Pcooooo1?l9jPXZooooo`03o`00
0?oooooooooo00kooooo002?ooooo`05o`000?moOgooOgmoogmoOol000003OmoOgl2o`0000;oOgmo
00Co0000ogmoOomoOgoo00008?ooool6o`WZ2Poooooo0ol9jPX^ooooo`03o`000?oooooooooo00ko
oooo002?ooooo`05o`000?moOgooOgmoogmoOol000003OmoOgl2o`0000;oOgmo00Co0000ogmoOomo
Ogoo00006_ooool6o`WZ2Q7ooooo1?l9jPXaooooo`03o`000?oooooooooo00kooooo002?ooooo`05
o`000?moOgooOgmoogmoOol000003OmoOgl2o`0000;oOgmo00Co0000ogmoOomoOgoo00005?ooool6
o`WZ2QCooooo0ol9jPXeooooo`03o`000?oooooooooo00kooooo002?ooooo`05o`000?moOgooOgmo
ogmoOol000003OmoOgl2o`0000;oOgmo00Co0000ogmoOomoOgoo00003_ooool6o`WZ2QOooooo0ol9
jPXhooooo`03o`000?oooooooooo00kooooo002@ooooo`04o`000?moOgooOgmoo`0000coOgmo0ol9
jPX2ogmoO`04o`000?moOgooOgmoo`0000Sooooo1_l9jPXIooooo`Co2NX:>oooool00ol0003ooooo
ooooo`0>ooooo`00R?ooool3o`WZ2PGooooo00Co0000ogmoOomoOgoo00001_moOgl5o`WZ2P;oOgmo
1_l9jPX01?moOgoo0000ooooooooool6o`WZ2Qcooooo0ol9jPXoooooo`03o`000?oooooooooo00ko
oooo0029ooooo`Ko2NX:00Coooooo`000?moOgooOgmo1_l00008o`WZ2P03o`000?l9jP[o2NX:00?o
2NX:00Co0000o`WZ2_l9jP[o2NX:7oooool3o`WZ2T;ooooo00?o0000ooooooooool03_ooool000oo
ooooR_l9jPX3ogmoO`[o2NX:00?oOgmoo`000?l000007Oooool4o`WZ2TGooooo00?o0000oooooooo
ool03_ooool008Wooooo1Ol9jPX2ooooo`;o000000?oOgmoo`000?moOgl01_moOgl3o`WZ2P;oOgmo
0_l9jPX01_l0003oOgmoogmoOol0003oOgmoo`0001_ooooo0ol9jPY9ooooo`03o`000?oooooooooo
00kooooo0028ooooo`;o2NX:1oooool00ol0003oOgmoo`000006ogmoO`03o`WZ2_moOgooOgmo00Co
Ogmo0_l00002ogmoO`03o`000?moOgoo000001Oooooo1?l9jPY<ooooo`03o`000?oooooooooo00ko
oooo002Aooooo`03o`000?moOgoo000000goOgmo0_l00002ogmoO`03o`000?moOgoo000001Cooooo
0ol9jPY@ooooo`03o`000?oooooooooo00kooooo002Aooooo`03o`000?moOgoo000000goOgmo0_l0
0002ogmoO`03o`000?moOgoo0000017ooooo0ol9jPYCooooo`03o`000?oooooooooo00kooooo002A
ooooo`03o`000?moOgoo000001;o000000?oOgmoo`000?ooool03?ooool4o`WZ2UKooooo00?o0000
ooooooooool03_ooool0097ooooo00?o0000ogmoOol000003OmoOgl2o`0000;oOgmo00?o0000ogmo
Ool000002_ooool3o`WZ2U[ooooo00?o0000ooooooooool03_ooool0097ooooo00?o0000ogmoOol0
00003OmoOgl2o`0000;oOgmo00?o0000ogmoOol000001_ooool4o`WZ2Ugooooo00?o0000oooooooo
ool03_ooool009;ooooo0_l0000=ogmoO`;o00000_moOgl2o`0000Cooooo0ol9jPYQooooo`03o`00
0?oooooooooo00kooooo002Booooo`;o00001OmoOgl:o`WZ2P;oOgmo0_l000001?oooooo2NX:o`WZ
2_l9jPYTooooo`03o`000?oooooooooo00kooooo002:ooooo`?o2NX:1Oooool8o`0000_o2NX:00?o
0000o`WZ2_l9jPX0Ioooool00ol0003oooooooooo`0>ooooo`00Roooool6o`WZ2P03ooooool0003o
000000;oOgmo3ol9jPX2o`0006Sooooo00?o0000ooooooooool03_ooool000ooooooQol9jPX4ogmo
O`?o2NX:0_moOgl3o`WZ2P?oOgmo0_l0001Xooooo`03o`000?oooooooooo00kooooo002;ooooo`Go
2NX:0oooool00ol0003oOgmoogmoO`03ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00Co2NX:ogmoOomo
Ogoo00000omoOgl00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00kooooo002:ooooo`;o
2NX:1ooooolCo`0006Wooooo00?o0000ooooooooool03_ooool009?ooooo4ol0001Yooooo`03o`00
0?oooooooooo00kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelRefractiveIndex[BK7][WaveLength->.532]", "Input",
  CellLabel->"In[92]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(1.5194724325673066`\)], "Output",
  CellLabel->"Out[92]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModelRefractiveIndex[SF11][WaveLength->.532]", "Input",
  CellLabel->"In[93]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(1.7947952231863677`\)], "Output",
  CellLabel->"Out[93]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?Rationalize", "Input",
  CellLabel->"In[94]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    RowBox[{"\<\"Rationalize[x] takes Real numbers in x that are close to \
rationals, and converts them to exact Rational numbers. Rationalize[x, dx] \
performs the conversion whenever the error made is smaller in magnitude than \
dx.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"Rationalize",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->{
  "Info3312042947-9251066", "AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Rationalize[ModelRefractiveIndex[SF11][WaveLength->.532],.02]\
\>", "Input",
  CellLabel->"In[95]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(9\/5\)], "Output",
  CellLabel->"Out[95]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rationalize[ModelRefractiveIndex[BK7][WaveLength->.532],.02]", "Input",
  CellLabel->"In[96]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(3\/2\)], "Output",
  CellLabel->"Out[96]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell["\<\
Py = (SymbolicRayEnd/. 
\tSymbolicTrace[opticalsystem,{{y,0,3},{c1>0,c2<0,c3<0,y\[Element]Reals}}, \
NormalizeSurfaceNormal->False, ReportedParameters->SymbolicRayEnd, \
RunningCommentary->All, Simplify->True, FinalFormat->False,
\tSymbolicRefractiveModels->{BK7->3/2, SF11->9/5}])[[2]];\
\>", "Input",
  CellLabel->"In[97]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[CellGroupData[{

Cell["ByteCount[Py]", "Input",
  CellLabel->"In[98]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(4096\)], "Output",
  CellLabel->"Out[98]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Py//InputForm", "Input",
  CellLabel->"In[99]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell["\<\
y*(1. - 0.8333333333333331*c2 + c1*(-6.385445898048419 + \
4.164421237857663*c2) + c2*(-23.99353490705878 - 53.30100786862726*c3) + \
63.961209442352725*c3 + 
  c1*(-39.96767453529393 - 408.42084246788704*c3 + c2*(119.90302360588177 + \
266.3614190007958*c3)) + 
  (-79.9515118029409*c2*(-0.0017089009379546 + c3)*c3*(0.48764285560680765 + \
c3) + 66.62625983578405*c2^2*(0.007971515150067884 + c3)*(0.20283168300952217 \
+ c3)*(0.7735647111781162 + c3) + 
    c3^2*(-0.39975755901470456 + 31.980604721176363*c3) - \
18.5072943988289*c2^3*(0.5169292315766226 + c3)*(1.2975315262148452 + \
0.7658726324299371*c3 + c3^2) + 
    c1*(-612.6312637018306*(-0.0018540657824575426 + \
c3)*c3*(0.09770927331916474 + c3) + \
1420.5942346709107*c2*(-0.0008775492072184491 + c3)*(0.042660433177280084 + \
c3)*(0.5220313761158 + c3) - 
      1091.3419250727047*c2^2*(-0.028920975829296026 + \
c3)*(0.24057370655264448 + c3)*(0.8093056267501366 + c3) + \
277.4598114591622*c2^3*(0.5169292315766226 + c3)*
       (1.297531526214845 + 0.7658726324299366*c3 + c3^2)) + \
c1^2*(3911.923789821072*(0.009138592301390268 + c3)*(0.02786745725476436 + \
c3)*(0.1672043655172598 + c3) + 
      5915.952801241696*c2^2*(-0.05172453852830349 + c3)*(0.2630887177228902 \
+ c3)*(0.840467368893461 + c3) - 8362.445782588522*c2*(0.5558346769858834 + \
c3)*
       (0.0021322577247055046 + 0.0794664514099874*c3 + c3^2) - \
1386.5514377910222*c2^3*(0.5169292315766221 + c3)*(1.2975315262148461 + \
0.7658726324299368*c3 + c3^2)) + 
    c1^3*(-10624.499029050985*c2^2*(-0.0305711690535631 + \
c3)*(0.25638873105418436 + c3)*(0.852412801250604 + c3) - \
8326.459239063663*(0.19890623747890349 + c3)*
       (0.01399394675838518 + 0.11160464690486825*c3 + c3^2) + \
16290.898511211512*c2*(0.550657007706981 + c3)*(0.010673489313858552 + \
0.14883676342155*c3 + c3^2) + 
      2309.6737019676048*c2^3*(0.5169292315766224 + c3)*(1.2975315262148457 + \
0.7658726324299371*c3 + c3^2)))*y^2)\
\>", "Output",
  CellLabel->"Out[99]//InputForm=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[meritFunction=ExpandAll[Integrate[Py^2,{y,-5,5}]];][[1]]\
\>", "Input",
  CellLabel->"In[100]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(38.71000000000001`\ Second\)], "Output",
  CellLabel->"Out[100]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ByteCount[meritFunction]", "Input",
  CellLabel->"In[101]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(43708\)], "Output",
  CellLabel->"Out[101]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["meritFunction//InputForm", "Input",
  CellLabel->"In[102]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell["\<\
83.33333333333333 - 7725.520072223724*c1 + 179467.42328278074*c1^2 - \
77244.79245903643*c1^3 + 2.686384088965151*^6*c1^4 - 172351.7135478436*c1^5 + \
1.1990021059754131*^7*c1^6 - 
 4137.811373398686*c2 + 212408.9693749286*c1*c2 - 990384.8241276548*c1^2*c2 + \
2.877853121571819*^6*c1^3*c2 - 1.832924021410707*^7*c1^4*c2 + \
1.0966652503587645*^7*c1^5*c2 - 
 9.906804433304237*^7*c1^6*c2 + 51572.782218815875*c2^2 - \
505938.4792684064*c1*c2^2 + 1.0086273901604646*^6*c1^2*c2^2 - \
1.0268587890209488*^6*c1^3*c2^2 + 1.6684772775022842*^7*c1^4*c2^2 + 
 2.817089520420558*^7*c1^5*c2^2 + 1.3119207727802566*^8*c1^6*c2^2 - \
36205.8495172385*c2^3 + 1.548086693855232*^6*c1*c2^3 - \
1.7922109105472267*^7*c1^2*c2^3 + 9.820077896997187*^7*c1^3*c2^3 - 
 3.008567653501071*^8*c1^4*c2^3 + 6.531375734981651*^8*c1^5*c2^3 - \
1.2994516382756152*^9*c1^6*c2^3 + 770621.7432028732*c2^4 - \
1.5362783655369086*^7*c1*c2^4 + 1.2129844142151959*^8*c1^2*c2^4 - 
 5.371592311617185*^8*c1^3*c2^4 + 1.8072237355127683*^9*c1^4*c2^4 - \
4.875158776606653*^9*c1^5*c2^4 + 6.73440111955497*^9*c1^6*c2^4 - \
46180.930506681754*c2^5 - 2.7131400739199156*^6*c1*c2^5 + 
 8.509113756155948*^7*c1^2*c2^5 - 8.508519403212641*^8*c1^3*c2^5 + \
3.823942437314061*^9*c1^4*c2^5 - 7.626641205205066*^9*c1^5*c2^5 + \
4.909316428643413*^9*c1^6*c2^5 + 3.4395836307242787*^6*c2^6 - 
 1.0313190087246548*^8*c1*c2^6 + 1.28845403488178*^9*c1^2*c2^6 - \
8.585064554984132*^9*c1^3*c2^6 + 3.217664264503948*^10*c1^4*c2^6 - \
6.431860511710032*^10*c1^5*c2^6 + 
 5.356995302780664*^10*c1^6*c2^6 + 10660.201573725453*c3 - \
561926.2879904569*c1*c3 + 3.232042333179159*^6*c1^2*c3 - \
7.54908270463919*^6*c1^3*c3 + 5.8659256157446004*^7*c1^4*c3 - 
 2.8316283716550138*^7*c1^5*c3 + 3.118053702644916*^8*c1^6*c3 - \
273376.3555487509*c2*c3 + 3.5270072652928173*^6*c1*c2*c3 - \
1.8163712023192946*^7*c1^2*c2*c3 + 1.0387401599868505*^8*c1^3*c2*c3 - 
 4.267297179618991*^8*c1^4*c2*c3 + 6.529090244318188*^8*c1^5*c2*c3 - \
2.8495182332229667*^9*c1^6*c2*c3 + 257170.6274145298*c2^2*c3 - \
4.921858767786396*^6*c1*c2^2*c3 + 
 4.669001802120763*^7*c1^2*c2^2*c3 - 2.901936267208843*^8*c1^3*c2^2*c3 + \
1.022685816112428*^9*c1^4*c2^2*c3 - 2.3512932946217184*^9*c1^5*c2^2*c3 + \
7.525267614801429*^9*c1^6*c2^2*c3 - 
 2.755184192395447*^6*c2^3*c3 + 6.106903637952671*^7*c1*c2^3*c3 - \
5.1286435120359313*^8*c1^2*c2^3*c3 + 2.1863328565487666*^9*c1^3*c2^3*c3 - \
6.154170340105774*^9*c1^4*c2^3*c3 + 
 1.5944062341812832*^10*c1^5*c2^3*c3 - 2.8492292033634136*^10*c1^6*c2^3*c3 + \
3.603258448096*^6*c2^4*c3 - 8.615513250476956*^7*c1*c2^4*c3 + \
9.426746241244583*^8*c1^2*c2^4*c3 - 
 6.633128882906318*^9*c1^3*c2^4*c3 + 3.2001849285345905*^10*c1^4*c2^4*c3 - \
9.219747786670241*^10*c1^5*c2^4*c3 + 1.1486681236666006*^11*c1^6*c2^4*c3 - \
6.197219187493397*^6*c2^5*c3 + 
 1.8369785950465462*^8*c1*c2^5*c3 - 2.2685185092057443*^9*c1^2*c2^5*c3 + \
1.5206329953466343*^10*c1^3*c2^5*c3 - 5.9338406067303085*^10*c1^4*c2^5*c3 + \
1.2931062340317773*^11*c1^5*c2^5*c3 - 
 1.2328440240524448*^11*c1^6*c2^5*c3 + 1.7368207534800593*^7*c2^6*c3 - \
5.2076543271439034*^8*c1*c2^6*c3 + 6.50605988381383*^9*c1^2*c2^6*c3 - \
4.335035832788493*^10*c1^3*c2^6*c3 + 
 1.624762376004455*^11*c1^4*c2^6*c3 - 3.2477735736504156*^11*c1^5*c2^6*c3 + \
2.7050194491725345*^11*c1^6*c2^6*c3 + 339920.29887983925*c3^2 - \
4.4365865591270365*^6*c1*c3^2 + 
 2.6616648285585493*^7*c1^2*c3^2 - 1.7285563214606816*^8*c1^3*c3^2 + \
6.866960902507284*^8*c1^4*c3^2 - 1.1848255367861927*^9*c1^5*c3^2 + \
4.70224481602699*^9*c1^6*c3^2 - 629861.8127289944*c2*c3^2 + 
 2.1357319956643984*^7*c1*c2*c3^2 - 2.8862047090173084*^8*c1^2*c2*c3^2 + \
1.8474059925133746*^9*c1^3*c2*c3^2 - 6.177751732729872*^9*c1^4*c2*c3^2 + \
1.7047245294845005*^10*c1^5*c2*c3^2 - 
 4.314392694858968*^10*c1^6*c2*c3^2 + 4.55635698327138*^6*c2^2*c3^2 - \
1.1860743021115477*^8*c1*c2^2*c3^2 + 1.1756655133946195*^9*c1^2*c2^2*c3^2 - \
5.947476723052926*^9*c1^3*c2^2*c3^2 + 
 2.0446201743547565*^10*c1^4*c2^2*c3^2 - 6.528121134630501*^10*c1^5*c2^2*c3^2 \
+ 1.2959353641169475*^11*c1^6*c2^2*c3^2 - 1.0493986835673371*^7*c2^3*c3^2 + \
2.6740229931503546*^8*c1*c2^3*c3^2 - 
 2.9733098654365163*^9*c1^2*c2^3*c3^2 + 2.021279641666957*^10*c1^3*c2^3*c3^2 \
- 9.458579618924527*^10*c1^4*c2^3*c3^2 + \
2.8014186238640594*^11*c1^5*c2^3*c3^2 - 3.795151684822233*^11*c1^6*c2^3*c3^2 \
+ 
 3.0018147354434848*^7*c2^4*c3^2 - 9.954338473361474*^8*c1*c2^4*c3^2 + \
1.3964445468930927*^10*c1^2*c2^4*c3^2 - 1.064279825807562*^11*c1^3*c2^4*c3^2 \
+ 4.6536821418298663*^11*c1^4*c2^4*c3^2 - 
 1.1059116472581458*^12*c1^5*c2^4*c3^2 + 1.113866914082069*^12*c1^6*c2^4*c3^2 \
- 5.178558258595619*^7*c2^5*c3^2 + 1.638247097835697*^9*c1*c2^5*c3^2 - \
2.153543748403822*^10*c1^2*c2^5*c3^2 + 
 1.5103063055335773*^11*c1^3*c2^5*c3^2 - 5.974594786251178*^11*c1^4*c2^5*c3^2 \
+ 1.2664737386600254*^12*c1^5*c2^5*c3^2 - \
1.1254345721407913*^12*c1^6*c2^5*c3^2 + 3.508191276491249*^7*c2^6*c3^2 - 
 1.0518902105966748*^9*c1*c2^6*c3^2 + 1.3141541798710089*^10*c1^2*c2^6*c3^2 - \
8.756306522358801*^10*c1^3*c2^6*c3^2 + 3.2818453962212317*^11*c1^4*c2^6*c3^2 \
- 6.560153600346769*^11*c1^5*c2^6*c3^2 + 
 5.4638485953785016*^11*c1^6*c2^6*c3^2 + 16029.069407182913*c3^3 - \
1.4221516248009166*^7*c1*c3^3 + 2.679699296267854*^8*c1^2*c3^3 - \
1.797613696507981*^9*c1^3*c3^3 + 
 5.943738639562176*^9*c1^4*c3^3 - 1.776566664414159*^10*c1^5*c3^3 + \
4.339850126561682*^10*c1^6*c3^3 - 8.345161805281889*^6*c2*c3^3 + \
2.351038179268103*^8*c1*c2*c3^3 - 
 2.556763097958812*^9*c1^2*c2*c3^3 + 1.484041581685373*^10*c1^3*c2*c3^3 - \
6.1730200989166855*^10*c1^4*c2*c3^3 + 2.1198282836744748*^11*c1^5*c2*c3^3 - \
3.799324303120444*^11*c1^6*c2*c3^3 + 
 2.060074313558452*^7*c2^2*c3^3 - 5.710662387683784*^8*c1*c2^2*c3^3 + \
6.933132162419197*^9*c1^2*c2^2*c3^3 - 5.164305811038682*^10*c1^3*c2^2*c3^3 + \
2.6436742399217947*^11*c1^4*c2^2*c3^3 - 
 8.450677606308281*^11*c1^5*c2^2*c3^3 + 1.202486643400443*^12*c1^6*c2^2*c3^3 \
- 5.30139018161296*^7*c2^3*c3^3 + 1.8173228134829347*^9*c1*c2^3*c3^3 - \
2.6658534210166084*^10*c1^2*c2^3*c3^3 + 
 2.1501438516796686*^11*c1^3*c2^3*c3^3 - \
1.0065036020618214*^12*c1^4*c2^3*c3^3 + 2.5859417316610435*^12*c1^5*c2^3*c3^3 \
- 2.833116754128015*^12*c1^6*c2^3*c3^3 + 1.3528095960521603*^8*c2^4*c3^3 - 
 4.561656737135868*^9*c1*c2^4*c3^3 + 6.394470239371801*^10*c1^2*c2^4*c3^3 - \
4.7804553226309796*^11*c1^3*c2^4*c3^3 + 2.0145013786973215*^12*c1^4*c2^4*c3^3 \
- 4.545281498309997*^12*c1^5*c2^4*c3^3 + 
 4.2955378831305464*^12*c1^6*c2^4*c3^3 - 1.4038328886608866*^8*c2^5*c3^3 + \
4.453359477695695*^9*c1*c2^5*c3^3 - 5.868697984160185*^10*c1^2*c2^5*c3^3 + \
4.116783021460412*^11*c1^3*c2^5*c3^3 - 
 1.6227309804615405*^12*c1^4*c2^5*c3^3 + \
3.4103653698807036*^12*c1^5*c2^5*c3^3 - 2.9872371843791484*^12*c1^6*c2^5*c3^3 \
+ 4.347360399890937*^7*c2^6*c3^3 - 1.3035052784107587*^9*c1*c2^6*c3^3 + 
 1.6285035195219995*^10*c1^2*c2^6*c3^3 - \
1.0850839428197389*^11*c1^3*c2^6*c3^3 + 4.066871954703166*^11*c1^4*c2^6*c3^3 \
- 8.129360611110518*^11*c1^5*c2^6*c3^3 + 
 6.770816395822441*^11*c1^6*c2^6*c3^3 + 5.11736249224076*^6*c3^4 - \
1.2940899742885114*^8*c1*c3^4 + 1.3467206530712311*^9*c1^2*c3^4 - \
8.473966072647891*^9*c1^3*c3^4 + 
 4.212661300460848*^10*c1^4*c3^4 - 1.5420246310297424*^11*c1^5*c3^4 + \
2.612293075165982*^11*c1^6*c3^4 - 1.6257511840092458*^7*c2*c3^4 + \
5.412254600477614*^8*c1*c2*c3^4 - 
 8.577515557890011*^9*c1^2*c2*c3^4 + 8.238513448531758*^10*c1^3*c2*c3^4 - \
4.827974475520635*^11*c1^4*c2*c3^4 + 1.5578972891303337*^12*c1^5*c2*c3^4 - \
2.095388335895248*^12*c1^6*c2*c3^4 + 
 6.925691332739684*^7*c2^2*c3^4 - 2.6883150522065763*^9*c1*c2^2*c3^4 + \
4.439884591471104*^10*c1^2*c2^2*c3^4 - 3.9690004109212604*^11*c1^3*c2^2*c3^4 \
+ 2.01355666309574*^12*c1^4*c2^2*c3^4 - 
 5.4692924431941*^12*c1^5*c2^2*c3^4 + 6.190452662809575*^12*c1^6*c2^2*c3^4 - \
2.0887671880898958*^8*c2^3*c3^4 + 7.539209481791954*^9*c1*c2^3*c3^4 - \
1.1322701335249127*^11*c1^2*c2^3*c3^4 + 
 9.062118007933304*^11*c1^3*c2^3*c3^4 - 4.0785453195595693*^12*c1^4*c2^3*c3^4 \
+ 9.790989007273338*^12*c1^5*c2^3*c3^4 - 9.797230617841871*^12*c1^6*c2^3*c3^4 \
+ 2.841011380977121*^8*c2^4*c3^4 - 
 9.53526046182426*^9*c1*c2^4*c3^4 + 1.3284284920609125*^11*c1^2*c2^4*c3^4 - \
9.842365899214786*^11*c1^3*c2^4*c3^4 + 4.093656706140883*^12*c1^4*c2^4*c3^4 - \
9.06944990355551*^12*c1^5*c2^4*c3^4 + 
 8.367233517685572*^12*c1^6*c2^4*c3^4 - 1.7179713794516996*^8*c2^5*c3^4 + \
5.4316208750132885*^9*c1*c2^5*c3^4 - 7.136283501189009*^10*c1^2*c2^5*c3^4 + \
4.990275429780605*^11*c1^3*c2^5*c3^4 - 
 1.9599143374877312*^12*c1^4*c2^5*c3^4 + \
4.1008762635135396*^12*c1^5*c2^5*c3^4 - 3.572678824220341*^12*c1^6*c2^5*c3^4 \
+ 3.8475751613931306*^7*c2^6*c3^4 - 1.1536505075778613*^9*c1*c2^6*c3^4 + 
 1.4412860024467558*^10*c1^2*c2^6*c3^4 - 9.603395261465988*^10*c1^3*c2^6*c3^4 \
+ 3.5993324864151556*^11*c1^4*c2^6*c3^4 - \
7.194785591298389*^11*c1^5*c2^6*c3^4 + 
 5.992423583647064*^11*c1^6*c2^6*c3^4 - 570736.0928192678*c3^5 - \
7.29072212817693*^7*c1*c3^5 + 2.6767927963567743*^9*c1^2*c3^5 - \
3.564657151210681*^10*c1^3*c3^5 + 
 2.3205158920013574*^11*c1^4*c3^5 - 7.484708095843163*^11*c1^5*c3^5 + \
9.610578503463467*^11*c1^6*c3^5 - 5.404116909913511*^7*c2*c3^5 + \
2.3903352382702436*^9*c1*c2*c3^5 - 
 4.2701901027519356*^10*c1^2*c2*c3^5 + 3.974114470350878*^11*c1^3*c2*c3^5 - \
2.0420962630364282*^12*c1^4*c2*c3^5 + 5.511090147081978*^12*c1^5*c2*c3^5 - \
6.116187006466256*^12*c1^6*c2*c3^5 + 
 2.3111670554659694*^8*c2^2*c3^5 - 8.862401862039667*^9*c1*c2^2*c3^5 + \
1.4020484628226752*^11*c1^2*c2^2*c3^5 - 1.1723047132665042*^12*c1^3*c2^2*c3^5 \
+ 5.467531887689922*^12*c1^4*c2^2*c3^5 - 
 1.3493307841533984*^13*c1^5*c2^2*c3^5 + \
1.3772109559723006*^13*c1^6*c2^2*c3^5 - 3.8321278669981676*^8*c2^3*c3^5 + \
1.3612498971470133*^10*c1*c2^3*c3^5 - 2.0022543260992398*^11*c1^2*c2^3*c3^5 + \

 1.5613596632552058*^12*c1^3*c2^3*c3^5 - 6.809568025665291*^12*c1^4*c2^3*c3^5 \
+ 1.575260232515778*^13*c1^5*c2^3*c3^5 - \
1.5104233003475846*^13*c1^6*c2^3*c3^5 + 3.119125293745963*^8*c2^4*c3^5 - 
 1.0428474965370953*^10*c1*c2^4*c3^5 + 1.4461452643130386*^11*c1^2*c2^4*c3^5 \
- 1.064943657528863*^12*c1^3*c2^4*c3^5 + 4.393389680376872*^12*c1^4*c2^4*c3^5 \
- 9.629761363676475*^12*c1^5*c2^4*c3^5 + 
 8.763293975809722*^12*c1^6*c2^4*c3^5 - 1.2480281811308348*^8*c2^5*c3^5 + \
3.948303808072467*^9*c1*c2^5*c3^5 - 5.190377345869161*^10*c1^2*c2^5*c3^5 + \
3.630065773632401*^11*c1^3*c2^5*c3^5 - 
 1.424885981885035*^12*c1^4*c2^5*c3^5 + 2.976856685347068*^12*c1^5*c2^5*c3^5 \
- 2.586503005541738*^12*c1^6*c2^5*c3^5 + 1.9615411836751346*^7*c2^6*c3^5 - \
5.881452310245018*^8*c1*c2^6*c3^5 + 
 7.347853473069412*^9*c1^2*c2^6*c3^5 - 4.895929128946633*^10*c1^3*c2^6*c3^5 + \
1.8349840119268198*^11*c1^4*c2^6*c3^5 - 3.667990267390709*^11*c1^5*c2^6*c3^5 \
+ 3.055011313955417*^11*c1^6*c2^6*c3^5 + 
 2.2829443712770708*^7*c3^6 - 8.74657066262634*^8*c1*c3^6 + \
1.3962688439914501*^10*c1^2*c3^6 - 1.1887732216584016*^11*c1^3*c3^6 + \
5.693135318961332*^11*c1^4*c3^6 - 
 1.4541283027798484*^12*c1^5*c3^6 + 1.5475429343702817*^12*c1^6*c3^6 - \
1.1414721856385353*^8*c2*c3^6 + 4.214832964236605*^9*c1*c2*c3^6 - \
6.475449711264695*^10*c1^2*c2*c3^6 + 
 5.2977937052167883*^11*c1^3*c2*c3^6 - 2.434021621874772*^12*c1^4*c2*c3^6 + \
5.9534963121059*^12*c1^5*c2*c3^6 - 6.05560278666632*^12*c1^6*c2*c3^6 + \
2.3780670534136152*^8*c2^2*c3^6 - 
 8.450792910750084*^9*c1*c2^2*c3^6 + 1.2482397116653235*^11*c1^2*c2^2*c3^6 - \
9.808128148134647*^11*c1^3*c2^2*c3^6 + 4.323512368750169*^12*c1^4*c2^2*c3^6 - \
1.0136291335540053*^13*c1^5*c2^2*c3^6 + 
 9.87326541304291*^12*c1^6*c2^2*c3^6 - 2.642296726015127*^8*c2^3*c3^6 + \
9.022982014082117*^9*c1*c2^3*c3^6 - 1.2800108643851454*^11*c1^2*c2^3*c3^6 + \
9.655407994743712*^11*c1^3*c2^3*c3^6 - 
 4.084517716372149*^12*c1^4*c2^3*c3^6 + 9.187648004947873*^12*c1^5*c2^3*c3^6 \
- 8.585448185254704*^12*c1^6*c2^3*c3^6 + 1.651435453759454*^8*c2^4*c3^6 - \
5.410121329581757*^9*c1*c2^4*c3^6 + 
 7.363626541833797*^10*c1^2*c2^4*c3^6 - 5.330504428334047*^11*c1^3*c2^4*c3^6 \
+ 2.1647477676009907*^12*c1^4*c2^4*c3^6 - \
4.676639493504751*^12*c1^5*c2^4*c3^6 + 4.199404003657192*^12*c1^6*c2^4*c3^6 - \

 5.504784845864844*^7*c2^5*c3^6 + 1.726959633454063*^9*c1*c2^5*c3^6 - \
2.253002416429701*^10*c1^2*c2^5*c3^6 + 1.564802015954863*^11*c1^3*c2^5*c3^6 - \
6.103253617905876*^11*c1^4*c2^5*c3^6 + 
 1.2676488844486382*^12*c1^5*c2^5*c3^6 - \
1.0954966966062238*^12*c1^6*c2^5*c3^6 + 7.645534508145615*^6*c2^6*c3^6 - \
2.2924242921956587*^8*c1*c2^6*c3^6 + 2.8639861225801277*^9*c1^2*c2^6*c3^6 - 
 1.90829514140837*^10*c1^3*c2^6*c3^6 + 7.152250333483447*^10*c1^4*c2^6*c3^6 - \
1.4296791929871854*^11*c1^5*c2^6*c3^6 + \
1.190757278919808*^11*c1^6*c2^6*c3^6\
\>", "Output",
  CellLabel->"Out[102]//InputForm=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
{Max[#], Min[#], Min[Abs[#]], Apply[Plus,#], Apply[Plus,Abs[#]], \
Apply[Plus,Abs[#]]/Length[#]}&[
\t(Apply[List,meritFunction]/.{c1->.1,c2->-.1,c3->-.1})]\
\>", "Input",
  CellLabel->"In[103]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \({5619.26287990457`, \(-4436.586559127038`\), 1.1907572789198102`*^-7, 
      2285.2987329133184`, 91804.90823246459`, 
      267.6527936806548`}\)], "Output",
  CellLabel->"Out[103]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
meritFunctionTruncated = 
\tApply[Plus,Transpose[
\tSelect[
\t\tTranspose[{(Apply[List,meritFunction]/.{c1->.1,c2->-.1,c3->-.1})//N,
\t\t\tApply[List,meritFunction]}]
\t,
\t\t(Abs[#[[1]]]>300)&
\t]][[2]]];
ByteCount[meritFunctionTruncated]\
\>", "Input",
  CellLabel->"In[104]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(6352\)], "Output",
  CellLabel->"Out[105]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
{Max[#], Min[#], Min[Abs[#]], Apply[Plus,#], Apply[Plus,Abs[#]], \
Apply[Plus,Abs[#]]/Length[#]}&[
\t(Apply[List,meritFunctionTruncated]/.{c1->.1,c2->-.1,c3->-.1})]\
\>", "Input",
  CellLabel->"In[106]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \({5619.26287990457`, \(-4436.586559127038`\), 356.46571512106846`, 
      2751.132020775463`, 79709.96639157379`, 
      1306.7207605176031`}\)], "Output",
  CellLabel->"Out[106]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Dc1 = D[meritFunctionTruncated,c1];
ByteCount[Dc1]\
\>", "Input",
  CellLabel->"In[107]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(5032\)], "Output",
  CellLabel->"Out[108]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Dc2 = D[meritFunctionTruncated,c2];
ByteCount[Dc2]\
\>", "Input",
  CellLabel->"In[109]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(3688\)], "Output",
  CellLabel->"Out[110]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Dc3 = D[meritFunctionTruncated,c3];
ByteCount[Dc3]\
\>", "Input",
  CellLabel->"In[111]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(5308\)], "Output",
  CellLabel->"Out[112]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["extrema = NSolve[{Dc1==0,Dc2==0,Dc3==0},{c1,c2,c3}]", "Input",
  CellLabel->"In[113]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \({{c1 \[Rule] 0.11605067223101957`, c2 \[Rule] 152.1464811413507`, 
        c3 \[Rule] \(-1.1916478748364343`\)}, {c1 \[Rule] 
          0.11134374359634605`, c2 \[Rule] 3.736849192355781`, 
        c3 \[Rule] 
          4.085565955366433`}, {c1 \[Rule] \(-0.01335668881595145`\) - 
            0.0004905893242419922`\ \[ImaginaryI], 
        c2 \[Rule] \(-1.1176357076411152`\) + 
            0.6822595571265753`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.6925795486243478`\) + 
            0.03175930398048109`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.01335668881595145`\) + 0.0004905893242419922`\ \[ImaginaryI], 
        c2 \[Rule] \(-1.1176357076411152`\) - 
            0.6822595571265753`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.6925795486243478`\) - 
            0.03175930398048109`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.18553038362747398`\)\(\[InvisibleSpace]\)\) + 
            0.032745438859825664`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.896975792565918`\) + 
            0.38359609670068406`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.15660574961302273`\) + 
            0.254614760360328`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.18553038362747398`\)\(\[InvisibleSpace]\)\) - 
            0.032745438859825664`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.896975792565918`\) - 
            0.38359609670068406`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.15660574961302273`\) - 
            0.254614760360328`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.20002697690986404`, c2 \[Rule] 0.3400039050528301`, 
        c3 \[Rule] 
          1.0356142979711676`}, {c1 \[Rule] \(\(0.005376284054179724`\)\(\
\[InvisibleSpace]\)\) - 0.058318880893286955`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.32485702448237636`\) + 
            0.2958782617585244`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.1878777518265394`\) + 
            0.2738783648124931`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.005376284054179724`\)\(\[InvisibleSpace]\)\) + 
            0.058318880893286955`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.32485702448237636`\) - 
            0.2958782617585244`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.1878777518265394`\) - 
            0.2738783648124931`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.030894638194114227`\)\(\[InvisibleSpace]\)\) + 
            0.019729402344586183`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.34778120558002257`\)\(\[InvisibleSpace]\)\) + 
            0.3547644301403089`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.23093988524332895`\)\(\[InvisibleSpace]\)\) + 
            0.24776859849200547`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.030894638194114227`\)\(\[InvisibleSpace]\)\) - 
            0.019729402344586183`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.34778120558002257`\)\(\[InvisibleSpace]\)\) - 
            0.3547644301403089`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.23093988524332895`\)\(\[InvisibleSpace]\)\) - 
            0.24776859849200547`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.5770648919800461`\) - 0.11276053407616465`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.10564295938675117`\)\(\[InvisibleSpace]\)\) - 
            0.04139658739023207`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.12456290543427223`\) + 
            0.039058149463350775`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.5770648919800461`\) + 0.11276053407616465`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.10564295938675117`\)\(\[InvisibleSpace]\)\) + 
            0.04139658739023207`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.12456290543427223`\) - 
            0.039058149463350775`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.029942789702913565`\)\(\[InvisibleSpace]\)\) - 
            0.04567103533407544`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.004012158564002046`\)\(\[InvisibleSpace]\)\) + 
            0.21621218511511064`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.07894092275566567`\)\(\[InvisibleSpace]\)\) + 
            0.391104868330632`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.029942789702913565`\)\(\[InvisibleSpace]\)\) + 
            0.04567103533407544`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.004012158564002046`\)\(\[InvisibleSpace]\)\) - 
            0.21621218511511064`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.07894092275566567`\)\(\[InvisibleSpace]\)\) - 
            0.391104868330632`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.4272500812500844`\) + 0.06830731179289694`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.1383303164320303`\)\(\[InvisibleSpace]\)\) - 
            0.029227025499337162`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.011919186583952232`\)\(\[InvisibleSpace]\)\) + 
            
            0.12376575100318053`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.4272500812500844`\) - 0.06830731179289694`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.1383303164320303`\)\(\[InvisibleSpace]\)\) + 
            0.029227025499337162`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.011919186583952232`\)\(\[InvisibleSpace]\)\) - 
            0.12376575100318053`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.15681335339190824`\)\(\[InvisibleSpace]\)\) - 
            0.4324836634781162`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.19193022311469207`\)\(\[InvisibleSpace]\)\) + 
            0.06505038172603791`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.04338724911393518`\) + 
            0.042278226704881516`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.15681335339190824`\)\(\[InvisibleSpace]\)\) + 
            0.4324836634781162`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.19193022311469207`\)\(\[InvisibleSpace]\)\) - 
            0.06505038172603791`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.04338724911393518`\) - 
            0.042278226704881516`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.044546089612845376`, c2 \[Rule] \(-0.16501577909902385`\), 
        c3 \[Rule] \(-0.375492147728197`\)}, {c1 \[Rule] \
\(-0.031353376620653586`\) + 0.013739318161840021`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.31016159170709934`\)\(\[InvisibleSpace]\)\) + 
            0.024516648900442282`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.2385064137022972`\)\(\[InvisibleSpace]\)\) + 
            0.02939226366012157`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.031353376620653586`\) - 0.013739318161840021`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.31016159170709934`\)\(\[InvisibleSpace]\)\) - 
            0.024516648900442282`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.2385064137022972`\)\(\[InvisibleSpace]\)\) - 
            0.02939226366012157`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.011941050636503645`\) + 0.010289096877470004`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.3247103950679065`\)\(\[InvisibleSpace]\)\) + 
            0.024173073668771514`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.21482630783963144`\)\(\[InvisibleSpace]\)\) + 
            0.07054758048127661`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.011941050636503645`\) - 0.010289096877470004`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.3247103950679065`\)\(\[InvisibleSpace]\)\) - 
            0.024173073668771514`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.21482630783963144`\)\(\[InvisibleSpace]\)\) - 
            0.07054758048127661`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.37074604606734674`\) - 0.27228032604508123`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.11883722358022317`\)\(\[InvisibleSpace]\)\) - 
            0.029152037315393824`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.03863554924093647`\) - 
            0.125431902398017`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.37074604606734674`\) + 0.27228032604508123`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.11883722358022317`\)\(\[InvisibleSpace]\)\) + 
            0.029152037315393824`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.03863554924093647`\) + 
            0.125431902398017`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.07021170457437569`\) - 0.048796876059957466`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.1602287201653326`\) + 
            0.23443709208786187`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.24660830908958908`\) + 
            0.09844362005989901`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.07021170457437569`\) + 0.048796876059957466`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.1602287201653326`\) - 
            0.23443709208786187`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.24660830908958908`\) - 
            0.09844362005989901`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.03282778913023576`\)\(\[InvisibleSpace]\)\) - 
            0.2886424519064631`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.12529302937353812`\)\(\[InvisibleSpace]\)\) + 
            0.0939771439638746`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.015356487367570257`\)\(\[InvisibleSpace]\)\) + 
            0.0193778245504913`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.03282778913023576`\)\(\[InvisibleSpace]\)\) + 
            0.2886424519064631`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.12529302937353812`\)\(\[InvisibleSpace]\)\) - 
            0.0939771439638746`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.015356487367570257`\)\(\[InvisibleSpace]\)\) - 
            0.0193778245504913`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.08950769005950927`\), c2 \[Rule] \(-0.20883999919638738`\), 
        c3 \[Rule] \(-0.3391986710242362`\)}, {c1 \[Rule] \
\(\(0.03589173479033634`\)\(\[InvisibleSpace]\)\) - 
            0.019015888621303496`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.18857240429173028`\)\(\[InvisibleSpace]\)\) + 
            0.09959322086609511`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.1390611725391968`\)\(\[InvisibleSpace]\)\) + 
            0.2048148221271117`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.03589173479033634`\)\(\[InvisibleSpace]\)\) + 
            0.019015888621303496`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.18857240429173028`\)\(\[InvisibleSpace]\)\) - 
            0.09959322086609511`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.1390611725391968`\)\(\[InvisibleSpace]\)\) - 
            0.2048148221271117`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.04059476766750596`\)\(\[InvisibleSpace]\)\) - 
            0.0108436747301039`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.17852777281958152`\)\(\[InvisibleSpace]\)\) + 
            0.14361490302926674`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.09423319347871782`\)\(\[InvisibleSpace]\)\) + 
            0.20471751236304964`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.04059476766750596`\)\(\[InvisibleSpace]\)\) + 
            0.0108436747301039`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.17852777281958152`\)\(\[InvisibleSpace]\)\) - 
            0.14361490302926674`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.09423319347871782`\)\(\[InvisibleSpace]\)\) - 
            0.20471751236304964`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.3519019359638031`\)\(\[InvisibleSpace]\)\) - 
            0.2004023469075786`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.1309514820726356`\)\(\[InvisibleSpace]\)\) + 
            0.09060138112321246`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.0008786327852728261`\)\(\[InvisibleSpace]\)\) - 
            0.022297007749511565`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.3519019359638031`\)\(\[InvisibleSpace]\)\) + 
            0.2004023469075786`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.1309514820726356`\)\(\[InvisibleSpace]\)\) - 
            0.09060138112321246`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.0008786327852728261`\)\(\[InvisibleSpace]\)\) + 
            0.022297007749511565`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.40645947591439824`\)\(\[InvisibleSpace]\)\) - 
            0.13450260116594143`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.1867838383202802`\)\(\[InvisibleSpace]\)\) + 
            0.09809625197605656`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.04400025779699009`\) - 
            0.03586885819370537`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.40645947591439824`\)\(\[InvisibleSpace]\)\) + 
            0.13450260116594143`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.1867838383202802`\)\(\[InvisibleSpace]\)\) - 
            0.09809625197605656`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.04400025779699009`\) + 
            0.03586885819370537`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.12407016391768806`\)\(\[InvisibleSpace]\)\) + 
            0.020061299713650366`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.2095146414551641`\) + 
            0.2823292515957024`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.04004054561971837`\)\(\[InvisibleSpace]\)\) + 
            0.007081218388871733`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.12407016391768806`\)\(\[InvisibleSpace]\)\) - 
            0.020061299713650366`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.2095146414551641`\) - 
            0.2823292515957024`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.04004054561971837`\)\(\[InvisibleSpace]\)\) - 
            0.007081218388871733`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.07879022894934605`\) - 0.20946087560595644`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.0795800296520508`\)\(\[InvisibleSpace]\)\) + 
            0.038457211217585455`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.015696876612557215`\)\(\[InvisibleSpace]\)\) + 
            0.04445055227218833`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.07879022894934605`\) + 0.20946087560595644`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.0795800296520508`\)\(\[InvisibleSpace]\)\) - 
            0.038457211217585455`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.015696876612557215`\)\(\[InvisibleSpace]\)\) - 
            0.04445055227218833`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.05218675586877097`\)\(\[InvisibleSpace]\)\) - 
            0.15454407043052196`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.10219614448801347`\)\(\[InvisibleSpace]\)\) + 
            0.11409034683827161`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.08311453014011277`\) + 
            0.07800828689054994`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.05218675586877097`\)\(\[InvisibleSpace]\)\) + 
            0.15454407043052196`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.10219614448801347`\)\(\[InvisibleSpace]\)\) - 
            0.11409034683827161`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.08311453014011277`\) - 
            0.07800828689054994`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.011601313000122173`\)\(\[InvisibleSpace]\)\) + 
            0.00554455740249026`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.2158412620324206`\)\(\[InvisibleSpace]\)\) + 
            0.08069921729004834`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.11174866575601576`\)\(\[InvisibleSpace]\)\) + 
            0.1357670363706165`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.011601313000122173`\)\(\[InvisibleSpace]\)\) - 
            0.00554455740249026`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.2158412620324206`\)\(\[InvisibleSpace]\)\) - 
            0.08069921729004834`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.11174866575601576`\)\(\[InvisibleSpace]\)\) - 
            0.1357670363706165`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.0425750701043578`\) + 0.04108484218164996`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.18809955965819325`\)\(\[InvisibleSpace]\)\) + 
            0.19953299893821272`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.10932324781092526`\)\(\[InvisibleSpace]\)\) - 
            0.011353952970851061`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.0425750701043578`\) - 0.04108484218164996`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.18809955965819325`\)\(\[InvisibleSpace]\)\) - 
            0.19953299893821272`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.10932324781092526`\)\(\[InvisibleSpace]\)\) + 
            0.011353952970851061`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.01690387554114329`\) - 0.10865246669319796`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.12148658159948557`\) + 
            0.028954579679561363`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.041405886216296144`\) + 
            0.15088905069309033`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.01690387554114329`\) + 0.10865246669319796`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.12148658159948557`\) - 
            0.028954579679561363`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.041405886216296144`\) - 
            0.15088905069309033`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.04754053869982746`\) - 0.2359449260475481`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.08795392003762971`\)\(\[InvisibleSpace]\)\) - 
            0.019106313685993293`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.03896376095168914`\)\(\[InvisibleSpace]\)\) + 
            0.016531285996597353`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.04754053869982746`\) + 0.2359449260475481`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.08795392003762971`\)\(\[InvisibleSpace]\)\) + 
            0.019106313685993293`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.03896376095168914`\)\(\[InvisibleSpace]\)\) - 
            0.016531285996597353`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.04299795981599819`\)\(\[InvisibleSpace]\)\) - 
            0.015723940293424266`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.07371667608644332`\) + 
            0.06821649959154968`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.08210236427406226`\)\(\[InvisibleSpace]\)\) + 
            0.22849242189536587`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.04299795981599819`\)\(\[InvisibleSpace]\)\) + 
            0.015723940293424266`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.07371667608644332`\) - 
            0.06821649959154968`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.08210236427406226`\)\(\[InvisibleSpace]\)\) - 
            0.22849242189536587`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.10170301971318699`\)\(\[InvisibleSpace]\)\) - 
            0.0595434705173672`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.0777946046179872`\) + 
            0.006411400864131049`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.1039744947543264`\) + 
            0.013292958321486349`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.10170301971318699`\)\(\[InvisibleSpace]\)\) + 
            0.0595434705173672`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.0777946046179872`\) - 
            0.006411400864131049`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.1039744947543264`\) - 
            0.013292958321486349`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.09995863374323703`\)\(\[InvisibleSpace]\)\) + 
            0.0056582660292226385`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.20874649286970345`\) + 
            0.06890667330428595`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.0033201258733600737`\)\(\[InvisibleSpace]\)\) - 
            0.050709517762727904`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.09995863374323703`\)\(\[InvisibleSpace]\)\) - 
            0.0056582660292226385`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.20874649286970345`\) - 
            0.06890667330428595`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.0033201258733600737`\)\(\[InvisibleSpace]\)\) + 
            0.050709517762727904`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.0364853550818419`\) - 0.09178679043107557`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.018745877835218364`\)\(\[InvisibleSpace]\)\) + 
            0.06735866749635983`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.04194894097749791`\)\(\[InvisibleSpace]\)\) + 
            0.1085711669365446`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.0364853550818419`\) + 0.09178679043107557`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.018745877835218364`\)\(\[InvisibleSpace]\)\) - 
            0.06735866749635983`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.04194894097749791`\)\(\[InvisibleSpace]\)\) - 
            0.1085711669365446`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.09749182423716518`\)\(\[InvisibleSpace]\)\) + 
            0.008855718415174437`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.07713824086968073`\) + 
            0.12940485658902`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.10602698988869043`\) - 
            0.06979452414011462`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.09749182423716518`\)\(\[InvisibleSpace]\)\) - 
            0.008855718415174437`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.07713824086968073`\) - 
            0.12940485658902`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.10602698988869043`\) + 
            0.06979452414011462`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.009209371875393892`\)\(\[InvisibleSpace]\)\) + 
            0.0715220616218046`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.12222789979757913`\)\(\[InvisibleSpace]\)\) + 
            0.14751399071490962`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.1587107621519204`\)\(\[InvisibleSpace]\)\) + 
            0.0730139446736156`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.009209371875393892`\)\(\[InvisibleSpace]\)\) - 
            0.0715220616218046`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.12222789979757913`\)\(\[InvisibleSpace]\)\) - 
            0.14751399071490962`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.1587107621519204`\)\(\[InvisibleSpace]\)\) - 
            
            0.0730139446736156`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.0998136706788543`\) - 0.18357860885898858`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.012049180259324983`\)\(\[InvisibleSpace]\)\) + 
            0.058691862210720445`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.11667241288307745`\) + 
            0.015694284995140265`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.0998136706788543`\) + 0.18357860885898858`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.012049180259324983`\)\(\[InvisibleSpace]\)\) - 
            0.058691862210720445`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.11667241288307745`\) - 
            0.015694284995140265`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.1440087913440904`\) - 0.15265271890717935`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.030221032655403157`\)\(\[InvisibleSpace]\)\) - 
            0.09841070780748365`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.027453805265518195`\) + 
            0.13853449802894285`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.1440087913440904`\) + 0.15265271890717935`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.030221032655403157`\)\(\[InvisibleSpace]\)\) + 
            0.09841070780748365`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.027453805265518195`\) - 
            0.13853449802894285`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.09939037551577597`\)\(\[InvisibleSpace]\)\) + 
            0.009492741158325066`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.17245232867306132`\) - 
            0.01905939093430804`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.024321477618574`\)\(\[InvisibleSpace]\)\) + 
            0.09382247496327986`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.09939037551577597`\)\(\[InvisibleSpace]\)\) - 
            0.009492741158325066`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.17245232867306132`\) + 
            0.01905939093430804`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.024321477618574`\)\(\[InvisibleSpace]\)\) - 
            0.09382247496327986`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.045196087116160605`\) - 0.036902129325620404`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.03287392497418814`\) + 
            0.07351600067578215`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.00044938727047279546`\)\(\[InvisibleSpace]\)\) + 
            0.1439429442587156`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.045196087116160605`\) + 0.036902129325620404`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.03287392497418814`\) - 
            0.07351600067578215`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.00044938727047279546`\)\(\[InvisibleSpace]\)\) - 
            0.1439429442587156`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.16382641070608392`, c2 \[Rule] 0.027364184360031126`, 
        c3 \[Rule] \(-0.06130211434610753`\)}, {c1 \[Rule] \
\(\(0.15718669141521716`\)\(\[InvisibleSpace]\)\) - 
            0.1501040580782326`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.012873784010279474`\) + 
            0.014967838794204418`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.0020151820121137465`\)\(\[InvisibleSpace]\)\) - 
            0.07077067414334422`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.15718669141521716`\)\(\[InvisibleSpace]\)\) + 
            0.1501040580782326`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.012873784010279474`\) - 
            0.014967838794204418`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.0020151820121137465`\)\(\[InvisibleSpace]\)\) + 
            0.07077067414334422`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.10686324447343344`\)\(\[InvisibleSpace]\)\) + 
            0.03644001939118837`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.17645078309487475`\) + 
            0.11010460157423127`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.1107028290022539`\)\(\[InvisibleSpace]\)\) + 
            0.07559786344839865`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.10686324447343344`\)\(\[InvisibleSpace]\)\) - 
            0.03644001939118837`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.17645078309487475`\) - 
            0.11010460157423127`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.1107028290022539`\)\(\[InvisibleSpace]\)\) - 
            0.07559786344839865`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.06896274100543284`\)\(\[InvisibleSpace]\)\) - 
            0.09768855642991303`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.08863637461304508`\) + 
            0.10600656284482098`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.15248655111565698`\)\(\[InvisibleSpace]\)\) + 
            0.009210104980325307`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.06896274100543284`\)\(\[InvisibleSpace]\)\) + 
            0.09768855642991303`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.08863637461304508`\) - 
            0.10600656284482098`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.15248655111565698`\)\(\[InvisibleSpace]\)\) - 
            0.009210104980325307`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.1409653440904085`\)\(\[InvisibleSpace]\)\) - 
            0.008109090010088905`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.07558577452995453`\)\(\[InvisibleSpace]\)\) + 
            0.11694796134725549`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.0471336367600859`\) + 
            0.031066500517867274`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.1409653440904085`\)\(\[InvisibleSpace]\)\) + 
            0.008109090010088905`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.07558577452995453`\)\(\[InvisibleSpace]\)\) - 
            0.11694796134725549`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.0471336367600859`\) - 
            0.031066500517867274`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.0704936950303912`\)\(\[InvisibleSpace]\)\) - 
            0.03767867425561309`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.14556078203061656`\)\(\[InvisibleSpace]\)\) - 
            0.06356854336014552`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.1290286440453016`\)\(\[InvisibleSpace]\)\) + 
            0.10284340379640813`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.0704936950303912`\)\(\[InvisibleSpace]\)\) + 
            0.03767867425561309`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.14556078203061656`\)\(\[InvisibleSpace]\)\) + 
            0.06356854336014552`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.1290286440453016`\)\(\[InvisibleSpace]\)\) - 
            0.10284340379640813`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.03031990873920472`\) + 0.04957544307714017`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.024334297022178538`\)\(\[InvisibleSpace]\)\) + 
            0.235389818651769`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.05323796062348607`\)\(\[InvisibleSpace]\)\) - 
            0.040223870486889`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.03031990873920472`\) - 0.04957544307714017`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.024334297022178538`\)\(\[InvisibleSpace]\)\) - 
            0.235389818651769`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.05323796062348607`\)\(\[InvisibleSpace]\)\) + 
            0.040223870486889`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.033700044719457534`\) + 0.011487246582396264`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.03179549903969031`\)\(\[InvisibleSpace]\)\) + 
            0.004794233047912994`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.009332748801205564`\) + 
            0.15916120678229317`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.033700044719457534`\) - 0.011487246582396264`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.03179549903969031`\)\(\[InvisibleSpace]\)\) - 
            0.004794233047912994`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.009332748801205564`\) - 
            0.15916120678229317`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.09316030837551871`\)\(\[InvisibleSpace]\)\) - 
            0.1096233614786799`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.1248619184047562`\)\(\[InvisibleSpace]\)\) - 
            0.01925270185439323`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.10234868751398359`\) + 
            0.023303210090021988`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.09316030837551871`\)\(\[InvisibleSpace]\)\) + 
            0.1096233614786799`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.1248619184047562`\)\(\[InvisibleSpace]\)\) + 
            0.01925270185439323`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.10234868751398359`\) - 
            0.023303210090021988`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.1511825203291907`, c2 \[Rule] 0.07142246589065343`, 
        c3 \[Rule] \(-0.053945622680045886`\)}, {c1 \[Rule] 
          0.02537755749289121`, c2 \[Rule] 0.13175393879640407`, 
        c3 \[Rule] 0.06795425498785758`}, {c1 \[Rule] 0.15209615752730485`, 
        c2 \[Rule] 0.077734573440211`, 
        c3 \[Rule] \(-0.05480824598966075`\)}, {c1 \[Rule] \
\(\(0.12497462049905812`\)\(\[InvisibleSpace]\)\) + 
            0.0058119861492849515`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.3431808440109377`\)\(\[InvisibleSpace]\)\) + 
            0.05448355361074081`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.027124794778785044`\) + 
            0.011054513456518433`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.12497462049905812`\)\(\[InvisibleSpace]\)\) - 
            0.0058119861492849515`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.3431808440109377`\)\(\[InvisibleSpace]\)\) - 
            0.05448355361074081`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.027124794778785044`\) - 
            
            0.011054513456518433`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.16452836206030488`\)\(\[InvisibleSpace]\)\) - 
            0.05805390792794852`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.14466081193390656`\)\(\[InvisibleSpace]\)\) + 
            0.08225138702984663`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.08167836299245591`\) - 
            0.07241253395914557`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.16452836206030488`\)\(\[InvisibleSpace]\)\) + 
            0.05805390792794852`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.14466081193390656`\)\(\[InvisibleSpace]\)\) - 
            0.08225138702984663`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.08167836299245591`\) + 
            0.07241253395914557`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.028016396488064078`\) - 0.012047914791130673`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.12509991970397538`\) + 
            0.15734480168988532`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.05462997964046482`\) - 
            0.09790070755429471`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.028016396488064078`\) + 0.012047914791130673`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.12509991970397538`\) - 
            0.15734480168988532`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.05462997964046482`\) + 
            0.09790070755429471`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.10327752650386407`\)\(\[InvisibleSpace]\)\) - 
            0.0732658728630486`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.054223690661089605`\)\(\[InvisibleSpace]\)\) + 
            0.0983262680729614`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.059035668521252534`\) - 
            0.09796766031292445`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.10327752650386407`\)\(\[InvisibleSpace]\)\) + 
            0.0732658728630486`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.054223690661089605`\)\(\[InvisibleSpace]\)\) - 
            0.0983262680729614`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.059035668521252534`\) + 
            0.09796766031292445`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.0033873387820421313`\) - 0.03944317825146386`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.02610430833502019`\)\(\[InvisibleSpace]\)\) + 
            0.09057308433200871`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.01229442489938028`\) + 
            0.011387940923439456`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.0033873387820421313`\) + 0.03944317825146386`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.02610430833502019`\)\(\[InvisibleSpace]\)\) - 
            0.09057308433200871`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.01229442489938028`\) - 
            0.011387940923439456`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.08585608509298699`\) - 0.06379790655374878`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.07260091006761163`\) - 
            0.028800425493445875`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.013609810277006643`\) + 
            0.09202089032162158`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.08585608509298699`\) + 0.06379790655374878`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.07260091006761163`\) + 
            0.028800425493445875`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.013609810277006643`\) - 
            0.09202089032162158`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.30002450402946124`, c2 \[Rule] 0.2439895677813828`, 
        c3 \[Rule] \(-0.018690406986785035`\)}, {c1 \[Rule] \
\(\(0.007661786861586242`\)\(\[InvisibleSpace]\)\) - 
            0.03228480735873426`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.07994851738354271`\) - 
            0.07007594435459373`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.0175280567436669`\)\(\[InvisibleSpace]\)\) + 
            0.14425125184792578`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.007661786861586242`\)\(\[InvisibleSpace]\)\) + 
            0.03228480735873426`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.07994851738354271`\) + 
            0.07007594435459373`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.0175280567436669`\)\(\[InvisibleSpace]\)\) - 
            0.14425125184792578`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.07954990836554056`\)\(\[InvisibleSpace]\)\) - 
            0.10679973850985762`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.0012298923081540797`\)\(\[InvisibleSpace]\)\) + 
            0.025357083625886102`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.020623383655226753`\) - 
            0.08062878226252519`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.07954990836554056`\)\(\[InvisibleSpace]\)\) + 
            0.10679973850985762`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.0012298923081540797`\)\(\[InvisibleSpace]\)\) - 
            0.025357083625886102`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.020623383655226753`\) + 
            
            0.08062878226252519`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.13760640274858385`\) + 0.003641223968685502`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.05841182442126821`\)\(\[InvisibleSpace]\)\) - 
            0.15281068398615782`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.09321625301550884`\) + 
            0.17486610149997073`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.13760640274858385`\) - 0.003641223968685502`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.05841182442126821`\)\(\[InvisibleSpace]\)\) + 
            0.15281068398615782`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.09321625301550884`\) - 
            0.17486610149997073`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.1294849209379138`\)\(\[InvisibleSpace]\)\) - 
            0.07230172680676972`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.26583742875644645`\)\(\[InvisibleSpace]\)\) + 
            0.014611494213850431`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.027876747122717378`\) - 
            0.007657795777271113`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.1294849209379138`\)\(\[InvisibleSpace]\)\) + 
            0.07230172680676972`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.26583742875644645`\)\(\[InvisibleSpace]\)\) - 
            0.014611494213850431`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.027876747122717378`\) + 
            0.007657795777271113`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.04007883383069132`\) - 0.02113024686993274`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.0640661059468548`\) + 
            0.056758899442853825`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.05744265251537785`\) + 
            0.009426392048502883`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.04007883383069132`\) + 0.02113024686993274`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.0640661059468548`\) - 
            0.056758899442853825`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.05744265251537785`\) - 
            0.009426392048502883`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.061850667425306594`\) - 0.15413121155690476`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.07029355488945613`\)\(\[InvisibleSpace]\)\) - 
            0.0040552356250022565`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.09076515677691085`\) - 
            0.08878445819605772`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.061850667425306594`\) + 0.15413121155690476`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.07029355488945613`\)\(\[InvisibleSpace]\)\) + 
            0.0040552356250022565`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.09076515677691085`\) + 
            0.08878445819605772`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.029976261929918407`\) - 0.03537390886627777`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.050045444190614664`\)\(\[InvisibleSpace]\)\) + 
            0.0269993929791805`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.01550552008369852`\) - 
            0.005143350047515809`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.029976261929918407`\) + 0.03537390886627777`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.050045444190614664`\)\(\[InvisibleSpace]\)\) - 
            0.0269993929791805`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.01550552008369852`\) + 
            0.005143350047515809`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.128455799103796`\)\(\[InvisibleSpace]\)\) - 
            0.003924346541499879`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.2633520328607019`\)\(\[InvisibleSpace]\)\) + 
            0.016081840043331876`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.021014257668536238`\) + 
            0.023151836941467052`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.128455799103796`\)\(\[InvisibleSpace]\)\) + 
            0.003924346541499879`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.2633520328607019`\)\(\[InvisibleSpace]\)\) - 
            0.016081840043331876`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.021014257668536238`\) - 
            0.023151836941467052`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.06942138694412829`\)\(\[InvisibleSpace]\)\) - 
            0.025462374273054922`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.16108970185671073`\) + 
            0.12489444529772922`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.2541875508687768`\)\(\[InvisibleSpace]\)\) - 
            0.06318340458139653`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.06942138694412829`\)\(\[InvisibleSpace]\)\) + 
            0.025462374273054922`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.16108970185671073`\) - 
            0.12489444529772922`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.2541875508687768`\)\(\[InvisibleSpace]\)\) + 
            0.06318340458139653`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.147186195001121`\)\(\[InvisibleSpace]\)\) + 
            0.03759608136026251`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.1938231693925794`\)\(\[InvisibleSpace]\)\) + 
            0.02758854573726602`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.045665104901853416`\) + 
            0.09271726792597941`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.147186195001121`\)\(\[InvisibleSpace]\)\) - 
            0.03759608136026251`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.1938231693925794`\)\(\[InvisibleSpace]\)\) - 
            0.02758854573726602`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.045665104901853416`\) - 
            0.09271726792597941`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.020045699902144266`\) - 0.09519535241523683`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.03209745368758686`\) - 
            0.11335906687150597`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.05563873845770132`\)\(\[InvisibleSpace]\)\) + 
            0.052844512065898186`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.020045699902144266`\) + 0.09519535241523683`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.03209745368758686`\) + 
            0.11335906687150597`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.05563873845770132`\)\(\[InvisibleSpace]\)\) - 
            0.052844512065898186`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.05364818151184115`\)\(\[InvisibleSpace]\)\) + 
            0.028446375046258736`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.07789679870050581`\)\(\[InvisibleSpace]\)\) + 
            0.0018196161381717835`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.06237281442448015`\)\(\[InvisibleSpace]\)\) + 
            0.0426674290598858`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.05364818151184115`\)\(\[InvisibleSpace]\)\) - 
            0.028446375046258736`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.07789679870050581`\)\(\[InvisibleSpace]\)\) - 
            0.0018196161381717835`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.06237281442448015`\)\(\[InvisibleSpace]\)\) - 
            0.0426674290598858`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.039261642019308464`\) - 0.0942196840733368`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.030482113454320652`\) + 
            0.07467946523812667`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.05667140170051391`\) - 
            0.11594057631583075`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.039261642019308464`\) + 0.0942196840733368`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.030482113454320652`\) - 
            0.07467946523812667`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.05667140170051391`\) + 
            0.11594057631583075`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.14154688643506655`\) - 0.06111992561702163`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.1153637702846555`\) - 
            0.043379063450029905`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.10151099903149342`\) + 
            0.017306939269994603`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.14154688643506655`\) + 0.06111992561702163`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.1153637702846555`\) + 
            0.043379063450029905`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.10151099903149342`\) - 
            0.017306939269994603`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.018738184614920106`\)\(\[InvisibleSpace]\)\) + 
            0.12164686290922956`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.0013848084819962012`\) + 
            0.06259334253635714`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.04013399441082811`\) + 
            0.09359031382666444`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.018738184614920106`\)\(\[InvisibleSpace]\)\) - 
            0.12164686290922956`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.0013848084819962012`\) - 
            0.06259334253635714`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.04013399441082811`\) - 
            0.09359031382666444`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.046900294841353954`\) + 0.10020469067743472`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.018390165122231013`\) + 
            0.03112847034925574`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.07948472927428288`\) + 
            0.12726001189555247`\ \[ImaginaryI]}, {c1 \[Rule] \
\(-0.046900294841353954`\) - 0.10020469067743472`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.018390165122231013`\) - 
            0.03112847034925574`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.07948472927428288`\) - 
            0.12726001189555247`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.004276750899972658`\)\(\[InvisibleSpace]\)\) - 
            0.035548243033467576`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.04893277614262344`\)\(\[InvisibleSpace]\)\) + 
            0.013179543054957893`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.0015444102533393067`\)\(\[InvisibleSpace]\)\) - 
            0.018325543603957748`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.004276750899972658`\)\(\[InvisibleSpace]\)\) + 
            0.035548243033467576`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.04893277614262344`\)\(\[InvisibleSpace]\)\) - 
            0.013179543054957893`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.0015444102533393067`\)\(\[InvisibleSpace]\)\) + 
            0.018325543603957748`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.028393314234958417`\)\(\[InvisibleSpace]\)\) + 
            0.00005725915063960269`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.008942821661407384`\) + 
            0.010376428766559061`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.0024102649596235925`\)\(\[InvisibleSpace]\)\) + 
            0.004181044541611228`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.028393314234958417`\)\(\[InvisibleSpace]\)\) - 
            0.00005725915063960269`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.008942821661407384`\) - 
            0.010376428766559061`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.0024102649596235925`\)\(\[InvisibleSpace]\)\) - 
            0.004181044541611228`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.0848757599141182`\)\(\[InvisibleSpace]\)\) - 
            0.03679288737265169`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.03177652058856294`\)\(\[InvisibleSpace]\)\) + 
            0.0477428723522354`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.06829011671885324`\)\(\[InvisibleSpace]\)\) - 
            0.05357921237481344`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.0848757599141182`\)\(\[InvisibleSpace]\)\) + 
            0.03679288737265169`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.03177652058856294`\)\(\[InvisibleSpace]\)\) - 
            0.0477428723522354`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.06829011671885324`\)\(\[InvisibleSpace]\)\) + 
            0.05357921237481344`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.10512333276300467`\)\(\[InvisibleSpace]\)\) + 
            0.07789123352763846`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.12192485473009268`\)\(\[InvisibleSpace]\)\) + 
            0.02905841626574183`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.01831368750516849`\) + 
            0.07981547351846924`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.10512333276300467`\)\(\[InvisibleSpace]\)\) - 
            0.07789123352763846`\ \[ImaginaryI], 
        c2 \[Rule] \(\(0.12192485473009268`\)\(\[InvisibleSpace]\)\) - 
            0.02905841626574183`\ \[ImaginaryI], 
        c3 \[Rule] \(-0.01831368750516849`\) - 
            0.07981547351846924`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.07619082399443497`\)\(\[InvisibleSpace]\)\) + 
            0.016903956260666285`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.0003689862504984389`\) - 
            0.011708347392985673`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.06537006386250989`\)\(\[InvisibleSpace]\)\) + 
            0.035592691833725286`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.07619082399443497`\)\(\[InvisibleSpace]\)\) - 
            0.016903956260666285`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.0003689862504984389`\) + 
            0.011708347392985673`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.06537006386250989`\)\(\[InvisibleSpace]\)\) - 
            0.035592691833725286`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.07626516893184486`\)\(\[InvisibleSpace]\)\) - 
            0.10866070482950693`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.021938869297608857`\) - 
            0.046807048769334954`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.10771441147684875`\)\(\[InvisibleSpace]\)\) - 
            0.058488857996943366`\ \[ImaginaryI]}, {c1 \[Rule] \
\(\(0.07626516893184486`\)\(\[InvisibleSpace]\)\) + 
            0.10866070482950693`\ \[ImaginaryI], 
        c2 \[Rule] \(-0.021938869297608857`\) + 
            0.046807048769334954`\ \[ImaginaryI], 
        c3 \[Rule] \(\(0.10771441147684875`\)\(\[InvisibleSpace]\)\) + 
            0.058488857996943366`\ \[ImaginaryI]}, {c1 \[Rule] 
          0.14210916224435002`, c2 \[Rule] 0.18685941665113162`, 
        c3 \[Rule] \(-0.02909168975937834`\)}, {c1 \[Rule] 
          0.005211502330649925`, c2 \[Rule] 0.0004402927510334305`, 
        c3 \[Rule] \(-0.012046638668606804`\)}, {c1 \[Rule] 
          0.013596102734347469`, c2 \[Rule] 0.0057254728887704475`, 
        c3 \[Rule] \(-0.004043641089041729`\)}, {c1 \[Rule] \
\(-0.005905339440562327`\), c2 \[Rule] 0.00036760047205412527`, 
        c3 \[Rule] \(-0.018976678662961828`\)}}\)], "Output",
  CellLabel->"Out[113]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Length[extrema]", "Input",
  CellLabel->"In[114]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \(154\)], "Output",
  CellLabel->"Out[114]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
finalextrema = 
\tUnion[Select[extrema,
\t\t((\tc1==Re[c1]&&c2==Re[c2]&&c3==Re[c3]&&
\t\t\tAbs[Re[c1]]<.1&&Abs[Re[c2]]<.1&&Abs[Re[c3]]<.1
\t\t)/.#)&]]\
\>", "Input",
  CellLabel->"In[115]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \({{c1 \[Rule] \(-0.005905339440562327`\), 
        c2 \[Rule] 0.00036760047205412527`, 
        c3 \[Rule] \(-0.018976678662961828`\)}, {c1 \[Rule] 
          0.005211502330649925`, c2 \[Rule] 0.0004402927510334305`, 
        c3 \[Rule] \(-0.012046638668606804`\)}, {c1 \[Rule] 
          0.013596102734347469`, c2 \[Rule] 0.0057254728887704475`, 
        c3 \[Rule] \(-0.004043641089041729`\)}}\)], "Output",
  CellLabel->"Out[115]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
finalextrema = 
\tMap[Apply[Rule,Transpose[{{c1,c2,c3},#}],2]&,Union[Re[{c1,c2,c3}/.Select[\
extrema,
\t\t((\tAbs[Re[c1]]<.1&&Abs[Re[c2]]<.1&&Abs[Re[c3]]<.1
\t\t)/.#)&]]]]\
\>", "Input",
  CellLabel->"In[116]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \({{c1 \[Rule] \(-0.08585608509298699`\), 
        c2 \[Rule] \(-0.07260091006761163`\), 
        c3 \[Rule] \(-0.013609810277006643`\)}, {c1 \[Rule] \
\(-0.07879022894934605`\), c2 \[Rule] 0.0795800296520508`, 
        c3 \[Rule] 
          0.015696876612557215`}, {c1 \[Rule] \(-0.061850667425306594`\), 
        c2 \[Rule] 0.07029355488945613`, 
        c3 \[Rule] \(-0.09076515677691085`\)}, {c1 \[Rule] \
\(-0.04754053869982746`\), c2 \[Rule] 0.08795392003762971`, 
        c3 \[Rule] 
          0.03896376095168914`}, {c1 \[Rule] \(-0.046900294841353954`\), 
        c2 \[Rule] \(-0.018390165122231013`\), 
        c3 \[Rule] \(-0.07948472927428288`\)}, {c1 \[Rule] \
\(-0.045196087116160605`\), c2 \[Rule] \(-0.03287392497418814`\), 
        c3 \[Rule] 
          0.00044938727047279546`}, {c1 \[Rule] \(-0.04007883383069132`\), 
        c2 \[Rule] \(-0.0640661059468548`\), 
        c3 \[Rule] \(-0.05744265251537785`\)}, {c1 \[Rule] \
\(-0.039261642019308464`\), c2 \[Rule] \(-0.030482113454320652`\), 
        c3 \[Rule] \(-0.05667140170051391`\)}, {c1 \[Rule] \
\(-0.0364853550818419`\), c2 \[Rule] 0.018745877835218364`, 
        c3 \[Rule] 
          0.04194894097749791`}, {c1 \[Rule] \(-0.033700044719457534`\), 
        c2 \[Rule] 0.03179549903969031`, 
        c3 \[Rule] \(-0.009332748801205564`\)}, {c1 \[Rule] \
\(-0.03031990873920472`\), c2 \[Rule] 0.024334297022178538`, 
        c3 \[Rule] 
          0.05323796062348607`}, {c1 \[Rule] \(-0.029976261929918407`\), 
        c2 \[Rule] 0.050045444190614664`, 
        c3 \[Rule] \(-0.01550552008369852`\)}, {c1 \[Rule] \
\(-0.020045699902144266`\), c2 \[Rule] \(-0.03209745368758686`\), 
        c3 \[Rule] 
          0.05563873845770132`}, {c1 \[Rule] \(-0.005905339440562327`\), 
        c2 \[Rule] 0.00036760047205412527`, 
        c3 \[Rule] \(-0.018976678662961828`\)}, {c1 \[Rule] \
\(-0.0033873387820421313`\), c2 \[Rule] 0.02610430833502019`, 
        c3 \[Rule] \(-0.01229442489938028`\)}, {c1 \[Rule] 
          0.004276750899972658`, c2 \[Rule] 0.04893277614262344`, 
        c3 \[Rule] 0.0015444102533393067`}, {c1 \[Rule] 
          0.005211502330649925`, c2 \[Rule] 0.0004402927510334305`, 
        c3 \[Rule] \(-0.012046638668606804`\)}, {c1 \[Rule] 
          0.007661786861586242`, c2 \[Rule] \(-0.07994851738354271`\), 
        c3 \[Rule] 0.0175280567436669`}, {c1 \[Rule] 0.013596102734347469`, 
        c2 \[Rule] 0.0057254728887704475`, 
        c3 \[Rule] \(-0.004043641089041729`\)}, {c1 \[Rule] 
          0.018738184614920106`, c2 \[Rule] \(-0.0013848084819962012`\), 
        c3 \[Rule] \(-0.04013399441082811`\)}, {c1 \[Rule] 
          0.028393314234958417`, c2 \[Rule] \(-0.008942821661407384`\), 
        c3 \[Rule] 0.0024102649596235925`}, {c1 \[Rule] 
          0.029942789702913565`, c2 \[Rule] 0.004012158564002046`, 
        c3 \[Rule] 0.07894092275566567`}, {c1 \[Rule] 0.04299795981599819`, 
        c2 \[Rule] \(-0.07371667608644332`\), 
        c3 \[Rule] 0.08210236427406226`}, {c1 \[Rule] 0.05364818151184115`, 
        c2 \[Rule] 0.07789679870050581`, 
        c3 \[Rule] 0.06237281442448015`}, {c1 \[Rule] 0.07619082399443497`, 
        c2 \[Rule] \(-0.0003689862504984389`\), 
        c3 \[Rule] 0.06537006386250989`}, {c1 \[Rule] 0.07954990836554056`, 
        c2 \[Rule] 0.0012298923081540797`, 
        c3 \[Rule] \(-0.020623383655226753`\)}, {c1 \[Rule] 
          0.0848757599141182`, c2 \[Rule] 0.03177652058856294`, 
        c3 \[Rule] 0.06829011671885324`}}\)], "Output",
  CellLabel->"Out[116]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Map[{meritFunction/.#,FindFocusFast[AnalyzeSystem[{
\tLineOfRays[10,NumberOfRays->6],
\tComponentRendering[{Move[
        SphericalLensSurface[(1/c1)/.#,50,ComponentMedium->3/2],100],
\t\tMove[SphericalLensSurface[(1/c2)/.#,50,ComponentMedium->{3/2,9/5}],115],
\t\tMove[SphericalLensSurface[(1/c3)/.#,50,ComponentMedium->9/5],120]}],
\t\tMove[Screen[50],200]}, PlotType->TopView, ShowArrows->False]]}&,
\t\tfinalextrema]\
\>", "Input",
  CellLabel->"In[117]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.55806 .10972 m
.48329 .10972 L
% vacuous filled polygon
newpath
.48329 .10972 m
.55806 .10972 L
.57143 .1494 L
.5 .1494 L
.48329 .10972 L
F
.5 .1494 m
.57143 .1494 L
.55806 .18909 L
.48329 .18909 L
.5 .1494 L
F
.48329 .18909 m
.55806 .18909 L
.48329 .18909 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.48329 .10972 m
.5 .1494 L
.48329 .18909 L
s
.55806 .18909 m
.57143 .1494 L
.55806 .10972 L
s
.5 g
.55806 .1494 m
.48329 .1494 L
% vacuous filled polygon
newpath
.48329 .1494 m
.55806 .1494 L
.57143 .1494 L
.5 .1494 L
.48329 .1494 L
F
.5 .1494 m
.57143 .1494 L
.55806 .1494 L
.48329 .1494 L
.5 .1494 L
F
.48329 .1494 m
.55806 .1494 L
.48329 .1494 L
F
0 g
.48329 .1494 m
.5 .1494 L
.48329 .1494 L
s
.55806 .1494 m
.57143 .1494 L
.55806 .1494 L
s
.5 g
.57436 .03036 m
.58612 .07004 L
% vacuous filled polygon
newpath
.58612 .07004 m
.59298 .10972 L
.55806 .10972 L
F
.55806 .10972 m
.59298 .10972 L
.59524 .1494 L
.57143 .1494 L
.55806 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59298 .18909 L
.55806 .18909 L
.57143 .1494 L
F
.55806 .18909 m
.59298 .18909 L
.58612 .22877 L
.55806 .18909 L
F
.58612 .22877 m
.57436 .26845 L
% vacuous filled polygon
newpath
0 g
.55806 .10972 m
.57143 .1494 L
.55806 .18909 L
s
.57436 .26845 m
.58612 .22877 L
.59298 .18909 L
.59524 .1494 L
.59298 .10972 L
.58612 .07004 L
.57436 .03036 L
s
.5 g
.57436 .1494 m
.58612 .1494 L
% vacuous filled polygon
newpath
.58612 .1494 m
.59298 .1494 L
.55806 .1494 L
F
.55806 .1494 m
.59298 .1494 L
.59524 .1494 L
.57143 .1494 L
.55806 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59298 .1494 L
.55806 .1494 L
.57143 .1494 L
F
.55806 .1494 m
.59298 .1494 L
.58612 .1494 L
.55806 .1494 L
F
.58612 .1494 m
.57436 .1494 L
% vacuous filled polygon
newpath
0 g
.55806 .1494 m
.57143 .1494 L
.55806 .1494 L
s
.57436 .1494 m
.58612 .1494 L
.59298 .1494 L
.59524 .1494 L
.59298 .1494 L
.58612 .1494 L
.57436 .1494 L
s
.57436 .26845 m
.57436 .2644 L
s
.57436 .2644 m
.57436 .2525 L
s
.57436 .2525 m
.57436 .23358 L
s
.57436 .23358 m
.57436 .20893 L
s
.57436 .20893 m
.57436 .18022 L
s
.57436 .18022 m
.57436 .1494 L
s
.57436 .1494 m
.57436 .11859 L
s
.57436 .11859 m
.57436 .08988 L
s
.57436 .08988 m
.57436 .06523 L
s
.57436 .06523 m
.57436 .04631 L
s
.57436 .04631 m
.57436 .03441 L
s
.57436 .03441 m
.57436 .03036 L
s
.57436 .03036 m
.57436 .03441 L
s
.57436 .03441 m
.57436 .04631 L
s
.57436 .04631 m
.57436 .06523 L
s
.57436 .06523 m
.57436 .08988 L
s
.57436 .08988 m
.57436 .11859 L
s
.57436 .11859 m
.57436 .1494 L
s
.57436 .1494 m
.57436 .18022 L
s
.57436 .18022 m
.57436 .20893 L
s
.57436 .20893 m
.57436 .23358 L
s
.57436 .23358 m
.57436 .2525 L
s
.57436 .2525 m
.57436 .2644 L
s
.57436 .2644 m
.57436 .26845 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49463 .1256 L
s
0 0 0 r
2 Mabswid
.49463 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49813 .13512 L
s
0 0 0 r
2 Mabswid
.49813 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.4998 .14464 L
s
0 0 0 r
2 Mabswid
.4998 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.4998 .15417 L
s
0 0 0 r
2 Mabswid
.4998 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49813 .16369 L
s
0 0 0 r
2 Mabswid
.49813 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49463 .17321 L
s
0 0 0 r
2 Mabswid
.49463 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49463 .1256 m
.56181 .11521 L
s
0 0 0 r
2 Mabswid
.56181 .11521 Mdot
.039 .916 .04 r
.5 Mabswid
.49813 .13512 m
.56816 .12895 L
s
0 0 0 r
2 Mabswid
.56816 .12895 Mdot
.039 .916 .04 r
.5 Mabswid
.4998 .14464 m
.57107 .1426 L
s
0 0 0 r
2 Mabswid
.57107 .1426 Mdot
.039 .916 .04 r
.5 Mabswid
.4998 .15417 m
.57107 .15621 L
s
0 0 0 r
2 Mabswid
.57107 .15621 Mdot
.039 .916 .04 r
.5 Mabswid
.49813 .16369 m
.56816 .16986 L
s
0 0 0 r
2 Mabswid
.56816 .16986 Mdot
.039 .916 .04 r
.5 Mabswid
.49463 .17321 m
.56181 .1836 L
s
0 0 0 r
2 Mabswid
.56181 .1836 Mdot
.039 .916 .04 r
.5 Mabswid
.56181 .11521 m
.59281 .10822 L
s
0 0 0 r
2 Mabswid
.59281 .10822 Mdot
.039 .916 .04 r
.5 Mabswid
.56816 .12895 m
.59443 .1256 L
s
0 0 0 r
2 Mabswid
.59443 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.57107 .1426 m
.59515 .1416 L
s
0 0 0 r
2 Mabswid
.59515 .1416 Mdot
.039 .916 .04 r
.5 Mabswid
.57107 .15621 m
.59515 .1572 L
s
0 0 0 r
2 Mabswid
.59515 .1572 Mdot
.039 .916 .04 r
.5 Mabswid
.56816 .16986 m
.59443 .17321 L
s
0 0 0 r
2 Mabswid
.59443 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.56181 .1836 m
.59281 .19059 L
s
0 0 0 r
2 Mabswid
.59281 .19059 Mdot
.039 .916 .04 r
.5 Mabswid
.59443 .1256 m
.97619 .05867 L
s
0 0 0 r
2 Mabswid
.97619 .05867 Mdot
.039 .916 .04 r
.5 Mabswid
.59515 .1416 m
.97619 .12009 L
s
0 0 0 r
2 Mabswid
.97619 .12009 Mdot
.039 .916 .04 r
.5 Mabswid
.59515 .1572 m
.97619 .17872 L
s
0 0 0 r
2 Mabswid
.97619 .17872 Mdot
.039 .916 .04 r
.5 Mabswid
.59443 .17321 m
.97619 .24014 L
s
0 0 0 r
2 Mabswid
.97619 .24014 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00:?ooooo00?o0000oooo
ooooool0JOooool00ol0003oooooooooo`0>ooooo`00Xoooool00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo00kooooo002Sooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0
3_ooool00:?ooooo0_l0001Zooooo`03o`000?oooooooooo00kooooo002Sooooo`;o0000J_ooool0
0ol0003oooooooooo`0>ooooo`00Xoooool2o`0006[ooooo00?o0000ooooooooool03_ooool00:?o
oooo00?o0000ooooool00000JOooool00ol0003oooooooooo`0>ooooo`00Xoooool00ol0003ooooo
o`00001Vooooo`?o2NX:0_l0000?ooooo`00Xoooool00ol0003oooooo`00001Pooooo`Ko2NX:0ooo
ool2o`0000oooooo002Sooooo`04o`000?ooooooooooo`0005[ooooo1Ol9jPX9ooooo`03o`000?oo
oooooooo00kooooo002Sooooo`04o`000?ooooooooooo`0005Cooooo1_l9jPX>ooooo`03o`000?oo
oooooooo00kooooo002Sooooo`04o`000?ooooooooooo`0004kooooo1_l9jPXDooooo`03o`000?oo
oooooooo00kooooo002Sooooo`04o`000?ooooooooooo`0004Wooooo1Ol9jPXJooooo`03o`000?oo
oooooooo00kooooo002Sooooo`04o`000?ooooooOgmoo`0004?ooooo1_l9jPXOooooo`03o`000?oo
oooooooo00kooooo002Sooooo`05o`000?moOgooOgmoogmoOol00000??ooool6o`WZ2RGooooo00?o
0000ooooooooool03_ooool00:?ooooo00Go0000ogmoOomoOgooOgmoo`00000fooooo`Ko2NX::ooo
ool00ol0003oooooooooo`0>ooooo`00Xoooool01Ol0003oOgmoogmoOomoOgoo0000037ooooo1Ol9
jPXaooooo`03o`000?oooooooooo00kooooo002Rooooo`03ogmoOol0003oOgmo00;oOgmo00?o0000
ooooooooool0:Oooool6o`WZ2SKooooo00?o0000ooooooooool03_ooool00:;ooooo00?oOgmoo`00
0?moOgl00_moOgl00ol0003oooooooooo`0Sooooo`Ko2NX:??ooool00ol0003oooooooooo`0>oooo
o`00XOooool2ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool07?ooool6o`WZ2T;o
oooo00?o0000ooooooooool03_ooool00:7ooooo0_moOgl01?l0003oOgmoogmoOomoOgl2o`0001Wo
oooo1Ol9jPY8ooooo`03o`000?oooooooooo00kooooo002;ooooo`03o`000?oooooooooo017ooooo
00Go0000ogmoOomoOgooOgmoo`000002ogmoO`03o`WZ2_l0003o000001?ooooo1_l9jPY=ooooo`03
o`000?oooooooooo00kooooo002;ooooo`03o`000?moOgooOgmo017oOgmo0_l000000omoOgoo2NX:
o`WZ2P02o`WZ2P;oOgmo00?o0000ooooooooool02oooool6o`WZ2U?ooooo00?o0000ooooooooool0
3_ooool008cooooo00?o0000ogmoOomoOgl03OmoOgl3o`WZ2P05o`000?l9jP[o2NX:ogmoOol00000
1?moOgl00ol0003oooooooooo`06ooooo`Go2NX:FOooool2o`0000oooooo002<ooooo`03o`000?mo
OgooOgmo00CoOgmo2Ol9jPX4ogmoO`04o`000?moOgooOgmoo`0000CoOgmo00?o0000ooooooooool0
1_l9jPYFooooo`So2NX:0_l0000?ooooo`003ooooomno`WZ2P03o`000?l9jP[o2NX:00?o2NX:3Omo
Ogl01Ol0003oOgmoogmoOol0003oOgmo00Ko2NX:BooooolAo`WZ2PSooooo00?o0000ooooooooool0
3_ooool008gooooo0_l0000=ogmoO`Wo2NX:0omoOgl2o`0003_ooooo4Ol9jPXIooooo`03o`000?oo
oooooooo00kooooo002=ooooo`?o00000omoOgl9o`WZ2PGoOgmo0ol00005ogmoO`03o`000?oooooo
oooo02Sooooo4Ol9jPXZooooo`03o`000?oooooooooo00kooooo000?ooooohCo2NX:3_moOgl00ol0
003oOgmoo`000005ogmoO`03o`000?oooooooooo01Oooooo4Ol9jPXkooooo`03o`000?oooooooooo
00kooooo002>ooooo`03o`000?moOgooOgmo013oOgmo0ol00004ogmoO`;o00002?oooolAo`WZ2Tco
oooo00?o0000ooooooooool03_ooool000ooooooOol9jPX00ol0003o2NX:o`WZ2P0Go`WZ2P03o`00
0?l9jP[o2NX:00Oo2NX:GOooool00ol0003oooooooooo`0>ooooo`00S_ooool2o`0001;oOgmo0_l0
0005ogmoO`03o`000?oooooooooo06?ooooo00?o0000ooooooooool03_ooool008_ooooo1Ol0000?
ogmoO`_o0000IOooool00ol0003oooooooooo`0>ooooo`003ooooomoo`WZ2P03o`000?l9jP[o2NX:
00Wo2NX:2?moOgl2o`0000CoOgmo0_l0001Uooooo`03o`000?oooooooooo00kooooo002>ooooo`;o
00002_moOgl>o`WZ2P03o`000?l9jP[o2NX:00So2NX:G?ooool00ol0003oooooooooo`0>ooooo`00
S_ooool2o`00017oOgmo00?o0000ogmoOol000001OmoOgl00ol0003oooooooooo`07oooooa7o2NX:
Boooool00ol0003oooooooooo`0>ooooo`003ooooon:o`WZ2PSoOgmo00?o0000ogmoOol000001Omo
Ogl00ol0003oooooooooo`0Hoooooa7o2NX:>_ooool00ol0003oooooooooo`0>ooooo`00SOooool0
0ol0003oOgmoogmoO`09ogmoO`go2NX:0omoOgl00ol0003oooooooooo`0Yoooooa7o2NX::Oooool0
0ol0003oooooooooo`0>ooooo`003ooooomno`WZ2P03o`000?l9jP[o2NX:00;o2NX:3_moOgl4o`00
00;oOgmo1_l9jPXjoooooa7o2NX:6?ooool00ol0003oooooooooo`0>ooooo`00S?ooool3o`0000?o
Ogmo1_l9jPX8ogmoO`04o`000?moOgooOgmoo`0000CoOgmo0_l00002ooooo`Ko2NX:AOoooolAo`WZ
2POooooo0_l0000?ooooo`00S?ooool00ol0003oOgmoogmoO`09ogmoO`Ko2NX:00?oOgmoo`000?l0
00000_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo00Oooooo1Ol9jPYAooooo`Oo
2NX:0_l0000?ooooo`00S?ooool00ol0003oOgmoogmoO`0?ogmoO`03o`WZ2_l0003o2NX:00;o2NX:
00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`0<ooooo`Ko2NX:D_ooool00ol0003ooooo
ooooo`0>ooooo`00Roooool00ol0003oOgmoogmoO`0AogmoO`04o`000?moOgooOgmoogmoO`Co2NX:
0_l0000Dooooo`Ko2NX:C?ooool00ol0003oooooooooo`0>ooooo`00Woooool4ogmoO`04o`000?mo
OgooOgmoogmoO`;o00006_ooool5o`WZ2TOooooo00?o0000ooooooooool03_ooool00:3ooooo0omo
Ogl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo01gooooo1_l9jPY1ooooo`03o`000?oo
oooooooo00kooooo002Qooooo`;oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`0S
ooooo`Ko2NX:>oooool00ol0003oooooooooo`0>ooooo`00XOooool2ogmoO`05o`000?moOgooOgmo
ogmoOol00000;?ooool6o`WZ2SGooooo00?o0000ooooooooool03_ooool00:;ooooo00?oOgmoo`00
0?moOgl00_moOgl00ol0003oooooooooo`0`ooooo`Go2NX:<?ooool00ol0003oooooooooo`0>oooo
o`00Xoooool01Ol0003oOgmoogmoOomoOgoo000003Oooooo1_l9jPXZooooo`03o`000?oooooooooo
00kooooo002Sooooo`05o`000?moOgooOgmoogmoOol00000?Oooool6o`WZ2RCooooo00?o0000oooo
ooooool03_ooool00:?ooooo00Go0000ogmoOomoOgooOgmoo`000013ooooo`Ko2NX:7_ooool00ol0
003oooooooooo`0>ooooo`00Xoooool01?l0003oOgmoogmoOol0001:ooooo`Go2NX:6Oooool00ol0
003oooooooooo`0>ooooo`00Xoooool01?l0003oooooogmoOol0001?ooooo`Ko2NX:4oooool00ol0
003oooooooooo`0>ooooo`00Xoooool01?l0003oooooooooool0001Eooooo`Ko2NX:3Oooool00ol0
003oooooooooo`0>ooooo`00Xoooool01?l0003oooooooooool0001Kooooo`Go2NX:2?ooool00ol0
003oooooooooo`0>ooooo`00Xoooool01?l0003oooooooooool0001Pooooo`Ko2NX:0_ooool00ol0
003oooooooooo`0>ooooo`00Xoooool00ol0003oooooo`00001Wooooo`;o2NX:0_l0000?ooooo`00
Xoooool00ol0003oooooo`00001Yooooo`;o00003oooool00:?ooooo00?o0000ooooool00000JOoo
ool00ol0003oooooooooo`0>ooooo`00Xoooool2o`0006[ooooo00?o0000ooooooooool03_ooool0
0:?ooooo0_l0001Zooooo`03o`000?oooooooooo00kooooo002Sooooo`;o0000J_ooool00ol0003o
ooooooooo`0>ooooo`00Xoooool2o`0006[ooooo00?o0000ooooooooool03_ooool00:?ooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`0>ooooo`00Xoooool00ol0003oooooooooo`1Y
ooooo`03o`000?oooooooooo00kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.58648 .10972 m
.48515 .10972 L
% vacuous filled polygon
newpath
.48515 .10972 m
.58648 .10972 L
.57143 .1494 L
.5 .1494 L
.48515 .10972 L
F
.5 .1494 m
.57143 .1494 L
.58648 .18909 L
.48515 .18909 L
.5 .1494 L
F
.48515 .18909 m
.58648 .18909 L
.48515 .18909 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.48515 .10972 m
.5 .1494 L
.48515 .18909 L
s
.58648 .18909 m
.57143 .1494 L
.58648 .10972 L
s
.5 g
.58648 .1494 m
.48515 .1494 L
% vacuous filled polygon
newpath
.48515 .1494 m
.58648 .1494 L
.57143 .1494 L
.5 .1494 L
.48515 .1494 L
F
.5 .1494 m
.57143 .1494 L
.58648 .1494 L
.48515 .1494 L
.5 .1494 L
F
.48515 .1494 m
.58648 .1494 L
.48515 .1494 L
F
0 g
.48515 .1494 m
.5 .1494 L
.48515 .1494 L
s
.58648 .1494 m
.57143 .1494 L
.58648 .1494 L
s
.5 g
.61957 .03036 m
.6058 .07004 L
% vacuous filled polygon
newpath
.6058 .07004 m
.59784 .10972 L
.58648 .10972 L
F
.58648 .10972 m
.59784 .10972 L
.59524 .1494 L
.57143 .1494 L
.58648 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59784 .18909 L
.58648 .18909 L
.57143 .1494 L
F
.58648 .18909 m
.59784 .18909 L
.6058 .22877 L
.58648 .18909 L
F
.6058 .22877 m
.61957 .26845 L
% vacuous filled polygon
newpath
0 g
.58648 .10972 m
.57143 .1494 L
.58648 .18909 L
s
.61957 .26845 m
.6058 .22877 L
.59784 .18909 L
.59524 .1494 L
.59784 .10972 L
.6058 .07004 L
.61957 .03036 L
s
.5 g
.61957 .1494 m
.6058 .1494 L
% vacuous filled polygon
newpath
.6058 .1494 m
.59784 .1494 L
.58648 .1494 L
F
.58648 .1494 m
.59784 .1494 L
.59524 .1494 L
.57143 .1494 L
.58648 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59784 .1494 L
.58648 .1494 L
.57143 .1494 L
F
.58648 .1494 m
.59784 .1494 L
.6058 .1494 L
.58648 .1494 L
F
.6058 .1494 m
.61957 .1494 L
% vacuous filled polygon
newpath
0 g
.58648 .1494 m
.57143 .1494 L
.58648 .1494 L
s
.61957 .1494 m
.6058 .1494 L
.59784 .1494 L
.59524 .1494 L
.59784 .1494 L
.6058 .1494 L
.61957 .1494 L
s
.61957 .26845 m
.61957 .2644 L
s
.61957 .2644 m
.61957 .2525 L
s
.61957 .2525 m
.61957 .23358 L
s
.61957 .23358 m
.61957 .20893 L
s
.61957 .20893 m
.61957 .18022 L
s
.61957 .18022 m
.61957 .1494 L
s
.61957 .1494 m
.61957 .11859 L
s
.61957 .11859 m
.61957 .08988 L
s
.61957 .08988 m
.61957 .06523 L
s
.61957 .06523 m
.61957 .04631 L
s
.61957 .04631 m
.61957 .03441 L
s
.61957 .03441 m
.61957 .03036 L
s
.61957 .03036 m
.61957 .03441 L
s
.61957 .03441 m
.61957 .04631 L
s
.61957 .04631 m
.61957 .06523 L
s
.61957 .06523 m
.61957 .08988 L
s
.61957 .08988 m
.61957 .11859 L
s
.61957 .11859 m
.61957 .1494 L
s
.61957 .1494 m
.61957 .18022 L
s
.61957 .18022 m
.61957 .20893 L
s
.61957 .20893 m
.61957 .23358 L
s
.61957 .23358 m
.61957 .2525 L
s
.61957 .2525 m
.61957 .2644 L
s
.61957 .2644 m
.61957 .26845 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49511 .1256 L
s
0 0 0 r
2 Mabswid
.49511 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49829 .13512 L
s
0 0 0 r
2 Mabswid
.49829 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49981 .14464 L
s
0 0 0 r
2 Mabswid
.49981 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49981 .15417 L
s
0 0 0 r
2 Mabswid
.49981 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49829 .16369 L
s
0 0 0 r
2 Mabswid
.49829 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49511 .17321 L
s
0 0 0 r
2 Mabswid
.49511 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49511 .1256 m
.58362 .1132 L
s
0 0 0 r
2 Mabswid
.58362 .1132 Mdot
.039 .916 .04 r
.5 Mabswid
.49829 .13512 m
.57504 .12894 L
s
0 0 0 r
2 Mabswid
.57504 .12894 Mdot
.039 .916 .04 r
.5 Mabswid
.49981 .14464 m
.5718 .14275 L
s
0 0 0 r
2 Mabswid
.5718 .14275 Mdot
.039 .916 .04 r
.5 Mabswid
.49981 .15417 m
.5718 .15606 L
s
0 0 0 r
2 Mabswid
.5718 .15606 Mdot
.039 .916 .04 r
.5 Mabswid
.49829 .16369 m
.57504 .16987 L
s
0 0 0 r
2 Mabswid
.57504 .16987 Mdot
.039 .916 .04 r
.5 Mabswid
.49511 .17321 m
.58362 .18561 L
s
0 0 0 r
2 Mabswid
.58362 .18561 Mdot
.039 .916 .04 r
.5 Mabswid
.58362 .1132 m
.59738 .11344 L
s
0 0 0 r
2 Mabswid
.59738 .11344 Mdot
.039 .916 .04 r
.5 Mabswid
.57504 .12894 m
.59594 .12883 L
s
0 0 0 r
2 Mabswid
.59594 .12883 Mdot
.039 .916 .04 r
.5 Mabswid
.5718 .14275 m
.59531 .14267 L
s
0 0 0 r
2 Mabswid
.59531 .14267 Mdot
.039 .916 .04 r
.5 Mabswid
.5718 .15606 m
.59531 .15614 L
s
0 0 0 r
2 Mabswid
.59531 .15614 Mdot
.039 .916 .04 r
.5 Mabswid
.57504 .16987 m
.59594 .16998 L
s
0 0 0 r
2 Mabswid
.59594 .16998 Mdot
.039 .916 .04 r
.5 Mabswid
.58362 .18561 m
.59738 .18537 L
s
0 0 0 r
2 Mabswid
.59738 .18537 Mdot
.039 .916 .04 r
.5 Mabswid
.59738 .11344 m
.97619 .0888 L
s
0 0 0 r
2 Mabswid
.97619 .0888 Mdot
.039 .916 .04 r
.5 Mabswid
.59594 .12883 m
.97619 .10447 L
s
0 0 0 r
2 Mabswid
.97619 .10447 Mdot
.039 .916 .04 r
.5 Mabswid
.59531 .14267 m
.97619 .13369 L
s
0 0 0 r
2 Mabswid
.97619 .13369 Mdot
.039 .916 .04 r
.5 Mabswid
.59531 .15614 m
.97619 .16512 L
s
0 0 0 r
2 Mabswid
.97619 .16512 Mdot
.039 .916 .04 r
.5 Mabswid
.59594 .16998 m
.97619 .19434 L
s
0 0 0 r
2 Mabswid
.97619 .19434 Mdot
.039 .916 .04 r
.5 Mabswid
.59738 .18537 m
.97619 .21001 L
s
0 0 0 r
2 Mabswid
.97619 .21001 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00:oooooo00?o0000oooo
ooooool0GOooool00ol0003oooooooooo`0>ooooo`00[oooool00ol0003oooooooooo`1Mooooo`03
o`000?oooooooooo00kooooo002^ooooo`;o0000Goooool00ol0003oooooooooo`0>ooooo`00[_oo
ool2o`0005oooooo00?o0000ooooooooool03_ooool00:kooooo0_l0001Oooooo`03o`000?oooooo
oooo00kooooo002]ooooo`03o`000?oooooo000005oooooo00?o0000ooooooooool03_ooool00:go
oooo00?o0000ooooool00000Goooool00ol0003oooooooooo`0>ooooo`00[?ooool01?l0003ooooo
ooooool0001Oooooo`03o`000?oooooooooo00kooooo002/ooooo`04o`000?ooooooooooo`0005oo
oooo00?o0000ooooooooool03_ooool00:cooooo00Co0000oooooooooooo0000Goooool00ol0003o
ooooooooo`0>ooooo`00Zoooool01Ol0003ooooooooooooooooo000005oooooo00?o0000oooooooo
ool03_ooool00:_ooooo00Go0000ooooooooooooooooo`00001Oooooo`03o`000?oooooooooo00ko
oooo002[ooooo`05o`000?ooooooooooooooool00000Goooool00ol0003oooooooooo`0>ooooo`00
Z_ooool00omoOgoo0000ooooo`02ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
3_ooool00:[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo00kooooo002Yooooo`03ogmoOol0003ooooo00?ooooo00?o0000ooooooooool0E_ooool7
o`WZ2P;o00003oooool00:Wooooo00?oOgmoo`000?ooool00oooool00ol0003oooooooooo`17oooo
o`oo2NX:1oooool2o`0000oooooo002Xooooo`;oOgmo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0iooooo`ko2NX:5_ooool00ol0003oooooooooo`0>ooooo`00Z?ooool2ogmoO`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool?o`WZ2RCooooo00?o0000ooooooooool0
3_ooool00:Sooooo00?oOgmoo`000?ooool01?ooool00ol0003oooooooooo`0Kooooo`oo2NX:<ooo
ool2o`0000oooooo002Wooooo`;oOgmo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=
ooooo`ko2NX:>_ooool8o`WZ2P;o00003oooool008_ooooo00?o0000ooooooooool05oooool2o`00
00;oOgmo00?o0000ooooooooool00oooool00ol0003o2NX:o`WZ2P0=o`WZ2SOooooo4Ol9jPX8oooo
o`03o`000?oooooooooo00kooooo002;ooooo`03o`000?moOgooOgmo01?oOgmo3ol9jPXeoooooa7o
2NX:6Oooool00ol0003oooooooooo`0>ooooo`00S?ooool00ol0003oOgmoogmoO`0:ogmoO`So2NX:
1?moOgl01?l0003oOgmoogmoOomoOgl2o`0000Cooooo00?o0000ooooooooool08_oooolAo`WZ2R[o
oooo00?o0000ooooooooool03_ooool008cooooo00?o0000ogmoOomoOgl00omoOgl7o`WZ2PcoOgmo
00Go0000ogmoOomoOgooOgmoo`000005ooooo`03o`000?oooooooooo017ooooo4Ol9jPXkooooo`03
o`000?oooooooooo00kooooo000?ooooogko2NX:00?o0000o`WZ2_l9jPX00_l9jPXCogmoO`05o`00
0?moOgooOgmoogmoOol000001Oooool00ol0003oooooooooo`0Ao`WZ2Tcooooo00?o0000oooooooo
ool03_ooool008gooooo0_l0000?ogmoO`[o2NX:00?o0000o`WZ2_l9jPX01ol9jPYMooooo`03o`00
0?oooooooooo00kooooo002=ooooo`?o00001?moOgl:o`WZ2PGoOgmo0_l00003ogmoO`;o00001Ooo
ool00ol0003oooooooooo`1<oooooa7o2NX:0_l0000?ooooo`003ooooomoo`WZ2P03o`000?l9jP[o
2NX:00?o2NX:4?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0:_oooolRo`WZ2Q7ooooo0_l0000?ooooo`00S_ooool00ol0003oOgmoogmoO`0Aogmo
O`;o00001?moOgl2o`0000Gooooo00?o0000ooooooooool02?oooolRo`WZ2S?ooooo00?o0000oooo
ooooool03_ooool000ooooooOol9jPX00ol0003o2NX:o`WZ2P0Go`WZ2P03o`000?l9jP[o2NX:00oo
2NX:EOooool00ol0003oooooooooo`0>ooooo`00S_ooool2o`0001?oOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
3_ooool008_ooooo1Ol0000BogmoO`Go00000_moOgl7o`0005oooooo00?o0000ooooooooool03_oo
ool000ooooooOol9jPX00ol0003o2NX:o`WZ2P09o`WZ2PSoOgmo0_l00004ogmoO`;o00001Oooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00kooooo002>ooooo`;o00002_moOgl>o`WZ
2P03o`000?l9jP[o2NX:01Wo2NX:Boooool00ol0003oooooooooo`0>ooooo`00S_ooool2o`0001?o
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;o
oooo<ol9jPXHooooo`;o00003oooool000ooooooOol9jPX00ol0003o2NX:o`WZ2P09o`WZ2PWoOgmo
00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Gooooo
6?l9jPX2o`0000oooooo002=ooooo`03o`000?moOgooOgmo00[oOgmo3_l9jPX00ol0003o2NX:o`WZ
2P06o`WZ2Ukooooo00?o0000ooooooooool03_ooool000ooooooO_l9jPX00ol0003o2NX:o`WZ2P03
o`WZ2Q3oOgmo0_l00003ogmoO`;o00001Oooool00ol0003oooooo`WZ2P0>o`WZ2Toooooo00?o0000
ooooooooool03_ooool008cooooo0ol00004ogmoO`So2NX:2_moOgl01Ol0003oOgmoogmoOomoOgoo
000000Gooooo00?o0000ooooooooool03_ooool>o`WZ2T7ooooo00?o0000ooooooooool03_ooool0
08cooooo00?o0000ogmoOomoOgl03?moOgl7o`WZ2P?oOgmo00Go0000ogmoOomoOgooOgmoo`000005
ooooo`03o`000?oooooooooo01cooooo3ol9jPXbooooo`03o`000?oooooooooo00kooooo002<oooo
o`03o`000?moOgooOgmo01?oOgmo3ol9jPX/ooooo`oo2NX:8oooool00ol0003oooooooooo`0>oooo
o`00Roooool00ol0003oOgmoogmoO`0GogmoO`;o00000_moOgl2o`0000Cooooo00?o0000ooooool9
jPX03_l9jPX/ooooo`ko2NX:5Oooool00ol0003oooooooooo`0>ooooo`00Y_ooool3ogmoO`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool>o`WZ2Rcooooo3ol9jPX6ooooo`;o0000
3oooool00:Oooooo0_moOgl00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo3ol9
jPX/ooooo`Ko2NX:0_l0000?ooooo`00Yoooool2ogmoO`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0:oooool?o`WZ2R?ooooo00?o0000ooooooooool03_ooool00:Sooooo0_moOgl00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03[ooooo3_l9jPXEooooo`03o`000?oooooooooo
00kooooo002Xooooo`;oOgmo00?o0000ooooooooool00_ooool00ol0003oooooooooo`18ooooo`oo
2NX:1_ooool00ol0003oooooooooo`0>ooooo`00ZOooool00omoOgoo0000ooooo`03ooooo`03o`00
0?oooooooooo05Oooooo1_l9jPX2o`0000oooooo002Yooooo`03ogmoOol0003ooooo00?ooooo00?o
0000ooooooooool0GOooool2o`0000oooooo002Yooooo`03ogmoOol0003ooooo00?ooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`0>ooooo`00Z_ooool00omoOgoo0000ooooo`02oooo
o`03o`000?oooooooooo05gooooo00?o0000ooooooooool03_ooool00:[ooooo00?oOgmoo`000?oo
ool00_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00kooooo002[ooooo`05o`00
0?ooooooooooooooool00000Goooool00ol0003oooooooooo`0>ooooo`00Zoooool01Ol0003ooooo
oooooooooooo000005oooooo00?o0000ooooooooool03_ooool00:cooooo00Co0000oooooooooooo
0000Goooool00ol0003oooooooooo`0>ooooo`00[?ooool01?l0003oooooooooool0001Oooooo`03
o`000?oooooooooo00kooooo002/ooooo`04o`000?ooooooooooo`0005oooooo00?o0000oooooooo
ool03_ooool00:gooooo00?o0000ooooool00000Goooool00ol0003oooooooooo`0>ooooo`00[Ooo
ool00ol0003oooooo`00001Oooooo`03o`000?oooooooooo00kooooo002]ooooo`03o`000?oooooo
000005oooooo00?o0000ooooooooool03_ooool00:kooooo0_l0001Oooooo`03o`000?oooooooooo
00kooooo002^ooooo`;o0000Goooool00ol0003oooooooooo`0>ooooo`00[_ooool2o`0005oooooo
00?o0000ooooooooool03_ooool00:oooooo00?o0000ooooooooool0GOooool00ol0003ooooooooo
o`0>ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.58427 .10972 m
.48899 .10972 L
% vacuous filled polygon
newpath
.48899 .10972 m
.58427 .10972 L
.57143 .1494 L
.5 .1494 L
.48899 .10972 L
F
.5 .1494 m
.57143 .1494 L
.58427 .18909 L
.48899 .18909 L
.5 .1494 L
F
.48899 .18909 m
.58427 .18909 L
.48899 .18909 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.48899 .10972 m
.5 .1494 L
.48899 .18909 L
s
.58427 .18909 m
.57143 .1494 L
.58427 .10972 L
s
.5 g
.58427 .1494 m
.48899 .1494 L
% vacuous filled polygon
newpath
.48899 .1494 m
.58427 .1494 L
.57143 .1494 L
.5 .1494 L
.48899 .1494 L
F
.5 .1494 m
.57143 .1494 L
.58427 .1494 L
.48899 .1494 L
.5 .1494 L
F
.48899 .1494 m
.58427 .1494 L
.48899 .1494 L
F
0 g
.48899 .1494 m
.5 .1494 L
.48899 .1494 L
s
.58427 .1494 m
.57143 .1494 L
.58427 .1494 L
s
.5 g
.57709 .10972 m
.58427 .10972 L
% vacuous filled polygon
newpath
.58427 .10972 m
.57709 .10972 L
.59524 .1494 L
.57143 .1494 L
.58427 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.57709 .18909 L
.58427 .18909 L
.57143 .1494 L
F
.58427 .18909 m
.57709 .18909 L
.58427 .18909 L
F
0 g
.58427 .10972 m
.57143 .1494 L
.58427 .18909 L
s
.57709 .18909 m
.59524 .1494 L
.57709 .10972 L
s
.5 g
.57709 .1494 m
.58427 .1494 L
% vacuous filled polygon
newpath
.58427 .1494 m
.57709 .1494 L
.59524 .1494 L
.57143 .1494 L
.58427 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.57709 .1494 L
.58427 .1494 L
.57143 .1494 L
F
.58427 .1494 m
.57709 .1494 L
.58427 .1494 L
F
0 g
.58427 .1494 m
.57143 .1494 L
.58427 .1494 L
s
.57709 .1494 m
.59524 .1494 L
.57709 .1494 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49623 .1256 L
s
0 0 0 r
2 Mabswid
.49623 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49866 .13512 L
s
0 0 0 r
2 Mabswid
.49866 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49985 .14464 L
s
0 0 0 r
2 Mabswid
.49985 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49985 .15417 L
s
0 0 0 r
2 Mabswid
.49985 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49866 .16369 L
s
0 0 0 r
2 Mabswid
.49866 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49623 .17321 L
s
0 0 0 r
2 Mabswid
.49623 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49623 .1256 m
.57988 .11664 L
s
0 0 0 r
2 Mabswid
.57988 .11664 Mdot
.039 .916 .04 r
.5 Mabswid
.49866 .13512 m
.57415 .13039 L
s
0 0 0 r
2 Mabswid
.57415 .13039 Mdot
.039 .916 .04 r
.5 Mabswid
.49985 .14464 m
.57172 .14316 L
s
0 0 0 r
2 Mabswid
.57172 .14316 Mdot
.039 .916 .04 r
.5 Mabswid
.49985 .15417 m
.57172 .15565 L
s
0 0 0 r
2 Mabswid
.57172 .15565 Mdot
.039 .916 .04 r
.5 Mabswid
.49866 .16369 m
.57415 .16842 L
s
0 0 0 r
2 Mabswid
.57415 .16842 Mdot
.039 .916 .04 r
.5 Mabswid
.49623 .17321 m
.57988 .18217 L
s
0 0 0 r
2 Mabswid
.57988 .18217 Mdot
.039 .916 .04 r
.5 Mabswid
.57988 .11664 m
.58376 .11666 L
s
0 0 0 r
2 Mabswid
.58376 .11666 Mdot
.039 .916 .04 r
.5 Mabswid
.57415 .13039 m
.59165 .13034 L
s
0 0 0 r
2 Mabswid
.59165 .13034 Mdot
.039 .916 .04 r
.5 Mabswid
.57172 .14316 m
.59486 .14312 L
s
0 0 0 r
2 Mabswid
.59486 .14312 Mdot
.039 .916 .04 r
.5 Mabswid
.57172 .15565 m
.59486 .15569 L
s
0 0 0 r
2 Mabswid
.59486 .15569 Mdot
.039 .916 .04 r
.5 Mabswid
.57415 .16842 m
.59165 .16847 L
s
0 0 0 r
2 Mabswid
.59165 .16847 Mdot
.039 .916 .04 r
.5 Mabswid
.57988 .18217 m
.58376 .18215 L
s
0 0 0 r
2 Mabswid
.58376 .18215 Mdot
.039 .916 .04 r
.5 Mabswid
.58376 .11666 m
.57318 .16472 L
s
0 0 0 r
2 Mabswid
.57318 .16472 Mdot
.039 .916 .04 r
.5 Mabswid
.59165 .13034 m
.97619 .26399 L
s
0 0 0 r
2 Mabswid
.97619 .26399 Mdot
.039 .916 .04 r
.5 Mabswid
.59486 .14312 m
.97619 .17907 L
s
0 0 0 r
2 Mabswid
.97619 .17907 Mdot
.039 .916 .04 r
.5 Mabswid
.59486 .15569 m
.97619 .11974 L
s
0 0 0 r
2 Mabswid
.97619 .11974 Mdot
.039 .916 .04 r
.5 Mabswid
.59165 .16847 m
.97619 .03482 L
s
0 0 0 r
2 Mabswid
.97619 .03482 Mdot
.039 .916 .04 r
.5 Mabswid
.58376 .18215 m
.57318 .13409 L
s
0 0 0 r
2 Mabswid
.57318 .13409 Mdot
.039 .916 .04 r
.5 Mabswid
.57318 .16472 m
.58538 .18002 L
s
0 0 0 r
2 Mabswid
.58538 .18002 Mdot
.039 .916 .04 r
.5 Mabswid
.57318 .13409 m
.58538 .11879 L
s
0 0 0 r
2 Mabswid
.58538 .11879 Mdot
.039 .916 .04 r
.5 Mabswid
.58538 .18002 m
.59513 .20088 L
s
0 0 0 r
2 Mabswid
.59513 .20088 Mdot
.039 .916 .04 r
.5 Mabswid
.58538 .11879 m
.59513 .09793 L
s
0 0 0 r
2 Mabswid
.59513 .09793 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oooooo4?ooool2o`00
00oooooo003oooooo`oooooo00?o2NX:o`000?l000003oooool00?oooooo3?ooool3o`WZ2P03oooo
ool0003ooooo00oooooo003oooooo`Wooooo0ol9jPX4ooooo`03o`000?oooooooooo00kooooo003o
ooooo`Kooooo0ol9jPX7ooooo`03o`000?oooooooooo00kooooo003oooooo`?ooooo0ol9jPX:oooo
o`03o`000?oooooooooo00kooooo003oooooo`?o2NX:3Oooool00ol0003oooooooooo`0>ooooo`00
o?ooool3o`WZ2Q3ooooo00?o0000ooooooooool03_ooool00?[ooooo0_l9jPXCooooo`03o`000?oo
oooooooo00kooooo003gooooo`?o2NX:5Oooool00ol0003oooooooooo`0>ooooo`00m?ooool3o`WZ
2QSooooo00?o0000ooooooooool03_ooool00?7ooooo0ol9jPXKooooo`03o`000?oooooooooo00ko
oooo003^ooooo`?o2NX:7_ooool00ol0003oooooooooo`0>ooooo`00joooool3o`WZ2R7ooooo00?o
0000ooooooooool03_ooool00>Sooooo0ol9jPXTooooo`03o`000?oooooooooo00kooooo003Voooo
o`;o2NX:9oooool00ol0003oooooooooo`0>ooooo`00hoooool3o`WZ2RWooooo00?o0000oooooooo
ool03_ooool00:Sooooo0_l0000fooooo`?o2NX:;?ooool00ol0003oooooooooo`0>ooooo`00Z?oo
ool2o`0003?ooooo0ol9jPX_ooooo`03o`000?oooooooooo00kooooo002Yooooo`03o`WZ2_oooooo
oooo02kooooo0ol9jPXbooooo`03o`000?oooooooooo00kooooo002Xooooo`03o`WZ2_oooooooooo
02cooooo0ol9jPXeooooo`03o`000?oooooooooo00kooooo002<ooooo`03o`000?oooooooooo01Go
oooo00Co0000ooooool0003o2NX:;?ooool3o`WZ2SSooooo00?o0000ooooooooool03_ooool008co
oooo00?o0000ogmoOomoOgl05OmoOgl3o`000003o`WZ2_oooooooooo02Oooooo0ol9jPXkooooo`03
o`000?oooooooooo00kooooo002<ooooo`03o`000?moOgooOgmo013oOgmo1_l9jPX00ol0003o2NX:
ooooo`0Wooooo`;o2NX:?_ooool2o`0000oooooo002=ooooo`03o`000?moOgooOgmo00CoOgmo2ol9
jPX6ogmoO`;o00009Oooool3o`WZ2S[ooooo1_l9jPX2o`0000oooooo000?ooooogko2NX:00?o0000
o`WZ2_l9jPX01?l9jPXAogmoO`;o2NX:8_ooool3o`WZ2S;ooooo2ol9jPX6ooooo`03o`000?oooooo
oooo00kooooo002=ooooo`;o00004omoOgl2o`0000;o2NX:0ol0000Mooooo`?o2NX::_ooool;o`WZ
2Q7ooooo00?o0000ooooooooool03_ooool008kooooo0_l00009ogmoO`Wo2NX:0_l00003o`WZ2P03
o`000?l9jP[o2NX:01Wooooo0ol9jPXQooooo`co2NX:7?ooool00ol0003oooooooooo`0>ooooo`00
3ooooomoo`WZ2P03o`000?l9jP[o2NX:00So2NX:2OmoOgl01_l0003o2NX:o`000?l9jP[oOgmoo`00
00;ooooo0ol9jPXCooooo`?o2NX:6Oooool;o`WZ2RSooooo00?o0000ooooooooool03_ooool008ko
oooo00?o0000ogmoOomoOgl04_moOgl01Ol9jP[oOgmoo`WZ2_moOgoo000000Gooooo0ol9jPX=oooo
o`?o2NX:4Oooool;o`WZ2S?ooooo00?o0000ooooooooool03_ooool000ooooooOol9jPX00ol0003o
2NX:o`WZ2P0Go`WZ2P03o`000?l9jP[o2NX:00Co2NX:00Coooooo`WZ2_l9jP[o2NX:2?ooool2o`WZ
2PSooooo3?l9jPXnooooo`03o`000?oooooooooo00kooooo002>ooooo`;o00004_moOgl2o`000004
o`WZ2_moOgooOgmoogmoO`;o00001OoooolFo`WZ2T[ooooo00?o0000ooooooooool03_ooool008co
oooo1?l0000BogmoO`;o000000?o2NX:o`000?l000000ol00005oooooaGo2NX:Boooool00ol0003o
ooooooooo`0>ooooo`003ooooomoo`WZ2P03o`000?l9jP[o2NX:01Oo2NX:00?o0000o`WZ2_l9jPX0
1?l9jPX3ooooo`?o2NX:1?ooool3o`WZ2PSooooo2_l9jPY1ooooo`03o`000?oooooooooo00kooooo
002>ooooo`;o00004_moOgl2o`000004o`WZ2_moOgooOgmoogmoO`;o00001Oooool3o`WZ2P[ooooo
0_l9jPX@ooooo`[o2NX:=oooool00ol0003oooooooooo`0>ooooo`00S_ooool2o`0001;oOgmo0_l0
00001OmoOgoo2NX:ogmoOomoOgoo000000?ooooo0ol9jPX?ooooo`?o2NX:5oooool:o`WZ2Rgooooo
00?o0000ooooooooool03_ooool000ooooooOol9jPX00ol0003o2NX:o`WZ2P09o`WZ2PSoOgmo00Go
0000o`WZ2_moOgoo2NX:ogmoO`02o`0000?o2NX:5Oooool3o`WZ2Qkooooo2_l9jPXSooooo`03o`00
0?oooooooooo00kooooo002>ooooo`03o`000?moOgooOgmo00WoOgmo2?l9jPX00ol0003o2NX:o`WZ
2P02o`WZ2P03o`000?l9jP[ooooo01[ooooo0ol9jPXUooooo`_o2NX:6?ooool00ol0003ooooooooo
o`0>ooooo`003ooooomno`WZ2P03o`000?l9jP[o2NX:00?o2NX:4OmoOgl2o`WZ2P03o`000?oooooo
oooo01kooooo0ol9jPX]ooooo`[o2NX:3_ooool00ol0003oooooooooo`0>ooooo`00SOooool2o`00
00CoOgmo1ol9jPX;ogmoO`;o00008oooool3o`WZ2SCooooo2_l9jPX4ooooo`;o00003oooool008go
oooo00?o0000ogmoOomoOgl02_moOgl7o`WZ2P?oOgmo0_l000000ol9jP[oooooooooo`0Tooooo`?o
2NX:>oooool4o`WZ2P;o00003oooool008cooooo00?o0000ogmoOomoOgl04_moOgl4o`WZ2P03o`00
0?l9jP[ooooo02Sooooo0_l9jPXmooooo`03o`000?oooooooooo00kooooo002<ooooo`03o`000?mo
OgooOgmo01GoOgmo00Co0000ogmoOol0003o2NX::_ooool3o`WZ2S[ooooo00?o0000ooooooooool0
3_ooool00:Oooooo00?o2NX:ooooooooool0:oooool3o`WZ2SOooooo00?o0000ooooooooool03_oo
ool00:Sooooo00?o2NX:ooooooooool0;Oooool3o`WZ2SCooooo00?o0000ooooooooool03_ooool0
0:Sooooo0_l0000aooooo`?o2NX:<Oooool00ol0003oooooooooo`0>ooooo`00Z?ooool2o`0003Co
oooo0ol9jPX^ooooo`03o`000?oooooooooo00kooooo003Qooooo`?o2NX::oooool00ol0003ooooo
ooooo`0>ooooo`00i?ooool3o`WZ2RSooooo00?o0000ooooooooool03_ooool00>Oooooo0_l9jPXV
ooooo`03o`000?oooooooooo00kooooo003Yooooo`?o2NX:8oooool00ol0003oooooooooo`0>oooo
o`00k?ooool3o`WZ2R3ooooo00?o0000ooooooooool03_ooool00>oooooo0ol9jPXMooooo`03o`00
0?oooooooooo00kooooo003booooo`?o2NX:6_ooool00ol0003oooooooooo`0>ooooo`00mOooool3
o`WZ2QOooooo00?o0000ooooooooool03_ooool00?Sooooo0ol9jPXDooooo`03o`000?oooooooooo
00kooooo003kooooo`;o2NX:4_ooool00ol0003oooooooooo`0>ooooo`00oOooool3o`WZ2Poooooo
00?o0000ooooooooool03_ooool00?oooooo0Oooool3o`WZ2Pcooooo00?o0000ooooooooool03_oo
ool00?oooooo1?ooool3o`WZ2PWooooo00?o0000ooooooooool03_ooool00?oooooo1oooool3o`WZ
2PKooooo00?o0000ooooooooool03_ooool00?oooooo2_ooool3o`WZ2P?ooooo00?o0000oooooooo
ool03_ooool00?oooooo3Oooool3o`WZ2P;o00003oooool00?oooooo4?ooool2o`0000oooooo003o
oooooa3ooooo00?o0000ooooooooool03_ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.46094 .07004 m
% vacuous filled polygon
newpath
.46094 .07004 m
.58874 .10972 L
.4918 .10972 L
.46094 .07004 L
F
.4918 .10972 m
.58874 .10972 L
.57143 .1494 L
.5 .1494 L
.4918 .10972 L
F
.5 .1494 m
.57143 .1494 L
.58874 .18909 L
.4918 .18909 L
.5 .1494 L
F
.4918 .18909 m
.58874 .18909 L
.46094 .22877 L
.4918 .18909 L
F
.46094 .22877 m
.46094 .22877 L
% vacuous filled polygon
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.46094 .07004 m
.4918 .10972 L
.5 .1494 L
.4918 .18909 L
.46094 .22877 L
s
.58874 .18909 m
.57143 .1494 L
.58874 .10972 L
s
.5 g
.46094 .1494 m
% vacuous filled polygon
newpath
.46094 .1494 m
.58874 .1494 L
.4918 .1494 L
.46094 .1494 L
F
.4918 .1494 m
.58874 .1494 L
.57143 .1494 L
.5 .1494 L
.4918 .1494 L
F
.5 .1494 m
.57143 .1494 L
.58874 .1494 L
.4918 .1494 L
.5 .1494 L
F
.4918 .1494 m
.58874 .1494 L
.46094 .1494 L
.4918 .1494 L
F
.46094 .1494 m
.46094 .1494 L
% vacuous filled polygon
newpath
0 g
.46094 .1494 m
.4918 .1494 L
.5 .1494 L
.4918 .1494 L
.46094 .1494 L
s
.58874 .1494 m
.57143 .1494 L
.58874 .1494 L
s
.5 g
.68981 .03036 m
.62451 .07004 L
% vacuous filled polygon
newpath
.62451 .07004 m
.60186 .10972 L
.58874 .10972 L
F
.58874 .10972 m
.60186 .10972 L
.59524 .1494 L
.57143 .1494 L
.58874 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.60186 .18909 L
.58874 .18909 L
.57143 .1494 L
F
.58874 .18909 m
.60186 .18909 L
.62451 .22877 L
.58874 .18909 L
F
.62451 .22877 m
.68981 .26845 L
% vacuous filled polygon
newpath
0 g
.58874 .10972 m
.57143 .1494 L
.58874 .18909 L
s
.68981 .26845 m
.62451 .22877 L
.60186 .18909 L
.59524 .1494 L
.60186 .10972 L
.62451 .07004 L
.68981 .03036 L
s
.5 g
.68981 .1494 m
.62451 .1494 L
% vacuous filled polygon
newpath
.62451 .1494 m
.60186 .1494 L
.58874 .1494 L
F
.58874 .1494 m
.60186 .1494 L
.59524 .1494 L
.57143 .1494 L
.58874 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.60186 .1494 L
.58874 .1494 L
.57143 .1494 L
F
.58874 .1494 m
.60186 .1494 L
.62451 .1494 L
.58874 .1494 L
F
.62451 .1494 m
.68981 .1494 L
% vacuous filled polygon
newpath
0 g
.58874 .1494 m
.57143 .1494 L
.58874 .1494 L
s
.68981 .1494 m
.62451 .1494 L
.60186 .1494 L
.59524 .1494 L
.60186 .1494 L
.62451 .1494 L
.68981 .1494 L
s
.68981 .26845 m
.68981 .2644 L
s
.68981 .2644 m
.68981 .2525 L
s
.68981 .2525 m
.68981 .23358 L
s
.68981 .23358 m
.68981 .20893 L
s
.68981 .20893 m
.68981 .18022 L
s
.68981 .18022 m
.68981 .1494 L
s
.68981 .1494 m
.68981 .11859 L
s
.68981 .11859 m
.68981 .08988 L
s
.68981 .08988 m
.68981 .06523 L
s
.68981 .06523 m
.68981 .04631 L
s
.68981 .04631 m
.68981 .03441 L
s
.68981 .03441 m
.68981 .03036 L
s
.68981 .03036 m
.68981 .03441 L
s
.68981 .03441 m
.68981 .04631 L
s
.68981 .04631 m
.68981 .06523 L
s
.68981 .06523 m
.68981 .08988 L
s
.68981 .08988 m
.68981 .11859 L
s
.68981 .11859 m
.68981 .1494 L
s
.68981 .1494 m
.68981 .18022 L
s
.68981 .18022 m
.68981 .20893 L
s
.68981 .20893 m
.68981 .23358 L
s
.68981 .23358 m
.68981 .2525 L
s
.68981 .2525 m
.68981 .2644 L
s
.68981 .2644 m
.68981 .26845 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49713 .1256 L
s
0 0 0 r
2 Mabswid
.49713 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49898 .13512 L
s
0 0 0 r
2 Mabswid
.49898 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49989 .14464 L
s
0 0 0 r
2 Mabswid
.49989 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49989 .15417 L
s
0 0 0 r
2 Mabswid
.49989 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49898 .16369 L
s
0 0 0 r
2 Mabswid
.49898 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49713 .17321 L
s
0 0 0 r
2 Mabswid
.49713 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49713 .1256 m
.5809 .11881 L
s
0 0 0 r
2 Mabswid
.5809 .11881 Mdot
.039 .916 .04 r
.5 Mabswid
.49898 .13512 m
.57447 .1315 L
s
0 0 0 r
2 Mabswid
.57447 .1315 Mdot
.039 .916 .04 r
.5 Mabswid
.49989 .14464 m
.57175 .1435 L
s
0 0 0 r
2 Mabswid
.57175 .1435 Mdot
.039 .916 .04 r
.5 Mabswid
.49989 .15417 m
.57175 .15531 L
s
0 0 0 r
2 Mabswid
.57175 .15531 Mdot
.039 .916 .04 r
.5 Mabswid
.49898 .16369 m
.57447 .16731 L
s
0 0 0 r
2 Mabswid
.57447 .16731 Mdot
.039 .916 .04 r
.5 Mabswid
.49713 .17321 m
.5809 .18 L
s
0 0 0 r
2 Mabswid
.5809 .18 Mdot
.039 .916 .04 r
.5 Mabswid
.5809 .11881 m
.59891 .11967 L
s
0 0 0 r
2 Mabswid
.59891 .11967 Mdot
.039 .916 .04 r
.5 Mabswid
.57447 .1315 m
.5965 .13192 L
s
0 0 0 r
2 Mabswid
.5965 .13192 Mdot
.039 .916 .04 r
.5 Mabswid
.57175 .1435 m
.59537 .14362 L
s
0 0 0 r
2 Mabswid
.59537 .14362 Mdot
.039 .916 .04 r
.5 Mabswid
.57175 .15531 m
.59537 .15519 L
s
0 0 0 r
2 Mabswid
.59537 .15519 Mdot
.039 .916 .04 r
.5 Mabswid
.57447 .16731 m
.5965 .16689 L
s
0 0 0 r
2 Mabswid
.5965 .16689 Mdot
.039 .916 .04 r
.5 Mabswid
.5809 .18 m
.59891 .17913 L
s
0 0 0 r
2 Mabswid
.59891 .17913 Mdot
.039 .916 .04 r
.5 Mabswid
.59891 .11967 m
.97619 .07585 L
s
0 0 0 r
2 Mabswid
.97619 .07585 Mdot
.039 .916 .04 r
.5 Mabswid
.5965 .13192 m
.97619 .1006 L
s
0 0 0 r
2 Mabswid
.97619 .1006 Mdot
.039 .916 .04 r
.5 Mabswid
.59537 .14362 m
.97619 .13267 L
s
0 0 0 r
2 Mabswid
.97619 .13267 Mdot
.039 .916 .04 r
.5 Mabswid
.59537 .15519 m
.97619 .16614 L
s
0 0 0 r
2 Mabswid
.97619 .16614 Mdot
.039 .916 .04 r
.5 Mabswid
.5965 .16689 m
.97619 .19821 L
s
0 0 0 r
2 Mabswid
.97619 .19821 Mdot
.039 .916 .04 r
.5 Mabswid
.59891 .17913 m
.97619 .22296 L
s
0 0 0 r
2 Mabswid
.97619 .22296 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00<7ooooo0_l0001<oooo
o`03o`000?oooooooooo00kooooo002oooooo`;o000000?oooooo`000?ooool0Boooool00ol0003o
ooooooooo`0>ooooo`00_Oooool2o`0000?ooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`0>ooooo`00_?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool03_ooool00;[ooooo0_l00006ooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool03_ooool00;Sooooo0_l00008ooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool03_ooool00;Kooooo0_l0000:ooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool03_ooool00;Cooooo0_l0000<ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
3_ooool00;?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo00kooooo002aooooo`;o00003oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo00kooooo0024ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo00kooooo0024ooooo`03o`000?moOgooOgmo02Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1:ooooo`;o00003oooool008Gooooo
00?o0000ogmoOomoOgl00_moOglUooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
A_ooool4o`WZ2P;o00003oooool008Kooooo00?o0000ogmoOomoOgl01?moOglRooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0?Oooool9o`WZ2PCooooo00?o0000ooooooooool03_oo
ool008Oooooo00?o0000ogmoOomoOgl01_moOglNooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0=Oooool8o`WZ2Pgooooo00?o0000ooooooooool03_ooool008Sooooo00?o0000ogmo
OomoOgl02?moOglJooooo`03ogmoOol0003ooooo01;ooooo00?o0000ooooooooool0;Oooool8o`WZ
2QGooooo00?o0000ooooooooool03_ooool008Wooooo00?o0000ogmoOomoOgl02omoOglEooooo`03
ogmoOol0003ooooo01?ooooo00?o0000ooooooooool09?ooool9o`WZ2Qgooooo00?o0000oooooooo
ool03_ooool008Wooooo00?o0000ogmoOomoOgl03_moOglAooooo`03ogmoOol0003ooooo01Cooooo
00?o0000ooooooooool07?ooool8o`WZ2RKooooo00?o0000ooooooooool03_ooool008[ooooo00?o
0000ogmoOomoOgl04?moOgl>ooooo`03ogmoOol0003ooooo01Cooooo00?o0000ooooooooool04ooo
ool9o`WZ2Rkooooo0_l0000?ooooo`00Roooool00ol0003oOgmoogmoO`0BogmoO`[ooooo00?oOgmo
o`000?ooool05Oooool00ol0003oooooooooo`0;ooooo`So2NX:<Oooool6o`WZ2P;o00003oooool0
08cooooo00?o0000ogmoOomoOgl05?moOgl6ooooo`;oOgmo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`02ooooo`Wo2NX:;?ooool=o`WZ2PKooooo00?o0000ooooooooool03_ooool008go
oooo00?o0000ogmoOomoOgl05_moOgl01Ooooooo0000ogmoOomoOgoo000001Cooooo2?l9jPXXoooo
o`go2NX:4oooool00ol0003oooooooooo`0>ooooo`00SOooool00ol0003oOgmoogmoO`0GogmoO`04
o`000?moOgooOgmoo`0000cooooo2?l9jPX3ooooo`03o`000?oooooooooo01gooooo3Ol9jPXPoooo
o`03o`000?oooooooooo00kooooo002=ooooo`03o`000?moOgooOgmo00ooOgmo1Ol9jPX00ol0003o
2NX:o`WZ2P02o`WZ2P;o00000oooool9o`WZ2P_ooooo00?o0000ooooooooool04Oooool<o`WZ2Rgo
oooo00?o0000ooooooooool03_ooool008gooooo00?o0000ogmoOomoOgl01?moOgl;o`WZ2PGoOgmo
0ol00002ogmoO`03o`000?l9jP[o2NX:00;o2NX:5?ooool00ol0003oooooooooo`04ooooo`go2NX:
>Oooool00ol0003oooooooooo`0>ooooo`003ooooon5o`WZ2Q7oOgmo00?o0000ogmoOomoOgl00_mo
Ogl00ol0003oooooooooo`0?ooooo`go2NX:A_ooool00ol0003oooooooooo`0>ooooo`00S_ooool2
o`0001?oOgmo0ol00004ogmoO`03o`000?oooooooooo00;ooooo3Ol9jPX6ooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool03_ooool008kooooo0_l00009ogmoO`oo2NX:00?o0000o`WZ
2_l9jPX01?l9jPXCooooo`03o`000?oooooooooo03Wooooo4Ol9jPX2o`0000oooooo000?ooooogoo
2NX:00?o0000o`WZ2_l9jPX02?l9jPX;ogmoO`04o`000?moOgooOgmoogmoO`;o00006?ooool00ol0
003oooooooooo`0Gooooob;o2NX:4Oooool2o`0000oooooo002>ooooo`03o`000?moOgooOgmo01?o
Ogmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`0>ooooob;o2NX:<oooool00ol0003o
ooooooooo`0>ooooo`003ooooomoo`WZ2P03o`000?l9jP[o2NX:01Oo2NX:00?o0000o`WZ2_l9jPX0
3ol9jPX8ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool03_ooool008kooooo0_l0
000BogmoO`;o00001?moOgl2o`0001Sooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0>ooooo`00Q?ooool<o`0001;oOgmo1_l000000omoOgoo0000o`00000Ho`0004cooooo00?o0000
ooooooooool03_ooool000ooooooOol9jPX00ol0003o2NX:o`WZ2P0Go`WZ2P03o`000?l9jP[o2NX:
013o2NX:1oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00kooooo002>ooooo`;o
00004_moOgl2o`0000CoOgmo0_l0000Aooooob;o2NX:<_ooool00ol0003oooooooooo`0>ooooo`00
S_ooool2o`0001?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Sooooo8_l9jPX@ooooo`03o`000?oooooooooo00kooooo000?ooooogoo2NX:00?o
0000o`WZ2_l9jPX02Ol9jPX9ogmoO`;o000000CoOgmoo`WZ2_l9jP[o00001ol9jPXBooooo`03o`00
0?oooooooooo03[ooooo4?l9jPX2o`0000oooooo002>ooooo`03o`000?moOgooOgmo00WoOgmo3?l9
jPX2ogmoO`;o00001_ooool;o`WZ2POooooo00?o0000ooooooooool0B_ooool2o`0000oooooo000?
ooooohKo2NX:4?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo00kooooo2ol9jPY9
ooooo`03o`000?oooooooooo00kooooo002>ooooo`;o00001OmoOgl;o`WZ2PCoOgmo0_l00003ogmo
O`;o00005oooool01?l0003oooooooooooooool<o`WZ2Sgooooo00?o0000ooooooooool03_ooool0
08gooooo00?o0000ogmoOomoOgl04?moOgl4o`WZ2P03o`000?l9jP[o2NX:00;o2NX:00?o0000o`WZ
2_l9jPX00ol9jPXCooooo`03o`000?oooooooooo00gooooo2ol9jPXbooooo`03o`000?oooooooooo
00kooooo002=ooooo`03o`000?moOgooOgmo01KoOgmo00Go0000ogmoOomoOgooOgmoo`000004oooo
o`Wo2NX:2_ooool00ol0003oooooooooo`0Hooooo`_o2NX:9oooool00ol0003oooooooooo`0>oooo
o`00SOooool00ol0003oOgmoogmoO`0GogmoO`04o`000?moOgooOgmoo`0000gooooo2?l9jPX2oooo
o`03o`000?oooooooooo02?ooooo3?l9jPXKooooo`03o`000?oooooooooo00kooooo002=ooooo`03
o`000?moOgooOgmo01GoOgmo0_ooool3ogmoO`03o`000?oooooooooo01?ooooo2?l9jPX/ooooo`_o
2NX:4?ooool00ol0003oooooooooo`0>ooooo`00S?ooool00ol0003oOgmoogmoO`0CogmoO`Kooooo
0omoOgl00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo2Ol9jPX^ooooo`_o2NX:
1Oooool2o`0000oooooo002;ooooo`03o`000?moOgooOgmo017oOgmo2_ooool2ogmoO`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool03?ooool8o`WZ2S7ooooo1Ol9jPX2o`0000oooooo002:
ooooo`03o`000?moOgooOgmo00ooOgmo3_ooool2ogmoO`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool05?ooool9o`WZ2Rgooooo00?o0000ooooooooool03_ooool008Wooooo00?o0000ogmo
OomoOgl03OmoOglBooooo`03ogmoOol0003ooooo01Cooooo00?o0000ooooooooool07Oooool8o`WZ
2RGooooo00?o0000ooooooooool03_ooool008Sooooo00?o0000ogmoOomoOgl02_moOglGooooo`03
ogmoOol0003ooooo01?ooooo00?o0000ooooooooool09Oooool9o`WZ2Qcooooo00?o0000oooooooo
ool03_ooool008Sooooo00?o0000ogmoOomoOgl01omoOglJooooo`;oOgmo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0^ooooo`So2NX:5?ooool00ol0003oooooooooo`0>ooooo`00Qooo
ool00ol0003oOgmoogmoO`05ogmoOakooooo00?oOgmoo`000?ooool04_ooool00ol0003ooooooooo
o`0fooooo`So2NX:3?ooool00ol0003oooooooooo`0>ooooo`00Q_ooool00ol0003oOgmoogmoO`03
ogmoOb;ooooo00?oOgmoo`000?ooool04Oooool00ol0003oooooooooo`0nooooo`Wo2NX:0oooool2
o`0000oooooo0025ooooo`04o`000?moOgooOgmoogmoObKooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`17ooooo`?o2NX:0_l0000?ooooo`00Q?ooool00ol0003oOgmoooooo`0Yoooo
o`;o00004?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00kooooo002booooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0>ooooo`00
/oooool2o`0000gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0>ooooo`00]Ooo
ool2o`0000_ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0>ooooo`00]oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool03_ooool0
0;Sooooo0_l00008ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool03_ooool00;[o
oooo0_l00006ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool03_ooool00;cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00kooooo
002mooooo`;o00000oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00kooooo002o
ooooo`;o000000?oooooo`000?ooool0Boooool00ol0003oooooooooo`0>ooooo`00`Oooool2o`00
04cooooo00?o0000ooooooooool03_ooool00<;ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0>ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.54244 .03036 m
.55897 .07004 L
.46179 .07004 L
F
.46179 .07004 m
.55897 .07004 L
.56837 .10972 L
.49192 .10972 L
.46179 .07004 L
F
.49192 .10972 m
.56837 .10972 L
.57143 .1494 L
.5 .1494 L
.49192 .10972 L
F
.5 .1494 m
.57143 .1494 L
.56837 .18909 L
.49192 .18909 L
.5 .1494 L
F
.49192 .18909 m
.56837 .18909 L
.55897 .22877 L
.46179 .22877 L
.49192 .18909 L
F
.46179 .22877 m
.55897 .22877 L
.54244 .26845 L
.46179 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.46179 .07004 m
.49192 .10972 L
.5 .1494 L
.49192 .18909 L
.46179 .22877 L
s
.54244 .26845 m
.55897 .22877 L
.56837 .18909 L
.57143 .1494 L
.56837 .10972 L
.55897 .07004 L
.54244 .03036 L
s
.5 g
.54244 .1494 m
.55897 .1494 L
.46179 .1494 L
F
.46179 .1494 m
.55897 .1494 L
.56837 .1494 L
.49192 .1494 L
.46179 .1494 L
F
.49192 .1494 m
.56837 .1494 L
.57143 .1494 L
.5 .1494 L
.49192 .1494 L
F
.5 .1494 m
.57143 .1494 L
.56837 .1494 L
.49192 .1494 L
.5 .1494 L
F
.49192 .1494 m
.56837 .1494 L
.55897 .1494 L
.46179 .1494 L
.49192 .1494 L
F
.46179 .1494 m
.55897 .1494 L
.54244 .1494 L
.46179 .1494 L
F
0 g
.46179 .1494 m
.49192 .1494 L
.5 .1494 L
.49192 .1494 L
.46179 .1494 L
s
.54244 .1494 m
.55897 .1494 L
.56837 .1494 L
.57143 .1494 L
.56837 .1494 L
.55897 .1494 L
.54244 .1494 L
s
.5 g
.54244 .03036 m
.55897 .07004 L
.54244 .03036 L
F
.55897 .07004 m
.58021 .10972 L
.56837 .10972 L
.55897 .07004 L
F
.56837 .10972 m
.58021 .10972 L
.59524 .1494 L
.57143 .1494 L
.56837 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.58021 .18909 L
.56837 .18909 L
.57143 .1494 L
F
.56837 .18909 m
.58021 .18909 L
.55897 .22877 L
.56837 .18909 L
F
.55897 .22877 m
.54244 .26845 L
.55897 .22877 L
F
0 g
.54244 .03036 m
.55897 .07004 L
.56837 .10972 L
.57143 .1494 L
.56837 .18909 L
.55897 .22877 L
.54244 .26845 L
s
.58021 .18909 m
.59524 .1494 L
.58021 .10972 L
s
.54244 .03036 m
0 0 rlineto s
.5 g
.54244 .1494 m
.55897 .1494 L
.54244 .1494 L
F
.55897 .1494 m
.58021 .1494 L
.56837 .1494 L
.55897 .1494 L
F
.56837 .1494 m
.58021 .1494 L
.59524 .1494 L
.57143 .1494 L
.56837 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.58021 .1494 L
.56837 .1494 L
.57143 .1494 L
F
.56837 .1494 m
.58021 .1494 L
.55897 .1494 L
.56837 .1494 L
F
.55897 .1494 m
.54244 .1494 L
.55897 .1494 L
F
0 g
.54244 .1494 m
.55897 .1494 L
.56837 .1494 L
.57143 .1494 L
.56837 .1494 L
.55897 .1494 L
.54244 .1494 L
s
.58021 .1494 m
.59524 .1494 L
.58021 .1494 L
s
.54244 .1494 m
0 0 rlineto s
.54244 .26845 m
.54244 .2644 L
s
.54244 .2644 m
.54244 .2525 L
s
.54244 .2525 m
.54244 .23358 L
s
.54244 .23358 m
.54244 .20893 L
s
.54244 .20893 m
.54244 .18022 L
s
.54244 .18022 m
.54244 .1494 L
s
.54244 .1494 m
.54244 .11859 L
s
.54244 .11859 m
.54244 .08988 L
s
.54244 .08988 m
.54244 .06523 L
s
.54244 .06523 m
.54244 .04631 L
s
.54244 .04631 m
.54244 .03441 L
s
.54244 .03441 m
.54244 .03036 L
s
.54244 .03036 m
.54244 .03441 L
s
.54244 .03441 m
.54244 .04631 L
s
.54244 .04631 m
.54244 .06523 L
s
.54244 .06523 m
.54244 .08988 L
s
.54244 .08988 m
.54244 .11859 L
s
.54244 .11859 m
.54244 .1494 L
s
.54244 .1494 m
.54244 .18022 L
s
.54244 .18022 m
.54244 .20893 L
s
.54244 .20893 m
.54244 .23358 L
s
.54244 .23358 m
.54244 .2525 L
s
.54244 .2525 m
.54244 .2644 L
s
.54244 .2644 m
.54244 .26845 L
s
.54244 .26845 m
0 0 rlineto s
.54244 .2644 m
.54244 .26845 L
s
.54244 .2644 m
0 0 rlineto s
.54244 .2525 m
.54244 .2644 L
s
.54244 .2525 m
0 0 rlineto s
.54244 .23358 m
.54244 .2525 L
s
.54244 .23358 m
0 0 rlineto s
.54244 .20893 m
.54244 .23358 L
s
.54244 .20893 m
0 0 rlineto s
.54244 .18022 m
.54244 .20893 L
s
.54244 .18022 m
0 0 rlineto s
.54244 .1494 m
.54244 .18022 L
s
.54244 .1494 m
0 0 rlineto s
.54244 .11859 m
.54244 .1494 L
s
.54244 .11859 m
0 0 rlineto s
.54244 .08988 m
.54244 .11859 L
s
.54244 .08988 m
0 0 rlineto s
.54244 .06523 m
.54244 .08988 L
s
.54244 .06523 m
0 0 rlineto s
.54244 .04631 m
.54244 .06523 L
s
.54244 .04631 m
0 0 rlineto s
.54244 .03441 m
.54244 .04631 L
s
.54244 .03441 m
0 0 rlineto s
.54244 .03036 m
.54244 .03441 L
s
.54244 .03036 m
0 0 rlineto s
.54244 .03441 m
.54244 .03036 L
s
.54244 .03441 m
0 0 rlineto s
.54244 .04631 m
.54244 .03441 L
s
.54244 .04631 m
0 0 rlineto s
.54244 .06523 m
.54244 .04631 L
s
.54244 .06523 m
0 0 rlineto s
.54244 .08988 m
.54244 .06523 L
s
.54244 .08988 m
0 0 rlineto s
.54244 .11859 m
.54244 .08988 L
s
.54244 .11859 m
0 0 rlineto s
.54244 .1494 m
.54244 .11859 L
s
.54244 .1494 m
0 0 rlineto s
.54244 .18022 m
.54244 .1494 L
s
.54244 .18022 m
0 0 rlineto s
.54244 .20893 m
.54244 .18022 L
s
.54244 .20893 m
0 0 rlineto s
.54244 .23358 m
.54244 .20893 L
s
.54244 .23358 m
0 0 rlineto s
.54244 .2525 m
.54244 .23358 L
s
.54244 .2525 m
0 0 rlineto s
.54244 .2644 m
.54244 .2525 L
s
.54244 .2644 m
0 0 rlineto s
.54244 .26845 m
.54244 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49717 .1256 L
s
0 0 0 r
2 Mabswid
.49717 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49899 .13512 L
s
0 0 0 r
2 Mabswid
.49899 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49989 .14464 L
s
0 0 0 r
2 Mabswid
.49989 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49989 .15417 L
s
0 0 0 r
2 Mabswid
.49989 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49899 .16369 L
s
0 0 0 r
2 Mabswid
.49899 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49717 .17321 L
s
0 0 0 r
2 Mabswid
.49717 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49717 .1256 m
.56973 .1198 L
s
0 0 0 r
2 Mabswid
.56973 .1198 Mdot
.039 .916 .04 r
.5 Mabswid
.49899 .13512 m
.57082 .13173 L
s
0 0 0 r
2 Mabswid
.57082 .13173 Mdot
.039 .916 .04 r
.5 Mabswid
.49989 .14464 m
.57136 .14353 L
s
0 0 0 r
2 Mabswid
.57136 .14353 Mdot
.039 .916 .04 r
.5 Mabswid
.49989 .15417 m
.57136 .15528 L
s
0 0 0 r
2 Mabswid
.57136 .15528 Mdot
.039 .916 .04 r
.5 Mabswid
.49899 .16369 m
.57082 .16708 L
s
0 0 0 r
2 Mabswid
.57082 .16708 Mdot
.039 .916 .04 r
.5 Mabswid
.49717 .17321 m
.56973 .17901 L
s
0 0 0 r
2 Mabswid
.56973 .17901 Mdot
.039 .916 .04 r
.5 Mabswid
.56973 .1198 m
.58657 .11836 L
s
0 0 0 r
2 Mabswid
.58657 .11836 Mdot
.039 .916 .04 r
.5 Mabswid
.57082 .13173 m
.59222 .13064 L
s
0 0 0 r
2 Mabswid
.59222 .13064 Mdot
.039 .916 .04 r
.5 Mabswid
.57136 .14353 m
.59491 .14313 L
s
0 0 0 r
2 Mabswid
.59491 .14313 Mdot
.039 .916 .04 r
.5 Mabswid
.57136 .15528 m
.59491 .15568 L
s
0 0 0 r
2 Mabswid
.59491 .15568 Mdot
.039 .916 .04 r
.5 Mabswid
.57082 .16708 m
.59222 .16817 L
s
0 0 0 r
2 Mabswid
.59222 .16817 Mdot
.039 .916 .04 r
.5 Mabswid
.56973 .17901 m
.58657 .18045 L
s
0 0 0 r
2 Mabswid
.58657 .18045 Mdot
.039 .916 .04 r
.5 Mabswid
.59222 .13064 m
.97619 .19965 L
s
0 0 0 r
2 Mabswid
.97619 .19965 Mdot
.039 .916 .04 r
.5 Mabswid
.59491 .14313 m
.97619 .16378 L
s
0 0 0 r
2 Mabswid
.97619 .16378 Mdot
.039 .916 .04 r
.5 Mabswid
.59491 .15568 m
.97619 .13503 L
s
0 0 0 r
2 Mabswid
.97619 .13503 Mdot
.039 .916 .04 r
.5 Mabswid
.59222 .16817 m
.97619 .09916 L
s
0 0 0 r
2 Mabswid
.97619 .09916 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo002Kooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool03_ooool0
09[ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0>ooooo`00VOooool00omoOgoo
0000o`00001cooooo`03o`000?oooooooooo00kooooo002Gooooo`?oOgmo0_l0001cooooo`03o`00
0?oooooooooo00kooooo002Eooooo`GoOgmo0_l0001cooooo`03o`000?oooooooooo00kooooo002C
ooooo`OoOgmo0ol0001booooo`03o`000?oooooooooo00kooooo002Aooooo`WoOgmo00?o0000ogmo
Ool00000L_ooool00ol0003oooooooooo`0>ooooo`00S_ooool<ogmoO`04o`000?moOgooOgmoo`00
077ooooo00?o0000ooooooooool03_ooool008cooooo3_moOgl01?l0003oOgmoogmoOol0001aoooo
o`03o`000?oooooooooo00kooooo002:oooooa3oOgmo00Go0000ogmoOomoOgooOgmoo`00001`oooo
o`03o`000?oooooooooo00kooooo0028oooooa;oOgmo0_l00002ogmoO`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool03_ooool008Gooooo00?o0000ogmoOomoOgl04_moOgl00ol0003oOgmo
ogmoO`02ogmoO`03o`000?oooooooooo06gooooo00?o0000ooooooooool03_ooool008Gooooo00?o
0000ogmoOomoOgl04_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo06gooooo00?o
0000ooooooooool03_ooool008Kooooo00?o0000ogmoOomoOgl04OmoOgl00ol0003oOgmoogmoO`02
ogmoO`03o`000?oooooooooo06gooooo00?o0000ooooooooool03_ooool008Oooooo00?o0000ogmo
OomoOgl04?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool03_ooool008Sooooo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo06cooooo00?o0000ooooooooool03_ooool008Sooooo00?o0000ogmoOomoOgl0
3omoOgl2o`0000CoOgmo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0>ooooo`00ROoo
ool00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOoooool0K?oo
ool00ol0003oooooooooo`0>ooooo`00R_ooool00ol0003oOgmoogmoO`0=ogmoO`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ogmoOomoOgl0K?ooool00ol0003oooooooooo`0>ooooo`00R_ooool00ol0
003oOgmoogmoO`0=ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl0JOooool3o`WZ
2P;o00003oooool008_ooooo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`04ogmoO`03
o`000?moOgooOgmo06?ooooo1Ol9jPX3ooooo`;o00003oooool008cooooo00?o0000ogmoOomoOgl0
2omoOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo05gooooo1_l9jPX8ooooo`03o`00
0?oooooooooo00kooooo002=ooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl01?mo
Ogl01Ol0003oOgmoogmoOomoOgoo000005Kooooo1Ol9jPX>ooooo`03o`000?oooooooooo00kooooo
002=ooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl01?moOgl01Ol0003oOgmoogmo
OomoOgoo0000057ooooo1Ol9jPXCooooo`03o`000?oooooooooo00kooooo002=ooooo`03o`000?mo
OgooOgmo00[oOgmo0_l00005ogmoO`;o000000?oOgmoo`WZ2_l9jPX00_l00019ooooo`Ko2NX:6?oo
ool00ol0003oooooooooo`0>ooooo`00SOooool00ol0003oOgmoogmoO`08ogmoO`Wo2NX:00?o0000
o`WZ2_l9jPX00_moOgl2o`0004Cooooo1Ol9jPXNooooo`03o`000?oooooooooo00kooooo000?oooo
ohWo2NX:0_moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000oooo
ooooool0?Oooool6o`WZ2R?ooooo00?o0000ooooooooool03_ooool008kooooo0_l0000:ogmoO`03
o`000?moOgooOgmo00CoOgmo0ol00003ogmoO`;o0000>?ooool5o`WZ2RWooooo00?o0000oooooooo
ool03_ooool008kooooo0_l00009ogmoO`ko2NX:00?o0000o`WZ2_l9jPX00_l9jPX_ooooo`Ko2NX:
;_ooool2o`0000oooooo000?ooooogoo2NX:00?o0000o`WZ2_l9jPX02?l9jPX00omoOgoo0000ogmo
O`06ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool00_ooool6o`WZ2RCooooo1Ol9
jPXZooooo`[o2NX:0_l0000?ooooo`00S_ooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgoo
Ogmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`07ooooo`Go2NX:6_ooool5
o`WZ2Q[ooooo5Ol9jPX:ooooo`03o`000?oooooooooo00kooooo000?ooooogoo2NX:00?o0000o`WZ
2_l9jPX05ol9jPX00ol0003o2NX:o`WZ2P08o`WZ2PCooooo1_l9jPX>ooooo`Ko2NX:2ooooolDo`WZ
2Qoooooo00?o0000ooooooooool03_ooool008kooooo0_l0000:ogmoO`;o00001_moOgl2o`0000Co
Ogmo0_l00009oooooa7o2NX:0_oooolFo`WZ2S?ooooo00?o0000ooooooooool03_ooool008Gooooo
2ol0000:ogmoO`Wo00000_moOgl5o`0000Wooooo8_l9jPXjooooo`03o`000?oooooooooo00kooooo
000?ooooogoo2NX:00?o0000o`WZ2_l9jPX05ol9jPX00ol0003o2NX:o`WZ2P08o`WZ2PSooooo1Ol9
jPX8ooooo`Ko2NX:1ooooolAo`WZ2RWooooo00?o0000ooooooooool03_ooool008kooooo0_l0000:
ogmoO`03o`000?moOgooOgmo00GoOgmo0_l00004ogmoO`;o00003?ooool5o`WZ2Q?ooooo1_l9jPXB
oooooa7o2NX:6?ooool00ol0003oooooooooo`0>ooooo`00S_ooool2o`0000[oOgmo00?o0000ogmo
OomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo00Gooooo1_l9jPXNoooo
o`Ko2NX:7OoooolAo`WZ2POooooo0_l0000?ooooo`003ooooomoo`WZ2P03o`000?l9jP[o2NX:01Go
2NX:00?oOgmoo`000?l000000_ooool5o`WZ2R[ooooo1Ol9jPXYooooo`Oo2NX:0_l0000?ooooo`00
S_ooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00GoOgmo0_l00002ogmoO`03o`WZ
2_l0003o2NX:00;o2NX:=?ooool6o`WZ2R[ooooo00?o0000ooooooooool03_ooool000ooooooQOl9
jPX6ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`0kooooo`Ko2NX:9?ooool00ol0003oooooooooo`0>ooooo`00S_ooool2o`0000CoOgmo2_l9jPX3
ogmoO`;o00000omoOgl00ol0003oooooooooo`12ooooo`Ko2NX:7_ooool00ol0003oooooooooo`0>
ooooo`00SOooool00ol0003oOgmoogmoO`0:ogmoO`;o00000_moOgl3o`WZ2P03o`000?l9jP[o2NX:
00;o2NX:0_l00019ooooo`Go2NX:6Oooool00ol0003oooooooooo`0>ooooo`00SOooool00ol0003o
OgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00_moOgl2o`0004ko
oooo1_l9jPXCooooo`03o`000?oooooooooo00kooooo002=ooooo`03o`000?moOgooOgmo00[oOgmo
00?o0000ogmoOomoOgl01?moOgl01Ol0003oOgmoogmoOomoOgoo000005Kooooo1_l9jPX=ooooo`03
o`000?oooooooooo00kooooo002=ooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl0
1?moOgl01?l0003oOgmoogmoOomoOgmMooooo`Go2NX:2?ooool00ol0003oooooooooo`0>ooooo`00
S?ooool00ol0003oOgmoogmoO`0;ogmoO`03o`000?moOgooOgmo00CoOgmo00Co0000ogmoOomoOgoo
OgmoH_ooool6o`WZ2P;ooooo00?o0000ooooooooool03_ooool008_ooooo00?o0000ogmoOomoOgl0
3?moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo06Wooooo0_l9jPX2o`0000oooooo
002:ooooo`03o`000?moOgooOgmo00goOgmo00?o0000ogmoOomoOgl00omoOgl01?l0003oOgmoogmo
OomoOgm[ooooo`;o00003oooool008[ooooo00?o0000ogmoOomoOgl03OmoOgl2o`0000CoOgmo00?o
0000ogmoOomoOgl0K?ooool00ol0003oooooooooo`0>ooooo`00ROooool00ol0003oOgmoogmoO`0>
ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl0K?ooool00ol0003oooooooooo`0>
ooooo`00R?ooool00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmo
Ooooool0K?ooool00ol0003oooooooooo`0>ooooo`00R?ooool00ol0003oOgmoogmoO`0?ogmoO`03
o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0>ooooo`00
Qoooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOoooool0
KOooool00ol0003oooooooooo`0>ooooo`00Q_ooool00ol0003oOgmoogmoO`0AogmoO`03o`000?mo
OgooOgmo00;oOgmo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0>ooooo`00QOooool0
0ol0003oOgmoogmoO`0BogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0>ooooo`00QooooolCogmoO`;o00000omoOgl00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo00kooooo0029oooooa7oOgmo00Go0000ogmoOomoOgooOgmoo`00001`oooo
o`03o`000?oooooooooo00kooooo002;ooooo`ooOgmo00Go0000ogmoOomoOgooOgmoo`00001`oooo
o`03o`000?oooooooooo00kooooo002=ooooo`goOgmo00Co0000ogmoOomoOgoo0000LOooool00ol0
003oooooooooo`0>ooooo`00Soooool;ogmoO`04o`000?moOgooOgmoo`00077ooooo00?o0000oooo
ooooool03_ooool0097ooooo2OmoOgl3o`0007;ooooo00?o0000ooooooooool03_ooool009;ooooo
2?moOgl00ol0003oOgmoo`00001booooo`03o`000?oooooooooo00kooooo002Dooooo`KoOgmo00?o
0000ogmoOol00000L_ooool00ol0003oooooooooo`0>ooooo`00U_ooool4ogmoO`;o0000Loooool0
0ol0003oooooooooo`0>ooooo`00V?ooool2ogmoO`;o0000Loooool00ol0003oooooooooo`0>oooo
o`00V_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00kooooo003oooooob7ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.5091 .03036 m
.54775 .07004 L
.46394 .07004 L
F
.46394 .07004 m
.54775 .07004 L
.56589 .10972 L
.49224 .10972 L
.46394 .07004 L
F
.49224 .10972 m
.56589 .10972 L
.57143 .1494 L
.5 .1494 L
.49224 .10972 L
F
.5 .1494 m
.57143 .1494 L
.56589 .18909 L
.49224 .18909 L
.5 .1494 L
F
.49224 .18909 m
.56589 .18909 L
.54775 .22877 L
.46394 .22877 L
.49224 .18909 L
F
.46394 .22877 m
.54775 .22877 L
.5091 .26845 L
.46394 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.46394 .07004 m
.49224 .10972 L
.5 .1494 L
.49224 .18909 L
.46394 .22877 L
s
.5091 .26845 m
.54775 .22877 L
.56589 .18909 L
.57143 .1494 L
.56589 .10972 L
.54775 .07004 L
.5091 .03036 L
s
.5 g
.5091 .1494 m
.54775 .1494 L
.46394 .1494 L
F
.46394 .1494 m
.54775 .1494 L
.56589 .1494 L
.49224 .1494 L
.46394 .1494 L
F
.49224 .1494 m
.56589 .1494 L
.57143 .1494 L
.5 .1494 L
.49224 .1494 L
F
.5 .1494 m
.57143 .1494 L
.56589 .1494 L
.49224 .1494 L
.5 .1494 L
F
.49224 .1494 m
.56589 .1494 L
.54775 .1494 L
.46394 .1494 L
.49224 .1494 L
F
.46394 .1494 m
.54775 .1494 L
.5091 .1494 L
.46394 .1494 L
F
0 g
.46394 .1494 m
.49224 .1494 L
.5 .1494 L
.49224 .1494 L
.46394 .1494 L
s
.5091 .1494 m
.54775 .1494 L
.56589 .1494 L
.57143 .1494 L
.56589 .1494 L
.54775 .1494 L
.5091 .1494 L
s
.5 g
.5091 .03036 m
.59591 .03036 L
.59554 .07004 L
.54775 .07004 L
.5091 .03036 L
F
.54775 .07004 m
.59554 .07004 L
.59531 .10972 L
.56589 .10972 L
.54775 .07004 L
F
.56589 .10972 m
.59531 .10972 L
.59524 .1494 L
.57143 .1494 L
.56589 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59531 .18909 L
.56589 .18909 L
.57143 .1494 L
F
.56589 .18909 m
.59531 .18909 L
.59554 .22877 L
.54775 .22877 L
.56589 .18909 L
F
.54775 .22877 m
.59554 .22877 L
.59591 .26845 L
.5091 .26845 L
.54775 .22877 L
F
0 g
.5091 .03036 m
.54775 .07004 L
.56589 .10972 L
.57143 .1494 L
.56589 .18909 L
.54775 .22877 L
.5091 .26845 L
.59591 .26845 L
.59554 .22877 L
.59531 .18909 L
.59524 .1494 L
.59531 .10972 L
.59554 .07004 L
.59591 .03036 L
.5091 .03036 L
s
.5 g
.5091 .1494 m
.59591 .1494 L
.59554 .1494 L
.54775 .1494 L
.5091 .1494 L
F
.54775 .1494 m
.59554 .1494 L
.59531 .1494 L
.56589 .1494 L
.54775 .1494 L
F
.56589 .1494 m
.59531 .1494 L
.59524 .1494 L
.57143 .1494 L
.56589 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59531 .1494 L
.56589 .1494 L
.57143 .1494 L
F
.56589 .1494 m
.59531 .1494 L
.59554 .1494 L
.54775 .1494 L
.56589 .1494 L
F
.54775 .1494 m
.59554 .1494 L
.59591 .1494 L
.5091 .1494 L
.54775 .1494 L
F
0 g
.5091 .1494 m
.54775 .1494 L
.56589 .1494 L
.57143 .1494 L
.56589 .1494 L
.54775 .1494 L
.5091 .1494 L
.59591 .1494 L
.59554 .1494 L
.59531 .1494 L
.59524 .1494 L
.59531 .1494 L
.59554 .1494 L
.59591 .1494 L
.5091 .1494 L
s
.5091 .26845 m
.5091 .2644 L
s
.5091 .2644 m
.5091 .2525 L
s
.5091 .2525 m
.5091 .23358 L
s
.5091 .23358 m
.5091 .20893 L
s
.5091 .20893 m
.5091 .18022 L
s
.5091 .18022 m
.5091 .1494 L
s
.5091 .1494 m
.5091 .11859 L
s
.5091 .11859 m
.5091 .08988 L
s
.5091 .08988 m
.5091 .06523 L
s
.5091 .06523 m
.5091 .04631 L
s
.5091 .04631 m
.5091 .03441 L
s
.5091 .03441 m
.5091 .03036 L
s
.5091 .03036 m
.5091 .03441 L
s
.5091 .03441 m
.5091 .04631 L
s
.5091 .04631 m
.5091 .06523 L
s
.5091 .06523 m
.5091 .08988 L
s
.5091 .08988 m
.5091 .11859 L
s
.5091 .11859 m
.5091 .1494 L
s
.5091 .1494 m
.5091 .18022 L
s
.5091 .18022 m
.5091 .20893 L
s
.5091 .20893 m
.5091 .23358 L
s
.5091 .23358 m
.5091 .2525 L
s
.5091 .2525 m
.5091 .2644 L
s
.5091 .2644 m
.5091 .26845 L
s
.5091 .26845 m
.59591 .26845 L
.59591 .2644 L
.5091 .2644 L
.5091 .26845 L
s
.5091 .2644 m
.59591 .2644 L
.59591 .2525 L
.5091 .2525 L
.5091 .2644 L
s
.5091 .2525 m
.59591 .2525 L
.59591 .23358 L
.5091 .23358 L
.5091 .2525 L
s
.5091 .23358 m
.59591 .23358 L
.59591 .20893 L
.5091 .20893 L
.5091 .23358 L
s
.5091 .20893 m
.59591 .20893 L
.59591 .18022 L
.5091 .18022 L
.5091 .20893 L
s
.5091 .18022 m
.59591 .18022 L
.59591 .1494 L
.5091 .1494 L
.5091 .18022 L
s
.5091 .1494 m
.59591 .1494 L
.59591 .11859 L
.5091 .11859 L
.5091 .1494 L
s
.5091 .11859 m
.59591 .11859 L
.59591 .08988 L
.5091 .08988 L
.5091 .11859 L
s
.5091 .08988 m
.59591 .08988 L
.59591 .06523 L
.5091 .06523 L
.5091 .08988 L
s
.5091 .06523 m
.59591 .06523 L
.59591 .04631 L
.5091 .04631 L
.5091 .06523 L
s
.5091 .04631 m
.59591 .04631 L
.59591 .03441 L
.5091 .03441 L
.5091 .04631 L
s
.5091 .03441 m
.59591 .03441 L
.59591 .03036 L
.5091 .03036 L
.5091 .03441 L
s
.5091 .03036 m
.59591 .03036 L
.59591 .03441 L
.5091 .03441 L
.5091 .03036 L
s
.5091 .03441 m
.59591 .03441 L
.59591 .04631 L
.5091 .04631 L
.5091 .03441 L
s
.5091 .04631 m
.59591 .04631 L
.59591 .06523 L
.5091 .06523 L
.5091 .04631 L
s
.5091 .06523 m
.59591 .06523 L
.59591 .08988 L
.5091 .08988 L
.5091 .06523 L
s
.5091 .08988 m
.59591 .08988 L
.59591 .11859 L
.5091 .11859 L
.5091 .08988 L
s
.5091 .11859 m
.59591 .11859 L
.59591 .1494 L
.5091 .1494 L
.5091 .11859 L
s
.5091 .1494 m
.59591 .1494 L
.59591 .18022 L
.5091 .18022 L
.5091 .1494 L
s
.5091 .18022 m
.59591 .18022 L
.59591 .20893 L
.5091 .20893 L
.5091 .18022 L
s
.5091 .20893 m
.59591 .20893 L
.59591 .23358 L
.5091 .23358 L
.5091 .20893 L
s
.5091 .23358 m
.59591 .23358 L
.59591 .2525 L
.5091 .2525 L
.5091 .23358 L
s
.5091 .2525 m
.59591 .2525 L
.59591 .2644 L
.5091 .2644 L
.5091 .2525 L
s
.5091 .2644 m
.59591 .2644 L
.59591 .26845 L
.5091 .26845 L
.5091 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49727 .1256 L
s
0 0 0 r
2 Mabswid
.49727 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49903 .13512 L
s
0 0 0 r
2 Mabswid
.49903 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49989 .14464 L
s
0 0 0 r
2 Mabswid
.49989 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49989 .15417 L
s
0 0 0 r
2 Mabswid
.49989 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49903 .16369 L
s
0 0 0 r
2 Mabswid
.49903 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49727 .17321 L
s
0 0 0 r
2 Mabswid
.49727 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49727 .1256 m
.56844 .12013 L
s
0 0 0 r
2 Mabswid
.56844 .12013 Mdot
.039 .916 .04 r
.5 Mabswid
.49903 .13512 m
.57036 .13187 L
s
0 0 0 r
2 Mabswid
.57036 .13187 Mdot
.039 .916 .04 r
.5 Mabswid
.49989 .14464 m
.57131 .14357 L
s
0 0 0 r
2 Mabswid
.57131 .14357 Mdot
.039 .916 .04 r
.5 Mabswid
.49989 .15417 m
.57131 .15524 L
s
0 0 0 r
2 Mabswid
.57131 .15524 Mdot
.039 .916 .04 r
.5 Mabswid
.49903 .16369 m
.57036 .16694 L
s
0 0 0 r
2 Mabswid
.57036 .16694 Mdot
.039 .916 .04 r
.5 Mabswid
.49727 .17321 m
.56844 .17868 L
s
0 0 0 r
2 Mabswid
.56844 .17868 Mdot
.039 .916 .04 r
.5 Mabswid
.56844 .12013 m
.59529 .11749 L
s
0 0 0 r
2 Mabswid
.59529 .11749 Mdot
.039 .916 .04 r
.5 Mabswid
.57036 .13187 m
.59526 .13042 L
s
0 0 0 r
2 Mabswid
.59526 .13042 Mdot
.039 .916 .04 r
.5 Mabswid
.57131 .14357 m
.59524 .14311 L
s
0 0 0 r
2 Mabswid
.59524 .14311 Mdot
.039 .916 .04 r
.5 Mabswid
.57131 .15524 m
.59524 .1557 L
s
0 0 0 r
2 Mabswid
.59524 .1557 Mdot
.039 .916 .04 r
.5 Mabswid
.57036 .16694 m
.59526 .16838 L
s
0 0 0 r
2 Mabswid
.59526 .16838 Mdot
.039 .916 .04 r
.5 Mabswid
.56844 .17868 m
.59529 .18132 L
s
0 0 0 r
2 Mabswid
.59529 .18132 Mdot
.039 .916 .04 r
.5 Mabswid
.59529 .11749 m
.97619 .04846 L
s
0 0 0 r
2 Mabswid
.97619 .04846 Mdot
.039 .916 .04 r
.5 Mabswid
.59526 .13042 m
.97619 .08982 L
s
0 0 0 r
2 Mabswid
.97619 .08982 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .14311 m
.97619 .1297 L
s
0 0 0 r
2 Mabswid
.97619 .1297 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .1557 m
.97619 .16911 L
s
0 0 0 r
2 Mabswid
.97619 .16911 Mdot
.039 .916 .04 r
.5 Mabswid
.59526 .16838 m
.97619 .20899 L
s
0 0 0 r
2 Mabswid
.97619 .20899 Mdot
.039 .916 .04 r
.5 Mabswid
.59529 .18132 m
.97619 .25035 L
s
0 0 0 r
2 Mabswid
.97619 .25035 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool0097ooooo6Ol0001Uoooo
o`03o`000?oooooooooo00kooooo002@ooooo`03ogmoOol0003o000001Oo0000IOooool00ol0003o
ooooooooo`0>ooooo`00Soooool2ogmoO`04o`000?moOgooOgmoo`0001CoOgmo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0>ooooo`00S_ooool3ogmoO`05o`000?moOgooOgmoogmoOol0
00004omoOgl00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00kooooo002=ooooo`CoOgmo
6Ol0001Uooooo`;o00003oooool008cooooo1OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?mo
OgooOgmo00ooOgmo00?o0000ooooooooool0H?ooool3o`WZ2P;o00003oooool008[ooooo1omoOgl0
0ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ooooooooool0F_ooool6
o`WZ2P?ooooo00?o0000ooooooooool03_ooool008Wooooo2?moOgl00ol0003oOgmoogmoO`05ogmo
O`03o`000?moOgooOgmo00goOgmo00?o0000ooooooooool0EOooool5o`WZ2PWooooo00?o0000oooo
ooooool03_ooool008Sooooo2OmoOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo00co
Ogmo00?o0000ooooooooool0Coooool6o`WZ2Pkooooo00?o0000ooooooooool03_ooool008Oooooo
2_moOglIo`0004_ooooo1_l9jPXDooooo`03o`000?oooooooooo00kooooo0025ooooo`03o`000?mo
OgooOgmo00WoOgmo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`0:ogmoO`03o`000?oo
oooooooo04Cooooo1Ol9jPXJooooo`03o`000?oooooooooo00kooooo0025ooooo`03o`000?moOgoo
Ogmo00WoOgmo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`0:ogmoO`03o`000?oooooo
oooo03kooooo1_l9jPXOooooo`03o`000?oooooooooo00kooooo0026ooooo`03o`000?moOgooOgmo
00SoOgmo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo
03Sooooo1_l9jPXUooooo`03o`000?oooooooooo00kooooo0027ooooo`03o`000?moOgooOgmo00Oo
Ogmo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo03?o
oooo1Ol9jPX[ooooo`03o`000?oooooooooo00kooooo0028ooooo`03o`000?moOgooOgmo00KoOgmo
00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`08ogmoO`03o`000?oooooooooo02gooooo
1_l9jPX`ooooo`03o`000?oooooooooo00kooooo0028ooooo`03o`000?moOgooOgmo00KoOgmo00?o
0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`08ogmoO`03o`000?oooooooooo02Oooooo1_l9
jPXfooooo`;o00003oooool008Wooooo00?o0000ogmoOomoOgl01OmoOglIo`0002Cooooo1Ol9jPXg
ooooo`Go2NX:0_l0000?ooooo`00R_ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo
00_oOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`0Looooo`Ko2NX:<oooool9o`WZ
2PGooooo00?o0000ooooooooool03_ooool008[ooooo00?o0000ogmoOomoOgl01?moOgl00ol0003o
OgmoogmoO`0;ogmoO`03o`000?moOgooOgmo00OoOgmo00?o0000ooooooooool05_ooool6o`WZ2S3o
oooo2Ol9jPX>ooooo`03o`000?oooooooooo00kooooo002;ooooo`03o`000?moOgooOgmo00?oOgmo
00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooooooo017ooooo
1Ol9jPX]ooooo`Wo2NX:5oooool00ol0003oooooooooo`0>ooooo`00S?ooool00ol0003oOgmoogmo
O`02ogmoO`03o`000?moOgooOgmo00coOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003ooooooooo
o`0;ooooo`Ko2NX::?ooool:o`WZ2R3ooooo00?o0000ooooooooool03_ooool008gooooo00Go0000
ogmoOomoOgooOgmoo`00000?ogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000ooooooooool01Ooo
ool6o`WZ2RGooooo2Ol9jPXZooooo`03o`000?oooooooooo00kooooo002=ooooo`05o`000?moOgoo
OgmoogmoOol000003omoOgl00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00Go2NX:8_oo
ool9o`WZ2S?ooooo00?o0000ooooooooool03_ooool008gooooo00Co0000ogmoOomoOgooOgmo5?l0
0003o`WZ2P04o`000?l9jP[o2NX:o`WZ2Qgooooo2_l9jPXlooooo`03o`000?oooooooooo00kooooo
002=ooooo`05o`000?moOgooOgmoogmoOol000001_moOgl=o`WZ2P?oOgmo0_l0000Fooooo`Wo2NX:
A_ooool00ol0003oooooooooo`0>ooooo`003ooooon9o`WZ2PWoOgmo00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oooooooooo`0;ooooo`Wo2NX:Coooool00ol0003oooooooooo`0>ooooo`00S_ooool2
o`000003ogmoOol0003oOgmo00koOgmo00?o0000ogmoOomoOgl01?moOgl2o`0000Cooooo2Ol9jPY;
ooooo`go2NX:0_l0000?ooooo`00S_ooool2o`000003ogmoOol0003oOgmo00KoOgmo2?l9jPX00ol0
003o2NX:o`WZ2P04o`WZ2P03o`000?l9jP[o2NX:00?o2NX:>ooooolIo`WZ2Pgooooo0_l0000?oooo
o`003ooooomoo`WZ2P03o`000?l9jP[o2NX:00So2NX:2?moOgl2o`0000KoOgmo00?o0000oooooooo
ool08ooooolJo`WZ2RKooooo00?o0000ooooooooool03_ooool008kooooo00Co0000ogmoOomoOgoo
00004?moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo00[ooooo6Ol9jPY0ooooo`03
o`000?oooooooooo00kooooo000?ooooogoo2NX:00?o0000o`WZ2_l9jPX05ol9jPX00ol0003o2NX:
o`WZ2P0;o`WZ2UWooooo00?o0000ooooooooool03_ooool008kooooo0_l000000omoOgoo0000ogmo
O`0?ogmoO`;o00001?moOgl2o`0006Gooooo00?o0000ooooooooool03_ooool008Gooooo2ol00000
0omoOgoo0000o`00000Go`0006Gooooo00?o0000ooooooooool03_ooool000ooooooOol9jPX00ol0
003o2NX:o`WZ2P0Go`WZ2P03o`000?l9jP[o2NX:00co2NX:F?ooool00ol0003oooooooooo`0>oooo
o`00S_ooool2o`000003ogmoOol0003oOgmo00ooOgmo0_l00004ogmoO`;o00003OoooolIo`WZ2Soo
oooo00?o0000ooooooooool03_ooool008kooooo0_l000000omoOgoo0000ogmoO`0?ogmoO`03o`00
0?moOgooOgmo00CoOgmo00?o0000ooooooooool09?oooolJo`WZ2RGooooo00?o0000ooooooooool0
3_ooool000ooooooOol9jPX00ol0003o2NX:o`WZ2P0@o`WZ2P03o`000?l9jP[o2NX:00?o2NX:00?o
Ogmoo`000?l00000@?oooolIo`WZ2Pcooooo00?o0000ooooooooool03_ooool008kooooo00Co0000
ogmoOomoOgoo00003omoOgl2o`0000CoOgmo00?o2NX:o`000?l9jPX01Ol9jPYDooooo`co2NX:0_l0
000?ooooo`003ooooon5o`WZ2PgoOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003oooooooooo`03
ooooo`Wo2NX:Eoooool2o`0000oooooo002>ooooo`;o000000CoOgmoo`000?moOgooOgmo2Ol9jPX4
ogmoO`;o00001_moOgl00ol0003oooooooooo`0<ooooo`Wo2NX:C_ooool00ol0003oooooooooo`0>
ooooo`00SOooool01?l0003oOgmoogmoOomoOgl<o`0000_o2NX:00?o0000o`WZ2_l9jPX00_l9jPXD
ooooo`Wo2NX:AOooool00ol0003oooooooooo`0>ooooo`00SOooool01Ol0003oOgmoogmoOomoOgoo
000000ooOgmo00?o0000ogmoOomoOgl01?moOgl2o`0000?ooooo1Ol9jPXHooooo`[o2NX:>oooool0
0ol0003oooooooooo`0>ooooo`00SOooool01Ol0003oOgmoogmoOomoOgoo000000ooOgmo00?o0000
ogmoOomoOgl01OmoOgl00ol0003oooooooooo`06ooooo`Go2NX:7Oooool9o`WZ2S;ooooo00?o0000
ooooooooool03_ooool008gooooo00Go0000ogmoOomoOgooOgmoo`00000?ogmoO`03o`000?moOgoo
Ogmo00GoOgmo00?o0000ooooooooool02oooool6o`WZ2R3ooooo2Ol9jPXYooooo`03o`000?oooooo
oooo00kooooo002<ooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl03?moOgl00ol0
003oOgmoogmoO`06ogmoO`03o`000?oooooooooo017ooooo1Ol9jPXTooooo`[o2NX:7oooool00ol0
003oooooooooo`0>ooooo`00Roooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00co
Ogmo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`0Fooooo`Ko2NX::?ooool9o`WZ2QKo
oooo00?o0000ooooooooool03_ooool008[ooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmo
ogmoO`0;ogmoO`03o`000?moOgooOgmo00OoOgmo00?o0000ooooooooool07?ooool5o`WZ2Rcooooo
2Ol9jPX=ooooo`03o`000?oooooooooo00kooooo002:ooooo`03o`000?moOgooOgmo00CoOgmo00?o
0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`07ogmoO`03o`000?oooooooooo027ooooo1Ol9
jPX`ooooo`Wo2NX:1?ooool2o`0000oooooo0029ooooo`03o`000?moOgooOgmo00GoOgmo6Ol0000X
ooooo`Ko2NX:<oooool4o`WZ2P;o00003oooool008Sooooo00?o0000ogmoOomoOgl01_moOgl00ol0
003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00SoOgmo00?o0000ooooooooool0;?ooool5o`WZ
2S;ooooo00?o0000ooooooooool03_ooool008Sooooo00?o0000ogmoOomoOgl01_moOgl00ol0003o
OgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00SoOgmo00?o0000ooooooooool0<Oooool5o`WZ2Rgo
oooo00?o0000ooooooooool03_ooool008Oooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmo
ogmoO`09ogmoO`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool0=_ooool6o`WZ2ROooooo
00?o0000ooooooooool03_ooool008Kooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmo
O`09ogmoO`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool0??ooool5o`WZ2R;ooooo00?o
0000ooooooooool03_ooool008Gooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`08
ogmoO`03o`000?moOgooOgmo00[oOgmo00?o0000ooooooooool0@Oooool5o`WZ2Qgooooo00?o0000
ooooooooool03_ooool008Oooooo2_moOglIo`0004Sooooo1_l9jPXGooooo`03o`000?oooooooooo
00kooooo0028ooooo`WoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0<ogmoO`03
o`000?oooooooooo04cooooo1Ol9jPXBooooo`03o`000?oooooooooo00kooooo0029ooooo`SoOgmo
00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`0=ogmoO`03o`000?oooooooooo057ooooo
1_l9jPX<ooooo`03o`000?oooooooooo00kooooo002:ooooo`OoOgmo00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oOgmoogmoO`0>ogmoO`03o`000?oooooooooo05Oooooo1Ol9jPX7ooooo`03o`000?oo
oooooooo00kooooo002;ooooo`KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`0?
ogmoO`03o`000?oooooooooo05cooooo1Ol9jPX2ooooo`;o00003oooool008cooooo1OmoOglIo`00
06?ooooo0_l9jPX2o`0000oooooo002=ooooo`CoOgmo00Go0000ogmoOomoOgooOgmoo`00000Cogmo
O`03o`000?oooooooooo06?ooooo00?o0000ooooooooool03_ooool008kooooo0omoOgl01?l0003o
OgmoogmoOol0000DogmoO`03o`000?oooooooooo06?ooooo00?o0000ooooooooool03_ooool008oo
oooo0_moOgl00ol0003oOgmoo`00000EogmoO`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool03_ooool0093ooooo00?oOgmoo`000?l000005ol0001Uooooo`03o`000?oooooooooo00kooooo
002AoooooaWo0000IOooool00ol0003oooooooooo`0>ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.4696 .07004 m
% vacuous filled polygon
newpath
.4696 .07004 m
.55995 .10972 L
.49318 .10972 L
.4696 .07004 L
F
.49318 .10972 m
.55995 .10972 L
.57143 .1494 L
.5 .1494 L
.49318 .10972 L
F
.5 .1494 m
.57143 .1494 L
.55995 .18909 L
.49318 .18909 L
.5 .1494 L
F
.49318 .18909 m
.55995 .18909 L
.4696 .22877 L
.49318 .18909 L
F
.4696 .22877 m
.4696 .22877 L
% vacuous filled polygon
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4696 .07004 m
.49318 .10972 L
.5 .1494 L
.49318 .18909 L
.4696 .22877 L
s
.55995 .18909 m
.57143 .1494 L
.55995 .10972 L
s
.5 g
.4696 .1494 m
% vacuous filled polygon
newpath
.4696 .1494 m
.55995 .1494 L
.49318 .1494 L
.4696 .1494 L
F
.49318 .1494 m
.55995 .1494 L
.57143 .1494 L
.5 .1494 L
.49318 .1494 L
F
.5 .1494 m
.57143 .1494 L
.55995 .1494 L
.49318 .1494 L
.5 .1494 L
F
.49318 .1494 m
.55995 .1494 L
.4696 .1494 L
.49318 .1494 L
F
.4696 .1494 m
.4696 .1494 L
% vacuous filled polygon
newpath
0 g
.4696 .1494 m
.49318 .1494 L
.5 .1494 L
.49318 .1494 L
.4696 .1494 L
s
.55995 .1494 m
.57143 .1494 L
.55995 .1494 L
s
.5 g
.53628 .07004 m
% vacuous filled polygon
newpath
.53628 .07004 m
.58512 .10972 L
.55995 .10972 L
F
.55995 .10972 m
.58512 .10972 L
.59524 .1494 L
.57143 .1494 L
.55995 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.58512 .18909 L
.55995 .18909 L
.57143 .1494 L
F
.55995 .18909 m
.58512 .18909 L
.53628 .22877 L
.55995 .18909 L
F
.53628 .22877 m
% vacuous filled polygon
newpath
0 g
.55995 .10972 m
.57143 .1494 L
.55995 .18909 L
s
.53628 .22877 m
.58512 .18909 L
.59524 .1494 L
.58512 .10972 L
.53628 .07004 L
s
.5 g
.53628 .1494 m
% vacuous filled polygon
newpath
.53628 .1494 m
.58512 .1494 L
.55995 .1494 L
F
.55995 .1494 m
.58512 .1494 L
.59524 .1494 L
.57143 .1494 L
.55995 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.58512 .1494 L
.55995 .1494 L
.57143 .1494 L
F
.55995 .1494 m
.58512 .1494 L
.53628 .1494 L
.55995 .1494 L
F
.53628 .1494 m
% vacuous filled polygon
newpath
0 g
.55995 .1494 m
.57143 .1494 L
.55995 .1494 L
s
.53628 .1494 m
.58512 .1494 L
.59524 .1494 L
.58512 .1494 L
.53628 .1494 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49759 .1256 L
s
0 0 0 r
2 Mabswid
.49759 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49914 .13512 L
s
0 0 0 r
2 Mabswid
.49914 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.4999 .14464 L
s
0 0 0 r
2 Mabswid
.4999 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.4999 .15417 L
s
0 0 0 r
2 Mabswid
.4999 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49914 .16369 L
s
0 0 0 r
2 Mabswid
.49914 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49759 .17321 L
s
0 0 0 r
2 Mabswid
.49759 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49759 .1256 m
.56577 .12097 L
s
0 0 0 r
2 Mabswid
.56577 .12097 Mdot
.039 .916 .04 r
.5 Mabswid
.49914 .13512 m
.56943 .13229 L
s
0 0 0 r
2 Mabswid
.56943 .13229 Mdot
.039 .916 .04 r
.5 Mabswid
.4999 .14464 m
.57121 .14369 L
s
0 0 0 r
2 Mabswid
.57121 .14369 Mdot
.039 .916 .04 r
.5 Mabswid
.4999 .15417 m
.57121 .15512 L
s
0 0 0 r
2 Mabswid
.57121 .15512 Mdot
.039 .916 .04 r
.5 Mabswid
.49914 .16369 m
.56943 .16652 L
s
0 0 0 r
2 Mabswid
.56943 .16652 Mdot
.039 .916 .04 r
.5 Mabswid
.49759 .17321 m
.56577 .17784 L
s
0 0 0 r
2 Mabswid
.56577 .17784 Mdot
.039 .916 .04 r
.5 Mabswid
.56577 .12097 m
.58909 .11808 L
s
0 0 0 r
2 Mabswid
.58909 .11808 Mdot
.039 .916 .04 r
.5 Mabswid
.56943 .13229 m
.59307 .13057 L
s
0 0 0 r
2 Mabswid
.59307 .13057 Mdot
.039 .916 .04 r
.5 Mabswid
.57121 .14369 m
.595 .14312 L
s
0 0 0 r
2 Mabswid
.595 .14312 Mdot
.039 .916 .04 r
.5 Mabswid
.57121 .15512 m
.595 .15569 L
s
0 0 0 r
2 Mabswid
.595 .15569 Mdot
.039 .916 .04 r
.5 Mabswid
.56943 .16652 m
.59307 .16824 L
s
0 0 0 r
2 Mabswid
.59307 .16824 Mdot
.039 .916 .04 r
.5 Mabswid
.56577 .17784 m
.58909 .18073 L
s
0 0 0 r
2 Mabswid
.58909 .18073 Mdot
.039 .916 .04 r
.5 Mabswid
.58909 .11808 m
.97619 .15754 L
s
0 0 0 r
2 Mabswid
.97619 .15754 Mdot
.039 .916 .04 r
.5 Mabswid
.59307 .13057 m
.97619 .15178 L
s
0 0 0 r
2 Mabswid
.97619 .15178 Mdot
.039 .916 .04 r
.5 Mabswid
.595 .14312 m
.97619 .14984 L
s
0 0 0 r
2 Mabswid
.97619 .14984 Mdot
.039 .916 .04 r
.5 Mabswid
.595 .15569 m
.97619 .14897 L
s
0 0 0 r
2 Mabswid
.97619 .14897 Mdot
.039 .916 .04 r
.5 Mabswid
.59307 .16824 m
.97619 .14702 L
s
0 0 0 r
2 Mabswid
.97619 .14702 Mdot
.039 .916 .04 r
.5 Mabswid
.58909 .18073 m
.97619 .14127 L
s
0 0 0 r
2 Mabswid
.97619 .14127 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0
003oooooooooo`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo00kooooo003ooooooa3ooooo
00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0003oooooooooo`0>ooooo`00ooooool@
ooooo`03o`000?oooooooooo00kooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oo
oooo4?ooool00ol0003oooooooooo`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo00kooooo
003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0003oooooooooo`0>
ooooo`00Qoooool00ol0003oooooooooo`0?ooooo`;o0000M?ooool00ol0003oooooooooo`0>oooo
o`00Qoooool00ol0003oOgmoooooo`0?ooooo`;oOgmo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`0>ooooo`00R?ooool00ol0003oOgmoogmoO`0?ooooo`;oOgmo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`0>ooooo`00R?ooool00ol0003oOgmoogmoO`02ogmoO`gooooo0omo
Ogl00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00kooooo0029ooooo`03o`000?moOgoo
Ogmo00CoOgmo2oooool3ogmoO`03o`000?oooooooooo06kooooo00?o0000ooooooooool03_ooool0
08Wooooo00?o0000ogmoOomoOgl01_moOgl9ooooo`CoOgmo0_l0001^ooooo`03o`000?oooooooooo
00kooooo002:ooooo`03o`000?moOgooOgmo00OoOgmo2?ooool5ogmoO`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool03_ooool008_ooooo00?o0000ogmoOomoOgl02?moOgl7ooooo`GoOgmo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0>ooooo`00Roooool00ol0003oOgmoogmo
O`0:ogmoO`Gooooo1_moOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00kooooo002<
ooooo`03o`000?moOgooOgmo00coOgmo0oooool6ogmoO`03o`000?oooooooooo06Sooooo00?o0000
ooooooooool03_ooool008cooooo00?o0000ogmoOomoOgl03_moOgl00oooooooOgmoogmoO`05ogmo
O`03o`000?oooooooooo06Oooooo00?o0000ooooooooool03_ooool008gooooo00?o0000ogmoOomo
Ogl03omoOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool03_ooool008gooooo00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoogmoO`04ogmoO`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool03_ooool008gooooo00?o0000ogmoOomoOgl03omo
Ogl00ol0003oOgmoogmoO`02ogmoO`;o2NX:00?o0000o`WZ2_l9jPX01?l9jPYRooooo`03o`000?oo
oooooooo00kooooo002=ooooo`03o`000?moOgooOgmo00SoOgmo2?l9jPX01?l0003o2NX:o`WZ2_l9
jPX2ogmoO`;o00001Oooool9o`WZ2UWooooo00?o0000ooooooooool03_ooool000ooooooROl9jPX8
ogmoO`;o00001OmoOgl00ol0003oooooooooo`0<ooooo`[o2NX:Coooool00ol0003oooooooooo`0>
ooooo`00S_ooool2o`00013oOgmo00?o0000ogmoOomoOgl01?moOgl3o`0001Kooooo2Ol9jPY6oooo
o`03o`000?oooooooooo00kooooo002>ooooo`;o00002OmoOgl8o`WZ2P03o`000?l9jP[o2NX:00oo
2NX:5_ooool:o`WZ2Scooooo00?o0000ooooooooool03_ooool000ooooooOol9jPX00ol0003o2NX:
o`WZ2P08o`WZ2PSoOgmo0_l00005ogmoO`03o`000?oooooooooo00Sooooo5Ol9jPX;ooooo`Wo2NX:
<oooool00ol0003oooooooooo`0>ooooo`00S_ooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?mo
OgooOgmo00CoOgmo00?o0000ooooooooool07OoooolMo`WZ2R[ooooo0_l0000?ooooo`003ooooomo
o`WZ2P03o`000?l9jP[o2NX:01Oo2NX:00?o0000o`WZ2_l9jPX06Ol9jPXIoooooaCo2NX:6Oooool5
o`WZ2P;o00003oooool008kooooo0_l0000BogmoO`;o00001?moOgl2o`0001[oooooBol9jPX2o`00
00oooooo0027ooooo`Wo00002OmoOglAo`0003;ooooo<ol9jPX2o`0000oooooo000?ooooogoo2NX:
00?o0000o`WZ2_l9jPX05ol9jPX00ol0003o2NX:o`WZ2P0ao`WZ2PSooooo4Ol9jPX=ooooo`Wo2NX:
1?ooool2o`0000oooooo002>ooooo`;o00004_moOgl2o`0000CoOgmo0_l0000YoooooaSo2NX:8?oo
ool4o`WZ2P;o00003oooool008kooooo0_l0000AogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000
ooooooooool05ooooolAo`WZ2P?ooooo2_l9jPX_ooooo`03o`000?oooooooooo00kooooo000?oooo
ogoo2NX:00?o0000o`WZ2_l9jPX04?l9jPX00ol0003o2NX:o`WZ2P02o`WZ2P;oOgmo0_l00007oooo
oa7o2NX:2Oooool;o`WZ2SWooooo00?o0000ooooooooool03_ooool008kooooo00?o0000ogmoOomo
Ogl04?moOgl2o`0000?oOgmo2ol9jPX@ooooo`[o2NX:A?ooool00ol0003oooooooooo`0>ooooo`00
3ooooon:o`WZ2POoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`0=ooooo`[o2NX:
C_ooool00ol0003oooooooooo`0>ooooo`00S_ooool2o`0000WoOgmo1ol9jPX00ol0003o2NX:o`WZ
2P02o`WZ2P;oOgmo00?o0000ooooooooool00_ooool;o`WZ2USooooo00?o0000ooooooooool03_oo
ool008gooooo00?o0000ogmoOomoOgl04?moOgl2o`0000?oOgmo00?o2NX:o`000?l9jPX01?l9jPYS
ooooo`03o`000?oooooooooo00kooooo002=ooooo`03o`000?moOgooOgmo00ooOgmo00?o0000ogmo
OomoOgl01?moOgl2o`0006Oooooo00?o0000ooooooooool03_ooool008gooooo00?o0000ogmoOomo
Ogl03omoOgl00ol0003oOgmoogmoO`03ogmoO`;o0000J?ooool00ol0003oooooooooo`0>ooooo`00
SOooool00ol0003oOgmoogmoO`0>ogmoO`03oooooomoOgooOgmo00?oOgmo00?o0000ooooooooool0
J?ooool00ol0003oooooooooo`0>ooooo`00S?ooool00ol0003oOgmoogmoO`0=ogmoO`?ooooo1?mo
Ogl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00kooooo002<ooooo`03o`000?moOgoo
Ogmo00_oOgmo1?ooool4ogmoO`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03_ooool0
08_ooooo00?o0000ogmoOomoOgl02OmoOgl7ooooo`?oOgmo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`0>ooooo`00Roooool00ol0003oOgmoogmoO`07ogmoO`Sooooo0_moOgl2o`0006ko
oooo00?o0000ooooooooool03_ooool008[ooooo00?o0000ogmoOomoOgl01_moOgl:ooooo`03ogmo
Ool0003ooooo06oooooo00?o0000ooooooooool03_ooool008Wooooo00?o0000ogmoOomoOgl01Omo
Ogl;ooooo`03ogmoOol0003ooooo073ooooo00?o0000ooooooooool03_ooool008Wooooo00?o0000
ogmoOomoOgl00omoOgl<ooooo`03ogmoOol0003ooooo077ooooo00?o0000ooooooooool03_ooool0
08Sooooo00Co0000ogmoOomoOgooOgmo3oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo00kooooo0028ooooo`03o`000?moOgoooooo00oooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`0>ooooo`00Qoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0003oooooooooo`0>ooooo`00oooo
ool@ooooo`03o`000?oooooooooo00kooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool0
0?oooooo4?ooool00ol0003oooooooooo`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo00ko
oooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0003ooooooooo
o`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo00kooooo003ooooooa3ooooo00?o0000oooo
ooooool03_ooool00?oooooo4?ooool00ol0003oooooooooo`0>ooooo`00ooooool@ooooo`03o`00
0?oooooooooo00kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.40191 .03036 m
.51636 .03036 L
.54977 .07004 L
.47043 .07004 L
.40191 .03036 L
F
.47043 .07004 m
.54977 .07004 L
.5663 .10972 L
.49332 .10972 L
.47043 .07004 L
F
.49332 .10972 m
.5663 .10972 L
.57143 .1494 L
.5 .1494 L
.49332 .10972 L
F
.5 .1494 m
.57143 .1494 L
.5663 .18909 L
.49332 .18909 L
.5 .1494 L
F
.49332 .18909 m
.5663 .18909 L
.54977 .22877 L
.47043 .22877 L
.49332 .18909 L
F
.47043 .22877 m
.54977 .22877 L
.51636 .26845 L
.40191 .26845 L
.47043 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.40191 .03036 m
.47043 .07004 L
.49332 .10972 L
.5 .1494 L
.49332 .18909 L
.47043 .22877 L
.40191 .26845 L
.51636 .26845 L
.54977 .22877 L
.5663 .18909 L
.57143 .1494 L
.5663 .10972 L
.54977 .07004 L
.51636 .03036 L
.40191 .03036 L
s
.5 g
.40191 .1494 m
.51636 .1494 L
.54977 .1494 L
.47043 .1494 L
.40191 .1494 L
F
.47043 .1494 m
.54977 .1494 L
.5663 .1494 L
.49332 .1494 L
.47043 .1494 L
F
.49332 .1494 m
.5663 .1494 L
.57143 .1494 L
.5 .1494 L
.49332 .1494 L
F
.5 .1494 m
.57143 .1494 L
.5663 .1494 L
.49332 .1494 L
.5 .1494 L
F
.49332 .1494 m
.5663 .1494 L
.54977 .1494 L
.47043 .1494 L
.49332 .1494 L
F
.47043 .1494 m
.54977 .1494 L
.51636 .1494 L
.40191 .1494 L
.47043 .1494 L
F
0 g
.40191 .1494 m
.47043 .1494 L
.49332 .1494 L
.5 .1494 L
.49332 .1494 L
.47043 .1494 L
.40191 .1494 L
.51636 .1494 L
.54977 .1494 L
.5663 .1494 L
.57143 .1494 L
.5663 .1494 L
.54977 .1494 L
.51636 .1494 L
.40191 .1494 L
s
.5 g
.51636 .03036 m
.53881 .07004 L
.54977 .07004 L
.51636 .03036 L
F
.54977 .07004 m
.53881 .07004 L
.58528 .10972 L
.5663 .10972 L
.54977 .07004 L
F
.5663 .10972 m
.58528 .10972 L
.59524 .1494 L
.57143 .1494 L
.5663 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.58528 .18909 L
.5663 .18909 L
.57143 .1494 L
F
.5663 .18909 m
.58528 .18909 L
.53881 .22877 L
.54977 .22877 L
.5663 .18909 L
F
.54977 .22877 m
.53881 .22877 L
.51636 .26845 L
.54977 .22877 L
F
0 g
.51636 .03036 m
.54977 .07004 L
.5663 .10972 L
.57143 .1494 L
.5663 .18909 L
.54977 .22877 L
.51636 .26845 L
s
.53881 .22877 m
.58528 .18909 L
.59524 .1494 L
.58528 .10972 L
.53881 .07004 L
s
.51636 .03036 m
0 0 rlineto s
.5 g
.51636 .1494 m
.53881 .1494 L
.54977 .1494 L
.51636 .1494 L
F
.54977 .1494 m
.53881 .1494 L
.58528 .1494 L
.5663 .1494 L
.54977 .1494 L
F
.5663 .1494 m
.58528 .1494 L
.59524 .1494 L
.57143 .1494 L
.5663 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.58528 .1494 L
.5663 .1494 L
.57143 .1494 L
F
.5663 .1494 m
.58528 .1494 L
.53881 .1494 L
.54977 .1494 L
.5663 .1494 L
F
.54977 .1494 m
.53881 .1494 L
.51636 .1494 L
.54977 .1494 L
F
0 g
.51636 .1494 m
.54977 .1494 L
.5663 .1494 L
.57143 .1494 L
.5663 .1494 L
.54977 .1494 L
.51636 .1494 L
s
.53881 .1494 m
.58528 .1494 L
.59524 .1494 L
.58528 .1494 L
.53881 .1494 L
s
.51636 .1494 m
0 0 rlineto s
.40191 .26845 m
.51636 .26845 L
.51636 .2644 L
.40191 .2644 L
.40191 .26845 L
s
.40191 .2644 m
.51636 .2644 L
.51636 .2525 L
.40191 .2525 L
.40191 .2644 L
s
.40191 .2525 m
.51636 .2525 L
.51636 .23358 L
.40191 .23358 L
.40191 .2525 L
s
.40191 .23358 m
.51636 .23358 L
.51636 .20893 L
.40191 .20893 L
.40191 .23358 L
s
.40191 .20893 m
.51636 .20893 L
.51636 .18022 L
.40191 .18022 L
.40191 .20893 L
s
.40191 .18022 m
.51636 .18022 L
.51636 .1494 L
.40191 .1494 L
.40191 .18022 L
s
.40191 .1494 m
.51636 .1494 L
.51636 .11859 L
.40191 .11859 L
.40191 .1494 L
s
.40191 .11859 m
.51636 .11859 L
.51636 .08988 L
.40191 .08988 L
.40191 .11859 L
s
.40191 .08988 m
.51636 .08988 L
.51636 .06523 L
.40191 .06523 L
.40191 .08988 L
s
.40191 .06523 m
.51636 .06523 L
.51636 .04631 L
.40191 .04631 L
.40191 .06523 L
s
.40191 .04631 m
.51636 .04631 L
.51636 .03441 L
.40191 .03441 L
.40191 .04631 L
s
.40191 .03441 m
.51636 .03441 L
.51636 .03036 L
.40191 .03036 L
.40191 .03441 L
s
.40191 .03036 m
.51636 .03036 L
.51636 .03441 L
.40191 .03441 L
.40191 .03036 L
s
.40191 .03441 m
.51636 .03441 L
.51636 .04631 L
.40191 .04631 L
.40191 .03441 L
s
.40191 .04631 m
.51636 .04631 L
.51636 .06523 L
.40191 .06523 L
.40191 .04631 L
s
.40191 .06523 m
.51636 .06523 L
.51636 .08988 L
.40191 .08988 L
.40191 .06523 L
s
.40191 .08988 m
.51636 .08988 L
.51636 .11859 L
.40191 .11859 L
.40191 .08988 L
s
.40191 .11859 m
.51636 .11859 L
.51636 .1494 L
.40191 .1494 L
.40191 .11859 L
s
.40191 .1494 m
.51636 .1494 L
.51636 .18022 L
.40191 .18022 L
.40191 .1494 L
s
.40191 .18022 m
.51636 .18022 L
.51636 .20893 L
.40191 .20893 L
.40191 .18022 L
s
.40191 .20893 m
.51636 .20893 L
.51636 .23358 L
.40191 .23358 L
.40191 .20893 L
s
.40191 .23358 m
.51636 .23358 L
.51636 .2525 L
.40191 .2525 L
.40191 .23358 L
s
.40191 .2525 m
.51636 .2525 L
.51636 .2644 L
.40191 .2644 L
.40191 .2525 L
s
.40191 .2644 m
.51636 .2644 L
.51636 .26845 L
.40191 .26845 L
.40191 .2644 L
s
.51636 .26845 m
0 0 rlineto s
.51636 .2644 m
.51636 .26845 L
s
.51636 .2644 m
0 0 rlineto s
.51636 .2525 m
.51636 .2644 L
s
.51636 .2525 m
0 0 rlineto s
.51636 .23358 m
.51636 .2525 L
s
.51636 .23358 m
0 0 rlineto s
.51636 .20893 m
.51636 .23358 L
s
.51636 .20893 m
0 0 rlineto s
.51636 .18022 m
.51636 .20893 L
s
.51636 .18022 m
0 0 rlineto s
.51636 .1494 m
.51636 .18022 L
s
.51636 .1494 m
0 0 rlineto s
.51636 .11859 m
.51636 .1494 L
s
.51636 .11859 m
0 0 rlineto s
.51636 .08988 m
.51636 .11859 L
s
.51636 .08988 m
0 0 rlineto s
.51636 .06523 m
.51636 .08988 L
s
.51636 .06523 m
0 0 rlineto s
.51636 .04631 m
.51636 .06523 L
s
.51636 .04631 m
0 0 rlineto s
.51636 .03441 m
.51636 .04631 L
s
.51636 .03441 m
0 0 rlineto s
.51636 .03036 m
.51636 .03441 L
s
.51636 .03036 m
0 0 rlineto s
.51636 .03441 m
.51636 .03036 L
s
.51636 .03441 m
0 0 rlineto s
.51636 .04631 m
.51636 .03441 L
s
.51636 .04631 m
0 0 rlineto s
.51636 .06523 m
.51636 .04631 L
s
.51636 .06523 m
0 0 rlineto s
.51636 .08988 m
.51636 .06523 L
s
.51636 .08988 m
0 0 rlineto s
.51636 .11859 m
.51636 .08988 L
s
.51636 .11859 m
0 0 rlineto s
.51636 .1494 m
.51636 .11859 L
s
.51636 .1494 m
0 0 rlineto s
.51636 .18022 m
.51636 .1494 L
s
.51636 .18022 m
0 0 rlineto s
.51636 .20893 m
.51636 .18022 L
s
.51636 .20893 m
0 0 rlineto s
.51636 .23358 m
.51636 .20893 L
s
.51636 .23358 m
0 0 rlineto s
.51636 .2525 m
.51636 .23358 L
s
.51636 .2525 m
0 0 rlineto s
.51636 .2644 m
.51636 .2525 L
s
.51636 .2644 m
0 0 rlineto s
.51636 .26845 m
.51636 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49764 .1256 L
s
0 0 0 r
2 Mabswid
.49764 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49916 .13512 L
s
0 0 0 r
2 Mabswid
.49916 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49991 .14464 L
s
0 0 0 r
2 Mabswid
.49991 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49991 .15417 L
s
0 0 0 r
2 Mabswid
.49991 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49916 .16369 L
s
0 0 0 r
2 Mabswid
.49916 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49764 .17321 L
s
0 0 0 r
2 Mabswid
.49764 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49764 .1256 m
.5688 .12087 L
s
0 0 0 r
2 Mabswid
.5688 .12087 Mdot
.039 .916 .04 r
.5 Mabswid
.49916 .13512 m
.57049 .1323 L
s
0 0 0 r
2 Mabswid
.57049 .1323 Mdot
.039 .916 .04 r
.5 Mabswid
.49991 .14464 m
.57132 .14371 L
s
0 0 0 r
2 Mabswid
.57132 .14371 Mdot
.039 .916 .04 r
.5 Mabswid
.49991 .15417 m
.57132 .1551 L
s
0 0 0 r
2 Mabswid
.57132 .1551 Mdot
.039 .916 .04 r
.5 Mabswid
.49916 .16369 m
.57049 .1665 L
s
0 0 0 r
2 Mabswid
.57049 .1665 Mdot
.039 .916 .04 r
.5 Mabswid
.49764 .17321 m
.5688 .17794 L
s
0 0 0 r
2 Mabswid
.5688 .17794 Mdot
.039 .916 .04 r
.5 Mabswid
.5688 .12087 m
.58958 .11908 L
s
0 0 0 r
2 Mabswid
.58958 .11908 Mdot
.039 .916 .04 r
.5 Mabswid
.57049 .1323 m
.59323 .13114 L
s
0 0 0 r
2 Mabswid
.59323 .13114 Mdot
.039 .916 .04 r
.5 Mabswid
.57132 .14371 m
.59502 .14331 L
s
0 0 0 r
2 Mabswid
.59502 .14331 Mdot
.039 .916 .04 r
.5 Mabswid
.57132 .1551 m
.59502 .1555 L
s
0 0 0 r
2 Mabswid
.59502 .1555 Mdot
.039 .916 .04 r
.5 Mabswid
.57049 .1665 m
.59323 .16767 L
s
0 0 0 r
2 Mabswid
.59323 .16767 Mdot
.039 .916 .04 r
.5 Mabswid
.5688 .17794 m
.58958 .17973 L
s
0 0 0 r
2 Mabswid
.58958 .17973 Mdot
.039 .916 .04 r
.5 Mabswid
.58958 .11908 m
.97619 .18061 L
s
0 0 0 r
2 Mabswid
.97619 .18061 Mdot
.039 .916 .04 r
.5 Mabswid
.59323 .13114 m
.97619 .16433 L
s
0 0 0 r
2 Mabswid
.97619 .16433 Mdot
.039 .916 .04 r
.5 Mabswid
.59502 .14331 m
.97619 .15384 L
s
0 0 0 r
2 Mabswid
.97619 .15384 Mdot
.039 .916 .04 r
.5 Mabswid
.59502 .1555 m
.97619 .14497 L
s
0 0 0 r
2 Mabswid
.97619 .14497 Mdot
.039 .916 .04 r
.5 Mabswid
.59323 .16767 m
.97619 .13448 L
s
0 0 0 r
2 Mabswid
.97619 .13448 Mdot
.039 .916 .04 r
.5 Mabswid
.58958 .17973 m
.97619 .1182 L
s
0 0 0 r
2 Mabswid
.97619 .1182 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo002Dooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool03_ooool0
07Gooooo7ol0001kooooo`03o`000?oooooooooo00kooooo001eooooob3o0000N_ooool00ol0003o
ooooooooo`0>ooooo`00MOooool01?l0003oooooooooooooool2o`0001SoOgmo0_l0001jooooo`03
o`000?oooooooooo00kooooo001eooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl0
5OmoOgl00ol0003oOgmoo`00001iooooo`03o`000?oooooooooo00kooooo001eooooob3o000000?o
Ogmoo`000?ooool0Moooool00ol0003oooooooooo`0>ooooo`00MOooool00ol0003oooooooooo`06
ooooo`;o00004omoOgl01Ol0003oOgmoogmoOomoOgoo000007Oooooo00?o0000ooooooooool03_oo
ool007Gooooo00?o0000ooooooooool02?ooool2o`00017oOgmo00?o0000ogmoOomoOgl00_moOgl0
0ol0003oooooooooo`1dooooo`03o`000?oooooooooo00kooooo001eooooo`03o`000?oooooooooo
00[ooooo0_l0000?ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`0>ooooo`00MOooool00ol0003oooooooooo`0<ooooo`03o`000?moOgooOgmo00co
Ogmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`1booooo`03o`000?oooooooooo00ko
oooo001eooooob3o00001_moOgl00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00kooooo
001eooooo`03o`000?oooooooooo00oooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmo
O`03ogmoO`;o000000?oOgmoo`000?ooool0LOooool00ol0003oooooooooo`0>ooooo`00MOooool0
0ol0003oooooooooo`0?ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl01OmoOgl2
o`0007;ooooo00?o0000ooooooooool03_ooool007Gooooo00?o0000ooooooooool04?ooool00ol0
003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00KoOgmo0_l0001aooooo`03o`000?oooooooooo
00kooooo001eooooo`03o`000?oooooooooo013ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003o
OgmoogmoO`07ogmoO`03o`000?oooooooooo06oooooo00?o0000ooooooooool03_ooool007Gooooo
00?o0000ooooooooool04Oooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00SoOgmo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0>ooooo`00MOooool00ol0003ooooooooo
o`0Aooooo`03o`000?moOgooOgmo00OoOgmo0_l00009ogmoO`?o0000K_ooool00ol0003ooooooooo
o`0>ooooo`00MOoooolOo`0000_oOgmo00?o0000ogmoOol00000KOooool00ol0003oooooooooo`0>
ooooo`00MOooool00ol0003oooooooooo`0Cooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmo
OomoOgl02OmoOgl01?l0003oOgmoogmoOol0001/ooooo`03o`000?oooooooooo00kooooo001eoooo
o`03o`000?oooooooooo01?ooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`09ogmo
O`05o`000?moOgooOgmoogmoOol00000Joooool00ol0003oooooooooo`0>ooooo`00MOooool00ol0
003oooooooooo`0Dooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl02_moOgl01Ol0
003oOgmoogmoOomoOgoo000006[ooooo00?o0000ooooooooool03_ooool007Gooooo00?o0000oooo
ooooool05?ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00[oOgmo00?o0000ogmo
OomoOgl00_moOgl00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00kooooo001eooooo`03
o`000?oooooooooo01Gooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`0;ogmoO`03
o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0>ooooo`00
MOooool00ol0003oooooooooo`0Eooooo`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl0
2omoOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0
3_ooool007Gooooo8?l0000<ogmoO`03o`000?moOgooOgmo00;oOgmo0ol0001Sooooo`?o2NX:0_l0
000?ooooo`00MOooool00ol0003oooooooooo`0Eooooo`03o`000?moOgooOgmo00?oOgmo00?o0000
ogmoOomoOgl00_moOgl9o`WZ2P03o`000?l9jP[o2NX:00Oo2NX:Foooool6o`WZ2P?ooooo0_l0000?
ooooo`003ooooon9o`WZ2PWoOgmo0_l00004ogmoO`04o`000?ooooooooooooooo`Oo2NX:C_ooool6
o`WZ2PWooooo00?o0000ooooooooool03_ooool007Gooooo00?o0000ooooooooool05_ooool2o`00
00?oOgmo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`03ogmoO`?o00002?ooool6o`WZ
2T;ooooo1_l9jPX?ooooo`03o`000?oooooooooo00kooooo001eooooo`03o`000?oooooooooo01Ko
oooo0_l00003ogmoO`03o`000?moOgooOgmo00?oOgmo2?l9jPX00ol0003o2NX:o`WZ2P0;o`WZ2PWo
oooo1ol9jPXdooooo`Oo2NX:5Oooool2o`0000oooooo000?ooooogoo2NX:00?o0000o`WZ2_l9jPX0
2?l9jPX8ogmoO`;o00001OmoOgl00ol0003oooooooooo`04ooooo`_o2NX:1Oooool6o`WZ2RSooooo
1_l9jPXFooooo`Ko2NX:0_l0000?ooooo`00MOooool00ol0003oooooooooo`0Fooooo`03o`000?mo
OgooOgmo00;oOgmo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oo
oooooooo00oooooo4_l9jPXKooooo`Ko2NX:4Oooool;o`WZ2PKooooo00?o0000ooooooooool03_oo
ool000ooooooOol9jPX00ol0003o2NX:o`WZ2P0Go`WZ2P03o`000?l9jP[o2NX:013o2NX:2oooool<
o`WZ2Poooooo1_l9jPX;ooooo`co2NX:4Oooool2o`0000oooooo001eooooo`03o`000?oooooooooo
01Kooooo0_l00003ogmoO`;o00003OmoOgl2o`0000CoOgmo0_l0000AooooobKo2NX:1_ooool;o`WZ
2PCooooo6Ol9jPX2o`0000oooooo001eooooocGo00006Ooooollo`WZ2Q3ooooo0_l0000?ooooo`00
3ooooomoo`WZ2P03o`000?l9jP[o2NX:01Oo2NX:00?o0000o`WZ2_l9jPX06?l9jPX<ooooo`co2NX:
1?ooool7o`WZ2P;ooooo2ol9jPX<oooooa3o2NX:0_l0000?ooooo`00MOooool00ol0003ooooooooo
o`0Fooooo`;o00000omoOgl00ol0003oOgmoogmoO`0<ogmoO`;o00001?moOgl2o`0001_ooooo2ol9
jPXFooooo`Ko2NX:1oooool<o`WZ2Q3ooooo00?o0000ooooooooool03_ooool007Gooooo00?o0000
ooooooooool05_ooool2o`0000?oOgmo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo00kooooo4?l9jPXSooooo`Oo2NX:3?ooool;o`WZ2PGooooo0_l0000?
ooooo`003ooooomoo`WZ2P03o`000?l9jP[o2NX:013o2NX:00?o0000o`WZ2_l9jPX00_l9jPX2ogmo
O`;o00001?ooool;o`WZ2P?ooooo1ol9jPX`ooooo`Ko2NX:4Oooool5o`WZ2P;o00003oooool007Go
oooo00?o0000ooooooooool05_ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00_o
Ogmo0_l00003ogmoO`So2NX:2?ooool6o`WZ2Sgooooo1ol9jPX?ooooo`03o`000?oooooooooo00ko
oooo000?oooooh[o2NX:2?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo00Kooooo
1_l9jPY:ooooo`Ko2NX:2Oooool00ol0003oooooooooo`0>ooooo`00MOooool00ol0003ooooooooo
o`0Fooooo`;o00000omoOgl00ol0003oOgmoogmoO`03ogmoO`So2NX:00?o0000o`WZ2_l9jPX00_l9
jPX01?moOgoo0000o`000?ooool6o`WZ2UKooooo1ol9jPX2ooooo`03o`000?oooooooooo00kooooo
001eooooob3o00003?moOgl2o`0000?oOgmo1?l9jPYSooooo`;o2NX:0_l0000?ooooo`00MOooool0
0ol0003oooooooooo`0Eooooo`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl02omoOgl0
0ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo06Kooooo0_l0000?ooooo`00MOooool00ol0
003oooooooooo`0Eooooo`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl02omoOgl01?l0
003oOgmoogmoOomoOgl2o`0006Sooooo00?o0000ooooooooool03_ooool007Gooooo00?o0000oooo
ooooool05Oooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00_oOgmo00Co0000ogmo
OomoOgoo0000J_ooool00ol0003oooooooooo`0>ooooo`00MOooool00ol0003oooooooooo`0Doooo
o`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl02_moOgl01?l0003oOgmoogmoOol0001[
ooooo`03o`000?oooooooooo00kooooo001eooooo`03o`000?oooooooooo01Cooooo00?o0000ogmo
OomoOgl01?moOgl00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgoo000006cooooo00?o0000oooo
ooooool03_ooool007Gooooo00?o0000ooooooooool04oooool00ol0003oOgmoogmoO`05ogmoO`03
o`000?moOgooOgmo00WoOgmo00?o0000ogmoOol00000KOooool00ol0003oooooooooo`0>ooooo`00
MOooool00ol0003oooooooooo`0Cooooo`03o`000?moOgooOgmo00GoOgmo0_l0000:ogmoO`;o0000
K_ooool00ol0003oooooooooo`0>ooooo`00MOoooolOo`0000[oOgmo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0>ooooo`00MOooool00ol0003oooooooooo`0Aooooo`03o`000?moOgoo
Ogmo00OoOgmo00?o0000ogmoOomoOgl01omoOgl2o`00073ooooo00?o0000ooooooooool03_ooool0
07Gooooo00?o0000ooooooooool04Oooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo
00KoOgmo00?o0000ogmoOol00000L?ooool00ol0003oooooooooo`0>ooooo`00MOooool00ol0003o
ooooooooo`0@ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003o
Ogmoo`00001aooooo`03o`000?oooooooooo00kooooo001eooooo`03o`000?oooooooooo013ooooo
00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`04ogmoO`04o`000?moOgooOgmoo`00077o
oooo00?o0000ooooooooool03_ooool007Gooooo00?o0000ooooooooool03_ooool2o`0000_oOgmo
00?o0000ogmoOomoOgl00omoOgl01?l0003oOgmoogmoOol0001booooo`03o`000?oooooooooo00ko
oooo001eooooob3o00001omoOgl00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00kooooo
001eooooo`03o`000?oooooooooo00_ooooo0_l0000>ogmoO`03o`000?moOgooOgmo00GoOgmo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`0>ooooo`00MOooool00ol0003oooooooooo`09
ooooo`;o00004?moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool03_ooool007Gooooo00?o0000ooooooooool02?ooool00ol0003oOgmoogmoO`0@ogmo
O`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0>oooo
o`00MOooool00ol0003oooooooooo`06ooooo`;o00004omoOgl00ol0003oOgmoogmoO`02ogmoO`03
o`000?oooooooooo07Cooooo00?o0000ooooooooool03_ooool007Gooooo8?l00002ogmoO`03o`00
0?oooooooooo07Gooooo00?o0000ooooooooool03_ooool007Gooooo00?o0000ooooooooool00ooo
ool00ol0003oOgmoogmoO`0EogmoO`05o`000?moOgooOgmoogmoOol00000Moooool00ol0003ooooo
ooooo`0>ooooo`00MOooool01?l0003oooooooooooooool2o`0001SoOgmo00Co0000ogmoOomoOgoo
0000N?ooool00ol0003oooooooooo`0>ooooo`00MOooool01?l0003oooooo`000?l0000JogmoO`?o
0000NOooool00ol0003oooooooooo`0>ooooo`00MOoooolPo`0007[ooooo00?o0000ooooooooool0
3_ooool007Gooooo7ol0001kooooo`03o`000?oooooooooo00kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.42298 .03036 m
.60105 .03036 L
.58414 .07004 L
.4731 .07004 L
.42298 .03036 L
F
.4731 .07004 m
.58414 .07004 L
.57455 .10972 L
.49382 .10972 L
.4731 .07004 L
F
.49382 .10972 m
.57455 .10972 L
.57143 .1494 L
.5 .1494 L
.49382 .10972 L
F
.5 .1494 m
.57143 .1494 L
.57455 .18909 L
.49382 .18909 L
.5 .1494 L
F
.49382 .18909 m
.57455 .18909 L
.58414 .22877 L
.4731 .22877 L
.49382 .18909 L
F
.4731 .22877 m
.58414 .22877 L
.60105 .26845 L
.42298 .26845 L
.4731 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.42298 .03036 m
.4731 .07004 L
.49382 .10972 L
.5 .1494 L
.49382 .18909 L
.4731 .22877 L
.42298 .26845 L
.60105 .26845 L
.58414 .22877 L
.57455 .18909 L
.57143 .1494 L
.57455 .10972 L
.58414 .07004 L
.60105 .03036 L
.42298 .03036 L
s
.5 g
.42298 .1494 m
.60105 .1494 L
.58414 .1494 L
.4731 .1494 L
.42298 .1494 L
F
.4731 .1494 m
.58414 .1494 L
.57455 .1494 L
.49382 .1494 L
.4731 .1494 L
F
.49382 .1494 m
.57455 .1494 L
.57143 .1494 L
.5 .1494 L
.49382 .1494 L
F
.5 .1494 m
.57143 .1494 L
.57455 .1494 L
.49382 .1494 L
.5 .1494 L
F
.49382 .1494 m
.57455 .1494 L
.58414 .1494 L
.4731 .1494 L
.49382 .1494 L
F
.4731 .1494 m
.58414 .1494 L
.60105 .1494 L
.42298 .1494 L
.4731 .1494 L
F
0 g
.42298 .1494 m
.4731 .1494 L
.49382 .1494 L
.5 .1494 L
.49382 .1494 L
.4731 .1494 L
.42298 .1494 L
.60105 .1494 L
.58414 .1494 L
.57455 .1494 L
.57143 .1494 L
.57455 .1494 L
.58414 .1494 L
.60105 .1494 L
.42298 .1494 L
s
.5 g
.60105 .03036 m
.62759 .07004 L
.58414 .07004 L
.60105 .03036 L
F
.58414 .07004 m
.62759 .07004 L
.6024 .10972 L
.57455 .10972 L
.58414 .07004 L
F
.57455 .10972 m
.6024 .10972 L
.59524 .1494 L
.57143 .1494 L
.57455 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.6024 .18909 L
.57455 .18909 L
.57143 .1494 L
F
.57455 .18909 m
.6024 .18909 L
.62759 .22877 L
.58414 .22877 L
.57455 .18909 L
F
.58414 .22877 m
.62759 .22877 L
.60105 .26845 L
.58414 .22877 L
F
0 g
.60105 .03036 m
.58414 .07004 L
.57455 .10972 L
.57143 .1494 L
.57455 .18909 L
.58414 .22877 L
.60105 .26845 L
s
.62759 .22877 m
.6024 .18909 L
.59524 .1494 L
.6024 .10972 L
.62759 .07004 L
s
.60105 .03036 m
0 0 rlineto s
.5 g
.60105 .1494 m
.62759 .1494 L
.58414 .1494 L
.60105 .1494 L
F
.58414 .1494 m
.62759 .1494 L
.6024 .1494 L
.57455 .1494 L
.58414 .1494 L
F
.57455 .1494 m
.6024 .1494 L
.59524 .1494 L
.57143 .1494 L
.57455 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.6024 .1494 L
.57455 .1494 L
.57143 .1494 L
F
.57455 .1494 m
.6024 .1494 L
.62759 .1494 L
.58414 .1494 L
.57455 .1494 L
F
.58414 .1494 m
.62759 .1494 L
.60105 .1494 L
.58414 .1494 L
F
0 g
.60105 .1494 m
.58414 .1494 L
.57455 .1494 L
.57143 .1494 L
.57455 .1494 L
.58414 .1494 L
.60105 .1494 L
s
.62759 .1494 m
.6024 .1494 L
.59524 .1494 L
.6024 .1494 L
.62759 .1494 L
s
.60105 .1494 m
0 0 rlineto s
.42298 .26845 m
.60105 .26845 L
.60105 .2644 L
.42298 .2644 L
.42298 .26845 L
s
.42298 .2644 m
.60105 .2644 L
.60105 .2525 L
.42298 .2525 L
.42298 .2644 L
s
.42298 .2525 m
.60105 .2525 L
.60105 .23358 L
.42298 .23358 L
.42298 .2525 L
s
.42298 .23358 m
.60105 .23358 L
.60105 .20893 L
.42298 .20893 L
.42298 .23358 L
s
.42298 .20893 m
.60105 .20893 L
.60105 .18022 L
.42298 .18022 L
.42298 .20893 L
s
.42298 .18022 m
.60105 .18022 L
.60105 .1494 L
.42298 .1494 L
.42298 .18022 L
s
.42298 .1494 m
.60105 .1494 L
.60105 .11859 L
.42298 .11859 L
.42298 .1494 L
s
.42298 .11859 m
.60105 .11859 L
.60105 .08988 L
.42298 .08988 L
.42298 .11859 L
s
.42298 .08988 m
.60105 .08988 L
.60105 .06523 L
.42298 .06523 L
.42298 .08988 L
s
.42298 .06523 m
.60105 .06523 L
.60105 .04631 L
.42298 .04631 L
.42298 .06523 L
s
.42298 .04631 m
.60105 .04631 L
.60105 .03441 L
.42298 .03441 L
.42298 .04631 L
s
.42298 .03441 m
.60105 .03441 L
.60105 .03036 L
.42298 .03036 L
.42298 .03441 L
s
.42298 .03036 m
.60105 .03036 L
.60105 .03441 L
.42298 .03441 L
.42298 .03036 L
s
.42298 .03441 m
.60105 .03441 L
.60105 .04631 L
.42298 .04631 L
.42298 .03441 L
s
.42298 .04631 m
.60105 .04631 L
.60105 .06523 L
.42298 .06523 L
.42298 .04631 L
s
.42298 .06523 m
.60105 .06523 L
.60105 .08988 L
.42298 .08988 L
.42298 .06523 L
s
.42298 .08988 m
.60105 .08988 L
.60105 .11859 L
.42298 .11859 L
.42298 .08988 L
s
.42298 .11859 m
.60105 .11859 L
.60105 .1494 L
.42298 .1494 L
.42298 .11859 L
s
.42298 .1494 m
.60105 .1494 L
.60105 .18022 L
.42298 .18022 L
.42298 .1494 L
s
.42298 .18022 m
.60105 .18022 L
.60105 .20893 L
.42298 .20893 L
.42298 .18022 L
s
.42298 .20893 m
.60105 .20893 L
.60105 .23358 L
.42298 .23358 L
.42298 .20893 L
s
.42298 .23358 m
.60105 .23358 L
.60105 .2525 L
.42298 .2525 L
.42298 .23358 L
s
.42298 .2525 m
.60105 .2525 L
.60105 .2644 L
.42298 .2644 L
.42298 .2525 L
s
.42298 .2644 m
.60105 .2644 L
.60105 .26845 L
.42298 .26845 L
.42298 .2644 L
s
.60105 .26845 m
0 0 rlineto s
.60105 .2644 m
.60105 .26845 L
s
.60105 .2644 m
0 0 rlineto s
.60105 .2525 m
.60105 .2644 L
s
.60105 .2525 m
0 0 rlineto s
.60105 .23358 m
.60105 .2525 L
s
.60105 .23358 m
0 0 rlineto s
.60105 .20893 m
.60105 .23358 L
s
.60105 .20893 m
0 0 rlineto s
.60105 .18022 m
.60105 .20893 L
s
.60105 .18022 m
0 0 rlineto s
.60105 .1494 m
.60105 .18022 L
s
.60105 .1494 m
0 0 rlineto s
.60105 .11859 m
.60105 .1494 L
s
.60105 .11859 m
0 0 rlineto s
.60105 .08988 m
.60105 .11859 L
s
.60105 .08988 m
0 0 rlineto s
.60105 .06523 m
.60105 .08988 L
s
.60105 .06523 m
0 0 rlineto s
.60105 .04631 m
.60105 .06523 L
s
.60105 .04631 m
0 0 rlineto s
.60105 .03441 m
.60105 .04631 L
s
.60105 .03441 m
0 0 rlineto s
.60105 .03036 m
.60105 .03441 L
s
.60105 .03036 m
0 0 rlineto s
.60105 .03441 m
.60105 .03036 L
s
.60105 .03441 m
0 0 rlineto s
.60105 .04631 m
.60105 .03441 L
s
.60105 .04631 m
0 0 rlineto s
.60105 .06523 m
.60105 .04631 L
s
.60105 .06523 m
0 0 rlineto s
.60105 .08988 m
.60105 .06523 L
s
.60105 .08988 m
0 0 rlineto s
.60105 .11859 m
.60105 .08988 L
s
.60105 .11859 m
0 0 rlineto s
.60105 .1494 m
.60105 .11859 L
s
.60105 .1494 m
0 0 rlineto s
.60105 .18022 m
.60105 .1494 L
s
.60105 .18022 m
0 0 rlineto s
.60105 .20893 m
.60105 .18022 L
s
.60105 .20893 m
0 0 rlineto s
.60105 .23358 m
.60105 .20893 L
s
.60105 .23358 m
0 0 rlineto s
.60105 .2525 m
.60105 .23358 L
s
.60105 .2525 m
0 0 rlineto s
.60105 .2644 m
.60105 .2525 L
s
.60105 .2644 m
0 0 rlineto s
.60105 .26845 m
.60105 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49781 .1256 L
s
0 0 0 r
2 Mabswid
.49781 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49922 .13512 L
s
0 0 0 r
2 Mabswid
.49922 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49991 .14464 L
s
0 0 0 r
2 Mabswid
.49991 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49991 .15417 L
s
0 0 0 r
2 Mabswid
.49991 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49922 .16369 L
s
0 0 0 r
2 Mabswid
.49922 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49781 .17321 L
s
0 0 0 r
2 Mabswid
.49781 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49781 .1256 m
.57303 .12096 L
s
0 0 0 r
2 Mabswid
.57303 .12096 Mdot
.039 .916 .04 r
.5 Mabswid
.49922 .13512 m
.57199 .13245 L
s
0 0 0 r
2 Mabswid
.57199 .13245 Mdot
.039 .916 .04 r
.5 Mabswid
.49991 .14464 m
.57149 .14377 L
s
0 0 0 r
2 Mabswid
.57149 .14377 Mdot
.039 .916 .04 r
.5 Mabswid
.49991 .15417 m
.57149 .15504 L
s
0 0 0 r
2 Mabswid
.57149 .15504 Mdot
.039 .916 .04 r
.5 Mabswid
.49922 .16369 m
.57199 .16636 L
s
0 0 0 r
2 Mabswid
.57199 .16636 Mdot
.039 .916 .04 r
.5 Mabswid
.49781 .17321 m
.57303 .17785 L
s
0 0 0 r
2 Mabswid
.57303 .17785 Mdot
.039 .916 .04 r
.5 Mabswid
.57303 .12096 m
.59908 .12012 L
s
0 0 0 r
2 Mabswid
.59908 .12012 Mdot
.039 .916 .04 r
.5 Mabswid
.57199 .13245 m
.59658 .13198 L
s
0 0 0 r
2 Mabswid
.59658 .13198 Mdot
.039 .916 .04 r
.5 Mabswid
.57149 .14377 m
.59539 .14362 L
s
0 0 0 r
2 Mabswid
.59539 .14362 Mdot
.039 .916 .04 r
.5 Mabswid
.57149 .15504 m
.59539 .15519 L
s
0 0 0 r
2 Mabswid
.59539 .15519 Mdot
.039 .916 .04 r
.5 Mabswid
.57199 .16636 m
.59658 .16683 L
s
0 0 0 r
2 Mabswid
.59658 .16683 Mdot
.039 .916 .04 r
.5 Mabswid
.57303 .17785 m
.59908 .17869 L
s
0 0 0 r
2 Mabswid
.59908 .17869 Mdot
.039 .916 .04 r
.5 Mabswid
.59658 .13198 m
.97619 .07006 L
s
0 0 0 r
2 Mabswid
.97619 .07006 Mdot
.039 .916 .04 r
.5 Mabswid
.59539 .14362 m
.97619 .12362 L
s
0 0 0 r
2 Mabswid
.97619 .12362 Mdot
.039 .916 .04 r
.5 Mabswid
.59539 .15519 m
.97619 .17519 L
s
0 0 0 r
2 Mabswid
.97619 .17519 Mdot
.039 .916 .04 r
.5 Mabswid
.59658 .16683 m
.97619 .22875 L
s
0 0 0 r
2 Mabswid
.97619 .22875 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo002Zooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool03_ooool0
07[ooooo<Ol0001Tooooo`03o`000?oooooooooo00kooooo001joooooc7o0000I?ooool00ol0003o
ooooooooo`0>ooooo`00N_ooool00ol0003oooooooooo`02o`0002[oOgmo0_l0001Tooooo`03o`00
0?oooooooooo00kooooo001jooooo`03o`000?oooooooooo00;ooooo00?o0000ogmoOomoOgl09omo
Ogl2o`000003ogmoOooooooooooo067ooooo00?o0000ooooooooool03_ooool007[ooooo<Ol00000
0omoOgooooooooooo`1Qooooo`03o`000?oooooooooo00kooooo001jooooo`03o`000?oooooooooo
00Cooooo0_l0000UogmoO`03o`000?moOgoo000000;oOgmoH_ooool00ol0003oooooooooo`0>oooo
o`00N_ooool00ol0003oooooooooo`06ooooo`03o`000?moOgooOgmo02;oOgmo00?o0000ogmoOol0
00000omoOgmQooooo`03o`000?oooooooooo00kooooo001jooooo`03o`000?oooooooooo00Oooooo
0_l0000QogmoO`04o`000?moOgooOgmoo`0000CoOgmoH?ooool00ol0003oooooooooo`0>ooooo`00
N_ooool00ol0003oooooooooo`09ooooo`03o`000?moOgooOgmo01koOgmo00Co0000ogmoOomoOgoo
00001?moOgmPooooo`03o`000?oooooooooo00kooooo001joooooc7o00001OmoOgmOooooo`03o`00
0?oooooooooo00kooooo001jooooo`03o`000?oooooooooo00_ooooo00?o0000ogmoOomoOgl06omo
Ogl01Ol0003oOgmoogmoOomoOgoo000000KoOgmo00?o0000ooooooooool0F?ooool3o`WZ2P;o0000
3oooool007[ooooo00?o0000ooooooooool02oooool00ol0003oOgmoogmoO`0KogmoO`05o`000?mo
OgooOgmoogmoOol000001_moOgl00ol0003oooooooooo`1Booooo`Ko2NX:0oooool2o`0000oooooo
001jooooo`03o`000?oooooooooo00cooooo00?o0000ogmoOomoOgl06_moOgl01Ol0003oOgmoogmo
OomoOgoo000000GoOgmo00?o0000ooooooooool0COooool6o`WZ2PWooooo00?o0000ooooooooool0
3_ooool007[ooooo00?o0000ooooooooool03?ooool00ol0003oOgmoogmoO`0IogmoO`03o`000?mo
OgooOgmo00;oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`17ooooo`Ko2NX:3ooo
ool00ol0003oooooooooo`0>ooooo`00N_ooool00ol0003oooooooooo`0=ooooo`03o`000?moOgoo
Ogmo01SoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooo
oooo04;ooooo1_l9jPXEooooo`03o`000?oooooooooo00kooooo001jooooo`03o`000?oooooooooo
00gooooo00?o0000ogmoOomoOgl06?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo
00;oOgmo00?o0000ooooooooool0??ooool6o`WZ2Q_ooooo00?o0000ooooooooool03_ooool007[o
oooo<Ol00003ogmoO`03o`000?oooooooooo03Oooooo1_l9jPXQooooo`03o`000?oooooooooo00ko
oooo001jooooo`03o`000?oooooooooo00kooooo00?o0000ogmoOomoOgl05_moOgl00ol0003oOgmo
ogmoO`03ogmoO`04o`000?moOgooOgmoo`0003Cooooo1_l9jPXWooooo`03o`000?oooooooooo00ko
oooo001jooooo`03o`000?oooooooooo00kooooo00?o0000ogmoOomoOgl05_moOgl00ol0003oOgmo
ogmoO`03ogmoO`04o`000?moOgooOgmoo`0002kooooo1_l9jPX]ooooo`03o`000?oooooooooo00ko
oooo001jooooo`03o`000?oooooooooo00oooooo00?o0000ogmoOomoOgl05OmoOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?moOgoo000002Wooooo1_l9jPXcooooo`03o`000?oooooooooo00kooooo
001jooooo`03o`000?oooooooooo00oooooo00?o0000ogmoOomoOgl05?moOgl00ol0003oOgmoogmo
O`04ogmoO`03o`000?moOgoo000002?ooooo1_l9jPXiooooo`03o`000?oooooooooo00kooooo001j
ooooo`03o`000?oooooooooo013ooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oOgmoogmoO`04
ogmoO`;o00007_ooool6o`WZ2Soooooo00?o0000ooooooooool03_ooool007[ooooo00?o0000oooo
ooooool04?ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo00CoOgmo0_l0000Hoooo
o`Ko2NX:AOooool00ol0003oooooooooo`0>ooooo`00N_oooolbo`0001;ooooo1_l9jPY;ooooo`03
o`000?oooooooooo00kooooo001jooooo`03o`000?oooooooooo013ooooo00?o0000ogmoOomoOgl0
2OmoOgl9o`WZ2P03o`000?l9jP[o2NX:00Co2NX:0ol0000<ooooo`Ko2NX:DOooool2o`0000oooooo
000?oooooh[o2NX:2OmoOgl2o`0000KoOgmo00?o0000ooooooooool01Oooool6o`WZ2Tgooooo2_l9
jPX2o`0000oooooo001jooooo`03o`000?oooooooooo017ooooo0_l0000CogmoO`03o`000?moOgoo
Ogmo00CoOgmo00?o0000ooooool9jPX01Ol9jPXnoooooaGo2NX:2_ooool00ol0003oooooooooo`0>
ooooo`00N_ooool00ol0003oooooooooo`0Aooooo`;o00002OmoOgl?o`WZ2P04o`000?l9jP[o2NX:
o`WZ2S3ooooo5?l9jPXOooooo`03o`000?oooooooooo00kooooo000?ooooogoo2NX:00?o0000o`WZ
2_l9jPX02?l9jPX9ogmoO`;o00001?moOgl3o`0001gooooo5?l9jPXcooooo`03o`000?oooooooooo
00kooooo001jooooo`03o`000?oooooooooo017ooooo00?o0000ogmoOomoOgl04OmoOgl00ol0003o
OgmoogmoO`05ogmoO`03o`000?oooooooooo00Kooooo5Ol9jPY7ooooo`03o`000?oooooooooo00ko
oooo000?ooooogoo2NX:00?o0000o`WZ2_l9jPX05ol9jPX00ol0003o2NX:o`WZ2P08o`WZ2Ucooooo
00?o0000ooooooooool03_ooool007[ooooo00?o0000ooooooooool04Oooool2o`0001;oOgmo0_l0
0004ogmoO`?o0000I?ooool00ol0003oooooooooo`0>ooooo`00N_oooolho`0005gooooo00?o0000
ooooooooool03_ooool000ooooooOol9jPX00ol0003o2NX:o`WZ2P0Go`WZ2P03o`000?l9jP[o2NX:
00So2NX:G?ooool00ol0003oooooooooo`0>ooooo`00N_ooool00ol0003oooooooooo`0Aooooo`;o
00004_moOgl2o`0000CoOgmo0ol00008oooooa7o2NX:Boooool00ol0003oooooooooo`0>ooooo`00
N_ooool00ol0003oooooooooo`0Aooooo`;o00004_moOgl00ol0003oOgmoogmoO`05ogmoO`03o`00
0?oooooooooo01Oooooo4Ol9jPXjooooo`03o`000?oooooooooo00kooooo000?ooooogoo2NX:00?o
0000o`WZ2_l9jPX05ol9jPX00ol0003o2NX:o`WZ2P02o`WZ2RSooooo4Ol9jPXYooooo`03o`000?oo
oooooooo00kooooo001jooooo`03o`000?oooooooooo017ooooo00?o0000ogmoOomoOgl04OmoOgl2
o`0000CoOgmo0ol00002ooooo`Ko2NX:<ooooolAo`WZ2QSooooo00?o0000ooooooooool03_ooool0
00ooooooRol9jPX9ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool01_ooool6o`WZ
2Skooooo4Ol9jPX7ooooo`;o00003oooool007[ooooo00?o0000ooooooooool04Oooool2o`0000[o
Ogmo2?l9jPX00ol0003o2NX:o`WZ2P03o`WZ2P03ogmoOol0003o000000kooooo1_l9jPY9ooooo`Oo
2NX:0_l0000?ooooo`00N_ooool^o`000004o`WZ2_l0003o0000o`0001?ooooo1_l9jPY:ooooo`03
o`000?oooooooooo00kooooo001jooooo`03o`000?oooooooooo013ooooo00?o0000ogmoOomoOgl0
4omoOgl00ol0003oOgmoogmoO`04ogmoO`;o00006Oooool6o`WZ2TCooooo00?o0000ooooooooool0
3_ooool007[ooooo00?o0000ooooooooool04?ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?mo
OgooOgmo00CoOgmo0_l0000Oooooo`Ko2NX:?_ooool00ol0003oooooooooo`0>ooooo`00N_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?moOgooOgmo01?oOgmo00?o0000ogmoOomoOgl01?moOgl2
o`0002Gooooo1_l9jPXhooooo`03o`000?oooooooooo00kooooo001jooooo`03o`000?oooooooooo
00oooooo00?o0000ogmoOomoOgl05?moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgoo0000
02[ooooo1_l9jPXbooooo`03o`000?oooooooooo00kooooo001jooooo`03o`000?oooooooooo00oo
oooo00?o0000ogmoOomoOgl05OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgoo0000033o
oooo1_l9jPX/ooooo`03o`000?oooooooooo00kooooo001jooooo`03o`000?oooooooooo00kooooo
00?o0000ogmoOomoOgl05_moOgl00ol0003oOgmoogmoO`03ogmoO`04o`000?moOgooOgmoo`0003Go
oooo1_l9jPXVooooo`03o`000?oooooooooo00kooooo001jooooo`03o`000?oooooooooo00kooooo
00?o0000ogmoOomoOgl05_moOgl00ol0003oOgmoogmoO`03ogmoO`04o`000?moOgooOgmoo`0003_o
oooo1_l9jPXPooooo`03o`000?oooooooooo00kooooo001joooooc7o00000omoOgl00ol0003ooooo
ooooo`0nooooo`Ko2NX:6_ooool00ol0003oooooooooo`0>ooooo`00N_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?moOgooOgmo01SoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmo
O`02ogmoO`03o`000?oooooooooo04?ooooo1_l9jPXDooooo`03o`000?oooooooooo00kooooo001j
ooooo`03o`000?oooooooooo00gooooo00?o0000ogmoOomoOgl06?moOgl00ol0003oOgmoogmoO`02
ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0BOooool6o`WZ2Pkooooo00?o0000
ooooooooool03_ooool007[ooooo00?o0000ooooooooool03?ooool00ol0003oOgmoogmoO`0Iogmo
O`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1>oooo
o`Ko2NX:2?ooool00ol0003oooooooooo`0>ooooo`00N_ooool00ol0003oooooooooo`0<ooooo`03
o`000?moOgooOgmo01[oOgmo00Go0000ogmoOomoOgooOgmoo`000005ogmoO`03o`000?oooooooooo
05Cooooo1_l9jPX2ooooo`03o`000?oooooooooo00kooooo001jooooo`03o`000?oooooooooo00[o
oooo0_l0000MogmoO`05o`000?moOgooOgmoogmoOol000001_moOgl00ol0003oooooooooo`1Ioooo
o`;o2NX:0_l0000?ooooo`00N_oooolao`0000KoOgmoG_ooool2o`0000oooooo001jooooo`03o`00
0?oooooooooo00Sooooo00?o0000ogmoOomoOgl07omoOgl01?l0003oOgmoogmoOol00006ogmoOeko
oooo00?o0000ooooooooool03_ooool007[ooooo00?o0000ooooooooool01oooool00ol0003oOgmo
ogmoO`0PogmoO`04o`000?moOgooOgmoo`0000GoOgmoGoooool00ol0003oooooooooo`0>ooooo`00
N_ooool00ol0003oooooooooo`05ooooo`;o00008omoOgl01?l0003oOgmoogmoOol00004ogmoOf3o
oooo00?o0000ooooooooool03_ooool007[ooooo00?o0000ooooooooool01?ooool00ol0003oOgmo
ogmoO`0TogmoO`03o`000?moOgoo000000CoOgmoH?ooool00ol0003oooooooooo`0>ooooo`00N_oo
oolao`0000?oOgmoHOooool00ol0003oooooooooo`0>ooooo`00N_ooool01?l0003ooooooooooooo
ool2o`0002SoOgmo00?o0000ogmoOol000000_moOgmRooooo`03o`000?oooooooooo00kooooo001j
ooooo`04o`000?ooooooooooo`0002_oOgmo0_l00002ogmoOf;ooooo00?o0000ooooooooool03_oo
ool007[ooooo00?o0000ooooool00000;?moOgl2o`000003ogmoOooooooooooo067ooooo00?o0000
ooooooooool03_ooool007[ooooo<Ol000000omoOgooooooooooo`1Qooooo`03o`000?oooooooooo
00kooooo001joooooc7o0000I?ooool00ol0003oooooooooo`0>ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.43482 .03036 m
.63032 .03036 L
.59419 .07004 L
.47561 .07004 L
.43482 .03036 L
F
.47561 .07004 m
.59419 .07004 L
.57678 .10972 L
.49431 .10972 L
.47561 .07004 L
F
.49431 .10972 m
.57678 .10972 L
.57143 .1494 L
.5 .1494 L
.49431 .10972 L
F
.5 .1494 m
.57143 .1494 L
.57678 .18909 L
.49431 .18909 L
.5 .1494 L
F
.49431 .18909 m
.57678 .18909 L
.59419 .22877 L
.47561 .22877 L
.49431 .18909 L
F
.47561 .22877 m
.59419 .22877 L
.63032 .26845 L
.43482 .26845 L
.47561 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.43482 .03036 m
.47561 .07004 L
.49431 .10972 L
.5 .1494 L
.49431 .18909 L
.47561 .22877 L
.43482 .26845 L
.63032 .26845 L
.59419 .22877 L
.57678 .18909 L
.57143 .1494 L
.57678 .10972 L
.59419 .07004 L
.63032 .03036 L
.43482 .03036 L
s
.5 g
.43482 .1494 m
.63032 .1494 L
.59419 .1494 L
.47561 .1494 L
.43482 .1494 L
F
.47561 .1494 m
.59419 .1494 L
.57678 .1494 L
.49431 .1494 L
.47561 .1494 L
F
.49431 .1494 m
.57678 .1494 L
.57143 .1494 L
.5 .1494 L
.49431 .1494 L
F
.5 .1494 m
.57143 .1494 L
.57678 .1494 L
.49431 .1494 L
.5 .1494 L
F
.49431 .1494 m
.57678 .1494 L
.59419 .1494 L
.47561 .1494 L
.49431 .1494 L
F
.47561 .1494 m
.59419 .1494 L
.63032 .1494 L
.43482 .1494 L
.47561 .1494 L
F
0 g
.43482 .1494 m
.47561 .1494 L
.49431 .1494 L
.5 .1494 L
.49431 .1494 L
.47561 .1494 L
.43482 .1494 L
.63032 .1494 L
.59419 .1494 L
.57678 .1494 L
.57143 .1494 L
.57678 .1494 L
.59419 .1494 L
.63032 .1494 L
.43482 .1494 L
s
.5 g
.63032 .03036 m
.58116 .03036 L
.58903 .07004 L
.59419 .07004 L
.63032 .03036 L
F
.59419 .07004 m
.58903 .07004 L
.59369 .10972 L
.57678 .10972 L
.59419 .07004 L
F
.57678 .10972 m
.59369 .10972 L
.59524 .1494 L
.57143 .1494 L
.57678 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59369 .18909 L
.57678 .18909 L
.57143 .1494 L
F
.57678 .18909 m
.59369 .18909 L
.58903 .22877 L
.59419 .22877 L
.57678 .18909 L
F
.59419 .22877 m
.58903 .22877 L
.58116 .26845 L
.63032 .26845 L
.59419 .22877 L
F
0 g
.63032 .03036 m
.59419 .07004 L
.57678 .10972 L
.57143 .1494 L
.57678 .18909 L
.59419 .22877 L
.63032 .26845 L
.58116 .26845 L
.58903 .22877 L
.59369 .18909 L
.59524 .1494 L
.59369 .10972 L
.58903 .07004 L
.58116 .03036 L
.63032 .03036 L
s
.5 g
.63032 .1494 m
.58116 .1494 L
.58903 .1494 L
.59419 .1494 L
.63032 .1494 L
F
.59419 .1494 m
.58903 .1494 L
.59369 .1494 L
.57678 .1494 L
.59419 .1494 L
F
.57678 .1494 m
.59369 .1494 L
.59524 .1494 L
.57143 .1494 L
.57678 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59369 .1494 L
.57678 .1494 L
.57143 .1494 L
F
.57678 .1494 m
.59369 .1494 L
.58903 .1494 L
.59419 .1494 L
.57678 .1494 L
F
.59419 .1494 m
.58903 .1494 L
.58116 .1494 L
.63032 .1494 L
.59419 .1494 L
F
0 g
.63032 .1494 m
.59419 .1494 L
.57678 .1494 L
.57143 .1494 L
.57678 .1494 L
.59419 .1494 L
.63032 .1494 L
.58116 .1494 L
.58903 .1494 L
.59369 .1494 L
.59524 .1494 L
.59369 .1494 L
.58903 .1494 L
.58116 .1494 L
.63032 .1494 L
s
.43482 .26845 m
.63032 .26845 L
.63032 .2644 L
.43482 .2644 L
.43482 .26845 L
s
.43482 .2644 m
.63032 .2644 L
.63032 .2525 L
.43482 .2525 L
.43482 .2644 L
s
.43482 .2525 m
.63032 .2525 L
.63032 .23358 L
.43482 .23358 L
.43482 .2525 L
s
.43482 .23358 m
.63032 .23358 L
.63032 .20893 L
.43482 .20893 L
.43482 .23358 L
s
.43482 .20893 m
.63032 .20893 L
.63032 .18022 L
.43482 .18022 L
.43482 .20893 L
s
.43482 .18022 m
.63032 .18022 L
.63032 .1494 L
.43482 .1494 L
.43482 .18022 L
s
.43482 .1494 m
.63032 .1494 L
.63032 .11859 L
.43482 .11859 L
.43482 .1494 L
s
.43482 .11859 m
.63032 .11859 L
.63032 .08988 L
.43482 .08988 L
.43482 .11859 L
s
.43482 .08988 m
.63032 .08988 L
.63032 .06523 L
.43482 .06523 L
.43482 .08988 L
s
.43482 .06523 m
.63032 .06523 L
.63032 .04631 L
.43482 .04631 L
.43482 .06523 L
s
.43482 .04631 m
.63032 .04631 L
.63032 .03441 L
.43482 .03441 L
.43482 .04631 L
s
.43482 .03441 m
.63032 .03441 L
.63032 .03036 L
.43482 .03036 L
.43482 .03441 L
s
.43482 .03036 m
.63032 .03036 L
.63032 .03441 L
.43482 .03441 L
.43482 .03036 L
s
.43482 .03441 m
.63032 .03441 L
.63032 .04631 L
.43482 .04631 L
.43482 .03441 L
s
.43482 .04631 m
.63032 .04631 L
.63032 .06523 L
.43482 .06523 L
.43482 .04631 L
s
.43482 .06523 m
.63032 .06523 L
.63032 .08988 L
.43482 .08988 L
.43482 .06523 L
s
.43482 .08988 m
.63032 .08988 L
.63032 .11859 L
.43482 .11859 L
.43482 .08988 L
s
.43482 .11859 m
.63032 .11859 L
.63032 .1494 L
.43482 .1494 L
.43482 .11859 L
s
.43482 .1494 m
.63032 .1494 L
.63032 .18022 L
.43482 .18022 L
.43482 .1494 L
s
.43482 .18022 m
.63032 .18022 L
.63032 .20893 L
.43482 .20893 L
.43482 .18022 L
s
.43482 .20893 m
.63032 .20893 L
.63032 .23358 L
.43482 .23358 L
.43482 .20893 L
s
.43482 .23358 m
.63032 .23358 L
.63032 .2525 L
.43482 .2525 L
.43482 .23358 L
s
.43482 .2525 m
.63032 .2525 L
.63032 .2644 L
.43482 .2644 L
.43482 .2525 L
s
.43482 .2644 m
.63032 .2644 L
.63032 .26845 L
.43482 .26845 L
.43482 .2644 L
s
.63032 .26845 m
.58116 .26845 L
.58116 .2644 L
.63032 .2644 L
.63032 .26845 L
s
.63032 .2644 m
.58116 .2644 L
.58116 .2525 L
.63032 .2525 L
.63032 .2644 L
s
.63032 .2525 m
.58116 .2525 L
.58116 .23358 L
.63032 .23358 L
.63032 .2525 L
s
.63032 .23358 m
.58116 .23358 L
.58116 .20893 L
.63032 .20893 L
.63032 .23358 L
s
.63032 .20893 m
.58116 .20893 L
.58116 .18022 L
.63032 .18022 L
.63032 .20893 L
s
.63032 .18022 m
.58116 .18022 L
.58116 .1494 L
.63032 .1494 L
.63032 .18022 L
s
.63032 .1494 m
.58116 .1494 L
.58116 .11859 L
.63032 .11859 L
.63032 .1494 L
s
.63032 .11859 m
.58116 .11859 L
.58116 .08988 L
.63032 .08988 L
.63032 .11859 L
s
.63032 .08988 m
.58116 .08988 L
.58116 .06523 L
.63032 .06523 L
.63032 .08988 L
s
.63032 .06523 m
.58116 .06523 L
.58116 .04631 L
.63032 .04631 L
.63032 .06523 L
s
.63032 .04631 m
.58116 .04631 L
.58116 .03441 L
.63032 .03441 L
.63032 .04631 L
s
.63032 .03441 m
.58116 .03441 L
.58116 .03036 L
.63032 .03036 L
.63032 .03441 L
s
.63032 .03036 m
.58116 .03036 L
.58116 .03441 L
.63032 .03441 L
.63032 .03036 L
s
.63032 .03441 m
.58116 .03441 L
.58116 .04631 L
.63032 .04631 L
.63032 .03441 L
s
.63032 .04631 m
.58116 .04631 L
.58116 .06523 L
.63032 .06523 L
.63032 .04631 L
s
.63032 .06523 m
.58116 .06523 L
.58116 .08988 L
.63032 .08988 L
.63032 .06523 L
s
.63032 .08988 m
.58116 .08988 L
.58116 .11859 L
.63032 .11859 L
.63032 .08988 L
s
.63032 .11859 m
.58116 .11859 L
.58116 .1494 L
.63032 .1494 L
.63032 .11859 L
s
.63032 .1494 m
.58116 .1494 L
.58116 .18022 L
.63032 .18022 L
.63032 .1494 L
s
.63032 .18022 m
.58116 .18022 L
.58116 .20893 L
.63032 .20893 L
.63032 .18022 L
s
.63032 .20893 m
.58116 .20893 L
.58116 .23358 L
.63032 .23358 L
.63032 .20893 L
s
.63032 .23358 m
.58116 .23358 L
.58116 .2525 L
.63032 .2525 L
.63032 .23358 L
s
.63032 .2525 m
.58116 .2525 L
.58116 .2644 L
.63032 .2644 L
.63032 .2525 L
s
.63032 .2644 m
.58116 .2644 L
.58116 .26845 L
.63032 .26845 L
.63032 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49798 .1256 L
s
0 0 0 r
2 Mabswid
.49798 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49928 .13512 L
s
0 0 0 r
2 Mabswid
.49928 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49992 .14464 L
s
0 0 0 r
2 Mabswid
.49992 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49992 .15417 L
s
0 0 0 r
2 Mabswid
.49992 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49928 .16369 L
s
0 0 0 r
2 Mabswid
.49928 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49798 .17321 L
s
0 0 0 r
2 Mabswid
.49798 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49798 .1256 m
.57409 .12127 L
s
0 0 0 r
2 Mabswid
.57409 .12127 Mdot
.039 .916 .04 r
.5 Mabswid
.49928 .13512 m
.57237 .13265 L
s
0 0 0 r
2 Mabswid
.57237 .13265 Mdot
.039 .916 .04 r
.5 Mabswid
.49992 .14464 m
.57153 .14384 L
s
0 0 0 r
2 Mabswid
.57153 .14384 Mdot
.039 .916 .04 r
.5 Mabswid
.49992 .15417 m
.57153 .15497 L
s
0 0 0 r
2 Mabswid
.57153 .15497 Mdot
.039 .916 .04 r
.5 Mabswid
.49928 .16369 m
.57237 .16616 L
s
0 0 0 r
2 Mabswid
.57237 .16616 Mdot
.039 .916 .04 r
.5 Mabswid
.49798 .17321 m
.57409 .17754 L
s
0 0 0 r
2 Mabswid
.57409 .17754 Mdot
.039 .916 .04 r
.5 Mabswid
.57409 .12127 m
.59444 .12097 L
s
0 0 0 r
2 Mabswid
.59444 .12097 Mdot
.039 .916 .04 r
.5 Mabswid
.57237 .13265 m
.59496 .13244 L
s
0 0 0 r
2 Mabswid
.59496 .13244 Mdot
.039 .916 .04 r
.5 Mabswid
.57153 .14384 m
.59521 .14376 L
s
0 0 0 r
2 Mabswid
.59521 .14376 Mdot
.039 .916 .04 r
.5 Mabswid
.57153 .15497 m
.59521 .15505 L
s
0 0 0 r
2 Mabswid
.59521 .15505 Mdot
.039 .916 .04 r
.5 Mabswid
.57237 .16616 m
.59496 .16637 L
s
0 0 0 r
2 Mabswid
.59496 .16637 Mdot
.039 .916 .04 r
.5 Mabswid
.57409 .17754 m
.59444 .17784 L
s
0 0 0 r
2 Mabswid
.59444 .17784 Mdot
.039 .916 .04 r
.5 Mabswid
.59444 .12097 m
.97619 .12761 L
s
0 0 0 r
2 Mabswid
.97619 .12761 Mdot
.039 .916 .04 r
.5 Mabswid
.59496 .13244 m
.97619 .13616 L
s
0 0 0 r
2 Mabswid
.97619 .13616 Mdot
.039 .916 .04 r
.5 Mabswid
.59521 .14376 m
.97619 .14497 L
s
0 0 0 r
2 Mabswid
.97619 .14497 Mdot
.039 .916 .04 r
.5 Mabswid
.59521 .15505 m
.97619 .15384 L
s
0 0 0 r
2 Mabswid
.97619 .15384 Mdot
.039 .916 .04 r
.5 Mabswid
.59496 .16637 m
.97619 .16265 L
s
0 0 0 r
2 Mabswid
.97619 .16265 Mdot
.039 .916 .04 r
.5 Mabswid
.59444 .17784 m
.97619 .17119 L
s
0 0 0 r
2 Mabswid
.97619 .17119 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool007gooooo=_l0001Loooo
o`03o`000?oooooooooo00kooooo001mooooocKo0000G?ooool00ol0003oooooooooo`0>ooooo`00
OOooool01?l0003oooooooooool0000TogmoO`03o`000?moOgooOgmo00SoOgmo00?o0000ooooool0
0000G?ooool00ol0003oooooooooo`0>ooooo`00OOooool01Ol0003ooooooooooooooooo000002?o
Ogmo0_l00008ogmoO`04o`000?ooooooooooo`0005cooooo00?o0000ooooooooool03_ooool007go
oooo=_l0001Looooo`03o`000?oooooooooo00kooooo001mooooo`03o`000?oooooooooo00?ooooo
00?o0000ogmoOomoOgl07omoOgl2o`0000KoOgmo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo00kooooo001mooooo`03o`000?oooooooooo00Cooooo00?o
0000ogmoOomoOgl07_moOgl2o`0000GoOgmo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo00kooooo001mooooo`03o`000?oooooooooo00Gooooo00?o0000
ogmoOomoOgl07OmoOgl2o`0000CoOgmo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00kooooo001mooooo`03o`000?oooooooooo00Kooooo00?o0000ogmo
OomoOgl07?moOgl00ol0003oOgmoo`000002ogmoO`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`0>ooooo`00OOoooolfo`0005cooooo00?o0000oooooooo
ool03_ooool007gooooo00?o0000ooooooooool02?ooool00ol0003oOgmoogmoO`0JogmoO`04o`00
0?moOgoo0000o`0000Wooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0>ooooo`00
OOooool00ol0003oooooooooo`08ooooo`03o`000?moOgooOgmo01[oOgmo00Co0000ogmoOol0003o
00002Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo001mooooo`03o`00
0?oooooooooo00Wooooo00?o0000ogmoOomoOgl06OmoOgl00ol0003oOgmoo`00000:ooooo`03o`00
0?oooooooooo05[ooooo00?o0000ooooooooool03_ooool007gooooo00?o0000ooooooooool02Ooo
ool00ol0003oOgmoogmoO`0IogmoO`03o`000?moOgoo000000[ooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`0>ooooo`00OOooool00ol0003oooooooooo`0:ooooo`03o`000?moOgoo
Ogmo01SoOgmo00?o0000ogmoOol000002_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo00kooooo001mooooo`03o`000?oooooooooo00[ooooo00?o0000ogmoOomoOgl06?moOgl3o`00
00[ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0>ooooo`00OOoooolfo`0005co
oooo00?o0000ooooooooool03_ooool007gooooo00?o0000ooooooooool02oooool00ol0003oOgmo
ogmoO`0GogmoO`;o000000?oOgmoo`000?ooool02?ooool00ol0003oooooooooo`1Jooooo`03o`00
0?oooooooooo00kooooo001mooooo`03o`000?oooooooooo00_ooooo00?o0000ogmoOomoOgl05omo
Ogl01?l0003oOgmoogmoOol00009ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
3_ooool007gooooo00?o0000ooooooooool03?ooool00ol0003oOgmoogmoO`0FogmoO`04o`000?mo
OgooOgmoo`0000Wooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0>ooooo`00OOoo
ool00ol0003oooooooooo`0<ooooo`03o`000?moOgooOgmo01KoOgmo00Co0000ogmoOomoOgoo0000
2Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo001mooooo`03o`000?oo
oooooooo00gooooo00?o0000ogmoOomoOgl05?moOgl2o`0000;oOgmo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo001mooooo`03o`000?oooooo
oooo00gooooo00?o0000ogmoOomoOgl05?moOgl2o`0000;oOgmo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo001mooooocKo0000G?ooool00ol0
003oooooooooo`0>ooooo`00OOooool00ol0003oooooooooo`0=ooooo`03o`000?moOgooOgmo00Wo
Ogmo2Ol9jPX00ol0003o2NX:o`WZ2P0No`WZ2Tcooooo00?o0000ooooooooool03_ooool000oooooo
R_l9jPX9ogmoO`;o000000CoOgmoo`000?moOgooOgmo0_l00008ooooo`03o`000?oooooooooo00ko
oooo<ol9jPXIooooo`;o00003oooool007gooooo00?o0000ooooooooool03_ooool2o`0001?oOgmo
00?o0000ogmoOol000000_moOgl00ol0003oooooooooo`07ooooo`03o`000?oooooooooo047ooooo
6Ol9jPX2o`0000oooooo001mooooo`03o`000?oooooooooo00kooooo0_l00009ogmoO`oo2NX:00?o
0000o`WZ2_l9jPX0<_l9jPXbooooo`03o`000?oooooooooo00kooooo000?ooooogoo2NX:00?o0000
o`WZ2_l9jPX02?l9jPX9ogmoO`;o000000CoOgmoo`000?moOgooOgmo0_l00008ooooo`03o`000?oo
oooooooo02Sooooo<_l9jPX2o`0000oooooo001mooooo`03o`000?oooooooooo00kooooo00?o0000
ogmoOomoOgl04_moOgl00ol0003oOgmoo`000003ogmoO`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0F_ooool2o`0000oooooo000?ooooogoo2NX:00?o0000o`WZ2_l9jPX05ol9jPX00ol0
003o2NX:o`WZ2P0bo`WZ2S;ooooo0_l0000?ooooo`00OOooool00ol0003oooooooooo`0>ooooo`;o
00004_moOgl2o`000004ogmoOol0003oOgmoogmoO`;o00002?ooool00ol0003oooooooooo`0Xoooo
oc;o2NX:0_l0000?ooooo`00OOoooolfo`0005cooooo0_l0000?ooooo`003ooooomoo`WZ2P03o`00
0?l9jP[o2NX:01Oo2NX:00?o0000o`WZ2_l9jPX0I?l9jPX2o`0000oooooo001mooooo`03o`000?oo
oooooooo00kooooo0_l0000BogmoO`;o000000CoOgmoo`000?moOgooOgmo0_l00008ooooo`03o`00
0?oooooooooo05[ooooo00?o0000ooooooooool03_ooool007gooooo00?o0000ooooooooool03_oo
ool2o`0001?oOgmo00?o0000ogmoOol000000omoOgl00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Oooooo<ol9jPX2o`0000oooooo000?ooooogoo2NX:00?o0000o`WZ2_l9jPX05ol9jPX0
0ol0003o2NX:o`WZ2P0ao`WZ2S?ooooo0_l0000?ooooo`00OOooool00ol0003oooooooooo`0>oooo
o`03o`000?moOgooOgmo017oOgmo0_l000001?moOgoo0000ogmoOomoOgl2o`0000Sooooo00?o0000
ooooooooool0F_ooool2o`0000oooooo000?oooooh_o2NX:2OmoOgl00ol0003oOgmoo`000002ogmo
O`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09ooooolco`WZ2P;o00003oooool007go
oooo00?o0000ooooooooool03_ooool2o`0000[oOgmo2?l9jPX00ol0003o2NX:o`WZ2P0go`WZ2S?o
oooo00?o0000ooooooooool03_ooool007gooooo=_l0001Looooo`03o`000?oooooooooo00kooooo
001mooooo`03o`000?oooooooooo00gooooo00?o0000ogmoOomoOgl05?moOgl2o`0000;oOgmo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo001m
ooooo`03o`000?oooooooooo00gooooo00?o0000ogmoOomoOgl05?moOgl2o`0000;oOgmo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo001moooo
o`03o`000?oooooooooo00gooooo00?o0000ogmoOomoOgl05?moOgl2o`0000;oOgmo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo001mooooo`03
o`000?oooooooooo00cooooo00?o0000ogmoOomoOgl05_moOgl01?l0003oOgmoogmoOol00009oooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03_ooool007gooooo00?o0000oooooooo
ool03?ooool00ol0003oOgmoogmoO`0FogmoO`04o`000?moOgooOgmoo`0000Wooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`0>ooooo`00OOooool00ol0003oooooooooo`0;ooooo`03
o`000?moOgooOgmo01OoOgmo00Co0000ogmoOomoOgoo00002Oooool00ol0003oooooooooo`1Joooo
o`03o`000?oooooooooo00kooooo001mooooo`03o`000?oooooooooo00_ooooo00?o0000ogmoOomo
Ogl05omoOgl2o`000003ogmoOol0003ooooo00Sooooo00?o0000ooooooooool0F_ooool00ol0003o
ooooooooo`0>ooooo`00OOoooolfo`0005cooooo00?o0000ooooooooool03_ooool007gooooo00?o
0000ooooooooool02_ooool00ol0003oOgmoogmoO`0HogmoO`?o00002_ooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo00kooooo001mooooo`03o`000?oooooooooo00[ooooo00?o0000
ogmoOomoOgl06?moOgl00ol0003oOgmoo`00000:ooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool03_ooool007gooooo00?o0000ooooooooool02Oooool00ol0003oOgmoogmoO`0Iogmo
O`03o`000?moOgoo000000[ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0>oooo
o`00OOooool00ol0003oooooooooo`09ooooo`03o`000?moOgooOgmo01WoOgmo00?o0000ogmoOol0
00002_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo001mooooo`03o`00
0?oooooooooo00Sooooo00?o0000ogmoOomoOgl06_moOgl01?l0003oOgmoo`000?l00009ooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool03_ooool007gooooo=_l0001Looooo`03o`00
0?oooooooooo00kooooo001mooooo`03o`000?oooooooooo00Kooooo00?o0000ogmoOomoOgl07?mo
Ogl01Ol0003oOgmoo`000?moOgoo000000Sooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`0>ooooo`00OOooool00ol0003oooooooooo`05ooooo`03o`000?moOgooOgmo01goOgmo00?o
0000ogmoOol000000_moOgl00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool03_ooool007gooooo00?o0000ooooooooool01?ooool00ol0003oOgmoogmoO`0N
ogmoO`;o00001?moOgl00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool03_ooool007gooooo00?o0000ooooooooool00oooool00ol0003oOgmoogmoO`0Oogmo
O`;o00001OmoOgl00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05[ooooo00?o0000oooo
ooooool03_ooool007gooooo=_l0001Looooo`03o`000?oooooooooo00kooooo001mooooo`05o`00
0?ooooooooooooooool000008omoOgl2o`0000OoOgmo00Go0000ooooooooooooooooo`00001Loooo
o`03o`000?oooooooooo00kooooo001mooooo`04o`000?ooooooooooo`0002CoOgmo0_l00008ogmo
O`04o`000?ooooooooooo`0005cooooo00?o0000ooooooooool03_ooool007gooooo00?o0000oooo
ool000009OmoOgl00ol0003oOgmoogmoO`08ogmoO`03o`000?oooooo000005cooooo00?o0000oooo
ooooool03_ooool007gooooo=_l0001Looooo`03o`000?oooooooooo00kooooo001mooooocKo0000
G?ooool00ol0003oooooooooo`0>ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.44539 .03036 m
.61181 .03036 L
.58825 .07004 L
.47847 .07004 L
.44539 .03036 L
F
.47847 .07004 m
.58825 .07004 L
.57549 .10972 L
.4949 .10972 L
.47847 .07004 L
F
.4949 .10972 m
.57549 .10972 L
.57143 .1494 L
.5 .1494 L
.4949 .10972 L
F
.5 .1494 m
.57143 .1494 L
.57549 .18909 L
.4949 .18909 L
.5 .1494 L
F
.4949 .18909 m
.57549 .18909 L
.58825 .22877 L
.47847 .22877 L
.4949 .18909 L
F
.47847 .22877 m
.58825 .22877 L
.61181 .26845 L
.44539 .26845 L
.47847 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.44539 .03036 m
.47847 .07004 L
.4949 .10972 L
.5 .1494 L
.4949 .18909 L
.47847 .22877 L
.44539 .26845 L
.61181 .26845 L
.58825 .22877 L
.57549 .18909 L
.57143 .1494 L
.57549 .10972 L
.58825 .07004 L
.61181 .03036 L
.44539 .03036 L
s
.5 g
.44539 .1494 m
.61181 .1494 L
.58825 .1494 L
.47847 .1494 L
.44539 .1494 L
F
.47847 .1494 m
.58825 .1494 L
.57549 .1494 L
.4949 .1494 L
.47847 .1494 L
F
.4949 .1494 m
.57549 .1494 L
.57143 .1494 L
.5 .1494 L
.4949 .1494 L
F
.5 .1494 m
.57143 .1494 L
.57549 .1494 L
.4949 .1494 L
.5 .1494 L
F
.4949 .1494 m
.57549 .1494 L
.58825 .1494 L
.47847 .1494 L
.4949 .1494 L
F
.47847 .1494 m
.58825 .1494 L
.61181 .1494 L
.44539 .1494 L
.47847 .1494 L
F
0 g
.44539 .1494 m
.47847 .1494 L
.4949 .1494 L
.5 .1494 L
.4949 .1494 L
.47847 .1494 L
.44539 .1494 L
.61181 .1494 L
.58825 .1494 L
.57549 .1494 L
.57143 .1494 L
.57549 .1494 L
.58825 .1494 L
.61181 .1494 L
.44539 .1494 L
s
.5 g
.61181 .03036 m
.64343 .07004 L
.58825 .07004 L
.61181 .03036 L
F
.58825 .07004 m
.64343 .07004 L
.60452 .10972 L
.57549 .10972 L
.58825 .07004 L
F
.57549 .10972 m
.60452 .10972 L
.59524 .1494 L
.57143 .1494 L
.57549 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.60452 .18909 L
.57549 .18909 L
.57143 .1494 L
F
.57549 .18909 m
.60452 .18909 L
.64343 .22877 L
.58825 .22877 L
.57549 .18909 L
F
.58825 .22877 m
.64343 .22877 L
.61181 .26845 L
.58825 .22877 L
F
0 g
.61181 .03036 m
.58825 .07004 L
.57549 .10972 L
.57143 .1494 L
.57549 .18909 L
.58825 .22877 L
.61181 .26845 L
s
.64343 .22877 m
.60452 .18909 L
.59524 .1494 L
.60452 .10972 L
.64343 .07004 L
s
.61181 .03036 m
0 0 rlineto s
.5 g
.61181 .1494 m
.64343 .1494 L
.58825 .1494 L
.61181 .1494 L
F
.58825 .1494 m
.64343 .1494 L
.60452 .1494 L
.57549 .1494 L
.58825 .1494 L
F
.57549 .1494 m
.60452 .1494 L
.59524 .1494 L
.57143 .1494 L
.57549 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.60452 .1494 L
.57549 .1494 L
.57143 .1494 L
F
.57549 .1494 m
.60452 .1494 L
.64343 .1494 L
.58825 .1494 L
.57549 .1494 L
F
.58825 .1494 m
.64343 .1494 L
.61181 .1494 L
.58825 .1494 L
F
0 g
.61181 .1494 m
.58825 .1494 L
.57549 .1494 L
.57143 .1494 L
.57549 .1494 L
.58825 .1494 L
.61181 .1494 L
s
.64343 .1494 m
.60452 .1494 L
.59524 .1494 L
.60452 .1494 L
.64343 .1494 L
s
.61181 .1494 m
0 0 rlineto s
.44539 .26845 m
.61181 .26845 L
.61181 .2644 L
.44539 .2644 L
.44539 .26845 L
s
.44539 .2644 m
.61181 .2644 L
.61181 .2525 L
.44539 .2525 L
.44539 .2644 L
s
.44539 .2525 m
.61181 .2525 L
.61181 .23358 L
.44539 .23358 L
.44539 .2525 L
s
.44539 .23358 m
.61181 .23358 L
.61181 .20893 L
.44539 .20893 L
.44539 .23358 L
s
.44539 .20893 m
.61181 .20893 L
.61181 .18022 L
.44539 .18022 L
.44539 .20893 L
s
.44539 .18022 m
.61181 .18022 L
.61181 .1494 L
.44539 .1494 L
.44539 .18022 L
s
.44539 .1494 m
.61181 .1494 L
.61181 .11859 L
.44539 .11859 L
.44539 .1494 L
s
.44539 .11859 m
.61181 .11859 L
.61181 .08988 L
.44539 .08988 L
.44539 .11859 L
s
.44539 .08988 m
.61181 .08988 L
.61181 .06523 L
.44539 .06523 L
.44539 .08988 L
s
.44539 .06523 m
.61181 .06523 L
.61181 .04631 L
.44539 .04631 L
.44539 .06523 L
s
.44539 .04631 m
.61181 .04631 L
.61181 .03441 L
.44539 .03441 L
.44539 .04631 L
s
.44539 .03441 m
.61181 .03441 L
.61181 .03036 L
.44539 .03036 L
.44539 .03441 L
s
.44539 .03036 m
.61181 .03036 L
.61181 .03441 L
.44539 .03441 L
.44539 .03036 L
s
.44539 .03441 m
.61181 .03441 L
.61181 .04631 L
.44539 .04631 L
.44539 .03441 L
s
.44539 .04631 m
.61181 .04631 L
.61181 .06523 L
.44539 .06523 L
.44539 .04631 L
s
.44539 .06523 m
.61181 .06523 L
.61181 .08988 L
.44539 .08988 L
.44539 .06523 L
s
.44539 .08988 m
.61181 .08988 L
.61181 .11859 L
.44539 .11859 L
.44539 .08988 L
s
.44539 .11859 m
.61181 .11859 L
.61181 .1494 L
.44539 .1494 L
.44539 .11859 L
s
.44539 .1494 m
.61181 .1494 L
.61181 .18022 L
.44539 .18022 L
.44539 .1494 L
s
.44539 .18022 m
.61181 .18022 L
.61181 .20893 L
.44539 .20893 L
.44539 .18022 L
s
.44539 .20893 m
.61181 .20893 L
.61181 .23358 L
.44539 .23358 L
.44539 .20893 L
s
.44539 .23358 m
.61181 .23358 L
.61181 .2525 L
.44539 .2525 L
.44539 .23358 L
s
.44539 .2525 m
.61181 .2525 L
.61181 .2644 L
.44539 .2644 L
.44539 .2525 L
s
.44539 .2644 m
.61181 .2644 L
.61181 .26845 L
.44539 .26845 L
.44539 .2644 L
s
.61181 .26845 m
0 0 rlineto s
.61181 .2644 m
.61181 .26845 L
s
.61181 .2644 m
0 0 rlineto s
.61181 .2525 m
.61181 .2644 L
s
.61181 .2525 m
0 0 rlineto s
.61181 .23358 m
.61181 .2525 L
s
.61181 .23358 m
0 0 rlineto s
.61181 .20893 m
.61181 .23358 L
s
.61181 .20893 m
0 0 rlineto s
.61181 .18022 m
.61181 .20893 L
s
.61181 .18022 m
0 0 rlineto s
.61181 .1494 m
.61181 .18022 L
s
.61181 .1494 m
0 0 rlineto s
.61181 .11859 m
.61181 .1494 L
s
.61181 .11859 m
0 0 rlineto s
.61181 .08988 m
.61181 .11859 L
s
.61181 .08988 m
0 0 rlineto s
.61181 .06523 m
.61181 .08988 L
s
.61181 .06523 m
0 0 rlineto s
.61181 .04631 m
.61181 .06523 L
s
.61181 .04631 m
0 0 rlineto s
.61181 .03441 m
.61181 .04631 L
s
.61181 .03441 m
0 0 rlineto s
.61181 .03036 m
.61181 .03441 L
s
.61181 .03036 m
0 0 rlineto s
.61181 .03441 m
.61181 .03036 L
s
.61181 .03441 m
0 0 rlineto s
.61181 .04631 m
.61181 .03441 L
s
.61181 .04631 m
0 0 rlineto s
.61181 .06523 m
.61181 .04631 L
s
.61181 .06523 m
0 0 rlineto s
.61181 .08988 m
.61181 .06523 L
s
.61181 .08988 m
0 0 rlineto s
.61181 .11859 m
.61181 .08988 L
s
.61181 .11859 m
0 0 rlineto s
.61181 .1494 m
.61181 .11859 L
s
.61181 .1494 m
0 0 rlineto s
.61181 .18022 m
.61181 .1494 L
s
.61181 .18022 m
0 0 rlineto s
.61181 .20893 m
.61181 .18022 L
s
.61181 .20893 m
0 0 rlineto s
.61181 .23358 m
.61181 .20893 L
s
.61181 .23358 m
0 0 rlineto s
.61181 .2525 m
.61181 .23358 L
s
.61181 .2525 m
0 0 rlineto s
.61181 .2644 m
.61181 .2525 L
s
.61181 .2644 m
0 0 rlineto s
.61181 .26845 m
.61181 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49818 .1256 L
s
0 0 0 r
2 Mabswid
.49818 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49935 .13512 L
s
0 0 0 r
2 Mabswid
.49935 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49993 .14464 L
s
0 0 0 r
2 Mabswid
.49993 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49993 .15417 L
s
0 0 0 r
2 Mabswid
.49993 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49935 .16369 L
s
0 0 0 r
2 Mabswid
.49935 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49818 .17321 L
s
0 0 0 r
2 Mabswid
.49818 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49818 .1256 m
.57339 .12176 L
s
0 0 0 r
2 Mabswid
.57339 .12176 Mdot
.039 .916 .04 r
.5 Mabswid
.49935 .13512 m
.57213 .13291 L
s
0 0 0 r
2 Mabswid
.57213 .13291 Mdot
.039 .916 .04 r
.5 Mabswid
.49993 .14464 m
.57151 .14392 L
s
0 0 0 r
2 Mabswid
.57151 .14392 Mdot
.039 .916 .04 r
.5 Mabswid
.49993 .15417 m
.57151 .15489 L
s
0 0 0 r
2 Mabswid
.57151 .15489 Mdot
.039 .916 .04 r
.5 Mabswid
.49935 .16369 m
.57213 .1659 L
s
0 0 0 r
2 Mabswid
.57213 .1659 Mdot
.039 .916 .04 r
.5 Mabswid
.49818 .17321 m
.57339 .17705 L
s
0 0 0 r
2 Mabswid
.57339 .17705 Mdot
.039 .916 .04 r
.5 Mabswid
.57339 .12176 m
.59978 .12127 L
s
0 0 0 r
2 Mabswid
.59978 .12127 Mdot
.039 .916 .04 r
.5 Mabswid
.57213 .13291 m
.59683 .13263 L
s
0 0 0 r
2 Mabswid
.59683 .13263 Mdot
.039 .916 .04 r
.5 Mabswid
.57151 .14392 m
.59541 .14383 L
s
0 0 0 r
2 Mabswid
.59541 .14383 Mdot
.039 .916 .04 r
.5 Mabswid
.57151 .15489 m
.59541 .15498 L
s
0 0 0 r
2 Mabswid
.59541 .15498 Mdot
.039 .916 .04 r
.5 Mabswid
.57213 .1659 m
.59683 .16618 L
s
0 0 0 r
2 Mabswid
.59683 .16618 Mdot
.039 .916 .04 r
.5 Mabswid
.57339 .17705 m
.59978 .17754 L
s
0 0 0 r
2 Mabswid
.59978 .17754 Mdot
.039 .916 .04 r
.5 Mabswid
.59683 .13263 m
.97619 .0649 L
s
0 0 0 r
2 Mabswid
.97619 .0649 Mdot
.039 .916 .04 r
.5 Mabswid
.59541 .14383 m
.97619 .12218 L
s
0 0 0 r
2 Mabswid
.97619 .12218 Mdot
.039 .916 .04 r
.5 Mabswid
.59541 .15498 m
.97619 .17663 L
s
0 0 0 r
2 Mabswid
.97619 .17663 Mdot
.039 .916 .04 r
.5 Mabswid
.59683 .16618 m
.97619 .2339 L
s
0 0 0 r
2 Mabswid
.97619 .2339 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo002]ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03_ooool0
083ooooo;_l0001Qooooo`03o`000?oooooooooo00kooooo0020ooooobko0000HOooool00ol0003o
ooooooooo`0>ooooo`00P?ooool2o`0002[oOgmo0_l0001Qooooo`03o`000?oooooooooo00kooooo
0020ooooo`03o`000?oooooo000002SoOgmo00Co0000ogmoOol0003oOgmoH?ooool00ol0003ooooo
ooooo`0>ooooo`00P?ooool^o`0000;oOgmoGoooool00ol0003oooooooooo`0>ooooo`00P?ooool0
1Ol0003ooooooooooooooooo000002GoOgmo00Co0000ogmoOomoOgoo00000omoOgmNooooo`03o`00
0?oooooooooo00kooooo0020ooooo`03o`000?oooooooooo00;ooooo00?o0000ogmoOomoOgl08_mo
Ogl01?l0003oOgmoogmoOol00004ogmoOegooooo00?o0000ooooooooool03_ooool0083ooooo00?o
0000ooooooooool00oooool00ol0003oOgmoogmoO`0PogmoO`05o`000?moOgooOgmoogmoOol00000
1OmoOgmLooooo`03o`000?oooooooooo00kooooo0020ooooo`03o`000?oooooooooo00Cooooo00?o
0000ogmoOomoOgl07_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00CoOgmoFooo
ool00ol0003oooooooooo`0>ooooo`00P?ooool^o`0000OoOgmoEoooool3o`WZ2P;o00003oooool0
083ooooo00?o0000ooooooooool01_ooool00ol0003oOgmoogmoO`0KogmoO`03o`000?moOgooOgmo
00?oOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`1=ooooo`Ko2NX:0oooool2o`00
00oooooo0020ooooo`03o`000?oooooooooo00Kooooo00?o0000ogmoOomoOgl06omoOgl00ol0003o
OgmoogmoO`03ogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000ooooooooool0BOooool5o`WZ2PWo
oooo00?o0000ooooooooool03_ooool0083ooooo00?o0000ooooooooool01oooool00ol0003oOgmo
ogmoO`0IogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003ooooo
ooooo`14ooooo`Ko2NX:3_ooool00ol0003oooooooooo`0>ooooo`00P?ooool00ol0003ooooooooo
o`07ooooo`03o`000?moOgooOgmo01WoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmo
O`03ogmoO`03o`000?oooooooooo03oooooo1_l9jPXDooooo`03o`000?oooooooooo00kooooo0020
ooooo`03o`000?oooooooooo00Sooooo00?o0000ogmoOomoOgl06?moOgl00ol0003oOgmoogmoO`04
ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0>oooool5o`WZ2Q[ooooo00?o0000
ooooooooool03_ooool0083ooooo00?o0000ooooooooool02?ooool00ol0003oOgmoogmoO`0Gogmo
O`03o`000?moOgooOgmo00GoOgmo00Go0000ogmoOomoOgooOgmoo`00000hooooo`Ko2NX:7oooool0
0ol0003oooooooooo`0>ooooo`00P?ooool^o`0000;oOgmo00?o0000ooooooooool0<Oooool6o`WZ
2RGooooo00?o0000ooooooooool03_ooool0083ooooo00?o0000ooooooooool02Oooool00ol0003o
OgmoogmoO`0FogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOol00000;oooool5o`WZ2R_o
oooo00?o0000ooooooooool03_ooool0083ooooo00?o0000ooooooooool02Oooool00ol0003oOgmo
ogmoO`0EogmoO`03o`000?moOgooOgmo00KoOgmo0_l0000Zooooo`Ko2NX:<?ooool00ol0003ooooo
ooooo`0>ooooo`00P?ooool00ol0003oooooooooo`0:ooooo`03o`000?moOgooOgmo01CoOgmo00?o
0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`0Sooooo`Ko2NX:=_ooool00ol0003ooooooooo
o`0>ooooo`00P?ooool00ol0003oooooooooo`0:ooooo`03o`000?moOgooOgmo01CoOgmo00?o0000
ogmoOomoOgl01OmoOgl2o`00023ooooo1Ol9jPXlooooo`03o`000?oooooooooo00kooooo0020oooo
o`03o`000?oooooooooo00_ooooo00?o0000ogmoOomoOgl04_moOgl00ol0003oOgmoogmoO`05ogmo
O`03o`000?oooooo000001[ooooo1_l9jPY1ooooo`03o`000?oooooooooo00kooooo0020ooooo`03
o`000?oooooooooo00_ooooo00?o0000ogmoOomoOgl04_moOgl00ol0003oOgmoogmoO`05ogmoO`03
o`000?oooooo000001Cooooo1_l9jPY7ooooo`03o`000?oooooooooo00kooooo0020ooooobko0000
3oooool5o`WZ2Tgooooo00?o0000ooooooooool03_ooool0083ooooo00?o0000ooooooooool02ooo
ool00ol0003oOgmoogmoO`08ogmoO`Wo2NX:00?o0000o`WZ2_l9jPX01?l9jPX3o`000003ooooool0
003ooooo00Sooooo1_l9jPY:ooooo`So2NX:0_l0000?ooooo`003ooooomoo`WZ2P03o`000?l9jP[o
2NX:00So2NX:2OmoOgl2o`0000GoOgmo0_l00002ooooo`04o`000?ooooooooooooooo`Ko2NX:?ooo
oolAo`WZ2PSooooo0_l0000?ooooo`00P?ooool00ol0003oooooooooo`0;ooooo`;o00004omoOgl0
0ol0003oOgmoogmoO`04ogmoO`03o`000?oooooo2NX:00Co2NX:=?oooolAo`WZ2QWooooo00?o0000
ooooooooool03_ooool0083ooooo00?o0000ooooooooool02oooool2o`0000WoOgmo4ol9jPX00ooo
oooo0000ooooo`0Uoooooa7o2NX::_ooool00ol0003oooooooooo`0>ooooo`003ooooomoo`WZ2P03
o`000?l9jP[o2NX:00So2NX:2OmoOgl2o`0000GoOgmo0_l00002ooooo`03o`000?oooooooooo01?o
oooo4Ol9jPXkooooo`03o`000?oooooooooo00kooooo0020ooooo`03o`000?oooooooooo00cooooo
00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`05ogmoO`04o`000?ooooooooooo`0000Co
oooo4Ol9jPY<ooooo`03o`000?oooooooooo00kooooo000?ooooogoo2NX:00?o0000o`WZ2_l9jPX0
5ol9jPX00ol0003o2NX:o`WZ2P07o`WZ2Ugooooo00?o0000ooooooooool03_ooool0083ooooo00?o
0000ooooooooool02oooool2o`0001;oOgmo0_l00004ogmoO`;o00000oooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo00kooooo0020ooooocOo0000F?ooool00ol0003oooooooooo`0>
ooooo`003ooooomoo`WZ2P03o`000?l9jP[o2NX:01Oo2NX:00?o0000o`WZ2_l9jPX02?l9jPYLoooo
o`03o`000?oooooooooo00kooooo0020ooooo`03o`000?oooooooooo00_ooooo0_l0000BogmoO`;o
00001?moOgl2o`0000?ooooo00?o0000ooooooooool00ooooolAo`WZ2T_ooooo00?o0000oooooooo
ool03_ooool0083ooooo00?o0000ooooooooool02oooool2o`0001;oOgmo00?o0000ogmoOomoOgl0
1OmoOgl01?l0003oooooooooool0000Foooooa7o2NX:>_ooool00ol0003oooooooooo`0>ooooo`00
3ooooomoo`WZ2P03o`000?l9jP[o2NX:01co2NX:00?o0000ooooooooool09OoooolAo`WZ2RWooooo
00?o0000ooooooooool03_ooool0083ooooo00?o0000ooooooooool03?ooool00ol0003oOgmoogmo
O`0@ogmoO`;o00001OmoOgl2o`0000;ooooo1_l9jPXcoooooa7o2NX:6?ooool00ol0003ooooooooo
o`0>ooooo`003ooooomoo`WZ2P03o`000?l9jP[o2NX:00Wo2NX:2OmoOgl00ol0003oOgmoogmoO`04
ogmoO`04o`000?ooooooooooo`0000Gooooo1Ol9jPXooooooa7o2NX:1oooool00ol0003ooooooooo
o`0>ooooo`00P?ooool00ol0003oooooooooo`0;ooooo`;o00002_moOgl8o`WZ2P03o`000?l9jP[o
2NX:00Co2NX:0_l00002ooooo`03o`000?oooooooooo00Sooooo1_l9jPY:ooooo`Oo2NX:0_l0000?
ooooo`00P?ooool^o`00013ooooo1_l9jPY;ooooo`;o00003oooool0083ooooo00?o0000oooooooo
ool02oooool00ol0003oOgmoogmoO`0BogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000ooooool0
00005_ooool5o`WZ2TKooooo00?o0000ooooooooool03_ooool0083ooooo00?o0000ooooooooool0
2oooool00ol0003oOgmoogmoO`0BogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000ooooool00000
6oooool6o`WZ2T3ooooo00?o0000ooooooooool03_ooool0083ooooo00?o0000ooooooooool02ooo
ool00ol0003oOgmoogmoO`0BogmoO`03o`000?moOgooOgmo00KoOgmo0_l0000Qooooo`Ko2NX:>_oo
ool00ol0003oooooooooo`0>ooooo`00P?ooool00ol0003oooooooooo`0:ooooo`03o`000?moOgoo
Ogmo01CoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`0Uooooo`Go2NX:=Oooool0
0ol0003oooooooooo`0>ooooo`00P?ooool00ol0003oooooooooo`0:ooooo`03o`000?moOgooOgmo
01CoOgmo00?o0000ogmoOomoOgl01_moOgl2o`0002_ooooo1_l9jPX_ooooo`03o`000?oooooooooo
00kooooo0020ooooo`03o`000?oooooooooo00Wooooo00?o0000ogmoOomoOgl05OmoOgl00ol0003o
OgmoogmoO`06ogmoO`03o`000?moOgoo0000033ooooo1_l9jPXYooooo`03o`000?oooooooooo00ko
oooo0020ooooo`03o`000?oooooooooo00Wooooo00?o0000ogmoOomoOgl05_moOgl00ol0003oOgmo
ogmoO`05ogmoO`04o`000?moOgooOgmoo`0003Gooooo1Ol9jPXTooooo`03o`000?oooooooooo00ko
oooo0020ooooobko00000omoOgl00ol0003oooooooooo`0gooooo`Ko2NX:7_ooool00ol0003ooooo
ooooo`0>ooooo`00P?ooool00ol0003oooooooooo`08ooooo`03o`000?moOgooOgmo01OoOgmo00?o
0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo03cooooo1_l9
jPXHooooo`03o`000?oooooooooo00kooooo0020ooooo`03o`000?oooooooooo00Sooooo00?o0000
ogmoOomoOgl06?moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000
ooooooooool0@Oooool5o`WZ2Q?ooooo00?o0000ooooooooool03_ooool0083ooooo00?o0000oooo
ooooool01oooool00ol0003oOgmoogmoO`0IogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ogmo
OomoOgl01?moOgl00ol0003oooooooooo`15ooooo`Ko2NX:3Oooool00ol0003oooooooooo`0>oooo
o`00P?ooool00ol0003oooooooooo`07ooooo`03o`000?moOgooOgmo01WoOgmo00?o0000ogmoOomo
Ogl01?moOgl00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo04[ooooo1_l9jPX7ooooo`03
o`000?oooooooooo00kooooo0020ooooo`03o`000?oooooooooo00Kooooo00?o0000ogmoOomoOgl0
6omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0
Coooool5o`WZ2P;ooooo00?o0000ooooooooool03_ooool0083ooooo;_l00008ogmoOeOooooo0_l9
jPX2o`0000oooooo0020ooooo`03o`000?oooooooooo00Gooooo00?o0000ogmoOomoOgl07OmoOgl0
0ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00KoOgmoFOooool2o`0000oooooo0020oooo
o`03o`000?oooooooooo00Cooooo00?o0000ogmoOomoOgl07_moOgl00ol0003oOgmoogmoO`02ogmo
O`03o`000?moOgooOgmo00GoOgmoF_ooool00ol0003oooooooooo`0>ooooo`00P?ooool00ol0003o
ooooooooo`03ooooo`03o`000?moOgooOgmo023oOgmo00Go0000ogmoOomoOgooOgmoo`000006ogmo
Oe_ooooo00?o0000ooooooooool03_ooool0083ooooo00?o0000ooooooooool00_ooool00ol0003o
OgmoogmoO`0QogmoO`05o`000?moOgooOgmoogmoOol000001OmoOgmLooooo`03o`000?oooooooooo
00kooooo0020ooooobko00001?moOgmMooooo`03o`000?oooooooooo00kooooo0020ooooo`05o`00
0?ooooooooooooooool000009_moOgl00ol0003oOgmoo`000003ogmoOekooooo00?o0000oooooooo
ool03_ooool0083ooooo00Co0000oooooooooooo00009omoOgl00ol0003oOgmoo`000003ogmoOeko
oooo00?o0000ooooooooool03_ooool0083ooooo00?o0000ooooool00000:OmoOgl2o`0000;oOgmo
Goooool00ol0003oooooooooo`0>ooooo`00P?ooool^o`000003ogmoOooooooooooo05kooooo00?o
0000ooooooooool03_ooool0083ooooo;_l0001Qooooo`03o`000?oooooooooo00kooooo003ooooo
ob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.44632 .03036 m
.61409 .07004 L
.47875 .07004 L
.44632 .03036 L
F
.47875 .07004 m
.61409 .07004 L
.5801 .10972 L
.49496 .10972 L
.47875 .07004 L
F
.49496 .10972 m
.5801 .10972 L
.57143 .1494 L
.5 .1494 L
.49496 .10972 L
F
.5 .1494 m
.57143 .1494 L
.5801 .18909 L
.49496 .18909 L
.5 .1494 L
F
.49496 .18909 m
.5801 .18909 L
.61409 .22877 L
.47875 .22877 L
.49496 .18909 L
F
.47875 .22877 m
.61409 .22877 L
.44632 .26845 L
.47875 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.44632 .03036 m
.47875 .07004 L
.49496 .10972 L
.5 .1494 L
.49496 .18909 L
.47875 .22877 L
.44632 .26845 L
s
.61409 .22877 m
.5801 .18909 L
.57143 .1494 L
.5801 .10972 L
.61409 .07004 L
s
.44632 .03036 m
0 0 rlineto s
.5 g
.44632 .1494 m
.61409 .1494 L
.47875 .1494 L
.44632 .1494 L
F
.47875 .1494 m
.61409 .1494 L
.5801 .1494 L
.49496 .1494 L
.47875 .1494 L
F
.49496 .1494 m
.5801 .1494 L
.57143 .1494 L
.5 .1494 L
.49496 .1494 L
F
.5 .1494 m
.57143 .1494 L
.5801 .1494 L
.49496 .1494 L
.5 .1494 L
F
.49496 .1494 m
.5801 .1494 L
.61409 .1494 L
.47875 .1494 L
.49496 .1494 L
F
.47875 .1494 m
.61409 .1494 L
.44632 .1494 L
.47875 .1494 L
F
0 g
.44632 .1494 m
.47875 .1494 L
.49496 .1494 L
.5 .1494 L
.49496 .1494 L
.47875 .1494 L
.44632 .1494 L
s
.61409 .1494 m
.5801 .1494 L
.57143 .1494 L
.5801 .1494 L
.61409 .1494 L
s
.44632 .1494 m
0 0 rlineto s
.5 g
.57123 .03036 m
.58481 .07004 L
.61409 .07004 L
F
.61409 .07004 m
.58481 .07004 L
.59266 .10972 L
.5801 .10972 L
.61409 .07004 L
F
.5801 .10972 m
.59266 .10972 L
.59524 .1494 L
.57143 .1494 L
.5801 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59266 .18909 L
.5801 .18909 L
.57143 .1494 L
F
.5801 .18909 m
.59266 .18909 L
.58481 .22877 L
.61409 .22877 L
.5801 .18909 L
F
.61409 .22877 m
.58481 .22877 L
.57123 .26845 L
.61409 .22877 L
F
0 g
.61409 .07004 m
.5801 .10972 L
.57143 .1494 L
.5801 .18909 L
.61409 .22877 L
s
.57123 .26845 m
.58481 .22877 L
.59266 .18909 L
.59524 .1494 L
.59266 .10972 L
.58481 .07004 L
.57123 .03036 L
s
.5 g
.57123 .1494 m
.58481 .1494 L
.61409 .1494 L
F
.61409 .1494 m
.58481 .1494 L
.59266 .1494 L
.5801 .1494 L
.61409 .1494 L
F
.5801 .1494 m
.59266 .1494 L
.59524 .1494 L
.57143 .1494 L
.5801 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59266 .1494 L
.5801 .1494 L
.57143 .1494 L
F
.5801 .1494 m
.59266 .1494 L
.58481 .1494 L
.61409 .1494 L
.5801 .1494 L
F
.61409 .1494 m
.58481 .1494 L
.57123 .1494 L
.61409 .1494 L
F
0 g
.61409 .1494 m
.5801 .1494 L
.57143 .1494 L
.5801 .1494 L
.61409 .1494 L
s
.57123 .1494 m
.58481 .1494 L
.59266 .1494 L
.59524 .1494 L
.59266 .1494 L
.58481 .1494 L
.57123 .1494 L
s
.44632 .26845 m
0 0 rlineto s
.44632 .2644 m
.44632 .26845 L
s
.44632 .2644 m
0 0 rlineto s
.44632 .2525 m
.44632 .2644 L
s
.44632 .2525 m
0 0 rlineto s
.44632 .23358 m
.44632 .2525 L
s
.44632 .23358 m
0 0 rlineto s
.44632 .20893 m
.44632 .23358 L
s
.44632 .20893 m
0 0 rlineto s
.44632 .18022 m
.44632 .20893 L
s
.44632 .18022 m
0 0 rlineto s
.44632 .1494 m
.44632 .18022 L
s
.44632 .1494 m
0 0 rlineto s
.44632 .11859 m
.44632 .1494 L
s
.44632 .11859 m
0 0 rlineto s
.44632 .08988 m
.44632 .11859 L
s
.44632 .08988 m
0 0 rlineto s
.44632 .06523 m
.44632 .08988 L
s
.44632 .06523 m
0 0 rlineto s
.44632 .04631 m
.44632 .06523 L
s
.44632 .04631 m
0 0 rlineto s
.44632 .03441 m
.44632 .04631 L
s
.44632 .03441 m
0 0 rlineto s
.44632 .03036 m
.44632 .03441 L
s
.44632 .03036 m
0 0 rlineto s
.44632 .03441 m
.44632 .03036 L
s
.44632 .03441 m
0 0 rlineto s
.44632 .04631 m
.44632 .03441 L
s
.44632 .04631 m
0 0 rlineto s
.44632 .06523 m
.44632 .04631 L
s
.44632 .06523 m
0 0 rlineto s
.44632 .08988 m
.44632 .06523 L
s
.44632 .08988 m
0 0 rlineto s
.44632 .11859 m
.44632 .08988 L
s
.44632 .11859 m
0 0 rlineto s
.44632 .1494 m
.44632 .11859 L
s
.44632 .1494 m
0 0 rlineto s
.44632 .18022 m
.44632 .1494 L
s
.44632 .18022 m
0 0 rlineto s
.44632 .20893 m
.44632 .18022 L
s
.44632 .20893 m
0 0 rlineto s
.44632 .23358 m
.44632 .20893 L
s
.44632 .23358 m
0 0 rlineto s
.44632 .2525 m
.44632 .23358 L
s
.44632 .2525 m
0 0 rlineto s
.44632 .2644 m
.44632 .2525 L
s
.44632 .2644 m
0 0 rlineto s
.44632 .26845 m
.44632 .2644 L
s
.57123 .26845 m
.57123 .2644 L
s
.57123 .2644 m
.57123 .2525 L
s
.57123 .2525 m
.57123 .23358 L
s
.57123 .23358 m
.57123 .20893 L
s
.57123 .20893 m
.57123 .18022 L
s
.57123 .18022 m
.57123 .1494 L
s
.57123 .1494 m
.57123 .11859 L
s
.57123 .11859 m
.57123 .08988 L
s
.57123 .08988 m
.57123 .06523 L
s
.57123 .06523 m
.57123 .04631 L
s
.57123 .04631 m
.57123 .03441 L
s
.57123 .03441 m
.57123 .03036 L
s
.57123 .03036 m
.57123 .03441 L
s
.57123 .03441 m
.57123 .04631 L
s
.57123 .04631 m
.57123 .06523 L
s
.57123 .06523 m
.57123 .08988 L
s
.57123 .08988 m
.57123 .11859 L
s
.57123 .11859 m
.57123 .1494 L
s
.57123 .1494 m
.57123 .18022 L
s
.57123 .18022 m
.57123 .20893 L
s
.57123 .20893 m
.57123 .23358 L
s
.57123 .23358 m
.57123 .2525 L
s
.57123 .2525 m
.57123 .2644 L
s
.57123 .2644 m
.57123 .26845 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49821 .1256 L
s
0 0 0 r
2 Mabswid
.49821 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49936 .13512 L
s
0 0 0 r
2 Mabswid
.49936 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49993 .14464 L
s
0 0 0 r
2 Mabswid
.49993 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49993 .15417 L
s
0 0 0 r
2 Mabswid
.49993 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49936 .16369 L
s
0 0 0 r
2 Mabswid
.49936 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49821 .17321 L
s
0 0 0 r
2 Mabswid
.49821 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49821 .1256 m
.57555 .1217 L
s
0 0 0 r
2 Mabswid
.57555 .1217 Mdot
.039 .916 .04 r
.5 Mabswid
.49936 .13512 m
.57287 .13291 L
s
0 0 0 r
2 Mabswid
.57287 .13291 Mdot
.039 .916 .04 r
.5 Mabswid
.49993 .14464 m
.57159 .14393 L
s
0 0 0 r
2 Mabswid
.57159 .14393 Mdot
.039 .916 .04 r
.5 Mabswid
.49993 .15417 m
.57159 .15488 L
s
0 0 0 r
2 Mabswid
.57159 .15488 Mdot
.039 .916 .04 r
.5 Mabswid
.49936 .16369 m
.57287 .1659 L
s
0 0 0 r
2 Mabswid
.57287 .1659 Mdot
.039 .916 .04 r
.5 Mabswid
.49821 .17321 m
.57555 .17711 L
s
0 0 0 r
2 Mabswid
.57555 .17711 Mdot
.039 .916 .04 r
.5 Mabswid
.57555 .1217 m
.594 .12187 L
s
0 0 0 r
2 Mabswid
.594 .12187 Mdot
.039 .916 .04 r
.5 Mabswid
.57287 .13291 m
.5948 .13301 L
s
0 0 0 r
2 Mabswid
.5948 .13301 Mdot
.039 .916 .04 r
.5 Mabswid
.57159 .14393 m
.59519 .14396 L
s
0 0 0 r
2 Mabswid
.59519 .14396 Mdot
.039 .916 .04 r
.5 Mabswid
.57159 .15488 m
.59519 .15485 L
s
0 0 0 r
2 Mabswid
.59519 .15485 Mdot
.039 .916 .04 r
.5 Mabswid
.57287 .1659 m
.5948 .1658 L
s
0 0 0 r
2 Mabswid
.5948 .1658 Mdot
.039 .916 .04 r
.5 Mabswid
.57555 .17711 m
.594 .17694 L
s
0 0 0 r
2 Mabswid
.594 .17694 Mdot
.039 .916 .04 r
.5 Mabswid
.594 .12187 m
.97619 .15591 L
s
0 0 0 r
2 Mabswid
.97619 .15591 Mdot
.039 .916 .04 r
.5 Mabswid
.5948 .13301 m
.97619 .15236 L
s
0 0 0 r
2 Mabswid
.97619 .15236 Mdot
.039 .916 .04 r
.5 Mabswid
.59519 .14396 m
.97619 .15025 L
s
0 0 0 r
2 Mabswid
.97619 .15025 Mdot
.039 .916 .04 r
.5 Mabswid
.59519 .15485 m
.97619 .14856 L
s
0 0 0 r
2 Mabswid
.97619 .14856 Mdot
.039 .916 .04 r
.5 Mabswid
.5948 .1658 m
.97619 .14645 L
s
0 0 0 r
2 Mabswid
.97619 .14645 Mdot
.039 .916 .04 r
.5 Mabswid
.594 .17694 m
.97619 .1429 L
s
0 0 0 r
2 Mabswid
.97619 .1429 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo0021ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool03_ooool0
087ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
00kooooo0021ooooo`03o`000?moOgooOgmo01kooooo00?o0000ogmoOoooool0J_ooool00ol0003o
ooooooooo`0>ooooo`00POooool2o`0000KoOgmo6Oooool2o`000003ogmoOooooooooooo06Sooooo
00?o0000ooooooooool03_ooool0087ooooo00?o0000ooooool000002OmoOglEooooo`;o00000_mo
OgmYooooo`03o`000?oooooooooo00kooooo0021ooooo`04o`000?ooooooooooo`0000goOgmo4?oo
ool2o`0000?oOgmoJ?ooool00ol0003oooooooooo`0>ooooo`00POooool01Ol0003ooooooooooooo
oooo0000013oOgmo3?ooool00ol0003oooooo`000003ogmoOfOooooo00?o0000ooooooooool03_oo
ool0087ooooo00Go0000ooooooooooooooooo`00000EogmoO`Oooooo00?o0000ooooool000001Omo
OgmUooooo`03o`000?oooooooooo00kooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000
ogmoOomoOgl05_moOgl3ooooo`04o`000?ooooooooooo`0000GoOgmoI?ooool00ol0003ooooooooo
o`0>ooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?moOgooOgmo01SoOgmo00Co0000
ogmoOooooooo00001_moOgmSooooo`03o`000?oooooooooo00kooooo0021ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ogmoOomoOgl05omoOgl01?l0003oOgmoogmoOol00007ogmoOf;ooooo00?o
0000ooooooooool03_ooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oOgmoogmoO`0F
ogmoO`05o`000?moOgooOgmoogmoOol000001omoOgl00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo00kooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ogmoOomoOgl05_moOgl0
1Ol0003oOgmoogmoOomoOgoo000000OoOgmo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`0>ooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?moOgooOgmo01GoOgmo00Go0000
ogmoOomoOgooOgmoo`000006ogmoO`03o`000?oooooooooo05oooooo00?o0000ooooooooool03_oo
ool0087ooooo00?o0000ooooooooool01_ooool00ol0003oOgmoogmoO`0EogmoO`05o`000?moOgoo
OgmoogmoOol000001OmoOgl00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00kooooo0021
ooooo`03o`000?oooooooooo00Oooooo00?o0000ogmoOomoOgl05?moOgl00ol0003oOgmoogmoO`02
ogmoO`05o`000?moOgooOgmoogmoOol00000Hoooool00ol0003oooooooooo`0>ooooo`00POooool0
0ol0003oooooooooo`07ooooo`03o`000?moOgooOgmo01CoOgmo00?o0000ogmoOomoOgl00_moOgl0
1?l0003oOgmoogmoOol0001Tooooo`03o`000?oooooooooo00kooooo0021ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgoo
000006Gooooo00?o0000ooooooooool03_ooool0087ooooo00?o0000ooooooooool02?ooool00ol0
003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOol00000IOooool00ol0
003oooooooooo`0>ooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?moOgooOgmo01?o
Ogmo00?o0000ogmoOomoOgl00_moOgl2o`0006Kooooo00?o0000ooooooooool03_ooool0087ooooo
00?o0000ooooooooool02Oooool00ol0003oOgmoogmoO`0BogmoO`03o`000?moOgooOgmo00;oOgmo
0_l0001Vooooo`03o`000?oooooooooo00kooooo0021ooooo`03o`000?oooooooooo00Wooooo00?o
0000ogmoOomoOgl04_moOgl01ol0003oOgmoogmoOomoOgoo0000ogmoOol00000I_ooool00ol0003o
ooooooooo`0>ooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?moOgooOgmo017oOgmo
00Co0000ogmoOomoOgoo00000_moOgl00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00ko
oooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000ogmoOomoOgl04OmoOgl01?l0003oOgmo
ogmoOol00002ogmoO`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03_ooool0087ooooo
00?o0000ooooooooool02_ooool00ol0003oOgmoogmoO`0AogmoO`04o`000?moOgooOgmoo`0000;o
Ogmo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0>ooooo`00POooool00ol0003ooooo
ooooo`0:ooooo`03o`000?moOgooOgmo00SoOgmo5_l9jPYPooooo`03o`000?oooooooooo00kooooo
000?ooooogoo2NX:00?o0000o`WZ2_l9jPX02?l9jPX9ogmoO`?o00000omoOgl2o`0000Gooooo2ol9
jPYEooooo`03o`000?oooooooooo00kooooo0021ooooo`03o`000?oooooooooo00[ooooo0_l0000B
ogmoO`03o`000?moOgoo000000?oOgmo00?o0000ooooooooool03oooool<o`WZ2TWooooo00?o0000
ooooooooool03_ooool0087ooooo00?o0000ooooooooool02_ooool2o`0000WoOgmo2Ol9jPX00ol0
003o2NX:o`WZ2P0=o`WZ2QCooooo2ol9jPXnooooo`03o`000?oooooooooo00kooooo000?ooooogoo
2NX:00?o0000o`WZ2_l9jPX02?l9jPX9ogmoO`;o00001?moOgl2o`0000Sooooo4Ol9jPX>ooooo`co
2NX:<_ooool00ol0003oooooooooo`0>ooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`00
0?moOgooOgmo013oOgmo0_l00005ogmoO`03o`000?oooooooooo01Oooooo4Ol9jPX9ooooo`_o2NX:
9oooool2o`0000oooooo000?ooooogoo2NX:00?o0000o`WZ2_l9jPX05ol9jPX00ol0003o2NX:o`WZ
2P0Io`WZ2Q3ooooo4Ol9jPX3ooooo`_o2NX:5_ooool6o`WZ2P;o00003oooool0087ooooo00?o0000
ooooooooool02_ooool2o`0001;oOgmo0_l00004ogmoO`;o00006_oooom;o`WZ2P;o00003oooool0
087ooooo3ol0000BogmoO`go00005?oooom<o`WZ2P;o00003oooool000ooooooOol9jPX00ol0003o
2NX:o`WZ2P0Go`WZ2P03o`000?l9jP[o2NX:01So2NX:6?oooolGo`WZ2QGooooo2?l9jPX2o`0000oo
oooo0021ooooo`03o`000?oooooooooo00[ooooo0_l0000BogmoO`;o00001?moOgl2o`0001gooooo
8?l9jPXXooooo`;o00003oooool0087ooooo00?o0000ooooooooool02_ooool2o`0001;oOgmo0_l0
0005ogmoO`03o`000?oooooooooo00Kooooo5Ol9jPX9ooooo`_o2NX:=?ooool00ol0003ooooooooo
o`0>ooooo`003ooooomoo`WZ2P03o`000?l9jP[o2NX:017o2NX:00?o0000o`WZ2_l9jPX03Ol9jPXC
ooooo`_o2NX:?oooool00ol0003oooooooooo`0>ooooo`00POooool00ol0003oooooooooo`0;oooo
o`03o`000?moOgooOgmo013oOgmo0_l00004ogmoO`;o00003oooool<o`WZ2T[ooooo00?o0000oooo
ooooool03_ooool000ooooooOol9jPX00ol0003o2NX:o`WZ2P09o`WZ2PSoOgmo00?o0000ogmoOol0
00000omoOgl00ol0003oooooooooo`03ooooo`_o2NX:E_ooool00ol0003oooooooooo`0>ooooo`00
POooool00ol0003oooooooooo`0:ooooo`;o00002_moOglDo`WZ2V7ooooo00?o0000ooooooooool0
3_ooool0087ooooo00?o0000ooooooooool02_ooool00ol0003oOgmoogmoO`0AogmoO`?o00000omo
Ogl2o`0006Gooooo00?o0000ooooooooool03_ooool0087ooooo00?o0000ooooooooool02_ooool0
0ol0003oOgmoogmoO`0AogmoO`04o`000?moOgooOgmoo`0000;oOgmo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`0>ooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?moOgoo
Ogmo017oOgmo00Co0000ogmoOomoOgoo00000_moOgl00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00kooooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000ogmoOomoOgl04OmoOgl0
1?l0003oOgmoogmoOol00002ogmoO`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03_oo
ool0087ooooo00?o0000ooooooooool02Oooool00ol0003oOgmoogmoO`0BogmoO`07o`000?moOgoo
OgmoogmoOol0003oOgmoo`00001Vooooo`03o`000?oooooooooo00kooooo0021ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ogmoOomoOgl04_moOgl00ol0003oOgmoogmoO`02ogmoO`;o0000I_oo
ool00ol0003oooooooooo`0>ooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?moOgoo
Ogmo01?oOgmo00?o0000ogmoOomoOgl00_moOgl2o`0006Kooooo00?o0000ooooooooool03_ooool0
087ooooo00?o0000ooooooooool02?ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo
00;oOgmo00?o0000ogmoOol00000IOooool00ol0003oooooooooo`0>ooooo`00POooool00ol0003o
ooooooooo`07ooooo`03o`000?moOgooOgmo01CoOgmo00?o0000ogmoOomoOgl00_moOgl01?l0003o
OgmoogmoOol0001Tooooo`03o`000?oooooooooo00kooooo0021ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ogmoOomoOgl05?moOgl00ol0003oOgmoogmoO`02ogmoO`04o`000?moOgooOgmoo`00
06Cooooo00?o0000ooooooooool03_ooool0087ooooo00?o0000ooooooooool01oooool00ol0003o
OgmoogmoO`0DogmoO`03o`000?moOgooOgmo00;oOgmo00Go0000ogmoOomoOgooOgmoo`00001Soooo
o`03o`000?oooooooooo00kooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000ogmoOomo
Ogl05OmoOgl01Ol0003oOgmoogmoOomoOgoo000000GoOgmo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0>ooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?moOgooOgmo01Go
Ogmo00Go0000ogmoOomoOgooOgmoo`000006ogmoO`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool03_ooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oOgmoogmoO`0FogmoO`05
o`000?moOgooOgmoogmoOol000001omoOgl00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
00kooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ogmoOomoOgl05_moOgl01Ol0003o
OgmoogmoOomoOgoo000000KoOgmoH_ooool00ol0003oooooooooo`0>ooooo`00POooool00ol0003o
ooooooooo`04ooooo`03o`000?moOgooOgmo01OoOgmo00Co0000ogmoOomoOgoo00001_moOgmSoooo
o`03o`000?oooooooooo00kooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomo
Ogl06?moOgl01?l0003oOgmoooooool00005ogmoOfCooooo00?o0000ooooooooool03_ooool0087o
oooo00?o0000ooooooooool00_ooool00ol0003oOgmoogmoO`0GogmoO`;ooooo00Co0000oooooooo
oooo00001?moOgmUooooo`03o`000?oooooooooo00kooooo0021ooooo`03o`000?oooooooooo00;o
oooo00?o0000ogmoOomoOgl04omoOgl6ooooo`03o`000?oooooo000000CoOgmoI_ooool00ol0003o
ooooooooo`0>ooooo`00POooool01Ol0003ooooooooooooooooo0000017oOgmo2oooool00ol0003o
ooooo`000003ogmoOfOooooo00?o0000ooooooooool03_ooool0087ooooo00Co0000oooooooooooo
00003_moOgl?ooooo`03o`000?oooooo000000;oOgmoJ?ooool00ol0003oooooooooo`0>ooooo`00
POooool01?l0003oooooooooool0000:ogmoOa?ooooo0_l00002ogmoOfWooooo00?o0000oooooooo
ool03_ooool0087ooooo00?o0000ooooool000001omoOglGooooo`;o000000?oOgmoooooooooool0
J?ooool00ol0003oooooooooo`0>ooooo`00POooool2o`0000CoOgmo6oooool2o`0006_ooooo00?o
0000ooooooooool03_ooool0087ooooo00?o0000ogmoOoooool07_ooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo00kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.46802 .03036 m
.5116 .03036 L
.54842 .07004 L
.48635 .07004 L
.46802 .03036 L
F
.48635 .07004 m
.54842 .07004 L
.56602 .10972 L
.49666 .10972 L
.48635 .07004 L
F
.49666 .10972 m
.56602 .10972 L
.57143 .1494 L
.5 .1494 L
.49666 .10972 L
F
.5 .1494 m
.57143 .1494 L
.56602 .18909 L
.49666 .18909 L
.5 .1494 L
F
.49666 .18909 m
.56602 .18909 L
.54842 .22877 L
.48635 .22877 L
.49666 .18909 L
F
.48635 .22877 m
.54842 .22877 L
.5116 .26845 L
.46802 .26845 L
.48635 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.46802 .03036 m
.48635 .07004 L
.49666 .10972 L
.5 .1494 L
.49666 .18909 L
.48635 .22877 L
.46802 .26845 L
.5116 .26845 L
.54842 .22877 L
.56602 .18909 L
.57143 .1494 L
.56602 .10972 L
.54842 .07004 L
.5116 .03036 L
.46802 .03036 L
s
.5 g
.46802 .1494 m
.5116 .1494 L
.54842 .1494 L
.48635 .1494 L
.46802 .1494 L
F
.48635 .1494 m
.54842 .1494 L
.56602 .1494 L
.49666 .1494 L
.48635 .1494 L
F
.49666 .1494 m
.56602 .1494 L
.57143 .1494 L
.5 .1494 L
.49666 .1494 L
F
.5 .1494 m
.57143 .1494 L
.56602 .1494 L
.49666 .1494 L
.5 .1494 L
F
.49666 .1494 m
.56602 .1494 L
.54842 .1494 L
.48635 .1494 L
.49666 .1494 L
F
.48635 .1494 m
.54842 .1494 L
.5116 .1494 L
.46802 .1494 L
.48635 .1494 L
F
0 g
.46802 .1494 m
.48635 .1494 L
.49666 .1494 L
.5 .1494 L
.49666 .1494 L
.48635 .1494 L
.46802 .1494 L
.5116 .1494 L
.54842 .1494 L
.56602 .1494 L
.57143 .1494 L
.56602 .1494 L
.54842 .1494 L
.5116 .1494 L
.46802 .1494 L
s
.5 g
.5116 .03036 m
.64879 .07004 L
.54842 .07004 L
.5116 .03036 L
F
.54842 .07004 m
.64879 .07004 L
.60499 .10972 L
.56602 .10972 L
.54842 .07004 L
F
.56602 .10972 m
.60499 .10972 L
.59524 .1494 L
.57143 .1494 L
.56602 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.60499 .18909 L
.56602 .18909 L
.57143 .1494 L
F
.56602 .18909 m
.60499 .18909 L
.64879 .22877 L
.54842 .22877 L
.56602 .18909 L
F
.54842 .22877 m
.64879 .22877 L
.5116 .26845 L
.54842 .22877 L
F
0 g
.5116 .03036 m
.54842 .07004 L
.56602 .10972 L
.57143 .1494 L
.56602 .18909 L
.54842 .22877 L
.5116 .26845 L
s
.64879 .22877 m
.60499 .18909 L
.59524 .1494 L
.60499 .10972 L
.64879 .07004 L
s
.5116 .03036 m
0 0 rlineto s
.5 g
.5116 .1494 m
.64879 .1494 L
.54842 .1494 L
.5116 .1494 L
F
.54842 .1494 m
.64879 .1494 L
.60499 .1494 L
.56602 .1494 L
.54842 .1494 L
F
.56602 .1494 m
.60499 .1494 L
.59524 .1494 L
.57143 .1494 L
.56602 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.60499 .1494 L
.56602 .1494 L
.57143 .1494 L
F
.56602 .1494 m
.60499 .1494 L
.64879 .1494 L
.54842 .1494 L
.56602 .1494 L
F
.54842 .1494 m
.64879 .1494 L
.5116 .1494 L
.54842 .1494 L
F
0 g
.5116 .1494 m
.54842 .1494 L
.56602 .1494 L
.57143 .1494 L
.56602 .1494 L
.54842 .1494 L
.5116 .1494 L
s
.64879 .1494 m
.60499 .1494 L
.59524 .1494 L
.60499 .1494 L
.64879 .1494 L
s
.5116 .1494 m
0 0 rlineto s
.46802 .26845 m
.5116 .26845 L
.5116 .2644 L
.46802 .2644 L
.46802 .26845 L
s
.46802 .2644 m
.5116 .2644 L
.5116 .2525 L
.46802 .2525 L
.46802 .2644 L
s
.46802 .2525 m
.5116 .2525 L
.5116 .23358 L
.46802 .23358 L
.46802 .2525 L
s
.46802 .23358 m
.5116 .23358 L
.5116 .20893 L
.46802 .20893 L
.46802 .23358 L
s
.46802 .20893 m
.5116 .20893 L
.5116 .18022 L
.46802 .18022 L
.46802 .20893 L
s
.46802 .18022 m
.5116 .18022 L
.5116 .1494 L
.46802 .1494 L
.46802 .18022 L
s
.46802 .1494 m
.5116 .1494 L
.5116 .11859 L
.46802 .11859 L
.46802 .1494 L
s
.46802 .11859 m
.5116 .11859 L
.5116 .08988 L
.46802 .08988 L
.46802 .11859 L
s
.46802 .08988 m
.5116 .08988 L
.5116 .06523 L
.46802 .06523 L
.46802 .08988 L
s
.46802 .06523 m
.5116 .06523 L
.5116 .04631 L
.46802 .04631 L
.46802 .06523 L
s
.46802 .04631 m
.5116 .04631 L
.5116 .03441 L
.46802 .03441 L
.46802 .04631 L
s
.46802 .03441 m
.5116 .03441 L
.5116 .03036 L
.46802 .03036 L
.46802 .03441 L
s
.46802 .03036 m
.5116 .03036 L
.5116 .03441 L
.46802 .03441 L
.46802 .03036 L
s
.46802 .03441 m
.5116 .03441 L
.5116 .04631 L
.46802 .04631 L
.46802 .03441 L
s
.46802 .04631 m
.5116 .04631 L
.5116 .06523 L
.46802 .06523 L
.46802 .04631 L
s
.46802 .06523 m
.5116 .06523 L
.5116 .08988 L
.46802 .08988 L
.46802 .06523 L
s
.46802 .08988 m
.5116 .08988 L
.5116 .11859 L
.46802 .11859 L
.46802 .08988 L
s
.46802 .11859 m
.5116 .11859 L
.5116 .1494 L
.46802 .1494 L
.46802 .11859 L
s
.46802 .1494 m
.5116 .1494 L
.5116 .18022 L
.46802 .18022 L
.46802 .1494 L
s
.46802 .18022 m
.5116 .18022 L
.5116 .20893 L
.46802 .20893 L
.46802 .18022 L
s
.46802 .20893 m
.5116 .20893 L
.5116 .23358 L
.46802 .23358 L
.46802 .20893 L
s
.46802 .23358 m
.5116 .23358 L
.5116 .2525 L
.46802 .2525 L
.46802 .23358 L
s
.46802 .2525 m
.5116 .2525 L
.5116 .2644 L
.46802 .2644 L
.46802 .2525 L
s
.46802 .2644 m
.5116 .2644 L
.5116 .26845 L
.46802 .26845 L
.46802 .2644 L
s
.5116 .26845 m
0 0 rlineto s
.5116 .2644 m
.5116 .26845 L
s
.5116 .2644 m
0 0 rlineto s
.5116 .2525 m
.5116 .2644 L
s
.5116 .2525 m
0 0 rlineto s
.5116 .23358 m
.5116 .2525 L
s
.5116 .23358 m
0 0 rlineto s
.5116 .20893 m
.5116 .23358 L
s
.5116 .20893 m
0 0 rlineto s
.5116 .18022 m
.5116 .20893 L
s
.5116 .18022 m
0 0 rlineto s
.5116 .1494 m
.5116 .18022 L
s
.5116 .1494 m
0 0 rlineto s
.5116 .11859 m
.5116 .1494 L
s
.5116 .11859 m
0 0 rlineto s
.5116 .08988 m
.5116 .11859 L
s
.5116 .08988 m
0 0 rlineto s
.5116 .06523 m
.5116 .08988 L
s
.5116 .06523 m
0 0 rlineto s
.5116 .04631 m
.5116 .06523 L
s
.5116 .04631 m
0 0 rlineto s
.5116 .03441 m
.5116 .04631 L
s
.5116 .03441 m
0 0 rlineto s
.5116 .03036 m
.5116 .03441 L
s
.5116 .03036 m
0 0 rlineto s
.5116 .03441 m
.5116 .03036 L
s
.5116 .03441 m
0 0 rlineto s
.5116 .04631 m
.5116 .03441 L
s
.5116 .04631 m
0 0 rlineto s
.5116 .06523 m
.5116 .04631 L
s
.5116 .06523 m
0 0 rlineto s
.5116 .08988 m
.5116 .06523 L
s
.5116 .08988 m
0 0 rlineto s
.5116 .11859 m
.5116 .08988 L
s
.5116 .11859 m
0 0 rlineto s
.5116 .1494 m
.5116 .11859 L
s
.5116 .1494 m
0 0 rlineto s
.5116 .18022 m
.5116 .1494 L
s
.5116 .18022 m
0 0 rlineto s
.5116 .20893 m
.5116 .18022 L
s
.5116 .20893 m
0 0 rlineto s
.5116 .23358 m
.5116 .20893 L
s
.5116 .23358 m
0 0 rlineto s
.5116 .2525 m
.5116 .23358 L
s
.5116 .2525 m
0 0 rlineto s
.5116 .2644 m
.5116 .2525 L
s
.5116 .2644 m
0 0 rlineto s
.5116 .26845 m
.5116 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.4988 .1256 L
s
0 0 0 r
2 Mabswid
.4988 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49957 .13512 L
s
0 0 0 r
2 Mabswid
.49957 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49995 .14464 L
s
0 0 0 r
2 Mabswid
.49995 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49995 .15417 L
s
0 0 0 r
2 Mabswid
.49995 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49957 .16369 L
s
0 0 0 r
2 Mabswid
.49957 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.4988 .17321 L
s
0 0 0 r
2 Mabswid
.4988 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.4988 .1256 m
.5691 .12324 L
s
0 0 0 r
2 Mabswid
.5691 .12324 Mdot
.039 .916 .04 r
.5 Mabswid
.49957 .13512 m
.57059 .13369 L
s
0 0 0 r
2 Mabswid
.57059 .13369 Mdot
.039 .916 .04 r
.5 Mabswid
.49995 .14464 m
.57134 .14417 L
s
0 0 0 r
2 Mabswid
.57134 .14417 Mdot
.039 .916 .04 r
.5 Mabswid
.49995 .15417 m
.57134 .15464 L
s
0 0 0 r
2 Mabswid
.57134 .15464 Mdot
.039 .916 .04 r
.5 Mabswid
.49957 .16369 m
.57059 .16512 L
s
0 0 0 r
2 Mabswid
.57059 .16512 Mdot
.039 .916 .04 r
.5 Mabswid
.4988 .17321 m
.5691 .17557 L
s
0 0 0 r
2 Mabswid
.5691 .17557 Mdot
.039 .916 .04 r
.5 Mabswid
.5691 .12324 m
.59993 .12146 L
s
0 0 0 r
2 Mabswid
.59993 .12146 Mdot
.039 .916 .04 r
.5 Mabswid
.57059 .13369 m
.59687 .13279 L
s
0 0 0 r
2 Mabswid
.59687 .13279 Mdot
.039 .916 .04 r
.5 Mabswid
.57134 .14417 m
.59542 .14389 L
s
0 0 0 r
2 Mabswid
.59542 .14389 Mdot
.039 .916 .04 r
.5 Mabswid
.57134 .15464 m
.59542 .15492 L
s
0 0 0 r
2 Mabswid
.59542 .15492 Mdot
.039 .916 .04 r
.5 Mabswid
.57059 .16512 m
.59687 .16602 L
s
0 0 0 r
2 Mabswid
.59687 .16602 Mdot
.039 .916 .04 r
.5 Mabswid
.5691 .17557 m
.59993 .17735 L
s
0 0 0 r
2 Mabswid
.59993 .17735 Mdot
.039 .916 .04 r
.5 Mabswid
.59687 .13279 m
.97619 .04518 L
s
0 0 0 r
2 Mabswid
.97619 .04518 Mdot
.039 .916 .04 r
.5 Mabswid
.59542 .14389 m
.97619 .11625 L
s
0 0 0 r
2 Mabswid
.97619 .11625 Mdot
.039 .916 .04 r
.5 Mabswid
.59542 .15492 m
.97619 .18256 L
s
0 0 0 r
2 Mabswid
.97619 .18256 Mdot
.039 .916 .04 r
.5 Mabswid
.59687 .16602 m
.97619 .25363 L
s
0 0 0 r
2 Mabswid
.97619 .25363 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo002Booooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool03_ooool0
08Kooooo3Ol0001looooo`03o`000?oooooooooo00kooooo0026ooooo`ko000000?oOgmooooooooo
ool0N?ooool00ol0003oooooooooo`0>ooooo`00Q_ooool2o`0000[oOgmo00?o0000ogmoOol00000
1?moOgmfooooo`03o`000?oooooooooo00kooooo0026ooooo`;o00002_moOgl01?l0003oOgmoogmo
Ool00006ogmoOg?ooooo0_l0000?ooooo`00Q_ooool=o`0000?oOgmo00?o0000ogmoOomoOgl01omo
Ogm]ooooo`;o2NX:0_l0000?ooooo`00Q_ooool00ol0003oooooo`000009ogmoO`03o`000?moOgoo
Ogmo00;oOgmo00?o0000ogmoOomoOgl02_moOgmTooooo`Go2NX:0_ooool00ol0003oooooooooo`0>
ooooo`00Q_ooool01?l0003oooooooooool00008ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000
ogmoOomoOgl03?moOgmMooooo`Co2NX:1oooool00ol0003oooooooooo`0>ooooo`00Q_ooool01?l0
003oooooooooool00008ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl03omoOgmD
ooooo`Go2NX:2oooool00ol0003oooooooooo`0>ooooo`00Q_ooool01Ol0003ooooooooooooooooo
000000OoOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`0BogmoOdcooooo1?l9jPX@
ooooo`03o`000?oooooooooo00kooooo0026ooooo`go00002?moOgl00ol0003oOgmoogmoO`0Dogmo
OdGooooo1?l9jPXDooooo`03o`000?oooooooooo00kooooo0026ooooo`03o`000?oooooooooo00;o
oooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo01Oo
Ogmo0_l0000jooooo`Go2NX:6?ooool00ol0003oooooooooo`0>ooooo`00Q_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmo
ogmoO`0FogmoO`03o`000?oooooooooo03Kooooo1?l9jPXMooooo`03o`000?oooooooooo00kooooo
0026ooooo`03o`000?oooooooooo00;ooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmo
O`08ogmoO`03o`000?moOgooOgmo01CoOgmo00?o0000ooooooooool0<_ooool5o`WZ2R7ooooo00?o
0000ooooooooool03_ooool008Kooooo00?o0000ooooooooool00oooool00ol0003oOgmoogmoO`03
ogmoO`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`0_
ooooo`Co2NX:9_ooool00ol0003oooooooooo`0>ooooo`00Q_ooool00ol0003oooooooooo`03oooo
o`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0Aogmo
O`03o`000?oooooooooo02_ooooo1Ol9jPXZooooo`03o`000?oooooooooo00kooooo0026ooooo`03
o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`09ogmoO`03
o`000?moOgooOgmo013oOgmo00?o0000ooooooooool0:?ooool4o`WZ2Roooooo00?o0000oooooooo
ool03_ooool008Kooooo3Ol0000<ogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ooooooooool0
9Oooool4o`WZ2S?ooooo00?o0000ooooooooool03_ooool008Kooooo00?o0000ooooooooool01?oo
ool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl03Omo
Ogl00ol0003oooooooooo`0Qooooo`Go2NX:=oooool00ol0003oooooooooo`0>ooooo`00Q_ooool0
0ol0003oooooooooo`04ooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl02_moOgl0
0ol0003oOgmoogmoO`0<ogmoO`03o`000?oooooooooo01kooooo1?l9jPXlooooo`03o`000?oooooo
oooo00kooooo0026ooooo`03o`000?oooooooooo00Cooooo00?o0000ogmoOomoOgl00_moOgl00ol0
003oOgmoogmoO`0;ogmoO`03o`000?moOgooOgmo00[oOgmo00?o0000ooooooooool06_ooool5o`WZ
2T3ooooo00?o0000ooooooooool03_ooool008Kooooo00?o0000ooooooooool01Oooool01Ol0003o
OgmoogmoOomoOgoo000000goOgmo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0Goooo
o`Co2NX:AOooool00ol0003oooooooooo`0>ooooo`00Q_ooool00ol0003oooooooooo`05ooooo`05
o`000?moOgooOgmoogmoOol000003_moOgl00ol0003oOgmoogmoO`07ogmoO`03o`000?oooooooooo
01?ooooo1Ol9jPY9ooooo`03o`000?oooooooooo00kooooo0026ooooo`03o`000?oooooooooo00Go
oooo00Go0000ogmoOomoOgooOgmoo`00000>ogmoO`03o`000?moOgooOgmo00OoOgmo00?o0000oooo
ooooool03oooool4o`WZ2Tkooooo0_l0000?ooooo`00Q_ooool=o`0000koOgmo00?o0000ogmoOomo
Ogl01omoOgl00ol0003oooooooooo`0;ooooo`Co2NX:Boooool7o`WZ2P;o00003oooool008Kooooo
00?o0000ooooooooool01Oooool01Ol0003oOgmoogmoOomoOgoo000000koOgmo0_l00003ogmoO`?o
2NX:0ol00008ooooo`Go2NX:@?ooool?o`WZ2POooooo00?o0000ooooooooool03_ooool000oooooo
Ool9jPX00ol0003o2NX:o`WZ2P0@o`WZ2P03o`000?l9jP[o2NX:00;o2NX:0omoOgl2o`0000Gooooo
1?l9jPXgooooo`ko2NX:5_ooool00ol0003oooooooooo`0>ooooo`00Q_ooool00ol0003ooooooooo
o`05ooooo`;o00000_moOgl00ol0003oOgmoogmoO`0<ogmoO`03o`000?moOgooOgmo00KoOgmo00?o
0000o`WZ2_l9jPX00ol9jPX/ooooo`oo2NX:9?ooool00ol0003oooooooooo`0>ooooo`00Q_ooool0
0ol0003oooooooooo`05ooooo`;o00000_moOgl00ol0003oOgmoogmoO`04ogmoO`So2NX:00?o0000
o`WZ2_l9jPX01ol9jPXRooooo`oo2NX:<oooool00ol0003oooooooooo`0>ooooo`003ooooomoo`WZ
2P03o`000?l9jP[o2NX:00So2NX:2?moOgl2o`0000KoOgmo0_l0000Dooooo`ko2NX:@_ooool00ol0
003oooooooooo`0>ooooo`00Q_ooool00ol0003oooooooooo`06ooooo`04o`000?moOgooOgmoo`00
00ooOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003oooooooooo`03ooooo`oo2NX:D?ooool00ol0
003oooooooooo`0>ooooo`003ooooomoo`WZ2P03o`000?l9jP[o2NX:01Oo2NX:00?o0000o`WZ2_l9
jPX01Ol9jPYOooooo`03o`000?oooooooooo00kooooo0026ooooo`03o`000?oooooooooo00Gooooo
0_l00002ogmoO`03o`000?moOgooOgmo00goOgmo0_l00004ogmoO`;o0000IOooool00ol0003ooooo
ooooo`0>ooooo`00Q_oooolMo`0000KoOgmo3ol0001Gooooo`03o`000?oooooooooo00kooooo000?
ooooogoo2NX:00?o0000o`WZ2_l9jPX05ol9jPX00ol0003o2NX:o`WZ2P05o`WZ2Uoooooo00?o0000
ooooooooool03_ooool008Kooooo00?o0000ooooooooool01Oooool2o`0000;oOgmo00?o0000ogmo
OomoOgl03OmoOgl2o`0000CoOgmo0_l00006ooooo`go2NX:D_ooool00ol0003oooooooooo`0>oooo
o`00Q_ooool00ol0003oooooooooo`05ooooo`;o00000_moOgl00ol0003oOgmoogmoO`0<ogmoO`;o
00001omoOgl00ol0003oooooooooo`0@ooooo`go2NX:AOooool00ol0003oooooooooo`0>ooooo`00
3ooooomoo`WZ2P03o`000?l9jP[o2NX:013o2NX:00?o0000o`WZ2_l9jPX02?l9jPXNooooo`go2NX:
>?ooool00ol0003oooooooooo`0>ooooo`00Q_ooool00ol0003oooooooooo`06ooooo`04o`000?mo
OgooOgmoo`0000ooOgmo00?o0000ogmoOomoOgl01?moOgl2o`000003ooooool9jP[o2NX:00;o2NX:
9oooool<o`WZ2Rcooooo00?o0000ooooooooool03_ooool000ooooooOol9jPX00ol0003o2NX:o`WZ
2P09o`WZ2POoOgmo0_l00007ogmoO`03o`000?oooooooooo00?ooooo1Ol9jPX^ooooo`go2NX:7ooo
ool00ol0003oooooooooo`0>ooooo`00Q_ooool00ol0003oooooooooo`05ooooo`;o00000_moOgl0
0ol0003oOgmoogmoO`05ogmoO`Oo2NX:00?o0000o`WZ2_l9jPX01Ol9jPX2o`0000[ooooo1?l9jPXg
ooooo`go2NX:4_ooool00ol0003oooooooooo`0>ooooo`00Q_ooool=o`0000koOgmo00?o0000ogmo
OomoOgl01OmoOgl3o`0000gooooo1?l9jPY0ooooo`go2NX:1Oooool2o`0000oooooo0026ooooo`03
o`000?oooooooooo00Gooooo00Go0000ogmoOomoOgooOgmoo`00000>ogmoO`03o`000?moOgooOgmo
00OoOgmo00?o0000ooooooooool03oooool4o`WZ2TWooooo1Ol9jPX2o`0000oooooo0026ooooo`03
o`000?oooooooooo00Gooooo00Go0000ogmoOomoOgooOgmoo`00000>ogmoO`03o`000?moOgooOgmo
00OoOgmo0_l0000Dooooo`Go2NX:BOooool00ol0003oooooooooo`0>ooooo`00Q_ooool00ol0003o
ooooooooo`05ooooo`05o`000?moOgooOgmoogmoOol000003_moOgl00ol0003oOgmoogmoO`09ogmo
O`03o`000?oooooooooo01Kooooo1?l9jPY5ooooo`03o`000?oooooooooo00kooooo0026ooooo`03
o`000?oooooooooo00Gooooo00Go0000ogmoOomoOgooOgmoo`00000=ogmoO`03o`000?moOgooOgmo
00_oOgmo00?o0000ooooooooool06Oooool4o`WZ2T7ooooo00?o0000ooooooooool03_ooool008Ko
oooo00?o0000ooooooooool01?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00_o
Ogmo00?o0000ogmoOomoOgl03?moOgl00ol0003oooooooooo`0Looooo`Co2NX:?Oooool00ol0003o
ooooooooo`0>ooooo`00Q_ooool00ol0003oooooooooo`04ooooo`03o`000?moOgooOgmo00;oOgmo
00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?oooooooooo01oooooo
1Ol9jPXhooooo`03o`000?oooooooooo00kooooo0026ooooo`03o`000?oooooooooo00Cooooo00?o
0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo00ooOgmo00?o
0000ooooooooool08oooool4o`WZ2SCooooo00?o0000ooooooooool03_ooool008Kooooo3Ol0000;
ogmoO`03o`000?moOgooOgmo017oOgmo00?o0000ooooooooool09_ooool4o`WZ2S3ooooo00?o0000
ooooooooool03_ooool008Kooooo00?o0000ooooooooool00oooool00ol0003oOgmoogmoO`03ogmo
O`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl04_moOgl00ol0003oooooooooo`0Yoooo
o`Co2NX:;?ooool00ol0003oooooooooo`0>ooooo`00Q_ooool00ol0003oooooooooo`03ooooo`03
o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`0CogmoO`03
o`000?oooooooooo02cooooo1Ol9jPXWooooo`03o`000?oooooooooo00kooooo0026ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`08ogmoO`03o`00
0?moOgooOgmo01GoOgmo00?o0000ooooooooool0<?ooool4o`WZ2R?ooooo00?o0000ooooooooool0
3_ooool008Kooooo00?o0000ooooooooool00_ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?mo
OgooOgmo00SoOgmo00?o0000ogmoOomoOgl05_moOgl00ol0003oooooooooo`0cooooo`Co2NX:7ooo
ool00ol0003oooooooooo`0>ooooo`00Q_ooool00ol0003oooooooooo`02ooooo`03o`000?moOgoo
Ogmo00CoOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`0HogmoO`03o`000?oooooo
oooo03Kooooo1?l9jPXKooooo`03o`000?oooooooooo00kooooo0026ooooo`go00002OmoOgl00ol0
003oOgmoogmoO`0FogmoOcoooooo1Ol9jPXFooooo`03o`000?oooooooooo00kooooo0026ooooo`05
o`000?ooooooooooooooool000001omoOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo
01CoOgmoAoooool4o`WZ2Q;ooooo00?o0000ooooooooool03_ooool008Kooooo00Go0000oooooooo
ooooooooo`000007ogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl04_moOgm>oooo
o`Co2NX:3_ooool00ol0003oooooooooo`0>ooooo`00Q_ooool01?l0003oooooooooool00008ogmo
O`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl03omoOgmFooooo`Co2NX:2_ooool00ol0
003oooooooooo`0>ooooo`00Q_ooool01?l0003oooooooooool00008ogmoO`03o`000?moOgooOgmo
00?oOgmo00?o0000ogmoOomoOgl03OmoOgmMooooo`Go2NX:1Oooool00ol0003oooooooooo`0>oooo
o`00Q_ooool=o`0000CoOgmo00?o0000ogmoOomoOgl02_moOgmVooooo`Co2NX:00?oooooo`000?l0
00003oooool008Kooooo00?o0000ooooool000002OmoOgl01Ol0003oOgmoogmoOomoOgoo000000[o
OgmoKOooool00ol9jP[o0000o`00000?ooooo`00Q_ooool00ol0003oooooo`000009ogmoO`04o`00
0?moOgooOgmoo`0000SoOgmoLOooool00ol0003oooooooooo`0>ooooo`00Q_ooool2o`0000[oOgmo
00?o0000ogmoOol000001OmoOgmeooooo`03o`000?oooooooooo00kooooo0026ooooo`ko00000omo
Ogmhooooo`03o`000?oooooooooo00kooooo0026ooooo`go000000?oOgmoooooooooool0NOooool0
0ol0003oooooooooo`0>ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.49116 .03036 m
.57198 .03036 L
.57167 .07004 L
.49608 .07004 L
.49116 .03036 L
F
.49608 .07004 m
.57167 .07004 L
.57149 .10972 L
.49902 .10972 L
.49608 .07004 L
F
.49902 .10972 m
.57149 .10972 L
.57143 .1494 L
.5 .1494 L
.49902 .10972 L
F
.5 .1494 m
.57143 .1494 L
.57149 .18909 L
.49902 .18909 L
.5 .1494 L
F
.49902 .18909 m
.57149 .18909 L
.57167 .22877 L
.49608 .22877 L
.49902 .18909 L
F
.49608 .22877 m
.57167 .22877 L
.57198 .26845 L
.49116 .26845 L
.49608 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.49116 .03036 m
.49608 .07004 L
.49902 .10972 L
.5 .1494 L
.49902 .18909 L
.49608 .22877 L
.49116 .26845 L
.57198 .26845 L
.57167 .22877 L
.57149 .18909 L
.57143 .1494 L
.57149 .10972 L
.57167 .07004 L
.57198 .03036 L
.49116 .03036 L
s
.5 g
.49116 .1494 m
.57198 .1494 L
.57167 .1494 L
.49608 .1494 L
.49116 .1494 L
F
.49608 .1494 m
.57167 .1494 L
.57149 .1494 L
.49902 .1494 L
.49608 .1494 L
F
.49902 .1494 m
.57149 .1494 L
.57143 .1494 L
.5 .1494 L
.49902 .1494 L
F
.5 .1494 m
.57143 .1494 L
.57149 .1494 L
.49902 .1494 L
.5 .1494 L
F
.49902 .1494 m
.57149 .1494 L
.57167 .1494 L
.49608 .1494 L
.49902 .1494 L
F
.49608 .1494 m
.57167 .1494 L
.57198 .1494 L
.49116 .1494 L
.49608 .1494 L
F
0 g
.49116 .1494 m
.49608 .1494 L
.49902 .1494 L
.5 .1494 L
.49902 .1494 L
.49608 .1494 L
.49116 .1494 L
.57198 .1494 L
.57167 .1494 L
.57149 .1494 L
.57143 .1494 L
.57149 .1494 L
.57167 .1494 L
.57198 .1494 L
.49116 .1494 L
s
.5 g
.57198 .03036 m
.5652 .03036 L
.58236 .07004 L
.57167 .07004 L
.57198 .03036 L
F
.57167 .07004 m
.58236 .07004 L
.59208 .10972 L
.57149 .10972 L
.57167 .07004 L
F
.57149 .10972 m
.59208 .10972 L
.59524 .1494 L
.57143 .1494 L
.57149 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59208 .18909 L
.57149 .18909 L
.57143 .1494 L
F
.57149 .18909 m
.59208 .18909 L
.58236 .22877 L
.57167 .22877 L
.57149 .18909 L
F
.57167 .22877 m
.58236 .22877 L
.5652 .26845 L
.57198 .26845 L
.57167 .22877 L
F
0 g
.57198 .03036 m
.57167 .07004 L
.57149 .10972 L
.57143 .1494 L
.57149 .18909 L
.57167 .22877 L
.57198 .26845 L
.5652 .26845 L
.58236 .22877 L
.59208 .18909 L
.59524 .1494 L
.59208 .10972 L
.58236 .07004 L
.5652 .03036 L
.57198 .03036 L
s
.5 g
.57198 .1494 m
.5652 .1494 L
.58236 .1494 L
.57167 .1494 L
.57198 .1494 L
F
.57167 .1494 m
.58236 .1494 L
.59208 .1494 L
.57149 .1494 L
.57167 .1494 L
F
.57149 .1494 m
.59208 .1494 L
.59524 .1494 L
.57143 .1494 L
.57149 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59208 .1494 L
.57149 .1494 L
.57143 .1494 L
F
.57149 .1494 m
.59208 .1494 L
.58236 .1494 L
.57167 .1494 L
.57149 .1494 L
F
.57167 .1494 m
.58236 .1494 L
.5652 .1494 L
.57198 .1494 L
.57167 .1494 L
F
0 g
.57198 .1494 m
.57167 .1494 L
.57149 .1494 L
.57143 .1494 L
.57149 .1494 L
.57167 .1494 L
.57198 .1494 L
.5652 .1494 L
.58236 .1494 L
.59208 .1494 L
.59524 .1494 L
.59208 .1494 L
.58236 .1494 L
.5652 .1494 L
.57198 .1494 L
s
.49116 .26845 m
.57198 .26845 L
.57198 .2644 L
.49116 .2644 L
.49116 .26845 L
s
.49116 .2644 m
.57198 .2644 L
.57198 .2525 L
.49116 .2525 L
.49116 .2644 L
s
.49116 .2525 m
.57198 .2525 L
.57198 .23358 L
.49116 .23358 L
.49116 .2525 L
s
.49116 .23358 m
.57198 .23358 L
.57198 .20893 L
.49116 .20893 L
.49116 .23358 L
s
.49116 .20893 m
.57198 .20893 L
.57198 .18022 L
.49116 .18022 L
.49116 .20893 L
s
.49116 .18022 m
.57198 .18022 L
.57198 .1494 L
.49116 .1494 L
.49116 .18022 L
s
.49116 .1494 m
.57198 .1494 L
.57198 .11859 L
.49116 .11859 L
.49116 .1494 L
s
.49116 .11859 m
.57198 .11859 L
.57198 .08988 L
.49116 .08988 L
.49116 .11859 L
s
.49116 .08988 m
.57198 .08988 L
.57198 .06523 L
.49116 .06523 L
.49116 .08988 L
s
.49116 .06523 m
.57198 .06523 L
.57198 .04631 L
.49116 .04631 L
.49116 .06523 L
s
.49116 .04631 m
.57198 .04631 L
.57198 .03441 L
.49116 .03441 L
.49116 .04631 L
s
.49116 .03441 m
.57198 .03441 L
.57198 .03036 L
.49116 .03036 L
.49116 .03441 L
s
.49116 .03036 m
.57198 .03036 L
.57198 .03441 L
.49116 .03441 L
.49116 .03036 L
s
.49116 .03441 m
.57198 .03441 L
.57198 .04631 L
.49116 .04631 L
.49116 .03441 L
s
.49116 .04631 m
.57198 .04631 L
.57198 .06523 L
.49116 .06523 L
.49116 .04631 L
s
.49116 .06523 m
.57198 .06523 L
.57198 .08988 L
.49116 .08988 L
.49116 .06523 L
s
.49116 .08988 m
.57198 .08988 L
.57198 .11859 L
.49116 .11859 L
.49116 .08988 L
s
.49116 .11859 m
.57198 .11859 L
.57198 .1494 L
.49116 .1494 L
.49116 .11859 L
s
.49116 .1494 m
.57198 .1494 L
.57198 .18022 L
.49116 .18022 L
.49116 .1494 L
s
.49116 .18022 m
.57198 .18022 L
.57198 .20893 L
.49116 .20893 L
.49116 .18022 L
s
.49116 .20893 m
.57198 .20893 L
.57198 .23358 L
.49116 .23358 L
.49116 .20893 L
s
.49116 .23358 m
.57198 .23358 L
.57198 .2525 L
.49116 .2525 L
.49116 .23358 L
s
.49116 .2525 m
.57198 .2525 L
.57198 .2644 L
.49116 .2644 L
.49116 .2525 L
s
.49116 .2644 m
.57198 .2644 L
.57198 .26845 L
.49116 .26845 L
.49116 .2644 L
s
.57198 .26845 m
.5652 .26845 L
.5652 .2644 L
.57198 .2644 L
.57198 .26845 L
s
.57198 .2644 m
.5652 .2644 L
.5652 .2525 L
.57198 .2525 L
.57198 .2644 L
s
.57198 .2525 m
.5652 .2525 L
.5652 .23358 L
.57198 .23358 L
.57198 .2525 L
s
.57198 .23358 m
.5652 .23358 L
.5652 .20893 L
.57198 .20893 L
.57198 .23358 L
s
.57198 .20893 m
.5652 .20893 L
.5652 .18022 L
.57198 .18022 L
.57198 .20893 L
s
.57198 .18022 m
.5652 .18022 L
.5652 .1494 L
.57198 .1494 L
.57198 .18022 L
s
.57198 .1494 m
.5652 .1494 L
.5652 .11859 L
.57198 .11859 L
.57198 .1494 L
s
.57198 .11859 m
.5652 .11859 L
.5652 .08988 L
.57198 .08988 L
.57198 .11859 L
s
.57198 .08988 m
.5652 .08988 L
.5652 .06523 L
.57198 .06523 L
.57198 .08988 L
s
.57198 .06523 m
.5652 .06523 L
.5652 .04631 L
.57198 .04631 L
.57198 .06523 L
s
.57198 .04631 m
.5652 .04631 L
.5652 .03441 L
.57198 .03441 L
.57198 .04631 L
s
.57198 .03441 m
.5652 .03441 L
.5652 .03036 L
.57198 .03036 L
.57198 .03441 L
s
.57198 .03036 m
.5652 .03036 L
.5652 .03441 L
.57198 .03441 L
.57198 .03036 L
s
.57198 .03441 m
.5652 .03441 L
.5652 .04631 L
.57198 .04631 L
.57198 .03441 L
s
.57198 .04631 m
.5652 .04631 L
.5652 .06523 L
.57198 .06523 L
.57198 .04631 L
s
.57198 .06523 m
.5652 .06523 L
.5652 .08988 L
.57198 .08988 L
.57198 .06523 L
s
.57198 .08988 m
.5652 .08988 L
.5652 .11859 L
.57198 .11859 L
.57198 .08988 L
s
.57198 .11859 m
.5652 .11859 L
.5652 .1494 L
.57198 .1494 L
.57198 .11859 L
s
.57198 .1494 m
.5652 .1494 L
.5652 .18022 L
.57198 .18022 L
.57198 .1494 L
s
.57198 .18022 m
.5652 .18022 L
.5652 .20893 L
.57198 .20893 L
.57198 .18022 L
s
.57198 .20893 m
.5652 .20893 L
.5652 .23358 L
.57198 .23358 L
.57198 .20893 L
s
.57198 .23358 m
.5652 .23358 L
.5652 .2525 L
.57198 .2525 L
.57198 .23358 L
s
.57198 .2525 m
.5652 .2525 L
.5652 .2644 L
.57198 .2644 L
.57198 .2525 L
s
.57198 .2644 m
.5652 .2644 L
.5652 .26845 L
.57198 .26845 L
.57198 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.49965 .1256 L
s
0 0 0 r
2 Mabswid
.49965 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49987 .13512 L
s
0 0 0 r
2 Mabswid
.49987 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49999 .14464 L
s
0 0 0 r
2 Mabswid
.49999 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49999 .15417 L
s
0 0 0 r
2 Mabswid
.49999 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49987 .16369 L
s
0 0 0 r
2 Mabswid
.49987 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.49965 .17321 L
s
0 0 0 r
2 Mabswid
.49965 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.49965 .1256 m
.57145 .12489 L
s
0 0 0 r
2 Mabswid
.57145 .12489 Mdot
.039 .916 .04 r
.5 Mabswid
.49987 .13512 m
.57144 .1347 L
s
0 0 0 r
2 Mabswid
.57144 .1347 Mdot
.039 .916 .04 r
.5 Mabswid
.49999 .14464 m
.57143 .1445 L
s
0 0 0 r
2 Mabswid
.57143 .1445 Mdot
.039 .916 .04 r
.5 Mabswid
.49999 .15417 m
.57143 .15431 L
s
0 0 0 r
2 Mabswid
.57143 .15431 Mdot
.039 .916 .04 r
.5 Mabswid
.49987 .16369 m
.57144 .16411 L
s
0 0 0 r
2 Mabswid
.57144 .16411 Mdot
.039 .916 .04 r
.5 Mabswid
.49965 .17321 m
.57145 .17392 L
s
0 0 0 r
2 Mabswid
.57145 .17392 Mdot
.039 .916 .04 r
.5 Mabswid
.57145 .12489 m
.59402 .12471 L
s
0 0 0 r
2 Mabswid
.59402 .12471 Mdot
.039 .916 .04 r
.5 Mabswid
.57144 .1347 m
.5948 .13459 L
s
0 0 0 r
2 Mabswid
.5948 .13459 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .1445 m
.59519 .14446 L
s
0 0 0 r
2 Mabswid
.59519 .14446 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .15431 m
.59519 .15434 L
s
0 0 0 r
2 Mabswid
.59519 .15434 Mdot
.039 .916 .04 r
.5 Mabswid
.57144 .16411 m
.5948 .16422 L
s
0 0 0 r
2 Mabswid
.5948 .16422 Mdot
.039 .916 .04 r
.5 Mabswid
.57145 .17392 m
.59402 .1741 L
s
0 0 0 r
2 Mabswid
.59402 .1741 Mdot
.039 .916 .04 r
.5 Mabswid
.59402 .12471 m
.97619 .14963 L
s
0 0 0 r
2 Mabswid
.97619 .14963 Mdot
.039 .916 .04 r
.5 Mabswid
.5948 .13459 m
.97619 .14941 L
s
0 0 0 r
2 Mabswid
.97619 .14941 Mdot
.039 .916 .04 r
.5 Mabswid
.59519 .14446 m
.97619 .14938 L
s
0 0 0 r
2 Mabswid
.97619 .14938 Mdot
.039 .916 .04 r
.5 Mabswid
.59519 .15434 m
.97619 .14943 L
s
0 0 0 r
2 Mabswid
.97619 .14943 Mdot
.039 .916 .04 r
.5 Mabswid
.5948 .16422 m
.97619 .1494 L
s
0 0 0 r
2 Mabswid
.97619 .1494 Mdot
.039 .916 .04 r
.5 Mabswid
.59402 .1741 m
.97619 .14917 L
s
0 0 0 r
2 Mabswid
.97619 .14917 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool008gooooo5_l0001/oooo
o`03o`000?oooooooooo00kooooo002=oooooaKo0000K?ooool00ol0003oooooooooo`0>ooooo`00
SOooool00ol0003oOgmoogmoO`0AogmoO`;o0000K?ooool00ol0003oooooooooo`0>ooooo`00SOoo
ool00ol0003oOgmoogmoO`0AogmoO`;o0000K?ooool00ol0003oooooooooo`0>ooooo`00SOoooolF
o`0006cooooo00?o0000ooooooooool03_ooool008gooooo00?o0000ogmoOomoOgl04OmoOgl3o`00
06_ooooo00?o0000ooooooooool03_ooool008gooooo0_l0000BogmoO`?o0000Joooool00ol0003o
ooooooooo`0>ooooo`00SOooool2o`0001;oOgmo0_l000000omoOgoo0000ooooo`1Yooooo`03o`00
0?oooooooooo00kooooo002=ooooo`;o00004_moOgl2o`000003ogmoOol0003ooooo06Wooooo00?o
0000ooooooooool03_ooool008gooooo5_l000000omoOgoo0000ooooo`1Yooooo`03o`000?oooooo
oooo00kooooo002=ooooo`;o00004_moOgl2o`0000;oOgmo00?o0000ooooooooool0Ioooool00ol0
003oooooooooo`0>ooooo`00SOooool2o`0001;oOgmo0_l00002ogmoO`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool03_ooool008gooooo0_l0000BogmoO`;o00000_moOgl00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo00kooooo002=ooooo`;o00004_moOgl2o`0000?oOgmo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`0>ooooo`00SOooool2o`0001;oOgmo0_l00003
ogmoO`03o`000?oooooooooo06Kooooo00?o0000ooooooooool03_ooool008gooooo0_l0000Bogmo
O`;o00000omoOgl00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00kooooo002=oooooaKo
00001?moOgl00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00kooooo002=ooooo`03o`00
0?oooooo0000017oOgmo0_l00004ogmoO`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
3_ooool008gooooo00?o0000ooooool000004OmoOgl2o`0000CoOgmo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`0>ooooo`00SOooool00ol0003oooooo`00000AogmoO`;o00001?moOgl0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00kooooo002=ooooo`03o`000?oooooo0000
017oOgmo0_l00005ogmoO`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03_ooool008go
oooo00?o0000ooooool000004OmoOgl2o`0000GoOgmo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`0>ooooo`00SOooool00ol0003oooooo`00000AogmoO`;o00001OmoOgl00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo00kooooo002=oooooaKo00001OmoOgl00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo00kooooo002=ooooo`03o`000?oooooo0000017oOgmo0_l00005
ogmoO`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03_ooool000ooooooOol9jPX00ol0
003o2NX:o`WZ2P0Oo`WZ2Uoooooo00?o0000ooooooooool03_ooool008gooooo0ol0000AogmoO`?o
00001?moOgl2o`0000Kooooo3ol9jPY@ooooo`03o`000?oooooooooo00kooooo002=ooooo`?o0000
4OmoOgl3o`0000CoOgmo0_l0000Eooooo`oo2NX:@Oooool00ol0003oooooooooo`0>ooooo`003ooo
oomoo`WZ2P03o`000?l9jP[o2NX:02Go2NX:6?ooool?o`WZ2S;ooooo00?o0000ooooooooool03_oo
ool008gooooo00?o0000ooooool000004OmoOgl2o`0000KoOgmo00?o0000ooooooooool02_oooolJ
o`WZ2Pgooooo3_l9jPXTooooo`03o`000?oooooooooo00kooooo000?ooooogoo2NX:00?o0000o`WZ
2_l9jPX05ol9jPX00ol0003o2NX:o`WZ2P0Io`WZ2Pcooooo6Ol9jPX2ooooo`oo2NX:5Oooool00ol0
003oooooooooo`0>ooooo`00SOooool3o`00017oOgmo0ol00004ogmoO`;o00006_oooom5o`WZ2PKo
oooo0_l0000?ooooo`00SOoooolMo`0003;ooooo<ol9jPX2o`0000oooooo000?ooooogoo2NX:00?o
0000o`WZ2_l9jPX05ol9jPX00ol0003o2NX:o`WZ2P0ao`WZ2Pcooooo7_l9jPX9ooooo`03o`000?oo
oooooooo00kooooo002=ooooo`?o00004OmoOgl3o`0000CoOgmo0_l0000UooooobKo2NX:6_ooool0
0ol0003oooooooooo`0>ooooo`00SOooool3o`00017oOgmo0ol00004ogmoO`;o00002ooooolJo`WZ
2PCooooo4Ol9jPX[ooooo`03o`000?oooooooooo00kooooo000?ooooogoo2NX:00?o0000o`WZ2_l9
jPX09?l9jPX=oooooa7o2NX:??ooool00ol0003oooooooooo`0>ooooo`00SOooool00ol0003ooooo
o`00000AogmoO`;o00001_moOgl00ol0003oooooooooo`05oooooa7o2NX:COooool00ol0003ooooo
ooooo`0>ooooo`003ooooomoo`WZ2P03o`000?l9jP[o2NX:023o2NX:G_ooool00ol0003ooooooooo
o`0>ooooo`00SOooool3o`00017oOgmo0ol00004ogmoO`;o0000IOooool00ol0003oooooooooo`0>
ooooo`00SOoooolFo`0000GoOgmo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0>oooo
o`00SOooool00ol0003oooooo`00000AogmoO`;o00001OmoOgl00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo00kooooo002=ooooo`03o`000?oooooo0000017oOgmo0_l00005ogmoO`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool03_ooool008gooooo00?o0000ooooool000004Omo
Ogl2o`0000GoOgmo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0>ooooo`00SOooool0
0ol0003oooooo`00000AogmoO`;o00001OmoOgl00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo00kooooo002=ooooo`03o`000?oooooo0000017oOgmo0_l00004ogmoO`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool03_ooool008gooooo00?o0000ooooool000004OmoOgl2o`0000Co
Ogmo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0>ooooo`00SOooool00ol0003ooooo
o`00000AogmoO`;o00001?moOgl00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00kooooo
002=oooooaKo00000omoOgl00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00kooooo002=
ooooo`;o00004_moOgl2o`0000?oOgmo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0>
ooooo`00SOooool2o`0001;oOgmo0_l00003ogmoO`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool03_ooool008gooooo0_l0000BogmoO`;o00000omoOgl00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo00kooooo002=ooooo`;o00004_moOgl2o`0000;oOgmo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0>ooooo`00SOooool2o`0001;oOgmo0_l00002ogmoO`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool03_ooool008gooooo5_l00002ogmoO`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool03_ooool008gooooo0_l0000BogmoO`;o000000?oOgmoo`00
0?ooool0JOooool00ol0003oooooooooo`0>ooooo`00SOooool2o`0001;oOgmo0_l000000omoOgoo
0000ooooo`1Yooooo`03o`000?oooooooooo00kooooo002=ooooo`;o00004_moOgl2o`000003ogmo
Ool0003ooooo06Wooooo00?o0000ooooooooool03_ooool008gooooo0_l0000BogmoO`?o0000Jooo
ool00ol0003oooooooooo`0>ooooo`00SOoooolGo`0006_ooooo00?o0000ooooooooool03_ooool0
08gooooo00?o0000ogmoOomoOgl04OmoOgl3o`0006_ooooo00?o0000ooooooooool03_ooool008go
oooo00?o0000ogmoOomoOgl04OmoOgl2o`0006cooooo00?o0000ooooooooool03_ooool008gooooo
00?o0000ogmoOomoOgl04OmoOgl2o`0006cooooo00?o0000ooooooooool03_ooool008gooooo5_l0
001/ooooo`03o`000?oooooooooo00kooooo002=oooooaKo0000K?ooool00ol0003oooooooooo`0>
ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.49495 .03036 m
.61563 .03036 L
.5896 .07004 L
.49776 .07004 L
.49495 .03036 L
F
.49776 .07004 m
.5896 .07004 L
.5758 .10972 L
.49944 .10972 L
.49776 .07004 L
F
.49944 .10972 m
.5758 .10972 L
.57143 .1494 L
.5 .1494 L
.49944 .10972 L
F
.5 .1494 m
.57143 .1494 L
.5758 .18909 L
.49944 .18909 L
.5 .1494 L
F
.49944 .18909 m
.5758 .18909 L
.5896 .22877 L
.49776 .22877 L
.49944 .18909 L
F
.49776 .22877 m
.5896 .22877 L
.61563 .26845 L
.49495 .26845 L
.49776 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.49495 .03036 m
.49776 .07004 L
.49944 .10972 L
.5 .1494 L
.49944 .18909 L
.49776 .22877 L
.49495 .26845 L
.61563 .26845 L
.5896 .22877 L
.5758 .18909 L
.57143 .1494 L
.5758 .10972 L
.5896 .07004 L
.61563 .03036 L
.49495 .03036 L
s
.5 g
.49495 .1494 m
.61563 .1494 L
.5896 .1494 L
.49776 .1494 L
.49495 .1494 L
F
.49776 .1494 m
.5896 .1494 L
.5758 .1494 L
.49944 .1494 L
.49776 .1494 L
F
.49944 .1494 m
.5758 .1494 L
.57143 .1494 L
.5 .1494 L
.49944 .1494 L
F
.5 .1494 m
.57143 .1494 L
.5758 .1494 L
.49944 .1494 L
.5 .1494 L
F
.49944 .1494 m
.5758 .1494 L
.5896 .1494 L
.49776 .1494 L
.49944 .1494 L
F
.49776 .1494 m
.5896 .1494 L
.61563 .1494 L
.49495 .1494 L
.49776 .1494 L
F
0 g
.49495 .1494 m
.49776 .1494 L
.49944 .1494 L
.5 .1494 L
.49944 .1494 L
.49776 .1494 L
.49495 .1494 L
.61563 .1494 L
.5896 .1494 L
.5758 .1494 L
.57143 .1494 L
.5758 .1494 L
.5896 .1494 L
.61563 .1494 L
.49495 .1494 L
s
.5 g
.61563 .03036 m
.57649 .03036 L
.58702 .07004 L
.5896 .07004 L
.61563 .03036 L
F
.5896 .07004 m
.58702 .07004 L
.5932 .10972 L
.5758 .10972 L
.5896 .07004 L
F
.5758 .10972 m
.5932 .10972 L
.59524 .1494 L
.57143 .1494 L
.5758 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.5932 .18909 L
.5758 .18909 L
.57143 .1494 L
F
.5758 .18909 m
.5932 .18909 L
.58702 .22877 L
.5896 .22877 L
.5758 .18909 L
F
.5896 .22877 m
.58702 .22877 L
.57649 .26845 L
.61563 .26845 L
.5896 .22877 L
F
0 g
.61563 .03036 m
.5896 .07004 L
.5758 .10972 L
.57143 .1494 L
.5758 .18909 L
.5896 .22877 L
.61563 .26845 L
.57649 .26845 L
.58702 .22877 L
.5932 .18909 L
.59524 .1494 L
.5932 .10972 L
.58702 .07004 L
.57649 .03036 L
.61563 .03036 L
s
.5 g
.61563 .1494 m
.57649 .1494 L
.58702 .1494 L
.5896 .1494 L
.61563 .1494 L
F
.5896 .1494 m
.58702 .1494 L
.5932 .1494 L
.5758 .1494 L
.5896 .1494 L
F
.5758 .1494 m
.5932 .1494 L
.59524 .1494 L
.57143 .1494 L
.5758 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.5932 .1494 L
.5758 .1494 L
.57143 .1494 L
F
.5758 .1494 m
.5932 .1494 L
.58702 .1494 L
.5896 .1494 L
.5758 .1494 L
F
.5896 .1494 m
.58702 .1494 L
.57649 .1494 L
.61563 .1494 L
.5896 .1494 L
F
0 g
.61563 .1494 m
.5896 .1494 L
.5758 .1494 L
.57143 .1494 L
.5758 .1494 L
.5896 .1494 L
.61563 .1494 L
.57649 .1494 L
.58702 .1494 L
.5932 .1494 L
.59524 .1494 L
.5932 .1494 L
.58702 .1494 L
.57649 .1494 L
.61563 .1494 L
s
.49495 .26845 m
.61563 .26845 L
.61563 .2644 L
.49495 .2644 L
.49495 .26845 L
s
.49495 .2644 m
.61563 .2644 L
.61563 .2525 L
.49495 .2525 L
.49495 .2644 L
s
.49495 .2525 m
.61563 .2525 L
.61563 .23358 L
.49495 .23358 L
.49495 .2525 L
s
.49495 .23358 m
.61563 .23358 L
.61563 .20893 L
.49495 .20893 L
.49495 .23358 L
s
.49495 .20893 m
.61563 .20893 L
.61563 .18022 L
.49495 .18022 L
.49495 .20893 L
s
.49495 .18022 m
.61563 .18022 L
.61563 .1494 L
.49495 .1494 L
.49495 .18022 L
s
.49495 .1494 m
.61563 .1494 L
.61563 .11859 L
.49495 .11859 L
.49495 .1494 L
s
.49495 .11859 m
.61563 .11859 L
.61563 .08988 L
.49495 .08988 L
.49495 .11859 L
s
.49495 .08988 m
.61563 .08988 L
.61563 .06523 L
.49495 .06523 L
.49495 .08988 L
s
.49495 .06523 m
.61563 .06523 L
.61563 .04631 L
.49495 .04631 L
.49495 .06523 L
s
.49495 .04631 m
.61563 .04631 L
.61563 .03441 L
.49495 .03441 L
.49495 .04631 L
s
.49495 .03441 m
.61563 .03441 L
.61563 .03036 L
.49495 .03036 L
.49495 .03441 L
s
.49495 .03036 m
.61563 .03036 L
.61563 .03441 L
.49495 .03441 L
.49495 .03036 L
s
.49495 .03441 m
.61563 .03441 L
.61563 .04631 L
.49495 .04631 L
.49495 .03441 L
s
.49495 .04631 m
.61563 .04631 L
.61563 .06523 L
.49495 .06523 L
.49495 .04631 L
s
.49495 .06523 m
.61563 .06523 L
.61563 .08988 L
.49495 .08988 L
.49495 .06523 L
s
.49495 .08988 m
.61563 .08988 L
.61563 .11859 L
.49495 .11859 L
.49495 .08988 L
s
.49495 .11859 m
.61563 .11859 L
.61563 .1494 L
.49495 .1494 L
.49495 .11859 L
s
.49495 .1494 m
.61563 .1494 L
.61563 .18022 L
.49495 .18022 L
.49495 .1494 L
s
.49495 .18022 m
.61563 .18022 L
.61563 .20893 L
.49495 .20893 L
.49495 .18022 L
s
.49495 .20893 m
.61563 .20893 L
.61563 .23358 L
.49495 .23358 L
.49495 .20893 L
s
.49495 .23358 m
.61563 .23358 L
.61563 .2525 L
.49495 .2525 L
.49495 .23358 L
s
.49495 .2525 m
.61563 .2525 L
.61563 .2644 L
.49495 .2644 L
.49495 .2525 L
s
.49495 .2644 m
.61563 .2644 L
.61563 .26845 L
.49495 .26845 L
.49495 .2644 L
s
.61563 .26845 m
.57649 .26845 L
.57649 .2644 L
.61563 .2644 L
.61563 .26845 L
s
.61563 .2644 m
.57649 .2644 L
.57649 .2525 L
.61563 .2525 L
.61563 .2644 L
s
.61563 .2525 m
.57649 .2525 L
.57649 .23358 L
.61563 .23358 L
.61563 .2525 L
s
.61563 .23358 m
.57649 .23358 L
.57649 .20893 L
.61563 .20893 L
.61563 .23358 L
s
.61563 .20893 m
.57649 .20893 L
.57649 .18022 L
.61563 .18022 L
.61563 .20893 L
s
.61563 .18022 m
.57649 .18022 L
.57649 .1494 L
.61563 .1494 L
.61563 .18022 L
s
.61563 .1494 m
.57649 .1494 L
.57649 .11859 L
.61563 .11859 L
.61563 .1494 L
s
.61563 .11859 m
.57649 .11859 L
.57649 .08988 L
.61563 .08988 L
.61563 .11859 L
s
.61563 .08988 m
.57649 .08988 L
.57649 .06523 L
.61563 .06523 L
.61563 .08988 L
s
.61563 .06523 m
.57649 .06523 L
.57649 .04631 L
.61563 .04631 L
.61563 .06523 L
s
.61563 .04631 m
.57649 .04631 L
.57649 .03441 L
.61563 .03441 L
.61563 .04631 L
s
.61563 .03441 m
.57649 .03441 L
.57649 .03036 L
.61563 .03036 L
.61563 .03441 L
s
.61563 .03036 m
.57649 .03036 L
.57649 .03441 L
.61563 .03441 L
.61563 .03036 L
s
.61563 .03441 m
.57649 .03441 L
.57649 .04631 L
.61563 .04631 L
.61563 .03441 L
s
.61563 .04631 m
.57649 .04631 L
.57649 .06523 L
.61563 .06523 L
.61563 .04631 L
s
.61563 .06523 m
.57649 .06523 L
.57649 .08988 L
.61563 .08988 L
.61563 .06523 L
s
.61563 .08988 m
.57649 .08988 L
.57649 .11859 L
.61563 .11859 L
.61563 .08988 L
s
.61563 .11859 m
.57649 .11859 L
.57649 .1494 L
.61563 .1494 L
.61563 .11859 L
s
.61563 .1494 m
.57649 .1494 L
.57649 .18022 L
.61563 .18022 L
.61563 .1494 L
s
.61563 .18022 m
.57649 .18022 L
.57649 .20893 L
.61563 .20893 L
.61563 .18022 L
s
.61563 .20893 m
.57649 .20893 L
.57649 .23358 L
.61563 .23358 L
.61563 .20893 L
s
.61563 .23358 m
.57649 .23358 L
.57649 .2525 L
.61563 .2525 L
.61563 .23358 L
s
.61563 .2525 m
.57649 .2525 L
.57649 .2644 L
.61563 .2644 L
.61563 .2525 L
s
.61563 .2644 m
.57649 .2644 L
.57649 .26845 L
.61563 .26845 L
.61563 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.4998 .1256 L
s
0 0 0 r
2 Mabswid
.4998 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.49993 .13512 L
s
0 0 0 r
2 Mabswid
.49993 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.49999 .14464 L
s
0 0 0 r
2 Mabswid
.49999 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.49999 .15417 L
s
0 0 0 r
2 Mabswid
.49999 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.49993 .16369 L
s
0 0 0 r
2 Mabswid
.49993 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.4998 .17321 L
s
0 0 0 r
2 Mabswid
.4998 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.4998 .1256 m
.57304 .12518 L
s
0 0 0 r
2 Mabswid
.57304 .12518 Mdot
.039 .916 .04 r
.5 Mabswid
.49993 .13512 m
.57201 .13488 L
s
0 0 0 r
2 Mabswid
.57201 .13488 Mdot
.039 .916 .04 r
.5 Mabswid
.49999 .14464 m
.57149 .14456 L
s
0 0 0 r
2 Mabswid
.57149 .14456 Mdot
.039 .916 .04 r
.5 Mabswid
.49999 .15417 m
.57149 .15425 L
s
0 0 0 r
2 Mabswid
.57149 .15425 Mdot
.039 .916 .04 r
.5 Mabswid
.49993 .16369 m
.57201 .16393 L
s
0 0 0 r
2 Mabswid
.57201 .16393 Mdot
.039 .916 .04 r
.5 Mabswid
.4998 .17321 m
.57304 .17363 L
s
0 0 0 r
2 Mabswid
.57304 .17363 Mdot
.039 .916 .04 r
.5 Mabswid
.57304 .12518 m
.5945 .12556 L
s
0 0 0 r
2 Mabswid
.5945 .12556 Mdot
.039 .916 .04 r
.5 Mabswid
.57201 .13488 m
.59497 .13512 L
s
0 0 0 r
2 Mabswid
.59497 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.57149 .14456 m
.59521 .14464 L
s
0 0 0 r
2 Mabswid
.59521 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.57149 .15425 m
.59521 .15416 L
s
0 0 0 r
2 Mabswid
.59521 .15416 Mdot
.039 .916 .04 r
.5 Mabswid
.57201 .16393 m
.59497 .16369 L
s
0 0 0 r
2 Mabswid
.59497 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.57304 .17363 m
.5945 .17325 L
s
0 0 0 r
2 Mabswid
.5945 .17325 Mdot
.039 .916 .04 r
.5 Mabswid
.5945 .12556 m
.97619 .15665 L
s
0 0 0 r
2 Mabswid
.97619 .15665 Mdot
.039 .916 .04 r
.5 Mabswid
.59497 .13512 m
.97619 .1536 L
s
0 0 0 r
2 Mabswid
.97619 .1536 Mdot
.039 .916 .04 r
.5 Mabswid
.59521 .14464 m
.97619 .15078 L
s
0 0 0 r
2 Mabswid
.97619 .15078 Mdot
.039 .916 .04 r
.5 Mabswid
.59521 .15416 m
.97619 .14803 L
s
0 0 0 r
2 Mabswid
.97619 .14803 Mdot
.039 .916 .04 r
.5 Mabswid
.59497 .16369 m
.97619 .14521 L
s
0 0 0 r
2 Mabswid
.97619 .14521 Mdot
.039 .916 .04 r
.5 Mabswid
.5945 .17325 m
.97619 .14216 L
s
0 0 0 r
2 Mabswid
.97619 .14216 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool008kooooo8Ol0001Poooo
o`03o`000?oooooooooo00kooooo002>ooooob7o0000H?ooool00ol0003oooooooooo`0>ooooo`00
S_ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgooOgmo00KoOgmo0_l0001Pooooo`03o`00
0?oooooooooo00kooooo002>ooooo`03o`000?moOgooOgmo01?oOgmo0_l00006ogmoO`03o`000?oo
oooo0000063ooooo00?o0000ooooooooool03_ooool008kooooo8Ol0001Pooooo`03o`000?oooooo
oooo00kooooo002>ooooo`03o`000?moOgooOgmo01?oOgmo0_l00005ogmoO`04o`000?oooooooooo
o`00063ooooo00?o0000ooooooooool03_ooool008kooooo00?o0000ogmoOomoOgl04omoOgl2o`00
00CoOgmo00Go0000ooooooooooooooooo`00001Pooooo`03o`000?oooooooooo00kooooo002>oooo
o`03o`000?moOgooOgmo01?oOgmo0_l00003ogmoO`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0G_ooool00ol0003oooooooooo`0>ooooo`00S_ooool00ol0003oOgmoogmoO`0CogmoO`03
o`000?moOgoo000000;oOgmo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo00kooooo002>ooooob7o0000H?ooool00ol0003oooooooooo`0>ooooo`00S_oo
ool00ol0003oOgmoogmoO`0CogmoO`04o`000?moOgoo0000o`0000Kooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`0>ooooo`00S_ooool00ol0003oOgmoogmoO`0CogmoO`04o`000?mo
Ogoo0000o`0000Kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0>ooooo`00S_oo
ool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgoo000000Oooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0>ooooo`00S_ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?moOgoo
000000Oooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0>ooooo`00S_ooool00ol0
003oOgmoogmoO`0CogmoO`04o`000?moOgoo0000o`0000Kooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0>ooooo`00S_ooool00ol0003oOgmoogmoO`0CogmoO`;o000000?oOgmoo`00
0?ooool01Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00kooooo002>ooooob7o
0000H?ooool00ol0003oooooooooo`0>ooooo`00S_ooool2o`0001CoOgmo0_l000000omoOgoo0000
ooooo`05ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03_ooool008kooooo0_l0
000DogmoO`04o`000?moOgooOgmoo`0000Kooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`0>ooooo`00S_ooool2o`0001CoOgmo00Go0000ogmoOomoOgooOgmoo`000005ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool03_ooool008kooooo0_l0000DogmoO`05o`000?mo
OgooOgmoogmoOol000001Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00kooooo
002>ooooo`;o00004omoOgl2o`0000?oOgmo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo00kooooo002>ooooo`;o00004omoOgl2o`0000?oOgmo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00kooooo002>oooo
ob7o0000H?ooool00ol0003oooooooooo`0>ooooo`00S_ooool2o`0001?oOgmo0_l00003ogmoO`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0>ooooo`00
3ooooomoo`WZ2P03o`000?l9jP[o2NX:017o2NX:00?o0000o`WZ2_l9jPX02_l9jPYPooooo`03o`00
0?oooooooooo00kooooo002>ooooo`;o00004_moOgl3o`0000?oOgmo0_l00004ooooo`03o`000?l9
jP[o2NX:00Wo2NX:EOooool00ol0003oooooooooo`0>ooooo`00S_ooool2o`0001;oOgmo0ol00003
ogmoO`;o00001?ooool00ol0003oooooooooo`09ooooo`co2NX:BOooool00ol0003oooooooooo`0>
ooooo`003ooooomoo`WZ2P03o`000?l9jP[o2NX:01Oo2NX:00?o0000o`WZ2_l9jPX02Ol9jPXBoooo
o`_o2NX:?_ooool00ol0003oooooooooo`0>ooooo`00S_ooool2o`0001;oOgmo00?o0000ogmoOol0
00001?moOgl00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo5Ol9jPX8ooooo`co
2NX:<_ooool2o`0000oooooo000?ooooogoo2NX:00?o0000o`WZ2_l9jPX05ol9jPX00ol0003o2NX:
o`WZ2P0Io`WZ2PGooooo7ol9jPXQooooo`Ko2NX:0_l0000?ooooo`00S_ooool2o`0001;oOgmo0ol0
0003ogmoO`;o00001?ooool00ol0003oooooooooo`0Coooood_o2NX:0_l0000?ooooo`00S_oooolQ
o`0001CoooooC?l9jPX2o`0000oooooo000?ooooogoo2NX:00?o0000o`WZ2_l9jPX05ol9jPX00ol0
003o2NX:o`WZ2P0Ho`WZ2QWooooo5?l9jPX?oooooa3o2NX:0_l0000?ooooo`00S_ooool2o`0001;o
Ogmo0ol00003ogmoO`;o00001?ooool00ol0003oooooooooo`0Goooooa[o2NX::?ooool5o`WZ2P;o
00003oooool008kooooo0_l0000BogmoO`?o00000omoOgl2o`0000Cooooo00?o0000ooooooooool0
0_oooolRo`WZ2S[ooooo00?o0000ooooooooool03_ooool000ooooooOol9jPX00ol0003o2NX:o`WZ
2P0Go`WZ2P03o`000?l9jP[o2NX:00So2NX:2?ooool=o`WZ2TOooooo00?o0000ooooooooool03_oo
ool008kooooo0_l0000BogmoO`03o`000?moOgoo000000CoOgmo00?o0000ooooooooool00_ooool=
o`WZ2UCooooo00?o0000ooooooooool03_ooool000ooooooOol9jPX00ol0003o2NX:o`WZ2P0Ao`WZ
2P03o`000?l9jP[o2NX:00Wo2NX:00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0>oooo
o`00S_ooool2o`0001;oOgmo0ol00003ogmoO`;o00001?ooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo00kooooo002>ooooob7o0000H?ooool00ol0003oooooooooo`0>ooooo`00S_oo
ool2o`0001?oOgmo0_l00003ogmoO`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0>ooooo`00S_ooool2o`0001?oOgmo0_l00003ogmoO`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0>ooooo`00S_ooool2o`00
01?oOgmo0_l00003ogmoO`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`0>ooooo`00S_ooool2o`0001CoOgmo00Go0000ogmoOomoOgooOgmoo`000005oooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool03_ooool008kooooo0_l0000DogmoO`05
o`000?moOgooOgmoogmoOol000001Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
00kooooo002>ooooo`;o00005?moOgl01?l0003oOgmoogmoOol00006ooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool03_ooool008kooooo0_l0000DogmoO`;o000000?oOgmoo`000?oo
ool01Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00kooooo002>ooooob7o0000
H?ooool00ol0003oooooooooo`0>ooooo`00S_ooool00ol0003oOgmoogmoO`0CogmoO`;o000000?o
Ogmoo`000?ooool01Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00kooooo002>
ooooo`03o`000?moOgooOgmo01?oOgmo00Co0000ogmoOol0003o00001_ooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo00kooooo002>ooooo`03o`000?moOgooOgmo01?oOgmo00?o0000
ogmoOol000001oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00kooooo002>oooo
o`03o`000?moOgooOgmo01?oOgmo00?o0000ogmoOol000001oooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo00kooooo002>ooooo`03o`000?moOgooOgmo01?oOgmo00Co0000ogmoOol0
003o00001_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00kooooo002>ooooob7o
0000H?ooool00ol0003oooooooooo`0>ooooo`00S_ooool00ol0003oOgmoogmoO`0CogmoO`05o`00
0?moOgoo0000ogmoOol000001Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00ko
oooo002>ooooo`03o`000?moOgooOgmo01?oOgmo00?o0000ogmoOol000000_moOgl00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03_ooool008kooooo00?o
0000ogmoOomoOgl04omoOgl2o`0000?oOgmo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo00kooooo002>ooooo`03o`000?moOgooOgmo01?oOgmo0_l00004
ogmoO`05o`000?ooooooooooooooool00000H?ooool00ol0003oooooooooo`0>ooooo`00S_oooolQ
o`00063ooooo00?o0000ooooooooool03_ooool008kooooo00?o0000ogmoOomoOgl04omoOgl2o`00
00GoOgmo00Co0000oooooooooooo0000H?ooool00ol0003oooooooooo`0>ooooo`00S_ooool00ol0
003oOgmoogmoO`0CogmoO`;o00001_moOgl00ol0003oooooo`00001Pooooo`03o`000?oooooooooo
00kooooo002>ooooo`03o`000?moOgooOgmo01?oOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003o
ooooo`00001Pooooo`03o`000?oooooooooo00kooooo002>ooooob7o0000H?ooool00ol0003ooooo
ooooo`0>ooooo`00S_oooolQo`00063ooooo00?o0000ooooooooool03_ooool00?oooooo8Oooool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.50638 .03036 m
.61243 .07004 L
.50283 .07004 L
.50638 .03036 L
F
.50283 .07004 m
.61243 .07004 L
.57989 .10972 L
.50071 .10972 L
.50283 .07004 L
F
.50071 .10972 m
.57989 .10972 L
.57143 .1494 L
.5 .1494 L
.50071 .10972 L
F
.5 .1494 m
.57143 .1494 L
.57989 .18909 L
.50071 .18909 L
.5 .1494 L
F
.50071 .18909 m
.57989 .18909 L
.61243 .22877 L
.50283 .22877 L
.50071 .18909 L
F
.50283 .22877 m
.61243 .22877 L
.50638 .26845 L
.50283 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.50638 .03036 m
.50283 .07004 L
.50071 .10972 L
.5 .1494 L
.50071 .18909 L
.50283 .22877 L
.50638 .26845 L
s
.61243 .22877 m
.57989 .18909 L
.57143 .1494 L
.57989 .10972 L
.61243 .07004 L
s
.50638 .03036 m
0 0 rlineto s
.5 g
.50638 .1494 m
.61243 .1494 L
.50283 .1494 L
.50638 .1494 L
F
.50283 .1494 m
.61243 .1494 L
.57989 .1494 L
.50071 .1494 L
.50283 .1494 L
F
.50071 .1494 m
.57989 .1494 L
.57143 .1494 L
.5 .1494 L
.50071 .1494 L
F
.5 .1494 m
.57143 .1494 L
.57989 .1494 L
.50071 .1494 L
.5 .1494 L
F
.50071 .1494 m
.57989 .1494 L
.61243 .1494 L
.50283 .1494 L
.50071 .1494 L
F
.50283 .1494 m
.61243 .1494 L
.50638 .1494 L
.50283 .1494 L
F
0 g
.50638 .1494 m
.50283 .1494 L
.50071 .1494 L
.5 .1494 L
.50071 .1494 L
.50283 .1494 L
.50638 .1494 L
s
.61243 .1494 m
.57989 .1494 L
.57143 .1494 L
.57989 .1494 L
.61243 .1494 L
s
.50638 .1494 m
0 0 rlineto s
.5 g
.59754 .03036 m
.59626 .07004 L
.61243 .07004 L
F
.61243 .07004 m
.59626 .07004 L
.59549 .10972 L
.57989 .10972 L
.61243 .07004 L
F
.57989 .10972 m
.59549 .10972 L
.59524 .1494 L
.57143 .1494 L
.57989 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59549 .18909 L
.57989 .18909 L
.57143 .1494 L
F
.57989 .18909 m
.59549 .18909 L
.59626 .22877 L
.61243 .22877 L
.57989 .18909 L
F
.61243 .22877 m
.59626 .22877 L
.59754 .26845 L
.61243 .22877 L
F
0 g
.61243 .07004 m
.57989 .10972 L
.57143 .1494 L
.57989 .18909 L
.61243 .22877 L
s
.59754 .26845 m
.59626 .22877 L
.59549 .18909 L
.59524 .1494 L
.59549 .10972 L
.59626 .07004 L
.59754 .03036 L
s
.5 g
.59754 .1494 m
.59626 .1494 L
.61243 .1494 L
F
.61243 .1494 m
.59626 .1494 L
.59549 .1494 L
.57989 .1494 L
.61243 .1494 L
F
.57989 .1494 m
.59549 .1494 L
.59524 .1494 L
.57143 .1494 L
.57989 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59549 .1494 L
.57989 .1494 L
.57143 .1494 L
F
.57989 .1494 m
.59549 .1494 L
.59626 .1494 L
.61243 .1494 L
.57989 .1494 L
F
.61243 .1494 m
.59626 .1494 L
.59754 .1494 L
.61243 .1494 L
F
0 g
.61243 .1494 m
.57989 .1494 L
.57143 .1494 L
.57989 .1494 L
.61243 .1494 L
s
.59754 .1494 m
.59626 .1494 L
.59549 .1494 L
.59524 .1494 L
.59549 .1494 L
.59626 .1494 L
.59754 .1494 L
s
.50638 .26845 m
0 0 rlineto s
.50638 .2644 m
.50638 .26845 L
s
.50638 .2644 m
0 0 rlineto s
.50638 .2525 m
.50638 .2644 L
s
.50638 .2525 m
0 0 rlineto s
.50638 .23358 m
.50638 .2525 L
s
.50638 .23358 m
0 0 rlineto s
.50638 .20893 m
.50638 .23358 L
s
.50638 .20893 m
0 0 rlineto s
.50638 .18022 m
.50638 .20893 L
s
.50638 .18022 m
0 0 rlineto s
.50638 .1494 m
.50638 .18022 L
s
.50638 .1494 m
0 0 rlineto s
.50638 .11859 m
.50638 .1494 L
s
.50638 .11859 m
0 0 rlineto s
.50638 .08988 m
.50638 .11859 L
s
.50638 .08988 m
0 0 rlineto s
.50638 .06523 m
.50638 .08988 L
s
.50638 .06523 m
0 0 rlineto s
.50638 .04631 m
.50638 .06523 L
s
.50638 .04631 m
0 0 rlineto s
.50638 .03441 m
.50638 .04631 L
s
.50638 .03441 m
0 0 rlineto s
.50638 .03036 m
.50638 .03441 L
s
.50638 .03036 m
0 0 rlineto s
.50638 .03441 m
.50638 .03036 L
s
.50638 .03441 m
0 0 rlineto s
.50638 .04631 m
.50638 .03441 L
s
.50638 .04631 m
0 0 rlineto s
.50638 .06523 m
.50638 .04631 L
s
.50638 .06523 m
0 0 rlineto s
.50638 .08988 m
.50638 .06523 L
s
.50638 .08988 m
0 0 rlineto s
.50638 .11859 m
.50638 .08988 L
s
.50638 .11859 m
0 0 rlineto s
.50638 .1494 m
.50638 .11859 L
s
.50638 .1494 m
0 0 rlineto s
.50638 .18022 m
.50638 .1494 L
s
.50638 .18022 m
0 0 rlineto s
.50638 .20893 m
.50638 .18022 L
s
.50638 .20893 m
0 0 rlineto s
.50638 .23358 m
.50638 .20893 L
s
.50638 .23358 m
0 0 rlineto s
.50638 .2525 m
.50638 .23358 L
s
.50638 .2525 m
0 0 rlineto s
.50638 .2644 m
.50638 .2525 L
s
.50638 .2644 m
0 0 rlineto s
.50638 .26845 m
.50638 .2644 L
s
.59754 .26845 m
.59754 .2644 L
s
.59754 .2644 m
.59754 .2525 L
s
.59754 .2525 m
.59754 .23358 L
s
.59754 .23358 m
.59754 .20893 L
s
.59754 .20893 m
.59754 .18022 L
s
.59754 .18022 m
.59754 .1494 L
s
.59754 .1494 m
.59754 .11859 L
s
.59754 .11859 m
.59754 .08988 L
s
.59754 .08988 m
.59754 .06523 L
s
.59754 .06523 m
.59754 .04631 L
s
.59754 .04631 m
.59754 .03441 L
s
.59754 .03441 m
.59754 .03036 L
s
.59754 .03036 m
.59754 .03441 L
s
.59754 .03441 m
.59754 .04631 L
s
.59754 .04631 m
.59754 .06523 L
s
.59754 .06523 m
.59754 .08988 L
s
.59754 .08988 m
.59754 .11859 L
s
.59754 .11859 m
.59754 .1494 L
s
.59754 .1494 m
.59754 .18022 L
s
.59754 .18022 m
.59754 .20893 L
s
.59754 .20893 m
.59754 .23358 L
s
.59754 .23358 m
.59754 .2525 L
s
.59754 .2525 m
.59754 .2644 L
s
.59754 .2644 m
.59754 .26845 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.50025 .1256 L
s
0 0 0 r
2 Mabswid
.50025 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.50009 .13512 L
s
0 0 0 r
2 Mabswid
.50009 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.50001 .14464 L
s
0 0 0 r
2 Mabswid
.50001 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.50001 .15417 L
s
0 0 0 r
2 Mabswid
.50001 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.50009 .16369 L
s
0 0 0 r
2 Mabswid
.50009 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.50025 .17321 L
s
0 0 0 r
2 Mabswid
.50025 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.50025 .1256 m
.57425 .12612 L
s
0 0 0 r
2 Mabswid
.57425 .12612 Mdot
.039 .916 .04 r
.5 Mabswid
.50009 .13512 m
.57244 .13543 L
s
0 0 0 r
2 Mabswid
.57244 .13543 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .14464 m
.57154 .14474 L
s
0 0 0 r
2 Mabswid
.57154 .14474 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .15417 m
.57154 .15406 L
s
0 0 0 r
2 Mabswid
.57154 .15406 Mdot
.039 .916 .04 r
.5 Mabswid
.50009 .16369 m
.57244 .16338 L
s
0 0 0 r
2 Mabswid
.57244 .16338 Mdot
.039 .916 .04 r
.5 Mabswid
.50025 .17321 m
.57425 .17269 L
s
0 0 0 r
2 Mabswid
.57425 .17269 Mdot
.039 .916 .04 r
.5 Mabswid
.57425 .12612 m
.59532 .12711 L
s
0 0 0 r
2 Mabswid
.59532 .12711 Mdot
.039 .916 .04 r
.5 Mabswid
.57244 .13543 m
.59527 .13606 L
s
0 0 0 r
2 Mabswid
.59527 .13606 Mdot
.039 .916 .04 r
.5 Mabswid
.57154 .14474 m
.59524 .14496 L
s
0 0 0 r
2 Mabswid
.59524 .14496 Mdot
.039 .916 .04 r
.5 Mabswid
.57154 .15406 m
.59524 .15385 L
s
0 0 0 r
2 Mabswid
.59524 .15385 Mdot
.039 .916 .04 r
.5 Mabswid
.57244 .16338 m
.59527 .16275 L
s
0 0 0 r
2 Mabswid
.59527 .16275 Mdot
.039 .916 .04 r
.5 Mabswid
.57425 .17269 m
.59532 .1717 L
s
0 0 0 r
2 Mabswid
.59532 .1717 Mdot
.039 .916 .04 r
.5 Mabswid
.59532 .12711 m
.97619 .15703 L
s
0 0 0 r
2 Mabswid
.97619 .15703 Mdot
.039 .916 .04 r
.5 Mabswid
.59527 .13606 m
.97619 .15375 L
s
0 0 0 r
2 Mabswid
.97619 .15375 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .14496 m
.97619 .15081 L
s
0 0 0 r
2 Mabswid
.97619 .15081 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .15385 m
.97619 .148 L
s
0 0 0 r
2 Mabswid
.97619 .148 Mdot
.039 .916 .04 r
.5 Mabswid
.59527 .16275 m
.97619 .14506 L
s
0 0 0 r
2 Mabswid
.97619 .14506 Mdot
.039 .916 .04 r
.5 Mabswid
.59532 .1717 m
.97619 .14178 L
s
0 0 0 r
2 Mabswid
.97619 .14178 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo002Aooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool03_ooool0
097ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
00kooooo002Aooooo`03o`000?moOgoooooo01Gooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`0>ooooo`00TOooool00ol0003oOgmoogmoO`02ogmoOa?ooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0>ooooo`00TOooool00ol0003oOgmoogmoO`05ogmoOa3ooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`0>ooooo`00TOooool00ol0003oOgmoogmoO`08
ogmoO`gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0>ooooo`00TOooool00ol0
003oOgmoogmoO`0;ogmoO`[ooooo00?o0000ogmoOoooool0Hoooool00ol0003oooooooooo`0>oooo
o`00T?ooool2o`0000ooOgmo2?ooool00ol0003oOgmoooooo`1Sooooo`03o`000?oooooooooo00ko
oooo002@ooooo`;o00004_moOgl5ooooo`03o`000?moOgooOgmo06?ooooo00?o0000ooooooooool0
3_ooool0093ooooo0_l0000EogmoO`;ooooo00?o0000ogmoOomoOgl0Hoooool00ol0003ooooooooo
o`0>ooooo`00T?ooool2o`0001OoOgmo00?o0000ogmoOomoOgl0Hoooool00ol0003oooooooooo`0>
ooooo`00T?ooool2o`0001OoOgmo00Go0000ogmoOomoOgooOgmoo`00001Qooooo`03o`000?oooooo
oooo00kooooo002@ooooo`;o00005omoOgl01Ol0003oOgmoogmoOomoOgoo0000067ooooo00?o0000
ooooooooool03_ooool0093ooooo0_l0000GogmoO`04o`000?moOgooOgmoo`0006;ooooo00?o0000
ooooooooool03_ooool0093ooooo0_l0000GogmoO`03o`000?moOgoo000006?ooooo00?o0000oooo
ooooool03_ooool0093ooooo0_l0000GogmoO`;o0000I?ooool00ol0003oooooooooo`0>ooooo`00
T?ooool2o`0001OoOgmo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0>ooooo`00Sooo
ool00ol0003oOgmoo`00000FogmoO`;o0000IOooool00ol0003oooooooooo`0>ooooo`00Soooool0
0ol0003oOgmoo`00000FogmoO`;o0000IOooool00ol0003oooooooooo`0>ooooo`00Soooool00ol0
003oOgmoo`00000EogmoO`03o`000?moOgoo000006Gooooo00?o0000ooooooooool03_ooool008oo
oooo00?o0000ogmoOol000005?moOgl01?l0003oOgmoogmoOol0001Uooooo`03o`000?oooooooooo
00kooooo002?ooooo`03o`000?moOgoo000001?oOgmo00Go0000ogmoOomoOgooOgmoo`00001Uoooo
o`03o`000?oooooooooo00kooooo002?ooooo`03o`000?moOgoo000001;oOgmo00?o0000ogmoOomo
Ogl00_moOgl00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00kooooo002?ooooo`03o`00
0?moOgoo000001;oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo00kooooo002?ooooo`03o`000?moOgoo000001;oOgmo00?o0000ogmoOomoOgl00_mo
Ogl00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00kooooo002?ooooo`03o`000?moOgoo
000001;oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo00kooooo000?oooooi?o2NX:00?o0000o`WZ2_l9jPX00_l9jPX00omoOgoo0000o`00001Uoooo
o`03o`000?oooooooooo00kooooo002?ooooo`?o00004?moOgl2o`0000?oOgmo00?o2NX:o`000?l9
jPX01_l9jPYOooooo`03o`000?oooooooooo00kooooo002?ooooo`?o00004?moOgl2o`0000GoOgmo
00?o0000ooooooooool01?ooool=o`WZ2U;ooooo00?o0000ooooooooool03_ooool000ooooooVOl9
jPX00ol0003o2NX:o`WZ2P09o`WZ2PWooooo3Ol9jPY5ooooo`03o`000?oooooooooo00kooooo002?
ooooo`03o`000?moOgoo0000017oOgmo00?o0000ogmoOomoOgl00_moOgl2o`0000[ooooo5Ol9jPX0
0ooooooo2NX:o`WZ2P0;o`WZ2SSooooo0_l0000?ooooo`003ooooonHo`WZ2P03ogmoOol0003o0000
01oooooo6_l9jPXVooooo`Ko2NX:0_l0000?ooooo`00Soooool3o`00013oOgmo0_l00003ogmoO`03
o`WZ2_l0003o2NX:04Oo2NX:1OoooolIo`WZ2P;o00003oooool008oooooo0ol0000@ogmoO`co0000
5Ooooom<o`WZ2P;o00003oooool000ooooooVOl9jPX00ol0003o2NX:o`WZ2P0Ho`WZ2Pcooooo8?l9
jPX>oooooa;o2NX:0_l0000?ooooo`00Soooool3o`00013oOgmo00?o0000ogmoOomoOgl01?moOgl0
0ol0003oooooooooo`0:oooooaWo2NX:1oooool<o`WZ2RSooooo1Ol9jPX2o`0000oooooo002?oooo
o`?o00001omoOgl?o`WZ2P03o`000?l9jP[o2NX:00_o2NX:4oooool=o`WZ2SWooooo00?o0000oooo
ooooool03_ooool000ooooooR_l9jPX9ogmoO`;o00001?moOgl2o`0001;ooooo3Ol9jPY6ooooo`03
o`000?oooooooooo00kooooo002?ooooo`03o`000?moOgoo0000013oOgmo0_l00004ogmoO`;o0000
1Oooool=o`WZ2U?ooooo00?o0000ooooooooool03_ooool000ooooooTol9jPX00ol0003o2NX:o`WZ
2P03o`WZ2P03o`000?l9jP[o2NX:00Co2NX:H?ooool00ol0003oooooooooo`0>ooooo`00Soooool3
o`00017oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo00kooooo002?ooooo`03o`000?moOgoo000001;oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo00kooooo002?ooooo`03o`000?moOgoo000001;o
Ogmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00ko
oooo002?ooooo`03o`000?moOgoo000001;oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo00kooooo002?ooooo`03o`000?moOgoo000001;oOgmo00?o
0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00kooooo002?
ooooo`03o`000?moOgoo000001?oOgmo00Go0000ogmoOomoOgooOgmoo`00001Uooooo`03o`000?oo
oooooooo00kooooo002?ooooo`03o`000?moOgoo000001CoOgmo00Co0000ogmoOomoOgoo0000IOoo
ool00ol0003oooooooooo`0>ooooo`00Soooool00ol0003oOgmoo`00000EogmoO`03o`000?moOgoo
000006Gooooo00?o0000ooooooooool03_ooool008oooooo00?o0000ogmoOol000005_moOgl2o`00
06Gooooo00?o0000ooooooooool03_ooool0093ooooo0_l0000GogmoO`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool03_ooool0093ooooo0_l0000GogmoO`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool03_ooool0093ooooo0_l0000GogmoO`;o0000I?ooool00ol0003ooooooooo
o`0>ooooo`00T?ooool2o`0001OoOgmo00?o0000ogmoOol00000Hoooool00ol0003oooooooooo`0>
ooooo`00T?ooool2o`0001OoOgmo00Co0000ogmoOomoOgoo0000H_ooool00ol0003oooooooooo`0>
ooooo`00T?ooool2o`0001OoOgmo00Go0000ogmoOomoOgooOgmoo`00001Qooooo`03o`000?oooooo
oooo00kooooo002@ooooo`;o00005omoOgl01?l0003oOgmoogmoOomoOgmRooooo`03o`000?oooooo
oooo00kooooo002@ooooo`;o00005omoOgl01?l0003oOgmoogmoOomoOgmRooooo`03o`000?oooooo
oooo00kooooo002@ooooo`;o00005OmoOgl2ooooo`03o`000?moOgooOgmo06?ooooo00?o0000oooo
ooooool03_ooool0093ooooo0_l0000BogmoO`Gooooo00?o0000ogmoOomoOgl0Hoooool00ol0003o
ooooooooo`0>ooooo`00T?ooool2o`00013oOgmo1oooool00ol0003oOgmoogmoO`1Sooooo`03o`00
0?oooooooooo00kooooo002Aooooo`03o`000?moOgooOgmo00_oOgmo2_ooool00ol0003oOgmooooo
o`1Sooooo`03o`000?oooooooooo00kooooo002Aooooo`03o`000?moOgooOgmo00SoOgmo3Oooool0
0ol0003oOgmoooooo`1Sooooo`03o`000?oooooooooo00kooooo002Aooooo`03o`000?moOgooOgmo
00KoOgmo3oooool00ol0003oOgmoooooo`1Sooooo`03o`000?oooooooooo00kooooo002Aooooo`03
o`000?moOgooOgmo00?oOgmo4_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00ko
oooo002Aooooo`04o`000?moOgooOgmoogmoOaCooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`0>ooooo`00TOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool03_ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.50779 .03036 m
.57208 .03036 L
.57172 .07004 L
.50345 .07004 L
.50779 .03036 L
F
.50345 .07004 m
.57172 .07004 L
.5715 .10972 L
.50086 .10972 L
.50345 .07004 L
F
.50086 .10972 m
.5715 .10972 L
.57143 .1494 L
.5 .1494 L
.50086 .10972 L
F
.5 .1494 m
.57143 .1494 L
.5715 .18909 L
.50086 .18909 L
.5 .1494 L
F
.50086 .18909 m
.5715 .18909 L
.57172 .22877 L
.50345 .22877 L
.50086 .18909 L
F
.50345 .22877 m
.57172 .22877 L
.57208 .26845 L
.50779 .26845 L
.50345 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.50779 .03036 m
.50345 .07004 L
.50086 .10972 L
.5 .1494 L
.50086 .18909 L
.50345 .22877 L
.50779 .26845 L
.57208 .26845 L
.57172 .22877 L
.5715 .18909 L
.57143 .1494 L
.5715 .10972 L
.57172 .07004 L
.57208 .03036 L
.50779 .03036 L
s
.5 g
.50779 .1494 m
.57208 .1494 L
.57172 .1494 L
.50345 .1494 L
.50779 .1494 L
F
.50345 .1494 m
.57172 .1494 L
.5715 .1494 L
.50086 .1494 L
.50345 .1494 L
F
.50086 .1494 m
.5715 .1494 L
.57143 .1494 L
.5 .1494 L
.50086 .1494 L
F
.5 .1494 m
.57143 .1494 L
.5715 .1494 L
.50086 .1494 L
.5 .1494 L
F
.50086 .1494 m
.5715 .1494 L
.57172 .1494 L
.50345 .1494 L
.50086 .1494 L
F
.50345 .1494 m
.57172 .1494 L
.57208 .1494 L
.50779 .1494 L
.50345 .1494 L
F
0 g
.50779 .1494 m
.50345 .1494 L
.50086 .1494 L
.5 .1494 L
.50086 .1494 L
.50345 .1494 L
.50779 .1494 L
.57208 .1494 L
.57172 .1494 L
.5715 .1494 L
.57143 .1494 L
.5715 .1494 L
.57172 .1494 L
.57208 .1494 L
.50779 .1494 L
s
.5 g
.57208 .03036 m
.57689 .03036 L
.58719 .07004 L
.57172 .07004 L
.57208 .03036 L
F
.57172 .07004 m
.58719 .07004 L
.59324 .10972 L
.5715 .10972 L
.57172 .07004 L
F
.5715 .10972 m
.59324 .10972 L
.59524 .1494 L
.57143 .1494 L
.5715 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59324 .18909 L
.5715 .18909 L
.57143 .1494 L
F
.5715 .18909 m
.59324 .18909 L
.58719 .22877 L
.57172 .22877 L
.5715 .18909 L
F
.57172 .22877 m
.58719 .22877 L
.57689 .26845 L
.57208 .26845 L
.57172 .22877 L
F
0 g
.57208 .03036 m
.57172 .07004 L
.5715 .10972 L
.57143 .1494 L
.5715 .18909 L
.57172 .22877 L
.57208 .26845 L
.57689 .26845 L
.58719 .22877 L
.59324 .18909 L
.59524 .1494 L
.59324 .10972 L
.58719 .07004 L
.57689 .03036 L
.57208 .03036 L
s
.5 g
.57208 .1494 m
.57689 .1494 L
.58719 .1494 L
.57172 .1494 L
.57208 .1494 L
F
.57172 .1494 m
.58719 .1494 L
.59324 .1494 L
.5715 .1494 L
.57172 .1494 L
F
.5715 .1494 m
.59324 .1494 L
.59524 .1494 L
.57143 .1494 L
.5715 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59324 .1494 L
.5715 .1494 L
.57143 .1494 L
F
.5715 .1494 m
.59324 .1494 L
.58719 .1494 L
.57172 .1494 L
.5715 .1494 L
F
.57172 .1494 m
.58719 .1494 L
.57689 .1494 L
.57208 .1494 L
.57172 .1494 L
F
0 g
.57208 .1494 m
.57172 .1494 L
.5715 .1494 L
.57143 .1494 L
.5715 .1494 L
.57172 .1494 L
.57208 .1494 L
.57689 .1494 L
.58719 .1494 L
.59324 .1494 L
.59524 .1494 L
.59324 .1494 L
.58719 .1494 L
.57689 .1494 L
.57208 .1494 L
s
.50779 .26845 m
.57208 .26845 L
.57208 .2644 L
.50779 .2644 L
.50779 .26845 L
s
.50779 .2644 m
.57208 .2644 L
.57208 .2525 L
.50779 .2525 L
.50779 .2644 L
s
.50779 .2525 m
.57208 .2525 L
.57208 .23358 L
.50779 .23358 L
.50779 .2525 L
s
.50779 .23358 m
.57208 .23358 L
.57208 .20893 L
.50779 .20893 L
.50779 .23358 L
s
.50779 .20893 m
.57208 .20893 L
.57208 .18022 L
.50779 .18022 L
.50779 .20893 L
s
.50779 .18022 m
.57208 .18022 L
.57208 .1494 L
.50779 .1494 L
.50779 .18022 L
s
.50779 .1494 m
.57208 .1494 L
.57208 .11859 L
.50779 .11859 L
.50779 .1494 L
s
.50779 .11859 m
.57208 .11859 L
.57208 .08988 L
.50779 .08988 L
.50779 .11859 L
s
.50779 .08988 m
.57208 .08988 L
.57208 .06523 L
.50779 .06523 L
.50779 .08988 L
s
.50779 .06523 m
.57208 .06523 L
.57208 .04631 L
.50779 .04631 L
.50779 .06523 L
s
.50779 .04631 m
.57208 .04631 L
.57208 .03441 L
.50779 .03441 L
.50779 .04631 L
s
.50779 .03441 m
.57208 .03441 L
.57208 .03036 L
.50779 .03036 L
.50779 .03441 L
s
.50779 .03036 m
.57208 .03036 L
.57208 .03441 L
.50779 .03441 L
.50779 .03036 L
s
.50779 .03441 m
.57208 .03441 L
.57208 .04631 L
.50779 .04631 L
.50779 .03441 L
s
.50779 .04631 m
.57208 .04631 L
.57208 .06523 L
.50779 .06523 L
.50779 .04631 L
s
.50779 .06523 m
.57208 .06523 L
.57208 .08988 L
.50779 .08988 L
.50779 .06523 L
s
.50779 .08988 m
.57208 .08988 L
.57208 .11859 L
.50779 .11859 L
.50779 .08988 L
s
.50779 .11859 m
.57208 .11859 L
.57208 .1494 L
.50779 .1494 L
.50779 .11859 L
s
.50779 .1494 m
.57208 .1494 L
.57208 .18022 L
.50779 .18022 L
.50779 .1494 L
s
.50779 .18022 m
.57208 .18022 L
.57208 .20893 L
.50779 .20893 L
.50779 .18022 L
s
.50779 .20893 m
.57208 .20893 L
.57208 .23358 L
.50779 .23358 L
.50779 .20893 L
s
.50779 .23358 m
.57208 .23358 L
.57208 .2525 L
.50779 .2525 L
.50779 .23358 L
s
.50779 .2525 m
.57208 .2525 L
.57208 .2644 L
.50779 .2644 L
.50779 .2525 L
s
.50779 .2644 m
.57208 .2644 L
.57208 .26845 L
.50779 .26845 L
.50779 .2644 L
s
.57208 .26845 m
.57689 .26845 L
.57689 .2644 L
.57208 .2644 L
.57208 .26845 L
s
.57208 .2644 m
.57689 .2644 L
.57689 .2525 L
.57208 .2525 L
.57208 .2644 L
s
.57208 .2525 m
.57689 .2525 L
.57689 .23358 L
.57208 .23358 L
.57208 .2525 L
s
.57208 .23358 m
.57689 .23358 L
.57689 .20893 L
.57208 .20893 L
.57208 .23358 L
s
.57208 .20893 m
.57689 .20893 L
.57689 .18022 L
.57208 .18022 L
.57208 .20893 L
s
.57208 .18022 m
.57689 .18022 L
.57689 .1494 L
.57208 .1494 L
.57208 .18022 L
s
.57208 .1494 m
.57689 .1494 L
.57689 .11859 L
.57208 .11859 L
.57208 .1494 L
s
.57208 .11859 m
.57689 .11859 L
.57689 .08988 L
.57208 .08988 L
.57208 .11859 L
s
.57208 .08988 m
.57689 .08988 L
.57689 .06523 L
.57208 .06523 L
.57208 .08988 L
s
.57208 .06523 m
.57689 .06523 L
.57689 .04631 L
.57208 .04631 L
.57208 .06523 L
s
.57208 .04631 m
.57689 .04631 L
.57689 .03441 L
.57208 .03441 L
.57208 .04631 L
s
.57208 .03441 m
.57689 .03441 L
.57689 .03036 L
.57208 .03036 L
.57208 .03441 L
s
.57208 .03036 m
.57689 .03036 L
.57689 .03441 L
.57208 .03441 L
.57208 .03036 L
s
.57208 .03441 m
.57689 .03441 L
.57689 .04631 L
.57208 .04631 L
.57208 .03441 L
s
.57208 .04631 m
.57689 .04631 L
.57689 .06523 L
.57208 .06523 L
.57208 .04631 L
s
.57208 .06523 m
.57689 .06523 L
.57689 .08988 L
.57208 .08988 L
.57208 .06523 L
s
.57208 .08988 m
.57689 .08988 L
.57689 .11859 L
.57208 .11859 L
.57208 .08988 L
s
.57208 .11859 m
.57689 .11859 L
.57689 .1494 L
.57208 .1494 L
.57208 .11859 L
s
.57208 .1494 m
.57689 .1494 L
.57689 .18022 L
.57208 .18022 L
.57208 .1494 L
s
.57208 .18022 m
.57689 .18022 L
.57689 .20893 L
.57208 .20893 L
.57208 .18022 L
s
.57208 .20893 m
.57689 .20893 L
.57689 .23358 L
.57208 .23358 L
.57208 .20893 L
s
.57208 .23358 m
.57689 .23358 L
.57689 .2525 L
.57208 .2525 L
.57208 .23358 L
s
.57208 .2525 m
.57689 .2525 L
.57689 .2644 L
.57208 .2644 L
.57208 .2525 L
s
.57208 .2644 m
.57689 .2644 L
.57689 .26845 L
.57208 .26845 L
.57208 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.50031 .1256 L
s
0 0 0 r
2 Mabswid
.50031 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.50011 .13512 L
s
0 0 0 r
2 Mabswid
.50011 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.50001 .14464 L
s
0 0 0 r
2 Mabswid
.50001 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.50001 .15417 L
s
0 0 0 r
2 Mabswid
.50001 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.50011 .16369 L
s
0 0 0 r
2 Mabswid
.50011 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.50031 .17321 L
s
0 0 0 r
2 Mabswid
.50031 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.50031 .1256 m
.57145 .12621 L
s
0 0 0 r
2 Mabswid
.57145 .12621 Mdot
.039 .916 .04 r
.5 Mabswid
.50011 .13512 m
.57144 .13549 L
s
0 0 0 r
2 Mabswid
.57144 .13549 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .14464 m
.57143 .14477 L
s
0 0 0 r
2 Mabswid
.57143 .14477 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .15417 m
.57143 .15404 L
s
0 0 0 r
2 Mabswid
.57143 .15404 Mdot
.039 .916 .04 r
.5 Mabswid
.50011 .16369 m
.57144 .16332 L
s
0 0 0 r
2 Mabswid
.57144 .16332 Mdot
.039 .916 .04 r
.5 Mabswid
.50031 .17321 m
.57145 .1726 L
s
0 0 0 r
2 Mabswid
.57145 .1726 Mdot
.039 .916 .04 r
.5 Mabswid
.57145 .12621 m
.59457 .12639 L
s
0 0 0 r
2 Mabswid
.59457 .12639 Mdot
.039 .916 .04 r
.5 Mabswid
.57144 .13549 m
.595 .1356 L
s
0 0 0 r
2 Mabswid
.595 .1356 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .14477 m
.59521 .1448 L
s
0 0 0 r
2 Mabswid
.59521 .1448 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .15404 m
.59521 .15401 L
s
0 0 0 r
2 Mabswid
.59521 .15401 Mdot
.039 .916 .04 r
.5 Mabswid
.57144 .16332 m
.595 .16321 L
s
0 0 0 r
2 Mabswid
.595 .16321 Mdot
.039 .916 .04 r
.5 Mabswid
.57145 .1726 m
.59457 .17242 L
s
0 0 0 r
2 Mabswid
.59457 .17242 Mdot
.039 .916 .04 r
.5 Mabswid
.59457 .12639 m
.97619 .14948 L
s
0 0 0 r
2 Mabswid
.97619 .14948 Mdot
.039 .916 .04 r
.5 Mabswid
.595 .1356 m
.97619 .14939 L
s
0 0 0 r
2 Mabswid
.97619 .14939 Mdot
.039 .916 .04 r
.5 Mabswid
.59521 .1448 m
.97619 .14939 L
s
0 0 0 r
2 Mabswid
.97619 .14939 Mdot
.039 .916 .04 r
.5 Mabswid
.59521 .15401 m
.97619 .14942 L
s
0 0 0 r
2 Mabswid
.97619 .14942 Mdot
.039 .916 .04 r
.5 Mabswid
.595 .16321 m
.97619 .14942 L
s
0 0 0 r
2 Mabswid
.97619 .14942 Mdot
.039 .916 .04 r
.5 Mabswid
.59457 .17242 m
.97619 .14933 L
s
0 0 0 r
2 Mabswid
.97619 .14933 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool0097ooooo5?l0001Zoooo
o`03o`000?oooooooooo00kooooo002AoooooaCo0000J_ooool00ol0003oooooooooo`0>ooooo`00
TOooool00ol0003oOgmoogmoO`0>ogmoO`03o`000?moOgoo000006[ooooo00?o0000ooooooooool0
3_ooool0097ooooo00?o0000ogmoOomoOgl03_moOgl01?l0003oOgmoo`000?l0001Yooooo`03o`00
0?oooooooooo00kooooo002AoooooaGo0000JOooool00ol0003oooooooooo`0>ooooo`00TOooool0
0ol0003oOgmoogmoO`0>ogmoO`04o`000?moOgoo0000o`0006Wooooo00?o0000ooooooooool03_oo
ool0093ooooo0_l0000@ogmoO`04o`000?moOgoo0000o`0006Wooooo00?o0000ooooooooool03_oo
ool0093ooooo0_l0000@ogmoO`04o`000?moOgoo0000o`0006Wooooo00?o0000ooooooooool03_oo
ool0093ooooo0_l0000@ogmoO`05o`000?moOgoo0000ogmoOol00000J?ooool00ol0003ooooooooo
o`0>ooooo`00T?oooolEo`000003ogmoOol0003ooooo06Oooooo00?o0000ooooooooool03_ooool0
093ooooo0_l0000@ogmoO`05o`000?moOgoo0000ogmoOol00000J?ooool00ol0003oooooooooo`0>
ooooo`00T?ooool2o`00013oOgmo00Go0000ogmoOol0003oOgmoo`00001Xooooo`03o`000?oooooo
oooo00kooooo002@ooooo`;o00004?moOgl01Ol0003oOgmoo`000?moOgoo000006Sooooo00?o0000
ooooooooool03_ooool0093ooooo0_l0000@ogmoO`05o`000?moOgoo0000ogmoOol00000J?ooool0
0ol0003oooooooooo`0>ooooo`00T?ooool2o`00013oOgmo00?o0000ogmoOol000000_moOgl00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo00kooooo002@ooooo`;o00004?moOgl00ol0003o
Ogmoo`000002ogmoO`03o`000?oooooooooo06Gooooo00?o0000ooooooooool03_ooool008oooooo
00?o0000ogmoOol000004ol00002ogmoO`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
3_ooool008oooooo00?o0000ogmoOol000004?moOgl00ol0003oOgmoo`000002ogmoO`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool03_ooool008oooooo00?o0000ogmoOol000004?moOgl0
0ol0003oOgmoo`000002ogmoO`03o`000?oooooooooo06Gooooo00?o0000ooooooooool03_ooool0
08oooooo00?o0000ogmoOol000004?moOgl00ol0003oOgmoo`000003ogmoO`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool03_ooool008oooooo00?o0000ogmoOol000004?moOgl00ol0003o
Ogmoo`000003ogmoO`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03_ooool008oooooo
00?o0000ogmoOol000004?moOgl00ol0003oOgmoo`000003ogmoO`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool03_ooool008oooooo00?o0000ogmoOol000004?moOgl00ol0003oOgmoo`00
0003ogmoO`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03_ooool008oooooo00?o0000
ogmoOol000004ol00003ogmoO`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03_ooool0
08oooooo00?o0000ogmoOol000004?moOgl00ol0003oOgmoo`000003ogmoO`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool03_ooool000ooooooUol9jPX2ogmoO`;o0000IOooool00ol0003o
ooooooooo`0>ooooo`00Soooool3o`00013oOgmo0ol000000omoOgoo2NX:o`WZ2P0:o`WZ2Ugooooo
00?o0000ooooooooool03_ooool008oooooo0ol0000@ogmoO`?o00001?moOgl00ol0003ooooooooo
o`06oooooa7o2NX:C?ooool00ol0003oooooooooo`0>ooooo`003ooooonIo`WZ2P03o`000?l9jP[o
2NX:00co2NX:3?oooolAo`WZ2S_ooooo00?o0000ooooooooool03_ooool008oooooo00?o0000ogmo
Ool000004?moOgl00ol0003oOgmoo`000003ogmoO`;o00003OoooolIo`WZ2PCooooo4Ol9jPXZoooo
o`03o`000?oooooooooo00kooooo000?oooooiWo2NX:00?o0000o`WZ2_l9jPX06Ol9jPX<ooooobKo
2NX:6Oooool00ol0003oooooooooo`0>ooooo`00Soooool3o`00013oOgmo0ol00003ogmoO`;o0000
6_oooom3o`WZ2PSooooo0_l0000?ooooo`00SooooolKo`0003;ooooo<ol9jPX2o`0000oooooo000?
oooooiWo2NX:00?o0000o`WZ2_l9jPX0Fol9jPX9ooooo`03o`000?oooooooooo00kooooo002?oooo
o`?o00004?moOgl00ol0003oOgmoo`000004ogmoO`03o`000?oooooooooo00kooooo8_l9jPX8oooo
oa7o2NX:6_ooool00ol0003oooooooooo`0>ooooo`00Soooool3o`0000OoOgmo3ol9jPX00ol0003o
2NX:o`WZ2P0?o`WZ2QWooooo4Ol9jPX[ooooo`03o`000?oooooooooo00kooooo000?oooooh[o2NX:
2OmoOgl3o`0000?oOgmo0_l0000Hoooooa7o2NX:??ooool00ol0003oooooooooo`0>ooooo`00Sooo
ool00ol0003oOgmoo`00000@ogmoO`?o00000omoOgl2o`0000Oooooo4Ol9jPY=ooooo`03o`000?oo
oooooooo00kooooo000?oooooj;o2NX:G_ooool00ol0003oooooooooo`0>ooooo`00Soooool3o`00
013oOgmo00?o0000ogmoOol000000omoOgl00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
00kooooo002?ooooo`03o`000?moOgoo000001?o00000omoOgl00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo00kooooo002?ooooo`03o`000?moOgoo0000013oOgmo00?o0000ogmoOol00000
0omoOgl00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00kooooo002?ooooo`03o`000?mo
Ogoo0000013oOgmo00?o0000ogmoOol000000omoOgl00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00kooooo002?ooooo`03o`000?moOgoo0000013oOgmo00?o0000ogmoOol000000omoOgl0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00kooooo002?ooooo`03o`000?moOgoo0000
013oOgmo00?o0000ogmoOol000000omoOgl00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
00kooooo002?ooooo`03o`000?moOgoo0000013oOgmo00?o0000ogmoOol000000omoOgl00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo00kooooo002?ooooo`03o`000?moOgoo0000013oOgmo
00?o0000ogmoOol000000_moOgl00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00kooooo
002?ooooo`03o`000?moOgoo0000013oOgmo00?o0000ogmoOol000000_moOgl00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo00kooooo002@oooooaGo00000_moOgl00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo00kooooo002@ooooo`;o00004?moOgl00ol0003oOgmoo`000002ogmo
O`03o`000?oooooooooo06Gooooo00?o0000ooooooooool03_ooool0093ooooo0_l0000@ogmoO`03
o`000?moOgoo000000;oOgmo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0>ooooo`00
T?ooool2o`00013oOgmo00Go0000ogmoOol0003oOgmoo`00001Xooooo`03o`000?oooooooooo00ko
oooo002@ooooo`;o00004?moOgl01Ol0003oOgmoo`000?moOgoo000006Sooooo00?o0000oooooooo
ool03_ooool0093ooooo0_l0000@ogmoO`05o`000?moOgoo0000ogmoOol00000J?ooool00ol0003o
ooooooooo`0>ooooo`00T?oooolEo`000003ogmoOol0003ooooo06Oooooo00?o0000ooooooooool0
3_ooool0093ooooo0_l0000@ogmoO`05o`000?moOgoo0000ogmoOol00000J?ooool00ol0003ooooo
ooooo`0>ooooo`00T?ooool2o`00013oOgmo00Go0000ogmoOol0003oOgmoo`00001Xooooo`03o`00
0?oooooooooo00kooooo002@ooooo`;o00004?moOgl01?l0003oOgmoo`000?l0001Yooooo`03o`00
0?oooooooooo00kooooo002@ooooo`;o00004?moOgl01?l0003oOgmoo`000?l0001Yooooo`03o`00
0?oooooooooo00kooooo002AoooooaGo0000JOooool00ol0003oooooooooo`0>ooooo`00TOooool0
0ol0003oOgmoogmoO`0>ogmoO`04o`000?moOgoo0000o`0006Wooooo00?o0000ooooooooool03_oo
ool0097ooooo00?o0000ogmoOomoOgl03_moOgl01?l0003oOgmoo`000?l0001Yooooo`03o`000?oo
oooooooo00kooooo002Aooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOol00000J_ooool0
0ol0003oooooooooo`0>ooooo`00TOoooolDo`0006[ooooo00?o0000ooooooooool03_ooool0097o
oooo5?l0001Zooooo`03o`000?oooooooooo00kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.51151 .03036 m
.50509 .07004 L
.51151 .03036 L
F
.50509 .07004 m
.55628 .10972 L
.50127 .10972 L
.50509 .07004 L
F
.50127 .10972 m
.55628 .10972 L
.57143 .1494 L
.5 .1494 L
.50127 .10972 L
F
.5 .1494 m
.57143 .1494 L
.55628 .18909 L
.50127 .18909 L
.5 .1494 L
F
.50127 .18909 m
.55628 .18909 L
.50509 .22877 L
.50127 .18909 L
F
.50509 .22877 m
.51151 .26845 L
.50509 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.51151 .03036 m
.50509 .07004 L
.50127 .10972 L
.5 .1494 L
.50127 .18909 L
.50509 .22877 L
.51151 .26845 L
s
.55628 .18909 m
.57143 .1494 L
.55628 .10972 L
s
.51151 .03036 m
0 0 rlineto s
.5 g
.51151 .1494 m
.50509 .1494 L
.51151 .1494 L
F
.50509 .1494 m
.55628 .1494 L
.50127 .1494 L
.50509 .1494 L
F
.50127 .1494 m
.55628 .1494 L
.57143 .1494 L
.5 .1494 L
.50127 .1494 L
F
.5 .1494 m
.57143 .1494 L
.55628 .1494 L
.50127 .1494 L
.5 .1494 L
F
.50127 .1494 m
.55628 .1494 L
.50509 .1494 L
.50127 .1494 L
F
.50509 .1494 m
.51151 .1494 L
.50509 .1494 L
F
0 g
.51151 .1494 m
.50509 .1494 L
.50127 .1494 L
.5 .1494 L
.50127 .1494 L
.50509 .1494 L
.51151 .1494 L
s
.55628 .1494 m
.57143 .1494 L
.55628 .1494 L
s
.51151 .1494 m
0 0 rlineto s
.5 g
.62271 .03036 m
.60709 .07004 L
% vacuous filled polygon
newpath
.60709 .07004 m
.59815 .10972 L
.55628 .10972 L
F
.55628 .10972 m
.59815 .10972 L
.59524 .1494 L
.57143 .1494 L
.55628 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59815 .18909 L
.55628 .18909 L
.57143 .1494 L
F
.55628 .18909 m
.59815 .18909 L
.60709 .22877 L
.55628 .18909 L
F
.60709 .22877 m
.62271 .26845 L
% vacuous filled polygon
newpath
0 g
.55628 .10972 m
.57143 .1494 L
.55628 .18909 L
s
.62271 .26845 m
.60709 .22877 L
.59815 .18909 L
.59524 .1494 L
.59815 .10972 L
.60709 .07004 L
.62271 .03036 L
s
.5 g
.62271 .1494 m
.60709 .1494 L
% vacuous filled polygon
newpath
.60709 .1494 m
.59815 .1494 L
.55628 .1494 L
F
.55628 .1494 m
.59815 .1494 L
.59524 .1494 L
.57143 .1494 L
.55628 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59815 .1494 L
.55628 .1494 L
.57143 .1494 L
F
.55628 .1494 m
.59815 .1494 L
.60709 .1494 L
.55628 .1494 L
F
.60709 .1494 m
.62271 .1494 L
% vacuous filled polygon
newpath
0 g
.55628 .1494 m
.57143 .1494 L
.55628 .1494 L
s
.62271 .1494 m
.60709 .1494 L
.59815 .1494 L
.59524 .1494 L
.59815 .1494 L
.60709 .1494 L
.62271 .1494 L
s
.51151 .26845 m
0 0 rlineto s
.51151 .2644 m
.51151 .26845 L
s
.51151 .2644 m
0 0 rlineto s
.51151 .2525 m
.51151 .2644 L
s
.51151 .2525 m
0 0 rlineto s
.51151 .23358 m
.51151 .2525 L
s
.51151 .23358 m
0 0 rlineto s
.51151 .20893 m
.51151 .23358 L
s
.51151 .20893 m
0 0 rlineto s
.51151 .18022 m
.51151 .20893 L
s
.51151 .18022 m
0 0 rlineto s
.51151 .1494 m
.51151 .18022 L
s
.51151 .1494 m
0 0 rlineto s
.51151 .11859 m
.51151 .1494 L
s
.51151 .11859 m
0 0 rlineto s
.51151 .08988 m
.51151 .11859 L
s
.51151 .08988 m
0 0 rlineto s
.51151 .06523 m
.51151 .08988 L
s
.51151 .06523 m
0 0 rlineto s
.51151 .04631 m
.51151 .06523 L
s
.51151 .04631 m
0 0 rlineto s
.51151 .03441 m
.51151 .04631 L
s
.51151 .03441 m
0 0 rlineto s
.51151 .03036 m
.51151 .03441 L
s
.51151 .03036 m
0 0 rlineto s
.51151 .03441 m
.51151 .03036 L
s
.51151 .03441 m
0 0 rlineto s
.51151 .04631 m
.51151 .03441 L
s
.51151 .04631 m
0 0 rlineto s
.51151 .06523 m
.51151 .04631 L
s
.51151 .06523 m
0 0 rlineto s
.51151 .08988 m
.51151 .06523 L
s
.51151 .08988 m
0 0 rlineto s
.51151 .11859 m
.51151 .08988 L
s
.51151 .11859 m
0 0 rlineto s
.51151 .1494 m
.51151 .11859 L
s
.51151 .1494 m
0 0 rlineto s
.51151 .18022 m
.51151 .1494 L
s
.51151 .18022 m
0 0 rlineto s
.51151 .20893 m
.51151 .18022 L
s
.51151 .20893 m
0 0 rlineto s
.51151 .23358 m
.51151 .20893 L
s
.51151 .23358 m
0 0 rlineto s
.51151 .2525 m
.51151 .23358 L
s
.51151 .2525 m
0 0 rlineto s
.51151 .2644 m
.51151 .2525 L
s
.51151 .2644 m
0 0 rlineto s
.51151 .26845 m
.51151 .2644 L
s
.62271 .26845 m
.62271 .2644 L
s
.62271 .2644 m
.62271 .2525 L
s
.62271 .2525 m
.62271 .23358 L
s
.62271 .23358 m
.62271 .20893 L
s
.62271 .20893 m
.62271 .18022 L
s
.62271 .18022 m
.62271 .1494 L
s
.62271 .1494 m
.62271 .11859 L
s
.62271 .11859 m
.62271 .08988 L
s
.62271 .08988 m
.62271 .06523 L
s
.62271 .06523 m
.62271 .04631 L
s
.62271 .04631 m
.62271 .03441 L
s
.62271 .03441 m
.62271 .03036 L
s
.62271 .03036 m
.62271 .03441 L
s
.62271 .03441 m
.62271 .04631 L
s
.62271 .04631 m
.62271 .06523 L
s
.62271 .06523 m
.62271 .08988 L
s
.62271 .08988 m
.62271 .11859 L
s
.62271 .11859 m
.62271 .1494 L
s
.62271 .1494 m
.62271 .18022 L
s
.62271 .18022 m
.62271 .20893 L
s
.62271 .20893 m
.62271 .23358 L
s
.62271 .23358 m
.62271 .2525 L
s
.62271 .2525 m
.62271 .2644 L
s
.62271 .2644 m
.62271 .26845 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.50046 .1256 L
s
0 0 0 r
2 Mabswid
.50046 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.50016 .13512 L
s
0 0 0 r
2 Mabswid
.50016 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.50002 .14464 L
s
0 0 0 r
2 Mabswid
.50002 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.50002 .15417 L
s
0 0 0 r
2 Mabswid
.50002 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.50016 .16369 L
s
0 0 0 r
2 Mabswid
.50016 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.50046 .17321 L
s
0 0 0 r
2 Mabswid
.50046 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.50046 .1256 m
.56682 .12644 L
s
0 0 0 r
2 Mabswid
.56682 .12644 Mdot
.039 .916 .04 r
.5 Mabswid
.50016 .13512 m
.56982 .13565 L
s
0 0 0 r
2 Mabswid
.56982 .13565 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .14464 m
.57125 .14482 L
s
0 0 0 r
2 Mabswid
.57125 .14482 Mdot
.039 .916 .04 r
.5 Mabswid
.50002 .15417 m
.57125 .15398 L
s
0 0 0 r
2 Mabswid
.57125 .15398 Mdot
.039 .916 .04 r
.5 Mabswid
.50016 .16369 m
.56982 .16316 L
s
0 0 0 r
2 Mabswid
.56982 .16316 Mdot
.039 .916 .04 r
.5 Mabswid
.50046 .17321 m
.56682 .17237 L
s
0 0 0 r
2 Mabswid
.56682 .17237 Mdot
.039 .916 .04 r
.5 Mabswid
.56682 .12644 m
.59636 .12472 L
s
0 0 0 r
2 Mabswid
.59636 .12472 Mdot
.039 .916 .04 r
.5 Mabswid
.56982 .13565 m
.59563 .1348 L
s
0 0 0 r
2 Mabswid
.59563 .1348 Mdot
.039 .916 .04 r
.5 Mabswid
.57125 .14482 m
.59528 .14457 L
s
0 0 0 r
2 Mabswid
.59528 .14457 Mdot
.039 .916 .04 r
.5 Mabswid
.57125 .15398 m
.59528 .15424 L
s
0 0 0 r
2 Mabswid
.59528 .15424 Mdot
.039 .916 .04 r
.5 Mabswid
.56982 .16316 m
.59563 .16401 L
s
0 0 0 r
2 Mabswid
.59563 .16401 Mdot
.039 .916 .04 r
.5 Mabswid
.56682 .17237 m
.59636 .17409 L
s
0 0 0 r
2 Mabswid
.59636 .17409 Mdot
.039 .916 .04 r
.5 Mabswid
.59636 .12472 m
.97619 .05558 L
s
0 0 0 r
2 Mabswid
.97619 .05558 Mdot
.039 .916 .04 r
.5 Mabswid
.59563 .1348 m
.97619 .09549 L
s
0 0 0 r
2 Mabswid
.97619 .09549 Mdot
.039 .916 .04 r
.5 Mabswid
.59528 .14457 m
.97619 .13178 L
s
0 0 0 r
2 Mabswid
.97619 .13178 Mdot
.039 .916 .04 r
.5 Mabswid
.59528 .15424 m
.97619 .16703 L
s
0 0 0 r
2 Mabswid
.97619 .16703 Mdot
.039 .916 .04 r
.5 Mabswid
.59563 .16401 m
.97619 .20332 L
s
0 0 0 r
2 Mabswid
.97619 .20332 Mdot
.039 .916 .04 r
.5 Mabswid
.59636 .17409 m
.97619 .24323 L
s
0 0 0 r
2 Mabswid
.97619 .24323 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo002Booooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool03_ooool0
09;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
00kooooo002Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`0>ooooo`00T_ooool00ol0003oooooooooo`0Jooooo`;o0000G_ooool00ol0003ooooo
ooooo`0>ooooo`00TOooool2o`0001cooooo0_l0001Nooooo`03o`000?oooooooooo00kooooo002A
ooooo`;o00007?ooool2o`0005kooooo00?o0000ooooooooool03_ooool0097ooooo0_l0000Koooo
o`03o`000?oooooo000005kooooo00?o0000ooooooooool03_ooool0097ooooo0_l0000Kooooo`03
o`000?oooooo000005_ooooo0ol9jPX2o`0000oooooo002Aooooo`;o00006_ooool01?l0003ooooo
ooooool0001Fooooo`Go2NX:0oooool2o`0000oooooo002@ooooo`03o`000?oooooo000001[ooooo
00Co0000oooooooooooo0000DOooool5o`WZ2PSooooo00?o0000ooooooooool03_ooool0093ooooo
00?o0000ooooool000006_ooool01?l0003oooooooooool0001;ooooo`Ko2NX:3Oooool00ol0003o
ooooooooo`0>ooooo`00T?ooool00ol0003oooooo`00000Iooooo`05o`000?ooooooooooooooool0
0000A_ooool5o`WZ2Q?ooooo00?o0000ooooooooool03_ooool0093ooooo00?o0000ogmoOol00000
6?ooool00omoOgoo0000ooooo`02ooooo`03o`000?oooooooooo03kooooo1_l9jPXHooooo`03o`00
0?oooooooooo00kooooo002@ooooo`03o`000?moOgoo000001Oooooo0_moOgl01Ol0003ooooooooo
oooooooo000003_ooooo1Ol9jPXNooooo`03o`000?oooooooooo00kooooo002@ooooo`04o`000?mo
Ogoo0000ogmoOaGooooo0_moOgl00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo
1Ol9jPXSooooo`03o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgoo000000;oOgmo4ooo
ool3ogmoO`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool6o`WZ2RSooooo00?o
0000ooooooooool03_ooool0093ooooo00?o0000ogmoOol000001?moOgl?ooooo`GoOgmo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`Go2NX:;_ooool00ol0003oooooooooo`0>
ooooo`00Soooool01?l0003oOgmoogmoOol00005ogmoO`gooooo1OmoOgl00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02Cooooo1Ol9jPXcooooo`03o`000?oooooooooo00kooooo002?oooo
o`04o`000?moOgooOgmoo`0000KoOgmo2oooool6ogmoO`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07_ooool6o`WZ2S?ooooo1Ol9jPX2o`0000oooooo002?ooooo`04o`000?moOgooOgmo
o`0000SoOgmo1oooool8ogmoO`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool5
o`WZ2S3ooooo2Ol9jPX5ooooo`;o00003oooool008oooooo00Co0000ogmoOomoOgoo00002OmoOgl5
ooooo`WoOgmo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`Go2NX:;?ooool9
o`WZ2Pkooooo00?o0000ooooooooool03_ooool008oooooo00Co0000ogmoOomoOgoo00002_moOgl3
ooooo`WoOgmo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`Ko2NX::?ooool9
o`WZ2QOooooo00?o0000ooooooooool03_ooool008oooooo00Co0000ogmoOomoOgoo00002omoOgl0
0ol0003oOgmoogmoO`08ogmoO`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool5
o`WZ2RCooooo2_l9jPXPooooo`03o`000?oooooooooo00kooooo002?ooooo`04o`000?moOgooOgmo
o`0000_oOgmo00?o0000ogmoOomoOgl02?moOgl00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo1_l9jPXPooooo`Wo2NX::_ooool00ol0003oooooooooo`0>ooooo`00Soooool01?l0
003oOgmoogmoOol0000<ogmoO`03o`000?moOgooOgmo00OoOgmo00?o0000ooooooooool01?ooool0
0ol0003o2NX:o`WZ2P03o`WZ2Qgooooo2Ol9jPXcooooo`03o`000?oooooooooo00kooooo002?oooo
o`04o`000?moOgooOgmoo`0000coOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`05
o`WZ2QSooooo2_l9jPXlooooo`03o`000?oooooooooo00kooooo000?oooooh[o2NX:1_moOgl3o`00
00?oOgmo0ol9jPX01?l0003o2NX:o`WZ2_l9jPX4ooooo`03o`000?oooooooooo00gooooo2Ol9jPY6
ooooo`03o`000?oooooooooo00kooooo002?ooooo`;o000000?oOgmoo`000?moOgl01OmoOgl7o`WZ
2P03o`000?l9jP[o2NX:00;o2NX:0omoOgl2o`0000Kooooo00?o0000ooooooooool01?ooool9o`WZ
2Toooooo0_l0000?ooooo`00Soooool2o`000003ogmoOol0003oOgmo00coOgmo00?o0000ogmoOomo
Ogl01OmoOgl2o`0000Cooooo2Ol9jPY7oooooa7o2NX:0_l0000?ooooo`003ooooonBo`WZ2P03o`00
0?l9jP[o2NX:00Co2NX:00?o0000o`WZ2_l9jPX00ol9jPX2ooooo`03o`000?oooooooooo02Wooooo
8_l9jPXAooooo`03o`000?oooooooooo00kooooo002?ooooo`04o`000?moOgooOgmoo`0000koOgmo
0_l00006ogmoO`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01ooooolRo`WZ2S?ooooo
00?o0000ooooooooool03_ooool000ooooooVOl9jPX00ol0003o2NX:o`WZ2P0?o`WZ2UGooooo00?o
0000ooooooooool03_ooool008oooooo0_l000000omoOgoo0000ogmoO`0=ogmoO`?o00001?moOgl2
o`0000Kooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0>ooooo`00Soooool4o`00
00_oOgmo1_l00005ogmoO`So0000G_ooool00ol0003oooooooooo`0>ooooo`003ooooonIo`WZ2P03
o`000?l9jP[o2NX:013o2NX:E?ooool00ol0003oooooooooo`0>ooooo`00Soooool2o`000003ogmo
Ool0003oOgmo00goOgmo00?o0000ogmoOomoOgl01?moOgl2o`0000Kooooo00?o0000ooooooooool0
2?oooolRo`WZ2S;ooooo00?o0000ooooooooool03_ooool008oooooo0_l000000omoOgoo0000ogmo
O`05ogmoO`So2NX:00?o0000o`WZ2_l9jPX00ol9jPX00omoOgoo0000o`000006ooooo`03o`000?oo
oooooooo02[ooooo8_l9jPX@ooooo`03o`000?oooooooooo00kooooo000?oooooh[o2NX:2?moOgl2
o`0000CoOgmo00?o2NX:o`000?l9jPX01Ol9jPX00ooooooo0000ooooo`1=oooooa3o2NX:0_l0000?
ooooo`00Soooool01?l0003oOgmoogmoOol0000=ogmoO`;o00001omoOgl00ol0003oooooooooo`03
ooooo`[o2NX:E_ooool2o`0000oooooo000?oooooi7o2NX:00?o0000o`WZ2_l9jPX01Ol9jPX00ol0
003o2NX:o`WZ2P02o`WZ2P?ooooo00?o0000ooooooooool01_ooool;o`WZ2T_ooooo00?o0000oooo
ooooool03_ooool008oooooo0_l000000omoOgoo0000ogmoO`0;ogmoO`03o`000?moOgooOgmo00Ko
Ogmo0_l00003ooooo`Go2NX:4_ooool:o`WZ2T7ooooo00?o0000ooooooooool03_ooool008oooooo
00Co0000ogmoOomoOgoo00003?moOgl00ol0003oOgmoogmoO`07ogmoO`03o`000?oooooooooo00Co
oooo00?o0000ooooool9jPX01?l9jPXGooooo`[o2NX:=oooool00ol0003oooooooooo`0>ooooo`00
Soooool01?l0003oOgmoogmoOol0000<ogmoO`03o`000?moOgooOgmo00OoOgmo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`Ko2NX:6oooool:o`WZ2Rgooooo00?o0000oooooooo
ool03_ooool008oooooo00Co0000ogmoOomoOgoo00002omoOgl00ol0003oOgmoogmoO`08ogmoO`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool5o`WZ2R3ooooo2_l9jPXSooooo`03
o`000?oooooooooo00kooooo002?ooooo`04o`000?moOgooOgmoo`0000[oOgmo0oooool9ogmoO`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool6o`WZ2RCooooo2ol9jPXHooooo`03
o`000?oooooooooo00kooooo002?ooooo`04o`000?moOgooOgmoo`0000WoOgmo1Oooool8ogmoO`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool5o`WZ2R[ooooo2_l9jPX>ooooo`03
o`000?oooooooooo00kooooo002?ooooo`04o`000?moOgooOgmoo`0000SoOgmo1oooool8ogmoO`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool06_ooool5o`WZ2Roooooo2_l9jPX4ooooo`03
o`000?oooooooooo00kooooo002?ooooo`04o`000?moOgooOgmoo`0000OoOgmo2Oooool7ogmoO`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool07oooool6o`WZ2S?ooooo1?l9jPX2o`0000oo
oooo002?ooooo`04o`000?moOgooOgmoo`0000GoOgmo3Oooool5ogmoO`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool09Oooool5o`WZ2S;ooooo0_l0000?ooooo`00T?ooool00ol0003oOgmo
o`000004ogmoO`oooooo1OmoOgl00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo
1Ol9jPX]ooooo`03o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgoo000000?oOgmo4Ooo
ool4ogmoO`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;oooool6o`WZ2ROooooo00?o
0000ooooooooool03_ooool0093ooooo00Co0000ogmoOol0003oOgmo5Oooool2ogmoO`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0=Oooool5o`WZ2R;ooooo00?o0000ooooooooool03_oo
ool0093ooooo00?o0000ogmoOol000005oooool00omoOgoo0000ooooo`03ooooo`03o`000?oooooo
oooo03[ooooo1Ol9jPXMooooo`03o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgoo0000
01Sooooo00?oOgmoo`000?ooool00_ooool00ol0003oooooooooo`0oooooo`Ko2NX:5oooool00ol0
003oooooooooo`0>ooooo`00T?ooool00ol0003oooooo`00000Iooooo`05o`000?oooooooooooooo
ool00000Aoooool5o`WZ2Q;ooooo00?o0000ooooooooool03_ooool0093ooooo00?o0000ooooool0
00006Oooool01Ol0003ooooooooooooooooo000004cooooo1_l9jPX<ooooo`03o`000?oooooooooo
00kooooo002@ooooo`03o`000?oooooo000001[ooooo00Co0000oooooooooooo0000D_ooool5o`WZ
2POooooo00?o0000ooooooooool03_ooool0093ooooo00?o0000ooooool000006_ooool01?l0003o
ooooooooool0001Gooooo`Go2NX:0_ooool2o`0000oooooo002Aooooo`;o00006_ooool01?l0003o
ooooooooool0001Looooo`;o2NX:0_l0000?ooooo`00TOooool2o`0001_ooooo00?o0000ooooool0
0000G_ooool00ol0003oooooooooo`0>ooooo`00TOooool2o`0001_ooooo00?o0000ooooool00000
G_ooool00ol0003oooooooooo`0>ooooo`00TOooool2o`0001_ooooo00?o0000ooooool00000G_oo
ool00ol0003oooooooooo`0>ooooo`00TOooool2o`0001cooooo0_l0001Nooooo`03o`000?oooooo
oooo00kooooo002Booooo`03o`000?oooooooooo01[ooooo0_l0001Nooooo`03o`000?oooooooooo
00kooooo002Booooo`03o`000?oooooooooo01[ooooo0_l0001Nooooo`03o`000?oooooooooo00ko
oooo002Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`0>ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.52085 .03036 m
.57999 .03036 L
.57522 .07004 L
.50911 .07004 L
.52085 .03036 L
F
.50911 .07004 m
.57522 .07004 L
.57238 .10972 L
.50226 .10972 L
.50911 .07004 L
F
.50226 .10972 m
.57238 .10972 L
.57143 .1494 L
.5 .1494 L
.50226 .10972 L
F
.5 .1494 m
.57143 .1494 L
.57238 .18909 L
.50226 .18909 L
.5 .1494 L
F
.50226 .18909 m
.57238 .18909 L
.57522 .22877 L
.50911 .22877 L
.50226 .18909 L
F
.50911 .22877 m
.57522 .22877 L
.57999 .26845 L
.52085 .26845 L
.50911 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.52085 .03036 m
.50911 .07004 L
.50226 .10972 L
.5 .1494 L
.50226 .18909 L
.50911 .22877 L
.52085 .26845 L
.57999 .26845 L
.57522 .22877 L
.57238 .18909 L
.57143 .1494 L
.57238 .10972 L
.57522 .07004 L
.57999 .03036 L
.52085 .03036 L
s
.5 g
.52085 .1494 m
.57999 .1494 L
.57522 .1494 L
.50911 .1494 L
.52085 .1494 L
F
.50911 .1494 m
.57522 .1494 L
.57238 .1494 L
.50226 .1494 L
.50911 .1494 L
F
.50226 .1494 m
.57238 .1494 L
.57143 .1494 L
.5 .1494 L
.50226 .1494 L
F
.5 .1494 m
.57143 .1494 L
.57238 .1494 L
.50226 .1494 L
.5 .1494 L
F
.50226 .1494 m
.57238 .1494 L
.57522 .1494 L
.50911 .1494 L
.50226 .1494 L
F
.50911 .1494 m
.57522 .1494 L
.57999 .1494 L
.52085 .1494 L
.50911 .1494 L
F
0 g
.52085 .1494 m
.50911 .1494 L
.50226 .1494 L
.5 .1494 L
.50226 .1494 L
.50911 .1494 L
.52085 .1494 L
.57999 .1494 L
.57522 .1494 L
.57238 .1494 L
.57143 .1494 L
.57238 .1494 L
.57522 .1494 L
.57999 .1494 L
.52085 .1494 L
s
.5 g
.57999 .03036 m
.58921 .03036 L
.59256 .07004 L
.57522 .07004 L
.57999 .03036 L
F
.57522 .07004 m
.59256 .07004 L
.59457 .10972 L
.57238 .10972 L
.57522 .07004 L
F
.57238 .10972 m
.59457 .10972 L
.59524 .1494 L
.57143 .1494 L
.57238 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59457 .18909 L
.57238 .18909 L
.57143 .1494 L
F
.57238 .18909 m
.59457 .18909 L
.59256 .22877 L
.57522 .22877 L
.57238 .18909 L
F
.57522 .22877 m
.59256 .22877 L
.58921 .26845 L
.57999 .26845 L
.57522 .22877 L
F
0 g
.57999 .03036 m
.57522 .07004 L
.57238 .10972 L
.57143 .1494 L
.57238 .18909 L
.57522 .22877 L
.57999 .26845 L
.58921 .26845 L
.59256 .22877 L
.59457 .18909 L
.59524 .1494 L
.59457 .10972 L
.59256 .07004 L
.58921 .03036 L
.57999 .03036 L
s
.5 g
.57999 .1494 m
.58921 .1494 L
.59256 .1494 L
.57522 .1494 L
.57999 .1494 L
F
.57522 .1494 m
.59256 .1494 L
.59457 .1494 L
.57238 .1494 L
.57522 .1494 L
F
.57238 .1494 m
.59457 .1494 L
.59524 .1494 L
.57143 .1494 L
.57238 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59457 .1494 L
.57238 .1494 L
.57143 .1494 L
F
.57238 .1494 m
.59457 .1494 L
.59256 .1494 L
.57522 .1494 L
.57238 .1494 L
F
.57522 .1494 m
.59256 .1494 L
.58921 .1494 L
.57999 .1494 L
.57522 .1494 L
F
0 g
.57999 .1494 m
.57522 .1494 L
.57238 .1494 L
.57143 .1494 L
.57238 .1494 L
.57522 .1494 L
.57999 .1494 L
.58921 .1494 L
.59256 .1494 L
.59457 .1494 L
.59524 .1494 L
.59457 .1494 L
.59256 .1494 L
.58921 .1494 L
.57999 .1494 L
s
.52085 .26845 m
.57999 .26845 L
.57999 .2644 L
.52085 .2644 L
.52085 .26845 L
s
.52085 .2644 m
.57999 .2644 L
.57999 .2525 L
.52085 .2525 L
.52085 .2644 L
s
.52085 .2525 m
.57999 .2525 L
.57999 .23358 L
.52085 .23358 L
.52085 .2525 L
s
.52085 .23358 m
.57999 .23358 L
.57999 .20893 L
.52085 .20893 L
.52085 .23358 L
s
.52085 .20893 m
.57999 .20893 L
.57999 .18022 L
.52085 .18022 L
.52085 .20893 L
s
.52085 .18022 m
.57999 .18022 L
.57999 .1494 L
.52085 .1494 L
.52085 .18022 L
s
.52085 .1494 m
.57999 .1494 L
.57999 .11859 L
.52085 .11859 L
.52085 .1494 L
s
.52085 .11859 m
.57999 .11859 L
.57999 .08988 L
.52085 .08988 L
.52085 .11859 L
s
.52085 .08988 m
.57999 .08988 L
.57999 .06523 L
.52085 .06523 L
.52085 .08988 L
s
.52085 .06523 m
.57999 .06523 L
.57999 .04631 L
.52085 .04631 L
.52085 .06523 L
s
.52085 .04631 m
.57999 .04631 L
.57999 .03441 L
.52085 .03441 L
.52085 .04631 L
s
.52085 .03441 m
.57999 .03441 L
.57999 .03036 L
.52085 .03036 L
.52085 .03441 L
s
.52085 .03036 m
.57999 .03036 L
.57999 .03441 L
.52085 .03441 L
.52085 .03036 L
s
.52085 .03441 m
.57999 .03441 L
.57999 .04631 L
.52085 .04631 L
.52085 .03441 L
s
.52085 .04631 m
.57999 .04631 L
.57999 .06523 L
.52085 .06523 L
.52085 .04631 L
s
.52085 .06523 m
.57999 .06523 L
.57999 .08988 L
.52085 .08988 L
.52085 .06523 L
s
.52085 .08988 m
.57999 .08988 L
.57999 .11859 L
.52085 .11859 L
.52085 .08988 L
s
.52085 .11859 m
.57999 .11859 L
.57999 .1494 L
.52085 .1494 L
.52085 .11859 L
s
.52085 .1494 m
.57999 .1494 L
.57999 .18022 L
.52085 .18022 L
.52085 .1494 L
s
.52085 .18022 m
.57999 .18022 L
.57999 .20893 L
.52085 .20893 L
.52085 .18022 L
s
.52085 .20893 m
.57999 .20893 L
.57999 .23358 L
.52085 .23358 L
.52085 .20893 L
s
.52085 .23358 m
.57999 .23358 L
.57999 .2525 L
.52085 .2525 L
.52085 .23358 L
s
.52085 .2525 m
.57999 .2525 L
.57999 .2644 L
.52085 .2644 L
.52085 .2525 L
s
.52085 .2644 m
.57999 .2644 L
.57999 .26845 L
.52085 .26845 L
.52085 .2644 L
s
.57999 .26845 m
.58921 .26845 L
.58921 .2644 L
.57999 .2644 L
.57999 .26845 L
s
.57999 .2644 m
.58921 .2644 L
.58921 .2525 L
.57999 .2525 L
.57999 .2644 L
s
.57999 .2525 m
.58921 .2525 L
.58921 .23358 L
.57999 .23358 L
.57999 .2525 L
s
.57999 .23358 m
.58921 .23358 L
.58921 .20893 L
.57999 .20893 L
.57999 .23358 L
s
.57999 .20893 m
.58921 .20893 L
.58921 .18022 L
.57999 .18022 L
.57999 .20893 L
s
.57999 .18022 m
.58921 .18022 L
.58921 .1494 L
.57999 .1494 L
.57999 .18022 L
s
.57999 .1494 m
.58921 .1494 L
.58921 .11859 L
.57999 .11859 L
.57999 .1494 L
s
.57999 .11859 m
.58921 .11859 L
.58921 .08988 L
.57999 .08988 L
.57999 .11859 L
s
.57999 .08988 m
.58921 .08988 L
.58921 .06523 L
.57999 .06523 L
.57999 .08988 L
s
.57999 .06523 m
.58921 .06523 L
.58921 .04631 L
.57999 .04631 L
.57999 .06523 L
s
.57999 .04631 m
.58921 .04631 L
.58921 .03441 L
.57999 .03441 L
.57999 .04631 L
s
.57999 .03441 m
.58921 .03441 L
.58921 .03036 L
.57999 .03036 L
.57999 .03441 L
s
.57999 .03036 m
.58921 .03036 L
.58921 .03441 L
.57999 .03441 L
.57999 .03036 L
s
.57999 .03441 m
.58921 .03441 L
.58921 .04631 L
.57999 .04631 L
.57999 .03441 L
s
.57999 .04631 m
.58921 .04631 L
.58921 .06523 L
.57999 .06523 L
.57999 .04631 L
s
.57999 .06523 m
.58921 .06523 L
.58921 .08988 L
.57999 .08988 L
.57999 .06523 L
s
.57999 .08988 m
.58921 .08988 L
.58921 .11859 L
.57999 .11859 L
.57999 .08988 L
s
.57999 .11859 m
.58921 .11859 L
.58921 .1494 L
.57999 .1494 L
.57999 .11859 L
s
.57999 .1494 m
.58921 .1494 L
.58921 .18022 L
.57999 .18022 L
.57999 .1494 L
s
.57999 .18022 m
.58921 .18022 L
.58921 .20893 L
.57999 .20893 L
.57999 .18022 L
s
.57999 .20893 m
.58921 .20893 L
.58921 .23358 L
.57999 .23358 L
.57999 .20893 L
s
.57999 .23358 m
.58921 .23358 L
.58921 .2525 L
.57999 .2525 L
.57999 .23358 L
s
.57999 .2525 m
.58921 .2525 L
.58921 .2644 L
.57999 .2644 L
.57999 .2525 L
s
.57999 .2644 m
.58921 .2644 L
.58921 .26845 L
.57999 .26845 L
.57999 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.50081 .1256 L
s
0 0 0 r
2 Mabswid
.50081 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.50029 .13512 L
s
0 0 0 r
2 Mabswid
.50029 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.50003 .14464 L
s
0 0 0 r
2 Mabswid
.50003 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.50003 .15417 L
s
0 0 0 r
2 Mabswid
.50003 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.50029 .16369 L
s
0 0 0 r
2 Mabswid
.50029 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.50081 .17321 L
s
0 0 0 r
2 Mabswid
.50081 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.50081 .1256 m
.57172 .1272 L
s
0 0 0 r
2 Mabswid
.57172 .1272 Mdot
.039 .916 .04 r
.5 Mabswid
.50029 .13512 m
.57154 .13609 L
s
0 0 0 r
2 Mabswid
.57154 .13609 Mdot
.039 .916 .04 r
.5 Mabswid
.50003 .14464 m
.57144 .14497 L
s
0 0 0 r
2 Mabswid
.57144 .14497 Mdot
.039 .916 .04 r
.5 Mabswid
.50003 .15417 m
.57144 .15384 L
s
0 0 0 r
2 Mabswid
.57144 .15384 Mdot
.039 .916 .04 r
.5 Mabswid
.50029 .16369 m
.57154 .16272 L
s
0 0 0 r
2 Mabswid
.57154 .16272 Mdot
.039 .916 .04 r
.5 Mabswid
.50081 .17321 m
.57172 .17161 L
s
0 0 0 r
2 Mabswid
.57172 .17161 Mdot
.039 .916 .04 r
.5 Mabswid
.57172 .1272 m
.59504 .12775 L
s
0 0 0 r
2 Mabswid
.59504 .12775 Mdot
.039 .916 .04 r
.5 Mabswid
.57154 .13609 m
.59517 .13642 L
s
0 0 0 r
2 Mabswid
.59517 .13642 Mdot
.039 .916 .04 r
.5 Mabswid
.57144 .14497 m
.59523 .14508 L
s
0 0 0 r
2 Mabswid
.59523 .14508 Mdot
.039 .916 .04 r
.5 Mabswid
.57144 .15384 m
.59523 .15373 L
s
0 0 0 r
2 Mabswid
.59523 .15373 Mdot
.039 .916 .04 r
.5 Mabswid
.57154 .16272 m
.59517 .16239 L
s
0 0 0 r
2 Mabswid
.59517 .16239 Mdot
.039 .916 .04 r
.5 Mabswid
.57172 .17161 m
.59504 .17106 L
s
0 0 0 r
2 Mabswid
.59504 .17106 Mdot
.039 .916 .04 r
.5 Mabswid
.59504 .12775 m
.97619 .14941 L
s
0 0 0 r
2 Mabswid
.97619 .14941 Mdot
.039 .916 .04 r
.5 Mabswid
.59517 .13642 m
.97619 .14939 L
s
0 0 0 r
2 Mabswid
.97619 .14939 Mdot
.039 .916 .04 r
.5 Mabswid
.59523 .14508 m
.97619 .14939 L
s
0 0 0 r
2 Mabswid
.97619 .14939 Mdot
.039 .916 .04 r
.5 Mabswid
.59523 .15373 m
.97619 .14942 L
s
0 0 0 r
2 Mabswid
.97619 .14942 Mdot
.039 .916 .04 r
.5 Mabswid
.59517 .16239 m
.97619 .14942 L
s
0 0 0 r
2 Mabswid
.97619 .14942 Mdot
.039 .916 .04 r
.5 Mabswid
.59504 .17106 m
.97619 .1494 L
s
0 0 0 r
2 Mabswid
.97619 .1494 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool009Gooooo4ol0001Woooo
o`03o`000?oooooooooo00kooooo002Eoooooa?o0000Ioooool00ol0003oooooooooo`0>ooooo`00
U?ooool2o`0000ooOgmo00?o0000ogmoOol00000Ioooool00ol0003oooooooooo`0>ooooo`00U?oo
ool2o`0000koOgmo0_l000000omoOgoo0000ooooo`1Vooooo`03o`000?oooooooooo00kooooo002D
oooooaCo0000Ioooool00ol0003oooooooooo`0>ooooo`00Toooool00ol0003oOgmoo`00000>ogmo
O`;o000000?oOgmoo`000?ooool0I_ooool00ol0003oooooooooo`0>ooooo`00Toooool00ol0003o
Ogmoo`00000>ogmoO`;o000000?oOgmoo`000?l00000I_ooool00ol0003oooooooooo`0>ooooo`00
T_ooool01?l0003oOgmoogmoOol0000>ogmoO`;o000000?oOgmoo`000?l00000I_ooool00ol0003o
ooooooooo`0>ooooo`00T_ooool01?l0003oOgmoogmoOol0000=ogmoO`04o`000?moOgoo0000ogmo
O`;o0000I_ooool00ol0003oooooooooo`0>ooooo`00T_ooool00ol0003oOgmoogmoO`0Do`0006Ko
oooo00?o0000ooooooooool03_ooool0097ooooo00Go0000ogmoOomoOgooOgmoo`00000=ogmoO`04
o`000?moOgoo0000ogmoO`;o0000I_ooool00ol0003oooooooooo`0>ooooo`00TOooool01Ol0003o
OgmoogmoOomoOgoo000000goOgmo00Co0000ogmoOol0003oOgmo0_l0001Vooooo`03o`000?oooooo
oooo00kooooo002Aooooo`05o`000?moOgooOgmoogmoOol000003OmoOgl01?l0003oOgmoo`000?mo
Ogl2o`0006Kooooo00?o0000ooooooooool03_ooool0097ooooo00Go0000ogmoOomoOgooOgmoo`00
000=ogmoO`04o`000?moOgoo0000ogmoO`;o0000I_ooool00ol0003oooooooooo`0>ooooo`00TOoo
ool01Ol0003oOgmoogmoOomoOgoo000000goOgmo00Co0000ogmoOol0003oOgmo0_l0001Vooooo`03
o`000?oooooooooo00kooooo002Aooooo`05o`000?moOgooOgmoogmoOol000003OmoOgl01?l0003o
Ogmoo`000?moOgl2o`0006Kooooo00?o0000ooooooooool03_ooool0093ooooo00?o0000ogmoOomo
Ogl00_moOglDo`0006Kooooo00?o0000ooooooooool03_ooool0093ooooo00?o0000ogmoOomoOgl0
0_moOgl00ol0003oOgmoogmoO`0:ogmoO`05o`000?moOgooOgmoo`000?moOgl00_l0001Vooooo`03
o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl0
2_moOgl01Ol0003oOgmoogmoOol0003oOgmo00;o0000I_ooool00ol0003oooooooooo`0>ooooo`00
T?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00[oOgmo00Go0000ogmoOomoOgoo
0000ogmoO`02o`0006Kooooo00?o0000ooooooooool03_ooool0093ooooo00?o0000ogmoOomoOgl0
0_moOgl00ol0003oOgmoogmoO`0:ogmoO`05o`000?moOgooOgmoo`000?moOgl00_l0001Vooooo`03
o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl0
2_moOgl01Ol0003oOgmoogmoOol0003oOgmo00;o0000I_ooool00ol0003oooooooooo`0>ooooo`00
T?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00[oOgmo00Go0000ogmoOomoOgoo
0000ogmoO`02o`0006Kooooo00?o0000ooooooooool03_ooool0093ooooo00?o0000ogmoOomoOgl0
0_moOglDo`0006Kooooo00?o0000ooooooooool03_ooool0093ooooo00?o0000ogmoOomoOgl00_mo
Ogl00ol0003oOgmoogmoO`0:ogmoO`05o`000?moOgooOgmoo`000?moOgl00_l0001Vooooo`03o`00
0?oooooooooo00kooooo000?oooooh_o2NX:2?moOgl2o`000003ogmoOol0003oOgmo00?o0000IOoo
ool00ol0003oooooooooo`0>ooooo`00Soooool2o`0000CoOgmo00?o0000ogmoOomoOgl00_moOgl>
o`WZ2P03o`000?l9jP[o2NX:00So2NX:G?ooool00ol0003oooooooooo`0>ooooo`00Soooool2o`00
00CoOgmo00?o0000ogmoOomoOgl02_moOgl02?l0003oOgmoogmoOol0003oOgmoo`000?moOgoo0000
2OoooolAo`WZ2T_ooooo00?o0000ooooooooool03_ooool000ooooooVOl9jPX00ol0003o2NX:o`WZ
2P0<o`WZ2Pgooooo4Ol9jPXjooooo`03o`000?oooooooooo00kooooo002?ooooo`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ogmoOomoOgl02_moOgl2o`000003ogmoOol0003oOgmo00?o00003OoooolI
o`WZ2PGooooo4Ol9jPXYooooo`03o`000?oooooooooo00kooooo000?oooooh_o2NX:2?moOgl2o`00
0003ogmoOol0003oOgmo00?o00009_oooolWo`WZ2QSooooo00?o0000ooooooooool03_ooool008oo
oooo0_l00004ogmoO`03o`000?moOgooOgmo00;oOgmo3_l9jPX00ol0003o2NX:o`WZ2P0bo`WZ2Pgo
oooo7_l9jPX7ooooo`;o00003oooool008oooooo6ol0000boooooc?o2NX:0_l0000?ooooo`003ooo
oonIo`WZ2P03o`000?l9jP[o2NX:05co2NX:2?ooool00ol0003oooooooooo`0>ooooo`00Soooool2
o`0000CoOgmo00?o0000ogmoOomoOgl02_moOgl02?l0003oOgmoogmoOol0003oOgmoo`000?moOgoo
00004?oooolRo`WZ2PWooooo4Ol9jPXIooooo`03o`000?oooooooooo00kooooo002?ooooo`;o0000
1?moOgl01?l0003oOgmoogmoOomoOgl?o`WZ2P03o`000?l9jP[o2NX:00oo2NX:6_oooolAo`WZ2R[o
oooo00?o0000ooooooooool03_ooool000ooooooR_l9jPX9ogmoO`;o000000?oOgmoo`000?moOgl0
0ol0000Ioooooa7o2NX:>oooool00ol0003oooooooooo`0>ooooo`00Soooool00ol0003oOgmoogmo
O`03ogmoO`03o`000?moOgooOgmo00[oOgmo0_l000000omoOgoo0000ogmoO`03o`0000Sooooo4Ol9
jPY<ooooo`03o`000?oooooooooo00kooooo000?oooooiWo2NX:00?o0000o`WZ2_l9jPX01ol9jPYM
ooooo`03o`000?oooooooooo00kooooo002?ooooo`;o00001?moOgl00ol0003oOgmoogmoO`0:ogmo
O`05o`000?moOgooOgmoo`000?moOgl00_l0001Vooooo`03o`000?oooooooooo00kooooo002@oooo
o`03o`000?moOgooOgmo00;oOgmo5?l0001Vooooo`03o`000?oooooooooo00kooooo002@ooooo`03
o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl02_moOgl01Ol0003oOgmoogmoOol0003oOgmo
00;o0000I_ooool00ol0003oooooooooo`0>ooooo`00T?ooool00ol0003oOgmoogmoO`02ogmoO`03
o`000?moOgooOgmo00[oOgmo00Go0000ogmoOomoOgoo0000ogmoO`02o`0006Kooooo00?o0000oooo
ooooool03_ooool0093ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0:ogmoO`05
o`000?moOgooOgmoo`000?moOgl00_l0001Vooooo`03o`000?oooooooooo00kooooo002@ooooo`03
o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl02_moOgl01Ol0003oOgmoogmoOol0003oOgmo
00;o0000I_ooool00ol0003oooooooooo`0>ooooo`00T?ooool00ol0003oOgmoogmoO`02ogmoO`03
o`000?moOgooOgmo00[oOgmo00Go0000ogmoOomoOgoo0000ogmoO`02o`0006Kooooo00?o0000oooo
ooooool03_ooool0093ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0:ogmoO`05
o`000?moOgooOgmoo`000?moOgl00_l0001Vooooo`03o`000?oooooooooo00kooooo002@ooooo`03
o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl02_moOgl01Ol0003oOgmoogmoOol0003oOgmo
00;o0000I_ooool00ol0003oooooooooo`0>ooooo`00TOooool01?l0003oOgmoogmoOomoOglDo`00
06Kooooo00?o0000ooooooooool03_ooool0097ooooo00Go0000ogmoOomoOgooOgmoo`00000=ogmo
O`04o`000?moOgoo0000ogmoO`;o0000I_ooool00ol0003oooooooooo`0>ooooo`00TOooool01Ol0
003oOgmoogmoOomoOgoo000000goOgmo00Co0000ogmoOol0003oOgmo0_l0001Vooooo`03o`000?oo
oooooooo00kooooo002Aooooo`05o`000?moOgooOgmoogmoOol000003OmoOgl01?l0003oOgmoo`00
0?moOgl2o`0006Kooooo00?o0000ooooooooool03_ooool0097ooooo00Go0000ogmoOomoOgooOgmo
o`00000=ogmoO`04o`000?moOgoo0000ogmoO`;o0000I_ooool00ol0003oooooooooo`0>ooooo`00
TOooool01Ol0003oOgmoogmoOomoOgoo000000goOgmo00Co0000ogmoOol0003oOgmo0_l0001Voooo
o`03o`000?oooooooooo00kooooo002Aooooo`04o`000?moOgooOgmoogmoOaCo0000I_ooool00ol0
003oooooooooo`0>ooooo`00T_ooool01?l0003oOgmoogmoOol0000=ogmoO`04o`000?moOgoo0000
ogmoO`;o0000I_ooool00ol0003oooooooooo`0>ooooo`00T_ooool01?l0003oOgmoogmoOol0000=
ogmoO`04o`000?moOgoo0000ogmoO`;o0000I_ooool00ol0003oooooooooo`0>ooooo`00T_ooool0
1?l0003oOgmoogmoOol0000>ogmoO`;o000000?oOgmoo`000?l00000I_ooool00ol0003ooooooooo
o`0>ooooo`00Toooool00ol0003oOgmoo`00000>ogmoO`;o000000?oOgmoo`000?l00000I_ooool0
0ol0003oooooooooo`0>ooooo`00Toooool00ol0003oOgmoo`00000Bo`0006Oooooo00?o0000oooo
ooooool03_ooool009?ooooo00?o0000ogmoOol000003_moOgl2o`000003ogmoOol0003ooooo06Ko
oooo00?o0000ooooooooool03_ooool009Cooooo0_l0000>ogmoO`;o000000?oOgmoo`000?ooool0
I_ooool00ol0003oooooooooo`0>ooooo`00U?ooool2o`0000ooOgmo00?o0000ogmoOol00000Iooo
ool00ol0003oooooooooo`0>ooooo`00U?oooolDo`0006Oooooo00?o0000ooooooooool03_ooool0
09Gooooo4ol0001Wooooo`03o`000?oooooooooo00kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.52961 .03036 m
.56937 .03036 L
.57051 .07004 L
.51271 .07004 L
.52961 .03036 L
F
.51271 .07004 m
.57051 .07004 L
.5712 .10972 L
.50312 .10972 L
.51271 .07004 L
F
.50312 .10972 m
.5712 .10972 L
.57143 .1494 L
.5 .1494 L
.50312 .10972 L
F
.5 .1494 m
.57143 .1494 L
.5712 .18909 L
.50312 .18909 L
.5 .1494 L
F
.50312 .18909 m
.5712 .18909 L
.57051 .22877 L
.51271 .22877 L
.50312 .18909 L
F
.51271 .22877 m
.57051 .22877 L
.56937 .26845 L
.52961 .26845 L
.51271 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.52961 .03036 m
.51271 .07004 L
.50312 .10972 L
.5 .1494 L
.50312 .18909 L
.51271 .22877 L
.52961 .26845 L
.56937 .26845 L
.57051 .22877 L
.5712 .18909 L
.57143 .1494 L
.5712 .10972 L
.57051 .07004 L
.56937 .03036 L
.52961 .03036 L
s
.5 g
.52961 .1494 m
.56937 .1494 L
.57051 .1494 L
.51271 .1494 L
.52961 .1494 L
F
.51271 .1494 m
.57051 .1494 L
.5712 .1494 L
.50312 .1494 L
.51271 .1494 L
F
.50312 .1494 m
.5712 .1494 L
.57143 .1494 L
.5 .1494 L
.50312 .1494 L
F
.5 .1494 m
.57143 .1494 L
.5712 .1494 L
.50312 .1494 L
.5 .1494 L
F
.50312 .1494 m
.5712 .1494 L
.57051 .1494 L
.51271 .1494 L
.50312 .1494 L
F
.51271 .1494 m
.57051 .1494 L
.56937 .1494 L
.52961 .1494 L
.51271 .1494 L
F
0 g
.52961 .1494 m
.51271 .1494 L
.50312 .1494 L
.5 .1494 L
.50312 .1494 L
.51271 .1494 L
.52961 .1494 L
.56937 .1494 L
.57051 .1494 L
.5712 .1494 L
.57143 .1494 L
.5712 .1494 L
.57051 .1494 L
.56937 .1494 L
.52961 .1494 L
s
.5 g
.56937 .03036 m
.56479 .07004 L
.57051 .07004 L
.56937 .03036 L
F
.57051 .07004 m
.56479 .07004 L
.58841 .10972 L
.5712 .10972 L
.57051 .07004 L
F
.5712 .10972 m
.58841 .10972 L
.59524 .1494 L
.57143 .1494 L
.5712 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.58841 .18909 L
.5712 .18909 L
.57143 .1494 L
F
.5712 .18909 m
.58841 .18909 L
.56479 .22877 L
.57051 .22877 L
.5712 .18909 L
F
.57051 .22877 m
.56479 .22877 L
.56937 .26845 L
.57051 .22877 L
F
0 g
.56937 .03036 m
.57051 .07004 L
.5712 .10972 L
.57143 .1494 L
.5712 .18909 L
.57051 .22877 L
.56937 .26845 L
s
.56479 .22877 m
.58841 .18909 L
.59524 .1494 L
.58841 .10972 L
.56479 .07004 L
s
.56937 .03036 m
0 0 rlineto s
.5 g
.56937 .1494 m
.56479 .1494 L
.57051 .1494 L
.56937 .1494 L
F
.57051 .1494 m
.56479 .1494 L
.58841 .1494 L
.5712 .1494 L
.57051 .1494 L
F
.5712 .1494 m
.58841 .1494 L
.59524 .1494 L
.57143 .1494 L
.5712 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.58841 .1494 L
.5712 .1494 L
.57143 .1494 L
F
.5712 .1494 m
.58841 .1494 L
.56479 .1494 L
.57051 .1494 L
.5712 .1494 L
F
.57051 .1494 m
.56479 .1494 L
.56937 .1494 L
.57051 .1494 L
F
0 g
.56937 .1494 m
.57051 .1494 L
.5712 .1494 L
.57143 .1494 L
.5712 .1494 L
.57051 .1494 L
.56937 .1494 L
s
.56479 .1494 m
.58841 .1494 L
.59524 .1494 L
.58841 .1494 L
.56479 .1494 L
s
.56937 .1494 m
0 0 rlineto s
.52961 .26845 m
.56937 .26845 L
.56937 .2644 L
.52961 .2644 L
.52961 .26845 L
s
.52961 .2644 m
.56937 .2644 L
.56937 .2525 L
.52961 .2525 L
.52961 .2644 L
s
.52961 .2525 m
.56937 .2525 L
.56937 .23358 L
.52961 .23358 L
.52961 .2525 L
s
.52961 .23358 m
.56937 .23358 L
.56937 .20893 L
.52961 .20893 L
.52961 .23358 L
s
.52961 .20893 m
.56937 .20893 L
.56937 .18022 L
.52961 .18022 L
.52961 .20893 L
s
.52961 .18022 m
.56937 .18022 L
.56937 .1494 L
.52961 .1494 L
.52961 .18022 L
s
.52961 .1494 m
.56937 .1494 L
.56937 .11859 L
.52961 .11859 L
.52961 .1494 L
s
.52961 .11859 m
.56937 .11859 L
.56937 .08988 L
.52961 .08988 L
.52961 .11859 L
s
.52961 .08988 m
.56937 .08988 L
.56937 .06523 L
.52961 .06523 L
.52961 .08988 L
s
.52961 .06523 m
.56937 .06523 L
.56937 .04631 L
.52961 .04631 L
.52961 .06523 L
s
.52961 .04631 m
.56937 .04631 L
.56937 .03441 L
.52961 .03441 L
.52961 .04631 L
s
.52961 .03441 m
.56937 .03441 L
.56937 .03036 L
.52961 .03036 L
.52961 .03441 L
s
.52961 .03036 m
.56937 .03036 L
.56937 .03441 L
.52961 .03441 L
.52961 .03036 L
s
.52961 .03441 m
.56937 .03441 L
.56937 .04631 L
.52961 .04631 L
.52961 .03441 L
s
.52961 .04631 m
.56937 .04631 L
.56937 .06523 L
.52961 .06523 L
.52961 .04631 L
s
.52961 .06523 m
.56937 .06523 L
.56937 .08988 L
.52961 .08988 L
.52961 .06523 L
s
.52961 .08988 m
.56937 .08988 L
.56937 .11859 L
.52961 .11859 L
.52961 .08988 L
s
.52961 .11859 m
.56937 .11859 L
.56937 .1494 L
.52961 .1494 L
.52961 .11859 L
s
.52961 .1494 m
.56937 .1494 L
.56937 .18022 L
.52961 .18022 L
.52961 .1494 L
s
.52961 .18022 m
.56937 .18022 L
.56937 .20893 L
.52961 .20893 L
.52961 .18022 L
s
.52961 .20893 m
.56937 .20893 L
.56937 .23358 L
.52961 .23358 L
.52961 .20893 L
s
.52961 .23358 m
.56937 .23358 L
.56937 .2525 L
.52961 .2525 L
.52961 .23358 L
s
.52961 .2525 m
.56937 .2525 L
.56937 .2644 L
.52961 .2644 L
.52961 .2525 L
s
.52961 .2644 m
.56937 .2644 L
.56937 .26845 L
.52961 .26845 L
.52961 .2644 L
s
.56937 .26845 m
0 0 rlineto s
.56937 .2644 m
.56937 .26845 L
s
.56937 .2644 m
0 0 rlineto s
.56937 .2525 m
.56937 .2644 L
s
.56937 .2525 m
0 0 rlineto s
.56937 .23358 m
.56937 .2525 L
s
.56937 .23358 m
0 0 rlineto s
.56937 .20893 m
.56937 .23358 L
s
.56937 .20893 m
0 0 rlineto s
.56937 .18022 m
.56937 .20893 L
s
.56937 .18022 m
0 0 rlineto s
.56937 .1494 m
.56937 .18022 L
s
.56937 .1494 m
0 0 rlineto s
.56937 .11859 m
.56937 .1494 L
s
.56937 .11859 m
0 0 rlineto s
.56937 .08988 m
.56937 .11859 L
s
.56937 .08988 m
0 0 rlineto s
.56937 .06523 m
.56937 .08988 L
s
.56937 .06523 m
0 0 rlineto s
.56937 .04631 m
.56937 .06523 L
s
.56937 .04631 m
0 0 rlineto s
.56937 .03441 m
.56937 .04631 L
s
.56937 .03441 m
0 0 rlineto s
.56937 .03036 m
.56937 .03441 L
s
.56937 .03036 m
0 0 rlineto s
.56937 .03441 m
.56937 .03036 L
s
.56937 .03441 m
0 0 rlineto s
.56937 .04631 m
.56937 .03441 L
s
.56937 .04631 m
0 0 rlineto s
.56937 .06523 m
.56937 .04631 L
s
.56937 .06523 m
0 0 rlineto s
.56937 .08988 m
.56937 .06523 L
s
.56937 .08988 m
0 0 rlineto s
.56937 .11859 m
.56937 .08988 L
s
.56937 .11859 m
0 0 rlineto s
.56937 .1494 m
.56937 .11859 L
s
.56937 .1494 m
0 0 rlineto s
.56937 .18022 m
.56937 .1494 L
s
.56937 .18022 m
0 0 rlineto s
.56937 .20893 m
.56937 .18022 L
s
.56937 .20893 m
0 0 rlineto s
.56937 .23358 m
.56937 .20893 L
s
.56937 .23358 m
0 0 rlineto s
.56937 .2525 m
.56937 .23358 L
s
.56937 .2525 m
0 0 rlineto s
.56937 .2644 m
.56937 .2525 L
s
.56937 .2644 m
0 0 rlineto s
.56937 .26845 m
.56937 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.50112 .1256 L
s
0 0 0 r
2 Mabswid
.50112 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.5004 .13512 L
s
0 0 0 r
2 Mabswid
.5004 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.50004 .14464 L
s
0 0 0 r
2 Mabswid
.50004 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.50004 .15417 L
s
0 0 0 r
2 Mabswid
.50004 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.5004 .16369 L
s
0 0 0 r
2 Mabswid
.5004 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.50112 .17321 L
s
0 0 0 r
2 Mabswid
.50112 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.50112 .1256 m
.57136 .1278 L
s
0 0 0 r
2 Mabswid
.57136 .1278 Mdot
.039 .916 .04 r
.5 Mabswid
.5004 .13512 m
.5714 .13645 L
s
0 0 0 r
2 Mabswid
.5714 .13645 Mdot
.039 .916 .04 r
.5 Mabswid
.50004 .14464 m
.57143 .14509 L
s
0 0 0 r
2 Mabswid
.57143 .14509 Mdot
.039 .916 .04 r
.5 Mabswid
.50004 .15417 m
.57143 .15372 L
s
0 0 0 r
2 Mabswid
.57143 .15372 Mdot
.039 .916 .04 r
.5 Mabswid
.5004 .16369 m
.5714 .16236 L
s
0 0 0 r
2 Mabswid
.5714 .16236 Mdot
.039 .916 .04 r
.5 Mabswid
.50112 .17321 m
.57136 .17101 L
s
0 0 0 r
2 Mabswid
.57136 .17101 Mdot
.039 .916 .04 r
.5 Mabswid
.57136 .1278 m
.59335 .12835 L
s
0 0 0 r
2 Mabswid
.59335 .12835 Mdot
.039 .916 .04 r
.5 Mabswid
.5714 .13645 m
.59457 .1368 L
s
0 0 0 r
2 Mabswid
.59457 .1368 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .14509 m
.59516 .14521 L
s
0 0 0 r
2 Mabswid
.59516 .14521 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .15372 m
.59516 .1536 L
s
0 0 0 r
2 Mabswid
.59516 .1536 Mdot
.039 .916 .04 r
.5 Mabswid
.5714 .16236 m
.59457 .16201 L
s
0 0 0 r
2 Mabswid
.59457 .16201 Mdot
.039 .916 .04 r
.5 Mabswid
.57136 .17101 m
.59335 .17046 L
s
0 0 0 r
2 Mabswid
.59335 .17046 Mdot
.039 .916 .04 r
.5 Mabswid
.59335 .12835 m
.97619 .20346 L
s
0 0 0 r
2 Mabswid
.97619 .20346 Mdot
.039 .916 .04 r
.5 Mabswid
.59457 .1368 m
.97619 .18023 L
s
0 0 0 r
2 Mabswid
.97619 .18023 Mdot
.039 .916 .04 r
.5 Mabswid
.59516 .14521 m
.97619 .15943 L
s
0 0 0 r
2 Mabswid
.97619 .15943 Mdot
.039 .916 .04 r
.5 Mabswid
.59516 .1536 m
.97619 .13938 L
s
0 0 0 r
2 Mabswid
.97619 .13938 Mdot
.039 .916 .04 r
.5 Mabswid
.59457 .16201 m
.97619 .11858 L
s
0 0 0 r
2 Mabswid
.97619 .11858 Mdot
.039 .916 .04 r
.5 Mabswid
.59335 .17046 m
.97619 .09535 L
s
0 0 0 r
2 Mabswid
.97619 .09535 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo002Rooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03_ooool0
09Oooooo3?l0001/ooooo`03o`000?oooooooooo00kooooo002Gooooo`co0000K?ooool00ol0003o
ooooooooo`0>ooooo`00U_ooool2o`0000[oOgmo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`0>ooooo`00U_ooool2o`0000[oOgmo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`0>ooooo`00UOooool00ol0003oOgmoo`00000;o`0006cooooo00?o0000ooooooooool03_ooool0
09Gooooo00?o0000ogmoOol000002_moOgl00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
00kooooo002Dooooo`04o`000?moOgooOgmoo`0000[oOgmo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`0>ooooo`00U?ooool01?l0003oOgmoogmoOol0000:ogmoO`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool03_ooool009?ooooo00Go0000ogmoOomoOgooOgmoo`00000:ogmo
O`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03_ooool009?ooooo00Co0000ogmoOomo
OgooOgmo3?l0001/ooooo`03o`000?oooooooooo00kooooo002Booooo`03o`000?moOgooOgmo00;o
Ogmo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoo`00001/ooooo`03o`000?oooooooooo00ko
oooo002Booooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmo
o`00001/ooooo`03o`000?oooooooooo00kooooo002Booooo`03o`000?moOgooOgmo00;oOgmo00?o
0000ogmoOomoOgl01omoOgl2o`0006cooooo00?o0000ooooooooool03_ooool009;ooooo00?o0000
ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`08ogmoO`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool03_ooool0097ooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`08ogmo
O`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03_ooool0097ooooo00?o0000ogmoOomo
Ogl00omoOgl00ol0003oOgmoogmoO`08ogmoO`;o0000Joooool00ol0003oooooooooo`0>ooooo`00
TOooool00ol0003oOgmoogmoO`03ogmoO`co000000?oOgmoo`000?ooool0JOooool00ol0003ooooo
ooooo`0>ooooo`00TOooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00SoOgmo00?o
0000ogmoOol00000Ioooool3o`WZ2P;o00003oooool0097ooooo00?o0000ogmoOomoOgl00omoOgl0
0ol0003oOgmoogmoO`08ogmoO`04o`000?moOgooOgmoo`00067ooooo1Ol9jPX3ooooo`;o00003ooo
ool0093ooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`08ogmoO`04o`000?moOgoo
Ogmoo`0005cooooo1Ol9jPX8ooooo`03o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgoo
Ogmo00CoOgmo00?o0000ogmoOomoOgl02?moOgl01Ol0003oOgmoogmoOomoOgoo000005Kooooo1Ol9
jPX=ooooo`03o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgooOgmo00CoOgmo00?o0000
ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo04kooooo1Ol9jPXB
ooooo`03o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmo
OomoOgl02?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo04Wooooo1Ol9jPXGoooo
o`03o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgooOgmo00CoOgmo3?l00004ogmoO`03
o`000?oooooooooo04Cooooo1Ol9jPXHooooo`Co2NX:0_l0000?ooooo`00T?ooool00ol0003oOgmo
ogmoO`04ogmoO`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003ooooo
ooooo`0nooooo`Ko2NX:5?ooool9o`WZ2PCooooo0_l0000?ooooo`003ooooon;o`WZ2PSoOgmo0_l0
0004ogmoO`03o`000?oooooooooo03Sooooo1Ol9jPXBooooo`So2NX:3Oooool00ol0003ooooooooo
o`0>ooooo`00Soooool2o`0000KoOgmo00?o0000ogmoOomoOgl04_l9jPXbooooo`Go2NX:3_ooool9
o`WZ2QGooooo00?o0000ooooooooool03_ooool008oooooo0_l00006ogmoO`03o`000?moOgooOgmo
00SoOgmo00?o0000ogmoOomoOgl00omoOgl2o`0000;ooooo1Ol9jPXXooooo`Go2NX:2_ooool9o`WZ
2Qkooooo00?o0000ooooooooool03_ooool000ooooooW_l9jPX4ooooo`Go2NX:7_ooool5o`WZ2POo
oooo2?l9jPXWooooo`03o`000?oooooooooo00kooooo002?ooooo`03o`000?moOgooOgmo00GoOgmo
00?o0000ogmoOomoOgl02?moOgl2o`0000CoOgmo0_l00003ooooo`ko2NX:5?ooool5o`WZ2P?ooooo
2Ol9jPXRooooo`go2NX:0_l0000?ooooo`003ooooon;o`WZ2PSoOgmo0_l00004ogmoO`;o00003?oo
ool:o`WZ2PWooooo3_l9jPXBoooooaWo2NX:3Oooool2o`0000oooooo002?ooooo`;o00001_moOgl0
0ol0003oOgmoogmoO`0>o`WZ2P03o`000?l9jP[o2NX:013o2NX:0oooool[o`WZ2RKooooo00?o0000
ooooooooool03_ooool008oooooo6ol0000<ooooobOo2NX:<_ooool00ol0003oooooooooo`0>oooo
o`003ooooonIo`WZ2P03o`000?l9jP[o2NX:01Co2NX:2oooool>o`WZ2PGooooo8_l9jPX@ooooo`03
o`000?oooooooooo00kooooo002?ooooo`;o00001_moOgl00ol0003oOgmoogmoO`08ogmoO`03o`00
0?moOgooOgmo00CoOgmo00?o0000ooooooooool03_l9jPXFooooo`Go2NX:0oooool9o`WZ2Qkooooo
4?l9jPX2o`0000oooooo002?ooooo`;o00001_moOgl00ol0003oOgmoo`WZ2P0Bo`WZ2PCooooo1Ol9
jPXPooooo`Go2NX:1oooool8o`WZ2RKooooo0_l0000?ooooo`003ooooon:o`WZ2PWoOgmo0_l00004
ogmoO`;o000000?oooooo`WZ2_l9jPX00ol9jPXZooooo`Go2NX:2_ooool9o`WZ2Qgooooo00?o0000
ooooooooool03_ooool008oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`08ogmo
O`;o000000?oOgmoo`WZ2_l9jPX01?l9jPXdooooo`Go2NX:3_ooool9o`WZ2QCooooo00?o0000oooo
ooooool03_ooool000ooooooU_l9jPX3ogmoO`;o0000>_ooool5o`WZ2Q;ooooo2?l9jPX<ooooo`03
o`000?oooooooooo00kooooo002?ooooo`;o00001_moOgl00ol0003oOgmoogmoO`08ogmoO`03o`00
0?moOgooOgmo00?oOgmo00?o0000ooooooooool0?_ooool6o`WZ2QCooooo2Ol9jPX3ooooo`03o`00
0?oooooooooo00kooooo002@ooooo`03o`000?moOgooOgmo00CoOgmo3?l00004ogmoO`03o`000?oo
oooooooo04Gooooo1Ol9jPXHooooo`?o2NX:0_l0000?ooooo`00T?ooool00ol0003oOgmoogmoO`04
ogmoO`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1:
ooooo`Go2NX:5_ooool2o`0000oooooo002@ooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmo
OomoOgl02?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo04oooooo1Ol9jPXAoooo
o`03o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomo
Ogl02?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo05Cooooo1Ol9jPX<ooooo`03
o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl0
2?moOgl01Ol0003oOgmoogmoOomoOgoo000005cooooo1Ol9jPX7ooooo`03o`000?oooooooooo00ko
oooo002@ooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl02?moOgl01?l0003oOgmo
ogmoOol0001Rooooo`Go2NX:0_ooool00ol0003oooooooooo`0>ooooo`00TOooool00ol0003oOgmo
ogmoO`03ogmoO`03o`000?moOgooOgmo00SoOgmo00Co0000ogmoOomoOgoo0000Ioooool2o`WZ2P;o
00003oooool0097ooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`08ogmoO`03o`00
0?moOgoo000006[ooooo0_l0000?ooooo`00TOooool00ol0003oOgmoogmoO`03ogmoO`go0000Jooo
ool00ol0003oooooooooo`0>ooooo`00TOooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgoo
Ogmo00SoOgmo0_l0001[ooooo`03o`000?oooooooooo00kooooo002Aooooo`03o`000?moOgooOgmo
00?oOgmo00?o0000ogmoOomoOgl02?moOgl00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
00kooooo002Booooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl02?moOgl00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo00kooooo002Booooo`03o`000?moOgooOgmo00;oOgmo
00?o0000ogmoOomoOgl01omoOgl2o`0006cooooo00?o0000ooooooooool03_ooool009;ooooo00?o
0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgoo000006cooooo00?o
0000ooooooooool03_ooool009;ooooo00?o0000ogmoOomoOgl00_moOgl<o`0006cooooo00?o0000
ooooooooool03_ooool009?ooooo00Go0000ogmoOomoOgooOgmoo`00000:ogmoO`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool03_ooool009?ooooo00Go0000ogmoOomoOgooOgmoo`00000:
ogmoO`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03_ooool009Cooooo00Co0000ogmo
OomoOgoo00002_moOgl00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00kooooo002Doooo
o`04o`000?moOgooOgmoo`0000[oOgmo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0>
ooooo`00UOooool00ol0003oOgmoo`00000;o`0006cooooo00?o0000ooooooooool03_ooool009Go
oooo00?o0000ogmoOol000002_moOgl00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00ko
oooo002Eooooo`03o`000?moOgoo000000[oOgmo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`0>ooooo`00U_ooool2o`0000[oOgmo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`0>ooooo`00U_ooool=o`0006cooooo00?o0000ooooooooool03_ooool009Oooooo3?l0001/oooo
o`03o`000?oooooooooo00kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.54958 .03036 m
.55795 .03036 L
.56548 .07004 L
.51997 .07004 L
.54958 .03036 L
F
.51997 .07004 m
.56548 .07004 L
.56995 .10972 L
.50476 .10972 L
.51997 .07004 L
F
.50476 .10972 m
.56995 .10972 L
.57143 .1494 L
.5 .1494 L
.50476 .10972 L
F
.5 .1494 m
.57143 .1494 L
.56995 .18909 L
.50476 .18909 L
.5 .1494 L
F
.50476 .18909 m
.56995 .18909 L
.56548 .22877 L
.51997 .22877 L
.50476 .18909 L
F
.51997 .22877 m
.56548 .22877 L
.55795 .26845 L
.54958 .26845 L
.51997 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.54958 .03036 m
.51997 .07004 L
.50476 .10972 L
.5 .1494 L
.50476 .18909 L
.51997 .22877 L
.54958 .26845 L
.55795 .26845 L
.56548 .22877 L
.56995 .18909 L
.57143 .1494 L
.56995 .10972 L
.56548 .07004 L
.55795 .03036 L
.54958 .03036 L
s
.5 g
.54958 .1494 m
.55795 .1494 L
.56548 .1494 L
.51997 .1494 L
.54958 .1494 L
F
.51997 .1494 m
.56548 .1494 L
.56995 .1494 L
.50476 .1494 L
.51997 .1494 L
F
.50476 .1494 m
.56995 .1494 L
.57143 .1494 L
.5 .1494 L
.50476 .1494 L
F
.5 .1494 m
.57143 .1494 L
.56995 .1494 L
.50476 .1494 L
.5 .1494 L
F
.50476 .1494 m
.56995 .1494 L
.56548 .1494 L
.51997 .1494 L
.50476 .1494 L
F
.51997 .1494 m
.56548 .1494 L
.55795 .1494 L
.54958 .1494 L
.51997 .1494 L
F
0 g
.54958 .1494 m
.51997 .1494 L
.50476 .1494 L
.5 .1494 L
.50476 .1494 L
.51997 .1494 L
.54958 .1494 L
.55795 .1494 L
.56548 .1494 L
.56995 .1494 L
.57143 .1494 L
.56995 .1494 L
.56548 .1494 L
.55795 .1494 L
.54958 .1494 L
s
.5 g
.55795 .03036 m
.59883 .03036 L
.59683 .07004 L
.56548 .07004 L
.55795 .03036 L
F
.56548 .07004 m
.59683 .07004 L
.59564 .10972 L
.56995 .10972 L
.56548 .07004 L
F
.56995 .10972 m
.59564 .10972 L
.59524 .1494 L
.57143 .1494 L
.56995 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59564 .18909 L
.56995 .18909 L
.57143 .1494 L
F
.56995 .18909 m
.59564 .18909 L
.59683 .22877 L
.56548 .22877 L
.56995 .18909 L
F
.56548 .22877 m
.59683 .22877 L
.59883 .26845 L
.55795 .26845 L
.56548 .22877 L
F
0 g
.55795 .03036 m
.56548 .07004 L
.56995 .10972 L
.57143 .1494 L
.56995 .18909 L
.56548 .22877 L
.55795 .26845 L
.59883 .26845 L
.59683 .22877 L
.59564 .18909 L
.59524 .1494 L
.59564 .10972 L
.59683 .07004 L
.59883 .03036 L
.55795 .03036 L
s
.5 g
.55795 .1494 m
.59883 .1494 L
.59683 .1494 L
.56548 .1494 L
.55795 .1494 L
F
.56548 .1494 m
.59683 .1494 L
.59564 .1494 L
.56995 .1494 L
.56548 .1494 L
F
.56995 .1494 m
.59564 .1494 L
.59524 .1494 L
.57143 .1494 L
.56995 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59564 .1494 L
.56995 .1494 L
.57143 .1494 L
F
.56995 .1494 m
.59564 .1494 L
.59683 .1494 L
.56548 .1494 L
.56995 .1494 L
F
.56548 .1494 m
.59683 .1494 L
.59883 .1494 L
.55795 .1494 L
.56548 .1494 L
F
0 g
.55795 .1494 m
.56548 .1494 L
.56995 .1494 L
.57143 .1494 L
.56995 .1494 L
.56548 .1494 L
.55795 .1494 L
.59883 .1494 L
.59683 .1494 L
.59564 .1494 L
.59524 .1494 L
.59564 .1494 L
.59683 .1494 L
.59883 .1494 L
.55795 .1494 L
s
.54958 .26845 m
.55795 .26845 L
.55795 .2644 L
.54958 .2644 L
.54958 .26845 L
s
.54958 .2644 m
.55795 .2644 L
.55795 .2525 L
.54958 .2525 L
.54958 .2644 L
s
.54958 .2525 m
.55795 .2525 L
.55795 .23358 L
.54958 .23358 L
.54958 .2525 L
s
.54958 .23358 m
.55795 .23358 L
.55795 .20893 L
.54958 .20893 L
.54958 .23358 L
s
.54958 .20893 m
.55795 .20893 L
.55795 .18022 L
.54958 .18022 L
.54958 .20893 L
s
.54958 .18022 m
.55795 .18022 L
.55795 .1494 L
.54958 .1494 L
.54958 .18022 L
s
.54958 .1494 m
.55795 .1494 L
.55795 .11859 L
.54958 .11859 L
.54958 .1494 L
s
.54958 .11859 m
.55795 .11859 L
.55795 .08988 L
.54958 .08988 L
.54958 .11859 L
s
.54958 .08988 m
.55795 .08988 L
.55795 .06523 L
.54958 .06523 L
.54958 .08988 L
s
.54958 .06523 m
.55795 .06523 L
.55795 .04631 L
.54958 .04631 L
.54958 .06523 L
s
.54958 .04631 m
.55795 .04631 L
.55795 .03441 L
.54958 .03441 L
.54958 .04631 L
s
.54958 .03441 m
.55795 .03441 L
.55795 .03036 L
.54958 .03036 L
.54958 .03441 L
s
.54958 .03036 m
.55795 .03036 L
.55795 .03441 L
.54958 .03441 L
.54958 .03036 L
s
.54958 .03441 m
.55795 .03441 L
.55795 .04631 L
.54958 .04631 L
.54958 .03441 L
s
.54958 .04631 m
.55795 .04631 L
.55795 .06523 L
.54958 .06523 L
.54958 .04631 L
s
.54958 .06523 m
.55795 .06523 L
.55795 .08988 L
.54958 .08988 L
.54958 .06523 L
s
.54958 .08988 m
.55795 .08988 L
.55795 .11859 L
.54958 .11859 L
.54958 .08988 L
s
.54958 .11859 m
.55795 .11859 L
.55795 .1494 L
.54958 .1494 L
.54958 .11859 L
s
.54958 .1494 m
.55795 .1494 L
.55795 .18022 L
.54958 .18022 L
.54958 .1494 L
s
.54958 .18022 m
.55795 .18022 L
.55795 .20893 L
.54958 .20893 L
.54958 .18022 L
s
.54958 .20893 m
.55795 .20893 L
.55795 .23358 L
.54958 .23358 L
.54958 .20893 L
s
.54958 .23358 m
.55795 .23358 L
.55795 .2525 L
.54958 .2525 L
.54958 .23358 L
s
.54958 .2525 m
.55795 .2525 L
.55795 .2644 L
.54958 .2644 L
.54958 .2525 L
s
.54958 .2644 m
.55795 .2644 L
.55795 .26845 L
.54958 .26845 L
.54958 .2644 L
s
.55795 .26845 m
.59883 .26845 L
.59883 .2644 L
.55795 .2644 L
.55795 .26845 L
s
.55795 .2644 m
.59883 .2644 L
.59883 .2525 L
.55795 .2525 L
.55795 .2644 L
s
.55795 .2525 m
.59883 .2525 L
.59883 .23358 L
.55795 .23358 L
.55795 .2525 L
s
.55795 .23358 m
.59883 .23358 L
.59883 .20893 L
.55795 .20893 L
.55795 .23358 L
s
.55795 .20893 m
.59883 .20893 L
.59883 .18022 L
.55795 .18022 L
.55795 .20893 L
s
.55795 .18022 m
.59883 .18022 L
.59883 .1494 L
.55795 .1494 L
.55795 .18022 L
s
.55795 .1494 m
.59883 .1494 L
.59883 .11859 L
.55795 .11859 L
.55795 .1494 L
s
.55795 .11859 m
.59883 .11859 L
.59883 .08988 L
.55795 .08988 L
.55795 .11859 L
s
.55795 .08988 m
.59883 .08988 L
.59883 .06523 L
.55795 .06523 L
.55795 .08988 L
s
.55795 .06523 m
.59883 .06523 L
.59883 .04631 L
.55795 .04631 L
.55795 .06523 L
s
.55795 .04631 m
.59883 .04631 L
.59883 .03441 L
.55795 .03441 L
.55795 .04631 L
s
.55795 .03441 m
.59883 .03441 L
.59883 .03036 L
.55795 .03036 L
.55795 .03441 L
s
.55795 .03036 m
.59883 .03036 L
.59883 .03441 L
.55795 .03441 L
.55795 .03036 L
s
.55795 .03441 m
.59883 .03441 L
.59883 .04631 L
.55795 .04631 L
.55795 .03441 L
s
.55795 .04631 m
.59883 .04631 L
.59883 .06523 L
.55795 .06523 L
.55795 .04631 L
s
.55795 .06523 m
.59883 .06523 L
.59883 .08988 L
.55795 .08988 L
.55795 .06523 L
s
.55795 .08988 m
.59883 .08988 L
.59883 .11859 L
.55795 .11859 L
.55795 .08988 L
s
.55795 .11859 m
.59883 .11859 L
.59883 .1494 L
.55795 .1494 L
.55795 .11859 L
s
.55795 .1494 m
.59883 .1494 L
.59883 .18022 L
.55795 .18022 L
.55795 .1494 L
s
.55795 .18022 m
.59883 .18022 L
.59883 .20893 L
.55795 .20893 L
.55795 .18022 L
s
.55795 .20893 m
.59883 .20893 L
.59883 .23358 L
.55795 .23358 L
.55795 .20893 L
s
.55795 .23358 m
.59883 .23358 L
.59883 .2525 L
.55795 .2525 L
.55795 .23358 L
s
.55795 .2525 m
.59883 .2525 L
.59883 .2644 L
.55795 .2644 L
.55795 .2525 L
s
.55795 .2644 m
.59883 .2644 L
.59883 .26845 L
.55795 .26845 L
.55795 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.5017 .1256 L
s
0 0 0 r
2 Mabswid
.5017 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.50061 .13512 L
s
0 0 0 r
2 Mabswid
.50061 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.50007 .14464 L
s
0 0 0 r
2 Mabswid
.50007 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.50007 .15417 L
s
0 0 0 r
2 Mabswid
.50007 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.50061 .16369 L
s
0 0 0 r
2 Mabswid
.50061 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.5017 .17321 L
s
0 0 0 r
2 Mabswid
.5017 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.5017 .1256 m
.57103 .1289 L
s
0 0 0 r
2 Mabswid
.57103 .1289 Mdot
.039 .916 .04 r
.5 Mabswid
.50061 .13512 m
.57129 .13713 L
s
0 0 0 r
2 Mabswid
.57129 .13713 Mdot
.039 .916 .04 r
.5 Mabswid
.50007 .14464 m
.57141 .14532 L
s
0 0 0 r
2 Mabswid
.57141 .14532 Mdot
.039 .916 .04 r
.5 Mabswid
.50007 .15417 m
.57141 .15349 L
s
0 0 0 r
2 Mabswid
.57141 .15349 Mdot
.039 .916 .04 r
.5 Mabswid
.50061 .16369 m
.57129 .16168 L
s
0 0 0 r
2 Mabswid
.57129 .16168 Mdot
.039 .916 .04 r
.5 Mabswid
.5017 .17321 m
.57103 .16991 L
s
0 0 0 r
2 Mabswid
.57103 .16991 Mdot
.039 .916 .04 r
.5 Mabswid
.57103 .1289 m
.59534 .12971 L
s
0 0 0 r
2 Mabswid
.59534 .12971 Mdot
.039 .916 .04 r
.5 Mabswid
.57129 .13713 m
.59527 .13761 L
s
0 0 0 r
2 Mabswid
.59527 .13761 Mdot
.039 .916 .04 r
.5 Mabswid
.57141 .14532 m
.59524 .14548 L
s
0 0 0 r
2 Mabswid
.59524 .14548 Mdot
.039 .916 .04 r
.5 Mabswid
.57141 .15349 m
.59524 .15333 L
s
0 0 0 r
2 Mabswid
.59524 .15333 Mdot
.039 .916 .04 r
.5 Mabswid
.57129 .16168 m
.59527 .1612 L
s
0 0 0 r
2 Mabswid
.59527 .1612 Mdot
.039 .916 .04 r
.5 Mabswid
.57103 .16991 m
.59534 .1691 L
s
0 0 0 r
2 Mabswid
.59534 .1691 Mdot
.039 .916 .04 r
.5 Mabswid
.59534 .12971 m
.97619 .14948 L
s
0 0 0 r
2 Mabswid
.97619 .14948 Mdot
.039 .916 .04 r
.5 Mabswid
.59527 .13761 m
.97619 .14941 L
s
0 0 0 r
2 Mabswid
.97619 .14941 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .14548 m
.97619 .1494 L
s
0 0 0 r
2 Mabswid
.97619 .1494 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .15333 m
.97619 .14941 L
s
0 0 0 r
2 Mabswid
.97619 .14941 Mdot
.039 .916 .04 r
.5 Mabswid
.59527 .1612 m
.97619 .1494 L
s
0 0 0 r
2 Mabswid
.97619 .1494 Mdot
.039 .916 .04 r
.5 Mabswid
.59534 .1691 m
.97619 .14933 L
s
0 0 0 r
2 Mabswid
.97619 .14933 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool009cooooo3ol0001Toooo
o`03o`000?oooooooooo00kooooo002Looooo`oo0000I?ooool00ol0003oooooooooo`0>ooooo`00
Voooool2o`0000;oOgmo00?o0000ogmoOomoOgl02?moOgl00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo00kooooo002Jooooo`03o`000?moOgoo000000;oOgmo0_l00009ogmoO`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool03_ooool009Wooooo00?o0000ogmoOomoOgl03ol0001T
ooooo`03o`000?oooooooooo00kooooo002Hooooo`05o`000?moOgooOgmoogmoOol000000_moOgl2
o`0000WoOgmo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0>ooooo`00V?ooool01Ol0
003oOgmoogmoOomoOgoo000000;oOgmo0_l00008ogmoO`;o0000I?ooool00ol0003oooooooooo`0>
ooooo`00Uoooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00;o00002?moOgl2o`00
06Cooooo00?o0000ooooooooool03_ooool009Kooooo00?o0000ogmoOomoOgl00omoOgl01_l0003o
OgmoogmoOol0003oOgmoo`0000OoOgmo0_l0001Tooooo`03o`000?oooooooooo00kooooo002Eoooo
o`03o`000?moOgooOgmo00CoOgmo3ol0001Tooooo`03o`000?oooooooooo00kooooo002Dooooo`03
o`000?moOgooOgmo00GoOgmo00Ko0000ogmoOomoOgoo0000ogmoOol00007ogmoO`;o0000I?ooool0
0ol0003oooooooooo`0>ooooo`00U?ooool00ol0003oOgmoogmoO`05ogmoO`06o`000?moOgooOgmo
o`000?moOgoo00001omoOgl2o`0006Cooooo00?o0000ooooooooool03_ooool009?ooooo00?o0000
ogmoOomoOgl01_moOgl01_l0003oOgmoogmoOol0003oOgmoo`0000OoOgmo0_l0001Tooooo`03o`00
0?oooooooooo00kooooo002Cooooo`03o`000?moOgooOgmo00KoOgmo00Ko0000ogmoOomoOgoo0000
ogmoOol00007ogmoO`;o0000I?ooool00ol0003oooooooooo`0>ooooo`00Toooool00ol0003oOgmo
ogmoO`06ogmoO`06o`000?moOgooOgmoo`000?moOgoo00001omoOgl2o`0006Cooooo00?o0000oooo
ooooool03_ooool009;ooooo00?o0000ogmoOomoOgl01omoOgl01_l0003oOgmoogmoOol0003oOgmo
o`0000OoOgmo0_l0001Tooooo`03o`000?oooooooooo00kooooo002Booooo`03o`000?moOgooOgmo
00OoOgmo3ol0001Tooooo`03o`000?oooooooooo00kooooo002Booooo`03o`000?moOgooOgmo00Oo
Ogmo00Co0000ogmoOomoOgoo00000_moOgl00ol0003oOgmoogmoO`04ogmoO`;o0000I?ooool00ol0
003oooooooooo`0>ooooo`00TOooool00ol0003oOgmoogmoO`08ogmoO`04o`000?moOgooOgmoo`00
00;oOgmo00?o0000ogmoOomoOgl01?moOgl2o`0006Cooooo00?o0000ooooooooool03_ooool0097o
oooo00?o0000ogmoOomoOgl02?moOgl01?l0003oOgmoogmoOol00002ogmoO`03o`000?moOgooOgmo
00CoOgmo0_l0001Tooooo`03o`000?oooooooooo00kooooo002Aooooo`03o`000?moOgooOgmo00So
Ogmo00Co0000ogmoOomoOgoo00000_moOgl00ol0003oOgmoogmoO`04ogmoO`;o0000I?ooool00ol0
003oooooooooo`0>ooooo`00T?ooool00ol0003oOgmoogmoO`09ogmoO`04o`000?moOgooOgmoo`00
00;oOgmo00?o0000ogmoOomoOgl01?moOgl2o`0006Cooooo00?o0000ooooooooool03_ooool0093o
oooo00?o0000ogmoOomoOgl02OmoOgl01?l0003oOgmoogmoOol00002ogmoO`03o`000?moOgooOgmo
00CoOgmo0_l0001Tooooo`03o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgooOgmo00Wo
Ogmo3ol0001Tooooo`03o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgooOgmo00WoOgmo
00Co0000ogmoOomoOgoo00000_moOgl00ol0003oOgmoogmoO`04ogmoO`;o0000I?ooool00ol0003o
ooooooooo`0>ooooo`003ooooon;o`WZ2P;oOgmo00Co0000ogmoOomoOgoo00000_moOgl00ol0003o
OgmoogmoO`04ogmoO`;o0000I?ooool00ol0003oooooooooo`0>ooooo`00Soooool2o`0000WoOgmo
3_l9jPX00ol0003o2NX:o`WZ2P08o`WZ2Ucooooo00?o0000ooooooooool03_ooool008oooooo0_l0
000;ogmoO`04o`000?moOgooOgmoo`0000;oOgmo0_l00004ogmoO`?o00002?oooolAo`WZ2T_ooooo
00?o0000ooooooooool03_ooool000ooooooV?l9jPX01?moOgoo0000o`000?l0000Ioooooa7o2NX:
>_ooool00ol0003oooooooooo`0>ooooo`00Soooool00ol0003oOgmoogmoO`0:ogmoO`04o`000?mo
OgooOgmoo`0000;oOgmo0_l00003ogmoO`03o`WZ2_l0003o2NX:017o2NX:6_oooolAo`WZ2RWooooo
00?o0000ooooooooool03_ooool000ooooooRol9jPX2ogmoO`04o`000?moOgooOgmoo`0000;oOgmo
0_l00004ogmoO`?o00004?oooolRo`WZ2PWooooo4Ol9jPXHooooo`03o`000?oooooooooo00kooooo
002?ooooo`;o00002OmoOgl>o`WZ2P03o`000?l9jP[o2NX:05go2NX:1oooool2o`0000oooooo002?
oooooaco0000<Ooooolco`WZ2P;o00003oooool000ooooooVOl9jPX00ol0003o2NX:o`WZ2P1Jo`WZ
2P[ooooo00?o0000ooooooooool03_ooool008oooooo0_l0000;ogmoO`04o`000?moOgooOgmoo`00
00;oOgmo00?o0000ogmoOomoOgl00omoOgl3o`0000oooooo=_l9jPXOooooo`03o`000?oooooooooo
00kooooo002?ooooo`;o00002?moOgl?o`WZ2P03o`000?l9jP[o2NX:00oo2NX:3_oooolDo`WZ2S?o
oooo00?o0000ooooooooool03_ooool000ooooooR_l9jPX3ogmoO`04o`000?moOgooOgmoo`0000;o
Ogmo0_l00005ogmoO`;o00002?oooolEo`WZ2TOooooo00?o0000ooooooooool03_ooool008oooooo
00?o0000ogmoOomoOgl01omoOgl?o`WZ2P03o`000?l9jP[o2NX:00So2NX:G?ooool00ol0003ooooo
ooooo`0>ooooo`003ooooon:o`WZ2P?oOgmo00Co0000ogmoOomoOgoo00000_moOgl2o`0000CoOgmo
0ol0001Tooooo`03o`000?oooooooooo00kooooo002?ooooo`;o00002omoOgl01?l0003oOgmoogmo
Ool00002ogmoO`03o`000?moOgooOgmo00CoOgmo0_l0001Tooooo`03o`000?oooooooooo00kooooo
002@ooooo`03o`000?moOgooOgmo00WoOgmo3ol0001Tooooo`03o`000?oooooooooo00kooooo002@
ooooo`03o`000?moOgooOgmo00WoOgmo00Co0000ogmoOomoOgoo00000_moOgl00ol0003oOgmoogmo
O`04ogmoO`;o0000I?ooool00ol0003oooooooooo`0>ooooo`00T?ooool00ol0003oOgmoogmoO`09
ogmoO`04o`000?moOgooOgmoo`0000;oOgmo00?o0000ogmoOomoOgl01?moOgl2o`0006Cooooo00?o
0000ooooooooool03_ooool0093ooooo00?o0000ogmoOomoOgl02OmoOgl01?l0003oOgmoogmoOol0
0002ogmoO`03o`000?moOgooOgmo00CoOgmo0_l0001Tooooo`03o`000?oooooooooo00kooooo002A
ooooo`03o`000?moOgooOgmo00SoOgmo00Co0000ogmoOomoOgoo00000_moOgl00ol0003oOgmoogmo
O`04ogmoO`;o0000I?ooool00ol0003oooooooooo`0>ooooo`00TOooool00ol0003oOgmoogmoO`08
ogmoO`04o`000?moOgooOgmoo`0000;oOgmo00?o0000ogmoOomoOgl01?moOgl2o`0006Cooooo00?o
0000ooooooooool03_ooool0097ooooo00?o0000ogmoOomoOgl02?moOgl01?l0003oOgmoogmoOol0
0002ogmoO`03o`000?moOgooOgmo00CoOgmo0_l0001Tooooo`03o`000?oooooooooo00kooooo002B
ooooo`03o`000?moOgooOgmo00OoOgmo00Co0000ogmoOomoOgoo00000_moOgl00ol0003oOgmoogmo
O`04ogmoO`;o0000I?ooool00ol0003oooooooooo`0>ooooo`00T_ooool00ol0003oOgmoogmoO`07
ogmoO`oo0000I?ooool00ol0003oooooooooo`0>ooooo`00T_ooool00ol0003oOgmoogmoO`07ogmo
O`06o`000?moOgooOgmoo`000?moOgoo00001omoOgl2o`0006Cooooo00?o0000ooooooooool03_oo
ool009?ooooo00?o0000ogmoOomoOgl01_moOgl01_l0003oOgmoogmoOol0003oOgmoo`0000OoOgmo
0_l0001Tooooo`03o`000?oooooooooo00kooooo002Cooooo`03o`000?moOgooOgmo00KoOgmo00Ko
0000ogmoOomoOgoo0000ogmoOol00007ogmoO`;o0000I?ooool00ol0003oooooooooo`0>ooooo`00
Toooool00ol0003oOgmoogmoO`06ogmoO`06o`000?moOgooOgmoo`000?moOgoo00001omoOgl2o`00
06Cooooo00?o0000ooooooooool03_ooool009Cooooo00?o0000ogmoOomoOgl01OmoOgl01_l0003o
OgmoogmoOol0003oOgmoo`0000OoOgmo0_l0001Tooooo`03o`000?oooooooooo00kooooo002Doooo
o`03o`000?moOgooOgmo00GoOgmo3ol0001Tooooo`03o`000?oooooooooo00kooooo002Eooooo`03
o`000?moOgooOgmo00CoOgmo00Ko0000ogmoOomoOgoo0000ogmoOol00007ogmoO`;o0000I?ooool0
0ol0003oooooooooo`0>ooooo`00U_ooool00ol0003oOgmoogmoO`03ogmoO`06o`000?moOgooOgmo
o`000?moOgoo00001omoOgl2o`0006Cooooo00?o0000ooooooooool03_ooool009Oooooo00?o0000
ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`02o`0000SoOgmo0_l0001Tooooo`03o`000?oooooo
oooo00kooooo002Gooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00_l00008ogmo
O`;o0000I?ooool00ol0003oooooooooo`0>ooooo`00V?ooool01?l0003oOgmoogmoOomoOgl?o`00
06Cooooo00?o0000ooooooooool03_ooool009Wooooo00Co0000ogmoOomoOgoo00000_moOgl2o`00
00WoOgmo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0>ooooo`00VOooool01?l0003o
OgmoogmoOol00002ogmoO`;o00002OmoOgl00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
00kooooo002Jooooo`03o`000?moOgoo000000;oOgmo00?o0000ogmoOomoOgl02?moOgl00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo00kooooo002Koooooa3o0000I?ooool00ol0003ooooo
ooooo`0>ooooo`00W?ooool?o`0006Cooooo00?o0000ooooooooool03_ooool00?oooooo8Oooool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.55359 .03036 m
.57741 .03036 L
.57409 .07004 L
.52122 .07004 L
.55359 .03036 L
F
.52122 .07004 m
.57409 .07004 L
.57209 .10972 L
.50503 .10972 L
.52122 .07004 L
F
.50503 .10972 m
.57209 .10972 L
.57143 .1494 L
.5 .1494 L
.50503 .10972 L
F
.5 .1494 m
.57143 .1494 L
.57209 .18909 L
.50503 .18909 L
.5 .1494 L
F
.50503 .18909 m
.57209 .18909 L
.57409 .22877 L
.52122 .22877 L
.50503 .18909 L
F
.52122 .22877 m
.57409 .22877 L
.57741 .26845 L
.55359 .26845 L
.52122 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.55359 .03036 m
.52122 .07004 L
.50503 .10972 L
.5 .1494 L
.50503 .18909 L
.52122 .22877 L
.55359 .26845 L
.57741 .26845 L
.57409 .22877 L
.57209 .18909 L
.57143 .1494 L
.57209 .10972 L
.57409 .07004 L
.57741 .03036 L
.55359 .03036 L
s
.5 g
.55359 .1494 m
.57741 .1494 L
.57409 .1494 L
.52122 .1494 L
.55359 .1494 L
F
.52122 .1494 m
.57409 .1494 L
.57209 .1494 L
.50503 .1494 L
.52122 .1494 L
F
.50503 .1494 m
.57209 .1494 L
.57143 .1494 L
.5 .1494 L
.50503 .1494 L
F
.5 .1494 m
.57143 .1494 L
.57209 .1494 L
.50503 .1494 L
.5 .1494 L
F
.50503 .1494 m
.57209 .1494 L
.57409 .1494 L
.52122 .1494 L
.50503 .1494 L
F
.52122 .1494 m
.57409 .1494 L
.57741 .1494 L
.55359 .1494 L
.52122 .1494 L
F
0 g
.55359 .1494 m
.52122 .1494 L
.50503 .1494 L
.5 .1494 L
.50503 .1494 L
.52122 .1494 L
.55359 .1494 L
.57741 .1494 L
.57409 .1494 L
.57209 .1494 L
.57143 .1494 L
.57209 .1494 L
.57409 .1494 L
.57741 .1494 L
.55359 .1494 L
s
.5 g
.57741 .03036 m
.57409 .07004 L
.57741 .03036 L
F
.57409 .07004 m
.61013 .10972 L
.57209 .10972 L
.57409 .07004 L
F
.57209 .10972 m
.61013 .10972 L
.59524 .1494 L
.57143 .1494 L
.57209 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.61013 .18909 L
.57209 .18909 L
.57143 .1494 L
F
.57209 .18909 m
.61013 .18909 L
.57409 .22877 L
.57209 .18909 L
F
.57409 .22877 m
.57741 .26845 L
.57409 .22877 L
F
0 g
.57741 .03036 m
.57409 .07004 L
.57209 .10972 L
.57143 .1494 L
.57209 .18909 L
.57409 .22877 L
.57741 .26845 L
s
.61013 .18909 m
.59524 .1494 L
.61013 .10972 L
s
.57741 .03036 m
0 0 rlineto s
.5 g
.57741 .1494 m
.57409 .1494 L
.57741 .1494 L
F
.57409 .1494 m
.61013 .1494 L
.57209 .1494 L
.57409 .1494 L
F
.57209 .1494 m
.61013 .1494 L
.59524 .1494 L
.57143 .1494 L
.57209 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.61013 .1494 L
.57209 .1494 L
.57143 .1494 L
F
.57209 .1494 m
.61013 .1494 L
.57409 .1494 L
.57209 .1494 L
F
.57409 .1494 m
.57741 .1494 L
.57409 .1494 L
F
0 g
.57741 .1494 m
.57409 .1494 L
.57209 .1494 L
.57143 .1494 L
.57209 .1494 L
.57409 .1494 L
.57741 .1494 L
s
.61013 .1494 m
.59524 .1494 L
.61013 .1494 L
s
.57741 .1494 m
0 0 rlineto s
.55359 .26845 m
.57741 .26845 L
.57741 .2644 L
.55359 .2644 L
.55359 .26845 L
s
.55359 .2644 m
.57741 .2644 L
.57741 .2525 L
.55359 .2525 L
.55359 .2644 L
s
.55359 .2525 m
.57741 .2525 L
.57741 .23358 L
.55359 .23358 L
.55359 .2525 L
s
.55359 .23358 m
.57741 .23358 L
.57741 .20893 L
.55359 .20893 L
.55359 .23358 L
s
.55359 .20893 m
.57741 .20893 L
.57741 .18022 L
.55359 .18022 L
.55359 .20893 L
s
.55359 .18022 m
.57741 .18022 L
.57741 .1494 L
.55359 .1494 L
.55359 .18022 L
s
.55359 .1494 m
.57741 .1494 L
.57741 .11859 L
.55359 .11859 L
.55359 .1494 L
s
.55359 .11859 m
.57741 .11859 L
.57741 .08988 L
.55359 .08988 L
.55359 .11859 L
s
.55359 .08988 m
.57741 .08988 L
.57741 .06523 L
.55359 .06523 L
.55359 .08988 L
s
.55359 .06523 m
.57741 .06523 L
.57741 .04631 L
.55359 .04631 L
.55359 .06523 L
s
.55359 .04631 m
.57741 .04631 L
.57741 .03441 L
.55359 .03441 L
.55359 .04631 L
s
.55359 .03441 m
.57741 .03441 L
.57741 .03036 L
.55359 .03036 L
.55359 .03441 L
s
.55359 .03036 m
.57741 .03036 L
.57741 .03441 L
.55359 .03441 L
.55359 .03036 L
s
.55359 .03441 m
.57741 .03441 L
.57741 .04631 L
.55359 .04631 L
.55359 .03441 L
s
.55359 .04631 m
.57741 .04631 L
.57741 .06523 L
.55359 .06523 L
.55359 .04631 L
s
.55359 .06523 m
.57741 .06523 L
.57741 .08988 L
.55359 .08988 L
.55359 .06523 L
s
.55359 .08988 m
.57741 .08988 L
.57741 .11859 L
.55359 .11859 L
.55359 .08988 L
s
.55359 .11859 m
.57741 .11859 L
.57741 .1494 L
.55359 .1494 L
.55359 .11859 L
s
.55359 .1494 m
.57741 .1494 L
.57741 .18022 L
.55359 .18022 L
.55359 .1494 L
s
.55359 .18022 m
.57741 .18022 L
.57741 .20893 L
.55359 .20893 L
.55359 .18022 L
s
.55359 .20893 m
.57741 .20893 L
.57741 .23358 L
.55359 .23358 L
.55359 .20893 L
s
.55359 .23358 m
.57741 .23358 L
.57741 .2525 L
.55359 .2525 L
.55359 .23358 L
s
.55359 .2525 m
.57741 .2525 L
.57741 .2644 L
.55359 .2644 L
.55359 .2525 L
s
.55359 .2644 m
.57741 .2644 L
.57741 .26845 L
.55359 .26845 L
.55359 .2644 L
s
.57741 .26845 m
0 0 rlineto s
.57741 .2644 m
.57741 .26845 L
s
.57741 .2644 m
0 0 rlineto s
.57741 .2525 m
.57741 .2644 L
s
.57741 .2525 m
0 0 rlineto s
.57741 .23358 m
.57741 .2525 L
s
.57741 .23358 m
0 0 rlineto s
.57741 .20893 m
.57741 .23358 L
s
.57741 .20893 m
0 0 rlineto s
.57741 .18022 m
.57741 .20893 L
s
.57741 .18022 m
0 0 rlineto s
.57741 .1494 m
.57741 .18022 L
s
.57741 .1494 m
0 0 rlineto s
.57741 .11859 m
.57741 .1494 L
s
.57741 .11859 m
0 0 rlineto s
.57741 .08988 m
.57741 .11859 L
s
.57741 .08988 m
0 0 rlineto s
.57741 .06523 m
.57741 .08988 L
s
.57741 .06523 m
0 0 rlineto s
.57741 .04631 m
.57741 .06523 L
s
.57741 .04631 m
0 0 rlineto s
.57741 .03441 m
.57741 .04631 L
s
.57741 .03441 m
0 0 rlineto s
.57741 .03036 m
.57741 .03441 L
s
.57741 .03036 m
0 0 rlineto s
.57741 .03441 m
.57741 .03036 L
s
.57741 .03441 m
0 0 rlineto s
.57741 .04631 m
.57741 .03441 L
s
.57741 .04631 m
0 0 rlineto s
.57741 .06523 m
.57741 .04631 L
s
.57741 .06523 m
0 0 rlineto s
.57741 .08988 m
.57741 .06523 L
s
.57741 .08988 m
0 0 rlineto s
.57741 .11859 m
.57741 .08988 L
s
.57741 .11859 m
0 0 rlineto s
.57741 .1494 m
.57741 .11859 L
s
.57741 .1494 m
0 0 rlineto s
.57741 .18022 m
.57741 .1494 L
s
.57741 .18022 m
0 0 rlineto s
.57741 .20893 m
.57741 .18022 L
s
.57741 .20893 m
0 0 rlineto s
.57741 .23358 m
.57741 .20893 L
s
.57741 .23358 m
0 0 rlineto s
.57741 .2525 m
.57741 .23358 L
s
.57741 .2525 m
0 0 rlineto s
.57741 .2644 m
.57741 .2525 L
s
.57741 .2644 m
0 0 rlineto s
.57741 .26845 m
.57741 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.50179 .1256 L
s
0 0 0 r
2 Mabswid
.50179 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.50064 .13512 L
s
0 0 0 r
2 Mabswid
.50064 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.50007 .14464 L
s
0 0 0 r
2 Mabswid
.50007 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.50007 .15417 L
s
0 0 0 r
2 Mabswid
.50007 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.50064 .16369 L
s
0 0 0 r
2 Mabswid
.50064 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.50179 .17321 L
s
0 0 0 r
2 Mabswid
.50179 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.50179 .1256 m
.5716 .12911 L
s
0 0 0 r
2 Mabswid
.5716 .12911 Mdot
.039 .916 .04 r
.5 Mabswid
.50064 .13512 m
.57149 .13725 L
s
0 0 0 r
2 Mabswid
.57149 .13725 Mdot
.039 .916 .04 r
.5 Mabswid
.50007 .14464 m
.57144 .14536 L
s
0 0 0 r
2 Mabswid
.57144 .14536 Mdot
.039 .916 .04 r
.5 Mabswid
.50007 .15417 m
.57144 .15345 L
s
0 0 0 r
2 Mabswid
.57144 .15345 Mdot
.039 .916 .04 r
.5 Mabswid
.50064 .16369 m
.57149 .16156 L
s
0 0 0 r
2 Mabswid
.57149 .16156 Mdot
.039 .916 .04 r
.5 Mabswid
.50179 .17321 m
.5716 .1697 L
s
0 0 0 r
2 Mabswid
.5716 .1697 Mdot
.039 .916 .04 r
.5 Mabswid
.5716 .12911 m
.59834 .13031 L
s
0 0 0 r
2 Mabswid
.59834 .13031 Mdot
.039 .916 .04 r
.5 Mabswid
.57149 .13725 m
.59634 .13791 L
s
0 0 0 r
2 Mabswid
.59634 .13791 Mdot
.039 .916 .04 r
.5 Mabswid
.57144 .14536 m
.59536 .14557 L
s
0 0 0 r
2 Mabswid
.59536 .14557 Mdot
.039 .916 .04 r
.5 Mabswid
.57144 .15345 m
.59536 .15324 L
s
0 0 0 r
2 Mabswid
.59536 .15324 Mdot
.039 .916 .04 r
.5 Mabswid
.57149 .16156 m
.59634 .1609 L
s
0 0 0 r
2 Mabswid
.59634 .1609 Mdot
.039 .916 .04 r
.5 Mabswid
.5716 .1697 m
.59834 .1685 L
s
0 0 0 r
2 Mabswid
.59834 .1685 Mdot
.039 .916 .04 r
.5 Mabswid
.59834 .13031 m
.97619 .05639 L
s
0 0 0 r
2 Mabswid
.97619 .05639 Mdot
.039 .916 .04 r
.5 Mabswid
.59634 .13791 m
.97619 .09659 L
s
0 0 0 r
2 Mabswid
.97619 .09659 Mdot
.039 .916 .04 r
.5 Mabswid
.59536 .14557 m
.97619 .13223 L
s
0 0 0 r
2 Mabswid
.97619 .13223 Mdot
.039 .916 .04 r
.5 Mabswid
.59536 .15324 m
.97619 .16658 L
s
0 0 0 r
2 Mabswid
.97619 .16658 Mdot
.039 .916 .04 r
.5 Mabswid
.59634 .1609 m
.97619 .20222 L
s
0 0 0 r
2 Mabswid
.97619 .20222 Mdot
.039 .916 .04 r
.5 Mabswid
.59834 .1685 m
.97619 .24242 L
s
0 0 0 r
2 Mabswid
.97619 .24242 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo002Tooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool03_ooool0
09gooooo2?l0001Zooooo`03o`000?oooooooooo00kooooo002Mooooo`So0000J_ooool00ol0003o
ooooooooo`0>ooooo`00W?ooool2o`0000KoOgmo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`0>ooooo`00Voooool00ol0003oOgmoo`000006ogmoO`03o`000?oooooooooo06Sooooo00?o
0000ooooooooool03_ooool009[ooooo00?o0000ogmoOomoOgl02?l0001Zooooo`03o`000?oooooo
oooo00kooooo002Iooooo`05o`000?moOgooOgmoogmoOol000001_moOgl00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo00kooooo002Iooooo`05o`000?moOgooOgmoogmoOol000001OmoOgl2
o`0006[ooooo0_l0000?ooooo`00V?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo
00?oOgmo0_l0001Wooooo`?o2NX:0_l0000?ooooo`00Uoooool00ol0003oOgmoogmoO`03ogmoO`03
o`000?moOgooOgmo00?oOgmo0_l0001Rooooo`Go2NX:0oooool00ol0003oooooooooo`0>ooooo`00
U_ooool00ol0003oOgmoogmoO`04ogmoO`So0000GOooool5o`WZ2PSooooo00?o0000ooooooooool0
3_ooool009Gooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`;o0000F?oo
ool5o`WZ2Pgooooo00?o0000ooooooooool03_ooool009Gooooo00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oOgmoogmoO`03ogmoO`;o0000Doooool5o`WZ2Q;ooooo00?o0000ooooooooool03_ooool0
09Cooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`;o0000C_ooool5o`WZ
2QOooooo00?o0000ooooooooool03_ooool009Cooooo00?o0000ogmoOomoOgl01_moOgl00ol0003o
OgmoogmoO`03ogmoO`;o0000BOooool5o`WZ2Qcooooo00?o0000ooooooooool03_ooool009?ooooo
00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`;o000000?oOgmoooooooooool0
@Oooool5o`WZ2R7ooooo00?o0000ooooooooool03_ooool009?ooooo00?o0000ogmoOomoOgl01omo
Ogl00ol0003oOgmoogmoO`03ogmoO`;o00000_moOglmooooo`Go2NX:9_ooool00ol0003ooooooooo
o`0>ooooo`00T_ooool00ol0003oOgmoogmoO`08ogmoO`So00000omoOglgooooo`Go2NX::oooool0
0ol0003oooooooooo`0>ooooo`00T_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo
00;oOgmo00?o0000ogmoOol000001?moOgl`ooooo`Ko2NX:<?ooool2o`0000oooooo002Booooo`03
o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoo`000005ogmoOb[o
oooo1Ol9jPXaooooo`Go2NX:0_l0000?ooooo`00TOooool00ol0003oOgmoogmoO`09ogmoO`03o`00
0?moOgooOgmo00;oOgmo00?o0000ogmoOol000001_moOglTooooo`Go2NX:;Oooool9o`WZ2PGooooo
00?o0000ooooooooool03_ooool0097ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmo
O`02ogmoO`03o`000?moOgoo000000OoOgmo7_ooool5o`WZ2RWooooo2Ol9jPX>ooooo`03o`000?oo
oooooooo00kooooo002@ooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl00_moOgl0
0ol0003oOgmoo`000008ogmoO`03o`000?oooooooooo01Gooooo1Ol9jPXUooooo`Wo2NX:5oooool0
0ol0003oooooooooo`0>ooooo`00T?ooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?moOgooOgmo
00;oOgmo00?o0000ogmoOol000002?moOgl00ol0003oooooooooo`0@ooooo`Go2NX:8?ooool:o`WZ
2R3ooooo00?o0000ooooooooool03_ooool0093ooooo00?o0000ogmoOomoOgl02_moOgl8o`0000Oo
Ogmo00?o0000ooooooooool03?ooool5o`WZ2Qcooooo2Ol9jPXZooooo`03o`000?oooooooooo00ko
oooo002@ooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmo
o`000007ogmoO`03o`000?oooooooooo00Oooooo1Ol9jPXHooooo`Wo2NX:<oooool00ol0003ooooo
ooooo`0>ooooo`003ooooon;o`WZ2P?oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoo`00
0007ogmoO`03o`000?oooooooooo00;ooooo1Ol9jPXCooooo`[o2NX:??ooool00ol0003ooooooooo
o`0>ooooo`00Soooool2o`0000WoOgmo3Ol9jPX2ogmoO`?o00001Ol9jPX?ooooo`Wo2NX:A_ooool0
0ol0003oooooooooo`0>ooooo`00Soooool2o`0000coOgmo00?o0000ogmoOomoOgl00_moOgl3o`00
00;oOgmo1Ol9jPX;ooooo`Wo2NX:@_ooool=o`WZ2P;o00003oooool000ooooooV?l9jPX01OmoOgoo
0000o`000?moOgoo000000;ooooo2Ol9jPXboooooaWo2NX:3Oooool2o`0000oooooo002?ooooo`03
o`000?moOgooOgmo00_oOgmo00?o0000ogmoOomoOgl00_moOgl3o`0000;oOgmo00?o2NX:o`000?l9
jPX01?l9jPXQoooooa[o2NX:9_ooool00ol0003oooooooooo`0>ooooo`003ooooon;o`WZ2P?oOgmo
00?o0000ogmoOomoOgl00_moOgl3o`0000?oOgmo0ol0000;oooooaWo2NX:@?ooool00ol0003ooooo
ooooo`0>ooooo`00Soooool2o`0000WoOgmo3_l9jPX00ol0003o2NX:o`WZ2P0;o`WZ2UWooooo00?o
0000ooooooooool03_ooool008oooooo5_l00003ogmoO`Ko0000HOooool00ol0003oooooooooo`0>
ooooo`003ooooonIo`WZ2P03o`000?l9jP[o2NX:013o2NX:E?ooool00ol0003oooooooooo`0>oooo
o`00Soooool2o`0000coOgmo00?o0000ogmoOomoOgl00_moOgl3o`0000?oOgmo0ol0000@ooooob;o
2NX:<_ooool00ol0003oooooooooo`0>ooooo`00Soooool2o`0000SoOgmo3ol9jPX00ol0003o2NX:
o`WZ2P04o`WZ2Rkooooo8_l9jPX@ooooo`03o`000?oooooooooo00kooooo000?oooooh[o2NX:1?mo
Ogl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgoo000000CoOgmo0_l00004ooooo`Wo2NX:Aooo
ool@o`WZ2P;o00003oooool008oooooo00?o0000ogmoOomoOgl01omoOglDo`WZ2P_ooooo2Ol9jPY>
ooooo`;o00003oooool000ooooooR_l9jPX4ogmoO`03o`000?moOgooOgmo00;oOgmo0ol00006ogmo
O`03o`000?oooooo2NX:00Co2NX:3oooool9o`WZ2TGooooo00?o0000ooooooooool03_ooool008oo
oooo0_l0000<ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOol000001omoOgl00ol0003o
ooooooooo`03ooooo`Go2NX:4oooool:o`WZ2S_ooooo00?o0000ooooooooool03_ooool0093ooooo
00?o0000ogmoOomoOgl02_moOgl8o`0000OoOgmo00?o0000ooooooooool02?ooool5o`WZ2QSooooo
2Ol9jPXbooooo`03o`000?oooooooooo00kooooo002@ooooo`03o`000?moOgooOgmo00[oOgmo00?o
0000ogmoOomoOgl00_moOgl00ol0003oOgmoo`000007ogmoO`03o`000?oooooooooo00gooooo1Ol9
jPXLooooo`Wo2NX::Oooool00ol0003oooooooooo`0>ooooo`00T?ooool00ol0003oOgmoogmoO`0:
ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOol000002?moOgl00ol0003oooooooooo`0A
ooooo`Go2NX:8?ooool:o`WZ2Qoooooo00?o0000ooooooooool03_ooool0093ooooo00?o0000ogmo
OomoOgl02_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgoo000000SoOgmo6Oooool5o`WZ
2RGooooo2Ol9jPXFooooo`03o`000?oooooooooo00kooooo002Aooooo`03o`000?moOgooOgmo00Wo
Ogmo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoo`000008ogmoOakooooo1Ol9jPXYooooo`Wo
2NX:3Oooool00ol0003oooooooooo`0>ooooo`00TOooool00ol0003oOgmoogmoO`09ogmoO`03o`00
0?moOgooOgmo00;oOgmo00?o0000ogmoOol000001omoOglTooooo`Go2NX:;Oooool9o`WZ2PCooooo
0_l0000?ooooo`00T_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00;oOgmo00?o
0000ogmoOol000001_moOglZooooo`Go2NX:<Oooool4o`WZ2P;o00003oooool009;ooooo00?o0000
ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgoo000000GoOgmo<?ooool6
o`WZ2Roooooo00?o0000ooooooooool03_ooool009?ooooo00?o0000ogmoOomoOgl01omoOgl8o`00
00CoOgmo=oooool5o`WZ2R[ooooo00?o0000ooooooooool03_ooool009?ooooo00?o0000ogmoOomo
Ogl01omoOgl00ol0003oOgmoogmoO`03ogmoO`;o00000omoOglmooooo`Go2NX:9Oooool00ol0003o
ooooooooo`0>ooooo`00Toooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00?oOgmo
0_l00002ogmoOd?ooooo1Ol9jPXPooooo`03o`000?oooooooooo00kooooo002Dooooo`03o`000?mo
OgooOgmo00KoOgmo00?o0000ogmoOomoOgl00omoOgl2o`000003ogmoOooooooooooo04Oooooo1Ol9
jPXKooooo`03o`000?oooooooooo00kooooo002Dooooo`03o`000?moOgooOgmo00KoOgmo00?o0000
ogmoOomoOgl00omoOgl2o`0004oooooo1Ol9jPXFooooo`03o`000?oooooooooo00kooooo002Eoooo
o`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl2o`0005Cooooo1Ol9jPXAoooo
o`03o`000?oooooooooo00kooooo002Eooooo`03o`000?moOgooOgmo00GoOgmo2?l0001Iooooo`Go
2NX:3?ooool00ol0003oooooooooo`0>ooooo`00U_ooool00ol0003oOgmoogmoO`04ogmoO`03o`00
0?moOgooOgmo00?oOgmo0_l0001Nooooo`Go2NX:1oooool00ol0003oooooooooo`0>ooooo`00Uooo
ool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo0_l0001Sooooo`Go2NX:0_oo
ool2o`0000oooooo002Hooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00omoOgl2
o`0006Sooooo0_l9jPX2o`0000oooooo002Hooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmo
OomoOgl00omoOgl2o`0006[ooooo00?o0000ooooooooool03_ooool009Wooooo00Co0000ogmoOomo
OgooOgmo2?l0001Zooooo`03o`000?oooooooooo00kooooo002Jooooo`04o`000?moOgooOgmoo`00
00KoOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0>ooooo`00V_ooool01?l0003o
OgmoogmoOol00006ogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool03_ooool009_o
oooo00?o0000ogmoOol000001_moOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00ko
oooo002Looooo`Wo0000J_ooool00ol0003oooooooooo`0>ooooo`00WOooool8o`0006[ooooo00?o
0000ooooooooool03_ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.53351 .07004 m
% vacuous filled polygon
newpath
.53351 .07004 m
.5578 .10972 L
.50735 .10972 L
.53351 .07004 L
F
.50735 .10972 m
.5578 .10972 L
.57143 .1494 L
.5 .1494 L
.50735 .10972 L
F
.5 .1494 m
.57143 .1494 L
.5578 .18909 L
.50735 .18909 L
.5 .1494 L
F
.50735 .18909 m
.5578 .18909 L
.53351 .22877 L
.50735 .18909 L
F
.53351 .22877 m
.53351 .22877 L
% vacuous filled polygon
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.53351 .07004 m
.50735 .10972 L
.5 .1494 L
.50735 .18909 L
.53351 .22877 L
s
.5578 .18909 m
.57143 .1494 L
.5578 .10972 L
s
.5 g
.53351 .1494 m
% vacuous filled polygon
newpath
.53351 .1494 m
.5578 .1494 L
.50735 .1494 L
.53351 .1494 L
F
.50735 .1494 m
.5578 .1494 L
.57143 .1494 L
.5 .1494 L
.50735 .1494 L
F
.5 .1494 m
.57143 .1494 L
.5578 .1494 L
.50735 .1494 L
.5 .1494 L
F
.50735 .1494 m
.5578 .1494 L
.53351 .1494 L
.50735 .1494 L
F
.53351 .1494 m
.53351 .1494 L
% vacuous filled polygon
newpath
0 g
.53351 .1494 m
.50735 .1494 L
.5 .1494 L
.50735 .1494 L
.53351 .1494 L
s
.5578 .1494 m
.57143 .1494 L
.5578 .1494 L
s
.5 g
.61094 .10972 m
.5578 .10972 L
% vacuous filled polygon
newpath
.5578 .10972 m
.61094 .10972 L
.59524 .1494 L
.57143 .1494 L
.5578 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.61094 .18909 L
.5578 .18909 L
.57143 .1494 L
F
.5578 .18909 m
.61094 .18909 L
.5578 .18909 L
F
0 g
.5578 .10972 m
.57143 .1494 L
.5578 .18909 L
s
.61094 .18909 m
.59524 .1494 L
.61094 .10972 L
s
.5 g
.61094 .1494 m
.5578 .1494 L
% vacuous filled polygon
newpath
.5578 .1494 m
.61094 .1494 L
.59524 .1494 L
.57143 .1494 L
.5578 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.61094 .1494 L
.5578 .1494 L
.57143 .1494 L
F
.5578 .1494 m
.61094 .1494 L
.5578 .1494 L
F
0 g
.5578 .1494 m
.57143 .1494 L
.5578 .1494 L
s
.61094 .1494 m
.59524 .1494 L
.61094 .1494 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.50259 .1256 L
s
0 0 0 r
2 Mabswid
.50259 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.50093 .13512 L
s
0 0 0 r
2 Mabswid
.50093 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.5001 .14464 L
s
0 0 0 r
2 Mabswid
.5001 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.5001 .15417 L
s
0 0 0 r
2 Mabswid
.5001 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.50093 .16369 L
s
0 0 0 r
2 Mabswid
.50093 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.50259 .17321 L
s
0 0 0 r
2 Mabswid
.50259 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.50259 .1256 m
.56857 .13041 L
s
0 0 0 r
2 Mabswid
.56857 .13041 Mdot
.039 .916 .04 r
.5 Mabswid
.50093 .13512 m
.57044 .13813 L
s
0 0 0 r
2 Mabswid
.57044 .13813 Mdot
.039 .916 .04 r
.5 Mabswid
.5001 .14464 m
.57132 .14566 L
s
0 0 0 r
2 Mabswid
.57132 .14566 Mdot
.039 .916 .04 r
.5 Mabswid
.5001 .15417 m
.57132 .15315 L
s
0 0 0 r
2 Mabswid
.57132 .15315 Mdot
.039 .916 .04 r
.5 Mabswid
.50093 .16369 m
.57044 .16068 L
s
0 0 0 r
2 Mabswid
.57044 .16068 Mdot
.039 .916 .04 r
.5 Mabswid
.50259 .17321 m
.56857 .1684 L
s
0 0 0 r
2 Mabswid
.56857 .1684 Mdot
.039 .916 .04 r
.5 Mabswid
.56857 .13041 m
.59835 .13067 L
s
0 0 0 r
2 Mabswid
.59835 .13067 Mdot
.039 .916 .04 r
.5 Mabswid
.57044 .13813 m
.59631 .13829 L
s
0 0 0 r
2 Mabswid
.59631 .13829 Mdot
.039 .916 .04 r
.5 Mabswid
.57132 .14566 m
.59536 .14572 L
s
0 0 0 r
2 Mabswid
.59536 .14572 Mdot
.039 .916 .04 r
.5 Mabswid
.57132 .15315 m
.59536 .15309 L
s
0 0 0 r
2 Mabswid
.59536 .15309 Mdot
.039 .916 .04 r
.5 Mabswid
.57044 .16068 m
.59631 .16052 L
s
0 0 0 r
2 Mabswid
.59631 .16052 Mdot
.039 .916 .04 r
.5 Mabswid
.56857 .1684 m
.59835 .16814 L
s
0 0 0 r
2 Mabswid
.59835 .16814 Mdot
.039 .916 .04 r
.5 Mabswid
.59631 .13829 m
.97619 .08189 L
s
0 0 0 r
2 Mabswid
.97619 .08189 Mdot
.039 .916 .04 r
.5 Mabswid
.59536 .14572 m
.97619 .12784 L
s
0 0 0 r
2 Mabswid
.97619 .12784 Mdot
.039 .916 .04 r
.5 Mabswid
.59536 .15309 m
.97619 .17097 L
s
0 0 0 r
2 Mabswid
.97619 .17097 Mdot
.039 .916 .04 r
.5 Mabswid
.59631 .16052 m
.97619 .21692 L
s
0 0 0 r
2 Mabswid
.97619 .21692 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0
003oooooooooo`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo00kooooo003ooooooa3ooooo
00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0003oooooooooo`0>ooooo`00ooooool@
ooooo`03o`000?oooooooooo00kooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oo
oooo4?ooool00ol0003oooooooooo`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo00kooooo
003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0003oooooooooo`0>
ooooo`00V?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo00kooooo002Hooooo`03
o`000?oooooooooo07Cooooo00?o0000ooooooooool03_ooool009Oooooo00?o0000ogmoOoooool0
MOooool00ol0003oooooooooo`0>ooooo`00U_ooool01?l0003oOgmoogmoOomoOgmeooooo`;o0000
3oooool009Kooooo00Co0000ogmoOomoOgooOgmoL_ooool3o`WZ2P;o00003oooool009Gooooo00?o
0000ogmoOomoOgl00omoOgmZooooo`Oo2NX:0oooool00ol0003oooooooooo`0>ooooo`00U?ooool0
0ol0003oOgmoogmoO`05ogmoOf;ooooo1ol9jPX:ooooo`03o`000?oooooooooo00kooooo002Doooo
o`03o`000?moOgooOgmo00GoOgmoFoooool7o`WZ2Q7ooooo00?o0000ooooooooool03_ooool009?o
oooo00?o0000ogmoOomoOgl01omoOgmCooooo`Oo2NX:6?ooool00ol0003oooooooooo`0>ooooo`00
Toooool00ol0003oOgmoogmoO`07ogmoOdgooooo1_l9jPXOooooo`03o`000?oooooooooo00kooooo
002Booooo`03o`000?moOgooOgmo00WoOgmoAOooool7o`WZ2RGooooo00?o0000ooooooooool03_oo
ool0097ooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02cooooo1ol9jPX/ooooo`03o`000?oooooooooo00kooooo002Aooooo`03o`000?moOgooOgmo
00_oOgmo00?o0000ogmoOomoOgl02omoOgl00ol0003oooooooooo`0Uooooo`Oo2NX:<oooool00ol0
003oooooooooo`0>ooooo`00TOooool00ol0003oOgmoogmoO`0;ogmoO`03o`000?moOgooOgmo00[o
Ogmo00?o0000ooooooooool07oooool7o`WZ2S[ooooo00?o0000ooooooooool03_ooool0097ooooo
00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo01Wooooo
1_l9jPY1ooooo`03o`000?oooooooooo00kooooo000?oooooh3o2NX:00?o0000o`WZ2_l9jPX00ol9
jPX;ogmoO`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool04_ooool7o`WZ2TOooooo0_l0
000?ooooo`00Soooool2o`0000CoOgmo2Ol9jPX2ogmoO`?o00001_moOgl3o`0000kooooo1ol9jPY4
ooooo`[o2NX:0_l0000?ooooo`00Soooool2o`0000goOgmo2ol9jPX3o`0000Oooooo1ol9jPXfoooo
oaGo2NX:2_ooool00ol0003oooooooooo`0>ooooo`003ooooon;o`WZ2POoOgmo0_l00005ogmoO`;o
000000?oOgmoo`000?l9jPX01_l9jPXYoooooaCo2NX:7oooool00ol0003oooooooooo`0>ooooo`00
T?ooool00ol0003oOgmoogmoO`07ogmoO`Oo2NX:00?o0000o`WZ2_l9jPX01?l9jPX01?l0003o2NX:
o`WZ2_l9jPXLoooooaCo2NX:<oooool00ol0003oooooooooo`0>ooooo`003ooooon;o`WZ2POoOgmo
0ol00004ogmoO`?o00002?oooolEo`WZ2TOooooo00?o0000ooooooooool03_ooool008oooooo0_l0
0009ogmoO`ko2NX:00?o0000o`WZ2_l9jPX02?l9jPYLooooo`03o`000?oooooooooo00kooooo002?
ooooo`[o00001_moOgl5o`0000CoOgmo1_l0001Qooooo`03o`000?oooooooooo00kooooo000?oooo
oiWo2NX:00?o0000o`WZ2_l9jPX02Ol9jPYKooooo`03o`000?oooooooooo00kooooo002?ooooo`;o
00004?moOgl2o`0000GoOgmo0ol00009oooooaGo2NX:A_ooool00ol0003oooooooooo`0>ooooo`00
Soooool2o`0000SoOgmo2?l9jPX00ol0003o2NX:o`WZ2P04o`WZ2P03o`000?l9jP[o2NX:00;o2NX:
7?oooolDo`WZ2S;ooooo00?o0000ooooooooool03_ooool000ooooooR_l9jPX8ogmoO`;o00001_mo
Ogl2o`0000;ooooo1ol9jPXYoooooaCo2NX:7_ooool00ol0003oooooooooo`0>ooooo`00T?ooool0
0ol0003oOgmoogmoO`06ogmoOa3o2NX:0ol00008ooooo`Oo2NX:=_oooolEo`WZ2PWooooo0_l0000?
ooooo`003ooooon0o`WZ2P03o`000?l9jP[o2NX:00Oo2NX:1omoOgl00ol0003oOgmoogmoO`08ogmo
O`03o`000?oooooooooo00gooooo1ol9jPY4ooooo`Wo2NX:0_l0000?ooooo`00Soooool2o`0000oo
Ogmo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0Cooooo`Oo2NX:A_ooool00ol0003o
ooooooooo`0>ooooo`00TOooool00ol0003oOgmoogmoO`0<ogmoO`03o`000?moOgooOgmo00WoOgmo
00?o0000ooooooooool06_ooool6o`WZ2T3ooooo00?o0000ooooooooool03_ooool0097ooooo00?o
0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`0:ogmoO`03o`000?oooooooooo023ooooo1ol9
jPXiooooo`03o`000?oooooooooo00kooooo002Aooooo`03o`000?moOgooOgmo00_oOgmo00?o0000
ogmoOomoOgl02omoOgl00ol0003oooooooooo`0Vooooo`Oo2NX:<_ooool00ol0003oooooooooo`0>
ooooo`00TOooool00ol0003oOgmoogmoO`0;ogmoOckooooo1ol9jPX[ooooo`03o`000?oooooooooo
00kooooo002Booooo`03o`000?moOgooOgmo00[oOgmoAOooool7o`WZ2RCooooo00?o0000oooooooo
ool03_ooool009?ooooo00?o0000ogmoOomoOgl02?moOgm=ooooo`Ko2NX:7_ooool00ol0003ooooo
ooooo`0>ooooo`00Toooool00ol0003oOgmoogmoO`07ogmoOeCooooo1ol9jPXGooooo`03o`000?oo
oooooooo00kooooo002Dooooo`03o`000?moOgooOgmo00KoOgmoFoooool7o`WZ2Q3ooooo00?o0000
ooooooooool03_ooool009Gooooo00?o0000ogmoOomoOgl01?moOgmSooooo`Oo2NX:2Oooool00ol0
003oooooooooo`0>ooooo`00UOooool00ol0003oOgmoogmoO`03ogmoOf_ooooo1ol9jPX2ooooo`;o
00003oooool009Kooooo00?o0000ogmoOomoOgl00_moOgmbooooo`;o2NX:0_l0000?ooooo`00U_oo
ool01?l0003oOgmoogmoOomoOgmeooooo`03o`000?oooooooooo00kooooo002Gooooo`03o`000?mo
OgooOgmo07Gooooo00?o0000ooooooooool03_ooool009Sooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooooooo`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo00kooooo003ooooooa3o
oooo00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0003oooooooooo`0>ooooo`00oooo
ool@ooooo`03o`000?oooooooooo00kooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool0
0?oooooo4?ooool00ol0003oooooooooo`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo00ko
oooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0003ooooooooo
o`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo00kooooo003ooooooa3ooooo00?o0000oooo
ooooool03_ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.54901 .07004 m
% vacuous filled polygon
newpath
.54901 .07004 m
.58606 .10972 L
.50936 .10972 L
.54901 .07004 L
F
.50936 .10972 m
.58606 .10972 L
.57143 .1494 L
.5 .1494 L
.50936 .10972 L
F
.5 .1494 m
.57143 .1494 L
.58606 .18909 L
.50936 .18909 L
.5 .1494 L
F
.50936 .18909 m
.58606 .18909 L
.54901 .22877 L
.50936 .18909 L
F
.54901 .22877 m
.54901 .22877 L
% vacuous filled polygon
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.54901 .07004 m
.50936 .10972 L
.5 .1494 L
.50936 .18909 L
.54901 .22877 L
s
.58606 .18909 m
.57143 .1494 L
.58606 .10972 L
s
.5 g
.54901 .1494 m
% vacuous filled polygon
newpath
.54901 .1494 m
.58606 .1494 L
.50936 .1494 L
.54901 .1494 L
F
.50936 .1494 m
.58606 .1494 L
.57143 .1494 L
.5 .1494 L
.50936 .1494 L
F
.5 .1494 m
.57143 .1494 L
.58606 .1494 L
.50936 .1494 L
.5 .1494 L
F
.50936 .1494 m
.58606 .1494 L
.54901 .1494 L
.50936 .1494 L
F
.54901 .1494 m
.54901 .1494 L
% vacuous filled polygon
newpath
0 g
.54901 .1494 m
.50936 .1494 L
.5 .1494 L
.50936 .1494 L
.54901 .1494 L
s
.58606 .1494 m
.57143 .1494 L
.58606 .1494 L
s
.5 g
.60636 .10972 m
.58606 .10972 L
% vacuous filled polygon
newpath
.58606 .10972 m
.60636 .10972 L
.59524 .1494 L
.57143 .1494 L
.58606 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.60636 .18909 L
.58606 .18909 L
.57143 .1494 L
F
.58606 .18909 m
.60636 .18909 L
.58606 .18909 L
F
0 g
.58606 .10972 m
.57143 .1494 L
.58606 .18909 L
s
.60636 .18909 m
.59524 .1494 L
.60636 .10972 L
s
.5 g
.60636 .1494 m
.58606 .1494 L
% vacuous filled polygon
newpath
.58606 .1494 m
.60636 .1494 L
.59524 .1494 L
.57143 .1494 L
.58606 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.60636 .1494 L
.58606 .1494 L
.57143 .1494 L
F
.58606 .1494 m
.60636 .1494 L
.58606 .1494 L
F
0 g
.58606 .1494 m
.57143 .1494 L
.58606 .1494 L
s
.60636 .1494 m
.59524 .1494 L
.60636 .1494 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.50325 .1256 L
s
0 0 0 r
2 Mabswid
.50325 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.50116 .13512 L
s
0 0 0 r
2 Mabswid
.50116 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.50013 .14464 L
s
0 0 0 r
2 Mabswid
.50013 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.50013 .15417 L
s
0 0 0 r
2 Mabswid
.50013 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.50116 .16369 L
s
0 0 0 r
2 Mabswid
.50116 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.50325 .17321 L
s
0 0 0 r
2 Mabswid
.50325 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.50325 .1256 m
.57393 .1321 L
s
0 0 0 r
2 Mabswid
.57393 .1321 Mdot
.039 .916 .04 r
.5 Mabswid
.50116 .13512 m
.57233 .13897 L
s
0 0 0 r
2 Mabswid
.57233 .13897 Mdot
.039 .916 .04 r
.5 Mabswid
.50013 .14464 m
.57153 .14592 L
s
0 0 0 r
2 Mabswid
.57153 .14592 Mdot
.039 .916 .04 r
.5 Mabswid
.50013 .15417 m
.57153 .15289 L
s
0 0 0 r
2 Mabswid
.57153 .15289 Mdot
.039 .916 .04 r
.5 Mabswid
.50116 .16369 m
.57233 .15984 L
s
0 0 0 r
2 Mabswid
.57233 .15984 Mdot
.039 .916 .04 r
.5 Mabswid
.50325 .17321 m
.57393 .16671 L
s
0 0 0 r
2 Mabswid
.57393 .16671 Mdot
.039 .916 .04 r
.5 Mabswid
.57393 .1321 m
.59662 .13494 L
s
0 0 0 r
2 Mabswid
.59662 .13494 Mdot
.039 .916 .04 r
.5 Mabswid
.57233 .13897 m
.59574 .1407 L
s
0 0 0 r
2 Mabswid
.59574 .1407 Mdot
.039 .916 .04 r
.5 Mabswid
.57153 .14592 m
.59529 .1465 L
s
0 0 0 r
2 Mabswid
.59529 .1465 Mdot
.039 .916 .04 r
.5 Mabswid
.57153 .15289 m
.59529 .15231 L
s
0 0 0 r
2 Mabswid
.59529 .15231 Mdot
.039 .916 .04 r
.5 Mabswid
.57233 .15984 m
.59574 .15811 L
s
0 0 0 r
2 Mabswid
.59574 .15811 Mdot
.039 .916 .04 r
.5 Mabswid
.57393 .16671 m
.59662 .16387 L
s
0 0 0 r
2 Mabswid
.59662 .16387 Mdot
.039 .916 .04 r
.5 Mabswid
.59662 .13494 m
.97619 .16216 L
s
0 0 0 r
2 Mabswid
.97619 .16216 Mdot
.039 .916 .04 r
.5 Mabswid
.59574 .1407 m
.97619 .15644 L
s
0 0 0 r
2 Mabswid
.97619 .15644 Mdot
.039 .916 .04 r
.5 Mabswid
.59529 .1465 m
.97619 .15165 L
s
0 0 0 r
2 Mabswid
.97619 .15165 Mdot
.039 .916 .04 r
.5 Mabswid
.59529 .15231 m
.97619 .14716 L
s
0 0 0 r
2 Mabswid
.97619 .14716 Mdot
.039 .916 .04 r
.5 Mabswid
.59574 .15811 m
.97619 .14237 L
s
0 0 0 r
2 Mabswid
.97619 .14237 Mdot
.039 .916 .04 r
.5 Mabswid
.59662 .16387 m
.97619 .13665 L
s
0 0 0 r
2 Mabswid
.97619 .13665 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0
003oooooooooo`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo00kooooo003ooooooa3ooooo
00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0003oooooooooo`0>ooooo`00ooooool@
ooooo`03o`000?oooooooooo00kooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oo
oooo4?ooool00ol0003oooooooooo`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo00kooooo
003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0003oooooooooo`0>
ooooo`00W?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00kooooo002Looooo`03
o`000?oooooooooo073ooooo00?o0000ooooooooool03_ooool009_ooooo00?o0000ogmoOoooool0
LOooool00ol0003oooooooooo`0>ooooo`00V_ooool01?l0003oOgmoogmoOomoOgmaooooo`03o`00
0?oooooooooo00kooooo002Iooooo`03o`000?moOgooOgmo00?oOgmoL?ooool00ol0003ooooooooo
o`0>ooooo`00V?ooool00ol0003oOgmoogmoO`05ogmoOfoooooo00?o0000ooooooooool03_ooool0
09Oooooo00?o0000ogmoOomoOgl01omoOgm^ooooo`03o`000?oooooooooo00kooooo002Fooooo`03
o`000?moOgooOgmo00WoOgmoKOooool00ol0003oooooooooo`0>ooooo`00UOooool00ol0003oOgmo
ogmoO`0;ogmoOfcooooo00?o0000ooooooooool03_ooool009Cooooo00?o0000ogmoOomoOgl03Omo
Ogm[ooooo`03o`000?oooooooooo00kooooo002Cooooo`03o`000?moOgooOgmo00ooOgmoJ_ooool0
0ol0003oooooooooo`0>ooooo`00T_ooool00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0>ooooo`00T_ooool00ol0003o
OgmoogmoO`0AogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0>ooooo`00T_ooool00ol0003oOgmoogmoO`0@ogmoO`03o`000?moOgooOgmo00CoOgmo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0>ooooo`00TOooool00ol0003oOgmoogmo
O`0AogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0>ooooo`003ooooon0o`WZ2P03o`000?l9jP[o2NX:00Co2NX:3omoOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo067ooooo00?o0000ooooooooool03_ooool008oooooo0ol00004ogmo
O`Wo2NX:1OmoOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool03_ooool008oooooo0_l0000>ogmoO`?o2NX:00?o0000o`WZ2_l9jPX00_l9jPX01?moOgoo
0000o`000?l0001Tooooo`03o`000?oooooooooo00kooooo000?oooooh_o2NX:2?moOgl3o`0000;o
Ogmo00?o2NX:o`000?l9jPX01ol9jPYHooooo`Ko2NX:0_l0000?ooooo`00T?ooool00ol0003oOgmo
ogmoO`07ogmoO`ko2NX:00?o0000o`WZ2_l9jPX05Ol9jPXlooooo`go2NX:1_ooool2o`0000oooooo
000?oooooh_o2NX:2?moOgl2o`0000CoOgmo0ol00009oooooa[o2NX:8Oooool=o`WZ2PKooooo3Ol9
jPX2o`0000oooooo002?ooooo`;o00002OmoOgl>o`WZ2P03o`000?l9jP[o2NX:03;o2NX:1Oooool]
o`WZ2P;o00003oooool008oooooo3_l00005ogmoO`Go000000?oOgmoo`000?l000000ol0000Foooo
odco2NX:0_l0000?ooooo`003ooooonIo`WZ2P03o`000?l9jP[o2NX:02_o2NX:5_oooolJo`WZ2PWo
oooo0_l0000?ooooo`00Soooool2o`00017oOgmo0_l00002ogmoO`;o2NX:00?o0000o`WZ2_l9jPX0
2ol9jPX6ooooo`go2NX:<OoooolEo`WZ2P;o00003oooool008oooooo0_l00008ogmoO`go2NX:0_mo
Ogl3o`0000Cooooo3Ol9jPY=ooooo`Ko2NX:0_l0000?ooooo`003ooooon:o`WZ2PGoOgmo1?l9jPX0
0ol0003o2NX:o`WZ2P03o`WZ2P03o`000?l9jP[o2NX:00Co2NX:H?ooool2o`0000oooooo002@oooo
o`03o`000?moOgooOgmo00;oOgmo2Ol9jPX4ogmoO`?o00001OmoOgl00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo00kooooo000?oooooh3o2NX:00?o0000o`WZ2_l9jPX00ol9jPX?ogmoO`03
o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0>ooooo`00
Soooool3o`0001?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo00kooooo002Aooooo`03o`000?moOgooOgmo017oOgmo00?o0000ogmoOomoOgl00omo
Ogl00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00kooooo002Booooo`03o`000?moOgoo
Ogmo013oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo00kooooo002Booooo`03o`000?moOgooOgmo017oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo00kooooo002Booooo`03o`000?moOgooOgmo017o
OgmoJOooool00ol0003oooooooooo`0>ooooo`00Toooool00ol0003oOgmoogmoO`0@ogmoOfWooooo
00?o0000ooooooooool03_ooool009Cooooo00?o0000ogmoOomoOgl03_moOgmZooooo`03o`000?oo
oooooooo00kooooo002Eooooo`03o`000?moOgooOgmo00coOgmoJoooool00ol0003oooooooooo`0>
ooooo`00U_ooool00ol0003oOgmoogmoO`0:ogmoOfcooooo00?o0000ooooooooool03_ooool009Oo
oooo00?o0000ogmoOomoOgl02?moOgm]ooooo`03o`000?oooooooooo00kooooo002Hooooo`03o`00
0?moOgooOgmo00KoOgmoK_ooool00ol0003oooooooooo`0>ooooo`00VOooool00ol0003oOgmoogmo
O`04ogmoOfoooooo00?o0000ooooooooool03_ooool009[ooooo00?o0000ogmoOomoOgl00_moOgm`
ooooo`03o`000?oooooooooo00kooooo002Kooooo`03o`000?moOgooOgmo077ooooo00?o0000oooo
ooooool03_ooool009cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0>ooooo`00
ooooool@ooooo`03o`000?oooooooooo00kooooo003ooooooa3ooooo00?o0000ooooooooool03_oo
ool00?oooooo4?ooool00ol0003oooooooooo`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo
00kooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oooooo4?ooool00ol0003ooooo
ooooo`0>ooooo`00ooooool@ooooo`03o`000?oooooooooo00kooooo003ooooooa3ooooo00?o0000
ooooooooool03_ooool00?oooooo4?ooool00ol0003oooooooooo`0>ooooo`00ooooool@ooooo`03
o`000?oooooooooo00kooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00?oooooo8Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.57088 .03036 m
.57118 .07004 L
% vacuous filled polygon
newpath
.57118 .07004 m
.57137 .10972 L
.51421 .10972 L
F
.51421 .10972 m
.57137 .10972 L
.57143 .1494 L
.5 .1494 L
.51421 .10972 L
F
.5 .1494 m
.57143 .1494 L
.57137 .18909 L
.51421 .18909 L
.5 .1494 L
F
.51421 .18909 m
.57137 .18909 L
.57118 .22877 L
.51421 .18909 L
F
.57118 .22877 m
.57088 .26845 L
% vacuous filled polygon
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.51421 .10972 m
.5 .1494 L
.51421 .18909 L
s
.57088 .26845 m
.57118 .22877 L
.57137 .18909 L
.57143 .1494 L
.57137 .10972 L
.57118 .07004 L
.57088 .03036 L
s
.5 g
.57088 .1494 m
.57118 .1494 L
% vacuous filled polygon
newpath
.57118 .1494 m
.57137 .1494 L
.51421 .1494 L
F
.51421 .1494 m
.57137 .1494 L
.57143 .1494 L
.5 .1494 L
.51421 .1494 L
F
.5 .1494 m
.57143 .1494 L
.57137 .1494 L
.51421 .1494 L
.5 .1494 L
F
.51421 .1494 m
.57137 .1494 L
.57118 .1494 L
.51421 .1494 L
F
.57118 .1494 m
.57088 .1494 L
% vacuous filled polygon
newpath
0 g
.51421 .1494 m
.5 .1494 L
.51421 .1494 L
s
.57088 .1494 m
.57118 .1494 L
.57137 .1494 L
.57143 .1494 L
.57137 .1494 L
.57118 .1494 L
.57088 .1494 L
s
.5 g
.57088 .03036 m
.57118 .07004 L
.57088 .03036 L
F
.57118 .07004 m
.607 .10972 L
.57137 .10972 L
.57118 .07004 L
F
.57137 .10972 m
.607 .10972 L
.59524 .1494 L
.57143 .1494 L
.57137 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.607 .18909 L
.57137 .18909 L
.57143 .1494 L
F
.57137 .18909 m
.607 .18909 L
.57118 .22877 L
.57137 .18909 L
F
.57118 .22877 m
.57088 .26845 L
.57118 .22877 L
F
0 g
.57088 .03036 m
.57118 .07004 L
.57137 .10972 L
.57143 .1494 L
.57137 .18909 L
.57118 .22877 L
.57088 .26845 L
s
.607 .18909 m
.59524 .1494 L
.607 .10972 L
s
.57088 .03036 m
0 0 rlineto s
.5 g
.57088 .1494 m
.57118 .1494 L
.57088 .1494 L
F
.57118 .1494 m
.607 .1494 L
.57137 .1494 L
.57118 .1494 L
F
.57137 .1494 m
.607 .1494 L
.59524 .1494 L
.57143 .1494 L
.57137 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.607 .1494 L
.57137 .1494 L
.57143 .1494 L
F
.57137 .1494 m
.607 .1494 L
.57118 .1494 L
.57137 .1494 L
F
.57118 .1494 m
.57088 .1494 L
.57118 .1494 L
F
0 g
.57088 .1494 m
.57118 .1494 L
.57137 .1494 L
.57143 .1494 L
.57137 .1494 L
.57118 .1494 L
.57088 .1494 L
s
.607 .1494 m
.59524 .1494 L
.607 .1494 L
s
.57088 .1494 m
0 0 rlineto s
.57088 .26845 m
.57088 .2644 L
s
.57088 .2644 m
.57088 .2525 L
s
.57088 .2525 m
.57088 .23358 L
s
.57088 .23358 m
.57088 .20893 L
s
.57088 .20893 m
.57088 .18022 L
s
.57088 .18022 m
.57088 .1494 L
s
.57088 .1494 m
.57088 .11859 L
s
.57088 .11859 m
.57088 .08988 L
s
.57088 .08988 m
.57088 .06523 L
s
.57088 .06523 m
.57088 .04631 L
s
.57088 .04631 m
.57088 .03441 L
s
.57088 .03441 m
.57088 .03036 L
s
.57088 .03036 m
.57088 .03441 L
s
.57088 .03441 m
.57088 .04631 L
s
.57088 .04631 m
.57088 .06523 L
s
.57088 .06523 m
.57088 .08988 L
s
.57088 .08988 m
.57088 .11859 L
s
.57088 .11859 m
.57088 .1494 L
s
.57088 .1494 m
.57088 .18022 L
s
.57088 .18022 m
.57088 .20893 L
s
.57088 .20893 m
.57088 .23358 L
s
.57088 .23358 m
.57088 .2525 L
s
.57088 .2525 m
.57088 .2644 L
s
.57088 .2644 m
.57088 .26845 L
s
.57088 .26845 m
0 0 rlineto s
.57088 .2644 m
.57088 .26845 L
s
.57088 .2644 m
0 0 rlineto s
.57088 .2525 m
.57088 .2644 L
s
.57088 .2525 m
0 0 rlineto s
.57088 .23358 m
.57088 .2525 L
s
.57088 .23358 m
0 0 rlineto s
.57088 .20893 m
.57088 .23358 L
s
.57088 .20893 m
0 0 rlineto s
.57088 .18022 m
.57088 .20893 L
s
.57088 .18022 m
0 0 rlineto s
.57088 .1494 m
.57088 .18022 L
s
.57088 .1494 m
0 0 rlineto s
.57088 .11859 m
.57088 .1494 L
s
.57088 .11859 m
0 0 rlineto s
.57088 .08988 m
.57088 .11859 L
s
.57088 .08988 m
0 0 rlineto s
.57088 .06523 m
.57088 .08988 L
s
.57088 .06523 m
0 0 rlineto s
.57088 .04631 m
.57088 .06523 L
s
.57088 .04631 m
0 0 rlineto s
.57088 .03441 m
.57088 .04631 L
s
.57088 .03441 m
0 0 rlineto s
.57088 .03036 m
.57088 .03441 L
s
.57088 .03036 m
0 0 rlineto s
.57088 .03441 m
.57088 .03036 L
s
.57088 .03441 m
0 0 rlineto s
.57088 .04631 m
.57088 .03441 L
s
.57088 .04631 m
0 0 rlineto s
.57088 .06523 m
.57088 .04631 L
s
.57088 .06523 m
0 0 rlineto s
.57088 .08988 m
.57088 .06523 L
s
.57088 .08988 m
0 0 rlineto s
.57088 .11859 m
.57088 .08988 L
s
.57088 .11859 m
0 0 rlineto s
.57088 .1494 m
.57088 .11859 L
s
.57088 .1494 m
0 0 rlineto s
.57088 .18022 m
.57088 .1494 L
s
.57088 .18022 m
0 0 rlineto s
.57088 .20893 m
.57088 .18022 L
s
.57088 .20893 m
0 0 rlineto s
.57088 .23358 m
.57088 .20893 L
s
.57088 .23358 m
0 0 rlineto s
.57088 .2525 m
.57088 .23358 L
s
.57088 .2525 m
0 0 rlineto s
.57088 .2644 m
.57088 .2525 L
s
.57088 .2644 m
0 0 rlineto s
.57088 .26845 m
.57088 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.50471 .1256 L
s
0 0 0 r
2 Mabswid
.50471 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.50165 .13512 L
s
0 0 0 r
2 Mabswid
.50165 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.50018 .14464 L
s
0 0 0 r
2 Mabswid
.50018 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.50018 .15417 L
s
0 0 0 r
2 Mabswid
.50018 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.50165 .16369 L
s
0 0 0 r
2 Mabswid
.50165 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.50471 .17321 L
s
0 0 0 r
2 Mabswid
.50471 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.50471 .1256 m
.57142 .13459 L
s
0 0 0 r
2 Mabswid
.57142 .13459 Mdot
.039 .916 .04 r
.5 Mabswid
.50165 .13512 m
.57143 .14054 L
s
0 0 0 r
2 Mabswid
.57143 .14054 Mdot
.039 .916 .04 r
.5 Mabswid
.50018 .14464 m
.57143 .14646 L
s
0 0 0 r
2 Mabswid
.57143 .14646 Mdot
.039 .916 .04 r
.5 Mabswid
.50018 .15417 m
.57143 .15235 L
s
0 0 0 r
2 Mabswid
.57143 .15235 Mdot
.039 .916 .04 r
.5 Mabswid
.50165 .16369 m
.57143 .15827 L
s
0 0 0 r
2 Mabswid
.57143 .15827 Mdot
.039 .916 .04 r
.5 Mabswid
.50471 .17321 m
.57142 .16422 L
s
0 0 0 r
2 Mabswid
.57142 .16422 Mdot
.039 .916 .04 r
.5 Mabswid
.57142 .13459 m
.59624 .13736 L
s
0 0 0 r
2 Mabswid
.59624 .13736 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .14054 m
.5956 .14211 L
s
0 0 0 r
2 Mabswid
.5956 .14211 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .14646 m
.59528 .14696 L
s
0 0 0 r
2 Mabswid
.59528 .14696 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .15235 m
.59528 .15185 L
s
0 0 0 r
2 Mabswid
.59528 .15185 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .15827 m
.5956 .1567 L
s
0 0 0 r
2 Mabswid
.5956 .1567 Mdot
.039 .916 .04 r
.5 Mabswid
.57142 .16422 m
.59624 .16145 L
s
0 0 0 r
2 Mabswid
.59624 .16145 Mdot
.039 .916 .04 r
.5 Mabswid
.59624 .13736 m
.97619 .16304 L
s
0 0 0 r
2 Mabswid
.97619 .16304 Mdot
.039 .916 .04 r
.5 Mabswid
.5956 .14211 m
.97619 .15575 L
s
0 0 0 r
2 Mabswid
.97619 .15575 Mdot
.039 .916 .04 r
.5 Mabswid
.59528 .14696 m
.97619 .15124 L
s
0 0 0 r
2 Mabswid
.97619 .15124 Mdot
.039 .916 .04 r
.5 Mabswid
.59528 .15185 m
.97619 .14757 L
s
0 0 0 r
2 Mabswid
.97619 .14757 Mdot
.039 .916 .04 r
.5 Mabswid
.5956 .1567 m
.97619 .14306 L
s
0 0 0 r
2 Mabswid
.97619 .14306 Mdot
.039 .916 .04 r
.5 Mabswid
.59624 .16145 m
.97619 .13577 L
s
0 0 0 r
2 Mabswid
.97619 .13577 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo002Rooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03_ooool0
0:;ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0>ooooo`00X_ooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo00kooooo002Rooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool03_ooool00:;ooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`0>ooooo`00X_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00kooooo002Roooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03_ooool00:;ooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`0>ooooo`00X_ooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00kooooo002Rooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03_oo
ool00:;ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0>ooooo`00X_ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo00kooooo002Qooooo`03ogmoOol0003ooooo06_o
oooo00?o0000ooooooooool03_ooool00:3ooooo0_moOgl00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00kooooo002Oooooo`?oOgmo00?o0000ogmoOoooool0J_ooool00ol0003ooooooooo
o`0>ooooo`00WOooool5ogmoO`03o`000?moOgooOgmo06[ooooo00?o0000ooooooooool03_ooool0
09cooooo1_moOgl01?l0003oOgmoogmoOomoOgmYooooo`03o`000?oooooooooo00kooooo002Joooo
o`SoOgmo00?o0000ogmoOomoOgl00_moOgmXooooo`03o`000?oooooooooo00kooooo002Iooooo`Wo
Ogmo00?o0000ogmoOomoOgl00omoOgmWooooo`03o`000?oooooooooo00kooooo002Hooooo`[oOgmo
00?o0000ogmoOomoOgl01?moOgmVooooo`03o`000?oooooooooo00kooooo002Fooooo`coOgmo00?o
0000ogmoOomoOgl01OmoOgmUooooo`03o`000?oooooooooo00kooooo002Eooooo`goOgmo00?o0000
ogmoOomoOgl01_moOgmTooooo`03o`000?oooooooooo00kooooo002Cooooo`03o`000?moOgooOgmo
00coOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
00kooooo002Cooooo`03o`000?moOgooOgmo00coOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo00kooooo002Booooo`03o`000?moOgooOgmo00goOgmo
00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00kooooo
002Booooo`03o`000?moOgooOgmo00goOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo00kooooo000?ooooohGo2NX:3_moOgl00ol0003oOgmoogmoO`06
ogmoO`03o`000?oooooooooo067ooooo00?o0000ooooooooool03_ooool0093ooooo0_l00002ogmo
O`Ko2NX:2?moOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool03_ooool008oooooo0ol00008ogmoO`Ko2NX:0_moOgl2o`0000KoOgmo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`0>ooooo`003ooooon;o`WZ2PKoOgmo2?l9jPX00ol0003o2NX:
o`WZ2P06o`WZ2UOooooo1ol9jPX2o`0000oooooo002@ooooo`03o`000?moOgooOgmo00OoOgmo3Ol9
jPX01?moOgoo0000o`000?l00006ooooo`oo2NX:>Oooool?o`WZ2POooooo0_l0000?ooooo`003ooo
oon;o`WZ2PSoOgmo0_l00003ogmoO`03o`WZ2_l0003o2NX:017o2NX:1Oooool>o`WZ2Qgooooo3_l9
jPX9ooooo`go2NX:0_l0000?ooooo`00Soooool2o`0000WoOgmo3_l9jPX00ol0003o2NX:o`WZ2P1T
o`WZ2P;o00003oooool008oooooo1Ol0000>ogmoO`;o00000_moOgl2o`WZ2P03o`000?l9jP[o2NX:
06Co2NX:0_l0000?ooooo`003ooooonGo`WZ2P;oOgmo0_l0000<oooooaWo2NX:7Oooool>o`WZ2PGo
oooo4?l9jPX2o`0000oooooo002?ooooo`;o00003?moOgl;o`WZ2P03o`000?l9jP[o2NX:01Co2NX:
>oooool?o`WZ2PKooooo0_l0000?ooooo`00Soooool2o`0000?oOgmo2Ol9jPX5ogmoO`;o00000_mo
Ogl2o`WZ2P03o`000?l9jP[o2NX:00Go2NX:FOooool6o`WZ2P;o00003oooool000ooooooQOl9jPX:
ogmoO`So2NX:1?moOgl00ol0003oooooooooo`1Rooooo`;o00003oooool0097ooooo00Co0000ogmo
OomoOgooOgmo2Ol9jPX4ogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`0>ooooo`003ooooon6o`WZ2PgoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo00kooooo002@ooooo`?o00003omoOgl00ol0003o
OgmoogmoO`06ogmoO`03o`000?oooooooooo067ooooo00?o0000ooooooooool03_ooool009;ooooo
00?o0000ogmoOomoOgl03OmoOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooooooo067ooooo
00?o0000ooooooooool03_ooool009;ooooo00?o0000ogmoOomoOgl03OmoOgl00ol0003oOgmoogmo
O`07ogmoO`03o`000?oooooooooo063ooooo00?o0000ooooooooool03_ooool009?ooooo00?o0000
ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`07ogmoO`03o`000?oooooooooo063ooooo00?o0000
ooooooooool03_ooool009Gooooo3OmoOgl00ol0003oOgmoogmoO`07ogmoOf?ooooo00?o0000oooo
ooooool03_ooool009Kooooo3?moOgl00ol0003oOgmoogmoO`07ogmoOf?ooooo00?o0000oooooooo
ool03_ooool009Oooooo2omoOgl00ol0003oOgmoogmoO`06ogmoOfCooooo00?o0000ooooooooool0
3_ooool009Wooooo2OmoOgl00ol0003oOgmoogmoO`05ogmoOfGooooo00?o0000ooooooooool03_oo
ool009[ooooo2?moOgl00ol0003oOgmoogmoO`04ogmoOfKooooo00?o0000ooooooooool03_ooool0
09cooooo1_moOgl00ol0003oOgmoogmoO`03ogmoOfOooooo00?o0000ooooooooool03_ooool009go
oooo1OmoOgl00ol0003oOgmoogmoO`02ogmoOfSooooo00?o0000ooooooooool03_ooool009kooooo
1?moOgl01?l0003oOgmoogmoOomoOgmYooooo`03o`000?oooooooooo00kooooo002Pooooo`;oOgmo
00?o0000ogmoOomoOgl0J_ooool00ol0003oooooooooo`0>ooooo`00XOooool00omoOgoo0000ogmo
O`1[ooooo`03o`000?oooooooooo00kooooo002Rooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool03_ooool00:;ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0>oooo
o`00X_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00kooooo002Rooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool03_ooool00:;ooooo00?o0000ooooooooool0J_oo
ool00ol0003oooooooooo`0>ooooo`00X_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooo
oooo00kooooo002Rooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03_ooool00:;o
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0>ooooo`00X_ooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo00kooooo002Rooooo`03o`000?oooooooooo06[ooooo00?o
0000ooooooooool03_ooool00:;ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0>
ooooo`00X_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00kooooo003oooooob7o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.57326 .03036 m
.57224 .07004 L
% vacuous filled polygon
newpath
.57224 .07004 m
.57163 .10972 L
.51504 .10972 L
F
.51504 .10972 m
.57163 .10972 L
.57143 .1494 L
.5 .1494 L
.51504 .10972 L
F
.5 .1494 m
.57143 .1494 L
.57163 .18909 L
.51504 .18909 L
.5 .1494 L
F
.51504 .18909 m
.57163 .18909 L
.57224 .22877 L
.51504 .18909 L
F
.57224 .22877 m
.57326 .26845 L
% vacuous filled polygon
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.51504 .10972 m
.5 .1494 L
.51504 .18909 L
s
.57326 .26845 m
.57224 .22877 L
.57163 .18909 L
.57143 .1494 L
.57163 .10972 L
.57224 .07004 L
.57326 .03036 L
s
.5 g
.57326 .1494 m
.57224 .1494 L
% vacuous filled polygon
newpath
.57224 .1494 m
.57163 .1494 L
.51504 .1494 L
F
.51504 .1494 m
.57163 .1494 L
.57143 .1494 L
.5 .1494 L
.51504 .1494 L
F
.5 .1494 m
.57143 .1494 L
.57163 .1494 L
.51504 .1494 L
.5 .1494 L
F
.51504 .1494 m
.57163 .1494 L
.57224 .1494 L
.51504 .1494 L
F
.57224 .1494 m
.57326 .1494 L
% vacuous filled polygon
newpath
0 g
.51504 .1494 m
.5 .1494 L
.51504 .1494 L
s
.57326 .1494 m
.57224 .1494 L
.57163 .1494 L
.57143 .1494 L
.57163 .1494 L
.57224 .1494 L
.57326 .1494 L
s
.5 g
.57326 .03036 m
.56218 .03036 L
.58117 .07004 L
.57224 .07004 L
.57326 .03036 L
F
.57224 .07004 m
.58117 .07004 L
.5918 .10972 L
.57163 .10972 L
.57224 .07004 L
F
.57163 .10972 m
.5918 .10972 L
.59524 .1494 L
.57143 .1494 L
.57163 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.5918 .18909 L
.57163 .18909 L
.57143 .1494 L
F
.57163 .18909 m
.5918 .18909 L
.58117 .22877 L
.57224 .22877 L
.57163 .18909 L
F
.57224 .22877 m
.58117 .22877 L
.56218 .26845 L
.57326 .26845 L
.57224 .22877 L
F
0 g
.57326 .03036 m
.57224 .07004 L
.57163 .10972 L
.57143 .1494 L
.57163 .18909 L
.57224 .22877 L
.57326 .26845 L
.56218 .26845 L
.58117 .22877 L
.5918 .18909 L
.59524 .1494 L
.5918 .10972 L
.58117 .07004 L
.56218 .03036 L
.57326 .03036 L
s
.5 g
.57326 .1494 m
.56218 .1494 L
.58117 .1494 L
.57224 .1494 L
.57326 .1494 L
F
.57224 .1494 m
.58117 .1494 L
.5918 .1494 L
.57163 .1494 L
.57224 .1494 L
F
.57163 .1494 m
.5918 .1494 L
.59524 .1494 L
.57143 .1494 L
.57163 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.5918 .1494 L
.57163 .1494 L
.57143 .1494 L
F
.57163 .1494 m
.5918 .1494 L
.58117 .1494 L
.57224 .1494 L
.57163 .1494 L
F
.57224 .1494 m
.58117 .1494 L
.56218 .1494 L
.57326 .1494 L
.57224 .1494 L
F
0 g
.57326 .1494 m
.57224 .1494 L
.57163 .1494 L
.57143 .1494 L
.57163 .1494 L
.57224 .1494 L
.57326 .1494 L
.56218 .1494 L
.58117 .1494 L
.5918 .1494 L
.59524 .1494 L
.5918 .1494 L
.58117 .1494 L
.56218 .1494 L
.57326 .1494 L
s
.57326 .26845 m
.57326 .2644 L
s
.57326 .2644 m
.57326 .2525 L
s
.57326 .2525 m
.57326 .23358 L
s
.57326 .23358 m
.57326 .20893 L
s
.57326 .20893 m
.57326 .18022 L
s
.57326 .18022 m
.57326 .1494 L
s
.57326 .1494 m
.57326 .11859 L
s
.57326 .11859 m
.57326 .08988 L
s
.57326 .08988 m
.57326 .06523 L
s
.57326 .06523 m
.57326 .04631 L
s
.57326 .04631 m
.57326 .03441 L
s
.57326 .03441 m
.57326 .03036 L
s
.57326 .03036 m
.57326 .03441 L
s
.57326 .03441 m
.57326 .04631 L
s
.57326 .04631 m
.57326 .06523 L
s
.57326 .06523 m
.57326 .08988 L
s
.57326 .08988 m
.57326 .11859 L
s
.57326 .11859 m
.57326 .1494 L
s
.57326 .1494 m
.57326 .18022 L
s
.57326 .18022 m
.57326 .20893 L
s
.57326 .20893 m
.57326 .23358 L
s
.57326 .23358 m
.57326 .2525 L
s
.57326 .2525 m
.57326 .2644 L
s
.57326 .2644 m
.57326 .26845 L
s
.57326 .26845 m
.56218 .26845 L
.56218 .2644 L
.57326 .2644 L
.57326 .26845 L
s
.57326 .2644 m
.56218 .2644 L
.56218 .2525 L
.57326 .2525 L
.57326 .2644 L
s
.57326 .2525 m
.56218 .2525 L
.56218 .23358 L
.57326 .23358 L
.57326 .2525 L
s
.57326 .23358 m
.56218 .23358 L
.56218 .20893 L
.57326 .20893 L
.57326 .23358 L
s
.57326 .20893 m
.56218 .20893 L
.56218 .18022 L
.57326 .18022 L
.57326 .20893 L
s
.57326 .18022 m
.56218 .18022 L
.56218 .1494 L
.57326 .1494 L
.57326 .18022 L
s
.57326 .1494 m
.56218 .1494 L
.56218 .11859 L
.57326 .11859 L
.57326 .1494 L
s
.57326 .11859 m
.56218 .11859 L
.56218 .08988 L
.57326 .08988 L
.57326 .11859 L
s
.57326 .08988 m
.56218 .08988 L
.56218 .06523 L
.57326 .06523 L
.57326 .08988 L
s
.57326 .06523 m
.56218 .06523 L
.56218 .04631 L
.57326 .04631 L
.57326 .06523 L
s
.57326 .04631 m
.56218 .04631 L
.56218 .03441 L
.57326 .03441 L
.57326 .04631 L
s
.57326 .03441 m
.56218 .03441 L
.56218 .03036 L
.57326 .03036 L
.57326 .03441 L
s
.57326 .03036 m
.56218 .03036 L
.56218 .03441 L
.57326 .03441 L
.57326 .03036 L
s
.57326 .03441 m
.56218 .03441 L
.56218 .04631 L
.57326 .04631 L
.57326 .03441 L
s
.57326 .04631 m
.56218 .04631 L
.56218 .06523 L
.57326 .06523 L
.57326 .04631 L
s
.57326 .06523 m
.56218 .06523 L
.56218 .08988 L
.57326 .08988 L
.57326 .06523 L
s
.57326 .08988 m
.56218 .08988 L
.56218 .11859 L
.57326 .11859 L
.57326 .08988 L
s
.57326 .11859 m
.56218 .11859 L
.56218 .1494 L
.57326 .1494 L
.57326 .11859 L
s
.57326 .1494 m
.56218 .1494 L
.56218 .18022 L
.57326 .18022 L
.57326 .1494 L
s
.57326 .18022 m
.56218 .18022 L
.56218 .20893 L
.57326 .20893 L
.57326 .18022 L
s
.57326 .20893 m
.56218 .20893 L
.56218 .23358 L
.57326 .23358 L
.57326 .20893 L
s
.57326 .23358 m
.56218 .23358 L
.56218 .2525 L
.57326 .2525 L
.57326 .23358 L
s
.57326 .2525 m
.56218 .2525 L
.56218 .2644 L
.57326 .2644 L
.57326 .2525 L
s
.57326 .2644 m
.56218 .2644 L
.56218 .26845 L
.57326 .26845 L
.57326 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.50494 .1256 L
s
0 0 0 r
2 Mabswid
.50494 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.50173 .13512 L
s
0 0 0 r
2 Mabswid
.50173 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.50019 .14464 L
s
0 0 0 r
2 Mabswid
.50019 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.50019 .15417 L
s
0 0 0 r
2 Mabswid
.50019 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.50173 .16369 L
s
0 0 0 r
2 Mabswid
.50173 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.50494 .17321 L
s
0 0 0 r
2 Mabswid
.50494 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.50494 .1256 m
.57146 .13501 L
s
0 0 0 r
2 Mabswid
.57146 .13501 Mdot
.039 .916 .04 r
.5 Mabswid
.50173 .13512 m
.57144 .14079 L
s
0 0 0 r
2 Mabswid
.57144 .14079 Mdot
.039 .916 .04 r
.5 Mabswid
.50019 .14464 m
.57143 .14654 L
s
0 0 0 r
2 Mabswid
.57143 .14654 Mdot
.039 .916 .04 r
.5 Mabswid
.50019 .15417 m
.57143 .15227 L
s
0 0 0 r
2 Mabswid
.57143 .15227 Mdot
.039 .916 .04 r
.5 Mabswid
.50173 .16369 m
.57144 .15802 L
s
0 0 0 r
2 Mabswid
.57144 .15802 Mdot
.039 .916 .04 r
.5 Mabswid
.50494 .17321 m
.57146 .1638 L
s
0 0 0 r
2 Mabswid
.57146 .1638 Mdot
.039 .916 .04 r
.5 Mabswid
.57146 .13501 m
.59495 .13779 L
s
0 0 0 r
2 Mabswid
.59495 .13779 Mdot
.039 .916 .04 r
.5 Mabswid
.57144 .14079 m
.59513 .1424 L
s
0 0 0 r
2 Mabswid
.59513 .1424 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .14654 m
.59523 .14707 L
s
0 0 0 r
2 Mabswid
.59523 .14707 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .15227 m
.59523 .15174 L
s
0 0 0 r
2 Mabswid
.59523 .15174 Mdot
.039 .916 .04 r
.5 Mabswid
.57144 .15802 m
.59513 .15641 L
s
0 0 0 r
2 Mabswid
.59513 .15641 Mdot
.039 .916 .04 r
.5 Mabswid
.57146 .1638 m
.59495 .16102 L
s
0 0 0 r
2 Mabswid
.59495 .16102 Mdot
.039 .916 .04 r
.5 Mabswid
.59495 .13779 m
.97619 .23731 L
s
0 0 0 r
2 Mabswid
.97619 .23731 Mdot
.039 .916 .04 r
.5 Mabswid
.59513 .1424 m
.97619 .19891 L
s
0 0 0 r
2 Mabswid
.97619 .19891 Mdot
.039 .916 .04 r
.5 Mabswid
.59523 .14707 m
.97619 .16543 L
s
0 0 0 r
2 Mabswid
.97619 .16543 Mdot
.039 .916 .04 r
.5 Mabswid
.59523 .15174 m
.97619 .13338 L
s
0 0 0 r
2 Mabswid
.97619 .13338 Mdot
.039 .916 .04 r
.5 Mabswid
.59513 .15641 m
.97619 .0999 L
s
0 0 0 r
2 Mabswid
.97619 .0999 Mdot
.039 .916 .04 r
.5 Mabswid
.59495 .16102 m
.97619 .0615 L
s
0 0 0 r
2 Mabswid
.97619 .0615 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool00:3ooooo1?l0001[oooo
o`03o`000?oooooooooo00kooooo002Pooooo`Co0000Joooool00ol0003oooooooooo`0>ooooo`00
X?ooool2o`000003ogmoOol0003ooooo06[ooooo00?o0000ooooooooool03_ooool00:3ooooo0_l0
00000omoOgoo0000ooooo`1Zooooo`03o`000?oooooooooo00kooooo002Pooooo`Co0000Joooool0
0ol0003oooooooooo`0>ooooo`00X?ooool01?l0003oooooo`000?l0001[ooooo`03o`000?oooooo
oooo00kooooo002Pooooo`04o`000?oooooo0000o`0006_ooooo00?o0000ooooooooool03_ooool0
0:3ooooo00Co0000ooooool0003o0000Joooool00ol0003oooooooooo`0>ooooo`00X?ooool00ol0
003oooooo`000002o`0006Sooooo0_l9jPX2o`0000oooooo002Pooooo`Go0000I?ooool4o`WZ2P;o
oooo0_l0000?ooooo`00X?ooool01_l0003oooooo`000?l0003oOgmoo`00063ooooo0ol9jPX6oooo
o`03o`000?oooooooooo00kooooo002Pooooo`06o`000?moOgoo0000o`000?moOgoo0000G?ooool4
o`WZ2PWooooo00?o0000ooooooooool03_ooool00:3ooooo00Ko0000ogmoOol0003o0000ogmoOol0
001Hooooo`Co2NX:3Oooool00ol0003oooooooooo`0>ooooo`00Woooool00omoOgoo0000ogmoO`02
o`0000;oOgmo00?o0000ooooooooool0DOooool4o`WZ2Q7ooooo00?o0000ooooooooool03_ooool0
09gooooo0omoOgl01?l0003oOgmoo`000?l00002ogmoO`03o`000?oooooooooo04gooooo1?l9jPXE
ooooo`03o`000?oooooooooo00kooooo002Looooo`CoOgmo00Co0000ogmoOol0003o00000_moOgl0
0ol0003oooooooooo`1:ooooo`?o2NX:6Oooool00ol0003oooooooooo`0>ooooo`00V_ooool6ogmo
O`Co00000omoOgl00ol0003oooooooooo`15ooooo`Co2NX:7?ooool00ol0003oooooooooo`0>oooo
o`00VOooool7ogmoO`04o`000?moOgoo0000o`0000?oOgmo00?o0000ooooooooool0@Oooool4o`WZ
2R3ooooo00?o0000ooooooooool03_ooool009Sooooo2?moOgl01?l0003oOgmoo`000?l00003ogmo
O`03o`000?oooooooooo03gooooo1?l9jPXQooooo`?o2NX:0_l0000?ooooo`00U_ooool:ogmoO`04
o`000?moOgoo0000o`0000?oOgmo00?o0000ooooooooool0>_ooool3o`WZ2Qkooooo1ol9jPX3oooo
o`;o00003oooool009Gooooo2omoOgl01?l0003oOgmoo`000?l00004ogmoO`03o`000?oooooooooo
03Gooooo1?l9jPXKooooo`Ko2NX:2_ooool00ol0003oooooooooo`0>ooooo`00Toooool00ol0003o
OgmoogmoO`0:ogmoO`04o`000?moOgoo0000o`0000CoOgmo00?o0000ooooooooool0<Oooool4o`WZ
2QWooooo1_l9jPX@ooooo`03o`000?oooooooooo00kooooo002Cooooo`03o`000?moOgooOgmo00[o
Ogmo00Co0000ogmoOol0003o00001?moOgl00ol0003oooooooooo`0]ooooo`Co2NX:5_ooool7o`WZ
2QKooooo00?o0000ooooooooool03_ooool009;ooooo00?o0000ogmoOomoOgl02omoOgl4o`0000Co
Ogmo00?o0000ooooooooool0:Oooool4o`WZ2QCooooo1_l9jPXMooooo`03o`000?oooooooooo00ko
oooo002Booooo`03o`000?moOgooOgmo00_oOgmo00Co0000ogmoOol0003o00001?moOgl00ol0003o
ooooooooo`0Vooooo`?o2NX:4_ooool6o`WZ2R?ooooo00?o0000ooooooooool03_ooool000oooooo
QOl9jPX<ogmoO`04o`000?moOgoo0000o`0000CoOgmo00?o0000ooooooooool08_ooool4o`WZ2Pko
oooo1ol9jPXYooooo`03o`000?oooooooooo00kooooo002@ooooo`;o00000_moOgl6o`WZ2PKoOgmo
00Co0000ogmoOol0003o00001?moOgl00ol0003oooooooooo`0Nooooo`Co2NX:3?ooool6o`WZ2S3o
oooo00?o0000ooooooooool03_ooool008oooooo0ol00008ogmoO`Ko2NX:00Co0000ogmoOol0003o
00001OmoOgl00ol0003oooooooooo`0Iooooo`Co2NX:2Oooool7o`WZ2Rcooooo2_l9jPX2o`0000oo
oooo000?oooooh_o2NX:1_moOgl7o`WZ2P03ogmoOol0003o000001Sooooo0ol9jPX7ooooo`Ko2NX:
7_oooolEo`WZ2P[ooooo0_l0000?ooooo`00T?ooool00ol0003oOgmoogmoO`07ogmoO`ko2NX:00Co
0000o`WZ2_l9jP[o2NX:4_ooool4o`WZ2PCooooo1_l9jPX@oooooaCo2NX:7oooool00ol0003ooooo
ooooo`0>ooooo`003ooooon;o`WZ2PKoOgmo00Co0000ogmoOol0003o00000omoOgl00ol9jP[o0000
o`WZ2P06o`WZ2P[ooooo1?l9jPX00ooooooo2NX:o`WZ2P05o`WZ2P;ooooo5?l9jPXcooooo`03o`00
0?oooooooooo00kooooo002?ooooo`;o00002OmoOgl>o`WZ2P03o`000?l9jP[o2NX:01go2NX:Aooo
ool00ol0003oooooooooo`0>ooooo`00Soooool5o`0000GoOgmo3ol9jPX00ol0003o2NX:o`WZ2P0N
o`WZ2TKooooo00?o0000ooooooooool03_ooool000ooooooR_l9jPX7ogmoO`04o`000?moOgoo0000
o`0000CoOgmo0_l00002ooooo`Oo2NX:1Oooool:o`WZ2POooooo5?l9jPXbooooo`03o`000?oooooo
oooo00kooooo002?ooooo`;o00003?moOgl;o`WZ2P03o`000?l9jP[o2NX:00Co2NX:3Oooool4o`WZ
2P;ooooo1ol9jPXDoooooaCo2NX:7_ooool00ol0003oooooooooo`0>ooooo`00Soooool2o`0000?o
Ogmo2Ol9jPX3ogmoO`04o`000?moOgoo0000o`0000;oOgmo0_l9jPX00ol0003o2NX:o`WZ2P0Eoooo
o`Co2NX:1Oooool6o`WZ2R;ooooo5Ol9jPX9ooooo`03o`000?oooooooooo00kooooo000?ooooohGo
2NX:2_moOgl8o`WZ2P?oOgmo00?o0000ooooooooool06?ooool3o`WZ2PSooooo1ol9jPX`ooooo`Wo
2NX:0_l0000?ooooo`00TOooool01?l0003oOgmoogmoOomoOgl9o`WZ2P;oOgmo00Co0000ogmoOol0
003o00001OmoOgl00ol0003oooooooooo`0Kooooo`Co2NX:2oooool7o`WZ2S;ooooo0_l0000?oooo
o`003ooooon6o`WZ2P_oOgmo00Co0000ogmoOol0003o00001?moOgl00ol0003oooooooooo`0Poooo
o`Co2NX:3_ooool7o`WZ2R_ooooo00?o0000ooooooooool03_ooool0093ooooo0ol0000=ogmoO`04
o`000?moOgoo0000o`0000CoOgmo00?o0000ooooooooool09?ooool4o`WZ2Q7ooooo1ol9jPXToooo
o`03o`000?oooooooooo00kooooo002Booooo`03o`000?moOgooOgmo00_oOgmo1?l00004ogmoO`03
o`000?oooooooooo02Sooooo1?l9jPXDooooo`Ko2NX:7_ooool00ol0003oooooooooo`0>ooooo`00
T_ooool00ol0003oOgmoogmoO`0;ogmoO`04o`000?moOgoo0000o`0000CoOgmo00?o0000oooooooo
ool0;?ooool4o`WZ2QKooooo1ol9jPXGooooo`03o`000?oooooooooo00kooooo002Cooooo`03o`00
0?moOgooOgmo00[oOgmo00Co0000ogmoOol0003o00001?moOgl00ol0003oooooooooo`0`ooooo`Co
2NX:6Oooool7o`WZ2Q3ooooo00?o0000ooooooooool03_ooool009Gooooo2omoOgl01?l0003oOgmo
o`000?l00004ogmoO`03o`000?oooooooooo03Cooooo1?l9jPXLooooo`Oo2NX:2Oooool00ol0003o
ooooooooo`0>ooooo`00U_ooool:ogmoO`04o`000?moOgoo0000o`0000CoOgmo00?o0000oooooooo
ool0>?ooool4o`WZ2Qoooooo1ol9jPX2ooooo`03o`000?oooooooooo00kooooo002Gooooo`WoOgmo
00Co0000ogmoOol0003o00000omoOgl00ol0003oooooooooo`0mooooo`Co2NX:8_ooool2o`WZ2P;o
00003oooool009Wooooo1omoOgl01?l0003oOgmoo`000?l00003ogmoO`03o`000?oooooooooo047o
oooo1?l9jPXPooooo`;o00003oooool009[ooooo1_moOgl01?l0003oOgmoo`000?l00003ogmoO`03
o`000?oooooooooo04Gooooo1?l9jPXLooooo`03o`000?oooooooooo00kooooo002Looooo`CoOgmo
1?l00002ogmoO`03o`000?oooooooooo04[ooooo1?l9jPXHooooo`03o`000?oooooooooo00kooooo
002Mooooo`?oOgmo00Co0000ogmoOol0003o00000_moOgl00ol0003oooooooooo`1>ooooo`?o2NX:
5Oooool00ol0003oooooooooo`0>ooooo`00W_ooool2ogmoO`04o`000?moOgoo0000o`0000;oOgmo
00?o0000ooooooooool0DOooool4o`WZ2Q7ooooo00?o0000ooooooooool03_ooool00:3ooooo00Co
0000ogmoOol0003o00000_moOgl00ol0003oooooooooo`1Eooooo`Co2NX:3Oooool00ol0003ooooo
ooooo`0>ooooo`00X?ooool01_l0003oOgmoo`000?l0003oOgmoo`0005cooooo1?l9jPX9ooooo`03
o`000?oooooooooo00kooooo002Pooooo`06o`000?oooooo0000o`000?moOgoo0000H?ooool4o`WZ
2PGooooo00?o0000ooooooooool03_ooool00:3ooooo1?l000000omoOgoo0000ooooo`1Sooooo`Co
2NX:00?oooooo`000?ooool03oooool00:3ooooo00?o0000ooooool000000_l0001Yooooo`03o`WZ
2_l0003o000000oooooo002Pooooo`03o`000?oooooo000000;o0000J_ooool2o`0000oooooo002P
ooooo`04o`000?oooooo0000o`0006_ooooo00?o0000ooooooooool03_ooool00:3ooooo00Co0000
ooooool0003o0000Joooool00ol0003oooooooooo`0>ooooo`00X?ooool4o`0006_ooooo00?o0000
ooooooooool03_ooool00:3ooooo00Co0000ooooool0003o0000Joooool00ol0003oooooooooo`0>
ooooo`00X?ooool01?l0003oooooo`000?l0001[ooooo`03o`000?oooooooooo00kooooo002Poooo
o`;o000000?oOgmoo`000?ooool0J_ooool00ol0003oooooooooo`0>ooooo`00X?ooool4o`0006_o
oooo00?o0000ooooooooool03_ooool00:3ooooo1?l0001[ooooo`03o`000?oooooooooo00kooooo
003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.63027 .03036 m
.59417 .07004 L
% vacuous filled polygon
newpath
.59417 .07004 m
.57678 .10972 L
.51644 .10972 L
F
.51644 .10972 m
.57678 .10972 L
.57143 .1494 L
.5 .1494 L
.51644 .10972 L
F
.5 .1494 m
.57143 .1494 L
.57678 .18909 L
.51644 .18909 L
.5 .1494 L
F
.51644 .18909 m
.57678 .18909 L
.59417 .22877 L
.51644 .18909 L
F
.59417 .22877 m
.63027 .26845 L
% vacuous filled polygon
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.51644 .10972 m
.5 .1494 L
.51644 .18909 L
s
.63027 .26845 m
.59417 .22877 L
.57678 .18909 L
.57143 .1494 L
.57678 .10972 L
.59417 .07004 L
.63027 .03036 L
s
.5 g
.63027 .1494 m
.59417 .1494 L
% vacuous filled polygon
newpath
.59417 .1494 m
.57678 .1494 L
.51644 .1494 L
F
.51644 .1494 m
.57678 .1494 L
.57143 .1494 L
.5 .1494 L
.51644 .1494 L
F
.5 .1494 m
.57143 .1494 L
.57678 .1494 L
.51644 .1494 L
.5 .1494 L
F
.51644 .1494 m
.57678 .1494 L
.59417 .1494 L
.51644 .1494 L
F
.59417 .1494 m
.63027 .1494 L
% vacuous filled polygon
newpath
0 g
.51644 .1494 m
.5 .1494 L
.51644 .1494 L
s
.63027 .1494 m
.59417 .1494 L
.57678 .1494 L
.57143 .1494 L
.57678 .1494 L
.59417 .1494 L
.63027 .1494 L
s
.5 g
.63027 .03036 m
.59417 .07004 L
.63027 .03036 L
F
.59417 .07004 m
.60763 .10972 L
.57678 .10972 L
.59417 .07004 L
F
.57678 .10972 m
.60763 .10972 L
.59524 .1494 L
.57143 .1494 L
.57678 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.60763 .18909 L
.57678 .18909 L
.57143 .1494 L
F
.57678 .18909 m
.60763 .18909 L
.59417 .22877 L
.57678 .18909 L
F
.59417 .22877 m
.63027 .26845 L
.59417 .22877 L
F
0 g
.63027 .03036 m
.59417 .07004 L
.57678 .10972 L
.57143 .1494 L
.57678 .18909 L
.59417 .22877 L
.63027 .26845 L
s
.60763 .18909 m
.59524 .1494 L
.60763 .10972 L
s
.63027 .03036 m
0 0 rlineto s
.5 g
.63027 .1494 m
.59417 .1494 L
.63027 .1494 L
F
.59417 .1494 m
.60763 .1494 L
.57678 .1494 L
.59417 .1494 L
F
.57678 .1494 m
.60763 .1494 L
.59524 .1494 L
.57143 .1494 L
.57678 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.60763 .1494 L
.57678 .1494 L
.57143 .1494 L
F
.57678 .1494 m
.60763 .1494 L
.59417 .1494 L
.57678 .1494 L
F
.59417 .1494 m
.63027 .1494 L
.59417 .1494 L
F
0 g
.63027 .1494 m
.59417 .1494 L
.57678 .1494 L
.57143 .1494 L
.57678 .1494 L
.59417 .1494 L
.63027 .1494 L
s
.60763 .1494 m
.59524 .1494 L
.60763 .1494 L
s
.63027 .1494 m
0 0 rlineto s
.63027 .26845 m
.63027 .2644 L
s
.63027 .2644 m
.63027 .2525 L
s
.63027 .2525 m
.63027 .23358 L
s
.63027 .23358 m
.63027 .20893 L
s
.63027 .20893 m
.63027 .18022 L
s
.63027 .18022 m
.63027 .1494 L
s
.63027 .1494 m
.63027 .11859 L
s
.63027 .11859 m
.63027 .08988 L
s
.63027 .08988 m
.63027 .06523 L
s
.63027 .06523 m
.63027 .04631 L
s
.63027 .04631 m
.63027 .03441 L
s
.63027 .03441 m
.63027 .03036 L
s
.63027 .03036 m
.63027 .03441 L
s
.63027 .03441 m
.63027 .04631 L
s
.63027 .04631 m
.63027 .06523 L
s
.63027 .06523 m
.63027 .08988 L
s
.63027 .08988 m
.63027 .11859 L
s
.63027 .11859 m
.63027 .1494 L
s
.63027 .1494 m
.63027 .18022 L
s
.63027 .18022 m
.63027 .20893 L
s
.63027 .20893 m
.63027 .23358 L
s
.63027 .23358 m
.63027 .2525 L
s
.63027 .2525 m
.63027 .2644 L
s
.63027 .2644 m
.63027 .26845 L
s
.63027 .26845 m
0 0 rlineto s
.63027 .2644 m
.63027 .26845 L
s
.63027 .2644 m
0 0 rlineto s
.63027 .2525 m
.63027 .2644 L
s
.63027 .2525 m
0 0 rlineto s
.63027 .23358 m
.63027 .2525 L
s
.63027 .23358 m
0 0 rlineto s
.63027 .20893 m
.63027 .23358 L
s
.63027 .20893 m
0 0 rlineto s
.63027 .18022 m
.63027 .20893 L
s
.63027 .18022 m
0 0 rlineto s
.63027 .1494 m
.63027 .18022 L
s
.63027 .1494 m
0 0 rlineto s
.63027 .11859 m
.63027 .1494 L
s
.63027 .11859 m
0 0 rlineto s
.63027 .08988 m
.63027 .11859 L
s
.63027 .08988 m
0 0 rlineto s
.63027 .06523 m
.63027 .08988 L
s
.63027 .06523 m
0 0 rlineto s
.63027 .04631 m
.63027 .06523 L
s
.63027 .04631 m
0 0 rlineto s
.63027 .03441 m
.63027 .04631 L
s
.63027 .03441 m
0 0 rlineto s
.63027 .03036 m
.63027 .03441 L
s
.63027 .03036 m
0 0 rlineto s
.63027 .03441 m
.63027 .03036 L
s
.63027 .03441 m
0 0 rlineto s
.63027 .04631 m
.63027 .03441 L
s
.63027 .04631 m
0 0 rlineto s
.63027 .06523 m
.63027 .04631 L
s
.63027 .06523 m
0 0 rlineto s
.63027 .08988 m
.63027 .06523 L
s
.63027 .08988 m
0 0 rlineto s
.63027 .11859 m
.63027 .08988 L
s
.63027 .11859 m
0 0 rlineto s
.63027 .1494 m
.63027 .11859 L
s
.63027 .1494 m
0 0 rlineto s
.63027 .18022 m
.63027 .1494 L
s
.63027 .18022 m
0 0 rlineto s
.63027 .20893 m
.63027 .18022 L
s
.63027 .20893 m
0 0 rlineto s
.63027 .23358 m
.63027 .20893 L
s
.63027 .23358 m
0 0 rlineto s
.63027 .2525 m
.63027 .23358 L
s
.63027 .2525 m
0 0 rlineto s
.63027 .2644 m
.63027 .2525 L
s
.63027 .2644 m
0 0 rlineto s
.63027 .26845 m
.63027 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.5053 .1256 L
s
0 0 0 r
2 Mabswid
.5053 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.50185 .13512 L
s
0 0 0 r
2 Mabswid
.50185 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.5002 .14464 L
s
0 0 0 r
2 Mabswid
.5002 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.5002 .15417 L
s
0 0 0 r
2 Mabswid
.5002 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.50185 .16369 L
s
0 0 0 r
2 Mabswid
.50185 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.5053 .17321 L
s
0 0 0 r
2 Mabswid
.5053 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.5053 .1256 m
.57205 .13578 L
s
0 0 0 r
2 Mabswid
.57205 .13578 Mdot
.039 .916 .04 r
.5 Mabswid
.50185 .13512 m
.57165 .1412 L
s
0 0 0 r
2 Mabswid
.57165 .1412 Mdot
.039 .916 .04 r
.5 Mabswid
.5002 .14464 m
.57145 .14666 L
s
0 0 0 r
2 Mabswid
.57145 .14666 Mdot
.039 .916 .04 r
.5 Mabswid
.5002 .15417 m
.57145 .15215 L
s
0 0 0 r
2 Mabswid
.57145 .15215 Mdot
.039 .916 .04 r
.5 Mabswid
.50185 .16369 m
.57165 .15761 L
s
0 0 0 r
2 Mabswid
.57165 .15761 Mdot
.039 .916 .04 r
.5 Mabswid
.5053 .17321 m
.57205 .16303 L
s
0 0 0 r
2 Mabswid
.57205 .16303 Mdot
.039 .916 .04 r
.5 Mabswid
.57205 .13578 m
.59599 .13918 L
s
0 0 0 r
2 Mabswid
.59599 .13918 Mdot
.039 .916 .04 r
.5 Mabswid
.57165 .1412 m
.59552 .14315 L
s
0 0 0 r
2 Mabswid
.59552 .14315 Mdot
.039 .916 .04 r
.5 Mabswid
.57145 .14666 m
.59527 .1473 L
s
0 0 0 r
2 Mabswid
.59527 .1473 Mdot
.039 .916 .04 r
.5 Mabswid
.57145 .15215 m
.59527 .15151 L
s
0 0 0 r
2 Mabswid
.59527 .15151 Mdot
.039 .916 .04 r
.5 Mabswid
.57165 .15761 m
.59552 .15566 L
s
0 0 0 r
2 Mabswid
.59552 .15566 Mdot
.039 .916 .04 r
.5 Mabswid
.57205 .16303 m
.59599 .15963 L
s
0 0 0 r
2 Mabswid
.59599 .15963 Mdot
.039 .916 .04 r
.5 Mabswid
.59599 .13918 m
.97619 .19146 L
s
0 0 0 r
2 Mabswid
.97619 .19146 Mdot
.039 .916 .04 r
.5 Mabswid
.59552 .14315 m
.97619 .17167 L
s
0 0 0 r
2 Mabswid
.97619 .17167 Mdot
.039 .916 .04 r
.5 Mabswid
.59527 .1473 m
.97619 .15638 L
s
0 0 0 r
2 Mabswid
.97619 .15638 Mdot
.039 .916 .04 r
.5 Mabswid
.59527 .15151 m
.97619 .14243 L
s
0 0 0 r
2 Mabswid
.97619 .14243 Mdot
.039 .916 .04 r
.5 Mabswid
.59552 .15566 m
.97619 .12714 L
s
0 0 0 r
2 Mabswid
.97619 .12714 Mdot
.039 .916 .04 r
.5 Mabswid
.59599 .15963 m
.97619 .10735 L
s
0 0 0 r
2 Mabswid
.97619 .10735 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo002booooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03_ooool0
0;;ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0>ooooo`00/Oooool2o`0005co
oooo00?o0000ooooooooool03_ooool00;3ooooo00?o0000ooooool00000G?ooool00ol0003ooooo
ooooo`0>ooooo`00[oooool01?l0003oooooooooool0001Looooo`03o`000?oooooooooo00kooooo
002^ooooo`05o`000?ooooooooooooooool00000G?ooool00ol0003oooooooooo`0>ooooo`00[Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03_oo
ool00:cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo00kooooo002[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0F_ooool00ol0
003oooooooooo`0>ooooo`00Z_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool03_ooool00:Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo00kooooo002Xooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`0>ooooo`00Yoooool00omoOgoo0000ooooo`08
ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03_ooool00:Gooooo0_moOgl00ol0
003oOgmoooooo`08ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03_ooool00:?o
oooo1?moOgl00ol0003oOgmoooooo`08ooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool03_ooool00:7ooooo1_moOgl00ol0003oOgmoooooo`08ooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooooooool03_ooool009oooooo1omoOgl01?l0003oOgmoogmoOomoOgl8ooooo`03o`00
0?oooooooooo05[ooooo00?o0000ooooooooool03_ooool009gooooo2OmoOgl01?l0003oOgmoogmo
OomoOgl8ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03_ooool009cooooo2_mo
Ogl01?l0003oOgmoogmoOomoOgl8ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
3_ooool009[ooooo2omoOgl00ol0003oOgmoogmoO`03ogmoO`Oooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`0>ooooo`00V?ooool=ogmoO`03o`000?moOgooOgmo00?oOgmo1oooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo002Fooooo`ooOgmo00?o0000ogmo
OomoOgl00omoOgl7ooooo`03o`000?oooooooooo05Kooooo1?l9jPX2o`0000oooooo002Cooooo`03
o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04oooooo1ol9jPX4ooooo`;o00003oooool009?ooooo00?o0000ogmoOomoOgl0
3_moOgl00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
B?ooool7o`WZ2P_ooooo00?o0000ooooooooool03_ooool009;ooooo00?o0000ogmoOomoOgl03omo
Ogl00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?oo
ool8o`WZ2Q;ooooo00?o0000ooooooooool03_ooool009;ooooo00?o0000ogmoOomoOgl03omoOgl0
0ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool7
o`WZ2Q[ooooo00?o0000ooooooooool03_ooool000ooooooQOl9jPX?ogmoO`03o`000?moOgooOgmo
00GoOgmo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`Oo2NX:8Oooool2o`00
00oooooo002@ooooo`;o00000_moOgl6o`WZ2PWoOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02_ooooo1ol9jPXQooooo`Oo2NX:0_l0000?ooooo`00
Soooool3o`0000SoOgmo1_l9jPX3ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Sooooo`So2NX:6Oooool?o`WZ2POooooo00?o0000ooooooooool0
3_ooool000ooooooQ_l9jPX;ogmoO`Oo2NX:00CoOgmoo`000?l0003o00001oooool00ol0003ooooo
ooooo`0Looooo`Oo2NX:4oooool>o`WZ2QKooooo00?o0000ooooooooool03_ooool0093ooooo00?o
0000ogmoOomoOgl00_moOgl9o`WZ2PCoOgmo0_l00003ogmoO`03o`WZ2_l0003o2NX:00Co2NX:1?oo
ool00ol0003oooooooooo`0Eooooo`Oo2NX:2oooool?o`WZ2RCooooo0_l0000?ooooo`003ooooon;
o`WZ2PCoOgmo2_l9jPX00ol0003o2NX:o`WZ2P0:o`WZ2Pgooooo2?l9jPX3ooooo`oo2NX:6_oooolI
o`WZ2P;o00003oooool008oooooo0_l00009ogmoO`ko2NX:00?o0000o`WZ2_l9jPX0Bol9jPXIoooo
o`03o`000?oooooooooo00kooooo002?ooooo`Go00001OmoOgl?o`WZ2P03o`000?l9jP[o2NX:03;o
2NX:<_ooool00ol0003oooooooooo`0>ooooo`003ooooon:o`WZ2PWoOgmo0_l00002ogmoO`;o2NX:
00?o0000o`WZ2_l9jPX02Ol9jPX@oooooa?o2NX:1_oooolRo`WZ2Q3ooooo0_l0000?ooooo`00Sooo
ool2o`0000coOgmo2ol9jPX00ol0003o2NX:o`WZ2P02o`WZ2PGooooo00?o0000ooooooooool05_oo
ool7o`WZ2PGooooo3?l9jPXLoooooa3o2NX:0_l0000?ooooo`00Soooool2o`0000?oOgmo2Ol9jPX2
ogmoO`Oo2NX:0_moOgl3o`0000Oooooo00?o0000ooooooooool07Oooool7o`WZ2P[ooooo3Ol9jPXO
ooooo`03o`000?oooooooooo00kooooo000?ooooohGo2NX:1OmoOgl6o`WZ2P?oOgmo0_l00006ogmo
O`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool8o`WZ2Poooooo3Ol9jPXBoooo
o`03o`000?oooooooooo00kooooo002Aooooo`03o`000?moOgoo2NX:00Go2NX:2_moOgl00ol0003o
OgmoogmoO`04ogmoO`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;?ooool7o`WZ2QGo
oooo3Ol9jPX5ooooo`;o00003oooool000ooooooQ?l9jPX@ogmoO`03o`000?moOgooOgmo00GoOgmo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0cooooo`Oo2NX:6oooool5o`WZ2P;o0000
3oooool0093ooooo0ol0000@ogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0jooooo`So2NX:6?ooool00ol0003oooooooooo`0>ooooo`00T_ooool0
0ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`12ooooo`Oo2NX:4Oooool00ol0003oooooooooo`0>ooooo`00T_ooool00ol0
003oOgmoogmoO`0?ogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000ooooooooool00oooool00ol0
003oooooooooo`19ooooo`Oo2NX:2_ooool00ol0003oooooooooo`0>ooooo`00Toooool00ol0003o
OgmoogmoO`0>ogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1@ooooo`Oo2NX:0oooool00ol0003oooooooooo`0>ooooo`00UOooool?ogmoO`03o`00
0?moOgooOgmo00GoOgmo1_ooool00ol0003oooooooooo`1Gooooo`?o2NX:0_l0000?ooooo`00Uooo
ool>ogmoO`03o`000?moOgooOgmo00CoOgmo1_ooool00ol0003oooooooooo`1Jooooo`;o00003ooo
ool009Wooooo3?moOgl00ol0003oOgmoogmoO`03ogmoO`Oooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`0>ooooo`00Voooool:ogmoO`03o`000?moOgooOgmo00?oOgmo1oooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo002Mooooo`WoOgmo00?o0000ogmoOomo
Ogl00_moOgl7ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03_ooool009oooooo
1omoOgl01?l0003oOgmoogmoOomoOgl8ooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool03_ooool00:3ooooo1_moOgl01?l0003oOgmoogmoOomoOgl8ooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool03_ooool00:;ooooo1OmoOgl00ol0003oOgmoogmoO`08ooooo`03o`00
0?oooooooooo05[ooooo00?o0000ooooooooool03_ooool00:Cooooo0omoOgl00ol0003oOgmooooo
o`08ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03_ooool00:Kooooo00?oOgmo
o`000?moOgl02Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo002Xoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0>oooo
o`00Z?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool03_ooool00:Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`03o`00
0?oooooooooo00kooooo002Zooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`0>ooooo`00Zoooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool03_ooool00:cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo002]ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0>ooooo`00[_ooool01Ol0003ooooo
oooooooooooo000005cooooo00?o0000ooooooooool03_ooool00:oooooo00Co0000oooooooooooo
0000G?ooool00ol0003oooooooooo`0>ooooo`00/?ooool00ol0003oooooo`00001Looooo`03o`00
0?oooooooooo00kooooo002aooooo`;o0000G?ooool00ol0003oooooooooo`0>ooooo`00/_ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[BoxData[
    \({{3514.4616218374526`, {FocalPoint \[Rule] {91.28945784851695`, 0, 0}, 
          FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.013486245551052593`, 
          SpotSize \[Rule] 0.013486245553160052`, 
          BackFocalLength \[Rule] 28.710542151483054`, 
          FocalPlaneTilt \[Rule] {0.9999999999999999`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {775.9742466133561`, {FocalPoint \[Rule] \
{30.148355297171946`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 1.341856669687849`, 
          SpotSize \[Rule] 1.3418566696878385`, 
          BackFocalLength \[Rule] 89.85164470282805`, 
          FocalPlaneTilt \[Rule] {0.9999999999999999`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {4192.012761213741`, {FocalPoint \[Rule] \
{115.82715371847196`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 3.7103335332745564`, 
          SpotSize \[Rule] 3.710333533274557`, 
          BackFocalLength \[Rule] 15.827153718471962`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {874.175836595173`, {FocalPoint \[Rule] \
{70.25165530994826`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.36220345738498094`, 
          SpotSize \[Rule] 0.3622034573850006`, 
          BackFocalLength \[Rule] 49.74834469005174`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {775.7484098366915`, {FocalPoint \[Rule] \
{141.5398915391221`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.1089297289569935`, 
          SpotSize \[Rule] 0.10892972895686305`, 
          BackFocalLength \[Rule] 21.539891539122095`, 
          FocalPlaneTilt \[Rule] {0.9999999999999999`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {1464.6549927050462`, {FocalPoint \[Rule] \
{82.90795733501837`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.024807848797740697`, 
          SpotSize \[Rule] 0.02480784879716786`, 
          BackFocalLength \[Rule] 37.09204266498163`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {0.3268603070231724`, {FocalPoint \[Rule] \
{185.2272492715715`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.238502561679639`, 
          SpotSize \[Rule] 0.238502561679639`, 
          BackFocalLength \[Rule] 65.22724927157151`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {66.25301899266987`, {FocalPoint \[Rule] \
{160.11515606034828`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.24181462358791678`, 
          SpotSize \[Rule] 0.2418146235879021`, 
          BackFocalLength \[Rule] 40.11515606034828`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {2547.2956187701075`, {FocalPoint \[Rule] \
{97.75728414166836`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.0334842770778362`, 
          SpotSize \[Rule] 0.033484277076987395`, 
          BackFocalLength \[Rule] 22.242715858331636`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {71.87338030145999`, {FocalPoint \[Rule] \
{468.6086940908671`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.117238779794957`, 
          SpotSize \[Rule] 0.11723877979494185`, 
          BackFocalLength \[Rule] 348.6086940908671`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {2845.8951501028773`, {FocalPoint \[Rule] \
{100.49456147574928`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.04419627047659744`, 
          SpotSize \[Rule] 0.044196270476275896`, 
          BackFocalLength \[Rule] 19.50543852425072`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {3.988954867630745`, {FocalPoint \[Rule] \
{185.5236933359824`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.08709641156853523`, 
          SpotSize \[Rule] 0.08709641156853523`, 
          BackFocalLength \[Rule] 65.52369333598239`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {4381.171607727888`, {FocalPoint \[Rule] \
{105.13048004333967`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.05636290026606275`, 
          SpotSize \[Rule] 0.056362900265558485`, 
          BackFocalLength \[Rule] 14.869519956660326`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {0.000388439088709984`, {FocalPoint \[Rule] \
{199.47672281520695`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.01559163667595951`, 
          SpotSize \[Rule] 0.015591636675959506`, 
          BackFocalLength \[Rule] 79.47672281520695`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {7.285235710397572`, {FocalPoint \[Rule] \
{181.46975612850903`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.013357371969199484`, 
          SpotSize \[Rule] 0.013357371969191173`, 
          BackFocalLength \[Rule] 61.46975612850903`, 
          FocalPlaneTilt \[Rule] {0.9999999999999999`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {8.068591866607317`, {FocalPoint \[Rule] \
{179.83614213666465`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.019054801386563267`, 
          SpotSize \[Rule] 0.019054801386580746`, 
          BackFocalLength \[Rule] 59.83614213666465`, 
          FocalPlaneTilt \[Rule] {0.9999999999999999`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {0.00013802125808465998`, {FocalPoint \[Rule] \
{199.83765385717652`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.00670351592379466`, 
          SpotSize \[Rule] 0.006703515923794661`, 
          BackFocalLength \[Rule] 79.83765385717652`, 
          FocalPlaneTilt \[Rule] {0.9999999999999999`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {1214.3797665334562`, {FocalPoint \[Rule] \
{91.37933236572816`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.07790756814631597`, 
          SpotSize \[Rule] 0.07790756814649838`, 
          BackFocalLength \[Rule] 28.62066763427184`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {0.00009802114265316588`, {FocalPoint \[Rule] \
{200.01418107350474`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.0027353816052949416`, 
          SpotSize \[Rule] 0.0027353816052949416`, 
          BackFocalLength \[Rule] 80.01418107350474`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {387.59759199237266`, {FocalPoint \[Rule] \
{142.42236656881792`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.06105604046829183`, 
          SpotSize \[Rule] 0.06105604046846639`, 
          BackFocalLength \[Rule] 22.42236656881792`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {0.000982951770528682`, {FocalPoint \[Rule] \
{199.77573095810143`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.005101090498739651`, 
          SpotSize \[Rule] 0.0051010904987396485`, 
          BackFocalLength \[Rule] 79.77573095810143`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {1073.3286118808403`, {FocalPoint \[Rule] \
{99.58845598084649`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.12711778932928544`, 
          SpotSize \[Rule] 0.12711778932917364`, 
          BackFocalLength \[Rule] 20.41154401915351`, 
          FocalPlaneTilt \[Rule] {0.9999999999999999`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {1781.9353349094238`, {FocalPoint \[Rule] \
{104.41470664896416`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.030565500718751436`, 
          SpotSize \[Rule] 0.030565500718751436`, 
          BackFocalLength \[Rule] 15.585293351035844`, 
          FocalPlaneTilt \[Rule] {0.9999999999999999`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {24.771176878160986`, {FocalPoint \[Rule] \
{163.10695702171202`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.03745621266241416`, 
          SpotSize \[Rule] 0.03745621266238452`, 
          BackFocalLength \[Rule] 43.10695702171202`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {27.344119946118077`, {FocalPoint \[Rule] \
{158.9227729080839`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.10477097912752156`, 
          SpotSize \[Rule] 0.10477097912752156`, 
          BackFocalLength \[Rule] 38.922772908083914`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {1037.6524526160435`, {FocalPoint \[Rule] \
{129.4521378073568`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.049930953549241375`, 
          SpotSize \[Rule] 0.04993095355094904`, 
          BackFocalLength \[Rule] 9.452137807356792`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] 
            TurboRays}}, {240.48068098874953`, {FocalPoint \[Rule] \
{136.24480343896073`, 0, 0}, FocusType \[Rule] RMSFocus, 
          WeightedSpotSize \[Rule] 0.07654156526043195`, 
          SpotSize \[Rule] 0.07654156526038552`, 
          BackFocalLength \[Rule] 16.24480343896073`, 
          FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
          TurboRays \[Rule] TurboRays}}}\)], "Output",
  CellLabel->"Out[117]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[localminimum = \
FindMinimum[meritFunction,{c1,.01},{c2,-.003},{c3,-.01},MaxIterations->200]]
\
\>", "Input",
  CellLabel->"In[118]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \({0.35000000000002274`\ Second, {0.00005403307166667642`, {c1 \[Rule] 
            0.012080558556426453`, c2 \[Rule] \(-0.0027097910335684675`\), 
          c3 \[Rule] \(-0.008477025770372824`\)}}}\)], "Output",
  CellLabel->"Out[118]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindFocusFast[AnalyzeSystem[{
\tLineOfRays[10,NumberOfRays->21],
\tComponentRendering[{Move[
        SphericalLensSurface[1/c1/.localminimum[[2]],50,ComponentMedium->BK7],\
100],
\t\tMove[SphericalLensSurface[1/c2/.localminimum[[2]],50,ComponentMedium->{\
BK7,SF11}],115],
\t\tMove[SphericalLensSurface[1/c3/.localminimum[[2]],50,ComponentMedium->\
SF11],120]}],
\tMove[Screen[50],200]}, PlotType->TopView, ShowArrows->False]]\
\>", "Input",
  CellLabel->"In[119]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.149405 0.0047619 [
[.5 .00655 -7.53125 -6 ]
[.5 .00655 7.53125 6 ]
[.57143 .00655 -7.53125 -6 ]
[.57143 .00655 7.53125 6 ]
[.59524 .00655 -7.53125 -6 ]
[.59524 .00655 7.53125 6 ]
[.97619 .00655 -4.75 -6 ]
[.97619 .00655 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.51841 .03036 m
.56739 .03036 L
.56964 .07004 L
.50807 .07004 L
.51841 .03036 L
F
.50807 .07004 m
.56964 .07004 L
.57098 .10972 L
.502 .10972 L
.50807 .07004 L
F
.502 .10972 m
.57098 .10972 L
.57143 .1494 L
.5 .1494 L
.502 .10972 L
F
.5 .1494 m
.57143 .1494 L
.57098 .18909 L
.502 .18909 L
.5 .1494 L
F
.502 .18909 m
.57098 .18909 L
.56964 .22877 L
.50807 .22877 L
.502 .18909 L
F
.50807 .22877 m
.56964 .22877 L
.56739 .26845 L
.51841 .26845 L
.50807 .22877 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.51841 .03036 m
.50807 .07004 L
.502 .10972 L
.5 .1494 L
.502 .18909 L
.50807 .22877 L
.51841 .26845 L
.56739 .26845 L
.56964 .22877 L
.57098 .18909 L
.57143 .1494 L
.57098 .10972 L
.56964 .07004 L
.56739 .03036 L
.51841 .03036 L
s
.5 g
.51841 .1494 m
.56739 .1494 L
.56964 .1494 L
.50807 .1494 L
.51841 .1494 L
F
.50807 .1494 m
.56964 .1494 L
.57098 .1494 L
.502 .1494 L
.50807 .1494 L
F
.502 .1494 m
.57098 .1494 L
.57143 .1494 L
.5 .1494 L
.502 .1494 L
F
.5 .1494 m
.57143 .1494 L
.57098 .1494 L
.502 .1494 L
.5 .1494 L
F
.502 .1494 m
.57098 .1494 L
.56964 .1494 L
.50807 .1494 L
.502 .1494 L
F
.50807 .1494 m
.56964 .1494 L
.56739 .1494 L
.51841 .1494 L
.50807 .1494 L
F
0 g
.51841 .1494 m
.50807 .1494 L
.502 .1494 L
.5 .1494 L
.502 .1494 L
.50807 .1494 L
.51841 .1494 L
.56739 .1494 L
.56964 .1494 L
.57098 .1494 L
.57143 .1494 L
.57098 .1494 L
.56964 .1494 L
.56739 .1494 L
.51841 .1494 L
s
.5 g
.56739 .03036 m
.58248 .03036 L
.5896 .07004 L
.56964 .07004 L
.56739 .03036 L
F
.56964 .07004 m
.5896 .07004 L
.59383 .10972 L
.57098 .10972 L
.56964 .07004 L
F
.57098 .10972 m
.59383 .10972 L
.59524 .1494 L
.57143 .1494 L
.57098 .10972 L
F
.57143 .1494 m
.59524 .1494 L
.59383 .18909 L
.57098 .18909 L
.57143 .1494 L
F
.57098 .18909 m
.59383 .18909 L
.5896 .22877 L
.56964 .22877 L
.57098 .18909 L
F
.56964 .22877 m
.5896 .22877 L
.58248 .26845 L
.56739 .26845 L
.56964 .22877 L
F
0 g
.56739 .03036 m
.56964 .07004 L
.57098 .10972 L
.57143 .1494 L
.57098 .18909 L
.56964 .22877 L
.56739 .26845 L
.58248 .26845 L
.5896 .22877 L
.59383 .18909 L
.59524 .1494 L
.59383 .10972 L
.5896 .07004 L
.58248 .03036 L
.56739 .03036 L
s
.5 g
.56739 .1494 m
.58248 .1494 L
.5896 .1494 L
.56964 .1494 L
.56739 .1494 L
F
.56964 .1494 m
.5896 .1494 L
.59383 .1494 L
.57098 .1494 L
.56964 .1494 L
F
.57098 .1494 m
.59383 .1494 L
.59524 .1494 L
.57143 .1494 L
.57098 .1494 L
F
.57143 .1494 m
.59524 .1494 L
.59383 .1494 L
.57098 .1494 L
.57143 .1494 L
F
.57098 .1494 m
.59383 .1494 L
.5896 .1494 L
.56964 .1494 L
.57098 .1494 L
F
.56964 .1494 m
.5896 .1494 L
.58248 .1494 L
.56739 .1494 L
.56964 .1494 L
F
0 g
.56739 .1494 m
.56964 .1494 L
.57098 .1494 L
.57143 .1494 L
.57098 .1494 L
.56964 .1494 L
.56739 .1494 L
.58248 .1494 L
.5896 .1494 L
.59383 .1494 L
.59524 .1494 L
.59383 .1494 L
.5896 .1494 L
.58248 .1494 L
.56739 .1494 L
s
.51841 .26845 m
.56739 .26845 L
.56739 .2644 L
.51841 .2644 L
.51841 .26845 L
s
.51841 .2644 m
.56739 .2644 L
.56739 .2525 L
.51841 .2525 L
.51841 .2644 L
s
.51841 .2525 m
.56739 .2525 L
.56739 .23358 L
.51841 .23358 L
.51841 .2525 L
s
.51841 .23358 m
.56739 .23358 L
.56739 .20893 L
.51841 .20893 L
.51841 .23358 L
s
.51841 .20893 m
.56739 .20893 L
.56739 .18022 L
.51841 .18022 L
.51841 .20893 L
s
.51841 .18022 m
.56739 .18022 L
.56739 .1494 L
.51841 .1494 L
.51841 .18022 L
s
.51841 .1494 m
.56739 .1494 L
.56739 .11859 L
.51841 .11859 L
.51841 .1494 L
s
.51841 .11859 m
.56739 .11859 L
.56739 .08988 L
.51841 .08988 L
.51841 .11859 L
s
.51841 .08988 m
.56739 .08988 L
.56739 .06523 L
.51841 .06523 L
.51841 .08988 L
s
.51841 .06523 m
.56739 .06523 L
.56739 .04631 L
.51841 .04631 L
.51841 .06523 L
s
.51841 .04631 m
.56739 .04631 L
.56739 .03441 L
.51841 .03441 L
.51841 .04631 L
s
.51841 .03441 m
.56739 .03441 L
.56739 .03036 L
.51841 .03036 L
.51841 .03441 L
s
.51841 .03036 m
.56739 .03036 L
.56739 .03441 L
.51841 .03441 L
.51841 .03036 L
s
.51841 .03441 m
.56739 .03441 L
.56739 .04631 L
.51841 .04631 L
.51841 .03441 L
s
.51841 .04631 m
.56739 .04631 L
.56739 .06523 L
.51841 .06523 L
.51841 .04631 L
s
.51841 .06523 m
.56739 .06523 L
.56739 .08988 L
.51841 .08988 L
.51841 .06523 L
s
.51841 .08988 m
.56739 .08988 L
.56739 .11859 L
.51841 .11859 L
.51841 .08988 L
s
.51841 .11859 m
.56739 .11859 L
.56739 .1494 L
.51841 .1494 L
.51841 .11859 L
s
.51841 .1494 m
.56739 .1494 L
.56739 .18022 L
.51841 .18022 L
.51841 .1494 L
s
.51841 .18022 m
.56739 .18022 L
.56739 .20893 L
.51841 .20893 L
.51841 .18022 L
s
.51841 .20893 m
.56739 .20893 L
.56739 .23358 L
.51841 .23358 L
.51841 .20893 L
s
.51841 .23358 m
.56739 .23358 L
.56739 .2525 L
.51841 .2525 L
.51841 .23358 L
s
.51841 .2525 m
.56739 .2525 L
.56739 .2644 L
.51841 .2644 L
.51841 .2525 L
s
.51841 .2644 m
.56739 .2644 L
.56739 .26845 L
.51841 .26845 L
.51841 .2644 L
s
.56739 .26845 m
.58248 .26845 L
.58248 .2644 L
.56739 .2644 L
.56739 .26845 L
s
.56739 .2644 m
.58248 .2644 L
.58248 .2525 L
.56739 .2525 L
.56739 .2644 L
s
.56739 .2525 m
.58248 .2525 L
.58248 .23358 L
.56739 .23358 L
.56739 .2525 L
s
.56739 .23358 m
.58248 .23358 L
.58248 .20893 L
.56739 .20893 L
.56739 .23358 L
s
.56739 .20893 m
.58248 .20893 L
.58248 .18022 L
.56739 .18022 L
.56739 .20893 L
s
.56739 .18022 m
.58248 .18022 L
.58248 .1494 L
.56739 .1494 L
.56739 .18022 L
s
.56739 .1494 m
.58248 .1494 L
.58248 .11859 L
.56739 .11859 L
.56739 .1494 L
s
.56739 .11859 m
.58248 .11859 L
.58248 .08988 L
.56739 .08988 L
.56739 .11859 L
s
.56739 .08988 m
.58248 .08988 L
.58248 .06523 L
.56739 .06523 L
.56739 .08988 L
s
.56739 .06523 m
.58248 .06523 L
.58248 .04631 L
.56739 .04631 L
.56739 .06523 L
s
.56739 .04631 m
.58248 .04631 L
.58248 .03441 L
.56739 .03441 L
.56739 .04631 L
s
.56739 .03441 m
.58248 .03441 L
.58248 .03036 L
.56739 .03036 L
.56739 .03441 L
s
.56739 .03036 m
.58248 .03036 L
.58248 .03441 L
.56739 .03441 L
.56739 .03036 L
s
.56739 .03441 m
.58248 .03441 L
.58248 .04631 L
.56739 .04631 L
.56739 .03441 L
s
.56739 .04631 m
.58248 .04631 L
.58248 .06523 L
.56739 .06523 L
.56739 .04631 L
s
.56739 .06523 m
.58248 .06523 L
.58248 .08988 L
.56739 .08988 L
.56739 .06523 L
s
.56739 .08988 m
.58248 .08988 L
.58248 .11859 L
.56739 .11859 L
.56739 .08988 L
s
.56739 .11859 m
.58248 .11859 L
.58248 .1494 L
.56739 .1494 L
.56739 .11859 L
s
.56739 .1494 m
.58248 .1494 L
.58248 .18022 L
.56739 .18022 L
.56739 .1494 L
s
.56739 .18022 m
.58248 .18022 L
.58248 .20893 L
.56739 .20893 L
.56739 .18022 L
s
.56739 .20893 m
.58248 .20893 L
.58248 .23358 L
.56739 .23358 L
.56739 .20893 L
s
.56739 .23358 m
.58248 .23358 L
.58248 .2525 L
.56739 .2525 L
.56739 .23358 L
s
.56739 .2525 m
.58248 .2525 L
.58248 .2644 L
.56739 .2644 L
.56739 .2525 L
s
.56739 .2644 m
.58248 .2644 L
.58248 .26845 L
.56739 .26845 L
.56739 .2644 L
s
.97619 .03036 m
.97619 .07004 L
.97619 .10972 L
.97619 .1494 L
.97619 .18909 L
.97619 .22877 L
.97619 .26845 L
.97619 .26845 L
.97619 .22877 L
.97619 .18909 L
.97619 .1494 L
.97619 .10972 L
.97619 .07004 L
.97619 .03036 L
.97619 .03036 L
s
.97619 .1494 m
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
.97619 .1494 L
s
.97619 .26845 m
.97619 .2644 L
.97619 .2525 L
.97619 .23358 L
.97619 .20893 L
.97619 .18022 L
.97619 .1494 L
.97619 .11859 L
.97619 .08988 L
.97619 .06523 L
.97619 .04631 L
.97619 .03441 L
.97619 .03036 L
.97619 .03441 L
.97619 .04631 L
.97619 .06523 L
.97619 .08988 L
.97619 .11859 L
.97619 .1494 L
.97619 .18022 L
.97619 .20893 L
.97619 .23358 L
.97619 .2525 L
.97619 .2644 L
.97619 .26845 L
s
.039 .916 .04 r
.02381 .1256 m
.50072 .1256 L
s
0 0 0 r
2 Mabswid
.50072 .1256 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .12798 m
.50058 .12798 L
s
0 0 0 r
2 Mabswid
.50058 .12798 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13036 m
.50046 .13036 L
s
0 0 0 r
2 Mabswid
.50046 .13036 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13274 m
.50035 .13274 L
s
0 0 0 r
2 Mabswid
.50035 .13274 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13512 m
.50026 .13512 L
s
0 0 0 r
2 Mabswid
.50026 .13512 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1375 m
.50018 .1375 L
s
0 0 0 r
2 Mabswid
.50018 .1375 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .13988 m
.50012 .13988 L
s
0 0 0 r
2 Mabswid
.50012 .13988 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14226 m
.50006 .14226 L
s
0 0 0 r
2 Mabswid
.50006 .14226 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14464 m
.50003 .14464 L
s
0 0 0 r
2 Mabswid
.50003 .14464 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14702 m
.50001 .14702 L
s
0 0 0 r
2 Mabswid
.50001 .14702 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1494 m
.5 .1494 L
s
0 0 0 r
2 Mabswid
.5 .1494 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15179 m
.50001 .15179 L
s
0 0 0 r
2 Mabswid
.50001 .15179 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15417 m
.50003 .15417 L
s
0 0 0 r
2 Mabswid
.50003 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15655 m
.50006 .15655 L
s
0 0 0 r
2 Mabswid
.50006 .15655 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .15893 m
.50012 .15893 L
s
0 0 0 r
2 Mabswid
.50012 .15893 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16131 m
.50018 .16131 L
s
0 0 0 r
2 Mabswid
.50018 .16131 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16369 m
.50026 .16369 L
s
0 0 0 r
2 Mabswid
.50026 .16369 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16607 m
.50035 .16607 L
s
0 0 0 r
2 Mabswid
.50035 .16607 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16845 m
.50046 .16845 L
s
0 0 0 r
2 Mabswid
.50046 .16845 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17083 m
.50058 .17083 L
s
0 0 0 r
2 Mabswid
.50058 .17083 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17321 m
.50072 .17321 L
s
0 0 0 r
2 Mabswid
.50072 .17321 Mdot
.039 .916 .04 r
.5 Mabswid
.50072 .1256 m
.57129 .12705 L
s
0 0 0 r
2 Mabswid
.57129 .12705 Mdot
.039 .916 .04 r
.5 Mabswid
.50058 .12798 m
.57131 .12929 L
s
0 0 0 r
2 Mabswid
.57131 .12929 Mdot
.039 .916 .04 r
.5 Mabswid
.50046 .13036 m
.57134 .13153 L
s
0 0 0 r
2 Mabswid
.57134 .13153 Mdot
.039 .916 .04 r
.5 Mabswid
.50035 .13274 m
.57136 .13376 L
s
0 0 0 r
2 Mabswid
.57136 .13376 Mdot
.039 .916 .04 r
.5 Mabswid
.50026 .13512 m
.57138 .136 L
s
0 0 0 r
2 Mabswid
.57138 .136 Mdot
.039 .916 .04 r
.5 Mabswid
.50018 .1375 m
.57139 .13824 L
s
0 0 0 r
2 Mabswid
.57139 .13824 Mdot
.039 .916 .04 r
.5 Mabswid
.50012 .13988 m
.57141 .14047 L
s
0 0 0 r
2 Mabswid
.57141 .14047 Mdot
.039 .916 .04 r
.5 Mabswid
.50006 .14226 m
.57142 .1427 L
s
0 0 0 r
2 Mabswid
.57142 .1427 Mdot
.039 .916 .04 r
.5 Mabswid
.50003 .14464 m
.57142 .14494 L
s
0 0 0 r
2 Mabswid
.57142 .14494 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .14702 m
.57143 .14717 L
s
0 0 0 r
2 Mabswid
.57143 .14717 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .1494 m
.57143 .1494 L
s
0 0 0 r
2 Mabswid
.57143 .1494 Mdot
.039 .916 .04 r
.5 Mabswid
.50001 .15179 m
.57143 .15164 L
s
0 0 0 r
2 Mabswid
.57143 .15164 Mdot
.039 .916 .04 r
.5 Mabswid
.50003 .15417 m
.57142 .15387 L
s
0 0 0 r
2 Mabswid
.57142 .15387 Mdot
.039 .916 .04 r
.5 Mabswid
.50006 .15655 m
.57142 .15611 L
s
0 0 0 r
2 Mabswid
.57142 .15611 Mdot
.039 .916 .04 r
.5 Mabswid
.50012 .15893 m
.57141 .15834 L
s
0 0 0 r
2 Mabswid
.57141 .15834 Mdot
.039 .916 .04 r
.5 Mabswid
.50018 .16131 m
.57139 .16057 L
s
0 0 0 r
2 Mabswid
.57139 .16057 Mdot
.039 .916 .04 r
.5 Mabswid
.50026 .16369 m
.57138 .16281 L
s
0 0 0 r
2 Mabswid
.57138 .16281 Mdot
.039 .916 .04 r
.5 Mabswid
.50035 .16607 m
.57136 .16504 L
s
0 0 0 r
2 Mabswid
.57136 .16504 Mdot
.039 .916 .04 r
.5 Mabswid
.50046 .16845 m
.57134 .16728 L
s
0 0 0 r
2 Mabswid
.57134 .16728 Mdot
.039 .916 .04 r
.5 Mabswid
.50058 .17083 m
.57131 .16952 L
s
0 0 0 r
2 Mabswid
.57131 .16952 Mdot
.039 .916 .04 r
.5 Mabswid
.50072 .17321 m
.57129 .17176 L
s
0 0 0 r
2 Mabswid
.57129 .17176 Mdot
.039 .916 .04 r
.5 Mabswid
.57129 .12705 m
.59481 .12742 L
s
0 0 0 r
2 Mabswid
.59481 .12742 Mdot
.039 .916 .04 r
.5 Mabswid
.57131 .12929 m
.59489 .12962 L
s
0 0 0 r
2 Mabswid
.59489 .12962 Mdot
.039 .916 .04 r
.5 Mabswid
.57134 .13153 m
.59496 .13182 L
s
0 0 0 r
2 Mabswid
.59496 .13182 Mdot
.039 .916 .04 r
.5 Mabswid
.57136 .13376 m
.59503 .13402 L
s
0 0 0 r
2 Mabswid
.59503 .13402 Mdot
.039 .916 .04 r
.5 Mabswid
.57138 .136 m
.59508 .13622 L
s
0 0 0 r
2 Mabswid
.59508 .13622 Mdot
.039 .916 .04 r
.5 Mabswid
.57139 .13824 m
.59513 .13842 L
s
0 0 0 r
2 Mabswid
.59513 .13842 Mdot
.039 .916 .04 r
.5 Mabswid
.57141 .14047 m
.59517 .14062 L
s
0 0 0 r
2 Mabswid
.59517 .14062 Mdot
.039 .916 .04 r
.5 Mabswid
.57142 .1427 m
.5952 .14281 L
s
0 0 0 r
2 Mabswid
.5952 .14281 Mdot
.039 .916 .04 r
.5 Mabswid
.57142 .14494 m
.59522 .14501 L
s
0 0 0 r
2 Mabswid
.59522 .14501 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .14717 m
.59523 .14721 L
s
0 0 0 r
2 Mabswid
.59523 .14721 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .1494 m
.59524 .1494 L
s
0 0 0 r
2 Mabswid
.59524 .1494 Mdot
.039 .916 .04 r
.5 Mabswid
.57143 .15164 m
.59523 .1516 L
s
0 0 0 r
2 Mabswid
.59523 .1516 Mdot
.039 .916 .04 r
.5 Mabswid
.57142 .15387 m
.59522 .1538 L
s
0 0 0 r
2 Mabswid
.59522 .1538 Mdot
.039 .916 .04 r
.5 Mabswid
.57142 .15611 m
.5952 .15599 L
s
0 0 0 r
2 Mabswid
.5952 .15599 Mdot
.039 .916 .04 r
.5 Mabswid
.57141 .15834 m
.59517 .15819 L
s
0 0 0 r
2 Mabswid
.59517 .15819 Mdot
.039 .916 .04 r
.5 Mabswid
.57139 .16057 m
.59513 .16039 L
s
0 0 0 r
2 Mabswid
.59513 .16039 Mdot
.039 .916 .04 r
.5 Mabswid
.57138 .16281 m
.59508 .16259 L
s
0 0 0 r
2 Mabswid
.59508 .16259 Mdot
.039 .916 .04 r
.5 Mabswid
.57136 .16504 m
.59503 .16479 L
s
0 0 0 r
2 Mabswid
.59503 .16479 Mdot
.039 .916 .04 r
.5 Mabswid
.57134 .16728 m
.59496 .16699 L
s
0 0 0 r
2 Mabswid
.59496 .16699 Mdot
.039 .916 .04 r
.5 Mabswid
.57131 .16952 m
.59489 .16919 L
s
0 0 0 r
2 Mabswid
.59489 .16919 Mdot
.039 .916 .04 r
.5 Mabswid
.57129 .17176 m
.59481 .17139 L
s
0 0 0 r
2 Mabswid
.59481 .17139 Mdot
.039 .916 .04 r
.5 Mabswid
.59481 .12742 m
.97619 .14998 L
s
0 0 0 r
2 Mabswid
.97619 .14998 Mdot
.039 .916 .04 r
.5 Mabswid
.59489 .12962 m
.97619 .14991 L
s
0 0 0 r
2 Mabswid
.97619 .14991 Mdot
.039 .916 .04 r
.5 Mabswid
.59496 .13182 m
.97619 .14984 L
s
0 0 0 r
2 Mabswid
.97619 .14984 Mdot
.039 .916 .04 r
.5 Mabswid
.59503 .13402 m
.97619 .14977 L
s
0 0 0 r
2 Mabswid
.97619 .14977 Mdot
.039 .916 .04 r
.5 Mabswid
.59508 .13622 m
.97619 .14971 L
s
0 0 0 r
2 Mabswid
.97619 .14971 Mdot
.039 .916 .04 r
.5 Mabswid
.59513 .13842 m
.97619 .14966 L
s
0 0 0 r
2 Mabswid
.97619 .14966 Mdot
.039 .916 .04 r
.5 Mabswid
.59517 .14062 m
.97619 .1496 L
s
0 0 0 r
2 Mabswid
.97619 .1496 Mdot
.039 .916 .04 r
.5 Mabswid
.5952 .14281 m
.97619 .14955 L
s
0 0 0 r
2 Mabswid
.97619 .14955 Mdot
.039 .916 .04 r
.5 Mabswid
.59522 .14501 m
.97619 .1495 L
s
0 0 0 r
2 Mabswid
.97619 .1495 Mdot
.039 .916 .04 r
.5 Mabswid
.59523 .14721 m
.97619 .14945 L
s
0 0 0 r
2 Mabswid
.97619 .14945 Mdot
.039 .916 .04 r
.5 Mabswid
.59524 .1494 m
.97619 .1494 L
s
0 0 0 r
2 Mabswid
.97619 .1494 Mdot
.039 .916 .04 r
.5 Mabswid
.59523 .1516 m
.97619 .14936 L
s
0 0 0 r
2 Mabswid
.97619 .14936 Mdot
.039 .916 .04 r
.5 Mabswid
.59522 .1538 m
.97619 .14931 L
s
0 0 0 r
2 Mabswid
.97619 .14931 Mdot
.039 .916 .04 r
.5 Mabswid
.5952 .15599 m
.97619 .14926 L
s
0 0 0 r
2 Mabswid
.97619 .14926 Mdot
.039 .916 .04 r
.5 Mabswid
.59517 .15819 m
.97619 .14921 L
s
0 0 0 r
2 Mabswid
.97619 .14921 Mdot
.039 .916 .04 r
.5 Mabswid
.59513 .16039 m
.97619 .14915 L
s
0 0 0 r
2 Mabswid
.97619 .14915 Mdot
.039 .916 .04 r
.5 Mabswid
.59508 .16259 m
.97619 .1491 L
s
0 0 0 r
2 Mabswid
.97619 .1491 Mdot
.039 .916 .04 r
.5 Mabswid
.59503 .16479 m
.97619 .14904 L
s
0 0 0 r
2 Mabswid
.97619 .14904 Mdot
.039 .916 .04 r
.5 Mabswid
.59496 .16699 m
.97619 .14897 L
s
0 0 0 r
2 Mabswid
.97619 .14897 Mdot
.039 .916 .04 r
.5 Mabswid
.59489 .16919 m
.97619 .1489 L
s
0 0 0 r
2 Mabswid
.97619 .1489 Mdot
.039 .916 .04 r
.5 Mabswid
.59481 .17139 m
.97619 .14883 L
s
0 0 0 r
2 Mabswid
.97619 .14883 Mdot
gsave
.5 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57143 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .00655 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L3) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00655 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .275 L
0 .275 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[119]:=",
  ImageSize->{288, 79.1875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ROooool6o`000004ooooool0
003o0000o`0000[ooooo3ol0001Qooooo`?o00004?ooool008[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00003oooool0
08[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00gooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00004?ooool008[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool04?ooool008[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`00063ooooo00Co0000oooooooooooo00003oooool008Wooooo
0ol00004ooooo`;o00002oooool3o`0000?ooooo0ol00004ooooo`?o0000HOooool3o`0000oooooo
003oooooob7ooooo003ooooooa3ooooo00?o0000ooooooooool03_ooool009Cooooo4_l0001Yoooo
o`03o`000?oooooooooo00kooooo002Doooooa;o0000JOooool00ol0003oooooooooo`0>ooooo`00
U?ooool00ol0003oOgmoogmoO`0:ogmoO`05o`000?moOgooOgmoogmoOol00000JOooool00ol0003o
ooooooooo`0>ooooo`00Toooool2o`0000coOgmo00Co0000ogmoOomoOgooOgmo0_l0001Xooooo`03
o`000?oooooooooo00kooooo002CoooooaCo0000J?ooool00ol0003oooooooooo`0>ooooo`00Tooo
ool2o`0000coOgmo00Co0000ogmoOomoOgooOgmo0_l0001Xooooo`03o`000?oooooooooo00kooooo
002Booooo`03o`000?moOgoo000000coOgmo0_l00002ogmoO`;o0000J?ooool00ol0003ooooooooo
o`0>ooooo`00T_ooool00ol0003oOgmoo`00000<ogmoO`;o00000_moOgl2o`0006Sooooo00?o0000
ooooooooool03_ooool009;ooooo00?o0000ogmoOol000003?moOgl2o`0000;oOgmo00?o0000ogmo
Ool00000Ioooool00ol0003oooooooooo`0>ooooo`00TOooool00ol0003oOgmoogmoO`0Bo`000003
ogmoOol0003ooooo06Kooooo00?o0000ooooooooool03_ooool0097ooooo00Co0000ogmoOomoOgoo
00003?moOgl2o`0000;oOgmo00?o0000ogmoOol00000Ioooool00ol0003oooooooooo`0>ooooo`00
TOooool01?l0003oOgmoogmoOol0000<ogmoO`;o00000_moOgl00ol0003oOgmoo`00001Wooooo`03
o`000?oooooooooo00kooooo002Aooooo`04o`000?moOgooOgmoo`0000coOgmo0_l00002ogmoO`03
o`000?moOgoo000006Oooooo00?o0000ooooooooool03_ooool0097ooooo00Co0000ogmoOomoOgoo
00003?moOgl2o`0000;oOgmo00?o0000ogmoOol00000Ioooool00ol0003oooooooooo`0>ooooo`00
TOooool01?l0003oOgmoogmoOol0000<ogmoO`;o00000_moOgl00ol0003oOgmoo`00001Wooooo`03
o`000?oooooooooo00kooooo002Aooooo`04o`000?moOgooOgmoo`0000coOgmo0_l00002ogmoO`03
o`000?moOgoo000006Oooooo00?o0000ooooooooool03_ooool0093ooooo00Co0000ogmoOomoOgoo
Ogmo4_l00002ogmoO`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03_ooool0093ooooo
00Go0000ogmoOomoOgooOgmoo`00000<ogmoO`;o00000_moOgl01?l0003oOgmoogmoOol0001Voooo
o`03o`000?oooooooooo00kooooo002@ooooo`05o`000?moOgooOgmoogmoOol000003?moOgl2o`00
00;oOgmo00Co0000ogmoOomoOgoo0000I_ooool00ol0003oooooooooo`0>ooooo`00T?ooool01Ol0
003oOgmoogmoOomoOgoo000000coOgmo0_l00002ogmoO`04o`000?moOgooOgmoo`0006Kooooo00?o
0000ooooooooool03_ooool0093ooooo00Go0000ogmoOomoOgooOgmoo`00000<ogmoO`;o00000_mo
Ogl01?l0003oOgmoogmoOol0001Vooooo`03o`000?oooooooooo00kooooo002@ooooo`05o`000?mo
OgooOgmoogmoOol000003?moOgl2o`0000;oOgmo00Co0000ogmoOomoOgoo0000I_ooool00ol0003o
ooooooooo`0>ooooo`00T?ooool01Ol0003oOgmoogmoOomoOgoo000000coOgmo0_l00002ogmoO`04
o`000?moOgooOgmoo`0006Kooooo00?o0000ooooooooool03_ooool0093ooooo00Co0000ogmoOomo
OgooOgmo4_l00002ogmoO`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03_ooool0093o
oooo00Go0000ogmoOomoOgooOgmoo`00000<ogmoO`;o00000_moOgl01?l0003oOgmoogmoOol0001V
ooooo`03o`000?oooooooooo00kooooo000?oooooh_o2NX:1omoOgl3o`000004ogmoOol0003oOgmo
ogmoO`;o0000IOooool00ol0003oooooooooo`0>ooooo`003ooooonTo`WZ2Ucooooo00?o0000oooo
ooooool03_ooool000ooooooVOl9jPX00ol0003o2NX:o`WZ2P0Io`WZ2T_ooooo00?o0000oooooooo
ool03_ooool000ooooooVOl9jPX00ol0003o2NX:o`WZ2P0Zo`WZ2S[ooooo00?o0000ooooooooool0
3_ooool000ooooooVOl9jPX00ol0003o2NX:o`WZ2P0ko`WZ2RWooooo00?o0000ooooooooool03_oo
ool000ooooooVOl9jPX00ol0003o2NX:o`WZ2P1<o`WZ2QSooooo00?o0000ooooooooool03_ooool0
00ooooooVOl9jPX00ol0003o2NX:o`WZ2P1Mo`WZ2POooooo0_l0000?ooooo`003ooooonIo`WZ2P03
o`000?l9jP[o2NX:06Co2NX:0_l0000?ooooo`003ooooonIo`WZ2P03o`000?l9jP[o2NX:05_o2NX:
2Oooool00ol0003oooooooooo`0>ooooo`003ooooonIo`WZ2P03o`000?l9jP[o2NX:04[o2NX:6_oo
ool00ol0003oooooooooo`0>ooooo`003ooooonIo`WZ2P03o`000?l9jP[o2NX:03Wo2NX::oooool0
0ol0003oooooooooo`0>ooooo`003ooooonIo`WZ2P03o`000?l9jP[o2NX:02So2NX:??ooool00ol0
003oooooooooo`0>ooooo`003ooooonIo`WZ2P03o`000?l9jP[o2NX:01Oo2NX:COooool00ol0003o
ooooooooo`0>ooooo`003ooooonRo`WZ2Ukooooo00?o0000ooooooooool03_ooool008oooooo0_l0
0003ogmoO`03o`000?moOgooOgmo00[oOgmo0_l00002ogmoO`04o`000?moOgooOgmoo`0006Kooooo
00?o0000ooooooooool03_ooool0093ooooo00Co0000ogmoOomoOgooOgmo4_l00002ogmoO`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool03_ooool0093ooooo00Go0000ogmoOomoOgooOgmo
o`00000<ogmoO`;o00000_moOgl01?l0003oOgmoogmoOol0001Vooooo`03o`000?oooooooooo00ko
oooo002@ooooo`05o`000?moOgooOgmoogmoOol000003?moOgl2o`0000;oOgmo00Co0000ogmoOomo
Ogoo0000I_ooool00ol0003oooooooooo`0>ooooo`00T?ooool01Ol0003oOgmoogmoOomoOgoo0000
00coOgmo0_l00002ogmoO`04o`000?moOgooOgmoo`0006Kooooo00?o0000ooooooooool03_ooool0
093ooooo00Go0000ogmoOomoOgooOgmoo`00000<ogmoO`;o00000_moOgl01?l0003oOgmoogmoOol0
001Vooooo`03o`000?oooooooooo00kooooo002@ooooo`05o`000?moOgooOgmoogmoOol000003?mo
Ogl2o`0000;oOgmo00Co0000ogmoOomoOgoo0000I_ooool00ol0003oooooooooo`0>ooooo`00T?oo
ool01Ol0003oOgmoogmoOomoOgoo000000coOgmo0_l00002ogmoO`04o`000?moOgooOgmoo`0006Ko
oooo00?o0000ooooooooool03_ooool0093ooooo00Go0000ogmoOomoOgooOgmoo`00000<ogmoO`;o
00000_moOgl01?l0003oOgmoogmoOol0001Vooooo`03o`000?oooooooooo00kooooo002Aooooo`03
o`000?moOgooOgmo01;o000000?oOgmoo`000?ooool0I_ooool00ol0003oooooooooo`0>ooooo`00
TOooool01?l0003oOgmoogmoOol0000<ogmoO`;o00000_moOgl00ol0003oOgmoo`00001Wooooo`03
o`000?oooooooooo00kooooo002Aooooo`04o`000?moOgooOgmoo`0000coOgmo0_l00002ogmoO`03
o`000?moOgoo000006Oooooo00?o0000ooooooooool03_ooool0097ooooo00Co0000ogmoOomoOgoo
00003?moOgl2o`0000;oOgmo00?o0000ogmoOol00000Ioooool00ol0003oooooooooo`0>ooooo`00
TOooool01?l0003oOgmoogmoOol0000<ogmoO`;o00000_moOgl00ol0003oOgmoo`00001Wooooo`03
o`000?oooooooooo00kooooo002Aooooo`04o`000?moOgooOgmoo`0000coOgmo0_l00002ogmoO`03
o`000?moOgoo000006Oooooo00?o0000ooooooooool03_ooool0097ooooo00?o0000ogmoOomoOgl0
4_l000000omoOgoo0000ooooo`1Vooooo`03o`000?oooooooooo00kooooo002Aooooo`04o`000?mo
OgooOgmoo`0000coOgmo0_l00002ogmoO`03o`000?moOgoo000006Oooooo00?o0000ooooooooool0
3_ooool009;ooooo00?o0000ogmoOol000003?moOgl2o`0000;oOgmo00?o0000ogmoOol00000Iooo
ool00ol0003oooooooooo`0>ooooo`00T_ooool00ol0003oOgmoo`00000<ogmoO`;o00000_moOgl2
o`0006Sooooo00?o0000ooooooooool03_ooool009;ooooo00?o0000ogmoOol000003?moOgl2o`00
00;oOgmo0_l0001Xooooo`03o`000?oooooooooo00kooooo002CoooooaCo0000J?ooool00ol0003o
ooooooooo`0>ooooo`00Toooool2o`0000coOgmo00Co0000ogmoOomoOgooOgmo0_l0001Xooooo`03
o`000?oooooooooo00kooooo002Cooooo`;o00003?moOgl01?l0003oOgmoogmoOomoOgl2o`0006So
oooo00?o0000ooooooooool03_ooool009?ooooo0_l0000<ogmoO`05o`000?moOgooOgmoogmoOol0
0000JOooool00ol0003oooooooooo`0>ooooo`00U?oooolBo`0006Wooooo00?o0000ooooooooool0
3_ooool009Cooooo4_l0001Yooooo`03o`000?oooooooooo00kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {78.1875, 0}} -> {-12.0668, -34.6856, \
0.780954, 0.780954}},
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],

Cell[BoxData[
    \({FocalPoint \[Rule] {198.0668449776327`, 0, 0}, 
      FocusType \[Rule] RMSFocus, 
      WeightedSpotSize \[Rule] 0.003554499922354537`, 
      SpotSize \[Rule] 0.003554499922354903`, 
      BackFocalLength \[Rule] 78.06684497763271`, 
      FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
      TurboRays \[Rule] TurboRays}\)], "Output",
  CellLabel->"Out[119]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindFocusFast[{
\tLineOfRays[10,NumberOfRays->101],
\tComponentRendering[{Move[
        SphericalLensSurface[1/c1/.localminimum[[2]],50,ComponentMedium->BK7],\
100],
\t\tMove[SphericalLensSurface[1/c2/.localminimum[[2]],50,ComponentMedium->{\
BK7,SF11}],115],
\t\tMove[SphericalLensSurface[1/c3/.localminimum[[2]],50,ComponentMedium->\
SF11],120]}],
\tMove[Screen[50],200]}]\
\>", "Input",
  CellLabel->"In[120]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[BoxData[
    \({FocalPoint \[Rule] {198.08299304577247`, 0, 0}, 
      FocusType \[Rule] RMSFocus, 
      WeightedSpotSize \[Rule] 0.0032111914796282`, 
      SpotSize \[Rule] 0.0032111914796283353`, 
      BackFocalLength \[Rule] 78.08299304577247`, 
      FocalPlaneTilt \[Rule] {1.`, 0, 0}, 
      TurboRays \[Rule] TurboRays}\)], "Output",
  CellLabel->"Out[120]=",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.2.3", "AOG2.2", "AOG2."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3 Geometric Intensity Calculations", "Subsection",
  CellTags->{"AOG0.", "2.3", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell[CellGroupData[{

Cell["Set-up System", "Subsubsection",
  CellTags->{"AOG0.", "2.3.1", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell[CellGroupData[{

Cell["\<\
localminimum = {c1\[Rule]0.041742,c2\[Rule]-0.00807904}\
\>", "Input",
  CellLabel->"In[121]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell[BoxData[
    \({c1 \[Rule] 0.041742`, c2 \[Rule] \(-0.00807904`\)}\)], "Output",
  CellLabel->"Out[121]=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}]
}, Open  ]],

Cell["\<\
optics = {
\tSphericalLens[1/c1/.localminimum,1/c2/.localminimum,30,20,ComponentMedium->\
3/2],
\tMove[Screen[50],{d+50,50}]};\
\>", "Input",
  CellLabel->"In[122]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell["\<\
opticalsystem = {Move[LineOfRays[10,NumberOfRays->21],{-50,{y,0}}],optics};\
\>", "Input",
  CellLabel->"In[123]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell[CellGroupData[{

Cell["\<\
tracedsystem = AnalyzeSystem[opticalsystem,PlotType->TopView];\
\>", "Input",
  CellLabel->"In[124]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00952381 0.279286 0.00952381 [
[.59524 .10786 -5.03125 -6 ]
[.59524 .10786 5.03125 6 ]
[.97619 .01262 -4.75 -6 ]
[.97619 .01262 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .53 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.55026 .13643 m
.68179 .13643 L
.68662 .18405 L
.52083 .18405 L
.55026 .13643 L
F
.52083 .18405 m
.68662 .18405 L
.68951 .23167 L
.50502 .23167 L
.52083 .18405 L
F
.50502 .23167 m
.68951 .23167 L
.69048 .27929 L
.5 .27929 L
.50502 .23167 L
F
.5 .27929 m
.69048 .27929 L
.68951 .3269 L
.50502 .3269 L
.5 .27929 L
F
.50502 .3269 m
.68951 .3269 L
.68662 .37452 L
.52083 .37452 L
.50502 .3269 L
F
.52083 .37452 m
.68662 .37452 L
.68179 .42214 L
.55026 .42214 L
.52083 .37452 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.55026 .13643 m
.52083 .18405 L
.50502 .23167 L
.5 .27929 L
.50502 .3269 L
.52083 .37452 L
.55026 .42214 L
.68179 .42214 L
.68662 .37452 L
.68951 .3269 L
.69048 .27929 L
.68951 .23167 L
.68662 .18405 L
.68179 .13643 L
.55026 .13643 L
s
.5 g
.55026 .27929 m
.68179 .27929 L
.68662 .27929 L
.52083 .27929 L
.55026 .27929 L
F
.52083 .27929 m
.68662 .27929 L
.68951 .27929 L
.50502 .27929 L
.52083 .27929 L
F
.50502 .27929 m
.68951 .27929 L
.69048 .27929 L
.5 .27929 L
.50502 .27929 L
F
.5 .27929 m
.69048 .27929 L
.68951 .27929 L
.50502 .27929 L
.5 .27929 L
F
.50502 .27929 m
.68951 .27929 L
.68662 .27929 L
.52083 .27929 L
.50502 .27929 L
F
.52083 .27929 m
.68662 .27929 L
.68179 .27929 L
.55026 .27929 L
.52083 .27929 L
F
0 g
.55026 .27929 m
.52083 .27929 L
.50502 .27929 L
.5 .27929 L
.50502 .27929 L
.52083 .27929 L
.55026 .27929 L
.68179 .27929 L
.68662 .27929 L
.68951 .27929 L
.69048 .27929 L
.68951 .27929 L
.68662 .27929 L
.68179 .27929 L
.55026 .27929 L
s
.55026 .42214 m
.68179 .42214 L
.68179 .41728 L
.55026 .41728 L
.55026 .42214 L
s
.55026 .41728 m
.68179 .41728 L
.68179 .403 L
.55026 .403 L
.55026 .41728 L
s
.55026 .403 m
.68179 .403 L
.68179 .3803 L
.55026 .3803 L
.55026 .403 L
s
.55026 .3803 m
.68179 .3803 L
.68179 .35071 L
.55026 .35071 L
.55026 .3803 L
s
.55026 .35071 m
.68179 .35071 L
.68179 .31626 L
.55026 .31626 L
.55026 .35071 L
s
.55026 .31626 m
.68179 .31626 L
.68179 .27929 L
.55026 .27929 L
.55026 .31626 L
s
.55026 .27929 m
.68179 .27929 L
.68179 .24231 L
.55026 .24231 L
.55026 .27929 L
s
.55026 .24231 m
.68179 .24231 L
.68179 .20786 L
.55026 .20786 L
.55026 .24231 L
s
.55026 .20786 m
.68179 .20786 L
.68179 .17827 L
.55026 .17827 L
.55026 .20786 L
s
.55026 .17827 m
.68179 .17827 L
.68179 .15557 L
.55026 .15557 L
.55026 .17827 L
s
.55026 .15557 m
.68179 .15557 L
.68179 .1413 L
.55026 .1413 L
.55026 .15557 L
s
.55026 .1413 m
.68179 .1413 L
.68179 .13643 L
.55026 .13643 L
.55026 .1413 L
s
.55026 .13643 m
.68179 .13643 L
.68179 .1413 L
.55026 .1413 L
.55026 .13643 L
s
.55026 .1413 m
.68179 .1413 L
.68179 .15557 L
.55026 .15557 L
.55026 .1413 L
s
.55026 .15557 m
.68179 .15557 L
.68179 .17827 L
.55026 .17827 L
.55026 .15557 L
s
.55026 .17827 m
.68179 .17827 L
.68179 .20786 L
.55026 .20786 L
.55026 .17827 L
s
.55026 .20786 m
.68179 .20786 L
.68179 .24231 L
.55026 .24231 L
.55026 .20786 L
s
.55026 .24231 m
.68179 .24231 L
.68179 .27929 L
.55026 .27929 L
.55026 .24231 L
s
.55026 .27929 m
.68179 .27929 L
.68179 .31626 L
.55026 .31626 L
.55026 .27929 L
s
.55026 .31626 m
.68179 .31626 L
.68179 .35071 L
.55026 .35071 L
.55026 .31626 L
s
.55026 .35071 m
.68179 .35071 L
.68179 .3803 L
.55026 .3803 L
.55026 .35071 L
s
.55026 .3803 m
.68179 .3803 L
.68179 .403 L
.55026 .403 L
.55026 .3803 L
s
.55026 .403 m
.68179 .403 L
.68179 .41728 L
.55026 .41728 L
.55026 .403 L
s
.55026 .41728 m
.68179 .41728 L
.68179 .42214 L
.55026 .42214 L
.55026 .41728 L
s
.97619 .04119 m
.97619 .12056 L
.97619 .19992 L
.97619 .27929 L
.97619 .35865 L
.97619 .43802 L
.97619 .51738 L
.97619 .51738 L
.97619 .43802 L
.97619 .35865 L
.97619 .27929 L
.97619 .19992 L
.97619 .12056 L
.97619 .04119 L
.97619 .04119 L
s
.97619 .27929 m
.97619 .27929 L
.97619 .27929 L
.97619 .27929 L
.97619 .27929 L
.97619 .27929 L
.97619 .27929 L
.97619 .27929 L
.97619 .27929 L
.97619 .27929 L
.97619 .27929 L
.97619 .27929 L
.97619 .27929 L
.97619 .27929 L
.97619 .27929 L
s
.97619 .51738 m
.97619 .50927 L
.97619 .48548 L
.97619 .44764 L
.97619 .39833 L
.97619 .34091 L
.97619 .27929 L
.97619 .21766 L
.97619 .16024 L
.97619 .11093 L
.97619 .07309 L
.97619 .0493 L
.97619 .04119 L
.97619 .0493 L
.97619 .07309 L
.97619 .11093 L
.97619 .16024 L
.97619 .21766 L
.97619 .27929 L
.97619 .34091 L
.97619 .39833 L
.97619 .44764 L
.97619 .48548 L
.97619 .50927 L
.97619 .51738 L
s
.039 .916 .04 r
.02381 .23167 m
.50502 .23167 L
s
% Start of user PostScript
-50. -5. 0.527584 -5. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50502 .23167 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .23643 m
.50406 .23643 L
s
% Start of user PostScript
-50. -4.5 0.426433 -4.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50406 .23643 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24119 m
.5032 .24119 L
s
% Start of user PostScript
-50. -4. 0.336296 -4. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5032 .24119 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24595 m
.50245 .24595 L
s
% Start of user PostScript
-50. -3.5 0.257049 -3.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50245 .24595 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25071 m
.5018 .25071 L
s
% Start of user PostScript
-50. -3. 0.188581 -3. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5018 .25071 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25548 m
.50125 .25548 L
s
% Start of user PostScript
-50. -2.5 0.130801 -2.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50125 .25548 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26024 m
.5008 .26024 L
s
% Start of user PostScript
-50. -2. 0.08363 -2. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5008 .26024 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .265 m
.50045 .265 L
s
% Start of user PostScript
-50. -1.5 0.0470059 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50045 .265 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .26976 m
.5002 .26976 L
s
% Start of user PostScript
-50. -1. 0.0208801 -1. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5002 .26976 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27452 m
.50005 .27452 L
s
% Start of user PostScript
-50. -0.5 0.00521832 -0.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50005 .27452 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .27929 m
.5 .27929 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5 .27929 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28405 m
.50005 .28405 L
s
% Start of user PostScript
-50. 0.5 0.00521832 0.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50005 .28405 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .28881 m
.5002 .28881 L
s
% Start of user PostScript
-50. 1. 0.0208801 1. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5002 .28881 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29357 m
.50045 .29357 L
s
% Start of user PostScript
-50. 1.5 0.0470059 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50045 .29357 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29833 m
.5008 .29833 L
s
% Start of user PostScript
-50. 2. 0.08363 2. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5008 .29833 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .3031 m
.50125 .3031 L
s
% Start of user PostScript
-50. 2.5 0.130801 2.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50125 .3031 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .30786 m
.5018 .30786 L
s
% Start of user PostScript
-50. 3. 0.188581 3. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5018 .30786 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .31262 m
.50245 .31262 L
s
% Start of user PostScript
-50. 3.5 0.257049 3.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50245 .31262 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .31738 m
.5032 .31738 L
s
% Start of user PostScript
-50. 4. 0.336296 4. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.5032 .31738 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .32214 m
.50406 .32214 L
s
% Start of user PostScript
-50. 4.5 0.426433 4.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50406 .32214 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .3269 m
.50502 .3269 L
s
% Start of user PostScript
-50. 5. 0.527584 5. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50502 .3269 Mdot
.039 .916 .04 r
.5 Mabswid
.50502 .23167 m
.68997 .24475 L
s
% Start of user PostScript
0.527584 -5. 19.9469 -3.62623 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68997 .24475 Mdot
.039 .916 .04 r
.5 Mabswid
.50406 .23643 m
.69007 .24823 L
s
% Start of user PostScript
0.426433 -4.5 19.957 -3.26065 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69007 .24823 Mdot
.039 .916 .04 r
.5 Mabswid
.5032 .24119 m
.69015 .2517 L
s
% Start of user PostScript
0.336296 -4. 19.9661 -2.89603 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69015 .2517 Mdot
.039 .916 .04 r
.5 Mabswid
.50245 .24595 m
.69023 .25517 L
s
% Start of user PostScript
0.257049 -3.5 19.9741 -2.53225 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69023 .25517 Mdot
.039 .916 .04 r
.5 Mabswid
.5018 .25071 m
.6903 .25863 L
s
% Start of user PostScript
0.188581 -3. 19.981 -2.16919 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6903 .25863 Mdot
.039 .916 .04 r
.5 Mabswid
.50125 .25548 m
.69035 .26208 L
s
% Start of user PostScript
0.130801 -2.5 19.9868 -1.80674 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69035 .26208 Mdot
.039 .916 .04 r
.5 Mabswid
.5008 .26024 m
.6904 .26553 L
s
% Start of user PostScript
0.08363 -2. 19.9916 -1.44479 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6904 .26553 Mdot
.039 .916 .04 r
.5 Mabswid
.50045 .265 m
.69043 .26897 L
s
% Start of user PostScript
0.0470059 -1.5 19.9953 -1.08325 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69043 .26897 Mdot
.039 .916 .04 r
.5 Mabswid
.5002 .26976 m
.69046 .27241 L
s
% Start of user PostScript
0.0208801 -1. 19.9979 -0.722001 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69046 .27241 Mdot
.039 .916 .04 r
.5 Mabswid
.50005 .27452 m
.69047 .27585 L
s
% Start of user PostScript
0.00521832 -0.5 19.9995 -0.360951 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69047 .27585 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .27929 m
.69048 .27929 L
s
% Start of user PostScript
0 0 20. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69048 .27929 Mdot
.039 .916 .04 r
.5 Mabswid
.50005 .28405 m
.69047 .28272 L
s
% Start of user PostScript
0.00521832 0.5 19.9995 0.360951 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69047 .28272 Mdot
.039 .916 .04 r
.5 Mabswid
.5002 .28881 m
.69046 .28616 L
s
% Start of user PostScript
0.0208801 1. 19.9979 0.722001 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69046 .28616 Mdot
.039 .916 .04 r
.5 Mabswid
.50045 .29357 m
.69043 .2896 L
s
% Start of user PostScript
0.0470059 1.5 19.9953 1.08325 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69043 .2896 Mdot
.039 .916 .04 r
.5 Mabswid
.5008 .29833 m
.6904 .29305 L
s
% Start of user PostScript
0.08363 2. 19.9916 1.44479 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6904 .29305 Mdot
.039 .916 .04 r
.5 Mabswid
.50125 .3031 m
.69035 .29649 L
s
% Start of user PostScript
0.130801 2.5 19.9868 1.80674 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69035 .29649 Mdot
.039 .916 .04 r
.5 Mabswid
.5018 .30786 m
.6903 .29994 L
s
% Start of user PostScript
0.188581 3. 19.981 2.16919 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6903 .29994 Mdot
.039 .916 .04 r
.5 Mabswid
.50245 .31262 m
.69023 .3034 L
s
% Start of user PostScript
0.257049 3.5 19.9741 2.53225 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69023 .3034 Mdot
.039 .916 .04 r
.5 Mabswid
.5032 .31738 m
.69015 .30687 L
s
% Start of user PostScript
0.336296 4. 19.9661 2.89603 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69015 .30687 Mdot
.039 .916 .04 r
.5 Mabswid
.50406 .32214 m
.69007 .31034 L
s
% Start of user PostScript
0.426433 4.5 19.957 3.26065 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.69007 .31034 Mdot
.039 .916 .04 r
.5 Mabswid
.50502 .3269 m
.68997 .31382 L
s
% Start of user PostScript
0.527584 5. 19.9469 3.62623 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68997 .31382 Mdot
.039 .916 .04 r
.5 Mabswid
.68997 .24475 m
.97619 .27951 L
s
% Start of user PostScript
19.9469 -3.62623 50. 0.0238369 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27951 Mdot
.039 .916 .04 r
.5 Mabswid
.69007 .24823 m
.97619 .27938 L
s
% Start of user PostScript
19.957 -3.26065 50. 0.00948384 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27938 Mdot
.039 .916 .04 r
.5 Mabswid
.69015 .2517 m
.97619 .27928 L
s
% Start of user PostScript
19.9661 -2.89603 50. -0.000966777 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27928 Mdot
.039 .916 .04 r
.5 Mabswid
.69023 .25517 m
.97619 .27921 L
s
% Start of user PostScript
19.9741 -2.53225 50. -0.00801844 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27921 Mdot
.039 .916 .04 r
.5 Mabswid
.6903 .25863 m
.97619 .27917 L
s
% Start of user PostScript
19.981 -2.16919 50. -0.0121485 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27917 Mdot
.039 .916 .04 r
.5 Mabswid
.69035 .26208 m
.97619 .27915 L
s
% Start of user PostScript
19.9868 -1.80674 50. -0.0138124 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27915 Mdot
.039 .916 .04 r
.5 Mabswid
.6904 .26553 m
.97619 .27916 L
s
% Start of user PostScript
19.9916 -1.44479 50. -0.0134474 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27916 Mdot
.039 .916 .04 r
.5 Mabswid
.69043 .26897 m
.97619 .27918 L
s
% Start of user PostScript
19.9953 -1.08325 50. -0.0114764 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27918 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .27241 m
.97619 .27921 L
s
% Start of user PostScript
19.9979 -0.722001 50. -0.00831044 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27921 Mdot
.039 .916 .04 r
.5 Mabswid
.69047 .27585 m
.97619 .27924 L
s
% Start of user PostScript
19.9995 -0.360951 50. -0.00435253 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27924 Mdot
.039 .916 .04 r
.5 Mabswid
.69048 .27929 m
.97619 .27929 L
s
% Start of user PostScript
20. 0 50. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27929 Mdot
.039 .916 .04 r
.5 Mabswid
.69047 .28272 m
.97619 .27933 L
s
% Start of user PostScript
19.9995 0.360951 50. 0.00435253 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27933 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .28616 m
.97619 .27936 L
s
% Start of user PostScript
19.9979 0.722001 50. 0.00831044 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27936 Mdot
.039 .916 .04 r
.5 Mabswid
.69043 .2896 m
.97619 .2794 L
s
% Start of user PostScript
19.9953 1.08325 50. 0.0114764 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .2794 Mdot
.039 .916 .04 r
.5 Mabswid
.6904 .29305 m
.97619 .27941 L
s
% Start of user PostScript
19.9916 1.44479 50. 0.0134474 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27941 Mdot
.039 .916 .04 r
.5 Mabswid
.69035 .29649 m
.97619 .27942 L
s
% Start of user PostScript
19.9868 1.80674 50. 0.0138124 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27942 Mdot
.039 .916 .04 r
.5 Mabswid
.6903 .29994 m
.97619 .2794 L
s
% Start of user PostScript
19.981 2.16919 50. 0.0121485 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .2794 Mdot
.039 .916 .04 r
.5 Mabswid
.69023 .3034 m
.97619 .27936 L
s
% Start of user PostScript
19.9741 2.53225 50. 0.00801844 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27936 Mdot
.039 .916 .04 r
.5 Mabswid
.69015 .30687 m
.97619 .27929 L
s
% Start of user PostScript
19.9661 2.89603 50. 0.000966777 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27929 Mdot
.039 .916 .04 r
.5 Mabswid
.69007 .31034 m
.97619 .2792 L
s
% Start of user PostScript
19.957 3.26065 50. -0.00948384 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .2792 Mdot
.039 .916 .04 r
.5 Mabswid
.68997 .31382 m
.97619 .27906 L
s
% Start of user PostScript
19.9469 3.62623 50. -0.0238369 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .27906 Mdot
gsave
.59524 .10786 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .01262 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .53 L
0 .53 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[124]:=",
  ImageSize->{288, 152.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000V2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolDooooo`?o00002_oo
ool00?oooooo5?ooool01?l0003oooooooooool00009ooooo`00oooooolGooooo`03o`000?oooooo
oooo00Oooooo003ooooooaGooooo0_l0000:ooooo`00oooooolDooooo`03o`000?oooooooooo00[o
oooo003ooooooaCooooo00Co0000oooooooooooo00002Oooool00?oooooo5Oooool3o`0000Wooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooooaKooooo00?o0000oooooooo
ool02?ooool00?oooooo5_ooool00ol0003oooooooooo`08ooooo`00oooooolFooooo`03o`000?oo
oooooooo00Sooooo003ooooooaKooooo00?o0000ooooooooool02?ooool00?oooooo5_ooool00ol0
003oooooooooo`08ooooo`00oooooolFooooo`03o`000?oooooooooo00Sooooo003ooooooaKooooo
00?o0000ooooooooool02?ooool00?oooooo5_ooool00ol0003oooooooooo`08ooooo`00oooooolF
ooooo`03o`000?oooooooooo00Sooooo003ooooooaKooooo00?o0000ooooooooool02?ooool00?oo
oooo5_ooool00ol0003oooooooooo`08ooooo`00oooooolFooooo`03o`000?oooooooooo00Sooooo
003ooooooaKooooo00?o0000ooooooooool02?ooool00?oooooo5_ooool00ol0003oooooooooo`08
ooooo`00oooooolFooooo`03o`000?oooooooooo00Sooooo003ooooooaKooooo00?o0000oooooooo
ool02?ooool00?oooooo5_ooool00ol0003oooooooooo`08ooooo`00Yoooool6o`0006Sooooo00?o
0000ooooooooool02?ooool00:Sooooo00Go0000ooooooooooooooooo`00001Xooooo`03o`000?oo
oooooooo00Sooooo002Xooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool02?ooool0
0:Sooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`08ooooo`00Z?ooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo00Sooooo002Xooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool02?ooool00:Oooooo0ol0001[ooooo`03o`000?oooooooooo00Sooooo003o
oooooaKooooo00?o0000ooooooooool02?ooool00?oooooo5_ooool00ol0003oooooooooo`08oooo
o`00oooooolFooooo`03o`000?oooooooooo00Sooooo002MooooobKo0000D_ooool00ol0003ooooo
ooooo`08ooooo`00WOoooolVo`0005;ooooo00?o0000ooooooooool02?ooool009cooooo0_l0000T
ogmoO`03o`000?oooooooooo053ooooo00?o0000ooooooooool02?ooool009_ooooo00?o0000ogmo
Ool000009?moOgl00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Sooooo002Kooooo`03
o`000?moOgoo000002CoOgmo0_l0001Aooooo`03o`000?oooooooooo00Sooooo002Jooooo`03o`00
0?moOgooOgmo02Oo0000DOooool00ol0003oooooooooo`08ooooo`00V_ooool01?l0003oOgmoogmo
Ool0000TogmoO`;o0000DOooool00ol0003oooooooooo`08ooooo`00VOooool01Ol0003oOgmoogmo
OomoOgoo000002CoOgmo0_l0001Aooooo`03o`000?oooooooooo00Sooooo002Hooooo`03o`000?mo
OgooOgmo00;oOgmo00?o0000ogmoOomoOgl08_moOgl2o`00057ooooo00?o0000ooooooooool02?oo
ool009Sooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0RogmoO`;o0000DOooool0
0ol0003oooooooooo`08ooooo`00Uoooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo
02;oOgmo0_l0001Aooooo`03o`000?oooooooooo00Sooooo002Gooooo`03o`000?moOgooOgmo00?o
Ogmo9_l000000omoOgoo0000ooooo`1?ooooo`03o`000?oooooooooo00Sooooo002Fooooo`03o`00
0?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03o`00
0?oooooooooo00Sooooo002Eooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl08_mo
Ogl00ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00Sooooo002Eooooo`03o`000?moOgoo
Ogmo00GoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oooooo
oooo00Sooooo002Dooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0
003oOgmoo`00001@ooooo`03o`000?oooooooooo00Sooooo002Dooooo`03o`000?moOgooOgmo00Ko
Ogmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00So
oooo002Dooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmo
o`00001@ooooo`03o`000?oooooooooo00Sooooo002Cooooo`03o`000?moOgooOgmo00OoOgmo00?o
0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00Sooooo002C
ooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@
ooooo`03o`000?oooooooooo00Sooooo002Cooooo`03o`000?moOgooOgmo00OoOgmo9_l000000omo
Ogoo0000ooooo`1?ooooo`03o`000?oooooooooo00Sooooo002Booooo`03o`000?moOgooOgmo00So
Ogmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00So
oooo002Booooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmo
o`00001@ooooo`03o`000?oooooooooo00Sooooo002Booooo`03o`000?moOgooOgmo00SoOgmo00?o
0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00Sooooo002A
ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@
ooooo`03o`000?oooooooooo00Sooooo0028ooooo`?o2NX:1_ooool00ol0003oOgmoogmoO`09ogmo
O`03o`000?moOgooOgmo02;oOgmo00?o0000ogmoOol00000D?ooool00ol0003oooooooooo`08oooo
o`00R?ooool7o`WZ2P03ooooool0003o000000_oOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003o
Ogmoo`00001@ooooo`03o`000?oooooooooo00Sooooo0009oooooi7o2NX:0omoOgl00ol0003oOgmo
ogmoO`0RogmoO`03o`000?moOgoo0000053ooooo00?o0000ooooooooool02?ooool000WoooooX_l9
jPXBogmoO`?o2NX:0_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00Sooooo0009
ooooohKo2NX:00?o0000o`WZ2_l9jPX0:_l9jPX00omoOgoo2NX:o`WZ2P04o`WZ2P03ogmoOol0003o
oooo04oooooo00?o0000ooooooooool02?ooool008Sooooo1ol9jPX2o`0000WoOgmo;ol9jPY<oooo
o`03o`000?oooooooooo00Sooooo0009ooooohKo2NX:00?o0000o`WZ2_l9jPX03?l9jPX>ogmoObGo
2NX:A?ooool00ol0003oooooooooo`08ooooo`002Ooooon6o`WZ2P03o`000?l9jP[o2NX:02Oo2NX:
0omoOgl8o`WZ2P03o`000?l9jP[o2NX:01;o2NX:??ooool00ol0003oooooooooo`08ooooo`002Ooo
oonko`WZ2P03o`000?l9jP[o2NX:01[o2NX:=?ooool00ol0003oooooooooo`08ooooo`00Qoooool7
o`WZ2P03ooooool0003o000000coOgmo00?o0000o`WZ2_l9jPX09?l9jPX00ol0003o2NX:o`WZ2P0R
o`WZ2Rcooooo00?o0000ooooooooool02?ooool000WoooooX_l9jPX>ogmoO`_o2NX:00?o0000o`WZ
2_l9jPX0:ol9jPXSooooo`03o`000?oooooooooo00Sooooo0009oooook_o2NX:00?o0000o`WZ2_l9
jPX0<ol9jPXKooooo`03o`000?oooooooooo00Sooooo0009oooook_o2NX:00?o0000o`WZ2_l9jPX0
>ol9jPX;ooooo`;o2NX:1_ooool00ol0003oooooooooo`08ooooo`00Qoooool7o`WZ2P03ooooool0
003o000000coOgmo00?o0000ogmoOomoOgl02omoOglIo`WZ2P03o`000?l9jP[o2NX:04?o2NX:0ooo
ool5o`WZ2P?ooooo00?o0000ooooooooool02?ooool000Wooooo^ol9jPX00ol0003o2NX:o`WZ2P1>
o`WZ2P;o00002Oooool000Wooooo^ol9jPX00ol0003o2NX:o`WZ2P1>o`WZ2P;o00002Oooool000Wo
oooo^ol9jPX00ol0003o2NX:o`WZ2P1=o`WZ2P03ooooool0003ooooo00Wooooo0027ooooo`Oo2NX:
00?oooooo`000?l000003?moOgl00ol0003oOgmoogmoO`0:ogmoOa[o2NX:00?o0000o`WZ2_l9jPX0
@_l9jPX4ooooo`Co2NX:1?ooool00ol0003oooooooooo`08ooooo`002Ooooonko`WZ2P03o`000?l9
jP[o2NX:03[o2NX:3?ooool00ol9jP[oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009
oooook_o2NX:00?o0000o`WZ2_l9jPX0<_l9jPXLooooo`03o`000?oooooooooo00Sooooo0009oooo
oj7o2NX:3_moOgl<o`WZ2P03o`000?l9jP[o2NX:02[o2NX:9?ooool00ol0003oooooooooo`08oooo
o`00Qoooool7o`WZ2P03ooooool0003o000000coOgmo9ol9jPX00ol0003o2NX:o`WZ2P0Qo`WZ2Rgo
oooo00?o0000ooooooooool02?ooool000Wooooo^ol9jPX00ol0003o2NX:o`WZ2P0Io`WZ2SGooooo
00?o0000ooooooooool02?ooool000WoooooQ_l9jPX00ol0003o2NX:o`WZ2P0Vo`WZ2PCoOgmo2?l9
jPX00ol0003o2NX:o`WZ2P0Ao`WZ2Sgooooo00?o0000ooooooooool02?ooool000WoooooQ_l9jPX0
0ol0003o2NX:o`WZ2P0;o`WZ2P03o`000?moOgooOgmo00[oOgmo9_l9jPY5ooooo`03o`000?oooooo
oooo00Sooooo0028ooooo`Oo2NX:0_l00008ogmoOboo2NX:COooool00ol0003oooooooooo`08oooo
o`002Ooooon6o`WZ2P03o`000?l9jP[o2NX:02Wo2NX:0_moOgl5o`WZ2P03o`000?moOgoo0000053o
oooo00?o0000ooooooooool02?ooool000WoooooXOl9jPXCogmoO`;o2NX:0omoOgl00ol0003oOgmo
o`00001@ooooo`03o`000?oooooooooo00Sooooo0009oooooi3o2NX:1?moOgl00ol0003oOgmoogmo
O`0RogmoO`03o`000?moOgoo0000053ooooo00?o0000ooooooooool02?ooool008Sooooo1_l9jPX2
ooooo`;o00002omoOgl00ol0003oOgmoogmoO`0RogmoO`03o`000?moOgoo0000053ooooo00?o0000
ooooooooool02?ooool008Sooooo0_l9jPX7ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmo
OomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00Sooooo002Aooooo`03
o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03
o`000?oooooooooo00Sooooo002Aooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ogmoOomoOgl0
8_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00Sooooo002Booooo`03o`000?mo
OgooOgmo00SoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oo
oooooooo00Sooooo002Booooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl08_moOgl0
0ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00Sooooo002Booooo`03o`000?moOgooOgmo
00SoOgmo9_l000000omoOgoo0000ooooo`1?ooooo`03o`000?oooooooooo00Sooooo002Cooooo`03
o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03
o`000?oooooooooo00Sooooo002Cooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl0
8_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00Sooooo002Cooooo`03o`000?mo
OgooOgmo00OoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oo
oooooooo00Sooooo002Dooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl08_moOgl0
0ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00Sooooo002Dooooo`03o`000?moOgooOgmo
00KoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo
00Sooooo002Dooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003o
Ogmoo`00001@ooooo`03o`000?oooooooooo00Sooooo002Eooooo`03o`000?moOgooOgmo00GoOgmo
00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00Sooooo
002Eooooo`03o`000?moOgooOgmo00GoOgmo9_l000000omoOgoo0000ooooo`1?ooooo`03o`000?oo
oooooooo00Sooooo002Fooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl08_moOgl0
0ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo00Sooooo002Gooooo`03o`000?moOgooOgmo
00?oOgmo00?o0000ogmoOomoOgl08_moOgl00ol0003oOgmoo`00001@ooooo`03o`000?oooooooooo
00Sooooo002Gooooo`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl08_moOgl2o`00057o
oooo00?o0000ooooooooool02?ooool009Sooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmo
ogmoO`0RogmoO`;o0000DOooool00ol0003oooooooooo`08ooooo`00V?ooool00ol0003oOgmoogmo
O`02ogmoO`03o`000?moOgooOgmo02;oOgmo0_l0001Aooooo`03o`000?oooooooooo00Sooooo002I
ooooo`05o`000?moOgooOgmoogmoOol000009?moOgl2o`00057ooooo00?o0000ooooooooool02?oo
ool009[ooooo00?o0000ogmoOomoOgl09ol0001Aooooo`03o`000?oooooooooo00Sooooo002Joooo
o`04o`000?moOgooOgmoo`0002CoOgmo0_l0001Aooooo`03o`000?oooooooooo00Sooooo002Koooo
o`03o`000?moOgoo000002CoOgmo0_l0001Aooooo`03o`000?oooooooooo00Sooooo002Kooooo`03
o`000?moOgoo000002CoOgmo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`08ooooo`00
W?oooolWo`0005;ooooo00?o0000ooooooooool02?ooool009gooooo9_l0001Booooo`03o`000?oo
oooooooo00Sooooo003ooooooaKooooo00?o0000ooooooooool02?ooool00?oooooo5_ooool00ol0
003oooooooooo`08ooooo`00oooooolFooooo`03o`000?oooooooooo00Sooooo003ooooooaKooooo
00?o0000ooooooooool02?ooool00?oooooo5_ooool00ol0003oooooooooo`08ooooo`00oooooolF
ooooo`03o`000?oooooooooo00Sooooo003ooooooaKooooo00?o0000ooooooooool02?ooool00?oo
oooo5_ooool00ol0003oooooooooo`08ooooo`00oooooolFooooo`03o`000?oooooooooo00Sooooo
003ooooooaKooooo00?o0000ooooooooool02?ooool00?oooooo5_ooool00ol0003oooooooooo`08
ooooo`00oooooolFooooo`03o`000?oooooooooo00Sooooo003ooooooaKooooo00?o0000oooooooo
ool02?ooool00?oooooo5_ooool00ol0003oooooooooo`08ooooo`00oooooolFooooo`03o`000?oo
oooooooo00Sooooo003ooooooaKooooo00?o0000ooooooooool02?ooool00?oooooo5_ooool00ol0
003oooooooooo`08ooooo`00oooooolFooooo`03o`000?oooooooooo00Sooooo003ooooooaKooooo
00?o0000ooooooooool02?ooool00?oooooo5_ooool00ol0003oooooooooo`08ooooo`00oooooolF
ooooo`03o`000?oooooooooo00Sooooo003ooooooaKooooo00?o0000ooooooooool02?ooool00?oo
oooo5_ooool00ol0003oooooooooo`08ooooo`00oooooolFooooo`03o`000?oooooooooo00Sooooo
003ooooooaKooooo00?o0000ooooooooool02?ooool00?oooooo5_ooool00ol0003oooooooooo`08
ooooo`00oooooolFooooo`03o`000?oooooooooo00Sooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {151.625, 0}} -> {-53.5327, -30.2385, 0.37305, \
0.37305}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}]
}, Open  ]],

Cell["\<\
data = ReadRays[tracedsystem, {SurfaceCoordinates[[1]], IntersectionNumber}];\
\
\>", "Input",
  CellLabel->"In[125]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell[CellGroupData[{

Cell["indata = Select[data,(#[[2]]==1)&]", "Input",
  CellLabel->"In[126]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell[BoxData[
    \({{\(-5.`\), 1}, {\(-4.5`\), 1}, {\(-4.`\), 1}, {\(-3.5`\), 
        1}, {\(-3.`\), 1}, {\(-2.5`\), 1}, {\(-2.`\), 1}, {\(-1.5`\), 
        1}, {\(-1.`\), 1}, {\(-0.5`\), 1}, {0, 1}, {0.5`, 1}, {1.`, 
        1}, {1.5`, 1}, {2.`, 1}, {2.5`, 1}, {3.`, 1}, {3.5`, 1}, {4.`, 
        1}, {4.5`, 1}, {5.`, 1}}\)], "Output",
  CellLabel->"Out[126]=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
dataplot = \
ListPlot[Map[{#[[1,1]],#[[2,1]]}&,Transpose[{indata,Select[data,(#[[2]]==3)&]}\
]]];\
\>", "Input",
  CellLabel->"In[127]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 12.3465 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 .06209 -30 -4.5 ]
[.4875 .06209 0 4.5 ]
[.4875 .18555 -30 -4.5 ]
[.4875 .18555 0 4.5 ]
[.4875 .43248 -24 -4.5 ]
[.4875 .43248 0 4.5 ]
[.4875 .55595 -24 -4.5 ]
[.4875 .55595 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .06209 m
.50625 .06209 L
s
[(-0.02)] .4875 .06209 1 0 Mshowa
.5 .18555 m
.50625 .18555 L
s
[(-0.01)] .4875 .18555 1 0 Mshowa
.5 .43248 m
.50625 .43248 L
s
[(0.01)] .4875 .43248 1 0 Mshowa
.5 .55595 m
.50625 .55595 L
s
[(0.02)] .4875 .55595 1 0 Mshowa
.125 Mabswid
.5 .08678 m
.50375 .08678 L
s
.5 .11147 m
.50375 .11147 L
s
.5 .13617 m
.50375 .13617 L
s
.5 .16086 m
.50375 .16086 L
s
.5 .21025 m
.50375 .21025 L
s
.5 .23494 m
.50375 .23494 L
s
.5 .25963 m
.50375 .25963 L
s
.5 .28432 m
.50375 .28432 L
s
.5 .33371 m
.50375 .33371 L
s
.5 .3584 m
.50375 .3584 L
s
.5 .3831 m
.50375 .3831 L
s
.5 .40779 m
.50375 .40779 L
s
.5 .45717 m
.50375 .45717 L
s
.5 .48187 m
.50375 .48187 L
s
.5 .50656 m
.50375 .50656 L
s
.5 .53125 m
.50375 .53125 L
s
.5 .03739 m
.50375 .03739 L
s
.5 .0127 m
.50375 .0127 L
s
.5 .58064 m
.50375 .58064 L
s
.5 .60533 m
.50375 .60533 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .60332 Mdot
.07143 .42611 Mdot
.11905 .29708 Mdot
.16667 .21002 Mdot
.21429 .15903 Mdot
.2619 .13848 Mdot
.30952 .14299 Mdot
.35714 .16732 Mdot
.40476 .20641 Mdot
.45238 .25528 Mdot
.5 .30902 Mdot
.54762 .36276 Mdot
.59524 .41162 Mdot
.64286 .45071 Mdot
.69048 .47505 Mdot
.7381 .47955 Mdot
.78571 .45901 Mdot
.83333 .40802 Mdot
.88095 .32095 Mdot
.92857 .19192 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[127]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oSoooool0
0ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003o
ooooooooo`2>ooooo`00Soooool2o`0008Kooooo0_l00007ooooo`00Soooool00ol0003ooooooooo
o`25ooooo`;o00001oooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000oooo
ooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0
S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo0_l0002?ooooo`00Soooool00ol0
003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003ooooo
ooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00MOooool2o`0000Cooooo00?o0000
ooooooooool00oooool2o`0000;ooooo1Ol00005ooooo`03o`000?oooooooooo08kooooo001doooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo08kooooo001]ooooo`Go00000_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool3o`0008ko
oooo001dooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo08kooooo001dooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0S_ooool007Cooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2>ooooo`00
MOooool2o`0000[ooooo0_l00003ooooo`?o00001_ooool00ol0003oooooooooo`2>ooooo`00Sooo
ool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool2o`00
08oooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo
002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?oooo
o`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`;o0000
Soooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool0
08oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo
00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000
ooooooooool0S_ooool004[ooooo0_l00013ooooo`;o0000Soooool004[ooooo0_l0000<ooooo`;o
0000=Oooool00ol0003oooooooooo`2>ooooo`00F?ooool2o`0003Gooooo00?o0000ooooooooool0
S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool0
08oooooo00?o0000ooooooooool0S_ooool003gooooo0_l0001@ooooo`03o`000?oooooooooo08ko
oooo000mooooo`;o0000D?ooool2o`0008oooooo001Uooooo`;o0000:?ooool00ol0003ooooooooo
o`2>ooooo`00IOooool2o`0002Sooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000oooo
ooooool0S_ooool007Gooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o
00001_ooool00ol0003oooooooooo`2>ooooo`00M?ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2>oooo
o`00KOooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S_ooool007Cooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo0ol0
002>ooooo`00M?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1gooooo`;o00005Oooool007Cooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`;o00001oooool00ol0003o
ooooooooo`1gooooo`;o00005Oooool007Gooooo0_l0000:ooooo`;o00001?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo001c
ooooo`;o00006_ooool00ol0003oooooooooo`2>ooooo`00;oooool2o`0004;ooooo0_l0000Joooo
o`03o`000?oooooooooo08kooooo000_ooooo`;o0000G_ooool2o`0008oooooo002?ooooo`03o`00
0?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooo
oooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08ko
oooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`;o0000Soooool008oooooo00?o0000
ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000oooooooo
ool0S_ooool008oooooo00?o0000ooooooooool0S_ooool0087ooooo0_l0000<ooooo`03o`000?oo
oooooooo08kooooo0021ooooo`;o00003?ooool00ol0003oooooooooo`2>ooooo`00Soooool2o`00
08oooooo002?ooooo`03o`000?oooooooooo08kooooo000Tooooo`?o0000<Oooool5o`0003;ooooo
00?o0000ooooooooool0<Oooool5o`0003?ooooo0ol0000Rooooo`009Oooool00ol0003ooooooooo
o`0aooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0<_ooool01?l0003ooooo
ooooool0000dooooo`03o`000?oooooooooo027ooooo000Looooo`Go000000?oooooo`000?l00000
0ol0000[ooooo`Go00000oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0<Oooool5o`0002;ooooo000Rooooo`04o`000?ooooooooooo`0003Gooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo033ooooo
00Co0000oooooooooooo00008oooool002?ooooo00?o0000ooooool00000<_ooool01Ol0003ooooo
oooooooooooo000003;ooooo00?o0000ooooooooool0<Oooool01Ol0003ooooooooooooooooo0000
03;ooooo00?o0000ooooool000008oooool002Cooooo0_l0000booooo`05o`000?oooooooooooooo
ool00000<_ooool2o`0003;ooooo00Go0000ooooooooooooooooo`00000cooooo`;o00008oooool0
02Gooooo00?o0000ooooooooool0<Oooool3o`0003?ooooo00?o0000ooooooooool0<_ooool3o`00
03Gooooo00?o0000ooooooooool08Oooool008oooooo00?o0000ooooooooool0S_ooool0027ooooo
0_l0001/ooooo`03o`000?oooooooooo08kooooo000Qooooo`;o0000K?ooool00ol0003ooooooooo
o`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>oooo
o`00ool0000Po`00007ooooo0007ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Kooooo000Rooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08Ooo
ool008oooooo00?o0000ooooooooool0JOooool2o`0002?ooooo002?ooooo`03o`000?oooooooooo
06Wooooo0_l0000Sooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003ooooo
ooooo`2>ooooo`00Soooool2o`0008oooooo002?ooooo`03o`000?oooooooooo08kooooo002?oooo
o`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`00
0?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooo
oooo08kooooo002?ooooo`;o0000Soooool008oooooo00?o0000ooooooooool02_ooool2o`0008;o
oooo002?ooooo`03o`000?oooooooooo00[ooooo0_l00022ooooo`00Soooool00ol0003ooooooooo
o`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>oooo
o`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool2o`0008oooooo002?ooooo`03o`000?oo
oooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo
08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo
002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`;o0000GOooool2o`00033ooooo002?oooo
o`03o`000?oooooooooo01Sooooo0_l00012ooooo`;o0000<?ooool008oooooo00?o0000oooooooo
ool06?ooool2o`0007Cooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oo
oooooooo08kooooo000Dooooo`;o0000Goooool2o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000?ooooo0ol00006ooooo`03o`000?oooooooooo08kooooo000Dooooo`;o0000G_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2>ooooo`00M?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool3o`0008kooooo001dooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo08kooooo001dooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08kooooo001dooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Oooooo00?o0000
ooooooooool0S_ooool007Gooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo02Gooooo0_l0001Wooooo`00
Soooool00ol0003oooooooooo`0Uooooo`;o0000Ioooool008oooooo0_l0002?ooooo`00Soooool0
0ol0003oooooooooo`1>ooooo`;o0000?_ooool008oooooo00?o0000ooooooooool0C_ooool2o`00
03kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo
002?ooooo`03o`000?oooooooooo03?ooooo0_l0001Iooooo`00Soooool00ol0003oooooooooo`0c
ooooo`;o00003?ooool2o`0004_ooooo002?ooooo`03o`000?oooooooooo047ooooo0_l0001;oooo
o`00Soooool2o`0008oooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oo
oooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo
08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo
002?ooooo`;o0000Soooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000oooo
ooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0
S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool0
08oooooo0_l0002?ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003ooooo
ooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00MOooool2o`0000Cooooo00?o0000
ooooooooool00oooool2o`0000;ooooo1Ol00005ooooo`03o`000?oooooooooo08kooooo001doooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo08kooooo001dooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08ko
oooo001dooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`?o0000S_ooool007Cooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2>ooooo`00M?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08kooooo001eooooo`;o0000
2_ooool2o`0000?ooooo0ol00006ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oo
oooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo
08kooooo002?ooooo`;o0000Soooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o
0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000oooo
ooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool000Kooooo0_l00027ooooo`03o`00
0?oooooooooo08kooooo0006ooooo`;o0000Qoooool2o`0008oooooo002?ooooo`03o`000?oooooo
oooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08ko
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.26302, -0.025029, \
0.0366761, 0.000282911}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.3", "AOG2."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preliminary Characterization", "Subsubsection",
  CellTags->{"AOG0.", "2.3.2", "AOG2.", "AOG2.3", "AOG2.3.2"}],

Cell[CellGroupData[{

Cell["FindFocus[opticalsystem]", "Input",
  CellLabel->"In[128]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00551 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.49474 13.6658 0.502754 13.6658 [
[.08476 -0.0125 -15 -9 ]
[.08476 -0.0125 15 0 ]
[.22142 -0.0125 -15 -9 ]
[.22142 -0.0125 15 0 ]
[.35808 -0.0125 -15 -9 ]
[.35808 -0.0125 15 0 ]
[.49474 -0.0125 -3 -9 ]
[.49474 -0.0125 3 0 ]
[.6314 -0.0125 -12 -9 ]
[.6314 -0.0125 12 0 ]
[.76806 -0.0125 -12 -9 ]
[.76806 -0.0125 12 0 ]
[.90471 -0.0125 -12 -9 ]
[.90471 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09278 -30 -4.5 ]
[-0.0125 .09278 0 4.5 ]
[-0.0125 .22944 -30 -4.5 ]
[-0.0125 .22944 0 4.5 ]
[-0.0125 .3661 -30 -4.5 ]
[-0.0125 .3661 0 4.5 ]
[-0.0125 .50275 -6 -4.5 ]
[-0.0125 .50275 0 4.5 ]
[-0.0125 .63941 -24 -4.5 ]
[-0.0125 .63941 0 4.5 ]
[-0.0125 .77607 -24 -4.5 ]
[-0.0125 .77607 0 4.5 ]
[-0.0125 .91273 -24 -4.5 ]
[-0.0125 .91273 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1.00551 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1.00551 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08476 0 m
.08476 .00625 L
s
[(-0.03)] .08476 -0.0125 0 1 Mshowa
.22142 0 m
.22142 .00625 L
s
[(-0.02)] .22142 -0.0125 0 1 Mshowa
.35808 0 m
.35808 .00625 L
s
[(-0.01)] .35808 -0.0125 0 1 Mshowa
.49474 0 m
.49474 .00625 L
s
[(0)] .49474 -0.0125 0 1 Mshowa
.6314 0 m
.6314 .00625 L
s
[(0.01)] .6314 -0.0125 0 1 Mshowa
.76806 0 m
.76806 .00625 L
s
[(0.02)] .76806 -0.0125 0 1 Mshowa
.90471 0 m
.90471 .00625 L
s
[(0.03)] .90471 -0.0125 0 1 Mshowa
.125 Mabswid
.1121 0 m
.1121 .00375 L
s
.13943 0 m
.13943 .00375 L
s
.16676 0 m
.16676 .00375 L
s
.19409 0 m
.19409 .00375 L
s
.24875 0 m
.24875 .00375 L
s
.27609 0 m
.27609 .00375 L
s
.30342 0 m
.30342 .00375 L
s
.33075 0 m
.33075 .00375 L
s
.38541 0 m
.38541 .00375 L
s
.41274 0 m
.41274 .00375 L
s
.44008 0 m
.44008 .00375 L
s
.46741 0 m
.46741 .00375 L
s
.52207 0 m
.52207 .00375 L
s
.5494 0 m
.5494 .00375 L
s
.57673 0 m
.57673 .00375 L
s
.60407 0 m
.60407 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.68606 0 m
.68606 .00375 L
s
.71339 0 m
.71339 .00375 L
s
.74072 0 m
.74072 .00375 L
s
.79539 0 m
.79539 .00375 L
s
.82272 0 m
.82272 .00375 L
s
.85005 0 m
.85005 .00375 L
s
.87738 0 m
.87738 .00375 L
s
.05743 0 m
.05743 .00375 L
s
.0301 0 m
.0301 .00375 L
s
.00277 0 m
.00277 .00375 L
s
.93205 0 m
.93205 .00375 L
s
.95938 0 m
.95938 .00375 L
s
.98671 0 m
.98671 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09278 m
.00625 .09278 L
s
[(-0.03)] -0.0125 .09278 1 0 Mshowa
0 .22944 m
.00625 .22944 L
s
[(-0.02)] -0.0125 .22944 1 0 Mshowa
0 .3661 m
.00625 .3661 L
s
[(-0.01)] -0.0125 .3661 1 0 Mshowa
0 .50275 m
.00625 .50275 L
s
[(0)] -0.0125 .50275 1 0 Mshowa
0 .63941 m
.00625 .63941 L
s
[(0.01)] -0.0125 .63941 1 0 Mshowa
0 .77607 m
.00625 .77607 L
s
[(0.02)] -0.0125 .77607 1 0 Mshowa
0 .91273 m
.00625 .91273 L
s
[(0.03)] -0.0125 .91273 1 0 Mshowa
.125 Mabswid
0 .12011 m
.00375 .12011 L
s
0 .14744 m
.00375 .14744 L
s
0 .17477 m
.00375 .17477 L
s
0 .20211 m
.00375 .20211 L
s
0 .25677 m
.00375 .25677 L
s
0 .2841 m
.00375 .2841 L
s
0 .31143 m
.00375 .31143 L
s
0 .33876 m
.00375 .33876 L
s
0 .39343 m
.00375 .39343 L
s
0 .42076 m
.00375 .42076 L
s
0 .44809 m
.00375 .44809 L
s
0 .47542 m
.00375 .47542 L
s
0 .53009 m
.00375 .53009 L
s
0 .55742 m
.00375 .55742 L
s
0 .58475 m
.00375 .58475 L
s
0 .61208 m
.00375 .61208 L
s
0 .66674 m
.00375 .66674 L
s
0 .69408 m
.00375 .69408 L
s
0 .72141 m
.00375 .72141 L
s
0 .74874 m
.00375 .74874 L
s
0 .8034 m
.00375 .8034 L
s
0 .83073 m
.00375 .83073 L
s
0 .85807 m
.00375 .85807 L
s
0 .8854 m
.00375 .8854 L
s
0 .06545 m
.00375 .06545 L
s
0 .03812 m
.00375 .03812 L
s
0 .01078 m
.00375 .01078 L
s
0 .94006 m
.00375 .94006 L
s
0 .96739 m
.00375 .96739 L
s
0 .99472 m
.00375 .99472 L
s
.25 Mabswid
0 0 m
0 1.00551 L
s
.08476 .99926 m
.08476 1.00551 L
s
.22142 .99926 m
.22142 1.00551 L
s
.35808 .99926 m
.35808 1.00551 L
s
.49474 .99926 m
.49474 1.00551 L
s
.6314 .99926 m
.6314 1.00551 L
s
.76806 .99926 m
.76806 1.00551 L
s
.90471 .99926 m
.90471 1.00551 L
s
.125 Mabswid
.1121 1.00176 m
.1121 1.00551 L
s
.13943 1.00176 m
.13943 1.00551 L
s
.16676 1.00176 m
.16676 1.00551 L
s
.19409 1.00176 m
.19409 1.00551 L
s
.24875 1.00176 m
.24875 1.00551 L
s
.27609 1.00176 m
.27609 1.00551 L
s
.30342 1.00176 m
.30342 1.00551 L
s
.33075 1.00176 m
.33075 1.00551 L
s
.38541 1.00176 m
.38541 1.00551 L
s
.41274 1.00176 m
.41274 1.00551 L
s
.44008 1.00176 m
.44008 1.00551 L
s
.46741 1.00176 m
.46741 1.00551 L
s
.52207 1.00176 m
.52207 1.00551 L
s
.5494 1.00176 m
.5494 1.00551 L
s
.57673 1.00176 m
.57673 1.00551 L
s
.60407 1.00176 m
.60407 1.00551 L
s
.65873 1.00176 m
.65873 1.00551 L
s
.68606 1.00176 m
.68606 1.00551 L
s
.71339 1.00176 m
.71339 1.00551 L
s
.74072 1.00176 m
.74072 1.00551 L
s
.79539 1.00176 m
.79539 1.00551 L
s
.82272 1.00176 m
.82272 1.00551 L
s
.85005 1.00176 m
.85005 1.00551 L
s
.87738 1.00176 m
.87738 1.00551 L
s
.05743 1.00176 m
.05743 1.00551 L
s
.0301 1.00176 m
.0301 1.00551 L
s
.00277 1.00176 m
.00277 1.00551 L
s
.93205 1.00176 m
.93205 1.00551 L
s
.95938 1.00176 m
.95938 1.00551 L
s
.98671 1.00176 m
.98671 1.00551 L
s
.25 Mabswid
0 1.00551 m
1 1.00551 L
s
.99375 .09278 m
1 .09278 L
s
.99375 .22944 m
1 .22944 L
s
.99375 .3661 m
1 .3661 L
s
.99375 .50275 m
1 .50275 L
s
.99375 .63941 m
1 .63941 L
s
.99375 .77607 m
1 .77607 L
s
.99375 .91273 m
1 .91273 L
s
.125 Mabswid
.99625 .12011 m
1 .12011 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .17477 m
1 .17477 L
s
.99625 .20211 m
1 .20211 L
s
.99625 .25677 m
1 .25677 L
s
.99625 .2841 m
1 .2841 L
s
.99625 .31143 m
1 .31143 L
s
.99625 .33876 m
1 .33876 L
s
.99625 .39343 m
1 .39343 L
s
.99625 .42076 m
1 .42076 L
s
.99625 .44809 m
1 .44809 L
s
.99625 .47542 m
1 .47542 L
s
.99625 .53009 m
1 .53009 L
s
.99625 .55742 m
1 .55742 L
s
.99625 .58475 m
1 .58475 L
s
.99625 .61208 m
1 .61208 L
s
.99625 .66674 m
1 .66674 L
s
.99625 .69408 m
1 .69408 L
s
.99625 .72141 m
1 .72141 L
s
.99625 .74874 m
1 .74874 L
s
.99625 .8034 m
1 .8034 L
s
.99625 .83073 m
1 .83073 L
s
.99625 .85807 m
1 .85807 L
s
.99625 .8854 m
1 .8854 L
s
.99625 .06545 m
1 .06545 L
s
.99625 .03812 m
1 .03812 L
s
.99625 .01078 m
1 .01078 L
s
.99625 .94006 m
1 .94006 L
s
.99625 .96739 m
1 .96739 L
s
.99625 .99472 m
1 .99472 L
s
.25 Mabswid
1 0 m
1 1.00551 L
s
.039 .916 .04 r
2.5 Mabswid
.81571 .50275 Mdot
.62006 .50275 Mdot
.47773 .50275 Mdot
.38185 .50275 Mdot
.32589 .50275 Mdot
.30363 .50275 Mdot
.30909 .50275 Mdot
.3365 .50275 Mdot
.38023 .50275 Mdot
.43479 .50275 Mdot
.49474 .50275 Mdot
.55469 .50275 Mdot
.60925 .50275 Mdot
.65298 .50275 Mdot
.68039 .50275 Mdot
.68585 .50275 Mdot
.66359 .50275 Mdot
.60763 .50275 Mdot
.51175 .50275 Mdot
.36942 .50275 Mdot
.17377 .50275 Mdot
0 0 0 r
.0002 w
.97619 .50275 m
.93457 .69858 L
.81689 .86054 L
.64352 .96064 L
.44441 .98157 L
.25401 .9197 L
.10524 .78574 L
.02381 .60285 L
.02381 .40265 L
.10524 .21976 L
.25401 .08581 L
.44441 .02394 L
.64352 .04487 L
.81689 .14497 L
.93457 .30693 L
.97619 .50275 L
s
0 0 m
1 0 L
1 1.00551 L
0 1.00551 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[128]:=",
  ImageSize->{288, 289.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00018B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00;oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?o
oooo0ol0000?ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000ko
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00005?ooool2o`0001So
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00003oooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol0000=ooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00000oooool3o`00013ooooo000^ooooo`04o`000?ooooooooooo`0000So
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00_ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000go
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo01;ooooo00Co0000oooooooooooo00005_ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00003?ooool01?l0003ooooooooo
ool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0=oooo
o`009oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo00Cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`06ooooo`Go00000_ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool04_ooool01?l0
003oooooooooool0000Fooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`0=ooooo`00;_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000>ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Booooo`04o`000?oo
ooooooooo`0001Kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00003ooooo`;o00004?ooool002kooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool02oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool04_ooool01?l0
003oooooooooool0000Fooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00gooooo000^ooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
00_ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool02oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo0_l0000Dooooo`04o`000?ooooooooooo`0001Kooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00002ooooo`;o00003oooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0:ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00go
oooo000_ooooo`;o00002_ooool2o`0000?ooooo0ol0000?ooooo`;o00002_ooool2o`0000?ooooo
0ol0000?ooooo`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool04oooool2o`0001Sooooo
0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`0>ooooo`;o00002_ooool2o`0000?ooooo
0ol0000>ooooo`;o00002_ooool2o`0000?ooooo0ol0000@ooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008Oooooono`00007ooooo000Qooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`00007ooooo000Qooooo`;o0000n_ooool2o`00007ooooo000Qooooo`03o`000?oooooo
oooo0?[ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`3jooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo06cooooo
1ol00027ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0JOooool3o`0000Oooooo2_l0
001mooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0I_ooool3o`0001Cooooo2ol0001b
ooooo`7o00000Oooool0027ooooo0_l0001Tooooo`?o00008_ooool:o`0006Oooooo0_l00001oooo
o`008Oooool00ol0003oooooooooo`1Pooooo`?o0000;oooool:o`0005kooooo0Ol00001ooooo`00
8Oooool00ol0003oooooooooo`1Mooooo`?o0000??ooool6o`0005Sooooo0Ol00001ooooo`008Ooo
ool00ol0003oooooooooo`1Jooooo`?o0000AOooool2o`0005Kooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`1Gooooo`?o0000B_ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool0E?ooool3o`0004kooooo0_l0001Cooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool0DOooool3o`0005?ooooo0_l0001Aooooo`7o00000Oooool0027ooooo
0_l0001?ooooo`?o0000F?ooool00ol0003oooooooooo`1=ooooo`;o00000Oooool0027ooooo00?o
0000ooooooooool0Boooool3o`0005cooooo0_l0001>ooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool0B?ooool3o`00067ooooo0_l0001<ooooo`7o00000Oooool0027ooooo00?o0000oooo
ooooool0AOooool3o`0006Kooooo00?o0000ooooooooool0BOooool1o`00007ooooo000Qooooo`03
o`000?oooooooooo04;ooooo0ol0001Zooooo`;o0000BOooool1o`00007ooooo0008ooooo`;o0000
1?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0
?oooool3o`0006oooooo0_l00017ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0looooo`?o0000M?ooool00ol0003oooooooooo`14ooooo`7o00000Oooool000Go
00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool00_ooool2o`0003cooooo00?o0000ooooooooool0M_ooool2o`0004?ooooo0_l00001
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0
0005ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0NOooool2o`0004;ooooo0Ol0
0001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo07cooooo
0_l00010ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0?Oooool1o`00007ooooo0008ooooo`;o
00002_ooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0POooool2o`0003gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo08Cooooo0_l0000kooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo03Sooooo0Ol00001ooooo`008Oooool2
o`0003Cooooo0_l0002;ooooo`;o0000=oooool2o`00007ooooo000Qooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0SOooool2o`0003Kooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0<oooool1o`00007o
oooo000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0T_ooool2o`0003?ooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09Gooooo0_l0
000aooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2H
ooooo`03o`000?oooooooooo02kooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo09[ooooo0_l0000^ooooo`7o00000Oooool0027ooooo0_l0000]ooooo`03
o`000?oooooooooo09gooooo00?o0000ooooooooool0:_ooool2o`00007ooooo000Qooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0[ooooo`7o0000
0Oooool0027ooooo00?o0000ooooooooool0:Oooool2o`000:;ooooo00?o0000ooooooooool0:_oo
ool1o`00007ooooo000Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Xoooool0
0ol0003oooooooooo`0Yooooo`7o00000Oooool0027ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`2Uooooo`03o`000?oooooooooo02Sooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0:?ooool1o`00007o
oooo000Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Z?ooool00ol0003ooooo
ooooo`0Wooooo`7o00000Oooool0027ooooo0_l0000Uooooo`03o`000?oooooooooo0:[ooooo00?o
0000ooooooooool09Oooool2o`00007ooooo000Qooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0Zoooool00ol0003oooooooooo`0Vooooo`7o00000Oooool0027ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02Gooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`0Pooooo`;o0000/Oooool00ol0003oooooooooo`0Tooooo`7o
00000Oooool0027ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo02?ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo0;?ooooo00?o0000ooooooooool08oooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`0Rooooo`7o00000Oooool0
027ooooo0_l0000Mooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooooooool08?ooool2o`00
007ooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0^Oooool00ol0003o
ooooooooo`0Pooooo`7o00000Oooool0027ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo023ooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool07oooool1o`00007ooooo0008
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000Cooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo01kooooo0Ol00001
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<3ooooo
00?o0000ooooooooool07Oooool1o`00007ooooo0005o`0000;ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo01gooooo0Ol00001ooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool00oooool2o`0001Oooooo00?o0000ooooooooool0`_ooool00ol0003oooooooooo`0Koooo
o`;o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo0<?ooooo00?o0000ooooooooool06oooool1o`00007ooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo01_o
oooo0Ol00001ooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool06_ooool1o`00007ooooo
000Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0a_ooool00ol0003ooooooooo
o`0Iooooo`7o00000Oooool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`38
ooooo`03o`000?oooooooooo01Sooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool06?ooool1o`00007ooooo000Qooooo`;o
00005?ooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo01Kooooo0_l00001ooooo`00
8Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0
5_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0cOoo
ool00ol0003oooooooooo`0Eooooo`7o00000Oooool0027ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`3=ooooo`03o`000?oooooooooo01Gooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo0<kooooo00?o0000ooooooooool05?ooool1o`00
007ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0d?ooool00ol0003o
ooooooooo`0Cooooo`7o00000Oooool0027ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`3Aooooo`03o`000?oooooooooo01;ooooo0Ol00001ooooo`008Oooool2o`00017ooooo00?o
0000ooooooooool0d_ooool00ol0003oooooooooo`0Aooooo`;o00000Oooool0027ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`3Cooooo`03o`000?oooooooooo017ooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0=Gooooo00?o0000oooo
ooooool04?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0eOooool00ol0003oooooooooo`0@ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`3Fooooo`03o`000?oooooooooo00oooooo0Ol00001ooooo`008Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0=Sooooo00?o0000ooooooooool03_oo
ool1o`00007ooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0fOooool0
0ol0003oooooooooo`0=ooooo`7o00000Oooool0027ooooo0_l0000>ooooo`03o`000?oooooooooo
0=[ooooo00?o0000ooooooooool03?ooool2o`00007ooooo000Qooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0f_ooool00ol0003oooooooooo`0=ooooo`7o00000Oooool0027ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`3Looooo`03o`000?oooooooooo00cooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0=cooooo00?o
0000ooooooooool03?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0gOooool00ol0003oooooooooo`0<ooooo`7o00000Oooool0027ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`3Mooooo`03o`000?oooooooooo00cooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=gooooo00?o0000oooooooo
ool03?ooool1o`00007ooooo000Qooooo`;o00002oooool00ol0003oooooooooo`3Oooooo`03o`00
0?oooooooooo00[ooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo0=oooooo00?o0000ooooooooool02oooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0h?ooool00ol0003oooooooooo`0;ooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3Pooooo`03o`000?oooooooooo
00_ooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?o
oooo0ol00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0hOooool00ol0003o
ooooooooo`0;ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`3Rooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`001Ol00002ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0h_ooool00ol0003oooooooooo`0:
ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`000?oooooooooo0>?ooooo00?o
0000ooooooooool02Oooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0hoooool00ol0003oooooooooo`0:ooooo`7o00000Oooool000Oooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`;o00001_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0>Cooooo00?o0000ooooooooool02_ooool1o`00007o
oooo0008ooooo`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0>Gooooo00?o0000ooooooooool02Oooool1o`00007ooooo
000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i_ooool00ol0003ooooooooo
o`09ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3V
ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0>Kooooo00?o0000ooooooooool02Oooool1o`00007ooooo000Qooooo`;o
00001Oooool00ol0003oooooooooo`3Wooooo`03o`000?oooooooooo00Sooooo0_l00001ooooo`00
8Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>Sooooo00?o0000ooooooooool0
2?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0jOoo
ool00ol0003oooooooooo`08ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3Yooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0>Wooooo00?o0000ooooooooool02?ooool1o`00
007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0jOooool00ol0003o
ooooooooo`08ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3Zooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`008Oooool2o`0000Cooooo00?o
0000ooooooooool0j_ooool00ol0003oooooooooo`06ooooo`;o00000Oooool0027ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`3Zooooo`03o`000?oooooooooo00Oooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>[ooooo00?o0000oooo
ooooool01oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0j_ooool00ol0003oooooooooo`07ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3[ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>_ooooo00?o0000ooooooooool01_oo
ool1o`00007ooooo000Qooooo`;o00001?ooool00ol0003oooooooooo`3[ooooo`03o`000?oooooo
oooo00Gooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0>_ooooo00?o0000ooooooooool01_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0joooool00ol0003oooooooooo`06ooooo`7o00000Oooool0027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo00Gooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>cooooo00?o
0000ooooooooool01Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0k?ooool00ol0003oooooooooo`05ooooo`7o00000Oooool0027ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo00Gooooo0Ol00001oooo
o`008Oooool2o`0000Cooooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`04ooooo`;o
00000Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3]ooooo`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0>gooooo00?o0000ooooooooool01?ooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`04ooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo
00Cooooo0Ol00001ooooo`006_ooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3]ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`006Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_ooool00ol0003o
ooooooooo`03ooooo`7o00000Oooool001Wooooo00Co0000oooooooooooo00001?ooool2o`0000Co
oooo00?o0000ooooooooool08_ooool2o`WZ2Qoooooo0ol9jPX3ooooo`Co2NX:1oooool5o`WZ2P_o
oooo0_l9jPX9ooooo`;o2NX:0_ooool2o`WZ2P?ooooo0_l9jPX9ooooo`;o2NX:2oooool2o`WZ2P03
ooooool9jP[o2NX:00Oooooo1?l9jPX3ooooo`?o2NX:7oooool2o`WZ2ROooooo00?o0000oooooooo
ool00_ooool2o`00007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Rooooo`;o2NX:7oooool3o`WZ2P?ooooo1?l9jPX7ooooo`Go
2NX:2oooool2o`WZ2PWooooo0_l9jPX2ooooo`;o2NX:0oooool2o`WZ2PWooooo0_l9jPX;ooooo`;o
2NX:00?oooooo`WZ2_l9jPX01oooool4o`WZ2P?ooooo0ol9jPXOooooo`;o2NX:9oooool00ol0003o
ooooooooo`03ooooo`7o00000Oooool001Wooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool00oooool1o`00007o
oooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3]ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Cooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>gooooo00?o
0000ooooooooool01?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0kOooool00ol0003oooooooooo`04ooooo`7o00000Oooool0027ooooo0_l00004oooo
o`03o`000?oooooooooo0>gooooo00?o0000ooooooooool00oooool2o`00007ooooo000Qooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`05ooooo`7o
00000Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3/ooooo`03o`00
0?oooooooooo00Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0>cooooo00?o0000ooooooooool01Oooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`05ooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo
00Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>_o
oooo00?o0000ooooooooool01_ooool1o`00007ooooo000Qooooo`;o00001?ooool00ol0003ooooo
ooooo`3[ooooo`03o`000?oooooooooo00Gooooo0_l00001ooooo`008Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0>_ooooo00?o0000ooooooooool01_ooool1o`00007ooooo000Q
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0joooool00ol0003oooooooooo`06
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3[oooo
o`03o`000?oooooooooo00Kooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0>[ooooo00?o0000ooooooooool01oooool1o`00007ooooo000Qooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0j_ooool00ol0003oooooooooo`07ooooo`7o0000
0Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Zooooo`03o`000?oo
oooooooo00Oooooo0Ol00001ooooo`008Oooool2o`0000Cooooo00?o0000ooooooooool0j_ooool0
0ol0003oooooooooo`06ooooo`;o00000Oooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3Zooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0>Wooooo00?o0000ooooooooool02?ooool1o`00007o
oooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0jOooool00ol0003ooooo
ooooo`08ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3Yooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0>Wooooo00?o0000ooooooooool02?ooool1o`00007ooooo000Qoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0jOooool00ol0003oooooooooo`08oooo
o`7o00000Oooool0027ooooo0_l00005ooooo`03o`000?oooooooooo0>Oooooo00?o0000oooooooo
ool02?ooool2o`00007ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
ioooool00ol0003oooooooooo`09ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3Vooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>Kooooo00?o0000ooooooooool02Oooool1
o`00007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`00
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Vooooo`03o`000?oooooooooo
00Wooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0>Cooooo00?o0000ooooooooool02_ooool1o`00007ooooo0007ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0i?ooool00ol0003oooooooooo`0:ooooo`7o00000Ooo
ool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Cooooo0_l00008ooooo`03o`000?oooooooooo0>?ooooo00?o0000ooooooooool0
2Oooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0hoooool00ol0003oooooooooo`0:ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00002ooooo`;o00001_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0>;ooooo00?o0000ooooooooool02_ooool1o`00007ooooo0008ooooo`;o
00002_ooool2o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo0>7ooooo00?o0000ooooooooool02oooool1o`00007ooooo000Qooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0hOooool00ol0003oooooooooo`0;ooooo`7o0000
0Oooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3Pooooo`03o`000?oo
oooooooo00_ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo0>3ooooo00?o0000ooooooooool02oooool1o`00007ooooo000Qooooo`;o00002oooool00ol0
003oooooooooo`3Oooooo`03o`000?oooooooooo00[ooooo0_l00001ooooo`008Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0=kooooo00?o0000ooooooooool03?ooool1o`00007o
oooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0gOooool00ol0003ooooo
ooooo`0<ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`3Mooooo`03o`000?oooooooooo00cooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo0=gooooo00?o0000ooooooooool03?ooool1o`00007ooooo000Qoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0g?ooool00ol0003oooooooooo`0<oooo
o`7o00000Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3Kooooo`03
o`000?oooooooooo00gooooo0Ol00001ooooo`008Oooool2o`0000kooooo00?o0000ooooooooool0
f_ooool00ol0003oooooooooo`0<ooooo`;o00000Oooool0027ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`3Jooooo`03o`000?oooooooooo00gooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0=Wooooo00?o0000ooooooooool03Oooool1
o`00007ooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0f?ooool00ol0
003oooooooooo`0>ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`3Fooooo`03o`000?oooooooooo00oooooo0Ol00001ooooo`008Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0=Gooooo00?o0000ooooooooool04?ooool1o`00007ooooo
000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0eOooool00ol0003ooooooooo
o`0@ooooo`7o00000Oooool0027ooooo0_l0000Aooooo`03o`000?oooooooooo0=?ooooo00?o0000
ooooooooool04?ooool2o`00007ooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0d_ooool00ol0003oooooooooo`0Booooo`7o00000Oooool0027ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`3Aooooo`03o`000?oooooooooo01;ooooo0Ol00001ooooo`00
8Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0=3ooooo00?o0000ooooooooool0
4oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0c_oo
ool00ol0003oooooooooo`0Dooooo`7o00000Oooool0027ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`3=ooooo`03o`000?oooooooooo01Gooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo0<gooooo00?o0000ooooooooool05Oooool1o`00
007ooooo000Qooooo`;o00005?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01Go
oooo0_l00001ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<[ooooo
00?o0000ooooooooool05oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0b?ooool00ol0003oooooooooo`0Hooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo01Sooooo0Ol00001
ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00004oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`0Ioooo
o`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`35ooooo`03o`000?oooooooooo01[ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0<Cooooo00?o0000ooooooooool06oooool1o`00007ooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`03ooooo`;o00005oooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo01[o
oooo0_l00001ooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0`_ooool00ol0003oooooooooo`0Looooo`7o00000Oooool000Oooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Gooooo`;o0000`Oooool00ol0003oooooooooo`0Mooooo`7o0000
0Oooool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo01gooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool07_ooool1
o`00007ooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`0Oooooo`7o00000Oooool0027ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`2hooooo`03o`000?oooooooooo023ooooo0Ol00001ooooo`008Oooool2o`0001kooooo
00?o0000ooooooooool0]oooool00ol0003oooooooooo`0Oooooo`;o00000Oooool0027ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo027ooooo0Ol0
0001ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;?ooooo00?o0000
ooooooooool08_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo023ooooo0_l0002boooo
o`03o`000?oooooooooo02?ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo0:oooooo00?o0000ooooooooool08oooool1o`00007ooooo000Qooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`0Tooooo`7o0000
0Oooool0027ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2[ooooo`03o`000?oo
oooooooo02Gooooo0Ol00001ooooo`008Oooool2o`0002Kooooo00?o0000ooooooooool0ZOooool0
0ol0003oooooooooo`0Uooooo`;o00000Oooool0027ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`2Xooooo`03o`000?oooooooooo02Kooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool09oooool1o`00007o
oooo000Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Y?ooool00ol0003ooooo
ooooo`0Xooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`2Sooooo`03o`000?oooooooooo02Sooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0Z
ooooo`;o0000X_ooool00ol0003oooooooooo`0Yooooo`7o00000Oooool0027ooooo0_l0000]oooo
o`03o`000?oooooooooo09kooooo00?o0000ooooooooool0:Oooool2o`00007ooooo000Qooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0Voooool2o`0002gooooo0Ol00001ooooo`00
8Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo09Sooooo0_l0000_ooooo`7o0000
0Oooool0027ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Fooooo`03o`000?oo
oooooooo02oooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo09?ooooo0_l0000booooo`7o00000Oooool0027ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`2@ooooo`;o0000=?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0SOooool2o`0003Kooooo0Ol00001ooooo`008Oooool2o`0003Cooooo
0_l0002<ooooo`03o`000?oooooooooo03Gooooo0_l00001ooooo`008Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo08Oooooo0_l0000iooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`24ooooo`;o0000>oooool1o`00007ooooo000Qoooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0POooool2o`0003gooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0?Oooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o0000
0oooool3o`0000Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1looooo`;o0000
@?ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`1iooooo`;o0000@_ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`;o0000??ooool0
0ol0003oooooooooo`1fooooo`;o0000@oooool2o`00007ooooo0007ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000oooool2o`0000Gooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`1cooooo`;o0000A_ooool1o`00007ooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03gooooo0ol0001aooooo`03o`000?oooooooooo04Kooooo0Ol00001ooooo`001ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo0ol0001/ooooo`;o0000BOooool1o`00
007ooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo04?o
oooo0ol0001Wooooo`;o0000Boooool1o`00007ooooo000Qooooo`03o`000?oooooooooo04Kooooo
0ol0001Rooooo`;o0000COooool1o`00007ooooo000Qooooo`03o`000?oooooooooo04Wooooo0ol0
001Nooooo`03o`000?oooooooooo04gooooo0Ol00001ooooo`008Oooool2o`0004gooooo0ol0001I
ooooo`;o0000Coooool2o`00007ooooo000Qooooo`03o`000?oooooooooo04oooooo0ol0001Doooo
o`;o0000D_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo05;ooooo0ol0001?ooooo`;o
0000E?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo05Gooooo0ol0001;ooooo`03o`00
0?oooooooooo05Cooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1Hooooo`?o0000A_oo
ool2o`0005Oooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1Kooooo`?o0000?_ooool5
o`0005Wooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1Nooooo`?o0000<_ooool9o`00
05kooooo0Ol00001ooooo`008Oooool2o`0006;ooooo0ol0000Wooooo`So0000I_ooool2o`00007o
oooo000Qooooo`03o`000?oooooooooo06Cooooo0ol0000Kooooo`Wo0000Koooool1o`00007ooooo
000Qooooo`03o`000?oooooooooo06Oooooo0ol0000@ooooo`So0000N?ooool1o`00007ooooo000Q
ooooo`03o`000?oooooooooo06[ooooo0ol00004ooooo`Wo0000P?ooool1o`00007ooooo000Qoooo
o`03o`000?oooooooooo06gooooo1?l00029ooooo`7o00000Oooool0027ooooo00?o0000oooooooo
ool0n_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`008Ooo
ool2o`000?[ooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00001ooooo`008Oooooono`00
007ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {288.562, 0}} -> {-0.0457708, -0.0433705, \
0.000288431, 0.000288431}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Screen", "\[Rule]", 
          TagBox[
            StyleBox[
              
              TagBox[\(Move[Screen[0.07046053117546919`], 
                  49.99711776386677`]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(TurboSystem \[Rule] "-traced system-"\), 
        ",", \(FocalPoint \[Rule] {49.99711776386677`, 0, 0}\), 
        ",", \(FocusType \[Rule] RMSFocus\), 
        ",", \(WeightedSpotSize \[Rule] 0.011799204514843302`\), 
        ",", \(SpotSize \[Rule] 0.011799204514843302`\), 
        ",", \(BackFocalLength \[Rule] 29.99711776386677`\), 
        ",", \(FocalPlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(TurboRays \[Rule] "-ray intercepts of 1 surfaces-"\)}], 
      "}"}]], "Output",
  CellLabel->"Out[128]=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["PSF[opticalsystem,NumberOfPoints->512,PaddingFactor->10];", "Input",
  CellLabel->"In[129]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.132513 0.0147151 0.357689 [
[.10246 -0.0125 -6 -9 ]
[.10246 -0.0125 6 0 ]
[.23497 -0.0125 -6 -9 ]
[.23497 -0.0125 6 0 ]
[.36749 -0.0125 -6 -9 ]
[.36749 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.63251 -0.0125 -3 -9 ]
[.63251 -0.0125 3 0 ]
[.76503 -0.0125 -3 -9 ]
[.76503 -0.0125 3 0 ]
[.89754 -0.0125 -3 -9 ]
[.89754 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10414 -24 -4.5 ]
[-0.0125 .10414 0 4.5 ]
[-0.0125 .19356 -18 -4.5 ]
[-0.0125 .19356 0 4.5 ]
[-0.0125 .28298 -24 -4.5 ]
[-0.0125 .28298 0 4.5 ]
[-0.0125 .3724 -6 -4.5 ]
[-0.0125 .3724 0 4.5 ]
[-0.0125 .46183 -24 -4.5 ]
[-0.0125 .46183 0 4.5 ]
[-0.0125 .55125 -18 -4.5 ]
[-0.0125 .55125 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10246 0 m
.10246 .00625 L
s
[(-3)] .10246 -0.0125 0 1 Mshowa
.23497 0 m
.23497 .00625 L
s
[(-2)] .23497 -0.0125 0 1 Mshowa
.36749 0 m
.36749 .00625 L
s
[(-1)] .36749 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.63251 0 m
.63251 .00625 L
s
[(1)] .63251 -0.0125 0 1 Mshowa
.76503 0 m
.76503 .00625 L
s
[(2)] .76503 -0.0125 0 1 Mshowa
.89754 0 m
.89754 .00625 L
s
[(3)] .89754 -0.0125 0 1 Mshowa
.125 Mabswid
.12896 0 m
.12896 .00375 L
s
.15547 0 m
.15547 .00375 L
s
.18197 0 m
.18197 .00375 L
s
.20847 0 m
.20847 .00375 L
s
.26148 0 m
.26148 .00375 L
s
.28798 0 m
.28798 .00375 L
s
.31448 0 m
.31448 .00375 L
s
.34098 0 m
.34098 .00375 L
s
.39399 0 m
.39399 .00375 L
s
.42049 0 m
.42049 .00375 L
s
.44699 0 m
.44699 .00375 L
s
.4735 0 m
.4735 .00375 L
s
.5265 0 m
.5265 .00375 L
s
.55301 0 m
.55301 .00375 L
s
.57951 0 m
.57951 .00375 L
s
.60601 0 m
.60601 .00375 L
s
.65902 0 m
.65902 .00375 L
s
.68552 0 m
.68552 .00375 L
s
.71202 0 m
.71202 .00375 L
s
.73852 0 m
.73852 .00375 L
s
.79153 0 m
.79153 .00375 L
s
.81803 0 m
.81803 .00375 L
s
.84453 0 m
.84453 .00375 L
s
.87104 0 m
.87104 .00375 L
s
.07596 0 m
.07596 .00375 L
s
.04946 0 m
.04946 .00375 L
s
.02295 0 m
.02295 .00375 L
s
.92404 0 m
.92404 .00375 L
s
.95054 0 m
.95054 .00375 L
s
.97705 0 m
.97705 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10414 m
.00625 .10414 L
s
[(0.25)] -0.0125 .10414 1 0 Mshowa
0 .19356 m
.00625 .19356 L
s
[(0.5)] -0.0125 .19356 1 0 Mshowa
0 .28298 m
.00625 .28298 L
s
[(0.75)] -0.0125 .28298 1 0 Mshowa
0 .3724 m
.00625 .3724 L
s
[(1)] -0.0125 .3724 1 0 Mshowa
0 .46183 m
.00625 .46183 L
s
[(1.25)] -0.0125 .46183 1 0 Mshowa
0 .55125 m
.00625 .55125 L
s
[(1.5)] -0.0125 .55125 1 0 Mshowa
.125 Mabswid
0 .0326 m
.00375 .0326 L
s
0 .05048 m
.00375 .05048 L
s
0 .06837 m
.00375 .06837 L
s
0 .08625 m
.00375 .08625 L
s
0 .12202 m
.00375 .12202 L
s
0 .13991 m
.00375 .13991 L
s
0 .15779 m
.00375 .15779 L
s
0 .17568 m
.00375 .17568 L
s
0 .21144 m
.00375 .21144 L
s
0 .22933 m
.00375 .22933 L
s
0 .24721 m
.00375 .24721 L
s
0 .2651 m
.00375 .2651 L
s
0 .30087 m
.00375 .30087 L
s
0 .31875 m
.00375 .31875 L
s
0 .33664 m
.00375 .33664 L
s
0 .35452 m
.00375 .35452 L
s
0 .39029 m
.00375 .39029 L
s
0 .40817 m
.00375 .40817 L
s
0 .42606 m
.00375 .42606 L
s
0 .44394 m
.00375 .44394 L
s
0 .47971 m
.00375 .47971 L
s
0 .4976 m
.00375 .4976 L
s
0 .51548 m
.00375 .51548 L
s
0 .53336 m
.00375 .53336 L
s
0 .56913 m
.00375 .56913 L
s
0 .58702 m
.00375 .58702 L
s
0 .6049 m
.00375 .6049 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.10246 .61178 m
.10246 .61803 L
s
.23497 .61178 m
.23497 .61803 L
s
.36749 .61178 m
.36749 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.63251 .61178 m
.63251 .61803 L
s
.76503 .61178 m
.76503 .61803 L
s
.89754 .61178 m
.89754 .61803 L
s
.125 Mabswid
.12896 .61428 m
.12896 .61803 L
s
.15547 .61428 m
.15547 .61803 L
s
.18197 .61428 m
.18197 .61803 L
s
.20847 .61428 m
.20847 .61803 L
s
.26148 .61428 m
.26148 .61803 L
s
.28798 .61428 m
.28798 .61803 L
s
.31448 .61428 m
.31448 .61803 L
s
.34098 .61428 m
.34098 .61803 L
s
.39399 .61428 m
.39399 .61803 L
s
.42049 .61428 m
.42049 .61803 L
s
.44699 .61428 m
.44699 .61803 L
s
.4735 .61428 m
.4735 .61803 L
s
.5265 .61428 m
.5265 .61803 L
s
.55301 .61428 m
.55301 .61803 L
s
.57951 .61428 m
.57951 .61803 L
s
.60601 .61428 m
.60601 .61803 L
s
.65902 .61428 m
.65902 .61803 L
s
.68552 .61428 m
.68552 .61803 L
s
.71202 .61428 m
.71202 .61803 L
s
.73852 .61428 m
.73852 .61803 L
s
.79153 .61428 m
.79153 .61803 L
s
.81803 .61428 m
.81803 .61803 L
s
.84453 .61428 m
.84453 .61803 L
s
.87104 .61428 m
.87104 .61803 L
s
.07596 .61428 m
.07596 .61803 L
s
.04946 .61428 m
.04946 .61803 L
s
.02295 .61428 m
.02295 .61803 L
s
.92404 .61428 m
.92404 .61803 L
s
.95054 .61428 m
.95054 .61803 L
s
.97705 .61428 m
.97705 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10414 m
1 .10414 L
s
.99375 .19356 m
1 .19356 L
s
.99375 .28298 m
1 .28298 L
s
.99375 .3724 m
1 .3724 L
s
.99375 .46183 m
1 .46183 L
s
.99375 .55125 m
1 .55125 L
s
.125 Mabswid
.99625 .0326 m
1 .0326 L
s
.99625 .05048 m
1 .05048 L
s
.99625 .06837 m
1 .06837 L
s
.99625 .08625 m
1 .08625 L
s
.99625 .12202 m
1 .12202 L
s
.99625 .13991 m
1 .13991 L
s
.99625 .15779 m
1 .15779 L
s
.99625 .17568 m
1 .17568 L
s
.99625 .21144 m
1 .21144 L
s
.99625 .22933 m
1 .22933 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .2651 m
1 .2651 L
s
.99625 .30087 m
1 .30087 L
s
.99625 .31875 m
1 .31875 L
s
.99625 .33664 m
1 .33664 L
s
.99625 .35452 m
1 .35452 L
s
.99625 .39029 m
1 .39029 L
s
.99625 .40817 m
1 .40817 L
s
.99625 .42606 m
1 .42606 L
s
.99625 .44394 m
1 .44394 L
s
.99625 .47971 m
1 .47971 L
s
.99625 .4976 m
1 .4976 L
s
.99625 .51548 m
1 .51548 L
s
.99625 .53336 m
1 .53336 L
s
.99625 .56913 m
1 .56913 L
s
.99625 .58702 m
1 .58702 L
s
.99625 .6049 m
1 .6049 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .4409 Mdot
.05428 .53792 Mdot
.08481 .5893 Mdot
.11538 .60332 Mdot
.146 .58759 Mdot
.17665 .54911 Mdot
.20734 .49424 Mdot
.23806 .42871 Mdot
.26881 .35767 Mdot
.29958 .28566 Mdot
.33038 .21664 Mdot
.36119 .15399 Mdot
.39202 .10051 Mdot
.42287 .05845 Mdot
.45372 .02948 Mdot
.48457 .01472 Mdot
.51543 .01472 Mdot
.54628 .02948 Mdot
.57713 .05845 Mdot
.60798 .10051 Mdot
.63881 .15399 Mdot
.66962 .21664 Mdot
.70042 .28566 Mdot
.73119 .35767 Mdot
.76194 .42871 Mdot
.79266 .49424 Mdot
.82335 .54911 Mdot
.854 .58759 Mdot
.88462 .60332 Mdot
.91519 .5893 Mdot
.94572 .53792 Mdot
.97619 .4409 Mdot
.5 Mabswid
.02381 .4409 m
.03853 .48776 L
.04619 .51215 L
.05024 .52505 L
.05247 .53215 L
.05357 .53564 L
.05405 .53717 L
.05458 .53842 L
.05553 .54002 L
.05654 .54172 L
.05867 .5453 L
.06238 .55156 L
.06965 .56379 L
.07767 .57728 L
.08147 .58368 L
.08332 .5868 L
.08413 .58816 L
.08455 .58887 L
.085 .58939 L
.08547 .58961 L
.0859 .58981 L
.08675 .5902 L
.08862 .59105 L
.09257 .59286 L
.09977 .59616 L
.10734 .59963 L
.11064 .60115 L
.11239 .60195 L
.11424 .60279 L
.11469 .603 L
.11518 .60323 L
.11546 .60328 L
.11572 .60315 L
.11622 .60289 L
.11805 .60195 L
.12167 .60009 L
.12964 .596 L
.13746 .59198 L
.14127 .59002 L
.14473 .58824 L
.14557 .58781 L
.146 .58759 L
.14646 .58701 L
.14744 .58578 L
.14834 .58465 L
.15175 .58037 L
.15925 .57096 L
.17462 .55166 L
.18941 .5263 L
.20513 .49818 L
Mistroke
.22028 .46664 L
.23485 .43556 L
.25035 .40031 L
.26528 .36582 L
.28114 .32882 L
.29642 .29305 L
.31113 .25978 L
.32677 .22473 L
.34183 .19335 L
.35632 .1639 L
.37174 .1357 L
.38658 .10996 L
.40236 .08642 L
.41755 .06569 L
.43218 .04971 L
.44773 .0351 L
.46271 .02518 L
.47711 .01828 L
.48071 .01656 L
.48267 .01562 L
.48363 .01517 L
.48405 .01497 L
.4845 .01475 L
.48499 .01472 L
.48546 .01472 L
.48648 .01472 L
.48865 .01472 L
.49245 .01472 L
.49988 .01472 L
.50383 .01472 L
.50805 .01472 L
.51014 .01472 L
.51212 .01472 L
.51389 .01472 L
.51438 .01472 L
.5149 .01472 L
.51534 .01472 L
.51582 .0149 L
.52309 .01838 L
.53107 .0222 L
.53839 .0257 L
.5421 .02748 L
.54391 .02834 L
.54556 .02913 L
.54599 .02934 L
.54645 .02964 L
.5469 .03005 L
.5473 .03043 L
.54917 .03219 L
.55311 .03589 L
Mistroke
.56811 .04998 L
.58253 .06581 L
.59789 .08675 L
.61267 .10865 L
.62838 .1359 L
.64351 .16356 L
.65807 .19316 L
.67356 .22547 L
.68848 .2589 L
.70432 .2948 L
.7196 .33054 L
.73429 .36483 L
.74992 .40093 L
.76497 .43517 L
.77944 .46604 L
.79485 .49815 L
.80968 .52466 L
.82544 .55174 L
.84063 .5708 L
.84757 .57952 L
.85153 .58449 L
.85247 .58567 L
.85346 .58692 L
.85387 .58743 L
.85431 .58775 L
.85479 .588 L
.85524 .58823 L
.85887 .59009 L
.86278 .5921 L
.87078 .59621 L
.87837 .60011 L
.88045 .60118 L
.88265 .60231 L
.88356 .60277 L
.88406 .60303 L
.88453 .60327 L
.8848 .60324 L
.88509 .6031 L
.8856 .60287 L
.8866 .60241 L
.90184 .59543 L
.90603 .5935 L
.90998 .59169 L
.9117 .5909 L
.91352 .59007 L
.91447 .58963 L
.91473 .58951 L
.91501 .58938 L
.91552 .58875 L
.91735 .58567 L
Mistroke
.93228 .56053 L
.93985 .5478 L
.94384 .54108 L
.94481 .53945 L
.94534 .53855 L
.9456 .53811 L
.94585 .5375 L
.94614 .53659 L
.94645 .53559 L
.94699 .53385 L
.94807 .53044 L
.95597 .50527 L
.96327 .48202 L
.97619 .4409 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[129]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00>oooool3o`0001gooooo1Ol0000Mooooo`?o00006oooool2o`0001kooooo0ol0000Moooo
o`Go00007Oooool3o`00023ooooo000jooooo`05o`000?ooooooooooooooool000007Oooool01?l0
003oooooooooool0000Nooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00007_oo
ool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0001cooooo00Go0000oooooooooooo
ooooo`00000Oooooo`00=?ooool5o`0000Gooooo00?o0000ooooooooool05?ooool5o`0000?ooooo
00?o0000ooooooooool05_ooool5o`0000?ooooo00?o0000ooooooooool06Oooool01?l0003ooooo
ooooool0000Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Mooooo`00??ooool2o`00023ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Iooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Mooooo`;o00008?ooool003kooooo00?o0000ooooooooool06_ooool01Ol0003ooooo
oooooooooooo000001kooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool0000Noooo
o`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooo
oooo01gooooo000jooooo`05o`000?ooooooooooooooool000007?ooool01Ol0003ooooooooooooo
oooo000001gooooo0_l0000Kooooo`04o`000?ooooooooooo`0001gooooo0_l0000Nooooo`05o`00
0?ooooooooooooooool000007?ooool01Ol0003ooooooooooooooooo000001oooooo000kooooo`?o
00007_ooool3o`0001oooooo00?o0000ooooooooool06_ooool2o`0001oooooo00?o0000oooooooo
ool07Oooool3o`0001kooooo0ol0000Pooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`008Ooooooho`0000Oooooo000Jooooo`;o00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool001Wooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo
00?o0000ooooooooool01Oooool001Wooooo00Co0000oooooooooooo00001?ooool2o`0007Gooooo
2_l0001eooooo`;o00001oooool001Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1booooo`Co00000_ooool01?l0003oooooooooooooool4o`0007Cooooo00?o0000oooooooo
ool01Oooool001Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1`ooooo`;o
00001_ooool00ol0003oooooooooo`05ooooo`;o0000L_ooool00ol0003oooooooooo`05ooooo`00
6Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06kooooo0_l00008ooooo`03
o`000?oooooooooo00Oooooo0_l0001`ooooo`03o`000?oooooooooo00Gooooo000Jooooo`;o0000
1Oooool00ol0003oooooooooo`1/ooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`;o0000
Koooool00ol0003oooooooooo`05ooooo`008Oooool2o`0006gooooo0_l0000:ooooo`03o`000?oo
oooooooo00Sooooo0ol0001]ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0Joooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Joooool0
0ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool01Oooool0027ooooo
0_l0001Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`1Wooooo`;o00001oooool0027ooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`1Uooooo`;o00004Oooool00ol0003oooooooooo`0@
ooooo`;o0000Ioooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1Uoooo
o`;o00004Oooool00ol0003oooooooooo`0@ooooo`;o0000Ioooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000
IOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
Hoooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool01Ooo
ool0027ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000HOooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Goooool2o`0000Oo
oooo000Qooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool01Oooool000Sooooo0_l0
0004ooooo`04o`000?ooooooooooooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05gooooo0_l0000Iooooo`03o`000?oooooooooo01Oooooo0_l0001Pooooo`03o`000?oooooooooo
00Gooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`;o0000G_ooool2o`0001Wooooo00?o0000ooooooooool05oooool2o`00
05oooooo0_l00007ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
00Gooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Ko0000ooooooooooooooooo`000?oo
ool4o`0000Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`05ooooo`001oooool0
1?l0003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000008ooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool01Oooool000Sooooo0_l00009ooooo`?o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`05ooooo`008Ooo
ool2o`0005cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo05[ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`05ooooo`008Oooool2o`0005[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Sooooo
0_l00007ooooo`008Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Gooooo000Q
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooo
ooooool0EOooool3o`00023ooooo00?o0000ooooooooool07oooool2o`0005Sooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool0EOooool2o`00027ooooo00?o0000oooooooo
ool07oooool2o`0005Sooooo00?o0000ooooooooool01Oooool0027ooooo0_l0001Gooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Eooooo`;o0000
1oooool0027ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`05ooooo`008Oooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool01Oooool0027ooooo0_l0001Eooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Cooooo`;o00001oooool0027ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`05ooooo`003_ooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`05ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Gooooo000=ooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2o`0005;ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo053ooooo0_l00007ooooo`003Ooo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`05ooooo`003Oooool01?l0003oooooooooool00007ooooo`Co0000
1Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Gooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo00Gooooo000>ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`05ooooo`008Oooool2o`00053ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04kooooo0_l00007ooooo`008Oooool00ol0
003oooooooooo`1>ooooo`;o0000:?ooool00ol0003oooooooooo`0Wooooo`;o0000D?ooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1>ooooo`;o0000:?ooool00ol0003o
ooooooooo`0Wooooo`;o0000D?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000Coooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0COooool2o`0000Oooooo000Q
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
1Oooool0027ooooo0_l0001=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`1;ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool01Oooool0027ooooo
0_l0001;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`19ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`05ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo0007oooo
o`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`001oooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000Aooo
ool2o`00033ooooo00?o0000ooooooooool0;_ooool2o`0004Sooooo0_l00007ooooo`001oooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooo000000?o00001Oooool00ol0003ooooooooo
o`16ooooo`;o0000<?ooool00ol0003oooooooooo`0^ooooo`;o0000BOooool00ol0003ooooooooo
o`05ooooo`001oooool01?l0003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003o
ooooo`000008ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01Oooool000Sooooo
0_l00008ooooo`Go000000?oooooo`000?l000000ol00004ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool01Oooool0027ooooo0_l00016ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`15ooooo`;o00001oooool0027ooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool01Oooool0027ooooo0_l00015ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`13ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`05ooooo`008Oooool2o`0004;ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo043ooooo
0_l00007ooooo`008Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Gooooo000Q
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`05ooooo`008Oooool2o`00047ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03oooooo0_l00007ooooo`00
8Oooool00ol0003oooooooooo`0oooooo`;o0000=oooool00ol0003oooooooooo`0fooooo`;o0000
@Oooool00ol0003oooooooooo`05ooooo`006Oooool3o`0000Gooooo00?o0000ooooooooool0?ooo
ool2o`0003Oooooo00?o0000ooooooooool0=_ooool2o`00047ooooo00?o0000ooooooooool01Ooo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00Gooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`05ooooo`006_ooool00ol0003oooooooooo`04ooooo`;o0000?_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0?Oooool2o`0000Oo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`05ooooo`006Oooool2o`0000Kooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`05ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool01Oooool0027ooooo0_l0000mooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0looooo`;o00001oooool0027ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Ooo
ool0027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`008Oooool2o`00
03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
03Wooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Go
oooo000Qooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`05ooooo`008Oooool2o`0003Sooooo0_l0000o
ooooo`03o`000?oooooooooo03kooooo0_l0000hooooo`;o00001oooool0027ooooo00?o0000oooo
ooooool0=oooool2o`0003oooooo00?o0000ooooooooool0?_ooool2o`0003Wooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`05ooooo`00
8Oooool00ol0003oooooooooo`02ooooo`;o0000<oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool0<?ooool2o`0000Gooooo00?o0000ooooooooool0
1Oooool0027ooooo0_l00003ooooo`;o0000<_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool0;oooool2o`0000Cooooo0_l00007ooooo`008Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`001oooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00002
ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`002?ooool00ol0003oooooooooo`08oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo0008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo0008ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`002?ooool00ol0003o
ooooooooo`07ooooo`06o`000?ooooooooooooooool0003ooooo1?l00005ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0007ooooo`;o00002Oooool01ol0003ooooooooooooooooo0000ooooool000002?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`002?ooool00ol0003oooooooooo`08ooooo`?o00000_ooool5
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool0027ooooo0_l00006ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool01Oooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool09_ooool3o`0004Kooooo00?o0000ooooooooool0AOooool2o`0002Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Gooooo0ol00016ooooo`03o`000?oooooooooo04Gooooo0_l0000X
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0027ooooo0_l00008oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool2o`0000Oooooo000Qooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`;o00002Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Sooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`05ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`008Oooool2o`0000_ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`;o00001oooool0027ooooo00?o0000
ooooooooool02_ooool2o`0001oooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`03o`000?oooooooooo00Gooooo000=oooo
o`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0:oooo
o`;o00007_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool07?ooool2o`0000cooooo00?o0000ooooooooool01Oooool000kooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool000ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool06_ooool2o`0004kooooo00?o0000ooooooooool0COooool2o`0001_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`003_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`03o`000?oooooooooo01Wooooo
0_l0001>ooooo`03o`000?oooooooooo04gooooo0_l0000Kooooo`03o`000?oooooooooo00_ooooo
0_l00007ooooo`003_ooool00ol0003oooooooooo`07ooooo`Co00001Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`05ooooo`003Oooool2o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05
ooooo`003_ooool00ol0003oooooooooo`07ooooo`Go00001?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05oooo
o`008Oooool2o`0000oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`;o
00001oooool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Ooo
ool0027ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo05?ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0=ooooo`;o0000EOooool00ol0003oooooooooo`1Dooooo`;o00003oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00004_ooool2o`0000go
oooo0_l0001Fooooo`03o`000?oooooooooo05Cooooo0_l0000=ooooo`;o00004oooool2o`0000Oo
oooo000Qooooo`03o`000?oooooooooo017ooooo1Ol00008ooooo`Co0000E_ooool00ol0003ooooo
ooooo`1Dooooo`Go00002Oooool3o`0001Cooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`;o0000F_ooool00ol0003ooooooooo
o`1Iooooo`;o00001Oooool2o`0001Oooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000
ooooooooool05oooool5o`0005cooooo00?o0000ooooooooool0Foooool5o`0001Wooooo00?o0000
ooooooooool01Oooool0027ooooo0_l0000Jooooo`;o0000GOooool00ol0003oooooooooo`1Loooo
o`;o00006_ooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0027ooooon?l00007ooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00<oooool3o`0008[ooooo00?o0000ooooooooool0
:oooool3o`0001Gooooo00?o0000ooooooooool05oooool003Cooooo00?o0000ooooooooool0R?oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_oo
ool002kooooo0ol00003ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000oooool4
o`000003ooooool0003o000000?o00001oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6
o`0000Kooooo1?l00002ooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000o`000003
o`0000;ooooo0ol00002ooooo`?o00001?ooool3o`0000;ooooo0ol000001?oooooo0000o`000?oo
ool3o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000ooo
ool4o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1Ol00002ooooo`?o00000_oo
ool3o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000;ooooo2_l00005ooooo`03o`00
0?oooooooooo01Gooooo000]ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo000]ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool5o`0000;ooooo00?o0000oooo
ooooool00_ooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`Go00002?oo
ool00ol0003oooooooooo`02ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000?ooooo
00?o0000ooooool000000_ooool5o`0000?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000;ooooo0ol00005ooooo`03o`000?oooooooooo01Gooooo000]ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`?o00000_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?oooooooooooooo
ool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001Oooool01_l0
003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool05Oooool002gooooo00Ko0000
ooooooooooooooooo`000?ooool4o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000?ooooo
0_l00005ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?o
oooo1?l00003ooooo`?o00002Oooool01Ol0003oooooooooool0003ooooo00?o00001?ooool4o`00
00;ooooo1?l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00002oooo
o`Co00000oooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo1_l000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000;ooooo1?l00003ooooo`Wo00000oooool3o`0000?ooooo1?l00004oooo
o`03o`000?oooooooooo01Gooooo000]ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Fooooo`00;_ooool3o`0000Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0=ooooo`?o00002Oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2
o`0000[ooooo1?l00004ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o0000;_ooool0
0ol0003oooooooooo`0Hooooo`?o00005_ooool00ol0003oooooooooo`02ooooo`;o00002oooool0
0ol0003oooooooooo`0Gooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.79293, -0.177895, \
0.0305317, 0.0113111}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 12.0848 0.0144968 0.000133415 [
[.01661 .002 -15 -9 ]
[.01661 .002 15 0 ]
[.2583 .002 -15 -9 ]
[.2583 .002 15 0 ]
[.5 .002 -3 -9 ]
[.5 .002 3 0 ]
[.7417 .002 -12 -9 ]
[.7417 .002 12 0 ]
[.98339 .002 -12 -9 ]
[.98339 .002 12 0 ]
[.01131 .14791 -24 -4.5 ]
[.01131 .14791 0 4.5 ]
[.01131 .28133 -24 -4.5 ]
[.01131 .28133 0 4.5 ]
[.01131 .41474 -24 -4.5 ]
[.01131 .41474 0 4.5 ]
[.01131 .54815 -24 -4.5 ]
[.01131 .54815 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01661 .0145 m
.01661 .02075 L
s
[(-0.04)] .01661 .002 0 1 Mshowa
.2583 .0145 m
.2583 .02075 L
s
[(-0.02)] .2583 .002 0 1 Mshowa
.5 .0145 m
.5 .02075 L
s
[(0)] .5 .002 0 1 Mshowa
.7417 .0145 m
.7417 .02075 L
s
[(0.02)] .7417 .002 0 1 Mshowa
.98339 .0145 m
.98339 .02075 L
s
[(0.04)] .98339 .002 0 1 Mshowa
.125 Mabswid
.07703 .0145 m
.07703 .01825 L
s
.13745 .0145 m
.13745 .01825 L
s
.19788 .0145 m
.19788 .01825 L
s
.31873 .0145 m
.31873 .01825 L
s
.37915 .0145 m
.37915 .01825 L
s
.43958 .0145 m
.43958 .01825 L
s
.56042 .0145 m
.56042 .01825 L
s
.62085 .0145 m
.62085 .01825 L
s
.68127 .0145 m
.68127 .01825 L
s
.80212 .0145 m
.80212 .01825 L
s
.86255 .0145 m
.86255 .01825 L
s
.92297 .0145 m
.92297 .01825 L
s
.25 Mabswid
0 .0145 m
1 .0145 L
s
.02381 .14791 m
.03006 .14791 L
s
[(1000)] .01131 .14791 1 0 Mshowa
.02381 .28133 m
.03006 .28133 L
s
[(2000)] .01131 .28133 1 0 Mshowa
.02381 .41474 m
.03006 .41474 L
s
[(3000)] .01131 .41474 1 0 Mshowa
.02381 .54815 m
.03006 .54815 L
s
[(4000)] .01131 .54815 1 0 Mshowa
.125 Mabswid
.02381 .04118 m
.02756 .04118 L
s
.02381 .06786 m
.02756 .06786 L
s
.02381 .09455 m
.02756 .09455 L
s
.02381 .12123 m
.02756 .12123 L
s
.02381 .17459 m
.02756 .17459 L
s
.02381 .20128 m
.02756 .20128 L
s
.02381 .22796 m
.02756 .22796 L
s
.02381 .25464 m
.02756 .25464 L
s
.02381 .30801 m
.02756 .30801 L
s
.02381 .33469 m
.02756 .33469 L
s
.02381 .36137 m
.02756 .36137 L
s
.02381 .38806 m
.02756 .38806 L
s
.02381 .44142 m
.02756 .44142 L
s
.02381 .46811 m
.02756 .46811 L
s
.02381 .49479 m
.02756 .49479 L
s
.02381 .52147 m
.02756 .52147 L
s
.02381 .57484 m
.02756 .57484 L
s
.02381 .60152 m
.02756 .60152 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .02166 m
.02785 .02308 L
.03188 .02414 L
.03592 .0245 L
.03995 .02395 L
.04399 .02253 L
.04802 .02056 L
.05206 .01857 L
.05609 .01719 L
.06013 .01698 L
.06416 .01829 L
.0682 .02115 L
.07224 .02521 L
.07627 .0298 L
.08031 .03407 L
.08434 .03716 L
.08838 .03839 L
.09241 .03743 L
.09645 .03437 L
.10048 .02973 L
.10452 .02439 L
.10856 .01941 L
.11259 .01588 L
.11663 .01472 L
.12066 .01654 L
.1247 .02154 L
.12873 .02947 L
.13277 .03962 L
.1368 .05091 L
.14084 .06197 L
.14487 .07133 L
.14891 .07756 L
.15295 .07956 L
.15698 .07676 L
.16102 .06931 L
.16505 .05827 L
.16909 .04562 L
.17312 .0341 L
.17716 .02689 L
.18119 .02712 L
.18523 .03725 L
.18927 .05848 L
.1933 .09031 L
.19734 .13029 L
.20137 .17419 L
.20541 .21653 L
.20944 .25148 L
.21348 .27389 L
.21751 .28045 L
.22155 .27046 L
Mistroke
.22559 .24638 L
.22962 .21361 L
.23366 .17984 L
.23769 .15373 L
.24173 .1434 L
.24576 .15486 L
.2498 .19066 L
.25383 .24919 L
.25787 .32466 L
.2619 .40784 L
.26594 .48754 L
.26998 .55243 L
.27401 .59302 L
.27805 .60332 L
.28208 .58197 L
.28612 .53253 L
.29015 .46296 L
.29419 .38429 L
.29822 .30878 L
.30226 .24789 L
.3063 .21032 L
.31033 .20067 L
.31437 .2187 L
.3184 .25948 L
.32244 .31433 L
.32647 .37235 L
.33051 .42231 L
.33454 .45457 L
.33858 .46262 L
.34262 .44404 L
.34665 .40079 L
.35069 .3386 L
.35472 .26587 L
.35876 .19199 L
.36279 .12565 L
.36683 .07333 L
.37086 .03831 L
.3749 .02036 L
.37893 .01613 L
.38297 .02024 L
.38701 .02678 L
.39104 .03087 L
.39508 .02995 L
.39911 .02455 L
.40315 .01825 L
.40718 .01691 L
.41122 .02723 L
.41525 .05499 L
.41929 .10333 L
.42333 .17153 L
Mistroke
.42736 .2545 L
.4314 .34332 L
.43543 .42659 L
.43947 .49246 L
.4435 .5309 L
.44754 .53576 L
.45157 .50608 L
.45561 .4464 L
.45964 .36604 L
.46368 .27729 L
.46772 .19305 L
.47175 .12437 L
.47579 .07839 L
.47982 .05715 L
.48386 .05757 L
.48789 .0725 L
.49193 .09267 L
.49596 .10912 L
.5 .11539 L
.50404 .10912 L
.50807 .09266 L
.51211 .07248 L
.51614 .05756 L
.52018 .05715 L
.52421 .07839 L
.52825 .12438 L
.53228 .19306 L
.53632 .2773 L
.54036 .36605 L
.54439 .4464 L
.54843 .50606 L
.55246 .53574 L
.5565 .53087 L
.56053 .49242 L
.56457 .42656 L
.5686 .34329 L
.57264 .25447 L
.57667 .17151 L
.58071 .10333 L
.58475 .05499 L
.58878 .02723 L
.59282 .01691 L
.59685 .01825 L
.60089 .02454 L
.60492 .02995 L
.60896 .03087 L
.61299 .02678 L
.61703 .02024 L
.62107 .01613 L
.6251 .02037 L
Mistroke
.62914 .03832 L
.63317 .07333 L
.63721 .12564 L
.64124 .19198 L
.64528 .26586 L
.64931 .33858 L
.65335 .40076 L
.65738 .44401 L
.66142 .46259 L
.66546 .45454 L
.66949 .42229 L
.67353 .37233 L
.67756 .31433 L
.6816 .25949 L
.68563 .21871 L
.68967 .20069 L
.6937 .21034 L
.69774 .24791 L
.70178 .30881 L
.70581 .38431 L
.70985 .46297 L
.71388 .53254 L
.71792 .58197 L
.72195 .60332 L
.72599 .59301 L
.73002 .55243 L
.73406 .48754 L
.7381 .40784 L
.74213 .32466 L
.74617 .2492 L
.7502 .19067 L
.75424 .15487 L
.75827 .14341 L
.76231 .15373 L
.76634 .17984 L
.77038 .21361 L
.77441 .24636 L
.77845 .27044 L
.78249 .28042 L
.78652 .27386 L
.79056 .25145 L
.79459 .21651 L
.79863 .17417 L
.80266 .13028 L
.8067 .09031 L
.81073 .05848 L
.81477 .03725 L
.81881 .02712 L
.82284 .02689 L
.82688 .0341 L
Mistroke
.83091 .04561 L
.83495 .05826 L
.83898 .0693 L
.84302 .07675 L
.84705 .07956 L
.85109 .07756 L
.85513 .07133 L
.85916 .06197 L
.8632 .05091 L
.86723 .03963 L
.87127 .02947 L
.8753 .02154 L
.87934 .01654 L
.88337 .01472 L
.88741 .01588 L
.89144 .01941 L
.89548 .02439 L
.89952 .02973 L
.90355 .03437 L
.90759 .03743 L
.91162 .03839 L
.91566 .03716 L
.91969 .03407 L
.92373 .0298 L
.92776 .02521 L
.9318 .02115 L
.93584 .01829 L
.93987 .01698 L
.94391 .01719 L
.94794 .01857 L
.95198 .02056 L
.95601 .02253 L
.96005 .02395 L
.96408 .0245 L
.96812 .02414 L
.97215 .02307 L
.97619 .02166 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[129]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol0000Yoooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0002kooooo0_l0000boooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0002Sooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00004ooooo`?o00001Oooool001?ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002go
oooo00Co0000oooooooooooo0000<?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00009oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool000cooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`05o`00027ooooo1Ol00002
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`0]ooooo`04o`000?ooooooooooo`00033ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo00002?oo
ool01Ol0003oooooooooool0003ooooo00Go00001Oooool001?ooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool09oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;?oo
ool01?l0003oooooooooool0000`ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo00Cooooo000Cooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00000Yooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo02_ooooo00Co0000oooooooooooo0000<?ooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Uooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000006ooooo`004ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000Yooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo02_ooooo00Co0000oooooooooooo0000<?ooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Uooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000oooool2o`0000Kooooo000Dooooo`;o00002_oo
ool2o`0000Gooooo00?o0000ooooooooool0:?ooool2o`0000[ooooo0_l00003ooooo`?o0000;ooo
ool2o`0003;ooooo0_l0000:ooooo`;o00000oooool3o`0002Wooooo0_l0000:ooooo`;o00001Ooo
ool00ol0003oooooooooo`04ooooo`007Oooool00ol0003oooooooooo`3oooooo`7ooooo000Moooo
o`03o`000?oooooooooo0?oooooo0Oooool001gooooo00?o0000ooooooooool0ooooool1ooooo`00
7Oooool00ol0003oooooooooo`3oooooo`7ooooo000Gooooooko00002oooool001_ooooo00?o0000
ooooool000001Oooool2o`0000;ooooo0ol000000ooooooo0000ooooo`06ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool3o`0000Cooooo0_l00007ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`;o00001?oo
ool3o`0000kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`04o`00
0?oooooo0000o`0000;ooooo0_l00007ooooo`03o`000?oooooooooo00gooooo000Mooooo`Ko0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
??ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooo`00000oooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`Ko00004Oooool001gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02_ooool2o`00033ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000/
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000<?ooool2o`0000gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo
000Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Wooooo0_l0000_ooooo`03o`000?oooooooooo00;ooooo0_l0
0003ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooooooo0_l00004ooooo`03o`00
0?oooooooooo02gooooo0_l0000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Looooo`007Oooool00ol0003oooooooooo`0<ooooo`;o00000_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000
;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02o`0001oooooo000Mooooo`;o00003oooool2o`0000Wooooo
00?o0000ooooooooool01oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02co
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`07ooooo`;o00008Oooool001go
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool00000;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0/ooooo`05o`000?ooooooooooooooool000002Oooool0
0ol0003oooooooooo`0Zooooo`007Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`00000^ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02cooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo02_ooooo000Mooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0:oooool001gooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0[ooooo`007Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03_ooool2o`0000Oooooo0_l0000?ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0;?ooool001gooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00kooooo0_l00007ooooo`;o00003oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02gooooo000Mooooo`;o00007?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooool000001Oooool00ol0003oooooo`00
000?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;Oooool001gooooo00?o0000
ooooooooool07?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000<?ooool001go
oooo00?o0000ooooooooool07?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000`ooooo`007Ooo
ool00ol0003oooooooooo`0Mooooo`;o00002Oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Oooooo0_l0000aooooo`007Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03[ooooo000Mooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0>_ooool001gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0jooooo`007Oooool2o`0002Wooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0>_ooool001gooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0jooooo`007Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool000001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0jooooo`007Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0jooooo`007Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0jooooo`007Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0koooo
o`007Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0>oooool001gooooo0_l0000Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
>oooool001gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03_ooooo000Mooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0kooooo`007Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0>oooool000?ooooo0ol00004ooooo`;o00001?ooool2o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0kooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0>oooool000Cooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool3o`0002Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0>oooool000Cooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ool000007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo03_ooooo0004ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooo000001gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooool000002?ooool00ol0003ooooooooo
o`0looooo`000oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooo000001gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooool000002?ooool00ol0003o
ooooooooo`0looooo`001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
o`00000Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0??ooool001gooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000001cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`0looooo`007Oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00007?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo03cooooo000Mooooo`;o0000:oooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0??ooool001gooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0??ooool001gooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool0??ooool001gooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool0??ooool001gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000006oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool0??ooool001gooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000006oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool0??ooool001gooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000006oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0?Oooool001gooooo0_l0000/ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Oooool001gooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo000Mooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00cooooo0_l0000;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`;o00003Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0?Oooool001gooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooo`00000:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo000Mooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0mooooo`007Oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000003?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Oooool001gooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02oooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo
000Mooooo`;o0000;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02oooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo000M
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ool0000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0mooooo`007Oooool00ol0003oooooooooo`0/ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000@?ooool0
01gooooo00?o0000ooooooooool0;?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000010ooooo`00
7Oooool00ol0003oooooooooo`0/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000000_ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000043ooooo000M
ooooo`03o`000?oooooooooo02cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0
00002oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000@?ooool001go
oooo0_l0000]ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0:oooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000_ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000043ooooo000Mooooo`03o`000?oo
oooooooo02cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00[ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002oooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000@?ooool001gooooo00?o0000oooo
ooooool0;?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`00043ooooo000Mooooo`03o`000?oooooooooo02gooooo
00?o0000ooooool000001oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`000011ooooo`007Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`00000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000@Oooool0
00;ooooo1Ol00003ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooo`000011ooooo`000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo02gooooo0_l00008ooooo`03o`000?oooooooooo00[ooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooooooo
o`06ooooo`;o0000@Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool3o`0002ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`10ooooo`001Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04[ooooo0002ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1:ooooo`000oooool3
o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B_ooool0
01gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0B_ooool001gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B_ooool001gooooo
0_l0000iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1:ooooo`007Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1:ooooo`007Oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1:
ooooo`007Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1:ooooo`007Oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1:ooooo`00
7Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1:ooooo`007Oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1:ooooo`007Oooool2
o`0003Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo04[ooooo000Mooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04[ooooo000Mooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04[o
oooo000Mooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo04[ooooo000Mooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04[ooooo000M
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo04[ooooo000Mooooo`;o0000>Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool001gooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0B_ooool001gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Boooool001gooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Booo
ool001gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0Boooool001gooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool001go
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Boooool001gooooo0_l0000jooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`007Oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1;ooooo`007Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`007Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo
000001Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`000oooool3o`00
00Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000E
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000005Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo0006ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Boooool000Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`?o0000>Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000E
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool000Kooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1;ooooo`000_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_o
oooo0003ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool01?l0003ooooo
ooooool0000Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000009oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool001gooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooo
oooo00005_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000002Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_ooooo000Mooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
o`0001Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1;ooooo`007Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0
000Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000009ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Boooool001gooooo0_l0000jooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00000Fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Cooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo04_ooooo000Mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooo000001Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Boooool001gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooool000005_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`007Ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool2o`0001Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05Oooool00ol0003oooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0C?ooool001gooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0_l0000Gooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Gooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C?ooool0
01gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000001Kooooo00Go0000
ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1<ooooo`007Oooool2o`0003_ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool000005_ooool01Ol0003ooooooooo
oooooooo000002Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`007Ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_oo
ool01Ol0003ooooooooooooooooo000001Kooooo00Go0000ooooooooooooooooo`00000Uooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0C?ooool001gooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02;ooooo00Go0000oooooooooooo
ooooo`00000Fooooo`05o`000?ooooooooooooooool000009Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04cooooo000Mooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0001Sooooo00Co0000oooo
oooooooo00009Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo000Moooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Roooo
o`04o`000?ooooooooooo`0001Sooooo00Co0000oooooooooooo00009Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04cooooo000Mooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0001Sooooo00Co
0000oooooooooooo00009Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo
000Mooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Rooooo`04o`000?ooooooooooo`0001Sooooo00Co0000oooooooooooo00009Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04cooooo000Mooooo`;o0000>oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00006?ooool01?l0003o
ooooooooool0000Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C?ooool001go
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02;o
oooo00Co0000oooooooooooo00006?ooool01?l0003oooooooooool0000Uooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0C?ooool001gooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00006?ooool0
1?l0003oooooooooool0000Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C?oo
ool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02?ooooo00Co0000oooooooooooo00006?ooool01?l0003oooooooooool0000Vooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0C?ooool001gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo0000
6?ooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0C?ooool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooool000006?ooool00ol0003oooooo`00000Wooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0C?ooool001gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool000006?oo
ool00ol0003oooooo`00000Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C?oo
ool001gooooo0_l0000looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooo`00000Hooooo`03o`000?oooooo000002Oooooo00Go0000ooooooooooooooooo`00
001?ooooo`007Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool09?ooool2o`0001[ooooo0_l0000Wooooo`05o`000?ooooooooooooooool00000Cooo
ool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Cooooo0_l0000Jooooo`;o00009oooool01Ol0003ooooooooooooooooo000004oooooo000M
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0T
ooooo`;o00006_ooool2o`0002Oooooo00Go0000ooooooooooooooooo`00001?ooooo`001?ooool3
o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Vooooo`05o`000?ooooooooooooooool00000Coooool000Gooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo00Go0000oooooooo
ooooooooo`00001[ooooo`05o`000?ooooooooooooooool00000Coooool000;ooooo1Ol00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03cooooo00Go0000ooooooooooooooooo`00001[ooooo`05
o`000?ooooooooooooooool00000Coooool000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool3o`0003cooooo00Go0000ooooooooooooooooo`00001[ooooo`05o`000?oooooooooooooo
ool00000Coooool000?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0looooo`05o`000?ooooooooooooooool00000Joooool01Ol0003ooooooooooooooooo000004oo
oooo0004ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0looooo`05o`000?oooooo
ooooooooool00000Joooool01Ol0003ooooooooooooooooo000004oooooo0005ooooo`03o`000?oo
oooooooo00;ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0??oo
ool01?l0003oooooooooool0001]ooooo`04o`000?ooooooooooo`0004oooooo000Mooooo`03o`00
0?oooooooooo03cooooo00Co0000oooooooooooo0000KOooool01?l0003oooooooooool0001?oooo
o`007Oooool00ol0003oooooooooo`0looooo`04o`000?ooooooooooo`0006gooooo00Co0000oooo
oooooooo0000Coooool001gooooo0_l0000mooooo`04o`000?ooooooooooo`0006gooooo00Co0000
oooooooooooo0000Coooool001gooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`00001]
ooooo`03o`000?oooooo0000053ooooo000Mooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ool00000KOooool00ol0003oooooo`00001@ooooo`007Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooo000006gooooo00?o0000ooooool00000D?ooool001gooooo00?o0000ooooooooool0
?Oooool00ol0003oooooo`00001]ooooo`03o`000?oooooo0000053ooooo000Mooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooool00000KOooool00ol0003oooooo`00001@ooooo`007Oooool0
0ol0003oooooooooo`0mooooo`;o0000Koooool2o`00053ooooo000Mooooo`;o0000?oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo04oooooo000Mooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1?ooooo`007Oooool00ol0003ooooo
ooooo`3oooooo`7ooooo000Mooooo`03o`000?oooooooooo0?oooooo0Oooool001gooooo00?o0000
ooooooooool0ooooool1ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00Hooo
ool3o`00057ooooo0ol0001Vooooo`00I?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo06Gooooo000iooooo`?o00001?ooool3o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o00000_ooool3o`0000Cooooo0ol00003
ooooo`Co00000_ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_oo
ool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l00002ooooo`Go00000ooo
ool2o`0000Cooooo00?o0000ooooooooool01oooool3o`0000Gooooo0_l000000ooooooo0000o`00
0002o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o0000
0_ooool3o`000003ooooool0003o000002gooooo000jooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00Co
0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0002kooooo000jooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool5o`0000;ooooo0ol00002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0/ooooo`00>_ooool3o`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0:ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`;o00000oooool01ol0
003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooooooo
o`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000002Oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0/ooooo`00>_oo
ool01?l0003oooooooooool00002ooooo`?o00000_ooool3o`0000?ooooo1?l00002ooooo`Co0000
2Oooool00ol0003oooooooooo`02ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo
0ol00003ooooo`;o00001?ooool3o`0000[ooooo00Co0000oooooooooooooooo1?l00002ooooo`Co
00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0003o00000oooool4o`00
00;ooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oooooooooo00;ooooo0_l000001?oo
oooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co00000_ooool3o`0000Cooooo0ol00002
ooooo`Co0000;oooool003[ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`09
ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
ool0000Dooooo`03o`000?oooooooooo047ooooo000iooooo`Co00002_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo0ol0000Kooooo`;o00002?ooool5o`0000Sooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo1Ol0
000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0491415, -360.465, \
0.000327239, 29.6414}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["GPSF[opticalsystem,NumberOfRays->512];", "Input",
  CellLabel->"In[130]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 18.8363 0.0135294 8.76077e-05 [
[.12327 .00103 -15 -9 ]
[.12327 .00103 15 0 ]
[.31164 .00103 -15 -9 ]
[.31164 .00103 15 0 ]
[.68836 .00103 -12 -9 ]
[.68836 .00103 12 0 ]
[.87673 .00103 -12 -9 ]
[.87673 .00103 12 0 ]
[.4875 .10114 -24 -4.5 ]
[.4875 .10114 0 4.5 ]
[.4875 .18874 -24 -4.5 ]
[.4875 .18874 0 4.5 ]
[.4875 .27635 -24 -4.5 ]
[.4875 .27635 0 4.5 ]
[.4875 .36396 -24 -4.5 ]
[.4875 .36396 0 4.5 ]
[.4875 .45157 -24 -4.5 ]
[.4875 .45157 0 4.5 ]
[.4875 .53918 -24 -4.5 ]
[.4875 .53918 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12327 .01353 m
.12327 .01978 L
s
[(-0.02)] .12327 .00103 0 1 Mshowa
.31164 .01353 m
.31164 .01978 L
s
[(-0.01)] .31164 .00103 0 1 Mshowa
.68836 .01353 m
.68836 .01978 L
s
[(0.01)] .68836 .00103 0 1 Mshowa
.87673 .01353 m
.87673 .01978 L
s
[(0.02)] .87673 .00103 0 1 Mshowa
.125 Mabswid
.16095 .01353 m
.16095 .01728 L
s
.19862 .01353 m
.19862 .01728 L
s
.23629 .01353 m
.23629 .01728 L
s
.27396 .01353 m
.27396 .01728 L
s
.34931 .01353 m
.34931 .01728 L
s
.38698 .01353 m
.38698 .01728 L
s
.42465 .01353 m
.42465 .01728 L
s
.46233 .01353 m
.46233 .01728 L
s
.53767 .01353 m
.53767 .01728 L
s
.57535 .01353 m
.57535 .01728 L
s
.61302 .01353 m
.61302 .01728 L
s
.65069 .01353 m
.65069 .01728 L
s
.72604 .01353 m
.72604 .01728 L
s
.76371 .01353 m
.76371 .01728 L
s
.80138 .01353 m
.80138 .01728 L
s
.83905 .01353 m
.83905 .01728 L
s
.0856 .01353 m
.0856 .01728 L
s
.04793 .01353 m
.04793 .01728 L
s
.01026 .01353 m
.01026 .01728 L
s
.9144 .01353 m
.9144 .01728 L
s
.95207 .01353 m
.95207 .01728 L
s
.98974 .01353 m
.98974 .01728 L
s
.25 Mabswid
0 .01353 m
1 .01353 L
s
.5 .10114 m
.50625 .10114 L
s
[(1000)] .4875 .10114 1 0 Mshowa
.5 .18874 m
.50625 .18874 L
s
[(2000)] .4875 .18874 1 0 Mshowa
.5 .27635 m
.50625 .27635 L
s
[(3000)] .4875 .27635 1 0 Mshowa
.5 .36396 m
.50625 .36396 L
s
[(4000)] .4875 .36396 1 0 Mshowa
.5 .45157 m
.50625 .45157 L
s
[(5000)] .4875 .45157 1 0 Mshowa
.5 .53918 m
.50625 .53918 L
s
[(6000)] .4875 .53918 1 0 Mshowa
.125 Mabswid
.5 .03105 m
.50375 .03105 L
s
.5 .04857 m
.50375 .04857 L
s
.5 .06609 m
.50375 .06609 L
s
.5 .08362 m
.50375 .08362 L
s
.5 .11866 m
.50375 .11866 L
s
.5 .13618 m
.50375 .13618 L
s
.5 .1537 m
.50375 .1537 L
s
.5 .17122 m
.50375 .17122 L
s
.5 .20627 m
.50375 .20627 L
s
.5 .22379 m
.50375 .22379 L
s
.5 .24131 m
.50375 .24131 L
s
.5 .25883 m
.50375 .25883 L
s
.5 .29387 m
.50375 .29387 L
s
.5 .3114 m
.50375 .3114 L
s
.5 .32892 m
.50375 .32892 L
s
.5 .34644 m
.50375 .34644 L
s
.5 .38148 m
.50375 .38148 L
s
.5 .399 m
.50375 .399 L
s
.5 .41652 m
.50375 .41652 L
s
.5 .43405 m
.50375 .43405 L
s
.5 .46909 m
.50375 .46909 L
s
.5 .48661 m
.50375 .48661 L
s
.5 .50413 m
.50375 .50413 L
s
.5 .52165 m
.50375 .52165 L
s
.5 .5567 m
.50375 .5567 L
s
.5 .57422 m
.50375 .57422 L
s
.5 .59174 m
.50375 .59174 L
s
.5 .60926 m
.50375 .60926 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Geometric Point Spread Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.04759 .02913 L
.05356 .03375 L
.05685 .03579 L
.05996 .03731 L
.06172 .038 L
.06363 .03863 L
.06698 .03944 L
.06863 .03974 L
.07038 .03999 L
.07201 .04017 L
.07351 .04031 L
.0764 .04051 L
.0795 .04067 L
.08237 .04078 L
.0851 .04086 L
.09787 .0412 L
.12137 .04182 L
.14638 .04252 L
.17046 .04323 L
.17679 .04343 L
.18012 .04353 L
.18194 .04359 L
.18283 .04362 L
.18364 .04364 L
.1844 .04368 L
.18513 .04371 L
.18672 .04379 L
.18848 .04389 L
.1901 .04401 L
.19148 .04415 L
.19295 .04433 L
.19443 .04458 L
.19605 .04497 L
.1975 .04545 L
.19908 .04617 L
.20073 .04723 L
.20226 .0486 L
.2037 .05032 L
.20502 .05236 L
.20653 .05542 L
.20796 .05914 L
.20951 .06435 L
.21116 .07143 L
.21412 .08917 L
.21576 .1024 L
.21729 .11729 L
.22079 .16116 L
.22386 .21141 L
.2272 .27745 L
Mistroke
.23328 .41319 L
.2361 .47354 L
.23915 .52947 L
.24056 .55061 L
.24204 .56926 L
.2433 .58202 L
.24468 .59256 L
.24552 .59716 L
.24627 .60022 L
.24669 .60146 L
.24715 .60245 L
.24758 .60305 L
.24798 .60332 L
.24869 .60314 L
.24947 .602 L
.24986 .60107 L
.25028 .59982 L
.25105 .59692 L
.25252 .58926 L
.25406 .57868 L
.25681 .55505 L
.26306 .49247 L
.26973 .43236 L
.27611 .3896 L
.2819 .36158 L
.28772 .3404 L
.29321 .32466 L
.30555 .2983 L
.31691 .28078 L
.32848 .26704 L
.3412 .25518 L
.35419 .24555 L
.36605 .23839 L
.38998 .22742 L
.40171 .22332 L
.41448 .21963 L
.42639 .2168 L
.43955 .21428 L
.452 .21242 L
.4637 .2111 L
.46974 .21056 L
.4761 .21011 L
.48154 .20981 L
.48439 .20969 L
.48748 .20958 L
.49073 .20948 L
.49222 .20945 L
.4938 .20942 L
.49522 .2094 L
.49603 .20939 L
Mistroke
.49678 .20939 L
.49746 .20938 L
.49811 .20938 L
.49886 .20937 L
.49954 .20937 L
.50035 .20937 L
.50109 .20937 L
.50149 .20938 L
.50194 .20938 L
.50273 .20938 L
.50349 .20939 L
.50428 .20939 L
.50496 .2094 L
.5057 .20942 L
.50736 .20944 L
.50916 .20948 L
.51243 .20957 L
.51569 .20969 L
.51871 .20982 L
.52444 .21015 L
.53068 .2106 L
.53731 .21119 L
.54931 .21259 L
.56056 .21429 L
.58438 .21933 L
.59672 .22283 L
.60971 .22729 L
.63317 .23797 L
.64525 .24518 L
.65814 .25464 L
.67129 .2668 L
.68369 .28161 L
.69602 .30115 L
.70738 .3262 L
.71335 .3439 L
.71893 .36511 L
.72506 .39638 L
.73164 .44343 L
.73753 .49839 L
.7438 .5607 L
.74566 .5765 L
.74741 .5888 L
.74817 .59318 L
.74898 .59704 L
.7494 .59872 L
.74986 .60029 L
.75068 .60228 L
.7511 .60293 L
.75151 .60327 L
.75227 .60318 L
Mistroke
.75269 .60271 L
.75309 .60198 L
.75352 .60088 L
.75398 .59933 L
.75473 .59594 L
.75544 .59179 L
.75705 .5788 L
.75856 .56224 L
.76021 .53953 L
.76321 .48725 L
.76884 .3654 L
.7755 .22341 L
.77864 .16969 L
.78153 .13044 L
.78452 .09996 L
.7861 .08765 L
.78776 .07709 L
.79056 .06408 L
.79215 .05884 L
.79363 .05505 L
.7953 .05182 L
.79689 .04955 L
.79831 .04804 L
.79986 .04681 L
.80154 .04586 L
.80239 .04549 L
.80333 .04516 L
.80498 .04471 L
.80654 .04441 L
.80803 .0442 L
.80942 .04406 L
.81095 .04393 L
.81258 .04383 L
.8143 .04374 L
.81592 .04367 L
.81895 .04356 L
.83034 .04321 L
.854 .04251 L
.87917 .0418 L
.89169 .04147 L
.90341 .04117 L
.91465 .04087 L
.91788 .04077 L
.92096 .04065 L
.92371 .04051 L
.92672 .04029 L
.9283 .04014 L
.93 .03994 L
.9315 .03972 L
.93308 .03943 L
Mistroke
.93609 .03871 L
.93885 .03779 L
.94203 .03638 L
.945 .03469 L
.95176 .02968 L
.95766 .02465 L
.96077 .02213 L
.96407 .01976 L
.96695 .01803 L
.97013 .01653 L
.97302 .0155 L
.97573 .01481 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[130]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol0000Joooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0004Wooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00006oooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000;ooooo1Ol0000Wooooo`00:?ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Aoooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool06Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00009oooool0027ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`0Booooo`Go00000_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Aoooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool06Oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool09oooool0
02Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo01Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo04Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo02Kooooo000Xooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo01Oooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04Oooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Wo
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool09Oooool002Sooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool05oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo0_l00019ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool2o`0001_ooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool09Oooool002Wooooo0_l0000:oooo
o`;o00000oooool3o`0001_ooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`18oooo
o`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool06_ooool2o`0000[ooooo0_l00003oooo
o`?o0000:?ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0
S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool0
017ooooooOl0000Booooo`004oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_l00005ooooo`03o`000?oooooooooo01;ooooo000Jooooo`;o0000Loooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo01[ooooo000Looooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0L?ooool2o`0001cooooo000Mooooo`03o`000?oooooooooo06oooooo0_l0
001_ooooo`;o00007_ooool001kooooo0_l0001_ooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool07_ooool0023ooooo1?l0001[ooooo`03o`000?oooooooooo06Wooooo1?l0000Qoooo
o`009?oooolNo`0004gooooo00?o0000ooooooooool0BooooolNo`0002Gooooo0012ooooo`;o0000
Boooool00ol0003oooooooooo`18ooooo`?o0000@oooool004Cooooo00?o0000ooooooooool0B?oo
ool2o`0004Wooooo00?o0000ooooooooool0@oooool004Gooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo04Cooooo0015ooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`14ooooo`00AOooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool004Kooooo
00?o0000ooooooooool0A_ooool2o`0004Oooooo00?o0000ooooooooool0AOooool004Kooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Gooooo0016
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15
ooooo`00A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0AOooool004Oooooo00?o0000ooooooooool0AOooool2o`0004Oooooo00?o0000oooooooo
ool0AOooool004Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo04Kooooo0017ooooo`03o`000?oooooooooo02_ooooo0ol00004ooooo`;o00001?oo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0A_oo
ool004Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0A_ooool004Oooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0A_ooool004Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`?o0000AOooool00ol0003oooooooooo`16ooooo`00Aoooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`16ooooo`00Aoooool00ol0003oooooooooo`0[ooooo`;o00001?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Kooooo0018ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Kooooo0018ooooo`03o`000?oooooooooo
04Cooooo0_l00015ooooo`03o`000?oooooooooo04Oooooo0018ooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`17ooooo`00B?ooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Aoooool004Sooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Oooooo0018
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`17
ooooo`00B?ooool00ol0003oooooooooo`14ooooo`;o0000AOooool00ol0003oooooooooo`17oooo
o`00BOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool0Aoooool004Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo04Oooooo0019ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`17ooooo`00BOooool00ol0003oooooooooo`13ooooo`;o0000A?ooool0
0ol0003oooooooooo`18ooooo`00BOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo04Sooooo0019ooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`18ooooo`00BOooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000
ooooooooool0@oooool2o`0004Cooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000oooo
ooooool0:?ooool5o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`18ooooo`00BOooool00ol0003oooooooooo`0Yooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`18ooooo`00BOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`18ooooo`00BOooool00ol0003o
ooooooooo`0[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool3o`0004?ooooo00?o
0000ooooooooool0B?ooool004Wooooo00?o0000ooooooooool0:?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`18oooo
o`00BOooool00ol0003oooooooooo`0Xooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04Sooooo0019ooooo`03o`000?oo
oooooooo02Wooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000ooooooooool0@oooool2
o`0004Cooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000ooooooooool0>ooooolAo`00
03gooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000ooooooooool0<_ooool9o`0000So
oooo00?o0000ooooooooool01_ooool9o`0003Cooooo00?o0000ooooooooool0B?ooool004Wooooo
00?o0000ooooooooool0;oooool3o`00017ooooo00?o0000ooooooooool03oooool3o`00037ooooo
00?o0000ooooooooool0B?ooool004Wooooo00?o0000ooooooooool0;?ooool3o`0001Cooooo00?o
0000ooooooooool04_ooool3o`0002kooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000
ooooooooool0:Oooool3o`0001Oooooo0_l0000Fooooo`?o0000:oooool00ol0003oooooooooo`18
ooooo`00BOooool00ol0003oooooooooo`0Vooooo`?o00006_ooool00ol0003oooooooooo`0Hoooo
o`Co00009oooool00ol0003oooooooooo`18ooooo`00BOooool00ol0003oooooooooo`0Sooooo`?o
00007Oooool00ol0003oooooooooo`0Looooo`?o00009?ooool00ol0003oooooooooo`18ooooo`00
BOooool00ol0003oooooooooo`0Pooooo`?o00008?ooool00ol0003oooooooooo`0Oooooo`;o0000
8_ooool00ol0003oooooooooo`18ooooo`00BOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo027ooooo0_l0000Rooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0B?oo
ool004Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`18ooooo`00B_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo04Sooooo001:ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0B?ooool004[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`18ooooo`00B_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Kooooo0_l0
000Wooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0B?ooool004[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`19ooooo`00B_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00kooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19oooo
o`00B_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00kooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`19ooooo`00B_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool3o`0002[ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`19ooooo`00B_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`00B_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool004[ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0BOooool004[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0C
ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`0002kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`19ooooo`00B_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo04Wooooo001:ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0BOooool004[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`19ooooo`00B_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Wooooo001:ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0;oooool2o`00033ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`19ooooo`00Boooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
04Wooooo001;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0BOooool004_ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`00Boooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo037ooooo0_l0000booooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0BOooool004_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`19
ooooo`00Boooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04[ooooo001;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0B_ooool004_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1:ooooo`00Boooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03?ooooo0_l0000dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0B_oo
ool004_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1:ooooo`00Boooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo0ol00003ooooo`;o00001?ooool2o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1:ooooo`00Boooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01co
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1:ooooo`00Boooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Wooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`?o0000=?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo04[ooooo001;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool06Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1:ooooo`00Boooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool000000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0B_ooool004_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Looooo`;o0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0B_ooool004_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04[ooooo001<ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Oooool2o`0003Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1:ooooo`00C?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo04[ooooo001<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B_oo
ool004cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1:ooooo`00C?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo0_l0000gooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Boooool004cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1;ooooo`00C?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo
001<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Boooool004cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0gooooo`;o0000=oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04_ooooo001<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Boooool004cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1;ooooo`00
C?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04_ooooo001<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Boooool004cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0gooooo`;o0000>?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04_ooooo001<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Boooool004co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`?o00001?ooool2o`0000Co
oooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Boooool004cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Looooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Boooool004cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo0ol0000gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Boooool004cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04_ooooo001<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool4o`00
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo04cooooo001<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1<ooooo`00C?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01gooooo1Ol00003ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<ooooo`00
C?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo0_l0000iooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool004cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1<ooooo`00C?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo04cooooo001<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool004co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0iooooo`;o0000>_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04cooooo001<ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0C?ooool004cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1<ooooo`00C?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo001<oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C?ooool004gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0iooooo`;o0000>_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04cooooo001=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
C?ooool004gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`00COooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04cooooo001=ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0>Oooool2o`0003_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1<ooooo`00COooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04co
oooo001=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool3o`0000Cooooo
0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04cooooo001=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool07oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04cooooo001=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo0ol0000jooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0C?ooool004gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`Co0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0C?ooool004gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04cooooo001=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00Go0000ooooooooooooooooo`00001>ooooo`00COooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo027ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000Coooool004gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0jooooo`;o0000??ooool01?l0003oooooooooool0001?
ooooo`00C_ooool01Ol0003ooooooooooooooooo000003cooooo00?o0000ooooooooool0>oooool0
1?l0003oooooooooool0001?ooooo`00C_ooool01Ol0003ooooooooooooooooo000003cooooo00?o
0000ooooooooool0>oooool01?l0003oooooooooool0001?ooooo`00C_ooool01?l0003ooooooooo
ool0000mooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000Coooool004kooooo
00Co0000oooooooooooo0000?Oooool2o`0003cooooo00Co0000oooooooooooo0000Coooool004ko
oooo00Co0000oooooooooooo0000?Oooool00ol0003oooooooooo`0kooooo`04o`000?oooooooooo
o`0004oooooo001>ooooo`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0>oooool0
1?l0003oooooooooool0001?ooooo`00C_ooool01?l0003oooooooooool0000mooooo`03o`000?oo
oooooooo03_ooooo00Co0000oooooooooooo0000Coooool004oooooo00?o0000ooooool00000?Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooo0000053ooooo001?ooooo`03o`000?oooooo
000003gooooo0_l0000mooooo`;o0000D?ooool004oooooo0_l0000nooooo`03o`000?oooooooooo
03cooooo0_l0001@ooooo`00Coooool2o`0003kooooo00?o0000ooooooooool0??ooool2o`00053o
oooo001?ooooo`;o0000?_ooool00ol0003oooooooooo`0looooo`;o0000D?ooool008oooooo0_l0
002?ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>oooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00V?ooool3o`0008Gooooo002Ioooo
o`03o`000?oooooooooo08Cooooo000cooooo`?o00000oooool3o`0000?ooooo0ol00002ooooo`05
o`000?oooooo0000ooooool000000_ooool3o`0000Cooooo0_l00002ooooo`?o00000oooool5o`00
00;ooooo0ol00008ooooo`?o00001?ooool3o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o00000_ooool3o`0000Cooooo0ol00003
ooooo`Co00000_ooool4o`0000Oooooo0ol00005ooooo`;o000000?oooooo`000?l000000_l00000
1?oooooo0000o`000?ooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000;ooooo0ol0
00000ooooooo0000o`00000dooooo`00<_ooool01ol0003ooooooooooooooooo0000ooooool00000
1Oooool03Ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo0000ooooool00000
1_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0
003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo0000=Oooool003;ooooo00Ko0000oooooooooooo
ooooo`000?ooool5o`000003ooooool0003ooooo00;ooooo00So0000ooooool0003oooooo`000?oo
oooo0000ooooo`Go00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool5o`0000;ooooo0ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo03?ooooo000booooo`03o`000?oooooo000000Co0000
0oooool00ol0003oooooo`000003ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo
000000?ooooo00Co0000oooooooooooo00001Oooool2o`0000Gooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Kooooo0ol00002ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool02_ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`07ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01?l0003oooooooooool00006ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo03?ooooo000booooo`03
o`000?oooooooooo00Cooooo0ol00003ooooo`?o00000_ooool2o`000003ooooool0003ooooo00;o
oooo0ol00002ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`?o00001?ooool3o`00
00Wooooo00Co0000oooooooooooo00000_ooool3o`0000;ooooo0ol00003ooooo`Co00000_ooool4
o`0000Wooooo00?o0000ooooooooool00_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`?o00000oooool2o`0000Cooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo0_l00000
1?oooooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co00000_ooool3o`0000Cooooo0ol0
0002ooooo`Co0000=_ooool003;ooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oo
oooooooo01_ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`0001cooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0000Doooo
o`03o`000?oooooooooo04Sooooo000cooooo`?o00006oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00gooooo1?l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool3o`0001_ooooo0_l00008ooooo`Go00005?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo047ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0301738, -549.598, \
0.00021027, 45.2097}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.3", "AOG2."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inverse Position", "Subsubsection",
  CellTags->{"AOG0.", "2.3.3", "AOG2.", "AOG2.3", "AOG2.3.3"}],

Cell[CellGroupData[{

Cell["\<\
symbolicy = (SymbolicSurfaceCoordinates/.SymbolicTrace[opticalsystem, 
\t{{y,0,5},{y\[Element]Reals,d\[Element]Reals}}, \
ReportedParameters->SymbolicSurfaceCoordinates])[[1]]\
\>", "Input",
  CellLabel->"In[131]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],

Cell[BoxData[
    \(0.0088364155326911`\ y - 0.02376778501234205`\ d\ y - 
      0.0005252504582623431`\ y\^3 - 0.000020208680803274196`\ d\ y\^3 - 
      7.261063197351916`*^-7\ y\^5 - 
      2.7313719833446508`*^-8\ d\ y\^5\)], "Output",
  CellLabel->"Out[131]=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["oplot = Plot[symbolicy/.{d->0},{y,-5, 5}];", "Input",
  CellLabel->"In[132]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 12.3952 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 .06111 -30 -4.5 ]
[.4875 .06111 0 4.5 ]
[.4875 .18507 -30 -4.5 ]
[.4875 .18507 0 4.5 ]
[.4875 .43297 -24 -4.5 ]
[.4875 .43297 0 4.5 ]
[.4875 .55692 -24 -4.5 ]
[.4875 .55692 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .06111 m
.50625 .06111 L
s
[(-0.02)] .4875 .06111 1 0 Mshowa
.5 .18507 m
.50625 .18507 L
s
[(-0.01)] .4875 .18507 1 0 Mshowa
.5 .43297 m
.50625 .43297 L
s
[(0.01)] .4875 .43297 1 0 Mshowa
.5 .55692 m
.50625 .55692 L
s
[(0.02)] .4875 .55692 1 0 Mshowa
.125 Mabswid
.5 .0859 m
.50375 .0859 L
s
.5 .11069 m
.50375 .11069 L
s
.5 .13548 m
.50375 .13548 L
s
.5 .16028 m
.50375 .16028 L
s
.5 .20986 m
.50375 .20986 L
s
.5 .23465 m
.50375 .23465 L
s
.5 .25944 m
.50375 .25944 L
s
.5 .28423 m
.50375 .28423 L
s
.5 .33381 m
.50375 .33381 L
s
.5 .3586 m
.50375 .3586 L
s
.5 .38339 m
.50375 .38339 L
s
.5 .40818 m
.50375 .40818 L
s
.5 .45776 m
.50375 .45776 L
s
.5 .48255 m
.50375 .48255 L
s
.5 .50734 m
.50375 .50734 L
s
.5 .53213 m
.50375 .53213 L
s
.5 .03632 m
.50375 .03632 L
s
.5 .01153 m
.50375 .01153 L
s
.5 .58171 m
.50375 .58171 L
s
.5 .6065 m
.50375 .6065 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .4556 L
.10458 .33134 L
.12507 .28357 L
.14415 .24594 L
.16371 .21383 L
.18221 .18915 L
.20262 .16789 L
.2212 .15365 L
.2309 .14803 L
.24117 .14337 L
.24995 .1404 L
.25494 .13912 L
.25962 .13817 L
.26458 .13744 L
.26739 .13714 L
.26873 .13703 L
.27 .13694 L
.2712 .13688 L
.2725 .13682 L
.27368 .13679 L
.27477 .13677 L
.27595 .13676 L
.27725 .13677 L
.2779 .13678 L
.2786 .1368 L
.27986 .13684 L
.2811 .1369 L
.28225 .13697 L
.28484 .13717 L
.28712 .13741 L
.28955 .13771 L
.29375 .13837 L
.29839 .1393 L
.30848 .142 L
.31773 .14527 L
.33859 .15521 L
.35751 .16702 L
.37821 .1826 L
.41878 .21965 L
.45782 .26107 L
.49932 .30823 L
.5393 .35376 L
.57777 .3949 L
.61869 .43288 L
.63904 .4486 L
.65809 .46094 L
.67635 .4703 L
.68661 .47439 L
.69598 .47734 L
Mistroke
.70076 .47854 L
.70585 .47959 L
.71065 .48035 L
.71277 .48062 L
.715 .48085 L
.71628 .48096 L
.71768 .48106 L
.71896 .48114 L
.72014 .48119 L
.7208 .48122 L
.72152 .48124 L
.72228 .48125 L
.72301 .48127 L
.72368 .48127 L
.7244 .48127 L
.72568 .48126 L
.72687 .48123 L
.72815 .48119 L
.72936 .48113 L
.73047 .48106 L
.73303 .48085 L
.73574 .48056 L
.74075 .47979 L
.74531 .47886 L
.75552 .47589 L
.76498 .47203 L
.7739 .46738 L
.79395 .45312 L
.81242 .43507 L
.83122 .4115 L
.85187 .37914 L
.89226 .29457 L
.93114 .18374 L
.97247 .03045 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[132]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oSoooool0
0ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003o
ooooooooo`2>ooooo`00Soooool2o`0008oooooo002?ooooo`03o`000?oooooooooo08Gooooo00?o
0000ooooooooool01_ooool008oooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`06
ooooo`00Soooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Kooooo002?ooooo`03
o`000?oooooooooo08Cooooo00?o0000ooooooooool01oooool008oooooo00?o0000ooooooooool0
Q?ooool00ol0003oooooooooo`07ooooo`00Soooool00ol0003oooooooooo`24ooooo`03o`000?oo
oooooooo00Oooooo002?ooooo`;o0000QOooool00ol0003oooooooooo`07ooooo`00Soooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo00Sooooo002?ooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool02?ooool008oooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`08ooooo`00Soooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Wooooo001e
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000Gooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`09ooooo`00M?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooooooo00Wooooo001]ooooo`Go00000_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool3o`0008;o
oooo00?o0000ooooooooool02Oooool007Cooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0POooool00ol0
003oooooooooo`0:ooooo`00M?ooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool02_ooool007Cooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`21ooooo`03
o`000?oooooooooo00[ooooo001eooooo`;o00002_ooool2o`0000?ooooo0ol00006ooooo`03o`00
0?oooooooooo087ooooo00?o0000ooooooooool02_ooool008oooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`0;ooooo`00Soooool00ol0003oooooooooo`20ooooo`03o`000?oooooo
oooo00_ooooo002?ooooo`;o0000POooool00ol0003oooooooooo`0;ooooo`00Soooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo00cooooo002?ooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool03?ooool008oooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`0<ooooo`00Soooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00cooooo002?oooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool03Oooool008oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`0=ooooo`00Soooool2o`0007oooooo00?o0000ooooooooool0
3Oooool008oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0=ooooo`00Soooool0
0ol0003oooooooooo`1mooooo`03o`000?oooooooooo00kooooo002?ooooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool03_ooool008oooooo00?o0000ooooooooool0OOooool00ol0003o
ooooooooo`0>ooooo`00Soooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00oooooo
002?ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool03oooool008oooooo0_l0001m
ooooo`03o`000?oooooooooo00oooooo0018oooooa3o0000=oooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo00oooooo0016ooooo`;o00004?ooool3o`0003Cooooo00?o0000oooooooo
ool0Noooool00ol0003oooooooooo`0@ooooo`00A?ooool2o`0001Gooooo0_l0000booooo`03o`00
0?oooooooooo07_ooooo00?o0000ooooooooool04?ooool0047ooooo0ol0000Iooooo`;o0000<?oo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo013ooooo0010ooooo`03o`000?oooooo
oooo01cooooo0_l0000^ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool04?ooool0
03kooooo0_l0000Qooooo`;o0000;?ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo
017ooooo000mooooo`03o`000?oooooooooo02?ooooo0_l0000Zooooo`;o0000Noooool00ol0003o
ooooooooo`0Aooooo`00??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Aooooo`00>oooool00ol0003ooooooooo
o`0Xooooo`;o00009oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo01;ooooo000j
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooooooo01;ooooo000iooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo01;ooooo000hooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool02?ooool2o`0000Cooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo0ol00006ooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool04_ooool003Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`06ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo07Sooooo00?o0000ooooooooool04oooool003Kooooo00?o0000oooooooo
ool0<oooool6o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0C
ooooo`00=Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo0ol0
001hooooo`03o`000?oooooooooo01?ooooo000dooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo01Cooooo
000dooooo`03o`000?oooooooooo03Wooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00Kooooo00Co0000oooooooooooo00000_ooool2o`0000Oooooo00?o0000oooooooo
ool0Moooool00ol0003oooooooooo`0Dooooo`00<oooool00ol0003oooooooooo`0kooooo`04o`00
0?ooooooooooooooo`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1gooooo`03o`000?oooooooooo01Cooooo000booooo`03o`000?oooooooooo03gooooo
0_l0000Kooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool0037ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo07Kooooo00?o
0000ooooooooool05Oooool0037ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool0033ooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Fooooo`;o0000M_ooool00ol0003oooooooooo`0Foooo
o`00;oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0MOooool00ol0003oooooooooo`0Fooooo`00;oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0Fooooo`00;_oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0M?oo
ool00ol0003oooooooooo`0Gooooo`00;Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0Gooooo`00;Oooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`0Gooooo`00;?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Hooooo`00:oooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo013ooooo0_l0001dooooo`03o`000?oooooooooo01Sooooo
000[ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01Wooooo000Yoooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo01Wooooo000Yooooo`03o`000?oooooooooo05Cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01Wooooo000Xooooo`03o`00
0?oooooooooo05Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo01[ooooo000Xooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo01[ooooo000Wooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool02Oooool2o`0007;ooooo00?o0000ooooooooool06_ooool0
02Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool06oooool002Cooooo0ol0000aooooo`Go00009oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo037ooooo1Ol0000cooooo`?o00001?ooool00ol0003o
ooooooooo`0Kooooo`009Oooool2o`0003;ooooo00Co0000oooooooooooo0000:?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo0000=?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo000Looooo`Go000000?oooooo`000?l0
00000ol0000[ooooo`Go00000oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0aooooo`Go00000oooool00ol0003o
ooooooooo`0Looooo`008_ooool01?l0003oooooooooool0000eooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo033o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Looooo`008oooool00ol0003o
ooooo`00000booooo`05o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo037ooooo00Go0000ooooooooooooooooo`00000booooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool07?ooool002Cooooo0_l0000booooo`05o`000?oooooooooo
ooooool00000;?ooool00ol0003oooooooooo`03ooooo`;o0000<_ooool01Ol0003ooooooooooooo
oooo000003?ooooo0_l00003ooooo`03o`000?oooooooooo01gooooo000Tooooo`;o0000<oooool3
o`0002gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0booooo`?o0000=Oooool0
1Ol0003ooooooooooooooooo000001oooooo000Sooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01gooooo000Soooo
o`03o`000?oooooooooo06Gooooo00Go0000ooooooooooooooooo`00001_ooooo`03o`000?oooooo
oooo01kooooo000Rooooo`03o`000?oooooooooo06Oooooo00Co0000oooooooooooo0000Koooool0
0ol0003oooooooooo`0Nooooo`008_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo0000
06kooooo00?o0000ooooooooool07oooool0027ooooo00?o0000ooooooooool0J_ooool2o`0006ko
oooo00?o0000ooooooooool07oooool00?oo00008?l00001ooooo`001oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`;o00003?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo000Pooooo`03o`000?oooooo000003Gooooo00?o0000
ooooooooool0=?ooool2o`0003Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Q
ooooo`008?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo000006[ooooo00?o0000oooo
ooooool08Oooool001oooooo00?o0000ooooooooool0KOooool01?l0003oooooooooool0001Yoooo
o`03o`000?oooooooooo027ooooo000Oooooo`03o`000?oooooooooo06gooooo00Go0000oooooooo
ooooooooo`00001Wooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02;o
oooo000Nooooo`03o`000?oooooooooo06kooooo0_l00004ooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool08oooool001gooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool08oooool001gooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool09?ooool001gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo05oooooo00?o0000ooooooooool09?ooool001cooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool09Oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool09Oooool001cooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool09_oo
ool001_ooooo00?o0000ooooooooool0LOooool2o`0000Wooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`0Vooooo`006oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Vooooo`006oooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`0Wooooo`006_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Wooooo`006_ooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`0Xooooo`006_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0Doooool00ol0003oooooooooo`0Xooooo`006Oooool00ol0003oooooooooo`1coooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Yoooo
o`006Oooool00ol0003oooooooooo`1cooooo`;o00004?ooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo02Wooooo000Iooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02[ooooo000Hooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo02_ooooo000Hooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02_ooooo000Hooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool04oooool2o`0004[ooooo00?o0000ooooooooool0;?ooool001Oo
oooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool0;Oooool001Oooooo00?o0000ooooooooool0MOooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0;Oooool001Oooooo00?o
0000ooooooooool0MOooool2o`0001Sooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0^ooooo`005_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0_ooooo`005_ooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo01Wooooo0_l00011ooooo`03o`000?oooooooooo02oooooo000Fooooo`03
o`000?oooooooooo07Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo033ooooo000Eooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo037ooooo000Eooooo`03o`000?oo
oooooooo05gooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<_oo
ool001Gooooo00?o0000ooooooooool0G?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0<oooool001Cooooo00?o0000ooooooooool0GOoo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Oooooo`;o0000=_ooool00ol0003oooooooooo`0dooooo`00
5?ooool00ol0003oooooooooo`1Mooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`05ooooo`?o00008Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo03Gooooo000Dooooo`03o`000?oooooooooo05gooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03Kooooo000Coooo
o`03o`000?oooooooooo05kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`;o00001oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0=oooool001?ooooo00?o0000ooooooooool0Goooool2o`0000[ooooo0_l00004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo03Sooooo000Cooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool09Oooool2o`0002_ooooo00?o0000ooooooooool0>Oooool001;ooooo00?o0000oooooooo
ool0N_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo0_l0000looooo`00
4_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0looooo`004_ooool00ol0003oooooooooo`1jooooo`;o0000:_oo
ool00ol0003oooooooooo`0Qooooo`;o0000?oooool001;ooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0Zooooo`;o00008?ooool00ol0003oooooooooo`0oooooo`004Oooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo02cooooo0ol0000Looooo`03o`000?oooooooooo
043ooooo000Aooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0;oooool3o`0001So
oooo00?o0000ooooooooool0@Oooool0017ooooo00?o0000ooooooooool0Noooool00ol0003ooooo
ooooo`0booooo`?o00004oooool2o`0004Cooooo000Aooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`?o0000A_ooool0013ooooo00?o0000
ooooooooool0O?ooool00ol0003oooooooooo`0fooooo`oo0000BOooool0013ooooo00?o0000oooo
ooooool0O?ooool2o`0008oooooo000@ooooo`03o`000?oooooooooo07cooooo00?o0000oooooooo
ool0S_ooool0013ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`2>ooooo`003ooo
ool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo08kooooo000?ooooo`03o`000?oooooo
oooo07gooooo00?o0000ooooooooool0S_ooool000oooooo00?o0000ooooooooool0OOooool00ol0
003oooooooooo`2>ooooo`003_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo08ko
oooo000>ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`003_ooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo08kooooo000>ooooo`03o`000?oooooooooo07kooooo00?o0000
ooooooooool0S_ooool000gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`2>oooo
o`003Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08kooooo000=ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0S_ooool000gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`2>ooooo`003?ooool00ol0003oooooooooo`20ooooo`;o0000Soooool0
00cooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`2>ooooo`003?ooool00ol0003o
ooooooooo`20ooooo`03o`000?oooooooooo08kooooo000<ooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0S_ooool000_ooooo00?o0000ooooooooool0POooool00ol0003ooooooooo
o`2>ooooo`002oooool00ol0003oooooooooo`1Wooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00000_ooool5o`0000Gooooo00?o0000ooooooooool0S_ooool000_ooooo00?o0000oooo
ooooool0I_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`2>ooooo`002oooool00ol0003ooooooooo
o`1Vooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`05ooooo`?o0000S_ooool000[ooooo00?o0000ooooooooool0Ioooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2>ooooo`002_ooool00ol0003oooooooooo`1Wooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0S_ooool000[ooooo00?o0000ooooooooool0Ioooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo08kooooo0009ooooo`03o`000?oooooooooo06Wooooo0_l0000:ooooo`;o0000
0oooool3o`0000Kooooo00?o0000ooooooooool0S_ooool000Wooooo00?o0000ooooooooool0Pooo
ool00ol0003oooooooooo`2>ooooo`002Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo08kooooo0009ooooo`03o`000?oooooooooo08?ooooo0_l0002?ooooo`002?ooool00ol0003o
ooooooooo`24ooooo`03o`000?oooooooooo08kooooo0008ooooo`03o`000?oooooooooo08Cooooo
00?o0000ooooooooool0S_ooool000Sooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`2>ooooo`002?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo08kooooo0007oooo
o`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0S_ooool000Oooooo00?o0000oooooooo
ool0QOooool00ol0003oooooooooo`2>ooooo`00Soooool2o`0008oooooo002?ooooo`03o`000?oo
oooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo
08kooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.26302, -0.0249306, \
0.0366761, 0.0002818}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[dataplot,oplot];", "Input",
  CellLabel->"In[133]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 12.3465 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 .06209 -30 -4.5 ]
[.4875 .06209 0 4.5 ]
[.4875 .18555 -30 -4.5 ]
[.4875 .18555 0 4.5 ]
[.4875 .43248 -24 -4.5 ]
[.4875 .43248 0 4.5 ]
[.4875 .55595 -24 -4.5 ]
[.4875 .55595 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .06209 m
.50625 .06209 L
s
[(-0.02)] .4875 .06209 1 0 Mshowa
.5 .18555 m
.50625 .18555 L
s
[(-0.01)] .4875 .18555 1 0 Mshowa
.5 .43248 m
.50625 .43248 L
s
[(0.01)] .4875 .43248 1 0 Mshowa
.5 .55595 m
.50625 .55595 L
s
[(0.02)] .4875 .55595 1 0 Mshowa
.125 Mabswid
.5 .08678 m
.50375 .08678 L
s
.5 .11147 m
.50375 .11147 L
s
.5 .13617 m
.50375 .13617 L
s
.5 .16086 m
.50375 .16086 L
s
.5 .21025 m
.50375 .21025 L
s
.5 .23494 m
.50375 .23494 L
s
.5 .25963 m
.50375 .25963 L
s
.5 .28432 m
.50375 .28432 L
s
.5 .33371 m
.50375 .33371 L
s
.5 .3584 m
.50375 .3584 L
s
.5 .3831 m
.50375 .3831 L
s
.5 .40779 m
.50375 .40779 L
s
.5 .45717 m
.50375 .45717 L
s
.5 .48187 m
.50375 .48187 L
s
.5 .50656 m
.50375 .50656 L
s
.5 .53125 m
.50375 .53125 L
s
.5 .03739 m
.50375 .03739 L
s
.5 .0127 m
.50375 .0127 L
s
.5 .58064 m
.50375 .58064 L
s
.5 .60533 m
.50375 .60533 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .60332 Mdot
.07143 .42611 Mdot
.11905 .29708 Mdot
.16667 .21002 Mdot
.21429 .15903 Mdot
.2619 .13848 Mdot
.30952 .14299 Mdot
.35714 .16732 Mdot
.40476 .20641 Mdot
.45238 .25528 Mdot
.5 .30902 Mdot
.54762 .36276 Mdot
.59524 .41162 Mdot
.64286 .45071 Mdot
.69048 .47505 Mdot
.7381 .47955 Mdot
.78571 .45901 Mdot
.83333 .40802 Mdot
.88095 .32095 Mdot
.92857 .19192 Mdot
.97619 .01472 Mdot
.5 Mabswid
.02381 .60216 m
.06244 .45502 L
.10458 .33126 L
.12507 .28367 L
.14415 .24619 L
.16371 .21421 L
.18221 .18962 L
.20263 .16844 L
.2212 .15426 L
.2309 .14866 L
.24117 .14402 L
.24995 .14106 L
.25494 .13979 L
.25962 .13885 L
.26458 .13811 L
.26739 .13782 L
.26873 .13771 L
.27 .13762 L
.2712 .13755 L
.2725 .1375 L
.27368 .13746 L
.27477 .13745 L
.27595 .13744 L
.27725 .13745 L
.2779 .13746 L
.2786 .13748 L
.27986 .13752 L
.2811 .13758 L
.28225 .13765 L
.28484 .13785 L
.28712 .13808 L
.28955 .13838 L
.29375 .13904 L
.29839 .13997 L
.30848 .14266 L
.31773 .14591 L
.33859 .15581 L
.35751 .16758 L
.37821 .1831 L
.41878 .22 L
.45782 .26126 L
.49932 .30824 L
.5393 .35358 L
.57777 .39457 L
.61869 .4324 L
.63904 .44806 L
.65809 .46034 L
.67635 .46967 L
.68661 .47374 L
.69598 .47668 L
Mistroke
.70076 .47788 L
.70585 .47892 L
.71065 .47968 L
.71277 .47994 L
.715 .48017 L
.71628 .48028 L
.71768 .48038 L
.71896 .48046 L
.72014 .48051 L
.7208 .48054 L
.72152 .48056 L
.72228 .48058 L
.72301 .48059 L
.72368 .48059 L
.7244 .48059 L
.72568 .48058 L
.72687 .48056 L
.72815 .48051 L
.72936 .48045 L
.73047 .48038 L
.73303 .48018 L
.73574 .47988 L
.74075 .47912 L
.74531 .47819 L
.75552 .47524 L
.76498 .47139 L
.7739 .46676 L
.79395 .45256 L
.81242 .43458 L
.83122 .4111 L
.85187 .37887 L
.89226 .29463 L
.93114 .18423 L
.97247 .03155 L
.97619 .01587 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[133]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oSoooool0
0ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003o
ooooooooo`2>ooooo`00Soooool2o`0008Kooooo0_l00007ooooo`00Soooool00ol0003ooooooooo
o`25ooooo`;o00001oooool008oooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`06
ooooo`00Soooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Kooooo002?ooooo`03
o`000?oooooooooo08Cooooo00?o0000ooooooooool01oooool008oooooo00?o0000ooooooooool0
Q?ooool00ol0003oooooooooo`07ooooo`00Soooool00ol0003oooooooooo`24ooooo`03o`000?oo
oooooooo00Oooooo002?ooooo`;o0000QOooool00ol0003oooooooooo`07ooooo`00Soooool00ol0
003oooooooooo`24ooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool02?ooool008oooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`08ooooo`00Soooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00Sooooo001e
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000Gooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`09ooooo`00M?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooooooo00Wooooo001]ooooo`Go00000_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool3o`0008;o
oooo00?o0000ooooooooool02Oooool007Cooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`09ooooo`00M?ooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool02_ooool007Cooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`21ooooo`03
o`000?oooooooooo00[ooooo001eooooo`;o00002_ooool2o`0000?ooooo0ol00006ooooo`03o`00
0?oooooooooo087ooooo00?o0000ooooooooool02_ooool008oooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`0:ooooo`00Soooool00ol0003oooooooooo`20ooooo`03o`000?oooooo
oooo00_ooooo002?ooooo`;o0000POooool00ol0003oooooooooo`0;ooooo`00Soooool00ol0003o
ooooooooo`20ooooo`03o`000?oooooooooo00_ooooo002?ooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool03?ooool008oooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`0<ooooo`00Soooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00cooooo002?oooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool03?ooool008oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`0=ooooo`00Soooool2o`0007oooooo00?o0000ooooooooool0
3Oooool008oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0=ooooo`00Soooool0
0ol0003oooooooooo`1mooooo`03o`000?oooooooooo00kooooo002?ooooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool03_ooool008oooooo00?o0000ooooooooool0OOooool00ol0003o
ooooooooo`0>ooooo`00Soooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00kooooo
002?ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool03oooool008oooooo00?o0000
ooooooooool0O?ooool00ol0003oooooooooo`0?ooooo`00B_ooool;o`0003[ooooo0_l0001moooo
o`03o`000?oooooooooo00oooooo0016ooooo`Ko00002Oooool6o`0003Cooooo00?o0000oooooooo
ool0Noooool00ol0003oooooooooo`0@ooooo`00A?ooool2o`0001;ooooo0_l000000ooooooo0000
o`00000booooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool04?ooool0047ooooo0ol0
000Iooooo`;o0000<?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo013ooooo0010
ooooo`03o`000?oooooooooo01cooooo0_l0000^ooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool04?ooool003kooooo0_l0000Qooooo`;o0000;?ooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo017ooooo000mooooo`;o00009?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool04Oooool003cooooo0ol0000Uooooo`03o`00
0?oooooooooo02Sooooo0_l0001kooooo`03o`000?oooooooooo017ooooo000kooooo`03o`000?oo
oooooooo02Oooooo0_l0000Xooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool04Ooo
ool003[ooooo00?o0000ooooooooool0:?ooool3o`0002Oooooo00?o0000ooooooooool0NOooool0
0ol0003oooooooooo`0Booooo`00>Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Booooo`00>?ooool00ol0003o
ooooooooo`0^ooooo`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?o
oooo0ol00006ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool04_ooool003Oooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool04oooool003Kooooo00?o0000ooooooooool0<oooool6o`0000;o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Cooooo`00=Oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo0ol0001hooooo`03o`000?oo
oooooooo01?ooooo000dooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1gooooo`;o00005Oooool003Cooooo00?o0000ooooooooool0>Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool01?l0003ooooo
ooooool00002ooooo`;o00001oooool00ol0003oooooooooo`1gooooo`;o00005Oooool003?ooooo
00?o0000ooooooooool0>oooool01?l0003oooooooooooooool2o`0000[ooooo0_l00004ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0Dooooo`00
<_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`0Eooooo`00<Oooool00ol0003oooooooooo`0oooooo`;o00006_oo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo000_ooooo`?o0000@Oooool2
o`0001[ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`00;oooool2o`00
04Cooooo00?o0000ooooooooool05oooool2o`0007Kooooo00?o0000ooooooooool05_ooool002oo
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo07Go
oooo00?o0000ooooooooool05_ooool002oooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool05_ooool002kooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool05oooool002gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool05oooool002gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07Cooooo00?o0000oooo
ooooool05oooool002cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool06?ooool002_ooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0@ooooo`;o0000M?ooool00ol0003oooooooooo`0Hooooo`00:ooo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Iooooo`00:Oooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`0Iooooo`00:Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Iooooo`00:?ooool00ol0003ooooo
ooooo`1Fooooo`;o00003?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo01[ooooo
000Xooooo`03o`000?oooooooooo05Kooooo0_l0000<ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool06_ooool002Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`09
ooooo`;o0000L_ooool00ol0003oooooooooo`0Jooooo`009oooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Koooo
o`009?ooool3o`00037ooooo1Ol0000Wooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0<Oooool5o`0003?ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo000Uooooo`;o0000
<_ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0<_ooool01?l0003oooooooooool0000dooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06oooool001cooooo1Ol000000ooooooo0000o`000003o`0002_ooooo1Ol00003ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo037ooooo1Ol00003ooooo`03o`000?oooooooooo01cooooo000Rooooo`04o`00
0?ooooooooooo`0003Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo01cooooo000Sooooo`03o`000?oooooo000003;ooooo00Go0000oooooooo
ooooooooo`00000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool01Ol0
003ooooooooooooooooo000003;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`0L
ooooo`009?ooool2o`0003;ooooo00Go0000ooooooooooooooooo`00000/ooooo`03o`000?oooooo
oooo00?ooooo0_l0000booooo`05o`000?ooooooooooooooool00000<oooool2o`0000?ooooo00?o
0000ooooooooool07Oooool002Cooooo0_l0000cooooo`?o0000;Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03;ooooo0ol0000eooooo`05o`000?ooooooooooooooool000007ooo
ool002?ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool07Oooool0027ooooo0ol0001Wooooo`05o`000?oooooooooo
ooooool00000Koooool00ol0003oooooooooo`0Nooooo`008Oooool2o`0006Wooooo00Co0000oooo
oooooooo0000Koooool00ol0003oooooooooo`0Nooooo`008_ooool00ol0003oooooooooo`1Xoooo
o`03o`000?oooooo000006kooooo00?o0000ooooooooool07oooool0027ooooo00?o0000oooooooo
ool0J_ooool2o`0006kooooo00?o0000ooooooooool07oooool00?oo00008?l00001ooooo`001ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo0_l0000=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool0023ooooo00?o0000ooooool00000=Oooool0
0ol0003oooooooooo`0dooooo`;o0000=Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo027ooooo000Pooooo`03o`000?oooooooooo06cooooo00?o0000ooooool00000JOooool2o`00
02?ooooo000Oooooo`03o`000?oooooooooo06gooooo00Co0000oooooooooooo0000J?ooool2o`00
02?ooooo000Oooooo`03o`000?oooooooooo06gooooo00Go0000ooooooooooooooooo`00001Woooo
o`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`00
0?oooooooooo06kooooo0_l00004ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
8oooool001gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool08oooool001gooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool09?ooool0
01gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool09?ooool001cooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool09Oooool001cooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05cooooo
00?o0000ooooooooool09Oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool09_ooool001_ooooo00?o0000
ooooooooool0LOooool2o`0000Wooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0V
ooooo`006oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Wooooo0ol0001Ioooo
o`03o`000?oooooooooo02Kooooo000Kooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool02_ooool2o`0005Sooooo00?o0000ooooooooool09oooool001[ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0
9oooool001[ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0:?ooool001[ooooo00?o0000ooooooooool0L_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0:?ooool0
01Wooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool0:Oooool001Wooooo00?o0000ooooooooool0Loooool2o`00013o
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Yooooo`006Oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`0Zooooo`006?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`0[ooooo`006?ooool00ol0003oooooooooo`1d
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0[
ooooo`006?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo01?ooooo0_l0001:oooo
o`03o`000?oooooooooo02cooooo000Gooooo`03o`000?oooooooooo07Gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo02gooooo000Gooooo`03o`00
0?oooooooooo07Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo02gooooo000Gooooo`03o`000?oooooooooo07Gooooo0_l0000Hooooo`03o`000?oo
oooooooo04;ooooo0_l0000`ooooo`005_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooo
oooo01Sooooo0_l00012ooooo`;o0000<?ooool001Kooooo00?o0000ooooooooool0M_ooool00ol0
003oooooooooo`0Hooooo`?o0000@Oooool00ol0003oooooooooo`0_ooooo`005_ooool00ol0003o
ooooooooo`1fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0`ooooo`005Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0aooooo`005?ooool2o`0005oooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<_ooool001Cooooo0_l0001N
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0cooooo`005?ooool00ol0003oooooooooo`1Mooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`?o00007oooool2o`0003Ko
oooo00?o0000ooooooooool0=?ooool001Cooooo00?o0000ooooooooool0GOooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0=Oooool001Co
oooo00?o0000ooooooooool0GOooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0=_ooool001?ooooo00?o0000ooooooooool0G_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0_l00007ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0gooooo`004oooool0
0ol0003oooooooooo`1Oooooo`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0>?ooool0
01?ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Uooooo`;o0000:oooool00ol0
003oooooooooo`0iooooo`004_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo02Go
oooo1?l0000Wooooo`;o0000??ooool001;ooooo00?o0000ooooooooool0N_ooool2o`0002[ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0looooo`004_ooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo02[ooooo0_l0000Qooooo`?o0000?_ooool001;ooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`0/ooooo`;o00007_ooool01?l0003oooooo`000?l0
000nooooo`004Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`10ooooo`004Oooool00ol0003oooooooooo`1koooo
o`03o`000?oooooooooo02oooooo0ol0000Hooooo`03o`000?oooooooooo047ooooo000Aooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool0<_ooool3o`0001?ooooo0_l00014ooooo`00
4Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo1Ol00009ooooo`Oo0000
A_ooool0013ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0hooooo`_o0000Booo
ool0013ooooo00?o0000ooooooooool0O?ooool2o`0008oooooo000@ooooo`03o`000?oooooooooo
07cooooo00?o0000ooooooooool0S_ooool0013ooooo00?o0000ooooooooool0O?ooool00ol0003o
ooooooooo`2>ooooo`003oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo08kooooo
000?ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0S_ooool000oooooo00?o0000
ooooooooool0OOooool00ol0003oooooooooo`2>ooooo`003_ooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo08kooooo000>ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`00
3_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo08kooooo000>ooooo`03o`000?oo
oooooooo07kooooo00?o0000ooooooooool0S_ooool000gooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`2>ooooo`003Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
08kooooo000=ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0S_ooool000gooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`2>ooooo`003?ooool00ol0003ooooooooo
o`20ooooo`;o0000Soooool000cooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`2>
ooooo`003?ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo08kooooo000<ooooo`03
o`000?oooooooooo083ooooo00?o0000ooooooooool0S_ooool000_ooooo00?o0000ooooooooool0
Ioooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00005ooooo`03o`00
0?oooooooooo08kooooo000;ooooo`03o`000?oooooooooo06Kooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool0S_ooool000_ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2>
ooooo`002oooool00ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`?o0000S_ooool000[ooooo00?o0000
ooooooooool0Ioooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08kooooo000:ooooo`03o`00
0?oooooooooo06Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2>ooooo`002_ooool00ol0
003oooooooooo`1Xooooo`;o00002_ooool2o`0000?ooooo0ol00006ooooo`03o`000?oooooooooo
08kooooo0009ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0S_ooool000Wooooo
00?o0000ooooooooool0Poooool00ol0003oooooooooo`2>ooooo`002Oooool00ol0003ooooooooo
o`23ooooo`03o`000?oooooooooo08kooooo0009ooooo`03o`000?oooooooooo08?ooooo0_l0002?
ooooo`002?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo08kooooo0008ooooo`03
o`000?oooooooooo08Cooooo00?o0000ooooooooool0S_ooool000Sooooo00?o0000ooooooooool0
Q?ooool00ol0003oooooooooo`2>ooooo`002?ooool00ol0003oooooooooo`24ooooo`03o`000?oo
oooooooo08kooooo0007ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0S_ooool0
00Kooooo0_l00027ooooo`03o`000?oooooooooo08kooooo0006ooooo`;o0000Qoooool2o`0008oo
oooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?
ooooo`03o`000?oooooooooo08kooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.26302, -0.025029, \
0.0366761, 0.000282911}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dy = D[symbolicy,y]", "Input",
  CellLabel->"In[134]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],

Cell[BoxData[
    \(\(\(0.0088364155326911`\)\(\[InvisibleSpace]\)\) - 
      0.02376778501234205`\ d - 0.0015757513747870293`\ y\^2 - 
      0.00006062604240982259`\ d\ y\^2 - 3.6305315986759584`*^-6\ y\^4 - 
      1.3656859916723253`*^-7\ d\ y\^4\)], "Output",
  CellLabel->"Out[134]=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],

Cell["Cderivative = Compile[{y,d},Evaluate[Dy]];", "Input",
  CellLabel->"In[135]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],

Cell["ytransfer = Compile[{y,d},Evaluate[symbolicy]];", "Input",
  CellLabel->"In[136]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot[Evaluate[{symbolicy,1/Abs[Dy]}/.d->0],{y,-5,5}];\
\>", "Input",
  CellLabel->"In[137]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 20.0558 0.0147151 0.000178109 [
[.09888 .00222 -15 -9 ]
[.09888 .00222 15 0 ]
[.29944 .00222 -15 -9 ]
[.29944 .00222 15 0 ]
[.70056 .00222 -12 -9 ]
[.70056 .00222 12 0 ]
[.90112 .00222 -12 -9 ]
[.90112 .00222 12 0 ]
[.4875 .10377 -18 -4.5 ]
[.4875 .10377 0 4.5 ]
[.4875 .19282 -24 -4.5 ]
[.4875 .19282 0 4.5 ]
[.4875 .28188 -24 -4.5 ]
[.4875 .28188 0 4.5 ]
[.4875 .37093 -24 -4.5 ]
[.4875 .37093 0 4.5 ]
[.4875 .45999 -24 -4.5 ]
[.4875 .45999 0 4.5 ]
[.4875 .54904 -24 -4.5 ]
[.4875 .54904 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09888 .01472 m
.09888 .02097 L
s
[(-0.02)] .09888 .00222 0 1 Mshowa
.29944 .01472 m
.29944 .02097 L
s
[(-0.01)] .29944 .00222 0 1 Mshowa
.70056 .01472 m
.70056 .02097 L
s
[(0.01)] .70056 .00222 0 1 Mshowa
.90112 .01472 m
.90112 .02097 L
s
[(0.02)] .90112 .00222 0 1 Mshowa
.125 Mabswid
.139 .01472 m
.139 .01847 L
s
.17911 .01472 m
.17911 .01847 L
s
.21922 .01472 m
.21922 .01847 L
s
.25933 .01472 m
.25933 .01847 L
s
.33955 .01472 m
.33955 .01847 L
s
.37967 .01472 m
.37967 .01847 L
s
.41978 .01472 m
.41978 .01847 L
s
.45989 .01472 m
.45989 .01847 L
s
.54011 .01472 m
.54011 .01847 L
s
.58022 .01472 m
.58022 .01847 L
s
.62033 .01472 m
.62033 .01847 L
s
.66045 .01472 m
.66045 .01847 L
s
.74067 .01472 m
.74067 .01847 L
s
.78078 .01472 m
.78078 .01847 L
s
.82089 .01472 m
.82089 .01847 L
s
.861 .01472 m
.861 .01847 L
s
.05877 .01472 m
.05877 .01847 L
s
.01866 .01472 m
.01866 .01847 L
s
.94123 .01472 m
.94123 .01847 L
s
.98134 .01472 m
.98134 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .10377 m
.50625 .10377 L
s
[(500)] .4875 .10377 1 0 Mshowa
.5 .19282 m
.50625 .19282 L
s
[(1000)] .4875 .19282 1 0 Mshowa
.5 .28188 m
.50625 .28188 L
s
[(1500)] .4875 .28188 1 0 Mshowa
.5 .37093 m
.50625 .37093 L
s
[(2000)] .4875 .37093 1 0 Mshowa
.5 .45999 m
.50625 .45999 L
s
[(2500)] .4875 .45999 1 0 Mshowa
.5 .54904 m
.50625 .54904 L
s
[(3000)] .4875 .54904 1 0 Mshowa
.125 Mabswid
.5 .03253 m
.50375 .03253 L
s
.5 .05034 m
.50375 .05034 L
s
.5 .06815 m
.50375 .06815 L
s
.5 .08596 m
.50375 .08596 L
s
.5 .12158 m
.50375 .12158 L
s
.5 .13939 m
.50375 .13939 L
s
.5 .1572 m
.50375 .1572 L
s
.5 .17501 m
.50375 .17501 L
s
.5 .21063 m
.50375 .21063 L
s
.5 .22845 m
.50375 .22845 L
s
.5 .24626 m
.50375 .24626 L
s
.5 .26407 m
.50375 .26407 L
s
.5 .29969 m
.50375 .29969 L
s
.5 .3175 m
.50375 .3175 L
s
.5 .33531 m
.50375 .33531 L
s
.5 .35312 m
.50375 .35312 L
s
.5 .38874 m
.50375 .38874 L
s
.5 .40655 m
.50375 .40655 L
s
.5 .42437 m
.50375 .42437 L
s
.5 .44218 m
.50375 .44218 L
s
.5 .4778 m
.50375 .4778 L
s
.5 .49561 m
.50375 .49561 L
s
.5 .51342 m
.50375 .51342 L
s
.5 .53123 m
.50375 .53123 L
s
.5 .56685 m
.50375 .56685 L
s
.5 .58466 m
.50375 .58466 L
s
.5 .60247 m
.50375 .60247 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.97619 .02014 m
.85294 .02077 L
.73718 .02155 L
.63387 .02253 L
.58132 .02319 L
.53612 .02389 L
.49494 .02468 L
.45907 .02553 L
.39963 .02749 L
.37245 .02875 L
.34639 .03035 L
.32633 .03196 L
.30648 .03411 L
.29676 .03546 L
.28812 .0369 L
.27345 .04014 L
.26612 .04234 L
.25985 .04469 L
.25355 .04772 L
.2475 .05162 L
.24236 .05619 L
.23815 .0614 L
.23615 .06463 L
.2341 .06869 L
.23213 .07364 L
.23045 .07908 L
.22899 .08517 L
.22773 .09203 L
.2267 .09936 L
.22568 .10898 L
.2247 .12209 L
.22425 .13014 L
.2238 .14047 L
.22344 .15075 L
.22309 .16383 L
.22278 .17861 L
.22253 .19491 L
.22228 .21689 L
.22207 .24304 L
.2219 .27286 L
.22174 .31518 L
.22159 .38015 L
.22153 .42464 L
.22147 .48779 L
s
.22147 .48779 m
.22141 .61803 L
s
.22141 .61803 m
.22146 .50348 L
.22157 .40418 L
.22168 .34394 L
.22184 .2925 L
.22193 .27234 L
.22204 .25341 L
.22226 .22605 L
.22248 .20575 L
.22277 .18638 L
.22306 .17197 L
.22343 .15815 L
.22381 .14722 L
.22416 .13902 L
.22456 .13141 L
.22534 .11995 L
.22628 .11 L
.22741 .10112 L
.22847 .09478 L
.22973 .08892 L
.23104 .08404 L
.23254 .07955 L
.23548 .07293 L
.23849 .06801 L
.24266 .063 L
.24696 .05919 L
.25112 .05633 L
.25593 .05371 L
.26556 .04982 L
.27148 .04803 L
.27728 .04657 L
.28975 .04411 L
.30419 .04204 L
.31856 .04049 L
.33511 .03913 L
.35151 .03809 L
.3673 .0373 L
.3824 .0367 L
.39912 .03616 L
.4179 .0357 L
.43588 .03536 L
.45335 .03513 L
.46333 .03503 L
.47266 .03496 L
.47775 .03493 L
.48256 .03491 L
.48689 .03489 L
.48933 .03488 L
.49159 .03488 L
.49401 .03488 L
Mistroke
.49628 .03487 L
.49757 .03487 L
.49876 .03487 L
.50013 .03487 L
.50143 .03487 L
.50269 .03487 L
.50402 .03487 L
.50642 .03488 L
.50789 .03488 L
.50928 .03488 L
.51186 .03489 L
.51635 .0349 L
.52052 .03492 L
.53 .03498 L
.53921 .03505 L
.54903 .03515 L
.56667 .0354 L
.58253 .03571 L
.60009 .03614 L
.61598 .03664 L
.63295 .03732 L
.65037 .0382 L
.66507 .03914 L
.68022 .04037 L
.69381 .04179 L
.70559 .04337 L
.71799 .04554 L
.72868 .04807 L
.7394 .05164 L
.74491 .05412 L
.7496 .05678 L
.75379 .05978 L
.7579 .06358 L
.76114 .06749 L
.76441 .07273 L
.76758 .07988 L
.7692 .08485 L
.77057 .09018 L
.77175 .096 L
.77294 .10358 L
.77396 .11228 L
.77483 .12216 L
.77559 .13408 L
.77598 .14206 L
.77631 .15037 L
.77661 .15922 L
.7769 .17029 L
.77714 .1814 L
.77738 .1957 L
.77762 .21342 L
Mistroke
.77784 .23659 L
.77802 .26364 L
.77817 .29594 L
.77833 .34745 L
.77845 .41494 L
.77851 .46562 L
.77856 .53824 L
Mfstroke
.77856 .53824 m
.77859 .61803 L
s
.7786 .61803 m
.7786 .60688 L
.77851 .46383 L
.77839 .36932 L
.77831 .33173 L
.77822 .3037 L
.77805 .26226 L
.77786 .23311 L
.77763 .208 L
.77751 .19735 L
.77736 .18684 L
.77709 .17171 L
.77677 .15805 L
.77644 .14711 L
.77612 .13841 L
.77573 .12976 L
.77528 .12172 L
.77438 .10966 L
.77378 .10349 L
.77317 .09833 L
.77194 .09007 L
.7705 .08287 L
.76904 .07729 L
.7673 .07208 L
.76529 .06738 L
.76151 .06091 L
.75751 .05606 L
.75262 .05171 L
.74674 .04789 L
.74051 .04484 L
.73418 .04243 L
.72662 .04016 L
.71786 .03808 L
.70879 .03635 L
.69961 .03493 L
.68077 .03265 L
.6591 .03075 L
.63355 .02908 L
.60949 .02788 L
.58065 .02674 L
.51417 .02488 L
.47194 .02403 L
.43024 .02336 L
.34136 .02227 L
.23079 .02131 L
.13541 .0207 L
.02381 .02014 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[137]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol0000Qoooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0005Oooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00008_ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000;ooooo1Ol0000Iooooo`006_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008?ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0EOooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool08?ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00006Oooool001?ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`0Iooooo`Go00000_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0EOooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool08?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo01oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo05Gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo01Sooooo000Jooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo01kooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo05Gooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo023o
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool05oooool001[ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo0_l0001Gooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool2o`0002;ooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool05oooool001_ooooo0_l0000:oooo
o`;o00000oooool3o`0002;ooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`1Foooo
o`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool08Oooool2o`0000[ooooo0_l00003oooo
o`?o00006_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0
S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool0
00Ooooooool0000Bo`0000Sooooo000<oooooa;o00001?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooooooo4ol0000=ooooo`007_oooomUo`0000co
oooo00?o0000ooooooooool00_oooom/o`00023ooooo001`oooooc[o0000M_ooool006?ooooo3Ol0
000Oooooo`03o`000?oooooooooo01Sooooo5?l0001Rooooo`00FOooool:o`0002Cooooo4ol0000T
ooooo`[o0000F?ooool005?ooooo1_l0000<ooooob;o00002?ooool00ol0003oooooooooo`08oooo
ob7o00003Oooool5o`0005?ooooo001@ooooo`?o00001Oooool=o`0002[ooooo00?o0000oooooooo
ool0:Oooool<o`0000Kooooo0_l0001Aooooo`00COooool3o`0000Cooooo1?l0000gooooo`03o`00
0?oooooooooo03Gooooo1_l00002ooooo`?o0000C_ooool004_ooooo0_l00003ooooo`Co0000>ooo
ool00ol0003oooooooooo`0kooooo`?o00000_ooool2o`0004cooooo001:ooooo`04o`000?oooooo
ooooooooo`;o0000?oooool2o`0003oooooo0_l00002ooooo`03o`000?oooooooooo04Wooooo0019
ooooo`03o`000?oooooo000000;o0000@Oooool00ol0003oooooooooo`10ooooo`;o000000?ooooo
o`000?ooool0BOooool004Wooooo0_l00014ooooo`03o`000?oooooooooo04;ooooo0_l0001:oooo
o`00B?ooool2o`0004Gooooo00?o0000ooooooooool0@oooool2o`0004Wooooo0017ooooo`03o`00
0?oooooo000004Gooooo00?o0000ooooooooool0A?ooool2o`0004Sooooo0016ooooo`03o`000?oo
oooo000004Kooooo0_l00015ooooo`;o0000B?ooool004Kooooo0_l00017ooooo`03o`000?oooooo
oooo04Gooooo0_l00017ooooo`00A_ooool2o`0004Oooooo00?o0000ooooooooool0AOooool2o`00
04Oooooo0015ooooo`;o0000B?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Go
oooo0015ooooo`;o0000B?ooool2o`0004Oooooo0_l00016ooooo`00AOooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo04Kooooo0_l00016ooooo`00AOooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0A?ooool004Gooooo00?o0000oooo
ooooool0<oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo04Cooooo0014ooooo`;o0000=?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool0A?ooool004Cooooo0_l0000hooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`?o0000
Aoooool2o`0004Gooooo0014ooooo`;o0000>?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`17ooooo`;o
0000AOooool004Cooooo00?o0000ooooooooool0<oooool4o`0000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0@oooool004Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo04?ooooo0014ooooo`03o`000?oooooooooo03?ooooo1Ol00003oooo
o`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`13oooo
o`00A?ooool00ol0003oooooooooo`18ooooo`;o0000BOooool00ol0003oooooooooo`13ooooo`00
A?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
@oooool004Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo04?ooooo0014ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`13ooooo`00A?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool0@oooool004Cooooo00?o0000ooooooooool0B?ooool2o`0004Wo
oooo00?o0000ooooooooool0@oooool004Cooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo04?ooooo0014ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`13ooooo`00A?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0@oooool004Cooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04?ooooo0014ooooo`03
o`000?oooooooooo04Sooooo0_l00019ooooo`03o`000?oooooooooo04?ooooo0013ooooo`;o0000
B_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04?ooooo0013ooooo`;o0000B_oo
ool00ol0003oooooooooo`18ooooo`;o0000A?ooool004?ooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003o
ooooooooo`19ooooo`;o0000B_ooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o
0000ooooooooool0;oooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`12ooooo`00@oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo0ol00019ooooo`03o`00
0?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03
o`000?oooooooooo02oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`03
ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool2o`0004[ooooo00?o0000oooo
ooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo
04Wooooo0_l0001:ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12
ooooo`00@oooool00ol0003oooooooooo`19ooooo`;o0000B_ooool00ol0003oooooooooo`12oooo
o`00@oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0@_ooool004?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool2o`00
04[ooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo02oooooo
0ol00003ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12oooo
o`00@oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo0ol00019ooooo`03o`000?oooooooooo04;ooooo0013
ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo02oooooo0_l00003ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000oooooooo
ool0<?ooool01?l0003oooooooooooooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003ooooo
ooooo`19ooooo`;o0000B_ooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12oooo
o`00@oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0@_ooool004?ooooo00?o0000ooooooooool0BOooool2o`0004[ooooo00?o0000ooooooooool0
@_ooool004?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool2o`0004[o
oooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03
o`000?oooooooooo04Wooooo0_l0001:ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@ooo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_oo
ool004?ooooo00?o0000ooooooooool0;_ooool5o`0000?ooooo0_l00004ooooo`;o00001?ooool2
o`0000Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0
003oooooooooo`0_ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo0ol00019ooooo`03o`000?oooooooooo04;ooooo0013oooo
o`03o`000?oooooooooo037ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0;_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`0^ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;o
oooo0013ooooo`03o`000?oooooooooo02oooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o
0000ooooooooool0BOooool2o`0004[ooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12oooo
o`00@oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0@_ooool004?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo0_l0001:ooooo`03o`000?oo
oooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003ooooooooo
o`19ooooo`;o0000B_ooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00
@oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
@_ooool004?ooooo00?o0000ooooooooool0BOooool2o`0004[ooooo00?o0000ooooooooool0@_oo
ool004?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo04;ooooo0013ooooo`03o`000?oooooooooo02kooooo1Ol00002ooooo`?o00001?ooool2o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?o
oooo00?o0000ooooooooool0;oooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo0ol00019ooooo`03o`000?oooooooooo04;o
oooo0013ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo02ko
oooo00Ko0000ooooooooooooooooo`000?ooool4o`0000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
@_ooool004?ooooo00?o0000ooooooooool0;_ooool01ol0003ooooooooooooooooo0000ooooool0
00001_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`0_oooo
o`?o00000_ooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo0_l0001:ooooo`03
o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003o
ooooooooo`19ooooo`;o0000B_ooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12
ooooo`00@oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool2o`0004[ooooo00?o0000oooooooo
ool0@_ooool004?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wo
oooo0_l0001:ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003ooooooooo
o`0_ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo02kooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0@_ooool004?ooooo00?o0000ooooooooool0<_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000
ooooooooool0<?ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo0ol00019ooooo`03o`000?oooooooooo04;o
oooo0013ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo
02kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0;oooool3o`0000Cooooo
0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`12ooooo`00@oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool2o`0004[ooooo00?o0000
ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOoo
ool2o`0004[ooooo00?o0000ooooooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12ooooo`00@oooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0@_ooool004?ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;ooooo
0013ooooo`03o`000?oooooooooo04Wooooo0_l0001:ooooo`03o`000?oooooooooo04;ooooo0013
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`12
ooooo`00@oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0@_ooool004?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`12ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0262371, -255.465, \
0.000182837, 20.5882}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["inversey = Solve[ys==symbolicy,y]", "Input",
  CellLabel->"In[138]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],

Cell[BoxData[
    \({{y \[Rule] 
          Root[ys - 0.0088364155326911`\ #1 + 0.02376778501234205`\ d\ #1 + 
                0.0005252504582623431`\ #1\^3 + 
                0.000020208680803274196`\ d\ #1\^3 + 
                7.261063197351916`*^-7\ #1\^5 + 
                2.7313719833446508`*^-8\ d\ #1\^5 &, 1]}, {y \[Rule] 
          Root[ys - 0.0088364155326911`\ #1 + 0.02376778501234205`\ d\ #1 + 
                0.0005252504582623431`\ #1\^3 + 
                0.000020208680803274196`\ d\ #1\^3 + 
                7.261063197351916`*^-7\ #1\^5 + 
                2.7313719833446508`*^-8\ d\ #1\^5 &, 2]}, {y \[Rule] 
          Root[ys - 0.0088364155326911`\ #1 + 0.02376778501234205`\ d\ #1 + 
                0.0005252504582623431`\ #1\^3 + 
                0.000020208680803274196`\ d\ #1\^3 + 
                7.261063197351916`*^-7\ #1\^5 + 
                2.7313719833446508`*^-8\ d\ #1\^5 &, 3]}, {y \[Rule] 
          Root[ys - 0.0088364155326911`\ #1 + 0.02376778501234205`\ d\ #1 + 
                0.0005252504582623431`\ #1\^3 + 
                0.000020208680803274196`\ d\ #1\^3 + 
                7.261063197351916`*^-7\ #1\^5 + 
                2.7313719833446508`*^-8\ d\ #1\^5 &, 4]}, {y \[Rule] 
          Root[ys - 0.0088364155326911`\ #1 + 0.02376778501234205`\ d\ #1 + 
                0.0005252504582623431`\ #1\^3 + 
                0.000020208680803274196`\ d\ #1\^3 + 
                7.261063197351916`*^-7\ #1\^5 + 
                2.7313719833446508`*^-8\ d\ #1\^5 &, 5]}}\)], "Output",
  CellLabel->"Out[138]=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[Evaluate[y/.inversey/.d->0],{ys,-.02,.02}];", "Input",
  CellLabel->"In[139]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],

Cell[BoxData[
    \(Plot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(Root[\(\(\(\(\(\(ys - \(\(0.0088364155326911`\\ #1\)\) + \
\(\(0.0005252504582623431`\\ #1\^3\)\) + \(\(7.261063197351916`*^-7\\ #1\^5\)\
\)\)\) &\)\), 2\)\)]\) is not a machine-size real number at \!\(ys\) = \
\!\(-0.019999998333333335`\)."\)], "Message",
  CellLabel->"From In[139]:=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],

Cell[BoxData[
    \(Plot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(Root[\(\(\(\(\(\(ys - \(\(0.0088364155326911`\\ #1\)\) + \
\(\(0.0005252504582623431`\\ #1\^3\)\) + \(\(7.261063197351916`*^-7\\ #1\^5\)\
\)\)\) &\)\), 2\)\)]\) is not a machine-size real number at \!\(ys\) = \
\!\(-0.01837732033708337`\)."\)], "Message",
  CellLabel->"From In[139]:=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],

Cell[BoxData[
    \(Plot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(Root[\(\(\(\(\(\(ys - \(\(0.0088364155326911`\\ #1\)\) + \
\(\(0.0005252504582623431`\\ #1\^3\)\) + \(\(7.261063197351916`*^-7\\ #1\^5\)\
\)\)\) &\)\), 2\)\)]\) is not a machine-size real number at \!\(ys\) = \
\!\(-0.01660764800562505`\)."\)], "Message",
  CellLabel->"From In[139]:=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Plot :: \"plnr\"\) will be suppressed during \
this calculation."\)], "Message",
  CellLabel->"From In[139]:=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 23.8095 0.309017 0.0602794 [
[.02381 .29652 -15 -9 ]
[.02381 .29652 15 0 ]
[.2619 .29652 -15 -9 ]
[.2619 .29652 15 0 ]
[.7381 .29652 -12 -9 ]
[.7381 .29652 12 0 ]
[.97619 .29652 -12 -9 ]
[.97619 .29652 12 0 ]
[.4875 .0679 -12 -4.5 ]
[.4875 .0679 0 4.5 ]
[.4875 .18846 -12 -4.5 ]
[.4875 .18846 0 4.5 ]
[.4875 .42958 -6 -4.5 ]
[.4875 .42958 0 4.5 ]
[.4875 .55013 -6 -4.5 ]
[.4875 .55013 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-0.02)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.01)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.01)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.02)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .0679 m
.50625 .0679 L
s
[(-4)] .4875 .0679 1 0 Mshowa
.5 .18846 m
.50625 .18846 L
s
[(-2)] .4875 .18846 1 0 Mshowa
.5 .42958 m
.50625 .42958 L
s
[(2)] .4875 .42958 1 0 Mshowa
.5 .55013 m
.50625 .55013 L
s
[(4)] .4875 .55013 1 0 Mshowa
.125 Mabswid
.5 .09804 m
.50375 .09804 L
s
.5 .12818 m
.50375 .12818 L
s
.5 .15832 m
.50375 .15832 L
s
.5 .2186 m
.50375 .2186 L
s
.5 .24874 m
.50375 .24874 L
s
.5 .27888 m
.50375 .27888 L
s
.5 .33916 m
.50375 .33916 L
s
.5 .3693 m
.50375 .3693 L
s
.5 .39944 m
.50375 .39944 L
s
.5 .45972 m
.50375 .45972 L
s
.5 .48986 m
.50375 .48986 L
s
.5 .52 m
.50375 .52 L
s
.5 .03776 m
.50375 .03776 L
s
.5 .00762 m
.50375 .00762 L
s
.5 .58027 m
.50375 .58027 L
s
.5 .61041 m
.50375 .61041 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .60009 L
.10458 .59646 L
.12507 .59465 L
.14415 .59293 L
.1536 .59207 L
.16254 .59125 L
.16494 .59103 L
.16748 .5908 L
.16812 .59074 L
.1688 .59067 L
.16956 .163 L
.17026 .16045 L
.17095 .15868 L
.17161 .1573 L
.17284 .15514 L
.17732 .14942 L
.18221 .14486 L
.19253 .13759 L
.20188 .13239 L
.22285 .1231 L
.26292 .1098 L
.30147 .09977 L
.34247 .09079 L
.38196 .08322 L
.41993 .07667 L
.46036 .0703 L
.49927 .06464 L
.54063 .05904 L
.58047 .05398 L
.6188 .04938 L
.65958 .04473 L
.69885 .04047 L
.7366 .03655 L
.7768 .03254 L
.81549 .02883 L
.85663 .02503 L
.89626 .0215 L
.93436 .01821 L
.97492 .01482 L
.97619 .01472 L
s
.16964 .17177 m
.17023 .17391 L
.17147 .17701 L
.17284 .17958 L
.17768 .18615 L
.18221 .19079 L
.20172 .20515 L
.22272 .21663 L
.26394 .23464 L
.30365 .24927 L
.34184 .262 L
.38249 .27469 L
.42162 .28637 L
.4632 .29845 L
.50327 .30995 L
.54182 .32103 L
.58282 .33297 L
.62231 .34481 L
.66028 .35672 L
.7007 .37029 L
.73961 .38481 L
.75942 .39309 L
.78097 .40326 L
.80167 .41501 L
.81089 .42145 L
.81607 .42569 L
.82082 .43024 L
.82551 .4359 L
.82787 .43971 L
.82851 .44099 L
.8292 .44257 L
.83045 .44667 L
s
.16964 .59059 m
.17023 .59054 L
.17284 .5903 L
.18221 .58942 L
.22272 .58554 L
.26055 .58178 L
.30084 .5776 L
.33961 .57339 L
.38084 .5687 L
.42054 .56393 L
.45874 .55908 L
.49938 .55358 L
.53851 .5479 L
.58009 .54136 L
.62016 .53443 L
.65871 .527 L
.69971 .51798 L
.7392 .50762 L
.77717 .49493 L
.79668 .48637 L
.80762 .48035 L
.81246 .4772 L
.8176 .47333 L
.82231 .469 L
.82502 .46591 L
.82624 .46429 L
.82751 .46233 L
.82979 .45743 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[139]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00TOooool00ol0003ooooooooo
o`2<ooooo`00TOooool00ol0003oooooooooo`2<ooooo`00TOooool2o`0008gooooo002Aooooo`03
o`000?oooooooooo08cooooo002Aooooo`03o`000?oooooooooo07Wooooo1ol0000<ooooo`00TOoo
ool00ol0003oooooooooo`1^ooooo`_o00004oooool0097ooooo00?o0000ooooooooool0I?ooool:
o`0001kooooo002Aooooo`03o`000?oooooooooo05Wooooo2ol0000Xooooo`00TOooool00ol0003o
ooooooooo`1>ooooo`_o0000<oooool0097ooooo00?o0000ooooooooool0@oooool;o`0003kooooo
002Aooooo`;o0000>Oooool;o`0004Wooooo002Aooooo`03o`000?oooooooooo02kooooo2_l0001D
ooooo`00TOooool00ol0003oooooooooo`0Sooooo`_o0000G_ooool0097ooooo00?o0000oooooooo
ool06?ooool;o`0006Wooooo002Aooooo`03o`000?oooooooooo013ooooo2?l0001dooooo`00TOoo
ool00ol0003oooooooooo`0;ooooo`Go0000O?ooool008Wooooo0ol00005ooooo`03o`000?oooooo
oooo00;ooooo2Ol00021ooooo`00R_ooool01?l0003oooooooooooooool8o`0008[ooooo0021oooo
o`Go000000?oooooo`000?l000001Ol00003ooooo`;o0000SOooool008?ooooo1_l000000ooooooo
0000ooooo`05ooooo`03o`000?oooooooooo08cooooo001nooooo`Go00001Oooool00ol0003ooooo
o`000006ooooo`03o`000?oooooooooo08cooooo001fooooo`So00002oooool2o`0000Kooooo00?o
0000ooooooooool0S?ooool006gooooo2Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0S?ooool006Sooooo1Ol0000Tooooo`03o`000?oooooooooo08cooooo001Sooooo`Go
0000:Oooool00ol0003oooooooooo`2<ooooo`00Goooool4o`0002kooooo00?o0000ooooooooool0
S?ooool005cooooo0ol0000booooo`;o0000SOooool005Sooooo1?l0000eooooo`03o`000?oooooo
oooo08cooooo001Eooooo`?o0000>Oooool00ol0003oooooooooo`2<ooooo`00D_ooool3o`0003co
oooo00?o0000ooooooooool0S?ooool004kooooo1?l0000oooooo`03o`000?oooooooooo08cooooo
001:ooooo`Co0000@oooool00ol0003oooooooooo`2<ooooo`00Aoooool3o`0004Oooooo00?o0000
ooooooooool0S?ooool004Cooooo0ol0001:ooooo`03o`000?oooooooooo08cooooo0012ooooo`;o
0000COooool00ol0003oooooooooo`2<ooooo`00@?ooool2o`0004oooooo0_l0002=ooooo`00?_oo
ool2o`00057ooooo00?o0000ooooooooool0S?ooool003cooooo0_l0001Cooooo`03o`000?oooooo
oooo08cooooo000kooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0S?ooool003Wo
oooo0_l0001Fooooo`03o`000?oooooooooo08cooooo000hooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool0S?ooool003Sooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`2<ooooo`00=oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo08cooooo000foooo
o`;o0000FOooool2o`0008gooooo000fooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool0S?ooool003Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2<ooooo`00=_oo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo08cooooo000fooooo`03o`000?oooooo
oooo05Sooooo00?o0000ooooooooool0S?ooool003Kooooo0_l0001Iooooo`03o`000?oooooooooo
08cooooo000fooooo`?o0000C_ooool5o`0000Gooooo00?o0000ooooooooool0S?ooool003Kooooo
00Co0000oooooooooooo0000C_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
08cooooo000fooooo`04o`000?ooooooooooo`0004Oooooo1Ol00003ooooo`03o`000?oooooooooo
00Gooooo0_l0002=ooooo`00=_ooool01?l0003oooooooooooooool2o`0004kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`2<ooooo`00=_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04Sooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
08cooooo000fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Aoooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0S?ooool003Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`17ooooo`?o00001_ooool00ol0003oooooooooo`2<ooooo`00
=_ooool00ol0003oooooooooo`06ooooo`;o0000D?ooool00ol0003oooooooooo`2<ooooo`00=_oo
ool00ol0003oooooooooo`08ooooo`;o0000C_ooool00ol0003oooooooooo`2<ooooo`00=_ooool0
0ol0003oooooooooo`0:ooooo`;o0000C?ooool00ol0003oooooooooo`2<ooooo`00=_ooool00ol0
003oooooooooo`0<ooooo`;o0000B_ooool2o`0008gooooo000fooooo`03o`000?oooooooooo00ko
oooo0_l00018ooooo`03o`000?oooooooooo08cooooo000fooooo`03o`000?oooooooooo013ooooo
0ol00015ooooo`03o`000?oooooooooo08cooooo000fooooo`03o`000?oooooooooo01?ooooo0_l0
0013ooooo`03o`000?oooooooooo08cooooo000fooooo`03o`000?oooooooooo01Gooooo0_l00011
ooooo`03o`000?oooooooooo08cooooo000fooooo`03o`000?oooooooooo01Oooooo0_l0000ooooo
o`03o`000?oooooooooo08cooooo000fooooo`03o`000?oooooooooo01Wooooo0ol0000looooo`03
o`000?oooooooooo08cooooo000fooooo`03o`000?oooooooooo01cooooo0ol0000iooooo`03o`00
0?oooooooooo08cooooo000fooooo`03o`000?oooooooooo01oooooo0ol0000fooooo`03o`000?oo
oooooooo08cooooo000fooooo`03o`000?oooooooooo02;ooooo0ol0000cooooo`;o0000SOooool0
03Kooooo00?o0000ooooooooool09Oooool3o`00033ooooo00?o0000ooooooooool0S?ooool003Ko
oooo00?o0000ooooooooool0:?ooool3o`0002gooooo00?o0000ooooooooool0S?ooool003Kooooo
00?o0000ooooooooool0:oooool3o`0002[ooooo00?o0000ooooooooool0S?ooool003Kooooo00?o
0000ooooooooool0;_ooool3o`0002Oooooo00?o0000ooooooooool0S?ooool000Sooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00006Oooool00ol0003oooooooooo`0@
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000gooooo0ol0000T
ooooo`03o`000?oooooooooo03Cooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003
ooooo`?o0000;Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002
ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00006Oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0?ooooo`?o00008Oooool00ol0
003oooooooooo`0cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`001Ol00002ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Sooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0Booooo`?o00007_ooool00ol0003oooooooooo`0cooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0[oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`02ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Eooooo`Co00006_ooool2o`00
03Cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo02_ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
6Oooool3o`0001Oooooo00?o0000ooooooooool0<oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0:oooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool1o`00007ooooo0Oooool000Oooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool2o`0001kooooo1?l0000Cooooo`03o`000?oooooooooo03?ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`;o0000;Oooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool1o`00007ooooo0Ooo
ool000Sooooo0_l0000:ooooo`;o00000oooool3o`0001[ooooo00?o0000ooooooooool04?ooool2
o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo023ooooo1?l0000?ooooo`03o`000?oooooo
oooo03Cooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`0/ooooo`;o00002_ooool2
o`0000?ooooo0ol00003ooooo`00=_ooool00ol0003oooooooooo`19ooooo`?o00003?ooool00ol0
003oooooooooo`2<ooooo`00=_ooool00ol0003oooooooooo`1<ooooo`Co00002?ooool00ol0003o
ooooooooo`2<ooooo`00=_ooool00ol0003oooooooooo`1@ooooo`Co00001?ooool00ol0003ooooo
ooooo`2<ooooo`00=_ooool00ol0003oooooooooo`1Dooooo`?o000000?oooooo`000?ooool0SOoo
ool000Soooooool0000Co`0000Kooooo000?ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?l00006ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo000?ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Co
oooo0ol0000gooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02_ooool003Kooooo
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`07ooooo`?o0000P_ooool003Kooooo00?o
0000ooooooooool0F?ooool00ol0003oooooooooo`0:ooooo`?o0000Ooooool003Kooooo00?o0000
ooooooooool0F?ooool00ol0003oooooooooo`0=ooooo`?o0000O?ooool003Kooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`0@ooooo`?o0000NOooool003Kooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`0Cooooo`?o0000M_ooool003Kooooo00?o0000ooooooooool0
F?ooool2o`0001Oooooo1?l0001booooo`00=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooooooo01[ooooo0ol0001_ooooo`00=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo
oooo01gooooo1?l0001[ooooo`00=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
027ooooo0ol0001Xooooo`00=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo02Co
oooo0ol0001Uooooo`00=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo02Oooooo
0ol0001Rooooo`00=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo02[ooooo0ol0
001Oooooo`00=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo02gooooo0ol0001L
ooooo`00=_ooool00ol0003oooooooooo`1Hooooo`;o0000<Oooool3o`0005Wooooo000fooooo`03
o`000?oooooooooo05Sooooo00?o0000ooooooooool0<oooool2o`0005Oooooo000fooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool0=Oooool3o`0005Cooooo000fooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool0>?ooool3o`00057ooooo000fooooo`03o`000?oooooo
oooo05Sooooo00?o0000ooooooooool0>oooool3o`0004kooooo000fooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool0?_ooool2o`0004cooooo000fooooo`03o`000?oooooooooo05So
oooo00?o0000ooooooooool0@?ooool3o`0004Wooooo000fooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool0@oooool2o`0004Oooooo000fooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool0AOooool2o`0004Gooooo000fooooo`03o`000?oooooooooo05Sooooo0_l00018
ooooo`;o0000@oooool003Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`19oooo
o`;o0000@Oooool003Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1;ooooo`;o
0000?oooool003Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1=ooooo`;o0000
?Oooool003Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo03[ooooo000fooooo`03o`000?oooooooooo04kooooo1Ol00005ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool0>Oooool003Kooooo00?o0000ooooooooool0Coooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo057ooooo0_l0000iooooo`00=_ooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`0fooooo`00=_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Co
oooo0_l0001Eooooo`03o`000?oooooooooo03Gooooo000fooooo`03o`000?oooooooooo04kooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo05Cooooo00?o0000oooooooo
ool0=Oooool003Kooooo00?o0000ooooooooool0C_ooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0dooooo`00=_ooool00ol0003ooooo
ooooo`1?ooooo`?o00001_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo03?ooooo
000fooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`0cooooo`00=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05Oooooo00?o0000
ooooooooool0<_ooool003Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2<oooo
o`00=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo08cooooo000fooooo`03o`00
0?oooooooooo05Sooooo0_l0001Hooooo`03o`000?oooooooooo03;ooooo000fooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0cooooo`00=_ooool0
0ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0=?ooool0
03Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
03Gooooo000fooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`0fooooo`00=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo057ooooo
0_l0000iooooo`00=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04oooooo0_l0
000kooooo`00=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04cooooo0ol0000m
ooooo`00=_ooool00ol0003oooooooooo`1Hooooo`;o0000Boooool2o`00043ooooo000fooooo`03
o`000?oooooooooo05Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`10ooooo`00
=_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04Kooooo0ol00013ooooo`00=_oo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04?ooooo0ol00016ooooo`00=_ooool0
0ol0003oooooooooo`1Hooooo`03o`000?oooooooooo043ooooo0ol00019ooooo`00=_ooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo03cooooo1?l0001<ooooo`00=_ooool00ol0003o
ooooooooo`1Hooooo`03o`000?oooooooooo03Sooooo1?l0001@ooooo`00=_ooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo03Gooooo0ol0001Dooooo`00=_ooool00ol0003ooooooooo
o`1Hooooo`03o`000?oooooooooo037ooooo1?l0001Gooooo`00=_ooool00ol0003oooooooooo`1H
ooooo`;o0000;_ooool4o`0005_ooooo000fooooo`03o`000?oooooooooo05Sooooo00?o0000oooo
ooooool0:_ooool3o`0005oooooo000fooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool09Oooool5o`0006;ooooo000fooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
8?ooool5o`0006Oooooo000fooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool06?oo
ool8o`0006cooooo000fooooo`03o`000?oooooooooo053ooooo0ol00005ooooo`03o`000?oooooo
oooo00oooooo2Ol0001dooooo`00=_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02_ooool5o`0007gooooo000fooooo`03o`000?oooooooooo04ko
oooo1Ol00005ooooo`03o`000?oooooooooo00Cooooo1_l00022ooooo`00=_ooool00ol0003ooooo
ooooo`1>ooooo`04o`000?ooooooooooo`0000Kooooo1ol00028ooooo`00=_ooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooo000000So0000SOooool003Kooooo00?o0000ooooooooool0B_oo
ool8o`0000Kooooo00?o0000ooooooooool0S?ooool003Kooooo00?o0000ooooooooool0AOooool5
o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2<ooooo`00=_ooool00ol0
003oooooooooo`0mooooo`So00004oooool00ol0003oooooooooo`2<ooooo`00=_ooool00ol0003o
ooooooooo`0booooo`_o00006oooool00ol0003oooooooooo`2<ooooo`00=_ooool00ol0003ooooo
ooooo`0Wooooo`_o00009_ooool00ol0003oooooooooo`2<ooooo`00=_ooool00ol0003ooooooooo
o`0Looooo`_o0000<Oooool00ol0003oooooooooo`2<ooooo`00=_ooool00ol0003oooooooooo`0D
ooooo`So0000??ooool2o`0008gooooo000fooooo`03o`000?oooooooooo00oooooo1Ol00014oooo
o`03o`000?oooooooooo08cooooo000fooooo`03o`000?oooooooooo00Oooooo2?l00019ooooo`03
o`000?oooooooooo08cooooo000aooooo`oo0000DOooool00ol0003oooooooooo`2<ooooo`00:?oo
ool9o`00063ooooo00?o0000ooooooooool0S?ooool001Cooooo5?l0001Yooooo`03o`000?oooooo
oooo08cooooo000?ooooo`Go0000OOooool00ol0003oooooooooo`2<ooooo`00TOooool00ol0003o
ooooooooo`2<ooooo`00TOooool2o`0008gooooo002Aooooo`03o`000?oooooooooo08cooooo002A
ooooo`03o`000?oooooooooo08cooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0223079, -5.37607, \
0.000153848, 0.0607676}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.3", "AOG2."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Geometric Intensity Analysis", "Subsubsection",
  CellTags->{"AOG0.", "2.3.4", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell["(*Fast Version including aperture effects: presently=10*)", "Input",
  CellLabel->"In[140]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell["\<\
Clear[GeometricIntensity];
GeometricIntensity = 
\tFunction[{ys,d},
\t\tApply[Plus,
\t\tMap[If[Abs[#]<=5.,1/(Abs[dummy2]/.y->#+.0001),0]&,
\t\t\tSelect[
\t\t\t\tChop[dummy1]
\t\t\t,
\t\t\t\t(Head[#]=!=Symbol&&Im[#]==0)&
\t\t\t]
\t\t]]
\t]/.{dummy1->(y/.inversey),dummy2->Dy};\
\>", "Input",
  CellLabel->"In[141]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[CellGroupData[{

Cell["GeometricIntensity//InputForm", "Input",
  CellLabel->"In[143]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell["\<\
Function[{ys, d}, 
 Plus @@ (If[Abs[#1] <= 5., 1/(Abs[0.0088364155326911 - 0.02376778501234205*d \
- 0.0015757513747870293*y^2 - 0.00006062604240982259*d*y^2 - \
3.6305315986759584*^-6*y^4 - 
         1.3656859916723253*^-7*d*y^4] /. y -> #1 + 0.0001), 0] & ) /@ 
   Select[Chop[{Root[ys - 0.0088364155326911*#1 + 0.02376778501234205*d*#1 + \
0.0005252504582623431*#1^3 + 0.000020208680803274196*d*#1^3 + \
7.261063197351916*^-7*#1^5 + 
         2.7313719833446508*^-8*d*#1^5 & , 1], Root[ys - \
0.0088364155326911*#1 + 0.02376778501234205*d*#1 + 0.0005252504582623431*#1^3 \
+ 0.000020208680803274196*d*#1^3 + 
         7.261063197351916*^-7*#1^5 + 2.7313719833446508*^-8*d*#1^5 & , 2], \
Root[ys - 0.0088364155326911*#1 + 0.02376778501234205*d*#1 + \
0.0005252504582623431*#1^3 + 
         0.000020208680803274196*d*#1^3 + 7.261063197351916*^-7*#1^5 + \
2.7313719833446508*^-8*d*#1^5 & , 3], 
      Root[ys - 0.0088364155326911*#1 + 0.02376778501234205*d*#1 + \
0.0005252504582623431*#1^3 + 0.000020208680803274196*d*#1^3 + \
7.261063197351916*^-7*#1^5 + 2.7313719833446508*^-8*d*#1^5 & , 4], 
      Root[ys - 0.0088364155326911*#1 + 0.02376778501234205*d*#1 + \
0.0005252504582623431*#1^3 + 0.000020208680803274196*d*#1^3 + \
7.261063197351916*^-7*#1^5 + 2.7313719833446508*^-8*d*#1^5 & , 
       5]}], Head[#1] =!= Symbol && Im[#1] == 0 & ]]\
\>", "Output",
  CellLabel->"Out[143]//InputForm=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[NIntegrate]", "Input",
  CellLabel->"In[144]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"AccuracyGoal", "\[Rule]", 
          InterpretationBox["\[Infinity]",
            DirectedInfinity[ 1]]}], ",", \(Compiled \[Rule] True\), 
        ",", \(GaussPoints \[Rule] Automatic\), 
        ",", \(MaxPoints \[Rule] Automatic\), ",", \(MaxRecursion \[Rule] 6\),
         ",", \(Method \[Rule] Automatic\), ",", \(MinRecursion \[Rule] 0\), 
        ",", \(PrecisionGoal \[Rule] Automatic\), 
        ",", \(SingularityDepth \[Rule] 4\), 
        ",", \(WorkingPrecision \[Rule] 16\)}], "}"}]], "Output",
  CellLabel->"Out[144]=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Off[NIntegrate::slwcon];
NIntegrate[GeometricIntensity[ys,0],{ys,-.04,.04},MaxRecursion->12]\
\>", "Input",
  CellLabel->"In[145]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[BoxData[
    \(9.956931368784398`\)], "Output",
  CellLabel->"Out[146]=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell["On[NIntegrate::slwcon];", "Input",
  CellLabel->"In[147]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[CellGroupData[{

Cell["Plot[GeometricIntensity[ys,0],{ys,-.03,.03}];", "Input",
  CellLabel->"In[148]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 15.873 0.0147151 0.000433187 [
[.02381 .00222 -15 -9 ]
[.02381 .00222 15 0 ]
[.18254 .00222 -15 -9 ]
[.18254 .00222 15 0 ]
[.34127 .00222 -15 -9 ]
[.34127 .00222 15 0 ]
[.65873 .00222 -12 -9 ]
[.65873 .00222 12 0 ]
[.81746 .00222 -12 -9 ]
[.81746 .00222 12 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.4875 .10135 -18 -4.5 ]
[.4875 .10135 0 4.5 ]
[.4875 .18799 -18 -4.5 ]
[.4875 .18799 0 4.5 ]
[.4875 .27463 -18 -4.5 ]
[.4875 .27463 0 4.5 ]
[.4875 .36126 -18 -4.5 ]
[.4875 .36126 0 4.5 ]
[.4875 .4479 -24 -4.5 ]
[.4875 .4479 0 4.5 ]
[.4875 .53454 -24 -4.5 ]
[.4875 .53454 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-0.03)] .02381 .00222 0 1 Mshowa
.18254 .01472 m
.18254 .02097 L
s
[(-0.02)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(-0.01)] .34127 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(0.01)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(0.02)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(0.03)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .10135 m
.50625 .10135 L
s
[(200)] .4875 .10135 1 0 Mshowa
.5 .18799 m
.50625 .18799 L
s
[(400)] .4875 .18799 1 0 Mshowa
.5 .27463 m
.50625 .27463 L
s
[(600)] .4875 .27463 1 0 Mshowa
.5 .36126 m
.50625 .36126 L
s
[(800)] .4875 .36126 1 0 Mshowa
.5 .4479 m
.50625 .4479 L
s
[(1000)] .4875 .4479 1 0 Mshowa
.5 .53454 m
.50625 .53454 L
s
[(1200)] .4875 .53454 1 0 Mshowa
.125 Mabswid
.5 .03637 m
.50375 .03637 L
s
.5 .05803 m
.50375 .05803 L
s
.5 .07969 m
.50375 .07969 L
s
.5 .12301 m
.50375 .12301 L
s
.5 .14467 m
.50375 .14467 L
s
.5 .16633 m
.50375 .16633 L
s
.5 .20965 m
.50375 .20965 L
s
.5 .23131 m
.50375 .23131 L
s
.5 .25297 m
.50375 .25297 L
s
.5 .29629 m
.50375 .29629 L
s
.5 .31795 m
.50375 .31795 L
s
.5 .33961 m
.50375 .33961 L
s
.5 .38292 m
.50375 .38292 L
s
.5 .40458 m
.50375 .40458 L
s
.5 .42624 m
.50375 .42624 L
s
.5 .46956 m
.50375 .46956 L
s
.5 .49122 m
.50375 .49122 L
s
.5 .51288 m
.50375 .51288 L
s
.5 .5562 m
.50375 .5562 L
s
.5 .57786 m
.50375 .57786 L
s
.5 .59952 m
.50375 .59952 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.08255 .01472 L
.0932 .01472 L
.10458 .01472 L
.11009 .01472 L
.11531 .01472 L
.11999 .01472 L
.12127 .01472 L
.12197 .01472 L
.12263 .01472 L
.12379 .02792 L
.12507 .02794 L
.14415 .0282 L
.18292 .02879 L
.22415 .02949 L
.24474 .02988 L
.25477 .03007 L
.26386 .03026 L
.26843 .03035 L
.27338 .03046 L
.27565 .03051 L
.27689 .03053 L
.27805 .03056 L
.27903 .03058 L
s
.27903 .03058 m
.27961 .61803 L
s
.28178 .61803 m
.28234 .54876 L
.28356 .4663 L
.28486 .41126 L
.28597 .3779 L
.28719 .34973 L
.2885 .32614 L
.28991 .30585 L
.29246 .27795 L
.2949 .2581 L
.29746 .24176 L
.30205 .21989 L
.30705 .20265 L
.31159 .19069 L
.31649 .18043 L
.32179 .17145 L
.33124 .15917 L
.34016 .15046 L
.34962 .14325 L
.36003 .13699 L
.37103 .13174 L
.38108 .12785 L
.40052 .12209 L
.41124 .11967 L
.42142 .11776 L
.43103 .11626 L
.44126 .11493 L
.45085 .11392 L
.45966 .11318 L
.46997 .11251 L
.47539 .11224 L
.48111 .11201 L
.48352 .11194 L
.4861 .11187 L
.48832 .11182 L
.49074 .11177 L
.49222 .11175 L
.49358 .11173 L
.49486 .11172 L
.49554 .11171 L
.49627 .11171 L
.49753 .1117 L
.49871 .1117 L
.49937 .1117 L
.50006 .11169 L
.5013 .1117 L
.50254 .1117 L
.50324 .1117 L
.50388 .11171 L
.50506 .11172 L
Mistroke
.50631 .11173 L
.50848 .11176 L
.51087 .1118 L
.51615 .11193 L
.52108 .11209 L
.52994 .1125 L
.53946 .11311 L
.54961 .11397 L
.56067 .11516 L
.57023 .11644 L
.58079 .11814 L
.60054 .12235 L
.61136 .12536 L
.62154 .12879 L
.63135 .13278 L
.64169 .13793 L
.65138 .14394 L
.66019 .15076 L
.66972 .16024 L
.67461 .16629 L
.67991 .17412 L
.68482 .18295 L
.68935 .19295 L
.69368 .20485 L
.69827 .22117 L
.70079 .23252 L
.70319 .24556 L
.70537 .26002 L
.70769 .27935 L
.70901 .29286 L
.7102 .30727 L
.71253 .34422 L
.71384 .37294 L
.71453 .39166 L
.71525 .41526 L
.71589 .44032 L
.71659 .47445 L
.71782 .56336 L
Mfstroke
.71782 .56336 m
.71819 .61803 L
s
.72083 .61803 m
.72125 .03058 L
.72239 .03055 L
.72729 .03045 L
.73612 .03026 L
.77692 .02947 L
.81621 .02881 L
.85398 .02823 L
.86341 .0281 L
.86856 .02803 L
.87334 .02796 L
.87464 .02794 L
.87586 .02793 L
.87653 .02792 L
.87726 .01472 L
.87854 .01472 L
.88423 .01472 L
.8942 .01472 L
.93514 .01472 L
.97457 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[148]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000Goooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0001Kooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o0000@?ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol0000Gooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000_ooool5o`0001Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`?o00001?ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005Oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0?_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool05Oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005Ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`01ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`0<ooooo`Go00000_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03_ooool5o`0000;ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
03kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo01Gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000oooool2o`0001Kooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Cooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`;o00001?ooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01?ooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool04oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0?_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool00008ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`01ooooo`001oooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`0Cooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`;o0000@?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo0_l0000Gooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00Oooool000Sooooo0_l0000:ooooo`;o
00000oooool3o`0001Oooooo0_l0000:ooooo`;o00000oooool3o`0001Oooooo0_l0000:ooooo`;o
00001?ooool00ol0003oooooooooo`0oooooo`;o00002_ooool2o`0000Cooooo00?o0000oooooooo
ool05_ooool2o`0000[ooooo0_l00003ooooo`?o00005oooool2o`0000[ooooo0_l00003ooooo`?o
00001?ooool0097ooooo00?o0000ooooooooool0S?ooool0097ooooo00?o0000ooooooooool0S?oo
ool0097ooooo00?o0000ooooooooool0S?ooool0097ooooo00?o0000ooooooooool0S?ooool000So
ooooool0000Co`0000Kooooo000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo0_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`003oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool02oooool002[ooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02Kooooo000Zooooob_o0000??ooool00ol0
003oooooooooo`0iooooob_o0000:?ooool005Cooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo053ooooo001Dooooo`03o`000?oooooooooo03[ooooo
0_l0000jooooo`03o`000?oooooooooo053ooooo001Dooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`1@ooooo`00E?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo053ooooo001Dooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1@ooooo`00
E?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
D?ooool005Cooooo00?o0000ooooooooool0>_ooool2o`0003[ooooo00?o0000ooooooooool0D?oo
ool005Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo053ooooo001Dooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`1@ooooo`00E?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo053ooooo001Dooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`1@ooooo`00E?ooool00ol0003oooooooooo`0j
ooooo`;o0000>_ooool00ol0003oooooooooo`1@ooooo`00E?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo053ooooo001Dooooo`03o`00
0?oooooooooo02Cooooo1Ol00003ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`1@ooooo`00E?ooool00ol0003oooooooooo`0Uooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo053ooooo001Doooo
o`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00oooool2o`0003[ooooo00?o0000ooooooooool0D?oo
ool005Cooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000ooooooooool09?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0;o`00
03Oooooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000ooooooooool09Oooool@o`0000Go
oooo00?o0000ooooooooool00_ooool>o`0002Wooooo00?o0000ooooooooool0D?ooool005Cooooo
00?o0000ooooooooool08oooool5o`0001;ooooo00?o0000ooooooooool04?ooool7o`0002;ooooo
00?o0000ooooooooool0D?ooool005Cooooo00?o0000ooooooooool07Oooool6o`0001Oooooo00?o
0000ooooooooool05oooool4o`0001kooooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000
ooooooooool06_ooool3o`0001gooooo0_l0000Looooo`?o00006oooool00ol0003oooooooooo`1@
ooooo`00E?ooool00ol0003oooooooooo`0Hooooo`;o00008?ooool00ol0003oooooooooo`0Noooo
o`;o00006Oooool00ol0003oooooooooo`1@ooooo`00E?ooool00ol0003oooooooooo`0Eooooo`?o
00008_ooool00ol0003oooooooooo`0Pooooo`;o00005oooool00ol0003oooooooooo`1@ooooo`00
E?ooool00ol0003oooooooooo`0Booooo`?o00009Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02?ooooo0ol0000Cooooo`03o`000?oo
oooooooo053ooooo001Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool2
o`0002Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1@ooooo`00E?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo053ooooo001Dooooo`03o`000?oooooooooo00go
oooo0_l0000[ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1@ooooo`00E?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo
001Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1@ooooo`00E?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02gooooo0_l0000]ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0D?ooool005Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1@ooooo`00
E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo053ooooo001Dooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Looooo`?o00000oooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`00E?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`Go00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Gooooo0_l0000`ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0D?ooool005Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Kooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1@ooooo`00E?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo053ooooo001Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool2o`00
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1@ooooo`00E?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool2
o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1@ooooo`00E?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
053ooooo001Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool2o`0003;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`00E?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo053ooooo001Dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0D?ooool005Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1@
ooooo`00E?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo053ooooo001Dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0dooooo`;o0000=?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo053ooooo001Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0D?oo
ool005Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1@ooooo`00E?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo053ooooo001Dooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1@ooooo`00E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo0_l0
000eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Gooooo00Go0000
ooooooooooooooooo`00001Booooo`00E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0=Oooool01Ol0003ooooooooooooooooo000005;ooooo001D
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool3o`0000Cooooo0_l00004
ooooo`;o00001_ooool00ol0003oooooooooo`0eooooo`05o`000?ooooooooooooooool00000D_oo
ool005Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool0=Oooool01Ol0003ooooooooooooooooo000005;ooooo001Dooooo`05
o`000?ooooooooooooooool000008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03Gooooo
00Go0000ooooooooooooooooo`00001Booooo`00E?ooool01Ol0003ooooooooooooooooo000002;o
oooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool2
o`0003Kooooo00Go0000ooooooooooooooooo`00001Booooo`00E?ooool01Ol0003ooooooooooooo
oooo000002;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool0=Oooool01Ol0003ooooooooooooooooo0000
05;ooooo001Dooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`0eooooo`05o`000?ooooooooooooooool00000D_ooool005Cooooo00Go0000oooooooooooooooo
o`00000Tooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo03Gooooo
00Go0000ooooooooooooooooo`00001Booooo`00E?ooool01Ol0003ooooooooooooooooo000003So
oooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool0001Booooo`00E?ooool01?l0003o
ooooooooool0000iooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo0000D_ooool0
05Cooooo00Co0000oooooooooooo0000>Oooool2o`0003Oooooo00Co0000oooooooooooo0000D_oo
ool005Cooooo00Co0000oooooooooooo0000>Oooool00ol0003oooooooooo`0fooooo`04o`000?oo
ooooooooo`0005;ooooo001Dooooo`04o`000?ooooooooooo`0003Wooooo00?o0000ooooooooool0
=_ooool01?l0003oooooooooool0001Booooo`00E?ooool01?l0003oooooooooool0000iooooo`03
o`000?oooooooooo03Kooooo00Co0000oooooooooooo0000D_ooool005Cooooo00Co0000oooooooo
oooo0000>Oooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0005;ooooo001Doooo
o`04o`000?ooooooooooo`0003Wooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool0
001Booooo`00E?ooool01?l0003oooooooooool0000iooooo`;o0000=oooool01?l0003ooooooooo
ool0001Booooo`00E?ooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo03Kooooo
00Co0000oooooooooooo0000D_ooool005Cooooo00Co0000oooooooooooo0000>Oooool00ol0003o
ooooooooo`0fooooo`04o`000?ooooooooooo`0005;ooooo001Dooooo`04o`000?ooooooooooo`00
03Wooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool0001Booooo`00E?ooool01?l0
003oooooooooool0000iooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo0000D_oo
ool005Cooooo00Co0000oooooooooooo0000>Oooool00ol0003oooooooooo`0fooooo`04o`000?oo
ooooooooo`0005;ooooo001Dooooo`03o`000?oooooo000003[ooooo0_l0000gooooo`04o`000?oo
ooooooooo`0005;ooooo001Dooooo`03o`000?oooooo000003[ooooo00?o0000ooooooooool0=_oo
ool01?l0003oooooooooool0001Booooo`00E?ooool00ol0003oooooo`00000jooooo`03o`000?oo
oooooooo03Kooooo00Co0000oooooooooooo0000D_ooool005Cooooo00?o0000ooooool000009Ooo
ool3o`0000Cooooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`0fooooo`04o`000?oo
ooooooooo`0005;ooooo001Dooooo`03o`000?oooooo000002Cooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`0fooooo`04o`000?ooooooooooo`0005;ooooo001Dooooo`03o`000?oooooo0000
02Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001Oooool2o`0003Oooooo00Co0000oooooooooooo0000D_ooool005Cooooo
00?o0000ooooool000009Oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooool00000D_ooool005Co
oooo00?o0000ooooool000009?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooool00000D_ooool005Cooooo00?o0000ooooool000009?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooool00000D_ooool005Cooooo00?o0000ooooool00000
9Oooool3o`0000Cooooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooo000005;ooooo001Dooooo`03o`000?oooooo000003[ooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooo`00001Booooo`00E?ooool00ol0003oooooo`00000jooooo`;o0000>?ooool0
0ol0003oooooo`00001Booooo`00E?ooool00ol0003oooooo`00000jooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooool00000D_ooool005Cooooo00?o0000ooooool00000>_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooo000005;ooooo001Dooooo`03o`000?oooooo000003[ooooo
00?o0000ooooooooool0=oooool00ol0003oooooo`00001Booooo`00E?ooool00ol0003oooooo`00
000jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooool00000D_ooool005Cooooo00?o0000
ooooool00000>_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo000005;ooooo001Doooo
o`03o`000?oooooo000003[ooooo0_l0000hooooo`03o`000?oooooo000005;ooooo001Dooooo`03
o`000?oooooo000003[ooooo00?o0000ooooooooool0=oooool00ol0003oooooo`00001Booooo`00
E?ooool00ol0003oooooo`00000jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooool00000
D_ooool005Cooooo00?o0000ooooool00000>_ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooo000005;ooooo001Dooooo`03o`000?oooooo000003[ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooo`00001Booooo`00E?ooool00ol0003oooooo`00000jooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooool00000D_ooool005Cooooo00?o0000ooooool00000>_ooool2o`0003So
oooo00?o0000ooooool00000D_ooool005Cooooo00?o0000ooooool00000>_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooo000005;ooooo001Dooooo`03o`000?oooooo000003[ooooo00?o
0000ooooooooool0=oooool00ol0003oooooo`00001Booooo`00E?ooool00ol0003oooooo`00000j
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooool00000D_ooool005Cooooo0_l0000Poooo
o`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooo000005;ooooo001Dooooo`;o00008Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooool00000D_ooool005Cooooo0_l0000Q
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Gooooo0_l0000hooooo`03o`000?oooooo000005;o
oooo001Dooooo`;o00008Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooool00000D_ooool005Cooooo0_l0000Qooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0=oooool00ol0003oooooo`00001Booooo`00E?oo
ool2o`00023ooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03Sooooo0_l0001Boooo
o`00E?ooool2o`00027ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`;o
00001_ooool00ol0003oooooooooo`0hooooo`;o0000D_ooool005Cooooo0_l0000kooooo`03o`00
0?oooooooooo03Sooooo0_l0001Booooo`00E?ooool2o`0003_ooooo0_l0000iooooo`;o0000D_oo
ool005Cooooo0_l0000kooooo`03o`000?oooooooooo03Sooooo0_l0001Booooo`00E?ooool2o`00
03_ooooo00?o0000ooooooooool0>?ooool2o`0005;ooooo001Dooooo`;o0000>oooool00ol0003o
ooooooooo`0hooooo`;o0000D_ooool005Cooooo0_l0000kooooo`03o`000?oooooooooo03Sooooo
0_l0001Booooo`00E?ooool2o`0003_ooooo00?o0000ooooooooool0>?ooool2o`0005;ooooo001D
ooooo`;o0000>oooool2o`0003Wooooo0_l0001Booooo`00E?ooool2o`0003_ooooo00?o0000oooo
ooooool0>?ooool2o`0005;ooooo001Dooooo`;o0000>oooool00ol0003oooooooooo`0hooooo`;o
0000D_ooool005Cooooo0_l0000kooooo`03o`000?oooooooooo03Sooooo0_l0001Booooo`00E?oo
ool2o`0003_ooooo00?o0000ooooooooool0>?ooool2o`0005;ooooo001Dooooo`;o0000>oooool0
0ol0003oooooooooo`0hooooo`;o0000D_ooool005Cooooo0_l0000kooooo`;o0000>Oooool2o`00
05;ooooo001Dooooo`;o0000>oooool00ol0003oooooooooo`0hooooo`;o0000D_ooool005Cooooo
0_l0000kooooo`03o`000?oooooooooo03Sooooo0_l0001Booooo`00E?ooool2o`00023ooooo0ol0
0002ooooo`Go00000oooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo03Sooooo0_l0
001Booooo`00E?ooool2o`00027ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`0hooooo`;o0000D_ooool005Cooooo0_l0000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool0>?ooool2o`0005;ooooo001Dooooo`;o00008Oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00?ooooo0_l0000iooooo`;o0000D_ooool005Cooooo0_l0000Qoooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0hooooo`;o0000
D_ooool005Cooooo0_l0000Pooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
03Sooooo0_l0001Booooo`00E?ooool2o`00027ooooo00?o0000ooooooooool00_ooool3o`0000Co
oooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`0hooooo`;o0000D_ooool005Cooooo
0_l0000kooooo`03o`000?oooooooooo03Sooooo0_l0001Booooo`00E?ooool2o`0003_ooooo00?o
0000ooooooooool0>?ooool2o`0005;ooooo001Dooooo`;o0000>oooool2o`0003Wooooo0_l0001B
ooooo`00E?ooool2o`0003_ooooo00?o0000ooooooooool0>?ooool2o`0005;ooooo001Dooooo`;o
0000>oooool00ol0003oooooooooo`0hooooo`;o0000D_ooool005Cooooo0_l0000kooooo`03o`00
0?oooooooooo03Sooooo0_l0001Booooo`00E?ooool2o`0003_ooooo00?o0000ooooooooool0>?oo
ool2o`0005;ooooo001Dooooo`;o0000>oooool00ol0003oooooooooo`0hooooo`;o0000D_ooool0
05Cooooo0_l0000kooooo`;o0000>Oooool2o`0005;ooooo001Dooooo`;o0000>oooool00ol0003o
ooooooooo`0hooooo`;o0000D_ooool005Cooooo0_l0000kooooo`03o`000?oooooooooo03Sooooo
0_l0001Booooo`00E?ooool2o`0003_ooooo00?o0000ooooooooool0>?ooool2o`0005;ooooo001D
ooooo`;o0000>oooool00ol0003oooooooooo`0hooooo`;o0000D_ooool005Cooooo0_l0000koooo
o`;o0000>Oooool2o`0005;ooooo001Dooooo`;o0000>oooool00ol0003oooooooooo`0hooooo`;o
0000D_ooool005Cooooo0_l0000kooooo`03o`000?oooooooooo03Sooooo0_l0001Booooo`00E?oo
ool2o`0003_ooooo00?o0000ooooooooool0>?ooool2o`0005;ooooo001Dooooo`;o0000>oooool0
0ol0003oooooooooo`0hooooo`;o0000D_ooool005Cooooo0_l0000kooooo`03o`000?oooooooooo
03Sooooo0_l0001Booooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0334975, -105.037, \
0.000231017, 8.46502}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["paraxialfocus = d/.Solve[Evaluate[(Dy/.y->0)==0],d][[1]]", "Input",
  CellLabel->"In[149]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[BoxData[
    \(0.37178119576992796`\)], "Output",
  CellLabel->"Out[149]=",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[GeometricIntensity[ys,paraxialfocus],{ys,-.03,.03}];", "Input",
  CellLabel->"In[150]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 15.873 0.0147151 0.000349293 [
[.02381 .00222 -15 -9 ]
[.02381 .00222 15 0 ]
[.18254 .00222 -15 -9 ]
[.18254 .00222 15 0 ]
[.34127 .00222 -15 -9 ]
[.34127 .00222 15 0 ]
[.65873 .00222 -12 -9 ]
[.65873 .00222 12 0 ]
[.81746 .00222 -12 -9 ]
[.81746 .00222 12 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.4875 .10204 -18 -4.5 ]
[.4875 .10204 0 4.5 ]
[.4875 .18936 -18 -4.5 ]
[.4875 .18936 0 4.5 ]
[.4875 .27668 -18 -4.5 ]
[.4875 .27668 0 4.5 ]
[.4875 .36401 -24 -4.5 ]
[.4875 .36401 0 4.5 ]
[.4875 .45133 -24 -4.5 ]
[.4875 .45133 0 4.5 ]
[.4875 .53865 -24 -4.5 ]
[.4875 .53865 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-0.03)] .02381 .00222 0 1 Mshowa
.18254 .01472 m
.18254 .02097 L
s
[(-0.02)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(-0.01)] .34127 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(0.01)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(0.02)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(0.03)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .10204 m
.50625 .10204 L
s
[(250)] .4875 .10204 1 0 Mshowa
.5 .18936 m
.50625 .18936 L
s
[(500)] .4875 .18936 1 0 Mshowa
.5 .27668 m
.50625 .27668 L
s
[(750)] .4875 .27668 1 0 Mshowa
.5 .36401 m
.50625 .36401 L
s
[(1000)] .4875 .36401 1 0 Mshowa
.5 .45133 m
.50625 .45133 L
s
[(1250)] .4875 .45133 1 0 Mshowa
.5 .53865 m
.50625 .53865 L
s
[(1500)] .4875 .53865 1 0 Mshowa
.125 Mabswid
.5 .03218 m
.50375 .03218 L
s
.5 .04964 m
.50375 .04964 L
s
.5 .06711 m
.50375 .06711 L
s
.5 .08457 m
.50375 .08457 L
s
.5 .1195 m
.50375 .1195 L
s
.5 .13697 m
.50375 .13697 L
s
.5 .15443 m
.50375 .15443 L
s
.5 .1719 m
.50375 .1719 L
s
.5 .20683 m
.50375 .20683 L
s
.5 .22429 m
.50375 .22429 L
s
.5 .24176 m
.50375 .24176 L
s
.5 .25922 m
.50375 .25922 L
s
.5 .29415 m
.50375 .29415 L
s
.5 .31161 m
.50375 .31161 L
s
.5 .32908 m
.50375 .32908 L
s
.5 .34654 m
.50375 .34654 L
s
.5 .38147 m
.50375 .38147 L
s
.5 .39894 m
.50375 .39894 L
s
.5 .4164 m
.50375 .4164 L
s
.5 .43387 m
.50375 .43387 L
s
.5 .4688 m
.50375 .4688 L
s
.5 .48626 m
.50375 .48626 L
s
.5 .50373 m
.50375 .50373 L
s
.5 .52119 m
.50375 .52119 L
s
.5 .55612 m
.50375 .55612 L
s
.5 .57358 m
.50375 .57358 L
s
.5 .59105 m
.50375 .59105 L
s
.5 .60851 m
.50375 .60851 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0293 m
.06244 .03016 L
.10458 .03126 L
.14415 .03249 L
.18221 .0339 L
.22272 .03575 L
.26171 .03802 L
.30316 .04123 L
.32392 .04329 L
.34309 .0456 L
.36292 .04854 L
.3815 .05201 L
.40022 .05658 L
.4108 .05985 L
.42085 .06362 L
.43053 .06809 L
.4411 .07433 L
.4507 .08188 L
.45962 .09148 L
.4647 .0987 L
.47019 .10875 L
.47537 .12157 L
.47784 .12938 L
.48014 .13811 L
.48446 .16004 L
.48674 .17633 L
.48919 .19995 L
.49042 .21551 L
.49176 .23672 L
.49302 .26281 L
.49419 .29511 L
.49524 .33505 L
.4964 .40071 L
.49761 .52233 L
s
.49761 .52233 m
.49801 .61803 L
s
.502 .61803 m
.50237 .52494 L
.50345 .41206 L
.50471 .33712 L
.50543 .30812 L
.50609 .28652 L
.5073 .25551 L
.50858 .23085 L
.50981 .21239 L
.51113 .19642 L
.51351 .17434 L
.51635 .15528 L
.51893 .14213 L
.52348 .12507 L
.52843 .11182 L
.5331 .10241 L
.53744 .09548 L
.54253 .08887 L
.54803 .08307 L
.558 .07496 L
.5677 .06903 L
.57662 .06471 L
.59548 .05784 L
.61616 .05252 L
.63571 .04877 L
.65664 .04564 L
.69805 .04112 L
.73795 .03805 L
.77633 .03581 L
.81716 .03393 L
.85648 .03247 L
.89429 .0313 L
.93454 .03024 L
.97328 .02936 L
.97619 .0293 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[150]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000Goooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0001Kooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o0000@?ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol0000Gooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000_ooool5o`0001Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`?o00001?ooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005Oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0?_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool05Oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005Ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`01ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`0<ooooo`Go00000_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03_ooool5o`0000;ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
03kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo01Gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000oooool2o`0001Kooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Cooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`;o00001?ooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01?ooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool04oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0?_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool00008ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`01ooooo`001oooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`0Cooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`;o0000@?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo0_l0000Gooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00Oooool000Sooooo0_l0000:ooooo`;o
00000oooool3o`0001Oooooo0_l0000:ooooo`;o00000oooool3o`0001Oooooo0_l0000:ooooo`;o
00001?ooool00ol0003oooooooooo`0oooooo`;o00002_ooool2o`0000Cooooo00?o0000oooooooo
ool05_ooool2o`0000[ooooo0_l00003ooooo`?o00005oooool2o`0000[ooooo0_l00003ooooo`?o
00001?ooool0097ooooo00?o0000ooooooooool0S?ooool0097ooooo00?o0000ooooooooool0S?oo
ool0097ooooo00?o0000ooooooooool0S?ooool0097ooooo00?o0000ooooooooool0S?ooool000So
ooooool0000Co`0000Kooooo000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo000?ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00_ooooo002Aooooo`03o`000?oooooooooo08cooooo000?oooooaco0000I_ooool00ol0
003oooooooooo`1Soooooaco00003Oooool002_ooooo5_l0001@ooooo`;o0000CooooolEo`0002Wo
oooo0011oooooaKo0000>_ooool00ol0003oooooooooo`0hoooooaKo0000?_ooool005Oooooo2?l0
000booooo`03o`000?oooooooooo02gooooo2ol0001Dooooo`00Goooool;o`0002Oooooo00?o0000
ooooooooool09Oooool8o`0005oooooo001Zooooo`Go00008_ooool2o`00023ooooo1_l0001Woooo
o`00Koooool5o`0001gooooo00?o0000ooooooooool06oooool4o`0006gooooo001dooooo`Co0000
6Oooool00ol0003oooooooooo`0Hooooo`?o0000LOooool007Sooooo0ol0000Fooooo`03o`000?oo
oooooooo01Kooooo0_l0001dooooo`00Noooool2o`0001Cooooo00?o0000ooooooooool04oooool3
o`0007Kooooo001mooooo`03o`000?oooooooooo017ooooo0_l0000Aooooo`?o0000NOooool007ko
oooo0_l0000Aooooo`03o`000?oooooooooo00kooooo0_l0001looooo`00P?ooool2o`0000oooooo
00?o0000ooooooooool03?ooool2o`0007kooooo0022ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1mooooo`00Poooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0O_ooool008?ooooo00?o0000oooo
ooooool02oooool2o`0000[ooooo0_l00021ooooo`00Q?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0POooool007_ooooo1Ol00002ooooo`Co0000
0oooool2o`0000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`21ooooo`00O?oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo0_l000001Ooooooo0000oooooooooooo0000
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`22ooooo`00OOooool00ol0003o
ooooooooo`05ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo08;ooooo001nooooo`03o`000?oooooooooo00Co
oooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`03ooooo`;o00001oooool00ol0
003oooooooooo`23ooooo`00Noooool01_l0003ooooooooooooooooo0000ooooo`Co00000oooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q?oo
ool007_ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Kooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Gooooo001looooo`?o0000
0_ooool5o`0000;ooooo0ol00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
QOooool008Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo08Gooooo002:ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`000?oooooo
oooo08Kooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`26ooooo`00R_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0Q_ooool008[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo08Kooooo002;ooooo`03o`000?oooooooooo00?ooooo0_l0
0003ooooo`03o`000?oooooooooo08Oooooo002;ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`27ooooo`00Roooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Qoooool008_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Oooooo002;ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00002:ooooo`00S?ooool00ol0003ooooo
ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`28ooooo`00S?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000R_ooool008cooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000008[ooooo002<ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo0000Roooool008cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0002;ooooo`00SOooool01?l0003oooooooooooooool2o`000003ooooool0003ooooo08[ooooo
002=ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`29ooooo`00O?oo
ool3o`0000Cooooo0_l00004ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool0ROooool007_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooo
ooooo`0008_ooooo001oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0008_ooooo001oooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`;o000000?oooooo`000?ooool0R_ooool007_ooooo1?l00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo08Wooooo001kooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool0ROooool007_ooooo1Ol00003ooooo`;o00001?ooool2o`0000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`29ooooo`00S_ooool00ol0003oooooooooo`02o`000003
ooooool0003ooooo08[ooooo002>ooooo`06o`000?ooooooooooo`000?oooooo0000S?ooool008ko
oooo00Ko0000oooooooooooo0000ooooool0002<ooooo`00S_ooool01_l0003oooooooooool0003o
ooooo`0008cooooo002>ooooo`06o`000?ooooooooooo`000?oooooo0000S?ooool008kooooo00?o
0000ooooooooool00ol0002<ooooo`00S_ooool01_l0003oooooooooool0003oooooo`0008cooooo
002>ooooo`06o`000?ooooooooooo`000?oooooo0000S?ooool008kooooo00Ko0000oooooooooooo
0000ooooool0002<ooooo`00S_ooool01_l0003oooooooooool0003oooooo`0008cooooo002>oooo
o`03o`000?oooooooooo00?o0000S?ooool008kooooo00?o0000ooooooooool00_l0002=ooooo`00
S_ooool00ol0003oooooooooo`02o`0008gooooo002?ooooo`04o`000?oooooo0000o`0008gooooo
002?ooooo`04o`000?oooooo0000o`0008gooooo002?ooooo`04o`000?oooooo0000o`0008gooooo
002?ooooo`04o`000?oooooo0000o`0008gooooo001mooooo`03o`000?oooooooooo00;ooooo0ol0
0004ooooo`;o00001?ooool01?l0003oooooo`000?l0002=ooooo`00OOooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooooooooooooooo0000
ooooo`;o0000SOooool007kooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002
ooooo`06o`000?ooooooooooooooool0003ooooo0_l0002=ooooo`00O_ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
08gooooo001oooooo`03o`000?oooooo000000?o00000oooool01?l0003oooooooooool00003oooo
o`04o`000?oooooo0000o`0008gooooo001kooooo`07o`000?ooooooooooooooool0003oooooo`00
0006ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000ooooool0003o0000SOooool007_ooooo
1Ol000000ooooooo0000o`000003o`0000?ooooo0_l00004ooooo`04o`000?oooooo0000o`0008go
oooo002?ooooo`04o`000?oooooo0000o`0008gooooo002?ooooo`04o`000?oooooo0000o`0008go
oooo002?ooooo`04o`000?oooooo0000o`0008gooooo002?ooooo`04o`000?oooooo0000o`0008go
oooo002?ooooo`04o`000?oooooo0000o`0008gooooo002?ooooo`04o`000?oooooo0000o`0008go
oooo002?ooooo`04o`000?oooooo0000o`0008gooooo002?ooooo`04o`000?oooooo0000o`0008go
oooo002?ooooo`04o`000?oooooo0000o`0008gooooo002?ooooo`04o`000?oooooo0000o`0008go
oooo002?ooooo`04o`000?oooooo0000o`0008gooooo002?ooooo`04o`000?oooooo0000o`0008go
oooo002?ooooo`04o`000?oooooo0000o`0008gooooo002?ooooo`04o`000?oooooo0000o`0008go
oooo002?ooooo`04o`000?oooooo0000o`0008gooooo002?ooooo`04o`000?oooooo0000o`0008go
oooo002?ooooo`04o`000?oooooo0000o`0008gooooo001fooooo`?o00001?ooool2o`0000Cooooo
0_l00004ooooo`;o00001?ooool01?l0003oooooo`000?l0002=ooooo`00Moooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00003ooooo`04o`000?oooooo0000o`0008gooooo001gooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000ooooool0003o0000SOooool007Oooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooo`000?l0002=ooooo`00Moooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`?o0000SOooool007Kooooo0_l00004ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`?o0000SOoo
ool007Oooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2
o`0008kooooo002@ooooo`?o0000SOooool0093ooooo0_l0002>ooooo`00T?ooool2o`0008kooooo
002@ooooo`;o0000S_ooool0093ooooo0_l0002>ooooo`00T?ooool3o`0008gooooo002@ooooo`;o
0000S_ooool0093ooooo0_l0002>ooooo`00T?ooool2o`0008kooooo002@ooooo`;o0000S_ooool0
093ooooo0ol0002=ooooo`00T?ooool2o`0008kooooo002@ooooo`;o0000S_ooool0093ooooo0_l0
002>ooooo`00T?ooool3o`0008gooooo002@ooooo`;o0000S_ooool0093ooooo0_l0002>ooooo`00
M_ooool3o`0000;ooooo1Ol00002ooooo`?o00001?ooool2o`0000Gooooo0_l0002>ooooo`00Mooo
ool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0002>ooooo`00Moooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`?o0000SOooool007Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`00
08kooooo001gooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003o`00
00?ooooo00Co0000oooooooooooo00001?ooool2o`0008kooooo001fooooo`;o00000oooool01ol0
003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool00004ooooo`;o0000
S_ooool007Oooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1Ol00003ooooo`;o00001Ooo
ool2o`0008kooooo002@ooooo`?o0000SOooool0093ooooo0_l0002>ooooo`00T?ooool2o`0008ko
oooo002@ooooo`;o0000S_ooool0093ooooo0_l0002>ooooo`00T?ooool3o`0008gooooo002@oooo
o`;o0000S_ooool0093ooooo0_l0002>ooooo`00T?ooool2o`0008kooooo002@ooooo`?o0000SOoo
ool0093ooooo0_l0002>ooooo`00T?ooool2o`0008kooooo002@ooooo`;o0000S_ooool0093ooooo
0_l0002>ooooo`00T?ooool3o`0008gooooo002@ooooo`;o0000S_ooool007Kooooo0ol00003oooo
o`?o00001?ooool2o`0000Cooooo0_l00005ooooo`;o0000S_ooool007Oooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`;o0000S_ooool007Oooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool2o`0008kooooo001gooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0ol0002=ooooo`00
Moooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`;o0000S_ooool007Kooooo0_l00003ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`;o0000S_oo
ool007Oooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo0_l0
002>ooooo`00T?ooool2o`0008kooooo002@ooooo`?o0000SOooool0093ooooo0_l0002>ooooo`00
T?ooool2o`0008kooooo002@ooooo`;o0000S_ooool0093ooooo0ol0002=ooooo`00T?ooool2o`00
08kooooo002@ooooo`;o0000S_ooool0093ooooo0_l0002>ooooo`00T?ooool2o`0008kooooo002@
ooooo`?o0000SOooool0093ooooo0_l0002>ooooo`00T?ooool2o`0008kooooo002@ooooo`;o0000
S_ooool0093ooooo0_l0002>ooooo`00T?ooool3o`0008gooooo002@ooooo`;o0000S_ooool0093o
oooo0_l0002>ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0334975, -130.265, \
0.000231017, 10.4982}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[GeometricIntensity[0,d],{d,-.5,.5}];", "Input",
  CellLabel->"In[151]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.0147151 3.28493e-05 [
[.11905 .00222 -12 -9 ]
[.11905 .00222 12 0 ]
[.30952 .00222 -12 -9 ]
[.30952 .00222 12 0 ]
[.69048 .00222 -9 -9 ]
[.69048 .00222 9 0 ]
[.88095 .00222 -9 -9 ]
[.88095 .00222 9 0 ]
[.4875 .09684 -24 -4.5 ]
[.4875 .09684 0 4.5 ]
[.4875 .17896 -24 -4.5 ]
[.4875 .17896 0 4.5 ]
[.4875 .26109 -24 -4.5 ]
[.4875 .26109 0 4.5 ]
[.4875 .34321 -30 -4.5 ]
[.4875 .34321 0 4.5 ]
[.4875 .42533 -30 -4.5 ]
[.4875 .42533 0 4.5 ]
[.4875 .50746 -30 -4.5 ]
[.4875 .50746 0 4.5 ]
[.4875 .58958 -30 -4.5 ]
[.4875 .58958 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .01472 m
.11905 .02097 L
s
[(-0.4)] .11905 .00222 0 1 Mshowa
.30952 .01472 m
.30952 .02097 L
s
[(-0.2)] .30952 .00222 0 1 Mshowa
.69048 .01472 m
.69048 .02097 L
s
[(0.2)] .69048 .00222 0 1 Mshowa
.88095 .01472 m
.88095 .02097 L
s
[(0.4)] .88095 .00222 0 1 Mshowa
.125 Mabswid
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.07143 .01472 m
.07143 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .09684 m
.50625 .09684 L
s
[(2500)] .4875 .09684 1 0 Mshowa
.5 .17896 m
.50625 .17896 L
s
[(5000)] .4875 .17896 1 0 Mshowa
.5 .26109 m
.50625 .26109 L
s
[(7500)] .4875 .26109 1 0 Mshowa
.5 .34321 m
.50625 .34321 L
s
[(10000)] .4875 .34321 1 0 Mshowa
.5 .42533 m
.50625 .42533 L
s
[(12500)] .4875 .42533 1 0 Mshowa
.5 .50746 m
.50625 .50746 L
s
[(15000)] .4875 .50746 1 0 Mshowa
.5 .58958 m
.50625 .58958 L
s
[(17500)] .4875 .58958 1 0 Mshowa
.125 Mabswid
.5 .03114 m
.50375 .03114 L
s
.5 .04756 m
.50375 .04756 L
s
.5 .06399 m
.50375 .06399 L
s
.5 .08041 m
.50375 .08041 L
s
.5 .11326 m
.50375 .11326 L
s
.5 .12969 m
.50375 .12969 L
s
.5 .14611 m
.50375 .14611 L
s
.5 .16254 m
.50375 .16254 L
s
.5 .19539 m
.50375 .19539 L
s
.5 .21181 m
.50375 .21181 L
s
.5 .22824 m
.50375 .22824 L
s
.5 .24466 m
.50375 .24466 L
s
.5 .27751 m
.50375 .27751 L
s
.5 .29393 m
.50375 .29393 L
s
.5 .31036 m
.50375 .31036 L
s
.5 .32678 m
.50375 .32678 L
s
.5 .35963 m
.50375 .35963 L
s
.5 .37606 m
.50375 .37606 L
s
.5 .39248 m
.50375 .39248 L
s
.5 .40891 m
.50375 .40891 L
s
.5 .44176 m
.50375 .44176 L
s
.5 .45818 m
.50375 .45818 L
s
.5 .47461 m
.50375 .47461 L
s
.5 .49103 m
.50375 .49103 L
s
.5 .52388 m
.50375 .52388 L
s
.5 .5403 m
.50375 .5403 L
s
.5 .55673 m
.50375 .55673 L
s
.5 .57315 m
.50375 .57315 L
s
.5 .606 m
.50375 .606 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0163 m
.06244 .01638 L
.10458 .01647 L
.14415 .01657 L
.18221 .01667 L
.22272 .0168 L
.26171 .01694 L
.28158 .01701 L
.29205 .01706 L
.30316 .0171 L
.30791 .01713 L
.31054 .01714 L
.31183 .01714 L
.31304 .01715 L
.31371 .01715 L
.31444 .01951 L
.31524 .01952 L
.31597 .01953 L
.31865 .01955 L
.32392 .0196 L
.34309 .01979 L
.38315 .02023 L
.4217 .02072 L
.46271 .02136 L
.50219 .02212 L
.54016 .02302 L
.58059 .02426 L
.6195 .02586 L
.63931 .02689 L
.66086 .02826 L
.6798 .02974 L
.7007 .0318 L
.72048 .03434 L
.73144 .0361 L
.74149 .03801 L
.76083 .04286 L
.77099 .04632 L
.78169 .051 L
.79123 .05652 L
.79648 .06034 L
.80143 .06463 L
.80605 .06944 L
.81105 .07582 L
.81527 .08247 L
.8198 .09143 L
.82469 .1042 L
.82926 .12072 L
.83205 .13416 L
.8347 .15051 L
.83708 .16952 L
Mistroke
.83967 .1974 L
.8411 .21754 L
.84245 .24102 L
.84366 .26727 L
.84496 .30344 L
.84639 .35708 L
.84711 .3924 L
.8479 .44054 L
.84857 .49266 L
.84929 .56472 L
Mfstroke
.84929 .56472 m
.84963 .61803 L
s
.8564 .61803 m
.85709 .45155 L
.85838 .32052 L
.8596 .25304 L
.86072 .21298 L
.862 .18086 L
.86321 .15885 L
.8643 .14353 L
.86547 .13023 L
.86676 .11854 L
.86811 .10849 L
.87055 .09464 L
.8728 .08504 L
.8749 .07794 L
.87968 .06613 L
.88236 .06125 L
.8849 .05742 L
.88967 .0517 L
.8948 .04703 L
.90039 .04314 L
.90978 .03835 L
.91512 .03628 L
.92014 .03464 L
.93024 .032 L
.94114 .02983 L
.95821 .02736 L
.97619 .02549 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[151]:=",
  ImageSize->{598.75, 370.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009F0001LR000`400?l00000o`00003ooooooooo
oooooeSooooo0018ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o0000H?ooool2o`00
00Cooooo00Co0000oooooooooooooooo1Ol0003=ooooo`;o00001?ooool01?l0003ooooooooooooo
ool5o`00063ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00015ooooo`00Aoooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0003<ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo0000Goooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo04Cooooo0010
ooooo`Go00000_ooool01?l0003oooooooooool00007ooooo`Go0000F?ooool5o`0000;ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`3<ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool0Goooool01?l0003oooooooooool00007ooooo`Go0000AOooool004Oo
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0001Pooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool0boooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo05kooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00016oooo
o`00Aoooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000063ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo00000<cooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000005oooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`000016ooooo`00Aoooool01?l0003oooooooooool00009ooooo`;o0000H?ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000c?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool00000Goooool01?l0003oooooooooool00009oooo
o`;o0000A_ooool004Sooooo0_l0000;ooooo`03o`000?oooooooooo05oooooo0_l00009ooooo`?o
0000c_ooool2o`0000Wooooo0ol0001Qooooo`;o00002oooool00ol0003oooooooooo`14ooooo`00
ooooool[ooooo`03o`000?oooooooooo0?oooooo:_ooool00?oooooo:oooool00ol0003ooooooooo
o`3oooooob[ooooo003oooooob_ooooo00?o0000ooooooooool0oooooolZooooo`00ooooool[oooo
o`03o`000?oooooooooo0?oooooo:_ooool00?oooooo:oooool00ol0003oooooooooo`3oooooob[o
oooo003oooooob_ooooo00?o0000ooooooooool0oooooolZooooo`00ooooool[ooooo`03o`000?oo
oooooooo0?oooooo:_ooool00?oooooo:oooool00ol0003oooooooooo`3oooooob[ooooo003ooooo
ob_ooooo00?o0000ooooooooool0oooooolZooooo`001_ooooooo`000?oo0000C?l00006ooooo`00
5?oooonZo`0001Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`005?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04_oo
ool004cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1<o`00023ooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo04[ooooo003ooooo
o`_ooooo;_l0003ooooooaoooooo003oooooob_ooooo00?o0000ooooooooool02oooool^o`000?3o
oooo003oooooob_ooooo00?o0000ooooooooool0>OoooolAo`000<Gooooo1_l0000Dooooo`00oooo
ool[ooooo`03o`000?oooooooooo04[ooooo3?l0002aooooo`So00006_ooool00?oooooo:oooool0
0ol0003oooooooooo`1Fooooo`co0000X?ooool5o`0002;ooooo003oooooob_ooooo1?l0001Qoooo
o`co0000S_ooool6o`0002Oooooo003oooooob_ooooo00?o0000ooooooooool0K_ooool<o`0007co
oooo1_l0000]ooooo`00ooooool[ooooo`03o`000?oooooooooo07[ooooo2Ol0001_ooooo`Co0000
<oooool00?oooooo:oooool00ol0003oooooooooo`23ooooo`Ko0000I_ooool3o`0003Oooooo003o
ooooob_ooooo00?o0000ooooooooool0ROooool5o`00063ooooo00?o0000ooooooooool0>?ooool0
0?oooooo:oooool00ol0003oooooooooo`2>ooooo`Co0000F_ooool2o`0003_ooooo003oooooob_o
oooo00?o0000ooooooooool0T_ooool3o`0005Cooooo0ol0000mooooo`00ooooool[ooooo`03o`00
0?oooooooooo09Gooooo1?l0001>ooooo`;o0000@?ooool00?oooooo:oooool00ol0003ooooooooo
o`2Iooooo`?o0000B_ooool00ol0003oooooooooo`10ooooo`00ooooool[ooooo`03o`000?oooooo
oooo09cooooo0_l00017ooooo`03o`000?oooooooooo047ooooo003oooooob_ooooo1?l0002Moooo
o`;o0000@oooool2o`0004Cooooo003oooooob_ooooo00?o0000ooooooooool0X?ooool2o`00043o
oooo00?o0000ooooooooool0A?ooool00?oooooo:oooool00ol0003oooooooooo`2Rooooo`;o0000
?Oooool00ol0003oooooooooo`15ooooo`00ooooool[ooooo`03o`000?oooooooooo0:Cooooo0_l0
000kooooo`03o`000?oooooooooo04Gooooo003oooooob_ooooo00?o0000ooooooooool0Y_ooool2
o`0003Sooooo00?o0000ooooooooool0A_ooool00?oooooo:oooool00ol0003oooooooooo`2Xoooo
o`;o0000=Oooool00ol0003oooooooooo`17ooooo`00ooooool[ooooo`03o`000?oooooooooo0:[o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`18ooooo`00ooooool[ooooo`03o`00
0?oooooooooo0:_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`18ooooo`00oooo
ool[ooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`19ooooo`00ooooool[ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`19ooooo`00ooooool[ooooo`Co0000[Oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo04[ooooo003oooooob_ooooo00?o0000ooooooooool0[_ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo04_ooooo003oooooob_ooooo00?o0000ooooooooool0
[oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04_ooooo003oooooob_ooooo00?o
0000ooooooooool0/?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04_ooooo003o
ooooob_ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04cooooo003oooooob_ooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo04cooooo003oooooob_ooooo00?o0000ooooooooool0/oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo04cooooo003oooooob_ooooo00?o0000ooooooooool0
/oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04gooooo003oooooob_ooooo00?o
0000ooooooooool0]?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04gooooo003o
ooooob_ooooo1?l0002dooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0COooool0
0?oooooo:oooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0C_ooool00?oooooo:oooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0C_ooool00?oooooo:oooool00ol0003oooooooooo`2gooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0Coooool00?oooooo:oooool00ol0003ooooooooo
o`2gooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Coooool00?oooooo:oooool0
0ol0003oooooooooo`2gooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Coooool0
0?oooooo:oooool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0D?ooool00?oooooo3?ooool5o`0000;ooooo0ol00004ooooo`;o00001?ooool2o`0000Wo
oooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo053o
oooo003oooooo`gooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0;Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1@ooooo`00ooooool>
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo053ooooo003oooooo`oooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool01_ooool5o`000;Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1@ooooo`00
ooooool<ooooo`06o`000?ooooooooooooooool0003ooooo1?l00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0D?ooool00?oooooo3?ooool01ol0003ooooooooooooo
oooo0000ooooool000001_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
053ooooo003oooooo`gooooo0ol00002ooooo`Go00000oooool2o`0000Cooooo0_l00009ooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Aooooo`00
ooooool[ooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`1Aooooo`00ooooool[ooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1Aooooo`00ooooool[ooooo`03o`000?oooooooooo0;_ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1Aooooo`00ooooool[ooooo`03o`000?oooooooooo
0;cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Aooooo`00ooooool[ooooo`03
o`000?oooooooooo0;cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Aooooo`00
ooooool[ooooo`Co0000^oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo057ooooo
003oooooob_ooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo05;ooooo003oooooob_ooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo05;ooooo003oooooob_ooooo00?o0000ooooooooool0_Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo05;ooooo003oooooob_ooooo00?o0000oooooooo
ool0__ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05;ooooo003oooooob_ooooo
00?o0000ooooooooool0__ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05;ooooo
003oooooob_ooooo00?o0000ooooooooool0__ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo05;ooooo003oooooob_ooooo00?o0000ooooooooool0__ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo05?ooooo003oooooob_ooooo00?o0000ooooooooool0_oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo05?ooooo003oooooob_ooooo00?o0000oooooooo
ool0_oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05?ooooo003oooooob_ooooo
1?l0002nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Doooool00?oooooo:ooo
ool00ol0003oooooooooo`2oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Dooo
ool00?oooooo:oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Doooool00?oooooo:oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0Doooool00?oooooo:oooool00ol0003oooooooooo`30ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0Doooool00?oooooo:oooool00ol0003ooooo
ooooo`30ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0E?ooool00?oooooo:ooo
ool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0E?oo
ool00?oooooo:oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0E?ooool00?oooooo:oooool00ol0003oooooooooo`31ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0E?ooool00?oooooo:oooool00ol0003oooooooooo`31ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0E?ooool00?oooooo:oooool4o`000<3ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Dooooo`00ooooool[ooooo`03o`000?oo
oooooooo0<7ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Dooooo`00ooooool[
ooooo`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1D
ooooo`00ooooool[ooooo`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`1Dooooo`00ooooool[ooooo`03o`000?oooooooooo0<7ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Dooooo`00ooooool[ooooo`03o`000?oooooooooo0<7ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Dooooo`00ooooool[ooooo`03o`000?oo
oooooooo0<7ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Dooooo`00ooooool[
ooooo`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1D
ooooo`00ooooool[ooooo`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1Dooooo`00ooooool[ooooo`Co0000`Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo05Cooooo003oooooob_ooooo00?o0000ooooooooool0`_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05Cooooo003oooooob_ooooo00?o0000ooooooooool0`_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Cooooo003oooooob_ooooo00?o0000
ooooooooool0`_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Cooooo003ooooo
ob_ooooo00?o0000ooooooooool0`_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
05Cooooo003oooooob_ooooo00?o0000ooooooooool0`_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo05Gooooo003oooooob_ooooo00?o0000ooooooooool0`_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo05Gooooo003oooooo`gooooo0ol00004ooooo`;o00001?oo
ool2o`0000Cooooo0_l00009ooooo`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1Eooooo`00ooooool<ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`32ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0EOooool00?oooooo4?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0<?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00ooooool@
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00Kooooo1Ol00031ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0EOooool00?oooooo3?ooool4o`0000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool0`oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo003ooooo
o`cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`33ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0EOooool00?oooooo3?ooool5o`0000?ooooo0_l0
0004ooooo`;o00001?ooool2o`0000Wooooo00?o0000ooooooooool0`oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05Gooooo003oooooob_ooooo00?o0000ooooooooool0`oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo003oooooob_ooooo00?o0000oooo
ooooool0`oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo003oooooob_o
oooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Go
oooo003oooooob_ooooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo05Gooooo003oooooob_ooooo00?o0000ooooooooool0a?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo05Gooooo003oooooob_ooooo1?l00033ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0EOooool00?oooooo:oooool00ol0003oooooooooo`34oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0EOooool00?oooooo:oooool00ol0003o
ooooooooo`34ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E_ooool00?oooooo
:oooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
E_ooool00?oooooo:oooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0E_ooool00?oooooo:oooool00ol0003oooooooooo`34ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0E_ooool00?oooooo:oooool00ol0003oooooooooo`34oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E_ooool00?oooooo:oooool00ol0003o
ooooooooo`34ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E_ooool00?oooooo
:oooool00ol0003oooooooooo`35ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
E_ooool00?oooooo:oooool00ol0003oooooooooo`35ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0E_ooool00?oooooo:oooool4o`000<Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Fooooo`00ooooool[ooooo`03o`000?oooooooooo0<Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Fooooo`00ooooool[ooooo`03o`000?oooooooooo0<Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`00ooooool[ooooo`03o`00
0?oooooooooo0<Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`00oooo
ool[ooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1Fooooo`00ooooool[ooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Fooooo`00ooooool[ooooo`03o`000?oooooooooo0<Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Fooooo`00ooooool[ooooo`03o`000?oooooooooo0<Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`00ooooool[ooooo`03o`00
0?oooooooooo0<Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`00oooo
ool[ooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1Fooooo`00ooooool[ooooo`Co0000a?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05Kooooo003oooooob_ooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05Kooooo003oooooob_ooooo00?o0000ooooooooool0a_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05Kooooo003oooooob_ooooo00?o0000ooooooooool0
a_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo003oooooob_ooooo00?o
0000ooooooooool0a_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo003o
ooooob_ooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo003oooooob_ooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05Kooooo003oooooob_ooooo00?o0000ooooooooool0a_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05Kooooo003oooooob_ooooo00?o0000ooooooooool0
a_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo003oooooob_ooooo1?l0
0035ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool00?oooooo:oooool0
0ol0003oooooooooo`36ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool0
0?oooooo:oooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0E_ooool00?oooooo:oooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0E_ooool00?oooooo:oooool00ol0003oooooooooo`36ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool00?oooooo:oooool00ol0003ooooooooo
o`36ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool00?oooooo:oooool0
0ol0003oooooooooo`36ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool0
0?oooooo3_ooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`0000Cooooo0_l00009oooo
o`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Foooo
o`00ooooool>ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`36ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool00?oooooo3oooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Fooooo`00ooooool?ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Ko
oooo1Ol00034ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool00?oooooo
4?ooool00ol0003oooooo`000003o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Fooooo`00ooooool<ooooo`07o`000?ooooooooooooooool0003oooooo`000006
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`36ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool00?oooooo3?oo
ool5o`000003ooooool0003o000000?o00000oooool2o`0000Cooooo0_l00009ooooo`03o`000?oo
oooooooo0<Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00ooooool[
ooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1F
ooooo`00ooooool[ooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Fooooo`00ooooool[ooooo`03o`000?oooooooooo0<Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Fooooo`00ooooool[ooooo`03o`000?oooooooooo0<Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00ooooool[ooooo`03o`000?oo
oooooooo0<Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00ooooool[
ooooo`Co0000aOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo003ooooo
ob_ooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05Kooooo003oooooob_ooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05Kooooo003oooooob_ooooo00?o0000ooooooooool0a_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05Kooooo003oooooob_ooooo00?o0000ooooooooool0a_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo003oooooob_ooooo00?o0000
ooooooooool0a_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo003ooooo
ob_ooooo00?o0000ooooooooool0aoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
05Kooooo003oooooob_ooooo00?o0000ooooooooool0aoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo05Oooooo003oooooob_ooooo00?o0000ooooooooool0aoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo05Oooooo003oooooob_ooooo00?o0000ooooooooool0aooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo003oooooob_ooooo1?l00036
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00?oooooo:oooool00ol0
003oooooooooo`37ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00?oo
oooo:oooool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Eoooool00?oooooo:oooool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Eoooool00?oooooo:oooool00ol0003oooooooooo`37ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Eoooool00?oooooo:oooool00ol0003oooooooooo`37
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00?oooooo:oooool00ol0
003oooooooooo`37ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00?oo
oooo:oooool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Eoooool00?oooooo:oooool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Eoooool00?oooooo:oooool00ol0003oooooooooo`37ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Eoooool00?oooooo:oooool4o`000<Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`00ooooool[ooooo`03o`000?oooooooooo
0<Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`00ooooool[ooooo`03
o`000?oooooooooo0<Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`00
ooooool[ooooo`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Gooooo`00ooooool[ooooo`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Gooooo`00ooooool[ooooo`03o`000?oooooooooo0<Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`00ooooool[ooooo`03o`000?oooooooooo
0<Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`00ooooool[ooooo`03
o`000?oooooooooo0<Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`00
ooooool[ooooo`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Gooooo`00ooooool[ooooo`Co0000a_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05Oooooo003oooooob_ooooo00?o0000ooooooooool0aoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05Oooooo003oooooob_ooooo00?o0000ooooooooool0aoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo003oooooob_ooooo00?o0000oooooooo
ool0b?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Oooooo003oooooob_ooooo
00?o0000ooooooooool0b?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Oooooo
003oooooob_ooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo05Oooooo003oooooob_ooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05Oooooo003oooooo`Oooooo0ol00004ooooo`;o00001?ooool2o`00
00Cooooo0_l00004ooooo`;o00002Oooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Eoooool00?oooooo2?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0b?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05Oooooo003oooooo`Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0<Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Gooooo`00ooooool8ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool5o`000<Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Gooooo`00ooooool8ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`38ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Eoooool00?oooooo1oooool2o`0000Cooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Eoooool00?oooooo2?ooool00ol0003oooooooooo`03ooooo`;o
00001?ooool2o`0000Cooooo0_l00004ooooo`;o00002Oooool00ol0003oooooooooo`38ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Eoooool00?oooooo:oooool00ol0003ooooo
ooooo`38ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Eoooool00?oooooo:ooo
ool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Eooo
ool00?oooooo:oooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Eoooool00?oooooo:oooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Eoooool00?oooooo:oooool00ol0003oooooooooo`38ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Eoooool00?oooooo:oooool4o`000<Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Gooooo`00ooooool[ooooo`03o`000?oo
oooooooo0<Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Gooooo`00ooooool[
ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1G
ooooo`00ooooool[ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Gooooo`00ooooool[ooooo`03o`000?oooooooooo0<Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Gooooo`00ooooool[ooooo`03o`000?oooooooooo0<Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Gooooo`00ooooool[ooooo`03o`000?oo
oooooooo0<Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Gooooo`00ooooool[
ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1G
ooooo`00ooooool[ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Gooooo`00ooooool[ooooo`03o`000?oooooooooo0<Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Gooooo`00ooooool[ooooo`Co0000aoooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05Oooooo003oooooob_ooooo00?o0000ooooooooool0b?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Oooooo003oooooob_ooooo00?o0000
ooooooooool0b?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Oooooo003ooooo
ob_ooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
05Oooooo003oooooob_ooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05Oooooo003oooooob_ooooo00?o0000ooooooooool0b?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05Oooooo003oooooob_ooooo00?o0000ooooooooool0b?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Oooooo003oooooob_ooooo00?o0000
ooooooooool0b?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo003ooooo
ob_ooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
05Sooooo003oooooob_ooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05Sooooo003oooooob_ooooo1?l00037ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0003oooooooooo`38ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0003oooooooooo`38
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0
003oooooooooo`38ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool00?oo
oooo:oooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0F?ooool00?oooooo:oooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0003oooooooooo`38ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0003oooooooooo`38
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0
003oooooooooo`38ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool00?oo
oooo:oooool4o`000<Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Hooooo`00
ooooool[ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Hooooo`00ooooool[ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Hooooo`00ooooool[ooooo`03o`000?oooooooooo0<Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Hooooo`00ooooool[ooooo`03o`000?oooooooooo
0<Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Hooooo`00ooooool[ooooo`03
o`000?oooooooooo0<Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Hooooo`00
ooooool[ooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Hooooo`00ooooool7ooooo`?o00000_ooool5o`0000;ooooo0ol00004ooooo`;o00001?oo
ool2o`0000Wooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05Sooooo003oooooo`Sooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05Sooooo003oooooo`Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Hooooo`00ooooool8ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01_ooool5o`000<Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Hooooo`00ooooool8ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`00
0003o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo0<Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`00
ooooool7ooooo`;o00000oooool01ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0bOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo003oooooo`Sooooo00?o0000
ooooooooool00_ooool3o`0000;ooooo1Ol00003ooooo`;o00001?ooool2o`0000Wooooo00?o0000
ooooooooool0bOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo003ooooo
ob_ooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05Sooooo003oooooob_ooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05Sooooo003oooooob_ooooo00?o0000ooooooooool0bOooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo05Sooooo003oooooob_ooooo00?o0000ooooooooool0bOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo003oooooob_ooooo00?o0000
ooooooooool0bOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo003ooooo
ob_ooooo1?l00038ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F?ooool00?oo
oooo:oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0F?ooool00?oooooo:oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0003oooooooooo`39ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0003oooooooooo`39
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0
003oooooooooo`39ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F?ooool00?oo
oooo:oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0F?ooool00?oooooo:oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0003oooooooooo`39ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0003oooooooooo`39
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F?ooool00?oooooo:oooool4o`00
0<Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`00ooooool[ooooo`03
o`000?oooooooooo0<Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`00
ooooool[ooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Hooooo`00ooooool[ooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Hooooo`00ooooool[ooooo`03o`000?oooooooooo0<Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`00ooooool[ooooo`03o`000?oooooooooo
0<Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`00ooooool[ooooo`03
o`000?oooooooooo0<Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`00
ooooool[ooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Hooooo`00ooooool[ooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Hooooo`00ooooool[ooooo`03o`000?oooooooooo0<Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`00ooooool[ooooo`Co0000b?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo003oooooob_ooooo00?o0000oooooooo
ool0bOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo003oooooob_ooooo
00?o0000ooooooooool0bOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo
003oooooob_ooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05Sooooo003oooooob_ooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05Sooooo003oooooob_ooooo00?o0000ooooooooool0bOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo003oooooob_ooooo00?o0000oooooooo
ool0bOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo003oooooob_ooooo
00?o0000ooooooooool0bOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo
003oooooob_ooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05Sooooo003oooooob_ooooo1?l00038ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0F?ooool00?oooooo:oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0003oooooooooo`39ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0F?ooool00?oooooo:oooool00ol0003ooooo
ooooo`39ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F?ooool00?oooooo:ooo
ool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F?oo
ool00?oooooo:oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0F?ooool00?oooooo:oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0F?ooool00?oooooo1oooool3o`0000?ooooo0ol00004ooooo`;o
00001?ooool2o`0000Cooooo0_l00009ooooo`03o`000?oooooooooo0<Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Hooooo`00ooooool8ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0<Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`00ooooool8ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`39ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0F?ooool00?oooooo2?ooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo1Ol00037ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0F?ooool00?oooooo2?ooool01?l0003oooooooooooooool4
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05Sooooo003oooooo`Oooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05Sooooo003oooooo`Sooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001?ooool2
o`0000Cooooo0_l00009ooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Hooooo`00ooooool[ooooo`03o`000?oooooooooo0<Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Hooooo`00ooooool[ooooo`03o`000?oooooooooo0<Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`00ooooool[ooooo`03o`00
0?oooooooooo0<Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`00oooo
ool[ooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Hooooo`00ooooool[ooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Hooooo`00ooooool[ooooo`Co0000b?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05Sooooo003oooooob_ooooo00?o0000ooooooooool0bOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05Sooooo003oooooob_ooooo00?o0000ooooooooool0
bOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo003oooooob_ooooo00?o
0000ooooooooool0bOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo003o
ooooob_ooooo00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000005[ooooo003o
ooooob_ooooo00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000005[ooooo003o
ooooob_ooooo00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000005[ooooo003o
ooooob_ooooo00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000005[ooooo003o
ooooob_ooooo00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000005[ooooo003o
ooooob_ooooo00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000005[ooooo003o
ooooob_ooooo1?l00039ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool0
0ol0003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool0
0ol0003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool0
0ol0003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool0
0ol0003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool0
0ol0003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool0
0ol0003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool0
0ol0003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool0
0ol0003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool0
0ol0003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool4
o`000<Wooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool[ooooo`03o`000?oooooo
oooo0<[ooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool[ooooo`03o`000?oooooo
oooo0<[ooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool[ooooo`03o`000?oooooo
oooo0<[ooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool[ooooo`03o`000?oooooo
oooo0<[ooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool[ooooo`03o`000?oooooo
oooo0<[ooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool[ooooo`03o`000?oooooo
oooo0<[ooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool[ooooo`03o`000?oooooo
oooo0<[ooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool[ooooo`03o`000?oooooo
oooo0<[ooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool[ooooo`Co0000bOooool0
1Ol0003ooooooooooooooooo000005[ooooo003oooooob_ooooo00?o0000ooooooooool0b_ooool0
1Ol0003ooooooooooooooooo000005[ooooo003oooooob_ooooo00?o0000ooooooooool0b_ooool0
1Ol0003ooooooooooooooooo000005[ooooo003oooooob_ooooo00?o0000ooooooooool0b_ooool0
1Ol0003ooooooooooooooooo000005[ooooo003oooooob_ooooo00?o0000ooooooooool0b_ooool0
1Ol0003ooooooooooooooooo000005[ooooo003oooooob_ooooo00?o0000ooooooooool0b_ooool0
1Ol0003ooooooooooooooooo000005[ooooo003oooooob_ooooo00?o0000ooooooooool0b_ooool0
1Ol0003ooooooooooooooooo000005[ooooo003oooooo`Oooooo0ol00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00004ooooo`;o00001?ooool2o`0000Wooooo00?o0000ooooooooool0b_ooool0
1Ol0003ooooooooooooooooo000005[ooooo003oooooo`Sooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0b_ooool01Ol0003o
oooooooooooooooo000005[ooooo003oooooo`Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0<[ooooo00Go0000ooooooooooooooooo`00
001Jooooo`00ooooool8ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
1_ooool5o`000<Sooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool8ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000000ol00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3:ooooo`05o`000?oooooooooo
ooooool00000F_ooool00?oooooo1oooool2o`0000?ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000Kooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo0<[ooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool8ooooo`04
o`000?ooooooooooooooo`Go000000?oooooo`000?l000000ol00003ooooo`;o00001?ooool2o`00
00Wooooo00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000005[ooooo003ooooo
ob_ooooo00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000005[ooooo003ooooo
ob_ooooo00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000005[ooooo003ooooo
ob_ooooo00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000005[ooooo003ooooo
ob_ooooo00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000005[ooooo003ooooo
ob_ooooo00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000005[ooooo003ooooo
ob_ooooo1?l00039ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool00ol0
003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool00ol0
003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool00ol0
003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool00ol0
003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool00ol0
003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool00ol0
003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00?oooooo:oooool00ol0
003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000F_ooool00001\
\>"],
  ImageRangeCache->{{{0, 597.75}, {369.062, 0}} -> {-0.536725, -849.056, \
0.00179582, 52.0651}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot[GeometricIntensity[0,d],{d,-.5,.5},PlotRange->{0,1000}];\
\>", "Input",
  CellLabel->"In[152]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.952381 0 0.000618034 [
[.11905 -0.0125 -12 -9 ]
[.11905 -0.0125 12 0 ]
[.30952 -0.0125 -12 -9 ]
[.30952 -0.0125 12 0 ]
[.69048 -0.0125 -9 -9 ]
[.69048 -0.0125 9 0 ]
[.88095 -0.0125 -9 -9 ]
[.88095 -0.0125 9 0 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -24 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-0.4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-0.2)] .30952 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(0.2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(0.4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .12361 m
.50625 .12361 L
s
[(200)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(400)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(600)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(800)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1000)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02983 m
.06244 .03128 L
.10458 .03304 L
.14415 .03488 L
.18221 .03686 L
.22272 .03922 L
.26171 .04181 L
.28158 .04326 L
.29205 .04406 L
.30316 .04495 L
.30791 .04534 L
.31054 .04556 L
.31183 .04567 L
.31304 .04577 L
.31371 .04583 L
.31444 .0903 L
.31524 .09044 L
.31597 .09056 L
.31865 .09102 L
.32392 .09194 L
.34309 .09544 L
.38315 .10368 L
.4217 .11305 L
.46271 .12504 L
.50219 .13923 L
.54016 .15625 L
.58059 .17956 L
.6195 .20959 L
.63931 .22907 L
.66086 .25478 L
.6798 .28264 L
.7007 .32137 L
.72048 .36916 L
.73144 .40229 L
.74149 .43833 L
.76083 .5296 L
.77099 .59455 L
s
.77099 .59455 m
.77384 .61803 L
s
.89422 .61803 m
.8948 .60807 L
.90039 .5347 L
.90978 .44462 L
.91512 .40569 L
.92014 .37485 L
.93024 .32514 L
.94114 .28444 L
.95821 .23782 L
.97619 .2028 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[152]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:?ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002?ooooo0_l00004oooo
o`04o`000?ooooooooooooooo`Go0000D?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
000Sooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00009_ooool002Oooooo00Co0000
oooooooooooo00002_ooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo0000Coooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0002;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Uooooo`008?ooool5
o`0000;ooooo00Co0000oooooooooooo00001oooool5o`0001_ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool0Coooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo02;ooooo00Co0000oooooooooooo00001oooool5o`0002Kooooo000Wooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00008oooool01?l0003oooooooooool0
000:ooooo`03o`000?oooooooooo04kooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`0Qooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00009oooool002Oo
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000Sooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00001?ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Rooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000009oooool002Oooooo00Co0000oooooooooooo00002Oooool2o`0002?ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000004oooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000002;ooooo00Co0000oooooooooooo00002Oooool2o`00
02Oooooo000Xooooo`;o00002oooool00ol0003oooooooooo`0Rooooo`;o00002Oooool3o`00057o
oooo0_l00009ooooo`?o00009?ooool2o`0000_ooooo00?o0000ooooooooool09Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool000goooooool00006o`0000ko
oooo000Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Cooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>
ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00
Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`005?oooolK
o`00063ooooo0_l0002?ooooo`00;ooooolDo`0004cooooo00?o0000ooooooooool0S_ooool004?o
oooo2_l00012ooooo`03o`000?oooooooooo08kooooo001=oooooa3o0000<_ooool00ol0003ooooo
ooooo`2>ooooo`00GOooool3o`0002oooooo00?o0000ooooooooool0S_ooool005oooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`2>ooooo`00Goooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo08kooooo001Oooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0S_ooool005oooooo00?o0000ooooooooool0;Oooool2o`0008oooooo001Oooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0S_ooool005oooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`2>ooooo`00Goooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
08kooooo001Oooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0S_ooool005oooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2>ooooo`00Goooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo08kooooo001Oooooo`;o0000;_ooool00ol0003oooooooooo`2>
ooooo`00HOooool4o`0002[ooooo0_l0002?ooooo`00IOooool5o`0002Gooooo00?o0000oooooooo
ool0S_ooool006[ooooo1Ol0000Pooooo`03o`000?oooooooooo08kooooo001_ooooo`Ko00006_oo
ool00ol0003oooooooooo`2>ooooo`00MOooool5o`0001Gooooo00?o0000ooooooooool0S_ooool0
07[ooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0S_ooool007_o
oooo00?o0000ooooooooool01?l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2>ooooo`00O?ooool00ol0003oooooooooo`02ooooo`Co
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo08kooooo001mooooo`05
o`000?ooooooooooooooool000000_ooool4o`0000;ooooo00?o0000ooooooooool00_ooool3o`00
08kooooo001jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`Co00001?ooool00ol0003oooooooooo`2>ooooo`00N_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03o`0000;ooooo00?o
0000ooooooooool0S_ooool007_ooooo0ol00004ooooo`;o00001?ooool2o`0000?ooooo0ol0002@
ooooo`00Soooool3o`0008kooooo002?ooooo`03o`000?oooooooooo00;o0000S?ooool008oooooo
00?o0000ooooooooool00_ooool3o`0008Wooooo002?ooooo`03o`000?oooooooooo00Gooooo0_l0
0027ooooo`00Soooool2o`0000Sooooo0_l00025ooooo`00Soooool00ol0003oooooooooo`09oooo
o`;o0000Poooool008oooooo00?o0000ooooooooool02oooool2o`00087ooooo002?ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0O_ooool008oooooo00?o0000ooooooooool03_oo
ool2o`0007kooooo002?ooooo`03o`000?oooooooooo013ooooo0_l0001looooo`00Soooool00ol0
003oooooooooo`0Booooo`;o0000N_ooool008oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1gooooo`00Soooool2o`0001Kooooo00?o0000ooooooooool0M_ooool008oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1eooooo`00Soooool00ol0003oooooooooo`0G
ooooo`;o0000MOooool008oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1boooo
o`00Soooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool04oooool008oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Jooooo`03o`00
0?oooooooooo01?ooooo002?ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0F?oo
ool00ol0003oooooooooo`0Dooooo`00Soooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool05?ooool008oooooo0_l0000Oooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool05Oooool008oooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo01Gooooo002?ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Eooooo`00Soooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool05_ooool008oooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01Kooooo001loooo
o`?o00000oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`0Gooooo`00OOooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Gooooo`00N_ooool5o`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Hooooo`00N_ooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool3o`0002Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Hooooo`00
Noooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool06?ooool007cooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool06Oooool007gooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Ioooo
o`00Soooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool06_ooool008oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo01[ooooo002?ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0Jooooo`00Soooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool06oooool008oooooo0_l0000/ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool06oooool008oooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01_ooooo002?ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Looooo`00Soooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07?ooool008oooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo002?oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Moooo
o`00Soooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool07Oooool008oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo01gooooo002?ooooo`;o0000<?ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo01gooooo002?ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Mooooo`00Soooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool07_ooool008oooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo01kooooo002?ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Nooooo`00Soooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool07_ooool008oooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01kooooo002?oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Ooooo
o`00Soooool2o`0003Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Oooooo`00
Soooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
7oooool008oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo01oooooo002?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0Pooooo`00Soooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool08?ooool007_ooooo0ol00004ooooo`;o00001?ooool2o`0000Go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo023o
oooo001jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo023ooooo001jooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo023ooooo001jooooo`Co00000ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo0ol0000fooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool08Oooool007[ooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo027ooooo001kooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Q
ooooo`00O?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool08Oooool008oooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo027ooooo002?ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Qooooo`00Sooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool08_oo
ool008oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo02;ooooo002?ooooo`;o0000>_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02;ooooo002?ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0Rooooo`00Soooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool08_ooool008oooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02;ooooo002?ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0Sooooo`00Soooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool08oooool008oooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02?ooooo002?ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Sooooo`00Sooo
ool2o`0003gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Sooooo`00Soooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09?ooool0
08oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
02Cooooo002?ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Tooooo`00Soooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool09?ooool008oooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo02Cooooo002?ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Tooooo`00Soooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09?ooool008oooooo0_l0000nooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool09?ooool008oooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Cooooo002?ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`00Soooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool0
08oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Gooooo001kooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`00N_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0U
ooooo`00N_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Uooooo`00Noooool3o`0000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`?o0000?oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo02Gooooo001jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo001jooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo
001kooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Uooooo`00Soooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09Oooool008oooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Kooooo002?ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Vooooo`00
Soooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
9_ooool008oooooo0_l00012ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09_oo
ool008oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo02Kooooo002?ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0Vooooo`00Soooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool09_ooool008oooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo02Kooooo002?ooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Vooooo`00Soooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09_ooool008oooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Kooooo002?ooooo`;o
0000@oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Oooooo002?ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Wooooo`00Sooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09ooo
ool008oooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02Oooooo002?ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Wooooo`00Soooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool09oooool008oooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02Oooooo002?ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Wooooo`00Soooool2o`0004Cooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Wooooo`00Soooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:?ooool008oooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo002?ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Xooooo`00Sooo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:?oo
ool007Gooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Xooooo`00M_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Xooooo`00M_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Xoooo
o`00M_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`?o0000A?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo02Sooooo001fooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0009Go
oooo001eooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000UOooool007Kooooo00?o0000ooooooooool00oooool2o`00
00Cooooo0_l00004ooooo`;o0000U_ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.581299, -76.4114, \
0.00405086, 6.24232}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell["\<\
Note that the following plots are very time consuming to construct. Some \
systems may require 10 - 15 minutes for each plot. The results are well worth \
the wait however.\
\>", "Text",
  CellLabel->"In[113]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[CellGroupData[{

Cell["\<\
Plot3D[GeometricIntensity[ys,d], {ys,-.05,.05}, {d,-.5, \
.5},PlotPoints->150,PlotRange->{0,500}];\
\>", "Input",
  CellLabel->"In[153]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.08608 .22315 -30 -8.87306 ]
[.08608 .22315 0 .12694 ]
[.20731 .17545 -29.1845 -9 ]
[.20731 .17545 .81554 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.46808 .07289 -21.346 -9 ]
[.46808 .07289 2.65396 0 ]
[.60856 .01769 -20.3453 -9 ]
[.60856 .01769 3.65472 0 ]
[.73498 .04732 0 -6.2105 ]
[.73498 .04732 24 2.7895 ]
[.79846 .14452 0 -6.11593 ]
[.79846 .14452 24 2.88407 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.90976 .31495 0 -5.95504 ]
[.90976 .31495 18 3.04496 ]
[.95881 .39008 0 -5.88604 ]
[.95881 .39008 18 3.11396 ]
[.02494 .25992 -6 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.0179 .30404 -18 -2.77522 ]
[.0179 .30404 0 6.22478 ]
[.01066 .34944 -18 -2.81369 ]
[.01066 .34944 0 6.18631 ]
[.0032 .39618 -18 -2.85342 ]
[.0032 .39618 0 6.14658 ]
[-0.00448 .44432 -18 -2.89446 ]
[-0.00448 .44432 0 6.10554 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09549 .2323 m
.1002 .23687 L
s
[(-0.04)] .08608 .22315 1 .97179 Mshowa
.21633 .18498 m
.22084 .18975 L
s
[(-0.02)] .20731 .17545 .94563 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.47614 .08324 m
.48017 .08842 L
s
[(0.02)] .46808 .07289 .77884 1 Mshowa
.61605 .02846 m
.6198 .03385 L
s
[(0.04)] .60856 .01769 .69544 1 Mshowa
.125 Mabswid
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.18558 .19702 m
.18832 .19985 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.51046 .06981 m
.51284 .07294 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.06616 .24378 m
.06901 .2465 L
s
.03716 .25514 m
.04004 .25782 L
s
.65216 .01432 m
.65436 .01759 L
s
.68874 0 m
.69089 .0033 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72272 .05198 m
.71658 .05431 L
s
[(-0.4)] .73498 .04732 -1 .38011 Mshowa
.78611 .14895 m
.77994 .15117 L
s
[(-0.2)] .79846 .14452 -1 .3591 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.89727 .31899 m
.89103 .32101 L
s
[(0.2)] .90976 .31495 -1 .32334 Mshowa
.94627 .39394 m
.94 .39587 L
s
[(0.4)] .95881 .39008 -1 .30801 Mshowa
.125 Mabswid
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.7708 .12553 m
.7671 .12688 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.9099 .3383 m
.90615 .3395 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.70593 .0263 m
.70226 .02771 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(0)] .02494 .25992 1 -0.39157 Mshowa
.03016 .29934 m
.03628 .29699 L
s
[(100)] .0179 .30404 1 -0.38329 Mshowa
.02295 .34483 m
.02909 .34253 L
s
[(200)] .01066 .34944 1 -0.37474 Mshowa
.01552 .39167 m
.02169 .38942 L
s
[(300)] .0032 .39618 1 -0.36591 Mshowa
.00788 .43991 m
.01406 .43771 L
s
[(400)] -0.00448 .44432 1 -0.35679 Mshowa
0 .48963 m
.0062 .48748 L
s
[(500)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03578 .26388 m
.03944 .26245 L
s
.03438 .27267 m
.03805 .27124 L
s
.03298 .28151 m
.03665 .28009 L
s
.03157 .2904 m
.03525 .28898 L
s
.02873 .30833 m
.03241 .30693 L
s
.0273 .31738 m
.03098 .31598 L
s
.02585 .32648 m
.02954 .32509 L
s
.0244 .33563 m
.02809 .33424 L
s
.02148 .35409 m
.02517 .35272 L
s
.02 .3634 m
.02369 .36203 L
s
.01852 .37277 m
.02221 .37141 L
s
.01703 .38219 m
.02072 .38083 L
s
.01401 .40121 m
.01771 .39986 L
s
.01249 .4108 m
.01619 .40946 L
s
.01096 .42044 m
.01467 .41911 L
s
.00943 .43015 m
.01313 .42882 L
s
.00632 .44974 m
.01003 .44842 L
s
.00476 .45962 m
.00847 .45831 L
s
.00318 .46956 m
.00689 .46826 L
s
.00159 .47957 m
.00531 .47827 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.649 .733 .91 r
.40279 .60994 .40484 .6119 .40827 .611 .40623 .60904 Metetra
.649 .733 .91 r
.40623 .60904 .40827 .611 .41171 .61011 .40967 .60814 Metetra
.648 .732 .91 r
.40967 .60814 .41171 .61011 .41516 .60921 .41312 .60725 Metetra
.648 .732 .911 r
.41312 .60725 .41516 .60921 .41861 .60832 .41657 .60635 Metetra
.648 .732 .911 r
.41657 .60635 .41861 .60832 .42207 .60743 .42003 .60546 Metetra
.647 .732 .911 r
.42003 .60546 .42207 .60743 .42553 .60655 .4235 .60457 Metetra
.647 .732 .911 r
.4235 .60457 .42553 .60655 .42899 .60566 .42696 .60369 Metetra
.646 .731 .911 r
.42696 .60369 .42899 .60566 .43246 .60478 .43043 .6028 Metetra
.646 .731 .911 r
.43043 .6028 .43246 .60478 .43593 .60391 .43391 .60192 Metetra
.645 .731 .911 r
.43391 .60192 .43593 .60391 .43941 .60303 .43739 .60104 Metetra
.645 .731 .911 r
.43739 .60104 .43941 .60303 .44289 .60216 .44088 .60017 Metetra
.644 .73 .911 r
.44088 .60017 .44289 .60216 .44638 .60129 .44437 .5993 Metetra
.644 .73 .911 r
.44437 .5993 .44638 .60129 .44988 .60043 .44786 .59843 Metetra
.643 .73 .911 r
.44786 .59843 .44988 .60043 .45337 .59957 .45136 .59757 Metetra
.643 .729 .912 r
.45136 .59757 .45337 .59957 .45687 .59872 .45487 .59671 Metetra
.642 .729 .912 r
.45487 .59671 .45687 .59872 .46038 .59786 .45838 .59585 Metetra
.641 .729 .912 r
.45838 .59585 .46038 .59786 .46389 .59702 .46189 .595 Metetra
.641 .728 .912 r
.46189 .595 .46389 .59702 .46741 .59618 .46541 .59416 Metetra
.64 .728 .912 r
.46541 .59416 .46741 .59618 .47093 .59534 .46894 .59332 Metetra
.639 .727 .912 r
.46894 .59332 .47093 .59534 .47446 .59451 .47247 .59248 Metetra
.638 .727 .912 r
.47247 .59248 .47446 .59451 .47799 .59369 .476 .59166 Metetra
.638 .727 .912 r
.476 .59166 .47799 .59369 .48153 .59287 .47954 .59083 Metetra
.637 .726 .913 r
.47954 .59083 .48153 .59287 .48507 .59206 .48308 .59002 Metetra
.636 .726 .913 r
.48308 .59002 .48507 .59206 .48861 .59126 .48663 .58921 Metetra
.635 .725 .913 r
.48663 .58921 .48861 .59126 .49216 .59047 .49019 .58841 Metetra
.634 .725 .913 r
.49019 .58841 .49216 .59047 .49572 .58968 .49375 .58762 Metetra
.633 .724 .913 r
.49375 .58762 .49572 .58968 .49928 .5889 .49731 .58684 Metetra
.631 .723 .914 r
.49731 .58684 .49928 .5889 .50285 .58814 .50088 .58607 Metetra
.63 .723 .914 r
.50088 .58607 .50285 .58814 .50642 .58738 .50445 .58531 Metetra
.629 .722 .914 r
.50445 .58531 .50642 .58738 .51 .58663 .50803 .58456 Metetra
.627 .721 .914 r
.50803 .58456 .51 .58663 .51358 .5859 .51162 .58382 Metetra
.626 .72 .915 r
.51162 .58382 .51358 .5859 .51717 .58518 .51521 .58309 Metetra
.624 .72 .915 r
.51521 .58309 .51717 .58518 .52076 .58447 .51881 .58238 Metetra
.622 .719 .915 r
.51881 .58238 .52076 .58447 .52436 .58378 .52241 .58168 Metetra
.62 .718 .916 r
.52241 .58168 .52436 .58378 .52797 .5831 .52601 .58099 Metetra
.618 .717 .916 r
.52601 .58099 .52797 .5831 .53158 .58244 .52963 .58033 Metetra
.616 .715 .917 r
.52963 .58033 .53158 .58244 .53519 .5818 .53325 .57968 Metetra
.613 .714 .917 r
.53325 .57968 .53519 .5818 .53881 .58118 .53687 .57905 Metetra
.611 .713 .917 r
.53687 .57905 .53881 .58118 .54244 .58058 .5405 .57845 Metetra
.608 .711 .918 r
.5405 .57845 .54244 .58058 .54607 .58 .54414 .57786 Metetra
.605 .71 .918 r
.54414 .57786 .54607 .58 .54971 .57945 .54778 .57731 Metetra
.601 .708 .919 r
.54778 .57731 .54971 .57945 .55336 .57893 .55143 .57678 Metetra
.598 .706 .92 r
.55143 .57678 .55336 .57893 .55701 .57844 .55508 .57628 Metetra
.593 .704 .92 r
.55508 .57628 .55701 .57844 .56067 .57798 .55874 .57581 Metetra
.589 .702 .921 r
.55874 .57581 .56067 .57798 .56433 .57755 .56241 .57538 Metetra
.584 .699 .922 r
.56241 .57538 .56433 .57755 .568 .57717 .56608 .57499 Metetra
.578 .696 .923 r
.56608 .57499 .568 .57717 .57168 .57684 .56976 .57464 Metetra
.571 .693 .924 r
.56976 .57464 .57168 .57684 .57537 .57655 .57345 .57434 Metetra
.564 .69 .925 r
.57345 .57434 .57537 .57655 .57906 .57631 .57715 .5741 Metetra
.556 .686 .926 r
.57715 .5741 .57906 .57631 .58276 .57614 .58085 .57392 Metetra
.547 .681 .927 r
.58085 .57392 .58276 .57614 .58647 .57604 .58456 .5738 Metetra
.536 .675 .928 r
.58456 .5738 .58647 .57604 .59019 .57601 .58828 .57377 Metetra
.523 .669 .929 r
.58828 .57377 .59019 .57601 .59392 .57607 .59201 .57381 Metetra
.509 .662 .93 r
.59201 .57381 .59392 .57607 .59765 .57622 .59575 .57396 Metetra
.491 .653 .931 r
.59575 .57396 .59765 .57622 .6014 .57649 .5995 .57422 Metetra
.471 .642 .932 r
.5995 .57422 .6014 .57649 .60516 .57689 .60326 .5746 Metetra
.446 .629 .932 r
.60326 .5746 .60516 .57689 .60893 .57743 .60703 .57513 Metetra
.415 .613 .931 r
.60703 .57513 .60893 .57743 .61271 .57814 .61081 .57584 Metetra
.377 .593 .929 r
.61081 .57584 .61271 .57814 .61651 .57905 .61461 .57674 Metetra
.329 .566 .925 r
.61461 .57674 .61651 .57905 .62032 .5802 .61843 .57788 Metetra
.268 .531 .915 r
.61843 .57788 .62032 .5802 .62415 .58162 .62226 .5793 Metetra
.188 .483 .897 r
.62226 .5793 .62415 .58162 .628 .58337 .62611 .58106 Metetra
.084 .417 .865 r
.62611 .58106 .628 .58337 .63188 .58552 .62999 .58322 Metetra
0 .326 .809 r
.62999 .58322 .63188 .58552 .63578 .58814 .6339 .58588 Metetra
0 .203 .716 r
.6339 .58588 .63578 .58814 .63972 .59136 .63784 .58915 Metetra
0 .049 .575 r
.63784 .58915 .63972 .59136 .6437 .5953 .64182 .59319 Metetra
.602 .12 0 r
.64182 .59319 .6437 .5953 .64772 .60012 .64585 .59818 Metetra
.751 .275 0 r
.64585 .59818 .64772 .60012 .65181 .60603 .64995 .60436 Metetra
.846 .394 0 r
.64995 .60436 .65181 .60603 .65596 .61323 .65412 .61201 Metetra
.894 .472 .135 r
.65412 .61201 .65596 .61323 .6602 .62188 .65838 .62139 Metetra
.91 .515 .241 r
.65838 .62139 .6602 .62188 .66452 .63191 .66275 .63258 Metetra
.901 .528 .317 r
.66275 .63258 .66452 .63191 .6689 .64266 .66719 .645 Metetra
.866 .507 .368 r
.66719 .645 .6689 .64266 .67326 .65234 .67165 .65668 Metetra
.772 .422 .393 r
.67165 .65668 .67326 .65234 .67748 .65798 .67594 .66383 Metetra
.477 .155 .341 r
.67594 .66383 .67748 .65798 .68142 .6569 .67989 .66275 Metetra
0 0 .004 r
.67989 .66275 .68142 .6569 .68505 .64908 .68347 .65342 Metetra
.896 .833 .368 r
.68347 .65342 .68505 .64908 .68848 .63721 .68683 .63954 Metetra
.994 .856 .515 r
.68683 .63954 .68848 .63721 .69184 .62424 .69012 .6249 Metetra
.992 .837 .585 r
.69012 .6249 .69184 .62424 .69521 .61198 .69345 .61147 Metetra
.972 .817 .631 r
.69345 .61147 .69521 .61198 .69864 .60109 .69684 .59984 Metetra
.948 .802 .665 r
.69684 .59984 .69864 .60109 .70211 .59163 .70031 .58993 Metetra
.926 .791 .693 r
.70031 .58993 .70211 .59163 .70565 .58347 .70383 .58148 Metetra
.905 .783 .716 r
.70383 .58148 .70565 .58347 .70923 .57638 .70741 .57423 Metetra
.885 .777 .737 r
.70741 .57423 .70923 .57638 .71285 .57019 .71103 .56792 Metetra
.868 .773 .755 r
.71103 .56792 .71285 .57019 .71651 .56471 .71469 .56238 Metetra
.852 .769 .77 r
.71469 .56238 .71651 .56471 .72019 .55982 .71838 .55745 Metetra
.837 .766 .783 r
.71838 .55745 .72019 .55982 .7239 .5554 .72209 .55302 Metetra
.824 .763 .795 r
.72209 .55302 .7239 .5554 .72763 .55139 .72583 .54899 Metetra
.812 .761 .805 r
.72583 .54899 .72763 .55139 .73138 .5477 .72958 .5453 Metetra
.801 .759 .814 r
.72958 .5453 .73138 .5477 .73515 .54429 .73335 .54189 Metetra
.791 .757 .822 r
.73335 .54189 .73515 .54429 .73893 .54111 .73714 .53871 Metetra
.782 .756 .829 r
.73714 .53871 .73893 .54111 .74273 .53813 .74094 .53573 Metetra
.774 .754 .836 r
.74094 .53573 .74273 .53813 .74653 .53532 .74475 .53293 Metetra
.766 .753 .841 r
.74475 .53293 .74653 .53532 .75035 .53266 .74858 .53027 Metetra
.76 .752 .846 r
.74858 .53027 .75035 .53266 .75418 .53012 .75241 .52774 Metetra
.753 .751 .85 r
.75241 .52774 .75418 .53012 .75802 .52769 .75626 .52532 Metetra
.748 .75 .854 r
.75626 .52532 .75802 .52769 .76187 .52537 .76011 .52299 Metetra
.743 .75 .858 r
.76011 .52299 .76187 .52537 .76573 .52313 .76397 .52076 Metetra
.738 .749 .861 r
.76397 .52076 .76573 .52313 .76959 .52096 .76784 .5186 Metetra
.734 .748 .864 r
.76784 .5186 .76959 .52096 .77347 .51886 .77172 .5165 Metetra
.73 .748 .867 r
.77172 .5165 .77347 .51886 .77735 .51683 .77561 .51447 Metetra
.726 .747 .869 r
.77561 .51447 .77735 .51683 .78124 .51484 .7795 .51249 Metetra
.723 .747 .871 r
.7795 .51249 .78124 .51484 .78514 .51291 .7834 .51056 Metetra
.72 .746 .873 r
.7834 .51056 .78514 .51291 .78904 .51102 .78731 .50868 Metetra
.717 .746 .875 r
.78731 .50868 .78904 .51102 .79295 .50917 .79123 .50683 Metetra
.714 .746 .877 r
.79123 .50683 .79295 .50917 .79687 .50736 .79515 .50502 Metetra
.712 .745 .878 r
.79515 .50502 .79687 .50736 .8008 .50558 .79908 .50324 Metetra
.709 .745 .88 r
.79908 .50324 .8008 .50558 .80473 .50383 .80302 .50149 Metetra
.707 .745 .881 r
.80302 .50149 .80473 .50383 .80867 .50211 .80696 .49977 Metetra
.705 .745 .882 r
.80696 .49977 .80867 .50211 .81261 .50041 .81091 .49808 Metetra
.703 .744 .883 r
.81091 .49808 .81261 .50041 .81656 .49874 .81487 .49641 Metetra
.702 .744 .885 r
.81487 .49641 .81656 .49874 .82052 .49709 .81883 .49476 Metetra
.7 .744 .886 r
.81883 .49476 .82052 .49709 .82449 .49546 .8228 .49312 Metetra
.698 .744 .886 r
.8228 .49312 .82449 .49546 .82846 .49384 .82677 .49151 Metetra
.697 .744 .887 r
.82677 .49151 .82846 .49384 .83243 .49225 .83075 .48991 Metetra
.696 .743 .888 r
.83075 .48991 .83243 .49225 .83642 .49066 .83474 .48833 Metetra
.694 .743 .889 r
.83474 .48833 .83642 .49066 .84041 .4891 .83873 .48677 Metetra
.693 .743 .89 r
.83873 .48677 .84041 .4891 .8444 .48754 .84273 .48521 Metetra
.692 .743 .89 r
.84273 .48521 .8444 .48754 .8484 .486 .84674 .48367 Metetra
.691 .743 .891 r
.84674 .48367 .8484 .486 .85241 .48447 .85075 .48214 Metetra
.69 .743 .892 r
.85075 .48214 .85241 .48447 .85642 .48295 .85477 .48062 Metetra
.689 .743 .892 r
.85477 .48062 .85642 .48295 .86044 .48144 .85879 .47911 Metetra
.688 .743 .893 r
.85879 .47911 .86044 .48144 .86447 .47995 .86282 .47761 Metetra
.687 .743 .893 r
.86282 .47761 .86447 .47995 .8685 .47845 .86685 .47612 Metetra
.686 .742 .894 r
.86685 .47612 .8685 .47845 .87253 .47697 .8709 .47464 Metetra
.686 .742 .894 r
.8709 .47464 .87253 .47697 .87658 .4755 .87494 .47316 Metetra
.685 .742 .895 r
.87494 .47316 .87658 .4755 .88063 .47403 .879 .47169 Metetra
.684 .742 .895 r
.879 .47169 .88063 .47403 .88468 .47257 .88306 .47023 Metetra
.684 .742 .895 r
.88306 .47023 .88468 .47257 .88874 .47111 .88712 .46877 Metetra
.683 .742 .896 r
.88712 .46877 .88874 .47111 .89281 .46966 .89119 .46732 Metetra
.682 .742 .896 r
.89119 .46732 .89281 .46966 .89688 .46822 .89527 .46588 Metetra
.682 .742 .897 r
.89527 .46588 .89688 .46822 .90096 .46678 .89935 .46444 Metetra
.681 .742 .897 r
.89935 .46444 .90096 .46678 .90505 .46535 .90344 .463 Metetra
.681 .742 .897 r
.90344 .463 .90505 .46535 .90914 .46392 .90754 .46157 Metetra
.68 .742 .897 r
.90754 .46157 .90914 .46392 .91323 .46249 .91164 .46014 Metetra
.68 .742 .898 r
.91164 .46014 .91323 .46249 .91733 .46107 .91574 .45872 Metetra
.679 .742 .898 r
.91574 .45872 .91733 .46107 .92144 .45965 .91986 .4573 Metetra
.679 .742 .898 r
.91986 .4573 .92144 .45965 .92556 .45824 .92398 .45588 Metetra
.678 .742 .899 r
.92398 .45588 .92556 .45824 .92968 .45682 .9281 .45447 Metetra
.678 .742 .899 r
.9281 .45447 .92968 .45682 .9338 .45542 .93223 .45306 Metetra
.678 .742 .899 r
.93223 .45306 .9338 .45542 .93794 .45401 .93637 .45165 Metetra
.677 .742 .899 r
.93637 .45165 .93794 .45401 .94207 .45261 .94051 .45024 Metetra
.677 .742 .899 r
.94051 .45024 .94207 .45261 .94622 .45121 .94466 .44884 Metetra
.677 .742 .9 r
.94466 .44884 .94622 .45121 .95037 .44981 .94881 .44744 Metetra
.676 .742 .9 r
.94881 .44744 .95037 .44981 .95452 .44841 .95297 .44604 Metetra
.676 .742 .9 r
.95297 .44604 .95452 .44841 .95869 .44702 .95714 .44464 Metetra
.676 .741 .9 r
.95714 .44464 .95869 .44702 .96285 .44562 .96131 .44325 Metetra
.675 .741 .9 r
.96131 .44325 .96285 .44562 .96703 .44423 .96549 .44185 Metetra
.675 .741 .901 r
.96549 .44185 .96703 .44423 .97121 .44284 .96967 .44046 Metetra
.649 .733 .91 r
.40074 .60798 .40279 .60994 .40623 .60904 .40418 .60708 Metetra
.649 .733 .91 r
.40418 .60708 .40623 .60904 .40967 .60814 .40763 .60618 Metetra
.649 .732 .91 r
.40763 .60618 .40967 .60814 .41312 .60725 .41108 .60528 Metetra
.648 .732 .91 r
.41108 .60528 .41312 .60725 .41657 .60635 .41453 .60438 Metetra
.648 .732 .911 r
.41453 .60438 .41657 .60635 .42003 .60546 .41799 .60348 Metetra
.647 .732 .911 r
.41799 .60348 .42003 .60546 .4235 .60457 .42146 .60259 Metetra
.647 .732 .911 r
.42146 .60259 .4235 .60457 .42696 .60369 .42493 .6017 Metetra
.647 .731 .911 r
.42493 .6017 .42696 .60369 .43043 .6028 .4284 .60081 Metetra
.646 .731 .911 r
.4284 .60081 .43043 .6028 .43391 .60192 .43188 .59993 Metetra
.646 .731 .911 r
.43188 .59993 .43391 .60192 .43739 .60104 .43537 .59905 Metetra
.645 .731 .911 r
.43537 .59905 .43739 .60104 .44088 .60017 .43886 .59817 Metetra
.645 .73 .911 r
.43886 .59817 .44088 .60017 .44437 .5993 .44235 .59729 Metetra
.644 .73 .911 r
.44235 .59729 .44437 .5993 .44786 .59843 .44585 .59642 Metetra
.643 .73 .911 r
.44585 .59642 .44786 .59843 .45136 .59757 .44935 .59556 Metetra
.643 .729 .911 r
.44935 .59556 .45136 .59757 .45487 .59671 .45286 .59469 Metetra
.642 .729 .912 r
.45286 .59469 .45487 .59671 .45838 .59585 .45637 .59383 Metetra
.642 .729 .912 r
.45637 .59383 .45838 .59585 .46189 .595 .45989 .59298 Metetra
.641 .728 .912 r
.45989 .59298 .46189 .595 .46541 .59416 .46341 .59213 Metetra
.64 .728 .912 r
.46341 .59213 .46541 .59416 .46894 .59332 .46694 .59129 Metetra
.639 .727 .912 r
.46694 .59129 .46894 .59332 .47247 .59248 .47047 .59045 Metetra
.639 .727 .912 r
.47047 .59045 .47247 .59248 .476 .59166 .47401 .58962 Metetra
.638 .727 .912 r
.47401 .58962 .476 .59166 .47954 .59083 .47755 .58879 Metetra
.637 .726 .913 r
.47755 .58879 .47954 .59083 .48308 .59002 .48109 .58797 Metetra
.636 .726 .913 r
.48109 .58797 .48308 .59002 .48663 .58921 .48465 .58716 Metetra
.635 .725 .913 r
.48465 .58716 .48663 .58921 .49019 .58841 .4882 .58636 Metetra
.634 .725 .913 r
.4882 .58636 .49019 .58841 .49375 .58762 .49176 .58556 Metetra
.633 .724 .913 r
.49176 .58556 .49375 .58762 .49731 .58684 .49533 .58477 Metetra
.632 .723 .913 r
.49533 .58477 .49731 .58684 .50088 .58607 .4989 .584 Metetra
.63 .723 .914 r
.4989 .584 .50088 .58607 .50445 .58531 .50248 .58323 Metetra
.629 .722 .914 r
.50248 .58323 .50445 .58531 .50803 .58456 .50606 .58247 Metetra
.628 .721 .914 r
.50606 .58247 .50803 .58456 .51162 .58382 .50965 .58173 Metetra
.626 .72 .914 r
.50965 .58173 .51162 .58382 .51521 .58309 .51325 .58099 Metetra
.624 .72 .915 r
.51325 .58099 .51521 .58309 .51881 .58238 .51684 .58028 Metetra
.623 .719 .915 r
.51684 .58028 .51881 .58238 .52241 .58168 .52045 .57957 Metetra
.621 .718 .915 r
.52045 .57957 .52241 .58168 .52601 .58099 .52406 .57888 Metetra
.619 .717 .916 r
.52406 .57888 .52601 .58099 .52963 .58033 .52767 .57821 Metetra
.616 .715 .916 r
.52767 .57821 .52963 .58033 .53325 .57968 .5313 .57756 Metetra
.614 .714 .917 r
.5313 .57756 .53325 .57968 .53687 .57905 .53492 .57692 Metetra
.611 .713 .917 r
.53492 .57692 .53687 .57905 .5405 .57845 .53855 .57631 Metetra
.609 .711 .918 r
.53855 .57631 .5405 .57845 .54414 .57786 .54219 .57572 Metetra
.605 .71 .918 r
.54219 .57572 .54414 .57786 .54778 .57731 .54584 .57515 Metetra
.602 .708 .919 r
.54584 .57515 .54778 .57731 .55143 .57678 .54949 .57461 Metetra
.598 .706 .919 r
.54949 .57461 .55143 .57678 .55508 .57628 .55315 .57411 Metetra
.594 .704 .92 r
.55315 .57411 .55508 .57628 .55874 .57581 .55681 .57363 Metetra
.59 .702 .921 r
.55681 .57363 .55874 .57581 .56241 .57538 .56048 .57319 Metetra
.585 .699 .921 r
.56048 .57319 .56241 .57538 .56608 .57499 .56415 .57279 Metetra
.579 .696 .922 r
.56415 .57279 .56608 .57499 .56976 .57464 .56784 .57244 Metetra
.573 .693 .923 r
.56784 .57244 .56976 .57464 .57345 .57434 .57153 .57213 Metetra
.565 .69 .924 r
.57153 .57213 .57345 .57434 .57715 .5741 .57523 .57188 Metetra
.557 .686 .925 r
.57523 .57188 .57715 .5741 .58085 .57392 .57893 .57168 Metetra
.548 .681 .926 r
.57893 .57168 .58085 .57392 .58456 .5738 .58265 .57156 Metetra
.537 .675 .927 r
.58265 .57156 .58456 .5738 .58828 .57377 .58637 .57151 Metetra
.525 .669 .928 r
.58637 .57151 .58828 .57377 .59201 .57381 .5901 .57155 Metetra
.511 .662 .929 r
.5901 .57155 .59201 .57381 .59575 .57396 .59384 .57168 Metetra
.494 .653 .93 r
.59384 .57168 .59575 .57396 .5995 .57422 .59759 .57192 Metetra
.473 .642 .931 r
.59759 .57192 .5995 .57422 .60326 .5746 .60135 .5723 Metetra
.449 .63 .931 r
.60135 .5723 .60326 .5746 .60703 .57513 .60513 .57282 Metetra
.419 .613 .93 r
.60513 .57282 .60703 .57513 .61081 .57584 .60891 .57351 Metetra
.382 .593 .928 r
.60891 .57351 .61081 .57584 .61461 .57674 .61271 .5744 Metetra
.334 .567 .923 r
.61271 .5744 .61461 .57674 .61843 .57788 .61653 .57553 Metetra
.274 .531 .914 r
.61653 .57553 .61843 .57788 .62226 .5793 .62037 .57694 Metetra
.195 .484 .897 r
.62037 .57694 .62226 .5793 .62611 .58106 .62422 .5787 Metetra
.092 .418 .866 r
.62422 .5787 .62611 .58106 .62999 .58322 .6281 .58087 Metetra
0 .327 .811 r
.6281 .58087 .62999 .58322 .6339 .58588 .63201 .58355 Metetra
0 .203 .719 r
.63201 .58355 .6339 .58588 .63784 .58915 .63595 .58686 Metetra
0 .047 .578 r
.63595 .58686 .63784 .58915 .64182 .59319 .63994 .59098 Metetra
.601 .126 0 r
.63994 .59098 .64182 .59319 .64585 .59818 .64397 .59611 Metetra
.755 .286 0 r
.64397 .59611 .64585 .59818 .64995 .60436 .64808 .60254 Metetra
.853 .408 0 r
.64808 .60254 .64995 .60436 .65412 .61201 .65226 .61061 Metetra
.902 .488 .144 r
.65226 .61061 .65412 .61201 .65838 .62139 .65655 .62072 Metetra
.919 .533 .252 r
.65655 .62072 .65838 .62139 .66275 .63258 .66096 .63312 Metetra
.912 .548 .329 r
.66096 .63312 .66275 .63258 .66719 .645 .66549 .64742 Metetra
.881 .532 .383 r
.66549 .64742 .66719 .645 .67165 .65668 .67005 .66151 Metetra
.793 .454 .413 r
.67005 .66151 .67165 .65668 .67594 .66383 .67443 .67061 Metetra
.491 .183 .371 r
.67443 .67061 .67594 .66383 .67989 .66275 .67839 .66953 Metetra
0 0 .011 r
.67839 .66953 .67989 .66275 .68347 .65342 .6819 .65825 Metetra
.92 .824 .364 r
.6819 .65825 .68347 .65342 .68683 .63954 .68516 .64195 Metetra
.998 .841 .507 r
.68516 .64195 .68683 .63954 .69012 .6249 .68838 .62542 Metetra
.991 .822 .577 r
.68838 .62542 .69012 .6249 .69345 .61147 .69167 .61078 Metetra
.969 .805 .624 r
.69167 .61078 .69345 .61147 .69684 .59984 .69503 .59841 Metetra
.946 .792 .659 r
.69503 .59841 .69684 .59984 .70031 .58993 .69849 .58807 Metetra
.923 .783 .688 r
.69849 .58807 .70031 .58993 .70383 .58148 .70201 .57937 Metetra
.902 .776 .713 r
.70201 .57937 .70383 .58148 .70741 .57423 .70558 .57197 Metetra
.883 .771 .734 r
.70558 .57197 .70741 .57423 .71103 .56792 .70921 .56558 Metetra
.866 .768 .752 r
.70921 .56558 .71103 .56792 .71469 .56238 .71287 .55999 Metetra
.85 .765 .768 r
.71287 .55999 .71469 .56238 .71838 .55745 .71656 .55503 Metetra
.835 .762 .782 r
.71656 .55503 .71838 .55745 .72209 .55302 .72028 .55059 Metetra
.822 .76 .794 r
.72028 .55059 .72209 .55302 .72583 .54899 .72402 .54655 Metetra
.81 .758 .804 r
.72402 .54655 .72583 .54899 .72958 .5453 .72778 .54286 Metetra
.799 .757 .814 r
.72778 .54286 .72958 .5453 .73335 .54189 .73156 .53945 Metetra
.79 .755 .822 r
.73156 .53945 .73335 .54189 .73714 .53871 .73535 .53628 Metetra
.781 .754 .829 r
.73535 .53628 .73714 .53871 .74094 .53573 .73915 .53331 Metetra
.773 .753 .835 r
.73915 .53331 .74094 .53573 .74475 .53293 .74297 .53051 Metetra
.765 .752 .841 r
.74297 .53051 .74475 .53293 .74858 .53027 .7468 .52786 Metetra
.759 .751 .846 r
.7468 .52786 .74858 .53027 .75241 .52774 .75064 .52534 Metetra
.752 .75 .85 r
.75064 .52534 .75241 .52774 .75626 .52532 .75449 .52292 Metetra
.747 .749 .854 r
.75449 .52292 .75626 .52532 .76011 .52299 .75834 .52061 Metetra
.742 .749 .858 r
.75834 .52061 .76011 .52299 .76397 .52076 .76221 .51838 Metetra
.737 .748 .861 r
.76221 .51838 .76397 .52076 .76784 .5186 .76609 .51622 Metetra
.733 .748 .864 r
.76609 .51622 .76784 .5186 .77172 .5165 .76997 .51413 Metetra
.729 .747 .866 r
.76997 .51413 .77172 .5165 .77561 .51447 .77386 .5121 Metetra
.725 .747 .869 r
.77386 .5121 .77561 .51447 .7795 .51249 .77776 .51013 Metetra
.722 .746 .871 r
.77776 .51013 .7795 .51249 .7834 .51056 .78167 .5082 Metetra
.719 .746 .873 r
.78167 .5082 .7834 .51056 .78731 .50868 .78558 .50632 Metetra
.716 .746 .875 r
.78558 .50632 .78731 .50868 .79123 .50683 .7895 .50448 Metetra
.714 .745 .877 r
.7895 .50448 .79123 .50683 .79515 .50502 .79343 .50267 Metetra
.711 .745 .878 r
.79343 .50267 .79515 .50502 .79908 .50324 .79736 .50089 Metetra
.709 .745 .88 r
.79736 .50089 .79908 .50324 .80302 .50149 .8013 .49915 Metetra
.707 .744 .881 r
.8013 .49915 .80302 .50149 .80696 .49977 .80525 .49743 Metetra
.705 .744 .882 r
.80525 .49743 .80696 .49977 .81091 .49808 .8092 .49574 Metetra
.703 .744 .883 r
.8092 .49574 .81091 .49808 .81487 .49641 .81316 .49407 Metetra
.701 .744 .885 r
.81316 .49407 .81487 .49641 .81883 .49476 .81713 .49242 Metetra
.7 .744 .886 r
.81713 .49242 .81883 .49476 .8228 .49312 .8211 .49078 Metetra
.698 .743 .886 r
.8211 .49078 .8228 .49312 .82677 .49151 .82508 .48917 Metetra
.697 .743 .887 r
.82508 .48917 .82677 .49151 .83075 .48991 .82907 .48758 Metetra
.695 .743 .888 r
.82907 .48758 .83075 .48991 .83474 .48833 .83306 .48599 Metetra
.694 .743 .889 r
.83306 .48599 .83474 .48833 .83873 .48677 .83706 .48443 Metetra
.693 .743 .89 r
.83706 .48443 .83873 .48677 .84273 .48521 .84106 .48287 Metetra
.692 .743 .89 r
.84106 .48287 .84273 .48521 .84674 .48367 .84507 .48133 Metetra
.691 .743 .891 r
.84507 .48133 .84674 .48367 .85075 .48214 .84908 .4798 Metetra
.69 .743 .892 r
.84908 .4798 .85075 .48214 .85477 .48062 .85311 .47828 Metetra
.689 .743 .892 r
.85311 .47828 .85477 .48062 .85879 .47911 .85713 .47677 Metetra
.688 .742 .893 r
.85713 .47677 .85879 .47911 .86282 .47761 .86117 .47527 Metetra
.687 .742 .893 r
.86117 .47527 .86282 .47761 .86685 .47612 .86521 .47378 Metetra
.686 .742 .894 r
.86521 .47378 .86685 .47612 .8709 .47464 .86925 .47229 Metetra
.686 .742 .894 r
.86925 .47229 .8709 .47464 .87494 .47316 .87331 .47082 Metetra
.685 .742 .895 r
.87331 .47082 .87494 .47316 .879 .47169 .87736 .46935 Metetra
.684 .742 .895 r
.87736 .46935 .879 .47169 .88306 .47023 .88143 .46788 Metetra
.683 .742 .895 r
.88143 .46788 .88306 .47023 .88712 .46877 .8855 .46643 Metetra
.683 .742 .896 r
.8855 .46643 .88712 .46877 .89119 .46732 .88957 .46497 Metetra
.682 .742 .896 r
.88957 .46497 .89119 .46732 .89527 .46588 .89365 .46353 Metetra
.682 .742 .897 r
.89365 .46353 .89527 .46588 .89935 .46444 .89774 .46208 Metetra
.681 .742 .897 r
.89774 .46208 .89935 .46444 .90344 .463 .90183 .46065 Metetra
.681 .742 .897 r
.90183 .46065 .90344 .463 .90754 .46157 .90593 .45921 Metetra
.68 .742 .897 r
.90593 .45921 .90754 .46157 .91164 .46014 .91004 .45779 Metetra
.68 .742 .898 r
.91004 .45779 .91164 .46014 .91574 .45872 .91415 .45636 Metetra
.679 .742 .898 r
.91415 .45636 .91574 .45872 .91986 .4573 .91827 .45494 Metetra
.679 .742 .898 r
.91827 .45494 .91986 .4573 .92398 .45588 .92239 .45352 Metetra
.678 .742 .899 r
.92239 .45352 .92398 .45588 .9281 .45447 .92652 .4521 Metetra
.678 .742 .899 r
.92652 .4521 .9281 .45447 .93223 .45306 .93065 .45069 Metetra
.678 .742 .899 r
.93065 .45069 .93223 .45306 .93637 .45165 .93479 .44928 Metetra
.677 .742 .899 r
.93479 .44928 .93637 .45165 .94051 .45024 .93894 .44787 Metetra
.677 .742 .899 r
.93894 .44787 .94051 .45024 .94466 .44884 .94309 .44647 Metetra
.677 .741 .9 r
.94309 .44647 .94466 .44884 .94881 .44744 .94725 .44507 Metetra
.676 .741 .9 r
.94725 .44507 .94881 .44744 .95297 .44604 .95142 .44366 Metetra
.676 .741 .9 r
.95142 .44366 .95297 .44604 .95714 .44464 .95559 .44227 Metetra
.676 .741 .9 r
.95559 .44227 .95714 .44464 .96131 .44325 .95977 .44087 Metetra
.675 .741 .9 r
.95977 .44087 .96131 .44325 .96549 .44185 .96395 .43947 Metetra
.675 .741 .901 r
.96395 .43947 .96549 .44185 .96967 .44046 .96814 .43808 Metetra
.649 .733 .91 r
.39868 .60602 .40074 .60798 .40418 .60708 .40213 .60511 Metetra
.649 .733 .91 r
.40213 .60511 .40418 .60708 .40763 .60618 .40558 .60421 Metetra
.649 .732 .91 r
.40558 .60421 .40763 .60618 .41108 .60528 .40903 .6033 Metetra
.648 .732 .91 r
.40903 .6033 .41108 .60528 .41453 .60438 .41249 .6024 Metetra
.648 .732 .91 r
.41249 .6024 .41453 .60438 .41799 .60348 .41595 .6015 Metetra
.647 .732 .911 r
.41595 .6015 .41799 .60348 .42146 .60259 .41942 .60061 Metetra
.647 .732 .911 r
.41942 .60061 .42146 .60259 .42493 .6017 .42289 .59971 Metetra
.647 .731 .911 r
.42289 .59971 .42493 .6017 .4284 .60081 .42637 .59882 Metetra
.646 .731 .911 r
.42637 .59882 .4284 .60081 .43188 .59993 .42985 .59793 Metetra
.646 .731 .911 r
.42985 .59793 .43188 .59993 .43537 .59905 .43334 .59705 Metetra
.645 .731 .911 r
.43334 .59705 .43537 .59905 .43886 .59817 .43683 .59616 Metetra
.645 .73 .911 r
.43683 .59616 .43886 .59817 .44235 .59729 .44033 .59529 Metetra
.644 .73 .911 r
.44033 .59529 .44235 .59729 .44585 .59642 .44383 .59441 Metetra
.644 .73 .911 r
.44383 .59441 .44585 .59642 .44935 .59556 .44733 .59354 Metetra
.643 .729 .911 r
.44733 .59354 .44935 .59556 .45286 .59469 .45084 .59267 Metetra
.642 .729 .911 r
.45084 .59267 .45286 .59469 .45637 .59383 .45436 .59181 Metetra
.642 .729 .912 r
.45436 .59181 .45637 .59383 .45989 .59298 .45788 .59095 Metetra
.641 .728 .912 r
.45788 .59095 .45989 .59298 .46341 .59213 .4614 .5901 Metetra
.64 .728 .912 r
.4614 .5901 .46341 .59213 .46694 .59129 .46493 .58925 Metetra
.64 .727 .912 r
.46493 .58925 .46694 .59129 .47047 .59045 .46847 .58841 Metetra
.639 .727 .912 r
.46847 .58841 .47047 .59045 .47401 .58962 .47201 .58757 Metetra
.638 .727 .912 r
.47201 .58757 .47401 .58962 .47755 .58879 .47555 .58674 Metetra
.637 .726 .912 r
.47555 .58674 .47755 .58879 .48109 .58797 .4791 .58592 Metetra
.636 .726 .913 r
.4791 .58592 .48109 .58797 .48465 .58716 .48266 .5851 Metetra
.635 .725 .913 r
.48266 .5851 .48465 .58716 .4882 .58636 .48621 .58429 Metetra
.634 .725 .913 r
.48621 .58429 .4882 .58636 .49176 .58556 .48978 .58349 Metetra
.633 .724 .913 r
.48978 .58349 .49176 .58556 .49533 .58477 .49335 .5827 Metetra
.632 .723 .913 r
.49335 .5827 .49533 .58477 .4989 .584 .49692 .58192 Metetra
.631 .723 .914 r
.49692 .58192 .4989 .584 .50248 .58323 .5005 .58114 Metetra
.629 .722 .914 r
.5005 .58114 .50248 .58323 .50606 .58247 .50409 .58038 Metetra
.628 .721 .914 r
.50409 .58038 .50606 .58247 .50965 .58173 .50768 .57963 Metetra
.626 .72 .914 r
.50768 .57963 .50965 .58173 .51325 .58099 .51128 .57889 Metetra
.625 .72 .915 r
.51128 .57889 .51325 .58099 .51684 .58028 .51488 .57817 Metetra
.623 .719 .915 r
.51488 .57817 .51684 .58028 .52045 .57957 .51849 .57746 Metetra
.621 .718 .915 r
.51849 .57746 .52045 .57957 .52406 .57888 .5221 .57676 Metetra
.619 .717 .916 r
.5221 .57676 .52406 .57888 .52767 .57821 .52572 .57608 Metetra
.617 .715 .916 r
.52572 .57608 .52767 .57821 .5313 .57756 .52934 .57542 Metetra
.615 .714 .916 r
.52934 .57542 .5313 .57756 .53492 .57692 .53297 .57478 Metetra
.612 .713 .917 r
.53297 .57478 .53492 .57692 .53855 .57631 .5366 .57416 Metetra
.609 .711 .917 r
.5366 .57416 .53855 .57631 .54219 .57572 .54025 .57356 Metetra
.606 .71 .918 r
.54025 .57356 .54219 .57572 .54584 .57515 .54389 .57299 Metetra
.603 .708 .918 r
.54389 .57299 .54584 .57515 .54949 .57461 .54755 .57245 Metetra
.599 .706 .919 r
.54755 .57245 .54949 .57461 .55315 .57411 .55121 .57193 Metetra
.595 .704 .919 r
.55121 .57193 .55315 .57411 .55681 .57363 .55487 .57145 Metetra
.591 .702 .92 r
.55487 .57145 .55681 .57363 .56048 .57319 .55854 .571 Metetra
.586 .699 .921 r
.55854 .571 .56048 .57319 .56415 .57279 .56222 .57059 Metetra
.58 .696 .922 r
.56222 .57059 .56415 .57279 .56784 .57244 .56591 .57022 Metetra
.574 .693 .922 r
.56591 .57022 .56784 .57244 .57153 .57213 .5696 .56991 Metetra
.567 .69 .923 r
.5696 .56991 .57153 .57213 .57523 .57188 .5733 .56964 Metetra
.559 .686 .924 r
.5733 .56964 .57523 .57188 .57893 .57168 .57701 .56944 Metetra
.55 .681 .925 r
.57701 .56944 .57893 .57168 .58265 .57156 .58073 .5693 Metetra
.539 .676 .926 r
.58073 .5693 .58265 .57156 .58637 .57151 .58445 .56924 Metetra
.527 .669 .927 r
.58445 .56924 .58637 .57151 .5901 .57155 .58819 .56926 Metetra
.513 .662 .928 r
.58819 .56926 .5901 .57155 .59384 .57168 .59193 .56938 Metetra
.496 .653 .929 r
.59193 .56938 .59384 .57168 .59759 .57192 .59568 .56961 Metetra
.476 .643 .93 r
.59568 .56961 .59759 .57192 .60135 .5723 .59945 .56997 Metetra
.452 .63 .93 r
.59945 .56997 .60135 .5723 .60513 .57282 .60322 .57048 Metetra
.423 .614 .929 r
.60322 .57048 .60513 .57282 .60891 .57351 .60701 .57115 Metetra
.386 .594 .927 r
.60701 .57115 .60891 .57351 .61271 .5744 .61081 .57203 Metetra
.34 .567 .922 r
.61081 .57203 .61271 .5744 .61653 .57553 .61463 .57315 Metetra
.281 .533 .914 r
.61463 .57315 .61653 .57553 .62037 .57694 .61847 .57455 Metetra
.204 .486 .897 r
.61847 .57455 .62037 .57694 .62422 .5787 .62232 .5763 Metetra
.102 .421 .867 r
.62232 .5763 .62422 .5787 .6281 .58087 .6262 .57846 Metetra
0 .33 .813 r
.6262 .57846 .6281 .58087 .63201 .58355 .63011 .58115 Metetra
0 .206 .723 r
.63011 .58115 .63201 .58355 .63595 .58686 .63406 .5845 Metetra
0 .048 .583 r
.63406 .5845 .63595 .58686 .63994 .59098 .63804 .58867 Metetra
.596 .128 0 r
.63804 .58867 .63994 .59098 .64397 .59611 .64208 .59392 Metetra
.755 .292 0 r
.64208 .59392 .64397 .59611 .64808 .60254 .64619 .60056 Metetra
.857 .418 0 r
.64619 .60056 .64808 .60254 .65226 .61061 .65039 .60902 Metetra
.909 .501 .15 r
.65039 .60902 .65226 .61061 .65655 .62072 .65471 .61983 Metetra
.927 .548 .26 r
.65471 .61983 .65655 .62072 .66096 .63312 .65917 .63347 Metetra
.922 .566 .338 r
.65917 .63347 .66096 .63312 .66549 .64742 .66377 .64985 Metetra
.895 .554 .394 r
.66377 .64985 .66549 .64742 .67005 .66151 .66845 .66685 Metetra
.814 .483 .429 r
.66845 .66685 .67005 .66151 .67443 .67061 .67295 .67847 Metetra
.504 .208 .398 r
.67295 .67847 .67443 .67061 .67839 .66953 .67693 .67739 Metetra
0 0 .008 r
.67693 .67739 .67839 .66953 .6819 .65825 .68035 .6636 Metetra
.941 .815 .364 r
.68035 .6636 .6819 .65825 .68516 .64195 .68349 .64439 Metetra
1 .825 .502 r
.68349 .64439 .68516 .64195 .68838 .62542 .68663 .62577 Metetra
.988 .808 .572 r
.68663 .62577 .68838 .62542 .69167 .61078 .68987 .60987 Metetra
.966 .793 .618 r
.68987 .60987 .69167 .61078 .69503 .59841 .69321 .59679 Metetra
.942 .782 .654 r
.69321 .59679 .69503 .59841 .69849 .58807 .69665 .58605 Metetra
.92 .775 .684 r
.69665 .58605 .69849 .58807 .70201 .57937 .70017 .57714 Metetra
.899 .77 .709 r
.70017 .57714 .70201 .57937 .70558 .57197 .70375 .56961 Metetra
.881 .766 .731 r
.70375 .56961 .70558 .57197 .70921 .56558 .70738 .56316 Metetra
.864 .763 .75 r
.70738 .56316 .70921 .56558 .71287 .55999 .71104 .55753 Metetra
.848 .761 .766 r
.71104 .55753 .71287 .55999 .71656 .55503 .71474 .55256 Metetra
.834 .759 .78 r
.71474 .55256 .71656 .55503 .72028 .55059 .71846 .54811 Metetra
.821 .757 .793 r
.71846 .54811 .72028 .55059 .72402 .54655 .72221 .54408 Metetra
.809 .756 .803 r
.72221 .54408 .72402 .54655 .72778 .54286 .72597 .54039 Metetra
.798 .754 .813 r
.72597 .54039 .72778 .54286 .73156 .53945 .72975 .53699 Metetra
.788 .753 .821 r
.72975 .53699 .73156 .53945 .73535 .53628 .73355 .53383 Metetra
.779 .752 .828 r
.73355 .53383 .73535 .53628 .73915 .53331 .73736 .53087 Metetra
.771 .751 .835 r
.73736 .53087 .73915 .53331 .74297 .53051 .74118 .52808 Metetra
.764 .75 .84 r
.74118 .52808 .74297 .53051 .7468 .52786 .74501 .52544 Metetra
.758 .75 .845 r
.74501 .52544 .7468 .52786 .75064 .52534 .74886 .52292 Metetra
.752 .749 .85 r
.74886 .52292 .75064 .52534 .75449 .52292 .75271 .52052 Metetra
.746 .748 .854 r
.75271 .52052 .75449 .52292 .75834 .52061 .75657 .51821 Metetra
.741 .748 .858 r
.75657 .51821 .75834 .52061 .76221 .51838 .76044 .51598 Metetra
.736 .747 .861 r
.76044 .51598 .76221 .51838 .76609 .51622 .76432 .51383 Metetra
.732 .747 .864 r
.76432 .51383 .76609 .51622 .76997 .51413 .76821 .51175 Metetra
.728 .746 .866 r
.76821 .51175 .76997 .51413 .77386 .5121 .77211 .50973 Metetra
.725 .746 .869 r
.77211 .50973 .77386 .5121 .77776 .51013 .77601 .50776 Metetra
.721 .746 .871 r
.77601 .50776 .77776 .51013 .78167 .5082 .77992 .50583 Metetra
.718 .745 .873 r
.77992 .50583 .78167 .5082 .78558 .50632 .78384 .50395 Metetra
.716 .745 .875 r
.78384 .50395 .78558 .50632 .7895 .50448 .78777 .50211 Metetra
.713 .745 .877 r
.78777 .50211 .7895 .50448 .79343 .50267 .7917 .50031 Metetra
.711 .744 .878 r
.7917 .50031 .79343 .50267 .79736 .50089 .79564 .49854 Metetra
.708 .744 .88 r
.79564 .49854 .79736 .50089 .8013 .49915 .79958 .49679 Metetra
.706 .744 .881 r
.79958 .49679 .8013 .49915 .80525 .49743 .80353 .49508 Metetra
.704 .744 .882 r
.80353 .49508 .80525 .49743 .8092 .49574 .80749 .49339 Metetra
.703 .744 .883 r
.80749 .49339 .8092 .49574 .81316 .49407 .81146 .49172 Metetra
.701 .743 .885 r
.81146 .49172 .81316 .49407 .81713 .49242 .81543 .49007 Metetra
.699 .743 .886 r
.81543 .49007 .81713 .49242 .8211 .49078 .8194 .48844 Metetra
.698 .743 .886 r
.8194 .48844 .8211 .49078 .82508 .48917 .82339 .48683 Metetra
.696 .743 .887 r
.82339 .48683 .82508 .48917 .82907 .48758 .82738 .48523 Metetra
.695 .743 .888 r
.82738 .48523 .82907 .48758 .83306 .48599 .83137 .48365 Metetra
.694 .743 .889 r
.83137 .48365 .83306 .48599 .83706 .48443 .83537 .48208 Metetra
.693 .743 .89 r
.83537 .48208 .83706 .48443 .84106 .48287 .83938 .48053 Metetra
.692 .743 .89 r
.83938 .48053 .84106 .48287 .84507 .48133 .8434 .47899 Metetra
.69 .742 .891 r
.8434 .47899 .84507 .48133 .84908 .4798 .84742 .47746 Metetra
.69 .742 .892 r
.84742 .47746 .84908 .4798 .85311 .47828 .85144 .47594 Metetra
.689 .742 .892 r
.85144 .47594 .85311 .47828 .85713 .47677 .85547 .47443 Metetra
.688 .742 .893 r
.85547 .47443 .85713 .47677 .86117 .47527 .85951 .47292 Metetra
.687 .742 .893 r
.85951 .47292 .86117 .47527 .86521 .47378 .86356 .47143 Metetra
.686 .742 .894 r
.86356 .47143 .86521 .47378 .86925 .47229 .86761 .46995 Metetra
.685 .742 .894 r
.86761 .46995 .86925 .47229 .87331 .47082 .87166 .46847 Metetra
.685 .742 .895 r
.87166 .46847 .87331 .47082 .87736 .46935 .87572 .467 Metetra
.684 .742 .895 r
.87572 .467 .87736 .46935 .88143 .46788 .87979 .46553 Metetra
.683 .742 .895 r
.87979 .46553 .88143 .46788 .8855 .46643 .88387 .46407 Metetra
.683 .742 .896 r
.88387 .46407 .8855 .46643 .88957 .46497 .88795 .46262 Metetra
.682 .742 .896 r
.88795 .46262 .88957 .46497 .89365 .46353 .89203 .46117 Metetra
.682 .742 .897 r
.89203 .46117 .89365 .46353 .89774 .46208 .89612 .45973 Metetra
.681 .742 .897 r
.89612 .45973 .89774 .46208 .90183 .46065 .90022 .45829 Metetra
.68 .742 .897 r
.90022 .45829 .90183 .46065 .90593 .45921 .90433 .45685 Metetra
.68 .742 .897 r
.90433 .45685 .90593 .45921 .91004 .45779 .90843 .45542 Metetra
.68 .742 .898 r
.90843 .45542 .91004 .45779 .91415 .45636 .91255 .454 Metetra
.679 .742 .898 r
.91255 .454 .91415 .45636 .91827 .45494 .91667 .45257 Metetra
.679 .742 .898 r
.91667 .45257 .91827 .45494 .92239 .45352 .9208 .45115 Metetra
.678 .742 .899 r
.9208 .45115 .92239 .45352 .92652 .4521 .92493 .44973 Metetra
.678 .741 .899 r
.92493 .44973 .92652 .4521 .93065 .45069 .92907 .44832 Metetra
.677 .741 .899 r
.92907 .44832 .93065 .45069 .93479 .44928 .93322 .44691 Metetra
.677 .741 .899 r
.93322 .44691 .93479 .44928 .93894 .44787 .93737 .4455 Metetra
.677 .741 .899 r
.93737 .4455 .93894 .44787 .94309 .44647 .94153 .44409 Metetra
.676 .741 .9 r
.94153 .44409 .94309 .44647 .94725 .44507 .94569 .44269 Metetra
.676 .741 .9 r
.94569 .44269 .94725 .44507 .95142 .44366 .94986 .44128 Metetra
.676 .741 .9 r
.94986 .44128 .95142 .44366 .95559 .44227 .95403 .43988 Metetra
.675 .741 .9 r
.95403 .43988 .95559 .44227 .95977 .44087 .95822 .43848 Metetra
.675 .741 .9 r
.95822 .43848 .95977 .44087 .96395 .43947 .9624 .43708 Metetra
.675 .741 .901 r
.9624 .43708 .96395 .43947 .96814 .43808 .9666 .43569 Metetra
.649 .733 .91 r
.39662 .60405 .39868 .60602 .40213 .60511 .40007 .60314 Metetra
.649 .733 .91 r
.40007 .60314 .40213 .60511 .40558 .60421 .40352 .60223 Metetra
.649 .732 .91 r
.40352 .60223 .40558 .60421 .40903 .6033 .40698 .60132 Metetra
.648 .732 .91 r
.40698 .60132 .40903 .6033 .41249 .6024 .41044 .60042 Metetra
.648 .732 .91 r
.41044 .60042 .41249 .6024 .41595 .6015 .4139 .59952 Metetra
.648 .732 .91 r
.4139 .59952 .41595 .6015 .41942 .60061 .41738 .59862 Metetra
.647 .732 .911 r
.41738 .59862 .41942 .60061 .42289 .59971 .42085 .59772 Metetra
.647 .731 .911 r
.42085 .59772 .42289 .59971 .42637 .59882 .42433 .59682 Metetra
.646 .731 .911 r
.42433 .59682 .42637 .59882 .42985 .59793 .42782 .59593 Metetra
.646 .731 .911 r
.42782 .59593 .42985 .59793 .43334 .59705 .4313 .59504 Metetra
.645 .731 .911 r
.4313 .59504 .43334 .59705 .43683 .59616 .4348 .59416 Metetra
.645 .73 .911 r
.4348 .59416 .43683 .59616 .44033 .59529 .4383 .59327 Metetra
.644 .73 .911 r
.4383 .59327 .44033 .59529 .44383 .59441 .4418 .59239 Metetra
.644 .73 .911 r
.4418 .59239 .44383 .59441 .44733 .59354 .44531 .59152 Metetra
.643 .729 .911 r
.44531 .59152 .44733 .59354 .45084 .59267 .44882 .59065 Metetra
.643 .729 .911 r
.44882 .59065 .45084 .59267 .45436 .59181 .45234 .58978 Metetra
.642 .729 .911 r
.45234 .58978 .45436 .59181 .45788 .59095 .45586 .58892 Metetra
.641 .728 .912 r
.45586 .58892 .45788 .59095 .4614 .5901 .45939 .58806 Metetra
.641 .728 .912 r
.45939 .58806 .4614 .5901 .46493 .58925 .46292 .58721 Metetra
.64 .727 .912 r
.46292 .58721 .46493 .58925 .46847 .58841 .46646 .58636 Metetra
.639 .727 .912 r
.46646 .58636 .46847 .58841 .47201 .58757 .47 .58552 Metetra
.638 .727 .912 r
.47 .58552 .47201 .58757 .47555 .58674 .47355 .58468 Metetra
.637 .726 .912 r
.47355 .58468 .47555 .58674 .4791 .58592 .4771 .58386 Metetra
.637 .726 .912 r
.4771 .58386 .4791 .58592 .48266 .5851 .48066 .58304 Metetra
.636 .725 .913 r
.48066 .58304 .48266 .5851 .48621 .58429 .48422 .58222 Metetra
.635 .725 .913 r
.48422 .58222 .48621 .58429 .48978 .58349 .48779 .58142 Metetra
.633 .724 .913 r
.48779 .58142 .48978 .58349 .49335 .5827 .49136 .58062 Metetra
.632 .723 .913 r
.49136 .58062 .49335 .5827 .49692 .58192 .49494 .57983 Metetra
.631 .723 .913 r
.49494 .57983 .49692 .58192 .5005 .58114 .49852 .57905 Metetra
.63 .722 .914 r
.49852 .57905 .5005 .58114 .50409 .58038 .50211 .57829 Metetra
.628 .721 .914 r
.50211 .57829 .50409 .58038 .50768 .57963 .50571 .57753 Metetra
.627 .72 .914 r
.50571 .57753 .50768 .57963 .51128 .57889 .5093 .57679 Metetra
.625 .72 .914 r
.5093 .57679 .51128 .57889 .51488 .57817 .51291 .57606 Metetra
.624 .719 .915 r
.51291 .57606 .51488 .57817 .51849 .57746 .51652 .57534 Metetra
.622 .718 .915 r
.51652 .57534 .51849 .57746 .5221 .57676 .52013 .57464 Metetra
.62 .717 .915 r
.52013 .57464 .5221 .57676 .52572 .57608 .52375 .57395 Metetra
.618 .715 .916 r
.52375 .57395 .52572 .57608 .52934 .57542 .52738 .57328 Metetra
.615 .714 .916 r
.52738 .57328 .52934 .57542 .53297 .57478 .53101 .57264 Metetra
.613 .713 .916 r
.53101 .57264 .53297 .57478 .5366 .57416 .53465 .57201 Metetra
.61 .711 .917 r
.53465 .57201 .5366 .57416 .54025 .57356 .53829 .5714 Metetra
.607 .71 .917 r
.53829 .5714 .54025 .57356 .54389 .57299 .54194 .57082 Metetra
.604 .708 .918 r
.54194 .57082 .54389 .57299 .54755 .57245 .5456 .57027 Metetra
.6 .706 .918 r
.5456 .57027 .54755 .57245 .55121 .57193 .54926 .56974 Metetra
.596 .704 .919 r
.54926 .56974 .55121 .57193 .55487 .57145 .55293 .56925 Metetra
.592 .702 .92 r
.55293 .56925 .55487 .57145 .55854 .571 .55661 .56879 Metetra
.587 .699 .92 r
.55661 .56879 .55854 .571 .56222 .57059 .56029 .56838 Metetra
.581 .696 .921 r
.56029 .56838 .56222 .57059 .56591 .57022 .56398 .568 Metetra
.575 .693 .922 r
.56398 .568 .56591 .57022 .5696 .56991 .56767 .56767 Metetra
.568 .69 .923 r
.56767 .56767 .5696 .56991 .5733 .56964 .57138 .5674 Metetra
.56 .686 .923 r
.57138 .5674 .5733 .56964 .57701 .56944 .57509 .56718 Metetra
.552 .681 .924 r
.57509 .56718 .57701 .56944 .58073 .5693 .5788 .56703 Metetra
.541 .676 .925 r
.5788 .56703 .58073 .5693 .58445 .56924 .58253 .56696 Metetra
.529 .669 .926 r
.58253 .56696 .58445 .56924 .58819 .56926 .58627 .56697 Metetra
.516 .662 .927 r
.58627 .56697 .58819 .56926 .59193 .56938 .59001 .56707 Metetra
.499 .653 .928 r
.59001 .56707 .59193 .56938 .59568 .56961 .59377 .56729 Metetra
.48 .643 .929 r
.59377 .56729 .59568 .56961 .59945 .56997 .59753 .56763 Metetra
.456 .63 .929 r
.59753 .56763 .59945 .56997 .60322 .57048 .60131 .56812 Metetra
.427 .615 .928 r
.60131 .56812 .60322 .57048 .60701 .57115 .6051 .56877 Metetra
.392 .595 .926 r
.6051 .56877 .60701 .57115 .61081 .57203 .6089 .56963 Metetra
.347 .569 .922 r
.6089 .56963 .61081 .57203 .61463 .57315 .61272 .57073 Metetra
.289 .534 .913 r
.61272 .57073 .61463 .57315 .61847 .57455 .61656 .57212 Metetra
.213 .488 .897 r
.61656 .57212 .61847 .57455 .62232 .5763 .62042 .57385 Metetra
.113 .424 .868 r
.62042 .57385 .62232 .5763 .6262 .57846 .6243 .57601 Metetra
0 .335 .817 r
.6243 .57601 .6262 .57846 .63011 .58115 .62821 .57869 Metetra
0 .212 .729 r
.62821 .57869 .63011 .58115 .63406 .5845 .63216 .58205 Metetra
0 .053 .592 r
.63216 .58205 .63406 .5845 .63804 .58867 .63614 .58626 Metetra
.587 .126 0 r
.63614 .58626 .63804 .58867 .64208 .59392 .64019 .5916 Metetra
.752 .295 0 r
.64019 .5916 .64208 .59392 .64619 .60056 .6443 .59841 Metetra
.859 .426 0 r
.6443 .59841 .64619 .60056 .65039 .60902 .64851 .60722 Metetra
.914 .512 .153 r
.64851 .60722 .65039 .60902 .65471 .61983 .65285 .61869 Metetra
.933 .562 .265 r
.65285 .61869 .65471 .61983 .65917 .63347 .65735 .63358 Metetra
.931 .582 .345 r
.65735 .63358 .65917 .63347 .66377 .64985 .66205 .65223 Metetra
.908 .574 .402 r
.66205 .65223 .66377 .64985 .66845 .66685 .66686 .67271 Metetra
.834 .511 .442 r
.66686 .67271 .66845 .66685 .67295 .67847 .67151 .68764 Metetra
.514 .23 .421 r
.67151 .68764 .67295 .67847 .67693 .67739 .6755 .68656 Metetra
.6755 .68656 .67693 .67739 .68035 .6636 .6788 .66946 Metetra
.959 .806 .368 r
.6788 .66946 .68035 .6636 .68349 .64439 .68181 .64676 Metetra
1 .81 .499 r
.68181 .64676 .68349 .64439 .68663 .62577 .68486 .62587 Metetra
.985 .794 .568 r
.68486 .62587 .68663 .62577 .68987 .60987 .68805 .60871 Metetra
.961 .782 .614 r
.68805 .60871 .68987 .60987 .69321 .59679 .69138 .59496 Metetra
.938 .773 .651 r
.69138 .59496 .69321 .59679 .69665 .58605 .69481 .58387 Metetra
.916 .767 .681 r
.69481 .58387 .69665 .58605 .70017 .57714 .69832 .57477 Metetra
.896 .763 .707 r
.69832 .57477 .70017 .57714 .70375 .56961 .7019 .56715 Metetra
.878 .761 .729 r
.7019 .56715 .70375 .56961 .70738 .56316 .70553 .56065 Metetra
.861 .759 .748 r
.70553 .56065 .70738 .56316 .71104 .55753 .7092 .55501 Metetra
.846 .757 .765 r
.7092 .55501 .71104 .55753 .71474 .55256 .71291 .55004 Metetra
.832 .756 .779 r
.71291 .55004 .71474 .55256 .71846 .54811 .71663 .54559 Metetra
.819 .754 .792 r
.71663 .54559 .71846 .54811 .72221 .54408 .72038 .54157 Metetra
.807 .753 .803 r
.72038 .54157 .72221 .54408 .72597 .54039 .72415 .53789 Metetra
.796 .752 .812 r
.72415 .53789 .72597 .54039 .72975 .53699 .72794 .53451 Metetra
.787 .751 .821 r
.72794 .53451 .72975 .53699 .73355 .53383 .73174 .53136 Metetra
.778 .751 .828 r
.73174 .53136 .73355 .53383 .73736 .53087 .73556 .52841 Metetra
.77 .75 .834 r
.73556 .52841 .73736 .53087 .74118 .52808 .73939 .52563 Metetra
.763 .749 .84 r
.73939 .52563 .74118 .52808 .74501 .52544 .74322 .523 Metetra
.756 .749 .845 r
.74322 .523 .74501 .52544 .74886 .52292 .74707 .52049 Metetra
.751 .748 .85 r
.74707 .52049 .74886 .52292 .75271 .52052 .75093 .51809 Metetra
.745 .747 .854 r
.75093 .51809 .75271 .52052 .75657 .51821 .7548 .51579 Metetra
.74 .747 .857 r
.7548 .51579 .75657 .51821 .76044 .51598 .75867 .51357 Metetra
.736 .746 .861 r
.75867 .51357 .76044 .51598 .76432 .51383 .76256 .51143 Metetra
.731 .746 .864 r
.76256 .51143 .76432 .51383 .76821 .51175 .76645 .50936 Metetra
.728 .746 .866 r
.76645 .50936 .76821 .51175 .77211 .50973 .77035 .50734 Metetra
.724 .745 .869 r
.77035 .50734 .77211 .50973 .77601 .50776 .77426 .50537 Metetra
.721 .745 .871 r
.77426 .50537 .77601 .50776 .77992 .50583 .77818 .50345 Metetra
.718 .745 .873 r
.77818 .50345 .77992 .50583 .78384 .50395 .7821 .50158 Metetra
.715 .744 .875 r
.7821 .50158 .78384 .50395 .78777 .50211 .78603 .49974 Metetra
.712 .744 .877 r
.78603 .49974 .78777 .50211 .7917 .50031 .78996 .49794 Metetra
.71 .744 .878 r
.78996 .49794 .7917 .50031 .79564 .49854 .79391 .49617 Metetra
.708 .744 .88 r
.79391 .49617 .79564 .49854 .79958 .49679 .79786 .49443 Metetra
.706 .744 .881 r
.79786 .49443 .79958 .49679 .80353 .49508 .80181 .49272 Metetra
.704 .743 .882 r
.80181 .49272 .80353 .49508 .80749 .49339 .80577 .49103 Metetra
.702 .743 .883 r
.80577 .49103 .80749 .49339 .81146 .49172 .80974 .48936 Metetra
.7 .743 .885 r
.80974 .48936 .81146 .49172 .81543 .49007 .81372 .48771 Metetra
.699 .743 .886 r
.81372 .48771 .81543 .49007 .8194 .48844 .8177 .48608 Metetra
.697 .743 .886 r
.8177 .48608 .8194 .48844 .82339 .48683 .82169 .48447 Metetra
.696 .743 .887 r
.82169 .48447 .82339 .48683 .82738 .48523 .82568 .48288 Metetra
.695 .743 .888 r
.82568 .48288 .82738 .48523 .83137 .48365 .82968 .4813 Metetra
.693 .743 .889 r
.82968 .4813 .83137 .48365 .83537 .48208 .83369 .47973 Metetra
.692 .742 .89 r
.83369 .47973 .83537 .48208 .83938 .48053 .8377 .47818 Metetra
.691 .742 .89 r
.8377 .47818 .83938 .48053 .8434 .47899 .84172 .47663 Metetra
.69 .742 .891 r
.84172 .47663 .8434 .47899 .84742 .47746 .84574 .4751 Metetra
.689 .742 .892 r
.84574 .4751 .84742 .47746 .85144 .47594 .84977 .47358 Metetra
.688 .742 .892 r
.84977 .47358 .85144 .47594 .85547 .47443 .85381 .47207 Metetra
.687 .742 .893 r
.85381 .47207 .85547 .47443 .85951 .47292 .85785 .47057 Metetra
.687 .742 .893 r
.85785 .47057 .85951 .47292 .86356 .47143 .8619 .46908 Metetra
.686 .742 .894 r
.8619 .46908 .86356 .47143 .86761 .46995 .86596 .46759 Metetra
.685 .742 .894 r
.86596 .46759 .86761 .46995 .87166 .46847 .87002 .46611 Metetra
.684 .742 .895 r
.87002 .46611 .87166 .46847 .87572 .467 .87408 .46464 Metetra
.684 .742 .895 r
.87408 .46464 .87572 .467 .87979 .46553 .87815 .46317 Metetra
.683 .742 .895 r
.87815 .46317 .87979 .46553 .88387 .46407 .88223 .46171 Metetra
.683 .742 .896 r
.88223 .46171 .88387 .46407 .88795 .46262 .88632 .46026 Metetra
.682 .742 .896 r
.88632 .46026 .88795 .46262 .89203 .46117 .89041 .45881 Metetra
.681 .742 .897 r
.89041 .45881 .89203 .46117 .89612 .45973 .8945 .45736 Metetra
.681 .742 .897 r
.8945 .45736 .89612 .45973 .90022 .45829 .89861 .45592 Metetra
.68 .742 .897 r
.89861 .45592 .90022 .45829 .90433 .45685 .90271 .45449 Metetra
.68 .742 .897 r
.90271 .45449 .90433 .45685 .90843 .45542 .90683 .45305 Metetra
.679 .742 .898 r
.90683 .45305 .90843 .45542 .91255 .454 .91095 .45162 Metetra
.679 .741 .898 r
.91095 .45162 .91255 .454 .91667 .45257 .91507 .4502 Metetra
.679 .741 .898 r
.91507 .4502 .91667 .45257 .9208 .45115 .91921 .44878 Metetra
.678 .741 .899 r
.91921 .44878 .9208 .45115 .92493 .44973 .92334 .44736 Metetra
.678 .741 .899 r
.92334 .44736 .92493 .44973 .92907 .44832 .92749 .44594 Metetra
.677 .741 .899 r
.92749 .44594 .92907 .44832 .93322 .44691 .93164 .44453 Metetra
.677 .741 .899 r
.93164 .44453 .93322 .44691 .93737 .4455 .93579 .44312 Metetra
.677 .741 .899 r
.93579 .44312 .93737 .4455 .94153 .44409 .93995 .44171 Metetra
.676 .741 .9 r
.93995 .44171 .94153 .44409 .94569 .44269 .94412 .4403 Metetra
.676 .741 .9 r
.94412 .4403 .94569 .44269 .94986 .44128 .9483 .43889 Metetra
.676 .741 .9 r
.9483 .43889 .94986 .44128 .95403 .43988 .95248 .43749 Metetra
.675 .741 .9 r
.95248 .43749 .95403 .43988 .95822 .43848 .95666 .43609 Metetra
.675 .741 .9 r
.95666 .43609 .95822 .43848 .9624 .43708 .96085 .43469 Metetra
.675 .741 .901 r
.96085 .43469 .9624 .43708 .9666 .43569 .96505 .43329 Metetra
.65 .733 .91 r
.39456 .60207 .39662 .60405 .40007 .60314 .39801 .60116 Metetra
.649 .733 .91 r
.39801 .60116 .40007 .60314 .40352 .60223 .40146 .60025 Metetra
.649 .732 .91 r
.40146 .60025 .40352 .60223 .40698 .60132 .40492 .59934 Metetra
.649 .732 .91 r
.40492 .59934 .40698 .60132 .41044 .60042 .40838 .59843 Metetra
.648 .732 .91 r
.40838 .59843 .41044 .60042 .4139 .59952 .41185 .59752 Metetra
.648 .732 .91 r
.41185 .59752 .4139 .59952 .41738 .59862 .41533 .59662 Metetra
.647 .732 .91 r
.41533 .59662 .41738 .59862 .42085 .59772 .4188 .59572 Metetra
.647 .731 .91 r
.4188 .59572 .42085 .59772 .42433 .59682 .42229 .59482 Metetra
.647 .731 .911 r
.42229 .59482 .42433 .59682 .42782 .59593 .42577 .59392 Metetra
.646 .731 .911 r
.42577 .59392 .42782 .59593 .4313 .59504 .42927 .59303 Metetra
.646 .731 .911 r
.42927 .59303 .4313 .59504 .4348 .59416 .43276 .59214 Metetra
.645 .73 .911 r
.43276 .59214 .4348 .59416 .4383 .59327 .43626 .59126 Metetra
.645 .73 .911 r
.43626 .59126 .4383 .59327 .4418 .59239 .43977 .59037 Metetra
.644 .73 .911 r
.43977 .59037 .4418 .59239 .44531 .59152 .44328 .58949 Metetra
.643 .729 .911 r
.44328 .58949 .44531 .59152 .44882 .59065 .4468 .58862 Metetra
.643 .729 .911 r
.4468 .58862 .44882 .59065 .45234 .58978 .45032 .58775 Metetra
.642 .729 .911 r
.45032 .58775 .45234 .58978 .45586 .58892 .45384 .58688 Metetra
.642 .728 .911 r
.45384 .58688 .45586 .58892 .45939 .58806 .45737 .58602 Metetra
.641 .728 .912 r
.45737 .58602 .45939 .58806 .46292 .58721 .46091 .58516 Metetra
.64 .727 .912 r
.46091 .58516 .46292 .58721 .46646 .58636 .46445 .58431 Metetra
.639 .727 .912 r
.46445 .58431 .46646 .58636 .47 .58552 .46799 .58346 Metetra
.639 .727 .912 r
.46799 .58346 .47 .58552 .47355 .58468 .47154 .58262 Metetra
.638 .726 .912 r
.47154 .58262 .47355 .58468 .4771 .58386 .4751 .58179 Metetra
.637 .726 .912 r
.4751 .58179 .4771 .58386 .48066 .58304 .47866 .58096 Metetra
.636 .725 .912 r
.47866 .58096 .48066 .58304 .48422 .58222 .48222 .58015 Metetra
.635 .725 .913 r
.48222 .58015 .48422 .58222 .48779 .58142 .4858 .57934 Metetra
.634 .724 .913 r
.4858 .57934 .48779 .58142 .49136 .58062 .48937 .57853 Metetra
.633 .723 .913 r
.48937 .57853 .49136 .58062 .49494 .57983 .49295 .57774 Metetra
.631 .723 .913 r
.49295 .57774 .49494 .57983 .49852 .57905 .49654 .57696 Metetra
.63 .722 .913 r
.49654 .57696 .49852 .57905 .50211 .57829 .50013 .57618 Metetra
.629 .721 .914 r
.50013 .57618 .50211 .57829 .50571 .57753 .50372 .57542 Metetra
.627 .72 .914 r
.50372 .57542 .50571 .57753 .5093 .57679 .50733 .57467 Metetra
.626 .72 .914 r
.50733 .57467 .5093 .57679 .51291 .57606 .51093 .57394 Metetra
.624 .719 .914 r
.51093 .57394 .51291 .57606 .51652 .57534 .51455 .57321 Metetra
.622 .718 .915 r
.51455 .57321 .51652 .57534 .52013 .57464 .51816 .5725 Metetra
.62 .717 .915 r
.51816 .5725 .52013 .57464 .52375 .57395 .52179 .57181 Metetra
.618 .715 .915 r
.52179 .57181 .52375 .57395 .52738 .57328 .52542 .57114 Metetra
.616 .714 .916 r
.52542 .57114 .52738 .57328 .53101 .57264 .52905 .57048 Metetra
.613 .713 .916 r
.52905 .57048 .53101 .57264 .53465 .57201 .53269 .56985 Metetra
.611 .711 .916 r
.53269 .56985 .53465 .57201 .53829 .5714 .53634 .56924 Metetra
.608 .71 .917 r
.53634 .56924 .53829 .5714 .54194 .57082 .53999 .56865 Metetra
.604 .708 .917 r
.53999 .56865 .54194 .57082 .5456 .57027 .54365 .56808 Metetra
.601 .706 .918 r
.54365 .56808 .5456 .57027 .54926 .56974 .54731 .56755 Metetra
.597 .704 .919 r
.54731 .56755 .54926 .56974 .55293 .56925 .55099 .56705 Metetra
.593 .702 .919 r
.55099 .56705 .55293 .56925 .55661 .56879 .55466 .56658 Metetra
.588 .699 .92 r
.55466 .56658 .55661 .56879 .56029 .56838 .55835 .56615 Metetra
.582 .697 .92 r
.55835 .56615 .56029 .56838 .56398 .568 .56204 .56577 Metetra
.576 .693 .921 r
.56204 .56577 .56398 .568 .56767 .56767 .56574 .56543 Metetra
.57 .69 .922 r
.56574 .56543 .56767 .56767 .57138 .5674 .56944 .56514 Metetra
.562 .686 .923 r
.56944 .56514 .57138 .5674 .57509 .56718 .57316 .56491 Metetra
.553 .681 .924 r
.57316 .56491 .57509 .56718 .5788 .56703 .57688 .56475 Metetra
.543 .676 .925 r
.57688 .56475 .5788 .56703 .58253 .56696 .58061 .56466 Metetra
.532 .67 .925 r
.58061 .56466 .58253 .56696 .58627 .56697 .58434 .56466 Metetra
.518 .662 .926 r
.58434 .56466 .58627 .56697 .59001 .56707 .58809 .56475 Metetra
.502 .654 .927 r
.58809 .56475 .59001 .56707 .59377 .56729 .59185 .56494 Metetra
.483 .644 .928 r
.59185 .56494 .59377 .56729 .59753 .56763 .59561 .56527 Metetra
.46 .631 .928 r
.59561 .56527 .59753 .56763 .60131 .56812 .59939 .56574 Metetra
.432 .615 .927 r
.59939 .56574 .60131 .56812 .6051 .56877 .60319 .56638 Metetra
.397 .596 .925 r
.60319 .56638 .6051 .56877 .6089 .56963 .60699 .56721 Metetra
.353 .57 .921 r
.60699 .56721 .6089 .56963 .61272 .57073 .61081 .56829 Metetra
.297 .537 .913 r
.61081 .56829 .61272 .57073 .61656 .57212 .61465 .56965 Metetra
.223 .491 .897 r
.61465 .56965 .61656 .57212 .62042 .57385 .61851 .57136 Metetra
.126 .429 .87 r
.61851 .57136 .62042 .57385 .6243 .57601 .62239 .5735 Metetra
0 .341 .821 r
.62239 .5735 .6243 .57601 .62821 .57869 .6263 .57617 Metetra
0 .22 .737 r
.6263 .57617 .62821 .57869 .63216 .58205 .63025 .57953 Metetra
0 .061 .603 r
.63025 .57953 .63216 .58205 .63614 .58626 .63424 .58376 Metetra
.574 .121 0 r
.63424 .58376 .63614 .58626 .64019 .5916 .63828 .58915 Metetra
.746 .295 0 r
.63828 .58915 .64019 .5916 .6443 .59841 .6424 .5961 Metetra
.859 .43 0 r
.6424 .5961 .6443 .59841 .64851 .60722 .64662 .6052 Metetra
.917 .521 .152 r
.64662 .6052 .64851 .60722 .65285 .61869 .65098 .61726 Metetra
.939 .573 .268 r
.65098 .61726 .65285 .61869 .65735 .63358 .65552 .63338 Metetra
.939 .596 .349 r
.65552 .63338 .65735 .63358 .66205 .65223 .6603 .65444 Metetra
.919 .593 .407 r
.6603 .65444 .66205 .65223 .66686 .67271 .66529 .67906 Metetra
.854 .537 .451 r
.66529 .67906 .66686 .67271 .67151 .68764 .67011 .69835 Metetra
.523 .249 .441 r
.67011 .69835 .67151 .68764 .6755 .68656 .67413 .69728 Metetra
.67413 .69728 .6755 .68656 .6788 .66946 .67726 .67581 Metetra
.973 .797 .375 r
.67726 .67581 .6788 .66946 .68181 .64676 .68011 .64897 Metetra
.998 .796 .499 r
.68011 .64897 .68181 .64676 .68486 .62587 .68307 .62565 Metetra
.98 .782 .565 r
.68307 .62565 .68486 .62587 .68805 .60871 .68622 .60726 Metetra
.956 .771 .611 r
.68622 .60726 .68805 .60871 .69138 .59496 .68952 .59291 Metetra
.934 .764 .648 r
.68952 .59291 .69138 .59496 .69481 .58387 .69295 .58152 Metetra
.913 .76 .678 r
.69295 .58152 .69481 .58387 .69832 .57477 .69647 .57228 Metetra
.893 .757 .705 r
.69647 .57228 .69832 .57477 .7019 .56715 .70005 .5646 Metetra
.875 .756 .727 r
.70005 .5646 .7019 .56715 .70553 .56065 .70368 .55807 Metetra
.858 .754 .747 r
.70368 .55807 .70553 .56065 .7092 .55501 .70736 .55243 Metetra
.843 .753 .764 r
.70736 .55243 .7092 .55501 .71291 .55004 .71107 .54746 Metetra
.829 .752 .778 r
.71107 .54746 .71291 .55004 .71663 .54559 .7148 .54303 Metetra
.817 .752 .791 r
.7148 .54303 .71663 .54559 .72038 .54157 .71856 .53902 Metetra
.805 .751 .802 r
.71856 .53902 .72038 .54157 .72415 .53789 .72233 .53537 Metetra
.795 .75 .812 r
.72233 .53537 .72415 .53789 .72794 .53451 .72613 .53199 Metetra
.785 .75 .82 r
.72613 .53199 .72794 .53451 .73174 .53136 .72993 .52886 Metetra
.777 .749 .828 r
.72993 .52886 .73174 .53136 .73556 .52841 .73375 .52592 Metetra
.769 .748 .834 r
.73375 .52592 .73556 .52841 .73939 .52563 .73759 .52316 Metetra
.762 .748 .84 r
.73759 .52316 .73939 .52563 .74322 .523 .74143 .52054 Metetra
.755 .747 .845 r
.74143 .52054 .74322 .523 .74707 .52049 .74528 .51804 Metetra
.749 .747 .85 r
.74528 .51804 .74707 .52049 .75093 .51809 .74915 .51566 Metetra
.744 .746 .854 r
.74915 .51566 .75093 .51809 .7548 .51579 .75302 .51336 Metetra
.739 .746 .857 r
.75302 .51336 .7548 .51579 .75867 .51357 .7569 .51116 Metetra
.735 .746 .861 r
.7569 .51116 .75867 .51357 .76256 .51143 .76079 .50902 Metetra
.731 .745 .864 r
.76079 .50902 .76256 .51143 .76645 .50936 .76469 .50695 Metetra
.727 .745 .866 r
.76469 .50695 .76645 .50936 .77035 .50734 .76859 .50494 Metetra
.723 .745 .869 r
.76859 .50494 .77035 .50734 .77426 .50537 .7725 .50298 Metetra
.72 .744 .871 r
.7725 .50298 .77426 .50537 .77818 .50345 .77642 .50107 Metetra
.717 .744 .873 r
.77642 .50107 .77818 .50345 .7821 .50158 .78035 .4992 Metetra
.714 .744 .875 r
.78035 .4992 .7821 .50158 .78603 .49974 .78428 .49736 Metetra
.712 .744 .877 r
.78428 .49736 .78603 .49974 .78996 .49794 .78823 .49556 Metetra
.71 .744 .878 r
.78823 .49556 .78996 .49794 .79391 .49617 .79217 .4938 Metetra
.707 .743 .88 r
.79217 .4938 .79391 .49617 .79786 .49443 .79613 .49206 Metetra
.705 .743 .881 r
.79613 .49206 .79786 .49443 .80181 .49272 .80009 .49035 Metetra
.703 .743 .882 r
.80009 .49035 .80181 .49272 .80577 .49103 .80405 .48866 Metetra
.702 .743 .883 r
.80405 .48866 .80577 .49103 .80974 .48936 .80803 .48699 Metetra
.7 .743 .885 r
.80803 .48699 .80974 .48936 .81372 .48771 .81201 .48535 Metetra
.698 .743 .886 r
.81201 .48535 .81372 .48771 .8177 .48608 .81599 .48372 Metetra
.697 .743 .887 r
.81599 .48372 .8177 .48608 .82169 .48447 .81999 .48211 Metetra
.696 .742 .887 r
.81999 .48211 .82169 .48447 .82568 .48288 .82398 .48052 Metetra
.694 .742 .888 r
.82398 .48052 .82568 .48288 .82968 .4813 .82799 .47894 Metetra
.693 .742 .889 r
.82799 .47894 .82968 .4813 .83369 .47973 .832 .47737 Metetra
.692 .742 .89 r
.832 .47737 .83369 .47973 .8377 .47818 .83601 .47582 Metetra
.691 .742 .89 r
.83601 .47582 .8377 .47818 .84172 .47663 .84004 .47427 Metetra
.69 .742 .891 r
.84004 .47427 .84172 .47663 .84574 .4751 .84407 .47274 Metetra
.689 .742 .892 r
.84407 .47274 .84574 .4751 .84977 .47358 .8481 .47122 Metetra
.688 .742 .892 r
.8481 .47122 .84977 .47358 .85381 .47207 .85214 .46971 Metetra
.687 .742 .893 r
.85214 .46971 .85381 .47207 .85785 .47057 .85619 .46821 Metetra
.686 .742 .893 r
.85619 .46821 .85785 .47057 .8619 .46908 .86024 .46671 Metetra
.686 .742 .894 r
.86024 .46671 .8619 .46908 .86596 .46759 .8643 .46523 Metetra
.685 .742 .894 r
.8643 .46523 .86596 .46759 .87002 .46611 .86836 .46375 Metetra
.684 .742 .895 r
.86836 .46375 .87002 .46611 .87408 .46464 .87244 .46227 Metetra
.684 .742 .895 r
.87244 .46227 .87408 .46464 .87815 .46317 .87651 .46081 Metetra
.683 .742 .895 r
.87651 .46081 .87815 .46317 .88223 .46171 .88059 .45935 Metetra
.682 .742 .896 r
.88059 .45935 .88223 .46171 .88632 .46026 .88468 .45789 Metetra
.682 .742 .896 r
.88468 .45789 .88632 .46026 .89041 .45881 .88878 .45644 Metetra
.681 .742 .897 r
.88878 .45644 .89041 .45881 .8945 .45736 .89288 .45499 Metetra
.681 .741 .897 r
.89288 .45499 .8945 .45736 .89861 .45592 .89699 .45355 Metetra
.68 .741 .897 r
.89699 .45355 .89861 .45592 .90271 .45449 .9011 .45211 Metetra
.68 .741 .897 r
.9011 .45211 .90271 .45449 .90683 .45305 .90522 .45068 Metetra
.679 .741 .898 r
.90522 .45068 .90683 .45305 .91095 .45162 .90934 .44925 Metetra
.679 .741 .898 r
.90934 .44925 .91095 .45162 .91507 .4502 .91347 .44782 Metetra
.678 .741 .898 r
.91347 .44782 .91507 .4502 .91921 .44878 .91761 .4464 Metetra
.678 .741 .899 r
.91761 .4464 .91921 .44878 .92334 .44736 .92175 .44498 Metetra
.678 .741 .899 r
.92175 .44498 .92334 .44736 .92749 .44594 .9259 .44356 Metetra
.677 .741 .899 r
.9259 .44356 .92749 .44594 .93164 .44453 .93005 .44214 Metetra
.677 .741 .899 r
.93005 .44214 .93164 .44453 .93579 .44312 .93421 .44073 Metetra
.677 .741 .899 r
.93421 .44073 .93579 .44312 .93995 .44171 .93838 .43932 Metetra
.676 .741 .9 r
.93838 .43932 .93995 .44171 .94412 .4403 .94255 .43791 Metetra
.676 .741 .9 r
.94255 .43791 .94412 .4403 .9483 .43889 .94673 .4365 Metetra
.676 .741 .9 r
.94673 .4365 .9483 .43889 .95248 .43749 .95091 .43509 Metetra
.675 .741 .9 r
.95091 .43509 .95248 .43749 .95666 .43609 .9551 .43369 Metetra
.675 .741 .9 r
.9551 .43369 .95666 .43609 .96085 .43469 .9593 .43229 Metetra
.675 .741 .901 r
.9593 .43229 .96085 .43469 .96505 .43329 .9635 .43088 Metetra
.65 .733 .91 r
.39249 .6001 .39456 .60207 .39801 .60116 .39594 .59918 Metetra
.649 .733 .91 r
.39594 .59918 .39801 .60116 .40146 .60025 .3994 .59826 Metetra
.649 .732 .91 r
.3994 .59826 .40146 .60025 .40492 .59934 .40286 .59735 Metetra
.649 .732 .91 r
.40286 .59735 .40492 .59934 .40838 .59843 .40632 .59644 Metetra
.648 .732 .91 r
.40632 .59644 .40838 .59843 .41185 .59752 .4098 .59553 Metetra
.648 .732 .91 r
.4098 .59553 .41185 .59752 .41533 .59662 .41327 .59462 Metetra
.648 .732 .91 r
.41327 .59462 .41533 .59662 .4188 .59572 .41675 .59372 Metetra
.647 .731 .91 r
.41675 .59372 .4188 .59572 .42229 .59482 .42024 .59281 Metetra
.647 .731 .91 r
.42024 .59281 .42229 .59482 .42577 .59392 .42373 .59191 Metetra
.646 .731 .911 r
.42373 .59191 .42577 .59392 .42927 .59303 .42722 .59102 Metetra
.646 .731 .911 r
.42722 .59102 .42927 .59303 .43276 .59214 .43072 .59012 Metetra
.645 .73 .911 r
.43072 .59012 .43276 .59214 .43626 .59126 .43423 .58923 Metetra
.645 .73 .911 r
.43423 .58923 .43626 .59126 .43977 .59037 .43773 .58834 Metetra
.644 .73 .911 r
.43773 .58834 .43977 .59037 .44328 .58949 .44125 .58746 Metetra
.644 .729 .911 r
.44125 .58746 .44328 .58949 .4468 .58862 .44477 .58658 Metetra
.643 .729 .911 r
.44477 .58658 .4468 .58862 .45032 .58775 .44829 .58571 Metetra
.642 .729 .911 r
.44829 .58571 .45032 .58775 .45384 .58688 .45182 .58484 Metetra
.642 .728 .911 r
.45182 .58484 .45384 .58688 .45737 .58602 .45535 .58397 Metetra
.641 .728 .911 r
.45535 .58397 .45737 .58602 .46091 .58516 .45889 .58311 Metetra
.64 .728 .912 r
.45889 .58311 .46091 .58516 .46445 .58431 .46243 .58225 Metetra
.64 .727 .912 r
.46243 .58225 .46445 .58431 .46799 .58346 .46598 .5814 Metetra
.639 .727 .912 r
.46598 .5814 .46799 .58346 .47154 .58262 .46953 .58056 Metetra
.638 .726 .912 r
.46953 .58056 .47154 .58262 .4751 .58179 .47309 .57972 Metetra
.637 .726 .912 r
.47309 .57972 .4751 .58179 .47866 .58096 .47665 .57889 Metetra
.636 .725 .912 r
.47665 .57889 .47866 .58096 .48222 .58015 .48022 .57807 Metetra
.635 .725 .912 r
.48022 .57807 .48222 .58015 .4858 .57934 .4838 .57725 Metetra
.634 .724 .913 r
.4838 .57725 .4858 .57934 .48937 .57853 .48737 .57644 Metetra
.633 .723 .913 r
.48737 .57644 .48937 .57853 .49295 .57774 .49096 .57564 Metetra
.632 .723 .913 r
.49096 .57564 .49295 .57774 .49654 .57696 .49455 .57486 Metetra
.63 .722 .913 r
.49455 .57486 .49654 .57696 .50013 .57618 .49814 .57408 Metetra
.629 .721 .913 r
.49814 .57408 .50013 .57618 .50372 .57542 .50174 .57331 Metetra
.628 .72 .914 r
.50174 .57331 .50372 .57542 .50733 .57467 .50534 .57255 Metetra
.626 .72 .914 r
.50534 .57255 .50733 .57467 .51093 .57394 .50895 .57181 Metetra
.624 .719 .914 r
.50895 .57181 .51093 .57394 .51455 .57321 .51257 .57108 Metetra
.623 .718 .914 r
.51257 .57108 .51455 .57321 .51816 .5725 .51619 .57037 Metetra
.621 .717 .915 r
.51619 .57037 .51816 .5725 .52179 .57181 .51982 .56967 Metetra
.619 .716 .915 r
.51982 .56967 .52179 .57181 .52542 .57114 .52345 .56899 Metetra
.616 .714 .915 r
.52345 .56899 .52542 .57114 .52905 .57048 .52709 .56832 Metetra
.614 .713 .916 r
.52709 .56832 .52905 .57048 .53269 .56985 .53073 .56768 Metetra
.611 .712 .916 r
.53073 .56768 .53269 .56985 .53634 .56924 .53438 .56706 Metetra
.608 .71 .917 r
.53438 .56706 .53634 .56924 .53999 .56865 .53803 .56646 Metetra
.605 .708 .917 r
.53803 .56646 .53999 .56865 .54365 .56808 .54169 .56589 Metetra
.602 .706 .918 r
.54169 .56589 .54365 .56808 .54731 .56755 .54536 .56535 Metetra
.598 .704 .918 r
.54536 .56535 .54731 .56755 .55099 .56705 .54904 .56484 Metetra
.594 .702 .919 r
.54904 .56484 .55099 .56705 .55466 .56658 .55272 .56436 Metetra
.589 .7 .919 r
.55272 .56436 .55466 .56658 .55835 .56615 .5564 .56392 Metetra
.584 .697 .92 r
.5564 .56392 .55835 .56615 .56204 .56577 .5601 .56353 Metetra
.578 .694 .921 r
.5601 .56353 .56204 .56577 .56574 .56543 .5638 .56318 Metetra
.571 .69 .921 r
.5638 .56318 .56574 .56543 .56944 .56514 .5675 .56288 Metetra
.564 .686 .922 r
.5675 .56288 .56944 .56514 .57316 .56491 .57122 .56263 Metetra
.555 .681 .923 r
.57122 .56263 .57316 .56491 .57688 .56475 .57494 .56246 Metetra
.545 .676 .924 r
.57494 .56246 .57688 .56475 .58061 .56466 .57867 .56235 Metetra
.534 .67 .925 r
.57867 .56235 .58061 .56466 .58434 .56466 .58242 .56233 Metetra
.521 .663 .925 r
.58242 .56233 .58434 .56466 .58809 .56475 .58616 .56241 Metetra
.505 .654 .926 r
.58616 .56241 .58809 .56475 .59185 .56494 .58992 .56259 Metetra
.487 .644 .927 r
.58992 .56259 .59185 .56494 .59561 .56527 .59369 .56289 Metetra
.464 .632 .927 r
.59369 .56289 .59561 .56527 .59939 .56574 .59747 .56334 Metetra
.437 .617 .926 r
.59747 .56334 .59939 .56574 .60319 .56638 .60127 .56395 Metetra
.403 .597 .924 r
.60127 .56395 .60319 .56638 .60699 .56721 .60507 .56477 Metetra
.361 .572 .92 r
.60507 .56477 .60699 .56721 .61081 .56829 .60889 .56582 Metetra
.306 .54 .912 r
.60889 .56582 .61081 .56829 .61465 .56965 .61273 .56716 Metetra
.235 .495 .898 r
.61273 .56716 .61465 .56965 .61851 .57136 .61659 .56884 Metetra
.14 .434 .872 r
.61659 .56884 .61851 .57136 .62239 .5735 .62048 .57095 Metetra
.014 .348 .826 r
.62048 .57095 .62239 .5735 .6263 .57617 .62439 .5736 Metetra
0 .229 .745 r
.62439 .5736 .6263 .57617 .63025 .57953 .62833 .57693 Metetra
0 .072 .615 r
.62833 .57693 .63025 .57953 .63424 .58376 .63232 .58116 Metetra
0 0 .432 r
.63232 .58116 .63424 .58376 .63828 .58915 .63637 .58658 Metetra
.737 .29 0 r
.63637 .58658 .63828 .58915 .6424 .5961 .64049 .59362 Metetra
.856 .432 0 r
.64049 .59362 .6424 .5961 .64662 .6052 .64471 .60294 Metetra
.919 .527 .149 r
.64471 .60294 .64662 .6052 .65098 .61726 .64909 .61552 Metetra
.944 .582 .268 r
.64909 .61552 .65098 .61726 .65552 .63338 .65367 .63279 Metetra
.946 .608 .352 r
.65367 .63279 .65552 .63338 .6603 .65444 .65854 .65636 Metetra
.93 .609 .411 r
.65854 .65636 .6603 .65444 .66529 .67906 .66371 .68583 Metetra
.873 .562 .458 r
.66371 .68583 .66529 .67906 .67011 .69835 .66878 .71094 Metetra
.531 .266 .459 r
.66878 .71094 .67011 .69835 .67413 .69728 .67281 .70987 Metetra
.67281 .70987 .67413 .69728 .67726 .67581 .67573 .68259 Metetra
.984 .788 .384 r
.67573 .68259 .67726 .67581 .68011 .64897 .67839 .65088 Metetra
.995 .783 .5 r
.67839 .65088 .68011 .64897 .68307 .62565 .68126 .62504 Metetra
.975 .769 .564 r
.68126 .62504 .68307 .62565 .68622 .60726 .68436 .60549 Metetra
.951 .76 .609 r
.68436 .60549 .68622 .60726 .68952 .59291 .68766 .59062 Metetra
.929 .755 .646 r
.68766 .59062 .68952 .59291 .69295 .58152 .69108 .579 Metetra
.908 .753 .677 r
.69108 .579 .69295 .58152 .69647 .57228 .6946 .56966 Metetra
.889 .752 .703 r
.6946 .56966 .69647 .57228 .70005 .5646 .69819 .56195 Metetra
.872 .751 .726 r
.69819 .56195 .70005 .5646 .70368 .55807 .70183 .55542 Metetra
.856 .75 .746 r
.70183 .55542 .70368 .55807 .70736 .55243 .70551 .54979 Metetra
.841 .75 .763 r
.70551 .54979 .70736 .55243 .71107 .54746 .70922 .54484 Metetra
.827 .75 .778 r
.70922 .54484 .71107 .54746 .7148 .54303 .71296 .54043 Metetra
.815 .749 .791 r
.71296 .54043 .7148 .54303 .71856 .53902 .71673 .53644 Metetra
.803 .749 .802 r
.71673 .53644 .71856 .53902 .72233 .53537 .72051 .53281 Metetra
.793 .748 .812 r
.72051 .53281 .72233 .53537 .72613 .53199 .7243 .52946 Metetra
.784 .748 .82 r
.7243 .52946 .72613 .53199 .72993 .52886 .72812 .52634 Metetra
.775 .747 .828 r
.72812 .52634 .72993 .52886 .73375 .52592 .73194 .52342 Metetra
.768 .747 .834 r
.73194 .52342 .73375 .52592 .73759 .52316 .73578 .52067 Metetra
.761 .747 .84 r
.73578 .52067 .73759 .52316 .74143 .52054 .73963 .51806 Metetra
.754 .746 .845 r
.73963 .51806 .74143 .52054 .74528 .51804 .74349 .51558 Metetra
.748 .746 .85 r
.74349 .51558 .74528 .51804 .74915 .51566 .74736 .51321 Metetra
.743 .746 .854 r
.74736 .51321 .74915 .51566 .75302 .51336 .75123 .51092 Metetra
.738 .745 .857 r
.75123 .51092 .75302 .51336 .7569 .51116 .75512 .50872 Metetra
.734 .745 .861 r
.75512 .50872 .7569 .51116 .76079 .50902 .75901 .5066 Metetra
.73 .745 .864 r
.75901 .5066 .76079 .50902 .76469 .50695 .76292 .50453 Metetra
.726 .744 .866 r
.76292 .50453 .76469 .50695 .76859 .50494 .76683 .50253 Metetra
.723 .744 .869 r
.76683 .50253 .76859 .50494 .7725 .50298 .77074 .50058 Metetra
.719 .744 .871 r
.77074 .50058 .7725 .50298 .77642 .50107 .77467 .49867 Metetra
.717 .744 .873 r
.77467 .49867 .77642 .50107 .78035 .4992 .7786 .4968 Metetra
.714 .744 .875 r
.7786 .4968 .78035 .4992 .78428 .49736 .78254 .49497 Metetra
.711 .743 .877 r
.78254 .49497 .78428 .49736 .78823 .49556 .78648 .49318 Metetra
.709 .743 .878 r
.78648 .49318 .78823 .49556 .79217 .4938 .79043 .49142 Metetra
.707 .743 .88 r
.79043 .49142 .79217 .4938 .79613 .49206 .79439 .48968 Metetra
.705 .743 .881 r
.79439 .48968 .79613 .49206 .80009 .49035 .79836 .48797 Metetra
.703 .743 .882 r
.79836 .48797 .80009 .49035 .80405 .48866 .80233 .48629 Metetra
.701 .743 .884 r
.80233 .48629 .80405 .48866 .80803 .48699 .80631 .48462 Metetra
.7 .743 .885 r
.80631 .48462 .80803 .48699 .81201 .48535 .81029 .48298 Metetra
.698 .742 .886 r
.81029 .48298 .81201 .48535 .81599 .48372 .81428 .48135 Metetra
.697 .742 .887 r
.81428 .48135 .81599 .48372 .81999 .48211 .81828 .47974 Metetra
.695 .742 .887 r
.81828 .47974 .81999 .48211 .82398 .48052 .82228 .47815 Metetra
.694 .742 .888 r
.82228 .47815 .82398 .48052 .82799 .47894 .82629 .47657 Metetra
.693 .742 .889 r
.82629 .47657 .82799 .47894 .832 .47737 .8303 .475 Metetra
.692 .742 .89 r
.8303 .475 .832 .47737 .83601 .47582 .83432 .47345 Metetra
.691 .742 .89 r
.83432 .47345 .83601 .47582 .84004 .47427 .83835 .47191 Metetra
.69 .742 .891 r
.83835 .47191 .84004 .47427 .84407 .47274 .84238 .47038 Metetra
.689 .742 .892 r
.84238 .47038 .84407 .47274 .8481 .47122 .84642 .46886 Metetra
.688 .742 .892 r
.84642 .46886 .8481 .47122 .85214 .46971 .85047 .46734 Metetra
.687 .742 .893 r
.85047 .46734 .85214 .46971 .85619 .46821 .85452 .46584 Metetra
.686 .742 .893 r
.85452 .46584 .85619 .46821 .86024 .46671 .85858 .46435 Metetra
.685 .742 .894 r
.85858 .46435 .86024 .46671 .8643 .46523 .86264 .46286 Metetra
.685 .742 .894 r
.86264 .46286 .8643 .46523 .86836 .46375 .86671 .46138 Metetra
.684 .742 .895 r
.86671 .46138 .86836 .46375 .87244 .46227 .87078 .4599 Metetra
.683 .742 .895 r
.87078 .4599 .87244 .46227 .87651 .46081 .87487 .45843 Metetra
.683 .741 .895 r
.87487 .45843 .87651 .46081 .88059 .45935 .87895 .45697 Metetra
.682 .741 .896 r
.87895 .45697 .88059 .45935 .88468 .45789 .88305 .45551 Metetra
.682 .741 .896 r
.88305 .45551 .88468 .45789 .88878 .45644 .88714 .45406 Metetra
.681 .741 .897 r
.88714 .45406 .88878 .45644 .89288 .45499 .89125 .45261 Metetra
.681 .741 .897 r
.89125 .45261 .89288 .45499 .89699 .45355 .89536 .45117 Metetra
.68 .741 .897 r
.89536 .45117 .89699 .45355 .9011 .45211 .89948 .44973 Metetra
.68 .741 .898 r
.89948 .44973 .9011 .45211 .90522 .45068 .9036 .4483 Metetra
.679 .741 .898 r
.9036 .4483 .90522 .45068 .90934 .44925 .90773 .44686 Metetra
.679 .741 .898 r
.90773 .44686 .90934 .44925 .91347 .44782 .91186 .44544 Metetra
.678 .741 .898 r
.91186 .44544 .91347 .44782 .91761 .4464 .916 .44401 Metetra
.678 .741 .899 r
.916 .44401 .91761 .4464 .92175 .44498 .92015 .44259 Metetra
.677 .741 .899 r
.92015 .44259 .92175 .44498 .9259 .44356 .9243 .44117 Metetra
.677 .741 .899 r
.9243 .44117 .9259 .44356 .93005 .44214 .92846 .43975 Metetra
.677 .741 .899 r
.92846 .43975 .93005 .44214 .93421 .44073 .93263 .43833 Metetra
.676 .741 .899 r
.93263 .43833 .93421 .44073 .93838 .43932 .9368 .43692 Metetra
.676 .741 .9 r
.9368 .43692 .93838 .43932 .94255 .43791 .94097 .43551 Metetra
.676 .741 .9 r
.94097 .43551 .94255 .43791 .94673 .4365 .94516 .4341 Metetra
.675 .741 .9 r
.94516 .4341 .94673 .4365 .95091 .43509 .94935 .43269 Metetra
.675 .741 .9 r
.94935 .43269 .95091 .43509 .9551 .43369 .95354 .43128 Metetra
.675 .741 .9 r
.95354 .43128 .9551 .43369 .9593 .43229 .95774 .42988 Metetra
.675 .741 .901 r
.95774 .42988 .9593 .43229 .9635 .43088 .96195 .42847 Metetra
.65 .733 .91 r
.39041 .59811 .39249 .6001 .39594 .59918 .39387 .59719 Metetra
.649 .733 .91 r
.39387 .59719 .39594 .59918 .3994 .59826 .39733 .59627 Metetra
.649 .732 .91 r
.39733 .59627 .3994 .59826 .40286 .59735 .40079 .59536 Metetra
.649 .732 .91 r
.40079 .59536 .40286 .59735 .40632 .59644 .40426 .59444 Metetra
.648 .732 .91 r
.40426 .59444 .40632 .59644 .4098 .59553 .40773 .59353 Metetra
.648 .732 .91 r
.40773 .59353 .4098 .59553 .41327 .59462 .41121 .59262 Metetra
.648 .732 .91 r
.41121 .59262 .41327 .59462 .41675 .59372 .4147 .59171 Metetra
.647 .731 .91 r
.4147 .59171 .41675 .59372 .42024 .59281 .41818 .5908 Metetra
.647 .731 .91 r
.41818 .5908 .42024 .59281 .42373 .59191 .42168 .5899 Metetra
.646 .731 .91 r
.42168 .5899 .42373 .59191 .42722 .59102 .42517 .589 Metetra
.646 .731 .911 r
.42517 .589 .42722 .59102 .43072 .59012 .42868 .5881 Metetra
.645 .73 .911 r
.42868 .5881 .43072 .59012 .43423 .58923 .43218 .5872 Metetra
.645 .73 .911 r
.43218 .5872 .43423 .58923 .43773 .58834 .43569 .58631 Metetra
.644 .73 .911 r
.43569 .58631 .43773 .58834 .44125 .58746 .43921 .58543 Metetra
.644 .729 .911 r
.43921 .58543 .44125 .58746 .44477 .58658 .44273 .58454 Metetra
.643 .729 .911 r
.44273 .58454 .44477 .58658 .44829 .58571 .44626 .58366 Metetra
.643 .729 .911 r
.44626 .58366 .44829 .58571 .45182 .58484 .44979 .58279 Metetra
.642 .728 .911 r
.44979 .58279 .45182 .58484 .45535 .58397 .45333 .58192 Metetra
.641 .728 .911 r
.45333 .58192 .45535 .58397 .45889 .58311 .45687 .58105 Metetra
.641 .728 .911 r
.45687 .58105 .45889 .58311 .46243 .58225 .46041 .58019 Metetra
.64 .727 .912 r
.46041 .58019 .46243 .58225 .46598 .5814 .46396 .57933 Metetra
.639 .727 .912 r
.46396 .57933 .46598 .5814 .46953 .58056 .46752 .57849 Metetra
.638 .726 .912 r
.46752 .57849 .46953 .58056 .47309 .57972 .47108 .57764 Metetra
.637 .726 .912 r
.47108 .57764 .47309 .57972 .47665 .57889 .47465 .57681 Metetra
.636 .725 .912 r
.47465 .57681 .47665 .57889 .48022 .57807 .47822 .57598 Metetra
.635 .725 .912 r
.47822 .57598 .48022 .57807 .4838 .57725 .48179 .57516 Metetra
.634 .724 .912 r
.48179 .57516 .4838 .57725 .48737 .57644 .48537 .57435 Metetra
.633 .723 .913 r
.48537 .57435 .48737 .57644 .49096 .57564 .48896 .57354 Metetra
.632 .723 .913 r
.48896 .57354 .49096 .57564 .49455 .57486 .49255 .57275 Metetra
.631 .722 .913 r
.49255 .57275 .49455 .57486 .49814 .57408 .49615 .57196 Metetra
.63 .721 .913 r
.49615 .57196 .49814 .57408 .50174 .57331 .49975 .57119 Metetra
.628 .72 .913 r
.49975 .57119 .50174 .57331 .50534 .57255 .50336 .57043 Metetra
.627 .72 .914 r
.50336 .57043 .50534 .57255 .50895 .57181 .50697 .56968 Metetra
.625 .719 .914 r
.50697 .56968 .50895 .57181 .51257 .57108 .51059 .56894 Metetra
.623 .718 .914 r
.51059 .56894 .51257 .57108 .51619 .57037 .51421 .56822 Metetra
.621 .717 .914 r
.51421 .56822 .51619 .57037 .51982 .56967 .51784 .56752 Metetra
.619 .716 .915 r
.51784 .56752 .51982 .56967 .52345 .56899 .52147 .56683 Metetra
.617 .714 .915 r
.52147 .56683 .52345 .56899 .52709 .56832 .52511 .56616 Metetra
.615 .713 .915 r
.52511 .56616 .52709 .56832 .53073 .56768 .52876 .56551 Metetra
.612 .712 .916 r
.52876 .56551 .53073 .56768 .53438 .56706 .53241 .56488 Metetra
.609 .71 .916 r
.53241 .56488 .53438 .56706 .53803 .56646 .53607 .56427 Metetra
.606 .708 .917 r
.53607 .56427 .53803 .56646 .54169 .56589 .53973 .56369 Metetra
.603 .706 .917 r
.53973 .56369 .54169 .56589 .54536 .56535 .5434 .56314 Metetra
.599 .704 .918 r
.5434 .56314 .54536 .56535 .54904 .56484 .54708 .56262 Metetra
.595 .702 .918 r
.54708 .56262 .54904 .56484 .55272 .56436 .55076 .56213 Metetra
.59 .7 .919 r
.55076 .56213 .55272 .56436 .5564 .56392 .55445 .56168 Metetra
.585 .697 .919 r
.55445 .56168 .5564 .56392 .5601 .56353 .55815 .56128 Metetra
.579 .694 .92 r
.55815 .56128 .5601 .56353 .5638 .56318 .56185 .56091 Metetra
.573 .69 .921 r
.56185 .56091 .5638 .56318 .5675 .56288 .56556 .5606 Metetra
.565 .686 .921 r
.56556 .5606 .5675 .56288 .57122 .56263 .56928 .56035 Metetra
.557 .682 .922 r
.56928 .56035 .57122 .56263 .57494 .56246 .57301 .56016 Metetra
.547 .677 .923 r
.57301 .56016 .57494 .56246 .57867 .56235 .57674 .56004 Metetra
.536 .671 .924 r
.57674 .56004 .57867 .56235 .58242 .56233 .58048 .56 Metetra
.524 .663 .925 r
.58048 .56 .58242 .56233 .58616 .56241 .58423 .56005 Metetra
.508 .655 .925 r
.58423 .56005 .58616 .56241 .58992 .56259 .58799 .56021 Metetra
.49 .645 .926 r
.58799 .56021 .58992 .56259 .59369 .56289 .59177 .5605 Metetra
.469 .633 .926 r
.59177 .5605 .59369 .56289 .59747 .56334 .59555 .56092 Metetra
.442 .618 .925 r
.59555 .56092 .59747 .56334 .60127 .56395 .59934 .56151 Metetra
.409 .599 .923 r
.59934 .56151 .60127 .56395 .60507 .56477 .60315 .5623 Metetra
.368 .575 .919 r
.60315 .5623 .60507 .56477 .60889 .56582 .60697 .56332 Metetra
.315 .543 .912 r
.60697 .56332 .60889 .56582 .61273 .56716 .61081 .56463 Metetra
.246 .5 .899 r
.61081 .56463 .61273 .56716 .61659 .56884 .61467 .56628 Metetra
.155 .44 .874 r
.61467 .56628 .61659 .56884 .62048 .57095 .61856 .56835 Metetra
.033 .357 .831 r
.61856 .56835 .62048 .57095 .62439 .5736 .62247 .57096 Metetra
0 .241 .755 r
.62247 .57096 .62439 .5736 .62833 .57693 .62641 .57426 Metetra
0 .086 .63 r
.62641 .57426 .62833 .57693 .63232 .58116 .6304 .57847 Metetra
0 0 .45 r
.6304 .57847 .63232 .58116 .63637 .58658 .63445 .58388 Metetra
.724 .283 0 r
.63445 .58388 .63637 .58658 .64049 .59362 .63857 .59097 Metetra
.851 .431 0 r
.63857 .59097 .64049 .59362 .64471 .60294 .6428 .60045 Metetra
.919 .531 .142 r
.6428 .60045 .64471 .60294 .64909 .61552 .64718 .61344 Metetra
.947 .59 .266 r
.64718 .61344 .64909 .61552 .65367 .63279 .65179 .63174 Metetra
.951 .619 .352 r
.65179 .63174 .65367 .63279 .65854 .65636 .65675 .65783 Metetra
.939 .623 .412 r
.65675 .65783 .65854 .65636 .66371 .68583 .66213 .69289 Metetra
.885 .578 .461 r
.66213 .69289 .66371 .68583 .66878 .71094 .66741 .72328 Metetra
.529 .263 .455 r
.66741 .72328 .66878 .71094 .67281 .70987 .67147 .7222 Metetra
.835 .709 .177 r
.67147 .7222 .67281 .70987 .67573 .68259 .67419 .68965 Metetra
.991 .778 .396 r
.67419 .68965 .67573 .68259 .67839 .65088 .67664 .65235 Metetra
.991 .77 .503 r
.67664 .65235 .67839 .65088 .68126 .62504 .67942 .62398 Metetra
.969 .757 .564 r
.67942 .62398 .68126 .62504 .68436 .60549 .68249 .60339 Metetra
.945 .751 .608 r
.68249 .60339 .68436 .60549 .68766 .59062 .68577 .58809 Metetra
.924 .748 .645 r
.68577 .58809 .68766 .59062 .69108 .579 .6892 .57631 Metetra
.904 .746 .676 r
.6892 .57631 .69108 .579 .6946 .56966 .69272 .56692 Metetra
.886 .746 .702 r
.69272 .56692 .6946 .56966 .69819 .56195 .69632 .5592 Metetra
.869 .746 .725 r
.69632 .5592 .69819 .56195 .70183 .55542 .69996 .55269 Metetra
.853 .747 .745 r
.69996 .55269 .70183 .55542 .70551 .54979 .70365 .54709 Metetra
.838 .747 .763 r
.70365 .54709 .70551 .54979 .70922 .54484 .70737 .54217 Metetra
.825 .747 .778 r
.70737 .54217 .70922 .54484 .71296 .54043 .71112 .53779 Metetra
.812 .747 .791 r
.71112 .53779 .71296 .54043 .71673 .53644 .71489 .53383 Metetra
.801 .747 .802 r
.71489 .53383 .71673 .53644 .72051 .53281 .71867 .53022 Metetra
.791 .747 .812 r
.71867 .53022 .72051 .53281 .7243 .52946 .72248 .52689 Metetra
.782 .746 .82 r
.72248 .52689 .7243 .52946 .72812 .52634 .7263 .5238 Metetra
.774 .746 .828 r
.7263 .5238 .72812 .52634 .73194 .52342 .73013 .5209 Metetra
.766 .746 .834 r
.73013 .5209 .73194 .52342 .73578 .52067 .73397 .51817 Metetra
.759 .746 .84 r
.73397 .51817 .73578 .52067 .73963 .51806 .73783 .51558 Metetra
.753 .745 .845 r
.73783 .51558 .73963 .51806 .74349 .51558 .74169 .51311 Metetra
.747 .745 .85 r
.74169 .51311 .74349 .51558 .74736 .51321 .74556 .51074 Metetra
.742 .745 .854 r
.74556 .51074 .74736 .51321 .75123 .51092 .74944 .50847 Metetra
.737 .744 .858 r
.74944 .50847 .75123 .51092 .75512 .50872 .75334 .50628 Metetra
.733 .744 .861 r
.75334 .50628 .75512 .50872 .75901 .5066 .75723 .50416 Metetra
.729 .744 .864 r
.75723 .50416 .75901 .5066 .76292 .50453 .76114 .50211 Metetra
.725 .744 .867 r
.76114 .50211 .76292 .50453 .76683 .50253 .76506 .50011 Metetra
.722 .744 .869 r
.76506 .50011 .76683 .50253 .77074 .50058 .76898 .49816 Metetra
.719 .743 .871 r
.76898 .49816 .77074 .50058 .77467 .49867 .77291 .49626 Metetra
.716 .743 .873 r
.77291 .49626 .77467 .49867 .7786 .4968 .77684 .4944 Metetra
.713 .743 .875 r
.77684 .4944 .7786 .4968 .78254 .49497 .78079 .49258 Metetra
.711 .743 .877 r
.78079 .49258 .78254 .49497 .78648 .49318 .78474 .49079 Metetra
.708 .743 .878 r
.78474 .49079 .78648 .49318 .79043 .49142 .78869 .48903 Metetra
.706 .743 .88 r
.78869 .48903 .79043 .49142 .79439 .48968 .79265 .48729 Metetra
.704 .743 .881 r
.79265 .48729 .79439 .48968 .79836 .48797 .79662 .48559 Metetra
.703 .742 .882 r
.79662 .48559 .79836 .48797 .80233 .48629 .8006 .4839 Metetra
.701 .742 .884 r
.8006 .4839 .80233 .48629 .80631 .48462 .80458 .48224 Metetra
.699 .742 .885 r
.80458 .48224 .80631 .48462 .81029 .48298 .80857 .4806 Metetra
.698 .742 .886 r
.80857 .4806 .81029 .48298 .81428 .48135 .81256 .47897 Metetra
.696 .742 .887 r
.81256 .47897 .81428 .48135 .81828 .47974 .81657 .47737 Metetra
.695 .742 .887 r
.81657 .47737 .81828 .47974 .82228 .47815 .82057 .47577 Metetra
.694 .742 .888 r
.82057 .47577 .82228 .47815 .82629 .47657 .82459 .47419 Metetra
.693 .742 .889 r
.82459 .47419 .82629 .47657 .8303 .475 .82861 .47263 Metetra
.691 .742 .89 r
.82861 .47263 .8303 .475 .83432 .47345 .83263 .47108 Metetra
.69 .742 .89 r
.83263 .47108 .83432 .47345 .83835 .47191 .83666 .46953 Metetra
.689 .742 .891 r
.83666 .46953 .83835 .47191 .84238 .47038 .8407 .468 Metetra
.688 .742 .892 r
.8407 .468 .84238 .47038 .84642 .46886 .84474 .46648 Metetra
.688 .742 .892 r
.84474 .46648 .84642 .46886 .85047 .46734 .84879 .46497 Metetra
.687 .742 .893 r
.84879 .46497 .85047 .46734 .85452 .46584 .85285 .46347 Metetra
.686 .742 .893 r
.85285 .46347 .85452 .46584 .85858 .46435 .85691 .46197 Metetra
.685 .741 .894 r
.85691 .46197 .85858 .46435 .86264 .46286 .86098 .46048 Metetra
.684 .741 .894 r
.86098 .46048 .86264 .46286 .86671 .46138 .86505 .459 Metetra
.684 .741 .895 r
.86505 .459 .86671 .46138 .87078 .4599 .86913 .45752 Metetra
.683 .741 .895 r
.86913 .45752 .87078 .4599 .87487 .45843 .87322 .45606 Metetra
.683 .741 .896 r
.87322 .45606 .87487 .45843 .87895 .45697 .87731 .45459 Metetra
.682 .741 .896 r
.87731 .45459 .87895 .45697 .88305 .45551 .8814 .45313 Metetra
.681 .741 .896 r
.8814 .45313 .88305 .45551 .88714 .45406 .88551 .45168 Metetra
.681 .741 .897 r
.88551 .45168 .88714 .45406 .89125 .45261 .88962 .45023 Metetra
.68 .741 .897 r
.88962 .45023 .89125 .45261 .89536 .45117 .89373 .44879 Metetra
.68 .741 .897 r
.89373 .44879 .89536 .45117 .89948 .44973 .89785 .44734 Metetra
.679 .741 .898 r
.89785 .44734 .89948 .44973 .9036 .4483 .90198 .44591 Metetra
.679 .741 .898 r
.90198 .44591 .9036 .4483 .90773 .44686 .90611 .44447 Metetra
.679 .741 .898 r
.90611 .44447 .90773 .44686 .91186 .44544 .91025 .44304 Metetra
.678 .741 .898 r
.91025 .44304 .91186 .44544 .916 .44401 .9144 .44162 Metetra
.678 .741 .899 r
.9144 .44162 .916 .44401 .92015 .44259 .91855 .44019 Metetra
.677 .741 .899 r
.91855 .44019 .92015 .44259 .9243 .44117 .92271 .43877 Metetra
.677 .741 .899 r
.92271 .43877 .9243 .44117 .92846 .43975 .92687 .43735 Metetra
.677 .741 .899 r
.92687 .43735 .92846 .43975 .93263 .43833 .93104 .43593 Metetra
.676 .741 .9 r
.93104 .43593 .93263 .43833 .9368 .43692 .93521 .43452 Metetra
.676 .741 .9 r
.93521 .43452 .9368 .43692 .94097 .43551 .9394 .4331 Metetra
.676 .741 .9 r
.9394 .4331 .94097 .43551 .94516 .4341 .94358 .43169 Metetra
.675 .741 .9 r
.94358 .43169 .94516 .4341 .94935 .43269 .94778 .43028 Metetra
.675 .741 .9 r
.94778 .43028 .94935 .43269 .95354 .43128 .95198 .42887 Metetra
.675 .741 .9 r
.95198 .42887 .95354 .43128 .95774 .42988 .95618 .42746 Metetra
.675 .741 .901 r
.95618 .42746 .95774 .42988 .96195 .42847 .96039 .42606 Metetra
.65 .733 .91 r
.38833 .59612 .39041 .59811 .39387 .59719 .39179 .5952 Metetra
.65 .733 .91 r
.39179 .5952 .39387 .59719 .39733 .59627 .39525 .59428 Metetra
.649 .732 .91 r
.39525 .59428 .39733 .59627 .40079 .59536 .39872 .59336 Metetra
.649 .732 .91 r
.39872 .59336 .40079 .59536 .40426 .59444 .40219 .59244 Metetra
.649 .732 .91 r
.40219 .59244 .40426 .59444 .40773 .59353 .40567 .59152 Metetra
.648 .732 .91 r
.40567 .59152 .40773 .59353 .41121 .59262 .40915 .59061 Metetra
.648 .732 .91 r
.40915 .59061 .41121 .59262 .4147 .59171 .41263 .58969 Metetra
.647 .731 .91 r
.41263 .58969 .4147 .59171 .41818 .5908 .41613 .58878 Metetra
.647 .731 .91 r
.41613 .58878 .41818 .5908 .42168 .5899 .41962 .58788 Metetra
.647 .731 .91 r
.41962 .58788 .42168 .5899 .42517 .589 .42312 .58697 Metetra
.646 .731 .91 r
.42312 .58697 .42517 .589 .42868 .5881 .42663 .58607 Metetra
.646 .73 .911 r
.42663 .58607 .42868 .5881 .43218 .5872 .43014 .58517 Metetra
.645 .73 .911 r
.43014 .58517 .43218 .5872 .43569 .58631 .43365 .58428 Metetra
.645 .73 .911 r
.43365 .58428 .43569 .58631 .43921 .58543 .43717 .58338 Metetra
.644 .729 .911 r
.43717 .58338 .43921 .58543 .44273 .58454 .44069 .5825 Metetra
.643 .729 .911 r
.44069 .5825 .44273 .58454 .44626 .58366 .44422 .58161 Metetra
.643 .729 .911 r
.44422 .58161 .44626 .58366 .44979 .58279 .44776 .58073 Metetra
.642 .728 .911 r
.44776 .58073 .44979 .58279 .45333 .58192 .45129 .57986 Metetra
.642 .728 .911 r
.45129 .57986 .45333 .58192 .45687 .58105 .45484 .57899 Metetra
.641 .728 .911 r
.45484 .57899 .45687 .58105 .46041 .58019 .45839 .57812 Metetra
.64 .727 .911 r
.45839 .57812 .46041 .58019 .46396 .57933 .46194 .57726 Metetra
.639 .727 .912 r
.46194 .57726 .46396 .57933 .46752 .57849 .4655 .57641 Metetra
.639 .726 .912 r
.4655 .57641 .46752 .57849 .47108 .57764 .46906 .57556 Metetra
.638 .726 .912 r
.46906 .57556 .47108 .57764 .47465 .57681 .47263 .57472 Metetra
.637 .725 .912 r
.47263 .57472 .47465 .57681 .47822 .57598 .4762 .57389 Metetra
.636 .725 .912 r
.4762 .57389 .47822 .57598 .48179 .57516 .47978 .57306 Metetra
.635 .724 .912 r
.47978 .57306 .48179 .57516 .48537 .57435 .48337 .57224 Metetra
.634 .723 .912 r
.48337 .57224 .48537 .57435 .48896 .57354 .48696 .57143 Metetra
.632 .723 .913 r
.48696 .57143 .48896 .57354 .49255 .57275 .49055 .57063 Metetra
.631 .722 .913 r
.49055 .57063 .49255 .57275 .49615 .57196 .49415 .56984 Metetra
.63 .721 .913 r
.49415 .56984 .49615 .57196 .49975 .57119 .49775 .56906 Metetra
.629 .721 .913 r
.49775 .56906 .49975 .57119 .50336 .57043 .50136 .5683 Metetra
.627 .72 .913 r
.50136 .5683 .50336 .57043 .50697 .56968 .50498 .56754 Metetra
.625 .719 .914 r
.50498 .56754 .50697 .56968 .51059 .56894 .5086 .5668 Metetra
.624 .718 .914 r
.5086 .5668 .51059 .56894 .51421 .56822 .51223 .56607 Metetra
.622 .717 .914 r
.51223 .56607 .51421 .56822 .51784 .56752 .51586 .56536 Metetra
.62 .716 .914 r
.51586 .56536 .51784 .56752 .52147 .56683 .5195 .56466 Metetra
.618 .714 .915 r
.5195 .56466 .52147 .56683 .52511 .56616 .52314 .56398 Metetra
.615 .713 .915 r
.52314 .56398 .52511 .56616 .52876 .56551 .52679 .56333 Metetra
.613 .712 .915 r
.52679 .56333 .52876 .56551 .53241 .56488 .53044 .56269 Metetra
.61 .71 .916 r
.53044 .56269 .53241 .56488 .53607 .56427 .5341 .56208 Metetra
.607 .708 .916 r
.5341 .56208 .53607 .56427 .53973 .56369 .53777 .56149 Metetra
.603 .707 .917 r
.53777 .56149 .53973 .56369 .5434 .56314 .54144 .56093 Metetra
.6 .705 .917 r
.54144 .56093 .5434 .56314 .54708 .56262 .54512 .5604 Metetra
.596 .702 .918 r
.54512 .5604 .54708 .56262 .55076 .56213 .54881 .5599 Metetra
.591 .7 .918 r
.54881 .5599 .55076 .56213 .55445 .56168 .5525 .55944 Metetra
.586 .697 .919 r
.5525 .55944 .55445 .56168 .55815 .56128 .5562 .55902 Metetra
.581 .694 .919 r
.5562 .55902 .55815 .56128 .56185 .56091 .5599 .55864 Metetra
.574 .691 .92 r
.5599 .55864 .56185 .56091 .56556 .5606 .56362 .55832 Metetra
.567 .687 .921 r
.56362 .55832 .56556 .5606 .56928 .56035 .56734 .55805 Metetra
.559 .682 .922 r
.56734 .55805 .56928 .56035 .57301 .56016 .57106 .55784 Metetra
.55 .677 .922 r
.57106 .55784 .57301 .56016 .57674 .56004 .5748 .55771 Metetra
.539 .671 .923 r
.5748 .55771 .57674 .56004 .58048 .56 .57854 .55765 Metetra
.526 .664 .924 r
.57854 .55765 .58048 .56 .58423 .56005 .5823 .55769 Metetra
.512 .656 .924 r
.5823 .55769 .58423 .56005 .58799 .56021 .58606 .55783 Metetra
.494 .646 .925 r
.58606 .55783 .58799 .56021 .59177 .5605 .58983 .55809 Metetra
.473 .634 .925 r
.58983 .55809 .59177 .5605 .59555 .56092 .59362 .55849 Metetra
.447 .619 .924 r
.59362 .55849 .59555 .56092 .59934 .56151 .59741 .55905 Metetra
.416 .601 .922 r
.59741 .55905 .59934 .56151 .60315 .5623 .60122 .55981 Metetra
.376 .577 .919 r
.60122 .55981 .60315 .5623 .60697 .56332 .60505 .5608 Metetra
.325 .546 .912 r
.60505 .5608 .60697 .56332 .61081 .56463 .60889 .56207 Metetra
.259 .505 .9 r
.60889 .56207 .61081 .56463 .61467 .56628 .61275 .56368 Metetra
.171 .447 .877 r
.61275 .56368 .61467 .56628 .61856 .56835 .61663 .56571 Metetra
.053 .367 .836 r
.61663 .56571 .61856 .56835 .62247 .57096 .62054 .56828 Metetra
0 .255 .765 r
.62054 .56828 .62247 .57096 .62641 .57426 .62449 .57153 Metetra
0 .103 .646 r
.62449 .57153 .62641 .57426 .6304 .57847 .62847 .57569 Metetra
0 0 .471 r
.62847 .57569 .6304 .57847 .63445 .58388 .63252 .58107 Metetra
.707 .271 0 r
.63252 .58107 .63445 .58388 .63857 .59097 .63664 .58816 Metetra
.843 .426 0 r
.63664 .58816 .63857 .59097 .6428 .60045 .64086 .59772 Metetra
.918 .532 .132 r
.64086 .59772 .6428 .60045 .64718 .61344 .64525 .61102 Metetra
.95 .595 .261 r
.64525 .61102 .64718 .61344 .65179 .63174 .64989 .63018 Metetra
.956 .627 .35 r
.64989 .63018 .65179 .63174 .65675 .65783 .65493 .65868 Metetra
.947 .635 .412 r
.65493 .65868 .65675 .65783 .66213 .69289 .66054 .7 Metetra
.854 .542 .458 r
.66054 .7 .66213 .69289 .66741 .72328 .66546 .72129 Metetra
.645 .763 .934 r
.66546 .72129 .66741 .72328 .67147 .7222 .66952 .72021 Metetra
.957 .737 .565 r
.66952 .72021 .67147 .7222 .67419 .68965 .67265 .69677 Metetra
.995 .769 .408 r
.67265 .69677 .67419 .68965 .67664 .65235 .67486 .65319 Metetra
.986 .757 .508 r
.67486 .65319 .67664 .65235 .67942 .62398 .67755 .6224 Metetra
.962 .746 .565 r
.67755 .6224 .67942 .62398 .68249 .60339 .68059 .60093 Metetra
.939 .742 .608 r
.68059 .60093 .68249 .60339 .68577 .58809 .68387 .58533 Metetra
.919 .74 .644 r
.68387 .58533 .68577 .58809 .6892 .57631 .6873 .57346 Metetra
.9 .74 .675 r
.6873 .57346 .6892 .57631 .69272 .56692 .69083 .56406 Metetra
.882 .741 .702 r
.69083 .56406 .69272 .56692 .69632 .5592 .69444 .55637 Metetra
.865 .742 .725 r
.69444 .55637 .69632 .5592 .69996 .55269 .69809 .5499 Metetra
.85 .743 .745 r
.69809 .5499 .69996 .55269 .70365 .54709 .70179 .54434 Metetra
.835 .744 .763 r
.70179 .54434 .70365 .54709 .70737 .54217 .70551 .53946 Metetra
.822 .744 .778 r
.70551 .53946 .70737 .54217 .71112 .53779 .70927 .53512 Metetra
.81 .745 .791 r
.70927 .53512 .71112 .53779 .71489 .53383 .71304 .53119 Metetra
.799 .745 .802 r
.71304 .53119 .71489 .53383 .71867 .53022 .71684 .52761 Metetra
.789 .745 .812 r
.71684 .52761 .71867 .53022 .72248 .52689 .72065 .52431 Metetra
.78 .745 .82 r
.72065 .52431 .72248 .52689 .7263 .5238 .72447 .52124 Metetra
.772 .745 .828 r
.72447 .52124 .7263 .5238 .73013 .5209 .72831 .51836 Metetra
.765 .745 .835 r
.72831 .51836 .73013 .5209 .73397 .51817 .73216 .51565 Metetra
.758 .744 .84 r
.73216 .51565 .73397 .51817 .73783 .51558 .73602 .51307 Metetra
.752 .744 .845 r
.73602 .51307 .73783 .51558 .74169 .51311 .73989 .51062 Metetra
.746 .744 .85 r
.73989 .51062 .74169 .51311 .74556 .51074 .74376 .50827 Metetra
.741 .744 .854 r
.74376 .50827 .74556 .51074 .74944 .50847 .74765 .50601 Metetra
.736 .744 .858 r
.74765 .50601 .74944 .50847 .75334 .50628 .75155 .50383 Metetra
.732 .744 .861 r
.75155 .50383 .75334 .50628 .75723 .50416 .75545 .50172 Metetra
.728 .743 .864 r
.75545 .50172 .75723 .50416 .76114 .50211 .75936 .49967 Metetra
.724 .743 .867 r
.75936 .49967 .76114 .50211 .76506 .50011 .76328 .49768 Metetra
.721 .743 .869 r
.76328 .49768 .76506 .50011 .76898 .49816 .76721 .49574 Metetra
.718 .743 .871 r
.76721 .49574 .76898 .49816 .77291 .49626 .77114 .49385 Metetra
.715 .743 .873 r
.77114 .49385 .77291 .49626 .77684 .4944 .77508 .49199 Metetra
.713 .743 .875 r
.77508 .49199 .77684 .4944 .78079 .49258 .77903 .49017 Metetra
.71 .743 .877 r
.77903 .49017 .78079 .49258 .78474 .49079 .78298 .48838 Metetra
.708 .742 .878 r
.78298 .48838 .78474 .49079 .78869 .48903 .78694 .48663 Metetra
.706 .742 .88 r
.78694 .48663 .78869 .48903 .79265 .48729 .79091 .4849 Metetra
.704 .742 .881 r
.79091 .4849 .79265 .48729 .79662 .48559 .79489 .48319 Metetra
.702 .742 .883 r
.79489 .48319 .79662 .48559 .8006 .4839 .79887 .48151 Metetra
.7 .742 .884 r
.79887 .48151 .8006 .4839 .80458 .48224 .80285 .47985 Metetra
.699 .742 .885 r
.80285 .47985 .80458 .48224 .80857 .4806 .80685 .47821 Metetra
.697 .742 .886 r
.80685 .47821 .80857 .4806 .81256 .47897 .81084 .47659 Metetra
.696 .742 .887 r
.81084 .47659 .81256 .47897 .81657 .47737 .81485 .47498 Metetra
.695 .742 .888 r
.81485 .47498 .81657 .47737 .82057 .47577 .81886 .47339 Metetra
.693 .742 .888 r
.81886 .47339 .82057 .47577 .82459 .47419 .82288 .47181 Metetra
.692 .742 .889 r
.82288 .47181 .82459 .47419 .82861 .47263 .8269 .47025 Metetra
.691 .742 .89 r
.8269 .47025 .82861 .47263 .83263 .47108 .83093 .4687 Metetra
.69 .742 .891 r
.83093 .4687 .83263 .47108 .83666 .46953 .83497 .46715 Metetra
.689 .742 .891 r
.83497 .46715 .83666 .46953 .8407 .468 .83901 .46562 Metetra
.688 .741 .892 r
.83901 .46562 .8407 .468 .84474 .46648 .84306 .4641 Metetra
.687 .741 .892 r
.84306 .4641 .84474 .46648 .84879 .46497 .84711 .46259 Metetra
.686 .741 .893 r
.84711 .46259 .84879 .46497 .85285 .46347 .85117 .46109 Metetra
.686 .741 .893 r
.85117 .46109 .85285 .46347 .85691 .46197 .85524 .45959 Metetra
.685 .741 .894 r
.85524 .45959 .85691 .46197 .86098 .46048 .85931 .4581 Metetra
.684 .741 .894 r
.85931 .4581 .86098 .46048 .86505 .459 .86339 .45662 Metetra
.684 .741 .895 r
.86339 .45662 .86505 .459 .86913 .45752 .86747 .45514 Metetra
.683 .741 .895 r
.86747 .45514 .86913 .45752 .87322 .45606 .87156 .45367 Metetra
.682 .741 .896 r
.87156 .45367 .87322 .45606 .87731 .45459 .87566 .45221 Metetra
.682 .741 .896 r
.87566 .45221 .87731 .45459 .8814 .45313 .87976 .45075 Metetra
.681 .741 .896 r
.87976 .45075 .8814 .45313 .88551 .45168 .88387 .44929 Metetra
.681 .741 .897 r
.88387 .44929 .88551 .45168 .88962 .45023 .88798 .44784 Metetra
.68 .741 .897 r
.88798 .44784 .88962 .45023 .89373 .44879 .8921 .44639 Metetra
.68 .741 .897 r
.8921 .44639 .89373 .44879 .89785 .44734 .89622 .44495 Metetra
.679 .741 .898 r
.89622 .44495 .89785 .44734 .90198 .44591 .90036 .44351 Metetra
.679 .741 .898 r
.90036 .44351 .90198 .44591 .90611 .44447 .90449 .44208 Metetra
.678 .741 .898 r
.90449 .44208 .90611 .44447 .91025 .44304 .90864 .44064 Metetra
.678 .741 .898 r
.90864 .44064 .91025 .44304 .9144 .44162 .91279 .43922 Metetra
.678 .741 .899 r
.91279 .43922 .9144 .44162 .91855 .44019 .91694 .43779 Metetra
.677 .741 .899 r
.91694 .43779 .91855 .44019 .92271 .43877 .9211 .43636 Metetra
.677 .741 .899 r
.9211 .43636 .92271 .43877 .92687 .43735 .92527 .43494 Metetra
.677 .741 .899 r
.92527 .43494 .92687 .43735 .93104 .43593 .92945 .43352 Metetra
.676 .741 .9 r
.92945 .43352 .93104 .43593 .93521 .43452 .93363 .43211 Metetra
.676 .741 .9 r
.93363 .43211 .93521 .43452 .9394 .4331 .93781 .43069 Metetra
.676 .741 .9 r
.93781 .43069 .9394 .4331 .94358 .43169 .942 .42928 Metetra
.675 .741 .9 r
.942 .42928 .94358 .43169 .94778 .43028 .9462 .42786 Metetra
.675 .741 .9 r
.9462 .42786 .94778 .43028 .95198 .42887 .9504 .42645 Metetra
.675 .741 .9 r
.9504 .42645 .95198 .42887 .95618 .42746 .95461 .42504 Metetra
.674 .741 .901 r
.95461 .42504 .95618 .42746 .96039 .42606 .95883 .42363 Metetra
.65 .733 .91 r
.38624 .59413 .38833 .59612 .39179 .5952 .38971 .5932 Metetra
.65 .733 .91 r
.38971 .5932 .39179 .5952 .39525 .59428 .39317 .59228 Metetra
.649 .732 .91 r
.39317 .59228 .39525 .59428 .39872 .59336 .39664 .59135 Metetra
.649 .732 .91 r
.39664 .59135 .39872 .59336 .40219 .59244 .40012 .59043 Metetra
.649 .732 .91 r
.40012 .59043 .40219 .59244 .40567 .59152 .4036 .58951 Metetra
.648 .732 .91 r
.4036 .58951 .40567 .59152 .40915 .59061 .40708 .58859 Metetra
.648 .732 .91 r
.40708 .58859 .40915 .59061 .41263 .58969 .41057 .58767 Metetra
.648 .731 .91 r
.41057 .58767 .41263 .58969 .41613 .58878 .41406 .58676 Metetra
.647 .731 .91 r
.41406 .58676 .41613 .58878 .41962 .58788 .41756 .58585 Metetra
.647 .731 .91 r
.41756 .58585 .41962 .58788 .42312 .58697 .42106 .58494 Metetra
.646 .731 .91 r
.42106 .58494 .42312 .58697 .42663 .58607 .42457 .58403 Metetra
.646 .73 .91 r
.42457 .58403 .42663 .58607 .43014 .58517 .42808 .58313 Metetra
.645 .73 .911 r
.42808 .58313 .43014 .58517 .43365 .58428 .4316 .58223 Metetra
.645 .73 .911 r
.4316 .58223 .43365 .58428 .43717 .58338 .43512 .58134 Metetra
.644 .729 .911 r
.43512 .58134 .43717 .58338 .44069 .5825 .43865 .58044 Metetra
.644 .729 .911 r
.43865 .58044 .44069 .5825 .44422 .58161 .44218 .57956 Metetra
.643 .729 .911 r
.44218 .57956 .44422 .58161 .44776 .58073 .44572 .57867 Metetra
.642 .728 .911 r
.44572 .57867 .44776 .58073 .45129 .57986 .44926 .57779 Metetra
.642 .728 .911 r
.44926 .57779 .45129 .57986 .45484 .57899 .45281 .57692 Metetra
.641 .728 .911 r
.45281 .57692 .45484 .57899 .45839 .57812 .45636 .57605 Metetra
.64 .727 .911 r
.45636 .57605 .45839 .57812 .46194 .57726 .45991 .57518 Metetra
.64 .727 .911 r
.45991 .57518 .46194 .57726 .4655 .57641 .46347 .57433 Metetra
.639 .726 .912 r
.46347 .57433 .4655 .57641 .46906 .57556 .46704 .57347 Metetra
.638 .726 .912 r
.46704 .57347 .46906 .57556 .47263 .57472 .47061 .57263 Metetra
.637 .725 .912 r
.47061 .57263 .47263 .57472 .4762 .57389 .47419 .57179 Metetra
.636 .725 .912 r
.47419 .57179 .4762 .57389 .47978 .57306 .47777 .57096 Metetra
.635 .724 .912 r
.47777 .57096 .47978 .57306 .48337 .57224 .48136 .57013 Metetra
.634 .724 .912 r
.48136 .57013 .48337 .57224 .48696 .57143 .48495 .56932 Metetra
.633 .723 .912 r
.48495 .56932 .48696 .57143 .49055 .57063 .48855 .56851 Metetra
.632 .722 .913 r
.48855 .56851 .49055 .57063 .49415 .56984 .49215 .56772 Metetra
.63 .721 .913 r
.49215 .56772 .49415 .56984 .49775 .56906 .49575 .56693 Metetra
.629 .721 .913 r
.49575 .56693 .49775 .56906 .50136 .5683 .49937 .56616 Metetra
.627 .72 .913 r
.49937 .56616 .50136 .5683 .50498 .56754 .50299 .5654 Metetra
.626 .719 .913 r
.50299 .5654 .50498 .56754 .5086 .5668 .50661 .56465 Metetra
.624 .718 .914 r
.50661 .56465 .5086 .5668 .51223 .56607 .51024 .56391 Metetra
.622 .717 .914 r
.51024 .56391 .51223 .56607 .51586 .56536 .51387 .56319 Metetra
.62 .716 .914 r
.51387 .56319 .51586 .56536 .5195 .56466 .51751 .56249 Metetra
.618 .715 .915 r
.51751 .56249 .5195 .56466 .52314 .56398 .52116 .56181 Metetra
.616 .713 .915 r
.52116 .56181 .52314 .56398 .52679 .56333 .52481 .56114 Metetra
.613 .712 .915 r
.52481 .56114 .52679 .56333 .53044 .56269 .52847 .56049 Metetra
.611 .71 .916 r
.52847 .56049 .53044 .56269 .5341 .56208 .53213 .55987 Metetra
.608 .709 .916 r
.53213 .55987 .5341 .56208 .53777 .56149 .5358 .55927 Metetra
.604 .707 .916 r
.5358 .55927 .53777 .56149 .54144 .56093 .53948 .5587 Metetra
.601 .705 .917 r
.53948 .5587 .54144 .56093 .54512 .5604 .54316 .55816 Metetra
.597 .703 .917 r
.54316 .55816 .54512 .5604 .54881 .5599 .54685 .55765 Metetra
.592 .7 .918 r
.54685 .55765 .54881 .5599 .5525 .55944 .55054 .55718 Metetra
.587 .697 .918 r
.55054 .55718 .5525 .55944 .5562 .55902 .55424 .55675 Metetra
.582 .694 .919 r
.55424 .55675 .5562 .55902 .5599 .55864 .55795 .55636 Metetra
.576 .691 .92 r
.55795 .55636 .5599 .55864 .56362 .55832 .56167 .55602 Metetra
.569 .687 .92 r
.56167 .55602 .56362 .55832 .56734 .55805 .56539 .55574 Metetra
.561 .683 .921 r
.56539 .55574 .56734 .55805 .57106 .55784 .56912 .55552 Metetra
.552 .678 .922 r
.56912 .55552 .57106 .55784 .5748 .55771 .57286 .55537 Metetra
.541 .672 .922 r
.57286 .55537 .5748 .55771 .57854 .55765 .5766 .55529 Metetra
.529 .665 .923 r
.5766 .55529 .57854 .55765 .5823 .55769 .58036 .55531 Metetra
.515 .657 .924 r
.58036 .55531 .5823 .55769 .58606 .55783 .58412 .55543 Metetra
.498 .647 .924 r
.58412 .55543 .58606 .55783 .58983 .55809 .5879 .55566 Metetra
.478 .635 .924 r
.5879 .55566 .58983 .55809 .59362 .55849 .59168 .55604 Metetra
.453 .621 .923 r
.59168 .55604 .59362 .55849 .59741 .55905 .59548 .55658 Metetra
.422 .603 .922 r
.59548 .55658 .59741 .55905 .60122 .55981 .59929 .5573 Metetra
.384 .58 .918 r
.59929 .5573 .60122 .55981 .60505 .5608 .60312 .55826 Metetra
.335 .55 .912 r
.60312 .55826 .60505 .5608 .60889 .56207 .60696 .55949 Metetra
.271 .51 .9 r
.60696 .55949 .60889 .56207 .61275 .56368 .61082 .56105 Metetra
.187 .455 .879 r
.61082 .56105 .61275 .56368 .61663 .56571 .6147 .56303 Metetra
.074 .378 .842 r
.6147 .56303 .61663 .56571 .62054 .56828 .61861 .56555 Metetra
0 .269 .776 r
.61861 .56555 .62054 .56828 .62449 .57153 .62256 .56874 Metetra
0 .121 .664 r
.62256 .56874 .62449 .57153 .62847 .57569 .62654 .57283 Metetra
0 0 .495 r
.62654 .57283 .62847 .57569 .63252 .58107 .63058 .57815 Metetra
.686 .256 0 r
.63058 .57815 .63252 .58107 .63664 .58816 .6347 .58519 Metetra
.833 .419 0 r
.6347 .58519 .63664 .58816 .64086 .59772 .63892 .59476 Metetra
.916 .532 .119 r
.63892 .59476 .64086 .59772 .64525 .61102 .64331 .60824 Metetra
.951 .599 .254 r
.64331 .60824 .64525 .61102 .64989 .63018 .64797 .62806 Metetra
.961 .634 .347 r
.64797 .62806 .64989 .63018 .65493 .65868 .65307 .65873 Metetra
.954 .646 .41 r
.65307 .65873 .65493 .65868 .66054 .7 .65892 .70682 Metetra
.801 .48 .446 r
.65892 .70682 .66054 .7 .66546 .72129 .6635 .7193 Metetra
.645 .763 .934 r
.6635 .7193 .66546 .72129 .66952 .72021 .66756 .71822 Metetra
.944 .757 .619 r
.66756 .71822 .66952 .72021 .67265 .69677 .67107 .7036 Metetra
.995 .758 .422 r
.67107 .7036 .67265 .69677 .67486 .65319 .67303 .65324 Metetra
.979 .745 .513 r
.67303 .65324 .67486 .65319 .67755 .6224 .67565 .62026 Metetra
.955 .736 .567 r
.67565 .62026 .67755 .6224 .68059 .60093 .67868 .59813 Metetra
.933 .733 .609 r
.67868 .59813 .68059 .60093 .68387 .58533 .68196 .58234 Metetra
.914 .733 .644 r
.68196 .58234 .68387 .58533 .6873 .57346 .6854 .57045 Metetra
.895 .735 .675 r
.6854 .57045 .6873 .57346 .69083 .56406 .68894 .56109 Metetra
.878 .737 .702 r
.68894 .56109 .69083 .56406 .69444 .55637 .69255 .55346 Metetra
.862 .738 .725 r
.69255 .55346 .69444 .55637 .69809 .5499 .69621 .54705 Metetra
.846 .74 .746 r
.69621 .54705 .69809 .5499 .70179 .54434 .69992 .54154 Metetra
.832 .741 .763 r
.69992 .54154 .70179 .54434 .70551 .53946 .70365 .53671 Metetra
.82 .742 .778 r
.70365 .53671 .70551 .53946 .70927 .53512 .70741 .53241 Metetra
.808 .742 .791 r
.70741 .53241 .70927 .53512 .71304 .53119 .71119 .52853 Metetra
.797 .743 .802 r
.71119 .52853 .71304 .53119 .71684 .52761 .71499 .52498 Metetra
.787 .743 .812 r
.71499 .52498 .71684 .52761 .72065 .52431 .71881 .52171 Metetra
.778 .743 .821 r
.71881 .52171 .72065 .52431 .72447 .52124 .72264 .51866 Metetra
.77 .743 .828 r
.72264 .51866 .72447 .52124 .72831 .51836 .72648 .51581 Metetra
.763 .743 .835 r
.72648 .51581 .72831 .51836 .73216 .51565 .73034 .51311 Metetra
.756 .743 .841 r
.73034 .51311 .73216 .51565 .73602 .51307 .7342 .51056 Metetra
.75 .743 .846 r
.7342 .51056 .73602 .51307 .73989 .51062 .73808 .50812 Metetra
.745 .743 .85 r
.73808 .50812 .73989 .51062 .74376 .50827 .74196 .50578 Metetra
.74 .743 .854 r
.74196 .50578 .74376 .50827 .74765 .50601 .74585 .50353 Metetra
.735 .743 .858 r
.74585 .50353 .74765 .50601 .75155 .50383 .74975 .50137 Metetra
.731 .743 .861 r
.74975 .50137 .75155 .50383 .75545 .50172 .75366 .49927 Metetra
.727 .743 .864 r
.75366 .49927 .75545 .50172 .75936 .49967 .75758 .49723 Metetra
.724 .743 .867 r
.75758 .49723 .75936 .49967 .76328 .49768 .7615 .49525 Metetra
.72 .743 .869 r
.7615 .49525 .76328 .49768 .76721 .49574 .76543 .49331 Metetra
.717 .742 .871 r
.76543 .49331 .76721 .49574 .77114 .49385 .76937 .49142 Metetra
.715 .742 .873 r
.76937 .49142 .77114 .49385 .77508 .49199 .77332 .48957 Metetra
.712 .742 .875 r
.77332 .48957 .77508 .49199 .77903 .49017 .77727 .48776 Metetra
.71 .742 .877 r
.77727 .48776 .77903 .49017 .78298 .48838 .78123 .48597 Metetra
.707 .742 .879 r
.78123 .48597 .78298 .48838 .78694 .48663 .78519 .48422 Metetra
.705 .742 .88 r
.78519 .48422 .78694 .48663 .79091 .4849 .78916 .4825 Metetra
.703 .742 .881 r
.78916 .4825 .79091 .4849 .79489 .48319 .79314 .4808 Metetra
.702 .742 .883 r
.79314 .4808 .79489 .48319 .79887 .48151 .79713 .47912 Metetra
.7 .742 .884 r
.79713 .47912 .79887 .48151 .80285 .47985 .80112 .47746 Metetra
.698 .742 .885 r
.80112 .47746 .80285 .47985 .80685 .47821 .80512 .47582 Metetra
.697 .742 .886 r
.80512 .47582 .80685 .47821 .81084 .47659 .80912 .4742 Metetra
.696 .742 .887 r
.80912 .4742 .81084 .47659 .81485 .47498 .81313 .47259 Metetra
.694 .742 .888 r
.81313 .47259 .81485 .47498 .81886 .47339 .81714 .471 Metetra
.693 .742 .888 r
.81714 .471 .81886 .47339 .82288 .47181 .82117 .46943 Metetra
.692 .741 .889 r
.82117 .46943 .82288 .47181 .8269 .47025 .82519 .46786 Metetra
.691 .741 .89 r
.82519 .46786 .8269 .47025 .83093 .4687 .82923 .46631 Metetra
.69 .741 .891 r
.82923 .46631 .83093 .4687 .83497 .46715 .83327 .46477 Metetra
.689 .741 .891 r
.83327 .46477 .83497 .46715 .83901 .46562 .83732 .46324 Metetra
.688 .741 .892 r
.83732 .46324 .83901 .46562 .84306 .4641 .84137 .46172 Metetra
.687 .741 .892 r
.84137 .46172 .84306 .4641 .84711 .46259 .84543 .4602 Metetra
.686 .741 .893 r
.84543 .4602 .84711 .46259 .85117 .46109 .84949 .4587 Metetra
.685 .741 .893 r
.84949 .4587 .85117 .46109 .85524 .45959 .85356 .4572 Metetra
.685 .741 .894 r
.85356 .4572 .85524 .45959 .85931 .4581 .85764 .45571 Metetra
.684 .741 .894 r
.85764 .45571 .85931 .4581 .86339 .45662 .86172 .45423 Metetra
.683 .741 .895 r
.86172 .45423 .86339 .45662 .86747 .45514 .86581 .45275 Metetra
.683 .741 .895 r
.86581 .45275 .86747 .45514 .87156 .45367 .8699 .45128 Metetra
.682 .741 .896 r
.8699 .45128 .87156 .45367 .87566 .45221 .874 .44981 Metetra
.682 .741 .896 r
.874 .44981 .87566 .45221 .87976 .45075 .87811 .44835 Metetra
.681 .741 .896 r
.87811 .44835 .87976 .45075 .88387 .44929 .88222 .4469 Metetra
.681 .741 .897 r
.88222 .4469 .88387 .44929 .88798 .44784 .88634 .44544 Metetra
.68 .741 .897 r
.88634 .44544 .88798 .44784 .8921 .44639 .89046 .444 Metetra
.68 .741 .897 r
.89046 .444 .8921 .44639 .89622 .44495 .89459 .44255 Metetra
.679 .741 .898 r
.89459 .44255 .89622 .44495 .90036 .44351 .89873 .44111 Metetra
.679 .741 .898 r
.89873 .44111 .90036 .44351 .90449 .44208 .90287 .43967 Metetra
.678 .741 .898 r
.90287 .43967 .90449 .44208 .90864 .44064 .90702 .43824 Metetra
.678 .741 .898 r
.90702 .43824 .90864 .44064 .91279 .43922 .91117 .43681 Metetra
.677 .741 .899 r
.91117 .43681 .91279 .43922 .91694 .43779 .91533 .43538 Metetra
.677 .741 .899 r
.91533 .43538 .91694 .43779 .9211 .43636 .9195 .43395 Metetra
.677 .741 .899 r
.9195 .43395 .9211 .43636 .92527 .43494 .92367 .43253 Metetra
.676 .741 .899 r
.92367 .43253 .92527 .43494 .92945 .43352 .92785 .43111 Metetra
.676 .741 .9 r
.92785 .43111 .92945 .43352 .93363 .43211 .93203 .42969 Metetra
.676 .741 .9 r
.93203 .42969 .93363 .43211 .93781 .43069 .93622 .42827 Metetra
.675 .741 .9 r
.93622 .42827 .93781 .43069 .942 .42928 .94042 .42685 Metetra
.675 .741 .9 r
.94042 .42685 .942 .42928 .9462 .42786 .94462 .42544 Metetra
.675 .741 .9 r
.94462 .42544 .9462 .42786 .9504 .42645 .94883 .42403 Metetra
.675 .741 .9 r
.94883 .42403 .9504 .42645 .95461 .42504 .95305 .42261 Metetra
.674 .741 .901 r
.95305 .42261 .95461 .42504 .95883 .42363 .95727 .4212 Metetra
.65 .733 .91 r
.38415 .59213 .38624 .59413 .38971 .5932 .38762 .5912 Metetra
.65 .733 .91 r
.38762 .5912 .38971 .5932 .39317 .59228 .39109 .59027 Metetra
.65 .733 .91 r
.39109 .59027 .39317 .59228 .39664 .59135 .39456 .58934 Metetra
.649 .732 .91 r
.39456 .58934 .39664 .59135 .40012 .59043 .39804 .58842 Metetra
.649 .732 .91 r
.39804 .58842 .40012 .59043 .4036 .58951 .40152 .58749 Metetra
.648 .732 .91 r
.40152 .58749 .4036 .58951 .40708 .58859 .40501 .58657 Metetra
.648 .732 .91 r
.40501 .58657 .40708 .58859 .41057 .58767 .4085 .58565 Metetra
.648 .731 .91 r
.4085 .58565 .41057 .58767 .41406 .58676 .41199 .58473 Metetra
.647 .731 .91 r
.41199 .58473 .41406 .58676 .41756 .58585 .41549 .58382 Metetra
.647 .731 .91 r
.41549 .58382 .41756 .58585 .42106 .58494 .419 .5829 Metetra
.646 .731 .91 r
.419 .5829 .42106 .58494 .42457 .58403 .42251 .582 Metetra
.646 .73 .91 r
.42251 .582 .42457 .58403 .42808 .58313 .42603 .58109 Metetra
.645 .73 .91 r
.42603 .58109 .42808 .58313 .4316 .58223 .42955 .58019 Metetra
.645 .73 .911 r
.42955 .58019 .4316 .58223 .43512 .58134 .43307 .57929 Metetra
.644 .729 .911 r
.43307 .57929 .43512 .58134 .43865 .58044 .4366 .57839 Metetra
.644 .729 .911 r
.4366 .57839 .43865 .58044 .44218 .57956 .44013 .5775 Metetra
.643 .729 .911 r
.44013 .5775 .44218 .57956 .44572 .57867 .44367 .57661 Metetra
.643 .728 .911 r
.44367 .57661 .44572 .57867 .44926 .57779 .44722 .57572 Metetra
.642 .728 .911 r
.44722 .57572 .44926 .57779 .45281 .57692 .45077 .57485 Metetra
.641 .728 .911 r
.45077 .57485 .45281 .57692 .45636 .57605 .45432 .57397 Metetra
.641 .727 .911 r
.45432 .57397 .45636 .57605 .45991 .57518 .45788 .5731 Metetra
.64 .727 .911 r
.45788 .5731 .45991 .57518 .46347 .57433 .46144 .57224 Metetra
.639 .726 .911 r
.46144 .57224 .46347 .57433 .46704 .57347 .46501 .57138 Metetra
.638 .726 .912 r
.46501 .57138 .46704 .57347 .47061 .57263 .46859 .57053 Metetra
.637 .725 .912 r
.46859 .57053 .47061 .57263 .47419 .57179 .47217 .56969 Metetra
.636 .725 .912 r
.47217 .56969 .47419 .57179 .47777 .57096 .47575 .56885 Metetra
.635 .724 .912 r
.47575 .56885 .47777 .57096 .48136 .57013 .47934 .56802 Metetra
.634 .724 .912 r
.47934 .56802 .48136 .57013 .48495 .56932 .48294 .5672 Metetra
.633 .723 .912 r
.48294 .5672 .48495 .56932 .48855 .56851 .48654 .56639 Metetra
.632 .722 .912 r
.48654 .56639 .48855 .56851 .49215 .56772 .49014 .56559 Metetra
.631 .721 .913 r
.49014 .56559 .49215 .56772 .49575 .56693 .49375 .5648 Metetra
.629 .721 .913 r
.49375 .5648 .49575 .56693 .49937 .56616 .49737 .56402 Metetra
.628 .72 .913 r
.49737 .56402 .49937 .56616 .50299 .5654 .50099 .56325 Metetra
.626 .719 .913 r
.50099 .56325 .50299 .5654 .50661 .56465 .50461 .56249 Metetra
.625 .718 .913 r
.50461 .56249 .50661 .56465 .51024 .56391 .50825 .56175 Metetra
.623 .717 .914 r
.50825 .56175 .51024 .56391 .51387 .56319 .51188 .56102 Metetra
.621 .716 .914 r
.51188 .56102 .51387 .56319 .51751 .56249 .51553 .56031 Metetra
.619 .715 .914 r
.51553 .56031 .51751 .56249 .52116 .56181 .51917 .55962 Metetra
.617 .713 .915 r
.51917 .55962 .52116 .56181 .52481 .56114 .52283 .55895 Metetra
.614 .712 .915 r
.52283 .55895 .52481 .56114 .52847 .56049 .52649 .55829 Metetra
.611 .71 .915 r
.52649 .55829 .52847 .56049 .53213 .55987 .53015 .55766 Metetra
.609 .709 .916 r
.53015 .55766 .53213 .55987 .5358 .55927 .53383 .55705 Metetra
.605 .707 .916 r
.53383 .55705 .5358 .55927 .53948 .5587 .53751 .55647 Metetra
.602 .705 .916 r
.53751 .55647 .53948 .5587 .54316 .55816 .54119 .55592 Metetra
.598 .703 .917 r
.54119 .55592 .54316 .55816 .54685 .55765 .54488 .5554 Metetra
.594 .7 .917 r
.54488 .5554 .54685 .55765 .55054 .55718 .54858 .55492 Metetra
.589 .698 .918 r
.54858 .55492 .55054 .55718 .55424 .55675 .55228 .55448 Metetra
.583 .695 .918 r
.55228 .55448 .55424 .55675 .55795 .55636 .55599 .55408 Metetra
.577 .691 .919 r
.55599 .55408 .55795 .55636 .56167 .55602 .55971 .55372 Metetra
.571 .687 .92 r
.55971 .55372 .56167 .55602 .56539 .55574 .56343 .55342 Metetra
.563 .683 .92 r
.56343 .55342 .56539 .55574 .56912 .55552 .56717 .55319 Metetra
.554 .678 .921 r
.56717 .55319 .56912 .55552 .57286 .55537 .57091 .55302 Metetra
.544 .672 .922 r
.57091 .55302 .57286 .55537 .5766 .55529 .57466 .55292 Metetra
.532 .666 .922 r
.57466 .55292 .5766 .55529 .58036 .55531 .57841 .55292 Metetra
.518 .658 .923 r
.57841 .55292 .58036 .55531 .58412 .55543 .58218 .55302 Metetra
.502 .648 .923 r
.58218 .55302 .58412 .55543 .5879 .55566 .58596 .55323 Metetra
.482 .637 .923 r
.58596 .55323 .5879 .55566 .59168 .55604 .58974 .55358 Metetra
.458 .623 .922 r
.58974 .55358 .59168 .55604 .59548 .55658 .59354 .55408 Metetra
.429 .605 .921 r
.59354 .55408 .59548 .55658 .59929 .5573 .59736 .55478 Metetra
.392 .583 .918 r
.59736 .55478 .59929 .5573 .60312 .55826 .60118 .55569 Metetra
.345 .554 .912 r
.60118 .55569 .60312 .55826 .60696 .55949 .60502 .55688 Metetra
.284 .516 .901 r
.60502 .55688 .60696 .55949 .61082 .56105 .60889 .55839 Metetra
.203 .463 .882 r
.60889 .55839 .61082 .56105 .6147 .56303 .61277 .56032 Metetra
.095 .389 .847 r
.61277 .56032 .6147 .56303 .61861 .56555 .61668 .56277 Metetra
0 .285 .786 r
.61668 .56277 .61861 .56555 .62256 .56874 .62062 .56589 Metetra
0 .142 .682 r
.62062 .56589 .62256 .56874 .62654 .57283 .6246 .5699 Metetra
0 0 .52 r
.6246 .5699 .62654 .57283 .63058 .57815 .62864 .57513 Metetra
.661 .237 0 r
.62864 .57513 .63058 .57815 .6347 .58519 .63275 .58208 Metetra
.819 .407 0 r
.63275 .58208 .6347 .58519 .63892 .59476 .63697 .59159 Metetra
.911 .528 .103 r
.63697 .59159 .63892 .59476 .64331 .60824 .64135 .60511 Metetra
.952 .601 .244 r
.64135 .60511 .64331 .60824 .64797 .62806 .64602 .62536 Metetra
.964 .64 .342 r
.64602 .62536 .64797 .62806 .65307 .65873 .65117 .65782 Metetra
.96 .655 .407 r
.65117 .65782 .65307 .65873 .65892 .70682 .65726 .71283 Metetra
.689 .354 .403 r
.65726 .71283 .65892 .70682 .6635 .7193 .66153 .71731 Metetra
.645 .763 .934 r
.66153 .71731 .6635 .7193 .66756 .71822 .6656 .71622 Metetra
.892 .79 .741 r
.6656 .71622 .66756 .71822 .67107 .7036 .66945 .70962 Metetra
.993 .748 .437 r
.66945 .70962 .67107 .7036 .67303 .65324 .67116 .65232 Metetra
.971 .733 .519 r
.67116 .65232 .67303 .65324 .67565 .62026 .67372 .61754 Metetra
.948 .726 .57 r
.67372 .61754 .67565 .62026 .67868 .59813 .67674 .59497 Metetra
.927 .725 .61 r
.67674 .59497 .67868 .59813 .68196 .58234 .68003 .57913 Metetra
.908 .727 .645 r
.68003 .57913 .68196 .58234 .6854 .57045 .68348 .5673 Metetra
.89 .73 .676 r
.68348 .5673 .6854 .57045 .68894 .56109 .68703 .55803 Metetra
.874 .732 .703 r
.68703 .55803 .68894 .56109 .69255 .55346 .69065 .55047 Metetra
.858 .735 .726 r
.69065 .55047 .69255 .55346 .69621 .54705 .69433 .54414 Metetra
.843 .737 .746 r
.69433 .54414 .69621 .54705 .69992 .54154 .69804 .5387 Metetra
.83 .738 .764 r
.69804 .5387 .69992 .54154 .70365 .53671 .70178 .53393 Metetra
.817 .74 .779 r
.70178 .53393 .70365 .53671 .70741 .53241 .70555 .52968 Metetra
.805 .74 .792 r
.70555 .52968 .70741 .53241 .71119 .52853 .70934 .52584 Metetra
.795 .741 .803 r
.70934 .52584 .71119 .52853 .71499 .52498 .71315 .52233 Metetra
.785 .742 .813 r
.71315 .52233 .71499 .52498 .71881 .52171 .71697 .51909 Metetra
.777 .742 .821 r
.71697 .51909 .71881 .52171 .72264 .51866 .72081 .51607 Metetra
.769 .742 .829 r
.72081 .51607 .72264 .51866 .72648 .51581 .72465 .51324 Metetra
.762 .742 .835 r
.72465 .51324 .72648 .51581 .73034 .51311 .72851 .51056 Metetra
.755 .742 .841 r
.72851 .51056 .73034 .51311 .7342 .51056 .73238 .50803 Metetra
.749 .742 .846 r
.73238 .50803 .7342 .51056 .73808 .50812 .73626 .5056 Metetra
.744 .742 .851 r
.73626 .5056 .73808 .50812 .74196 .50578 .74015 .50328 Metetra
.739 .742 .855 r
.74015 .50328 .74196 .50578 .74585 .50353 .74405 .50105 Metetra
.734 .742 .858 r
.74405 .50105 .74585 .50353 .74975 .50137 .74796 .49889 Metetra
.73 .742 .861 r
.74796 .49889 .74975 .50137 .75366 .49927 .75187 .4968 Metetra
.726 .742 .864 r
.75187 .4968 .75366 .49927 .75758 .49723 .75579 .49477 Metetra
.723 .742 .867 r
.75579 .49477 .75758 .49723 .7615 .49525 .75972 .4928 Metetra
.72 .742 .869 r
.75972 .4928 .7615 .49525 .76543 .49331 .76365 .49087 Metetra
.717 .742 .872 r
.76365 .49087 .76543 .49331 .76937 .49142 .7676 .48899 Metetra
.714 .742 .874 r
.7676 .48899 .76937 .49142 .77332 .48957 .77155 .48714 Metetra
.711 .742 .875 r
.77155 .48714 .77332 .48957 .77727 .48776 .7755 .48534 Metetra
.709 .742 .877 r
.7755 .48534 .77727 .48776 .78123 .48597 .77947 .48356 Metetra
.707 .742 .879 r
.77947 .48356 .78123 .48597 .78519 .48422 .78344 .48181 Metetra
.705 .742 .88 r
.78344 .48181 .78519 .48422 .78916 .4825 .78741 .48009 Metetra
.703 .742 .881 r
.78741 .48009 .78916 .4825 .79314 .4808 .7914 .47839 Metetra
.701 .742 .883 r
.7914 .47839 .79314 .4808 .79713 .47912 .79539 .47671 Metetra
.699 .742 .884 r
.79539 .47671 .79713 .47912 .80112 .47746 .79938 .47506 Metetra
.698 .741 .885 r
.79938 .47506 .80112 .47746 .80512 .47582 .80338 .47342 Metetra
.696 .741 .886 r
.80338 .47342 .80512 .47582 .80912 .4742 .80739 .4718 Metetra
.695 .741 .887 r
.80739 .4718 .80912 .4742 .81313 .47259 .8114 .4702 Metetra
.694 .741 .888 r
.8114 .4702 .81313 .47259 .81714 .471 .81542 .46861 Metetra
.693 .741 .889 r
.81542 .46861 .81714 .471 .82117 .46943 .81945 .46703 Metetra
.692 .741 .889 r
.81945 .46703 .82117 .46943 .82519 .46786 .82348 .46547 Metetra
.69 .741 .89 r
.82348 .46547 .82519 .46786 .82923 .46631 .82752 .46392 Metetra
.689 .741 .891 r
.82752 .46392 .82923 .46631 .83327 .46477 .83157 .46237 Metetra
.689 .741 .891 r
.83157 .46237 .83327 .46477 .83732 .46324 .83562 .46084 Metetra
.688 .741 .892 r
.83562 .46084 .83732 .46324 .84137 .46172 .83967 .45932 Metetra
.687 .741 .892 r
.83967 .45932 .84137 .46172 .84543 .4602 .84374 .45781 Metetra
.686 .741 .893 r
.84374 .45781 .84543 .4602 .84949 .4587 .8478 .4563 Metetra
.685 .741 .893 r
.8478 .4563 .84949 .4587 .85356 .4572 .85188 .45481 Metetra
.685 .741 .894 r
.85188 .45481 .85356 .4572 .85764 .45571 .85596 .45332 Metetra
.684 .741 .894 r
.85596 .45332 .85764 .45571 .86172 .45423 .86005 .45183 Metetra
.683 .741 .895 r
.86005 .45183 .86172 .45423 .86581 .45275 .86414 .45035 Metetra
.683 .741 .895 r
.86414 .45035 .86581 .45275 .8699 .45128 .86824 .44888 Metetra
.682 .741 .896 r
.86824 .44888 .8699 .45128 .874 .44981 .87234 .44741 Metetra
.681 .741 .896 r
.87234 .44741 .874 .44981 .87811 .44835 .87645 .44595 Metetra
.681 .741 .896 r
.87645 .44595 .87811 .44835 .88222 .4469 .88057 .44449 Metetra
.68 .741 .897 r
.88057 .44449 .88222 .4469 .88634 .44544 .88469 .44304 Metetra
.68 .741 .897 r
.88469 .44304 .88634 .44544 .89046 .444 .88882 .44159 Metetra
.679 .741 .897 r
.88882 .44159 .89046 .444 .89459 .44255 .89295 .44015 Metetra
.679 .741 .898 r
.89295 .44015 .89459 .44255 .89873 .44111 .8971 .4387 Metetra
.679 .741 .898 r
.8971 .4387 .89873 .44111 .90287 .43967 .90124 .43726 Metetra
.678 .741 .898 r
.90124 .43726 .90287 .43967 .90702 .43824 .90539 .43583 Metetra
.678 .741 .898 r
.90539 .43583 .90702 .43824 .91117 .43681 .90955 .4344 Metetra
.677 .741 .899 r
.90955 .4344 .91117 .43681 .91533 .43538 .91372 .43297 Metetra
.677 .741 .899 r
.91372 .43297 .91533 .43538 .9195 .43395 .91789 .43154 Metetra
.677 .741 .899 r
.91789 .43154 .9195 .43395 .92367 .43253 .92206 .43011 Metetra
.676 .741 .899 r
.92206 .43011 .92367 .43253 .92785 .43111 .92625 .42869 Metetra
.676 .741 .9 r
.92625 .42869 .92785 .43111 .93203 .42969 .93044 .42727 Metetra
.676 .741 .9 r
.93044 .42727 .93203 .42969 .93622 .42827 .93463 .42585 Metetra
.675 .741 .9 r
.93463 .42585 .93622 .42827 .94042 .42685 .93883 .42443 Metetra
.675 .741 .9 r
.93883 .42443 .94042 .42685 .94462 .42544 .94304 .42301 Metetra
.675 .741 .9 r
.94304 .42301 .94462 .42544 .94883 .42403 .94725 .42159 Metetra
.675 .741 .901 r
.94725 .42159 .94883 .42403 .95305 .42261 .95147 .42018 Metetra
.674 .741 .901 r
.95147 .42018 .95305 .42261 .95727 .4212 .9557 .41877 Metetra
.65 .733 .91 r
.38206 .59013 .38415 .59213 .38762 .5912 .38553 .58919 Metetra
.65 .733 .91 r
.38553 .58919 .38762 .5912 .39109 .59027 .389 .58826 Metetra
.65 .733 .91 r
.389 .58826 .39109 .59027 .39456 .58934 .39247 .58733 Metetra
.649 .732 .91 r
.39247 .58733 .39456 .58934 .39804 .58842 .39595 .5864 Metetra
.649 .732 .91 r
.39595 .5864 .39804 .58842 .40152 .58749 .39944 .58547 Metetra
.649 .732 .91 r
.39944 .58547 .40152 .58749 .40501 .58657 .40293 .58455 Metetra
.648 .732 .91 r
.40293 .58455 .40501 .58657 .4085 .58565 .40642 .58362 Metetra
.648 .731 .91 r
.40642 .58362 .4085 .58565 .41199 .58473 .40992 .5827 Metetra
.647 .731 .91 r
.40992 .5827 .41199 .58473 .41549 .58382 .41342 .58178 Metetra
.647 .731 .91 r
.41342 .58178 .41549 .58382 .419 .5829 .41693 .58086 Metetra
.647 .731 .91 r
.41693 .58086 .419 .5829 .42251 .582 .42045 .57995 Metetra
.646 .73 .91 r
.42045 .57995 .42251 .582 .42603 .58109 .42396 .57904 Metetra
.646 .73 .91 r
.42396 .57904 .42603 .58109 .42955 .58019 .42749 .57813 Metetra
.645 .73 .91 r
.42749 .57813 .42955 .58019 .43307 .57929 .43101 .57723 Metetra
.645 .729 .91 r
.43101 .57723 .43307 .57929 .4366 .57839 .43455 .57633 Metetra
.644 .729 .911 r
.43455 .57633 .4366 .57839 .44013 .5775 .43808 .57543 Metetra
.643 .729 .911 r
.43808 .57543 .44013 .5775 .44367 .57661 .44163 .57454 Metetra
.643 .728 .911 r
.44163 .57454 .44367 .57661 .44722 .57572 .44517 .57365 Metetra
.642 .728 .911 r
.44517 .57365 .44722 .57572 .45077 .57485 .44872 .57277 Metetra
.642 .728 .911 r
.44872 .57277 .45077 .57485 .45432 .57397 .45228 .57189 Metetra
.641 .727 .911 r
.45228 .57189 .45432 .57397 .45788 .5731 .45584 .57101 Metetra
.64 .727 .911 r
.45584 .57101 .45788 .5731 .46144 .57224 .45941 .57015 Metetra
.639 .726 .911 r
.45941 .57015 .46144 .57224 .46501 .57138 .46298 .56928 Metetra
.639 .726 .911 r
.46298 .56928 .46501 .57138 .46859 .57053 .46656 .56843 Metetra
.638 .725 .911 r
.46656 .56843 .46859 .57053 .47217 .56969 .47014 .56758 Metetra
.637 .725 .912 r
.47014 .56758 .47217 .56969 .47575 .56885 .47373 .56674 Metetra
.636 .724 .912 r
.47373 .56674 .47575 .56885 .47934 .56802 .47732 .5659 Metetra
.635 .724 .912 r
.47732 .5659 .47934 .56802 .48294 .5672 .48092 .56508 Metetra
.634 .723 .912 r
.48092 .56508 .48294 .5672 .48654 .56639 .48452 .56426 Metetra
.632 .722 .912 r
.48452 .56426 .48654 .56639 .49014 .56559 .48813 .56345 Metetra
.631 .722 .912 r
.48813 .56345 .49014 .56559 .49375 .5648 .49174 .56265 Metetra
.63 .721 .913 r
.49174 .56265 .49375 .5648 .49737 .56402 .49536 .56187 Metetra
.628 .72 .913 r
.49536 .56187 .49737 .56402 .50099 .56325 .49898 .56109 Metetra
.627 .719 .913 r
.49898 .56109 .50099 .56325 .50461 .56249 .50261 .56033 Metetra
.625 .718 .913 r
.50261 .56033 .50461 .56249 .50825 .56175 .50625 .55958 Metetra
.623 .717 .913 r
.50625 .55958 .50825 .56175 .51188 .56102 .50989 .55885 Metetra
.622 .716 .914 r
.50989 .55885 .51188 .56102 .51553 .56031 .51353 .55813 Metetra
.62 .715 .914 r
.51353 .55813 .51553 .56031 .51917 .55962 .51719 .55743 Metetra
.617 .714 .914 r
.51719 .55743 .51917 .55962 .52283 .55895 .52084 .55675 Metetra
.615 .712 .915 r
.52084 .55675 .52283 .55895 .52649 .55829 .5245 .55608 Metetra
.612 .711 .915 r
.5245 .55608 .52649 .55829 .53015 .55766 .52817 .55544 Metetra
.609 .709 .915 r
.52817 .55544 .53015 .55766 .53383 .55705 .53185 .55483 Metetra
.606 .707 .916 r
.53185 .55483 .53383 .55705 .53751 .55647 .53553 .55424 Metetra
.603 .705 .916 r
.53553 .55424 .53751 .55647 .54119 .55592 .53922 .55368 Metetra
.599 .703 .916 r
.53922 .55368 .54119 .55592 .54488 .5554 .54291 .55315 Metetra
.595 .701 .917 r
.54291 .55315 .54488 .5554 .54858 .55492 .54661 .55265 Metetra
.59 .698 .917 r
.54661 .55265 .54858 .55492 .55228 .55448 .55032 .55219 Metetra
.585 .695 .918 r
.55032 .55219 .55228 .55448 .55599 .55408 .55403 .55178 Metetra
.579 .692 .918 r
.55403 .55178 .55599 .55408 .55971 .55372 .55775 .55141 Metetra
.572 .688 .919 r
.55775 .55141 .55971 .55372 .56343 .55342 .56148 .5511 Metetra
.565 .684 .92 r
.56148 .5511 .56343 .55342 .56717 .55319 .56521 .55085 Metetra
.556 .679 .92 r
.56521 .55085 .56717 .55319 .57091 .55302 .56895 .55066 Metetra
.546 .673 .921 r
.56895 .55066 .57091 .55302 .57466 .55292 .57271 .55055 Metetra
.535 .666 .921 r
.57271 .55055 .57466 .55292 .57841 .55292 .57646 .55052 Metetra
.522 .659 .922 r
.57646 .55052 .57841 .55292 .58218 .55302 .58023 .55059 Metetra
.506 .65 .922 r
.58023 .55059 .58218 .55302 .58596 .55323 .58401 .55078 Metetra
.487 .638 .922 r
.58401 .55078 .58596 .55323 .58974 .55358 .5878 .5511 Metetra
.464 .625 .922 r
.5878 .5511 .58974 .55358 .59354 .55408 .5916 .55157 Metetra
.436 .608 .92 r
.5916 .55157 .59354 .55408 .59736 .55478 .59541 .55223 Metetra
.4 .587 .917 r
.59541 .55223 .59736 .55478 .60118 .55569 .59924 .55311 Metetra
.355 .559 .912 r
.59924 .55311 .60118 .55569 .60502 .55688 .60308 .55425 Metetra
.297 .522 .902 r
.60308 .55425 .60502 .55688 .60889 .55839 .60695 .55571 Metetra
.22 .471 .884 r
.60695 .55571 .60889 .55839 .61277 .56032 .61083 .55758 Metetra
.117 .401 .853 r
.61083 .55758 .61277 .56032 .61668 .56277 .61474 .55995 Metetra
0 .302 .797 r
.61474 .55995 .61668 .56277 .62062 .56589 .61868 .56299 Metetra
0 .164 .7 r
.61868 .56299 .62062 .56589 .6246 .5699 .62266 .5669 Metetra
0 0 .547 r
.62266 .5669 .6246 .5699 .62864 .57513 .62669 .57202 Metetra
.632 .214 0 r
.62669 .57202 .62864 .57513 .63275 .58208 .63079 .57884 Metetra
.802 .393 0 r
.63079 .57884 .63275 .58208 .63697 .59159 .63501 .58822 Metetra
.904 .522 .083 r
.63501 .58822 .63697 .59159 .64135 .60511 .63938 .60165 Metetra
.951 .602 .232 r
.63938 .60165 .64135 .60511 .64602 .62536 .64404 .62208 Metetra
.966 .644 .335 r
.64404 .62208 .64602 .62536 .65117 .65782 .64923 .65583 Metetra
.965 .662 .402 r
.64923 .65583 .65117 .65782 .65726 .71283 .65549 .71639 Metetra
.39 0 .168 r
.65549 .71639 .65726 .71283 .66153 .71731 .65956 .7153 Metetra
.645 .763 .934 r
.65956 .7153 .66153 .71731 .6656 .71622 .66364 .71422 Metetra
.645 .763 .934 r
.66364 .71422 .6656 .71622 .66945 .70962 .66772 .71313 Metetra
.986 .733 .46 r
.66772 .71313 .66945 .70962 .67116 .65232 .66923 .65031 Metetra
.963 .722 .526 r
.66923 .65031 .67116 .65232 .67372 .61754 .67176 .61423 Metetra
.94 .717 .573 r
.67176 .61423 .67372 .61754 .67674 .59497 .67479 .59148 Metetra
.921 .718 .612 r
.67479 .59148 .67674 .59497 .68003 .57913 .67809 .57572 Metetra
.903 .721 .647 r
.67809 .57572 .68003 .57913 .68348 .5673 .68156 .56402 Metetra
.886 .725 .677 r
.68156 .56402 .68348 .5673 .68703 .55803 .68512 .55487 Metetra
.869 .728 .704 r
.68512 .55487 .68703 .55803 .69065 .55047 .68875 .54742 Metetra
.854 .731 .727 r
.68875 .54742 .69065 .55047 .69433 .54414 .69244 .54118 Metetra
.84 .734 .747 r
.69244 .54118 .69433 .54414 .69804 .5387 .69616 .53582 Metetra
.826 .736 .765 r
.69616 .53582 .69804 .5387 .70178 .53393 .69991 .53111 Metetra
.814 .738 .78 r
.69991 .53111 .70178 .53393 .70555 .52968 .70368 .52691 Metetra
.803 .739 .792 r
.70368 .52691 .70555 .52968 .70934 .52584 .70748 .52312 Metetra
.793 .74 .804 r
.70748 .52312 .70934 .52584 .71315 .52233 .71129 .51965 Metetra
.783 .74 .813 r
.71129 .51965 .71315 .52233 .71697 .51909 .71512 .51645 Metetra
.775 .741 .822 r
.71512 .51645 .71697 .51909 .72081 .51607 .71897 .51346 Metetra
.767 .741 .829 r
.71897 .51346 .72081 .51607 .72465 .51324 .72282 .51065 Metetra
.76 .741 .836 r
.72282 .51065 .72465 .51324 .72851 .51056 .72669 .508 Metetra
.754 .741 .841 r
.72669 .508 .72851 .51056 .73238 .50803 .73056 .50548 Metetra
.748 .742 .846 r
.73056 .50548 .73238 .50803 .73626 .5056 .73445 .50308 Metetra
.742 .742 .851 r
.73445 .50308 .73626 .5056 .74015 .50328 .73834 .50077 Metetra
.738 .742 .855 r
.73834 .50077 .74015 .50328 .74405 .50105 .74224 .49855 Metetra
.733 .742 .858 r
.74224 .49855 .74405 .50105 .74796 .49889 .74615 .49641 Metetra
.729 .742 .862 r
.74615 .49641 .74796 .49889 .75187 .4968 .75007 .49433 Metetra
.725 .742 .865 r
.75007 .49433 .75187 .4968 .75579 .49477 .754 .49231 Metetra
.722 .742 .867 r
.754 .49231 .75579 .49477 .75972 .4928 .75793 .49035 Metetra
.719 .742 .87 r
.75793 .49035 .75972 .4928 .76365 .49087 .76187 .48843 Metetra
.716 .742 .872 r
.76187 .48843 .76365 .49087 .7676 .48899 .76582 .48655 Metetra
.713 .742 .874 r
.76582 .48655 .7676 .48899 .77155 .48714 .76977 .48471 Metetra
.711 .741 .876 r
.76977 .48471 .77155 .48714 .7755 .48534 .77373 .48291 Metetra
.708 .741 .877 r
.77373 .48291 .7755 .48534 .77947 .48356 .7777 .48113 Metetra
.706 .741 .879 r
.7777 .48113 .77947 .48356 .78344 .48181 .78168 .47939 Metetra
.704 .741 .88 r
.78168 .47939 .78344 .48181 .78741 .48009 .78566 .47767 Metetra
.702 .741 .882 r
.78566 .47767 .78741 .48009 .7914 .47839 .78964 .47597 Metetra
.701 .741 .883 r
.78964 .47597 .7914 .47839 .79539 .47671 .79364 .4743 Metetra
.699 .741 .884 r
.79364 .4743 .79539 .47671 .79938 .47506 .79764 .47265 Metetra
.697 .741 .885 r
.79764 .47265 .79938 .47506 .80338 .47342 .80164 .47101 Metetra
.696 .741 .886 r
.80164 .47101 .80338 .47342 .80739 .4718 .80566 .4694 Metetra
.695 .741 .887 r
.80566 .4694 .80739 .4718 .8114 .4702 .80967 .46779 Metetra
.693 .741 .888 r
.80967 .46779 .8114 .4702 .81542 .46861 .8137 .4662 Metetra
.692 .741 .889 r
.8137 .4662 .81542 .46861 .81945 .46703 .81773 .46463 Metetra
.691 .741 .889 r
.81773 .46463 .81945 .46703 .82348 .46547 .82177 .46307 Metetra
.69 .741 .89 r
.82177 .46307 .82348 .46547 .82752 .46392 .82581 .46151 Metetra
.689 .741 .891 r
.82581 .46151 .82752 .46392 .83157 .46237 .82986 .45997 Metetra
.688 .741 .891 r
.82986 .45997 .83157 .46237 .83562 .46084 .83391 .45844 Metetra
.687 .741 .892 r
.83391 .45844 .83562 .46084 .83967 .45932 .83797 .45692 Metetra
.687 .741 .893 r
.83797 .45692 .83967 .45932 .84374 .45781 .84204 .45541 Metetra
.686 .741 .893 r
.84204 .45541 .84374 .45781 .8478 .4563 .84611 .4539 Metetra
.685 .741 .894 r
.84611 .4539 .8478 .4563 .85188 .45481 .85019 .4524 Metetra
.684 .741 .894 r
.85019 .4524 .85188 .45481 .85596 .45332 .85428 .45091 Metetra
.684 .741 .894 r
.85428 .45091 .85596 .45332 .86005 .45183 .85837 .44943 Metetra
.683 .741 .895 r
.85837 .44943 .86005 .45183 .86414 .45035 .86247 .44795 Metetra
.682 .741 .895 r
.86247 .44795 .86414 .45035 .86824 .44888 .86657 .44648 Metetra
.682 .741 .896 r
.86657 .44648 .86824 .44888 .87234 .44741 .87068 .44501 Metetra
.681 .741 .896 r
.87068 .44501 .87234 .44741 .87645 .44595 .87479 .44354 Metetra
.681 .741 .896 r
.87479 .44354 .87645 .44595 .88057 .44449 .87891 .44209 Metetra
.68 .741 .897 r
.87891 .44209 .88057 .44449 .88469 .44304 .88304 .44063 Metetra
.68 .741 .897 r
.88304 .44063 .88469 .44304 .88882 .44159 .88717 .43918 Metetra
.679 .741 .897 r
.88717 .43918 .88882 .44159 .89295 .44015 .89131 .43773 Metetra
.679 .741 .898 r
.89131 .43773 .89295 .44015 .8971 .4387 .89546 .43629 Metetra
.678 .741 .898 r
.89546 .43629 .8971 .4387 .90124 .43726 .89961 .43485 Metetra
.678 .741 .898 r
.89961 .43485 .90124 .43726 .90539 .43583 .90377 .43341 Metetra
.678 .741 .898 r
.90377 .43341 .90539 .43583 .90955 .4344 .90793 .43198 Metetra
.677 .741 .899 r
.90793 .43198 .90955 .4344 .91372 .43297 .9121 .43054 Metetra
.677 .741 .899 r
.9121 .43054 .91372 .43297 .91789 .43154 .91627 .42911 Metetra
.676 .741 .899 r
.91627 .42911 .91789 .43154 .92206 .43011 .92046 .42769 Metetra
.676 .741 .899 r
.92046 .42769 .92206 .43011 .92625 .42869 .92464 .42626 Metetra
.676 .741 .9 r
.92464 .42626 .92625 .42869 .93044 .42727 .92884 .42484 Metetra
.676 .741 .9 r
.92884 .42484 .93044 .42727 .93463 .42585 .93303 .42341 Metetra
.675 .741 .9 r
.93303 .42341 .93463 .42585 .93883 .42443 .93724 .42199 Metetra
.675 .741 .9 r
.93724 .42199 .93883 .42443 .94304 .42301 .94145 .42057 Metetra
.675 .741 .9 r
.94145 .42057 .94304 .42301 .94725 .42159 .94567 .41916 Metetra
.674 .741 .901 r
.94567 .41916 .94725 .42159 .95147 .42018 .94989 .41774 Metetra
.674 .741 .901 r
.94989 .41774 .95147 .42018 .9557 .41877 .95412 .41632 Metetra
.65 .733 .91 r
.37996 .58812 .38206 .59013 .38553 .58919 .38343 .58718 Metetra
.65 .733 .91 r
.38343 .58718 .38553 .58919 .389 .58826 .3869 .58625 Metetra
.65 .733 .91 r
.3869 .58625 .389 .58826 .39247 .58733 .39038 .58531 Metetra
.649 .732 .91 r
.39038 .58531 .39247 .58733 .39595 .5864 .39386 .58438 Metetra
.649 .732 .91 r
.39386 .58438 .39595 .5864 .39944 .58547 .39735 .58344 Metetra
.649 .732 .91 r
.39735 .58344 .39944 .58547 .40293 .58455 .40084 .58252 Metetra
.648 .732 .91 r
.40084 .58252 .40293 .58455 .40642 .58362 .40434 .58159 Metetra
.648 .731 .91 r
.40434 .58159 .40642 .58362 .40992 .5827 .40784 .58066 Metetra
.648 .731 .91 r
.40784 .58066 .40992 .5827 .41342 .58178 .41135 .57974 Metetra
.647 .731 .91 r
.41135 .57974 .41342 .58178 .41693 .58086 .41486 .57882 Metetra
.647 .731 .91 r
.41486 .57882 .41693 .58086 .42045 .57995 .41838 .5779 Metetra
.646 .73 .91 r
.41838 .5779 .42045 .57995 .42396 .57904 .4219 .57699 Metetra
.646 .73 .91 r
.4219 .57699 .42396 .57904 .42749 .57813 .42542 .57607 Metetra
.645 .73 .91 r
.42542 .57607 .42749 .57813 .43101 .57723 .42895 .57517 Metetra
.645 .73 .91 r
.42895 .57517 .43101 .57723 .43455 .57633 .43249 .57426 Metetra
.644 .729 .91 r
.43249 .57426 .43455 .57633 .43808 .57543 .43603 .57336 Metetra
.644 .729 .911 r
.43603 .57336 .43808 .57543 .44163 .57454 .43957 .57246 Metetra
.643 .729 .911 r
.43957 .57246 .44163 .57454 .44517 .57365 .44312 .57157 Metetra
.642 .728 .911 r
.44312 .57157 .44517 .57365 .44872 .57277 .44668 .57068 Metetra
.642 .728 .911 r
.44668 .57068 .44872 .57277 .45228 .57189 .45024 .5698 Metetra
.641 .727 .911 r
.45024 .5698 .45228 .57189 .45584 .57101 .4538 .56892 Metetra
.64 .727 .911 r
.4538 .56892 .45584 .57101 .45941 .57015 .45737 .56805 Metetra
.64 .726 .911 r
.45737 .56805 .45941 .57015 .46298 .56928 .46095 .56718 Metetra
.639 .726 .911 r
.46095 .56718 .46298 .56928 .46656 .56843 .46453 .56632 Metetra
.638 .725 .911 r
.46453 .56632 .46656 .56843 .47014 .56758 .46811 .56546 Metetra
.637 .725 .911 r
.46811 .56546 .47014 .56758 .47373 .56674 .4717 .56462 Metetra
.636 .724 .912 r
.4717 .56462 .47373 .56674 .47732 .5659 .4753 .56378 Metetra
.635 .724 .912 r
.4753 .56378 .47732 .5659 .48092 .56508 .4789 .56295 Metetra
.634 .723 .912 r
.4789 .56295 .48092 .56508 .48452 .56426 .4825 .56212 Metetra
.633 .722 .912 r
.4825 .56212 .48452 .56426 .48813 .56345 .48611 .56131 Metetra
.632 .722 .912 r
.48611 .56131 .48813 .56345 .49174 .56265 .48973 .56051 Metetra
.63 .721 .912 r
.48973 .56051 .49174 .56265 .49536 .56187 .49335 .55971 Metetra
.629 .72 .913 r
.49335 .55971 .49536 .56187 .49898 .56109 .49698 .55893 Metetra
.627 .719 .913 r
.49698 .55893 .49898 .56109 .50261 .56033 .50061 .55816 Metetra
.626 .718 .913 r
.50061 .55816 .50261 .56033 .50625 .55958 .50425 .55741 Metetra
.624 .717 .913 r
.50425 .55741 .50625 .55958 .50989 .55885 .50789 .55667 Metetra
.622 .716 .913 r
.50789 .55667 .50989 .55885 .51353 .55813 .51154 .55594 Metetra
.62 .715 .914 r
.51154 .55594 .51353 .55813 .51719 .55743 .51519 .55523 Metetra
.618 .714 .914 r
.51519 .55523 .51719 .55743 .52084 .55675 .51885 .55454 Metetra
.616 .712 .914 r
.51885 .55454 .52084 .55675 .5245 .55608 .52252 .55387 Metetra
.613 .711 .915 r
.52252 .55387 .5245 .55608 .52817 .55544 .52619 .55322 Metetra
.61 .709 .915 r
.52619 .55322 .52817 .55544 .53185 .55483 .52987 .55259 Metetra
.607 .707 .915 r
.52987 .55259 .53185 .55483 .53553 .55424 .53355 .55199 Metetra
.604 .705 .916 r
.53355 .55199 .53553 .55424 .53922 .55368 .53724 .55142 Metetra
.6 .703 .916 r
.53724 .55142 .53922 .55368 .54291 .55315 .54093 .55088 Metetra
.596 .701 .916 r
.54093 .55088 .54291 .55315 .54661 .55265 .54464 .55037 Metetra
.591 .698 .917 r
.54464 .55037 .54661 .55265 .55032 .55219 .54835 .5499 Metetra
.586 .695 .917 r
.54835 .5499 .55032 .55219 .55403 .55178 .55206 .54948 Metetra
.581 .692 .918 r
.55206 .54948 .55403 .55178 .55775 .55141 .55578 .5491 Metetra
.574 .688 .919 r
.55578 .5491 .55775 .55141 .56148 .5511 .55951 .54877 Metetra
.567 .684 .919 r
.55951 .54877 .56148 .5511 .56521 .55085 .56325 .5485 Metetra
.559 .679 .92 r
.56325 .5485 .56521 .55085 .56895 .55066 .567 .54829 Metetra
.549 .674 .92 r
.567 .54829 .56895 .55066 .57271 .55055 .57075 .54816 Metetra
.538 .667 .921 r
.57075 .54816 .57271 .55055 .57646 .55052 .57451 .54811 Metetra
.525 .66 .921 r
.57451 .54811 .57646 .55052 .58023 .55059 .57828 .54816 Metetra
.51 .651 .921 r
.57828 .54816 .58023 .55059 .58401 .55078 .58206 .54832 Metetra
.491 .64 .921 r
.58206 .54832 .58401 .55078 .5878 .5511 .58585 .54861 Metetra
.469 .627 .921 r
.58585 .54861 .5878 .5511 .5916 .55157 .58966 .54905 Metetra
.442 .611 .92 r
.58966 .54905 .5916 .55157 .59541 .55223 .59347 .54967 Metetra
.409 .59 .917 r
.59347 .54967 .59541 .55223 .59924 .55311 .5973 .55051 Metetra
.366 .563 .912 r
.5973 .55051 .59924 .55311 .60308 .55425 .60114 .5516 Metetra
.31 .528 .903 r
.60114 .5516 .60308 .55425 .60695 .55571 .605 .553 Metetra
.238 .48 .887 r
.605 .553 .60695 .55571 .61083 .55758 .60888 .55481 Metetra
.14 .413 .858 r
.60888 .55481 .61083 .55758 .61474 .55995 .61279 .5571 Metetra
.008 .319 .807 r
.61279 .5571 .61474 .55995 .61868 .56299 .61673 .56005 Metetra
0 .187 .719 r
.61673 .56005 .61868 .56299 .62266 .5669 .62071 .56385 Metetra
0 .013 .575 r
.62071 .56385 .62266 .5669 .62669 .57202 .62473 .56883 Metetra
0 0 .374 r
.62473 .56883 .62669 .57202 .63079 .57884 .62883 .57548 Metetra
.78 .374 0 r
.62883 .57548 .63079 .57884 .63501 .58822 .63303 .58466 Metetra
.894 .513 .059 r
.63303 .58466 .63501 .58822 .63938 .60165 .6374 .59789 Metetra
.949 .6 .216 r
.6374 .59789 .63938 .60165 .64404 .62208 .64204 .61823 Metetra
.968 .647 .326 r
.64204 .61823 .64404 .62208 .64923 .65583 .64724 .65268 Metetra
.968 .666 .393 r
.64724 .65268 .64923 .65583 .65549 .71639 .65352 .71439 Metetra
.645 .763 .934 r
.65352 .71439 .65549 .71639 .65956 .7153 .65759 .7133 Metetra
.645 .763 .934 r
.65759 .7133 .65956 .7153 .66364 .71422 .66166 .71221 Metetra
.645 .763 .934 r
.66166 .71221 .66364 .71422 .66772 .71313 .66575 .71112 Metetra
.965 .708 .495 r
.66575 .71112 .66772 .71313 .66923 .65031 .66726 .64714 Metetra
.954 .711 .532 r
.66726 .64714 .66923 .65031 .67176 .61423 .66977 .61036 Metetra
.932 .709 .577 r
.66977 .61036 .67176 .61423 .67479 .59148 .67282 .58769 Metetra
.914 .712 .615 r
.67282 .58769 .67479 .59148 .67809 .57572 .67614 .57213 Metetra
.897 .716 .649 r
.67614 .57213 .67809 .57572 .68156 .56402 .67962 .56061 Metetra
.881 .721 .679 r
.67962 .56061 .68156 .56402 .68512 .55487 .6832 .55162 Metetra
.865 .725 .705 r
.6832 .55162 .68512 .55487 .68875 .54742 .68684 .54431 Metetra
.85 .729 .728 r
.68684 .54431 .68875 .54742 .69244 .54118 .69054 .53818 Metetra
.836 .731 .748 r
.69054 .53818 .69244 .54118 .69616 .53582 .69427 .5329 Metetra
.823 .734 .766 r
.69427 .5329 .69616 .53582 .69991 .53111 .69803 .52826 Metetra
.811 .736 .781 r
.69803 .52826 .69991 .53111 .70368 .52691 .70181 .52413 Metetra
.8 .737 .793 r
.70181 .52413 .70368 .52691 .70748 .52312 .70562 .52039 Metetra
.79 .738 .804 r
.70562 .52039 .70748 .52312 .71129 .51965 .70944 .51696 Metetra
.781 .739 .814 r
.70944 .51696 .71129 .51965 .71512 .51645 .71327 .51379 Metetra
.773 .74 .822 r
.71327 .51379 .71512 .51645 .71897 .51346 .71712 .51083 Metetra
.765 .74 .83 r
.71712 .51083 .71897 .51346 .72282 .51065 .72098 .50806 Metetra
.758 .74 .836 r
.72098 .50806 .72282 .51065 .72669 .508 .72485 .50543 Metetra
.752 .741 .842 r
.72485 .50543 .72669 .508 .73056 .50548 .72873 .50293 Metetra
.746 .741 .847 r
.72873 .50293 .73056 .50548 .73445 .50308 .73262 .50055 Metetra
.741 .741 .851 r
.73262 .50055 .73445 .50308 .73834 .50077 .73652 .49826 Metetra
.736 .741 .855 r
.73652 .49826 .73834 .50077 .74224 .49855 .74043 .49605 Metetra
.732 .741 .859 r
.74043 .49605 .74224 .49855 .74615 .49641 .74435 .49392 Metetra
.728 .741 .862 r
.74435 .49392 .74615 .49641 .75007 .49433 .74827 .49185 Metetra
.724 .741 .865 r
.74827 .49185 .75007 .49433 .754 .49231 .7522 .48984 Metetra
.721 .741 .868 r
.7522 .48984 .754 .49231 .75793 .49035 .75614 .48788 Metetra
.718 .741 .87 r
.75614 .48788 .75793 .49035 .76187 .48843 .76008 .48597 Metetra
.715 .741 .872 r
.76008 .48597 .76187 .48843 .76582 .48655 .76404 .4841 Metetra
.712 .741 .874 r
.76404 .4841 .76582 .48655 .76977 .48471 .76799 .48227 Metetra
.71 .741 .876 r
.76799 .48227 .76977 .48471 .77373 .48291 .77196 .48047 Metetra
.708 .741 .878 r
.77196 .48047 .77373 .48291 .7777 .48113 .77593 .4787 Metetra
.706 .741 .879 r
.77593 .4787 .7777 .48113 .78168 .47939 .77991 .47696 Metetra
.704 .741 .88 r
.77991 .47696 .78168 .47939 .78566 .47767 .7839 .47525 Metetra
.702 .741 .882 r
.7839 .47525 .78566 .47767 .78964 .47597 .78789 .47355 Metetra
.7 .741 .883 r
.78789 .47355 .78964 .47597 .79364 .4743 .79189 .47188 Metetra
.699 .741 .884 r
.79189 .47188 .79364 .4743 .79764 .47265 .79589 .47023 Metetra
.697 .741 .885 r
.79589 .47023 .79764 .47265 .80164 .47101 .7999 .4686 Metetra
.696 .741 .886 r
.7999 .4686 .80164 .47101 .80566 .4694 .80392 .46698 Metetra
.694 .741 .887 r
.80392 .46698 .80566 .4694 .80967 .46779 .80794 .46538 Metetra
.693 .741 .888 r
.80794 .46538 .80967 .46779 .8137 .4662 .81197 .46379 Metetra
.692 .741 .889 r
.81197 .46379 .8137 .4662 .81773 .46463 .81601 .46222 Metetra
.691 .741 .889 r
.81601 .46222 .81773 .46463 .82177 .46307 .82005 .46066 Metetra
.69 .741 .89 r
.82005 .46066 .82177 .46307 .82581 .46151 .82409 .45911 Metetra
.689 .741 .891 r
.82409 .45911 .82581 .46151 .82986 .45997 .82815 .45757 Metetra
.688 .741 .891 r
.82815 .45757 .82986 .45997 .83391 .45844 .83221 .45604 Metetra
.687 .741 .892 r
.83221 .45604 .83391 .45844 .83797 .45692 .83627 .45451 Metetra
.686 .741 .893 r
.83627 .45451 .83797 .45692 .84204 .45541 .84034 .453 Metetra
.685 .741 .893 r
.84034 .453 .84204 .45541 .84611 .4539 .84442 .4515 Metetra
.685 .741 .894 r
.84442 .4515 .84611 .4539 .85019 .4524 .8485 .45 Metetra
.684 .741 .894 r
.8485 .45 .85019 .4524 .85428 .45091 .85259 .4485 Metetra
.683 .741 .895 r
.85259 .4485 .85428 .45091 .85837 .44943 .85669 .44702 Metetra
.683 .741 .895 r
.85669 .44702 .85837 .44943 .86247 .44795 .86079 .44554 Metetra
.682 .741 .895 r
.86079 .44554 .86247 .44795 .86657 .44648 .8649 .44406 Metetra
.682 .741 .896 r
.8649 .44406 .86657 .44648 .87068 .44501 .86901 .4426 Metetra
.681 .741 .896 r
.86901 .4426 .87068 .44501 .87479 .44354 .87313 .44113 Metetra
.68 .741 .896 r
.87313 .44113 .87479 .44354 .87891 .44209 .87726 .43967 Metetra
.68 .741 .897 r
.87726 .43967 .87891 .44209 .88304 .44063 .88139 .43821 Metetra
.68 .741 .897 r
.88139 .43821 .88304 .44063 .88717 .43918 .88552 .43676 Metetra
.679 .741 .897 r
.88552 .43676 .88717 .43918 .89131 .43773 .88967 .43531 Metetra
.679 .741 .898 r
.88967 .43531 .89131 .43773 .89546 .43629 .89382 .43387 Metetra
.678 .741 .898 r
.89382 .43387 .89546 .43629 .89961 .43485 .89797 .43243 Metetra
.678 .741 .898 r
.89797 .43243 .89961 .43485 .90377 .43341 .90213 .43099 Metetra
.677 .741 .898 r
.90213 .43099 .90377 .43341 .90793 .43198 .9063 .42955 Metetra
.677 .741 .899 r
.9063 .42955 .90793 .43198 .9121 .43054 .91048 .42812 Metetra
.677 .741 .899 r
.91048 .42812 .9121 .43054 .91627 .42911 .91466 .42668 Metetra
.676 .741 .899 r
.91466 .42668 .91627 .42911 .92046 .42769 .91884 .42525 Metetra
.676 .741 .899 r
.91884 .42525 .92046 .42769 .92464 .42626 .92303 .42383 Metetra
.676 .741 .9 r
.92303 .42383 .92464 .42626 .92884 .42484 .92723 .4224 Metetra
.675 .741 .9 r
.92723 .4224 .92884 .42484 .93303 .42341 .93143 .42098 Metetra
.675 .741 .9 r
.93143 .42098 .93303 .42341 .93724 .42199 .93564 .41955 Metetra
.675 .741 .9 r
.93564 .41955 .93724 .42199 .94145 .42057 .93986 .41813 Metetra
.675 .741 .9 r
.93986 .41813 .94145 .42057 .94567 .41916 .94408 .41671 Metetra
.674 .741 .901 r
.94408 .41671 .94567 .41916 .94989 .41774 .94831 .41529 Metetra
.674 .741 .901 r
.94831 .41529 .94989 .41774 .95412 .41632 .95255 .41387 Metetra
.651 .733 .91 r
.37786 .58611 .37996 .58812 .38343 .58718 .38133 .58517 Metetra
.65 .733 .91 r
.38133 .58517 .38343 .58718 .3869 .58625 .3848 .58423 Metetra
.65 .733 .91 r
.3848 .58423 .3869 .58625 .39038 .58531 .38828 .58329 Metetra
.65 .732 .91 r
.38828 .58329 .39038 .58531 .39386 .58438 .39177 .58235 Metetra
.649 .732 .91 r
.39177 .58235 .39386 .58438 .39735 .58344 .39526 .58141 Metetra
.649 .732 .91 r
.39526 .58141 .39735 .58344 .40084 .58252 .39876 .58048 Metetra
.649 .732 .91 r
.39876 .58048 .40084 .58252 .40434 .58159 .40226 .57955 Metetra
.648 .732 .91 r
.40226 .57955 .40434 .58159 .40784 .58066 .40576 .57862 Metetra
.648 .731 .91 r
.40576 .57862 .40784 .58066 .41135 .57974 .40927 .57769 Metetra
.647 .731 .91 r
.40927 .57769 .41135 .57974 .41486 .57882 .41278 .57677 Metetra
.647 .731 .91 r
.41278 .57677 .41486 .57882 .41838 .5779 .4163 .57585 Metetra
.646 .73 .91 r
.4163 .57585 .41838 .5779 .4219 .57699 .41982 .57493 Metetra
.646 .73 .91 r
.41982 .57493 .4219 .57699 .42542 .57607 .42335 .57401 Metetra
.646 .73 .91 r
.42335 .57401 .42542 .57607 .42895 .57517 .42689 .5731 Metetra
.645 .73 .91 r
.42689 .5731 .42895 .57517 .43249 .57426 .43042 .57219 Metetra
.644 .729 .91 r
.43042 .57219 .43249 .57426 .43603 .57336 .43397 .57128 Metetra
.644 .729 .91 r
.43397 .57128 .43603 .57336 .43957 .57246 .43751 .57038 Metetra
.643 .729 .911 r
.43751 .57038 .43957 .57246 .44312 .57157 .44107 .56949 Metetra
.643 .728 .911 r
.44107 .56949 .44312 .57157 .44668 .57068 .44463 .56859 Metetra
.642 .728 .911 r
.44463 .56859 .44668 .57068 .45024 .5698 .44819 .5677 Metetra
.641 .727 .911 r
.44819 .5677 .45024 .5698 .4538 .56892 .45176 .56682 Metetra
.641 .727 .911 r
.45176 .56682 .4538 .56892 .45737 .56805 .45533 .56594 Metetra
.64 .726 .911 r
.45533 .56594 .45737 .56805 .46095 .56718 .45891 .56507 Metetra
.639 .726 .911 r
.45891 .56507 .46095 .56718 .46453 .56632 .46249 .56421 Metetra
.638 .725 .911 r
.46249 .56421 .46453 .56632 .46811 .56546 .46608 .56335 Metetra
.637 .725 .911 r
.46608 .56335 .46811 .56546 .4717 .56462 .46967 .56249 Metetra
.636 .724 .911 r
.46967 .56249 .4717 .56462 .4753 .56378 .47327 .56165 Metetra
.635 .724 .912 r
.47327 .56165 .4753 .56378 .4789 .56295 .47687 .56081 Metetra
.634 .723 .912 r
.47687 .56081 .4789 .56295 .4825 .56212 .48048 .55998 Metetra
.633 .722 .912 r
.48048 .55998 .4825 .56212 .48611 .56131 .48409 .55916 Metetra
.632 .722 .912 r
.48409 .55916 .48611 .56131 .48973 .56051 .48771 .55835 Metetra
.631 .721 .912 r
.48771 .55835 .48973 .56051 .49335 .55971 .49133 .55755 Metetra
.629 .72 .912 r
.49133 .55755 .49335 .55971 .49698 .55893 .49496 .55676 Metetra
.628 .719 .913 r
.49496 .55676 .49698 .55893 .50061 .55816 .4986 .55599 Metetra
.626 .718 .913 r
.4986 .55599 .50061 .55816 .50425 .55741 .50224 .55523 Metetra
.625 .717 .913 r
.50224 .55523 .50425 .55741 .50789 .55667 .50588 .55448 Metetra
.623 .716 .913 r
.50588 .55448 .50789 .55667 .51154 .55594 .50954 .55374 Metetra
.621 .715 .913 r
.50954 .55374 .51154 .55594 .51519 .55523 .51319 .55303 Metetra
.619 .714 .914 r
.51319 .55303 .51519 .55523 .51885 .55454 .51685 .55233 Metetra
.616 .712 .914 r
.51685 .55233 .51885 .55454 .52252 .55387 .52052 .55165 Metetra
.614 .711 .914 r
.52052 .55165 .52252 .55387 .52619 .55322 .5242 .55099 Metetra
.611 .709 .915 r
.5242 .55099 .52619 .55322 .52987 .55259 .52788 .55035 Metetra
.608 .708 .915 r
.52788 .55035 .52987 .55259 .53355 .55199 .53156 .54974 Metetra
.605 .706 .915 r
.53156 .54974 .53355 .55199 .53724 .55142 .53526 .54916 Metetra
.601 .704 .916 r
.53526 .54916 .53724 .55142 .54093 .55088 .53895 .54861 Metetra
.597 .701 .916 r
.53895 .54861 .54093 .55088 .54464 .55037 .54266 .54809 Metetra
.593 .699 .917 r
.54266 .54809 .54464 .55037 .54835 .5499 .54637 .54761 Metetra
.588 .696 .917 r
.54637 .54761 .54835 .5499 .55206 .54948 .55009 .54717 Metetra
.582 .693 .917 r
.55009 .54717 .55206 .54948 .55578 .5491 .55381 .54677 Metetra
.576 .689 .918 r
.55381 .54677 .55578 .5491 .55951 .54877 .55755 .54643 Metetra
.569 .685 .918 r
.55755 .54643 .55951 .54877 .56325 .5485 .56129 .54614 Metetra
.561 .68 .919 r
.56129 .54614 .56325 .5485 .567 .54829 .56503 .54591 Metetra
.552 .675 .92 r
.56503 .54591 .567 .54829 .57075 .54816 .56879 .54576 Metetra
.541 .668 .92 r
.56879 .54576 .57075 .54816 .57451 .54811 .57255 .54569 Metetra
.528 .661 .92 r
.57255 .54569 .57451 .54811 .57828 .54816 .57633 .54572 Metetra
.514 .652 .921 r
.57633 .54572 .57828 .54816 .58206 .54832 .58011 .54585 Metetra
.496 .642 .921 r
.58011 .54585 .58206 .54832 .58585 .54861 .5839 .54611 Metetra
.475 .629 .92 r
.5839 .54611 .58585 .54861 .58966 .54905 .5877 .54652 Metetra
.449 .613 .919 r
.5877 .54652 .58966 .54905 .59347 .54967 .59152 .5471 Metetra
.417 .593 .917 r
.59152 .5471 .59347 .54967 .5973 .55051 .59535 .54789 Metetra
.376 .568 .912 r
.59535 .54789 .5973 .55051 .60114 .5516 .59919 .54893 Metetra
.324 .534 .904 r
.59919 .54893 .60114 .5516 .605 .553 .60305 .55028 Metetra
.255 .489 .889 r
.60305 .55028 .605 .553 .60888 .55481 .60694 .55201 Metetra
.162 .426 .863 r
.60694 .55201 .60888 .55481 .61279 .5571 .61084 .55422 Metetra
.037 .337 .817 r
.61084 .55422 .61279 .5571 .61673 .56005 .61478 .55706 Metetra
0 .211 .737 r
.61478 .55706 .61673 .56005 .62071 .56385 .61875 .56074 Metetra
0 .043 .603 r
.61875 .56074 .62071 .56385 .62473 .56883 .62277 .56556 Metetra
0 0 .41 r
.62277 .56556 .62473 .56883 .62883 .57548 .62686 .57202 Metetra
.754 .351 0 r
.62686 .57202 .62883 .57548 .63303 .58466 .63105 .58095 Metetra
.881 .5 .031 r
.63105 .58095 .63303 .58466 .6374 .59789 .6354 .59386 Metetra
.945 .596 .198 r
.6354 .59386 .6374 .59789 .64204 .61823 .64002 .61386 Metetra
.969 .648 .315 r
.64002 .61386 .64204 .61823 .64724 .65268 .6452 .64836 Metetra
.972 .67 .385 r
.6452 .64836 .64724 .65268 .65352 .71439 .65153 .71238 Metetra
.645 .763 .934 r
.65153 .71238 .65352 .71439 .65759 .7133 .65561 .71129 Metetra
.645 .763 .934 r
.65561 .71129 .65759 .7133 .66166 .71221 .65969 .71019 Metetra
.645 .763 .934 r
.65969 .71019 .66166 .71221 .66575 .71112 .66378 .7091 Metetra
.965 .707 .493 r
.66378 .7091 .66575 .71112 .66726 .64714 .66523 .64281 Metetra
.944 .701 .539 r
.66523 .64281 .66726 .64714 .66977 .61036 .66776 .60597 Metetra
.925 .701 .581 r
.66776 .60597 .66977 .61036 .67282 .58769 .67084 .58363 Metetra
.908 .706 .618 r
.67084 .58363 .67282 .58769 .67614 .57213 .67418 .56838 Metetra
.892 .711 .651 r
.67418 .56838 .67614 .57213 .67962 .56061 .67768 .55711 Metetra
.876 .717 .681 r
.67768 .55711 .67962 .56061 .6832 .55162 .68127 .54831 Metetra
.861 .722 .707 r
.68127 .54831 .6832 .55162 .68684 .54431 .68493 .54115 Metetra
.847 .726 .73 r
.68493 .54115 .68684 .54431 .69054 .53818 .68864 .53513 Metetra
.833 .729 .75 r
.68864 .53513 .69054 .53818 .69427 .5329 .69238 .52995 Metetra
.82 .732 .767 r
.69238 .52995 .69427 .5329 .69803 .52826 .69615 .52539 Metetra
.809 .734 .782 r
.69615 .52539 .69803 .52826 .70181 .52413 .69994 .52132 Metetra
.798 .736 .794 r
.69994 .52132 .70181 .52413 .70562 .52039 .70375 .51763 Metetra
.788 .737 .805 r
.70375 .51763 .70562 .52039 .70944 .51696 .70758 .51425 Metetra
.779 .738 .815 r
.70758 .51425 .70944 .51696 .71327 .51379 .71142 .51112 Metetra
.771 .738 .823 r
.71142 .51112 .71327 .51379 .71712 .51083 .71527 .5082 Metetra
.763 .739 .83 r
.71527 .5082 .71712 .51083 .72098 .50806 .71914 .50545 Metetra
.757 .739 .837 r
.71914 .50545 .72098 .50806 .72485 .50543 .72301 .50285 Metetra
.751 .74 .842 r
.72301 .50285 .72485 .50543 .72873 .50293 .7269 .50037 Metetra
.745 .74 .847 r
.7269 .50037 .72873 .50293 .73262 .50055 .7308 .498 Metetra
.74 .74 .852 r
.7308 .498 .73262 .50055 .73652 .49826 .7347 .49573 Metetra
.735 .74 .856 r
.7347 .49573 .73652 .49826 .74043 .49605 .73861 .49354 Metetra
.731 .741 .859 r
.73861 .49354 .74043 .49605 .74435 .49392 .74253 .49142 Metetra
.727 .741 .862 r
.74253 .49142 .74435 .49392 .74827 .49185 .74646 .48936 Metetra
.723 .741 .865 r
.74646 .48936 .74827 .49185 .7522 .48984 .7504 .48736 Metetra
.72 .741 .868 r
.7504 .48736 .7522 .48984 .75614 .48788 .75434 .48541 Metetra
.717 .741 .87 r
.75434 .48541 .75614 .48788 .76008 .48597 .75829 .48351 Metetra
.714 .741 .872 r
.75829 .48351 .76008 .48597 .76404 .4841 .76225 .48165 Metetra
.712 .741 .874 r
.76225 .48165 .76404 .4841 .76799 .48227 .76621 .47982 Metetra
.709 .741 .876 r
.76621 .47982 .76799 .48227 .77196 .48047 .77018 .47803 Metetra
.707 .741 .878 r
.77018 .47803 .77196 .48047 .77593 .4787 .77416 .47626 Metetra
.705 .741 .879 r
.77416 .47626 .77593 .4787 .77991 .47696 .77814 .47453 Metetra
.703 .741 .881 r
.77814 .47453 .77991 .47696 .7839 .47525 .78213 .47281 Metetra
.701 .741 .882 r
.78213 .47281 .7839 .47525 .78789 .47355 .78613 .47113 Metetra
.7 .741 .883 r
.78613 .47113 .78789 .47355 .79189 .47188 .79013 .46946 Metetra
.698 .741 .884 r
.79013 .46946 .79189 .47188 .79589 .47023 .79414 .46781 Metetra
.697 .741 .885 r
.79414 .46781 .79589 .47023 .7999 .4686 .79815 .46618 Metetra
.695 .741 .886 r
.79815 .46618 .7999 .4686 .80392 .46698 .80218 .46456 Metetra
.694 .741 .887 r
.80218 .46456 .80392 .46698 .80794 .46538 .8062 .46297 Metetra
.693 .741 .888 r
.8062 .46297 .80794 .46538 .81197 .46379 .81024 .46138 Metetra
.692 .741 .889 r
.81024 .46138 .81197 .46379 .81601 .46222 .81428 .45981 Metetra
.691 .741 .89 r
.81428 .45981 .81601 .46222 .82005 .46066 .81832 .45824 Metetra
.69 .741 .89 r
.81832 .45824 .82005 .46066 .82409 .45911 .82237 .45669 Metetra
.689 .741 .891 r
.82237 .45669 .82409 .45911 .82815 .45757 .82643 .45515 Metetra
.688 .741 .892 r
.82643 .45515 .82815 .45757 .83221 .45604 .83049 .45362 Metetra
.687 .741 .892 r
.83049 .45362 .83221 .45604 .83627 .45451 .83456 .4521 Metetra
.686 .741 .893 r
.83456 .4521 .83627 .45451 .84034 .453 .83864 .45059 Metetra
.685 .741 .893 r
.83864 .45059 .84034 .453 .84442 .4515 .84272 .44908 Metetra
.685 .741 .894 r
.84272 .44908 .84442 .4515 .8485 .45 .84681 .44758 Metetra
.684 .741 .894 r
.84681 .44758 .8485 .45 .85259 .4485 .8509 .44609 Metetra
.683 .741 .895 r
.8509 .44609 .85259 .4485 .85669 .44702 .855 .4446 Metetra
.683 .741 .895 r
.855 .4446 .85669 .44702 .86079 .44554 .85911 .44312 Metetra
.682 .741 .895 r
.85911 .44312 .86079 .44554 .8649 .44406 .86322 .44165 Metetra
.681 .741 .896 r
.86322 .44165 .8649 .44406 .86901 .4426 .86734 .44018 Metetra
.681 .741 .896 r
.86734 .44018 .86901 .4426 .87313 .44113 .87146 .43871 Metetra
.68 .741 .897 r
.87146 .43871 .87313 .44113 .87726 .43967 .87559 .43725 Metetra
.68 .741 .897 r
.87559 .43725 .87726 .43967 .88139 .43821 .87973 .43579 Metetra
.679 .741 .897 r
.87973 .43579 .88139 .43821 .88552 .43676 .88387 .43434 Metetra
.679 .741 .897 r
.88387 .43434 .88552 .43676 .88967 .43531 .88802 .43289 Metetra
.678 .741 .898 r
.88802 .43289 .88967 .43531 .89382 .43387 .89217 .43144 Metetra
.678 .741 .898 r
.89217 .43144 .89382 .43387 .89797 .43243 .89633 .43 Metetra
.678 .741 .898 r
.89633 .43 .89797 .43243 .90213 .43099 .9005 .42856 Metetra
.677 .741 .899 r
.9005 .42856 .90213 .43099 .9063 .42955 .90467 .42712 Metetra
.677 .741 .899 r
.90467 .42712 .9063 .42955 .91048 .42812 .90885 .42568 Metetra
.677 .741 .899 r
.90885 .42568 .91048 .42812 .91466 .42668 .91303 .42425 Metetra
.676 .741 .899 r
.91303 .42425 .91466 .42668 .91884 .42525 .91722 .42282 Metetra
.676 .741 .899 r
.91722 .42282 .91884 .42525 .92303 .42383 .92142 .42139 Metetra
.676 .741 .9 r
.92142 .42139 .92303 .42383 .92723 .4224 .92562 .41996 Metetra
.675 .741 .9 r
.92562 .41996 .92723 .4224 .93143 .42098 .92983 .41853 Metetra
.675 .741 .9 r
.92983 .41853 .93143 .42098 .93564 .41955 .93404 .41711 Metetra
.675 .741 .9 r
.93404 .41711 .93564 .41955 .93986 .41813 .93827 .41568 Metetra
.674 .741 .9 r
.93827 .41568 .93986 .41813 .94408 .41671 .94249 .41426 Metetra
.674 .741 .901 r
.94249 .41426 .94408 .41671 .94831 .41529 .94672 .41284 Metetra
.674 .741 .901 r
.94672 .41284 .94831 .41529 .95255 .41387 .95096 .41142 Metetra
.651 .733 .91 r
.37575 .58409 .37786 .58611 .38133 .58517 .37922 .58314 Metetra
.65 .733 .91 r
.37922 .58314 .38133 .58517 .3848 .58423 .3827 .5822 Metetra
.65 .733 .91 r
.3827 .5822 .3848 .58423 .38828 .58329 .38618 .58126 Metetra
.65 .732 .91 r
.38618 .58126 .38828 .58329 .39177 .58235 .38967 .58032 Metetra
.649 .732 .91 r
.38967 .58032 .39177 .58235 .39526 .58141 .39316 .57938 Metetra
.649 .732 .91 r
.39316 .57938 .39526 .58141 .39876 .58048 .39666 .57844 Metetra
.649 .732 .91 r
.39666 .57844 .39876 .58048 .40226 .57955 .40016 .57751 Metetra
.648 .732 .91 r
.40016 .57751 .40226 .57955 .40576 .57862 .40367 .57657 Metetra
.648 .731 .91 r
.40367 .57657 .40576 .57862 .40927 .57769 .40718 .57564 Metetra
.648 .731 .91 r
.40718 .57564 .40927 .57769 .41278 .57677 .4107 .57471 Metetra
.647 .731 .91 r
.4107 .57471 .41278 .57677 .4163 .57585 .41422 .57379 Metetra
.647 .731 .91 r
.41422 .57379 .4163 .57585 .41982 .57493 .41775 .57286 Metetra
.646 .73 .91 r
.41775 .57286 .41982 .57493 .42335 .57401 .42128 .57194 Metetra
.646 .73 .91 r
.42128 .57194 .42335 .57401 .42689 .5731 .42482 .57103 Metetra
.645 .73 .91 r
.42482 .57103 .42689 .5731 .43042 .57219 .42836 .57011 Metetra
.645 .729 .91 r
.42836 .57011 .43042 .57219 .43397 .57128 .4319 .5692 Metetra
.644 .729 .91 r
.4319 .5692 .43397 .57128 .43751 .57038 .43545 .5683 Metetra
.644 .729 .91 r
.43545 .5683 .43751 .57038 .44107 .56949 .43901 .5674 Metetra
.643 .728 .911 r
.43901 .5674 .44107 .56949 .44463 .56859 .44257 .5665 Metetra
.642 .728 .911 r
.44257 .5665 .44463 .56859 .44819 .5677 .44613 .56561 Metetra
.642 .727 .911 r
.44613 .56561 .44819 .5677 .45176 .56682 .4497 .56472 Metetra
.641 .727 .911 r
.4497 .56472 .45176 .56682 .45533 .56594 .45328 .56383 Metetra
.64 .727 .911 r
.45328 .56383 .45533 .56594 .45891 .56507 .45686 .56296 Metetra
.639 .726 .911 r
.45686 .56296 .45891 .56507 .46249 .56421 .46044 .56209 Metetra
.639 .726 .911 r
.46044 .56209 .46249 .56421 .46608 .56335 .46404 .56122 Metetra
.638 .725 .911 r
.46404 .56122 .46608 .56335 .46967 .56249 .46763 .56036 Metetra
.637 .724 .911 r
.46763 .56036 .46967 .56249 .47327 .56165 .47123 .55951 Metetra
.636 .724 .911 r
.47123 .55951 .47327 .56165 .47687 .56081 .47484 .55867 Metetra
.635 .723 .912 r
.47484 .55867 .47687 .56081 .48048 .55998 .47845 .55783 Metetra
.634 .723 .912 r
.47845 .55783 .48048 .55998 .48409 .55916 .48206 .55701 Metetra
.632 .722 .912 r
.48206 .55701 .48409 .55916 .48771 .55835 .48569 .55619 Metetra
.631 .721 .912 r
.48569 .55619 .48771 .55835 .49133 .55755 .48931 .55539 Metetra
.63 .72 .912 r
.48931 .55539 .49133 .55755 .49496 .55676 .49295 .55459 Metetra
.628 .719 .912 r
.49295 .55459 .49496 .55676 .4986 .55599 .49658 .55381 Metetra
.627 .718 .913 r
.49658 .55381 .4986 .55599 .50224 .55523 .50023 .55304 Metetra
.625 .717 .913 r
.50023 .55304 .50224 .55523 .50588 .55448 .50387 .55228 Metetra
.623 .716 .913 r
.50387 .55228 .50588 .55448 .50954 .55374 .50753 .55154 Metetra
.621 .715 .913 r
.50753 .55154 .50954 .55374 .51319 .55303 .51119 .55082 Metetra
.619 .714 .913 r
.51119 .55082 .51319 .55303 .51685 .55233 .51485 .55011 Metetra
.617 .713 .914 r
.51485 .55011 .51685 .55233 .52052 .55165 .51853 .54942 Metetra
.615 .711 .914 r
.51853 .54942 .52052 .55165 .5242 .55099 .5222 .54875 Metetra
.612 .71 .914 r
.5222 .54875 .5242 .55099 .52788 .55035 .52588 .54811 Metetra
.609 .708 .915 r
.52588 .54811 .52788 .55035 .53156 .54974 .52957 .54749 Metetra
.606 .706 .915 r
.52957 .54749 .53156 .54974 .53526 .54916 .53327 .54689 Metetra
.602 .704 .915 r
.53327 .54689 .53526 .54916 .53895 .54861 .53697 .54633 Metetra
.598 .702 .916 r
.53697 .54633 .53895 .54861 .54266 .54809 .54068 .5458 Metetra
.594 .699 .916 r
.54068 .5458 .54266 .54809 .54637 .54761 .54439 .5453 Metetra
.589 .696 .917 r
.54439 .5453 .54637 .54761 .55009 .54717 .54811 .54485 Metetra
.584 .693 .917 r
.54811 .54485 .55009 .54717 .55381 .54677 .55184 .54444 Metetra
.578 .689 .917 r
.55184 .54444 .55381 .54677 .55755 .54643 .55558 .54408 Metetra
.571 .685 .918 r
.55558 .54408 .55755 .54643 .56129 .54614 .55932 .54377 Metetra
.563 .681 .918 r
.55932 .54377 .56129 .54614 .56503 .54591 .56307 .54353 Metetra
.554 .675 .919 r
.56307 .54353 .56503 .54591 .56879 .54576 .56682 .54336 Metetra
.544 .669 .919 r
.56682 .54336 .56879 .54576 .57255 .54569 .57059 .54326 Metetra
.532 .662 .92 r
.57059 .54326 .57255 .54569 .57633 .54572 .57437 .54326 Metetra
.518 .654 .92 r
.57437 .54326 .57633 .54572 .58011 .54585 .57815 .54337 Metetra
.501 .644 .92 r
.57815 .54337 .58011 .54585 .5839 .54611 .58194 .5436 Metetra
.481 .631 .919 r
.58194 .5436 .5839 .54611 .5877 .54652 .58575 .54397 Metetra
.456 .616 .918 r
.58575 .54397 .5877 .54652 .59152 .5471 .58957 .54451 Metetra
.425 .597 .916 r
.58957 .54451 .59152 .5471 .59535 .54789 .5934 .54526 Metetra
.386 .573 .912 r
.5934 .54526 .59535 .54789 .59919 .54893 .59724 .54624 Metetra
.337 .541 .905 r
.59724 .54624 .59919 .54893 .60305 .55028 .6011 .54753 Metetra
.271 .498 .891 r
.6011 .54753 .60305 .55028 .60694 .55201 .60498 .54919 Metetra
.184 .438 .868 r
.60498 .54919 .60694 .55201 .61084 .55422 .60889 .55131 Metetra
.067 .354 .827 r
.60889 .55131 .61084 .55422 .61478 .55706 .61282 .55405 Metetra
0 .236 .754 r
.61282 .55405 .61478 .55706 .61875 .56074 .61679 .55759 Metetra
0 .075 .631 r
.61679 .55759 .61875 .56074 .62277 .56556 .62081 .56224 Metetra
0 0 .448 r
.62081 .56224 .62277 .56556 .62686 .57202 .62489 .56847 Metetra
.723 .323 0 r
.62489 .56847 .62686 .57202 .63105 .58095 .62906 .5771 Metetra
.865 .484 0 r
.62906 .5771 .63105 .58095 .6354 .59386 .63339 .5896 Metetra
.939 .589 .176 r
.63339 .5896 .6354 .59386 .64002 .61386 .63799 .60904 Metetra
.969 .648 .302 r
.63799 .60904 .64002 .61386 .6452 .64836 .64313 .64297 Metetra
.974 .674 .379 r
.64313 .64297 .6452 .64836 .65153 .71238 .64954 .71036 Metetra
.645 .763 .934 r
.64954 .71036 .65153 .71238 .65561 .71129 .65362 .70927 Metetra
.645 .763 .934 r
.65362 .70927 .65561 .71129 .65969 .71019 .65771 .70817 Metetra
.645 .763 .934 r
.65771 .70817 .65969 .71019 .66378 .7091 .6618 .70708 Metetra
.966 .706 .491 r
.6618 .70708 .66378 .7091 .66523 .64281 .66315 .6374 Metetra
.935 .691 .545 r
.66315 .6374 .66523 .64281 .66776 .60597 .66573 .60112 Metetra
.918 .695 .585 r
.66573 .60112 .66776 .60597 .67084 .58363 .66884 .57933 Metetra
.902 .701 .621 r
.66884 .57933 .67084 .58363 .67418 .56838 .67221 .56449 Metetra
.887 .707 .654 r
.67221 .56449 .67418 .56838 .67768 .55711 .67573 .55352 Metetra
.871 .714 .684 r
.67573 .55352 .67768 .55711 .68127 .54831 .67934 .54494 Metetra
.857 .719 .71 r
.67934 .54494 .68127 .54831 .68493 .54115 .68301 .53794 Metetra
.843 .724 .732 r
.68301 .53794 .68493 .54115 .68864 .53513 .68673 .53205 Metetra
.829 .727 .752 r
.68673 .53205 .68864 .53513 .69238 .52995 .69048 .52697 Metetra
.817 .73 .769 r
.69048 .52697 .69238 .52995 .69615 .52539 .69426 .5225 Metetra
.806 .732 .783 r
.69426 .5225 .69615 .52539 .69994 .52132 .69806 .5185 Metetra
.795 .734 .796 r
.69806 .5185 .69994 .52132 .70375 .51763 .70187 .51486 Metetra
.786 .735 .807 r
.70187 .51486 .70375 .51763 .70758 .51425 .70571 .51153 Metetra
.777 .737 .816 r
.70571 .51153 .70758 .51425 .71142 .51112 .70956 .50844 Metetra
.769 .737 .824 r
.70956 .50844 .71142 .51112 .71527 .5082 .71342 .50555 Metetra
.762 .738 .831 r
.71342 .50555 .71527 .5082 .71914 .50545 .71729 .50283 Metetra
.755 .739 .837 r
.71729 .50283 .71914 .50545 .72301 .50285 .72117 .50025 Metetra
.749 .739 .843 r
.72117 .50025 .72301 .50285 .7269 .50037 .72506 .4978 Metetra
.743 .739 .848 r
.72506 .4978 .7269 .50037 .7308 .498 .72896 .49545 Metetra
.739 .74 .852 r
.72896 .49545 .7308 .498 .7347 .49573 .73287 .49319 Metetra
.734 .74 .856 r
.73287 .49319 .7347 .49573 .73861 .49354 .73679 .49101 Metetra
.73 .74 .86 r
.73679 .49101 .73861 .49354 .74253 .49142 .74072 .48891 Metetra
.726 .74 .863 r
.74072 .48891 .74253 .49142 .74646 .48936 .74465 .48686 Metetra
.722 .74 .866 r
.74465 .48686 .74646 .48936 .7504 .48736 .74859 .48487 Metetra
.719 .74 .868 r
.74859 .48487 .7504 .48736 .75434 .48541 .75254 .48293 Metetra
.716 .74 .87 r
.75254 .48293 .75434 .48541 .75829 .48351 .75649 .48104 Metetra
.714 .74 .873 r
.75649 .48104 .75829 .48351 .76225 .48165 .76046 .47918 Metetra
.711 .74 .875 r
.76046 .47918 .76225 .48165 .76621 .47982 .76442 .47736 Metetra
.709 .74 .876 r
.76442 .47736 .76621 .47982 .77018 .47803 .7684 .47557 Metetra
.706 .74 .878 r
.7684 .47557 .77018 .47803 .77416 .47626 .77238 .47382 Metetra
.704 .74 .879 r
.77238 .47382 .77416 .47626 .77814 .47453 .77637 .47208 Metetra
.703 .741 .881 r
.77637 .47208 .77814 .47453 .78213 .47281 .78036 .47038 Metetra
.701 .741 .882 r
.78036 .47038 .78213 .47281 .78613 .47113 .78436 .46869 Metetra
.699 .741 .883 r
.78436 .46869 .78613 .47113 .79013 .46946 .78837 .46703 Metetra
.698 .741 .884 r
.78837 .46703 .79013 .46946 .79414 .46781 .79238 .46538 Metetra
.696 .741 .885 r
.79238 .46538 .79414 .46781 .79815 .46618 .7964 .46375 Metetra
.695 .741 .886 r
.7964 .46375 .79815 .46618 .80218 .46456 .80043 .46214 Metetra
.694 .741 .887 r
.80043 .46214 .80218 .46456 .8062 .46297 .80446 .46054 Metetra
.692 .741 .888 r
.80446 .46054 .8062 .46297 .81024 .46138 .8085 .45896 Metetra
.691 .741 .889 r
.8085 .45896 .81024 .46138 .81428 .45981 .81254 .45738 Metetra
.69 .741 .89 r
.81254 .45738 .81428 .45981 .81832 .45824 .81659 .45582 Metetra
.689 .741 .89 r
.81659 .45582 .81832 .45824 .82237 .45669 .82065 .45427 Metetra
.688 .741 .891 r
.82065 .45427 .82237 .45669 .82643 .45515 .82471 .45273 Metetra
.687 .741 .892 r
.82471 .45273 .82643 .45515 .83049 .45362 .82878 .4512 Metetra
.687 .741 .892 r
.82878 .4512 .83049 .45362 .83456 .4521 .83285 .44968 Metetra
.686 .741 .893 r
.83285 .44968 .83456 .4521 .83864 .45059 .83693 .44817 Metetra
.685 .741 .893 r
.83693 .44817 .83864 .45059 .84272 .44908 .84102 .44666 Metetra
.684 .741 .894 r
.84102 .44666 .84272 .44908 .84681 .44758 .84511 .44516 Metetra
.684 .741 .894 r
.84511 .44516 .84681 .44758 .8509 .44609 .84921 .44367 Metetra
.683 .741 .895 r
.84921 .44367 .8509 .44609 .855 .4446 .85331 .44218 Metetra
.682 .741 .895 r
.85331 .44218 .855 .4446 .85911 .44312 .85742 .4407 Metetra
.682 .741 .895 r
.85742 .4407 .85911 .44312 .86322 .44165 .86154 .43922 Metetra
.681 .741 .896 r
.86154 .43922 .86322 .44165 .86734 .44018 .86566 .43775 Metetra
.681 .741 .896 r
.86566 .43775 .86734 .44018 .87146 .43871 .86979 .43629 Metetra
.68 .741 .897 r
.86979 .43629 .87146 .43871 .87559 .43725 .87393 .43482 Metetra
.68 .741 .897 r
.87393 .43482 .87559 .43725 .87973 .43579 .87807 .43336 Metetra
.679 .741 .897 r
.87807 .43336 .87973 .43579 .88387 .43434 .88221 .43191 Metetra
.679 .741 .897 r
.88221 .43191 .88387 .43434 .88802 .43289 .88636 .43046 Metetra
.678 .741 .898 r
.88636 .43046 .88802 .43289 .89217 .43144 .89052 .42901 Metetra
.678 .741 .898 r
.89052 .42901 .89217 .43144 .89633 .43 .89469 .42756 Metetra
.678 .741 .898 r
.89469 .42756 .89633 .43 .9005 .42856 .89886 .42612 Metetra
.677 .741 .899 r
.89886 .42612 .9005 .42856 .90467 .42712 .90303 .42468 Metetra
.677 .741 .899 r
.90303 .42468 .90467 .42712 .90885 .42568 .90722 .42324 Metetra
.676 .741 .899 r
.90722 .42324 .90885 .42568 .91303 .42425 .91141 .42181 Metetra
.676 .741 .899 r
.91141 .42181 .91303 .42425 .91722 .42282 .9156 .42037 Metetra
.676 .741 .899 r
.9156 .42037 .91722 .42282 .92142 .42139 .9198 .41894 Metetra
.675 .741 .9 r
.9198 .41894 .92142 .42139 .92562 .41996 .92401 .41751 Metetra
.675 .741 .9 r
.92401 .41751 .92562 .41996 .92983 .41853 .92822 .41608 Metetra
.675 .741 .9 r
.92822 .41608 .92983 .41853 .93404 .41711 .93244 .41465 Metetra
.675 .741 .9 r
.93244 .41465 .93404 .41711 .93827 .41568 .93667 .41323 Metetra
.674 .741 .9 r
.93667 .41323 .93827 .41568 .94249 .41426 .9409 .4118 Metetra
.674 .741 .901 r
.9409 .4118 .94249 .41426 .94672 .41284 .94513 .41038 Metetra
.674 .741 .901 r
.94513 .41038 .94672 .41284 .95096 .41142 .94938 .40895 Metetra
.651 .733 .909 r
.37363 .58207 .37575 .58409 .37922 .58314 .37711 .58112 Metetra
.65 .733 .91 r
.37711 .58112 .37922 .58314 .3827 .5822 .38059 .58017 Metetra
.65 .733 .91 r
.38059 .58017 .3827 .5822 .38618 .58126 .38408 .57922 Metetra
.65 .732 .91 r
.38408 .57922 .38618 .58126 .38967 .58032 .38757 .57828 Metetra
.65 .732 .91 r
.38757 .57828 .38967 .58032 .39316 .57938 .39106 .57734 Metetra
.649 .732 .91 r
.39106 .57734 .39316 .57938 .39666 .57844 .39456 .5764 Metetra
.649 .732 .91 r
.39456 .5764 .39666 .57844 .40016 .57751 .39807 .57546 Metetra
.648 .732 .91 r
.39807 .57546 .40016 .57751 .40367 .57657 .40158 .57452 Metetra
.648 .731 .91 r
.40158 .57452 .40367 .57657 .40718 .57564 .40509 .57358 Metetra
.648 .731 .91 r
.40509 .57358 .40718 .57564 .4107 .57471 .40861 .57265 Metetra
.647 .731 .91 r
.40861 .57265 .4107 .57471 .41422 .57379 .41214 .57172 Metetra
.647 .731 .91 r
.41214 .57172 .41422 .57379 .41775 .57286 .41567 .5708 Metetra
.646 .73 .91 r
.41567 .5708 .41775 .57286 .42128 .57194 .4192 .56987 Metetra
.646 .73 .91 r
.4192 .56987 .42128 .57194 .42482 .57103 .42274 .56895 Metetra
.645 .73 .91 r
.42274 .56895 .42482 .57103 .42836 .57011 .42628 .56803 Metetra
.645 .729 .91 r
.42628 .56803 .42836 .57011 .4319 .5692 .42983 .56712 Metetra
.644 .729 .91 r
.42983 .56712 .4319 .5692 .43545 .5683 .43338 .56621 Metetra
.644 .729 .91 r
.43338 .56621 .43545 .5683 .43901 .5674 .43694 .5653 Metetra
.643 .728 .91 r
.43694 .5653 .43901 .5674 .44257 .5665 .44051 .5644 Metetra
.643 .728 .911 r
.44051 .5644 .44257 .5665 .44613 .56561 .44407 .5635 Metetra
.642 .727 .911 r
.44407 .5635 .44613 .56561 .4497 .56472 .44765 .56261 Metetra
.641 .727 .911 r
.44765 .56261 .4497 .56472 .45328 .56383 .45123 .56172 Metetra
.64 .727 .911 r
.45123 .56172 .45328 .56383 .45686 .56296 .45481 .56084 Metetra
.64 .726 .911 r
.45481 .56084 .45686 .56296 .46044 .56209 .4584 .55996 Metetra
.639 .726 .911 r
.4584 .55996 .46044 .56209 .46404 .56122 .46199 .55909 Metetra
.638 .725 .911 r
.46199 .55909 .46404 .56122 .46763 .56036 .46559 .55823 Metetra
.637 .725 .911 r
.46559 .55823 .46763 .56036 .47123 .55951 .46919 .55737 Metetra
.636 .724 .911 r
.46919 .55737 .47123 .55951 .47484 .55867 .4728 .55652 Metetra
.635 .723 .911 r
.4728 .55652 .47484 .55867 .47845 .55783 .47641 .55568 Metetra
.634 .723 .912 r
.47641 .55568 .47845 .55783 .48206 .55701 .48003 .55485 Metetra
.633 .722 .912 r
.48003 .55485 .48206 .55701 .48569 .55619 .48366 .55403 Metetra
.632 .721 .912 r
.48366 .55403 .48569 .55619 .48931 .55539 .48729 .55322 Metetra
.63 .72 .912 r
.48729 .55322 .48931 .55539 .49295 .55459 .49092 .55241 Metetra
.629 .72 .912 r
.49092 .55241 .49295 .55459 .49658 .55381 .49456 .55162 Metetra
.627 .719 .912 r
.49456 .55162 .49658 .55381 .50023 .55304 .49821 .55085 Metetra
.626 .718 .913 r
.49821 .55085 .50023 .55304 .50387 .55228 .50186 .55008 Metetra
.624 .717 .913 r
.50186 .55008 .50387 .55228 .50753 .55154 .50552 .54933 Metetra
.622 .715 .913 r
.50552 .54933 .50753 .55154 .51119 .55082 .50918 .5486 Metetra
.62 .714 .913 r
.50918 .5486 .51119 .55082 .51485 .55011 .51285 .54789 Metetra
.618 .713 .913 r
.51285 .54789 .51485 .55011 .51853 .54942 .51652 .54719 Metetra
.615 .711 .914 r
.51652 .54719 .51853 .54942 .5222 .54875 .5202 .54651 Metetra
.613 .71 .914 r
.5202 .54651 .5222 .54875 .52588 .54811 .52389 .54586 Metetra
.61 .708 .914 r
.52389 .54586 .52588 .54811 .52957 .54749 .52758 .54523 Metetra
.607 .706 .915 r
.52758 .54523 .52957 .54749 .53327 .54689 .53128 .54462 Metetra
.603 .704 .915 r
.53128 .54462 .53327 .54689 .53697 .54633 .53498 .54405 Metetra
.6 .702 .915 r
.53498 .54405 .53697 .54633 .54068 .5458 .53869 .5435 Metetra
.595 .699 .916 r
.53869 .5435 .54068 .5458 .54439 .5453 .54241 .54299 Metetra
.591 .697 .916 r
.54241 .54299 .54439 .5453 .54811 .54485 .54613 .54253 Metetra
.585 .694 .916 r
.54613 .54253 .54811 .54485 .55184 .54444 .54986 .5421 Metetra
.58 .69 .917 r
.54986 .5421 .55184 .54444 .55558 .54408 .5536 .54172 Metetra
.573 .686 .917 r
.5536 .54172 .55558 .54408 .55932 .54377 .55734 .5414 Metetra
.565 .682 .918 r
.55734 .5414 .55932 .54377 .56307 .54353 .5611 .54114 Metetra
.557 .676 .918 r
.5611 .54114 .56307 .54353 .56682 .54336 .56486 .54094 Metetra
.547 .67 .919 r
.56486 .54094 .56682 .54336 .57059 .54326 .56862 .54083 Metetra
.535 .663 .919 r
.56862 .54083 .57059 .54326 .57437 .54326 .5724 .5408 Metetra
.522 .655 .919 r
.5724 .5408 .57437 .54326 .57815 .54337 .57619 .54088 Metetra
.505 .645 .919 r
.57619 .54088 .57815 .54337 .58194 .5436 .57998 .54108 Metetra
.486 .633 .919 r
.57998 .54108 .58194 .5436 .58575 .54397 .58379 .54141 Metetra
.462 .619 .918 r
.58379 .54141 .58575 .54397 .58957 .54451 .58761 .54191 Metetra
.433 .601 .916 r
.58761 .54191 .58957 .54451 .5934 .54526 .59144 .54261 Metetra
.397 .577 .912 r
.59144 .54261 .5934 .54526 .59724 .54624 .59528 .54354 Metetra
.35 .547 .905 r
.59528 .54354 .59724 .54624 .6011 .54753 .59914 .54477 Metetra
.288 .506 .893 r
.59914 .54477 .6011 .54753 .60498 .54919 .60302 .54635 Metetra
.206 .451 .873 r
.60302 .54635 .60498 .54919 .60889 .55131 .60693 .54838 Metetra
.096 .372 .836 r
.60693 .54838 .60889 .55131 .61282 .55405 .61086 .551 Metetra
0 .261 .77 r
.61086 .551 .61282 .55405 .61679 .55759 .61482 .5544 Metetra
0 .108 .659 r
.61482 .5544 .61679 .55759 .62081 .56224 .61883 .55887 Metetra
0 0 .487 r
.61883 .55887 .62081 .56224 .62489 .56847 .62291 .56485 Metetra
.688 .292 0 r
.62291 .56485 .62489 .56847 .62906 .5771 .62707 .57314 Metetra
.844 .464 0 r
.62707 .57314 .62906 .5771 .63339 .5896 .63138 .58515 Metetra
.931 .58 .15 r
.63138 .58515 .63339 .5896 .63799 .60904 .63594 .60384 Metetra
.967 .646 .286 r
.63594 .60384 .63799 .60904 .64313 .64297 .64102 .63664 Metetra
.976 .677 .376 r
.64102 .63664 .64313 .64297 .64954 .71036 .64755 .70834 Metetra
.645 .763 .934 r
.64755 .70834 .64954 .71036 .65362 .70927 .65163 .70725 Metetra
.645 .763 .934 r
.65163 .70725 .65362 .70927 .65771 .70817 .65572 .70615 Metetra
.645 .763 .934 r
.65572 .70615 .65771 .70817 .6618 .70708 .65982 .70505 Metetra
.966 .705 .489 r
.65982 .70505 .6618 .70708 .66315 .6374 .66104 .63105 Metetra
.926 .683 .551 r
.66104 .63105 .66315 .6374 .66573 .60112 .66368 .59589 Metetra
.91 .689 .589 r
.66368 .59589 .66573 .60112 .66884 .57933 .66684 .57484 Metetra
.896 .696 .625 r
.66684 .57484 .66884 .57933 .67221 .56449 .67024 .56048 Metetra
.881 .704 .657 r
.67024 .56048 .67221 .56449 .67573 .55352 .67377 .54985 Metetra
.867 .711 .686 r
.67377 .54985 .67573 .55352 .67934 .54494 .6774 .54151 Metetra
.853 .717 .712 r
.6774 .54151 .67934 .54494 .68301 .53794 .68109 .53469 Metetra
.839 .721 .734 r
.68109 .53469 .68301 .53794 .68673 .53205 .68481 .52894 Metetra
.826 .725 .754 r
.68481 .52894 .68673 .53205 .69048 .52697 .68858 .52397 Metetra
.814 .728 .77 r
.68858 .52397 .69048 .52697 .69426 .5225 .69236 .51959 Metetra
.803 .731 .785 r
.69236 .51959 .69426 .5225 .69806 .5185 .69617 .51565 Metetra
.792 .733 .797 r
.69617 .51565 .69806 .5185 .70187 .51486 .7 .51208 Metetra
.783 .734 .808 r
.7 .51208 .70187 .51486 .70571 .51153 .70384 .50879 Metetra
.775 .736 .817 r
.70384 .50879 .70571 .51153 .70956 .50844 .70769 .50574 Metetra
.767 .737 .825 r
.70769 .50574 .70956 .50844 .71342 .50555 .71156 .50289 Metetra
.76 .737 .832 r
.71156 .50289 .71342 .50555 .71729 .50283 .71544 .5002 Metetra
.753 .738 .838 r
.71544 .5002 .71729 .50283 .72117 .50025 .71932 .49765 Metetra
.747 .738 .844 r
.71932 .49765 .72117 .50025 .72506 .4978 .72322 .49521 Metetra
.742 .739 .849 r
.72322 .49521 .72506 .4978 .72896 .49545 .72713 .49289 Metetra
.737 .739 .853 r
.72713 .49289 .72896 .49545 .73287 .49319 .73104 .49065 Metetra
.733 .739 .857 r
.73104 .49065 .73287 .49319 .73679 .49101 .73497 .48848 Metetra
.729 .739 .86 r
.73497 .48848 .73679 .49101 .74072 .48891 .7389 .48639 Metetra
.725 .74 .863 r
.7389 .48639 .74072 .48891 .74465 .48686 .74284 .48436 Metetra
.721 .74 .866 r
.74284 .48436 .74465 .48686 .74859 .48487 .74678 .48238 Metetra
.718 .74 .868 r
.74678 .48238 .74859 .48487 .75254 .48293 .75073 .48045 Metetra
.715 .74 .871 r
.75073 .48045 .75254 .48293 .75649 .48104 .75469 .47856 Metetra
.713 .74 .873 r
.75469 .47856 .75649 .48104 .76046 .47918 .75866 .47671 Metetra
.71 .74 .875 r
.75866 .47671 .76046 .47918 .76442 .47736 .76263 .4749 Metetra
.708 .74 .877 r
.76263 .4749 .76442 .47736 .7684 .47557 .76661 .47312 Metetra
.706 .74 .878 r
.76661 .47312 .7684 .47557 .77238 .47382 .7706 .47136 Metetra
.704 .74 .88 r
.7706 .47136 .77238 .47382 .77637 .47208 .77459 .46964 Metetra
.702 .74 .881 r
.77459 .46964 .77637 .47208 .78036 .47038 .77859 .46793 Metetra
.7 .74 .882 r
.77859 .46793 .78036 .47038 .78436 .46869 .78259 .46625 Metetra
.699 .74 .883 r
.78259 .46625 .78436 .46869 .78837 .46703 .78661 .46459 Metetra
.697 .74 .885 r
.78661 .46459 .78837 .46703 .79238 .46538 .79062 .46295 Metetra
.696 .74 .886 r
.79062 .46295 .79238 .46538 .7964 .46375 .79465 .46132 Metetra
.694 .74 .887 r
.79465 .46132 .7964 .46375 .80043 .46214 .79868 .45971 Metetra
.693 .74 .887 r
.79868 .45971 .80043 .46214 .80446 .46054 .80271 .45811 Metetra
.692 .74 .888 r
.80271 .45811 .80446 .46054 .8085 .45896 .80676 .45653 Metetra
.691 .74 .889 r
.80676 .45653 .8085 .45896 .81254 .45738 .8108 .45496 Metetra
.69 .74 .89 r
.8108 .45496 .81254 .45738 .81659 .45582 .81486 .4534 Metetra
.689 .74 .89 r
.81486 .4534 .81659 .45582 .82065 .45427 .81892 .45185 Metetra
.688 .74 .891 r
.81892 .45185 .82065 .45427 .82471 .45273 .82299 .45031 Metetra
.687 .74 .892 r
.82299 .45031 .82471 .45273 .82878 .4512 .82706 .44878 Metetra
.686 .74 .892 r
.82706 .44878 .82878 .4512 .83285 .44968 .83114 .44726 Metetra
.685 .74 .893 r
.83114 .44726 .83285 .44968 .83693 .44817 .83522 .44574 Metetra
.685 .74 .893 r
.83522 .44574 .83693 .44817 .84102 .44666 .83931 .44423 Metetra
.684 .74 .894 r
.83931 .44423 .84102 .44666 .84511 .44516 .84341 .44273 Metetra
.683 .74 .894 r
.84341 .44273 .84511 .44516 .84921 .44367 .84751 .44124 Metetra
.683 .74 .895 r
.84751 .44124 .84921 .44367 .85331 .44218 .85162 .43975 Metetra
.682 .74 .895 r
.85162 .43975 .85331 .44218 .85742 .4407 .85574 .43827 Metetra
.682 .741 .896 r
.85574 .43827 .85742 .4407 .86154 .43922 .85986 .43679 Metetra
.681 .741 .896 r
.85986 .43679 .86154 .43922 .86566 .43775 .86398 .43532 Metetra
.68 .741 .896 r
.86398 .43532 .86566 .43775 .86979 .43629 .86812 .43385 Metetra
.68 .741 .897 r
.86812 .43385 .86979 .43629 .87393 .43482 .87225 .43239 Metetra
.679 .741 .897 r
.87225 .43239 .87393 .43482 .87807 .43336 .8764 .43093 Metetra
.679 .741 .897 r
.8764 .43093 .87807 .43336 .88221 .43191 .88055 .42947 Metetra
.679 .741 .898 r
.88055 .42947 .88221 .43191 .88636 .43046 .88471 .42802 Metetra
.678 .741 .898 r
.88471 .42802 .88636 .43046 .89052 .42901 .88887 .42657 Metetra
.678 .741 .898 r
.88887 .42657 .89052 .42901 .89469 .42756 .89304 .42512 Metetra
.677 .741 .898 r
.89304 .42512 .89469 .42756 .89886 .42612 .89721 .42368 Metetra
.677 .741 .899 r
.89721 .42368 .89886 .42612 .90303 .42468 .90139 .42223 Metetra
.677 .741 .899 r
.90139 .42223 .90303 .42468 .90722 .42324 .90558 .42079 Metetra
.676 .741 .899 r
.90558 .42079 .90722 .42324 .91141 .42181 .90977 .41936 Metetra
.676 .741 .899 r
.90977 .41936 .91141 .42181 .9156 .42037 .91397 .41792 Metetra
.676 .741 .9 r
.91397 .41792 .9156 .42037 .9198 .41894 .91818 .41649 Metetra
.675 .741 .9 r
.91818 .41649 .9198 .41894 .92401 .41751 .92239 .41505 Metetra
.675 .741 .9 r
.92239 .41505 .92401 .41751 .92822 .41608 .92661 .41362 Metetra
.675 .741 .9 r
.92661 .41362 .92822 .41608 .93244 .41465 .93083 .41219 Metetra
.675 .741 .9 r
.93083 .41219 .93244 .41465 .93667 .41323 .93506 .41076 Metetra
.674 .741 .9 r
.93506 .41076 .93667 .41323 .9409 .4118 .9393 .40934 Metetra
.674 .741 .901 r
.9393 .40934 .9409 .4118 .94513 .41038 .94354 .40791 Metetra
.674 .741 .901 r
.94354 .40791 .94513 .41038 .94938 .40895 .94779 .40649 Metetra
.651 .733 .909 r
.37151 .58004 .37363 .58207 .37711 .58112 .37499 .57909 Metetra
.651 .733 .909 r
.37499 .57909 .37711 .58112 .38059 .58017 .37848 .57814 Metetra
.65 .733 .909 r
.37848 .57814 .38059 .58017 .38408 .57922 .38196 .57719 Metetra
.65 .732 .91 r
.38196 .57719 .38408 .57922 .38757 .57828 .38546 .57624 Metetra
.65 .732 .91 r
.38546 .57624 .38757 .57828 .39106 .57734 .38896 .57529 Metetra
.649 .732 .91 r
.38896 .57529 .39106 .57734 .39456 .5764 .39246 .57435 Metetra
.649 .732 .91 r
.39246 .57435 .39456 .5764 .39807 .57546 .39597 .5734 Metetra
.649 .732 .91 r
.39597 .5734 .39807 .57546 .40158 .57452 .39948 .57246 Metetra
.648 .731 .91 r
.39948 .57246 .40158 .57452 .40509 .57358 .403 .57152 Metetra
.648 .731 .91 r
.403 .57152 .40509 .57358 .40861 .57265 .40652 .57059 Metetra
.647 .731 .91 r
.40652 .57059 .40861 .57265 .41214 .57172 .41005 .56965 Metetra
.647 .731 .91 r
.41005 .56965 .41214 .57172 .41567 .5708 .41358 .56872 Metetra
.647 .73 .91 r
.41358 .56872 .41567 .5708 .4192 .56987 .41712 .56779 Metetra
.646 .73 .91 r
.41712 .56779 .4192 .56987 .42274 .56895 .42066 .56687 Metetra
.646 .73 .91 r
.42066 .56687 .42274 .56895 .42628 .56803 .4242 .56595 Metetra
.645 .729 .91 r
.4242 .56595 .42628 .56803 .42983 .56712 .42776 .56503 Metetra
.645 .729 .91 r
.42776 .56503 .42983 .56712 .43338 .56621 .43131 .56411 Metetra
.644 .729 .91 r
.43131 .56411 .43338 .56621 .43694 .5653 .43487 .5632 Metetra
.643 .728 .91 r
.43487 .5632 .43694 .5653 .44051 .5644 .43844 .56229 Metetra
.643 .728 .91 r
.43844 .56229 .44051 .5644 .44407 .5635 .44201 .56139 Metetra
.642 .728 .91 r
.44201 .56139 .44407 .5635 .44765 .56261 .44559 .56049 Metetra
.641 .727 .911 r
.44559 .56049 .44765 .56261 .45123 .56172 .44917 .5596 Metetra
.641 .727 .911 r
.44917 .5596 .45123 .56172 .45481 .56084 .45275 .55871 Metetra
.64 .726 .911 r
.45275 .55871 .45481 .56084 .4584 .55996 .45634 .55783 Metetra
.639 .726 .911 r
.45634 .55783 .4584 .55996 .46199 .55909 .45994 .55696 Metetra
.638 .725 .911 r
.45994 .55696 .46199 .55909 .46559 .55823 .46354 .55609 Metetra
.637 .725 .911 r
.46354 .55609 .46559 .55823 .46919 .55737 .46715 .55523 Metetra
.636 .724 .911 r
.46715 .55523 .46919 .55737 .4728 .55652 .47076 .55437 Metetra
.635 .723 .911 r
.47076 .55437 .4728 .55652 .47641 .55568 .47438 .55352 Metetra
.634 .723 .911 r
.47438 .55352 .47641 .55568 .48003 .55485 .478 .55269 Metetra
.633 .722 .912 r
.478 .55269 .48003 .55485 .48366 .55403 .48163 .55186 Metetra
.632 .721 .912 r
.48163 .55186 .48366 .55403 .48729 .55322 .48526 .55104 Metetra
.631 .721 .912 r
.48526 .55104 .48729 .55322 .49092 .55241 .4889 .55023 Metetra
.629 .72 .912 r
.4889 .55023 .49092 .55241 .49456 .55162 .49254 .54943 Metetra
.628 .719 .912 r
.49254 .54943 .49456 .55162 .49821 .55085 .49619 .54865 Metetra
.626 .718 .912 r
.49619 .54865 .49821 .55085 .50186 .55008 .49984 .54788 Metetra
.625 .717 .913 r
.49984 .54788 .50186 .55008 .50552 .54933 .5035 .54712 Metetra
.623 .716 .913 r
.5035 .54712 .50552 .54933 .50918 .5486 .50717 .54638 Metetra
.621 .714 .913 r
.50717 .54638 .50918 .5486 .51285 .54789 .51084 .54566 Metetra
.619 .713 .913 r
.51084 .54566 .51285 .54789 .51652 .54719 .51451 .54495 Metetra
.616 .712 .913 r
.51451 .54495 .51652 .54719 .5202 .54651 .5182 .54426 Metetra
.614 .71 .914 r
.5182 .54426 .5202 .54651 .52389 .54586 .52189 .5436 Metetra
.611 .708 .914 r
.52189 .5436 .52389 .54586 .52758 .54523 .52558 .54296 Metetra
.608 .707 .914 r
.52558 .54296 .52758 .54523 .53128 .54462 .52928 .54234 Metetra
.605 .705 .915 r
.52928 .54234 .53128 .54462 .53498 .54405 .53299 .54176 Metetra
.601 .702 .915 r
.53299 .54176 .53498 .54405 .53869 .5435 .5367 .5412 Metetra
.597 .7 .915 r
.5367 .5412 .53869 .5435 .54241 .54299 .54042 .54068 Metetra
.592 .697 .916 r
.54042 .54068 .54241 .54299 .54613 .54253 .54415 .5402 Metetra
.587 .694 .916 r
.54415 .5402 .54613 .54253 .54986 .5421 .54788 .53975 Metetra
.581 .691 .916 r
.54788 .53975 .54986 .5421 .5536 .54172 .55162 .53936 Metetra
.575 .687 .917 r
.55162 .53936 .5536 .54172 .55734 .5414 .55536 .53902 Metetra
.568 .682 .917 r
.55536 .53902 .55734 .5414 .5611 .54114 .55912 .53874 Metetra
.559 .677 .918 r
.55912 .53874 .5611 .54114 .56486 .54094 .56288 .53852 Metetra
.55 .671 .918 r
.56288 .53852 .56486 .54094 .56862 .54083 .56665 .53838 Metetra
.539 .665 .918 r
.56665 .53838 .56862 .54083 .5724 .5408 .57043 .53833 Metetra
.525 .657 .919 r
.57043 .53833 .5724 .5408 .57619 .54088 .57422 .53838 Metetra
.51 .647 .918 r
.57422 .53838 .57619 .54088 .57998 .54108 .57802 .53855 Metetra
.491 .636 .918 r
.57802 .53855 .57998 .54108 .58379 .54141 .58182 .53885 Metetra
.469 .622 .917 r
.58182 .53885 .58379 .54141 .58761 .54191 .58564 .53931 Metetra
.441 .604 .915 r
.58564 .53931 .58761 .54191 .59144 .54261 .58947 .53996 Metetra
.406 .582 .912 r
.58947 .53996 .59144 .54261 .59528 .54354 .59332 .54083 Metetra
.362 .553 .906 r
.59332 .54083 .59528 .54354 .59914 .54477 .59718 .54199 Metetra
.304 .515 .895 r
.59718 .54199 .59914 .54477 .60302 .54635 .60106 .54349 Metetra
.228 .463 .877 r
.60106 .54349 .60302 .54635 .60693 .54838 .60496 .54543 Metetra
.124 .39 .844 r
.60496 .54543 .60693 .54838 .61086 .551 .60889 .54793 Metetra
0 .286 .786 r
.60889 .54793 .61086 .551 .61482 .5544 .61285 .55118 Metetra
0 .141 .685 r
.61285 .55118 .61482 .5544 .61883 .55887 .61686 .55545 Metetra
0 0 .526 r
.61686 .55545 .61883 .55887 .62291 .56485 .62092 .56118 Metetra
.646 .256 0 r
.62092 .56118 .62291 .56485 .62707 .57314 .62507 .56909 Metetra
.819 .439 0 r
.62507 .56909 .62707 .57314 .63138 .58515 .62936 .58054 Metetra
.92 .567 .12 r
.62936 .58054 .63138 .58515 .63594 .60384 .63388 .59834 Metetra
.965 .642 .267 r
.63388 .59834 .63594 .60384 .64102 .63664 .63889 .62956 Metetra
.977 .678 .367 r
.63889 .62956 .64102 .63664 .64755 .70834 .6453 .69901 Metetra
.277 .267 .667 r
.6453 .69901 .64755 .70834 .65163 .70725 .64963 .70522 Metetra
.645 .763 .934 r
.64963 .70522 .65163 .70725 .65572 .70615 .65373 .70412 Metetra
.913 .782 .704 r
.65373 .70412 .65572 .70615 .65982 .70505 .65755 .69576 Metetra
.937 .676 .517 r
.65755 .69576 .65982 .70505 .66104 .63105 .6589 .62394 Metetra
.917 .676 .558 r
.6589 .62394 .66104 .63105 .66368 .59589 .66162 .59036 Metetra
.904 .683 .594 r
.66162 .59036 .66368 .59589 .66684 .57484 .66482 .5702 Metetra
.89 .692 .629 r
.66482 .5702 .66684 .57484 .67024 .56048 .66825 .5564 Metetra
.876 .701 .661 r
.66825 .5564 .67024 .56048 .67377 .54985 .67181 .54613 Metetra
.862 .708 .69 r
.67181 .54613 .67377 .54985 .6774 .54151 .67546 .53804 Metetra
.848 .715 .715 r
.67546 .53804 .6774 .54151 .68109 .53469 .67916 .53142 Metetra
.835 .72 .737 r
.67916 .53142 .68109 .53469 .68481 .52894 .6829 .52581 Metetra
.822 .724 .756 r
.6829 .52581 .68481 .52894 .68858 .52397 .68667 .52095 Metetra
.811 .727 .772 r
.68667 .52095 .68858 .52397 .69236 .51959 .69046 .51666 Metetra
.8 .73 .786 r
.69046 .51666 .69236 .51959 .69617 .51565 .69428 .5128 Metetra
.79 .732 .799 r
.69428 .5128 .69617 .51565 .7 .51208 .69811 .50928 Metetra
.781 .733 .809 r
.69811 .50928 .7 .51208 .70384 .50879 .70196 .50604 Metetra
.772 .735 .818 r
.70196 .50604 .70384 .50879 .70769 .50574 .70582 .50304 Metetra
.765 .736 .826 r
.70582 .50304 .70769 .50574 .71156 .50289 .7097 .50022 Metetra
.758 .736 .833 r
.7097 .50022 .71156 .50289 .71544 .5002 .71358 .49756 Metetra
.752 .737 .839 r
.71358 .49756 .71544 .5002 .71932 .49765 .71747 .49503 Metetra
.746 .738 .844 r
.71747 .49503 .71932 .49765 .72322 .49521 .72138 .49262 Metetra
.741 .738 .849 r
.72138 .49262 .72322 .49521 .72713 .49289 .72529 .49032 Metetra
.736 .738 .853 r
.72529 .49032 .72713 .49289 .73104 .49065 .72921 .48809 Metetra
.731 .739 .857 r
.72921 .48809 .73104 .49065 .73497 .48848 .73314 .48595 Metetra
.728 .739 .861 r
.73314 .48595 .73497 .48848 .7389 .48639 .73707 .48387 Metetra
.724 .739 .864 r
.73707 .48387 .7389 .48639 .74284 .48436 .74101 .48185 Metetra
.72 .739 .866 r
.74101 .48185 .74284 .48436 .74678 .48238 .74497 .47988 Metetra
.717 .739 .869 r
.74497 .47988 .74678 .48238 .75073 .48045 .74892 .47796 Metetra
.715 .74 .871 r
.74892 .47796 .75073 .48045 .75469 .47856 .75289 .47608 Metetra
.712 .74 .873 r
.75289 .47608 .75469 .47856 .75866 .47671 .75686 .47424 Metetra
.709 .74 .875 r
.75686 .47424 .75866 .47671 .76263 .4749 .76084 .47243 Metetra
.707 .74 .877 r
.76084 .47243 .76263 .4749 .76661 .47312 .76482 .47065 Metetra
.705 .74 .878 r
.76482 .47065 .76661 .47312 .7706 .47136 .76881 .4689 Metetra
.703 .74 .88 r
.76881 .4689 .7706 .47136 .77459 .46964 .77281 .46718 Metetra
.701 .74 .881 r
.77281 .46718 .77459 .46964 .77859 .46793 .77681 .46548 Metetra
.7 .74 .882 r
.77681 .46548 .77859 .46793 .78259 .46625 .78082 .4638 Metetra
.698 .74 .884 r
.78082 .4638 .78259 .46625 .78661 .46459 .78484 .46214 Metetra
.697 .74 .885 r
.78484 .46214 .78661 .46459 .79062 .46295 .78886 .4605 Metetra
.695 .74 .886 r
.78886 .4605 .79062 .46295 .79465 .46132 .79289 .45888 Metetra
.694 .74 .887 r
.79289 .45888 .79465 .46132 .79868 .45971 .79692 .45727 Metetra
.693 .74 .888 r
.79692 .45727 .79868 .45971 .80271 .45811 .80096 .45567 Metetra
.692 .74 .888 r
.80096 .45567 .80271 .45811 .80676 .45653 .80501 .45409 Metetra
.691 .74 .889 r
.80501 .45409 .80676 .45653 .8108 .45496 .80906 .45252 Metetra
.689 .74 .89 r
.80906 .45252 .8108 .45496 .81486 .4534 .81312 .45096 Metetra
.689 .74 .891 r
.81312 .45096 .81486 .4534 .81892 .45185 .81719 .44941 Metetra
.688 .74 .891 r
.81719 .44941 .81892 .45185 .82299 .45031 .82126 .44788 Metetra
.687 .74 .892 r
.82126 .44788 .82299 .45031 .82706 .44878 .82533 .44635 Metetra
.686 .74 .892 r
.82533 .44635 .82706 .44878 .83114 .44726 .82942 .44482 Metetra
.685 .74 .893 r
.82942 .44482 .83114 .44726 .83522 .44574 .83351 .44331 Metetra
.684 .74 .893 r
.83351 .44331 .83522 .44574 .83931 .44423 .8376 .4418 Metetra
.684 .74 .894 r
.8376 .4418 .83931 .44423 .84341 .44273 .8417 .4403 Metetra
.683 .74 .894 r
.8417 .4403 .84341 .44273 .84751 .44124 .84581 .43881 Metetra
.682 .74 .895 r
.84581 .43881 .84751 .44124 .85162 .43975 .84992 .43732 Metetra
.682 .74 .895 r
.84992 .43732 .85162 .43975 .85574 .43827 .85404 .43583 Metetra
.681 .74 .896 r
.85404 .43583 .85574 .43827 .85986 .43679 .85817 .43436 Metetra
.681 .74 .896 r
.85817 .43436 .85986 .43679 .86398 .43532 .8623 .43288 Metetra
.68 .74 .896 r
.8623 .43288 .86398 .43532 .86812 .43385 .86643 .43141 Metetra
.68 .74 .897 r
.86643 .43141 .86812 .43385 .87225 .43239 .87058 .42995 Metetra
.679 .74 .897 r
.87058 .42995 .87225 .43239 .8764 .43093 .87473 .42849 Metetra
.679 .74 .897 r
.87473 .42849 .8764 .43093 .88055 .42947 .87888 .42703 Metetra
.678 .74 .898 r
.87888 .42703 .88055 .42947 .88471 .42802 .88304 .42557 Metetra
.678 .74 .898 r
.88304 .42557 .88471 .42802 .88887 .42657 .88721 .42412 Metetra
.678 .74 .898 r
.88721 .42412 .88887 .42657 .89304 .42512 .89138 .42267 Metetra
.677 .74 .898 r
.89138 .42267 .89304 .42512 .89721 .42368 .89556 .42123 Metetra
.677 .741 .899 r
.89556 .42123 .89721 .42368 .90139 .42223 .89975 .41978 Metetra
.677 .741 .899 r
.89975 .41978 .90139 .42223 .90558 .42079 .90394 .41834 Metetra
.676 .741 .899 r
.90394 .41834 .90558 .42079 .90977 .41936 .90814 .4169 Metetra
.676 .741 .899 r
.90814 .4169 .90977 .41936 .91397 .41792 .91234 .41546 Metetra
.676 .741 .9 r
.91234 .41546 .91397 .41792 .91818 .41649 .91655 .41403 Metetra
.675 .741 .9 r
.91655 .41403 .91818 .41649 .92239 .41505 .92077 .41259 Metetra
.675 .741 .9 r
.92077 .41259 .92239 .41505 .92661 .41362 .92499 .41116 Metetra
.675 .741 .9 r
.92499 .41116 .92661 .41362 .93083 .41219 .92922 .40973 Metetra
.674 .741 .9 r
.92922 .40973 .93083 .41219 .93506 .41076 .93345 .4083 Metetra
.674 .741 .9 r
.93345 .4083 .93506 .41076 .9393 .40934 .93769 .40687 Metetra
.674 .741 .901 r
.93769 .40687 .9393 .40934 .94354 .40791 .94194 .40544 Metetra
.674 .741 .901 r
.94194 .40544 .94354 .40791 .94779 .40649 .94619 .40401 Metetra
.651 .733 .909 r
.36939 .57801 .37151 .58004 .37499 .57909 .37287 .57705 Metetra
.651 .733 .909 r
.37287 .57705 .37499 .57909 .37848 .57814 .37636 .5761 Metetra
.65 .733 .909 r
.37636 .5761 .37848 .57814 .38196 .57719 .37985 .57514 Metetra
.65 .733 .909 r
.37985 .57514 .38196 .57719 .38546 .57624 .38334 .57419 Metetra
.65 .732 .91 r
.38334 .57419 .38546 .57624 .38896 .57529 .38685 .57324 Metetra
.649 .732 .91 r
.38685 .57324 .38896 .57529 .39246 .57435 .39035 .57229 Metetra
.649 .732 .91 r
.39035 .57229 .39246 .57435 .39597 .5734 .39386 .57134 Metetra
.649 .732 .91 r
.39386 .57134 .39597 .5734 .39948 .57246 .39738 .5704 Metetra
.648 .731 .91 r
.39738 .5704 .39948 .57246 .403 .57152 .4009 .56946 Metetra
.648 .731 .91 r
.4009 .56946 .403 .57152 .40652 .57059 .40442 .56852 Metetra
.648 .731 .91 r
.40442 .56852 .40652 .57059 .41005 .56965 .40795 .56758 Metetra
.647 .731 .91 r
.40795 .56758 .41005 .56965 .41358 .56872 .41149 .56664 Metetra
.647 .73 .91 r
.41149 .56664 .41358 .56872 .41712 .56779 .41503 .56571 Metetra
.646 .73 .91 r
.41503 .56571 .41712 .56779 .42066 .56687 .41857 .56478 Metetra
.646 .73 .91 r
.41857 .56478 .42066 .56687 .4242 .56595 .42212 .56385 Metetra
.645 .729 .91 r
.42212 .56385 .4242 .56595 .42776 .56503 .42568 .56293 Metetra
.645 .729 .91 r
.42568 .56293 .42776 .56503 .43131 .56411 .42923 .56201 Metetra
.644 .729 .91 r
.42923 .56201 .43131 .56411 .43487 .5632 .4328 .5611 Metetra
.644 .728 .91 r
.4328 .5611 .43487 .5632 .43844 .56229 .43637 .56018 Metetra
.643 .728 .91 r
.43637 .56018 .43844 .56229 .44201 .56139 .43994 .55928 Metetra
.642 .728 .91 r
.43994 .55928 .44201 .56139 .44559 .56049 .44352 .55837 Metetra
.642 .727 .91 r
.44352 .55837 .44559 .56049 .44917 .5596 .4471 .55748 Metetra
.641 .727 .911 r
.4471 .55748 .44917 .5596 .45275 .55871 .45069 .55658 Metetra
.64 .726 .911 r
.45069 .55658 .45275 .55871 .45634 .55783 .45429 .5557 Metetra
.639 .726 .911 r
.45429 .5557 .45634 .55783 .45994 .55696 .45788 .55482 Metetra
.639 .725 .911 r
.45788 .55482 .45994 .55696 .46354 .55609 .46149 .55394 Metetra
.638 .725 .911 r
.46149 .55394 .46354 .55609 .46715 .55523 .4651 .55307 Metetra
.637 .724 .911 r
.4651 .55307 .46715 .55523 .47076 .55437 .46871 .55221 Metetra
.636 .724 .911 r
.46871 .55221 .47076 .55437 .47438 .55352 .47233 .55136 Metetra
.635 .723 .911 r
.47233 .55136 .47438 .55352 .478 .55269 .47596 .55052 Metetra
.634 .722 .911 r
.47596 .55052 .478 .55269 .48163 .55186 .47959 .54968 Metetra
.632 .721 .912 r
.47959 .54968 .48163 .55186 .48526 .55104 .48322 .54886 Metetra
.631 .721 .912 r
.48322 .54886 .48526 .55104 .4889 .55023 .48686 .54804 Metetra
.63 .72 .912 r
.48686 .54804 .4889 .55023 .49254 .54943 .49051 .54724 Metetra
.628 .719 .912 r
.49051 .54724 .49254 .54943 .49619 .54865 .49416 .54645 Metetra
.627 .718 .912 r
.49416 .54645 .49619 .54865 .49984 .54788 .49782 .54567 Metetra
.625 .717 .912 r
.49782 .54567 .49984 .54788 .5035 .54712 .50148 .5449 Metetra
.623 .716 .913 r
.50148 .5449 .5035 .54712 .50717 .54638 .50515 .54415 Metetra
.621 .715 .913 r
.50515 .54415 .50717 .54638 .51084 .54566 .50882 .54342 Metetra
.619 .713 .913 r
.50882 .54342 .51084 .54566 .51451 .54495 .5125 .54271 Metetra
.617 .712 .913 r
.5125 .54271 .51451 .54495 .5182 .54426 .51619 .54201 Metetra
.615 .71 .913 r
.51619 .54201 .5182 .54426 .52189 .5436 .51988 .54134 Metetra
.612 .709 .914 r
.51988 .54134 .52189 .5436 .52558 .54296 .52358 .54068 Metetra
.609 .707 .914 r
.52358 .54068 .52558 .54296 .52928 .54234 .52728 .54006 Metetra
.606 .705 .914 r
.52728 .54006 .52928 .54234 .53299 .54176 .53099 .53946 Metetra
.602 .703 .915 r
.53099 .53946 .53299 .54176 .5367 .5412 .5347 .53889 Metetra
.598 .7 .915 r
.5347 .53889 .5367 .5412 .54042 .54068 .53843 .53836 Metetra
.594 .698 .915 r
.53843 .53836 .54042 .54068 .54415 .5402 .54215 .53786 Metetra
.589 .695 .916 r
.54215 .53786 .54415 .5402 .54788 .53975 .54589 .5374 Metetra
.583 .691 .916 r
.54589 .5374 .54788 .53975 .55162 .53936 .54963 .53699 Metetra
.577 .687 .916 r
.54963 .53699 .55162 .53936 .55536 .53902 .55338 .53663 Metetra
.57 .683 .917 r
.55338 .53663 .55536 .53902 .55912 .53874 .55714 .53633 Metetra
.562 .678 .917 r
.55714 .53633 .55912 .53874 .56288 .53852 .5609 .5361 Metetra
.553 .673 .917 r
.5609 .5361 .56288 .53852 .56665 .53838 .56468 .53593 Metetra
.542 .666 .918 r
.56468 .53593 .56665 .53838 .57043 .53833 .56846 .53586 Metetra
.529 .658 .918 r
.56846 .53586 .57043 .53833 .57422 .53838 .57225 .53588 Metetra
.515 .649 .918 r
.57225 .53588 .57422 .53838 .57802 .53855 .57605 .53601 Metetra
.497 .638 .917 r
.57605 .53601 .57802 .53855 .58182 .53885 .57985 .53627 Metetra
.475 .625 .917 r
.57985 .53627 .58182 .53885 .58564 .53931 .58368 .53669 Metetra
.449 .608 .915 r
.58368 .53669 .58564 .53931 .58947 .53996 .58751 .53729 Metetra
.416 .587 .912 r
.58751 .53729 .58947 .53996 .59332 .54083 .59135 .53811 Metetra
.375 .56 .906 r
.59135 .53811 .59332 .54083 .59718 .54199 .59522 .5392 Metetra
.32 .524 .897 r
.59522 .5392 .59718 .54199 .60106 .54349 .5991 .54062 Metetra
.249 .475 .88 r
.5991 .54062 .60106 .54349 .60496 .54543 .603 .54246 Metetra
.152 .407 .851 r
.603 .54246 .60496 .54543 .60889 .54793 .60692 .54485 Metetra
.021 .31 .8 r
.60692 .54485 .60889 .54793 .61285 .55118 .61088 .54794 Metetra
0 .174 .711 r
.61088 .54794 .61285 .55118 .61686 .55545 .61488 .55201 Metetra
0 0 .564 r
.61488 .55201 .61686 .55545 .62092 .56118 .61893 .55746 Metetra
0 0 .358 r
.61893 .55746 .62092 .56118 .62507 .56909 .62307 .56498 Metetra
.788 .409 0 r
.62307 .56498 .62507 .56909 .62936 .58054 .62733 .57583 Metetra
.905 .551 .086 r
.62733 .57583 .62936 .58054 .63388 .59834 .63181 .59263 Metetra
.96 .636 .244 r
.63181 .59263 .63388 .59834 .63889 .62956 .63674 .62193 Metetra
.978 .678 .353 r
.63674 .62193 .63889 .62956 .6453 .69901 .64295 .6868 Metetra
0 0 .455 r
.64295 .6868 .6453 .69901 .64963 .70522 .64763 .70318 Metetra
.645 .763 .934 r
.64763 .70318 .64963 .70522 .65373 .70412 .65173 .70208 Metetra
.951 .747 .591 r
.65173 .70208 .65373 .70412 .65755 .69576 .65519 .68354 Metetra
.922 .663 .528 r
.65519 .68354 .65755 .69576 .6589 .62394 .65674 .61629 Metetra
.909 .669 .564 r
.65674 .61629 .6589 .62394 .66162 .59036 .65955 .58462 Metetra
.897 .679 .599 r
.65955 .58462 .66162 .59036 .66482 .5702 .6628 .56546 Metetra
.884 .689 .634 r
.6628 .56546 .66482 .5702 .66825 .5564 .66626 .55224 Metetra
.871 .698 .665 r
.66626 .55224 .66825 .5564 .67181 .54613 .66985 .54236 Metetra
.857 .706 .693 r
.66985 .54236 .67181 .54613 .67546 .53804 .67351 .53455 Metetra
.844 .713 .718 r
.67351 .53455 .67546 .53804 .67916 .53142 .67722 .52812 Metetra
.831 .718 .74 r
.67722 .52812 .67916 .53142 .6829 .52581 .68097 .52266 Metetra
.819 .722 .758 r
.68097 .52266 .6829 .52581 .68667 .52095 .68476 .51792 Metetra
.807 .726 .774 r
.68476 .51792 .68667 .52095 .69046 .51666 .68856 .51371 Metetra
.797 .728 .788 r
.68856 .51371 .69046 .51666 .69428 .5128 .69239 .50993 Metetra
.787 .731 .8 r
.69239 .50993 .69428 .5128 .69811 .50928 .69623 .50647 Metetra
.778 .732 .81 r
.69623 .50647 .69811 .50928 .70196 .50604 .70008 .50329 Metetra
.77 .734 .819 r
.70008 .50329 .70196 .50604 .70582 .50304 .70395 .50032 Metetra
.763 .735 .827 r
.70395 .50032 .70582 .50304 .7097 .50022 .70783 .49754 Metetra
.756 .736 .834 r
.70783 .49754 .7097 .50022 .71358 .49756 .71172 .49491 Metetra
.75 .736 .84 r
.71172 .49491 .71358 .49756 .71747 .49503 .71562 .49241 Metetra
.744 .737 .845 r
.71562 .49241 .71747 .49503 .72138 .49262 .71953 .49003 Metetra
.739 .738 .85 r
.71953 .49003 .72138 .49262 .72529 .49032 .72344 .48774 Metetra
.735 .738 .854 r
.72344 .48774 .72529 .49032 .72921 .48809 .72737 .48553 Metetra
.73 .738 .858 r
.72737 .48553 .72921 .48809 .73314 .48595 .7313 .4834 Metetra
.726 .739 .861 r
.7313 .4834 .73314 .48595 .73707 .48387 .73524 .48134 Metetra
.723 .739 .864 r
.73524 .48134 .73707 .48387 .74101 .48185 .73919 .47933 Metetra
.72 .739 .867 r
.73919 .47933 .74101 .48185 .74497 .47988 .74315 .47737 Metetra
.716 .739 .869 r
.74315 .47737 .74497 .47988 .74892 .47796 .74711 .47546 Metetra
.714 .739 .871 r
.74711 .47546 .74892 .47796 .75289 .47608 .75108 .47359 Metetra
.711 .739 .874 r
.75108 .47359 .75289 .47608 .75686 .47424 .75505 .47175 Metetra
.709 .739 .875 r
.75505 .47175 .75686 .47424 .76084 .47243 .75903 .46995 Metetra
.707 .74 .877 r
.75903 .46995 .76084 .47243 .76482 .47065 .76302 .46818 Metetra
.704 .74 .879 r
.76302 .46818 .76482 .47065 .76881 .4689 .76702 .46644 Metetra
.703 .74 .88 r
.76702 .46644 .76881 .4689 .77281 .46718 .77102 .46472 Metetra
.701 .74 .881 r
.77102 .46472 .77281 .46718 .77681 .46548 .77503 .46302 Metetra
.699 .74 .883 r
.77503 .46302 .77681 .46548 .78082 .4638 .77904 .46135 Metetra
.698 .74 .884 r
.77904 .46135 .78082 .4638 .78484 .46214 .78306 .45969 Metetra
.696 .74 .885 r
.78306 .45969 .78484 .46214 .78886 .4605 .78709 .45805 Metetra
.695 .74 .886 r
.78709 .45805 .78886 .4605 .79289 .45888 .79112 .45643 Metetra
.694 .74 .887 r
.79112 .45643 .79289 .45888 .79692 .45727 .79516 .45483 Metetra
.692 .74 .888 r
.79516 .45483 .79692 .45727 .80096 .45567 .79921 .45323 Metetra
.691 .74 .889 r
.79921 .45323 .80096 .45567 .80501 .45409 .80326 .45165 Metetra
.69 .74 .889 r
.80326 .45165 .80501 .45409 .80906 .45252 .80731 .45008 Metetra
.689 .74 .89 r
.80731 .45008 .80906 .45252 .81312 .45096 .81138 .44852 Metetra
.688 .74 .891 r
.81138 .44852 .81312 .45096 .81719 .44941 .81545 .44698 Metetra
.687 .74 .891 r
.81545 .44698 .81719 .44941 .82126 .44788 .81952 .44544 Metetra
.686 .74 .892 r
.81952 .44544 .82126 .44788 .82533 .44635 .8236 .44391 Metetra
.686 .74 .892 r
.8236 .44391 .82533 .44635 .82942 .44482 .82769 .44238 Metetra
.685 .74 .893 r
.82769 .44238 .82942 .44482 .83351 .44331 .83179 .44087 Metetra
.684 .74 .894 r
.83179 .44087 .83351 .44331 .8376 .4418 .83588 .43936 Metetra
.684 .74 .894 r
.83588 .43936 .8376 .4418 .8417 .4403 .83999 .43786 Metetra
.683 .74 .894 r
.83999 .43786 .8417 .4403 .84581 .43881 .8441 .43637 Metetra
.682 .74 .895 r
.8441 .43637 .84581 .43881 .84992 .43732 .84822 .43488 Metetra
.682 .74 .895 r
.84822 .43488 .84992 .43732 .85404 .43583 .85234 .43339 Metetra
.681 .74 .896 r
.85234 .43339 .85404 .43583 .85817 .43436 .85647 .43191 Metetra
.681 .74 .896 r
.85647 .43191 .85817 .43436 .8623 .43288 .86061 .43044 Metetra
.68 .74 .896 r
.86061 .43044 .8623 .43288 .86643 .43141 .86475 .42897 Metetra
.68 .74 .897 r
.86475 .42897 .86643 .43141 .87058 .42995 .8689 .4275 Metetra
.679 .74 .897 r
.8689 .4275 .87058 .42995 .87473 .42849 .87305 .42604 Metetra
.679 .74 .897 r
.87305 .42604 .87473 .42849 .87888 .42703 .87721 .42458 Metetra
.678 .74 .898 r
.87721 .42458 .87888 .42703 .88304 .42557 .88138 .42312 Metetra
.678 .74 .898 r
.88138 .42312 .88304 .42557 .88721 .42412 .88555 .42167 Metetra
.677 .74 .898 r
.88555 .42167 .88721 .42412 .89138 .42267 .88973 .42022 Metetra
.677 .74 .898 r
.88973 .42022 .89138 .42267 .89556 .42123 .89391 .41877 Metetra
.677 .74 .899 r
.89391 .41877 .89556 .42123 .89975 .41978 .8981 .41732 Metetra
.676 .74 .899 r
.8981 .41732 .89975 .41978 .90394 .41834 .9023 .41588 Metetra
.676 .74 .899 r
.9023 .41588 .90394 .41834 .90814 .4169 .9065 .41444 Metetra
.676 .74 .899 r
.9065 .41444 .90814 .4169 .91234 .41546 .91071 .413 Metetra
.675 .74 .9 r
.91071 .413 .91234 .41546 .91655 .41403 .91492 .41156 Metetra
.675 .74 .9 r
.91492 .41156 .91655 .41403 .92077 .41259 .91914 .41012 Metetra
.675 .741 .9 r
.91914 .41012 .92077 .41259 .92499 .41116 .92337 .40869 Metetra
.675 .741 .9 r
.92337 .40869 .92499 .41116 .92922 .40973 .9276 .40725 Metetra
.674 .741 .9 r
.9276 .40725 .92922 .40973 .93345 .4083 .93184 .40582 Metetra
.674 .741 .901 r
.93184 .40582 .93345 .4083 .93769 .40687 .93609 .40439 Metetra
.674 .741 .901 r
.93609 .40439 .93769 .40687 .94194 .40544 .94034 .40296 Metetra
.674 .741 .901 r
.94034 .40296 .94194 .40544 .94619 .40401 .9446 .40153 Metetra
.651 .733 .909 r
.36726 .57597 .36939 .57801 .37287 .57705 .37074 .57501 Metetra
.651 .733 .909 r
.37074 .57501 .37287 .57705 .37636 .5761 .37423 .57405 Metetra
.651 .733 .909 r
.37423 .57405 .37636 .5761 .37985 .57514 .37773 .57309 Metetra
.65 .733 .909 r
.37773 .57309 .37985 .57514 .38334 .57419 .38123 .57214 Metetra
.65 .732 .909 r
.38123 .57214 .38334 .57419 .38685 .57324 .38473 .57118 Metetra
.65 .732 .909 r
.38473 .57118 .38685 .57324 .39035 .57229 .38824 .57023 Metetra
.649 .732 .91 r
.38824 .57023 .39035 .57229 .39386 .57134 .39175 .56928 Metetra
.649 .732 .91 r
.39175 .56928 .39386 .57134 .39738 .5704 .39527 .56833 Metetra
.649 .731 .91 r
.39527 .56833 .39738 .5704 .4009 .56946 .39879 .56739 Metetra
.648 .731 .91 r
.39879 .56739 .4009 .56946 .40442 .56852 .40232 .56644 Metetra
.648 .731 .91 r
.40232 .56644 .40442 .56852 .40795 .56758 .40585 .5655 Metetra
.647 .731 .91 r
.40585 .5655 .40795 .56758 .41149 .56664 .40939 .56456 Metetra
.647 .73 .91 r
.40939 .56456 .41149 .56664 .41503 .56571 .41293 .56362 Metetra
.646 .73 .91 r
.41293 .56362 .41503 .56571 .41857 .56478 .41648 .56269 Metetra
.646 .73 .91 r
.41648 .56269 .41857 .56478 .42212 .56385 .42003 .56176 Metetra
.646 .73 .91 r
.42003 .56176 .42212 .56385 .42568 .56293 .42359 .56083 Metetra
.645 .729 .91 r
.42359 .56083 .42568 .56293 .42923 .56201 .42715 .55991 Metetra
.644 .729 .91 r
.42715 .55991 .42923 .56201 .4328 .5611 .43072 .55899 Metetra
.644 .728 .91 r
.43072 .55899 .4328 .5611 .43637 .56018 .43429 .55807 Metetra
.643 .728 .91 r
.43429 .55807 .43637 .56018 .43994 .55928 .43787 .55716 Metetra
.643 .728 .91 r
.43787 .55716 .43994 .55928 .44352 .55837 .44145 .55625 Metetra
.642 .727 .91 r
.44145 .55625 .44352 .55837 .4471 .55748 .44503 .55535 Metetra
.641 .727 .91 r
.44503 .55535 .4471 .55748 .45069 .55658 .44863 .55445 Metetra
.641 .726 .911 r
.44863 .55445 .45069 .55658 .45429 .5557 .45222 .55356 Metetra
.64 .726 .911 r
.45222 .55356 .45429 .5557 .45788 .55482 .45583 .55267 Metetra
.639 .725 .911 r
.45583 .55267 .45788 .55482 .46149 .55394 .45943 .55179 Metetra
.638 .725 .911 r
.45943 .55179 .46149 .55394 .4651 .55307 .46304 .55092 Metetra
.637 .724 .911 r
.46304 .55092 .4651 .55307 .46871 .55221 .46666 .55005 Metetra
.636 .724 .911 r
.46666 .55005 .46871 .55221 .47233 .55136 .47028 .54919 Metetra
.635 .723 .911 r
.47028 .54919 .47233 .55136 .47596 .55052 .47391 .54834 Metetra
.634 .722 .911 r
.47391 .54834 .47596 .55052 .47959 .54968 .47754 .5475 Metetra
.633 .722 .911 r
.47754 .5475 .47959 .54968 .48322 .54886 .48118 .54667 Metetra
.632 .721 .911 r
.48118 .54667 .48322 .54886 .48686 .54804 .48483 .54585 Metetra
.63 .72 .912 r
.48483 .54585 .48686 .54804 .49051 .54724 .48848 .54504 Metetra
.629 .719 .912 r
.48848 .54504 .49051 .54724 .49416 .54645 .49213 .54424 Metetra
.627 .718 .912 r
.49213 .54424 .49416 .54645 .49782 .54567 .49579 .54345 Metetra
.626 .717 .912 r
.49579 .54345 .49782 .54567 .50148 .5449 .49946 .54268 Metetra
.624 .716 .912 r
.49946 .54268 .50148 .5449 .50515 .54415 .50313 .54192 Metetra
.622 .715 .912 r
.50313 .54192 .50515 .54415 .50882 .54342 .5068 .54118 Metetra
.62 .714 .913 r
.5068 .54118 .50882 .54342 .5125 .54271 .51049 .54046 Metetra
.618 .712 .913 r
.51049 .54046 .5125 .54271 .51619 .54201 .51417 .53975 Metetra
.615 .711 .913 r
.51417 .53975 .51619 .54201 .51988 .54134 .51787 .53907 Metetra
.613 .709 .913 r
.51787 .53907 .51988 .54134 .52358 .54068 .52157 .5384 Metetra
.61 .707 .914 r
.52157 .5384 .52358 .54068 .52728 .54006 .52527 .53777 Metetra
.607 .705 .914 r
.52527 .53777 .52728 .54006 .53099 .53946 .52899 .53716 Metetra
.603 .703 .914 r
.52899 .53716 .53099 .53946 .5347 .53889 .5327 .53658 Metetra
.599 .701 .915 r
.5327 .53658 .5347 .53889 .53843 .53836 .53643 .53603 Metetra
.595 .698 .915 r
.53643 .53603 .53843 .53836 .54215 .53786 .54016 .53552 Metetra
.59 .695 .915 r
.54016 .53552 .54215 .53786 .54589 .5374 .5439 .53504 Metetra
.585 .692 .916 r
.5439 .53504 .54589 .5374 .54963 .53699 .54764 .53462 Metetra
.579 .688 .916 r
.54764 .53462 .54963 .53699 .55338 .53663 .55139 .53424 Metetra
.572 .684 .916 r
.55139 .53424 .55338 .53663 .55714 .53633 .55515 .53392 Metetra
.564 .679 .917 r
.55515 .53392 .55714 .53633 .5609 .5361 .55892 .53366 Metetra
.555 .674 .917 r
.55892 .53366 .5609 .5361 .56468 .53593 .56269 .53348 Metetra
.545 .667 .917 r
.56269 .53348 .56468 .53593 .56846 .53586 .56648 .53337 Metetra
.533 .66 .917 r
.56648 .53337 .56846 .53586 .57225 .53588 .57027 .53336 Metetra
.519 .651 .917 r
.57027 .53336 .57225 .53588 .57605 .53601 .57407 .53346 Metetra
.502 .64 .917 r
.57407 .53346 .57605 .53601 .57985 .53627 .57788 .53369 Metetra
.482 .628 .916 r
.57788 .53369 .57985 .53627 .58368 .53669 .5817 .53406 Metetra
.457 .612 .915 r
.5817 .53406 .58368 .53669 .58751 .53729 .58554 .53462 Metetra
.426 .592 .912 r
.58554 .53462 .58751 .53729 .59135 .53811 .58938 .53538 Metetra
.387 .566 .907 r
.58938 .53538 .59135 .53811 .59522 .5392 .59325 .5364 Metetra
.336 .532 .898 r
.59325 .5364 .59522 .5392 .5991 .54062 .59713 .53774 Metetra
.269 .486 .884 r
.59713 .53774 .5991 .54062 .603 .54246 .60102 .53949 Metetra
.179 .423 .858 r
.60102 .53949 .603 .54246 .60692 .54485 .60495 .54174 Metetra
.057 .334 .813 r
.60495 .54174 .60692 .54485 .61088 .54794 .6089 .54468 Metetra
0 .207 .734 r
.6089 .54468 .61088 .54794 .61488 .55201 .61289 .54854 Metetra
0 .035 .602 r
.61289 .54854 .61488 .55201 .61893 .55746 .61694 .55371 Metetra
0 0 .407 r
.61694 .55371 .61893 .55746 .62307 .56498 .62106 .56082 Metetra
.752 .375 0 r
.62106 .56082 .62307 .56498 .62733 .57583 .6253 .57105 Metetra
.886 .53 .046 r
.6253 .57105 .62733 .57583 .63181 .59263 .62974 .58678 Metetra
.954 .627 .217 r
.62974 .58678 .63181 .59263 .63674 .62193 .63459 .61396 Metetra
.978 .676 .337 r
.63459 .61396 .63674 .62193 .64295 .6868 .64057 .67315 Metetra
0 0 .153 r
.64057 .67315 .64295 .6868 .64763 .70318 .64562 .70115 Metetra
.645 .763 .934 r
.64562 .70115 .64763 .70318 .65173 .70208 .64973 .70004 Metetra
.96 .728 .543 r
.64973 .70004 .65173 .70208 .65519 .68354 .65277 .66986 Metetra
.911 .654 .537 r
.65277 .66986 .65519 .68354 .65674 .61629 .65456 .60829 Metetra
.902 .664 .57 r
.65456 .60829 .65674 .61629 .65955 .58462 .65747 .57874 Metetra
.891 .676 .605 r
.65747 .57874 .65955 .58462 .6628 .56546 .66077 .56064 Metetra
.879 .686 .638 r
.66077 .56064 .6628 .56546 .66626 .55224 .66427 .54804 Metetra
.866 .696 .669 r
.66427 .54804 .66626 .55224 .66985 .54236 .66788 .53856 Metetra
.853 .704 .697 r
.66788 .53856 .66985 .54236 .67351 .53455 .67156 .53103 Metetra
.84 .711 .722 r
.67156 .53103 .67351 .53455 .67722 .52812 .67528 .5248 Metetra
.827 .717 .743 r
.67528 .5248 .67722 .52812 .68097 .52266 .67905 .5195 Metetra
.815 .721 .761 r
.67905 .5195 .68097 .52266 .68476 .51792 .68284 .51487 Metetra
.804 .725 .777 r
.68284 .51487 .68476 .51792 .68856 .51371 .68665 .51076 Metetra
.794 .727 .79 r
.68665 .51076 .68856 .51371 .69239 .50993 .69049 .50705 Metetra
.784 .73 .802 r
.69049 .50705 .69239 .50993 .69623 .50647 .69433 .50365 Metetra
.776 .732 .812 r
.69433 .50365 .69623 .50647 .70008 .50329 .6982 .50052 Metetra
.768 .733 .821 r
.6982 .50052 .70008 .50329 .70395 .50032 .70207 .4976 Metetra
.761 .734 .828 r
.70207 .4976 .70395 .50032 .70783 .49754 .70596 .49485 Metetra
.754 .735 .835 r
.70596 .49485 .70783 .49754 .71172 .49491 .70985 .49225 Metetra
.748 .736 .841 r
.70985 .49225 .71172 .49491 .71562 .49241 .71376 .48978 Metetra
.743 .736 .846 r
.71376 .48978 .71562 .49241 .71953 .49003 .71767 .48742 Metetra
.738 .737 .851 r
.71767 .48742 .71953 .49003 .72344 .48774 .72159 .48515 Metetra
.733 .737 .855 r
.72159 .48515 .72344 .48774 .72737 .48553 .72552 .48297 Metetra
.729 .738 .858 r
.72552 .48297 .72737 .48553 .7313 .4834 .72946 .48085 Metetra
.725 .738 .862 r
.72946 .48085 .7313 .4834 .73524 .48134 .73341 .4788 Metetra
.722 .738 .865 r
.73341 .4788 .73524 .48134 .73919 .47933 .73736 .4768 Metetra
.719 .739 .867 r
.73736 .4768 .73919 .47933 .74315 .47737 .74132 .47485 Metetra
.716 .739 .87 r
.74132 .47485 .74315 .47737 .74711 .47546 .74529 .47295 Metetra
.713 .739 .872 r
.74529 .47295 .74711 .47546 .75108 .47359 .74926 .47109 Metetra
.71 .739 .874 r
.74926 .47109 .75108 .47359 .75505 .47175 .75324 .46926 Metetra
.708 .739 .876 r
.75324 .46926 .75505 .47175 .75903 .46995 .75723 .46747 Metetra
.706 .739 .877 r
.75723 .46747 .75903 .46995 .76302 .46818 .76122 .4657 Metetra
.704 .739 .879 r
.76122 .4657 .76302 .46818 .76702 .46644 .76522 .46396 Metetra
.702 .739 .88 r
.76522 .46396 .76702 .46644 .77102 .46472 .76923 .46225 Metetra
.7 .74 .882 r
.76923 .46225 .77102 .46472 .77503 .46302 .77324 .46056 Metetra
.699 .74 .883 r
.77324 .46056 .77503 .46302 .77904 .46135 .77726 .45889 Metetra
.697 .74 .884 r
.77726 .45889 .77904 .46135 .78306 .45969 .78128 .45724 Metetra
.696 .74 .885 r
.78128 .45724 .78306 .45969 .78709 .45805 .78532 .4556 Metetra
.694 .74 .886 r
.78532 .4556 .78709 .45805 .79112 .45643 .78935 .45398 Metetra
.693 .74 .887 r
.78935 .45398 .79112 .45643 .79516 .45483 .7934 .45237 Metetra
.692 .74 .888 r
.7934 .45237 .79516 .45483 .79921 .45323 .79745 .45078 Metetra
.691 .74 .889 r
.79745 .45078 .79921 .45323 .80326 .45165 .8015 .4492 Metetra
.69 .74 .889 r
.8015 .4492 .80326 .45165 .80731 .45008 .80556 .44764 Metetra
.689 .74 .89 r
.80556 .44764 .80731 .45008 .81138 .44852 .80963 .44608 Metetra
.688 .74 .891 r
.80963 .44608 .81138 .44852 .81545 .44698 .81371 .44453 Metetra
.687 .74 .891 r
.81371 .44453 .81545 .44698 .81952 .44544 .81778 .44299 Metetra
.686 .74 .892 r
.81778 .44299 .81952 .44544 .8236 .44391 .82187 .44146 Metetra
.685 .74 .893 r
.82187 .44146 .8236 .44391 .82769 .44238 .82596 .43994 Metetra
.685 .74 .893 r
.82596 .43994 .82769 .44238 .83179 .44087 .83006 .43842 Metetra
.684 .74 .894 r
.83006 .43842 .83179 .44087 .83588 .43936 .83416 .43692 Metetra
.683 .74 .894 r
.83416 .43692 .83588 .43936 .83999 .43786 .83827 .43542 Metetra
.683 .74 .895 r
.83827 .43542 .83999 .43786 .8441 .43637 .84239 .43392 Metetra
.682 .74 .895 r
.84239 .43392 .8441 .43637 .84822 .43488 .84651 .43243 Metetra
.681 .74 .895 r
.84651 .43243 .84822 .43488 .85234 .43339 .85064 .43094 Metetra
.681 .74 .896 r
.85064 .43094 .85234 .43339 .85647 .43191 .85477 .42946 Metetra
.68 .74 .896 r
.85477 .42946 .85647 .43191 .86061 .43044 .85891 .42799 Metetra
.68 .74 .896 r
.85891 .42799 .86061 .43044 .86475 .42897 .86306 .42652 Metetra
.679 .74 .897 r
.86306 .42652 .86475 .42897 .8689 .4275 .86721 .42505 Metetra
.679 .74 .897 r
.86721 .42505 .8689 .4275 .87305 .42604 .87137 .42358 Metetra
.678 .74 .897 r
.87137 .42358 .87305 .42604 .87721 .42458 .87554 .42212 Metetra
.678 .74 .898 r
.87554 .42212 .87721 .42458 .88138 .42312 .87971 .42066 Metetra
.678 .74 .898 r
.87971 .42066 .88138 .42312 .88555 .42167 .88388 .41921 Metetra
.677 .74 .898 r
.88388 .41921 .88555 .42167 .88973 .42022 .88806 .41776 Metetra
.677 .74 .898 r
.88806 .41776 .88973 .42022 .89391 .41877 .89225 .41631 Metetra
.677 .74 .899 r
.89225 .41631 .89391 .41877 .8981 .41732 .89645 .41486 Metetra
.676 .74 .899 r
.89645 .41486 .8981 .41732 .9023 .41588 .90065 .41341 Metetra
.676 .74 .899 r
.90065 .41341 .9023 .41588 .9065 .41444 .90486 .41197 Metetra
.676 .74 .899 r
.90486 .41197 .9065 .41444 .91071 .413 .90907 .41053 Metetra
.675 .74 .9 r
.90907 .41053 .91071 .413 .91492 .41156 .91329 .40909 Metetra
.675 .74 .9 r
.91329 .40909 .91492 .41156 .91914 .41012 .91751 .40765 Metetra
.675 .74 .9 r
.91751 .40765 .91914 .41012 .92337 .40869 .92174 .40621 Metetra
.674 .74 .9 r
.92174 .40621 .92337 .40869 .9276 .40725 .92598 .40477 Metetra
.674 .74 .9 r
.92598 .40477 .9276 .40725 .93184 .40582 .93022 .40334 Metetra
.674 .74 .901 r
.93022 .40334 .93184 .40582 .93609 .40439 .93447 .4019 Metetra
.674 .74 .901 r
.93447 .4019 .93609 .40439 .94034 .40296 .93873 .40047 Metetra
.673 .741 .901 r
.93873 .40047 .94034 .40296 .9446 .40153 .94299 .39904 Metetra
.651 .733 .909 r
.36512 .57393 .36726 .57597 .37074 .57501 .36861 .57297 Metetra
.651 .733 .909 r
.36861 .57297 .37074 .57501 .37423 .57405 .3721 .572 Metetra
.651 .733 .909 r
.3721 .572 .37423 .57405 .37773 .57309 .3756 .57104 Metetra
.65 .733 .909 r
.3756 .57104 .37773 .57309 .38123 .57214 .3791 .57008 Metetra
.65 .732 .909 r
.3791 .57008 .38123 .57214 .38473 .57118 .38261 .56912 Metetra
.65 .732 .909 r
.38261 .56912 .38473 .57118 .38824 .57023 .38612 .56817 Metetra
.649 .732 .909 r
.38612 .56817 .38824 .57023 .39175 .56928 .38964 .56721 Metetra
.649 .732 .909 r
.38964 .56721 .39175 .56928 .39527 .56833 .39316 .56626 Metetra
.649 .731 .91 r
.39316 .56626 .39527 .56833 .39879 .56739 .39668 .56531 Metetra
.648 .731 .91 r
.39668 .56531 .39879 .56739 .40232 .56644 .40021 .56436 Metetra
.648 .731 .91 r
.40021 .56436 .40232 .56644 .40585 .5655 .40375 .56341 Metetra
.648 .731 .91 r
.40375 .56341 .40585 .5655 .40939 .56456 .40729 .56247 Metetra
.647 .73 .91 r
.40729 .56247 .40939 .56456 .41293 .56362 .41083 .56153 Metetra
.647 .73 .91 r
.41083 .56153 .41293 .56362 .41648 .56269 .41438 .56059 Metetra
.646 .73 .91 r
.41438 .56059 .41648 .56269 .42003 .56176 .41794 .55966 Metetra
.646 .73 .91 r
.41794 .55966 .42003 .56176 .42359 .56083 .4215 .55872 Metetra
.645 .729 .91 r
.4215 .55872 .42359 .56083 .42715 .55991 .42506 .5578 Metetra
.645 .729 .91 r
.42506 .5578 .42715 .55991 .43072 .55899 .42863 .55687 Metetra
.644 .729 .91 r
.42863 .55687 .43072 .55899 .43429 .55807 .43221 .55595 Metetra
.644 .728 .91 r
.43221 .55595 .43429 .55807 .43787 .55716 .43579 .55503 Metetra
.643 .728 .91 r
.43579 .55503 .43787 .55716 .44145 .55625 .43937 .55412 Metetra
.642 .727 .91 r
.43937 .55412 .44145 .55625 .44503 .55535 .44296 .55321 Metetra
.642 .727 .91 r
.44296 .55321 .44503 .55535 .44863 .55445 .44656 .55231 Metetra
.641 .726 .91 r
.44656 .55231 .44863 .55445 .45222 .55356 .45016 .55141 Metetra
.64 .726 .91 r
.45016 .55141 .45222 .55356 .45583 .55267 .45376 .55052 Metetra
.639 .725 .911 r
.45376 .55052 .45583 .55267 .45943 .55179 .45737 .54963 Metetra
.638 .725 .911 r
.45737 .54963 .45943 .55179 .46304 .55092 .46099 .54876 Metetra
.638 .724 .911 r
.46099 .54876 .46304 .55092 .46666 .55005 .46461 .54788 Metetra
.637 .724 .911 r
.46461 .54788 .46666 .55005 .47028 .54919 .46823 .54702 Metetra
.636 .723 .911 r
.46823 .54702 .47028 .54919 .47391 .54834 .47186 .54616 Metetra
.635 .722 .911 r
.47186 .54616 .47391 .54834 .47754 .5475 .4755 .54532 Metetra
.633 .722 .911 r
.4755 .54532 .47754 .5475 .48118 .54667 .47914 .54448 Metetra
.632 .721 .911 r
.47914 .54448 .48118 .54667 .48483 .54585 .48278 .54365 Metetra
.631 .72 .911 r
.48278 .54365 .48483 .54585 .48848 .54504 .48644 .54283 Metetra
.629 .719 .912 r
.48644 .54283 .48848 .54504 .49213 .54424 .49009 .54202 Metetra
.628 .718 .912 r
.49009 .54202 .49213 .54424 .49579 .54345 .49376 .54123 Metetra
.626 .717 .912 r
.49376 .54123 .49579 .54345 .49946 .54268 .49742 .54045 Metetra
.625 .716 .912 r
.49742 .54045 .49946 .54268 .50313 .54192 .5011 .53968 Metetra
.623 .715 .912 r
.5011 .53968 .50313 .54192 .5068 .54118 .50478 .53893 Metetra
.621 .714 .912 r
.50478 .53893 .5068 .54118 .51049 .54046 .50846 .5382 Metetra
.619 .712 .913 r
.50846 .5382 .51049 .54046 .51417 .53975 .51215 .53749 Metetra
.616 .711 .913 r
.51215 .53749 .51417 .53975 .51787 .53907 .51585 .53679 Metetra
.614 .709 .913 r
.51585 .53679 .51787 .53907 .52157 .5384 .51955 .53612 Metetra
.611 .708 .913 r
.51955 .53612 .52157 .5384 .52527 .53777 .52326 .53547 Metetra
.608 .706 .914 r
.52326 .53547 .52527 .53777 .52899 .53716 .52698 .53485 Metetra
.604 .704 .914 r
.52698 .53485 .52899 .53716 .5327 .53658 .5307 .53426 Metetra
.601 .701 .914 r
.5307 .53426 .5327 .53658 .53643 .53603 .53443 .53369 Metetra
.597 .699 .914 r
.53443 .53369 .53643 .53603 .54016 .53552 .53816 .53317 Metetra
.592 .696 .915 r
.53816 .53317 .54016 .53552 .5439 .53504 .5419 .53268 Metetra
.587 .693 .915 r
.5419 .53268 .5439 .53504 .54764 .53462 .54565 .53224 Metetra
.581 .689 .915 r
.54565 .53224 .54764 .53462 .55139 .53424 .5494 .53184 Metetra
.574 .685 .916 r
.5494 .53184 .55139 .53424 .55515 .53392 .55316 .5315 Metetra
.567 .68 .916 r
.55316 .5315 .55515 .53392 .55892 .53366 .55693 .53122 Metetra
.558 .675 .916 r
.55693 .53122 .55892 .53366 .56269 .53348 .56071 .53101 Metetra
.548 .669 .917 r
.56071 .53101 .56269 .53348 .56648 .53337 .56449 .53088 Metetra
.537 .662 .917 r
.56449 .53088 .56648 .53337 .57027 .53336 .56829 .53084 Metetra
.523 .653 .917 r
.56829 .53084 .57027 .53336 .57407 .53346 .57209 .53091 Metetra
.507 .643 .916 r
.57209 .53091 .57407 .53346 .57788 .53369 .5759 .5311 Metetra
.488 .63 .916 r
.5759 .5311 .57788 .53369 .5817 .53406 .57973 .53143 Metetra
.464 .615 .914 r
.57973 .53143 .5817 .53406 .58554 .53462 .58356 .53193 Metetra
.435 .596 .912 r
.58356 .53193 .58554 .53462 .58938 .53538 .58741 .53264 Metetra
.398 .572 .907 r
.58741 .53264 .58938 .53538 .59325 .5364 .59127 .5336 Metetra
.351 .54 .9 r
.59127 .5336 .59325 .5364 .59713 .53774 .59515 .53486 Metetra
.289 .498 .887 r
.59515 .53486 .59713 .53774 .60102 .53949 .59905 .5365 Metetra
.205 .439 .864 r
.59905 .5365 .60102 .53949 .60495 .54174 .60297 .53863 Metetra
.092 .357 .825 r
.60297 .53863 .60495 .54174 .6089 .54468 .60692 .54141 Metetra
0 .239 .755 r
.60692 .54141 .6089 .54468 .61289 .54854 .61091 .54506 Metetra
0 .078 .637 r
.61091 .54506 .61289 .54854 .61694 .55371 .61494 .54994 Metetra
0 0 .456 r
.61494 .54994 .61694 .55371 .62106 .56082 .61905 .55664 Metetra
.709 .335 0 r
.61905 .55664 .62106 .56082 .6253 .57105 .62326 .56623 Metetra
.862 .505 .001 r
.62326 .56623 .6253 .57105 .62974 .58678 .62766 .58087 Metetra
.944 .615 .186 r
.62766 .58087 .62974 .58678 .63459 .61396 .63242 .60584 Metetra
.976 .673 .318 r
.63242 .60584 .63459 .61396 .64057 .67315 .63817 .65885 Metetra
.865 .598 .067 r
.63817 .65885 .64057 .67315 .64562 .70115 .64361 .6991 Metetra
.645 .763 .934 r
.64361 .6991 .64562 .70115 .64973 .70004 .64772 .69799 Metetra
.963 .718 .518 r
.64772 .69799 .64973 .70004 .65277 .66986 .65034 .65553 Metetra
.901 .647 .544 r
.65034 .65553 .65277 .66986 .65456 .60829 .65238 .60013 Metetra
.895 .66 .576 r
.65238 .60013 .65456 .60829 .65747 .57874 .65539 .57279 Metetra
.885 .673 .61 r
.65539 .57279 .65747 .57874 .66077 .56064 .65874 .55578 Metetra
.874 .684 .643 r
.65874 .55578 .66077 .56064 .66427 .54804 .66227 .54382 Metetra
.861 .694 .674 r
.66227 .54382 .66427 .54804 .66788 .53856 .6659 .53475 Metetra
.848 .703 .701 r
.6659 .53475 .66788 .53856 .67156 .53103 .6696 .5275 Metetra
.836 .71 .725 r
.6696 .5275 .67156 .53103 .67528 .5248 .67334 .52147 Metetra
.823 .716 .746 r
.67334 .52147 .67528 .5248 .67905 .5195 .67712 .51632 Metetra
.812 .72 .764 r
.67712 .51632 .67905 .5195 .68284 .51487 .68092 .51181 Metetra
.801 .724 .779 r
.68092 .51181 .68284 .51487 .68665 .51076 .68474 .50779 Metetra
.791 .727 .792 r
.68474 .50779 .68665 .51076 .69049 .50705 .68858 .50416 Metetra
.782 .729 .804 r
.68858 .50416 .69049 .50705 .69433 .50365 .69244 .50083 Metetra
.773 .731 .814 r
.69244 .50083 .69433 .50365 .6982 .50052 .69631 .49775 Metetra
.766 .732 .822 r
.69631 .49775 .6982 .50052 .70207 .4976 .70019 .49487 Metetra
.759 .733 .83 r
.70019 .49487 .70207 .4976 .70596 .49485 .70408 .49216 Metetra
.752 .734 .836 r
.70408 .49216 .70596 .49485 .70985 .49225 .70798 .48959 Metetra
.746 .735 .842 r
.70798 .48959 .70985 .49225 .71376 .48978 .71189 .48715 Metetra
.741 .736 .847 r
.71189 .48715 .71376 .48978 .71767 .48742 .71581 .48481 Metetra
.736 .737 .851 r
.71581 .48481 .71767 .48742 .72159 .48515 .71974 .48256 Metetra
.732 .737 .855 r
.71974 .48256 .72159 .48515 .72552 .48297 .72368 .48039 Metetra
.728 .737 .859 r
.72368 .48039 .72552 .48297 .72946 .48085 .72762 .47829 Metetra
.724 .738 .862 r
.72762 .47829 .72946 .48085 .73341 .4788 .73157 .47625 Metetra
.721 .738 .865 r
.73157 .47625 .73341 .4788 .73736 .4768 .73553 .47427 Metetra
.718 .738 .868 r
.73553 .47427 .73736 .4768 .74132 .47485 .73949 .47233 Metetra
.715 .738 .87 r
.73949 .47233 .74132 .47485 .74529 .47295 .74346 .47044 Metetra
.712 .739 .872 r
.74346 .47044 .74529 .47295 .74926 .47109 .74744 .46859 Metetra
.71 .739 .874 r
.74744 .46859 .74926 .47109 .75324 .46926 .75143 .46677 Metetra
.707 .739 .876 r
.75143 .46677 .75324 .46926 .75723 .46747 .75542 .46498 Metetra
.705 .739 .878 r
.75542 .46498 .75723 .46747 .76122 .4657 .75942 .46322 Metetra
.703 .739 .879 r
.75942 .46322 .76122 .4657 .76522 .46396 .76342 .46149 Metetra
.701 .739 .881 r
.76342 .46149 .76522 .46396 .76923 .46225 .76743 .45978 Metetra
.7 .739 .882 r
.76743 .45978 .76923 .46225 .77324 .46056 .77145 .45809 Metetra
.698 .739 .883 r
.77145 .45809 .77324 .46056 .77726 .45889 .77547 .45642 Metetra
.697 .739 .884 r
.77547 .45642 .77726 .45889 .78128 .45724 .7795 .45477 Metetra
.695 .74 .885 r
.7795 .45477 .78128 .45724 .78532 .4556 .78354 .45314 Metetra
.694 .74 .886 r
.78354 .45314 .78532 .4556 .78935 .45398 .78758 .45152 Metetra
.693 .74 .887 r
.78758 .45152 .78935 .45398 .7934 .45237 .79163 .44992 Metetra
.692 .74 .888 r
.79163 .44992 .7934 .45237 .79745 .45078 .79568 .44833 Metetra
.69 .74 .889 r
.79568 .44833 .79745 .45078 .8015 .4492 .79974 .44675 Metetra
.689 .74 .89 r
.79974 .44675 .8015 .4492 .80556 .44764 .80381 .44518 Metetra
.688 .74 .89 r
.80381 .44518 .80556 .44764 .80963 .44608 .80788 .44363 Metetra
.688 .74 .891 r
.80788 .44363 .80963 .44608 .81371 .44453 .81196 .44208 Metetra
.687 .74 .892 r
.81196 .44208 .81371 .44453 .81778 .44299 .81604 .44054 Metetra
.686 .74 .892 r
.81604 .44054 .81778 .44299 .82187 .44146 .82013 .43901 Metetra
.685 .74 .893 r
.82013 .43901 .82187 .44146 .82596 .43994 .82423 .43749 Metetra
.684 .74 .893 r
.82423 .43749 .82596 .43994 .83006 .43842 .82833 .43597 Metetra
.684 .74 .894 r
.82833 .43597 .83006 .43842 .83416 .43692 .83244 .43447 Metetra
.683 .74 .894 r
.83244 .43447 .83416 .43692 .83827 .43542 .83655 .43296 Metetra
.682 .74 .895 r
.83655 .43296 .83827 .43542 .84239 .43392 .84067 .43147 Metetra
.682 .74 .895 r
.84067 .43147 .84239 .43392 .84651 .43243 .8448 .42998 Metetra
.681 .74 .895 r
.8448 .42998 .84651 .43243 .85064 .43094 .84893 .42849 Metetra
.681 .74 .896 r
.84893 .42849 .85064 .43094 .85477 .42946 .85307 .42701 Metetra
.68 .74 .896 r
.85307 .42701 .85477 .42946 .85891 .42799 .85722 .42553 Metetra
.68 .74 .897 r
.85722 .42553 .85891 .42799 .86306 .42652 .86137 .42406 Metetra
.679 .74 .897 r
.86137 .42406 .86306 .42652 .86721 .42505 .86552 .42259 Metetra
.679 .74 .897 r
.86552 .42259 .86721 .42505 .87137 .42358 .86969 .42112 Metetra
.678 .74 .897 r
.86969 .42112 .87137 .42358 .87554 .42212 .87386 .41966 Metetra
.678 .74 .898 r
.87386 .41966 .87554 .42212 .87971 .42066 .87803 .4182 Metetra
.678 .74 .898 r
.87803 .4182 .87971 .42066 .88388 .41921 .88221 .41674 Metetra
.677 .74 .898 r
.88221 .41674 .88388 .41921 .88806 .41776 .8864 .41529 Metetra
.677 .74 .899 r
.8864 .41529 .88806 .41776 .89225 .41631 .89059 .41384 Metetra
.676 .74 .899 r
.89059 .41384 .89225 .41631 .89645 .41486 .89479 .41239 Metetra
.676 .74 .899 r
.89479 .41239 .89645 .41486 .90065 .41341 .899 .41094 Metetra
.676 .74 .899 r
.899 .41094 .90065 .41341 .90486 .41197 .90321 .40949 Metetra
.675 .74 .899 r
.90321 .40949 .90486 .41197 .90907 .41053 .90742 .40805 Metetra
.675 .74 .9 r
.90742 .40805 .90907 .41053 .91329 .40909 .91165 .40661 Metetra
.675 .74 .9 r
.91165 .40661 .91329 .40909 .91751 .40765 .91588 .40517 Metetra
.675 .74 .9 r
.91588 .40517 .91751 .40765 .92174 .40621 .92011 .40373 Metetra
.674 .74 .9 r
.92011 .40373 .92174 .40621 .92598 .40477 .92436 .40229 Metetra
.674 .74 .9 r
.92436 .40229 .92598 .40477 .93022 .40334 .9286 .40085 Metetra
.674 .74 .901 r
.9286 .40085 .93022 .40334 .93447 .4019 .93286 .39941 Metetra
.674 .74 .901 r
.93286 .39941 .93447 .4019 .93873 .40047 .93712 .39798 Metetra
.673 .74 .901 r
.93712 .39798 .93873 .40047 .94299 .39904 .94139 .39654 Metetra
.651 .733 .909 r
.36298 .57188 .36512 .57393 .36861 .57297 .36647 .57092 Metetra
.651 .733 .909 r
.36647 .57092 .36861 .57297 .3721 .572 .36997 .56995 Metetra
.651 .733 .909 r
.36997 .56995 .3721 .572 .3756 .57104 .37347 .56898 Metetra
.651 .733 .909 r
.37347 .56898 .3756 .57104 .3791 .57008 .37697 .56802 Metetra
.65 .732 .909 r
.37697 .56802 .3791 .57008 .38261 .56912 .38048 .56706 Metetra
.65 .732 .909 r
.38048 .56706 .38261 .56912 .38612 .56817 .384 .5661 Metetra
.65 .732 .909 r
.384 .5661 .38612 .56817 .38964 .56721 .38752 .56514 Metetra
.649 .732 .909 r
.38752 .56514 .38964 .56721 .39316 .56626 .39104 .56418 Metetra
.649 .732 .909 r
.39104 .56418 .39316 .56626 .39668 .56531 .39457 .56323 Metetra
.648 .731 .91 r
.39457 .56323 .39668 .56531 .40021 .56436 .3981 .56228 Metetra
.648 .731 .91 r
.3981 .56228 .40021 .56436 .40375 .56341 .40164 .56133 Metetra
.648 .731 .91 r
.40164 .56133 .40375 .56341 .40729 .56247 .40518 .56038 Metetra
.647 .731 .91 r
.40518 .56038 .40729 .56247 .41083 .56153 .40873 .55943 Metetra
.647 .73 .91 r
.40873 .55943 .41083 .56153 .41438 .56059 .41228 .55849 Metetra
.646 .73 .91 r
.41228 .55849 .41438 .56059 .41794 .55966 .41584 .55755 Metetra
.646 .73 .91 r
.41584 .55755 .41794 .55966 .4215 .55872 .4194 .55661 Metetra
.645 .729 .91 r
.4194 .55661 .4215 .55872 .42506 .5578 .42297 .55568 Metetra
.645 .729 .91 r
.42297 .55568 .42506 .5578 .42863 .55687 .42654 .55475 Metetra
.644 .729 .91 r
.42654 .55475 .42863 .55687 .43221 .55595 .43012 .55382 Metetra
.644 .728 .91 r
.43012 .55382 .43221 .55595 .43579 .55503 .4337 .5529 Metetra
.643 .728 .91 r
.4337 .5529 .43579 .55503 .43937 .55412 .43729 .55199 Metetra
.643 .727 .91 r
.43729 .55199 .43937 .55412 .44296 .55321 .44088 .55107 Metetra
.642 .727 .91 r
.44088 .55107 .44296 .55321 .44656 .55231 .44448 .55016 Metetra
.641 .727 .91 r
.44448 .55016 .44656 .55231 .45016 .55141 .44808 .54926 Metetra
.64 .726 .91 r
.44808 .54926 .45016 .55141 .45376 .55052 .45169 .54836 Metetra
.64 .726 .91 r
.45169 .54836 .45376 .55052 .45737 .54963 .4553 .54747 Metetra
.639 .725 .911 r
.4553 .54747 .45737 .54963 .46099 .54876 .45892 .54659 Metetra
.638 .724 .911 r
.45892 .54659 .46099 .54876 .46461 .54788 .46254 .54571 Metetra
.637 .724 .911 r
.46254 .54571 .46461 .54788 .46823 .54702 .46617 .54484 Metetra
.636 .723 .911 r
.46617 .54484 .46823 .54702 .47186 .54616 .46981 .54398 Metetra
.635 .723 .911 r
.46981 .54398 .47186 .54616 .4755 .54532 .47344 .54312 Metetra
.634 .722 .911 r
.47344 .54312 .4755 .54532 .47914 .54448 .47709 .54228 Metetra
.633 .721 .911 r
.47709 .54228 .47914 .54448 .48278 .54365 .48074 .54144 Metetra
.631 .72 .911 r
.48074 .54144 .48278 .54365 .48644 .54283 .48439 .54062 Metetra
.63 .719 .911 r
.48439 .54062 .48644 .54283 .49009 .54202 .48805 .53981 Metetra
.629 .719 .912 r
.48805 .53981 .49009 .54202 .49376 .54123 .49172 .539 Metetra
.627 .718 .912 r
.49172 .539 .49376 .54123 .49742 .54045 .49539 .53822 Metetra
.625 .716 .912 r
.49539 .53822 .49742 .54045 .5011 .53968 .49907 .53744 Metetra
.623 .715 .912 r
.49907 .53744 .5011 .53968 .50478 .53893 .50275 .53668 Metetra
.622 .714 .912 r
.50275 .53668 .50478 .53893 .50846 .5382 .50644 .53594 Metetra
.619 .713 .912 r
.50644 .53594 .50846 .5382 .51215 .53749 .51013 .53522 Metetra
.617 .711 .913 r
.51013 .53522 .51215 .53749 .51585 .53679 .51383 .53451 Metetra
.615 .71 .913 r
.51383 .53451 .51585 .53679 .51955 .53612 .51754 .53383 Metetra
.612 .708 .913 r
.51754 .53383 .51955 .53612 .52326 .53547 .52125 .53317 Metetra
.609 .706 .913 r
.52125 .53317 .52326 .53547 .52698 .53485 .52496 .53254 Metetra
.606 .704 .914 r
.52496 .53254 .52698 .53485 .5307 .53426 .52869 .53193 Metetra
.602 .702 .914 r
.52869 .53193 .5307 .53426 .53443 .53369 .53242 .53135 Metetra
.598 .699 .914 r
.53242 .53135 .53443 .53369 .53816 .53317 .53615 .53081 Metetra
.593 .696 .914 r
.53615 .53081 .53816 .53317 .5419 .53268 .5399 .53031 Metetra
.588 .693 .915 r
.5399 .53031 .5419 .53268 .54565 .53224 .54365 .52985 Metetra
.583 .69 .915 r
.54365 .52985 .54565 .53224 .5494 .53184 .5474 .52944 Metetra
.577 .686 .915 r
.5474 .52944 .5494 .53184 .55316 .5315 .55117 .52908 Metetra
.569 .681 .916 r
.55117 .52908 .55316 .5315 .55693 .53122 .55494 .52878 Metetra
.561 .676 .916 r
.55494 .52878 .55693 .53122 .56071 .53101 .55872 .52854 Metetra
.552 .67 .916 r
.55872 .52854 .56071 .53101 .56449 .53088 .56251 .52839 Metetra
.541 .663 .916 r
.56251 .52839 .56449 .53088 .56829 .53084 .5663 .52832 Metetra
.528 .655 .916 r
.5663 .52832 .56829 .53084 .57209 .53091 .57011 .52835 Metetra
.512 .645 .916 r
.57011 .52835 .57209 .53091 .5759 .5311 .57392 .5285 Metetra
.494 .633 .915 r
.57392 .5285 .5759 .5311 .57973 .53143 .57775 .52879 Metetra
.472 .619 .914 r
.57775 .52879 .57973 .53143 .58356 .53193 .58158 .52925 Metetra
.444 .601 .912 r
.58158 .52925 .58356 .53193 .58741 .53264 .58543 .5299 Metetra
.41 .578 .908 r
.58543 .5299 .58741 .53264 .59127 .5336 .58929 .53078 Metetra
.365 .548 .901 r
.58929 .53078 .59127 .5336 .59515 .53486 .59317 .53196 Metetra
.307 .509 .889 r
.59317 .53196 .59515 .53486 .59905 .5365 .59707 .5335 Metetra
.23 .454 .87 r
.59707 .5335 .59905 .5365 .60297 .53863 .60099 .53551 Metetra
.126 .378 .835 r
.60099 .53551 .60297 .53863 .60692 .54141 .60493 .53813 Metetra
0 .27 .775 r
.60493 .53813 .60692 .54141 .61091 .54506 .60892 .54158 Metetra
0 .12 .67 r
.60892 .54158 .61091 .54506 .61494 .54994 .61294 .54617 Metetra
0 0 .505 r
.61294 .54617 .61494 .54994 .61905 .55664 .61704 .55245 Metetra
.659 .29 0 r
.61704 .55245 .61905 .55664 .62326 .56623 .62123 .5614 Metetra
.832 .474 0 r
.62123 .5614 .62326 .56623 .62766 .58087 .62558 .57495 Metetra
.931 .599 .15 r
.62558 .57495 .62766 .58087 .63242 .60584 .63026 .5977 Metetra
.973 .668 .295 r
.63026 .5977 .63242 .60584 .63817 .65885 .63578 .64455 Metetra
.94 .657 .194 r
.63578 .64455 .63817 .65885 .64361 .6991 .64159 .69705 Metetra
.645 .763 .934 r
.64159 .69705 .64361 .6991 .64772 .69799 .6457 .69594 Metetra
.964 .711 .504 r
.6457 .69594 .64772 .69799 .65034 .65553 .64791 .6412 Metetra
.893 .641 .551 r
.64791 .6412 .65034 .65553 .65238 .60013 .65021 .59197 Metetra
.888 .657 .582 r
.65021 .59197 .65238 .60013 .65539 .57279 .6533 .56684 Metetra
.879 .671 .616 r
.6533 .56684 .65539 .57279 .65874 .55578 .65671 .55092 Metetra
.868 .683 .649 r
.65671 .55092 .65874 .55578 .66227 .54382 .66027 .53959 Metetra
.856 .693 .679 r
.66027 .53959 .66227 .54382 .6659 .53475 .66393 .53093 Metetra
.844 .702 .706 r
.66393 .53093 .6659 .53475 .6696 .5275 .66764 .52396 Metetra
.832 .709 .729 r
.66764 .52396 .6696 .5275 .67334 .52147 .6714 .51814 Metetra
.82 .715 .749 r
.6714 .51814 .67334 .52147 .67712 .51632 .67518 .51314 Metetra
.808 .719 .767 r
.67518 .51314 .67712 .51632 .68092 .51181 .67899 .50875 Metetra
.798 .723 .782 r
.67899 .50875 .68092 .51181 .68474 .50779 .68283 .50483 Metetra
.788 .726 .794 r
.68283 .50483 .68474 .50779 .68858 .50416 .68668 .50127 Metetra
.779 .728 .806 r
.68668 .50127 .68858 .50416 .69244 .50083 .69054 .498 Metetra
.771 .73 .815 r
.69054 .498 .69244 .50083 .69631 .49775 .69441 .49497 Metetra
.763 .732 .823 r
.69441 .49497 .69631 .49775 .70019 .49487 .6983 .49213 Metetra
.756 .733 .831 r
.6983 .49213 .70019 .49487 .70408 .49216 .7022 .48946 Metetra
.75 .734 .837 r
.7022 .48946 .70408 .49216 .70798 .48959 .70611 .48692 Metetra
.745 .735 .843 r
.70611 .48692 .70798 .48959 .71189 .48715 .71002 .48451 Metetra
.739 .735 .848 r
.71002 .48451 .71189 .48715 .71581 .48481 .71395 .48219 Metetra
.735 .736 .852 r
.71395 .48219 .71581 .48481 .71974 .48256 .71788 .47996 Metetra
.73 .737 .856 r
.71788 .47996 .71974 .48256 .72368 .48039 .72182 .47781 Metetra
.727 .737 .86 r
.72182 .47781 .72368 .48039 .72762 .47829 .72577 .47573 Metetra
.723 .737 .863 r
.72577 .47573 .72762 .47829 .73157 .47625 .72973 .4737 Metetra
.72 .738 .866 r
.72973 .4737 .73157 .47625 .73553 .47427 .73369 .47173 Metetra
.717 .738 .868 r
.73369 .47173 .73553 .47427 .73949 .47233 .73766 .4698 Metetra
.714 .738 .87 r
.73766 .4698 .73949 .47233 .74346 .47044 .74164 .46792 Metetra
.711 .738 .873 r
.74164 .46792 .74346 .47044 .74744 .46859 .74562 .46608 Metetra
.709 .739 .875 r
.74562 .46608 .74744 .46859 .75143 .46677 .74961 .46426 Metetra
.707 .739 .876 r
.74961 .46426 .75143 .46677 .75542 .46498 .7536 .46248 Metetra
.704 .739 .878 r
.7536 .46248 .75542 .46498 .75942 .46322 .75761 .46073 Metetra
.703 .739 .879 r
.75761 .46073 .75942 .46322 .76342 .46149 .76162 .459 Metetra
.701 .739 .881 r
.76162 .459 .76342 .46149 .76743 .45978 .76563 .4573 Metetra
.699 .739 .882 r
.76563 .4573 .76743 .45978 .77145 .45809 .76965 .45561 Metetra
.698 .739 .883 r
.76965 .45561 .77145 .45809 .77547 .45642 .77368 .45395 Metetra
.696 .739 .884 r
.77368 .45395 .77547 .45642 .7795 .45477 .77772 .4523 Metetra
.695 .739 .885 r
.77772 .4523 .7795 .45477 .78354 .45314 .78176 .45067 Metetra
.693 .739 .886 r
.78176 .45067 .78354 .45314 .78758 .45152 .7858 .44906 Metetra
.692 .74 .887 r
.7858 .44906 .78758 .45152 .79163 .44992 .78985 .44745 Metetra
.691 .74 .888 r
.78985 .44745 .79163 .44992 .79568 .44833 .79391 .44587 Metetra
.69 .74 .889 r
.79391 .44587 .79568 .44833 .79974 .44675 .79798 .44429 Metetra
.689 .74 .89 r
.79798 .44429 .79974 .44675 .80381 .44518 .80205 .44272 Metetra
.688 .74 .89 r
.80205 .44272 .80381 .44518 .80788 .44363 .80612 .44117 Metetra
.687 .74 .891 r
.80612 .44117 .80788 .44363 .81196 .44208 .81021 .43962 Metetra
.686 .74 .892 r
.81021 .43962 .81196 .44208 .81604 .44054 .8143 .43808 Metetra
.686 .74 .892 r
.8143 .43808 .81604 .44054 .82013 .43901 .81839 .43655 Metetra
.685 .74 .893 r
.81839 .43655 .82013 .43901 .82423 .43749 .82249 .43503 Metetra
.684 .74 .893 r
.82249 .43503 .82423 .43749 .82833 .43597 .8266 .43352 Metetra
.683 .74 .894 r
.8266 .43352 .82833 .43597 .83244 .43447 .83071 .43201 Metetra
.683 .74 .894 r
.83071 .43201 .83244 .43447 .83655 .43296 .83483 .4305 Metetra
.682 .74 .895 r
.83483 .4305 .83655 .43296 .84067 .43147 .83895 .42901 Metetra
.682 .74 .895 r
.83895 .42901 .84067 .43147 .8448 .42998 .84309 .42752 Metetra
.681 .74 .896 r
.84309 .42752 .8448 .42998 .84893 .42849 .84722 .42603 Metetra
.68 .74 .896 r
.84722 .42603 .84893 .42849 .85307 .42701 .85137 .42455 Metetra
.68 .74 .896 r
.85137 .42455 .85307 .42701 .85722 .42553 .85551 .42307 Metetra
.679 .74 .897 r
.85551 .42307 .85722 .42553 .86137 .42406 .85967 .42159 Metetra
.679 .74 .897 r
.85967 .42159 .86137 .42406 .86552 .42259 .86383 .42012 Metetra
.679 .74 .897 r
.86383 .42012 .86552 .42259 .86969 .42112 .868 .41866 Metetra
.678 .74 .898 r
.868 .41866 .86969 .42112 .87386 .41966 .87217 .41719 Metetra
.678 .74 .898 r
.87217 .41719 .87386 .41966 .87803 .4182 .87635 .41573 Metetra
.677 .74 .898 r
.87635 .41573 .87803 .4182 .88221 .41674 .88054 .41427 Metetra
.677 .74 .898 r
.88054 .41427 .88221 .41674 .8864 .41529 .88473 .41282 Metetra
.677 .74 .899 r
.88473 .41282 .8864 .41529 .89059 .41384 .88892 .41136 Metetra
.676 .74 .899 r
.88892 .41136 .89059 .41384 .89479 .41239 .89313 .40991 Metetra
.676 .74 .899 r
.89313 .40991 .89479 .41239 .899 .41094 .89734 .40846 Metetra
.676 .74 .899 r
.89734 .40846 .899 .41094 .90321 .40949 .90155 .40701 Metetra
.675 .74 .9 r
.90155 .40701 .90321 .40949 .90742 .40805 .90578 .40557 Metetra
.675 .74 .9 r
.90578 .40557 .90742 .40805 .91165 .40661 .91 .40412 Metetra
.675 .74 .9 r
.91 .40412 .91165 .40661 .91588 .40517 .91424 .40268 Metetra
.674 .74 .9 r
.91424 .40268 .91588 .40517 .92011 .40373 .91848 .40124 Metetra
.674 .74 .9 r
.91848 .40124 .92011 .40373 .92436 .40229 .92273 .3998 Metetra
.674 .74 .9 r
.92273 .3998 .92436 .40229 .9286 .40085 .92698 .39836 Metetra
.674 .74 .901 r
.92698 .39836 .9286 .40085 .93286 .39941 .93124 .39692 Metetra
.674 .74 .901 r
.93124 .39692 .93286 .39941 .93712 .39798 .9355 .39548 Metetra
.673 .74 .901 r
.9355 .39548 .93712 .39798 .94139 .39654 .93977 .39404 Metetra
.651 .733 .909 r
.36084 .56983 .36298 .57188 .36647 .57092 .36433 .56886 Metetra
.651 .733 .909 r
.36433 .56886 .36647 .57092 .36997 .56995 .36783 .56789 Metetra
.651 .733 .909 r
.36783 .56789 .36997 .56995 .37347 .56898 .37133 .56692 Metetra
.651 .733 .909 r
.37133 .56692 .37347 .56898 .37697 .56802 .37484 .56595 Metetra
.65 .732 .909 r
.37484 .56595 .37697 .56802 .38048 .56706 .37835 .56499 Metetra
.65 .732 .909 r
.37835 .56499 .38048 .56706 .384 .5661 .38187 .56402 Metetra
.65 .732 .909 r
.38187 .56402 .384 .5661 .38752 .56514 .38539 .56306 Metetra
.649 .732 .909 r
.38539 .56306 .38752 .56514 .39104 .56418 .38892 .5621 Metetra
.649 .732 .909 r
.38892 .5621 .39104 .56418 .39457 .56323 .39245 .56114 Metetra
.649 .731 .909 r
.39245 .56114 .39457 .56323 .3981 .56228 .39598 .56019 Metetra
.648 .731 .909 r
.39598 .56019 .3981 .56228 .40164 .56133 .39953 .55923 Metetra
.648 .731 .91 r
.39953 .55923 .40164 .56133 .40518 .56038 .40307 .55828 Metetra
.647 .731 .91 r
.40307 .55828 .40518 .56038 .40873 .55943 .40662 .55733 Metetra
.647 .73 .91 r
.40662 .55733 .40873 .55943 .41228 .55849 .41018 .55638 Metetra
.647 .73 .91 r
.41018 .55638 .41228 .55849 .41584 .55755 .41374 .55544 Metetra
.646 .73 .91 r
.41374 .55544 .41584 .55755 .4194 .55661 .4173 .5545 Metetra
.646 .729 .91 r
.4173 .5545 .4194 .55661 .42297 .55568 .42087 .55356 Metetra
.645 .729 .91 r
.42087 .55356 .42297 .55568 .42654 .55475 .42445 .55263 Metetra
.645 .729 .91 r
.42445 .55263 .42654 .55475 .43012 .55382 .42803 .55169 Metetra
.644 .728 .91 r
.42803 .55169 .43012 .55382 .4337 .5529 .43161 .55077 Metetra
.643 .728 .91 r
.43161 .55077 .4337 .5529 .43729 .55199 .4352 .54985 Metetra
.643 .728 .91 r
.4352 .54985 .43729 .55199 .44088 .55107 .4388 .54893 Metetra
.642 .727 .91 r
.4388 .54893 .44088 .55107 .44448 .55016 .4424 .54801 Metetra
.641 .727 .91 r
.4424 .54801 .44448 .55016 .44808 .54926 .44601 .54711 Metetra
.641 .726 .91 r
.44601 .54711 .44808 .54926 .45169 .54836 .44962 .5462 Metetra
.64 .726 .91 r
.44962 .5462 .45169 .54836 .4553 .54747 .45323 .54531 Metetra
.639 .725 .91 r
.45323 .54531 .4553 .54747 .45892 .54659 .45685 .54442 Metetra
.638 .725 .911 r
.45685 .54442 .45892 .54659 .46254 .54571 .46048 .54353 Metetra
.637 .724 .911 r
.46048 .54353 .46254 .54571 .46617 .54484 .46411 .54266 Metetra
.636 .723 .911 r
.46411 .54266 .46617 .54484 .46981 .54398 .46775 .54179 Metetra
.635 .723 .911 r
.46775 .54179 .46981 .54398 .47344 .54312 .47139 .54093 Metetra
.634 .722 .911 r
.47139 .54093 .47344 .54312 .47709 .54228 .47503 .54008 Metetra
.633 .721 .911 r
.47503 .54008 .47709 .54228 .48074 .54144 .47869 .53923 Metetra
.632 .72 .911 r
.47869 .53923 .48074 .54144 .48439 .54062 .48234 .5384 Metetra
.631 .72 .911 r
.48234 .5384 .48439 .54062 .48805 .53981 .48601 .53758 Metetra
.629 .719 .911 r
.48601 .53758 .48805 .53981 .49172 .539 .48968 .53677 Metetra
.628 .718 .912 r
.48968 .53677 .49172 .539 .49539 .53822 .49335 .53598 Metetra
.626 .717 .912 r
.49335 .53598 .49539 .53822 .49907 .53744 .49703 .53519 Metetra
.624 .716 .912 r
.49703 .53519 .49907 .53744 .50275 .53668 .50071 .53443 Metetra
.622 .714 .912 r
.50071 .53443 .50275 .53668 .50644 .53594 .50441 .53368 Metetra
.62 .713 .912 r
.50441 .53368 .50644 .53594 .51013 .53522 .5081 .53294 Metetra
.618 .712 .912 r
.5081 .53294 .51013 .53522 .51383 .53451 .5118 .53223 Metetra
.616 .71 .913 r
.5118 .53223 .51383 .53451 .51754 .53383 .51551 .53153 Metetra
.613 .708 .913 r
.51551 .53153 .51754 .53383 .52125 .53317 .51923 .53086 Metetra
.61 .707 .913 r
.51923 .53086 .52125 .53317 .52496 .53254 .52295 .53022 Metetra
.607 .704 .913 r
.52295 .53022 .52496 .53254 .52869 .53193 .52667 .5296 Metetra
.603 .702 .913 r
.52667 .5296 .52869 .53193 .53242 .53135 .53041 .52901 Metetra
.599 .7 .914 r
.53041 .52901 .53242 .53135 .53615 .53081 .53415 .52846 Metetra
.595 .697 .914 r
.53415 .52846 .53615 .53081 .5399 .53031 .53789 .52794 Metetra
.59 .694 .914 r
.53789 .52794 .5399 .53031 .54365 .52985 .54164 .52746 Metetra
.585 .691 .915 r
.54164 .52746 .54365 .52985 .5474 .52944 .5454 .52703 Metetra
.579 .687 .915 r
.5454 .52703 .5474 .52944 .55117 .52908 .54917 .52665 Metetra
.572 .682 .915 r
.54917 .52665 .55117 .52908 .55494 .52878 .55294 .52633 Metetra
.564 .677 .915 r
.55294 .52633 .55494 .52878 .55872 .52854 .55672 .52607 Metetra
.555 .671 .915 r
.55672 .52607 .55872 .52854 .56251 .52839 .56051 .52589 Metetra
.544 .665 .916 r
.56051 .52589 .56251 .52839 .5663 .52832 .56431 .52579 Metetra
.532 .657 .916 r
.56431 .52579 .5663 .52832 .57011 .52835 .56812 .52579 Metetra
.517 .647 .915 r
.56812 .52579 .57011 .52835 .57392 .5285 .57193 .5259 Metetra
.5 .636 .915 r
.57193 .5259 .57392 .5285 .57775 .52879 .57576 .52615 Metetra
.479 .622 .913 r
.57576 .52615 .57775 .52879 .58158 .52925 .5796 .52656 Metetra
.453 .605 .911 r
.5796 .52656 .58158 .52925 .58543 .5299 .58345 .52715 Metetra
.42 .584 .908 r
.58345 .52715 .58543 .5299 .58929 .53078 .58731 .52797 Metetra
.379 .556 .902 r
.58731 .52797 .58929 .53078 .59317 .53196 .59119 .52906 Metetra
.326 .519 .892 r
.59119 .52906 .59317 .53196 .59707 .5335 .59508 .53051 Metetra
.254 .469 .875 r
.59508 .53051 .59707 .5335 .60099 .53551 .599 .53239 Metetra
.158 .399 .845 r
.599 .53239 .60099 .53551 .60493 .53813 .60295 .53485 Metetra
.027 .3 .792 r
.60295 .53485 .60493 .53813 .60892 .54158 .60692 .53809 Metetra
0 .161 .701 r
.60692 .53809 .60892 .54158 .61294 .54617 .61094 .5424 Metetra
0 0 .552 r
.61094 .5424 .61294 .54617 .61704 .55245 .61502 .54827 Metetra
0 0 .341 r
.61502 .54827 .61704 .55245 .62123 .5614 .61919 .55659 Metetra
.795 .437 0 r
.61919 .55659 .62123 .5614 .62558 .57495 .62351 .56906 Metetra
.913 .578 .108 r
.62351 .56906 .62558 .57495 .63026 .5977 .62811 .58967 Metetra
.968 .659 .267 r
.62811 .58967 .63026 .5977 .63578 .64455 .63341 .63068 Metetra
.968 .679 .267 r
.63341 .63068 .63578 .64455 .64159 .69705 .63957 .695 Metetra
.645 .763 .934 r
.63957 .695 .64159 .69705 .6457 .69594 .64368 .69388 Metetra
.965 .707 .495 r
.64368 .69388 .6457 .69594 .64791 .6412 .64552 .6273 Metetra
.886 .638 .557 r
.64552 .6273 .64791 .6412 .65021 .59197 .64804 .58391 Metetra
.882 .655 .589 r
.64804 .58391 .65021 .59197 .6533 .56684 .65122 .56093 Metetra
.874 .669 .622 r
.65122 .56093 .6533 .56684 .65671 .55092 .65468 .54607 Metetra
.863 .682 .655 r
.65468 .54607 .65671 .55092 .66027 .53959 .65827 .53537 Metetra
.852 .692 .684 r
.65827 .53537 .66027 .53959 .66393 .53093 .66195 .52711 Metetra
.839 .701 .71 r
.66195 .52711 .66393 .53093 .66764 .52396 .66568 .52042 Metetra
.827 .708 .733 r
.66568 .52042 .66764 .52396 .6714 .51814 .66945 .5148 Metetra
.816 .714 .753 r
.66945 .5148 .6714 .51814 .67518 .51314 .67324 .50995 Metetra
.805 .718 .77 r
.67324 .50995 .67518 .51314 .67899 .50875 .67707 .50568 Metetra
.794 .722 .784 r
.67707 .50568 .67899 .50875 .68283 .50483 .68091 .50185 Metetra
.785 .725 .797 r
.68091 .50185 .68283 .50483 .68668 .50127 .68476 .49837 Metetra
.776 .728 .807 r
.68476 .49837 .68668 .50127 .69054 .498 .68863 .49516 Metetra
.768 .73 .817 r
.68863 .49516 .69054 .498 .69441 .49497 .69252 .49218 Metetra
.761 .731 .825 r
.69252 .49218 .69441 .49497 .6983 .49213 .69641 .48939 Metetra
.754 .732 .832 r
.69641 .48939 .6983 .49213 .7022 .48946 .70031 .48675 Metetra
.748 .733 .838 r
.70031 .48675 .7022 .48946 .70611 .48692 .70423 .48425 Metetra
.743 .734 .844 r
.70423 .48425 .70611 .48692 .71002 .48451 .70815 .48186 Metetra
.738 .735 .849 r
.70815 .48186 .71002 .48451 .71395 .48219 .71208 .47957 Metetra
.733 .736 .853 r
.71208 .47957 .71395 .48219 .71788 .47996 .71602 .47736 Metetra
.729 .736 .857 r
.71602 .47736 .71788 .47996 .72182 .47781 .71997 .47523 Metetra
.725 .737 .86 r
.71997 .47523 .72182 .47781 .72577 .47573 .72392 .47316 Metetra
.722 .737 .863 r
.72392 .47316 .72577 .47573 .72973 .4737 .72788 .47115 Metetra
.719 .737 .866 r
.72788 .47115 .72973 .4737 .73369 .47173 .73185 .46919 Metetra
.716 .738 .869 r
.73185 .46919 .73369 .47173 .73766 .4698 .73582 .46727 Metetra
.713 .738 .871 r
.73582 .46727 .73766 .4698 .74164 .46792 .7398 .4654 Metetra
.71 .738 .873 r
.7398 .4654 .74164 .46792 .74562 .46608 .74379 .46356 Metetra
.708 .738 .875 r
.74379 .46356 .74562 .46608 .74961 .46426 .74779 .46176 Metetra
.706 .738 .877 r
.74779 .46176 .74961 .46426 .7536 .46248 .75179 .45998 Metetra
.704 .739 .878 r
.75179 .45998 .7536 .46248 .75761 .46073 .75579 .45823 Metetra
.702 .739 .88 r
.75579 .45823 .75761 .46073 .76162 .459 .75981 .45651 Metetra
.7 .739 .881 r
.75981 .45651 .76162 .459 .76563 .4573 .76383 .45481 Metetra
.699 .739 .882 r
.76383 .45481 .76563 .4573 .76965 .45561 .76785 .45313 Metetra
.697 .739 .884 r
.76785 .45313 .76965 .45561 .77368 .45395 .77189 .45147 Metetra
.696 .739 .885 r
.77189 .45147 .77368 .45395 .77772 .4523 .77592 .44983 Metetra
.694 .739 .886 r
.77592 .44983 .77772 .4523 .78176 .45067 .77997 .4482 Metetra
.693 .739 .887 r
.77997 .4482 .78176 .45067 .7858 .44906 .78402 .44658 Metetra
.692 .739 .888 r
.78402 .44658 .7858 .44906 .78985 .44745 .78808 .44498 Metetra
.691 .739 .888 r
.78808 .44498 .78985 .44745 .79391 .44587 .79214 .4434 Metetra
.69 .739 .889 r
.79214 .4434 .79391 .44587 .79798 .44429 .79621 .44182 Metetra
.689 .74 .89 r
.79621 .44182 .79798 .44429 .80205 .44272 .80028 .44026 Metetra
.688 .74 .891 r
.80028 .44026 .80205 .44272 .80612 .44117 .80436 .4387 Metetra
.687 .74 .891 r
.80436 .4387 .80612 .44117 .81021 .43962 .80845 .43716 Metetra
.686 .74 .892 r
.80845 .43716 .81021 .43962 .8143 .43808 .81254 .43562 Metetra
.685 .74 .892 r
.81254 .43562 .8143 .43808 .81839 .43655 .81664 .43409 Metetra
.685 .74 .893 r
.81664 .43409 .81839 .43655 .82249 .43503 .82075 .43257 Metetra
.684 .74 .893 r
.82075 .43257 .82249 .43503 .8266 .43352 .82486 .43105 Metetra
.683 .74 .894 r
.82486 .43105 .8266 .43352 .83071 .43201 .82898 .42954 Metetra
.683 .74 .894 r
.82898 .42954 .83071 .43201 .83483 .4305 .8331 .42804 Metetra
.682 .74 .895 r
.8331 .42804 .83483 .4305 .83895 .42901 .83723 .42654 Metetra
.681 .74 .895 r
.83723 .42654 .83895 .42901 .84309 .42752 .84137 .42505 Metetra
.681 .74 .896 r
.84137 .42505 .84309 .42752 .84722 .42603 .84551 .42356 Metetra
.68 .74 .896 r
.84551 .42356 .84722 .42603 .85137 .42455 .84965 .42208 Metetra
.68 .74 .896 r
.84965 .42208 .85137 .42455 .85551 .42307 .85381 .4206 Metetra
.679 .74 .897 r
.85381 .4206 .85551 .42307 .85967 .42159 .85797 .41912 Metetra
.679 .74 .897 r
.85797 .41912 .85967 .42159 .86383 .42012 .86213 .41765 Metetra
.678 .74 .897 r
.86213 .41765 .86383 .42012 .868 .41866 .8663 .41618 Metetra
.678 .74 .898 r
.8663 .41618 .868 .41866 .87217 .41719 .87048 .41472 Metetra
.678 .74 .898 r
.87048 .41472 .87217 .41719 .87635 .41573 .87467 .41325 Metetra
.677 .74 .898 r
.87467 .41325 .87635 .41573 .88054 .41427 .87886 .41179 Metetra
.677 .74 .898 r
.87886 .41179 .88054 .41427 .88473 .41282 .88305 .41034 Metetra
.676 .74 .899 r
.88305 .41034 .88473 .41282 .88892 .41136 .88725 .40888 Metetra
.676 .74 .899 r
.88725 .40888 .88892 .41136 .89313 .40991 .89146 .40743 Metetra
.676 .74 .899 r
.89146 .40743 .89313 .40991 .89734 .40846 .89568 .40598 Metetra
.676 .74 .899 r
.89568 .40598 .89734 .40846 .90155 .40701 .8999 .40453 Metetra
.675 .74 .9 r
.8999 .40453 .90155 .40701 .90578 .40557 .90412 .40308 Metetra
.675 .74 .9 r
.90412 .40308 .90578 .40557 .91 .40412 .90836 .40163 Metetra
.675 .74 .9 r
.90836 .40163 .91 .40412 .91424 .40268 .9126 .40019 Metetra
.674 .74 .9 r
.9126 .40019 .91424 .40268 .91848 .40124 .91684 .39874 Metetra
.674 .74 .9 r
.91684 .39874 .91848 .40124 .92273 .3998 .92109 .3973 Metetra
.674 .74 .9 r
.92109 .3973 .92273 .3998 .92698 .39836 .92535 .39586 Metetra
.674 .74 .901 r
.92535 .39586 .92698 .39836 .93124 .39692 .92961 .39441 Metetra
.673 .74 .901 r
.92961 .39441 .93124 .39692 .9355 .39548 .93388 .39297 Metetra
.673 .74 .901 r
.93388 .39297 .9355 .39548 .93977 .39404 .93816 .39153 Metetra
.652 .733 .909 r
.35869 .56777 .36084 .56983 .36433 .56886 .36218 .5668 Metetra
.651 .733 .909 r
.36218 .5668 .36433 .56886 .36783 .56789 .36568 .56583 Metetra
.651 .733 .909 r
.36568 .56583 .36783 .56789 .37133 .56692 .36919 .56485 Metetra
.651 .733 .909 r
.36919 .56485 .37133 .56692 .37484 .56595 .3727 .56388 Metetra
.65 .732 .909 r
.3727 .56388 .37484 .56595 .37835 .56499 .37621 .56291 Metetra
.65 .732 .909 r
.37621 .56291 .37835 .56499 .38187 .56402 .37973 .56195 Metetra
.65 .732 .909 r
.37973 .56195 .38187 .56402 .38539 .56306 .38326 .56098 Metetra
.65 .732 .909 r
.38326 .56098 .38539 .56306 .38892 .5621 .38679 .56001 Metetra
.649 .732 .909 r
.38679 .56001 .38892 .5621 .39245 .56114 .39032 .55905 Metetra
.649 .731 .909 r
.39032 .55905 .39245 .56114 .39598 .56019 .39386 .55809 Metetra
.648 .731 .909 r
.39386 .55809 .39598 .56019 .39953 .55923 .39741 .55713 Metetra
.648 .731 .909 r
.39741 .55713 .39953 .55923 .40307 .55828 .40095 .55618 Metetra
.648 .731 .91 r
.40095 .55618 .40307 .55828 .40662 .55733 .40451 .55522 Metetra
.647 .73 .91 r
.40451 .55522 .40662 .55733 .41018 .55638 .40807 .55427 Metetra
.647 .73 .91 r
.40807 .55427 .41018 .55638 .41374 .55544 .41163 .55332 Metetra
.646 .73 .91 r
.41163 .55332 .41374 .55544 .4173 .5545 .4152 .55238 Metetra
.646 .729 .91 r
.4152 .55238 .4173 .5545 .42087 .55356 .41877 .55143 Metetra
.645 .729 .91 r
.41877 .55143 .42087 .55356 .42445 .55263 .42235 .55049 Metetra
.645 .729 .91 r
.42235 .55049 .42445 .55263 .42803 .55169 .42593 .54956 Metetra
.644 .728 .91 r
.42593 .54956 .42803 .55169 .43161 .55077 .42952 .54863 Metetra
.644 .728 .91 r
.42952 .54863 .43161 .55077 .4352 .54985 .43311 .5477 Metetra
.643 .728 .91 r
.43311 .5477 .4352 .54985 .4388 .54893 .43671 .54678 Metetra
.642 .727 .91 r
.43671 .54678 .4388 .54893 .4424 .54801 .44031 .54586 Metetra
.642 .727 .91 r
.44031 .54586 .4424 .54801 .44601 .54711 .44392 .54495 Metetra
.641 .726 .91 r
.44392 .54495 .44601 .54711 .44962 .5462 .44754 .54404 Metetra
.64 .726 .91 r
.44754 .54404 .44962 .5462 .45323 .54531 .45115 .54314 Metetra
.639 .725 .91 r
.45115 .54314 .45323 .54531 .45685 .54442 .45478 .54224 Metetra
.639 .725 .91 r
.45478 .54224 .45685 .54442 .46048 .54353 .45841 .54135 Metetra
.638 .724 .91 r
.45841 .54135 .46048 .54353 .46411 .54266 .46204 .54047 Metetra
.637 .724 .911 r
.46204 .54047 .46411 .54266 .46775 .54179 .46568 .53959 Metetra
.636 .723 .911 r
.46568 .53959 .46775 .54179 .47139 .54093 .46932 .53873 Metetra
.635 .722 .911 r
.46932 .53873 .47139 .54093 .47503 .54008 .47297 .53787 Metetra
.634 .721 .911 r
.47297 .53787 .47503 .54008 .47869 .53923 .47663 .53702 Metetra
.632 .721 .911 r
.47663 .53702 .47869 .53923 .48234 .5384 .48029 .53618 Metetra
.631 .72 .911 r
.48029 .53618 .48234 .5384 .48601 .53758 .48396 .53535 Metetra
.63 .719 .911 r
.48396 .53535 .48601 .53758 .48968 .53677 .48763 .53454 Metetra
.628 .718 .911 r
.48763 .53454 .48968 .53677 .49335 .53598 .4913 .53373 Metetra
.627 .717 .911 r
.4913 .53373 .49335 .53598 .49703 .53519 .49499 .53294 Metetra
.625 .716 .912 r
.49499 .53294 .49703 .53519 .50071 .53443 .49867 .53216 Metetra
.623 .715 .912 r
.49867 .53216 .50071 .53443 .50441 .53368 .50237 .5314 Metetra
.621 .713 .912 r
.50237 .5314 .50441 .53368 .5081 .53294 .50607 .53066 Metetra
.619 .712 .912 r
.50607 .53066 .5081 .53294 .5118 .53223 .50977 .52994 Metetra
.616 .71 .912 r
.50977 .52994 .5118 .53223 .51551 .53153 .51348 .52923 Metetra
.614 .709 .913 r
.51348 .52923 .51551 .53153 .51923 .53086 .5172 .52855 Metetra
.611 .707 .913 r
.5172 .52855 .51923 .53086 .52295 .53022 .52092 .52789 Metetra
.608 .705 .913 r
.52092 .52789 .52295 .53022 .52667 .5296 .52465 .52726 Metetra
.605 .703 .913 r
.52465 .52726 .52667 .5296 .53041 .52901 .52839 .52666 Metetra
.601 .7 .913 r
.52839 .52666 .53041 .52901 .53415 .52846 .53213 .52609 Metetra
.597 .698 .914 r
.53213 .52609 .53415 .52846 .53789 .52794 .53588 .52556 Metetra
.592 .695 .914 r
.53588 .52556 .53789 .52794 .54164 .52746 .53963 .52506 Metetra
.587 .691 .914 r
.53963 .52506 .54164 .52746 .5454 .52703 .5434 .52461 Metetra
.581 .688 .914 r
.5434 .52461 .5454 .52703 .54917 .52665 .54716 .52422 Metetra
.574 .683 .915 r
.54716 .52422 .54917 .52665 .55294 .52633 .55094 .52387 Metetra
.567 .678 .915 r
.55094 .52387 .55294 .52633 .55672 .52607 .55472 .52359 Metetra
.558 .673 .915 r
.55472 .52359 .55672 .52607 .56051 .52589 .55852 .52338 Metetra
.548 .666 .915 r
.55852 .52338 .56051 .52589 .56431 .52579 .56232 .52326 Metetra
.536 .659 .915 r
.56232 .52326 .56431 .52579 .56812 .52579 .56612 .52322 Metetra
.522 .65 .915 r
.56612 .52322 .56812 .52579 .57193 .5259 .56994 .5233 Metetra
.506 .639 .914 r
.56994 .5233 .57193 .5259 .57576 .52615 .57377 .5235 Metetra
.486 .626 .913 r
.57377 .5235 .57576 .52615 .5796 .52656 .57761 .52386 Metetra
.461 .61 .911 r
.57761 .52386 .5796 .52656 .58345 .52715 .58146 .52439 Metetra
.431 .59 .908 r
.58146 .52439 .58345 .52715 .58731 .52797 .58532 .52515 Metetra
.392 .563 .903 r
.58532 .52515 .58731 .52797 .59119 .52906 .5892 .52616 Metetra
.343 .529 .894 r
.5892 .52616 .59119 .52906 .59508 .53051 .5931 .52751 Metetra
.277 .483 .879 r
.5931 .52751 .59508 .53051 .599 .53239 .59701 .52927 Metetra
.189 .419 .853 r
.59701 .52927 .599 .53239 .60295 .53485 .60095 .53158 Metetra
.068 .329 .808 r
.60095 .53158 .60295 .53485 .60692 .53809 .60492 .53461 Metetra
0 .2 .729 r
.60492 .53461 .60692 .53809 .61094 .5424 .60893 .53864 Metetra
0 .025 .596 r
.60893 .53864 .61094 .5424 .61502 .54827 .613 .54411 Metetra
0 0 .4 r
.613 .54411 .61502 .54827 .61919 .55659 .61715 .55182 Metetra
.751 .394 0 r
.61715 .55182 .61919 .55659 .62351 .56906 .62143 .56326 Metetra
.89 .552 .06 r
.62143 .56326 .62351 .56906 .62811 .58967 .62596 .58183 Metetra
.959 .648 .235 r
.62596 .58183 .62811 .58967 .63341 .63068 .63107 .61751 Metetra
.978 .687 .312 r
.63107 .61751 .63341 .63068 .63957 .695 .63754 .69293 Metetra
.645 .763 .934 r
.63754 .69293 .63957 .695 .64368 .69388 .64166 .69182 Metetra
.965 .705 .489 r
.64166 .69182 .64368 .69388 .64552 .6273 .64315 .61411 Metetra
.88 .635 .564 r
.64315 .61411 .64552 .6273 .64804 .58391 .64587 .57605 Metetra
.877 .653 .596 r
.64587 .57605 .64804 .58391 .65122 .56093 .64914 .55509 Metetra
.869 .668 .629 r
.64914 .55509 .65122 .56093 .65468 .54607 .65264 .54126 Metetra
.858 .681 .661 r
.65264 .54126 .65468 .54607 .65827 .53537 .65627 .53117 Metetra
.847 .692 .689 r
.65627 .53117 .65827 .53537 .66195 .52711 .65996 .5233 Metetra
.835 .7 .715 r
.65996 .5233 .66195 .52711 .66568 .52042 .66371 .51688 Metetra
.823 .708 .737 r
.66371 .51688 .66568 .52042 .66945 .5148 .66749 .51146 Metetra
.812 .713 .756 r
.66749 .51146 .66945 .5148 .67324 .50995 .6713 .50677 Metetra
.801 .718 .773 r
.6713 .50677 .67324 .50995 .67707 .50568 .67513 .50261 Metetra
.791 .722 .787 r
.67513 .50261 .67707 .50568 .68091 .50185 .67898 .49887 Metetra
.782 .725 .799 r
.67898 .49887 .68091 .50185 .68476 .49837 .68285 .49546 Metetra
.774 .727 .809 r
.68285 .49546 .68476 .49837 .68863 .49516 .68673 .49232 Metetra
.766 .729 .819 r
.68673 .49232 .68863 .49516 .69252 .49218 .69062 .48939 Metetra
.759 .731 .827 r
.69062 .48939 .69252 .49218 .69641 .48939 .69452 .48664 Metetra
.752 .732 .833 r
.69452 .48664 .69641 .48939 .70031 .48675 .69843 .48404 Metetra
.747 .733 .839 r
.69843 .48404 .70031 .48675 .70423 .48425 .70234 .48157 Metetra
.741 .734 .845 r
.70234 .48157 .70423 .48425 .70815 .48186 .70627 .47921 Metetra
.736 .735 .85 r
.70627 .47921 .70815 .48186 .71208 .47957 .71021 .47694 Metetra
.732 .735 .854 r
.71021 .47694 .71208 .47957 .71602 .47736 .71415 .47475 Metetra
.728 .736 .858 r
.71415 .47475 .71602 .47736 .71997 .47523 .7181 .47264 Metetra
.724 .736 .861 r
.7181 .47264 .71997 .47523 .72392 .47316 .72206 .47058 Metetra
.721 .737 .864 r
.72206 .47058 .72392 .47316 .72788 .47115 .72603 .46858 Metetra
.717 .737 .867 r
.72603 .46858 .72788 .47115 .73185 .46919 .73 .46664 Metetra
.715 .737 .869 r
.73 .46664 .73185 .46919 .73582 .46727 .73398 .46473 Metetra
.712 .738 .871 r
.73398 .46473 .73582 .46727 .7398 .4654 .73797 .46287 Metetra
.709 .738 .873 r
.73797 .46287 .7398 .4654 .74379 .46356 .74196 .46104 Metetra
.707 .738 .875 r
.74196 .46104 .74379 .46356 .74779 .46176 .74596 .45924 Metetra
.705 .738 .877 r
.74596 .45924 .74779 .46176 .75179 .45998 .74996 .45747 Metetra
.703 .738 .879 r
.74996 .45747 .75179 .45998 .75579 .45823 .75397 .45573 Metetra
.701 .739 .88 r
.75397 .45573 .75579 .45823 .75981 .45651 .75799 .45401 Metetra
.7 .739 .881 r
.75799 .45401 .75981 .45651 .76383 .45481 .76202 .45232 Metetra
.698 .739 .883 r
.76202 .45232 .76383 .45481 .76785 .45313 .76605 .45064 Metetra
.696 .739 .884 r
.76605 .45064 .76785 .45313 .77189 .45147 .77008 .44898 Metetra
.695 .739 .885 r
.77008 .44898 .77189 .45147 .77592 .44983 .77413 .44734 Metetra
.694 .739 .886 r
.77413 .44734 .77592 .44983 .77997 .4482 .77818 .44572 Metetra
.693 .739 .887 r
.77818 .44572 .77997 .4482 .78402 .44658 .78223 .44411 Metetra
.691 .739 .888 r
.78223 .44411 .78402 .44658 .78808 .44498 .78629 .44251 Metetra
.69 .739 .889 r
.78629 .44251 .78808 .44498 .79214 .4434 .79036 .44092 Metetra
.689 .739 .889 r
.79036 .44092 .79214 .4434 .79621 .44182 .79443 .43935 Metetra
.688 .739 .89 r
.79443 .43935 .79621 .44182 .80028 .44026 .79851 .43779 Metetra
.687 .739 .891 r
.79851 .43779 .80028 .44026 .80436 .4387 .8026 .43623 Metetra
.687 .74 .891 r
.8026 .43623 .80436 .4387 .80845 .43716 .80669 .43469 Metetra
.686 .74 .892 r
.80669 .43469 .80845 .43716 .81254 .43562 .81079 .43315 Metetra
.685 .74 .892 r
.81079 .43315 .81254 .43562 .81664 .43409 .81489 .43162 Metetra
.684 .74 .893 r
.81489 .43162 .81664 .43409 .82075 .43257 .819 .4301 Metetra
.684 .74 .894 r
.819 .4301 .82075 .43257 .82486 .43105 .82312 .42858 Metetra
.683 .74 .894 r
.82312 .42858 .82486 .43105 .82898 .42954 .82724 .42707 Metetra
.682 .74 .894 r
.82724 .42707 .82898 .42954 .8331 .42804 .83137 .42557 Metetra
.682 .74 .895 r
.83137 .42557 .8331 .42804 .83723 .42654 .8355 .42407 Metetra
.681 .74 .895 r
.8355 .42407 .83723 .42654 .84137 .42505 .83964 .42258 Metetra
.681 .74 .896 r
.83964 .42258 .84137 .42505 .84551 .42356 .84379 .42109 Metetra
.68 .74 .896 r
.84379 .42109 .84551 .42356 .84965 .42208 .84794 .4196 Metetra
.68 .74 .896 r
.84794 .4196 .84965 .42208 .85381 .4206 .8521 .41812 Metetra
.679 .74 .897 r
.8521 .41812 .85381 .4206 .85797 .41912 .85626 .41665 Metetra
.679 .74 .897 r
.85626 .41665 .85797 .41912 .86213 .41765 .86043 .41517 Metetra
.678 .74 .897 r
.86043 .41517 .86213 .41765 .8663 .41618 .86461 .4137 Metetra
.678 .74 .898 r
.86461 .4137 .8663 .41618 .87048 .41472 .86879 .41224 Metetra
.677 .74 .898 r
.86879 .41224 .87048 .41472 .87467 .41325 .87298 .41077 Metetra
.677 .74 .898 r
.87298 .41077 .87467 .41325 .87886 .41179 .87717 .40931 Metetra
.677 .74 .898 r
.87717 .40931 .87886 .41179 .88305 .41034 .88137 .40785 Metetra
.676 .74 .899 r
.88137 .40785 .88305 .41034 .88725 .40888 .88558 .40639 Metetra
.676 .74 .899 r
.88558 .40639 .88725 .40888 .89146 .40743 .88979 .40494 Metetra
.676 .74 .899 r
.88979 .40494 .89146 .40743 .89568 .40598 .89401 .40348 Metetra
.675 .74 .899 r
.89401 .40348 .89568 .40598 .8999 .40453 .89824 .40203 Metetra
.675 .74 .9 r
.89824 .40203 .8999 .40453 .90412 .40308 .90247 .40058 Metetra
.675 .74 .9 r
.90247 .40058 .90412 .40308 .90836 .40163 .9067 .39913 Metetra
.675 .74 .9 r
.9067 .39913 .90836 .40163 .9126 .40019 .91095 .39768 Metetra
.674 .74 .9 r
.91095 .39768 .9126 .40019 .91684 .39874 .9152 .39624 Metetra
.674 .74 .9 r
.9152 .39624 .91684 .39874 .92109 .3973 .91945 .39479 Metetra
.674 .74 .901 r
.91945 .39479 .92109 .3973 .92535 .39586 .92372 .39335 Metetra
.674 .74 .901 r
.92372 .39335 .92535 .39586 .92961 .39441 .92798 .3919 Metetra
.673 .74 .901 r
.92798 .3919 .92961 .39441 .93388 .39297 .93226 .39046 Metetra
.673 .74 .901 r
.93226 .39046 .93388 .39297 .93816 .39153 .93654 .38902 Metetra
.652 .733 .909 r
.35653 .56571 .35869 .56777 .36218 .5668 .36003 .56473 Metetra
.651 .733 .909 r
.36003 .56473 .36218 .5668 .36568 .56583 .36353 .56376 Metetra
.651 .733 .909 r
.36353 .56376 .36568 .56583 .36919 .56485 .36704 .56278 Metetra
.651 .733 .909 r
.36704 .56278 .36919 .56485 .3727 .56388 .37056 .56181 Metetra
.651 .733 .909 r
.37056 .56181 .3727 .56388 .37621 .56291 .37407 .56083 Metetra
.65 .732 .909 r
.37407 .56083 .37621 .56291 .37973 .56195 .3776 .55986 Metetra
.65 .732 .909 r
.3776 .55986 .37973 .56195 .38326 .56098 .38112 .55889 Metetra
.65 .732 .909 r
.38112 .55889 .38326 .56098 .38679 .56001 .38466 .55792 Metetra
.649 .732 .909 r
.38466 .55792 .38679 .56001 .39032 .55905 .38819 .55696 Metetra
.649 .731 .909 r
.38819 .55696 .39032 .55905 .39386 .55809 .39173 .55599 Metetra
.649 .731 .909 r
.39173 .55599 .39386 .55809 .39741 .55713 .39528 .55503 Metetra
.648 .731 .909 r
.39528 .55503 .39741 .55713 .40095 .55618 .39883 .55407 Metetra
.648 .731 .909 r
.39883 .55407 .40095 .55618 .40451 .55522 .40239 .55311 Metetra
.647 .73 .909 r
.40239 .55311 .40451 .55522 .40807 .55427 .40595 .55215 Metetra
.647 .73 .91 r
.40595 .55215 .40807 .55427 .41163 .55332 .40952 .5512 Metetra
.647 .73 .91 r
.40952 .5512 .41163 .55332 .4152 .55238 .41309 .55025 Metetra
.646 .729 .91 r
.41309 .55025 .4152 .55238 .41877 .55143 .41666 .5493 Metetra
.646 .729 .91 r
.41666 .5493 .41877 .55143 .42235 .55049 .42024 .54836 Metetra
.645 .729 .91 r
.42024 .54836 .42235 .55049 .42593 .54956 .42383 .54742 Metetra
.644 .728 .91 r
.42383 .54742 .42593 .54956 .42952 .54863 .42742 .54648 Metetra
.644 .728 .91 r
.42742 .54648 .42952 .54863 .43311 .5477 .43102 .54555 Metetra
.643 .728 .91 r
.43102 .54555 .43311 .5477 .43671 .54678 .43462 .54462 Metetra
.643 .727 .91 r
.43462 .54462 .43671 .54678 .44031 .54586 .43822 .5437 Metetra
.642 .727 .91 r
.43822 .5437 .44031 .54586 .44392 .54495 .44184 .54278 Metetra
.641 .726 .91 r
.44184 .54278 .44392 .54495 .44754 .54404 .44545 .54187 Metetra
.641 .726 .91 r
.44545 .54187 .44754 .54404 .45115 .54314 .44907 .54096 Metetra
.64 .725 .91 r
.44907 .54096 .45115 .54314 .45478 .54224 .4527 .54006 Metetra
.639 .725 .91 r
.4527 .54006 .45478 .54224 .45841 .54135 .45633 .53916 Metetra
.638 .724 .91 r
.45633 .53916 .45841 .54135 .46204 .54047 .45997 .53827 Metetra
.637 .724 .91 r
.45997 .53827 .46204 .54047 .46568 .53959 .46361 .53739 Metetra
.636 .723 .911 r
.46361 .53739 .46568 .53959 .46932 .53873 .46726 .53652 Metetra
.635 .722 .911 r
.46726 .53652 .46932 .53873 .47297 .53787 .47091 .53565 Metetra
.634 .722 .911 r
.47091 .53565 .47297 .53787 .47663 .53702 .47457 .5348 Metetra
.633 .721 .911 r
.47457 .5348 .47663 .53702 .48029 .53618 .47823 .53395 Metetra
.632 .72 .911 r
.47823 .53395 .48029 .53618 .48396 .53535 .4819 .53312 Metetra
.63 .719 .911 r
.4819 .53312 .48396 .53535 .48763 .53454 .48557 .53229 Metetra
.629 .718 .911 r
.48557 .53229 .48763 .53454 .4913 .53373 .48925 .53148 Metetra
.627 .717 .911 r
.48925 .53148 .4913 .53373 .49499 .53294 .49294 .53068 Metetra
.626 .716 .911 r
.49294 .53068 .49499 .53294 .49867 .53216 .49663 .5299 Metetra
.624 .715 .912 r
.49663 .5299 .49867 .53216 .50237 .5314 .50033 .52913 Metetra
.622 .714 .912 r
.50033 .52913 .50237 .5314 .50607 .53066 .50403 .52838 Metetra
.62 .712 .912 r
.50403 .52838 .50607 .53066 .50977 .52994 .50774 .52764 Metetra
.617 .711 .912 r
.50774 .52764 .50977 .52994 .51348 .52923 .51145 .52693 Metetra
.615 .709 .912 r
.51145 .52693 .51348 .52923 .5172 .52855 .51517 .52623 Metetra
.612 .707 .912 r
.51517 .52623 .5172 .52855 .52092 .52789 .5189 .52556 Metetra
.609 .705 .913 r
.5189 .52556 .52092 .52789 .52465 .52726 .52263 .52492 Metetra
.606 .703 .913 r
.52263 .52492 .52465 .52726 .52839 .52666 .52637 .52431 Metetra
.602 .701 .913 r
.52637 .52431 .52839 .52666 .53213 .52609 .53011 .52372 Metetra
.598 .698 .913 r
.53011 .52372 .53213 .52609 .53588 .52556 .53386 .52317 Metetra
.594 .695 .914 r
.53386 .52317 .53588 .52556 .53963 .52506 .53762 .52266 Metetra
.589 .692 .914 r
.53762 .52266 .53963 .52506 .5434 .52461 .54138 .5222 Metetra
.583 .689 .914 r
.54138 .5222 .5434 .52461 .54716 .52422 .54516 .52178 Metetra
.577 .684 .914 r
.54516 .52178 .54716 .52422 .55094 .52387 .54893 .52141 Metetra
.569 .68 .914 r
.54893 .52141 .55094 .52387 .55472 .52359 .55272 .52111 Metetra
.561 .674 .914 r
.55272 .52111 .55472 .52359 .55852 .52338 .55651 .52087 Metetra
.551 .668 .915 r
.55651 .52087 .55852 .52338 .56232 .52326 .56032 .52072 Metetra
.54 .661 .914 r
.56032 .52072 .56232 .52326 .56612 .52322 .56413 .52065 Metetra
.527 .652 .914 r
.56413 .52065 .56612 .52322 .56994 .5233 .56795 .52069 Metetra
.511 .642 .914 r
.56795 .52069 .56994 .5233 .57377 .5235 .57178 .52085 Metetra
.492 .629 .913 r
.57178 .52085 .57377 .5235 .57761 .52386 .57562 .52116 Metetra
.469 .614 .911 r
.57562 .52116 .57761 .52386 .58146 .52439 .57947 .52164 Metetra
.441 .595 .908 r
.57947 .52164 .58146 .52439 .58532 .52515 .58333 .52232 Metetra
.405 .571 .904 r
.58333 .52232 .58532 .52515 .5892 .52616 .58721 .52326 Metetra
.359 .539 .896 r
.58721 .52326 .5892 .52616 .5931 .52751 .59111 .52451 Metetra
.299 .496 .883 r
.59111 .52451 .5931 .52751 .59701 .52927 .59502 .52615 Metetra
.217 .438 .86 r
.59502 .52615 .59701 .52927 .60095 .53158 .59896 .52831 Metetra
.107 .355 .821 r
.59896 .52831 .60095 .53158 .60492 .53461 .60292 .53113 Metetra
0 .238 .753 r
.60292 .53113 .60492 .53461 .60893 .53864 .60693 .53489 Metetra
0 .075 .637 r
.60693 .53489 .60893 .53864 .613 .54411 .61098 .53998 Metetra
0 0 .457 r
.61098 .53998 .613 .54411 .61715 .55182 .61511 .5471 Metetra
.699 .345 0 r
.61511 .5471 .61715 .55182 .62143 .56326 .61936 .55756 Metetra
.86 .52 .007 r
.61936 .55756 .62143 .56326 .62596 .58183 .62382 .57424 Metetra
.947 .633 .197 r
.62382 .57424 .62596 .58183 .63107 .61751 .62876 .60519 Metetra
.98 .689 .336 r
.62876 .60519 .63107 .61751 .63754 .69293 .6354 .68738 Metetra
.627 .561 .76 r
.6354 .68738 .63754 .69293 .64166 .69182 .63952 .68635 Metetra
.955 .692 .498 r
.63952 .68635 .64166 .69182 .64315 .61411 .64082 .60176 Metetra
.875 .634 .571 r
.64082 .60176 .64315 .61411 .64587 .57605 .64372 .56843 Metetra
.872 .652 .603 r
.64372 .56843 .64587 .57605 .64914 .55509 .64707 .54936 Metetra
.864 .668 .636 r
.64707 .54936 .64914 .55509 .65264 .54126 .65061 .53651 Metetra
.854 .68 .667 r
.65061 .53651 .65264 .54126 .65627 .53117 .65426 .527 Metetra
.842 .691 .695 r
.65426 .527 .65627 .53117 .65996 .5233 .65798 .51951 Metetra
.831 .7 .72 r
.65798 .51951 .65996 .5233 .66371 .51688 .66174 .51336 Metetra
.819 .707 .741 r
.66174 .51336 .66371 .51688 .66749 .51146 .66554 .50813 Metetra
.808 .713 .76 r
.66554 .50813 .66749 .51146 .6713 .50677 .66936 .50358 Metetra
.798 .717 .776 r
.66936 .50358 .6713 .50677 .67513 .50261 .6732 .49954 Metetra
.788 .721 .789 r
.6732 .49954 .67513 .50261 .67898 .49887 .67706 .4959 Metetra
.779 .724 .801 r
.67706 .4959 .67898 .49887 .68285 .49546 .68093 .49256 Metetra
.771 .727 .812 r
.68093 .49256 .68285 .49546 .68673 .49232 .68481 .48948 Metetra
.763 .729 .82 r
.68481 .48948 .68673 .49232 .69062 .48939 .68871 .4866 Metetra
.757 .73 .828 r
.68871 .4866 .69062 .48939 .69452 .48664 .69262 .48389 Metetra
.75 .731 .835 r
.69262 .48389 .69452 .48664 .69843 .48404 .69653 .48133 Metetra
.745 .733 .841 r
.69653 .48133 .69843 .48404 .70234 .48157 .70046 .47889 Metetra
.739 .734 .846 r
.70046 .47889 .70234 .48157 .70627 .47921 .70439 .47655 Metetra
.735 .734 .851 r
.70439 .47655 .70627 .47921 .71021 .47694 .70833 .4743 Metetra
.73 .735 .855 r
.70833 .4743 .71021 .47694 .71415 .47475 .71228 .47214 Metetra
.726 .736 .858 r
.71228 .47214 .71415 .47475 .7181 .47264 .71624 .47004 Metetra
.723 .736 .862 r
.71624 .47004 .7181 .47264 .72206 .47058 .7202 .468 Metetra
.719 .736 .865 r
.7202 .468 .72206 .47058 .72603 .46858 .72417 .46602 Metetra
.716 .737 .867 r
.72417 .46602 .72603 .46858 .73 .46664 .72815 .46408 Metetra
.714 .737 .87 r
.72815 .46408 .73 .46664 .73398 .46473 .73213 .46219 Metetra
.711 .737 .872 r
.73213 .46219 .73398 .46473 .73797 .46287 .73612 .46033 Metetra
.709 .738 .874 r
.73612 .46033 .73797 .46287 .74196 .46104 .74012 .45851 Metetra
.706 .738 .876 r
.74012 .45851 .74196 .46104 .74596 .45924 .74412 .45672 Metetra
.704 .738 .877 r
.74412 .45672 .74596 .45924 .74996 .45747 .74814 .45496 Metetra
.702 .738 .879 r
.74814 .45496 .74996 .45747 .75397 .45573 .75215 .45322 Metetra
.701 .738 .88 r
.75215 .45322 .75397 .45573 .75799 .45401 .75617 .45151 Metetra
.699 .738 .882 r
.75617 .45151 .75799 .45401 .76202 .45232 .7602 .44982 Metetra
.697 .739 .883 r
.7602 .44982 .76202 .45232 .76605 .45064 .76424 .44815 Metetra
.696 .739 .884 r
.76424 .44815 .76605 .45064 .77008 .44898 .76828 .44649 Metetra
.695 .739 .885 r
.76828 .44649 .77008 .44898 .77413 .44734 .77233 .44486 Metetra
.693 .739 .886 r
.77233 .44486 .77413 .44734 .77818 .44572 .77638 .44323 Metetra
.692 .739 .887 r
.77638 .44323 .77818 .44572 .78223 .44411 .78044 .44162 Metetra
.691 .739 .888 r
.78044 .44162 .78223 .44411 .78629 .44251 .78451 .44003 Metetra
.69 .739 .889 r
.78451 .44003 .78629 .44251 .79036 .44092 .78858 .43844 Metetra
.689 .739 .889 r
.78858 .43844 .79036 .44092 .79443 .43935 .79266 .43687 Metetra
.688 .739 .89 r
.79266 .43687 .79443 .43935 .79851 .43779 .79674 .43531 Metetra
.687 .739 .891 r
.79674 .43531 .79851 .43779 .8026 .43623 .80083 .43375 Metetra
.686 .739 .891 r
.80083 .43375 .8026 .43623 .80669 .43469 .80493 .43221 Metetra
.685 .739 .892 r
.80493 .43221 .80669 .43469 .81079 .43315 .80903 .43067 Metetra
.685 .74 .893 r
.80903 .43067 .81079 .43315 .81489 .43162 .81314 .42914 Metetra
.684 .74 .893 r
.81314 .42914 .81489 .43162 .819 .4301 .81725 .42762 Metetra
.683 .74 .894 r
.81725 .42762 .819 .4301 .82312 .42858 .82137 .4261 Metetra
.683 .74 .894 r
.82137 .4261 .82312 .42858 .82724 .42707 .8255 .42459 Metetra
.682 .74 .895 r
.8255 .42459 .82724 .42707 .83137 .42557 .82963 .42309 Metetra
.681 .74 .895 r
.82963 .42309 .83137 .42557 .8355 .42407 .83377 .42159 Metetra
.681 .74 .895 r
.83377 .42159 .8355 .42407 .83964 .42258 .83791 .4201 Metetra
.68 .74 .896 r
.83791 .4201 .83964 .42258 .84379 .42109 .84206 .41861 Metetra
.68 .74 .896 r
.84206 .41861 .84379 .42109 .84794 .4196 .84622 .41712 Metetra
.679 .74 .896 r
.84622 .41712 .84794 .4196 .8521 .41812 .85038 .41564 Metetra
.679 .74 .897 r
.85038 .41564 .8521 .41812 .85626 .41665 .85455 .41416 Metetra
.678 .74 .897 r
.85455 .41416 .85626 .41665 .86043 .41517 .85872 .41269 Metetra
.678 .74 .897 r
.85872 .41269 .86043 .41517 .86461 .4137 .8629 .41122 Metetra
.678 .74 .898 r
.8629 .41122 .86461 .4137 .86879 .41224 .86709 .40975 Metetra
.677 .74 .898 r
.86709 .40975 .86879 .41224 .87298 .41077 .87128 .40828 Metetra
.677 .74 .898 r
.87128 .40828 .87298 .41077 .87717 .40931 .87548 .40682 Metetra
.677 .74 .899 r
.87548 .40682 .87717 .40931 .88137 .40785 .87969 .40536 Metetra
.676 .74 .899 r
.87969 .40536 .88137 .40785 .88558 .40639 .8839 .4039 Metetra
.676 .74 .899 r
.8839 .4039 .88558 .40639 .88979 .40494 .88812 .40244 Metetra
.676 .74 .899 r
.88812 .40244 .88979 .40494 .89401 .40348 .89234 .40098 Metetra
.675 .74 .899 r
.89234 .40098 .89401 .40348 .89824 .40203 .89657 .39953 Metetra
.675 .74 .9 r
.89657 .39953 .89824 .40203 .90247 .40058 .90081 .39808 Metetra
.675 .74 .9 r
.90081 .39808 .90247 .40058 .9067 .39913 .90505 .39663 Metetra
.674 .74 .9 r
.90505 .39663 .9067 .39913 .91095 .39768 .9093 .39518 Metetra
.674 .74 .9 r
.9093 .39518 .91095 .39768 .9152 .39624 .91355 .39373 Metetra
.674 .74 .9 r
.91355 .39373 .9152 .39624 .91945 .39479 .91781 .39228 Metetra
.674 .74 .901 r
.91781 .39228 .91945 .39479 .92372 .39335 .92208 .39083 Metetra
.673 .74 .901 r
.92208 .39083 .92372 .39335 .92798 .3919 .92635 .38939 Metetra
.673 .74 .901 r
.92635 .38939 .92798 .3919 .93226 .39046 .93063 .38794 Metetra
.673 .74 .901 r
.93063 .38794 .93226 .39046 .93654 .38902 .93492 .3865 Metetra
.652 .733 .909 r
.35437 .56365 .35653 .56571 .36003 .56473 .35787 .56266 Metetra
.652 .733 .909 r
.35787 .56266 .36003 .56473 .36353 .56376 .36138 .56168 Metetra
.651 .733 .909 r
.36138 .56168 .36353 .56376 .36704 .56278 .36489 .5607 Metetra
.651 .733 .909 r
.36489 .5607 .36704 .56278 .37056 .56181 .36841 .55973 Metetra
.651 .733 .909 r
.36841 .55973 .37056 .56181 .37407 .56083 .37193 .55875 Metetra
.65 .732 .909 r
.37193 .55875 .37407 .56083 .3776 .55986 .37545 .55777 Metetra
.65 .732 .909 r
.37545 .55777 .3776 .55986 .38112 .55889 .37898 .5568 Metetra
.65 .732 .909 r
.37898 .5568 .38112 .55889 .38466 .55792 .38252 .55583 Metetra
.649 .732 .909 r
.38252 .55583 .38466 .55792 .38819 .55696 .38606 .55485 Metetra
.649 .731 .909 r
.38606 .55485 .38819 .55696 .39173 .55599 .3896 .55389 Metetra
.649 .731 .909 r
.3896 .55389 .39173 .55599 .39528 .55503 .39315 .55292 Metetra
.648 .731 .909 r
.39315 .55292 .39528 .55503 .39883 .55407 .39671 .55195 Metetra
.648 .731 .909 r
.39671 .55195 .39883 .55407 .40239 .55311 .40026 .55099 Metetra
.648 .73 .909 r
.40026 .55099 .40239 .55311 .40595 .55215 .40383 .55003 Metetra
.647 .73 .909 r
.40383 .55003 .40595 .55215 .40952 .5512 .4074 .54907 Metetra
.647 .73 .909 r
.4074 .54907 .40952 .5512 .41309 .55025 .41097 .54812 Metetra
.646 .73 .91 r
.41097 .54812 .41309 .55025 .41666 .5493 .41455 .54717 Metetra
.646 .729 .91 r
.41455 .54717 .41666 .5493 .42024 .54836 .41813 .54622 Metetra
.645 .729 .91 r
.41813 .54622 .42024 .54836 .42383 .54742 .42172 .54527 Metetra
.645 .729 .91 r
.42172 .54527 .42383 .54742 .42742 .54648 .42532 .54433 Metetra
.644 .728 .91 r
.42532 .54433 .42742 .54648 .43102 .54555 .42892 .5434 Metetra
.644 .728 .91 r
.42892 .5434 .43102 .54555 .43462 .54462 .43252 .54246 Metetra
.643 .727 .91 r
.43252 .54246 .43462 .54462 .43822 .5437 .43613 .54153 Metetra
.642 .727 .91 r
.43613 .54153 .43822 .5437 .44184 .54278 .43974 .54061 Metetra
.642 .726 .91 r
.43974 .54061 .44184 .54278 .44545 .54187 .44336 .53969 Metetra
.641 .726 .91 r
.44336 .53969 .44545 .54187 .44907 .54096 .44699 .53878 Metetra
.64 .725 .91 r
.44699 .53878 .44907 .54096 .4527 .54006 .45062 .53787 Metetra
.639 .725 .91 r
.45062 .53787 .4527 .54006 .45633 .53916 .45425 .53697 Metetra
.638 .724 .91 r
.45425 .53697 .45633 .53916 .45997 .53827 .45789 .53607 Metetra
.638 .724 .91 r
.45789 .53607 .45997 .53827 .46361 .53739 .46154 .53519 Metetra
.637 .723 .91 r
.46154 .53519 .46361 .53739 .46726 .53652 .46519 .53431 Metetra
.636 .722 .91 r
.46519 .53431 .46726 .53652 .47091 .53565 .46884 .53344 Metetra
.634 .722 .911 r
.46884 .53344 .47091 .53565 .47457 .5348 .4725 .53257 Metetra
.633 .721 .911 r
.4725 .53257 .47457 .5348 .47823 .53395 .47617 .53172 Metetra
.632 .72 .911 r
.47617 .53172 .47823 .53395 .4819 .53312 .47984 .53088 Metetra
.631 .719 .911 r
.47984 .53088 .4819 .53312 .48557 .53229 .48352 .53005 Metetra
.629 .718 .911 r
.48352 .53005 .48557 .53229 .48925 .53148 .4872 .52923 Metetra
.628 .717 .911 r
.4872 .52923 .48925 .53148 .49294 .53068 .49089 .52842 Metetra
.626 .716 .911 r
.49089 .52842 .49294 .53068 .49663 .5299 .49458 .52763 Metetra
.624 .715 .911 r
.49458 .52763 .49663 .5299 .50033 .52913 .49828 .52685 Metetra
.623 .714 .912 r
.49828 .52685 .50033 .52913 .50403 .52838 .50199 .52608 Metetra
.62 .713 .912 r
.50199 .52608 .50403 .52838 .50774 .52764 .5057 .52534 Metetra
.618 .711 .912 r
.5057 .52534 .50774 .52764 .51145 .52693 .50941 .52462 Metetra
.616 .71 .912 r
.50941 .52462 .51145 .52693 .51517 .52623 .51314 .52391 Metetra
.613 .708 .912 r
.51314 .52391 .51517 .52623 .5189 .52556 .51687 .52323 Metetra
.61 .706 .912 r
.51687 .52323 .5189 .52556 .52263 .52492 .5206 .52257 Metetra
.607 .704 .913 r
.5206 .52257 .52263 .52492 .52637 .52431 .52434 .52195 Metetra
.604 .702 .913 r
.52434 .52195 .52637 .52431 .53011 .52372 .52809 .52135 Metetra
.6 .699 .913 r
.52809 .52135 .53011 .52372 .53386 .52317 .53184 .52078 Metetra
.595 .696 .913 r
.53184 .52078 .53386 .52317 .53762 .52266 .5356 .52026 Metetra
.59 .693 .913 r
.5356 .52026 .53762 .52266 .54138 .5222 .53937 .51977 Metetra
.585 .689 .914 r
.53937 .51977 .54138 .5222 .54516 .52178 .54314 .51933 Metetra
.579 .685 .914 r
.54314 .51933 .54516 .52178 .54893 .52141 .54692 .51895 Metetra
.572 .681 .914 r
.54692 .51895 .54893 .52141 .55272 .52111 .55071 .51862 Metetra
.564 .676 .914 r
.55071 .51862 .55272 .52111 .55651 .52087 .55451 .51836 Metetra
.555 .67 .914 r
.55451 .51836 .55651 .52087 .56032 .52072 .55831 .51817 Metetra
.544 .663 .914 r
.55831 .51817 .56032 .52072 .56413 .52065 .56213 .51808 Metetra
.532 .654 .914 r
.56213 .51808 .56413 .52065 .56795 .52069 .56595 .51808 Metetra
.517 .645 .913 r
.56595 .51808 .56795 .52069 .57178 .52085 .56978 .5182 Metetra
.499 .633 .912 r
.56978 .5182 .57178 .52085 .57562 .52116 .57362 .51846 Metetra
.477 .618 .911 r
.57362 .51846 .57562 .52116 .57947 .52164 .57747 .51888 Metetra
.451 .6 .908 r
.57747 .51888 .57947 .52164 .58333 .52232 .58134 .5195 Metetra
.417 .578 .904 r
.58134 .5195 .58333 .52232 .58721 .52326 .58522 .52036 Metetra
.375 .548 .897 r
.58522 .52036 .58721 .52326 .59111 .52451 .58911 .52151 Metetra
.319 .509 .886 r
.58911 .52151 .59111 .52451 .59502 .52615 .59302 .52304 Metetra
.245 .455 .867 r
.59302 .52304 .59502 .52615 .59896 .52831 .59696 .52504 Metetra
.144 .38 .833 r
.59696 .52504 .59896 .52831 .60292 .53113 .60092 .52768 Metetra
.005 .274 .775 r
.60092 .52768 .60292 .53113 .60693 .53489 .60492 .53117 Metetra
0 .124 .674 r
.60492 .53117 .60693 .53489 .61098 .53998 .60896 .53589 Metetra
0 0 .513 r
.60896 .53589 .61098 .53998 .61511 .5471 .61307 .54244 Metetra
0 0 .292 r
.61307 .54244 .61511 .5471 .61936 .55756 .61729 .55198 Metetra
.823 .482 0 r
.61729 .55198 .61936 .55756 .62382 .57424 .62169 .56693 Metetra
.93 .612 .152 r
.62169 .56693 .62382 .57424 .62876 .60519 .62649 .59373 Metetra
.981 .69 .362 r
.62649 .59373 .62876 .60519 .6354 .68738 .63347 .6888 Metetra
.092 0 0 r
.63347 .6888 .6354 .68738 .63952 .68635 .63759 .68767 Metetra
.974 .711 .468 r
.63759 .68767 .63952 .68635 .64082 .60176 .63852 .59028 Metetra
.87 .633 .578 r
.63852 .59028 .64082 .60176 .64372 .56843 .64158 .56109 Metetra
.867 .652 .61 r
.64158 .56109 .64372 .56843 .64707 .54936 .64499 .54375 Metetra
.859 .668 .642 r
.64499 .54375 .64707 .54936 .65061 .53651 .64858 .53181 Metetra
.849 .68 .673 r
.64858 .53181 .65061 .53651 .65426 .527 .65226 .52286 Metetra
.838 .691 .7 r
.65226 .52286 .65426 .527 .65798 .51951 .65599 .51574 Metetra
.826 .7 .725 r
.65599 .51574 .65798 .51951 .66174 .51336 .65977 .50985 Metetra
.815 .707 .745 r
.65977 .50985 .66174 .51336 .66554 .50813 .66358 .50481 Metetra
.805 .713 .763 r
.66358 .50481 .66554 .50813 .66936 .50358 .66741 .50041 Metetra
.794 .717 .779 r
.66741 .50041 .66936 .50358 .6732 .49954 .67126 .49648 Metetra
.785 .721 .792 r
.67126 .49648 .6732 .49954 .67706 .4959 .67513 .49292 Metetra
.776 .724 .804 r
.67513 .49292 .67706 .4959 .68093 .49256 .67901 .48966 Metetra
.768 .726 .814 r
.67901 .48966 .68093 .49256 .68481 .48948 .6829 .48663 Metetra
.761 .728 .822 r
.6829 .48663 .68481 .48948 .68871 .4866 .6868 .4838 Metetra
.754 .73 .83 r
.6868 .4838 .68871 .4866 .69262 .48389 .69071 .48114 Metetra
.748 .731 .836 r
.69071 .48114 .69262 .48389 .69653 .48133 .69463 .47861 Metetra
.743 .732 .842 r
.69463 .47861 .69653 .48133 .70046 .47889 .69857 .4762 Metetra
.738 .733 .847 r
.69857 .4762 .70046 .47889 .70439 .47655 .7025 .47389 Metetra
.733 .734 .852 r
.7025 .47389 .70439 .47655 .70833 .4743 .70645 .47167 Metetra
.729 .735 .856 r
.70645 .47167 .70833 .4743 .71228 .47214 .71041 .46952 Metetra
.725 .735 .859 r
.71041 .46952 .71228 .47214 .71624 .47004 .71437 .46744 Metetra
.722 .736 .862 r
.71437 .46744 .71624 .47004 .7202 .468 .71834 .46542 Metetra
.718 .736 .865 r
.71834 .46542 .7202 .468 .72417 .46602 .72231 .46344 Metetra
.715 .737 .868 r
.72231 .46344 .72417 .46602 .72815 .46408 .72629 .46152 Metetra
.713 .737 .87 r
.72629 .46152 .72815 .46408 .73213 .46219 .73028 .45964 Metetra
.71 .737 .872 r
.73028 .45964 .73213 .46219 .73612 .46033 .73428 .45779 Metetra
.708 .737 .874 r
.73428 .45779 .73612 .46033 .74012 .45851 .73828 .45598 Metetra
.706 .738 .876 r
.73828 .45598 .74012 .45851 .74412 .45672 .74229 .4542 Metetra
.704 .738 .878 r
.74229 .4542 .74412 .45672 .74814 .45496 .7463 .45244 Metetra
.702 .738 .879 r
.7463 .45244 .74814 .45496 .75215 .45322 .75032 .45071 Metetra
.7 .738 .881 r
.75032 .45071 .75215 .45322 .75617 .45151 .75435 .449 Metetra
.698 .738 .882 r
.75435 .449 .75617 .45151 .7602 .44982 .75838 .44732 Metetra
.697 .738 .883 r
.75838 .44732 .7602 .44982 .76424 .44815 .76242 .44565 Metetra
.695 .739 .884 r
.76242 .44565 .76424 .44815 .76828 .44649 .76647 .444 Metetra
.694 .739 .885 r
.76647 .444 .76828 .44649 .77233 .44486 .77052 .44236 Metetra
.693 .739 .886 r
.77052 .44236 .77233 .44486 .77638 .44323 .77458 .44074 Metetra
.692 .739 .887 r
.77458 .44074 .77638 .44323 .78044 .44162 .77864 .43913 Metetra
.691 .739 .888 r
.77864 .43913 .78044 .44162 .78451 .44003 .78271 .43754 Metetra
.689 .739 .889 r
.78271 .43754 .78451 .44003 .78858 .43844 .78679 .43596 Metetra
.688 .739 .89 r
.78679 .43596 .78858 .43844 .79266 .43687 .79087 .43439 Metetra
.688 .739 .89 r
.79087 .43439 .79266 .43687 .79674 .43531 .79496 .43282 Metetra
.687 .739 .891 r
.79496 .43282 .79674 .43531 .80083 .43375 .79906 .43127 Metetra
.686 .739 .892 r
.79906 .43127 .80083 .43375 .80493 .43221 .80316 .42973 Metetra
.685 .739 .892 r
.80316 .42973 .80493 .43221 .80903 .43067 .80726 .42819 Metetra
.684 .739 .893 r
.80726 .42819 .80903 .43067 .81314 .42914 .81138 .42666 Metetra
.684 .739 .893 r
.81138 .42666 .81314 .42914 .81725 .42762 .81549 .42514 Metetra
.683 .74 .894 r
.81549 .42514 .81725 .42762 .82137 .4261 .81962 .42362 Metetra
.682 .74 .894 r
.81962 .42362 .82137 .4261 .8255 .42459 .82375 .42211 Metetra
.682 .74 .895 r
.82375 .42211 .8255 .42459 .82963 .42309 .82789 .42061 Metetra
.681 .74 .895 r
.82789 .42061 .82963 .42309 .83377 .42159 .83203 .41911 Metetra
.681 .74 .895 r
.83203 .41911 .83377 .42159 .83791 .4201 .83618 .41761 Metetra
.68 .74 .896 r
.83618 .41761 .83791 .4201 .84206 .41861 .84033 .41612 Metetra
.68 .74 .896 r
.84033 .41612 .84206 .41861 .84622 .41712 .84449 .41463 Metetra
.679 .74 .897 r
.84449 .41463 .84622 .41712 .85038 .41564 .84866 .41315 Metetra
.679 .74 .897 r
.84866 .41315 .85038 .41564 .85455 .41416 .85283 .41167 Metetra
.678 .74 .897 r
.85283 .41167 .85455 .41416 .85872 .41269 .85701 .4102 Metetra
.678 .74 .898 r
.85701 .4102 .85872 .41269 .8629 .41122 .8612 .40872 Metetra
.677 .74 .898 r
.8612 .40872 .8629 .41122 .86709 .40975 .86539 .40725 Metetra
.677 .74 .898 r
.86539 .40725 .86709 .40975 .87128 .40828 .86959 .40579 Metetra
.677 .74 .898 r
.86959 .40579 .87128 .40828 .87548 .40682 .87379 .40432 Metetra
.676 .74 .899 r
.87379 .40432 .87548 .40682 .87969 .40536 .878 .40286 Metetra
.676 .74 .899 r
.878 .40286 .87969 .40536 .8839 .4039 .88222 .4014 Metetra
.676 .74 .899 r
.88222 .4014 .8839 .4039 .88812 .40244 .88644 .39994 Metetra
.675 .74 .899 r
.88644 .39994 .88812 .40244 .89234 .40098 .89067 .39848 Metetra
.675 .74 .899 r
.89067 .39848 .89234 .40098 .89657 .39953 .8949 .39702 Metetra
.675 .74 .9 r
.8949 .39702 .89657 .39953 .90081 .39808 .89914 .39557 Metetra
.675 .74 .9 r
.89914 .39557 .90081 .39808 .90505 .39663 .90339 .39412 Metetra
.674 .74 .9 r
.90339 .39412 .90505 .39663 .9093 .39518 .90764 .39266 Metetra
.674 .74 .9 r
.90764 .39266 .9093 .39518 .91355 .39373 .9119 .39121 Metetra
.674 .74 .9 r
.9119 .39121 .91355 .39373 .91781 .39228 .91616 .38976 Metetra
.674 .74 .901 r
.91616 .38976 .91781 .39228 .92208 .39083 .92044 .38831 Metetra
.673 .74 .901 r
.92044 .38831 .92208 .39083 .92635 .38939 .92471 .38686 Metetra
.673 .74 .901 r
.92471 .38686 .92635 .38939 .93063 .38794 .929 .38542 Metetra
.673 .74 .901 r
.929 .38542 .93063 .38794 .93492 .3865 .93329 .38397 Metetra
.652 .733 .909 r
.35221 .56158 .35437 .56365 .35787 .56266 .35571 .56059 Metetra
.652 .733 .909 r
.35571 .56059 .35787 .56266 .36138 .56168 .35922 .55961 Metetra
.651 .733 .909 r
.35922 .55961 .36138 .56168 .36489 .5607 .36273 .55862 Metetra
.651 .733 .909 r
.36273 .55862 .36489 .5607 .36841 .55973 .36625 .55764 Metetra
.651 .733 .909 r
.36625 .55764 .36841 .55973 .37193 .55875 .36977 .55666 Metetra
.651 .732 .909 r
.36977 .55666 .37193 .55875 .37545 .55777 .3733 .55568 Metetra
.65 .732 .909 r
.3733 .55568 .37545 .55777 .37898 .5568 .37684 .5547 Metetra
.65 .732 .909 r
.37684 .5547 .37898 .5568 .38252 .55583 .38037 .55372 Metetra
.65 .732 .909 r
.38037 .55372 .38252 .55583 .38606 .55485 .38392 .55275 Metetra
.649 .732 .909 r
.38392 .55275 .38606 .55485 .3896 .55389 .38746 .55178 Metetra
.649 .731 .909 r
.38746 .55178 .3896 .55389 .39315 .55292 .39102 .5508 Metetra
.649 .731 .909 r
.39102 .5508 .39315 .55292 .39671 .55195 .39457 .54983 Metetra
.648 .731 .909 r
.39457 .54983 .39671 .55195 .40026 .55099 .39814 .54887 Metetra
.648 .731 .909 r
.39814 .54887 .40026 .55099 .40383 .55003 .4017 .5479 Metetra
.647 .73 .909 r
.4017 .5479 .40383 .55003 .4074 .54907 .40527 .54694 Metetra
.647 .73 .909 r
.40527 .54694 .4074 .54907 .41097 .54812 .40885 .54598 Metetra
.646 .73 .909 r
.40885 .54598 .41097 .54812 .41455 .54717 .41243 .54503 Metetra
.646 .729 .91 r
.41243 .54503 .41455 .54717 .41813 .54622 .41602 .54407 Metetra
.645 .729 .91 r
.41602 .54407 .41813 .54622 .42172 .54527 .41961 .54312 Metetra
.645 .729 .91 r
.41961 .54312 .42172 .54527 .42532 .54433 .42321 .54218 Metetra
.644 .728 .91 r
.42321 .54218 .42532 .54433 .42892 .5434 .42681 .54124 Metetra
.644 .728 .91 r
.42681 .54124 .42892 .5434 .43252 .54246 .43042 .5403 Metetra
.643 .727 .91 r
.43042 .5403 .43252 .54246 .43613 .54153 .43403 .53936 Metetra
.643 .727 .91 r
.43403 .53936 .43613 .54153 .43974 .54061 .43765 .53843 Metetra
.642 .727 .91 r
.43765 .53843 .43974 .54061 .44336 .53969 .44127 .53751 Metetra
.641 .726 .91 r
.44127 .53751 .44336 .53969 .44699 .53878 .44489 .53659 Metetra
.64 .726 .91 r
.44489 .53659 .44699 .53878 .45062 .53787 .44853 .53568 Metetra
.64 .725 .91 r
.44853 .53568 .45062 .53787 .45425 .53697 .45216 .53477 Metetra
.639 .725 .91 r
.45216 .53477 .45425 .53697 .45789 .53607 .45581 .53387 Metetra
.638 .724 .91 r
.45581 .53387 .45789 .53607 .46154 .53519 .45945 .53298 Metetra
.637 .723 .91 r
.45945 .53298 .46154 .53519 .46519 .53431 .46311 .53209 Metetra
.636 .723 .91 r
.46311 .53209 .46519 .53431 .46884 .53344 .46677 .53121 Metetra
.635 .722 .91 r
.46677 .53121 .46884 .53344 .4725 .53257 .47043 .53034 Metetra
.634 .721 .911 r
.47043 .53034 .4725 .53257 .47617 .53172 .4741 .52948 Metetra
.633 .72 .911 r
.4741 .52948 .47617 .53172 .47984 .53088 .47777 .52863 Metetra
.631 .72 .911 r
.47777 .52863 .47984 .53088 .48352 .53005 .48145 .52779 Metetra
.63 .719 .911 r
.48145 .52779 .48352 .53005 .4872 .52923 .48514 .52697 Metetra
.628 .718 .911 r
.48514 .52697 .4872 .52923 .49089 .52842 .48883 .52615 Metetra
.627 .717 .911 r
.48883 .52615 .49089 .52842 .49458 .52763 .49253 .52535 Metetra
.625 .715 .911 r
.49253 .52535 .49458 .52763 .49828 .52685 .49623 .52456 Metetra
.623 .714 .911 r
.49623 .52456 .49828 .52685 .50199 .52608 .49994 .52379 Metetra
.621 .713 .911 r
.49994 .52379 .50199 .52608 .5057 .52534 .50365 .52304 Metetra
.619 .711 .912 r
.50365 .52304 .5057 .52534 .50941 .52462 .50737 .5223 Metetra
.617 .71 .912 r
.50737 .5223 .50941 .52462 .51314 .52391 .5111 .52158 Metetra
.614 .708 .912 r
.5111 .52158 .51314 .52391 .51687 .52323 .51483 .52089 Metetra
.611 .706 .912 r
.51483 .52089 .51687 .52323 .5206 .52257 .51857 .52022 Metetra
.608 .704 .912 r
.51857 .52022 .5206 .52257 .52434 .52195 .52231 .51958 Metetra
.605 .702 .912 r
.52231 .51958 .52434 .52195 .52809 .52135 .52606 .51897 Metetra
.601 .7 .913 r
.52606 .51897 .52809 .52135 .53184 .52078 .52982 .51839 Metetra
.597 .697 .913 r
.52982 .51839 .53184 .52078 .5356 .52026 .53358 .51785 Metetra
.592 .694 .913 r
.53358 .51785 .5356 .52026 .53937 .51977 .53735 .51734 Metetra
.587 .69 .913 r
.53735 .51734 .53937 .51977 .54314 .51933 .54112 .51689 Metetra
.581 .686 .913 r
.54112 .51689 .54314 .51933 .54692 .51895 .54491 .51648 Metetra
.574 .682 .913 r
.54491 .51648 .54692 .51895 .55071 .51862 .5487 .51613 Metetra
.567 .677 .914 r
.5487 .51613 .55071 .51862 .55451 .51836 .5525 .51584 Metetra
.558 .671 .914 r
.5525 .51584 .55451 .51836 .55831 .51817 .5563 .51563 Metetra
.548 .665 .914 r
.5563 .51563 .55831 .51817 .56213 .51808 .56012 .5155 Metetra
.536 .657 .913 r
.56012 .5155 .56213 .51808 .56595 .51808 .56394 .51547 Metetra
.522 .647 .913 r
.56394 .51547 .56595 .51808 .56978 .5182 .56777 .51555 Metetra
.505 .636 .912 r
.56777 .51555 .56978 .5182 .57362 .51846 .57162 .51576 Metetra
.485 .622 .911 r
.57162 .51576 .57362 .51846 .57747 .51888 .57547 .51612 Metetra
.46 .606 .908 r
.57547 .51612 .57747 .51888 .58134 .5195 .57934 .51668 Metetra
.429 .584 .905 r
.57934 .51668 .58134 .5195 .58522 .52036 .58322 .51746 Metetra
.389 .557 .899 r
.58322 .51746 .58522 .52036 .58911 .52151 .58711 .51852 Metetra
.338 .521 .889 r
.58711 .51852 .58911 .52151 .59302 .52304 .59102 .51993 Metetra
.27 .472 .872 r
.59102 .51993 .59302 .52304 .59696 .52504 .59495 .52179 Metetra
.178 .404 .843 r
.59495 .52179 .59696 .52504 .60092 .52768 .59891 .52423 Metetra
.052 .307 .794 r
.59891 .52423 .60092 .52768 .60492 .53117 .6029 .52747 Metetra
0 .171 .707 r
.6029 .52747 .60492 .53117 .60896 .53589 .60694 .53184 Metetra
0 0 .565 r
.60694 .53184 .60896 .53589 .61307 .54244 .61103 .53786 Metetra
0 0 .358 r
.61103 .53786 .61307 .54244 .61729 .55198 .61522 .54654 Metetra
.777 .436 0 r
.61522 .54654 .61729 .55198 .62169 .56693 .61957 .55991 Metetra
.907 .586 .102 r
.61957 .55991 .62169 .56693 .62649 .59373 .62424 .58313 Metetra
.98 .689 .377 r
.62424 .58313 .62649 .59373 .63347 .6888 .63142 .68672 Metetra
.645 .763 .934 r
.63142 .68672 .63347 .6888 .63759 .68767 .63555 .68559 Metetra
.966 .7 .479 r
.63555 .68559 .63759 .68767 .63852 .59028 .63626 .57966 Metetra
.866 .633 .585 r
.63626 .57966 .63852 .59028 .64158 .56109 .63944 .55405 Metetra
.862 .652 .617 r
.63944 .55405 .64158 .56109 .64499 .54375 .64292 .53827 Metetra
.854 .668 .649 r
.64292 .53827 .64499 .54375 .64858 .53181 .64655 .5272 Metetra
.844 .681 .679 r
.64655 .5272 .64858 .53181 .65226 .52286 .65025 .51877 Metetra
.833 .691 .706 r
.65025 .51877 .65226 .52286 .65599 .51574 .654 .512 Metetra
.822 .7 .73 r
.654 .512 .65599 .51574 .65977 .50985 .6578 .50635 Metetra
.811 .707 .75 r
.6578 .50635 .65977 .50985 .66358 .50481 .66162 .5015 Metetra
.801 .712 .767 r
.66162 .5015 .66358 .50481 .66741 .50041 .66546 .49723 Metetra
.791 .717 .782 r
.66546 .49723 .66741 .50041 .67126 .49648 .66932 .49341 Metetra
.782 .721 .795 r
.66932 .49341 .67126 .49648 .67513 .49292 .67319 .48994 Metetra
.773 .723 .806 r
.67319 .48994 .67513 .49292 .67901 .48966 .67708 .48675 Metetra
.766 .726 .816 r
.67708 .48675 .67901 .48966 .6829 .48663 .68098 .48379 Metetra
.759 .728 .824 r
.68098 .48379 .6829 .48663 .6868 .4838 .68489 .48101 Metetra
.752 .729 .831 r
.68489 .48101 .6868 .4838 .69071 .48114 .68881 .47838 Metetra
.746 .731 .838 r
.68881 .47838 .69071 .48114 .69463 .47861 .69273 .47589 Metetra
.741 .732 .843 r
.69273 .47589 .69463 .47861 .69857 .4762 .69667 .47351 Metetra
.736 .733 .848 r
.69667 .47351 .69857 .4762 .7025 .47389 .70061 .47122 Metetra
.732 .734 .852 r
.70061 .47122 .7025 .47389 .70645 .47167 .70457 .46902 Metetra
.728 .734 .856 r
.70457 .46902 .70645 .47167 .71041 .46952 .70852 .4669 Metetra
.724 .735 .86 r
.70852 .4669 .71041 .46952 .71437 .46744 .71249 .46483 Metetra
.72 .735 .863 r
.71249 .46483 .71437 .46744 .71834 .46542 .71647 .46282 Metetra
.717 .736 .866 r
.71647 .46282 .71834 .46542 .72231 .46344 .72045 .46087 Metetra
.714 .736 .868 r
.72045 .46087 .72231 .46344 .72629 .46152 .72443 .45895 Metetra
.712 .737 .871 r
.72443 .45895 .72629 .46152 .73028 .45964 .72843 .45708 Metetra
.709 .737 .873 r
.72843 .45708 .73028 .45964 .73428 .45779 .73243 .45524 Metetra
.707 .737 .875 r
.73243 .45524 .73428 .45779 .73828 .45598 .73643 .45344 Metetra
.705 .737 .877 r
.73643 .45344 .73828 .45598 .74229 .4542 .74045 .45166 Metetra
.703 .738 .878 r
.74045 .45166 .74229 .4542 .7463 .45244 .74447 .44992 Metetra
.701 .738 .88 r
.74447 .44992 .7463 .45244 .75032 .45071 .74849 .44819 Metetra
.699 .738 .881 r
.74849 .44819 .75032 .45071 .75435 .449 .75252 .44649 Metetra
.698 .738 .882 r
.75252 .44649 .75435 .449 .75838 .44732 .75656 .44481 Metetra
.696 .738 .883 r
.75656 .44481 .75838 .44732 .76242 .44565 .76061 .44314 Metetra
.695 .738 .885 r
.76061 .44314 .76242 .44565 .76647 .444 .76466 .44149 Metetra
.694 .739 .886 r
.76466 .44149 .76647 .444 .77052 .44236 .76871 .43986 Metetra
.692 .739 .887 r
.76871 .43986 .77052 .44236 .77458 .44074 .77278 .43824 Metetra
.691 .739 .887 r
.77278 .43824 .77458 .44074 .77864 .43913 .77684 .43664 Metetra
.69 .739 .888 r
.77684 .43664 .77864 .43913 .78271 .43754 .78092 .43505 Metetra
.689 .739 .889 r
.78092 .43505 .78271 .43754 .78679 .43596 .785 .43347 Metetra
.688 .739 .89 r
.785 .43347 .78679 .43596 .79087 .43439 .78909 .4319 Metetra
.687 .739 .89 r
.78909 .4319 .79087 .43439 .79496 .43282 .79318 .43033 Metetra
.686 .739 .891 r
.79318 .43033 .79496 .43282 .79906 .43127 .79728 .42878 Metetra
.686 .739 .892 r
.79728 .42878 .79906 .43127 .80316 .42973 .80138 .42724 Metetra
.685 .739 .892 r
.80138 .42724 .80316 .42973 .80726 .42819 .80549 .4257 Metetra
.684 .739 .893 r
.80549 .4257 .80726 .42819 .81138 .42666 .80961 .42417 Metetra
.683 .739 .893 r
.80961 .42417 .81138 .42666 .81549 .42514 .81373 .42265 Metetra
.683 .739 .894 r
.81373 .42265 .81549 .42514 .81962 .42362 .81786 .42113 Metetra
.682 .739 .894 r
.81786 .42113 .81962 .42362 .82375 .42211 .822 .41962 Metetra
.682 .74 .895 r
.822 .41962 .82375 .42211 .82789 .42061 .82614 .41812 Metetra
.681 .74 .895 r
.82614 .41812 .82789 .42061 .83203 .41911 .83029 .41662 Metetra
.68 .74 .896 r
.83029 .41662 .83203 .41911 .83618 .41761 .83444 .41512 Metetra
.68 .74 .896 r
.83444 .41512 .83618 .41761 .84033 .41612 .8386 .41363 Metetra
.679 .74 .896 r
.8386 .41363 .84033 .41612 .84449 .41463 .84277 .41214 Metetra
.679 .74 .897 r
.84277 .41214 .84449 .41463 .84866 .41315 .84694 .41066 Metetra
.679 .74 .897 r
.84694 .41066 .84866 .41315 .85283 .41167 .85111 .40918 Metetra
.678 .74 .897 r
.85111 .40918 .85283 .41167 .85701 .4102 .8553 .4077 Metetra
.678 .74 .898 r
.8553 .4077 .85701 .4102 .8612 .40872 .85949 .40622 Metetra
.677 .74 .898 r
.85949 .40622 .8612 .40872 .86539 .40725 .86368 .40475 Metetra
.677 .74 .898 r
.86368 .40475 .86539 .40725 .86959 .40579 .86789 .40328 Metetra
.677 .74 .898 r
.86789 .40328 .86959 .40579 .87379 .40432 .87209 .40182 Metetra
.676 .74 .899 r
.87209 .40182 .87379 .40432 .878 .40286 .87631 .40035 Metetra
.676 .74 .899 r
.87631 .40035 .878 .40286 .88222 .4014 .88053 .39889 Metetra
.676 .74 .899 r
.88053 .39889 .88222 .4014 .88644 .39994 .88475 .39743 Metetra
.675 .74 .899 r
.88475 .39743 .88644 .39994 .89067 .39848 .88899 .39597 Metetra
.675 .74 .9 r
.88899 .39597 .89067 .39848 .8949 .39702 .89323 .39451 Metetra
.675 .74 .9 r
.89323 .39451 .8949 .39702 .89914 .39557 .89747 .39305 Metetra
.674 .74 .9 r
.89747 .39305 .89914 .39557 .90339 .39412 .90172 .3916 Metetra
.674 .74 .9 r
.90172 .3916 .90339 .39412 .90764 .39266 .90598 .39014 Metetra
.674 .74 .9 r
.90598 .39014 .90764 .39266 .9119 .39121 .91024 .38869 Metetra
.674 .74 .9 r
.91024 .38869 .9119 .39121 .91616 .38976 .91451 .38724 Metetra
.673 .74 .901 r
.91451 .38724 .91616 .38976 .92044 .38831 .91879 .38578 Metetra
.673 .74 .901 r
.91879 .38578 .92044 .38831 .92471 .38686 .92307 .38433 Metetra
.673 .74 .901 r
.92307 .38433 .92471 .38686 .929 .38542 .92736 .38288 Metetra
.673 .74 .901 r
.92736 .38288 .929 .38542 .93329 .38397 .93166 .38143 Metetra
.652 .733 .909 r
.35003 .5595 .35221 .56158 .35571 .56059 .35354 .55851 Metetra
.652 .733 .909 r
.35354 .55851 .35571 .56059 .35922 .55961 .35705 .55752 Metetra
.652 .733 .909 r
.35705 .55752 .35922 .55961 .36273 .55862 .36057 .55653 Metetra
.651 .733 .909 r
.36057 .55653 .36273 .55862 .36625 .55764 .36409 .55555 Metetra
.651 .733 .909 r
.36409 .55555 .36625 .55764 .36977 .55666 .36762 .55456 Metetra
.651 .732 .909 r
.36762 .55456 .36977 .55666 .3733 .55568 .37115 .55358 Metetra
.65 .732 .909 r
.37115 .55358 .3733 .55568 .37684 .5547 .37468 .5526 Metetra
.65 .732 .909 r
.37468 .5526 .37684 .5547 .38037 .55372 .37823 .55162 Metetra
.65 .732 .909 r
.37823 .55162 .38037 .55372 .38392 .55275 .38177 .55064 Metetra
.649 .732 .909 r
.38177 .55064 .38392 .55275 .38746 .55178 .38532 .54966 Metetra
.649 .731 .909 r
.38532 .54966 .38746 .55178 .39102 .5508 .38888 .54868 Metetra
.649 .731 .909 r
.38888 .54868 .39102 .5508 .39457 .54983 .39244 .54771 Metetra
.648 .731 .909 r
.39244 .54771 .39457 .54983 .39814 .54887 .396 .54674 Metetra
.648 .731 .909 r
.396 .54674 .39814 .54887 .4017 .5479 .39957 .54577 Metetra
.648 .73 .909 r
.39957 .54577 .4017 .5479 .40527 .54694 .40315 .54481 Metetra
.647 .73 .909 r
.40315 .54481 .40527 .54694 .40885 .54598 .40673 .54384 Metetra
.647 .73 .909 r
.40673 .54384 .40885 .54598 .41243 .54503 .41031 .54288 Metetra
.646 .729 .909 r
.41031 .54288 .41243 .54503 .41602 .54407 .4139 .54192 Metetra
.646 .729 .909 r
.4139 .54192 .41602 .54407 .41961 .54312 .41749 .54097 Metetra
.645 .729 .91 r
.41749 .54097 .41961 .54312 .42321 .54218 .42109 .54002 Metetra
.645 .728 .91 r
.42109 .54002 .42321 .54218 .42681 .54124 .4247 .53907 Metetra
.644 .728 .91 r
.4247 .53907 .42681 .54124 .43042 .5403 .42831 .53813 Metetra
.643 .728 .91 r
.42831 .53813 .43042 .5403 .43403 .53936 .43192 .53719 Metetra
.643 .727 .91 r
.43192 .53719 .43403 .53936 .43765 .53843 .43554 .53625 Metetra
.642 .727 .91 r
.43554 .53625 .43765 .53843 .44127 .53751 .43917 .53532 Metetra
.642 .726 .91 r
.43917 .53532 .44127 .53751 .44489 .53659 .4428 .5344 Metetra
.641 .726 .91 r
.4428 .5344 .44489 .53659 .44853 .53568 .44643 .53348 Metetra
.64 .725 .91 r
.44643 .53348 .44853 .53568 .45216 .53477 .45007 .53257 Metetra
.639 .725 .91 r
.45007 .53257 .45216 .53477 .45581 .53387 .45372 .53166 Metetra
.638 .724 .91 r
.45372 .53166 .45581 .53387 .45945 .53298 .45737 .53076 Metetra
.637 .723 .91 r
.45737 .53076 .45945 .53298 .46311 .53209 .46103 .52987 Metetra
.636 .723 .91 r
.46103 .52987 .46311 .53209 .46677 .53121 .46469 .52898 Metetra
.635 .722 .91 r
.46469 .52898 .46677 .53121 .47043 .53034 .46835 .52811 Metetra
.634 .721 .91 r
.46835 .52811 .47043 .53034 .4741 .52948 .47203 .52724 Metetra
.633 .721 .91 r
.47203 .52724 .4741 .52948 .47777 .52863 .4757 .52638 Metetra
.632 .72 .911 r
.4757 .52638 .47777 .52863 .48145 .52779 .47939 .52554 Metetra
.63 .719 .911 r
.47939 .52554 .48145 .52779 .48514 .52697 .48308 .5247 Metetra
.629 .718 .911 r
.48308 .5247 .48514 .52697 .48883 .52615 .48677 .52388 Metetra
.627 .717 .911 r
.48677 .52388 .48883 .52615 .49253 .52535 .49047 .52307 Metetra
.626 .716 .911 r
.49047 .52307 .49253 .52535 .49623 .52456 .49417 .52227 Metetra
.624 .715 .911 r
.49417 .52227 .49623 .52456 .49994 .52379 .49788 .52149 Metetra
.622 .713 .911 r
.49788 .52149 .49994 .52379 .50365 .52304 .5016 .52072 Metetra
.62 .712 .911 r
.5016 .52072 .50365 .52304 .50737 .5223 .50532 .51998 Metetra
.618 .71 .912 r
.50532 .51998 .50737 .5223 .5111 .52158 .50905 .51925 Metetra
.615 .709 .912 r
.50905 .51925 .5111 .52158 .51483 .52089 .51279 .51855 Metetra
.612 .707 .912 r
.51279 .51855 .51483 .52089 .51857 .52022 .51653 .51787 Metetra
.609 .705 .912 r
.51653 .51787 .51857 .52022 .52231 .51958 .52027 .51721 Metetra
.606 .703 .912 r
.52027 .51721 .52231 .51958 .52606 .51897 .52403 .51659 Metetra
.603 .7 .912 r
.52403 .51659 .52606 .51897 .52982 .51839 .52779 .51599 Metetra
.598 .698 .912 r
.52779 .51599 .52982 .51839 .53358 .51785 .53155 .51543 Metetra
.594 .695 .913 r
.53155 .51543 .53358 .51785 .53735 .51734 .53532 .51491 Metetra
.589 .691 .913 r
.53532 .51491 .53735 .51734 .54112 .51689 .5391 .51443 Metetra
.583 .688 .913 r
.5391 .51443 .54112 .51689 .54491 .51648 .54289 .51401 Metetra
.577 .683 .913 r
.54289 .51401 .54491 .51648 .5487 .51613 .54668 .51363 Metetra
.57 .678 .913 r
.54668 .51363 .5487 .51613 .5525 .51584 .55048 .51332 Metetra
.561 .673 .913 r
.55048 .51332 .5525 .51584 .5563 .51563 .55429 .51308 Metetra
.552 .666 .913 r
.55429 .51308 .5563 .51563 .56012 .5155 .55811 .51292 Metetra
.54 .659 .913 r
.55811 .51292 .56012 .5155 .56394 .51547 .56193 .51285 Metetra
.527 .65 .913 r
.56193 .51285 .56394 .51547 .56777 .51555 .56577 .51289 Metetra
.511 .639 .912 r
.56577 .51289 .56777 .51555 .57162 .51576 .56961 .51305 Metetra
.492 .626 .911 r
.56961 .51305 .57162 .51576 .57547 .51612 .57347 .51337 Metetra
.469 .611 .908 r
.57347 .51337 .57547 .51612 .57934 .51668 .57733 .51386 Metetra
.44 .591 .905 r
.57733 .51386 .57934 .51668 .58322 .51746 .58121 .51456 Metetra
.403 .565 .9 r
.58121 .51456 .58322 .51746 .58711 .51852 .58511 .51553 Metetra
.356 .532 .891 r
.58511 .51553 .58711 .51852 .59102 .51993 .58902 .51683 Metetra
.294 .487 .877 r
.58902 .51683 .59102 .51993 .59495 .52179 .59295 .51855 Metetra
.21 .425 .852 r
.59295 .51855 .59495 .52179 .59891 .52423 .5969 .52081 Metetra
.096 .338 .81 r
.5969 .52081 .59891 .52423 .6029 .52747 .60089 .52381 Metetra
0 .215 .737 r
.60089 .52381 .6029 .52747 .60694 .53184 .60491 .52783 Metetra
0 .044 .613 r
.60491 .52783 .60694 .53184 .61103 .53786 .60899 .53336 Metetra
0 0 .424 r
.60899 .53336 .61103 .53786 .61522 .54654 .61315 .54124 Metetra
.723 .383 0 r
.61315 .54124 .61522 .54654 .61957 .55991 .61745 .55319 Metetra
.877 .553 .044 r
.61745 .55319 .61957 .55991 .62424 .58313 .62203 .57333 Metetra
.979 .688 .388 r
.62203 .57333 .62424 .58313 .63142 .68672 .62937 .68463 Metetra
.645 .763 .934 r
.62937 .68463 .63142 .68672 .63555 .68559 .6335 .6835 Metetra
.966 .699 .477 r
.6335 .6835 .63555 .68559 .63626 .57966 .63402 .56983 Metetra
.862 .634 .592 r
.63402 .56983 .63626 .57966 .63944 .55405 .63732 .5473 Metetra
.858 .653 .625 r
.63732 .5473 .63944 .55405 .64292 .53827 .64086 .53295 Metetra
.85 .669 .657 r
.64086 .53295 .64292 .53827 .64655 .5272 .64451 .52266 Metetra
.84 .681 .686 r
.64451 .52266 .64655 .5272 .65025 .51877 .64824 .51472 Metetra
.829 .692 .712 r
.64824 .51472 .65025 .51877 .654 .512 .65201 .50829 Metetra
.818 .7 .735 r
.65201 .50829 .654 .512 .6578 .50635 .65582 .50288 Metetra
.807 .707 .754 r
.65582 .50288 .6578 .50635 .66162 .5015 .65965 .4982 Metetra
.797 .712 .771 r
.65965 .4982 .66162 .5015 .66546 .49723 .6635 .49407 Metetra
.788 .717 .785 r
.6635 .49407 .66546 .49723 .66932 .49341 .66737 .49036 Metetra
.779 .72 .798 r
.66737 .49036 .66932 .49341 .67319 .48994 .67125 .48697 Metetra
.771 .723 .809 r
.67125 .48697 .67319 .48994 .67708 .48675 .67515 .48385 Metetra
.763 .726 .818 r
.67515 .48385 .67708 .48675 .68098 .48379 .67905 .48094 Metetra
.756 .728 .826 r
.67905 .48094 .68098 .48379 .68489 .48101 .68297 .47821 Metetra
.75 .729 .833 r
.68297 .47821 .68489 .48101 .68881 .47838 .68689 .47562 Metetra
.744 .731 .839 r
.68689 .47562 .68881 .47838 .69273 .47589 .69083 .47317 Metetra
.739 .732 .844 r
.69083 .47317 .69273 .47589 .69667 .47351 .69477 .47082 Metetra
.734 .733 .849 r
.69477 .47082 .69667 .47351 .70061 .47122 .69872 .46856 Metetra
.73 .733 .853 r
.69872 .46856 .70061 .47122 .70457 .46902 .70268 .46638 Metetra
.726 .734 .857 r
.70268 .46638 .70457 .46902 .70852 .4669 .70664 .46427 Metetra
.723 .735 .861 r
.70664 .46427 .70852 .4669 .71249 .46483 .71061 .46222 Metetra
.719 .735 .864 r
.71061 .46222 .71249 .46483 .71647 .46282 .71459 .46023 Metetra
.716 .736 .867 r
.71459 .46023 .71647 .46282 .72045 .46087 .71858 .45829 Metetra
.713 .736 .869 r
.71858 .45829 .72045 .46087 .72443 .45895 .72257 .45638 Metetra
.711 .736 .871 r
.72257 .45638 .72443 .45895 .72843 .45708 .72657 .45452 Metetra
.708 .737 .873 r
.72657 .45452 .72843 .45708 .73243 .45524 .73057 .45269 Metetra
.706 .737 .875 r
.73057 .45269 .73243 .45524 .73643 .45344 .73458 .4509 Metetra
.704 .737 .877 r
.73458 .4509 .73643 .45344 .74045 .45166 .7386 .44913 Metetra
.702 .737 .879 r
.7386 .44913 .74045 .45166 .74447 .44992 .74262 .44739 Metetra
.7 .738 .88 r
.74262 .44739 .74447 .44992 .74849 .44819 .74665 .44567 Metetra
.699 .738 .881 r
.74665 .44567 .74849 .44819 .75252 .44649 .75069 .44397 Metetra
.697 .738 .883 r
.75069 .44397 .75252 .44649 .75656 .44481 .75473 .44229 Metetra
.696 .738 .884 r
.75473 .44229 .75656 .44481 .76061 .44314 .75878 .44063 Metetra
.694 .738 .885 r
.75878 .44063 .76061 .44314 .76466 .44149 .76284 .43899 Metetra
.693 .738 .886 r
.76284 .43899 .76466 .44149 .76871 .43986 .7669 .43736 Metetra
.692 .739 .887 r
.7669 .43736 .76871 .43986 .77278 .43824 .77097 .43574 Metetra
.691 .739 .888 r
.77097 .43574 .77278 .43824 .77684 .43664 .77504 .43414 Metetra
.69 .739 .888 r
.77504 .43414 .77684 .43664 .78092 .43505 .77912 .43255 Metetra
.689 .739 .889 r
.77912 .43255 .78092 .43505 .785 .43347 .7832 .43097 Metetra
.688 .739 .89 r
.7832 .43097 .785 .43347 .78909 .4319 .78729 .4294 Metetra
.687 .739 .891 r
.78729 .4294 .78909 .4319 .79318 .43033 .79139 .42784 Metetra
.686 .739 .891 r
.79139 .42784 .79318 .43033 .79728 .42878 .7955 .42629 Metetra
.685 .739 .892 r
.7955 .42629 .79728 .42878 .80138 .42724 .7996 .42474 Metetra
.684 .739 .892 r
.7996 .42474 .80138 .42724 .80549 .4257 .80372 .42321 Metetra
.684 .739 .893 r
.80372 .42321 .80549 .4257 .80961 .42417 .80784 .42168 Metetra
.683 .739 .894 r
.80784 .42168 .80961 .42417 .81373 .42265 .81197 .42016 Metetra
.682 .739 .894 r
.81197 .42016 .81373 .42265 .81786 .42113 .8161 .41864 Metetra
.682 .739 .894 r
.8161 .41864 .81786 .42113 .822 .41962 .82024 .41713 Metetra
.681 .739 .895 r
.82024 .41713 .822 .41962 .82614 .41812 .82439 .41562 Metetra
.681 .74 .895 r
.82439 .41562 .82614 .41812 .83029 .41662 .82854 .41412 Metetra
.68 .74 .896 r
.82854 .41412 .83029 .41662 .83444 .41512 .8327 .41262 Metetra
.68 .74 .896 r
.8327 .41262 .83444 .41512 .8386 .41363 .83686 .41113 Metetra
.679 .74 .896 r
.83686 .41113 .8386 .41363 .84277 .41214 .84103 .40964 Metetra
.679 .74 .897 r
.84103 .40964 .84277 .41214 .84694 .41066 .84521 .40816 Metetra
.678 .74 .897 r
.84521 .40816 .84694 .41066 .85111 .40918 .84939 .40667 Metetra
.678 .74 .897 r
.84939 .40667 .85111 .40918 .8553 .4077 .85358 .4052 Metetra
.678 .74 .898 r
.85358 .4052 .8553 .4077 .85949 .40622 .85777 .40372 Metetra
.677 .74 .898 r
.85777 .40372 .85949 .40622 .86368 .40475 .86197 .40225 Metetra
.677 .74 .898 r
.86197 .40225 .86368 .40475 .86789 .40328 .86618 .40077 Metetra
.676 .74 .898 r
.86618 .40077 .86789 .40328 .87209 .40182 .87039 .39931 Metetra
.676 .74 .899 r
.87039 .39931 .87209 .40182 .87631 .40035 .87461 .39784 Metetra
.676 .74 .899 r
.87461 .39784 .87631 .40035 .88053 .39889 .87884 .39637 Metetra
.675 .74 .899 r
.87884 .39637 .88053 .39889 .88475 .39743 .88307 .39491 Metetra
.675 .74 .899 r
.88307 .39491 .88475 .39743 .88899 .39597 .8873 .39345 Metetra
.675 .74 .9 r
.8873 .39345 .88899 .39597 .89323 .39451 .89155 .39199 Metetra
.675 .74 .9 r
.89155 .39199 .89323 .39451 .89747 .39305 .8958 .39053 Metetra
.674 .74 .9 r
.8958 .39053 .89747 .39305 .90172 .3916 .90005 .38907 Metetra
.674 .74 .9 r
.90005 .38907 .90172 .3916 .90598 .39014 .90432 .38762 Metetra
.674 .74 .9 r
.90432 .38762 .90598 .39014 .91024 .38869 .90858 .38616 Metetra
.674 .74 .901 r
.90858 .38616 .91024 .38869 .91451 .38724 .91286 .3847 Metetra
.673 .74 .901 r
.91286 .3847 .91451 .38724 .91879 .38578 .91714 .38325 Metetra
.673 .74 .901 r
.91714 .38325 .91879 .38578 .92307 .38433 .92143 .3818 Metetra
.673 .74 .901 r
.92143 .3818 .92307 .38433 .92736 .38288 .92572 .38034 Metetra
.673 .74 .901 r
.92572 .38034 .92736 .38288 .93166 .38143 .93002 .37889 Metetra
.652 .733 .909 r
.34786 .55742 .35003 .5595 .35354 .55851 .35137 .55643 Metetra
.652 .733 .909 r
.35137 .55643 .35354 .55851 .35705 .55752 .35488 .55543 Metetra
.652 .733 .909 r
.35488 .55543 .35705 .55752 .36057 .55653 .3584 .55444 Metetra
.651 .733 .909 r
.3584 .55444 .36057 .55653 .36409 .55555 .36193 .55345 Metetra
.651 .733 .909 r
.36193 .55345 .36409 .55555 .36762 .55456 .36546 .55246 Metetra
.651 .733 .909 r
.36546 .55246 .36762 .55456 .37115 .55358 .36899 .55148 Metetra
.651 .732 .909 r
.36899 .55148 .37115 .55358 .37468 .5526 .37253 .55049 Metetra
.65 .732 .909 r
.37253 .55049 .37468 .5526 .37823 .55162 .37607 .5495 Metetra
.65 .732 .909 r
.37607 .5495 .37823 .55162 .38177 .55064 .37962 .54852 Metetra
.65 .732 .909 r
.37962 .54852 .38177 .55064 .38532 .54966 .38317 .54754 Metetra
.649 .731 .909 r
.38317 .54754 .38532 .54966 .38888 .54868 .38673 .54656 Metetra
.649 .731 .909 r
.38673 .54656 .38888 .54868 .39244 .54771 .39029 .54558 Metetra
.649 .731 .909 r
.39029 .54558 .39244 .54771 .396 .54674 .39386 .54461 Metetra
.648 .731 .909 r
.39386 .54461 .396 .54674 .39957 .54577 .39743 .54363 Metetra
.648 .73 .909 r
.39743 .54363 .39957 .54577 .40315 .54481 .40101 .54266 Metetra
.647 .73 .909 r
.40101 .54266 .40315 .54481 .40673 .54384 .40459 .5417 Metetra
.647 .73 .909 r
.40459 .5417 .40673 .54384 .41031 .54288 .40818 .54073 Metetra
.646 .729 .909 r
.40818 .54073 .41031 .54288 .4139 .54192 .41177 .53977 Metetra
.646 .729 .909 r
.41177 .53977 .4139 .54192 .41749 .54097 .41537 .53881 Metetra
.645 .729 .909 r
.41537 .53881 .41749 .54097 .42109 .54002 .41897 .53785 Metetra
.645 .728 .909 r
.41897 .53785 .42109 .54002 .4247 .53907 .42258 .5369 Metetra
.644 .728 .91 r
.42258 .5369 .4247 .53907 .42831 .53813 .42619 .53595 Metetra
.644 .728 .91 r
.42619 .53595 .42831 .53813 .43192 .53719 .42981 .53501 Metetra
.643 .727 .91 r
.42981 .53501 .43192 .53719 .43554 .53625 .43343 .53407 Metetra
.643 .727 .91 r
.43343 .53407 .43554 .53625 .43917 .53532 .43706 .53313 Metetra
.642 .726 .91 r
.43706 .53313 .43917 .53532 .4428 .5344 .4407 .5322 Metetra
.641 .726 .91 r
.4407 .5322 .4428 .5344 .44643 .53348 .44433 .53128 Metetra
.64 .725 .91 r
.44433 .53128 .44643 .53348 .45007 .53257 .44798 .53036 Metetra
.64 .725 .91 r
.44798 .53036 .45007 .53257 .45372 .53166 .45163 .52945 Metetra
.639 .724 .91 r
.45163 .52945 .45372 .53166 .45737 .53076 .45528 .52854 Metetra
.638 .724 .91 r
.45528 .52854 .45737 .53076 .46103 .52987 .45894 .52764 Metetra
.637 .723 .91 r
.45894 .52764 .46103 .52987 .46469 .52898 .4626 .52675 Metetra
.636 .722 .91 r
.4626 .52675 .46469 .52898 .46835 .52811 .46627 .52587 Metetra
.635 .722 .91 r
.46627 .52587 .46835 .52811 .47203 .52724 .46995 .52499 Metetra
.634 .721 .91 r
.46995 .52499 .47203 .52724 .4757 .52638 .47363 .52413 Metetra
.632 .72 .91 r
.47363 .52413 .4757 .52638 .47939 .52554 .47731 .52327 Metetra
.631 .719 .911 r
.47731 .52327 .47939 .52554 .48308 .5247 .48101 .52243 Metetra
.63 .718 .911 r
.48101 .52243 .48308 .5247 .48677 .52388 .4847 .5216 Metetra
.628 .717 .911 r
.4847 .5216 .48677 .52388 .49047 .52307 .4884 .52078 Metetra
.627 .716 .911 r
.4884 .52078 .49047 .52307 .49417 .52227 .49211 .51997 Metetra
.625 .715 .911 r
.49211 .51997 .49417 .52227 .49788 .52149 .49583 .51918 Metetra
.623 .714 .911 r
.49583 .51918 .49788 .52149 .5016 .52072 .49955 .51841 Metetra
.621 .712 .911 r
.49955 .51841 .5016 .52072 .50532 .51998 .50327 .51765 Metetra
.619 .711 .911 r
.50327 .51765 .50532 .51998 .50905 .51925 .507 .51692 Metetra
.616 .709 .911 r
.507 .51692 .50905 .51925 .51279 .51855 .51074 .5162 Metetra
.614 .707 .912 r
.51074 .5162 .51279 .51855 .51653 .51787 .51448 .51551 Metetra
.611 .705 .912 r
.51448 .51551 .51653 .51787 .52027 .51721 .51823 .51484 Metetra
.607 .703 .912 r
.51823 .51484 .52027 .51721 .52403 .51659 .52199 .5142 Metetra
.604 .701 .912 r
.52199 .5142 .52403 .51659 .52779 .51599 .52575 .51359 Metetra
.6 .698 .912 r
.52575 .51359 .52779 .51599 .53155 .51543 .52952 .51301 Metetra
.596 .695 .912 r
.52952 .51301 .53155 .51543 .53532 .51491 .53329 .51248 Metetra
.591 .692 .912 r
.53329 .51248 .53532 .51491 .5391 .51443 .53707 .51198 Metetra
.585 .689 .913 r
.53707 .51198 .5391 .51443 .54289 .51401 .54086 .51153 Metetra
.579 .684 .913 r
.54086 .51153 .54289 .51401 .54668 .51363 .54466 .51113 Metetra
.572 .68 .913 r
.54466 .51113 .54668 .51363 .55048 .51332 .54846 .5108 Metetra
.564 .674 .913 r
.54846 .5108 .55048 .51332 .55429 .51308 .55227 .51053 Metetra
.555 .668 .913 r
.55227 .51053 .55429 .51308 .55811 .51292 .55609 .51033 Metetra
.544 .661 .913 r
.55609 .51033 .55811 .51292 .56193 .51285 .55992 .51023 Metetra
.532 .653 .912 r
.55992 .51023 .56193 .51285 .56577 .51289 .56376 .51023 Metetra
.517 .642 .911 r
.56376 .51023 .56577 .51289 .56961 .51305 .5676 .51035 Metetra
.499 .63 .91 r
.5676 .51035 .56961 .51305 .57347 .51337 .57146 .51061 Metetra
.477 .615 .908 r
.57146 .51061 .57347 .51337 .57733 .51386 .57532 .51104 Metetra
.45 .597 .906 r
.57532 .51104 .57733 .51386 .58121 .51456 .5792 .51167 Metetra
.417 .573 .901 r
.5792 .51167 .58121 .51456 .58511 .51553 .5831 .51255 Metetra
.373 .542 .893 r
.5831 .51255 .58511 .51553 .58902 .51683 .58701 .51374 Metetra
.317 .501 .881 r
.58701 .51374 .58902 .51683 .59295 .51855 .59094 .51532 Metetra
.241 .445 .86 r
.59094 .51532 .59295 .51855 .5969 .52081 .59489 .51741 Metetra
.137 .367 .824 r
.59489 .51741 .5969 .52081 .60089 .52381 .59887 .52018 Metetra
0 .255 .762 r
.59887 .52018 .60089 .52381 .60491 .52783 .60288 .52388 Metetra
0 .099 .655 r
.60288 .52388 .60491 .52783 .60899 .53336 .60695 .52894 Metetra
0 0 .486 r
.60695 .52894 .60899 .53336 .61315 .54124 .61109 .53609 Metetra
.659 .324 0 r
.61109 .53609 .61315 .54124 .61745 .55319 .61535 .54676 Metetra
.838 .512 0 r
.61535 .54676 .61745 .55319 .62203 .57333 .61983 .56425 Metetra
.978 .687 .396 r
.61983 .56425 .62203 .57333 .62937 .68463 .62731 .68254 Metetra
.645 .763 .934 r
.62731 .68254 .62937 .68463 .6335 .6835 .63145 .68141 Metetra
.966 .699 .475 r
.63145 .68141 .6335 .6835 .63402 .56983 .63182 .56074 Metetra
.858 .636 .6 r
.63182 .56074 .63402 .56983 .63732 .5473 .63521 .54085 Metetra
.853 .654 .633 r
.63521 .54085 .63732 .5473 .64086 .53295 .6388 .52776 Metetra
.845 .67 .664 r
.6388 .52776 .64086 .53295 .64451 .52266 .64248 .5182 Metetra
.835 .682 .693 r
.64248 .5182 .64451 .52266 .64824 .51472 .64623 .51073 Metetra
.825 .692 .718 r
.64623 .51073 .64824 .51472 .65201 .50829 .65002 .50461 Metetra
.814 .7 .74 r
.65002 .50461 .65201 .50829 .65582 .50288 .65384 .49943 Metetra
.803 .707 .759 r
.65384 .49943 .65582 .50288 .65965 .4982 .65768 .49492 Metetra
.794 .712 .775 r
.65768 .49492 .65965 .4982 .6635 .49407 .66154 .49092 Metetra
.784 .717 .789 r
.66154 .49092 .6635 .49407 .66737 .49036 .66542 .48731 Metetra
.776 .72 .801 r
.66542 .48731 .66737 .49036 .67125 .48697 .66931 .484 Metetra
.768 .723 .811 r
.66931 .484 .67125 .48697 .67515 .48385 .67321 .48095 Metetra
.761 .725 .82 r
.67321 .48095 .67515 .48385 .67905 .48094 .67712 .47809 Metetra
.754 .727 .828 r
.67712 .47809 .67905 .48094 .68297 .47821 .68105 .47541 Metetra
.748 .729 .835 r
.68105 .47541 .68297 .47821 .68689 .47562 .68498 .47286 Metetra
.742 .73 .84 r
.68498 .47286 .68689 .47562 .69083 .47317 .68892 .47044 Metetra
.737 .731 .846 r
.68892 .47044 .69083 .47317 .69477 .47082 .69286 .46812 Metetra
.733 .732 .85 r
.69286 .46812 .69477 .47082 .69872 .46856 .69682 .46588 Metetra
.729 .733 .855 r
.69682 .46588 .69872 .46856 .70268 .46638 .70078 .46373 Metetra
.725 .734 .858 r
.70078 .46373 .70268 .46638 .70664 .46427 .70475 .46164 Metetra
.721 .734 .862 r
.70475 .46164 .70664 .46427 .71061 .46222 .70873 .45961 Metetra
.718 .735 .864 r
.70873 .45961 .71061 .46222 .71459 .46023 .71271 .45763 Metetra
.715 .735 .867 r
.71271 .45763 .71459 .46023 .71858 .45829 .7167 .4557 Metetra
.712 .736 .87 r
.7167 .4557 .71858 .45829 .72257 .45638 .7207 .45381 Metetra
.71 .736 .872 r
.7207 .45381 .72257 .45638 .72657 .45452 .7247 .45196 Metetra
.707 .737 .874 r
.7247 .45196 .72657 .45452 .73057 .45269 .72871 .45014 Metetra
.705 .737 .876 r
.72871 .45014 .73057 .45269 .73458 .4509 .73273 .44835 Metetra
.703 .737 .877 r
.73273 .44835 .73458 .4509 .7386 .44913 .73675 .44659 Metetra
.701 .737 .879 r
.73675 .44659 .7386 .44913 .74262 .44739 .74078 .44485 Metetra
.7 .738 .88 r
.74078 .44485 .74262 .44739 .74665 .44567 .74481 .44314 Metetra
.698 .738 .882 r
.74481 .44314 .74665 .44567 .75069 .44397 .74885 .44144 Metetra
.697 .738 .883 r
.74885 .44144 .75069 .44397 .75473 .44229 .7529 .43977 Metetra
.695 .738 .884 r
.7529 .43977 .75473 .44229 .75878 .44063 .75696 .43811 Metetra
.694 .738 .885 r
.75696 .43811 .75878 .44063 .76284 .43899 .76101 .43647 Metetra
.693 .738 .886 r
.76101 .43647 .76284 .43899 .7669 .43736 .76508 .43485 Metetra
.691 .738 .887 r
.76508 .43485 .7669 .43736 .77097 .43574 .76915 .43323 Metetra
.69 .739 .888 r
.76915 .43323 .77097 .43574 .77504 .43414 .77323 .43163 Metetra
.689 .739 .889 r
.77323 .43163 .77504 .43414 .77912 .43255 .77731 .43004 Metetra
.688 .739 .889 r
.77731 .43004 .77912 .43255 .7832 .43097 .7814 .42846 Metetra
.687 .739 .89 r
.7814 .42846 .7832 .43097 .78729 .4294 .7855 .4269 Metetra
.686 .739 .891 r
.7855 .4269 .78729 .4294 .79139 .42784 .7896 .42534 Metetra
.686 .739 .891 r
.7896 .42534 .79139 .42784 .7955 .42629 .79371 .42379 Metetra
.685 .739 .892 r
.79371 .42379 .7955 .42629 .7996 .42474 .79782 .42224 Metetra
.684 .739 .893 r
.79782 .42224 .7996 .42474 .80372 .42321 .80194 .42071 Metetra
.683 .739 .893 r
.80194 .42071 .80372 .42321 .80784 .42168 .80607 .41918 Metetra
.683 .739 .894 r
.80607 .41918 .80784 .42168 .81197 .42016 .8102 .41765 Metetra
.682 .739 .894 r
.8102 .41765 .81197 .42016 .8161 .41864 .81434 .41614 Metetra
.682 .739 .895 r
.81434 .41614 .8161 .41864 .82024 .41713 .81848 .41463 Metetra
.681 .739 .895 r
.81848 .41463 .82024 .41713 .82439 .41562 .82263 .41312 Metetra
.68 .739 .895 r
.82263 .41312 .82439 .41562 .82854 .41412 .82679 .41162 Metetra
.68 .74 .896 r
.82679 .41162 .82854 .41412 .8327 .41262 .83095 .41012 Metetra
.679 .74 .896 r
.83095 .41012 .8327 .41262 .83686 .41113 .83512 .40863 Metetra
.679 .74 .896 r
.83512 .40863 .83686 .41113 .84103 .40964 .83929 .40714 Metetra
.679 .74 .897 r
.83929 .40714 .84103 .40964 .84521 .40816 .84347 .40565 Metetra
.678 .74 .897 r
.84347 .40565 .84521 .40816 .84939 .40667 .84766 .40417 Metetra
.678 .74 .897 r
.84766 .40417 .84939 .40667 .85358 .4052 .85185 .40268 Metetra
.677 .74 .898 r
.85185 .40268 .85358 .4052 .85777 .40372 .85605 .40121 Metetra
.677 .74 .898 r
.85605 .40121 .85777 .40372 .86197 .40225 .86026 .39973 Metetra
.677 .74 .898 r
.86026 .39973 .86197 .40225 .86618 .40077 .86447 .39826 Metetra
.676 .74 .899 r
.86447 .39826 .86618 .40077 .87039 .39931 .86869 .39679 Metetra
.676 .74 .899 r
.86869 .39679 .87039 .39931 .87461 .39784 .87291 .39532 Metetra
.676 .74 .899 r
.87291 .39532 .87461 .39784 .87884 .39637 .87714 .39385 Metetra
.675 .74 .899 r
.87714 .39385 .87884 .39637 .88307 .39491 .88137 .39239 Metetra
.675 .74 .899 r
.88137 .39239 .88307 .39491 .8873 .39345 .88562 .39092 Metetra
.675 .74 .9 r
.88562 .39092 .8873 .39345 .89155 .39199 .88986 .38946 Metetra
.674 .74 .9 r
.88986 .38946 .89155 .39199 .8958 .39053 .89412 .388 Metetra
.674 .74 .9 r
.89412 .388 .8958 .39053 .90005 .38907 .89838 .38654 Metetra
.674 .74 .9 r
.89838 .38654 .90005 .38907 .90432 .38762 .90265 .38508 Metetra
.674 .74 .9 r
.90265 .38508 .90432 .38762 .90858 .38616 .90692 .38362 Metetra
.673 .74 .901 r
.90692 .38362 .90858 .38616 .91286 .3847 .9112 .38217 Metetra
.673 .74 .901 r
.9112 .38217 .91286 .3847 .91714 .38325 .91548 .38071 Metetra
.673 .74 .901 r
.91548 .38071 .91714 .38325 .92143 .3818 .91978 .37925 Metetra
.673 .74 .901 r
.91978 .37925 .92143 .3818 .92572 .38034 .92407 .3778 Metetra
.673 .74 .901 r
.92407 .3778 .92572 .38034 .93002 .37889 .92838 .37634 Metetra
.652 .733 .909 r
.34568 .55533 .34786 .55742 .35137 .55643 .34919 .55434 Metetra
.652 .733 .909 r
.34919 .55434 .35137 .55643 .35488 .55543 .35271 .55334 Metetra
.652 .733 .909 r
.35271 .55334 .35488 .55543 .3584 .55444 .35623 .55235 Metetra
.652 .733 .909 r
.35623 .55235 .3584 .55444 .36193 .55345 .35976 .55135 Metetra
.651 .733 .909 r
.35976 .55135 .36193 .55345 .36546 .55246 .36329 .55036 Metetra
.651 .733 .909 r
.36329 .55036 .36546 .55246 .36899 .55148 .36682 .54937 Metetra
.651 .732 .909 r
.36682 .54937 .36899 .55148 .37253 .55049 .37037 .54838 Metetra
.65 .732 .909 r
.37037 .54838 .37253 .55049 .37607 .5495 .37391 .54739 Metetra
.65 .732 .909 r
.37391 .54739 .37607 .5495 .37962 .54852 .37746 .5464 Metetra
.65 .732 .909 r
.37746 .5464 .37962 .54852 .38317 .54754 .38102 .54542 Metetra
.649 .731 .909 r
.38102 .54542 .38317 .54754 .38673 .54656 .38458 .54443 Metetra
.649 .731 .909 r
.38458 .54443 .38673 .54656 .39029 .54558 .38815 .54345 Metetra
.649 .731 .909 r
.38815 .54345 .39029 .54558 .39386 .54461 .39172 .54247 Metetra
.648 .731 .909 r
.39172 .54247 .39386 .54461 .39743 .54363 .39529 .54149 Metetra
.648 .73 .909 r
.39529 .54149 .39743 .54363 .40101 .54266 .39887 .54052 Metetra
.648 .73 .909 r
.39887 .54052 .40101 .54266 .40459 .5417 .40246 .53954 Metetra
.647 .73 .909 r
.40246 .53954 .40459 .5417 .40818 .54073 .40605 .53857 Metetra
.647 .73 .909 r
.40605 .53857 .40818 .54073 .41177 .53977 .40964 .53761 Metetra
.646 .729 .909 r
.40964 .53761 .41177 .53977 .41537 .53881 .41324 .53664 Metetra
.646 .729 .909 r
.41324 .53664 .41537 .53881 .41897 .53785 .41685 .53568 Metetra
.645 .729 .909 r
.41685 .53568 .41897 .53785 .42258 .5369 .42046 .53473 Metetra
.645 .728 .909 r
.42046 .53473 .42258 .5369 .42619 .53595 .42408 .53377 Metetra
.644 .728 .91 r
.42408 .53377 .42619 .53595 .42981 .53501 .4277 .53282 Metetra
.643 .727 .91 r
.4277 .53282 .42981 .53501 .43343 .53407 .43132 .53188 Metetra
.643 .727 .91 r
.43132 .53188 .43343 .53407 .43706 .53313 .43495 .53094 Metetra
.642 .726 .91 r
.43495 .53094 .43706 .53313 .4407 .5322 .43859 .53 Metetra
.641 .726 .91 r
.43859 .53 .4407 .5322 .44433 .53128 .44223 .52907 Metetra
.641 .725 .91 r
.44223 .52907 .44433 .53128 .44798 .53036 .44588 .52815 Metetra
.64 .725 .91 r
.44588 .52815 .44798 .53036 .45163 .52945 .44953 .52723 Metetra
.639 .724 .91 r
.44953 .52723 .45163 .52945 .45528 .52854 .45318 .52632 Metetra
.638 .724 .91 r
.45318 .52632 .45528 .52854 .45894 .52764 .45685 .52541 Metetra
.637 .723 .91 r
.45685 .52541 .45894 .52764 .4626 .52675 .46051 .52451 Metetra
.636 .722 .91 r
.46051 .52451 .4626 .52675 .46627 .52587 .46419 .52362 Metetra
.635 .722 .91 r
.46419 .52362 .46627 .52587 .46995 .52499 .46786 .52274 Metetra
.634 .721 .91 r
.46786 .52274 .46995 .52499 .47363 .52413 .47155 .52187 Metetra
.633 .72 .91 r
.47155 .52187 .47363 .52413 .47731 .52327 .47524 .52101 Metetra
.632 .719 .91 r
.47524 .52101 .47731 .52327 .48101 .52243 .47893 .52016 Metetra
.63 .718 .91 r
.47893 .52016 .48101 .52243 .4847 .5216 .48263 .51932 Metetra
.629 .717 .911 r
.48263 .51932 .4847 .5216 .4884 .52078 .48634 .51849 Metetra
.627 .716 .911 r
.48634 .51849 .4884 .52078 .49211 .51997 .49005 .51767 Metetra
.625 .715 .911 r
.49005 .51767 .49211 .51997 .49583 .51918 .49376 .51687 Metetra
.624 .714 .911 r
.49376 .51687 .49583 .51918 .49955 .51841 .49749 .51609 Metetra
.622 .713 .911 r
.49749 .51609 .49955 .51841 .50327 .51765 .50121 .51532 Metetra
.62 .711 .911 r
.50121 .51532 .50327 .51765 .507 .51692 .50495 .51458 Metetra
.617 .71 .911 r
.50495 .51458 .507 .51692 .51074 .5162 .50869 .51385 Metetra
.615 .708 .911 r
.50869 .51385 .51074 .5162 .51448 .51551 .51243 .51314 Metetra
.612 .706 .911 r
.51243 .51314 .51448 .51551 .51823 .51484 .51619 .51246 Metetra
.609 .704 .912 r
.51619 .51246 .51823 .51484 .52199 .5142 .51994 .51181 Metetra
.605 .702 .912 r
.51994 .51181 .52199 .5142 .52575 .51359 .52371 .51118 Metetra
.602 .699 .912 r
.52371 .51118 .52575 .51359 .52952 .51301 .52748 .51059 Metetra
.597 .696 .912 r
.52748 .51059 .52952 .51301 .53329 .51248 .53126 .51004 Metetra
.593 .693 .912 r
.53126 .51004 .53329 .51248 .53707 .51198 .53504 .50952 Metetra
.588 .69 .912 r
.53504 .50952 .53707 .51198 .54086 .51153 .53883 .50905 Metetra
.582 .686 .912 r
.53883 .50905 .54086 .51153 .54466 .51113 .54263 .50863 Metetra
.575 .681 .912 r
.54263 .50863 .54466 .51113 .54846 .5108 .54644 .50827 Metetra
.567 .676 .912 r
.54644 .50827 .54846 .5108 .55227 .51053 .55025 .50797 Metetra
.559 .67 .912 r
.55025 .50797 .55227 .51053 .55609 .51033 .55407 .50775 Metetra
.549 .663 .912 r
.55407 .50775 .55609 .51033 .55992 .51023 .5579 .50761 Metetra
.537 .655 .912 r
.5579 .50761 .55992 .51023 .56376 .51023 .56174 .50757 Metetra
.523 .646 .911 r
.56174 .50757 .56376 .51023 .5676 .51035 .56559 .50765 Metetra
.506 .634 .91 r
.56559 .50765 .5676 .51035 .57146 .51061 .56944 .50786 Metetra
.485 .62 .908 r
.56944 .50786 .57146 .51061 .57532 .51104 .57331 .50823 Metetra
.46 .603 .906 r
.57331 .50823 .57532 .51104 .5792 .51167 .57719 .50879 Metetra
.429 .581 .902 r
.57719 .50879 .5792 .51167 .5831 .51255 .58109 .50958 Metetra
.389 .552 .895 r
.58109 .50958 .5831 .51255 .58701 .51374 .585 .51067 Metetra
.337 .515 .884 r
.585 .51067 .58701 .51374 .59094 .51532 .58892 .51212 Metetra
.268 .464 .867 r
.58892 .51212 .59094 .51532 .59489 .51741 .59287 .51404 Metetra
.175 .394 .836 r
.59287 .51404 .59489 .51741 .59887 .52018 .59685 .51658 Metetra
.046 .293 .784 r
.59685 .51658 .59887 .52018 .60288 .52388 .60085 .51998 Metetra
0 .152 .693 r
.60085 .51998 .60288 .52388 .60695 .52894 .60491 .5246 Metetra
0 0 .545 r
.60491 .5246 .60695 .52894 .61109 .53609 .60903 .53108 Metetra
0 0 .333 r
.60903 .53108 .61109 .53609 .61535 .54676 .61325 .54061 Metetra
.79 .463 0 r
.61325 .54061 .61535 .54676 .61983 .56425 .61766 .55584 Metetra
.976 .687 .402 r
.61766 .55584 .61983 .56425 .62731 .68254 .62525 .68045 Metetra
.645 .763 .934 r
.62525 .68045 .62731 .68254 .63145 .68141 .62939 .67931 Metetra
.966 .698 .474 r
.62939 .67931 .63145 .68141 .63182 .56074 .62964 .55231 Metetra
.854 .638 .609 r
.62964 .55231 .63182 .56074 .63521 .54085 .63311 .53467 Metetra
.849 .656 .641 r
.63311 .53467 .63521 .54085 .6388 .52776 .63674 .52272 Metetra
.841 .671 .672 r
.63674 .52272 .6388 .52776 .64248 .5182 .64045 .51383 Metetra
.831 .683 .699 r
.64045 .51383 .64248 .5182 .64623 .51073 .64422 .50678 Metetra
.82 .693 .724 r
.64422 .50678 .64623 .51073 .65002 .50461 .64803 .50096 Metetra
.81 .701 .745 r
.64803 .50096 .65002 .50461 .65384 .49943 .65186 .496 Metetra
.8 .707 .763 r
.65186 .496 .65384 .49943 .65768 .49492 .65571 .49165 Metetra
.79 .712 .779 r
.65571 .49165 .65768 .49492 .66154 .49092 .65958 .48777 Metetra
.781 .717 .792 r
.65958 .48777 .66154 .49092 .66542 .48731 .66347 .48426 Metetra
.773 .72 .803 r
.66347 .48426 .66542 .48731 .66931 .484 .66736 .48104 Metetra
.765 .723 .813 r
.66736 .48104 .66931 .484 .67321 .48095 .67127 .47805 Metetra
.758 .725 .822 r
.67127 .47805 .67321 .48095 .67712 .47809 .67519 .47525 Metetra
.752 .727 .83 r
.67519 .47525 .67712 .47809 .68105 .47541 .67912 .47261 Metetra
.746 .729 .836 r
.67912 .47261 .68105 .47541 .68498 .47286 .68306 .4701 Metetra
.74 .73 .842 r
.68306 .4701 .68498 .47286 .68892 .47044 .687 .46771 Metetra
.736 .731 .847 r
.687 .46771 .68892 .47044 .69286 .46812 .69095 .46542 Metetra
.731 .732 .852 r
.69095 .46542 .69286 .46812 .69682 .46588 .69492 .46321 Metetra
.727 .733 .856 r
.69492 .46321 .69682 .46588 .70078 .46373 .69888 .46108 Metetra
.723 .734 .859 r
.69888 .46108 .70078 .46373 .70475 .46164 .70286 .459 Metetra
.72 .734 .862 r
.70286 .459 .70475 .46164 .70873 .45961 .70684 .45699 Metetra
.717 .735 .865 r
.70684 .45699 .70873 .45961 .71271 .45763 .71083 .45503 Metetra
.714 .735 .868 r
.71083 .45503 .71271 .45763 .7167 .4557 .71482 .45311 Metetra
.711 .736 .87 r
.71482 .45311 .7167 .4557 .7207 .45381 .71882 .45123 Metetra
.709 .736 .872 r
.71882 .45123 .7207 .45381 .7247 .45196 .72283 .44939 Metetra
.707 .736 .874 r
.72283 .44939 .7247 .45196 .72871 .45014 .72685 .44758 Metetra
.704 .737 .876 r
.72685 .44758 .72871 .45014 .73273 .44835 .73087 .44579 Metetra
.702 .737 .878 r
.73087 .44579 .73273 .44835 .73675 .44659 .7349 .44404 Metetra
.701 .737 .879 r
.7349 .44404 .73675 .44659 .74078 .44485 .73893 .44231 Metetra
.699 .737 .881 r
.73893 .44231 .74078 .44485 .74481 .44314 .74297 .4406 Metetra
.697 .738 .882 r
.74297 .4406 .74481 .44314 .74885 .44144 .74701 .43891 Metetra
.696 .738 .883 r
.74701 .43891 .74885 .44144 .7529 .43977 .75107 .43724 Metetra
.695 .738 .884 r
.75107 .43724 .7529 .43977 .75696 .43811 .75512 .43559 Metetra
.693 .738 .885 r
.75512 .43559 .75696 .43811 .76101 .43647 .75919 .43395 Metetra
.692 .738 .886 r
.75919 .43395 .76101 .43647 .76508 .43485 .76326 .43233 Metetra
.691 .738 .887 r
.76326 .43233 .76508 .43485 .76915 .43323 .76733 .43072 Metetra
.69 .738 .888 r
.76733 .43072 .76915 .43323 .77323 .43163 .77142 .42912 Metetra
.689 .739 .889 r
.77142 .42912 .77323 .43163 .77731 .43004 .7755 .42753 Metetra
.688 .739 .89 r
.7755 .42753 .77731 .43004 .7814 .42846 .7796 .42596 Metetra
.687 .739 .89 r
.7796 .42596 .7814 .42846 .7855 .4269 .7837 .42439 Metetra
.686 .739 .891 r
.7837 .42439 .7855 .4269 .7896 .42534 .7878 .42283 Metetra
.685 .739 .892 r
.7878 .42283 .7896 .42534 .79371 .42379 .79192 .42128 Metetra
.685 .739 .892 r
.79192 .42128 .79371 .42379 .79782 .42224 .79603 .41974 Metetra
.684 .739 .893 r
.79603 .41974 .79782 .42224 .80194 .42071 .80016 .4182 Metetra
.683 .739 .893 r
.80016 .4182 .80194 .42071 .80607 .41918 .80429 .41667 Metetra
.683 .739 .894 r
.80429 .41667 .80607 .41918 .8102 .41765 .80843 .41515 Metetra
.682 .739 .894 r
.80843 .41515 .8102 .41765 .81434 .41614 .81257 .41363 Metetra
.681 .739 .895 r
.81257 .41363 .81434 .41614 .81848 .41463 .81672 .41212 Metetra
.681 .739 .895 r
.81672 .41212 .81848 .41463 .82263 .41312 .82087 .41061 Metetra
.68 .739 .895 r
.82087 .41061 .82263 .41312 .82679 .41162 .82503 .40911 Metetra
.68 .739 .896 r
.82503 .40911 .82679 .41162 .83095 .41012 .8292 .40761 Metetra
.679 .739 .896 r
.8292 .40761 .83095 .41012 .83512 .40863 .83337 .40611 Metetra
.679 .74 .897 r
.83337 .40611 .83512 .40863 .83929 .40714 .83755 .40462 Metetra
.678 .74 .897 r
.83755 .40462 .83929 .40714 .84347 .40565 .84174 .40313 Metetra
.678 .74 .897 r
.84174 .40313 .84347 .40565 .84766 .40417 .84593 .40165 Metetra
.678 .74 .898 r
.84593 .40165 .84766 .40417 .85185 .40268 .85012 .40017 Metetra
.677 .74 .898 r
.85012 .40017 .85185 .40268 .85605 .40121 .85433 .39869 Metetra
.677 .74 .898 r
.85433 .39869 .85605 .40121 .86026 .39973 .85854 .39721 Metetra
.676 .74 .898 r
.85854 .39721 .86026 .39973 .86447 .39826 .86275 .39574 Metetra
.676 .74 .899 r
.86275 .39574 .86447 .39826 .86869 .39679 .86698 .39427 Metetra
.676 .74 .899 r
.86698 .39427 .86869 .39679 .87291 .39532 .8712 .39279 Metetra
.675 .74 .899 r
.8712 .39279 .87291 .39532 .87714 .39385 .87544 .39133 Metetra
.675 .74 .899 r
.87544 .39133 .87714 .39385 .88137 .39239 .87968 .38986 Metetra
.675 .74 .899 r
.87968 .38986 .88137 .39239 .88562 .39092 .88392 .38839 Metetra
.675 .74 .9 r
.88392 .38839 .88562 .39092 .88986 .38946 .88818 .38693 Metetra
.674 .74 .9 r
.88818 .38693 .88986 .38946 .89412 .388 .89244 .38547 Metetra
.674 .74 .9 r
.89244 .38547 .89412 .388 .89838 .38654 .8967 .384 Metetra
.674 .74 .9 r
.8967 .384 .89838 .38654 .90265 .38508 .90097 .38254 Metetra
.674 .74 .9 r
.90097 .38254 .90265 .38508 .90692 .38362 .90525 .38108 Metetra
.673 .74 .901 r
.90525 .38108 .90692 .38362 .9112 .38217 .90953 .37962 Metetra
.673 .74 .901 r
.90953 .37962 .9112 .38217 .91548 .38071 .91382 .37816 Metetra
.673 .74 .901 r
.91382 .37816 .91548 .38071 .91978 .37925 .91812 .3767 Metetra
.673 .74 .901 r
.91812 .3767 .91978 .37925 .92407 .3778 .92242 .37525 Metetra
.672 .74 .901 r
.92242 .37525 .92407 .3778 .92838 .37634 .92673 .37379 Metetra
.652 .734 .909 r
.34349 .55324 .34568 .55533 .34919 .55434 .34701 .55224 Metetra
.652 .733 .909 r
.34701 .55224 .34919 .55434 .35271 .55334 .35053 .55124 Metetra
.652 .733 .909 r
.35053 .55124 .35271 .55334 .35623 .55235 .35405 .55024 Metetra
.652 .733 .909 r
.35405 .55024 .35623 .55235 .35976 .55135 .35758 .54925 Metetra
.651 .733 .909 r
.35758 .54925 .35976 .55135 .36329 .55036 .36112 .54825 Metetra
.651 .733 .909 r
.36112 .54825 .36329 .55036 .36682 .54937 .36466 .54725 Metetra
.651 .732 .909 r
.36466 .54725 .36682 .54937 .37037 .54838 .3682 .54626 Metetra
.651 .732 .909 r
.3682 .54626 .37037 .54838 .37391 .54739 .37175 .54527 Metetra
.65 .732 .909 r
.37175 .54527 .37391 .54739 .37746 .5464 .3753 .54427 Metetra
.65 .732 .909 r
.3753 .54427 .37746 .5464 .38102 .54542 .37886 .54329 Metetra
.65 .732 .909 r
.37886 .54329 .38102 .54542 .38458 .54443 .38242 .5423 Metetra
.649 .731 .909 r
.38242 .5423 .38458 .54443 .38815 .54345 .38599 .54131 Metetra
.649 .731 .909 r
.38599 .54131 .38815 .54345 .39172 .54247 .38957 .54033 Metetra
.649 .731 .909 r
.38957 .54033 .39172 .54247 .39529 .54149 .39315 .53934 Metetra
.648 .731 .909 r
.39315 .53934 .39529 .54149 .39887 .54052 .39673 .53837 Metetra
.648 .73 .909 r
.39673 .53837 .39887 .54052 .40246 .53954 .40032 .53739 Metetra
.647 .73 .909 r
.40032 .53739 .40246 .53954 .40605 .53857 .40391 .53641 Metetra
.647 .73 .909 r
.40391 .53641 .40605 .53857 .40964 .53761 .40751 .53544 Metetra
.646 .729 .909 r
.40751 .53544 .40964 .53761 .41324 .53664 .41111 .53447 Metetra
.646 .729 .909 r
.41111 .53447 .41324 .53664 .41685 .53568 .41472 .53351 Metetra
.645 .729 .909 r
.41472 .53351 .41685 .53568 .42046 .53473 .41833 .53255 Metetra
.645 .728 .909 r
.41833 .53255 .42046 .53473 .42408 .53377 .42195 .53159 Metetra
.644 .728 .909 r
.42195 .53159 .42408 .53377 .4277 .53282 .42558 .53063 Metetra
.644 .727 .909 r
.42558 .53063 .4277 .53282 .43132 .53188 .4292 .52968 Metetra
.643 .727 .91 r
.4292 .52968 .43132 .53188 .43495 .53094 .43284 .52874 Metetra
.642 .727 .91 r
.43284 .52874 .43495 .53094 .43859 .53 .43648 .52779 Metetra
.642 .726 .91 r
.43648 .52779 .43859 .53 .44223 .52907 .44012 .52686 Metetra
.641 .726 .91 r
.44012 .52686 .44223 .52907 .44588 .52815 .44377 .52593 Metetra
.64 .725 .91 r
.44377 .52593 .44588 .52815 .44953 .52723 .44742 .525 Metetra
.639 .725 .91 r
.44742 .525 .44953 .52723 .45318 .52632 .45108 .52409 Metetra
.639 .724 .91 r
.45108 .52409 .45318 .52632 .45685 .52541 .45475 .52317 Metetra
.638 .723 .91 r
.45475 .52317 .45685 .52541 .46051 .52451 .45842 .52227 Metetra
.637 .723 .91 r
.45842 .52227 .46051 .52451 .46419 .52362 .46209 .52137 Metetra
.636 .722 .91 r
.46209 .52137 .46419 .52362 .46786 .52274 .46578 .52048 Metetra
.635 .721 .91 r
.46578 .52048 .46786 .52274 .47155 .52187 .46946 .5196 Metetra
.633 .72 .91 r
.46946 .5196 .47155 .52187 .47524 .52101 .47315 .51874 Metetra
.632 .72 .91 r
.47315 .51874 .47524 .52101 .47893 .52016 .47685 .51788 Metetra
.631 .719 .91 r
.47685 .51788 .47893 .52016 .48263 .51932 .48055 .51703 Metetra
.629 .718 .91 r
.48055 .51703 .48263 .51932 .48634 .51849 .48426 .51619 Metetra
.628 .717 .91 r
.48426 .51619 .48634 .51849 .49005 .51767 .48798 .51537 Metetra
.626 .715 .911 r
.48798 .51537 .49005 .51767 .49376 .51687 .4917 .51456 Metetra
.624 .714 .911 r
.4917 .51456 .49376 .51687 .49749 .51609 .49542 .51377 Metetra
.623 .713 .911 r
.49542 .51377 .49749 .51609 .50121 .51532 .49915 .51299 Metetra
.62 .712 .911 r
.49915 .51299 .50121 .51532 .50495 .51458 .50289 .51223 Metetra
.618 .71 .911 r
.50289 .51223 .50495 .51458 .50869 .51385 .50663 .51149 Metetra
.616 .708 .911 r
.50663 .51149 .50869 .51385 .51243 .51314 .51038 .51077 Metetra
.613 .706 .911 r
.51038 .51077 .51243 .51314 .51619 .51246 .51414 .51008 Metetra
.61 .704 .911 r
.51414 .51008 .51619 .51246 .51994 .51181 .5179 .50941 Metetra
.607 .702 .911 r
.5179 .50941 .51994 .51181 .52371 .51118 .52166 .50877 Metetra
.603 .7 .912 r
.52166 .50877 .52371 .51118 .52748 .51059 .52544 .50816 Metetra
.599 .697 .912 r
.52544 .50816 .52748 .51059 .53126 .51004 .52922 .50759 Metetra
.595 .694 .912 r
.52922 .50759 .53126 .51004 .53504 .50952 .533 .50706 Metetra
.59 .691 .912 r
.533 .50706 .53504 .50952 .53883 .50905 .5368 .50657 Metetra
.584 .687 .912 r
.5368 .50657 .53883 .50905 .54263 .50863 .5406 .50613 Metetra
.578 .682 .912 r
.5406 .50613 .54263 .50863 .54644 .50827 .54441 .50574 Metetra
.57 .678 .912 r
.54441 .50574 .54644 .50827 .55025 .50797 .54822 .50542 Metetra
.562 .672 .912 r
.54822 .50542 .55025 .50797 .55407 .50775 .55205 .50516 Metetra
.552 .665 .912 r
.55205 .50516 .55407 .50775 .5579 .50761 .55588 .50499 Metetra
.541 .658 .911 r
.55588 .50499 .5579 .50761 .56174 .50757 .55972 .50491 Metetra
.528 .648 .911 r
.55972 .50491 .56174 .50757 .56559 .50765 .56357 .50494 Metetra
.512 .638 .91 r
.56357 .50494 .56559 .50765 .56944 .50786 .56743 .5051 Metetra
.493 .624 .908 r
.56743 .5051 .56944 .50786 .57331 .50823 .5713 .50541 Metetra
.47 .608 .906 r
.5713 .50541 .57331 .50823 .57719 .50879 .57518 .5059 Metetra
.441 .588 .902 r
.57518 .5059 .57719 .50879 .58109 .50958 .57907 .50662 Metetra
.404 .562 .897 r
.57907 .50662 .58109 .50958 .585 .51067 .58298 .5076 Metetra
.357 .527 .887 r
.58298 .5076 .585 .51067 .58892 .51212 .58691 .50892 Metetra
.294 .481 .872 r
.58691 .50892 .58892 .51212 .59287 .51404 .59085 .51068 Metetra
.21 .418 .847 r
.59085 .51068 .59287 .51404 .59685 .51658 .59482 .51302 Metetra
.094 .328 .803 r
.59482 .51302 .59685 .51658 .60085 .51998 .59882 .51613 Metetra
0 .201 .726 r
.59882 .51613 .60085 .51998 .60491 .5246 .60287 .52035 Metetra
0 .026 .598 r
.60287 .52035 .60491 .5246 .60903 .53108 .60697 .52621 Metetra
0 0 .405 r
.60697 .52621 .60903 .53108 .61325 .54061 .61116 .53472 Metetra
.972 .683 .421 r
.61116 .53472 .61325 .54061 .61766 .55584 .61904 .67949 Metetra
.56 .343 .542 r
.61904 .67949 .61766 .55584 .62525 .68045 .62318 .67835 Metetra
.645 .763 .934 r
.62318 .67835 .62525 .68045 .62939 .67931 .62733 .67721 Metetra
.645 .763 .934 r
.62733 .67721 .62939 .67931 .62964 .55231 .63148 .67607 Metetra
0 0 .346 r
.63148 .67607 .62964 .55231 .63311 .53467 .63101 .52876 Metetra
.845 .658 .649 r
.63101 .52876 .63311 .53467 .63674 .52272 .63468 .51783 Metetra
.836 .672 .679 r
.63468 .51783 .63674 .52272 .64045 .51383 .63842 .50954 Metetra
.826 .684 .706 r
.63842 .50954 .64045 .51383 .64422 .50678 .64221 .5029 Metetra
.816 .694 .73 r
.64221 .5029 .64422 .50678 .64803 .50096 .64603 .49735 Metetra
.806 .701 .75 r
.64603 .49735 .64803 .50096 .65186 .496 .64987 .49259 Metetra
.796 .708 .767 r
.64987 .49259 .65186 .496 .65571 .49165 .65374 .4884 Metetra
.786 .713 .782 r
.65374 .4884 .65571 .49165 .65958 .48777 .65762 .48464 Metetra
.778 .717 .795 r
.65762 .48464 .65958 .48777 .66347 .48426 .66151 .48123 Metetra
.77 .72 .806 r
.66151 .48123 .66347 .48426 .66736 .48104 .66541 .47808 Metetra
.762 .723 .816 r
.66541 .47808 .66736 .48104 .67127 .47805 .66933 .47515 Metetra
.756 .725 .824 r
.66933 .47515 .67127 .47805 .67519 .47525 .67326 .47241 Metetra
.749 .727 .831 r
.67326 .47241 .67519 .47525 .67912 .47261 .67719 .46981 Metetra
.744 .729 .838 r
.67719 .46981 .67912 .47261 .68306 .4701 .68113 .46734 Metetra
.739 .73 .843 r
.68113 .46734 .68306 .4701 .687 .46771 .68508 .46498 Metetra
.734 .731 .848 r
.68508 .46498 .687 .46771 .69095 .46542 .68904 .46272 Metetra
.73 .732 .853 r
.68904 .46272 .69095 .46542 .69492 .46321 .69301 .46053 Metetra
.726 .733 .857 r
.69301 .46053 .69492 .46321 .69888 .46108 .69698 .45842 Metetra
.722 .733 .86 r
.69698 .45842 .69888 .46108 .70286 .459 .70096 .45637 Metetra
.719 .734 .863 r
.70096 .45637 .70286 .459 .70684 .45699 .70495 .45437 Metetra
.716 .735 .866 r
.70495 .45437 .70684 .45699 .71083 .45503 .70894 .45242 Metetra
.713 .735 .869 r
.70894 .45242 .71083 .45503 .71482 .45311 .71294 .45051 Metetra
.71 .736 .871 r
.71294 .45051 .71482 .45311 .71882 .45123 .71695 .44864 Metetra
.708 .736 .873 r
.71695 .44864 .71882 .45123 .72283 .44939 .72096 .44681 Metetra
.706 .736 .875 r
.72096 .44681 .72283 .44939 .72685 .44758 .72498 .44501 Metetra
.704 .737 .877 r
.72498 .44501 .72685 .44758 .73087 .44579 .729 .44324 Metetra
.702 .737 .878 r
.729 .44324 .73087 .44579 .7349 .44404 .73304 .44149 Metetra
.7 .737 .88 r
.73304 .44149 .7349 .44404 .73893 .44231 .73707 .43976 Metetra
.698 .737 .881 r
.73707 .43976 .73893 .44231 .74297 .4406 .74112 .43806 Metetra
.697 .737 .882 r
.74112 .43806 .74297 .4406 .74701 .43891 .74517 .43638 Metetra
.695 .738 .884 r
.74517 .43638 .74701 .43891 .75107 .43724 .74922 .43471 Metetra
.694 .738 .885 r
.74922 .43471 .75107 .43724 .75512 .43559 .75329 .43306 Metetra
.693 .738 .886 r
.75329 .43306 .75512 .43559 .75919 .43395 .75735 .43143 Metetra
.692 .738 .887 r
.75735 .43143 .75919 .43395 .76326 .43233 .76143 .42981 Metetra
.69 .738 .888 r
.76143 .42981 .76326 .43233 .76733 .43072 .76551 .4282 Metetra
.689 .738 .888 r
.76551 .4282 .76733 .43072 .77142 .42912 .7696 .4266 Metetra
.688 .738 .889 r
.7696 .4266 .77142 .42912 .7755 .42753 .77369 .42502 Metetra
.687 .739 .89 r
.77369 .42502 .7755 .42753 .7796 .42596 .77779 .42344 Metetra
.687 .739 .891 r
.77779 .42344 .7796 .42596 .7837 .42439 .78189 .42187 Metetra
.686 .739 .891 r
.78189 .42187 .7837 .42439 .7878 .42283 .786 .42032 Metetra
.685 .739 .892 r
.786 .42032 .7878 .42283 .79192 .42128 .79012 .41877 Metetra
.684 .739 .892 r
.79012 .41877 .79192 .42128 .79603 .41974 .79424 .41722 Metetra
.684 .739 .893 r
.79424 .41722 .79603 .41974 .80016 .4182 .79837 .41569 Metetra
.683 .739 .893 r
.79837 .41569 .80016 .4182 .80429 .41667 .80251 .41416 Metetra
.682 .739 .894 r
.80251 .41416 .80429 .41667 .80843 .41515 .80665 .41263 Metetra
.682 .739 .894 r
.80665 .41263 .80843 .41515 .81257 .41363 .81079 .41112 Metetra
.681 .739 .895 r
.81079 .41112 .81257 .41363 .81672 .41212 .81495 .4096 Metetra
.681 .739 .895 r
.81495 .4096 .81672 .41212 .82087 .41061 .81911 .4081 Metetra
.68 .739 .896 r
.81911 .4081 .82087 .41061 .82503 .40911 .82327 .40659 Metetra
.68 .739 .896 r
.82327 .40659 .82503 .40911 .8292 .40761 .82744 .40509 Metetra
.679 .739 .896 r
.82744 .40509 .8292 .40761 .83337 .40611 .83162 .4036 Metetra
.679 .739 .897 r
.83162 .4036 .83337 .40611 .83755 .40462 .8358 .4021 Metetra
.678 .74 .897 r
.8358 .4021 .83755 .40462 .84174 .40313 .83999 .40061 Metetra
.678 .74 .897 r
.83999 .40061 .84174 .40313 .84593 .40165 .84419 .39913 Metetra
.677 .74 .898 r
.84419 .39913 .84593 .40165 .85012 .40017 .84839 .39765 Metetra
.677 .74 .898 r
.84839 .39765 .85012 .40017 .85433 .39869 .8526 .39616 Metetra
.677 .74 .898 r
.8526 .39616 .85433 .39869 .85854 .39721 .85681 .39469 Metetra
.676 .74 .898 r
.85681 .39469 .85854 .39721 .86275 .39574 .86103 .39321 Metetra
.676 .74 .899 r
.86103 .39321 .86275 .39574 .86698 .39427 .86526 .39174 Metetra
.676 .74 .899 r
.86526 .39174 .86698 .39427 .8712 .39279 .86949 .39026 Metetra
.675 .74 .899 r
.86949 .39026 .8712 .39279 .87544 .39133 .87373 .38879 Metetra
.675 .74 .899 r
.87373 .38879 .87544 .39133 .87968 .38986 .87798 .38732 Metetra
.675 .74 .9 r
.87798 .38732 .87968 .38986 .88392 .38839 .88223 .38586 Metetra
.674 .74 .9 r
.88223 .38586 .88392 .38839 .88818 .38693 .88648 .38439 Metetra
.674 .74 .9 r
.88648 .38439 .88818 .38693 .89244 .38547 .89075 .38292 Metetra
.674 .74 .9 r
.89075 .38292 .89244 .38547 .8967 .384 .89502 .38146 Metetra
.674 .74 .9 r
.89502 .38146 .8967 .384 .90097 .38254 .89929 .38 Metetra
.673 .74 .9 r
.89929 .38 .90097 .38254 .90525 .38108 .90358 .37853 Metetra
.673 .74 .901 r
.90358 .37853 .90525 .38108 .90953 .37962 .90786 .37707 Metetra
.673 .74 .901 r
.90786 .37707 .90953 .37962 .91382 .37816 .91216 .37561 Metetra
.673 .74 .901 r
.91216 .37561 .91382 .37816 .91812 .3767 .91646 .37415 Metetra
.673 .74 .901 r
.91646 .37415 .91812 .3767 .92242 .37525 .92077 .37269 Metetra
.672 .74 .901 r
.92077 .37269 .92242 .37525 .92673 .37379 .92508 .37123 Metetra
.653 .734 .909 r
.3413 .55115 .34349 .55324 .34701 .55224 .34482 .55014 Metetra
.652 .733 .909 r
.34482 .55014 .34701 .55224 .35053 .55124 .34834 .54914 Metetra
.652 .733 .909 r
.34834 .54914 .35053 .55124 .35405 .55024 .35187 .54814 Metetra
.652 .733 .909 r
.35187 .54814 .35405 .55024 .35758 .54925 .3554 .54713 Metetra
.652 .733 .909 r
.3554 .54713 .35758 .54925 .36112 .54825 .35894 .54613 Metetra
.651 .733 .909 r
.35894 .54613 .36112 .54825 .36466 .54725 .36248 .54513 Metetra
.651 .732 .909 r
.36248 .54513 .36466 .54725 .3682 .54626 .36603 .54414 Metetra
.651 .732 .909 r
.36603 .54414 .3682 .54626 .37175 .54527 .36958 .54314 Metetra
.65 .732 .909 r
.36958 .54314 .37175 .54527 .3753 .54427 .37314 .54214 Metetra
.65 .732 .909 r
.37314 .54214 .3753 .54427 .37886 .54329 .3767 .54115 Metetra
.65 .732 .909 r
.3767 .54115 .37886 .54329 .38242 .5423 .38026 .54016 Metetra
.649 .731 .909 r
.38026 .54016 .38242 .5423 .38599 .54131 .38384 .53917 Metetra
.649 .731 .909 r
.38384 .53917 .38599 .54131 .38957 .54033 .38741 .53818 Metetra
.649 .731 .909 r
.38741 .53818 .38957 .54033 .39315 .53934 .39099 .53719 Metetra
.648 .731 .909 r
.39099 .53719 .39315 .53934 .39673 .53837 .39458 .53621 Metetra
.648 .73 .909 r
.39458 .53621 .39673 .53837 .40032 .53739 .39817 .53523 Metetra
.648 .73 .909 r
.39817 .53523 .40032 .53739 .40391 .53641 .40177 .53425 Metetra
.647 .73 .909 r
.40177 .53425 .40391 .53641 .40751 .53544 .40537 .53327 Metetra
.647 .729 .909 r
.40537 .53327 .40751 .53544 .41111 .53447 .40897 .5323 Metetra
.646 .729 .909 r
.40897 .5323 .41111 .53447 .41472 .53351 .41258 .53133 Metetra
.646 .729 .909 r
.41258 .53133 .41472 .53351 .41833 .53255 .4162 .53036 Metetra
.645 .728 .909 r
.4162 .53036 .41833 .53255 .42195 .53159 .41982 .5294 Metetra
.645 .728 .909 r
.41982 .5294 .42195 .53159 .42558 .53063 .42345 .52844 Metetra
.644 .728 .909 r
.42345 .52844 .42558 .53063 .4292 .52968 .42708 .52748 Metetra
.643 .727 .909 r
.42708 .52748 .4292 .52968 .43284 .52874 .43072 .52653 Metetra
.643 .727 .909 r
.43072 .52653 .43284 .52874 .43648 .52779 .43436 .52558 Metetra
.642 .726 .91 r
.43436 .52558 .43648 .52779 .44012 .52686 .43801 .52464 Metetra
.641 .726 .91 r
.43801 .52464 .44012 .52686 .44377 .52593 .44166 .52371 Metetra
.641 .725 .91 r
.44166 .52371 .44377 .52593 .44742 .525 .44532 .52277 Metetra
.64 .725 .91 r
.44532 .52277 .44742 .525 .45108 .52409 .44898 .52185 Metetra
.639 .724 .91 r
.44898 .52185 .45108 .52409 .45475 .52317 .45265 .52093 Metetra
.638 .723 .91 r
.45265 .52093 .45475 .52317 .45842 .52227 .45632 .52002 Metetra
.637 .723 .91 r
.45632 .52002 .45842 .52227 .46209 .52137 .46 .51912 Metetra
.636 .722 .91 r
.46 .51912 .46209 .52137 .46578 .52048 .46368 .51822 Metetra
.635 .721 .91 r
.46368 .51822 .46578 .52048 .46946 .5196 .46737 .51734 Metetra
.634 .721 .91 r
.46737 .51734 .46946 .5196 .47315 .51874 .47107 .51646 Metetra
.633 .72 .91 r
.47107 .51646 .47315 .51874 .47685 .51788 .47477 .51559 Metetra
.631 .719 .91 r
.47477 .51559 .47685 .51788 .48055 .51703 .47847 .51473 Metetra
.63 .718 .91 r
.47847 .51473 .48055 .51703 .48426 .51619 .48218 .51389 Metetra
.629 .717 .91 r
.48218 .51389 .48426 .51619 .48798 .51537 .4859 .51306 Metetra
.627 .716 .91 r
.4859 .51306 .48798 .51537 .4917 .51456 .48962 .51224 Metetra
.625 .715 .911 r
.48962 .51224 .4917 .51456 .49542 .51377 .49335 .51144 Metetra
.623 .713 .911 r
.49335 .51144 .49542 .51377 .49915 .51299 .49708 .51065 Metetra
.621 .712 .911 r
.49708 .51065 .49915 .51299 .50289 .51223 .50082 .50988 Metetra
.619 .71 .911 r
.50082 .50988 .50289 .51223 .50663 .51149 .50457 .50913 Metetra
.617 .709 .911 r
.50457 .50913 .50663 .51149 .51038 .51077 .50832 .5084 Metetra
.614 .707 .911 r
.50832 .5084 .51038 .51077 .51414 .51008 .51208 .50769 Metetra
.611 .705 .911 r
.51208 .50769 .51414 .51008 .5179 .50941 .51584 .50701 Metetra
.608 .703 .911 r
.51584 .50701 .5179 .50941 .52166 .50877 .51961 .50636 Metetra
.605 .701 .911 r
.51961 .50636 .52166 .50877 .52544 .50816 .52339 .50573 Metetra
.601 .698 .911 r
.52339 .50573 .52544 .50816 .52922 .50759 .52717 .50514 Metetra
.596 .695 .912 r
.52717 .50514 .52922 .50759 .533 .50706 .53096 .50459 Metetra
.592 .692 .912 r
.53096 .50459 .533 .50706 .5368 .50657 .53476 .50408 Metetra
.586 .688 .912 r
.53476 .50408 .5368 .50657 .5406 .50613 .53856 .50362 Metetra
.58 .684 .912 r
.53856 .50362 .5406 .50613 .54441 .50574 .54237 .50321 Metetra
.573 .679 .912 r
.54237 .50321 .54441 .50574 .54822 .50542 .54619 .50286 Metetra
.565 .674 .912 r
.54619 .50286 .54822 .50542 .55205 .50516 .55002 .50258 Metetra
.556 .667 .911 r
.55002 .50258 .55205 .50516 .55588 .50499 .55385 .50237 Metetra
.546 .66 .911 r
.55385 .50237 .55588 .50499 .55972 .50491 .55769 .50225 Metetra
.533 .651 .911 r
.55769 .50225 .55972 .50491 .56357 .50494 .56154 .50224 Metetra
.518 .641 .91 r
.56154 .50224 .56357 .50494 .56743 .5051 .5654 .50235 Metetra
.501 .629 .908 r
.5654 .50235 .56743 .5051 .5713 .50541 .56928 .50261 Metetra
.479 .613 .906 r
.56928 .50261 .5713 .50541 .57518 .5059 .57316 .50303 Metetra
.452 .594 .903 r
.57316 .50303 .57518 .5059 .57907 .50662 .57705 .50366 Metetra
.418 .57 .898 r
.57705 .50366 .57907 .50662 .58298 .5076 .58096 .50455 Metetra
.375 .539 .89 r
.58096 .50455 .58298 .5076 .58691 .50892 .58489 .50575 Metetra
.318 .497 .877 r
.58489 .50575 .58691 .50892 .59085 .51068 .58883 .50736 Metetra
.242 .44 .855 r
.58883 .50736 .59085 .51068 .59482 .51302 .5928 .50949 Metetra
.138 .36 .818 r
.5928 .50949 .59482 .51302 .59882 .51613 .59679 .51234 Metetra
0 .246 .755 r
.59679 .51234 .59882 .51613 .60287 .52035 .60082 .51618 Metetra
0 .087 .646 r
.60082 .51618 .60287 .52035 .60697 .52621 .60491 .52148 Metetra
0 0 .474 r
.60491 .52148 .60697 .52621 .61116 .53472 .60907 .52908 Metetra
.971 .683 .423 r
.60907 .52908 .61116 .53472 .61904 .67949 .61696 .67738 Metetra
.645 .763 .934 r
.61696 .67738 .61904 .67949 .62318 .67835 .62111 .67624 Metetra
.645 .763 .934 r
.62111 .67624 .62318 .67835 .62733 .67721 .62526 .6751 Metetra
.645 .763 .934 r
.62526 .6751 .62733 .67721 .63148 .67607 .62942 .67395 Metetra
.967 .696 .469 r
.62942 .67395 .63148 .67607 .63101 .52876 .62893 .5231 Metetra
.841 .66 .658 r
.62893 .5231 .63101 .52876 .63468 .51783 .63263 .51307 Metetra
.832 .674 .687 r
.63263 .51307 .63468 .51783 .63842 .50954 .63639 .50533 Metetra
.822 .685 .713 r
.63639 .50533 .63842 .50954 .64221 .5029 .6402 .49906 Metetra
.812 .695 .735 r
.6402 .49906 .64221 .5029 .64603 .49735 .64403 .49378 Metetra
.802 .702 .755 r
.64403 .49378 .64603 .49735 .64987 .49259 .64789 .48921 Metetra
.792 .708 .772 r
.64789 .48921 .64987 .49259 .65374 .4884 .65176 .48517 Metetra
.783 .713 .786 r
.65176 .48517 .65374 .4884 .65762 .48464 .65565 .48152 Metetra
.775 .717 .798 r
.65565 .48152 .65762 .48464 .66151 .48123 .65955 .4782 Metetra
.767 .72 .809 r
.65955 .4782 .66151 .48123 .66541 .47808 .66346 .47513 Metetra
.76 .723 .818 r
.66346 .47513 .66541 .47808 .66933 .47515 .66738 .47226 Metetra
.753 .725 .826 r
.66738 .47226 .66933 .47515 .67326 .47241 .67131 .46957 Metetra
.747 .727 .833 r
.67131 .46957 .67326 .47241 .67719 .46981 .67526 .46701 Metetra
.742 .728 .839 r
.67526 .46701 .67719 .46981 .68113 .46734 .6792 .46458 Metetra
.737 .73 .845 r
.6792 .46458 .68113 .46734 .68508 .46498 .68316 .46226 Metetra
.732 .731 .85 r
.68316 .46226 .68508 .46498 .68904 .46272 .68712 .46002 Metetra
.728 .732 .854 r
.68712 .46002 .68904 .46272 .69301 .46053 .6911 .45785 Metetra
.724 .733 .858 r
.6911 .45785 .69301 .46053 .69698 .45842 .69507 .45576 Metetra
.721 .733 .861 r
.69507 .45576 .69698 .45842 .70096 .45637 .69906 .45373 Metetra
.717 .734 .864 r
.69906 .45373 .70096 .45637 .70495 .45437 .70305 .45174 Metetra
.715 .734 .867 r
.70305 .45174 .70495 .45437 .70894 .45242 .70705 .44981 Metetra
.712 .735 .869 r
.70705 .44981 .70894 .45242 .71294 .45051 .71105 .44791 Metetra
.709 .735 .871 r
.71105 .44791 .71294 .45051 .71695 .44864 .71506 .44606 Metetra
.707 .736 .874 r
.71506 .44606 .71695 .44864 .72096 .44681 .71908 .44423 Metetra
.705 .736 .875 r
.71908 .44423 .72096 .44681 .72498 .44501 .72311 .44244 Metetra
.703 .736 .877 r
.72311 .44244 .72498 .44501 .729 .44324 .72714 .44067 Metetra
.701 .737 .879 r
.72714 .44067 .729 .44324 .73304 .44149 .73117 .43893 Metetra
.699 .737 .88 r
.73117 .43893 .73304 .44149 .73707 .43976 .73521 .43721 Metetra
.698 .737 .881 r
.73521 .43721 .73707 .43976 .74112 .43806 .73926 .43552 Metetra
.696 .737 .883 r
.73926 .43552 .74112 .43806 .74517 .43638 .74332 .43384 Metetra
.695 .738 .884 r
.74332 .43384 .74517 .43638 .74922 .43471 .74738 .43217 Metetra
.693 .738 .885 r
.74738 .43217 .74922 .43471 .75329 .43306 .75145 .43053 Metetra
.692 .738 .886 r
.75145 .43053 .75329 .43306 .75735 .43143 .75552 .4289 Metetra
.691 .738 .887 r
.75552 .4289 .75735 .43143 .76143 .42981 .7596 .42728 Metetra
.69 .738 .888 r
.7596 .42728 .76143 .42981 .76551 .4282 .76368 .42567 Metetra
.689 .738 .889 r
.76368 .42567 .76551 .4282 .7696 .4266 .76777 .42408 Metetra
.688 .738 .889 r
.76777 .42408 .7696 .4266 .77369 .42502 .77187 .42249 Metetra
.687 .738 .89 r
.77187 .42249 .77369 .42502 .77779 .42344 .77597 .42092 Metetra
.686 .739 .891 r
.77597 .42092 .77779 .42344 .78189 .42187 .78008 .41935 Metetra
.685 .739 .891 r
.78008 .41935 .78189 .42187 .786 .42032 .7842 .4178 Metetra
.685 .739 .892 r
.7842 .4178 .786 .42032 .79012 .41877 .78832 .41625 Metetra
.684 .739 .893 r
.78832 .41625 .79012 .41877 .79424 .41722 .79245 .4147 Metetra
.683 .739 .893 r
.79245 .4147 .79424 .41722 .79837 .41569 .79658 .41317 Metetra
.683 .739 .894 r
.79658 .41317 .79837 .41569 .80251 .41416 .80072 .41164 Metetra
.682 .739 .894 r
.80072 .41164 .80251 .41416 .80665 .41263 .80486 .41012 Metetra
.681 .739 .894 r
.80486 .41012 .80665 .41263 .81079 .41112 .80902 .4086 Metetra
.681 .739 .895 r
.80902 .4086 .81079 .41112 .81495 .4096 .81317 .40708 Metetra
.68 .739 .895 r
.81317 .40708 .81495 .4096 .81911 .4081 .81734 .40557 Metetra
.68 .739 .896 r
.81734 .40557 .81911 .4081 .82327 .40659 .82151 .40407 Metetra
.679 .739 .896 r
.82151 .40407 .82327 .40659 .82744 .40509 .82568 .40257 Metetra
.679 .739 .896 r
.82568 .40257 .82744 .40509 .83162 .4036 .82986 .40107 Metetra
.678 .739 .897 r
.82986 .40107 .83162 .4036 .8358 .4021 .83405 .39958 Metetra
.678 .739 .897 r
.83405 .39958 .8358 .4021 .83999 .40061 .83825 .39809 Metetra
.678 .74 .897 r
.83825 .39809 .83999 .40061 .84419 .39913 .84245 .3966 Metetra
.677 .74 .898 r
.84245 .3966 .84419 .39913 .84839 .39765 .84665 .39512 Metetra
.677 .74 .898 r
.84665 .39512 .84839 .39765 .8526 .39616 .85087 .39363 Metetra
.676 .74 .898 r
.85087 .39363 .8526 .39616 .85681 .39469 .85508 .39215 Metetra
.676 .74 .898 r
.85508 .39215 .85681 .39469 .86103 .39321 .85931 .39068 Metetra
.676 .74 .899 r
.85931 .39068 .86103 .39321 .86526 .39174 .86354 .3892 Metetra
.675 .74 .899 r
.86354 .3892 .86526 .39174 .86949 .39026 .86778 .38773 Metetra
.675 .74 .899 r
.86778 .38773 .86949 .39026 .87373 .38879 .87202 .38625 Metetra
.675 .74 .899 r
.87202 .38625 .87373 .38879 .87798 .38732 .87627 .38478 Metetra
.675 .74 .9 r
.87627 .38478 .87798 .38732 .88223 .38586 .88053 .38331 Metetra
.674 .74 .9 r
.88053 .38331 .88223 .38586 .88648 .38439 .88479 .38184 Metetra
.674 .74 .9 r
.88479 .38184 .88648 .38439 .89075 .38292 .88906 .38037 Metetra
.674 .74 .9 r
.88906 .38037 .89075 .38292 .89502 .38146 .89333 .37891 Metetra
.674 .74 .9 r
.89333 .37891 .89502 .38146 .89929 .38 .89761 .37744 Metetra
.673 .74 .901 r
.89761 .37744 .89929 .38 .90358 .37853 .9019 .37598 Metetra
.673 .74 .901 r
.9019 .37598 .90358 .37853 .90786 .37707 .90619 .37451 Metetra
.673 .74 .901 r
.90619 .37451 .90786 .37707 .91216 .37561 .91049 .37305 Metetra
.673 .74 .901 r
.91049 .37305 .91216 .37561 .91646 .37415 .9148 .37158 Metetra
.672 .74 .901 r
.9148 .37158 .91646 .37415 .92077 .37269 .91911 .37012 Metetra
.672 .74 .901 r
.91911 .37012 .92077 .37269 .92508 .37123 .92343 .36866 Metetra
.653 .734 .909 r
.3391 .54905 .3413 .55115 .34482 .55014 .34262 .54804 Metetra
.652 .733 .909 r
.34262 .54804 .34482 .55014 .34834 .54914 .34615 .54703 Metetra
.652 .733 .909 r
.34615 .54703 .34834 .54914 .35187 .54814 .34968 .54602 Metetra
.652 .733 .909 r
.34968 .54602 .35187 .54814 .3554 .54713 .35321 .54502 Metetra
.652 .733 .909 r
.35321 .54502 .3554 .54713 .35894 .54613 .35675 .54401 Metetra
.651 .733 .909 r
.35675 .54401 .35894 .54613 .36248 .54513 .3603 .54301 Metetra
.651 .733 .909 r
.3603 .54301 .36248 .54513 .36603 .54414 .36385 .54201 Metetra
.651 .732 .909 r
.36385 .54201 .36603 .54414 .36958 .54314 .3674 .54101 Metetra
.651 .732 .909 r
.3674 .54101 .36958 .54314 .37314 .54214 .37096 .54001 Metetra
.65 .732 .909 r
.37096 .54001 .37314 .54214 .3767 .54115 .37453 .53901 Metetra
.65 .732 .909 r
.37453 .53901 .3767 .54115 .38026 .54016 .3781 .53801 Metetra
.65 .731 .909 r
.3781 .53801 .38026 .54016 .38384 .53917 .38167 .53702 Metetra
.649 .731 .909 r
.38167 .53702 .38384 .53917 .38741 .53818 .38525 .53603 Metetra
.649 .731 .909 r
.38525 .53603 .38741 .53818 .39099 .53719 .38884 .53504 Metetra
.649 .731 .909 r
.38884 .53504 .39099 .53719 .39458 .53621 .39242 .53405 Metetra
.648 .73 .909 r
.39242 .53405 .39458 .53621 .39817 .53523 .39602 .53306 Metetra
.648 .73 .909 r
.39602 .53306 .39817 .53523 .40177 .53425 .39962 .53208 Metetra
.647 .73 .909 r
.39962 .53208 .40177 .53425 .40537 .53327 .40322 .5311 Metetra
.647 .73 .909 r
.40322 .5311 .40537 .53327 .40897 .5323 .40683 .53012 Metetra
.646 .729 .909 r
.40683 .53012 .40897 .5323 .41258 .53133 .41044 .52914 Metetra
.646 .729 .909 r
.41044 .52914 .41258 .53133 .4162 .53036 .41406 .52817 Metetra
.645 .728 .909 r
.41406 .52817 .4162 .53036 .41982 .5294 .41769 .5272 Metetra
.645 .728 .909 r
.41769 .5272 .41982 .5294 .42345 .52844 .42132 .52624 Metetra
.644 .728 .909 r
.42132 .52624 .42345 .52844 .42708 .52748 .42495 .52528 Metetra
.644 .727 .909 r
.42495 .52528 .42708 .52748 .43072 .52653 .42859 .52432 Metetra
.643 .727 .909 r
.42859 .52432 .43072 .52653 .43436 .52558 .43224 .52337 Metetra
.642 .726 .909 r
.43224 .52337 .43436 .52558 .43801 .52464 .43589 .52242 Metetra
.642 .726 .909 r
.43589 .52242 .43801 .52464 .44166 .52371 .43954 .52148 Metetra
.641 .725 .91 r
.43954 .52148 .44166 .52371 .44532 .52277 .4432 .52054 Metetra
.64 .725 .91 r
.4432 .52054 .44532 .52277 .44898 .52185 .44687 .51961 Metetra
.639 .724 .91 r
.44687 .51961 .44898 .52185 .45265 .52093 .45054 .51869 Metetra
.638 .724 .91 r
.45054 .51869 .45265 .52093 .45632 .52002 .45421 .51777 Metetra
.638 .723 .91 r
.45421 .51777 .45632 .52002 .46 .51912 .4579 .51686 Metetra
.637 .722 .91 r
.4579 .51686 .46 .51912 .46368 .51822 .46158 .51596 Metetra
.636 .722 .91 r
.46158 .51596 .46368 .51822 .46737 .51734 .46528 .51506 Metetra
.634 .721 .91 r
.46528 .51506 .46737 .51734 .47107 .51646 .46897 .51418 Metetra
.633 .72 .91 r
.46897 .51418 .47107 .51646 .47477 .51559 .47268 .5133 Metetra
.632 .719 .91 r
.47268 .5133 .47477 .51559 .47847 .51473 .47638 .51244 Metetra
.631 .718 .91 r
.47638 .51244 .47847 .51473 .48218 .51389 .4801 .51158 Metetra
.629 .717 .91 r
.4801 .51158 .48218 .51389 .4859 .51306 .48382 .51074 Metetra
.628 .716 .91 r
.48382 .51074 .4859 .51306 .48962 .51224 .48754 .50992 Metetra
.626 .715 .91 r
.48754 .50992 .48962 .51224 .49335 .51144 .49128 .5091 Metetra
.624 .714 .91 r
.49128 .5091 .49335 .51144 .49708 .51065 .49501 .50831 Metetra
.622 .712 .911 r
.49501 .50831 .49708 .51065 .50082 .50988 .49876 .50753 Metetra
.62 .711 .911 r
.49876 .50753 .50082 .50988 .50457 .50913 .5025 .50676 Metetra
.618 .709 .911 r
.5025 .50676 .50457 .50913 .50832 .5084 .50626 .50602 Metetra
.615 .708 .911 r
.50626 .50602 .50832 .5084 .51208 .50769 .51002 .5053 Metetra
.612 .706 .911 r
.51002 .5053 .51208 .50769 .51584 .50701 .51379 .50461 Metetra
.609 .704 .911 r
.51379 .50461 .51584 .50701 .51961 .50636 .51756 .50394 Metetra
.606 .701 .911 r
.51756 .50394 .51961 .50636 .52339 .50573 .52134 .5033 Metetra
.602 .699 .911 r
.52134 .5033 .52339 .50573 .52717 .50514 .52512 .50269 Metetra
.598 .696 .911 r
.52512 .50269 .52717 .50514 .53096 .50459 .52892 .50212 Metetra
.594 .693 .911 r
.52892 .50212 .53096 .50459 .53476 .50408 .53271 .50159 Metetra
.589 .689 .911 r
.53271 .50159 .53476 .50408 .53856 .50362 .53652 .50111 Metetra
.583 .685 .911 r
.53652 .50111 .53856 .50362 .54237 .50321 .54033 .50067 Metetra
.576 .681 .911 r
.54033 .50067 .54237 .50321 .54619 .50286 .54415 .5003 Metetra
.569 .675 .911 r
.54415 .5003 .54619 .50286 .55002 .50258 .54798 .49999 Metetra
.56 .669 .911 r
.54798 .49999 .55002 .50258 .55385 .50237 .55182 .49975 Metetra
.55 .662 .911 r
.55182 .49975 .55385 .50237 .55769 .50225 .55566 .4996 Metetra
.538 .654 .91 r
.55566 .4996 .55769 .50225 .56154 .50224 .55952 .49954 Metetra
.524 .644 .91 r
.55952 .49954 .56154 .50224 .5654 .50235 .56338 .4996 Metetra
.508 .633 .908 r
.56338 .4996 .5654 .50235 .56928 .50261 .56725 .4998 Metetra
.487 .619 .906 r
.56725 .4998 .56928 .50261 .57316 .50303 .57113 .50016 Metetra
.463 .601 .904 r
.57113 .50016 .57316 .50303 .57705 .50366 .57503 .50071 Metetra
.432 .579 .899 r
.57503 .50071 .57705 .50366 .58096 .50455 .57894 .50151 Metetra
.392 .55 .892 r
.57894 .50151 .58096 .50455 .58489 .50575 .58286 .50259 Metetra
.34 .512 .881 r
.58286 .50259 .58489 .50575 .58883 .50736 .5868 .50405 Metetra
.272 .461 .863 r
.5868 .50405 .58883 .50736 .5928 .50949 .59077 .506 Metetra
.179 .389 .832 r
.59077 .506 .5928 .50949 .59679 .51234 .59476 .5086 Metetra
.051 .288 .779 r
.59476 .5086 .59679 .51234 .60082 .51618 .59878 .51209 Metetra
0 .145 .687 r
.59878 .51209 .60082 .51618 .60491 .52148 .60285 .51688 Metetra
0 0 .538 r
.60285 .51688 .60491 .52148 .60907 .52908 .60699 .52367 Metetra
.971 .683 .424 r
.60699 .52367 .60907 .52908 .61696 .67738 .61488 .67528 Metetra
.645 .763 .934 r
.61488 .67528 .61696 .67738 .62111 .67624 .61903 .67413 Metetra
.645 .763 .934 r
.61903 .67413 .62111 .67624 .62526 .6751 .62319 .67298 Metetra
.645 .763 .934 r
.62319 .67298 .62526 .6751 .62942 .67395 .62735 .67184 Metetra
.967 .696 .469 r
.62735 .67184 .62942 .67395 .62893 .5231 .62684 .51766 Metetra
.836 .662 .666 r
.62684 .51766 .62893 .5231 .63263 .51307 .63058 .50844 Metetra
.827 .676 .694 r
.63058 .50844 .63263 .51307 .63639 .50533 .63436 .50121 Metetra
.818 .687 .719 r
.63436 .50121 .63639 .50533 .6402 .49906 .63818 .49528 Metetra
.808 .695 .741 r
.63818 .49528 .6402 .49906 .64403 .49378 .64203 .49024 Metetra
.798 .703 .76 r
.64203 .49024 .64403 .49378 .64789 .48921 .6459 .48586 Metetra
.788 .709 .776 r
.6459 .48586 .64789 .48921 .65176 .48517 .64978 .48195 Metetra
.78 .713 .79 r
.64978 .48195 .65176 .48517 .65565 .48152 .65368 .47842 Metetra
.771 .717 .802 r
.65368 .47842 .65565 .48152 .65955 .4782 .65758 .47518 Metetra
.764 .72 .812 r
.65758 .47518 .65955 .4782 .66346 .47513 .6615 .47218 Metetra
.757 .723 .821 r
.6615 .47218 .66346 .47513 .66738 .47226 .66543 .46937 Metetra
.751 .725 .828 r
.66543 .46937 .66738 .47226 .67131 .46957 .66937 .46673 Metetra
.745 .727 .835 r
.66937 .46673 .67131 .46957 .67526 .46701 .67332 .46422 Metetra
.74 .728 .841 r
.67332 .46422 .67526 .46701 .6792 .46458 .67727 .46182 Metetra
.735 .73 .846 r
.67727 .46182 .6792 .46458 .68316 .46226 .68123 .45952 Metetra
.73 .731 .851 r
.68123 .45952 .68316 .46226 .68712 .46002 .6852 .45731 Metetra
.726 .732 .855 r
.6852 .45731 .68712 .46002 .6911 .45785 .68918 .45517 Metetra
.723 .732 .859 r
.68918 .45517 .6911 .45785 .69507 .45576 .69316 .4531 Metetra
.719 .733 .862 r
.69316 .4531 .69507 .45576 .69906 .45373 .69715 .45108 Metetra
.716 .734 .865 r
.69715 .45108 .69906 .45373 .70305 .45174 .70115 .44912 Metetra
.713 .734 .867 r
.70115 .44912 .70305 .45174 .70705 .44981 .70515 .44719 Metetra
.711 .735 .87 r
.70515 .44719 .70705 .44981 .71105 .44791 .70916 .44531 Metetra
.708 .735 .872 r
.70916 .44531 .71105 .44791 .71506 .44606 .71318 .44346 Metetra
.706 .736 .874 r
.71318 .44346 .71506 .44606 .71908 .44423 .7172 .44165 Metetra
.704 .736 .876 r
.7172 .44165 .71908 .44423 .72311 .44244 .72123 .43986 Metetra
.702 .736 .878 r
.72123 .43986 .72311 .44244 .72714 .44067 .72526 .43811 Metetra
.7 .737 .879 r
.72526 .43811 .72714 .44067 .73117 .43893 .7293 .43637 Metetra
.699 .737 .881 r
.7293 .43637 .73117 .43893 .73521 .43721 .73335 .43466 Metetra
.697 .737 .882 r
.73335 .43466 .73521 .43721 .73926 .43552 .7374 .43296 Metetra
.696 .737 .883 r
.7374 .43296 .73926 .43552 .74332 .43384 .74146 .43129 Metetra
.694 .737 .884 r
.74146 .43129 .74332 .43384 .74738 .43217 .74553 .42963 Metetra
.693 .738 .885 r
.74553 .42963 .74738 .43217 .75145 .43053 .7496 .42799 Metetra
.692 .738 .886 r
.7496 .42799 .75145 .43053 .75552 .4289 .75368 .42636 Metetra
.691 .738 .887 r
.75368 .42636 .75552 .4289 .7596 .42728 .75776 .42474 Metetra
.69 .738 .888 r
.75776 .42474 .7596 .42728 .76368 .42567 .76185 .42314 Metetra
.689 .738 .889 r
.76185 .42314 .76368 .42567 .76777 .42408 .76595 .42155 Metetra
.688 .738 .89 r
.76595 .42155 .76777 .42408 .77187 .42249 .77005 .41996 Metetra
.687 .738 .89 r
.77005 .41996 .77187 .42249 .77597 .42092 .77415 .41839 Metetra
.686 .738 .891 r
.77415 .41839 .77597 .42092 .78008 .41935 .77827 .41683 Metetra
.685 .739 .892 r
.77827 .41683 .78008 .41935 .7842 .4178 .78239 .41527 Metetra
.684 .739 .892 r
.78239 .41527 .7842 .4178 .78832 .41625 .78651 .41372 Metetra
.684 .739 .893 r
.78651 .41372 .78832 .41625 .79245 .4147 .79065 .41218 Metetra
.683 .739 .893 r
.79065 .41218 .79245 .4147 .79658 .41317 .79478 .41064 Metetra
.682 .739 .894 r
.79478 .41064 .79658 .41317 .80072 .41164 .79893 .40911 Metetra
.682 .739 .894 r
.79893 .40911 .80072 .41164 .80486 .41012 .80308 .40759 Metetra
.681 .739 .895 r
.80308 .40759 .80486 .41012 .80902 .4086 .80723 .40607 Metetra
.681 .739 .895 r
.80723 .40607 .80902 .4086 .81317 .40708 .8114 .40456 Metetra
.68 .739 .895 r
.8114 .40456 .81317 .40708 .81734 .40557 .81556 .40305 Metetra
.68 .739 .896 r
.81556 .40305 .81734 .40557 .82151 .40407 .81974 .40154 Metetra
.679 .739 .896 r
.81974 .40154 .82151 .40407 .82568 .40257 .82392 .40004 Metetra
.679 .739 .897 r
.82392 .40004 .82568 .40257 .82986 .40107 .8281 .39854 Metetra
.678 .739 .897 r
.8281 .39854 .82986 .40107 .83405 .39958 .8323 .39705 Metetra
.678 .739 .897 r
.8323 .39705 .83405 .39958 .83825 .39809 .8365 .39556 Metetra
.677 .739 .897 r
.8365 .39556 .83825 .39809 .84245 .3966 .8407 .39407 Metetra
.677 .74 .898 r
.8407 .39407 .84245 .3966 .84665 .39512 .84491 .39258 Metetra
.677 .74 .898 r
.84491 .39258 .84665 .39512 .85087 .39363 .84913 .3911 Metetra
.676 .74 .898 r
.84913 .3911 .85087 .39363 .85508 .39215 .85335 .38961 Metetra
.676 .74 .899 r
.85335 .38961 .85508 .39215 .85931 .39068 .85758 .38813 Metetra
.676 .74 .899 r
.85758 .38813 .85931 .39068 .86354 .3892 .86182 .38666 Metetra
.675 .74 .899 r
.86182 .38666 .86354 .3892 .86778 .38773 .86606 .38518 Metetra
.675 .74 .899 r
.86606 .38518 .86778 .38773 .87202 .38625 .87031 .38371 Metetra
.675 .74 .899 r
.87031 .38371 .87202 .38625 .87627 .38478 .87456 .38223 Metetra
.674 .74 .9 r
.87456 .38223 .87627 .38478 .88053 .38331 .87882 .38076 Metetra
.674 .74 .9 r
.87882 .38076 .88053 .38331 .88479 .38184 .88309 .37929 Metetra
.674 .74 .9 r
.88309 .37929 .88479 .38184 .88906 .38037 .88736 .37782 Metetra
.674 .74 .9 r
.88736 .37782 .88906 .38037 .89333 .37891 .89164 .37635 Metetra
.673 .74 .9 r
.89164 .37635 .89333 .37891 .89761 .37744 .89592 .37488 Metetra
.673 .74 .901 r
.89592 .37488 .89761 .37744 .9019 .37598 .90022 .37341 Metetra
.673 .74 .901 r
.90022 .37341 .9019 .37598 .90619 .37451 .90451 .37195 Metetra
.673 .74 .901 r
.90451 .37195 .90619 .37451 .91049 .37305 .90882 .37048 Metetra
.673 .74 .901 r
.90882 .37048 .91049 .37305 .9148 .37158 .91313 .36901 Metetra
.672 .74 .901 r
.91313 .36901 .9148 .37158 .91911 .37012 .91745 .36755 Metetra
.672 .74 .901 r
.91745 .36755 .91911 .37012 .92343 .36866 .92177 .36608 Metetra
.653 .734 .909 r
.3369 .54694 .3391 .54905 .34262 .54804 .34042 .54593 Metetra
.653 .733 .909 r
.34042 .54593 .34262 .54804 .34615 .54703 .34395 .54492 Metetra
.652 .733 .909 r
.34395 .54492 .34615 .54703 .34968 .54602 .34748 .54391 Metetra
.652 .733 .909 r
.34748 .54391 .34968 .54602 .35321 .54502 .35102 .5429 Metetra
.652 .733 .909 r
.35102 .5429 .35321 .54502 .35675 .54401 .35457 .54189 Metetra
.652 .733 .909 r
.35457 .54189 .35675 .54401 .3603 .54301 .35811 .54088 Metetra
.651 .733 .909 r
.35811 .54088 .3603 .54301 .36385 .54201 .36167 .53988 Metetra
.651 .732 .909 r
.36167 .53988 .36385 .54201 .3674 .54101 .36522 .53887 Metetra
.651 .732 .909 r
.36522 .53887 .3674 .54101 .37096 .54001 .36879 .53787 Metetra
.65 .732 .909 r
.36879 .53787 .37096 .54001 .37453 .53901 .37235 .53687 Metetra
.65 .732 .909 r
.37235 .53687 .37453 .53901 .3781 .53801 .37593 .53586 Metetra
.65 .732 .909 r
.37593 .53586 .3781 .53801 .38167 .53702 .3795 .53487 Metetra
.649 .731 .909 r
.3795 .53487 .38167 .53702 .38525 .53603 .38309 .53387 Metetra
.649 .731 .909 r
.38309 .53387 .38525 .53603 .38884 .53504 .38667 .53287 Metetra
.649 .731 .909 r
.38667 .53287 .38884 .53504 .39242 .53405 .39026 .53188 Metetra
.648 .73 .909 r
.39026 .53188 .39242 .53405 .39602 .53306 .39386 .53089 Metetra
.648 .73 .909 r
.39386 .53089 .39602 .53306 .39962 .53208 .39746 .5299 Metetra
.647 .73 .909 r
.39746 .5299 .39962 .53208 .40322 .5311 .40107 .52892 Metetra
.647 .73 .909 r
.40107 .52892 .40322 .5311 .40683 .53012 .40468 .52793 Metetra
.647 .729 .909 r
.40468 .52793 .40683 .53012 .41044 .52914 .4083 .52695 Metetra
.646 .729 .909 r
.4083 .52695 .41044 .52914 .41406 .52817 .41192 .52597 Metetra
.646 .729 .909 r
.41192 .52597 .41406 .52817 .41769 .5272 .41555 .525 Metetra
.645 .728 .909 r
.41555 .525 .41769 .5272 .42132 .52624 .41918 .52403 Metetra
.645 .728 .909 r
.41918 .52403 .42132 .52624 .42495 .52528 .42282 .52306 Metetra
.644 .727 .909 r
.42282 .52306 .42495 .52528 .42859 .52432 .42646 .5221 Metetra
.643 .727 .909 r
.42646 .5221 .42859 .52432 .43224 .52337 .43011 .52114 Metetra
.643 .727 .909 r
.43011 .52114 .43224 .52337 .43589 .52242 .43376 .52019 Metetra
.642 .726 .909 r
.43376 .52019 .43589 .52242 .43954 .52148 .43742 .51924 Metetra
.641 .726 .909 r
.43742 .51924 .43954 .52148 .4432 .52054 .44108 .5183 Metetra
.641 .725 .909 r
.44108 .5183 .4432 .52054 .44687 .51961 .44475 .51736 Metetra
.64 .724 .91 r
.44475 .51736 .44687 .51961 .45054 .51869 .44843 .51643 Metetra
.639 .724 .91 r
.44843 .51643 .45054 .51869 .45421 .51777 .4521 .51551 Metetra
.638 .723 .91 r
.4521 .51551 .45421 .51777 .4579 .51686 .45579 .51459 Metetra
.637 .723 .91 r
.45579 .51459 .4579 .51686 .46158 .51596 .45948 .51368 Metetra
.636 .722 .91 r
.45948 .51368 .46158 .51596 .46528 .51506 .46317 .51278 Metetra
.635 .721 .91 r
.46317 .51278 .46528 .51506 .46897 .51418 .46687 .51189 Metetra
.634 .72 .91 r
.46687 .51189 .46897 .51418 .47268 .5133 .47058 .51101 Metetra
.633 .719 .91 r
.47058 .51101 .47268 .5133 .47638 .51244 .47429 .51014 Metetra
.631 .719 .91 r
.47429 .51014 .47638 .51244 .4801 .51158 .47801 .50927 Metetra
.63 .718 .91 r
.47801 .50927 .4801 .51158 .48382 .51074 .48173 .50842 Metetra
.628 .716 .91 r
.48173 .50842 .48382 .51074 .48754 .50992 .48546 .50759 Metetra
.627 .715 .91 r
.48546 .50759 .48754 .50992 .49128 .5091 .4892 .50677 Metetra
.625 .714 .91 r
.4892 .50677 .49128 .5091 .49501 .50831 .49294 .50596 Metetra
.623 .713 .91 r
.49294 .50596 .49501 .50831 .49876 .50753 .49668 .50517 Metetra
.621 .711 .91 r
.49668 .50517 .49876 .50753 .5025 .50676 .50043 .50439 Metetra
.619 .71 .911 r
.50043 .50439 .5025 .50676 .50626 .50602 .50419 .50364 Metetra
.616 .708 .911 r
.50419 .50364 .50626 .50602 .51002 .5053 .50795 .50291 Metetra
.614 .706 .911 r
.50795 .50291 .51002 .5053 .51379 .50461 .51172 .5022 Metetra
.611 .704 .911 r
.51172 .5022 .51379 .50461 .51756 .50394 .5155 .50152 Metetra
.607 .702 .911 r
.5155 .50152 .51756 .50394 .52134 .5033 .51928 .50086 Metetra
.604 .699 .911 r
.51928 .50086 .52134 .5033 .52512 .50269 .52307 .50024 Metetra
.6 .697 .911 r
.52307 .50024 .52512 .50269 .52892 .50212 .52686 .49965 Metetra
.596 .694 .911 r
.52686 .49965 .52892 .50212 .53271 .50159 .53067 .4991 Metetra
.591 .69 .911 r
.53067 .4991 .53271 .50159 .53652 .50111 .53447 .4986 Metetra
.585 .686 .911 r
.53447 .4986 .53652 .50111 .54033 .50067 .53829 .49814 Metetra
.579 .682 .911 r
.53829 .49814 .54033 .50067 .54415 .5003 .54211 .49774 Metetra
.572 .677 .911 r
.54211 .49774 .54415 .5003 .54798 .49999 .54594 .4974 Metetra
.563 .671 .911 r
.54594 .4974 .54798 .49999 .55182 .49975 .54978 .49713 Metetra
.554 .665 .911 r
.54978 .49713 .55182 .49975 .55566 .4996 .55363 .49694 Metetra
.543 .657 .91 r
.55363 .49694 .55566 .4996 .55952 .49954 .55748 .49684 Metetra
.53 .648 .909 r
.55748 .49684 .55952 .49954 .56338 .4996 .56135 .49686 Metetra
.514 .637 .908 r
.56135 .49686 .56338 .4996 .56725 .4998 .56522 .497 Metetra
.495 .623 .907 r
.56522 .497 .56725 .4998 .57113 .50016 .5691 .4973 Metetra
.472 .607 .904 r
.5691 .4973 .57113 .50016 .57503 .50071 .573 .49778 Metetra
.444 .586 .9 r
.573 .49778 .57503 .50071 .57894 .50151 .57691 .49848 Metetra
.408 .56 .894 r
.57691 .49848 .57894 .50151 .58286 .50259 .58083 .49946 Metetra
.361 .526 .885 r
.58083 .49946 .58286 .50259 .5868 .50405 .58477 .50078 Metetra
.299 .479 .869 r
.58477 .50078 .5868 .50405 .59077 .506 .58873 .50255 Metetra
.216 .415 .843 r
.58873 .50255 .59077 .506 .59476 .5086 .59272 .50491 Metetra
.101 .326 .799 r
.59272 .50491 .59476 .5086 .59878 .51209 .59673 .50808 Metetra
0 .198 .723 r
.59673 .50808 .59878 .51209 .60285 .51688 .60079 .5124 Metetra
0 .022 .595 r
.60079 .5124 .60285 .51688 .60699 .52367 .60491 .51847 Metetra
.97 .683 .426 r
.60491 .51847 .60699 .52367 .61488 .67528 .61279 .67316 Metetra
.645 .763 .934 r
.61279 .67316 .61488 .67528 .61903 .67413 .61695 .67201 Metetra
.645 .763 .934 r
.61695 .67201 .61903 .67413 .62319 .67298 .6211 .67086 Metetra
.645 .763 .934 r
.6211 .67086 .62319 .67298 .62735 .67184 .62527 .66971 Metetra
.967 .696 .468 r
.62527 .66971 .62735 .67184 .62684 .51766 .62477 .51244 Metetra
.832 .664 .675 r
.62477 .51244 .62684 .51766 .63058 .50844 .62853 .50393 Metetra
.823 .677 .702 r
.62853 .50393 .63058 .50844 .63436 .50121 .63233 .49717 Metetra
.813 .688 .726 r
.63233 .49717 .63436 .50121 .63818 .49528 .63617 .49155 Metetra
.804 .697 .747 r
.63617 .49155 .63818 .49528 .64203 .49024 .64003 .48674 Metetra
.794 .703 .765 r
.64003 .48674 .64203 .49024 .6459 .48586 .6439 .48253 Metetra
.785 .709 .78 r
.6439 .48253 .6459 .48586 .64978 .48195 .6478 .47875 Metetra
.776 .714 .793 r
.6478 .47875 .64978 .48195 .65368 .47842 .6517 .47532 Metetra
.768 .717 .805 r
.6517 .47532 .65368 .47842 .65758 .47518 .65562 .47217 Metetra
.761 .72 .815 r
.65562 .47217 .65758 .47518 .6615 .47218 .65954 .46924 Metetra
.754 .723 .823 r
.65954 .46924 .6615 .47218 .66543 .46937 .66348 .46649 Metetra
.748 .725 .83 r
.66348 .46649 .66543 .46937 .66937 .46673 .66742 .46389 Metetra
.743 .727 .837 r
.66742 .46389 .66937 .46673 .67332 .46422 .67137 .46142 Metetra
.738 .728 .843 r
.67137 .46142 .67332 .46422 .67727 .46182 .67533 .45906 Metetra
.733 .73 .848 r
.67533 .45906 .67727 .46182 .68123 .45952 .6793 .45679 Metetra
.729 .731 .852 r
.6793 .45679 .68123 .45952 .6852 .45731 .68328 .45461 Metetra
.725 .732 .856 r
.68328 .45461 .6852 .45731 .68918 .45517 .68726 .45249 Metetra
.721 .732 .86 r
.68726 .45249 .68918 .45517 .69316 .4531 .69125 .45044 Metetra
.718 .733 .863 r
.69125 .45044 .69316 .4531 .69715 .45108 .69524 .44844 Metetra
.715 .734 .866 r
.69524 .44844 .69715 .45108 .70115 .44912 .69924 .44648 Metetra
.712 .734 .868 r
.69924 .44648 .70115 .44912 .70515 .44719 .70325 .44457 Metetra
.71 .735 .871 r
.70325 .44457 .70515 .44719 .70916 .44531 .70726 .4427 Metetra
.707 .735 .873 r
.70726 .4427 .70916 .44531 .71318 .44346 .71129 .44087 Metetra
.705 .736 .875 r
.71129 .44087 .71318 .44346 .7172 .44165 .71531 .43906 Metetra
.703 .736 .876 r
.71531 .43906 .7172 .44165 .72123 .43986 .71935 .43729 Metetra
.701 .736 .878 r
.71935 .43729 .72123 .43986 .72526 .43811 .72338 .43553 Metetra
.7 .736 .88 r
.72338 .43553 .72526 .43811 .7293 .43637 .72743 .4338 Metetra
.698 .737 .881 r
.72743 .4338 .7293 .43637 .73335 .43466 .73148 .4321 Metetra
.696 .737 .882 r
.73148 .4321 .73335 .43466 .7374 .43296 .73554 .43041 Metetra
.695 .737 .883 r
.73554 .43041 .7374 .43296 .74146 .43129 .7396 .42874 Metetra
.694 .737 .885 r
.7396 .42874 .74146 .43129 .74553 .42963 .74367 .42708 Metetra
.692 .737 .886 r
.74367 .42708 .74553 .42963 .7496 .42799 .74775 .42544 Metetra
.691 .738 .887 r
.74775 .42544 .7496 .42799 .75368 .42636 .75183 .42382 Metetra
.69 .738 .887 r
.75183 .42382 .75368 .42636 .75776 .42474 .75592 .42221 Metetra
.689 .738 .888 r
.75592 .42221 .75776 .42474 .76185 .42314 .76001 .4206 Metetra
.688 .738 .889 r
.76001 .4206 .76185 .42314 .76595 .42155 .76411 .41901 Metetra
.687 .738 .89 r
.76411 .41901 .76595 .42155 .77005 .41996 .76822 .41743 Metetra
.686 .738 .89 r
.76822 .41743 .77005 .41996 .77415 .41839 .77233 .41586 Metetra
.686 .738 .891 r
.77233 .41586 .77415 .41839 .77827 .41683 .77645 .4143 Metetra
.685 .739 .892 r
.77645 .4143 .77827 .41683 .78239 .41527 .78057 .41274 Metetra
.684 .739 .892 r
.78057 .41274 .78239 .41527 .78651 .41372 .7847 .41119 Metetra
.683 .739 .893 r
.7847 .41119 .78651 .41372 .79065 .41218 .78884 .40965 Metetra
.683 .739 .893 r
.78884 .40965 .79065 .41218 .79478 .41064 .79298 .40811 Metetra
.682 .739 .894 r
.79298 .40811 .79478 .41064 .79893 .40911 .79713 .40658 Metetra
.681 .739 .894 r
.79713 .40658 .79893 .40911 .80308 .40759 .80128 .40506 Metetra
.681 .739 .895 r
.80128 .40506 .80308 .40759 .80723 .40607 .80545 .40354 Metetra
.68 .739 .895 r
.80545 .40354 .80723 .40607 .8114 .40456 .80961 .40203 Metetra
.68 .739 .896 r
.80961 .40203 .8114 .40456 .81556 .40305 .81378 .40051 Metetra
.679 .739 .896 r
.81378 .40051 .81556 .40305 .81974 .40154 .81796 .39901 Metetra
.679 .739 .896 r
.81796 .39901 .81974 .40154 .82392 .40004 .82215 .39751 Metetra
.678 .739 .897 r
.82215 .39751 .82392 .40004 .8281 .39854 .82634 .39601 Metetra
.678 .739 .897 r
.82634 .39601 .8281 .39854 .8323 .39705 .83054 .39451 Metetra
.678 .739 .897 r
.83054 .39451 .8323 .39705 .8365 .39556 .83474 .39302 Metetra
.677 .739 .898 r
.83474 .39302 .8365 .39556 .8407 .39407 .83895 .39153 Metetra
.677 .739 .898 r
.83895 .39153 .8407 .39407 .84491 .39258 .84316 .39004 Metetra
.676 .74 .898 r
.84316 .39004 .84491 .39258 .84913 .3911 .84739 .38855 Metetra
.676 .74 .898 r
.84739 .38855 .84913 .3911 .85335 .38961 .85161 .38707 Metetra
.676 .74 .899 r
.85161 .38707 .85335 .38961 .85758 .38813 .85585 .38559 Metetra
.675 .74 .899 r
.85585 .38559 .85758 .38813 .86182 .38666 .86009 .38411 Metetra
.675 .74 .899 r
.86009 .38411 .86182 .38666 .86606 .38518 .86433 .38263 Metetra
.675 .74 .899 r
.86433 .38263 .86606 .38518 .87031 .38371 .86859 .38115 Metetra
.675 .74 .9 r
.86859 .38115 .87031 .38371 .87456 .38223 .87285 .37968 Metetra
.674 .74 .9 r
.87285 .37968 .87456 .38223 .87882 .38076 .87711 .3782 Metetra
.674 .74 .9 r
.87711 .3782 .87882 .38076 .88309 .37929 .88138 .37673 Metetra
.674 .74 .9 r
.88138 .37673 .88309 .37929 .88736 .37782 .88566 .37526 Metetra
.674 .74 .9 r
.88566 .37526 .88736 .37782 .89164 .37635 .88994 .37379 Metetra
.673 .74 .9 r
.88994 .37379 .89164 .37635 .89592 .37488 .89423 .37232 Metetra
.673 .74 .901 r
.89423 .37232 .89592 .37488 .90022 .37341 .89853 .37085 Metetra
.673 .74 .901 r
.89853 .37085 .90022 .37341 .90451 .37195 .90283 .36938 Metetra
.673 .74 .901 r
.90283 .36938 .90451 .37195 .90882 .37048 .90714 .36791 Metetra
.672 .74 .901 r
.90714 .36791 .90882 .37048 .91313 .36901 .91146 .36644 Metetra
.672 .74 .901 r
.91146 .36644 .91313 .36901 .91745 .36755 .91578 .36497 Metetra
.672 .74 .901 r
.91578 .36497 .91745 .36755 .92177 .36608 .92011 .3635 Metetra
.653 .734 .909 r
.33469 .54483 .3369 .54694 .34042 .54593 .33822 .54382 Metetra
.653 .734 .909 r
.33822 .54382 .34042 .54593 .34395 .54492 .34175 .5428 Metetra
.652 .733 .909 r
.34175 .5428 .34395 .54492 .34748 .54391 .34529 .54179 Metetra
.652 .733 .909 r
.34529 .54179 .34748 .54391 .35102 .5429 .34883 .54077 Metetra
.652 .733 .909 r
.34883 .54077 .35102 .5429 .35457 .54189 .35237 .53976 Metetra
.652 .733 .909 r
.35237 .53976 .35457 .54189 .35811 .54088 .35592 .53875 Metetra
.651 .733 .909 r
.35592 .53875 .35811 .54088 .36167 .53988 .35948 .53774 Metetra
.651 .732 .909 r
.35948 .53774 .36167 .53988 .36522 .53887 .36304 .53673 Metetra
.651 .732 .909 r
.36304 .53673 .36522 .53887 .36879 .53787 .3666 .53572 Metetra
.651 .732 .909 r
.3666 .53572 .36879 .53787 .37235 .53687 .37017 .53472 Metetra
.65 .732 .909 r
.37017 .53472 .37235 .53687 .37593 .53586 .37375 .53371 Metetra
.65 .732 .909 r
.37375 .53371 .37593 .53586 .3795 .53487 .37733 .53271 Metetra
.65 .731 .909 r
.37733 .53271 .3795 .53487 .38309 .53387 .38091 .53171 Metetra
.649 .731 .909 r
.38091 .53171 .38309 .53387 .38667 .53287 .3845 .53071 Metetra
.649 .731 .909 r
.3845 .53071 .38667 .53287 .39026 .53188 .3881 .52971 Metetra
.649 .731 .909 r
.3881 .52971 .39026 .53188 .39386 .53089 .3917 .52871 Metetra
.648 .73 .909 r
.3917 .52871 .39386 .53089 .39746 .5299 .3953 .52772 Metetra
.648 .73 .909 r
.3953 .52772 .39746 .5299 .40107 .52892 .39891 .52673 Metetra
.647 .73 .909 r
.39891 .52673 .40107 .52892 .40468 .52793 .40253 .52574 Metetra
.647 .729 .909 r
.40253 .52574 .40468 .52793 .4083 .52695 .40615 .52476 Metetra
.646 .729 .909 r
.40615 .52476 .4083 .52695 .41192 .52597 .40977 .52377 Metetra
.646 .729 .909 r
.40977 .52377 .41192 .52597 .41555 .525 .4134 .5228 Metetra
.645 .728 .909 r
.4134 .5228 .41555 .525 .41918 .52403 .41704 .52182 Metetra
.645 .728 .909 r
.41704 .52182 .41918 .52403 .42282 .52306 .42068 .52085 Metetra
.644 .728 .909 r
.42068 .52085 .42282 .52306 .42646 .5221 .42433 .51988 Metetra
.644 .727 .909 r
.42433 .51988 .42646 .5221 .43011 .52114 .42798 .51892 Metetra
.643 .727 .909 r
.42798 .51892 .43011 .52114 .43376 .52019 .43163 .51796 Metetra
.642 .726 .909 r
.43163 .51796 .43376 .52019 .43742 .51924 .43529 .51701 Metetra
.642 .726 .909 r
.43529 .51701 .43742 .51924 .44108 .5183 .43896 .51606 Metetra
.641 .725 .909 r
.43896 .51606 .44108 .5183 .44475 .51736 .44263 .51511 Metetra
.64 .725 .909 r
.44263 .51511 .44475 .51736 .44843 .51643 .44631 .51418 Metetra
.639 .724 .909 r
.44631 .51418 .44843 .51643 .4521 .51551 .44999 .51325 Metetra
.638 .723 .91 r
.44999 .51325 .4521 .51551 .45579 .51459 .45368 .51232 Metetra
.637 .723 .91 r
.45368 .51232 .45579 .51459 .45948 .51368 .45737 .51141 Metetra
.636 .722 .91 r
.45737 .51141 .45948 .51368 .46317 .51278 .46107 .5105 Metetra
.635 .721 .91 r
.46107 .5105 .46317 .51278 .46687 .51189 .46477 .5096 Metetra
.634 .721 .91 r
.46477 .5096 .46687 .51189 .47058 .51101 .46848 .50871 Metetra
.633 .72 .91 r
.46848 .50871 .47058 .51101 .47429 .51014 .4722 .50783 Metetra
.632 .719 .91 r
.4722 .50783 .47429 .51014 .47801 .50927 .47592 .50696 Metetra
.63 .718 .91 r
.47592 .50696 .47801 .50927 .48173 .50842 .47964 .5061 Metetra
.629 .717 .91 r
.47964 .5061 .48173 .50842 .48546 .50759 .48337 .50525 Metetra
.627 .716 .91 r
.48337 .50525 .48546 .50759 .4892 .50677 .48711 .50442 Metetra
.626 .714 .91 r
.48711 .50442 .4892 .50677 .49294 .50596 .49085 .50361 Metetra
.624 .713 .91 r
.49085 .50361 .49294 .50596 .49668 .50517 .4946 .5028 Metetra
.622 .712 .91 r
.4946 .5028 .49668 .50517 .50043 .50439 .49836 .50202 Metetra
.62 .71 .91 r
.49836 .50202 .50043 .50439 .50419 .50364 .50212 .50125 Metetra
.617 .709 .91 r
.50212 .50125 .50419 .50364 .50795 .50291 .50588 .50051 Metetra
.615 .707 .91 r
.50588 .50051 .50795 .50291 .51172 .5022 .50966 .49979 Metetra
.612 .705 .911 r
.50966 .49979 .51172 .5022 .5155 .50152 .51343 .49909 Metetra
.609 .703 .911 r
.51343 .49909 .5155 .50152 .51928 .50086 .51722 .49842 Metetra
.605 .7 .911 r
.51722 .49842 .51928 .50086 .52307 .50024 .52101 .49778 Metetra
.602 .698 .911 r
.52101 .49778 .52307 .50024 .52686 .49965 .52481 .49718 Metetra
.597 .695 .911 r
.52481 .49718 .52686 .49965 .53067 .4991 .52861 .49661 Metetra
.593 .691 .911 r
.52861 .49661 .53067 .4991 .53447 .4986 .53242 .49608 Metetra
.587 .688 .911 r
.53242 .49608 .53447 .4986 .53829 .49814 .53624 .4956 Metetra
.581 .683 .911 r
.53624 .4956 .53829 .49814 .54211 .49774 .54007 .49517 Metetra
.575 .679 .911 r
.54007 .49517 .54211 .49774 .54594 .4974 .5439 .49481 Metetra
.567 .673 .911 r
.5439 .49481 .54594 .4974 .54978 .49713 .54774 .4945 Metetra
.558 .667 .91 r
.54774 .4945 .54978 .49713 .55363 .49694 .55159 .49428 Metetra
.547 .66 .91 r
.55159 .49428 .55363 .49694 .55748 .49684 .55545 .49415 Metetra
.535 .651 .909 r
.55545 .49415 .55748 .49684 .56135 .49686 .55931 .49412 Metetra
.521 .64 .908 r
.55931 .49412 .56135 .49686 .56522 .497 .56319 .49421 Metetra
.503 .628 .907 r
.56319 .49421 .56522 .497 .5691 .4973 .56707 .49444 Metetra
.482 .613 .904 r
.56707 .49444 .5691 .4973 .573 .49778 .57097 .49485 Metetra
.455 .594 .901 r
.57097 .49485 .573 .49778 .57691 .49848 .57488 .49546 Metetra
.422 .569 .896 r
.57488 .49546 .57691 .49848 .58083 .49946 .5788 .49634 Metetra
.38 .538 .887 r
.5788 .49634 .58083 .49946 .58477 .50078 .58274 .49753 Metetra
.324 .496 .874 r
.58274 .49753 .58477 .50078 .58873 .50255 .5867 .49913 Metetra
.249 .439 .853 r
.5867 .49913 .58873 .50255 .59272 .50491 .59068 .50127 Metetra
.147 .36 .816 r
.59068 .50127 .59272 .50491 .59673 .50808 .59469 .50414 Metetra
.007 .246 .753 r
.59469 .50414 .59673 .50808 .60079 .5124 .59874 .50804 Metetra
.969 .682 .431 r
.59874 .50804 .60079 .5124 .60491 .51847 .60655 .67219 Metetra
.559 .342 .542 r
.60655 .67219 .60491 .51847 .61279 .67316 .6107 .67104 Metetra
.645 .763 .934 r
.6107 .67104 .61279 .67316 .61695 .67201 .61485 .66989 Metetra
.645 .763 .934 r
.61485 .66989 .61695 .67201 .6211 .67086 .61902 .66874 Metetra
.645 .763 .934 r
.61902 .66874 .6211 .67086 .62527 .66971 .62319 .66758 Metetra
.645 .763 .934 r
.62319 .66758 .62527 .66971 .62477 .51244 .62736 .66642 Metetra
0 0 .381 r
.62736 .66642 .62477 .51244 .62853 .50393 .62648 .49954 Metetra
.819 .679 .71 r
.62648 .49954 .62853 .50393 .63233 .49717 .6303 .4932 Metetra
.809 .689 .733 r
.6303 .4932 .63233 .49717 .63617 .49155 .63415 .48788 Metetra
.799 .698 .753 r
.63415 .48788 .63617 .49155 .64003 .48674 .63802 .48328 Metetra
.79 .704 .77 r
.63802 .48328 .64003 .48674 .6439 .48253 .64191 .47922 Metetra
.781 .71 .784 r
.64191 .47922 .6439 .48253 .6478 .47875 .64581 .47557 Metetra
.773 .714 .797 r
.64581 .47557 .6478 .47875 .6517 .47532 .64972 .47225 Metetra
.765 .718 .808 r
.64972 .47225 .6517 .47532 .65562 .47217 .65364 .46917 Metetra
.758 .721 .817 r
.65364 .46917 .65562 .47217 .65954 .46924 .65758 .46631 Metetra
.752 .723 .825 r
.65758 .46631 .65954 .46924 .66348 .46649 .66152 .46361 Metetra
.746 .725 .833 r
.66152 .46361 .66348 .46649 .66742 .46389 .66547 .46106 Metetra
.741 .727 .839 r
.66547 .46106 .66742 .46389 .67137 .46142 .66943 .45863 Metetra
.736 .728 .844 r
.66943 .45863 .67137 .46142 .67533 .45906 .67339 .4563 Metetra
.731 .73 .849 r
.67339 .4563 .67533 .45906 .6793 .45679 .67737 .45406 Metetra
.727 .731 .853 r
.67737 .45406 .6793 .45679 .68328 .45461 .68135 .4519 Metetra
.723 .731 .857 r
.68135 .4519 .68328 .45461 .68726 .45249 .68533 .44981 Metetra
.72 .732 .861 r
.68533 .44981 .68726 .45249 .69125 .45044 .68933 .44777 Metetra
.717 .733 .864 r
.68933 .44777 .69125 .45044 .69524 .44844 .69333 .44579 Metetra
.714 .734 .866 r
.69333 .44579 .69524 .44844 .69924 .44648 .69733 .44385 Metetra
.711 .734 .869 r
.69733 .44385 .69924 .44648 .70325 .44457 .70134 .44195 Metetra
.709 .735 .871 r
.70134 .44195 .70325 .44457 .70726 .4427 .70536 .44009 Metetra
.706 .735 .873 r
.70536 .44009 .70726 .4427 .71129 .44087 .70939 .43827 Metetra
.704 .735 .875 r
.70939 .43827 .71129 .44087 .71531 .43906 .71342 .43647 Metetra
.702 .736 .877 r
.71342 .43647 .71531 .43906 .71935 .43729 .71746 .4347 Metetra
.701 .736 .879 r
.71746 .4347 .71935 .43729 .72338 .43553 .7215 .43296 Metetra
.699 .736 .88 r
.7215 .43296 .72338 .43553 .72743 .4338 .72555 .43123 Metetra
.697 .737 .881 r
.72555 .43123 .72743 .4338 .73148 .4321 .72961 .42953 Metetra
.696 .737 .883 r
.72961 .42953 .73148 .4321 .73554 .43041 .73367 .42785 Metetra
.694 .737 .884 r
.73367 .42785 .73554 .43041 .7396 .42874 .73774 .42618 Metetra
.693 .737 .885 r
.73774 .42618 .7396 .42874 .74367 .42708 .74181 .42453 Metetra
.692 .737 .886 r
.74181 .42453 .74367 .42708 .74775 .42544 .74589 .4229 Metetra
.691 .738 .887 r
.74589 .4229 .74775 .42544 .75183 .42382 .74998 .42127 Metetra
.69 .738 .888 r
.74998 .42127 .75183 .42382 .75592 .42221 .75407 .41966 Metetra
.689 .738 .888 r
.75407 .41966 .75592 .42221 .76001 .4206 .75817 .41806 Metetra
.688 .738 .889 r
.75817 .41806 .76001 .4206 .76411 .41901 .76228 .41647 Metetra
.687 .738 .89 r
.76228 .41647 .76411 .41901 .76822 .41743 .76639 .41489 Metetra
.686 .738 .891 r
.76639 .41489 .76822 .41743 .77233 .41586 .7705 .41332 Metetra
.685 .738 .891 r
.7705 .41332 .77233 .41586 .77645 .4143 .77463 .41176 Metetra
.684 .738 .892 r
.77463 .41176 .77645 .4143 .78057 .41274 .77875 .4102 Metetra
.684 .739 .892 r
.77875 .4102 .78057 .41274 .7847 .41119 .78289 .40865 Metetra
.683 .739 .893 r
.78289 .40865 .7847 .41119 .78884 .40965 .78703 .40711 Metetra
.682 .739 .894 r
.78703 .40711 .78884 .40965 .79298 .40811 .79118 .40558 Metetra
.682 .739 .894 r
.79118 .40558 .79298 .40811 .79713 .40658 .79533 .40405 Metetra
.681 .739 .894 r
.79533 .40405 .79713 .40658 .80128 .40506 .79949 .40252 Metetra
.681 .739 .895 r
.79949 .40252 .80128 .40506 .80545 .40354 .80365 .401 Metetra
.68 .739 .895 r
.80365 .401 .80545 .40354 .80961 .40203 .80782 .39949 Metetra
.68 .739 .896 r
.80782 .39949 .80961 .40203 .81378 .40051 .812 .39798 Metetra
.679 .739 .896 r
.812 .39798 .81378 .40051 .81796 .39901 .81618 .39647 Metetra
.679 .739 .896 r
.81618 .39647 .81796 .39901 .82215 .39751 .82037 .39496 Metetra
.678 .739 .897 r
.82037 .39496 .82215 .39751 .82634 .39601 .82457 .39346 Metetra
.678 .739 .897 r
.82457 .39346 .82634 .39601 .83054 .39451 .82877 .39197 Metetra
.677 .739 .897 r
.82877 .39197 .83054 .39451 .83474 .39302 .83298 .39047 Metetra
.677 .739 .898 r
.83298 .39047 .83474 .39302 .83895 .39153 .83719 .38898 Metetra
.677 .739 .898 r
.83719 .38898 .83895 .39153 .84316 .39004 .84141 .38749 Metetra
.676 .739 .898 r
.84141 .38749 .84316 .39004 .84739 .38855 .84564 .386 Metetra
.676 .74 .898 r
.84564 .386 .84739 .38855 .85161 .38707 .84987 .38452 Metetra
.676 .74 .899 r
.84987 .38452 .85161 .38707 .85585 .38559 .85411 .38303 Metetra
.675 .74 .899 r
.85411 .38303 .85585 .38559 .86009 .38411 .85835 .38155 Metetra
.675 .74 .899 r
.85835 .38155 .86009 .38411 .86433 .38263 .86261 .38007 Metetra
.675 .74 .899 r
.86261 .38007 .86433 .38263 .86859 .38115 .86686 .37859 Metetra
.674 .74 .9 r
.86686 .37859 .86859 .38115 .87285 .37968 .87113 .37712 Metetra
.674 .74 .9 r
.87113 .37712 .87285 .37968 .87711 .3782 .8754 .37564 Metetra
.674 .74 .9 r
.8754 .37564 .87711 .3782 .88138 .37673 .87967 .37416 Metetra
.674 .74 .9 r
.87967 .37416 .88138 .37673 .88566 .37526 .88395 .37269 Metetra
.673 .74 .9 r
.88395 .37269 .88566 .37526 .88994 .37379 .88824 .37122 Metetra
.673 .74 .901 r
.88824 .37122 .88994 .37379 .89423 .37232 .89254 .36974 Metetra
.673 .74 .901 r
.89254 .36974 .89423 .37232 .89853 .37085 .89684 .36827 Metetra
.673 .74 .901 r
.89684 .36827 .89853 .37085 .90283 .36938 .90115 .3668 Metetra
.673 .74 .901 r
.90115 .3668 .90283 .36938 .90714 .36791 .90546 .36533 Metetra
.672 .74 .901 r
.90546 .36533 .90714 .36791 .91146 .36644 .90978 .36385 Metetra
.672 .74 .901 r
.90978 .36385 .91146 .36644 .91578 .36497 .91411 .36238 Metetra
.672 .74 .901 r
.91411 .36238 .91578 .36497 .92011 .3635 .91844 .36091 Metetra
.653 .734 .909 r
.33248 .54272 .33469 .54483 .33822 .54382 .33601 .5417 Metetra
.653 .734 .909 r
.33601 .5417 .33822 .54382 .34175 .5428 .33954 .54068 Metetra
.653 .733 .909 r
.33954 .54068 .34175 .5428 .34529 .54179 .34308 .53966 Metetra
.652 .733 .909 r
.34308 .53966 .34529 .54179 .34883 .54077 .34662 .53864 Metetra
.652 .733 .909 r
.34662 .53864 .34883 .54077 .35237 .53976 .35017 .53763 Metetra
.652 .733 .909 r
.35017 .53763 .35237 .53976 .35592 .53875 .35373 .53661 Metetra
.652 .733 .909 r
.35373 .53661 .35592 .53875 .35948 .53774 .35729 .5356 Metetra
.651 .732 .909 r
.35729 .5356 .35948 .53774 .36304 .53673 .36085 .53458 Metetra
.651 .732 .909 r
.36085 .53458 .36304 .53673 .3666 .53572 .36442 .53357 Metetra
.651 .732 .909 r
.36442 .53357 .3666 .53572 .37017 .53472 .36799 .53256 Metetra
.65 .732 .909 r
.36799 .53256 .37017 .53472 .37375 .53371 .37157 .53155 Metetra
.65 .732 .909 r
.37157 .53155 .37375 .53371 .37733 .53271 .37515 .53054 Metetra
.65 .731 .909 r
.37515 .53054 .37733 .53271 .38091 .53171 .37874 .52954 Metetra
.649 .731 .909 r
.37874 .52954 .38091 .53171 .3845 .53071 .38233 .52853 Metetra
.649 .731 .909 r
.38233 .52853 .3845 .53071 .3881 .52971 .38593 .52753 Metetra
.649 .731 .909 r
.38593 .52753 .3881 .52971 .3917 .52871 .38953 .52653 Metetra
.648 .73 .909 r
.38953 .52653 .3917 .52871 .3953 .52772 .39314 .52553 Metetra
.648 .73 .909 r
.39314 .52553 .3953 .52772 .39891 .52673 .39675 .52454 Metetra
.647 .73 .909 r
.39675 .52454 .39891 .52673 .40253 .52574 .40037 .52355 Metetra
.647 .729 .909 r
.40037 .52355 .40253 .52574 .40615 .52476 .40399 .52256 Metetra
.647 .729 .909 r
.40399 .52256 .40615 .52476 .40977 .52377 .40762 .52157 Metetra
.646 .729 .909 r
.40762 .52157 .40977 .52377 .4134 .5228 .41125 .52059 Metetra
.646 .728 .909 r
.41125 .52059 .4134 .5228 .41704 .52182 .41489 .51961 Metetra
.645 .728 .909 r
.41489 .51961 .41704 .52182 .42068 .52085 .41854 .51863 Metetra
.644 .728 .909 r
.41854 .51863 .42068 .52085 .42433 .51988 .42218 .51766 Metetra
.644 .727 .909 r
.42218 .51766 .42433 .51988 .42798 .51892 .42584 .51669 Metetra
.643 .727 .909 r
.42584 .51669 .42798 .51892 .43163 .51796 .4295 .51572 Metetra
.643 .726 .909 r
.4295 .51572 .43163 .51796 .43529 .51701 .43316 .51476 Metetra
.642 .726 .909 r
.43316 .51476 .43529 .51701 .43896 .51606 .43683 .51381 Metetra
.641 .725 .909 r
.43683 .51381 .43896 .51606 .44263 .51511 .4405 .51286 Metetra
.64 .725 .909 r
.4405 .51286 .44263 .51511 .44631 .51418 .44418 .51192 Metetra
.64 .724 .909 r
.44418 .51192 .44631 .51418 .44999 .51325 .44787 .51098 Metetra
.639 .724 .909 r
.44787 .51098 .44999 .51325 .45368 .51232 .45156 .51005 Metetra
.638 .723 .909 r
.45156 .51005 .45368 .51232 .45737 .51141 .45526 .50913 Metetra
.637 .722 .91 r
.45526 .50913 .45737 .51141 .46107 .5105 .45896 .50821 Metetra
.636 .722 .91 r
.45896 .50821 .46107 .5105 .46477 .5096 .46266 .5073 Metetra
.635 .721 .91 r
.46266 .5073 .46477 .5096 .46848 .50871 .46638 .50641 Metetra
.634 .72 .91 r
.46638 .50641 .46848 .50871 .4722 .50783 .47009 .50552 Metetra
.632 .719 .91 r
.47009 .50552 .4722 .50783 .47592 .50696 .47382 .50464 Metetra
.631 .718 .91 r
.47382 .50464 .47592 .50696 .47964 .5061 .47755 .50377 Metetra
.63 .717 .91 r
.47755 .50377 .47964 .5061 .48337 .50525 .48128 .50292 Metetra
.628 .716 .91 r
.48128 .50292 .48337 .50525 .48711 .50442 .48502 .50208 Metetra
.626 .715 .91 r
.48502 .50208 .48711 .50442 .49085 .50361 .48877 .50125 Metetra
.625 .714 .91 r
.48877 .50125 .49085 .50361 .4946 .5028 .49252 .50044 Metetra
.623 .712 .91 r
.49252 .50044 .4946 .5028 .49836 .50202 .49627 .49964 Metetra
.621 .711 .91 r
.49627 .49964 .49836 .50202 .50212 .50125 .50004 .49886 Metetra
.618 .709 .91 r
.50004 .49886 .50212 .50125 .50588 .50051 .50381 .49811 Metetra
.616 .707 .91 r
.50381 .49811 .50588 .50051 .50966 .49979 .50758 .49737 Metetra
.613 .705 .91 r
.50758 .49737 .50966 .49979 .51343 .49909 .51136 .49666 Metetra
.61 .703 .91 r
.51136 .49666 .51343 .49909 .51722 .49842 .51515 .49598 Metetra
.607 .701 .91 r
.51515 .49598 .51722 .49842 .52101 .49778 .51895 .49532 Metetra
.603 .699 .911 r
.51895 .49532 .52101 .49778 .52481 .49718 .52275 .4947 Metetra
.599 .696 .911 r
.52275 .4947 .52481 .49718 .52861 .49661 .52655 .49411 Metetra
.595 .692 .911 r
.52655 .49411 .52861 .49661 .53242 .49608 .53037 .49356 Metetra
.59 .689 .911 r
.53037 .49356 .53242 .49608 .53624 .4956 .53419 .49306 Metetra
.584 .685 .91 r
.53419 .49306 .53624 .4956 .54007 .49517 .53802 .49261 Metetra
.578 .68 .91 r
.53802 .49261 .54007 .49517 .5439 .49481 .54185 .49221 Metetra
.57 .675 .91 r
.54185 .49221 .5439 .49481 .54774 .4945 .54569 .49188 Metetra
.562 .669 .91 r
.54569 .49188 .54774 .4945 .55159 .49428 .54954 .49163 Metetra
.552 .662 .91 r
.54954 .49163 .55159 .49428 .55545 .49415 .5534 .49145 Metetra
.54 .654 .909 r
.5534 .49145 .55545 .49415 .55931 .49412 .55727 .49138 Metetra
.527 .644 .908 r
.55727 .49138 .55931 .49412 .56319 .49421 .56115 .49142 Metetra
.51 .632 .907 r
.56115 .49142 .56319 .49421 .56707 .49444 .56504 .4916 Metetra
.491 .618 .905 r
.56504 .4916 .56707 .49444 .57097 .49485 .56893 .49193 Metetra
.466 .601 .902 r
.56893 .49193 .57097 .49485 .57488 .49546 .57284 .49246 Metetra
.436 .578 .897 r
.57284 .49246 .57488 .49546 .5788 .49634 .57677 .49324 Metetra
.397 .55 .89 r
.57677 .49324 .5788 .49634 .58274 .49753 .5807 .4943 Metetra
.347 .512 .879 r
.5807 .4943 .58274 .49753 .5867 .49913 .58466 .49575 Metetra
.28 .461 .86 r
.58466 .49575 .5867 .49913 .59068 .50127 .58864 .49768 Metetra
.189 .39 .83 r
.58864 .49768 .59068 .50127 .59469 .50414 .59264 .50028 Metetra
.064 .29 .778 r
.59264 .50028 .59469 .50414 .59874 .50804 .59668 .50379 Metetra
.968 .682 .432 r
.59668 .50379 .59874 .50804 .60655 .67219 .60444 .67007 Metetra
.645 .763 .934 r
.60444 .67007 .60655 .67219 .6107 .67104 .6086 .66891 Metetra
.645 .763 .934 r
.6086 .66891 .6107 .67104 .61485 .66989 .61276 .66776 Metetra
.645 .763 .934 r
.61276 .66776 .61485 .66989 .61902 .66874 .61693 .6666 Metetra
.645 .763 .934 r
.61693 .6666 .61902 .66874 .62319 .66758 .6211 .66545 Metetra
.645 .763 .934 r
.6211 .66545 .62319 .66758 .62736 .66642 .62528 .66429 Metetra
.967 .695 .466 r
.62528 .66429 .62736 .66642 .62648 .49954 .62443 .49527 Metetra
.814 .681 .717 r
.62443 .49527 .62648 .49954 .6303 .4932 .62827 .4893 Metetra
.805 .691 .739 r
.62827 .4893 .6303 .4932 .63415 .48788 .63213 .48425 Metetra
.795 .699 .758 r
.63213 .48425 .63415 .48788 .63802 .48328 .63601 .47985 Metetra
.786 .705 .774 r
.63601 .47985 .63802 .48328 .64191 .47922 .63991 .47595 Metetra
.778 .71 .789 r
.63991 .47595 .64191 .47922 .64581 .47557 .64382 .47241 Metetra
.77 .715 .801 r
.64382 .47241 .64581 .47557 .64972 .47225 .64774 .46918 Metetra
.762 .718 .811 r
.64774 .46918 .64972 .47225 .65364 .46917 .65167 .46618 Metetra
.756 .721 .82 r
.65167 .46618 .65364 .46917 .65758 .46631 .65561 .46338 Metetra
.749 .723 .828 r
.65561 .46338 .65758 .46631 .66152 .46361 .65956 .46074 Metetra
.744 .725 .835 r
.65956 .46074 .66152 .46361 .66547 .46106 .66351 .45823 Metetra
.739 .727 .841 r
.66351 .45823 .66547 .46106 .66943 .45863 .66748 .45584 Metetra
.734 .728 .846 r
.66748 .45584 .66943 .45863 .67339 .4563 .67145 .45354 Metetra
.729 .729 .85 r
.67145 .45354 .67339 .4563 .67737 .45406 .67543 .45133 Metetra
.726 .731 .855 r
.67543 .45133 .67737 .45406 .68135 .4519 .67941 .44919 Metetra
.722 .731 .858 r
.67941 .44919 .68135 .4519 .68533 .44981 .6834 .44712 Metetra
.719 .732 .862 r
.6834 .44712 .68533 .44981 .68933 .44777 .6874 .4451 Metetra
.715 .733 .865 r
.6874 .4451 .68933 .44777 .69333 .44579 .69141 .44313 Metetra
.713 .734 .867 r
.69141 .44313 .69333 .44579 .69733 .44385 .69542 .44121 Metetra
.71 .734 .87 r
.69542 .44121 .69733 .44385 .70134 .44195 .69943 .43933 Metetra
.708 .735 .872 r
.69943 .43933 .70134 .44195 .70536 .44009 .70346 .43748 Metetra
.705 .735 .874 r
.70346 .43748 .70536 .44009 .70939 .43827 .70749 .43566 Metetra
.703 .735 .876 r
.70749 .43566 .70939 .43827 .71342 .43647 .71152 .43387 Metetra
.702 .736 .877 r
.71152 .43387 .71342 .43647 .71746 .4347 .71557 .43211 Metetra
.7 .736 .879 r
.71557 .43211 .71746 .4347 .7215 .43296 .71962 .43037 Metetra
.698 .736 .88 r
.71962 .43037 .7215 .43296 .72555 .43123 .72367 .42866 Metetra
.697 .737 .882 r
.72367 .42866 .72555 .43123 .72961 .42953 .72773 .42696 Metetra
.695 .737 .883 r
.72773 .42696 .72961 .42953 .73367 .42785 .7318 .42528 Metetra
.694 .737 .884 r
.7318 .42528 .73367 .42785 .73774 .42618 .73587 .42362 Metetra
.693 .737 .885 r
.73587 .42362 .73774 .42618 .74181 .42453 .73995 .42197 Metetra
.691 .737 .886 r
.73995 .42197 .74181 .42453 .74589 .4229 .74403 .42034 Metetra
.69 .738 .887 r
.74403 .42034 .74589 .4229 .74998 .42127 .74812 .41872 Metetra
.689 .738 .888 r
.74812 .41872 .74998 .42127 .75407 .41966 .75222 .41711 Metetra
.688 .738 .889 r
.75222 .41711 .75407 .41966 .75817 .41806 .75632 .41551 Metetra
.687 .738 .889 r
.75632 .41551 .75817 .41806 .76228 .41647 .76043 .41392 Metetra
.686 .738 .89 r
.76043 .41392 .76228 .41647 .76639 .41489 .76455 .41235 Metetra
.686 .738 .891 r
.76455 .41235 .76639 .41489 .7705 .41332 .76867 .41078 Metetra
.685 .738 .891 r
.76867 .41078 .7705 .41332 .77463 .41176 .7728 .40921 Metetra
.684 .738 .892 r
.7728 .40921 .77463 .41176 .77875 .4102 .77693 .40766 Metetra
.683 .738 .893 r
.77693 .40766 .77875 .4102 .78289 .40865 .78107 .40611 Metetra
.683 .739 .893 r
.78107 .40611 .78289 .40865 .78703 .40711 .78521 .40457 Metetra
.682 .739 .894 r
.78521 .40457 .78703 .40711 .79118 .40558 .78937 .40303 Metetra
.681 .739 .894 r
.78937 .40303 .79118 .40558 .79533 .40405 .79352 .4015 Metetra
.681 .739 .895 r
.79352 .4015 .79533 .40405 .79949 .40252 .79769 .39998 Metetra
.68 .739 .895 r
.79769 .39998 .79949 .40252 .80365 .401 .80186 .39846 Metetra
.68 .739 .895 r
.80186 .39846 .80365 .401 .80782 .39949 .80603 .39694 Metetra
.679 .739 .896 r
.80603 .39694 .80782 .39949 .812 .39798 .81021 .39543 Metetra
.679 .739 .896 r
.81021 .39543 .812 .39798 .81618 .39647 .8144 .39392 Metetra
.678 .739 .897 r
.8144 .39392 .81618 .39647 .82037 .39496 .81859 .39242 Metetra
.678 .739 .897 r
.81859 .39242 .82037 .39496 .82457 .39346 .82279 .39092 Metetra
.678 .739 .897 r
.82279 .39092 .82457 .39346 .82877 .39197 .827 .38942 Metetra
.677 .739 .897 r
.827 .38942 .82877 .39197 .83298 .39047 .83121 .38792 Metetra
.677 .739 .898 r
.83121 .38792 .83298 .39047 .83719 .38898 .83543 .38643 Metetra
.676 .739 .898 r
.83543 .38643 .83719 .38898 .84141 .38749 .83966 .38494 Metetra
.676 .739 .898 r
.83966 .38494 .84141 .38749 .84564 .386 .84389 .38345 Metetra
.676 .739 .899 r
.84389 .38345 .84564 .386 .84987 .38452 .84812 .38196 Metetra
.675 .74 .899 r
.84812 .38196 .84987 .38452 .85411 .38303 .85237 .38047 Metetra
.675 .74 .899 r
.85237 .38047 .85411 .38303 .85835 .38155 .85662 .37899 Metetra
.675 .74 .899 r
.85662 .37899 .85835 .38155 .86261 .38007 .86087 .37751 Metetra
.675 .74 .899 r
.86087 .37751 .86261 .38007 .86686 .37859 .86513 .37603 Metetra
.674 .74 .9 r
.86513 .37603 .86686 .37859 .87113 .37712 .8694 .37455 Metetra
.674 .74 .9 r
.8694 .37455 .87113 .37712 .8754 .37564 .87368 .37307 Metetra
.674 .74 .9 r
.87368 .37307 .8754 .37564 .87967 .37416 .87796 .37159 Metetra
.674 .74 .9 r
.87796 .37159 .87967 .37416 .88395 .37269 .88224 .37011 Metetra
.673 .74 .9 r
.88224 .37011 .88395 .37269 .88824 .37122 .88654 .36864 Metetra
.673 .74 .901 r
.88654 .36864 .88824 .37122 .89254 .36974 .89084 .36716 Metetra
.673 .74 .901 r
.89084 .36716 .89254 .36974 .89684 .36827 .89514 .36569 Metetra
.673 .74 .901 r
.89514 .36569 .89684 .36827 .90115 .3668 .89945 .36421 Metetra
.672 .74 .901 r
.89945 .36421 .90115 .3668 .90546 .36533 .90377 .36274 Metetra
.672 .74 .901 r
.90377 .36274 .90546 .36533 .90978 .36385 .9081 .36126 Metetra
.672 .74 .901 r
.9081 .36126 .90978 .36385 .91411 .36238 .91243 .35979 Metetra
.672 .74 .901 r
.91243 .35979 .91411 .36238 .91844 .36091 .91677 .35832 Metetra
.653 .734 .909 r
.33026 .5406 .33248 .54272 .33601 .5417 .33379 .53957 Metetra
.653 .734 .909 r
.33379 .53957 .33601 .5417 .33954 .54068 .33733 .53855 Metetra
.653 .733 .909 r
.33733 .53855 .33954 .54068 .34308 .53966 .34087 .53753 Metetra
.652 .733 .909 r
.34087 .53753 .34308 .53966 .34662 .53864 .34442 .53651 Metetra
.652 .733 .909 r
.34442 .53651 .34662 .53864 .35017 .53763 .34797 .53549 Metetra
.652 .733 .909 r
.34797 .53549 .35017 .53763 .35373 .53661 .35153 .53447 Metetra
.652 .733 .909 r
.35153 .53447 .35373 .53661 .35729 .5356 .35509 .53345 Metetra
.651 .733 .909 r
.35509 .53345 .35729 .5356 .36085 .53458 .35865 .53243 Metetra
.651 .732 .909 r
.35865 .53243 .36085 .53458 .36442 .53357 .36222 .53142 Metetra
.651 .732 .909 r
.36222 .53142 .36442 .53357 .36799 .53256 .3658 .5304 Metetra
.651 .732 .909 r
.3658 .5304 .36799 .53256 .37157 .53155 .36938 .52939 Metetra
.65 .732 .909 r
.36938 .52939 .37157 .53155 .37515 .53054 .37297 .52838 Metetra
.65 .731 .909 r
.37297 .52838 .37515 .53054 .37874 .52954 .37656 .52737 Metetra
.65 .731 .909 r
.37656 .52737 .37874 .52954 .38233 .52853 .38015 .52636 Metetra
.649 .731 .909 r
.38015 .52636 .38233 .52853 .38593 .52753 .38375 .52535 Metetra
.649 .731 .909 r
.38375 .52535 .38593 .52753 .38953 .52653 .38736 .52435 Metetra
.649 .73 .909 r
.38736 .52435 .38953 .52653 .39314 .52553 .39097 .52334 Metetra
.648 .73 .909 r
.39097 .52334 .39314 .52553 .39675 .52454 .39459 .52234 Metetra
.648 .73 .909 r
.39459 .52234 .39675 .52454 .40037 .52355 .39821 .52135 Metetra
.647 .73 .909 r
.39821 .52135 .40037 .52355 .40399 .52256 .40183 .52035 Metetra
.647 .729 .909 r
.40183 .52035 .40399 .52256 .40762 .52157 .40546 .51936 Metetra
.646 .729 .909 r
.40546 .51936 .40762 .52157 .41125 .52059 .4091 .51837 Metetra
.646 .729 .909 r
.4091 .51837 .41125 .52059 .41489 .51961 .41274 .51739 Metetra
.645 .728 .909 r
.41274 .51739 .41489 .51961 .41854 .51863 .41639 .5164 Metetra
.645 .728 .909 r
.41639 .5164 .41854 .51863 .42218 .51766 .42004 .51542 Metetra
.644 .727 .909 r
.42004 .51542 .42218 .51766 .42584 .51669 .42369 .51445 Metetra
.644 .727 .909 r
.42369 .51445 .42584 .51669 .4295 .51572 .42736 .51348 Metetra
.643 .726 .909 r
.42736 .51348 .4295 .51572 .43316 .51476 .43102 .51252 Metetra
.642 .726 .909 r
.43102 .51252 .43316 .51476 .43683 .51381 .4347 .51155 Metetra
.642 .725 .909 r
.4347 .51155 .43683 .51381 .4405 .51286 .43837 .5106 Metetra
.641 .725 .909 r
.43837 .5106 .4405 .51286 .44418 .51192 .44206 .50965 Metetra
.64 .724 .909 r
.44206 .50965 .44418 .51192 .44787 .51098 .44574 .50871 Metetra
.639 .724 .909 r
.44574 .50871 .44787 .51098 .45156 .51005 .44944 .50777 Metetra
.638 .723 .909 r
.44944 .50777 .45156 .51005 .45526 .50913 .45314 .50684 Metetra
.637 .723 .909 r
.45314 .50684 .45526 .50913 .45896 .50821 .45684 .50592 Metetra
.636 .722 .909 r
.45684 .50592 .45896 .50821 .46266 .5073 .46055 .505 Metetra
.635 .721 .909 r
.46055 .505 .46266 .5073 .46638 .50641 .46427 .5041 Metetra
.634 .72 .91 r
.46427 .5041 .46638 .50641 .47009 .50552 .46799 .5032 Metetra
.633 .719 .91 r
.46799 .5032 .47009 .50552 .47382 .50464 .47171 .50231 Metetra
.632 .718 .91 r
.47171 .50231 .47382 .50464 .47755 .50377 .47544 .50144 Metetra
.63 .717 .91 r
.47544 .50144 .47755 .50377 .48128 .50292 .47918 .50058 Metetra
.629 .716 .91 r
.47918 .50058 .48128 .50292 .48502 .50208 .48292 .49972 Metetra
.627 .715 .91 r
.48292 .49972 .48502 .50208 .48877 .50125 .48667 .49889 Metetra
.626 .714 .91 r
.48667 .49889 .48877 .50125 .49252 .50044 .49043 .49807 Metetra
.624 .713 .91 r
.49043 .49807 .49252 .50044 .49627 .49964 .49419 .49726 Metetra
.622 .711 .91 r
.49419 .49726 .49627 .49964 .50004 .49886 .49795 .49647 Metetra
.619 .71 .91 r
.49795 .49647 .50004 .49886 .50381 .49811 .50173 .4957 Metetra
.617 .708 .91 r
.50173 .4957 .50381 .49811 .50758 .49737 .5055 .49495 Metetra
.614 .706 .91 r
.5055 .49495 .50758 .49737 .51136 .49666 .50929 .49423 Metetra
.612 .704 .91 r
.50929 .49423 .51136 .49666 .51515 .49598 .51308 .49353 Metetra
.608 .702 .91 r
.51308 .49353 .51515 .49598 .51895 .49532 .51688 .49286 Metetra
.605 .699 .91 r
.51688 .49286 .51895 .49532 .52275 .4947 .52068 .49222 Metetra
.601 .697 .91 r
.52068 .49222 .52275 .4947 .52655 .49411 .52449 .49161 Metetra
.597 .694 .91 r
.52449 .49161 .52655 .49411 .53037 .49356 .52831 .49105 Metetra
.592 .69 .91 r
.52831 .49105 .53037 .49356 .53419 .49306 .53213 .49052 Metetra
.586 .686 .91 r
.53213 .49052 .53419 .49306 .53802 .49261 .53596 .49004 Metetra
.58 .682 .91 r
.53596 .49004 .53802 .49261 .54185 .49221 .5398 .48962 Metetra
.573 .677 .91 r
.5398 .48962 .54185 .49221 .54569 .49188 .54364 .48926 Metetra
.565 .671 .91 r
.54364 .48926 .54569 .49188 .54954 .49163 .5475 .48897 Metetra
.556 .664 .909 r
.5475 .48897 .54954 .49163 .5534 .49145 .55136 .48876 Metetra
.545 .657 .909 r
.55136 .48876 .5534 .49145 .55727 .49138 .55523 .48864 Metetra
.532 .648 .908 r
.55523 .48864 .55727 .49138 .56115 .49142 .55911 .48864 Metetra
.517 .637 .907 r
.55911 .48864 .56115 .49142 .56504 .4916 .56299 .48875 Metetra
.499 .623 .905 r
.56299 .48875 .56504 .4916 .56893 .49193 .56689 .48903 Metetra
.476 .607 .902 r
.56689 .48903 .56893 .49193 .57284 .49246 .5708 .48948 Metetra
.449 .587 .898 r
.5708 .48948 .57284 .49246 .57677 .49324 .57473 .49015 Metetra
.413 .56 .892 r
.57473 .49015 .57677 .49324 .5807 .4943 .57866 .4911 Metetra
.368 .526 .882 r
.57866 .4911 .5807 .4943 .58466 .49575 .58262 .4924 Metetra
.308 .481 .867 r
.58262 .4924 .58466 .49575 .58864 .49768 .58659 .49415 Metetra
.227 .418 .842 r
.58659 .49415 .58864 .49768 .59264 .50028 .59059 .49649 Metetra
.116 .33 .799 r
.59059 .49649 .59264 .50028 .59668 .50379 .59462 .49964 Metetra
.968 .682 .433 r
.59462 .49964 .59668 .50379 .60444 .67007 .60233 .66794 Metetra
.645 .763 .934 r
.60233 .66794 .60444 .67007 .6086 .66891 .60649 .66678 Metetra
.645 .763 .934 r
.60649 .66678 .6086 .66891 .61276 .66776 .61066 .66562 Metetra
.645 .763 .934 r
.61066 .66562 .61276 .66776 .61693 .6666 .61483 .66446 Metetra
.645 .763 .934 r
.61483 .66446 .61693 .6666 .6211 .66545 .61901 .6633 Metetra
.645 .763 .934 r
.61901 .6633 .6211 .66545 .62528 .66429 .62319 .66214 Metetra
.967 .695 .465 r
.62319 .66214 .62528 .66429 .62443 .49527 .62238 .49109 Metetra
.81 .683 .724 r
.62238 .49109 .62443 .49527 .62827 .4893 .62624 .48547 Metetra
.801 .693 .745 r
.62624 .48547 .62827 .4893 .63213 .48425 .63011 .48067 Metetra
.792 .7 .764 r
.63011 .48067 .63213 .48425 .63601 .47985 .634 .47646 Metetra
.783 .706 .779 r
.634 .47646 .63601 .47985 .63991 .47595 .63791 .47269 Metetra
.774 .711 .793 r
.63791 .47269 .63991 .47595 .64382 .47241 .64183 .46927 Metetra
.767 .715 .804 r
.64183 .46927 .64382 .47241 .64774 .46918 .64575 .46613 Metetra
.759 .718 .814 r
.64575 .46613 .64774 .46918 .65167 .46618 .64969 .4632 Metetra
.753 .721 .823 r
.64969 .4632 .65167 .46618 .65561 .46338 .65364 .46046 Metetra
.747 .723 .83 r
.65364 .46046 .65561 .46338 .65956 .46074 .65759 .45787 Metetra
.741 .725 .837 r
.65759 .45787 .65956 .46074 .66351 .45823 .66155 .4554 Metetra
.736 .727 .842 r
.66155 .4554 .66351 .45823 .66748 .45584 .66552 .45305 Metetra
.732 .728 .847 r
.66552 .45305 .66748 .45584 .67145 .45354 .6695 .45078 Metetra
.728 .729 .852 r
.6695 .45078 .67145 .45354 .67543 .45133 .67348 .4486 Metetra
.724 .73 .856 r
.67348 .4486 .67543 .45133 .67941 .44919 .67747 .44648 Metetra
.72 .731 .859 r
.67747 .44648 .67941 .44919 .6834 .44712 .68147 .44443 Metetra
.717 .732 .863 r
.68147 .44443 .6834 .44712 .6874 .4451 .68547 .44243 Metetra
.714 .733 .865 r
.68547 .44243 .6874 .4451 .69141 .44313 .68948 .44048 Metetra
.712 .733 .868 r
.68948 .44048 .69141 .44313 .69542 .44121 .6935 .43857 Metetra
.709 .734 .87 r
.6935 .43857 .69542 .44121 .69943 .43933 .69752 .4367 Metetra
.707 .734 .873 r
.69752 .4367 .69943 .43933 .70346 .43748 .70155 .43486 Metetra
.705 .735 .875 r
.70155 .43486 .70346 .43748 .70749 .43566 .70558 .43305 Metetra
.703 .735 .876 r
.70558 .43305 .70749 .43566 .71152 .43387 .70962 .43127 Metetra
.701 .736 .878 r
.70962 .43127 .71152 .43387 .71557 .43211 .71367 .42952 Metetra
.699 .736 .879 r
.71367 .42952 .71557 .43211 .71962 .43037 .71772 .42779 Metetra
.697 .736 .881 r
.71772 .42779 .71962 .43037 .72367 .42866 .72178 .42608 Metetra
.696 .736 .882 r
.72178 .42608 .72367 .42866 .72773 .42696 .72585 .42439 Metetra
.695 .737 .883 r
.72585 .42439 .72773 .42696 .7318 .42528 .72992 .42271 Metetra
.693 .737 .884 r
.72992 .42271 .7318 .42528 .73587 .42362 .734 .42105 Metetra
.692 .737 .886 r
.734 .42105 .73587 .42362 .73995 .42197 .73808 .41941 Metetra
.691 .737 .886 r
.73808 .41941 .73995 .42197 .74403 .42034 .74217 .41778 Metetra
.69 .737 .887 r
.74217 .41778 .74403 .42034 .74812 .41872 .74626 .41616 Metetra
.689 .738 .888 r
.74626 .41616 .74812 .41872 .75222 .41711 .75037 .41456 Metetra
.688 .738 .889 r
.75037 .41456 .75222 .41711 .75632 .41551 .75447 .41296 Metetra
.687 .738 .89 r
.75447 .41296 .75632 .41551 .76043 .41392 .75859 .41137 Metetra
.686 .738 .89 r
.75859 .41137 .76043 .41392 .76455 .41235 .76271 .4098 Metetra
.685 .738 .891 r
.76271 .4098 .76455 .41235 .76867 .41078 .76683 .40823 Metetra
.684 .738 .892 r
.76683 .40823 .76867 .41078 .7728 .40921 .77096 .40667 Metetra
.684 .738 .892 r
.77096 .40667 .7728 .40921 .77693 .40766 .7751 .40511 Metetra
.683 .738 .893 r
.7751 .40511 .77693 .40766 .78107 .40611 .77925 .40356 Metetra
.682 .739 .893 r
.77925 .40356 .78107 .40611 .78521 .40457 .78339 .40202 Metetra
.682 .739 .894 r
.78339 .40202 .78521 .40457 .78937 .40303 .78755 .40049 Metetra
.681 .739 .894 r
.78755 .40049 .78937 .40303 .79352 .4015 .79171 .39896 Metetra
.681 .739 .895 r
.79171 .39896 .79352 .4015 .79769 .39998 .79588 .39743 Metetra
.68 .739 .895 r
.79588 .39743 .79769 .39998 .80186 .39846 .80005 .39591 Metetra
.68 .739 .896 r
.80005 .39591 .80186 .39846 .80603 .39694 .80423 .39439 Metetra
.679 .739 .896 r
.80423 .39439 .80603 .39694 .81021 .39543 .80842 .39288 Metetra
.679 .739 .896 r
.80842 .39288 .81021 .39543 .8144 .39392 .81261 .39137 Metetra
.678 .739 .897 r
.81261 .39137 .8144 .39392 .81859 .39242 .81681 .38986 Metetra
.678 .739 .897 r
.81681 .38986 .81859 .39242 .82279 .39092 .82102 .38836 Metetra
.677 .739 .897 r
.82102 .38836 .82279 .39092 .827 .38942 .82523 .38686 Metetra
.677 .739 .898 r
.82523 .38686 .827 .38942 .83121 .38792 .82944 .38536 Metetra
.677 .739 .898 r
.82944 .38536 .83121 .38792 .83543 .38643 .83367 .38387 Metetra
.676 .739 .898 r
.83367 .38387 .83543 .38643 .83966 .38494 .8379 .38237 Metetra
.676 .739 .898 r
.8379 .38237 .83966 .38494 .84389 .38345 .84213 .38088 Metetra
.676 .739 .899 r
.84213 .38088 .84389 .38345 .84812 .38196 .84637 .37939 Metetra
.675 .739 .899 r
.84637 .37939 .84812 .38196 .85237 .38047 .85062 .37791 Metetra
.675 .74 .899 r
.85062 .37791 .85237 .38047 .85662 .37899 .85487 .37642 Metetra
.675 .74 .899 r
.85487 .37642 .85662 .37899 .86087 .37751 .85913 .37494 Metetra
.674 .74 .9 r
.85913 .37494 .86087 .37751 .86513 .37603 .8634 .37345 Metetra
.674 .74 .9 r
.8634 .37345 .86513 .37603 .8694 .37455 .86767 .37197 Metetra
.674 .74 .9 r
.86767 .37197 .8694 .37455 .87368 .37307 .87195 .37049 Metetra
.674 .74 .9 r
.87195 .37049 .87368 .37307 .87796 .37159 .87624 .36901 Metetra
.673 .74 .9 r
.87624 .36901 .87796 .37159 .88224 .37011 .88053 .36753 Metetra
.673 .74 .9 r
.88053 .36753 .88224 .37011 .88654 .36864 .88483 .36605 Metetra
.673 .74 .901 r
.88483 .36605 .88654 .36864 .89084 .36716 .88913 .36458 Metetra
.673 .74 .901 r
.88913 .36458 .89084 .36716 .89514 .36569 .89344 .3631 Metetra
.673 .74 .901 r
.89344 .3631 .89514 .36569 .89945 .36421 .89776 .36162 Metetra
.672 .74 .901 r
.89776 .36162 .89945 .36421 .90377 .36274 .90208 .36014 Metetra
.672 .74 .901 r
.90208 .36014 .90377 .36274 .9081 .36126 .90641 .35867 Metetra
.672 .74 .901 r
.90641 .35867 .9081 .36126 .91243 .35979 .91075 .35719 Metetra
.672 .74 .902 r
.91075 .35719 .91243 .35979 .91677 .35832 .91509 .35571 Metetra
.653 .734 .909 r
.32804 .53847 .33026 .5406 .33379 .53957 .33157 .53744 Metetra
.653 .734 .909 r
.33157 .53744 .33379 .53957 .33733 .53855 .33511 .53642 Metetra
.653 .734 .909 r
.33511 .53642 .33733 .53855 .34087 .53753 .33866 .53539 Metetra
.653 .733 .909 r
.33866 .53539 .34087 .53753 .34442 .53651 .3422 .53437 Metetra
.652 .733 .909 r
.3422 .53437 .34442 .53651 .34797 .53549 .34576 .53334 Metetra
.652 .733 .909 r
.34576 .53334 .34797 .53549 .35153 .53447 .34932 .53232 Metetra
.652 .733 .909 r
.34932 .53232 .35153 .53447 .35509 .53345 .35288 .5313 Metetra
.652 .733 .909 r
.35288 .5313 .35509 .53345 .35865 .53243 .35645 .53028 Metetra
.651 .732 .909 r
.35645 .53028 .35865 .53243 .36222 .53142 .36003 .52926 Metetra
.651 .732 .909 r
.36003 .52926 .36222 .53142 .3658 .5304 .3636 .52824 Metetra
.651 .732 .909 r
.3636 .52824 .3658 .5304 .36938 .52939 .36719 .52722 Metetra
.65 .732 .909 r
.36719 .52722 .36938 .52939 .37297 .52838 .37078 .5262 Metetra
.65 .732 .909 r
.37078 .5262 .37297 .52838 .37656 .52737 .37437 .52519 Metetra
.65 .731 .909 r
.37437 .52519 .37656 .52737 .38015 .52636 .37797 .52418 Metetra
.649 .731 .909 r
.37797 .52418 .38015 .52636 .38375 .52535 .38157 .52316 Metetra
.649 .731 .909 r
.38157 .52316 .38375 .52535 .38736 .52435 .38518 .52216 Metetra
.649 .731 .909 r
.38518 .52216 .38736 .52435 .39097 .52334 .38879 .52115 Metetra
.648 .73 .909 r
.38879 .52115 .39097 .52334 .39459 .52234 .39241 .52014 Metetra
.648 .73 .909 r
.39241 .52014 .39459 .52234 .39821 .52135 .39604 .51914 Metetra
.647 .73 .909 r
.39604 .51914 .39821 .52135 .40183 .52035 .39967 .51814 Metetra
.647 .729 .909 r
.39967 .51814 .40183 .52035 .40546 .51936 .4033 .51714 Metetra
.647 .729 .909 r
.4033 .51714 .40546 .51936 .4091 .51837 .40694 .51615 Metetra
.646 .729 .909 r
.40694 .51615 .4091 .51837 .41274 .51739 .41058 .51516 Metetra
.646 .728 .909 r
.41058 .51516 .41274 .51739 .41639 .5164 .41423 .51417 Metetra
.645 .728 .909 r
.41423 .51417 .41639 .5164 .42004 .51542 .41789 .51319 Metetra
.644 .727 .909 r
.41789 .51319 .42004 .51542 .42369 .51445 .42155 .51221 Metetra
.644 .727 .909 r
.42155 .51221 .42369 .51445 .42736 .51348 .42521 .51123 Metetra
.643 .727 .909 r
.42521 .51123 .42736 .51348 .43102 .51252 .42888 .51026 Metetra
.643 .726 .909 r
.42888 .51026 .43102 .51252 .4347 .51155 .43256 .5093 Metetra
.642 .726 .909 r
.43256 .5093 .4347 .51155 .43837 .5106 .43624 .50833 Metetra
.641 .725 .909 r
.43624 .50833 .43837 .5106 .44206 .50965 .43992 .50738 Metetra
.64 .725 .909 r
.43992 .50738 .44206 .50965 .44574 .50871 .44361 .50643 Metetra
.64 .724 .909 r
.44361 .50643 .44574 .50871 .44944 .50777 .44731 .50549 Metetra
.639 .723 .909 r
.44731 .50549 .44944 .50777 .45314 .50684 .45101 .50455 Metetra
.638 .723 .909 r
.45101 .50455 .45314 .50684 .45684 .50592 .45472 .50362 Metetra
.637 .722 .909 r
.45472 .50362 .45684 .50592 .46055 .505 .45843 .5027 Metetra
.636 .721 .909 r
.45843 .5027 .46055 .505 .46427 .5041 .46215 .50178 Metetra
.635 .72 .909 r
.46215 .50178 .46427 .5041 .46799 .5032 .46587 .50088 Metetra
.634 .72 .909 r
.46587 .50088 .46799 .5032 .47171 .50231 .4696 .49999 Metetra
.632 .719 .91 r
.4696 .49999 .47171 .50231 .47544 .50144 .47334 .4991 Metetra
.631 .718 .91 r
.47334 .4991 .47544 .50144 .47918 .50058 .47708 .49823 Metetra
.63 .717 .91 r
.47708 .49823 .47918 .50058 .48292 .49972 .48082 .49737 Metetra
.628 .716 .91 r
.48082 .49737 .48292 .49972 .48667 .49889 .48458 .49652 Metetra
.626 .714 .91 r
.48458 .49652 .48667 .49889 .49043 .49807 .48833 .49569 Metetra
.625 .713 .91 r
.48833 .49569 .49043 .49807 .49419 .49726 .4921 .49487 Metetra
.623 .712 .91 r
.4921 .49487 .49419 .49726 .49795 .49647 .49587 .49407 Metetra
.62 .71 .91 r
.49587 .49407 .49795 .49647 .50173 .4957 .49964 .49329 Metetra
.618 .709 .91 r
.49964 .49329 .50173 .4957 .5055 .49495 .50342 .49253 Metetra
.616 .707 .91 r
.50342 .49253 .5055 .49495 .50929 .49423 .50721 .49179 Metetra
.613 .705 .91 r
.50721 .49179 .50929 .49423 .51308 .49353 .511 .49108 Metetra
.61 .703 .91 r
.511 .49108 .51308 .49353 .51688 .49286 .5148 .49039 Metetra
.606 .7 .91 r
.5148 .49039 .51688 .49286 .52068 .49222 .51861 .48974 Metetra
.603 .698 .91 r
.51861 .48974 .52068 .49222 .52449 .49161 .52242 .48911 Metetra
.599 .695 .91 r
.52242 .48911 .52449 .49161 .52831 .49105 .52624 .48852 Metetra
.594 .691 .91 r
.52624 .48852 .52831 .49105 .53213 .49052 .53007 .48798 Metetra
.589 .688 .91 r
.53007 .48798 .53213 .49052 .53596 .49004 .5339 .48748 Metetra
.583 .683 .91 r
.5339 .48748 .53596 .49004 .5398 .48962 .53774 .48703 Metetra
.576 .679 .91 r
.53774 .48703 .5398 .48962 .54364 .48926 .54159 .48664 Metetra
.569 .673 .909 r
.54159 .48664 .54364 .48926 .5475 .48897 .54544 .48632 Metetra
.56 .667 .909 r
.54544 .48632 .5475 .48897 .55136 .48876 .54931 .48607 Metetra
.55 .66 .909 r
.54931 .48607 .55136 .48876 .55523 .48864 .55318 .48591 Metetra
.538 .651 .908 r
.55318 .48591 .55523 .48864 .55911 .48864 .55706 .48586 Metetra
.524 .641 .907 r
.55706 .48586 .55911 .48864 .56299 .48875 .56095 .48592 Metetra
.507 .628 .905 r
.56095 .48592 .56299 .48875 .56689 .48903 .56485 .48613 Metetra
.486 .613 .903 r
.56485 .48613 .56689 .48903 .5708 .48948 .56876 .48651 Metetra
.46 .594 .899 r
.56876 .48651 .5708 .48948 .57473 .49015 .57268 .48709 Metetra
.428 .57 .894 r
.57268 .48709 .57473 .49015 .57866 .4911 .57662 .48793 Metetra
.387 .54 .886 r
.57662 .48793 .57866 .4911 .58262 .4924 .58057 .48909 Metetra
.333 .499 .873 r
.58057 .48909 .58262 .4924 .58659 .49415 .58455 .49065 Metetra
.261 .443 .852 r
.58455 .49065 .58659 .49415 .59059 .49649 .58854 .49276 Metetra
.163 .365 .816 r
.58854 .49276 .59059 .49649 .59462 .49964 .59256 .49559 Metetra
.968 .682 .433 r
.59256 .49559 .59462 .49964 .60233 .66794 .60021 .6658 Metetra
.645 .763 .934 r
.60021 .6658 .60233 .66794 .60649 .66678 .60438 .66464 Metetra
.645 .763 .934 r
.60438 .66464 .60649 .66678 .61066 .66562 .60855 .66348 Metetra
.645 .763 .934 r
.60855 .66348 .61066 .66562 .61483 .66446 .61272 .66232 Metetra
.645 .763 .934 r
.61272 .66232 .61483 .66446 .61901 .6633 .61691 .66116 Metetra
.645 .763 .934 r
.61691 .66116 .61901 .6633 .62319 .66214 .62109 .65999 Metetra
.967 .695 .465 r
.62109 .65999 .62319 .66214 .62238 .49109 .62033 .48702 Metetra
.806 .685 .731 r
.62033 .48702 .62238 .49109 .62624 .48547 .6242 .48171 Metetra
.797 .694 .752 r
.6242 .48171 .62624 .48547 .63011 .48067 .62809 .47714 Metetra
.788 .701 .769 r
.62809 .47714 .63011 .48067 .634 .47646 .63199 .4731 Metetra
.779 .707 .784 r
.63199 .4731 .634 .47646 .63791 .47269 .6359 .46946 Metetra
.771 .712 .796 r
.6359 .46946 .63791 .47269 .64183 .46927 .63983 .46615 Metetra
.764 .715 .807 r
.63983 .46615 .64183 .46927 .64575 .46613 .64376 .46309 Metetra
.757 .719 .817 r
.64376 .46309 .64575 .46613 .64969 .4632 .64771 .46023 Metetra
.75 .721 .825 r
.64771 .46023 .64969 .4632 .65364 .46046 .65166 .45755 Metetra
.745 .724 .832 r
.65166 .45755 .65364 .46046 .65759 .45787 .65562 .45501 Metetra
.739 .725 .839 r
.65562 .45501 .65759 .45787 .66155 .4554 .65959 .45258 Metetra
.735 .727 .844 r
.65959 .45258 .66155 .4554 .66552 .45305 .66356 .45026 Metetra
.73 .728 .849 r
.66356 .45026 .66552 .45305 .6695 .45078 .66754 .44803 Metetra
.726 .729 .853 r
.66754 .44803 .6695 .45078 .67348 .4486 .67153 .44587 Metetra
.722 .73 .857 r
.67153 .44587 .67348 .4486 .67747 .44648 .67553 .44378 Metetra
.719 .731 .86 r
.67553 .44378 .67747 .44648 .68147 .44443 .67953 .44174 Metetra
.716 .732 .864 r
.67953 .44174 .68147 .44443 .68547 .44243 .68354 .43976 Metetra
.713 .733 .866 r
.68354 .43976 .68547 .44243 .68948 .44048 .68755 .43782 Metetra
.71 .733 .869 r
.68755 .43782 .68948 .44048 .6935 .43857 .69157 .43593 Metetra
.708 .734 .871 r
.69157 .43593 .6935 .43857 .69752 .4367 .6956 .43407 Metetra
.706 .734 .873 r
.6956 .43407 .69752 .4367 .70155 .43486 .69963 .43224 Metetra
.704 .735 .875 r
.69963 .43224 .70155 .43486 .70558 .43305 .70367 .43044 Metetra
.702 .735 .877 r
.70367 .43044 .70558 .43305 .70962 .43127 .70772 .42867 Metetra
.7 .736 .878 r
.70772 .42867 .70962 .43127 .71367 .42952 .71177 .42692 Metetra
.698 .736 .88 r
.71177 .42692 .71367 .42952 .71772 .42779 .71583 .4252 Metetra
.697 .736 .881 r
.71583 .4252 .71772 .42779 .72178 .42608 .71989 .42349 Metetra
.695 .736 .883 r
.71989 .42349 .72178 .42608 .72585 .42439 .72396 .42181 Metetra
.694 .737 .884 r
.72396 .42181 .72585 .42439 .72992 .42271 .72804 .42014 Metetra
.693 .737 .885 r
.72804 .42014 .72992 .42271 .734 .42105 .73212 .41848 Metetra
.691 .737 .886 r
.73212 .41848 .734 .42105 .73808 .41941 .73621 .41684 Metetra
.69 .737 .887 r
.73621 .41684 .73808 .41941 .74217 .41778 .7403 .41521 Metetra
.689 .737 .888 r
.7403 .41521 .74217 .41778 .74626 .41616 .7444 .4136 Metetra
.688 .738 .888 r
.7444 .4136 .74626 .41616 .75037 .41456 .74851 .41199 Metetra
.687 .738 .889 r
.74851 .41199 .75037 .41456 .75447 .41296 .75262 .4104 Metetra
.686 .738 .89 r
.75262 .4104 .75447 .41296 .75859 .41137 .75674 .40882 Metetra
.686 .738 .891 r
.75674 .40882 .75859 .41137 .76271 .4098 .76086 .40724 Metetra
.685 .738 .891 r
.76086 .40724 .76271 .4098 .76683 .40823 .76499 .40567 Metetra
.684 .738 .892 r
.76499 .40567 .76683 .40823 .77096 .40667 .76913 .40411 Metetra
.683 .738 .892 r
.76913 .40411 .77096 .40667 .7751 .40511 .77327 .40256 Metetra
.683 .738 .893 r
.77327 .40256 .7751 .40511 .77925 .40356 .77742 .40101 Metetra
.682 .738 .893 r
.77742 .40101 .77925 .40356 .78339 .40202 .78157 .39947 Metetra
.681 .739 .894 r
.78157 .39947 .78339 .40202 .78755 .40049 .78573 .39793 Metetra
.681 .739 .894 r
.78573 .39793 .78755 .40049 .79171 .39896 .7899 .3964 Metetra
.68 .739 .895 r
.7899 .3964 .79171 .39896 .79588 .39743 .79407 .39487 Metetra
.68 .739 .895 r
.79407 .39487 .79588 .39743 .80005 .39591 .79825 .39335 Metetra
.679 .739 .896 r
.79825 .39335 .80005 .39591 .80423 .39439 .80243 .39183 Metetra
.679 .739 .896 r
.80243 .39183 .80423 .39439 .80842 .39288 .80662 .39032 Metetra
.678 .739 .896 r
.80662 .39032 .80842 .39288 .81261 .39137 .81082 .38881 Metetra
.678 .739 .897 r
.81082 .38881 .81261 .39137 .81681 .38986 .81502 .3873 Metetra
.678 .739 .897 r
.81502 .3873 .81681 .38986 .82102 .38836 .81923 .3858 Metetra
.677 .739 .897 r
.81923 .3858 .82102 .38836 .82523 .38686 .82345 .3843 Metetra
.677 .739 .898 r
.82345 .3843 .82523 .38686 .82944 .38536 .82767 .3828 Metetra
.676 .739 .898 r
.82767 .3828 .82944 .38536 .83367 .38387 .8319 .3813 Metetra
.676 .739 .898 r
.8319 .3813 .83367 .38387 .8379 .38237 .83613 .37981 Metetra
.676 .739 .898 r
.83613 .37981 .8379 .38237 .84213 .38088 .84037 .37831 Metetra
.675 .739 .899 r
.84037 .37831 .84213 .38088 .84637 .37939 .84462 .37682 Metetra
.675 .739 .899 r
.84462 .37682 .84637 .37939 .85062 .37791 .84887 .37533 Metetra
.675 .74 .899 r
.84887 .37533 .85062 .37791 .85487 .37642 .85313 .37385 Metetra
.675 .74 .899 r
.85313 .37385 .85487 .37642 .85913 .37494 .85739 .37236 Metetra
.674 .74 .9 r
.85739 .37236 .85913 .37494 .8634 .37345 .86166 .37088 Metetra
.674 .74 .9 r
.86166 .37088 .8634 .37345 .86767 .37197 .86594 .36939 Metetra
.674 .74 .9 r
.86594 .36939 .86767 .37197 .87195 .37049 .87022 .36791 Metetra
.674 .74 .9 r
.87022 .36791 .87195 .37049 .87624 .36901 .87451 .36643 Metetra
.673 .74 .9 r
.87451 .36643 .87624 .36901 .88053 .36753 .87881 .36494 Metetra
.673 .74 .901 r
.87881 .36494 .88053 .36753 .88483 .36605 .88311 .36346 Metetra
.673 .74 .901 r
.88311 .36346 .88483 .36605 .88913 .36458 .88742 .36198 Metetra
.673 .74 .901 r
.88742 .36198 .88913 .36458 .89344 .3631 .89174 .3605 Metetra
.672 .74 .901 r
.89174 .3605 .89344 .3631 .89776 .36162 .89606 .35902 Metetra
.672 .74 .901 r
.89606 .35902 .89776 .36162 .90208 .36014 .90039 .35754 Metetra
.672 .74 .901 r
.90039 .35754 .90208 .36014 .90641 .35867 .90472 .35606 Metetra
.672 .74 .901 r
.90472 .35606 .90641 .35867 .91075 .35719 .90906 .35458 Metetra
.672 .74 .902 r
.90906 .35458 .91075 .35719 .91509 .35571 .91341 .35311 Metetra
.653 .734 .909 r
.32581 .53634 .32804 .53847 .33157 .53744 .32934 .53531 Metetra
.653 .734 .909 r
.32934 .53531 .33157 .53744 .33511 .53642 .33289 .53428 Metetra
.653 .734 .909 r
.33289 .53428 .33511 .53642 .33866 .53539 .33643 .53325 Metetra
.653 .733 .909 r
.33643 .53325 .33866 .53539 .3422 .53437 .33999 .53222 Metetra
.652 .733 .909 r
.33999 .53222 .3422 .53437 .34576 .53334 .34354 .53119 Metetra
.652 .733 .909 r
.34354 .53119 .34576 .53334 .34932 .53232 .34711 .53017 Metetra
.652 .733 .909 r
.34711 .53017 .34932 .53232 .35288 .5313 .35067 .52914 Metetra
.652 .733 .909 r
.35067 .52914 .35288 .5313 .35645 .53028 .35424 .52811 Metetra
.651 .732 .909 r
.35424 .52811 .35645 .53028 .36003 .52926 .35782 .52709 Metetra
.651 .732 .909 r
.35782 .52709 .36003 .52926 .3636 .52824 .3614 .52607 Metetra
.651 .732 .909 r
.3614 .52607 .3636 .52824 .36719 .52722 .36499 .52504 Metetra
.651 .732 .909 r
.36499 .52504 .36719 .52722 .37078 .5262 .36858 .52402 Metetra
.65 .732 .909 r
.36858 .52402 .37078 .5262 .37437 .52519 .37218 .52301 Metetra
.65 .731 .909 r
.37218 .52301 .37437 .52519 .37797 .52418 .37578 .52199 Metetra
.65 .731 .909 r
.37578 .52199 .37797 .52418 .38157 .52316 .37939 .52097 Metetra
.649 .731 .909 r
.37939 .52097 .38157 .52316 .38518 .52216 .383 .51996 Metetra
.649 .731 .909 r
.383 .51996 .38518 .52216 .38879 .52115 .38661 .51895 Metetra
.649 .73 .909 r
.38661 .51895 .38879 .52115 .39241 .52014 .39024 .51794 Metetra
.648 .73 .909 r
.39024 .51794 .39241 .52014 .39604 .51914 .39386 .51693 Metetra
.648 .73 .909 r
.39386 .51693 .39604 .51914 .39967 .51814 .39749 .51593 Metetra
.647 .729 .909 r
.39749 .51593 .39967 .51814 .4033 .51714 .40113 .51492 Metetra
.647 .729 .909 r
.40113 .51492 .4033 .51714 .40694 .51615 .40477 .51393 Metetra
.646 .729 .909 r
.40477 .51393 .40694 .51615 .41058 .51516 .40842 .51293 Metetra
.646 .728 .909 r
.40842 .51293 .41058 .51516 .41423 .51417 .41207 .51194 Metetra
.645 .728 .909 r
.41207 .51194 .41423 .51417 .41789 .51319 .41573 .51095 Metetra
.645 .728 .909 r
.41573 .51095 .41789 .51319 .42155 .51221 .41939 .50996 Metetra
.644 .727 .909 r
.41939 .50996 .42155 .51221 .42521 .51123 .42306 .50898 Metetra
.644 .727 .909 r
.42306 .50898 .42521 .51123 .42888 .51026 .42673 .508 Metetra
.643 .726 .909 r
.42673 .508 .42888 .51026 .43256 .5093 .43041 .50703 Metetra
.642 .726 .909 r
.43041 .50703 .43256 .5093 .43624 .50833 .43409 .50607 Metetra
.642 .725 .909 r
.43409 .50607 .43624 .50833 .43992 .50738 .43778 .5051 Metetra
.641 .725 .909 r
.43778 .5051 .43992 .50738 .44361 .50643 .44148 .50415 Metetra
.64 .724 .909 r
.44148 .50415 .44361 .50643 .44731 .50549 .44518 .5032 Metetra
.639 .724 .909 r
.44518 .5032 .44731 .50549 .45101 .50455 .44888 .50225 Metetra
.638 .723 .909 r
.44888 .50225 .45101 .50455 .45472 .50362 .45259 .50132 Metetra
.637 .722 .909 r
.45259 .50132 .45472 .50362 .45843 .5027 .45631 .50039 Metetra
.636 .722 .909 r
.45631 .50039 .45843 .5027 .46215 .50178 .46003 .49947 Metetra
.635 .721 .909 r
.46003 .49947 .46215 .50178 .46587 .50088 .46376 .49855 Metetra
.634 .72 .909 r
.46376 .49855 .46587 .50088 .4696 .49999 .46749 .49765 Metetra
.633 .719 .909 r
.46749 .49765 .4696 .49999 .47334 .4991 .47123 .49676 Metetra
.632 .718 .909 r
.47123 .49676 .47334 .4991 .47708 .49823 .47497 .49588 Metetra
.63 .717 .909 r
.47497 .49588 .47708 .49823 .48082 .49737 .47872 .49501 Metetra
.629 .716 .91 r
.47872 .49501 .48082 .49737 .48458 .49652 .48247 .49415 Metetra
.627 .715 .91 r
.48247 .49415 .48458 .49652 .48833 .49569 .48623 .49331 Metetra
.625 .714 .91 r
.48623 .49331 .48833 .49569 .4921 .49487 .49 .49248 Metetra
.623 .712 .91 r
.49 .49248 .4921 .49487 .49587 .49407 .49377 .49167 Metetra
.621 .711 .91 r
.49377 .49167 .49587 .49407 .49964 .49329 .49755 .49088 Metetra
.619 .709 .91 r
.49755 .49088 .49964 .49329 .50342 .49253 .50133 .49011 Metetra
.617 .707 .91 r
.50133 .49011 .50342 .49253 .50721 .49179 .50512 .48935 Metetra
.614 .705 .91 r
.50512 .48935 .50721 .49179 .511 .49108 .50892 .48863 Metetra
.611 .703 .91 r
.50892 .48863 .511 .49108 .5148 .49039 .51272 .48792 Metetra
.608 .701 .91 r
.51272 .48792 .5148 .49039 .51861 .48974 .51653 .48725 Metetra
.604 .698 .91 r
.51653 .48725 .51861 .48974 .52242 .48911 .52035 .48661 Metetra
.6 .696 .91 r
.52035 .48661 .52242 .48911 .52624 .48852 .52417 .486 Metetra
.596 .692 .91 r
.52417 .486 .52624 .48852 .53007 .48798 .528 .48543 Metetra
.591 .689 .91 r
.528 .48543 .53007 .48798 .5339 .48748 .53183 .48491 Metetra
.586 .685 .91 r
.53183 .48491 .5339 .48748 .53774 .48703 .53568 .48444 Metetra
.579 .68 .909 r
.53568 .48444 .53774 .48703 .54159 .48664 .53953 .48402 Metetra
.572 .675 .909 r
.53953 .48402 .54159 .48664 .54544 .48632 .54338 .48366 Metetra
.564 .669 .909 r
.54338 .48366 .54544 .48632 .54931 .48607 .54725 .48338 Metetra
.554 .662 .908 r
.54725 .48338 .54931 .48607 .55318 .48591 .55112 .48319 Metetra
.543 .654 .908 r
.55112 .48319 .55318 .48591 .55706 .48586 .55501 .48308 Metetra
.53 .644 .907 r
.55501 .48308 .55706 .48586 .56095 .48592 .5589 .4831 Metetra
.514 .633 .905 r
.5589 .4831 .56095 .48592 .56485 .48613 .5628 .48324 Metetra
.495 .619 .903 r
.5628 .48324 .56485 .48613 .56876 .48651 .56671 .48355 Metetra
.471 .601 .9 r
.56671 .48355 .56876 .48651 .57268 .48709 .57064 .48404 Metetra
.442 .58 .895 r
.57064 .48404 .57268 .48709 .57662 .48793 .57457 .48478 Metetra
.405 .552 .888 r
.57457 .48478 .57662 .48793 .58057 .48909 .57853 .4858 Metetra
.357 .515 .877 r
.57853 .4858 .58057 .48909 .58455 .49065 .5825 .4872 Metetra
.292 .465 .86 r
.5825 .4872 .58455 .49065 .58854 .49276 .58649 .48909 Metetra
.967 .681 .436 r
.58649 .48909 .58854 .49276 .59256 .49559 .59393 .66482 Metetra
.557 .341 .541 r
.59393 .66482 .59256 .49559 .60021 .6658 .59809 .66366 Metetra
.645 .763 .934 r
.59809 .66366 .60021 .6658 .60438 .66464 .60226 .6625 Metetra
.645 .763 .934 r
.60226 .6625 .60438 .66464 .60855 .66348 .60643 .66133 Metetra
.645 .763 .934 r
.60643 .66133 .60855 .66348 .61272 .66232 .61061 .66017 Metetra
.645 .763 .934 r
.61061 .66017 .61272 .66232 .61691 .66116 .6148 .659 Metetra
.645 .763 .934 r
.6148 .659 .61691 .66116 .62109 .65999 .61899 .65783 Metetra
.645 .763 .934 r
.61899 .65783 .62109 .65999 .62033 .48702 .62319 .65666 Metetra
0 0 .387 r
.62319 .65666 .62033 .48702 .6242 .48171 .62217 .47801 Metetra
.793 .696 .758 r
.62217 .47801 .6242 .48171 .62809 .47714 .62606 .47365 Metetra
.784 .702 .774 r
.62606 .47365 .62809 .47714 .63199 .4731 .62997 .46977 Metetra
.775 .708 .788 r
.62997 .46977 .63199 .4731 .6359 .46946 .6339 .46626 Metetra
.768 .712 .8 r
.6339 .46626 .6359 .46946 .63983 .46615 .63783 .46304 Metetra
.76 .716 .811 r
.63783 .46304 .63983 .46615 .64376 .46309 .64177 .46006 Metetra
.754 .719 .82 r
.64177 .46006 .64376 .46309 .64771 .46023 .64572 .45727 Metetra
.748 .722 .828 r
.64572 .45727 .64771 .46023 .65166 .45755 .64968 .45464 Metetra
.742 .724 .834 r
.64968 .45464 .65166 .45755 .65562 .45501 .65364 .45215 Metetra
.737 .726 .84 r
.65364 .45215 .65562 .45501 .65959 .45258 .65762 .44976 Metetra
.733 .727 .846 r
.65762 .44976 .65959 .45258 .66356 .45026 .6616 .44747 Metetra
.728 .728 .85 r
.6616 .44747 .66356 .45026 .66754 .44803 .66558 .44527 Metetra
.724 .729 .855 r
.66558 .44527 .66754 .44803 .67153 .44587 .66958 .44314 Metetra
.721 .73 .858 r
.66958 .44314 .67153 .44587 .67553 .44378 .67358 .44107 Metetra
.718 .731 .862 r
.67358 .44107 .67553 .44378 .67953 .44174 .67759 .43905 Metetra
.715 .732 .865 r
.67759 .43905 .67953 .44174 .68354 .43976 .6816 .43709 Metetra
.712 .733 .867 r
.6816 .43709 .68354 .43976 .68755 .43782 .68562 .43516 Metetra
.709 .733 .87 r
.68562 .43516 .68755 .43782 .69157 .43593 .68964 .43328 Metetra
.707 .734 .872 r
.68964 .43328 .69157 .43593 .6956 .43407 .69368 .43143 Metetra
.705 .734 .874 r
.69368 .43143 .6956 .43407 .69963 .43224 .69771 .42961 Metetra
.703 .735 .876 r
.69771 .42961 .69963 .43224 .70367 .43044 .70176 .42783 Metetra
.701 .735 .877 r
.70176 .42783 .70367 .43044 .70772 .42867 .70581 .42606 Metetra
.699 .735 .879 r
.70581 .42606 .70772 .42867 .71177 .42692 .70986 .42432 Metetra
.698 .736 .88 r
.70986 .42432 .71177 .42692 .71583 .4252 .71393 .4226 Metetra
.696 .736 .882 r
.71393 .4226 .71583 .4252 .71989 .42349 .71799 .4209 Metetra
.695 .736 .883 r
.71799 .4209 .71989 .42349 .72396 .42181 .72207 .41922 Metetra
.693 .737 .884 r
.72207 .41922 .72396 .42181 .72804 .42014 .72615 .41756 Metetra
.692 .737 .885 r
.72615 .41756 .72804 .42014 .73212 .41848 .73024 .41591 Metetra
.691 .737 .886 r
.73024 .41591 .73212 .41848 .73621 .41684 .73433 .41427 Metetra
.69 .737 .887 r
.73433 .41427 .73621 .41684 .7403 .41521 .73843 .41264 Metetra
.689 .737 .888 r
.73843 .41264 .7403 .41521 .7444 .4136 .74253 .41103 Metetra
.688 .737 .889 r
.74253 .41103 .7444 .4136 .74851 .41199 .74664 .40943 Metetra
.687 .738 .889 r
.74664 .40943 .74851 .41199 .75262 .4104 .75076 .40784 Metetra
.686 .738 .89 r
.75076 .40784 .75262 .4104 .75674 .40882 .75488 .40625 Metetra
.685 .738 .891 r
.75488 .40625 .75674 .40882 .76086 .40724 .75901 .40468 Metetra
.684 .738 .891 r
.75901 .40468 .76086 .40724 .76499 .40567 .76314 .40311 Metetra
.684 .738 .892 r
.76314 .40311 .76499 .40567 .76913 .40411 .76728 .40155 Metetra
.683 .738 .893 r
.76728 .40155 .76913 .40411 .77327 .40256 .77143 .4 Metetra
.682 .738 .893 r
.77143 .4 .77327 .40256 .77742 .40101 .77558 .39845 Metetra
.682 .738 .894 r
.77558 .39845 .77742 .40101 .78157 .39947 .77974 .39691 Metetra
.681 .739 .894 r
.77974 .39691 .78157 .39947 .78573 .39793 .78391 .39537 Metetra
.681 .739 .895 r
.78391 .39537 .78573 .39793 .7899 .3964 .78808 .39384 Metetra
.68 .739 .895 r
.78808 .39384 .7899 .3964 .79407 .39487 .79225 .39231 Metetra
.68 .739 .895 r
.79225 .39231 .79407 .39487 .79825 .39335 .79644 .39079 Metetra
.679 .739 .896 r
.79644 .39079 .79825 .39335 .80243 .39183 .80063 .38927 Metetra
.679 .739 .896 r
.80063 .38927 .80243 .39183 .80662 .39032 .80482 .38776 Metetra
.678 .739 .897 r
.80482 .38776 .80662 .39032 .81082 .38881 .80902 .38625 Metetra
.678 .739 .897 r
.80902 .38625 .81082 .38881 .81502 .3873 .81323 .38474 Metetra
.677 .739 .897 r
.81323 .38474 .81502 .3873 .81923 .3858 .81744 .38323 Metetra
.677 .739 .897 r
.81744 .38323 .81923 .3858 .82345 .3843 .82166 .38173 Metetra
.677 .739 .898 r
.82166 .38173 .82345 .3843 .82767 .3828 .82589 .38023 Metetra
.676 .739 .898 r
.82589 .38023 .82767 .3828 .8319 .3813 .83012 .37873 Metetra
.676 .739 .898 r
.83012 .37873 .8319 .3813 .83613 .37981 .83436 .37723 Metetra
.676 .739 .899 r
.83436 .37723 .83613 .37981 .84037 .37831 .8386 .37574 Metetra
.675 .739 .899 r
.8386 .37574 .84037 .37831 .84462 .37682 .84286 .37425 Metetra
.675 .739 .899 r
.84286 .37425 .84462 .37682 .84887 .37533 .84711 .37275 Metetra
.675 .739 .899 r
.84711 .37275 .84887 .37533 .85313 .37385 .85138 .37127 Metetra
.674 .74 .899 r
.85138 .37127 .85313 .37385 .85739 .37236 .85565 .36978 Metetra
.674 .74 .9 r
.85565 .36978 .85739 .37236 .86166 .37088 .85992 .36829 Metetra
.674 .74 .9 r
.85992 .36829 .86166 .37088 .86594 .36939 .8642 .3668 Metetra
.674 .74 .9 r
.8642 .3668 .86594 .36939 .87022 .36791 .86849 .36532 Metetra
.673 .74 .9 r
.86849 .36532 .87022 .36791 .87451 .36643 .87279 .36383 Metetra
.673 .74 .9 r
.87279 .36383 .87451 .36643 .87881 .36494 .87709 .36235 Metetra
.673 .74 .901 r
.87709 .36235 .87881 .36494 .88311 .36346 .88139 .36087 Metetra
.673 .74 .901 r
.88139 .36087 .88311 .36346 .88742 .36198 .88571 .35938 Metetra
.673 .74 .901 r
.88571 .35938 .88742 .36198 .89174 .3605 .89003 .3579 Metetra
.672 .74 .901 r
.89003 .3579 .89174 .3605 .89606 .35902 .89435 .35642 Metetra
.672 .74 .901 r
.89435 .35642 .89606 .35902 .90039 .35754 .89869 .35494 Metetra
.672 .74 .901 r
.89869 .35494 .90039 .35754 .90472 .35606 .90303 .35345 Metetra
.672 .74 .901 r
.90303 .35345 .90472 .35606 .90906 .35458 .90737 .35197 Metetra
.672 .74 .902 r
.90737 .35197 .90906 .35458 .91341 .35311 .91172 .35049 Metetra
.653 .734 .908 r
.32357 .5342 .32581 .53634 .32934 .53531 .32711 .53317 Metetra
.653 .734 .909 r
.32711 .53317 .32934 .53531 .33289 .53428 .33066 .53214 Metetra
.653 .734 .909 r
.33066 .53214 .33289 .53428 .33643 .53325 .33421 .5311 Metetra
.653 .733 .909 r
.33421 .5311 .33643 .53325 .33999 .53222 .33776 .53007 Metetra
.653 .733 .909 r
.33776 .53007 .33999 .53222 .34354 .53119 .34132 .52904 Metetra
.652 .733 .909 r
.34132 .52904 .34354 .53119 .34711 .53017 .34489 .52801 Metetra
.652 .733 .909 r
.34489 .52801 .34711 .53017 .35067 .52914 .34846 .52698 Metetra
.652 .733 .909 r
.34846 .52698 .35067 .52914 .35424 .52811 .35203 .52595 Metetra
.652 .733 .909 r
.35203 .52595 .35424 .52811 .35782 .52709 .35561 .52492 Metetra
.651 .732 .909 r
.35561 .52492 .35782 .52709 .3614 .52607 .3592 .52389 Metetra
.651 .732 .909 r
.3592 .52389 .3614 .52607 .36499 .52504 .36279 .52287 Metetra
.651 .732 .909 r
.36279 .52287 .36499 .52504 .36858 .52402 .36638 .52184 Metetra
.65 .732 .909 r
.36638 .52184 .36858 .52402 .37218 .52301 .36998 .52082 Metetra
.65 .731 .909 r
.36998 .52082 .37218 .52301 .37578 .52199 .37358 .5198 Metetra
.65 .731 .909 r
.37358 .5198 .37578 .52199 .37939 .52097 .37719 .51878 Metetra
.649 .731 .909 r
.37719 .51878 .37939 .52097 .383 .51996 .38081 .51776 Metetra
.649 .731 .909 r
.38081 .51776 .383 .51996 .38661 .51895 .38443 .51674 Metetra
.649 .73 .909 r
.38443 .51674 .38661 .51895 .39024 .51794 .38805 .51573 Metetra
.648 .73 .909 r
.38805 .51573 .39024 .51794 .39386 .51693 .39168 .51472 Metetra
.648 .73 .909 r
.39168 .51472 .39386 .51693 .39749 .51593 .39532 .51371 Metetra
.647 .73 .909 r
.39532 .51371 .39749 .51593 .40113 .51492 .39896 .5127 Metetra
.647 .729 .909 r
.39896 .5127 .40113 .51492 .40477 .51393 .4026 .5117 Metetra
.647 .729 .909 r
.4026 .5117 .40477 .51393 .40842 .51293 .40625 .51069 Metetra
.646 .729 .909 r
.40625 .51069 .40842 .51293 .41207 .51194 .40991 .5097 Metetra
.646 .728 .909 r
.40991 .5097 .41207 .51194 .41573 .51095 .41357 .5087 Metetra
.645 .728 .909 r
.41357 .5087 .41573 .51095 .41939 .50996 .41723 .50771 Metetra
.644 .727 .909 r
.41723 .50771 .41939 .50996 .42306 .50898 .4209 .50672 Metetra
.644 .727 .909 r
.4209 .50672 .42306 .50898 .42673 .508 .42458 .50574 Metetra
.643 .726 .909 r
.42458 .50574 .42673 .508 .43041 .50703 .42826 .50476 Metetra
.643 .726 .909 r
.42826 .50476 .43041 .50703 .43409 .50607 .43195 .50379 Metetra
.642 .725 .909 r
.43195 .50379 .43409 .50607 .43778 .5051 .43564 .50282 Metetra
.641 .725 .909 r
.43564 .50282 .43778 .5051 .44148 .50415 .43934 .50186 Metetra
.64 .724 .909 r
.43934 .50186 .44148 .50415 .44518 .5032 .44304 .5009 Metetra
.64 .724 .909 r
.44304 .5009 .44518 .5032 .44888 .50225 .44675 .49995 Metetra
.639 .723 .909 r
.44675 .49995 .44888 .50225 .45259 .50132 .45046 .49901 Metetra
.638 .722 .909 r
.45046 .49901 .45259 .50132 .45631 .50039 .45418 .49807 Metetra
.637 .722 .909 r
.45418 .49807 .45631 .50039 .46003 .49947 .4579 .49714 Metetra
.636 .721 .909 r
.4579 .49714 .46003 .49947 .46376 .49855 .46163 .49622 Metetra
.635 .72 .909 r
.46163 .49622 .46376 .49855 .46749 .49765 .46537 .49531 Metetra
.634 .719 .909 r
.46537 .49531 .46749 .49765 .47123 .49676 .46911 .49441 Metetra
.632 .718 .909 r
.46911 .49441 .47123 .49676 .47497 .49588 .47286 .49352 Metetra
.631 .717 .909 r
.47286 .49352 .47497 .49588 .47872 .49501 .47661 .49264 Metetra
.629 .716 .909 r
.47661 .49264 .47872 .49501 .48247 .49415 .48037 .49178 Metetra
.628 .715 .909 r
.48037 .49178 .48247 .49415 .48623 .49331 .48413 .49093 Metetra
.626 .714 .909 r
.48413 .49093 .48623 .49331 .49 .49248 .4879 .49009 Metetra
.624 .713 .91 r
.4879 .49009 .49 .49248 .49377 .49167 .49167 .48927 Metetra
.622 .711 .91 r
.49167 .48927 .49377 .49167 .49755 .49088 .49545 .48846 Metetra
.62 .71 .91 r
.49545 .48846 .49755 .49088 .50133 .49011 .49924 .48768 Metetra
.618 .708 .91 r
.49924 .48768 .50133 .49011 .50512 .48935 .50303 .48691 Metetra
.615 .706 .91 r
.50303 .48691 .50512 .48935 .50892 .48863 .50683 .48617 Metetra
.613 .704 .91 r
.50683 .48617 .50892 .48863 .51272 .48792 .51064 .48545 Metetra
.609 .702 .91 r
.51064 .48545 .51272 .48792 .51653 .48725 .51445 .48476 Metetra
.606 .699 .91 r
.51445 .48476 .51653 .48725 .52035 .48661 .51827 .4841 Metetra
.602 .697 .91 r
.51827 .4841 .52035 .48661 .52417 .486 .52209 .48348 Metetra
.598 .694 .91 r
.52209 .48348 .52417 .486 .528 .48543 .52593 .48289 Metetra
.593 .69 .91 r
.52593 .48289 .528 .48543 .53183 .48491 .52976 .48234 Metetra
.588 .686 .909 r
.52976 .48234 .53183 .48491 .53568 .48444 .53361 .48184 Metetra
.582 .682 .909 r
.53361 .48184 .53568 .48444 .53953 .48402 .53746 .4814 Metetra
.575 .677 .909 r
.53746 .4814 .53953 .48402 .54338 .48366 .54132 .48101 Metetra
.567 .671 .909 r
.54132 .48101 .54338 .48366 .54725 .48338 .54519 .4807 Metetra
.558 .665 .908 r
.54519 .4807 .54725 .48338 .55112 .48319 .54907 .48046 Metetra
.548 .657 .908 r
.54907 .48046 .55112 .48319 .55501 .48308 .55295 .48032 Metetra
.536 .648 .907 r
.55295 .48032 .55501 .48308 .5589 .4831 .55684 .48028 Metetra
.521 .637 .905 r
.55684 .48028 .5589 .4831 .5628 .48324 .56075 .48036 Metetra
.503 .624 .903 r
.56075 .48036 .5628 .48324 .56671 .48355 .56466 .4806 Metetra
.482 .608 .901 r
.56466 .4806 .56671 .48355 .57064 .48404 .56858 .48101 Metetra
.455 .588 .897 r
.56858 .48101 .57064 .48404 .57457 .48478 .57252 .48165 Metetra
.421 .563 .891 r
.57252 .48165 .57457 .48478 .57853 .4858 .57647 .48255 Metetra
.378 .53 .881 r
.57647 .48255 .57853 .4858 .5825 .4872 .58044 .4838 Metetra
.321 .485 .866 r
.58044 .4838 .5825 .4872 .58649 .48909 .58443 .48548 Metetra
.967 .681 .437 r
.58443 .48548 .58649 .48909 .59393 .66482 .5918 .66268 Metetra
.645 .763 .934 r
.5918 .66268 .59393 .66482 .59809 .66366 .59596 .66151 Metetra
.645 .763 .934 r
.59596 .66151 .59809 .66366 .60226 .6625 .60014 .66035 Metetra
.645 .763 .934 r
.60014 .66035 .60226 .6625 .60643 .66133 .60431 .65918 Metetra
.645 .763 .934 r
.60431 .65918 .60643 .66133 .61061 .66017 .6085 .65801 Metetra
.645 .763 .934 r
.6085 .65801 .61061 .66017 .6148 .659 .61269 .65684 Metetra
.645 .763 .934 r
.61269 .65684 .6148 .659 .61899 .65783 .61689 .65567 Metetra
.645 .763 .934 r
.61689 .65567 .61899 .65783 .62319 .65666 .62109 .6545 Metetra
.967 .695 .463 r
.62109 .6545 .62319 .65666 .62217 .47801 .62013 .47437 Metetra
.789 .697 .763 r
.62013 .47437 .62217 .47801 .62606 .47365 .62404 .4702 Metetra
.78 .704 .779 r
.62404 .4702 .62606 .47365 .62997 .46977 .62796 .46647 Metetra
.772 .709 .792 r
.62796 .46647 .62997 .46977 .6339 .46626 .63189 .46308 Metetra
.764 .713 .804 r
.63189 .46308 .6339 .46626 .63783 .46304 .63582 .45995 Metetra
.758 .717 .814 r
.63582 .45995 .63783 .46304 .64177 .46006 .63977 .45705 Metetra
.751 .719 .823 r
.63977 .45705 .64177 .46006 .64572 .45727 .64373 .45432 Metetra
.745 .722 .83 r
.64373 .45432 .64572 .45727 .64968 .45464 .64769 .45175 Metetra
.74 .724 .837 r
.64769 .45175 .64968 .45464 .65364 .45215 .65167 .44929 Metetra
.735 .726 .842 r
.65167 .44929 .65364 .45215 .65762 .44976 .65564 .44695 Metetra
.731 .727 .847 r
.65564 .44695 .65762 .44976 .6616 .44747 .65963 .44469 Metetra
.727 .728 .852 r
.65963 .44469 .6616 .44747 .66558 .44527 .66362 .44251 Metetra
.723 .73 .856 r
.66362 .44251 .66558 .44527 .66958 .44314 .66762 .4404 Metetra
.719 .73 .859 r
.66762 .4404 .66958 .44314 .67358 .44107 .67163 .43835 Metetra
.716 .731 .863 r
.67163 .43835 .67358 .44107 .67759 .43905 .67564 .43636 Metetra
.713 .732 .865 r
.67564 .43636 .67759 .43905 .6816 .43709 .67966 .43441 Metetra
.711 .733 .868 r
.67966 .43441 .6816 .43709 .68562 .43516 .68368 .4325 Metetra
.708 .733 .87 r
.68368 .4325 .68562 .43516 .68964 .43328 .68771 .43063 Metetra
.706 .734 .873 r
.68771 .43063 .68964 .43328 .69368 .43143 .69175 .42879 Metetra
.704 .734 .875 r
.69175 .42879 .69368 .43143 .69771 .42961 .69579 .42699 Metetra
.702 .735 .876 r
.69579 .42699 .69771 .42961 .70176 .42783 .69984 .42521 Metetra
.7 .735 .878 r
.69984 .42521 .70176 .42783 .70581 .42606 .70389 .42345 Metetra
.698 .735 .88 r
.70389 .42345 .70581 .42606 .70986 .42432 .70795 .42172 Metetra
.697 .736 .881 r
.70795 .42172 .70986 .42432 .71393 .4226 .71202 .42 Metetra
.695 .736 .882 r
.71202 .42 .71393 .4226 .71799 .4209 .71609 .41831 Metetra
.694 .736 .883 r
.71609 .41831 .71799 .4209 .72207 .41922 .72017 .41663 Metetra
.693 .736 .884 r
.72017 .41663 .72207 .41922 .72615 .41756 .72426 .41497 Metetra
.692 .737 .886 r
.72426 .41497 .72615 .41756 .73024 .41591 .72835 .41332 Metetra
.69 .737 .886 r
.72835 .41332 .73024 .41591 .73433 .41427 .73245 .41169 Metetra
.689 .737 .887 r
.73245 .41169 .73433 .41427 .73843 .41264 .73655 .41007 Metetra
.688 .737 .888 r
.73655 .41007 .73843 .41264 .74253 .41103 .74066 .40846 Metetra
.687 .737 .889 r
.74066 .40846 .74253 .41103 .74664 .40943 .74477 .40686 Metetra
.687 .738 .89 r
.74477 .40686 .74664 .40943 .75076 .40784 .74889 .40527 Metetra
.686 .738 .89 r
.74889 .40527 .75076 .40784 .75488 .40625 .75302 .40368 Metetra
.685 .738 .891 r
.75302 .40368 .75488 .40625 .75901 .40468 .75715 .40211 Metetra
.684 .738 .892 r
.75715 .40211 .75901 .40468 .76314 .40311 .76129 .40054 Metetra
.683 .738 .892 r
.76129 .40054 .76314 .40311 .76728 .40155 .76544 .39898 Metetra
.683 .738 .893 r
.76544 .39898 .76728 .40155 .77143 .4 .76959 .39743 Metetra
.682 .738 .893 r
.76959 .39743 .77143 .4 .77558 .39845 .77374 .39588 Metetra
.682 .738 .894 r
.77374 .39588 .77558 .39845 .77974 .39691 .77791 .39434 Metetra
.681 .738 .894 r
.77791 .39434 .77974 .39691 .78391 .39537 .78208 .3928 Metetra
.68 .739 .895 r
.78208 .3928 .78391 .39537 .78808 .39384 .78625 .39127 Metetra
.68 .739 .895 r
.78625 .39127 .78808 .39384 .79225 .39231 .79043 .38975 Metetra
.679 .739 .896 r
.79043 .38975 .79225 .39231 .79644 .39079 .79462 .38822 Metetra
.679 .739 .896 r
.79462 .38822 .79644 .39079 .80063 .38927 .79882 .3867 Metetra
.678 .739 .896 r
.79882 .3867 .80063 .38927 .80482 .38776 .80301 .38519 Metetra
.678 .739 .897 r
.80301 .38519 .80482 .38776 .80902 .38625 .80722 .38367 Metetra
.678 .739 .897 r
.80722 .38367 .80902 .38625 .81323 .38474 .81143 .38216 Metetra
.677 .739 .897 r
.81143 .38216 .81323 .38474 .81744 .38323 .81565 .38066 Metetra
.677 .739 .898 r
.81565 .38066 .81744 .38323 .82166 .38173 .81988 .37915 Metetra
.676 .739 .898 r
.81988 .37915 .82166 .38173 .82589 .38023 .82411 .37765 Metetra
.676 .739 .898 r
.82411 .37765 .82589 .38023 .83012 .37873 .82834 .37615 Metetra
.676 .739 .898 r
.82834 .37615 .83012 .37873 .83436 .37723 .83259 .37465 Metetra
.675 .739 .899 r
.83259 .37465 .83436 .37723 .8386 .37574 .83683 .37316 Metetra
.675 .739 .899 r
.83683 .37316 .8386 .37574 .84286 .37425 .84109 .37166 Metetra
.675 .739 .899 r
.84109 .37166 .84286 .37425 .84711 .37275 .84535 .37017 Metetra
.675 .739 .899 r
.84535 .37017 .84711 .37275 .85138 .37127 .84962 .36868 Metetra
.674 .739 .9 r
.84962 .36868 .85138 .37127 .85565 .36978 .85389 .36719 Metetra
.674 .74 .9 r
.85389 .36719 .85565 .36978 .85992 .36829 .85817 .3657 Metetra
.674 .74 .9 r
.85817 .3657 .85992 .36829 .8642 .3668 .86246 .36421 Metetra
.674 .74 .9 r
.86246 .36421 .8642 .3668 .86849 .36532 .86675 .36272 Metetra
.673 .74 .9 r
.86675 .36272 .86849 .36532 .87279 .36383 .87105 .36123 Metetra
.673 .74 .9 r
.87105 .36123 .87279 .36383 .87709 .36235 .87536 .35975 Metetra
.673 .74 .901 r
.87536 .35975 .87709 .36235 .88139 .36087 .87967 .35826 Metetra
.673 .74 .901 r
.87967 .35826 .88139 .36087 .88571 .35938 .88399 .35678 Metetra
.672 .74 .901 r
.88399 .35678 .88571 .35938 .89003 .3579 .88831 .35529 Metetra
.672 .74 .901 r
.88831 .35529 .89003 .3579 .89435 .35642 .89264 .35381 Metetra
.672 .74 .901 r
.89264 .35381 .89435 .35642 .89869 .35494 .89698 .35232 Metetra
.672 .74 .901 r
.89698 .35232 .89869 .35494 .90303 .35345 .90133 .35084 Metetra
.672 .74 .902 r
.90133 .35084 .90303 .35345 .90737 .35197 .90568 .34935 Metetra
.672 .74 .902 r
.90568 .34935 .90737 .35197 .91172 .35049 .91003 .34787 Metetra
.654 .734 .908 r
.32133 .53206 .32357 .5342 .32711 .53317 .32487 .53103 Metetra
.653 .734 .908 r
.32487 .53103 .32711 .53317 .33066 .53214 .32842 .52999 Metetra
.653 .734 .908 r
.32842 .52999 .33066 .53214 .33421 .5311 .33198 .52895 Metetra
.653 .733 .908 r
.33198 .52895 .33421 .5311 .33776 .53007 .33553 .52791 Metetra
.653 .733 .909 r
.33553 .52791 .33776 .53007 .34132 .52904 .3391 .52688 Metetra
.652 .733 .909 r
.3391 .52688 .34132 .52904 .34489 .52801 .34267 .52584 Metetra
.652 .733 .909 r
.34267 .52584 .34489 .52801 .34846 .52698 .34624 .52481 Metetra
.652 .733 .909 r
.34624 .52481 .34846 .52698 .35203 .52595 .34982 .52378 Metetra
.652 .733 .909 r
.34982 .52378 .35203 .52595 .35561 .52492 .3534 .52274 Metetra
.651 .732 .909 r
.3534 .52274 .35561 .52492 .3592 .52389 .35699 .52171 Metetra
.651 .732 .909 r
.35699 .52171 .3592 .52389 .36279 .52287 .36058 .52068 Metetra
.651 .732 .909 r
.36058 .52068 .36279 .52287 .36638 .52184 .36418 .51965 Metetra
.651 .732 .909 r
.36418 .51965 .36638 .52184 .36998 .52082 .36778 .51863 Metetra
.65 .732 .909 r
.36778 .51863 .36998 .52082 .37358 .5198 .37138 .5176 Metetra
.65 .731 .909 r
.37138 .5176 .37358 .5198 .37719 .51878 .375 .51657 Metetra
.65 .731 .909 r
.375 .51657 .37719 .51878 .38081 .51776 .37861 .51555 Metetra
.649 .731 .909 r
.37861 .51555 .38081 .51776 .38443 .51674 .38224 .51453 Metetra
.649 .731 .909 r
.38224 .51453 .38443 .51674 .38805 .51573 .38586 .51351 Metetra
.649 .73 .909 r
.38586 .51351 .38805 .51573 .39168 .51472 .3895 .5125 Metetra
.648 .73 .909 r
.3895 .5125 .39168 .51472 .39532 .51371 .39313 .51148 Metetra
.648 .73 .909 r
.39313 .51148 .39532 .51371 .39896 .5127 .39678 .51047 Metetra
.647 .729 .909 r
.39678 .51047 .39896 .5127 .4026 .5117 .40043 .50946 Metetra
.647 .729 .909 r
.40043 .50946 .4026 .5117 .40625 .51069 .40408 .50845 Metetra
.646 .729 .909 r
.40408 .50845 .40625 .51069 .40991 .5097 .40774 .50745 Metetra
.646 .728 .909 r
.40774 .50745 .40991 .5097 .41357 .5087 .4114 .50645 Metetra
.645 .728 .909 r
.4114 .50645 .41357 .5087 .41723 .50771 .41507 .50546 Metetra
.645 .727 .909 r
.41507 .50546 .41723 .50771 .4209 .50672 .41874 .50446 Metetra
.644 .727 .909 r
.41874 .50446 .4209 .50672 .42458 .50574 .42242 .50347 Metetra
.644 .727 .909 r
.42242 .50347 .42458 .50574 .42826 .50476 .42611 .50249 Metetra
.643 .726 .909 r
.42611 .50249 .42826 .50476 .43195 .50379 .4298 .50151 Metetra
.642 .726 .909 r
.4298 .50151 .43195 .50379 .43564 .50282 .43349 .50054 Metetra
.642 .725 .909 r
.43349 .50054 .43564 .50282 .43934 .50186 .43719 .49957 Metetra
.641 .725 .909 r
.43719 .49957 .43934 .50186 .44304 .5009 .4409 .4986 Metetra
.64 .724 .909 r
.4409 .4986 .44304 .5009 .44675 .49995 .44461 .49765 Metetra
.639 .723 .909 r
.44461 .49765 .44675 .49995 .45046 .49901 .44832 .4967 Metetra
.638 .723 .909 r
.44832 .4967 .45046 .49901 .45418 .49807 .45204 .49575 Metetra
.637 .722 .909 r
.45204 .49575 .45418 .49807 .4579 .49714 .45577 .49482 Metetra
.636 .721 .909 r
.45577 .49482 .4579 .49714 .46163 .49622 .4595 .49389 Metetra
.635 .721 .909 r
.4595 .49389 .46163 .49622 .46537 .49531 .46324 .49297 Metetra
.634 .72 .909 r
.46324 .49297 .46537 .49531 .46911 .49441 .46699 .49206 Metetra
.633 .719 .909 r
.46699 .49206 .46911 .49441 .47286 .49352 .47074 .49116 Metetra
.632 .718 .909 r
.47074 .49116 .47286 .49352 .47661 .49264 .47449 .49028 Metetra
.63 .717 .909 r
.47449 .49028 .47661 .49264 .48037 .49178 .47825 .4894 Metetra
.629 .716 .909 r
.47825 .4894 .48037 .49178 .48413 .49093 .48202 .48854 Metetra
.627 .714 .909 r
.48202 .48854 .48413 .49093 .4879 .49009 .48579 .48769 Metetra
.625 .713 .909 r
.48579 .48769 .4879 .49009 .49167 .48927 .48957 .48686 Metetra
.623 .712 .909 r
.48957 .48686 .49167 .48927 .49545 .48846 .49335 .48604 Metetra
.621 .71 .909 r
.49335 .48604 .49545 .48846 .49924 .48768 .49714 .48524 Metetra
.619 .709 .909 r
.49714 .48524 .49924 .48768 .50303 .48691 .50094 .48446 Metetra
.617 .707 .909 r
.50094 .48446 .50303 .48691 .50683 .48617 .50474 .48371 Metetra
.614 .705 .909 r
.50474 .48371 .50683 .48617 .51064 .48545 .50855 .48298 Metetra
.611 .703 .909 r
.50855 .48298 .51064 .48545 .51445 .48476 .51236 .48227 Metetra
.608 .7 .909 r
.51236 .48227 .51445 .48476 .51827 .4841 .51619 .48159 Metetra
.604 .698 .909 r
.51619 .48159 .51827 .4841 .52209 .48348 .52001 .48095 Metetra
.6 .695 .909 r
.52001 .48095 .52209 .48348 .52593 .48289 .52385 .48034 Metetra
.596 .691 .909 r
.52385 .48034 .52593 .48289 .52976 .48234 .52769 .47977 Metetra
.59 .688 .909 r
.52769 .47977 .52976 .48234 .53361 .48184 .53154 .47925 Metetra
.585 .684 .909 r
.53154 .47925 .53361 .48184 .53746 .4814 .53539 .47878 Metetra
.578 .679 .909 r
.53539 .47878 .53746 .4814 .54132 .48101 .53925 .47836 Metetra
.571 .674 .909 r
.53925 .47836 .54132 .48101 .54519 .4807 .54312 .47801 Metetra
.563 .667 .908 r
.54312 .47801 .54519 .4807 .54907 .48046 .547 .47774 Metetra
.553 .66 .907 r
.547 .47774 .54907 .48046 .55295 .48032 .55089 .47755 Metetra
.541 .652 .907 r
.55089 .47755 .55295 .48032 .55684 .48028 .55478 .47746 Metetra
.527 .641 .905 r
.55478 .47746 .55684 .48028 .56075 .48036 .55869 .4775 Metetra
.511 .629 .904 r
.55869 .4775 .56075 .48036 .56466 .4806 .5626 .47766 Metetra
.491 .614 .901 r
.5626 .47766 .56466 .4806 .56858 .48101 .56653 .478 Metetra
.467 .596 .898 r
.56653 .478 .56858 .48101 .57252 .48165 .57047 .47854 Metetra
.436 .573 .893 r
.57047 .47854 .57252 .48165 .57647 .48255 .57442 .47933 Metetra
.397 .543 .885 r
.57442 .47933 .57647 .48255 .58044 .4838 .57839 .48043 Metetra
.346 .504 .872 r
.57839 .48043 .58044 .4838 .58443 .48548 .58237 .48193 Metetra
.967 .681 .437 r
.58237 .48193 .58443 .48548 .5918 .66268 .58966 .66053 Metetra
.645 .763 .934 r
.58966 .66053 .5918 .66268 .59596 .66151 .59383 .65936 Metetra
.645 .763 .934 r
.59383 .65936 .59596 .66151 .60014 .66035 .59801 .65819 Metetra
.645 .763 .934 r
.59801 .65819 .60014 .66035 .60431 .65918 .60219 .65702 Metetra
.645 .763 .934 r
.60219 .65702 .60431 .65918 .6085 .65801 .60638 .65585 Metetra
.645 .763 .934 r
.60638 .65585 .6085 .65801 .61269 .65684 .61057 .65468 Metetra
.645 .763 .934 r
.61057 .65468 .61269 .65684 .61689 .65567 .61477 .6535 Metetra
.645 .763 .934 r
.61477 .6535 .61689 .65567 .62109 .6545 .61898 .65232 Metetra
.967 .695 .463 r
.61898 .65232 .62109 .6545 .62013 .47437 .61809 .47078 Metetra
.785 .699 .769 r
.61809 .47078 .62013 .47437 .62404 .4702 .62201 .46679 Metetra
.776 .705 .784 r
.62201 .46679 .62404 .4702 .62796 .46647 .62593 .4632 Metetra
.769 .71 .797 r
.62593 .4632 .62796 .46647 .63189 .46308 .62987 .45992 Metetra
.761 .714 .808 r
.62987 .45992 .63189 .46308 .63582 .45995 .63382 .45688 Metetra
.755 .717 .817 r
.63382 .45688 .63582 .45995 .63977 .45705 .63777 .45405 Metetra
.749 .72 .825 r
.63777 .45405 .63977 .45705 .64373 .45432 .64174 .45138 Metetra
.743 .722 .832 r
.64174 .45138 .64373 .45432 .64769 .45175 .64571 .44886 Metetra
.738 .724 .839 r
.64571 .44886 .64769 .45175 .65167 .44929 .64968 .44645 Metetra
.733 .726 .844 r
.64968 .44645 .65167 .44929 .65564 .44695 .65367 .44413 Metetra
.729 .727 .849 r
.65367 .44413 .65564 .44695 .65963 .44469 .65766 .44191 Metetra
.725 .729 .853 r
.65766 .44191 .65963 .44469 .66362 .44251 .66166 .43976 Metetra
.721 .73 .857 r
.66166 .43976 .66362 .44251 .66762 .4404 .66566 .43767 Metetra
.718 .731 .861 r
.66566 .43767 .66762 .4404 .67163 .43835 .66967 .43564 Metetra
.715 .731 .864 r
.66967 .43564 .67163 .43835 .67564 .43636 .67369 .43366 Metetra
.712 .732 .866 r
.67369 .43366 .67564 .43636 .67966 .43441 .67771 .43173 Metetra
.71 .733 .869 r
.67771 .43173 .67966 .43441 .68368 .4325 .68174 .42984 Metetra
.707 .733 .871 r
.68174 .42984 .68368 .4325 .68771 .43063 .68577 .42798 Metetra
.705 .734 .873 r
.68577 .42798 .68771 .43063 .69175 .42879 .68981 .42615 Metetra
.703 .734 .875 r
.68981 .42615 .69175 .42879 .69579 .42699 .69386 .42435 Metetra
.701 .735 .877 r
.69386 .42435 .69579 .42699 .69984 .42521 .69791 .42258 Metetra
.699 .735 .879 r
.69791 .42258 .69984 .42521 .70389 .42345 .70197 .42083 Metetra
.698 .735 .88 r
.70197 .42083 .70389 .42345 .70795 .42172 .70604 .41911 Metetra
.696 .736 .881 r
.70604 .41911 .70795 .42172 .71202 .42 .71011 .4174 Metetra
.695 .736 .883 r
.71011 .4174 .71202 .42 .71609 .41831 .71419 .41571 Metetra
.693 .736 .884 r
.71419 .41571 .71609 .41831 .72017 .41663 .71827 .41404 Metetra
.692 .736 .885 r
.71827 .41404 .72017 .41663 .72426 .41497 .72236 .41238 Metetra
.691 .737 .886 r
.72236 .41238 .72426 .41497 .72835 .41332 .72646 .41074 Metetra
.69 .737 .887 r
.72646 .41074 .72835 .41332 .73245 .41169 .73056 .40911 Metetra
.689 .737 .888 r
.73056 .40911 .73245 .41169 .73655 .41007 .73466 .40749 Metetra
.688 .737 .889 r
.73466 .40749 .73655 .41007 .74066 .40846 .73878 .40588 Metetra
.687 .737 .889 r
.73878 .40588 .74066 .40846 .74477 .40686 .7429 .40428 Metetra
.686 .738 .89 r
.7429 .40428 .74477 .40686 .74889 .40527 .74702 .40269 Metetra
.685 .738 .891 r
.74702 .40269 .74889 .40527 .75302 .40368 .75115 .40111 Metetra
.685 .738 .891 r
.75115 .40111 .75302 .40368 .75715 .40211 .75529 .39954 Metetra
.684 .738 .892 r
.75529 .39954 .75715 .40211 .76129 .40054 .75944 .39797 Metetra
.683 .738 .892 r
.75944 .39797 .76129 .40054 .76544 .39898 .76358 .39641 Metetra
.682 .738 .893 r
.76358 .39641 .76544 .39898 .76959 .39743 .76774 .39486 Metetra
.682 .738 .894 r
.76774 .39486 .76959 .39743 .77374 .39588 .7719 .39331 Metetra
.681 .738 .894 r
.7719 .39331 .77374 .39588 .77791 .39434 .77607 .39177 Metetra
.681 .738 .894 r
.77607 .39177 .77791 .39434 .78208 .3928 .78024 .39023 Metetra
.68 .739 .895 r
.78024 .39023 .78208 .3928 .78625 .39127 .78442 .3887 Metetra
.68 .739 .895 r
.78442 .3887 .78625 .39127 .79043 .38975 .78861 .38717 Metetra
.679 .739 .896 r
.78861 .38717 .79043 .38975 .79462 .38822 .7928 .38565 Metetra
.679 .739 .896 r
.7928 .38565 .79462 .38822 .79882 .3867 .797 .38413 Metetra
.678 .739 .896 r
.797 .38413 .79882 .3867 .80301 .38519 .8012 .38261 Metetra
.678 .739 .897 r
.8012 .38261 .80301 .38519 .80722 .38367 .80541 .3811 Metetra
.677 .739 .897 r
.80541 .3811 .80722 .38367 .81143 .38216 .80963 .37959 Metetra
.677 .739 .897 r
.80963 .37959 .81143 .38216 .81565 .38066 .81385 .37808 Metetra
.677 .739 .898 r
.81385 .37808 .81565 .38066 .81988 .37915 .81808 .37657 Metetra
.676 .739 .898 r
.81808 .37657 .81988 .37915 .82411 .37765 .82232 .37507 Metetra
.676 .739 .898 r
.82232 .37507 .82411 .37765 .82834 .37615 .82656 .37357 Metetra
.676 .739 .898 r
.82656 .37357 .82834 .37615 .83259 .37465 .83081 .37207 Metetra
.675 .739 .899 r
.83081 .37207 .83259 .37465 .83683 .37316 .83506 .37057 Metetra
.675 .739 .899 r
.83506 .37057 .83683 .37316 .84109 .37166 .83932 .36907 Metetra
.675 .739 .899 r
.83932 .36907 .84109 .37166 .84535 .37017 .84359 .36758 Metetra
.674 .739 .899 r
.84359 .36758 .84535 .37017 .84962 .36868 .84786 .36608 Metetra
.674 .739 .9 r
.84786 .36608 .84962 .36868 .85389 .36719 .85214 .36459 Metetra
.674 .739 .9 r
.85214 .36459 .85389 .36719 .85817 .3657 .85642 .3631 Metetra
.674 .74 .9 r
.85642 .3631 .85817 .3657 .86246 .36421 .86071 .36161 Metetra
.673 .74 .9 r
.86071 .36161 .86246 .36421 .86675 .36272 .86501 .36012 Metetra
.673 .74 .9 r
.86501 .36012 .86675 .36272 .87105 .36123 .86932 .35863 Metetra
.673 .74 .901 r
.86932 .35863 .87105 .36123 .87536 .35975 .87363 .35714 Metetra
.673 .74 .901 r
.87363 .35714 .87536 .35975 .87967 .35826 .87794 .35565 Metetra
.673 .74 .901 r
.87794 .35565 .87967 .35826 .88399 .35678 .88227 .35416 Metetra
.672 .74 .901 r
.88227 .35416 .88399 .35678 .88831 .35529 .8866 .35267 Metetra
.672 .74 .901 r
.8866 .35267 .88831 .35529 .89264 .35381 .89093 .35119 Metetra
.672 .74 .901 r
.89093 .35119 .89264 .35381 .89698 .35232 .89527 .3497 Metetra
.672 .74 .901 r
.89527 .3497 .89698 .35232 .90133 .35084 .89962 .34821 Metetra
.672 .74 .902 r
.89962 .34821 .90133 .35084 .90568 .34935 .90398 .34672 Metetra
.671 .74 .902 r
.90398 .34672 .90568 .34935 .91003 .34787 .90834 .34524 Metetra
.654 .734 .908 r
.31909 .52992 .32133 .53206 .32487 .53103 .32263 .52888 Metetra
.653 .734 .908 r
.32263 .52888 .32487 .53103 .32842 .52999 .32618 .52784 Metetra
.653 .734 .908 r
.32618 .52784 .32842 .52999 .33198 .52895 .32974 .52679 Metetra
.653 .734 .908 r
.32974 .52679 .33198 .52895 .33553 .52791 .3333 .52575 Metetra
.653 .733 .908 r
.3333 .52575 .33553 .52791 .3391 .52688 .33687 .52471 Metetra
.653 .733 .908 r
.33687 .52471 .3391 .52688 .34267 .52584 .34044 .52368 Metetra
.652 .733 .908 r
.34044 .52368 .34267 .52584 .34624 .52481 .34401 .52264 Metetra
.652 .733 .909 r
.34401 .52264 .34624 .52481 .34982 .52378 .34759 .5216 Metetra
.652 .733 .909 r
.34759 .5216 .34982 .52378 .3534 .52274 .35118 .52056 Metetra
.652 .732 .909 r
.35118 .52056 .3534 .52274 .35699 .52171 .35477 .51953 Metetra
.651 .732 .909 r
.35477 .51953 .35699 .52171 .36058 .52068 .35836 .51849 Metetra
.651 .732 .909 r
.35836 .51849 .36058 .52068 .36418 .51965 .36196 .51746 Metetra
.651 .732 .909 r
.36196 .51746 .36418 .51965 .36778 .51863 .36557 .51643 Metetra
.65 .732 .909 r
.36557 .51643 .36778 .51863 .37138 .5176 .36918 .5154 Metetra
.65 .731 .909 r
.36918 .5154 .37138 .5176 .375 .51657 .37279 .51437 Metetra
.65 .731 .909 r
.37279 .51437 .375 .51657 .37861 .51555 .37641 .51334 Metetra
.649 .731 .909 r
.37641 .51334 .37861 .51555 .38224 .51453 .38004 .51232 Metetra
.649 .731 .909 r
.38004 .51232 .38224 .51453 .38586 .51351 .38367 .51129 Metetra
.649 .73 .909 r
.38367 .51129 .38586 .51351 .3895 .5125 .38731 .51027 Metetra
.648 .73 .909 r
.38731 .51027 .3895 .5125 .39313 .51148 .39095 .50925 Metetra
.648 .73 .909 r
.39095 .50925 .39313 .51148 .39678 .51047 .39459 .50823 Metetra
.648 .729 .909 r
.39459 .50823 .39678 .51047 .40043 .50946 .39824 .50722 Metetra
.647 .729 .909 r
.39824 .50722 .40043 .50946 .40408 .50845 .4019 .50621 Metetra
.647 .729 .909 r
.4019 .50621 .40408 .50845 .40774 .50745 .40556 .5052 Metetra
.646 .728 .909 r
.40556 .5052 .40774 .50745 .4114 .50645 .40923 .5042 Metetra
.646 .728 .909 r
.40923 .5042 .4114 .50645 .41507 .50546 .4129 .50319 Metetra
.645 .728 .909 r
.4129 .50319 .41507 .50546 .41874 .50446 .41658 .5022 Metetra
.644 .727 .909 r
.41658 .5022 .41874 .50446 .42242 .50347 .42026 .5012 Metetra
.644 .727 .909 r
.42026 .5012 .42242 .50347 .42611 .50249 .42394 .50021 Metetra
.643 .726 .909 r
.42394 .50021 .42611 .50249 .4298 .50151 .42764 .49923 Metetra
.643 .726 .909 r
.42764 .49923 .4298 .50151 .43349 .50054 .43134 .49825 Metetra
.642 .725 .909 r
.43134 .49825 .43349 .50054 .43719 .49957 .43504 .49727 Metetra
.641 .725 .909 r
.43504 .49727 .43719 .49957 .4409 .4986 .43875 .4963 Metetra
.64 .724 .909 r
.43875 .4963 .4409 .4986 .44461 .49765 .44246 .49534 Metetra
.64 .724 .909 r
.44246 .49534 .44461 .49765 .44832 .4967 .44618 .49438 Metetra
.639 .723 .909 r
.44618 .49438 .44832 .4967 .45204 .49575 .44991 .49343 Metetra
.638 .722 .909 r
.44991 .49343 .45204 .49575 .45577 .49482 .45364 .49249 Metetra
.637 .722 .909 r
.45364 .49249 .45577 .49482 .4595 .49389 .45737 .49155 Metetra
.636 .721 .909 r
.45737 .49155 .4595 .49389 .46324 .49297 .46111 .49062 Metetra
.635 .72 .909 r
.46111 .49062 .46324 .49297 .46699 .49206 .46486 .48971 Metetra
.633 .719 .909 r
.46486 .48971 .46699 .49206 .47074 .49116 .46861 .4888 Metetra
.632 .718 .909 r
.46861 .4888 .47074 .49116 .47449 .49028 .47237 .4879 Metetra
.631 .717 .909 r
.47237 .4879 .47449 .49028 .47825 .4894 .47613 .48702 Metetra
.629 .716 .909 r
.47613 .48702 .47825 .4894 .48202 .48854 .4799 .48615 Metetra
.628 .715 .909 r
.4799 .48615 .48202 .48854 .48579 .48769 .48368 .48529 Metetra
.626 .714 .909 r
.48368 .48529 .48579 .48769 .48957 .48686 .48746 .48444 Metetra
.624 .712 .909 r
.48746 .48444 .48957 .48686 .49335 .48604 .49125 .48362 Metetra
.622 .711 .909 r
.49125 .48362 .49335 .48604 .49714 .48524 .49504 .48281 Metetra
.62 .709 .909 r
.49504 .48281 .49714 .48524 .50094 .48446 .49884 .48201 Metetra
.618 .707 .909 r
.49884 .48201 .50094 .48446 .50474 .48371 .50264 .48124 Metetra
.615 .706 .909 r
.50264 .48124 .50474 .48371 .50855 .48298 .50646 .4805 Metetra
.612 .703 .909 r
.50646 .4805 .50855 .48298 .51236 .48227 .51027 .47978 Metetra
.609 .701 .909 r
.51027 .47978 .51236 .48227 .51619 .48159 .5141 .47908 Metetra
.606 .699 .909 r
.5141 .47908 .51619 .48159 .52001 .48095 .51793 .47842 Metetra
.602 .696 .909 r
.51793 .47842 .52001 .48095 .52385 .48034 .52176 .47779 Metetra
.598 .693 .909 r
.52176 .47779 .52385 .48034 .52769 .47977 .52561 .4772 Metetra
.593 .689 .909 r
.52561 .4772 .52769 .47977 .53154 .47925 .52946 .47666 Metetra
.587 .685 .909 r
.52946 .47666 .53154 .47925 .53539 .47878 .53332 .47616 Metetra
.581 .681 .909 r
.53332 .47616 .53539 .47878 .53925 .47836 .53718 .47572 Metetra
.574 .676 .908 r
.53718 .47572 .53925 .47836 .54312 .47801 .54105 .47533 Metetra
.566 .67 .908 r
.54105 .47533 .54312 .47801 .547 .47774 .54493 .47502 Metetra
.557 .663 .907 r
.54493 .47502 .547 .47774 .55089 .47755 .54882 .47479 Metetra
.546 .655 .907 r
.54882 .47479 .55089 .47755 .55478 .47746 .55272 .47466 Metetra
.534 .645 .905 r
.55272 .47466 .55478 .47746 .55869 .4775 .55663 .47464 Metetra
.518 .634 .904 r
.55663 .47464 .55869 .4775 .5626 .47766 .56054 .47474 Metetra
.5 .62 .902 r
.56054 .47474 .5626 .47766 .56653 .478 .56447 .47501 Metetra
.478 .603 .899 r
.56447 .47501 .56653 .478 .57047 .47854 .56841 .47545 Metetra
.45 .582 .894 r
.56841 .47545 .57047 .47854 .57442 .47933 .57236 .47613 Metetra
.415 .555 .887 r
.57236 .47613 .57442 .47933 .57839 .48043 .57633 .4771 Metetra
.966 .681 .439 r
.57633 .4771 .57839 .48043 .58237 .48193 .58335 .65954 Metetra
.556 .339 .54 r
.58335 .65954 .58237 .48193 .58966 .66053 .58752 .65837 Metetra
.645 .763 .934 r
.58752 .65837 .58966 .66053 .59383 .65936 .59169 .6572 Metetra
.645 .763 .934 r
.59169 .6572 .59383 .65936 .59801 .65819 .59587 .65603 Metetra
.645 .763 .934 r
.59587 .65603 .59801 .65819 .60219 .65702 .60006 .65486 Metetra
.645 .763 .934 r
.60006 .65486 .60219 .65702 .60638 .65585 .60425 .65368 Metetra
.645 .763 .934 r
.60425 .65368 .60638 .65585 .61057 .65468 .60845 .6525 Metetra
.645 .763 .934 r
.60845 .6525 .61057 .65468 .61477 .6535 .61265 .65133 Metetra
.645 .763 .934 r
.61265 .65133 .61477 .6535 .61898 .65232 .61687 .65014 Metetra
.645 .763 .934 r
.61687 .65014 .61898 .65232 .61809 .47078 .62108 .64896 Metetra
0 0 .388 r
.62108 .64896 .61809 .47078 .62201 .46679 .61997 .46342 Metetra
.773 .706 .789 r
.61997 .46342 .62201 .46679 .62593 .4632 .62391 .45996 Metetra
.765 .711 .801 r
.62391 .45996 .62593 .4632 .62987 .45992 .62785 .45678 Metetra
.758 .714 .811 r
.62785 .45678 .62987 .45992 .63382 .45688 .63181 .45383 Metetra
.752 .718 .82 r
.63181 .45383 .63382 .45688 .63777 .45405 .63577 .45106 Metetra
.746 .72 .828 r
.63577 .45106 .63777 .45405 .64174 .45138 .63974 .44845 Metetra
.741 .722 .835 r
.63974 .44845 .64174 .45138 .64571 .44886 .64371 .44597 Metetra
.736 .724 .841 r
.64371 .44597 .64571 .44886 .64968 .44645 .6477 .4436 Metetra
.731 .726 .846 r
.6477 .4436 .64968 .44645 .65367 .44413 .65168 .44133 Metetra
.727 .727 .851 r
.65168 .44133 .65367 .44413 .65766 .44191 .65568 .43913 Metetra
.723 .729 .855 r
.65568 .43913 .65766 .44191 .66166 .43976 .65968 .437 Metetra
.72 .73 .858 r
.65968 .437 .66166 .43976 .66566 .43767 .66369 .43494 Metetra
.717 .731 .862 r
.66369 .43494 .66566 .43767 .66967 .43564 .66771 .43293 Metetra
.714 .731 .865 r
.66771 .43293 .66967 .43564 .67369 .43366 .67173 .43097 Metetra
.711 .732 .867 r
.67173 .43097 .67369 .43366 .67771 .43173 .67576 .42905 Metetra
.708 .733 .87 r
.67576 .42905 .67771 .43173 .68174 .42984 .67979 .42717 Metetra
.706 .733 .872 r
.67979 .42717 .68174 .42984 .68577 .42798 .68383 .42532 Metetra
.704 .734 .874 r
.68383 .42532 .68577 .42798 .68981 .42615 .68788 .42351 Metetra
.702 .734 .876 r
.68788 .42351 .68981 .42615 .69386 .42435 .69193 .42172 Metetra
.7 .735 .878 r
.69193 .42172 .69386 .42435 .69791 .42258 .69599 .41996 Metetra
.698 .735 .879 r
.69599 .41996 .69791 .42258 .70197 .42083 .70005 .41821 Metetra
.697 .735 .881 r
.70005 .41821 .70197 .42083 .70604 .41911 .70412 .41649 Metetra
.695 .736 .882 r
.70412 .41649 .70604 .41911 .71011 .4174 .7082 .41479 Metetra
.694 .736 .883 r
.7082 .41479 .71011 .4174 .71419 .41571 .71228 .41311 Metetra
.693 .736 .884 r
.71228 .41311 .71419 .41571 .71827 .41404 .71637 .41144 Metetra
.692 .736 .885 r
.71637 .41144 .71827 .41404 .72236 .41238 .72046 .40979 Metetra
.69 .737 .886 r
.72046 .40979 .72236 .41238 .72646 .41074 .72456 .40815 Metetra
.689 .737 .887 r
.72456 .40815 .72646 .41074 .73056 .40911 .72866 .40652 Metetra
.688 .737 .888 r
.72866 .40652 .73056 .40911 .73466 .40749 .73278 .4049 Metetra
.687 .737 .889 r
.73278 .4049 .73466 .40749 .73878 .40588 .73689 .40329 Metetra
.687 .737 .89 r
.73689 .40329 .73878 .40588 .7429 .40428 .74102 .4017 Metetra
.686 .737 .89 r
.74102 .4017 .7429 .40428 .74702 .40269 .74515 .40011 Metetra
.685 .738 .891 r
.74515 .40011 .74702 .40269 .75115 .40111 .74928 .39853 Metetra
.684 .738 .892 r
.74928 .39853 .75115 .40111 .75529 .39954 .75343 .39696 Metetra
.683 .738 .892 r
.75343 .39696 .75529 .39954 .75944 .39797 .75757 .39539 Metetra
.683 .738 .893 r
.75757 .39539 .75944 .39797 .76358 .39641 .76173 .39383 Metetra
.682 .738 .893 r
.76173 .39383 .76358 .39641 .76774 .39486 .76589 .39228 Metetra
.682 .738 .894 r
.76589 .39228 .76774 .39486 .7719 .39331 .77005 .39073 Metetra
.681 .738 .894 r
.77005 .39073 .7719 .39331 .77607 .39177 .77423 .38919 Metetra
.68 .738 .895 r
.77423 .38919 .77607 .39177 .78024 .39023 .7784 .38765 Metetra
.68 .738 .895 r
.7784 .38765 .78024 .39023 .78442 .3887 .78259 .38612 Metetra
.679 .739 .895 r
.78259 .38612 .78442 .3887 .78861 .38717 .78678 .38459 Metetra
.679 .739 .896 r
.78678 .38459 .78861 .38717 .7928 .38565 .79098 .38307 Metetra
.678 .739 .896 r
.79098 .38307 .7928 .38565 .797 .38413 .79518 .38155 Metetra
.678 .739 .897 r
.79518 .38155 .797 .38413 .8012 .38261 .79939 .38003 Metetra
.678 .739 .897 r
.79939 .38003 .8012 .38261 .80541 .3811 .8036 .37851 Metetra
.677 .739 .897 r
.8036 .37851 .80541 .3811 .80963 .37959 .80782 .377 Metetra
.677 .739 .897 r
.80782 .377 .80963 .37959 .81385 .37808 .81205 .37549 Metetra
.676 .739 .898 r
.81205 .37549 .81385 .37808 .81808 .37657 .81628 .37398 Metetra
.676 .739 .898 r
.81628 .37398 .81808 .37657 .82232 .37507 .82052 .37248 Metetra
.676 .739 .898 r
.82052 .37248 .82232 .37507 .82656 .37357 .82477 .37097 Metetra
.675 .739 .899 r
.82477 .37097 .82656 .37357 .83081 .37207 .82902 .36947 Metetra
.675 .739 .899 r
.82902 .36947 .83081 .37207 .83506 .37057 .83328 .36797 Metetra
.675 .739 .899 r
.83328 .36797 .83506 .37057 .83932 .36907 .83755 .36647 Metetra
.675 .739 .899 r
.83755 .36647 .83932 .36907 .84359 .36758 .84182 .36498 Metetra
.674 .739 .899 r
.84182 .36498 .84359 .36758 .84786 .36608 .84609 .36348 Metetra
.674 .739 .9 r
.84609 .36348 .84786 .36608 .85214 .36459 .85038 .36199 Metetra
.674 .739 .9 r
.85038 .36199 .85214 .36459 .85642 .3631 .85467 .36049 Metetra
.674 .74 .9 r
.85467 .36049 .85642 .3631 .86071 .36161 .85896 .359 Metetra
.673 .74 .9 r
.85896 .359 .86071 .36161 .86501 .36012 .86326 .35751 Metetra
.673 .74 .9 r
.86326 .35751 .86501 .36012 .86932 .35863 .86757 .35602 Metetra
.673 .74 .901 r
.86757 .35602 .86932 .35863 .87363 .35714 .87189 .35452 Metetra
.673 .74 .901 r
.87189 .35452 .87363 .35714 .87794 .35565 .87621 .35303 Metetra
.672 .74 .901 r
.87621 .35303 .87794 .35565 .88227 .35416 .88054 .35154 Metetra
.672 .74 .901 r
.88054 .35154 .88227 .35416 .8866 .35267 .88487 .35005 Metetra
.672 .74 .901 r
.88487 .35005 .8866 .35267 .89093 .35119 .88921 .34856 Metetra
.672 .74 .901 r
.88921 .34856 .89093 .35119 .89527 .3497 .89356 .34707 Metetra
.672 .74 .901 r
.89356 .34707 .89527 .3497 .89962 .34821 .89791 .34558 Metetra
.672 .74 .902 r
.89791 .34558 .89962 .34821 .90398 .34672 .90227 .34409 Metetra
.671 .74 .902 r
.90227 .34409 .90398 .34672 .90834 .34524 .90664 .3426 Metetra
.654 .734 .908 r
.31683 .52777 .31909 .52992 .32263 .52888 .32038 .52672 Metetra
.654 .734 .908 r
.32038 .52672 .32263 .52888 .32618 .52784 .32394 .52568 Metetra
.653 .734 .908 r
.32394 .52568 .32618 .52784 .32974 .52679 .3275 .52463 Metetra
.653 .734 .908 r
.3275 .52463 .32974 .52679 .3333 .52575 .33106 .52359 Metetra
.653 .733 .908 r
.33106 .52359 .3333 .52575 .33687 .52471 .33463 .52254 Metetra
.653 .733 .908 r
.33463 .52254 .33687 .52471 .34044 .52368 .3382 .5215 Metetra
.652 .733 .908 r
.3382 .5215 .34044 .52368 .34401 .52264 .34178 .52046 Metetra
.652 .733 .908 r
.34178 .52046 .34401 .52264 .34759 .5216 .34536 .51942 Metetra
.652 .733 .908 r
.34536 .51942 .34759 .5216 .35118 .52056 .34895 .51838 Metetra
.652 .733 .908 r
.34895 .51838 .35118 .52056 .35477 .51953 .35255 .51734 Metetra
.651 .732 .909 r
.35255 .51734 .35477 .51953 .35836 .51849 .35614 .5163 Metetra
.651 .732 .909 r
.35614 .5163 .35836 .51849 .36196 .51746 .35975 .51526 Metetra
.651 .732 .909 r
.35975 .51526 .36196 .51746 .36557 .51643 .36336 .51422 Metetra
.651 .732 .909 r
.36336 .51422 .36557 .51643 .36918 .5154 .36697 .51319 Metetra
.65 .731 .909 r
.36697 .51319 .36918 .5154 .37279 .51437 .37059 .51216 Metetra
.65 .731 .909 r
.37059 .51216 .37279 .51437 .37641 .51334 .37421 .51112 Metetra
.65 .731 .909 r
.37421 .51112 .37641 .51334 .38004 .51232 .37784 .51009 Metetra
.649 .731 .909 r
.37784 .51009 .38004 .51232 .38367 .51129 .38147 .50907 Metetra
.649 .73 .909 r
.38147 .50907 .38367 .51129 .38731 .51027 .38511 .50804 Metetra
.649 .73 .909 r
.38511 .50804 .38731 .51027 .39095 .50925 .38875 .50702 Metetra
.648 .73 .909 r
.38875 .50702 .39095 .50925 .39459 .50823 .3924 .50599 Metetra
.648 .73 .909 r
.3924 .50599 .39459 .50823 .39824 .50722 .39606 .50498 Metetra
.647 .729 .909 r
.39606 .50498 .39824 .50722 .4019 .50621 .39972 .50396 Metetra
.647 .729 .909 r
.39972 .50396 .4019 .50621 .40556 .5052 .40338 .50295 Metetra
.646 .729 .909 r
.40338 .50295 .40556 .5052 .40923 .5042 .40705 .50194 Metetra
.646 .728 .909 r
.40705 .50194 .40923 .5042 .4129 .50319 .41072 .50093 Metetra
.645 .728 .909 r
.41072 .50093 .4129 .50319 .41658 .5022 .4144 .49992 Metetra
.645 .727 .909 r
.4144 .49992 .41658 .5022 .42026 .5012 .41809 .49892 Metetra
.644 .727 .909 r
.41809 .49892 .42026 .5012 .42394 .50021 .42178 .49793 Metetra
.644 .726 .909 r
.42178 .49793 .42394 .50021 .42764 .49923 .42547 .49694 Metetra
.643 .726 .909 r
.42547 .49694 .42764 .49923 .43134 .49825 .42918 .49595 Metetra
.642 .726 .909 r
.42918 .49595 .43134 .49825 .43504 .49727 .43288 .49497 Metetra
.642 .725 .909 r
.43288 .49497 .43504 .49727 .43875 .4963 .43659 .49399 Metetra
.641 .724 .909 r
.43659 .49399 .43875 .4963 .44246 .49534 .44031 .49302 Metetra
.64 .724 .909 r
.44031 .49302 .44246 .49534 .44618 .49438 .44403 .49206 Metetra
.639 .723 .909 r
.44403 .49206 .44618 .49438 .44991 .49343 .44776 .4911 Metetra
.638 .723 .909 r
.44776 .4911 .44991 .49343 .45364 .49249 .45149 .49015 Metetra
.637 .722 .909 r
.45149 .49015 .45364 .49249 .45737 .49155 .45523 .48921 Metetra
.636 .721 .909 r
.45523 .48921 .45737 .49155 .46111 .49062 .45898 .48827 Metetra
.635 .72 .909 r
.45898 .48827 .46111 .49062 .46486 .48971 .46273 .48735 Metetra
.634 .719 .909 r
.46273 .48735 .46486 .48971 .46861 .4888 .46648 .48643 Metetra
.633 .718 .909 r
.46648 .48643 .46861 .4888 .47237 .4879 .47024 .48553 Metetra
.632 .718 .909 r
.47024 .48553 .47237 .4879 .47613 .48702 .47401 .48463 Metetra
.63 .716 .909 r
.47401 .48463 .47613 .48702 .4799 .48615 .47778 .48375 Metetra
.629 .715 .909 r
.47778 .48375 .4799 .48615 .48368 .48529 .48156 .48288 Metetra
.627 .714 .909 r
.48156 .48288 .48368 .48529 .48746 .48444 .48535 .48203 Metetra
.625 .713 .909 r
.48535 .48203 .48746 .48444 .49125 .48362 .48914 .48119 Metetra
.623 .711 .909 r
.48914 .48119 .49125 .48362 .49504 .48281 .49293 .48037 Metetra
.621 .71 .909 r
.49293 .48037 .49504 .48281 .49884 .48201 .49673 .47956 Metetra
.619 .708 .909 r
.49673 .47956 .49884 .48201 .50264 .48124 .50054 .47878 Metetra
.616 .706 .909 r
.50054 .47878 .50264 .48124 .50646 .4805 .50436 .47802 Metetra
.614 .704 .909 r
.50436 .47802 .50646 .4805 .51027 .47978 .50818 .47728 Metetra
.611 .702 .909 r
.50818 .47728 .51027 .47978 .5141 .47908 .512 .47657 Metetra
.607 .7 .909 r
.512 .47657 .5141 .47908 .51793 .47842 .51584 .47589 Metetra
.604 .697 .909 r
.51584 .47589 .51793 .47842 .52176 .47779 .51968 .47524 Metetra
.6 .694 .909 r
.51968 .47524 .52176 .47779 .52561 .4772 .52352 .47463 Metetra
.595 .691 .909 r
.52352 .47463 .52561 .4772 .52946 .47666 .52738 .47406 Metetra
.59 .687 .909 r
.52738 .47406 .52946 .47666 .53332 .47616 .53124 .47354 Metetra
.584 .682 .908 r
.53124 .47354 .53332 .47616 .53718 .47572 .5351 .47307 Metetra
.578 .678 .908 r
.5351 .47307 .53718 .47572 .54105 .47533 .53898 .47266 Metetra
.57 .672 .908 r
.53898 .47266 .54105 .47533 .54493 .47502 .54286 .47231 Metetra
.561 .666 .907 r
.54286 .47231 .54493 .47502 .54882 .47479 .54675 .47204 Metetra
.551 .658 .907 r
.54675 .47204 .54882 .47479 .55272 .47466 .55065 .47186 Metetra
.539 .649 .906 r
.55065 .47186 .55272 .47466 .55663 .47464 .55456 .47179 Metetra
.525 .639 .904 r
.55456 .47179 .55663 .47464 .56054 .47474 .55848 .47183 Metetra
.509 .626 .902 r
.55848 .47183 .56054 .47474 .56447 .47501 .56241 .47202 Metetra
.488 .61 .9 r
.56241 .47202 .56447 .47501 .56841 .47545 .56635 .47239 Metetra
.463 .591 .896 r
.56635 .47239 .56841 .47545 .57236 .47613 .5703 .47297 Metetra
.431 .567 .89 r
.5703 .47297 .57236 .47613 .57633 .4771 .57426 .47381 Metetra
.966 .681 .44 r
.57426 .47381 .57633 .4771 .58335 .65954 .5812 .65738 Metetra
.645 .763 .934 r
.5812 .65738 .58335 .65954 .58752 .65837 .58537 .65621 Metetra
.645 .763 .934 r
.58537 .65621 .58752 .65837 .59169 .6572 .58954 .65504 Metetra
.645 .763 .934 r
.58954 .65504 .59169 .6572 .59587 .65603 .59373 .65386 Metetra
.645 .763 .934 r
.59373 .65386 .59587 .65603 .60006 .65486 .59792 .65269 Metetra
.645 .763 .934 r
.59792 .65269 .60006 .65486 .60425 .65368 .60212 .65151 Metetra
.645 .763 .934 r
.60212 .65151 .60425 .65368 .60845 .6525 .60632 .65033 Metetra
.645 .763 .934 r
.60632 .65033 .60845 .6525 .61265 .65133 .61053 .64914 Metetra
.645 .763 .934 r
.61053 .64914 .61265 .65133 .61687 .65014 .61475 .64796 Metetra
.645 .763 .934 r
.61475 .64796 .61687 .65014 .62108 .64896 .61897 .64677 Metetra
.968 .694 .461 r
.61897 .64677 .62108 .64896 .61997 .46342 .61794 .46009 Metetra
.769 .707 .793 r
.61794 .46009 .61997 .46342 .62391 .45996 .62188 .45674 Metetra
.762 .711 .805 r
.62188 .45674 .62391 .45996 .62785 .45678 .62583 .45366 Metetra
.755 .715 .815 r
.62583 .45366 .62785 .45678 .63181 .45383 .62979 .45079 Metetra
.749 .718 .823 r
.62979 .45079 .63181 .45383 .63577 .45106 .63376 .44809 Metetra
.743 .721 .831 r
.63376 .44809 .63577 .45106 .63974 .44845 .63773 .44553 Metetra
.738 .723 .837 r
.63773 .44553 .63974 .44845 .64371 .44597 .64172 .44309 Metetra
.733 .725 .843 r
.64172 .44309 .64371 .44597 .6477 .4436 .6457 .44076 Metetra
.729 .726 .848 r
.6457 .44076 .6477 .4436 .65168 .44133 .6497 .43852 Metetra
.725 .728 .852 r
.6497 .43852 .65168 .44133 .65568 .43913 .6537 .43635 Metetra
.722 .729 .856 r
.6537 .43635 .65568 .43913 .65968 .437 .65771 .43425 Metetra
.718 .73 .86 r
.65771 .43425 .65968 .437 .66369 .43494 .66172 .43221 Metetra
.715 .731 .863 r
.66172 .43221 .66369 .43494 .66771 .43293 .66574 .43022 Metetra
.712 .731 .866 r
.66574 .43022 .66771 .43293 .67173 .43097 .66977 .42827 Metetra
.71 .732 .868 r
.66977 .42827 .67173 .43097 .67576 .42905 .6738 .42637 Metetra
.707 .733 .871 r
.6738 .42637 .67576 .42905 .67979 .42717 .67784 .4245 Metetra
.705 .733 .873 r
.67784 .4245 .67979 .42717 .68383 .42532 .68188 .42267 Metetra
.703 .734 .875 r
.68188 .42267 .68383 .42532 .68788 .42351 .68593 .42086 Metetra
.701 .734 .876 r
.68593 .42086 .68788 .42351 .69193 .42172 .68999 .41908 Metetra
.699 .735 .878 r
.68999 .41908 .69193 .42172 .69599 .41996 .69405 .41732 Metetra
.698 .735 .88 r
.69405 .41732 .69599 .41996 .70005 .41821 .69812 .41559 Metetra
.696 .735 .881 r
.69812 .41559 .70005 .41821 .70412 .41649 .7022 .41388 Metetra
.695 .736 .882 r
.7022 .41388 .70412 .41649 .7082 .41479 .70628 .41218 Metetra
.693 .736 .883 r
.70628 .41218 .7082 .41479 .71228 .41311 .71036 .4105 Metetra
.692 .736 .885 r
.71036 .4105 .71228 .41311 .71637 .41144 .71445 .40884 Metetra
.691 .736 .886 r
.71445 .40884 .71637 .41144 .72046 .40979 .71855 .40719 Metetra
.69 .737 .887 r
.71855 .40719 .72046 .40979 .72456 .40815 .72266 .40555 Metetra
.689 .737 .887 r
.72266 .40555 .72456 .40815 .72866 .40652 .72677 .40392 Metetra
.688 .737 .888 r
.72677 .40392 .72866 .40652 .73278 .4049 .73088 .40231 Metetra
.687 .737 .889 r
.73088 .40231 .73278 .4049 .73689 .40329 .73501 .40071 Metetra
.686 .737 .89 r
.73501 .40071 .73689 .40329 .74102 .4017 .73913 .39911 Metetra
.685 .737 .89 r
.73913 .39911 .74102 .4017 .74515 .40011 .74327 .39752 Metetra
.685 .738 .891 r
.74327 .39752 .74515 .40011 .74928 .39853 .74741 .39594 Metetra
.684 .738 .892 r
.74741 .39594 .74928 .39853 .75343 .39696 .75156 .39437 Metetra
.683 .738 .892 r
.75156 .39437 .75343 .39696 .75757 .39539 .75571 .39281 Metetra
.682 .738 .893 r
.75571 .39281 .75757 .39539 .76173 .39383 .75987 .39125 Metetra
.682 .738 .893 r
.75987 .39125 .76173 .39383 .76589 .39228 .76403 .3897 Metetra
.681 .738 .894 r
.76403 .3897 .76589 .39228 .77005 .39073 .7682 .38815 Metetra
.681 .738 .894 r
.7682 .38815 .77005 .39073 .77423 .38919 .77238 .38661 Metetra
.68 .738 .895 r
.77238 .38661 .77423 .38919 .7784 .38765 .77656 .38507 Metetra
.68 .738 .895 r
.77656 .38507 .7784 .38765 .78259 .38612 .78075 .38354 Metetra
.679 .739 .896 r
.78075 .38354 .78259 .38612 .78678 .38459 .78495 .38201 Metetra
.679 .739 .896 r
.78495 .38201 .78678 .38459 .79098 .38307 .78915 .38048 Metetra
.678 .739 .896 r
.78915 .38048 .79098 .38307 .79518 .38155 .79335 .37896 Metetra
.678 .739 .897 r
.79335 .37896 .79518 .38155 .79939 .38003 .79757 .37744 Metetra
.677 .739 .897 r
.79757 .37744 .79939 .38003 .8036 .37851 .80179 .37592 Metetra
.677 .739 .897 r
.80179 .37592 .8036 .37851 .80782 .377 .80601 .37441 Metetra
.677 .739 .898 r
.80601 .37441 .80782 .377 .81205 .37549 .81024 .3729 Metetra
.676 .739 .898 r
.81024 .3729 .81205 .37549 .81628 .37398 .81448 .37139 Metetra
.676 .739 .898 r
.81448 .37139 .81628 .37398 .82052 .37248 .81873 .36988 Metetra
.676 .739 .898 r
.81873 .36988 .82052 .37248 .82477 .37097 .82298 .36838 Metetra
.675 .739 .899 r
.82298 .36838 .82477 .37097 .82902 .36947 .82723 .36687 Metetra
.675 .739 .899 r
.82723 .36687 .82902 .36947 .83328 .36797 .8315 .36537 Metetra
.675 .739 .899 r
.8315 .36537 .83328 .36797 .83755 .36647 .83577 .36387 Metetra
.674 .739 .899 r
.83577 .36387 .83755 .36647 .84182 .36498 .84004 .36237 Metetra
.674 .739 .9 r
.84004 .36237 .84182 .36498 .84609 .36348 .84432 .36087 Metetra
.674 .739 .9 r
.84432 .36087 .84609 .36348 .85038 .36199 .84861 .35938 Metetra
.674 .739 .9 r
.84861 .35938 .85038 .36199 .85467 .36049 .85291 .35788 Metetra
.673 .739 .9 r
.85291 .35788 .85467 .36049 .85896 .359 .85721 .35638 Metetra
.673 .74 .9 r
.85721 .35638 .85896 .359 .86326 .35751 .86151 .35489 Metetra
.673 .74 .9 r
.86151 .35489 .86326 .35751 .86757 .35602 .86583 .3534 Metetra
.673 .74 .901 r
.86583 .3534 .86757 .35602 .87189 .35452 .87015 .3519 Metetra
.673 .74 .901 r
.87015 .3519 .87189 .35452 .87621 .35303 .87447 .35041 Metetra
.672 .74 .901 r
.87447 .35041 .87621 .35303 .88054 .35154 .87881 .34892 Metetra
.672 .74 .901 r
.87881 .34892 .88054 .35154 .88487 .35005 .88314 .34742 Metetra
.672 .74 .901 r
.88314 .34742 .88487 .35005 .88921 .34856 .88749 .34593 Metetra
.672 .74 .901 r
.88749 .34593 .88921 .34856 .89356 .34707 .89184 .34444 Metetra
.672 .74 .902 r
.89184 .34444 .89356 .34707 .89791 .34558 .8962 .34294 Metetra
.671 .74 .902 r
.8962 .34294 .89791 .34558 .90227 .34409 .90056 .34145 Metetra
.671 .74 .902 r
.90056 .34145 .90227 .34409 .90664 .3426 .90494 .33996 Metetra
.654 .734 .908 r
.31458 .52561 .31683 .52777 .32038 .52672 .31813 .52456 Metetra
.654 .734 .908 r
.31813 .52456 .32038 .52672 .32394 .52568 .32169 .52352 Metetra
.653 .734 .908 r
.32169 .52352 .32394 .52568 .3275 .52463 .32525 .52247 Metetra
.653 .734 .908 r
.32525 .52247 .3275 .52463 .33106 .52359 .32881 .52142 Metetra
.653 .734 .908 r
.32881 .52142 .33106 .52359 .33463 .52254 .33239 .52037 Metetra
.653 .733 .908 r
.33239 .52037 .33463 .52254 .3382 .5215 .33596 .51932 Metetra
.653 .733 .908 r
.33596 .51932 .3382 .5215 .34178 .52046 .33954 .51828 Metetra
.652 .733 .908 r
.33954 .51828 .34178 .52046 .34536 .51942 .34313 .51723 Metetra
.652 .733 .908 r
.34313 .51723 .34536 .51942 .34895 .51838 .34672 .51619 Metetra
.652 .733 .908 r
.34672 .51619 .34895 .51838 .35255 .51734 .35032 .51514 Metetra
.652 .732 .908 r
.35032 .51514 .35255 .51734 .35614 .5163 .35392 .5141 Metetra
.651 .732 .908 r
.35392 .5141 .35614 .5163 .35975 .51526 .35752 .51306 Metetra
.651 .732 .908 r
.35752 .51306 .35975 .51526 .36336 .51422 .36114 .51202 Metetra
.651 .732 .908 r
.36114 .51202 .36336 .51422 .36697 .51319 .36475 .51098 Metetra
.65 .732 .909 r
.36475 .51098 .36697 .51319 .37059 .51216 .36837 .50994 Metetra
.65 .731 .909 r
.36837 .50994 .37059 .51216 .37421 .51112 .372 .5089 Metetra
.65 .731 .909 r
.372 .5089 .37421 .51112 .37784 .51009 .37563 .50787 Metetra
.649 .731 .909 r
.37563 .50787 .37784 .51009 .38147 .50907 .37927 .50684 Metetra
.649 .731 .909 r
.37927 .50684 .38147 .50907 .38511 .50804 .38291 .50581 Metetra
.649 .73 .909 r
.38291 .50581 .38511 .50804 .38875 .50702 .38656 .50478 Metetra
.648 .73 .909 r
.38656 .50478 .38875 .50702 .3924 .50599 .39021 .50375 Metetra
.648 .73 .909 r
.39021 .50375 .3924 .50599 .39606 .50498 .39386 .50273 Metetra
.648 .729 .909 r
.39386 .50273 .39606 .50498 .39972 .50396 .39753 .5017 Metetra
.647 .729 .909 r
.39753 .5017 .39972 .50396 .40338 .50295 .40119 .50069 Metetra
.647 .729 .909 r
.40119 .50069 .40338 .50295 .40705 .50194 .40487 .49967 Metetra
.646 .728 .909 r
.40487 .49967 .40705 .50194 .41072 .50093 .40854 .49866 Metetra
.646 .728 .909 r
.40854 .49866 .41072 .50093 .4144 .49992 .41223 .49765 Metetra
.645 .728 .909 r
.41223 .49765 .4144 .49992 .41809 .49892 .41591 .49664 Metetra
.645 .727 .909 r
.41591 .49664 .41809 .49892 .42178 .49793 .41961 .49564 Metetra
.644 .727 .909 r
.41961 .49564 .42178 .49793 .42547 .49694 .42331 .49464 Metetra
.643 .726 .909 r
.42331 .49464 .42547 .49694 .42918 .49595 .42701 .49365 Metetra
.643 .726 .909 r
.42701 .49365 .42918 .49595 .43288 .49497 .43072 .49266 Metetra
.642 .725 .909 r
.43072 .49266 .43288 .49497 .43659 .49399 .43443 .49168 Metetra
.641 .725 .909 r
.43443 .49168 .43659 .49399 .44031 .49302 .43815 .4907 Metetra
.64 .724 .909 r
.43815 .4907 .44031 .49302 .44403 .49206 .44188 .48973 Metetra
.64 .723 .909 r
.44188 .48973 .44403 .49206 .44776 .4911 .44561 .48877 Metetra
.639 .723 .909 r
.44561 .48877 .44776 .4911 .45149 .49015 .44935 .48781 Metetra
.638 .722 .909 r
.44935 .48781 .45149 .49015 .45523 .48921 .45309 .48686 Metetra
.637 .721 .909 r
.45309 .48686 .45523 .48921 .45898 .48827 .45684 .48592 Metetra
.636 .721 .909 r
.45684 .48592 .45898 .48827 .46273 .48735 .46059 .48498 Metetra
.635 .72 .909 r
.46059 .48498 .46273 .48735 .46648 .48643 .46435 .48406 Metetra
.633 .719 .909 r
.46435 .48406 .46648 .48643 .47024 .48553 .46811 .48315 Metetra
.632 .718 .909 r
.46811 .48315 .47024 .48553 .47401 .48463 .47188 .48224 Metetra
.631 .717 .909 r
.47188 .48224 .47401 .48463 .47778 .48375 .47566 .48135 Metetra
.629 .716 .909 r
.47566 .48135 .47778 .48375 .48156 .48288 .47944 .48047 Metetra
.628 .715 .909 r
.47944 .48047 .48156 .48288 .48535 .48203 .48323 .47961 Metetra
.626 .713 .909 r
.48323 .47961 .48535 .48203 .48914 .48119 .48702 .47876 Metetra
.624 .712 .909 r
.48702 .47876 .48914 .48119 .49293 .48037 .49082 .47792 Metetra
.622 .71 .909 r
.49082 .47792 .49293 .48037 .49673 .47956 .49462 .47711 Metetra
.62 .709 .909 r
.49462 .47711 .49673 .47956 .50054 .47878 .49843 .47631 Metetra
.618 .707 .909 r
.49843 .47631 .50054 .47878 .50436 .47802 .50225 .47553 Metetra
.615 .705 .909 r
.50225 .47553 .50436 .47802 .50818 .47728 .50607 .47478 Metetra
.612 .703 .909 r
.50607 .47478 .50818 .47728 .512 .47657 .5099 .47406 Metetra
.609 .701 .909 r
.5099 .47406 .512 .47657 .51584 .47589 .51374 .47336 Metetra
.605 .698 .909 r
.51374 .47336 .51584 .47589 .51968 .47524 .51758 .47269 Metetra
.602 .695 .909 r
.51758 .47269 .51968 .47524 .52352 .47463 .52143 .47206 Metetra
.597 .692 .909 r
.52143 .47206 .52352 .47463 .52738 .47406 .52529 .47147 Metetra
.592 .688 .909 r
.52529 .47147 .52738 .47406 .53124 .47354 .52915 .47092 Metetra
.587 .684 .908 r
.52915 .47092 .53124 .47354 .5351 .47307 .53302 .47042 Metetra
.581 .679 .908 r
.53302 .47042 .5351 .47307 .53898 .47266 .5369 .46998 Metetra
.574 .674 .908 r
.5369 .46998 .53898 .47266 .54286 .47231 .54078 .4696 Metetra
.565 .668 .907 r
.54078 .4696 .54286 .47231 .54675 .47204 .54468 .46929 Metetra
.556 .661 .906 r
.54468 .46929 .54675 .47204 .55065 .47186 .54858 .46907 Metetra
.545 .653 .906 r
.54858 .46907 .55065 .47186 .55456 .47179 .55249 .46895 Metetra
.532 .643 .904 r
.55249 .46895 .55456 .47179 .55848 .47183 .55641 .46893 Metetra
.516 .631 .903 r
.55641 .46893 .55848 .47183 .56241 .47202 .56034 .46906 Metetra
.497 .617 .9 r
.56034 .46906 .56241 .47202 .56635 .47239 .56428 .46934 Metetra
.474 .599 .897 r
.56428 .46934 .56635 .47239 .5703 .47297 .56823 .46983 Metetra
.445 .577 .892 r
.56823 .46983 .5703 .47297 .57426 .47381 .5722 .47055 Metetra
.966 .681 .44 r
.5722 .47055 .57426 .47381 .5812 .65738 .57903 .65522 Metetra
.645 .763 .934 r
.57903 .65522 .5812 .65738 .58537 .65621 .58321 .65404 Metetra
.645 .763 .934 r
.58321 .65404 .58537 .65621 .58954 .65504 .58739 .65287 Metetra
.645 .763 .934 r
.58739 .65287 .58954 .65504 .59373 .65386 .59158 .65169 Metetra
.645 .763 .934 r
.59158 .65169 .59373 .65386 .59792 .65269 .59578 .65051 Metetra
.645 .763 .934 r
.59578 .65051 .59792 .65269 .60212 .65151 .59998 .64933 Metetra
.645 .763 .934 r
.59998 .64933 .60212 .65151 .60632 .65033 .60419 .64814 Metetra
.645 .763 .934 r
.60419 .64814 .60632 .65033 .61053 .64914 .6084 .64696 Metetra
.645 .763 .934 r
.6084 .64696 .61053 .64914 .61475 .64796 .61262 .64577 Metetra
.645 .763 .934 r
.61262 .64577 .61475 .64796 .61897 .64677 .61685 .64458 Metetra
.968 .694 .461 r
.61685 .64458 .61897 .64677 .61794 .46009 .6159 .45679 Metetra
.766 .708 .798 r
.6159 .45679 .61794 .46009 .62188 .45674 .61985 .45356 Metetra
.759 .712 .809 r
.61985 .45356 .62188 .45674 .62583 .45366 .62381 .45056 Metetra
.752 .716 .818 r
.62381 .45056 .62583 .45366 .62979 .45079 .62777 .44776 Metetra
.746 .719 .826 r
.62777 .44776 .62979 .45079 .63376 .44809 .63175 .44512 Metetra
.741 .721 .833 r
.63175 .44512 .63376 .44809 .63773 .44553 .63573 .44262 Metetra
.736 .723 .839 r
.63573 .44262 .63773 .44553 .64172 .44309 .63971 .44022 Metetra
.731 .725 .845 r
.63971 .44022 .64172 .44309 .6457 .44076 .64371 .43793 Metetra
.727 .726 .849 r
.64371 .43793 .6457 .44076 .6497 .43852 .64771 .43572 Metetra
.723 .728 .854 r
.64771 .43572 .6497 .43852 .6537 .43635 .65171 .43358 Metetra
.72 .729 .857 r
.65171 .43358 .6537 .43635 .65771 .43425 .65573 .4315 Metetra
.717 .73 .861 r
.65573 .4315 .65771 .43425 .66172 .43221 .65975 .42948 Metetra
.714 .731 .864 r
.65975 .42948 .66172 .43221 .66574 .43022 .66377 .42751 Metetra
.711 .731 .867 r
.66377 .42751 .66574 .43022 .66977 .42827 .6678 .42558 Metetra
.709 .732 .869 r
.6678 .42558 .66977 .42827 .6738 .42637 .67184 .42369 Metetra
.706 .733 .871 r
.67184 .42369 .6738 .42637 .67784 .4245 .67588 .42183 Metetra
.704 .733 .873 r
.67588 .42183 .67784 .4245 .68188 .42267 .67993 .42001 Metetra
.702 .734 .875 r
.67993 .42001 .68188 .42267 .68593 .42086 .68399 .41821 Metetra
.7 .734 .877 r
.68399 .41821 .68593 .42086 .68999 .41908 .68805 .41644 Metetra
.699 .735 .879 r
.68805 .41644 .68999 .41908 .69405 .41732 .69211 .41469 Metetra
.697 .735 .88 r
.69211 .41469 .69405 .41732 .69812 .41559 .69619 .41296 Metetra
.695 .735 .881 r
.69619 .41296 .69812 .41559 .7022 .41388 .70027 .41126 Metetra
.694 .736 .883 r
.70027 .41126 .7022 .41388 .70628 .41218 .70435 .40956 Metetra
.693 .736 .884 r
.70435 .40956 .70628 .41218 .71036 .4105 .70844 .40789 Metetra
.692 .736 .885 r
.70844 .40789 .71036 .4105 .71445 .40884 .71254 .40623 Metetra
.69 .736 .886 r
.71254 .40623 .71445 .40884 .71855 .40719 .71664 .40458 Metetra
.689 .737 .887 r
.71664 .40458 .71855 .40719 .72266 .40555 .72075 .40295 Metetra
.688 .737 .888 r
.72075 .40295 .72266 .40555 .72677 .40392 .72487 .40133 Metetra
.687 .737 .889 r
.72487 .40133 .72677 .40392 .73088 .40231 .72899 .39971 Metetra
.687 .737 .889 r
.72899 .39971 .73088 .40231 .73501 .40071 .73311 .39811 Metetra
.686 .737 .89 r
.73311 .39811 .73501 .40071 .73913 .39911 .73725 .39652 Metetra
.685 .737 .891 r
.73725 .39652 .73913 .39911 .74327 .39752 .74138 .39493 Metetra
.684 .738 .891 r
.74138 .39493 .74327 .39752 .74741 .39594 .74553 .39335 Metetra
.683 .738 .892 r
.74553 .39335 .74741 .39594 .75156 .39437 .74968 .39178 Metetra
.683 .738 .893 r
.74968 .39178 .75156 .39437 .75571 .39281 .75384 .39022 Metetra
.682 .738 .893 r
.75384 .39022 .75571 .39281 .75987 .39125 .758 .38866 Metetra
.681 .738 .894 r
.758 .38866 .75987 .39125 .76403 .3897 .76217 .38711 Metetra
.681 .738 .894 r
.76217 .38711 .76403 .3897 .7682 .38815 .76634 .38556 Metetra
.68 .738 .894 r
.76634 .38556 .7682 .38815 .77238 .38661 .77053 .38402 Metetra
.68 .738 .895 r
.77053 .38402 .77238 .38661 .77656 .38507 .77471 .38248 Metetra
.679 .738 .895 r
.77471 .38248 .77656 .38507 .78075 .38354 .77891 .38094 Metetra
.679 .739 .896 r
.77891 .38094 .78075 .38354 .78495 .38201 .78311 .37941 Metetra
.678 .739 .896 r
.78311 .37941 .78495 .38201 .78915 .38048 .78731 .37789 Metetra
.678 .739 .896 r
.78731 .37789 .78915 .38048 .79335 .37896 .79152 .37636 Metetra
.678 .739 .897 r
.79152 .37636 .79335 .37896 .79757 .37744 .79574 .37484 Metetra
.677 .739 .897 r
.79574 .37484 .79757 .37744 .80179 .37592 .79997 .37333 Metetra
.677 .739 .897 r
.79997 .37333 .80179 .37592 .80601 .37441 .8042 .37181 Metetra
.676 .739 .898 r
.8042 .37181 .80601 .37441 .81024 .3729 .80843 .3703 Metetra
.676 .739 .898 r
.80843 .3703 .81024 .3729 .81448 .37139 .81267 .36879 Metetra
.676 .739 .898 r
.81267 .36879 .81448 .37139 .81873 .36988 .81692 .36728 Metetra
.675 .739 .898 r
.81692 .36728 .81873 .36988 .82298 .36838 .82118 .36577 Metetra
.675 .739 .899 r
.82118 .36577 .82298 .36838 .82723 .36687 .82544 .36427 Metetra
.675 .739 .899 r
.82544 .36427 .82723 .36687 .8315 .36537 .82971 .36276 Metetra
.675 .739 .899 r
.82971 .36276 .8315 .36537 .83577 .36387 .83398 .36126 Metetra
.674 .739 .899 r
.83398 .36126 .83577 .36387 .84004 .36237 .83826 .35976 Metetra
.674 .739 .9 r
.83826 .35976 .84004 .36237 .84432 .36087 .84255 .35826 Metetra
.674 .739 .9 r
.84255 .35826 .84432 .36087 .84861 .35938 .84684 .35676 Metetra
.674 .739 .9 r
.84684 .35676 .84861 .35938 .85291 .35788 .85114 .35526 Metetra
.673 .739 .9 r
.85114 .35526 .85291 .35788 .85721 .35638 .85545 .35376 Metetra
.673 .74 .9 r
.85545 .35376 .85721 .35638 .86151 .35489 .85976 .35227 Metetra
.673 .74 .901 r
.85976 .35227 .86151 .35489 .86583 .3534 .86408 .35077 Metetra
.673 .74 .901 r
.86408 .35077 .86583 .3534 .87015 .3519 .8684 .34927 Metetra
.672 .74 .901 r
.8684 .34927 .87015 .3519 .87447 .35041 .87273 .34778 Metetra
.672 .74 .901 r
.87273 .34778 .87447 .35041 .87881 .34892 .87707 .34628 Metetra
.672 .74 .901 r
.87707 .34628 .87881 .34892 .88314 .34742 .88141 .34479 Metetra
.672 .74 .901 r
.88141 .34479 .88314 .34742 .88749 .34593 .88576 .34329 Metetra
.672 .74 .901 r
.88576 .34329 .88749 .34593 .89184 .34444 .89012 .34179 Metetra
.672 .74 .902 r
.89012 .34179 .89184 .34444 .8962 .34294 .89448 .3403 Metetra
.671 .74 .902 r
.89448 .3403 .8962 .34294 .90056 .34145 .89885 .3388 Metetra
.671 .74 .902 r
.89885 .3388 .90056 .34145 .90494 .33996 .90323 .33731 Metetra
.054 .05 .534 r
.313 .51275 .31458 .52561 .31813 .52456 .31587 .5224 Metetra
.654 .734 .908 r
.31587 .5224 .31813 .52456 .32169 .52352 .31943 .52135 Metetra
.654 .734 .908 r
.31943 .52135 .32169 .52352 .32525 .52247 .32299 .52029 Metetra
.653 .734 .908 r
.32299 .52029 .32525 .52247 .32881 .52142 .32656 .51924 Metetra
.653 .734 .908 r
.32656 .51924 .32881 .52142 .33239 .52037 .33014 .51819 Metetra
.653 .733 .908 r
.33014 .51819 .33239 .52037 .33596 .51932 .33372 .51714 Metetra
.653 .733 .908 r
.33372 .51714 .33596 .51932 .33954 .51828 .3373 .51609 Metetra
.653 .733 .908 r
.3373 .51609 .33954 .51828 .34313 .51723 .34089 .51504 Metetra
.652 .733 .908 r
.34089 .51504 .34313 .51723 .34672 .51619 .34448 .51399 Metetra
.652 .733 .908 r
.34448 .51399 .34672 .51619 .35032 .51514 .34808 .51294 Metetra
.652 .732 .908 r
.34808 .51294 .35032 .51514 .35392 .5141 .35169 .51189 Metetra
.652 .732 .908 r
.35169 .51189 .35392 .5141 .35752 .51306 .3553 .51085 Metetra
.651 .732 .908 r
.3553 .51085 .35752 .51306 .36114 .51202 .35891 .5098 Metetra
.651 .732 .908 r
.35891 .5098 .36114 .51202 .36475 .51098 .36253 .50876 Metetra
.651 .732 .908 r
.36253 .50876 .36475 .51098 .36837 .50994 .36615 .50772 Metetra
.65 .731 .908 r
.36615 .50772 .36837 .50994 .372 .5089 .36978 .50668 Metetra
.65 .731 .908 r
.36978 .50668 .372 .5089 .37563 .50787 .37342 .50564 Metetra
.65 .731 .908 r
.37342 .50564 .37563 .50787 .37927 .50684 .37706 .5046 Metetra
.649 .731 .909 r
.37706 .5046 .37927 .50684 .38291 .50581 .3807 .50356 Metetra
.649 .73 .909 r
.3807 .50356 .38291 .50581 .38656 .50478 .38435 .50253 Metetra
.649 .73 .909 r
.38435 .50253 .38656 .50478 .39021 .50375 .38801 .5015 Metetra
.648 .73 .909 r
.38801 .5015 .39021 .50375 .39386 .50273 .39167 .50047 Metetra
.648 .729 .909 r
.39167 .50047 .39386 .50273 .39753 .5017 .39533 .49944 Metetra
.647 .729 .909 r
.39533 .49944 .39753 .5017 .40119 .50069 .399 .49842 Metetra
.647 .729 .909 r
.399 .49842 .40119 .50069 .40487 .49967 .40268 .4974 Metetra
.646 .728 .909 r
.40268 .4974 .40487 .49967 .40854 .49866 .40636 .49638 Metetra
.646 .728 .909 r
.40636 .49638 .40854 .49866 .41223 .49765 .41004 .49537 Metetra
.645 .728 .909 r
.41004 .49537 .41223 .49765 .41591 .49664 .41373 .49436 Metetra
.645 .727 .909 r
.41373 .49436 .41591 .49664 .41961 .49564 .41743 .49335 Metetra
.644 .727 .909 r
.41743 .49335 .41961 .49564 .42331 .49464 .42113 .49234 Metetra
.644 .726 .909 r
.42113 .49234 .42331 .49464 .42701 .49365 .42484 .49135 Metetra
.643 .726 .909 r
.42484 .49135 .42701 .49365 .43072 .49266 .42855 .49035 Metetra
.642 .725 .909 r
.42855 .49035 .43072 .49266 .43443 .49168 .43227 .48936 Metetra
.642 .725 .909 r
.43227 .48936 .43443 .49168 .43815 .4907 .43599 .48838 Metetra
.641 .724 .909 r
.43599 .48838 .43815 .4907 .44188 .48973 .43972 .4874 Metetra
.64 .724 .909 r
.43972 .4874 .44188 .48973 .44561 .48877 .44345 .48643 Metetra
.639 .723 .909 r
.44345 .48643 .44561 .48877 .44935 .48781 .44719 .48547 Metetra
.638 .722 .909 r
.44719 .48547 .44935 .48781 .45309 .48686 .45094 .48451 Metetra
.637 .722 .909 r
.45094 .48451 .45309 .48686 .45684 .48592 .45469 .48356 Metetra
.636 .721 .909 r
.45469 .48356 .45684 .48592 .46059 .48498 .45845 .48262 Metetra
.635 .72 .909 r
.45845 .48262 .46059 .48498 .46435 .48406 .46221 .48168 Metetra
.634 .719 .909 r
.46221 .48168 .46435 .48406 .46811 .48315 .46597 .48076 Metetra
.633 .718 .909 r
.46597 .48076 .46811 .48315 .47188 .48224 .46975 .47985 Metetra
.631 .717 .909 r
.46975 .47985 .47188 .48224 .47566 .48135 .47353 .47895 Metetra
.63 .716 .909 r
.47353 .47895 .47566 .48135 .47944 .48047 .47731 .47806 Metetra
.629 .715 .909 r
.47731 .47806 .47944 .48047 .48323 .47961 .4811 .47718 Metetra
.627 .714 .909 r
.4811 .47718 .48323 .47961 .48702 .47876 .4849 .47632 Metetra
.625 .712 .909 r
.4849 .47632 .48702 .47876 .49082 .47792 .4887 .47547 Metetra
.623 .711 .909 r
.4887 .47547 .49082 .47792 .49462 .47711 .49251 .47465 Metetra
.621 .709 .909 r
.49251 .47465 .49462 .47711 .49843 .47631 .49632 .47384 Metetra
.619 .708 .909 r
.49632 .47384 .49843 .47631 .50225 .47553 .50014 .47305 Metetra
.616 .706 .909 r
.50014 .47305 .50225 .47553 .50607 .47478 .50397 .47228 Metetra
.613 .704 .909 r
.50397 .47228 .50607 .47478 .5099 .47406 .5078 .47154 Metetra
.61 .701 .909 r
.5078 .47154 .5099 .47406 .51374 .47336 .51164 .47082 Metetra
.607 .699 .909 r
.51164 .47082 .51374 .47336 .51758 .47269 .51549 .47014 Metetra
.603 .696 .909 r
.51549 .47014 .51758 .47269 .52143 .47206 .51934 .46949 Metetra
.599 .693 .908 r
.51934 .46949 .52143 .47206 .52529 .47147 .5232 .46887 Metetra
.595 .69 .908 r
.5232 .46887 .52529 .47147 .52915 .47092 .52706 .4683 Metetra
.589 .686 .908 r
.52706 .4683 .52915 .47092 .53302 .47042 .53094 .46778 Metetra
.584 .681 .908 r
.53094 .46778 .53302 .47042 .5369 .46998 .53482 .4673 Metetra
.577 .676 .908 r
.53482 .4673 .5369 .46998 .54078 .4696 .5387 .46689 Metetra
.569 .671 .907 r
.5387 .46689 .54078 .4696 .54468 .46929 .5426 .46655 Metetra
.56 .664 .906 r
.5426 .46655 .54468 .46929 .54858 .46907 .5465 .46629 Metetra
.55 .656 .906 r
.5465 .46629 .54858 .46907 .55249 .46895 .55041 .46611 Metetra
.538 .647 .904 r
.55041 .46611 .55249 .46895 .55641 .46893 .55434 .46605 Metetra
.524 .636 .903 r
.55434 .46605 .55641 .46893 .56034 .46906 .55827 .46611 Metetra
.506 .623 .901 r
.55827 .46611 .56034 .46906 .56428 .46934 .56221 .46632 Metetra
.485 .607 .898 r
.56221 .46632 .56428 .46934 .56823 .46983 .56616 .46671 Metetra
.966 .681 .442 r
.56616 .46671 .56823 .46983 .5722 .47055 .57269 .65422 Metetra
.555 .337 .539 r
.57269 .65422 .5722 .47055 .57903 .65522 .57687 .65305 Metetra
.645 .763 .934 r
.57687 .65305 .57903 .65522 .58321 .65404 .58105 .65187 Metetra
.645 .763 .934 r
.58105 .65187 .58321 .65404 .58739 .65287 .58524 .65069 Metetra
.645 .763 .934 r
.58524 .65069 .58739 .65287 .59158 .65169 .58943 .64951 Metetra
.645 .763 .934 r
.58943 .64951 .59158 .65169 .59578 .65051 .59363 .64832 Metetra
.645 .763 .934 r
.59363 .64832 .59578 .65051 .59998 .64933 .59783 .64714 Metetra
.645 .763 .934 r
.59783 .64714 .59998 .64933 .60419 .64814 .60204 .64595 Metetra
.645 .763 .934 r
.60204 .64595 .60419 .64814 .6084 .64696 .60626 .64476 Metetra
.645 .763 .934 r
.60626 .64476 .6084 .64696 .61262 .64577 .61049 .64357 Metetra
.645 .763 .934 r
.61049 .64357 .61262 .64577 .61685 .64458 .61472 .64238 Metetra
.645 .763 .934 r
.61472 .64238 .61685 .64458 .6159 .45679 .61896 .64119 Metetra
0 0 .388 r
.61896 .64119 .6159 .45679 .61985 .45356 .61782 .45039 Metetra
.756 .713 .812 r
.61782 .45039 .61985 .45356 .62381 .45056 .62178 .44748 Metetra
.75 .716 .821 r
.62178 .44748 .62381 .45056 .62777 .44776 .62575 .44475 Metetra
.744 .719 .829 r
.62575 .44475 .62777 .44776 .63175 .44512 .62973 .44217 Metetra
.739 .721 .835 r
.62973 .44217 .63175 .44512 .63573 .44262 .63372 .43971 Metetra
.734 .723 .841 r
.63372 .43971 .63573 .44262 .63971 .44022 .63771 .43736 Metetra
.729 .725 .846 r
.63771 .43736 .63971 .44022 .64371 .43793 .64171 .4351 Metetra
.725 .727 .851 r
.64171 .4351 .64371 .43793 .64771 .43572 .64571 .43292 Metetra
.722 .728 .855 r
.64571 .43292 .64771 .43572 .65171 .43358 .64972 .4308 Metetra
.718 .729 .859 r
.64972 .4308 .65171 .43358 .65573 .4315 .65374 .42875 Metetra
.715 .73 .862 r
.65374 .42875 .65573 .4315 .65975 .42948 .65777 .42675 Metetra
.712 .731 .865 r
.65777 .42675 .65975 .42948 .66377 .42751 .6618 .42479 Metetra
.71 .731 .868 r
.6618 .42479 .66377 .42751 .6678 .42558 .66583 .42288 Metetra
.707 .732 .87 r
.66583 .42288 .6678 .42558 .67184 .42369 .66987 .421 Metetra
.705 .733 .872 r
.66987 .421 .67184 .42369 .67588 .42183 .67392 .41916 Metetra
.703 .733 .874 r
.67392 .41916 .67588 .42183 .67993 .42001 .67797 .41734 Metetra
.701 .734 .876 r
.67797 .41734 .67993 .42001 .68399 .41821 .68203 .41556 Metetra
.699 .734 .878 r
.68203 .41556 .68399 .41821 .68805 .41644 .6861 .41379 Metetra
.698 .735 .879 r
.6861 .41379 .68805 .41644 .69211 .41469 .69017 .41205 Metetra
.696 .735 .881 r
.69017 .41205 .69211 .41469 .69619 .41296 .69425 .41033 Metetra
.695 .735 .882 r
.69425 .41033 .69619 .41296 .70027 .41126 .69833 .40863 Metetra
.693 .736 .883 r
.69833 .40863 .70027 .41126 .70435 .40956 .70242 .40694 Metetra
.692 .736 .884 r
.70242 .40694 .70435 .40956 .70844 .40789 .70652 .40527 Metetra
.691 .736 .885 r
.70652 .40527 .70844 .40789 .71254 .40623 .71062 .40362 Metetra
.69 .736 .886 r
.71062 .40362 .71254 .40623 .71664 .40458 .71473 .40197 Metetra
.689 .737 .887 r
.71473 .40197 .71664 .40458 .72075 .40295 .71884 .40034 Metetra
.688 .737 .888 r
.71884 .40034 .72075 .40295 .72487 .40133 .72296 .39872 Metetra
.687 .737 .889 r
.72296 .39872 .72487 .40133 .72899 .39971 .72708 .39711 Metetra
.686 .737 .89 r
.72708 .39711 .72899 .39971 .73311 .39811 .73122 .39551 Metetra
.685 .737 .89 r
.73122 .39551 .73311 .39811 .73725 .39652 .73535 .39392 Metetra
.684 .737 .891 r
.73535 .39392 .73725 .39652 .74138 .39493 .7395 .39233 Metetra
.684 .738 .892 r
.7395 .39233 .74138 .39493 .74553 .39335 .74365 .39076 Metetra
.683 .738 .892 r
.74365 .39076 .74553 .39335 .74968 .39178 .7478 .38919 Metetra
.682 .738 .893 r
.7478 .38919 .74968 .39178 .75384 .39022 .75196 .38762 Metetra
.682 .738 .893 r
.75196 .38762 .75384 .39022 .758 .38866 .75613 .38606 Metetra
.681 .738 .894 r
.75613 .38606 .758 .38866 .76217 .38711 .7603 .38451 Metetra
.681 .738 .894 r
.7603 .38451 .76217 .38711 .76634 .38556 .76448 .38296 Metetra
.68 .738 .895 r
.76448 .38296 .76634 .38556 .77053 .38402 .76867 .38142 Metetra
.68 .738 .895 r
.76867 .38142 .77053 .38402 .77471 .38248 .77286 .37988 Metetra
.679 .738 .895 r
.77286 .37988 .77471 .38248 .77891 .38094 .77706 .37835 Metetra
.679 .738 .896 r
.77706 .37835 .77891 .38094 .78311 .37941 .78126 .37682 Metetra
.678 .739 .896 r
.78126 .37682 .78311 .37941 .78731 .37789 .78547 .37529 Metetra
.678 .739 .897 r
.78547 .37529 .78731 .37789 .79152 .37636 .78969 .37376 Metetra
.677 .739 .897 r
.78969 .37376 .79152 .37636 .79574 .37484 .79391 .37224 Metetra
.677 .739 .897 r
.79391 .37224 .79574 .37484 .79997 .37333 .79814 .37072 Metetra
.677 .739 .898 r
.79814 .37072 .79997 .37333 .8042 .37181 .80237 .36921 Metetra
.676 .739 .898 r
.80237 .36921 .8042 .37181 .80843 .3703 .80662 .36769 Metetra
.676 .739 .898 r
.80662 .36769 .80843 .3703 .81267 .36879 .81086 .36618 Metetra
.676 .739 .898 r
.81086 .36618 .81267 .36879 .81692 .36728 .81512 .36467 Metetra
.675 .739 .899 r
.81512 .36467 .81692 .36728 .82118 .36577 .81938 .36316 Metetra
.675 .739 .899 r
.81938 .36316 .82118 .36577 .82544 .36427 .82364 .36165 Metetra
.675 .739 .899 r
.82364 .36165 .82544 .36427 .82971 .36276 .82791 .36015 Metetra
.674 .739 .899 r
.82791 .36015 .82971 .36276 .83398 .36126 .83219 .35864 Metetra
.674 .739 .899 r
.83219 .35864 .83398 .36126 .83826 .35976 .83648 .35714 Metetra
.674 .739 .9 r
.83648 .35714 .83826 .35976 .84255 .35826 .84077 .35564 Metetra
.674 .739 .9 r
.84077 .35564 .84255 .35826 .84684 .35676 .84507 .35414 Metetra
.673 .739 .9 r
.84507 .35414 .84684 .35676 .85114 .35526 .84937 .35264 Metetra
.673 .739 .9 r
.84937 .35264 .85114 .35526 .85545 .35376 .85368 .35114 Metetra
.673 .739 .9 r
.85368 .35114 .85545 .35376 .85976 .35227 .858 .34964 Metetra
.673 .74 .901 r
.858 .34964 .85976 .35227 .86408 .35077 .86232 .34814 Metetra
.673 .74 .901 r
.86232 .34814 .86408 .35077 .8684 .34927 .86665 .34664 Metetra
.672 .74 .901 r
.86665 .34664 .8684 .34927 .87273 .34778 .87098 .34514 Metetra
.672 .74 .901 r
.87098 .34514 .87273 .34778 .87707 .34628 .87533 .34364 Metetra
.672 .74 .901 r
.87533 .34364 .87707 .34628 .88141 .34479 .87967 .34214 Metetra
.672 .74 .901 r
.87967 .34214 .88141 .34479 .88576 .34329 .88403 .34064 Metetra
.672 .74 .902 r
.88403 .34064 .88576 .34329 .89012 .34179 .88839 .33915 Metetra
.671 .74 .902 r
.88839 .33915 .89012 .34179 .89448 .3403 .89276 .33765 Metetra
.671 .74 .902 r
.89276 .33765 .89448 .3403 .89885 .3388 .89713 .33615 Metetra
.966 .78 .602 r
.89713 .33615 .89885 .3388 .90323 .33731 .90018 .32343 Metetra
.664 .741 .907 r
.31073 .51064 .313 .51275 .31587 .5224 .31428 .50949 Metetra
.597 .443 .643 r
.31428 .50949 .31587 .5224 .31943 .52135 .31784 .50834 Metetra
.053 .049 .532 r
.31784 .50834 .31943 .52135 .32299 .52029 .32074 .51812 Metetra
.654 .734 .908 r
.32074 .51812 .32299 .52029 .32656 .51924 .32431 .51706 Metetra
.653 .734 .908 r
.32431 .51706 .32656 .51924 .33014 .51819 .32788 .51601 Metetra
.653 .733 .908 r
.32788 .51601 .33014 .51819 .33372 .51714 .33147 .51495 Metetra
.653 .733 .908 r
.33147 .51495 .33372 .51714 .3373 .51609 .33505 .5139 Metetra
.653 .733 .908 r
.33505 .5139 .3373 .51609 .34089 .51504 .33865 .51284 Metetra
.652 .733 .908 r
.33865 .51284 .34089 .51504 .34448 .51399 .34224 .51179 Metetra
.652 .733 .908 r
.34224 .51179 .34448 .51399 .34808 .51294 .34584 .51074 Metetra
.652 .733 .908 r
.34584 .51074 .34808 .51294 .35169 .51189 .34945 .50969 Metetra
.652 .732 .908 r
.34945 .50969 .35169 .51189 .3553 .51085 .35306 .50864 Metetra
.651 .732 .908 r
.35306 .50864 .3553 .51085 .35891 .5098 .35668 .50759 Metetra
.651 .732 .908 r
.35668 .50759 .35891 .5098 .36253 .50876 .3603 .50654 Metetra
.651 .732 .908 r
.3603 .50654 .36253 .50876 .36615 .50772 .36393 .50549 Metetra
.651 .731 .908 r
.36393 .50549 .36615 .50772 .36978 .50668 .36756 .50445 Metetra
.65 .731 .908 r
.36756 .50445 .36978 .50668 .37342 .50564 .3712 .5034 Metetra
.65 .731 .908 r
.3712 .5034 .37342 .50564 .37706 .5046 .37484 .50236 Metetra
.65 .731 .908 r
.37484 .50236 .37706 .5046 .3807 .50356 .37849 .50132 Metetra
.649 .73 .908 r
.37849 .50132 .3807 .50356 .38435 .50253 .38214 .50028 Metetra
.649 .73 .908 r
.38214 .50028 .38435 .50253 .38801 .5015 .3858 .49924 Metetra
.648 .73 .908 r
.3858 .49924 .38801 .5015 .39167 .50047 .38946 .49821 Metetra
.648 .73 .909 r
.38946 .49821 .39167 .50047 .39533 .49944 .39313 .49718 Metetra
.648 .729 .909 r
.39313 .49718 .39533 .49944 .399 .49842 .3968 .49615 Metetra
.647 .729 .909 r
.3968 .49615 .399 .49842 .40268 .4974 .40048 .49512 Metetra
.647 .729 .909 r
.40048 .49512 .40268 .4974 .40636 .49638 .40417 .4941 Metetra
.646 .728 .909 r
.40417 .4941 .40636 .49638 .41004 .49537 .40785 .49308 Metetra
.646 .728 .909 r
.40785 .49308 .41004 .49537 .41373 .49436 .41155 .49206 Metetra
.645 .727 .909 r
.41155 .49206 .41373 .49436 .41743 .49335 .41525 .49105 Metetra
.645 .727 .909 r
.41525 .49105 .41743 .49335 .42113 .49234 .41895 .49004 Metetra
.644 .727 .909 r
.41895 .49004 .42113 .49234 .42484 .49135 .42266 .48904 Metetra
.643 .726 .909 r
.42266 .48904 .42484 .49135 .42855 .49035 .42638 .48804 Metetra
.643 .726 .909 r
.42638 .48804 .42855 .49035 .43227 .48936 .4301 .48704 Metetra
.642 .725 .909 r
.4301 .48704 .43227 .48936 .43599 .48838 .43383 .48605 Metetra
.641 .724 .909 r
.43383 .48605 .43599 .48838 .43972 .4874 .43756 .48507 Metetra
.64 .724 .909 r
.43756 .48507 .43972 .4874 .44345 .48643 .44129 .48409 Metetra
.64 .723 .909 r
.44129 .48409 .44345 .48643 .44719 .48547 .44504 .48312 Metetra
.639 .723 .909 r
.44504 .48312 .44719 .48547 .45094 .48451 .44878 .48215 Metetra
.638 .722 .909 r
.44878 .48215 .45094 .48451 .45469 .48356 .45254 .48119 Metetra
.637 .721 .909 r
.45254 .48119 .45469 .48356 .45845 .48262 .4563 .48024 Metetra
.636 .72 .909 r
.4563 .48024 .45845 .48262 .46221 .48168 .46006 .4793 Metetra
.635 .72 .909 r
.46006 .4793 .46221 .48168 .46597 .48076 .46383 .47837 Metetra
.633 .719 .909 r
.46383 .47837 .46597 .48076 .46975 .47985 .46761 .47745 Metetra
.632 .718 .909 r
.46761 .47745 .46975 .47985 .47353 .47895 .47139 .47654 Metetra
.631 .717 .909 r
.47139 .47654 .47353 .47895 .47731 .47806 .47518 .47564 Metetra
.629 .715 .909 r
.47518 .47564 .47731 .47806 .4811 .47718 .47897 .47475 Metetra
.628 .714 .909 r
.47897 .47475 .4811 .47718 .4849 .47632 .48277 .47388 Metetra
.626 .713 .909 r
.48277 .47388 .4849 .47632 .4887 .47547 .48658 .47302 Metetra
.624 .712 .909 r
.48658 .47302 .4887 .47547 .49251 .47465 .49039 .47218 Metetra
.622 .71 .909 r
.49039 .47218 .49251 .47465 .49632 .47384 .4942 .47136 Metetra
.62 .708 .909 r
.4942 .47136 .49632 .47384 .50014 .47305 .49803 .47056 Metetra
.617 .707 .909 r
.49803 .47056 .50014 .47305 .50397 .47228 .50186 .46978 Metetra
.615 .705 .909 r
.50186 .46978 .50397 .47228 .5078 .47154 .50569 .46902 Metetra
.612 .702 .909 r
.50569 .46902 .5078 .47154 .51164 .47082 .50953 .46829 Metetra
.609 .7 .909 r
.50953 .46829 .51164 .47082 .51549 .47014 .51338 .46758 Metetra
.605 .697 .908 r
.51338 .46758 .51549 .47014 .51934 .46949 .51724 .46691 Metetra
.601 .694 .908 r
.51724 .46691 .51934 .46949 .5232 .46887 .5211 .46628 Metetra
.597 .691 .908 r
.5211 .46628 .5232 .46887 .52706 .4683 .52497 .46568 Metetra
.592 .687 .908 r
.52497 .46568 .52706 .4683 .53094 .46778 .52884 .46513 Metetra
.586 .683 .908 r
.52884 .46513 .53094 .46778 .53482 .4673 .53273 .46463 Metetra
.58 .678 .907 r
.53273 .46463 .53482 .4673 .5387 .46689 .53662 .46419 Metetra
.573 .673 .907 r
.53662 .46419 .5387 .46689 .5426 .46655 .54051 .46381 Metetra
.565 .667 .906 r
.54051 .46381 .5426 .46655 .5465 .46629 .54442 .46351 Metetra
.555 .659 .906 r
.54442 .46351 .5465 .46629 .55041 .46611 .54833 .46329 Metetra
.544 .651 .905 r
.54833 .46329 .55041 .46611 .55434 .46605 .55226 .46317 Metetra
.53 .641 .903 r
.55226 .46317 .55434 .46605 .55827 .46611 .55619 .46317 Metetra
.515 .628 .901 r
.55619 .46317 .55827 .46611 .56221 .46632 .56013 .46331 Metetra
.495 .613 .899 r
.56013 .46331 .56221 .46632 .56616 .46671 .56409 .46362 Metetra
.966 .681 .442 r
.56409 .46362 .56616 .46671 .57269 .65422 .57052 .65205 Metetra
.645 .763 .934 r
.57052 .65205 .57269 .65422 .57687 .65305 .5747 .65087 Metetra
.645 .763 .934 r
.5747 .65087 .57687 .65305 .58105 .65187 .57888 .64969 Metetra
.645 .763 .934 r
.57888 .64969 .58105 .65187 .58524 .65069 .58307 .64851 Metetra
.645 .763 .934 r
.58307 .64851 .58524 .65069 .58943 .64951 .58727 .64732 Metetra
.645 .763 .934 r
.58727 .64732 .58943 .64951 .59363 .64832 .59147 .64614 Metetra
.645 .763 .934 r
.59147 .64614 .59363 .64832 .59783 .64714 .59568 .64495 Metetra
.645 .763 .934 r
.59568 .64495 .59783 .64714 .60204 .64595 .5999 .64376 Metetra
.645 .763 .934 r
.5999 .64376 .60204 .64595 .60626 .64476 .60412 .64256 Metetra
.645 .763 .934 r
.60412 .64256 .60626 .64476 .61049 .64357 .60835 .64137 Metetra
.645 .763 .934 r
.60835 .64137 .61049 .64357 .61472 .64238 .61258 .64017 Metetra
.645 .763 .934 r
.61258 .64017 .61472 .64238 .61896 .64119 .61683 .63898 Metetra
.968 .694 .459 r
.61683 .63898 .61896 .64119 .61782 .45039 .61578 .44725 Metetra
.753 .714 .816 r
.61578 .44725 .61782 .45039 .62178 .44748 .61975 .44442 Metetra
.747 .717 .824 r
.61975 .44442 .62178 .44748 .62575 .44475 .62373 .44175 Metetra
.741 .72 .831 r
.62373 .44175 .62575 .44475 .62973 .44217 .62771 .43922 Metetra
.736 .722 .838 r
.62771 .43922 .62973 .44217 .63372 .43971 .6317 .43681 Metetra
.732 .724 .843 r
.6317 .43681 .63372 .43971 .63771 .43736 .6357 .4345 Metetra
.727 .725 .848 r
.6357 .4345 .63771 .43736 .64171 .4351 .6397 .43227 Metetra
.724 .727 .853 r
.6397 .43227 .64171 .4351 .64571 .43292 .64371 .43012 Metetra
.72 .728 .857 r
.64371 .43012 .64571 .43292 .64972 .4308 .64773 .42803 Metetra
.717 .729 .86 r
.64773 .42803 .64972 .4308 .65374 .42875 .65175 .426 Metetra
.714 .73 .863 r
.65175 .426 .65374 .42875 .65777 .42675 .65578 .42402 Metetra
.711 .731 .866 r
.65578 .42402 .65777 .42675 .6618 .42479 .65982 .42208 Metetra
.709 .732 .869 r
.65982 .42208 .6618 .42479 .66583 .42288 .66386 .42018 Metetra
.706 .732 .871 r
.66386 .42018 .66583 .42288 .66987 .421 .6679 .41831 Metetra
.704 .733 .873 r
.6679 .41831 .66987 .421 .67392 .41916 .67196 .41648 Metetra
.702 .733 .875 r
.67196 .41648 .67392 .41916 .67797 .41734 .67601 .41468 Metetra
.7 .734 .877 r
.67601 .41468 .67797 .41734 .68203 .41556 .68008 .4129 Metetra
.699 .734 .878 r
.68008 .4129 .68203 .41556 .6861 .41379 .68415 .41114 Metetra
.697 .735 .88 r
.68415 .41114 .6861 .41379 .69017 .41205 .68822 .40941 Metetra
.696 .735 .881 r
.68822 .40941 .69017 .41205 .69425 .41033 .69231 .4077 Metetra
.694 .735 .882 r
.69231 .4077 .69425 .41033 .69833 .40863 .69639 .406 Metetra
.693 .736 .884 r
.69639 .406 .69833 .40863 .70242 .40694 .70049 .40432 Metetra
.692 .736 .885 r
.70049 .40432 .70242 .40694 .70652 .40527 .70459 .40265 Metetra
.69 .736 .886 r
.70459 .40265 .70652 .40527 .71062 .40362 .70869 .401 Metetra
.689 .736 .887 r
.70869 .401 .71062 .40362 .71473 .40197 .71281 .39936 Metetra
.688 .737 .888 r
.71281 .39936 .71473 .40197 .71884 .40034 .71692 .39773 Metetra
.687 .737 .888 r
.71692 .39773 .71884 .40034 .72296 .39872 .72105 .39611 Metetra
.687 .737 .889 r
.72105 .39611 .72296 .39872 .72708 .39711 .72518 .39451 Metetra
.686 .737 .89 r
.72518 .39451 .72708 .39711 .73122 .39551 .72931 .39291 Metetra
.685 .737 .891 r
.72931 .39291 .73122 .39551 .73535 .39392 .73345 .39131 Metetra
.684 .737 .891 r
.73345 .39131 .73535 .39392 .7395 .39233 .7376 .38973 Metetra
.683 .738 .892 r
.7376 .38973 .7395 .39233 .74365 .39076 .74176 .38816 Metetra
.683 .738 .892 r
.74176 .38816 .74365 .39076 .7478 .38919 .74592 .38659 Metetra
.682 .738 .893 r
.74592 .38659 .7478 .38919 .75196 .38762 .75008 .38502 Metetra
.681 .738 .893 r
.75008 .38502 .75196 .38762 .75613 .38606 .75425 .38346 Metetra
.681 .738 .894 r
.75425 .38346 .75613 .38606 .7603 .38451 .75843 .38191 Metetra
.68 .738 .894 r
.75843 .38191 .7603 .38451 .76448 .38296 .76262 .38036 Metetra
.68 .738 .895 r
.76262 .38036 .76448 .38296 .76867 .38142 .76681 .37882 Metetra
.679 .738 .895 r
.76681 .37882 .76867 .38142 .77286 .37988 .771 .37728 Metetra
.679 .738 .896 r
.771 .37728 .77286 .37988 .77706 .37835 .7752 .37574 Metetra
.678 .738 .896 r
.7752 .37574 .77706 .37835 .78126 .37682 .77941 .37421 Metetra
.678 .739 .896 r
.77941 .37421 .78126 .37682 .78547 .37529 .78363 .37268 Metetra
.678 .739 .897 r
.78363 .37268 .78547 .37529 .78969 .37376 .78785 .37116 Metetra
.677 .739 .897 r
.78785 .37116 .78969 .37376 .79391 .37224 .79208 .36964 Metetra
.677 .739 .897 r
.79208 .36964 .79391 .37224 .79814 .37072 .79631 .36812 Metetra
.676 .739 .898 r
.79631 .36812 .79814 .37072 .80237 .36921 .80055 .3666 Metetra
.676 .739 .898 r
.80055 .3666 .80237 .36921 .80662 .36769 .80479 .36508 Metetra
.676 .739 .898 r
.80479 .36508 .80662 .36769 .81086 .36618 .80905 .36357 Metetra
.675 .739 .898 r
.80905 .36357 .81086 .36618 .81512 .36467 .8133 .36205 Metetra
.675 .739 .899 r
.8133 .36205 .81512 .36467 .81938 .36316 .81757 .36054 Metetra
.675 .739 .899 r
.81757 .36054 .81938 .36316 .82364 .36165 .82184 .35904 Metetra
.675 .739 .899 r
.82184 .35904 .82364 .36165 .82791 .36015 .82612 .35753 Metetra
.674 .739 .899 r
.82612 .35753 .82791 .36015 .83219 .35864 .8304 .35602 Metetra
.674 .739 .9 r
.8304 .35602 .83219 .35864 .83648 .35714 .83469 .35452 Metetra
.674 .739 .9 r
.83469 .35452 .83648 .35714 .84077 .35564 .83898 .35301 Metetra
.673 .739 .9 r
.83898 .35301 .84077 .35564 .84507 .35414 .84329 .35151 Metetra
.673 .739 .9 r
.84329 .35151 .84507 .35414 .84937 .35264 .84759 .35 Metetra
.673 .739 .9 r
.84759 .35 .84937 .35264 .85368 .35114 .85191 .3485 Metetra
.673 .739 .901 r
.85191 .3485 .85368 .35114 .858 .34964 .85623 .347 Metetra
.673 .74 .901 r
.85623 .347 .858 .34964 .86232 .34814 .86056 .3455 Metetra
.672 .74 .901 r
.86056 .3455 .86232 .34814 .86665 .34664 .86489 .344 Metetra
.672 .74 .901 r
.86489 .344 .86665 .34664 .87098 .34514 .86923 .34249 Metetra
.672 .74 .901 r
.86923 .34249 .87098 .34514 .87533 .34364 .87358 .34099 Metetra
.672 .74 .901 r
.87358 .34099 .87533 .34364 .87967 .34214 .87793 .33949 Metetra
.672 .74 .901 r
.87793 .33949 .87967 .34214 .88403 .34064 .88229 .33799 Metetra
.671 .74 .902 r
.88229 .33799 .88403 .34064 .88839 .33915 .88666 .33649 Metetra
.965 .779 .601 r
.88666 .33649 .88839 .33915 .89276 .33765 .88972 .32365 Metetra
.597 .442 .642 r
.88972 .32365 .89276 .33765 .89713 .33615 .89409 .32223 Metetra
.597 .443 .643 r
.89409 .32223 .89713 .33615 .90018 .32343 .89847 .32082 Metetra
.664 .741 .907 r
.30846 .50852 .31073 .51064 .31428 .50949 .31202 .50737 Metetra
.664 .741 .907 r
.31202 .50737 .31428 .50949 .31784 .50834 .31558 .50622 Metetra
.664 .741 .907 r
.31558 .50622 .31784 .50834 .32074 .51812 .31914 .50506 Metetra
.053 .048 .532 r
.31914 .50506 .32074 .51812 .32431 .51706 .32205 .51488 Metetra
.653 .734 .908 r
.32205 .51488 .32431 .51706 .32788 .51601 .32563 .51382 Metetra
.653 .734 .908 r
.32563 .51382 .32788 .51601 .33147 .51495 .32921 .51276 Metetra
.653 .733 .908 r
.32921 .51276 .33147 .51495 .33505 .5139 .3328 .5117 Metetra
.653 .733 .908 r
.3328 .5117 .33505 .5139 .33865 .51284 .3364 .51064 Metetra
.653 .733 .908 r
.3364 .51064 .33865 .51284 .34224 .51179 .34 .50958 Metetra
.652 .733 .908 r
.34 .50958 .34224 .51179 .34584 .51074 .3436 .50853 Metetra
.652 .733 .908 r
.3436 .50853 .34584 .51074 .34945 .50969 .34721 .50747 Metetra
.652 .732 .908 r
.34721 .50747 .34945 .50969 .35306 .50864 .35082 .50642 Metetra
.652 .732 .908 r
.35082 .50642 .35306 .50864 .35668 .50759 .35444 .50536 Metetra
.651 .732 .908 r
.35444 .50536 .35668 .50759 .3603 .50654 .35807 .50431 Metetra
.651 .732 .908 r
.35807 .50431 .3603 .50654 .36393 .50549 .3617 .50326 Metetra
.651 .732 .908 r
.3617 .50326 .36393 .50549 .36756 .50445 .36534 .50221 Metetra
.65 .731 .908 r
.36534 .50221 .36756 .50445 .3712 .5034 .36898 .50116 Metetra
.65 .731 .908 r
.36898 .50116 .3712 .5034 .37484 .50236 .37262 .50011 Metetra
.65 .731 .908 r
.37262 .50011 .37484 .50236 .37849 .50132 .37627 .49907 Metetra
.649 .731 .908 r
.37627 .49907 .37849 .50132 .38214 .50028 .37993 .49803 Metetra
.649 .73 .908 r
.37993 .49803 .38214 .50028 .3858 .49924 .38359 .49698 Metetra
.649 .73 .908 r
.38359 .49698 .3858 .49924 .38946 .49821 .38725 .49595 Metetra
.648 .73 .908 r
.38725 .49595 .38946 .49821 .39313 .49718 .39092 .49491 Metetra
.648 .729 .908 r
.39092 .49491 .39313 .49718 .3968 .49615 .3946 .49387 Metetra
.647 .729 .908 r
.3946 .49387 .3968 .49615 .40048 .49512 .39828 .49284 Metetra
.647 .729 .908 r
.39828 .49284 .40048 .49512 .40417 .4941 .40197 .49181 Metetra
.646 .728 .908 r
.40197 .49181 .40417 .4941 .40785 .49308 .40566 .49079 Metetra
.646 .728 .909 r
.40566 .49079 .40785 .49308 .41155 .49206 .40936 .48977 Metetra
.645 .728 .909 r
.40936 .48977 .41155 .49206 .41525 .49105 .41306 .48875 Metetra
.645 .727 .909 r
.41306 .48875 .41525 .49105 .41895 .49004 .41677 .48773 Metetra
.644 .727 .909 r
.41677 .48773 .41895 .49004 .42266 .48904 .42048 .48672 Metetra
.644 .726 .909 r
.42048 .48672 .42266 .48904 .42638 .48804 .4242 .48572 Metetra
.643 .726 .909 r
.4242 .48572 .42638 .48804 .4301 .48704 .42792 .48471 Metetra
.642 .725 .909 r
.42792 .48471 .4301 .48704 .43383 .48605 .43165 .48372 Metetra
.642 .725 .909 r
.43165 .48372 .43383 .48605 .43756 .48507 .43539 .48273 Metetra
.641 .724 .909 r
.43539 .48273 .43756 .48507 .44129 .48409 .43913 .48174 Metetra
.64 .724 .909 r
.43913 .48174 .44129 .48409 .44504 .48312 .44287 .48076 Metetra
.639 .723 .909 r
.44287 .48076 .44504 .48312 .44878 .48215 .44662 .47979 Metetra
.638 .722 .909 r
.44662 .47979 .44878 .48215 .45254 .48119 .45038 .47882 Metetra
.637 .721 .909 r
.45038 .47882 .45254 .48119 .4563 .48024 .45414 .47787 Metetra
.636 .721 .909 r
.45414 .47787 .4563 .48024 .46006 .4793 .45791 .47692 Metetra
.635 .72 .909 r
.45791 .47692 .46006 .4793 .46383 .47837 .46168 .47598 Metetra
.634 .719 .909 r
.46168 .47598 .46383 .47837 .46761 .47745 .46546 .47505 Metetra
.633 .718 .909 r
.46546 .47505 .46761 .47745 .47139 .47654 .46925 .47413 Metetra
.631 .717 .909 r
.46925 .47413 .47139 .47654 .47518 .47564 .47304 .47322 Metetra
.63 .716 .909 r
.47304 .47322 .47518 .47564 .47897 .47475 .47684 .47232 Metetra
.629 .715 .909 r
.47684 .47232 .47897 .47475 .48277 .47388 .48064 .47144 Metetra
.627 .713 .909 r
.48064 .47144 .48277 .47388 .48658 .47302 .48445 .47057 Metetra
.625 .712 .909 r
.48445 .47057 .48658 .47302 .49039 .47218 .48826 .46972 Metetra
.623 .711 .909 r
.48826 .46972 .49039 .47218 .4942 .47136 .49208 .46888 Metetra
.621 .709 .909 r
.49208 .46888 .4942 .47136 .49803 .47056 .49591 .46807 Metetra
.619 .707 .909 r
.49591 .46807 .49803 .47056 .50186 .46978 .49974 .46727 Metetra
.616 .705 .909 r
.49974 .46727 .50186 .46978 .50569 .46902 .50358 .4665 Metetra
.613 .703 .908 r
.50358 .4665 .50569 .46902 .50953 .46829 .50742 .46575 Metetra
.61 .701 .908 r
.50742 .46575 .50953 .46829 .51338 .46758 .51127 .46503 Metetra
.607 .698 .908 r
.51127 .46503 .51338 .46758 .51724 .46691 .51513 .46434 Metetra
.603 .696 .908 r
.51513 .46434 .51724 .46691 .5211 .46628 .519 .46368 Metetra
.599 .692 .908 r
.519 .46368 .5211 .46628 .52497 .46568 .52287 .46307 Metetra
.594 .689 .908 r
.52287 .46307 .52497 .46568 .52884 .46513 .52675 .46249 Metetra
.589 .685 .908 r
.52675 .46249 .52884 .46513 .53273 .46463 .53063 .46196 Metetra
.583 .68 .907 r
.53063 .46196 .53273 .46463 .53662 .46419 .53452 .46149 Metetra
.576 .675 .907 r
.53452 .46149 .53662 .46419 .54051 .46381 .53842 .46108 Metetra
.569 .669 .906 r
.53842 .46108 .54051 .46381 .54442 .46351 .54233 .46073 Metetra
.56 .662 .906 r
.54233 .46073 .54442 .46351 .54833 .46329 .54625 .46047 Metetra
.549 .654 .905 r
.54625 .46047 .54833 .46329 .55226 .46317 .55017 .4603 Metetra
.537 .645 .903 r
.55017 .4603 .55226 .46317 .55619 .46317 .55411 .46025 Metetra
.522 .634 .902 r
.55411 .46025 .55619 .46317 .56013 .46331 .55805 .46032 Metetra
.965 .681 .444 r
.55805 .46032 .56013 .46331 .56409 .46362 .56416 .65105 Metetra
.554 .336 .539 r
.56416 .65105 .56409 .46362 .57052 .65205 .56834 .64987 Metetra
.645 .763 .934 r
.56834 .64987 .57052 .65205 .5747 .65087 .57252 .64869 Metetra
.645 .763 .934 r
.57252 .64869 .5747 .65087 .57888 .64969 .57671 .6475 Metetra
.645 .763 .934 r
.57671 .6475 .57888 .64969 .58307 .64851 .5809 .64632 Metetra
.842 .797 .808 r
.5809 .64632 .58307 .64851 .58727 .64732 .58505 .64184 Metetra
.789 .648 .706 r
.58505 .64184 .58727 .64732 .59147 .64614 .58916 .63572 Metetra
.605 .473 .675 r
.58916 .63572 .59147 .64614 .59568 .64495 .59336 .63453 Metetra
.418 .35 .674 r
.59336 .63453 .59568 .64495 .5999 .64376 .59768 .63826 Metetra
.398 .437 .785 r
.59768 .63826 .5999 .64376 .60412 .64256 .60197 .64036 Metetra
.645 .763 .934 r
.60197 .64036 .60412 .64256 .60835 .64137 .6062 .63916 Metetra
.645 .763 .934 r
.6062 .63916 .60835 .64137 .61258 .64017 .61044 .63796 Metetra
.645 .763 .934 r
.61044 .63796 .61258 .64017 .61683 .63898 .61469 .63676 Metetra
.645 .763 .934 r
.61469 .63676 .61683 .63898 .61578 .44725 .61894 .63556 Metetra
0 0 .388 r
.61894 .63556 .61578 .44725 .61975 .44442 .61771 .44137 Metetra
.744 .718 .827 r
.61771 .44137 .61975 .44442 .62373 .44175 .6217 .43877 Metetra
.739 .72 .834 r
.6217 .43877 .62373 .44175 .62771 .43922 .62569 .43629 Metetra
.734 .722 .84 r
.62569 .43629 .62771 .43922 .6317 .43681 .62968 .43392 Metetra
.73 .724 .845 r
.62968 .43392 .6317 .43681 .6357 .4345 .63369 .43165 Metetra
.726 .726 .85 r
.63369 .43165 .6357 .4345 .6397 .43227 .6377 .42945 Metetra
.722 .727 .854 r
.6377 .42945 .6397 .43227 .64371 .43012 .64171 .42732 Metetra
.719 .728 .858 r
.64171 .42732 .64371 .43012 .64773 .42803 .64573 .42526 Metetra
.715 .729 .861 r
.64573 .42526 .64773 .42803 .65175 .426 .64976 .42325 Metetra
.713 .73 .864 r
.64976 .42325 .65175 .426 .65578 .42402 .65379 .42128 Metetra
.71 .731 .867 r
.65379 .42128 .65578 .42402 .65982 .42208 .65783 .41936 Metetra
.707 .732 .87 r
.65783 .41936 .65982 .42208 .66386 .42018 .66188 .41748 Metetra
.705 .732 .872 r
.66188 .41748 .66386 .42018 .6679 .41831 .66593 .41562 Metetra
.703 .733 .874 r
.66593 .41562 .6679 .41831 .67196 .41648 .66998 .4138 Metetra
.701 .733 .876 r
.66998 .4138 .67196 .41648 .67601 .41468 .67405 .41201 Metetra
.699 .734 .877 r
.67405 .41201 .67601 .41468 .68008 .4129 .67812 .41024 Metetra
.698 .734 .879 r
.67812 .41024 .68008 .4129 .68415 .41114 .68219 .40849 Metetra
.696 .735 .88 r
.68219 .40849 .68415 .41114 .68822 .40941 .68627 .40677 Metetra
.695 .735 .882 r
.68627 .40677 .68822 .40941 .69231 .4077 .69036 .40506 Metetra
.693 .735 .883 r
.69036 .40506 .69231 .4077 .69639 .406 .69445 .40337 Metetra
.692 .736 .884 r
.69445 .40337 .69639 .406 .70049 .40432 .69855 .40169 Metetra
.691 .736 .885 r
.69855 .40169 .70049 .40432 .70459 .40265 .70265 .40003 Metetra
.69 .736 .886 r
.70265 .40003 .70459 .40265 .70869 .401 .70676 .39838 Metetra
.689 .736 .887 r
.70676 .39838 .70869 .401 .71281 .39936 .71088 .39674 Metetra
.688 .736 .888 r
.71088 .39674 .71281 .39936 .71692 .39773 .715 .39512 Metetra
.687 .737 .889 r
.715 .39512 .71692 .39773 .72105 .39611 .71913 .3935 Metetra
.686 .737 .889 r
.71913 .3935 .72105 .39611 .72518 .39451 .72326 .39189 Metetra
.685 .737 .89 r
.72326 .39189 .72518 .39451 .72931 .39291 .72741 .3903 Metetra
.684 .737 .891 r
.72741 .3903 .72931 .39291 .73345 .39131 .73155 .38871 Metetra
.684 .737 .891 r
.73155 .38871 .73345 .39131 .7376 .38973 .7357 .38712 Metetra
.683 .737 .892 r
.7357 .38712 .7376 .38973 .74176 .38816 .73986 .38555 Metetra
.682 .738 .893 r
.73986 .38555 .74176 .38816 .74592 .38659 .74403 .38398 Metetra
.682 .738 .893 r
.74403 .38398 .74592 .38659 .75008 .38502 .7482 .38242 Metetra
.681 .738 .894 r
.7482 .38242 .75008 .38502 .75425 .38346 .75237 .38086 Metetra
.681 .738 .894 r
.75237 .38086 .75425 .38346 .75843 .38191 .75656 .3793 Metetra
.68 .738 .895 r
.75656 .3793 .75843 .38191 .76262 .38036 .76074 .37776 Metetra
.68 .738 .895 r
.76074 .37776 .76262 .38036 .76681 .37882 .76494 .37621 Metetra
.679 .738 .895 r
.76494 .37621 .76681 .37882 .771 .37728 .76914 .37467 Metetra
.679 .738 .896 r
.76914 .37467 .771 .37728 .7752 .37574 .77335 .37314 Metetra
.678 .738 .896 r
.77335 .37314 .7752 .37574 .77941 .37421 .77756 .3716 Metetra
.678 .739 .896 r
.77756 .3716 .77941 .37421 .78363 .37268 .78178 .37007 Metetra
.677 .739 .897 r
.78178 .37007 .78363 .37268 .78785 .37116 .786 .36855 Metetra
.677 .739 .897 r
.786 .36855 .78785 .37116 .79208 .36964 .79024 .36702 Metetra
.677 .739 .897 r
.79024 .36702 .79208 .36964 .79631 .36812 .79447 .3655 Metetra
.676 .739 .898 r
.79447 .3655 .79631 .36812 .80055 .3666 .79872 .36398 Metetra
.676 .739 .898 r
.79872 .36398 .80055 .3666 .80479 .36508 .80297 .36246 Metetra
.676 .739 .898 r
.80297 .36246 .80479 .36508 .80905 .36357 .80722 .36095 Metetra
.675 .739 .899 r
.80722 .36095 .80905 .36357 .8133 .36205 .81149 .35943 Metetra
.675 .739 .899 r
.81149 .35943 .8133 .36205 .81757 .36054 .81576 .35792 Metetra
.675 .739 .899 r
.81576 .35792 .81757 .36054 .82184 .35904 .82003 .35641 Metetra
.674 .739 .899 r
.82003 .35641 .82184 .35904 .82612 .35753 .82431 .3549 Metetra
.674 .739 .899 r
.82431 .3549 .82612 .35753 .8304 .35602 .8286 .35339 Metetra
.674 .739 .9 r
.8286 .35339 .8304 .35602 .83469 .35452 .83289 .35188 Metetra
.674 .739 .9 r
.83289 .35188 .83469 .35452 .83898 .35301 .8372 .35038 Metetra
.673 .739 .9 r
.8372 .35038 .83898 .35301 .84329 .35151 .8415 .34887 Metetra
.673 .739 .9 r
.8415 .34887 .84329 .35151 .84759 .35 .84582 .34736 Metetra
.673 .739 .9 r
.84582 .34736 .84759 .35 .85191 .3485 .85013 .34586 Metetra
.673 .739 .901 r
.85013 .34586 .85191 .3485 .85623 .347 .85446 .34436 Metetra
.672 .739 .901 r
.85446 .34436 .85623 .347 .86056 .3455 .85879 .34285 Metetra
.672 .74 .901 r
.85879 .34285 .86056 .3455 .86489 .344 .86313 .34135 Metetra
.672 .74 .901 r
.86313 .34135 .86489 .344 .86923 .34249 .86748 .33984 Metetra
.672 .74 .901 r
.86748 .33984 .86923 .34249 .87358 .34099 .87183 .33834 Metetra
.672 .74 .901 r
.87183 .33834 .87358 .34099 .87793 .33949 .87619 .33684 Metetra
.672 .74 .901 r
.87619 .33684 .87793 .33949 .88229 .33799 .88055 .33533 Metetra
.965 .778 .601 r
.88055 .33533 .88229 .33799 .88666 .33649 .88362 .32245 Metetra
.597 .442 .642 r
.88362 .32245 .88666 .33649 .88972 .32365 .888 .32104 Metetra
.664 .741 .907 r
.888 .32104 .88972 .32365 .89409 .32223 .89237 .31962 Metetra
.664 .741 .907 r
.89237 .31962 .89409 .32223 .89847 .32082 .89676 .3182 Metetra
.664 .741 .907 r
.30619 .50639 .30846 .50852 .31202 .50737 .30975 .50524 Metetra
.664 .741 .907 r
.30975 .50524 .31202 .50737 .31558 .50622 .31331 .50409 Metetra
.664 .741 .907 r
.31331 .50409 .31558 .50622 .31914 .50506 .31688 .50293 Metetra
.664 .741 .907 r
.31688 .50293 .31914 .50506 .32205 .51488 .32045 .50177 Metetra
.052 .047 .531 r
.32045 .50177 .32205 .51488 .32563 .51382 .32336 .51162 Metetra
.653 .734 .908 r
.32336 .51162 .32563 .51382 .32921 .51276 .32695 .51056 Metetra
.653 .733 .908 r
.32695 .51056 .32921 .51276 .3328 .5117 .33054 .5095 Metetra
.653 .733 .908 r
.33054 .5095 .3328 .5117 .3364 .51064 .33414 .50843 Metetra
.653 .733 .908 r
.33414 .50843 .3364 .51064 .34 .50958 .33774 .50737 Metetra
.652 .733 .908 r
.33774 .50737 .34 .50958 .3436 .50853 .34135 .50631 Metetra
.652 .733 .908 r
.34135 .50631 .3436 .50853 .34721 .50747 .34496 .50525 Metetra
.652 .733 .908 r
.34496 .50525 .34721 .50747 .35082 .50642 .34858 .50419 Metetra
.652 .732 .908 r
.34858 .50419 .35082 .50642 .35444 .50536 .3522 .50313 Metetra
.651 .732 .908 r
.3522 .50313 .35444 .50536 .35807 .50431 .35583 .50208 Metetra
.651 .732 .908 r
.35583 .50208 .35807 .50431 .3617 .50326 .35946 .50102 Metetra
.651 .732 .908 r
.35946 .50102 .3617 .50326 .36534 .50221 .3631 .49997 Metetra
.651 .731 .908 r
.3631 .49997 .36534 .50221 .36898 .50116 .36675 .49891 Metetra
.65 .731 .908 r
.36675 .49891 .36898 .50116 .37262 .50011 .37039 .49786 Metetra
.65 .731 .908 r
.37039 .49786 .37262 .50011 .37627 .49907 .37405 .49681 Metetra
.65 .731 .908 r
.37405 .49681 .37627 .49907 .37993 .49803 .37771 .49577 Metetra
.649 .73 .908 r
.37771 .49577 .37993 .49803 .38359 .49698 .38137 .49472 Metetra
.649 .73 .908 r
.38137 .49472 .38359 .49698 .38725 .49595 .38504 .49368 Metetra
.648 .73 .908 r
.38504 .49368 .38725 .49595 .39092 .49491 .38871 .49263 Metetra
.648 .73 .908 r
.38871 .49263 .39092 .49491 .3946 .49387 .39239 .49159 Metetra
.648 .729 .908 r
.39239 .49159 .3946 .49387 .39828 .49284 .39608 .49056 Metetra
.647 .729 .908 r
.39608 .49056 .39828 .49284 .40197 .49181 .39977 .48952 Metetra
.647 .728 .908 r
.39977 .48952 .40197 .49181 .40566 .49079 .40346 .48849 Metetra
.646 .728 .908 r
.40346 .48849 .40566 .49079 .40936 .48977 .40716 .48746 Metetra
.646 .728 .908 r
.40716 .48746 .40936 .48977 .41306 .48875 .41087 .48644 Metetra
.645 .727 .908 r
.41087 .48644 .41306 .48875 .41677 .48773 .41458 .48542 Metetra
.645 .727 .908 r
.41458 .48542 .41677 .48773 .42048 .48672 .41829 .4844 Metetra
.644 .726 .908 r
.41829 .4844 .42048 .48672 .4242 .48572 .42202 .48339 Metetra
.643 .726 .908 r
.42202 .48339 .4242 .48572 .42792 .48471 .42574 .48238 Metetra
.643 .725 .908 r
.42574 .48238 .42792 .48471 .43165 .48372 .42948 .48138 Metetra
.642 .725 .909 r
.42948 .48138 .43165 .48372 .43539 .48273 .43321 .48038 Metetra
.641 .724 .909 r
.43321 .48038 .43539 .48273 .43913 .48174 .43696 .47939 Metetra
.64 .724 .909 r
.43696 .47939 .43913 .48174 .44287 .48076 .4407 .4784 Metetra
.64 .723 .909 r
.4407 .4784 .44287 .48076 .44662 .47979 .44446 .47742 Metetra
.639 .722 .909 r
.44446 .47742 .44662 .47979 .45038 .47882 .44822 .47645 Metetra
.638 .722 .909 r
.44822 .47645 .45038 .47882 .45414 .47787 .45198 .47548 Metetra
.637 .721 .909 r
.45198 .47548 .45414 .47787 .45791 .47692 .45576 .47453 Metetra
.636 .72 .909 r
.45576 .47453 .45791 .47692 .46168 .47598 .45953 .47358 Metetra
.635 .719 .909 r
.45953 .47358 .46168 .47598 .46546 .47505 .46331 .47264 Metetra
.633 .718 .909 r
.46331 .47264 .46546 .47505 .46925 .47413 .4671 .47171 Metetra
.632 .717 .909 r
.4671 .47171 .46925 .47413 .47304 .47322 .4709 .47079 Metetra
.631 .716 .909 r
.4709 .47079 .47304 .47322 .47684 .47232 .4747 .46989 Metetra
.629 .715 .909 r
.4747 .46989 .47684 .47232 .48064 .47144 .4785 .46899 Metetra
.628 .714 .909 r
.4785 .46899 .48064 .47144 .48445 .47057 .48231 .46811 Metetra
.626 .713 .909 r
.48231 .46811 .48445 .47057 .48826 .46972 .48613 .46725 Metetra
.624 .711 .908 r
.48613 .46725 .48826 .46972 .49208 .46888 .48995 .4664 Metetra
.622 .71 .908 r
.48995 .4664 .49208 .46888 .49591 .46807 .49378 .46557 Metetra
.62 .708 .908 r
.49378 .46557 .49591 .46807 .49974 .46727 .49762 .46476 Metetra
.617 .706 .908 r
.49762 .46476 .49974 .46727 .50358 .4665 .50146 .46397 Metetra
.615 .704 .908 r
.50146 .46397 .50358 .4665 .50742 .46575 .50531 .46321 Metetra
.612 .702 .908 r
.50531 .46321 .50742 .46575 .51127 .46503 .50916 .46247 Metetra
.609 .699 .908 r
.50916 .46247 .51127 .46503 .51513 .46434 .51302 .46176 Metetra
.605 .697 .908 r
.51302 .46176 .51513 .46434 .519 .46368 .51689 .46109 Metetra
.601 .694 .908 r
.51689 .46109 .519 .46368 .52287 .46307 .52076 .46045 Metetra
.597 .69 .908 r
.52076 .46045 .52287 .46307 .52675 .46249 .52464 .45985 Metetra
.592 .687 .907 r
.52464 .45985 .52675 .46249 .53063 .46196 .52853 .45929 Metetra
.586 .682 .907 r
.52853 .45929 .53063 .46196 .53452 .46149 .53243 .45879 Metetra
.58 .677 .907 r
.53243 .45879 .53452 .46149 .53842 .46108 .53633 .45834 Metetra
.572 .672 .906 r
.53633 .45834 .53842 .46108 .54233 .46073 .54024 .45797 Metetra
.564 .665 .906 r
.54024 .45797 .54233 .46073 .54625 .46047 .54416 .45766 Metetra
.554 .658 .905 r
.54416 .45766 .54625 .46047 .55017 .4603 .54809 .45745 Metetra
.543 .649 .904 r
.54809 .45745 .55017 .4603 .55411 .46025 .55202 .45733 Metetra
.529 .638 .902 r
.55202 .45733 .55411 .46025 .55805 .46032 .55597 .45734 Metetra
.965 .681 .444 r
.55597 .45734 .55805 .46032 .56416 .65105 .56197 .64887 Metetra
.645 .763 .934 r
.56197 .64887 .56416 .65105 .56834 .64987 .56615 .64769 Metetra
.645 .763 .934 r
.56615 .64769 .56834 .64987 .57252 .64869 .57033 .6465 Metetra
.645 .763 .934 r
.57033 .6465 .57252 .64869 .57671 .6475 .57453 .64531 Metetra
.846 .797 .803 r
.57453 .64531 .57671 .6475 .5809 .64632 .57867 .64068 Metetra
.847 .668 .661 r
.57867 .64068 .5809 .64632 .58505 .64184 .58272 .63022 Metetra
.69 .519 .651 r
.58272 .63022 .58505 .64184 .58916 .63572 .58684 .62483 Metetra
.603 .468 .67 r
.58684 .62483 .58916 .63572 .59336 .63453 .59104 .62363 Metetra
.457 .371 .671 r
.59104 .62363 .59336 .63453 .59768 .63826 .59533 .62662 Metetra
.215 .199 .624 r
.59533 .62662 .59768 .63826 .60197 .64036 .59974 .63469 Metetra
.39 .427 .779 r
.59974 .63469 .60197 .64036 .6062 .63916 .60405 .63695 Metetra
.645 .763 .934 r
.60405 .63695 .6062 .63916 .61044 .63796 .6083 .63574 Metetra
.645 .763 .934 r
.6083 .63574 .61044 .63796 .61469 .63676 .61255 .63454 Metetra
.645 .763 .934 r
.61255 .63454 .61469 .63676 .61894 .63556 .6168 .63333 Metetra
.969 .694 .458 r
.6168 .63333 .61894 .63556 .61771 .44137 .61567 .43834 Metetra
.742 .718 .83 r
.61567 .43834 .61771 .44137 .6217 .43877 .61966 .43579 Metetra
.736 .721 .836 r
.61966 .43579 .6217 .43877 .62569 .43629 .62366 .43337 Metetra
.732 .723 .842 r
.62366 .43337 .62569 .43629 .62968 .43392 .62766 .43104 Metetra
.728 .724 .847 r
.62766 .43104 .62968 .43392 .63369 .43165 .63167 .4288 Metetra
.724 .726 .852 r
.63167 .4288 .63369 .43165 .6377 .42945 .63568 .42663 Metetra
.72 .727 .856 r
.63568 .42663 .6377 .42945 .64171 .42732 .6397 .42453 Metetra
.717 .728 .859 r
.6397 .42453 .64171 .42732 .64573 .42526 .64373 .42249 Metetra
.714 .729 .863 r
.64373 .42249 .64573 .42526 .64976 .42325 .64776 .4205 Metetra
.711 .73 .865 r
.64776 .4205 .64976 .42325 .65379 .42128 .6518 .41855 Metetra
.709 .731 .868 r
.6518 .41855 .65379 .42128 .65783 .41936 .65584 .41664 Metetra
.706 .732 .87 r
.65584 .41664 .65783 .41936 .66188 .41748 .65989 .41477 Metetra
.704 .732 .873 r
.65989 .41477 .66188 .41748 .66593 .41562 .66395 .41293 Metetra
.702 .733 .875 r
.66395 .41293 .66593 .41562 .66998 .4138 .66801 .41112 Metetra
.7 .733 .876 r
.66801 .41112 .66998 .4138 .67405 .41201 .67208 .40934 Metetra
.699 .734 .878 r
.67208 .40934 .67405 .41201 .67812 .41024 .67615 .40758 Metetra
.697 .734 .88 r
.67615 .40758 .67812 .41024 .68219 .40849 .68023 .40584 Metetra
.695 .735 .881 r
.68023 .40584 .68219 .40849 .68627 .40677 .68431 .40412 Metetra
.694 .735 .882 r
.68431 .40412 .68627 .40677 .69036 .40506 .68841 .40241 Metetra
.693 .735 .883 r
.68841 .40241 .69036 .40506 .69445 .40337 .6925 .40073 Metetra
.692 .736 .884 r
.6925 .40073 .69445 .40337 .69855 .40169 .69661 .39906 Metetra
.69 .736 .886 r
.69661 .39906 .69855 .40169 .70265 .40003 .70071 .3974 Metetra
.689 .736 .886 r
.70071 .3974 .70265 .40003 .70676 .39838 .70483 .39575 Metetra
.688 .736 .887 r
.70483 .39575 .70676 .39838 .71088 .39674 .70895 .39412 Metetra
.687 .736 .888 r
.70895 .39412 .71088 .39674 .715 .39512 .71308 .39249 Metetra
.686 .737 .889 r
.71308 .39249 .715 .39512 .71913 .3935 .71721 .39088 Metetra
.686 .737 .89 r
.71721 .39088 .71913 .3935 .72326 .39189 .72135 .38928 Metetra
.685 .737 .89 r
.72135 .38928 .72326 .39189 .72741 .3903 .72549 .38768 Metetra
.684 .737 .891 r
.72549 .38768 .72741 .3903 .73155 .38871 .72964 .38609 Metetra
.683 .737 .892 r
.72964 .38609 .73155 .38871 .7357 .38712 .7338 .38451 Metetra
.683 .737 .892 r
.7338 .38451 .7357 .38712 .73986 .38555 .73796 .38293 Metetra
.682 .738 .893 r
.73796 .38293 .73986 .38555 .74403 .38398 .74213 .38137 Metetra
.681 .738 .893 r
.74213 .38137 .74403 .38398 .7482 .38242 .74631 .3798 Metetra
.681 .738 .894 r
.74631 .3798 .7482 .38242 .75237 .38086 .75049 .37824 Metetra
.68 .738 .894 r
.75049 .37824 .75237 .38086 .75656 .3793 .75467 .37669 Metetra
.68 .738 .895 r
.75467 .37669 .75656 .3793 .76074 .37776 .75887 .37514 Metetra
.679 .738 .895 r
.75887 .37514 .76074 .37776 .76494 .37621 .76307 .3736 Metetra
.679 .738 .896 r
.76307 .3736 .76494 .37621 .76914 .37467 .76727 .37206 Metetra
.678 .738 .896 r
.76727 .37206 .76914 .37467 .77335 .37314 .77148 .37052 Metetra
.678 .738 .896 r
.77148 .37052 .77335 .37314 .77756 .3716 .7757 .36899 Metetra
.678 .739 .897 r
.7757 .36899 .77756 .3716 .78178 .37007 .77992 .36746 Metetra
.677 .739 .897 r
.77992 .36746 .78178 .37007 .786 .36855 .78415 .36593 Metetra
.677 .739 .897 r
.78415 .36593 .786 .36855 .79024 .36702 .78839 .3644 Metetra
.676 .739 .898 r
.78839 .3644 .79024 .36702 .79447 .3655 .79263 .36288 Metetra
.676 .739 .898 r
.79263 .36288 .79447 .3655 .79872 .36398 .79688 .36136 Metetra
.676 .739 .898 r
.79688 .36136 .79872 .36398 .80297 .36246 .80114 .35984 Metetra
.675 .739 .898 r
.80114 .35984 .80297 .36246 .80722 .36095 .8054 .35832 Metetra
.675 .739 .899 r
.8054 .35832 .80722 .36095 .81149 .35943 .80967 .3568 Metetra
.675 .739 .899 r
.80967 .3568 .81149 .35943 .81576 .35792 .81394 .35529 Metetra
.674 .739 .899 r
.81394 .35529 .81576 .35792 .82003 .35641 .81822 .35378 Metetra
.674 .739 .899 r
.81822 .35378 .82003 .35641 .82431 .3549 .8225 .35227 Metetra
.674 .739 .9 r
.8225 .35227 .82431 .3549 .8286 .35339 .8268 .35075 Metetra
.674 .739 .9 r
.8268 .35075 .8286 .35339 .83289 .35188 .8311 .34924 Metetra
.673 .739 .9 r
.8311 .34924 .83289 .35188 .8372 .35038 .8354 .34774 Metetra
.673 .739 .9 r
.8354 .34774 .8372 .35038 .8415 .34887 .83971 .34623 Metetra
.673 .739 .9 r
.83971 .34623 .8415 .34887 .84582 .34736 .84403 .34472 Metetra
.673 .739 .9 r
.84403 .34472 .84582 .34736 .85013 .34586 .84835 .34321 Metetra
.673 .739 .901 r
.84835 .34321 .85013 .34586 .85446 .34436 .85269 .3417 Metetra
.672 .739 .901 r
.85269 .3417 .85446 .34436 .85879 .34285 .85702 .3402 Metetra
.672 .74 .901 r
.85702 .3402 .85879 .34285 .86313 .34135 .86137 .33869 Metetra
.672 .74 .901 r
.86137 .33869 .86313 .34135 .86748 .33984 .86572 .33718 Metetra
.672 .74 .901 r
.86572 .33718 .86748 .33984 .87183 .33834 .87007 .33568 Metetra
.672 .74 .901 r
.87007 .33568 .87183 .33834 .87619 .33684 .87444 .33417 Metetra
.965 .778 .602 r
.87444 .33417 .87619 .33684 .88055 .33533 .87753 .32126 Metetra
.596 .441 .641 r
.87753 .32126 .88055 .33533 .88362 .32245 .88189 .31984 Metetra
.664 .741 .907 r
.88189 .31984 .88362 .32245 .888 .32104 .88627 .31842 Metetra
.664 .741 .907 r
.88627 .31842 .888 .32104 .89237 .31962 .89065 .317 Metetra
.664 .741 .907 r
.89065 .317 .89237 .31962 .89676 .3182 .89504 .31558 Metetra
.664 .741 .907 r
.30391 .50426 .30619 .50639 .30975 .50524 .30747 .50311 Metetra
.664 .741 .907 r
.30747 .50311 .30975 .50524 .31331 .50409 .31103 .50195 Metetra
.664 .741 .907 r
.31103 .50195 .31331 .50409 .31688 .50293 .3146 .50079 Metetra
.664 .741 .907 r
.3146 .50079 .31688 .50293 .32045 .50177 .31818 .49963 Metetra
.664 .741 .907 r
.31818 .49963 .32045 .50177 .32336 .51162 .32176 .49847 Metetra
.052 .047 .531 r
.32176 .49847 .32336 .51162 .32695 .51056 .32468 .50835 Metetra
.653 .733 .908 r
.32468 .50835 .32695 .51056 .33054 .5095 .32828 .50729 Metetra
.653 .733 .908 r
.32828 .50729 .33054 .5095 .33414 .50843 .33188 .50622 Metetra
.653 .733 .908 r
.33188 .50622 .33414 .50843 .33774 .50737 .33548 .50516 Metetra
.653 .733 .908 r
.33548 .50516 .33774 .50737 .34135 .50631 .33909 .50409 Metetra
.652 .733 .908 r
.33909 .50409 .34135 .50631 .34496 .50525 .34271 .50303 Metetra
.652 .733 .908 r
.34271 .50303 .34496 .50525 .34858 .50419 .34633 .50196 Metetra
.652 .732 .908 r
.34633 .50196 .34858 .50419 .3522 .50313 .34996 .5009 Metetra
.652 .732 .908 r
.34996 .5009 .3522 .50313 .35583 .50208 .35359 .49984 Metetra
.651 .732 .908 r
.35359 .49984 .35583 .50208 .35946 .50102 .35722 .49878 Metetra
.651 .732 .908 r
.35722 .49878 .35946 .50102 .3631 .49997 .36086 .49772 Metetra
.651 .732 .908 r
.36086 .49772 .3631 .49997 .36675 .49891 .36451 .49666 Metetra
.65 .731 .908 r
.36451 .49666 .36675 .49891 .37039 .49786 .36816 .49561 Metetra
.65 .731 .908 r
.36816 .49561 .37039 .49786 .37405 .49681 .37182 .49455 Metetra
.65 .731 .908 r
.37182 .49455 .37405 .49681 .37771 .49577 .37548 .4935 Metetra
.649 .731 .908 r
.37548 .4935 .37771 .49577 .38137 .49472 .37915 .49245 Metetra
.649 .73 .908 r
.37915 .49245 .38137 .49472 .38504 .49368 .38282 .4914 Metetra
.649 .73 .908 r
.38282 .4914 .38504 .49368 .38871 .49263 .3865 .49035 Metetra
.648 .73 .908 r
.3865 .49035 .38871 .49263 .39239 .49159 .39018 .48931 Metetra
.648 .729 .908 r
.39018 .48931 .39239 .49159 .39608 .49056 .39387 .48827 Metetra
.647 .729 .908 r
.39387 .48827 .39608 .49056 .39977 .48952 .39756 .48723 Metetra
.647 .729 .908 r
.39756 .48723 .39977 .48952 .40346 .48849 .40126 .48619 Metetra
.646 .728 .908 r
.40126 .48619 .40346 .48849 .40716 .48746 .40496 .48516 Metetra
.646 .728 .908 r
.40496 .48516 .40716 .48746 .41087 .48644 .40867 .48413 Metetra
.645 .727 .908 r
.40867 .48413 .41087 .48644 .41458 .48542 .41238 .4831 Metetra
.645 .727 .908 r
.41238 .4831 .41458 .48542 .41829 .4844 .4161 .48208 Metetra
.644 .727 .908 r
.4161 .48208 .41829 .4844 .42202 .48339 .41983 .48106 Metetra
.644 .726 .908 r
.41983 .48106 .42202 .48339 .42574 .48238 .42356 .48004 Metetra
.643 .726 .908 r
.42356 .48004 .42574 .48238 .42948 .48138 .42729 .47904 Metetra
.642 .725 .908 r
.42729 .47904 .42948 .48138 .43321 .48038 .43103 .47803 Metetra
.642 .725 .908 r
.43103 .47803 .43321 .48038 .43696 .47939 .43478 .47703 Metetra
.641 .724 .908 r
.43478 .47703 .43696 .47939 .4407 .4784 .43853 .47604 Metetra
.64 .723 .908 r
.43853 .47604 .4407 .4784 .44446 .47742 .44229 .47505 Metetra
.639 .723 .908 r
.44229 .47505 .44446 .47742 .44822 .47645 .44605 .47407 Metetra
.638 .722 .908 r
.44605 .47407 .44822 .47645 .45198 .47548 .44982 .4731 Metetra
.637 .721 .908 r
.44982 .4731 .45198 .47548 .45576 .47453 .45359 .47213 Metetra
.636 .72 .908 r
.45359 .47213 .45576 .47453 .45953 .47358 .45737 .47118 Metetra
.635 .72 .908 r
.45737 .47118 .45953 .47358 .46331 .47264 .46116 .47023 Metetra
.634 .719 .908 r
.46116 .47023 .46331 .47264 .4671 .47171 .46495 .46929 Metetra
.633 .718 .908 r
.46495 .46929 .4671 .47171 .4709 .47079 .46875 .46836 Metetra
.632 .717 .908 r
.46875 .46836 .4709 .47079 .4747 .46989 .47255 .46745 Metetra
.63 .716 .908 r
.47255 .46745 .4747 .46989 .4785 .46899 .47636 .46654 Metetra
.629 .714 .908 r
.47636 .46654 .4785 .46899 .48231 .46811 .48017 .46565 Metetra
.627 .713 .908 r
.48017 .46565 .48231 .46811 .48613 .46725 .48399 .46478 Metetra
.625 .712 .908 r
.48399 .46478 .48613 .46725 .48995 .4664 .48782 .46392 Metetra
.623 .71 .908 r
.48782 .46392 .48995 .4664 .49378 .46557 .49165 .46307 Metetra
.621 .709 .908 r
.49165 .46307 .49378 .46557 .49762 .46476 .49549 .46225 Metetra
.619 .707 .908 r
.49549 .46225 .49762 .46476 .50146 .46397 .49933 .46145 Metetra
.616 .705 .908 r
.49933 .46145 .50146 .46397 .50531 .46321 .50319 .46067 Metetra
.613 .703 .908 r
.50319 .46067 .50531 .46321 .50916 .46247 .50704 .45991 Metetra
.61 .7 .908 r
.50704 .45991 .50916 .46247 .51302 .46176 .51091 .45919 Metetra
.607 .698 .908 r
.51091 .45919 .51302 .46176 .51689 .46109 .51478 .45849 Metetra
.603 .695 .908 r
.51478 .45849 .51689 .46109 .52076 .46045 .51865 .45783 Metetra
.599 .692 .908 r
.51865 .45783 .52076 .46045 .52464 .45985 .52254 .45721 Metetra
.594 .688 .907 r
.52254 .45721 .52464 .45985 .52853 .45929 .52643 .45663 Metetra
.589 .684 .907 r
.52643 .45663 .52853 .45929 .53243 .45879 .53033 .45609 Metetra
.583 .679 .907 r
.53033 .45609 .53243 .45879 .53633 .45834 .53423 .45562 Metetra
.576 .674 .906 r
.53423 .45562 .53633 .45834 .54024 .45797 .53814 .4552 Metetra
.568 .668 .906 r
.53814 .4552 .54024 .45797 .54416 .45766 .54206 .45486 Metetra
.559 .661 .905 r
.54206 .45486 .54416 .45766 .54809 .45745 .54599 .4546 Metetra
.549 .653 .904 r
.54599 .4546 .54809 .45745 .55202 .45733 .54993 .45443 Metetra
.536 .643 .902 r
.54993 .45443 .55202 .45733 .55597 .45734 .55388 .45438 Metetra
.965 .681 .444 r
.55388 .45438 .55597 .45734 .56197 .64887 .55977 .64668 Metetra
.645 .763 .934 r
.55977 .64668 .56197 .64887 .56615 .64769 .56395 .6455 Metetra
.645 .763 .934 r
.56395 .6455 .56615 .64769 .57033 .6465 .56814 .64431 Metetra
.645 .763 .934 r
.56814 .64431 .57033 .6465 .57453 .64531 .57234 .64311 Metetra
.941 .757 .625 r
.57234 .64311 .57453 .64531 .57867 .64068 .57634 .62843 Metetra
.738 .547 .635 r
.57634 .62843 .57867 .64068 .58272 .63022 .58041 .61938 Metetra
.686 .522 .659 r
.58041 .61938 .58272 .63022 .58684 .62483 .58454 .61459 Metetra
.605 .475 .677 r
.58454 .61459 .58684 .62483 .59104 .62363 .58873 .61338 Metetra
.476 .39 .68 r
.58873 .61338 .59104 .62363 .59533 .62662 .593 .61576 Metetra
.268 .243 .645 r
.593 .61576 .59533 .62662 .59974 .63469 .59737 .62241 Metetra
0 .029 .544 r
.59737 .62241 .59974 .63469 .60405 .63695 .6019 .63472 Metetra
.645 .763 .934 r
.6019 .63472 .60405 .63695 .6083 .63574 .60615 .63352 Metetra
.645 .763 .934 r
.60615 .63352 .6083 .63574 .61255 .63454 .6104 .63231 Metetra
.645 .763 .934 r
.6104 .63231 .61255 .63454 .6168 .63333 .61466 .6311 Metetra
.969 .694 .458 r
.61466 .6311 .6168 .63333 .61567 .43834 .61363 .43533 Metetra
.739 .719 .833 r
.61363 .43533 .61567 .43834 .61966 .43579 .61762 .43283 Metetra
.734 .721 .839 r
.61762 .43283 .61966 .43579 .62366 .43337 .62163 .43045 Metetra
.73 .723 .844 r
.62163 .43045 .62366 .43337 .62766 .43104 .62563 .42816 Metetra
.726 .725 .849 r
.62563 .42816 .62766 .43104 .63167 .4288 .62965 .42595 Metetra
.722 .726 .853 r
.62965 .42595 .63167 .4288 .63568 .42663 .63366 .42382 Metetra
.719 .727 .857 r
.63366 .42382 .63568 .42663 .6397 .42453 .63769 .42174 Metetra
.715 .729 .861 r
.63769 .42174 .6397 .42453 .64373 .42249 .64172 .41972 Metetra
.713 .729 .864 r
.64172 .41972 .64373 .42249 .64776 .4205 .64576 .41775 Metetra
.71 .73 .867 r
.64576 .41775 .64776 .4205 .6518 .41855 .6498 .41582 Metetra
.707 .731 .869 r
.6498 .41582 .6518 .41855 .65584 .41664 .65385 .41393 Metetra
.705 .732 .871 r
.65385 .41393 .65584 .41664 .65989 .41477 .6579 .41207 Metetra
.703 .732 .873 r
.6579 .41207 .65989 .41477 .66395 .41293 .66196 .41024 Metetra
.701 .733 .875 r
.66196 .41024 .66395 .41293 .66801 .41112 .66603 .40844 Metetra
.699 .733 .877 r
.66603 .40844 .66801 .41112 .67208 .40934 .6701 .40666 Metetra
.698 .734 .879 r
.6701 .40666 .67208 .40934 .67615 .40758 .67418 .40491 Metetra
.696 .734 .88 r
.67418 .40491 .67615 .40758 .68023 .40584 .67826 .40318 Metetra
.695 .735 .881 r
.67826 .40318 .68023 .40584 .68431 .40412 .68235 .40146 Metetra
.693 .735 .883 r
.68235 .40146 .68431 .40412 .68841 .40241 .68645 .39977 Metetra
.692 .735 .884 r
.68645 .39977 .68841 .40241 .6925 .40073 .69055 .39808 Metetra
.691 .736 .885 r
.69055 .39808 .6925 .40073 .69661 .39906 .69466 .39642 Metetra
.69 .736 .886 r
.69466 .39642 .69661 .39906 .70071 .3974 .69877 .39476 Metetra
.689 .736 .887 r
.69877 .39476 .70071 .3974 .70483 .39575 .70289 .39312 Metetra
.688 .736 .888 r
.70289 .39312 .70483 .39575 .70895 .39412 .70701 .39149 Metetra
.687 .736 .889 r
.70701 .39149 .70895 .39412 .71308 .39249 .71115 .38987 Metetra
.686 .737 .889 r
.71115 .38987 .71308 .39249 .71721 .39088 .71528 .38826 Metetra
.685 .737 .89 r
.71528 .38826 .71721 .39088 .72135 .38928 .71943 .38665 Metetra
.684 .737 .891 r
.71943 .38665 .72135 .38928 .72549 .38768 .72358 .38506 Metetra
.684 .737 .891 r
.72358 .38506 .72549 .38768 .72964 .38609 .72773 .38347 Metetra
.683 .737 .892 r
.72773 .38347 .72964 .38609 .7338 .38451 .73189 .38189 Metetra
.682 .737 .892 r
.73189 .38189 .7338 .38451 .73796 .38293 .73606 .38032 Metetra
.682 .738 .893 r
.73606 .38032 .73796 .38293 .74213 .38137 .74023 .37875 Metetra
.681 .738 .894 r
.74023 .37875 .74213 .38137 .74631 .3798 .74441 .37718 Metetra
.681 .738 .894 r
.74441 .37718 .74631 .3798 .75049 .37824 .7486 .37563 Metetra
.68 .738 .894 r
.7486 .37563 .75049 .37824 .75467 .37669 .75279 .37407 Metetra
.68 .738 .895 r
.75279 .37407 .75467 .37669 .75887 .37514 .75699 .37252 Metetra
.679 .738 .895 r
.75699 .37252 .75887 .37514 .76307 .3736 .76119 .37098 Metetra
.679 .738 .896 r
.76119 .37098 .76307 .3736 .76727 .37206 .7654 .36944 Metetra
.678 .738 .896 r
.7654 .36944 .76727 .37206 .77148 .37052 .76962 .3679 Metetra
.678 .738 .896 r
.76962 .3679 .77148 .37052 .7757 .36899 .77384 .36636 Metetra
.677 .738 .897 r
.77384 .36636 .7757 .36899 .77992 .36746 .77807 .36483 Metetra
.677 .739 .897 r
.77807 .36483 .77992 .36746 .78415 .36593 .7823 .3633 Metetra
.677 .739 .897 r
.7823 .3633 .78415 .36593 .78839 .3644 .78654 .36178 Metetra
.676 .739 .898 r
.78654 .36178 .78839 .3644 .79263 .36288 .79079 .36025 Metetra
.676 .739 .898 r
.79079 .36025 .79263 .36288 .79688 .36136 .79504 .35873 Metetra
.676 .739 .898 r
.79504 .35873 .79688 .36136 .80114 .35984 .7993 .35721 Metetra
.675 .739 .898 r
.7993 .35721 .80114 .35984 .8054 .35832 .80357 .35569 Metetra
.675 .739 .899 r
.80357 .35569 .8054 .35832 .80967 .3568 .80784 .35417 Metetra
.675 .739 .899 r
.80784 .35417 .80967 .3568 .81394 .35529 .81212 .35265 Metetra
.674 .739 .899 r
.81212 .35265 .81394 .35529 .81822 .35378 .8164 .35114 Metetra
.674 .739 .899 r
.8164 .35114 .81822 .35378 .8225 .35227 .82069 .34962 Metetra
.674 .739 .9 r
.82069 .34962 .8225 .35227 .8268 .35075 .82499 .34811 Metetra
.674 .739 .9 r
.82499 .34811 .8268 .35075 .8311 .34924 .82929 .3466 Metetra
.673 .739 .9 r
.82929 .3466 .8311 .34924 .8354 .34774 .8336 .34509 Metetra
.673 .739 .9 r
.8336 .34509 .8354 .34774 .83971 .34623 .83792 .34358 Metetra
.673 .739 .9 r
.83792 .34358 .83971 .34623 .84403 .34472 .84224 .34207 Metetra
.673 .739 .901 r
.84224 .34207 .84403 .34472 .84835 .34321 .84657 .34056 Metetra
.672 .739 .901 r
.84657 .34056 .84835 .34321 .85269 .3417 .85091 .33905 Metetra
.672 .739 .901 r
.85091 .33905 .85269 .3417 .85702 .3402 .85525 .33754 Metetra
.672 .74 .901 r
.85525 .33754 .85702 .3402 .86137 .33869 .8596 .33603 Metetra
.672 .74 .901 r
.8596 .33603 .86137 .33869 .86572 .33718 .86395 .33452 Metetra
.672 .74 .901 r
.86395 .33452 .86572 .33718 .87007 .33568 .86831 .33301 Metetra
.964 .777 .602 r
.86831 .33301 .87007 .33568 .87444 .33417 .87142 .32006 Metetra
.596 .441 .641 r
.87142 .32006 .87444 .33417 .87753 .32126 .87579 .31864 Metetra
.664 .741 .907 r
.87579 .31864 .87753 .32126 .88189 .31984 .88016 .31722 Metetra
.664 .741 .907 r
.88016 .31722 .88189 .31984 .88627 .31842 .88454 .3158 Metetra
.664 .741 .907 r
.88454 .3158 .88627 .31842 .89065 .317 .88893 .31437 Metetra
.664 .741 .907 r
.88893 .31437 .89065 .317 .89504 .31558 .89332 .31295 Metetra
.664 .741 .907 r
.30162 .50213 .30391 .50426 .30747 .50311 .30519 .50097 Metetra
.664 .741 .907 r
.30519 .50097 .30747 .50311 .31103 .50195 .30875 .49981 Metetra
.664 .741 .907 r
.30875 .49981 .31103 .50195 .3146 .50079 .31233 .49865 Metetra
.664 .741 .907 r
.31233 .49865 .3146 .50079 .31818 .49963 .31591 .49749 Metetra
.664 .741 .907 r
.31591 .49749 .31818 .49963 .32176 .49847 .31949 .49632 Metetra
.664 .741 .907 r
.31949 .49632 .32176 .49847 .32468 .50835 .32308 .49515 Metetra
.051 .046 .53 r
.32308 .49515 .32468 .50835 .32828 .50729 .32601 .50507 Metetra
.653 .733 .908 r
.32601 .50507 .32828 .50729 .33188 .50622 .32961 .504 Metetra
.653 .733 .908 r
.32961 .504 .33188 .50622 .33548 .50516 .33322 .50293 Metetra
.653 .733 .908 r
.33322 .50293 .33548 .50516 .33909 .50409 .33683 .50187 Metetra
.652 .733 .908 r
.33683 .50187 .33909 .50409 .34271 .50303 .34045 .5008 Metetra
.652 .733 .908 r
.34045 .5008 .34271 .50303 .34633 .50196 .34408 .49973 Metetra
.652 .732 .908 r
.34408 .49973 .34633 .50196 .34996 .5009 .3477 .49866 Metetra
.652 .732 .908 r
.3477 .49866 .34996 .5009 .35359 .49984 .35134 .4976 Metetra
.651 .732 .908 r
.35134 .4976 .35359 .49984 .35722 .49878 .35498 .49653 Metetra
.651 .732 .908 r
.35498 .49653 .35722 .49878 .36086 .49772 .35862 .49547 Metetra
.651 .732 .908 r
.35862 .49547 .36086 .49772 .36451 .49666 .36227 .49441 Metetra
.651 .731 .908 r
.36227 .49441 .36451 .49666 .36816 .49561 .36592 .49335 Metetra
.65 .731 .908 r
.36592 .49335 .36816 .49561 .37182 .49455 .36958 .49229 Metetra
.65 .731 .908 r
.36958 .49229 .37182 .49455 .37548 .4935 .37325 .49123 Metetra
.65 .731 .908 r
.37325 .49123 .37548 .4935 .37915 .49245 .37692 .49017 Metetra
.649 .73 .908 r
.37692 .49017 .37915 .49245 .38282 .4914 .38059 .48912 Metetra
.649 .73 .908 r
.38059 .48912 .38282 .4914 .3865 .49035 .38427 .48807 Metetra
.648 .73 .908 r
.38427 .48807 .3865 .49035 .39018 .48931 .38796 .48702 Metetra
.648 .729 .908 r
.38796 .48702 .39018 .48931 .39387 .48827 .39165 .48597 Metetra
.648 .729 .908 r
.39165 .48597 .39387 .48827 .39756 .48723 .39534 .48493 Metetra
.647 .729 .908 r
.39534 .48493 .39756 .48723 .40126 .48619 .39905 .48388 Metetra
.647 .728 .908 r
.39905 .48388 .40126 .48619 .40496 .48516 .40275 .48285 Metetra
.646 .728 .908 r
.40275 .48285 .40496 .48516 .40867 .48413 .40646 .48181 Metetra
.646 .728 .908 r
.40646 .48181 .40867 .48413 .41238 .4831 .41018 .48078 Metetra
.645 .727 .908 r
.41018 .48078 .41238 .4831 .4161 .48208 .4139 .47975 Metetra
.645 .727 .908 r
.4139 .47975 .4161 .48208 .41983 .48106 .41763 .47872 Metetra
.644 .726 .908 r
.41763 .47872 .41983 .48106 .42356 .48004 .42136 .4777 Metetra
.643 .726 .908 r
.42136 .4777 .42356 .48004 .42729 .47904 .4251 .47669 Metetra
.643 .725 .908 r
.4251 .47669 .42729 .47904 .43103 .47803 .42885 .47568 Metetra
.642 .725 .908 r
.42885 .47568 .43103 .47803 .43478 .47703 .4326 .47467 Metetra
.641 .724 .908 r
.4326 .47467 .43478 .47703 .43853 .47604 .43635 .47367 Metetra
.641 .724 .908 r
.43635 .47367 .43853 .47604 .44229 .47505 .44011 .47268 Metetra
.64 .723 .908 r
.44011 .47268 .44229 .47505 .44605 .47407 .44388 .47169 Metetra
.639 .722 .908 r
.44388 .47169 .44605 .47407 .44982 .4731 .44765 .47071 Metetra
.638 .722 .908 r
.44765 .47071 .44982 .4731 .45359 .47213 .45143 .46973 Metetra
.637 .721 .908 r
.45143 .46973 .45359 .47213 .45737 .47118 .45521 .46877 Metetra
.636 .72 .908 r
.45521 .46877 .45737 .47118 .46116 .47023 .459 .46781 Metetra
.635 .719 .908 r
.459 .46781 .46116 .47023 .46495 .46929 .46279 .46686 Metetra
.634 .718 .908 r
.46279 .46686 .46495 .46929 .46875 .46836 .46659 .46593 Metetra
.632 .717 .908 r
.46659 .46593 .46875 .46836 .47255 .46745 .4704 .465 Metetra
.631 .716 .908 r
.4704 .465 .47255 .46745 .47636 .46654 .47421 .46409 Metetra
.629 .715 .908 r
.47421 .46409 .47636 .46654 .48017 .46565 .47803 .46319 Metetra
.628 .714 .908 r
.47803 .46319 .48017 .46565 .48399 .46478 .48185 .4623 Metetra
.626 .712 .908 r
.48185 .4623 .48399 .46478 .48782 .46392 .48568 .46143 Metetra
.624 .711 .908 r
.48568 .46143 .48782 .46392 .49165 .46307 .48952 .46057 Metetra
.622 .709 .908 r
.48952 .46057 .49165 .46307 .49549 .46225 .49336 .45974 Metetra
.62 .708 .908 r
.49336 .45974 .49549 .46225 .49933 .46145 .4972 .45892 Metetra
.617 .706 .908 r
.4972 .45892 .49933 .46145 .50319 .46067 .50106 .45812 Metetra
.615 .704 .908 r
.50106 .45812 .50319 .46067 .50704 .45991 .50492 .45735 Metetra
.612 .701 .908 r
.50492 .45735 .50704 .45991 .51091 .45919 .50879 .45661 Metetra
.609 .699 .908 r
.50879 .45661 .51091 .45919 .51478 .45849 .51266 .45589 Metetra
.605 .696 .908 r
.51266 .45589 .51478 .45849 .51865 .45783 .51654 .45521 Metetra
.601 .693 .907 r
.51654 .45521 .51865 .45783 .52254 .45721 .52042 .45457 Metetra
.597 .69 .907 r
.52042 .45457 .52254 .45721 .52643 .45663 .52432 .45396 Metetra
.592 .686 .907 r
.52432 .45396 .52643 .45663 .53033 .45609 .52822 .4534 Metetra
.586 .681 .907 r
.52822 .4534 .53033 .45609 .53423 .45562 .53213 .45289 Metetra
.58 .676 .906 r
.53213 .45289 .53423 .45562 .53814 .4552 .53604 .45244 Metetra
.572 .671 .906 r
.53604 .45244 .53814 .4552 .54206 .45486 .53997 .45206 Metetra
.564 .664 .905 r
.53997 .45206 .54206 .45486 .54599 .4546 .5439 .45176 Metetra
.554 .656 .904 r
.5439 .45176 .54599 .4546 .54993 .45443 .54784 .45154 Metetra
.965 .681 .446 r
.54784 .45154 .54993 .45443 .55388 .45438 .55338 .64568 Metetra
.553 .335 .537 r
.55338 .64568 .55388 .45438 .55977 .64668 .55756 .64449 Metetra
.645 .763 .934 r
.55756 .64449 .55977 .64668 .56395 .6455 .56175 .6433 Metetra
.645 .763 .934 r
.56175 .6433 .56395 .6455 .56814 .64431 .56595 .64211 Metetra
.932 .765 .652 r
.56595 .64211 .56814 .64431 .57234 .64311 .57001 .62995 Metetra
.768 .563 .621 r
.57001 .62995 .57234 .64311 .57634 .62843 .57403 .61714 Metetra
.732 .549 .644 r
.57403 .61714 .57634 .62843 .58041 .61938 .57812 .60923 Metetra
.682 .525 .666 r
.57812 .60923 .58041 .61938 .58454 .61459 .58225 .60492 Metetra
.607 .482 .683 r
.58225 .60492 .58454 .61459 .58873 .61338 .58643 .60371 Metetra
.492 .407 .688 r
.58643 .60371 .58873 .61338 .593 .61576 .59069 .60559 Metetra
.312 .281 .663 r
.59069 .60559 .593 .61576 .59737 .62241 .59503 .61108 Metetra
.044 .083 .578 r
.59503 .61108 .59737 .62241 .6019 .63472 .5995 .6215 Metetra
.181 .162 .599 r
.5995 .6215 .6019 .63472 .60615 .63352 .60399 .63129 Metetra
.645 .763 .934 r
.60399 .63129 .60615 .63352 .6104 .63231 .60825 .63008 Metetra
.645 .763 .934 r
.60825 .63008 .6104 .63231 .61466 .6311 .61251 .62886 Metetra
.645 .763 .934 r
.61251 .62886 .61466 .6311 .61363 .43533 .61678 .62765 Metetra
0 0 .386 r
.61678 .62765 .61363 .43533 .61762 .43283 .61558 .42988 Metetra
.732 .722 .841 r
.61558 .42988 .61762 .43283 .62163 .43045 .61959 .42754 Metetra
.728 .724 .846 r
.61959 .42754 .62163 .43045 .62563 .42816 .6236 .42529 Metetra
.724 .725 .851 r
.6236 .42529 .62563 .42816 .62965 .42595 .62762 .42312 Metetra
.72 .726 .855 r
.62762 .42312 .62965 .42595 .63366 .42382 .63164 .42101 Metetra
.717 .728 .859 r
.63164 .42101 .63366 .42382 .63769 .42174 .63567 .41896 Metetra
.714 .729 .862 r
.63567 .41896 .63769 .42174 .64172 .41972 .63971 .41696 Metetra
.711 .73 .865 r
.63971 .41696 .64172 .41972 .64576 .41775 .64375 .415 Metetra
.709 .73 .868 r
.64375 .415 .64576 .41775 .6498 .41582 .6478 .41309 Metetra
.706 .731 .87 r
.6478 .41309 .6498 .41582 .65385 .41393 .65185 .41121 Metetra
.704 .732 .872 r
.65185 .41121 .65385 .41393 .6579 .41207 .65591 .40936 Metetra
.702 .732 .874 r
.65591 .40936 .6579 .41207 .66196 .41024 .65997 .40755 Metetra
.7 .733 .876 r
.65997 .40755 .66196 .41024 .66603 .40844 .66404 .40575 Metetra
.699 .733 .878 r
.66404 .40575 .66603 .40844 .6701 .40666 .66812 .40399 Metetra
.697 .734 .879 r
.66812 .40399 .6701 .40666 .67418 .40491 .6722 .40224 Metetra
.695 .734 .881 r
.6722 .40224 .67418 .40491 .67826 .40318 .67629 .40052 Metetra
.694 .735 .882 r
.67629 .40052 .67826 .40318 .68235 .40146 .68039 .39881 Metetra
.693 .735 .883 r
.68039 .39881 .68235 .40146 .68645 .39977 .68449 .39712 Metetra
.692 .735 .884 r
.68449 .39712 .68645 .39977 .69055 .39808 .68859 .39544 Metetra
.69 .736 .885 r
.68859 .39544 .69055 .39808 .69466 .39642 .6927 .39377 Metetra
.689 .736 .886 r
.6927 .39377 .69466 .39642 .69877 .39476 .69682 .39212 Metetra
.688 .736 .887 r
.69682 .39212 .69877 .39476 .70289 .39312 .70095 .39048 Metetra
.687 .736 .888 r
.70095 .39048 .70289 .39312 .70701 .39149 .70507 .38886 Metetra
.686 .736 .889 r
.70507 .38886 .70701 .39149 .71115 .38987 .70921 .38724 Metetra
.686 .737 .89 r
.70921 .38724 .71115 .38987 .71528 .38826 .71335 .38563 Metetra
.685 .737 .89 r
.71335 .38563 .71528 .38826 .71943 .38665 .7175 .38403 Metetra
.684 .737 .891 r
.7175 .38403 .71943 .38665 .72358 .38506 .72165 .38243 Metetra
.683 .737 .892 r
.72165 .38243 .72358 .38506 .72773 .38347 .72581 .38085 Metetra
.683 .737 .892 r
.72581 .38085 .72773 .38347 .73189 .38189 .72998 .37927 Metetra
.682 .737 .893 r
.72998 .37927 .73189 .38189 .73606 .38032 .73415 .37769 Metetra
.681 .738 .893 r
.73415 .37769 .73606 .38032 .74023 .37875 .73833 .37612 Metetra
.681 .738 .894 r
.73833 .37612 .74023 .37875 .74441 .37718 .74251 .37456 Metetra
.68 .738 .894 r
.74251 .37456 .74441 .37718 .7486 .37563 .7467 .373 Metetra
.68 .738 .895 r
.7467 .373 .7486 .37563 .75279 .37407 .7509 .37145 Metetra
.679 .738 .895 r
.7509 .37145 .75279 .37407 .75699 .37252 .7551 .3699 Metetra
.679 .738 .895 r
.7551 .3699 .75699 .37252 .76119 .37098 .75931 .36835 Metetra
.678 .738 .896 r
.75931 .36835 .76119 .37098 .7654 .36944 .76352 .36681 Metetra
.678 .738 .896 r
.76352 .36681 .7654 .36944 .76962 .3679 .76774 .36527 Metetra
.677 .738 .897 r
.76774 .36527 .76962 .3679 .77384 .36636 .77197 .36374 Metetra
.677 .738 .897 r
.77197 .36374 .77384 .36636 .77807 .36483 .7762 .3622 Metetra
.677 .739 .897 r
.7762 .3622 .77807 .36483 .7823 .3633 .78044 .36067 Metetra
.676 .739 .897 r
.78044 .36067 .7823 .3633 .78654 .36178 .78469 .35914 Metetra
.676 .739 .898 r
.78469 .35914 .78654 .36178 .79079 .36025 .78894 .35762 Metetra
.676 .739 .898 r
.78894 .35762 .79079 .36025 .79504 .35873 .7932 .35609 Metetra
.675 .739 .898 r
.7932 .35609 .79504 .35873 .7993 .35721 .79746 .35457 Metetra
.675 .739 .899 r
.79746 .35457 .7993 .35721 .80357 .35569 .80173 .35305 Metetra
.675 .739 .899 r
.80173 .35305 .80357 .35569 .80784 .35417 .80601 .35153 Metetra
.674 .739 .899 r
.80601 .35153 .80784 .35417 .81212 .35265 .81029 .35001 Metetra
.674 .739 .899 r
.81029 .35001 .81212 .35265 .8164 .35114 .81458 .34849 Metetra
.674 .739 .899 r
.81458 .34849 .8164 .35114 .82069 .34962 .81887 .34698 Metetra
.674 .739 .9 r
.81887 .34698 .82069 .34962 .82499 .34811 .82318 .34546 Metetra
.673 .739 .9 r
.82318 .34546 .82499 .34811 .82929 .3466 .82748 .34395 Metetra
.673 .739 .9 r
.82748 .34395 .82929 .3466 .8336 .34509 .8318 .34243 Metetra
.673 .739 .9 r
.8318 .34243 .8336 .34509 .83792 .34358 .83612 .34092 Metetra
.673 .739 .9 r
.83612 .34092 .83792 .34358 .84224 .34207 .84045 .33941 Metetra
.673 .739 .901 r
.84045 .33941 .84224 .34207 .84657 .34056 .84478 .33789 Metetra
.672 .739 .901 r
.84478 .33789 .84657 .34056 .85091 .33905 .84912 .33638 Metetra
.672 .739 .901 r
.84912 .33638 .85091 .33905 .85525 .33754 .85347 .33487 Metetra
.672 .739 .901 r
.85347 .33487 .85525 .33754 .8596 .33603 .85782 .33336 Metetra
.672 .74 .901 r
.85782 .33336 .8596 .33603 .86395 .33452 .86218 .33185 Metetra
.964 .777 .602 r
.86218 .33185 .86395 .33452 .86831 .33301 .8653 .31886 Metetra
.596 .44 .641 r
.8653 .31886 .86831 .33301 .87142 .32006 .86967 .31744 Metetra
.664 .741 .907 r
.86967 .31744 .87142 .32006 .87579 .31864 .87404 .31602 Metetra
.664 .741 .907 r
.87404 .31602 .87579 .31864 .88016 .31722 .87842 .31459 Metetra
.664 .741 .907 r
.87842 .31459 .88016 .31722 .88454 .3158 .88281 .31317 Metetra
.664 .741 .907 r
.88281 .31317 .88454 .3158 .88893 .31437 .8872 .31174 Metetra
.664 .741 .907 r
.8872 .31174 .88893 .31437 .89332 .31295 .8916 .31031 Metetra
.664 .741 .907 r
.29933 .49999 .30162 .50213 .30519 .50097 .3029 .49883 Metetra
.664 .741 .907 r
.3029 .49883 .30519 .50097 .30875 .49981 .30647 .49766 Metetra
.664 .741 .907 r
.30647 .49766 .30875 .49981 .31233 .49865 .31004 .4965 Metetra
.664 .741 .907 r
.31004 .4965 .31233 .49865 .31591 .49749 .31363 .49533 Metetra
.664 .741 .907 r
.31363 .49533 .31591 .49749 .31949 .49632 .31721 .49417 Metetra
.664 .741 .907 r
.31721 .49417 .31949 .49632 .32308 .49515 .3208 .493 Metetra
.664 .741 .907 r
.3208 .493 .32308 .49515 .32601 .50507 .3244 .49183 Metetra
.595 .44 .64 r
.3244 .49183 .32601 .50507 .32961 .504 .328 .49065 Metetra
.051 .045 .529 r
.328 .49065 .32961 .504 .33322 .50293 .33095 .50071 Metetra
.653 .733 .908 r
.33095 .50071 .33322 .50293 .33683 .50187 .33457 .49963 Metetra
.653 .733 .908 r
.33457 .49963 .33683 .50187 .34045 .5008 .33819 .49856 Metetra
.652 .733 .908 r
.33819 .49856 .34045 .5008 .34408 .49973 .34181 .49749 Metetra
.652 .733 .908 r
.34181 .49749 .34408 .49973 .3477 .49866 .34545 .49642 Metetra
.652 .732 .908 r
.34545 .49642 .3477 .49866 .35134 .4976 .34908 .49535 Metetra
.652 .732 .908 r
.34908 .49535 .35134 .4976 .35498 .49653 .35272 .49428 Metetra
.651 .732 .908 r
.35272 .49428 .35498 .49653 .35862 .49547 .35637 .49321 Metetra
.651 .732 .908 r
.35637 .49321 .35862 .49547 .36227 .49441 .36002 .49215 Metetra
.651 .731 .908 r
.36002 .49215 .36227 .49441 .36592 .49335 .36368 .49108 Metetra
.65 .731 .908 r
.36368 .49108 .36592 .49335 .36958 .49229 .36734 .49002 Metetra
.65 .731 .908 r
.36734 .49002 .36958 .49229 .37325 .49123 .37101 .48895 Metetra
.65 .731 .908 r
.37101 .48895 .37325 .49123 .37692 .49017 .37468 .48789 Metetra
.649 .73 .908 r
.37468 .48789 .37692 .49017 .38059 .48912 .37836 .48683 Metetra
.649 .73 .908 r
.37836 .48683 .38059 .48912 .38427 .48807 .38204 .48578 Metetra
.649 .73 .908 r
.38204 .48578 .38427 .48807 .38796 .48702 .38573 .48472 Metetra
.648 .73 .908 r
.38573 .48472 .38796 .48702 .39165 .48597 .38943 .48367 Metetra
.648 .729 .908 r
.38943 .48367 .39165 .48597 .39534 .48493 .39313 .48262 Metetra
.647 .729 .908 r
.39313 .48262 .39534 .48493 .39905 .48388 .39683 .48157 Metetra
.647 .729 .908 r
.39683 .48157 .39905 .48388 .40275 .48285 .40054 .48053 Metetra
.647 .728 .908 r
.40054 .48053 .40275 .48285 .40646 .48181 .40425 .47949 Metetra
.646 .728 .908 r
.40425 .47949 .40646 .48181 .41018 .48078 .40797 .47845 Metetra
.645 .727 .908 r
.40797 .47845 .41018 .48078 .4139 .47975 .4117 .47741 Metetra
.645 .727 .908 r
.4117 .47741 .4139 .47975 .41763 .47872 .41543 .47638 Metetra
.644 .727 .908 r
.41543 .47638 .41763 .47872 .42136 .4777 .41917 .47536 Metetra
.644 .726 .908 r
.41917 .47536 .42136 .4777 .4251 .47669 .42291 .47433 Metetra
.643 .726 .908 r
.42291 .47433 .4251 .47669 .42885 .47568 .42666 .47332 Metetra
.642 .725 .908 r
.42666 .47332 .42885 .47568 .4326 .47467 .43041 .4723 Metetra
.642 .724 .908 r
.43041 .4723 .4326 .47467 .43635 .47367 .43417 .4713 Metetra
.641 .724 .908 r
.43417 .4713 .43635 .47367 .44011 .47268 .43793 .4703 Metetra
.64 .723 .908 r
.43793 .4703 .44011 .47268 .44388 .47169 .4417 .4693 Metetra
.639 .723 .908 r
.4417 .4693 .44388 .47169 .44765 .47071 .44547 .46831 Metetra
.638 .722 .908 r
.44547 .46831 .44765 .47071 .45143 .46973 .44925 .46733 Metetra
.637 .721 .908 r
.44925 .46733 .45143 .46973 .45521 .46877 .45304 .46636 Metetra
.636 .72 .908 r
.45304 .46636 .45521 .46877 .459 .46781 .45683 .46539 Metetra
.635 .719 .908 r
.45683 .46539 .459 .46781 .46279 .46686 .46063 .46444 Metetra
.634 .719 .908 r
.46063 .46444 .46279 .46686 .46659 .46593 .46443 .46349 Metetra
.633 .718 .908 r
.46443 .46349 .46659 .46593 .4704 .465 .46824 .46255 Metetra
.632 .717 .908 r
.46824 .46255 .4704 .465 .47421 .46409 .47206 .46163 Metetra
.63 .715 .908 r
.47206 .46163 .47421 .46409 .47803 .46319 .47588 .46072 Metetra
.629 .714 .908 r
.47588 .46072 .47803 .46319 .48185 .4623 .4797 .45982 Metetra
.627 .713 .908 r
.4797 .45982 .48185 .4623 .48568 .46143 .48354 .45894 Metetra
.625 .712 .908 r
.48354 .45894 .48568 .46143 .48952 .46057 .48737 .45807 Metetra
.623 .71 .908 r
.48737 .45807 .48952 .46057 .49336 .45974 .49122 .45722 Metetra
.621 .708 .908 r
.49122 .45722 .49336 .45974 .4972 .45892 .49507 .45639 Metetra
.619 .707 .908 r
.49507 .45639 .4972 .45892 .50106 .45812 .49893 .45558 Metetra
.616 .705 .908 r
.49893 .45558 .50106 .45812 .50492 .45735 .50279 .45479 Metetra
.613 .702 .908 r
.50279 .45479 .50492 .45735 .50879 .45661 .50666 .45403 Metetra
.61 .7 .908 r
.50666 .45403 .50879 .45661 .51266 .45589 .51054 .4533 Metetra
.607 .697 .908 r
.51054 .4533 .51266 .45589 .51654 .45521 .51442 .45259 Metetra
.603 .694 .907 r
.51442 .45259 .51654 .45521 .52042 .45457 .51831 .45193 Metetra
.599 .691 .907 r
.51831 .45193 .52042 .45457 .52432 .45396 .5222 .4513 Metetra
.594 .688 .907 r
.5222 .4513 .52432 .45396 .52822 .4534 .52611 .45071 Metetra
.589 .683 .907 r
.52611 .45071 .52822 .4534 .53213 .45289 .53002 .45017 Metetra
.583 .679 .906 r
.53002 .45017 .53213 .45289 .53604 .45244 .53394 .44969 Metetra
.576 .673 .906 r
.53394 .44969 .53604 .45244 .53997 .45206 .53786 .44927 Metetra
.568 .667 .905 r
.53786 .44927 .53997 .45206 .5439 .45176 .5418 .44893 Metetra
.559 .66 .904 r
.5418 .44893 .5439 .45176 .54784 .45154 .54574 .44867 Metetra
.965 .681 .446 r
.54574 .44867 .54784 .45154 .55338 .64568 .55117 .64348 Metetra
.645 .763 .934 r
.55117 .64348 .55338 .64568 .55756 .64449 .55535 .64229 Metetra
.645 .763 .934 r
.55535 .64229 .55756 .64449 .56175 .6433 .55955 .64109 Metetra
.88 .791 .757 r
.55955 .64109 .56175 .6433 .56595 .64211 .56369 .63488 Metetra
.869 .658 .614 r
.56369 .63488 .56595 .64211 .57001 .62995 .56769 .61768 Metetra
.76 .561 .629 r
.56769 .61768 .57001 .62995 .57403 .61714 .57174 .60665 Metetra
.727 .551 .652 r
.57174 .60665 .57403 .61714 .57812 .60923 .57583 .59967 Metetra
.679 .528 .674 r
.57583 .59967 .57812 .60923 .58225 .60492 .57997 .59577 Metetra
.609 .489 .69 r
.57997 .59577 .58225 .60492 .58643 .60371 .58415 .59455 Metetra
.506 .422 .696 r
.58415 .59455 .58643 .60371 .59069 .60559 .58839 .59601 Metetra
.35 .314 .678 r
.58839 .59601 .59069 .60559 .59503 .61108 .5927 .60056 Metetra
.119 .145 .613 r
.5927 .60056 .59503 .61108 .5995 .6215 .59712 .60918 Metetra
0 0 .472 r
.59712 .60918 .5995 .6215 .60399 .63129 .60171 .62401 Metetra
.319 .337 .723 r
.60171 .62401 .60399 .63129 .60825 .63008 .60609 .62784 Metetra
.645 .763 .934 r
.60609 .62784 .60825 .63008 .61251 .62886 .61036 .62662 Metetra
.645 .763 .934 r
.61036 .62662 .61251 .62886 .61678 .62765 .61463 .6254 Metetra
.969 .694 .456 r
.61463 .6254 .61678 .62765 .61558 .42988 .61354 .42695 Metetra
.73 .722 .843 r
.61354 .42695 .61558 .42988 .61959 .42754 .61755 .42464 Metetra
.726 .724 .848 r
.61755 .42464 .61959 .42754 .6236 .42529 .62156 .42243 Metetra
.722 .725 .853 r
.62156 .42243 .6236 .42529 .62762 .42312 .62559 .42028 Metetra
.719 .727 .857 r
.62559 .42028 .62762 .42312 .63164 .42101 .62962 .4182 Metetra
.715 .728 .86 r
.62962 .4182 .63164 .42101 .63567 .41896 .63365 .41617 Metetra
.713 .729 .863 r
.63365 .41617 .63567 .41896 .63971 .41696 .63769 .41419 Metetra
.71 .73 .866 r
.63769 .41419 .63971 .41696 .64375 .415 .64174 .41225 Metetra
.707 .731 .869 r
.64174 .41225 .64375 .415 .6478 .41309 .64579 .41035 Metetra
.705 .731 .871 r
.64579 .41035 .6478 .41309 .65185 .41121 .64985 .40849 Metetra
.703 .732 .873 r
.64985 .40849 .65185 .41121 .65591 .40936 .65391 .40665 Metetra
.701 .732 .875 r
.65391 .40665 .65591 .40936 .65997 .40755 .65798 .40485 Metetra
.699 .733 .877 r
.65798 .40485 .65997 .40755 .66404 .40575 .66205 .40307 Metetra
.698 .733 .878 r
.66205 .40307 .66404 .40575 .66812 .40399 .66614 .40131 Metetra
.696 .734 .88 r
.66614 .40131 .66812 .40399 .6722 .40224 .67022 .39957 Metetra
.695 .734 .881 r
.67022 .39957 .6722 .40224 .67629 .40052 .67432 .39785 Metetra
.693 .735 .882 r
.67432 .39785 .67629 .40052 .68039 .39881 .67841 .39615 Metetra
.692 .735 .884 r
.67841 .39615 .68039 .39881 .68449 .39712 .68252 .39446 Metetra
.691 .735 .885 r
.68252 .39446 .68449 .39712 .68859 .39544 .68663 .39279 Metetra
.69 .736 .886 r
.68663 .39279 .68859 .39544 .6927 .39377 .69075 .39113 Metetra
.689 .736 .887 r
.69075 .39113 .6927 .39377 .69682 .39212 .69487 .38948 Metetra
.688 .736 .888 r
.69487 .38948 .69682 .39212 .70095 .39048 .699 .38784 Metetra
.687 .736 .888 r
.699 .38784 .70095 .39048 .70507 .38886 .70313 .38622 Metetra
.686 .736 .889 r
.70313 .38622 .70507 .38886 .70921 .38724 .70727 .3846 Metetra
.685 .737 .89 r
.70727 .3846 .70921 .38724 .71335 .38563 .71142 .38299 Metetra
.684 .737 .891 r
.71142 .38299 .71335 .38563 .7175 .38403 .71557 .38139 Metetra
.684 .737 .891 r
.71557 .38139 .7175 .38403 .72165 .38243 .71973 .3798 Metetra
.683 .737 .892 r
.71973 .3798 .72165 .38243 .72581 .38085 .72389 .37821 Metetra
.682 .737 .892 r
.72389 .37821 .72581 .38085 .72998 .37927 .72806 .37664 Metetra
.682 .737 .893 r
.72806 .37664 .72998 .37927 .73415 .37769 .73224 .37506 Metetra
.681 .738 .893 r
.73224 .37506 .73415 .37769 .73833 .37612 .73642 .37349 Metetra
.681 .738 .894 r
.73642 .37349 .73833 .37612 .74251 .37456 .74061 .37193 Metetra
.68 .738 .894 r
.74061 .37193 .74251 .37456 .7467 .373 .7448 .37037 Metetra
.679 .738 .895 r
.7448 .37037 .7467 .373 .7509 .37145 .749 .36882 Metetra
.679 .738 .895 r
.749 .36882 .7509 .37145 .7551 .3699 .75321 .36727 Metetra
.679 .738 .896 r
.75321 .36727 .7551 .3699 .75931 .36835 .75742 .36572 Metetra
.678 .738 .896 r
.75742 .36572 .75931 .36835 .76352 .36681 .76164 .36418 Metetra
.678 .738 .896 r
.76164 .36418 .76352 .36681 .76774 .36527 .76587 .36264 Metetra
.677 .738 .897 r
.76587 .36264 .76774 .36527 .77197 .36374 .7701 .3611 Metetra
.677 .738 .897 r
.7701 .3611 .77197 .36374 .7762 .3622 .77433 .35957 Metetra
.676 .739 .897 r
.77433 .35957 .7762 .3622 .78044 .36067 .77858 .35803 Metetra
.676 .739 .898 r
.77858 .35803 .78044 .36067 .78469 .35914 .78283 .3565 Metetra
.676 .739 .898 r
.78283 .3565 .78469 .35914 .78894 .35762 .78708 .35498 Metetra
.675 .739 .898 r
.78708 .35498 .78894 .35762 .7932 .35609 .79135 .35345 Metetra
.675 .739 .898 r
.79135 .35345 .7932 .35609 .79746 .35457 .79561 .35193 Metetra
.675 .739 .899 r
.79561 .35193 .79746 .35457 .80173 .35305 .79989 .3504 Metetra
.675 .739 .899 r
.79989 .3504 .80173 .35305 .80601 .35153 .80417 .34888 Metetra
.674 .739 .899 r
.80417 .34888 .80601 .35153 .81029 .35001 .80846 .34736 Metetra
.674 .739 .899 r
.80846 .34736 .81029 .35001 .81458 .34849 .81275 .34584 Metetra
.674 .739 .9 r
.81275 .34584 .81458 .34849 .81887 .34698 .81705 .34432 Metetra
.674 .739 .9 r
.81705 .34432 .81887 .34698 .82318 .34546 .82136 .34281 Metetra
.673 .739 .9 r
.82136 .34281 .82318 .34546 .82748 .34395 .82567 .34129 Metetra
.673 .739 .9 r
.82567 .34129 .82748 .34395 .8318 .34243 .82999 .33977 Metetra
.673 .739 .9 r
.82999 .33977 .8318 .34243 .83612 .34092 .83432 .33826 Metetra
.673 .739 .901 r
.83432 .33826 .83612 .34092 .84045 .33941 .83865 .33674 Metetra
.672 .739 .901 r
.83865 .33674 .84045 .33941 .84478 .33789 .84299 .33523 Metetra
.672 .739 .901 r
.84299 .33523 .84478 .33789 .84912 .33638 .84733 .33371 Metetra
.672 .739 .901 r
.84733 .33371 .84912 .33638 .85347 .33487 .85168 .3322 Metetra
.963 .775 .602 r
.85168 .3322 .85347 .33487 .85782 .33336 .85482 .31908 Metetra
.595 .439 .64 r
.85482 .31908 .85782 .33336 .86218 .33185 .85918 .31766 Metetra
.595 .44 .64 r
.85918 .31766 .86218 .33185 .8653 .31886 .86354 .31624 Metetra
.664 .741 .907 r
.86354 .31624 .8653 .31886 .86967 .31744 .86792 .31481 Metetra
.664 .741 .907 r
.86792 .31481 .86967 .31744 .87404 .31602 .87229 .31339 Metetra
.664 .741 .907 r
.87229 .31339 .87404 .31602 .87842 .31459 .87668 .31196 Metetra
.664 .741 .907 r
.87668 .31196 .87842 .31459 .88281 .31317 .88107 .31053 Metetra
.664 .741 .907 r
.88107 .31053 .88281 .31317 .8872 .31174 .88546 .3091 Metetra
.664 .741 .907 r
.88546 .3091 .8872 .31174 .8916 .31031 .88987 .30766 Metetra
.664 .741 .907 r
.29703 .49784 .29933 .49999 .3029 .49883 .3006 .49668 Metetra
.664 .741 .907 r
.3006 .49668 .3029 .49883 .30647 .49766 .30418 .49551 Metetra
.664 .741 .907 r
.30418 .49551 .30647 .49766 .31004 .4965 .30776 .49435 Metetra
.664 .741 .907 r
.30776 .49435 .31004 .4965 .31363 .49533 .31134 .49318 Metetra
.664 .741 .907 r
.31134 .49318 .31363 .49533 .31721 .49417 .31493 .49201 Metetra
.664 .741 .907 r
.31493 .49201 .31721 .49417 .3208 .493 .31852 .49083 Metetra
.664 .741 .907 r
.31852 .49083 .3208 .493 .3244 .49183 .32212 .48966 Metetra
.664 .741 .907 r
.32212 .48966 .3244 .49183 .328 .49065 .32572 .48848 Metetra
.664 .741 .907 r
.32572 .48848 .328 .49065 .33095 .50071 .32933 .48731 Metetra
.05 .044 .529 r
.32933 .48731 .33095 .50071 .33457 .49963 .33229 .4974 Metetra
.653 .733 .908 r
.33229 .4974 .33457 .49963 .33819 .49856 .33592 .49632 Metetra
.653 .733 .908 r
.33592 .49632 .33819 .49856 .34181 .49749 .33955 .49525 Metetra
.652 .733 .908 r
.33955 .49525 .34181 .49749 .34545 .49642 .34318 .49417 Metetra
.652 .732 .908 r
.34318 .49417 .34545 .49642 .34908 .49535 .34682 .4931 Metetra
.652 .732 .908 r
.34682 .4931 .34908 .49535 .35272 .49428 .35047 .49202 Metetra
.651 .732 .908 r
.35047 .49202 .35272 .49428 .35637 .49321 .35412 .49095 Metetra
.651 .732 .908 r
.35412 .49095 .35637 .49321 .36002 .49215 .35777 .48988 Metetra
.651 .732 .908 r
.35777 .48988 .36002 .49215 .36368 .49108 .36143 .48881 Metetra
.651 .731 .908 r
.36143 .48881 .36368 .49108 .36734 .49002 .3651 .48774 Metetra
.65 .731 .908 r
.3651 .48774 .36734 .49002 .37101 .48895 .36877 .48667 Metetra
.65 .731 .908 r
.36877 .48667 .37101 .48895 .37468 .48789 .37244 .48561 Metetra
.65 .731 .908 r
.37244 .48561 .37468 .48789 .37836 .48683 .37613 .48454 Metetra
.649 .73 .908 r
.37613 .48454 .37836 .48683 .38204 .48578 .37981 .48348 Metetra
.649 .73 .908 r
.37981 .48348 .38204 .48578 .38573 .48472 .3835 .48242 Metetra
.649 .73 .908 r
.3835 .48242 .38573 .48472 .38943 .48367 .3872 .48136 Metetra
.648 .729 .908 r
.3872 .48136 .38943 .48367 .39313 .48262 .3909 .48031 Metetra
.648 .729 .908 r
.3909 .48031 .39313 .48262 .39683 .48157 .39461 .47926 Metetra
.647 .729 .908 r
.39461 .47926 .39683 .48157 .40054 .48053 .39832 .47821 Metetra
.647 .728 .908 r
.39832 .47821 .40054 .48053 .40425 .47949 .40204 .47716 Metetra
.646 .728 .908 r
.40204 .47716 .40425 .47949 .40797 .47845 .40576 .47612 Metetra
.646 .728 .908 r
.40576 .47612 .40797 .47845 .4117 .47741 .40949 .47508 Metetra
.645 .727 .908 r
.40949 .47508 .4117 .47741 .41543 .47638 .41323 .47404 Metetra
.645 .727 .908 r
.41323 .47404 .41543 .47638 .41917 .47536 .41696 .47301 Metetra
.644 .726 .908 r
.41696 .47301 .41917 .47536 .42291 .47433 .42071 .47198 Metetra
.643 .726 .908 r
.42071 .47198 .42291 .47433 .42666 .47332 .42446 .47095 Metetra
.643 .725 .908 r
.42446 .47095 .42666 .47332 .43041 .4723 .42822 .46993 Metetra
.642 .725 .908 r
.42822 .46993 .43041 .4723 .43417 .4713 .43198 .46892 Metetra
.641 .724 .908 r
.43198 .46892 .43417 .4713 .43793 .4703 .43574 .46791 Metetra
.641 .724 .908 r
.43574 .46791 .43793 .4703 .4417 .4693 .43952 .46691 Metetra
.64 .723 .908 r
.43952 .46691 .4417 .4693 .44547 .46831 .44329 .46591 Metetra
.639 .722 .908 r
.44329 .46591 .44547 .46831 .44925 .46733 .44708 .46492 Metetra
.638 .721 .908 r
.44708 .46492 .44925 .46733 .45304 .46636 .45087 .46394 Metetra
.637 .721 .908 r
.45087 .46394 .45304 .46636 .45683 .46539 .45466 .46297 Metetra
.636 .72 .908 r
.45466 .46297 .45683 .46539 .46063 .46444 .45846 .462 Metetra
.635 .719 .908 r
.45846 .462 .46063 .46444 .46443 .46349 .46227 .46105 Metetra
.634 .718 .908 r
.46227 .46105 .46443 .46349 .46824 .46255 .46608 .4601 Metetra
.632 .717 .908 r
.46608 .4601 .46824 .46255 .47206 .46163 .4699 .45917 Metetra
.631 .716 .908 r
.4699 .45917 .47206 .46163 .47588 .46072 .47372 .45825 Metetra
.629 .715 .908 r
.47372 .45825 .47588 .46072 .4797 .45982 .47755 .45734 Metetra
.628 .714 .908 r
.47755 .45734 .4797 .45982 .48354 .45894 .48139 .45644 Metetra
.626 .712 .908 r
.48139 .45644 .48354 .45894 .48737 .45807 .48523 .45556 Metetra
.624 .711 .908 r
.48523 .45556 .48737 .45807 .49122 .45722 .48908 .4547 Metetra
.622 .709 .908 r
.48908 .4547 .49122 .45722 .49507 .45639 .49293 .45385 Metetra
.62 .707 .908 r
.49293 .45385 .49507 .45639 .49893 .45558 .49679 .45303 Metetra
.617 .705 .908 r
.49679 .45303 .49893 .45558 .50279 .45479 .50066 .45223 Metetra
.615 .703 .908 r
.50066 .45223 .50279 .45479 .50666 .45403 .50453 .45145 Metetra
.612 .701 .908 r
.50453 .45145 .50666 .45403 .51054 .4533 .50841 .4507 Metetra
.609 .699 .907 r
.50841 .4507 .51054 .4533 .51442 .45259 .51229 .44997 Metetra
.605 .696 .907 r
.51229 .44997 .51442 .45259 .51831 .45193 .51619 .44929 Metetra
.601 .693 .907 r
.51619 .44929 .51831 .45193 .5222 .4513 .52008 .44863 Metetra
.597 .689 .907 r
.52008 .44863 .5222 .4513 .52611 .45071 .52399 .44802 Metetra
.592 .685 .907 r
.52399 .44802 .52611 .45071 .53002 .45017 .5279 .44746 Metetra
.586 .681 .906 r
.5279 .44746 .53002 .45017 .53394 .44969 .53182 .44694 Metetra
.579 .676 .906 r
.53182 .44694 .53394 .44969 .53786 .44927 .53575 .44649 Metetra
.572 .67 .905 r
.53575 .44649 .53786 .44927 .5418 .44893 .53969 .4461 Metetra
.964 .681 .448 r
.53969 .4461 .5418 .44893 .54574 .44867 .54476 .64247 Metetra
.552 .333 .536 r
.54476 .64247 .54574 .44867 .55117 .64348 .54895 .64128 Metetra
.645 .763 .934 r
.54895 .64128 .55117 .64348 .55535 .64229 .55314 .64008 Metetra
.645 .763 .934 r
.55314 .64008 .55535 .64229 .55955 .64109 .55733 .63888 Metetra
.947 .748 .602 r
.55733 .63888 .55955 .64109 .56369 .63488 .56136 .621 Metetra
.777 .566 .614 r
.56136 .621 .56369 .63488 .56769 .61768 .56539 .60645 Metetra
.755 .564 .637 r
.56539 .60645 .56769 .61768 .57174 .60665 .56946 .59685 Metetra
.722 .553 .66 r
.56946 .59685 .57174 .60665 .57583 .59967 .57356 .59064 Metetra
.676 .532 .681 r
.57356 .59064 .57583 .59967 .57997 .59577 .5777 .58708 Metetra
.612 .496 .697 r
.5777 .58708 .57997 .59577 .58415 .59455 .58188 .58585 Metetra
.518 .437 .703 r
.58188 .58585 .58415 .59455 .58839 .59601 .58611 .58696 Metetra
.382 .343 .69 r
.58611 .58696 .58839 .59601 .5927 .60056 .5904 .59073 Metetra
.183 .198 .641 r
.5904 .59073 .5927 .60056 .59712 .60918 .59478 .5979 Metetra
0 0 .529 r
.59478 .5979 .59712 .60918 .60171 .62401 .59929 .61006 Metetra
0 0 .491 r
.59929 .61006 .60171 .62401 .60609 .62784 .60392 .62559 Metetra
.645 .763 .934 r
.60392 .62559 .60609 .62784 .61036 .62662 .6082 .62437 Metetra
.645 .763 .934 r
.6082 .62437 .61036 .62662 .61463 .6254 .61248 .62315 Metetra
.645 .763 .934 r
.61248 .62315 .61463 .6254 .61354 .42695 .61676 .62192 Metetra
0 0 .385 r
.61676 .62192 .61354 .42695 .61755 .42464 .6155 .42175 Metetra
.724 .724 .85 r
.6155 .42175 .61755 .42464 .62156 .42243 .61952 .41957 Metetra
.72 .726 .855 r
.61952 .41957 .62156 .42243 .62559 .42028 .62355 .41745 Metetra
.717 .727 .858 r
.62355 .41745 .62559 .42028 .62962 .4182 .62758 .41539 Metetra
.714 .728 .862 r
.62758 .41539 .62962 .4182 .63365 .41617 .63162 .41339 Metetra
.711 .729 .865 r
.63162 .41339 .63365 .41617 .63769 .41419 .63567 .41142 Metetra
.709 .73 .867 r
.63567 .41142 .63769 .41419 .64174 .41225 .63972 .4095 Metetra
.706 .731 .87 r
.63972 .4095 .64174 .41225 .64579 .41035 .64378 .40762 Metetra
.704 .731 .872 r
.64378 .40762 .64579 .41035 .64985 .40849 .64784 .40577 Metetra
.702 .732 .874 r
.64784 .40577 .64985 .40849 .65391 .40665 .65191 .40395 Metetra
.7 .733 .876 r
.65191 .40395 .65391 .40665 .65798 .40485 .65598 .40215 Metetra
.698 .733 .877 r
.65598 .40215 .65798 .40485 .66205 .40307 .66006 .40038 Metetra
.697 .734 .879 r
.66006 .40038 .66205 .40307 .66614 .40131 .66415 .39863 Metetra
.695 .734 .88 r
.66415 .39863 .66614 .40131 .67022 .39957 .66824 .39689 Metetra
.694 .734 .882 r
.66824 .39689 .67022 .39957 .67432 .39785 .67233 .39518 Metetra
.693 .735 .883 r
.67233 .39518 .67432 .39785 .67841 .39615 .67644 .39348 Metetra
.691 .735 .884 r
.67644 .39348 .67841 .39615 .68252 .39446 .68055 .3918 Metetra
.69 .735 .885 r
.68055 .3918 .68252 .39446 .68663 .39279 .68466 .39013 Metetra
.689 .736 .886 r
.68466 .39013 .68663 .39279 .69075 .39113 .68878 .38848 Metetra
.688 .736 .887 r
.68878 .38848 .69075 .39113 .69487 .38948 .69291 .38683 Metetra
.687 .736 .888 r
.69291 .38683 .69487 .38948 .699 .38784 .69704 .3852 Metetra
.686 .736 .889 r
.69704 .3852 .699 .38784 .70313 .38622 .70118 .38358 Metetra
.686 .736 .889 r
.70118 .38358 .70313 .38622 .70727 .3846 .70532 .38196 Metetra
.685 .737 .89 r
.70532 .38196 .70727 .3846 .71142 .38299 .70947 .38035 Metetra
.684 .737 .891 r
.70947 .38035 .71142 .38299 .71557 .38139 .71363 .37876 Metetra
.683 .737 .891 r
.71363 .37876 .71557 .38139 .71973 .3798 .71779 .37716 Metetra
.683 .737 .892 r
.71779 .37716 .71973 .3798 .72389 .37821 .72196 .37558 Metetra
.682 .737 .893 r
.72196 .37558 .72389 .37821 .72806 .37664 .72614 .374 Metetra
.681 .737 .893 r
.72614 .374 .72806 .37664 .73224 .37506 .73032 .37243 Metetra
.681 .738 .894 r
.73032 .37243 .73224 .37506 .73642 .37349 .7345 .37086 Metetra
.68 .738 .894 r
.7345 .37086 .73642 .37349 .74061 .37193 .7387 .3693 Metetra
.68 .738 .895 r
.7387 .3693 .74061 .37193 .7448 .37037 .7429 .36774 Metetra
.679 .738 .895 r
.7429 .36774 .7448 .37037 .749 .36882 .7471 .36618 Metetra
.679 .738 .895 r
.7471 .36618 .749 .36882 .75321 .36727 .75131 .36463 Metetra
.678 .738 .896 r
.75131 .36463 .75321 .36727 .75742 .36572 .75553 .36308 Metetra
.678 .738 .896 r
.75553 .36308 .75742 .36572 .76164 .36418 .75975 .36154 Metetra
.677 .738 .896 r
.75975 .36154 .76164 .36418 .76587 .36264 .76398 .36 Metetra
.677 .738 .897 r
.76398 .36 .76587 .36264 .7701 .3611 .76822 .35846 Metetra
.677 .738 .897 r
.76822 .35846 .7701 .3611 .77433 .35957 .77246 .35692 Metetra
.676 .739 .897 r
.77246 .35692 .77433 .35957 .77858 .35803 .77671 .35539 Metetra
.676 .739 .898 r
.77671 .35539 .77858 .35803 .78283 .3565 .78096 .35386 Metetra
.676 .739 .898 r
.78096 .35386 .78283 .3565 .78708 .35498 .78522 .35233 Metetra
.675 .739 .898 r
.78522 .35233 .78708 .35498 .79135 .35345 .78949 .3508 Metetra
.675 .739 .899 r
.78949 .3508 .79135 .35345 .79561 .35193 .79376 .34928 Metetra
.675 .739 .899 r
.79376 .34928 .79561 .35193 .79989 .3504 .79804 .34775 Metetra
.674 .739 .899 r
.79804 .34775 .79989 .3504 .80417 .34888 .80233 .34623 Metetra
.674 .739 .899 r
.80233 .34623 .80417 .34888 .80846 .34736 .80662 .3447 Metetra
.674 .739 .899 r
.80662 .3447 .80846 .34736 .81275 .34584 .81092 .34318 Metetra
.674 .739 .9 r
.81092 .34318 .81275 .34584 .81705 .34432 .81522 .34166 Metetra
.673 .739 .9 r
.81522 .34166 .81705 .34432 .82136 .34281 .81954 .34014 Metetra
.673 .739 .9 r
.81954 .34014 .82136 .34281 .82567 .34129 .82385 .33862 Metetra
.673 .739 .9 r
.82385 .33862 .82567 .34129 .82999 .33977 .82818 .3371 Metetra
.673 .739 .9 r
.82818 .3371 .82999 .33977 .83432 .33826 .83251 .33559 Metetra
.673 .739 .901 r
.83251 .33559 .83432 .33826 .83865 .33674 .83684 .33407 Metetra
.672 .739 .901 r
.83684 .33407 .83865 .33674 .84299 .33523 .84119 .33255 Metetra
.672 .739 .901 r
.84119 .33255 .84299 .33523 .84733 .33371 .84554 .33103 Metetra
.963 .775 .602 r
.84554 .33103 .84733 .33371 .85168 .3322 .84869 .31788 Metetra
.595 .438 .639 r
.84869 .31788 .85168 .3322 .85482 .31908 .85305 .31645 Metetra
.664 .741 .907 r
.85305 .31645 .85482 .31908 .85918 .31766 .85741 .31503 Metetra
.664 .741 .907 r
.85741 .31503 .85918 .31766 .86354 .31624 .86178 .31361 Metetra
.664 .741 .907 r
.86178 .31361 .86354 .31624 .86792 .31481 .86616 .31218 Metetra
.664 .741 .907 r
.86616 .31218 .86792 .31481 .87229 .31339 .87054 .31075 Metetra
.664 .741 .907 r
.87054 .31075 .87229 .31339 .87668 .31196 .87493 .30932 Metetra
.664 .741 .907 r
.87493 .30932 .87668 .31196 .88107 .31053 .87932 .30788 Metetra
.664 .741 .907 r
.87932 .30788 .88107 .31053 .88546 .3091 .88372 .30645 Metetra
.664 .741 .907 r
.88372 .30645 .88546 .3091 .88987 .30766 .88813 .30501 Metetra
.664 .741 .907 r
.29473 .49569 .29703 .49784 .3006 .49668 .2983 .49453 Metetra
.664 .741 .907 r
.2983 .49453 .3006 .49668 .30418 .49551 .30188 .49336 Metetra
.664 .741 .907 r
.30188 .49336 .30418 .49551 .30776 .49435 .30546 .49219 Metetra
.664 .741 .907 r
.30546 .49219 .30776 .49435 .31134 .49318 .30905 .49101 Metetra
.664 .741 .907 r
.30905 .49101 .31134 .49318 .31493 .49201 .31264 .48984 Metetra
.664 .741 .907 r
.31264 .48984 .31493 .49201 .31852 .49083 .31624 .48866 Metetra
.664 .741 .907 r
.31624 .48866 .31852 .49083 .32212 .48966 .31984 .48749 Metetra
.664 .741 .907 r
.31984 .48749 .32212 .48966 .32572 .48848 .32345 .48631 Metetra
.664 .741 .907 r
.32345 .48631 .32572 .48848 .32933 .48731 .32706 .48513 Metetra
.664 .741 .907 r
.32706 .48513 .32933 .48731 .33229 .4974 .33067 .48395 Metetra
.049 .044 .528 r
.33067 .48395 .33229 .4974 .33592 .49632 .33364 .49408 Metetra
.653 .733 .908 r
.33364 .49408 .33592 .49632 .33955 .49525 .33727 .493 Metetra
.652 .733 .908 r
.33727 .493 .33955 .49525 .34318 .49417 .34091 .49192 Metetra
.652 .733 .908 r
.34091 .49192 .34318 .49417 .34682 .4931 .34456 .49084 Metetra
.652 .732 .908 r
.34456 .49084 .34682 .4931 .35047 .49202 .3482 .48976 Metetra
.652 .732 .908 r
.3482 .48976 .35047 .49202 .35412 .49095 .35186 .48868 Metetra
.651 .732 .908 r
.35186 .48868 .35412 .49095 .35777 .48988 .35551 .48761 Metetra
.651 .732 .908 r
.35551 .48761 .35777 .48988 .36143 .48881 .35918 .48653 Metetra
.651 .731 .908 r
.35918 .48653 .36143 .48881 .3651 .48774 .36285 .48546 Metetra
.65 .731 .908 r
.36285 .48546 .3651 .48774 .36877 .48667 .36652 .48439 Metetra
.65 .731 .908 r
.36652 .48439 .36877 .48667 .37244 .48561 .3702 .48332 Metetra
.65 .731 .908 r
.3702 .48332 .37244 .48561 .37613 .48454 .37388 .48225 Metetra
.649 .73 .908 r
.37388 .48225 .37613 .48454 .37981 .48348 .37757 .48118 Metetra
.649 .73 .908 r
.37757 .48118 .37981 .48348 .3835 .48242 .38127 .48012 Metetra
.649 .73 .908 r
.38127 .48012 .3835 .48242 .3872 .48136 .38497 .47905 Metetra
.648 .73 .908 r
.38497 .47905 .3872 .48136 .3909 .48031 .38867 .47799 Metetra
.648 .729 .908 r
.38867 .47799 .3909 .48031 .39461 .47926 .39238 .47694 Metetra
.648 .729 .908 r
.39238 .47694 .39461 .47926 .39832 .47821 .3961 .47588 Metetra
.647 .728 .908 r
.3961 .47588 .39832 .47821 .40204 .47716 .39982 .47483 Metetra
.647 .728 .908 r
.39982 .47483 .40204 .47716 .40576 .47612 .40354 .47378 Metetra
.646 .728 .908 r
.40354 .47378 .40576 .47612 .40949 .47508 .40728 .47273 Metetra
.646 .727 .908 r
.40728 .47273 .40949 .47508 .41323 .47404 .41101 .47169 Metetra
.645 .727 .908 r
.41101 .47169 .41323 .47404 .41696 .47301 .41476 .47065 Metetra
.644 .726 .908 r
.41476 .47065 .41696 .47301 .42071 .47198 .4185 .46961 Metetra
.644 .726 .908 r
.4185 .46961 .42071 .47198 .42446 .47095 .42226 .46858 Metetra
.643 .725 .908 r
.42226 .46858 .42446 .47095 .42822 .46993 .42602 .46756 Metetra
.642 .725 .908 r
.42602 .46756 .42822 .46993 .43198 .46892 .42978 .46654 Metetra
.642 .724 .908 r
.42978 .46654 .43198 .46892 .43574 .46791 .43355 .46552 Metetra
.641 .724 .908 r
.43355 .46552 .43574 .46791 .43952 .46691 .43733 .46451 Metetra
.64 .723 .908 r
.43733 .46451 .43952 .46691 .44329 .46591 .44111 .46351 Metetra
.639 .722 .908 r
.44111 .46351 .44329 .46591 .44708 .46492 .44489 .46251 Metetra
.638 .722 .908 r
.44489 .46251 .44708 .46492 .45087 .46394 .44869 .46152 Metetra
.638 .721 .908 r
.44869 .46152 .45087 .46394 .45466 .46297 .45248 .46054 Metetra
.636 .72 .908 r
.45248 .46054 .45466 .46297 .45846 .462 .45629 .45957 Metetra
.635 .719 .908 r
.45629 .45957 .45846 .462 .46227 .46105 .4601 .4586 Metetra
.634 .718 .908 r
.4601 .4586 .46227 .46105 .46608 .4601 .46391 .45765 Metetra
.633 .717 .908 r
.46391 .45765 .46608 .4601 .4699 .45917 .46773 .4567 Metetra
.632 .716 .908 r
.46773 .4567 .4699 .45917 .47372 .45825 .47156 .45577 Metetra
.63 .715 .908 r
.47156 .45577 .47372 .45825 .47755 .45734 .47539 .45485 Metetra
.629 .714 .908 r
.47539 .45485 .47755 .45734 .48139 .45644 .47923 .45394 Metetra
.627 .713 .908 r
.47923 .45394 .48139 .45644 .48523 .45556 .48308 .45305 Metetra
.625 .711 .908 r
.48308 .45305 .48523 .45556 .48908 .4547 .48693 .45218 Metetra
.623 .71 .908 r
.48693 .45218 .48908 .4547 .49293 .45385 .49078 .45132 Metetra
.621 .708 .908 r
.49078 .45132 .49293 .45385 .49679 .45303 .49465 .45048 Metetra
.619 .706 .908 r
.49465 .45048 .49679 .45303 .50066 .45223 .49852 .44966 Metetra
.616 .704 .908 r
.49852 .44966 .50066 .45223 .50453 .45145 .50239 .44887 Metetra
.613 .702 .908 r
.50239 .44887 .50453 .45145 .50841 .4507 .50627 .4481 Metetra
.61 .7 .907 r
.50627 .4481 .50841 .4507 .51229 .44997 .51016 .44736 Metetra
.607 .697 .907 r
.51016 .44736 .51229 .44997 .51619 .44929 .51406 .44665 Metetra
.603 .694 .907 r
.51406 .44665 .51619 .44929 .52008 .44863 .51796 .44597 Metetra
.599 .691 .907 r
.51796 .44597 .52008 .44863 .52399 .44802 .52187 .44533 Metetra
.594 .687 .906 r
.52187 .44533 .52399 .44802 .5279 .44746 .52578 .44474 Metetra
.589 .683 .906 r
.52578 .44474 .5279 .44746 .53182 .44694 .52971 .4442 Metetra
.583 .678 .906 r
.52971 .4442 .53182 .44694 .53575 .44649 .53364 .44371 Metetra
.576 .672 .905 r
.53364 .44371 .53575 .44649 .53969 .4461 .53758 .44329 Metetra
.964 .681 .448 r
.53758 .44329 .53969 .4461 .54476 .64247 .54253 .64027 Metetra
.645 .763 .934 r
.54253 .64027 .54476 .64247 .54895 .64128 .54672 .63907 Metetra
.645 .763 .934 r
.54672 .63907 .54895 .64128 .55314 .64008 .55091 .63787 Metetra
.923 .771 .675 r
.55091 .63787 .55314 .64008 .55733 .63888 .55503 .62746 Metetra
.83 .61 .605 r
.55503 .62746 .55733 .63888 .56136 .621 .55905 .60855 Metetra
.772 .569 .623 r
.55905 .60855 .56136 .621 .56539 .60645 .56311 .59608 Metetra
.75 .566 .646 r
.56311 .59608 .56539 .60645 .56946 .59685 .56719 .58765 Metetra
.718 .555 .668 r
.56719 .58765 .56946 .59685 .57356 .59064 .5713 .58208 Metetra
.674 .536 .688 r
.5713 .58208 .57356 .59064 .5777 .58708 .57544 .57881 Metetra
.614 .502 .703 r
.57544 .57881 .5777 .58708 .58188 .58585 .57962 .57757 Metetra
.529 .45 .71 r
.57962 .57757 .58188 .58585 .58611 .58696 .58384 .57839 Metetra
.409 .368 .701 r
.58384 .57839 .58611 .58696 .5904 .59073 .58811 .58149 Metetra
.238 .244 .663 r
.58811 .58149 .5904 .59073 .59478 .5979 .59245 .58749 Metetra
.003 .065 .576 r
.59245 .58749 .59478 .5979 .59929 .61006 .59691 .59754 Metetra
0 0 .422 r
.59691 .59754 .59929 .61006 .60392 .62559 .60154 .61408 Metetra
.208 .197 .625 r
.60154 .61408 .60392 .62559 .6082 .62437 .60603 .62211 Metetra
.645 .763 .934 r
.60603 .62211 .6082 .62437 .61248 .62315 .61031 .62089 Metetra
.645 .763 .934 r
.61031 .62089 .61248 .62315 .61676 .62192 .6146 .61966 Metetra
.969 .694 .455 r
.6146 .61966 .61676 .62192 .6155 .42175 .61345 .41887 Metetra
.722 .725 .852 r
.61345 .41887 .6155 .42175 .61952 .41957 .61748 .41672 Metetra
.718 .726 .856 r
.61748 .41672 .61952 .41957 .62355 .41745 .62151 .41463 Metetra
.715 .727 .86 r
.62151 .41463 .62355 .41745 .62758 .41539 .62555 .41259 Metetra
.712 .728 .863 r
.62555 .41259 .62758 .41539 .63162 .41339 .62959 .4106 Metetra
.71 .729 .866 r
.62959 .4106 .63162 .41339 .63567 .41142 .63364 .40866 Metetra
.707 .73 .868 r
.63364 .40866 .63567 .41142 .63972 .4095 .6377 .40676 Metetra
.705 .731 .871 r
.6377 .40676 .63972 .4095 .64378 .40762 .64176 .40489 Metetra
.703 .732 .873 r
.64176 .40489 .64378 .40762 .64784 .40577 .64583 .40305 Metetra
.701 .732 .875 r
.64583 .40305 .64784 .40577 .65191 .40395 .6499 .40123 Metetra
.699 .733 .877 r
.6499 .40123 .65191 .40395 .65598 .40215 .65398 .39945 Metetra
.698 .733 .878 r
.65398 .39945 .65598 .40215 .66006 .40038 .65806 .39768 Metetra
.696 .734 .88 r
.65806 .39768 .66006 .40038 .66415 .39863 .66215 .39594 Metetra
.695 .734 .881 r
.66215 .39594 .66415 .39863 .66824 .39689 .66625 .39421 Metetra
.693 .734 .882 r
.66625 .39421 .66824 .39689 .67233 .39518 .67035 .39251 Metetra
.692 .735 .883 r
.67035 .39251 .67233 .39518 .67644 .39348 .67446 .39082 Metetra
.691 .735 .885 r
.67446 .39082 .67644 .39348 .68055 .3918 .67857 .38914 Metetra
.69 .735 .886 r
.67857 .38914 .68055 .3918 .68466 .39013 .68269 .38747 Metetra
.689 .736 .887 r
.68269 .38747 .68466 .39013 .68878 .38848 .68681 .38582 Metetra
.688 .736 .887 r
.68681 .38582 .68878 .38848 .69291 .38683 .69094 .38418 Metetra
.687 .736 .888 r
.69094 .38418 .69291 .38683 .69704 .3852 .69508 .38255 Metetra
.686 .736 .889 r
.69508 .38255 .69704 .3852 .70118 .38358 .69922 .38093 Metetra
.685 .736 .89 r
.69922 .38093 .70118 .38358 .70532 .38196 .70337 .37931 Metetra
.684 .737 .89 r
.70337 .37931 .70532 .38196 .70947 .38035 .70753 .37771 Metetra
.684 .737 .891 r
.70753 .37771 .70947 .38035 .71363 .37876 .71169 .37611 Metetra
.683 .737 .892 r
.71169 .37611 .71363 .37876 .71779 .37716 .71586 .37452 Metetra
.682 .737 .892 r
.71586 .37452 .71779 .37716 .72196 .37558 .72003 .37294 Metetra
.682 .737 .893 r
.72003 .37294 .72196 .37558 .72614 .374 .72421 .37136 Metetra
.681 .737 .893 r
.72421 .37136 .72614 .374 .73032 .37243 .72839 .36979 Metetra
.68 .738 .894 r
.72839 .36979 .73032 .37243 .7345 .37086 .73259 .36822 Metetra
.68 .738 .894 r
.73259 .36822 .7345 .37086 .7387 .3693 .73678 .36665 Metetra
.679 .738 .895 r
.73678 .36665 .7387 .3693 .7429 .36774 .74099 .36509 Metetra
.679 .738 .895 r
.74099 .36509 .7429 .36774 .7471 .36618 .7452 .36354 Metetra
.678 .738 .896 r
.7452 .36354 .7471 .36618 .75131 .36463 .74941 .36199 Metetra
.678 .738 .896 r
.74941 .36199 .75131 .36463 .75553 .36308 .75363 .36044 Metetra
.678 .738 .896 r
.75363 .36044 .75553 .36308 .75975 .36154 .75786 .35889 Metetra
.677 .738 .897 r
.75786 .35889 .75975 .36154 .76398 .36 .7621 .35735 Metetra
.677 .738 .897 r
.7621 .35735 .76398 .36 .76822 .35846 .76634 .35581 Metetra
.676 .738 .897 r
.76634 .35581 .76822 .35846 .77246 .35692 .77058 .35428 Metetra
.676 .739 .898 r
.77058 .35428 .77246 .35692 .77671 .35539 .77483 .35274 Metetra
.676 .739 .898 r
.77483 .35274 .77671 .35539 .78096 .35386 .77909 .35121 Metetra
.675 .739 .898 r
.77909 .35121 .78096 .35386 .78522 .35233 .78336 .34968 Metetra
.675 .739 .898 r
.78336 .34968 .78522 .35233 .78949 .3508 .78763 .34815 Metetra
.675 .739 .899 r
.78763 .34815 .78949 .3508 .79376 .34928 .79191 .34662 Metetra
.675 .739 .899 r
.79191 .34662 .79376 .34928 .79804 .34775 .79619 .34509 Metetra
.674 .739 .899 r
.79619 .34509 .79804 .34775 .80233 .34623 .80048 .34357 Metetra
.674 .739 .899 r
.80048 .34357 .80233 .34623 .80662 .3447 .80478 .34204 Metetra
.674 .739 .9 r
.80478 .34204 .80662 .3447 .81092 .34318 .80908 .34052 Metetra
.673 .739 .9 r
.80908 .34052 .81092 .34318 .81522 .34166 .81339 .33899 Metetra
.673 .739 .9 r
.81339 .33899 .81522 .34166 .81954 .34014 .81771 .33747 Metetra
.673 .739 .9 r
.81771 .33747 .81954 .34014 .82385 .33862 .82203 .33595 Metetra
.673 .739 .9 r
.82203 .33595 .82385 .33862 .82818 .3371 .82636 .33443 Metetra
.673 .739 .9 r
.82636 .33443 .82818 .3371 .83251 .33559 .83069 .33291 Metetra
.672 .739 .901 r
.83069 .33291 .83251 .33559 .83684 .33407 .83504 .33139 Metetra
.672 .739 .901 r
.83504 .33139 .83684 .33407 .84119 .33255 .83938 .32987 Metetra
.963 .774 .602 r
.83938 .32987 .84119 .33255 .84554 .33103 .84256 .31667 Metetra
.595 .438 .639 r
.84256 .31667 .84554 .33103 .84869 .31788 .84691 .31525 Metetra
.664 .741 .907 r
.84691 .31525 .84869 .31788 .85305 .31645 .85127 .31382 Metetra
.664 .741 .907 r
.85127 .31382 .85305 .31645 .85741 .31503 .85564 .3124 Metetra
.664 .741 .907 r
.85564 .3124 .85741 .31503 .86178 .31361 .86001 .31097 Metetra
.664 .741 .907 r
.86001 .31097 .86178 .31361 .86616 .31218 .86439 .30954 Metetra
.664 .741 .907 r
.86439 .30954 .86616 .31218 .87054 .31075 .86878 .3081 Metetra
.664 .741 .907 r
.86878 .3081 .87054 .31075 .87493 .30932 .87317 .30667 Metetra
.664 .741 .907 r
.87317 .30667 .87493 .30932 .87932 .30788 .87757 .30523 Metetra
.664 .741 .907 r
.87757 .30523 .87932 .30788 .88372 .30645 .88198 .30379 Metetra
.664 .741 .907 r
.88198 .30379 .88372 .30645 .88813 .30501 .88639 .30235 Metetra
.664 .741 .907 r
.29242 .49354 .29473 .49569 .2983 .49453 .296 .49237 Metetra
.664 .741 .907 r
.296 .49237 .2983 .49453 .30188 .49336 .29958 .49119 Metetra
.664 .741 .907 r
.29958 .49119 .30188 .49336 .30546 .49219 .30316 .49002 Metetra
.664 .741 .907 r
.30316 .49002 .30546 .49219 .30905 .49101 .30675 .48885 Metetra
.664 .741 .907 r
.30675 .48885 .30905 .49101 .31264 .48984 .31035 .48767 Metetra
.664 .741 .907 r
.31035 .48767 .31264 .48984 .31624 .48866 .31395 .48649 Metetra
.664 .741 .907 r
.31395 .48649 .31624 .48866 .31984 .48749 .31755 .48531 Metetra
.664 .741 .907 r
.31755 .48531 .31984 .48749 .32345 .48631 .32116 .48413 Metetra
.664 .741 .907 r
.32116 .48413 .32345 .48631 .32706 .48513 .32477 .48295 Metetra
.664 .741 .907 r
.32477 .48295 .32706 .48513 .33067 .48395 .32839 .48176 Metetra
.664 .741 .907 r
.32839 .48176 .33067 .48395 .33364 .49408 .33202 .48057 Metetra
.049 .043 .528 r
.33202 .48057 .33364 .49408 .33727 .493 .335 .49074 Metetra
.653 .733 .908 r
.335 .49074 .33727 .493 .34091 .49192 .33864 .48966 Metetra
.652 .733 .908 r
.33864 .48966 .34091 .49192 .34456 .49084 .34228 .48857 Metetra
.652 .732 .908 r
.34228 .48857 .34456 .49084 .3482 .48976 .34593 .48749 Metetra
.652 .732 .908 r
.34593 .48749 .3482 .48976 .35186 .48868 .34959 .48641 Metetra
.652 .732 .908 r
.34959 .48641 .35186 .48868 .35551 .48761 .35325 .48533 Metetra
.651 .732 .908 r
.35325 .48533 .35551 .48761 .35918 .48653 .35692 .48425 Metetra
.651 .732 .908 r
.35692 .48425 .35918 .48653 .36285 .48546 .36059 .48317 Metetra
.651 .731 .908 r
.36059 .48317 .36285 .48546 .36652 .48439 .36427 .4821 Metetra
.65 .731 .908 r
.36427 .4821 .36652 .48439 .3702 .48332 .36795 .48102 Metetra
.65 .731 .908 r
.36795 .48102 .3702 .48332 .37388 .48225 .37163 .47995 Metetra
.65 .731 .908 r
.37163 .47995 .37388 .48225 .37757 .48118 .37533 .47888 Metetra
.649 .73 .908 r
.37533 .47888 .37757 .48118 .38127 .48012 .37902 .47781 Metetra
.649 .73 .908 r
.37902 .47781 .38127 .48012 .38497 .47905 .38273 .47674 Metetra
.649 .73 .908 r
.38273 .47674 .38497 .47905 .38867 .47799 .38644 .47567 Metetra
.648 .729 .908 r
.38644 .47567 .38867 .47799 .39238 .47694 .39015 .47461 Metetra
.648 .729 .908 r
.39015 .47461 .39238 .47694 .3961 .47588 .39387 .47355 Metetra
.647 .729 .908 r
.39387 .47355 .3961 .47588 .39982 .47483 .39759 .47249 Metetra
.647 .728 .908 r
.39759 .47249 .39982 .47483 .40354 .47378 .40132 .47143 Metetra
.646 .728 .908 r
.40132 .47143 .40354 .47378 .40728 .47273 .40506 .47038 Metetra
.646 .727 .908 r
.40506 .47038 .40728 .47273 .41101 .47169 .4088 .46933 Metetra
.645 .727 .908 r
.4088 .46933 .41101 .47169 .41476 .47065 .41254 .46829 Metetra
.645 .727 .908 r
.41254 .46829 .41476 .47065 .4185 .46961 .41629 .46725 Metetra
.644 .726 .908 r
.41629 .46725 .4185 .46961 .42226 .46858 .42005 .46621 Metetra
.644 .726 .908 r
.42005 .46621 .42226 .46858 .42602 .46756 .42381 .46518 Metetra
.643 .725 .908 r
.42381 .46518 .42602 .46756 .42978 .46654 .42758 .46415 Metetra
.642 .725 .908 r
.42758 .46415 .42978 .46654 .43355 .46552 .43135 .46313 Metetra
.641 .724 .908 r
.43135 .46313 .43355 .46552 .43733 .46451 .43513 .46211 Metetra
.641 .723 .908 r
.43513 .46211 .43733 .46451 .44111 .46351 .43892 .4611 Metetra
.64 .723 .908 r
.43892 .4611 .44111 .46351 .44489 .46251 .44271 .4601 Metetra
.639 .722 .908 r
.44271 .4601 .44489 .46251 .44869 .46152 .4465 .4591 Metetra
.638 .721 .908 r
.4465 .4591 .44869 .46152 .45248 .46054 .4503 .45811 Metetra
.637 .721 .908 r
.4503 .45811 .45248 .46054 .45629 .45957 .45411 .45713 Metetra
.636 .72 .908 r
.45411 .45713 .45629 .45957 .4601 .4586 .45792 .45615 Metetra
.635 .719 .908 r
.45792 .45615 .4601 .4586 .46391 .45765 .46174 .45519 Metetra
.634 .718 .908 r
.46174 .45519 .46391 .45765 .46773 .4567 .46556 .45424 Metetra
.632 .717 .908 r
.46556 .45424 .46773 .4567 .47156 .45577 .46939 .45329 Metetra
.631 .716 .908 r
.46939 .45329 .47156 .45577 .47539 .45485 .47323 .45236 Metetra
.63 .715 .908 r
.47323 .45236 .47539 .45485 .47923 .45394 .47707 .45144 Metetra
.628 .713 .908 r
.47707 .45144 .47923 .45394 .48308 .45305 .48092 .45054 Metetra
.626 .712 .908 r
.48092 .45054 .48308 .45305 .48693 .45218 .48477 .44965 Metetra
.624 .71 .908 r
.48477 .44965 .48693 .45218 .49078 .45132 .48863 .44878 Metetra
.622 .709 .908 r
.48863 .44878 .49078 .45132 .49465 .45048 .4925 .44793 Metetra
.62 .707 .908 r
.4925 .44793 .49465 .45048 .49852 .44966 .49637 .44709 Metetra
.618 .705 .908 r
.49637 .44709 .49852 .44966 .50239 .44887 .50025 .44628 Metetra
.615 .703 .907 r
.50025 .44628 .50239 .44887 .50627 .4481 .50414 .4455 Metetra
.612 .701 .907 r
.50414 .4455 .50627 .4481 .51016 .44736 .50803 .44474 Metetra
.609 .698 .907 r
.50803 .44474 .51016 .44736 .51406 .44665 .51193 .44401 Metetra
.605 .695 .907 r
.51193 .44401 .51406 .44665 .51796 .44597 .51583 .44331 Metetra
.601 .692 .907 r
.51583 .44331 .51796 .44597 .52187 .44533 .51974 .44265 Metetra
.597 .689 .906 r
.51974 .44265 .52187 .44533 .52578 .44474 .52366 .44203 Metetra
.592 .685 .906 r
.52366 .44203 .52578 .44474 .52971 .4442 .52759 .44146 Metetra
.586 .68 .906 r
.52759 .44146 .52971 .4442 .53364 .44371 .53152 .44094 Metetra
.579 .675 .905 r
.53152 .44094 .53364 .44371 .53758 .44329 .53546 .44048 Metetra
.964 .681 .448 r
.53546 .44048 .53758 .44329 .54253 .64027 .54029 .63805 Metetra
.645 .763 .934 r
.54029 .63805 .54253 .64027 .54672 .63907 .54448 .63685 Metetra
.645 .763 .934 r
.54448 .63685 .54672 .63907 .55091 .63787 .54868 .63565 Metetra
.952 .738 .577 r
.54868 .63565 .55091 .63787 .55503 .62746 .55272 .61313 Metetra
.783 .569 .61 r
.55272 .61313 .55503 .62746 .55905 .60855 .55676 .59724 Metetra
.768 .571 .633 r
.55676 .59724 .55905 .60855 .56311 .59608 .56084 .58644 Metetra
.745 .568 .655 r
.56084 .58644 .56311 .59608 .56719 .58765 .56493 .57897 Metetra
.714 .558 .676 r
.56493 .57897 .56719 .58765 .5713 .58208 .56905 .57394 Metetra
.672 .539 .695 r
.56905 .57394 .5713 .58208 .57544 .57881 .57319 .5709 Metetra
.616 .509 .71 r
.57319 .5709 .57544 .57881 .57962 .57757 .57736 .56966 Metetra
.539 .462 .717 r
.57736 .56966 .57962 .57757 .58384 .57839 .58157 .57022 Metetra
.433 .39 .711 r
.58157 .57022 .58384 .57839 .58811 .58149 .58583 .57278 Metetra
.284 .283 .682 r
.58583 .57278 .58811 .58149 .59245 .58749 .59015 .5778 Metetra
.08 .129 .613 r
.59015 .5778 .59245 .58749 .59691 .59754 .59456 .58617 Metetra
0 0 .487 r
.59456 .58617 .59691 .59754 .60154 .61408 .59911 .59966 Metetra
0 0 .373 r
.59911 .59966 .60154 .61408 .60603 .62211 .60385 .61985 Metetra
.645 .763 .934 r
.60385 .61985 .60603 .62211 .61031 .62089 .60814 .61862 Metetra
.645 .763 .934 r
.60814 .61862 .61031 .62089 .6146 .61966 .61244 .61739 Metetra
.969 .694 .455 r
.61244 .61739 .6146 .61966 .61345 .41887 .6114 .41599 Metetra
.72 .725 .854 r
.6114 .41599 .61345 .41887 .61748 .41672 .61543 .41387 Metetra
.717 .726 .858 r
.61543 .41387 .61748 .41672 .62151 .41463 .61946 .4118 Metetra
.714 .728 .861 r
.61946 .4118 .62151 .41463 .62555 .41259 .62351 .40979 Metetra
.711 .729 .864 r
.62351 .40979 .62555 .41259 .62959 .4106 .62756 .40782 Metetra
.709 .729 .867 r
.62756 .40782 .62959 .4106 .63364 .40866 .63161 .4059 Metetra
.706 .73 .869 r
.63161 .4059 .63364 .40866 .6377 .40676 .63567 .40401 Metetra
.704 .731 .872 r
.63567 .40401 .6377 .40676 .64176 .40489 .63974 .40215 Metetra
.702 .732 .874 r
.63974 .40215 .64176 .40489 .64583 .40305 .64381 .40032 Metetra
.7 .732 .876 r
.64381 .40032 .64583 .40305 .6499 .40123 .64788 .39852 Metetra
.698 .733 .877 r
.64788 .39852 .6499 .40123 .65398 .39945 .65197 .39674 Metetra
.697 .733 .879 r
.65197 .39674 .65398 .39945 .65806 .39768 .65606 .39499 Metetra
.695 .734 .88 r
.65606 .39499 .65806 .39768 .66215 .39594 .66015 .39325 Metetra
.694 .734 .882 r
.66015 .39325 .66215 .39594 .66625 .39421 .66425 .39153 Metetra
.693 .734 .883 r
.66425 .39153 .66625 .39421 .67035 .39251 .66836 .38983 Metetra
.691 .735 .884 r
.66836 .38983 .67035 .39251 .67446 .39082 .67247 .38814 Metetra
.69 .735 .885 r
.67247 .38814 .67446 .39082 .67857 .38914 .67659 .38647 Metetra
.689 .735 .886 r
.67659 .38647 .67857 .38914 .68269 .38747 .68071 .38481 Metetra
.688 .736 .887 r
.68071 .38481 .68269 .38747 .68681 .38582 .68484 .38316 Metetra
.687 .736 .888 r
.68484 .38316 .68681 .38582 .69094 .38418 .68898 .38152 Metetra
.686 .736 .889 r
.68898 .38152 .69094 .38418 .69508 .38255 .69312 .37989 Metetra
.685 .736 .889 r
.69312 .37989 .69508 .38255 .69922 .38093 .69727 .37827 Metetra
.685 .736 .89 r
.69727 .37827 .69922 .38093 .70337 .37931 .70142 .37666 Metetra
.684 .737 .891 r
.70142 .37666 .70337 .37931 .70753 .37771 .70558 .37506 Metetra
.683 .737 .891 r
.70558 .37506 .70753 .37771 .71169 .37611 .70974 .37346 Metetra
.683 .737 .892 r
.70974 .37346 .71169 .37611 .71586 .37452 .71391 .37187 Metetra
.682 .737 .893 r
.71391 .37187 .71586 .37452 .72003 .37294 .71809 .37029 Metetra
.681 .737 .893 r
.71809 .37029 .72003 .37294 .72421 .37136 .72228 .36871 Metetra
.681 .737 .894 r
.72228 .36871 .72421 .37136 .72839 .36979 .72647 .36714 Metetra
.68 .738 .894 r
.72647 .36714 .72839 .36979 .73259 .36822 .73066 .36557 Metetra
.68 .738 .895 r
.73066 .36557 .73259 .36822 .73678 .36665 .73486 .36401 Metetra
.679 .738 .895 r
.73486 .36401 .73678 .36665 .74099 .36509 .73907 .36245 Metetra
.679 .738 .895 r
.73907 .36245 .74099 .36509 .7452 .36354 .74328 .36089 Metetra
.678 .738 .896 r
.74328 .36089 .7452 .36354 .74941 .36199 .7475 .35934 Metetra
.678 .738 .896 r
.7475 .35934 .74941 .36199 .75363 .36044 .75173 .35779 Metetra
.677 .738 .896 r
.75173 .35779 .75363 .36044 .75786 .35889 .75596 .35624 Metetra
.677 .738 .897 r
.75596 .35624 .75786 .35889 .7621 .35735 .7602 .3547 Metetra
.677 .738 .897 r
.7602 .3547 .7621 .35735 .76634 .35581 .76445 .35316 Metetra
.676 .738 .897 r
.76445 .35316 .76634 .35581 .77058 .35428 .7687 .35162 Metetra
.676 .739 .898 r
.7687 .35162 .77058 .35428 .77483 .35274 .77296 .35008 Metetra
.676 .739 .898 r
.77296 .35008 .77483 .35274 .77909 .35121 .77722 .34855 Metetra
.675 .739 .898 r
.77722 .34855 .77909 .35121 .78336 .34968 .78149 .34702 Metetra
.675 .739 .898 r
.78149 .34702 .78336 .34968 .78763 .34815 .78577 .34548 Metetra
.675 .739 .899 r
.78577 .34548 .78763 .34815 .79191 .34662 .79005 .34395 Metetra
.674 .739 .899 r
.79005 .34395 .79191 .34662 .79619 .34509 .79434 .34243 Metetra
.674 .739 .899 r
.79434 .34243 .79619 .34509 .80048 .34357 .79863 .3409 Metetra
.674 .739 .899 r
.79863 .3409 .80048 .34357 .80478 .34204 .80293 .33937 Metetra
.674 .739 .9 r
.80293 .33937 .80478 .34204 .80908 .34052 .80724 .33785 Metetra
.673 .739 .9 r
.80724 .33785 .80908 .34052 .81339 .33899 .81156 .33632 Metetra
.673 .739 .9 r
.81156 .33632 .81339 .33899 .81771 .33747 .81588 .3348 Metetra
.673 .739 .9 r
.81588 .3348 .81771 .33747 .82203 .33595 .8202 .33327 Metetra
.673 .739 .9 r
.8202 .33327 .82203 .33595 .82636 .33443 .82454 .33175 Metetra
.672 .739 .901 r
.82454 .33175 .82636 .33443 .83069 .33291 .82888 .33023 Metetra
.672 .739 .901 r
.82888 .33023 .83069 .33291 .83504 .33139 .83322 .3287 Metetra
.962 .774 .602 r
.83322 .3287 .83504 .33139 .83938 .32987 .83641 .31547 Metetra
.594 .437 .639 r
.83641 .31547 .83938 .32987 .84256 .31667 .84076 .31404 Metetra
.664 .741 .907 r
.84076 .31404 .84256 .31667 .84691 .31525 .84512 .31262 Metetra
.664 .741 .907 r
.84512 .31262 .84691 .31525 .85127 .31382 .84949 .31119 Metetra
.664 .741 .907 r
.84949 .31119 .85127 .31382 .85564 .3124 .85386 .30976 Metetra
.664 .741 .907 r
.85386 .30976 .85564 .3124 .86001 .31097 .85824 .30832 Metetra
.664 .741 .907 r
.85824 .30832 .86001 .31097 .86439 .30954 .86262 .30689 Metetra
.664 .741 .907 r
.86262 .30689 .86439 .30954 .86878 .3081 .86702 .30545 Metetra
.664 .741 .907 r
.86702 .30545 .86878 .3081 .87317 .30667 .87141 .30401 Metetra
.664 .741 .907 r
.87141 .30401 .87317 .30667 .87757 .30523 .87582 .30257 Metetra
.664 .741 .907 r
.87582 .30257 .87757 .30523 .88198 .30379 .88023 .30113 Metetra
.664 .741 .907 r
.88023 .30113 .88198 .30379 .88639 .30235 .88465 .29968 Metetra
.664 .741 .907 r
.29011 .49137 .29242 .49354 .296 .49237 .29368 .4902 Metetra
.664 .741 .907 r
.29368 .4902 .296 .49237 .29958 .49119 .29727 .48903 Metetra
.664 .741 .907 r
.29727 .48903 .29958 .49119 .30316 .49002 .30085 .48785 Metetra
.664 .741 .907 r
.30085 .48785 .30316 .49002 .30675 .48885 .30445 .48667 Metetra
.664 .741 .907 r
.30445 .48667 .30675 .48885 .31035 .48767 .30805 .48549 Metetra
.664 .741 .907 r
.30805 .48549 .31035 .48767 .31395 .48649 .31165 .48431 Metetra
.664 .741 .907 r
.31165 .48431 .31395 .48649 .31755 .48531 .31526 .48313 Metetra
.664 .741 .907 r
.31526 .48313 .31755 .48531 .32116 .48413 .31887 .48194 Metetra
.664 .741 .907 r
.31887 .48194 .32116 .48413 .32477 .48295 .32249 .48076 Metetra
.664 .741 .907 r
.32249 .48076 .32477 .48295 .32839 .48176 .32611 .47957 Metetra
.664 .741 .907 r
.32611 .47957 .32839 .48176 .33202 .48057 .32974 .47838 Metetra
.664 .741 .907 r
.32974 .47838 .33202 .48057 .335 .49074 .33337 .47719 Metetra
.594 .437 .638 r
.33337 .47719 .335 .49074 .33864 .48966 .33701 .476 Metetra
.048 .042 .526 r
.33701 .476 .33864 .48966 .34228 .48857 .34001 .48631 Metetra
.652 .732 .908 r
.34001 .48631 .34228 .48857 .34593 .48749 .34366 .48522 Metetra
.652 .732 .908 r
.34366 .48522 .34593 .48749 .34959 .48641 .34732 .48413 Metetra
.652 .732 .908 r
.34732 .48413 .34959 .48641 .35325 .48533 .35098 .48305 Metetra
.651 .732 .908 r
.35098 .48305 .35325 .48533 .35692 .48425 .35465 .48196 Metetra
.651 .732 .908 r
.35465 .48196 .35692 .48425 .36059 .48317 .35833 .48088 Metetra
.651 .731 .908 r
.35833 .48088 .36059 .48317 .36427 .4821 .36201 .4798 Metetra
.651 .731 .908 r
.36201 .4798 .36427 .4821 .36795 .48102 .36569 .47872 Metetra
.65 .731 .908 r
.36569 .47872 .36795 .48102 .37163 .47995 .36938 .47764 Metetra
.65 .731 .908 r
.36938 .47764 .37163 .47995 .37533 .47888 .37308 .47657 Metetra
.65 .73 .908 r
.37308 .47657 .37533 .47888 .37902 .47781 .37678 .47549 Metetra
.649 .73 .908 r
.37678 .47549 .37902 .47781 .38273 .47674 .38048 .47442 Metetra
.649 .73 .908 r
.38048 .47442 .38273 .47674 .38644 .47567 .38419 .47335 Metetra
.648 .729 .908 r
.38419 .47335 .38644 .47567 .39015 .47461 .38791 .47228 Metetra
.648 .729 .908 r
.38791 .47228 .39015 .47461 .39387 .47355 .39163 .47121 Metetra
.648 .729 .908 r
.39163 .47121 .39387 .47355 .39759 .47249 .39536 .47015 Metetra
.647 .728 .908 r
.39536 .47015 .39759 .47249 .40132 .47143 .39909 .46909 Metetra
.647 .728 .908 r
.39909 .46909 .40132 .47143 .40506 .47038 .40283 .46803 Metetra
.646 .728 .908 r
.40283 .46803 .40506 .47038 .4088 .46933 .40657 .46697 Metetra
.646 .727 .908 r
.40657 .46697 .4088 .46933 .41254 .46829 .41032 .46592 Metetra
.645 .727 .908 r
.41032 .46592 .41254 .46829 .41629 .46725 .41408 .46488 Metetra
.645 .726 .908 r
.41408 .46488 .41629 .46725 .42005 .46621 .41784 .46383 Metetra
.644 .726 .908 r
.41784 .46383 .42005 .46621 .42381 .46518 .4216 .46279 Metetra
.643 .725 .908 r
.4216 .46279 .42381 .46518 .42758 .46415 .42537 .46176 Metetra
.643 .725 .908 r
.42537 .46176 .42758 .46415 .43135 .46313 .42915 .46073 Metetra
.642 .724 .908 r
.42915 .46073 .43135 .46313 .43513 .46211 .43293 .45971 Metetra
.641 .724 .908 r
.43293 .45971 .43513 .46211 .43892 .4611 .43672 .45869 Metetra
.64 .723 .908 r
.43672 .45869 .43892 .4611 .44271 .4601 .44051 .45767 Metetra
.639 .722 .908 r
.44051 .45767 .44271 .4601 .4465 .4591 .44431 .45667 Metetra
.639 .722 .908 r
.44431 .45667 .4465 .4591 .4503 .45811 .44811 .45567 Metetra
.638 .721 .908 r
.44811 .45567 .4503 .45811 .45411 .45713 .45192 .45468 Metetra
.637 .72 .908 r
.45192 .45468 .45411 .45713 .45792 .45615 .45574 .4537 Metetra
.636 .719 .908 r
.45574 .4537 .45792 .45615 .46174 .45519 .45956 .45273 Metetra
.634 .718 .908 r
.45956 .45273 .46174 .45519 .46556 .45424 .46339 .45176 Metetra
.633 .717 .908 r
.46339 .45176 .46556 .45424 .46939 .45329 .46722 .45081 Metetra
.632 .716 .908 r
.46722 .45081 .46939 .45329 .47323 .45236 .47106 .44987 Metetra
.63 .715 .908 r
.47106 .44987 .47323 .45236 .47707 .45144 .47491 .44894 Metetra
.629 .714 .908 r
.47491 .44894 .47707 .45144 .48092 .45054 .47876 .44802 Metetra
.627 .713 .908 r
.47876 .44802 .48092 .45054 .48477 .44965 .48261 .44712 Metetra
.625 .711 .908 r
.48261 .44712 .48477 .44965 .48863 .44878 .48648 .44624 Metetra
.623 .71 .908 r
.48648 .44624 .48863 .44878 .4925 .44793 .49035 .44537 Metetra
.621 .708 .908 r
.49035 .44537 .4925 .44793 .49637 .44709 .49422 .44453 Metetra
.619 .706 .907 r
.49422 .44453 .49637 .44709 .50025 .44628 .4981 .4437 Metetra
.616 .704 .907 r
.4981 .4437 .50025 .44628 .50414 .4455 .50199 .44289 Metetra
.614 .702 .907 r
.50199 .44289 .50414 .4455 .50803 .44474 .50589 .44212 Metetra
.61 .699 .907 r
.50589 .44212 .50803 .44474 .51193 .44401 .50979 .44137 Metetra
.607 .697 .907 r
.50979 .44137 .51193 .44401 .51583 .44331 .5137 .44065 Metetra
.603 .694 .907 r
.5137 .44065 .51583 .44331 .51974 .44265 .51761 .43997 Metetra
.599 .69 .906 r
.51761 .43997 .51974 .44265 .52366 .44203 .52153 .43932 Metetra
.594 .686 .906 r
.52153 .43932 .52366 .44203 .52759 .44146 .52546 .43872 Metetra
.589 .682 .906 r
.52546 .43872 .52759 .44146 .53152 .44094 .5294 .43817 Metetra
.964 .681 .45 r
.5294 .43817 .53152 .44094 .53546 .44048 .53386 .63704 Metetra
.551 .331 .535 r
.53386 .63704 .53546 .44048 .54029 .63805 .53805 .63584 Metetra
.645 .763 .934 r
.53805 .63584 .54029 .63805 .54448 .63685 .54224 .63463 Metetra
.937 .758 .634 r
.54224 .63463 .54448 .63685 .54868 .63565 .54637 .62071 Metetra
.806 .583 .599 r
.54637 .62071 .54868 .63565 .55272 .61313 .55042 .60041 Metetra
.78 .572 .619 r
.55042 .60041 .55272 .61313 .55676 .59724 .55449 .58687 Metetra
.763 .574 .642 r
.55449 .58687 .55676 .59724 .56084 .58644 .55858 .57741 Metetra
.74 .571 .664 r
.55858 .57741 .56084 .58644 .56493 .57897 .56268 .57074 Metetra
.71 .561 .684 r
.56268 .57074 .56493 .57897 .56905 .57394 .5668 .56617 Metetra
.67 .543 .702 r
.5668 .56617 .56905 .57394 .57319 .5709 .57095 .56334 Metetra
.617 .516 .716 r
.57095 .56334 .57319 .5709 .57736 .56966 .57512 .56209 Metetra
.548 .473 .723 r
.57512 .56209 .57736 .56966 .58157 .57022 .57932 .56244 Metetra
.454 .41 .72 r
.57932 .56244 .58157 .57022 .58583 .57278 .58356 .56453 Metetra
.324 .318 .698 r
.58356 .56453 .58583 .57278 .59015 .5778 .58786 .56873 Metetra
.147 .185 .644 r
.58786 .56873 .59015 .5778 .59456 .58617 .59223 .57574 Metetra
0 .006 .542 r
.59223 .57574 .59456 .58617 .59911 .59966 .59671 .58686 Metetra
0 0 .385 r
.59671 .58686 .59911 .59966 .60385 .61985 .60139 .60479 Metetra
.156 .132 .577 r
.60139 .60479 .60385 .61985 .60814 .61862 .60597 .61635 Metetra
.645 .763 .934 r
.60597 .61635 .60814 .61862 .61244 .61739 .61027 .61511 Metetra
.645 .763 .934 r
.61027 .61511 .61244 .61739 .6114 .41599 .61458 .61388 Metetra
0 0 .382 r
.61458 .61388 .6114 .41599 .61543 .41387 .61337 .41103 Metetra
.715 .727 .859 r
.61337 .41103 .61543 .41387 .61946 .4118 .61741 .40898 Metetra
.712 .728 .862 r
.61741 .40898 .61946 .4118 .62351 .40979 .62146 .40699 Metetra
.71 .729 .865 r
.62146 .40699 .62351 .40979 .62756 .40782 .62552 .40504 Metetra
.707 .73 .868 r
.62552 .40504 .62756 .40782 .63161 .4059 .62957 .40313 Metetra
.705 .73 .87 r
.62957 .40313 .63161 .4059 .63567 .40401 .63364 .40126 Metetra
.703 .731 .873 r
.63364 .40126 .63567 .40401 .63974 .40215 .63771 .39941 Metetra
.701 .732 .874 r
.63771 .39941 .63974 .40215 .64381 .40032 .64178 .3976 Metetra
.699 .732 .876 r
.64178 .3976 .64381 .40032 .64788 .39852 .64587 .39581 Metetra
.698 .733 .878 r
.64587 .39581 .64788 .39852 .65197 .39674 .64995 .39404 Metetra
.696 .733 .879 r
.64995 .39404 .65197 .39674 .65606 .39499 .65405 .39229 Metetra
.695 .734 .881 r
.65405 .39229 .65606 .39499 .66015 .39325 .65815 .39056 Metetra
.693 .734 .882 r
.65815 .39056 .66015 .39325 .66425 .39153 .66225 .38885 Metetra
.692 .734 .883 r
.66225 .38885 .66425 .39153 .66836 .38983 .66636 .38715 Metetra
.691 .735 .884 r
.66636 .38715 .66836 .38983 .67247 .38814 .67048 .38547 Metetra
.69 .735 .885 r
.67048 .38547 .67247 .38814 .67659 .38647 .6746 .3838 Metetra
.689 .735 .886 r
.6746 .3838 .67659 .38647 .68071 .38481 .67873 .38214 Metetra
.688 .736 .887 r
.67873 .38214 .68071 .38481 .68484 .38316 .68286 .3805 Metetra
.687 .736 .888 r
.68286 .3805 .68484 .38316 .68898 .38152 .687 .37886 Metetra
.686 .736 .889 r
.687 .37886 .68898 .38152 .69312 .37989 .69115 .37723 Metetra
.685 .736 .89 r
.69115 .37723 .69312 .37989 .69727 .37827 .6953 .37562 Metetra
.684 .736 .89 r
.6953 .37562 .69727 .37827 .70142 .37666 .69946 .37401 Metetra
.683 .737 .891 r
.69946 .37401 .70142 .37666 .70558 .37506 .70362 .3724 Metetra
.683 .737 .892 r
.70362 .3724 .70558 .37506 .70974 .37346 .70779 .37081 Metetra
.682 .737 .892 r
.70779 .37081 .70974 .37346 .71391 .37187 .71197 .36922 Metetra
.682 .737 .893 r
.71197 .36922 .71391 .37187 .71809 .37029 .71615 .36764 Metetra
.681 .737 .893 r
.71615 .36764 .71809 .37029 .72228 .36871 .72034 .36606 Metetra
.68 .737 .894 r
.72034 .36606 .72228 .36871 .72647 .36714 .72453 .36449 Metetra
.68 .738 .894 r
.72453 .36449 .72647 .36714 .73066 .36557 .72873 .36292 Metetra
.679 .738 .895 r
.72873 .36292 .73066 .36557 .73486 .36401 .73294 .36135 Metetra
.679 .738 .895 r
.73294 .36135 .73486 .36401 .73907 .36245 .73715 .35979 Metetra
.678 .738 .896 r
.73715 .35979 .73907 .36245 .74328 .36089 .74137 .35824 Metetra
.678 .738 .896 r
.74137 .35824 .74328 .36089 .7475 .35934 .74559 .35668 Metetra
.678 .738 .896 r
.74559 .35668 .7475 .35934 .75173 .35779 .74982 .35513 Metetra
.677 .738 .897 r
.74982 .35513 .75173 .35779 .75596 .35624 .75406 .35359 Metetra
.677 .738 .897 r
.75406 .35359 .75596 .35624 .7602 .3547 .7583 .35204 Metetra
.676 .738 .897 r
.7583 .35204 .7602 .3547 .76445 .35316 .76255 .3505 Metetra
.676 .738 .898 r
.76255 .3505 .76445 .35316 .7687 .35162 .76681 .34896 Metetra
.676 .738 .898 r
.76681 .34896 .7687 .35162 .77296 .35008 .77107 .34742 Metetra
.675 .739 .898 r
.77107 .34742 .77296 .35008 .77722 .34855 .77534 .34588 Metetra
.675 .739 .898 r
.77534 .34588 .77722 .34855 .78149 .34702 .77961 .34435 Metetra
.675 .739 .899 r
.77961 .34435 .78149 .34702 .78577 .34548 .7839 .34282 Metetra
.674 .739 .899 r
.7839 .34282 .78577 .34548 .79005 .34395 .78818 .34128 Metetra
.674 .739 .899 r
.78818 .34128 .79005 .34395 .79434 .34243 .79248 .33975 Metetra
.674 .739 .899 r
.79248 .33975 .79434 .34243 .79863 .3409 .79678 .33822 Metetra
.674 .739 .9 r
.79678 .33822 .79863 .3409 .80293 .33937 .80108 .3367 Metetra
.673 .739 .9 r
.80108 .3367 .80293 .33937 .80724 .33785 .80539 .33517 Metetra
.673 .739 .9 r
.80539 .33517 .80724 .33785 .81156 .33632 .80971 .33364 Metetra
.673 .739 .9 r
.80971 .33364 .81156 .33632 .81588 .3348 .81404 .33211 Metetra
.673 .739 .9 r
.81404 .33211 .81588 .3348 .8202 .33327 .81837 .33059 Metetra
.673 .739 .9 r
.81837 .33059 .8202 .33327 .82454 .33175 .82271 .32906 Metetra
.962 .772 .602 r
.82271 .32906 .82454 .33175 .82888 .33023 .82592 .31569 Metetra
.594 .436 .637 r
.82592 .31569 .82888 .33023 .83322 .3287 .83026 .31426 Metetra
.594 .437 .638 r
.83026 .31426 .83322 .3287 .83641 .31547 .83461 .31284 Metetra
.664 .741 .907 r
.83461 .31284 .83641 .31547 .84076 .31404 .83897 .31141 Metetra
.664 .741 .907 r
.83897 .31141 .84076 .31404 .84512 .31262 .84333 .30998 Metetra
.664 .741 .907 r
.84333 .30998 .84512 .31262 .84949 .31119 .8477 .30854 Metetra
.664 .741 .907 r
.8477 .30854 .84949 .31119 .85386 .30976 .85208 .30711 Metetra
.664 .741 .907 r
.85208 .30711 .85386 .30976 .85824 .30832 .85646 .30567 Metetra
.664 .741 .907 r
.85646 .30567 .85824 .30832 .86262 .30689 .86085 .30423 Metetra
.664 .741 .907 r
.86085 .30423 .86262 .30689 .86702 .30545 .86525 .30279 Metetra
.664 .741 .907 r
.86525 .30279 .86702 .30545 .87141 .30401 .86965 .30135 Metetra
.664 .741 .907 r
.86965 .30135 .87141 .30401 .87582 .30257 .87406 .2999 Metetra
.664 .741 .907 r
.87406 .2999 .87582 .30257 .88023 .30113 .87848 .29845 Metetra
.664 .741 .907 r
.87848 .29845 .88023 .30113 .88465 .29968 .8829 .297 Metetra
.664 .741 .907 r
.28778 .48921 .29011 .49137 .29368 .4902 .29137 .48803 Metetra
.664 .741 .907 r
.29137 .48803 .29368 .4902 .29727 .48903 .29495 .48685 Metetra
.664 .741 .907 r
.29495 .48685 .29727 .48903 .30085 .48785 .29854 .48567 Metetra
.664 .741 .907 r
.29854 .48567 .30085 .48785 .30445 .48667 .30214 .48449 Metetra
.664 .741 .907 r
.30214 .48449 .30445 .48667 .30805 .48549 .30574 .48331 Metetra
.664 .741 .907 r
.30574 .48331 .30805 .48549 .31165 .48431 .30935 .48213 Metetra
.664 .741 .907 r
.30935 .48213 .31165 .48431 .31526 .48313 .31296 .48094 Metetra
.664 .741 .907 r
.31296 .48094 .31526 .48313 .31887 .48194 .31657 .47975 Metetra
.664 .741 .907 r
.31657 .47975 .31887 .48194 .32249 .48076 .32019 .47856 Metetra
.664 .741 .907 r
.32019 .47856 .32249 .48076 .32611 .47957 .32382 .47737 Metetra
.664 .741 .907 r
.32382 .47737 .32611 .47957 .32974 .47838 .32745 .47618 Metetra
.664 .741 .907 r
.32745 .47618 .32974 .47838 .33337 .47719 .33108 .47499 Metetra
.664 .741 .907 r
.33108 .47499 .33337 .47719 .33701 .476 .33472 .47379 Metetra
.664 .741 .907 r
.33472 .47379 .33701 .476 .34001 .48631 .33837 .47259 Metetra
.048 .041 .526 r
.33837 .47259 .34001 .48631 .34366 .48522 .34138 .48294 Metetra
.652 .732 .908 r
.34138 .48294 .34366 .48522 .34732 .48413 .34504 .48185 Metetra
.652 .732 .908 r
.34504 .48185 .34732 .48413 .35098 .48305 .34871 .48076 Metetra
.652 .732 .908 r
.34871 .48076 .35098 .48305 .35465 .48196 .35238 .47967 Metetra
.651 .732 .908 r
.35238 .47967 .35465 .48196 .35833 .48088 .35606 .47859 Metetra
.651 .731 .908 r
.35606 .47859 .35833 .48088 .36201 .4798 .35974 .4775 Metetra
.651 .731 .908 r
.35974 .4775 .36201 .4798 .36569 .47872 .36343 .47641 Metetra
.65 .731 .908 r
.36343 .47641 .36569 .47872 .36938 .47764 .36712 .47533 Metetra
.65 .731 .908 r
.36712 .47533 .36938 .47764 .37308 .47657 .37082 .47425 Metetra
.65 .73 .908 r
.37082 .47425 .37308 .47657 .37678 .47549 .37452 .47317 Metetra
.649 .73 .908 r
.37452 .47317 .37678 .47549 .38048 .47442 .37823 .47209 Metetra
.649 .73 .908 r
.37823 .47209 .38048 .47442 .38419 .47335 .38195 .47102 Metetra
.649 .73 .908 r
.38195 .47102 .38419 .47335 .38791 .47228 .38567 .46994 Metetra
.648 .729 .908 r
.38567 .46994 .38791 .47228 .39163 .47121 .38939 .46887 Metetra
.648 .729 .908 r
.38939 .46887 .39163 .47121 .39536 .47015 .39312 .4678 Metetra
.647 .729 .908 r
.39312 .4678 .39536 .47015 .39909 .46909 .39686 .46673 Metetra
.647 .728 .908 r
.39686 .46673 .39909 .46909 .40283 .46803 .4006 .46567 Metetra
.646 .728 .908 r
.4006 .46567 .40283 .46803 .40657 .46697 .40435 .46461 Metetra
.646 .727 .908 r
.40435 .46461 .40657 .46697 .41032 .46592 .4081 .46355 Metetra
.645 .727 .908 r
.4081 .46355 .41032 .46592 .41408 .46488 .41185 .4625 Metetra
.645 .727 .908 r
.41185 .4625 .41408 .46488 .41784 .46383 .41562 .46145 Metetra
.644 .726 .908 r
.41562 .46145 .41784 .46383 .4216 .46279 .41939 .4604 Metetra
.644 .726 .908 r
.41939 .4604 .4216 .46279 .42537 .46176 .42316 .45936 Metetra
.643 .725 .908 r
.42316 .45936 .42537 .46176 .42915 .46073 .42694 .45833 Metetra
.642 .725 .908 r
.42694 .45833 .42915 .46073 .43293 .45971 .43072 .4573 Metetra
.642 .724 .908 r
.43072 .4573 .43293 .45971 .43672 .45869 .43451 .45627 Metetra
.641 .723 .908 r
.43451 .45627 .43672 .45869 .44051 .45767 .43831 .45525 Metetra
.64 .723 .908 r
.43831 .45525 .44051 .45767 .44431 .45667 .44211 .45424 Metetra
.639 .722 .908 r
.44211 .45424 .44431 .45667 .44811 .45567 .44592 .45323 Metetra
.638 .721 .908 r
.44592 .45323 .44811 .45567 .45192 .45468 .44973 .45223 Metetra
.637 .72 .908 r
.44973 .45223 .45192 .45468 .45574 .4537 .45355 .45124 Metetra
.636 .72 .908 r
.45355 .45124 .45574 .4537 .45956 .45273 .45738 .45026 Metetra
.635 .719 .908 r
.45738 .45026 .45956 .45273 .46339 .45176 .46121 .44929 Metetra
.634 .718 .908 r
.46121 .44929 .46339 .45176 .46722 .45081 .46504 .44832 Metetra
.633 .717 .908 r
.46504 .44832 .46722 .45081 .47106 .44987 .46889 .44737 Metetra
.631 .716 .908 r
.46889 .44737 .47106 .44987 .47491 .44894 .47273 .44643 Metetra
.63 .714 .908 r
.47273 .44643 .47491 .44894 .47876 .44802 .47659 .44551 Metetra
.628 .713 .908 r
.47659 .44551 .47876 .44802 .48261 .44712 .48045 .44459 Metetra
.626 .712 .908 r
.48045 .44459 .48261 .44712 .48648 .44624 .48432 .4437 Metetra
.624 .71 .908 r
.48432 .4437 .48648 .44624 .49035 .44537 .48819 .44282 Metetra
.622 .709 .907 r
.48819 .44282 .49035 .44537 .49422 .44453 .49207 .44195 Metetra
.62 .707 .907 r
.49207 .44195 .49422 .44453 .4981 .4437 .49595 .44111 Metetra
.618 .705 .907 r
.49595 .44111 .4981 .4437 .50199 .44289 .49984 .44029 Metetra
.615 .703 .907 r
.49984 .44029 .50199 .44289 .50589 .44212 .50374 .4395 Metetra
.612 .7 .907 r
.50374 .4395 .50589 .44212 .50979 .44137 .50764 .43873 Metetra
.609 .698 .907 r
.50764 .43873 .50979 .44137 .5137 .44065 .51155 .43799 Metetra
.605 .695 .907 r
.51155 .43799 .5137 .44065 .51761 .43997 .51547 .43728 Metetra
.601 .692 .906 r
.51547 .43728 .51761 .43997 .52153 .43932 .5194 .43661 Metetra
.597 .688 .906 r
.5194 .43661 .52153 .43932 .52546 .43872 .52333 .43599 Metetra
.592 .684 .906 r
.52333 .43599 .52546 .43872 .5294 .43817 .52727 .43541 Metetra
.964 .681 .45 r
.52727 .43541 .5294 .43817 .53386 .63704 .5316 .63482 Metetra
.645 .763 .934 r
.5316 .63482 .53386 .63704 .53805 .63584 .5358 .63361 Metetra
.657 .766 .93 r
.5358 .63361 .53805 .63584 .54224 .63463 .54 .6323 Metetra
.953 .731 .564 r
.54 .6323 .54224 .63463 .54637 .62071 .54406 .6059 Metetra
.787 .57 .606 r
.54406 .6059 .54637 .62071 .55042 .60041 .54814 .58897 Metetra
.775 .575 .629 r
.54814 .58897 .55042 .60041 .55449 .58687 .55222 .57728 Metetra
.758 .577 .651 r
.55222 .57728 .55449 .58687 .55858 .57741 .55632 .56893 Metetra
.735 .573 .672 r
.55632 .56893 .55858 .57741 .56268 .57074 .56043 .56292 Metetra
.706 .564 .692 r
.56043 .56292 .56268 .57074 .5668 .56617 .56456 .55873 Metetra
.668 .548 .709 r
.56456 .55873 .5668 .56617 .57095 .56334 .5687 .55608 Metetra
.619 .522 .722 r
.5687 .55608 .57095 .56334 .57512 .56209 .57287 .55483 Metetra
.556 .484 .73 r
.57287 .55483 .57512 .56209 .57932 .56244 .57707 .55499 Metetra
.472 .428 .728 r
.57707 .55499 .57932 .56244 .58356 .56453 .5813 .55668 Metetra
.358 .348 .711 r
.5813 .55668 .58356 .56453 .58786 .56873 .58558 .5602 Metetra
.204 .233 .669 r
.58558 .5602 .58786 .56873 .59223 .57574 .58992 .56609 Metetra
.003 .076 .588 r
.58992 .56609 .59223 .57574 .59671 .58686 .59435 .57534 Metetra
0 0 .455 r
.59435 .57534 .59671 .58686 .60139 .60479 .59894 .58987 Metetra
0 0 .278 r
.59894 .58987 .60139 .60479 .60597 .61635 .60378 .61396 Metetra
.635 .749 .931 r
.60378 .61396 .60597 .61635 .61027 .61511 .60809 .61283 Metetra
.645 .763 .934 r
.60809 .61283 .61027 .61511 .61458 .61388 .6124 .61159 Metetra
.97 .694 .453 r
.6124 .61159 .61458 .61388 .61337 .41103 .61131 .40819 Metetra
.714 .727 .861 r
.61131 .40819 .61337 .41103 .61741 .40898 .61536 .40617 Metetra
.711 .728 .864 r
.61536 .40617 .61741 .40898 .62146 .40699 .61941 .4042 Metetra
.708 .729 .867 r
.61941 .4042 .62146 .40699 .62552 .40504 .62347 .40226 Metetra
.706 .73 .869 r
.62347 .40226 .62552 .40504 .62957 .40313 .62753 .40037 Metetra
.704 .731 .871 r
.62753 .40037 .62957 .40313 .63364 .40126 .6316 .39851 Metetra
.702 .731 .873 r
.6316 .39851 .63364 .40126 .63771 .39941 .63568 .39668 Metetra
.7 .732 .875 r
.63568 .39668 .63771 .39941 .64178 .3976 .63976 .39487 Metetra
.698 .732 .877 r
.63976 .39487 .64178 .3976 .64587 .39581 .64384 .39309 Metetra
.697 .733 .879 r
.64384 .39309 .64587 .39581 .64995 .39404 .64794 .39133 Metetra
.695 .733 .88 r
.64794 .39133 .64995 .39404 .65405 .39229 .65203 .38959 Metetra
.694 .734 .881 r
.65203 .38959 .65405 .39229 .65815 .39056 .65614 .38786 Metetra
.692 .734 .883 r
.65614 .38786 .65815 .39056 .66225 .38885 .66025 .38616 Metetra
.691 .734 .884 r
.66025 .38616 .66225 .38885 .66636 .38715 .66436 .38447 Metetra
.69 .735 .885 r
.66436 .38447 .66636 .38715 .67048 .38547 .66848 .38279 Metetra
.689 .735 .886 r
.66848 .38279 .67048 .38547 .6746 .3838 .67261 .38112 Metetra
.688 .735 .887 r
.67261 .38112 .6746 .3838 .67873 .38214 .67674 .37947 Metetra
.687 .736 .888 r
.67674 .37947 .67873 .38214 .68286 .3805 .68088 .37783 Metetra
.686 .736 .889 r
.68088 .37783 .68286 .3805 .687 .37886 .68502 .37619 Metetra
.685 .736 .889 r
.68502 .37619 .687 .37886 .69115 .37723 .68917 .37457 Metetra
.685 .736 .89 r
.68917 .37457 .69115 .37723 .6953 .37562 .69333 .37295 Metetra
.684 .736 .891 r
.69333 .37295 .6953 .37562 .69946 .37401 .69749 .37135 Metetra
.683 .737 .891 r
.69749 .37135 .69946 .37401 .70362 .3724 .70166 .36974 Metetra
.682 .737 .892 r
.70166 .36974 .70362 .3724 .70779 .37081 .70584 .36815 Metetra
.682 .737 .892 r
.70584 .36815 .70779 .37081 .71197 .36922 .71002 .36656 Metetra
.681 .737 .893 r
.71002 .36656 .71197 .36922 .71615 .36764 .7142 .36498 Metetra
.681 .737 .894 r
.7142 .36498 .71615 .36764 .72034 .36606 .71839 .3634 Metetra
.68 .737 .894 r
.71839 .3634 .72034 .36606 .72453 .36449 .72259 .36183 Metetra
.68 .738 .894 r
.72259 .36183 .72453 .36449 .72873 .36292 .7268 .36026 Metetra
.679 .738 .895 r
.7268 .36026 .72873 .36292 .73294 .36135 .73101 .35869 Metetra
.679 .738 .895 r
.73101 .35869 .73294 .36135 .73715 .35979 .73523 .35713 Metetra
.678 .738 .896 r
.73523 .35713 .73715 .35979 .74137 .35824 .73945 .35558 Metetra
.678 .738 .896 r
.73945 .35558 .74137 .35824 .74559 .35668 .74368 .35402 Metetra
.677 .738 .896 r
.74368 .35402 .74559 .35668 .74982 .35513 .74791 .35247 Metetra
.677 .738 .897 r
.74791 .35247 .74982 .35513 .75406 .35359 .75215 .35092 Metetra
.677 .738 .897 r
.75215 .35092 .75406 .35359 .7583 .35204 .7564 .34938 Metetra
.676 .738 .897 r
.7564 .34938 .7583 .35204 .76255 .3505 .76066 .34783 Metetra
.676 .738 .898 r
.76066 .34783 .76255 .3505 .76681 .34896 .76492 .34629 Metetra
.675 .738 .898 r
.76492 .34629 .76681 .34896 .77107 .34742 .76918 .34475 Metetra
.675 .739 .898 r
.76918 .34475 .77107 .34742 .77534 .34588 .77346 .34321 Metetra
.675 .739 .898 r
.77346 .34321 .77534 .34588 .77961 .34435 .77774 .34168 Metetra
.675 .739 .899 r
.77774 .34168 .77961 .34435 .7839 .34282 .78202 .34014 Metetra
.674 .739 .899 r
.78202 .34014 .7839 .34282 .78818 .34128 .78631 .33861 Metetra
.674 .739 .899 r
.78631 .33861 .78818 .34128 .79248 .33975 .79061 .33708 Metetra
.674 .739 .899 r
.79061 .33708 .79248 .33975 .79678 .33822 .79491 .33554 Metetra
.674 .739 .9 r
.79491 .33554 .79678 .33822 .80108 .3367 .79923 .33401 Metetra
.673 .739 .9 r
.79923 .33401 .80108 .3367 .80539 .33517 .80354 .33248 Metetra
.673 .739 .9 r
.80354 .33248 .80539 .33517 .80971 .33364 .80787 .33095 Metetra
.673 .739 .9 r
.80787 .33095 .80971 .33364 .81404 .33211 .8122 .32942 Metetra
.673 .739 .9 r
.8122 .32942 .81404 .33211 .81837 .33059 .81653 .32789 Metetra
.961 .772 .602 r
.81653 .32789 .81837 .33059 .82271 .32906 .81976 .31448 Metetra
.593 .436 .637 r
.81976 .31448 .82271 .32906 .82592 .31569 .8241 .31306 Metetra
.664 .741 .907 r
.8241 .31306 .82592 .31569 .83026 .31426 .82845 .31163 Metetra
.664 .741 .907 r
.82845 .31163 .83026 .31426 .83461 .31284 .8328 .3102 Metetra
.664 .741 .907 r
.8328 .3102 .83461 .31284 .83897 .31141 .83717 .30877 Metetra
.664 .741 .907 r
.83717 .30877 .83897 .31141 .84333 .30998 .84153 .30733 Metetra
.664 .741 .907 r
.84153 .30733 .84333 .30998 .8477 .30854 .84591 .30589 Metetra
.664 .741 .907 r
.84591 .30589 .8477 .30854 .85208 .30711 .85029 .30445 Metetra
.664 .741 .907 r
.85029 .30445 .85208 .30711 .85646 .30567 .85468 .30301 Metetra
.664 .741 .907 r
.85468 .30301 .85646 .30567 .86085 .30423 .85907 .30157 Metetra
.664 .741 .907 r
.85907 .30157 .86085 .30423 .86525 .30279 .86347 .30012 Metetra
.664 .741 .907 r
.86347 .30012 .86525 .30279 .86965 .30135 .86788 .29868 Metetra
.664 .741 .907 r
.86788 .29868 .86965 .30135 .87406 .2999 .8723 .29723 Metetra
.664 .741 .907 r
.8723 .29723 .87406 .2999 .87848 .29845 .87672 .29577 Metetra
.664 .741 .907 r
.87672 .29577 .87848 .29845 .8829 .297 .88115 .29432 Metetra
.664 .741 .907 r
.28546 .48703 .28778 .48921 .29137 .48803 .28904 .48585 Metetra
.664 .741 .907 r
.28904 .48585 .29137 .48803 .29495 .48685 .29263 .48467 Metetra
.664 .741 .907 r
.29263 .48467 .29495 .48685 .29854 .48567 .29623 .48349 Metetra
.664 .741 .907 r
.29623 .48349 .29854 .48567 .30214 .48449 .29982 .48231 Metetra
.664 .741 .907 r
.29982 .48231 .30214 .48449 .30574 .48331 .30343 .48112 Metetra
.664 .741 .907 r
.30343 .48112 .30574 .48331 .30935 .48213 .30704 .47993 Metetra
.664 .741 .907 r
.30704 .47993 .30935 .48213 .31296 .48094 .31065 .47875 Metetra
.664 .741 .907 r
.31065 .47875 .31296 .48094 .31657 .47975 .31427 .47756 Metetra
.664 .741 .907 r
.31427 .47756 .31657 .47975 .32019 .47856 .31789 .47636 Metetra
.664 .741 .907 r
.31789 .47636 .32019 .47856 .32382 .47737 .32152 .47517 Metetra
.664 .741 .907 r
.32152 .47517 .32382 .47737 .32745 .47618 .32515 .47397 Metetra
.664 .741 .907 r
.32515 .47397 .32745 .47618 .33108 .47499 .32879 .47278 Metetra
.664 .741 .907 r
.32879 .47278 .33108 .47499 .33472 .47379 .33244 .47158 Metetra
.664 .741 .907 r
.33244 .47158 .33472 .47379 .33837 .47259 .33608 .47038 Metetra
.664 .741 .907 r
.33608 .47038 .33837 .47259 .34138 .48294 .33974 .46918 Metetra
.047 .04 .525 r
.33974 .46918 .34138 .48294 .34504 .48185 .34276 .47956 Metetra
.652 .732 .908 r
.34276 .47956 .34504 .48185 .34871 .48076 .34643 .47847 Metetra
.652 .732 .908 r
.34643 .47847 .34871 .48076 .35238 .47967 .3501 .47738 Metetra
.651 .732 .908 r
.3501 .47738 .35238 .47967 .35606 .47859 .35378 .47628 Metetra
.651 .732 .908 r
.35378 .47628 .35606 .47859 .35974 .4775 .35747 .47519 Metetra
.651 .731 .908 r
.35747 .47519 .35974 .4775 .36343 .47641 .36116 .4741 Metetra
.651 .731 .908 r
.36116 .4741 .36343 .47641 .36712 .47533 .36486 .47302 Metetra
.65 .731 .908 r
.36486 .47302 .36712 .47533 .37082 .47425 .36856 .47193 Metetra
.65 .731 .908 r
.36856 .47193 .37082 .47425 .37452 .47317 .37227 .47084 Metetra
.65 .73 .908 r
.37227 .47084 .37452 .47317 .37823 .47209 .37598 .46976 Metetra
.649 .73 .908 r
.37598 .46976 .37823 .47209 .38195 .47102 .37969 .46868 Metetra
.649 .73 .908 r
.37969 .46868 .38195 .47102 .38567 .46994 .38342 .4676 Metetra
.648 .729 .908 r
.38342 .4676 .38567 .46994 .38939 .46887 .38715 .46652 Metetra
.648 .729 .908 r
.38715 .46652 .38939 .46887 .39312 .4678 .39088 .46545 Metetra
.648 .729 .908 r
.39088 .46545 .39312 .4678 .39686 .46673 .39462 .46438 Metetra
.647 .728 .908 r
.39462 .46438 .39686 .46673 .4006 .46567 .39836 .46331 Metetra
.647 .728 .908 r
.39836 .46331 .4006 .46567 .40435 .46461 .40211 .46224 Metetra
.646 .728 .908 r
.40211 .46224 .40435 .46461 .4081 .46355 .40587 .46118 Metetra
.646 .727 .908 r
.40587 .46118 .4081 .46355 .41185 .4625 .40963 .46012 Metetra
.645 .727 .908 r
.40963 .46012 .41185 .4625 .41562 .46145 .41339 .45906 Metetra
.645 .726 .908 r
.41339 .45906 .41562 .46145 .41939 .4604 .41716 .45801 Metetra
.644 .726 .908 r
.41716 .45801 .41939 .4604 .42316 .45936 .42094 .45696 Metetra
.643 .725 .908 r
.42094 .45696 .42316 .45936 .42694 .45833 .42472 .45592 Metetra
.643 .725 .908 r
.42472 .45592 .42694 .45833 .43072 .4573 .42851 .45488 Metetra
.642 .724 .908 r
.42851 .45488 .43072 .4573 .43451 .45627 .43231 .45385 Metetra
.641 .724 .908 r
.43231 .45385 .43451 .45627 .43831 .45525 .43611 .45282 Metetra
.64 .723 .908 r
.43611 .45282 .43831 .45525 .44211 .45424 .43991 .4518 Metetra
.64 .722 .908 r
.43991 .4518 .44211 .45424 .44592 .45323 .44372 .45079 Metetra
.639 .722 .908 r
.44372 .45079 .44592 .45323 .44973 .45223 .44754 .44978 Metetra
.638 .721 .908 r
.44754 .44978 .44973 .45223 .45355 .45124 .45136 .44878 Metetra
.637 .72 .908 r
.45136 .44878 .45355 .45124 .45738 .45026 .45519 .44779 Metetra
.636 .719 .908 r
.45519 .44779 .45738 .45026 .46121 .44929 .45902 .44681 Metetra
.634 .718 .908 r
.45902 .44681 .46121 .44929 .46504 .44832 .46286 .44583 Metetra
.633 .717 .908 r
.46286 .44583 .46504 .44832 .46889 .44737 .46671 .44487 Metetra
.632 .716 .908 r
.46671 .44487 .46889 .44737 .47273 .44643 .47056 .44392 Metetra
.63 .715 .908 r
.47056 .44392 .47273 .44643 .47659 .44551 .47442 .44298 Metetra
.629 .714 .908 r
.47442 .44298 .47659 .44551 .48045 .44459 .47828 .44206 Metetra
.627 .712 .908 r
.47828 .44206 .48045 .44459 .48432 .4437 .48215 .44115 Metetra
.625 .711 .907 r
.48215 .44115 .48432 .4437 .48819 .44282 .48602 .44026 Metetra
.624 .709 .907 r
.48602 .44026 .48819 .44282 .49207 .44195 .48991 .43938 Metetra
.621 .708 .907 r
.48991 .43938 .49207 .44195 .49595 .44111 .49379 .43852 Metetra
.619 .706 .907 r
.49379 .43852 .49595 .44111 .49984 .44029 .49769 .43769 Metetra
.617 .704 .907 r
.49769 .43769 .49984 .44029 .50374 .4395 .50159 .43688 Metetra
.614 .702 .907 r
.50159 .43688 .50374 .4395 .50764 .43873 .5055 .43609 Metetra
.611 .699 .907 r
.5055 .43609 .50764 .43873 .51155 .43799 .50941 .43533 Metetra
.607 .696 .907 r
.50941 .43533 .51155 .43799 .51547 .43728 .51333 .4346 Metetra
.603 .693 .906 r
.51333 .4346 .51547 .43728 .5194 .43661 .51726 .43391 Metetra
.599 .69 .906 r
.51726 .43391 .5194 .43661 .52333 .43599 .52119 .43326 Metetra
.963 .681 .451 r
.52119 .43326 .52333 .43599 .52727 .43541 .52515 .6338 Metetra
.55 .33 .534 r
.52515 .6338 .52727 .43541 .5316 .63482 .52934 .63259 Metetra
.645 .763 .934 r
.52934 .63259 .5316 .63482 .5358 .63361 .53354 .63138 Metetra
.944 .749 .609 r
.53354 .63138 .5358 .63361 .54 .6323 .53769 .61428 Metetra
.79 .564 .594 r
.53769 .61428 .54 .6323 .54406 .6059 .54178 .59289 Metetra
.784 .574 .616 r
.54178 .59289 .54406 .6059 .54814 .58897 .54587 .57855 Metetra
.771 .579 .638 r
.54587 .57855 .54814 .58897 .55222 .57728 .54997 .56835 Metetra
.754 .579 .66 r
.54997 .56835 .55222 .57728 .55632 .56893 .55407 .5609 Metetra
.731 .576 .68 r
.55407 .5609 .55632 .56893 .56043 .56292 .55819 .55546 Metetra
.702 .567 .699 r
.55819 .55546 .56043 .56292 .56456 .55873 .56232 .5516 Metetra
.666 .552 .715 r
.56232 .5516 .56456 .55873 .5687 .55608 .56647 .54909 Metetra
.621 .528 .728 r
.56647 .54909 .5687 .55608 .57287 .55483 .57063 .54784 Metetra
.563 .494 .736 r
.57063 .54784 .57287 .55483 .57707 .55499 .57482 .54784 Metetra
.488 .445 .736 r
.57482 .54784 .57707 .55499 .5813 .55668 .57905 .54919 Metetra
.388 .374 .723 r
.57905 .54919 .5813 .55668 .58558 .5602 .58331 .55214 Metetra
.254 .275 .69 r
.58331 .55214 .58558 .5602 .58992 .56609 .58763 .5571 Metetra
.078 .139 .625 r
.58763 .5571 .58992 .56609 .59435 .57534 .59202 .56484 Metetra
0 0 .516 r
.59202 .56484 .59435 .57534 .59894 .58987 .59653 .57677 Metetra
0 0 .359 r
.59653 .57677 .59894 .58987 .60378 .61396 .60124 .59579 Metetra
.121 .091 .547 r
.60124 .59579 .60378 .61396 .60809 .61283 .60591 .61054 Metetra
.645 .763 .934 r
.60591 .61054 .60809 .61283 .6124 .61159 .61022 .6093 Metetra
.645 .763 .934 r
.61022 .6093 .6124 .61159 .61131 .40819 .61455 .60805 Metetra
0 0 .381 r
.61455 .60805 .61131 .40819 .61536 .40617 .6133 .40335 Metetra
.709 .728 .865 r
.6133 .40335 .61536 .40617 .61941 .4042 .61736 .4014 Metetra
.707 .729 .868 r
.61736 .4014 .61941 .4042 .62347 .40226 .62142 .39949 Metetra
.705 .73 .87 r
.62142 .39949 .62347 .40226 .62753 .40037 .62549 .39761 Metetra
.703 .731 .872 r
.62549 .39761 .62753 .40037 .6316 .39851 .62956 .39576 Metetra
.701 .731 .874 r
.62956 .39576 .6316 .39851 .63568 .39668 .63364 .39394 Metetra
.699 .732 .876 r
.63364 .39394 .63568 .39668 .63976 .39487 .63772 .39214 Metetra
.697 .733 .878 r
.63772 .39214 .63976 .39487 .64384 .39309 .64182 .39037 Metetra
.696 .733 .879 r
.64182 .39037 .64384 .39309 .64794 .39133 .64591 .38862 Metetra
.694 .733 .881 r
.64591 .38862 .64794 .39133 .65203 .38959 .65001 .38688 Metetra
.693 .734 .882 r
.65001 .38688 .65203 .38959 .65614 .38786 .65412 .38517 Metetra
.692 .734 .883 r
.65412 .38517 .65614 .38786 .66025 .38616 .65823 .38347 Metetra
.691 .735 .884 r
.65823 .38347 .66025 .38616 .66436 .38447 .66235 .38178 Metetra
.689 .735 .885 r
.66235 .38178 .66436 .38447 .66848 .38279 .66648 .38011 Metetra
.688 .735 .886 r
.66648 .38011 .66848 .38279 .67261 .38112 .67061 .37844 Metetra
.687 .735 .887 r
.67061 .37844 .67261 .38112 .67674 .37947 .67475 .37679 Metetra
.687 .736 .888 r
.67475 .37679 .67674 .37947 .68088 .37783 .67889 .37515 Metetra
.686 .736 .889 r
.67889 .37515 .68088 .37783 .68502 .37619 .68304 .37352 Metetra
.685 .736 .89 r
.68304 .37352 .68502 .37619 .68917 .37457 .68719 .3719 Metetra
.684 .736 .89 r
.68719 .3719 .68917 .37457 .69333 .37295 .69136 .37029 Metetra
.683 .736 .891 r
.69136 .37029 .69333 .37295 .69749 .37135 .69552 .36868 Metetra
.683 .737 .892 r
.69552 .36868 .69749 .37135 .70166 .36974 .69969 .36708 Metetra
.682 .737 .892 r
.69969 .36708 .70166 .36974 .70584 .36815 .70387 .36549 Metetra
.681 .737 .893 r
.70387 .36549 .70584 .36815 .71002 .36656 .70806 .3639 Metetra
.681 .737 .893 r
.70806 .3639 .71002 .36656 .7142 .36498 .71225 .36231 Metetra
.68 .737 .894 r
.71225 .36231 .7142 .36498 .71839 .3634 .71645 .36074 Metetra
.68 .737 .894 r
.71645 .36074 .71839 .3634 .72259 .36183 .72065 .35916 Metetra
.679 .738 .895 r
.72065 .35916 .72259 .36183 .7268 .36026 .72486 .35759 Metetra
.679 .738 .895 r
.72486 .35759 .7268 .36026 .73101 .35869 .72907 .35603 Metetra
.678 .738 .895 r
.72907 .35603 .73101 .35869 .73523 .35713 .7333 .35447 Metetra
.678 .738 .896 r
.7333 .35447 .73523 .35713 .73945 .35558 .73752 .35291 Metetra
.677 .738 .896 r
.73752 .35291 .73945 .35558 .74368 .35402 .74176 .35136 Metetra
.677 .738 .897 r
.74176 .35136 .74368 .35402 .74791 .35247 .746 .3498 Metetra
.677 .738 .897 r
.746 .3498 .74791 .35247 .75215 .35092 .75024 .34825 Metetra
.676 .738 .897 r
.75024 .34825 .75215 .35092 .7564 .34938 .75449 .34671 Metetra
.676 .738 .898 r
.75449 .34671 .7564 .34938 .76066 .34783 .75875 .34516 Metetra
.676 .738 .898 r
.75875 .34516 .76066 .34783 .76492 .34629 .76302 .34362 Metetra
.675 .738 .898 r
.76302 .34362 .76492 .34629 .76918 .34475 .76729 .34208 Metetra
.675 .739 .898 r
.76729 .34208 .76918 .34475 .77346 .34321 .77157 .34054 Metetra
.675 .739 .899 r
.77157 .34054 .77346 .34321 .77774 .34168 .77585 .339 Metetra
.674 .739 .899 r
.77585 .339 .77774 .34168 .78202 .34014 .78014 .33746 Metetra
.674 .739 .899 r
.78014 .33746 .78202 .34014 .78631 .33861 .78444 .33592 Metetra
.674 .739 .899 r
.78444 .33592 .78631 .33861 .79061 .33708 .78874 .33439 Metetra
.674 .739 .899 r
.78874 .33439 .79061 .33708 .79491 .33554 .79305 .33286 Metetra
.673 .739 .9 r
.79305 .33286 .79491 .33554 .79923 .33401 .79736 .33132 Metetra
.673 .739 .9 r
.79736 .33132 .79923 .33401 .80354 .33248 .80169 .32979 Metetra
.673 .739 .9 r
.80169 .32979 .80354 .33248 .80787 .33095 .80601 .32826 Metetra
.673 .739 .9 r
.80601 .32826 .80787 .33095 .8122 .32942 .81035 .32673 Metetra
.961 .771 .602 r
.81035 .32673 .8122 .32942 .81653 .32789 .81359 .31328 Metetra
.593 .435 .637 r
.81359 .31328 .81653 .32789 .81976 .31448 .81793 .31185 Metetra
.664 .741 .907 r
.81793 .31185 .81976 .31448 .8241 .31306 .82228 .31042 Metetra
.664 .741 .907 r
.82228 .31042 .8241 .31306 .82845 .31163 .82663 .30899 Metetra
.664 .741 .907 r
.82663 .30899 .82845 .31163 .8328 .3102 .83099 .30755 Metetra
.664 .741 .907 r
.83099 .30755 .8328 .3102 .83717 .30877 .83536 .30612 Metetra
.664 .741 .907 r
.83536 .30612 .83717 .30877 .84153 .30733 .83973 .30468 Metetra
.664 .741 .907 r
.83973 .30468 .84153 .30733 .84591 .30589 .84411 .30324 Metetra
.664 .741 .907 r
.84411 .30324 .84591 .30589 .85029 .30445 .8485 .30179 Metetra
.664 .741 .907 r
.8485 .30179 .85029 .30445 .85468 .30301 .85289 .30035 Metetra
.664 .741 .907 r
.85289 .30035 .85468 .30301 .85907 .30157 .85729 .2989 Metetra
.664 .741 .907 r
.85729 .2989 .85907 .30157 .86347 .30012 .8617 .29745 Metetra
.664 .741 .907 r
.8617 .29745 .86347 .30012 .86788 .29868 .86611 .296 Metetra
.664 .741 .907 r
.86611 .296 .86788 .29868 .8723 .29723 .87053 .29454 Metetra
.664 .741 .907 r
.87053 .29454 .8723 .29723 .87672 .29577 .87495 .29309 Metetra
.664 .741 .907 r
.87495 .29309 .87672 .29577 .88115 .29432 .87939 .29163 Metetra
.664 .741 .907 r
.28313 .48486 .28546 .48703 .28904 .48585 .28671 .48367 Metetra
.664 .741 .907 r
.28671 .48367 .28904 .48585 .29263 .48467 .29031 .48249 Metetra
.664 .741 .907 r
.29031 .48249 .29263 .48467 .29623 .48349 .2939 .4813 Metetra
.664 .741 .907 r
.2939 .4813 .29623 .48349 .29982 .48231 .2975 .48012 Metetra
.664 .741 .907 r
.2975 .48012 .29982 .48231 .30343 .48112 .30111 .47893 Metetra
.664 .741 .907 r
.30111 .47893 .30343 .48112 .30704 .47993 .30472 .47774 Metetra
.664 .741 .907 r
.30472 .47774 .30704 .47993 .31065 .47875 .30834 .47655 Metetra
.664 .741 .907 r
.30834 .47655 .31065 .47875 .31427 .47756 .31196 .47535 Metetra
.664 .741 .907 r
.31196 .47535 .31427 .47756 .31789 .47636 .31559 .47416 Metetra
.664 .741 .907 r
.31559 .47416 .31789 .47636 .32152 .47517 .31922 .47296 Metetra
.664 .741 .907 r
.31922 .47296 .32152 .47517 .32515 .47397 .32285 .47176 Metetra
.664 .741 .907 r
.32285 .47176 .32515 .47397 .32879 .47278 .3265 .47056 Metetra
.664 .741 .907 r
.3265 .47056 .32879 .47278 .33244 .47158 .33014 .46936 Metetra
.664 .741 .907 r
.33014 .46936 .33244 .47158 .33608 .47038 .33379 .46816 Metetra
.664 .741 .907 r
.33379 .46816 .33608 .47038 .33974 .46918 .33745 .46695 Metetra
.664 .741 .907 r
.33745 .46695 .33974 .46918 .34276 .47956 .34111 .46575 Metetra
.046 .04 .525 r
.34111 .46575 .34276 .47956 .34643 .47847 .34414 .47617 Metetra
.652 .732 .908 r
.34414 .47617 .34643 .47847 .3501 .47738 .34782 .47507 Metetra
.652 .732 .908 r
.34782 .47507 .3501 .47738 .35378 .47628 .3515 .47398 Metetra
.651 .732 .908 r
.3515 .47398 .35378 .47628 .35747 .47519 .35519 .47288 Metetra
.651 .731 .908 r
.35519 .47288 .35747 .47519 .36116 .4741 .35889 .47179 Metetra
.651 .731 .908 r
.35889 .47179 .36116 .4741 .36486 .47302 .36259 .47069 Metetra
.65 .731 .908 r
.36259 .47069 .36486 .47302 .36856 .47193 .36629 .4696 Metetra
.65 .731 .908 r
.36629 .4696 .36856 .47193 .37227 .47084 .37 .46851 Metetra
.65 .73 .908 r
.37 .46851 .37227 .47084 .37598 .46976 .37372 .46742 Metetra
.649 .73 .908 r
.37372 .46742 .37598 .46976 .37969 .46868 .37744 .46634 Metetra
.649 .73 .908 r
.37744 .46634 .37969 .46868 .38342 .4676 .38116 .46525 Metetra
.649 .73 .908 r
.38116 .46525 .38342 .4676 .38715 .46652 .38489 .46417 Metetra
.648 .729 .908 r
.38489 .46417 .38715 .46652 .39088 .46545 .38863 .46309 Metetra
.648 .729 .908 r
.38863 .46309 .39088 .46545 .39462 .46438 .39237 .46201 Metetra
.647 .729 .908 r
.39237 .46201 .39462 .46438 .39836 .46331 .39612 .46094 Metetra
.647 .728 .908 r
.39612 .46094 .39836 .46331 .40211 .46224 .39987 .45987 Metetra
.647 .728 .908 r
.39987 .45987 .40211 .46224 .40587 .46118 .40363 .4588 Metetra
.646 .727 .908 r
.40363 .4588 .40587 .46118 .40963 .46012 .40739 .45773 Metetra
.645 .727 .908 r
.40739 .45773 .40963 .46012 .41339 .45906 .41116 .45667 Metetra
.645 .727 .908 r
.41116 .45667 .41339 .45906 .41716 .45801 .41494 .45561 Metetra
.644 .726 .908 r
.41494 .45561 .41716 .45801 .42094 .45696 .41872 .45456 Metetra
.644 .726 .908 r
.41872 .45456 .42094 .45696 .42472 .45592 .4225 .45351 Metetra
.643 .725 .908 r
.4225 .45351 .42472 .45592 .42851 .45488 .4263 .45246 Metetra
.642 .724 .908 r
.4263 .45246 .42851 .45488 .43231 .45385 .43009 .45142 Metetra
.642 .724 .908 r
.43009 .45142 .43231 .45385 .43611 .45282 .43389 .45039 Metetra
.641 .723 .908 r
.43389 .45039 .43611 .45282 .43991 .4518 .4377 .44936 Metetra
.64 .723 .908 r
.4377 .44936 .43991 .4518 .44372 .45079 .44152 .44834 Metetra
.639 .722 .908 r
.44152 .44834 .44372 .45079 .44754 .44978 .44534 .44732 Metetra
.638 .721 .908 r
.44534 .44732 .44754 .44978 .45136 .44878 .44916 .44631 Metetra
.637 .72 .908 r
.44916 .44631 .45136 .44878 .45519 .44779 .45299 .44531 Metetra
.636 .72 .908 r
.45299 .44531 .45519 .44779 .45902 .44681 .45683 .44432 Metetra
.635 .719 .908 r
.45683 .44432 .45902 .44681 .46286 .44583 .46067 .44334 Metetra
.634 .718 .908 r
.46067 .44334 .46286 .44583 .46671 .44487 .46452 .44237 Metetra
.633 .717 .908 r
.46452 .44237 .46671 .44487 .47056 .44392 .46838 .44141 Metetra
.631 .716 .908 r
.46838 .44141 .47056 .44392 .47442 .44298 .47224 .44046 Metetra
.63 .714 .908 r
.47224 .44046 .47442 .44298 .47828 .44206 .4761 .43952 Metetra
.628 .713 .907 r
.4761 .43952 .47828 .44206 .48215 .44115 .47998 .4386 Metetra
.626 .712 .907 r
.47998 .4386 .48215 .44115 .48602 .44026 .48385 .4377 Metetra
.625 .71 .907 r
.48385 .4377 .48602 .44026 .48991 .43938 .48774 .43681 Metetra
.623 .709 .907 r
.48774 .43681 .48991 .43938 .49379 .43852 .49163 .43593 Metetra
.62 .707 .907 r
.49163 .43593 .49379 .43852 .49769 .43769 .49553 .43508 Metetra
.618 .705 .907 r
.49553 .43508 .49769 .43769 .50159 .43688 .49943 .43425 Metetra
.615 .703 .907 r
.49943 .43425 .50159 .43688 .5055 .43609 .50334 .43345 Metetra
.612 .7 .907 r
.50334 .43345 .5055 .43609 .50941 .43533 .50726 .43267 Metetra
.609 .698 .906 r
.50726 .43267 .50941 .43533 .51333 .4346 .51118 .43192 Metetra
.606 .695 .906 r
.51118 .43192 .51333 .4346 .51726 .43391 .51511 .43121 Metetra
.602 .692 .906 r
.51511 .43121 .51726 .43391 .52119 .43326 .51905 .43053 Metetra
.963 .681 .451 r
.51905 .43053 .52119 .43326 .52515 .6338 .52288 .63157 Metetra
.645 .763 .934 r
.52288 .63157 .52515 .6338 .52934 .63259 .52707 .63036 Metetra
.812 .796 .836 r
.52707 .63036 .52934 .63259 .53354 .63138 .53127 .62665 Metetra
.929 .701 .571 r
.53127 .62665 .53354 .63138 .53769 .61428 .5354 .599 Metetra
.788 .569 .604 r
.5354 .599 .53769 .61428 .54178 .59289 .53951 .58129 Metetra
.78 .578 .626 r
.53951 .58129 .54178 .59289 .54587 .57855 .54361 .56896 Metetra
.767 .582 .648 r
.54361 .56896 .54587 .57855 .54997 .56835 .54772 .55997 Metetra
.749 .582 .669 r
.54772 .55997 .54997 .56835 .55407 .5609 .55183 .55328 Metetra
.727 .579 .689 r
.55183 .55328 .55407 .5609 .55819 .55546 .55595 .54832 Metetra
.699 .57 .706 r
.55595 .54832 .55819 .55546 .56232 .5516 .56008 .54474 Metetra
.665 .556 .722 r
.56008 .54474 .56232 .5516 .56647 .54909 .56423 .54237 Metetra
.623 .535 .734 r
.56423 .54237 .56647 .54909 .57063 .54784 .5684 .54111 Metetra
.57 .504 .741 r
.5684 .54111 .57063 .54784 .57482 .54784 .57258 .54097 Metetra
.502 .46 .742 r
.57258 .54097 .57482 .54784 .57905 .54919 .5768 .54203 Metetra
.413 .398 .733 r
.5768 .54203 .57905 .54919 .58331 .55214 .58105 .54448 Metetra
.296 .312 .707 r
.58105 .54448 .58331 .55214 .58763 .5571 .58534 .54867 Metetra
.143 .193 .656 r
.58534 .54867 .58763 .5571 .59202 .56484 .58971 .55518 Metetra
0 .038 .567 r
.58971 .55518 .59202 .56484 .59653 .57677 .59416 .56507 Metetra
0 0 .433 r
.59416 .56507 .59653 .57677 .60124 .59579 .59877 .58038 Metetra
0 0 .261 r
.59877 .58038 .60124 .59579 .60591 .61054 .60366 .60573 Metetra
.444 .498 .821 r
.60366 .60573 .60591 .61054 .61022 .6093 .60804 .607 Metetra
.645 .763 .934 r
.60804 .607 .61022 .6093 .61455 .60805 .61237 .60575 Metetra
.97 .694 .451 r
.61237 .60575 .61455 .60805 .6133 .40335 .61124 .40054 Metetra
.708 .729 .866 r
.61124 .40054 .6133 .40335 .61736 .4014 .6153 .39861 Metetra
.706 .729 .869 r
.6153 .39861 .61736 .4014 .62142 .39949 .61936 .39671 Metetra
.704 .73 .871 r
.61936 .39671 .62142 .39949 .62549 .39761 .62344 .39484 Metetra
.702 .731 .873 r
.62344 .39484 .62549 .39761 .62956 .39576 .62751 .39301 Metetra
.7 .732 .875 r
.62751 .39301 .62956 .39576 .63364 .39394 .6316 .3912 Metetra
.698 .732 .877 r
.6316 .3912 .63364 .39394 .63772 .39214 .63569 .38941 Metetra
.696 .733 .879 r
.63569 .38941 .63772 .39214 .64182 .39037 .63978 .38765 Metetra
.695 .733 .88 r
.63978 .38765 .64182 .39037 .64591 .38862 .64388 .3859 Metetra
.694 .734 .881 r
.64388 .3859 .64591 .38862 .65001 .38688 .64799 .38418 Metetra
.692 .734 .883 r
.64799 .38418 .65001 .38688 .65412 .38517 .6521 .38247 Metetra
.691 .734 .884 r
.6521 .38247 .65412 .38517 .65823 .38347 .65622 .38077 Metetra
.69 .735 .885 r
.65622 .38077 .65823 .38347 .66235 .38178 .66034 .37909 Metetra
.689 .735 .886 r
.66034 .37909 .66235 .38178 .66648 .38011 .66447 .37742 Metetra
.688 .735 .887 r
.66447 .37742 .66648 .38011 .67061 .37844 .66861 .37576 Metetra
.687 .735 .888 r
.66861 .37576 .67061 .37844 .67475 .37679 .67275 .37411 Metetra
.686 .736 .888 r
.67275 .37411 .67475 .37679 .67889 .37515 .6769 .37247 Metetra
.685 .736 .889 r
.6769 .37247 .67889 .37515 .68304 .37352 .68105 .37085 Metetra
.684 .736 .89 r
.68105 .37085 .68304 .37352 .68719 .3719 .68521 .36923 Metetra
.684 .736 .891 r
.68521 .36923 .68719 .3719 .69136 .37029 .68938 .36761 Metetra
.683 .737 .891 r
.68938 .36761 .69136 .37029 .69552 .36868 .69355 .36601 Metetra
.682 .737 .892 r
.69355 .36601 .69552 .36868 .69969 .36708 .69772 .36441 Metetra
.682 .737 .892 r
.69772 .36441 .69969 .36708 .70387 .36549 .70191 .36282 Metetra
.681 .737 .893 r
.70191 .36282 .70387 .36549 .70806 .3639 .7061 .36123 Metetra
.681 .737 .893 r
.7061 .36123 .70806 .3639 .71225 .36231 .71029 .35965 Metetra
.68 .737 .894 r
.71029 .35965 .71225 .36231 .71645 .36074 .71449 .35807 Metetra
.679 .737 .894 r
.71449 .35807 .71645 .36074 .72065 .35916 .7187 .35649 Metetra
.679 .738 .895 r
.7187 .35649 .72065 .35916 .72486 .35759 .72291 .35492 Metetra
.679 .738 .895 r
.72291 .35492 .72486 .35759 .72907 .35603 .72713 .35336 Metetra
.678 .738 .896 r
.72713 .35336 .72907 .35603 .7333 .35447 .73136 .3518 Metetra
.678 .738 .896 r
.73136 .3518 .7333 .35447 .73752 .35291 .73559 .35024 Metetra
.677 .738 .896 r
.73559 .35024 .73752 .35291 .74176 .35136 .73983 .34868 Metetra
.677 .738 .897 r
.73983 .34868 .74176 .35136 .746 .3498 .74407 .34713 Metetra
.676 .738 .897 r
.74407 .34713 .746 .3498 .75024 .34825 .74833 .34558 Metetra
.676 .738 .897 r
.74833 .34558 .75024 .34825 .75449 .34671 .75258 .34403 Metetra
.676 .738 .898 r
.75258 .34403 .75449 .34671 .75875 .34516 .75685 .34248 Metetra
.675 .738 .898 r
.75685 .34248 .75875 .34516 .76302 .34362 .76111 .34094 Metetra
.675 .738 .898 r
.76111 .34094 .76302 .34362 .76729 .34208 .76539 .33939 Metetra
.675 .739 .898 r
.76539 .33939 .76729 .34208 .77157 .34054 .76967 .33785 Metetra
.675 .739 .899 r
.76967 .33785 .77157 .34054 .77585 .339 .77396 .33631 Metetra
.674 .739 .899 r
.77396 .33631 .77585 .339 .78014 .33746 .77826 .33477 Metetra
.674 .739 .899 r
.77826 .33477 .78014 .33746 .78444 .33592 .78256 .33323 Metetra
.674 .739 .899 r
.78256 .33323 .78444 .33592 .78874 .33439 .78686 .3317 Metetra
.673 .739 .9 r
.78686 .3317 .78874 .33439 .79305 .33286 .79118 .33016 Metetra
.673 .739 .9 r
.79118 .33016 .79305 .33286 .79736 .33132 .7955 .32863 Metetra
.673 .739 .9 r
.7955 .32863 .79736 .33132 .80169 .32979 .79982 .32709 Metetra
.673 .739 .9 r
.79982 .32709 .80169 .32979 .80601 .32826 .80416 .32556 Metetra
.961 .771 .602 r
.80416 .32556 .80601 .32826 .81035 .32673 .80742 .31207 Metetra
.593 .435 .636 r
.80742 .31207 .81035 .32673 .81359 .31328 .81176 .31064 Metetra
.664 .741 .907 r
.81176 .31064 .81359 .31328 .81793 .31185 .8161 .30921 Metetra
.664 .741 .907 r
.8161 .30921 .81793 .31185 .82228 .31042 .82045 .30777 Metetra
.664 .741 .907 r
.82045 .30777 .82228 .31042 .82663 .30899 .82481 .30634 Metetra
.664 .741 .907 r
.82481 .30634 .82663 .30899 .83099 .30755 .82918 .3049 Metetra
.664 .741 .907 r
.82918 .3049 .83099 .30755 .83536 .30612 .83355 .30346 Metetra
.664 .741 .907 r
.83355 .30346 .83536 .30612 .83973 .30468 .83793 .30201 Metetra
.664 .741 .907 r
.83793 .30201 .83973 .30468 .84411 .30324 .84231 .30057 Metetra
.664 .741 .907 r
.84231 .30057 .84411 .30324 .8485 .30179 .8467 .29912 Metetra
.664 .741 .907 r
.8467 .29912 .8485 .30179 .85289 .30035 .8511 .29767 Metetra
.664 .741 .907 r
.8511 .29767 .85289 .30035 .85729 .2989 .8555 .29622 Metetra
.664 .741 .907 r
.8555 .29622 .85729 .2989 .8617 .29745 .85991 .29477 Metetra
.664 .741 .907 r
.85991 .29477 .8617 .29745 .86611 .296 .86433 .29331 Metetra
.664 .741 .907 r
.86433 .29331 .86611 .296 .87053 .29454 .86875 .29185 Metetra
.664 .741 .907 r
.86875 .29185 .87053 .29454 .87495 .29309 .87319 .29039 Metetra
.664 .741 .907 r
.87319 .29039 .87495 .29309 .87939 .29163 .87762 .28893 Metetra
.664 .741 .907 r
.28079 .48267 .28313 .48486 .28671 .48367 .28438 .48149 Metetra
.664 .741 .907 r
.28438 .48149 .28671 .48367 .29031 .48249 .28797 .4803 Metetra
.664 .741 .907 r
.28797 .4803 .29031 .48249 .2939 .4813 .29157 .47911 Metetra
.664 .741 .907 r
.29157 .47911 .2939 .4813 .2975 .48012 .29518 .47792 Metetra
.664 .741 .907 r
.29518 .47792 .2975 .48012 .30111 .47893 .29879 .47673 Metetra
.664 .741 .907 r
.29879 .47673 .30111 .47893 .30472 .47774 .3024 .47554 Metetra
.664 .741 .907 r
.3024 .47554 .30472 .47774 .30834 .47655 .30602 .47434 Metetra
.664 .741 .907 r
.30602 .47434 .30834 .47655 .31196 .47535 .30965 .47315 Metetra
.664 .741 .907 r
.30965 .47315 .31196 .47535 .31559 .47416 .31328 .47195 Metetra
.664 .741 .907 r
.31328 .47195 .31559 .47416 .31922 .47296 .31691 .47075 Metetra
.664 .741 .907 r
.31691 .47075 .31922 .47296 .32285 .47176 .32055 .46955 Metetra
.664 .741 .907 r
.32055 .46955 .32285 .47176 .3265 .47056 .32419 .46834 Metetra
.664 .741 .907 r
.32419 .46834 .3265 .47056 .33014 .46936 .32784 .46714 Metetra
.664 .741 .907 r
.32784 .46714 .33014 .46936 .33379 .46816 .3315 .46593 Metetra
.664 .741 .907 r
.3315 .46593 .33379 .46816 .33745 .46695 .33516 .46472 Metetra
.664 .741 .907 r
.33516 .46472 .33745 .46695 .34111 .46575 .33882 .46351 Metetra
.664 .741 .907 r
.33882 .46351 .34111 .46575 .34414 .47617 .34249 .4623 Metetra
.046 .039 .524 r
.34249 .4623 .34414 .47617 .34782 .47507 .34553 .47277 Metetra
.652 .732 .908 r
.34553 .47277 .34782 .47507 .3515 .47398 .34922 .47166 Metetra
.652 .732 .908 r
.34922 .47166 .3515 .47398 .35519 .47288 .35291 .47056 Metetra
.651 .732 .908 r
.35291 .47056 .35519 .47288 .35889 .47179 .35661 .46947 Metetra
.651 .731 .908 r
.35661 .46947 .35889 .47179 .36259 .47069 .36031 .46837 Metetra
.651 .731 .908 r
.36031 .46837 .36259 .47069 .36629 .4696 .36402 .46727 Metetra
.65 .731 .908 r
.36402 .46727 .36629 .4696 .37 .46851 .36773 .46618 Metetra
.65 .731 .908 r
.36773 .46618 .37 .46851 .37372 .46742 .37145 .46508 Metetra
.65 .73 .908 r
.37145 .46508 .37372 .46742 .37744 .46634 .37517 .46399 Metetra
.649 .73 .908 r
.37517 .46399 .37744 .46634 .38116 .46525 .3789 .4629 Metetra
.649 .73 .908 r
.3789 .4629 .38116 .46525 .38489 .46417 .38264 .46181 Metetra
.649 .729 .908 r
.38264 .46181 .38489 .46417 .38863 .46309 .38638 .46073 Metetra
.648 .729 .908 r
.38638 .46073 .38863 .46309 .39237 .46201 .39012 .45964 Metetra
.648 .729 .908 r
.39012 .45964 .39237 .46201 .39612 .46094 .39387 .45856 Metetra
.647 .728 .908 r
.39387 .45856 .39612 .46094 .39987 .45987 .39763 .45749 Metetra
.647 .728 .908 r
.39763 .45749 .39987 .45987 .40363 .4588 .40139 .45641 Metetra
.646 .728 .908 r
.40139 .45641 .40363 .4588 .40739 .45773 .40516 .45534 Metetra
.646 .727 .908 r
.40516 .45534 .40739 .45773 .41116 .45667 .40893 .45427 Metetra
.645 .727 .908 r
.40893 .45427 .41116 .45667 .41494 .45561 .41271 .45321 Metetra
.645 .726 .908 r
.41271 .45321 .41494 .45561 .41872 .45456 .41649 .45214 Metetra
.644 .726 .908 r
.41649 .45214 .41872 .45456 .4225 .45351 .42028 .45109 Metetra
.643 .725 .908 r
.42028 .45109 .4225 .45351 .4263 .45246 .42407 .45004 Metetra
.643 .725 .908 r
.42407 .45004 .4263 .45246 .43009 .45142 .42787 .44899 Metetra
.642 .724 .908 r
.42787 .44899 .43009 .45142 .43389 .45039 .43168 .44795 Metetra
.641 .724 .908 r
.43168 .44795 .43389 .45039 .4377 .44936 .43549 .44691 Metetra
.641 .723 .908 r
.43549 .44691 .4377 .44936 .44152 .44834 .43931 .44588 Metetra
.64 .722 .908 r
.43931 .44588 .44152 .44834 .44534 .44732 .44313 .44486 Metetra
.639 .722 .908 r
.44313 .44486 .44534 .44732 .44916 .44631 .44696 .44384 Metetra
.638 .721 .908 r
.44696 .44384 .44916 .44631 .45299 .44531 .45079 .44283 Metetra
.637 .72 .908 r
.45079 .44283 .45299 .44531 .45683 .44432 .45463 .44183 Metetra
.636 .719 .908 r
.45463 .44183 .45683 .44432 .46067 .44334 .45848 .44084 Metetra
.635 .718 .908 r
.45848 .44084 .46067 .44334 .46452 .44237 .46233 .43986 Metetra
.633 .717 .908 r
.46233 .43986 .46452 .44237 .46838 .44141 .46619 .43889 Metetra
.632 .716 .908 r
.46619 .43889 .46838 .44141 .47224 .44046 .47005 .43793 Metetra
.631 .715 .907 r
.47005 .43793 .47224 .44046 .4761 .43952 .47392 .43698 Metetra
.629 .714 .907 r
.47392 .43698 .4761 .43952 .47998 .4386 .4778 .43605 Metetra
.627 .712 .907 r
.4778 .43605 .47998 .4386 .48385 .4377 .48168 .43513 Metetra
.626 .711 .907 r
.48168 .43513 .48385 .4377 .48774 .43681 .48557 .43423 Metetra
.624 .709 .907 r
.48557 .43423 .48774 .43681 .49163 .43593 .48946 .43334 Metetra
.622 .708 .907 r
.48946 .43334 .49163 .43593 .49553 .43508 .49336 .43248 Metetra
.619 .706 .907 r
.49336 .43248 .49553 .43508 .49943 .43425 .49727 .43163 Metetra
.617 .704 .907 r
.49727 .43163 .49943 .43425 .50334 .43345 .50118 .43081 Metetra
.614 .701 .907 r
.50118 .43081 .50334 .43345 .50726 .43267 .5051 .43001 Metetra
.611 .699 .906 r
.5051 .43001 .50726 .43267 .51118 .43192 .50903 .42924 Metetra
.608 .696 .906 r
.50903 .42924 .51118 .43192 .51511 .43121 .51296 .4285 Metetra
.963 .682 .453 r
.51296 .4285 .51511 .43121 .51905 .43053 .5164 .63054 Metetra
.549 .329 .533 r
.5164 .63054 .51905 .43053 .52288 .63157 .5206 .62933 Metetra
.645 .763 .934 r
.5206 .62933 .52288 .63157 .52707 .63036 .5248 .62812 Metetra
.948 .742 .591 r
.5248 .62812 .52707 .63036 .53127 .62665 .52898 .60792 Metetra
.79 .562 .593 r
.52898 .60792 .53127 .62665 .5354 .599 .53312 .58573 Metetra
.786 .574 .614 r
.53312 .58573 .5354 .599 .53951 .58129 .53724 .57079 Metetra
.776 .581 .636 r
.53724 .57079 .53951 .58129 .54361 .56896 .54136 .56006 Metetra
.763 .585 .657 r
.54136 .56006 .54361 .56896 .54772 .55997 .54547 .55207 Metetra
.745 .585 .678 r
.54547 .55207 .54772 .55997 .55183 .55328 .54959 .54602 Metetra
.723 .582 .696 r
.54959 .54602 .55183 .55328 .55595 .54832 .55371 .54147 Metetra
.696 .574 .713 r
.55371 .54147 .55595 .54832 .56008 .54474 .55785 .53814 Metetra
.664 .56 .728 r
.55785 .53814 .56008 .54474 .56423 .54237 .562 .53587 Metetra
.625 .541 .74 r
.562 .53587 .56423 .54237 .5684 .54111 .56616 .53461 Metetra
.576 .513 .747 r
.56616 .53461 .5684 .54111 .57258 .54097 .57035 .53434 Metetra
.515 .473 .749 r
.57035 .53434 .57258 .54097 .5768 .54203 .57455 .53515 Metetra
.436 .419 .742 r
.57455 .53515 .5768 .54203 .58105 .54448 .57879 .53719 Metetra
.333 .344 .722 r
.57879 .53719 .58105 .54448 .58534 .54867 .58307 .54072 Metetra
.199 .241 .681 r
.58307 .54072 .58534 .54867 .58971 .55518 .58741 .54622 Metetra
.027 .104 .609 r
.58741 .54622 .58971 .55518 .59416 .56507 .59182 .55448 Metetra
0 0 .497 r
.59182 .55448 .59416 .56507 .59877 .58038 .59636 .56699 Metetra
0 0 .343 r
.59636 .56699 .59877 .58038 .60366 .60573 .60109 .58683 Metetra
.016 .013 .508 r
.60109 .58683 .60366 .60573 .60804 .607 .60585 .60469 Metetra
.645 .763 .934 r
.60585 .60469 .60804 .607 .61237 .60575 .61018 .60344 Metetra
.645 .763 .934 r
.61018 .60344 .61237 .60575 .61124 .40054 .61452 .60219 Metetra
0 0 .38 r
.61452 .60219 .61124 .40054 .6153 .39861 .61323 .39582 Metetra
.705 .73 .87 r
.61323 .39582 .6153 .39861 .61936 .39671 .6173 .39393 Metetra
.703 .73 .872 r
.6173 .39393 .61936 .39671 .62344 .39484 .62138 .39208 Metetra
.701 .731 .874 r
.62138 .39208 .62344 .39484 .62751 .39301 .62546 .39026 Metetra
.699 .732 .876 r
.62546 .39026 .62751 .39301 .6316 .3912 .62955 .38846 Metetra
.697 .732 .878 r
.62955 .38846 .6316 .3912 .63569 .38941 .63364 .38668 Metetra
.696 .733 .879 r
.63364 .38668 .63569 .38941 .63978 .38765 .63774 .38492 Metetra
.694 .733 .881 r
.63774 .38492 .63978 .38765 .64388 .3859 .64185 .38319 Metetra
.693 .734 .882 r
.64185 .38319 .64388 .3859 .64799 .38418 .64596 .38147 Metetra
.692 .734 .883 r
.64596 .38147 .64799 .38418 .6521 .38247 .65008 .37976 Metetra
.69 .734 .884 r
.65008 .37976 .6521 .38247 .65622 .38077 .6542 .37807 Metetra
.689 .735 .885 r
.6542 .37807 .65622 .38077 .66034 .37909 .65833 .37639 Metetra
.688 .735 .886 r
.65833 .37639 .66034 .37909 .66447 .37742 .66246 .37473 Metetra
.687 .735 .887 r
.66246 .37473 .66447 .37742 .66861 .37576 .6666 .37307 Metetra
.686 .735 .888 r
.6666 .37307 .66861 .37576 .67275 .37411 .67075 .37143 Metetra
.686 .736 .889 r
.67075 .37143 .67275 .37411 .6769 .37247 .6749 .36979 Metetra
.685 .736 .89 r
.6749 .36979 .6769 .37247 .68105 .37085 .67906 .36817 Metetra
.684 .736 .89 r
.67906 .36817 .68105 .37085 .68521 .36923 .68322 .36655 Metetra
.683 .736 .891 r
.68322 .36655 .68521 .36923 .68938 .36761 .68739 .36494 Metetra
.683 .737 .892 r
.68739 .36494 .68938 .36761 .69355 .36601 .69157 .36333 Metetra
.682 .737 .892 r
.69157 .36333 .69355 .36601 .69772 .36441 .69575 .36173 Metetra
.681 .737 .893 r
.69575 .36173 .69772 .36441 .70191 .36282 .69993 .36014 Metetra
.681 .737 .893 r
.69993 .36014 .70191 .36282 .7061 .36123 .70413 .35855 Metetra
.68 .737 .894 r
.70413 .35855 .7061 .36123 .71029 .35965 .70833 .35697 Metetra
.68 .737 .894 r
.70833 .35697 .71029 .35965 .71449 .35807 .71253 .35539 Metetra
.679 .737 .895 r
.71253 .35539 .71449 .35807 .7187 .35649 .71675 .35382 Metetra
.679 .738 .895 r
.71675 .35382 .7187 .35649 .72291 .35492 .72096 .35225 Metetra
.678 .738 .895 r
.72096 .35225 .72291 .35492 .72713 .35336 .72519 .35068 Metetra
.678 .738 .896 r
.72519 .35068 .72713 .35336 .73136 .3518 .72942 .34912 Metetra
.677 .738 .896 r
.72942 .34912 .73136 .3518 .73559 .35024 .73366 .34756 Metetra
.677 .738 .897 r
.73366 .34756 .73559 .35024 .73983 .34868 .7379 .346 Metetra
.677 .738 .897 r
.7379 .346 .73983 .34868 .74407 .34713 .74215 .34445 Metetra
.676 .738 .897 r
.74215 .34445 .74407 .34713 .74833 .34558 .7464 .3429 Metetra
.676 .738 .897 r
.7464 .3429 .74833 .34558 .75258 .34403 .75066 .34135 Metetra
.676 .738 .898 r
.75066 .34135 .75258 .34403 .75685 .34248 .75493 .3398 Metetra
.675 .738 .898 r
.75493 .3398 .75685 .34248 .76111 .34094 .75921 .33825 Metetra
.675 .738 .898 r
.75921 .33825 .76111 .34094 .76539 .33939 .76349 .33671 Metetra
.675 .739 .899 r
.76349 .33671 .76539 .33939 .76967 .33785 .76777 .33516 Metetra
.674 .739 .899 r
.76777 .33516 .76967 .33785 .77396 .33631 .77207 .33362 Metetra
.674 .739 .899 r
.77207 .33362 .77396 .33631 .77826 .33477 .77637 .33208 Metetra
.674 .739 .899 r
.77637 .33208 .77826 .33477 .78256 .33323 .78067 .33054 Metetra
.674 .739 .899 r
.78067 .33054 .78256 .33323 .78686 .3317 .78498 .329 Metetra
.673 .739 .9 r
.78498 .329 .78686 .3317 .79118 .33016 .7893 .32746 Metetra
.673 .739 .9 r
.7893 .32746 .79118 .33016 .7955 .32863 .79363 .32592 Metetra
.673 .739 .9 r
.79363 .32592 .7955 .32863 .79982 .32709 .79796 .32439 Metetra
.96 .77 .602 r
.79796 .32439 .79982 .32709 .80416 .32556 .80124 .31086 Metetra
.592 .434 .636 r
.80124 .31086 .80416 .32556 .80742 .31207 .80557 .30943 Metetra
.664 .741 .907 r
.80557 .30943 .80742 .31207 .81176 .31064 .80992 .30799 Metetra
.664 .741 .907 r
.80992 .30799 .81176 .31064 .8161 .30921 .81427 .30656 Metetra
.664 .741 .907 r
.81427 .30656 .8161 .30921 .82045 .30777 .81862 .30512 Metetra
.664 .741 .907 r
.81862 .30512 .82045 .30777 .82481 .30634 .82299 .30368 Metetra
.664 .741 .907 r
.82299 .30368 .82481 .30634 .82918 .3049 .82735 .30224 Metetra
.664 .741 .907 r
.82735 .30224 .82918 .3049 .83355 .30346 .83173 .30079 Metetra
.664 .741 .907 r
.83173 .30079 .83355 .30346 .83793 .30201 .83611 .29935 Metetra
.664 .741 .907 r
.83611 .29935 .83793 .30201 .84231 .30057 .8405 .2979 Metetra
.664 .741 .907 r
.8405 .2979 .84231 .30057 .8467 .29912 .8449 .29645 Metetra
.664 .741 .907 r
.8449 .29645 .8467 .29912 .8511 .29767 .8493 .29499 Metetra
.664 .741 .907 r
.8493 .29499 .8511 .29767 .8555 .29622 .85371 .29354 Metetra
.664 .741 .907 r
.85371 .29354 .8555 .29622 .85991 .29477 .85812 .29208 Metetra
.664 .741 .907 r
.85812 .29208 .85991 .29477 .86433 .29331 .86255 .29062 Metetra
.664 .741 .907 r
.86255 .29062 .86433 .29331 .86875 .29185 .86698 .28916 Metetra
.664 .741 .907 r
.86698 .28916 .86875 .29185 .87319 .29039 .87141 .28769 Metetra
.664 .741 .907 r
.87141 .28769 .87319 .29039 .87762 .28893 .87585 .28623 Metetra
.664 .741 .907 r
.27844 .48048 .28079 .48267 .28438 .48149 .28204 .47929 Metetra
.664 .741 .907 r
.28204 .47929 .28438 .48149 .28797 .4803 .28563 .47811 Metetra
.664 .741 .907 r
.28563 .47811 .28797 .4803 .29157 .47911 .28924 .47691 Metetra
.664 .741 .907 r
.28924 .47691 .29157 .47911 .29518 .47792 .29285 .47572 Metetra
.664 .741 .907 r
.29285 .47572 .29518 .47792 .29879 .47673 .29646 .47453 Metetra
.664 .741 .907 r
.29646 .47453 .29879 .47673 .3024 .47554 .30008 .47333 Metetra
.664 .741 .907 r
.30008 .47333 .3024 .47554 .30602 .47434 .3037 .47213 Metetra
.664 .741 .907 r
.3037 .47213 .30602 .47434 .30965 .47315 .30733 .47093 Metetra
.664 .741 .907 r
.30733 .47093 .30965 .47315 .31328 .47195 .31096 .46973 Metetra
.664 .741 .907 r
.31096 .46973 .31328 .47195 .31691 .47075 .3146 .46853 Metetra
.664 .741 .907 r
.3146 .46853 .31691 .47075 .32055 .46955 .31824 .46732 Metetra
.664 .741 .907 r
.31824 .46732 .32055 .46955 .32419 .46834 .32189 .46612 Metetra
.664 .741 .907 r
.32189 .46612 .32419 .46834 .32784 .46714 .32554 .46491 Metetra
.664 .741 .907 r
.32554 .46491 .32784 .46714 .3315 .46593 .3292 .4637 Metetra
.664 .741 .907 r
.3292 .4637 .3315 .46593 .33516 .46472 .33286 .46249 Metetra
.664 .741 .907 r
.33286 .46249 .33516 .46472 .33882 .46351 .33653 .46128 Metetra
.664 .741 .907 r
.33653 .46128 .33882 .46351 .34249 .4623 .3402 .46006 Metetra
.664 .741 .907 r
.3402 .46006 .34249 .4623 .34553 .47277 .34388 .45884 Metetra
.592 .434 .636 r
.34388 .45884 .34553 .47277 .34922 .47166 .34756 .45763 Metetra
.045 .038 .523 r
.34756 .45763 .34922 .47166 .35291 .47056 .35062 .46824 Metetra
.651 .732 .908 r
.35062 .46824 .35291 .47056 .35661 .46947 .35432 .46714 Metetra
.651 .731 .908 r
.35432 .46714 .35661 .46947 .36031 .46837 .35803 .46604 Metetra
.651 .731 .908 r
.35803 .46604 .36031 .46837 .36402 .46727 .36174 .46493 Metetra
.651 .731 .908 r
.36174 .46493 .36402 .46727 .36773 .46618 .36545 .46383 Metetra
.65 .731 .908 r
.36545 .46383 .36773 .46618 .37145 .46508 .36918 .46274 Metetra
.65 .73 .908 r
.36918 .46274 .37145 .46508 .37517 .46399 .3729 .46164 Metetra
.65 .73 .908 r
.3729 .46164 .37517 .46399 .3789 .4629 .37663 .46054 Metetra
.649 .73 .908 r
.37663 .46054 .3789 .4629 .38264 .46181 .38037 .45945 Metetra
.649 .73 .908 r
.38037 .45945 .38264 .46181 .38638 .46073 .38411 .45836 Metetra
.648 .729 .908 r
.38411 .45836 .38638 .46073 .39012 .45964 .38786 .45727 Metetra
.648 .729 .908 r
.38786 .45727 .39012 .45964 .39387 .45856 .39162 .45618 Metetra
.648 .729 .908 r
.39162 .45618 .39387 .45856 .39763 .45749 .39538 .4551 Metetra
.647 .728 .908 r
.39538 .4551 .39763 .45749 .40139 .45641 .39914 .45402 Metetra
.647 .728 .908 r
.39914 .45402 .40139 .45641 .40516 .45534 .40291 .45294 Metetra
.646 .727 .908 r
.40291 .45294 .40516 .45534 .40893 .45427 .40669 .45187 Metetra
.646 .727 .908 r
.40669 .45187 .40893 .45427 .41271 .45321 .41047 .4508 Metetra
.645 .726 .908 r
.41047 .4508 .41271 .45321 .41649 .45214 .41425 .44973 Metetra
.644 .726 .908 r
.41425 .44973 .41649 .45214 .42028 .45109 .41805 .44867 Metetra
.644 .725 .908 r
.41805 .44867 .42028 .45109 .42407 .45004 .42184 .44761 Metetra
.643 .725 .908 r
.42184 .44761 .42407 .45004 .42787 .44899 .42565 .44655 Metetra
.642 .724 .908 r
.42565 .44655 .42787 .44899 .43168 .44795 .42946 .4455 Metetra
.642 .724 .908 r
.42946 .4455 .43168 .44795 .43549 .44691 .43327 .44446 Metetra
.641 .723 .908 r
.43327 .44446 .43549 .44691 .43931 .44588 .43709 .44342 Metetra
.64 .723 .908 r
.43709 .44342 .43931 .44588 .44313 .44486 .44092 .44239 Metetra
.639 .722 .908 r
.44092 .44239 .44313 .44486 .44696 .44384 .44475 .44137 Metetra
.638 .721 .908 r
.44475 .44137 .44696 .44384 .45079 .44283 .44859 .44035 Metetra
.637 .72 .908 r
.44859 .44035 .45079 .44283 .45463 .44183 .45243 .43934 Metetra
.636 .719 .908 r
.45243 .43934 .45463 .44183 .45848 .44084 .45628 .43834 Metetra
.635 .719 .908 r
.45628 .43834 .45848 .44084 .46233 .43986 .46013 .43735 Metetra
.634 .718 .908 r
.46013 .43735 .46233 .43986 .46619 .43889 .46399 .43637 Metetra
.633 .717 .907 r
.46399 .43637 .46619 .43889 .47005 .43793 .46786 .4354 Metetra
.631 .715 .907 r
.46786 .4354 .47005 .43793 .47392 .43698 .47173 .43444 Metetra
.63 .714 .907 r
.47173 .43444 .47392 .43698 .4778 .43605 .47561 .4335 Metetra
.628 .713 .907 r
.47561 .4335 .4778 .43605 .48168 .43513 .4795 .43256 Metetra
.627 .712 .907 r
.4795 .43256 .48168 .43513 .48557 .43423 .48339 .43165 Metetra
.625 .71 .907 r
.48339 .43165 .48557 .43423 .48946 .43334 .48729 .43075 Metetra
.623 .708 .907 r
.48729 .43075 .48946 .43334 .49336 .43248 .49119 .42987 Metetra
.621 .707 .907 r
.49119 .42987 .49336 .43248 .49727 .43163 .4951 .42901 Metetra
.618 .705 .907 r
.4951 .42901 .49727 .43163 .50118 .43081 .49902 .42817 Metetra
.616 .702 .907 r
.49902 .42817 .50118 .43081 .5051 .43001 .50294 .42735 Metetra
.613 .7 .906 r
.50294 .42735 .5051 .43001 .50903 .42924 .50687 .42656 Metetra
.609 .697 .906 r
.50687 .42656 .50903 .42924 .51296 .4285 .51081 .4258 Metetra
.963 .682 .453 r
.51081 .4258 .51296 .4285 .5164 .63054 .51412 .6283 Metetra
.645 .763 .934 r
.51412 .6283 .5164 .63054 .5206 .62933 .51831 .62709 Metetra
.879 .789 .756 r
.51831 .62709 .5206 .62933 .5248 .62812 .52252 .62079 Metetra
.906 .673 .576 r
.52252 .62079 .5248 .62812 .52898 .60792 .52671 .59223 Metetra
.789 .568 .602 r
.52671 .59223 .52898 .60792 .53312 .58573 .53086 .57397 Metetra
.783 .578 .624 r
.53086 .57397 .53312 .58573 .53724 .57079 .53499 .56118 Metetra
.772 .585 .645 r
.53499 .56118 .53724 .57079 .54136 .56006 .53911 .55174 Metetra
.758 .588 .666 r
.53911 .55174 .54136 .56006 .54547 .55207 .54323 .54458 Metetra
.74 .588 .686 r
.54323 .54458 .54547 .55207 .54959 .54602 .54735 .53908 Metetra
.719 .585 .704 r
.54735 .53908 .54959 .54602 .55371 .54147 .55148 .53488 Metetra
.693 .577 .72 r
.55148 .53488 .55371 .54147 .55785 .53814 .55562 .53176 Metetra
.663 .565 .734 r
.55562 .53176 .55785 .53814 .562 .53587 .55977 .52959 Metetra
.626 .547 .745 r
.55977 .52959 .562 .53587 .56616 .53461 .56393 .52832 Metetra
.581 .521 .752 r
.56393 .52832 .56616 .53461 .57035 .53434 .56811 .52795 Metetra
.526 .486 .755 r
.56811 .52795 .57035 .53434 .57455 .53515 .57231 .52854 Metetra
.456 .438 .75 r
.57231 .52854 .57455 .53515 .57879 .53719 .57654 .53021 Metetra
.365 .372 .734 r
.57654 .53021 .57879 .53719 .58307 .54072 .58081 .53319 Metetra
.248 .283 .702 r
.58081 .53319 .58307 .54072 .58741 .54622 .58512 .53784 Metetra
.097 .164 .644 r
.58512 .53784 .58741 .54622 .59182 .55448 .5895 .54479 Metetra
0 .011 .551 r
.5895 .54479 .59182 .55448 .59636 .56699 .59398 .55512 Metetra
0 0 .418 r
.59398 .55512 .59636 .56699 .60109 .58683 .59861 .57099 Metetra
0 0 .252 r
.59861 .57099 .60109 .58683 .60585 .60469 .60353 .59725 Metetra
.314 .333 .721 r
.60353 .59725 .60585 .60469 .61018 .60344 .60799 .60112 Metetra
.645 .763 .934 r
.60799 .60112 .61018 .60344 .61452 .60219 .61233 .59986 Metetra
.97 .693 .45 r
.61233 .59986 .61452 .60219 .61323 .39582 .61116 .39303 Metetra
.703 .73 .871 r
.61116 .39303 .61323 .39582 .6173 .39393 .61524 .39116 Metetra
.701 .731 .873 r
.61524 .39116 .6173 .39393 .62138 .39208 .61932 .38932 Metetra
.7 .731 .875 r
.61932 .38932 .62138 .39208 .62546 .39026 .62341 .3875 Metetra
.698 .732 .877 r
.62341 .3875 .62546 .39026 .62955 .38846 .6275 .38571 Metetra
.696 .732 .878 r
.6275 .38571 .62955 .38846 .63364 .38668 .6316 .38395 Metetra
.695 .733 .88 r
.6316 .38395 .63364 .38668 .63774 .38492 .6357 .3822 Metetra
.693 .733 .881 r
.6357 .3822 .63774 .38492 .64185 .38319 .63981 .38047 Metetra
.692 .734 .883 r
.63981 .38047 .64185 .38319 .64596 .38147 .64393 .37875 Metetra
.691 .734 .884 r
.64393 .37875 .64596 .38147 .65008 .37976 .64805 .37705 Metetra
.69 .734 .885 r
.64805 .37705 .65008 .37976 .6542 .37807 .65217 .37537 Metetra
.689 .735 .886 r
.65217 .37537 .6542 .37807 .65833 .37639 .65631 .37369 Metetra
.688 .735 .887 r
.65631 .37369 .65833 .37639 .66246 .37473 .66044 .37203 Metetra
.687 .735 .888 r
.66044 .37203 .66246 .37473 .6666 .37307 .66459 .37038 Metetra
.686 .736 .888 r
.66459 .37038 .6666 .37307 .67075 .37143 .66874 .36874 Metetra
.685 .736 .889 r
.66874 .36874 .67075 .37143 .6749 .36979 .6729 .3671 Metetra
.684 .736 .89 r
.6729 .3671 .6749 .36979 .67906 .36817 .67706 .36548 Metetra
.684 .736 .891 r
.67706 .36548 .67906 .36817 .68322 .36655 .68123 .36386 Metetra
.683 .736 .891 r
.68123 .36386 .68322 .36655 .68739 .36494 .6854 .36225 Metetra
.682 .737 .892 r
.6854 .36225 .68739 .36494 .69157 .36333 .68958 .36065 Metetra
.682 .737 .892 r
.68958 .36065 .69157 .36333 .69575 .36173 .69377 .35905 Metetra
.681 .737 .893 r
.69377 .35905 .69575 .36173 .69993 .36014 .69796 .35746 Metetra
.68 .737 .893 r
.69796 .35746 .69993 .36014 .70413 .35855 .70216 .35587 Metetra
.68 .737 .894 r
.70216 .35587 .70413 .35855 .70833 .35697 .70636 .35429 Metetra
.679 .737 .894 r
.70636 .35429 .70833 .35697 .71253 .35539 .71057 .35271 Metetra
.679 .737 .895 r
.71057 .35271 .71253 .35539 .71675 .35382 .71479 .35114 Metetra
.678 .738 .895 r
.71479 .35114 .71675 .35382 .72096 .35225 .71901 .34957 Metetra
.678 .738 .896 r
.71901 .34957 .72096 .35225 .72519 .35068 .72324 .348 Metetra
.678 .738 .896 r
.72324 .348 .72519 .35068 .72942 .34912 .72747 .34644 Metetra
.677 .738 .896 r
.72747 .34644 .72942 .34912 .73366 .34756 .73171 .34488 Metetra
.677 .738 .897 r
.73171 .34488 .73366 .34756 .7379 .346 .73596 .34332 Metetra
.676 .738 .897 r
.73596 .34332 .7379 .346 .74215 .34445 .74022 .34176 Metetra
.676 .738 .897 r
.74022 .34176 .74215 .34445 .7464 .3429 .74448 .34021 Metetra
.676 .738 .898 r
.74448 .34021 .7464 .3429 .75066 .34135 .74874 .33866 Metetra
.675 .738 .898 r
.74874 .33866 .75066 .34135 .75493 .3398 .75301 .33711 Metetra
.675 .738 .898 r
.75301 .33711 .75493 .3398 .75921 .33825 .75729 .33556 Metetra
.675 .738 .898 r
.75729 .33556 .75921 .33825 .76349 .33671 .76158 .33401 Metetra
.674 .739 .899 r
.76158 .33401 .76349 .33671 .76777 .33516 .76587 .33247 Metetra
.674 .739 .899 r
.76587 .33247 .76777 .33516 .77207 .33362 .77017 .33092 Metetra
.674 .739 .899 r
.77017 .33092 .77207 .33362 .77637 .33208 .77447 .32938 Metetra
.674 .739 .899 r
.77447 .32938 .77637 .33208 .78067 .33054 .77878 .32784 Metetra
.673 .739 .9 r
.77878 .32784 .78067 .33054 .78498 .329 .7831 .32629 Metetra
.673 .739 .9 r
.7831 .32629 .78498 .329 .7893 .32746 .78742 .32475 Metetra
.96 .769 .602 r
.78742 .32475 .7893 .32746 .79363 .32592 .79072 .31108 Metetra
.592 .433 .635 r
.79072 .31108 .79363 .32592 .79796 .32439 .79505 .30965 Metetra
.592 .434 .636 r
.79505 .30965 .79796 .32439 .80124 .31086 .79938 .30821 Metetra
.664 .741 .907 r
.79938 .30821 .80124 .31086 .80557 .30943 .80372 .30678 Metetra
.664 .741 .907 r
.80372 .30678 .80557 .30943 .80992 .30799 .80807 .30534 Metetra
.664 .741 .907 r
.80807 .30534 .80992 .30799 .81427 .30656 .81243 .3039 Metetra
.664 .741 .907 r
.81243 .3039 .81427 .30656 .81862 .30512 .81679 .30246 Metetra
.664 .741 .907 r
.81679 .30246 .81862 .30512 .82299 .30368 .82115 .30101 Metetra
.664 .741 .907 r
.82115 .30101 .82299 .30368 .82735 .30224 .82553 .29957 Metetra
.664 .741 .907 r
.82553 .29957 .82735 .30224 .83173 .30079 .82991 .29812 Metetra
.664 .741 .907 r
.82991 .29812 .83173 .30079 .83611 .29935 .8343 .29667 Metetra
.664 .741 .907 r
.8343 .29667 .83611 .29935 .8405 .2979 .83869 .29522 Metetra
.664 .741 .907 r
.83869 .29522 .8405 .2979 .8449 .29645 .84309 .29376 Metetra
.664 .741 .907 r
.84309 .29376 .8449 .29645 .8493 .29499 .8475 .2923 Metetra
.664 .741 .907 r
.8475 .2923 .8493 .29499 .85371 .29354 .85191 .29084 Metetra
.664 .741 .907 r
.85191 .29084 .85371 .29354 .85812 .29208 .85633 .28938 Metetra
.664 .741 .907 r
.85633 .28938 .85812 .29208 .86255 .29062 .86076 .28792 Metetra
.664 .741 .907 r
.86076 .28792 .86255 .29062 .86698 .28916 .86519 .28645 Metetra
.664 .741 .907 r
.86519 .28645 .86698 .28916 .87141 .28769 .86963 .28498 Metetra
.664 .741 .907 r
.86963 .28498 .87141 .28769 .87585 .28623 .87408 .28351 Metetra
.664 .741 .907 r
.27609 .47829 .27844 .48048 .28204 .47929 .27969 .4771 Metetra
.664 .741 .907 r
.27969 .4771 .28204 .47929 .28563 .47811 .28329 .4759 Metetra
.664 .741 .907 r
.28329 .4759 .28563 .47811 .28924 .47691 .2869 .47471 Metetra
.664 .741 .907 r
.2869 .47471 .28924 .47691 .29285 .47572 .29051 .47351 Metetra
.664 .741 .907 r
.29051 .47351 .29285 .47572 .29646 .47453 .29412 .47232 Metetra
.664 .741 .907 r
.29412 .47232 .29646 .47453 .30008 .47333 .29774 .47112 Metetra
.664 .741 .907 r
.29774 .47112 .30008 .47333 .3037 .47213 .30137 .46992 Metetra
.664 .741 .907 r
.30137 .46992 .3037 .47213 .30733 .47093 .305 .46871 Metetra
.664 .741 .907 r
.305 .46871 .30733 .47093 .31096 .46973 .30863 .46751 Metetra
.664 .741 .907 r
.30863 .46751 .31096 .46973 .3146 .46853 .31228 .4663 Metetra
.664 .741 .907 r
.31228 .4663 .3146 .46853 .31824 .46732 .31592 .4651 Metetra
.664 .741 .907 r
.31592 .4651 .31824 .46732 .32189 .46612 .31957 .46389 Metetra
.664 .741 .907 r
.31957 .46389 .32189 .46612 .32554 .46491 .32323 .46267 Metetra
.664 .741 .907 r
.32323 .46267 .32554 .46491 .3292 .4637 .32689 .46146 Metetra
.664 .741 .907 r
.32689 .46146 .3292 .4637 .33286 .46249 .33055 .46025 Metetra
.664 .741 .907 r
.33055 .46025 .33286 .46249 .33653 .46128 .33422 .45903 Metetra
.664 .741 .907 r
.33422 .45903 .33653 .46128 .3402 .46006 .3379 .45781 Metetra
.664 .741 .907 r
.3379 .45781 .3402 .46006 .34388 .45884 .34158 .45659 Metetra
.664 .741 .907 r
.34158 .45659 .34388 .45884 .34756 .45763 .34527 .45537 Metetra
.664 .741 .907 r
.34527 .45537 .34756 .45763 .35062 .46824 .34896 .45415 Metetra
.045 .037 .523 r
.34896 .45415 .35062 .46824 .35432 .46714 .35203 .46481 Metetra
.651 .732 .908 r
.35203 .46481 .35432 .46714 .35803 .46604 .35574 .4637 Metetra
.651 .731 .908 r
.35574 .4637 .35803 .46604 .36174 .46493 .35945 .46259 Metetra
.651 .731 .908 r
.35945 .46259 .36174 .46493 .36545 .46383 .36317 .46149 Metetra
.65 .731 .908 r
.36317 .46149 .36545 .46383 .36918 .46274 .3669 .46038 Metetra
.65 .731 .908 r
.3669 .46038 .36918 .46274 .3729 .46164 .37063 .45928 Metetra
.65 .73 .908 r
.37063 .45928 .3729 .46164 .37663 .46054 .37436 .45818 Metetra
.649 .73 .908 r
.37436 .45818 .37663 .46054 .38037 .45945 .3781 .45708 Metetra
.649 .73 .908 r
.3781 .45708 .38037 .45945 .38411 .45836 .38185 .45599 Metetra
.649 .729 .908 r
.38185 .45599 .38411 .45836 .38786 .45727 .3856 .45489 Metetra
.648 .729 .908 r
.3856 .45489 .38786 .45727 .39162 .45618 .38936 .4538 Metetra
.648 .729 .908 r
.38936 .4538 .39162 .45618 .39538 .4551 .39312 .45271 Metetra
.647 .728 .908 r
.39312 .45271 .39538 .4551 .39914 .45402 .39689 .45162 Metetra
.647 .728 .908 r
.39689 .45162 .39914 .45402 .40291 .45294 .40066 .45054 Metetra
.646 .728 .908 r
.40066 .45054 .40291 .45294 .40669 .45187 .40444 .44946 Metetra
.646 .727 .908 r
.40444 .44946 .40669 .45187 .41047 .4508 .40822 .44838 Metetra
.645 .727 .908 r
.40822 .44838 .41047 .4508 .41425 .44973 .41201 .44731 Metetra
.645 .726 .908 r
.41201 .44731 .41425 .44973 .41805 .44867 .41581 .44624 Metetra
.644 .726 .908 r
.41581 .44624 .41805 .44867 .42184 .44761 .41961 .44517 Metetra
.644 .725 .908 r
.41961 .44517 .42184 .44761 .42565 .44655 .42342 .44411 Metetra
.643 .725 .908 r
.42342 .44411 .42565 .44655 .42946 .4455 .42723 .44306 Metetra
.642 .724 .908 r
.42723 .44306 .42946 .4455 .43327 .44446 .43105 .44201 Metetra
.641 .723 .908 r
.43105 .44201 .43327 .44446 .43709 .44342 .43487 .44096 Metetra
.641 .723 .908 r
.43487 .44096 .43709 .44342 .44092 .44239 .4387 .43992 Metetra
.64 .722 .908 r
.4387 .43992 .44092 .44239 .44475 .44137 .44253 .43889 Metetra
.639 .721 .908 r
.44253 .43889 .44475 .44137 .44859 .44035 .44637 .43786 Metetra
.638 .721 .908 r
.44637 .43786 .44859 .44035 .45243 .43934 .45022 .43685 Metetra
.637 .72 .908 r
.45022 .43685 .45243 .43934 .45628 .43834 .45407 .43584 Metetra
.636 .719 .908 r
.45407 .43584 .45628 .43834 .46013 .43735 .45793 .43484 Metetra
.635 .718 .907 r
.45793 .43484 .46013 .43735 .46399 .43637 .4618 .43384 Metetra
.634 .717 .907 r
.4618 .43384 .46399 .43637 .46786 .4354 .46567 .43286 Metetra
.632 .716 .907 r
.46567 .43286 .46786 .4354 .47173 .43444 .46954 .43189 Metetra
.631 .715 .907 r
.46954 .43189 .47173 .43444 .47561 .4335 .47342 .43094 Metetra
.629 .714 .907 r
.47342 .43094 .47561 .4335 .4795 .43256 .47731 .42999 Metetra
.628 .712 .907 r
.47731 .42999 .4795 .43256 .48339 .43165 .48121 .42906 Metetra
.626 .711 .907 r
.48121 .42906 .48339 .43165 .48729 .43075 .48511 .42815 Metetra
.624 .709 .907 r
.48511 .42815 .48729 .43075 .49119 .42987 .48902 .42726 Metetra
.622 .707 .907 r
.48902 .42726 .49119 .42987 .4951 .42901 .49293 .42638 Metetra
.62 .706 .907 r
.49293 .42638 .4951 .42901 .49902 .42817 .49685 .42552 Metetra
.617 .704 .907 r
.49685 .42552 .49902 .42817 .50294 .42735 .50077 .42469 Metetra
.614 .701 .906 r
.50077 .42469 .50294 .42735 .50687 .42656 .50471 .42388 Metetra
.963 .682 .454 r
.50471 .42388 .50687 .42656 .51081 .4258 .50762 .62728 Metetra
.548 .328 .532 r
.50762 .62728 .51081 .4258 .51412 .6283 .51182 .62606 Metetra
.645 .763 .934 r
.51182 .62606 .51412 .6283 .51831 .62709 .51602 .62484 Metetra
.951 .736 .577 r
.51602 .62484 .51831 .62709 .52252 .62079 .52026 .60147 Metetra
.789 .561 .591 r
.52026 .60147 .52252 .62079 .52671 .59223 .52445 .57873 Metetra
.787 .574 .612 r
.52445 .57873 .52671 .59223 .53086 .57397 .52861 .56339 Metetra
.78 .583 .634 r
.52861 .56339 .53086 .57397 .53499 .56118 .53274 .5523 Metetra
.768 .589 .655 r
.53274 .5523 .53499 .56118 .53911 .55174 .53687 .54393 Metetra
.754 .591 .675 r
.53687 .54393 .53911 .55174 .54323 .54458 .54099 .53746 Metetra
.736 .591 .694 r
.54099 .53746 .54323 .54458 .54735 .53908 .54512 .53242 Metetra
.715 .588 .712 r
.54512 .53242 .54735 .53908 .55148 .53488 .54925 .52853 Metetra
.691 .581 .727 r
.54925 .52853 .55148 .53488 .55562 .53176 .55339 .52559 Metetra
.662 .569 .74 r
.55339 .52559 .55562 .53176 .55977 .52959 .55754 .5235 Metetra
.628 .552 .75 r
.55754 .5235 .55977 .52959 .56393 .52832 .5617 .52223 Metetra
.586 .529 .758 r
.5617 .52223 .56393 .52832 .56811 .52795 .56588 .52176 Metetra
.536 .498 .76 r
.56588 .52176 .56811 .52795 .57231 .52854 .57008 .52216 Metetra
.473 .455 .757 r
.57008 .52216 .57231 .52854 .57654 .53021 .5743 .52351 Metetra
.393 .397 .745 r
.5743 .52351 .57654 .53021 .58081 .53319 .57855 .52602 Metetra
.29 .319 .719 r
.57855 .52602 .58081 .53319 .58512 .53784 .58285 .52996 Metetra
.158 .215 .673 r
.58285 .52996 .58512 .53784 .5895 .54479 .5872 .53583 Metetra
0 .081 .597 r
.5872 .53583 .5895 .54479 .59398 .55512 .59163 .54444 Metetra
0 0 .484 r
.59163 .54444 .59398 .55512 .59861 .57099 .59618 .55734 Metetra
0 0 .335 r
.59618 .55734 .59861 .57099 .60353 .59725 .60095 .57773 Metetra
0 0 .462 r
.60095 .57773 .60353 .59725 .60799 .60112 .60579 .5988 Metetra
.645 .763 .934 r
.60579 .5988 .60799 .60112 .61233 .59986 .61013 .59754 Metetra
.645 .763 .934 r
.61013 .59754 .61233 .59986 .61116 .39303 .61449 .59627 Metetra
0 0 .378 r
.61449 .59627 .61116 .39303 .61524 .39116 .61317 .38838 Metetra
.7 .731 .874 r
.61317 .38838 .61524 .39116 .61932 .38932 .61725 .38655 Metetra
.699 .731 .876 r
.61725 .38655 .61932 .38932 .62341 .3875 .62135 .38475 Metetra
.697 .732 .878 r
.62135 .38475 .62341 .3875 .6275 .38571 .62544 .38297 Metetra
.695 .732 .879 r
.62544 .38297 .6275 .38571 .6316 .38395 .62954 .38121 Metetra
.694 .733 .881 r
.62954 .38121 .6316 .38395 .6357 .3822 .63365 .37947 Metetra
.693 .733 .882 r
.63365 .37947 .6357 .3822 .63981 .38047 .63777 .37774 Metetra
.691 .734 .883 r
.63777 .37774 .63981 .38047 .64393 .37875 .64189 .37603 Metetra
.69 .734 .884 r
.64189 .37603 .64393 .37875 .64805 .37705 .64601 .37434 Metetra
.689 .734 .885 r
.64601 .37434 .64805 .37705 .65217 .37537 .65014 .37266 Metetra
.688 .735 .886 r
.65014 .37266 .65217 .37537 .65631 .37369 .65428 .37099 Metetra
.687 .735 .887 r
.65428 .37099 .65631 .37369 .66044 .37203 .65842 .36933 Metetra
.686 .735 .888 r
.65842 .36933 .66044 .37203 .66459 .37038 .66257 .36768 Metetra
.685 .736 .889 r
.66257 .36768 .66459 .37038 .66874 .36874 .66673 .36604 Metetra
.685 .736 .89 r
.66673 .36604 .66874 .36874 .6729 .3671 .67089 .36441 Metetra
.684 .736 .89 r
.67089 .36441 .6729 .3671 .67706 .36548 .67505 .36279 Metetra
.683 .736 .891 r
.67505 .36279 .67706 .36548 .68123 .36386 .67923 .36117 Metetra
.682 .736 .892 r
.67923 .36117 .68123 .36386 .6854 .36225 .6834 .35956 Metetra
.682 .737 .892 r
.6834 .35956 .6854 .36225 .68958 .36065 .68759 .35796 Metetra
.681 .737 .893 r
.68759 .35796 .68958 .36065 .69377 .35905 .69178 .35636 Metetra
.681 .737 .893 r
.69178 .35636 .69377 .35905 .69796 .35746 .69598 .35477 Metetra
.68 .737 .894 r
.69598 .35477 .69796 .35746 .70216 .35587 .70018 .35319 Metetra
.68 .737 .894 r
.70018 .35319 .70216 .35587 .70636 .35429 .70439 .3516 Metetra
.679 .737 .895 r
.70439 .3516 .70636 .35429 .71057 .35271 .7086 .35002 Metetra
.679 .737 .895 r
.7086 .35002 .71057 .35271 .71479 .35114 .71282 .34845 Metetra
.678 .738 .895 r
.71282 .34845 .71479 .35114 .71901 .34957 .71705 .34688 Metetra
.678 .738 .896 r
.71705 .34688 .71901 .34957 .72324 .348 .72128 .34531 Metetra
.677 .738 .896 r
.72128 .34531 .72324 .348 .72747 .34644 .72552 .34375 Metetra
.677 .738 .897 r
.72552 .34375 .72747 .34644 .73171 .34488 .72977 .34218 Metetra
.677 .738 .897 r
.72977 .34218 .73171 .34488 .73596 .34332 .73402 .34062 Metetra
.676 .738 .897 r
.73402 .34062 .73596 .34332 .74022 .34176 .73828 .33907 Metetra
.676 .738 .897 r
.73828 .33907 .74022 .34176 .74448 .34021 .74254 .33751 Metetra
.675 .738 .898 r
.74254 .33751 .74448 .34021 .74874 .33866 .74681 .33596 Metetra
.675 .738 .898 r
.74681 .33596 .74874 .33866 .75301 .33711 .75109 .33441 Metetra
.675 .738 .898 r
.75109 .33441 .75301 .33711 .75729 .33556 .75537 .33286 Metetra
.675 .738 .899 r
.75537 .33286 .75729 .33556 .76158 .33401 .75966 .33131 Metetra
.674 .739 .899 r
.75966 .33131 .76158 .33401 .76587 .33247 .76396 .32976 Metetra
.674 .739 .899 r
.76396 .32976 .76587 .33247 .77017 .33092 .76826 .32822 Metetra
.674 .739 .899 r
.76826 .32822 .77017 .33092 .77447 .32938 .77257 .32667 Metetra
.674 .739 .899 r
.77257 .32667 .77447 .32938 .77878 .32784 .77688 .32513 Metetra
.673 .739 .9 r
.77688 .32513 .77878 .32784 .7831 .32629 .78121 .32358 Metetra
.959 .769 .602 r
.78121 .32358 .7831 .32629 .78742 .32475 .78453 .30987 Metetra
.591 .432 .635 r
.78453 .30987 .78742 .32475 .79072 .31108 .78885 .30843 Metetra
.664 .741 .907 r
.78885 .30843 .79072 .31108 .79505 .30965 .79318 .307 Metetra
.664 .741 .907 r
.79318 .307 .79505 .30965 .79938 .30821 .79752 .30556 Metetra
.664 .741 .907 r
.79752 .30556 .79938 .30821 .80372 .30678 .80187 .30412 Metetra
.664 .741 .907 r
.80187 .30412 .80372 .30678 .80807 .30534 .80622 .30268 Metetra
.664 .741 .907 r
.80622 .30268 .80807 .30534 .81243 .3039 .81058 .30124 Metetra
.664 .741 .907 r
.81058 .30124 .81243 .3039 .81679 .30246 .81495 .29979 Metetra
.664 .741 .907 r
.81495 .29979 .81679 .30246 .82115 .30101 .81932 .29834 Metetra
.664 .741 .907 r
.81932 .29834 .82115 .30101 .82553 .29957 .8237 .29689 Metetra
.664 .741 .907 r
.8237 .29689 .82553 .29957 .82991 .29812 .82808 .29544 Metetra
.664 .741 .907 r
.82808 .29544 .82991 .29812 .8343 .29667 .83247 .29398 Metetra
.664 .741 .907 r
.83247 .29398 .8343 .29667 .83869 .29522 .83687 .29253 Metetra
.664 .741 .907 r
.83687 .29253 .83869 .29522 .84309 .29376 .84128 .29107 Metetra
.664 .741 .907 r
.84128 .29107 .84309 .29376 .8475 .2923 .84569 .28961 Metetra
.664 .741 .907 r
.84569 .28961 .8475 .2923 .85191 .29084 .85011 .28814 Metetra
.664 .741 .907 r
.85011 .28814 .85191 .29084 .85633 .28938 .85453 .28668 Metetra
.664 .741 .907 r
.85453 .28668 .85633 .28938 .86076 .28792 .85896 .28521 Metetra
.664 .741 .907 r
.85896 .28521 .86076 .28792 .86519 .28645 .8634 .28374 Metetra
.664 .741 .907 r
.8634 .28374 .86519 .28645 .86963 .28498 .86785 .28227 Metetra
.664 .741 .907 r
.86785 .28227 .86963 .28498 .87408 .28351 .8723 .28079 Metetra
.664 .741 .907 r
.27374 .47609 .27609 .47829 .27969 .4771 .27734 .47489 Metetra
.664 .741 .907 r
.27734 .47489 .27969 .4771 .28329 .4759 .28094 .4737 Metetra
.664 .741 .907 r
.28094 .4737 .28329 .4759 .2869 .47471 .28455 .4725 Metetra
.664 .741 .907 r
.28455 .4725 .2869 .47471 .29051 .47351 .28816 .4713 Metetra
.664 .741 .907 r
.28816 .4713 .29051 .47351 .29412 .47232 .29178 .4701 Metetra
.664 .741 .907 r
.29178 .4701 .29412 .47232 .29774 .47112 .2954 .4689 Metetra
.664 .741 .907 r
.2954 .4689 .29774 .47112 .30137 .46992 .29903 .46769 Metetra
.664 .741 .907 r
.29903 .46769 .30137 .46992 .305 .46871 .30267 .46649 Metetra
.664 .741 .907 r
.30267 .46649 .305 .46871 .30863 .46751 .30631 .46528 Metetra
.664 .741 .907 r
.30631 .46528 .30863 .46751 .31228 .4663 .30995 .46407 Metetra
.664 .741 .907 r
.30995 .46407 .31228 .4663 .31592 .4651 .3136 .46286 Metetra
.664 .741 .907 r
.3136 .46286 .31592 .4651 .31957 .46389 .31725 .46165 Metetra
.664 .741 .907 r
.31725 .46165 .31957 .46389 .32323 .46267 .32091 .46043 Metetra
.664 .741 .907 r
.32091 .46043 .32323 .46267 .32689 .46146 .32457 .45922 Metetra
.664 .741 .907 r
.32457 .45922 .32689 .46146 .33055 .46025 .32824 .458 Metetra
.664 .741 .907 r
.32824 .458 .33055 .46025 .33422 .45903 .33192 .45678 Metetra
.664 .741 .907 r
.33192 .45678 .33422 .45903 .3379 .45781 .3356 .45556 Metetra
.664 .741 .907 r
.3356 .45556 .3379 .45781 .34158 .45659 .33928 .45434 Metetra
.664 .741 .907 r
.33928 .45434 .34158 .45659 .34527 .45537 .34297 .45312 Metetra
.664 .741 .907 r
.34297 .45312 .34527 .45537 .34896 .45415 .34666 .45189 Metetra
.664 .741 .907 r
.34666 .45189 .34896 .45415 .35203 .46481 .35036 .45066 Metetra
.044 .036 .522 r
.35036 .45066 .35203 .46481 .35574 .4637 .35345 .46136 Metetra
.651 .731 .908 r
.35345 .46136 .35574 .4637 .35945 .46259 .35716 .46025 Metetra
.651 .731 .908 r
.35716 .46025 .35945 .46259 .36317 .46149 .36088 .45914 Metetra
.651 .731 .908 r
.36088 .45914 .36317 .46149 .3669 .46038 .36461 .45803 Metetra
.65 .731 .908 r
.36461 .45803 .3669 .46038 .37063 .45928 .36835 .45692 Metetra
.65 .73 .908 r
.36835 .45692 .37063 .45928 .37436 .45818 .37208 .45581 Metetra
.65 .73 .908 r
.37208 .45581 .37436 .45818 .3781 .45708 .37583 .45471 Metetra
.649 .73 .908 r
.37583 .45471 .3781 .45708 .38185 .45599 .37958 .45361 Metetra
.649 .73 .908 r
.37958 .45361 .38185 .45599 .3856 .45489 .38333 .45251 Metetra
.648 .729 .908 r
.38333 .45251 .3856 .45489 .38936 .4538 .38709 .45141 Metetra
.648 .729 .908 r
.38709 .45141 .38936 .4538 .39312 .45271 .39086 .45032 Metetra
.648 .728 .908 r
.39086 .45032 .39312 .45271 .39689 .45162 .39463 .44922 Metetra
.647 .728 .908 r
.39463 .44922 .39689 .45162 .40066 .45054 .3984 .44813 Metetra
.647 .728 .908 r
.3984 .44813 .40066 .45054 .40444 .44946 .40219 .44705 Metetra
.646 .727 .908 r
.40219 .44705 .40444 .44946 .40822 .44838 .40597 .44596 Metetra
.646 .727 .908 r
.40597 .44596 .40822 .44838 .41201 .44731 .40977 .44488 Metetra
.645 .726 .908 r
.40977 .44488 .41201 .44731 .41581 .44624 .41357 .44381 Metetra
.645 .726 .908 r
.41357 .44381 .41581 .44624 .41961 .44517 .41737 .44274 Metetra
.644 .725 .908 r
.41737 .44274 .41961 .44517 .42342 .44411 .42118 .44167 Metetra
.643 .725 .908 r
.42118 .44167 .42342 .44411 .42723 .44306 .42499 .4406 Metetra
.643 .724 .908 r
.42499 .4406 .42723 .44306 .43105 .44201 .42882 .43955 Metetra
.642 .724 .908 r
.42882 .43955 .43105 .44201 .43487 .44096 .43264 .43849 Metetra
.641 .723 .908 r
.43264 .43849 .43487 .44096 .4387 .43992 .43647 .43745 Metetra
.64 .722 .908 r
.43647 .43745 .4387 .43992 .44253 .43889 .44031 .43641 Metetra
.639 .722 .908 r
.44031 .43641 .44253 .43889 .44637 .43786 .44416 .43537 Metetra
.639 .721 .908 r
.44416 .43537 .44637 .43786 .45022 .43685 .44801 .43435 Metetra
.638 .72 .908 r
.44801 .43435 .45022 .43685 .45407 .43584 .45186 .43333 Metetra
.637 .719 .907 r
.45186 .43333 .45407 .43584 .45793 .43484 .45572 .43232 Metetra
.635 .718 .907 r
.45572 .43232 .45793 .43484 .4618 .43384 .45959 .43132 Metetra
.634 .718 .907 r
.45959 .43132 .4618 .43384 .46567 .43286 .46347 .43033 Metetra
.633 .716 .907 r
.46347 .43033 .46567 .43286 .46954 .43189 .46734 .42935 Metetra
.632 .715 .907 r
.46734 .42935 .46954 .43189 .47342 .43094 .47123 .42838 Metetra
.63 .714 .907 r
.47123 .42838 .47342 .43094 .47731 .42999 .47512 .42742 Metetra
.629 .713 .907 r
.47512 .42742 .47731 .42999 .48121 .42906 .47902 .42648 Metetra
.627 .711 .907 r
.47902 .42648 .48121 .42906 .48511 .42815 .48292 .42555 Metetra
.625 .71 .907 r
.48292 .42555 .48511 .42815 .48902 .42726 .48683 .42464 Metetra
.623 .708 .907 r
.48683 .42464 .48902 .42726 .49293 .42638 .49075 .42375 Metetra
.621 .707 .907 r
.49075 .42375 .49293 .42638 .49685 .42552 .49467 .42288 Metetra
.618 .705 .906 r
.49467 .42288 .49685 .42552 .50077 .42469 .4986 .42203 Metetra
.616 .702 .906 r
.4986 .42203 .50077 .42469 .50471 .42388 .50254 .4212 Metetra
.963 .682 .454 r
.50254 .4212 .50471 .42388 .50762 .62728 .50532 .62503 Metetra
.645 .763 .934 r
.50532 .62503 .50762 .62728 .51182 .62606 .50952 .62381 Metetra
.913 .775 .695 r
.50952 .62381 .51182 .62606 .51602 .62484 .51375 .61455 Metetra
.881 .646 .579 r
.51375 .61455 .51602 .62484 .52026 .60147 .51801 .58545 Metetra
.788 .567 .601 r
.51801 .58545 .52026 .60147 .52445 .57873 .5222 .56684 Metetra
.784 .579 .622 r
.5222 .56684 .52445 .57873 .52861 .56339 .52636 .55376 Metetra
.776 .587 .644 r
.52636 .55376 .52861 .56339 .53274 .5523 .53049 .54402 Metetra
.764 .592 .665 r
.53049 .54402 .53274 .5523 .53687 .54393 .53462 .53653 Metetra
.75 .595 .684 r
.53462 .53653 .53687 .54393 .54099 .53746 .53875 .53066 Metetra
.732 .594 .702 r
.53875 .53066 .54099 .53746 .54512 .53242 .54288 .52602 Metetra
.712 .591 .719 r
.54288 .52602 .54512 .53242 .54925 .52853 .54701 .52239 Metetra
.688 .584 .733 r
.54701 .52239 .54925 .52853 .55339 .52559 .55116 .5196 Metetra
.661 .573 .746 r
.55116 .5196 .55339 .52559 .55754 .5235 .55531 .51759 Metetra
.629 .558 .756 r
.55531 .51759 .55754 .5235 .5617 .52223 .55947 .51631 Metetra
.591 .537 .763 r
.55947 .51631 .5617 .52223 .56588 .52176 .56365 .51577 Metetra
.545 .508 .766 r
.56365 .51577 .56588 .52176 .57008 .52216 .56784 .51599 Metetra
.488 .47 .764 r
.56784 .51599 .57008 .52216 .5743 .52351 .57206 .51708 Metetra
.417 .42 .754 r
.57206 .51708 .5743 .52351 .57855 .52602 .5763 .51917 Metetra
.327 .351 .734 r
.5763 .51917 .57855 .52602 .58285 .52996 .58058 .52251 Metetra
.211 .261 .696 r
.58058 .52251 .58285 .52996 .5872 .53583 .58491 .52748 Metetra
.065 .142 .635 r
.58491 .52748 .5872 .53583 .59163 .54444 .58931 .53471 Metetra
0 0 .541 r
.58931 .53471 .59163 .54444 .59618 .55734 .5938 .54534 Metetra
0 0 .41 r
.5938 .54534 .59618 .55734 .60095 .57773 .59845 .56155 Metetra
0 0 .25 r
.59845 .56155 .60095 .57773 .60579 .5988 .60339 .58837 Metetra
.227 .223 .646 r
.60339 .58837 .60579 .5988 .61013 .59754 .60793 .5952 Metetra
.645 .763 .934 r
.60793 .5952 .61013 .59754 .61449 .59627 .61229 .59394 Metetra
.971 .693 .448 r
.61229 .59394 .61449 .59627 .61317 .38838 .61109 .3856 Metetra
.699 .731 .875 r
.61109 .3856 .61317 .38838 .61725 .38655 .61518 .38379 Metetra
.698 .732 .877 r
.61518 .38379 .61725 .38655 .62135 .38475 .61928 .38199 Metetra
.696 .732 .878 r
.61928 .38199 .62135 .38475 .62544 .38297 .62338 .38022 Metetra
.695 .733 .88 r
.62338 .38022 .62544 .38297 .62954 .38121 .62749 .37847 Metetra
.693 .733 .881 r
.62749 .37847 .62954 .38121 .63365 .37947 .6316 .37674 Metetra
.692 .733 .882 r
.6316 .37674 .63365 .37947 .63777 .37774 .63572 .37502 Metetra
.691 .734 .884 r
.63572 .37502 .63777 .37774 .64189 .37603 .63984 .37331 Metetra
.69 .734 .885 r
.63984 .37331 .64189 .37603 .64601 .37434 .64397 .37163 Metetra
.689 .735 .886 r
.64397 .37163 .64601 .37434 .65014 .37266 .64811 .36995 Metetra
.688 .735 .887 r
.64811 .36995 .65014 .37266 .65428 .37099 .65225 .36828 Metetra
.687 .735 .888 r
.65225 .36828 .65428 .37099 .65842 .36933 .6564 .36663 Metetra
.686 .735 .888 r
.6564 .36663 .65842 .36933 .66257 .36768 .66055 .36498 Metetra
.685 .736 .889 r
.66055 .36498 .66257 .36768 .66673 .36604 .66471 .36334 Metetra
.684 .736 .89 r
.66471 .36334 .66673 .36604 .67089 .36441 .66887 .36171 Metetra
.683 .736 .891 r
.66887 .36171 .67089 .36441 .67505 .36279 .67304 .36009 Metetra
.683 .736 .891 r
.67304 .36009 .67505 .36279 .67923 .36117 .67722 .35848 Metetra
.682 .736 .892 r
.67722 .35848 .67923 .36117 .6834 .35956 .6814 .35687 Metetra
.681 .737 .892 r
.6814 .35687 .6834 .35956 .68759 .35796 .68559 .35527 Metetra
.681 .737 .893 r
.68559 .35527 .68759 .35796 .69178 .35636 .68979 .35367 Metetra
.68 .737 .893 r
.68979 .35367 .69178 .35636 .69598 .35477 .69399 .35208 Metetra
.68 .737 .894 r
.69399 .35208 .69598 .35477 .70018 .35319 .6982 .35049 Metetra
.679 .737 .894 r
.6982 .35049 .70018 .35319 .70439 .3516 .70241 .34891 Metetra
.679 .737 .895 r
.70241 .34891 .70439 .3516 .7086 .35002 .70663 .34733 Metetra
.678 .737 .895 r
.70663 .34733 .7086 .35002 .71282 .34845 .71085 .34576 Metetra
.678 .738 .896 r
.71085 .34576 .71282 .34845 .71705 .34688 .71509 .34419 Metetra
.677 .738 .896 r
.71509 .34419 .71705 .34688 .72128 .34531 .71932 .34262 Metetra
.677 .738 .896 r
.71932 .34262 .72128 .34531 .72552 .34375 .72357 .34105 Metetra
.677 .738 .897 r
.72357 .34105 .72552 .34375 .72977 .34218 .72782 .33949 Metetra
.676 .738 .897 r
.72782 .33949 .72977 .34218 .73402 .34062 .73207 .33793 Metetra
.676 .738 .897 r
.73207 .33793 .73402 .34062 .73828 .33907 .73634 .33637 Metetra
.676 .738 .898 r
.73634 .33637 .73828 .33907 .74254 .33751 .74061 .33481 Metetra
.675 .738 .898 r
.74061 .33481 .74254 .33751 .74681 .33596 .74488 .33326 Metetra
.675 .738 .898 r
.74488 .33326 .74681 .33596 .75109 .33441 .74916 .3317 Metetra
.675 .738 .898 r
.74916 .3317 .75109 .33441 .75537 .33286 .75345 .33015 Metetra
.674 .738 .899 r
.75345 .33015 .75537 .33286 .75966 .33131 .75774 .3286 Metetra
.674 .739 .899 r
.75774 .3286 .75966 .33131 .76396 .32976 .76204 .32705 Metetra
.674 .739 .899 r
.76204 .32705 .76396 .32976 .76826 .32822 .76635 .3255 Metetra
.674 .739 .899 r
.76635 .3255 .76826 .32822 .77257 .32667 .77066 .32396 Metetra
.673 .739 .9 r
.77066 .32396 .77257 .32667 .77688 .32513 .77498 .32241 Metetra
.959 .768 .602 r
.77498 .32241 .77688 .32513 .78121 .32358 .77832 .30866 Metetra
.591 .432 .634 r
.77832 .30866 .78121 .32358 .78453 .30987 .78265 .30722 Metetra
.664 .741 .907 r
.78265 .30722 .78453 .30987 .78885 .30843 .78698 .30578 Metetra
.664 .741 .907 r
.78698 .30578 .78885 .30843 .79318 .307 .79131 .30434 Metetra
.664 .741 .907 r
.79131 .30434 .79318 .307 .79752 .30556 .79566 .3029 Metetra
.664 .741 .907 r
.79566 .3029 .79752 .30556 .80187 .30412 .80001 .30146 Metetra
.664 .741 .907 r
.80001 .30146 .80187 .30412 .80622 .30268 .80437 .30001 Metetra
.664 .741 .907 r
.80437 .30001 .80622 .30268 .81058 .30124 .80873 .29857 Metetra
.664 .741 .907 r
.80873 .29857 .81058 .30124 .81495 .29979 .8131 .29712 Metetra
.664 .741 .907 r
.8131 .29712 .81495 .29979 .81932 .29834 .81748 .29566 Metetra
.664 .741 .907 r
.81748 .29566 .81932 .29834 .8237 .29689 .82186 .29421 Metetra
.664 .741 .907 r
.82186 .29421 .8237 .29689 .82808 .29544 .82625 .29275 Metetra
.664 .741 .907 r
.82625 .29275 .82808 .29544 .83247 .29398 .83065 .29129 Metetra
.664 .741 .907 r
.83065 .29129 .83247 .29398 .83687 .29253 .83505 .28983 Metetra
.664 .741 .907 r
.83505 .28983 .83687 .29253 .84128 .29107 .83946 .28837 Metetra
.664 .741 .907 r
.83946 .28837 .84128 .29107 .84569 .28961 .84388 .2869 Metetra
.664 .741 .907 r
.84388 .2869 .84569 .28961 .85011 .28814 .8483 .28544 Metetra
.664 .741 .907 r
.8483 .28544 .85011 .28814 .85453 .28668 .85273 .28396 Metetra
.664 .741 .907 r
.85273 .28396 .85453 .28668 .85896 .28521 .85717 .28249 Metetra
.664 .741 .907 r
.85717 .28249 .85896 .28521 .8634 .28374 .86161 .28102 Metetra
.664 .741 .907 r
.86161 .28102 .8634 .28374 .86785 .28227 .86606 .27954 Metetra
.664 .741 .907 r
.86606 .27954 .86785 .28227 .8723 .28079 .87052 .27806 Metetra
.664 .741 .907 r
.27138 .47388 .27374 .47609 .27734 .47489 .27498 .47268 Metetra
.664 .741 .907 r
.27498 .47268 .27734 .47489 .28094 .4737 .27858 .47149 Metetra
.664 .741 .907 r
.27858 .47149 .28094 .4737 .28455 .4725 .2822 .47029 Metetra
.664 .741 .907 r
.2822 .47029 .28455 .4725 .28816 .4713 .28581 .46908 Metetra
.664 .741 .907 r
.28581 .46908 .28816 .4713 .29178 .4701 .28943 .46788 Metetra
.664 .741 .907 r
.28943 .46788 .29178 .4701 .2954 .4689 .29306 .46667 Metetra
.664 .741 .907 r
.29306 .46667 .2954 .4689 .29903 .46769 .29669 .46547 Metetra
.664 .741 .907 r
.29669 .46547 .29903 .46769 .30267 .46649 .30033 .46426 Metetra
.664 .741 .907 r
.30033 .46426 .30267 .46649 .30631 .46528 .30397 .46305 Metetra
.664 .741 .907 r
.30397 .46305 .30631 .46528 .30995 .46407 .30762 .46184 Metetra
.664 .741 .907 r
.30762 .46184 .30995 .46407 .3136 .46286 .31127 .46062 Metetra
.664 .741 .907 r
.31127 .46062 .3136 .46286 .31725 .46165 .31493 .45941 Metetra
.664 .741 .907 r
.31493 .45941 .31725 .46165 .32091 .46043 .31859 .45819 Metetra
.664 .741 .907 r
.31859 .45819 .32091 .46043 .32457 .45922 .32225 .45697 Metetra
.664 .741 .907 r
.32225 .45697 .32457 .45922 .32824 .458 .32593 .45575 Metetra
.664 .741 .907 r
.32593 .45575 .32824 .458 .33192 .45678 .3296 .45453 Metetra
.664 .741 .907 r
.3296 .45453 .33192 .45678 .3356 .45556 .33329 .4533 Metetra
.664 .741 .907 r
.33329 .4533 .3356 .45556 .33928 .45434 .33697 .45208 Metetra
.664 .741 .907 r
.33697 .45208 .33928 .45434 .34297 .45312 .34067 .45085 Metetra
.664 .741 .907 r
.34067 .45085 .34297 .45312 .34666 .45189 .34436 .44962 Metetra
.664 .741 .907 r
.34436 .44962 .34666 .45189 .35036 .45066 .34807 .44839 Metetra
.664 .741 .907 r
.34807 .44839 .35036 .45066 .35345 .46136 .35177 .44716 Metetra
.044 .036 .521 r
.35177 .44716 .35345 .46136 .35716 .46025 .35487 .45789 Metetra
.651 .731 .908 r
.35487 .45789 .35716 .46025 .36088 .45914 .35859 .45678 Metetra
.651 .731 .908 r
.35859 .45678 .36088 .45914 .36461 .45803 .36232 .45567 Metetra
.651 .731 .908 r
.36232 .45567 .36461 .45803 .36835 .45692 .36606 .45455 Metetra
.65 .731 .908 r
.36606 .45455 .36835 .45692 .37208 .45581 .3698 .45344 Metetra
.65 .73 .908 r
.3698 .45344 .37208 .45581 .37583 .45471 .37355 .45233 Metetra
.649 .73 .908 r
.37355 .45233 .37583 .45471 .37958 .45361 .3773 .45123 Metetra
.649 .73 .908 r
.3773 .45123 .37958 .45361 .38333 .45251 .38106 .45012 Metetra
.649 .729 .908 r
.38106 .45012 .38333 .45251 .38709 .45141 .38482 .44902 Metetra
.648 .729 .908 r
.38482 .44902 .38709 .45141 .39086 .45032 .38859 .44792 Metetra
.648 .729 .908 r
.38859 .44792 .39086 .45032 .39463 .44922 .39236 .44682 Metetra
.647 .728 .908 r
.39236 .44682 .39463 .44922 .3984 .44813 .39614 .44572 Metetra
.647 .728 .908 r
.39614 .44572 .3984 .44813 .40219 .44705 .39993 .44463 Metetra
.647 .728 .908 r
.39993 .44463 .40219 .44705 .40597 .44596 .40372 .44354 Metetra
.646 .727 .908 r
.40372 .44354 .40597 .44596 .40977 .44488 .40751 .44245 Metetra
.645 .727 .908 r
.40751 .44245 .40977 .44488 .41357 .44381 .41132 .44137 Metetra
.645 .726 .908 r
.41132 .44137 .41357 .44381 .41737 .44274 .41512 .44029 Metetra
.644 .726 .908 r
.41512 .44029 .41737 .44274 .42118 .44167 .41894 .43922 Metetra
.644 .725 .908 r
.41894 .43922 .42118 .44167 .42499 .4406 .42276 .43815 Metetra
.643 .725 .908 r
.42276 .43815 .42499 .4406 .42882 .43955 .42658 .43708 Metetra
.642 .724 .908 r
.42658 .43708 .42882 .43955 .43264 .43849 .43041 .43602 Metetra
.642 .723 .908 r
.43041 .43602 .43264 .43849 .43647 .43745 .43425 .43497 Metetra
.641 .723 .908 r
.43425 .43497 .43647 .43745 .44031 .43641 .43809 .43392 Metetra
.64 .722 .908 r
.43809 .43392 .44031 .43641 .44416 .43537 .44193 .43288 Metetra
.639 .721 .908 r
.44193 .43288 .44416 .43537 .44801 .43435 .44579 .43184 Metetra
.638 .721 .907 r
.44579 .43184 .44801 .43435 .45186 .43333 .44965 .43081 Metetra
.637 .72 .907 r
.44965 .43081 .45186 .43333 .45572 .43232 .45351 .42979 Metetra
.636 .719 .907 r
.45351 .42979 .45572 .43232 .45959 .43132 .45738 .42878 Metetra
.635 .718 .907 r
.45738 .42878 .45959 .43132 .46347 .43033 .46126 .42778 Metetra
.634 .717 .907 r
.46126 .42778 .46347 .43033 .46734 .42935 .46514 .42679 Metetra
.632 .716 .907 r
.46514 .42679 .46734 .42935 .47123 .42838 .46903 .42581 Metetra
.631 .715 .907 r
.46903 .42581 .47123 .42838 .47512 .42742 .47292 .42485 Metetra
.63 .714 .907 r
.47292 .42485 .47512 .42742 .47902 .42648 .47683 .42389 Metetra
.628 .712 .907 r
.47683 .42389 .47902 .42648 .48292 .42555 .48073 .42295 Metetra
.626 .711 .907 r
.48073 .42295 .48292 .42555 .48683 .42464 .48465 .42203 Metetra
.624 .709 .907 r
.48465 .42203 .48683 .42464 .49075 .42375 .48857 .42112 Metetra
.622 .707 .907 r
.48857 .42112 .49075 .42375 .49467 .42288 .49249 .42024 Metetra
.62 .706 .906 r
.49249 .42024 .49467 .42288 .4986 .42203 .49642 .41937 Metetra
.962 .682 .456 r
.49642 .41937 .4986 .42203 .50254 .4212 .49881 .62399 Metetra
.547 .326 .531 r
.49881 .62399 .50254 .4212 .50532 .62503 .50301 .62277 Metetra
.645 .763 .934 r
.50301 .62277 .50532 .62503 .50952 .62381 .50721 .62155 Metetra
.953 .731 .565 r
.50721 .62155 .50952 .62381 .51375 .61455 .51152 .59479 Metetra
.787 .559 .59 r
.51152 .59479 .51375 .61455 .51801 .58545 .51577 .57177 Metetra
.787 .573 .611 r
.51577 .57177 .51801 .58545 .5222 .56684 .51995 .55621 Metetra
.781 .584 .633 r
.51995 .55621 .5222 .56684 .52636 .55376 .52411 .54489 Metetra
.772 .591 .654 r
.52411 .54489 .52636 .55376 .53049 .54402 .52825 .53627 Metetra
.76 .596 .674 r
.52825 .53627 .53049 .54402 .53462 .53653 .53238 .52951 Metetra
.745 .598 .693 r
.53238 .52951 .53462 .53653 .53875 .53066 .53651 .52414 Metetra
.728 .597 .71 r
.53651 .52414 .53875 .53066 .54288 .52602 .54065 .51985 Metetra
.709 .594 .726 r
.54065 .51985 .54288 .52602 .54701 .52239 .54478 .51644 Metetra
.686 .588 .74 r
.54478 .51644 .54701 .52239 .55116 .5196 .54892 .5138 Metetra
.66 .578 .751 r
.54892 .5138 .55116 .5196 .55531 .51759 .55308 .51185 Metetra
.631 .564 .761 r
.55308 .51185 .55531 .51759 .55947 .51631 .55724 .51057 Metetra
.595 .544 .767 r
.55724 .51057 .55947 .51631 .56365 .51577 .56141 .50995 Metetra
.553 .519 .771 r
.56141 .50995 .56365 .51577 .56784 .51599 .56561 .51002 Metetra
.502 .484 .77 r
.56561 .51002 .56784 .51599 .57206 .51708 .56982 .51087 Metetra
.439 .439 .763 r
.56982 .51087 .57206 .51708 .5763 .51917 .57406 .5126 Metetra
.359 .38 .746 r
.57406 .5126 .5763 .51917 .58058 .52251 .57832 .51543 Metetra
.258 .301 .716 r
.57832 .51543 .58058 .52251 .58491 .52748 .58263 .51965 Metetra
.129 .197 .666 r
.58263 .51965 .58491 .52748 .58931 .53471 .587 .52576 Metetra
0 .065 .589 r
.587 .52576 .58931 .53471 .5938 .54534 .59144 .53459 Metetra
0 0 .477 r
.59144 .53459 .5938 .54534 .59845 .56155 .59601 .54771 Metetra
0 0 .333 r
.59601 .54771 .59845 .56155 .60339 .58837 .60079 .56838 Metetra
0 0 .407 r
.60079 .56838 .60339 .58837 .60793 .5952 .60572 .59286 Metetra
.645 .763 .934 r
.60572 .59286 .60793 .5952 .61229 .59394 .61009 .59159 Metetra
.645 .763 .934 r
.61009 .59159 .61229 .59394 .61109 .3856 .61446 .59032 Metetra
0 0 .377 r
.61446 .59032 .61109 .3856 .61518 .38379 .61311 .38102 Metetra
.697 .732 .878 r
.61311 .38102 .61518 .38379 .61928 .38199 .61721 .37924 Metetra
.695 .732 .879 r
.61721 .37924 .61928 .38199 .62338 .38022 .62131 .37747 Metetra
.694 .733 .881 r
.62131 .37747 .62338 .38022 .62749 .37847 .62542 .37573 Metetra
.692 .733 .882 r
.62542 .37573 .62749 .37847 .6316 .37674 .62954 .374 Metetra
.691 .734 .883 r
.62954 .374 .6316 .37674 .63572 .37502 .63366 .37229 Metetra
.69 .734 .884 r
.63366 .37229 .63572 .37502 .63984 .37331 .63779 .37059 Metetra
.689 .734 .885 r
.63779 .37059 .63984 .37331 .64397 .37163 .64193 .36891 Metetra
.688 .735 .886 r
.64193 .36891 .64397 .37163 .64811 .36995 .64607 .36723 Metetra
.687 .735 .887 r
.64607 .36723 .64811 .36995 .65225 .36828 .65021 .36557 Metetra
.686 .735 .888 r
.65021 .36557 .65225 .36828 .6564 .36663 .65436 .36392 Metetra
.685 .735 .889 r
.65436 .36392 .6564 .36663 .66055 .36498 .65852 .36227 Metetra
.685 .736 .89 r
.65852 .36227 .66055 .36498 .66471 .36334 .66268 .36064 Metetra
.684 .736 .89 r
.66268 .36064 .66471 .36334 .66887 .36171 .66685 .35901 Metetra
.683 .736 .891 r
.66685 .35901 .66887 .36171 .67304 .36009 .67103 .35739 Metetra
.682 .736 .892 r
.67103 .35739 .67304 .36009 .67722 .35848 .67521 .35578 Metetra
.682 .736 .892 r
.67521 .35578 .67722 .35848 .6814 .35687 .6794 .35417 Metetra
.681 .737 .893 r
.6794 .35417 .6814 .35687 .68559 .35527 .68359 .35257 Metetra
.681 .737 .893 r
.68359 .35257 .68559 .35527 .68979 .35367 .68779 .35097 Metetra
.68 .737 .894 r
.68779 .35097 .68979 .35367 .69399 .35208 .692 .34938 Metetra
.679 .737 .894 r
.692 .34938 .69399 .35208 .6982 .35049 .69621 .3478 Metetra
.679 .737 .895 r
.69621 .3478 .6982 .35049 .70241 .34891 .70043 .34621 Metetra
.679 .737 .895 r
.70043 .34621 .70241 .34891 .70663 .34733 .70465 .34463 Metetra
.678 .737 .895 r
.70465 .34463 .70663 .34733 .71085 .34576 .70888 .34306 Metetra
.678 .738 .896 r
.70888 .34306 .71085 .34576 .71509 .34419 .71311 .34149 Metetra
.677 .738 .896 r
.71311 .34149 .71509 .34419 .71932 .34262 .71736 .33992 Metetra
.677 .738 .897 r
.71736 .33992 .71932 .34262 .72357 .34105 .72161 .33835 Metetra
.676 .738 .897 r
.72161 .33835 .72357 .34105 .72782 .33949 .72586 .33678 Metetra
.676 .738 .897 r
.72586 .33678 .72782 .33949 .73207 .33793 .73012 .33522 Metetra
.676 .738 .897 r
.73012 .33522 .73207 .33793 .73634 .33637 .73439 .33366 Metetra
.675 .738 .898 r
.73439 .33366 .73634 .33637 .74061 .33481 .73866 .3321 Metetra
.675 .738 .898 r
.73866 .3321 .74061 .33481 .74488 .33326 .74294 .33055 Metetra
.675 .738 .898 r
.74294 .33055 .74488 .33326 .74916 .3317 .74723 .32899 Metetra
.675 .738 .899 r
.74723 .32899 .74916 .3317 .75345 .33015 .75152 .32744 Metetra
.674 .738 .899 r
.75152 .32744 .75345 .33015 .75774 .3286 .75582 .32589 Metetra
.674 .739 .899 r
.75582 .32589 .75774 .3286 .76204 .32705 .76012 .32433 Metetra
.674 .739 .899 r
.76012 .32433 .76204 .32705 .76635 .3255 .76444 .32278 Metetra
.673 .739 .899 r
.76444 .32278 .76635 .3255 .77066 .32396 .76875 .32123 Metetra
.959 .768 .603 r
.76875 .32123 .77066 .32396 .77498 .32241 .77211 .30744 Metetra
.591 .431 .634 r
.77211 .30744 .77498 .32241 .77832 .30866 .77643 .306 Metetra
.664 .741 .907 r
.77643 .306 .77832 .30866 .78265 .30722 .78076 .30457 Metetra
.664 .741 .907 r
.78076 .30457 .78265 .30722 .78698 .30578 .7851 .30312 Metetra
.664 .741 .907 r
.7851 .30312 .78698 .30578 .79131 .30434 .78944 .30168 Metetra
.664 .741 .907 r
.78944 .30168 .79131 .30434 .79566 .3029 .79379 .30024 Metetra
.664 .741 .907 r
.79379 .30024 .79566 .3029 .80001 .30146 .79814 .29879 Metetra
.664 .741 .907 r
.79814 .29879 .80001 .30146 .80437 .30001 .8025 .29734 Metetra
.664 .741 .907 r
.8025 .29734 .80437 .30001 .80873 .29857 .80687 .29589 Metetra
.664 .741 .907 r
.80687 .29589 .80873 .29857 .8131 .29712 .81125 .29443 Metetra
.664 .741 .907 r
.81125 .29443 .8131 .29712 .81748 .29566 .81563 .29298 Metetra
.664 .741 .907 r
.81563 .29298 .81748 .29566 .82186 .29421 .82002 .29152 Metetra
.664 .741 .907 r
.82002 .29152 .82186 .29421 .82625 .29275 .82441 .29006 Metetra
.664 .741 .907 r
.82441 .29006 .82625 .29275 .83065 .29129 .82881 .28859 Metetra
.664 .741 .907 r
.82881 .28859 .83065 .29129 .83505 .28983 .83322 .28713 Metetra
.664 .741 .907 r
.83322 .28713 .83505 .28983 .83946 .28837 .83764 .28566 Metetra
.664 .741 .907 r
.83764 .28566 .83946 .28837 .84388 .2869 .84206 .28419 Metetra
.664 .741 .907 r
.84206 .28419 .84388 .2869 .8483 .28544 .84649 .28272 Metetra
.664 .741 .907 r
.84649 .28272 .8483 .28544 .85273 .28396 .85092 .28125 Metetra
.664 .741 .907 r
.85092 .28125 .85273 .28396 .85717 .28249 .85536 .27977 Metetra
.664 .741 .907 r
.85536 .27977 .85717 .28249 .86161 .28102 .85981 .27829 Metetra
.664 .741 .907 r
.85981 .27829 .86161 .28102 .86606 .27954 .86427 .27681 Metetra
.664 .741 .907 r
.86427 .27681 .86606 .27954 .87052 .27806 .86873 .27533 Metetra
.664 .741 .907 r
.26901 .47167 .27138 .47388 .27498 .47268 .27261 .47047 Metetra
.664 .741 .907 r
.27261 .47047 .27498 .47268 .27858 .47149 .27622 .46927 Metetra
.664 .741 .907 r
.27622 .46927 .27858 .47149 .2822 .47029 .27984 .46806 Metetra
.664 .741 .907 r
.27984 .46806 .2822 .47029 .28581 .46908 .28346 .46686 Metetra
.664 .741 .907 r
.28346 .46686 .28581 .46908 .28943 .46788 .28708 .46565 Metetra
.664 .741 .907 r
.28708 .46565 .28943 .46788 .29306 .46667 .29071 .46444 Metetra
.664 .741 .907 r
.29071 .46444 .29306 .46667 .29669 .46547 .29435 .46323 Metetra
.664 .741 .907 r
.29435 .46323 .29669 .46547 .30033 .46426 .29798 .46202 Metetra
.664 .741 .907 r
.29798 .46202 .30033 .46426 .30397 .46305 .30163 .46081 Metetra
.664 .741 .907 r
.30163 .46081 .30397 .46305 .30762 .46184 .30528 .45959 Metetra
.664 .741 .907 r
.30528 .45959 .30762 .46184 .31127 .46062 .30893 .45838 Metetra
.664 .741 .907 r
.30893 .45838 .31127 .46062 .31493 .45941 .31259 .45716 Metetra
.664 .741 .907 r
.31259 .45716 .31493 .45941 .31859 .45819 .31626 .45594 Metetra
.664 .741 .907 r
.31626 .45594 .31859 .45819 .32225 .45697 .31993 .45472 Metetra
.664 .741 .907 r
.31993 .45472 .32225 .45697 .32593 .45575 .3236 .45349 Metetra
.664 .741 .907 r
.3236 .45349 .32593 .45575 .3296 .45453 .32728 .45227 Metetra
.664 .741 .907 r
.32728 .45227 .3296 .45453 .33329 .4533 .33097 .45104 Metetra
.664 .741 .907 r
.33097 .45104 .33329 .4533 .33697 .45208 .33466 .44981 Metetra
.664 .741 .907 r
.33466 .44981 .33697 .45208 .34067 .45085 .33835 .44858 Metetra
.664 .741 .907 r
.33835 .44858 .34067 .45085 .34436 .44962 .34206 .44735 Metetra
.664 .741 .907 r
.34206 .44735 .34436 .44962 .34807 .44839 .34576 .44611 Metetra
.664 .741 .907 r
.34576 .44611 .34807 .44839 .35177 .44716 .34947 .44488 Metetra
.664 .741 .907 r
.34947 .44488 .35177 .44716 .35487 .45789 .35319 .44364 Metetra
.043 .035 .521 r
.35319 .44364 .35487 .45789 .35859 .45678 .35629 .45442 Metetra
.651 .731 .908 r
.35629 .45442 .35859 .45678 .36232 .45567 .36003 .4533 Metetra
.651 .731 .908 r
.36003 .4533 .36232 .45567 .36606 .45455 .36377 .45218 Metetra
.65 .731 .908 r
.36377 .45218 .36606 .45455 .3698 .45344 .36751 .45106 Metetra
.65 .73 .908 r
.36751 .45106 .3698 .45344 .37355 .45233 .37126 .44995 Metetra
.65 .73 .908 r
.37126 .44995 .37355 .45233 .3773 .45123 .37502 .44884 Metetra
.649 .73 .908 r
.37502 .44884 .3773 .45123 .38106 .45012 .37878 .44773 Metetra
.649 .729 .908 r
.37878 .44773 .38106 .45012 .38482 .44902 .38254 .44662 Metetra
.649 .729 .908 r
.38254 .44662 .38482 .44902 .38859 .44792 .38631 .44551 Metetra
.648 .729 .908 r
.38631 .44551 .38859 .44792 .39236 .44682 .39009 .44441 Metetra
.648 .728 .908 r
.39009 .44441 .39236 .44682 .39614 .44572 .39387 .44331 Metetra
.647 .728 .908 r
.39387 .44331 .39614 .44572 .39993 .44463 .39766 .44221 Metetra
.647 .728 .908 r
.39766 .44221 .39993 .44463 .40372 .44354 .40146 .44111 Metetra
.646 .727 .908 r
.40146 .44111 .40372 .44354 .40751 .44245 .40526 .44002 Metetra
.646 .727 .908 r
.40526 .44002 .40751 .44245 .41132 .44137 .40906 .43893 Metetra
.645 .726 .908 r
.40906 .43893 .41132 .44137 .41512 .44029 .41287 .43784 Metetra
.645 .726 .908 r
.41287 .43784 .41512 .44029 .41894 .43922 .41669 .43676 Metetra
.644 .725 .908 r
.41669 .43676 .41894 .43922 .42276 .43815 .42051 .43569 Metetra
.643 .725 .908 r
.42051 .43569 .42276 .43815 .42658 .43708 .42434 .43461 Metetra
.643 .724 .908 r
.42434 .43461 .42658 .43708 .43041 .43602 .42817 .43355 Metetra
.642 .724 .908 r
.42817 .43355 .43041 .43602 .43425 .43497 .43201 .43248 Metetra
.641 .723 .908 r
.43201 .43248 .43425 .43497 .43809 .43392 .43585 .43143 Metetra
.64 .722 .908 r
.43585 .43143 .43809 .43392 .44193 .43288 .43971 .43038 Metetra
.64 .722 .907 r
.43971 .43038 .44193 .43288 .44579 .43184 .44356 .42933 Metetra
.639 .721 .907 r
.44356 .42933 .44579 .43184 .44965 .43081 .44742 .4283 Metetra
.638 .72 .907 r
.44742 .4283 .44965 .43081 .45351 .42979 .45129 .42727 Metetra
.637 .719 .907 r
.45129 .42727 .45351 .42979 .45738 .42878 .45517 .42625 Metetra
.636 .718 .907 r
.45517 .42625 .45738 .42878 .46126 .42778 .45905 .42524 Metetra
.634 .717 .907 r
.45905 .42524 .46126 .42778 .46514 .42679 .46293 .42424 Metetra
.633 .716 .907 r
.46293 .42424 .46514 .42679 .46903 .42581 .46682 .42325 Metetra
.632 .715 .907 r
.46682 .42325 .46903 .42581 .47292 .42485 .47072 .42227 Metetra
.63 .714 .907 r
.47072 .42227 .47292 .42485 .47683 .42389 .47463 .4213 Metetra
.629 .713 .907 r
.47463 .4213 .47683 .42389 .48073 .42295 .47854 .42035 Metetra
.627 .711 .907 r
.47854 .42035 .48073 .42295 .48465 .42203 .48245 .41941 Metetra
.625 .71 .907 r
.48245 .41941 .48465 .42203 .48857 .42112 .48638 .41849 Metetra
.623 .708 .907 r
.48638 .41849 .48857 .42112 .49249 .42024 .49031 .41759 Metetra
.621 .706 .906 r
.49031 .41759 .49249 .42024 .49642 .41937 .49424 .41671 Metetra
.962 .682 .456 r
.49424 .41671 .49642 .41937 .49881 .62399 .49649 .62174 Metetra
.645 .763 .934 r
.49649 .62174 .49881 .62399 .50301 .62277 .50069 .62051 Metetra
.93 .761 .65 r
.50069 .62051 .50301 .62277 .50721 .62155 .50496 .60784 Metetra
.854 .619 .581 r
.50496 .60784 .50721 .62155 .51152 .59479 .50929 .57856 Metetra
.788 .566 .6 r
.50929 .57856 .51152 .59479 .51577 .57177 .51352 .55981 Metetra
.785 .579 .621 r
.51352 .55981 .51577 .57177 .51995 .55621 .51771 .54657 Metetra
.778 .588 .643 r
.51771 .54657 .51995 .55621 .52411 .54489 .52186 .53665 Metetra
.768 .595 .663 r
.52186 .53665 .52411 .54489 .52825 .53627 .52601 .52895 Metetra
.756 .599 .683 r
.52601 .52895 .52825 .53627 .53238 .52951 .53014 .52282 Metetra
.741 .601 .701 r
.53014 .52282 .53238 .52951 .53651 .52414 .53428 .51787 Metetra
.725 .601 .718 r
.53428 .51787 .53651 .52414 .54065 .51985 .53841 .51388 Metetra
.706 .597 .732 r
.53841 .51388 .54065 .51985 .54478 .51644 .54255 .51067 Metetra
.684 .591 .746 r
.54255 .51067 .54478 .51644 .54892 .5138 .54669 .50816 Metetra
.66 .582 .757 r
.54669 .50816 .54892 .5138 .55308 .51185 .55085 .50627 Metetra
.632 .569 .766 r
.55085 .50627 .55308 .51185 .55724 .51057 .55501 .50498 Metetra
.599 .551 .772 r
.55501 .50498 .55724 .51057 .56141 .50995 .55918 .50429 Metetra
.561 .528 .776 r
.55918 .50429 .56141 .50995 .56561 .51002 .56337 .50423 Metetra
.514 .497 .775 r
.56337 .50423 .56561 .51002 .56982 .51087 .56758 .50486 Metetra
.458 .457 .77 r
.56758 .50486 .56982 .51087 .57406 .5126 .57181 .50629 Metetra
.387 .405 .757 r
.57181 .50629 .57406 .5126 .57832 .51543 .57607 .50868 Metetra
.298 .336 .733 r
.57607 .50868 .57832 .51543 .58263 .51965 .58036 .51226 Metetra
.185 .245 .692 r
.58036 .51226 .58263 .51965 .587 .52576 .58471 .51743 Metetra
.044 .129 .629 r
.58471 .51743 .587 .52576 .59144 .53459 .58911 .52484 Metetra
0 0 .535 r
.58911 .52484 .59144 .53459 .59601 .54771 .59362 .53561 Metetra
0 0 .408 r
.59362 .53561 .59601 .54771 .60079 .56838 .59828 .55196 Metetra
0 0 .253 r
.59828 .55196 .60079 .56838 .60572 .59286 .60324 .57896 Metetra
.166 .147 .59 r
.60324 .57896 .60572 .59286 .61009 .59159 .60788 .58924 Metetra
.645 .763 .934 r
.60788 .58924 .61009 .59159 .61446 .59032 .61225 .58797 Metetra
.971 .693 .447 r
.61225 .58797 .61446 .59032 .61311 .38102 .61103 .37825 Metetra
.696 .732 .878 r
.61103 .37825 .61311 .38102 .61721 .37924 .61513 .37648 Metetra
.694 .732 .88 r
.61513 .37648 .61721 .37924 .62131 .37747 .61924 .37472 Metetra
.693 .733 .881 r
.61924 .37472 .62131 .37747 .62542 .37573 .62336 .37299 Metetra
.692 .733 .882 r
.62336 .37299 .62542 .37573 .62954 .374 .62748 .37126 Metetra
.691 .734 .884 r
.62748 .37126 .62954 .374 .63366 .37229 .6316 .36956 Metetra
.689 .734 .885 r
.6316 .36956 .63366 .37229 .63779 .37059 .63574 .36786 Metetra
.688 .734 .886 r
.63574 .36786 .63779 .37059 .64193 .36891 .63988 .36618 Metetra
.687 .735 .887 r
.63988 .36618 .64193 .36891 .64607 .36723 .64402 .36451 Metetra
.687 .735 .888 r
.64402 .36451 .64607 .36723 .65021 .36557 .64817 .36285 Metetra
.686 .735 .888 r
.64817 .36285 .65021 .36557 .65436 .36392 .65233 .3612 Metetra
.685 .735 .889 r
.65233 .3612 .65436 .36392 .65852 .36227 .65649 .35956 Metetra
.684 .736 .89 r
.65649 .35956 .65852 .36227 .66268 .36064 .66066 .35793 Metetra
.683 .736 .891 r
.66066 .35793 .66268 .36064 .66685 .35901 .66483 .35631 Metetra
.683 .736 .891 r
.66483 .35631 .66685 .35901 .67103 .35739 .66901 .35469 Metetra
.682 .736 .892 r
.66901 .35469 .67103 .35739 .67521 .35578 .67319 .35307 Metetra
.681 .736 .892 r
.67319 .35307 .67521 .35578 .6794 .35417 .67739 .35147 Metetra
.681 .737 .893 r
.67739 .35147 .6794 .35417 .68359 .35257 .68158 .34987 Metetra
.68 .737 .893 r
.68158 .34987 .68359 .35257 .68779 .35097 .68579 .34827 Metetra
.68 .737 .894 r
.68579 .34827 .68779 .35097 .692 .34938 .69 .34668 Metetra
.679 .737 .894 r
.69 .34668 .692 .34938 .69621 .3478 .69421 .34509 Metetra
.679 .737 .895 r
.69421 .34509 .69621 .3478 .70043 .34621 .69844 .34351 Metetra
.678 .737 .895 r
.69844 .34351 .70043 .34621 .70465 .34463 .70266 .34193 Metetra
.678 .737 .896 r
.70266 .34193 .70465 .34463 .70888 .34306 .7069 .34035 Metetra
.677 .738 .896 r
.7069 .34035 .70888 .34306 .71311 .34149 .71114 .33878 Metetra
.677 .738 .896 r
.71114 .33878 .71311 .34149 .71736 .33992 .71539 .33721 Metetra
.677 .738 .897 r
.71539 .33721 .71736 .33992 .72161 .33835 .71964 .33564 Metetra
.676 .738 .897 r
.71964 .33564 .72161 .33835 .72586 .33678 .7239 .33408 Metetra
.676 .738 .897 r
.7239 .33408 .72586 .33678 .73012 .33522 .72816 .33251 Metetra
.676 .738 .898 r
.72816 .33251 .73012 .33522 .73439 .33366 .73244 .33095 Metetra
.675 .738 .898 r
.73244 .33095 .73439 .33366 .73866 .3321 .73671 .32939 Metetra
.675 .738 .898 r
.73671 .32939 .73866 .3321 .74294 .33055 .741 .32783 Metetra
.675 .738 .898 r
.741 .32783 .74294 .33055 .74723 .32899 .74529 .32628 Metetra
.674 .738 .899 r
.74529 .32628 .74723 .32899 .75152 .32744 .74959 .32472 Metetra
.674 .738 .899 r
.74959 .32472 .75152 .32744 .75582 .32589 .75389 .32317 Metetra
.674 .739 .899 r
.75389 .32317 .75582 .32589 .76012 .32433 .7582 .32161 Metetra
.674 .739 .899 r
.7582 .32161 .76012 .32433 .76444 .32278 .76252 .32006 Metetra
.958 .767 .603 r
.76252 .32006 .76444 .32278 .76875 .32123 .76589 .30623 Metetra
.59 .431 .633 r
.76589 .30623 .76875 .32123 .77211 .30744 .77021 .30479 Metetra
.664 .741 .907 r
.77021 .30479 .77211 .30744 .77643 .306 .77454 .30335 Metetra
.664 .741 .907 r
.77454 .30335 .77643 .306 .78076 .30457 .77887 .3019 Metetra
.664 .741 .907 r
.77887 .3019 .78076 .30457 .7851 .30312 .78321 .30046 Metetra
.664 .741 .907 r
.78321 .30046 .7851 .30312 .78944 .30168 .78756 .29901 Metetra
.664 .741 .907 r
.78756 .29901 .78944 .30168 .79379 .30024 .79191 .29756 Metetra
.664 .741 .907 r
.79191 .29756 .79379 .30024 .79814 .29879 .79627 .29611 Metetra
.664 .741 .907 r
.79627 .29611 .79814 .29879 .8025 .29734 .80064 .29466 Metetra
.664 .741 .907 r
.80064 .29466 .8025 .29734 .80687 .29589 .80501 .2932 Metetra
.664 .741 .907 r
.80501 .2932 .80687 .29589 .81125 .29443 .80939 .29174 Metetra
.664 .741 .907 r
.80939 .29174 .81125 .29443 .81563 .29298 .81378 .29028 Metetra
.664 .741 .907 r
.81378 .29028 .81563 .29298 .82002 .29152 .81817 .28882 Metetra
.664 .741 .907 r
.81817 .28882 .82002 .29152 .82441 .29006 .82257 .28735 Metetra
.664 .741 .907 r
.82257 .28735 .82441 .29006 .82881 .28859 .82698 .28589 Metetra
.664 .741 .907 r
.82698 .28589 .82881 .28859 .83322 .28713 .83139 .28442 Metetra
.664 .741 .907 r
.83139 .28442 .83322 .28713 .83764 .28566 .83581 .28295 Metetra
.664 .741 .907 r
.83581 .28295 .83764 .28566 .84206 .28419 .84023 .28147 Metetra
.664 .741 .907 r
.84023 .28147 .84206 .28419 .84649 .28272 .84467 .28 Metetra
.664 .741 .907 r
.84467 .28 .84649 .28272 .85092 .28125 .84911 .27852 Metetra
.664 .741 .907 r
.84911 .27852 .85092 .28125 .85536 .27977 .85355 .27704 Metetra
.664 .741 .907 r
.85355 .27704 .85536 .27977 .85981 .27829 .85801 .27555 Metetra
.664 .741 .907 r
.85801 .27555 .85981 .27829 .86427 .27681 .86247 .27407 Metetra
.664 .741 .907 r
.86247 .27407 .86427 .27681 .86873 .27533 .86693 .27258 Metetra
.664 .741 .907 r
.26663 .46945 .26901 .47167 .27261 .47047 .27024 .46825 Metetra
.664 .741 .907 r
.27024 .46825 .27261 .47047 .27622 .46927 .27385 .46705 Metetra
.664 .741 .907 r
.27385 .46705 .27622 .46927 .27984 .46806 .27747 .46584 Metetra
.664 .741 .907 r
.27747 .46584 .27984 .46806 .28346 .46686 .28109 .46463 Metetra
.664 .741 .907 r
.28109 .46463 .28346 .46686 .28708 .46565 .28472 .46342 Metetra
.664 .741 .907 r
.28472 .46342 .28708 .46565 .29071 .46444 .28835 .46221 Metetra
.664 .741 .907 r
.28835 .46221 .29071 .46444 .29435 .46323 .29199 .461 Metetra
.664 .741 .907 r
.29199 .461 .29435 .46323 .29798 .46202 .29563 .45978 Metetra
.664 .741 .907 r
.29563 .45978 .29798 .46202 .30163 .46081 .29928 .45856 Metetra
.664 .741 .907 r
.29928 .45856 .30163 .46081 .30528 .45959 .30294 .45735 Metetra
.664 .741 .907 r
.30294 .45735 .30528 .45959 .30893 .45838 .30659 .45613 Metetra
.664 .741 .907 r
.30659 .45613 .30893 .45838 .31259 .45716 .31026 .4549 Metetra
.664 .741 .907 r
.31026 .4549 .31259 .45716 .31626 .45594 .31392 .45368 Metetra
.664 .741 .907 r
.31392 .45368 .31626 .45594 .31993 .45472 .3176 .45246 Metetra
.664 .741 .907 r
.3176 .45246 .31993 .45472 .3236 .45349 .32128 .45123 Metetra
.664 .741 .907 r
.32128 .45123 .3236 .45349 .32728 .45227 .32496 .45 Metetra
.664 .741 .907 r
.32496 .45 .32728 .45227 .33097 .45104 .32865 .44877 Metetra
.664 .741 .907 r
.32865 .44877 .33097 .45104 .33466 .44981 .33234 .44754 Metetra
.664 .741 .907 r
.33234 .44754 .33466 .44981 .33835 .44858 .33604 .4463 Metetra
.664 .741 .907 r
.33604 .4463 .33835 .44858 .34206 .44735 .33974 .44507 Metetra
.664 .741 .907 r
.33974 .44507 .34206 .44735 .34576 .44611 .34345 .44383 Metetra
.664 .741 .907 r
.34345 .44383 .34576 .44611 .34947 .44488 .34717 .44259 Metetra
.664 .741 .907 r
.34717 .44259 .34947 .44488 .35319 .44364 .35089 .44135 Metetra
.664 .741 .907 r
.35089 .44135 .35319 .44364 .35629 .45442 .35461 .44011 Metetra
.59 .43 .633 r
.35461 .44011 .35629 .45442 .36003 .4533 .35834 .43887 Metetra
.043 .034 .52 r
.35834 .43887 .36003 .4533 .36377 .45218 .36147 .4498 Metetra
.651 .731 .908 r
.36147 .4498 .36377 .45218 .36751 .45106 .36521 .44868 Metetra
.65 .731 .908 r
.36521 .44868 .36751 .45106 .37126 .44995 .36897 .44756 Metetra
.65 .73 .908 r
.36897 .44756 .37126 .44995 .37502 .44884 .37273 .44644 Metetra
.65 .73 .908 r
.37273 .44644 .37502 .44884 .37878 .44773 .37649 .44533 Metetra
.649 .73 .908 r
.37649 .44533 .37878 .44773 .38254 .44662 .38026 .44421 Metetra
.649 .729 .908 r
.38026 .44421 .38254 .44662 .38631 .44551 .38403 .4431 Metetra
.648 .729 .908 r
.38403 .4431 .38631 .44551 .39009 .44441 .38782 .44199 Metetra
.648 .729 .908 r
.38782 .44199 .39009 .44441 .39387 .44331 .3916 .44088 Metetra
.648 .728 .908 r
.3916 .44088 .39387 .44331 .39766 .44221 .39539 .43978 Metetra
.647 .728 .908 r
.39539 .43978 .39766 .44221 .40146 .44111 .39919 .43868 Metetra
.647 .727 .908 r
.39919 .43868 .40146 .44111 .40526 .44002 .40299 .43758 Metetra
.646 .727 .908 r
.40299 .43758 .40526 .44002 .40906 .43893 .4068 .43648 Metetra
.646 .727 .908 r
.4068 .43648 .40906 .43893 .41287 .43784 .41061 .43539 Metetra
.645 .726 .908 r
.41061 .43539 .41287 .43784 .41669 .43676 .41443 .4343 Metetra
.644 .726 .908 r
.41443 .4343 .41669 .43676 .42051 .43569 .41826 .43322 Metetra
.644 .725 .908 r
.41826 .43322 .42051 .43569 .42434 .43461 .42209 .43214 Metetra
.643 .725 .908 r
.42209 .43214 .42434 .43461 .42817 .43355 .42593 .43106 Metetra
.642 .724 .908 r
.42593 .43106 .42817 .43355 .43201 .43248 .42977 .42999 Metetra
.642 .723 .908 r
.42977 .42999 .43201 .43248 .43585 .43143 .43362 .42893 Metetra
.641 .723 .907 r
.43362 .42893 .43585 .43143 .43971 .43038 .43747 .42787 Metetra
.64 .722 .907 r
.43747 .42787 .43971 .43038 .44356 .42933 .44133 .42682 Metetra
.639 .721 .907 r
.44133 .42682 .44356 .42933 .44742 .4283 .4452 .42578 Metetra
.638 .721 .907 r
.4452 .42578 .44742 .4283 .45129 .42727 .44907 .42474 Metetra
.637 .72 .907 r
.44907 .42474 .45129 .42727 .45517 .42625 .45294 .42371 Metetra
.636 .719 .907 r
.45294 .42371 .45517 .42625 .45905 .42524 .45683 .42269 Metetra
.635 .718 .907 r
.45683 .42269 .45905 .42524 .46293 .42424 .46072 .42168 Metetra
.634 .717 .907 r
.46072 .42168 .46293 .42424 .46682 .42325 .46461 .42068 Metetra
.633 .716 .907 r
.46461 .42068 .46682 .42325 .47072 .42227 .46851 .41969 Metetra
.631 .715 .907 r
.46851 .41969 .47072 .42227 .47463 .4213 .47242 .41871 Metetra
.63 .713 .907 r
.47242 .41871 .47463 .4213 .47854 .42035 .47634 .41774 Metetra
.628 .712 .907 r
.47634 .41774 .47854 .42035 .48245 .41941 .48025 .41679 Metetra
.626 .711 .907 r
.48025 .41679 .48245 .41941 .48638 .41849 .48418 .41586 Metetra
.625 .709 .907 r
.48418 .41586 .48638 .41849 .49031 .41759 .48811 .41494 Metetra
.962 .682 .457 r
.48811 .41494 .49031 .41759 .49424 .41671 .48996 .6207 Metetra
.546 .325 .53 r
.48996 .6207 .49424 .41671 .49649 .62174 .49416 .61947 Metetra
.645 .763 .934 r
.49416 .61947 .49649 .62174 .50069 .62051 .49836 .61824 Metetra
.954 .726 .555 r
.49836 .61824 .50069 .62051 .50496 .60784 .50276 .58782 Metetra
.786 .557 .59 r
.50276 .58782 .50496 .60784 .50929 .57856 .50706 .56478 Metetra
.787 .573 .611 r
.50706 .56478 .50929 .57856 .51352 .55981 .51128 .54916 Metetra
.782 .584 .632 r
.51128 .54916 .51352 .55981 .51771 .54657 .51546 .53772 Metetra
.775 .593 .653 r
.51546 .53772 .51771 .54657 .52186 .53665 .51962 .52895 Metetra
.764 .599 .673 r
.51962 .52895 .52186 .53665 .52601 .52895 .52377 .52201 Metetra
.752 .603 .692 r
.52377 .52201 .52601 .52895 .53014 .52282 .5279 .5164 Metetra
.737 .604 .709 r
.5279 .5164 .53014 .52282 .53428 .51787 .53204 .51184 Metetra
.721 .604 .725 r
.53204 .51184 .53428 .51787 .53841 .51388 .53618 .5081 Metetra
.703 .601 .739 r
.53618 .5081 .53841 .51388 .54255 .51067 .54032 .50507 Metetra
.682 .595 .751 r
.54032 .50507 .54255 .51067 .54669 .50816 .54446 .50266 Metetra
.659 .586 .762 r
.54446 .50266 .54669 .50816 .55085 .50627 .54861 .50082 Metetra
.633 .574 .77 r
.54861 .50082 .55085 .50627 .55501 .50498 .55278 .49953 Metetra
.603 .558 .777 r
.55278 .49953 .55501 .50498 .55918 .50429 .55695 .49878 Metetra
.568 .537 .78 r
.55695 .49878 .55918 .50429 .56337 .50423 .56114 .4986 Metetra
.526 .509 .781 r
.56114 .4986 .56337 .50423 .56758 .50486 .56534 .49905 Metetra
.475 .474 .776 r
.56534 .49905 .56758 .50486 .57181 .50629 .56957 .50021 Metetra
.412 .427 .766 r
.56957 .50021 .57181 .50629 .57607 .50868 .57382 .50221 Metetra
.333 .367 .747 r
.57382 .50221 .57607 .50868 .58036 .51226 .5781 .50525 Metetra
.234 .288 .714 r
.5781 .50525 .58036 .51226 .58471 .51743 .58242 .50965 Metetra
.11 .185 .662 r
.58242 .50965 .58471 .51743 .58911 .52484 .5868 .51589 Metetra
0 .057 .584 r
.5868 .51589 .58911 .52484 .59362 .53561 .59126 .52483 Metetra
0 0 .475 r
.59126 .52483 .59362 .53561 .59828 .55196 .59584 .53801 Metetra
0 0 .335 r
.59584 .53801 .59828 .55196 .60324 .57896 .60063 .5587 Metetra
0 0 .339 r
.60063 .5587 .60324 .57896 .60788 .58924 .60566 .58689 Metetra
.645 .763 .934 r
.60566 .58689 .60788 .58924 .61225 .58797 .61004 .58561 Metetra
.645 .763 .934 r
.61004 .58561 .61225 .58797 .61103 .37825 .61443 .58432 Metetra
0 0 .375 r
.61443 .58432 .61103 .37825 .61513 .37648 .61305 .37372 Metetra
.694 .732 .881 r
.61305 .37372 .61513 .37648 .61924 .37472 .61716 .37197 Metetra
.692 .733 .882 r
.61716 .37197 .61924 .37472 .62336 .37299 .62128 .37024 Metetra
.691 .733 .883 r
.62128 .37024 .62336 .37299 .62748 .37126 .62541 .36852 Metetra
.69 .734 .884 r
.62541 .36852 .62748 .37126 .6316 .36956 .62954 .36682 Metetra
.689 .734 .885 r
.62954 .36682 .6316 .36956 .63574 .36786 .63368 .36513 Metetra
.688 .734 .886 r
.63368 .36513 .63574 .36786 .63988 .36618 .63782 .36346 Metetra
.687 .735 .887 r
.63782 .36346 .63988 .36618 .64402 .36451 .64197 .36179 Metetra
.686 .735 .888 r
.64197 .36179 .64402 .36451 .64817 .36285 .64612 .36013 Metetra
.685 .735 .889 r
.64612 .36013 .64817 .36285 .65233 .3612 .65028 .35849 Metetra
.684 .736 .89 r
.65028 .35849 .65233 .3612 .65649 .35956 .65445 .35685 Metetra
.684 .736 .89 r
.65445 .35685 .65649 .35956 .66066 .35793 .65862 .35522 Metetra
.683 .736 .891 r
.65862 .35522 .66066 .35793 .66483 .35631 .6628 .35359 Metetra
.682 .736 .892 r
.6628 .35359 .66483 .35631 .66901 .35469 .66698 .35198 Metetra
.682 .736 .892 r
.66698 .35198 .66901 .35469 .67319 .35307 .67117 .35036 Metetra
.681 .737 .893 r
.67117 .35036 .67319 .35307 .67739 .35147 .67537 .34876 Metetra
.68 .737 .893 r
.67537 .34876 .67739 .35147 .68158 .34987 .67957 .34716 Metetra
.68 .737 .894 r
.67957 .34716 .68158 .34987 .68579 .34827 .68378 .34556 Metetra
.679 .737 .894 r
.68378 .34556 .68579 .34827 .69 .34668 .68799 .34397 Metetra
.679 .737 .895 r
.68799 .34397 .69 .34668 .69421 .34509 .69222 .34238 Metetra
.678 .737 .895 r
.69222 .34238 .69421 .34509 .69844 .34351 .69644 .3408 Metetra
.678 .737 .895 r
.69644 .3408 .69844 .34351 .70266 .34193 .70067 .33922 Metetra
.678 .737 .896 r
.70067 .33922 .70266 .34193 .7069 .34035 .70491 .33764 Metetra
.677 .738 .896 r
.70491 .33764 .7069 .34035 .71114 .33878 .70916 .33607 Metetra
.677 .738 .897 r
.70916 .33607 .71114 .33878 .71539 .33721 .71341 .3345 Metetra
.676 .738 .897 r
.71341 .3345 .71539 .33721 .71964 .33564 .71767 .33293 Metetra
.676 .738 .897 r
.71767 .33293 .71964 .33564 .7239 .33408 .72193 .33136 Metetra
.676 .738 .897 r
.72193 .33136 .7239 .33408 .72816 .33251 .7262 .32979 Metetra
.675 .738 .898 r
.7262 .32979 .72816 .33251 .73244 .33095 .73048 .32823 Metetra
.675 .738 .898 r
.73048 .32823 .73244 .33095 .73671 .32939 .73476 .32667 Metetra
.675 .738 .898 r
.73476 .32667 .73671 .32939 .741 .32783 .73905 .32511 Metetra
.674 .738 .899 r
.73905 .32511 .741 .32783 .74529 .32628 .74334 .32355 Metetra
.674 .738 .899 r
.74334 .32355 .74529 .32628 .74959 .32472 .74765 .32199 Metetra
.674 .738 .899 r
.74765 .32199 .74959 .32472 .75389 .32317 .75195 .32044 Metetra
.958 .766 .602 r
.75195 .32044 .75389 .32317 .7582 .32161 .75535 .30645 Metetra
.59 .429 .632 r
.75535 .30645 .7582 .32161 .76252 .32006 .75967 .30501 Metetra
.59 .43 .633 r
.75967 .30501 .76252 .32006 .76589 .30623 .76398 .30357 Metetra
.664 .741 .907 r
.76398 .30357 .76589 .30623 .77021 .30479 .76831 .30213 Metetra
.664 .741 .907 r
.76831 .30213 .77021 .30479 .77454 .30335 .77264 .30068 Metetra
.664 .741 .907 r
.77264 .30068 .77454 .30335 .77887 .3019 .77698 .29923 Metetra
.664 .741 .907 r
.77698 .29923 .77887 .3019 .78321 .30046 .78132 .29778 Metetra
.664 .741 .907 r
.78132 .29778 .78321 .30046 .78756 .29901 .78567 .29633 Metetra
.664 .741 .907 r
.78567 .29633 .78756 .29901 .79191 .29756 .79003 .29488 Metetra
.664 .741 .907 r
.79003 .29488 .79191 .29756 .79627 .29611 .7944 .29342 Metetra
.664 .741 .907 r
.7944 .29342 .79627 .29611 .80064 .29466 .79877 .29197 Metetra
.664 .741 .907 r
.79877 .29197 .80064 .29466 .80501 .2932 .80314 .29051 Metetra
.664 .741 .907 r
.80314 .29051 .80501 .2932 .80939 .29174 .80753 .28904 Metetra
.664 .741 .907 r
.80753 .28904 .80939 .29174 .81378 .29028 .81192 .28758 Metetra
.664 .741 .907 r
.81192 .28758 .81378 .29028 .81817 .28882 .81632 .28611 Metetra
.664 .741 .907 r
.81632 .28611 .81817 .28882 .82257 .28735 .82072 .28464 Metetra
.664 .741 .907 r
.82072 .28464 .82257 .28735 .82698 .28589 .82513 .28317 Metetra
.664 .741 .907 r
.82513 .28317 .82698 .28589 .83139 .28442 .82955 .2817 Metetra
.664 .741 .907 r
.82955 .2817 .83139 .28442 .83581 .28295 .83397 .28022 Metetra
.664 .741 .907 r
.83397 .28022 .83581 .28295 .84023 .28147 .83841 .27875 Metetra
.664 .741 .907 r
.83841 .27875 .84023 .28147 .84467 .28 .84284 .27727 Metetra
.664 .741 .907 r
.84284 .27727 .84467 .28 .84911 .27852 .84729 .27578 Metetra
.664 .741 .907 r
.84729 .27578 .84911 .27852 .85355 .27704 .85174 .2743 Metetra
.664 .741 .907 r
.85174 .2743 .85355 .27704 .85801 .27555 .8562 .27281 Metetra
.664 .741 .907 r
.8562 .27281 .85801 .27555 .86247 .27407 .86066 .27132 Metetra
.664 .741 .907 r
.86066 .27132 .86247 .27407 .86693 .27258 .86514 .26983 Metetra
.664 .741 .907 r
.26425 .46723 .26663 .46945 .27024 .46825 .26786 .46602 Metetra
.664 .741 .907 r
.26786 .46602 .27024 .46825 .27385 .46705 .27148 .46482 Metetra
.664 .741 .907 r
.27148 .46482 .27385 .46705 .27747 .46584 .2751 .46361 Metetra
.664 .741 .907 r
.2751 .46361 .27747 .46584 .28109 .46463 .27873 .4624 Metetra
.664 .741 .907 r
.27873 .4624 .28109 .46463 .28472 .46342 .28236 .46118 Metetra
.664 .741 .907 r
.28236 .46118 .28472 .46342 .28835 .46221 .28599 .45997 Metetra
.664 .741 .907 r
.28599 .45997 .28835 .46221 .29199 .461 .28963 .45875 Metetra
.664 .741 .907 r
.28963 .45875 .29199 .461 .29563 .45978 .29328 .45753 Metetra
.664 .741 .907 r
.29328 .45753 .29563 .45978 .29928 .45856 .29693 .45631 Metetra
.664 .741 .907 r
.29693 .45631 .29928 .45856 .30294 .45735 .30059 .45509 Metetra
.664 .741 .907 r
.30059 .45509 .30294 .45735 .30659 .45613 .30425 .45387 Metetra
.664 .741 .907 r
.30425 .45387 .30659 .45613 .31026 .4549 .30791 .45264 Metetra
.664 .741 .907 r
.30791 .45264 .31026 .4549 .31392 .45368 .31158 .45142 Metetra
.664 .741 .907 r
.31158 .45142 .31392 .45368 .3176 .45246 .31526 .45019 Metetra
.664 .741 .907 r
.31526 .45019 .3176 .45246 .32128 .45123 .31894 .44896 Metetra
.664 .741 .907 r
.31894 .44896 .32128 .45123 .32496 .45 .32263 .44773 Metetra
.664 .741 .907 r
.32263 .44773 .32496 .45 .32865 .44877 .32632 .44649 Metetra
.664 .741 .907 r
.32632 .44649 .32865 .44877 .33234 .44754 .33001 .44526 Metetra
.664 .741 .907 r
.33001 .44526 .33234 .44754 .33604 .4463 .33372 .44402 Metetra
.664 .741 .907 r
.33372 .44402 .33604 .4463 .33974 .44507 .33742 .44278 Metetra
.664 .741 .907 r
.33742 .44278 .33974 .44507 .34345 .44383 .34114 .44154 Metetra
.664 .741 .907 r
.34114 .44154 .34345 .44383 .34717 .44259 .34485 .4403 Metetra
.664 .741 .907 r
.34485 .4403 .34717 .44259 .35089 .44135 .34858 .43906 Metetra
.664 .741 .907 r
.34858 .43906 .35089 .44135 .35461 .44011 .3523 .43781 Metetra
.664 .741 .907 r
.3523 .43781 .35461 .44011 .35834 .43887 .35604 .43656 Metetra
.664 .741 .907 r
.35604 .43656 .35834 .43887 .36147 .4498 .35977 .43532 Metetra
.042 .033 .519 r
.35977 .43532 .36147 .4498 .36521 .44868 .36291 .44629 Metetra
.65 .731 .908 r
.36291 .44629 .36521 .44868 .36897 .44756 .36667 .44517 Metetra
.65 .73 .908 r
.36667 .44517 .36897 .44756 .37273 .44644 .37043 .44405 Metetra
.65 .73 .908 r
.37043 .44405 .37273 .44644 .37649 .44533 .3742 .44292 Metetra
.649 .73 .908 r
.3742 .44292 .37649 .44533 .38026 .44421 .37797 .4418 Metetra
.649 .729 .908 r
.37797 .4418 .38026 .44421 .38403 .4431 .38175 .44069 Metetra
.649 .729 .908 r
.38175 .44069 .38403 .4431 .38782 .44199 .38553 .43957 Metetra
.648 .729 .908 r
.38553 .43957 .38782 .44199 .3916 .44088 .38932 .43846 Metetra
.648 .728 .908 r
.38932 .43846 .3916 .44088 .39539 .43978 .39312 .43735 Metetra
.647 .728 .908 r
.39312 .43735 .39539 .43978 .39919 .43868 .39692 .43624 Metetra
.647 .728 .908 r
.39692 .43624 .39919 .43868 .40299 .43758 .40072 .43513 Metetra
.646 .727 .908 r
.40072 .43513 .40299 .43758 .4068 .43648 .40453 .43403 Metetra
.646 .727 .908 r
.40453 .43403 .4068 .43648 .41061 .43539 .40835 .43293 Metetra
.645 .726 .908 r
.40835 .43293 .41061 .43539 .41443 .4343 .41217 .43184 Metetra
.645 .726 .908 r
.41217 .43184 .41443 .4343 .41826 .43322 .416 .43075 Metetra
.644 .725 .908 r
.416 .43075 .41826 .43322 .42209 .43214 .41984 .42966 Metetra
.644 .725 .908 r
.41984 .42966 .42209 .43214 .42593 .43106 .42368 .42858 Metetra
.643 .724 .908 r
.42368 .42858 .42593 .43106 .42977 .42999 .42752 .4275 Metetra
.642 .724 .907 r
.42752 .4275 .42977 .42999 .43362 .42893 .43137 .42643 Metetra
.641 .723 .907 r
.43137 .42643 .43362 .42893 .43747 .42787 .43523 .42536 Metetra
.641 .722 .907 r
.43523 .42536 .43747 .42787 .44133 .42682 .43909 .4243 Metetra
.64 .722 .907 r
.43909 .4243 .44133 .42682 .4452 .42578 .44296 .42325 Metetra
.639 .721 .907 r
.44296 .42325 .4452 .42578 .44907 .42474 .44684 .4222 Metetra
.638 .72 .907 r
.44684 .4222 .44907 .42474 .45294 .42371 .45072 .42117 Metetra
.637 .719 .907 r
.45072 .42117 .45294 .42371 .45683 .42269 .4546 .42014 Metetra
.636 .718 .907 r
.4546 .42014 .45683 .42269 .46072 .42168 .4585 .41911 Metetra
.635 .717 .907 r
.4585 .41911 .46072 .42168 .46461 .42068 .4624 .4181 Metetra
.633 .716 .907 r
.4624 .4181 .46461 .42068 .46851 .41969 .4663 .4171 Metetra
.632 .715 .907 r
.4663 .4171 .46851 .41969 .47242 .41871 .47021 .41611 Metetra
.631 .714 .907 r
.47021 .41611 .47242 .41871 .47634 .41774 .47413 .41514 Metetra
.629 .713 .907 r
.47413 .41514 .47634 .41774 .48025 .41679 .47805 .41417 Metetra
.627 .711 .907 r
.47805 .41417 .48025 .41679 .48418 .41586 .48198 .41323 Metetra
.626 .71 .907 r
.48198 .41323 .48418 .41586 .48811 .41494 .48592 .41229 Metetra
.962 .682 .457 r
.48592 .41229 .48811 .41494 .48996 .6207 .48762 .61843 Metetra
.645 .763 .934 r
.48762 .61843 .48996 .6207 .49416 .61947 .49182 .6172 Metetra
.941 .749 .616 r
.49182 .6172 .49416 .61947 .49836 .61824 .49616 .60059 Metetra
.827 .591 .582 r
.49616 .60059 .49836 .61824 .50276 .58782 .50056 .57149 Metetra
.787 .565 .6 r
.50056 .57149 .50276 .58782 .50706 .56478 .50483 .55279 Metetra
.785 .579 .621 r
.50483 .55279 .50706 .56478 .51128 .54916 .50904 .53953 Metetra
.779 .589 .642 r
.50904 .53953 .51128 .54916 .51546 .53772 .51322 .52953 Metetra
.771 .597 .663 r
.51322 .52953 .51546 .53772 .51962 .52895 .51738 .5217 Metetra
.76 .603 .682 r
.51738 .5217 .51962 .52895 .52377 .52201 .52152 .5154 Metetra
.748 .606 .7 r
.52152 .5154 .52377 .52201 .5279 .5164 .52566 .51025 Metetra
.734 .608 .717 r
.52566 .51025 .5279 .5164 .53204 .51184 .5298 .506 Metetra
.718 .607 .732 r
.5298 .506 .53204 .51184 .53618 .5081 .53394 .50249 Metetra
.7 .604 .745 r
.53394 .50249 .53618 .5081 .54032 .50507 .53808 .49962 Metetra
.681 .598 .757 r
.53808 .49962 .54032 .50507 .54446 .50266 .54223 .4973 Metetra
.659 .59 .767 r
.54223 .4973 .54446 .50266 .54861 .50082 .54638 .49551 Metetra
.634 .579 .775 r
.54638 .49551 .54861 .50082 .55278 .49953 .55055 .49421 Metetra
.606 .564 .781 r
.55055 .49421 .55278 .49953 .55695 .49878 .55472 .49341 Metetra
.574 .545 .785 r
.55472 .49341 .55695 .49878 .56114 .4986 .55891 .49313 Metetra
.535 .52 .785 r
.55891 .49313 .56114 .4986 .56534 .49905 .56311 .49341 Metetra
.489 .488 .782 r
.56311 .49341 .56534 .49905 .56957 .50021 .56733 .49433 Metetra
.433 .447 .774 r
.56733 .49433 .56957 .50021 .57382 .50221 .57157 .49599 Metetra
.364 .394 .759 r
.57157 .49599 .57382 .50221 .5781 .50525 .57584 .49857 Metetra
.277 .325 .732 r
.57584 .49857 .5781 .50525 .58242 .50965 .58015 .50231 Metetra
.168 .235 .69 r
.58015 .50231 .58242 .50965 .5868 .51589 .5845 .5076 Metetra
.032 .122 .626 r
.5845 .5076 .5868 .51589 .59126 .52483 .58892 .51508 Metetra
0 0 .533 r
.58892 .51508 .59126 .52483 .59584 .53801 .59344 .52587 Metetra
0 0 .41 r
.59344 .52587 .59584 .53801 .60063 .5587 .59811 .54216 Metetra
0 0 .261 r
.59811 .54216 .60063 .5587 .60566 .58689 .60308 .56898 Metetra
.122 .093 .549 r
.60308 .56898 .60566 .58689 .61004 .58561 .60782 .58324 Metetra
.645 .763 .934 r
.60782 .58324 .61004 .58561 .61443 .58432 .61222 .58195 Metetra
.971 .693 .445 r
.61222 .58195 .61443 .58432 .61305 .37372 .61096 .37096 Metetra
.693 .733 .881 r
.61096 .37096 .61305 .37372 .61716 .37197 .61508 .36922 Metetra
.692 .733 .882 r
.61508 .36922 .61716 .37197 .62128 .37024 .6192 .36749 Metetra
.69 .733 .884 r
.6192 .36749 .62128 .37024 .62541 .36852 .62333 .36578 Metetra
.689 .734 .885 r
.62333 .36578 .62541 .36852 .62954 .36682 .62747 .36408 Metetra
.688 .734 .886 r
.62747 .36408 .62954 .36682 .63368 .36513 .63161 .3624 Metetra
.687 .734 .887 r
.63161 .3624 .63368 .36513 .63782 .36346 .63576 .36073 Metetra
.686 .735 .888 r
.63576 .36073 .63782 .36346 .64197 .36179 .63991 .35906 Metetra
.685 .735 .888 r
.63991 .35906 .64197 .36179 .64612 .36013 .64407 .35741 Metetra
.685 .735 .889 r
.64407 .35741 .64612 .36013 .65028 .35849 .64823 .35577 Metetra
.684 .736 .89 r
.64823 .35577 .65028 .35849 .65445 .35685 .65241 .35413 Metetra
.683 .736 .891 r
.65241 .35413 .65445 .35685 .65862 .35522 .65658 .3525 Metetra
.682 .736 .891 r
.65658 .3525 .65862 .35522 .6628 .35359 .66076 .35088 Metetra
.682 .736 .892 r
.66076 .35088 .6628 .35359 .66698 .35198 .66495 .34926 Metetra
.681 .736 .892 r
.66495 .34926 .66698 .35198 .67117 .35036 .66915 .34765 Metetra
.681 .737 .893 r
.66915 .34765 .67117 .35036 .67537 .34876 .67335 .34604 Metetra
.68 .737 .893 r
.67335 .34604 .67537 .34876 .67957 .34716 .67756 .34444 Metetra
.68 .737 .894 r
.67756 .34444 .67957 .34716 .68378 .34556 .68177 .34285 Metetra
.679 .737 .894 r
.68177 .34285 .68378 .34556 .68799 .34397 .68599 .34126 Metetra
.679 .737 .895 r
.68599 .34126 .68799 .34397 .69222 .34238 .69021 .33967 Metetra
.678 .737 .895 r
.69021 .33967 .69222 .34238 .69644 .3408 .69444 .33808 Metetra
.678 .737 .896 r
.69444 .33808 .69644 .3408 .70067 .33922 .69868 .3365 Metetra
.677 .738 .896 r
.69868 .3365 .70067 .33922 .70491 .33764 .70292 .33492 Metetra
.677 .738 .896 r
.70292 .33492 .70491 .33764 .70916 .33607 .70717 .33335 Metetra
.676 .738 .897 r
.70717 .33335 .70916 .33607 .71341 .3345 .71143 .33178 Metetra
.676 .738 .897 r
.71143 .33178 .71341 .3345 .71767 .33293 .71569 .33021 Metetra
.676 .738 .897 r
.71569 .33021 .71767 .33293 .72193 .33136 .71996 .32864 Metetra
.675 .738 .898 r
.71996 .32864 .72193 .33136 .7262 .32979 .72423 .32707 Metetra
.675 .738 .898 r
.72423 .32707 .7262 .32979 .73048 .32823 .72851 .32551 Metetra
.675 .738 .898 r
.72851 .32551 .73048 .32823 .73476 .32667 .7328 .32394 Metetra
.675 .738 .898 r
.7328 .32394 .73476 .32667 .73905 .32511 .7371 .32238 Metetra
.674 .738 .899 r
.7371 .32238 .73905 .32511 .74334 .32355 .7414 .32082 Metetra
.674 .738 .899 r
.7414 .32082 .74334 .32355 .74765 .32199 .7457 .31926 Metetra
.957 .765 .602 r
.7457 .31926 .74765 .32199 .75195 .32044 .74912 .30523 Metetra
.589 .429 .632 r
.74912 .30523 .75195 .32044 .75535 .30645 .75343 .30379 Metetra
.664 .741 .907 r
.75343 .30379 .75535 .30645 .75967 .30501 .75775 .30235 Metetra
.664 .741 .907 r
.75775 .30235 .75967 .30501 .76398 .30357 .76207 .3009 Metetra
.664 .741 .907 r
.76207 .3009 .76398 .30357 .76831 .30213 .7664 .29946 Metetra
.664 .741 .907 r
.7664 .29946 .76831 .30213 .77264 .30068 .77074 .29801 Metetra
.664 .741 .907 r
.77074 .29801 .77264 .30068 .77698 .29923 .77508 .29656 Metetra
.664 .741 .907 r
.77508 .29656 .77698 .29923 .78132 .29778 .77943 .2951 Metetra
.664 .741 .907 r
.77943 .2951 .78132 .29778 .78567 .29633 .78378 .29365 Metetra
.664 .741 .907 r
.78378 .29365 .78567 .29633 .79003 .29488 .78815 .29219 Metetra
.664 .741 .907 r
.78815 .29219 .79003 .29488 .7944 .29342 .79251 .29073 Metetra
.664 .741 .907 r
.79251 .29073 .7944 .29342 .79877 .29197 .79689 .28927 Metetra
.664 .741 .907 r
.79689 .28927 .79877 .29197 .80314 .29051 .80127 .2878 Metetra
.664 .741 .907 r
.80127 .2878 .80314 .29051 .80753 .28904 .80566 .28634 Metetra
.664 .741 .907 r
.80566 .28634 .80753 .28904 .81192 .28758 .81006 .28487 Metetra
.664 .741 .907 r
.81006 .28487 .81192 .28758 .81632 .28611 .81446 .2834 Metetra
.664 .741 .907 r
.81446 .2834 .81632 .28611 .82072 .28464 .81887 .28193 Metetra
.664 .741 .907 r
.81887 .28193 .82072 .28464 .82513 .28317 .82328 .28045 Metetra
.664 .741 .907 r
.82328 .28045 .82513 .28317 .82955 .2817 .82771 .27897 Metetra
.664 .741 .907 r
.82771 .27897 .82955 .2817 .83397 .28022 .83214 .27749 Metetra
.664 .741 .907 r
.83214 .27749 .83397 .28022 .83841 .27875 .83657 .27601 Metetra
.664 .741 .907 r
.83657 .27601 .83841 .27875 .84284 .27727 .84102 .27453 Metetra
.664 .741 .907 r
.84102 .27453 .84284 .27727 .84729 .27578 .84546 .27304 Metetra
.664 .741 .907 r
.84546 .27304 .84729 .27578 .85174 .2743 .84992 .27155 Metetra
.664 .741 .907 r
.84992 .27155 .85174 .2743 .8562 .27281 .85438 .27006 Metetra
.664 .741 .907 r
.85438 .27006 .8562 .27281 .86066 .27132 .85885 .26857 Metetra
.664 .741 .907 r
.85885 .26857 .86066 .27132 .86514 .26983 .86333 .26707 Metetra
.664 .741 .907 r
.26187 .465 .26425 .46723 .26786 .46602 .26548 .46379 Metetra
.664 .741 .907 r
.26548 .46379 .26786 .46602 .27148 .46482 .2691 .46258 Metetra
.664 .741 .907 r
.2691 .46258 .27148 .46482 .2751 .46361 .27272 .46137 Metetra
.664 .741 .907 r
.27272 .46137 .2751 .46361 .27873 .4624 .27635 .46015 Metetra
.664 .741 .907 r
.27635 .46015 .27873 .4624 .28236 .46118 .27999 .45894 Metetra
.664 .741 .907 r
.27999 .45894 .28236 .46118 .28599 .45997 .28362 .45772 Metetra
.664 .741 .907 r
.28362 .45772 .28599 .45997 .28963 .45875 .28727 .4565 Metetra
.664 .741 .907 r
.28727 .4565 .28963 .45875 .29328 .45753 .29092 .45528 Metetra
.664 .741 .907 r
.29092 .45528 .29328 .45753 .29693 .45631 .29457 .45406 Metetra
.664 .741 .907 r
.29457 .45406 .29693 .45631 .30059 .45509 .29823 .45283 Metetra
.664 .741 .907 r
.29823 .45283 .30059 .45509 .30425 .45387 .30189 .45161 Metetra
.664 .741 .907 r
.30189 .45161 .30425 .45387 .30791 .45264 .30556 .45038 Metetra
.664 .741 .907 r
.30556 .45038 .30791 .45264 .31158 .45142 .30924 .44915 Metetra
.664 .741 .907 r
.30924 .44915 .31158 .45142 .31526 .45019 .31292 .44792 Metetra
.664 .741 .907 r
.31292 .44792 .31526 .45019 .31894 .44896 .3166 .44668 Metetra
.664 .741 .907 r
.3166 .44668 .31894 .44896 .32263 .44773 .32029 .44545 Metetra
.664 .741 .907 r
.32029 .44545 .32263 .44773 .32632 .44649 .32398 .44421 Metetra
.664 .741 .907 r
.32398 .44421 .32632 .44649 .33001 .44526 .32768 .44297 Metetra
.664 .741 .907 r
.32768 .44297 .33001 .44526 .33372 .44402 .33139 .44173 Metetra
.664 .741 .907 r
.33139 .44173 .33372 .44402 .33742 .44278 .3351 .44049 Metetra
.664 .741 .907 r
.3351 .44049 .33742 .44278 .34114 .44154 .33881 .43925 Metetra
.664 .741 .907 r
.33881 .43925 .34114 .44154 .34485 .4403 .34253 .438 Metetra
.664 .741 .907 r
.34253 .438 .34485 .4403 .34858 .43906 .34626 .43676 Metetra
.664 .741 .907 r
.34626 .43676 .34858 .43906 .3523 .43781 .34999 .43551 Metetra
.664 .741 .907 r
.34999 .43551 .3523 .43781 .35604 .43656 .35373 .43426 Metetra
.664 .741 .907 r
.35373 .43426 .35604 .43656 .35977 .43532 .35747 .43301 Metetra
.664 .741 .907 r
.35747 .43301 .35977 .43532 .36291 .44629 .36122 .43175 Metetra
.041 .032 .519 r
.36122 .43175 .36291 .44629 .36667 .44517 .36436 .44277 Metetra
.65 .731 .908 r
.36436 .44277 .36667 .44517 .37043 .44405 .36813 .44164 Metetra
.65 .73 .908 r
.36813 .44164 .37043 .44405 .3742 .44292 .3719 .44051 Metetra
.65 .73 .908 r
.3719 .44051 .3742 .44292 .37797 .4418 .37568 .43939 Metetra
.649 .73 .908 r
.37568 .43939 .37797 .4418 .38175 .44069 .37946 .43827 Metetra
.649 .729 .908 r
.37946 .43827 .38175 .44069 .38553 .43957 .38324 .43714 Metetra
.649 .729 .908 r
.38324 .43714 .38553 .43957 .38932 .43846 .38704 .43603 Metetra
.648 .729 .908 r
.38704 .43603 .38932 .43846 .39312 .43735 .39083 .43491 Metetra
.648 .728 .908 r
.39083 .43491 .39312 .43735 .39692 .43624 .39464 .4338 Metetra
.647 .728 .908 r
.39464 .4338 .39692 .43624 .40072 .43513 .39845 .43268 Metetra
.647 .727 .908 r
.39845 .43268 .40072 .43513 .40453 .43403 .40226 .43158 Metetra
.646 .727 .908 r
.40226 .43158 .40453 .43403 .40835 .43293 .40608 .43047 Metetra
.646 .727 .908 r
.40608 .43047 .40835 .43293 .41217 .43184 .40991 .42937 Metetra
.645 .726 .908 r
.40991 .42937 .41217 .43184 .416 .43075 .41374 .42827 Metetra
.645 .726 .908 r
.41374 .42827 .416 .43075 .41984 .42966 .41758 .42718 Metetra
.644 .725 .908 r
.41758 .42718 .41984 .42966 .42368 .42858 .42142 .42609 Metetra
.643 .725 .907 r
.42142 .42609 .42368 .42858 .42752 .4275 .42527 .425 Metetra
.643 .724 .907 r
.42527 .425 .42752 .4275 .43137 .42643 .42912 .42392 Metetra
.642 .723 .907 r
.42912 .42392 .43137 .42643 .43523 .42536 .43298 .42285 Metetra
.641 .723 .907 r
.43298 .42285 .43523 .42536 .43909 .4243 .43685 .42178 Metetra
.64 .722 .907 r
.43685 .42178 .43909 .4243 .44296 .42325 .44072 .42072 Metetra
.639 .721 .907 r
.44072 .42072 .44296 .42325 .44684 .4222 .4446 .41967 Metetra
.639 .721 .907 r
.4446 .41967 .44684 .4222 .45072 .42117 .44849 .41862 Metetra
.638 .72 .907 r
.44849 .41862 .45072 .42117 .4546 .42014 .45238 .41758 Metetra
.637 .719 .907 r
.45238 .41758 .4546 .42014 .4585 .41911 .45627 .41655 Metetra
.635 .718 .907 r
.45627 .41655 .4585 .41911 .4624 .4181 .46017 .41553 Metetra
.634 .717 .907 r
.46017 .41553 .4624 .4181 .4663 .4171 .46408 .41452 Metetra
.633 .716 .907 r
.46408 .41452 .4663 .4171 .47021 .41611 .46799 .41351 Metetra
.632 .715 .907 r
.46799 .41351 .47021 .41611 .47413 .41514 .47191 .41253 Metetra
.63 .713 .907 r
.47191 .41253 .47413 .41514 .47805 .41417 .47584 .41155 Metetra
.628 .712 .907 r
.47584 .41155 .47805 .41417 .48198 .41323 .47977 .41059 Metetra
.961 .682 .459 r
.47977 .41059 .48198 .41323 .48592 .41229 .48107 .61739 Metetra
.545 .323 .529 r
.48107 .61739 .48592 .41229 .48762 .61843 .48527 .61616 Metetra
.645 .763 .934 r
.48527 .61616 .48762 .61843 .49182 .6172 .48948 .61492 Metetra
.955 .722 .547 r
.48948 .61492 .49182 .6172 .49616 .60059 .49399 .58052 Metetra
.785 .556 .59 r
.49399 .58052 .49616 .60059 .50056 .57149 .49834 .55771 Metetra
.786 .572 .611 r
.49834 .55771 .50056 .57149 .50483 .55279 .5026 .54216 Metetra
.783 .584 .632 r
.5026 .54216 .50483 .55279 .50904 .53953 .5068 .53072 Metetra
.776 .594 .653 r
.5068 .53072 .50904 .53953 .51322 .52953 .51098 .52188 Metetra
.767 .601 .673 r
.51098 .52188 .51322 .52953 .51738 .5217 .51513 .51483 Metetra
.756 .606 .691 r
.51513 .51483 .51738 .5217 .52152 .5154 .51928 .50907 Metetra
.744 .609 .709 r
.51928 .50907 .52152 .5154 .52566 .51025 .52342 .50431 Metetra
.73 .611 .724 r
.52342 .50431 .52566 .51025 .5298 .506 .52756 .50035 Metetra
.715 .61 .739 r
.52756 .50035 .5298 .506 .53394 .50249 .5317 .49704 Metetra
.698 .607 .751 r
.5317 .49704 .53394 .50249 .53808 .49962 .53584 .4943 Metetra
.679 .602 .762 r
.53584 .4943 .53808 .49962 .54223 .4973 .53999 .49207 Metetra
.659 .594 .772 r
.53999 .49207 .54223 .4973 .54638 .49551 .54415 .49031 Metetra
.636 .584 .779 r
.54415 .49031 .54638 .49551 .55055 .49421 .54831 .48901 Metetra
.609 .57 .785 r
.54831 .48901 .55055 .49421 .55472 .49341 .55249 .48816 Metetra
.579 .553 .789 r
.55249 .48816 .55472 .49341 .55891 .49313 .55667 .48779 Metetra
.544 .53 .79 r
.55667 .48779 .55891 .49313 .56311 .49341 .56087 .48793 Metetra
.503 .502 .788 r
.56087 .48793 .56311 .49341 .56733 .49433 .56509 .48863 Metetra
.453 .465 .781 r
.56509 .48863 .56733 .49433 .57157 .49599 .56933 .49001 Metetra
.391 .418 .769 r
.56933 .49001 .57157 .49599 .57584 .49857 .57359 .49218 Metetra
.314 .357 .747 r
.57359 .49218 .57584 .49857 .58015 .50231 .57788 .49536 Metetra
.218 .279 .713 r
.57788 .49536 .58015 .50231 .5845 .5076 .58222 .49985 Metetra
.099 .179 .66 r
.58222 .49985 .5845 .5076 .58892 .51508 .58661 .50615 Metetra
0 .055 .583 r
.58661 .50615 .58892 .51508 .59344 .52587 .59107 .51509 Metetra
0 0 .477 r
.59107 .51509 .59344 .52587 .59811 .54216 .59566 .52819 Metetra
0 0 .342 r
.59566 .52819 .59811 .54216 .60308 .56898 .60046 .54864 Metetra
0 0 .259 r
.60046 .54864 .60308 .56898 .60782 .58324 .6056 .58086 Metetra
.645 .763 .934 r
.6056 .58086 .60782 .58324 .61222 .58195 .61 .57957 Metetra
.645 .763 .934 r
.61 .57957 .61222 .58195 .61096 .37096 .6144 .57828 Metetra
0 0 .374 r
.6144 .57828 .61096 .37096 .61508 .36922 .61299 .36646 Metetra
.691 .733 .883 r
.61299 .36646 .61508 .36922 .6192 .36749 .61712 .36474 Metetra
.69 .734 .884 r
.61712 .36474 .6192 .36749 .62333 .36578 .62125 .36303 Metetra
.689 .734 .885 r
.62125 .36303 .62333 .36578 .62747 .36408 .62539 .36134 Metetra
.688 .734 .886 r
.62539 .36134 .62747 .36408 .63161 .3624 .62954 .35966 Metetra
.687 .735 .887 r
.62954 .35966 .63161 .3624 .63576 .36073 .63369 .35799 Metetra
.686 .735 .888 r
.63369 .35799 .63576 .36073 .63991 .35906 .63785 .35633 Metetra
.685 .735 .889 r
.63785 .35633 .63991 .35906 .64407 .35741 .64201 .35468 Metetra
.684 .735 .89 r
.64201 .35468 .64407 .35741 .64823 .35577 .64618 .35304 Metetra
.683 .736 .89 r
.64618 .35304 .64823 .35577 .65241 .35413 .65036 .3514 Metetra
.683 .736 .891 r
.65036 .3514 .65241 .35413 .65658 .3525 .65454 .34978 Metetra
.682 .736 .892 r
.65454 .34978 .65658 .3525 .66076 .35088 .65872 .34815 Metetra
.681 .736 .892 r
.65872 .34815 .66076 .35088 .66495 .34926 .66292 .34654 Metetra
.681 .736 .893 r
.66292 .34654 .66495 .34926 .66915 .34765 .66712 .34493 Metetra
.68 .737 .893 r
.66712 .34493 .66915 .34765 .67335 .34604 .67132 .34332 Metetra
.68 .737 .894 r
.67132 .34332 .67335 .34604 .67756 .34444 .67553 .34172 Metetra
.679 .737 .894 r
.67553 .34172 .67756 .34444 .68177 .34285 .67975 .34013 Metetra
.679 .737 .895 r
.67975 .34013 .68177 .34285 .68599 .34126 .68397 .33854 Metetra
.678 .737 .895 r
.68397 .33854 .68599 .34126 .69021 .33967 .6882 .33695 Metetra
.678 .737 .895 r
.6882 .33695 .69021 .33967 .69444 .33808 .69244 .33536 Metetra
.677 .737 .896 r
.69244 .33536 .69444 .33808 .69868 .3365 .69668 .33378 Metetra
.677 .738 .896 r
.69668 .33378 .69868 .3365 .70292 .33492 .70093 .3322 Metetra
.677 .738 .897 r
.70093 .3322 .70292 .33492 .70717 .33335 .70518 .33063 Metetra
.676 .738 .897 r
.70518 .33063 .70717 .33335 .71143 .33178 .70944 .32905 Metetra
.676 .738 .897 r
.70944 .32905 .71143 .33178 .71569 .33021 .71371 .32748 Metetra
.676 .738 .897 r
.71371 .32748 .71569 .33021 .71996 .32864 .71798 .32591 Metetra
.675 .738 .898 r
.71798 .32591 .71996 .32864 .72423 .32707 .72226 .32434 Metetra
.675 .738 .898 r
.72226 .32434 .72423 .32707 .72851 .32551 .72655 .32278 Metetra
.675 .738 .898 r
.72655 .32278 .72851 .32551 .7328 .32394 .73084 .32121 Metetra
.674 .738 .899 r
.73084 .32121 .7328 .32394 .7371 .32238 .73514 .31965 Metetra
.674 .738 .899 r
.73514 .31965 .7371 .32238 .7414 .32082 .73944 .31808 Metetra
.957 .765 .603 r
.73944 .31808 .7414 .32082 .7457 .31926 .74288 .30401 Metetra
.589 .428 .632 r
.74288 .30401 .7457 .31926 .74912 .30523 .74719 .30257 Metetra
.664 .741 .907 r
.74719 .30257 .74912 .30523 .75343 .30379 .7515 .30113 Metetra
.664 .741 .907 r
.7515 .30113 .75343 .30379 .75775 .30235 .75582 .29968 Metetra
.664 .741 .907 r
.75582 .29968 .75775 .30235 .76207 .3009 .76015 .29823 Metetra
.664 .741 .907 r
.76015 .29823 .76207 .3009 .7664 .29946 .76449 .29678 Metetra
.664 .741 .907 r
.76449 .29678 .7664 .29946 .77074 .29801 .76883 .29533 Metetra
.664 .741 .907 r
.76883 .29533 .77074 .29801 .77508 .29656 .77317 .29387 Metetra
.664 .741 .907 r
.77317 .29387 .77508 .29656 .77943 .2951 .77753 .29242 Metetra
.664 .741 .907 r
.77753 .29242 .77943 .2951 .78378 .29365 .78189 .29096 Metetra
.664 .741 .907 r
.78189 .29096 .78378 .29365 .78815 .29219 .78625 .28949 Metetra
.664 .741 .907 r
.78625 .28949 .78815 .29219 .79251 .29073 .79063 .28803 Metetra
.664 .741 .907 r
.79063 .28803 .79251 .29073 .79689 .28927 .79501 .28656 Metetra
.664 .741 .907 r
.79501 .28656 .79689 .28927 .80127 .2878 .7994 .2851 Metetra
.664 .741 .907 r
.7994 .2851 .80127 .2878 .80566 .28634 .80379 .28363 Metetra
.664 .741 .907 r
.80379 .28363 .80566 .28634 .81006 .28487 .80819 .28215 Metetra
.664 .741 .907 r
.80819 .28215 .81006 .28487 .81446 .2834 .8126 .28068 Metetra
.664 .741 .907 r
.8126 .28068 .81446 .2834 .81887 .28193 .81701 .2792 Metetra
.664 .741 .907 r
.81701 .2792 .81887 .28193 .82328 .28045 .82143 .27772 Metetra
.664 .741 .907 r
.82143 .27772 .82328 .28045 .82771 .27897 .82586 .27624 Metetra
.664 .741 .907 r
.82586 .27624 .82771 .27897 .83214 .27749 .83029 .27475 Metetra
.664 .741 .907 r
.83029 .27475 .83214 .27749 .83657 .27601 .83473 .27327 Metetra
.664 .741 .907 r
.83473 .27327 .83657 .27601 .84102 .27453 .83918 .27178 Metetra
.664 .741 .907 r
.83918 .27178 .84102 .27453 .84546 .27304 .84364 .27029 Metetra
.664 .741 .907 r
.84364 .27029 .84546 .27304 .84992 .27155 .8481 .2688 Metetra
.664 .741 .907 r
.8481 .2688 .84992 .27155 .85438 .27006 .85257 .2673 Metetra
.664 .741 .907 r
.85257 .2673 .85438 .27006 .85885 .26857 .85704 .2658 Metetra
.664 .741 .907 r
.85704 .2658 .85885 .26857 .86333 .26707 .86152 .2643 Metetra
.664 .741 .907 r
.25948 .46277 .26187 .465 .26548 .46379 .26309 .46156 Metetra
.664 .741 .907 r
.26309 .46156 .26548 .46379 .2691 .46258 .26671 .46034 Metetra
.664 .741 .907 r
.26671 .46034 .2691 .46258 .27272 .46137 .27034 .45913 Metetra
.664 .741 .907 r
.27034 .45913 .27272 .46137 .27635 .46015 .27397 .45791 Metetra
.664 .741 .907 r
.27397 .45791 .27635 .46015 .27999 .45894 .27761 .45669 Metetra
.664 .741 .907 r
.27761 .45669 .27999 .45894 .28362 .45772 .28125 .45547 Metetra
.664 .741 .907 r
.28125 .45547 .28362 .45772 .28727 .4565 .2849 .45425 Metetra
.664 .741 .907 r
.2849 .45425 .28727 .4565 .29092 .45528 .28855 .45302 Metetra
.664 .741 .907 r
.28855 .45302 .29092 .45528 .29457 .45406 .29221 .45179 Metetra
.664 .741 .907 r
.29221 .45179 .29457 .45406 .29823 .45283 .29587 .45057 Metetra
.664 .741 .907 r
.29587 .45057 .29823 .45283 .30189 .45161 .29953 .44934 Metetra
.664 .741 .907 r
.29953 .44934 .30189 .45161 .30556 .45038 .30321 .44811 Metetra
.664 .741 .907 r
.30321 .44811 .30556 .45038 .30924 .44915 .30688 .44687 Metetra
.664 .741 .907 r
.30688 .44687 .30924 .44915 .31292 .44792 .31057 .44564 Metetra
.664 .741 .907 r
.31057 .44564 .31292 .44792 .3166 .44668 .31425 .4444 Metetra
.664 .741 .907 r
.31425 .4444 .3166 .44668 .32029 .44545 .31795 .44316 Metetra
.664 .741 .907 r
.31795 .44316 .32029 .44545 .32398 .44421 .32164 .44193 Metetra
.664 .741 .907 r
.32164 .44193 .32398 .44421 .32768 .44297 .32535 .44068 Metetra
.664 .741 .907 r
.32535 .44068 .32768 .44297 .33139 .44173 .32905 .43944 Metetra
.664 .741 .907 r
.32905 .43944 .33139 .44173 .3351 .44049 .33277 .4382 Metetra
.664 .741 .907 r
.33277 .4382 .3351 .44049 .33881 .43925 .33649 .43695 Metetra
.664 .741 .907 r
.33649 .43695 .33881 .43925 .34253 .438 .34021 .4357 Metetra
.664 .741 .907 r
.34021 .4357 .34253 .438 .34626 .43676 .34394 .43445 Metetra
.664 .741 .907 r
.34394 .43445 .34626 .43676 .34999 .43551 .34767 .4332 Metetra
.664 .741 .907 r
.34767 .4332 .34999 .43551 .35373 .43426 .35141 .43194 Metetra
.664 .741 .907 r
.35141 .43194 .35373 .43426 .35747 .43301 .35516 .43069 Metetra
.664 .741 .907 r
.35516 .43069 .35747 .43301 .36122 .43175 .35891 .42943 Metetra
.664 .741 .907 r
.35891 .42943 .36122 .43175 .36436 .44277 .36266 .42817 Metetra
.041 .032 .518 r
.36266 .42817 .36436 .44277 .36813 .44164 .36582 .43923 Metetra
.65 .73 .908 r
.36582 .43923 .36813 .44164 .3719 .44051 .3696 .4381 Metetra
.65 .73 .908 r
.3696 .4381 .3719 .44051 .37568 .43939 .37338 .43697 Metetra
.65 .73 .908 r
.37338 .43697 .37568 .43939 .37946 .43827 .37716 .43584 Metetra
.649 .729 .908 r
.37716 .43584 .37946 .43827 .38324 .43714 .38095 .43471 Metetra
.649 .729 .908 r
.38095 .43471 .38324 .43714 .38704 .43603 .38475 .43359 Metetra
.648 .729 .908 r
.38475 .43359 .38704 .43603 .39083 .43491 .38855 .43247 Metetra
.648 .728 .908 r
.38855 .43247 .39083 .43491 .39464 .4338 .39235 .43135 Metetra
.648 .728 .908 r
.39235 .43135 .39464 .4338 .39845 .43268 .39617 .43023 Metetra
.647 .728 .908 r
.39617 .43023 .39845 .43268 .40226 .43158 .39998 .42911 Metetra
.647 .727 .908 r
.39998 .42911 .40226 .43158 .40608 .43047 .40381 .428 Metetra
.646 .727 .908 r
.40381 .428 .40608 .43047 .40991 .42937 .40764 .4269 Metetra
.646 .726 .908 r
.40764 .4269 .40991 .42937 .41374 .42827 .41147 .42579 Metetra
.645 .726 .908 r
.41147 .42579 .41374 .42827 .41758 .42718 .41531 .42469 Metetra
.644 .725 .907 r
.41531 .42469 .41758 .42718 .42142 .42609 .41916 .42359 Metetra
.644 .725 .907 r
.41916 .42359 .42142 .42609 .42527 .425 .42301 .4225 Metetra
.643 .724 .907 r
.42301 .4225 .42527 .425 .42912 .42392 .42687 .42142 Metetra
.642 .724 .907 r
.42687 .42142 .42912 .42392 .43298 .42285 .43073 .42033 Metetra
.642 .723 .907 r
.43073 .42033 .43298 .42285 .43685 .42178 .4346 .41926 Metetra
.641 .722 .907 r
.4346 .41926 .43685 .42178 .44072 .42072 .43848 .41819 Metetra
.64 .722 .907 r
.43848 .41819 .44072 .42072 .4446 .41967 .44236 .41712 Metetra
.639 .721 .907 r
.44236 .41712 .4446 .41967 .44849 .41862 .44625 .41607 Metetra
.638 .72 .907 r
.44625 .41607 .44849 .41862 .45238 .41758 .45014 .41502 Metetra
.637 .719 .907 r
.45014 .41502 .45238 .41758 .45627 .41655 .45404 .41398 Metetra
.636 .718 .907 r
.45404 .41398 .45627 .41655 .46017 .41553 .45794 .41295 Metetra
.635 .717 .907 r
.45794 .41295 .46017 .41553 .46408 .41452 .46186 .41192 Metetra
.634 .716 .907 r
.46186 .41192 .46408 .41452 .46799 .41351 .46577 .41091 Metetra
.632 .715 .907 r
.46577 .41091 .46799 .41351 .47191 .41253 .4697 .40991 Metetra
.631 .714 .907 r
.4697 .40991 .47191 .41253 .47584 .41155 .47363 .40893 Metetra
.629 .713 .907 r
.47363 .40893 .47584 .41155 .47977 .41059 .47756 .40795 Metetra
.961 .682 .459 r
.47756 .40795 .47977 .41059 .48107 .61739 .47871 .61511 Metetra
.645 .763 .934 r
.47871 .61511 .48107 .61739 .48527 .61616 .48291 .61388 Metetra
.947 .739 .59 r
.48291 .61388 .48527 .61616 .48948 .61492 .48734 .5928 Metetra
.799 .564 .582 r
.48734 .5928 .48948 .61492 .49399 .58052 .49181 .56423 Metetra
.786 .565 .601 r
.49181 .56423 .49399 .58052 .49834 .55771 .49612 .54575 Metetra
.785 .579 .622 r
.49612 .54575 .49834 .55771 .5026 .54216 .50036 .53257 Metetra
.78 .59 .643 r
.50036 .53257 .5026 .54216 .5068 .53072 .50456 .52257 Metetra
.773 .598 .663 r
.50456 .52257 .5068 .53072 .51098 .52188 .50873 .51469 Metetra
.763 .605 .682 r
.50873 .51469 .51098 .52188 .51513 .51483 .51289 .50829 Metetra
.752 .61 .7 r
.51289 .50829 .51513 .51483 .51928 .50907 .51703 .503 Metetra
.74 .613 .717 r
.51703 .503 .51928 .50907 .52342 .50431 .52118 .49858 Metetra
.726 .614 .732 r
.52118 .49858 .52342 .50431 .52756 .50035 .52532 .49486 Metetra
.712 .613 .745 r
.52532 .49486 .52756 .50035 .5317 .49704 .52946 .49173 Metetra
.695 .61 .757 r
.52946 .49173 .5317 .49704 .53584 .4943 .53361 .48911 Metetra
.678 .605 .767 r
.53361 .48911 .53584 .4943 .53999 .49207 .53776 .48696 Metetra
.658 .598 .776 r
.53776 .48696 .53999 .49207 .54415 .49031 .54191 .48523 Metetra
.637 .589 .784 r
.54191 .48523 .54415 .49031 .54831 .48901 .54608 .48393 Metetra
.612 .576 .789 r
.54608 .48393 .54831 .48901 .55249 .48816 .55025 .48304 Metetra
.585 .56 .793 r
.55025 .48304 .55249 .48816 .55667 .48779 .55444 .48258 Metetra
.553 .54 .794 r
.55444 .48258 .55667 .48779 .56087 .48793 .55863 .48258 Metetra
.515 .514 .793 r
.55863 .48258 .56087 .48793 .56509 .48863 .56285 .48311 Metetra
.47 .481 .788 r
.56285 .48311 .56509 .48863 .56933 .49001 .56708 .48422 Metetra
.415 .44 .778 r
.56708 .48422 .56933 .49001 .57359 .49218 .57134 .48605 Metetra
.347 .386 .76 r
.57134 .48605 .57359 .49218 .57788 .49536 .57562 .48875 Metetra
.263 .318 .732 r
.57562 .48875 .57788 .49536 .58222 .49985 .57994 .49257 Metetra
.157 .23 .689 r
.57994 .49257 .58222 .49985 .58661 .50615 .5843 .4979 Metetra
.028 .12 .625 r
.5843 .4979 .58661 .50615 .59107 .51509 .58873 .50537 Metetra
0 0 .535 r
.58873 .50537 .59107 .51509 .59566 .52819 .59326 .51606 Metetra
0 0 .417 r
.59326 .51606 .59566 .52819 .60046 .54864 .59794 .53212 Metetra
0 0 .273 r
.59794 .53212 .60046 .54864 .6056 .58086 .60291 .55842 Metetra
.089 .053 .518 r
.60291 .55842 .6056 .58086 .61 .57957 .60777 .57719 Metetra
.645 .763 .934 r
.60777 .57719 .61 .57957 .6144 .57828 .61218 .57589 Metetra
.972 .693 .443 r
.61218 .57589 .6144 .57828 .61299 .36646 .6109 .3637 Metetra
.69 .733 .884 r
.6109 .3637 .61299 .36646 .61712 .36474 .61503 .36198 Metetra
.689 .734 .885 r
.61503 .36198 .61712 .36474 .62125 .36303 .61917 .36028 Metetra
.688 .734 .886 r
.61917 .36028 .62125 .36303 .62539 .36134 .62331 .3586 Metetra
.687 .734 .887 r
.62331 .3586 .62539 .36134 .62954 .35966 .62746 .35692 Metetra
.686 .735 .888 r
.62746 .35692 .62954 .35966 .63369 .35799 .63162 .35525 Metetra
.685 .735 .888 r
.63162 .35525 .63369 .35799 .63785 .35633 .63578 .3536 Metetra
.684 .735 .889 r
.63578 .3536 .63785 .35633 .64201 .35468 .63995 .35195 Metetra
.684 .735 .89 r
.63995 .35195 .64201 .35468 .64618 .35304 .64412 .35031 Metetra
.683 .736 .891 r
.64412 .35031 .64618 .35304 .65036 .3514 .6483 .34867 Metetra
.682 .736 .891 r
.6483 .34867 .65036 .3514 .65454 .34978 .65249 .34705 Metetra
.682 .736 .892 r
.65249 .34705 .65454 .34978 .65872 .34815 .65668 .34543 Metetra
.681 .736 .892 r
.65668 .34543 .65872 .34815 .66292 .34654 .66088 .34381 Metetra
.68 .736 .893 r
.66088 .34381 .66292 .34654 .66712 .34493 .66508 .3422 Metetra
.68 .737 .893 r
.66508 .3422 .66712 .34493 .67132 .34332 .66929 .3406 Metetra
.679 .737 .894 r
.66929 .3406 .67132 .34332 .67553 .34172 .6735 .339 Metetra
.679 .737 .894 r
.6735 .339 .67553 .34172 .67975 .34013 .67773 .3374 Metetra
.678 .737 .895 r
.67773 .3374 .67975 .34013 .68397 .33854 .68195 .33581 Metetra
.678 .737 .895 r
.68195 .33581 .68397 .33854 .6882 .33695 .68619 .33422 Metetra
.678 .737 .896 r
.68619 .33422 .6882 .33695 .69244 .33536 .69043 .33264 Metetra
.677 .737 .896 r
.69043 .33264 .69244 .33536 .69668 .33378 .69467 .33105 Metetra
.677 .738 .896 r
.69467 .33105 .69668 .33378 .70093 .3322 .69893 .32947 Metetra
.676 .738 .897 r
.69893 .32947 .70093 .3322 .70518 .33063 .70319 .3279 Metetra
.676 .738 .897 r
.70319 .3279 .70518 .33063 .70944 .32905 .70745 .32632 Metetra
.676 .738 .897 r
.70745 .32632 .70944 .32905 .71371 .32748 .71172 .32475 Metetra
.675 .738 .898 r
.71172 .32475 .71371 .32748 .71798 .32591 .716 .32318 Metetra
.675 .738 .898 r
.716 .32318 .71798 .32591 .72226 .32434 .72028 .32161 Metetra
.675 .738 .898 r
.72028 .32161 .72226 .32434 .72655 .32278 .72457 .32004 Metetra
.674 .738 .898 r
.72457 .32004 .72655 .32278 .73084 .32121 .72887 .31847 Metetra
.674 .738 .899 r
.72887 .31847 .73084 .32121 .73514 .31965 .73317 .3169 Metetra
.957 .764 .603 r
.73317 .3169 .73514 .31965 .73944 .31808 .73663 .30279 Metetra
.589 .428 .631 r
.73663 .30279 .73944 .31808 .74288 .30401 .74094 .30135 Metetra
.664 .741 .907 r
.74094 .30135 .74288 .30401 .74719 .30257 .74525 .2999 Metetra
.664 .741 .907 r
.74525 .2999 .74719 .30257 .7515 .30113 .74957 .29845 Metetra
.664 .741 .907 r
.74957 .29845 .7515 .30113 .75582 .29968 .75389 .297 Metetra
.664 .741 .907 r
.75389 .297 .75582 .29968 .76015 .29823 .75823 .29555 Metetra
.664 .741 .907 r
.75823 .29555 .76015 .29823 .76449 .29678 .76257 .2941 Metetra
.664 .741 .907 r
.76257 .2941 .76449 .29678 .76883 .29533 .76691 .29264 Metetra
.664 .741 .907 r
.76691 .29264 .76883 .29533 .77317 .29387 .77126 .29118 Metetra
.664 .741 .907 r
.77126 .29118 .77317 .29387 .77753 .29242 .77562 .28972 Metetra
.664 .741 .907 r
.77562 .28972 .77753 .29242 .78189 .29096 .77999 .28826 Metetra
.664 .741 .907 r
.77999 .28826 .78189 .29096 .78625 .28949 .78436 .28679 Metetra
.664 .741 .907 r
.78436 .28679 .78625 .28949 .79063 .28803 .78874 .28532 Metetra
.664 .741 .907 r
.78874 .28532 .79063 .28803 .79501 .28656 .79312 .28385 Metetra
.664 .741 .907 r
.79312 .28385 .79501 .28656 .7994 .2851 .79751 .28238 Metetra
.664 .741 .907 r
.79751 .28238 .7994 .2851 .80379 .28363 .80191 .2809 Metetra
.664 .741 .907 r
.80191 .2809 .80379 .28363 .80819 .28215 .80632 .27943 Metetra
.664 .741 .907 r
.80632 .27943 .80819 .28215 .8126 .28068 .81073 .27795 Metetra
.664 .741 .907 r
.81073 .27795 .8126 .28068 .81701 .2792 .81515 .27647 Metetra
.664 .741 .907 r
.81515 .27647 .81701 .2792 .82143 .27772 .81957 .27498 Metetra
.664 .741 .907 r
.81957 .27498 .82143 .27772 .82586 .27624 .82401 .2735 Metetra
.664 .741 .907 r
.82401 .2735 .82586 .27624 .83029 .27475 .82844 .27201 Metetra
.664 .741 .907 r
.82844 .27201 .83029 .27475 .83473 .27327 .83289 .27052 Metetra
.664 .741 .907 r
.83289 .27052 .83473 .27327 .83918 .27178 .83734 .26903 Metetra
.664 .741 .907 r
.83734 .26903 .83918 .27178 .84364 .27029 .8418 .26753 Metetra
.664 .741 .907 r
.8418 .26753 .84364 .27029 .8481 .2688 .84627 .26603 Metetra
.664 .741 .907 r
.84627 .26603 .8481 .2688 .85257 .2673 .85074 .26453 Metetra
.664 .741 .907 r
.85074 .26453 .85257 .2673 .85704 .2658 .85522 .26303 Metetra
.664 .741 .907 r
.85522 .26303 .85704 .2658 .86152 .2643 .85971 .26153 Metetra
.664 .741 .907 r
.25708 .46053 .25948 .46277 .26309 .46156 .2607 .45931 Metetra
.664 .741 .907 r
.2607 .45931 .26309 .46156 .26671 .46034 .26432 .4581 Metetra
.664 .741 .907 r
.26432 .4581 .26671 .46034 .27034 .45913 .26795 .45688 Metetra
.664 .741 .907 r
.26795 .45688 .27034 .45913 .27397 .45791 .27159 .45566 Metetra
.664 .741 .907 r
.27159 .45566 .27397 .45791 .27761 .45669 .27523 .45443 Metetra
.664 .741 .907 r
.27523 .45443 .27761 .45669 .28125 .45547 .27887 .45321 Metetra
.664 .741 .907 r
.27887 .45321 .28125 .45547 .2849 .45425 .28252 .45198 Metetra
.664 .741 .907 r
.28252 .45198 .2849 .45425 .28855 .45302 .28617 .45076 Metetra
.664 .741 .907 r
.28617 .45076 .28855 .45302 .29221 .45179 .28983 .44953 Metetra
.664 .741 .907 r
.28983 .44953 .29221 .45179 .29587 .45057 .2935 .4483 Metetra
.664 .741 .907 r
.2935 .4483 .29587 .45057 .29953 .44934 .29717 .44706 Metetra
.664 .741 .907 r
.29717 .44706 .29953 .44934 .30321 .44811 .30084 .44583 Metetra
.664 .741 .907 r
.30084 .44583 .30321 .44811 .30688 .44687 .30452 .44459 Metetra
.664 .741 .907 r
.30452 .44459 .30688 .44687 .31057 .44564 .30821 .44336 Metetra
.664 .741 .907 r
.30821 .44336 .31057 .44564 .31425 .4444 .3119 .44212 Metetra
.664 .741 .907 r
.3119 .44212 .31425 .4444 .31795 .44316 .3156 .44087 Metetra
.664 .741 .907 r
.3156 .44087 .31795 .44316 .32164 .44193 .3193 .43963 Metetra
.664 .741 .907 r
.3193 .43963 .32164 .44193 .32535 .44068 .323 .43839 Metetra
.664 .741 .907 r
.323 .43839 .32535 .44068 .32905 .43944 .32671 .43714 Metetra
.664 .741 .907 r
.32671 .43714 .32905 .43944 .33277 .4382 .33043 .43589 Metetra
.664 .741 .907 r
.33043 .43589 .33277 .4382 .33649 .43695 .33415 .43464 Metetra
.664 .741 .907 r
.33415 .43464 .33649 .43695 .34021 .4357 .33788 .43339 Metetra
.664 .741 .907 r
.33788 .43339 .34021 .4357 .34394 .43445 .34161 .43214 Metetra
.664 .741 .907 r
.34161 .43214 .34394 .43445 .34767 .4332 .34535 .43088 Metetra
.664 .741 .907 r
.34535 .43088 .34767 .4332 .35141 .43194 .34909 .42963 Metetra
.664 .741 .907 r
.34909 .42963 .35141 .43194 .35516 .43069 .35284 .42837 Metetra
.664 .741 .907 r
.35284 .42837 .35516 .43069 .35891 .42943 .35659 .42711 Metetra
.664 .741 .907 r
.35659 .42711 .35891 .42943 .36266 .42817 .36035 .42584 Metetra
.664 .741 .907 r
.36035 .42584 .36266 .42817 .36582 .43923 .36412 .42458 Metetra
.588 .427 .631 r
.36412 .42458 .36582 .43923 .3696 .4381 .36788 .42331 Metetra
.04 .03 .517 r
.36788 .42331 .3696 .4381 .37338 .43697 .37107 .43454 Metetra
.65 .73 .908 r
.37107 .43454 .37338 .43697 .37716 .43584 .37486 .43341 Metetra
.649 .73 .908 r
.37486 .43341 .37716 .43584 .38095 .43471 .37865 .43228 Metetra
.649 .729 .908 r
.37865 .43228 .38095 .43471 .38475 .43359 .38245 .43115 Metetra
.649 .729 .908 r
.38245 .43115 .38475 .43359 .38855 .43247 .38625 .43002 Metetra
.648 .729 .908 r
.38625 .43002 .38855 .43247 .39235 .43135 .39006 .42889 Metetra
.648 .728 .908 r
.39006 .42889 .39235 .43135 .39617 .43023 .39388 .42777 Metetra
.647 .728 .908 r
.39388 .42777 .39617 .43023 .39998 .42911 .3977 .42665 Metetra
.647 .727 .908 r
.3977 .42665 .39998 .42911 .40381 .428 .40153 .42553 Metetra
.646 .727 .908 r
.40153 .42553 .40381 .428 .40764 .4269 .40536 .42442 Metetra
.646 .727 .908 r
.40536 .42442 .40764 .4269 .41147 .42579 .4092 .42331 Metetra
.645 .726 .907 r
.4092 .42331 .41147 .42579 .41531 .42469 .41304 .4222 Metetra
.645 .726 .907 r
.41304 .4222 .41531 .42469 .41916 .42359 .41689 .42109 Metetra
.644 .725 .907 r
.41689 .42109 .41916 .42359 .42301 .4225 .42075 .42 Metetra
.643 .725 .907 r
.42075 .42 .42301 .4225 .42687 .42142 .42461 .4189 Metetra
.643 .724 .907 r
.42461 .4189 .42687 .42142 .43073 .42033 .42848 .41781 Metetra
.642 .723 .907 r
.42848 .41781 .43073 .42033 .4346 .41926 .43235 .41673 Metetra
.641 .723 .907 r
.43235 .41673 .4346 .41926 .43848 .41819 .43623 .41565 Metetra
.641 .722 .907 r
.43623 .41565 .43848 .41819 .44236 .41712 .44011 .41458 Metetra
.64 .721 .907 r
.44011 .41458 .44236 .41712 .44625 .41607 .444 .41351 Metetra
.639 .721 .907 r
.444 .41351 .44625 .41607 .45014 .41502 .4479 .41245 Metetra
.638 .72 .907 r
.4479 .41245 .45014 .41502 .45404 .41398 .4518 .4114 Metetra
.637 .719 .907 r
.4518 .4114 .45404 .41398 .45794 .41295 .45571 .41036 Metetra
.636 .718 .907 r
.45571 .41036 .45794 .41295 .46186 .41192 .45962 .40933 Metetra
.634 .717 .907 r
.45962 .40933 .46186 .41192 .46577 .41091 .46355 .40831 Metetra
.633 .716 .907 r
.46355 .40831 .46577 .41091 .4697 .40991 .46747 .4073 Metetra
.632 .715 .907 r
.46747 .4073 .4697 .40991 .47363 .40893 .4714 .4063 Metetra
.961 .682 .46 r
.4714 .4063 .47363 .40893 .47756 .40795 .47214 .61407 Metetra
.544 .322 .528 r
.47214 .61407 .47756 .40795 .47871 .61511 .47634 .61283 Metetra
.768 .791 .871 r
.47634 .61283 .47871 .61511 .48291 .61388 .48057 .61002 Metetra
.944 .706 .549 r
.48057 .61002 .48291 .61388 .48734 .5928 .48521 .57288 Metetra
.783 .556 .591 r
.48521 .57288 .48734 .5928 .49181 .56423 .48961 .55051 Metetra
.785 .572 .611 r
.48961 .55051 .49181 .56423 .49612 .54575 .49389 .53517 Metetra
.783 .585 .632 r
.49389 .53517 .49612 .54575 .50036 .53257 .49812 .52381 Metetra
.777 .595 .653 r
.49812 .52381 .50036 .53257 .50456 .52257 .50231 .51498 Metetra
.769 .603 .673 r
.50231 .51498 .50456 .52257 .50873 .51469 .50648 .50788 Metetra
.759 .609 .692 r
.50648 .50788 .50873 .51469 .51289 .50829 .51064 .50204 Metetra
.748 .613 .709 r
.51064 .50204 .51289 .50829 .51703 .503 .51479 .49716 Metetra
.736 .616 .724 r
.51479 .49716 .51703 .503 .52118 .49858 .51893 .49303 Metetra
.723 .617 .739 r
.51893 .49303 .52118 .49858 .52532 .49486 .52307 .48953 Metetra
.709 .616 .751 r
.52307 .48953 .52532 .49486 .52946 .49173 .52722 .48656 Metetra
.693 .613 .763 r
.52722 .48656 .52946 .49173 .53361 .48911 .53137 .48405 Metetra
.676 .609 .772 r
.53137 .48405 .53361 .48911 .53776 .48696 .53552 .48196 Metetra
.658 .602 .781 r
.53552 .48196 .53776 .48696 .54191 .48523 .53967 .48026 Metetra
.638 .593 .788 r
.53967 .48026 .54191 .48523 .54608 .48393 .54384 .47895 Metetra
.615 .582 .793 r
.54384 .47895 .54608 .48393 .55025 .48304 .54801 .47802 Metetra
.589 .567 .797 r
.54801 .47802 .55025 .48304 .55444 .48258 .5522 .47749 Metetra
.56 .548 .798 r
.5522 .47749 .55444 .48258 .55863 .48258 .5564 .47738 Metetra
.526 .525 .798 r
.5564 .47738 .55863 .48258 .56285 .48311 .56061 .47773 Metetra
.485 .496 .794 r
.56061 .47773 .56285 .48311 .56708 .48422 .56484 .47862 Metetra
.436 .459 .785 r
.56484 .47862 .56708 .48422 .57134 .48605 .56909 .48014 Metetra
.376 .412 .771 r
.56909 .48014 .57134 .48605 .57562 .48875 .57336 .48243 Metetra
.301 .352 .748 r
.57336 .48243 .57562 .48875 .57994 .49257 .57767 .48568 Metetra
.209 .275 .713 r
.57767 .48568 .57994 .49257 .5843 .4979 .58201 .4902 Metetra
.094 .178 .66 r
.58201 .4902 .5843 .4979 .58873 .50537 .58641 .49648 Metetra
0 .057 .585 r
.58641 .49648 .58873 .50537 .59326 .51606 .59089 .50533 Metetra
0 0 .483 r
.59089 .50533 .59326 .51606 .59794 .53212 .59548 .51821 Metetra
0 0 .353 r
.59548 .51821 .59794 .53212 .60291 .55842 .60028 .53821 Metetra
0 0 .201 r
.60028 .53821 .60291 .55842 .60777 .57719 .6055 .5732 Metetra
.508 .583 .866 r
.6055 .5732 .60777 .57719 .61218 .57589 .60995 .5735 Metetra
.645 .763 .934 r
.60995 .5735 .61218 .57589 .6109 .3637 .61437 .57219 Metetra
0 0 .373 r
.61437 .57219 .6109 .3637 .61503 .36198 .61294 .35923 Metetra
.688 .734 .885 r
.61294 .35923 .61503 .36198 .61917 .36028 .61708 .35753 Metetra
.687 .734 .886 r
.61708 .35753 .61917 .36028 .62331 .3586 .62123 .35585 Metetra
.686 .734 .887 r
.62123 .35585 .62331 .3586 .62746 .35692 .62538 .35418 Metetra
.686 .735 .888 r
.62538 .35418 .62746 .35692 .63162 .35525 .62954 .35251 Metetra
.685 .735 .889 r
.62954 .35251 .63162 .35525 .63578 .3536 .63371 .35086 Metetra
.684 .735 .89 r
.63371 .35086 .63578 .3536 .63995 .35195 .63788 .34921 Metetra
.683 .735 .89 r
.63788 .34921 .63995 .35195 .64412 .35031 .64206 .34757 Metetra
.683 .736 .891 r
.64206 .34757 .64412 .35031 .6483 .34867 .64624 .34594 Metetra
.682 .736 .892 r
.64624 .34594 .6483 .34867 .65249 .34705 .65043 .34431 Metetra
.681 .736 .892 r
.65043 .34431 .65249 .34705 .65668 .34543 .65463 .3427 Metetra
.681 .736 .893 r
.65463 .3427 .65668 .34543 .66088 .34381 .65883 .34108 Metetra
.68 .736 .893 r
.65883 .34108 .66088 .34381 .66508 .3422 .66304 .33947 Metetra
.68 .737 .894 r
.66304 .33947 .66508 .3422 .66929 .3406 .66725 .33787 Metetra
.679 .737 .894 r
.66725 .33787 .66929 .3406 .6735 .339 .67147 .33627 Metetra
.679 .737 .895 r
.67147 .33627 .6735 .339 .67773 .3374 .6757 .33467 Metetra
.678 .737 .895 r
.6757 .33467 .67773 .3374 .68195 .33581 .67993 .33308 Metetra
.678 .737 .895 r
.67993 .33308 .68195 .33581 .68619 .33422 .68417 .33149 Metetra
.677 .737 .896 r
.68417 .33149 .68619 .33422 .69043 .33264 .68841 .3299 Metetra
.677 .737 .896 r
.68841 .3299 .69043 .33264 .69467 .33105 .69266 .32832 Metetra
.677 .738 .897 r
.69266 .32832 .69467 .33105 .69893 .32947 .69692 .32674 Metetra
.676 .738 .897 r
.69692 .32674 .69893 .32947 .70319 .3279 .70118 .32516 Metetra
.676 .738 .897 r
.70118 .32516 .70319 .3279 .70745 .32632 .70545 .32358 Metetra
.675 .738 .897 r
.70545 .32358 .70745 .32632 .71172 .32475 .70973 .32201 Metetra
.675 .738 .898 r
.70973 .32201 .71172 .32475 .716 .32318 .71401 .32043 Metetra
.675 .738 .898 r
.71401 .32043 .716 .32318 .72028 .32161 .7183 .31886 Metetra
.675 .738 .898 r
.7183 .31886 .72028 .32161 .72457 .32004 .72259 .31729 Metetra
.956 .763 .602 r
.72259 .31729 .72457 .32004 .72887 .31847 .72608 .30301 Metetra
.588 .426 .63 r
.72608 .30301 .72887 .31847 .73317 .3169 .73037 .30157 Metetra
.588 .427 .631 r
.73037 .30157 .73317 .3169 .73663 .30279 .73468 .30012 Metetra
.664 .741 .907 r
.73468 .30012 .73663 .30279 .74094 .30135 .73899 .29868 Metetra
.664 .741 .907 r
.73899 .29868 .74094 .30135 .74525 .2999 .74331 .29723 Metetra
.664 .741 .907 r
.74331 .29723 .74525 .2999 .74957 .29845 .74763 .29577 Metetra
.664 .741 .907 r
.74763 .29577 .74957 .29845 .75389 .297 .75196 .29432 Metetra
.664 .741 .907 r
.75196 .29432 .75389 .297 .75823 .29555 .7563 .29286 Metetra
.664 .741 .907 r
.7563 .29286 .75823 .29555 .76257 .2941 .76064 .29141 Metetra
.664 .741 .907 r
.76064 .29141 .76257 .2941 .76691 .29264 .76499 .28994 Metetra
.664 .741 .907 r
.76499 .28994 .76691 .29264 .77126 .29118 .76935 .28848 Metetra
.664 .741 .907 r
.76935 .28848 .77126 .29118 .77562 .28972 .77371 .28702 Metetra
.664 .741 .907 r
.77371 .28702 .77562 .28972 .77999 .28826 .77808 .28555 Metetra
.664 .741 .907 r
.77808 .28555 .77999 .28826 .78436 .28679 .78246 .28408 Metetra
.664 .741 .907 r
.78246 .28408 .78436 .28679 .78874 .28532 .78684 .28261 Metetra
.664 .741 .907 r
.78684 .28261 .78874 .28532 .79312 .28385 .79123 .28113 Metetra
.664 .741 .907 r
.79123 .28113 .79312 .28385 .79751 .28238 .79563 .27966 Metetra
.664 .741 .907 r
.79563 .27966 .79751 .28238 .80191 .2809 .80003 .27818 Metetra
.664 .741 .907 r
.80003 .27818 .80191 .2809 .80632 .27943 .80444 .2767 Metetra
.664 .741 .907 r
.80444 .2767 .80632 .27943 .81073 .27795 .80886 .27521 Metetra
.664 .741 .907 r
.80886 .27521 .81073 .27795 .81515 .27647 .81328 .27373 Metetra
.664 .741 .907 r
.81328 .27373 .81515 .27647 .81957 .27498 .81771 .27224 Metetra
.664 .741 .907 r
.81771 .27224 .81957 .27498 .82401 .2735 .82215 .27075 Metetra
.664 .741 .907 r
.82215 .27075 .82401 .2735 .82844 .27201 .82659 .26926 Metetra
.664 .741 .907 r
.82659 .26926 .82844 .27201 .83289 .27052 .83104 .26776 Metetra
.664 .741 .907 r
.83104 .26776 .83289 .27052 .83734 .26903 .8355 .26626 Metetra
.664 .741 .907 r
.8355 .26626 .83734 .26903 .8418 .26753 .83996 .26476 Metetra
.664 .741 .907 r
.83996 .26476 .8418 .26753 .84627 .26603 .84443 .26326 Metetra
.664 .741 .907 r
.84443 .26326 .84627 .26603 .85074 .26453 .84891 .26176 Metetra
.664 .741 .907 r
.84891 .26176 .85074 .26453 .85522 .26303 .8534 .26025 Metetra
.664 .741 .907 r
.8534 .26025 .85522 .26303 .85971 .26153 .85789 .25874 Metetra
.664 .741 .907 r
.25467 .45828 .25708 .46053 .2607 .45931 .2583 .45706 Metetra
.664 .741 .907 r
.2583 .45706 .2607 .45931 .26432 .4581 .26192 .45584 Metetra
.664 .741 .907 r
.26192 .45584 .26432 .4581 .26795 .45688 .26556 .45462 Metetra
.664 .741 .907 r
.26556 .45462 .26795 .45688 .27159 .45566 .26919 .4534 Metetra
.664 .741 .907 r
.26919 .4534 .27159 .45566 .27523 .45443 .27284 .45217 Metetra
.664 .741 .907 r
.27284 .45217 .27523 .45443 .27887 .45321 .27648 .45095 Metetra
.664 .741 .907 r
.27648 .45095 .27887 .45321 .28252 .45198 .28014 .44972 Metetra
.664 .741 .907 r
.28014 .44972 .28252 .45198 .28617 .45076 .28379 .44849 Metetra
.664 .741 .907 r
.28379 .44849 .28617 .45076 .28983 .44953 .28746 .44725 Metetra
.664 .741 .907 r
.28746 .44725 .28983 .44953 .2935 .4483 .29112 .44602 Metetra
.664 .741 .907 r
.29112 .44602 .2935 .4483 .29717 .44706 .2948 .44478 Metetra
.664 .741 .907 r
.2948 .44478 .29717 .44706 .30084 .44583 .29848 .44355 Metetra
.664 .741 .907 r
.29848 .44355 .30084 .44583 .30452 .44459 .30216 .44231 Metetra
.664 .741 .907 r
.30216 .44231 .30452 .44459 .30821 .44336 .30585 .44107 Metetra
.664 .741 .907 r
.30585 .44107 .30821 .44336 .3119 .44212 .30954 .43982 Metetra
.664 .741 .907 r
.30954 .43982 .3119 .44212 .3156 .44087 .31324 .43858 Metetra
.664 .741 .907 r
.31324 .43858 .3156 .44087 .3193 .43963 .31694 .43733 Metetra
.664 .741 .907 r
.31694 .43733 .3193 .43963 .323 .43839 .32065 .43608 Metetra
.664 .741 .907 r
.32065 .43608 .323 .43839 .32671 .43714 .32437 .43483 Metetra
.664 .741 .907 r
.32437 .43483 .32671 .43714 .33043 .43589 .32809 .43358 Metetra
.664 .741 .907 r
.32809 .43358 .33043 .43589 .33415 .43464 .33181 .43233 Metetra
.664 .741 .907 r
.33181 .43233 .33415 .43464 .33788 .43339 .33554 .43108 Metetra
.664 .741 .907 r
.33554 .43108 .33788 .43339 .34161 .43214 .33928 .42982 Metetra
.664 .741 .907 r
.33928 .42982 .34161 .43214 .34535 .43088 .34302 .42856 Metetra
.664 .741 .907 r
.34302 .42856 .34535 .43088 .34909 .42963 .34676 .4273 Metetra
.664 .741 .907 r
.34676 .4273 .34909 .42963 .35284 .42837 .35052 .42604 Metetra
.664 .741 .907 r
.35052 .42604 .35284 .42837 .35659 .42711 .35427 .42477 Metetra
.664 .741 .907 r
.35427 .42477 .35659 .42711 .36035 .42584 .35803 .42351 Metetra
.664 .741 .907 r
.35803 .42351 .36035 .42584 .36412 .42458 .3618 .42224 Metetra
.664 .741 .907 r
.3618 .42224 .36412 .42458 .36788 .42331 .36557 .42097 Metetra
.664 .741 .907 r
.36557 .42097 .36788 .42331 .37107 .43454 .36935 .4197 Metetra
.04 .03 .516 r
.36935 .4197 .37107 .43454 .37486 .43341 .37255 .43097 Metetra
.65 .73 .908 r
.37255 .43097 .37486 .43341 .37865 .43228 .37634 .42984 Metetra
.649 .729 .908 r
.37634 .42984 .37865 .43228 .38245 .43115 .38015 .4287 Metetra
.649 .729 .908 r
.38015 .4287 .38245 .43115 .38625 .43002 .38395 .42757 Metetra
.648 .729 .908 r
.38395 .42757 .38625 .43002 .39006 .42889 .38777 .42643 Metetra
.648 .728 .908 r
.38777 .42643 .39006 .42889 .39388 .42777 .39159 .4253 Metetra
.648 .728 .908 r
.39159 .4253 .39388 .42777 .3977 .42665 .39541 .42418 Metetra
.647 .728 .908 r
.39541 .42418 .3977 .42665 .40153 .42553 .39924 .42305 Metetra
.647 .727 .907 r
.39924 .42305 .40153 .42553 .40536 .42442 .40308 .42193 Metetra
.646 .727 .907 r
.40308 .42193 .40536 .42442 .4092 .42331 .40692 .42081 Metetra
.646 .726 .907 r
.40692 .42081 .4092 .42331 .41304 .4222 .41077 .4197 Metetra
.645 .726 .907 r
.41077 .4197 .41304 .4222 .41689 .42109 .41462 .41859 Metetra
.645 .725 .907 r
.41462 .41859 .41689 .42109 .42075 .42 .41848 .41748 Metetra
.644 .725 .907 r
.41848 .41748 .42075 .42 .42461 .4189 .42234 .41638 Metetra
.643 .724 .907 r
.42234 .41638 .42461 .4189 .42848 .41781 .42621 .41529 Metetra
.643 .724 .907 r
.42621 .41529 .42848 .41781 .43235 .41673 .43009 .41419 Metetra
.642 .723 .907 r
.43009 .41419 .43235 .41673 .43623 .41565 .43397 .41311 Metetra
.641 .722 .907 r
.43397 .41311 .43623 .41565 .44011 .41458 .43786 .41203 Metetra
.64 .722 .907 r
.43786 .41203 .44011 .41458 .444 .41351 .44175 .41095 Metetra
.639 .721 .907 r
.44175 .41095 .444 .41351 .4479 .41245 .44565 .40989 Metetra
.638 .72 .907 r
.44565 .40989 .4479 .41245 .4518 .4114 .44956 .40883 Metetra
.637 .719 .907 r
.44956 .40883 .4518 .4114 .45571 .41036 .45347 .40778 Metetra
.636 .718 .907 r
.45347 .40778 .45571 .41036 .45962 .40933 .45739 .40673 Metetra
.635 .718 .907 r
.45739 .40673 .45962 .40933 .46355 .40831 .46131 .4057 Metetra
.634 .716 .907 r
.46131 .4057 .46355 .40831 .46747 .4073 .46524 .40468 Metetra
.633 .715 .907 r
.46524 .40468 .46747 .4073 .4714 .4063 .46918 .40367 Metetra
.961 .682 .46 r
.46918 .40367 .4714 .4063 .47214 .61407 .46976 .61178 Metetra
.645 .763 .934 r
.46976 .61178 .47214 .61407 .47634 .61283 .47397 .61054 Metetra
.95 .731 .571 r
.47397 .61054 .47634 .61283 .48057 .61002 .47852 .58451 Metetra
.779 .545 .582 r
.47852 .58451 .48057 .61002 .48521 .57288 .48304 .55675 Metetra
.785 .564 .601 r
.48304 .55675 .48521 .57288 .48961 .55051 .48739 .53865 Metetra
.784 .579 .622 r
.48739 .53865 .48961 .55051 .49389 .53517 .49166 .52565 Metetra
.78 .59 .643 r
.49166 .52565 .49389 .53517 .49812 .52381 .49588 .51573 Metetra
.773 .6 .664 r
.49588 .51573 .49812 .52381 .50231 .51498 .50006 .50785 Metetra
.765 .607 .683 r
.50006 .50785 .50231 .51498 .50648 .50788 .50423 .50142 Metetra
.755 .613 .701 r
.50423 .50142 .50648 .50788 .51064 .50204 .50839 .49605 Metetra
.745 .617 .717 r
.50839 .49605 .51064 .50204 .51479 .49716 .51254 .49152 Metetra
.733 .619 .732 r
.51254 .49152 .51479 .49716 .51893 .49303 .51668 .48765 Metetra
.72 .62 .745 r
.51668 .48765 .51893 .49303 .52307 .48953 .52083 .48434 Metetra
.706 .619 .757 r
.52083 .48434 .52307 .48953 .52722 .48656 .52497 .4815 Metetra
.691 .616 .768 r
.52497 .4815 .52722 .48656 .53137 .48405 .52912 .47909 Metetra
.675 .612 .777 r
.52912 .47909 .53137 .48405 .53552 .48196 .53328 .47706 Metetra
.658 .606 .785 r
.53328 .47706 .53552 .48196 .53967 .48026 .53743 .47539 Metetra
.639 .598 .792 r
.53743 .47539 .53967 .48026 .54384 .47895 .5416 .47407 Metetra
.618 .587 .797 r
.5416 .47407 .54384 .47895 .54801 .47802 .54578 .47311 Metetra
.594 .573 .8 r
.54578 .47311 .54801 .47802 .5522 .47749 .54996 .4725 Metetra
.567 .557 .802 r
.54996 .4725 .5522 .47749 .5564 .47738 .55416 .47229 Metetra
.535 .536 .802 r
.55416 .47229 .5564 .47738 .56061 .47773 .55837 .4725 Metetra
.498 .509 .799 r
.55837 .4725 .56061 .47773 .56484 .47862 .56259 .47318 Metetra
.454 .476 .792 r
.56259 .47318 .56484 .47862 .56909 .48014 .56684 .47443 Metetra
.401 .435 .78 r
.56684 .47443 .56909 .48014 .57336 .48243 .5711 .47636 Metetra
.335 .382 .762 r
.5711 .47636 .57336 .48243 .57767 .48568 .5754 .47912 Metetra
.254 .314 .733 r
.5754 .47912 .57767 .48568 .58201 .4902 .57973 .48297 Metetra
.153 .229 .69 r
.57973 .48297 .58201 .4902 .58641 .49648 .5841 .48828 Metetra
.029 .122 .627 r
.5841 .48828 .58641 .49648 .59089 .50533 .58854 .49566 Metetra
0 0 .54 r
.58854 .49566 .59089 .50533 .59548 .51821 .59308 .50616 Metetra
0 0 .426 r
.59308 .50616 .59548 .51821 .60028 .53821 .59776 .52184 Metetra
0 0 .288 r
.59776 .52184 .60028 .53821 .6055 .5732 .60272 .54731 Metetra
.023 0 .484 r
.60272 .54731 .6055 .5732 .60995 .5735 .60771 .57109 Metetra
.645 .763 .934 r
.60771 .57109 .60995 .5735 .61437 .57219 .61214 .56979 Metetra
.972 .693 .442 r
.61214 .56979 .61437 .57219 .61294 .35923 .61084 .35647 Metetra
.688 .734 .886 r
.61084 .35647 .61294 .35923 .61708 .35753 .61498 .35478 Metetra
.687 .734 .887 r
.61498 .35478 .61708 .35753 .62123 .35585 .61914 .3531 Metetra
.686 .735 .888 r
.61914 .3531 .62123 .35585 .62538 .35418 .6233 .35143 Metetra
.685 .735 .888 r
.6233 .35143 .62538 .35418 .62954 .35251 .62746 .34977 Metetra
.684 .735 .889 r
.62746 .34977 .62954 .35251 .63371 .35086 .63163 .34811 Metetra
.684 .735 .89 r
.63163 .34811 .63371 .35086 .63788 .34921 .63581 .34647 Metetra
.683 .736 .891 r
.63581 .34647 .63788 .34921 .64206 .34757 .63999 .34483 Metetra
.682 .736 .891 r
.63999 .34483 .64206 .34757 .64624 .34594 .64418 .3432 Metetra
.682 .736 .892 r
.64418 .3432 .64624 .34594 .65043 .34431 .64837 .34158 Metetra
.681 .736 .892 r
.64837 .34158 .65043 .34431 .65463 .3427 .65257 .33996 Metetra
.68 .736 .893 r
.65257 .33996 .65463 .3427 .65883 .34108 .65678 .33834 Metetra
.68 .737 .893 r
.65678 .33834 .65883 .34108 .66304 .33947 .66099 .33674 Metetra
.679 .737 .894 r
.66099 .33674 .66304 .33947 .66725 .33787 .66521 .33513 Metetra
.679 .737 .894 r
.66521 .33513 .66725 .33787 .67147 .33627 .66943 .33353 Metetra
.678 .737 .895 r
.66943 .33353 .67147 .33627 .6757 .33467 .67366 .33193 Metetra
.678 .737 .895 r
.67366 .33193 .6757 .33467 .67993 .33308 .6779 .33034 Metetra
.677 .737 .896 r
.6779 .33034 .67993 .33308 .68417 .33149 .68214 .32875 Metetra
.677 .737 .896 r
.68214 .32875 .68417 .33149 .68841 .3299 .68639 .32716 Metetra
.677 .737 .896 r
.68639 .32716 .68841 .3299 .69266 .32832 .69065 .32558 Metetra
.676 .738 .897 r
.69065 .32558 .69266 .32832 .69692 .32674 .69491 .324 Metetra
.676 .738 .897 r
.69491 .324 .69692 .32674 .70118 .32516 .69918 .32242 Metetra
.676 .738 .897 r
.69918 .32242 .70118 .32516 .70545 .32358 .70345 .32084 Metetra
.675 .738 .898 r
.70345 .32084 .70545 .32358 .70973 .32201 .70773 .31926 Metetra
.675 .738 .898 r
.70773 .31926 .70973 .32201 .71401 .32043 .71202 .31769 Metetra
.675 .738 .898 r
.71202 .31769 .71401 .32043 .7183 .31886 .71631 .31611 Metetra
.956 .763 .602 r
.71631 .31611 .7183 .31886 .72259 .31729 .71981 .30179 Metetra
.588 .426 .63 r
.71981 .30179 .72259 .31729 .72608 .30301 .72411 .30035 Metetra
.664 .741 .907 r
.72411 .30035 .72608 .30301 .73037 .30157 .72841 .2989 Metetra
.664 .741 .907 r
.72841 .2989 .73037 .30157 .73468 .30012 .73272 .29745 Metetra
.664 .741 .907 r
.73272 .29745 .73468 .30012 .73899 .29868 .73704 .296 Metetra
.664 .741 .907 r
.73704 .296 .73899 .29868 .74331 .29723 .74136 .29454 Metetra
.664 .741 .907 r
.74136 .29454 .74331 .29723 .74763 .29577 .74569 .29309 Metetra
.664 .741 .907 r
.74569 .29309 .74763 .29577 .75196 .29432 .75002 .29163 Metetra
.664 .741 .907 r
.75002 .29163 .75196 .29432 .7563 .29286 .75436 .29017 Metetra
.664 .741 .907 r
.75436 .29017 .7563 .29286 .76064 .29141 .75871 .28871 Metetra
.664 .741 .907 r
.75871 .28871 .76064 .29141 .76499 .28994 .76306 .28724 Metetra
.664 .741 .907 r
.76306 .28724 .76499 .28994 .76935 .28848 .76743 .28577 Metetra
.664 .741 .907 r
.76743 .28577 .76935 .28848 .77371 .28702 .77179 .2843 Metetra
.664 .741 .907 r
.77179 .2843 .77371 .28702 .77808 .28555 .77617 .28283 Metetra
.664 .741 .907 r
.77617 .28283 .77808 .28555 .78246 .28408 .78055 .28136 Metetra
.664 .741 .907 r
.78055 .28136 .78246 .28408 .78684 .28261 .78494 .27988 Metetra
.664 .741 .907 r
.78494 .27988 .78684 .28261 .79123 .28113 .78933 .2784 Metetra
.664 .741 .907 r
.78933 .2784 .79123 .28113 .79563 .27966 .79373 .27692 Metetra
.664 .741 .907 r
.79373 .27692 .79563 .27966 .80003 .27818 .79814 .27544 Metetra
.664 .741 .907 r
.79814 .27544 .80003 .27818 .80444 .2767 .80256 .27395 Metetra
.664 .741 .907 r
.80256 .27395 .80444 .2767 .80886 .27521 .80698 .27247 Metetra
.664 .741 .907 r
.80698 .27247 .80886 .27521 .81328 .27373 .81141 .27098 Metetra
.664 .741 .907 r
.81141 .27098 .81328 .27373 .81771 .27224 .81584 .26949 Metetra
.664 .741 .907 r
.81584 .26949 .81771 .27224 .82215 .27075 .82028 .26799 Metetra
.664 .741 .907 r
.82028 .26799 .82215 .27075 .82659 .26926 .82473 .26649 Metetra
.664 .741 .907 r
.82473 .26649 .82659 .26926 .83104 .26776 .82919 .265 Metetra
.664 .741 .907 r
.82919 .265 .83104 .26776 .8355 .26626 .83365 .26349 Metetra
.664 .741 .907 r
.83365 .26349 .8355 .26626 .83996 .26476 .83812 .26199 Metetra
.664 .741 .907 r
.83812 .26199 .83996 .26476 .84443 .26326 .84259 .26048 Metetra
.664 .741 .907 r
.84259 .26048 .84443 .26326 .84891 .26176 .84708 .25898 Metetra
.664 .741 .907 r
.84708 .25898 .84891 .26176 .8534 .26025 .85157 .25747 Metetra
.664 .741 .907 r
.85157 .25747 .8534 .26025 .85789 .25874 .85606 .25595 Metetra
.664 .741 .907 r
.25226 .45603 .25467 .45828 .2583 .45706 .25589 .45481 Metetra
.664 .741 .907 r
.25589 .45481 .2583 .45706 .26192 .45584 .25952 .45359 Metetra
.664 .741 .907 r
.25952 .45359 .26192 .45584 .26556 .45462 .26315 .45236 Metetra
.664 .741 .907 r
.26315 .45236 .26556 .45462 .26919 .4534 .26679 .45113 Metetra
.664 .741 .907 r
.26679 .45113 .26919 .4534 .27284 .45217 .27044 .44991 Metetra
.664 .741 .907 r
.27044 .44991 .27284 .45217 .27648 .45095 .27409 .44868 Metetra
.664 .741 .907 r
.27409 .44868 .27648 .45095 .28014 .44972 .27775 .44744 Metetra
.664 .741 .907 r
.27775 .44744 .28014 .44972 .28379 .44849 .28141 .44621 Metetra
.664 .741 .907 r
.28141 .44621 .28379 .44849 .28746 .44725 .28507 .44497 Metetra
.664 .741 .907 r
.28507 .44497 .28746 .44725 .29112 .44602 .28874 .44374 Metetra
.664 .741 .907 r
.28874 .44374 .29112 .44602 .2948 .44478 .29242 .4425 Metetra
.664 .741 .907 r
.29242 .4425 .2948 .44478 .29848 .44355 .2961 .44126 Metetra
.664 .741 .907 r
.2961 .44126 .29848 .44355 .30216 .44231 .29979 .44001 Metetra
.664 .741 .907 r
.29979 .44001 .30216 .44231 .30585 .44107 .30348 .43877 Metetra
.664 .741 .907 r
.30348 .43877 .30585 .44107 .30954 .43982 .30718 .43752 Metetra
.664 .741 .907 r
.30718 .43752 .30954 .43982 .31324 .43858 .31088 .43628 Metetra
.664 .741 .907 r
.31088 .43628 .31324 .43858 .31694 .43733 .31459 .43503 Metetra
.664 .741 .907 r
.31459 .43503 .31694 .43733 .32065 .43608 .3183 .43378 Metetra
.664 .741 .907 r
.3183 .43378 .32065 .43608 .32437 .43483 .32202 .43252 Metetra
.664 .741 .907 r
.32202 .43252 .32437 .43483 .32809 .43358 .32574 .43127 Metetra
.664 .741 .907 r
.32574 .43127 .32809 .43358 .33181 .43233 .32947 .43001 Metetra
.664 .741 .907 r
.32947 .43001 .33181 .43233 .33554 .43108 .3332 .42875 Metetra
.664 .741 .907 r
.3332 .42875 .33554 .43108 .33928 .42982 .33694 .42749 Metetra
.664 .741 .907 r
.33694 .42749 .33928 .42982 .34302 .42856 .34068 .42623 Metetra
.664 .741 .907 r
.34068 .42623 .34302 .42856 .34676 .4273 .34443 .42497 Metetra
.664 .741 .907 r
.34443 .42497 .34676 .4273 .35052 .42604 .34819 .4237 Metetra
.664 .741 .907 r
.34819 .4237 .35052 .42604 .35427 .42477 .35195 .42244 Metetra
.664 .741 .907 r
.35195 .42244 .35427 .42477 .35803 .42351 .35571 .42117 Metetra
.664 .741 .907 r
.35571 .42117 .35803 .42351 .3618 .42224 .35948 .4199 Metetra
.664 .741 .907 r
.35948 .4199 .3618 .42224 .36557 .42097 .36326 .41862 Metetra
.664 .741 .907 r
.36326 .41862 .36557 .42097 .36935 .4197 .36704 .41735 Metetra
.664 .741 .907 r
.36704 .41735 .36935 .4197 .37255 .43097 .37082 .41607 Metetra
.039 .029 .516 r
.37082 .41607 .37255 .43097 .37634 .42984 .37403 .42739 Metetra
.65 .73 .908 r
.37403 .42739 .37634 .42984 .38015 .4287 .37784 .42625 Metetra
.649 .729 .908 r
.37784 .42625 .38015 .4287 .38395 .42757 .38165 .42511 Metetra
.649 .729 .908 r
.38165 .42511 .38395 .42757 .38777 .42643 .38546 .42397 Metetra
.648 .729 .908 r
.38546 .42397 .38777 .42643 .39159 .4253 .38929 .42283 Metetra
.648 .728 .908 r
.38929 .42283 .39159 .4253 .39541 .42418 .39311 .4217 Metetra
.647 .728 .907 r
.39311 .4217 .39541 .42418 .39924 .42305 .39695 .42057 Metetra
.647 .728 .907 r
.39695 .42057 .39924 .42305 .40308 .42193 .40079 .41944 Metetra
.647 .727 .907 r
.40079 .41944 .40308 .42193 .40692 .42081 .40463 .41832 Metetra
.646 .727 .907 r
.40463 .41832 .40692 .42081 .41077 .4197 .40848 .4172 Metetra
.645 .726 .907 r
.40848 .4172 .41077 .4197 .41462 .41859 .41234 .41608 Metetra
.645 .726 .907 r
.41234 .41608 .41462 .41859 .41848 .41748 .4162 .41497 Metetra
.644 .725 .907 r
.4162 .41497 .41848 .41748 .42234 .41638 .42007 .41386 Metetra
.644 .725 .907 r
.42007 .41386 .42234 .41638 .42621 .41529 .42394 .41275 Metetra
.643 .724 .907 r
.42394 .41275 .42621 .41529 .43009 .41419 .42782 .41165 Metetra
.642 .723 .907 r
.42782 .41165 .43009 .41419 .43397 .41311 .43171 .41056 Metetra
.642 .723 .907 r
.43171 .41056 .43397 .41311 .43786 .41203 .4356 .40947 Metetra
.641 .722 .907 r
.4356 .40947 .43786 .41203 .44175 .41095 .4395 .40839 Metetra
.64 .721 .907 r
.4395 .40839 .44175 .41095 .44565 .40989 .4434 .40731 Metetra
.639 .721 .907 r
.4434 .40731 .44565 .40989 .44956 .40883 .44731 .40624 Metetra
.638 .72 .907 r
.44731 .40624 .44956 .40883 .45347 .40778 .45122 .40518 Metetra
.637 .719 .907 r
.45122 .40518 .45347 .40778 .45739 .40673 .45515 .40413 Metetra
.636 .718 .907 r
.45515 .40413 .45739 .40673 .46131 .4057 .45907 .40309 Metetra
.635 .717 .907 r
.45907 .40309 .46131 .4057 .46524 .40468 .46301 .40206 Metetra
.961 .682 .461 r
.46301 .40206 .46524 .40468 .46918 .40367 .46318 .61073 Metetra
.543 .321 .527 r
.46318 .61073 .46918 .40367 .46976 .61178 .46738 .60949 Metetra
.907 .775 .703 r
.46738 .60949 .46976 .61178 .47397 .61054 .47171 .60058 Metetra
.897 .657 .567 r
.47171 .60058 .47397 .61054 .47852 .58451 .47641 .56493 Metetra
.782 .555 .592 r
.47641 .56493 .47852 .58451 .48304 .55675 .48086 .5432 Metetra
.785 .572 .612 r
.48086 .5432 .48304 .55675 .48739 .53865 .48517 .52817 Metetra
.782 .585 .633 r
.48517 .52817 .48739 .53865 .49166 .52565 .48942 .51697 Metetra
.777 .596 .654 r
.48942 .51697 .49166 .52565 .49588 .51573 .49363 .50821 Metetra
.77 .605 .674 r
.49363 .50821 .49588 .51573 .50006 .50785 .49781 .50112 Metetra
.761 .611 .692 r
.49781 .50112 .50006 .50785 .50423 .50142 .50198 .49524 Metetra
.752 .617 .709 r
.50198 .49524 .50423 .50142 .50839 .49605 .50614 .49029 Metetra
.741 .62 .725 r
.50614 .49029 .50839 .49605 .51254 .49152 .51029 .48605 Metetra
.729 .622 .739 r
.51029 .48605 .51254 .49152 .51668 .48765 .51443 .48241 Metetra
.717 .623 .752 r
.51443 .48241 .51668 .48765 .52083 .48434 .51858 .47927 Metetra
.703 .622 .763 r
.51858 .47927 .52083 .48434 .52497 .4815 .52273 .47656 Metetra
.689 .619 .773 r
.52273 .47656 .52497 .4815 .52912 .47909 .52688 .47423 Metetra
.674 .615 .782 r
.52688 .47423 .52912 .47909 .53328 .47706 .53103 .47225 Metetra
.658 .609 .789 r
.53103 .47225 .53328 .47706 .53743 .47539 .53519 .47061 Metetra
.64 .602 .795 r
.53519 .47061 .53743 .47539 .5416 .47407 .53936 .46928 Metetra
.62 .592 .8 r
.53936 .46928 .5416 .47407 .54578 .47311 .54353 .46829 Metetra
.598 .58 .804 r
.54353 .46829 .54578 .47311 .54996 .4725 .54772 .46762 Metetra
.573 .564 .806 r
.54772 .46762 .54996 .4725 .55416 .47229 .55192 .46731 Metetra
.544 .545 .806 r
.55192 .46731 .55416 .47229 .55837 .4725 .55612 .46739 Metetra
.511 .521 .804 r
.55612 .46739 .55837 .4725 .56259 .47318 .56035 .4679 Metetra
.471 .492 .798 r
.56035 .4679 .56259 .47318 .56684 .47443 .56459 .46891 Metetra
.423 .455 .789 r
.56459 .46891 .56684 .47443 .5711 .47636 .56885 .47052 Metetra
.365 .408 .773 r
.56885 .47052 .5711 .47636 .5754 .47912 .57313 .47286 Metetra
.293 .349 .75 r
.57313 .47286 .5754 .47912 .57973 .48297 .57745 .47614 Metetra
.204 .274 .714 r
.57745 .47614 .57973 .48297 .5841 .48828 .58181 .48064 Metetra
.095 .18 .663 r
.58181 .48064 .5841 .48828 .58854 .49566 .58622 .48684 Metetra
0 .063 .59 r
.58622 .48684 .58854 .49566 .59308 .50616 .5907 .49551 Metetra
0 0 .491 r
.5907 .49551 .59308 .50616 .59776 .52184 .5953 .50807 Metetra
0 0 .367 r
.5953 .50807 .59776 .52184 .60272 .54731 .6001 .52743 Metetra
0 0 .22 r
.6001 .52743 .60272 .54731 .60771 .57109 .60529 .56092 Metetra
.231 .231 .653 r
.60529 .56092 .60771 .57109 .61214 .56979 .6099 .56737 Metetra
.645 .763 .934 r
.6099 .56737 .61214 .56979 .61084 .35647 .61434 .56606 Metetra
0 0 .371 r
.61434 .56606 .61084 .35647 .61498 .35478 .61288 .35202 Metetra
.686 .734 .887 r
.61288 .35202 .61498 .35478 .61914 .3531 .61704 .35034 Metetra
.685 .735 .888 r
.61704 .35034 .61914 .3531 .6233 .35143 .6212 .34867 Metetra
.685 .735 .889 r
.6212 .34867 .6233 .35143 .62746 .34977 .62537 .34701 Metetra
.684 .735 .89 r
.62537 .34701 .62746 .34977 .63163 .34811 .62955 .34536 Metetra
.683 .735 .89 r
.62955 .34536 .63163 .34811 .63581 .34647 .63373 .34372 Metetra
.682 .736 .891 r
.63373 .34372 .63581 .34647 .63999 .34483 .63791 .34209 Metetra
.682 .736 .892 r
.63791 .34209 .63999 .34483 .64418 .3432 .64211 .34046 Metetra
.681 .736 .892 r
.64211 .34046 .64418 .3432 .64837 .34158 .64631 .33883 Metetra
.681 .736 .893 r
.64631 .33883 .64837 .34158 .65257 .33996 .65051 .33722 Metetra
.68 .736 .893 r
.65051 .33722 .65257 .33996 .65678 .33834 .65472 .3356 Metetra
.679 .737 .894 r
.65472 .3356 .65678 .33834 .66099 .33674 .65894 .33399 Metetra
.679 .737 .894 r
.65894 .33399 .66099 .33674 .66521 .33513 .66316 .33239 Metetra
.678 .737 .895 r
.66316 .33239 .66521 .33513 .66943 .33353 .66739 .33079 Metetra
.678 .737 .895 r
.66739 .33079 .66943 .33353 .67366 .33193 .67162 .32919 Metetra
.678 .737 .895 r
.67162 .32919 .67366 .33193 .6779 .33034 .67586 .3276 Metetra
.677 .737 .896 r
.67586 .3276 .6779 .33034 .68214 .32875 .68011 .32601 Metetra
.677 .737 .896 r
.68011 .32601 .68214 .32875 .68639 .32716 .68437 .32442 Metetra
.676 .737 .897 r
.68437 .32442 .68639 .32716 .69065 .32558 .68863 .32283 Metetra
.676 .738 .897 r
.68863 .32283 .69065 .32558 .69491 .324 .69289 .32125 Metetra
.676 .738 .897 r
.69289 .32125 .69491 .324 .69918 .32242 .69716 .31967 Metetra
.675 .738 .897 r
.69716 .31967 .69918 .32242 .70345 .32084 .70144 .31809 Metetra
.675 .738 .898 r
.70144 .31809 .70345 .32084 .70773 .31926 .70573 .31651 Metetra
.675 .738 .898 r
.70573 .31651 .70773 .31926 .71202 .31769 .71002 .31493 Metetra
.955 .762 .602 r
.71002 .31493 .71202 .31769 .71631 .31611 .71354 .30057 Metetra
.587 .425 .629 r
.71354 .30057 .71631 .31611 .71981 .30179 .71784 .29912 Metetra
.664 .741 .907 r
.71784 .29912 .71981 .30179 .72411 .30035 .72214 .29767 Metetra
.664 .741 .907 r
.72214 .29767 .72411 .30035 .72841 .2989 .72644 .29622 Metetra
.664 .741 .907 r
.72644 .29622 .72841 .2989 .73272 .29745 .73076 .29477 Metetra
.664 .741 .907 r
.73076 .29477 .73272 .29745 .73704 .296 .73508 .29331 Metetra
.664 .741 .907 r
.73508 .29331 .73704 .296 .74136 .29454 .7394 .29185 Metetra
.664 .741 .907 r
.7394 .29185 .74136 .29454 .74569 .29309 .74374 .29039 Metetra
.664 .741 .907 r
.74374 .29039 .74569 .29309 .75002 .29163 .74808 .28893 Metetra
.664 .741 .907 r
.74808 .28893 .75002 .29163 .75436 .29017 .75242 .28747 Metetra
.664 .741 .907 r
.75242 .28747 .75436 .29017 .75871 .28871 .75677 .286 Metetra
.664 .741 .907 r
.75677 .286 .75871 .28871 .76306 .28724 .76113 .28453 Metetra
.664 .741 .907 r
.76113 .28453 .76306 .28724 .76743 .28577 .7655 .28306 Metetra
.664 .741 .907 r
.7655 .28306 .76743 .28577 .77179 .2843 .76987 .28159 Metetra
.664 .741 .907 r
.76987 .28159 .77179 .2843 .77617 .28283 .77425 .28011 Metetra
.664 .741 .907 r
.77425 .28011 .77617 .28283 .78055 .28136 .77864 .27863 Metetra
.664 .741 .907 r
.77864 .27863 .78055 .28136 .78494 .27988 .78303 .27715 Metetra
.664 .741 .907 r
.78303 .27715 .78494 .27988 .78933 .2784 .78743 .27567 Metetra
.664 .741 .907 r
.78743 .27567 .78933 .2784 .79373 .27692 .79183 .27418 Metetra
.664 .741 .907 r
.79183 .27418 .79373 .27692 .79814 .27544 .79625 .2727 Metetra
.664 .741 .907 r
.79625 .2727 .79814 .27544 .80256 .27395 .80067 .27121 Metetra
.664 .741 .907 r
.80067 .27121 .80256 .27395 .80698 .27247 .80509 .26972 Metetra
.664 .741 .907 r
.80509 .26972 .80698 .27247 .81141 .27098 .80953 .26822 Metetra
.664 .741 .907 r
.80953 .26822 .81141 .27098 .81584 .26949 .81397 .26672 Metetra
.664 .741 .907 r
.81397 .26672 .81584 .26949 .82028 .26799 .81841 .26523 Metetra
.664 .741 .907 r
.81841 .26523 .82028 .26799 .82473 .26649 .82287 .26373 Metetra
.664 .741 .907 r
.82287 .26373 .82473 .26649 .82919 .265 .82733 .26222 Metetra
.664 .741 .907 r
.82733 .26222 .82919 .265 .83365 .26349 .83179 .26072 Metetra
.664 .741 .907 r
.83179 .26072 .83365 .26349 .83812 .26199 .83627 .25921 Metetra
.664 .741 .907 r
.83627 .25921 .83812 .26199 .84259 .26048 .84075 .2577 Metetra
.664 .741 .907 r
.84075 .2577 .84259 .26048 .84708 .25898 .84524 .25619 Metetra
.664 .741 .907 r
.84524 .25619 .84708 .25898 .85157 .25747 .84973 .25467 Metetra
.664 .741 .907 r
.84973 .25467 .85157 .25747 .85606 .25595 .85423 .25315 Metetra
.664 .741 .907 r
.24985 .45377 .25226 .45603 .25589 .45481 .25347 .45255 Metetra
.664 .741 .907 r
.25347 .45255 .25589 .45481 .25952 .45359 .25711 .45132 Metetra
.664 .741 .907 r
.25711 .45132 .25952 .45359 .26315 .45236 .26075 .45009 Metetra
.664 .741 .907 r
.26075 .45009 .26315 .45236 .26679 .45113 .26439 .44886 Metetra
.664 .741 .907 r
.26439 .44886 .26679 .45113 .27044 .44991 .26804 .44763 Metetra
.664 .741 .907 r
.26804 .44763 .27044 .44991 .27409 .44868 .27169 .4464 Metetra
.664 .741 .907 r
.27169 .4464 .27409 .44868 .27775 .44744 .27535 .44516 Metetra
.664 .741 .907 r
.27535 .44516 .27775 .44744 .28141 .44621 .27901 .44393 Metetra
.664 .741 .907 r
.27901 .44393 .28141 .44621 .28507 .44497 .28268 .44269 Metetra
.664 .741 .907 r
.28268 .44269 .28507 .44497 .28874 .44374 .28636 .44145 Metetra
.664 .741 .907 r
.28636 .44145 .28874 .44374 .29242 .4425 .29004 .44021 Metetra
.664 .741 .907 r
.29004 .44021 .29242 .4425 .2961 .44126 .29372 .43896 Metetra
.664 .741 .907 r
.29372 .43896 .2961 .44126 .29979 .44001 .29741 .43772 Metetra
.664 .741 .907 r
.29741 .43772 .29979 .44001 .30348 .43877 .30111 .43647 Metetra
.664 .741 .907 r
.30111 .43647 .30348 .43877 .30718 .43752 .30481 .43522 Metetra
.664 .741 .907 r
.30481 .43522 .30718 .43752 .31088 .43628 .30851 .43397 Metetra
.664 .741 .907 r
.30851 .43397 .31088 .43628 .31459 .43503 .31222 .43272 Metetra
.664 .741 .907 r
.31222 .43272 .31459 .43503 .3183 .43378 .31594 .43146 Metetra
.664 .741 .907 r
.31594 .43146 .3183 .43378 .32202 .43252 .31966 .43021 Metetra
.664 .741 .907 r
.31966 .43021 .32202 .43252 .32574 .43127 .32338 .42895 Metetra
.664 .741 .907 r
.32338 .42895 .32574 .43127 .32947 .43001 .32711 .42769 Metetra
.664 .741 .907 r
.32711 .42769 .32947 .43001 .3332 .42875 .33085 .42643 Metetra
.664 .741 .907 r
.33085 .42643 .3332 .42875 .33694 .42749 .33459 .42516 Metetra
.664 .741 .907 r
.33459 .42516 .33694 .42749 .34068 .42623 .33834 .4239 Metetra
.664 .741 .907 r
.33834 .4239 .34068 .42623 .34443 .42497 .34209 .42263 Metetra
.664 .741 .907 r
.34209 .42263 .34443 .42497 .34819 .4237 .34585 .42136 Metetra
.664 .741 .907 r
.34585 .42136 .34819 .4237 .35195 .42244 .34961 .42009 Metetra
.664 .741 .907 r
.34961 .42009 .35195 .42244 .35571 .42117 .35338 .41882 Metetra
.664 .741 .907 r
.35338 .41882 .35571 .42117 .35948 .4199 .35715 .41755 Metetra
.664 .741 .907 r
.35715 .41755 .35948 .4199 .36326 .41862 .36093 .41627 Metetra
.664 .741 .907 r
.36093 .41627 .36326 .41862 .36704 .41735 .36472 .41499 Metetra
.664 .741 .907 r
.36472 .41499 .36704 .41735 .37082 .41607 .36851 .41371 Metetra
.664 .741 .907 r
.36851 .41371 .37082 .41607 .37403 .42739 .3723 .41243 Metetra
.038 .028 .515 r
.3723 .41243 .37403 .42739 .37784 .42625 .37552 .42379 Metetra
.649 .729 .908 r
.37552 .42379 .37784 .42625 .38165 .42511 .37934 .42264 Metetra
.649 .729 .908 r
.37934 .42264 .38165 .42511 .38546 .42397 .38316 .4215 Metetra
.649 .729 .908 r
.38316 .4215 .38546 .42397 .38929 .42283 .38698 .42036 Metetra
.648 .728 .908 r
.38698 .42036 .38929 .42283 .39311 .4217 .39081 .41922 Metetra
.648 .728 .907 r
.39081 .41922 .39311 .4217 .39695 .42057 .39465 .41808 Metetra
.647 .728 .907 r
.39465 .41808 .39695 .42057 .40079 .41944 .39849 .41695 Metetra
.647 .727 .907 r
.39849 .41695 .40079 .41944 .40463 .41832 .40234 .41582 Metetra
.646 .727 .907 r
.40234 .41582 .40463 .41832 .40848 .4172 .40619 .41469 Metetra
.646 .726 .907 r
.40619 .41469 .40848 .4172 .41234 .41608 .41005 .41357 Metetra
.645 .726 .907 r
.41005 .41357 .41234 .41608 .4162 .41497 .41392 .41245 Metetra
.645 .725 .907 r
.41392 .41245 .4162 .41497 .42007 .41386 .41779 .41133 Metetra
.644 .725 .907 r
.41779 .41133 .42007 .41386 .42394 .41275 .42167 .41022 Metetra
.643 .724 .907 r
.42167 .41022 .42394 .41275 .42782 .41165 .42555 .40911 Metetra
.643 .724 .907 r
.42555 .40911 .42782 .41165 .43171 .41056 .42944 .40801 Metetra
.642 .723 .907 r
.42944 .40801 .43171 .41056 .4356 .40947 .43333 .40691 Metetra
.641 .723 .907 r
.43333 .40691 .4356 .40947 .4395 .40839 .43723 .40582 Metetra
.64 .722 .907 r
.43723 .40582 .4395 .40839 .4434 .40731 .44114 .40474 Metetra
.64 .721 .907 r
.44114 .40474 .4434 .40731 .44731 .40624 .44505 .40366 Metetra
.639 .72 .907 r
.44505 .40366 .44731 .40624 .45122 .40518 .44897 .40259 Metetra
.638 .719 .907 r
.44897 .40259 .45122 .40518 .45515 .40413 .4529 .40153 Metetra
.637 .719 .907 r
.4529 .40153 .45515 .40413 .45907 .40309 .45683 .40047 Metetra
.635 .718 .907 r
.45683 .40047 .45907 .40309 .46301 .40206 .46076 .39943 Metetra
.961 .682 .461 r
.46076 .39943 .46301 .40206 .46318 .61073 .46078 .60844 Metetra
.645 .763 .934 r
.46078 .60844 .46318 .61073 .46738 .60949 .46499 .60719 Metetra
.952 .724 .556 r
.46499 .60719 .46738 .60949 .47171 .60058 .4697 .57578 Metetra
.778 .545 .583 r
.4697 .57578 .47171 .60058 .47641 .56493 .47427 .54908 Metetra
.784 .564 .603 r
.47427 .54908 .47641 .56493 .48086 .5432 .47865 .53149 Metetra
.783 .579 .624 r
.47865 .53149 .48086 .5432 .48517 .52817 .48294 .51875 Metetra
.78 .591 .644 r
.48294 .51875 .48517 .52817 .48942 .51697 .48718 .50897 Metetra
.774 .601 .665 r
.48718 .50897 .48942 .51697 .49363 .50821 .49138 .50116 Metetra
.766 .609 .684 r
.49138 .50116 .49363 .50821 .49781 .50112 .49556 .49472 Metetra
.758 .615 .701 r
.49556 .49472 .49781 .50112 .50198 .49524 .49972 .48932 Metetra
.748 .62 .718 r
.49972 .48932 .50198 .49524 .50614 .49029 .50388 .48472 Metetra
.737 .624 .732 r
.50388 .48472 .50614 .49029 .51029 .48605 .50803 .48075 Metetra
.726 .625 .746 r
.50803 .48075 .51029 .48605 .51443 .48241 .51218 .47731 Metetra
.714 .626 .758 r
.51218 .47731 .51443 .48241 .51858 .47927 .51633 .47432 Metetra
.701 .625 .768 r
.51633 .47432 .51858 .47927 .52273 .47656 .52048 .47172 Metetra
.687 .622 .778 r
.52048 .47172 .52273 .47656 .52688 .47423 .52463 .46946 Metetra
.673 .619 .786 r
.52463 .46946 .52688 .47423 .53103 .47225 .52878 .46753 Metetra
.657 .613 .793 r
.52878 .46753 .53103 .47225 .53519 .47061 .53295 .46591 Metetra
.641 .606 .799 r
.53295 .46591 .53519 .47061 .53936 .46928 .53711 .46458 Metetra
.622 .597 .804 r
.53711 .46458 .53936 .46928 .54353 .46829 .54129 .46356 Metetra
.602 .585 .807 r
.54129 .46356 .54353 .46829 .54772 .46762 .54548 .46283 Metetra
.578 .571 .809 r
.54548 .46283 .54772 .46762 .55192 .46731 .54967 .46244 Metetra
.552 .554 .81 r
.54967 .46244 .55192 .46731 .55612 .46739 .55388 .4624 Metetra
.522 .533 .808 r
.55388 .4624 .55612 .46739 .56035 .4679 .5581 .46275 Metetra
.486 .506 .804 r
.5581 .46275 .56035 .4679 .56459 .46891 .56234 .46355 Metetra
.443 .473 .796 r
.56234 .46355 .56459 .46891 .56885 .47052 .5666 .46488 Metetra
.391 .432 .783 r
.5666 .46488 .56885 .47052 .57313 .47286 .57087 .46686 Metetra
.328 .38 .764 r
.57087 .46686 .57313 .47286 .57745 .47614 .57518 .46965 Metetra
.25 .314 .735 r
.57518 .46965 .57745 .47614 .58181 .48064 .57952 .47348 Metetra
.153 .231 .692 r
.57952 .47348 .58181 .48064 .58622 .48684 .58391 .47871 Metetra
.035 .128 .631 r
.58391 .47871 .58622 .48684 .5907 .49551 .58835 .48594 Metetra
0 .003 .548 r
.58835 .48594 .5907 .49551 .5953 .50807 .59289 .49616 Metetra
0 0 .438 r
.59289 .49616 .5953 .50807 .6001 .52743 .59757 .51132 Metetra
0 0 .305 r
.59757 .51132 .6001 .52743 .60529 .56092 .60252 .53572 Metetra
0 0 .407 r
.60252 .53572 .60529 .56092 .6099 .56737 .60766 .56495 Metetra
.645 .763 .934 r
.60766 .56495 .6099 .56737 .61434 .56606 .6121 .56364 Metetra
.972 .693 .44 r
.6121 .56364 .61434 .56606 .61288 .35202 .61078 .34925 Metetra
.686 .734 .888 r
.61078 .34925 .61288 .35202 .61704 .35034 .61494 .34758 Metetra
.685 .735 .888 r
.61494 .34758 .61704 .35034 .6212 .34867 .61911 .34591 Metetra
.684 .735 .889 r
.61911 .34591 .6212 .34867 .62537 .34701 .62328 .34426 Metetra
.683 .735 .89 r
.62328 .34426 .62537 .34701 .62955 .34536 .62746 .34261 Metetra
.683 .735 .891 r
.62746 .34261 .62955 .34536 .63373 .34372 .63164 .34097 Metetra
.682 .736 .891 r
.63164 .34097 .63373 .34372 .63791 .34209 .63583 .33934 Metetra
.681 .736 .892 r
.63583 .33934 .63791 .34209 .64211 .34046 .64003 .33771 Metetra
.681 .736 .892 r
.64003 .33771 .64211 .34046 .64631 .33883 .64423 .33608 Metetra
.68 .736 .893 r
.64423 .33608 .64631 .33883 .65051 .33722 .64844 .33447 Metetra
.68 .736 .893 r
.64844 .33447 .65051 .33722 .65472 .3356 .65266 .33285 Metetra
.679 .737 .894 r
.65266 .33285 .65472 .3356 .65894 .33399 .65688 .33125 Metetra
.679 .737 .894 r
.65688 .33125 .65894 .33399 .66316 .33239 .66111 .32964 Metetra
.678 .737 .895 r
.66111 .32964 .66316 .33239 .66739 .33079 .66534 .32804 Metetra
.678 .737 .895 r
.66534 .32804 .66739 .33079 .67162 .32919 .66958 .32644 Metetra
.677 .737 .896 r
.66958 .32644 .67162 .32919 .67586 .3276 .67382 .32485 Metetra
.677 .737 .896 r
.67382 .32485 .67586 .3276 .68011 .32601 .67808 .32326 Metetra
.677 .737 .896 r
.67808 .32326 .68011 .32601 .68437 .32442 .68233 .32167 Metetra
.676 .738 .897 r
.68233 .32167 .68437 .32442 .68863 .32283 .6866 .32008 Metetra
.676 .738 .897 r
.6866 .32008 .68863 .32283 .69289 .32125 .69087 .31849 Metetra
.675 .738 .897 r
.69087 .31849 .69289 .32125 .69716 .31967 .69515 .31691 Metetra
.675 .738 .898 r
.69515 .31691 .69716 .31967 .70144 .31809 .69943 .31533 Metetra
.675 .738 .898 r
.69943 .31533 .70144 .31809 .70573 .31651 .70372 .31375 Metetra
.955 .762 .603 r
.70372 .31375 .70573 .31651 .71002 .31493 .70726 .29935 Metetra
.587 .425 .629 r
.70726 .29935 .71002 .31493 .71354 .30057 .71156 .2979 Metetra
.664 .741 .907 r
.71156 .2979 .71354 .30057 .71784 .29912 .71585 .29645 Metetra
.664 .741 .907 r
.71585 .29645 .71784 .29912 .72214 .29767 .72016 .29499 Metetra
.664 .741 .907 r
.72016 .29499 .72214 .29767 .72644 .29622 .72447 .29354 Metetra
.664 .741 .907 r
.72447 .29354 .72644 .29622 .73076 .29477 .72879 .29208 Metetra
.664 .741 .907 r
.72879 .29208 .73076 .29477 .73508 .29331 .73311 .29062 Metetra
.664 .741 .907 r
.73311 .29062 .73508 .29331 .7394 .29185 .73744 .28916 Metetra
.664 .741 .907 r
.73744 .28916 .7394 .29185 .74374 .29039 .74178 .28769 Metetra
.664 .741 .907 r
.74178 .28769 .74374 .29039 .74808 .28893 .74612 .28623 Metetra
.664 .741 .907 r
.74612 .28623 .74808 .28893 .75242 .28747 .75048 .28476 Metetra
.664 .741 .907 r
.75048 .28476 .75242 .28747 .75677 .286 .75483 .28329 Metetra
.664 .741 .907 r
.75483 .28329 .75677 .286 .76113 .28453 .7592 .28181 Metetra
.664 .741 .907 r
.7592 .28181 .76113 .28453 .7655 .28306 .76357 .28034 Metetra
.664 .741 .907 r
.76357 .28034 .7655 .28306 .76987 .28159 .76794 .27886 Metetra
.664 .741 .907 r
.76794 .27886 .76987 .28159 .77425 .28011 .77233 .27738 Metetra
.664 .741 .907 r
.77233 .27738 .77425 .28011 .77864 .27863 .77672 .2759 Metetra
.664 .741 .907 r
.77672 .2759 .77864 .27863 .78303 .27715 .78112 .27441 Metetra
.664 .741 .907 r
.78112 .27441 .78303 .27715 .78743 .27567 .78552 .27293 Metetra
.664 .741 .907 r
.78552 .27293 .78743 .27567 .79183 .27418 .78993 .27144 Metetra
.664 .741 .907 r
.78993 .27144 .79183 .27418 .79625 .2727 .79435 .26994 Metetra
.664 .741 .907 r
.79435 .26994 .79625 .2727 .80067 .27121 .79877 .26845 Metetra
.664 .741 .907 r
.79877 .26845 .80067 .27121 .80509 .26972 .8032 .26696 Metetra
.664 .741 .907 r
.8032 .26696 .80509 .26972 .80953 .26822 .80764 .26546 Metetra
.664 .741 .907 r
.80764 .26546 .80953 .26822 .81397 .26672 .81209 .26396 Metetra
.664 .741 .907 r
.81209 .26396 .81397 .26672 .81841 .26523 .81654 .26245 Metetra
.664 .741 .907 r
.81654 .26245 .81841 .26523 .82287 .26373 .821 .26095 Metetra
.664 .741 .907 r
.821 .26095 .82287 .26373 .82733 .26222 .82546 .25944 Metetra
.664 .741 .907 r
.82546 .25944 .82733 .26222 .83179 .26072 .82993 .25793 Metetra
.664 .741 .907 r
.82993 .25793 .83179 .26072 .83627 .25921 .83441 .25642 Metetra
.664 .741 .907 r
.83441 .25642 .83627 .25921 .84075 .2577 .8389 .2549 Metetra
.664 .741 .907 r
.8389 .2549 .84075 .2577 .84524 .25619 .84339 .25339 Metetra
.664 .741 .907 r
.84339 .25339 .84524 .25619 .84973 .25467 .84789 .25187 Metetra
.664 .741 .907 r
.84789 .25187 .84973 .25467 .85423 .25315 .8524 .25035 Metetra
.664 .741 .907 r
.24742 .45151 .24985 .45377 .25347 .45255 .25105 .45028 Metetra
.664 .741 .907 r
.25105 .45028 .25347 .45255 .25711 .45132 .25469 .44905 Metetra
.664 .741 .907 r
.25469 .44905 .25711 .45132 .26075 .45009 .25833 .44782 Metetra
.664 .741 .907 r
.25833 .44782 .26075 .45009 .26439 .44886 .26198 .44659 Metetra
.664 .741 .907 r
.26198 .44659 .26439 .44886 .26804 .44763 .26563 .44535 Metetra
.664 .741 .907 r
.26563 .44535 .26804 .44763 .27169 .4464 .26929 .44412 Metetra
.664 .741 .907 r
.26929 .44412 .27169 .4464 .27535 .44516 .27295 .44288 Metetra
.664 .741 .907 r
.27295 .44288 .27535 .44516 .27901 .44393 .27662 .44164 Metetra
.664 .741 .907 r
.27662 .44164 .27901 .44393 .28268 .44269 .28029 .4404 Metetra
.664 .741 .907 r
.28029 .4404 .28268 .44269 .28636 .44145 .28397 .43915 Metetra
.664 .741 .907 r
.28397 .43915 .28636 .44145 .29004 .44021 .28765 .43791 Metetra
.664 .741 .907 r
.28765 .43791 .29004 .44021 .29372 .43896 .29134 .43666 Metetra
.664 .741 .907 r
.29134 .43666 .29372 .43896 .29741 .43772 .29503 .43541 Metetra
.664 .741 .907 r
.29503 .43541 .29741 .43772 .30111 .43647 .29873 .43416 Metetra
.664 .741 .907 r
.29873 .43416 .30111 .43647 .30481 .43522 .30243 .43291 Metetra
.664 .741 .907 r
.30243 .43291 .30481 .43522 .30851 .43397 .30614 .43165 Metetra
.664 .741 .907 r
.30614 .43165 .30851 .43397 .31222 .43272 .30985 .4304 Metetra
.664 .741 .907 r
.30985 .4304 .31222 .43272 .31594 .43146 .31357 .42914 Metetra
.664 .741 .907 r
.31357 .42914 .31594 .43146 .31966 .43021 .31729 .42788 Metetra
.664 .741 .907 r
.31729 .42788 .31966 .43021 .32338 .42895 .32102 .42662 Metetra
.664 .741 .907 r
.32102 .42662 .32338 .42895 .32711 .42769 .32476 .42536 Metetra
.664 .741 .907 r
.32476 .42536 .32711 .42769 .33085 .42643 .3285 .42409 Metetra
.664 .741 .907 r
.3285 .42409 .33085 .42643 .33459 .42516 .33224 .42283 Metetra
.664 .741 .907 r
.33224 .42283 .33459 .42516 .33834 .4239 .33599 .42156 Metetra
.664 .741 .907 r
.33599 .42156 .33834 .4239 .34209 .42263 .33975 .42029 Metetra
.664 .741 .907 r
.33975 .42029 .34209 .42263 .34585 .42136 .34351 .41902 Metetra
.664 .741 .907 r
.34351 .41902 .34585 .42136 .34961 .42009 .34727 .41774 Metetra
.664 .741 .907 r
.34727 .41774 .34961 .42009 .35338 .41882 .35105 .41647 Metetra
.664 .741 .907 r
.35105 .41647 .35338 .41882 .35715 .41755 .35482 .41519 Metetra
.664 .741 .907 r
.35482 .41519 .35715 .41755 .36093 .41627 .35861 .41391 Metetra
.664 .741 .907 r
.35861 .41391 .36093 .41627 .36472 .41499 .36239 .41263 Metetra
.664 .741 .907 r
.36239 .41263 .36472 .41499 .36851 .41371 .36619 .41135 Metetra
.664 .741 .907 r
.36619 .41135 .36851 .41371 .3723 .41243 .36998 .41006 Metetra
.664 .741 .907 r
.36998 .41006 .3723 .41243 .37552 .42379 .37379 .40878 Metetra
.038 .028 .515 r
.37379 .40878 .37552 .42379 .37934 .42264 .37702 .42017 Metetra
.649 .729 .908 r
.37702 .42017 .37934 .42264 .38316 .4215 .38084 .41903 Metetra
.649 .729 .908 r
.38084 .41903 .38316 .4215 .38698 .42036 .38467 .41788 Metetra
.648 .729 .907 r
.38467 .41788 .38698 .42036 .39081 .41922 .38851 .41673 Metetra
.648 .728 .907 r
.38851 .41673 .39081 .41922 .39465 .41808 .39235 .41559 Metetra
.648 .728 .907 r
.39235 .41559 .39465 .41808 .39849 .41695 .39619 .41445 Metetra
.647 .728 .907 r
.39619 .41445 .39849 .41695 .40234 .41582 .40004 .41331 Metetra
.647 .727 .907 r
.40004 .41331 .40234 .41582 .40619 .41469 .4039 .41218 Metetra
.646 .727 .907 r
.4039 .41218 .40619 .41469 .41005 .41357 .40776 .41105 Metetra
.646 .726 .907 r
.40776 .41105 .41005 .41357 .41392 .41245 .41163 .40992 Metetra
.645 .726 .907 r
.41163 .40992 .41392 .41245 .41779 .41133 .41551 .4088 Metetra
.644 .725 .907 r
.41551 .4088 .41779 .41133 .42167 .41022 .41939 .40768 Metetra
.644 .725 .907 r
.41939 .40768 .42167 .41022 .42555 .40911 .42327 .40656 Metetra
.643 .724 .907 r
.42327 .40656 .42555 .40911 .42944 .40801 .42717 .40545 Metetra
.642 .724 .907 r
.42717 .40545 .42944 .40801 .43333 .40691 .43106 .40435 Metetra
.642 .723 .907 r
.43106 .40435 .43333 .40691 .43723 .40582 .43497 .40325 Metetra
.641 .722 .907 r
.43497 .40325 .43723 .40582 .44114 .40474 .43888 .40216 Metetra
.64 .721 .907 r
.43888 .40216 .44114 .40474 .44505 .40366 .44279 .40107 Metetra
.639 .721 .907 r
.44279 .40107 .44505 .40366 .44897 .40259 .44671 .39999 Metetra
.638 .72 .907 r
.44671 .39999 .44897 .40259 .4529 .40153 .45064 .39892 Metetra
.637 .719 .907 r
.45064 .39892 .4529 .40153 .45683 .40047 .45458 .39786 Metetra
.96 .682 .463 r
.45458 .39786 .45683 .40047 .46076 .39943 .45418 .60738 Metetra
.542 .319 .526 r
.45418 .60738 .46076 .39943 .46078 .60844 .45838 .60613 Metetra
.936 .75 .626 r
.45838 .60613 .46078 .60844 .46499 .60719 .46286 .59054 Metetra
.848 .609 .576 r
.46286 .59054 .46499 .60719 .4697 .57578 .46761 .5567 Metetra
.781 .555 .593 r
.46761 .5567 .4697 .57578 .47427 .54908 .47209 .53576 Metetra
.784 .572 .614 r
.47209 .53576 .47427 .54908 .47865 .53149 .47644 .52115 Metetra
.782 .586 .635 r
.47644 .52115 .47865 .53149 .48294 .51875 .48071 .51017 Metetra
.777 .597 .655 r
.48071 .51017 .48294 .51875 .48718 .50897 .48493 .50153 Metetra
.771 .606 .675 r
.48493 .50153 .48718 .50897 .49138 .50116 .48913 .49449 Metetra
.763 .613 .693 r
.48913 .49449 .49138 .50116 .49556 .49472 .4933 .48862 Metetra
.754 .619 .71 r
.4933 .48862 .49556 .49472 .49972 .48932 .49746 .48363 Metetra
.744 .624 .726 r
.49746 .48363 .49972 .48932 .50388 .48472 .50162 .47933 Metetra
.734 .627 .74 r
.50162 .47933 .50388 .48472 .50803 .48075 .50577 .4756 Metetra
.723 .628 .752 r
.50577 .4756 .50803 .48075 .51218 .47731 .50992 .47234 Metetra
.711 .629 .764 r
.50992 .47234 .51218 .47731 .51633 .47432 .51407 .46948 Metetra
.699 .628 .774 r
.51407 .46948 .51633 .47432 .52048 .47172 .51822 .46697 Metetra
.686 .625 .783 r
.51822 .46697 .52048 .47172 .52463 .46946 .52238 .46479 Metetra
.672 .622 .79 r
.52238 .46479 .52463 .46946 .52878 .46753 .52653 .4629 Metetra
.657 .617 .797 r
.52653 .4629 .52878 .46753 .53295 .46591 .5307 .46129 Metetra
.641 .61 .803 r
.5307 .46129 .53295 .46591 .53711 .46458 .53487 .45996 Metetra
.624 .601 .807 r
.53487 .45996 .53711 .46458 .54129 .46356 .53904 .45891 Metetra
.605 .591 .81 r
.53904 .45891 .54129 .46356 .54548 .46283 .54323 .45814 Metetra
.584 .578 .813 r
.54323 .45814 .54548 .46283 .54967 .46244 .54743 .45766 Metetra
.559 .562 .813 r
.54743 .45766 .54967 .46244 .55388 .4624 .55163 .45751 Metetra
.532 .543 .812 r
.55163 .45751 .55388 .4624 .5581 .46275 .55585 .45772 Metetra
.499 .519 .808 r
.55585 .45772 .5581 .46275 .56234 .46355 .56009 .45833 Metetra
.461 .49 .802 r
.56009 .45833 .56234 .46355 .5666 .46488 .56434 .45942 Metetra
.415 .453 .792 r
.56434 .45942 .5666 .46488 .57087 .46686 .56861 .46108 Metetra
.358 .407 .776 r
.56861 .46108 .57087 .46686 .57518 .46965 .57291 .46345 Metetra
.29 .349 .752 r
.57291 .46345 .57518 .46965 .57952 .47348 .57724 .4667 Metetra
.204 .277 .717 r
.57724 .4667 .57952 .47348 .58391 .47871 .5816 .47114 Metetra
.1 .185 .666 r
.5816 .47114 .58391 .47871 .58835 .48594 .58602 .47721 Metetra
0 .073 .596 r
.58602 .47721 .58835 .48594 .59289 .49616 .59051 .48564 Metetra
0 0 .502 r
.59051 .48564 .59289 .49616 .59757 .51132 .59512 .49777 Metetra
0 0 .383 r
.59512 .49777 .59757 .51132 .60252 .53572 .5999 .51632 Metetra
0 0 .242 r
.5999 .51632 .60252 .53572 .60766 .56495 .60506 .54799 Metetra
.127 .101 .556 r
.60506 .54799 .60766 .56495 .6121 .56364 .60986 .56121 Metetra
.645 .763 .934 r
.60986 .56121 .6121 .56364 .61078 .34925 .61431 .55988 Metetra
0 0 .369 r
.61431 .55988 .61078 .34925 .61494 .34758 .61283 .34481 Metetra
.684 .735 .889 r
.61283 .34481 .61494 .34758 .61911 .34591 .617 .34315 Metetra
.684 .735 .89 r
.617 .34315 .61911 .34591 .62328 .34426 .62118 .3415 Metetra
.683 .735 .89 r
.62118 .3415 .62328 .34426 .62746 .34261 .62536 .33985 Metetra
.682 .736 .891 r
.62536 .33985 .62746 .34261 .63164 .34097 .62955 .33821 Metetra
.682 .736 .892 r
.62955 .33821 .63164 .34097 .63583 .33934 .63375 .33658 Metetra
.681 .736 .892 r
.63375 .33658 .63583 .33934 .64003 .33771 .63795 .33495 Metetra
.68 .736 .893 r
.63795 .33495 .64003 .33771 .64423 .33608 .64216 .33333 Metetra
.68 .736 .893 r
.64216 .33333 .64423 .33608 .64844 .33447 .64637 .33171 Metetra
.679 .736 .894 r
.64637 .33171 .64844 .33447 .65266 .33285 .65059 .3301 Metetra
.679 .737 .894 r
.65059 .3301 .65266 .33285 .65688 .33125 .65481 .32849 Metetra
.678 .737 .895 r
.65481 .32849 .65688 .33125 .66111 .32964 .65905 .32689 Metetra
.678 .737 .895 r
.65905 .32689 .66111 .32964 .66534 .32804 .66328 .32529 Metetra
.677 .737 .895 r
.66328 .32529 .66534 .32804 .66958 .32644 .66753 .32369 Metetra
.677 .737 .896 r
.66753 .32369 .66958 .32644 .67382 .32485 .67178 .32209 Metetra
.677 .737 .896 r
.67178 .32209 .67382 .32485 .67808 .32326 .67603 .3205 Metetra
.676 .737 .897 r
.67603 .3205 .67808 .32326 .68233 .32167 .6803 .31891 Metetra
.676 .738 .897 r
.6803 .31891 .68233 .32167 .6866 .32008 .68457 .31732 Metetra
.676 .738 .897 r
.68457 .31732 .6866 .32008 .69087 .31849 .68884 .31573 Metetra
.675 .738 .897 r
.68884 .31573 .69087 .31849 .69515 .31691 .69312 .31415 Metetra
.675 .738 .898 r
.69312 .31415 .69515 .31691 .69943 .31533 .69741 .31257 Metetra
.955 .761 .603 r
.69741 .31257 .69943 .31533 .70372 .31375 .70098 .29812 Metetra
.587 .424 .628 r
.70098 .29812 .70372 .31375 .70726 .29935 .70527 .29667 Metetra
.664 .741 .907 r
.70527 .29667 .70726 .29935 .71156 .2979 .70956 .29522 Metetra
.664 .741 .907 r
.70956 .29522 .71156 .2979 .71585 .29645 .71387 .29376 Metetra
.664 .741 .907 r
.71387 .29376 .71585 .29645 .72016 .29499 .71818 .2923 Metetra
.664 .741 .907 r
.71818 .2923 .72016 .29499 .72447 .29354 .72249 .29084 Metetra
.664 .741 .907 r
.72249 .29084 .72447 .29354 .72879 .29208 .72681 .28938 Metetra
.664 .741 .907 r
.72681 .28938 .72879 .29208 .73311 .29062 .73114 .28792 Metetra
.664 .741 .907 r
.73114 .28792 .73311 .29062 .73744 .28916 .73548 .28645 Metetra
.664 .741 .907 r
.73548 .28645 .73744 .28916 .74178 .28769 .73982 .28498 Metetra
.664 .741 .907 r
.73982 .28498 .74178 .28769 .74612 .28623 .74417 .28351 Metetra
.664 .741 .907 r
.74417 .28351 .74612 .28623 .75048 .28476 .74852 .28204 Metetra
.664 .741 .907 r
.74852 .28204 .75048 .28476 .75483 .28329 .75289 .28056 Metetra
.664 .741 .907 r
.75289 .28056 .75483 .28329 .7592 .28181 .75725 .27909 Metetra
.664 .741 .907 r
.75725 .27909 .7592 .28181 .76357 .28034 .76163 .27761 Metetra
.664 .741 .907 r
.76163 .27761 .76357 .28034 .76794 .27886 .76601 .27612 Metetra
.664 .741 .907 r
.76601 .27612 .76794 .27886 .77233 .27738 .7704 .27464 Metetra
.664 .741 .907 r
.7704 .27464 .77233 .27738 .77672 .2759 .7748 .27315 Metetra
.664 .741 .907 r
.7748 .27315 .77672 .2759 .78112 .27441 .7792 .27167 Metetra
.664 .741 .907 r
.7792 .27167 .78112 .27441 .78552 .27293 .78361 .27017 Metetra
.664 .741 .907 r
.78361 .27017 .78552 .27293 .78993 .27144 .78802 .26868 Metetra
.664 .741 .907 r
.78802 .26868 .78993 .27144 .79435 .26994 .79244 .26719 Metetra
.664 .741 .907 r
.79244 .26719 .79435 .26994 .79877 .26845 .79687 .26569 Metetra
.664 .741 .907 r
.79687 .26569 .79877 .26845 .8032 .26696 .80131 .26419 Metetra
.664 .741 .907 r
.80131 .26419 .8032 .26696 .80764 .26546 .80575 .26268 Metetra
.664 .741 .907 r
.80575 .26268 .80764 .26546 .81209 .26396 .8102 .26118 Metetra
.664 .741 .907 r
.8102 .26118 .81209 .26396 .81654 .26245 .81466 .25967 Metetra
.664 .741 .907 r
.81466 .25967 .81654 .26245 .821 .26095 .81912 .25816 Metetra
.664 .741 .907 r
.81912 .25816 .821 .26095 .82546 .25944 .82359 .25665 Metetra
.664 .741 .907 r
.82359 .25665 .82546 .25944 .82993 .25793 .82807 .25514 Metetra
.664 .741 .907 r
.82807 .25514 .82993 .25793 .83441 .25642 .83255 .25362 Metetra
.664 .741 .907 r
.83255 .25362 .83441 .25642 .8389 .2549 .83704 .2521 Metetra
.664 .741 .907 r
.83704 .2521 .8389 .2549 .84339 .25339 .84154 .25058 Metetra
.664 .741 .907 r
.84154 .25058 .84339 .25339 .84789 .25187 .84605 .24906 Metetra
.664 .741 .907 r
.84605 .24906 .84789 .25187 .8524 .25035 .85056 .24753 Metetra
.664 .741 .907 r
.24499 .44924 .24742 .45151 .25105 .45028 .24863 .44801 Metetra
.664 .741 .907 r
.24863 .44801 .25105 .45028 .25469 .44905 .25227 .44678 Metetra
.664 .741 .907 r
.25227 .44678 .25469 .44905 .25833 .44782 .25591 .44554 Metetra
.664 .741 .907 r
.25591 .44554 .25833 .44782 .26198 .44659 .25956 .44431 Metetra
.664 .741 .907 r
.25956 .44431 .26198 .44659 .26563 .44535 .26322 .44307 Metetra
.664 .741 .907 r
.26322 .44307 .26563 .44535 .26929 .44412 .26688 .44183 Metetra
.664 .741 .907 r
.26688 .44183 .26929 .44412 .27295 .44288 .27054 .44059 Metetra
.664 .741 .907 r
.27054 .44059 .27295 .44288 .27662 .44164 .27421 .43934 Metetra
.664 .741 .907 r
.27421 .43934 .27662 .44164 .28029 .4404 .27789 .4381 Metetra
.664 .741 .907 r
.27789 .4381 .28029 .4404 .28397 .43915 .28157 .43685 Metetra
.664 .741 .907 r
.28157 .43685 .28397 .43915 .28765 .43791 .28525 .4356 Metetra
.664 .741 .907 r
.28525 .4356 .28765 .43791 .29134 .43666 .28894 .43435 Metetra
.664 .741 .907 r
.28894 .43435 .29134 .43666 .29503 .43541 .29264 .4331 Metetra
.664 .741 .907 r
.29264 .4331 .29503 .43541 .29873 .43416 .29634 .43185 Metetra
.664 .741 .907 r
.29634 .43185 .29873 .43416 .30243 .43291 .30005 .43059 Metetra
.664 .741 .907 r
.30005 .43059 .30243 .43291 .30614 .43165 .30376 .42933 Metetra
.664 .741 .907 r
.30376 .42933 .30614 .43165 .30985 .4304 .30747 .42808 Metetra
.664 .741 .907 r
.30747 .42808 .30985 .4304 .31357 .42914 .3112 .42681 Metetra
.664 .741 .907 r
.3112 .42681 .31357 .42914 .31729 .42788 .31492 .42555 Metetra
.664 .741 .907 r
.31492 .42555 .31729 .42788 .32102 .42662 .31865 .42429 Metetra
.664 .741 .907 r
.31865 .42429 .32102 .42662 .32476 .42536 .32239 .42302 Metetra
.664 .741 .907 r
.32239 .42302 .32476 .42536 .3285 .42409 .32614 .42175 Metetra
.664 .741 .907 r
.32614 .42175 .3285 .42409 .33224 .42283 .32988 .42048 Metetra
.664 .741 .907 r
.32988 .42048 .33224 .42283 .33599 .42156 .33364 .41921 Metetra
.664 .741 .907 r
.33364 .41921 .33599 .42156 .33975 .42029 .3374 .41794 Metetra
.664 .741 .907 r
.3374 .41794 .33975 .42029 .34351 .41902 .34116 .41666 Metetra
.664 .741 .907 r
.34116 .41666 .34351 .41902 .34727 .41774 .34493 .41539 Metetra
.664 .741 .907 r
.34493 .41539 .34727 .41774 .35105 .41647 .3487 .41411 Metetra
.664 .741 .907 r
.3487 .41411 .35105 .41647 .35482 .41519 .35248 .41283 Metetra
.664 .741 .907 r
.35248 .41283 .35482 .41519 .35861 .41391 .35627 .41154 Metetra
.664 .741 .907 r
.35627 .41154 .35861 .41391 .36239 .41263 .36006 .41026 Metetra
.664 .741 .907 r
.36006 .41026 .36239 .41263 .36619 .41135 .36386 .40897 Metetra
.664 .741 .907 r
.36386 .40897 .36619 .41135 .36998 .41006 .36766 .40769 Metetra
.664 .741 .907 r
.36766 .40769 .36998 .41006 .37379 .40878 .37147 .4064 Metetra
.664 .741 .907 r
.37147 .4064 .37379 .40878 .37702 .42017 .37528 .4051 Metetra
.586 .424 .628 r
.37528 .4051 .37702 .42017 .38084 .41903 .3791 .40381 Metetra
.037 .026 .513 r
.3791 .40381 .38084 .41903 .38467 .41788 .38235 .41539 Metetra
.649 .729 .907 r
.38235 .41539 .38467 .41788 .38851 .41673 .38619 .41424 Metetra
.648 .728 .907 r
.38619 .41424 .38851 .41673 .39235 .41559 .39003 .41309 Metetra
.648 .728 .907 r
.39003 .41309 .39235 .41559 .39619 .41445 .39388 .41195 Metetra
.647 .728 .907 r
.39388 .41195 .39619 .41445 .40004 .41331 .39774 .4108 Metetra
.647 .727 .907 r
.39774 .4108 .40004 .41331 .4039 .41218 .4016 .40966 Metetra
.646 .727 .907 r
.4016 .40966 .4039 .41218 .40776 .41105 .40547 .40852 Metetra
.646 .726 .907 r
.40547 .40852 .40776 .41105 .41163 .40992 .40934 .40739 Metetra
.645 .726 .907 r
.40934 .40739 .41163 .40992 .41551 .4088 .41322 .40626 Metetra
.645 .725 .907 r
.41322 .40626 .41551 .4088 .41939 .40768 .4171 .40513 Metetra
.644 .725 .907 r
.4171 .40513 .41939 .40768 .42327 .40656 .42099 .40401 Metetra
.644 .724 .907 r
.42099 .40401 .42327 .40656 .42717 .40545 .42488 .40289 Metetra
.643 .724 .907 r
.42488 .40289 .42717 .40545 .43106 .40435 .42879 .40178 Metetra
.642 .723 .907 r
.42879 .40178 .43106 .40435 .43497 .40325 .43269 .40067 Metetra
.641 .723 .907 r
.43269 .40067 .43497 .40325 .43888 .40216 .43661 .39957 Metetra
.641 .722 .907 r
.43661 .39957 .43888 .40216 .44279 .40107 .44053 .39848 Metetra
.64 .721 .907 r
.44053 .39848 .44279 .40107 .44671 .39999 .44445 .39739 Metetra
.639 .72 .907 r
.44445 .39739 .44671 .39999 .45064 .39892 .44838 .39631 Metetra
.638 .719 .907 r
.44838 .39631 .45064 .39892 .45458 .39786 .45232 .39523 Metetra
.96 .682 .463 r
.45232 .39523 .45458 .39786 .45418 .60738 .45176 .60508 Metetra
.645 .763 .934 r
.45176 .60508 .45418 .60738 .45838 .60613 .45598 .60382 Metetra
.954 .719 .546 r
.45598 .60382 .45838 .60613 .46286 .59054 .46087 .56668 Metetra
.777 .545 .584 r
.46087 .56668 .46286 .59054 .46761 .5567 .46548 .54124 Metetra
.783 .564 .604 r
.46548 .54124 .46761 .5567 .47209 .53576 .46989 .52426 Metetra
.783 .579 .625 r
.46989 .52426 .47209 .53576 .47644 .52115 .47421 .51186 Metetra
.779 .592 .646 r
.47421 .51186 .47644 .52115 .48071 .51017 .47846 .50227 Metetra
.774 .602 .666 r
.47846 .50227 .48071 .51017 .48493 .50153 .48268 .49456 Metetra
.767 .611 .685 r
.48268 .49456 .48493 .50153 .48913 .49449 .48687 .48817 Metetra
.759 .618 .703 r
.48687 .48817 .48913 .49449 .4933 .48862 .49104 .48277 Metetra
.75 .623 .719 r
.49104 .48277 .4933 .48862 .49746 .48363 .4952 .47813 Metetra
.74 .627 .733 r
.4952 .47813 .49746 .48363 .50162 .47933 .49936 .47411 Metetra
.73 .63 .747 r
.49936 .47411 .50162 .47933 .50577 .4756 .50351 .47058 Metetra
.719 .631 .758 r
.50351 .47058 .50577 .4756 .50992 .47234 .50766 .46747 Metetra
.708 .631 .769 r
.50766 .46747 .50992 .47234 .51407 .46948 .51181 .46473 Metetra
.696 .63 .779 r
.51181 .46473 .51407 .46948 .51822 .46697 .51596 .46231 Metetra
.684 .628 .787 r
.51596 .46231 .51822 .46697 .52238 .46479 .52012 .46019 Metetra
.671 .625 .794 r
.52012 .46019 .52238 .46479 .52653 .4629 .52428 .45834 Metetra
.657 .62 .801 r
.52428 .45834 .52653 .4629 .5307 .46129 .52845 .45675 Metetra
.642 .614 .806 r
.52845 .45675 .5307 .46129 .53487 .45996 .53262 .45542 Metetra
.626 .606 .81 r
.53262 .45542 .53487 .45996 .53904 .45891 .5368 .45434 Metetra
.608 .596 .814 r
.5368 .45434 .53904 .45891 .54323 .45814 .54098 .45352 Metetra
.588 .584 .816 r
.54098 .45352 .54323 .45814 .54743 .45766 .54518 .45297 Metetra
.566 .57 .816 r
.54518 .45297 .54743 .45766 .55163 .45751 .54939 .45273 Metetra
.541 .552 .816 r
.54939 .45273 .55163 .45751 .55585 .45772 .55361 .4528 Metetra
.511 .531 .813 r
.55361 .4528 .55585 .45772 .56009 .45833 .55784 .45325 Metetra
.476 .504 .808 r
.55784 .45325 .56009 .45833 .56434 .45942 .56209 .45412 Metetra
.435 .472 .799 r
.56209 .45412 .56434 .45942 .56861 .46108 .56635 .4555 Metetra
.385 .431 .786 r
.56635 .4555 .56861 .46108 .57291 .46345 .57064 .4575 Metetra
.324 .38 .766 r
.57064 .4575 .57291 .46345 .57724 .4667 .57496 .46027 Metetra
.25 .317 .737 r
.57496 .46027 .57724 .4667 .5816 .47114 .57931 .46404 Metetra
.157 .236 .696 r
.57931 .46404 .5816 .47114 .58602 .47721 .58371 .46916 Metetra
.044 .137 .637 r
.58371 .46916 .58602 .47721 .59051 .48564 .58816 .47618 Metetra
0 .017 .557 r
.58816 .47618 .59051 .48564 .59512 .49777 .5927 .48606 Metetra
0 0 .453 r
.5927 .48606 .59512 .49777 .5999 .51632 .59738 .50059 Metetra
0 0 .325 r
.59738 .50059 .5999 .51632 .60506 .54799 .60231 .52372 Metetra
0 0 .301 r
.60231 .52372 .60506 .54799 .60986 .56121 .6076 .55877 Metetra
.645 .763 .934 r
.6076 .55877 .60986 .56121 .61431 .55988 .61206 .55744 Metetra
.972 .692 .439 r
.61206 .55744 .61431 .55988 .61283 .34481 .61072 .34205 Metetra
.684 .735 .889 r
.61072 .34205 .61283 .34481 .617 .34315 .61489 .34039 Metetra
.683 .735 .89 r
.61489 .34039 .617 .34315 .62118 .3415 .61908 .33874 Metetra
.682 .735 .891 r
.61908 .33874 .62118 .3415 .62536 .33985 .62326 .33709 Metetra
.682 .736 .891 r
.62326 .33709 .62536 .33985 .62955 .33821 .62746 .33545 Metetra
.681 .736 .892 r
.62746 .33545 .62955 .33821 .63375 .33658 .63166 .33382 Metetra
.681 .736 .892 r
.63166 .33382 .63375 .33658 .63795 .33495 .63586 .33219 Metetra
.68 .736 .893 r
.63586 .33219 .63795 .33495 .64216 .33333 .64007 .33057 Metetra
.68 .736 .894 r
.64007 .33057 .64216 .33333 .64637 .33171 .64429 .32896 Metetra
.679 .737 .894 r
.64429 .32896 .64637 .33171 .65059 .3301 .64852 .32734 Metetra
.679 .737 .894 r
.64852 .32734 .65059 .3301 .65481 .32849 .65275 .32573 Metetra
.678 .737 .895 r
.65275 .32573 .65481 .32849 .65905 .32689 .65698 .32413 Metetra
.678 .737 .895 r
.65698 .32413 .65905 .32689 .66328 .32529 .66122 .32253 Metetra
.677 .737 .896 r
.66122 .32253 .66328 .32529 .66753 .32369 .66547 .32093 Metetra
.677 .737 .896 r
.66547 .32093 .66753 .32369 .67178 .32209 .66973 .31933 Metetra
.676 .737 .896 r
.66973 .31933 .67178 .32209 .67603 .3205 .67399 .31774 Metetra
.676 .737 .897 r
.67399 .31774 .67603 .3205 .6803 .31891 .67825 .31615 Metetra
.676 .738 .897 r
.67825 .31615 .6803 .31891 .68457 .31732 .68253 .31456 Metetra
.675 .738 .897 r
.68253 .31456 .68457 .31732 .68884 .31573 .68681 .31297 Metetra
.954 .76 .602 r
.68681 .31297 .68884 .31573 .69312 .31415 .6904 .29834 Metetra
.586 .423 .627 r
.6904 .29834 .69312 .31415 .69741 .31257 .69468 .29689 Metetra
.586 .424 .628 r
.69468 .29689 .69741 .31257 .70098 .29812 .69897 .29544 Metetra
.664 .741 .907 r
.69897 .29544 .70098 .29812 .70527 .29667 .70326 .29398 Metetra
.664 .741 .907 r
.70326 .29398 .70527 .29667 .70956 .29522 .70757 .29253 Metetra
.664 .741 .907 r
.70757 .29253 .70956 .29522 .71387 .29376 .71187 .29107 Metetra
.664 .741 .907 r
.71187 .29107 .71387 .29376 .71818 .2923 .71619 .28961 Metetra
.664 .741 .907 r
.71619 .28961 .71818 .2923 .72249 .29084 .72051 .28814 Metetra
.664 .741 .907 r
.72051 .28814 .72249 .29084 .72681 .28938 .72483 .28668 Metetra
.664 .741 .907 r
.72483 .28668 .72681 .28938 .73114 .28792 .72917 .28521 Metetra
.664 .741 .907 r
.72917 .28521 .73114 .28792 .73548 .28645 .73351 .28374 Metetra
.664 .741 .907 r
.73351 .28374 .73548 .28645 .73982 .28498 .73785 .28227 Metetra
.664 .741 .907 r
.73785 .28227 .73982 .28498 .74417 .28351 .74221 .28079 Metetra
.664 .741 .907 r
.74221 .28079 .74417 .28351 .74852 .28204 .74657 .27931 Metetra
.664 .741 .907 r
.74657 .27931 .74852 .28204 .75289 .28056 .75093 .27783 Metetra
.664 .741 .907 r
.75093 .27783 .75289 .28056 .75725 .27909 .75531 .27635 Metetra
.664 .741 .907 r
.75531 .27635 .75725 .27909 .76163 .27761 .75969 .27487 Metetra
.664 .741 .907 r
.75969 .27487 .76163 .27761 .76601 .27612 .76407 .27338 Metetra
.664 .741 .907 r
.76407 .27338 .76601 .27612 .7704 .27464 .76847 .27189 Metetra
.664 .741 .907 r
.76847 .27189 .7704 .27464 .7748 .27315 .77287 .2704 Metetra
.664 .741 .907 r
.77287 .2704 .7748 .27315 .7792 .27167 .77727 .26891 Metetra
.664 .741 .907 r
.77727 .26891 .7792 .27167 .78361 .27017 .78169 .26742 Metetra
.664 .741 .907 r
.78169 .26742 .78361 .27017 .78802 .26868 .78611 .26592 Metetra
.664 .741 .907 r
.78611 .26592 .78802 .26868 .79244 .26719 .79053 .26442 Metetra
.664 .741 .907 r
.79053 .26442 .79244 .26719 .79687 .26569 .79497 .26292 Metetra
.664 .741 .907 r
.79497 .26292 .79687 .26569 .80131 .26419 .79941 .26141 Metetra
.664 .741 .907 r
.79941 .26141 .80131 .26419 .80575 .26268 .80386 .2599 Metetra
.664 .741 .907 r
.80386 .2599 .80575 .26268 .8102 .26118 .80831 .2584 Metetra
.664 .741 .907 r
.80831 .2584 .8102 .26118 .81466 .25967 .81277 .25688 Metetra
.664 .741 .907 r
.81277 .25688 .81466 .25967 .81912 .25816 .81724 .25537 Metetra
.664 .741 .907 r
.81724 .25537 .81912 .25816 .82359 .25665 .82172 .25385 Metetra
.664 .741 .907 r
.82172 .25385 .82359 .25665 .82807 .25514 .8262 .25234 Metetra
.664 .741 .907 r
.8262 .25234 .82807 .25514 .83255 .25362 .83069 .25081 Metetra
.664 .741 .907 r
.83069 .25081 .83255 .25362 .83704 .2521 .83518 .24929 Metetra
.664 .741 .907 r
.83518 .24929 .83704 .2521 .84154 .25058 .83969 .24777 Metetra
.664 .741 .907 r
.83969 .24777 .84154 .25058 .84605 .24906 .8442 .24624 Metetra
.664 .741 .907 r
.8442 .24624 .84605 .24906 .85056 .24753 .84871 .24471 Metetra
.664 .741 .907 r
.24256 .44697 .24499 .44924 .24863 .44801 .2462 .44573 Metetra
.664 .741 .907 r
.2462 .44573 .24863 .44801 .25227 .44678 .24984 .4445 Metetra
.664 .741 .907 r
.24984 .4445 .25227 .44678 .25591 .44554 .25349 .44326 Metetra
.664 .741 .907 r
.25349 .44326 .25591 .44554 .25956 .44431 .25714 .44202 Metetra
.664 .741 .907 r
.25714 .44202 .25956 .44431 .26322 .44307 .2608 .44078 Metetra
.664 .741 .907 r
.2608 .44078 .26322 .44307 .26688 .44183 .26446 .43954 Metetra
.664 .741 .907 r
.26446 .43954 .26688 .44183 .27054 .44059 .26813 .43829 Metetra
.664 .741 .907 r
.26813 .43829 .27054 .44059 .27421 .43934 .2718 .43704 Metetra
.664 .741 .907 r
.2718 .43704 .27421 .43934 .27789 .4381 .27548 .4358 Metetra
.664 .741 .907 r
.27548 .4358 .27789 .4381 .28157 .43685 .27916 .43455 Metetra
.664 .741 .907 r
.27916 .43455 .28157 .43685 .28525 .4356 .28285 .43329 Metetra
.664 .741 .907 r
.28285 .43329 .28525 .4356 .28894 .43435 .28654 .43204 Metetra
.664 .741 .907 r
.28654 .43204 .28894 .43435 .29264 .4331 .29024 .43079 Metetra
.664 .741 .907 r
.29024 .43079 .29264 .4331 .29634 .43185 .29395 .42953 Metetra
.664 .741 .907 r
.29395 .42953 .29634 .43185 .30005 .43059 .29766 .42827 Metetra
.664 .741 .907 r
.29766 .42827 .30005 .43059 .30376 .42933 .30137 .42701 Metetra
.664 .741 .907 r
.30137 .42701 .30376 .42933 .30747 .42808 .30509 .42575 Metetra
.664 .741 .907 r
.30509 .42575 .30747 .42808 .3112 .42681 .30882 .42448 Metetra
.664 .741 .907 r
.30882 .42448 .3112 .42681 .31492 .42555 .31255 .42322 Metetra
.664 .741 .907 r
.31255 .42322 .31492 .42555 .31865 .42429 .31628 .42195 Metetra
.664 .741 .907 r
.31628 .42195 .31865 .42429 .32239 .42302 .32002 .42068 Metetra
.664 .741 .907 r
.32002 .42068 .32239 .42302 .32614 .42175 .32377 .41941 Metetra
.664 .741 .907 r
.32377 .41941 .32614 .42175 .32988 .42048 .32752 .41813 Metetra
.664 .741 .907 r
.32752 .41813 .32988 .42048 .33364 .41921 .33128 .41686 Metetra
.664 .741 .907 r
.33128 .41686 .33364 .41921 .3374 .41794 .33504 .41558 Metetra
.664 .741 .907 r
.33504 .41558 .3374 .41794 .34116 .41666 .33881 .4143 Metetra
.664 .741 .907 r
.33881 .4143 .34116 .41666 .34493 .41539 .34258 .41302 Metetra
.664 .741 .907 r
.34258 .41302 .34493 .41539 .3487 .41411 .34636 .41174 Metetra
.664 .741 .907 r
.34636 .41174 .3487 .41411 .35248 .41283 .35014 .41046 Metetra
.664 .741 .907 r
.35014 .41046 .35248 .41283 .35627 .41154 .35393 .40917 Metetra
.664 .741 .907 r
.35393 .40917 .35627 .41154 .36006 .41026 .35772 .40788 Metetra
.664 .741 .907 r
.35772 .40788 .36006 .41026 .36386 .40897 .36152 .40659 Metetra
.664 .741 .907 r
.36152 .40659 .36386 .40897 .36766 .40769 .36533 .4053 Metetra
.664 .741 .907 r
.36533 .4053 .36766 .40769 .37147 .4064 .36914 .40401 Metetra
.664 .741 .907 r
.36914 .40401 .37147 .4064 .37528 .4051 .37295 .40271 Metetra
.664 .741 .907 r
.37295 .40271 .37528 .4051 .3791 .40381 .37678 .40142 Metetra
.664 .741 .907 r
.37678 .40142 .3791 .40381 .38235 .41539 .3806 .40012 Metetra
.037 .026 .513 r
.3806 .40012 .38235 .41539 .38619 .41424 .38387 .41174 Metetra
.649 .729 .907 r
.38387 .41174 .38619 .41424 .39003 .41309 .38772 .41059 Metetra
.648 .728 .907 r
.38772 .41059 .39003 .41309 .39388 .41195 .39157 .40944 Metetra
.648 .728 .907 r
.39157 .40944 .39388 .41195 .39774 .4108 .39543 .40829 Metetra
.647 .728 .907 r
.39543 .40829 .39774 .4108 .4016 .40966 .39929 .40714 Metetra
.647 .727 .907 r
.39929 .40714 .4016 .40966 .40547 .40852 .40316 .406 Metetra
.646 .727 .907 r
.40316 .406 .40547 .40852 .40934 .40739 .40704 .40485 Metetra
.646 .726 .907 r
.40704 .40485 .40934 .40739 .41322 .40626 .41092 .40372 Metetra
.645 .726 .907 r
.41092 .40372 .41322 .40626 .4171 .40513 .41481 .40258 Metetra
.645 .725 .907 r
.41481 .40258 .4171 .40513 .42099 .40401 .4187 .40145 Metetra
.644 .725 .907 r
.4187 .40145 .42099 .40401 .42488 .40289 .4226 .40033 Metetra
.643 .724 .907 r
.4226 .40033 .42488 .40289 .42879 .40178 .4265 .39921 Metetra
.643 .724 .907 r
.4265 .39921 .42879 .40178 .43269 .40067 .43041 .39809 Metetra
.642 .723 .907 r
.43041 .39809 .43269 .40067 .43661 .39957 .43433 .39698 Metetra
.641 .722 .907 r
.43433 .39698 .43661 .39957 .44053 .39848 .43825 .39588 Metetra
.64 .722 .907 r
.43825 .39588 .44053 .39848 .44445 .39739 .44218 .39478 Metetra
.639 .721 .907 r
.44218 .39478 .44445 .39739 .44838 .39631 .44612 .39369 Metetra
.96 .682 .464 r
.44612 .39369 .44838 .39631 .45232 .39523 .44514 .60402 Metetra
.541 .318 .525 r
.44514 .60402 .45232 .39523 .45176 .60508 .44935 .60276 Metetra
.946 .735 .586 r
.44935 .60276 .45176 .60508 .45598 .60382 .45401 .58006 Metetra
.803 .565 .578 r
.45401 .58006 .45598 .60382 .46087 .56668 .4588 .54824 Metetra
.78 .556 .595 r
.4588 .54824 .46087 .56668 .46548 .54124 .46331 .52823 Metetra
.783 .573 .616 r
.46331 .52823 .46548 .54124 .46989 .52426 .46768 .5141 Metetra
.781 .586 .637 r
.46768 .5141 .46989 .52426 .47421 .51186 .47197 .5034 Metetra
.777 .598 .657 r
.47197 .5034 .47421 .51186 .47846 .50227 .47621 .49492 Metetra
.771 .607 .677 r
.47621 .49492 .47846 .50227 .48268 .49456 .48042 .48797 Metetra
.763 .615 .695 r
.48042 .48797 .48268 .49456 .48687 .48817 .4846 .48213 Metetra
.755 .622 .711 r
.4846 .48213 .48687 .48817 .49104 .48277 .48877 .47714 Metetra
.746 .627 .727 r
.48877 .47714 .49104 .48277 .4952 .47813 .49294 .47281 Metetra
.737 .63 .741 r
.49294 .47281 .4952 .47813 .49936 .47411 .49709 .46902 Metetra
.727 .633 .753 r
.49709 .46902 .49936 .47411 .50351 .47058 .50124 .46568 Metetra
.717 .634 .764 r
.50124 .46568 .50351 .47058 .50766 .46747 .5054 .46271 Metetra
.706 .634 .774 r
.5054 .46271 .50766 .46747 .51181 .46473 .50955 .46008 Metetra
.694 .633 .783 r
.50955 .46008 .51181 .46473 .51596 .46231 .5137 .45774 Metetra
.683 .631 .791 r
.5137 .45774 .51596 .46231 .52012 .46019 .51786 .45567 Metetra
.67 .628 .798 r
.51786 .45567 .52012 .46019 .52428 .45834 .52202 .45386 Metetra
.657 .623 .804 r
.52202 .45386 .52428 .45834 .52845 .45675 .52619 .45228 Metetra
.643 .617 .809 r
.52619 .45228 .52845 .45675 .53262 .45542 .53036 .45094 Metetra
.628 .61 .813 r
.53036 .45094 .53262 .45542 .5368 .45434 .53454 .44984 Metetra
.611 .601 .817 r
.53454 .44984 .5368 .45434 .54098 .45352 .53873 .44898 Metetra
.593 .59 .819 r
.53873 .44898 .54098 .45352 .54518 .45297 .54293 .44837 Metetra
.572 .577 .82 r
.54293 .44837 .54518 .45297 .54939 .45273 .54714 .44803 Metetra
.549 .561 .819 r
.54714 .44803 .54939 .45273 .55361 .4528 .55135 .44799 Metetra
.522 .542 .817 r
.55135 .44799 .55361 .4528 .55784 .45325 .55559 .44829 Metetra
.491 .518 .813 r
.55559 .44829 .55784 .45325 .56209 .45412 .55983 .44897 Metetra
.454 .489 .806 r
.55983 .44897 .56209 .45412 .56635 .4555 .5641 .4501 Metetra
.409 .453 .795 r
.5641 .4501 .56635 .4555 .57064 .4575 .56838 .45178 Metetra
.355 .408 .778 r
.56838 .45178 .57064 .4575 .57496 .46027 .57269 .45413 Metetra
.289 .352 .754 r
.57269 .45413 .57496 .46027 .57931 .46404 .57703 .45734 Metetra
.208 .281 .72 r
.57703 .45734 .57931 .46404 .58371 .46916 .5814 .46167 Metetra
.108 .194 .672 r
.5814 .46167 .58371 .46916 .58816 .47618 .58583 .46756 Metetra
0 .086 .604 r
.58583 .46756 .58816 .47618 .5927 .48606 .59033 .4757 Metetra
0 0 .515 r
.59033 .4757 .5927 .48606 .59738 .50059 .59493 .48734 Metetra
0 0 .401 r
.59493 .48734 .59738 .50059 .60231 .52372 .59971 .50495 Metetra
0 0 .266 r
.59971 .50495 .60231 .52372 .6076 .55877 .60483 .53456 Metetra
.075 .037 .507 r
.60483 .53456 .6076 .55877 .61206 .55744 .60981 .55499 Metetra
.645 .763 .934 r
.60981 .55499 .61206 .55744 .61072 .34205 .61428 .55366 Metetra
0 0 .368 r
.61428 .55366 .61072 .34205 .61489 .34039 .61278 .33762 Metetra
.683 .735 .89 r
.61278 .33762 .61489 .34039 .61908 .33874 .61697 .33597 Metetra
.682 .735 .891 r
.61697 .33597 .61908 .33874 .62326 .33709 .62116 .33432 Metetra
.681 .736 .892 r
.62116 .33432 .62326 .33709 .62746 .33545 .62536 .33269 Metetra
.681 .736 .892 r
.62536 .33269 .62746 .33545 .63166 .33382 .62956 .33106 Metetra
.68 .736 .893 r
.62956 .33106 .63166 .33382 .63586 .33219 .63377 .32943 Metetra
.68 .736 .893 r
.63377 .32943 .63586 .33219 .64007 .33057 .63799 .32781 Metetra
.679 .736 .894 r
.63799 .32781 .64007 .33057 .64429 .32896 .64221 .32619 Metetra
.679 .737 .894 r
.64221 .32619 .64429 .32896 .64852 .32734 .64644 .32458 Metetra
.678 .737 .895 r
.64644 .32458 .64852 .32734 .65275 .32573 .65067 .32297 Metetra
.678 .737 .895 r
.65067 .32297 .65275 .32573 .65698 .32413 .65491 .32136 Metetra
.677 .737 .896 r
.65491 .32136 .65698 .32413 .66122 .32253 .65916 .31976 Metetra
.677 .737 .896 r
.65916 .31976 .66122 .32253 .66547 .32093 .66341 .31816 Metetra
.677 .737 .896 r
.66341 .31816 .66547 .32093 .66973 .31933 .66767 .31656 Metetra
.676 .737 .897 r
.66767 .31656 .66973 .31933 .67399 .31774 .67193 .31497 Metetra
.676 .737 .897 r
.67193 .31497 .67399 .31774 .67825 .31615 .67621 .31338 Metetra
.675 .738 .897 r
.67621 .31338 .67825 .31615 .68253 .31456 .68048 .31178 Metetra
.954 .759 .602 r
.68048 .31178 .68253 .31456 .68681 .31297 .6841 .29712 Metetra
.585 .422 .627 r
.6841 .29712 .68681 .31297 .6904 .29834 .68838 .29566 Metetra
.664 .741 .907 r
.68838 .29566 .6904 .29834 .69468 .29689 .69267 .29421 Metetra
.664 .741 .907 r
.69267 .29421 .69468 .29689 .69897 .29544 .69696 .29275 Metetra
.664 .741 .907 r
.69696 .29275 .69897 .29544 .70326 .29398 .70126 .29129 Metetra
.664 .741 .907 r
.70126 .29129 .70326 .29398 .70757 .29253 .70556 .28983 Metetra
.664 .741 .907 r
.70556 .28983 .70757 .29253 .71187 .29107 .70987 .28837 Metetra
.664 .741 .907 r
.70987 .28837 .71187 .29107 .71619 .28961 .71419 .2869 Metetra
.664 .741 .907 r
.71419 .2869 .71619 .28961 .72051 .28814 .71852 .28544 Metetra
.664 .741 .907 r
.71852 .28544 .72051 .28814 .72483 .28668 .72285 .28396 Metetra
.664 .741 .907 r
.72285 .28396 .72483 .28668 .72917 .28521 .72719 .28249 Metetra
.664 .741 .907 r
.72719 .28249 .72917 .28521 .73351 .28374 .73153 .28102 Metetra
.664 .741 .907 r
.73153 .28102 .73351 .28374 .73785 .28227 .73588 .27954 Metetra
.664 .741 .907 r
.73588 .27954 .73785 .28227 .74221 .28079 .74024 .27806 Metetra
.664 .741 .907 r
.74024 .27806 .74221 .28079 .74657 .27931 .7446 .27658 Metetra
.664 .741 .907 r
.7446 .27658 .74657 .27931 .75093 .27783 .74898 .2751 Metetra
.664 .741 .907 r
.74898 .2751 .75093 .27783 .75531 .27635 .75335 .27361 Metetra
.664 .741 .907 r
.75335 .27361 .75531 .27635 .75969 .27487 .75774 .27212 Metetra
.664 .741 .907 r
.75774 .27212 .75969 .27487 .76407 .27338 .76213 .27063 Metetra
.664 .741 .907 r
.76213 .27063 .76407 .27338 .76847 .27189 .76653 .26914 Metetra
.664 .741 .907 r
.76653 .26914 .76847 .27189 .77287 .2704 .77093 .26765 Metetra
.664 .741 .907 r
.77093 .26765 .77287 .2704 .77727 .26891 .77534 .26615 Metetra
.664 .741 .907 r
.77534 .26615 .77727 .26891 .78169 .26742 .77976 .26465 Metetra
.664 .741 .907 r
.77976 .26465 .78169 .26742 .78611 .26592 .78419 .26315 Metetra
.664 .741 .907 r
.78419 .26315 .78611 .26592 .79053 .26442 .78862 .26164 Metetra
.664 .741 .907 r
.78862 .26164 .79053 .26442 .79497 .26292 .79306 .26014 Metetra
.664 .741 .907 r
.79306 .26014 .79497 .26292 .79941 .26141 .7975 .25863 Metetra
.664 .741 .907 r
.7975 .25863 .79941 .26141 .80386 .2599 .80196 .25712 Metetra
.664 .741 .907 r
.80196 .25712 .80386 .2599 .80831 .2584 .80642 .2556 Metetra
.664 .741 .907 r
.80642 .2556 .80831 .2584 .81277 .25688 .81088 .25409 Metetra
.664 .741 .907 r
.81088 .25409 .81277 .25688 .81724 .25537 .81535 .25257 Metetra
.664 .741 .907 r
.81535 .25257 .81724 .25537 .82172 .25385 .81983 .25105 Metetra
.664 .741 .907 r
.81983 .25105 .82172 .25385 .8262 .25234 .82432 .24953 Metetra
.664 .741 .907 r
.82432 .24953 .8262 .25234 .83069 .25081 .82882 .248 Metetra
.664 .741 .907 r
.82882 .248 .83069 .25081 .83518 .24929 .83332 .24647 Metetra
.664 .741 .907 r
.83332 .24647 .83518 .24929 .83969 .24777 .83782 .24494 Metetra
.664 .741 .907 r
.83782 .24494 .83969 .24777 .8442 .24624 .84234 .24341 Metetra
.664 .741 .907 r
.84234 .24341 .8442 .24624 .84871 .24471 .84686 .24188 Metetra
.664 .741 .907 r
.24012 .44469 .24256 .44697 .2462 .44573 .24376 .44345 Metetra
.664 .741 .907 r
.24376 .44345 .2462 .44573 .24984 .4445 .2474 .44221 Metetra
.664 .741 .907 r
.2474 .44221 .24984 .4445 .25349 .44326 .25105 .44097 Metetra
.664 .741 .907 r
.25105 .44097 .25349 .44326 .25714 .44202 .25471 .43973 Metetra
.664 .741 .907 r
.25471 .43973 .25714 .44202 .2608 .44078 .25837 .43848 Metetra
.664 .741 .907 r
.25837 .43848 .2608 .44078 .26446 .43954 .26204 .43724 Metetra
.664 .741 .907 r
.26204 .43724 .26446 .43954 .26813 .43829 .26571 .43599 Metetra
.664 .741 .907 r
.26571 .43599 .26813 .43829 .2718 .43704 .26938 .43474 Metetra
.664 .741 .907 r
.26938 .43474 .2718 .43704 .27548 .4358 .27306 .43349 Metetra
.664 .741 .907 r
.27306 .43349 .27548 .4358 .27916 .43455 .27675 .43223 Metetra
.664 .741 .907 r
.27675 .43223 .27916 .43455 .28285 .43329 .28044 .43098 Metetra
.664 .741 .907 r
.28044 .43098 .28285 .43329 .28654 .43204 .28414 .42972 Metetra
.664 .741 .907 r
.28414 .42972 .28654 .43204 .29024 .43079 .28784 .42846 Metetra
.664 .741 .907 r
.28784 .42846 .29024 .43079 .29395 .42953 .29155 .4272 Metetra
.664 .741 .907 r
.29155 .4272 .29395 .42953 .29766 .42827 .29526 .42594 Metetra
.664 .741 .907 r
.29526 .42594 .29766 .42827 .30137 .42701 .29898 .42468 Metetra
.664 .741 .907 r
.29898 .42468 .30137 .42701 .30509 .42575 .3027 .42341 Metetra
.664 .741 .907 r
.3027 .42341 .30509 .42575 .30882 .42448 .30643 .42214 Metetra
.664 .741 .907 r
.30643 .42214 .30882 .42448 .31255 .42322 .31016 .42087 Metetra
.664 .741 .907 r
.31016 .42087 .31255 .42322 .31628 .42195 .3139 .4196 Metetra
.664 .741 .907 r
.3139 .4196 .31628 .42195 .32002 .42068 .31765 .41833 Metetra
.664 .741 .907 r
.31765 .41833 .32002 .42068 .32377 .41941 .32139 .41706 Metetra
.664 .741 .907 r
.32139 .41706 .32377 .41941 .32752 .41813 .32515 .41578 Metetra
.664 .741 .907 r
.32515 .41578 .32752 .41813 .33128 .41686 .32891 .4145 Metetra
.664 .741 .907 r
.32891 .4145 .33128 .41686 .33504 .41558 .33267 .41322 Metetra
.664 .741 .907 r
.33267 .41322 .33504 .41558 .33881 .4143 .33645 .41194 Metetra
.664 .741 .907 r
.33645 .41194 .33881 .4143 .34258 .41302 .34022 .41065 Metetra
.664 .741 .907 r
.34022 .41065 .34258 .41302 .34636 .41174 .344 .40937 Metetra
.664 .741 .907 r
.344 .40937 .34636 .41174 .35014 .41046 .34779 .40808 Metetra
.664 .741 .907 r
.34779 .40808 .35014 .41046 .35393 .40917 .35158 .40679 Metetra
.664 .741 .907 r
.35158 .40679 .35393 .40917 .35772 .40788 .35538 .4055 Metetra
.664 .741 .907 r
.35538 .4055 .35772 .40788 .36152 .40659 .35918 .40421 Metetra
.664 .741 .907 r
.35918 .40421 .36152 .40659 .36533 .4053 .36299 .40291 Metetra
.664 .741 .907 r
.36299 .40291 .36533 .4053 .36914 .40401 .3668 .40162 Metetra
.664 .741 .907 r
.3668 .40162 .36914 .40401 .37295 .40271 .37062 .40032 Metetra
.664 .741 .907 r
.37062 .40032 .37295 .40271 .37678 .40142 .37445 .39902 Metetra
.664 .741 .907 r
.37445 .39902 .37678 .40142 .3806 .40012 .37828 .39772 Metetra
.664 .741 .907 r
.37828 .39772 .3806 .40012 .38387 .41174 .38211 .39641 Metetra
.036 .025 .512 r
.38211 .39641 .38387 .41174 .38772 .41059 .3854 .40808 Metetra
.648 .729 .907 r
.3854 .40808 .38772 .41059 .39157 .40944 .38925 .40692 Metetra
.648 .728 .907 r
.38925 .40692 .39157 .40944 .39543 .40829 .39311 .40577 Metetra
.648 .728 .907 r
.39311 .40577 .39543 .40829 .39929 .40714 .39698 .40461 Metetra
.647 .727 .907 r
.39698 .40461 .39929 .40714 .40316 .406 .40085 .40346 Metetra
.647 .727 .907 r
.40085 .40346 .40316 .406 .40704 .40485 .40473 .40231 Metetra
.646 .726 .907 r
.40473 .40231 .40704 .40485 .41092 .40372 .40862 .40117 Metetra
.646 .726 .907 r
.40862 .40117 .41092 .40372 .41481 .40258 .41251 .40003 Metetra
.645 .726 .907 r
.41251 .40003 .41481 .40258 .4187 .40145 .4164 .39889 Metetra
.644 .725 .907 r
.4164 .39889 .4187 .40145 .4226 .40033 .42031 .39776 Metetra
.644 .724 .907 r
.42031 .39776 .4226 .40033 .4265 .39921 .42421 .39663 Metetra
.643 .724 .907 r
.42421 .39663 .4265 .39921 .43041 .39809 .42813 .39551 Metetra
.642 .723 .907 r
.42813 .39551 .43041 .39809 .43433 .39698 .43205 .39439 Metetra
.642 .723 .907 r
.43205 .39439 .43433 .39698 .43825 .39588 .43597 .39328 Metetra
.641 .722 .907 r
.43597 .39328 .43825 .39588 .44218 .39478 .43991 .39217 Metetra
.64 .721 .907 r
.43991 .39217 .44218 .39478 .44612 .39369 .44385 .39107 Metetra
.96 .682 .464 r
.44385 .39107 .44612 .39369 .44514 .60402 .44271 .6017 Metetra
.78 .791 .862 r
.44271 .6017 .44514 .60402 .44935 .60276 .44696 .59865 Metetra
.943 .703 .546 r
.44696 .59865 .44935 .60276 .45401 .58006 .45204 .55731 Metetra
.776 .546 .586 r
.45204 .55731 .45401 .58006 .4588 .54824 .45668 .53325 Metetra
.782 .565 .607 r
.45668 .53325 .4588 .54824 .46331 .52823 .46112 .51697 Metetra
.782 .58 .628 r
.46112 .51697 .46331 .52823 .46768 .5141 .46545 .50497 Metetra
.779 .593 .648 r
.46545 .50497 .46768 .5141 .47197 .5034 .46972 .49561 Metetra
.774 .603 .668 r
.46972 .49561 .47197 .5034 .47621 .49492 .47395 .48803 Metetra
.767 .612 .687 r
.47395 .48803 .47621 .49492 .48042 .48797 .47815 .48172 Metetra
.76 .62 .704 r
.47815 .48172 .48042 .48797 .4846 .48213 .48233 .47635 Metetra
.752 .626 .72 r
.48233 .47635 .4846 .48213 .48877 .47714 .4865 .47171 Metetra
.743 .63 .735 r
.4865 .47171 .48877 .47714 .49294 .47281 .49066 .46765 Metetra
.733 .634 .748 r
.49066 .46765 .49294 .47281 .49709 .46902 .49482 .46407 Metetra
.724 .636 .759 r
.49482 .46407 .49709 .46902 .50124 .46568 .49898 .46089 Metetra
.714 .637 .77 r
.49898 .46089 .50124 .46568 .5054 .46271 .50313 .45805 Metetra
.703 .637 .78 r
.50313 .45805 .5054 .46271 .50955 .46008 .50728 .45551 Metetra
.693 .636 .788 r
.50728 .45551 .50955 .46008 .5137 .45774 .51144 .45324 Metetra
.681 .634 .795 r
.51144 .45324 .5137 .45774 .51786 .45567 .5156 .45123 Metetra
.669 .631 .802 r
.5156 .45123 .51786 .45567 .52202 .45386 .51976 .44944 Metetra
.657 .626 .808 r
.51976 .44944 .52202 .45386 .52619 .45228 .52393 .44788 Metetra
.644 .621 .812 r
.52393 .44788 .52619 .45228 .53036 .45094 .52811 .44653 Metetra
.629 .614 .816 r
.52811 .44653 .53036 .45094 .53454 .44984 .53229 .44541 Metetra
.614 .606 .819 r
.53229 .44541 .53454 .44984 .53873 .44898 .53648 .44451 Metetra
.597 .596 .822 r
.53648 .44451 .53873 .44898 .54293 .44837 .54067 .44384 Metetra
.578 .584 .823 r
.54067 .44384 .54293 .44837 .54714 .44803 .54488 .44342 Metetra
.556 .569 .822 r
.54488 .44342 .54714 .44803 .55135 .44799 .5491 .44328 Metetra
.532 .552 .821 r
.5491 .44328 .55135 .44799 .55559 .44829 .55333 .44344 Metetra
.503 .53 .817 r
.55333 .44344 .55559 .44829 .55983 .44897 .55758 .44395 Metetra
.47 .504 .811 r
.55758 .44395 .55983 .44897 .5641 .4501 .56184 .44486 Metetra
.43 .472 .802 r
.56184 .44486 .5641 .4501 .56838 .45178 .56612 .44626 Metetra
.382 .432 .789 r
.56612 .44626 .56838 .45178 .57269 .45413 .57042 .44825 Metetra
.324 .383 .769 r
.57042 .44825 .57269 .45413 .57703 .45734 .57474 .45097 Metetra
.252 .321 .741 r
.57474 .45097 .57703 .45734 .5814 .46167 .57911 .45465 Metetra
.165 .244 .7 r
.57911 .45465 .5814 .46167 .58583 .46756 .58351 .45962 Metetra
.057 .148 .644 r
.58351 .45962 .58583 .46756 .59033 .4757 .58797 .46639 Metetra
0 .033 .568 r
.58797 .46639 .59033 .4757 .59493 .48734 .59252 .47586 Metetra
0 0 .469 r
.59252 .47586 .59493 .48734 .59971 .50495 .59719 .48967 Metetra
0 0 .347 r
.59719 .48967 .59971 .50495 .60483 .53456 .6021 .5114 Metetra
0 0 .205 r
.6021 .5114 .60483 .53456 .60981 .55499 .6075 .5507 Metetra
.491 .562 .855 r
.6075 .5507 .60981 .55499 .61428 .55366 .61202 .5512 Metetra
.973 .692 .437 r
.61202 .5512 .61428 .55366 .61278 .33762 .61066 .33484 Metetra
.682 .735 .891 r
.61066 .33484 .61278 .33762 .61697 .33597 .61485 .33319 Metetra
.682 .735 .891 r
.61485 .33319 .61697 .33597 .62116 .33432 .61905 .33155 Metetra
.681 .736 .892 r
.61905 .33155 .62116 .33432 .62536 .33269 .62325 .32992 Metetra
.68 .736 .893 r
.62325 .32992 .62536 .33269 .62956 .33106 .62746 .32828 Metetra
.68 .736 .893 r
.62746 .32828 .62956 .33106 .63377 .32943 .63167 .32666 Metetra
.679 .736 .894 r
.63167 .32666 .63377 .32943 .63799 .32781 .63589 .32504 Metetra
.679 .736 .894 r
.63589 .32504 .63799 .32781 .64221 .32619 .64012 .32342 Metetra
.678 .737 .894 r
.64012 .32342 .64221 .32619 .64644 .32458 .64435 .32181 Metetra
.678 .737 .895 r
.64435 .32181 .64644 .32458 .65067 .32297 .64859 .3202 Metetra
.677 .737 .895 r
.64859 .3202 .65067 .32297 .65491 .32136 .65284 .31859 Metetra
.677 .737 .896 r
.65284 .31859 .65491 .32136 .65916 .31976 .65709 .31699 Metetra
.677 .737 .896 r
.65709 .31699 .65916 .31976 .66341 .31816 .66134 .31539 Metetra
.676 .737 .896 r
.66134 .31539 .66341 .31816 .66767 .31656 .66561 .31379 Metetra
.676 .737 .897 r
.66561 .31379 .66767 .31656 .67193 .31497 .66988 .31219 Metetra
.676 .738 .897 r
.66988 .31219 .67193 .31497 .67621 .31338 .67415 .3106 Metetra
.953 .759 .603 r
.67415 .3106 .67621 .31338 .68048 .31178 .67779 .29589 Metetra
.585 .422 .626 r
.67779 .29589 .68048 .31178 .6841 .29712 .68207 .29443 Metetra
.664 .741 .907 r
.68207 .29443 .6841 .29712 .68838 .29566 .68635 .29298 Metetra
.664 .741 .907 r
.68635 .29298 .68838 .29566 .69267 .29421 .69064 .29152 Metetra
.664 .741 .907 r
.69064 .29152 .69267 .29421 .69696 .29275 .69494 .29006 Metetra
.664 .741 .907 r
.69494 .29006 .69696 .29275 .70126 .29129 .69924 .28859 Metetra
.664 .741 .907 r
.69924 .28859 .70126 .29129 .70556 .28983 .70355 .28713 Metetra
.664 .741 .907 r
.70355 .28713 .70556 .28983 .70987 .28837 .70787 .28566 Metetra
.664 .741 .907 r
.70787 .28566 .70987 .28837 .71419 .2869 .71219 .28419 Metetra
.664 .741 .907 r
.71219 .28419 .71419 .2869 .71852 .28544 .71652 .28272 Metetra
.664 .741 .907 r
.71652 .28272 .71852 .28544 .72285 .28396 .72086 .28125 Metetra
.664 .741 .907 r
.72086 .28125 .72285 .28396 .72719 .28249 .7252 .27977 Metetra
.664 .741 .907 r
.7252 .27977 .72719 .28249 .73153 .28102 .72955 .27829 Metetra
.664 .741 .907 r
.72955 .27829 .73153 .28102 .73588 .27954 .7339 .27681 Metetra
.664 .741 .907 r
.7339 .27681 .73588 .27954 .74024 .27806 .73827 .27533 Metetra
.664 .741 .907 r
.73827 .27533 .74024 .27806 .7446 .27658 .74264 .27384 Metetra
.664 .741 .907 r
.74264 .27384 .7446 .27658 .74898 .2751 .74701 .27235 Metetra
.664 .741 .907 r
.74701 .27235 .74898 .2751 .75335 .27361 .75139 .27086 Metetra
.664 .741 .907 r
.75139 .27086 .75335 .27361 .75774 .27212 .75578 .26937 Metetra
.664 .741 .907 r
.75578 .26937 .75774 .27212 .76213 .27063 .76018 .26788 Metetra
.664 .741 .907 r
.76018 .26788 .76213 .27063 .76653 .26914 .76458 .26638 Metetra
.664 .741 .907 r
.76458 .26638 .76653 .26914 .77093 .26765 .76899 .26488 Metetra
.664 .741 .907 r
.76899 .26488 .77093 .26765 .77534 .26615 .77341 .26338 Metetra
.664 .741 .907 r
.77341 .26338 .77534 .26615 .77976 .26465 .77783 .26187 Metetra
.664 .741 .907 r
.77783 .26187 .77976 .26465 .78419 .26315 .78226 .26037 Metetra
.664 .741 .907 r
.78226 .26037 .78419 .26315 .78862 .26164 .7867 .25886 Metetra
.664 .741 .907 r
.7867 .25886 .78862 .26164 .79306 .26014 .79114 .25735 Metetra
.664 .741 .907 r
.79114 .25735 .79306 .26014 .7975 .25863 .79559 .25584 Metetra
.664 .741 .907 r
.79559 .25584 .7975 .25863 .80196 .25712 .80005 .25432 Metetra
.664 .741 .907 r
.80005 .25432 .80196 .25712 .80642 .2556 .80451 .2528 Metetra
.664 .741 .907 r
.80451 .2528 .80642 .2556 .81088 .25409 .80899 .25128 Metetra
.664 .741 .907 r
.80899 .25128 .81088 .25409 .81535 .25257 .81346 .24976 Metetra
.664 .741 .907 r
.81346 .24976 .81535 .25257 .81983 .25105 .81795 .24824 Metetra
.664 .741 .907 r
.81795 .24824 .81983 .25105 .82432 .24953 .82244 .24671 Metetra
.664 .741 .907 r
.82244 .24671 .82432 .24953 .82882 .248 .82694 .24518 Metetra
.664 .741 .907 r
.82694 .24518 .82882 .248 .83332 .24647 .83145 .24365 Metetra
.664 .741 .907 r
.83145 .24365 .83332 .24647 .83782 .24494 .83596 .24211 Metetra
.664 .741 .907 r
.83596 .24211 .83782 .24494 .84234 .24341 .84048 .24058 Metetra
.664 .741 .907 r
.84048 .24058 .84234 .24341 .84686 .24188 .84501 .23904 Metetra
.664 .741 .907 r
.23767 .4424 .24012 .44469 .24376 .44345 .24131 .44116 Metetra
.664 .741 .907 r
.24131 .44116 .24376 .44345 .2474 .44221 .24496 .43992 Metetra
.664 .741 .907 r
.24496 .43992 .2474 .44221 .25105 .44097 .24861 .43867 Metetra
.664 .741 .907 r
.24861 .43867 .25105 .44097 .25471 .43973 .25227 .43743 Metetra
.664 .741 .907 r
.25227 .43743 .25471 .43973 .25837 .43848 .25594 .43618 Metetra
.664 .741 .907 r
.25594 .43618 .25837 .43848 .26204 .43724 .25961 .43493 Metetra
.664 .741 .907 r
.25961 .43493 .26204 .43724 .26571 .43599 .26328 .43368 Metetra
.664 .741 .907 r
.26328 .43368 .26571 .43599 .26938 .43474 .26696 .43243 Metetra
.664 .741 .907 r
.26696 .43243 .26938 .43474 .27306 .43349 .27064 .43117 Metetra
.664 .741 .907 r
.27064 .43117 .27306 .43349 .27675 .43223 .27433 .42992 Metetra
.664 .741 .907 r
.27433 .42992 .27675 .43223 .28044 .43098 .27803 .42866 Metetra
.664 .741 .907 r
.27803 .42866 .28044 .43098 .28414 .42972 .28173 .4274 Metetra
.664 .741 .907 r
.28173 .4274 .28414 .42972 .28784 .42846 .28543 .42614 Metetra
.664 .741 .907 r
.28543 .42614 .28784 .42846 .29155 .4272 .28914 .42487 Metetra
.664 .741 .907 r
.28914 .42487 .29155 .4272 .29526 .42594 .29286 .42361 Metetra
.664 .741 .907 r
.29286 .42361 .29526 .42594 .29898 .42468 .29658 .42234 Metetra
.664 .741 .907 r
.29658 .42234 .29898 .42468 .3027 .42341 .30031 .42107 Metetra
.664 .741 .907 r
.30031 .42107 .3027 .42341 .30643 .42214 .30404 .4198 Metetra
.664 .741 .907 r
.30404 .4198 .30643 .42214 .31016 .42087 .30777 .41853 Metetra
.664 .741 .907 r
.30777 .41853 .31016 .42087 .3139 .4196 .31152 .41725 Metetra
.664 .741 .907 r
.31152 .41725 .3139 .4196 .31765 .41833 .31526 .41598 Metetra
.664 .741 .907 r
.31526 .41598 .31765 .41833 .32139 .41706 .31901 .4147 Metetra
.664 .741 .907 r
.31901 .4147 .32139 .41706 .32515 .41578 .32277 .41342 Metetra
.664 .741 .907 r
.32277 .41342 .32515 .41578 .32891 .4145 .32654 .41214 Metetra
.664 .741 .907 r
.32654 .41214 .32891 .4145 .33267 .41322 .3303 .41085 Metetra
.664 .741 .907 r
.3303 .41085 .33267 .41322 .33645 .41194 .33408 .40957 Metetra
.664 .741 .907 r
.33408 .40957 .33645 .41194 .34022 .41065 .33786 .40828 Metetra
.664 .741 .907 r
.33786 .40828 .34022 .41065 .344 .40937 .34164 .40699 Metetra
.664 .741 .907 r
.34164 .40699 .344 .40937 .34779 .40808 .34543 .4057 Metetra
.664 .741 .907 r
.34543 .4057 .34779 .40808 .35158 .40679 .34923 .40441 Metetra
.664 .741 .907 r
.34923 .40441 .35158 .40679 .35538 .4055 .35303 .40311 Metetra
.664 .741 .907 r
.35303 .40311 .35538 .4055 .35918 .40421 .35684 .40182 Metetra
.664 .741 .907 r
.35684 .40182 .35918 .40421 .36299 .40291 .36065 .40052 Metetra
.664 .741 .907 r
.36065 .40052 .36299 .40291 .3668 .40162 .36446 .39922 Metetra
.664 .741 .907 r
.36446 .39922 .3668 .40162 .37062 .40032 .36829 .39792 Metetra
.664 .741 .907 r
.36829 .39792 .37062 .40032 .37445 .39902 .37212 .39661 Metetra
.664 .741 .907 r
.37212 .39661 .37445 .39902 .37828 .39772 .37595 .39531 Metetra
.664 .741 .907 r
.37595 .39531 .37828 .39772 .38211 .39641 .37979 .394 Metetra
.664 .741 .907 r
.37979 .394 .38211 .39641 .3854 .40808 .38363 .39269 Metetra
.036 .024 .512 r
.38363 .39269 .3854 .40808 .38925 .40692 .38693 .4044 Metetra
.648 .728 .907 r
.38693 .4044 .38925 .40692 .39311 .40577 .39079 .40324 Metetra
.648 .728 .907 r
.39079 .40324 .39311 .40577 .39698 .40461 .39466 .40208 Metetra
.647 .728 .907 r
.39466 .40208 .39698 .40461 .40085 .40346 .39854 .40092 Metetra
.647 .727 .907 r
.39854 .40092 .40085 .40346 .40473 .40231 .40242 .39977 Metetra
.646 .727 .907 r
.40242 .39977 .40473 .40231 .40862 .40117 .40631 .39862 Metetra
.646 .726 .907 r
.40631 .39862 .40862 .40117 .41251 .40003 .4102 .39747 Metetra
.645 .726 .907 r
.4102 .39747 .41251 .40003 .4164 .39889 .4141 .39633 Metetra
.645 .725 .907 r
.4141 .39633 .4164 .39889 .42031 .39776 .41801 .39519 Metetra
.644 .725 .907 r
.41801 .39519 .42031 .39776 .42421 .39663 .42192 .39405 Metetra
.644 .724 .907 r
.42192 .39405 .42421 .39663 .42813 .39551 .42584 .39292 Metetra
.643 .724 .907 r
.42584 .39292 .42813 .39551 .43205 .39439 .42976 .39179 Metetra
.642 .723 .907 r
.42976 .39179 .43205 .39439 .43597 .39328 .43369 .39067 Metetra
.641 .722 .907 r
.43369 .39067 .43597 .39328 .43991 .39217 .43763 .38956 Metetra
.96 .682 .465 r
.43763 .38956 .43991 .39217 .44385 .39107 .43606 .60064 Metetra
.54 .316 .524 r
.43606 .60064 .44385 .39107 .44271 .6017 .44027 .59938 Metetra
.95 .725 .562 r
.44027 .59938 .44271 .6017 .44696 .59865 .44517 .56927 Metetra
.77 .534 .578 r
.44517 .56927 .44696 .59865 .45204 .55731 .44999 .53962 Metetra
.779 .557 .597 r
.44999 .53962 .45204 .55731 .45668 .53325 .45452 .52061 Metetra
.782 .574 .618 r
.45452 .52061 .45668 .53325 .46112 .51697 .45891 .50702 Metetra
.78 .587 .639 r
.45891 .50702 .46112 .51697 .46545 .50497 .46322 .49665 Metetra
.776 .599 .659 r
.46322 .49665 .46545 .50497 .46972 .49561 .46747 .48836 Metetra
.771 .609 .679 r
.46747 .48836 .46972 .49561 .47395 .48803 .47169 .48153 Metetra
.764 .617 .697 r
.47169 .48153 .47395 .48803 .47815 .48172 .47588 .47576 Metetra
.756 .624 .713 r
.47588 .47576 .47815 .48172 .48233 .47635 .48006 .47079 Metetra
.748 .629 .728 r
.48006 .47079 .48233 .47635 .4865 .47171 .48423 .46646 Metetra
.739 .634 .742 r
.48423 .46646 .4865 .47171 .49066 .46765 .48839 .46264 Metetra
.73 .637 .754 r
.48839 .46264 .49066 .46765 .49482 .46407 .49255 .45924 Metetra
.721 .639 .765 r
.49255 .45924 .49482 .46407 .49898 .46089 .4967 .4562 Metetra
.711 .639 .775 r
.4967 .4562 .49898 .46089 .50313 .45805 .50086 .45347 Metetra
.701 .639 .784 r
.50086 .45347 .50313 .45805 .50728 .45551 .50501 .45102 Metetra
.691 .638 .792 r
.50501 .45102 .50728 .45551 .51144 .45324 .50917 .44882 Metetra
.68 .637 .799 r
.50917 .44882 .51144 .45324 .5156 .45123 .51333 .44684 Metetra
.669 .634 .806 r
.51333 .44684 .5156 .45123 .51976 .44944 .5175 .44509 Metetra
.657 .63 .811 r
.5175 .44509 .51976 .44944 .52393 .44788 .52167 .44353 Metetra
.644 .625 .815 r
.52167 .44353 .52393 .44788 .52811 .44653 .52584 .44219 Metetra
.631 .618 .819 r
.52584 .44219 .52811 .44653 .53229 .44541 .53003 .44104 Metetra
.616 .611 .822 r
.53003 .44104 .53229 .44541 .53648 .44451 .53422 .4401 Metetra
.6 .601 .824 r
.53422 .4401 .53648 .44451 .54067 .44384 .53842 .43938 Metetra
.583 .59 .825 r
.53842 .43938 .54067 .44384 .54488 .44342 .54263 .43889 Metetra
.563 .577 .825 r
.54263 .43889 .54488 .44342 .5491 .44328 .54684 .43866 Metetra
.541 .561 .824 r
.54684 .43866 .5491 .44328 .55333 .44344 .55107 .4387 Metetra
.515 .541 .821 r
.55107 .4387 .55333 .44344 .55758 .44395 .55532 .43905 Metetra
.484 .518 .816 r
.55532 .43905 .55758 .44395 .56184 .44486 .55958 .43977 Metetra
.449 .489 .809 r
.55958 .43977 .56184 .44486 .56612 .44626 .56385 .44092 Metetra
.406 .454 .797 r
.56385 .44092 .56612 .44626 .57042 .44825 .56815 .44258 Metetra
.355 .41 .781 r
.56815 .44258 .57042 .44825 .57474 .45097 .57247 .44489 Metetra
.292 .356 .758 r
.57247 .44489 .57474 .45097 .57911 .45465 .57681 .44802 Metetra
.214 .288 .724 r
.57681 .44802 .57911 .45465 .58351 .45962 .5812 .45222 Metetra
.119 .204 .678 r
.5812 .45222 .58351 .45962 .58797 .46639 .58563 .4579 Metetra
.005 .101 .614 r
.58563 .4579 .58797 .46639 .59252 .47586 .59014 .46571 Metetra
0 0 .529 r
.59014 .46571 .59252 .47586 .59719 .48967 .59474 .47677 Metetra
0 0 .421 r
.59474 .47677 .59719 .48967 .6021 .5114 .5995 .49337 Metetra
0 0 .292 r
.5995 .49337 .6021 .5114 .6075 .5507 .60458 .52078 Metetra
.002 0 .466 r
.60458 .52078 .6075 .5507 .61202 .5512 .60976 .54873 Metetra
.645 .763 .934 r
.60976 .54873 .61202 .5512 .61066 .33484 .61424 .54739 Metetra
0 0 .366 r
.61424 .54739 .61066 .33484 .61485 .33319 .61273 .33041 Metetra
.681 .736 .892 r
.61273 .33041 .61485 .33319 .61905 .33155 .61693 .32877 Metetra
.681 .736 .892 r
.61693 .32877 .61905 .33155 .62325 .32992 .62114 .32714 Metetra
.68 .736 .893 r
.62114 .32714 .62325 .32992 .62746 .32828 .62535 .32551 Metetra
.68 .736 .893 r
.62535 .32551 .62746 .32828 .63167 .32666 .62957 .32388 Metetra
.679 .736 .894 r
.62957 .32388 .63167 .32666 .63589 .32504 .63379 .32226 Metetra
.679 .736 .894 r
.63379 .32226 .63589 .32504 .64012 .32342 .63802 .32065 Metetra
.678 .737 .895 r
.63802 .32065 .64012 .32342 .64435 .32181 .64226 .31903 Metetra
.678 .737 .895 r
.64226 .31903 .64435 .32181 .64859 .3202 .6465 .31742 Metetra
.677 .737 .896 r
.6465 .31742 .64859 .3202 .65284 .31859 .65075 .31582 Metetra
.677 .737 .896 r
.65075 .31582 .65284 .31859 .65709 .31699 .65501 .31421 Metetra
.676 .737 .896 r
.65501 .31421 .65709 .31699 .66134 .31539 .65927 .31261 Metetra
.676 .737 .897 r
.65927 .31261 .66134 .31539 .66561 .31379 .66354 .31101 Metetra
.676 .737 .897 r
.66354 .31101 .66561 .31379 .66988 .31219 .66781 .30941 Metetra
.953 .758 .603 r
.66781 .30941 .66988 .31219 .67415 .3106 .67147 .29466 Metetra
.585 .421 .626 r
.67147 .29466 .67415 .3106 .67779 .29589 .67575 .2932 Metetra
.664 .741 .907 r
.67575 .2932 .67779 .29589 .68207 .29443 .68003 .29174 Metetra
.664 .741 .907 r
.68003 .29174 .68207 .29443 .68635 .29298 .68432 .29028 Metetra
.664 .741 .907 r
.68432 .29028 .68635 .29298 .69064 .29152 .68861 .28882 Metetra
.664 .741 .907 r
.68861 .28882 .69064 .29152 .69494 .29006 .69292 .28735 Metetra
.664 .741 .907 r
.69292 .28735 .69494 .29006 .69924 .28859 .69722 .28589 Metetra
.664 .741 .907 r
.69722 .28589 .69924 .28859 .70355 .28713 .70154 .28442 Metetra
.664 .741 .907 r
.70154 .28442 .70355 .28713 .70787 .28566 .70586 .28295 Metetra
.664 .741 .907 r
.70586 .28295 .70787 .28566 .71219 .28419 .71019 .28147 Metetra
.664 .741 .907 r
.71019 .28147 .71219 .28419 .71652 .28272 .71452 .28 Metetra
.664 .741 .907 r
.71452 .28 .71652 .28272 .72086 .28125 .71886 .27852 Metetra
.664 .741 .907 r
.71886 .27852 .72086 .28125 .7252 .27977 .72321 .27704 Metetra
.664 .741 .907 r
.72321 .27704 .7252 .27977 .72955 .27829 .72756 .27555 Metetra
.664 .741 .907 r
.72756 .27555 .72955 .27829 .7339 .27681 .73192 .27407 Metetra
.664 .741 .907 r
.73192 .27407 .7339 .27681 .73827 .27533 .73629 .27258 Metetra
.664 .741 .907 r
.73629 .27258 .73827 .27533 .74264 .27384 .74066 .27109 Metetra
.664 .741 .907 r
.74066 .27109 .74264 .27384 .74701 .27235 .74504 .2696 Metetra
.664 .741 .907 r
.74504 .2696 .74701 .27235 .75139 .27086 .74943 .26811 Metetra
.664 .741 .907 r
.74943 .26811 .75139 .27086 .75578 .26937 .75382 .26661 Metetra
.664 .741 .907 r
.75382 .26661 .75578 .26937 .76018 .26788 .75822 .26511 Metetra
.664 .741 .907 r
.75822 .26511 .76018 .26788 .76458 .26638 .76263 .26361 Metetra
.664 .741 .907 r
.76263 .26361 .76458 .26638 .76899 .26488 .76705 .26211 Metetra
.664 .741 .907 r
.76705 .26211 .76899 .26488 .77341 .26338 .77147 .2606 Metetra
.664 .741 .907 r
.77147 .2606 .77341 .26338 .77783 .26187 .7759 .25909 Metetra
.664 .741 .907 r
.7759 .25909 .77783 .26187 .78226 .26037 .78033 .25758 Metetra
.664 .741 .907 r
.78033 .25758 .78226 .26037 .7867 .25886 .78477 .25607 Metetra
.664 .741 .907 r
.78477 .25607 .7867 .25886 .79114 .25735 .78922 .25455 Metetra
.664 .741 .907 r
.78922 .25455 .79114 .25735 .79559 .25584 .79368 .25304 Metetra
.664 .741 .907 r
.79368 .25304 .79559 .25584 .80005 .25432 .79814 .25152 Metetra
.664 .741 .907 r
.79814 .25152 .80005 .25432 .80451 .2528 .80261 .24999 Metetra
.664 .741 .907 r
.80261 .24999 .80451 .2528 .80899 .25128 .80708 .24847 Metetra
.664 .741 .907 r
.80708 .24847 .80899 .25128 .81346 .24976 .81157 .24694 Metetra
.664 .741 .907 r
.81157 .24694 .81346 .24976 .81795 .24824 .81606 .24541 Metetra
.664 .741 .907 r
.81606 .24541 .81795 .24824 .82244 .24671 .82055 .24388 Metetra
.664 .741 .907 r
.82055 .24388 .82244 .24671 .82694 .24518 .82506 .24235 Metetra
.664 .741 .907 r
.82506 .24235 .82694 .24518 .83145 .24365 .82957 .24081 Metetra
.664 .741 .907 r
.82957 .24081 .83145 .24365 .83596 .24211 .83409 .23927 Metetra
.664 .741 .907 r
.83409 .23927 .83596 .24211 .84048 .24058 .83861 .23773 Metetra
.664 .741 .907 r
.83861 .23773 .84048 .24058 .84501 .23904 .84314 .23619 Metetra
.664 .741 .907 r
.23522 .44011 .23767 .4424 .24131 .44116 .23886 .43887 Metetra
.664 .741 .907 r
.23886 .43887 .24131 .44116 .24496 .43992 .24251 .43762 Metetra
.664 .741 .907 r
.24251 .43762 .24496 .43992 .24861 .43867 .24617 .43637 Metetra
.664 .741 .907 r
.24617 .43637 .24861 .43867 .25227 .43743 .24983 .43512 Metetra
.664 .741 .907 r
.24983 .43512 .25227 .43743 .25594 .43618 .2535 .43387 Metetra
.664 .741 .907 r
.2535 .43387 .25594 .43618 .25961 .43493 .25717 .43262 Metetra
.664 .741 .907 r
.25717 .43262 .25961 .43493 .26328 .43368 .26085 .43137 Metetra
.664 .741 .907 r
.26085 .43137 .26328 .43368 .26696 .43243 .26453 .43011 Metetra
.664 .741 .907 r
.26453 .43011 .26696 .43243 .27064 .43117 .26822 .42885 Metetra
.664 .741 .907 r
.26822 .42885 .27064 .43117 .27433 .42992 .27191 .42759 Metetra
.664 .741 .907 r
.27191 .42759 .27433 .42992 .27803 .42866 .27561 .42633 Metetra
.664 .741 .907 r
.27561 .42633 .27803 .42866 .28173 .4274 .27931 .42507 Metetra
.664 .741 .907 r
.27931 .42507 .28173 .4274 .28543 .42614 .28302 .4238 Metetra
.664 .741 .907 r
.28302 .4238 .28543 .42614 .28914 .42487 .28673 .42253 Metetra
.664 .741 .907 r
.28673 .42253 .28914 .42487 .29286 .42361 .29045 .42127 Metetra
.664 .741 .907 r
.29045 .42127 .29286 .42361 .29658 .42234 .29417 .41999 Metetra
.664 .741 .907 r
.29417 .41999 .29658 .42234 .30031 .42107 .2979 .41872 Metetra
.664 .741 .907 r
.2979 .41872 .30031 .42107 .30404 .4198 .30164 .41745 Metetra
.664 .741 .907 r
.30164 .41745 .30404 .4198 .30777 .41853 .30538 .41617 Metetra
.664 .741 .907 r
.30538 .41617 .30777 .41853 .31152 .41725 .30912 .41489 Metetra
.664 .741 .907 r
.30912 .41489 .31152 .41725 .31526 .41598 .31287 .41361 Metetra
.664 .741 .907 r
.31287 .41361 .31526 .41598 .31901 .4147 .31663 .41233 Metetra
.664 .741 .907 r
.31663 .41233 .31901 .4147 .32277 .41342 .32039 .41105 Metetra
.664 .741 .907 r
.32039 .41105 .32277 .41342 .32654 .41214 .32416 .40976 Metetra
.664 .741 .907 r
.32416 .40976 .32654 .41214 .3303 .41085 .32793 .40848 Metetra
.664 .741 .907 r
.32793 .40848 .3303 .41085 .33408 .40957 .33171 .40719 Metetra
.664 .741 .907 r
.33171 .40719 .33408 .40957 .33786 .40828 .33549 .4059 Metetra
.664 .741 .907 r
.33549 .4059 .33786 .40828 .34164 .40699 .33928 .40461 Metetra
.664 .741 .907 r
.33928 .40461 .34164 .40699 .34543 .4057 .34307 .40331 Metetra
.664 .741 .907 r
.34307 .40331 .34543 .4057 .34923 .40441 .34687 .40202 Metetra
.664 .741 .907 r
.34687 .40202 .34923 .40441 .35303 .40311 .35067 .40072 Metetra
.664 .741 .907 r
.35067 .40072 .35303 .40311 .35684 .40182 .35448 .39942 Metetra
.664 .741 .907 r
.35448 .39942 .35684 .40182 .36065 .40052 .3583 .39812 Metetra
.664 .741 .907 r
.3583 .39812 .36065 .40052 .36446 .39922 .36212 .39681 Metetra
.664 .741 .907 r
.36212 .39681 .36446 .39922 .36829 .39792 .36594 .39551 Metetra
.664 .741 .907 r
.36594 .39551 .36829 .39792 .37212 .39661 .36978 .3942 Metetra
.664 .741 .907 r
.36978 .3942 .37212 .39661 .37595 .39531 .37361 .39289 Metetra
.664 .741 .907 r
.37361 .39289 .37595 .39531 .37979 .394 .37746 .39158 Metetra
.664 .741 .907 r
.37746 .39158 .37979 .394 .38363 .39269 .3813 .39027 Metetra
.664 .741 .907 r
.3813 .39027 .38363 .39269 .38693 .4044 .38516 .38895 Metetra
.035 .024 .511 r
.38516 .38895 .38693 .4044 .39079 .40324 .38846 .40071 Metetra
.648 .728 .907 r
.38846 .40071 .39079 .40324 .39466 .40208 .39234 .39954 Metetra
.648 .728 .907 r
.39234 .39954 .39466 .40208 .39854 .40092 .39622 .39838 Metetra
.647 .727 .907 r
.39622 .39838 .39854 .40092 .40242 .39977 .4001 .39722 Metetra
.647 .727 .907 r
.4001 .39722 .40242 .39977 .40631 .39862 .40399 .39606 Metetra
.646 .727 .907 r
.40399 .39606 .40631 .39862 .4102 .39747 .40789 .39491 Metetra
.646 .726 .907 r
.40789 .39491 .4102 .39747 .4141 .39633 .41179 .39375 Metetra
.645 .726 .907 r
.41179 .39375 .4141 .39633 .41801 .39519 .4157 .39261 Metetra
.645 .725 .907 r
.4157 .39261 .41801 .39519 .42192 .39405 .41962 .39146 Metetra
.644 .725 .907 r
.41962 .39146 .42192 .39405 .42584 .39292 .42354 .39032 Metetra
.643 .724 .907 r
.42354 .39032 .42584 .39292 .42976 .39179 .42747 .38919 Metetra
.643 .723 .907 r
.42747 .38919 .42976 .39179 .43369 .39067 .4314 .38806 Metetra
.959 .682 .467 r
.4314 .38806 .43369 .39067 .43763 .38956 .42941 .59957 Metetra
.54 .316 .523 r
.42941 .59957 .43763 .38956 .43606 .60064 .43361 .59831 Metetra
.927 .758 .653 r
.43361 .59831 .43606 .60064 .44027 .59938 .43812 .58554 Metetra
.875 .633 .569 r
.43812 .58554 .44027 .59938 .44517 .56927 .44321 .54776 Metetra
.776 .547 .589 r
.44321 .54776 .44517 .56927 .44999 .53962 .44787 .52517 Metetra
.781 .566 .609 r
.44787 .52517 .44999 .53962 .45452 .52061 .45233 .50964 Metetra
.781 .581 .63 r
.45233 .50964 .45452 .52061 .45891 .50702 .45668 .49807 Metetra
.778 .594 .651 r
.45668 .49807 .45891 .50702 .46322 .49665 .46097 .48898 Metetra
.773 .605 .67 r
.46097 .48898 .46322 .49665 .46747 .48836 .4652 .48157 Metetra
.767 .614 .689 r
.4652 .48157 .46747 .48836 .47169 .48153 .46941 .47536 Metetra
.76 .622 .706 r
.46941 .47536 .47169 .48153 .47588 .47576 .4736 .47005 Metetra
.753 .628 .722 r
.4736 .47005 .47588 .47576 .48006 .47079 .47778 .46543 Metetra
.744 .633 .736 r
.47778 .46543 .48006 .47079 .48423 .46646 .48195 .46136 Metetra
.736 .637 .749 r
.48195 .46136 .48423 .46646 .48839 .46264 .48611 .45775 Metetra
.727 .639 .761 r
.48611 .45775 .48839 .46264 .49255 .45924 .49027 .45451 Metetra
.718 .641 .771 r
.49027 .45451 .49255 .45924 .4967 .4562 .49442 .45161 Metetra
.709 .642 .781 r
.49442 .45161 .4967 .4562 .50086 .45347 .49858 .44898 Metetra
.699 .642 .789 r
.49858 .44898 .50086 .45347 .50501 .45102 .50274 .4466 Metetra
.689 .641 .797 r
.50274 .4466 .50501 .45102 .50917 .44882 .5069 .44446 Metetra
.679 .639 .803 r
.5069 .44446 .50917 .44882 .51333 .44684 .51106 .44253 Metetra
.668 .636 .809 r
.51106 .44253 .51333 .44684 .5175 .44509 .51523 .44079 Metetra
.657 .633 .814 r
.51523 .44079 .5175 .44509 .52167 .44353 .5194 .43925 Metetra
.645 .628 .818 r
.5194 .43925 .52167 .44353 .52584 .44219 .52358 .4379 Metetra
.632 .622 .822 r
.52358 .4379 .52584 .44219 .53003 .44104 .52776 .43673 Metetra
.619 .615 .825 r
.52776 .43673 .53003 .44104 .53422 .4401 .53196 .43576 Metetra
.604 .606 .827 r
.53196 .43576 .53422 .4401 .53842 .43938 .53616 .43499 Metetra
.588 .596 .828 r
.53616 .43499 .53842 .43938 .54263 .43889 .54037 .43444 Metetra
.569 .584 .828 r
.54037 .43444 .54263 .43889 .54684 .43866 .54459 .43411 Metetra
.549 .569 .827 r
.54459 .43411 .54684 .43866 .55107 .4387 .54882 .43404 Metetra
.525 .552 .825 r
.54882 .43404 .55107 .4387 .55532 .43905 .55306 .43426 Metetra
.498 .53 .821 r
.55306 .43426 .55532 .43905 .55958 .43977 .55731 .4348 Metetra
.466 .505 .815 r
.55731 .4348 .55958 .43977 .56385 .44092 .56159 .43573 Metetra
.427 .473 .805 r
.56159 .43573 .56385 .44092 .56815 .44258 .56588 .43712 Metetra
.382 .435 .791 r
.56588 .43712 .56815 .44258 .57247 .44489 .57019 .43907 Metetra
.326 .387 .772 r
.57019 .43907 .57247 .44489 .57681 .44802 .57453 .44172 Metetra
.258 .328 .745 r
.57453 .44172 .57681 .44802 .5812 .45222 .5789 .44529 Metetra
.174 .253 .706 r
.5789 .44529 .5812 .45222 .58563 .4579 .58331 .45007 Metetra
.073 .162 .653 r
.58331 .45007 .58563 .4579 .59014 .46571 .58778 .45656 Metetra
0 .052 .581 r
.58778 .45656 .59014 .46571 .59474 .47677 .59233 .46558 Metetra
0 0 .487 r
.59233 .46558 .59474 .47677 .5995 .49337 .597 .47862 Metetra
0 0 .371 r
.597 .47862 .5995 .49337 .60458 .52078 .60188 .49886 Metetra
0 0 .234 r
.60188 .49886 .60458 .52078 .60976 .54873 .6072 .53456 Metetra
.157 .14 .587 r
.6072 .53456 .60976 .54873 .61424 .54739 .61198 .54491 Metetra
.645 .763 .934 r
.61198 .54491 .61424 .54739 .61273 .33041 .61648 .54356 Metetra
0 0 .366 r
.61648 .54356 .61273 .33041 .61693 .32877 .61481 .32599 Metetra
.68 .736 .893 r
.61481 .32599 .61693 .32877 .62114 .32714 .61902 .32436 Metetra
.68 .736 .893 r
.61902 .32436 .62114 .32714 .62535 .32551 .62324 .32273 Metetra
.679 .736 .894 r
.62324 .32273 .62535 .32551 .62957 .32388 .62746 .3211 Metetra
.679 .736 .894 r
.62746 .3211 .62957 .32388 .63379 .32226 .63169 .31948 Metetra
.678 .737 .895 r
.63169 .31948 .63379 .32226 .63802 .32065 .63592 .31787 Metetra
.678 .737 .895 r
.63592 .31787 .63802 .32065 .64226 .31903 .64017 .31625 Metetra
.677 .737 .895 r
.64017 .31625 .64226 .31903 .6465 .31742 .64441 .31464 Metetra
.677 .737 .896 r
.64441 .31464 .6465 .31742 .65075 .31582 .64867 .31303 Metetra
.677 .737 .896 r
.64867 .31303 .65075 .31582 .65501 .31421 .65293 .31143 Metetra
.676 .737 .896 r
.65293 .31143 .65501 .31421 .65927 .31261 .65719 .30982 Metetra
.676 .737 .897 r
.65719 .30982 .65927 .31261 .66354 .31101 .66147 .30822 Metetra
.953 .758 .603 r
.66147 .30822 .66354 .31101 .66781 .30941 .66515 .29342 Metetra
.584 .42 .626 r
.66515 .29342 .66781 .30941 .67147 .29466 .66942 .29197 Metetra
.664 .741 .907 r
.66942 .29197 .67147 .29466 .67575 .2932 .6737 .29051 Metetra
.664 .741 .907 r
.6737 .29051 .67575 .2932 .68003 .29174 .67799 .28904 Metetra
.664 .741 .907 r
.67799 .28904 .68003 .29174 .68432 .29028 .68228 .28758 Metetra
.664 .741 .907 r
.68228 .28758 .68432 .29028 .68861 .28882 .68658 .28611 Metetra
.664 .741 .907 r
.68658 .28611 .68861 .28882 .69292 .28735 .69089 .28464 Metetra
.664 .741 .907 r
.69089 .28464 .69292 .28735 .69722 .28589 .6952 .28317 Metetra
.664 .741 .907 r
.6952 .28317 .69722 .28589 .70154 .28442 .69952 .2817 Metetra
.664 .741 .907 r
.69952 .2817 .70154 .28442 .70586 .28295 .70384 .28022 Metetra
.664 .741 .907 r
.70384 .28022 .70586 .28295 .71019 .28147 .70817 .27875 Metetra
.664 .741 .907 r
.70817 .27875 .71019 .28147 .71452 .28 .71251 .27727 Metetra
.664 .741 .907 r
.71251 .27727 .71452 .28 .71886 .27852 .71686 .27578 Metetra
.664 .741 .907 r
.71686 .27578 .71886 .27852 .72321 .27704 .72121 .2743 Metetra
.664 .741 .907 r
.72121 .2743 .72321 .27704 .72756 .27555 .72557 .27281 Metetra
.664 .741 .907 r
.72557 .27281 .72756 .27555 .73192 .27407 .72993 .27132 Metetra
.664 .741 .907 r
.72993 .27132 .73192 .27407 .73629 .27258 .7343 .26983 Metetra
.664 .741 .907 r
.7343 .26983 .73629 .27258 .74066 .27109 .73868 .26834 Metetra
.664 .741 .907 r
.73868 .26834 .74066 .27109 .74504 .2696 .74307 .26684 Metetra
.664 .741 .907 r
.74307 .26684 .74504 .2696 .74943 .26811 .74746 .26534 Metetra
.664 .741 .907 r
.74746 .26534 .74943 .26811 .75382 .26661 .75186 .26384 Metetra
.664 .741 .907 r
.75186 .26384 .75382 .26661 .75822 .26511 .75626 .26234 Metetra
.664 .741 .907 r
.75626 .26234 .75822 .26511 .76263 .26361 .76068 .26083 Metetra
.664 .741 .907 r
.76068 .26083 .76263 .26361 .76705 .26211 .7651 .25932 Metetra
.664 .741 .907 r
.7651 .25932 .76705 .26211 .77147 .2606 .76952 .25781 Metetra
.664 .741 .907 r
.76952 .25781 .77147 .2606 .7759 .25909 .77395 .2563 Metetra
.664 .741 .907 r
.77395 .2563 .7759 .25909 .78033 .25758 .77839 .25479 Metetra
.664 .741 .907 r
.77839 .25479 .78033 .25758 .78477 .25607 .78284 .25327 Metetra
.664 .741 .907 r
.78284 .25327 .78477 .25607 .78922 .25455 .78729 .25175 Metetra
.664 .741 .907 r
.78729 .25175 .78922 .25455 .79368 .25304 .79175 .25023 Metetra
.664 .741 .907 r
.79175 .25023 .79368 .25304 .79814 .25152 .79622 .24871 Metetra
.664 .741 .907 r
.79622 .24871 .79814 .25152 .80261 .24999 .8007 .24718 Metetra
.664 .741 .907 r
.8007 .24718 .80261 .24999 .80708 .24847 .80518 .24565 Metetra
.664 .741 .907 r
.80518 .24565 .80708 .24847 .81157 .24694 .80966 .24412 Metetra
.664 .741 .907 r
.80966 .24412 .81157 .24694 .81606 .24541 .81416 .24258 Metetra
.664 .741 .907 r
.81416 .24258 .81606 .24541 .82055 .24388 .81866 .24105 Metetra
.664 .741 .907 r
.81866 .24105 .82055 .24388 .82506 .24235 .82317 .23951 Metetra
.664 .741 .907 r
.82317 .23951 .82506 .24235 .82957 .24081 .82769 .23797 Metetra
.664 .741 .907 r
.82769 .23797 .82957 .24081 .83409 .23927 .83221 .23643 Metetra
.664 .741 .907 r
.83221 .23643 .83409 .23927 .83861 .23773 .83674 .23488 Metetra
.664 .741 .907 r
.83674 .23488 .83861 .23773 .84314 .23619 .84128 .23333 Metetra
.664 .741 .907 r
.23275 .43781 .23522 .44011 .23886 .43887 .2364 .43656 Metetra
.664 .741 .907 r
.2364 .43656 .23886 .43887 .24251 .43762 .24006 .43532 Metetra
.664 .741 .907 r
.24006 .43532 .24251 .43762 .24617 .43637 .24372 .43407 Metetra
.664 .741 .907 r
.24372 .43407 .24617 .43637 .24983 .43512 .24738 .43281 Metetra
.664 .741 .907 r
.24738 .43281 .24983 .43512 .2535 .43387 .25105 .43156 Metetra
.664 .741 .907 r
.25105 .43156 .2535 .43387 .25717 .43262 .25473 .4303 Metetra
.664 .741 .907 r
.25473 .4303 .25717 .43262 .26085 .43137 .25841 .42904 Metetra
.664 .741 .907 r
.25841 .42904 .26085 .43137 .26453 .43011 .26209 .42778 Metetra
.664 .741 .907 r
.26209 .42778 .26453 .43011 .26822 .42885 .26578 .42652 Metetra
.664 .741 .907 r
.26578 .42652 .26822 .42885 .27191 .42759 .26948 .42526 Metetra
.664 .741 .907 r
.26948 .42526 .27191 .42759 .27561 .42633 .27318 .424 Metetra
.664 .741 .907 r
.27318 .424 .27561 .42633 .27931 .42507 .27689 .42273 Metetra
.664 .741 .907 r
.27689 .42273 .27931 .42507 .28302 .4238 .2806 .42146 Metetra
.664 .741 .907 r
.2806 .42146 .28302 .4238 .28673 .42253 .28431 .42019 Metetra
.664 .741 .907 r
.28431 .42019 .28673 .42253 .29045 .42127 .28804 .41892 Metetra
.664 .741 .907 r
.28804 .41892 .29045 .42127 .29417 .41999 .29176 .41764 Metetra
.664 .741 .907 r
.29176 .41764 .29417 .41999 .2979 .41872 .2955 .41637 Metetra
.664 .741 .907 r
.2955 .41637 .2979 .41872 .30164 .41745 .29923 .41509 Metetra
.664 .741 .907 r
.29923 .41509 .30164 .41745 .30538 .41617 .30298 .41381 Metetra
.664 .741 .907 r
.30298 .41381 .30538 .41617 .30912 .41489 .30672 .41253 Metetra
.664 .741 .907 r
.30672 .41253 .30912 .41489 .31287 .41361 .31048 .41125 Metetra
.664 .741 .907 r
.31048 .41125 .31287 .41361 .31663 .41233 .31424 .40996 Metetra
.664 .741 .907 r
.31424 .40996 .31663 .41233 .32039 .41105 .318 .40868 Metetra
.664 .741 .907 r
.318 .40868 .32039 .41105 .32416 .40976 .32177 .40739 Metetra
.664 .741 .907 r
.32177 .40739 .32416 .40976 .32793 .40848 .32555 .4061 Metetra
.664 .741 .907 r
.32555 .4061 .32793 .40848 .33171 .40719 .32933 .40481 Metetra
.664 .741 .907 r
.32933 .40481 .33171 .40719 .33549 .4059 .33311 .40351 Metetra
.664 .741 .907 r
.33311 .40351 .33549 .4059 .33928 .40461 .3369 .40222 Metetra
.664 .741 .907 r
.3369 .40222 .33928 .40461 .34307 .40331 .3407 .40092 Metetra
.664 .741 .907 r
.3407 .40092 .34307 .40331 .34687 .40202 .3445 .39962 Metetra
.664 .741 .907 r
.3445 .39962 .34687 .40202 .35067 .40072 .34831 .39832 Metetra
.664 .741 .907 r
.34831 .39832 .35067 .40072 .35448 .39942 .35212 .39701 Metetra
.664 .741 .907 r
.35212 .39701 .35448 .39942 .3583 .39812 .35594 .39571 Metetra
.664 .741 .907 r
.35594 .39571 .3583 .39812 .36212 .39681 .35977 .3944 Metetra
.664 .741 .907 r
.35977 .3944 .36212 .39681 .36594 .39551 .3636 .39309 Metetra
.664 .741 .907 r
.3636 .39309 .36594 .39551 .36978 .3942 .36743 .39178 Metetra
.664 .741 .907 r
.36743 .39178 .36978 .3942 .37361 .39289 .37127 .39047 Metetra
.664 .741 .907 r
.37127 .39047 .37361 .39289 .37746 .39158 .37512 .38916 Metetra
.664 .741 .907 r
.37512 .38916 .37746 .39158 .3813 .39027 .37897 .38784 Metetra
.664 .741 .907 r
.37897 .38784 .3813 .39027 .38516 .38895 .38283 .38652 Metetra
.664 .741 .907 r
.38283 .38652 .38516 .38895 .38846 .40071 .38669 .3852 Metetra
.584 .42 .625 r
.38669 .3852 .38846 .40071 .39234 .39954 .39056 .38388 Metetra
.034 .022 .51 r
.39056 .38388 .39234 .39954 .39622 .39838 .39389 .39583 Metetra
.648 .728 .907 r
.39389 .39583 .39622 .39838 .4001 .39722 .39778 .39466 Metetra
.647 .727 .907 r
.39778 .39466 .4001 .39722 .40399 .39606 .40167 .3935 Metetra
.647 .727 .907 r
.40167 .3935 .40399 .39606 .40789 .39491 .40557 .39234 Metetra
.646 .726 .907 r
.40557 .39234 .40789 .39491 .41179 .39375 .40948 .39118 Metetra
.646 .726 .907 r
.40948 .39118 .41179 .39375 .4157 .39261 .41339 .39002 Metetra
.645 .725 .907 r
.41339 .39002 .4157 .39261 .41962 .39146 .41731 .38887 Metetra
.644 .725 .907 r
.41731 .38887 .41962 .39146 .42354 .39032 .42124 .38773 Metetra
.644 .724 .907 r
.42124 .38773 .42354 .39032 .42747 .38919 .42517 .38658 Metetra
.643 .724 .907 r
.42517 .38658 .42747 .38919 .4314 .38806 .4291 .38545 Metetra
.959 .682 .467 r
.4291 .38545 .4314 .38806 .42941 .59957 .42695 .59725 Metetra
.645 .763 .934 r
.42695 .59725 .42941 .59957 .43361 .59831 .43116 .59598 Metetra
.952 .718 .547 r
.43116 .59598 .43361 .59831 .43812 .58554 .43633 .55833 Metetra
.77 .536 .58 r
.43633 .55833 .43812 .58554 .44321 .54776 .44117 .53089 Metetra
.779 .558 .6 r
.44117 .53089 .44321 .54776 .44787 .52517 .44572 .51293 Metetra
.781 .575 .621 r
.44572 .51293 .44787 .52517 .45233 .50964 .45012 .49993 Metetra
.779 .589 .642 r
.45012 .49993 .45233 .50964 .45668 .49807 .45444 .48991 Metetra
.775 .6 .662 r
.45444 .48991 .45668 .49807 .46097 .48898 .45871 .48185 Metetra
.77 .61 .681 r
.45871 .48185 .46097 .48898 .4652 .48157 .46293 .47516 Metetra
.764 .619 .699 r
.46293 .47516 .4652 .48157 .46941 .47536 .46714 .46947 Metetra
.757 .626 .715 r
.46714 .46947 .46941 .47536 .4736 .47005 .47132 .46455 Metetra
.749 .632 .73 r
.47132 .46455 .4736 .47005 .47778 .46543 .4755 .46024 Metetra
.741 .636 .744 r
.4755 .46024 .47778 .46543 .48195 .46136 .47966 .4564 Metetra
.733 .64 .756 r
.47966 .4564 .48195 .46136 .48611 .45775 .48383 .45298 Metetra
.724 .642 .767 r
.48383 .45298 .48611 .45775 .49027 .45451 .48798 .44989 Metetra
.715 .644 .777 r
.48798 .44989 .49027 .45451 .49442 .45161 .49214 .4471 Metetra
.706 .645 .786 r
.49214 .4471 .49442 .45161 .49858 .44898 .4963 .44456 Metetra
.697 .644 .794 r
.4963 .44456 .49858 .44898 .50274 .4466 .50046 .44226 Metetra
.687 .644 .801 r
.50046 .44226 .50274 .4466 .5069 .44446 .50462 .44016 Metetra
.678 .642 .807 r
.50462 .44016 .5069 .44446 .51106 .44253 .50879 .43827 Metetra
.667 .639 .812 r
.50879 .43827 .51106 .44253 .51523 .44079 .51296 .43655 Metetra
.657 .636 .817 r
.51296 .43655 .51523 .44079 .5194 .43925 .51713 .43502 Metetra
.646 .631 .821 r
.51713 .43502 .5194 .43925 .52358 .4379 .52131 .43366 Metetra
.634 .626 .825 r
.52131 .43366 .52358 .4379 .52776 .43673 .5255 .43248 Metetra
.621 .619 .827 r
.5255 .43248 .52776 .43673 .53196 .43576 .52969 .43148 Metetra
.607 .611 .829 r
.52969 .43148 .53196 .43576 .53616 .43499 .53389 .43067 Metetra
.592 .602 .831 r
.53389 .43067 .53616 .43499 .54037 .43444 .5381 .43005 Metetra
.575 .59 .831 r
.5381 .43005 .54037 .43444 .54459 .43411 .54232 .42964 Metetra
.556 .577 .83 r
.54232 .42964 .54459 .43411 .54882 .43404 .54655 .42947 Metetra
.534 .561 .829 r
.54655 .42947 .54882 .43404 .55306 .43426 .5508 .42956 Metetra
.509 .542 .825 r
.5508 .42956 .55306 .43426 .55731 .4348 .55505 .42995 Metetra
.481 .519 .82 r
.55505 .42995 .55731 .4348 .56159 .43573 .55932 .43068 Metetra
.446 .491 .812 r
.55932 .43068 .56159 .43573 .56588 .43712 .56361 .43182 Metetra
.406 .457 .8 r
.56361 .43182 .56588 .43712 .57019 .43907 .56791 .43346 Metetra
.356 .414 .784 r
.56791 .43346 .57019 .43907 .57453 .44172 .57224 .43571 Metetra
.296 .362 .761 r
.57224 .43571 .57453 .44172 .5789 .44529 .5766 .43873 Metetra
.223 .297 .73 r
.5766 .43873 .5789 .44529 .58331 .45007 .581 .44278 Metetra
.133 .217 .685 r
.581 .44278 .58331 .45007 .58778 .45656 .58544 .44822 Metetra
.025 .118 .625 r
.58544 .44822 .58778 .45656 .59233 .46558 .58994 .45565 Metetra
0 .001 .544 r
.58994 .45565 .59233 .46558 .597 .47862 .59455 .46612 Metetra
0 0 .442 r
.59455 .46612 .597 .47862 .60188 .49886 .5993 .48164 Metetra
0 0 .319 r
.5993 .48164 .60188 .49886 .6072 .53456 .60433 .50681 Metetra
0 0 .352 r
.60433 .50681 .6072 .53456 .61198 .54491 .60971 .54242 Metetra
.645 .763 .934 r
.60971 .54242 .61198 .54491 .61648 .54356 .61421 .54107 Metetra
.973 .692 .434 r
.61421 .54107 .61648 .54356 .61481 .32599 .61268 .32321 Metetra
.68 .736 .893 r
.61268 .32321 .61481 .32599 .61902 .32436 .6169 .32157 Metetra
.679 .736 .893 r
.6169 .32157 .61902 .32436 .62324 .32273 .62112 .31994 Metetra
.679 .736 .894 r
.62112 .31994 .62324 .32273 .62746 .3211 .62534 .31832 Metetra
.678 .736 .894 r
.62534 .31832 .62746 .3211 .63169 .31948 .62958 .3167 Metetra
.678 .737 .895 r
.62958 .3167 .63169 .31948 .63592 .31787 .63382 .31508 Metetra
.677 .737 .895 r
.63382 .31508 .63592 .31787 .64017 .31625 .63806 .31346 Metetra
.677 .737 .896 r
.63806 .31346 .64017 .31625 .64441 .31464 .64232 .31185 Metetra
.677 .737 .896 r
.64232 .31185 .64441 .31464 .64867 .31303 .64657 .31024 Metetra
.676 .737 .896 r
.64657 .31024 .64867 .31303 .65293 .31143 .65084 .30864 Metetra
.952 .757 .602 r
.65084 .30864 .65293 .31143 .65719 .30982 .65455 .29365 Metetra
.584 .419 .624 r
.65455 .29365 .65719 .30982 .66147 .30822 .65882 .29219 Metetra
.584 .42 .625 r
.65882 .29219 .66147 .30822 .66515 .29342 .66309 .29073 Metetra
.664 .741 .907 r
.66309 .29073 .66515 .29342 .66942 .29197 .66736 .28927 Metetra
.664 .741 .907 r
.66736 .28927 .66942 .29197 .6737 .29051 .67165 .2878 Metetra
.664 .741 .907 r
.67165 .2878 .6737 .29051 .67799 .28904 .67594 .28634 Metetra
.664 .741 .907 r
.67594 .28634 .67799 .28904 .68228 .28758 .68024 .28487 Metetra
.664 .741 .907 r
.68024 .28487 .68228 .28758 .68658 .28611 .68454 .2834 Metetra
.664 .741 .907 r
.68454 .2834 .68658 .28611 .69089 .28464 .68885 .28193 Metetra
.664 .741 .907 r
.68885 .28193 .69089 .28464 .6952 .28317 .69317 .28045 Metetra
.664 .741 .907 r
.69317 .28045 .6952 .28317 .69952 .2817 .69749 .27897 Metetra
.664 .741 .907 r
.69749 .27897 .69952 .2817 .70384 .28022 .70182 .27749 Metetra
.664 .741 .907 r
.70182 .27749 .70384 .28022 .70817 .27875 .70616 .27601 Metetra
.664 .741 .907 r
.70616 .27601 .70817 .27875 .71251 .27727 .7105 .27453 Metetra
.664 .741 .907 r
.7105 .27453 .71251 .27727 .71686 .27578 .71485 .27304 Metetra
.664 .741 .907 r
.71485 .27304 .71686 .27578 .72121 .2743 .71921 .27155 Metetra
.664 .741 .907 r
.71921 .27155 .72121 .2743 .72557 .27281 .72357 .27006 Metetra
.664 .741 .907 r
.72357 .27006 .72557 .27281 .72993 .27132 .72794 .26857 Metetra
.664 .741 .907 r
.72794 .26857 .72993 .27132 .7343 .26983 .73232 .26707 Metetra
.664 .741 .907 r
.73232 .26707 .7343 .26983 .73868 .26834 .7367 .26557 Metetra
.664 .741 .907 r
.7367 .26557 .73868 .26834 .74307 .26684 .74109 .26407 Metetra
.664 .741 .907 r
.74109 .26407 .74307 .26684 .74746 .26534 .74548 .26257 Metetra
.664 .741 .907 r
.74548 .26257 .74746 .26534 .75186 .26384 .74989 .26106 Metetra
.664 .741 .907 r
.74989 .26106 .75186 .26384 .75626 .26234 .7543 .25956 Metetra
.664 .741 .907 r
.7543 .25956 .75626 .26234 .76068 .26083 .75872 .25805 Metetra
.664 .741 .907 r
.75872 .25805 .76068 .26083 .7651 .25932 .76314 .25653 Metetra
.664 .741 .907 r
.76314 .25653 .7651 .25932 .76952 .25781 .76757 .25502 Metetra
.664 .741 .907 r
.76757 .25502 .76952 .25781 .77395 .2563 .77201 .2535 Metetra
.664 .741 .907 r
.77201 .2535 .77395 .2563 .77839 .25479 .77645 .25198 Metetra
.664 .741 .907 r
.77645 .25198 .77839 .25479 .78284 .25327 .7809 .25046 Metetra
.664 .741 .907 r
.7809 .25046 .78284 .25327 .78729 .25175 .78536 .24894 Metetra
.664 .741 .907 r
.78536 .24894 .78729 .25175 .79175 .25023 .78983 .24741 Metetra
.664 .741 .907 r
.78983 .24741 .79175 .25023 .79622 .24871 .7943 .24589 Metetra
.664 .741 .907 r
.7943 .24589 .79622 .24871 .8007 .24718 .79878 .24435 Metetra
.664 .741 .907 r
.79878 .24435 .8007 .24718 .80518 .24565 .80326 .24282 Metetra
.664 .741 .907 r
.80326 .24282 .80518 .24565 .80966 .24412 .80776 .24129 Metetra
.664 .741 .907 r
.80776 .24129 .80966 .24412 .81416 .24258 .81226 .23975 Metetra
.664 .741 .907 r
.81226 .23975 .81416 .24258 .81866 .24105 .81676 .23821 Metetra
.664 .741 .907 r
.81676 .23821 .81866 .24105 .82317 .23951 .82128 .23666 Metetra
.664 .741 .907 r
.82128 .23666 .82317 .23951 .82769 .23797 .8258 .23512 Metetra
.664 .741 .907 r
.8258 .23512 .82769 .23797 .83221 .23643 .83033 .23357 Metetra
.664 .741 .907 r
.83033 .23357 .83221 .23643 .83674 .23488 .83486 .23202 Metetra
.664 .741 .907 r
.83486 .23202 .83674 .23488 .84128 .23333 .8394 .23047 Metetra
.664 .741 .907 r
.23029 .43551 .23275 .43781 .2364 .43656 .23394 .43426 Metetra
.664 .741 .907 r
.23394 .43426 .2364 .43656 .24006 .43532 .2376 .43301 Metetra
.664 .741 .907 r
.2376 .43301 .24006 .43532 .24372 .43407 .24126 .43175 Metetra
.664 .741 .907 r
.24126 .43175 .24372 .43407 .24738 .43281 .24493 .4305 Metetra
.664 .741 .907 r
.24493 .4305 .24738 .43281 .25105 .43156 .2486 .42924 Metetra
.664 .741 .907 r
.2486 .42924 .25105 .43156 .25473 .4303 .25228 .42798 Metetra
.664 .741 .907 r
.25228 .42798 .25473 .4303 .25841 .42904 .25596 .42672 Metetra
.664 .741 .907 r
.25596 .42672 .25841 .42904 .26209 .42778 .25965 .42545 Metetra
.664 .741 .907 r
.25965 .42545 .26209 .42778 .26578 .42652 .26334 .42419 Metetra
.664 .741 .907 r
.26334 .42419 .26578 .42652 .26948 .42526 .26704 .42292 Metetra
.664 .741 .907 r
.26704 .42292 .26948 .42526 .27318 .424 .27075 .42166 Metetra
.664 .741 .907 r
.27075 .42166 .27318 .424 .27689 .42273 .27446 .42039 Metetra
.664 .741 .907 r
.27446 .42039 .27689 .42273 .2806 .42146 .27817 .41911 Metetra
.664 .741 .907 r
.27817 .41911 .2806 .42146 .28431 .42019 .28189 .41784 Metetra
.664 .741 .907 r
.28189 .41784 .28431 .42019 .28804 .41892 .28561 .41656 Metetra
.664 .741 .907 r
.28561 .41656 .28804 .41892 .29176 .41764 .28935 .41529 Metetra
.664 .741 .907 r
.28935 .41529 .29176 .41764 .2955 .41637 .29308 .41401 Metetra
.664 .741 .907 r
.29308 .41401 .2955 .41637 .29923 .41509 .29682 .41273 Metetra
.664 .741 .907 r
.29682 .41273 .29923 .41509 .30298 .41381 .30057 .41145 Metetra
.664 .741 .907 r
.30057 .41145 .30298 .41381 .30672 .41253 .30432 .41016 Metetra
.664 .741 .907 r
.30432 .41016 .30672 .41253 .31048 .41125 .30808 .40887 Metetra
.664 .741 .907 r
.30808 .40887 .31048 .41125 .31424 .40996 .31184 .40759 Metetra
.664 .741 .907 r
.31184 .40759 .31424 .40996 .318 .40868 .31561 .4063 Metetra
.664 .741 .907 r
.31561 .4063 .318 .40868 .32177 .40739 .31938 .405 Metetra
.664 .741 .907 r
.31938 .405 .32177 .40739 .32555 .4061 .32316 .40371 Metetra
.664 .741 .907 r
.32316 .40371 .32555 .4061 .32933 .40481 .32694 .40242 Metetra
.664 .741 .907 r
.32694 .40242 .32933 .40481 .33311 .40351 .33073 .40112 Metetra
.664 .741 .907 r
.33073 .40112 .33311 .40351 .3369 .40222 .33452 .39982 Metetra
.664 .741 .907 r
.33452 .39982 .3369 .40222 .3407 .40092 .33832 .39852 Metetra
.664 .741 .907 r
.33832 .39852 .3407 .40092 .3445 .39962 .34213 .39721 Metetra
.664 .741 .907 r
.34213 .39721 .3445 .39962 .34831 .39832 .34594 .39591 Metetra
.664 .741 .907 r
.34594 .39591 .34831 .39832 .35212 .39701 .34976 .3946 Metetra
.664 .741 .907 r
.34976 .3946 .35212 .39701 .35594 .39571 .35358 .39329 Metetra
.664 .741 .907 r
.35358 .39329 .35594 .39571 .35977 .3944 .35741 .39198 Metetra
.664 .741 .907 r
.35741 .39198 .35977 .3944 .3636 .39309 .36124 .39067 Metetra
.664 .741 .907 r
.36124 .39067 .3636 .39309 .36743 .39178 .36508 .38936 Metetra
.664 .741 .907 r
.36508 .38936 .36743 .39178 .37127 .39047 .36892 .38804 Metetra
.664 .741 .907 r
.36892 .38804 .37127 .39047 .37512 .38916 .37277 .38672 Metetra
.664 .741 .907 r
.37277 .38672 .37512 .38916 .37897 .38784 .37663 .3854 Metetra
.664 .741 .907 r
.37663 .3854 .37897 .38784 .38283 .38652 .38049 .38408 Metetra
.664 .741 .907 r
.38049 .38408 .38283 .38652 .38669 .3852 .38435 .38276 Metetra
.664 .741 .907 r
.38435 .38276 .38669 .3852 .39056 .38388 .38822 .38143 Metetra
.664 .741 .907 r
.38822 .38143 .39056 .38388 .39389 .39583 .3921 .3801 Metetra
.034 .022 .509 r
.3921 .3801 .39389 .39583 .39778 .39466 .39545 .3921 Metetra
.647 .727 .907 r
.39545 .3921 .39778 .39466 .40167 .3935 .39935 .39093 Metetra
.647 .727 .907 r
.39935 .39093 .40167 .3935 .40557 .39234 .40325 .38976 Metetra
.646 .727 .907 r
.40325 .38976 .40557 .39234 .40948 .39118 .40716 .3886 Metetra
.646 .726 .907 r
.40716 .3886 .40948 .39118 .41339 .39002 .41108 .38744 Metetra
.645 .726 .907 r
.41108 .38744 .41339 .39002 .41731 .38887 .415 .38628 Metetra
.645 .725 .907 r
.415 .38628 .41731 .38887 .42124 .38773 .41893 .38512 Metetra
.644 .725 .907 r
.41893 .38512 .42124 .38773 .42517 .38658 .42286 .38397 Metetra
.959 .682 .468 r
.42286 .38397 .42517 .38658 .4291 .38545 .42027 .59618 Metetra
.539 .314 .522 r
.42027 .59618 .4291 .38545 .42695 .59725 .42448 .59491 Metetra
.945 .735 .589 r
.42448 .59491 .42695 .59725 .43116 .59598 .4293 .57242 Metetra
.812 .573 .576 r
.4293 .57242 .43116 .59598 .43633 .55833 .43438 .53812 Metetra
.775 .549 .592 r
.43438 .53812 .43633 .55833 .44117 .53089 .43905 .51702 Metetra
.78 .567 .612 r
.43905 .51702 .44117 .53089 .44572 .51293 .44353 .50228 Metetra
.78 .583 .633 r
.44353 .50228 .44572 .51293 .45012 .49993 .44789 .49118 Metetra
.777 .595 .654 r
.44789 .49118 .45012 .49993 .45444 .48991 .45219 .48238 Metetra
.773 .606 .673 r
.45219 .48238 .45444 .48991 .45871 .48185 .45644 .47516 Metetra
.767 .616 .691 r
.45644 .47516 .45871 .48185 .46293 .47516 .46066 .46907 Metetra
.76 .624 .708 r
.46066 .46907 .46293 .47516 .46714 .46947 .46485 .46383 Metetra
.753 .63 .724 r
.46485 .46383 .46714 .46947 .47132 .46455 .46904 .45925 Metetra
.745 .635 .738 r
.46904 .45925 .47132 .46455 .4755 .46024 .47321 .4552 Metetra
.738 .64 .751 r
.47321 .4552 .4755 .46024 .47966 .4564 .47738 .45157 Metetra
.729 .643 .762 r
.47738 .45157 .47966 .4564 .48383 .45298 .48154 .44831 Metetra
.721 .645 .773 r
.48154 .44831 .48383 .45298 .48798 .44989 .4857 .44535 Metetra
.712 .646 .782 r
.4857 .44535 .48798 .44989 .49214 .4471 .48986 .44266 Metetra
.704 .647 .79 r
.48986 .44266 .49214 .4471 .4963 .44456 .49402 .44021 Metetra
.695 .647 .798 r
.49402 .44021 .4963 .44456 .50046 .44226 .49818 .43797 Metetra
.686 .646 .804 r
.49818 .43797 .50046 .44226 .50462 .44016 .50234 .43592 Metetra
.677 .644 .81 r
.50234 .43592 .50462 .44016 .50879 .43827 .50651 .43406 Metetra
.667 .642 .815 r
.50651 .43406 .50879 .43827 .51296 .43655 .51068 .43237 Metetra
.657 .638 .82 r
.51068 .43237 .51296 .43655 .51713 .43502 .51486 .43084 Metetra
.646 .634 .824 r
.51486 .43084 .51713 .43502 .52131 .43366 .51904 .42948 Metetra
.635 .629 .827 r
.51904 .42948 .52131 .43366 .5255 .43248 .52323 .42828 Metetra
.623 .623 .83 r
.52323 .42828 .5255 .43248 .52969 .43148 .52742 .42725 Metetra
.61 .616 .832 r
.52742 .42725 .52969 .43148 .53389 .43067 .53163 .4264 Metetra
.596 .607 .833 r
.53163 .4264 .53389 .43067 .5381 .43005 .53584 .42572 Metetra
.58 .597 .834 r
.53584 .42572 .5381 .43005 .54232 .42964 .54006 .42525 Metetra
.563 .584 .833 r
.54006 .42525 .54232 .42964 .54655 .42947 .54429 .42498 Metetra
.543 .57 .832 r
.54429 .42498 .54655 .42947 .5508 .42956 .54853 .42496 Metetra
.52 .552 .829 r
.54853 .42496 .5508 .42956 .55505 .42995 .55279 .42521 Metetra
.494 .532 .824 r
.55279 .42521 .55505 .42995 .55932 .43068 .55705 .42576 Metetra
.463 .507 .818 r
.55705 .42576 .55932 .43068 .56361 .43182 .56134 .42669 Metetra
.427 .476 .808 r
.56134 .42669 .56361 .43182 .56791 .43346 .56564 .42805 Metetra
.383 .439 .795 r
.56564 .42805 .56791 .43346 .57224 .43571 .56996 .42994 Metetra
.33 .393 .776 r
.56996 .42994 .57224 .43571 .5766 .43873 .57431 .43251 Metetra
.265 .336 .749 r
.57431 .43251 .5766 .43873 .581 .44278 .57869 .43594 Metetra
.186 .265 .712 r
.57869 .43594 .581 .44278 .58544 .44822 .58311 .44052 Metetra
.09 .178 .662 r
.58311 .44052 .58544 .44822 .58994 .45565 .58759 .4467 Metetra
0 .072 .594 r
.58759 .4467 .58994 .45565 .59455 .46612 .59213 .45523 Metetra
0 0 .505 r
.59213 .45523 .59455 .46612 .5993 .48164 .5968 .46746 Metetra
0 0 .395 r
.5968 .46746 .5993 .48164 .60433 .50681 .60166 .48618 Metetra
0 0 .265 r
.60166 .48618 .60433 .50681 .60971 .54242 .6069 .51834 Metetra
.072 .036 .506 r
.6069 .51834 .60971 .54242 .61421 .54107 .61194 .53857 Metetra
.645 .763 .934 r
.61194 .53857 .61421 .54107 .61268 .32321 .61646 .53721 Metetra
0 0 .365 r
.61646 .53721 .61268 .32321 .6169 .32157 .61477 .31878 Metetra
.679 .736 .894 r
.61477 .31878 .6169 .32157 .62112 .31994 .61899 .31715 Metetra
.679 .736 .894 r
.61899 .31715 .62112 .31994 .62534 .31832 .62322 .31553 Metetra
.678 .736 .895 r
.62322 .31553 .62534 .31832 .62958 .3167 .62746 .3139 Metetra
.678 .737 .895 r
.62746 .3139 .62958 .3167 .63382 .31508 .63171 .31229 Metetra
.677 .737 .895 r
.63171 .31229 .63382 .31508 .63806 .31346 .63596 .31067 Metetra
.677 .737 .896 r
.63596 .31067 .63806 .31346 .64232 .31185 .64021 .30906 Metetra
.676 .737 .896 r
.64021 .30906 .64232 .31185 .64657 .31024 .64448 .30745 Metetra
.952 .756 .603 r
.64448 .30745 .64657 .31024 .65084 .30864 .64821 .29242 Metetra
.583 .418 .624 r
.64821 .29242 .65084 .30864 .65455 .29365 .65248 .29096 Metetra
.664 .741 .907 r
.65248 .29096 .65455 .29365 .65882 .29219 .65674 .28949 Metetra
.664 .741 .907 r
.65674 .28949 .65882 .29219 .66309 .29073 .66102 .28803 Metetra
.664 .741 .907 r
.66102 .28803 .66309 .29073 .66736 .28927 .6653 .28656 Metetra
.664 .741 .907 r
.6653 .28656 .66736 .28927 .67165 .2878 .66959 .2851 Metetra
.664 .741 .907 r
.66959 .2851 .67165 .2878 .67594 .28634 .67388 .28363 Metetra
.664 .741 .907 r
.67388 .28363 .67594 .28634 .68024 .28487 .67819 .28215 Metetra
.664 .741 .907 r
.67819 .28215 .68024 .28487 .68454 .2834 .68249 .28068 Metetra
.664 .741 .907 r
.68249 .28068 .68454 .2834 .68885 .28193 .68681 .2792 Metetra
.664 .741 .907 r
.68681 .2792 .68885 .28193 .69317 .28045 .69113 .27772 Metetra
.664 .741 .907 r
.69113 .27772 .69317 .28045 .69749 .27897 .69546 .27624 Metetra
.664 .741 .907 r
.69546 .27624 .69749 .27897 .70182 .27749 .69979 .27475 Metetra
.664 .741 .907 r
.69979 .27475 .70182 .27749 .70616 .27601 .70413 .27327 Metetra
.664 .741 .907 r
.70413 .27327 .70616 .27601 .7105 .27453 .70848 .27178 Metetra
.664 .741 .907 r
.70848 .27178 .7105 .27453 .71485 .27304 .71284 .27029 Metetra
.664 .741 .907 r
.71284 .27029 .71485 .27304 .71921 .27155 .7172 .2688 Metetra
.664 .741 .907 r
.7172 .2688 .71921 .27155 .72357 .27006 .72156 .2673 Metetra
.664 .741 .907 r
.72156 .2673 .72357 .27006 .72794 .26857 .72594 .2658 Metetra
.664 .741 .907 r
.72594 .2658 .72794 .26857 .73232 .26707 .73032 .2643 Metetra
.664 .741 .907 r
.73032 .2643 .73232 .26707 .7367 .26557 .73471 .2628 Metetra
.664 .741 .907 r
.73471 .2628 .7367 .26557 .74109 .26407 .7391 .2613 Metetra
.664 .741 .907 r
.7391 .2613 .74109 .26407 .74548 .26257 .7435 .25979 Metetra
.664 .741 .907 r
.7435 .25979 .74548 .26257 .74989 .26106 .74791 .25828 Metetra
.664 .741 .907 r
.74791 .25828 .74989 .26106 .7543 .25956 .75233 .25677 Metetra
.664 .741 .907 r
.75233 .25677 .7543 .25956 .75872 .25805 .75675 .25525 Metetra
.664 .741 .907 r
.75675 .25525 .75872 .25805 .76314 .25653 .76118 .25374 Metetra
.664 .741 .907 r
.76118 .25374 .76314 .25653 .76757 .25502 .76561 .25222 Metetra
.664 .741 .907 r
.76561 .25222 .76757 .25502 .77201 .2535 .77006 .2507 Metetra
.664 .741 .907 r
.77006 .2507 .77201 .2535 .77645 .25198 .7745 .24917 Metetra
.664 .741 .907 r
.7745 .24917 .77645 .25198 .7809 .25046 .77896 .24765 Metetra
.664 .741 .907 r
.77896 .24765 .7809 .25046 .78536 .24894 .78342 .24612 Metetra
.664 .741 .907 r
.78342 .24612 .78536 .24894 .78983 .24741 .78789 .24459 Metetra
.664 .741 .907 r
.78789 .24459 .78983 .24741 .7943 .24589 .79237 .24306 Metetra
.664 .741 .907 r
.79237 .24306 .7943 .24589 .79878 .24435 .79685 .24152 Metetra
.664 .741 .907 r
.79685 .24152 .79878 .24435 .80326 .24282 .80135 .23998 Metetra
.664 .741 .907 r
.80135 .23998 .80326 .24282 .80776 .24129 .80584 .23844 Metetra
.664 .741 .907 r
.80584 .23844 .80776 .24129 .81226 .23975 .81035 .2369 Metetra
.664 .741 .907 r
.81035 .2369 .81226 .23975 .81676 .23821 .81486 .23536 Metetra
.664 .741 .907 r
.81486 .23536 .81676 .23821 .82128 .23666 .81938 .23381 Metetra
.664 .741 .907 r
.81938 .23381 .82128 .23666 .8258 .23512 .82391 .23226 Metetra
.664 .741 .907 r
.82391 .23226 .8258 .23512 .83033 .23357 .82844 .23071 Metetra
.664 .741 .907 r
.82844 .23071 .83033 .23357 .83486 .23202 .83298 .22915 Metetra
.664 .741 .907 r
.83298 .22915 .83486 .23202 .8394 .23047 .83753 .2276 Metetra
.664 .741 .907 r
.22781 .4332 .23029 .43551 .23394 .43426 .23147 .43194 Metetra
.664 .741 .907 r
.23147 .43194 .23394 .43426 .2376 .43301 .23513 .43069 Metetra
.664 .741 .907 r
.23513 .43069 .2376 .43301 .24126 .43175 .2388 .42943 Metetra
.664 .741 .907 r
.2388 .42943 .24126 .43175 .24493 .4305 .24247 .42817 Metetra
.664 .741 .907 r
.24247 .42817 .24493 .4305 .2486 .42924 .24614 .42691 Metetra
.664 .741 .907 r
.24614 .42691 .2486 .42924 .25228 .42798 .24982 .42565 Metetra
.664 .741 .907 r
.24982 .42565 .25228 .42798 .25596 .42672 .25351 .42438 Metetra
.664 .741 .907 r
.25351 .42438 .25596 .42672 .25965 .42545 .2572 .42312 Metetra
.664 .741 .907 r
.2572 .42312 .25965 .42545 .26334 .42419 .2609 .42185 Metetra
.664 .741 .907 r
.2609 .42185 .26334 .42419 .26704 .42292 .2646 .42058 Metetra
.664 .741 .907 r
.2646 .42058 .26704 .42292 .27075 .42166 .26831 .41931 Metetra
.664 .741 .907 r
.26831 .41931 .27075 .42166 .27446 .42039 .27202 .41804 Metetra
.664 .741 .907 r
.27202 .41804 .27446 .42039 .27817 .41911 .27574 .41676 Metetra
.664 .741 .907 r
.27574 .41676 .27817 .41911 .28189 .41784 .27946 .41548 Metetra
.664 .741 .907 r
.27946 .41548 .28189 .41784 .28561 .41656 .28319 .41421 Metetra
.664 .741 .907 r
.28319 .41421 .28561 .41656 .28935 .41529 .28692 .41292 Metetra
.664 .741 .907 r
.28692 .41292 .28935 .41529 .29308 .41401 .29066 .41164 Metetra
.664 .741 .907 r
.29066 .41164 .29308 .41401 .29682 .41273 .2944 .41036 Metetra
.664 .741 .907 r
.2944 .41036 .29682 .41273 .30057 .41145 .29815 .40907 Metetra
.664 .741 .907 r
.29815 .40907 .30057 .41145 .30432 .41016 .30191 .40778 Metetra
.664 .741 .907 r
.30191 .40778 .30432 .41016 .30808 .40887 .30567 .40649 Metetra
.664 .741 .907 r
.30567 .40649 .30808 .40887 .31184 .40759 .30943 .4052 Metetra
.664 .741 .907 r
.30943 .4052 .31184 .40759 .31561 .4063 .3132 .40391 Metetra
.664 .741 .907 r
.3132 .40391 .31561 .4063 .31938 .405 .31698 .40261 Metetra
.664 .741 .907 r
.31698 .40261 .31938 .405 .32316 .40371 .32076 .40132 Metetra
.664 .741 .907 r
.32076 .40132 .32316 .40371 .32694 .40242 .32455 .40002 Metetra
.664 .741 .907 r
.32455 .40002 .32694 .40242 .33073 .40112 .32834 .39872 Metetra
.664 .741 .907 r
.32834 .39872 .33073 .40112 .33452 .39982 .33214 .39742 Metetra
.664 .741 .907 r
.33214 .39742 .33452 .39982 .33832 .39852 .33594 .39611 Metetra
.664 .741 .907 r
.33594 .39611 .33832 .39852 .34213 .39721 .33975 .3948 Metetra
.664 .741 .907 r
.33975 .3948 .34213 .39721 .34594 .39591 .34357 .3935 Metetra
.664 .741 .907 r
.34357 .3935 .34594 .39591 .34976 .3946 .34739 .39219 Metetra
.664 .741 .907 r
.34739 .39219 .34976 .3946 .35358 .39329 .35121 .39087 Metetra
.664 .741 .907 r
.35121 .39087 .35358 .39329 .35741 .39198 .35504 .38956 Metetra
.664 .741 .907 r
.35504 .38956 .35741 .39198 .36124 .39067 .35888 .38824 Metetra
.664 .741 .907 r
.35888 .38824 .36124 .39067 .36508 .38936 .36272 .38693 Metetra
.664 .741 .907 r
.36272 .38693 .36508 .38936 .36892 .38804 .36657 .38561 Metetra
.664 .741 .907 r
.36657 .38561 .36892 .38804 .37277 .38672 .37042 .38429 Metetra
.664 .741 .907 r
.37042 .38429 .37277 .38672 .37663 .3854 .37428 .38296 Metetra
.664 .741 .907 r
.37428 .38296 .37663 .3854 .38049 .38408 .37814 .38164 Metetra
.664 .741 .907 r
.37814 .38164 .38049 .38408 .38435 .38276 .38201 .38031 Metetra
.664 .741 .907 r
.38201 .38031 .38435 .38276 .38822 .38143 .38589 .37898 Metetra
.664 .741 .907 r
.38589 .37898 .38822 .38143 .3921 .3801 .38977 .37765 Metetra
.664 .741 .907 r
.38977 .37765 .3921 .3801 .39545 .3921 .39365 .37632 Metetra
.033 .021 .509 r
.39365 .37632 .39545 .3921 .39935 .39093 .39701 .38836 Metetra
.647 .727 .907 r
.39701 .38836 .39935 .39093 .40325 .38976 .40092 .38718 Metetra
.647 .727 .907 r
.40092 .38718 .40325 .38976 .40716 .3886 .40483 .38601 Metetra
.646 .726 .907 r
.40483 .38601 .40716 .3886 .41108 .38744 .40875 .38484 Metetra
.646 .726 .907 r
.40875 .38484 .41108 .38744 .415 .38628 .41268 .38368 Metetra
.645 .725 .907 r
.41268 .38368 .415 .38628 .41893 .38512 .41661 .38251 Metetra
.645 .725 .907 r
.41661 .38251 .41893 .38512 .42286 .38397 .42055 .38136 Metetra
.959 .682 .468 r
.42055 .38136 .42286 .38397 .42027 .59618 .41779 .59384 Metetra
.703 .778 .91 r
.41779 .59384 .42027 .59618 .42448 .59491 .42203 .59196 Metetra
.95 .71 .54 r
.42203 .59196 .42448 .59491 .4293 .57242 .4275 .54736 Metetra
.77 .538 .583 r
.4275 .54736 .4293 .57242 .43438 .53812 .43234 .5221 Metetra
.778 .56 .603 r
.43234 .5221 .43438 .53812 .43905 .51702 .4369 .50522 Metetra
.78 .576 .624 r
.4369 .50522 .43905 .51702 .44353 .50228 .44132 .49283 Metetra
.778 .59 .645 r
.44132 .49283 .44353 .50228 .44789 .49118 .44565 .48319 Metetra
.775 .602 .665 r
.44565 .48319 .44789 .49118 .45219 .48238 .44992 .47537 Metetra
.769 .612 .684 r
.44992 .47537 .45219 .48238 .45644 .47516 .45416 .46884 Metetra
.763 .621 .701 r
.45416 .46884 .45644 .47516 .46066 .46907 .45837 .46326 Metetra
.757 .628 .717 r
.45837 .46326 .46066 .46907 .46485 .46383 .46256 .4584 Metetra
.75 .634 .732 r
.46256 .4584 .46485 .46383 .46904 .45925 .46674 .45412 Metetra
.742 .639 .745 r
.46674 .45412 .46904 .45925 .47321 .4552 .47092 .4503 Metetra
.734 .643 .757 r
.47092 .4503 .47321 .4552 .47738 .45157 .47508 .44686 Metetra
.726 .646 .768 r
.47508 .44686 .47738 .45157 .48154 .44831 .47924 .44374 Metetra
.718 .648 .778 r
.47924 .44374 .48154 .44831 .4857 .44535 .4834 .4409 Metetra
.71 .649 .787 r
.4834 .4409 .4857 .44535 .48986 .44266 .48756 .43831 Metetra
.702 .649 .795 r
.48756 .43831 .48986 .44266 .49402 .44021 .49173 .43593 Metetra
.693 .649 .802 r
.49173 .43593 .49402 .44021 .49818 .43797 .49589 .43374 Metetra
.684 .648 .808 r
.49589 .43374 .49818 .43797 .50234 .43592 .50005 .43174 Metetra
.676 .647 .814 r
.50005 .43174 .50234 .43592 .50651 .43406 .50422 .42991 Metetra
.666 .644 .819 r
.50422 .42991 .50651 .43406 .51068 .43237 .5084 .42823 Metetra
.657 .641 .823 r
.5084 .42823 .51068 .43237 .51486 .43084 .51258 .42671 Metetra
.647 .637 .827 r
.51258 .42671 .51486 .43084 .51904 .42948 .51676 .42535 Metetra
.636 .632 .83 r
.51676 .42535 .51904 .42948 .52323 .42828 .52095 .42414 Metetra
.625 .627 .832 r
.52095 .42414 .52323 .42828 .52742 .42725 .52515 .42308 Metetra
.613 .62 .834 r
.52515 .42308 .52742 .42725 .53163 .4264 .52935 .42218 Metetra
.6 .612 .835 r
.52935 .42218 .53163 .4264 .53584 .42572 .53357 .42146 Metetra
.585 .602 .836 r
.53357 .42146 .53584 .42572 .54006 .42525 .53779 .42091 Metetra
.569 .591 .836 r
.53779 .42091 .54006 .42525 .54429 .42498 .54202 .42057 Metetra
.551 .578 .835 r
.54202 .42057 .54429 .42498 .54853 .42496 .54626 .42044 Metetra
.53 .562 .832 r
.54626 .42044 .54853 .42496 .55279 .42521 .55052 .42056 Metetra
.506 .543 .829 r
.55052 .42056 .55279 .42521 .55705 .42576 .55478 .42096 Metetra
.478 .521 .823 r
.55478 .42096 .55705 .42576 .56134 .42669 .55907 .42169 Metetra
.446 .493 .815 r
.55907 .42169 .56134 .42669 .56564 .42805 .56336 .42281 Metetra
.407 .46 .803 r
.56336 .42281 .56564 .42805 .56996 .42994 .56768 .42439 Metetra
.36 .42 .788 r
.56768 .42439 .56996 .42994 .57431 .43251 .57202 .42656 Metetra
.303 .369 .766 r
.57202 .42656 .57431 .43251 .57869 .43594 .57639 .42947 Metetra
.233 .307 .735 r
.57639 .42947 .57869 .43594 .58311 .44052 .58079 .43334 Metetra
.148 .23 .693 r
.58079 .43334 .58311 .44052 .58759 .4467 .58524 .43852 Metetra
.046 .137 .636 r
.58524 .43852 .58759 .4467 .59213 .45523 .58975 .44555 Metetra
0 .024 .561 r
.58975 .44555 .59213 .45523 .5968 .46746 .59435 .45539 Metetra
0 0 .464 r
.59435 .45539 .5968 .46746 .60166 .48618 .59909 .46981 Metetra
0 0 .347 r
.59909 .46981 .60166 .48618 .6069 .51834 .60408 .49276 Metetra
0 0 .21 r
.60408 .49276 .6069 .51834 .61194 .53857 .60965 .53544 Metetra
.589 .689 .911 r
.60965 .53544 .61194 .53857 .61646 .53721 .61418 .5347 Metetra
.974 .692 .432 r
.61418 .5347 .61646 .53721 .61477 .31878 .61263 .31598 Metetra
.679 .736 .894 r
.61263 .31598 .61477 .31878 .61899 .31715 .61686 .31435 Metetra
.678 .736 .894 r
.61686 .31435 .61899 .31715 .62322 .31553 .6211 .31273 Metetra
.678 .737 .895 r
.6211 .31273 .62322 .31553 .62746 .3139 .62534 .31111 Metetra
.677 .737 .895 r
.62534 .31111 .62746 .3139 .63171 .31229 .62959 .30949 Metetra
.677 .737 .896 r
.62959 .30949 .63171 .31229 .63596 .31067 .63384 .30787 Metetra
.677 .737 .896 r
.63384 .30787 .63596 .31067 .64021 .30906 .6381 .30626 Metetra
.951 .756 .603 r
.6381 .30626 .64021 .30906 .64448 .30745 .64187 .29118 Metetra
.583 .418 .623 r
.64187 .29118 .64448 .30745 .64821 .29242 .64613 .28972 Metetra
.664 .741 .907 r
.64613 .28972 .64821 .29242 .65248 .29096 .65039 .28826 Metetra
.664 .741 .907 r
.65039 .28826 .65248 .29096 .65674 .28949 .65467 .28679 Metetra
.664 .741 .907 r
.65467 .28679 .65674 .28949 .66102 .28803 .65895 .28532 Metetra
.664 .741 .907 r
.65895 .28532 .66102 .28803 .6653 .28656 .66323 .28385 Metetra
.664 .741 .907 r
.66323 .28385 .6653 .28656 .66959 .2851 .66753 .28238 Metetra
.664 .741 .907 r
.66753 .28238 .66959 .2851 .67388 .28363 .67182 .2809 Metetra
.664 .741 .907 r
.67182 .2809 .67388 .28363 .67819 .28215 .67613 .27943 Metetra
.664 .741 .907 r
.67613 .27943 .67819 .28215 .68249 .28068 .68044 .27795 Metetra
.664 .741 .907 r
.68044 .27795 .68249 .28068 .68681 .2792 .68476 .27647 Metetra
.664 .741 .907 r
.68476 .27647 .68681 .2792 .69113 .27772 .68909 .27498 Metetra
.664 .741 .907 r
.68909 .27498 .69113 .27772 .69546 .27624 .69342 .2735 Metetra
.664 .741 .907 r
.69342 .2735 .69546 .27624 .69979 .27475 .69776 .27201 Metetra
.664 .741 .907 r
.69776 .27201 .69979 .27475 .70413 .27327 .7021 .27052 Metetra
.664 .741 .907 r
.7021 .27052 .70413 .27327 .70848 .27178 .70646 .26903 Metetra
.664 .741 .907 r
.70646 .26903 .70848 .27178 .71284 .27029 .71082 .26753 Metetra
.664 .741 .907 r
.71082 .26753 .71284 .27029 .7172 .2688 .71518 .26603 Metetra
.664 .741 .907 r
.71518 .26603 .7172 .2688 .72156 .2673 .71955 .26453 Metetra
.664 .741 .907 r
.71955 .26453 .72156 .2673 .72594 .2658 .72393 .26303 Metetra
.664 .741 .907 r
.72393 .26303 .72594 .2658 .73032 .2643 .72832 .26153 Metetra
.664 .741 .907 r
.72832 .26153 .73032 .2643 .73471 .2628 .73271 .26002 Metetra
.664 .741 .907 r
.73271 .26002 .73471 .2628 .7391 .2613 .73711 .25851 Metetra
.664 .741 .907 r
.73711 .25851 .7391 .2613 .7435 .25979 .74152 .257 Metetra
.664 .741 .907 r
.74152 .257 .7435 .25979 .74791 .25828 .74593 .25549 Metetra
.664 .741 .907 r
.74593 .25549 .74791 .25828 .75233 .25677 .75035 .25397 Metetra
.664 .741 .907 r
.75035 .25397 .75233 .25677 .75675 .25525 .75478 .25245 Metetra
.664 .741 .907 r
.75478 .25245 .75675 .25525 .76118 .25374 .75921 .25093 Metetra
.664 .741 .907 r
.75921 .25093 .76118 .25374 .76561 .25222 .76365 .24941 Metetra
.664 .741 .907 r
.76365 .24941 .76561 .25222 .77006 .2507 .7681 .24788 Metetra
.664 .741 .907 r
.7681 .24788 .77006 .2507 .7745 .24917 .77255 .24636 Metetra
.664 .741 .907 r
.77255 .24636 .7745 .24917 .77896 .24765 .77701 .24483 Metetra
.664 .741 .907 r
.77701 .24483 .77896 .24765 .78342 .24612 .78148 .24329 Metetra
.664 .741 .907 r
.78148 .24329 .78342 .24612 .78789 .24459 .78596 .24176 Metetra
.664 .741 .907 r
.78596 .24176 .78789 .24459 .79237 .24306 .79044 .24022 Metetra
.664 .741 .907 r
.79044 .24022 .79237 .24306 .79685 .24152 .79493 .23868 Metetra
.664 .741 .907 r
.79493 .23868 .79685 .24152 .80135 .23998 .79942 .23714 Metetra
.664 .741 .907 r
.79942 .23714 .80135 .23998 .80584 .23844 .80393 .23559 Metetra
.664 .741 .907 r
.80393 .23559 .80584 .23844 .81035 .2369 .80843 .23405 Metetra
.664 .741 .907 r
.80843 .23405 .81035 .2369 .81486 .23536 .81295 .2325 Metetra
.664 .741 .907 r
.81295 .2325 .81486 .23536 .81938 .23381 .81748 .23095 Metetra
.664 .741 .907 r
.81748 .23095 .81938 .23381 .82391 .23226 .82201 .22939 Metetra
.664 .741 .907 r
.82201 .22939 .82391 .23226 .82844 .23071 .82655 .22784 Metetra
.664 .741 .907 r
.82655 .22784 .82844 .23071 .83298 .22915 .83109 .22628 Metetra
.664 .741 .907 r
.83109 .22628 .83298 .22915 .83753 .2276 .83564 .22472 Metetra
.664 .741 .907 r
.22533 .43088 .22781 .4332 .23147 .43194 .22899 .42963 Metetra
.664 .741 .907 r
.22899 .42963 .23147 .43194 .23513 .43069 .23266 .42837 Metetra
.664 .741 .907 r
.23266 .42837 .23513 .43069 .2388 .42943 .23633 .42711 Metetra
.664 .741 .907 r
.23633 .42711 .2388 .42943 .24247 .42817 .24 .42584 Metetra
.664 .741 .907 r
.24 .42584 .24247 .42817 .24614 .42691 .24368 .42458 Metetra
.664 .741 .907 r
.24368 .42458 .24614 .42691 .24982 .42565 .24736 .42331 Metetra
.664 .741 .907 r
.24736 .42331 .24982 .42565 .25351 .42438 .25105 .42205 Metetra
.664 .741 .907 r
.25105 .42205 .25351 .42438 .2572 .42312 .25475 .42078 Metetra
.664 .741 .907 r
.25475 .42078 .2572 .42312 .2609 .42185 .25845 .41951 Metetra
.664 .741 .907 r
.25845 .41951 .2609 .42185 .2646 .42058 .26215 .41823 Metetra
.664 .741 .907 r
.26215 .41823 .2646 .42058 .26831 .41931 .26586 .41696 Metetra
.664 .741 .907 r
.26586 .41696 .26831 .41931 .27202 .41804 .26958 .41568 Metetra
.664 .741 .907 r
.26958 .41568 .27202 .41804 .27574 .41676 .2733 .4144 Metetra
.664 .741 .907 r
.2733 .4144 .27574 .41676 .27946 .41548 .27702 .41312 Metetra
.664 .741 .907 r
.27702 .41312 .27946 .41548 .28319 .41421 .28075 .41184 Metetra
.664 .741 .907 r
.28075 .41184 .28319 .41421 .28692 .41292 .28449 .41056 Metetra
.664 .741 .907 r
.28449 .41056 .28692 .41292 .29066 .41164 .28823 .40927 Metetra
.664 .741 .907 r
.28823 .40927 .29066 .41164 .2944 .41036 .29198 .40798 Metetra
.664 .741 .907 r
.29198 .40798 .2944 .41036 .29815 .40907 .29573 .40669 Metetra
.664 .741 .907 r
.29573 .40669 .29815 .40907 .30191 .40778 .29949 .4054 Metetra
.664 .741 .907 r
.29949 .4054 .30191 .40778 .30567 .40649 .30325 .40411 Metetra
.664 .741 .907 r
.30325 .40411 .30567 .40649 .30943 .4052 .30702 .40281 Metetra
.664 .741 .907 r
.30702 .40281 .30943 .4052 .3132 .40391 .3108 .40152 Metetra
.664 .741 .907 r
.3108 .40152 .3132 .40391 .31698 .40261 .31458 .40022 Metetra
.664 .741 .907 r
.31458 .40022 .31698 .40261 .32076 .40132 .31836 .39892 Metetra
.664 .741 .907 r
.31836 .39892 .32076 .40132 .32455 .40002 .32215 .39762 Metetra
.664 .741 .907 r
.32215 .39762 .32455 .40002 .32834 .39872 .32595 .39631 Metetra
.664 .741 .907 r
.32595 .39631 .32834 .39872 .33214 .39742 .32975 .39501 Metetra
.664 .741 .907 r
.32975 .39501 .33214 .39742 .33594 .39611 .33355 .3937 Metetra
.664 .741 .907 r
.33355 .3937 .33594 .39611 .33975 .3948 .33737 .39239 Metetra
.664 .741 .907 r
.33737 .39239 .33975 .3948 .34357 .3935 .34118 .39108 Metetra
.664 .741 .907 r
.34118 .39108 .34357 .3935 .34739 .39219 .34501 .38976 Metetra
.664 .741 .907 r
.34501 .38976 .34739 .39219 .35121 .39087 .34884 .38845 Metetra
.664 .741 .907 r
.34884 .38845 .35121 .39087 .35504 .38956 .35267 .38713 Metetra
.664 .741 .907 r
.35267 .38713 .35504 .38956 .35888 .38824 .35651 .38581 Metetra
.664 .741 .907 r
.35651 .38581 .35888 .38824 .36272 .38693 .36036 .38449 Metetra
.664 .741 .907 r
.36036 .38449 .36272 .38693 .36657 .38561 .36421 .38317 Metetra
.664 .741 .907 r
.36421 .38317 .36657 .38561 .37042 .38429 .36806 .38184 Metetra
.664 .741 .907 r
.36806 .38184 .37042 .38429 .37428 .38296 .37192 .38051 Metetra
.664 .741 .907 r
.37192 .38051 .37428 .38296 .37814 .38164 .37579 .37918 Metetra
.664 .741 .907 r
.37579 .37918 .37814 .38164 .38201 .38031 .37966 .37785 Metetra
.664 .741 .907 r
.37966 .37785 .38201 .38031 .38589 .37898 .38354 .37652 Metetra
.664 .741 .907 r
.38354 .37652 .38589 .37898 .38977 .37765 .38743 .37519 Metetra
.664 .741 .907 r
.38743 .37519 .38977 .37765 .39365 .37632 .39132 .37385 Metetra
.664 .741 .907 r
.39132 .37385 .39365 .37632 .39701 .38836 .39521 .37251 Metetra
.033 .02 .508 r
.39521 .37251 .39701 .38836 .40092 .38718 .39859 .3846 Metetra
.647 .727 .907 r
.39859 .3846 .40092 .38718 .40483 .38601 .4025 .38342 Metetra
.647 .727 .907 r
.4025 .38342 .40483 .38601 .40875 .38484 .40643 .38224 Metetra
.646 .726 .907 r
.40643 .38224 .40875 .38484 .41268 .38368 .41035 .38107 Metetra
.646 .726 .907 r
.41035 .38107 .41268 .38368 .41661 .38251 .41429 .3799 Metetra
.958 .682 .469 r
.41429 .3799 .41661 .38251 .42055 .38136 .4111 .59277 Metetra
.538 .313 .521 r
.4111 .59277 .42055 .38136 .41779 .59384 .41531 .5915 Metetra
.95 .723 .56 r
.41531 .5915 .41779 .59384 .42203 .59196 .42048 .55944 Metetra
.763 .526 .575 r
.42048 .55944 .42203 .59196 .4275 .54736 .42555 .52845 Metetra
.775 .551 .595 r
.42555 .52845 .4275 .54736 .43234 .5221 .43022 .50884 Metetra
.779 .569 .616 r
.43022 .50884 .43234 .5221 .4369 .50522 .43471 .49491 Metetra
.779 .584 .637 r
.43471 .49491 .4369 .50522 .44132 .49283 .43908 .4843 Metetra
.776 .597 .657 r
.43908 .4843 .44132 .49283 .44565 .48319 .44339 .47581 Metetra
.772 .608 .676 r
.44339 .47581 .44565 .48319 .44992 .47537 .44765 .46879 Metetra
.766 .617 .694 r
.44765 .46879 .44992 .47537 .45416 .46884 .45187 .46284 Metetra
.76 .625 .711 r
.45187 .46284 .45416 .46884 .45837 .46326 .45608 .45769 Metetra
.753 .632 .726 r
.45608 .45769 .45837 .46326 .46256 .4584 .46027 .45317 Metetra
.746 .638 .74 r
.46027 .45317 .46256 .4584 .46674 .45412 .46445 .44914 Metetra
.739 .642 .753 r
.46445 .44914 .46674 .45412 .47092 .4503 .46862 .44552 Metetra
.731 .646 .764 r
.46862 .44552 .47092 .4503 .47508 .44686 .47278 .44225 Metetra
.723 .648 .774 r
.47278 .44225 .47508 .44686 .47924 .44374 .47695 .43926 Metetra
.715 .65 .783 r
.47695 .43926 .47924 .44374 .4834 .4409 .48111 .43653 Metetra
.708 .651 .792 r
.48111 .43653 .4834 .4409 .48756 .43831 .48527 .43402 Metetra
.699 .652 .799 r
.48527 .43402 .48756 .43831 .49173 .43593 .48943 .4317 Metetra
.691 .652 .806 r
.48943 .4317 .49173 .43593 .49589 .43374 .4936 .42957 Metetra
.683 .651 .812 r
.4936 .42957 .49589 .43374 .50005 .43174 .49777 .42761 Metetra
.675 .649 .817 r
.49777 .42761 .50005 .43174 .50422 .42991 .50194 .4258 Metetra
.666 .647 .821 r
.50194 .4258 .50422 .42991 .5084 .42823 .50611 .42414 Metetra
.657 .644 .826 r
.50611 .42414 .5084 .42823 .51258 .42671 .51029 .42263 Metetra
.647 .64 .829 r
.51029 .42263 .51258 .42671 .51676 .42535 .51448 .42126 Metetra
.637 .636 .832 r
.51448 .42126 .51676 .42535 .52095 .42414 .51867 .42003 Metetra
.627 .63 .834 r
.51867 .42003 .52095 .42414 .52515 .42308 .52287 .41895 Metetra
.615 .624 .836 r
.52287 .41895 .52515 .42308 .52935 .42218 .52708 .41802 Metetra
.603 .616 .838 r
.52708 .41802 .52935 .42218 .53357 .42146 .53129 .41725 Metetra
.589 .608 .838 r
.53129 .41725 .53357 .42146 .53779 .42091 .53552 .41664 Metetra
.574 .597 .838 r
.53552 .41664 .53779 .42091 .54202 .42057 .53975 .41622 Metetra
.558 .585 .837 r
.53975 .41622 .54202 .42057 .54626 .42044 .54399 .416 Metetra
.539 .571 .835 r
.54399 .416 .54626 .42044 .55052 .42056 .54825 .416 Metetra
.517 .554 .832 r
.54825 .416 .55052 .42056 .55478 .42096 .55251 .41626 Metetra
.492 .534 .828 r
.55251 .41626 .55478 .42096 .55907 .42169 .55679 .41682 Metetra
.462 .509 .821 r
.55679 .41682 .55907 .42169 .56336 .42281 .56109 .41772 Metetra
.428 .48 .811 r
.56109 .41772 .56336 .42281 .56768 .42439 .5654 .41903 Metetra
.386 .444 .798 r
.5654 .41903 .56768 .42439 .57202 .42656 .56974 .42086 Metetra
.336 .399 .78 r
.56974 .42086 .57202 .42656 .57639 .42947 .57409 .42332 Metetra
.275 .345 .754 r
.57409 .42332 .57639 .42947 .58079 .43334 .57848 .42659 Metetra
.2 .277 .719 r
.57848 .42659 .58079 .43334 .58524 .43852 .58291 .43095 Metetra
.109 .194 .672 r
.58291 .43095 .58524 .43852 .58975 .44555 .58739 .43681 Metetra
0 .094 .608 r
.58739 .43681 .58975 .44555 .59435 .45539 .59194 .44484 Metetra
0 0 .525 r
.59194 .44484 .59435 .45539 .59909 .46981 .5966 .45624 Metetra
0 0 .421 r
.5966 .45624 .59909 .46981 .60408 .49276 .60143 .47344 Metetra
0 0 .297 r
.60143 .47344 .60408 .49276 .60965 .53544 .60661 .50223 Metetra
.021 0 .466 r
.60661 .50223 .60965 .53544 .61418 .5347 .6119 .53218 Metetra
.645 .763 .934 r
.6119 .53218 .61418 .5347 .61263 .31598 .61643 .53082 Metetra
0 0 .363 r
.61643 .53082 .61263 .31598 .61686 .31435 .61473 .31155 Metetra
.678 .736 .895 r
.61473 .31155 .61686 .31435 .6211 .31273 .61897 .30993 Metetra
.677 .737 .895 r
.61897 .30993 .6211 .31273 .62534 .31111 .62321 .3083 Metetra
.677 .737 .895 r
.62321 .3083 .62534 .31111 .62959 .30949 .62747 .30668 Metetra
.677 .737 .896 r
.62747 .30668 .62959 .30949 .63384 .30787 .63172 .30507 Metetra
.951 .755 .603 r
.63172 .30507 .63384 .30787 .6381 .30626 .63551 .28994 Metetra
.582 .417 .623 r
.63551 .28994 .6381 .30626 .64187 .29118 .63977 .28848 Metetra
.664 .741 .907 r
.63977 .28848 .64187 .29118 .64613 .28972 .64403 .28702 Metetra
.664 .741 .907 r
.64403 .28702 .64613 .28972 .65039 .28826 .6483 .28555 Metetra
.664 .741 .907 r
.6483 .28555 .65039 .28826 .65467 .28679 .65258 .28408 Metetra
.664 .741 .907 r
.65258 .28408 .65467 .28679 .65895 .28532 .65687 .28261 Metetra
.664 .741 .907 r
.65687 .28261 .65895 .28532 .66323 .28385 .66116 .28113 Metetra
.664 .741 .907 r
.66116 .28113 .66323 .28385 .66753 .28238 .66545 .27966 Metetra
.664 .741 .907 r
.66545 .27966 .66753 .28238 .67182 .2809 .66976 .27818 Metetra
.664 .741 .907 r
.66976 .27818 .67182 .2809 .67613 .27943 .67407 .2767 Metetra
.664 .741 .907 r
.67407 .2767 .67613 .27943 .68044 .27795 .67839 .27521 Metetra
.664 .741 .907 r
.67839 .27521 .68044 .27795 .68476 .27647 .68271 .27373 Metetra
.664 .741 .907 r
.68271 .27373 .68476 .27647 .68909 .27498 .68704 .27224 Metetra
.664 .741 .907 r
.68704 .27224 .68909 .27498 .69342 .2735 .69138 .27075 Metetra
.664 .741 .907 r
.69138 .27075 .69342 .2735 .69776 .27201 .69572 .26926 Metetra
.664 .741 .907 r
.69572 .26926 .69776 .27201 .7021 .27052 .70007 .26776 Metetra
.664 .741 .907 r
.70007 .26776 .7021 .27052 .70646 .26903 .70443 .26626 Metetra
.664 .741 .907 r
.70443 .26626 .70646 .26903 .71082 .26753 .70879 .26476 Metetra
.664 .741 .907 r
.70879 .26476 .71082 .26753 .71518 .26603 .71316 .26326 Metetra
.664 .741 .907 r
.71316 .26326 .71518 .26603 .71955 .26453 .71754 .26176 Metetra
.664 .741 .907 r
.71754 .26176 .71955 .26453 .72393 .26303 .72192 .26025 Metetra
.664 .741 .907 r
.72192 .26025 .72393 .26303 .72832 .26153 .72631 .25874 Metetra
.664 .741 .907 r
.72631 .25874 .72832 .26153 .73271 .26002 .73071 .25723 Metetra
.664 .741 .907 r
.73071 .25723 .73271 .26002 .73711 .25851 .73511 .25572 Metetra
.664 .741 .907 r
.73511 .25572 .73711 .25851 .74152 .257 .73952 .2542 Metetra
.664 .741 .907 r
.73952 .2542 .74152 .257 .74593 .25549 .74394 .25269 Metetra
.664 .741 .907 r
.74394 .25269 .74593 .25549 .75035 .25397 .74837 .25117 Metetra
.664 .741 .907 r
.74837 .25117 .75035 .25397 .75478 .25245 .7528 .24964 Metetra
.664 .741 .907 r
.7528 .24964 .75478 .25245 .75921 .25093 .75724 .24812 Metetra
.664 .741 .907 r
.75724 .24812 .75921 .25093 .76365 .24941 .76168 .24659 Metetra
.664 .741 .907 r
.76168 .24659 .76365 .24941 .7681 .24788 .76613 .24506 Metetra
.664 .741 .907 r
.76613 .24506 .7681 .24788 .77255 .24636 .77059 .24353 Metetra
.664 .741 .907 r
.77059 .24353 .77255 .24636 .77701 .24483 .77506 .24199 Metetra
.664 .741 .907 r
.77506 .24199 .77701 .24483 .78148 .24329 .77953 .24046 Metetra
.664 .741 .907 r
.77953 .24046 .78148 .24329 .78596 .24176 .78401 .23892 Metetra
.664 .741 .907 r
.78401 .23892 .78596 .24176 .79044 .24022 .7885 .23738 Metetra
.664 .741 .907 r
.7885 .23738 .79044 .24022 .79493 .23868 .79299 .23583 Metetra
.664 .741 .907 r
.79299 .23583 .79493 .23868 .79942 .23714 .79749 .23429 Metetra
.664 .741 .907 r
.79749 .23429 .79942 .23714 .80393 .23559 .802 .23274 Metetra
.664 .741 .907 r
.802 .23274 .80393 .23559 .80843 .23405 .80652 .23119 Metetra
.664 .741 .907 r
.80652 .23119 .80843 .23405 .81295 .2325 .81104 .22963 Metetra
.664 .741 .907 r
.81104 .22963 .81295 .2325 .81748 .23095 .81557 .22808 Metetra
.664 .741 .907 r
.81557 .22808 .81748 .23095 .82201 .22939 .8201 .22652 Metetra
.664 .741 .907 r
.8201 .22652 .82201 .22939 .82655 .22784 .82465 .22496 Metetra
.664 .741 .907 r
.82465 .22496 .82655 .22784 .83109 .22628 .8292 .22339 Metetra
.664 .741 .907 r
.8292 .22339 .83109 .22628 .83564 .22472 .83375 .22183 Metetra
.664 .741 .907 r
.22285 .42856 .22533 .43088 .22899 .42963 .22651 .4273 Metetra
.664 .741 .907 r
.22651 .4273 .22899 .42963 .23266 .42837 .23018 .42604 Metetra
.664 .741 .907 r
.23018 .42604 .23266 .42837 .23633 .42711 .23385 .42477 Metetra
.664 .741 .907 r
.23385 .42477 .23633 .42711 .24 .42584 .23752 .42351 Metetra
.664 .741 .907 r
.23752 .42351 .24 .42584 .24368 .42458 .24121 .42224 Metetra
.664 .741 .907 r
.24121 .42224 .24368 .42458 .24736 .42331 .24489 .42097 Metetra
.664 .741 .907 r
.24489 .42097 .24736 .42331 .25105 .42205 .24859 .4197 Metetra
.664 .741 .907 r
.24859 .4197 .25105 .42205 .25475 .42078 .25228 .41843 Metetra
.664 .741 .907 r
.25228 .41843 .25475 .42078 .25845 .41951 .25599 .41715 Metetra
.664 .741 .907 r
.25599 .41715 .25845 .41951 .26215 .41823 .25969 .41588 Metetra
.664 .741 .907 r
.25969 .41588 .26215 .41823 .26586 .41696 .26341 .4146 Metetra
.664 .741 .907 r
.26341 .4146 .26586 .41696 .26958 .41568 .26713 .41332 Metetra
.664 .741 .907 r
.26713 .41332 .26958 .41568 .2733 .4144 .27085 .41204 Metetra
.664 .741 .907 r
.27085 .41204 .2733 .4144 .27702 .41312 .27458 .41075 Metetra
.664 .741 .907 r
.27458 .41075 .27702 .41312 .28075 .41184 .27831 .40947 Metetra
.664 .741 .907 r
.27831 .40947 .28075 .41184 .28449 .41056 .28205 .40818 Metetra
.664 .741 .907 r
.28205 .40818 .28449 .41056 .28823 .40927 .2858 .40689 Metetra
.664 .741 .907 r
.2858 .40689 .28823 .40927 .29198 .40798 .28955 .4056 Metetra
.664 .741 .907 r
.28955 .4056 .29198 .40798 .29573 .40669 .29331 .40431 Metetra
.664 .741 .907 r
.29331 .40431 .29573 .40669 .29949 .4054 .29707 .40301 Metetra
.664 .741 .907 r
.29707 .40301 .29949 .4054 .30325 .40411 .30083 .40172 Metetra
.664 .741 .907 r
.30083 .40172 .30325 .40411 .30702 .40281 .30461 .40042 Metetra
.664 .741 .907 r
.30461 .40042 .30702 .40281 .3108 .40152 .30838 .39912 Metetra
.664 .741 .907 r
.30838 .39912 .3108 .40152 .31458 .40022 .31217 .39782 Metetra
.664 .741 .907 r
.31217 .39782 .31458 .40022 .31836 .39892 .31595 .39651 Metetra
.664 .741 .907 r
.31595 .39651 .31836 .39892 .32215 .39762 .31975 .39521 Metetra
.664 .741 .907 r
.31975 .39521 .32215 .39762 .32595 .39631 .32355 .3939 Metetra
.664 .741 .907 r
.32355 .3939 .32595 .39631 .32975 .39501 .32735 .39259 Metetra
.664 .741 .907 r
.32735 .39259 .32975 .39501 .33355 .3937 .33116 .39128 Metetra
.664 .741 .907 r
.33116 .39128 .33355 .3937 .33737 .39239 .33498 .38996 Metetra
.664 .741 .907 r
.33498 .38996 .33737 .39239 .34118 .39108 .3388 .38865 Metetra
.664 .741 .907 r
.3388 .38865 .34118 .39108 .34501 .38976 .34262 .38733 Metetra
.664 .741 .907 r
.34262 .38733 .34501 .38976 .34884 .38845 .34646 .38601 Metetra
.664 .741 .907 r
.34646 .38601 .34884 .38845 .35267 .38713 .35029 .38469 Metetra
.664 .741 .907 r
.35029 .38469 .35267 .38713 .35651 .38581 .35414 .38337 Metetra
.664 .741 .907 r
.35414 .38337 .35651 .38581 .36036 .38449 .35798 .38204 Metetra
.664 .741 .907 r
.35798 .38204 .36036 .38449 .36421 .38317 .36184 .38072 Metetra
.664 .741 .907 r
.36184 .38072 .36421 .38317 .36806 .38184 .3657 .37939 Metetra
.664 .741 .907 r
.3657 .37939 .36806 .38184 .37192 .38051 .36956 .37806 Metetra
.664 .741 .907 r
.36956 .37806 .37192 .38051 .37579 .37918 .37343 .37673 Metetra
.664 .741 .907 r
.37343 .37673 .37579 .37918 .37966 .37785 .37731 .37539 Metetra
.664 .741 .907 r
.37731 .37539 .37966 .37785 .38354 .37652 .38119 .37406 Metetra
.664 .741 .907 r
.38119 .37406 .38354 .37652 .38743 .37519 .38508 .37272 Metetra
.664 .741 .907 r
.38508 .37272 .38743 .37519 .39132 .37385 .38897 .37138 Metetra
.664 .741 .907 r
.38897 .37138 .39132 .37385 .39521 .37251 .39287 .37004 Metetra
.664 .741 .907 r
.39287 .37004 .39521 .37251 .39859 .3846 .39678 .36869 Metetra
.582 .417 .623 r
.39678 .36869 .39859 .3846 .4025 .38342 .40069 .36734 Metetra
.032 .019 .507 r
.40069 .36734 .4025 .38342 .40643 .38224 .40409 .37964 Metetra
.646 .726 .907 r
.40409 .37964 .40643 .38224 .41035 .38107 .40802 .37846 Metetra
.646 .726 .907 r
.40802 .37846 .41035 .38107 .41429 .3799 .41196 .37728 Metetra
.958 .682 .469 r
.41196 .37728 .41429 .3799 .4111 .59277 .4086 .59042 Metetra
.931 .751 .636 r
.4086 .59042 .4111 .59277 .41531 .5915 .41326 .57574 Metetra
.867 .624 .569 r
.41326 .57574 .41531 .5915 .42048 .55944 .41867 .53647 Metetra
.771 .541 .587 r
.41867 .53647 .42048 .55944 .42555 .52845 .4235 .51331 Metetra
.777 .562 .607 r
.4235 .51331 .42555 .52845 .43022 .50884 .42807 .4975 Metetra
.779 .578 .628 r
.42807 .4975 .43022 .50884 .43471 .49491 .43249 .48574 Metetra
.777 .592 .649 r
.43249 .48574 .43471 .49491 .43908 .4843 .43683 .47649 Metetra
.774 .604 .668 r
.43683 .47649 .43908 .4843 .44339 .47581 .44112 .46893 Metetra
.769 .614 .687 r
.44112 .46893 .44339 .47581 .44765 .46879 .44536 .46258 Metetra
.763 .622 .704 r
.44536 .46258 .44765 .46879 .45187 .46284 .44958 .45711 Metetra
.757 .63 .72 r
.44958 .45711 .45187 .46284 .45608 .45769 .45378 .45233 Metetra
.75 .636 .734 r
.45378 .45233 .45608 .45769 .46027 .45317 .45797 .44809 Metetra
.743 .641 .748 r
.45797 .44809 .46027 .45317 .46445 .44914 .46214 .4443 Metetra
.735 .645 .759 r
.46214 .4443 .46445 .44914 .46862 .44552 .46631 .44086 Metetra
.728 .649 .77 r
.46631 .44086 .46862 .44552 .47278 .44225 .47048 .43773 Metetra
.72 .651 .78 r
.47048 .43773 .47278 .44225 .47695 .43926 .47464 .43486 Metetra
.713 .653 .788 r
.47464 .43486 .47695 .43926 .48111 .43653 .47881 .43222 Metetra
.705 .654 .796 r
.47881 .43222 .48111 .43653 .48527 .43402 .48297 .42979 Metetra
.698 .654 .803 r
.48297 .42979 .48527 .43402 .48943 .4317 .48713 .42754 Metetra
.69 .654 .809 r
.48713 .42754 .48943 .4317 .4936 .42957 .4913 .42545 Metetra
.682 .653 .815 r
.4913 .42545 .4936 .42957 .49777 .42761 .49547 .42352 Metetra
.674 .651 .82 r
.49547 .42352 .49777 .42761 .50194 .4258 .49964 .42174 Metetra
.665 .649 .824 r
.49964 .42174 .50194 .4258 .50611 .42414 .50382 .4201 Metetra
.657 .646 .828 r
.50382 .4201 .50611 .42414 .51029 .42263 .50801 .41859 Metetra
.648 .643 .831 r
.50801 .41859 .51029 .42263 .51448 .42126 .51219 .41721 Metetra
.638 .639 .834 r
.51219 .41721 .51448 .42126 .51867 .42003 .51639 .41597 Metetra
.628 .634 .837 r
.51639 .41597 .51867 .42003 .52287 .41895 .52059 .41487 Metetra
.618 .628 .838 r
.52059 .41487 .52287 .41895 .52708 .41802 .5248 .4139 Metetra
.606 .621 .84 r
.5248 .4139 .52708 .41802 .53129 .41725 .52902 .41309 Metetra
.594 .613 .841 r
.52902 .41309 .53129 .41725 .53552 .41664 .53324 .41243 Metetra
.58 .603 .841 r
.53324 .41243 .53552 .41664 .53975 .41622 .53747 .41193 Metetra
.564 .592 .84 r
.53747 .41193 .53975 .41622 .54399 .416 .54172 .41163 Metetra
.547 .579 .838 r
.54172 .41163 .54399 .416 .54825 .416 .54597 .41153 Metetra
.527 .564 .836 r
.54597 .41153 .54825 .416 .55251 .41626 .55024 .41166 Metetra
.504 .545 .832 r
.55024 .41166 .55251 .41626 .55679 .41682 .55452 .41205 Metetra
.478 .523 .826 r
.55452 .41205 .55679 .41682 .56109 .41772 .55881 .41276 Metetra
.446 .497 .818 r
.55881 .41276 .56109 .41772 .5654 .41903 .56312 .41384 Metetra
.409 .465 .807 r
.56312 .41384 .5654 .41903 .56974 .42086 .56745 .41537 Metetra
.365 .426 .791 r
.56745 .41537 .56974 .42086 .57409 .42332 .5718 .41744 Metetra
.311 .378 .77 r
.5718 .41744 .57409 .42332 .57848 .42659 .57618 .42022 Metetra
.245 .319 .741 r
.57618 .42022 .57848 .42659 .58291 .43095 .58059 .4239 Metetra
.165 .246 .702 r
.58059 .4239 .58291 .43095 .58739 .43681 .58505 .4288 Metetra
.068 .156 .648 r
.58505 .4288 .58739 .43681 .59194 .44484 .58956 .43543 Metetra
0 .05 .578 r
.58956 .43543 .59194 .44484 .5966 .45624 .59416 .44462 Metetra
0 0 .487 r
.59416 .44462 .5966 .45624 .60143 .47344 .59888 .45794 Metetra
0 0 .376 r
.59888 .45794 .60143 .47344 .60661 .50223 .60383 .47874 Metetra
0 0 .246 r
.60383 .47874 .60661 .50223 .6119 .53218 .60927 .516 Metetra
.13 .108 .563 r
.60927 .516 .6119 .53218 .61643 .53082 .61415 .52829 Metetra
.974 .692 .43 r
.61415 .52829 .61643 .53082 .61473 .31155 .61258 .30874 Metetra
.678 .736 .895 r
.61258 .30874 .61473 .31155 .61897 .30993 .61683 .30712 Metetra
.677 .737 .895 r
.61683 .30712 .61897 .30993 .62321 .3083 .62108 .30549 Metetra
.95 .754 .602 r
.62108 .30549 .62321 .3083 .62747 .30668 .6249 .29017 Metetra
.582 .416 .622 r
.6249 .29017 .62747 .30668 .63172 .30507 .62915 .28871 Metetra
.582 .417 .623 r
.62915 .28871 .63172 .30507 .63551 .28994 .6334 .28724 Metetra
.664 .741 .907 r
.6334 .28724 .63551 .28994 .63977 .28848 .63767 .28577 Metetra
.664 .741 .907 r
.63767 .28577 .63977 .28848 .64403 .28702 .64193 .2843 Metetra
.664 .741 .907 r
.64193 .2843 .64403 .28702 .6483 .28555 .64621 .28283 Metetra
.664 .741 .907 r
.64621 .28283 .6483 .28555 .65258 .28408 .65049 .28136 Metetra
.664 .741 .907 r
.65049 .28136 .65258 .28408 .65687 .28261 .65478 .27988 Metetra
.664 .741 .907 r
.65478 .27988 .65687 .28261 .66116 .28113 .65908 .2784 Metetra
.664 .741 .907 r
.65908 .2784 .66116 .28113 .66545 .27966 .66338 .27692 Metetra
.664 .741 .907 r
.66338 .27692 .66545 .27966 .66976 .27818 .66769 .27544 Metetra
.664 .741 .907 r
.66769 .27544 .66976 .27818 .67407 .2767 .672 .27395 Metetra
.664 .741 .907 r
.672 .27395 .67407 .2767 .67839 .27521 .67632 .27247 Metetra
.664 .741 .907 r
.67632 .27247 .67839 .27521 .68271 .27373 .68065 .27098 Metetra
.664 .741 .907 r
.68065 .27098 .68271 .27373 .68704 .27224 .68499 .26949 Metetra
.664 .741 .907 r
.68499 .26949 .68704 .27224 .69138 .27075 .68933 .26799 Metetra
.664 .741 .907 r
.68933 .26799 .69138 .27075 .69572 .26926 .69368 .26649 Metetra
.664 .741 .907 r
.69368 .26649 .69572 .26926 .70007 .26776 .69803 .265 Metetra
.664 .741 .907 r
.69803 .265 .70007 .26776 .70443 .26626 .70239 .26349 Metetra
.664 .741 .907 r
.70239 .26349 .70443 .26626 .70879 .26476 .70676 .26199 Metetra
.664 .741 .907 r
.70676 .26199 .70879 .26476 .71316 .26326 .71114 .26048 Metetra
.664 .741 .907 r
.71114 .26048 .71316 .26326 .71754 .26176 .71552 .25898 Metetra
.664 .741 .907 r
.71552 .25898 .71754 .26176 .72192 .26025 .71991 .25747 Metetra
.664 .741 .907 r
.71991 .25747 .72192 .26025 .72631 .25874 .7243 .25595 Metetra
.664 .741 .907 r
.7243 .25595 .72631 .25874 .73071 .25723 .7287 .25444 Metetra
.664 .741 .907 r
.7287 .25444 .73071 .25723 .73511 .25572 .73311 .25292 Metetra
.664 .741 .907 r
.73311 .25292 .73511 .25572 .73952 .2542 .73753 .2514 Metetra
.664 .741 .907 r
.73753 .2514 .73952 .2542 .74394 .25269 .74195 .24988 Metetra
.664 .741 .907 r
.74195 .24988 .74394 .25269 .74837 .25117 .74638 .24835 Metetra
.664 .741 .907 r
.74638 .24835 .74837 .25117 .7528 .24964 .75081 .24683 Metetra
.664 .741 .907 r
.75081 .24683 .7528 .24964 .75724 .24812 .75526 .2453 Metetra
.664 .741 .907 r
.75526 .2453 .75724 .24812 .76168 .24659 .75971 .24376 Metetra
.664 .741 .907 r
.75971 .24376 .76168 .24659 .76613 .24506 .76416 .24223 Metetra
.664 .741 .907 r
.76416 .24223 .76613 .24506 .77059 .24353 .76863 .24069 Metetra
.664 .741 .907 r
.76863 .24069 .77059 .24353 .77506 .24199 .7731 .23916 Metetra
.664 .741 .907 r
.7731 .23916 .77506 .24199 .77953 .24046 .77758 .23761 Metetra
.664 .741 .907 r
.77758 .23761 .77953 .24046 .78401 .23892 .78206 .23607 Metetra
.664 .741 .907 r
.78206 .23607 .78401 .23892 .7885 .23738 .78655 .23452 Metetra
.664 .741 .907 r
.78655 .23452 .7885 .23738 .79299 .23583 .79105 .23298 Metetra
.664 .741 .907 r
.79105 .23298 .79299 .23583 .79749 .23429 .79556 .23142 Metetra
.664 .741 .907 r
.79556 .23142 .79749 .23429 .802 .23274 .80007 .22987 Metetra
.664 .741 .907 r
.80007 .22987 .802 .23274 .80652 .23119 .80459 .22832 Metetra
.664 .741 .907 r
.80459 .22832 .80652 .23119 .81104 .22963 .80912 .22676 Metetra
.664 .741 .907 r
.80912 .22676 .81104 .22963 .81557 .22808 .81365 .2252 Metetra
.664 .741 .907 r
.81365 .2252 .81557 .22808 .8201 .22652 .81819 .22363 Metetra
.664 .741 .907 r
.81819 .22363 .8201 .22652 .82465 .22496 .82274 .22207 Metetra
.664 .741 .907 r
.82274 .22207 .82465 .22496 .8292 .22339 .8273 .2205 Metetra
.664 .741 .907 r
.8273 .2205 .8292 .22339 .83375 .22183 .83186 .21893 Metetra
.664 .741 .907 r
.22036 .42623 .22285 .42856 .22651 .4273 .22402 .42497 Metetra
.664 .741 .907 r
.22402 .42497 .22651 .4273 .23018 .42604 .22769 .4237 Metetra
.664 .741 .907 r
.22769 .4237 .23018 .42604 .23385 .42477 .23136 .42244 Metetra
.664 .741 .907 r
.23136 .42244 .23385 .42477 .23752 .42351 .23504 .42117 Metetra
.664 .741 .907 r
.23504 .42117 .23752 .42351 .24121 .42224 .23873 .4199 Metetra
.664 .741 .907 r
.23873 .4199 .24121 .42224 .24489 .42097 .24242 .41862 Metetra
.664 .741 .907 r
.24242 .41862 .24489 .42097 .24859 .4197 .24611 .41735 Metetra
.664 .741 .907 r
.24611 .41735 .24859 .4197 .25228 .41843 .24982 .41607 Metetra
.664 .741 .907 r
.24982 .41607 .25228 .41843 .25599 .41715 .25352 .4148 Metetra
.664 .741 .907 r
.25352 .4148 .25599 .41715 .25969 .41588 .25723 .41352 Metetra
.664 .741 .907 r
.25723 .41352 .25969 .41588 .26341 .4146 .26095 .41223 Metetra
.664 .741 .907 r
.26095 .41223 .26341 .4146 .26713 .41332 .26467 .41095 Metetra
.664 .741 .907 r
.26467 .41095 .26713 .41332 .27085 .41204 .2684 .40967 Metetra
.664 .741 .907 r
.2684 .40967 .27085 .41204 .27458 .41075 .27213 .40838 Metetra
.664 .741 .907 r
.27213 .40838 .27458 .41075 .27831 .40947 .27587 .40709 Metetra
.664 .741 .907 r
.27587 .40709 .27831 .40947 .28205 .40818 .27961 .4058 Metetra
.664 .741 .907 r
.27961 .4058 .28205 .40818 .2858 .40689 .28336 .40451 Metetra
.664 .741 .907 r
.28336 .40451 .2858 .40689 .28955 .4056 .28711 .40321 Metetra
.664 .741 .907 r
.28711 .40321 .28955 .4056 .29331 .40431 .29087 .40192 Metetra
.664 .741 .907 r
.29087 .40192 .29331 .40431 .29707 .40301 .29464 .40062 Metetra
.664 .741 .907 r
.29464 .40062 .29707 .40301 .30083 .40172 .29841 .39932 Metetra
.664 .741 .907 r
.29841 .39932 .30083 .40172 .30461 .40042 .30218 .39802 Metetra
.664 .741 .907 r
.30218 .39802 .30461 .40042 .30838 .39912 .30596 .39671 Metetra
.664 .741 .907 r
.30596 .39671 .30838 .39912 .31217 .39782 .30975 .39541 Metetra
.664 .741 .907 r
.30975 .39541 .31217 .39782 .31595 .39651 .31354 .3941 Metetra
.664 .741 .907 r
.31354 .3941 .31595 .39651 .31975 .39521 .31734 .39279 Metetra
.664 .741 .907 r
.31734 .39279 .31975 .39521 .32355 .3939 .32114 .39148 Metetra
.664 .741 .907 r
.32114 .39148 .32355 .3939 .32735 .39259 .32495 .39017 Metetra
.664 .741 .907 r
.32495 .39017 .32735 .39259 .33116 .39128 .32876 .38885 Metetra
.664 .741 .907 r
.32876 .38885 .33116 .39128 .33498 .38996 .33258 .38753 Metetra
.664 .741 .907 r
.33258 .38753 .33498 .38996 .3388 .38865 .3364 .38622 Metetra
.664 .741 .907 r
.3364 .38622 .3388 .38865 .34262 .38733 .34023 .3849 Metetra
.664 .741 .907 r
.34023 .3849 .34262 .38733 .34646 .38601 .34407 .38357 Metetra
.664 .741 .907 r
.34407 .38357 .34646 .38601 .35029 .38469 .34791 .38225 Metetra
.664 .741 .907 r
.34791 .38225 .35029 .38469 .35414 .38337 .35176 .38092 Metetra
.664 .741 .907 r
.35176 .38092 .35414 .38337 .35798 .38204 .35561 .37959 Metetra
.664 .741 .907 r
.35561 .37959 .35798 .38204 .36184 .38072 .35946 .37826 Metetra
.664 .741 .907 r
.35946 .37826 .36184 .38072 .3657 .37939 .36333 .37693 Metetra
.664 .741 .907 r
.36333 .37693 .3657 .37939 .36956 .37806 .3672 .3756 Metetra
.664 .741 .907 r
.3672 .3756 .36956 .37806 .37343 .37673 .37107 .37426 Metetra
.664 .741 .907 r
.37107 .37426 .37343 .37673 .37731 .37539 .37495 .37292 Metetra
.664 .741 .907 r
.37495 .37292 .37731 .37539 .38119 .37406 .37884 .37158 Metetra
.664 .741 .907 r
.37884 .37158 .38119 .37406 .38508 .37272 .38273 .37024 Metetra
.664 .741 .907 r
.38273 .37024 .38508 .37272 .38897 .37138 .38663 .3689 Metetra
.664 .741 .907 r
.38663 .3689 .38897 .37138 .39287 .37004 .39053 .36755 Metetra
.664 .741 .907 r
.39053 .36755 .39287 .37004 .39678 .36869 .39444 .3662 Metetra
.664 .741 .907 r
.39444 .3662 .39678 .36869 .40069 .36734 .39835 .36485 Metetra
.664 .741 .907 r
.39835 .36485 .40069 .36734 .40409 .37964 .40227 .3635 Metetra
.031 .018 .506 r
.40227 .3635 .40409 .37964 .40802 .37846 .40568 .37585 Metetra
.958 .682 .471 r
.40568 .37585 .40802 .37846 .41196 .37728 .40189 .58934 Metetra
.537 .311 .52 r
.40189 .58934 .41196 .37728 .4086 .59042 .4061 .58806 Metetra
.952 .716 .544 r
.4061 .58806 .4086 .59042 .41326 .57574 .41167 .54674 Metetra
.764 .53 .579 r
.41167 .54674 .41326 .57574 .41867 .53647 .41671 .51884 Metetra
.775 .553 .599 r
.41671 .51884 .41867 .53647 .4235 .51331 .42138 .50068 Metetra
.778 .571 .62 r
.42138 .50068 .4235 .51331 .42807 .4975 .42587 .48755 Metetra
.778 .586 .64 r
.42587 .48755 .42807 .4975 .43249 .48574 .43026 .47743 Metetra
.775 .599 .661 r
.43026 .47743 .43249 .48574 .43683 .47649 .43457 .46927 Metetra
.771 .61 .68 r
.43457 .46927 .43683 .47649 .44112 .46893 .43883 .46247 Metetra
.765 .619 .697 r
.43883 .46247 .44112 .46893 .44536 .46258 .44307 .45667 Metetra
.76 .627 .714 r
.44307 .45667 .44536 .46258 .44958 .45711 .44728 .45162 Metetra
.753 .634 .729 r
.44728 .45162 .44958 .45711 .45378 .45233 .45147 .44716 Metetra
.746 .64 .742 r
.45147 .44716 .45378 .45233 .45797 .44809 .45566 .44317 Metetra
.739 .645 .755 r
.45566 .44317 .45797 .44809 .46214 .4443 .45983 .43957 Metetra
.732 .648 .766 r
.45983 .43957 .46214 .4443 .46631 .44086 .464 .4363 Metetra
.725 .651 .776 r
.464 .4363 .46631 .44086 .47048 .43773 .46817 .4333 Metetra
.718 .654 .785 r
.46817 .4333 .47048 .43773 .47464 .43486 .47233 .43054 Metetra
.71 .655 .793 r
.47233 .43054 .47464 .43486 .47881 .43222 .4765 .42798 Metetra
.703 .656 .8 r
.4765 .42798 .47881 .43222 .48297 .42979 .48066 .42562 Metetra
.696 .656 .807 r
.48066 .42562 .48297 .42979 .48713 .42754 .48483 .42342 Metetra
.688 .656 .813 r
.48483 .42342 .48713 .42754 .4913 .42545 .489 .42138 Metetra
.681 .655 .818 r
.489 .42138 .4913 .42545 .49547 .42352 .49317 .41948 Metetra
.673 .654 .823 r
.49317 .41948 .49547 .42352 .49964 .42174 .49735 .41772 Metetra
.665 .652 .827 r
.49735 .41772 .49964 .42174 .50382 .4201 .50153 .41609 Metetra
.657 .649 .831 r
.50153 .41609 .50382 .4201 .50801 .41859 .50571 .41459 Metetra
.648 .646 .834 r
.50571 .41459 .50801 .41859 .51219 .41721 .5099 .41321 Metetra
.639 .642 .837 r
.5099 .41321 .51219 .41721 .51639 .41597 .5141 .41195 Metetra
.63 .637 .839 r
.5141 .41195 .51639 .41597 .52059 .41487 .5183 .41083 Metetra
.62 .632 .841 r
.5183 .41083 .52059 .41487 .5248 .4139 .52252 .40983 Metetra
.609 .625 .842 r
.52252 .40983 .5248 .4139 .52902 .41309 .52673 .40897 Metetra
.597 .618 .843 r
.52673 .40897 .52902 .41309 .53324 .41243 .53096 .40826 Metetra
.584 .609 .843 r
.53096 .40826 .53324 .41243 .53747 .41193 .53519 .40771 Metetra
.57 .599 .842 r
.53519 .40771 .53747 .41193 .54172 .41163 .53944 .40732 Metetra
.554 .587 .841 r
.53944 .40732 .54172 .41163 .54597 .41153 .54369 .40712 Metetra
.536 .572 .839 r
.54369 .40712 .54597 .41153 .55024 .41166 .54796 .40714 Metetra
.515 .556 .835 r
.54796 .40714 .55024 .41166 .55452 .41205 .55224 .4074 Metetra
.491 .536 .831 r
.55224 .4074 .55452 .41205 .55881 .41276 .55653 .40793 Metetra
.463 .512 .824 r
.55653 .40793 .55881 .41276 .56312 .41384 .56084 .4088 Metetra
.43 .484 .814 r
.56084 .4088 .56312 .41384 .56745 .41537 .56516 .41006 Metetra
.39 .449 .801 r
.56516 .41006 .56745 .41537 .5718 .41744 .56951 .4118 Metetra
.343 .407 .784 r
.56951 .4118 .5718 .41744 .57618 .42022 .57388 .41415 Metetra
.285 .355 .76 r
.57388 .41415 .57618 .42022 .58059 .4239 .57828 .41726 Metetra
.215 .291 .727 r
.57828 .41726 .58059 .4239 .58505 .4288 .58271 .42138 Metetra
.129 .212 .682 r
.58271 .42138 .58505 .4288 .58956 .43543 .5872 .4269 Metetra
.026 .117 .623 r
.5872 .4269 .58956 .43543 .59416 .44462 .59175 .43441 Metetra
0 .004 .545 r
.59175 .43441 .59416 .44462 .59888 .45794 .5964 .44499 Metetra
0 0 .447 r
.5964 .44499 .59888 .45794 .60383 .47874 .60121 .4607 Metetra
0 0 .33 r
.60121 .4607 .60383 .47874 .60927 .516 .60632 .48635 Metetra
0 0 .329 r
.60632 .48635 .60927 .516 .61415 .52829 .61186 .52575 Metetra
.645 .763 .934 r
.61186 .52575 .61415 .52829 .61258 .30874 .61641 .52437 Metetra
0 0 .361 r
.61641 .52437 .61258 .30874 .61683 .30712 .61469 .3043 Metetra
.95 .753 .602 r
.61469 .3043 .61683 .30712 .62108 .30549 .61853 .28893 Metetra
.581 .415 .621 r
.61853 .28893 .62108 .30549 .6249 .29017 .62277 .28747 Metetra
.664 .741 .907 r
.62277 .28747 .6249 .29017 .62915 .28871 .62703 .286 Metetra
.664 .741 .907 r
.62703 .286 .62915 .28871 .6334 .28724 .63129 .28453 Metetra
.664 .741 .907 r
.63129 .28453 .6334 .28724 .63767 .28577 .63556 .28306 Metetra
.664 .741 .907 r
.63556 .28306 .63767 .28577 .64193 .2843 .63983 .28159 Metetra
.664 .741 .907 r
.63983 .28159 .64193 .2843 .64621 .28283 .64411 .28011 Metetra
.664 .741 .907 r
.64411 .28011 .64621 .28283 .65049 .28136 .6484 .27863 Metetra
.664 .741 .907 r
.6484 .27863 .65049 .28136 .65478 .27988 .65269 .27715 Metetra
.664 .741 .907 r
.65269 .27715 .65478 .27988 .65908 .2784 .65699 .27567 Metetra
.664 .741 .907 r
.65699 .27567 .65908 .2784 .66338 .27692 .6613 .27418 Metetra
.664 .741 .907 r
.6613 .27418 .66338 .27692 .66769 .27544 .66561 .2727 Metetra
.664 .741 .907 r
.66561 .2727 .66769 .27544 .672 .27395 .66993 .27121 Metetra
.664 .741 .907 r
.66993 .27121 .672 .27395 .67632 .27247 .67425 .26972 Metetra
.664 .741 .907 r
.67425 .26972 .67632 .27247 .68065 .27098 .67859 .26822 Metetra
.664 .741 .907 r
.67859 .26822 .68065 .27098 .68499 .26949 .68293 .26672 Metetra
.664 .741 .907 r
.68293 .26672 .68499 .26949 .68933 .26799 .68727 .26523 Metetra
.664 .741 .907 r
.68727 .26523 .68933 .26799 .69368 .26649 .69162 .26373 Metetra
.664 .741 .907 r
.69162 .26373 .69368 .26649 .69803 .265 .69598 .26222 Metetra
.664 .741 .907 r
.69598 .26222 .69803 .265 .70239 .26349 .70035 .26072 Metetra
.664 .741 .907 r
.70035 .26072 .70239 .26349 .70676 .26199 .70472 .25921 Metetra
.664 .741 .907 r
.70472 .25921 .70676 .26199 .71114 .26048 .7091 .2577 Metetra
.664 .741 .907 r
.7091 .2577 .71114 .26048 .71552 .25898 .71349 .25619 Metetra
.664 .741 .907 r
.71349 .25619 .71552 .25898 .71991 .25747 .71788 .25467 Metetra
.664 .741 .907 r
.71788 .25467 .71991 .25747 .7243 .25595 .72228 .25315 Metetra
.664 .741 .907 r
.72228 .25315 .7243 .25595 .7287 .25444 .72669 .25163 Metetra
.664 .741 .907 r
.72669 .25163 .7287 .25444 .73311 .25292 .7311 .25011 Metetra
.664 .741 .907 r
.7311 .25011 .73311 .25292 .73753 .2514 .73552 .24859 Metetra
.664 .741 .907 r
.73552 .24859 .73753 .2514 .74195 .24988 .73995 .24706 Metetra
.664 .741 .907 r
.73995 .24706 .74195 .24988 .74638 .24835 .74438 .24553 Metetra
.664 .741 .907 r
.74438 .24553 .74638 .24835 .75081 .24683 .74883 .244 Metetra
.664 .741 .907 r
.74883 .244 .75081 .24683 .75526 .2453 .75327 .24247 Metetra
.664 .741 .907 r
.75327 .24247 .75526 .2453 .75971 .24376 .75773 .24093 Metetra
.664 .741 .907 r
.75773 .24093 .75971 .24376 .76416 .24223 .76219 .23939 Metetra
.664 .741 .907 r
.76219 .23939 .76416 .24223 .76863 .24069 .76666 .23785 Metetra
.664 .741 .907 r
.76666 .23785 .76863 .24069 .7731 .23916 .77113 .23631 Metetra
.664 .741 .907 r
.77113 .23631 .7731 .23916 .77758 .23761 .77562 .23476 Metetra
.664 .741 .907 r
.77562 .23476 .77758 .23761 .78206 .23607 .78011 .23321 Metetra
.664 .741 .907 r
.78011 .23321 .78206 .23607 .78655 .23452 .7846 .23166 Metetra
.664 .741 .907 r
.7846 .23166 .78655 .23452 .79105 .23298 .78911 .23011 Metetra
.664 .741 .907 r
.78911 .23011 .79105 .23298 .79556 .23142 .79362 .22855 Metetra
.664 .741 .907 r
.79362 .22855 .79556 .23142 .80007 .22987 .79814 .227 Metetra
.664 .741 .907 r
.79814 .227 .80007 .22987 .80459 .22832 .80266 .22544 Metetra
.664 .741 .907 r
.80266 .22544 .80459 .22832 .80912 .22676 .80719 .22387 Metetra
.664 .741 .907 r
.80719 .22387 .80912 .22676 .81365 .2252 .81173 .22231 Metetra
.664 .741 .907 r
.81173 .22231 .81365 .2252 .81819 .22363 .81628 .22074 Metetra
.664 .741 .907 r
.81628 .22074 .81819 .22363 .82274 .22207 .82083 .21917 Metetra
.664 .741 .907 r
.82083 .21917 .82274 .22207 .8273 .2205 .82539 .2176 Metetra
.664 .741 .907 r
.82539 .2176 .8273 .2205 .83186 .21893 .82996 .21602 Metetra
.664 .741 .907 r
.21786 .4239 .22036 .42623 .22402 .42497 .22152 .42263 Metetra
.664 .741 .907 r
.22152 .42263 .22402 .42497 .22769 .4237 .2252 .42136 Metetra
.664 .741 .907 r
.2252 .42136 .22769 .4237 .23136 .42244 .22887 .42009 Metetra
.664 .741 .907 r
.22887 .42009 .23136 .42244 .23504 .42117 .23256 .41882 Metetra
.664 .741 .907 r
.23256 .41882 .23504 .42117 .23873 .4199 .23625 .41755 Metetra
.664 .741 .907 r
.23625 .41755 .23873 .4199 .24242 .41862 .23994 .41627 Metetra
.664 .741 .907 r
.23994 .41627 .24242 .41862 .24611 .41735 .24364 .41499 Metetra
.664 .741 .907 r
.24364 .41499 .24611 .41735 .24982 .41607 .24734 .41371 Metetra
.664 .741 .907 r
.24734 .41371 .24982 .41607 .25352 .4148 .25105 .41243 Metetra
.664 .741 .907 r
.25105 .41243 .25352 .4148 .25723 .41352 .25476 .41115 Metetra
.664 .741 .907 r
.25476 .41115 .25723 .41352 .26095 .41223 .25848 .40986 Metetra
.664 .741 .907 r
.25848 .40986 .26095 .41223 .26467 .41095 .26221 .40858 Metetra
.664 .741 .907 r
.26221 .40858 .26467 .41095 .2684 .40967 .26594 .40729 Metetra
.664 .741 .907 r
.26594 .40729 .2684 .40967 .27213 .40838 .26967 .406 Metetra
.664 .741 .907 r
.26967 .406 .27213 .40838 .27587 .40709 .27342 .40471 Metetra
.664 .741 .907 r
.27342 .40471 .27587 .40709 .27961 .4058 .27716 .40341 Metetra
.664 .741 .907 r
.27716 .40341 .27961 .4058 .28336 .40451 .28091 .40212 Metetra
.664 .741 .907 r
.28091 .40212 .28336 .40451 .28711 .40321 .28467 .40082 Metetra
.664 .741 .907 r
.28467 .40082 .28711 .40321 .29087 .40192 .28843 .39952 Metetra
.664 .741 .907 r
.28843 .39952 .29087 .40192 .29464 .40062 .2922 .39822 Metetra
.664 .741 .907 r
.2922 .39822 .29464 .40062 .29841 .39932 .29597 .39691 Metetra
.664 .741 .907 r
.29597 .39691 .29841 .39932 .30218 .39802 .29975 .39561 Metetra
.664 .741 .907 r
.29975 .39561 .30218 .39802 .30596 .39671 .30353 .3943 Metetra
.664 .741 .907 r
.30353 .3943 .30596 .39671 .30975 .39541 .30732 .39299 Metetra
.664 .741 .907 r
.30732 .39299 .30975 .39541 .31354 .3941 .31112 .39168 Metetra
.664 .741 .907 r
.31112 .39168 .31354 .3941 .31734 .39279 .31492 .39037 Metetra
.664 .741 .907 r
.31492 .39037 .31734 .39279 .32114 .39148 .31872 .38905 Metetra
.664 .741 .907 r
.31872 .38905 .32114 .39148 .32495 .39017 .32254 .38774 Metetra
.664 .741 .907 r
.32254 .38774 .32495 .39017 .32876 .38885 .32635 .38642 Metetra
.664 .741 .907 r
.32635 .38642 .32876 .38885 .33258 .38753 .33017 .3851 Metetra
.664 .741 .907 r
.33017 .3851 .33258 .38753 .3364 .38622 .334 .38378 Metetra
.664 .741 .907 r
.334 .38378 .3364 .38622 .34023 .3849 .33784 .38245 Metetra
.664 .741 .907 r
.33784 .38245 .34023 .3849 .34407 .38357 .34167 .38113 Metetra
.664 .741 .907 r
.34167 .38113 .34407 .38357 .34791 .38225 .34552 .3798 Metetra
.664 .741 .907 r
.34552 .3798 .34791 .38225 .35176 .38092 .34937 .37847 Metetra
.664 .741 .907 r
.34937 .37847 .35176 .38092 .35561 .37959 .35322 .37714 Metetra
.664 .741 .907 r
.35322 .37714 .35561 .37959 .35946 .37826 .35708 .3758 Metetra
.664 .741 .907 r
.35708 .3758 .35946 .37826 .36333 .37693 .36095 .37447 Metetra
.664 .741 .907 r
.36095 .37447 .36333 .37693 .3672 .3756 .36482 .37313 Metetra
.664 .741 .907 r
.36482 .37313 .3672 .3756 .37107 .37426 .3687 .37179 Metetra
.664 .741 .907 r
.3687 .37179 .37107 .37426 .37495 .37292 .37259 .37045 Metetra
.664 .741 .907 r
.37259 .37045 .37495 .37292 .37884 .37158 .37647 .3691 Metetra
.664 .741 .907 r
.37647 .3691 .37884 .37158 .38273 .37024 .38037 .36776 Metetra
.664 .741 .907 r
.38037 .36776 .38273 .37024 .38663 .3689 .38427 .36641 Metetra
.664 .741 .907 r
.38427 .36641 .38663 .3689 .39053 .36755 .38818 .36506 Metetra
.664 .741 .907 r
.38818 .36506 .39053 .36755 .39444 .3662 .39209 .36371 Metetra
.664 .741 .907 r
.39209 .36371 .39444 .3662 .39835 .36485 .396 .36236 Metetra
.664 .741 .907 r
.396 .36236 .39835 .36485 .40227 .3635 .39993 .361 Metetra
.957 .682 .473 r
.39993 .361 .40227 .3635 .40568 .37585 .39516 .58826 Metetra
.536 .31 .519 r
.39516 .58826 .40568 .37585 .40189 .58934 .39937 .58698 Metetra
.946 .728 .576 r
.39937 .58698 .40189 .58934 .4061 .58806 .4045 .56025 Metetra
.794 .554 .575 r
.4045 .56025 .4061 .58806 .41167 .54674 .40983 .52572 Metetra
.771 .544 .59 r
.40983 .52572 .41167 .54674 .41671 .51884 .41465 .50457 Metetra
.777 .564 .611 r
.41465 .50457 .41671 .51884 .42138 .50068 .41922 .4898 Metetra
.778 .58 .632 r
.41922 .4898 .42138 .50068 .42587 .48755 .42365 .47866 Metetra
.776 .594 .653 r
.42365 .47866 .42587 .48755 .43026 .47743 .428 .46981 Metetra
.772 .605 .672 r
.428 .46981 .43026 .47743 .43457 .46927 .43229 .46252 Metetra
.768 .616 .69 r
.43229 .46252 .43457 .46927 .43883 .46247 .43654 .45635 Metetra
.762 .624 .707 r
.43654 .45635 .43883 .46247 .44307 .45667 .44077 .45102 Metetra
.756 .632 .723 r
.44077 .45102 .44307 .45667 .44728 .45162 .44497 .44633 Metetra
.75 .638 .737 r
.44497 .44633 .44728 .45162 .45147 .44716 .44916 .44215 Metetra
.743 .643 .75 r
.44916 .44215 .45147 .44716 .45566 .44317 .45334 .43838 Metetra
.736 .648 .761 r
.45334 .43838 .45566 .44317 .45983 .43957 .45752 .43496 Metetra
.729 .651 .772 r
.45752 .43496 .45983 .43957 .464 .4363 .46169 .43183 Metetra
.722 .654 .781 r
.46169 .43183 .464 .4363 .46817 .4333 .46585 .42894 Metetra
.715 .656 .79 r
.46585 .42894 .46817 .4333 .47233 .43054 .47002 .42628 Metetra
.708 .657 .798 r
.47002 .42628 .47233 .43054 .4765 .42798 .47419 .42381 Metetra
.701 .658 .804 r
.47419 .42381 .4765 .42798 .48066 .42562 .47835 .4215 Metetra
.694 .658 .811 r
.47835 .4215 .48066 .42562 .48483 .42342 .48252 .41936 Metetra
.687 .658 .816 r
.48252 .41936 .48483 .42342 .489 .42138 .48669 .41735 Metetra
.679 .657 .821 r
.48669 .41735 .489 .42138 .49317 .41948 .49087 .41549 Metetra
.672 .656 .826 r
.49087 .41549 .49317 .41948 .49735 .41772 .49505 .41374 Metetra
.665 .654 .83 r
.49505 .41374 .49735 .41772 .50153 .41609 .49923 .41213 Metetra
.657 .651 .833 r
.49923 .41213 .50153 .41609 .50571 .41459 .50342 .41062 Metetra
.649 .648 .836 r
.50342 .41062 .50571 .41459 .5099 .41321 .50761 .40924 Metetra
.64 .645 .839 r
.50761 .40924 .5099 .41321 .5141 .41195 .51181 .40798 Metetra
.631 .64 .841 r
.51181 .40798 .5141 .41195 .5183 .41083 .51601 .40683 Metetra
.622 .635 .843 r
.51601 .40683 .5183 .41083 .52252 .40983 .52023 .4058 Metetra
.612 .629 .844 r
.52023 .4058 .52252 .40983 .52673 .40897 .52445 .40491 Metetra
.601 .622 .845 r
.52445 .40491 .52673 .40897 .53096 .40826 .52867 .40415 Metetra
.589 .614 .845 r
.52867 .40415 .53096 .40826 .53519 .40771 .53291 .40353 Metetra
.576 .605 .845 r
.53291 .40353 .53519 .40771 .53944 .40732 .53716 .40307 Metetra
.561 .594 .844 r
.53716 .40307 .53944 .40732 .54369 .40712 .54141 .40279 Metetra
.544 .581 .842 r
.54141 .40279 .54369 .40712 .54796 .40714 .54568 .4027 Metetra
.525 .566 .839 r
.54568 .4027 .54796 .40714 .55224 .4074 .54996 .40283 Metetra
.503 .548 .835 r
.54996 .40283 .55224 .4074 .55653 .40793 .55425 .40321 Metetra
.478 .526 .829 r
.55425 .40321 .55653 .40793 .56084 .4088 .55855 .40389 Metetra
.448 .501 .821 r
.55855 .40389 .56084 .4088 .56516 .41006 .56288 .40492 Metetra
.413 .47 .81 r
.56288 .40492 .56516 .41006 .56951 .4118 .56722 .40637 Metetra
.371 .433 .795 r
.56722 .40637 .56951 .4118 .57388 .41415 .57158 .40834 Metetra
.32 .387 .775 r
.57158 .40834 .57388 .41415 .57828 .41726 .57597 .41097 Metetra
.258 .331 .748 r
.57597 .41097 .57828 .41726 .58271 .42138 .58039 .41445 Metetra
.183 .262 .711 r
.58039 .41445 .58271 .42138 .5872 .4269 .58485 .41907 Metetra
.092 .177 .661 r
.58485 .41907 .5872 .4269 .59175 .43441 .58937 .42528 Metetra
0 .076 .595 r
.58937 .42528 .59175 .43441 .5964 .44499 .59396 .43382 Metetra
0 0 .51 r
.59396 .43382 .5964 .44499 .60121 .4607 .59867 .44607 Metetra
0 0 .405 r
.59867 .44607 .60121 .4607 .60632 .48635 .60359 .46484 Metetra
0 0 .282 r
.60359 .46484 .60632 .48635 .61186 .52575 .60891 .49726 Metetra
.049 .009 .485 r
.60891 .49726 .61186 .52575 .61641 .52437 .61412 .52182 Metetra
.645 .763 .934 r
.61412 .52182 .61641 .52437 .61469 .3043 .61868 .52044 Metetra
0 0 .34 r
.61868 .52044 .61469 .3043 .61853 .28893 .61639 .28623 Metetra
.664 .741 .907 r
.61639 .28623 .61853 .28893 .62277 .28747 .62065 .28476 Metetra
.664 .741 .907 r
.62065 .28476 .62277 .28747 .62703 .286 .6249 .28329 Metetra
.664 .741 .907 r
.6249 .28329 .62703 .286 .63129 .28453 .62917 .28181 Metetra
.664 .741 .907 r
.62917 .28181 .63129 .28453 .63556 .28306 .63344 .28034 Metetra
.664 .741 .907 r
.63344 .28034 .63556 .28306 .63983 .28159 .63772 .27886 Metetra
.664 .741 .907 r
.63772 .27886 .63983 .28159 .64411 .28011 .642 .27738 Metetra
.664 .741 .907 r
.642 .27738 .64411 .28011 .6484 .27863 .64629 .2759 Metetra
.664 .741 .907 r
.64629 .2759 .6484 .27863 .65269 .27715 .65059 .27441 Metetra
.664 .741 .907 r
.65059 .27441 .65269 .27715 .65699 .27567 .6549 .27293 Metetra
.664 .741 .907 r
.6549 .27293 .65699 .27567 .6613 .27418 .65921 .27144 Metetra
.664 .741 .907 r
.65921 .27144 .6613 .27418 .66561 .2727 .66352 .26994 Metetra
.664 .741 .907 r
.66352 .26994 .66561 .2727 .66993 .27121 .66785 .26845 Metetra
.664 .741 .907 r
.66785 .26845 .66993 .27121 .67425 .26972 .67218 .26696 Metetra
.664 .741 .907 r
.67218 .26696 .67425 .26972 .67859 .26822 .67652 .26546 Metetra
.664 .741 .907 r
.67652 .26546 .67859 .26822 .68293 .26672 .68086 .26396 Metetra
.664 .741 .907 r
.68086 .26396 .68293 .26672 .68727 .26523 .68521 .26245 Metetra
.664 .741 .907 r
.68521 .26245 .68727 .26523 .69162 .26373 .68957 .26095 Metetra
.664 .741 .907 r
.68957 .26095 .69162 .26373 .69598 .26222 .69393 .25944 Metetra
.664 .741 .907 r
.69393 .25944 .69598 .26222 .70035 .26072 .6983 .25793 Metetra
.664 .741 .907 r
.6983 .25793 .70035 .26072 .70472 .25921 .70268 .25642 Metetra
.664 .741 .907 r
.70268 .25642 .70472 .25921 .7091 .2577 .70707 .2549 Metetra
.664 .741 .907 r
.70707 .2549 .7091 .2577 .71349 .25619 .71146 .25339 Metetra
.664 .741 .907 r
.71146 .25339 .71349 .25619 .71788 .25467 .71585 .25187 Metetra
.664 .741 .907 r
.71585 .25187 .71788 .25467 .72228 .25315 .72026 .25035 Metetra
.664 .741 .907 r
.72026 .25035 .72228 .25315 .72669 .25163 .72467 .24882 Metetra
.664 .741 .907 r
.72467 .24882 .72669 .25163 .7311 .25011 .72909 .2473 Metetra
.664 .741 .907 r
.72909 .2473 .7311 .25011 .73552 .24859 .73351 .24577 Metetra
.664 .741 .907 r
.73351 .24577 .73552 .24859 .73995 .24706 .73795 .24424 Metetra
.664 .741 .907 r
.73795 .24424 .73995 .24706 .74438 .24553 .74238 .2427 Metetra
.664 .741 .907 r
.74238 .2427 .74438 .24553 .74883 .244 .74683 .24117 Metetra
.664 .741 .907 r
.74683 .24117 .74883 .244 .75327 .24247 .75128 .23963 Metetra
.664 .741 .907 r
.75128 .23963 .75327 .24247 .75773 .24093 .75574 .23809 Metetra
.664 .741 .907 r
.75574 .23809 .75773 .24093 .76219 .23939 .76021 .23655 Metetra
.664 .741 .907 r
.76021 .23655 .76219 .23939 .76666 .23785 .76468 .235 Metetra
.664 .741 .907 r
.76468 .235 .76666 .23785 .77113 .23631 .76916 .23345 Metetra
.664 .741 .907 r
.76916 .23345 .77113 .23631 .77562 .23476 .77365 .2319 Metetra
.664 .741 .907 r
.77365 .2319 .77562 .23476 .78011 .23321 .77815 .23035 Metetra
.664 .741 .907 r
.77815 .23035 .78011 .23321 .7846 .23166 .78265 .22879 Metetra
.664 .741 .907 r
.78265 .22879 .7846 .23166 .78911 .23011 .78716 .22724 Metetra
.664 .741 .907 r
.78716 .22724 .78911 .23011 .79362 .22855 .79167 .22568 Metetra
.664 .741 .907 r
.79167 .22568 .79362 .22855 .79814 .227 .7962 .22411 Metetra
.664 .741 .907 r
.7962 .22411 .79814 .227 .80266 .22544 .80072 .22255 Metetra
.664 .741 .907 r
.80072 .22255 .80266 .22544 .80719 .22387 .80526 .22098 Metetra
.664 .741 .907 r
.80526 .22098 .80719 .22387 .81173 .22231 .80981 .21941 Metetra
.664 .741 .907 r
.80981 .21941 .81173 .22231 .81628 .22074 .81436 .21784 Metetra
.664 .741 .907 r
.81436 .21784 .81628 .22074 .82083 .21917 .81892 .21627 Metetra
.664 .741 .907 r
.81892 .21627 .82083 .21917 .82539 .2176 .82348 .21469 Metetra
.664 .741 .907 r
.82348 .21469 .82539 .2176 .82996 .21602 .82805 .21311 Metetra
.664 .741 .907 r
.21535 .42156 .21786 .4239 .22152 .42263 .21902 .42029 Metetra
.664 .741 .907 r
.21902 .42029 .22152 .42263 .2252 .42136 .2227 .41902 Metetra
.664 .741 .907 r
.2227 .41902 .2252 .42136 .22887 .42009 .22638 .41774 Metetra
.664 .741 .907 r
.22638 .41774 .22887 .42009 .23256 .41882 .23006 .41647 Metetra
.664 .741 .907 r
.23006 .41647 .23256 .41882 .23625 .41755 .23375 .41519 Metetra
.664 .741 .907 r
.23375 .41519 .23625 .41755 .23994 .41627 .23745 .41391 Metetra
.664 .741 .907 r
.23745 .41391 .23994 .41627 .24364 .41499 .24115 .41263 Metetra
.664 .741 .907 r
.24115 .41263 .24364 .41499 .24734 .41371 .24486 .41135 Metetra
.664 .741 .907 r
.24486 .41135 .24734 .41371 .25105 .41243 .24857 .41006 Metetra
.664 .741 .907 r
.24857 .41006 .25105 .41243 .25476 .41115 .25229 .40878 Metetra
.664 .741 .907 r
.25229 .40878 .25476 .41115 .25848 .40986 .25601 .40749 Metetra
.664 .741 .907 r
.25601 .40749 .25848 .40986 .26221 .40858 .25974 .4062 Metetra
.664 .741 .907 r
.25974 .4062 .26221 .40858 .26594 .40729 .26347 .4049 Metetra
.664 .741 .907 r
.26347 .4049 .26594 .40729 .26967 .406 .26721 .40361 Metetra
.664 .741 .907 r
.26721 .40361 .26967 .406 .27342 .40471 .27096 .40232 Metetra
.664 .741 .907 r
.27096 .40232 .27342 .40471 .27716 .40341 .27471 .40102 Metetra
.664 .741 .907 r
.27471 .40102 .27716 .40341 .28091 .40212 .27846 .39972 Metetra
.664 .741 .907 r
.27846 .39972 .28091 .40212 .28467 .40082 .28222 .39842 Metetra
.664 .741 .907 r
.28222 .39842 .28467 .40082 .28843 .39952 .28599 .39711 Metetra
.664 .741 .907 r
.28599 .39711 .28843 .39952 .2922 .39822 .28976 .39581 Metetra
.664 .741 .907 r
.28976 .39581 .2922 .39822 .29597 .39691 .29353 .3945 Metetra
.664 .741 .907 r
.29353 .3945 .29597 .39691 .29975 .39561 .29731 .39319 Metetra
.664 .741 .907 r
.29731 .39319 .29975 .39561 .30353 .3943 .3011 .39188 Metetra
.664 .741 .907 r
.3011 .39188 .30353 .3943 .30732 .39299 .30489 .39057 Metetra
.664 .741 .907 r
.30489 .39057 .30732 .39299 .31112 .39168 .30869 .38926 Metetra
.664 .741 .907 r
.30869 .38926 .31112 .39168 .31492 .39037 .3125 .38794 Metetra
.664 .741 .907 r
.3125 .38794 .31492 .39037 .31872 .38905 .3163 .38662 Metetra
.664 .741 .907 r
.3163 .38662 .31872 .38905 .32254 .38774 .32012 .3853 Metetra
.664 .741 .907 r
.32012 .3853 .32254 .38774 .32635 .38642 .32394 .38398 Metetra
.664 .741 .907 r
.32394 .38398 .32635 .38642 .33017 .3851 .32776 .38266 Metetra
.664 .741 .907 r
.32776 .38266 .33017 .3851 .334 .38378 .3316 .38133 Metetra
.664 .741 .907 r
.3316 .38133 .334 .38378 .33784 .38245 .33543 .38 Metetra
.664 .741 .907 r
.33543 .38 .33784 .38245 .34167 .38113 .33927 .37867 Metetra
.664 .741 .907 r
.33927 .37867 .34167 .38113 .34552 .3798 .34312 .37734 Metetra
.664 .741 .907 r
.34312 .37734 .34552 .3798 .34937 .37847 .34698 .37601 Metetra
.664 .741 .907 r
.34698 .37601 .34937 .37847 .35322 .37714 .35083 .37467 Metetra
.664 .741 .907 r
.35083 .37467 .35322 .37714 .35708 .3758 .3547 .37334 Metetra
.664 .741 .907 r
.3547 .37334 .35708 .3758 .36095 .37447 .35857 .372 Metetra
.664 .741 .907 r
.35857 .372 .36095 .37447 .36482 .37313 .36244 .37065 Metetra
.664 .741 .907 r
.36244 .37065 .36482 .37313 .3687 .37179 .36633 .36931 Metetra
.664 .741 .907 r
.36633 .36931 .3687 .37179 .37259 .37045 .37021 .36797 Metetra
.664 .741 .907 r
.37021 .36797 .37259 .37045 .37647 .3691 .37411 .36662 Metetra
.664 .741 .907 r
.37411 .36662 .37647 .3691 .38037 .36776 .378 .36527 Metetra
.664 .741 .907 r
.378 .36527 .38037 .36776 .38427 .36641 .38191 .36392 Metetra
.664 .741 .907 r
.38191 .36392 .38427 .36641 .38818 .36506 .38582 .36257 Metetra
.664 .741 .907 r
.38582 .36257 .38818 .36506 .39209 .36371 .38973 .36121 Metetra
.664 .741 .907 r
.38973 .36121 .39209 .36371 .396 .36236 .39365 .35985 Metetra
.664 .741 .907 r
.39365 .35985 .396 .36236 .39993 .361 .39758 .3585 Metetra
.957 .682 .473 r
.39758 .3585 .39993 .361 .39516 .58826 .39264 .5859 Metetra
.943 .733 .591 r
.39264 .5859 .39516 .58826 .39937 .58698 .39766 .56323 Metetra
.792 .557 .581 r
.39766 .56323 .39937 .58698 .4045 .56025 .40285 .5344 Metetra
.766 .534 .583 r
.40285 .5344 .4045 .56025 .40983 .52572 .40786 .50933 Metetra
.775 .556 .603 r
.40786 .50933 .40983 .52572 .41465 .50457 .41253 .49255 Metetra
.777 .573 .624 r
.41253 .49255 .41465 .50457 .41922 .4898 .41702 .48021 Metetra
.777 .588 .645 r
.41702 .48021 .41922 .4898 .42365 .47866 .42141 .47059 Metetra
.774 .601 .664 r
.42141 .47059 .42365 .47866 .428 .46981 .42573 .46275 Metetra
.77 .612 .683 r
.42573 .46275 .428 .46981 .43229 .46252 .43 .45618 Metetra
.765 .621 .701 r
.43 .45618 .43229 .46252 .43654 .45635 .43424 .45054 Metetra
.759 .629 .717 r
.43424 .45054 .43654 .45635 .44077 .45102 .43846 .4456 Metetra
.753 .636 .732 r
.43846 .4456 .44077 .45102 .44497 .44633 .44266 .44121 Metetra
.746 .642 .745 r
.44266 .44121 .44497 .44633 .44916 .44215 .44684 .43728 Metetra
.74 .647 .757 r
.44684 .43728 .44916 .44215 .45334 .43838 .45102 .43371 Metetra
.733 .651 .768 r
.45102 .43371 .45334 .43838 .45752 .43496 .4552 .43044 Metetra
.726 .654 .778 r
.4552 .43044 .45752 .43496 .46169 .43183 .45937 .42744 Metetra
.719 .657 .787 r
.45937 .42744 .46169 .43183 .46585 .42894 .46353 .42466 Metetra
.712 .658 .795 r
.46353 .42466 .46585 .42894 .47002 .42628 .4677 .42209 Metetra
.706 .66 .802 r
.4677 .42209 .47002 .42628 .47419 .42381 .47187 .41968 Metetra
.699 .66 .808 r
.47187 .41968 .47419 .42381 .47835 .4215 .47604 .41744 Metetra
.692 .661 .814 r
.47604 .41744 .47835 .4215 .48252 .41936 .48021 .41534 Metetra
.685 .66 .819 r
.48021 .41534 .48252 .41936 .48669 .41735 .48438 .41337 Metetra
.678 .659 .824 r
.48438 .41337 .48669 .41735 .49087 .41549 .48856 .41153 Metetra
.671 .658 .828 r
.48856 .41153 .49087 .41549 .49505 .41374 .49274 .4098 Metetra
.664 .656 .832 r
.49274 .4098 .49505 .41374 .49923 .41213 .49692 .4082 Metetra
.657 .654 .835 r
.49692 .4082 .49923 .41213 .50342 .41062 .50111 .4067 Metetra
.649 .651 .838 r
.50111 .4067 .50342 .41062 .50761 .40924 .50531 .40531 Metetra
.641 .647 .841 r
.50531 .40531 .50761 .40924 .51181 .40798 .50951 .40403 Metetra
.633 .643 .843 r
.50951 .40403 .51181 .40798 .51601 .40683 .51372 .40287 Metetra
.624 .638 .844 r
.51372 .40287 .51601 .40683 .52023 .4058 .51793 .40182 Metetra
.614 .633 .846 r
.51793 .40182 .52023 .4058 .52445 .40491 .52216 .40088 Metetra
.604 .626 .847 r
.52216 .40088 .52445 .40491 .52867 .40415 .52639 .40008 Metetra
.593 .619 .847 r
.52639 .40008 .52867 .40415 .53291 .40353 .53062 .39941 Metetra
.581 .61 .847 r
.53062 .39941 .53291 .40353 .53716 .40307 .53487 .39888 Metetra
.567 .6 .846 r
.53487 .39888 .53716 .40307 .54141 .40279 .53913 .39852 Metetra
.552 .588 .844 r
.53913 .39852 .54141 .40279 .54568 .4027 .54339 .39833 Metetra
.534 .575 .842 r
.54339 .39833 .54568 .4027 .54996 .40283 .54767 .39835 Metetra
.514 .558 .838 r
.54767 .39835 .54996 .40283 .55425 .40321 .55196 .39859 Metetra
.492 .539 .833 r
.55196 .39859 .55425 .40321 .55855 .40389 .55627 .3991 Metetra
.465 .516 .827 r
.55627 .3991 .55855 .40389 .56288 .40492 .56059 .39992 Metetra
.433 .489 .817 r
.56059 .39992 .56288 .40492 .56722 .40637 .56492 .40112 Metetra
.396 .456 .805 r
.56492 .40112 .56722 .40637 .57158 .40834 .56928 .40277 Metetra
.351 .415 .788 r
.56928 .40277 .57158 .40834 .57597 .41097 .57366 .40499 Metetra
.297 .366 .765 r
.57366 .40499 .57597 .41097 .58039 .41445 .57807 .40792 Metetra
.23 .305 .735 r
.57807 .40792 .58039 .41445 .58485 .41907 .58251 .4118 Metetra
.15 .231 .693 r
.58251 .4118 .58485 .41907 .58937 .42528 .587 .41697 Metetra
.053 .14 .637 r
.587 .41697 .58937 .42528 .59396 .43382 .59156 .42397 Metetra
0 .033 .565 r
.59156 .42397 .59396 .43382 .59867 .44607 .5962 .43373 Metetra
0 0 .473 r
.5962 .43373 .59867 .44607 .60359 .46484 .60099 .44803 Metetra
0 0 .362 r
.60099 .44803 .60359 .46484 .60891 .49726 .60603 .47079 Metetra
0 0 .448 r
.60603 .47079 .60891 .49726 .61412 .52182 .61125 .49745 Metetra
.067 .031 .503 r
.61125 .49745 .61412 .52182 .61868 .52044 .61639 .51788 Metetra
.974 .691 .426 r
.61639 .51788 .61868 .52044 .61639 .28623 .61426 .28351 Metetra
.664 .741 .907 r
.61426 .28351 .61639 .28623 .62065 .28476 .61851 .28204 Metetra
.664 .741 .907 r
.61851 .28204 .62065 .28476 .6249 .28329 .62278 .28056 Metetra
.664 .741 .907 r
.62278 .28056 .6249 .28329 .62917 .28181 .62704 .27909 Metetra
.664 .741 .907 r
.62704 .27909 .62917 .28181 .63344 .28034 .63132 .27761 Metetra
.664 .741 .907 r
.63132 .27761 .63344 .28034 .63772 .27886 .6356 .27612 Metetra
.664 .741 .907 r
.6356 .27612 .63772 .27886 .642 .27738 .63989 .27464 Metetra
.664 .741 .907 r
.63989 .27464 .642 .27738 .64629 .2759 .64419 .27315 Metetra
.664 .741 .907 r
.64419 .27315 .64629 .2759 .65059 .27441 .64849 .27167 Metetra
.664 .741 .907 r
.64849 .27167 .65059 .27441 .6549 .27293 .6528 .27017 Metetra
.664 .741 .907 r
.6528 .27017 .6549 .27293 .65921 .27144 .65711 .26868 Metetra
.664 .741 .907 r
.65711 .26868 .65921 .27144 .66352 .26994 .66143 .26719 Metetra
.664 .741 .907 r
.66143 .26719 .66352 .26994 .66785 .26845 .66576 .26569 Metetra
.664 .741 .907 r
.66576 .26569 .66785 .26845 .67218 .26696 .6701 .26419 Metetra
.664 .741 .907 r
.6701 .26419 .67218 .26696 .67652 .26546 .67444 .26268 Metetra
.664 .741 .907 r
.67444 .26268 .67652 .26546 .68086 .26396 .67879 .26118 Metetra
.664 .741 .907 r
.67879 .26118 .68086 .26396 .68521 .26245 .68314 .25967 Metetra
.664 .741 .907 r
.68314 .25967 .68521 .26245 .68957 .26095 .68751 .25816 Metetra
.664 .741 .907 r
.68751 .25816 .68957 .26095 .69393 .25944 .69187 .25665 Metetra
.664 .741 .907 r
.69187 .25665 .69393 .25944 .6983 .25793 .69625 .25514 Metetra
.664 .741 .907 r
.69625 .25514 .6983 .25793 .70268 .25642 .70063 .25362 Metetra
.664 .741 .907 r
.70063 .25362 .70268 .25642 .70707 .2549 .70502 .2521 Metetra
.664 .741 .907 r
.70502 .2521 .70707 .2549 .71146 .25339 .70942 .25058 Metetra
.664 .741 .907 r
.70942 .25058 .71146 .25339 .71585 .25187 .71382 .24906 Metetra
.664 .741 .907 r
.71382 .24906 .71585 .25187 .72026 .25035 .71823 .24753 Metetra
.664 .741 .907 r
.71823 .24753 .72026 .25035 .72467 .24882 .72265 .246 Metetra
.664 .741 .907 r
.72265 .246 .72467 .24882 .72909 .2473 .72707 .24447 Metetra
.664 .741 .907 r
.72707 .24447 .72909 .2473 .73351 .24577 .7315 .24294 Metetra
.664 .741 .907 r
.7315 .24294 .73351 .24577 .73795 .24424 .73594 .2414 Metetra
.664 .741 .907 r
.73594 .2414 .73795 .24424 .74238 .2427 .74038 .23987 Metetra
.664 .741 .907 r
.74038 .23987 .74238 .2427 .74683 .24117 .74483 .23833 Metetra
.664 .741 .907 r
.74483 .23833 .74683 .24117 .75128 .23963 .74929 .23678 Metetra
.664 .741 .907 r
.74929 .23678 .75128 .23963 .75574 .23809 .75375 .23524 Metetra
.664 .741 .907 r
.75375 .23524 .75574 .23809 .76021 .23655 .75822 .23369 Metetra
.664 .741 .907 r
.75822 .23369 .76021 .23655 .76468 .235 .7627 .23214 Metetra
.664 .741 .907 r
.7627 .23214 .76468 .235 .76916 .23345 .76719 .23059 Metetra
.664 .741 .907 r
.76719 .23059 .76916 .23345 .77365 .2319 .77168 .22903 Metetra
.664 .741 .907 r
.77168 .22903 .77365 .2319 .77815 .23035 .77618 .22748 Metetra
.664 .741 .907 r
.77618 .22748 .77815 .23035 .78265 .22879 .78069 .22592 Metetra
.664 .741 .907 r
.78069 .22592 .78265 .22879 .78716 .22724 .7852 .22436 Metetra
.664 .741 .907 r
.7852 .22436 .78716 .22724 .79167 .22568 .78972 .22279 Metetra
.664 .741 .907 r
.78972 .22279 .79167 .22568 .7962 .22411 .79425 .22122 Metetra
.664 .741 .907 r
.79425 .22122 .7962 .22411 .80072 .22255 .79878 .21965 Metetra
.664 .741 .907 r
.79878 .21965 .80072 .22255 .80526 .22098 .80333 .21808 Metetra
.664 .741 .907 r
.80333 .21808 .80526 .22098 .80981 .21941 .80787 .21651 Metetra
.664 .741 .907 r
.80787 .21651 .80981 .21941 .81436 .21784 .81243 .21493 Metetra
.664 .741 .907 r
.81243 .21493 .81436 .21784 .81892 .21627 .817 .21335 Metetra
.664 .741 .907 r
.817 .21335 .81892 .21627 .82348 .21469 .82157 .21177 Metetra
.664 .741 .907 r
.82157 .21177 .82348 .21469 .82805 .21311 .82614 .21019 Metetra
.664 .741 .907 r
.21284 .41921 .21535 .42156 .21902 .42029 .21651 .41794 Metetra
.664 .741 .907 r
.21651 .41794 .21902 .42029 .2227 .41902 .22019 .41666 Metetra
.664 .741 .907 r
.22019 .41666 .2227 .41902 .22638 .41774 .22387 .41539 Metetra
.664 .741 .907 r
.22387 .41539 .22638 .41774 .23006 .41647 .22756 .41411 Metetra
.664 .741 .907 r
.22756 .41411 .23006 .41647 .23375 .41519 .23126 .41283 Metetra
.664 .741 .907 r
.23126 .41283 .23375 .41519 .23745 .41391 .23496 .41154 Metetra
.664 .741 .907 r
.23496 .41154 .23745 .41391 .24115 .41263 .23866 .41026 Metetra
.664 .741 .907 r
.23866 .41026 .24115 .41263 .24486 .41135 .24237 .40897 Metetra
.664 .741 .907 r
.24237 .40897 .24486 .41135 .24857 .41006 .24609 .40769 Metetra
.664 .741 .907 r
.24609 .40769 .24857 .41006 .25229 .40878 .24981 .4064 Metetra
.664 .741 .907 r
.24981 .4064 .25229 .40878 .25601 .40749 .25353 .4051 Metetra
.664 .741 .907 r
.25353 .4051 .25601 .40749 .25974 .4062 .25726 .40381 Metetra
.664 .741 .907 r
.25726 .40381 .25974 .4062 .26347 .4049 .261 .40251 Metetra
.664 .741 .907 r
.261 .40251 .26347 .4049 .26721 .40361 .26474 .40122 Metetra
.664 .741 .907 r
.26474 .40122 .26721 .40361 .27096 .40232 .26849 .39992 Metetra
.664 .741 .907 r
.26849 .39992 .27096 .40232 .27471 .40102 .27224 .39862 Metetra
.664 .741 .907 r
.27224 .39862 .27471 .40102 .27846 .39972 .276 .39731 Metetra
.664 .741 .907 r
.276 .39731 .27846 .39972 .28222 .39842 .27976 .39601 Metetra
.664 .741 .907 r
.27976 .39601 .28222 .39842 .28599 .39711 .28353 .3947 Metetra
.664 .741 .907 r
.28353 .3947 .28599 .39711 .28976 .39581 .28731 .3934 Metetra
.664 .741 .907 r
.28731 .3934 .28976 .39581 .29353 .3945 .29109 .39208 Metetra
.664 .741 .907 r
.29109 .39208 .29353 .3945 .29731 .39319 .29487 .39077 Metetra
.664 .741 .907 r
.29487 .39077 .29731 .39319 .3011 .39188 .29866 .38946 Metetra
.664 .741 .907 r
.29866 .38946 .3011 .39188 .30489 .39057 .30246 .38814 Metetra
.664 .741 .907 r
.30246 .38814 .30489 .39057 .30869 .38926 .30626 .38682 Metetra
.664 .741 .907 r
.30626 .38682 .30869 .38926 .3125 .38794 .31007 .38551 Metetra
.664 .741 .907 r
.31007 .38551 .3125 .38794 .3163 .38662 .31388 .38418 Metetra
.664 .741 .907 r
.31388 .38418 .3163 .38662 .32012 .3853 .3177 .38286 Metetra
.664 .741 .907 r
.3177 .38286 .32012 .3853 .32394 .38398 .32152 .38153 Metetra
.664 .741 .907 r
.32152 .38153 .32394 .38398 .32776 .38266 .32535 .38021 Metetra
.664 .741 .907 r
.32535 .38021 .32776 .38266 .3316 .38133 .32918 .37888 Metetra
.664 .741 .907 r
.32918 .37888 .3316 .38133 .33543 .38 .33302 .37755 Metetra
.664 .741 .907 r
.33302 .37755 .33543 .38 .33927 .37867 .33687 .37621 Metetra
.664 .741 .907 r
.33687 .37621 .33927 .37867 .34312 .37734 .34072 .37488 Metetra
.664 .741 .907 r
.34072 .37488 .34312 .37734 .34698 .37601 .34458 .37354 Metetra
.664 .741 .907 r
.34458 .37354 .34698 .37601 .35083 .37467 .34844 .3722 Metetra
.664 .741 .907 r
.34844 .3722 .35083 .37467 .3547 .37334 .35231 .37086 Metetra
.664 .741 .907 r
.35231 .37086 .3547 .37334 .35857 .372 .35618 .36952 Metetra
.664 .741 .907 r
.35618 .36952 .35857 .372 .36244 .37065 .36006 .36817 Metetra
.664 .741 .907 r
.36006 .36817 .36244 .37065 .36633 .36931 .36394 .36683 Metetra
.664 .741 .907 r
.36394 .36683 .36633 .36931 .37021 .36797 .36783 .36548 Metetra
.664 .741 .907 r
.36783 .36548 .37021 .36797 .37411 .36662 .37173 .36413 Metetra
.664 .741 .907 r
.37173 .36413 .37411 .36662 .378 .36527 .37563 .36277 Metetra
.664 .741 .907 r
.37563 .36277 .378 .36527 .38191 .36392 .37954 .36142 Metetra
.664 .741 .907 r
.37954 .36142 .38191 .36392 .38582 .36257 .38345 .36006 Metetra
.664 .741 .907 r
.38345 .36006 .38582 .36257 .38973 .36121 .38737 .3587 Metetra
.664 .741 .907 r
.38737 .3587 .38973 .36121 .39365 .35985 .3913 .35734 Metetra
.957 .682 .474 r
.3913 .35734 .39365 .35985 .39758 .3585 .38589 .58482 Metetra
.535 .309 .519 r
.38589 .58482 .39758 .3585 .39264 .5859 .3901 .58353 Metetra
.953 .71 .533 r
.3901 .58353 .39264 .5859 .39766 .56323 .39631 .53048 Metetra
.759 .523 .575 r
.39631 .53048 .39766 .56323 .40285 .5344 .40155 .5002 Metetra
.59 .389 .577 r
.40155 .5002 .40285 .5344 .40786 .50933 .40579 .49589 Metetra
.776 .566 .616 r
.40579 .49589 .40786 .50933 .41253 .49255 .41036 .48214 Metetra
.777 .582 .636 r
.41036 .48214 .41253 .49255 .41702 .48021 .41479 .47161 Metetra
.775 .596 .657 r
.41479 .47161 .41702 .48021 .42141 .47059 .41914 .46317 Metetra
.771 .607 .676 r
.41914 .46317 .42141 .47059 .42573 .46275 .42344 .45615 Metetra
.767 .618 .694 r
.42344 .45615 .42573 .46275 .43 .45618 .4277 .45017 Metetra
.761 .626 .711 r
.4277 .45017 .43 .45618 .43424 .45054 .43193 .44497 Metetra
.755 .634 .726 r
.43193 .44497 .43424 .45054 .43846 .4456 .43614 .44038 Metetra
.749 .64 .74 r
.43614 .44038 .43846 .4456 .44266 .44121 .44033 .43626 Metetra
.743 .646 .752 r
.44033 .43626 .44266 .44121 .44684 .43728 .44452 .43254 Metetra
.736 .65 .764 r
.44452 .43254 .44684 .43728 .45102 .43371 .4487 .42914 Metetra
.73 .654 .774 r
.4487 .42914 .45102 .43371 .4552 .43044 .45287 .42602 Metetra
.723 .657 .783 r
.45287 .42602 .4552 .43044 .45937 .42744 .45704 .42313 Metetra
.717 .659 .792 r
.45704 .42313 .45937 .42744 .46353 .42466 .46121 .42045 Metetra
.71 .661 .799 r
.46121 .42045 .46353 .42466 .4677 .42209 .46538 .41795 Metetra
.704 .662 .806 r
.46538 .41795 .4677 .42209 .47187 .41968 .46955 .41561 Metetra
.697 .662 .812 r
.46955 .41561 .47187 .41968 .47604 .41744 .47372 .41342 Metetra
.691 .663 .818 r
.47372 .41342 .47604 .41744 .48021 .41534 .47789 .41136 Metetra
.684 .662 .822 r
.47789 .41136 .48021 .41534 .48438 .41337 .48206 .40942 Metetra
.677 .661 .827 r
.48206 .40942 .48438 .41337 .48856 .41153 .48624 .40761 Metetra
.671 .66 .831 r
.48624 .40761 .48856 .41153 .49274 .4098 .49043 .4059 Metetra
.664 .658 .834 r
.49043 .4059 .49274 .4098 .49692 .4082 .49461 .4043 Metetra
.657 .656 .838 r
.49461 .4043 .49692 .4082 .50111 .4067 .49881 .40281 Metetra
.65 .653 .84 r
.49881 .40281 .50111 .4067 .50531 .40531 .50301 .40141 Metetra
.642 .65 .843 r
.50301 .40141 .50531 .40531 .50951 .40403 .50721 .40012 Metetra
.634 .646 .845 r
.50721 .40012 .50951 .40403 .51372 .40287 .51142 .39894 Metetra
.626 .642 .846 r
.51142 .39894 .51372 .40287 .51793 .40182 .51564 .39786 Metetra
.617 .636 .848 r
.51564 .39786 .51793 .40182 .52216 .40088 .51986 .3969 Metetra
.607 .63 .848 r
.51986 .3969 .52216 .40088 .52639 .40008 .52409 .39605 Metetra
.597 .623 .849 r
.52409 .39605 .52639 .40008 .53062 .39941 .52833 .39533 Metetra
.585 .615 .849 r
.52833 .39533 .53062 .39941 .53487 .39888 .53258 .39475 Metetra
.573 .606 .848 r
.53258 .39475 .53487 .39888 .53913 .39852 .53684 .39431 Metetra
.558 .595 .847 r
.53684 .39431 .53913 .39852 .54339 .39833 .54111 .39404 Metetra
.543 .583 .845 r
.54111 .39404 .54339 .39833 .54767 .39835 .54539 .39395 Metetra
.524 .568 .842 r
.54539 .39395 .54767 .39835 .55196 .39859 .54968 .39406 Metetra
.504 .551 .837 r
.54968 .39406 .55196 .39859 .55627 .3991 .55398 .39442 Metetra
.48 .53 .832 r
.55398 .39442 .55627 .3991 .56059 .39992 .5583 .39506 Metetra
.451 .506 .824 r
.5583 .39506 .56059 .39992 .56492 .40112 .56263 .39603 Metetra
.418 .476 .813 r
.56263 .39603 .56492 .40112 .56928 .40277 .56698 .3974 Metetra
.378 .441 .799 r
.56698 .3974 .56928 .40277 .57366 .40499 .57136 .39926 Metetra
.33 .397 .78 r
.57136 .39926 .57366 .40499 .57807 .40792 .57576 .40173 Metetra
.272 .344 .754 r
.57576 .40173 .57807 .40792 .58251 .4118 .58019 .405 Metetra
.201 .278 .72 r
.58019 .405 .58251 .4118 .587 .41697 .58465 .40933 Metetra
.116 .198 .674 r
.58465 .40933 .587 .41697 .59156 .42397 .58918 .41512 Metetra
.014 .102 .612 r
.58918 .41512 .59156 .42397 .5962 .43373 .59377 .42303 Metetra
0 0 .533 r
.59377 .42303 .5962 .43373 .60099 .44803 .59847 .43423 Metetra
.503 .379 .644 r
.59847 .43423 .60099 .44803 .60603 .47079 .60298 .43584 Metetra
.089 .025 .483 r
.60298 .43584 .60603 .47079 .61125 .49745 .60818 .46392 Metetra
0 0 .246 r
.60818 .46392 .61125 .49745 .61639 .51788 .61409 .51531 Metetra
.645 .763 .934 r
.61409 .51531 .61639 .51788 .61426 .28351 .61866 .51391 Metetra
0 0 .361 r
.61866 .51391 .61426 .28351 .61851 .28204 .61637 .27931 Metetra
.664 .741 .907 r
.61637 .27931 .61851 .28204 .62278 .28056 .62064 .27783 Metetra
.664 .741 .907 r
.62064 .27783 .62278 .28056 .62704 .27909 .62491 .27635 Metetra
.664 .741 .907 r
.62491 .27635 .62704 .27909 .63132 .27761 .62919 .27487 Metetra
.664 .741 .907 r
.62919 .27487 .63132 .27761 .6356 .27612 .63348 .27338 Metetra
.664 .741 .907 r
.63348 .27338 .6356 .27612 .63989 .27464 .63777 .27189 Metetra
.664 .741 .907 r
.63777 .27189 .63989 .27464 .64419 .27315 .64207 .2704 Metetra
.664 .741 .907 r
.64207 .2704 .64419 .27315 .64849 .27167 .64638 .26891 Metetra
.664 .741 .907 r
.64638 .26891 .64849 .27167 .6528 .27017 .65069 .26742 Metetra
.664 .741 .907 r
.65069 .26742 .6528 .27017 .65711 .26868 .65501 .26592 Metetra
.664 .741 .907 r
.65501 .26592 .65711 .26868 .66143 .26719 .65934 .26442 Metetra
.664 .741 .907 r
.65934 .26442 .66143 .26719 .66576 .26569 .66367 .26292 Metetra
.664 .741 .907 r
.66367 .26292 .66576 .26569 .6701 .26419 .66801 .26141 Metetra
.664 .741 .907 r
.66801 .26141 .6701 .26419 .67444 .26268 .67236 .2599 Metetra
.664 .741 .907 r
.67236 .2599 .67444 .26268 .67879 .26118 .67671 .2584 Metetra
.664 .741 .907 r
.67671 .2584 .67879 .26118 .68314 .25967 .68107 .25688 Metetra
.664 .741 .907 r
.68107 .25688 .68314 .25967 .68751 .25816 .68544 .25537 Metetra
.664 .741 .907 r
.68544 .25537 .68751 .25816 .69187 .25665 .68981 .25385 Metetra
.664 .741 .907 r
.68981 .25385 .69187 .25665 .69625 .25514 .69419 .25234 Metetra
.664 .741 .907 r
.69419 .25234 .69625 .25514 .70063 .25362 .69858 .25081 Metetra
.664 .741 .907 r
.69858 .25081 .70063 .25362 .70502 .2521 .70297 .24929 Metetra
.664 .741 .907 r
.70297 .24929 .70502 .2521 .70942 .25058 .70737 .24777 Metetra
.664 .741 .907 r
.70737 .24777 .70942 .25058 .71382 .24906 .71178 .24624 Metetra
.664 .741 .907 r
.71178 .24624 .71382 .24906 .71823 .24753 .71619 .24471 Metetra
.664 .741 .907 r
.71619 .24471 .71823 .24753 .72265 .246 .72061 .24318 Metetra
.664 .741 .907 r
.72061 .24318 .72265 .246 .72707 .24447 .72504 .24164 Metetra
.664 .741 .907 r
.72504 .24164 .72707 .24447 .7315 .24294 .72948 .2401 Metetra
.664 .741 .907 r
.72948 .2401 .7315 .24294 .73594 .2414 .73392 .23856 Metetra
.664 .741 .907 r
.73392 .23856 .73594 .2414 .74038 .23987 .73837 .23702 Metetra
.664 .741 .907 r
.73837 .23702 .74038 .23987 .74483 .23833 .74282 .23548 Metetra
.664 .741 .907 r
.74282 .23548 .74483 .23833 .74929 .23678 .74729 .23393 Metetra
.664 .741 .907 r
.74729 .23393 .74929 .23678 .75375 .23524 .75176 .23238 Metetra
.664 .741 .907 r
.75176 .23238 .75375 .23524 .75822 .23369 .75623 .23083 Metetra
.664 .741 .907 r
.75623 .23083 .75822 .23369 .7627 .23214 .76071 .22927 Metetra
.664 .741 .907 r
.76071 .22927 .7627 .23214 .76719 .23059 .76521 .22772 Metetra
.664 .741 .907 r
.76521 .22772 .76719 .23059 .77168 .22903 .7697 .22616 Metetra
.664 .741 .907 r
.7697 .22616 .77168 .22903 .77618 .22748 .77421 .2246 Metetra
.664 .741 .907 r
.77421 .2246 .77618 .22748 .78069 .22592 .77872 .22303 Metetra
.664 .741 .907 r
.77872 .22303 .78069 .22592 .7852 .22436 .78324 .22146 Metetra
.664 .741 .907 r
.78324 .22146 .7852 .22436 .78972 .22279 .78776 .2199 Metetra
.664 .741 .907 r
.78776 .2199 .78972 .22279 .79425 .22122 .7923 .21832 Metetra
.664 .741 .907 r
.7923 .21832 .79425 .22122 .79878 .21965 .79684 .21675 Metetra
.664 .741 .907 r
.79684 .21675 .79878 .21965 .80333 .21808 .80138 .21517 Metetra
.664 .741 .907 r
.80138 .21517 .80333 .21808 .80787 .21651 .80594 .2136 Metetra
.664 .741 .907 r
.80594 .2136 .80787 .21651 .81243 .21493 .8105 .21201 Metetra
.664 .741 .907 r
.8105 .21201 .81243 .21493 .817 .21335 .81507 .21043 Metetra
.664 .741 .907 r
.81507 .21043 .817 .21335 .82157 .21177 .81964 .20884 Metetra
.664 .741 .907 r
.81964 .20884 .82157 .21177 .82614 .21019 .82423 .20725 Metetra
.664 .741 .907 r
.21032 .41686 .21284 .41921 .21651 .41794 .214 .41558 Metetra
.664 .741 .907 r
.214 .41558 .21651 .41794 .22019 .41666 .21768 .4143 Metetra
.664 .741 .907 r
.21768 .4143 .22019 .41666 .22387 .41539 .22136 .41302 Metetra
.664 .741 .907 r
.22136 .41302 .22387 .41539 .22756 .41411 .22506 .41174 Metetra
.664 .741 .907 r
.22506 .41174 .22756 .41411 .23126 .41283 .22875 .41046 Metetra
.664 .741 .907 r
.22875 .41046 .23126 .41283 .23496 .41154 .23246 .40917 Metetra
.664 .741 .907 r
.23246 .40917 .23496 .41154 .23866 .41026 .23616 .40788 Metetra
.664 .741 .907 r
.23616 .40788 .23866 .41026 .24237 .40897 .23988 .40659 Metetra
.664 .741 .907 r
.23988 .40659 .24237 .40897 .24609 .40769 .2436 .4053 Metetra
.664 .741 .907 r
.2436 .4053 .24609 .40769 .24981 .4064 .24732 .40401 Metetra
.664 .741 .907 r
.24732 .40401 .24981 .4064 .25353 .4051 .25105 .40271 Metetra
.664 .741 .907 r
.25105 .40271 .25353 .4051 .25726 .40381 .25478 .40142 Metetra
.664 .741 .907 r
.25478 .40142 .25726 .40381 .261 .40251 .25852 .40012 Metetra
.664 .741 .907 r
.25852 .40012 .261 .40251 .26474 .40122 .26227 .39882 Metetra
.664 .741 .907 r
.26227 .39882 .26474 .40122 .26849 .39992 .26602 .39752 Metetra
.664 .741 .907 r
.26602 .39752 .26849 .39992 .27224 .39862 .26977 .39621 Metetra
.664 .741 .907 r
.26977 .39621 .27224 .39862 .276 .39731 .27353 .3949 Metetra
.664 .741 .907 r
.27353 .3949 .276 .39731 .27976 .39601 .2773 .3936 Metetra
.664 .741 .907 r
.2773 .3936 .27976 .39601 .28353 .3947 .28107 .39229 Metetra
.664 .741 .907 r
.28107 .39229 .28353 .3947 .28731 .3934 .28485 .39097 Metetra
.664 .741 .907 r
.28485 .39097 .28731 .3934 .29109 .39208 .28863 .38966 Metetra
.664 .741 .907 r
.28863 .38966 .29109 .39208 .29487 .39077 .29242 .38835 Metetra
.664 .741 .907 r
.29242 .38835 .29487 .39077 .29866 .38946 .29622 .38703 Metetra
.664 .741 .907 r
.29622 .38703 .29866 .38946 .30246 .38814 .30001 .38571 Metetra
.664 .741 .907 r
.30001 .38571 .30246 .38814 .30626 .38682 .30382 .38439 Metetra
.664 .741 .907 r
.30382 .38439 .30626 .38682 .31007 .38551 .30763 .38306 Metetra
.664 .741 .907 r
.30763 .38306 .31007 .38551 .31388 .38418 .31144 .38174 Metetra
.664 .741 .907 r
.31144 .38174 .31388 .38418 .3177 .38286 .31527 .38041 Metetra
.664 .741 .907 r
.31527 .38041 .3177 .38286 .32152 .38153 .31909 .37908 Metetra
.664 .741 .907 r
.31909 .37908 .32152 .38153 .32535 .38021 .32292 .37775 Metetra
.664 .741 .907 r
.32292 .37775 .32535 .38021 .32918 .37888 .32676 .37642 Metetra
.664 .741 .907 r
.32676 .37642 .32918 .37888 .33302 .37755 .33061 .37508 Metetra
.664 .741 .907 r
.33061 .37508 .33302 .37755 .33687 .37621 .33445 .37375 Metetra
.664 .741 .907 r
.33445 .37375 .33687 .37621 .34072 .37488 .33831 .37241 Metetra
.664 .741 .907 r
.33831 .37241 .34072 .37488 .34458 .37354 .34217 .37107 Metetra
.664 .741 .907 r
.34217 .37107 .34458 .37354 .34844 .3722 .34603 .36973 Metetra
.664 .741 .907 r
.34603 .36973 .34844 .3722 .35231 .37086 .34991 .36838 Metetra
.664 .741 .907 r
.34991 .36838 .35231 .37086 .35618 .36952 .35378 .36703 Metetra
.664 .741 .907 r
.35378 .36703 .35618 .36952 .36006 .36817 .35767 .36569 Metetra
.664 .741 .907 r
.35767 .36569 .36006 .36817 .36394 .36683 .36155 .36434 Metetra
.664 .741 .907 r
.36155 .36434 .36394 .36683 .36783 .36548 .36545 .36298 Metetra
.664 .741 .907 r
.36545 .36298 .36783 .36548 .37173 .36413 .36935 .36163 Metetra
.664 .741 .907 r
.36935 .36163 .37173 .36413 .37563 .36277 .37325 .36027 Metetra
.664 .741 .907 r
.37325 .36027 .37563 .36277 .37954 .36142 .37716 .35891 Metetra
.664 .741 .907 r
.37716 .35891 .37954 .36142 .38345 .36006 .38108 .35755 Metetra
.664 .741 .907 r
.38108 .35755 .38345 .36006 .38737 .3587 .385 .35619 Metetra
.664 .741 .907 r
.385 .35619 .38737 .3587 .3913 .35734 .38893 .35483 Metetra
.957 .682 .474 r
.38893 .35483 .3913 .35734 .38589 .58482 .38335 .58245 Metetra
.949 .718 .553 r
.38335 .58245 .38589 .58482 .3901 .58353 .38901 .5454 Metetra
.767 .526 .57 r
.38901 .5454 .3901 .58353 .39631 .53048 .39461 .5077 Metetra
.769 .539 .587 r
.39461 .5077 .39631 .53048 .40155 .5002 .39955 .48521 Metetra
.777 .561 .608 r
.39955 .48521 .40155 .5002 .40579 .49589 .4042 .46968 Metetra
.679 .466 .59 r
.4042 .46968 .40579 .49589 .41036 .48214 .40868 .45802 Metetra
.433 .284 .578 r
.40868 .45802 .41036 .48214 .41479 .47161 .41254 .46378 Metetra
.773 .603 .669 r
.41254 .46378 .41479 .47161 .41914 .46317 .41686 .45627 Metetra
.768 .614 .687 r
.41686 .45627 .41914 .46317 .42344 .45615 .42114 .44993 Metetra
.763 .623 .704 r
.42114 .44993 .42344 .45615 .4277 .45017 .42539 .44445 Metetra
.758 .631 .72 r
.42539 .44445 .4277 .45017 .43193 .44497 .42961 .43963 Metetra
.752 .638 .735 r
.42961 .43963 .43193 .44497 .43614 .44038 .43381 .43533 Metetra
.746 .644 .748 r
.43381 .43533 .43614 .44038 .44033 .43626 .438 .43145 Metetra
.74 .649 .759 r
.438 .43145 .44033 .43626 .44452 .43254 .44219 .42792 Metetra
.733 .653 .77 r
.44219 .42792 .44452 .43254 .4487 .42914 .44636 .42467 Metetra
.727 .657 .78 r
.44636 .42467 .4487 .42914 .45287 .42602 .45054 .42168 Metetra
.72 .659 .789 r
.45054 .42168 .45287 .42602 .45704 .42313 .45471 .4189 Metetra
.714 .661 .796 r
.45471 .4189 .45704 .42313 .46121 .42045 .45888 .4163 Metetra
.708 .663 .803 r
.45888 .4163 .46121 .42045 .46538 .41795 .46305 .41387 Metetra
.702 .664 .81 r
.46305 .41387 .46538 .41795 .46955 .41561 .46722 .41159 Metetra
.695 .664 .816 r
.46722 .41159 .46955 .41561 .47372 .41342 .47139 .40944 Metetra
.689 .664 .821 r
.47139 .40944 .47372 .41342 .47789 .41136 .47557 .40742 Metetra
.683 .664 .825 r
.47557 .40742 .47789 .41136 .48206 .40942 .47974 .40552 Metetra
.677 .663 .83 r
.47974 .40552 .48206 .40942 .48624 .40761 .48392 .40372 Metetra
.67 .662 .833 r
.48392 .40372 .48624 .40761 .49043 .4059 .48811 .40203 Metetra
.664 .66 .837 r
.48811 .40203 .49043 .4059 .49461 .4043 .4923 .40044 Metetra
.657 .658 .84 r
.4923 .40044 .49461 .4043 .49881 .40281 .4965 .39894 Metetra
.65 .656 .842 r
.4965 .39894 .49881 .40281 .50301 .40141 .5007 .39755 Metetra
.643 .653 .845 r
.5007 .39755 .50301 .40141 .50721 .40012 .5049 .39625 Metetra
.635 .649 .846 r
.5049 .39625 .50721 .40012 .51142 .39894 .50912 .39505 Metetra
.627 .645 .848 r
.50912 .39505 .51142 .39894 .51564 .39786 .51333 .39395 Metetra
.619 .64 .849 r
.51333 .39395 .51564 .39786 .51986 .3969 .51756 .39295 Metetra
.61 .634 .85 r
.51756 .39295 .51986 .3969 .52409 .39605 .52179 .39207 Metetra
.6 .628 .851 r
.52179 .39207 .52409 .39605 .52833 .39533 .52604 .3913 Metetra
.59 .62 .851 r
.52604 .3913 .52833 .39533 .53258 .39475 .53029 .39066 Metetra
.578 .612 .85 r
.53029 .39066 .53258 .39475 .53684 .39431 .53455 .39015 Metetra
.565 .602 .849 r
.53455 .39015 .53684 .39431 .54111 .39404 .53882 .3898 Metetra
.55 .59 .847 r
.53882 .3898 .54111 .39404 .54539 .39395 .54309 .38961 Metetra
.534 .577 .845 r
.54309 .38961 .54539 .39395 .54968 .39406 .54739 .38962 Metetra
.515 .561 .841 r
.54739 .38962 .54968 .39406 .55398 .39442 .55169 .38984 Metetra
.493 .543 .836 r
.55169 .38984 .55398 .39442 .5583 .39506 .556 .39031 Metetra
.468 .521 .829 r
.556 .39031 .5583 .39506 .56263 .39603 .56034 .39108 Metetra
.438 .495 .82 r
.56034 .39108 .56263 .39603 .56698 .3974 .56468 .3922 Metetra
.402 .463 .808 r
.56468 .3922 .56698 .3974 .57136 .39926 .56905 .39375 Metetra
.36 .424 .793 r
.56905 .39375 .57136 .39926 .57576 .40173 .57344 .39583 Metetra
.309 .378 .771 r
.57344 .39583 .57576 .40173 .58019 .405 .57786 .39859 Metetra
.247 .32 .742 r
.57786 .39859 .58019 .405 .58465 .40933 .58231 .40222 Metetra
.171 .25 .704 r
.58231 .40222 .58465 .40933 .58918 .41512 .58681 .40704 Metetra
.791 .613 .659 r
.58681 .40704 .58918 .41512 .59377 .42303 .59105 .3984 Metetra
.375 .246 .575 r
.59105 .3984 .59377 .42303 .59847 .43423 .59567 .40745 Metetra
.306 .192 .556 r
.59567 .40745 .59847 .43423 .60298 .43584 .60042 .42045 Metetra
0 0 .389 r
.60042 .42045 .60298 .43584 .60818 .46392 .60539 .44057 Metetra
0 0 .268 r
.60539 .44057 .60818 .46392 .61409 .51531 .61083 .47623 Metetra
.018 0 .455 r
.61083 .47623 .61409 .51531 .61866 .51391 .61636 .51133 Metetra
.975 .691 .424 r
.61636 .51133 .61866 .51391 .61637 .27931 .61423 .27658 Metetra
.664 .741 .907 r
.61423 .27658 .61637 .27931 .62064 .27783 .6185 .2751 Metetra
.664 .741 .907 r
.6185 .2751 .62064 .27783 .62491 .27635 .62278 .27361 Metetra
.664 .741 .907 r
.62278 .27361 .62491 .27635 .62919 .27487 .62706 .27212 Metetra
.664 .741 .907 r
.62706 .27212 .62919 .27487 .63348 .27338 .63135 .27063 Metetra
.664 .741 .907 r
.63135 .27063 .63348 .27338 .63777 .27189 .63565 .26914 Metetra
.664 .741 .907 r
.63565 .26914 .63777 .27189 .64207 .2704 .63995 .26765 Metetra
.664 .741 .907 r
.63995 .26765 .64207 .2704 .64638 .26891 .64427 .26615 Metetra
.664 .741 .907 r
.64427 .26615 .64638 .26891 .65069 .26742 .64858 .26465 Metetra
.664 .741 .907 r
.64858 .26465 .65069 .26742 .65501 .26592 .65291 .26315 Metetra
.664 .741 .907 r
.65291 .26315 .65501 .26592 .65934 .26442 .65724 .26164 Metetra
.664 .741 .907 r
.65724 .26164 .65934 .26442 .66367 .26292 .66158 .26014 Metetra
.664 .741 .907 r
.66158 .26014 .66367 .26292 .66801 .26141 .66592 .25863 Metetra
.664 .741 .907 r
.66592 .25863 .66801 .26141 .67236 .2599 .67027 .25712 Metetra
.664 .741 .907 r
.67027 .25712 .67236 .2599 .67671 .2584 .67463 .2556 Metetra
.664 .741 .907 r
.67463 .2556 .67671 .2584 .68107 .25688 .67899 .25409 Metetra
.664 .741 .907 r
.67899 .25409 .68107 .25688 .68544 .25537 .68336 .25257 Metetra
.664 .741 .907 r
.68336 .25257 .68544 .25537 .68981 .25385 .68774 .25105 Metetra
.664 .741 .907 r
.68774 .25105 .68981 .25385 .69419 .25234 .69213 .24953 Metetra
.664 .741 .907 r
.69213 .24953 .69419 .25234 .69858 .25081 .69652 .248 Metetra
.664 .741 .907 r
.69652 .248 .69858 .25081 .70297 .24929 .70092 .24647 Metetra
.664 .741 .907 r
.70092 .24647 .70297 .24929 .70737 .24777 .70532 .24494 Metetra
.664 .741 .907 r
.70532 .24494 .70737 .24777 .71178 .24624 .70973 .24341 Metetra
.664 .741 .907 r
.70973 .24341 .71178 .24624 .71619 .24471 .71415 .24188 Metetra
.664 .741 .907 r
.71415 .24188 .71619 .24471 .72061 .24318 .71858 .24034 Metetra
.664 .741 .907 r
.71858 .24034 .72061 .24318 .72504 .24164 .72301 .2388 Metetra
.664 .741 .907 r
.72301 .2388 .72504 .24164 .72948 .2401 .72745 .23726 Metetra
.664 .741 .907 r
.72745 .23726 .72948 .2401 .73392 .23856 .7319 .23571 Metetra
.664 .741 .907 r
.7319 .23571 .73392 .23856 .73837 .23702 .73635 .23417 Metetra
.664 .741 .907 r
.73635 .23417 .73837 .23702 .74282 .23548 .74081 .23262 Metetra
.664 .741 .907 r
.74081 .23262 .74282 .23548 .74729 .23393 .74528 .23107 Metetra
.664 .741 .907 r
.74528 .23107 .74729 .23393 .75176 .23238 .74975 .22951 Metetra
.664 .741 .907 r
.74975 .22951 .75176 .23238 .75623 .23083 .75423 .22796 Metetra
.664 .741 .907 r
.75423 .22796 .75623 .23083 .76071 .22927 .75872 .2264 Metetra
.664 .741 .907 r
.75872 .2264 .76071 .22927 .76521 .22772 .76322 .22484 Metetra
.664 .741 .907 r
.76322 .22484 .76521 .22772 .7697 .22616 .76772 .22327 Metetra
.664 .741 .907 r
.76772 .22327 .7697 .22616 .77421 .2246 .77223 .22171 Metetra
.664 .741 .907 r
.77223 .22171 .77421 .2246 .77872 .22303 .77675 .22014 Metetra
.664 .741 .907 r
.77675 .22014 .77872 .22303 .78324 .22146 .78127 .21857 Metetra
.664 .741 .907 r
.78127 .21857 .78324 .22146 .78776 .2199 .7858 .21699 Metetra
.664 .741 .907 r
.7858 .21699 .78776 .2199 .7923 .21832 .79034 .21542 Metetra
.664 .741 .907 r
.79034 .21542 .7923 .21832 .79684 .21675 .79488 .21384 Metetra
.664 .741 .907 r
.79488 .21384 .79684 .21675 .80138 .21517 .79944 .21226 Metetra
.664 .741 .907 r
.79944 .21226 .80138 .21517 .80594 .2136 .804 .21067 Metetra
.664 .741 .907 r
.804 .21067 .80594 .2136 .8105 .21201 .80856 .20909 Metetra
.664 .741 .907 r
.80856 .20909 .8105 .21201 .81507 .21043 .81314 .2075 Metetra
.664 .741 .907 r
.81314 .2075 .81507 .21043 .81964 .20884 .81772 .20591 Metetra
.664 .741 .907 r
.81772 .20591 .81964 .20884 .82423 .20725 .82231 .20431 Metetra
.664 .741 .907 r
.20779 .4145 .21032 .41686 .214 .41558 .21147 .41322 Metetra
.664 .741 .907 r
.21147 .41322 .214 .41558 .21768 .4143 .21516 .41194 Metetra
.664 .741 .907 r
.21516 .41194 .21768 .4143 .22136 .41302 .21885 .41065 Metetra
.664 .741 .907 r
.21885 .41065 .22136 .41302 .22506 .41174 .22254 .40937 Metetra
.664 .741 .907 r
.22254 .40937 .22506 .41174 .22875 .41046 .22624 .40808 Metetra
.664 .741 .907 r
.22624 .40808 .22875 .41046 .23246 .40917 .22995 .40679 Metetra
.664 .741 .907 r
.22995 .40679 .23246 .40917 .23616 .40788 .23366 .4055 Metetra
.664 .741 .907 r
.23366 .4055 .23616 .40788 .23988 .40659 .23738 .40421 Metetra
.664 .741 .907 r
.23738 .40421 .23988 .40659 .2436 .4053 .2411 .40291 Metetra
.664 .741 .907 r
.2411 .40291 .2436 .4053 .24732 .40401 .24482 .40162 Metetra
.664 .741 .907 r
.24482 .40162 .24732 .40401 .25105 .40271 .24856 .40032 Metetra
.664 .741 .907 r
.24856 .40032 .25105 .40271 .25478 .40142 .25229 .39902 Metetra
.664 .741 .907 r
.25229 .39902 .25478 .40142 .25852 .40012 .25604 .39772 Metetra
.664 .741 .907 r
.25604 .39772 .25852 .40012 .26227 .39882 .25979 .39641 Metetra
.664 .741 .907 r
.25979 .39641 .26227 .39882 .26602 .39752 .26354 .39511 Metetra
.664 .741 .907 r
.26354 .39511 .26602 .39752 .26977 .39621 .2673 .3938 Metetra
.664 .741 .907 r
.2673 .3938 .26977 .39621 .27353 .3949 .27106 .39249 Metetra
.664 .741 .907 r
.27106 .39249 .27353 .3949 .2773 .3936 .27483 .39118 Metetra
.664 .741 .907 r
.27483 .39118 .2773 .3936 .28107 .39229 .27861 .38986 Metetra
.664 .741 .907 r
.27861 .38986 .28107 .39229 .28485 .39097 .28239 .38855 Metetra
.664 .741 .907 r
.28239 .38855 .28485 .39097 .28863 .38966 .28617 .38723 Metetra
.664 .741 .907 r
.28617 .38723 .28863 .38966 .29242 .38835 .28997 .38591 Metetra
.664 .741 .907 r
.28997 .38591 .29242 .38835 .29622 .38703 .29376 .38459 Metetra
.664 .741 .907 r
.29376 .38459 .29622 .38703 .30001 .38571 .29756 .38327 Metetra
.664 .741 .907 r
.29756 .38327 .30001 .38571 .30382 .38439 .30137 .38194 Metetra
.664 .741 .907 r
.30137 .38194 .30382 .38439 .30763 .38306 .30519 .38062 Metetra
.664 .741 .907 r
.30519 .38062 .30763 .38306 .31144 .38174 .309 .37929 Metetra
.664 .741 .907 r
.309 .37929 .31144 .38174 .31527 .38041 .31283 .37796 Metetra
.664 .741 .907 r
.31283 .37796 .31527 .38041 .31909 .37908 .31666 .37662 Metetra
.664 .741 .907 r
.31666 .37662 .31909 .37908 .32292 .37775 .3205 .37529 Metetra
.664 .741 .907 r
.3205 .37529 .32292 .37775 .32676 .37642 .32434 .37395 Metetra
.664 .741 .907 r
.32434 .37395 .32676 .37642 .33061 .37508 .32818 .37261 Metetra
.664 .741 .907 r
.32818 .37261 .33061 .37508 .33445 .37375 .33204 .37127 Metetra
.664 .741 .907 r
.33204 .37127 .33445 .37375 .33831 .37241 .33589 .36993 Metetra
.664 .741 .907 r
.33589 .36993 .33831 .37241 .34217 .37107 .33976 .36859 Metetra
.664 .741 .907 r
.33976 .36859 .34217 .37107 .34603 .36973 .34363 .36724 Metetra
.664 .741 .907 r
.34363 .36724 .34603 .36973 .34991 .36838 .3475 .36589 Metetra
.664 .741 .907 r
.3475 .36589 .34991 .36838 .35378 .36703 .35138 .36454 Metetra
.664 .741 .907 r
.35138 .36454 .35378 .36703 .35767 .36569 .35527 .36319 Metetra
.664 .741 .907 r
.35527 .36319 .35767 .36569 .36155 .36434 .35916 .36184 Metetra
.664 .741 .907 r
.35916 .36184 .36155 .36434 .36545 .36298 .36306 .36048 Metetra
.664 .741 .907 r
.36306 .36048 .36545 .36298 .36935 .36163 .36696 .35912 Metetra
.664 .741 .907 r
.36696 .35912 .36935 .36163 .37325 .36027 .37087 .35776 Metetra
.664 .741 .907 r
.37087 .35776 .37325 .36027 .37716 .35891 .37478 .3564 Metetra
.664 .741 .907 r
.37478 .3564 .37716 .35891 .38108 .35755 .3787 .35504 Metetra
.664 .741 .907 r
.3787 .35504 .38108 .35755 .385 .35619 .38263 .35367 Metetra
.957 .682 .475 r
.38263 .35367 .385 .35619 .38893 .35483 .37658 .58136 Metetra
.51 .287 .513 r
.37658 .58136 .38893 .35483 .38335 .58245 .3814 .56586 Metetra
.879 .632 .561 r
.3814 .56586 .38335 .58245 .38901 .5454 .38755 .51708 Metetra
.762 .528 .579 r
.38755 .51708 .38901 .5454 .39461 .5077 .39272 .4904 Metetra
.774 .553 .6 r
.39272 .4904 .39461 .5077 .39955 .48521 .39748 .47279 Metetra
.778 .572 .621 r
.39748 .47279 .39955 .48521 .4042 .46968 .40202 .45992 Metetra
.779 .588 .641 r
.40202 .45992 .4042 .46968 .40868 .45802 .40644 .44989 Metetra
.778 .602 .661 r
.40644 .44989 .40868 .45802 .41254 .46378 .41078 .44171 Metetra
.355 .231 .57 r
.41078 .44171 .41254 .46378 .41686 .45627 .41457 .44982 Metetra
.765 .62 .698 r
.41457 .44982 .41686 .45627 .42114 .44993 .41883 .44403 Metetra
.76 .628 .714 r
.41883 .44403 .42114 .44993 .42539 .44445 .42306 .43897 Metetra
.755 .636 .729 r
.42306 .43897 .42539 .44445 .42961 .43963 .42728 .43448 Metetra
.749 .642 .743 r
.42728 .43448 .42961 .43963 .43381 .43533 .43148 .43043 Metetra
.743 .648 .755 r
.43148 .43043 .43381 .43533 .438 .43145 .43567 .42676 Metetra
.736 .652 .766 r
.43567 .42676 .438 .43145 .44219 .42792 .43985 .4234 Metetra
.73 .656 .776 r
.43985 .4234 .44219 .42792 .44636 .42467 .44403 .42029 Metetra
.724 .659 .785 r
.44403 .42029 .44636 .42467 .45054 .42168 .4482 .41741 Metetra
.718 .662 .793 r
.4482 .41741 .45054 .42168 .45471 .4189 .45237 .41472 Metetra
.712 .664 .801 r
.45237 .41472 .45471 .4189 .45888 .4163 .45654 .4122 Metetra
.706 .665 .807 r
.45654 .4122 .45888 .4163 .46305 .41387 .46071 .40984 Metetra
.7 .666 .813 r
.46071 .40984 .46305 .41387 .46722 .41159 .46488 .40761 Metetra
.694 .666 .819 r
.46488 .40761 .46722 .41159 .47139 .40944 .46906 .40551 Metetra
.688 .666 .824 r
.46906 .40551 .47139 .40944 .47557 .40742 .47324 .40352 Metetra
.682 .666 .828 r
.47324 .40352 .47557 .40742 .47974 .40552 .47742 .40164 Metetra
.676 .665 .832 r
.47742 .40164 .47974 .40552 .48392 .40372 .4816 .39987 Metetra
.67 .664 .836 r
.4816 .39987 .48392 .40372 .48811 .40203 .48579 .39819 Metetra
.663 .662 .839 r
.48579 .39819 .48811 .40203 .4923 .40044 .48998 .39661 Metetra
.657 .66 .842 r
.48998 .39661 .4923 .40044 .4965 .39894 .49418 .39511 Metetra
.65 .658 .844 r
.49418 .39511 .4965 .39894 .5007 .39755 .49838 .39371 Metetra
.644 .655 .846 r
.49838 .39371 .5007 .39755 .5049 .39625 .50259 .3924 Metetra
.637 .652 .848 r
.50259 .3924 .5049 .39625 .50912 .39505 .50681 .39119 Metetra
.629 .648 .85 r
.50681 .39119 .50912 .39505 .51333 .39395 .51103 .39006 Metetra
.621 .643 .851 r
.51103 .39006 .51333 .39395 .51756 .39295 .51526 .38904 Metetra
.613 .638 .852 r
.51526 .38904 .51756 .39295 .52179 .39207 .51949 .38812 Metetra
.603 .632 .852 r
.51949 .38812 .52179 .39207 .52604 .3913 .52374 .38731 Metetra
.593 .625 .852 r
.52374 .38731 .52604 .3913 .53029 .39066 .52799 .38661 Metetra
.583 .617 .852 r
.52799 .38661 .53029 .39066 .53455 .39015 .53225 .38605 Metetra
.57 .608 .851 r
.53225 .38605 .53455 .39015 .53882 .3898 .53652 .38562 Metetra
.557 .597 .85 r
.53652 .38562 .53882 .3898 .54309 .38961 .5408 .38534 Metetra
.542 .585 .847 r
.5408 .38534 .54309 .38961 .54739 .38962 .54509 .38524 Metetra
.525 .571 .844 r
.54509 .38524 .54739 .38962 .55169 .38984 .54939 .38534 Metetra
.505 .554 .84 r
.54939 .38534 .55169 .38984 .556 .39031 .55371 .38567 Metetra
.482 .534 .834 r
.55371 .38567 .556 .39031 .56034 .39108 .55804 .38626 Metetra
.455 .511 .827 r
.55804 .38626 .56034 .39108 .56468 .3922 .56239 .38716 Metetra
.424 .483 .817 r
.56239 .38716 .56468 .3922 .56905 .39375 .56675 .38844 Metetra
.386 .449 .803 r
.56675 .38844 .56905 .39375 .57344 .39583 .57113 .39018 Metetra
.341 .408 .785 r
.57113 .39018 .57344 .39583 .57786 .39859 .57554 .3925 Metetra
.286 .357 .761 r
.57554 .3925 .57786 .39859 .58231 .40222 .57998 .39555 Metetra
.847 .658 .648 r
.57998 .39555 .58231 .40222 .58681 .40704 .58418 .38453 Metetra
.439 .297 .59 r
.58418 .38453 .58681 .40704 .59105 .3984 .58869 .39001 Metetra
.021 .116 .625 r
.58869 .39001 .59105 .3984 .59567 .40745 .59326 .3974 Metetra
0 .01 .55 r
.59326 .3974 .59567 .40745 .60042 .42045 .59793 .40768 Metetra
0 0 .458 r
.59793 .40768 .60042 .42045 .60539 .44057 .60275 .42281 Metetra
0 0 .349 r
.60275 .42281 .60539 .44057 .61083 .47623 .60787 .4472 Metetra
0 0 .221 r
.60787 .4472 .61083 .47623 .61636 .51133 .61366 .49422 Metetra
.118 .095 .554 r
.61366 .49422 .61636 .51133 .61423 .27658 .61865 .50734 Metetra
0 0 .359 r
.61865 .50734 .61423 .27658 .6185 .2751 .61635 .27235 Metetra
.664 .741 .907 r
.61635 .27235 .6185 .2751 .62278 .27361 .62063 .27086 Metetra
.664 .741 .907 r
.62063 .27086 .62278 .27361 .62706 .27212 .62492 .26937 Metetra
.664 .741 .907 r
.62492 .26937 .62706 .27212 .63135 .27063 .62922 .26788 Metetra
.664 .741 .907 r
.62922 .26788 .63135 .27063 .63565 .26914 .63352 .26638 Metetra
.664 .741 .907 r
.63352 .26638 .63565 .26914 .63995 .26765 .63783 .26488 Metetra
.664 .741 .907 r
.63783 .26488 .63995 .26765 .64427 .26615 .64214 .26338 Metetra
.664 .741 .907 r
.64214 .26338 .64427 .26615 .64858 .26465 .64647 .26187 Metetra
.664 .741 .907 r
.64647 .26187 .64858 .26465 .65291 .26315 .65079 .26037 Metetra
.664 .741 .907 r
.65079 .26037 .65291 .26315 .65724 .26164 .65513 .25886 Metetra
.664 .741 .907 r
.65513 .25886 .65724 .26164 .66158 .26014 .65947 .25735 Metetra
.664 .741 .907 r
.65947 .25735 .66158 .26014 .66592 .25863 .66382 .25584 Metetra
.664 .741 .907 r
.66382 .25584 .66592 .25863 .67027 .25712 .66818 .25432 Metetra
.664 .741 .907 r
.66818 .25432 .67027 .25712 .67463 .2556 .67254 .2528 Metetra
.664 .741 .907 r
.67254 .2528 .67463 .2556 .67899 .25409 .67691 .25128 Metetra
.664 .741 .907 r
.67691 .25128 .67899 .25409 .68336 .25257 .68128 .24976 Metetra
.664 .741 .907 r
.68128 .24976 .68336 .25257 .68774 .25105 .68567 .24824 Metetra
.664 .741 .907 r
.68567 .24824 .68774 .25105 .69213 .24953 .69006 .24671 Metetra
.664 .741 .907 r
.69006 .24671 .69213 .24953 .69652 .248 .69445 .24518 Metetra
.664 .741 .907 r
.69445 .24518 .69652 .248 .70092 .24647 .69886 .24365 Metetra
.664 .741 .907 r
.69886 .24365 .70092 .24647 .70532 .24494 .70327 .24211 Metetra
.664 .741 .907 r
.70327 .24211 .70532 .24494 .70973 .24341 .70768 .24058 Metetra
.664 .741 .907 r
.70768 .24058 .70973 .24341 .71415 .24188 .71211 .23904 Metetra
.664 .741 .907 r
.71211 .23904 .71415 .24188 .71858 .24034 .71654 .2375 Metetra
.664 .741 .907 r
.71654 .2375 .71858 .24034 .72301 .2388 .72097 .23595 Metetra
.664 .741 .907 r
.72097 .23595 .72301 .2388 .72745 .23726 .72542 .23441 Metetra
.664 .741 .907 r
.72542 .23441 .72745 .23726 .7319 .23571 .72987 .23286 Metetra
.664 .741 .907 r
.72987 .23286 .7319 .23571 .73635 .23417 .73433 .23131 Metetra
.664 .741 .907 r
.73433 .23131 .73635 .23417 .74081 .23262 .73879 .22975 Metetra
.664 .741 .907 r
.73879 .22975 .74081 .23262 .74528 .23107 .74326 .2282 Metetra
.664 .741 .907 r
.74326 .2282 .74528 .23107 .74975 .22951 .74774 .22664 Metetra
.664 .741 .907 r
.74774 .22664 .74975 .22951 .75423 .22796 .75223 .22508 Metetra
.664 .741 .907 r
.75223 .22508 .75423 .22796 .75872 .2264 .75672 .22351 Metetra
.664 .741 .907 r
.75672 .22351 .75872 .2264 .76322 .22484 .76122 .22195 Metetra
.664 .741 .907 r
.76122 .22195 .76322 .22484 .76772 .22327 .76573 .22038 Metetra
.664 .741 .907 r
.76573 .22038 .76772 .22327 .77223 .22171 .77025 .21881 Metetra
.664 .741 .907 r
.77025 .21881 .77223 .22171 .77675 .22014 .77477 .21723 Metetra
.664 .741 .907 r
.77477 .21723 .77675 .22014 .78127 .21857 .7793 .21566 Metetra
.664 .741 .907 r
.7793 .21566 .78127 .21857 .7858 .21699 .78383 .21408 Metetra
.664 .741 .907 r
.78383 .21408 .7858 .21699 .79034 .21542 .78837 .2125 Metetra
.664 .741 .907 r
.78837 .2125 .79034 .21542 .79488 .21384 .79293 .21092 Metetra
.664 .741 .907 r
.79293 .21092 .79488 .21384 .79944 .21226 .79748 .20933 Metetra
.664 .741 .907 r
.79748 .20933 .79944 .21226 .804 .21067 .80205 .20774 Metetra
.664 .741 .907 r
.80205 .20774 .804 .21067 .80856 .20909 .80662 .20615 Metetra
.664 .741 .907 r
.80662 .20615 .80856 .20909 .81314 .2075 .8112 .20456 Metetra
.664 .741 .907 r
.8112 .20456 .81314 .2075 .81772 .20591 .81578 .20296 Metetra
.664 .741 .907 r
.81578 .20296 .81772 .20591 .82231 .20431 .82038 .20137 Metetra
.664 .741 .907 r
.20526 .41214 .20779 .4145 .21147 .41322 .20895 .41085 Metetra
.664 .741 .907 r
.20895 .41085 .21147 .41322 .21516 .41194 .21263 .40957 Metetra
.664 .741 .907 r
.21263 .40957 .21516 .41194 .21885 .41065 .21633 .40828 Metetra
.664 .741 .907 r
.21633 .40828 .21885 .41065 .22254 .40937 .22002 .40699 Metetra
.664 .741 .907 r
.22002 .40699 .22254 .40937 .22624 .40808 .22373 .4057 Metetra
.664 .741 .907 r
.22373 .4057 .22624 .40808 .22995 .40679 .22744 .40441 Metetra
.664 .741 .907 r
.22744 .40441 .22995 .40679 .23366 .4055 .23115 .40311 Metetra
.664 .741 .907 r
.23115 .40311 .23366 .4055 .23738 .40421 .23487 .40182 Metetra
.664 .741 .907 r
.23487 .40182 .23738 .40421 .2411 .40291 .23859 .40052 Metetra
.664 .741 .907 r
.23859 .40052 .2411 .40291 .24482 .40162 .24232 .39922 Metetra
.664 .741 .907 r
.24232 .39922 .24482 .40162 .24856 .40032 .24606 .39792 Metetra
.664 .741 .907 r
.24606 .39792 .24856 .40032 .25229 .39902 .2498 .39661 Metetra
.664 .741 .907 r
.2498 .39661 .25229 .39902 .25604 .39772 .25355 .39531 Metetra
.664 .741 .907 r
.25355 .39531 .25604 .39772 .25979 .39641 .2573 .394 Metetra
.664 .741 .907 r
.2573 .394 .25979 .39641 .26354 .39511 .26105 .39269 Metetra
.664 .741 .907 r
.26105 .39269 .26354 .39511 .2673 .3938 .26482 .39138 Metetra
.664 .741 .907 r
.26482 .39138 .2673 .3938 .27106 .39249 .26858 .39007 Metetra
.664 .741 .907 r
.26858 .39007 .27106 .39249 .27483 .39118 .27236 .38875 Metetra
.664 .741 .907 r
.27236 .38875 .27483 .39118 .27861 .38986 .27613 .38743 Metetra
.664 .741 .907 r
.27613 .38743 .27861 .38986 .28239 .38855 .27992 .38611 Metetra
.664 .741 .907 r
.27992 .38611 .28239 .38855 .28617 .38723 .28371 .38479 Metetra
.664 .741 .907 r
.28371 .38479 .28617 .38723 .28997 .38591 .2875 .38347 Metetra
.664 .741 .907 r
.2875 .38347 .28997 .38591 .29376 .38459 .2913 .38215 Metetra
.664 .741 .907 r
.2913 .38215 .29376 .38459 .29756 .38327 .29511 .38082 Metetra
.664 .741 .907 r
.29511 .38082 .29756 .38327 .30137 .38194 .29892 .37949 Metetra
.664 .741 .907 r
.29892 .37949 .30137 .38194 .30519 .38062 .30274 .37816 Metetra
.664 .741 .907 r
.30274 .37816 .30519 .38062 .309 .37929 .30656 .37683 Metetra
.664 .741 .907 r
.30656 .37683 .309 .37929 .31283 .37796 .31039 .37549 Metetra
.664 .741 .907 r
.31039 .37549 .31283 .37796 .31666 .37662 .31422 .37416 Metetra
.664 .741 .907 r
.31422 .37416 .31666 .37662 .3205 .37529 .31806 .37282 Metetra
.664 .741 .907 r
.31806 .37282 .3205 .37529 .32434 .37395 .3219 .37148 Metetra
.664 .741 .907 r
.3219 .37148 .32434 .37395 .32818 .37261 .32575 .37014 Metetra
.664 .741 .907 r
.32575 .37014 .32818 .37261 .33204 .37127 .32961 .36879 Metetra
.664 .741 .907 r
.32961 .36879 .33204 .37127 .33589 .36993 .33347 .36745 Metetra
.664 .741 .907 r
.33347 .36745 .33589 .36993 .33976 .36859 .33734 .3661 Metetra
.664 .741 .907 r
.33734 .3661 .33976 .36859 .34363 .36724 .34121 .36475 Metetra
.664 .741 .907 r
.34121 .36475 .34363 .36724 .3475 .36589 .34509 .3634 Metetra
.664 .741 .907 r
.34509 .3634 .3475 .36589 .35138 .36454 .34897 .36205 Metetra
.664 .741 .907 r
.34897 .36205 .35138 .36454 .35527 .36319 .35286 .36069 Metetra
.664 .741 .907 r
.35286 .36069 .35527 .36319 .35916 .36184 .35676 .35933 Metetra
.664 .741 .907 r
.35676 .35933 .35916 .36184 .36306 .36048 .36066 .35797 Metetra
.664 .741 .907 r
.36066 .35797 .36306 .36048 .36696 .35912 .36456 .35661 Metetra
.664 .741 .907 r
.36456 .35661 .36696 .35912 .37087 .35776 .36848 .35525 Metetra
.664 .741 .907 r
.36848 .35525 .37087 .35776 .37478 .3564 .3724 .35388 Metetra
.664 .741 .907 r
.3724 .35388 .37478 .3564 .3787 .35504 .37632 .35251 Metetra
.956 .682 .476 r
.37632 .35251 .3787 .35504 .38263 .35367 .36981 .58027 Metetra
.534 .307 .517 r
.36981 .58027 .38263 .35367 .37658 .58136 .37402 .57898 Metetra
.951 .711 .538 r
.37402 .57898 .37658 .58136 .3814 .56586 .38033 .52905 Metetra
.753 .515 .572 r
.38033 .52905 .3814 .56586 .38755 .51708 .3858 .49669 Metetra
.77 .544 .592 r
.3858 .49669 .38755 .51708 .39272 .4904 .3907 .47647 Metetra
.776 .565 .613 r
.3907 .47647 .39272 .4904 .39748 .47279 .39533 .46216 Metetra
.779 .582 .634 r
.39533 .46216 .39748 .47279 .40202 .45992 .39981 .45124 Metetra
.778 .597 .654 r
.39981 .45124 .40202 .45992 .40644 .44989 .40419 .44246 Metetra
.776 .61 .673 r
.40419 .44246 .40644 .44989 .41078 .44171 .4085 .43515 Metetra
.773 .621 .692 r
.4085 .43515 .41078 .44171 .41457 .44982 .41277 .4289 Metetra
.294 .19 .562 r
.41277 .4289 .41457 .44982 .41883 .44403 .41651 .4384 Metetra
.757 .633 .724 r
.41651 .4384 .41883 .44403 .42306 .43897 .42073 .43371 Metetra
.751 .64 .738 r
.42073 .43371 .42306 .43897 .42728 .43448 .42494 .42949 Metetra
.745 .646 .751 r
.42494 .42949 .42728 .43448 .43148 .43043 .42914 .42568 Metetra
.739 .651 .762 r
.42914 .42568 .43148 .43043 .43567 .42676 .43332 .42219 Metetra
.733 .655 .773 r
.43332 .42219 .43567 .42676 .43985 .4234 .43751 .41897 Metetra
.727 .659 .782 r
.43751 .41897 .43985 .4234 .44403 .42029 .44168 .41599 Metetra
.721 .662 .79 r
.44168 .41599 .44403 .42029 .4482 .41741 .44585 .41321 Metetra
.715 .664 .798 r
.44585 .41321 .4482 .41741 .45237 .41472 .45003 .41061 Metetra
.709 .666 .805 r
.45003 .41061 .45237 .41472 .45654 .4122 .4542 .40816 Metetra
.703 .667 .811 r
.4542 .40816 .45654 .4122 .46071 .40984 .45837 .40586 Metetra
.698 .668 .817 r
.45837 .40586 .46071 .40984 .46488 .40761 .46255 .40368 Metetra
.692 .668 .822 r
.46255 .40368 .46488 .40761 .46906 .40551 .46672 .40161 Metetra
.686 .668 .827 r
.46672 .40161 .46906 .40551 .47324 .40352 .4709 .39966 Metetra
.681 .668 .831 r
.4709 .39966 .47324 .40352 .47742 .40164 .47508 .3978 Metetra
.675 .667 .835 r
.47508 .3978 .47742 .40164 .4816 .39987 .47927 .39605 Metetra
.669 .666 .838 r
.47927 .39605 .4816 .39987 .48579 .39819 .48346 .39438 Metetra
.663 .664 .841 r
.48346 .39438 .48579 .39819 .48998 .39661 .48766 .3928 Metetra
.657 .663 .844 r
.48766 .3928 .48998 .39661 .49418 .39511 .49186 .39131 Metetra
.651 .66 .846 r
.49186 .39131 .49418 .39511 .49838 .39371 .49606 .38991 Metetra
.644 .657 .848 r
.49606 .38991 .49838 .39371 .50259 .3924 .50027 .38859 Metetra
.638 .654 .85 r
.50027 .38859 .50259 .3924 .50681 .39119 .50449 .38736 Metetra
.631 .651 .851 r
.50449 .38736 .50681 .39119 .51103 .39006 .50872 .38621 Metetra
.623 .646 .853 r
.50872 .38621 .51103 .39006 .51526 .38904 .51295 .38516 Metetra
.615 .641 .853 r
.51295 .38516 .51526 .38904 .51949 .38812 .51718 .38421 Metetra
.606 .636 .854 r
.51718 .38421 .51949 .38812 .52374 .38731 .52143 .38335 Metetra
.597 .629 .854 r
.52143 .38335 .52374 .38731 .52799 .38661 .52569 .38261 Metetra
.587 .622 .854 r
.52569 .38261 .52799 .38661 .53225 .38605 .52995 .38199 Metetra
.576 .614 .853 r
.52995 .38199 .53225 .38605 .53652 .38562 .53422 .38149 Metetra
.563 .604 .852 r
.53422 .38149 .53652 .38562 .5408 .38534 .5385 .38114 Metetra
.549 .593 .85 r
.5385 .38114 .5408 .38534 .54509 .38524 .54279 .38094 Metetra
.534 .58 .847 r
.54279 .38094 .54509 .38524 .54939 .38534 .5471 .38093 Metetra
.516 .565 .844 r
.5471 .38093 .54939 .38534 .55371 .38567 .55141 .38112 Metetra
.495 .547 .839 r
.55141 .38112 .55371 .38567 .55804 .38626 .55574 .38155 Metetra
.471 .526 .832 r
.55574 .38155 .55804 .38626 .56239 .38716 .56008 .38225 Metetra
.443 .501 .824 r
.56008 .38225 .56239 .38716 .56675 .38844 .56444 .38329 Metetra
.409 .47 .812 r
.56444 .38329 .56675 .38844 .57113 .39018 .56882 .38474 Metetra
.369 .434 .797 r
.56882 .38474 .57113 .39018 .57554 .3925 .57323 .38668 Metetra
.876 .683 .639 r
.57323 .38668 .57554 .3925 .57998 .39555 .57741 .37423 Metetra
.476 .326 .597 r
.57741 .37423 .57998 .39555 .58418 .38453 .58185 .37775 Metetra
.168 .257 .713 r
.58185 .37775 .58418 .38453 .58869 .39001 .58633 .38235 Metetra
.084 .177 .663 r
.58633 .38235 .58869 .39001 .59326 .3974 .59087 .38844 Metetra
0 .081 .6 r
.59087 .38844 .59326 .3974 .59793 .40768 .59548 .39673 Metetra
0 0 .519 r
.59548 .39673 .59793 .40768 .60275 .42281 .60021 .40848 Metetra
0 0 .422 r
.60021 .40848 .60275 .42281 .60787 .4472 .60513 .42627 Metetra
0 0 .308 r
.60513 .42627 .60787 .4472 .61366 .49422 .61044 .45649 Metetra
0 0 .333 r
.61044 .45649 .61366 .49422 .61865 .50734 .61634 .50474 Metetra
.645 .763 .934 r
.61634 .50474 .61865 .50734 .61635 .27235 .62095 .50333 Metetra
0 0 .359 r
.62095 .50333 .61635 .27235 .62063 .27086 .61848 .26811 Metetra
.664 .741 .907 r
.61848 .26811 .62063 .27086 .62492 .26937 .62278 .26661 Metetra
.664 .741 .907 r
.62278 .26661 .62492 .26937 .62922 .26788 .62708 .26511 Metetra
.664 .741 .907 r
.62708 .26511 .62922 .26788 .63352 .26638 .63138 .26361 Metetra
.664 .741 .907 r
.63138 .26361 .63352 .26638 .63783 .26488 .6357 .26211 Metetra
.664 .741 .907 r
.6357 .26211 .63783 .26488 .64214 .26338 .64002 .2606 Metetra
.664 .741 .907 r
.64002 .2606 .64214 .26338 .64647 .26187 .64434 .25909 Metetra
.664 .741 .907 r
.64434 .25909 .64647 .26187 .65079 .26037 .64868 .25758 Metetra
.664 .741 .907 r
.64868 .25758 .65079 .26037 .65513 .25886 .65302 .25607 Metetra
.664 .741 .907 r
.65302 .25607 .65513 .25886 .65947 .25735 .65736 .25455 Metetra
.664 .741 .907 r
.65736 .25455 .65947 .25735 .66382 .25584 .66172 .25304 Metetra
.664 .741 .907 r
.66172 .25304 .66382 .25584 .66818 .25432 .66608 .25152 Metetra
.664 .741 .907 r
.66608 .25152 .66818 .25432 .67254 .2528 .67044 .24999 Metetra
.664 .741 .907 r
.67044 .24999 .67254 .2528 .67691 .25128 .67482 .24847 Metetra
.664 .741 .907 r
.67482 .24847 .67691 .25128 .68128 .24976 .6792 .24694 Metetra
.664 .741 .907 r
.6792 .24694 .68128 .24976 .68567 .24824 .68359 .24541 Metetra
.664 .741 .907 r
.68359 .24541 .68567 .24824 .69006 .24671 .68798 .24388 Metetra
.664 .741 .907 r
.68798 .24388 .69006 .24671 .69445 .24518 .69238 .24235 Metetra
.664 .741 .907 r
.69238 .24235 .69445 .24518 .69886 .24365 .69679 .24081 Metetra
.664 .741 .907 r
.69679 .24081 .69886 .24365 .70327 .24211 .7012 .23927 Metetra
.664 .741 .907 r
.7012 .23927 .70327 .24211 .70768 .24058 .70562 .23773 Metetra
.664 .741 .907 r
.70562 .23773 .70768 .24058 .71211 .23904 .71005 .23619 Metetra
.664 .741 .907 r
.71005 .23619 .71211 .23904 .71654 .2375 .71449 .23464 Metetra
.664 .741 .907 r
.71449 .23464 .71654 .2375 .72097 .23595 .71893 .23309 Metetra
.664 .741 .907 r
.71893 .23309 .72097 .23595 .72542 .23441 .72338 .23154 Metetra
.664 .741 .907 r
.72338 .23154 .72542 .23441 .72987 .23286 .72784 .22999 Metetra
.664 .741 .907 r
.72784 .22999 .72987 .23286 .73433 .23131 .7323 .22844 Metetra
.664 .741 .907 r
.7323 .22844 .73433 .23131 .73879 .22975 .73677 .22688 Metetra
.664 .741 .907 r
.73677 .22688 .73879 .22975 .74326 .2282 .74125 .22532 Metetra
.664 .741 .907 r
.74125 .22532 .74326 .2282 .74774 .22664 .74573 .22375 Metetra
.664 .741 .907 r
.74573 .22375 .74774 .22664 .75223 .22508 .75022 .22219 Metetra
.664 .741 .907 r
.75022 .22219 .75223 .22508 .75672 .22351 .75472 .22062 Metetra
.664 .741 .907 r
.75472 .22062 .75672 .22351 .76122 .22195 .75922 .21905 Metetra
.664 .741 .907 r
.75922 .21905 .76122 .22195 .76573 .22038 .76374 .21748 Metetra
.664 .741 .907 r
.76374 .21748 .76573 .22038 .77025 .21881 .76826 .2159 Metetra
.664 .741 .907 r
.76826 .2159 .77025 .21881 .77477 .21723 .77278 .21432 Metetra
.664 .741 .907 r
.77278 .21432 .77477 .21723 .7793 .21566 .77732 .21274 Metetra
.664 .741 .907 r
.77732 .21274 .7793 .21566 .78383 .21408 .78186 .21116 Metetra
.664 .741 .907 r
.78186 .21116 .78383 .21408 .78837 .2125 .78641 .20958 Metetra
.664 .741 .907 r
.78641 .20958 .78837 .2125 .79293 .21092 .79096 .20799 Metetra
.664 .741 .907 r
.79096 .20799 .79293 .21092 .79748 .20933 .79552 .2064 Metetra
.664 .741 .907 r
.79552 .2064 .79748 .20933 .80205 .20774 .80009 .20481 Metetra
.664 .741 .907 r
.80009 .20481 .80205 .20774 .80662 .20615 .80467 .20321 Metetra
.664 .741 .907 r
.80467 .20321 .80662 .20615 .8112 .20456 .80925 .20161 Metetra
.664 .741 .907 r
.80925 .20161 .8112 .20456 .81578 .20296 .81385 .20001 Metetra
.664 .741 .907 r
.81385 .20001 .81578 .20296 .82038 .20137 .81844 .19841 Metetra
.664 .741 .907 r
.20272 .40976 .20526 .41214 .20895 .41085 .20641 .40848 Metetra
.664 .741 .907 r
.20641 .40848 .20895 .41085 .21263 .40957 .2101 .40719 Metetra
.664 .741 .907 r
.2101 .40719 .21263 .40957 .21633 .40828 .2138 .4059 Metetra
.664 .741 .907 r
.2138 .4059 .21633 .40828 .22002 .40699 .2175 .40461 Metetra
.664 .741 .907 r
.2175 .40461 .22002 .40699 .22373 .4057 .2212 .40331 Metetra
.664 .741 .907 r
.2212 .40331 .22373 .4057 .22744 .40441 .22492 .40202 Metetra
.664 .741 .907 r
.22492 .40202 .22744 .40441 .23115 .40311 .22863 .40072 Metetra
.664 .741 .907 r
.22863 .40072 .23115 .40311 .23487 .40182 .23235 .39942 Metetra
.664 .741 .907 r
.23235 .39942 .23487 .40182 .23859 .40052 .23608 .39812 Metetra
.664 .741 .907 r
.23608 .39812 .23859 .40052 .24232 .39922 .23982 .39681 Metetra
.664 .741 .907 r
.23982 .39681 .24232 .39922 .24606 .39792 .24355 .39551 Metetra
.664 .741 .907 r
.24355 .39551 .24606 .39792 .2498 .39661 .2473 .3942 Metetra
.664 .741 .907 r
.2473 .3942 .2498 .39661 .25355 .39531 .25105 .39289 Metetra
.664 .741 .907 r
.25105 .39289 .25355 .39531 .2573 .394 .2548 .39158 Metetra
.664 .741 .907 r
.2548 .39158 .2573 .394 .26105 .39269 .25856 .39027 Metetra
.664 .741 .907 r
.25856 .39027 .26105 .39269 .26482 .39138 .26233 .38895 Metetra
.664 .741 .907 r
.26233 .38895 .26482 .39138 .26858 .39007 .2661 .38764 Metetra
.664 .741 .907 r
.2661 .38764 .26858 .39007 .27236 .38875 .26987 .38632 Metetra
.664 .741 .907 r
.26987 .38632 .27236 .38875 .27613 .38743 .27366 .385 Metetra
.664 .741 .907 r
.27366 .385 .27613 .38743 .27992 .38611 .27744 .38367 Metetra
.664 .741 .907 r
.27744 .38367 .27992 .38611 .28371 .38479 .28124 .38235 Metetra
.664 .741 .907 r
.28124 .38235 .28371 .38479 .2875 .38347 .28503 .38102 Metetra
.664 .741 .907 r
.28503 .38102 .2875 .38347 .2913 .38215 .28884 .3797 Metetra
.664 .741 .907 r
.28884 .3797 .2913 .38215 .29511 .38082 .29265 .37837 Metetra
.664 .741 .907 r
.29265 .37837 .29511 .38082 .29892 .37949 .29646 .37703 Metetra
.664 .741 .907 r
.29646 .37703 .29892 .37949 .30274 .37816 .30028 .3757 Metetra
.664 .741 .907 r
.30028 .3757 .30274 .37816 .30656 .37683 .30411 .37436 Metetra
.664 .741 .907 r
.30411 .37436 .30656 .37683 .31039 .37549 .30794 .37303 Metetra
.664 .741 .907 r
.30794 .37303 .31039 .37549 .31422 .37416 .31177 .37169 Metetra
.664 .741 .907 r
.31177 .37169 .31422 .37416 .31806 .37282 .31562 .37034 Metetra
.664 .741 .907 r
.31562 .37034 .31806 .37282 .3219 .37148 .31946 .369 Metetra
.664 .741 .907 r
.31946 .369 .3219 .37148 .32575 .37014 .32332 .36766 Metetra
.664 .741 .907 r
.32332 .36766 .32575 .37014 .32961 .36879 .32718 .36631 Metetra
.664 .741 .907 r
.32718 .36631 .32961 .36879 .33347 .36745 .33104 .36496 Metetra
.664 .741 .907 r
.33104 .36496 .33347 .36745 .33734 .3661 .33491 .36361 Metetra
.664 .741 .907 r
.33491 .36361 .33734 .3661 .34121 .36475 .33879 .36225 Metetra
.664 .741 .907 r
.33879 .36225 .34121 .36475 .34509 .3634 .34267 .3609 Metetra
.664 .741 .907 r
.34267 .3609 .34509 .3634 .34897 .36205 .34656 .35954 Metetra
.664 .741 .907 r
.34656 .35954 .34897 .36205 .35286 .36069 .35045 .35818 Metetra
.664 .741 .907 r
.35045 .35818 .35286 .36069 .35676 .35933 .35435 .35682 Metetra
.664 .741 .907 r
.35435 .35682 .35676 .35933 .36066 .35797 .35825 .35546 Metetra
.664 .741 .907 r
.35825 .35546 .36066 .35797 .36456 .35661 .36216 .35409 Metetra
.664 .741 .907 r
.36216 .35409 .36456 .35661 .36848 .35525 .36608 .35272 Metetra
.664 .741 .907 r
.36608 .35272 .36848 .35525 .3724 .35388 .37 .35135 Metetra
.664 .741 .907 r
.37 .35135 .3724 .35388 .37632 .35251 .37393 .34998 Metetra
.956 .682 .476 r
.37393 .34998 .37632 .35251 .36981 .58027 .36723 .57788 Metetra
.947 .721 .563 r
.36723 .57788 .36981 .58027 .37402 .57898 .37288 .54484 Metetra
.788 .545 .569 r
.37288 .54484 .37402 .57898 .38033 .52905 .37878 .5044 Metetra
.764 .534 .584 r
.37878 .5044 .38033 .52905 .3858 .49669 .38388 .48085 Metetra
.774 .557 .605 r
.38388 .48085 .3858 .49669 .3907 .47647 .38861 .4648 Metetra
.778 .575 .626 r
.38861 .4648 .3907 .47647 .39533 .46216 .39315 .45284 Metetra
.778 .591 .647 r
.39315 .45284 .39533 .46216 .39981 .45124 .39757 .44338 Metetra
.777 .605 .666 r
.39757 .44338 .39981 .45124 .40419 .44246 .40191 .4356 Metetra
.774 .617 .685 r
.40191 .4356 .40419 .44246 .4085 .43515 .4062 .429 Metetra
.77 .628 .702 r
.4062 .429 .4085 .43515 .41277 .4289 .41045 .42327 Metetra
.766 .637 .718 r
.41045 .42327 .41277 .4289 .41651 .4384 .41468 .4182 Metetra
.247 .158 .553 r
.41468 .4182 .41651 .4384 .42073 .43371 .41839 .42862 Metetra
.748 .644 .746 r
.41839 .42862 .42073 .43371 .42494 .42949 .4226 .42466 Metetra
.742 .65 .758 r
.4226 .42466 .42494 .42949 .42914 .42568 .42679 .42104 Metetra
.736 .654 .769 r
.42679 .42104 .42914 .42568 .43332 .42219 .43097 .41772 Metetra
.73 .658 .779 r
.43097 .41772 .43332 .42219 .43751 .41897 .43515 .41463 Metetra
.724 .662 .787 r
.43515 .41463 .43751 .41897 .44168 .41599 .43933 .41176 Metetra
.718 .664 .795 r
.43933 .41176 .44168 .41599 .44585 .41321 .4435 .40908 Metetra
.713 .666 .803 r
.4435 .40908 .44585 .41321 .45003 .41061 .44768 .40655 Metetra
.707 .668 .809 r
.44768 .40655 .45003 .41061 .4542 .40816 .45185 .40417 Metetra
.701 .669 .815 r
.45185 .40417 .4542 .40816 .45837 .40586 .45603 .40191 Metetra
.696 .67 .82 r
.45603 .40191 .45837 .40586 .46255 .40368 .4602 .39978 Metetra
.69 .67 .825 r
.4602 .39978 .46255 .40368 .46672 .40161 .46438 .39775 Metetra
.685 .67 .83 r
.46438 .39775 .46672 .40161 .4709 .39966 .46856 .39583 Metetra
.68 .67 .833 r
.46856 .39583 .4709 .39966 .47508 .3978 .47275 .394 Metetra
.674 .669 .837 r
.47275 .394 .47508 .3978 .47927 .39605 .47693 .39225 Metetra
.668 .668 .84 r
.47693 .39225 .47927 .39605 .48346 .39438 .48113 .3906 Metetra
.663 .666 .843 r
.48113 .3906 .48346 .39438 .48766 .3928 .48533 .38903 Metetra
.657 .665 .846 r
.48533 .38903 .48766 .3928 .49186 .39131 .48953 .38754 Metetra
.651 .662 .848 r
.48953 .38754 .49186 .39131 .49606 .38991 .49374 .38613 Metetra
.645 .66 .85 r
.49374 .38613 .49606 .38991 .50027 .38859 .49795 .3848 Metetra
.639 .657 .852 r
.49795 .3848 .50027 .38859 .50449 .38736 .50217 .38355 Metetra
.632 .653 .853 r
.50217 .38355 .50449 .38736 .50872 .38621 .5064 .38239 Metetra
.625 .649 .854 r
.5064 .38239 .50872 .38621 .51295 .38516 .51063 .38131 Metetra
.617 .645 .855 r
.51063 .38131 .51295 .38516 .51718 .38421 .51487 .38033 Metetra
.609 .639 .855 r
.51487 .38033 .51718 .38421 .52143 .38335 .51912 .37944 Metetra
.601 .634 .856 r
.51912 .37944 .52143 .38335 .52569 .38261 .52338 .37865 Metetra
.591 .627 .856 r
.52338 .37865 .52569 .38261 .52995 .38199 .52764 .37797 Metetra
.581 .619 .855 r
.52764 .37797 .52995 .38199 .53422 .38149 .53192 .37741 Metetra
.569 .61 .854 r
.53192 .37741 .53422 .38149 .5385 .38114 .5362 .37698 Metetra
.556 .6 .852 r
.5362 .37698 .5385 .38114 .54279 .38094 .54049 .3767 Metetra
.542 .588 .85 r
.54049 .3767 .54279 .38094 .5471 .38093 .5448 .37658 Metetra
.525 .574 .847 r
.5448 .37658 .5471 .38093 .55141 .38112 .54911 .37665 Metetra
.507 .558 .843 r
.54911 .37665 .55141 .38112 .55574 .38155 .55344 .37694 Metetra
.485 .539 .837 r
.55344 .37694 .55574 .38155 .56008 .38225 .55778 .37747 Metetra
.46 .516 .83 r
.55778 .37747 .56008 .38225 .56444 .38329 .56214 .3783 Metetra
.43 .49 .82 r
.56214 .3783 .56444 .38329 .56882 .38474 .56651 .37949 Metetra
.893 .698 .632 r
.56651 .37949 .56882 .38474 .57323 .38668 .57069 .3661 Metetra
.499 .344 .601 r
.57069 .3661 .57323 .38668 .57741 .37423 .5751 .36841 Metetra
.277 .361 .769 r
.5751 .36841 .57741 .37423 .58185 .37775 .57953 .37139 Metetra
.215 .302 .738 r
.57953 .37139 .58185 .37775 .58633 .38235 .58399 .37525 Metetra
.141 .23 .696 r
.58399 .37525 .58633 .38235 .59087 .38844 .5885 .38032 Metetra
.053 .145 .642 r
.5885 .38032 .59087 .38844 .59548 .39673 .59307 .3871 Metetra
0 .044 .573 r
.59307 .3871 .59548 .39673 .60021 .40848 .59773 .39645 Metetra
0 0 .487 r
.59773 .39645 .60021 .40848 .60513 .42627 .60253 .40997 Metetra
0 0 .385 r
.60253 .40997 .60513 .42627 .61044 .45649 .60757 .43117 Metetra
0 0 .265 r
.60757 .43117 .61044 .45649 .61634 .50474 .61315 .46968 Metetra
.025 0 .463 r
.61315 .46968 .61634 .50474 .62095 .50333 .61863 .50071 Metetra
.975 .69 .421 r
.61863 .50071 .62095 .50333 .61848 .26811 .61633 .26534 Metetra
.664 .741 .907 r
.61633 .26534 .61848 .26811 .62278 .26661 .62063 .26384 Metetra
.664 .741 .907 r
.62063 .26384 .62278 .26661 .62708 .26511 .62493 .26234 Metetra
.664 .741 .907 r
.62493 .26234 .62708 .26511 .63138 .26361 .62924 .26083 Metetra
.664 .741 .907 r
.62924 .26083 .63138 .26361 .6357 .26211 .63356 .25932 Metetra
.664 .741 .907 r
.63356 .25932 .6357 .26211 .64002 .2606 .63788 .25781 Metetra
.664 .741 .907 r
.63788 .25781 .64002 .2606 .64434 .25909 .64221 .2563 Metetra
.664 .741 .907 r
.64221 .2563 .64434 .25909 .64868 .25758 .64655 .25479 Metetra
.664 .741 .907 r
.64655 .25479 .64868 .25758 .65302 .25607 .6509 .25327 Metetra
.664 .741 .907 r
.6509 .25327 .65302 .25607 .65736 .25455 .65525 .25175 Metetra
.664 .741 .907 r
.65525 .25175 .65736 .25455 .66172 .25304 .65961 .25023 Metetra
.664 .741 .907 r
.65961 .25023 .66172 .25304 .66608 .25152 .66397 .24871 Metetra
.664 .741 .907 r
.66397 .24871 .66608 .25152 .67044 .24999 .66834 .24718 Metetra
.664 .741 .907 r
.66834 .24718 .67044 .24999 .67482 .24847 .67272 .24565 Metetra
.664 .741 .907 r
.67272 .24565 .67482 .24847 .6792 .24694 .67711 .24412 Metetra
.664 .741 .907 r
.67711 .24412 .6792 .24694 .68359 .24541 .6815 .24258 Metetra
.664 .741 .907 r
.6815 .24258 .68359 .24541 .68798 .24388 .6859 .24105 Metetra
.664 .741 .907 r
.6859 .24105 .68798 .24388 .69238 .24235 .6903 .23951 Metetra
.664 .741 .907 r
.6903 .23951 .69238 .24235 .69679 .24081 .69472 .23797 Metetra
.664 .741 .907 r
.69472 .23797 .69679 .24081 .7012 .23927 .69913 .23643 Metetra
.664 .741 .907 r
.69913 .23643 .7012 .23927 .70562 .23773 .70356 .23488 Metetra
.664 .741 .907 r
.70356 .23488 .70562 .23773 .71005 .23619 .70799 .23333 Metetra
.664 .741 .907 r
.70799 .23333 .71005 .23619 .71449 .23464 .71243 .23178 Metetra
.664 .741 .907 r
.71243 .23178 .71449 .23464 .71893 .23309 .71688 .23023 Metetra
.664 .741 .907 r
.71688 .23023 .71893 .23309 .72338 .23154 .72133 .22867 Metetra
.664 .741 .907 r
.72133 .22867 .72338 .23154 .72784 .22999 .7258 .22712 Metetra
.664 .741 .907 r
.7258 .22712 .72784 .22999 .7323 .22844 .73026 .22556 Metetra
.664 .741 .907 r
.73026 .22556 .7323 .22844 .73677 .22688 .73474 .22399 Metetra
.664 .741 .907 r
.73474 .22399 .73677 .22688 .74125 .22532 .73922 .22243 Metetra
.664 .741 .907 r
.73922 .22243 .74125 .22532 .74573 .22375 .74371 .22086 Metetra
.664 .741 .907 r
.74371 .22086 .74573 .22375 .75022 .22219 .74821 .21929 Metetra
.664 .741 .907 r
.74821 .21929 .75022 .22219 .75472 .22062 .75271 .21772 Metetra
.664 .741 .907 r
.75271 .21772 .75472 .22062 .75922 .21905 .75722 .21614 Metetra
.664 .741 .907 r
.75722 .21614 .75922 .21905 .76374 .21748 .76174 .21457 Metetra
.664 .741 .907 r
.76174 .21457 .76374 .21748 .76826 .2159 .76626 .21299 Metetra
.664 .741 .907 r
.76626 .21299 .76826 .2159 .77278 .21432 .77079 .2114 Metetra
.664 .741 .907 r
.77079 .2114 .77278 .21432 .77732 .21274 .77533 .20982 Metetra
.664 .741 .907 r
.77533 .20982 .77732 .21274 .78186 .21116 .77988 .20823 Metetra
.664 .741 .907 r
.77988 .20823 .78186 .21116 .78641 .20958 .78443 .20664 Metetra
.664 .741 .907 r
.78443 .20664 .78641 .20958 .79096 .20799 .78899 .20505 Metetra
.664 .741 .907 r
.78899 .20505 .79096 .20799 .79552 .2064 .79356 .20346 Metetra
.664 .741 .907 r
.79356 .20346 .79552 .2064 .80009 .20481 .79813 .20186 Metetra
.664 .741 .907 r
.79813 .20186 .80009 .20481 .80467 .20321 .80272 .20026 Metetra
.664 .741 .907 r
.80272 .20026 .80467 .20321 .80925 .20161 .8073 .19866 Metetra
.664 .741 .907 r
.8073 .19866 .80925 .20161 .81385 .20001 .8119 .19705 Metetra
.664 .741 .907 r
.8119 .19705 .81385 .20001 .81844 .19841 .81651 .19544 Metetra
.664 .741 .907 r
.20018 .40739 .20272 .40976 .20641 .40848 .20387 .4061 Metetra
.664 .741 .907 r
.20387 .4061 .20641 .40848 .2101 .40719 .20756 .40481 Metetra
.664 .741 .907 r
.20756 .40481 .2101 .40719 .2138 .4059 .21126 .40351 Metetra
.664 .741 .907 r
.21126 .40351 .2138 .4059 .2175 .40461 .21496 .40222 Metetra
.664 .741 .907 r
.21496 .40222 .2175 .40461 .2212 .40331 .21867 .40092 Metetra
.664 .741 .907 r
.21867 .40092 .2212 .40331 .22492 .40202 .22239 .39962 Metetra
.664 .741 .907 r
.22239 .39962 .22492 .40202 .22863 .40072 .22611 .39832 Metetra
.664 .741 .907 r
.22611 .39832 .22863 .40072 .23235 .39942 .22983 .39701 Metetra
.664 .741 .907 r
.22983 .39701 .23235 .39942 .23608 .39812 .23357 .39571 Metetra
.664 .741 .907 r
.23357 .39571 .23608 .39812 .23982 .39681 .2373 .3944 Metetra
.664 .741 .907 r
.2373 .3944 .23982 .39681 .24355 .39551 .24104 .39309 Metetra
.664 .741 .907 r
.24104 .39309 .24355 .39551 .2473 .3942 .24479 .39178 Metetra
.664 .741 .907 r
.24479 .39178 .2473 .3942 .25105 .39289 .24854 .39047 Metetra
.664 .741 .907 r
.24854 .39047 .25105 .39289 .2548 .39158 .2523 .38916 Metetra
.664 .741 .907 r
.2523 .38916 .2548 .39158 .25856 .39027 .25606 .38784 Metetra
.664 .741 .907 r
.25606 .38784 .25856 .39027 .26233 .38895 .25983 .38652 Metetra
.664 .741 .907 r
.25983 .38652 .26233 .38895 .2661 .38764 .26361 .3852 Metetra
.664 .741 .907 r
.26361 .3852 .2661 .38764 .26987 .38632 .26738 .38388 Metetra
.664 .741 .907 r
.26738 .38388 .26987 .38632 .27366 .385 .27117 .38255 Metetra
.664 .741 .907 r
.27117 .38255 .27366 .385 .27744 .38367 .27496 .38123 Metetra
.664 .741 .907 r
.27496 .38123 .27744 .38367 .28124 .38235 .27876 .3799 Metetra
.664 .741 .907 r
.27876 .3799 .28124 .38235 .28503 .38102 .28256 .37857 Metetra
.664 .741 .907 r
.28256 .37857 .28503 .38102 .28884 .3797 .28636 .37724 Metetra
.664 .741 .907 r
.28636 .37724 .28884 .3797 .29265 .37837 .29018 .37591 Metetra
.664 .741 .907 r
.29018 .37591 .29265 .37837 .29646 .37703 .29399 .37457 Metetra
.664 .741 .907 r
.29399 .37457 .29646 .37703 .30028 .3757 .29782 .37323 Metetra
.664 .741 .907 r
.29782 .37323 .30028 .3757 .30411 .37436 .30165 .37189 Metetra
.664 .741 .907 r
.30165 .37189 .30411 .37436 .30794 .37303 .30548 .37055 Metetra
.664 .741 .907 r
.30548 .37055 .30794 .37303 .31177 .37169 .30932 .36921 Metetra
.664 .741 .907 r
.30932 .36921 .31177 .37169 .31562 .37034 .31317 .36786 Metetra
.664 .741 .907 r
.31317 .36786 .31562 .37034 .31946 .369 .31702 .36652 Metetra
.664 .741 .907 r
.31702 .36652 .31946 .369 .32332 .36766 .32088 .36517 Metetra
.664 .741 .907 r
.32088 .36517 .32332 .36766 .32718 .36631 .32474 .36382 Metetra
.664 .741 .907 r
.32474 .36382 .32718 .36631 .33104 .36496 .32861 .36246 Metetra
.664 .741 .907 r
.32861 .36246 .33104 .36496 .33491 .36361 .33248 .36111 Metetra
.664 .741 .907 r
.33248 .36111 .33491 .36361 .33879 .36225 .33636 .35975 Metetra
.664 .741 .907 r
.33636 .35975 .33879 .36225 .34267 .3609 .34024 .35839 Metetra
.664 .741 .907 r
.34024 .35839 .34267 .3609 .34656 .35954 .34414 .35703 Metetra
.664 .741 .907 r
.34414 .35703 .34656 .35954 .35045 .35818 .34803 .35567 Metetra
.664 .741 .907 r
.34803 .35567 .35045 .35818 .35435 .35682 .35193 .3543 Metetra
.664 .741 .907 r
.35193 .3543 .35435 .35682 .35825 .35546 .35584 .35293 Metetra
.664 .741 .907 r
.35584 .35293 .35825 .35546 .36216 .35409 .35976 .35157 Metetra
.664 .741 .907 r
.35976 .35157 .36216 .35409 .36608 .35272 .36368 .35019 Metetra
.664 .741 .907 r
.36368 .35019 .36608 .35272 .37 .35135 .3676 .34882 Metetra
.956 .682 .478 r
.3676 .34882 .37 .35135 .37393 .34998 .36044 .57679 Metetra
.517 .293 .513 r
.36044 .57679 .37393 .34998 .36723 .57788 .36507 .56667 Metetra
.909 .661 .553 r
.36507 .56667 .36723 .57788 .37288 .54484 .37163 .51401 Metetra
.757 .522 .577 r
.37163 .51401 .37288 .54484 .37878 .5044 .37698 .48608 Metetra
.771 .548 .597 r
.37698 .48608 .37878 .5044 .38388 .48085 .38184 .4679 Metetra
.776 .568 .618 r
.38184 .4679 .38388 .48085 .38861 .4648 .38645 .45472 Metetra
.778 .585 .639 r
.38645 .45472 .38861 .4648 .39315 .45284 .39092 .44449 Metetra
.777 .599 .659 r
.39092 .44449 .39315 .45284 .39757 .44338 .3953 .43618 Metetra
.775 .612 .678 r
.3953 .43618 .39757 .44338 .40191 .4356 .39961 .4292 Metetra
.771 .624 .696 r
.39961 .4292 .40191 .4356 .4062 .429 .40388 .42319 Metetra
.768 .634 .713 r
.40388 .42319 .4062 .429 .41045 .42327 .40812 .4179 Metetra
.763 .642 .728 r
.40812 .4179 .41045 .42327 .41468 .4182 .41234 .41317 Metetra
.759 .65 .741 r
.41234 .41317 .41468 .4182 .41839 .42862 .41654 .40888 Metetra
.21 .133 .545 r
.41654 .40888 .41839 .42862 .4226 .42466 .42024 .41996 Metetra
.739 .653 .765 r
.42024 .41996 .4226 .42466 .42679 .42104 .42443 .41652 Metetra
.733 .658 .775 r
.42443 .41652 .42679 .42104 .43097 .41772 .42862 .41333 Metetra
.727 .661 .784 r
.42862 .41333 .43097 .41772 .43515 .41463 .4328 .41037 Metetra
.722 .664 .793 r
.4328 .41037 .43515 .41463 .43933 .41176 .43697 .4076 Metetra
.716 .666 .8 r
.43697 .4076 .43933 .41176 .4435 .40908 .44115 .405 Metetra
.71 .668 .807 r
.44115 .405 .4435 .40908 .44768 .40655 .44532 .40254 Metetra
.705 .67 .813 r
.44532 .40254 .44768 .40655 .45185 .40417 .4495 .40022 Metetra
.7 .671 .819 r
.4495 .40022 .45185 .40417 .45603 .40191 .45367 .39801 Metetra
.694 .671 .824 r
.45367 .39801 .45603 .40191 .4602 .39978 .45785 .39592 Metetra
.689 .672 .828 r
.45785 .39592 .4602 .39978 .46438 .39775 .46203 .39393 Metetra
.684 .672 .832 r
.46203 .39393 .46438 .39775 .46856 .39583 .46622 .39203 Metetra
.679 .671 .836 r
.46622 .39203 .46856 .39583 .47275 .394 .4704 .39022 Metetra
.673 .671 .839 r
.4704 .39022 .47275 .394 .47693 .39225 .47459 .38849 Metetra
.668 .67 .842 r
.47459 .38849 .47693 .39225 .48113 .3906 .47879 .38684 Metetra
.663 .668 .845 r
.47879 .38684 .48113 .3906 .48533 .38903 .48299 .38528 Metetra
.657 .666 .847 r
.48299 .38528 .48533 .38903 .48953 .38754 .4872 .38379 Metetra
.651 .664 .85 r
.4872 .38379 .48953 .38754 .49374 .38613 .49141 .38237 Metetra
.646 .662 .851 r
.49141 .38237 .49374 .38613 .49795 .3848 .49562 .38103 Metetra
.64 .659 .853 r
.49562 .38103 .49795 .3848 .50217 .38355 .49985 .37977 Metetra
.633 .656 .854 r
.49985 .37977 .50217 .38355 .5064 .38239 .50408 .37859 Metetra
.627 .652 .856 r
.50408 .37859 .5064 .38239 .51063 .38131 .50831 .37749 Metetra
.619 .648 .856 r
.50831 .37749 .51063 .38131 .51487 .38033 .51256 .37648 Metetra
.612 .643 .857 r
.51256 .37648 .51487 .38033 .51912 .37944 .51681 .37555 Metetra
.604 .637 .857 r
.51681 .37555 .51912 .37944 .52338 .37865 .52107 .37472 Metetra
.595 .631 .857 r
.52107 .37472 .52338 .37865 .52764 .37797 .52533 .37399 Metetra
.585 .624 .857 r
.52533 .37399 .52764 .37797 .53192 .37741 .52961 .37338 Metetra
.575 .616 .856 r
.52961 .37338 .53192 .37741 .5362 .37698 .53389 .37288 Metetra
.563 .606 .854 r
.53389 .37288 .5362 .37698 .54049 .3767 .53819 .37252 Metetra
.549 .595 .852 r
.53819 .37252 .54049 .3767 .5448 .37658 .54249 .37231 Metetra
.534 .583 .85 r
.54249 .37231 .5448 .37658 .54911 .37665 .54681 .37227 Metetra
.517 .568 .846 r
.54681 .37227 .54911 .37665 .55344 .37694 .55113 .37242 Metetra
.498 .551 .841 r
.55113 .37242 .55344 .37694 .55778 .37747 .55548 .3728 Metetra
.475 .531 .835 r
.55548 .3728 .55778 .37747 .56214 .3783 .55983 .37344 Metetra
.904 .707 .626 r
.55983 .37344 .56214 .3783 .56651 .37949 .56402 .3594 Metetra
.515 .356 .604 r
.56402 .3594 .56651 .37949 .57069 .3661 .56839 .36089 Metetra
.356 .436 .806 r
.56839 .36089 .57069 .3661 .5751 .36841 .57279 .36284 Metetra
.311 .393 .785 r
.57279 .36284 .5751 .36841 .57953 .37139 .57721 .36536 Metetra
.257 .341 .759 r
.57721 .36536 .57953 .37139 .58399 .37525 .58166 .36862 Metetra
.192 .278 .724 r
.58166 .36862 .58399 .37525 .5885 .38032 .58615 .37287 Metetra
.113 .202 .679 r
.58615 .37287 .5885 .38032 .59307 .3871 .59069 .37847 Metetra
.02 .112 .62 r
.59069 .37847 .59307 .3871 .59773 .39645 .5953 .38604 Metetra
0 .007 .545 r
.5953 .38604 .59773 .39645 .60253 .40997 .60001 .39663 Metetra
0 0 .454 r
.60001 .39663 .60253 .40997 .60757 .43117 .60489 .41233 Metetra
0 0 .347 r
.60489 .41233 .60757 .43117 .61315 .46968 .61009 .43803 Metetra
0 0 .219 r
.61009 .43803 .61315 .46968 .61863 .50071 .61606 .48906 Metetra
.196 .192 .627 r
.61606 .48906 .61863 .50071 .61633 .26534 .62094 .49667 Metetra
0 0 .357 r
.62094 .49667 .61633 .26534 .62063 .26384 .61847 .26106 Metetra
.664 .741 .907 r
.61847 .26106 .62063 .26384 .62493 .26234 .62278 .25956 Metetra
.664 .741 .907 r
.62278 .25956 .62493 .26234 .62924 .26083 .62709 .25805 Metetra
.664 .741 .907 r
.62709 .25805 .62924 .26083 .63356 .25932 .63142 .25653 Metetra
.664 .741 .907 r
.63142 .25653 .63356 .25932 .63788 .25781 .63574 .25502 Metetra
.664 .741 .907 r
.63574 .25502 .63788 .25781 .64221 .2563 .64008 .2535 Metetra
.664 .741 .907 r
.64008 .2535 .64221 .2563 .64655 .25479 .64442 .25198 Metetra
.664 .741 .907 r
.64442 .25198 .64655 .25479 .6509 .25327 .64877 .25046 Metetra
.664 .741 .907 r
.64877 .25046 .6509 .25327 .65525 .25175 .65313 .24894 Metetra
.664 .741 .907 r
.65313 .24894 .65525 .25175 .65961 .25023 .65749 .24741 Metetra
.664 .741 .907 r
.65749 .24741 .65961 .25023 .66397 .24871 .66186 .24589 Metetra
.664 .741 .907 r
.66186 .24589 .66397 .24871 .66834 .24718 .66624 .24435 Metetra
.664 .741 .907 r
.66624 .24435 .66834 .24718 .67272 .24565 .67062 .24282 Metetra
.664 .741 .907 r
.67062 .24282 .67272 .24565 .67711 .24412 .67501 .24129 Metetra
.664 .741 .907 r
.67501 .24129 .67711 .24412 .6815 .24258 .6794 .23975 Metetra
.664 .741 .907 r
.6794 .23975 .6815 .24258 .6859 .24105 .68381 .23821 Metetra
.664 .741 .907 r
.68381 .23821 .6859 .24105 .6903 .23951 .68822 .23666 Metetra
.664 .741 .907 r
.68822 .23666 .6903 .23951 .69472 .23797 .69264 .23512 Metetra
.664 .741 .907 r
.69264 .23512 .69472 .23797 .69913 .23643 .69706 .23357 Metetra
.664 .741 .907 r
.69706 .23357 .69913 .23643 .70356 .23488 .70149 .23202 Metetra
.664 .741 .907 r
.70149 .23202 .70356 .23488 .70799 .23333 .70593 .23047 Metetra
.664 .741 .907 r
.70593 .23047 .70799 .23333 .71243 .23178 .71037 .22891 Metetra
.664 .741 .907 r
.71037 .22891 .71243 .23178 .71688 .23023 .71483 .22736 Metetra
.664 .741 .907 r
.71483 .22736 .71688 .23023 .72133 .22867 .71928 .2258 Metetra
.664 .741 .907 r
.71928 .2258 .72133 .22867 .7258 .22712 .72375 .22423 Metetra
.664 .741 .907 r
.72375 .22423 .7258 .22712 .73026 .22556 .72822 .22267 Metetra
.664 .741 .907 r
.72822 .22267 .73026 .22556 .73474 .22399 .7327 .2211 Metetra
.664 .741 .907 r
.7327 .2211 .73474 .22399 .73922 .22243 .73719 .21953 Metetra
.664 .741 .907 r
.73719 .21953 .73922 .22243 .74371 .22086 .74168 .21796 Metetra
.664 .741 .907 r
.74168 .21796 .74371 .22086 .74821 .21929 .74618 .21639 Metetra
.664 .741 .907 r
.74618 .21639 .74821 .21929 .75271 .21772 .75069 .21481 Metetra
.664 .741 .907 r
.75069 .21481 .75271 .21772 .75722 .21614 .75521 .21323 Metetra
.664 .741 .907 r
.75521 .21323 .75722 .21614 .76174 .21457 .75973 .21165 Metetra
.664 .741 .907 r
.75973 .21165 .76174 .21457 .76626 .21299 .76426 .21006 Metetra
.664 .741 .907 r
.76426 .21006 .76626 .21299 .77079 .2114 .7688 .20848 Metetra
.664 .741 .907 r
.7688 .20848 .77079 .2114 .77533 .20982 .77334 .20689 Metetra
.664 .741 .907 r
.77334 .20689 .77533 .20982 .77988 .20823 .77789 .2053 Metetra
.664 .741 .907 r
.77789 .2053 .77988 .20823 .78443 .20664 .78245 .2037 Metetra
.664 .741 .907 r
.78245 .2037 .78443 .20664 .78899 .20505 .78702 .2021 Metetra
.664 .741 .907 r
.78702 .2021 .78899 .20505 .79356 .20346 .79159 .2005 Metetra
.664 .741 .907 r
.79159 .2005 .79356 .20346 .79813 .20186 .79617 .1989 Metetra
.664 .741 .907 r
.79617 .1989 .79813 .20186 .80272 .20026 .80076 .1973 Metetra
.664 .741 .907 r
.80076 .1973 .80272 .20026 .8073 .19866 .80535 .19569 Metetra
.664 .741 .907 r
.80535 .19569 .8073 .19866 .8119 .19705 .80995 .19408 Metetra
.664 .741 .907 r
.80995 .19408 .8119 .19705 .81651 .19544 .81456 .19247 Metetra
.664 .741 .907 r
.19763 .405 .20018 .40739 .20387 .4061 .20132 .40371 Metetra
.664 .741 .907 r
.20132 .40371 .20387 .4061 .20756 .40481 .20502 .40242 Metetra
.664 .741 .907 r
.20502 .40242 .20756 .40481 .21126 .40351 .20872 .40112 Metetra
.664 .741 .907 r
.20872 .40112 .21126 .40351 .21496 .40222 .21242 .39982 Metetra
.664 .741 .907 r
.21242 .39982 .21496 .40222 .21867 .40092 .21614 .39852 Metetra
.664 .741 .907 r
.21614 .39852 .21867 .40092 .22239 .39962 .21985 .39721 Metetra
.664 .741 .907 r
.21985 .39721 .22239 .39962 .22611 .39832 .22358 .39591 Metetra
.664 .741 .907 r
.22358 .39591 .22611 .39832 .22983 .39701 .22731 .3946 Metetra
.664 .741 .907 r
.22731 .3946 .22983 .39701 .23357 .39571 .23104 .39329 Metetra
.664 .741 .907 r
.23104 .39329 .23357 .39571 .2373 .3944 .23478 .39198 Metetra
.664 .741 .907 r
.23478 .39198 .2373 .3944 .24104 .39309 .23852 .39067 Metetra
.664 .741 .907 r
.23852 .39067 .24104 .39309 .24479 .39178 .24227 .38936 Metetra
.664 .741 .907 r
.24227 .38936 .24479 .39178 .24854 .39047 .24603 .38804 Metetra
.664 .741 .907 r
.24603 .38804 .24854 .39047 .2523 .38916 .24979 .38672 Metetra
.664 .741 .907 r
.24979 .38672 .2523 .38916 .25606 .38784 .25356 .3854 Metetra
.664 .741 .907 r
.25356 .3854 .25606 .38784 .25983 .38652 .25733 .38408 Metetra
.664 .741 .907 r
.25733 .38408 .25983 .38652 .26361 .3852 .26111 .38276 Metetra
.664 .741 .907 r
.26111 .38276 .26361 .3852 .26738 .38388 .26489 .38143 Metetra
.664 .741 .907 r
.26489 .38143 .26738 .38388 .27117 .38255 .26868 .3801 Metetra
.664 .741 .907 r
.26868 .3801 .27117 .38255 .27496 .38123 .27247 .37878 Metetra
.664 .741 .907 r
.27247 .37878 .27496 .38123 .27876 .3799 .27627 .37744 Metetra
.664 .741 .907 r
.27627 .37744 .27876 .3799 .28256 .37857 .28007 .37611 Metetra
.664 .741 .907 r
.28007 .37611 .28256 .37857 .28636 .37724 .28388 .37478 Metetra
.664 .741 .907 r
.28388 .37478 .28636 .37724 .29018 .37591 .2877 .37344 Metetra
.664 .741 .907 r
.2877 .37344 .29018 .37591 .29399 .37457 .29152 .3721 Metetra
.664 .741 .907 r
.29152 .3721 .29399 .37457 .29782 .37323 .29535 .37076 Metetra
.664 .741 .907 r
.29535 .37076 .29782 .37323 .30165 .37189 .29918 .36941 Metetra
.664 .741 .907 r
.29918 .36941 .30165 .37189 .30548 .37055 .30302 .36807 Metetra
.664 .741 .907 r
.30302 .36807 .30548 .37055 .30932 .36921 .30686 .36672 Metetra
.664 .741 .907 r
.30686 .36672 .30932 .36921 .31317 .36786 .31071 .36537 Metetra
.664 .741 .907 r
.31071 .36537 .31317 .36786 .31702 .36652 .31457 .36402 Metetra
.664 .741 .907 r
.31457 .36402 .31702 .36652 .32088 .36517 .31843 .36267 Metetra
.664 .741 .907 r
.31843 .36267 .32088 .36517 .32474 .36382 .32229 .36132 Metetra
.664 .741 .907 r
.32229 .36132 .32474 .36382 .32861 .36246 .32616 .35996 Metetra
.664 .741 .907 r
.32616 .35996 .32861 .36246 .33248 .36111 .33004 .3586 Metetra
.664 .741 .907 r
.33004 .3586 .33248 .36111 .33636 .35975 .33392 .35724 Metetra
.664 .741 .907 r
.33392 .35724 .33636 .35975 .34024 .35839 .33781 .35588 Metetra
.664 .741 .907 r
.33781 .35588 .34024 .35839 .34414 .35703 .34171 .35451 Metetra
.664 .741 .907 r
.34171 .35451 .34414 .35703 .34803 .35567 .34561 .35314 Metetra
.664 .741 .907 r
.34561 .35314 .34803 .35567 .35193 .3543 .34951 .35178 Metetra
.664 .741 .907 r
.34951 .35178 .35193 .3543 .35584 .35293 .35342 .35041 Metetra
.664 .741 .907 r
.35342 .35041 .35584 .35293 .35976 .35157 .35734 .34903 Metetra
.664 .741 .907 r
.35734 .34903 .35976 .35157 .36368 .35019 .36126 .34766 Metetra
.955 .682 .479 r
.36126 .34766 .36368 .35019 .3676 .34882 .35363 .57569 Metetra
.532 .304 .515 r
.35363 .57569 .3676 .34882 .36044 .57679 .35784 .5744 Metetra
.95 .711 .541 r
.35784 .5744 .36044 .57679 .36507 .56667 .3643 .5263 Metetra
.748 .509 .57 r
.3643 .5263 .36507 .56667 .37163 .51401 .36999 .4924 Metetra
.766 .539 .59 r
.36999 .4924 .37163 .51401 .37698 .48608 .37502 .47156 Metetra
.774 .561 .61 r
.37502 .47156 .37698 .48608 .38184 .4679 .37972 .45692 Metetra
.777 .579 .631 r
.37972 .45692 .38184 .4679 .38645 .45472 .38425 .44581 Metetra
.777 .594 .652 r
.38425 .44581 .38645 .45472 .39092 .44449 .38867 .43691 Metetra
.775 .607 .672 r
.38867 .43691 .39092 .44449 .3953 .43618 .39301 .42951 Metetra
.772 .619 .69 r
.39301 .42951 .3953 .43618 .39961 .4292 .3973 .42319 Metetra
.769 .63 .707 r
.3973 .42319 .39961 .4292 .40388 .42319 .40156 .41766 Metetra
.765 .639 .722 r
.40156 .41766 .40388 .42319 .40812 .4179 .40579 .41274 Metetra
.76 .647 .737 r
.40579 .41274 .40812 .4179 .41234 .41317 .41 .40831 Metetra
.755 .654 .749 r
.41 .40831 .41234 .41317 .41654 .40888 .41419 .40426 Metetra
.751 .66 .761 r
.41419 .40426 .41654 .40888 .42024 .41996 .41837 .40054 Metetra
.609 .425 .607 r
.41837 .40054 .42024 .41996 .42443 .41652 .42255 .39707 Metetra
.165 .102 .534 r
.42255 .39707 .42443 .41652 .42862 .41333 .42625 .40903 Metetra
.724 .664 .79 r
.42625 .40903 .42862 .41333 .4328 .41037 .43043 .40618 Metetra
.719 .666 .797 r
.43043 .40618 .4328 .41037 .43697 .4076 .43461 .4035 Metetra
.714 .669 .804 r
.43461 .4035 .43697 .4076 .44115 .405 .43879 .40097 Metetra
.708 .67 .811 r
.43879 .40097 .44115 .405 .44532 .40254 .44296 .39858 Metetra
.703 .672 .817 r
.44296 .39858 .44532 .40254 .4495 .40022 .44714 .39631 Metetra
.698 .673 .822 r
.44714 .39631 .4495 .40022 .45367 .39801 .45132 .39415 Metetra
.693 .673 .827 r
.45132 .39415 .45367 .39801 .45785 .39592 .4555 .39209 Metetra
.688 .673 .831 r
.4555 .39209 .45785 .39592 .46203 .39393 .45968 .39013 Metetra
.683 .673 .835 r
.45968 .39013 .46203 .39393 .46622 .39203 .46386 .38826 Metetra
.678 .673 .838 r
.46386 .38826 .46622 .39203 .4704 .39022 .46805 .38646 Metetra
.673 .672 .841 r
.46805 .38646 .4704 .39022 .47459 .38849 .47225 .38475 Metetra
.667 .671 .844 r
.47225 .38475 .47459 .38849 .47879 .38684 .47645 .38311 Metetra
.662 .67 .847 r
.47645 .38311 .47879 .38684 .48299 .38528 .48065 .38155 Metetra
.657 .668 .849 r
.48065 .38155 .48299 .38528 .4872 .38379 .48486 .38006 Metetra
.652 .666 .851 r
.48486 .38006 .4872 .38379 .49141 .38237 .48907 .37864 Metetra
.646 .664 .853 r
.48907 .37864 .49141 .38237 .49562 .38103 .49329 .3773 Metetra
.64 .661 .855 r
.49329 .3773 .49562 .38103 .49985 .37977 .49752 .37602 Metetra
.634 .658 .856 r
.49752 .37602 .49985 .37977 .50408 .37859 .50175 .37482 Metetra
.628 .655 .857 r
.50175 .37482 .50408 .37859 .50831 .37749 .50599 .3737 Metetra
.621 .651 .858 r
.50599 .3737 .50831 .37749 .51256 .37648 .51023 .37266 Metetra
.614 .646 .858 r
.51023 .37266 .51256 .37648 .51681 .37555 .51449 .3717 Metetra
.607 .641 .859 r
.51449 .3717 .51681 .37555 .52107 .37472 .51875 .37083 Metetra
.598 .635 .859 r
.51875 .37083 .52107 .37472 .52533 .37399 .52302 .37005 Metetra
.589 .629 .858 r
.52302 .37005 .52533 .37399 .52961 .37338 .52729 .36938 Metetra
.579 .621 .858 r
.52729 .36938 .52961 .37338 .53389 .37288 .53158 .36882 Metetra
.568 .612 .856 r
.53158 .36882 .53389 .37288 .53819 .37252 .53588 .36839 Metetra
.556 .602 .855 r
.53588 .36839 .53819 .37252 .54249 .37231 .54018 .36809 Metetra
.543 .591 .852 r
.54018 .36809 .54249 .37231 .54681 .37227 .5445 .36795 Metetra
.527 .577 .849 r
.5445 .36795 .54681 .37227 .55113 .37242 .54883 .36799 Metetra
.915 .716 .619 r
.54883 .36799 .55113 .37242 .55548 .3728 .55303 .35306 Metetra
.532 .369 .606 r
.55303 .35306 .55548 .3728 .55983 .37344 .55737 .3537 Metetra
.526 .365 .605 r
.55737 .3537 .55983 .37344 .56402 .3594 .56172 .35462 Metetra
.415 .491 .829 r
.56172 .35462 .56402 .3594 .56839 .36089 .56609 .35586 Metetra
.382 .459 .816 r
.56609 .35586 .56839 .36089 .57279 .36284 .57048 .35749 Metetra
.342 .422 .799 r
.57048 .35749 .57279 .36284 .57721 .36536 .57489 .35962 Metetra
.294 .376 .777 r
.57489 .35962 .57721 .36536 .58166 .36862 .57933 .36238 Metetra
.237 .321 .747 r
.57933 .36238 .58166 .36862 .58615 .37287 .5838 .36595 Metetra
.167 .254 .709 r
.5838 .36595 .58615 .37287 .59069 .37847 .58832 .37062 Metetra
.085 .173 .66 r
.58832 .37062 .59069 .37847 .5953 .38604 .59289 .37682 Metetra
0 .078 .596 r
.59289 .37682 .5953 .38604 .60001 .39663 .59754 .38529 Metetra
0 0 .516 r
.59754 .38529 .60001 .39663 .60489 .41233 .60232 .39737 Metetra
0 0 .42 r
.60232 .39737 .60489 .41233 .61009 .43803 .6073 .4158 Metetra
0 0 .308 r
.6073 .4158 .61009 .43803 .61606 .48906 .6127 .4476 Metetra
0 0 .382 r
.6127 .4476 .61606 .48906 .62094 .49667 .61862 .49404 Metetra
.645 .763 .934 r
.61862 .49404 .62094 .49667 .61847 .26106 .62326 .49261 Metetra
0 0 .357 r
.62326 .49261 .61847 .26106 .62278 .25956 .62062 .25677 Metetra
.664 .741 .907 r
.62062 .25677 .62278 .25956 .62709 .25805 .62494 .25525 Metetra
.664 .741 .907 r
.62494 .25525 .62709 .25805 .63142 .25653 .62927 .25374 Metetra
.664 .741 .907 r
.62927 .25374 .63142 .25653 .63574 .25502 .6336 .25222 Metetra
.664 .741 .907 r
.6336 .25222 .63574 .25502 .64008 .2535 .63794 .2507 Metetra
.664 .741 .907 r
.63794 .2507 .64008 .2535 .64442 .25198 .64229 .24917 Metetra
.664 .741 .907 r
.64229 .24917 .64442 .25198 .64877 .25046 .64664 .24765 Metetra
.664 .741 .907 r
.64664 .24765 .64877 .25046 .65313 .24894 .651 .24612 Metetra
.664 .741 .907 r
.651 .24612 .65313 .24894 .65749 .24741 .65537 .24459 Metetra
.664 .741 .907 r
.65537 .24459 .65749 .24741 .66186 .24589 .65974 .24306 Metetra
.664 .741 .907 r
.65974 .24306 .66186 .24589 .66624 .24435 .66412 .24152 Metetra
.664 .741 .907 r
.66412 .24152 .66624 .24435 .67062 .24282 .66851 .23998 Metetra
.664 .741 .907 r
.66851 .23998 .67062 .24282 .67501 .24129 .6729 .23844 Metetra
.664 .741 .907 r
.6729 .23844 .67501 .24129 .6794 .23975 .67731 .2369 Metetra
.664 .741 .907 r
.67731 .2369 .6794 .23975 .68381 .23821 .68171 .23536 Metetra
.664 .741 .907 r
.68171 .23536 .68381 .23821 .68822 .23666 .68613 .23381 Metetra
.664 .741 .907 r
.68613 .23381 .68822 .23666 .69264 .23512 .69055 .23226 Metetra
.664 .741 .907 r
.69055 .23226 .69264 .23512 .69706 .23357 .69498 .23071 Metetra
.664 .741 .907 r
.69498 .23071 .69706 .23357 .70149 .23202 .69942 .22915 Metetra
.664 .741 .907 r
.69942 .22915 .70149 .23202 .70593 .23047 .70386 .2276 Metetra
.664 .741 .907 r
.70386 .2276 .70593 .23047 .71037 .22891 .70831 .22604 Metetra
.664 .741 .907 r
.70831 .22604 .71037 .22891 .71483 .22736 .71276 .22448 Metetra
.664 .741 .907 r
.71276 .22448 .71483 .22736 .71928 .2258 .71723 .22291 Metetra
.664 .741 .907 r
.71723 .22291 .71928 .2258 .72375 .22423 .7217 .22134 Metetra
.664 .741 .907 r
.7217 .22134 .72375 .22423 .72822 .22267 .72618 .21978 Metetra
.664 .741 .907 r
.72618 .21978 .72822 .22267 .7327 .2211 .73066 .2182 Metetra
.664 .741 .907 r
.73066 .2182 .7327 .2211 .73719 .21953 .73515 .21663 Metetra
.664 .741 .907 r
.73515 .21663 .73719 .21953 .74168 .21796 .73965 .21505 Metetra
.664 .741 .907 r
.73965 .21505 .74168 .21796 .74618 .21639 .74416 .21347 Metetra
.664 .741 .907 r
.74416 .21347 .74618 .21639 .75069 .21481 .74867 .21189 Metetra
.664 .741 .907 r
.74867 .21189 .75069 .21481 .75521 .21323 .75319 .21031 Metetra
.664 .741 .907 r
.75319 .21031 .75521 .21323 .75973 .21165 .75772 .20872 Metetra
.664 .741 .907 r
.75772 .20872 .75973 .21165 .76426 .21006 .76225 .20713 Metetra
.664 .741 .907 r
.76225 .20713 .76426 .21006 .7688 .20848 .76679 .20554 Metetra
.664 .741 .907 r
.76679 .20554 .7688 .20848 .77334 .20689 .77134 .20395 Metetra
.664 .741 .907 r
.77134 .20395 .77334 .20689 .77789 .2053 .7759 .20235 Metetra
.664 .741 .907 r
.7759 .20235 .77789 .2053 .78245 .2037 .78046 .20075 Metetra
.664 .741 .907 r
.78046 .20075 .78245 .2037 .78702 .2021 .78503 .19915 Metetra
.664 .741 .907 r
.78503 .19915 .78702 .2021 .79159 .2005 .78961 .19754 Metetra
.664 .741 .907 r
.78961 .19754 .79159 .2005 .79617 .1989 .7942 .19594 Metetra
.664 .741 .907 r
.7942 .19594 .79617 .1989 .80076 .1973 .79879 .19433 Metetra
.664 .741 .907 r
.79879 .19433 .80076 .1973 .80535 .19569 .80339 .19272 Metetra
.664 .741 .907 r
.80339 .19272 .80535 .19569 .80995 .19408 .808 .1911 Metetra
.664 .741 .907 r
.808 .1911 .80995 .19408 .81456 .19247 .81261 .18948 Metetra
.664 .741 .907 r
.19507 .40261 .19763 .405 .20132 .40371 .19876 .40132 Metetra
.664 .741 .907 r
.19876 .40132 .20132 .40371 .20502 .40242 .20246 .40002 Metetra
.664 .741 .907 r
.20246 .40002 .20502 .40242 .20872 .40112 .20617 .39872 Metetra
.664 .741 .907 r
.20617 .39872 .20872 .40112 .21242 .39982 .20988 .39742 Metetra
.664 .741 .907 r
.20988 .39742 .21242 .39982 .21614 .39852 .21359 .39611 Metetra
.664 .741 .907 r
.21359 .39611 .21614 .39852 .21985 .39721 .21731 .3948 Metetra
.664 .741 .907 r
.21731 .3948 .21985 .39721 .22358 .39591 .22104 .3935 Metetra
.664 .741 .907 r
.22104 .3935 .22358 .39591 .22731 .3946 .22477 .39219 Metetra
.664 .741 .907 r
.22477 .39219 .22731 .3946 .23104 .39329 .22851 .39087 Metetra
.664 .741 .907 r
.22851 .39087 .23104 .39329 .23478 .39198 .23225 .38956 Metetra
.664 .741 .907 r
.23225 .38956 .23478 .39198 .23852 .39067 .236 .38824 Metetra
.664 .741 .907 r
.236 .38824 .23852 .39067 .24227 .38936 .23975 .38693 Metetra
.664 .741 .907 r
.23975 .38693 .24227 .38936 .24603 .38804 .24351 .38561 Metetra
.664 .741 .907 r
.24351 .38561 .24603 .38804 .24979 .38672 .24728 .38429 Metetra
.664 .741 .907 r
.24728 .38429 .24979 .38672 .25356 .3854 .25105 .38296 Metetra
.664 .741 .907 r
.25105 .38296 .25356 .3854 .25733 .38408 .25482 .38164 Metetra
.664 .741 .907 r
.25482 .38164 .25733 .38408 .26111 .38276 .2586 .38031 Metetra
.664 .741 .907 r
.2586 .38031 .26111 .38276 .26489 .38143 .26239 .37898 Metetra
.664 .741 .907 r
.26239 .37898 .26489 .38143 .26868 .3801 .26618 .37765 Metetra
.664 .741 .907 r
.26618 .37765 .26868 .3801 .27247 .37878 .26998 .37632 Metetra
.664 .741 .907 r
.26998 .37632 .27247 .37878 .27627 .37744 .27378 .37498 Metetra
.664 .741 .907 r
.27378 .37498 .27627 .37744 .28007 .37611 .27759 .37364 Metetra
.664 .741 .907 r
.27759 .37364 .28007 .37611 .28388 .37478 .2814 .37231 Metetra
.664 .741 .907 r
.2814 .37231 .28388 .37478 .2877 .37344 .28522 .37096 Metetra
.664 .741 .907 r
.28522 .37096 .2877 .37344 .29152 .3721 .28904 .36962 Metetra
.664 .741 .907 r
.28904 .36962 .29152 .3721 .29535 .37076 .29287 .36828 Metetra
.664 .741 .907 r
.29287 .36828 .29535 .37076 .29918 .36941 .29671 .36693 Metetra
.664 .741 .907 r
.29671 .36693 .29918 .36941 .30302 .36807 .30055 .36558 Metetra
.664 .741 .907 r
.30055 .36558 .30302 .36807 .30686 .36672 .3044 .36423 Metetra
.664 .741 .907 r
.3044 .36423 .30686 .36672 .31071 .36537 .30825 .36288 Metetra
.664 .741 .907 r
.30825 .36288 .31071 .36537 .31457 .36402 .31211 .36152 Metetra
.664 .741 .907 r
.31211 .36152 .31457 .36402 .31843 .36267 .31597 .36017 Metetra
.664 .741 .907 r
.31597 .36017 .31843 .36267 .32229 .36132 .31984 .35881 Metetra
.664 .741 .907 r
.31984 .35881 .32229 .36132 .32616 .35996 .32372 .35745 Metetra
.664 .741 .907 r
.32372 .35745 .32616 .35996 .33004 .3586 .3276 .35609 Metetra
.664 .741 .907 r
.3276 .35609 .33004 .3586 .33392 .35724 .33148 .35472 Metetra
.664 .741 .907 r
.33148 .35472 .33392 .35724 .33781 .35588 .33537 .35336 Metetra
.664 .741 .907 r
.33537 .35336 .33781 .35588 .34171 .35451 .33927 .35199 Metetra
.664 .741 .907 r
.33927 .35199 .34171 .35451 .34561 .35314 .34318 .35062 Metetra
.664 .741 .907 r
.34318 .35062 .34561 .35314 .34951 .35178 .34708 .34924 Metetra
.664 .741 .907 r
.34708 .34924 .34951 .35178 .35342 .35041 .351 .34787 Metetra
.664 .741 .907 r
.351 .34787 .35342 .35041 .35734 .34903 .35492 .34649 Metetra
.664 .741 .907 r
.35492 .34649 .35734 .34903 .36126 .34766 .35885 .34511 Metetra
.955 .682 .479 r
.35885 .34511 .36126 .34766 .35363 .57569 .35103 .5733 Metetra
.945 .722 .569 r
.35103 .5733 .35363 .57569 .35784 .5744 .35671 .54251 Metetra
.802 .557 .569 r
.35671 .54251 .35784 .5744 .3643 .5263 .3629 .50013 Metetra
.761 .529 .582 r
.3629 .50013 .3643 .5263 .36999 .4924 .36813 .47589 Metetra
.771 .553 .603 r
.36813 .47589 .36999 .4924 .37502 .47156 .37295 .45951 Metetra
.775 .572 .624 r
.37295 .45951 .37502 .47156 .37972 .45692 .37755 .44736 Metetra
.776 .588 .645 r
.37755 .44736 .37972 .45692 .38425 .44581 .38201 .43779 Metetra
.775 .602 .665 r
.38201 .43779 .38425 .44581 .38867 .43691 .38639 .42993 Metetra
.773 .615 .683 r
.38639 .42993 .38867 .43691 .39301 .42951 .3907 .42327 Metetra
.77 .626 .701 r
.3907 .42327 .39301 .42951 .3973 .42319 .39497 .41749 Metetra
.766 .636 .717 r
.39497 .41749 .3973 .42319 .40156 .41766 .39922 .41237 Metetra
.762 .644 .732 r
.39922 .41237 .40156 .41766 .40579 .41274 .40344 .40778 Metetra
.757 .652 .745 r
.40344 .40778 .40579 .41274 .41 .40831 .40764 .4036 Metetra
.752 .658 .757 r
.40764 .4036 .41 .40831 .41419 .40426 .41183 .39977 Metetra
.748 .664 .768 r
.41183 .39977 .41419 .40426 .41837 .40054 .41601 .39621 Metetra
.743 .669 .778 r
.41601 .39621 .41837 .40054 .42255 .39707 .42019 .39289 Metetra
.738 .673 .787 r
.42019 .39289 .42255 .39707 .42625 .40903 .42435 .38977 Metetra
.145 .088 .529 r
.42435 .38977 .42625 .40903 .43043 .40618 .42806 .40205 Metetra
.716 .669 .802 r
.42806 .40205 .43043 .40618 .43461 .4035 .43224 .39945 Metetra
.711 .671 .809 r
.43224 .39945 .43461 .4035 .43879 .40097 .43642 .397 Metetra
.706 .672 .815 r
.43642 .397 .43879 .40097 .44296 .39858 .44059 .39466 Metetra
.701 .674 .82 r
.44059 .39466 .44296 .39858 .44714 .39631 .44477 .39244 Metetra
.696 .674 .825 r
.44477 .39244 .44714 .39631 .45132 .39415 .44895 .39032 Metetra
.691 .675 .829 r
.44895 .39032 .45132 .39415 .4555 .39209 .45313 .3883 Metetra
.686 .675 .833 r
.45313 .3883 .4555 .39209 .45968 .39013 .45732 .38636 Metetra
.682 .675 .837 r
.45732 .38636 .45968 .39013 .46386 .38826 .46151 .38451 Metetra
.677 .675 .841 r
.46151 .38451 .46386 .38826 .46805 .38646 .4657 .38274 Metetra
.672 .674 .844 r
.4657 .38274 .46805 .38646 .47225 .38475 .4699 .38104 Metetra
.667 .673 .846 r
.4699 .38104 .47225 .38475 .47645 .38311 .4741 .37941 Metetra
.662 .672 .849 r
.4741 .37941 .47645 .38311 .48065 .38155 .4783 .37785 Metetra
.657 .67 .851 r
.4783 .37785 .48065 .38155 .48486 .38006 .48251 .37636 Metetra
.652 .668 .853 r
.48251 .37636 .48486 .38006 .48907 .37864 .48673 .37493 Metetra
.647 .666 .855 r
.48673 .37493 .48907 .37864 .49329 .3773 .49095 .37358 Metetra
.641 .664 .856 r
.49095 .37358 .49329 .3773 .49752 .37602 .49518 .37229 Metetra
.636 .661 .857 r
.49518 .37229 .49752 .37602 .50175 .37482 .49942 .37108 Metetra
.63 .657 .858 r
.49942 .37108 .50175 .37482 .50599 .3737 .50366 .36993 Metetra
.623 .654 .859 r
.50366 .36993 .50599 .3737 .51023 .37266 .50791 .36887 Metetra
.617 .649 .86 r
.50791 .36887 .51023 .37266 .51449 .3717 .51216 .36788 Metetra
.609 .645 .86 r
.51216 .36788 .51449 .3717 .51875 .37083 .51643 .36697 Metetra
.602 .639 .86 r
.51643 .36697 .51875 .37083 .52302 .37005 .5207 .36615 Metetra
.593 .633 .86 r
.5207 .36615 .52302 .37005 .52729 .36938 .52498 .36543 Metetra
.584 .626 .859 r
.52498 .36543 .52729 .36938 .53158 .36882 .52926 .36481 Metetra
.574 .618 .858 r
.52926 .36481 .53158 .36882 .53588 .36839 .53356 .36431 Metetra
.563 .609 .857 r
.53356 .36431 .53588 .36839 .54018 .36809 .53787 .36393 Metetra
.55 .598 .855 r
.53787 .36393 .54018 .36809 .5445 .36795 .54219 .3637 Metetra
.92 .72 .617 r
.54219 .3637 .5445 .36795 .54883 .36799 .54641 .34844 Metetra
.538 .374 .606 r
.54641 .34844 .54883 .36799 .55303 .35306 .55073 .34873 Metetra
.48 .552 .852 r
.55073 .34873 .55303 .35306 .55737 .3537 .55507 .34922 Metetra
.459 .532 .845 r
.55507 .34922 .55737 .3537 .56172 .35462 .55942 .34996 Metetra
.433 .508 .836 r
.55942 .34996 .56172 .35462 .56609 .35586 .56379 .35098 Metetra
.404 .48 .825 r
.56379 .35098 .56609 .35586 .57048 .35749 .56817 .35234 Metetra
.369 .447 .81 r
.56817 .35234 .57048 .35749 .57489 .35962 .57258 .35413 Metetra
.327 .407 .791 r
.57258 .35413 .57489 .35962 .57933 .36238 .57701 .35646 Metetra
.276 .358 .767 r
.57701 .35646 .57933 .36238 .5838 .36595 .58147 .35947 Metetra
.215 .299 .735 r
.58147 .35947 .5838 .36595 .58832 .37062 .58596 .36338 Metetra
.142 .228 .694 r
.58596 .36338 .58832 .37062 .59289 .37682 .59051 .36851 Metetra
.055 .143 .64 r
.59051 .36851 .59289 .37682 .59754 .38529 .59511 .3754 Metetra
0 .043 .571 r
.59511 .3754 .59754 .38529 .60232 .39737 .59981 .38492 Metetra
0 0 .486 r
.59981 .38492 .60232 .39737 .6073 .4158 .60466 .39878 Metetra
0 0 .385 r
.60466 .39878 .6073 .4158 .6127 .4476 .60976 .42069 Metetra
0 0 .267 r
.60976 .42069 .6127 .4476 .61862 .49404 .61546 .46121 Metetra
.029 0 .468 r
.61546 .46121 .61862 .49404 .62326 .49261 .62093 .48996 Metetra
.976 .69 .417 r
.62093 .48996 .62326 .49261 .62062 .25677 .61845 .25397 Metetra
.664 .741 .907 r
.61845 .25397 .62062 .25677 .62494 .25525 .62278 .25245 Metetra
.664 .741 .907 r
.62278 .25245 .62494 .25525 .62927 .25374 .62711 .25093 Metetra
.664 .741 .907 r
.62711 .25093 .62927 .25374 .6336 .25222 .63145 .24941 Metetra
.664 .741 .907 r
.63145 .24941 .6336 .25222 .63794 .2507 .63579 .24788 Metetra
.664 .741 .907 r
.63579 .24788 .63794 .2507 .64229 .24917 .64014 .24636 Metetra
.664 .741 .907 r
.64014 .24636 .64229 .24917 .64664 .24765 .6445 .24483 Metetra
.664 .741 .907 r
.6445 .24483 .64664 .24765 .651 .24612 .64887 .24329 Metetra
.664 .741 .907 r
.64887 .24329 .651 .24612 .65537 .24459 .65324 .24176 Metetra
.664 .741 .907 r
.65324 .24176 .65537 .24459 .65974 .24306 .65762 .24022 Metetra
.664 .741 .907 r
.65762 .24022 .65974 .24306 .66412 .24152 .662 .23868 Metetra
.664 .741 .907 r
.662 .23868 .66412 .24152 .66851 .23998 .6664 .23714 Metetra
.664 .741 .907 r
.6664 .23714 .66851 .23998 .6729 .23844 .67079 .23559 Metetra
.664 .741 .907 r
.67079 .23559 .6729 .23844 .67731 .2369 .6752 .23405 Metetra
.664 .741 .907 r
.6752 .23405 .67731 .2369 .68171 .23536 .67961 .2325 Metetra
.664 .741 .907 r
.67961 .2325 .68171 .23536 .68613 .23381 .68403 .23095 Metetra
.664 .741 .907 r
.68403 .23095 .68613 .23381 .69055 .23226 .68846 .22939 Metetra
.664 .741 .907 r
.68846 .22939 .69055 .23226 .69498 .23071 .69289 .22784 Metetra
.664 .741 .907 r
.69289 .22784 .69498 .23071 .69942 .22915 .69733 .22628 Metetra
.664 .741 .907 r
.69733 .22628 .69942 .22915 .70386 .2276 .70178 .22472 Metetra
.664 .741 .907 r
.70178 .22472 .70386 .2276 .70831 .22604 .70624 .22315 Metetra
.664 .741 .907 r
.70624 .22315 .70831 .22604 .71276 .22448 .7107 .22159 Metetra
.664 .741 .907 r
.7107 .22159 .71276 .22448 .71723 .22291 .71517 .22002 Metetra
.664 .741 .907 r
.71517 .22002 .71723 .22291 .7217 .22134 .71964 .21845 Metetra
.664 .741 .907 r
.71964 .21845 .7217 .22134 .72618 .21978 .72412 .21687 Metetra
.664 .741 .907 r
.72412 .21687 .72618 .21978 .73066 .2182 .72861 .2153 Metetra
.664 .741 .907 r
.72861 .2153 .73066 .2182 .73515 .21663 .73311 .21372 Metetra
.664 .741 .907 r
.73311 .21372 .73515 .21663 .73965 .21505 .73761 .21214 Metetra
.664 .741 .907 r
.73761 .21214 .73965 .21505 .74416 .21347 .74213 .21055 Metetra
.664 .741 .907 r
.74213 .21055 .74416 .21347 .74867 .21189 .74664 .20897 Metetra
.664 .741 .907 r
.74664 .20897 .74867 .21189 .75319 .21031 .75117 .20738 Metetra
.664 .741 .907 r
.75117 .20738 .75319 .21031 .75772 .20872 .7557 .20579 Metetra
.664 .741 .907 r
.7557 .20579 .75772 .20872 .76225 .20713 .76024 .20419 Metetra
.664 .741 .907 r
.76024 .20419 .76225 .20713 .76679 .20554 .76479 .2026 Metetra
.664 .741 .907 r
.76479 .2026 .76679 .20554 .77134 .20395 .76934 .201 Metetra
.664 .741 .907 r
.76934 .201 .77134 .20395 .7759 .20235 .7739 .1994 Metetra
.664 .741 .907 r
.7739 .1994 .7759 .20235 .78046 .20075 .77847 .19779 Metetra
.664 .741 .907 r
.77847 .19779 .78046 .20075 .78503 .19915 .78305 .19618 Metetra
.664 .741 .907 r
.78305 .19618 .78503 .19915 .78961 .19754 .78763 .19458 Metetra
.664 .741 .907 r
.78763 .19458 .78961 .19754 .7942 .19594 .79222 .19296 Metetra
.664 .741 .907 r
.79222 .19296 .7942 .19594 .79879 .19433 .79682 .19135 Metetra
.664 .741 .907 r
.79682 .19135 .79879 .19433 .80339 .19272 .80142 .18973 Metetra
.664 .741 .907 r
.80142 .18973 .80339 .19272 .808 .1911 .80603 .18811 Metetra
.664 .741 .907 r
.80603 .18811 .808 .1911 .81261 .18948 .81065 .18649 Metetra
.664 .741 .907 r
.1925 .40022 .19507 .40261 .19876 .40132 .1962 .39892 Metetra
.664 .741 .907 r
.1962 .39892 .19876 .40132 .20246 .40002 .1999 .39762 Metetra
.664 .741 .907 r
.1999 .39762 .20246 .40002 .20617 .39872 .20361 .39631 Metetra
.664 .741 .907 r
.20361 .39631 .20617 .39872 .20988 .39742 .20732 .39501 Metetra
.664 .741 .907 r
.20732 .39501 .20988 .39742 .21359 .39611 .21104 .3937 Metetra
.664 .741 .907 r
.21104 .3937 .21359 .39611 .21731 .3948 .21477 .39239 Metetra
.664 .741 .907 r
.21477 .39239 .21731 .3948 .22104 .3935 .2185 .39108 Metetra
.664 .741 .907 r
.2185 .39108 .22104 .3935 .22477 .39219 .22223 .38976 Metetra
.664 .741 .907 r
.22223 .38976 .22477 .39219 .22851 .39087 .22597 .38845 Metetra
.664 .741 .907 r
.22597 .38845 .22851 .39087 .23225 .38956 .22972 .38713 Metetra
.664 .741 .907 r
.22972 .38713 .23225 .38956 .236 .38824 .23347 .38581 Metetra
.664 .741 .907 r
.23347 .38581 .236 .38824 .23975 .38693 .23723 .38449 Metetra
.664 .741 .907 r
.23723 .38449 .23975 .38693 .24351 .38561 .24099 .38317 Metetra
.664 .741 .907 r
.24099 .38317 .24351 .38561 .24728 .38429 .24475 .38184 Metetra
.664 .741 .907 r
.24475 .38184 .24728 .38429 .25105 .38296 .24853 .38051 Metetra
.664 .741 .907 r
.24853 .38051 .25105 .38296 .25482 .38164 .25231 .37918 Metetra
.664 .741 .907 r
.25231 .37918 .25482 .38164 .2586 .38031 .25609 .37785 Metetra
.664 .741 .907 r
.25609 .37785 .2586 .38031 .26239 .37898 .25988 .37652 Metetra
.664 .741 .907 r
.25988 .37652 .26239 .37898 .26618 .37765 .26367 .37519 Metetra
.664 .741 .907 r
.26367 .37519 .26618 .37765 .26998 .37632 .26747 .37385 Metetra
.664 .741 .907 r
.26747 .37385 .26998 .37632 .27378 .37498 .27128 .37251 Metetra
.664 .741 .907 r
.27128 .37251 .27378 .37498 .27759 .37364 .27509 .37117 Metetra
.664 .741 .907 r
.27509 .37117 .27759 .37364 .2814 .37231 .27891 .36983 Metetra
.664 .741 .907 r
.27891 .36983 .2814 .37231 .28522 .37096 .28273 .36848 Metetra
.664 .741 .907 r
.28273 .36848 .28522 .37096 .28904 .36962 .28656 .36714 Metetra
.664 .741 .907 r
.28656 .36714 .28904 .36962 .29287 .36828 .29039 .36579 Metetra
.664 .741 .907 r
.29039 .36579 .29287 .36828 .29671 .36693 .29423 .36444 Metetra
.664 .741 .907 r
.29423 .36444 .29671 .36693 .30055 .36558 .29807 .36309 Metetra
.664 .741 .907 r
.29807 .36309 .30055 .36558 .3044 .36423 .30192 .36173 Metetra
.664 .741 .907 r
.30192 .36173 .3044 .36423 .30825 .36288 .30578 .36038 Metetra
.664 .741 .907 r
.30578 .36038 .30825 .36288 .31211 .36152 .30964 .35902 Metetra
.664 .741 .907 r
.30964 .35902 .31211 .36152 .31597 .36017 .31351 .35766 Metetra
.664 .741 .907 r
.31351 .35766 .31597 .36017 .31984 .35881 .31738 .3563 Metetra
.664 .741 .907 r
.31738 .3563 .31984 .35881 .32372 .35745 .32126 .35493 Metetra
.664 .741 .907 r
.32126 .35493 .32372 .35745 .3276 .35609 .32514 .35357 Metetra
.664 .741 .907 r
.32514 .35357 .3276 .35609 .33148 .35472 .32903 .3522 Metetra
.664 .741 .907 r
.32903 .3522 .33148 .35472 .33537 .35336 .33293 .35083 Metetra
.664 .741 .907 r
.33293 .35083 .33537 .35336 .33927 .35199 .33683 .34946 Metetra
.664 .741 .907 r
.33683 .34946 .33927 .35199 .34318 .35062 .34074 .34808 Metetra
.664 .741 .907 r
.34074 .34808 .34318 .35062 .34708 .34924 .34465 .3467 Metetra
.664 .741 .907 r
.34465 .3467 .34708 .34924 .351 .34787 .34857 .34533 Metetra
.664 .741 .907 r
.34857 .34533 .351 .34787 .35492 .34649 .35249 .34395 Metetra
.955 .682 .48 r
.35249 .34395 .35492 .34649 .35885 .34511 .3442 .57219 Metetra
.521 .294 .512 r
.3442 .57219 .35885 .34511 .35103 .5733 .34872 .56495 Metetra
.923 .677 .548 r
.34872 .56495 .35103 .5733 .35671 .54251 .35567 .50974 Metetra
.753 .518 .575 r
.35567 .50974 .35671 .54251 .3629 .50013 .36118 .48104 Metetra
.768 .544 .595 r
.36118 .48104 .3629 .50013 .36813 .47589 .36614 .46253 Metetra
.774 .565 .616 r
.36614 .46253 .36813 .47589 .37295 .45951 .37081 .44918 Metetra
.776 .582 .637 r
.37081 .44918 .37295 .45951 .37755 .44736 .37533 .43885 Metetra
.775 .597 .658 r
.37533 .43885 .37755 .44736 .38201 .43779 .37974 .43047 Metetra
.774 .61 .677 r
.37974 .43047 .38201 .43779 .38639 .42993 .38408 .42344 Metetra
.771 .622 .695 r
.38408 .42344 .38639 .42993 .3907 .42327 .38838 .41739 Metetra
.767 .632 .711 r
.38838 .41739 .3907 .42327 .39497 .41749 .39264 .41206 Metetra
.763 .641 .727 r
.39264 .41206 .39497 .41749 .39922 .41237 .39687 .4073 Metetra
.759 .649 .74 r
.39687 .4073 .39922 .41237 .40344 .40778 .40108 .40298 Metetra
.754 .656 .753 r
.40108 .40298 .40344 .40778 .40764 .4036 .40528 .39903 Metetra
.749 .662 .764 r
.40528 .39903 .40764 .4036 .41183 .39977 .40946 .39538 Metetra
.745 .667 .775 r
.40946 .39538 .41183 .39977 .41601 .39621 .41364 .39198 Metetra
.74 .672 .784 r
.41364 .39198 .41601 .39621 .42019 .39289 .41782 .38878 Metetra
.736 .676 .792 r
.41782 .38878 .42019 .39289 .42435 .38977 .42198 .38577 Metetra
.731 .68 .8 r
.42198 .38577 .42435 .38977 .42806 .40205 .42615 .38292 Metetra
.128 .076 .525 r
.42615 .38292 .42806 .40205 .43224 .39945 .42986 .39546 Metetra
.709 .673 .813 r
.42986 .39546 .43224 .39945 .43642 .397 .43404 .39307 Metetra
.704 .674 .818 r
.43404 .39307 .43642 .397 .44059 .39466 .43822 .39078 Metetra
.699 .675 .823 r
.43822 .39078 .44059 .39466 .44477 .39244 .4424 .38861 Metetra
.694 .676 .828 r
.4424 .38861 .44477 .39244 .44895 .39032 .44658 .38653 Metetra
.69 .677 .832 r
.44658 .38653 .44895 .39032 .45313 .3883 .45077 .38454 Metetra
.685 .677 .836 r
.45077 .38454 .45313 .3883 .45732 .38636 .45495 .38263 Metetra
.68 .677 .84 r
.45495 .38263 .45732 .38636 .46151 .38451 .45915 .38079 Metetra
.676 .676 .843 r
.45915 .38079 .46151 .38451 .4657 .38274 .46334 .37903 Metetra
.671 .676 .846 r
.46334 .37903 .4657 .38274 .4699 .38104 .46754 .37734 Metetra
.667 .675 .848 r
.46754 .37734 .4699 .38104 .4741 .37941 .47174 .37572 Metetra
.662 .673 .85 r
.47174 .37572 .4741 .37941 .4783 .37785 .47595 .37417 Metetra
.657 .672 .853 r
.47595 .37417 .4783 .37785 .48251 .37636 .48017 .37267 Metetra
.652 .67 .854 r
.48017 .37267 .48251 .37636 .48673 .37493 .48439 .37125 Metetra
.647 .668 .856 r
.48439 .37125 .48673 .37493 .49095 .37358 .48861 .36988 Metetra
.642 .666 .857 r
.48861 .36988 .49095 .37358 .49518 .37229 .49284 .36859 Metetra
.637 .663 .859 r
.49284 .36859 .49518 .37229 .49942 .37108 .49708 .36735 Metetra
.631 .66 .86 r
.49708 .36735 .49942 .37108 .50366 .36993 .50132 .36619 Metetra
.625 .656 .861 r
.50132 .36619 .50366 .36993 .50791 .36887 .50557 .3651 Metetra
.619 .652 .861 r
.50557 .3651 .50791 .36887 .51216 .36788 .50983 .36408 Metetra
.612 .648 .861 r
.50983 .36408 .51216 .36788 .51643 .36697 .5141 .36314 Metetra
.605 .643 .862 r
.5141 .36314 .51643 .36697 .5207 .36615 .51837 .36228 Metetra
.597 .637 .861 r
.51837 .36228 .5207 .36615 .52498 .36543 .52265 .36151 Metetra
.588 .63 .861 r
.52265 .36151 .52498 .36543 .52926 .36481 .52694 .36084 Metetra
.579 .623 .86 r
.52694 .36084 .52926 .36481 .53356 .36431 .53124 .36028 Metetra
.568 .615 .859 r
.53124 .36028 .53356 .36431 .53787 .36393 .53555 .35983 Metetra
.923 .723 .615 r
.53555 .35983 .53787 .36393 .54219 .3637 .5398 .34431 Metetra
.543 .378 .607 r
.5398 .34431 .54219 .3637 .54641 .34844 .54411 .34431 Metetra
.509 .579 .861 r
.54411 .34431 .54641 .34844 .55073 .34873 .54843 .34448 Metetra
.492 .563 .856 r
.54843 .34448 .55073 .34873 .55507 .34922 .55277 .34484 Metetra
.473 .545 .85 r
.55277 .34484 .55507 .34922 .55942 .34996 .55711 .34541 Metetra
.45 .524 .842 r
.55711 .34541 .55942 .34996 .56379 .35098 .56148 .34623 Metetra
.424 .499 .832 r
.56148 .34623 .56379 .35098 .56817 .35234 .56586 .34736 Metetra
.393 .469 .82 r
.56586 .34736 .56817 .35234 .57258 .35413 .57026 .34886 Metetra
.355 .434 .804 r
.57026 .34886 .57258 .35413 .57701 .35646 .57468 .35081 Metetra
.311 .391 .784 r
.57468 .35081 .57701 .35646 .58147 .35947 .57913 .35335 Metetra
.257 .339 .757 r
.57913 .35335 .58147 .35947 .58596 .36338 .58361 .35663 Metetra
.193 .277 .722 r
.58361 .35663 .58596 .36338 .59051 .36851 .58814 .36092 Metetra
.116 .201 .677 r
.58814 .36092 .59051 .36851 .59511 .3754 .59271 .36657 Metetra
.024 .112 .618 r
.59271 .36657 .59511 .3754 .59981 .38492 .59735 .37423 Metetra
0 .008 .544 r
.59735 .37423 .59981 .38492 .60466 .39878 .60211 .38499 Metetra
0 0 .455 r
.60211 .38499 .60466 .39878 .60976 .42069 .60704 .40102 Metetra
0 0 .349 r
.60704 .40102 .60976 .42069 .61546 .46121 .61231 .42751 Metetra
0 0 .224 r
.61231 .42751 .61546 .46121 .62093 .48996 .61843 .48121 Metetra
.272 .289 .695 r
.61843 .48121 .62093 .48996 .61845 .25397 .62326 .48587 Metetra
0 0 .356 r
.62326 .48587 .61845 .25397 .62278 .25245 .62061 .24964 Metetra
.664 .741 .907 r
.62061 .24964 .62278 .25245 .62711 .25093 .62495 .24812 Metetra
.664 .741 .907 r
.62495 .24812 .62711 .25093 .63145 .24941 .62929 .24659 Metetra
.664 .741 .907 r
.62929 .24659 .63145 .24941 .63579 .24788 .63364 .24506 Metetra
.664 .741 .907 r
.63364 .24506 .63579 .24788 .64014 .24636 .638 .24353 Metetra
.664 .741 .907 r
.638 .24353 .64014 .24636 .6445 .24483 .64236 .24199 Metetra
.664 .741 .907 r
.64236 .24199 .6445 .24483 .64887 .24329 .64673 .24046 Metetra
.664 .741 .907 r
.64673 .24046 .64887 .24329 .65324 .24176 .6511 .23892 Metetra
.664 .741 .907 r
.6511 .23892 .65324 .24176 .65762 .24022 .65549 .23738 Metetra
.664 .741 .907 r
.65549 .23738 .65762 .24022 .662 .23868 .65988 .23583 Metetra
.664 .741 .907 r
.65988 .23583 .662 .23868 .6664 .23714 .66427 .23429 Metetra
.664 .741 .907 r
.66427 .23429 .6664 .23714 .67079 .23559 .66868 .23274 Metetra
.664 .741 .907 r
.66868 .23274 .67079 .23559 .6752 .23405 .67309 .23119 Metetra
.664 .741 .907 r
.67309 .23119 .6752 .23405 .67961 .2325 .67751 .22963 Metetra
.664 .741 .907 r
.67751 .22963 .67961 .2325 .68403 .23095 .68193 .22808 Metetra
.664 .741 .907 r
.68193 .22808 .68403 .23095 .68846 .22939 .68636 .22652 Metetra
.664 .741 .907 r
.68636 .22652 .68846 .22939 .69289 .22784 .6908 .22496 Metetra
.664 .741 .907 r
.6908 .22496 .69289 .22784 .69733 .22628 .69525 .22339 Metetra
.664 .741 .907 r
.69525 .22339 .69733 .22628 .70178 .22472 .6997 .22183 Metetra
.664 .741 .907 r
.6997 .22183 .70178 .22472 .70624 .22315 .70416 .22026 Metetra
.664 .741 .907 r
.70416 .22026 .70624 .22315 .7107 .22159 .70862 .21869 Metetra
.664 .741 .907 r
.70862 .21869 .7107 .22159 .71517 .22002 .7131 .21711 Metetra
.664 .741 .907 r
.7131 .21711 .71517 .22002 .71964 .21845 .71758 .21554 Metetra
.664 .741 .907 r
.71758 .21554 .71964 .21845 .72412 .21687 .72207 .21396 Metetra
.664 .741 .907 r
.72207 .21396 .72412 .21687 .72861 .2153 .72656 .21238 Metetra
.664 .741 .907 r
.72656 .21238 .72861 .2153 .73311 .21372 .73106 .2108 Metetra
.664 .741 .907 r
.73106 .2108 .73311 .21372 .73761 .21214 .73557 .20921 Metetra
.664 .741 .907 r
.73557 .20921 .73761 .21214 .74213 .21055 .74009 .20762 Metetra
.664 .741 .907 r
.74009 .20762 .74213 .21055 .74664 .20897 .74461 .20603 Metetra
.664 .741 .907 r
.74461 .20603 .74664 .20897 .75117 .20738 .74914 .20444 Metetra
.664 .741 .907 r
.74914 .20444 .75117 .20738 .7557 .20579 .75368 .20284 Metetra
.664 .741 .907 r
.75368 .20284 .7557 .20579 .76024 .20419 .75822 .20124 Metetra
.664 .741 .907 r
.75822 .20124 .76024 .20419 .76479 .2026 .76277 .19964 Metetra
.664 .741 .907 r
.76277 .19964 .76479 .2026 .76934 .201 .76733 .19804 Metetra
.664 .741 .907 r
.76733 .19804 .76934 .201 .7739 .1994 .7719 .19643 Metetra
.664 .741 .907 r
.7719 .19643 .7739 .1994 .77847 .19779 .77647 .19482 Metetra
.664 .741 .907 r
.77647 .19482 .77847 .19779 .78305 .19618 .78105 .19321 Metetra
.664 .741 .907 r
.78105 .19321 .78305 .19618 .78763 .19458 .78564 .1916 Metetra
.664 .741 .907 r
.78564 .1916 .78763 .19458 .79222 .19296 .79024 .18998 Metetra
.664 .741 .907 r
.79024 .18998 .79222 .19296 .79682 .19135 .79484 .18836 Metetra
.664 .741 .907 r
.79484 .18836 .79682 .19135 .80142 .18973 .79945 .18674 Metetra
.664 .741 .907 r
.79945 .18674 .80142 .18973 .80603 .18811 .80407 .18512 Metetra
.664 .741 .907 r
.80407 .18512 .80603 .18811 .81065 .18649 .80869 .18349 Metetra
.664 .741 .907 r
.18993 .39782 .1925 .40022 .1962 .39892 .19363 .39651 Metetra
.664 .741 .907 r
.19363 .39651 .1962 .39892 .1999 .39762 .19734 .39521 Metetra
.664 .741 .907 r
.19734 .39521 .1999 .39762 .20361 .39631 .20105 .3939 Metetra
.664 .741 .907 r
.20105 .3939 .20361 .39631 .20732 .39501 .20476 .39259 Metetra
.664 .741 .907 r
.20476 .39259 .20732 .39501 .21104 .3937 .20849 .39128 Metetra
.664 .741 .907 r
.20849 .39128 .21104 .3937 .21477 .39239 .21221 .38996 Metetra
.664 .741 .907 r
.21221 .38996 .21477 .39239 .2185 .39108 .21595 .38865 Metetra
.664 .741 .907 r
.21595 .38865 .2185 .39108 .22223 .38976 .21968 .38733 Metetra
.664 .741 .907 r
.21968 .38733 .22223 .38976 .22597 .38845 .22343 .38601 Metetra
.664 .741 .907 r
.22343 .38601 .22597 .38845 .22972 .38713 .22718 .38469 Metetra
.664 .741 .907 r
.22718 .38469 .22972 .38713 .23347 .38581 .23093 .38337 Metetra
.664 .741 .907 r
.23093 .38337 .23347 .38581 .23723 .38449 .23469 .38204 Metetra
.664 .741 .907 r
.23469 .38204 .23723 .38449 .24099 .38317 .23846 .38072 Metetra
.664 .741 .907 r
.23846 .38072 .24099 .38317 .24475 .38184 .24223 .37939 Metetra
.664 .741 .907 r
.24223 .37939 .24475 .38184 .24853 .38051 .246 .37806 Metetra
.664 .741 .907 r
.246 .37806 .24853 .38051 .25231 .37918 .24978 .37673 Metetra
.664 .741 .907 r
.24978 .37673 .25231 .37918 .25609 .37785 .25357 .37539 Metetra
.664 .741 .907 r
.25357 .37539 .25609 .37785 .25988 .37652 .25736 .37406 Metetra
.664 .741 .907 r
.25736 .37406 .25988 .37652 .26367 .37519 .26116 .37272 Metetra
.664 .741 .907 r
.26116 .37272 .26367 .37519 .26747 .37385 .26496 .37138 Metetra
.664 .741 .907 r
.26496 .37138 .26747 .37385 .27128 .37251 .26877 .37004 Metetra
.664 .741 .907 r
.26877 .37004 .27128 .37251 .27509 .37117 .27259 .36869 Metetra
.664 .741 .907 r
.27259 .36869 .27509 .37117 .27891 .36983 .27641 .36734 Metetra
.664 .741 .907 r
.27641 .36734 .27891 .36983 .28273 .36848 .28023 .366 Metetra
.664 .741 .907 r
.28023 .366 .28273 .36848 .28656 .36714 .28406 .36465 Metetra
.664 .741 .907 r
.28406 .36465 .28656 .36714 .29039 .36579 .2879 .3633 Metetra
.664 .741 .907 r
.2879 .3633 .29039 .36579 .29423 .36444 .29174 .36194 Metetra
.664 .741 .907 r
.29174 .36194 .29423 .36444 .29807 .36309 .29559 .36059 Metetra
.664 .741 .907 r
.29559 .36059 .29807 .36309 .30192 .36173 .29944 .35923 Metetra
.664 .741 .907 r
.29944 .35923 .30192 .36173 .30578 .36038 .3033 .35787 Metetra
.664 .741 .907 r
.3033 .35787 .30578 .36038 .30964 .35902 .30717 .35651 Metetra
.664 .741 .907 r
.30717 .35651 .30964 .35902 .31351 .35766 .31104 .35514 Metetra
.664 .741 .907 r
.31104 .35514 .31351 .35766 .31738 .3563 .31492 .35378 Metetra
.664 .741 .907 r
.31492 .35378 .31738 .3563 .32126 .35493 .3188 .35241 Metetra
.664 .741 .907 r
.3188 .35241 .32126 .35493 .32514 .35357 .32269 .35104 Metetra
.664 .741 .907 r
.32269 .35104 .32514 .35357 .32903 .3522 .32658 .34967 Metetra
.664 .741 .907 r
.32658 .34967 .32903 .3522 .33293 .35083 .33048 .34829 Metetra
.664 .741 .907 r
.33048 .34829 .33293 .35083 .33683 .34946 .33438 .34692 Metetra
.664 .741 .907 r
.33438 .34692 .33683 .34946 .34074 .34808 .33829 .34554 Metetra
.664 .741 .907 r
.33829 .34554 .34074 .34808 .34465 .3467 .34221 .34416 Metetra
.664 .741 .907 r
.34221 .34416 .34465 .3467 .34857 .34533 .34613 .34278 Metetra
.955 .682 .481 r
.34613 .34278 .34857 .34533 .35249 .34395 .33737 .57109 Metetra
.53 .302 .513 r
.33737 .57109 .35249 .34395 .3442 .57219 .34158 .56979 Metetra
.949 .711 .543 r
.34158 .56979 .3442 .57219 .34872 .56495 .34825 .52198 Metetra
.743 .504 .568 r
.34825 .52198 .34872 .56495 .35567 .50974 .35414 .48724 Metetra
.763 .535 .588 r
.35414 .48724 .35567 .50974 .36118 .48104 .35927 .46609 Metetra
.772 .558 .609 r
.35927 .46609 .36118 .48104 .36614 .46253 .36404 .4513 Metetra
.775 .576 .63 r
.36404 .4513 .36614 .46253 .37081 .44918 .36862 .4401 Metetra
.775 .592 .651 r
.36862 .4401 .37081 .44918 .37533 .43885 .37308 .43115 Metetra
.774 .605 .67 r
.37308 .43115 .37533 .43885 .37974 .43047 .37745 .42371 Metetra
.771 .618 .689 r
.37745 .42371 .37974 .43047 .38408 .42344 .38176 .41736 Metetra
.768 .628 .706 r
.38176 .41736 .38408 .42344 .38838 .41739 .38604 .4118 Metetra
.764 .638 .721 r
.38604 .4118 .38838 .41739 .39264 .41206 .39028 .40686 Metetra
.76 .646 .736 r
.39028 .40686 .39264 .41206 .39687 .4073 .39451 .4024 Metetra
.755 .653 .749 r
.39451 .4024 .39687 .4073 .40108 .40298 .39871 .39833 Metetra
.751 .66 .76 r
.39871 .39833 .40108 .40298 .40528 .39903 .40291 .39458 Metetra
.746 .666 .771 r
.40291 .39458 .40528 .39903 .40946 .39538 .40709 .39109 Metetra
.742 .67 .781 r
.40709 .39109 .40946 .39538 .41364 .39198 .41127 .38782 Metetra
.737 .675 .789 r
.41127 .38782 .41364 .39198 .41782 .38878 .41544 .38475 Metetra
.733 .678 .797 r
.41544 .38475 .41782 .38878 .42198 .38577 .41961 .38183 Metetra
.729 .682 .805 r
.41961 .38183 .42198 .38577 .42615 .38292 .42377 .37906 Metetra
.725 .685 .811 r
.42377 .37906 .42615 .38292 .42986 .39546 .42794 .37641 Metetra
.115 .067 .521 r
.42794 .37641 .42986 .39546 .43404 .39307 .43166 .38918 Metetra
.702 .676 .822 r
.43166 .38918 .43404 .39307 .43822 .39078 .43584 .38694 Metetra
.697 .677 .826 r
.43584 .38694 .43822 .39078 .4424 .38861 .44002 .38481 Metetra
.693 .678 .831 r
.44002 .38481 .4424 .38861 .44658 .38653 .44421 .38276 Metetra
.688 .678 .835 r
.44421 .38276 .44658 .38653 .45077 .38454 .44839 .3808 Metetra
.684 .678 .838 r
.44839 .3808 .45077 .38454 .45495 .38263 .45258 .37891 Metetra
.68 .678 .842 r
.45258 .37891 .45495 .38263 .45915 .38079 .45678 .3771 Metetra
.675 .678 .845 r
.45678 .3771 .45915 .38079 .46334 .37903 .46097 .37535 Metetra
.671 .677 .847 r
.46097 .37535 .46334 .37903 .46754 .37734 .46518 .37367 Metetra
.666 .676 .85 r
.46518 .37367 .46754 .37734 .47174 .37572 .46938 .37206 Metetra
.662 .675 .852 r
.46938 .37206 .47174 .37572 .47595 .37417 .47359 .3705 Metetra
.657 .674 .854 r
.47359 .3705 .47595 .37417 .48017 .37267 .47781 .36901 Metetra
.653 .672 .856 r
.47781 .36901 .48017 .37267 .48439 .37125 .48203 .36758 Metetra
.648 .67 .857 r
.48203 .36758 .48439 .37125 .48861 .36988 .48626 .36621 Metetra
.643 .668 .859 r
.48626 .36621 .48861 .36988 .49284 .36859 .4905 .3649 Metetra
.638 .665 .86 r
.4905 .3649 .49284 .36859 .49708 .36735 .49474 .36365 Metetra
.632 .662 .861 r
.49474 .36365 .49708 .36735 .50132 .36619 .49898 .36247 Metetra
.627 .659 .862 r
.49898 .36247 .50132 .36619 .50557 .3651 .50324 .36135 Metetra
.621 .655 .862 r
.50324 .36135 .50557 .3651 .50983 .36408 .5075 .36031 Metetra
.614 .651 .863 r
.5075 .36031 .50983 .36408 .5141 .36314 .51177 .35933 Metetra
.608 .646 .863 r
.51177 .35933 .5141 .36314 .51837 .36228 .51604 .35844 Metetra
.6 .641 .863 r
.51604 .35844 .51837 .36228 .52265 .36151 .52033 .35763 Metetra
.592 .635 .862 r
.52033 .35763 .52265 .36151 .52694 .36084 .52462 .35691 Metetra
.583 .628 .862 r
.52462 .35691 .52694 .36084 .53124 .36028 .52892 .35628 Metetra
.925 .725 .613 r
.52892 .35628 .53124 .36028 .53555 .35983 .53319 .34054 Metetra
.548 .381 .607 r
.53319 .34054 .53555 .35983 .5398 .34431 .53749 .34033 Metetra
.532 .6 .867 r
.53749 .34033 .5398 .34431 .54411 .34431 .5418 .34024 Metetra
.518 .588 .864 r
.5418 .34024 .54411 .34431 .54843 .34448 .54612 .3403 Metetra
.503 .573 .859 r
.54612 .3403 .54843 .34448 .55277 .34484 .55046 .34053 Metetra
.486 .557 .854 r
.55046 .34053 .55277 .34484 .55711 .34541 .55481 .34095 Metetra
.465 .538 .847 r
.55481 .34095 .55711 .34541 .56148 .34623 .55917 .3416 Metetra
.442 .516 .839 r
.55917 .3416 .56148 .34623 .56586 .34736 .56355 .34252 Metetra
.414 .489 .828 r
.56355 .34252 .56586 .34736 .57026 .34886 .56795 .34376 Metetra
.381 .458 .815 r
.56795 .34376 .57026 .34886 .57468 .35081 .57236 .3454 Metetra
.342 .42 .797 r
.57236 .3454 .57468 .35081 .57913 .35335 .5768 .34754 Metetra
.295 .375 .775 r
.5768 .34754 .57913 .35335 .58361 .35663 .58127 .3503 Metetra
.238 .32 .746 r
.58127 .3503 .58361 .35663 .58814 .36092 .58578 .35388 Metetra
.17 .253 .708 r
.58578 .35388 .58814 .36092 .59271 .36657 .59032 .35857 Metetra
.089 .173 .658 r
.59032 .35857 .59271 .36657 .59735 .37423 .59493 .36481 Metetra
0 .079 .595 r
.59493 .36481 .59735 .37423 .60211 .38499 .59962 .37336 Metetra
0 0 .517 r
.59962 .37336 .60211 .38499 .60704 .40102 .60443 .38558 Metetra
0 0 .422 r
.60443 .38558 .60704 .40102 .61231 .42751 .60947 .40433 Metetra
0 0 .312 r
.60947 .40433 .61231 .42751 .61843 .48121 .61495 .43701 Metetra
0 0 .402 r
.61495 .43701 .61843 .48121 .62326 .48587 .62093 .4832 Metetra
.645 .763 .934 r
.62093 .4832 .62326 .48587 .62061 .24964 .6256 .48175 Metetra
0 0 .356 r
.6256 .48175 .62061 .24964 .62495 .24812 .62278 .2453 Metetra
.664 .741 .907 r
.62278 .2453 .62495 .24812 .62929 .24659 .62713 .24376 Metetra
.664 .741 .907 r
.62713 .24376 .62929 .24659 .63364 .24506 .63148 .24223 Metetra
.664 .741 .907 r
.63148 .24223 .63364 .24506 .638 .24353 .63584 .24069 Metetra
.664 .741 .907 r
.63584 .24069 .638 .24353 .64236 .24199 .64021 .23916 Metetra
.664 .741 .907 r
.64021 .23916 .64236 .24199 .64673 .24046 .64458 .23761 Metetra
.664 .741 .907 r
.64458 .23761 .64673 .24046 .6511 .23892 .64896 .23607 Metetra
.664 .741 .907 r
.64896 .23607 .6511 .23892 .65549 .23738 .65335 .23452 Metetra
.664 .741 .907 r
.65335 .23452 .65549 .23738 .65988 .23583 .65775 .23298 Metetra
.664 .741 .907 r
.65775 .23298 .65988 .23583 .66427 .23429 .66215 .23142 Metetra
.664 .741 .907 r
.66215 .23142 .66427 .23429 .66868 .23274 .66656 .22987 Metetra
.664 .741 .907 r
.66656 .22987 .66868 .23274 .67309 .23119 .67097 .22832 Metetra
.664 .741 .907 r
.67097 .22832 .67309 .23119 .67751 .22963 .67539 .22676 Metetra
.664 .741 .907 r
.67539 .22676 .67751 .22963 .68193 .22808 .67982 .2252 Metetra
.664 .741 .907 r
.67982 .2252 .68193 .22808 .68636 .22652 .68426 .22363 Metetra
.664 .741 .907 r
.68426 .22363 .68636 .22652 .6908 .22496 .6887 .22207 Metetra
.664 .741 .907 r
.6887 .22207 .6908 .22496 .69525 .22339 .69315 .2205 Metetra
.664 .741 .907 r
.69315 .2205 .69525 .22339 .6997 .22183 .69761 .21893 Metetra
.664 .741 .907 r
.69761 .21893 .6997 .22183 .70416 .22026 .70207 .21736 Metetra
.664 .741 .907 r
.70207 .21736 .70416 .22026 .70862 .21869 .70655 .21578 Metetra
.664 .741 .907 r
.70655 .21578 .70862 .21869 .7131 .21711 .71102 .2142 Metetra
.664 .741 .907 r
.71102 .2142 .7131 .21711 .71758 .21554 .71551 .21262 Metetra
.664 .741 .907 r
.71551 .21262 .71758 .21554 .72207 .21396 .72 .21104 Metetra
.664 .741 .907 r
.72 .21104 .72207 .21396 .72656 .21238 .7245 .20945 Metetra
.664 .741 .907 r
.7245 .20945 .72656 .21238 .73106 .2108 .72901 .20787 Metetra
.664 .741 .907 r
.72901 .20787 .73106 .2108 .73557 .20921 .73352 .20628 Metetra
.664 .741 .907 r
.73352 .20628 .73557 .20921 .74009 .20762 .73804 .20468 Metetra
.664 .741 .907 r
.73804 .20468 .74009 .20762 .74461 .20603 .74257 .20309 Metetra
.664 .741 .907 r
.74257 .20309 .74461 .20603 .74914 .20444 .74711 .20149 Metetra
.664 .741 .907 r
.74711 .20149 .74914 .20444 .75368 .20284 .75165 .19989 Metetra
.664 .741 .907 r
.75165 .19989 .75368 .20284 .75822 .20124 .7562 .19829 Metetra
.664 .741 .907 r
.7562 .19829 .75822 .20124 .76277 .19964 .76075 .19668 Metetra
.664 .741 .907 r
.76075 .19668 .76277 .19964 .76733 .19804 .76532 .19507 Metetra
.664 .741 .907 r
.76532 .19507 .76733 .19804 .7719 .19643 .76989 .19346 Metetra
.664 .741 .907 r
.76989 .19346 .7719 .19643 .77647 .19482 .77447 .19185 Metetra
.664 .741 .907 r
.77447 .19185 .77647 .19482 .78105 .19321 .77905 .19023 Metetra
.664 .741 .907 r
.77905 .19023 .78105 .19321 .78564 .1916 .78365 .18861 Metetra
.664 .741 .907 r
.78365 .18861 .78564 .1916 .79024 .18998 .78825 .18699 Metetra
.664 .741 .907 r
.78825 .18699 .79024 .18998 .79484 .18836 .79286 .18537 Metetra
.664 .741 .907 r
.79286 .18537 .79484 .18836 .79945 .18674 .79747 .18374 Metetra
.664 .741 .907 r
.79747 .18374 .79945 .18674 .80407 .18512 .80209 .18211 Metetra
.664 .741 .907 r
.80209 .18211 .80407 .18512 .80869 .18349 .80672 .18048 Metetra
.664 .741 .907 r
.18735 .39541 .18993 .39782 .19363 .39651 .19105 .3941 Metetra
.664 .741 .907 r
.19105 .3941 .19363 .39651 .19734 .39521 .19476 .39279 Metetra
.664 .741 .907 r
.19476 .39279 .19734 .39521 .20105 .3939 .19848 .39148 Metetra
.664 .741 .907 r
.19848 .39148 .20105 .3939 .20476 .39259 .2022 .39017 Metetra
.664 .741 .907 r
.2022 .39017 .20476 .39259 .20849 .39128 .20592 .38885 Metetra
.664 .741 .907 r
.20592 .38885 .20849 .39128 .21221 .38996 .20965 .38753 Metetra
.664 .741 .907 r
.20965 .38753 .21221 .38996 .21595 .38865 .21339 .38622 Metetra
.664 .741 .907 r
.21339 .38622 .21595 .38865 .21968 .38733 .21713 .3849 Metetra
.664 .741 .907 r
.21713 .3849 .21968 .38733 .22343 .38601 .22088 .38357 Metetra
.664 .741 .907 r
.22088 .38357 .22343 .38601 .22718 .38469 .22463 .38225 Metetra
.664 .741 .907 r
.22463 .38225 .22718 .38469 .23093 .38337 .22839 .38092 Metetra
.664 .741 .907 r
.22839 .38092 .23093 .38337 .23469 .38204 .23215 .37959 Metetra
.664 .741 .907 r
.23215 .37959 .23469 .38204 .23846 .38072 .23592 .37826 Metetra
.664 .741 .907 r
.23592 .37826 .23846 .38072 .24223 .37939 .23969 .37693 Metetra
.664 .741 .907 r
.23969 .37693 .24223 .37939 .246 .37806 .24347 .3756 Metetra
.664 .741 .907 r
.24347 .3756 .246 .37806 .24978 .37673 .24725 .37426 Metetra
.664 .741 .907 r
.24725 .37426 .24978 .37673 .25357 .37539 .25104 .37292 Metetra
.664 .741 .907 r
.25104 .37292 .25357 .37539 .25736 .37406 .25484 .37158 Metetra
.664 .741 .907 r
.25484 .37158 .25736 .37406 .26116 .37272 .25864 .37024 Metetra
.664 .741 .907 r
.25864 .37024 .26116 .37272 .26496 .37138 .26245 .3689 Metetra
.664 .741 .907 r
.26245 .3689 .26496 .37138 .26877 .37004 .26626 .36755 Metetra
.664 .741 .907 r
.26626 .36755 .26877 .37004 .27259 .36869 .27008 .3662 Metetra
.664 .741 .907 r
.27008 .3662 .27259 .36869 .27641 .36734 .2739 .36485 Metetra
.664 .741 .907 r
.2739 .36485 .27641 .36734 .28023 .366 .27773 .3635 Metetra
.664 .741 .907 r
.27773 .3635 .28023 .366 .28406 .36465 .28156 .36215 Metetra
.664 .741 .907 r
.28156 .36215 .28406 .36465 .2879 .3633 .2854 .36079 Metetra
.664 .741 .907 r
.2854 .36079 .2879 .3633 .29174 .36194 .28925 .35944 Metetra
.664 .741 .907 r
.28925 .35944 .29174 .36194 .29559 .36059 .2931 .35808 Metetra
.664 .741 .907 r
.2931 .35808 .29559 .36059 .29944 .35923 .29696 .35672 Metetra
.664 .741 .907 r
.29696 .35672 .29944 .35923 .3033 .35787 .30082 .35535 Metetra
.664 .741 .907 r
.30082 .35535 .3033 .35787 .30717 .35651 .30469 .35399 Metetra
.664 .741 .907 r
.30469 .35399 .30717 .35651 .31104 .35514 .30856 .35262 Metetra
.664 .741 .907 r
.30856 .35262 .31104 .35514 .31492 .35378 .31244 .35125 Metetra
.664 .741 .907 r
.31244 .35125 .31492 .35378 .3188 .35241 .31633 .34988 Metetra
.664 .741 .907 r
.31633 .34988 .3188 .35241 .32269 .35104 .32022 .3485 Metetra
.664 .741 .907 r
.32022 .3485 .32269 .35104 .32658 .34967 .32412 .34713 Metetra
.664 .741 .907 r
.32412 .34713 .32658 .34967 .33048 .34829 .32802 .34575 Metetra
.664 .741 .907 r
.32802 .34575 .33048 .34829 .33438 .34692 .33193 .34437 Metetra
.664 .741 .907 r
.33193 .34437 .33438 .34692 .33829 .34554 .33584 .34299 Metetra
.664 .741 .907 r
.33584 .34299 .33829 .34554 .34221 .34416 .33976 .34161 Metetra
.664 .741 .907 r
.33976 .34161 .34221 .34416 .34613 .34278 .34369 .34022 Metetra
.955 .682 .481 r
.34369 .34022 .34613 .34278 .33737 .57109 .33473 .56868 Metetra
.944 .722 .571 r
.33473 .56868 .33737 .57109 .34158 .56979 .34055 .53806 Metetra
.805 .56 .568 r
.34055 .53806 .34158 .56979 .34825 .52198 .34699 .49479 Metetra
.757 .525 .581 r
.34699 .49479 .34825 .52198 .35414 .48724 .35234 .47027 Metetra
.769 .55 .602 r
.35234 .47027 .35414 .48724 .35927 .46609 .35724 .45378 Metetra
.774 .569 .623 r
.35724 .45378 .35927 .46609 .36404 .4513 .36188 .44157 Metetra
.775 .586 .644 r
.36188 .44157 .36404 .4513 .36862 .4401 .36639 .43197 Metetra
.774 .6 .664 r
.36639 .43197 .36862 .4401 .37308 .43115 .37079 .42408 Metetra
.772 .613 .683 r
.37079 .42408 .37308 .43115 .37745 .42371 .37513 .4174 Metetra
.769 .625 .7 r
.37513 .4174 .37745 .42371 .38176 .41736 .37943 .4116 Metetra
.765 .634 .716 r
.37943 .4116 .38176 .41736 .38604 .4118 .38369 .40647 Metetra
.761 .643 .731 r
.38369 .40647 .38604 .4118 .39028 .40686 .38792 .40186 Metetra
.757 .651 .744 r
.38792 .40186 .39028 .40686 .39451 .4024 .39214 .39767 Metetra
.752 .658 .757 r
.39214 .39767 .39451 .4024 .39871 .39833 .39634 .39381 Metetra
.748 .664 .768 r
.39634 .39381 .39871 .39833 .40291 .39458 .40053 .39023 Metetra
.743 .669 .778 r
.40053 .39023 .40291 .39458 .40709 .39109 .40471 .38689 Metetra
.739 .673 .787 r
.40471 .38689 .40709 .39109 .41127 .38782 .40888 .38375 Metetra
.735 .677 .795 r
.40888 .38375 .41127 .38782 .41544 .38475 .41306 .38077 Metetra
.731 .681 .802 r
.41306 .38077 .41544 .38475 .41961 .38183 .41722 .37795 Metetra
.726 .684 .809 r
.41722 .37795 .41961 .38183 .42377 .37906 .42139 .37525 Metetra
.723 .687 .815 r
.42139 .37525 .42377 .37906 .42794 .37641 .42556 .37267 Metetra
.719 .689 .821 r
.42556 .37267 .42794 .37641 .43166 .38918 .42973 .37019 Metetra
.59 .411 .608 r
.42973 .37019 .43166 .38918 .43584 .38694 .43389 .3678 Metetra
.096 .054 .515 r
.43389 .3678 .43584 .38694 .44002 .38481 .43764 .38104 Metetra
.691 .679 .834 r
.43764 .38104 .44002 .38481 .44421 .38276 .44183 .37903 Metetra
.687 .68 .837 r
.44183 .37903 .44421 .38276 .44839 .3808 .44601 .37709 Metetra
.683 .68 .841 r
.44601 .37709 .44839 .3808 .45258 .37891 .45021 .37522 Metetra
.679 .68 .844 r
.45021 .37522 .45258 .37891 .45678 .3771 .4544 .37343 Metetra
.674 .679 .847 r
.4544 .37343 .45678 .3771 .46097 .37535 .4586 .37169 Metetra
.67 .679 .849 r
.4586 .37169 .46097 .37535 .46518 .37367 .46281 .37002 Metetra
.666 .678 .852 r
.46281 .37002 .46518 .37367 .46938 .37206 .46702 .36841 Metetra
.662 .677 .854 r
.46702 .36841 .46938 .37206 .47359 .3705 .47123 .36686 Metetra
.657 .675 .856 r
.47123 .36686 .47359 .3705 .47781 .36901 .47545 .36537 Metetra
.653 .674 .857 r
.47545 .36537 .47781 .36901 .48203 .36758 .47968 .36393 Metetra
.648 .672 .859 r
.47968 .36393 .48203 .36758 .48626 .36621 .48391 .36255 Metetra
.644 .67 .86 r
.48391 .36255 .48626 .36621 .4905 .3649 .48814 .36123 Metetra
.639 .667 .861 r
.48814 .36123 .4905 .3649 .49474 .36365 .49239 .35997 Metetra
.634 .665 .862 r
.49239 .35997 .49474 .36365 .49898 .36247 .49664 .35877 Metetra
.628 .661 .863 r
.49664 .35877 .49898 .36247 .50324 .36135 .50089 .35763 Metetra
.623 .658 .864 r
.50089 .35763 .50324 .36135 .5075 .36031 .50516 .35656 Metetra
.617 .654 .864 r
.50516 .35656 .5075 .36031 .51177 .35933 .50943 .35556 Metetra
.61 .65 .864 r
.50943 .35556 .51177 .35933 .51604 .35844 .51371 .35463 Metetra
.603 .645 .864 r
.51371 .35463 .51604 .35844 .52033 .35763 .51799 .35377 Metetra
.928 .727 .61 r
.51799 .35377 .52033 .35763 .52462 .35691 .5223 .33756 Metetra
.552 .384 .607 r
.5223 .33756 .52462 .35691 .52892 .35628 .52658 .33708 Metetra
.551 .383 .607 r
.52658 .33708 .52892 .35628 .53319 .34054 .53088 .33668 Metetra
.55 .617 .872 r
.53088 .33668 .53319 .34054 .53749 .34033 .53518 .3364 Metetra
.539 .607 .869 r
.53518 .3364 .53749 .34033 .5418 .34024 .53949 .33623 Metetra
.527 .596 .866 r
.53949 .33623 .5418 .34024 .54612 .3403 .54381 .33619 Metetra
.513 .583 .862 r
.54381 .33619 .54612 .3403 .55046 .34053 .54815 .3363 Metetra
.497 .568 .858 r
.54815 .3363 .55046 .34053 .55481 .34095 .5525 .33659 Metetra
.479 .551 .852 r
.5525 .33659 .55481 .34095 .55917 .3416 .55686 .33708 Metetra
.458 .531 .845 r
.55686 .33708 .55917 .3416 .56355 .34252 .56124 .33781 Metetra
.433 .507 .836 r
.56124 .33781 .56355 .34252 .56795 .34376 .56563 .33883 Metetra
.403 .479 .824 r
.56563 .33883 .56795 .34376 .57236 .3454 .57004 .34019 Metetra
.369 .446 .809 r
.57004 .34019 .57236 .3454 .5768 .34754 .57448 .34198 Metetra
.327 .406 .79 r
.57448 .34198 .5768 .34754 .58127 .3503 .57893 .3443 Metetra
.278 .358 .766 r
.57893 .3443 .58127 .3503 .58578 .35388 .58342 .34731 Metetra
.218 .299 .734 r
.58342 .34731 .58578 .35388 .59032 .35857 .58795 .35122 Metetra
.146 .229 .693 r
.58795 .35122 .59032 .35857 .59493 .36481 .59253 .35636 Metetra
.061 .145 .639 r
.59253 .35636 .59493 .36481 .59962 .37336 .59717 .36326 Metetra
0 .046 .571 r
.59717 .36326 .59962 .37336 .60443 .38558 .60191 .37284 Metetra
0 0 .488 r
.60191 .37284 .60443 .38558 .60947 .40433 .60679 .3868 Metetra
0 0 .389 r
.60679 .3868 .60947 .40433 .61495 .43701 .61195 .40901 Metetra
0 0 .274 r
.61195 .40901 .61495 .43701 .62093 .4832 .61773 .45047 Metetra
.028 0 .468 r
.61773 .45047 .62093 .4832 .6256 .48175 .62326 .47907 Metetra
.976 .69 .414 r
.62326 .47907 .6256 .48175 .62278 .2453 .6206 .24247 Metetra
.664 .741 .907 r
.6206 .24247 .62278 .2453 .62713 .24376 .62496 .24093 Metetra
.664 .741 .907 r
.62496 .24093 .62713 .24376 .63148 .24223 .62931 .23939 Metetra
.664 .741 .907 r
.62931 .23939 .63148 .24223 .63584 .24069 .63368 .23785 Metetra
.664 .741 .907 r
.63368 .23785 .63584 .24069 .64021 .23916 .63805 .23631 Metetra
.664 .741 .907 r
.63805 .23631 .64021 .23916 .64458 .23761 .64243 .23476 Metetra
.664 .741 .907 r
.64243 .23476 .64458 .23761 .64896 .23607 .64682 .23321 Metetra
.664 .741 .907 r
.64682 .23321 .64896 .23607 .65335 .23452 .65121 .23166 Metetra
.664 .741 .907 r
.65121 .23166 .65335 .23452 .65775 .23298 .65561 .23011 Metetra
.664 .741 .907 r
.65561 .23011 .65775 .23298 .66215 .23142 .66001 .22855 Metetra
.664 .741 .907 r
.66001 .22855 .66215 .23142 .66656 .22987 .66443 .227 Metetra
.664 .741 .907 r
.66443 .227 .66656 .22987 .67097 .22832 .66885 .22544 Metetra
.664 .741 .907 r
.66885 .22544 .67097 .22832 .67539 .22676 .67328 .22387 Metetra
.664 .741 .907 r
.67328 .22387 .67539 .22676 .67982 .2252 .67771 .22231 Metetra
.664 .741 .907 r
.67771 .22231 .67982 .2252 .68426 .22363 .68215 .22074 Metetra
.664 .741 .907 r
.68215 .22074 .68426 .22363 .6887 .22207 .6866 .21917 Metetra
.664 .741 .907 r
.6866 .21917 .6887 .22207 .69315 .2205 .69105 .2176 Metetra
.664 .741 .907 r
.69105 .2176 .69315 .2205 .69761 .21893 .69551 .21602 Metetra
.664 .741 .907 r
.69551 .21602 .69761 .21893 .70207 .21736 .69998 .21445 Metetra
.664 .741 .907 r
.69998 .21445 .70207 .21736 .70655 .21578 .70446 .21287 Metetra
.664 .741 .907 r
.70446 .21287 .70655 .21578 .71102 .2142 .70894 .21128 Metetra
.664 .741 .907 r
.70894 .21128 .71102 .2142 .71551 .21262 .71343 .2097 Metetra
.664 .741 .907 r
.71343 .2097 .71551 .21262 .72 .21104 .71793 .20811 Metetra
.664 .741 .907 r
.71793 .20811 .72 .21104 .7245 .20945 .72244 .20652 Metetra
.664 .741 .907 r
.72244 .20652 .7245 .20945 .72901 .20787 .72695 .20493 Metetra
.664 .741 .907 r
.72695 .20493 .72901 .20787 .73352 .20628 .73147 .20333 Metetra
.664 .741 .907 r
.73147 .20333 .73352 .20628 .73804 .20468 .73599 .20173 Metetra
.664 .741 .907 r
.73599 .20173 .73804 .20468 .74257 .20309 .74052 .20013 Metetra
.664 .741 .907 r
.74052 .20013 .74257 .20309 .74711 .20149 .74506 .19853 Metetra
.664 .741 .907 r
.74506 .19853 .74711 .20149 .75165 .19989 .74961 .19693 Metetra
.664 .741 .907 r
.74961 .19693 .75165 .19989 .7562 .19829 .75417 .19532 Metetra
.664 .741 .907 r
.75417 .19532 .7562 .19829 .76075 .19668 .75873 .19371 Metetra
.664 .741 .907 r
.75873 .19371 .76075 .19668 .76532 .19507 .7633 .1921 Metetra
.664 .741 .907 r
.7633 .1921 .76532 .19507 .76989 .19346 .76787 .19048 Metetra
.664 .741 .907 r
.76787 .19048 .76989 .19346 .77447 .19185 .77246 .18886 Metetra
.664 .741 .907 r
.77246 .18886 .77447 .19185 .77905 .19023 .77705 .18724 Metetra
.664 .741 .907 r
.77705 .18724 .77905 .19023 .78365 .18861 .78165 .18562 Metetra
.664 .741 .907 r
.78165 .18562 .78365 .18861 .78825 .18699 .78625 .18399 Metetra
.664 .741 .907 r
.78625 .18399 .78825 .18699 .79286 .18537 .79087 .18236 Metetra
.664 .741 .907 r
.79087 .18236 .79286 .18537 .79747 .18374 .79549 .18073 Metetra
.664 .741 .907 r
.79549 .18073 .79747 .18374 .80209 .18211 .80012 .1791 Metetra
.664 .741 .907 r
.80012 .1791 .80209 .18211 .80672 .18048 .80475 .17746 Metetra
.664 .741 .907 r
.18477 .39299 .18735 .39541 .19105 .3941 .18847 .39168 Metetra
.664 .741 .907 r
.18847 .39168 .19105 .3941 .19476 .39279 .19218 .39037 Metetra
.664 .741 .907 r
.19218 .39037 .19476 .39279 .19848 .39148 .1959 .38905 Metetra
.664 .741 .907 r
.1959 .38905 .19848 .39148 .2022 .39017 .19962 .38774 Metetra
.664 .741 .907 r
.19962 .38774 .2022 .39017 .20592 .38885 .20335 .38642 Metetra
.664 .741 .907 r
.20335 .38642 .20592 .38885 .20965 .38753 .20709 .3851 Metetra
.664 .741 .907 r
.20709 .3851 .20965 .38753 .21339 .38622 .21082 .38378 Metetra
.664 .741 .907 r
.21082 .38378 .21339 .38622 .21713 .3849 .21457 .38245 Metetra
.664 .741 .907 r
.21457 .38245 .21713 .3849 .22088 .38357 .21832 .38113 Metetra
.664 .741 .907 r
.21832 .38113 .22088 .38357 .22463 .38225 .22207 .3798 Metetra
.664 .741 .907 r
.22207 .3798 .22463 .38225 .22839 .38092 .22583 .37847 Metetra
.664 .741 .907 r
.22583 .37847 .22839 .38092 .23215 .37959 .2296 .37714 Metetra
.664 .741 .907 r
.2296 .37714 .23215 .37959 .23592 .37826 .23337 .3758 Metetra
.664 .741 .907 r
.23337 .3758 .23592 .37826 .23969 .37693 .23715 .37447 Metetra
.664 .741 .907 r
.23715 .37447 .23969 .37693 .24347 .3756 .24093 .37313 Metetra
.664 .741 .907 r
.24093 .37313 .24347 .3756 .24725 .37426 .24472 .37179 Metetra
.664 .741 .907 r
.24472 .37179 .24725 .37426 .25104 .37292 .24851 .37045 Metetra
.664 .741 .907 r
.24851 .37045 .25104 .37292 .25484 .37158 .25231 .3691 Metetra
.664 .741 .907 r
.25231 .3691 .25484 .37158 .25864 .37024 .25612 .36776 Metetra
.664 .741 .907 r
.25612 .36776 .25864 .37024 .26245 .3689 .25993 .36641 Metetra
.664 .741 .907 r
.25993 .36641 .26245 .3689 .26626 .36755 .26374 .36506 Metetra
.664 .741 .907 r
.26374 .36506 .26626 .36755 .27008 .3662 .26756 .36371 Metetra
.664 .741 .907 r
.26756 .36371 .27008 .3662 .2739 .36485 .27139 .36236 Metetra
.664 .741 .907 r
.27139 .36236 .2739 .36485 .27773 .3635 .27522 .361 Metetra
.664 .741 .907 r
.27522 .361 .27773 .3635 .28156 .36215 .27906 .35965 Metetra
.664 .741 .907 r
.27906 .35965 .28156 .36215 .2854 .36079 .2829 .35829 Metetra
.664 .741 .907 r
.2829 .35829 .2854 .36079 .28925 .35944 .28675 .35692 Metetra
.664 .741 .907 r
.28675 .35692 .28925 .35944 .2931 .35808 .29061 .35556 Metetra
.664 .741 .907 r
.29061 .35556 .2931 .35808 .29696 .35672 .29447 .3542 Metetra
.664 .741 .907 r
.29447 .3542 .29696 .35672 .30082 .35535 .29833 .35283 Metetra
.664 .741 .907 r
.29833 .35283 .30082 .35535 .30469 .35399 .3022 .35146 Metetra
.664 .741 .907 r
.3022 .35146 .30469 .35399 .30856 .35262 .30608 .35009 Metetra
.664 .741 .907 r
.30608 .35009 .30856 .35262 .31244 .35125 .30996 .34872 Metetra
.664 .741 .907 r
.30996 .34872 .31244 .35125 .31633 .34988 .31385 .34734 Metetra
.664 .741 .907 r
.31385 .34734 .31633 .34988 .32022 .3485 .31775 .34596 Metetra
.664 .741 .907 r
.31775 .34596 .32022 .3485 .32412 .34713 .32165 .34458 Metetra
.664 .741 .907 r
.32165 .34458 .32412 .34713 .32802 .34575 .32555 .3432 Metetra
.664 .741 .907 r
.32555 .3432 .32802 .34575 .33193 .34437 .32947 .34182 Metetra
.664 .741 .907 r
.32947 .34182 .33193 .34437 .33584 .34299 .33338 .34043 Metetra
.664 .741 .907 r
.33338 .34043 .33584 .34299 .33976 .34161 .33731 .33905 Metetra
.954 .682 .482 r
.33731 .33905 .33976 .34161 .34369 .34022 .32788 .56757 Metetra
.519 .292 .51 r
.32788 .56757 .34369 .34022 .33473 .56868 .33243 .56021 Metetra
.923 .676 .548 r
.33243 .56021 .33473 .56868 .34055 .53806 .33969 .50413 Metetra
.75 .514 .574 r
.33969 .50413 .34055 .53806 .34699 .49479 .34534 .47524 Metetra
.765 .542 .595 r
.34534 .47524 .34699 .49479 .35234 .47027 .35038 .45667 Metetra
.772 .563 .616 r
.35038 .45667 .35234 .47027 .35724 .45378 .35512 .44329 Metetra
.774 .58 .637 r
.35512 .44329 .35724 .45378 .36188 .44157 .35967 .43295 Metetra
.774 .595 .657 r
.35967 .43295 .36188 .44157 .36639 .43197 .36412 .42457 Metetra
.772 .609 .676 r
.36412 .42457 .36639 .43197 .37079 .42408 .36848 .41753 Metetra
.77 .621 .694 r
.36848 .41753 .37079 .42408 .37513 .4174 .3728 .41147 Metetra
.766 .631 .711 r
.3728 .41147 .37513 .4174 .37943 .4116 .37707 .40613 Metetra
.762 .64 .726 r
.37707 .40613 .37943 .4116 .38369 .40647 .38132 .40136 Metetra
.758 .648 .74 r
.38132 .40136 .38369 .40647 .38792 .40186 .38555 .39703 Metetra
.754 .655 .753 r
.38555 .39703 .38792 .40186 .39214 .39767 .38975 .39307 Metetra
.749 .662 .764 r
.38975 .39307 .39214 .39767 .39634 .39381 .39395 .3894 Metetra
.745 .667 .774 r
.39395 .3894 .39634 .39381 .40053 .39023 .39814 .38598 Metetra
.741 .672 .784 r
.39814 .38598 .40053 .39023 .40471 .38689 .40232 .38277 Metetra
.736 .676 .792 r
.40232 .38277 .40471 .38689 .40888 .38375 .40649 .37973 Metetra
.732 .68 .8 r
.40649 .37973 .40888 .38375 .41306 .38077 .41066 .37685 Metetra
.728 .683 .807 r
.41066 .37685 .41306 .38077 .41722 .37795 .41483 .37411 Metetra
.724 .686 .813 r
.41483 .37411 .41722 .37795 .42139 .37525 .419 .37148 Metetra
.72 .688 .819 r
.419 .37148 .42139 .37525 .42556 .37267 .42317 .36896 Metetra
.717 .691 .824 r
.42317 .36896 .42556 .37267 .42973 .37019 .42734 .36653 Metetra
.713 .692 .829 r
.42734 .36653 .42973 .37019 .43389 .3678 .43151 .36419 Metetra
.71 .694 .833 r
.43151 .36419 .43389 .3678 .43764 .38104 .43568 .36192 Metetra
.088 .047 .512 r
.43568 .36192 .43764 .38104 .44183 .37903 .43944 .37532 Metetra
.686 .681 .84 r
.43944 .37532 .44183 .37903 .44601 .37709 .44363 .3734 Metetra
.682 .681 .843 r
.44363 .3734 .44601 .37709 .45021 .37522 .44782 .37156 Metetra
.678 .681 .846 r
.44782 .37156 .45021 .37522 .4544 .37343 .45202 .36978 Metetra
.674 .681 .849 r
.45202 .36978 .4544 .37343 .4586 .37169 .45623 .36806 Metetra
.67 .68 .851 r
.45623 .36806 .4586 .37169 .46281 .37002 .46043 .36639 Metetra
.666 .679 .853 r
.46043 .36639 .46281 .37002 .46702 .36841 .46465 .36479 Metetra
.661 .678 .855 r
.46465 .36479 .46702 .36841 .47123 .36686 .46886 .36324 Metetra
.657 .677 .857 r
.46886 .36324 .47123 .36686 .47545 .36537 .47309 .36174 Metetra
.653 .675 .859 r
.47309 .36174 .47545 .36537 .47968 .36393 .47731 .3603 Metetra
.649 .674 .86 r
.47731 .3603 .47968 .36393 .48391 .36255 .48155 .35892 Metetra
.644 .672 .861 r
.48155 .35892 .48391 .36255 .48814 .36123 .48579 .35759 Metetra
.64 .669 .863 r
.48579 .35759 .48814 .36123 .49239 .35997 .49003 .35631 Metetra
.635 .667 .863 r
.49003 .35631 .49239 .35997 .49664 .35877 .49429 .35509 Metetra
.63 .664 .864 r
.49429 .35509 .49664 .35877 .50089 .35763 .49855 .35393 Metetra
.624 .66 .865 r
.49855 .35393 .50089 .35763 .50516 .35656 .50281 .35284 Metetra
.619 .657 .865 r
.50281 .35284 .50516 .35656 .50943 .35556 .50709 .3518 Metetra
.613 .653 .865 r
.50709 .3518 .50943 .35556 .51371 .35463 .51137 .35084 Metetra
.93 .728 .609 r
.51137 .35084 .51371 .35463 .51799 .35377 .5157 .33447 Metetra
.555 .385 .607 r
.5157 .33447 .51799 .35377 .5223 .33756 .51998 .33386 Metetra
.573 .637 .877 r
.51998 .33386 .5223 .33756 .52658 .33708 .52426 .33332 Metetra
.565 .63 .875 r
.52426 .33332 .52658 .33708 .53088 .33668 .52856 .33287 Metetra
.556 .622 .873 r
.52856 .33287 .53088 .33668 .53518 .3364 .53286 .33251 Metetra
.546 .613 .871 r
.53286 .33251 .53518 .3364 .53949 .33623 .53717 .33226 Metetra
.535 .603 .868 r
.53717 .33226 .53949 .33623 .54381 .33619 .5415 .33213 Metetra
.522 .591 .865 r
.5415 .33213 .54381 .33619 .54815 .3363 .54583 .33214 Metetra
.508 .578 .861 r
.54583 .33214 .54815 .3363 .5525 .33659 .55018 .33231 Metetra
.491 .563 .856 r
.55018 .33231 .5525 .33659 .55686 .33708 .55454 .33266 Metetra
.472 .544 .85 r
.55454 .33266 .55686 .33708 .56124 .33781 .55892 .33322 Metetra
.45 .523 .842 r
.55892 .33322 .56124 .33781 .56563 .33883 .56331 .33404 Metetra
.424 .498 .832 r
.56331 .33404 .56563 .33883 .57004 .34019 .56772 .33516 Metetra
.393 .469 .819 r
.56772 .33516 .57004 .34019 .57448 .34198 .57215 .33664 Metetra
.356 .433 .803 r
.57215 .33664 .57448 .34198 .57893 .3443 .5766 .33859 Metetra
.313 .391 .783 r
.5766 .33859 .57893 .3443 .58342 .34731 .58108 .34111 Metetra
.26 .34 .756 r
.58108 .34111 .58342 .34731 .58795 .35122 .58559 .34438 Metetra
.197 .278 .721 r
.58559 .34438 .58795 .35122 .59253 .35636 .59014 .34865 Metetra
.121 .203 .676 r
.59014 .34865 .59253 .35636 .59717 .36326 .59475 .3543 Metetra
.032 .115 .619 r
.59475 .3543 .59717 .36326 .60191 .37284 .59943 .36195 Metetra
0 .013 .546 r
.59943 .36195 .60191 .37284 .60679 .3868 .60422 .37272 Metetra
0 0 .458 r
.60422 .37272 .60679 .3868 .61195 .40901 .60919 .38882 Metetra
0 0 .355 r
.60919 .38882 .61195 .40901 .61773 .45047 .61451 .41551 Metetra
0 0 .233 r
.61451 .41551 .61773 .45047 .62326 .47907 .62074 .47016 Metetra
.268 .283 .692 r
.62074 .47016 .62326 .47907 .6206 .24247 .62561 .47492 Metetra
0 0 .354 r
.62561 .47492 .6206 .24247 .62496 .24093 .62278 .23809 Metetra
.664 .741 .907 r
.62278 .23809 .62496 .24093 .62931 .23939 .62714 .23655 Metetra
.664 .741 .907 r
.62714 .23655 .62931 .23939 .63368 .23785 .63151 .235 Metetra
.664 .741 .907 r
.63151 .235 .63368 .23785 .63805 .23631 .63589 .23345 Metetra
.664 .741 .907 r
.63589 .23345 .63805 .23631 .64243 .23476 .64027 .2319 Metetra
.664 .741 .907 r
.64027 .2319 .64243 .23476 .64682 .23321 .64466 .23035 Metetra
.664 .741 .907 r
.64466 .23035 .64682 .23321 .65121 .23166 .64906 .22879 Metetra
.664 .741 .907 r
.64906 .22879 .65121 .23166 .65561 .23011 .65346 .22724 Metetra
.664 .741 .907 r
.65346 .22724 .65561 .23011 .66001 .22855 .65788 .22568 Metetra
.664 .741 .907 r
.65788 .22568 .66001 .22855 .66443 .227 .66229 .22411 Metetra
.664 .741 .907 r
.66229 .22411 .66443 .227 .66885 .22544 .66672 .22255 Metetra
.664 .741 .907 r
.66672 .22255 .66885 .22544 .67328 .22387 .67115 .22098 Metetra
.664 .741 .907 r
.67115 .22098 .67328 .22387 .67771 .22231 .67559 .21941 Metetra
.664 .741 .907 r
.67559 .21941 .67771 .22231 .68215 .22074 .68003 .21784 Metetra
.664 .741 .907 r
.68003 .21784 .68215 .22074 .6866 .21917 .68449 .21627 Metetra
.664 .741 .907 r
.68449 .21627 .6866 .21917 .69105 .2176 .68895 .21469 Metetra
.664 .741 .907 r
.68895 .21469 .69105 .2176 .69551 .21602 .69341 .21311 Metetra
.664 .741 .907 r
.69341 .21311 .69551 .21602 .69998 .21445 .69789 .21153 Metetra
.664 .741 .907 r
.69789 .21153 .69998 .21445 .70446 .21287 .70237 .20994 Metetra
.664 .741 .907 r
.70237 .20994 .70446 .21287 .70894 .21128 .70686 .20835 Metetra
.664 .741 .907 r
.70686 .20835 .70894 .21128 .71343 .2097 .71135 .20677 Metetra
.664 .741 .907 r
.71135 .20677 .71343 .2097 .71793 .20811 .71585 .20517 Metetra
.664 .741 .907 r
.71585 .20517 .71793 .20811 .72244 .20652 .72036 .20358 Metetra
.664 .741 .907 r
.72036 .20358 .72244 .20652 .72695 .20493 .72488 .20198 Metetra
.664 .741 .907 r
.72488 .20198 .72695 .20493 .73147 .20333 .7294 .20038 Metetra
.664 .741 .907 r
.7294 .20038 .73147 .20333 .73599 .20173 .73393 .19878 Metetra
.664 .741 .907 r
.73393 .19878 .73599 .20173 .74052 .20013 .73847 .19717 Metetra
.664 .741 .907 r
.73847 .19717 .74052 .20013 .74506 .19853 .74302 .19557 Metetra
.664 .741 .907 r
.74302 .19557 .74506 .19853 .74961 .19693 .74757 .19396 Metetra
.664 .741 .907 r
.74757 .19396 .74961 .19693 .75417 .19532 .75213 .19234 Metetra
.664 .741 .907 r
.75213 .19234 .75417 .19532 .75873 .19371 .7567 .19073 Metetra
.664 .741 .907 r
.7567 .19073 .75873 .19371 .7633 .1921 .76127 .18911 Metetra
.664 .741 .907 r
.76127 .18911 .7633 .1921 .76787 .19048 .76585 .18749 Metetra
.664 .741 .907 r
.76585 .18749 .76787 .19048 .77246 .18886 .77044 .18587 Metetra
.664 .741 .907 r
.77044 .18587 .77246 .18886 .77705 .18724 .77504 .18424 Metetra
.664 .741 .907 r
.77504 .18424 .77705 .18724 .78165 .18562 .77964 .18261 Metetra
.664 .741 .907 r
.77964 .18261 .78165 .18562 .78625 .18399 .78425 .18098 Metetra
.664 .741 .907 r
.78425 .18098 .78625 .18399 .79087 .18236 .78887 .17935 Metetra
.664 .741 .907 r
.78887 .17935 .79087 .18236 .79549 .18073 .7935 .17771 Metetra
.664 .741 .907 r
.7935 .17771 .79549 .18073 .80012 .1791 .79813 .17608 Metetra
.664 .741 .907 r
.79813 .17608 .80012 .1791 .80475 .17746 .80277 .17443 Metetra
.664 .741 .907 r
.18217 .39057 .18477 .39299 .18847 .39168 .18588 .38926 Metetra
.664 .741 .907 r
.18588 .38926 .18847 .39168 .19218 .39037 .1896 .38794 Metetra
.664 .741 .907 r
.1896 .38794 .19218 .39037 .1959 .38905 .19332 .38662 Metetra
.664 .741 .907 r
.19332 .38662 .1959 .38905 .19962 .38774 .19704 .3853 Metetra
.664 .741 .907 r
.19704 .3853 .19962 .38774 .20335 .38642 .20077 .38398 Metetra
.664 .741 .907 r
.20077 .38398 .20335 .38642 .20709 .3851 .20451 .38266 Metetra
.664 .741 .907 r
.20451 .38266 .20709 .3851 .21082 .38378 .20825 .38133 Metetra
.664 .741 .907 r
.20825 .38133 .21082 .38378 .21457 .38245 .212 .38 Metetra
.664 .741 .907 r
.212 .38 .21457 .38245 .21832 .38113 .21575 .37867 Metetra
.664 .741 .907 r
.21575 .37867 .21832 .38113 .22207 .3798 .21951 .37734 Metetra
.664 .741 .907 r
.21951 .37734 .22207 .3798 .22583 .37847 .22328 .37601 Metetra
.664 .741 .907 r
.22328 .37601 .22583 .37847 .2296 .37714 .22704 .37467 Metetra
.664 .741 .907 r
.22704 .37467 .2296 .37714 .23337 .3758 .23082 .37334 Metetra
.664 .741 .907 r
.23082 .37334 .23337 .3758 .23715 .37447 .2346 .372 Metetra
.664 .741 .907 r
.2346 .372 .23715 .37447 .24093 .37313 .23838 .37065 Metetra
.664 .741 .907 r
.23838 .37065 .24093 .37313 .24472 .37179 .24218 .36931 Metetra
.664 .741 .907 r
.24218 .36931 .24472 .37179 .24851 .37045 .24597 .36797 Metetra
.664 .741 .907 r
.24597 .36797 .24851 .37045 .25231 .3691 .24977 .36662 Metetra
.664 .741 .907 r
.24977 .36662 .25231 .3691 .25612 .36776 .25358 .36527 Metetra
.664 .741 .907 r
.25358 .36527 .25612 .36776 .25993 .36641 .2574 .36392 Metetra
.664 .741 .907 r
.2574 .36392 .25993 .36641 .26374 .36506 .26121 .36257 Metetra
.664 .741 .907 r
.26121 .36257 .26374 .36506 .26756 .36371 .26504 .36121 Metetra
.664 .741 .907 r
.26504 .36121 .26756 .36371 .27139 .36236 .26887 .35985 Metetra
.664 .741 .907 r
.26887 .35985 .27139 .36236 .27522 .361 .2727 .3585 Metetra
.664 .741 .907 r
.2727 .3585 .27522 .361 .27906 .35965 .27655 .35713 Metetra
.664 .741 .907 r
.27655 .35713 .27906 .35965 .2829 .35829 .28039 .35577 Metetra
.664 .741 .907 r
.28039 .35577 .2829 .35829 .28675 .35692 .28424 .35441 Metetra
.664 .741 .907 r
.28424 .35441 .28675 .35692 .29061 .35556 .2881 .35304 Metetra
.664 .741 .907 r
.2881 .35304 .29061 .35556 .29447 .3542 .29197 .35167 Metetra
.664 .741 .907 r
.29197 .35167 .29447 .3542 .29833 .35283 .29584 .3503 Metetra
.664 .741 .907 r
.29584 .3503 .29833 .35283 .3022 .35146 .29971 .34893 Metetra
.664 .741 .907 r
.29971 .34893 .3022 .35146 .30608 .35009 .30359 .34755 Metetra
.664 .741 .907 r
.30359 .34755 .30608 .35009 .30996 .34872 .30748 .34617 Metetra
.664 .741 .907 r
.30748 .34617 .30996 .34872 .31385 .34734 .31137 .3448 Metetra
.664 .741 .907 r
.31137 .3448 .31385 .34734 .31775 .34596 .31527 .34341 Metetra
.664 .741 .907 r
.31527 .34341 .31775 .34596 .32165 .34458 .31917 .34203 Metetra
.664 .741 .907 r
.31917 .34203 .32165 .34458 .32555 .3432 .32308 .34065 Metetra
.664 .741 .907 r
.32308 .34065 .32555 .3432 .32947 .34182 .327 .33926 Metetra
.664 .741 .907 r
.327 .33926 .32947 .34182 .33338 .34043 .33092 .33787 Metetra
.954 .682 .483 r
.33092 .33787 .33338 .34043 .33731 .33905 .32101 .56647 Metetra
.529 .299 .511 r
.32101 .56647 .33731 .33905 .32788 .56757 .32522 .56515 Metetra
.949 .71 .544 r
.32522 .56515 .32788 .56757 .33243 .56021 .3322 .51594 Metetra
.74 .501 .567 r
.3322 .51594 .33243 .56021 .33969 .50413 .33825 .48117 Metetra
.761 .533 .587 r
.33825 .48117 .33969 .50413 .34534 .47524 .34347 .46004 Metetra
.77 .555 .608 r
.34347 .46004 .34534 .47524 .35038 .45667 .34831 .44528 Metetra
.773 .574 .63 r
.34831 .44528 .35038 .45667 .35512 .44329 .35293 .43411 Metetra
.774 .59 .65 r
.35293 .43411 .35512 .44329 .35967 .43295 .35742 .42517 Metetra
.773 .604 .67 r
.35742 .42517 .35967 .43295 .36412 .42457 .36182 .41774 Metetra
.77 .616 .688 r
.36182 .41774 .36412 .42457 .36848 .41753 .36616 .41139 Metetra
.767 .627 .705 r
.36616 .41139 .36848 .41753 .3728 .41147 .37045 .40584 Metetra
.763 .637 .721 r
.37045 .40584 .3728 .41147 .37707 .40613 .37471 .4009 Metetra
.759 .646 .735 r
.37471 .4009 .37707 .40613 .38132 .40136 .37894 .39644 Metetra
.755 .653 .748 r
.37894 .39644 .38132 .40136 .38555 .39703 .38316 .39236 Metetra
.751 .66 .76 r
.38316 .39236 .38555 .39703 .38975 .39307 .38736 .3886 Metetra
.746 .665 .771 r
.38736 .3886 .38975 .39307 .39395 .3894 .39156 .38509 Metetra
.742 .67 .781 r
.39156 .38509 .39395 .3894 .39814 .38598 .39574 .38181 Metetra
.738 .675 .789 r
.39574 .38181 .39814 .38598 .40232 .38277 .39992 .37872 Metetra
.734 .679 .797 r
.39992 .37872 .40232 .38277 .40649 .37973 .40409 .37578 Metetra
.73 .682 .804 r
.40409 .37578 .40649 .37973 .41066 .37685 .40827 .37299 Metetra
.726 .685 .811 r
.40827 .37299 .41066 .37685 .41483 .37411 .41244 .37032 Metetra
.722 .688 .817 r
.41244 .37032 .41483 .37411 .419 .37148 .41661 .36776 Metetra
.718 .69 .822 r
.41661 .36776 .419 .37148 .42317 .36896 .42078 .36529 Metetra
.715 .692 .827 r
.42078 .36529 .42317 .36896 .42734 .36653 .42495 .36291 Metetra
.711 .694 .832 r
.42495 .36291 .42734 .36653 .43151 .36419 .42912 .36061 Metetra
.708 .695 .836 r
.42912 .36061 .43151 .36419 .43568 .36192 .43329 .35837 Metetra
.705 .697 .84 r
.43329 .35837 .43568 .36192 .43944 .37532 .43747 .35621 Metetra
.08 .042 .51 r
.43747 .35621 .43944 .37532 .44363 .3734 .44124 .36974 Metetra
.681 .683 .845 r
.44124 .36974 .44363 .3734 .44782 .37156 .44544 .36791 Metetra
.677 .682 .848 r
.44544 .36791 .44782 .37156 .45202 .36978 .44964 .36615 Metetra
.673 .682 .85 r
.44964 .36615 .45202 .36978 .45623 .36806 .45384 .36444 Metetra
.669 .681 .853 r
.45384 .36444 .45623 .36806 .46043 .36639 .45805 .36278 Metetra
.665 .681 .855 r
.45805 .36278 .46043 .36639 .46465 .36479 .46227 .36118 Metetra
.661 .68 .857 r
.46227 .36118 .46465 .36479 .46886 .36324 .46649 .35963 Metetra
.657 .678 .859 r
.46649 .35963 .46886 .36324 .47309 .36174 .47071 .35814 Metetra
.653 .677 .86 r
.47071 .35814 .47309 .36174 .47731 .3603 .47494 .35669 Metetra
.649 .675 .861 r
.47494 .35669 .47731 .3603 .48155 .35892 .47918 .3553 Metetra
.645 .673 .863 r
.47918 .3553 .48155 .35892 .48579 .35759 .48342 .35396 Metetra
.641 .671 .864 r
.48342 .35396 .48579 .35759 .49003 .35631 .48767 .35267 Metetra
.636 .669 .865 r
.48767 .35267 .49003 .35631 .49429 .35509 .49193 .35143 Metetra
.631 .666 .865 r
.49193 .35143 .49429 .35509 .49855 .35393 .49619 .35025 Metetra
.626 .663 .866 r
.49619 .35025 .49855 .35393 .50281 .35284 .50046 .34913 Metetra
.621 .659 .866 r
.50046 .34913 .50281 .35284 .50709 .3518 .50474 .34807 Metetra
.93 .729 .608 r
.50474 .34807 .50709 .3518 .51137 .35084 .5091 .33157 Metetra
.556 .386 .606 r
.5091 .33157 .51137 .35084 .5157 .33447 .51337 .33084 Metetra
.584 .648 .879 r
.51337 .33084 .5157 .33447 .51998 .33386 .51765 .33018 Metetra
.578 .642 .878 r
.51765 .33018 .51998 .33386 .52426 .33332 .52193 .32959 Metetra
.57 .635 .877 r
.52193 .32959 .52426 .33332 .52856 .33287 .52623 .32908 Metetra
.562 .628 .875 r
.52623 .32908 .52856 .33287 .53286 .33251 .53054 .32866 Metetra
.552 .619 .873 r
.53054 .32866 .53286 .33251 .53717 .33226 .53485 .32834 Metetra
.542 .61 .87 r
.53485 .32834 .53717 .33226 .5415 .33213 .53918 .32813 Metetra
.53 .599 .868 r
.53918 .32813 .5415 .33213 .54583 .33214 .54352 .32804 Metetra
.517 .587 .864 r
.54352 .32804 .54583 .33214 .55018 .33231 .54786 .3281 Metetra
.502 .573 .859 r
.54786 .3281 .55018 .33231 .55454 .33266 .55223 .32832 Metetra
.485 .557 .854 r
.55223 .32832 .55454 .33266 .55892 .33322 .5566 .32873 Metetra
.465 .538 .847 r
.5566 .32873 .55892 .33322 .56331 .33404 .56099 .32937 Metetra
.442 .516 .839 r
.56099 .32937 .56331 .33404 .56772 .33516 .5654 .33027 Metetra
.414 .489 .828 r
.5654 .33027 .56772 .33516 .57215 .33664 .56982 .3315 Metetra
.382 .458 .814 r
.56982 .3315 .57215 .33664 .5766 .33859 .57427 .33312 Metetra
.343 .421 .797 r
.57427 .33312 .5766 .33859 .58108 .34111 .57874 .33524 Metetra
.297 .375 .775 r
.57874 .33524 .58108 .34111 .58559 .34438 .58323 .33798 Metetra
.242 .321 .745 r
.58323 .33798 .58559 .34438 .59014 .34865 .58777 .34153 Metetra
.175 .255 .708 r
.58777 .34153 .59014 .34865 .59475 .3543 .59235 .34619 Metetra
.096 .177 .659 r
.59235 .34619 .59475 .3543 .59943 .36195 .59699 .3524 Metetra
.003 .085 .597 r
.59699 .3524 .59943 .36195 .60422 .37272 .60171 .36091 Metetra
0 0 .52 r
.60171 .36091 .60422 .37272 .60919 .38882 .60656 .37309 Metetra
0 0 .428 r
.60656 .37309 .60919 .38882 .61451 .41551 .61164 .39182 Metetra
0 0 .321 r
.61164 .39182 .61451 .41551 .62074 .47016 .61718 .42456 Metetra
0 0 .399 r
.61718 .42456 .62074 .47016 .62561 .47492 .62327 .47222 Metetra
.645 .763 .934 r
.62327 .47222 .62561 .47492 .62278 .23809 .62797 .47076 Metetra
0 0 .354 r
.62797 .47076 .62278 .23809 .62714 .23655 .62496 .23369 Metetra
.664 .741 .907 r
.62496 .23369 .62714 .23655 .63151 .235 .62934 .23214 Metetra
.664 .741 .907 r
.62934 .23214 .63151 .235 .63589 .23345 .63372 .23059 Metetra
.664 .741 .907 r
.63372 .23059 .63589 .23345 .64027 .2319 .63811 .22903 Metetra
.664 .741 .907 r
.63811 .22903 .64027 .2319 .64466 .23035 .6425 .22748 Metetra
.664 .741 .907 r
.6425 .22748 .64466 .23035 .64906 .22879 .64691 .22592 Metetra
.664 .741 .907 r
.64691 .22592 .64906 .22879 .65346 .22724 .65131 .22436 Metetra
.664 .741 .907 r
.65131 .22436 .65346 .22724 .65788 .22568 .65573 .22279 Metetra
.664 .741 .907 r
.65573 .22279 .65788 .22568 .66229 .22411 .66015 .22122 Metetra
.664 .741 .907 r
.66015 .22122 .66229 .22411 .66672 .22255 .66458 .21965 Metetra
.664 .741 .907 r
.66458 .21965 .66672 .22255 .67115 .22098 .66902 .21808 Metetra
.664 .741 .907 r
.66902 .21808 .67115 .22098 .67559 .21941 .67346 .21651 Metetra
.664 .741 .907 r
.67346 .21651 .67559 .21941 .68003 .21784 .67791 .21493 Metetra
.664 .741 .907 r
.67791 .21493 .68003 .21784 .68449 .21627 .68237 .21335 Metetra
.664 .741 .907 r
.68237 .21335 .68449 .21627 .68895 .21469 .68684 .21177 Metetra
.664 .741 .907 r
.68684 .21177 .68895 .21469 .69341 .21311 .69131 .21019 Metetra
.664 .741 .907 r
.69131 .21019 .69341 .21311 .69789 .21153 .69579 .2086 Metetra
.664 .741 .907 r
.69579 .2086 .69789 .21153 .70237 .20994 .70027 .20701 Metetra
.664 .741 .907 r
.70027 .20701 .70237 .20994 .70686 .20835 .70476 .20542 Metetra
.664 .741 .907 r
.70476 .20542 .70686 .20835 .71135 .20677 .70926 .20382 Metetra
.664 .741 .907 r
.70926 .20382 .71135 .20677 .71585 .20517 .71377 .20223 Metetra
.664 .741 .907 r
.71377 .20223 .71585 .20517 .72036 .20358 .71829 .20063 Metetra
.664 .741 .907 r
.71829 .20063 .72036 .20358 .72488 .20198 .72281 .19903 Metetra
.664 .741 .907 r
.72281 .19903 .72488 .20198 .7294 .20038 .72734 .19742 Metetra
.664 .741 .907 r
.72734 .19742 .7294 .20038 .73393 .19878 .73187 .19581 Metetra
.664 .741 .907 r
.73187 .19581 .73393 .19878 .73847 .19717 .73641 .1942 Metetra
.664 .741 .907 r
.73641 .1942 .73847 .19717 .74302 .19557 .74097 .19259 Metetra
.664 .741 .907 r
.74097 .19259 .74302 .19557 .74757 .19396 .74552 .19098 Metetra
.664 .741 .907 r
.74552 .19098 .74757 .19396 .75213 .19234 .75009 .18936 Metetra
.664 .741 .907 r
.75009 .18936 .75213 .19234 .7567 .19073 .75466 .18774 Metetra
.664 .741 .907 r
.75466 .18774 .7567 .19073 .76127 .18911 .75924 .18612 Metetra
.664 .741 .907 r
.75924 .18612 .76127 .18911 .76585 .18749 .76383 .18449 Metetra
.664 .741 .907 r
.76383 .18449 .76585 .18749 .77044 .18587 .76842 .18286 Metetra
.664 .741 .907 r
.76842 .18286 .77044 .18587 .77504 .18424 .77302 .18123 Metetra
.664 .741 .907 r
.77302 .18123 .77504 .18424 .77964 .18261 .77763 .1796 Metetra
.664 .741 .907 r
.77763 .1796 .77964 .18261 .78425 .18098 .78225 .17797 Metetra
.664 .741 .907 r
.78225 .17797 .78425 .18098 .78887 .17935 .78687 .17633 Metetra
.664 .741 .907 r
.78687 .17633 .78887 .17935 .7935 .17771 .7915 .17469 Metetra
.664 .741 .907 r
.7915 .17469 .7935 .17771 .79813 .17608 .79614 .17304 Metetra
.664 .741 .907 r
.79614 .17304 .79813 .17608 .80277 .17443 .80079 .1714 Metetra
.664 .741 .907 r
.17957 .38814 .18217 .39057 .18588 .38926 .18329 .38682 Metetra
.664 .741 .907 r
.18329 .38682 .18588 .38926 .1896 .38794 .187 .38551 Metetra
.664 .741 .907 r
.187 .38551 .1896 .38794 .19332 .38662 .19073 .38418 Metetra
.664 .741 .907 r
.19073 .38418 .19332 .38662 .19704 .3853 .19446 .38286 Metetra
.664 .741 .907 r
.19446 .38286 .19704 .3853 .20077 .38398 .19819 .38153 Metetra
.664 .741 .907 r
.19819 .38153 .20077 .38398 .20451 .38266 .20193 .38021 Metetra
.664 .741 .907 r
.20193 .38021 .20451 .38266 .20825 .38133 .20568 .37888 Metetra
.664 .741 .907 r
.20568 .37888 .20825 .38133 .212 .38 .20943 .37755 Metetra
.664 .741 .907 r
.20943 .37755 .212 .38 .21575 .37867 .21318 .37621 Metetra
.664 .741 .907 r
.21318 .37621 .21575 .37867 .21951 .37734 .21694 .37488 Metetra
.664 .741 .907 r
.21694 .37488 .21951 .37734 .22328 .37601 .22071 .37354 Metetra
.664 .741 .907 r
.22071 .37354 .22328 .37601 .22704 .37467 .22448 .3722 Metetra
.664 .741 .907 r
.22448 .3722 .22704 .37467 .23082 .37334 .22826 .37086 Metetra
.664 .741 .907 r
.22826 .37086 .23082 .37334 .2346 .372 .23204 .36952 Metetra
.664 .741 .907 r
.23204 .36952 .2346 .372 .23838 .37065 .23583 .36817 Metetra
.664 .741 .907 r
.23583 .36817 .23838 .37065 .24218 .36931 .23963 .36683 Metetra
.664 .741 .907 r
.23963 .36683 .24218 .36931 .24597 .36797 .24343 .36548 Metetra
.664 .741 .907 r
.24343 .36548 .24597 .36797 .24977 .36662 .24723 .36413 Metetra
.664 .741 .907 r
.24723 .36413 .24977 .36662 .25358 .36527 .25104 .36277 Metetra
.664 .741 .907 r
.25104 .36277 .25358 .36527 .2574 .36392 .25486 .36142 Metetra
.664 .741 .907 r
.25486 .36142 .2574 .36392 .26121 .36257 .25868 .36006 Metetra
.664 .741 .907 r
.25868 .36006 .26121 .36257 .26504 .36121 .26251 .3587 Metetra
.664 .741 .907 r
.26251 .3587 .26504 .36121 .26887 .35985 .26634 .35734 Metetra
.664 .741 .907 r
.26634 .35734 .26887 .35985 .2727 .3585 .27018 .35598 Metetra
.664 .741 .907 r
.27018 .35598 .2727 .3585 .27655 .35713 .27403 .35462 Metetra
.664 .741 .907 r
.27403 .35462 .27655 .35713 .28039 .35577 .27788 .35325 Metetra
.664 .741 .907 r
.27788 .35325 .28039 .35577 .28424 .35441 .28173 .35188 Metetra
.664 .741 .907 r
.28173 .35188 .28424 .35441 .2881 .35304 .28559 .35051 Metetra
.664 .741 .907 r
.28559 .35051 .2881 .35304 .29197 .35167 .28946 .34914 Metetra
.664 .741 .907 r
.28946 .34914 .29197 .35167 .29584 .3503 .29333 .34776 Metetra
.664 .741 .907 r
.29333 .34776 .29584 .3503 .29971 .34893 .29721 .34639 Metetra
.664 .741 .907 r
.29721 .34639 .29971 .34893 .30359 .34755 .3011 .34501 Metetra
.664 .741 .907 r
.3011 .34501 .30359 .34755 .30748 .34617 .30499 .34363 Metetra
.664 .741 .907 r
.30499 .34363 .30748 .34617 .31137 .3448 .30888 .34224 Metetra
.664 .741 .907 r
.30888 .34224 .31137 .3448 .31527 .34341 .31278 .34086 Metetra
.664 .741 .907 r
.31278 .34086 .31527 .34341 .31917 .34203 .31669 .33947 Metetra
.664 .741 .907 r
.31669 .33947 .31917 .34203 .32308 .34065 .3206 .33808 Metetra
.664 .741 .907 r
.3206 .33808 .32308 .34065 .327 .33926 .32452 .33669 Metetra
.664 .741 .907 r
.32452 .33669 .327 .33926 .33092 .33787 .32845 .3353 Metetra
.954 .682 .483 r
.32845 .3353 .33092 .33787 .32101 .56647 .31834 .56404 Metetra
.944 .72 .568 r
.31834 .56404 .32101 .56647 .32522 .56515 .32443 .53134 Metetra
.797 .552 .568 r
.32443 .53134 .32522 .56515 .3322 .51594 .33105 .48835 Metetra
.755 .523 .581 r
.33105 .48835 .3322 .51594 .33825 .48117 .33651 .464 Metetra
.767 .548 .601 r
.33651 .464 .33825 .48117 .34347 .46004 .34147 .4476 Metetra
.772 .568 .623 r
.34147 .4476 .34347 .46004 .34831 .44528 .34616 .43546 Metetra
.773 .584 .644 r
.34616 .43546 .34831 .44528 .35293 .43411 .3507 .4259 Metetra
.773 .599 .664 r
.3507 .4259 .35293 .43411 .35742 .42517 .35513 .41805 Metetra
.771 .612 .682 r
.35513 .41805 .35742 .42517 .36182 .41774 .3595 .41139 Metetra
.768 .624 .7 r
.3595 .41139 .36182 .41774 .36616 .41139 .36381 .4056 Metetra
.764 .634 .716 r
.36381 .4056 .36616 .41139 .37045 .40584 .36808 .40048 Metetra
.761 .643 .731 r
.36808 .40048 .37045 .40584 .37471 .4009 .37233 .39587 Metetra
.756 .65 .744 r
.37233 .39587 .37471 .4009 .37894 .39644 .37656 .39168 Metetra
.752 .657 .756 r
.37656 .39168 .37894 .39644 .38316 .39236 .38077 .38782 Metetra
.748 .663 .767 r
.38077 .38782 .38316 .39236 .38736 .3886 .38497 .38423 Metetra
.743 .669 .777 r
.38497 .38423 .38736 .3886 .39156 .38509 .38915 .38088 Metetra
.739 .674 .786 r
.38915 .38088 .39156 .38509 .39574 .38181 .39334 .37772 Metetra
.735 .678 .795 r
.39334 .37772 .39574 .38181 .39992 .37872 .39751 .37473 Metetra
.731 .681 .802 r
.39751 .37473 .39992 .37872 .40409 .37578 .40169 .37189 Metetra
.727 .684 .809 r
.40169 .37189 .40409 .37578 .40827 .37299 .40586 .36917 Metetra
.723 .687 .815 r
.40586 .36917 .40827 .37299 .41244 .37032 .41003 .36657 Metetra
.72 .69 .821 r
.41003 .36657 .41244 .37032 .41661 .36776 .4142 .36406 Metetra
.716 .692 .826 r
.4142 .36406 .41661 .36776 .42078 .36529 .41837 .36165 Metetra
.713 .694 .83 r
.41837 .36165 .42078 .36529 .42495 .36291 .42255 .35931 Metetra
.709 .695 .835 r
.42255 .35931 .42495 .36291 .42912 .36061 .42672 .35705 Metetra
.706 .697 .838 r
.42672 .35705 .42912 .36061 .43329 .35837 .4309 .35485 Metetra
.703 .698 .842 r
.4309 .35485 .43329 .35837 .43747 .35621 .43508 .35271 Metetra
.7 .699 .845 r
.43508 .35271 .43747 .35621 .44124 .36974 .43926 .35063 Metetra
.073 .037 .507 r
.43926 .35063 .44124 .36974 .44544 .36791 .44304 .36429 Metetra
.676 .684 .85 r
.44304 .36429 .44544 .36791 .44964 .36615 .44725 .36253 Metetra
.672 .683 .852 r
.44725 .36253 .44964 .36615 .45384 .36444 .45145 .36083 Metetra
.669 .683 .854 r
.45145 .36083 .45384 .36444 .45805 .36278 .45567 .35919 Metetra
.665 .682 .856 r
.45567 .35919 .45805 .36278 .46227 .36118 .45988 .35759 Metetra
.661 .681 .858 r
.45988 .35759 .46227 .36118 .46649 .35963 .46411 .35604 Metetra
.657 .68 .86 r
.46411 .35604 .46649 .35963 .47071 .35814 .46834 .35454 Metetra
.654 .679 .861 r
.46834 .35454 .47071 .35814 .47494 .35669 .47257 .35309 Metetra
.65 .677 .863 r
.47257 .35309 .47494 .35669 .47918 .3553 .47681 .35169 Metetra
.646 .675 .864 r
.47681 .35169 .47918 .3553 .48342 .35396 .48106 .35034 Metetra
.641 .673 .865 r
.48106 .35034 .48342 .35396 .48767 .35267 .48531 .34904 Metetra
.637 .671 .866 r
.48531 .34904 .48767 .35267 .49193 .35143 .48957 .34779 Metetra
.632 .668 .866 r
.48957 .34779 .49193 .35143 .49619 .35025 .49383 .34659 Metetra
.628 .665 .867 r
.49383 .34659 .49619 .35025 .50046 .34913 .4981 .34545 Metetra
.931 .729 .608 r
.4981 .34545 .50046 .34913 .50474 .34807 .50249 .32882 Metetra
.558 .387 .606 r
.50249 .32882 .50474 .34807 .5091 .33157 .50676 .328 Metetra
.594 .656 .881 r
.50676 .328 .5091 .33157 .51337 .33084 .51103 .32723 Metetra
.588 .651 .88 r
.51103 .32723 .51337 .33084 .51765 .33018 .51531 .32653 Metetra
.582 .646 .879 r
.51531 .32653 .51765 .33018 .52193 .32959 .5196 .32589 Metetra
.575 .64 .878 r
.5196 .32589 .52193 .32959 .52623 .32908 .5239 .32533 Metetra
.567 .633 .876 r
.5239 .32533 .52623 .32908 .53054 .32866 .52821 .32485 Metetra
.558 .625 .875 r
.52821 .32485 .53054 .32866 .53485 .32834 .53253 .32446 Metetra
.549 .616 .872 r
.53253 .32446 .53485 .32834 .53918 .32813 .53685 .32417 Metetra
.538 .607 .87 r
.53685 .32417 .53918 .32813 .54352 .32804 .54119 .32399 Metetra
.526 .595 .867 r
.54119 .32399 .54352 .32804 .54786 .3281 .54554 .32395 Metetra
.512 .583 .863 r
.54554 .32395 .54786 .3281 .55223 .32832 .5499 .32405 Metetra
.497 .568 .858 r
.5499 .32405 .55223 .32832 .5566 .32873 .55428 .32433 Metetra
.479 .551 .852 r
.55428 .32433 .5566 .32873 .56099 .32937 .55867 .32481 Metetra
.458 .531 .845 r
.55867 .32481 .56099 .32937 .5654 .33027 .56307 .32552 Metetra
.433 .507 .835 r
.56307 .32552 .5654 .33027 .56982 .3315 .56749 .32652 Metetra
.405 .48 .824 r
.56749 .32652 .56982 .3315 .57427 .33312 .57193 .32786 Metetra
.371 .447 .809 r
.57193 .32786 .57427 .33312 .57874 .33524 .5764 .32963 Metetra
.33 .407 .79 r
.5764 .32963 .57874 .33524 .58323 .33798 .58088 .33192 Metetra
.281 .359 .766 r
.58088 .33192 .58323 .33798 .58777 .34153 .5854 .33489 Metetra
.223 .302 .734 r
.5854 .33489 .58777 .34153 .59235 .34619 .58996 .33876 Metetra
.153 .232 .693 r
.58996 .33876 .59235 .34619 .59699 .3524 .59457 .34385 Metetra
.07 .15 .641 r
.59457 .34385 .59699 .3524 .60171 .36091 .59924 .35069 Metetra
0 .054 .575 r
.59924 .35069 .60171 .36091 .60656 .37309 .60401 .36018 Metetra
0 0 .493 r
.60401 .36018 .60656 .37309 .61164 .39182 .60894 .37404 Metetra
0 0 .397 r
.60894 .37404 .61164 .39182 .61718 .42456 .61414 .39608 Metetra
0 0 .285 r
.61414 .39608 .61718 .42456 .62327 .47222 .61997 .43728 Metetra
.019 0 .461 r
.61997 .43728 .62327 .47222 .62797 .47076 .62562 .46804 Metetra
.976 .689 .41 r
.62562 .46804 .62797 .47076 .62496 .23369 .62278 .23083 Metetra
.664 .741 .907 r
.62278 .23083 .62496 .23369 .62934 .23214 .62716 .22927 Metetra
.664 .741 .907 r
.62716 .22927 .62934 .23214 .63372 .23059 .63155 .22772 Metetra
.664 .741 .907 r
.63155 .22772 .63372 .23059 .63811 .22903 .63594 .22616 Metetra
.664 .741 .907 r
.63594 .22616 .63811 .22903 .6425 .22748 .64034 .2246 Metetra
.664 .741 .907 r
.64034 .2246 .6425 .22748 .64691 .22592 .64474 .22303 Metetra
.664 .741 .907 r
.64474 .22303 .64691 .22592 .65131 .22436 .64916 .22146 Metetra
.664 .741 .907 r
.64916 .22146 .65131 .22436 .65573 .22279 .65358 .2199 Metetra
.664 .741 .907 r
.65358 .2199 .65573 .22279 .66015 .22122 .65801 .21832 Metetra
.664 .741 .907 r
.65801 .21832 .66015 .22122 .66458 .21965 .66244 .21675 Metetra
.664 .741 .907 r
.66244 .21675 .66458 .21965 .66902 .21808 .66688 .21517 Metetra
.664 .741 .907 r
.66688 .21517 .66902 .21808 .67346 .21651 .67133 .2136 Metetra
.664 .741 .907 r
.67133 .2136 .67346 .21651 .67791 .21493 .67579 .21201 Metetra
.664 .741 .907 r
.67579 .21201 .67791 .21493 .68237 .21335 .68025 .21043 Metetra
.664 .741 .907 r
.68025 .21043 .68237 .21335 .68684 .21177 .68472 .20884 Metetra
.664 .741 .907 r
.68472 .20884 .68684 .21177 .69131 .21019 .68919 .20725 Metetra
.664 .741 .907 r
.68919 .20725 .69131 .21019 .69579 .2086 .69368 .20566 Metetra
.664 .741 .907 r
.69368 .20566 .69579 .2086 .70027 .20701 .69817 .20407 Metetra
.664 .741 .907 r
.69817 .20407 .70027 .20701 .70476 .20542 .70267 .20247 Metetra
.664 .741 .907 r
.70267 .20247 .70476 .20542 .70926 .20382 .70717 .20087 Metetra
.664 .741 .907 r
.70717 .20087 .70926 .20382 .71377 .20223 .71168 .19927 Metetra
.664 .741 .907 r
.71168 .19927 .71377 .20223 .71829 .20063 .7162 .19767 Metetra
.664 .741 .907 r
.7162 .19767 .71829 .20063 .72281 .19903 .72073 .19606 Metetra
.664 .741 .907 r
.72073 .19606 .72281 .19903 .72734 .19742 .72526 .19445 Metetra
.664 .741 .907 r
.72526 .19445 .72734 .19742 .73187 .19581 .7298 .19284 Metetra
.664 .741 .907 r
.7298 .19284 .73187 .19581 .73641 .1942 .73435 .19123 Metetra
.664 .741 .907 r
.73435 .19123 .73641 .1942 .74097 .19259 .73891 .18961 Metetra
.664 .741 .907 r
.73891 .18961 .74097 .19259 .74552 .19098 .74347 .18799 Metetra
.664 .741 .907 r
.74347 .18799 .74552 .19098 .75009 .18936 .74804 .18637 Metetra
.664 .741 .907 r
.74804 .18637 .75009 .18936 .75466 .18774 .75262 .18474 Metetra
.664 .741 .907 r
.75262 .18474 .75466 .18774 .75924 .18612 .7572 .18312 Metetra
.664 .741 .907 r
.7572 .18312 .75924 .18612 .76383 .18449 .76179 .18149 Metetra
.664 .741 .907 r
.76179 .18149 .76383 .18449 .76842 .18286 .76639 .17985 Metetra
.664 .741 .907 r
.76639 .17985 .76842 .18286 .77302 .18123 .771 .17822 Metetra
.664 .741 .907 r
.771 .17822 .77302 .18123 .77763 .1796 .77561 .17658 Metetra
.664 .741 .907 r
.77561 .17658 .77763 .1796 .78225 .17797 .78023 .17494 Metetra
.664 .741 .907 r
.78023 .17494 .78225 .17797 .78687 .17633 .78486 .1733 Metetra
.664 .741 .907 r
.78486 .1733 .78687 .17633 .7915 .17469 .7895 .17165 Metetra
.664 .741 .907 r
.7895 .17165 .7915 .17469 .79614 .17304 .79414 .17 Metetra
.664 .741 .907 r
.79414 .17 .79614 .17304 .80079 .1714 .7988 .16835 Metetra
.664 .741 .907 r
.17697 .38571 .17957 .38814 .18329 .38682 .18068 .38439 Metetra
.664 .741 .907 r
.18068 .38439 .18329 .38682 .187 .38551 .1844 .38306 Metetra
.664 .741 .907 r
.1844 .38306 .187 .38551 .19073 .38418 .18813 .38174 Metetra
.664 .741 .907 r
.18813 .38174 .19073 .38418 .19446 .38286 .19186 .38041 Metetra
.664 .741 .907 r
.19186 .38041 .19446 .38286 .19819 .38153 .1956 .37908 Metetra
.664 .741 .907 r
.1956 .37908 .19819 .38153 .20193 .38021 .19934 .37775 Metetra
.664 .741 .907 r
.19934 .37775 .20193 .38021 .20568 .37888 .20309 .37642 Metetra
.664 .741 .907 r
.20309 .37642 .20568 .37888 .20943 .37755 .20684 .37508 Metetra
.664 .741 .907 r
.20684 .37508 .20943 .37755 .21318 .37621 .2106 .37375 Metetra
.664 .741 .907 r
.2106 .37375 .21318 .37621 .21694 .37488 .21437 .37241 Metetra
.664 .741 .907 r
.21437 .37241 .21694 .37488 .22071 .37354 .21814 .37107 Metetra
.664 .741 .907 r
.21814 .37107 .22071 .37354 .22448 .3722 .22191 .36973 Metetra
.664 .741 .907 r
.22191 .36973 .22448 .3722 .22826 .37086 .22569 .36838 Metetra
.664 .741 .907 r
.22569 .36838 .22826 .37086 .23204 .36952 .22948 .36703 Metetra
.664 .741 .907 r
.22948 .36703 .23204 .36952 .23583 .36817 .23327 .36569 Metetra
.664 .741 .907 r
.23327 .36569 .23583 .36817 .23963 .36683 .23707 .36434 Metetra
.664 .741 .907 r
.23707 .36434 .23963 .36683 .24343 .36548 .24087 .36298 Metetra
.664 .741 .907 r
.24087 .36298 .24343 .36548 .24723 .36413 .24468 .36163 Metetra
.664 .741 .907 r
.24468 .36163 .24723 .36413 .25104 .36277 .2485 .36027 Metetra
.664 .741 .907 r
.2485 .36027 .25104 .36277 .25486 .36142 .25232 .35891 Metetra
.664 .741 .907 r
.25232 .35891 .25486 .36142 .25868 .36006 .25614 .35755 Metetra
.664 .741 .907 r
.25614 .35755 .25868 .36006 .26251 .3587 .25997 .35619 Metetra
.664 .741 .907 r
.25997 .35619 .26251 .3587 .26634 .35734 .26381 .35483 Metetra
.664 .741 .907 r
.26381 .35483 .26634 .35734 .27018 .35598 .26765 .35346 Metetra
.664 .741 .907 r
.26765 .35346 .27018 .35598 .27403 .35462 .2715 .35209 Metetra
.664 .741 .907 r
.2715 .35209 .27403 .35462 .27788 .35325 .27535 .35072 Metetra
.664 .741 .907 r
.27535 .35072 .27788 .35325 .28173 .35188 .27921 .34935 Metetra
.664 .741 .907 r
.27921 .34935 .28173 .35188 .28559 .35051 .28308 .34798 Metetra
.664 .741 .907 r
.28308 .34798 .28559 .35051 .28946 .34914 .28695 .3466 Metetra
.664 .741 .907 r
.28695 .3466 .28946 .34914 .29333 .34776 .29082 .34522 Metetra
.664 .741 .907 r
.29082 .34522 .29333 .34776 .29721 .34639 .29471 .34384 Metetra
.664 .741 .907 r
.29471 .34384 .29721 .34639 .3011 .34501 .29859 .34246 Metetra
.664 .741 .907 r
.29859 .34246 .3011 .34501 .30499 .34363 .30249 .34107 Metetra
.664 .741 .907 r
.30249 .34107 .30499 .34363 .30888 .34224 .30639 .33969 Metetra
.664 .741 .907 r
.30639 .33969 .30888 .34224 .31278 .34086 .31029 .3383 Metetra
.664 .741 .907 r
.31029 .3383 .31278 .34086 .31669 .33947 .3142 .33691 Metetra
.664 .741 .907 r
.3142 .33691 .31669 .33947 .3206 .33808 .31812 .33551 Metetra
.664 .741 .907 r
.31812 .33551 .3206 .33808 .32452 .33669 .32204 .33412 Metetra
.954 .682 .484 r
.32204 .33412 .32452 .33669 .32845 .3353 .31146 .56293 Metetra
.511 .284 .507 r
.31146 .56293 .32845 .3353 .31834 .56404 .31624 .55227 Metetra
.907 .66 .554 r
.31624 .55227 .31834 .56404 .32443 .53134 .32371 .49717 Metetra
.748 .512 .574 r
.32371 .49717 .32443 .53134 .33105 .48835 .32947 .46866 Metetra
.763 .54 .594 r
.32947 .46866 .33105 .48835 .33651 .464 .33458 .45029 Metetra
.77 .561 .616 r
.33458 .45029 .33651 .464 .34147 .4476 .33936 .43704 Metetra
.772 .579 .637 r
.33936 .43704 .34147 .4476 .34616 .43546 .34395 .42678 Metetra
.773 .594 .657 r
.34395 .42678 .34616 .43546 .3507 .4259 .34843 .41846 Metetra
.771 .608 .676 r
.34843 .41846 .3507 .4259 .35513 .41805 .35282 .41146 Metetra
.769 .62 .694 r
.35282 .41146 .35513 .41805 .3595 .41139 .35715 .40542 Metetra
.765 .63 .711 r
.35715 .40542 .3595 .41139 .36381 .4056 .36144 .40011 Metetra
.762 .64 .726 r
.36144 .40011 .36381 .4056 .36808 .40048 .3657 .39535 Metetra
.758 .648 .74 r
.3657 .39535 .36808 .40048 .37233 .39587 .36994 .39103 Metetra
.753 .655 .753 r
.36994 .39103 .37233 .39587 .37656 .39168 .37416 .38706 Metetra
.749 .661 .764 r
.37416 .38706 .37656 .39168 .38077 .38782 .37836 .38339 Metetra
.745 .667 .774 r
.37836 .38339 .38077 .38782 .38497 .38423 .38256 .37996 Metetra
.741 .672 .784 r
.38256 .37996 .38497 .38423 .38915 .38088 .38674 .37674 Metetra
.736 .676 .792 r
.38674 .37674 .38915 .38088 .39334 .37772 .39093 .3737 Metetra
.732 .68 .8 r
.39093 .3737 .39334 .37772 .39751 .37473 .3951 .37081 Metetra
.729 .684 .807 r
.3951 .37081 .39751 .37473 .40169 .37189 .39928 .36804 Metetra
.725 .687 .813 r
.39928 .36804 .40169 .37189 .40586 .36917 .40345 .3654 Metetra
.721 .689 .819 r
.40345 .3654 .40586 .36917 .41003 .36657 .40762 .36286 Metetra
.718 .691 .824 r
.40762 .36286 .41003 .36657 .4142 .36406 .41179 .36041 Metetra
.714 .693 .829 r
.41179 .36041 .4142 .36406 .41837 .36165 .41597 .35804 Metetra
.711 .695 .833 r
.41597 .35804 .41837 .36165 .42255 .35931 .42014 .35574 Metetra
.708 .697 .837 r
.42014 .35574 .42255 .35931 .42672 .35705 .42432 .35351 Metetra
.705 .698 .841 r
.42432 .35351 .42672 .35705 .4309 .35485 .4285 .35135 Metetra
.702 .699 .844 r
.4285 .35135 .4309 .35485 .43508 .35271 .43268 .34924 Metetra
.699 .7 .847 r
.43268 .34924 .43508 .35271 .43926 .35063 .43686 .34718 Metetra
.696 .701 .85 r
.43686 .34718 .43926 .35063 .44304 .36429 .44105 .34517 Metetra
.068 .033 .505 r
.44105 .34517 .44304 .36429 .44725 .36253 .44485 .35894 Metetra
.672 .685 .854 r
.44485 .35894 .44725 .36253 .45145 .36083 .44906 .35725 Metetra
.668 .684 .856 r
.44906 .35725 .45145 .36083 .45567 .35919 .45327 .35561 Metetra
.665 .683 .858 r
.45327 .35561 .45567 .35919 .45988 .35759 .4575 .35401 Metetra
.661 .683 .86 r
.4575 .35401 .45988 .35759 .46411 .35604 .46172 .35247 Metetra
.657 .681 .861 r
.46172 .35247 .46411 .35604 .46834 .35454 .46595 .35097 Metetra
.654 .68 .863 r
.46595 .35097 .46834 .35454 .47257 .35309 .47019 .34951 Metetra
.65 .679 .864 r
.47019 .34951 .47257 .35309 .47681 .35169 .47443 .3481 Metetra
.646 .677 .865 r
.47443 .3481 .47681 .35169 .48106 .35034 .47868 .34674 Metetra
.642 .675 .866 r
.47868 .34674 .48106 .35034 .48531 .34904 .48294 .34543 Metetra
.638 .673 .867 r
.48294 .34543 .48531 .34904 .48957 .34779 .4872 .34416 Metetra
.634 .67 .868 r
.4872 .34416 .48957 .34779 .49383 .34659 .49147 .34295 Metetra
.932 .73 .607 r
.49147 .34295 .49383 .34659 .4981 .34545 .49589 .32621 Metetra
.559 .388 .606 r
.49589 .32621 .4981 .34545 .50249 .32882 .50014 .3253 Metetra
.602 .663 .882 r
.50014 .3253 .50249 .32882 .50676 .328 .50441 .32445 Metetra
.597 .659 .882 r
.50441 .32445 .50676 .328 .51103 .32723 .50869 .32365 Metetra
.591 .655 .881 r
.50869 .32365 .51103 .32723 .51531 .32653 .51297 .3229 Metetra
.585 .649 .88 r
.51297 .3229 .51531 .32653 .5196 .32589 .51726 .32222 Metetra
.579 .644 .879 r
.51726 .32222 .5196 .32589 .5239 .32533 .52157 .32161 Metetra
.572 .637 .878 r
.52157 .32161 .5239 .32533 .52821 .32485 .52588 .32107 Metetra
.564 .63 .876 r
.52588 .32107 .52821 .32485 .53253 .32446 .5302 .32062 Metetra
.555 .622 .874 r
.5302 .32062 .53253 .32446 .53685 .32417 .53453 .32025 Metetra
.545 .613 .872 r
.53453 .32025 .53685 .32417 .54119 .32399 .53887 .32 Metetra
.534 .603 .869 r
.53887 .32 .54119 .32399 .54554 .32395 .54322 .31986 Metetra
.521 .591 .865 r
.54322 .31986 .54554 .32395 .5499 .32405 .54758 .31986 Metetra
.507 .578 .861 r
.54758 .31986 .5499 .32405 .55428 .32433 .55195 .32002 Metetra
.491 .563 .856 r
.55195 .32002 .55428 .32433 .55867 .32481 .55634 .32035 Metetra
.472 .545 .85 r
.55634 .32035 .55867 .32481 .56307 .32552 .56075 .3209 Metetra
.45 .524 .842 r
.56075 .3209 .56307 .32552 .56749 .32652 .56516 .32169 Metetra
.425 .499 .832 r
.56516 .32169 .56749 .32652 .57193 .32786 .5696 .32279 Metetra
.395 .47 .819 r
.5696 .32279 .57193 .32786 .5764 .32963 .57406 .32425 Metetra
.359 .435 .803 r
.57406 .32425 .5764 .32963 .58088 .33192 .57854 .32616 Metetra
.316 .393 .783 r
.57854 .32616 .58088 .33192 .5854 .33489 .58305 .32864 Metetra
.265 .342 .756 r
.58305 .32864 .5854 .33489 .58996 .33876 .58759 .33186 Metetra
.204 .281 .722 r
.58759 .33186 .58996 .33876 .59457 .34385 .59217 .33607 Metetra
.13 .209 .678 r
.59217 .33607 .59457 .34385 .59924 .35069 .5968 .34164 Metetra
.043 .122 .622 r
.5968 .34164 .59924 .35069 .60401 .36018 .60152 .3492 Metetra
0 .022 .551 r
.60152 .3492 .60401 .36018 .60894 .37404 .60634 .35983 Metetra
0 0 .466 r
.60634 .35983 .60894 .37404 .61414 .39608 .61135 .37571 Metetra
0 0 .366 r
.61135 .37571 .61414 .39608 .61997 .43728 .61671 .40202 Metetra
0 0 .247 r
.61671 .40202 .61997 .43728 .62562 .46804 .62298 .45571 Metetra
.181 .177 .617 r
.62298 .45571 .62562 .46804 .62278 .23083 .62799 .46384 Metetra
0 0 .352 r
.62799 .46384 .62278 .23083 .62716 .22927 .62497 .2264 Metetra
.664 .741 .907 r
.62497 .2264 .62716 .22927 .63155 .22772 .62936 .22484 Metetra
.664 .741 .907 r
.62936 .22484 .63155 .22772 .63594 .22616 .63376 .22327 Metetra
.664 .741 .907 r
.63376 .22327 .63594 .22616 .64034 .2246 .63817 .22171 Metetra
.664 .741 .907 r
.63817 .22171 .64034 .2246 .64474 .22303 .64258 .22014 Metetra
.664 .741 .907 r
.64258 .22014 .64474 .22303 .64916 .22146 .647 .21857 Metetra
.664 .741 .907 r
.647 .21857 .64916 .22146 .65358 .2199 .65142 .21699 Metetra
.664 .741 .907 r
.65142 .21699 .65358 .2199 .65801 .21832 .65585 .21542 Metetra
.664 .741 .907 r
.65585 .21542 .65801 .21832 .66244 .21675 .66029 .21384 Metetra
.664 .741 .907 r
.66029 .21384 .66244 .21675 .66688 .21517 .66474 .21226 Metetra
.664 .741 .907 r
.66474 .21226 .66688 .21517 .67133 .2136 .66919 .21067 Metetra
.664 .741 .907 r
.66919 .21067 .67133 .2136 .67579 .21201 .67365 .20909 Metetra
.664 .741 .907 r
.67365 .20909 .67579 .21201 .68025 .21043 .67812 .2075 Metetra
.664 .741 .907 r
.67812 .2075 .68025 .21043 .68472 .20884 .68259 .20591 Metetra
.664 .741 .907 r
.68259 .20591 .68472 .20884 .68919 .20725 .68707 .20431 Metetra
.664 .741 .907 r
.68707 .20431 .68919 .20725 .69368 .20566 .69156 .20272 Metetra
.664 .741 .907 r
.69156 .20272 .69368 .20566 .69817 .20407 .69606 .20112 Metetra
.664 .741 .907 r
.69606 .20112 .69817 .20407 .70267 .20247 .70056 .19952 Metetra
.664 .741 .907 r
.70056 .19952 .70267 .20247 .70717 .20087 .70507 .19791 Metetra
.664 .741 .907 r
.70507 .19791 .70717 .20087 .71168 .19927 .70959 .19631 Metetra
.664 .741 .907 r
.70959 .19631 .71168 .19927 .7162 .19767 .71411 .1947 Metetra
.664 .741 .907 r
.71411 .1947 .7162 .19767 .72073 .19606 .71864 .19309 Metetra
.664 .741 .907 r
.71864 .19309 .72073 .19606 .72526 .19445 .72318 .19147 Metetra
.664 .741 .907 r
.72318 .19147 .72526 .19445 .7298 .19284 .72773 .18986 Metetra
.664 .741 .907 r
.72773 .18986 .7298 .19284 .73435 .19123 .73228 .18824 Metetra
.664 .741 .907 r
.73228 .18824 .73435 .19123 .73891 .18961 .73684 .18662 Metetra
.664 .741 .907 r
.73684 .18662 .73891 .18961 .74347 .18799 .74141 .18499 Metetra
.664 .741 .907 r
.74141 .18499 .74347 .18799 .74804 .18637 .74598 .18337 Metetra
.664 .741 .907 r
.74598 .18337 .74804 .18637 .75262 .18474 .75057 .18174 Metetra
.664 .741 .907 r
.75057 .18174 .75262 .18474 .7572 .18312 .75516 .1801 Metetra
.664 .741 .907 r
.75516 .1801 .7572 .18312 .76179 .18149 .75975 .17847 Metetra
.664 .741 .907 r
.75975 .17847 .76179 .18149 .76639 .17985 .76436 .17683 Metetra
.664 .741 .907 r
.76436 .17683 .76639 .17985 .771 .17822 .76897 .17519 Metetra
.664 .741 .907 r
.76897 .17519 .771 .17822 .77561 .17658 .77359 .17355 Metetra
.664 .741 .907 r
.77359 .17355 .77561 .17658 .78023 .17494 .77822 .1719 Metetra
.664 .741 .907 r
.77822 .1719 .78023 .17494 .78486 .1733 .78285 .17026 Metetra
.664 .741 .907 r
.78285 .17026 .78486 .1733 .7895 .17165 .78749 .16861 Metetra
.664 .741 .907 r
.78749 .16861 .7895 .17165 .79414 .17 .79214 .16695 Metetra
.664 .741 .907 r
.79214 .16695 .79414 .17 .7988 .16835 .7968 .1653 Metetra
.664 .741 .907 r
.17435 .38327 .17697 .38571 .18068 .38439 .17807 .38194 Metetra
.664 .741 .907 r
.17807 .38194 .18068 .38439 .1844 .38306 .1818 .38062 Metetra
.664 .741 .907 r
.1818 .38062 .1844 .38306 .18813 .38174 .18553 .37929 Metetra
.664 .741 .907 r
.18553 .37929 .18813 .38174 .19186 .38041 .18926 .37796 Metetra
.664 .741 .907 r
.18926 .37796 .19186 .38041 .1956 .37908 .193 .37662 Metetra
.664 .741 .907 r
.193 .37662 .1956 .37908 .19934 .37775 .19675 .37529 Metetra
.664 .741 .907 r
.19675 .37529 .19934 .37775 .20309 .37642 .2005 .37395 Metetra
.664 .741 .907 r
.2005 .37395 .20309 .37642 .20684 .37508 .20426 .37261 Metetra
.664 .741 .907 r
.20426 .37261 .20684 .37508 .2106 .37375 .20802 .37127 Metetra
.664 .741 .907 r
.20802 .37127 .2106 .37375 .21437 .37241 .21179 .36993 Metetra
.664 .741 .907 r
.21179 .36993 .21437 .37241 .21814 .37107 .21556 .36859 Metetra
.664 .741 .907 r
.21556 .36859 .21814 .37107 .22191 .36973 .21934 .36724 Metetra
.664 .741 .907 r
.21934 .36724 .22191 .36973 .22569 .36838 .22312 .36589 Metetra
.664 .741 .907 r
.22312 .36589 .22569 .36838 .22948 .36703 .22691 .36454 Metetra
.664 .741 .907 r
.22691 .36454 .22948 .36703 .23327 .36569 .23071 .36319 Metetra
.664 .741 .907 r
.23071 .36319 .23327 .36569 .23707 .36434 .23451 .36184 Metetra
.664 .741 .907 r
.23451 .36184 .23707 .36434 .24087 .36298 .23831 .36048 Metetra
.664 .741 .907 r
.23831 .36048 .24087 .36298 .24468 .36163 .24213 .35912 Metetra
.664 .741 .907 r
.24213 .35912 .24468 .36163 .2485 .36027 .24594 .35776 Metetra
.664 .741 .907 r
.24594 .35776 .2485 .36027 .25232 .35891 .24977 .3564 Metetra
.664 .741 .907 r
.24977 .3564 .25232 .35891 .25614 .35755 .2536 .35504 Metetra
.664 .741 .907 r
.2536 .35504 .25614 .35755 .25997 .35619 .25743 .35367 Metetra
.664 .741 .907 r
.25743 .35367 .25997 .35619 .26381 .35483 .26127 .3523 Metetra
.664 .741 .907 r
.26127 .3523 .26381 .35483 .26765 .35346 .26512 .35093 Metetra
.664 .741 .907 r
.26512 .35093 .26765 .35346 .2715 .35209 .26897 .34956 Metetra
.664 .741 .907 r
.26897 .34956 .2715 .35209 .27535 .35072 .27282 .34819 Metetra
.664 .741 .907 r
.27282 .34819 .27535 .35072 .27921 .34935 .27669 .34681 Metetra
.664 .741 .907 r
.27669 .34681 .27921 .34935 .28308 .34798 .28055 .34543 Metetra
.664 .741 .907 r
.28055 .34543 .28308 .34798 .28695 .3466 .28443 .34405 Metetra
.664 .741 .907 r
.28443 .34405 .28695 .3466 .29082 .34522 .28831 .34267 Metetra
.664 .741 .907 r
.28831 .34267 .29082 .34522 .29471 .34384 .29219 .34129 Metetra
.664 .741 .907 r
.29219 .34129 .29471 .34384 .29859 .34246 .29608 .3399 Metetra
.664 .741 .907 r
.29608 .3399 .29859 .34246 .30249 .34107 .29998 .33851 Metetra
.664 .741 .907 r
.29998 .33851 .30249 .34107 .30639 .33969 .30388 .33712 Metetra
.664 .741 .907 r
.30388 .33712 .30639 .33969 .31029 .3383 .30779 .33573 Metetra
.664 .741 .907 r
.30779 .33573 .31029 .3383 .3142 .33691 .31171 .33433 Metetra
.664 .741 .907 r
.31171 .33433 .3142 .33691 .31812 .33551 .31563 .33294 Metetra
.953 .682 .486 r
.31563 .33294 .31812 .33551 .32204 .33412 .30456 .56181 Metetra
.527 .297 .509 r
.30456 .56181 .32204 .33412 .31146 .56293 .30877 .56049 Metetra
.948 .709 .542 r
.30877 .56049 .31146 .56293 .31624 .55227 .31618 .50821 Metetra
.738 .499 .567 r
.31618 .50821 .31624 .55227 .32371 .49717 .32234 .4742 Metetra
.759 .531 .588 r
.32234 .4742 .32371 .49717 .32947 .46866 .32764 .45342 Metetra
.768 .554 .609 r
.32764 .45342 .32947 .46866 .33458 .45029 .33253 .43887 Metetra
.771 .573 .63 r
.33253 .43887 .33458 .45029 .33936 .43704 .33718 .42782 Metetra
.772 .589 .651 r
.33718 .42782 .33936 .43704 .34395 .42678 .3417 .41897 Metetra
.771 .603 .67 r
.3417 .41897 .34395 .42678 .34843 .41846 .34612 .41161 Metetra
.769 .616 .689 r
.34612 .41161 .34843 .41846 .35282 .41146 .35048 .4053 Metetra
.766 .627 .706 r
.35048 .4053 .35282 .41146 .35715 .40542 .35479 .39978 Metetra
.763 .636 .721 r
.35479 .39978 .35715 .40542 .36144 .40011 .35906 .39485 Metetra
.759 .645 .736 r
.35906 .39485 .36144 .40011 .3657 .39535 .36331 .3904 Metetra
.755 .653 .749 r
.36331 .3904 .3657 .39535 .36994 .39103 .36754 .38633 Metetra
.75 .659 .76 r
.36754 .38633 .36994 .39103 .37416 .38706 .37175 .38257 Metetra
.746 .665 .771 r
.37175 .38257 .37416 .38706 .37836 .38339 .37595 .37907 Metetra
.742 .67 .781 r
.37595 .37907 .37836 .38339 .38256 .37996 .38014 .37579 Metetra
.738 .675 .789 r
.38014 .37579 .38256 .37996 .38674 .37674 .38433 .37268 Metetra
.734 .679 .797 r
.38433 .37268 .38674 .37674 .39093 .3737 .38851 .36974 Metetra
.73 .683 .805 r
.38851 .36974 .39093 .3737 .3951 .37081 .39268 .36693 Metetra
.726 .686 .811 r
.39268 .36693 .3951 .37081 .39928 .36804 .39686 .36425 Metetra
.722 .689 .817 r
.39686 .36425 .39928 .36804 .40345 .3654 .40103 .36167 Metetra
.719 .691 .822 r
.40103 .36167 .40345 .3654 .40762 .36286 .4052 .35918 Metetra
.716 .693 .827 r
.4052 .35918 .40762 .36286 .41179 .36041 .40938 .35678 Metetra
.712 .695 .832 r
.40938 .35678 .41179 .36041 .41597 .35804 .41355 .35445 Metetra
.709 .697 .836 r
.41355 .35445 .41597 .35804 .42014 .35574 .41773 .3522 Metetra
.706 .698 .84 r
.41773 .3522 .42014 .35574 .42432 .35351 .42191 .35 Metetra
.703 .699 .843 r
.42191 .35 .42432 .35351 .4285 .35135 .42609 .34786 Metetra
.7 .7 .846 r
.42609 .34786 .4285 .35135 .43268 .34924 .43027 .34578 Metetra
.698 .701 .849 r
.43027 .34578 .43268 .34924 .43686 .34718 .43446 .34374 Metetra
.695 .702 .852 r
.43446 .34374 .43686 .34718 .44105 .34517 .43865 .34175 Metetra
.692 .702 .855 r
.43865 .34175 .44105 .34517 .44485 .35894 .44285 .3398 Metetra
.579 .402 .606 r
.44285 .3398 .44485 .35894 .44906 .35725 .44705 .3379 Metetra
.059 .026 .502 r
.44705 .3379 .44906 .35725 .45327 .35561 .45088 .35204 Metetra
.664 .685 .859 r
.45088 .35204 .45327 .35561 .4575 .35401 .4551 .35045 Metetra
.661 .684 .861 r
.4551 .35045 .4575 .35401 .46172 .35247 .45933 .3489 Metetra
.658 .683 .862 r
.45933 .3489 .46172 .35247 .46595 .35097 .46356 .3474 Metetra
.654 .682 .864 r
.46356 .3474 .46595 .35097 .47019 .34951 .4678 .34594 Metetra
.65 .68 .865 r
.4678 .34594 .47019 .34951 .47443 .3481 .47205 .34453 Metetra
.647 .679 .866 r
.47205 .34453 .47443 .3481 .47868 .34674 .4763 .34316 Metetra
.643 .677 .867 r
.4763 .34316 .47868 .34674 .48294 .34543 .48056 .34183 Metetra
.933 .73 .605 r
.48056 .34183 .48294 .34543 .4872 .34416 .48503 .32473 Metetra
.561 .388 .605 r
.48503 .32473 .4872 .34416 .49147 .34295 .48927 .32371 Metetra
.56 .389 .606 r
.48927 .32371 .49147 .34295 .49589 .32621 .49353 .32273 Metetra
.609 .67 .883 r
.49353 .32273 .49589 .32621 .50014 .3253 .49779 .3218 Metetra
.604 .666 .883 r
.49779 .3218 .50014 .3253 .50441 .32445 .50206 .32091 Metetra
.6 .662 .882 r
.50206 .32091 .50441 .32445 .50869 .32365 .50634 .32008 Metetra
.594 .658 .882 r
.50634 .32008 .50869 .32365 .51297 .3229 .51063 .3193 Metetra
.589 .653 .881 r
.51063 .3193 .51297 .3229 .51726 .32222 .51492 .31857 Metetra
.583 .648 .88 r
.51492 .31857 .51726 .32222 .52157 .32161 .51922 .31791 Metetra
.576 .642 .879 r
.51922 .31791 .52157 .32161 .52588 .32107 .52354 .31732 Metetra
.569 .635 .877 r
.52354 .31732 .52588 .32107 .5302 .32062 .52786 .31681 Metetra
.56 .628 .876 r
.52786 .31681 .5302 .32062 .53453 .32025 .53219 .31638 Metetra
.551 .62 .874 r
.53219 .31638 .53453 .32025 .53887 .32 .53653 .31605 Metetra
.541 .61 .871 r
.53653 .31605 .53887 .32 .54322 .31986 .54089 .31583 Metetra
.53 .6 .868 r
.54089 .31583 .54322 .31986 .54758 .31986 .54525 .31573 Metetra
.517 .587 .864 r
.54525 .31573 .54758 .31986 .55195 .32002 .54963 .31577 Metetra
.502 .573 .86 r
.54963 .31577 .55195 .32002 .55634 .32035 .55401 .31598 Metetra
.485 .557 .854 r
.55401 .31598 .55634 .32035 .56075 .3209 .55842 .31637 Metetra
.466 .538 .847 r
.55842 .31637 .56075 .3209 .56516 .32169 .56283 .31699 Metetra
.443 .516 .839 r
.56283 .31699 .56516 .32169 .5696 .32279 .56727 .31787 Metetra
.416 .49 .828 r
.56727 .31787 .5696 .32279 .57406 .32425 .57172 .31906 Metetra
.385 .459 .814 r
.57172 .31906 .57406 .32425 .57854 .32616 .57619 .32065 Metetra
.347 .423 .797 r
.57619 .32065 .57854 .32616 .58305 .32864 .58069 .32272 Metetra
.302 .378 .775 r
.58069 .32272 .58305 .32864 .58759 .33186 .58522 .32541 Metetra
.248 .325 .746 r
.58522 .32541 .58759 .33186 .59217 .33607 .58978 .3289 Metetra
.184 .261 .709 r
.58978 .3289 .59217 .33607 .5968 .34164 .59439 .33348 Metetra
.107 .184 .662 r
.59439 .33348 .5968 .34164 .60152 .3492 .59906 .33958 Metetra
.016 .094 .602 r
.59906 .33958 .60152 .3492 .60634 .35983 .60381 .34794 Metetra
0 0 .527 r
.60381 .34794 .60634 .35983 .61135 .37571 .6087 .3599 Metetra
0 0 .437 r
.6087 .3599 .61135 .37571 .61671 .40202 .61381 .37826 Metetra
0 0 .334 r
.61381 .37826 .61671 .40202 .62298 .45571 .61938 .41024 Metetra
0 0 .375 r
.61938 .41024 .62298 .45571 .62799 .46384 .62564 .46111 Metetra
.645 .763 .934 r
.62564 .46111 .62799 .46384 .62497 .2264 .63037 .45962 Metetra
0 0 .352 r
.63037 .45962 .62497 .2264 .62936 .22484 .62718 .22195 Metetra
.664 .741 .907 r
.62718 .22195 .62936 .22484 .63376 .22327 .63158 .22038 Metetra
.664 .741 .907 r
.63158 .22038 .63376 .22327 .63817 .22171 .63599 .21881 Metetra
.664 .741 .907 r
.63599 .21881 .63817 .22171 .64258 .22014 .6404 .21723 Metetra
.664 .741 .907 r
.6404 .21723 .64258 .22014 .647 .21857 .64483 .21566 Metetra
.664 .741 .907 r
.64483 .21566 .647 .21857 .65142 .21699 .64926 .21408 Metetra
.664 .741 .907 r
.64926 .21408 .65142 .21699 .65585 .21542 .65369 .2125 Metetra
.664 .741 .907 r
.65369 .2125 .65585 .21542 .66029 .21384 .65814 .21092 Metetra
.664 .741 .907 r
.65814 .21092 .66029 .21384 .66474 .21226 .66259 .20933 Metetra
.664 .741 .907 r
.66259 .20933 .66474 .21226 .66919 .21067 .66705 .20774 Metetra
.664 .741 .907 r
.66705 .20774 .66919 .21067 .67365 .20909 .67151 .20615 Metetra
.664 .741 .907 r
.67151 .20615 .67365 .20909 .67812 .2075 .67598 .20456 Metetra
.664 .741 .907 r
.67598 .20456 .67812 .2075 .68259 .20591 .68046 .20296 Metetra
.664 .741 .907 r
.68046 .20296 .68259 .20591 .68707 .20431 .68495 .20137 Metetra
.664 .741 .907 r
.68495 .20137 .68707 .20431 .69156 .20272 .68944 .19977 Metetra
.664 .741 .907 r
.68944 .19977 .69156 .20272 .69606 .20112 .69394 .19816 Metetra
.664 .741 .907 r
.69394 .19816 .69606 .20112 .70056 .19952 .69845 .19656 Metetra
.664 .741 .907 r
.69845 .19656 .70056 .19952 .70507 .19791 .70296 .19495 Metetra
.664 .741 .907 r
.70296 .19495 .70507 .19791 .70959 .19631 .70749 .19334 Metetra
.664 .741 .907 r
.70749 .19334 .70959 .19631 .71411 .1947 .71202 .19172 Metetra
.664 .741 .907 r
.71202 .19172 .71411 .1947 .71864 .19309 .71655 .19011 Metetra
.664 .741 .907 r
.71655 .19011 .71864 .19309 .72318 .19147 .7211 .18849 Metetra
.664 .741 .907 r
.7211 .18849 .72318 .19147 .72773 .18986 .72565 .18687 Metetra
.664 .741 .907 r
.72565 .18687 .72773 .18986 .73228 .18824 .73021 .18524 Metetra
.664 .741 .907 r
.73021 .18524 .73228 .18824 .73684 .18662 .73477 .18362 Metetra
.664 .741 .907 r
.73477 .18362 .73684 .18662 .74141 .18499 .73934 .18199 Metetra
.664 .741 .907 r
.73934 .18199 .74141 .18499 .74598 .18337 .74392 .18036 Metetra
.664 .741 .907 r
.74392 .18036 .74598 .18337 .75057 .18174 .74851 .17872 Metetra
.664 .741 .907 r
.74851 .17872 .75057 .18174 .75516 .1801 .75311 .17708 Metetra
.664 .741 .907 r
.75311 .17708 .75516 .1801 .75975 .17847 .75771 .17544 Metetra
.664 .741 .907 r
.75771 .17544 .75975 .17847 .76436 .17683 .76232 .1738 Metetra
.664 .741 .907 r
.76232 .1738 .76436 .17683 .76897 .17519 .76694 .17216 Metetra
.664 .741 .907 r
.76694 .17216 .76897 .17519 .77359 .17355 .77156 .17051 Metetra
.664 .741 .907 r
.77156 .17051 .77359 .17355 .77822 .1719 .77619 .16886 Metetra
.664 .741 .907 r
.77619 .16886 .77822 .1719 .78285 .17026 .78083 .16721 Metetra
.664 .741 .907 r
.78083 .16721 .78285 .17026 .78749 .16861 .78548 .16555 Metetra
.664 .741 .907 r
.78548 .16555 .78749 .16861 .79214 .16695 .79013 .16389 Metetra
.664 .741 .907 r
.79013 .16389 .79214 .16695 .7968 .1653 .79479 .16223 Metetra
.664 .741 .907 r
.17173 .38082 .17435 .38327 .17807 .38194 .17545 .37949 Metetra
.664 .741 .907 r
.17545 .37949 .17807 .38194 .1818 .38062 .17918 .37816 Metetra
.664 .741 .907 r
.17918 .37816 .1818 .38062 .18553 .37929 .18291 .37683 Metetra
.664 .741 .907 r
.18291 .37683 .18553 .37929 .18926 .37796 .18665 .37549 Metetra
.664 .741 .907 r
.18665 .37549 .18926 .37796 .193 .37662 .1904 .37416 Metetra
.664 .741 .907 r
.1904 .37416 .193 .37662 .19675 .37529 .19415 .37282 Metetra
.664 .741 .907 r
.19415 .37282 .19675 .37529 .2005 .37395 .1979 .37148 Metetra
.664 .741 .907 r
.1979 .37148 .2005 .37395 .20426 .37261 .20166 .37014 Metetra
.664 .741 .907 r
.20166 .37014 .20426 .37261 .20802 .37127 .20543 .36879 Metetra
.664 .741 .907 r
.20543 .36879 .20802 .37127 .21179 .36993 .2092 .36745 Metetra
.664 .741 .907 r
.2092 .36745 .21179 .36993 .21556 .36859 .21297 .3661 Metetra
.664 .741 .907 r
.21297 .3661 .21556 .36859 .21934 .36724 .21675 .36475 Metetra
.664 .741 .907 r
.21675 .36475 .21934 .36724 .22312 .36589 .22054 .3634 Metetra
.664 .741 .907 r
.22054 .3634 .22312 .36589 .22691 .36454 .22433 .36205 Metetra
.664 .741 .907 r
.22433 .36205 .22691 .36454 .23071 .36319 .22813 .36069 Metetra
.664 .741 .907 r
.22813 .36069 .23071 .36319 .23451 .36184 .23194 .35933 Metetra
.664 .741 .907 r
.23194 .35933 .23451 .36184 .23831 .36048 .23575 .35797 Metetra
.664 .741 .907 r
.23575 .35797 .23831 .36048 .24213 .35912 .23956 .35661 Metetra
.664 .741 .907 r
.23956 .35661 .24213 .35912 .24594 .35776 .24338 .35525 Metetra
.664 .741 .907 r
.24338 .35525 .24594 .35776 .24977 .3564 .24721 .35388 Metetra
.664 .741 .907 r
.24721 .35388 .24977 .3564 .2536 .35504 .25104 .35251 Metetra
.664 .741 .907 r
.25104 .35251 .2536 .35504 .25743 .35367 .25488 .35114 Metetra
.664 .741 .907 r
.25488 .35114 .25743 .35367 .26127 .3523 .25872 .34977 Metetra
.664 .741 .907 r
.25872 .34977 .26127 .3523 .26512 .35093 .26257 .3484 Metetra
.664 .741 .907 r
.26257 .3484 .26512 .35093 .26897 .34956 .26643 .34702 Metetra
.664 .741 .907 r
.26643 .34702 .26897 .34956 .27282 .34819 .27029 .34564 Metetra
.664 .741 .907 r
.27029 .34564 .27282 .34819 .27669 .34681 .27415 .34426 Metetra
.664 .741 .907 r
.27415 .34426 .27669 .34681 .28055 .34543 .27802 .34288 Metetra
.664 .741 .907 r
.27802 .34288 .28055 .34543 .28443 .34405 .2819 .3415 Metetra
.664 .741 .907 r
.2819 .3415 .28443 .34405 .28831 .34267 .28578 .34011 Metetra
.664 .741 .907 r
.28578 .34011 .28831 .34267 .29219 .34129 .28967 .33873 Metetra
.664 .741 .907 r
.28967 .33873 .29219 .34129 .29608 .3399 .29357 .33734 Metetra
.664 .741 .907 r
.29357 .33734 .29608 .3399 .29998 .33851 .29747 .33594 Metetra
.664 .741 .907 r
.29747 .33594 .29998 .33851 .30388 .33712 .30137 .33455 Metetra
.664 .741 .907 r
.30137 .33455 .30388 .33712 .30779 .33573 .30529 .33315 Metetra
.664 .741 .907 r
.30529 .33315 .30779 .33573 .31171 .33433 .3092 .33175 Metetra
.664 .741 .907 r
.3092 .33175 .31171 .33433 .31563 .33294 .31313 .33035 Metetra
.953 .682 .486 r
.31313 .33035 .31563 .33294 .30456 .56181 .30186 .55938 Metetra
.945 .716 .561 r
.30186 .55938 .30456 .56181 .30877 .56049 .30838 .52241 Metetra
.779 .535 .567 r
.30838 .52241 .30877 .56049 .31618 .50821 .31511 .48085 Metetra
.753 .522 .581 r
.31511 .48085 .31618 .50821 .32234 .4742 .32064 .45707 Metetra
.765 .547 .602 r
.32064 .45707 .32234 .4742 .32764 .45342 .32565 .44099 Metetra
.77 .567 .623 r
.32565 .44099 .32764 .45342 .33253 .43887 .33038 .42904 Metetra
.772 .583 .644 r
.33038 .42904 .33253 .43887 .33718 .42782 .33495 .4196 Metetra
.771 .598 .664 r
.33495 .4196 .33718 .42782 .3417 .41897 .33941 .41183 Metetra
.77 .611 .683 r
.33941 .41183 .3417 .41897 .34612 .41161 .34379 .40523 Metetra
.767 .623 .7 r
.34379 .40523 .34612 .41161 .35048 .4053 .34812 .39949 Metetra
.763 .633 .717 r
.34812 .39949 .35048 .4053 .35479 .39978 .35241 .3944 Metetra
.76 .642 .731 r
.35241 .3944 .35479 .39978 .35906 .39485 .35667 .38981 Metetra
.756 .65 .745 r
.35667 .38981 .35906 .39485 .36331 .3904 .3609 .38563 Metetra
.752 .657 .757 r
.3609 .38563 .36331 .3904 .36754 .38633 .36512 .38178 Metetra
.747 .663 .768 r
.36512 .38178 .36754 .38633 .37175 .38257 .36933 .3782 Metetra
.743 .669 .778 r
.36933 .3782 .37175 .38257 .37595 .37907 .37353 .37484 Metetra
.739 .674 .787 r
.37353 .37484 .37595 .37907 .38014 .37579 .37772 .37168 Metetra
.735 .678 .795 r
.37772 .37168 .38014 .37579 .38433 .37268 .3819 .36869 Metetra
.731 .682 .802 r
.3819 .36869 .38433 .37268 .38851 .36974 .38608 .36584 Metetra
.727 .685 .809 r
.38608 .36584 .38851 .36974 .39268 .36693 .39026 .36311 Metetra
.724 .688 .815 r
.39026 .36311 .39268 .36693 .39686 .36425 .39443 .36049 Metetra
.72 .69 .821 r
.39443 .36049 .39686 .36425 .40103 .36167 .3986 .35797 Metetra
.717 .693 .826 r
.3986 .35797 .40103 .36167 .4052 .35918 .40278 .35554 Metetra
.714 .695 .83 r
.40278 .35554 .4052 .35918 .40938 .35678 .40695 .35318 Metetra
.711 .696 .835 r
.40695 .35318 .40938 .35678 .41355 .35445 .41113 .35089 Metetra
.708 .698 .839 r
.41113 .35089 .41355 .35445 .41773 .3522 .41531 .34867 Metetra
.705 .699 .842 r
.41531 .34867 .41773 .3522 .42191 .35 .41949 .34651 Metetra
.702 .7 .845 r
.41949 .34651 .42191 .35 .42609 .34786 .42367 .3444 Metetra
.699 .701 .849 r
.42367 .3444 .42609 .34786 .43027 .34578 .42786 .34233 Metetra
.696 .702 .851 r
.42786 .34233 .43027 .34578 .43446 .34374 .43205 .34032 Metetra
.694 .703 .854 r
.43205 .34032 .43446 .34374 .43865 .34175 .43625 .33835 Metetra
.691 .703 .856 r
.43625 .33835 .43865 .34175 .44285 .3398 .44044 .33641 Metetra
.689 .704 .859 r
.44044 .33641 .44285 .3398 .44705 .3379 .44465 .33452 Metetra
.687 .704 .861 r
.44465 .33452 .44705 .3379 .45088 .35204 .44885 .33266 Metetra
.055 .023 .5 r
.44885 .33266 .45088 .35204 .4551 .35045 .4527 .3469 Metetra
.661 .685 .862 r
.4527 .3469 .4551 .35045 .45933 .3489 .45693 .34536 Metetra
.658 .684 .864 r
.45693 .34536 .45933 .3489 .46356 .3474 .46117 .34385 Metetra
.654 .683 .865 r
.46117 .34385 .46356 .3474 .4678 .34594 .46541 .34239 Metetra
.651 .682 .866 r
.46541 .34239 .4678 .34594 .47205 .34453 .46966 .34097 Metetra
.647 .68 .867 r
.46966 .34097 .47205 .34453 .4763 .34316 .47392 .33959 Metetra
.933 .73 .605 r
.47392 .33959 .4763 .34316 .48056 .34183 .47841 .32238 Metetra
.561 .389 .605 r
.47841 .32238 .48056 .34183 .48503 .32473 .48266 .32131 Metetra
.619 .678 .884 r
.48266 .32131 .48503 .32473 .48927 .32371 .48691 .32027 Metetra
.615 .675 .884 r
.48691 .32027 .48927 .32371 .49353 .32273 .49116 .31927 Metetra
.611 .672 .884 r
.49116 .31927 .49353 .32273 .49779 .3218 .49543 .31831 Metetra
.607 .669 .884 r
.49543 .31831 .49779 .3218 .50206 .32091 .4997 .3174 Metetra
.602 .665 .883 r
.4997 .3174 .50206 .32091 .50634 .32008 .50398 .31653 Metetra
.597 .661 .883 r
.50398 .31653 .50634 .32008 .51063 .3193 .50827 .31571 Metetra
.592 .656 .882 r
.50827 .31571 .51063 .3193 .51492 .31857 .51257 .31494 Metetra
.586 .651 .881 r
.51257 .31494 .51492 .31857 .51922 .31791 .51688 .31424 Metetra
.58 .646 .88 r
.51688 .31424 .51922 .31791 .52354 .31732 .52119 .3136 Metetra
.573 .64 .879 r
.52119 .3136 .52354 .31732 .52786 .31681 .52552 .31303 Metetra
.566 .633 .877 r
.52552 .31303 .52786 .31681 .53219 .31638 .52985 .31254 Metetra
.557 .625 .875 r
.52985 .31254 .53219 .31638 .53653 .31605 .5342 .31214 Metetra
.548 .617 .873 r
.5342 .31214 .53653 .31605 .54089 .31583 .53855 .31184 Metetra
.538 .607 .87 r
.53855 .31184 .54089 .31583 .54525 .31573 .54292 .31166 Metetra
.526 .596 .867 r
.54292 .31166 .54525 .31573 .54963 .31577 .54729 .3116 Metetra
.512 .583 .863 r
.54729 .3116 .54963 .31577 .55401 .31598 .55168 .31168 Metetra
.497 .569 .858 r
.55168 .31168 .55401 .31598 .55842 .31637 .55608 .31194 Metetra
.48 .552 .852 r
.55608 .31194 .55842 .31637 .56283 .31699 .5605 .31239 Metetra
.459 .532 .845 r
.5605 .31239 .56283 .31699 .56727 .31787 .56493 .31308 Metetra
.435 .509 .835 r
.56493 .31308 .56727 .31787 .57172 .31906 .56938 .31405 Metetra
.407 .481 .824 r
.56938 .31405 .57172 .31906 .57619 .32065 .57385 .31535 Metetra
.374 .449 .809 r
.57385 .31535 .57619 .32065 .58069 .32272 .57834 .31707 Metetra
.335 .41 .791 r
.57834 .31707 .58069 .32272 .58522 .32541 .58286 .31931 Metetra
.287 .363 .767 r
.58286 .31931 .58522 .32541 .58978 .3289 .5874 .32222 Metetra
.231 .307 .736 r
.5874 .32222 .58978 .3289 .59439 .33348 .59199 .326 Metetra
.163 .239 .696 r
.59199 .326 .59439 .33348 .59906 .33958 .59663 .33099 Metetra
.082 .158 .645 r
.59663 .33099 .59906 .33958 .60381 .34794 .60133 .33768 Metetra
0 .064 .581 r
.60133 .33768 .60381 .34794 .6087 .3599 .60613 .34697 Metetra
0 0 .502 r
.60613 .34697 .6087 .3599 .61381 .37826 .61109 .3605 Metetra
0 0 .409 r
.61109 .3605 .61381 .37826 .61938 .41024 .61632 .38195 Metetra
0 0 .3 r
.61632 .38195 .61938 .41024 .62564 .46111 .62217 .42171 Metetra
.007 0 .449 r
.62217 .42171 .62564 .46111 .63037 .45962 .62801 .45688 Metetra
.977 .689 .406 r
.62801 .45688 .63037 .45962 .62718 .22195 .62498 .21905 Metetra
.664 .741 .907 r
.62498 .21905 .62718 .22195 .63158 .22038 .62939 .21748 Metetra
.664 .741 .907 r
.62939 .21748 .63158 .22038 .63599 .21881 .6338 .2159 Metetra
.664 .741 .907 r
.6338 .2159 .63599 .21881 .6404 .21723 .63822 .21432 Metetra
.664 .741 .907 r
.63822 .21432 .6404 .21723 .64483 .21566 .64265 .21274 Metetra
.664 .741 .907 r
.64265 .21274 .64483 .21566 .64926 .21408 .64709 .21116 Metetra
.664 .741 .907 r
.64709 .21116 .64926 .21408 .65369 .2125 .65153 .20958 Metetra
.664 .741 .907 r
.65153 .20958 .65369 .2125 .65814 .21092 .65598 .20799 Metetra
.664 .741 .907 r
.65598 .20799 .65814 .21092 .66259 .20933 .66043 .2064 Metetra
.664 .741 .907 r
.66043 .2064 .66259 .20933 .66705 .20774 .66489 .20481 Metetra
.664 .741 .907 r
.66489 .20481 .66705 .20774 .67151 .20615 .66936 .20321 Metetra
.664 .741 .907 r
.66936 .20321 .67151 .20615 .67598 .20456 .67384 .20161 Metetra
.664 .741 .907 r
.67384 .20161 .67598 .20456 .68046 .20296 .67833 .20001 Metetra
.664 .741 .907 r
.67833 .20001 .68046 .20296 .68495 .20137 .68282 .19841 Metetra
.664 .741 .907 r
.68282 .19841 .68495 .20137 .68944 .19977 .68731 .1968 Metetra
.664 .741 .907 r
.68731 .1968 .68944 .19977 .69394 .19816 .69182 .1952 Metetra
.664 .741 .907 r
.69182 .1952 .69394 .19816 .69845 .19656 .69633 .19358 Metetra
.664 .741 .907 r
.69633 .19358 .69845 .19656 .70296 .19495 .70085 .19197 Metetra
.664 .741 .907 r
.70085 .19197 .70296 .19495 .70749 .19334 .70538 .19036 Metetra
.664 .741 .907 r
.70538 .19036 .70749 .19334 .71202 .19172 .70991 .18874 Metetra
.664 .741 .907 r
.70991 .18874 .71202 .19172 .71655 .19011 .71446 .18712 Metetra
.664 .741 .907 r
.71446 .18712 .71655 .19011 .7211 .18849 .719 .18549 Metetra
.664 .741 .907 r
.719 .18549 .7211 .18849 .72565 .18687 .72356 .18387 Metetra
.664 .741 .907 r
.72356 .18387 .72565 .18687 .73021 .18524 .72812 .18224 Metetra
.664 .741 .907 r
.72812 .18224 .73021 .18524 .73477 .18362 .73269 .18061 Metetra
.664 .741 .907 r
.73269 .18061 .73477 .18362 .73934 .18199 .73727 .17897 Metetra
.664 .741 .907 r
.73727 .17897 .73934 .18199 .74392 .18036 .74186 .17734 Metetra
.664 .741 .907 r
.74186 .17734 .74392 .18036 .74851 .17872 .74645 .1757 Metetra
.664 .741 .907 r
.74645 .1757 .74851 .17872 .75311 .17708 .75105 .17406 Metetra
.664 .741 .907 r
.75105 .17406 .75311 .17708 .75771 .17544 .75566 .17241 Metetra
.664 .741 .907 r
.75566 .17241 .75771 .17544 .76232 .1738 .76027 .17076 Metetra
.664 .741 .907 r
.76027 .17076 .76232 .1738 .76694 .17216 .76489 .16911 Metetra
.664 .741 .907 r
.76489 .16911 .76694 .17216 .77156 .17051 .76952 .16746 Metetra
.664 .741 .907 r
.76952 .16746 .77156 .17051 .77619 .16886 .77416 .16581 Metetra
.664 .741 .907 r
.77416 .16581 .77619 .16886 .78083 .16721 .77881 .16415 Metetra
.664 .741 .907 r
.77881 .16415 .78083 .16721 .78548 .16555 .78346 .16249 Metetra
.664 .741 .907 r
.78346 .16249 .78548 .16555 .79013 .16389 .78812 .16083 Metetra
.664 .741 .907 r
.78812 .16083 .79013 .16389 .79479 .16223 .79279 .15916 Metetra
.664 .741 .907 r
.1691 .37837 .17173 .38082 .17545 .37949 .17283 .37703 Metetra
.664 .741 .907 r
.17283 .37703 .17545 .37949 .17918 .37816 .17656 .3757 Metetra
.664 .741 .907 r
.17656 .3757 .17918 .37816 .18291 .37683 .1803 .37436 Metetra
.664 .741 .907 r
.1803 .37436 .18291 .37683 .18665 .37549 .18404 .37303 Metetra
.664 .741 .907 r
.18404 .37303 .18665 .37549 .1904 .37416 .18778 .37169 Metetra
.664 .741 .907 r
.18778 .37169 .1904 .37416 .19415 .37282 .19154 .37034 Metetra
.664 .741 .907 r
.19154 .37034 .19415 .37282 .1979 .37148 .19529 .369 Metetra
.664 .741 .907 r
.19529 .369 .1979 .37148 .20166 .37014 .19906 .36766 Metetra
.664 .741 .907 r
.19906 .36766 .20166 .37014 .20543 .36879 .20283 .36631 Metetra
.664 .741 .907 r
.20283 .36631 .20543 .36879 .2092 .36745 .2066 .36496 Metetra
.664 .741 .907 r
.2066 .36496 .2092 .36745 .21297 .3661 .21038 .36361 Metetra
.664 .741 .907 r
.21038 .36361 .21297 .3661 .21675 .36475 .21416 .36225 Metetra
.664 .741 .907 r
.21416 .36225 .21675 .36475 .22054 .3634 .21796 .3609 Metetra
.664 .741 .907 r
.21796 .3609 .22054 .3634 .22433 .36205 .22175 .35954 Metetra
.664 .741 .907 r
.22175 .35954 .22433 .36205 .22813 .36069 .22555 .35818 Metetra
.664 .741 .907 r
.22555 .35818 .22813 .36069 .23194 .35933 .22936 .35682 Metetra
.664 .741 .907 r
.22936 .35682 .23194 .35933 .23575 .35797 .23317 .35546 Metetra
.664 .741 .907 r
.23317 .35546 .23575 .35797 .23956 .35661 .23699 .35409 Metetra
.664 .741 .907 r
.23699 .35409 .23956 .35661 .24338 .35525 .24082 .35272 Metetra
.664 .741 .907 r
.24082 .35272 .24338 .35525 .24721 .35388 .24465 .35135 Metetra
.664 .741 .907 r
.24465 .35135 .24721 .35388 .25104 .35251 .24848 .34998 Metetra
.664 .741 .907 r
.24848 .34998 .25104 .35251 .25488 .35114 .25232 .34861 Metetra
.664 .741 .907 r
.25232 .34861 .25488 .35114 .25872 .34977 .25617 .34723 Metetra
.664 .741 .907 r
.25617 .34723 .25872 .34977 .26257 .3484 .26002 .34586 Metetra
.664 .741 .907 r
.26002 .34586 .26257 .3484 .26643 .34702 .26388 .34448 Metetra
.664 .741 .907 r
.26388 .34448 .26643 .34702 .27029 .34564 .26774 .3431 Metetra
.664 .741 .907 r
.26774 .3431 .27029 .34564 .27415 .34426 .27161 .34171 Metetra
.664 .741 .907 r
.27161 .34171 .27415 .34426 .27802 .34288 .27549 .34033 Metetra
.664 .741 .907 r
.27549 .34033 .27802 .34288 .2819 .3415 .27937 .33894 Metetra
.664 .741 .907 r
.27937 .33894 .2819 .3415 .28578 .34011 .28325 .33755 Metetra
.664 .741 .907 r
.28325 .33755 .28578 .34011 .28967 .33873 .28715 .33616 Metetra
.664 .741 .907 r
.28715 .33616 .28967 .33873 .29357 .33734 .29104 .33476 Metetra
.664 .741 .907 r
.29104 .33476 .29357 .33734 .29747 .33594 .29495 .33337 Metetra
.664 .741 .907 r
.29495 .33337 .29747 .33594 .30137 .33455 .29886 .33197 Metetra
.664 .741 .907 r
.29886 .33197 .30137 .33455 .30529 .33315 .30277 .33057 Metetra
.664 .741 .907 r
.30277 .33057 .30529 .33315 .3092 .33175 .3067 .32917 Metetra
.953 .682 .487 r
.3067 .32917 .3092 .33175 .31313 .33035 .29495 .55826 Metetra
.497 .271 .502 r
.29495 .55826 .31313 .33035 .30186 .55938 .30019 .54138 Metetra
.876 .629 .561 r
.30019 .54138 .30186 .55938 .30838 .52241 .30774 .48893 Metetra
.746 .511 .574 r
.30774 .48893 .30838 .52241 .31511 .48085 .31357 .46135 Metetra
.762 .539 .595 r
.31357 .46135 .31511 .48085 .32064 .45707 .31873 .44344 Metetra
.768 .56 .616 r
.31873 .44344 .32064 .45707 .32565 .44099 .32355 .43045 Metetra
.771 .578 .638 r
.32355 .43045 .32565 .44099 .33038 .42904 .32818 .42036 Metetra
.771 .593 .658 r
.32818 .42036 .33038 .42904 .33495 .4196 .33267 .41215 Metetra
.77 .607 .677 r
.33267 .41215 .33495 .4196 .33941 .41183 .33709 .40523 Metetra
.767 .619 .695 r
.33709 .40523 .33941 .41183 .34379 .40523 .34144 .39926 Metetra
.764 .63 .712 r
.34144 .39926 .34379 .40523 .34812 .39949 .34574 .39398 Metetra
.761 .639 .727 r
.34574 .39398 .34812 .39949 .35241 .3944 .35001 .38925 Metetra
.757 .648 .741 r
.35001 .38925 .35241 .3944 .35667 .38981 .35426 .38495 Metetra
.753 .655 .753 r
.35426 .38495 .35667 .38981 .3609 .38563 .35849 .381 Metetra
.749 .661 .764 r
.35849 .381 .3609 .38563 .36512 .38178 .3627 .37734 Metetra
.744 .667 .775 r
.3627 .37734 .36512 .38178 .36933 .3782 .3669 .37392 Metetra
.74 .672 .784 r
.3669 .37392 .36933 .3782 .37353 .37484 .3711 .3707 Metetra
.736 .677 .792 r
.3711 .3707 .37353 .37484 .37772 .37168 .37528 .36765 Metetra
.732 .681 .8 r
.37528 .36765 .37772 .37168 .3819 .36869 .37947 .36475 Metetra
.729 .684 .807 r
.37947 .36475 .3819 .36869 .38608 .36584 .38364 .36198 Metetra
.725 .687 .813 r
.38364 .36198 .38608 .36584 .39026 .36311 .38782 .35933 Metetra
.722 .69 .819 r
.38782 .35933 .39026 .36311 .39443 .36049 .392 .35677 Metetra
.718 .692 .824 r
.392 .35677 .39443 .36049 .3986 .35797 .39617 .35431 Metetra
.715 .694 .829 r
.39617 .35431 .3986 .35797 .40278 .35554 .40035 .35192 Metetra
.712 .696 .833 r
.40035 .35192 .40278 .35554 .40695 .35318 .40453 .34961 Metetra
.709 .698 .837 r
.40453 .34961 .40695 .35318 .41113 .35089 .4087 .34736 Metetra
.706 .699 .841 r
.4087 .34736 .41113 .35089 .41531 .34867 .41288 .34517 Metetra
.703 .7 .845 r
.41288 .34517 .41531 .34867 .41949 .34651 .41707 .34303 Metetra
.7 .701 .848 r
.41707 .34303 .41949 .34651 .42367 .3444 .42125 .34094 Metetra
.698 .702 .851 r
.42125 .34094 .42367 .3444 .42786 .34233 .42544 .33891 Metetra
.695 .703 .853 r
.42544 .33891 .42786 .34233 .43205 .34032 .42964 .33691 Metetra
.693 .704 .856 r
.42964 .33691 .43205 .34032 .43625 .33835 .43383 .33495 Metetra
.69 .704 .858 r
.43383 .33495 .43625 .33835 .44044 .33641 .43804 .33303 Metetra
.688 .705 .86 r
.43804 .33303 .44044 .33641 .44465 .33452 .44224 .33115 Metetra
.686 .705 .862 r
.44224 .33115 .44465 .33452 .44885 .33266 .44645 .3293 Metetra
.684 .705 .864 r
.44645 .3293 .44885 .33266 .4527 .3469 .45067 .32749 Metetra
.051 .021 .499 r
.45067 .32749 .4527 .3469 .45693 .34536 .45453 .34182 Metetra
.658 .686 .865 r
.45453 .34182 .45693 .34536 .46117 .34385 .45877 .34031 Metetra
.654 .684 .866 r
.45877 .34031 .46117 .34385 .46541 .34239 .46301 .33885 Metetra
.651 .683 .867 r
.46301 .33885 .46541 .34239 .46966 .34097 .46727 .33742 Metetra
.933 .73 .605 r
.46727 .33742 .46966 .34097 .47392 .33959 .47179 .32012 Metetra
.562 .389 .604 r
.47179 .32012 .47392 .33959 .47841 .32238 .47603 .319 Metetra
.623 .682 .885 r
.47603 .319 .47841 .32238 .48266 .32131 .48028 .3179 Metetra
.62 .68 .885 r
.48028 .3179 .48266 .32131 .48691 .32027 .48453 .31684 Metetra
.617 .677 .885 r
.48453 .31684 .48691 .32027 .49116 .31927 .48879 .31582 Metetra
.613 .674 .885 r
.48879 .31582 .49116 .31927 .49543 .31831 .49306 .31483 Metetra
.609 .671 .884 r
.49306 .31483 .49543 .31831 .4997 .3174 .49734 .31389 Metetra
.605 .667 .884 r
.49734 .31389 .4997 .3174 .50398 .31653 .50162 .31299 Metetra
.6 .664 .883 r
.50162 .31299 .50398 .31653 .50827 .31571 .50592 .31214 Metetra
.595 .659 .883 r
.50592 .31214 .50827 .31571 .51257 .31494 .51022 .31134 Metetra
.59 .655 .882 r
.51022 .31134 .51257 .31494 .51688 .31424 .51453 .31059 Metetra
.584 .65 .881 r
.51453 .31059 .51688 .31424 .52119 .3136 .51884 .3099 Metetra
.578 .644 .88 r
.51884 .3099 .52119 .3136 .52552 .31303 .52317 .30928 Metetra
.571 .638 .879 r
.52317 .30928 .52552 .31303 .52985 .31254 .52751 .30874 Metetra
.563 .631 .877 r
.52751 .30874 .52985 .31254 .5342 .31214 .53185 .30828 Metetra
.554 .623 .875 r
.53185 .30828 .5342 .31214 .53855 .31184 .53621 .3079 Metetra
.545 .614 .872 r
.53621 .3079 .53855 .31184 .54292 .31166 .54058 .30763 Metetra
.534 .604 .869 r
.54058 .30763 .54292 .31166 .54729 .3116 .54495 .30748 Metetra
.522 .592 .866 r
.54495 .30748 .54729 .3116 .55168 .31168 .54934 .30746 Metetra
.508 .579 .862 r
.54934 .30746 .55168 .31168 .55608 .31194 .55375 .30759 Metetra
.492 .563 .856 r
.55375 .30759 .55608 .31194 .5605 .31239 .55816 .3079 Metetra
.474 .546 .85 r
.55816 .3079 .5605 .31239 .56493 .31308 .56259 .30842 Metetra
.452 .525 .842 r
.56259 .30842 .56493 .31308 .56938 .31405 .56704 .30918 Metetra
.427 .501 .832 r
.56704 .30918 .56938 .31405 .57385 .31535 .5715 .31024 Metetra
.398 .472 .82 r
.5715 .31024 .57385 .31535 .57834 .31707 .57599 .31165 Metetra
.363 .438 .804 r
.57599 .31165 .57834 .31707 .58286 .31931 .5805 .31351 Metetra
.322 .396 .784 r
.5805 .31351 .58286 .31931 .5874 .32222 .58503 .31593 Metetra
.272 .347 .758 r
.58503 .31593 .5874 .32222 .59199 .326 .5896 .31907 Metetra
.213 .288 .724 r
.5896 .31907 .59199 .326 .59663 .33099 .59421 .32318 Metetra
.142 .217 .682 r
.59421 .32318 .59663 .33099 .60133 .33768 .59888 .32861 Metetra
.058 .132 .627 r
.59888 .32861 .60133 .33768 .60613 .34697 .60362 .33597 Metetra
0 .035 .559 r
.60362 .33597 .60613 .34697 .61109 .3605 .60847 .34632 Metetra
0 0 .476 r
.60847 .34632 .61109 .3605 .61632 .38195 .61351 .36173 Metetra
0 0 .379 r
.61351 .36173 .61632 .38195 .62217 .42171 .6189 .3871 Metetra
0 0 .266 r
.6189 .3871 .62217 .42171 .62801 .45688 .62515 .43811 Metetra
.096 .072 .538 r
.62515 .43811 .62801 .45688 .62498 .21905 .6304 .45262 Metetra
0 0 .35 r
.6304 .45262 .62498 .21905 .62939 .21748 .62719 .21457 Metetra
.664 .741 .907 r
.62719 .21457 .62939 .21748 .6338 .2159 .63161 .21299 Metetra
.664 .741 .907 r
.63161 .21299 .6338 .2159 .63822 .21432 .63604 .2114 Metetra
.664 .741 .907 r
.63604 .2114 .63822 .21432 .64265 .21274 .64047 .20982 Metetra
.664 .741 .907 r
.64047 .20982 .64265 .21274 .64709 .21116 .64491 .20823 Metetra
.664 .741 .907 r
.64491 .20823 .64709 .21116 .65153 .20958 .64936 .20664 Metetra
.664 .741 .907 r
.64936 .20664 .65153 .20958 .65598 .20799 .65381 .20505 Metetra
.664 .741 .907 r
.65381 .20505 .65598 .20799 .66043 .2064 .65827 .20346 Metetra
.664 .741 .907 r
.65827 .20346 .66043 .2064 .66489 .20481 .66274 .20186 Metetra
.664 .741 .907 r
.66274 .20186 .66489 .20481 .66936 .20321 .66721 .20026 Metetra
.664 .741 .907 r
.66721 .20026 .66936 .20321 .67384 .20161 .67169 .19866 Metetra
.664 .741 .907 r
.67169 .19866 .67384 .20161 .67833 .20001 .67618 .19705 Metetra
.664 .741 .907 r
.67618 .19705 .67833 .20001 .68282 .19841 .68068 .19544 Metetra
.664 .741 .907 r
.68068 .19544 .68282 .19841 .68731 .1968 .68518 .19383 Metetra
.664 .741 .907 r
.68518 .19383 .68731 .1968 .69182 .1952 .68969 .19222 Metetra
.664 .741 .907 r
.68969 .19222 .69182 .1952 .69633 .19358 .69421 .1906 Metetra
.664 .741 .907 r
.69421 .1906 .69633 .19358 .70085 .19197 .69873 .18899 Metetra
.664 .741 .907 r
.69873 .18899 .70085 .19197 .70538 .19036 .70327 .18737 Metetra
.664 .741 .907 r
.70327 .18737 .70538 .19036 .70991 .18874 .70781 .18574 Metetra
.664 .741 .907 r
.70781 .18574 .70991 .18874 .71446 .18712 .71235 .18412 Metetra
.664 .741 .907 r
.71235 .18412 .71446 .18712 .719 .18549 .71691 .18249 Metetra
.664 .741 .907 r
.71691 .18249 .719 .18549 .72356 .18387 .72147 .18086 Metetra
.664 .741 .907 r
.72147 .18086 .72356 .18387 .72812 .18224 .72604 .17922 Metetra
.664 .741 .907 r
.72604 .17922 .72812 .18224 .73269 .18061 .73061 .17759 Metetra
.664 .741 .907 r
.73061 .17759 .73269 .18061 .73727 .17897 .73519 .17595 Metetra
.664 .741 .907 r
.73519 .17595 .73727 .17897 .74186 .17734 .73978 .17431 Metetra
.664 .741 .907 r
.73978 .17431 .74186 .17734 .74645 .1757 .74438 .17266 Metetra
.664 .741 .907 r
.74438 .17266 .74645 .1757 .75105 .17406 .74899 .17102 Metetra
.664 .741 .907 r
.74899 .17102 .75105 .17406 .75566 .17241 .7536 .16937 Metetra
.664 .741 .907 r
.7536 .16937 .75566 .17241 .76027 .17076 .75822 .16772 Metetra
.664 .741 .907 r
.75822 .16772 .76027 .17076 .76489 .16911 .76285 .16606 Metetra
.664 .741 .907 r
.76285 .16606 .76489 .16911 .76952 .16746 .76748 .1644 Metetra
.664 .741 .907 r
.76748 .1644 .76952 .16746 .77416 .16581 .77213 .16274 Metetra
.664 .741 .907 r
.77213 .16274 .77416 .16581 .77881 .16415 .77678 .16108 Metetra
.664 .741 .907 r
.77678 .16108 .77881 .16415 .78346 .16249 .78143 .15942 Metetra
.664 .741 .907 r
.78143 .15942 .78346 .16249 .78812 .16083 .7861 .15775 Metetra
.664 .741 .907 r
.7861 .15775 .78812 .16083 .79279 .15916 .79077 .15608 Metetra
.664 .741 .907 r
.16647 .37591 .1691 .37837 .17283 .37703 .1702 .37457 Metetra
.664 .741 .907 r
.1702 .37457 .17283 .37703 .17656 .3757 .17393 .37323 Metetra
.664 .741 .907 r
.17393 .37323 .17656 .3757 .1803 .37436 .17767 .37189 Metetra
.664 .741 .907 r
.17767 .37189 .1803 .37436 .18404 .37303 .18142 .37055 Metetra
.664 .741 .907 r
.18142 .37055 .18404 .37303 .18778 .37169 .18516 .36921 Metetra
.664 .741 .907 r
.18516 .36921 .18778 .37169 .19154 .37034 .18892 .36786 Metetra
.664 .741 .907 r
.18892 .36786 .19154 .37034 .19529 .369 .19268 .36652 Metetra
.664 .741 .907 r
.19268 .36652 .19529 .369 .19906 .36766 .19645 .36517 Metetra
.664 .741 .907 r
.19645 .36517 .19906 .36766 .20283 .36631 .20022 .36382 Metetra
.664 .741 .907 r
.20022 .36382 .20283 .36631 .2066 .36496 .204 .36246 Metetra
.664 .741 .907 r
.204 .36246 .2066 .36496 .21038 .36361 .20778 .36111 Metetra
.664 .741 .907 r
.20778 .36111 .21038 .36361 .21416 .36225 .21157 .35975 Metetra
.664 .741 .907 r
.21157 .35975 .21416 .36225 .21796 .3609 .21536 .35839 Metetra
.664 .741 .907 r
.21536 .35839 .21796 .3609 .22175 .35954 .21916 .35703 Metetra
.664 .741 .907 r
.21916 .35703 .22175 .35954 .22555 .35818 .22297 .35567 Metetra
.664 .741 .907 r
.22297 .35567 .22555 .35818 .22936 .35682 .22678 .3543 Metetra
.664 .741 .907 r
.22678 .3543 .22936 .35682 .23317 .35546 .23059 .35293 Metetra
.664 .741 .907 r
.23059 .35293 .23317 .35546 .23699 .35409 .23441 .35157 Metetra
.664 .741 .907 r
.23441 .35157 .23699 .35409 .24082 .35272 .23824 .35019 Metetra
.664 .741 .907 r
.23824 .35019 .24082 .35272 .24465 .35135 .24207 .34882 Metetra
.664 .741 .907 r
.24207 .34882 .24465 .35135 .24848 .34998 .24591 .34745 Metetra
.664 .741 .907 r
.24591 .34745 .24848 .34998 .25232 .34861 .24976 .34607 Metetra
.664 .741 .907 r
.24976 .34607 .25232 .34861 .25617 .34723 .25361 .34469 Metetra
.664 .741 .907 r
.25361 .34469 .25617 .34723 .26002 .34586 .25746 .34331 Metetra
.664 .741 .907 r
.25746 .34331 .26002 .34586 .26388 .34448 .26132 .34193 Metetra
.664 .741 .907 r
.26132 .34193 .26388 .34448 .26774 .3431 .26519 .34054 Metetra
.664 .741 .907 r
.26519 .34054 .26774 .3431 .27161 .34171 .26906 .33915 Metetra
.664 .741 .907 r
.26906 .33915 .27161 .34171 .27549 .34033 .27294 .33776 Metetra
.664 .741 .907 r
.27294 .33776 .27549 .34033 .27937 .33894 .27683 .33637 Metetra
.664 .741 .907 r
.27683 .33637 .27937 .33894 .28325 .33755 .28072 .33498 Metetra
.664 .741 .907 r
.28072 .33498 .28325 .33755 .28715 .33616 .28461 .33358 Metetra
.664 .741 .907 r
.28461 .33358 .28715 .33616 .29104 .33476 .28851 .33218 Metetra
.664 .741 .907 r
.28851 .33218 .29104 .33476 .29495 .33337 .29242 .33079 Metetra
.664 .741 .907 r
.29242 .33079 .29495 .33337 .29886 .33197 .29634 .32938 Metetra
.664 .741 .907 r
.29634 .32938 .29886 .33197 .30277 .33057 .30025 .32798 Metetra
.952 .682 .488 r
.30025 .32798 .30277 .33057 .3067 .32917 .28802 .55714 Metetra
.525 .294 .507 r
.28802 .55714 .3067 .32917 .29495 .55826 .29223 .55581 Metetra
.948 .707 .54 r
.29223 .55581 .29495 .55826 .30019 .54138 .3002 .49893 Metetra
.737 .499 .568 r
.3002 .49893 .30019 .54138 .30774 .48893 .30642 .46639 Metetra
.757 .53 .589 r
.30642 .46639 .30774 .48893 .31357 .46135 .31176 .44627 Metetra
.766 .553 .61 r
.31176 .44627 .31357 .46135 .31873 .44344 .31669 .43208 Metetra
.77 .572 .631 r
.31669 .43208 .31873 .44344 .32355 .43045 .32138 .42126 Metetra
.771 .588 .652 r
.32138 .42126 .32355 .43045 .32818 .42036 .32592 .41256 Metetra
.77 .603 .671 r
.32592 .41256 .32818 .42036 .33267 .41215 .33036 .4053 Metetra
.768 .615 .69 r
.33036 .4053 .33267 .41215 .33709 .40523 .33474 .39907 Metetra
.765 .626 .707 r
.33474 .39907 .33709 .40523 .34144 .39926 .33906 .3936 Metetra
.762 .636 .722 r
.33906 .3936 .34144 .39926 .34574 .39398 .34334 .38872 Metetra
.758 .645 .736 r
.34334 .38872 .34574 .39398 .35001 .38925 .3476 .3843 Metetra
.754 .653 .749 r
.3476 .3843 .35001 .38925 .35426 .38495 .35184 .38025 Metetra
.75 .659 .761 r
.35184 .38025 .35426 .38495 .35849 .381 .35606 .37651 Metetra
.746 .665 .772 r
.35606 .37651 .35849 .381 .3627 .37734 .36027 .37301 Metetra
.742 .671 .781 r
.36027 .37301 .3627 .37734 .3669 .37392 .36447 .36973 Metetra
.738 .675 .79 r
.36447 .36973 .3669 .37392 .3711 .3707 .36866 .36663 Metetra
.734 .679 .798 r
.36866 .36663 .3711 .3707 .37528 .36765 .37284 .36369 Metetra
.73 .683 .805 r
.37284 .36369 .37528 .36765 .37947 .36475 .37702 .36087 Metetra
.726 .686 .811 r
.37702 .36087 .37947 .36475 .38364 .36198 .3812 .35818 Metetra
.723 .689 .817 r
.3812 .35818 .38364 .36198 .38782 .35933 .38538 .35559 Metetra
.719 .692 .823 r
.38538 .35559 .38782 .35933 .392 .35677 .38956 .35309 Metetra
.716 .694 .828 r
.38956 .35309 .392 .35677 .39617 .35431 .39373 .35067 Metetra
.713 .696 .832 r
.39373 .35067 .39617 .35431 .40035 .35192 .39791 .34833 Metetra
.71 .698 .836 r
.39791 .34833 .40035 .35192 .40453 .34961 .40209 .34606 Metetra
.707 .699 .84 r
.40209 .34606 .40453 .34961 .4087 .34736 .40627 .34384 Metetra
.704 .7 .844 r
.40627 .34384 .4087 .34736 .41288 .34517 .41045 .34168 Metetra
.702 .701 .847 r
.41045 .34168 .41288 .34517 .41707 .34303 .41464 .33957 Metetra
.699 .702 .85 r
.41464 .33957 .41707 .34303 .42125 .34094 .41883 .33751 Metetra
.697 .703 .852 r
.41883 .33751 .42125 .34094 .42544 .33891 .42302 .33549 Metetra
.694 .704 .855 r
.42302 .33549 .42544 .33891 .42964 .33691 .42722 .33351 Metetra
.692 .705 .857 r
.42722 .33351 .42964 .33691 .43383 .33495 .43142 .33157 Metetra
.69 .705 .859 r
.43142 .33157 .43383 .33495 .43804 .33303 .43562 .32967 Metetra
.687 .705 .861 r
.43562 .32967 .43804 .33303 .44224 .33115 .43983 .32779 Metetra
.685 .706 .863 r
.43983 .32779 .44224 .33115 .44645 .3293 .44404 .32595 Metetra
.683 .706 .865 r
.44404 .32595 .44645 .3293 .45067 .32749 .44826 .32415 Metetra
.681 .706 .867 r
.44826 .32415 .45067 .32749 .45453 .34182 .45248 .32237 Metetra
.048 .018 .497 r
.45248 .32237 .45453 .34182 .45877 .34031 .45636 .33679 Metetra
.655 .686 .867 r
.45636 .33679 .45877 .34031 .46301 .33885 .46061 .33531 Metetra
.933 .73 .605 r
.46061 .33531 .46301 .33885 .46727 .33742 .46517 .31793 Metetra
.562 .389 .604 r
.46517 .31793 .46727 .33742 .47179 .32012 .4694 .31676 Metetra
.628 .686 .885 r
.4694 .31676 .47179 .32012 .47603 .319 .47365 .31562 Metetra
.625 .684 .885 r
.47365 .31562 .47603 .319 .48028 .3179 .4779 .31451 Metetra
.622 .681 .885 r
.4779 .31451 .48028 .3179 .48453 .31684 .48215 .31343 Metetra
.618 .679 .885 r
.48215 .31343 .48453 .31684 .48879 .31582 .48642 .31238 Metetra
.615 .676 .885 r
.48642 .31238 .48879 .31582 .49306 .31483 .49069 .31137 Metetra
.611 .673 .885 r
.49069 .31137 .49306 .31483 .49734 .31389 .49497 .3104 Metetra
.607 .67 .885 r
.49497 .3104 .49734 .31389 .50162 .31299 .49926 .30947 Metetra
.603 .666 .884 r
.49926 .30947 .50162 .31299 .50592 .31214 .50355 .30858 Metetra
.598 .662 .884 r
.50355 .30858 .50592 .31214 .51022 .31134 .50786 .30775 Metetra
.593 .658 .883 r
.50786 .30775 .51022 .31134 .51453 .31059 .51217 .30696 Metetra
.587 .653 .882 r
.51217 .30696 .51453 .31059 .51884 .3099 .51649 .30623 Metetra
.582 .648 .881 r
.51649 .30623 .51884 .3099 .52317 .30928 .52082 .30557 Metetra
.575 .642 .88 r
.52082 .30557 .52317 .30928 .52751 .30874 .52516 .30497 Metetra
.568 .636 .878 r
.52516 .30497 .52751 .30874 .53185 .30828 .52951 .30444 Metetra
.56 .628 .876 r
.52951 .30444 .53185 .30828 .53621 .3079 .53386 .304 Metetra
.551 .62 .874 r
.53386 .304 .53621 .3079 .54058 .30763 .53823 .30366 Metetra
.541 .611 .872 r
.53823 .30366 .54058 .30763 .54495 .30748 .54261 .30342 Metetra
.53 .6 .868 r
.54261 .30342 .54495 .30748 .54934 .30746 .547 .3033 Metetra
.518 .588 .865 r
.547 .3033 .54934 .30746 .55375 .30759 .55141 .30332 Metetra
.503 .574 .86 r
.55141 .30332 .55375 .30759 .55816 .3079 .55582 .3035 Metetra
.487 .558 .854 r
.55582 .3035 .55816 .3079 .56259 .30842 .56025 .30387 Metetra
.468 .54 .848 r
.56025 .30387 .56259 .30842 .56704 .30918 .5647 .30445 Metetra
.445 .518 .839 r
.5647 .30445 .56704 .30918 .5715 .31024 .56916 .30529 Metetra
.419 .492 .828 r
.56916 .30529 .5715 .31024 .57599 .31165 .57364 .30644 Metetra
.389 .462 .815 r
.57364 .30644 .57599 .31165 .5805 .31351 .57814 .30797 Metetra
.352 .426 .798 r
.57814 .30797 .5805 .31351 .58503 .31593 .58267 .30998 Metetra
.309 .383 .776 r
.58267 .30998 .58503 .31593 .5896 .31907 .58722 .31259 Metetra
.256 .331 .748 r
.58722 .31259 .5896 .31907 .59421 .32318 .59181 .31598 Metetra
.194 .268 .713 r
.59181 .31598 .59421 .32318 .59888 .32861 .59645 .32043 Metetra
.12 .193 .666 r
.59645 .32043 .59888 .32861 .60362 .33597 .60115 .32636 Metetra
.032 .106 .608 r
.60115 .32636 .60362 .33597 .60847 .34632 .60593 .33448 Metetra
0 .005 .536 r
.60593 .33448 .60847 .34632 .61351 .36173 .61084 .34605 Metetra
0 0 .45 r
.61084 .34605 .61351 .36173 .6189 .3871 .61598 .36373 Metetra
0 0 .35 r
.61598 .36373 .6189 .3871 .62515 .43811 .62156 .39421 Metetra
0 0 .326 r
.62156 .39421 .62515 .43811 .6304 .45262 .62803 .44985 Metetra
.645 .763 .934 r
.62803 .44985 .6304 .45262 .62719 .21457 .6328 .44835 Metetra
0 0 .35 r
.6328 .44835 .62719 .21457 .63161 .21299 .62941 .21006 Metetra
.664 .741 .907 r
.62941 .21006 .63161 .21299 .63604 .2114 .63384 .20848 Metetra
.664 .741 .907 r
.63384 .20848 .63604 .2114 .64047 .20982 .63828 .20689 Metetra
.664 .741 .907 r
.63828 .20689 .64047 .20982 .64491 .20823 .64273 .2053 Metetra
.664 .741 .907 r
.64273 .2053 .64491 .20823 .64936 .20664 .64718 .2037 Metetra
.664 .741 .907 r
.64718 .2037 .64936 .20664 .65381 .20505 .65164 .2021 Metetra
.664 .741 .907 r
.65164 .2021 .65381 .20505 .65827 .20346 .6561 .2005 Metetra
.664 .741 .907 r
.6561 .2005 .65827 .20346 .66274 .20186 .66057 .1989 Metetra
.664 .741 .907 r
.66057 .1989 .66274 .20186 .66721 .20026 .66505 .1973 Metetra
.664 .741 .907 r
.66505 .1973 .66721 .20026 .67169 .19866 .66954 .19569 Metetra
.664 .741 .907 r
.66954 .19569 .67169 .19866 .67618 .19705 .67403 .19408 Metetra
.664 .741 .907 r
.67403 .19408 .67618 .19705 .68068 .19544 .67853 .19247 Metetra
.664 .741 .907 r
.67853 .19247 .68068 .19544 .68518 .19383 .68304 .19085 Metetra
.664 .741 .907 r
.68304 .19085 .68518 .19383 .68969 .19222 .68756 .18924 Metetra
.664 .741 .907 r
.68756 .18924 .68969 .19222 .69421 .1906 .69208 .18762 Metetra
.664 .741 .907 r
.69208 .18762 .69421 .1906 .69873 .18899 .69661 .18599 Metetra
.664 .741 .907 r
.69661 .18599 .69873 .18899 .70327 .18737 .70115 .18437 Metetra
.664 .741 .907 r
.70115 .18437 .70327 .18737 .70781 .18574 .70569 .18274 Metetra
.664 .741 .907 r
.70569 .18274 .70781 .18574 .71235 .18412 .71024 .18111 Metetra
.664 .741 .907 r
.71024 .18111 .71235 .18412 .71691 .18249 .7148 .17948 Metetra
.664 .741 .907 r
.7148 .17948 .71691 .18249 .72147 .18086 .71937 .17784 Metetra
.664 .741 .907 r
.71937 .17784 .72147 .18086 .72604 .17922 .72394 .1762 Metetra
.664 .741 .907 r
.72394 .1762 .72604 .17922 .73061 .17759 .72852 .17456 Metetra
.664 .741 .907 r
.72852 .17456 .73061 .17759 .73519 .17595 .73311 .17292 Metetra
.664 .741 .907 r
.73311 .17292 .73519 .17595 .73978 .17431 .73771 .17127 Metetra
.664 .741 .907 r
.73771 .17127 .73978 .17431 .74438 .17266 .74231 .16962 Metetra
.664 .741 .907 r
.74231 .16962 .74438 .17266 .74899 .17102 .74692 .16797 Metetra
.664 .741 .907 r
.74692 .16797 .74899 .17102 .7536 .16937 .75154 .16632 Metetra
.664 .741 .907 r
.75154 .16632 .7536 .16937 .75822 .16772 .75616 .16466 Metetra
.664 .741 .907 r
.75616 .16466 .75822 .16772 .76285 .16606 .76079 .163 Metetra
.664 .741 .907 r
.76079 .163 .76285 .16606 .76748 .1644 .76543 .16134 Metetra
.664 .741 .907 r
.76543 .16134 .76748 .1644 .77213 .16274 .77008 .15967 Metetra
.664 .741 .907 r
.77008 .15967 .77213 .16274 .77678 .16108 .77474 .158 Metetra
.664 .741 .907 r
.77474 .158 .77678 .16108 .78143 .15942 .7794 .15633 Metetra
.664 .741 .907 r
.7794 .15633 .78143 .15942 .7861 .15775 .78407 .15466 Metetra
.664 .741 .907 r
.78407 .15466 .7861 .15775 .79077 .15608 .78875 .15299 Metetra
.664 .741 .907 r
.16383 .37344 .16647 .37591 .1702 .37457 .16756 .3721 Metetra
.664 .741 .907 r
.16756 .3721 .1702 .37457 .17393 .37323 .1713 .37076 Metetra
.664 .741 .907 r
.1713 .37076 .17393 .37323 .17767 .37189 .17504 .36941 Metetra
.664 .741 .907 r
.17504 .36941 .17767 .37189 .18142 .37055 .17879 .36807 Metetra
.664 .741 .907 r
.17879 .36807 .18142 .37055 .18516 .36921 .18254 .36672 Metetra
.664 .741 .907 r
.18254 .36672 .18516 .36921 .18892 .36786 .1863 .36537 Metetra
.664 .741 .907 r
.1863 .36537 .18892 .36786 .19268 .36652 .19006 .36402 Metetra
.664 .741 .907 r
.19006 .36402 .19268 .36652 .19645 .36517 .19383 .36267 Metetra
.664 .741 .907 r
.19383 .36267 .19645 .36517 .20022 .36382 .19761 .36132 Metetra
.664 .741 .907 r
.19761 .36132 .20022 .36382 .204 .36246 .20139 .35996 Metetra
.664 .741 .907 r
.20139 .35996 .204 .36246 .20778 .36111 .20517 .3586 Metetra
.664 .741 .907 r
.20517 .3586 .20778 .36111 .21157 .35975 .20896 .35724 Metetra
.664 .741 .907 r
.20896 .35724 .21157 .35975 .21536 .35839 .21276 .35588 Metetra
.664 .741 .907 r
.21276 .35588 .21536 .35839 .21916 .35703 .21656 .35451 Metetra
.664 .741 .907 r
.21656 .35451 .21916 .35703 .22297 .35567 .22037 .35314 Metetra
.664 .741 .907 r
.22037 .35314 .22297 .35567 .22678 .3543 .22419 .35178 Metetra
.664 .741 .907 r
.22419 .35178 .22678 .3543 .23059 .35293 .22801 .35041 Metetra
.664 .741 .907 r
.22801 .35041 .23059 .35293 .23441 .35157 .23183 .34903 Metetra
.664 .741 .907 r
.23183 .34903 .23441 .35157 .23824 .35019 .23566 .34766 Metetra
.664 .741 .907 r
.23566 .34766 .23824 .35019 .24207 .34882 .2395 .34628 Metetra
.664 .741 .907 r
.2395 .34628 .24207 .34882 .24591 .34745 .24334 .3449 Metetra
.664 .741 .907 r
.24334 .3449 .24591 .34745 .24976 .34607 .24719 .34352 Metetra
.664 .741 .907 r
.24719 .34352 .24976 .34607 .25361 .34469 .25104 .34214 Metetra
.664 .741 .907 r
.25104 .34214 .25361 .34469 .25746 .34331 .2549 .34075 Metetra
.664 .741 .907 r
.2549 .34075 .25746 .34331 .26132 .34193 .25876 .33937 Metetra
.664 .741 .907 r
.25876 .33937 .26132 .34193 .26519 .34054 .26263 .33798 Metetra
.664 .741 .907 r
.26263 .33798 .26519 .34054 .26906 .33915 .26651 .33659 Metetra
.664 .741 .907 r
.26651 .33659 .26906 .33915 .27294 .33776 .27039 .33519 Metetra
.664 .741 .907 r
.27039 .33519 .27294 .33776 .27683 .33637 .27428 .3338 Metetra
.664 .741 .907 r
.27428 .3338 .27683 .33637 .28072 .33498 .27817 .3324 Metetra
.664 .741 .907 r
.27817 .3324 .28072 .33498 .28461 .33358 .28207 .331 Metetra
.664 .741 .907 r
.28207 .331 .28461 .33358 .28851 .33218 .28598 .3296 Metetra
.664 .741 .907 r
.28598 .3296 .28851 .33218 .29242 .33079 .28989 .3282 Metetra
.664 .741 .907 r
.28989 .3282 .29242 .33079 .29634 .32938 .29381 .32679 Metetra
.664 .741 .907 r
.29381 .32679 .29634 .32938 .30025 .32798 .29773 .32538 Metetra
.952 .682 .488 r
.29773 .32538 .30025 .32798 .28802 .55714 .28529 .55468 Metetra
.945 .712 .554 r
.28529 .55468 .28802 .55714 .29223 .55581 .29241 .51158 Metetra
.754 .512 .566 r
.29241 .51158 .29223 .55581 .3002 .49893 .29917 .47238 Metetra
.752 .521 .582 r
.29917 .47238 .3002 .49893 .30642 .46639 .30474 .44955 Metetra
.764 .546 .603 r
.30474 .44955 .30642 .46639 .31176 .44627 .30979 .43397 Metetra
.769 .566 .625 r
.30979 .43397 .31176 .44627 .31669 .43208 .31455 .42231 Metetra
.77 .583 .645 r
.31455 .42231 .31669 .43208 .32138 .42126 .31914 .41307 Metetra
.77 .598 .665 r
.31914 .41307 .32138 .42126 .32592 .41256 .32362 .40544 Metetra
.768 .611 .684 r
.32362 .40544 .32592 .41256 .33036 .4053 .32802 .39894 Metetra
.766 .623 .702 r
.32802 .39894 .33036 .4053 .33474 .39907 .33236 .39326 Metetra
.762 .633 .718 r
.33236 .39326 .33474 .39907 .33906 .3936 .33666 .38822 Metetra
.759 .642 .732 r
.33666 .38822 .33906 .3936 .34334 .38872 .34093 .38367 Metetra
.755 .65 .746 r
.34093 .38367 .34334 .38872 .3476 .3843 .34518 .37952 Metetra
.751 .657 .758 r
.34518 .37952 .3476 .3843 .35184 .38025 .34941 .37569 Metetra
.747 .664 .769 r
.34941 .37569 .35184 .38025 .35606 .37651 .35362 .37212 Metetra
.743 .669 .778 r
.35362 .37212 .35606 .37651 .36027 .37301 .35782 .36878 Metetra
.739 .674 .787 r
.35782 .36878 .36027 .37301 .36447 .36973 .36202 .36562 Metetra
.735 .678 .795 r
.36202 .36562 .36447 .36973 .36866 .36663 .36621 .36263 Metetra
.731 .682 .803 r
.36621 .36263 .36866 .36663 .37284 .36369 .37039 .35978 Metetra
.727 .685 .81 r
.37039 .35978 .37284 .36369 .37702 .36087 .37457 .35704 Metetra
.724 .688 .816 r
.37457 .35704 .37702 .36087 .3812 .35818 .37875 .35442 Metetra
.721 .691 .821 r
.37875 .35442 .3812 .35818 .38538 .35559 .38293 .35189 Metetra
.717 .693 .826 r
.38293 .35189 .38538 .35559 .38956 .35309 .38711 .34944 Metetra
.714 .695 .831 r
.38711 .34944 .38956 .35309 .39373 .35067 .39129 .34707 Metetra
.711 .697 .835 r
.39129 .34707 .39373 .35067 .39791 .34833 .39546 .34477 Metetra
.708 .699 .839 r
.39546 .34477 .39791 .34833 .40209 .34606 .39965 .34253 Metetra
.706 .7 .842 r
.39965 .34253 .40209 .34606 .40627 .34384 .40383 .34034 Metetra
.703 .702 .846 r
.40383 .34034 .40627 .34384 .41045 .34168 .40801 .33821 Metetra
.7 .703 .849 r
.40801 .33821 .41045 .34168 .41464 .33957 .4122 .33613 Metetra
.698 .704 .852 r
.4122 .33613 .41464 .33957 .41883 .33751 .41639 .33409 Metetra
.695 .704 .854 r
.41639 .33409 .41883 .33751 .42302 .33549 .42059 .33209 Metetra
.693 .705 .857 r
.42059 .33209 .42302 .33549 .42722 .33351 .42479 .33012 Metetra
.691 .706 .859 r
.42479 .33012 .42722 .33351 .43142 .33157 .42899 .3282 Metetra
.689 .706 .861 r
.42899 .3282 .43142 .33157 .43562 .32967 .4332 .32631 Metetra
.686 .706 .863 r
.4332 .32631 .43562 .32967 .43983 .32779 .43741 .32444 Metetra
.684 .707 .865 r
.43741 .32444 .43983 .32779 .44404 .32595 .44163 .32261 Metetra
.682 .707 .866 r
.44163 .32261 .44404 .32595 .44826 .32415 .44585 .32081 Metetra
.68 .707 .868 r
.44585 .32081 .44826 .32415 .45248 .32237 .45007 .31904 Metetra
.678 .707 .869 r
.45007 .31904 .45248 .32237 .45636 .33679 .45431 .31729 Metetra
.568 .393 .604 r
.45431 .31729 .45636 .33679 .46061 .33531 .45854 .31581 Metetra
.563 .389 .604 r
.45854 .31581 .46061 .33531 .46517 .31793 .46277 .31459 Metetra
.632 .689 .886 r
.46277 .31459 .46517 .31793 .4694 .31676 .46701 .31341 Metetra
.629 .687 .886 r
.46701 .31341 .4694 .31676 .47365 .31562 .47126 .31225 Metetra
.626 .685 .886 r
.47126 .31225 .47365 .31562 .4779 .31451 .47551 .31112 Metetra
.623 .683 .886 r
.47551 .31112 .4779 .31451 .48215 .31343 .47977 .31002 Metetra
.62 .681 .886 r
.47977 .31002 .48215 .31343 .48642 .31238 .48404 .30895 Metetra
.616 .678 .886 r
.48404 .30895 .48642 .31238 .49069 .31137 .48831 .30792 Metetra
.613 .675 .886 r
.48831 .30792 .49069 .31137 .49497 .3104 .4926 .30692 Metetra
.609 .672 .885 r
.4926 .30692 .49497 .3104 .49926 .30947 .49689 .30596 Metetra
.605 .669 .885 r
.49689 .30596 .49926 .30947 .50355 .30858 .50118 .30505 Metetra
.601 .665 .884 r
.50118 .30505 .50355 .30858 .50786 .30775 .50549 .30418 Metetra
.596 .661 .884 r
.50549 .30418 .50786 .30775 .51217 .30696 .50981 .30335 Metetra
.591 .657 .883 r
.50981 .30335 .51217 .30696 .51649 .30623 .51413 .30258 Metetra
.585 .652 .882 r
.51413 .30258 .51649 .30623 .52082 .30557 .51846 .30187 Metetra
.579 .646 .881 r
.51846 .30187 .52082 .30557 .52516 .30497 .5228 .30122 Metetra
.573 .64 .88 r
.5228 .30122 .52516 .30497 .52951 .30444 .52715 .30064 Metetra
.565 .633 .878 r
.52715 .30064 .52951 .30444 .53386 .304 .53151 .30014 Metetra
.557 .626 .876 r
.53151 .30014 .53386 .304 .53823 .30366 .53588 .29973 Metetra
.548 .617 .874 r
.53588 .29973 .53823 .30366 .54261 .30342 .54027 .29941 Metetra
.538 .608 .871 r
.54027 .29941 .54261 .30342 .547 .3033 .54466 .2992 Metetra
.526 .597 .867 r
.54466 .2992 .547 .3033 .55141 .30332 .54906 .29912 Metetra
.513 .584 .863 r
.54906 .29912 .55141 .30332 .55582 .3035 .55348 .29918 Metetra
.498 .57 .858 r
.55348 .29918 .55582 .3035 .56025 .30387 .55791 .29941 Metetra
.481 .553 .852 r
.55791 .29941 .56025 .30387 .5647 .30445 .56235 .29983 Metetra
.461 .534 .845 r
.56235 .29983 .5647 .30445 .56916 .30529 .56681 .30048 Metetra
.438 .511 .836 r
.56681 .30048 .56916 .30529 .57364 .30644 .57129 .3014 Metetra
.411 .484 .825 r
.57129 .3014 .57364 .30644 .57814 .30797 .57578 .30265 Metetra
.379 .452 .81 r
.57578 .30265 .57814 .30797 .58267 .30998 .5803 .3043 Metetra
.341 .414 .792 r
.5803 .3043 .58267 .30998 .58722 .31259 .58485 .30647 Metetra
.295 .368 .769 r
.58485 .30647 .58722 .31259 .59181 .31598 .58942 .30928 Metetra
.24 .314 .739 r
.58942 .30928 .59181 .31598 .59645 .32043 .59404 .31294 Metetra
.175 .248 .7 r
.59404 .31294 .59645 .32043 .60115 .32636 .5987 .31777 Metetra
.097 .17 .651 r
.5987 .31777 .60115 .32636 .60593 .33448 .60344 .32425 Metetra
.007 .078 .589 r
.60344 .32425 .60593 .33448 .61084 .34605 .60826 .33322 Metetra
0 0 .513 r
.60826 .33322 .61084 .34605 .61598 .36373 .61324 .34623 Metetra
0 0 .423 r
.61324 .34623 .61598 .36373 .62156 .39421 .61849 .3667 Metetra
0 0 .319 r
.61849 .3667 .62156 .39421 .62803 .44985 .62433 .40406 Metetra
0 0 .436 r
.62433 .40406 .62803 .44985 .6328 .44835 .63043 .44557 Metetra
.977 .688 .403 r
.63043 .44557 .6328 .44835 .62941 .21006 .62721 .20713 Metetra
.664 .741 .907 r
.62721 .20713 .62941 .21006 .63384 .20848 .63165 .20554 Metetra
.664 .741 .907 r
.63165 .20554 .63384 .20848 .63828 .20689 .63609 .20395 Metetra
.664 .741 .907 r
.63609 .20395 .63828 .20689 .64273 .2053 .64054 .20235 Metetra
.664 .741 .907 r
.64054 .20235 .64273 .2053 .64718 .2037 .64499 .20075 Metetra
.664 .741 .907 r
.64499 .20075 .64718 .2037 .65164 .2021 .64946 .19915 Metetra
.664 .741 .907 r
.64946 .19915 .65164 .2021 .6561 .2005 .65393 .19754 Metetra
.664 .741 .907 r
.65393 .19754 .6561 .2005 .66057 .1989 .6584 .19594 Metetra
.664 .741 .907 r
.6584 .19594 .66057 .1989 .66505 .1973 .66289 .19433 Metetra
.664 .741 .907 r
.66289 .19433 .66505 .1973 .66954 .19569 .66738 .19272 Metetra
.664 .741 .907 r
.66738 .19272 .66954 .19569 .67403 .19408 .67188 .1911 Metetra
.664 .741 .907 r
.67188 .1911 .67403 .19408 .67853 .19247 .67638 .18948 Metetra
.664 .741 .907 r
.67638 .18948 .67853 .19247 .68304 .19085 .6809 .18786 Metetra
.664 .741 .907 r
.6809 .18786 .68304 .19085 .68756 .18924 .68542 .18624 Metetra
.664 .741 .907 r
.68542 .18624 .68756 .18924 .69208 .18762 .68994 .18462 Metetra
.664 .741 .907 r
.68994 .18462 .69208 .18762 .69661 .18599 .69448 .18299 Metetra
.664 .741 .907 r
.69448 .18299 .69661 .18599 .70115 .18437 .69902 .18136 Metetra
.664 .741 .907 r
.69902 .18136 .70115 .18437 .70569 .18274 .70357 .17973 Metetra
.664 .741 .907 r
.70357 .17973 .70569 .18274 .71024 .18111 .70813 .17809 Metetra
.664 .741 .907 r
.70813 .17809 .71024 .18111 .7148 .17948 .71269 .17645 Metetra
.664 .741 .907 r
.71269 .17645 .7148 .17948 .71937 .17784 .71726 .17481 Metetra
.664 .741 .907 r
.71726 .17481 .71937 .17784 .72394 .1762 .72184 .17317 Metetra
.664 .741 .907 r
.72184 .17317 .72394 .1762 .72852 .17456 .72643 .17152 Metetra
.664 .741 .907 r
.72643 .17152 .72852 .17456 .73311 .17292 .73102 .16988 Metetra
.664 .741 .907 r
.73102 .16988 .73311 .17292 .73771 .17127 .73562 .16822 Metetra
.664 .741 .907 r
.73562 .16822 .73771 .17127 .74231 .16962 .74023 .16657 Metetra
.664 .741 .907 r
.74023 .16657 .74231 .16962 .74692 .16797 .74484 .16491 Metetra
.664 .741 .907 r
.74484 .16491 .74692 .16797 .75154 .16632 .74947 .16325 Metetra
.664 .741 .907 r
.74947 .16325 .75154 .16632 .75616 .16466 .7541 .16159 Metetra
.664 .741 .907 r
.7541 .16159 .75616 .16466 .76079 .163 .75874 .15993 Metetra
.664 .741 .907 r
.75874 .15993 .76079 .163 .76543 .16134 .76338 .15826 Metetra
.664 .741 .907 r
.76338 .15826 .76543 .16134 .77008 .15967 .76803 .15659 Metetra
.664 .741 .907 r
.76803 .15659 .77008 .15967 .77474 .158 .77269 .15492 Metetra
.664 .741 .907 r
.77269 .15492 .77474 .158 .7794 .15633 .77736 .15324 Metetra
.664 .741 .907 r
.77736 .15324 .7794 .15633 .78407 .15466 .78204 .15157 Metetra
.664 .741 .907 r
.78204 .15157 .78407 .15466 .78875 .15299 .78672 .14988 Metetra
.664 .741 .907 r
.16118 .37096 .16383 .37344 .16756 .3721 .16491 .36962 Metetra
.664 .741 .907 r
.16491 .36962 .16756 .3721 .1713 .37076 .16865 .36828 Metetra
.664 .741 .907 r
.16865 .36828 .1713 .37076 .17504 .36941 .1724 .36693 Metetra
.664 .741 .907 r
.1724 .36693 .17504 .36941 .17879 .36807 .17615 .36558 Metetra
.664 .741 .907 r
.17615 .36558 .17879 .36807 .18254 .36672 .17991 .36423 Metetra
.664 .741 .907 r
.17991 .36423 .18254 .36672 .1863 .36537 .18367 .36288 Metetra
.664 .741 .907 r
.18367 .36288 .1863 .36537 .19006 .36402 .18743 .36152 Metetra
.664 .741 .907 r
.18743 .36152 .19006 .36402 .19383 .36267 .19121 .36017 Metetra
.664 .741 .907 r
.19121 .36017 .19383 .36267 .19761 .36132 .19499 .35881 Metetra
.664 .741 .907 r
.19499 .35881 .19761 .36132 .20139 .35996 .19877 .35745 Metetra
.664 .741 .907 r
.19877 .35745 .20139 .35996 .20517 .3586 .20256 .35609 Metetra
.664 .741 .907 r
.20256 .35609 .20517 .3586 .20896 .35724 .20635 .35472 Metetra
.664 .741 .907 r
.20635 .35472 .20896 .35724 .21276 .35588 .21015 .35336 Metetra
.664 .741 .907 r
.21015 .35336 .21276 .35588 .21656 .35451 .21396 .35199 Metetra
.664 .741 .907 r
.21396 .35199 .21656 .35451 .22037 .35314 .21777 .35062 Metetra
.664 .741 .907 r
.21777 .35062 .22037 .35314 .22419 .35178 .22159 .34924 Metetra
.664 .741 .907 r
.22159 .34924 .22419 .35178 .22801 .35041 .22541 .34787 Metetra
.664 .741 .907 r
.22541 .34787 .22801 .35041 .23183 .34903 .22924 .34649 Metetra
.664 .741 .907 r
.22924 .34649 .23183 .34903 .23566 .34766 .23307 .34511 Metetra
.664 .741 .907 r
.23307 .34511 .23566 .34766 .2395 .34628 .23691 .34373 Metetra
.664 .741 .907 r
.23691 .34373 .2395 .34628 .24334 .3449 .24076 .34235 Metetra
.664 .741 .907 r
.24076 .34235 .24334 .3449 .24719 .34352 .24461 .34097 Metetra
.664 .741 .907 r
.24461 .34097 .24719 .34352 .25104 .34214 .24847 .33958 Metetra
.664 .741 .907 r
.24847 .33958 .25104 .34214 .2549 .34075 .25233 .33819 Metetra
.664 .741 .907 r
.25233 .33819 .2549 .34075 .25876 .33937 .2562 .3368 Metetra
.664 .741 .907 r
.2562 .3368 .25876 .33937 .26263 .33798 .26007 .33541 Metetra
.664 .741 .907 r
.26007 .33541 .26263 .33798 .26651 .33659 .26395 .33401 Metetra
.664 .741 .907 r
.26395 .33401 .26651 .33659 .27039 .33519 .26783 .33262 Metetra
.664 .741 .907 r
.26783 .33262 .27039 .33519 .27428 .3338 .27173 .33122 Metetra
.664 .741 .907 r
.27173 .33122 .27428 .3338 .27817 .3324 .27562 .32981 Metetra
.664 .741 .907 r
.27562 .32981 .27817 .3324 .28207 .331 .27953 .32841 Metetra
.664 .741 .907 r
.27953 .32841 .28207 .331 .28598 .3296 .28343 .32701 Metetra
.664 .741 .907 r
.28343 .32701 .28598 .3296 .28989 .3282 .28735 .3256 Metetra
.664 .741 .907 r
.28735 .3256 .28989 .3282 .29381 .32679 .29127 .32419 Metetra
.952 .682 .489 r
.29127 .32419 .29381 .32679 .29773 .32538 .27834 .55356 Metetra
.477 .253 .496 r
.27834 .55356 .29773 .32538 .28529 .55468 .28428 .52811 Metetra
.835 .589 .566 r
.28428 .52811 .28529 .55468 .29241 .51158 .2918 .47958 Metetra
.746 .511 .576 r
.2918 .47958 .29241 .51158 .29917 .47238 .29765 .45338 Metetra
.76 .539 .597 r
.29765 .45338 .29917 .47238 .30474 .44955 .30285 .43614 Metetra
.767 .56 .618 r
.30285 .43614 .30474 .44955 .30979 .43397 .3077 .42354 Metetra
.769 .578 .639 r
.3077 .42354 .30979 .43397 .31455 .42231 .31234 .4137 Metetra
.77 .593 .66 r
.31234 .4137 .31455 .42231 .31914 .41307 .31686 .40565 Metetra
.768 .607 .679 r
.31686 .40565 .31914 .41307 .32362 .40544 .32129 .39886 Metetra
.766 .619 .697 r
.32129 .39886 .32362 .40544 .32802 .39894 .32565 .39296 Metetra
.763 .63 .713 r
.32565 .39296 .32802 .39894 .33236 .39326 .32997 .38775 Metetra
.76 .639 .728 r
.32997 .38775 .33236 .39326 .33666 .38822 .33425 .38307 Metetra
.756 .648 .742 r
.33425 .38307 .33666 .38822 .34093 .38367 .33851 .37881 Metetra
.752 .655 .754 r
.33851 .37881 .34093 .38367 .34518 .37952 .34274 .37489 Metetra
.748 .662 .765 r
.34274 .37489 .34518 .37952 .34941 .37569 .34697 .37125 Metetra
.744 .667 .776 r
.34697 .37125 .34941 .37569 .35362 .37212 .35117 .36784 Metetra
.74 .672 .785 r
.35117 .36784 .35362 .37212 .35782 .36878 .35537 .36463 Metetra
.736 .677 .793 r
.35537 .36463 .35782 .36878 .36202 .36562 .35956 .36159 Metetra
.732 .681 .801 r
.35956 .36159 .36202 .36562 .36621 .36263 .36375 .35869 Metetra
.729 .684 .808 r
.36375 .35869 .36621 .36263 .37039 .35978 .36793 .35592 Metetra
.725 .688 .814 r
.36793 .35592 .37039 .35978 .37457 .35704 .37212 .35326 Metetra
.722 .69 .82 r
.37212 .35326 .37457 .35704 .37875 .35442 .37629 .3507 Metetra
.718 .693 .825 r
.37629 .3507 .37875 .35442 .38293 .35189 .38047 .34822 Metetra
.715 .695 .829 r
.38047 .34822 .38293 .35189 .38711 .34944 .38465 .34582 Metetra
.712 .697 .834 r
.38465 .34582 .38711 .34944 .39129 .34707 .38883 .34349 Metetra
.709 .699 .838 r
.38883 .34349 .39129 .34707 .39546 .34477 .39301 .34123 Metetra
.707 .7 .841 r
.39301 .34123 .39546 .34477 .39965 .34253 .3972 .33902 Metetra
.704 .701 .845 r
.3972 .33902 .39965 .34253 .40383 .34034 .40138 .33687 Metetra
.701 .703 .848 r
.40138 .33687 .40383 .34034 .40801 .33821 .40557 .33476 Metetra
.699 .704 .851 r
.40557 .33476 .40801 .33821 .4122 .33613 .40976 .3327 Metetra
.697 .705 .853 r
.40976 .3327 .4122 .33613 .41639 .33409 .41395 .33068 Metetra
.694 .705 .856 r
.41395 .33068 .41639 .33409 .42059 .33209 .41815 .3287 Metetra
.692 .706 .858 r
.41815 .3287 .42059 .33209 .42479 .33012 .42235 .32675 Metetra
.69 .706 .86 r
.42235 .32675 .42479 .33012 .42899 .3282 .42656 .32484 Metetra
.688 .707 .862 r
.42656 .32484 .42899 .3282 .4332 .32631 .43077 .32295 Metetra
.686 .707 .864 r
.43077 .32295 .4332 .32631 .43741 .32444 .43499 .3211 Metetra
.684 .707 .866 r
.43499 .3211 .43741 .32444 .44163 .32261 .43921 .31928 Metetra
.682 .708 .867 r
.43921 .31928 .44163 .32261 .44585 .32081 .44343 .31749 Metetra
.936 .732 .602 r
.44343 .31749 .44585 .32081 .45007 .31904 .44806 .29961 Metetra
.568 .392 .603 r
.44806 .29961 .45007 .31904 .45431 .31729 .45226 .29811 Metetra
.568 .393 .604 r
.45226 .29811 .45431 .31729 .45854 .31581 .45648 .29662 Metetra
.568 .393 .604 r
.45648 .29662 .45854 .31581 .46277 .31459 .4607 .29514 Metetra
.025 .002 .489 r
.4607 .29514 .46277 .31459 .46701 .31341 .46461 .31006 Metetra
.63 .689 .886 r
.46461 .31006 .46701 .31341 .47126 .31225 .46886 .30888 Metetra
.627 .687 .886 r
.46886 .30888 .47126 .31225 .47551 .31112 .47311 .30773 Metetra
.624 .685 .887 r
.47311 .30773 .47551 .31112 .47977 .31002 .47738 .30662 Metetra
.621 .683 .887 r
.47738 .30662 .47977 .31002 .48404 .30895 .48165 .30553 Metetra
.618 .68 .886 r
.48165 .30553 .48404 .30895 .48831 .30792 .48593 .30447 Metetra
.615 .677 .886 r
.48593 .30447 .48831 .30792 .4926 .30692 .49021 .30345 Metetra
.611 .675 .886 r
.49021 .30345 .4926 .30692 .49689 .30596 .49451 .30247 Metetra
.607 .671 .886 r
.49451 .30247 .49689 .30596 .50118 .30505 .49881 .30152 Metetra
.603 .668 .885 r
.49881 .30152 .50118 .30505 .50549 .30418 .50312 .30062 Metetra
.599 .664 .885 r
.50312 .30062 .50549 .30418 .50981 .30335 .50744 .29976 Metetra
.594 .66 .884 r
.50744 .29976 .50981 .30335 .51413 .30258 .51176 .29895 Metetra
.589 .655 .883 r
.51176 .29895 .51413 .30258 .51846 .30187 .5161 .2982 Metetra
.583 .65 .882 r
.5161 .2982 .51846 .30187 .5228 .30122 .52044 .2975 Metetra
.577 .645 .881 r
.52044 .2975 .5228 .30122 .52715 .30064 .5248 .29687 Metetra
.57 .638 .879 r
.5248 .29687 .52715 .30064 .53151 .30014 .52916 .29631 Metetra
.563 .631 .877 r
.52916 .29631 .53151 .30014 .53588 .29973 .53353 .29583 Metetra
.554 .623 .875 r
.53353 .29583 .53588 .29973 .54027 .29941 .53791 .29544 Metetra
.545 .615 .873 r
.53791 .29544 .54027 .29941 .54466 .2992 .54231 .29515 Metetra
.534 .605 .87 r
.54231 .29515 .54466 .2992 .54906 .29912 .54671 .29498 Metetra
.523 .593 .866 r
.54671 .29498 .54906 .29912 .55348 .29918 .55113 .29493 Metetra
.509 .58 .862 r
.55113 .29493 .55348 .29918 .55791 .29941 .55556 .29503 Metetra
.494 .565 .857 r
.55556 .29503 .55791 .29941 .56235 .29983 .56 .29531 Metetra
.476 .548 .85 r
.56 .29531 .56235 .29983 .56681 .30048 .56446 .29579 Metetra
.455 .527 .842 r
.56446 .29579 .56681 .30048 .57129 .3014 .56893 .2965 Metetra
.431 .503 .833 r
.56893 .2965 .57129 .3014 .57578 .30265 .57343 .29751 Metetra
.403 .475 .82 r
.57343 .29751 .57578 .30265 .5803 .3043 .57794 .29886 Metetra
.369 .442 .805 r
.57794 .29886 .5803 .3043 .58485 .30647 .58248 .30065 Metetra
.329 .402 .785 r
.58248 .30065 .58485 .30647 .58942 .30928 .58704 .30298 Metetra
.281 .354 .76 r
.58704 .30298 .58942 .30928 .59404 .31294 .59164 .30601 Metetra
.224 .296 .728 r
.59164 .30601 .59404 .31294 .5987 .31777 .59628 .30997 Metetra
.155 .227 .687 r
.59628 .30997 .5987 .31777 .60344 .32425 .60097 .31521 Metetra
.075 .145 .634 r
.60097 .31521 .60344 .32425 .60826 .33322 .60574 .32231 Metetra
0 .051 .568 r
.60574 .32231 .60826 .33322 .61324 .34623 .61062 .33224 Metetra
0 0 .489 r
.61062 .33224 .61324 .34623 .61849 .3667 .61568 .34695 Metetra
0 0 .396 r
.61568 .34695 .61849 .3667 .62433 .40406 .62107 .37091 Metetra
0 0 .287 r
.62107 .37091 .62433 .40406 .63043 .44557 .62727 .41791 Metetra
.04 .004 .484 r
.62727 .41791 .63043 .44557 .62721 .20713 .63284 .44126 Metetra
0 0 .348 r
.63284 .44126 .62721 .20713 .63165 .20554 .62944 .2026 Metetra
.664 .741 .907 r
.62944 .2026 .63165 .20554 .63609 .20395 .63389 .201 Metetra
.664 .741 .907 r
.63389 .201 .63609 .20395 .64054 .20235 .63834 .1994 Metetra
.664 .741 .907 r
.63834 .1994 .64054 .20235 .64499 .20075 .6428 .19779 Metetra
.664 .741 .907 r
.6428 .19779 .64499 .20075 .64946 .19915 .64727 .19618 Metetra
.664 .741 .907 r
.64727 .19618 .64946 .19915 .65393 .19754 .65174 .19458 Metetra
.664 .741 .907 r
.65174 .19458 .65393 .19754 .6584 .19594 .65623 .19296 Metetra
.664 .741 .907 r
.65623 .19296 .6584 .19594 .66289 .19433 .66072 .19135 Metetra
.664 .741 .907 r
.66072 .19135 .66289 .19433 .66738 .19272 .66521 .18973 Metetra
.664 .741 .907 r
.66521 .18973 .66738 .19272 .67188 .1911 .66972 .18811 Metetra
.664 .741 .907 r
.66972 .18811 .67188 .1911 .67638 .18948 .67423 .18649 Metetra
.664 .741 .907 r
.67423 .18649 .67638 .18948 .6809 .18786 .67874 .18487 Metetra
.664 .741 .907 r
.67874 .18487 .6809 .18786 .68542 .18624 .68327 .18324 Metetra
.664 .741 .907 r
.68327 .18324 .68542 .18624 .68994 .18462 .6878 .18161 Metetra
.664 .741 .907 r
.6878 .18161 .68994 .18462 .69448 .18299 .69234 .17998 Metetra
.664 .741 .907 r
.69234 .17998 .69448 .18299 .69902 .18136 .69689 .17834 Metetra
.664 .741 .907 r
.69689 .17834 .69902 .18136 .70357 .17973 .70144 .17671 Metetra
.664 .741 .907 r
.70144 .17671 .70357 .17973 .70813 .17809 .706 .17507 Metetra
.664 .741 .907 r
.706 .17507 .70813 .17809 .71269 .17645 .71057 .17342 Metetra
.664 .741 .907 r
.71057 .17342 .71269 .17645 .71726 .17481 .71515 .17178 Metetra
.664 .741 .907 r
.71515 .17178 .71726 .17481 .72184 .17317 .71973 .17013 Metetra
.664 .741 .907 r
.71973 .17013 .72184 .17317 .72643 .17152 .72432 .16848 Metetra
.664 .741 .907 r
.72432 .16848 .72643 .17152 .73102 .16988 .72892 .16683 Metetra
.664 .741 .907 r
.72892 .16683 .73102 .16988 .73562 .16822 .73353 .16517 Metetra
.664 .741 .907 r
.73353 .16517 .73562 .16822 .74023 .16657 .73814 .16351 Metetra
.664 .741 .907 r
.73814 .16351 .74023 .16657 .74484 .16491 .74276 .16185 Metetra
.664 .741 .907 r
.74276 .16185 .74484 .16491 .74947 .16325 .74739 .16018 Metetra
.664 .741 .907 r
.74739 .16018 .74947 .16325 .7541 .16159 .75203 .15852 Metetra
.664 .741 .907 r
.75203 .15852 .7541 .16159 .75874 .15993 .75667 .15685 Metetra
.664 .741 .907 r
.75667 .15685 .75874 .15993 .76338 .15826 .76132 .15518 Metetra
.664 .741 .907 r
.76132 .15518 .76338 .15826 .76803 .15659 .76598 .1535 Metetra
.664 .741 .907 r
.76598 .1535 .76803 .15659 .77269 .15492 .77065 .15182 Metetra
.664 .741 .907 r
.77065 .15182 .77269 .15492 .77736 .15324 .77532 .15014 Metetra
.664 .741 .907 r
.77532 .15014 .77736 .15324 .78204 .15157 .78 .14846 Metetra
.664 .741 .907 r
.78 .14846 .78204 .15157 .78672 .14988 .78469 .14677 Metetra
.664 .741 .907 r
.15852 .36848 .16118 .37096 .16491 .36962 .16226 .36714 Metetra
.664 .741 .907 r
.16226 .36714 .16491 .36962 .16865 .36828 .166 .36579 Metetra
.664 .741 .907 r
.166 .36579 .16865 .36828 .1724 .36693 .16975 .36444 Metetra
.664 .741 .907 r
.16975 .36444 .1724 .36693 .17615 .36558 .17351 .36309 Metetra
.664 .741 .907 r
.17351 .36309 .17615 .36558 .17991 .36423 .17727 .36173 Metetra
.664 .741 .907 r
.17727 .36173 .17991 .36423 .18367 .36288 .18103 .36038 Metetra
.664 .741 .907 r
.18103 .36038 .18367 .36288 .18743 .36152 .1848 .35902 Metetra
.664 .741 .907 r
.1848 .35902 .18743 .36152 .19121 .36017 .18858 .35766 Metetra
.664 .741 .907 r
.18858 .35766 .19121 .36017 .19499 .35881 .19236 .3563 Metetra
.664 .741 .907 r
.19236 .3563 .19499 .35881 .19877 .35745 .19614 .35493 Metetra
.664 .741 .907 r
.19614 .35493 .19877 .35745 .20256 .35609 .19994 .35357 Metetra
.664 .741 .907 r
.19994 .35357 .20256 .35609 .20635 .35472 .20373 .3522 Metetra
.664 .741 .907 r
.20373 .3522 .20635 .35472 .21015 .35336 .20754 .35083 Metetra
.664 .741 .907 r
.20754 .35083 .21015 .35336 .21396 .35199 .21135 .34946 Metetra
.664 .741 .907 r
.21135 .34946 .21396 .35199 .21777 .35062 .21516 .34808 Metetra
.664 .741 .907 r
.21516 .34808 .21777 .35062 .22159 .34924 .21898 .3467 Metetra
.664 .741 .907 r
.21898 .3467 .22159 .34924 .22541 .34787 .22281 .34533 Metetra
.664 .741 .907 r
.22281 .34533 .22541 .34787 .22924 .34649 .22664 .34395 Metetra
.664 .741 .907 r
.22664 .34395 .22924 .34649 .23307 .34511 .23048 .34256 Metetra
.664 .741 .907 r
.23048 .34256 .23307 .34511 .23691 .34373 .23432 .34118 Metetra
.664 .741 .907 r
.23432 .34118 .23691 .34373 .24076 .34235 .23817 .33979 Metetra
.664 .741 .907 r
.23817 .33979 .24076 .34235 .24461 .34097 .24202 .3384 Metetra
.664 .741 .907 r
.24202 .3384 .24461 .34097 .24847 .33958 .24588 .33701 Metetra
.664 .741 .907 r
.24588 .33701 .24847 .33958 .25233 .33819 .24975 .33562 Metetra
.664 .741 .907 r
.24975 .33562 .25233 .33819 .2562 .3368 .25362 .33423 Metetra
.664 .741 .907 r
.25362 .33423 .2562 .3368 .26007 .33541 .2575 .33283 Metetra
.664 .741 .907 r
.2575 .33283 .26007 .33541 .26395 .33401 .26138 .33143 Metetra
.664 .741 .907 r
.26138 .33143 .26395 .33401 .26783 .33262 .26527 .33003 Metetra
.664 .741 .907 r
.26527 .33003 .26783 .33262 .27173 .33122 .26916 .32863 Metetra
.664 .741 .907 r
.26916 .32863 .27173 .33122 .27562 .32981 .27306 .32722 Metetra
.664 .741 .907 r
.27306 .32722 .27562 .32981 .27953 .32841 .27697 .32582 Metetra
.664 .741 .907 r
.27697 .32582 .27953 .32841 .28343 .32701 .28088 .32441 Metetra
.664 .741 .907 r
.28088 .32441 .28343 .32701 .28735 .3256 .2848 .323 Metetra
.951 .682 .49 r
.2848 .323 .28735 .3256 .29127 .32419 .27138 .55243 Metetra
.522 .291 .505 r
.27138 .55243 .29127 .32419 .27834 .55356 .27562 .55068 Metetra
.946 .703 .539 r
.27562 .55068 .27834 .55356 .28428 .52811 .28426 .48837 Metetra
.738 .5 .569 r
.28426 .48837 .28428 .52811 .2918 .47958 .29049 .45784 Metetra
.756 .531 .59 r
.29049 .45784 .2918 .47958 .29765 .45338 .29586 .43864 Metetra
.765 .554 .612 r
.29586 .43864 .29765 .45338 .30285 .43614 .30081 .42495 Metetra
.768 .572 .633 r
.30081 .42495 .30285 .43614 .3077 .42354 .30552 .41444 Metetra
.769 .588 .654 r
.30552 .41444 .3077 .42354 .31234 .4137 .31008 .40595 Metetra
.769 .603 .673 r
.31008 .40595 .31234 .4137 .31686 .40565 .31454 .39884 Metetra
.767 .615 .691 r
.31454 .39884 .31686 .40565 .32129 .39886 .31892 .39271 Metetra
.764 .627 .708 r
.31892 .39271 .32129 .39886 .32565 .39296 .32326 .38732 Metetra
.76 .636 .724 r
.32326 .38732 .32565 .39296 .32997 .38775 .32756 .3825 Metetra
.757 .645 .738 r
.32756 .3825 .32997 .38775 .33425 .38307 .33182 .37813 Metetra
.753 .653 .751 r
.33182 .37813 .33425 .38307 .33851 .37881 .33607 .37411 Metetra
.749 .66 .762 r
.33607 .37411 .33851 .37881 .34274 .37489 .3403 .37039 Metetra
.745 .666 .773 r
.3403 .37039 .34274 .37489 .34697 .37125 .34451 .36692 Metetra
.741 .671 .782 r
.34451 .36692 .34697 .37125 .35117 .36784 .34872 .36365 Metetra
.737 .676 .791 r
.34872 .36365 .35117 .36784 .35537 .36463 .35291 .36056 Metetra
.733 .68 .799 r
.35291 .36056 .35537 .36463 .35956 .36159 .3571 .35761 Metetra
.73 .683 .806 r
.3571 .35761 .35956 .36159 .36375 .35869 .36129 .3548 Metetra
.726 .687 .812 r
.36129 .3548 .36375 .35869 .36793 .35592 .36547 .35211 Metetra
.723 .69 .818 r
.36547 .35211 .36793 .35592 .37212 .35326 .36965 .34951 Metetra
.72 .692 .823 r
.36965 .34951 .37212 .35326 .37629 .3507 .37383 .34701 Metetra
.716 .695 .828 r
.37383 .34701 .37629 .3507 .38047 .34822 .37801 .34458 Metetra
.713 .697 .833 r
.37801 .34458 .38047 .34822 .38465 .34582 .38219 .34223 Metetra
.71 .698 .837 r
.38219 .34223 .38465 .34582 .38883 .34349 .38637 .33994 Metetra
.708 .7 .84 r
.38637 .33994 .38883 .34349 .39301 .34123 .39055 .33771 Metetra
.705 .701 .844 r
.39055 .33771 .39301 .34123 .3972 .33902 .39474 .33553 Metetra
.703 .703 .847 r
.39474 .33553 .3972 .33902 .40138 .33687 .39893 .33341 Metetra
.7 .704 .85 r
.39893 .33341 .40138 .33687 .40557 .33476 .40312 .33132 Metetra
.698 .705 .853 r
.40312 .33132 .40557 .33476 .40976 .3327 .40731 .32928 Metetra
.695 .705 .855 r
.40731 .32928 .40976 .3327 .41395 .33068 .41151 .32728 Metetra
.693 .706 .858 r
.41151 .32728 .41395 .33068 .41815 .3287 .41571 .32531 Metetra
.691 .707 .86 r
.41571 .32531 .41815 .3287 .42235 .32675 .41991 .32338 Metetra
.689 .707 .862 r
.41991 .32338 .42235 .32675 .42656 .32484 .42412 .32148 Metetra
.687 .708 .864 r
.42412 .32148 .42656 .32484 .43077 .32295 .42834 .31961 Metetra
.685 .708 .865 r
.42834 .31961 .43077 .32295 .43499 .3211 .43255 .31777 Metetra
.683 .708 .867 r
.43255 .31777 .43499 .3211 .43921 .31928 .43678 .31595 Metetra
.936 .732 .602 r
.43678 .31595 .43921 .31928 .44343 .31749 .44144 .29801 Metetra
.568 .392 .603 r
.44144 .29801 .44343 .31749 .44806 .29961 .44564 .29649 Metetra
.661 .715 .888 r
.44564 .29649 .44806 .29961 .45226 .29811 .44985 .29498 Metetra
.66 .714 .889 r
.44985 .29498 .45226 .29811 .45648 .29662 .45407 .29348 Metetra
.658 .714 .889 r
.45407 .29348 .45648 .29662 .4607 .29514 .45829 .292 Metetra
.657 .713 .89 r
.45829 .292 .4607 .29514 .46461 .31006 .46252 .29054 Metetra
.024 .001 .489 r
.46252 .29054 .46461 .31006 .46886 .30888 .46645 .30552 Metetra
.628 .688 .887 r
.46645 .30552 .46886 .30888 .47311 .30773 .47071 .30436 Metetra
.625 .686 .887 r
.47071 .30436 .47311 .30773 .47738 .30662 .47498 .30322 Metetra
.623 .684 .887 r
.47498 .30322 .47738 .30662 .48165 .30553 .47926 .30212 Metetra
.62 .682 .887 r
.47926 .30212 .48165 .30553 .48593 .30447 .48354 .30104 Metetra
.616 .679 .887 r
.48354 .30104 .48593 .30447 .49021 .30345 .48783 .3 Metetra
.613 .677 .887 r
.48783 .3 .49021 .30345 .49451 .30247 .49212 .29899 Metetra
.609 .674 .886 r
.49212 .29899 .49451 .30247 .49881 .30152 .49643 .29801 Metetra
.606 .67 .886 r
.49643 .29801 .49881 .30152 .50312 .30062 .50074 .29708 Metetra
.601 .667 .885 r
.50074 .29708 .50312 .30062 .50744 .29976 .50506 .29619 Metetra
.597 .663 .885 r
.50506 .29619 .50744 .29976 .51176 .29895 .50939 .29534 Metetra
.592 .659 .884 r
.50939 .29534 .51176 .29895 .5161 .2982 .51373 .29455 Metetra
.587 .654 .883 r
.51373 .29455 .5161 .2982 .52044 .2975 .51808 .29381 Metetra
.581 .649 .882 r
.51808 .29381 .52044 .2975 .5248 .29687 .52243 .29313 Metetra
.575 .643 .88 r
.52243 .29313 .5248 .29687 .52916 .29631 .5268 .29252 Metetra
.568 .636 .879 r
.5268 .29252 .52916 .29631 .53353 .29583 .53117 .29198 Metetra
.56 .629 .877 r
.53117 .29198 .53353 .29583 .53791 .29544 .53556 .29152 Metetra
.551 .621 .875 r
.53556 .29152 .53791 .29544 .54231 .29515 .53995 .29115 Metetra
.542 .612 .872 r
.53995 .29115 .54231 .29515 .54671 .29498 .54436 .29089 Metetra
.531 .601 .869 r
.54436 .29089 .54671 .29498 .55113 .29493 .54878 .29075 Metetra
.519 .589 .865 r
.54878 .29075 .55113 .29493 .55556 .29503 .55321 .29074 Metetra
.505 .576 .861 r
.55321 .29074 .55556 .29503 .56 .29531 .55765 .29088 Metetra
.489 .56 .855 r
.55765 .29088 .56 .29531 .56446 .29579 .56211 .29121 Metetra
.47 .542 .848 r
.56211 .29121 .56446 .29579 .56893 .2965 .56658 .29174 Metetra
.449 .521 .84 r
.56658 .29174 .56893 .2965 .57343 .29751 .57107 .29253 Metetra
.424 .496 .829 r
.57107 .29253 .57343 .29751 .57794 .29886 .57558 .29363 Metetra
.394 .466 .816 r
.57558 .29363 .57794 .29886 .58248 .30065 .58011 .29509 Metetra
.359 .431 .8 r
.58011 .29509 .58248 .30065 .58704 .30298 .58466 .29701 Metetra
.317 .389 .779 r
.58466 .29701 .58704 .30298 .59164 .30601 .58925 .29952 Metetra
.267 .338 .752 r
.58925 .29952 .59164 .30601 .59628 .30997 .59387 .30278 Metetra
.207 .278 .717 r
.59387 .30278 .59628 .30997 .60097 .31521 .59853 .30706 Metetra
.135 .206 .673 r
.59853 .30706 .60097 .31521 .60574 .32231 .60326 .31276 Metetra
.051 .121 .617 r
.60326 .31276 .60574 .32231 .61062 .33224 .60807 .32054 Metetra
0 .023 .548 r
.60807 .32054 .61062 .33224 .61568 .34695 .613 .33159 Metetra
0 0 .465 r
.613 .33159 .61568 .34695 .62107 .37091 .61815 .34833 Metetra
0 0 .368 r
.61815 .34833 .62107 .37091 .62727 .41791 .62372 .37674 Metetra
0 0 .254 r
.62372 .37674 .62727 .41791 .63284 .44126 .63045 .43802 Metetra
.607 .713 .92 r
.63045 .43802 .63284 .44126 .62944 .2026 .63526 .43693 Metetra
0 0 .348 r
.63526 .43693 .62944 .2026 .63389 .201 .63168 .19804 Metetra
.664 .741 .907 r
.63168 .19804 .63389 .201 .63834 .1994 .63614 .19643 Metetra
.664 .741 .907 r
.63614 .19643 .63834 .1994 .6428 .19779 .6406 .19482 Metetra
.664 .741 .907 r
.6406 .19482 .6428 .19779 .64727 .19618 .64508 .19321 Metetra
.664 .741 .907 r
.64508 .19321 .64727 .19618 .65174 .19458 .64956 .1916 Metetra
.664 .741 .907 r
.64956 .1916 .65174 .19458 .65623 .19296 .65404 .18998 Metetra
.664 .741 .907 r
.65404 .18998 .65623 .19296 .66072 .19135 .65854 .18836 Metetra
.664 .741 .907 r
.65854 .18836 .66072 .19135 .66521 .18973 .66304 .18674 Metetra
.664 .741 .907 r
.66304 .18674 .66521 .18973 .66972 .18811 .66755 .18512 Metetra
.664 .741 .907 r
.66755 .18512 .66972 .18811 .67423 .18649 .67206 .18349 Metetra
.664 .741 .907 r
.67206 .18349 .67423 .18649 .67874 .18487 .67659 .18186 Metetra
.664 .741 .907 r
.67659 .18186 .67874 .18487 .68327 .18324 .68112 .18023 Metetra
.664 .741 .907 r
.68112 .18023 .68327 .18324 .6878 .18161 .68565 .1786 Metetra
.664 .741 .907 r
.68565 .1786 .6878 .18161 .69234 .17998 .6902 .17696 Metetra
.664 .741 .907 r
.6902 .17696 .69234 .17998 .69689 .17834 .69475 .17532 Metetra
.664 .741 .907 r
.69475 .17532 .69689 .17834 .70144 .17671 .69931 .17368 Metetra
.664 .741 .907 r
.69931 .17368 .70144 .17671 .706 .17507 .70388 .17203 Metetra
.664 .741 .907 r
.70388 .17203 .706 .17507 .71057 .17342 .70845 .17038 Metetra
.664 .741 .907 r
.70845 .17038 .71057 .17342 .71515 .17178 .71303 .16873 Metetra
.664 .741 .907 r
.71303 .16873 .71515 .17178 .71973 .17013 .71762 .16708 Metetra
.664 .741 .907 r
.71762 .16708 .71973 .17013 .72432 .16848 .72222 .16542 Metetra
.664 .741 .907 r
.72222 .16542 .72432 .16848 .72892 .16683 .72682 .16377 Metetra
.664 .741 .907 r
.72682 .16377 .72892 .16683 .73353 .16517 .73143 .1621 Metetra
.664 .741 .907 r
.73143 .1621 .73353 .16517 .73814 .16351 .73605 .16044 Metetra
.664 .741 .907 r
.73605 .16044 .73814 .16351 .74276 .16185 .74068 .15877 Metetra
.664 .741 .907 r
.74068 .15877 .74276 .16185 .74739 .16018 .74531 .15711 Metetra
.664 .741 .907 r
.74531 .15711 .74739 .16018 .75203 .15852 .74995 .15543 Metetra
.664 .741 .907 r
.74995 .15543 .75203 .15852 .75667 .15685 .7546 .15376 Metetra
.664 .741 .907 r
.7546 .15376 .75667 .15685 .76132 .15518 .75925 .15208 Metetra
.664 .741 .907 r
.75925 .15208 .76132 .15518 .76598 .1535 .76392 .1504 Metetra
.664 .741 .907 r
.76392 .1504 .76598 .1535 .77065 .15182 .76859 .14872 Metetra
.664 .741 .907 r
.76859 .14872 .77065 .15182 .77532 .15014 .77327 .14703 Metetra
.664 .741 .907 r
.77327 .14703 .77532 .15014 .78 .14846 .77796 .14535 Metetra
.664 .741 .907 r
.77796 .14535 .78 .14846 .78469 .14677 .78265 .14365 Metetra
.664 .741 .907 r
.15586 .366 .15852 .36848 .16226 .36714 .1596 .36465 Metetra
.664 .741 .907 r
.1596 .36465 .16226 .36714 .166 .36579 .16335 .3633 Metetra
.664 .741 .907 r
.16335 .3633 .166 .36579 .16975 .36444 .1671 .36194 Metetra
.664 .741 .907 r
.1671 .36194 .16975 .36444 .17351 .36309 .17086 .36059 Metetra
.664 .741 .907 r
.17086 .36059 .17351 .36309 .17727 .36173 .17462 .35923 Metetra
.664 .741 .907 r
.17462 .35923 .17727 .36173 .18103 .36038 .17839 .35787 Metetra
.664 .741 .907 r
.17839 .35787 .18103 .36038 .1848 .35902 .18216 .35651 Metetra
.664 .741 .907 r
.18216 .35651 .1848 .35902 .18858 .35766 .18594 .35514 Metetra
.664 .741 .907 r
.18594 .35514 .18858 .35766 .19236 .3563 .18972 .35378 Metetra
.664 .741 .907 r
.18972 .35378 .19236 .3563 .19614 .35493 .19351 .35241 Metetra
.664 .741 .907 r
.19351 .35241 .19614 .35493 .19994 .35357 .19731 .35104 Metetra
.664 .741 .907 r
.19731 .35104 .19994 .35357 .20373 .3522 .20111 .34967 Metetra
.664 .741 .907 r
.20111 .34967 .20373 .3522 .20754 .35083 .20492 .34829 Metetra
.664 .741 .907 r
.20492 .34829 .20754 .35083 .21135 .34946 .20873 .34692 Metetra
.664 .741 .907 r
.20873 .34692 .21135 .34946 .21516 .34808 .21255 .34554 Metetra
.664 .741 .907 r
.21255 .34554 .21516 .34808 .21898 .3467 .21637 .34416 Metetra
.664 .741 .907 r
.21637 .34416 .21898 .3467 .22281 .34533 .2202 .34278 Metetra
.664 .741 .907 r
.2202 .34278 .22281 .34533 .22664 .34395 .22403 .34139 Metetra
.664 .741 .907 r
.22403 .34139 .22664 .34395 .23048 .34256 .22788 .34001 Metetra
.664 .741 .907 r
.22788 .34001 .23048 .34256 .23432 .34118 .23172 .33862 Metetra
.664 .741 .907 r
.23172 .33862 .23432 .34118 .23817 .33979 .23557 .33723 Metetra
.664 .741 .907 r
.23557 .33723 .23817 .33979 .24202 .3384 .23943 .33584 Metetra
.664 .741 .907 r
.23943 .33584 .24202 .3384 .24588 .33701 .24329 .33444 Metetra
.664 .741 .907 r
.24329 .33444 .24588 .33701 .24975 .33562 .24716 .33305 Metetra
.664 .741 .907 r
.24716 .33305 .24975 .33562 .25362 .33423 .25104 .33165 Metetra
.664 .741 .907 r
.25104 .33165 .25362 .33423 .2575 .33283 .25492 .33025 Metetra
.664 .741 .907 r
.25492 .33025 .2575 .33283 .26138 .33143 .25881 .32884 Metetra
.664 .741 .907 r
.25881 .32884 .26138 .33143 .26527 .33003 .2627 .32744 Metetra
.664 .741 .907 r
.2627 .32744 .26527 .33003 .26916 .32863 .2666 .32603 Metetra
.664 .741 .907 r
.2666 .32603 .26916 .32863 .27306 .32722 .2705 .32462 Metetra
.664 .741 .907 r
.2705 .32462 .27306 .32722 .27697 .32582 .27441 .32321 Metetra
.664 .741 .907 r
.27441 .32321 .27697 .32582 .28088 .32441 .27832 .3218 Metetra
.664 .741 .907 r
.27832 .3218 .28088 .32441 .2848 .323 .28225 .32038 Metetra
.951 .682 .49 r
.28225 .32038 .2848 .323 .27138 .55243 .26862 .54996 Metetra
.946 .708 .548 r
.26862 .54996 .27138 .55243 .27562 .55068 .27652 .49928 Metetra
.727 .487 .563 r
.27652 .49928 .27562 .55068 .28426 .48837 .28324 .4631 Metetra
.752 .522 .584 r
.28324 .4631 .28426 .48837 .29049 .45784 .28882 .44152 Metetra
.762 .547 .605 r
.28882 .44152 .29049 .45784 .29586 .43864 .29388 .42658 Metetra
.767 .567 .627 r
.29388 .42658 .29586 .43864 .30081 .42495 .29867 .41532 Metetra
.769 .583 .648 r
.29867 .41532 .30081 .42495 .30552 .41444 .30328 .40633 Metetra
.768 .598 .668 r
.30328 .40633 .30552 .41444 .31008 .40595 .30777 .39888 Metetra
.767 .611 .686 r
.30777 .39888 .31008 .40595 .31454 .39884 .31218 .3925 Metetra
.764 .623 .703 r
.31218 .3925 .31454 .39884 .31892 .39271 .31654 .38692 Metetra
.761 .633 .719 r
.31654 .38692 .31892 .39271 .32326 .38732 .32085 .38195 Metetra
.758 .642 .734 r
.32085 .38195 .32326 .38732 .32756 .3825 .32513 .37746 Metetra
.754 .65 .747 r
.32513 .37746 .32756 .3825 .33182 .37813 .32938 .37335 Metetra
.75 .658 .759 r
.32938 .37335 .33182 .37813 .33607 .37411 .33362 .36955 Metetra
.746 .664 .77 r
.33362 .36955 .33607 .37411 .3403 .37039 .33784 .36601 Metetra
.742 .669 .779 r
.33784 .36601 .3403 .37039 .34451 .36692 .34205 .36268 Metetra
.738 .674 .788 r
.34205 .36268 .34451 .36692 .34872 .36365 .34625 .35954 Metetra
.734 .679 .796 r
.34625 .35954 .34872 .36365 .35291 .36056 .35044 .35655 Metetra
.731 .682 .804 r
.35044 .35655 .35291 .36056 .3571 .35761 .35463 .3537 Metetra
.727 .686 .81 r
.35463 .3537 .3571 .35761 .36129 .3548 .35881 .35097 Metetra
.724 .689 .816 r
.35881 .35097 .36129 .3548 .36547 .35211 .363 .34834 Metetra
.721 .692 .822 r
.363 .34834 .36547 .35211 .36965 .34951 .36718 .34581 Metetra
.717 .694 .827 r
.36718 .34581 .36965 .34951 .37383 .34701 .37136 .34335 Metetra
.714 .696 .831 r
.37136 .34335 .37383 .34701 .37801 .34458 .37554 .34098 Metetra
.712 .698 .836 r
.37554 .34098 .37801 .34458 .38219 .34223 .37972 .33866 Metetra
.709 .7 .839 r
.37972 .33866 .38219 .34223 .38637 .33994 .3839 .33641 Metetra
.706 .701 .843 r
.3839 .33641 .38637 .33994 .39055 .33771 .38809 .33421 Metetra
.704 .703 .846 r
.38809 .33421 .39055 .33771 .39474 .33553 .39228 .33206 Metetra
.701 .704 .849 r
.39228 .33206 .39474 .33553 .39893 .33341 .39647 .32996 Metetra
.699 .705 .852 r
.39647 .32996 .39893 .33341 .40312 .33132 .40066 .3279 Metetra
.697 .706 .855 r
.40066 .3279 .40312 .33132 .40731 .32928 .40485 .32588 Metetra
.694 .706 .857 r
.40485 .32588 .40731 .32928 .41151 .32728 .40905 .32389 Metetra
.692 .707 .859 r
.40905 .32389 .41151 .32728 .41571 .32531 .41326 .32194 Metetra
.69 .708 .861 r
.41326 .32194 .41571 .32531 .41991 .32338 .41747 .32002 Metetra
.688 .708 .863 r
.41747 .32002 .41991 .32338 .42412 .32148 .42168 .31814 Metetra
.686 .708 .865 r
.42168 .31814 .42412 .32148 .42834 .31961 .4259 .31627 Metetra
.684 .709 .867 r
.4259 .31627 .42834 .31961 .43255 .31777 .43012 .31444 Metetra
.936 .731 .602 r
.43012 .31444 .43255 .31777 .43678 .31595 .43481 .29643 Metetra
.568 .392 .602 r
.43481 .29643 .43678 .31595 .44144 .29801 .43901 .29489 Metetra
.663 .716 .888 r
.43901 .29489 .44144 .29801 .44564 .29649 .44322 .29337 Metetra
.661 .716 .889 r
.44322 .29337 .44564 .29649 .44985 .29498 .44744 .29185 Metetra
.66 .715 .889 r
.44744 .29185 .44985 .29498 .45407 .29348 .45166 .29035 Metetra
.658 .715 .89 r
.45166 .29035 .45407 .29348 .45829 .292 .45589 .28887 Metetra
.657 .714 .89 r
.45589 .28887 .45829 .292 .46252 .29054 .46012 .2874 Metetra
.656 .713 .891 r
.46012 .2874 .46252 .29054 .46645 .30552 .46436 .28594 Metetra
.022 0 .488 r
.46436 .28594 .46645 .30552 .47071 .30436 .46831 .30099 Metetra
.627 .688 .888 r
.46831 .30099 .47071 .30436 .47498 .30322 .47258 .29984 Metetra
.624 .686 .888 r
.47258 .29984 .47498 .30322 .47926 .30212 .47686 .29871 Metetra
.621 .684 .888 r
.47686 .29871 .47926 .30212 .48354 .30104 .48114 .29761 Metetra
.618 .681 .887 r
.48114 .29761 .48354 .30104 .48783 .3 .48543 .29655 Metetra
.615 .679 .887 r
.48543 .29655 .48783 .3 .49212 .29899 .48973 .29551 Metetra
.611 .676 .887 r
.48973 .29551 .49212 .29899 .49643 .29801 .49404 .29451 Metetra
.608 .673 .887 r
.49404 .29451 .49643 .29801 .50074 .29708 .49836 .29355 Metetra
.604 .669 .886 r
.49836 .29355 .50074 .29708 .50506 .29619 .50268 .29263 Metetra
.6 .666 .885 r
.50268 .29263 .50506 .29619 .50939 .29534 .50701 .29175 Metetra
.595 .662 .885 r
.50701 .29175 .50939 .29534 .51373 .29455 .51136 .29092 Metetra
.59 .657 .884 r
.51136 .29092 .51373 .29455 .51808 .29381 .51571 .29014 Metetra
.585 .652 .883 r
.51571 .29014 .51808 .29381 .52243 .29313 .52006 .28941 Metetra
.579 .647 .882 r
.52006 .28941 .52243 .29313 .5268 .29252 .52443 .28875 Metetra
.573 .641 .88 r
.52443 .28875 .5268 .29252 .53117 .29198 .52881 .28815 Metetra
.565 .634 .879 r
.52881 .28815 .53117 .29198 .53556 .29152 .5332 .28763 Metetra
.557 .627 .876 r
.5332 .28763 .53556 .29152 .53995 .29115 .53759 .2872 Metetra
.549 .618 .874 r
.53759 .2872 .53995 .29115 .54436 .29089 .542 .28685 Metetra
.539 .609 .871 r
.542 .28685 .54436 .29089 .54878 .29075 .54642 .28662 Metetra
.528 .598 .868 r
.54642 .28662 .54878 .29075 .55321 .29074 .55085 .28651 Metetra
.515 .586 .864 r
.55085 .28651 .55321 .29074 .55765 .29088 .55529 .28653 Metetra
.5 .571 .859 r
.55529 .28653 .55765 .29088 .56211 .29121 .55975 .28672 Metetra
.484 .555 .853 r
.55975 .28672 .56211 .29121 .56658 .29174 .56422 .2871 Metetra
.465 .536 .846 r
.56422 .2871 .56658 .29174 .57107 .29253 .56871 .2877 Metetra
.442 .514 .837 r
.56871 .2877 .57107 .29253 .57558 .29363 .57321 .28856 Metetra
.416 .488 .826 r
.57321 .28856 .57558 .29363 .58011 .29509 .57774 .28975 Metetra
.385 .457 .812 r
.57774 .28975 .58011 .29509 .58466 .29701 .58229 .29132 Metetra
.348 .42 .794 r
.58229 .29132 .58466 .29701 .58925 .29952 .58686 .29339 Metetra
.304 .376 .771 r
.58686 .29339 .58925 .29952 .59387 .30278 .59146 .29608 Metetra
.252 .323 .742 r
.59146 .29608 .59387 .30278 .59853 .30706 .59611 .2996 Metetra
.189 .259 .705 r
.59611 .2996 .59853 .30706 .60326 .31276 .6008 .30423 Metetra
.115 .184 .658 r
.6008 .30423 .60326 .31276 .60807 .32054 .60556 .31043 Metetra
.028 .095 .599 r
.60556 .31043 .60807 .32054 .613 .33159 .61041 .31897 Metetra
0 0 .526 r
.61041 .31897 .613 .33159 .61815 .34833 .61541 .33131 Metetra
0 0 .44 r
.61541 .33131 .61815 .34833 .62372 .37674 .62066 .3505 Metetra
0 0 .34 r
.62066 .3505 .62372 .37674 .63045 .43802 .62647 .38476 Metetra
0 0 .422 r
.62647 .38476 .63045 .43802 .63526 .43693 .63288 .43411 Metetra
.977 .688 .399 r
.63288 .43411 .63526 .43693 .63168 .19804 .62947 .19507 Metetra
.664 .741 .907 r
.62947 .19507 .63168 .19804 .63614 .19643 .63393 .19346 Metetra
.664 .741 .907 r
.63393 .19346 .63614 .19643 .6406 .19482 .6384 .19185 Metetra
.664 .741 .907 r
.6384 .19185 .6406 .19482 .64508 .19321 .64288 .19023 Metetra
.664 .741 .907 r
.64288 .19023 .64508 .19321 .64956 .1916 .64736 .18861 Metetra
.664 .741 .907 r
.64736 .18861 .64956 .1916 .65404 .18998 .65185 .18699 Metetra
.664 .741 .907 r
.65185 .18699 .65404 .18998 .65854 .18836 .65635 .18537 Metetra
.664 .741 .907 r
.65635 .18537 .65854 .18836 .66304 .18674 .66086 .18374 Metetra
.664 .741 .907 r
.66086 .18374 .66304 .18674 .66755 .18512 .66537 .18211 Metetra
.664 .741 .907 r
.66537 .18211 .66755 .18512 .67206 .18349 .66989 .18048 Metetra
.664 .741 .907 r
.66989 .18048 .67206 .18349 .67659 .18186 .67442 .17885 Metetra
.664 .741 .907 r
.67442 .17885 .67659 .18186 .68112 .18023 .67896 .17721 Metetra
.664 .741 .907 r
.67896 .17721 .68112 .18023 .68565 .1786 .6835 .17557 Metetra
.664 .741 .907 r
.6835 .17557 .68565 .1786 .6902 .17696 .68805 .17393 Metetra
.664 .741 .907 r
.68805 .17393 .6902 .17696 .69475 .17532 .6926 .17228 Metetra
.664 .741 .907 r
.6926 .17228 .69475 .17532 .69931 .17368 .69717 .17064 Metetra
.664 .741 .907 r
.69717 .17064 .69931 .17368 .70388 .17203 .70174 .16899 Metetra
.664 .741 .907 r
.70174 .16899 .70388 .17203 .70845 .17038 .70632 .16733 Metetra
.664 .741 .907 r
.70632 .16733 .70845 .17038 .71303 .16873 .71091 .16568 Metetra
.664 .741 .907 r
.71091 .16568 .71303 .16873 .71762 .16708 .7155 .16402 Metetra
.664 .741 .907 r
.7155 .16402 .71762 .16708 .72222 .16542 .7201 .16236 Metetra
.664 .741 .907 r
.7201 .16236 .72222 .16542 .72682 .16377 .72471 .1607 Metetra
.664 .741 .907 r
.72471 .1607 .72682 .16377 .73143 .1621 .72933 .15903 Metetra
.664 .741 .907 r
.72933 .15903 .73143 .1621 .73605 .16044 .73395 .15736 Metetra
.664 .741 .907 r
.73395 .15736 .73605 .16044 .74068 .15877 .73858 .15569 Metetra
.664 .741 .907 r
.73858 .15569 .74068 .15877 .74531 .15711 .74322 .15402 Metetra
.664 .741 .907 r
.74322 .15402 .74531 .15711 .74995 .15543 .74787 .15234 Metetra
.664 .741 .907 r
.74787 .15234 .74995 .15543 .7546 .15376 .75252 .15066 Metetra
.664 .741 .907 r
.75252 .15066 .7546 .15376 .75925 .15208 .75718 .14898 Metetra
.664 .741 .907 r
.75718 .14898 .75925 .15208 .76392 .1504 .76185 .14729 Metetra
.664 .741 .907 r
.76185 .14729 .76392 .1504 .76859 .14872 .76653 .14561 Metetra
.664 .741 .907 r
.76653 .14561 .76859 .14872 .77327 .14703 .77121 .14391 Metetra
.664 .741 .907 r
.77121 .14391 .77327 .14703 .77796 .14535 .7759 .14222 Metetra
.664 .741 .907 r
.7759 .14222 .77796 .14535 .78265 .14365 .7806 .14053 Metetra
.664 .741 .907 r
.15319 .3635 .15586 .366 .1596 .36465 .15693 .36215 Metetra
.664 .741 .907 r
.15693 .36215 .1596 .36465 .16335 .3633 .16068 .36079 Metetra
.664 .741 .907 r
.16068 .36079 .16335 .3633 .1671 .36194 .16444 .35944 Metetra
.664 .741 .907 r
.16444 .35944 .1671 .36194 .17086 .36059 .1682 .35808 Metetra
.664 .741 .907 r
.1682 .35808 .17086 .36059 .17462 .35923 .17196 .35672 Metetra
.664 .741 .907 r
.17196 .35672 .17462 .35923 .17839 .35787 .17573 .35535 Metetra
.664 .741 .907 r
.17573 .35535 .17839 .35787 .18216 .35651 .17951 .35399 Metetra
.664 .741 .907 r
.17951 .35399 .18216 .35651 .18594 .35514 .18329 .35262 Metetra
.664 .741 .907 r
.18329 .35262 .18594 .35514 .18972 .35378 .18708 .35125 Metetra
.664 .741 .907 r
.18708 .35125 .18972 .35378 .19351 .35241 .19087 .34988 Metetra
.664 .741 .907 r
.19087 .34988 .19351 .35241 .19731 .35104 .19467 .3485 Metetra
.664 .741 .907 r
.19467 .3485 .19731 .35104 .20111 .34967 .19848 .34713 Metetra
.664 .741 .907 r
.19848 .34713 .20111 .34967 .20492 .34829 .20229 .34575 Metetra
.664 .741 .907 r
.20229 .34575 .20492 .34829 .20873 .34692 .2061 .34437 Metetra
.664 .741 .907 r
.2061 .34437 .20873 .34692 .21255 .34554 .20992 .34299 Metetra
.664 .741 .907 r
.20992 .34299 .21255 .34554 .21637 .34416 .21375 .34161 Metetra
.664 .741 .907 r
.21375 .34161 .21637 .34416 .2202 .34278 .21758 .34022 Metetra
.664 .741 .907 r
.21758 .34022 .2202 .34278 .22403 .34139 .22142 .33883 Metetra
.664 .741 .907 r
.22142 .33883 .22403 .34139 .22788 .34001 .22527 .33744 Metetra
.664 .741 .907 r
.22527 .33744 .22788 .34001 .23172 .33862 .22912 .33605 Metetra
.664 .741 .907 r
.22912 .33605 .23172 .33862 .23557 .33723 .23297 .33466 Metetra
.664 .741 .907 r
.23297 .33466 .23557 .33723 .23943 .33584 .23683 .33326 Metetra
.664 .741 .907 r
.23683 .33326 .23943 .33584 .24329 .33444 .2407 .33186 Metetra
.664 .741 .907 r
.2407 .33186 .24329 .33444 .24716 .33305 .24457 .33046 Metetra
.664 .741 .907 r
.24457 .33046 .24716 .33305 .25104 .33165 .24845 .32906 Metetra
.664 .741 .907 r
.24845 .32906 .25104 .33165 .25492 .33025 .25233 .32766 Metetra
.664 .741 .907 r
.25233 .32766 .25492 .33025 .25881 .32884 .25622 .32625 Metetra
.664 .741 .907 r
.25622 .32625 .25881 .32884 .2627 .32744 .26012 .32484 Metetra
.664 .741 .907 r
.26012 .32484 .2627 .32744 .2666 .32603 .26402 .32343 Metetra
.664 .741 .907 r
.26402 .32343 .2666 .32603 .2705 .32462 .26793 .32202 Metetra
.664 .741 .907 r
.26793 .32202 .2705 .32462 .27441 .32321 .27184 .3206 Metetra
.664 .741 .907 r
.27184 .3206 .27441 .32321 .27832 .3218 .27576 .31918 Metetra
.951 .682 .491 r
.27576 .31918 .27832 .3218 .28225 .32038 .26164 .54883 Metetra
.452 .231 .487 r
.26164 .54883 .28225 .32038 .26862 .54996 .26848 .51319 Metetra
.789 .545 .567 r
.26848 .51319 .26862 .54996 .27652 .49928 .27587 .46935 Metetra
.746 .513 .578 r
.27587 .46935 .27652 .49928 .28324 .4631 .28172 .44485 Metetra
.76 .54 .599 r
.28172 .44485 .28324 .4631 .28882 .44152 .28692 .42845 Metetra
.766 .561 .621 r
.28692 .42845 .28882 .44152 .29388 .42658 .29179 .41634 Metetra
.768 .578 .642 r
.29179 .41634 .29388 .42658 .29867 .41532 .29645 .40681 Metetra
.768 .594 .662 r
.29645 .40681 .29867 .41532 .30328 .40633 .30098 .39898 Metetra
.767 .607 .681 r
.30098 .39898 .30328 .40633 .30777 .39888 .30542 .39234 Metetra
.765 .62 .699 r
.30542 .39234 .30777 .39888 .31218 .3925 .3098 .38656 Metetra
.762 .63 .715 r
.3098 .38656 .31218 .3925 .31654 .38692 .31413 .38143 Metetra
.758 .64 .73 r
.31413 .38143 .31654 .38692 .32085 .38195 .31842 .37681 Metetra
.755 .648 .743 r
.31842 .37681 .32085 .38195 .32513 .37746 .32268 .3726 Metetra
.751 .655 .755 r
.32268 .3726 .32513 .37746 .32938 .37335 .32693 .36872 Metetra
.747 .662 .767 r
.32693 .36872 .32938 .37335 .33362 .36955 .33116 .36511 Metetra
.743 .668 .777 r
.33116 .36511 .33362 .36955 .33784 .36601 .33537 .36172 Metetra
.739 .673 .786 r
.33537 .36172 .33784 .36601 .34205 .36268 .33957 .35853 Metetra
.735 .677 .794 r
.33957 .35853 .34205 .36268 .34625 .35954 .34377 .3555 Metetra
.732 .681 .802 r
.34377 .3555 .34625 .35954 .35044 .35655 .34796 .35261 Metetra
.728 .685 .808 r
.34796 .35261 .35044 .35655 .35463 .3537 .35215 .34984 Metetra
.725 .688 .815 r
.35215 .34984 .35463 .3537 .35881 .35097 .35633 .34718 Metetra
.722 .691 .82 r
.35633 .34718 .35881 .35097 .363 .34834 .36052 .34462 Metetra
.718 .693 .825 r
.36052 .34462 .363 .34834 .36718 .34581 .3647 .34214 Metetra
.715 .696 .83 r
.3647 .34214 .36718 .34581 .37136 .34335 .36888 .33973 Metetra
.713 .698 .834 r
.36888 .33973 .37136 .34335 .37554 .34098 .37306 .33739 Metetra
.71 .699 .838 r
.37306 .33739 .37554 .34098 .37972 .33866 .37724 .33512 Metetra
.707 .701 .842 r
.37724 .33512 .37972 .33866 .3839 .33641 .38143 .3329 Metetra
.705 .702 .845 r
.38143 .3329 .3839 .33641 .38809 .33421 .38562 .33073 Metetra
.702 .704 .848 r
.38562 .33073 .38809 .33421 .39228 .33206 .3898 .32861 Metetra
.7 .705 .851 r
.3898 .32861 .39228 .33206 .39647 .32996 .394 .32653 Metetra
.698 .706 .854 r
.394 .32653 .39647 .32996 .40066 .3279 .39819 .32449 Metetra
.695 .707 .856 r
.39819 .32449 .40066 .3279 .40485 .32588 .40239 .32249 Metetra
.693 .707 .859 r
.40239 .32249 .40485 .32588 .40905 .32389 .40659 .32052 Metetra
.691 .708 .861 r
.40659 .32052 .40905 .32389 .41326 .32194 .4108 .31858 Metetra
.689 .708 .863 r
.4108 .31858 .41326 .32194 .41747 .32002 .41501 .31668 Metetra
.687 .709 .864 r
.41501 .31668 .41747 .32002 .42168 .31814 .41923 .3148 Metetra
.685 .709 .866 r
.41923 .3148 .42168 .31814 .4259 .31627 .42345 .31294 Metetra
.935 .731 .602 r
.42345 .31294 .4259 .31627 .43012 .31444 .42818 .29487 Metetra
.568 .391 .602 r
.42818 .29487 .43012 .31444 .43481 .29643 .43238 .29332 Metetra
.664 .717 .888 r
.43238 .29332 .43481 .29643 .43901 .29489 .43658 .29177 Metetra
.663 .716 .888 r
.43658 .29177 .43901 .29489 .44322 .29337 .4408 .29024 Metetra
.661 .716 .889 r
.4408 .29024 .44322 .29337 .44744 .29185 .44501 .28873 Metetra
.66 .716 .89 r
.44501 .28873 .44744 .29185 .45166 .29035 .44924 .28722 Metetra
.659 .715 .89 r
.44924 .28722 .45166 .29035 .45589 .28887 .45347 .28573 Metetra
.657 .715 .891 r
.45347 .28573 .45589 .28887 .46012 .2874 .45771 .28426 Metetra
.656 .714 .891 r
.45771 .28426 .46012 .2874 .46436 .28594 .46195 .28279 Metetra
.654 .713 .891 r
.46195 .28279 .46436 .28594 .46831 .30099 .4662 .28134 Metetra
.021 0 .487 r
.4662 .28134 .46831 .30099 .47258 .29984 .47017 .29646 Metetra
.625 .687 .888 r
.47017 .29646 .47258 .29984 .47686 .29871 .47445 .29531 Metetra
.623 .685 .888 r
.47445 .29531 .47686 .29871 .48114 .29761 .47874 .2942 Metetra
.62 .683 .888 r
.47874 .2942 .48114 .29761 .48543 .29655 .48303 .29311 Metetra
.617 .681 .888 r
.48303 .29311 .48543 .29655 .48973 .29551 .48734 .29205 Metetra
.613 .678 .888 r
.48734 .29205 .48973 .29551 .49404 .29451 .49165 .29103 Metetra
.61 .675 .887 r
.49165 .29103 .49404 .29451 .49836 .29355 .49597 .29004 Metetra
.606 .672 .887 r
.49597 .29004 .49836 .29355 .50268 .29263 .5003 .28909 Metetra
.602 .668 .886 r
.5003 .28909 .50268 .29263 .50701 .29175 .50463 .28817 Metetra
.598 .665 .886 r
.50463 .28817 .50701 .29175 .51136 .29092 .50898 .28731 Metetra
.593 .661 .885 r
.50898 .28731 .51136 .29092 .51571 .29014 .51333 .28649 Metetra
.588 .656 .884 r
.51333 .28649 .51571 .29014 .52006 .28941 .51769 .28572 Metetra
.583 .651 .883 r
.51769 .28572 .52006 .28941 .52443 .28875 .52206 .28501 Metetra
.577 .645 .881 r
.52206 .28501 .52443 .28875 .52881 .28815 .52644 .28436 Metetra
.57 .639 .88 r
.52644 .28436 .52881 .28815 .5332 .28763 .53083 .28378 Metetra
.563 .632 .878 r
.53083 .28378 .5332 .28763 .53759 .2872 .53523 .28328 Metetra
.555 .624 .876 r
.53523 .28328 .53759 .2872 .542 .28685 .53964 .28286 Metetra
.546 .616 .873 r
.53964 .28286 .542 .28685 .54642 .28662 .54406 .28255 Metetra
.536 .606 .87 r
.54406 .28255 .54642 .28662 .55085 .28651 .54849 .28234 Metetra
.524 .595 .867 r
.54849 .28234 .55085 .28651 .55529 .28653 .55293 .28226 Metetra
.511 .582 .863 r
.55293 .28226 .55529 .28653 .55975 .28672 .55739 .28233 Metetra
.496 .567 .857 r
.55739 .28233 .55975 .28672 .56422 .2871 .56186 .28256 Metetra
.479 .55 .851 r
.56186 .28256 .56422 .2871 .56871 .2877 .56635 .28299 Metetra
.459 .53 .843 r
.56635 .28299 .56871 .2877 .57321 .28856 .57085 .28365 Metetra
.436 .507 .834 r
.57085 .28365 .57321 .28856 .57774 .28975 .57537 .28459 Metetra
.408 .48 .822 r
.57537 .28459 .57774 .28975 .58229 .29132 .57991 .28587 Metetra
.376 .447 .807 r
.57991 .28587 .58229 .29132 .58686 .29339 .58448 .28757 Metetra
.337 .408 .788 r
.58448 .28757 .58686 .29339 .59146 .29608 .58907 .28979 Metetra
.291 .362 .764 r
.58907 .28979 .59146 .29608 .59611 .2996 .59369 .29268 Metetra
.237 .306 .733 r
.59369 .29268 .59611 .2996 .6008 .30423 .59836 .29646 Metetra
.171 .24 .693 r
.59836 .29646 .6008 .30423 .60556 .31043 .60308 .30147 Metetra
.094 .161 .643 r
.60308 .30147 .60556 .31043 .61041 .31897 .60788 .30822 Metetra
.004 .07 .58 r
.60788 .30822 .61041 .31897 .61541 .33131 .61278 .31764 Metetra
0 0 .504 r
.61278 .31764 .61541 .33131 .62066 .3505 .61785 .33148 Metetra
0 0 .415 r
.61785 .33148 .62066 .3505 .62647 .38476 .62323 .35368 Metetra
0 0 .312 r
.62323 .35368 .62647 .38476 .63288 .43411 .62935 .39588 Metetra
.005 0 .45 r
.62935 .39588 .63288 .43411 .62947 .19507 .63531 .42974 Metetra
0 0 .347 r
.63531 .42974 .62947 .19507 .63393 .19346 .63171 .19048 Metetra
.664 .741 .907 r
.63171 .19048 .63393 .19346 .6384 .19185 .63619 .18886 Metetra
.664 .741 .907 r
.63619 .18886 .6384 .19185 .64288 .19023 .64067 .18724 Metetra
.664 .741 .907 r
.64067 .18724 .64288 .19023 .64736 .18861 .64516 .18562 Metetra
.664 .741 .907 r
.64516 .18562 .64736 .18861 .65185 .18699 .64966 .18399 Metetra
.664 .741 .907 r
.64966 .18399 .65185 .18699 .65635 .18537 .65416 .18236 Metetra
.664 .741 .907 r
.65416 .18236 .65635 .18537 .66086 .18374 .65867 .18073 Metetra
.664 .741 .907 r
.65867 .18073 .66086 .18374 .66537 .18211 .66319 .1791 Metetra
.664 .741 .907 r
.66319 .1791 .66537 .18211 .66989 .18048 .66772 .17746 Metetra
.664 .741 .907 r
.66772 .17746 .66989 .18048 .67442 .17885 .67225 .17582 Metetra
.664 .741 .907 r
.67225 .17582 .67442 .17885 .67896 .17721 .67679 .17418 Metetra
.664 .741 .907 r
.67679 .17418 .67896 .17721 .6835 .17557 .68134 .17254 Metetra
.664 .741 .907 r
.68134 .17254 .6835 .17557 .68805 .17393 .68589 .17089 Metetra
.664 .741 .907 r
.68589 .17089 .68805 .17393 .6926 .17228 .69045 .16924 Metetra
.664 .741 .907 r
.69045 .16924 .6926 .17228 .69717 .17064 .69502 .16759 Metetra
.664 .741 .907 r
.69502 .16759 .69717 .17064 .70174 .16899 .6996 .16593 Metetra
.664 .741 .907 r
.6996 .16593 .70174 .16899 .70632 .16733 .70418 .16428 Metetra
.664 .741 .907 r
.70418 .16428 .70632 .16733 .71091 .16568 .70878 .16262 Metetra
.664 .741 .907 r
.70878 .16262 .71091 .16568 .7155 .16402 .71337 .16095 Metetra
.664 .741 .907 r
.71337 .16095 .7155 .16402 .7201 .16236 .71798 .15929 Metetra
.664 .741 .907 r
.71798 .15929 .7201 .16236 .72471 .1607 .7226 .15762 Metetra
.664 .741 .907 r
.7226 .15762 .72471 .1607 .72933 .15903 .72722 .15595 Metetra
.664 .741 .907 r
.72722 .15595 .72933 .15903 .73395 .15736 .73185 .15427 Metetra
.664 .741 .907 r
.73185 .15427 .73395 .15736 .73858 .15569 .73648 .1526 Metetra
.664 .741 .907 r
.73648 .1526 .73858 .15569 .74322 .15402 .74113 .15092 Metetra
.664 .741 .907 r
.74113 .15092 .74322 .15402 .74787 .15234 .74578 .14924 Metetra
.664 .741 .907 r
.74578 .14924 .74787 .15234 .75252 .15066 .75044 .14755 Metetra
.664 .741 .907 r
.75044 .14755 .75252 .15066 .75718 .14898 .7551 .14586 Metetra
.664 .741 .907 r
.7551 .14586 .75718 .14898 .76185 .14729 .75978 .14417 Metetra
.664 .741 .907 r
.75978 .14417 .76185 .14729 .76653 .14561 .76446 .14248 Metetra
.664 .741 .907 r
.76446 .14248 .76653 .14561 .77121 .14391 .76915 .14079 Metetra
.664 .741 .907 r
.76915 .14079 .77121 .14391 .7759 .14222 .77385 .13909 Metetra
.664 .741 .907 r
.77385 .13909 .7759 .14222 .7806 .14053 .77855 .13739 Metetra
.664 .741 .907 r
.15051 .361 .15319 .3635 .15693 .36215 .15426 .35965 Metetra
.664 .741 .907 r
.15426 .35965 .15693 .36215 .16068 .36079 .15801 .35829 Metetra
.664 .741 .907 r
.15801 .35829 .16068 .36079 .16444 .35944 .16177 .35692 Metetra
.664 .741 .907 r
.16177 .35692 .16444 .35944 .1682 .35808 .16553 .35556 Metetra
.664 .741 .907 r
.16553 .35556 .1682 .35808 .17196 .35672 .1693 .3542 Metetra
.664 .741 .907 r
.1693 .3542 .17196 .35672 .17573 .35535 .17308 .35283 Metetra
.664 .741 .907 r
.17308 .35283 .17573 .35535 .17951 .35399 .17686 .35146 Metetra
.664 .741 .907 r
.17686 .35146 .17951 .35399 .18329 .35262 .18064 .35009 Metetra
.664 .741 .907 r
.18064 .35009 .18329 .35262 .18708 .35125 .18443 .34872 Metetra
.664 .741 .907 r
.18443 .34872 .18708 .35125 .19087 .34988 .18823 .34734 Metetra
.664 .741 .907 r
.18823 .34734 .19087 .34988 .19467 .3485 .19203 .34596 Metetra
.664 .741 .907 r
.19203 .34596 .19467 .3485 .19848 .34713 .19584 .34458 Metetra
.664 .741 .907 r
.19584 .34458 .19848 .34713 .20229 .34575 .19965 .3432 Metetra
.664 .741 .907 r
.19965 .3432 .20229 .34575 .2061 .34437 .20347 .34182 Metetra
.664 .741 .907 r
.20347 .34182 .2061 .34437 .20992 .34299 .20729 .34043 Metetra
.664 .741 .907 r
.20729 .34043 .20992 .34299 .21375 .34161 .21112 .33905 Metetra
.664 .741 .907 r
.21112 .33905 .21375 .34161 .21758 .34022 .21496 .33766 Metetra
.664 .741 .907 r
.21496 .33766 .21758 .34022 .22142 .33883 .2188 .33626 Metetra
.664 .741 .907 r
.2188 .33626 .22142 .33883 .22527 .33744 .22265 .33487 Metetra
.664 .741 .907 r
.22265 .33487 .22527 .33744 .22912 .33605 .2265 .33348 Metetra
.664 .741 .907 r
.2265 .33348 .22912 .33605 .23297 .33466 .23036 .33208 Metetra
.664 .741 .907 r
.23036 .33208 .23297 .33466 .23683 .33326 .23423 .33068 Metetra
.664 .741 .907 r
.23423 .33068 .23683 .33326 .2407 .33186 .2381 .32928 Metetra
.664 .741 .907 r
.2381 .32928 .2407 .33186 .24457 .33046 .24197 .32787 Metetra
.664 .741 .907 r
.24197 .32787 .24457 .33046 .24845 .32906 .24585 .32647 Metetra
.664 .741 .907 r
.24585 .32647 .24845 .32906 .25233 .32766 .24974 .32506 Metetra
.664 .741 .907 r
.24974 .32506 .25233 .32766 .25622 .32625 .25363 .32365 Metetra
.664 .741 .907 r
.25363 .32365 .25622 .32625 .26012 .32484 .25753 .32223 Metetra
.664 .741 .907 r
.25753 .32223 .26012 .32484 .26402 .32343 .26144 .32082 Metetra
.664 .741 .907 r
.26144 .32082 .26402 .32343 .26793 .32202 .26535 .3194 Metetra
.664 .741 .907 r
.26535 .3194 .26793 .32202 .27184 .3206 .26926 .31798 Metetra
.951 .682 .492 r
.26926 .31798 .27184 .3206 .27576 .31918 .25465 .5477 Metetra
.493 .265 .497 r
.25465 .5477 .27576 .31918 .26164 .54883 .26003 .53155 Metetra
.881 .634 .561 r
.26003 .53155 .26164 .54883 .26848 .51319 .26837 .47685 Metetra
.739 .503 .572 r
.26837 .47685 .26848 .51319 .27587 .46935 .27455 .44871 Metetra
.756 .532 .593 r
.27455 .44871 .27587 .46935 .28172 .44485 .27992 .43059 Metetra
.764 .555 .614 r
.27992 .43059 .28172 .44485 .28692 .42845 .28488 .41752 Metetra
.767 .573 .636 r
.28488 .41752 .28692 .42845 .29179 .41634 .2896 .40739 Metetra
.768 .589 .656 r
.2896 .40739 .29179 .41634 .29645 .40681 .29418 .39915 Metetra
.767 .603 .676 r
.29418 .39915 .29645 .40681 .30098 .39898 .29865 .39222 Metetra
.765 .616 .694 r
.29865 .39222 .30098 .39898 .30542 .39234 .30305 .38623 Metetra
.762 .627 .71 r
.30305 .38623 .30542 .39234 .3098 .38656 .30739 .38094 Metetra
.759 .637 .726 r
.30739 .38094 .3098 .38656 .31413 .38143 .3117 .37619 Metetra
.756 .646 .739 r
.3117 .37619 .31413 .38143 .31842 .37681 .31597 .37188 Metetra
.752 .653 .752 r
.31597 .37188 .31842 .37681 .32268 .3726 .32023 .36791 Metetra
.748 .66 .764 r
.32023 .36791 .32268 .3726 .32693 .36872 .32446 .36422 Metetra
.744 .666 .774 r
.32446 .36422 .32693 .36872 .33116 .36511 .32868 .36078 Metetra
.74 .671 .783 r
.32868 .36078 .33116 .36511 .33537 .36172 .33289 .35753 Metetra
.736 .676 .792 r
.33289 .35753 .33537 .36172 .33957 .35853 .33709 .35445 Metetra
.733 .68 .799 r
.33709 .35445 .33957 .35853 .34377 .3555 .34128 .35152 Metetra
.729 .684 .806 r
.34128 .35152 .34377 .3555 .34796 .35261 .34547 .34872 Metetra
.726 .687 .813 r
.34547 .34872 .34796 .35261 .35215 .34984 .34966 .34603 Metetra
.723 .69 .819 r
.34966 .34603 .35215 .34984 .35633 .34718 .35384 .34343 Metetra
.719 .693 .824 r
.35384 .34343 .35633 .34718 .36052 .34462 .35803 .34092 Metetra
.716 .695 .829 r
.35803 .34092 .36052 .34462 .3647 .34214 .36221 .33849 Metetra
.713 .697 .833 r
.36221 .33849 .3647 .34214 .36888 .33973 .36639 .33613 Metetra
.711 .699 .837 r
.36639 .33613 .36888 .33973 .37306 .33739 .37057 .33384 Metetra
.708 .701 .841 r
.37057 .33384 .37306 .33739 .37724 .33512 .37476 .3316 Metetra
.706 .702 .844 r
.37476 .3316 .37724 .33512 .38143 .3329 .37895 .32941 Metetra
.703 .704 .848 r
.37895 .32941 .38143 .3329 .38562 .33073 .38314 .32727 Metetra
.701 .705 .85 r
.38314 .32727 .38562 .33073 .3898 .32861 .38733 .32517 Metetra
.698 .706 .853 r
.38733 .32517 .3898 .32861 .394 .32653 .39152 .32311 Metetra
.696 .707 .856 r
.39152 .32311 .394 .32653 .39819 .32449 .39572 .32109 Metetra
.694 .707 .858 r
.39572 .32109 .39819 .32449 .40239 .32249 .39992 .31911 Metetra
.692 .708 .86 r
.39992 .31911 .40239 .32249 .40659 .32052 .40413 .31715 Metetra
.69 .709 .862 r
.40413 .31715 .40659 .32052 .4108 .31858 .40834 .31523 Metetra
.688 .709 .864 r
.40834 .31523 .4108 .31858 .41501 .31668 .41255 .31333 Metetra
.935 .73 .601 r
.41255 .31333 .41501 .31668 .41923 .3148 .41734 .29491 Metetra
.567 .39 .6 r
.41734 .29491 .41923 .3148 .42345 .31294 .42153 .29333 Metetra
.568 .391 .601 r
.42153 .29333 .42345 .31294 .42818 .29487 .42573 .29176 Metetra
.665 .718 .888 r
.42573 .29176 .42818 .29487 .43238 .29332 .42994 .2902 Metetra
.664 .717 .888 r
.42994 .2902 .43238 .29332 .43658 .29177 .43415 .28865 Metetra
.663 .717 .889 r
.43415 .28865 .43658 .29177 .4408 .29024 .43836 .28712 Metetra
.661 .717 .89 r
.43836 .28712 .4408 .29024 .44501 .28873 .44258 .2856 Metetra
.66 .716 .89 r
.44258 .2856 .44501 .28873 .44924 .28722 .44681 .28409 Metetra
.659 .716 .891 r
.44681 .28409 .44924 .28722 .45347 .28573 .45105 .2826 Metetra
.657 .715 .891 r
.45105 .2826 .45347 .28573 .45771 .28426 .45529 .28111 Metetra
.656 .715 .891 r
.45529 .28111 .45771 .28426 .46195 .28279 .45954 .27964 Metetra
.655 .714 .892 r
.45954 .27964 .46195 .28279 .4662 .28134 .46379 .27819 Metetra
.653 .713 .892 r
.46379 .27819 .4662 .28134 .47017 .29646 .46805 .27674 Metetra
.564 .388 .601 r
.46805 .27674 .47017 .29646 .47445 .29531 .47232 .27531 Metetra
.018 0 .485 r
.47232 .27531 .47445 .29531 .47874 .2942 .47633 .29079 Metetra
.621 .685 .889 r
.47633 .29079 .47874 .2942 .48303 .29311 .48063 .28968 Metetra
.618 .683 .888 r
.48063 .28968 .48303 .29311 .48734 .29205 .48494 .2886 Metetra
.615 .68 .888 r
.48494 .2886 .48734 .29205 .49165 .29103 .48925 .28755 Metetra
.612 .677 .888 r
.48925 .28755 .49165 .29103 .49597 .29004 .49357 .28653 Metetra
.608 .674 .887 r
.49357 .28653 .49597 .29004 .5003 .28909 .4979 .28555 Metetra
.605 .671 .887 r
.4979 .28555 .5003 .28909 .50463 .28817 .50224 .28461 Metetra
.601 .667 .886 r
.50224 .28461 .50463 .28817 .50898 .28731 .50659 .28371 Metetra
.596 .664 .886 r
.50659 .28371 .50898 .28731 .51333 .28649 .51094 .28285 Metetra
.592 .659 .885 r
.51094 .28285 .51333 .28649 .51769 .28572 .51531 .28204 Metetra
.587 .655 .884 r
.51531 .28204 .51769 .28572 .52206 .28501 .51968 .28129 Metetra
.581 .649 .883 r
.51968 .28129 .52206 .28501 .52644 .28436 .52406 .28059 Metetra
.575 .644 .881 r
.52406 .28059 .52644 .28436 .53083 .28378 .52846 .27996 Metetra
.568 .637 .88 r
.52846 .27996 .53083 .28378 .53523 .28328 .53286 .2794 Metetra
.561 .63 .878 r
.53286 .2794 .53523 .28328 .53964 .28286 .53727 .27891 Metetra
.552 .622 .875 r
.53727 .27891 .53964 .28286 .54406 .28255 .54169 .27852 Metetra
.543 .613 .873 r
.54169 .27852 .54406 .28255 .54849 .28234 .54613 .27823 Metetra
.532 .603 .869 r
.54613 .27823 .54849 .28234 .55293 .28226 .55057 .27805 Metetra
.521 .591 .866 r
.55057 .27805 .55293 .28226 .55739 .28233 .55503 .27801 Metetra
.507 .578 .861 r
.55503 .27801 .55739 .28233 .56186 .28256 .5595 .27811 Metetra
.492 .562 .856 r
.5595 .27811 .56186 .28256 .56635 .28299 .56398 .27839 Metetra
.474 .545 .849 r
.56398 .27839 .56635 .28299 .57085 .28365 .56848 .27887 Metetra
.453 .524 .841 r
.56848 .27887 .57085 .28365 .57537 .28459 .573 .2796 Metetra
.429 .5 .83 r
.573 .2796 .57537 .28459 .57991 .28587 .57754 .28062 Metetra
.4 .471 .818 r
.57754 .28062 .57991 .28587 .58448 .28757 .5821 .282 Metetra
.366 .437 .802 r
.5821 .282 .58448 .28757 .58907 .28979 .58668 .28382 Metetra
.326 .396 .781 r
.58668 .28382 .58907 .28979 .59369 .29268 .59129 .2862 Metetra
.278 .348 .756 r
.59129 .2862 .59369 .29268 .59836 .29646 .59594 .28931 Metetra
.221 .29 .722 r
.59594 .28931 .59836 .29646 .60308 .30147 .60063 .29338 Metetra
.153 .22 .68 r
.60063 .29338 .60308 .30147 .60788 .30822 .60538 .2988 Metetra
.073 .138 .627 r
.60538 .2988 .60788 .30822 .61278 .31764 .61022 .30617 Metetra
0 .044 .561 r
.61022 .30617 .61278 .31764 .61785 .33148 .61517 .31658 Metetra
0 0 .482 r
.61517 .31658 .61785 .33148 .62323 .35368 .62032 .33218 Metetra
0 0 .39 r
.62032 .33218 .62323 .35368 .62935 .39588 .62587 .35815 Metetra
0 0 .282 r
.62587 .35815 .62935 .39588 .63531 .42974 .63242 .4116 Metetra
.1 .078 .543 r
.63242 .4116 .63531 .42974 .63171 .19048 .63776 .42536 Metetra
0 0 .347 r
.63776 .42536 .63171 .19048 .63619 .18886 .63397 .18587 Metetra
.664 .741 .907 r
.63397 .18587 .63619 .18886 .64067 .18724 .63846 .18424 Metetra
.664 .741 .907 r
.63846 .18424 .64067 .18724 .64516 .18562 .64295 .18261 Metetra
.664 .741 .907 r
.64295 .18261 .64516 .18562 .64966 .18399 .64745 .18098 Metetra
.664 .741 .907 r
.64745 .18098 .64966 .18399 .65416 .18236 .65196 .17935 Metetra
.664 .741 .907 r
.65196 .17935 .65416 .18236 .65867 .18073 .65648 .17771 Metetra
.664 .741 .907 r
.65648 .17771 .65867 .18073 .66319 .1791 .661 .17608 Metetra
.664 .741 .907 r
.661 .17608 .66319 .1791 .66772 .17746 .66553 .17443 Metetra
.664 .741 .907 r
.66553 .17443 .66772 .17746 .67225 .17582 .67007 .17279 Metetra
.664 .741 .907 r
.67007 .17279 .67225 .17582 .67679 .17418 .67462 .17114 Metetra
.664 .741 .907 r
.67462 .17114 .67679 .17418 .68134 .17254 .67917 .16949 Metetra
.664 .741 .907 r
.67917 .16949 .68134 .17254 .68589 .17089 .68373 .16784 Metetra
.664 .741 .907 r
.68373 .16784 .68589 .17089 .69045 .16924 .6883 .16619 Metetra
.664 .741 .907 r
.6883 .16619 .69045 .16924 .69502 .16759 .69287 .16453 Metetra
.664 .741 .907 r
.69287 .16453 .69502 .16759 .6996 .16593 .69745 .16287 Metetra
.664 .741 .907 r
.69745 .16287 .6996 .16593 .70418 .16428 .70204 .16121 Metetra
.664 .741 .907 r
.70204 .16121 .70418 .16428 .70878 .16262 .70664 .15954 Metetra
.664 .741 .907 r
.70664 .15954 .70878 .16262 .71337 .16095 .71124 .15788 Metetra
.664 .741 .907 r
.71124 .15788 .71337 .16095 .71798 .15929 .71585 .15621 Metetra
.664 .741 .907 r
.71585 .15621 .71798 .15929 .7226 .15762 .72047 .15453 Metetra
.664 .741 .907 r
.72047 .15453 .7226 .15762 .72722 .15595 .7251 .15286 Metetra
.664 .741 .907 r
.7251 .15286 .72722 .15595 .73185 .15427 .72973 .15118 Metetra
.664 .741 .907 r
.72973 .15118 .73185 .15427 .73648 .1526 .73438 .1495 Metetra
.664 .741 .907 r
.73438 .1495 .73648 .1526 .74113 .15092 .73903 .14781 Metetra
.664 .741 .907 r
.73903 .14781 .74113 .15092 .74578 .14924 .74368 .14612 Metetra
.664 .741 .907 r
.74368 .14612 .74578 .14924 .75044 .14755 .74835 .14443 Metetra
.664 .741 .907 r
.74835 .14443 .75044 .14755 .7551 .14586 .75302 .14274 Metetra
.664 .741 .907 r
.75302 .14274 .7551 .14586 .75978 .14417 .7577 .14105 Metetra
.664 .741 .907 r
.7577 .14105 .75978 .14417 .76446 .14248 .76239 .13935 Metetra
.664 .741 .907 r
.76239 .13935 .76446 .14248 .76915 .14079 .76708 .13765 Metetra
.664 .741 .907 r
.76708 .13765 .76915 .14079 .77385 .13909 .77178 .13594 Metetra
.664 .741 .907 r
.77178 .13594 .77385 .13909 .77855 .13739 .77649 .13424 Metetra
.664 .741 .907 r
.14783 .3585 .15051 .361 .15426 .35965 .15158 .35713 Metetra
.664 .741 .907 r
.15158 .35713 .15426 .35965 .15801 .35829 .15533 .35577 Metetra
.664 .741 .907 r
.15533 .35577 .15801 .35829 .16177 .35692 .15909 .35441 Metetra
.664 .741 .907 r
.15909 .35441 .16177 .35692 .16553 .35556 .16286 .35304 Metetra
.664 .741 .907 r
.16286 .35304 .16553 .35556 .1693 .3542 .16663 .35167 Metetra
.664 .741 .907 r
.16663 .35167 .1693 .3542 .17308 .35283 .17041 .3503 Metetra
.664 .741 .907 r
.17041 .3503 .17308 .35283 .17686 .35146 .17419 .34893 Metetra
.664 .741 .907 r
.17419 .34893 .17686 .35146 .18064 .35009 .17798 .34755 Metetra
.664 .741 .907 r
.17798 .34755 .18064 .35009 .18443 .34872 .18178 .34617 Metetra
.664 .741 .907 r
.18178 .34617 .18443 .34872 .18823 .34734 .18558 .3448 Metetra
.664 .741 .907 r
.18558 .3448 .18823 .34734 .19203 .34596 .18938 .34341 Metetra
.664 .741 .907 r
.18938 .34341 .19203 .34596 .19584 .34458 .19319 .34203 Metetra
.664 .741 .907 r
.19319 .34203 .19584 .34458 .19965 .3432 .19701 .34065 Metetra
.664 .741 .907 r
.19701 .34065 .19965 .3432 .20347 .34182 .20083 .33926 Metetra
.664 .741 .907 r
.20083 .33926 .20347 .34182 .20729 .34043 .20466 .33787 Metetra
.664 .741 .907 r
.20466 .33787 .20729 .34043 .21112 .33905 .20849 .33648 Metetra
.664 .741 .907 r
.20849 .33648 .21112 .33905 .21496 .33766 .21233 .33509 Metetra
.664 .741 .907 r
.21233 .33509 .21496 .33766 .2188 .33626 .21618 .33369 Metetra
.664 .741 .907 r
.21618 .33369 .2188 .33626 .22265 .33487 .22003 .33229 Metetra
.664 .741 .907 r
.22003 .33229 .22265 .33487 .2265 .33348 .22388 .33089 Metetra
.664 .741 .907 r
.22388 .33089 .2265 .33348 .23036 .33208 .22774 .32949 Metetra
.664 .741 .907 r
.22774 .32949 .23036 .33208 .23423 .33068 .23161 .32809 Metetra
.664 .741 .907 r
.23161 .32809 .23423 .33068 .2381 .32928 .23549 .32668 Metetra
.664 .741 .907 r
.23549 .32668 .2381 .32928 .24197 .32787 .23936 .32527 Metetra
.664 .741 .907 r
.23936 .32527 .24197 .32787 .24585 .32647 .24325 .32386 Metetra
.664 .741 .907 r
.24325 .32386 .24585 .32647 .24974 .32506 .24714 .32245 Metetra
.664 .741 .907 r
.24714 .32245 .24974 .32506 .25363 .32365 .25104 .32104 Metetra
.664 .741 .907 r
.25104 .32104 .25363 .32365 .25753 .32223 .25494 .31962 Metetra
.664 .741 .907 r
.25494 .31962 .25753 .32223 .26144 .32082 .25885 .3182 Metetra
.664 .741 .907 r
.25885 .3182 .26144 .32082 .26535 .3194 .26276 .31678 Metetra
.95 .682 .493 r
.26276 .31678 .26535 .3194 .26926 .31798 .24766 .54656 Metetra
.521 .288 .503 r
.24766 .54656 .26926 .31798 .25465 .5477 .25186 .54522 Metetra
.946 .705 .543 r
.25186 .54522 .25465 .5477 .26003 .53155 .26069 .486 Metetra
.73 .491 .565 r
.26069 .486 .26003 .53155 .26837 .47685 .2673 .4532 Metetra
.752 .524 .587 r
.2673 .4532 .26837 .47685 .27455 .44871 .27287 .43305 Metetra
.762 .548 .608 r
.27287 .43305 .27455 .44871 .27992 .43059 .27794 .41888 Metetra
.766 .568 .63 r
.27794 .41888 .27992 .43059 .28488 .41752 .28273 .40808 Metetra
.767 .584 .65 r
.28273 .40808 .28488 .41752 .2896 .40739 .28735 .3994 Metetra
.767 .599 .67 r
.28735 .3994 .2896 .40739 .29418 .39915 .29186 .39216 Metetra
.765 .612 .689 r
.29186 .39216 .29418 .39915 .29865 .39222 .29628 .38594 Metetra
.763 .624 .706 r
.29628 .38594 .29865 .39222 .30305 .38623 .30064 .38047 Metetra
.76 .634 .721 r
.30064 .38047 .30305 .38623 .30739 .38094 .30496 .37559 Metetra
.756 .643 .736 r
.30496 .37559 .30739 .38094 .3117 .37619 .30925 .37117 Metetra
.753 .651 .749 r
.30925 .37117 .3117 .37619 .31597 .37188 .31351 .36711 Metetra
.749 .658 .76 r
.31351 .36711 .31597 .37188 .32023 .36791 .31775 .36335 Metetra
.745 .664 .771 r
.31775 .36335 .32023 .36791 .32446 .36422 .32198 .35984 Metetra
.741 .67 .781 r
.32198 .35984 .32446 .36422 .32868 .36078 .3262 .35654 Metetra
.737 .675 .789 r
.3262 .35654 .32868 .36078 .33289 .35753 .3304 .35342 Metetra
.734 .679 .797 r
.3304 .35342 .33289 .35753 .33709 .35445 .3346 .35044 Metetra
.73 .683 .805 r
.3346 .35044 .33709 .35445 .34128 .35152 .33879 .3476 Metetra
.727 .686 .811 r
.33879 .3476 .34128 .35152 .34547 .34872 .34298 .34488 Metetra
.723 .689 .817 r
.34298 .34488 .34547 .34872 .34966 .34603 .34716 .34226 Metetra
.72 .692 .822 r
.34716 .34226 .34966 .34603 .35384 .34343 .35135 .33972 Metetra
.717 .695 .827 r
.35135 .33972 .35384 .34343 .35803 .34092 .35553 .33727 Metetra
.714 .697 .832 r
.35553 .33727 .35803 .34092 .36221 .33849 .35971 .33488 Metetra
.712 .699 .836 r
.35971 .33488 .36221 .33849 .36639 .33613 .3639 .33256 Metetra
.709 .7 .84 r
.3639 .33256 .36639 .33613 .37057 .33384 .36808 .3303 Metetra
.706 .702 .843 r
.36808 .3303 .37057 .33384 .37476 .3316 .37227 .3281 Metetra
.704 .703 .847 r
.37227 .3281 .37476 .3316 .37895 .32941 .37646 .32594 Metetra
.702 .705 .85 r
.37646 .32594 .37895 .32941 .38314 .32727 .38065 .32382 Metetra
.699 .706 .852 r
.38065 .32382 .38314 .32727 .38733 .32517 .38484 .32174 Metetra
.697 .707 .855 r
.38484 .32174 .38733 .32517 .39152 .32311 .38904 .31971 Metetra
.695 .708 .857 r
.38904 .31971 .39152 .32311 .39572 .32109 .39324 .3177 Metetra
.693 .708 .86 r
.39324 .3177 .39572 .32109 .39992 .31911 .39745 .31573 Metetra
.691 .709 .862 r
.39745 .31573 .39992 .31911 .40413 .31715 .40165 .31379 Metetra
.689 .709 .864 r
.40165 .31379 .40413 .31715 .40834 .31523 .40587 .31188 Metetra
.935 .729 .601 r
.40587 .31188 .40834 .31523 .41255 .31333 .41069 .2934 Metetra
.567 .389 .6 r
.41069 .2934 .41255 .31333 .41734 .29491 .41488 .2918 Metetra
.667 .718 .887 r
.41488 .2918 .41734 .29491 .42153 .29333 .41908 .29021 Metetra
.666 .718 .888 r
.41908 .29021 .42153 .29333 .42573 .29176 .42328 .28864 Metetra
.665 .718 .888 r
.42328 .28864 .42573 .29176 .42994 .2902 .42749 .28708 Metetra
.664 .718 .889 r
.42749 .28708 .42994 .2902 .43415 .28865 .4317 .28553 Metetra
.662 .718 .889 r
.4317 .28553 .43415 .28865 .43836 .28712 .43592 .284 Metetra
.661 .717 .89 r
.43592 .284 .43836 .28712 .44258 .2856 .44015 .28247 Metetra
.66 .717 .891 r
.44015 .28247 .44258 .2856 .44681 .28409 .44438 .28096 Metetra
.659 .716 .891 r
.44438 .28096 .44681 .28409 .45105 .2826 .44862 .27946 Metetra
.658 .716 .891 r
.44862 .27946 .45105 .2826 .45529 .28111 .45286 .27797 Metetra
.656 .715 .892 r
.45286 .27797 .45529 .28111 .45954 .27964 .45712 .27649 Metetra
.655 .715 .892 r
.45712 .27649 .45954 .27964 .46379 .27819 .46137 .27503 Metetra
.654 .714 .892 r
.46137 .27503 .46379 .27819 .46805 .27674 .46564 .27358 Metetra
.652 .713 .893 r
.46564 .27358 .46805 .27674 .47232 .27531 .46991 .27214 Metetra
.651 .713 .893 r
.46991 .27214 .47232 .27531 .47633 .29079 .47419 .27071 Metetra
.017 0 .484 r
.47419 .27071 .47633 .29079 .48063 .28968 .47822 .28626 Metetra
.62 .684 .889 r
.47822 .28626 .48063 .28968 .48494 .2886 .48253 .28515 Metetra
.617 .682 .889 r
.48253 .28515 .48494 .2886 .48925 .28755 .48684 .28408 Metetra
.614 .679 .888 r
.48684 .28408 .48925 .28755 .49357 .28653 .49117 .28304 Metetra
.611 .677 .888 r
.49117 .28304 .49357 .28653 .4979 .28555 .4955 .28203 Metetra
.607 .673 .888 r
.4955 .28203 .4979 .28555 .50224 .28461 .49985 .28106 Metetra
.603 .67 .887 r
.49985 .28106 .50224 .28461 .50659 .28371 .5042 .28013 Metetra
.599 .666 .886 r
.5042 .28013 .50659 .28371 .51094 .28285 .50856 .27924 Metetra
.595 .662 .886 r
.50856 .27924 .51094 .28285 .51531 .28204 .51292 .27839 Metetra
.59 .658 .885 r
.51292 .27839 .51531 .28204 .51968 .28129 .5173 .27759 Metetra
.585 .653 .884 r
.5173 .27759 .51968 .28129 .52406 .28059 .52168 .27685 Metetra
.579 .648 .882 r
.52168 .27685 .52406 .28059 .52846 .27996 .52608 .27616 Metetra
.573 .642 .881 r
.52608 .27616 .52846 .27996 .53286 .2794 .53048 .27555 Metetra
.566 .635 .879 r
.53048 .27555 .53286 .2794 .53727 .27891 .5349 .275 Metetra
.558 .628 .877 r
.5349 .275 .53727 .27891 .54169 .27852 .53932 .27454 Metetra
.55 .62 .875 r
.53932 .27454 .54169 .27852 .54613 .27823 .54376 .27417 Metetra
.54 .61 .872 r
.54376 .27417 .54613 .27823 .55057 .27805 .5482 .2739 Metetra
.529 .6 .868 r
.5482 .2739 .55057 .27805 .55503 .27801 .55266 .27375 Metetra
.517 .588 .864 r
.55266 .27375 .55503 .27801 .5595 .27811 .55713 .27374 Metetra
.503 .574 .86 r
.55713 .27374 .5595 .27811 .56398 .27839 .56162 .27388 Metetra
.487 .558 .854 r
.56162 .27388 .56398 .27839 .56848 .27887 .56612 .27421 Metetra
.469 .539 .847 r
.56612 .27421 .56848 .27887 .573 .2796 .57063 .27475 Metetra
.447 .518 .838 r
.57063 .27475 .573 .2796 .57754 .28062 .57516 .27555 Metetra
.422 .492 .827 r
.57516 .27555 .57754 .28062 .5821 .282 .57972 .27665 Metetra
.392 .462 .814 r
.57972 .27665 .5821 .282 .58668 .28382 .58429 .27814 Metetra
.357 .427 .796 r
.58429 .27814 .58668 .28382 .59129 .2862 .58889 .28009 Metetra
.315 .384 .775 r
.58889 .28009 .59129 .2862 .59594 .28931 .59353 .28264 Metetra
.265 .333 .747 r
.59353 .28264 .59594 .28931 .60063 .29338 .5982 .28597 Metetra
.205 .272 .712 r
.5982 .28597 .60063 .29338 .60538 .2988 .60291 .29036 Metetra
.134 .2 .667 r
.60291 .29036 .60538 .2988 .61022 .30617 .6077 .29623 Metetra
.051 .115 .611 r
.6077 .29623 .61022 .30617 .61517 .31658 .61257 .30428 Metetra
0 .018 .541 r
.61257 .30428 .61517 .31658 .62032 .33218 .61759 .31582 Metetra
0 0 .459 r
.61759 .31582 .62032 .33218 .62587 .35815 .62284 .33353 Metetra
0 0 .364 r
.62284 .33353 .62587 .35815 .63242 .4116 .62858 .36431 Metetra
0 0 .334 r
.62858 .36431 .63242 .4116 .63776 .42536 .63537 .4225 Metetra
.645 .763 .934 r
.63537 .4225 .63776 .42536 .63397 .18587 .64021 .42095 Metetra
0 0 .347 r
.64021 .42095 .63397 .18587 .63846 .18424 .63624 .18123 Metetra
.664 .741 .907 r
.63624 .18123 .63846 .18424 .64295 .18261 .64074 .1796 Metetra
.664 .741 .907 r
.64074 .1796 .64295 .18261 .64745 .18098 .64525 .17797 Metetra
.664 .741 .907 r
.64525 .17797 .64745 .18098 .65196 .17935 .64976 .17633 Metetra
.664 .741 .907 r
.64976 .17633 .65196 .17935 .65648 .17771 .65428 .17469 Metetra
.664 .741 .907 r
.65428 .17469 .65648 .17771 .661 .17608 .65881 .17304 Metetra
.664 .741 .907 r
.65881 .17304 .661 .17608 .66553 .17443 .66334 .1714 Metetra
.664 .741 .907 r
.66334 .1714 .66553 .17443 .67007 .17279 .66789 .16975 Metetra
.664 .741 .907 r
.66789 .16975 .67007 .17279 .67462 .17114 .67244 .1681 Metetra
.664 .741 .907 r
.67244 .1681 .67462 .17114 .67917 .16949 .67699 .16644 Metetra
.664 .741 .907 r
.67699 .16644 .67917 .16949 .68373 .16784 .68156 .16479 Metetra
.664 .741 .907 r
.68156 .16479 .68373 .16784 .6883 .16619 .68613 .16313 Metetra
.664 .741 .907 r
.68613 .16313 .6883 .16619 .69287 .16453 .69071 .16147 Metetra
.664 .741 .907 r
.69071 .16147 .69287 .16453 .69745 .16287 .6953 .1598 Metetra
.664 .741 .907 r
.6953 .1598 .69745 .16287 .70204 .16121 .69989 .15813 Metetra
.664 .741 .907 r
.69989 .15813 .70204 .16121 .70664 .15954 .70449 .15646 Metetra
.664 .741 .907 r
.70449 .15646 .70664 .15954 .71124 .15788 .7091 .15479 Metetra
.664 .741 .907 r
.7091 .15479 .71124 .15788 .71585 .15621 .71372 .15311 Metetra
.664 .741 .907 r
.71372 .15311 .71585 .15621 .72047 .15453 .71835 .15144 Metetra
.664 .741 .907 r
.71835 .15144 .72047 .15453 .7251 .15286 .72298 .14975 Metetra
.664 .741 .907 r
.72298 .14975 .7251 .15286 .72973 .15118 .72762 .14807 Metetra
.664 .741 .907 r
.72762 .14807 .72973 .15118 .73438 .1495 .73226 .14638 Metetra
.664 .741 .907 r
.73226 .14638 .73438 .1495 .73903 .14781 .73692 .1447 Metetra
.664 .741 .907 r
.73692 .1447 .73903 .14781 .74368 .14612 .74158 .143 Metetra
.664 .741 .907 r
.74158 .143 .74368 .14612 .74835 .14443 .74625 .14131 Metetra
.664 .741 .907 r
.74625 .14131 .74835 .14443 .75302 .14274 .75093 .13961 Metetra
.664 .741 .907 r
.75093 .13961 .75302 .14274 .7577 .14105 .75561 .13791 Metetra
.664 .741 .907 r
.75561 .13791 .7577 .14105 .76239 .13935 .76031 .13621 Metetra
.664 .741 .907 r
.76031 .13621 .76239 .13935 .76708 .13765 .76501 .1345 Metetra
.664 .741 .907 r
.76501 .1345 .76708 .13765 .77178 .13594 .76971 .13279 Metetra
.664 .741 .907 r
.76971 .13279 .77178 .13594 .77649 .13424 .77443 .13108 Metetra
.664 .741 .907 r
.14514 .35598 .14783 .3585 .15158 .35713 .14889 .35462 Metetra
.664 .741 .907 r
.14889 .35462 .15158 .35713 .15533 .35577 .15265 .35325 Metetra
.664 .741 .907 r
.15265 .35325 .15533 .35577 .15909 .35441 .15641 .35188 Metetra
.664 .741 .907 r
.15641 .35188 .15909 .35441 .16286 .35304 .16018 .35051 Metetra
.664 .741 .907 r
.16018 .35051 .16286 .35304 .16663 .35167 .16396 .34914 Metetra
.664 .741 .907 r
.16396 .34914 .16663 .35167 .17041 .3503 .16774 .34776 Metetra
.664 .741 .907 r
.16774 .34776 .17041 .3503 .17419 .34893 .17152 .34639 Metetra
.664 .741 .907 r
.17152 .34639 .17419 .34893 .17798 .34755 .17531 .34501 Metetra
.664 .741 .907 r
.17531 .34501 .17798 .34755 .18178 .34617 .17911 .34363 Metetra
.664 .741 .907 r
.17911 .34363 .18178 .34617 .18558 .3448 .18291 .34224 Metetra
.664 .741 .907 r
.18291 .34224 .18558 .3448 .18938 .34341 .18672 .34086 Metetra
.664 .741 .907 r
.18672 .34086 .18938 .34341 .19319 .34203 .19054 .33947 Metetra
.664 .741 .907 r
.19054 .33947 .19319 .34203 .19701 .34065 .19436 .33808 Metetra
.664 .741 .907 r
.19436 .33808 .19701 .34065 .20083 .33926 .19818 .33669 Metetra
.664 .741 .907 r
.19818 .33669 .20083 .33926 .20466 .33787 .20201 .3353 Metetra
.664 .741 .907 r
.20201 .3353 .20466 .33787 .20849 .33648 .20585 .3339 Metetra
.664 .741 .907 r
.20585 .3339 .20849 .33648 .21233 .33509 .20969 .33251 Metetra
.664 .741 .907 r
.20969 .33251 .21233 .33509 .21618 .33369 .21354 .33111 Metetra
.664 .741 .907 r
.21354 .33111 .21618 .33369 .22003 .33229 .2174 .32971 Metetra
.664 .741 .907 r
.2174 .32971 .22003 .33229 .22388 .33089 .22125 .3283 Metetra
.664 .741 .907 r
.22125 .3283 .22388 .33089 .22774 .32949 .22512 .3269 Metetra
.664 .741 .907 r
.22512 .3269 .22774 .32949 .23161 .32809 .22899 .32549 Metetra
.664 .741 .907 r
.22899 .32549 .23161 .32809 .23549 .32668 .23287 .32408 Metetra
.664 .741 .907 r
.23287 .32408 .23549 .32668 .23936 .32527 .23675 .32267 Metetra
.664 .741 .907 r
.23675 .32267 .23936 .32527 .24325 .32386 .24064 .32126 Metetra
.664 .741 .907 r
.24064 .32126 .24325 .32386 .24714 .32245 .24453 .31984 Metetra
.664 .741 .907 r
.24453 .31984 .24714 .32245 .25104 .32104 .24843 .31842 Metetra
.664 .741 .907 r
.24843 .31842 .25104 .32104 .25494 .31962 .25234 .317 Metetra
.664 .741 .907 r
.25234 .317 .25494 .31962 .25885 .3182 .25625 .31558 Metetra
.664 .741 .907 r
.25625 .31558 .25885 .3182 .26276 .31678 .26017 .31415 Metetra
.95 .682 .493 r
.26017 .31415 .26276 .31678 .24766 .54656 .24485 .54408 Metetra
.944 .71 .554 r
.24485 .54408 .24766 .54656 .25186 .54522 .25277 .49737 Metetra
.744 .502 .564 r
.25277 .49737 .25186 .54522 .26069 .486 .25996 .45848 Metetra
.747 .516 .581 r
.25996 .45848 .26069 .486 .2673 .4532 .26576 .43587 Metetra
.759 .542 .602 r
.26576 .43587 .2673 .4532 .27287 .43305 .27096 .42044 Metetra
.765 .562 .624 r
.27096 .42044 .27287 .43305 .27794 .41888 .27583 .40889 Metetra
.767 .58 .645 r
.27583 .40889 .27794 .41888 .28273 .40808 .28051 .39973 Metetra
.767 .595 .665 r
.28051 .39973 .28273 .40808 .28735 .3994 .28505 .39215 Metetra
.766 .608 .684 r
.28505 .39215 .28735 .3994 .29186 .39216 .2895 .38568 Metetra
.763 .62 .701 r
.2895 .38568 .29186 .39216 .29628 .38594 .29388 .38004 Metetra
.76 .631 .717 r
.29388 .38004 .29628 .38594 .30064 .38047 .29822 .37502 Metetra
.757 .64 .732 r
.29822 .37502 .30064 .38047 .30496 .37559 .30252 .37048 Metetra
.753 .649 .745 r
.30252 .37048 .30496 .37559 .30925 .37117 .30679 .36633 Metetra
.75 .656 .757 r
.30679 .36633 .30925 .37117 .31351 .36711 .31104 .36249 Metetra
.746 .662 .768 r
.31104 .36249 .31351 .36711 .31775 .36335 .31527 .35892 Metetra
.742 .668 .778 r
.31527 .35892 .31775 .36335 .32198 .35984 .31949 .35556 Metetra
.738 .673 .787 r
.31949 .35556 .32198 .35984 .3262 .35654 .3237 .35239 Metetra
.735 .678 .795 r
.3237 .35239 .3262 .35654 .3304 .35342 .3279 .34938 Metetra
.731 .682 .803 r
.3279 .34938 .3304 .35342 .3346 .35044 .3321 .3465 Metetra
.728 .685 .809 r
.3321 .3465 .3346 .35044 .33879 .3476 .33629 .34374 Metetra
.724 .689 .815 r
.33629 .34374 .33879 .3476 .34298 .34488 .34047 .34109 Metetra
.721 .691 .821 r
.34047 .34109 .34298 .34488 .34716 .34226 .34466 .33853 Metetra
.718 .694 .826 r
.34466 .33853 .34716 .34226 .35135 .33972 .34884 .33605 Metetra
.715 .696 .831 r
.34884 .33605 .35135 .33972 .35553 .33727 .35303 .33364 Metetra
.713 .698 .835 r
.35303 .33364 .35553 .33727 .35971 .33488 .35721 .3313 Metetra
.71 .7 .839 r
.35721 .3313 .35971 .33488 .3639 .33256 .3614 .32902 Metetra
.707 .702 .843 r
.3614 .32902 .3639 .33256 .36808 .3303 .36558 .32679 Metetra
.705 .703 .846 r
.36558 .32679 .36808 .3303 .37227 .3281 .36977 .32461 Metetra
.703 .705 .849 r
.36977 .32461 .37227 .3281 .37646 .32594 .37396 .32248 Metetra
.7 .706 .852 r
.37396 .32248 .37646 .32594 .38065 .32382 .37815 .32039 Metetra
.698 .707 .854 r
.37815 .32039 .38065 .32382 .38484 .32174 .38235 .31833 Metetra
.696 .708 .857 r
.38235 .31833 .38484 .32174 .38904 .31971 .38655 .31631 Metetra
.694 .708 .859 r
.38655 .31631 .38904 .31971 .39324 .3177 .39076 .31433 Metetra
.692 .709 .861 r
.39076 .31433 .39324 .3177 .39745 .31573 .39496 .31237 Metetra
.69 .71 .863 r
.39496 .31237 .39745 .31573 .40165 .31379 .39917 .31044 Metetra
.934 .729 .602 r
.39917 .31044 .40165 .31379 .40587 .31188 .40404 .2919 Metetra
.567 .389 .599 r
.40404 .2919 .40587 .31188 .41069 .2934 .40822 .29028 Metetra
.668 .719 .887 r
.40822 .29028 .41069 .2934 .41488 .2918 .41242 .28869 Metetra
.667 .719 .888 r
.41242 .28869 .41488 .2918 .41908 .29021 .41662 .2871 Metetra
.666 .719 .888 r
.41662 .2871 .41908 .29021 .42328 .28864 .42082 .28553 Metetra
.665 .719 .889 r
.42082 .28553 .42328 .28864 .42749 .28708 .42504 .28396 Metetra
.664 .718 .889 r
.42504 .28396 .42749 .28708 .4317 .28553 .42925 .28241 Metetra
.662 .718 .89 r
.42925 .28241 .4317 .28553 .43592 .284 .43348 .28087 Metetra
.661 .718 .89 r
.43348 .28087 .43592 .284 .44015 .28247 .43771 .27934 Metetra
.66 .717 .891 r
.43771 .27934 .44015 .28247 .44438 .28096 .44194 .27783 Metetra
.659 .717 .891 r
.44194 .27783 .44438 .28096 .44862 .27946 .44618 .27632 Metetra
.658 .717 .892 r
.44618 .27632 .44862 .27946 .45286 .27797 .45043 .27483 Metetra
.657 .716 .892 r
.45043 .27483 .45286 .27797 .45712 .27649 .45469 .27334 Metetra
.655 .715 .892 r
.45469 .27334 .45712 .27649 .46137 .27503 .45895 .27187 Metetra
.654 .715 .893 r
.45895 .27187 .46137 .27503 .46564 .27358 .46322 .27041 Metetra
.653 .714 .893 r
.46322 .27041 .46564 .27358 .46991 .27214 .46749 .26897 Metetra
.651 .713 .893 r
.46749 .26897 .46991 .27214 .47419 .27071 .47177 .26753 Metetra
.65 .712 .893 r
.47177 .26753 .47419 .27071 .47822 .28626 .47606 .26611 Metetra
.016 0 .484 r
.47606 .26611 .47822 .28626 .48253 .28515 .48011 .28172 Metetra
.619 .684 .889 r
.48011 .28172 .48253 .28515 .48684 .28408 .48443 .28062 Metetra
.616 .681 .889 r
.48443 .28062 .48684 .28408 .49117 .28304 .48876 .27956 Metetra
.613 .679 .889 r
.48876 .27956 .49117 .28304 .4955 .28203 .4931 .27852 Metetra
.609 .676 .888 r
.4931 .27852 .4955 .28203 .49985 .28106 .49744 .27752 Metetra
.606 .673 .888 r
.49744 .27752 .49985 .28106 .5042 .28013 .5018 .27656 Metetra
.602 .669 .887 r
.5018 .27656 .5042 .28013 .50856 .27924 .50616 .27564 Metetra
.598 .665 .886 r
.50616 .27564 .50856 .27924 .51292 .27839 .51053 .27475 Metetra
.593 .661 .886 r
.51053 .27475 .51292 .27839 .5173 .27759 .51491 .27392 Metetra
.588 .657 .885 r
.51491 .27392 .5173 .27759 .52168 .27685 .5193 .27313 Metetra
.583 .652 .883 r
.5193 .27313 .52168 .27685 .52608 .27616 .52369 .2724 Metetra
.577 .646 .882 r
.52369 .2724 .52608 .27616 .53048 .27555 .5281 .27173 Metetra
.571 .64 .88 r
.5281 .27173 .53048 .27555 .5349 .275 .53252 .27112 Metetra
.564 .633 .879 r
.53252 .27112 .5349 .275 .53932 .27454 .53694 .2706 Metetra
.556 .626 .876 r
.53694 .2706 .53932 .27454 .54376 .27417 .54138 .27015 Metetra
.547 .617 .874 r
.54138 .27015 .54376 .27417 .5482 .2739 .54583 .26981 Metetra
.537 .607 .871 r
.54583 .26981 .5482 .2739 .55266 .27375 .55029 .26956 Metetra
.526 .597 .867 r
.55029 .26956 .55266 .27375 .55713 .27374 .55476 .26944 Metetra
.513 .584 .863 r
.55476 .26944 .55713 .27374 .56162 .27388 .55925 .26947 Metetra
.499 .57 .858 r
.55925 .26947 .56162 .27388 .56612 .27421 .56374 .26965 Metetra
.482 .553 .852 r
.56374 .26965 .56612 .27421 .57063 .27475 .56826 .27002 Metetra
.463 .534 .844 r
.56826 .27002 .57063 .27475 .57516 .27555 .57279 .27062 Metetra
.441 .511 .835 r
.57279 .27062 .57516 .27555 .57972 .27665 .57734 .27149 Metetra
.415 .485 .823 r
.57734 .27149 .57972 .27665 .58429 .27814 .58191 .27268 Metetra
.384 .454 .809 r
.58191 .27268 .58429 .27814 .58889 .28009 .5865 .27427 Metetra
.347 .416 .791 r
.5865 .27427 .58889 .28009 .59353 .28264 .59112 .27637 Metetra
.303 .372 .768 r
.59112 .27637 .59353 .28264 .5982 .28597 .59577 .2791 Metetra
.251 .318 .738 r
.59577 .2791 .5982 .28597 .60291 .29036 .60047 .28268 Metetra
.189 .255 .701 r
.60047 .28268 .60291 .29036 .6077 .29623 .60521 .2874 Metetra
.115 .179 .653 r
.60521 .2874 .6077 .29623 .61257 .30428 .61003 .29376 Metetra
.029 .091 .593 r
.61003 .29376 .61257 .30428 .61759 .31582 .61495 .30258 Metetra
0 0 .521 r
.61495 .30258 .61759 .31582 .62284 .33353 .62003 .31542 Metetra
0 0 .436 r
.62003 .31542 .62284 .33353 .62858 .36431 .6254 .33567 Metetra
0 0 .338 r
.6254 .33567 .62858 .36431 .63537 .4225 .6314 .37276 Metetra
0 0 .428 r
.6314 .37276 .63537 .4225 .64021 .42095 .63782 .41808 Metetra
.978 .687 .393 r
.63782 .41808 .64021 .42095 .63624 .18123 .63401 .17822 Metetra
.664 .741 .907 r
.63401 .17822 .63624 .18123 .64074 .1796 .63852 .17658 Metetra
.664 .741 .907 r
.63852 .17658 .64074 .1796 .64525 .17797 .64303 .17494 Metetra
.664 .741 .907 r
.64303 .17494 .64525 .17797 .64976 .17633 .64755 .1733 Metetra
.664 .741 .907 r
.64755 .1733 .64976 .17633 .65428 .17469 .65207 .17165 Metetra
.664 .741 .907 r
.65207 .17165 .65428 .17469 .65881 .17304 .65661 .17 Metetra
.664 .741 .907 r
.65661 .17 .65881 .17304 .66334 .1714 .66115 .16835 Metetra
.664 .741 .907 r
.66115 .16835 .66334 .1714 .66789 .16975 .6657 .1667 Metetra
.664 .741 .907 r
.6657 .1667 .66789 .16975 .67244 .1681 .67025 .16504 Metetra
.664 .741 .907 r
.67025 .16504 .67244 .1681 .67699 .16644 .67481 .16338 Metetra
.664 .741 .907 r
.67481 .16338 .67699 .16644 .68156 .16479 .67938 .16172 Metetra
.664 .741 .907 r
.67938 .16172 .68156 .16479 .68613 .16313 .68396 .16006 Metetra
.664 .741 .907 r
.68396 .16006 .68613 .16313 .69071 .16147 .68855 .15839 Metetra
.664 .741 .907 r
.68855 .15839 .69071 .16147 .6953 .1598 .69314 .15672 Metetra
.664 .741 .907 r
.69314 .15672 .6953 .1598 .69989 .15813 .69774 .15505 Metetra
.664 .741 .907 r
.69774 .15505 .69989 .15813 .70449 .15646 .70234 .15337 Metetra
.664 .741 .907 r
.70234 .15337 .70449 .15646 .7091 .15479 .70696 .15169 Metetra
.664 .741 .907 r
.70696 .15169 .7091 .15479 .71372 .15311 .71158 .15001 Metetra
.664 .741 .907 r
.71158 .15001 .71372 .15311 .71835 .15144 .71621 .14833 Metetra
.664 .741 .907 r
.71621 .14833 .71835 .15144 .72298 .14975 .72085 .14664 Metetra
.664 .741 .907 r
.72085 .14664 .72298 .14975 .72762 .14807 .72549 .14496 Metetra
.664 .741 .907 r
.72549 .14496 .72762 .14807 .73226 .14638 .73014 .14326 Metetra
.664 .741 .907 r
.73014 .14326 .73226 .14638 .73692 .1447 .7348 .14157 Metetra
.664 .741 .907 r
.7348 .14157 .73692 .1447 .74158 .143 .73947 .13987 Metetra
.664 .741 .907 r
.73947 .13987 .74158 .143 .74625 .14131 .74415 .13817 Metetra
.664 .741 .907 r
.74415 .13817 .74625 .14131 .75093 .13961 .74883 .13647 Metetra
.664 .741 .907 r
.74883 .13647 .75093 .13961 .75561 .13791 .75352 .13476 Metetra
.664 .741 .907 r
.75352 .13476 .75561 .13791 .76031 .13621 .75822 .13306 Metetra
.664 .741 .907 r
.75822 .13306 .76031 .13621 .76501 .1345 .76292 .13134 Metetra
.664 .741 .907 r
.76292 .13134 .76501 .1345 .76971 .13279 .76764 .12963 Metetra
.664 .741 .907 r
.76764 .12963 .76971 .13279 .77443 .13108 .77236 .12791 Metetra
.664 .741 .907 r
.14244 .35346 .14514 .35598 .14889 .35462 .14619 .35209 Metetra
.664 .741 .907 r
.14619 .35209 .14889 .35462 .15265 .35325 .14996 .35072 Metetra
.664 .741 .907 r
.14996 .35072 .15265 .35325 .15641 .35188 .15372 .34935 Metetra
.664 .741 .907 r
.15372 .34935 .15641 .35188 .16018 .35051 .15749 .34798 Metetra
.664 .741 .907 r
.15749 .34798 .16018 .35051 .16396 .34914 .16127 .3466 Metetra
.664 .741 .907 r
.16127 .3466 .16396 .34914 .16774 .34776 .16506 .34522 Metetra
.664 .741 .907 r
.16506 .34522 .16774 .34776 .17152 .34639 .16885 .34384 Metetra
.664 .741 .907 r
.16885 .34384 .17152 .34639 .17531 .34501 .17264 .34246 Metetra
.664 .741 .907 r
.17264 .34246 .17531 .34501 .17911 .34363 .17644 .34107 Metetra
.664 .741 .907 r
.17644 .34107 .17911 .34363 .18291 .34224 .18025 .33969 Metetra
.664 .741 .907 r
.18025 .33969 .18291 .34224 .18672 .34086 .18406 .3383 Metetra
.664 .741 .907 r
.18406 .3383 .18672 .34086 .19054 .33947 .18788 .33691 Metetra
.664 .741 .907 r
.18788 .33691 .19054 .33947 .19436 .33808 .1917 .33551 Metetra
.664 .741 .907 r
.1917 .33551 .19436 .33808 .19818 .33669 .19553 .33412 Metetra
.664 .741 .907 r
.19553 .33412 .19818 .33669 .20201 .3353 .19936 .33272 Metetra
.664 .741 .907 r
.19936 .33272 .20201 .3353 .20585 .3339 .2032 .33132 Metetra
.664 .741 .907 r
.2032 .33132 .20585 .3339 .20969 .33251 .20705 .32992 Metetra
.664 .741 .907 r
.20705 .32992 .20969 .33251 .21354 .33111 .2109 .32852 Metetra
.664 .741 .907 r
.2109 .32852 .21354 .33111 .2174 .32971 .21476 .32711 Metetra
.664 .741 .907 r
.21476 .32711 .2174 .32971 .22125 .3283 .21862 .32571 Metetra
.664 .741 .907 r
.21862 .32571 .22125 .3283 .22512 .3269 .22249 .3243 Metetra
.664 .741 .907 r
.22249 .3243 .22512 .3269 .22899 .32549 .22636 .32289 Metetra
.664 .741 .907 r
.22636 .32289 .22899 .32549 .23287 .32408 .23024 .32147 Metetra
.664 .741 .907 r
.23024 .32147 .23287 .32408 .23675 .32267 .23413 .32006 Metetra
.664 .741 .907 r
.23413 .32006 .23675 .32267 .24064 .32126 .23802 .31864 Metetra
.664 .741 .907 r
.23802 .31864 .24064 .32126 .24453 .31984 .24192 .31722 Metetra
.664 .741 .907 r
.24192 .31722 .24453 .31984 .24843 .31842 .24582 .3158 Metetra
.664 .741 .907 r
.24582 .3158 .24843 .31842 .25234 .317 .24973 .31437 Metetra
.664 .741 .907 r
.24973 .31437 .25234 .317 .25625 .31558 .25365 .31295 Metetra
.95 .682 .494 r
.25365 .31295 .25625 .31558 .26017 .31415 .23783 .54294 Metetra
.458 .235 .487 r
.23783 .54294 .26017 .31415 .24485 .54408 .24453 .51187 Metetra
.812 .566 .567 r
.24453 .51187 .24485 .54408 .25277 .49737 .2525 .46472 Metetra
.741 .506 .575 r
.2525 .46472 .25277 .49737 .25996 .45848 .2586 .43912 Metetra
.756 .535 .596 r
.2586 .43912 .25996 .45848 .26576 .43587 .26395 .42222 Metetra
.763 .556 .618 r
.26395 .42222 .26576 .43587 .27096 .42044 .26891 .40984 Metetra
.766 .575 .639 r
.26891 .40984 .27096 .42044 .27583 .40889 .27364 .40014 Metetra
.767 .59 .659 r
.27364 .40014 .27583 .40889 .28051 .39973 .27822 .3922 Metetra
.766 .604 .679 r
.27822 .3922 .28051 .39973 .28505 .39215 .2827 .38547 Metetra
.764 .617 .697 r
.2827 .38547 .28505 .39215 .2895 .38568 .2871 .37963 Metetra
.761 .628 .713 r
.2871 .37963 .2895 .38568 .29388 .38004 .29146 .37446 Metetra
.758 .638 .728 r
.29146 .37446 .29388 .38004 .29822 .37502 .29577 .3698 Metetra
.754 .646 .742 r
.29577 .3698 .29822 .37502 .30252 .37048 .30005 .36556 Metetra
.751 .654 .754 r
.30005 .36556 .30252 .37048 .30679 .36633 .30431 .36164 Metetra
.747 .661 .765 r
.30431 .36164 .30679 .36633 .31104 .36249 .30855 .358 Metetra
.743 .667 .776 r
.30855 .358 .31104 .36249 .31527 .35892 .31277 .35459 Metetra
.739 .672 .785 r
.31277 .35459 .31527 .35892 .31949 .35556 .31699 .35137 Metetra
.736 .677 .793 r
.31699 .35137 .31949 .35556 .3237 .35239 .32119 .34832 Metetra
.732 .681 .801 r
.32119 .34832 .3237 .35239 .3279 .34938 .32539 .3454 Metetra
.729 .685 .808 r
.32539 .3454 .3279 .34938 .3321 .3465 .32958 .34261 Metetra
.725 .688 .814 r
.32958 .34261 .3321 .3465 .33629 .34374 .33377 .33993 Metetra
.722 .691 .82 r
.33377 .33993 .33629 .34374 .34047 .34109 .33796 .33734 Metetra
.719 .693 .825 r
.33796 .33734 .34047 .34109 .34466 .33853 .34214 .33483 Metetra
.716 .696 .83 r
.34214 .33483 .34466 .33853 .34884 .33605 .34633 .3324 Metetra
.713 .698 .834 r
.34633 .3324 .34884 .33605 .35303 .33364 .35051 .33004 Metetra
.711 .7 .838 r
.35051 .33004 .35303 .33364 .35721 .3313 .3547 .32774 Metetra
.708 .701 .842 r
.3547 .32774 .35721 .3313 .3614 .32902 .35889 .32549 Metetra
.706 .703 .845 r
.35889 .32549 .3614 .32902 .36558 .32679 .36307 .3233 Metetra
.703 .704 .848 r
.36307 .3233 .36558 .32679 .36977 .32461 .36726 .32114 Metetra
.701 .706 .851 r
.36726 .32114 .36977 .32461 .37396 .32248 .37146 .31904 Metetra
.699 .707 .854 r
.37146 .31904 .37396 .32248 .37815 .32039 .37565 .31696 Metetra
.697 .708 .856 r
.37565 .31696 .37815 .32039 .38235 .31833 .37985 .31493 Metetra
.695 .708 .858 r
.37985 .31493 .38235 .31833 .38655 .31631 .38406 .31293 Metetra
.693 .709 .861 r
.38406 .31293 .38655 .31631 .39076 .31433 .38826 .31096 Metetra
.691 .71 .863 r
.38826 .31096 .39076 .31433 .39496 .31237 .39247 .30902 Metetra
.934 .729 .602 r
.39247 .30902 .39496 .31237 .39917 .31044 .39737 .2904 Metetra
.567 .388 .599 r
.39737 .2904 .39917 .31044 .40404 .2919 .40156 .28878 Metetra
.669 .72 .887 r
.40156 .28878 .40404 .2919 .40822 .29028 .40575 .28717 Metetra
.668 .72 .887 r
.40575 .28717 .40822 .29028 .41242 .28869 .40995 .28557 Metetra
.667 .719 .888 r
.40995 .28557 .41242 .28869 .41662 .2871 .41415 .28398 Metetra
.666 .719 .889 r
.41415 .28398 .41662 .2871 .42082 .28553 .41836 .28241 Metetra
.665 .719 .889 r
.41836 .28241 .42082 .28553 .42504 .28396 .42257 .28084 Metetra
.663 .719 .89 r
.42257 .28084 .42504 .28396 .42925 .28241 .4268 .27929 Metetra
.662 .719 .89 r
.4268 .27929 .42925 .28241 .43348 .28087 .43102 .27775 Metetra
.661 .718 .891 r
.43102 .27775 .43348 .28087 .43771 .27934 .43526 .27622 Metetra
.66 .718 .891 r
.43526 .27622 .43771 .27934 .44194 .27783 .4395 .27469 Metetra
.659 .718 .892 r
.4395 .27469 .44194 .27783 .44618 .27632 .44374 .27318 Metetra
.658 .717 .892 r
.44374 .27318 .44618 .27632 .45043 .27483 .44799 .27168 Metetra
.657 .717 .892 r
.44799 .27168 .45043 .27483 .45469 .27334 .45225 .27019 Metetra
.656 .716 .893 r
.45225 .27019 .45469 .27334 .45895 .27187 .45652 .26872 Metetra
.654 .715 .893 r
.45652 .26872 .45895 .27187 .46322 .27041 .46079 .26725 Metetra
.653 .715 .893 r
.46079 .26725 .46322 .27041 .46749 .26897 .46507 .26579 Metetra
.652 .714 .894 r
.46507 .26579 .46749 .26897 .47177 .26753 .46935 .26435 Metetra
.651 .713 .894 r
.46935 .26435 .47177 .26753 .47606 .26611 .47365 .26292 Metetra
.649 .712 .894 r
.47365 .26292 .47606 .26611 .48011 .28172 .47795 .2615 Metetra
.015 0 .483 r
.47795 .2615 .48011 .28172 .48443 .28062 .48202 .27717 Metetra
.617 .683 .889 r
.48202 .27717 .48443 .28062 .48876 .27956 .48635 .27608 Metetra
.614 .681 .889 r
.48635 .27608 .48876 .27956 .4931 .27852 .49069 .27503 Metetra
.611 .678 .889 r
.49069 .27503 .4931 .27852 .49744 .27752 .49504 .274 Metetra
.608 .675 .888 r
.49504 .274 .49744 .27752 .5018 .27656 .49939 .27301 Metetra
.604 .672 .888 r
.49939 .27301 .5018 .27656 .50616 .27564 .50376 .27205 Metetra
.6 .668 .887 r
.50376 .27205 .50616 .27564 .51053 .27475 .50813 .27113 Metetra
.596 .664 .886 r
.50813 .27113 .51053 .27475 .51491 .27392 .51251 .27026 Metetra
.592 .66 .885 r
.51251 .27026 .51491 .27392 .5193 .27313 .51691 .26943 Metetra
.587 .656 .884 r
.51691 .26943 .5193 .27313 .52369 .2724 .52131 .26866 Metetra
.581 .65 .883 r
.52131 .26866 .52369 .2724 .5281 .27173 .52571 .26794 Metetra
.575 .645 .882 r
.52571 .26794 .5281 .27173 .53252 .27112 .53013 .26728 Metetra
.569 .638 .88 r
.53013 .26728 .53252 .27112 .53694 .2706 .53456 .26669 Metetra
.562 .631 .878 r
.53456 .26669 .53694 .2706 .54138 .27015 .539 .26618 Metetra
.554 .624 .876 r
.539 .26618 .54138 .27015 .54583 .26981 .54345 .26576 Metetra
.545 .615 .873 r
.54345 .26576 .54583 .26981 .55029 .26956 .54791 .26543 Metetra
.534 .605 .87 r
.54791 .26543 .55029 .26956 .55476 .26944 .55238 .26521 Metetra
.523 .593 .866 r
.55238 .26521 .55476 .26944 .55925 .26947 .55687 .26513 Metetra
.51 .58 .862 r
.55687 .26513 .55925 .26947 .56374 .26965 .56137 .26518 Metetra
.495 .565 .856 r
.56137 .26518 .56374 .26965 .56826 .27002 .56588 .26541 Metetra
.478 .548 .85 r
.56588 .26541 .56826 .27002 .57279 .27062 .57041 .26583 Metetra
.458 .528 .842 r
.57041 .26583 .57279 .27062 .57734 .27149 .57496 .26649 Metetra
.435 .505 .832 r
.57496 .26649 .57734 .27149 .58191 .27268 .57952 .26743 Metetra
.407 .477 .82 r
.57952 .26743 .58191 .27268 .5865 .27427 .58411 .26871 Metetra
.375 .444 .804 r
.58411 .26871 .5865 .27427 .59112 .27637 .58872 .27042 Metetra
.337 .405 .785 r
.58872 .27042 .59112 .27637 .59577 .2791 .59336 .27265 Metetra
.291 .359 .76 r
.59336 .27265 .59577 .2791 .60047 .28268 .59803 .27558 Metetra
.237 .303 .729 r
.59803 .27558 .60047 .28268 .60521 .2874 .60275 .27942 Metetra
.172 .236 .689 r
.60275 .27942 .60521 .2874 .61003 .29376 .60753 .28451 Metetra
.096 .158 .639 r
.60753 .28451 .61003 .29376 .61495 .30258 .61238 .29142 Metetra
.007 .067 .576 r
.61238 .29142 .61495 .30258 .62003 .31542 .61735 .3011 Metetra
0 0 .501 r
.61735 .3011 .62003 .31542 .6254 .33567 .62251 .31544 Metetra
0 0 .413 r
.62251 .31544 .6254 .33567 .6314 .37276 .62802 .33879 Metetra
0 0 .312 r
.62802 .33879 .6314 .37276 .63782 .41808 .63437 .38446 Metetra
.015 0 .461 r
.63437 .38446 .63782 .41808 .63401 .17822 .64029 .41364 Metetra
0 0 .345 r
.64029 .41364 .63401 .17822 .63852 .17658 .63629 .17355 Metetra
.664 .741 .907 r
.63629 .17355 .63852 .17658 .64303 .17494 .64081 .1719 Metetra
.664 .741 .907 r
.64081 .1719 .64303 .17494 .64755 .1733 .64533 .17026 Metetra
.664 .741 .907 r
.64533 .17026 .64755 .1733 .65207 .17165 .64986 .16861 Metetra
.664 .741 .907 r
.64986 .16861 .65207 .17165 .65661 .17 .6544 .16695 Metetra
.664 .741 .907 r
.6544 .16695 .65661 .17 .66115 .16835 .65895 .1653 Metetra
.664 .741 .907 r
.65895 .1653 .66115 .16835 .6657 .1667 .6635 .16364 Metetra
.664 .741 .907 r
.6635 .16364 .6657 .1667 .67025 .16504 .66806 .16198 Metetra
.664 .741 .907 r
.66806 .16198 .67025 .16504 .67481 .16338 .67263 .16031 Metetra
.664 .741 .907 r
.67263 .16031 .67481 .16338 .67938 .16172 .6772 .15865 Metetra
.664 .741 .907 r
.6772 .15865 .67938 .16172 .68396 .16006 .68178 .15698 Metetra
.664 .741 .907 r
.68178 .15698 .68396 .16006 .68855 .15839 .68637 .1553 Metetra
.664 .741 .907 r
.68637 .1553 .68855 .15839 .69314 .15672 .69097 .15363 Metetra
.664 .741 .907 r
.69097 .15363 .69314 .15672 .69774 .15505 .69558 .15195 Metetra
.664 .741 .907 r
.69558 .15195 .69774 .15505 .70234 .15337 .70019 .15027 Metetra
.664 .741 .907 r
.70019 .15027 .70234 .15337 .70696 .15169 .70481 .14859 Metetra
.664 .741 .907 r
.70481 .14859 .70696 .15169 .71158 .15001 .70943 .1469 Metetra
.664 .741 .907 r
.70943 .1469 .71158 .15001 .71621 .14833 .71407 .14522 Metetra
.664 .741 .907 r
.71407 .14522 .71621 .14833 .72085 .14664 .71871 .14352 Metetra
.664 .741 .907 r
.71871 .14352 .72085 .14664 .72549 .14496 .72336 .14183 Metetra
.664 .741 .907 r
.72336 .14183 .72549 .14496 .73014 .14326 .72802 .14013 Metetra
.664 .741 .907 r
.72802 .14013 .73014 .14326 .7348 .14157 .73268 .13843 Metetra
.664 .741 .907 r
.73268 .13843 .7348 .14157 .73947 .13987 .73736 .13673 Metetra
.664 .741 .907 r
.73736 .13673 .73947 .13987 .74415 .13817 .74204 .13503 Metetra
.664 .741 .907 r
.74204 .13503 .74415 .13817 .74883 .13647 .74673 .13332 Metetra
.664 .741 .907 r
.74673 .13332 .74883 .13647 .75352 .13476 .75142 .13161 Metetra
.664 .741 .907 r
.75142 .13161 .75352 .13476 .75822 .13306 .75613 .12989 Metetra
.664 .741 .907 r
.75613 .12989 .75822 .13306 .76292 .13134 .76084 .12818 Metetra
.664 .741 .907 r
.76084 .12818 .76292 .13134 .76764 .12963 .76556 .12646 Metetra
.664 .741 .907 r
.76556 .12646 .76764 .12963 .77236 .12791 .77028 .12474 Metetra
.664 .741 .907 r
.13973 .35093 .14244 .35346 .14619 .35209 .14349 .34956 Metetra
.664 .741 .907 r
.14349 .34956 .14619 .35209 .14996 .35072 .14725 .34819 Metetra
.664 .741 .907 r
.14725 .34819 .14996 .35072 .15372 .34935 .15103 .34681 Metetra
.664 .741 .907 r
.15103 .34681 .15372 .34935 .15749 .34798 .1548 .34543 Metetra
.664 .741 .907 r
.1548 .34543 .15749 .34798 .16127 .3466 .15858 .34405 Metetra
.664 .741 .907 r
.15858 .34405 .16127 .3466 .16506 .34522 .16237 .34267 Metetra
.664 .741 .907 r
.16237 .34267 .16506 .34522 .16885 .34384 .16616 .34129 Metetra
.664 .741 .907 r
.16616 .34129 .16885 .34384 .17264 .34246 .16996 .3399 Metetra
.664 .741 .907 r
.16996 .3399 .17264 .34246 .17644 .34107 .17376 .33851 Metetra
.664 .741 .907 r
.17376 .33851 .17644 .34107 .18025 .33969 .17757 .33712 Metetra
.664 .741 .907 r
.17757 .33712 .18025 .33969 .18406 .3383 .18139 .33573 Metetra
.664 .741 .907 r
.18139 .33573 .18406 .3383 .18788 .33691 .18521 .33433 Metetra
.664 .741 .907 r
.18521 .33433 .18788 .33691 .1917 .33551 .18903 .33294 Metetra
.664 .741 .907 r
.18903 .33294 .1917 .33551 .19553 .33412 .19287 .33154 Metetra
.664 .741 .907 r
.19287 .33154 .19553 .33412 .19936 .33272 .1967 .33014 Metetra
.664 .741 .907 r
.1967 .33014 .19936 .33272 .2032 .33132 .20055 .32874 Metetra
.664 .741 .907 r
.20055 .32874 .2032 .33132 .20705 .32992 .2044 .32733 Metetra
.664 .741 .907 r
.2044 .32733 .20705 .32992 .2109 .32852 .20825 .32592 Metetra
.664 .741 .907 r
.20825 .32592 .2109 .32852 .21476 .32711 .21211 .32451 Metetra
.664 .741 .907 r
.21211 .32451 .21476 .32711 .21862 .32571 .21598 .3231 Metetra
.664 .741 .907 r
.21598 .3231 .21862 .32571 .22249 .3243 .21985 .32169 Metetra
.664 .741 .907 r
.21985 .32169 .22249 .3243 .22636 .32289 .22373 .32028 Metetra
.664 .741 .907 r
.22373 .32028 .22636 .32289 .23024 .32147 .22761 .31886 Metetra
.664 .741 .907 r
.22761 .31886 .23024 .32147 .23413 .32006 .2315 .31744 Metetra
.664 .741 .907 r
.2315 .31744 .23413 .32006 .23802 .31864 .2354 .31602 Metetra
.664 .741 .907 r
.2354 .31602 .23802 .31864 .24192 .31722 .2393 .31459 Metetra
.664 .741 .907 r
.2393 .31459 .24192 .31722 .24582 .3158 .2432 .31317 Metetra
.664 .741 .907 r
.2432 .31317 .24582 .3158 .24973 .31437 .24712 .31174 Metetra
.949 .682 .495 r
.24712 .31174 .24973 .31437 .25365 .31295 .2308 .5418 Metetra
.501 .27 .496 r
.2308 .5418 .25365 .31295 .23783 .54294 .23581 .53103 Metetra
.906 .661 .556 r
.23581 .53103 .23783 .54294 .24453 .51187 .24489 .47219 Metetra
.733 .496 .569 r
.24489 .47219 .24453 .51187 .2525 .46472 .25136 .44287 Metetra
.752 .527 .59 r
.25136 .44287 .2525 .46472 .2586 .43912 .25689 .42426 Metetra
.761 .55 .612 r
.25689 .42426 .2586 .43912 .26395 .42222 .26195 .41092 Metetra
.765 .569 .633 r
.26195 .41092 .26395 .42222 .26891 .40984 .26675 .40064 Metetra
.766 .586 .654 r
.26675 .40064 .26891 .40984 .27364 .40014 .27137 .39231 Metetra
.766 .601 .674 r
.27137 .39231 .27364 .40014 .27822 .3922 .27588 .38531 Metetra
.764 .613 .692 r
.27588 .38531 .27822 .3922 .2827 .38547 .28031 .37926 Metetra
.761 .625 .709 r
.28031 .37926 .2827 .38547 .2871 .37963 .28468 .37393 Metetra
.758 .635 .724 r
.28468 .37393 .2871 .37963 .29146 .37446 .28901 .36915 Metetra
.755 .644 .738 r
.28901 .36915 .29146 .37446 .29577 .3698 .2933 .3648 Metetra
.751 .652 .751 r
.2933 .3648 .29577 .3698 .30005 .36556 .29757 .36081 Metetra
.748 .659 .762 r
.29757 .36081 .30005 .36556 .30431 .36164 .30182 .3571 Metetra
.744 .665 .773 r
.30182 .3571 .30431 .36164 .30855 .358 .30605 .35363 Metetra
.74 .67 .782 r
.30605 .35363 .30855 .358 .31277 .35459 .31027 .35036 Metetra
.736 .675 .791 r
.31027 .35036 .31277 .35459 .31699 .35137 .31448 .34726 Metetra
.733 .68 .799 r
.31448 .34726 .31699 .35137 .32119 .34832 .31868 .34431 Metetra
.729 .684 .806 r
.31868 .34431 .32119 .34832 .32539 .3454 .32287 .34148 Metetra
.726 .687 .812 r
.32287 .34148 .32539 .3454 .32958 .34261 .32706 .33877 Metetra
.723 .69 .818 r
.32706 .33877 .32958 .34261 .33377 .33993 .33125 .33615 Metetra
.72 .693 .823 r
.33125 .33615 .33377 .33993 .33796 .33734 .33544 .33362 Metetra
.717 .695 .828 r
.33544 .33362 .33796 .33734 .34214 .33483 .33962 .33117 Metetra
.714 .697 .833 r
.33962 .33117 .34214 .33483 .34633 .3324 .34381 .32879 Metetra
.712 .699 .837 r
.34381 .32879 .34633 .3324 .35051 .33004 .34799 .32647 Metetra
.709 .701 .841 r
.34799 .32647 .35051 .33004 .3547 .32774 .35218 .3242 Metetra
.707 .703 .844 r
.35218 .3242 .3547 .32774 .35889 .32549 .35637 .32199 Metetra
.704 .704 .847 r
.35637 .32199 .35889 .32549 .36307 .3233 .36056 .31982 Metetra
.702 .705 .85 r
.36056 .31982 .36307 .3233 .36726 .32114 .36475 .31769 Metetra
.7 .707 .853 r
.36475 .31769 .36726 .32114 .37146 .31904 .36895 .31561 Metetra
.698 .708 .855 r
.36895 .31561 .37146 .31904 .37565 .31696 .37315 .31356 Metetra
.696 .709 .858 r
.37315 .31356 .37565 .31696 .37985 .31493 .37735 .31154 Metetra
.694 .709 .86 r
.37735 .31154 .37985 .31493 .38406 .31293 .38155 .30955 Metetra
.692 .71 .862 r
.38155 .30955 .38406 .31293 .38826 .31096 .38576 .3076 Metetra
.934 .728 .602 r
.38576 .3076 .38826 .31096 .39247 .30902 .3907 .28892 Metetra
.566 .387 .598 r
.3907 .28892 .39247 .30902 .39737 .2904 .39488 .28729 Metetra
.67 .72 .886 r
.39488 .28729 .39737 .2904 .40156 .28878 .39907 .28566 Metetra
.669 .72 .887 r
.39907 .28566 .40156 .28878 .40575 .28717 .40327 .28405 Metetra
.668 .72 .888 r
.40327 .28405 .40575 .28717 .40995 .28557 .40747 .28245 Metetra
.667 .72 .889 r
.40747 .28245 .40995 .28557 .41415 .28398 .41168 .28087 Metetra
.666 .72 .889 r
.41168 .28087 .41415 .28398 .41836 .28241 .41589 .27929 Metetra
.664 .72 .89 r
.41589 .27929 .41836 .28241 .42257 .28084 .42011 .27772 Metetra
.663 .719 .89 r
.42011 .27772 .42257 .28084 .4268 .27929 .42433 .27617 Metetra
.662 .719 .891 r
.42433 .27617 .4268 .27929 .43102 .27775 .42856 .27462 Metetra
.661 .719 .891 r
.42856 .27462 .43102 .27775 .43526 .27622 .4328 .27308 Metetra
.66 .719 .892 r
.4328 .27308 .43526 .27622 .4395 .27469 .43704 .27156 Metetra
.659 .718 .892 r
.43704 .27156 .4395 .27469 .44374 .27318 .44129 .27004 Metetra
.658 .718 .893 r
.44129 .27004 .44374 .27318 .44799 .27168 .44555 .26854 Metetra
.657 .717 .893 r
.44555 .26854 .44799 .27168 .45225 .27019 .44981 .26704 Metetra
.656 .717 .893 r
.44981 .26704 .45225 .27019 .45652 .26872 .45408 .26556 Metetra
.655 .716 .893 r
.45408 .26556 .45652 .26872 .46079 .26725 .45836 .26408 Metetra
.653 .715 .894 r
.45836 .26408 .46079 .26725 .46507 .26579 .46264 .26262 Metetra
.652 .715 .894 r
.46264 .26262 .46507 .26579 .46935 .26435 .46693 .26117 Metetra
.651 .714 .894 r
.46693 .26117 .46935 .26435 .47365 .26292 .47122 .25973 Metetra
.65 .713 .894 r
.47122 .25973 .47365 .26292 .47795 .2615 .47553 .2583 Metetra
.648 .712 .894 r
.47553 .2583 .47795 .2615 .48202 .27717 .47984 .25688 Metetra
.014 0 .483 r
.47984 .25688 .48202 .27717 .48635 .27608 .48393 .27262 Metetra
.616 .683 .89 r
.48393 .27262 .48635 .27608 .49069 .27503 .48827 .27154 Metetra
.613 .68 .889 r
.48827 .27154 .49069 .27503 .49504 .274 .49262 .27048 Metetra
.61 .677 .889 r
.49262 .27048 .49504 .274 .49939 .27301 .49698 .26946 Metetra
.607 .674 .888 r
.49698 .26946 .49939 .27301 .50376 .27205 .50135 .26848 Metetra
.603 .671 .888 r
.50135 .26848 .50376 .27205 .50813 .27113 .50573 .26753 Metetra
.599 .667 .887 r
.50573 .26753 .50813 .27113 .51251 .27026 .51011 .26662 Metetra
.595 .663 .886 r
.51011 .26662 .51251 .27026 .51691 .26943 .51451 .26575 Metetra
.59 .659 .885 r
.51451 .26575 .51691 .26943 .52131 .26866 .51891 .26493 Metetra
.585 .654 .884 r
.51891 .26493 .52131 .26866 .52571 .26794 .52332 .26417 Metetra
.58 .649 .883 r
.52332 .26417 .52571 .26794 .53013 .26728 .52774 .26346 Metetra
.574 .643 .881 r
.52774 .26346 .53013 .26728 .53456 .26669 .53217 .26282 Metetra
.567 .637 .88 r
.53217 .26282 .53456 .26669 .539 .26618 .53662 .26224 Metetra
.559 .629 .878 r
.53662 .26224 .539 .26618 .54345 .26576 .54107 .26175 Metetra
.551 .621 .875 r
.54107 .26175 .54345 .26576 .54791 .26543 .54553 .26135 Metetra
.542 .612 .872 r
.54553 .26135 .54791 .26543 .55238 .26521 .55 .26104 Metetra
.531 .602 .869 r
.55 .26104 .55238 .26521 .55687 .26513 .55449 .26085 Metetra
.52 .59 .865 r
.55449 .26085 .55687 .26513 .56137 .26518 .55899 .26079 Metetra
.506 .577 .86 r
.55899 .26079 .56137 .26518 .56588 .26541 .5635 .26089 Metetra
.491 .561 .855 r
.5635 .26089 .56588 .26541 .57041 .26583 .56803 .26115 Metetra
.473 .543 .848 r
.56803 .26115 .57041 .26583 .57496 .26649 .57257 .26163 Metetra
.452 .522 .839 r
.57257 .26163 .57496 .26649 .57952 .26743 .57713 .26235 Metetra
.428 .498 .829 r
.57713 .26235 .57952 .26743 .58411 .26871 .58172 .26336 Metetra
.4 .469 .816 r
.58172 .26336 .58411 .26871 .58872 .27042 .58632 .26474 Metetra
.366 .435 .8 r
.58632 .26474 .58872 .27042 .59336 .27265 .59095 .26656 Metetra
.327 .394 .779 r
.59095 .26656 .59336 .27265 .59803 .27558 .59561 .26896 Metetra
.279 .345 .753 r
.59561 .26896 .59803 .27558 .60275 .27942 .60031 .27209 Metetra
.222 .287 .719 r
.60031 .27209 .60275 .27942 .60753 .28451 .60505 .2762 Metetra
.155 .218 .677 r
.60505 .2762 .60753 .28451 .61238 .29142 .60986 .2817 Metetra
.076 .137 .624 r
.60986 .2817 .61238 .29142 .61735 .3011 .61475 .2892 Metetra
0 .043 .558 r
.61475 .2892 .61735 .3011 .62251 .31544 .61978 .29986 Metetra
0 0 .48 r
.61978 .29986 .62251 .31544 .62802 .33879 .62502 .31597 Metetra
0 0 .39 r
.62502 .31597 .62802 .33879 .63437 .38446 .6307 .34317 Metetra
0 0 .284 r
.6307 .34317 .63437 .38446 .64029 .41364 .63754 .40098 Metetra
.175 .171 .614 r
.63754 .40098 .64029 .41364 .63629 .17355 .64276 .40917 Metetra
0 0 .345 r
.64276 .40917 .63629 .17355 .64081 .1719 .63858 .16886 Metetra
.664 .741 .907 r
.63858 .16886 .64081 .1719 .64533 .17026 .64311 .16721 Metetra
.664 .741 .907 r
.64311 .16721 .64533 .17026 .64986 .16861 .64764 .16555 Metetra
.664 .741 .907 r
.64764 .16555 .64986 .16861 .6544 .16695 .65219 .16389 Metetra
.664 .741 .907 r
.65219 .16389 .6544 .16695 .65895 .1653 .65674 .16223 Metetra
.664 .741 .907 r
.65674 .16223 .65895 .1653 .6635 .16364 .66129 .16057 Metetra
.664 .741 .907 r
.66129 .16057 .6635 .16364 .66806 .16198 .66586 .1589 Metetra
.664 .741 .907 r
.66586 .1589 .66806 .16198 .67263 .16031 .67043 .15723 Metetra
.664 .741 .907 r
.67043 .15723 .67263 .16031 .6772 .15865 .67501 .15556 Metetra
.664 .741 .907 r
.67501 .15556 .6772 .15865 .68178 .15698 .6796 .15389 Metetra
.664 .741 .907 r
.6796 .15389 .68178 .15698 .68637 .1553 .68419 .15221 Metetra
.664 .741 .907 r
.68419 .15221 .68637 .1553 .69097 .15363 .6888 .15053 Metetra
.664 .741 .907 r
.6888 .15053 .69097 .15363 .69558 .15195 .69341 .14885 Metetra
.664 .741 .907 r
.69341 .14885 .69558 .15195 .70019 .15027 .69802 .14716 Metetra
.664 .741 .907 r
.69802 .14716 .70019 .15027 .70481 .14859 .70265 .14548 Metetra
.664 .741 .907 r
.70265 .14548 .70481 .14859 .70943 .1469 .70728 .14378 Metetra
.664 .741 .907 r
.70728 .14378 .70943 .1469 .71407 .14522 .71192 .14209 Metetra
.664 .741 .907 r
.71192 .14209 .71407 .14522 .71871 .14352 .71657 .14039 Metetra
.664 .741 .907 r
.71657 .14039 .71871 .14352 .72336 .14183 .72122 .1387 Metetra
.664 .741 .907 r
.72122 .1387 .72336 .14183 .72802 .14013 .72589 .13699 Metetra
.664 .741 .907 r
.72589 .13699 .72802 .14013 .73268 .13843 .73056 .13529 Metetra
.664 .741 .907 r
.73056 .13529 .73268 .13843 .73736 .13673 .73524 .13358 Metetra
.664 .741 .907 r
.73524 .13358 .73736 .13673 .74204 .13503 .73992 .13187 Metetra
.664 .741 .907 r
.73992 .13187 .74204 .13503 .74673 .13332 .74462 .13016 Metetra
.664 .741 .907 r
.74462 .13016 .74673 .13332 .75142 .13161 .74932 .12844 Metetra
.664 .741 .907 r
.74932 .12844 .75142 .13161 .75613 .12989 .75403 .12672 Metetra
.664 .741 .907 r
.75403 .12672 .75613 .12989 .76084 .12818 .75874 .125 Metetra
.664 .741 .907 r
.75874 .125 .76084 .12818 .76556 .12646 .76347 .12328 Metetra
.664 .741 .907 r
.76347 .12328 .76556 .12646 .77028 .12474 .7682 .12155 Metetra
.664 .741 .907 r
.13702 .3484 .13973 .35093 .14349 .34956 .14078 .34702 Metetra
.664 .741 .907 r
.14078 .34702 .14349 .34956 .14725 .34819 .14455 .34564 Metetra
.664 .741 .907 r
.14455 .34564 .14725 .34819 .15103 .34681 .14832 .34426 Metetra
.664 .741 .907 r
.14832 .34426 .15103 .34681 .1548 .34543 .1521 .34288 Metetra
.664 .741 .907 r
.1521 .34288 .1548 .34543 .15858 .34405 .15588 .3415 Metetra
.664 .741 .907 r
.15588 .3415 .15858 .34405 .16237 .34267 .15967 .34011 Metetra
.664 .741 .907 r
.15967 .34011 .16237 .34267 .16616 .34129 .16347 .33873 Metetra
.664 .741 .907 r
.16347 .33873 .16616 .34129 .16996 .3399 .16727 .33734 Metetra
.664 .741 .907 r
.16727 .33734 .16996 .3399 .17376 .33851 .17108 .33594 Metetra
.664 .741 .907 r
.17108 .33594 .17376 .33851 .17757 .33712 .17489 .33455 Metetra
.664 .741 .907 r
.17489 .33455 .17757 .33712 .18139 .33573 .17871 .33315 Metetra
.664 .741 .907 r
.17871 .33315 .18139 .33573 .18521 .33433 .18253 .33175 Metetra
.664 .741 .907 r
.18253 .33175 .18521 .33433 .18903 .33294 .18636 .33035 Metetra
.664 .741 .907 r
.18636 .33035 .18903 .33294 .19287 .33154 .1902 .32895 Metetra
.664 .741 .907 r
.1902 .32895 .19287 .33154 .1967 .33014 .19404 .32755 Metetra
.664 .741 .907 r
.19404 .32755 .1967 .33014 .20055 .32874 .19788 .32614 Metetra
.664 .741 .907 r
.19788 .32614 .20055 .32874 .2044 .32733 .20174 .32473 Metetra
.664 .741 .907 r
.20174 .32473 .2044 .32733 .20825 .32592 .2056 .32332 Metetra
.664 .741 .907 r
.2056 .32332 .20825 .32592 .21211 .32451 .20946 .32191 Metetra
.664 .741 .907 r
.20946 .32191 .21211 .32451 .21598 .3231 .21333 .32049 Metetra
.664 .741 .907 r
.21333 .32049 .21598 .3231 .21985 .32169 .2172 .31908 Metetra
.664 .741 .907 r
.2172 .31908 .21985 .32169 .22373 .32028 .22109 .31766 Metetra
.664 .741 .907 r
.22109 .31766 .22373 .32028 .22761 .31886 .22497 .31624 Metetra
.664 .741 .907 r
.22497 .31624 .22761 .31886 .2315 .31744 .22887 .31481 Metetra
.664 .741 .907 r
.22887 .31481 .2315 .31744 .2354 .31602 .23276 .31339 Metetra
.664 .741 .907 r
.23276 .31339 .2354 .31602 .2393 .31459 .23667 .31196 Metetra
.664 .741 .907 r
.23667 .31196 .2393 .31459 .2432 .31317 .24058 .31053 Metetra
.949 .682 .496 r
.24058 .31053 .2432 .31317 .24712 .31174 .22376 .54065 Metetra
.518 .284 .5 r
.22376 .54065 .24712 .31174 .2308 .5418 .22796 .5393 Metetra
.944 .705 .546 r
.22796 .5393 .2308 .5418 .23581 .53103 .2371 .48126 Metetra
.724 .484 .563 r
.2371 .48126 .23581 .53103 .24489 .47219 .24405 .44721 Metetra
.748 .519 .584 r
.24405 .44721 .24489 .47219 .25136 .44287 .24979 .42658 Metetra
.759 .544 .606 r
.24979 .42658 .25136 .44287 .25689 .42426 .25496 .41217 Metetra
.764 .564 .628 r
.25496 .41217 .25689 .42426 .26195 .41092 .25983 .40124 Metetra
.766 .581 .649 r
.25983 .40124 .26195 .41092 .26675 .40064 .2645 .39248 Metetra
.765 .596 .669 r
.2645 .39248 .26675 .40064 .27137 .39231 .26905 .38518 Metetra
.764 .61 .687 r
.26905 .38518 .27137 .39231 .27588 .38531 .27351 .37892 Metetra
.762 .622 .704 r
.27351 .37892 .27588 .38531 .28031 .37926 .2779 .37342 Metetra
.759 .632 .72 r
.2779 .37342 .28031 .37926 .28468 .37393 .28224 .36851 Metetra
.756 .641 .735 r
.28224 .36851 .28468 .37393 .28901 .36915 .28654 .36407 Metetra
.752 .65 .748 r
.28654 .36407 .28901 .36915 .2933 .3648 .29082 .35999 Metetra
.748 .657 .759 r
.29082 .35999 .2933 .3648 .29757 .36081 .29507 .35621 Metetra
.745 .663 .77 r
.29507 .35621 .29757 .36081 .30182 .3571 .29931 .35268 Metetra
.741 .669 .78 r
.29931 .35268 .30182 .3571 .30605 .35363 .30354 .34936 Metetra
.737 .674 .789 r
.30354 .34936 .30605 .35363 .31027 .35036 .30775 .34621 Metetra
.734 .679 .797 r
.30775 .34621 .31027 .35036 .31448 .34726 .31195 .34322 Metetra
.73 .683 .804 r
.31195 .34322 .31448 .34726 .31868 .34431 .31615 .34036 Metetra
.727 .686 .811 r
.31615 .34036 .31868 .34431 .32287 .34148 .32034 .33762 Metetra
.724 .689 .817 r
.32034 .33762 .32287 .34148 .32706 .33877 .32453 .33498 Metetra
.721 .692 .822 r
.32453 .33498 .32706 .33877 .33125 .33615 .32872 .33242 Metetra
.718 .695 .827 r
.32872 .33242 .33125 .33615 .33544 .33362 .33291 .32995 Metetra
.715 .697 .832 r
.33291 .32995 .33544 .33362 .33962 .33117 .33709 .32754 Metetra
.712 .699 .836 r
.33709 .32754 .33962 .33117 .34381 .32879 .34128 .3252 Metetra
.71 .701 .84 r
.34128 .3252 .34381 .32879 .34799 .32647 .34547 .32291 Metetra
.707 .702 .843 r
.34547 .32291 .34799 .32647 .35218 .3242 .34966 .32068 Metetra
.705 .704 .846 r
.34966 .32068 .35218 .3242 .35637 .32199 .35385 .3185 Metetra
.703 .705 .849 r
.35385 .3185 .35637 .32199 .36056 .31982 .35804 .31636 Metetra
.701 .706 .852 r
.35804 .31636 .36056 .31982 .36475 .31769 .36223 .31425 Metetra
.698 .708 .855 r
.36223 .31425 .36475 .31769 .36895 .31561 .36643 .31219 Metetra
.696 .709 .857 r
.36643 .31219 .36895 .31561 .37315 .31356 .37063 .31016 Metetra
.695 .709 .859 r
.37063 .31016 .37315 .31356 .37735 .31154 .37484 .30816 Metetra
.933 .727 .601 r
.37484 .30816 .37735 .31154 .38155 .30955 .37984 .28911 Metetra
.566 .386 .597 r
.37984 .28911 .38155 .30955 .38576 .3076 .38402 .28745 Metetra
.566 .387 .598 r
.38402 .28745 .38576 .3076 .3907 .28892 .3882 .28581 Metetra
.671 .72 .886 r
.3882 .28581 .3907 .28892 .39488 .28729 .39239 .28417 Metetra
.67 .72 .887 r
.39239 .28417 .39488 .28729 .39907 .28566 .39658 .28255 Metetra
.669 .72 .888 r
.39658 .28255 .39907 .28566 .40327 .28405 .40078 .28094 Metetra
.668 .72 .889 r
.40078 .28094 .40327 .28405 .40747 .28245 .40498 .27934 Metetra
.666 .72 .889 r
.40498 .27934 .40747 .28245 .41168 .28087 .40919 .27775 Metetra
.665 .72 .89 r
.40919 .27775 .41168 .28087 .41589 .27929 .41341 .27617 Metetra
.664 .72 .89 r
.41341 .27617 .41589 .27929 .42011 .27772 .41763 .2746 Metetra
.663 .72 .891 r
.41763 .2746 .42011 .27772 .42433 .27617 .42186 .27304 Metetra
.662 .72 .891 r
.42186 .27304 .42433 .27617 .42856 .27462 .4261 .27149 Metetra
.661 .719 .892 r
.4261 .27149 .42856 .27462 .4328 .27308 .43034 .26995 Metetra
.66 .719 .892 r
.43034 .26995 .4328 .27308 .43704 .27156 .43458 .26842 Metetra
.659 .719 .893 r
.43458 .26842 .43704 .27156 .44129 .27004 .43884 .2669 Metetra
.658 .718 .893 r
.43884 .2669 .44129 .27004 .44555 .26854 .4431 .26539 Metetra
.657 .718 .893 r
.4431 .26539 .44555 .26854 .44981 .26704 .44736 .26389 Metetra
.656 .717 .893 r
.44736 .26389 .44981 .26704 .45408 .26556 .45164 .2624 Metetra
.655 .717 .894 r
.45164 .2624 .45408 .26556 .45836 .26408 .45592 .26091 Metetra
.654 .716 .894 r
.45592 .26091 .45836 .26408 .46264 .26262 .4602 .25944 Metetra
.653 .715 .894 r
.4602 .25944 .46264 .26262 .46693 .26117 .4645 .25798 Metetra
.651 .715 .894 r
.4645 .25798 .46693 .26117 .47122 .25973 .4688 .25653 Metetra
.65 .714 .895 r
.4688 .25653 .47122 .25973 .47553 .2583 .4731 .25509 Metetra
.649 .713 .895 r
.4731 .25509 .47553 .2583 .47984 .25688 .47742 .25367 Metetra
.647 .712 .895 r
.47742 .25367 .47984 .25688 .48393 .27262 .48174 .25225 Metetra
.56 .383 .598 r
.48174 .25225 .48393 .27262 .48827 .27154 .48606 .25085 Metetra
.012 0 .48 r
.48606 .25085 .48827 .27154 .49262 .27048 .4902 .26698 Metetra
.612 .679 .889 r
.4902 .26698 .49262 .27048 .49698 .26946 .49457 .26593 Metetra
.609 .676 .889 r
.49457 .26593 .49698 .26946 .50135 .26848 .49894 .26492 Metetra
.605 .673 .888 r
.49894 .26492 .50135 .26848 .50573 .26753 .50332 .26394 Metetra
.602 .67 .888 r
.50332 .26394 .50573 .26753 .51011 .26662 .50771 .26299 Metetra
.598 .666 .887 r
.50771 .26299 .51011 .26662 .51451 .26575 .5121 .26209 Metetra
.593 .662 .886 r
.5121 .26209 .51451 .26575 .51891 .26493 .51651 .26123 Metetra
.589 .658 .885 r
.51651 .26123 .51891 .26493 .52332 .26417 .52092 .26043 Metetra
.584 .653 .884 r
.52092 .26043 .52332 .26417 .52774 .26346 .52535 .25967 Metetra
.578 .647 .883 r
.52535 .25967 .52774 .26346 .53217 .26282 .52978 .25897 Metetra
.572 .641 .881 r
.52978 .25897 .53217 .26282 .53662 .26224 .53423 .25834 Metetra
.565 .635 .879 r
.53423 .25834 .53662 .26224 .54107 .26175 .53868 .25779 Metetra
.557 .627 .877 r
.53868 .25779 .54107 .26175 .54553 .26135 .54314 .25731 Metetra
.549 .619 .875 r
.54314 .25731 .54553 .26135 .55 .26104 .54762 .25692 Metetra
.539 .61 .872 r
.54762 .25692 .55 .26104 .55449 .26085 .55211 .25664 Metetra
.529 .599 .868 r
.55211 .25664 .55449 .26085 .55899 .26079 .55661 .25648 Metetra
.516 .587 .864 r
.55661 .25648 .55899 .26079 .5635 .26089 .56112 .25645 Metetra
.503 .573 .859 r
.56112 .25645 .5635 .26089 .56803 .26115 .56565 .25658 Metetra
.487 .557 .853 r
.56565 .25658 .56803 .26115 .57257 .26163 .57019 .25689 Metetra
.468 .538 .846 r
.57019 .25689 .57257 .26163 .57713 .26235 .57475 .25742 Metetra
.447 .516 .837 r
.57475 .25742 .57713 .26235 .58172 .26336 .57932 .2582 Metetra
.422 .491 .826 r
.57932 .2582 .58172 .26336 .58632 .26474 .58392 .2593 Metetra
.392 .461 .812 r
.58392 .2593 .58632 .26474 .59095 .26656 .58854 .26077 Metetra
.358 .425 .794 r
.58854 .26077 .59095 .26656 .59561 .26896 .59319 .26272 Metetra
.316 .383 .773 r
.59319 .26272 .59561 .26896 .60031 .27209 .59787 .26527 Metetra
.266 .332 .745 r
.59787 .26527 .60031 .27209 .60505 .2762 .60259 .26862 Metetra
.207 .271 .709 r
.60259 .26862 .60505 .2762 .60986 .2817 .60736 .27304 Metetra
.138 .199 .664 r
.60736 .27304 .60986 .2817 .61475 .2892 .6122 .27896 Metetra
.056 .115 .608 r
.6122 .27896 .61475 .2892 .61978 .29986 .61714 .28713 Metetra
0 .019 .54 r
.61714 .28713 .61978 .29986 .62502 .31597 .62223 .2989 Metetra
0 0 .459 r
.62223 .2989 .62502 .31597 .6307 .34317 .62757 .3171 Metetra
0 0 .366 r
.62757 .3171 .6307 .34317 .63754 .40098 .63346 .3492 Metetra
0 0 .37 r
.63346 .3492 .63754 .40098 .64276 .40917 .64036 .40626 Metetra
.645 .763 .934 r
.64036 .40626 .64276 .40917 .63858 .16886 .64525 .40468 Metetra
0 0 .345 r
.64525 .40468 .63858 .16886 .64311 .16721 .64088 .16415 Metetra
.664 .741 .907 r
.64088 .16415 .64311 .16721 .64764 .16555 .64542 .16249 Metetra
.664 .741 .907 r
.64542 .16249 .64764 .16555 .65219 .16389 .64997 .16083 Metetra
.664 .741 .907 r
.64997 .16083 .65219 .16389 .65674 .16223 .65452 .15916 Metetra
.664 .741 .907 r
.65452 .15916 .65674 .16223 .66129 .16057 .65908 .15749 Metetra
.664 .741 .907 r
.65908 .15749 .66129 .16057 .66586 .1589 .66365 .15582 Metetra
.664 .741 .907 r
.66365 .15582 .66586 .1589 .67043 .15723 .66823 .15415 Metetra
.664 .741 .907 r
.66823 .15415 .67043 .15723 .67501 .15556 .67282 .15247 Metetra
.664 .741 .907 r
.67282 .15247 .67501 .15556 .6796 .15389 .67741 .15079 Metetra
.664 .741 .907 r
.67741 .15079 .6796 .15389 .68419 .15221 .68201 .14911 Metetra
.664 .741 .907 r
.68201 .14911 .68419 .15221 .6888 .15053 .68662 .14742 Metetra
.664 .741 .907 r
.68662 .14742 .6888 .15053 .69341 .14885 .69123 .14573 Metetra
.664 .741 .907 r
.69123 .14573 .69341 .14885 .69802 .14716 .69585 .14404 Metetra
.664 .741 .907 r
.69585 .14404 .69802 .14716 .70265 .14548 .70049 .14235 Metetra
.664 .741 .907 r
.70049 .14235 .70265 .14548 .70728 .14378 .70512 .14066 Metetra
.664 .741 .907 r
.70512 .14066 .70728 .14378 .71192 .14209 .70977 .13896 Metetra
.664 .741 .907 r
.70977 .13896 .71192 .14209 .71657 .14039 .71442 .13726 Metetra
.664 .741 .907 r
.71442 .13726 .71657 .14039 .72122 .1387 .71908 .13555 Metetra
.664 .741 .907 r
.71908 .13555 .72122 .1387 .72589 .13699 .72375 .13384 Metetra
.664 .741 .907 r
.72375 .13384 .72589 .13699 .73056 .13529 .72843 .13213 Metetra
.664 .741 .907 r
.72843 .13213 .73056 .13529 .73524 .13358 .73311 .13042 Metetra
.664 .741 .907 r
.73311 .13042 .73524 .13358 .73992 .13187 .7378 .12871 Metetra
.664 .741 .907 r
.7378 .12871 .73992 .13187 .74462 .13016 .7425 .12699 Metetra
.664 .741 .907 r
.7425 .12699 .74462 .13016 .74932 .12844 .74721 .12527 Metetra
.664 .741 .907 r
.74721 .12527 .74932 .12844 .75403 .12672 .75192 .12354 Metetra
.664 .741 .907 r
.75192 .12354 .75403 .12672 .75874 .125 .75664 .12182 Metetra
.664 .741 .907 r
.75664 .12182 .75874 .125 .76347 .12328 .76137 .12009 Metetra
.664 .741 .907 r
.76137 .12009 .76347 .12328 .7682 .12155 .76611 .11835 Metetra
.664 .741 .907 r
.1343 .34586 .13702 .3484 .14078 .34702 .13806 .34448 Metetra
.664 .741 .907 r
.13806 .34448 .14078 .34702 .14455 .34564 .14183 .3431 Metetra
.664 .741 .907 r
.14183 .3431 .14455 .34564 .14832 .34426 .14561 .34171 Metetra
.664 .741 .907 r
.14561 .34171 .14832 .34426 .1521 .34288 .14939 .34033 Metetra
.664 .741 .907 r
.14939 .34033 .1521 .34288 .15588 .3415 .15318 .33894 Metetra
.664 .741 .907 r
.15318 .33894 .15588 .3415 .15967 .34011 .15697 .33755 Metetra
.664 .741 .907 r
.15697 .33755 .15967 .34011 .16347 .33873 .16077 .33616 Metetra
.664 .741 .907 r
.16077 .33616 .16347 .33873 .16727 .33734 .16457 .33476 Metetra
.664 .741 .907 r
.16457 .33476 .16727 .33734 .17108 .33594 .16839 .33337 Metetra
.664 .741 .907 r
.16839 .33337 .17108 .33594 .17489 .33455 .1722 .33197 Metetra
.664 .741 .907 r
.1722 .33197 .17489 .33455 .17871 .33315 .17602 .33057 Metetra
.664 .741 .907 r
.17602 .33057 .17871 .33315 .18253 .33175 .17985 .32917 Metetra
.664 .741 .907 r
.17985 .32917 .18253 .33175 .18636 .33035 .18368 .32776 Metetra
.664 .741 .907 r
.18368 .32776 .18636 .33035 .1902 .32895 .18752 .32636 Metetra
.664 .741 .907 r
.18752 .32636 .1902 .32895 .19404 .32755 .19136 .32495 Metetra
.664 .741 .907 r
.19136 .32495 .19404 .32755 .19788 .32614 .19521 .32354 Metetra
.664 .741 .907 r
.19521 .32354 .19788 .32614 .20174 .32473 .19907 .32213 Metetra
.664 .741 .907 r
.19907 .32213 .20174 .32473 .2056 .32332 .20293 .32071 Metetra
.664 .741 .907 r
.20293 .32071 .2056 .32332 .20946 .32191 .2068 .31929 Metetra
.664 .741 .907 r
.2068 .31929 .20946 .32191 .21333 .32049 .21067 .31788 Metetra
.664 .741 .907 r
.21067 .31788 .21333 .32049 .2172 .31908 .21455 .31645 Metetra
.664 .741 .907 r
.21455 .31645 .2172 .31908 .22109 .31766 .21844 .31503 Metetra
.664 .741 .907 r
.21844 .31503 .22109 .31766 .22497 .31624 .22233 .31361 Metetra
.664 .741 .907 r
.22233 .31361 .22497 .31624 .22887 .31481 .22622 .31218 Metetra
.664 .741 .907 r
.22622 .31218 .22887 .31481 .23276 .31339 .23012 .31075 Metetra
.664 .741 .907 r
.23012 .31075 .23276 .31339 .23667 .31196 .23403 .30932 Metetra
.664 .741 .907 r
.23403 .30932 .23667 .31196 .24058 .31053 .23795 .30788 Metetra
.949 .682 .496 r
.23795 .30788 .24058 .31053 .22376 .54065 .22091 .53815 Metetra
.942 .709 .557 r
.22091 .53815 .22376 .54065 .22796 .5393 .22906 .49246 Metetra
.751 .508 .564 r
.22906 .49246 .22796 .5393 .2371 .48126 .23663 .45228 Metetra
.743 .511 .579 r
.23663 .45228 .2371 .48126 .24405 .44721 .24263 .42923 Metetra
.756 .538 .6 r
.24263 .42923 .24405 .44721 .24979 .42658 .24794 .4136 Metetra
.762 .559 .622 r
.24794 .4136 .24979 .42658 .25496 .41217 .25289 .40195 Metetra
.765 .577 .643 r
.25289 .40195 .25496 .41217 .25983 .40124 .25762 .39272 Metetra
.765 .592 .663 r
.25762 .39272 .25983 .40124 .2645 .39248 .2622 .3851 Metetra
.764 .606 .682 r
.2622 .3851 .2645 .39248 .26905 .38518 .26668 .37861 Metetra
.762 .618 .7 r
.26668 .37861 .26905 .38518 .27351 .37892 .2711 .37294 Metetra
.759 .629 .716 r
.2711 .37294 .27351 .37892 .2779 .37342 .27545 .3679 Metetra
.756 .639 .731 r
.27545 .3679 .2779 .37342 .28224 .36851 .27977 .36334 Metetra
.753 .647 .744 r
.27977 .36334 .28224 .36851 .28654 .36407 .28406 .35917 Metetra
.749 .655 .757 r
.28406 .35917 .28654 .36407 .29082 .35999 .28832 .35532 Metetra
.745 .661 .768 r
.28832 .35532 .29082 .35999 .29507 .35621 .29256 .35173 Metetra
.742 .667 .778 r
.29256 .35173 .29507 .35621 .29931 .35268 .29679 .34836 Metetra
.738 .673 .787 r
.29679 .34836 .29931 .35268 .30354 .34936 .30101 .34517 Metetra
.735 .677 .795 r
.30101 .34517 .30354 .34936 .30775 .34621 .30522 .34214 Metetra
.731 .681 .802 r
.30522 .34214 .30775 .34621 .31195 .34322 .30942 .33925 Metetra
.728 .685 .809 r
.30942 .33925 .31195 .34322 .31615 .34036 .31362 .33648 Metetra
.725 .688 .815 r
.31362 .33648 .31615 .34036 .32034 .33762 .31781 .3338 Metetra
.722 .691 .821 r
.31781 .3338 .32034 .33762 .32453 .33498 .322 .33122 Metetra
.719 .694 .826 r
.322 .33122 .32453 .33498 .32872 .33242 .32618 .32873 Metetra
.716 .696 .83 r
.32618 .32873 .32872 .33242 .33291 .32995 .33037 .3263 Metetra
.713 .699 .835 r
.33037 .3263 .33291 .32995 .33709 .32754 .33456 .32394 Metetra
.71 .7 .839 r
.33456 .32394 .33709 .32754 .34128 .3252 .33874 .32163 Metetra
.708 .702 .842 r
.33874 .32163 .34128 .3252 .34547 .32291 .34293 .31939 Metetra
.706 .704 .846 r
.34293 .31939 .34547 .32291 .34966 .32068 .34712 .31718 Metetra
.703 .705 .849 r
.34712 .31718 .34966 .32068 .35385 .3185 .35131 .31503 Metetra
.701 .706 .852 r
.35131 .31503 .35385 .3185 .35804 .31636 .35551 .31291 Metetra
.699 .707 .854 r
.35551 .31291 .35804 .31636 .36223 .31425 .35971 .31083 Metetra
.697 .708 .857 r
.35971 .31083 .36223 .31425 .36643 .31219 .36391 .30878 Metetra
.695 .709 .859 r
.36391 .30878 .36643 .31219 .37063 .31016 .36811 .30677 Metetra
.933 .726 .601 r
.36811 .30677 .37063 .31016 .37484 .30816 .37315 .28766 Metetra
.565 .385 .596 r
.37315 .28766 .37484 .30816 .37984 .28911 .37733 .28599 Metetra
.673 .721 .885 r
.37733 .28599 .37984 .28911 .38402 .28745 .38151 .28433 Metetra
.672 .721 .886 r
.38151 .28433 .38402 .28745 .3882 .28581 .38569 .28269 Metetra
.67 .721 .887 r
.38569 .28269 .3882 .28581 .39239 .28417 .38988 .28105 Metetra
.669 .721 .888 r
.38988 .28105 .39239 .28417 .39658 .28255 .39408 .27943 Metetra
.668 .721 .888 r
.39408 .27943 .39658 .28255 .40078 .28094 .39828 .27782 Metetra
.667 .721 .889 r
.39828 .27782 .40078 .28094 .40498 .27934 .40249 .27622 Metetra
.666 .721 .89 r
.40249 .27622 .40498 .27934 .40919 .27775 .4067 .27463 Metetra
.665 .721 .89 r
.4067 .27463 .40919 .27775 .41341 .27617 .41093 .27305 Metetra
.664 .721 .891 r
.41093 .27305 .41341 .27617 .41763 .2746 .41515 .27148 Metetra
.663 .72 .891 r
.41515 .27148 .41763 .2746 .42186 .27304 .41938 .26992 Metetra
.662 .72 .892 r
.41938 .26992 .42186 .27304 .4261 .27149 .42362 .26836 Metetra
.661 .72 .892 r
.42362 .26836 .4261 .27149 .43034 .26995 .42787 .26682 Metetra
.66 .72 .893 r
.42787 .26682 .43034 .26995 .43458 .26842 .43212 .26528 Metetra
.659 .719 .893 r
.43212 .26528 .43458 .26842 .43884 .2669 .43638 .26376 Metetra
.658 .719 .893 r
.43638 .26376 .43884 .2669 .4431 .26539 .44064 .26224 Metetra
.657 .718 .894 r
.44064 .26224 .4431 .26539 .44736 .26389 .44491 .26073 Metetra
.656 .718 .894 r
.44491 .26073 .44736 .26389 .45164 .2624 .44919 .25923 Metetra
.655 .717 .894 r
.44919 .25923 .45164 .2624 .45592 .26091 .45347 .25775 Metetra
.654 .717 .894 r
.45347 .25775 .45592 .26091 .4602 .25944 .45776 .25627 Metetra
.653 .716 .894 r
.45776 .25627 .4602 .25944 .4645 .25798 .46206 .2548 Metetra
.652 .715 .895 r
.46206 .2548 .4645 .25798 .4688 .25653 .46636 .25334 Metetra
.651 .715 .895 r
.46636 .25334 .4688 .25653 .4731 .25509 .47067 .25189 Metetra
.649 .714 .895 r
.47067 .25189 .4731 .25509 .47742 .25367 .47499 .25045 Metetra
.648 .713 .895 r
.47499 .25045 .47742 .25367 .48174 .25225 .47931 .24903 Metetra
.647 .712 .895 r
.47931 .24903 .48174 .25225 .48606 .25085 .48364 .24762 Metetra
.645 .711 .895 r
.48364 .24762 .48606 .25085 .4902 .26698 .48798 .24622 Metetra
.011 0 .48 r
.48798 .24622 .4902 .26698 .49457 .26593 .49214 .26241 Metetra
.611 .679 .89 r
.49214 .26241 .49457 .26593 .49894 .26492 .49652 .26137 Metetra
.608 .676 .889 r
.49652 .26137 .49894 .26492 .50332 .26394 .5009 .26036 Metetra
.604 .673 .889 r
.5009 .26036 .50332 .26394 .50771 .26299 .50529 .25938 Metetra
.6 .669 .888 r
.50529 .25938 .50771 .26299 .5121 .26209 .50969 .25845 Metetra
.596 .665 .887 r
.50969 .25845 .5121 .26209 .51651 .26123 .5141 .25755 Metetra
.592 .661 .886 r
.5141 .25755 .51651 .26123 .52092 .26043 .51852 .2567 Metetra
.587 .657 .885 r
.51852 .2567 .52092 .26043 .52535 .25967 .52295 .2559 Metetra
.582 .652 .884 r
.52295 .2559 .52535 .25967 .52978 .25897 .52738 .25516 Metetra
.576 .646 .882 r
.52738 .25516 .52978 .25897 .53423 .25834 .53183 .25447 Metetra
.57 .64 .881 r
.53183 .25447 .53423 .25834 .53868 .25779 .53629 .25386 Metetra
.563 .633 .879 r
.53629 .25386 .53868 .25779 .54314 .25731 .54075 .25331 Metetra
.555 .625 .876 r
.54075 .25331 .54314 .25731 .54762 .25692 .54523 .25285 Metetra
.546 .617 .874 r
.54523 .25285 .54762 .25692 .55211 .25664 .54972 .25249 Metetra
.537 .607 .871 r
.54972 .25249 .55211 .25664 .55661 .25648 .55422 .25223 Metetra
.526 .596 .867 r
.55422 .25223 .55661 .25648 .56112 .25645 .55873 .25209 Metetra
.513 .583 .863 r
.55873 .25209 .56112 .25645 .56565 .25658 .56326 .2521 Metetra
.499 .569 .857 r
.56326 .2521 .56565 .25658 .57019 .25689 .5678 .25226 Metetra
.482 .552 .851 r
.5678 .25226 .57019 .25689 .57475 .25742 .57236 .25262 Metetra
.463 .533 .843 r
.57236 .25262 .57475 .25742 .57932 .2582 .57693 .2532 Metetra
.441 .51 .834 r
.57693 .2532 .57932 .2582 .58392 .2593 .58153 .25405 Metetra
.415 .484 .822 r
.58153 .25405 .58392 .2593 .58854 .26077 .58614 .25522 Metetra
.385 .452 .808 r
.58614 .25522 .58854 .26077 .59319 .26272 .59078 .2568 Metetra
.348 .415 .789 r
.59078 .2568 .59319 .26272 .59787 .26527 .59545 .25888 Metetra
.305 .371 .766 r
.59545 .25888 .59787 .26527 .60259 .26862 .60015 .2616 Metetra
.254 .318 .736 r
.60015 .2616 .60259 .26862 .60736 .27304 .60489 .26518 Metetra
.192 .254 .699 r
.60489 .26518 .60736 .27304 .6122 .27896 .60969 .26992 Metetra
.12 .18 .651 r
.60969 .26992 .6122 .27896 .61714 .28713 .61457 .27632 Metetra
.036 .093 .592 r
.61457 .27632 .61714 .28713 .62223 .2989 .61955 .28523 Metetra
0 0 .521 r
.61955 .28523 .62223 .2989 .62757 .3171 .62471 .29826 Metetra
0 0 .438 r
.62471 .29826 .62757 .3171 .63346 .3492 .63017 .31896 Metetra
0 0 .343 r
.63017 .31896 .63346 .3492 .64036 .40626 .63634 .35743 Metetra
0 0 .428 r
.63634 .35743 .64036 .40626 .64525 .40468 .64285 .40176 Metetra
.978 .686 .387 r
.64285 .40176 .64525 .40468 .64088 .16415 .63864 .16108 Metetra
.664 .741 .907 r
.63864 .16108 .64088 .16415 .64542 .16249 .64319 .15942 Metetra
.664 .741 .907 r
.64319 .15942 .64542 .16249 .64997 .16083 .64774 .15775 Metetra
.664 .741 .907 r
.64774 .15775 .64997 .16083 .65452 .15916 .6523 .15608 Metetra
.664 .741 .907 r
.6523 .15608 .65452 .15916 .65908 .15749 .65687 .1544 Metetra
.664 .741 .907 r
.65687 .1544 .65908 .15749 .66365 .15582 .66144 .15273 Metetra
.664 .741 .907 r
.66144 .15273 .66365 .15582 .66823 .15415 .66603 .15105 Metetra
.664 .741 .907 r
.66603 .15105 .66823 .15415 .67282 .15247 .67062 .14937 Metetra
.664 .741 .907 r
.67062 .14937 .67282 .15247 .67741 .15079 .67521 .14768 Metetra
.664 .741 .907 r
.67521 .14768 .67741 .15079 .68201 .14911 .67982 .14599 Metetra
.664 .741 .907 r
.67982 .14599 .68201 .14911 .68662 .14742 .68443 .1443 Metetra
.664 .741 .907 r
.68443 .1443 .68662 .14742 .69123 .14573 .68905 .14261 Metetra
.664 .741 .907 r
.68905 .14261 .69123 .14573 .69585 .14404 .69368 .14092 Metetra
.664 .741 .907 r
.69368 .14092 .69585 .14404 .70049 .14235 .69831 .13922 Metetra
.664 .741 .907 r
.69831 .13922 .70049 .14235 .70512 .14066 .70296 .13752 Metetra
.664 .741 .907 r
.70296 .13752 .70512 .14066 .70977 .13896 .70761 .13581 Metetra
.664 .741 .907 r
.70761 .13581 .70977 .13896 .71442 .13726 .71227 .13411 Metetra
.664 .741 .907 r
.71227 .13411 .71442 .13726 .71908 .13555 .71693 .1324 Metetra
.664 .741 .907 r
.71693 .1324 .71908 .13555 .72375 .13384 .7216 .13069 Metetra
.664 .741 .907 r
.7216 .13069 .72375 .13384 .72843 .13213 .72629 .12897 Metetra
.664 .741 .907 r
.72629 .12897 .72843 .13213 .73311 .13042 .73097 .12725 Metetra
.664 .741 .907 r
.73097 .12725 .73311 .13042 .7378 .12871 .73567 .12553 Metetra
.664 .741 .907 r
.73567 .12553 .7378 .12871 .7425 .12699 .74038 .12381 Metetra
.664 .741 .907 r
.74038 .12381 .7425 .12699 .74721 .12527 .74509 .12208 Metetra
.664 .741 .907 r
.74509 .12208 .74721 .12527 .75192 .12354 .74981 .12035 Metetra
.664 .741 .907 r
.74981 .12035 .75192 .12354 .75664 .12182 .75454 .11862 Metetra
.664 .741 .907 r
.75454 .11862 .75664 .12182 .76137 .12009 .75927 .11689 Metetra
.664 .741 .907 r
.75927 .11689 .76137 .12009 .76611 .11835 .76401 .11515 Metetra
.664 .741 .907 r
.13157 .34331 .1343 .34586 .13806 .34448 .13534 .34193 Metetra
.664 .741 .907 r
.13534 .34193 .13806 .34448 .14183 .3431 .13911 .34054 Metetra
.664 .741 .907 r
.13911 .34054 .14183 .3431 .14561 .34171 .14289 .33915 Metetra
.664 .741 .907 r
.14289 .33915 .14561 .34171 .14939 .34033 .14667 .33776 Metetra
.664 .741 .907 r
.14667 .33776 .14939 .34033 .15318 .33894 .15047 .33637 Metetra
.664 .741 .907 r
.15047 .33637 .15318 .33894 .15697 .33755 .15426 .33498 Metetra
.664 .741 .907 r
.15426 .33498 .15697 .33755 .16077 .33616 .15806 .33358 Metetra
.664 .741 .907 r
.15806 .33358 .16077 .33616 .16457 .33476 .16187 .33218 Metetra
.664 .741 .907 r
.16187 .33218 .16457 .33476 .16839 .33337 .16568 .33079 Metetra
.664 .741 .907 r
.16568 .33079 .16839 .33337 .1722 .33197 .1695 .32938 Metetra
.664 .741 .907 r
.1695 .32938 .1722 .33197 .17602 .33057 .17333 .32798 Metetra
.664 .741 .907 r
.17333 .32798 .17602 .33057 .17985 .32917 .17716 .32657 Metetra
.664 .741 .907 r
.17716 .32657 .17985 .32917 .18368 .32776 .181 .32517 Metetra
.664 .741 .907 r
.181 .32517 .18368 .32776 .18752 .32636 .18484 .32376 Metetra
.664 .741 .907 r
.18484 .32376 .18752 .32636 .19136 .32495 .18868 .32234 Metetra
.664 .741 .907 r
.18868 .32234 .19136 .32495 .19521 .32354 .19254 .32093 Metetra
.664 .741 .907 r
.19254 .32093 .19521 .32354 .19907 .32213 .1964 .31951 Metetra
.664 .741 .907 r
.1964 .31951 .19907 .32213 .20293 .32071 .20026 .31809 Metetra
.664 .741 .907 r
.20026 .31809 .20293 .32071 .2068 .31929 .20413 .31667 Metetra
.664 .741 .907 r
.20413 .31667 .2068 .31929 .21067 .31788 .20801 .31525 Metetra
.664 .741 .907 r
.20801 .31525 .21067 .31788 .21455 .31645 .21189 .31382 Metetra
.664 .741 .907 r
.21189 .31382 .21455 .31645 .21844 .31503 .21578 .3124 Metetra
.664 .741 .907 r
.21578 .3124 .21844 .31503 .22233 .31361 .21967 .31097 Metetra
.664 .741 .907 r
.21967 .31097 .22233 .31361 .22622 .31218 .22357 .30954 Metetra
.664 .741 .907 r
.22357 .30954 .22622 .31218 .23012 .31075 .22748 .3081 Metetra
.664 .741 .907 r
.22748 .3081 .23012 .31075 .23403 .30932 .23139 .30667 Metetra
.949 .682 .497 r
.23139 .30667 .23403 .30932 .23795 .30788 .21385 .537 Metetra
.456 .231 .483 r
.21385 .537 .23795 .30788 .22091 .53815 .22069 .50664 Metetra
.817 .571 .567 r
.22069 .50664 .22091 .53815 .22906 .49246 .2291 .45823 Metetra
.737 .502 .573 r
.2291 .45823 .22906 .49246 .23663 .45228 .23541 .43227 Metetra
.753 .531 .595 r
.23541 .43227 .23663 .45228 .24263 .42923 .24088 .41522 Metetra
.761 .553 .616 r
.24088 .41522 .24263 .42923 .24794 .4136 .24592 .40277 Metetra
.764 .572 .638 r
.24592 .40277 .24794 .4136 .25289 .40195 .25071 .39304 Metetra
.765 .588 .658 r
.25071 .39304 .25289 .40195 .25762 .39272 .25533 .38507 Metetra
.764 .602 .678 r
.25533 .38507 .25762 .39272 .2622 .3851 .25985 .37833 Metetra
.762 .615 .696 r
.25985 .37833 .2622 .3851 .26668 .37861 .26428 .37248 Metetra
.76 .626 .712 r
.26428 .37248 .26668 .37861 .2711 .37294 .26866 .3673 Metetra
.757 .636 .727 r
.26866 .3673 .2711 .37294 .27545 .3679 .27299 .36263 Metetra
.753 .645 .741 r
.27299 .36263 .27545 .3679 .27977 .36334 .27728 .35837 Metetra
.75 .653 .753 r
.27728 .35837 .27977 .36334 .28406 .35917 .28156 .35445 Metetra
.746 .66 .765 r
.28156 .35445 .28406 .35917 .28832 .35532 .28581 .3508 Metetra
.743 .666 .775 r
.28581 .3508 .28832 .35532 .29256 .35173 .29004 .34737 Metetra
.739 .671 .784 r
.29004 .34737 .29256 .35173 .29679 .34836 .29426 .34414 Metetra
.735 .676 .793 r
.29426 .34414 .29679 .34836 .30101 .34517 .29847 .34107 Metetra
.732 .68 .8 r
.29847 .34107 .30101 .34517 .30522 .34214 .30268 .33814 Metetra
.729 .684 .807 r
.30268 .33814 .30522 .34214 .30942 .33925 .30688 .33534 Metetra
.725 .688 .814 r
.30688 .33534 .30942 .33925 .31362 .33648 .31107 .33264 Metetra
.722 .691 .819 r
.31107 .33264 .31362 .33648 .31781 .3338 .31526 .33003 Metetra
.719 .693 .825 r
.31526 .33003 .31781 .3338 .322 .33122 .31945 .32751 Metetra
.717 .696 .829 r
.31945 .32751 .322 .33122 .32618 .32873 .32364 .32506 Metetra
.714 .698 .834 r
.32364 .32506 .32618 .32873 .33037 .3263 .32782 .32268 Metetra
.711 .7 .838 r
.32782 .32268 .33037 .3263 .33456 .32394 .33201 .32036 Metetra
.709 .702 .841 r
.33201 .32036 .33456 .32394 .33874 .32163 .3362 .31809 Metetra
.706 .703 .845 r
.3362 .31809 .33874 .32163 .34293 .31939 .34039 .31588 Metetra
.704 .705 .848 r
.34039 .31588 .34293 .31939 .34712 .31718 .34458 .3137 Metetra
.702 .706 .851 r
.34458 .3137 .34712 .31718 .35131 .31503 .34877 .31157 Metetra
.7 .707 .854 r
.34877 .31157 .35131 .31503 .35551 .31291 .35297 .30948 Metetra
.698 .708 .856 r
.35297 .30948 .35551 .31291 .35971 .31083 .35717 .30742 Metetra
.696 .709 .858 r
.35717 .30742 .35971 .31083 .36391 .30878 .36137 .30539 Metetra
.932 .726 .601 r
.36137 .30539 .36391 .30878 .36811 .30677 .36645 .28621 Metetra
.565 .385 .596 r
.36645 .28621 .36811 .30677 .37315 .28766 .37063 .28453 Metetra
.673 .721 .885 r
.37063 .28453 .37315 .28766 .37733 .28599 .37481 .28287 Metetra
.672 .721 .886 r
.37481 .28287 .37733 .28599 .38151 .28433 .37899 .28121 Metetra
.671 .721 .887 r
.37899 .28121 .38151 .28433 .38569 .28269 .38318 .27957 Metetra
.67 .721 .888 r
.38318 .27957 .38569 .28269 .38988 .28105 .38737 .27794 Metetra
.669 .721 .888 r
.38737 .27794 .38988 .28105 .39408 .27943 .39157 .27631 Metetra
.668 .721 .889 r
.39157 .27631 .39408 .27943 .39828 .27782 .39578 .2747 Metetra
.667 .721 .89 r
.39578 .2747 .39828 .27782 .40249 .27622 .39999 .2731 Metetra
.666 .721 .89 r
.39999 .2731 .40249 .27622 .4067 .27463 .40421 .27151 Metetra
.665 .721 .891 r
.40421 .27151 .4067 .27463 .41093 .27305 .40843 .26993 Metetra
.664 .721 .891 r
.40843 .26993 .41093 .27305 .41515 .27148 .41266 .26835 Metetra
.663 .721 .892 r
.41266 .26835 .41515 .27148 .41938 .26992 .4169 .26679 Metetra
.662 .721 .892 r
.4169 .26679 .41938 .26992 .42362 .26836 .42114 .26523 Metetra
.661 .72 .893 r
.42114 .26523 .42362 .26836 .42787 .26682 .42539 .26368 Metetra
.66 .72 .893 r
.42539 .26368 .42787 .26682 .43212 .26528 .42964 .26214 Metetra
.659 .72 .893 r
.42964 .26214 .43212 .26528 .43638 .26376 .43391 .26061 Metetra
.658 .719 .894 r
.43391 .26061 .43638 .26376 .44064 .26224 .43817 .25909 Metetra
.657 .719 .894 r
.43817 .25909 .44064 .26224 .44491 .26073 .44245 .25757 Metetra
.656 .718 .894 r
.44245 .25757 .44491 .26073 .44919 .25923 .44673 .25607 Metetra
.655 .718 .894 r
.44673 .25607 .44919 .25923 .45347 .25775 .45102 .25457 Metetra
.654 .717 .895 r
.45102 .25457 .45347 .25775 .45776 .25627 .45531 .25309 Metetra
.653 .717 .895 r
.45531 .25309 .45776 .25627 .46206 .2548 .45961 .25161 Metetra
.652 .716 .895 r
.45961 .25161 .46206 .2548 .46636 .25334 .46392 .25014 Metetra
.651 .715 .895 r
.46392 .25014 .46636 .25334 .47067 .25189 .46823 .24869 Metetra
.65 .715 .895 r
.46823 .24869 .47067 .25189 .47499 .25045 .47255 .24724 Metetra
.649 .714 .895 r
.47255 .24724 .47499 .25045 .47931 .24903 .47688 .2458 Metetra
.647 .713 .895 r
.47688 .2458 .47931 .24903 .48364 .24762 .48122 .24438 Metetra
.646 .712 .895 r
.48122 .24438 .48364 .24762 .48798 .24622 .48556 .24297 Metetra
.645 .711 .895 r
.48556 .24297 .48798 .24622 .49214 .26241 .48991 .24157 Metetra
.01 0 .479 r
.48991 .24157 .49214 .26241 .49652 .26137 .49409 .25783 Metetra
.61 .678 .89 r
.49409 .25783 .49652 .26137 .5009 .26036 .49848 .25679 Metetra
.607 .675 .889 r
.49848 .25679 .5009 .26036 .50529 .25938 .50287 .25579 Metetra
.603 .672 .889 r
.50287 .25579 .50529 .25938 .50969 .25845 .50728 .25482 Metetra
.599 .668 .888 r
.50728 .25482 .50969 .25845 .5141 .25755 .51169 .25389 Metetra
.595 .664 .887 r
.51169 .25389 .5141 .25755 .51852 .2567 .51611 .253 Metetra
.591 .66 .886 r
.51611 .253 .51852 .2567 .52295 .2559 .52054 .25216 Metetra
.586 .655 .885 r
.52054 .25216 .52295 .2559 .52738 .25516 .52498 .25137 Metetra
.58 .65 .883 r
.52498 .25137 .52738 .25516 .53183 .25447 .52943 .25063 Metetra
.575 .644 .882 r
.52943 .25063 .53183 .25447 .53629 .25386 .53389 .24996 Metetra
.568 .638 .88 r
.53389 .24996 .53629 .25386 .54075 .25331 .53836 .24935 Metetra
.561 .631 .878 r
.53836 .24935 .54075 .25331 .54523 .25285 .54284 .24883 Metetra
.553 .623 .876 r
.54284 .24883 .54523 .25285 .54972 .25249 .54733 .24838 Metetra
.544 .614 .873 r
.54733 .24838 .54972 .25249 .55422 .25223 .55183 .24804 Metetra
.534 .604 .87 r
.55183 .24804 .55422 .25223 .55873 .25209 .55634 .2478 Metetra
.523 .593 .866 r
.55634 .2478 .55873 .25209 .56326 .2521 .56087 .24769 Metetra
.51 .58 .861 r
.56087 .24769 .56326 .2521 .5678 .25226 .56541 .24773 Metetra
.495 .565 .856 r
.56541 .24773 .5678 .25226 .57236 .25262 .56997 .24793 Metetra
.478 .548 .849 r
.56997 .24793 .57236 .25262 .57693 .2532 .57454 .24833 Metetra
.458 .528 .841 r
.57454 .24833 .57693 .2532 .58153 .25405 .57913 .24897 Metetra
.436 .504 .831 r
.57913 .24897 .58153 .25405 .58614 .25522 .58374 .24988 Metetra
.409 .477 .819 r
.58374 .24988 .58614 .25522 .59078 .2568 .58837 .25114 Metetra
.377 .444 .803 r
.58837 .25114 .59078 .2568 .59545 .25888 .59303 .25283 Metetra
.339 .405 .784 r
.59303 .25283 .59545 .25888 .60015 .2616 .59771 .25505 Metetra
.294 .359 .759 r
.59771 .25505 .60015 .2616 .60489 .26518 .60244 .25795 Metetra
.241 .303 .728 r
.60244 .25795 .60489 .26518 .60969 .26992 .60721 .26178 Metetra
.177 .237 .688 r
.60721 .26178 .60969 .26992 .61457 .27632 .61204 .26687 Metetra
.102 .16 .638 r
.61204 .26687 .61457 .27632 .61955 .28523 .61695 .27379 Metetra
.016 .071 .576 r
.61695 .27379 .61955 .28523 .62471 .29826 .62198 .28352 Metetra
0 0 .502 r
.62198 .28352 .62471 .29826 .63017 .31896 .62722 .298 Metetra
0 0 .416 r
.62722 .298 .63017 .31896 .63634 .35743 .63282 .32173 Metetra
0 0 .318 r
.63282 .32173 .63634 .35743 .64285 .40176 .63935 .36876 Metetra
.015 0 .462 r
.63935 .36876 .64285 .40176 .63864 .16108 .64535 .39724 Metetra
0 0 .343 r
.64535 .39724 .63864 .16108 .64319 .15942 .64095 .15633 Metetra
.664 .741 .907 r
.64095 .15633 .64319 .15942 .64774 .15775 .6455 .15466 Metetra
.664 .741 .907 r
.6455 .15466 .64774 .15775 .6523 .15608 .65007 .15299 Metetra
.664 .741 .907 r
.65007 .15299 .6523 .15608 .65687 .1544 .65464 .15131 Metetra
.664 .741 .907 r
.65464 .15131 .65687 .1544 .66144 .15273 .65922 .14963 Metetra
.664 .741 .907 r
.65922 .14963 .66144 .15273 .66603 .15105 .66381 .14794 Metetra
.664 .741 .907 r
.66381 .14794 .66603 .15105 .67062 .14937 .66841 .14625 Metetra
.664 .741 .907 r
.66841 .14625 .67062 .14937 .67521 .14768 .67301 .14457 Metetra
.664 .741 .907 r
.67301 .14457 .67521 .14768 .67982 .14599 .67762 .14287 Metetra
.664 .741 .907 r
.67762 .14287 .67982 .14599 .68443 .1443 .68224 .14118 Metetra
.664 .741 .907 r
.68224 .14118 .68443 .1443 .68905 .14261 .68686 .13948 Metetra
.664 .741 .907 r
.68686 .13948 .68905 .14261 .69368 .14092 .6915 .13778 Metetra
.664 .741 .907 r
.6915 .13778 .69368 .14092 .69831 .13922 .69614 .13608 Metetra
.664 .741 .907 r
.69614 .13608 .69831 .13922 .70296 .13752 .70078 .13437 Metetra
.664 .741 .907 r
.70078 .13437 .70296 .13752 .70761 .13581 .70544 .13266 Metetra
.664 .741 .907 r
.70544 .13266 .70761 .13581 .71227 .13411 .7101 .13095 Metetra
.664 .741 .907 r
.7101 .13095 .71227 .13411 .71693 .1324 .71478 .12923 Metetra
.664 .741 .907 r
.71478 .12923 .71693 .1324 .7216 .13069 .71945 .12752 Metetra
.664 .741 .907 r
.71945 .12752 .7216 .13069 .72629 .12897 .72414 .1258 Metetra
.664 .741 .907 r
.72414 .1258 .72629 .12897 .73097 .12725 .72883 .12407 Metetra
.664 .741 .907 r
.72883 .12407 .73097 .12725 .73567 .12553 .73354 .12235 Metetra
.664 .741 .907 r
.73354 .12235 .73567 .12553 .74038 .12381 .73825 .12062 Metetra
.664 .741 .907 r
.73825 .12062 .74038 .12381 .74509 .12208 .74296 .11889 Metetra
.664 .741 .907 r
.74296 .11889 .74509 .12208 .74981 .12035 .74769 .11715 Metetra
.664 .741 .907 r
.74769 .11715 .74981 .12035 .75454 .11862 .75242 .11542 Metetra
.664 .741 .907 r
.75242 .11542 .75454 .11862 .75927 .11689 .75716 .11368 Metetra
.664 .741 .907 r
.75716 .11368 .75927 .11689 .76401 .11515 .76191 .11193 Metetra
.664 .741 .907 r
.12883 .34075 .13157 .34331 .13534 .34193 .1326 .33937 Metetra
.664 .741 .907 r
.1326 .33937 .13534 .34193 .13911 .34054 .13638 .33798 Metetra
.664 .741 .907 r
.13638 .33798 .13911 .34054 .14289 .33915 .14016 .33659 Metetra
.664 .741 .907 r
.14016 .33659 .14289 .33915 .14667 .33776 .14395 .33519 Metetra
.664 .741 .907 r
.14395 .33519 .14667 .33776 .15047 .33637 .14775 .3338 Metetra
.664 .741 .907 r
.14775 .3338 .15047 .33637 .15426 .33498 .15154 .3324 Metetra
.664 .741 .907 r
.15154 .3324 .15426 .33498 .15806 .33358 .15535 .331 Metetra
.664 .741 .907 r
.15535 .331 .15806 .33358 .16187 .33218 .15916 .3296 Metetra
.664 .741 .907 r
.15916 .3296 .16187 .33218 .16568 .33079 .16298 .3282 Metetra
.664 .741 .907 r
.16298 .3282 .16568 .33079 .1695 .32938 .1668 .32679 Metetra
.664 .741 .907 r
.1668 .32679 .1695 .32938 .17333 .32798 .17063 .32538 Metetra
.664 .741 .907 r
.17063 .32538 .17333 .32798 .17716 .32657 .17446 .32397 Metetra
.664 .741 .907 r
.17446 .32397 .17716 .32657 .181 .32517 .1783 .32256 Metetra
.664 .741 .907 r
.1783 .32256 .181 .32517 .18484 .32376 .18215 .32115 Metetra
.664 .741 .907 r
.18215 .32115 .18484 .32376 .18868 .32234 .186 .31973 Metetra
.664 .741 .907 r
.186 .31973 .18868 .32234 .19254 .32093 .18985 .31831 Metetra
.664 .741 .907 r
.18985 .31831 .19254 .32093 .1964 .31951 .19372 .31689 Metetra
.664 .741 .907 r
.19372 .31689 .1964 .31951 .20026 .31809 .19758 .31547 Metetra
.664 .741 .907 r
.19758 .31547 .20026 .31809 .20413 .31667 .20146 .31404 Metetra
.664 .741 .907 r
.20146 .31404 .20413 .31667 .20801 .31525 .20534 .31262 Metetra
.664 .741 .907 r
.20534 .31262 .20801 .31525 .21189 .31382 .20922 .31119 Metetra
.664 .741 .907 r
.20922 .31119 .21189 .31382 .21578 .3124 .21311 .30976 Metetra
.664 .741 .907 r
.21311 .30976 .21578 .3124 .21967 .31097 .21701 .30832 Metetra
.664 .741 .907 r
.21701 .30832 .21967 .31097 .22357 .30954 .22091 .30689 Metetra
.664 .741 .907 r
.22091 .30689 .22357 .30954 .22748 .3081 .22482 .30545 Metetra
.948 .682 .498 r
.22482 .30545 .22748 .3081 .23139 .30667 .20678 .53585 Metetra
.498 .266 .493 r
.20678 .53585 .23139 .30667 .21385 .537 .21184 .52521 Metetra
.907 .662 .557 r
.21184 .52521 .21385 .537 .22069 .50664 .22143 .4653 Metetra
.729 .491 .567 r
.22143 .4653 .22069 .50664 .2291 .45823 .22812 .43575 Metetra
.749 .524 .589 r
.22812 .43575 .2291 .45823 .23541 .43227 .23378 .41707 Metetra
.759 .547 .611 r
.23378 .41707 .23541 .43227 .24088 .41522 .23892 .40372 Metetra
.763 .567 .632 r
.23892 .40372 .24088 .41522 .24592 .40277 .24378 .39343 Metetra
.764 .584 .653 r
.24378 .39343 .24592 .40277 .25071 .39304 .24845 .3851 Metetra
.764 .599 .673 r
.24845 .3851 .25071 .39304 .25533 .38507 .25299 .37809 Metetra
.763 .612 .691 r
.25299 .37809 .25533 .38507 .25985 .37833 .25745 .37205 Metetra
.76 .623 .708 r
.25745 .37205 .25985 .37833 .26428 .37248 .26184 .36672 Metetra
.757 .634 .724 r
.26184 .36672 .26428 .37248 .26866 .3673 .26619 .36194 Metetra
.754 .643 .738 r
.26619 .36194 .26866 .3673 .27299 .36263 .2705 .35759 Metetra
.751 .651 .75 r
.2705 .35759 .27299 .36263 .27728 .35837 .27478 .35359 Metetra
.747 .658 .762 r
.27478 .35359 .27728 .35837 .28156 .35445 .27904 .34987 Metetra
.743 .664 .773 r
.27904 .34987 .28156 .35445 .28581 .3508 .28328 .34639 Metetra
.74 .67 .782 r
.28328 .34639 .28581 .3508 .29004 .34737 .2875 .34311 Metetra
.736 .675 .791 r
.2875 .34311 .29004 .34737 .29426 .34414 .29172 .34 Metetra
.733 .679 .798 r
.29172 .34 .29426 .34414 .29847 .34107 .29593 .33704 Metetra
.729 .683 .806 r
.29593 .33704 .29847 .34107 .30268 .33814 .30013 .3342 Metetra
.726 .687 .812 r
.30013 .3342 .30268 .33814 .30688 .33534 .30432 .33147 Metetra
.723 .69 .818 r
.30432 .33147 .30688 .33534 .31107 .33264 .30852 .32884 Metetra
.72 .693 .823 r
.30852 .32884 .31107 .33264 .31526 .33003 .31271 .3263 Metetra
.717 .695 .828 r
.31271 .3263 .31526 .33003 .31945 .32751 .3169 .32383 Metetra
.715 .698 .833 r
.3169 .32383 .31945 .32751 .32364 .32506 .32108 .32143 Metetra
.712 .7 .837 r
.32108 .32143 .32364 .32506 .32782 .32268 .32527 .31909 Metetra
.709 .701 .841 r
.32527 .31909 .32782 .32268 .33201 .32036 .32946 .31681 Metetra
.707 .703 .844 r
.32946 .31681 .33201 .32036 .3362 .31809 .33365 .31457 Metetra
.705 .705 .847 r
.33365 .31457 .3362 .31809 .34039 .31588 .33784 .31238 Metetra
.703 .706 .85 r
.33784 .31238 .34039 .31588 .34458 .3137 .34203 .31024 Metetra
.701 .707 .853 r
.34203 .31024 .34458 .3137 .34877 .31157 .34623 .30813 Metetra
.699 .708 .855 r
.34623 .30813 .34877 .31157 .35297 .30948 .35043 .30606 Metetra
.697 .709 .858 r
.35043 .30606 .35297 .30948 .35717 .30742 .35463 .30402 Metetra
.932 .726 .601 r
.35463 .30402 .35717 .30742 .36137 .30539 .35975 .28478 Metetra
.565 .384 .595 r
.35975 .28478 .36137 .30539 .36645 .28621 .36392 .28309 Metetra
.674 .721 .885 r
.36392 .28309 .36645 .28621 .37063 .28453 .3681 .28141 Metetra
.673 .721 .886 r
.3681 .28141 .37063 .28453 .37481 .28287 .37228 .27974 Metetra
.672 .722 .887 r
.37228 .27974 .37481 .28287 .37899 .28121 .37647 .27809 Metetra
.671 .722 .887 r
.37647 .27809 .37899 .28121 .38318 .27957 .38066 .27645 Metetra
.67 .722 .888 r
.38066 .27645 .38318 .27957 .38737 .27794 .38486 .27482 Metetra
.669 .722 .889 r
.38486 .27482 .38737 .27794 .39157 .27631 .38906 .2732 Metetra
.668 .722 .889 r
.38906 .2732 .39157 .27631 .39578 .2747 .39327 .27158 Metetra
.667 .722 .89 r
.39327 .27158 .39578 .2747 .39999 .2731 .39748 .26998 Metetra
.666 .722 .891 r
.39748 .26998 .39999 .2731 .40421 .27151 .40171 .26839 Metetra
.665 .722 .891 r
.40171 .26839 .40421 .27151 .40843 .26993 .40593 .2668 Metetra
.664 .721 .892 r
.40593 .2668 .40843 .26993 .41266 .26835 .41017 .26522 Metetra
.663 .721 .892 r
.41017 .26522 .41266 .26835 .4169 .26679 .41441 .26366 Metetra
.662 .721 .893 r
.41441 .26366 .4169 .26679 .42114 .26523 .41865 .26209 Metetra
.661 .721 .893 r
.41865 .26209 .42114 .26523 .42539 .26368 .42291 .26054 Metetra
.66 .72 .893 r
.42291 .26054 .42539 .26368 .42964 .26214 .42716 .259 Metetra
.659 .72 .894 r
.42716 .259 .42964 .26214 .43391 .26061 .43143 .25746 Metetra
.659 .72 .894 r
.43143 .25746 .43391 .26061 .43817 .25909 .4357 .25593 Metetra
.658 .719 .894 r
.4357 .25593 .43817 .25909 .44245 .25757 .43998 .25441 Metetra
.657 .719 .894 r
.43998 .25441 .44245 .25757 .44673 .25607 .44426 .2529 Metetra
.656 .718 .895 r
.44426 .2529 .44673 .25607 .45102 .25457 .44856 .2514 Metetra
.655 .718 .895 r
.44856 .2514 .45102 .25457 .45531 .25309 .45285 .24991 Metetra
.654 .717 .895 r
.45285 .24991 .45531 .25309 .45961 .25161 .45716 .24842 Metetra
.653 .717 .895 r
.45716 .24842 .45961 .25161 .46392 .25014 .46147 .24695 Metetra
.652 .716 .895 r
.46147 .24695 .46392 .25014 .46823 .24869 .46579 .24548 Metetra
.65 .715 .896 r
.46579 .24548 .46823 .24869 .47255 .24724 .47011 .24402 Metetra
.649 .714 .896 r
.47011 .24402 .47255 .24724 .47688 .2458 .47445 .24258 Metetra
.648 .714 .896 r
.47445 .24258 .47688 .2458 .48122 .24438 .47879 .24114 Metetra
.647 .713 .896 r
.47879 .24114 .48122 .24438 .48556 .24297 .48313 .23972 Metetra
.645 .712 .896 r
.48313 .23972 .48556 .24297 .48991 .24157 .48749 .23831 Metetra
.644 .71 .896 r
.48749 .23831 .48991 .24157 .49409 .25783 .49185 .23691 Metetra
.01 0 .479 r
.49185 .23691 .49409 .25783 .49848 .25679 .49605 .25323 Metetra
.609 .677 .89 r
.49605 .25323 .49848 .25679 .50287 .25579 .50045 .2522 Metetra
.605 .674 .889 r
.50045 .2522 .50287 .25579 .50728 .25482 .50485 .2512 Metetra
.602 .671 .888 r
.50485 .2512 .50728 .25482 .51169 .25389 .50927 .25024 Metetra
.598 .667 .888 r
.50927 .25024 .51169 .25389 .51611 .253 .51369 .24931 Metetra
.594 .663 .887 r
.51369 .24931 .51611 .253 .52054 .25216 .51813 .24843 Metetra
.589 .659 .886 r
.51813 .24843 .52054 .25216 .52498 .25137 .52257 .2476 Metetra
.584 .654 .885 r
.52257 .2476 .52498 .25137 .52943 .25063 .52702 .24682 Metetra
.579 .649 .883 r
.52702 .24682 .52943 .25063 .53389 .24996 .53148 .24609 Metetra
.573 .643 .882 r
.53148 .24609 .53389 .24996 .53836 .24935 .53595 .24543 Metetra
.566 .636 .88 r
.53595 .24543 .53836 .24935 .54284 .24883 .54044 .24484 Metetra
.559 .629 .878 r
.54044 .24484 .54284 .24883 .54733 .24838 .54493 .24432 Metetra
.551 .621 .875 r
.54493 .24432 .54733 .24838 .55183 .24804 .54943 .2439 Metetra
.542 .612 .872 r
.54943 .2439 .55183 .24804 .55634 .2478 .55395 .24357 Metetra
.531 .601 .869 r
.55395 .24357 .55634 .2478 .56087 .24769 .55848 .24336 Metetra
.52 .59 .865 r
.55848 .24336 .56087 .24769 .56541 .24773 .56302 .24328 Metetra
.507 .576 .86 r
.56302 .24328 .56541 .24773 .56997 .24793 .56757 .24334 Metetra
.491 .561 .854 r
.56757 .24334 .56997 .24793 .57454 .24833 .57214 .24359 Metetra
.474 .543 .847 r
.57214 .24359 .57454 .24833 .57913 .24897 .57673 .24404 Metetra
.453 .522 .839 r
.57673 .24404 .57913 .24897 .58374 .24988 .58134 .24473 Metetra
.43 .498 .828 r
.58134 .24473 .58374 .24988 .58837 .25114 .58596 .24572 Metetra
.402 .469 .815 r
.58596 .24572 .58837 .25114 .59303 .25283 .59061 .24706 Metetra
.369 .435 .798 r
.59061 .24706 .59303 .25283 .59771 .25505 .59528 .24886 Metetra
.33 .395 .778 r
.59528 .24886 .59771 .25505 .60244 .25795 .59999 .25122 Metetra
.283 .346 .752 r
.59999 .25122 .60244 .25795 .60721 .26178 .60474 .25432 Metetra
.227 .289 .718 r
.60474 .25432 .60721 .26178 .61204 .26687 .60953 .25841 Metetra
.162 .22 .676 r
.60953 .25841 .61204 .26687 .61695 .27379 .6144 .26387 Metetra
.084 .14 .624 r
.6144 .26387 .61695 .27379 .62198 .28352 .61935 .27136 Metetra
0 .049 .559 r
.61935 .27136 .62198 .28352 .62722 .298 .62444 .28202 Metetra
0 0 .483 r
.62444 .28202 .62722 .298 .63282 .32173 .62976 .29819 Metetra
0 0 .395 r
.62976 .29819 .63282 .32173 .63935 .36876 .63554 .32564 Metetra
0 0 .293 r
.63554 .32564 .63935 .36876 .64535 .39724 .64258 .38465 Metetra
.176 .174 .616 r
.64258 .38465 .64535 .39724 .64095 .15633 .64786 .39269 Metetra
0 0 .343 r
.64786 .39269 .64095 .15633 .6455 .15466 .64326 .15157 Metetra
.664 .741 .907 r
.64326 .15157 .6455 .15466 .65007 .15299 .64783 .14988 Metetra
.664 .741 .907 r
.64783 .14988 .65007 .15299 .65464 .15131 .65241 .1482 Metetra
.664 .741 .907 r
.65241 .1482 .65464 .15131 .65922 .14963 .657 .14651 Metetra
.664 .741 .907 r
.657 .14651 .65922 .14963 .66381 .14794 .66159 .14483 Metetra
.664 .741 .907 r
.66159 .14483 .66381 .14794 .66841 .14625 .66619 .14313 Metetra
.664 .741 .907 r
.66619 .14313 .66841 .14625 .67301 .14457 .6708 .14144 Metetra
.664 .741 .907 r
.6708 .14144 .67301 .14457 .67762 .14287 .67541 .13974 Metetra
.664 .741 .907 r
.67541 .13974 .67762 .14287 .68224 .14118 .68004 .13804 Metetra
.664 .741 .907 r
.68004 .13804 .68224 .14118 .68686 .13948 .68467 .13634 Metetra
.664 .741 .907 r
.68467 .13634 .68686 .13948 .6915 .13778 .68931 .13463 Metetra
.664 .741 .907 r
.68931 .13463 .6915 .13778 .69614 .13608 .69395 .13292 Metetra
.664 .741 .907 r
.69395 .13292 .69614 .13608 .70078 .13437 .69861 .13121 Metetra
.664 .741 .907 r
.69861 .13121 .70078 .13437 .70544 .13266 .70327 .1295 Metetra
.664 .741 .907 r
.70327 .1295 .70544 .13266 .7101 .13095 .70794 .12778 Metetra
.664 .741 .907 r
.70794 .12778 .7101 .13095 .71478 .12923 .71261 .12606 Metetra
.664 .741 .907 r
.71261 .12606 .71478 .12923 .71945 .12752 .7173 .12434 Metetra
.664 .741 .907 r
.7173 .12434 .71945 .12752 .72414 .1258 .72199 .12261 Metetra
.664 .741 .907 r
.72199 .12261 .72414 .1258 .72883 .12407 .72669 .12089 Metetra
.664 .741 .907 r
.72669 .12089 .72883 .12407 .73354 .12235 .73139 .11915 Metetra
.664 .741 .907 r
.73139 .11915 .73354 .12235 .73825 .12062 .73611 .11742 Metetra
.664 .741 .907 r
.73611 .11742 .73825 .12062 .74296 .11889 .74083 .11568 Metetra
.664 .741 .907 r
.74083 .11568 .74296 .11889 .74769 .11715 .74556 .11394 Metetra
.664 .741 .907 r
.74556 .11394 .74769 .11715 .75242 .11542 .7503 .1122 Metetra
.664 .741 .907 r
.7503 .1122 .75242 .11542 .75716 .11368 .75505 .11046 Metetra
.664 .741 .907 r
.75505 .11046 .75716 .11368 .76191 .11193 .7598 .10871 Metetra
.664 .741 .907 r
.12609 .33819 .12883 .34075 .1326 .33937 .12986 .3368 Metetra
.664 .741 .907 r
.12986 .3368 .1326 .33937 .13638 .33798 .13364 .33541 Metetra
.664 .741 .907 r
.13364 .33541 .13638 .33798 .14016 .33659 .13743 .33401 Metetra
.664 .741 .907 r
.13743 .33401 .14016 .33659 .14395 .33519 .14122 .33262 Metetra
.664 .741 .907 r
.14122 .33262 .14395 .33519 .14775 .3338 .14502 .33122 Metetra
.664 .741 .907 r
.14502 .33122 .14775 .3338 .15154 .3324 .14882 .32981 Metetra
.664 .741 .907 r
.14882 .32981 .15154 .3324 .15535 .331 .15263 .32841 Metetra
.664 .741 .907 r
.15263 .32841 .15535 .331 .15916 .3296 .15644 .32701 Metetra
.664 .741 .907 r
.15644 .32701 .15916 .3296 .16298 .3282 .16026 .3256 Metetra
.664 .741 .907 r
.16026 .3256 .16298 .3282 .1668 .32679 .16409 .32419 Metetra
.664 .741 .907 r
.16409 .32419 .1668 .32679 .17063 .32538 .16792 .32278 Metetra
.664 .741 .907 r
.16792 .32278 .17063 .32538 .17446 .32397 .17176 .32136 Metetra
.664 .741 .907 r
.17176 .32136 .17446 .32397 .1783 .32256 .1756 .31995 Metetra
.664 .741 .907 r
.1756 .31995 .1783 .32256 .18215 .32115 .17945 .31853 Metetra
.664 .741 .907 r
.17945 .31853 .18215 .32115 .186 .31973 .1833 .31711 Metetra
.664 .741 .907 r
.1833 .31711 .186 .31973 .18985 .31831 .18716 .31569 Metetra
.664 .741 .907 r
.18716 .31569 .18985 .31831 .19372 .31689 .19103 .31426 Metetra
.664 .741 .907 r
.19103 .31426 .19372 .31689 .19758 .31547 .1949 .31284 Metetra
.664 .741 .907 r
.1949 .31284 .19758 .31547 .20146 .31404 .19878 .31141 Metetra
.664 .741 .907 r
.19878 .31141 .20146 .31404 .20534 .31262 .20266 .30998 Metetra
.664 .741 .907 r
.20266 .30998 .20534 .31262 .20922 .31119 .20655 .30854 Metetra
.664 .741 .907 r
.20655 .30854 .20922 .31119 .21311 .30976 .21044 .30711 Metetra
.664 .741 .907 r
.21044 .30711 .21311 .30976 .21701 .30832 .21434 .30567 Metetra
.664 .741 .907 r
.21434 .30567 .21701 .30832 .22091 .30689 .21825 .30423 Metetra
.948 .682 .499 r
.21825 .30423 .22091 .30689 .22482 .30545 .1997 .5347 Metetra
.515 .281 .497 r
.1997 .5347 .22482 .30545 .20678 .53585 .20389 .53334 Metetra
.943 .704 .547 r
.20389 .53334 .20678 .53585 .21184 .52521 .21358 .4738 Metetra
.72 .48 .561 r
.21358 .4738 .21184 .52521 .22143 .4653 .22076 .43976 Metetra
.745 .516 .583 r
.22076 .43976 .22143 .4653 .22812 .43575 .22663 .41917 Metetra
.756 .541 .605 r
.22663 .41917 .22812 .43575 .23378 .41707 .23189 .40481 Metetra
.762 .562 .627 r
.23189 .40481 .23378 .41707 .23892 .40372 .23682 .39391 Metetra
.764 .579 .648 r
.23682 .39391 .23892 .40372 .24378 .39343 .24154 .38517 Metetra
.764 .595 .668 r
.24154 .38517 .24378 .39343 .24845 .3851 .24612 .37789 Metetra
.763 .608 .687 r
.24612 .37789 .24845 .3851 .25299 .37809 .25061 .37164 Metetra
.76 .62 .704 r
.25061 .37164 .25299 .37809 .25745 .37205 .25502 .36616 Metetra
.758 .631 .72 r
.25502 .36616 .25745 .37205 .26184 .36672 .25938 .36125 Metetra
.755 .64 .734 r
.25938 .36125 .26184 .36672 .26619 .36194 .2637 .35681 Metetra
.751 .649 .747 r
.2637 .35681 .26619 .36194 .2705 .35759 .26799 .35273 Metetra
.748 .656 .759 r
.26799 .35273 .2705 .35759 .27478 .35359 .27226 .34895 Metetra
.744 .663 .77 r
.27226 .34895 .27478 .35359 .27904 .34987 .2765 .34542 Metetra
.74 .668 .78 r
.2765 .34542 .27904 .34987 .28328 .34639 .28074 .34209 Metetra
.737 .674 .789 r
.28074 .34209 .28328 .34639 .2875 .34311 .28496 .33894 Metetra
.733 .678 .797 r
.28496 .33894 .2875 .34311 .29172 .34 .28917 .33594 Metetra
.73 .682 .804 r
.28917 .33594 .29172 .34 .29593 .33704 .29337 .33307 Metetra
.727 .686 .81 r
.29337 .33307 .29593 .33704 .30013 .3342 .29757 .33032 Metetra
.724 .689 .816 r
.29757 .33032 .30013 .3342 .30432 .33147 .30176 .32766 Metetra
.721 .692 .822 r
.30176 .32766 .30432 .33147 .30852 .32884 .30595 .32509 Metetra
.718 .695 .827 r
.30595 .32509 .30852 .32884 .31271 .3263 .31014 .3226 Metetra
.715 .697 .832 r
.31014 .3226 .31271 .3263 .3169 .32383 .31433 .32018 Metetra
.713 .699 .836 r
.31433 .32018 .3169 .32383 .32108 .32143 .31852 .31782 Metetra
.71 .701 .84 r
.31852 .31782 .32108 .32143 .32527 .31909 .32271 .31552 Metetra
.708 .703 .843 r
.32271 .31552 .32527 .31909 .32946 .31681 .3269 .31327 Metetra
.705 .704 .846 r
.3269 .31327 .32946 .31681 .33365 .31457 .33109 .31107 Metetra
.703 .706 .849 r
.33109 .31107 .33365 .31457 .33784 .31238 .33528 .30891 Metetra
.701 .707 .852 r
.33528 .30891 .33784 .31238 .34203 .31024 .33948 .30679 Metetra
.699 .708 .855 r
.33948 .30679 .34203 .31024 .34623 .30813 .34367 .3047 Metetra
.697 .709 .857 r
.34367 .3047 .34623 .30813 .35043 .30606 .34788 .30265 Metetra
.932 .725 .602 r
.34788 .30265 .35043 .30606 .35463 .30402 .35304 .28334 Metetra
.564 .383 .595 r
.35304 .28334 .35463 .30402 .35975 .28478 .3572 .28165 Metetra
.675 .722 .885 r
.3572 .28165 .35975 .28478 .36392 .28309 .36138 .27996 Metetra
.674 .722 .886 r
.36138 .27996 .36392 .28309 .3681 .28141 .36556 .27828 Metetra
.672 .722 .886 r
.36556 .27828 .3681 .28141 .37228 .27974 .36974 .27662 Metetra
.671 .722 .887 r
.36974 .27662 .37228 .27974 .37647 .27809 .37393 .27497 Metetra
.67 .722 .888 r
.37393 .27497 .37647 .27809 .38066 .27645 .37813 .27333 Metetra
.669 .722 .889 r
.37813 .27333 .38066 .27645 .38486 .27482 .38233 .2717 Metetra
.668 .722 .889 r
.38233 .2717 .38486 .27482 .38906 .2732 .38654 .27007 Metetra
.668 .722 .89 r
.38654 .27007 .38906 .2732 .39327 .27158 .39075 .26846 Metetra
.667 .722 .891 r
.39075 .26846 .39327 .27158 .39748 .26998 .39497 .26686 Metetra
.666 .722 .891 r
.39497 .26686 .39748 .26998 .40171 .26839 .3992 .26526 Metetra
.665 .722 .892 r
.3992 .26526 .40171 .26839 .40593 .2668 .40343 .26367 Metetra
.664 .722 .892 r
.40343 .26367 .40593 .2668 .41017 .26522 .40767 .26209 Metetra
.663 .722 .892 r
.40767 .26209 .41017 .26522 .41441 .26366 .41191 .26052 Metetra
.662 .721 .893 r
.41191 .26052 .41441 .26366 .41865 .26209 .41616 .25896 Metetra
.661 .721 .893 r
.41616 .25896 .41865 .26209 .42291 .26054 .42042 .2574 Metetra
.66 .721 .894 r
.42042 .2574 .42291 .26054 .42716 .259 .42468 .25585 Metetra
.66 .721 .894 r
.42468 .25585 .42716 .259 .43143 .25746 .42895 .25431 Metetra
.659 .72 .894 r
.42895 .25431 .43143 .25746 .4357 .25593 .43322 .25278 Metetra
.658 .72 .894 r
.43322 .25278 .4357 .25593 .43998 .25441 .4375 .25125 Metetra
.657 .719 .895 r
.4375 .25125 .43998 .25441 .44426 .2529 .44179 .24973 Metetra
.656 .719 .895 r
.44179 .24973 .44426 .2529 .44856 .2514 .44609 .24823 Metetra
.655 .718 .895 r
.44609 .24823 .44856 .2514 .45285 .24991 .45039 .24672 Metetra
.654 .718 .895 r
.45039 .24672 .45285 .24991 .45716 .24842 .4547 .24523 Metetra
.653 .717 .896 r
.4547 .24523 .45716 .24842 .46147 .24695 .45901 .24375 Metetra
.652 .717 .896 r
.45901 .24375 .46147 .24695 .46579 .24548 .46334 .24227 Metetra
.651 .716 .896 r
.46334 .24227 .46579 .24548 .47011 .24402 .46767 .24081 Metetra
.65 .715 .896 r
.46767 .24081 .47011 .24402 .47445 .24258 .472 .23935 Metetra
.649 .714 .896 r
.472 .23935 .47445 .24258 .47879 .24114 .47635 .23791 Metetra
.647 .713 .896 r
.47635 .23791 .47879 .24114 .48313 .23972 .4807 .23647 Metetra
.646 .712 .896 r
.4807 .23647 .48313 .23972 .48749 .23831 .48505 .23505 Metetra
.645 .711 .896 r
.48505 .23505 .48749 .23831 .49185 .23691 .48942 .23364 Metetra
.643 .71 .896 r
.48942 .23364 .49185 .23691 .49605 .25323 .49379 .23224 Metetra
.009 0 .478 r
.49379 .23224 .49605 .25323 .50045 .2522 .49802 .24863 Metetra
.608 .677 .89 r
.49802 .24863 .50045 .2522 .50485 .2512 .50243 .2476 Metetra
.604 .673 .889 r
.50243 .2476 .50485 .2512 .50927 .25024 .50684 .2466 Metetra
.601 .67 .888 r
.50684 .2466 .50927 .25024 .51369 .24931 .51127 .24565 Metetra
.597 .666 .888 r
.51127 .24565 .51369 .24931 .51813 .24843 .51571 .24473 Metetra
.593 .662 .887 r
.51571 .24473 .51813 .24843 .52257 .2476 .52015 .24385 Metetra
.588 .658 .886 r
.52015 .24385 .52257 .2476 .52702 .24682 .52461 .24303 Metetra
.583 .653 .884 r
.52461 .24303 .52702 .24682 .53148 .24609 .52907 .24225 Metetra
.577 .647 .883 r
.52907 .24225 .53148 .24609 .53595 .24543 .53355 .24154 Metetra
.571 .641 .881 r
.53355 .24154 .53595 .24543 .54044 .24484 .53803 .24088 Metetra
.565 .635 .879 r
.53803 .24088 .54044 .24484 .54493 .24432 .54253 .2403 Metetra
.557 .627 .877 r
.54253 .2403 .54493 .24432 .54943 .2439 .54703 .23981 Metetra
.549 .619 .874 r
.54703 .23981 .54943 .2439 .55395 .24357 .55155 .2394 Metetra
.539 .609 .871 r
.55155 .2394 .55395 .24357 .55848 .24336 .55608 .23909 Metetra
.529 .599 .868 r
.55608 .23909 .55848 .24336 .56302 .24328 .56062 .2389 Metetra
.517 .587 .864 r
.56062 .2389 .56302 .24328 .56757 .24334 .56517 .23885 Metetra
.503 .573 .859 r
.56517 .23885 .56757 .24334 .57214 .24359 .56974 .23895 Metetra
.487 .557 .852 r
.56974 .23895 .57214 .24359 .57673 .24404 .57433 .23923 Metetra
.469 .538 .845 r
.57433 .23923 .57673 .24404 .58134 .24473 .57893 .23973 Metetra
.448 .517 .836 r
.57893 .23973 .58134 .24473 .58596 .24572 .58355 .24048 Metetra
.424 .491 .825 r
.58355 .24048 .58596 .24572 .59061 .24706 .5882 .24154 Metetra
.395 .461 .811 r
.5882 .24154 .59061 .24706 .59528 .24886 .59286 .24298 Metetra
.361 .426 .794 r
.59286 .24298 .59528 .24886 .59999 .25122 .59756 .24489 Metetra
.32 .384 .772 r
.59756 .24489 .59999 .25122 .60474 .25432 .60228 .2474 Metetra
.271 .334 .744 r
.60228 .2474 .60474 .25432 .60953 .25841 .60705 .2507 Metetra
.214 .274 .709 r
.60705 .2507 .60953 .25841 .6144 .26387 .61188 .25507 Metetra
.146 .203 .665 r
.61188 .25507 .6144 .26387 .61935 .27136 .61677 .26095 Metetra
.066 .12 .61 r
.61677 .26095 .61935 .27136 .62444 .28202 .62177 .26906 Metetra
0 .026 .543 r
.62177 .26906 .62444 .28202 .62976 .29819 .62692 .28076 Metetra
0 0 .464 r
.62692 .28076 .62976 .29819 .63554 .32564 .63234 .29891 Metetra
0 0 .374 r
.63234 .29891 .63554 .32564 .64258 .38465 .63833 .33103 Metetra
0 0 .37 r
.63833 .33103 .64258 .38465 .64786 .39269 .64544 .38973 Metetra
.645 .763 .934 r
.64544 .38973 .64786 .39269 .64326 .15157 .65038 .38812 Metetra
0 0 .343 r
.65038 .38812 .64326 .15157 .64783 .14988 .64559 .14677 Metetra
.664 .741 .907 r
.64559 .14677 .64783 .14988 .65241 .1482 .65018 .14509 Metetra
.664 .741 .907 r
.65018 .14509 .65241 .1482 .657 .14651 .65477 .14339 Metetra
.664 .741 .907 r
.65477 .14339 .657 .14651 .66159 .14483 .65936 .1417 Metetra
.664 .741 .907 r
.65936 .1417 .66159 .14483 .66619 .14313 .66397 .14 Metetra
.664 .741 .907 r
.66397 .14 .66619 .14313 .6708 .14144 .66858 .1383 Metetra
.664 .741 .907 r
.66858 .1383 .6708 .14144 .67541 .13974 .6732 .1366 Metetra
.664 .741 .907 r
.6732 .1366 .67541 .13974 .68004 .13804 .67783 .1349 Metetra
.664 .741 .907 r
.67783 .1349 .68004 .13804 .68467 .13634 .68247 .13319 Metetra
.664 .741 .907 r
.68247 .13319 .68467 .13634 .68931 .13463 .68711 .13148 Metetra
.664 .741 .907 r
.68711 .13148 .68931 .13463 .69395 .13292 .69176 .12976 Metetra
.664 .741 .907 r
.69176 .12976 .69395 .13292 .69861 .13121 .69642 .12805 Metetra
.664 .741 .907 r
.69642 .12805 .69861 .13121 .70327 .1295 .70109 .12633 Metetra
.664 .741 .907 r
.70109 .12633 .70327 .1295 .70794 .12778 .70576 .1246 Metetra
.664 .741 .907 r
.70576 .1246 .70794 .12778 .71261 .12606 .71044 .12288 Metetra
.664 .741 .907 r
.71044 .12288 .71261 .12606 .7173 .12434 .71513 .12115 Metetra
.664 .741 .907 r
.71513 .12115 .7173 .12434 .72199 .12261 .71983 .11942 Metetra
.664 .741 .907 r
.71983 .11942 .72199 .12261 .72669 .12089 .72453 .11769 Metetra
.664 .741 .907 r
.72453 .11769 .72669 .12089 .73139 .11915 .72925 .11595 Metetra
.664 .741 .907 r
.72925 .11595 .73139 .11915 .73611 .11742 .73397 .11421 Metetra
.664 .741 .907 r
.73397 .11421 .73611 .11742 .74083 .11568 .7387 .11247 Metetra
.664 .741 .907 r
.7387 .11247 .74083 .11568 .74556 .11394 .74343 .11072 Metetra
.664 .741 .907 r
.74343 .11072 .74556 .11394 .7503 .1122 .74818 .10898 Metetra
.664 .741 .907 r
.74818 .10898 .7503 .1122 .75505 .11046 .75293 .10722 Metetra
.664 .741 .907 r
.75293 .10722 .75505 .11046 .7598 .10871 .75769 .10547 Metetra
.664 .741 .907 r
.12334 .33562 .12609 .33819 .12986 .3368 .12711 .33423 Metetra
.664 .741 .907 r
.12711 .33423 .12986 .3368 .13364 .33541 .1309 .33283 Metetra
.664 .741 .907 r
.1309 .33283 .13364 .33541 .13743 .33401 .13469 .33143 Metetra
.664 .741 .907 r
.13469 .33143 .13743 .33401 .14122 .33262 .13848 .33003 Metetra
.664 .741 .907 r
.13848 .33003 .14122 .33262 .14502 .33122 .14228 .32863 Metetra
.664 .741 .907 r
.14228 .32863 .14502 .33122 .14882 .32981 .14609 .32722 Metetra
.664 .741 .907 r
.14609 .32722 .14882 .32981 .15263 .32841 .1499 .32582 Metetra
.664 .741 .907 r
.1499 .32582 .15263 .32841 .15644 .32701 .15372 .32441 Metetra
.664 .741 .907 r
.15372 .32441 .15644 .32701 .16026 .3256 .15754 .323 Metetra
.664 .741 .907 r
.15754 .323 .16026 .3256 .16409 .32419 .16137 .32158 Metetra
.664 .741 .907 r
.16137 .32158 .16409 .32419 .16792 .32278 .1652 .32017 Metetra
.664 .741 .907 r
.1652 .32017 .16792 .32278 .17176 .32136 .16904 .31875 Metetra
.664 .741 .907 r
.16904 .31875 .17176 .32136 .1756 .31995 .17289 .31733 Metetra
.664 .741 .907 r
.17289 .31733 .1756 .31995 .17945 .31853 .17674 .31591 Metetra
.664 .741 .907 r
.17674 .31591 .17945 .31853 .1833 .31711 .1806 .31448 Metetra
.664 .741 .907 r
.1806 .31448 .1833 .31711 .18716 .31569 .18446 .31306 Metetra
.664 .741 .907 r
.18446 .31306 .18716 .31569 .19103 .31426 .18833 .31163 Metetra
.664 .741 .907 r
.18833 .31163 .19103 .31426 .1949 .31284 .19221 .3102 Metetra
.664 .741 .907 r
.19221 .3102 .1949 .31284 .19878 .31141 .19609 .30877 Metetra
.664 .741 .907 r
.19609 .30877 .19878 .31141 .20266 .30998 .19997 .30733 Metetra
.664 .741 .907 r
.19997 .30733 .20266 .30998 .20655 .30854 .20386 .30589 Metetra
.664 .741 .907 r
.20386 .30589 .20655 .30854 .21044 .30711 .20776 .30445 Metetra
.664 .741 .907 r
.20776 .30445 .21044 .30711 .21434 .30567 .21167 .30301 Metetra
.664 .741 .907 r
.21167 .30301 .21434 .30567 .21825 .30423 .21558 .30157 Metetra
.948 .682 .499 r
.21558 .30157 .21825 .30423 .1997 .5347 .1968 .53218 Metetra
.941 .708 .557 r
.1968 .53218 .1997 .5347 .20389 .53334 .2055 .48418 Metetra
.744 .501 .562 r
.2055 .48418 .20389 .53334 .21358 .4738 .21331 .4444 Metetra
.74 .508 .578 r
.21331 .4444 .21358 .4738 .22076 .43976 .21943 .42155 Metetra
.754 .535 .6 r
.21943 .42155 .22076 .43976 .22663 .41917 .22483 .40604 Metetra
.76 .557 .622 r
.22483 .40604 .22663 .41917 .23189 .40481 .22984 .39448 Metetra
.763 .575 .643 r
.22984 .39448 .23189 .40481 .23682 .39391 .23461 .38531 Metetra
.764 .591 .663 r
.23461 .38531 .23682 .39391 .24154 .38517 .23923 .37773 Metetra
.763 .605 .682 r
.23923 .37773 .24154 .38517 .24612 .37789 .24375 .37126 Metetra
.761 .617 .7 r
.24375 .37126 .24612 .37789 .25061 .37164 .24818 .36562 Metetra
.758 .628 .716 r
.24818 .36562 .25061 .37164 .25502 .36616 .25256 .36059 Metetra
.755 .638 .731 r
.25256 .36059 .25502 .36616 .25938 .36125 .25689 .35604 Metetra
.752 .646 .744 r
.25689 .35604 .25938 .36125 .2637 .35681 .26119 .35188 Metetra
.748 .654 .756 r
.26119 .35188 .2637 .35681 .26799 .35273 .26547 .34804 Metetra
.745 .661 .767 r
.26547 .34804 .26799 .35273 .27226 .34895 .26972 .34445 Metetra
.741 .667 .777 r
.26972 .34445 .27226 .34895 .2765 .34542 .27396 .34107 Metetra
.738 .672 .787 r
.27396 .34107 .2765 .34542 .28074 .34209 .27818 .33788 Metetra
.734 .677 .795 r
.27818 .33788 .28074 .34209 .28496 .33894 .2824 .33485 Metetra
.731 .681 .802 r
.2824 .33485 .28496 .33894 .28917 .33594 .2866 .33194 Metetra
.728 .685 .809 r
.2866 .33194 .28917 .33594 .29337 .33307 .2908 .32916 Metetra
.725 .688 .815 r
.2908 .32916 .29337 .33307 .29757 .33032 .295 .32648 Metetra
.722 .691 .821 r
.295 .32648 .29757 .33032 .30176 .32766 .29919 .32389 Metetra
.719 .694 .826 r
.29919 .32389 .30176 .32766 .30595 .32509 .30338 .32138 Metetra
.716 .697 .83 r
.30338 .32138 .30595 .32509 .31014 .3226 .30757 .31894 Metetra
.713 .699 .835 r
.30757 .31894 .31014 .3226 .31433 .32018 .31176 .31656 Metetra
.711 .701 .839 r
.31176 .31656 .31433 .32018 .31852 .31782 .31595 .31424 Metetra
.708 .703 .842 r
.31595 .31424 .31852 .31782 .32271 .31552 .32014 .31198 Metetra
.706 .704 .846 r
.32014 .31198 .32271 .31552 .3269 .31327 .32433 .30976 Metetra
.704 .706 .849 r
.32433 .30976 .3269 .31327 .33109 .31107 .32852 .30758 Metetra
.702 .707 .852 r
.32852 .30758 .33109 .31107 .33528 .30891 .33272 .30545 Metetra
.7 .708 .854 r
.33272 .30545 .33528 .30891 .33948 .30679 .33691 .30335 Metetra
.931 .724 .6 r
.33691 .30335 .33948 .30679 .34367 .3047 .34215 .28364 Metetra
.564 .382 .593 r
.34215 .28364 .34367 .3047 .34788 .30265 .34631 .28192 Metetra
.564 .383 .594 r
.34631 .28192 .34788 .30265 .35304 .28334 .35048 .28021 Metetra
.675 .722 .884 r
.35048 .28021 .35304 .28334 .3572 .28165 .35465 .27851 Metetra
.674 .722 .885 r
.35465 .27851 .3572 .28165 .36138 .27996 .35883 .27683 Metetra
.673 .722 .886 r
.35883 .27683 .36138 .27996 .36556 .27828 .36301 .27516 Metetra
.672 .722 .887 r
.36301 .27516 .36556 .27828 .36974 .27662 .3672 .2735 Metetra
.671 .722 .888 r
.3672 .2735 .36974 .27662 .37393 .27497 .3714 .27185 Metetra
.67 .723 .889 r
.3714 .27185 .37393 .27497 .37813 .27333 .37559 .27021 Metetra
.669 .723 .889 r
.37559 .27021 .37813 .27333 .38233 .2717 .3798 .26857 Metetra
.668 .723 .89 r
.3798 .26857 .38233 .2717 .38654 .27007 .38401 .26695 Metetra
.667 .723 .89 r
.38401 .26695 .38654 .27007 .39075 .26846 .38823 .26534 Metetra
.666 .723 .891 r
.38823 .26534 .39075 .26846 .39497 .26686 .39245 .26373 Metetra
.666 .722 .892 r
.39245 .26373 .39497 .26686 .3992 .26526 .39668 .26213 Metetra
.665 .722 .892 r
.39668 .26213 .3992 .26526 .40343 .26367 .40092 .26054 Metetra
.664 .722 .892 r
.40092 .26054 .40343 .26367 .40767 .26209 .40516 .25896 Metetra
.663 .722 .893 r
.40516 .25896 .40767 .26209 .41191 .26052 .4094 .25739 Metetra
.662 .722 .893 r
.4094 .25739 .41191 .26052 .41616 .25896 .41366 .25582 Metetra
.661 .722 .894 r
.41366 .25582 .41616 .25896 .42042 .2574 .41792 .25426 Metetra
.66 .721 .894 r
.41792 .25426 .42042 .2574 .42468 .25585 .42218 .2527 Metetra
.66 .721 .894 r
.42218 .2527 .42468 .25585 .42895 .25431 .42646 .25116 Metetra
.659 .721 .895 r
.42646 .25116 .42895 .25431 .43322 .25278 .43074 .24962 Metetra
.658 .72 .895 r
.43074 .24962 .43322 .25278 .4375 .25125 .43502 .24809 Metetra
.657 .72 .895 r
.43502 .24809 .4375 .25125 .44179 .24973 .43931 .24656 Metetra
.656 .719 .895 r
.43931 .24656 .44179 .24973 .44609 .24823 .44361 .24505 Metetra
.655 .719 .895 r
.44361 .24505 .44609 .24823 .45039 .24672 .44792 .24354 Metetra
.654 .718 .896 r
.44792 .24354 .45039 .24672 .4547 .24523 .45223 .24204 Metetra
.653 .718 .896 r
.45223 .24204 .4547 .24523 .45901 .24375 .45655 .24055 Metetra
.652 .717 .896 r
.45655 .24055 .45901 .24375 .46334 .24227 .46088 .23906 Metetra
.651 .717 .896 r
.46088 .23906 .46334 .24227 .46767 .24081 .46521 .23759 Metetra
.65 .716 .896 r
.46521 .23759 .46767 .24081 .472 .23935 .46955 .23612 Metetra
.649 .715 .896 r
.46955 .23612 .472 .23935 .47635 .23791 .4739 .23467 Metetra
.648 .714 .896 r
.4739 .23467 .47635 .23791 .4807 .23647 .47825 .23322 Metetra
.647 .713 .896 r
.47825 .23322 .4807 .23647 .48505 .23505 .48262 .23179 Metetra
.645 .712 .896 r
.48262 .23179 .48505 .23505 .48942 .23364 .48698 .23037 Metetra
.644 .711 .896 r
.48698 .23037 .48942 .23364 .49379 .23224 .49136 .22896 Metetra
.643 .71 .896 r
.49136 .22896 .49379 .23224 .49802 .24863 .49574 .22756 Metetra
.556 .377 .594 r
.49574 .22756 .49802 .24863 .50243 .2476 .50014 .22618 Metetra
.007 0 .476 r
.50014 .22618 .50243 .2476 .50684 .2466 .50441 .24298 Metetra
.603 .673 .889 r
.50441 .24298 .50684 .2466 .51127 .24565 .50884 .24199 Metetra
.6 .669 .888 r
.50884 .24199 .51127 .24565 .51571 .24473 .51328 .24104 Metetra
.596 .665 .887 r
.51328 .24104 .51571 .24473 .52015 .24385 .51773 .24012 Metetra
.591 .661 .886 r
.51773 .24012 .52015 .24385 .52461 .24303 .52219 .23926 Metetra
.587 .657 .885 r
.52219 .23926 .52461 .24303 .52907 .24225 .52666 .23844 Metetra
.582 .652 .884 r
.52666 .23844 .52907 .24225 .53355 .24154 .53113 .23767 Metetra
.576 .646 .883 r
.53113 .23767 .53355 .24154 .53803 .24088 .53562 .23696 Metetra
.57 .64 .881 r
.53562 .23696 .53803 .24088 .54253 .2403 .54012 .23632 Metetra
.563 .633 .879 r
.54012 .23632 .54253 .2403 .54703 .23981 .54462 .23576 Metetra
.555 .625 .876 r
.54462 .23576 .54703 .23981 .55155 .2394 .54914 .23527 Metetra
.547 .617 .874 r
.54914 .23527 .55155 .2394 .55608 .23909 .55367 .23488 Metetra
.537 .607 .871 r
.55367 .23488 .55608 .23909 .56062 .2389 .55822 .23459 Metetra
.526 .596 .867 r
.55822 .23459 .56062 .2389 .56517 .23885 .56277 .23443 Metetra
.514 .583 .862 r
.56277 .23443 .56517 .23885 .56974 .23895 .56734 .2344 Metetra
.5 .569 .857 r
.56734 .2344 .56974 .23895 .57433 .23923 .57193 .23454 Metetra
.484 .552 .851 r
.57193 .23454 .57433 .23923 .57893 .23973 .57653 .23486 Metetra
.465 .533 .843 r
.57653 .23486 .57893 .23973 .58355 .24048 .58114 .23541 Metetra
.443 .511 .833 r
.58114 .23541 .58355 .24048 .5882 .24154 .58578 .23622 Metetra
.418 .485 .822 r
.58578 .23622 .5882 .24154 .59286 .24298 .59044 .23735 Metetra
.388 .454 .807 r
.59044 .23735 .59286 .24298 .59756 .24489 .59513 .23888 Metetra
.352 .417 .789 r
.59513 .23888 .59756 .24489 .60228 .2474 .59984 .24092 Metetra
.31 .373 .766 r
.59984 .24092 .60228 .2474 .60705 .2507 .60459 .24359 Metetra
.26 .321 .736 r
.60459 .24359 .60705 .2507 .61188 .25507 .60938 .24711 Metetra
.2 .258 .699 r
.60938 .24711 .61188 .25507 .61677 .26095 .61424 .25178 Metetra
.13 .185 .653 r
.61424 .25178 .61677 .26095 .62177 .26906 .61916 .25809 Metetra
.048 .1 .595 r
.61916 .25809 .62177 .26906 .62692 .28076 .62421 .26689 Metetra
0 .004 .525 r
.62421 .26689 .62692 .28076 .63234 .29891 .62943 .27978 Metetra
0 0 .444 r
.62943 .27978 .63234 .29891 .63833 .33103 .63497 .30027 Metetra
0 0 .353 r
.63497 .30027 .63833 .33103 .64544 .38973 .64123 .33837 Metetra
0 0 .423 r
.64123 .33837 .64544 .38973 .65038 .38812 .64796 .38514 Metetra
.978 .685 .38 r
.64796 .38514 .65038 .38812 .64559 .14677 .64334 .14365 Metetra
.664 .741 .907 r
.64334 .14365 .64559 .14677 .65018 .14509 .64793 .14196 Metetra
.664 .741 .907 r
.64793 .14196 .65018 .14509 .65477 .14339 .65253 .14026 Metetra
.664 .741 .907 r
.65253 .14026 .65477 .14339 .65936 .1417 .65713 .13856 Metetra
.664 .741 .907 r
.65713 .13856 .65936 .1417 .66397 .14 .66174 .13686 Metetra
.664 .741 .907 r
.66174 .13686 .66397 .14 .66858 .1383 .66636 .13516 Metetra
.664 .741 .907 r
.66636 .13516 .66858 .1383 .6732 .1366 .67099 .13345 Metetra
.664 .741 .907 r
.67099 .13345 .6732 .1366 .67783 .1349 .67562 .13174 Metetra
.664 .741 .907 r
.67562 .13174 .67783 .1349 .68247 .13319 .68026 .13003 Metetra
.664 .741 .907 r
.68026 .13003 .68247 .13319 .68711 .13148 .68491 .12831 Metetra
.664 .741 .907 r
.68491 .12831 .68711 .13148 .69176 .12976 .68956 .12659 Metetra
.664 .741 .907 r
.68956 .12659 .69176 .12976 .69642 .12805 .69423 .12487 Metetra
.664 .741 .907 r
.69423 .12487 .69642 .12805 .70109 .12633 .6989 .12314 Metetra
.664 .741 .907 r
.6989 .12314 .70109 .12633 .70576 .1246 .70358 .12142 Metetra
.664 .741 .907 r
.70358 .12142 .70576 .1246 .71044 .12288 .70827 .11969 Metetra
.664 .741 .907 r
.70827 .11969 .71044 .12288 .71513 .12115 .71296 .11795 Metetra
.664 .741 .907 r
.71296 .11795 .71513 .12115 .71983 .11942 .71766 .11622 Metetra
.664 .741 .907 r
.71766 .11622 .71983 .11942 .72453 .11769 .72237 .11448 Metetra
.664 .741 .907 r
.72237 .11448 .72453 .11769 .72925 .11595 .72709 .11274 Metetra
.664 .741 .907 r
.72709 .11274 .72925 .11595 .73397 .11421 .73182 .11099 Metetra
.664 .741 .907 r
.73182 .11099 .73397 .11421 .7387 .11247 .73655 .10925 Metetra
.664 .741 .907 r
.73655 .10925 .7387 .11247 .74343 .11072 .74129 .10749 Metetra
.664 .741 .907 r
.74129 .10749 .74343 .11072 .74818 .10898 .74604 .10574 Metetra
.664 .741 .907 r
.74604 .10574 .74818 .10898 .75293 .10722 .7508 .10398 Metetra
.664 .741 .907 r
.7508 .10398 .75293 .10722 .75769 .10547 .75557 .10223 Metetra
.664 .741 .907 r
.12058 .33305 .12334 .33562 .12711 .33423 .12436 .33165 Metetra
.664 .741 .907 r
.12436 .33165 .12711 .33423 .1309 .33283 .12815 .33025 Metetra
.664 .741 .907 r
.12815 .33025 .1309 .33283 .13469 .33143 .13194 .32884 Metetra
.664 .741 .907 r
.13194 .32884 .13469 .33143 .13848 .33003 .13574 .32744 Metetra
.664 .741 .907 r
.13574 .32744 .13848 .33003 .14228 .32863 .13954 .32603 Metetra
.664 .741 .907 r
.13954 .32603 .14228 .32863 .14609 .32722 .14335 .32462 Metetra
.664 .741 .907 r
.14335 .32462 .14609 .32722 .1499 .32582 .14716 .32321 Metetra
.664 .741 .907 r
.14716 .32321 .1499 .32582 .15372 .32441 .15098 .3218 Metetra
.664 .741 .907 r
.15098 .3218 .15372 .32441 .15754 .323 .15481 .32038 Metetra
.664 .741 .907 r
.15481 .32038 .15754 .323 .16137 .32158 .15864 .31897 Metetra
.664 .741 .907 r
.15864 .31897 .16137 .32158 .1652 .32017 .16248 .31755 Metetra
.664 .741 .907 r
.16248 .31755 .1652 .32017 .16904 .31875 .16632 .31613 Metetra
.664 .741 .907 r
.16632 .31613 .16904 .31875 .17289 .31733 .17017 .3147 Metetra
.664 .741 .907 r
.17017 .3147 .17289 .31733 .17674 .31591 .17403 .31328 Metetra
.664 .741 .907 r
.17403 .31328 .17674 .31591 .1806 .31448 .17789 .31185 Metetra
.664 .741 .907 r
.17789 .31185 .1806 .31448 .18446 .31306 .18175 .31042 Metetra
.664 .741 .907 r
.18175 .31042 .18446 .31306 .18833 .31163 .18563 .30899 Metetra
.664 .741 .907 r
.18563 .30899 .18833 .31163 .19221 .3102 .1895 .30755 Metetra
.664 .741 .907 r
.1895 .30755 .19221 .3102 .19609 .30877 .19339 .30612 Metetra
.664 .741 .907 r
.19339 .30612 .19609 .30877 .19997 .30733 .19728 .30468 Metetra
.664 .741 .907 r
.19728 .30468 .19997 .30733 .20386 .30589 .20117 .30324 Metetra
.664 .741 .907 r
.20117 .30324 .20386 .30589 .20776 .30445 .20508 .30179 Metetra
.664 .741 .907 r
.20508 .30179 .20776 .30445 .21167 .30301 .20898 .30035 Metetra
.947 .682 .5 r
.20898 .30035 .21167 .30301 .21558 .30157 .1897 .53103 Metetra
.444 .219 .477 r
.1897 .53103 .21558 .30157 .1968 .53218 .1971 .49714 Metetra
.803 .557 .566 r
.1971 .49714 .1968 .53218 .2055 .48418 .20574 .4498 Metetra
.734 .499 .572 r
.20574 .4498 .2055 .48418 .21331 .4444 .21218 .42426 Metetra
.751 .529 .594 r
.21218 .42426 .21331 .4444 .21943 .42155 .21773 .40745 Metetra
.759 .551 .616 r
.21773 .40745 .21943 .42155 .22483 .40604 .22284 .39514 Metetra
.762 .57 .638 r
.22284 .39514 .22483 .40604 .22984 .39448 .22767 .3855 Metetra
.763 .587 .658 r
.22767 .3855 .22984 .39448 .23461 .38531 .23233 .3776 Metetra
.763 .601 .678 r
.23233 .3776 .23461 .38531 .23923 .37773 .23687 .37091 Metetra
.761 .614 .696 r
.23687 .37091 .23923 .37773 .24375 .37126 .24133 .36509 Metetra
.759 .625 .712 r
.24133 .36509 .24375 .37126 .24818 .36562 .24572 .35994 Metetra
.756 .635 .727 r
.24572 .35994 .24818 .36562 .25256 .36059 .25007 .35529 Metetra
.752 .644 .741 r
.25007 .35529 .25256 .36059 .25689 .35604 .25438 .35105 Metetra
.749 .652 .754 r
.25438 .35105 .25689 .35604 .26119 .35188 .25866 .34713 Metetra
.745 .659 .765 r
.25866 .34713 .26119 .35188 .26547 .34804 .26293 .34348 Metetra
.742 .665 .775 r
.26293 .34348 .26547 .34804 .26972 .34445 .26717 .34006 Metetra
.738 .671 .784 r
.26717 .34006 .26972 .34445 .27396 .34107 .2714 .33683 Metetra
.735 .676 .793 r
.2714 .33683 .27396 .34107 .27818 .33788 .27562 .33375 Metetra
.732 .68 .8 r
.27562 .33375 .27818 .33788 .2824 .33485 .27983 .33082 Metetra
.728 .684 .807 r
.27983 .33082 .2824 .33485 .2866 .33194 .28403 .32801 Metetra
.725 .688 .814 r
.28403 .32801 .2866 .33194 .2908 .32916 .28823 .3253 Metetra
.722 .691 .819 r
.28823 .3253 .2908 .32916 .295 .32648 .29242 .32269 Metetra
.719 .693 .825 r
.29242 .32269 .295 .32648 .29919 .32389 .29661 .32015 Metetra
.717 .696 .829 r
.29661 .32015 .29919 .32389 .30338 .32138 .3008 .3177 Metetra
.714 .698 .834 r
.3008 .3177 .30338 .32138 .30757 .31894 .30499 .3153 Metetra
.711 .7 .838 r
.30499 .3153 .30757 .31894 .31176 .31656 .30918 .31297 Metetra
.709 .702 .841 r
.30918 .31297 .31176 .31656 .31595 .31424 .31337 .31069 Metetra
.707 .704 .845 r
.31337 .31069 .31595 .31424 .32014 .31198 .31756 .30845 Metetra
.705 .705 .848 r
.31756 .30845 .32014 .31198 .32433 .30976 .32175 .30626 Metetra
.702 .707 .851 r
.32175 .30626 .32433 .30976 .32852 .30758 .32595 .30411 Metetra
.701 .708 .854 r
.32595 .30411 .32852 .30758 .33272 .30545 .33014 .302 Metetra
.931 .723 .601 r
.33014 .302 .33272 .30545 .33691 .30335 .33542 .28223 Metetra
.563 .381 .592 r
.33542 .28223 .33691 .30335 .34215 .28364 .33958 .2805 Metetra
.677 .722 .883 r
.33958 .2805 .34215 .28364 .34631 .28192 .34375 .27878 Metetra
.676 .722 .884 r
.34375 .27878 .34631 .28192 .35048 .28021 .34792 .27708 Metetra
.675 .722 .885 r
.34792 .27708 .35048 .28021 .35465 .27851 .35209 .27538 Metetra
.674 .722 .886 r
.35209 .27538 .35465 .27851 .35883 .27683 .35627 .2737 Metetra
.673 .723 .887 r
.35627 .2737 .35883 .27683 .36301 .27516 .36046 .27203 Metetra
.672 .723 .888 r
.36046 .27203 .36301 .27516 .3672 .2735 .36465 .27037 Metetra
.671 .723 .888 r
.36465 .27037 .3672 .2735 .3714 .27185 .36885 .26872 Metetra
.67 .723 .889 r
.36885 .26872 .3714 .27185 .37559 .27021 .37305 .26708 Metetra
.669 .723 .89 r
.37305 .26708 .37559 .27021 .3798 .26857 .37726 .26545 Metetra
.668 .723 .89 r
.37726 .26545 .3798 .26857 .38401 .26695 .38148 .26383 Metetra
.667 .723 .891 r
.38148 .26383 .38401 .26695 .38823 .26534 .3857 .26221 Metetra
.666 .723 .891 r
.3857 .26221 .38823 .26534 .39245 .26373 .38992 .2606 Metetra
.665 .723 .892 r
.38992 .2606 .39245 .26373 .39668 .26213 .39416 .259 Metetra
.665 .723 .892 r
.39416 .259 .39668 .26213 .40092 .26054 .3984 .25741 Metetra
.664 .723 .893 r
.3984 .25741 .40092 .26054 .40516 .25896 .40264 .25582 Metetra
.663 .722 .893 r
.40264 .25582 .40516 .25896 .4094 .25739 .40689 .25425 Metetra
.662 .722 .894 r
.40689 .25425 .4094 .25739 .41366 .25582 .41115 .25267 Metetra
.661 .722 .894 r
.41115 .25267 .41366 .25582 .41792 .25426 .41541 .25111 Metetra
.661 .722 .894 r
.41541 .25111 .41792 .25426 .42218 .2527 .41968 .24955 Metetra
.66 .721 .895 r
.41968 .24955 .42218 .2527 .42646 .25116 .42396 .248 Metetra
.659 .721 .895 r
.42396 .248 .42646 .25116 .43074 .24962 .42824 .24646 Metetra
.658 .721 .895 r
.42824 .24646 .43074 .24962 .43502 .24809 .43253 .24492 Metetra
.657 .72 .895 r
.43253 .24492 .43502 .24809 .43931 .24656 .43683 .24339 Metetra
.656 .72 .896 r
.43683 .24339 .43931 .24656 .44361 .24505 .44113 .24187 Metetra
.655 .72 .896 r
.44113 .24187 .44361 .24505 .44792 .24354 .44544 .24035 Metetra
.655 .719 .896 r
.44544 .24035 .44792 .24354 .45223 .24204 .44976 .23884 Metetra
.654 .718 .896 r
.44976 .23884 .45223 .24204 .45655 .24055 .45408 .23734 Metetra
.653 .718 .896 r
.45408 .23734 .45655 .24055 .46088 .23906 .45841 .23585 Metetra
.652 .717 .896 r
.45841 .23585 .46088 .23906 .46521 .23759 .46275 .23437 Metetra
.651 .717 .896 r
.46275 .23437 .46521 .23759 .46955 .23612 .46709 .23289 Metetra
.65 .716 .896 r
.46709 .23289 .46955 .23612 .4739 .23467 .47145 .23143 Metetra
.648 .715 .897 r
.47145 .23143 .4739 .23467 .47825 .23322 .4758 .22997 Metetra
.647 .714 .897 r
.4758 .22997 .47825 .23322 .48262 .23179 .48017 .22853 Metetra
.646 .713 .897 r
.48017 .22853 .48262 .23179 .48698 .23037 .48454 .22709 Metetra
.645 .712 .897 r
.48454 .22709 .48698 .23037 .49136 .22896 .48892 .22567 Metetra
.643 .711 .896 r
.48892 .22567 .49136 .22896 .49574 .22756 .49331 .22426 Metetra
.642 .71 .896 r
.49331 .22426 .49574 .22756 .50014 .22618 .49771 .22286 Metetra
.64 .708 .896 r
.49771 .22286 .50014 .22618 .50441 .24298 .50211 .22148 Metetra
.006 0 .475 r
.50211 .22148 .50441 .24298 .50884 .24199 .50641 .23835 Metetra
.602 .672 .889 r
.50641 .23835 .50884 .24199 .51328 .24104 .51085 .23736 Metetra
.599 .668 .888 r
.51085 .23736 .51328 .24104 .51773 .24012 .5153 .23641 Metetra
.595 .664 .887 r
.5153 .23641 .51773 .24012 .52219 .23926 .51976 .23551 Metetra
.59 .66 .886 r
.51976 .23551 .52219 .23926 .52666 .23844 .52423 .23464 Metetra
.585 .655 .885 r
.52423 .23464 .52666 .23844 .53113 .23767 .52871 .23383 Metetra
.58 .65 .884 r
.52871 .23383 .53113 .23767 .53562 .23696 .5332 .23307 Metetra
.574 .645 .882 r
.5332 .23307 .53562 .23696 .54012 .23632 .5377 .23238 Metetra
.568 .638 .88 r
.5377 .23238 .54012 .23632 .54462 .23576 .54221 .23175 Metetra
.561 .631 .878 r
.54221 .23175 .54462 .23576 .54914 .23527 .54673 .23119 Metetra
.553 .623 .876 r
.54673 .23119 .54914 .23527 .55367 .23488 .55127 .23072 Metetra
.544 .614 .873 r
.55127 .23072 .55367 .23488 .55822 .23459 .55581 .23035 Metetra
.535 .604 .87 r
.55581 .23035 .55822 .23459 .56277 .23443 .56037 .23008 Metetra
.524 .593 .866 r
.56037 .23008 .56277 .23443 .56734 .2344 .56494 .22994 Metetra
.511 .58 .861 r
.56494 .22994 .56734 .2344 .57193 .23454 .56952 .22994 Metetra
.496 .565 .855 r
.56952 .22994 .57193 .23454 .57653 .23486 .57412 .23011 Metetra
.48 .548 .849 r
.57412 .23011 .57653 .23486 .58114 .23541 .57873 .23048 Metetra
.46 .528 .841 r
.57873 .23048 .58114 .23541 .58578 .23622 .58337 .23107 Metetra
.438 .505 .831 r
.58337 .23107 .58578 .23622 .59044 .23735 .58802 .23195 Metetra
.412 .478 .818 r
.58802 .23195 .59044 .23735 .59513 .23888 .5927 .23316 Metetra
.381 .446 .803 r
.5927 .23316 .59513 .23888 .59984 .24092 .5974 .23479 Metetra
.344 .407 .783 r
.5974 .23479 .59984 .24092 .60459 .24359 .60214 .23695 Metetra
.3 .362 .759 r
.60214 .23695 .60459 .24359 .60938 .24711 .60691 .23979 Metetra
.248 .307 .728 r
.60691 .23979 .60938 .24711 .61424 .25178 .61173 .24353 Metetra
.186 .243 .689 r
.61173 .24353 .61424 .25178 .61916 .25809 .61661 .24853 Metetra
.114 .167 .64 r
.61661 .24853 .61916 .25809 .62421 .26689 .62157 .25532 Metetra
.03 .08 .58 r
.62157 .25532 .62421 .26689 .62943 .27978 .62667 .26489 Metetra
0 0 .508 r
.62667 .26489 .62943 .27978 .63497 .30027 .63196 .27912 Metetra
0 0 .425 r
.63196 .27912 .63497 .30027 .64123 .33837 .63764 .3024 Metetra
0 0 .331 r
.63764 .3024 .64123 .33837 .64796 .38514 .64426 .34837 Metetra
.003 0 .45 r
.64426 .34837 .64796 .38514 .64334 .14365 .6505 .38054 Metetra
0 0 .341 r
.6505 .38054 .64334 .14365 .64793 .14196 .64568 .13883 Metetra
.664 .741 .907 r
.64568 .13883 .64793 .14196 .65253 .14026 .65028 .13712 Metetra
.664 .741 .907 r
.65028 .13712 .65253 .14026 .65713 .13856 .65489 .13542 Metetra
.664 .741 .907 r
.65489 .13542 .65713 .13856 .66174 .13686 .65951 .13371 Metetra
.664 .741 .907 r
.65951 .13371 .66174 .13686 .66636 .13516 .66413 .132 Metetra
.664 .741 .907 r
.66413 .132 .66636 .13516 .67099 .13345 .66876 .13029 Metetra
.664 .741 .907 r
.66876 .13029 .67099 .13345 .67562 .13174 .6734 .12857 Metetra
.664 .741 .907 r
.6734 .12857 .67562 .13174 .68026 .13003 .67804 .12686 Metetra
.664 .741 .907 r
.67804 .12686 .68026 .13003 .68491 .12831 .6827 .12513 Metetra
.664 .741 .907 r
.6827 .12513 .68491 .12831 .68956 .12659 .68736 .12341 Metetra
.664 .741 .907 r
.68736 .12341 .68956 .12659 .69423 .12487 .69203 .12168 Metetra
.664 .741 .907 r
.69203 .12168 .69423 .12487 .6989 .12314 .69671 .11995 Metetra
.664 .741 .907 r
.69671 .11995 .6989 .12314 .70358 .12142 .70139 .11822 Metetra
.664 .741 .907 r
.70139 .11822 .70358 .12142 .70827 .11969 .70608 .11649 Metetra
.664 .741 .907 r
.70608 .11649 .70827 .11969 .71296 .11795 .71078 .11475 Metetra
.664 .741 .907 r
.71078 .11475 .71296 .11795 .71766 .11622 .71549 .11301 Metetra
.664 .741 .907 r
.71549 .11301 .71766 .11622 .72237 .11448 .72021 .11126 Metetra
.664 .741 .907 r
.72021 .11126 .72237 .11448 .72709 .11274 .72493 .10951 Metetra
.664 .741 .907 r
.72493 .10951 .72709 .11274 .73182 .11099 .72966 .10776 Metetra
.664 .741 .907 r
.72966 .10776 .73182 .11099 .73655 .10925 .7344 .10601 Metetra
.664 .741 .907 r
.7344 .10601 .73655 .10925 .74129 .10749 .73915 .10426 Metetra
.664 .741 .907 r
.73915 .10426 .74129 .10749 .74604 .10574 .7439 .1025 Metetra
.664 .741 .907 r
.7439 .1025 .74604 .10574 .7508 .10398 .74867 .10073 Metetra
.664 .741 .907 r
.74867 .10073 .7508 .10398 .75557 .10223 .75344 .09897 Metetra
.664 .741 .907 r
.11781 .33046 .12058 .33305 .12436 .33165 .1216 .32906 Metetra
.664 .741 .907 r
.1216 .32906 .12436 .33165 .12815 .33025 .12539 .32766 Metetra
.664 .741 .907 r
.12539 .32766 .12815 .33025 .13194 .32884 .12918 .32625 Metetra
.664 .741 .907 r
.12918 .32625 .13194 .32884 .13574 .32744 .13298 .32484 Metetra
.664 .741 .907 r
.13298 .32484 .13574 .32744 .13954 .32603 .13679 .32343 Metetra
.664 .741 .907 r
.13679 .32343 .13954 .32603 .14335 .32462 .1406 .32202 Metetra
.664 .741 .907 r
.1406 .32202 .14335 .32462 .14716 .32321 .14442 .3206 Metetra
.664 .741 .907 r
.14442 .3206 .14716 .32321 .15098 .3218 .14824 .31918 Metetra
.664 .741 .907 r
.14824 .31918 .15098 .3218 .15481 .32038 .15207 .31777 Metetra
.664 .741 .907 r
.15207 .31777 .15481 .32038 .15864 .31897 .15591 .31634 Metetra
.664 .741 .907 r
.15591 .31634 .15864 .31897 .16248 .31755 .15975 .31492 Metetra
.664 .741 .907 r
.15975 .31492 .16248 .31755 .16632 .31613 .1636 .3135 Metetra
.664 .741 .907 r
.1636 .3135 .16632 .31613 .17017 .3147 .16745 .31207 Metetra
.664 .741 .907 r
.16745 .31207 .17017 .3147 .17403 .31328 .17131 .31064 Metetra
.664 .741 .907 r
.17131 .31064 .17403 .31328 .17789 .31185 .17517 .30921 Metetra
.664 .741 .907 r
.17517 .30921 .17789 .31185 .18175 .31042 .17904 .30777 Metetra
.664 .741 .907 r
.17904 .30777 .18175 .31042 .18563 .30899 .18292 .30634 Metetra
.664 .741 .907 r
.18292 .30634 .18563 .30899 .1895 .30755 .1868 .3049 Metetra
.664 .741 .907 r
.1868 .3049 .1895 .30755 .19339 .30612 .19068 .30346 Metetra
.664 .741 .907 r
.19068 .30346 .19339 .30612 .19728 .30468 .19458 .30201 Metetra
.664 .741 .907 r
.19458 .30201 .19728 .30468 .20117 .30324 .19848 .30057 Metetra
.664 .741 .907 r
.19848 .30057 .20117 .30324 .20508 .30179 .20238 .29912 Metetra
.947 .682 .501 r
.20238 .29912 .20508 .30179 .20898 .30035 .18258 .52987 Metetra
.483 .252 .487 r
.18258 .52987 .20898 .30035 .1897 .53103 .18826 .51376 Metetra
.883 .637 .562 r
.18826 .51376 .1897 .53103 .1971 .49714 .19805 .45614 Metetra
.727 .489 .567 r
.19805 .45614 .1971 .49714 .20574 .4498 .20486 .42735 Metetra
.747 .522 .589 r
.20486 .42735 .20574 .4498 .21218 .42426 .2106 .40904 Metetra
.757 .546 .611 r
.2106 .40904 .21218 .42426 .21773 .40745 .2158 .39591 Metetra
.761 .565 .633 r
.2158 .39591 .21773 .40745 .22284 .39514 .2207 .38576 Metetra
.763 .582 .654 r
.2207 .38576 .22284 .39514 .22767 .3855 .22541 .37752 Metetra
.762 .597 .673 r
.22541 .37752 .22767 .3855 .23233 .3776 .22998 .37059 Metetra
.761 .611 .692 r
.22998 .37059 .23233 .3776 .23687 .37091 .23446 .36459 Metetra
.759 .622 .708 r
.23446 .36459 .23687 .37091 .24133 .36509 .23888 .3593 Metetra
.756 .633 .724 r
.23888 .3593 .24133 .36509 .24572 .35994 .24324 .35454 Metetra
.753 .642 .738 r
.24324 .35454 .24572 .35994 .25007 .35529 .24756 .35022 Metetra
.75 .65 .751 r
.24756 .35022 .25007 .35529 .25438 .35105 .25185 .34623 Metetra
.746 .657 .762 r
.25185 .34623 .25438 .35105 .25866 .34713 .25612 .34252 Metetra
.743 .664 .773 r
.25612 .34252 .25866 .34713 .26293 .34348 .26037 .33905 Metetra
.739 .669 .782 r
.26037 .33905 .26293 .34348 .26717 .34006 .2646 .33578 Metetra
.736 .675 .791 r
.2646 .33578 .26717 .34006 .2714 .33683 .26883 .33267 Metetra
.732 .679 .799 r
.26883 .33267 .2714 .33683 .27562 .33375 .27304 .3297 Metetra
.729 .683 .806 r
.27304 .3297 .27562 .33375 .27983 .33082 .27724 .32686 Metetra
.726 .687 .812 r
.27724 .32686 .27983 .33082 .28403 .32801 .28144 .32413 Metetra
.723 .69 .818 r
.28144 .32413 .28403 .32801 .28823 .3253 .28564 .32149 Metetra
.72 .693 .823 r
.28564 .32149 .28823 .3253 .29242 .32269 .28983 .31894 Metetra
.717 .695 .828 r
.28983 .31894 .29242 .32269 .29661 .32015 .29402 .31646 Metetra
.715 .698 .833 r
.29402 .31646 .29661 .32015 .3008 .3177 .29821 .31405 Metetra
.712 .7 .837 r
.29821 .31405 .3008 .3177 .30499 .3153 .3024 .31169 Metetra
.71 .702 .841 r
.3024 .31169 .30499 .3153 .30918 .31297 .30659 .3094 Metetra
.707 .704 .844 r
.30659 .3094 .30918 .31297 .31337 .31069 .31078 .30715 Metetra
.705 .705 .847 r
.31078 .30715 .31337 .31069 .31756 .30845 .31497 .30495 Metetra
.703 .707 .85 r
.31497 .30495 .31756 .30845 .32175 .30626 .31917 .30278 Metetra
.701 .708 .853 r
.31917 .30278 .32175 .30626 .32595 .30411 .32336 .30066 Metetra
.93 .723 .601 r
.32336 .30066 .32595 .30411 .33014 .302 .32868 .28082 Metetra
.563 .38 .592 r
.32868 .28082 .33014 .302 .33542 .28223 .33284 .27908 Metetra
.677 .722 .883 r
.33284 .27908 .33542 .28223 .33958 .2805 .33701 .27736 Metetra
.676 .722 .884 r
.33701 .27736 .33958 .2805 .34375 .27878 .34117 .27564 Metetra
.675 .722 .885 r
.34117 .27564 .34375 .27878 .34792 .27708 .34535 .27394 Metetra
.674 .723 .886 r
.34535 .27394 .34792 .27708 .35209 .27538 .34953 .27225 Metetra
.673 .723 .887 r
.34953 .27225 .35209 .27538 .35627 .2737 .35371 .27057 Metetra
.672 .723 .888 r
.35371 .27057 .35627 .2737 .36046 .27203 .3579 .26891 Metetra
.671 .723 .888 r
.3579 .26891 .36046 .27203 .36465 .27037 .3621 .26725 Metetra
.67 .723 .889 r
.3621 .26725 .36465 .27037 .36885 .26872 .3663 .2656 Metetra
.669 .723 .89 r
.3663 .2656 .36885 .26872 .37305 .26708 .3705 .26396 Metetra
.669 .723 .89 r
.3705 .26396 .37305 .26708 .37726 .26545 .37472 .26232 Metetra
.668 .723 .891 r
.37472 .26232 .37726 .26545 .38148 .26383 .37893 .2607 Metetra
.667 .723 .891 r
.37893 .2607 .38148 .26383 .3857 .26221 .38316 .25908 Metetra
.666 .723 .892 r
.38316 .25908 .3857 .26221 .38992 .2606 .38739 .25747 Metetra
.665 .723 .892 r
.38739 .25747 .38992 .2606 .39416 .259 .39163 .25587 Metetra
.664 .723 .893 r
.39163 .25587 .39416 .259 .3984 .25741 .39587 .25428 Metetra
.664 .723 .893 r
.39587 .25428 .3984 .25741 .40264 .25582 .40012 .25269 Metetra
.663 .723 .894 r
.40012 .25269 .40264 .25582 .40689 .25425 .40437 .2511 Metetra
.662 .723 .894 r
.40437 .2511 .40689 .25425 .41115 .25267 .40863 .24953 Metetra
.661 .722 .894 r
.40863 .24953 .41115 .25267 .41541 .25111 .4129 .24796 Metetra
.661 .722 .895 r
.4129 .24796 .41541 .25111 .41968 .24955 .41717 .2464 Metetra
.66 .722 .895 r
.41717 .2464 .41968 .24955 .42396 .248 .42146 .24484 Metetra
.659 .722 .895 r
.42146 .24484 .42396 .248 .42824 .24646 .42574 .24329 Metetra
.658 .721 .895 r
.42574 .24329 .42824 .24646 .43253 .24492 .43004 .24175 Metetra
.657 .721 .896 r
.43004 .24175 .43253 .24492 .43683 .24339 .43434 .24021 Metetra
.657 .72 .896 r
.43434 .24021 .43683 .24339 .44113 .24187 .43864 .23868 Metetra
.656 .72 .896 r
.43864 .23868 .44113 .24187 .44544 .24035 .44296 .23716 Metetra
.655 .72 .896 r
.44296 .23716 .44544 .24035 .44976 .23884 .44728 .23564 Metetra
.654 .719 .896 r
.44728 .23564 .44976 .23884 .45408 .23734 .45161 .23414 Metetra
.653 .718 .896 r
.45161 .23414 .45408 .23734 .45841 .23585 .45594 .23264 Metetra
.652 .718 .897 r
.45594 .23264 .45841 .23585 .46275 .23437 .46028 .23114 Metetra
.651 .717 .897 r
.46028 .23114 .46275 .23437 .46709 .23289 .46463 .22966 Metetra
.65 .716 .897 r
.46463 .22966 .46709 .23289 .47145 .23143 .46899 .22818 Metetra
.649 .716 .897 r
.46899 .22818 .47145 .23143 .4758 .22997 .47335 .22672 Metetra
.648 .715 .897 r
.47335 .22672 .4758 .22997 .48017 .22853 .47772 .22526 Metetra
.647 .714 .897 r
.47772 .22526 .48017 .22853 .48454 .22709 .48209 .22382 Metetra
.645 .713 .897 r
.48209 .22382 .48454 .22709 .48892 .22567 .48648 .22238 Metetra
.644 .712 .897 r
.48648 .22238 .48892 .22567 .49331 .22426 .49087 .22096 Metetra
.643 .711 .897 r
.49087 .22096 .49331 .22426 .49771 .22286 .49527 .21955 Metetra
.641 .71 .897 r
.49527 .21955 .49771 .22286 .50211 .22148 .49968 .21815 Metetra
.64 .708 .896 r
.49968 .21815 .50211 .22148 .50641 .23835 .50409 .21677 Metetra
.006 0 .475 r
.50409 .21677 .50641 .23835 .51085 .23736 .50841 .2337 Metetra
.601 .671 .889 r
.50841 .2337 .51085 .23736 .5153 .23641 .51287 .23272 Metetra
.598 .667 .888 r
.51287 .23272 .5153 .23641 .51976 .23551 .51733 .23177 Metetra
.593 .663 .887 r
.51733 .23177 .51976 .23551 .52423 .23464 .52181 .23087 Metetra
.589 .659 .886 r
.52181 .23087 .52423 .23464 .52871 .23383 .52629 .23002 Metetra
.584 .654 .885 r
.52629 .23002 .52871 .23383 .5332 .23307 .53078 .22921 Metetra
.579 .649 .883 r
.53078 .22921 .5332 .23307 .5377 .23238 .53528 .22846 Metetra
.573 .643 .882 r
.53528 .22846 .5377 .23238 .54221 .23175 .5398 .22777 Metetra
.567 .637 .88 r
.5398 .22777 .54221 .23175 .54673 .23119 .54432 .22715 Metetra
.559 .629 .878 r
.54432 .22715 .54673 .23119 .55127 .23072 .54885 .22661 Metetra
.551 .621 .875 r
.54885 .22661 .55127 .23072 .55581 .23035 .5534 .22616 Metetra
.542 .612 .872 r
.5534 .22616 .55581 .23035 .56037 .23008 .55796 .2258 Metetra
.532 .602 .869 r
.55796 .2258 .56037 .23008 .56494 .22994 .56253 .22555 Metetra
.521 .59 .865 r
.56253 .22555 .56494 .22994 .56952 .22994 .56711 .22544 Metetra
.508 .577 .86 r
.56711 .22544 .56952 .22994 .57412 .23011 .57171 .22547 Metetra
.493 .562 .854 r
.57171 .22547 .57412 .23011 .57873 .23048 .57632 .22567 Metetra
.476 .544 .847 r
.57632 .22567 .57873 .23048 .58337 .23107 .58095 .22608 Metetra
.456 .523 .838 r
.58095 .22608 .58337 .23107 .58802 .23195 .5856 .22673 Metetra
.433 .499 .828 r
.5856 .22673 .58802 .23195 .5927 .23316 .59027 .22766 Metetra
.405 .471 .815 r
.59027 .22766 .5927 .23316 .5974 .23479 .59497 .22896 Metetra
.373 .437 .798 r
.59497 .22896 .5974 .23479 .60214 .23695 .59969 .23069 Metetra
.335 .398 .778 r
.59969 .23069 .60214 .23695 .60691 .23979 .60444 .23298 Metetra
.29 .35 .752 r
.60444 .23298 .60691 .23979 .61173 .24353 .60924 .236 Metetra
.236 .294 .72 r
.60924 .236 .61173 .24353 .61661 .24853 .61408 .23998 Metetra
.172 .227 .679 r
.61408 .23998 .61661 .24853 .62157 .25532 .619 .24532 Metetra
.097 .149 .628 r
.619 .24532 .62157 .25532 .62667 .26489 .624 .25264 Metetra
.012 .059 .565 r
.624 .25264 .62667 .26489 .63196 .27912 .62915 .26305 Metetra
0 0 .491 r
.62915 .26305 .63196 .27912 .63764 .3024 .63453 .27883 Metetra
0 0 .406 r
.63453 .27883 .63764 .3024 .64426 .34837 .64038 .3055 Metetra
0 0 .308 r
.64038 .3055 .64426 .34837 .6505 .38054 .64748 .36221 Metetra
.095 .075 .542 r
.64748 .36221 .6505 .38054 .64568 .13883 .65305 .37591 Metetra
0 0 .341 r
.65305 .37591 .64568 .13883 .65028 .13712 .64803 .13398 Metetra
.664 .741 .907 r
.64803 .13398 .65028 .13712 .65489 .13542 .65264 .13227 Metetra
.664 .741 .907 r
.65264 .13227 .65489 .13542 .65951 .13371 .65726 .13055 Metetra
.664 .741 .907 r
.65726 .13055 .65951 .13371 .66413 .132 .66189 .12884 Metetra
.664 .741 .907 r
.66189 .12884 .66413 .132 .66876 .13029 .66653 .12712 Metetra
.664 .741 .907 r
.66653 .12712 .66876 .13029 .6734 .12857 .67117 .1254 Metetra
.664 .741 .907 r
.67117 .1254 .6734 .12857 .67804 .12686 .67582 .12368 Metetra
.664 .741 .907 r
.67582 .12368 .67804 .12686 .6827 .12513 .68048 .12195 Metetra
.664 .741 .907 r
.68048 .12195 .6827 .12513 .68736 .12341 .68515 .12022 Metetra
.664 .741 .907 r
.68515 .12022 .68736 .12341 .69203 .12168 .68982 .11849 Metetra
.664 .741 .907 r
.68982 .11849 .69203 .12168 .69671 .11995 .69451 .11675 Metetra
.664 .741 .907 r
.69451 .11675 .69671 .11995 .70139 .11822 .6992 .11501 Metetra
.664 .741 .907 r
.6992 .11501 .70139 .11822 .70608 .11649 .70389 .11327 Metetra
.664 .741 .907 r
.70389 .11327 .70608 .11649 .71078 .11475 .7086 .11153 Metetra
.664 .741 .907 r
.7086 .11153 .71078 .11475 .71549 .11301 .71331 .10978 Metetra
.664 .741 .907 r
.71331 .10978 .71549 .11301 .72021 .11126 .71803 .10803 Metetra
.664 .741 .907 r
.71803 .10803 .72021 .11126 .72493 .10951 .72276 .10628 Metetra
.664 .741 .907 r
.72276 .10628 .72493 .10951 .72966 .10776 .7275 .10453 Metetra
.664 .741 .907 r
.7275 .10453 .72966 .10776 .7344 .10601 .73224 .10277 Metetra
.664 .741 .907 r
.73224 .10277 .7344 .10601 .73915 .10426 .737 .10101 Metetra
.664 .741 .907 r
.737 .10101 .73915 .10426 .7439 .1025 .74176 .09924 Metetra
.664 .741 .907 r
.74176 .09924 .7439 .1025 .74867 .10073 .74653 .09747 Metetra
.664 .741 .907 r
.74653 .09747 .74867 .10073 .75344 .09897 .7513 .0957 Metetra
.664 .741 .907 r
.11504 .32787 .11781 .33046 .1216 .32906 .11883 .32647 Metetra
.664 .741 .907 r
.11883 .32647 .1216 .32906 .12539 .32766 .12262 .32506 Metetra
.664 .741 .907 r
.12262 .32506 .12539 .32766 .12918 .32625 .12642 .32365 Metetra
.664 .741 .907 r
.12642 .32365 .12918 .32625 .13298 .32484 .13022 .32223 Metetra
.664 .741 .907 r
.13022 .32223 .13298 .32484 .13679 .32343 .13403 .32082 Metetra
.664 .741 .907 r
.13403 .32082 .13679 .32343 .1406 .32202 .13785 .3194 Metetra
.664 .741 .907 r
.13785 .3194 .1406 .32202 .14442 .3206 .14167 .31798 Metetra
.664 .741 .907 r
.14167 .31798 .14442 .3206 .14824 .31918 .14549 .31656 Metetra
.664 .741 .907 r
.14549 .31656 .14824 .31918 .15207 .31777 .14933 .31514 Metetra
.664 .741 .907 r
.14933 .31514 .15207 .31777 .15591 .31634 .15317 .31372 Metetra
.664 .741 .907 r
.15317 .31372 .15591 .31634 .15975 .31492 .15701 .31229 Metetra
.664 .741 .907 r
.15701 .31229 .15975 .31492 .1636 .3135 .16086 .31086 Metetra
.664 .741 .907 r
.16086 .31086 .1636 .3135 .16745 .31207 .16472 .30943 Metetra
.664 .741 .907 r
.16472 .30943 .16745 .31207 .17131 .31064 .16858 .30799 Metetra
.664 .741 .907 r
.16858 .30799 .17131 .31064 .17517 .30921 .17244 .30656 Metetra
.664 .741 .907 r
.17244 .30656 .17517 .30921 .17904 .30777 .17632 .30512 Metetra
.664 .741 .907 r
.17632 .30512 .17904 .30777 .18292 .30634 .1802 .30368 Metetra
.664 .741 .907 r
.1802 .30368 .18292 .30634 .1868 .3049 .18408 .30224 Metetra
.664 .741 .907 r
.18408 .30224 .1868 .3049 .19068 .30346 .18797 .30079 Metetra
.664 .741 .907 r
.18797 .30079 .19068 .30346 .19458 .30201 .19187 .29935 Metetra
.664 .741 .907 r
.19187 .29935 .19458 .30201 .19848 .30057 .19577 .2979 Metetra
.947 .682 .502 r
.19577 .2979 .19848 .30057 .20238 .29912 .17546 .52871 Metetra
.513 .277 .494 r
.17546 .52871 .20238 .29912 .18258 .52987 .17965 .52734 Metetra
.942 .703 .547 r
.17965 .52734 .18258 .52987 .18826 .51376 .19019 .46366 Metetra
.719 .478 .562 r
.19019 .46366 .18826 .51376 .19805 .45614 .19747 .43087 Metetra
.743 .515 .584 r
.19747 .43087 .19805 .45614 .20486 .42735 .20342 .41085 Metetra
.754 .54 .606 r
.20342 .41085 .20486 .42735 .2106 .40904 .20874 .39679 Metetra
.76 .561 .628 r
.20874 .39679 .2106 .40904 .2158 .39591 .21371 .38609 Metetra
.762 .578 .649 r
.21371 .38609 .2158 .39591 .2207 .38576 .21847 .37749 Metetra
.762 .594 .669 r
.21847 .37749 .2207 .38576 .22541 .37752 .22307 .3703 Metetra
.761 .607 .687 r
.22307 .3703 .22541 .37752 .22998 .37059 .22758 .36411 Metetra
.759 .619 .705 r
.22758 .36411 .22998 .37059 .23446 .36459 .23201 .35868 Metetra
.756 .63 .72 r
.23201 .35868 .23446 .36459 .23888 .3593 .23639 .35381 Metetra
.753 .64 .735 r
.23639 .35381 .23888 .3593 .24324 .35454 .24073 .3494 Metetra
.75 .648 .748 r
.24073 .3494 .24324 .35454 .24756 .35022 .24503 .34534 Metetra
.747 .656 .76 r
.24503 .34534 .24756 .35022 .25185 .34623 .2493 .34157 Metetra
.743 .662 .77 r
.2493 .34157 .25185 .34623 .25612 .34252 .25356 .33805 Metetra
.74 .668 .78 r
.25356 .33805 .25612 .34252 .26037 .33905 .2578 .33473 Metetra
.736 .673 .789 r
.2578 .33473 .26037 .33905 .2646 .33578 .26202 .33158 Metetra
.733 .678 .797 r
.26202 .33158 .2646 .33578 .26883 .33267 .26624 .32858 Metetra
.73 .682 .804 r
.26624 .32858 .26883 .33267 .27304 .3297 .27045 .32571 Metetra
.727 .686 .811 r
.27045 .32571 .27304 .3297 .27724 .32686 .27465 .32296 Metetra
.724 .689 .817 r
.27465 .32296 .27724 .32686 .28144 .32413 .27885 .32029 Metetra
.721 .692 .822 r
.27885 .32029 .28144 .32413 .28564 .32149 .28304 .31772 Metetra
.718 .695 .827 r
.28304 .31772 .28564 .32149 .28983 .31894 .28723 .31522 Metetra
.715 .697 .832 r
.28723 .31522 .28983 .31894 .29402 .31646 .29142 .31279 Metetra
.713 .699 .836 r
.29142 .31279 .29402 .31646 .29821 .31405 .29561 .31042 Metetra
.71 .701 .84 r
.29561 .31042 .29821 .31405 .3024 .31169 .2998 .30811 Metetra
.708 .703 .843 r
.2998 .30811 .3024 .31169 .30659 .3094 .30399 .30585 Metetra
.706 .705 .847 r
.30399 .30585 .30659 .3094 .31078 .30715 .30819 .30363 Metetra
.704 .706 .85 r
.30819 .30363 .31078 .30715 .31497 .30495 .31238 .30146 Metetra
.702 .708 .852 r
.31238 .30146 .31497 .30495 .31917 .30278 .31657 .29932 Metetra
.93 .723 .601 r
.31657 .29932 .31917 .30278 .32336 .30066 .32194 .27942 Metetra
.563 .38 .591 r
.32194 .27942 .32336 .30066 .32868 .28082 .32609 .27767 Metetra
.678 .722 .883 r
.32609 .27767 .32868 .28082 .33284 .27908 .33026 .27594 Metetra
.677 .722 .884 r
.33026 .27594 .33284 .27908 .33701 .27736 .33442 .27422 Metetra
.676 .723 .885 r
.33442 .27422 .33701 .27736 .34117 .27564 .33859 .27251 Metetra
.675 .723 .886 r
.33859 .27251 .34117 .27564 .34535 .27394 .34277 .27081 Metetra
.674 .723 .887 r
.34277 .27081 .34535 .27394 .34953 .27225 .34695 .26912 Metetra
.673 .723 .887 r
.34695 .26912 .34953 .27225 .35371 .27057 .35114 .26745 Metetra
.672 .723 .888 r
.35114 .26745 .35371 .27057 .3579 .26891 .35533 .26578 Metetra
.671 .724 .889 r
.35533 .26578 .3579 .26891 .3621 .26725 .35953 .26412 Metetra
.67 .724 .89 r
.35953 .26412 .3621 .26725 .3663 .2656 .36374 .26247 Metetra
.669 .724 .89 r
.36374 .26247 .3663 .2656 .3705 .26396 .36795 .26083 Metetra
.668 .724 .891 r
.36795 .26083 .3705 .26396 .37472 .26232 .37216 .2592 Metetra
.667 .724 .891 r
.37216 .2592 .37472 .26232 .37893 .2607 .37638 .25757 Metetra
.667 .724 .892 r
.37638 .25757 .37893 .2607 .38316 .25908 .38061 .25595 Metetra
.666 .724 .892 r
.38061 .25595 .38316 .25908 .38739 .25747 .38485 .25434 Metetra
.665 .724 .893 r
.38485 .25434 .38739 .25747 .39163 .25587 .38909 .25273 Metetra
.664 .723 .893 r
.38909 .25273 .39163 .25587 .39587 .25428 .39333 .25114 Metetra
.664 .723 .894 r
.39333 .25114 .39587 .25428 .40012 .25269 .39759 .24954 Metetra
.663 .723 .894 r
.39759 .24954 .40012 .25269 .40437 .2511 .40184 .24796 Metetra
.662 .723 .894 r
.40184 .24796 .40437 .2511 .40863 .24953 .40611 .24638 Metetra
.661 .723 .895 r
.40611 .24638 .40863 .24953 .4129 .24796 .41038 .24481 Metetra
.661 .723 .895 r
.41038 .24481 .4129 .24796 .41717 .2464 .41466 .24324 Metetra
.66 .722 .895 r
.41466 .24324 .41717 .2464 .42146 .24484 .41894 .24168 Metetra
.659 .722 .895 r
.41894 .24168 .42146 .24484 .42574 .24329 .42324 .24012 Metetra
.658 .722 .896 r
.42324 .24012 .42574 .24329 .43004 .24175 .42753 .23857 Metetra
.658 .721 .896 r
.42753 .23857 .43004 .24175 .43434 .24021 .43184 .23703 Metetra
.657 .721 .896 r
.43184 .23703 .43434 .24021 .43864 .23868 .43615 .2355 Metetra
.656 .721 .896 r
.43615 .2355 .43864 .23868 .44296 .23716 .44047 .23397 Metetra
.655 .72 .896 r
.44047 .23397 .44296 .23716 .44728 .23564 .44479 .23244 Metetra
.654 .72 .897 r
.44479 .23244 .44728 .23564 .45161 .23414 .44912 .23093 Metetra
.653 .719 .897 r
.44912 .23093 .45161 .23414 .45594 .23264 .45346 .22942 Metetra
.652 .718 .897 r
.45346 .22942 .45594 .23264 .46028 .23114 .45781 .22792 Metetra
.651 .718 .897 r
.45781 .22792 .46028 .23114 .46463 .22966 .46216 .22643 Metetra
.651 .717 .897 r
.46216 .22643 .46463 .22966 .46899 .22818 .46652 .22494 Metetra
.649 .716 .897 r
.46652 .22494 .46899 .22818 .47335 .22672 .47089 .22346 Metetra
.648 .716 .897 r
.47089 .22346 .47335 .22672 .47772 .22526 .47526 .222 Metetra
.647 .715 .897 r
.47526 .222 .47772 .22526 .48209 .22382 .47964 .22054 Metetra
.646 .714 .897 r
.47964 .22054 .48209 .22382 .48648 .22238 .48403 .21909 Metetra
.645 .713 .897 r
.48403 .21909 .48648 .22238 .49087 .22096 .48842 .21766 Metetra
.644 .712 .897 r
.48842 .21766 .49087 .22096 .49527 .21955 .49283 .21623 Metetra
.642 .711 .897 r
.49283 .21623 .49527 .21955 .49968 .21815 .49724 .21482 Metetra
.641 .709 .897 r
.49724 .21482 .49968 .21815 .50409 .21677 .50166 .21342 Metetra
.639 .708 .897 r
.50166 .21342 .50409 .21677 .50841 .2337 .50608 .21204 Metetra
.005 0 .474 r
.50608 .21204 .50841 .2337 .51287 .23272 .51043 .22904 Metetra
.6 .67 .889 r
.51043 .22904 .51287 .23272 .51733 .23177 .5149 .22806 Metetra
.597 .667 .888 r
.5149 .22806 .51733 .23177 .52181 .23087 .51937 .22712 Metetra
.592 .662 .887 r
.51937 .22712 .52181 .23087 .52629 .23002 .52386 .22622 Metetra
.588 .658 .886 r
.52386 .22622 .52629 .23002 .53078 .22921 .52835 .22537 Metetra
.583 .653 .885 r
.52835 .22537 .53078 .22921 .53528 .22846 .53286 .22457 Metetra
.578 .648 .883 r
.53286 .22457 .53528 .22846 .5398 .22777 .53737 .22383 Metetra
.572 .642 .881 r
.53737 .22383 .5398 .22777 .54432 .22715 .5419 .22315 Metetra
.565 .635 .879 r
.5419 .22315 .54432 .22715 .54885 .22661 .54643 .22254 Metetra
.558 .628 .877 r
.54643 .22254 .54885 .22661 .5534 .22616 .55098 .22201 Metetra
.549 .619 .875 r
.55098 .22201 .5534 .22616 .55796 .2258 .55554 .22157 Metetra
.54 .61 .871 r
.55554 .22157 .55796 .2258 .56253 .22555 .56011 .22123 Metetra
.53 .599 .868 r
.56011 .22123 .56253 .22555 .56711 .22544 .5647 .22101 Metetra
.518 .587 .863 r
.5647 .22101 .56711 .22544 .57171 .22547 .5693 .22092 Metetra
.505 .574 .858 r
.5693 .22092 .57171 .22547 .57632 .22567 .57391 .22098 Metetra
.489 .558 .852 r
.57391 .22098 .57632 .22567 .58095 .22608 .57854 .22122 Metetra
.472 .539 .845 r
.57854 .22122 .58095 .22608 .5856 .22673 .58318 .22167 Metetra
.451 .518 .836 r
.58318 .22167 .5856 .22673 .59027 .22766 .58785 .22237 Metetra
.427 .493 .825 r
.58785 .22237 .59027 .22766 .59497 .22896 .59254 .22337 Metetra
.399 .464 .811 r
.59254 .22337 .59497 .22896 .59969 .23069 .59725 .22474 Metetra
.366 .429 .794 r
.59725 .22474 .59969 .23069 .60444 .23298 .60199 .22658 Metetra
.326 .388 .773 r
.60199 .22658 .60444 .23298 .60924 .236 .60677 .22901 Metetra
.279 .339 .745 r
.60677 .22901 .60924 .236 .61408 .23998 .61158 .23221 Metetra
.224 .28 .711 r
.61158 .23221 .61408 .23998 .619 .24532 .61646 .23646 Metetra
.158 .211 .668 r
.61646 .23646 .619 .24532 .624 .25264 .6214 .24217 Metetra
.081 .131 .615 r
.6214 .24217 .624 .25264 .62915 .26305 .62645 .25006 Metetra
0 .039 .55 r
.62645 .25006 .62915 .26305 .63453 .27883 .63166 .26142 Metetra
0 0 .473 r
.63166 .26142 .63453 .27883 .64038 .3055 .63714 .27898 Metetra
0 0 .387 r
.63714 .27898 .64038 .3055 .64748 .36221 .64319 .30982 Metetra
0 0 .337 r
.64319 .30982 .64748 .36221 .65305 .37591 .65062 .37289 Metetra
.645 .763 .934 r
.65062 .37289 .65305 .37591 .64803 .13398 .65561 .37125 Metetra
0 0 .341 r
.65561 .37125 .64803 .13398 .65264 .13227 .65039 .1291 Metetra
.664 .741 .907 r
.65039 .1291 .65264 .13227 .65726 .13055 .65501 .12738 Metetra
.664 .741 .907 r
.65501 .12738 .65726 .13055 .66189 .12884 .65965 .12566 Metetra
.664 .741 .907 r
.65965 .12566 .66189 .12884 .66653 .12712 .66429 .12394 Metetra
.664 .741 .907 r
.66429 .12394 .66653 .12712 .67117 .1254 .66894 .12221 Metetra
.664 .741 .907 r
.66894 .12221 .67117 .1254 .67582 .12368 .6736 .12049 Metetra
.664 .741 .907 r
.6736 .12049 .67582 .12368 .68048 .12195 .67826 .11875 Metetra
.664 .741 .907 r
.67826 .11875 .68048 .12195 .68515 .12022 .68293 .11702 Metetra
.664 .741 .907 r
.68293 .11702 .68515 .12022 .68982 .11849 .68761 .11528 Metetra
.664 .741 .907 r
.68761 .11528 .68982 .11849 .69451 .11675 .6923 .11354 Metetra
.664 .741 .907 r
.6923 .11354 .69451 .11675 .6992 .11501 .69699 .1118 Metetra
.664 .741 .907 r
.69699 .1118 .6992 .11501 .70389 .11327 .7017 .11005 Metetra
.664 .741 .907 r
.7017 .11005 .70389 .11327 .7086 .11153 .70641 .1083 Metetra
.664 .741 .907 r
.70641 .1083 .7086 .11153 .71331 .10978 .71113 .10655 Metetra
.664 .741 .907 r
.71113 .10655 .71331 .10978 .71803 .10803 .71585 .1048 Metetra
.664 .741 .907 r
.71585 .1048 .71803 .10803 .72276 .10628 .72059 .10304 Metetra
.664 .741 .907 r
.72059 .10304 .72276 .10628 .7275 .10453 .72533 .10128 Metetra
.664 .741 .907 r
.72533 .10128 .7275 .10453 .73224 .10277 .73008 .09951 Metetra
.664 .741 .907 r
.73008 .09951 .73224 .10277 .737 .10101 .73484 .09775 Metetra
.664 .741 .907 r
.73484 .09775 .737 .10101 .74176 .09924 .73961 .09598 Metetra
.664 .741 .907 r
.73961 .09598 .74176 .09924 .74653 .09747 .74438 .0942 Metetra
.664 .741 .907 r
.74438 .0942 .74653 .09747 .7513 .0957 .74916 .09243 Metetra
.664 .741 .907 r
.11226 .32527 .11504 .32787 .11883 .32647 .11605 .32386 Metetra
.664 .741 .907 r
.11605 .32386 .11883 .32647 .12262 .32506 .11984 .32245 Metetra
.664 .741 .907 r
.11984 .32245 .12262 .32506 .12642 .32365 .12365 .32104 Metetra
.664 .741 .907 r
.12365 .32104 .12642 .32365 .13022 .32223 .12745 .31962 Metetra
.664 .741 .907 r
.12745 .31962 .13022 .32223 .13403 .32082 .13127 .3182 Metetra
.664 .741 .907 r
.13127 .3182 .13403 .32082 .13785 .3194 .13508 .31678 Metetra
.664 .741 .907 r
.13508 .31678 .13785 .3194 .14167 .31798 .13891 .31536 Metetra
.664 .741 .907 r
.13891 .31536 .14167 .31798 .14549 .31656 .14274 .31393 Metetra
.664 .741 .907 r
.14274 .31393 .14549 .31656 .14933 .31514 .14658 .31251 Metetra
.664 .741 .907 r
.14658 .31251 .14933 .31514 .15317 .31372 .15042 .31108 Metetra
.664 .741 .907 r
.15042 .31108 .15317 .31372 .15701 .31229 .15426 .30965 Metetra
.664 .741 .907 r
.15426 .30965 .15701 .31229 .16086 .31086 .15812 .30821 Metetra
.664 .741 .907 r
.15812 .30821 .16086 .31086 .16472 .30943 .16198 .30678 Metetra
.664 .741 .907 r
.16198 .30678 .16472 .30943 .16858 .30799 .16584 .30534 Metetra
.664 .741 .907 r
.16584 .30534 .16858 .30799 .17244 .30656 .16971 .3039 Metetra
.664 .741 .907 r
.16971 .3039 .17244 .30656 .17632 .30512 .17359 .30246 Metetra
.664 .741 .907 r
.17359 .30246 .17632 .30512 .1802 .30368 .17747 .30101 Metetra
.664 .741 .907 r
.17747 .30101 .1802 .30368 .18408 .30224 .18136 .29957 Metetra
.664 .741 .907 r
.18136 .29957 .18408 .30224 .18797 .30079 .18525 .29812 Metetra
.664 .741 .907 r
.18525 .29812 .18797 .30079 .19187 .29935 .18915 .29667 Metetra
.664 .741 .907 r
.18915 .29667 .19187 .29935 .19577 .2979 .19306 .29522 Metetra
.947 .682 .502 r
.19306 .29522 .19577 .2979 .17546 .52871 .17251 .52617 Metetra
.941 .705 .555 r
.17251 .52617 .17546 .52871 .17965 .52734 .18212 .4727 Metetra
.725 .483 .56 r
.18212 .4727 .17965 .52734 .19019 .46366 .19 .43491 Metetra
.739 .507 .579 r
.19 .43491 .19019 .46366 .19747 .43087 .19619 .41288 Metetra
.752 .534 .601 r
.19619 .41288 .19747 .43087 .20342 .41085 .20165 .3978 Metetra
.758 .556 .623 r
.20165 .3978 .20342 .41085 .20874 .39679 .2067 .38649 Metetra
.761 .574 .644 r
.2067 .38649 .20874 .39679 .21371 .38609 .21151 .37749 Metetra
.762 .59 .664 r
.21151 .37749 .21371 .38609 .21847 .37749 .21615 .37003 Metetra
.761 .604 .683 r
.21615 .37003 .21847 .37749 .22307 .3703 .22069 .36365 Metetra
.759 .616 .701 r
.22069 .36365 .22307 .3703 .22758 .36411 .22514 .35807 Metetra
.757 .628 .717 r
.22514 .35807 .22758 .36411 .23201 .35868 .22953 .35309 Metetra
.754 .637 .732 r
.22953 .35309 .23201 .35868 .23639 .35381 .23388 .34858 Metetra
.751 .646 .745 r
.23388 .34858 .23639 .35381 .24073 .3494 .23819 .34445 Metetra
.747 .654 .757 r
.23819 .34445 .24073 .3494 .24503 .34534 .24248 .34062 Metetra
.744 .661 .768 r
.24248 .34062 .24503 .34534 .2493 .34157 .24674 .33705 Metetra
.74 .667 .778 r
.24674 .33705 .2493 .34157 .25356 .33805 .25098 .33369 Metetra
.737 .672 .787 r
.25098 .33369 .25356 .33805 .2578 .33473 .25521 .3305 Metetra
.734 .677 .795 r
.25521 .3305 .2578 .33473 .26202 .33158 .25943 .32747 Metetra
.73 .681 .803 r
.25943 .32747 .26202 .33158 .26624 .32858 .26364 .32457 Metetra
.727 .685 .809 r
.26364 .32457 .26624 .32858 .27045 .32571 .26785 .32179 Metetra
.724 .688 .815 r
.26785 .32179 .27045 .32571 .27465 .32296 .27205 .3191 Metetra
.721 .691 .821 r
.27205 .3191 .27465 .32296 .27885 .32029 .27624 .31651 Metetra
.718 .694 .826 r
.27624 .31651 .27885 .32029 .28304 .31772 .28044 .31399 Metetra
.716 .697 .831 r
.28044 .31399 .28304 .31772 .28723 .31522 .28463 .31154 Metetra
.713 .699 .835 r
.28463 .31154 .28723 .31522 .29142 .31279 .28882 .30916 Metetra
.711 .701 .839 r
.28882 .30916 .29142 .31279 .29561 .31042 .29301 .30683 Metetra
.709 .703 .843 r
.29301 .30683 .29561 .31042 .2998 .30811 .2972 .30455 Metetra
.706 .704 .846 r
.2972 .30455 .2998 .30811 .30399 .30585 .30139 .30232 Metetra
.704 .706 .849 r
.30139 .30232 .30399 .30585 .30819 .30363 .30558 .30013 Metetra
.929 .721 .6 r
.30558 .30013 .30819 .30363 .31238 .30146 .31103 .27979 Metetra
.562 .378 .589 r
.31103 .27979 .31238 .30146 .31657 .29932 .31518 .27802 Metetra
.562 .379 .591 r
.31518 .27802 .31657 .29932 .32194 .27942 .31934 .27626 Metetra
.678 .722 .882 r
.31934 .27626 .32194 .27942 .32609 .27767 .3235 .27452 Metetra
.677 .722 .883 r
.3235 .27452 .32609 .27767 .33026 .27594 .32766 .27279 Metetra
.676 .723 .885 r
.32766 .27279 .33026 .27594 .33442 .27422 .33183 .27107 Metetra
.675 .723 .885 r
.33183 .27107 .33442 .27422 .33859 .27251 .33601 .26937 Metetra
.674 .723 .886 r
.33601 .26937 .33859 .27251 .34277 .27081 .34019 .26767 Metetra
.673 .723 .887 r
.34019 .26767 .34277 .27081 .34695 .26912 .34437 .26599 Metetra
.672 .724 .888 r
.34437 .26599 .34695 .26912 .35114 .26745 .34856 .26431 Metetra
.671 .724 .889 r
.34856 .26431 .35114 .26745 .35533 .26578 .35276 .26265 Metetra
.67 .724 .889 r
.35276 .26265 .35533 .26578 .35953 .26412 .35696 .26099 Metetra
.67 .724 .89 r
.35696 .26099 .35953 .26412 .36374 .26247 .36117 .25934 Metetra
.669 .724 .891 r
.36117 .25934 .36374 .26247 .36795 .26083 .36538 .2577 Metetra
.668 .724 .891 r
.36538 .2577 .36795 .26083 .37216 .2592 .3696 .25607 Metetra
.667 .724 .892 r
.3696 .25607 .37216 .2592 .37638 .25757 .37383 .25444 Metetra
.666 .724 .892 r
.37383 .25444 .37638 .25757 .38061 .25595 .37806 .25282 Metetra
.666 .724 .893 r
.37806 .25282 .38061 .25595 .38485 .25434 .3823 .2512 Metetra
.665 .724 .893 r
.3823 .2512 .38485 .25434 .38909 .25273 .38654 .2496 Metetra
.664 .724 .894 r
.38654 .2496 .38909 .25273 .39333 .25114 .39079 .24799 Metetra
.664 .724 .894 r
.39079 .24799 .39333 .25114 .39759 .24954 .39505 .2464 Metetra
.663 .724 .894 r
.39505 .2464 .39759 .24954 .40184 .24796 .39931 .24481 Metetra
.662 .723 .895 r
.39931 .24481 .40184 .24796 .40611 .24638 .40358 .24323 Metetra
.661 .723 .895 r
.40358 .24323 .40611 .24638 .41038 .24481 .40786 .24165 Metetra
.661 .723 .895 r
.40786 .24165 .41038 .24481 .41466 .24324 .41214 .24008 Metetra
.66 .723 .895 r
.41214 .24008 .41466 .24324 .41894 .24168 .41643 .23851 Metetra
.659 .722 .896 r
.41643 .23851 .41894 .24168 .42324 .24012 .42072 .23695 Metetra
.658 .722 .896 r
.42072 .23695 .42324 .24012 .42753 .23857 .42502 .2354 Metetra
.658 .722 .896 r
.42502 .2354 .42753 .23857 .43184 .23703 .42933 .23385 Metetra
.657 .721 .896 r
.42933 .23385 .43184 .23703 .43615 .2355 .43365 .2323 Metetra
.656 .721 .896 r
.43365 .2323 .43615 .2355 .44047 .23397 .43797 .23077 Metetra
.655 .721 .897 r
.43797 .23077 .44047 .23397 .44479 .23244 .4423 .22924 Metetra
.655 .72 .897 r
.4423 .22924 .44479 .23244 .44912 .23093 .44663 .22772 Metetra
.654 .72 .897 r
.44663 .22772 .44912 .23093 .45346 .22942 .45097 .2262 Metetra
.653 .719 .897 r
.45097 .2262 .45346 .22942 .45781 .22792 .45532 .22469 Metetra
.652 .718 .897 r
.45532 .22469 .45781 .22792 .46216 .22643 .45968 .22319 Metetra
.651 .718 .897 r
.45968 .22319 .46216 .22643 .46652 .22494 .46404 .22169 Metetra
.65 .717 .897 r
.46404 .22169 .46652 .22494 .47089 .22346 .46841 .22021 Metetra
.649 .716 .897 r
.46841 .22021 .47089 .22346 .47526 .222 .47279 .21873 Metetra
.648 .716 .897 r
.47279 .21873 .47526 .222 .47964 .22054 .47718 .21726 Metetra
.647 .715 .897 r
.47718 .21726 .47964 .22054 .48403 .21909 .48157 .2158 Metetra
.646 .714 .897 r
.48157 .2158 .48403 .21909 .48842 .21766 .48597 .21435 Metetra
.644 .713 .897 r
.48597 .21435 .48842 .21766 .49283 .21623 .49038 .21292 Metetra
.643 .712 .897 r
.49038 .21292 .49283 .21623 .49724 .21482 .49479 .21149 Metetra
.642 .71 .897 r
.49479 .21149 .49724 .21482 .50166 .21342 .49921 .21008 Metetra
.64 .709 .897 r
.49921 .21008 .50166 .21342 .50608 .21204 .50364 .20868 Metetra
.639 .708 .897 r
.50364 .20868 .50608 .21204 .51043 .22904 .50808 .20729 Metetra
.553 .372 .59 r
.50808 .20729 .51043 .22904 .5149 .22806 .51253 .20592 Metetra
.003 0 .472 r
.51253 .20592 .5149 .22806 .51937 .22712 .51693 .22338 Metetra
.596 .666 .888 r
.51693 .22338 .51937 .22712 .52386 .22622 .52142 .22245 Metetra
.591 .661 .887 r
.52142 .22245 .52386 .22622 .52835 .22537 .52592 .22155 Metetra
.587 .657 .886 r
.52592 .22155 .52835 .22537 .53286 .22457 .53043 .22071 Metetra
.582 .652 .884 r
.53043 .22071 .53286 .22457 .53737 .22383 .53494 .21991 Metetra
.576 .646 .883 r
.53494 .21991 .53737 .22383 .5419 .22315 .53947 .21918 Metetra
.57 .64 .881 r
.53947 .21918 .5419 .22315 .54643 .22254 .54401 .21851 Metetra
.563 .633 .879 r
.54401 .21851 .54643 .22254 .55098 .22201 .54856 .21791 Metetra
.556 .626 .877 r
.54856 .21791 .55098 .22201 .55554 .22157 .55312 .21739 Metetra
.547 .617 .874 r
.55312 .21739 .55554 .22157 .56011 .22123 .55769 .21697 Metetra
.538 .608 .871 r
.55769 .21697 .56011 .22123 .5647 .22101 .56228 .21665 Metetra
.527 .597 .867 r
.56228 .21665 .5647 .22101 .5693 .22092 .56688 .21644 Metetra
.515 .584 .862 r
.56688 .21644 .5693 .22092 .57391 .22098 .57149 .21638 Metetra
.502 .57 .857 r
.57149 .21638 .57391 .22098 .57854 .22122 .57612 .21647 Metetra
.486 .554 .851 r
.57612 .21647 .57854 .22122 .58318 .22167 .58076 .21674 Metetra
.468 .535 .843 r
.58076 .21674 .58318 .22167 .58785 .22237 .58542 .21724 Metetra
.447 .513 .833 r
.58542 .21724 .58785 .22237 .59254 .22337 .59011 .21799 Metetra
.422 .487 .822 r
.59011 .21799 .59254 .22337 .59725 .22474 .59481 .21906 Metetra
.393 .457 .807 r
.59481 .21906 .59725 .22474 .60199 .22658 .59954 .22052 Metetra
.358 .421 .789 r
.59954 .22052 .60199 .22658 .60677 .22901 .6043 .22247 Metetra
.317 .378 .767 r
.6043 .22247 .60677 .22901 .61158 .23221 .6091 .22505 Metetra
.269 .327 .738 r
.6091 .22505 .61158 .23221 .61646 .23646 .61394 .22844 Metetra
.211 .266 .702 r
.61394 .22844 .61646 .23646 .6214 .24217 .61884 .23296 Metetra
.143 .195 .657 r
.61884 .23296 .6214 .24217 .62645 .25006 .62382 .23907 Metetra
.065 .112 .601 r
.62382 .23907 .62645 .25006 .63166 .26142 .62892 .24758 Metetra
0 .019 .534 r
.62892 .24758 .63166 .26142 .63714 .27898 .63419 .26001 Metetra
0 0 .456 r
.63419 .26001 .63714 .27898 .64319 .30982 .63978 .27965 Metetra
0 0 .368 r
.63978 .27965 .64319 .30982 .65062 .37289 .64608 .3157 Metetra
0 0 .415 r
.64608 .3157 .65062 .37289 .65561 .37125 .65318 .36822 Metetra
.978 .684 .374 r
.65318 .36822 .65561 .37125 .65039 .1291 .64813 .12593 Metetra
.664 .741 .907 r
.64813 .12593 .65039 .1291 .65501 .12738 .65276 .12421 Metetra
.664 .741 .907 r
.65276 .12421 .65501 .12738 .65965 .12566 .6574 .12248 Metetra
.664 .741 .907 r
.6574 .12248 .65965 .12566 .66429 .12394 .66204 .12075 Metetra
.664 .741 .907 r
.66204 .12075 .66429 .12394 .66894 .12221 .6667 .11902 Metetra
.664 .741 .907 r
.6667 .11902 .66894 .12221 .6736 .12049 .67136 .11729 Metetra
.664 .741 .907 r
.67136 .11729 .6736 .12049 .67826 .11875 .67603 .11555 Metetra
.664 .741 .907 r
.67603 .11555 .67826 .11875 .68293 .11702 .68071 .11381 Metetra
.664 .741 .907 r
.68071 .11381 .68293 .11702 .68761 .11528 .68539 .11207 Metetra
.664 .741 .907 r
.68539 .11207 .68761 .11528 .6923 .11354 .69009 .11032 Metetra
.664 .741 .907 r
.69009 .11032 .6923 .11354 .69699 .1118 .69479 .10857 Metetra
.664 .741 .907 r
.69479 .10857 .69699 .1118 .7017 .11005 .69949 .10682 Metetra
.664 .741 .907 r
.69949 .10682 .7017 .11005 .70641 .1083 .70421 .10507 Metetra
.664 .741 .907 r
.70421 .10507 .70641 .1083 .71113 .10655 .70894 .10331 Metetra
.664 .741 .907 r
.70894 .10331 .71113 .10655 .71585 .1048 .71367 .10155 Metetra
.664 .741 .907 r
.71367 .10155 .71585 .1048 .72059 .10304 .71841 .09979 Metetra
.664 .741 .907 r
.71841 .09979 .72059 .10304 .72533 .10128 .72316 .09802 Metetra
.664 .741 .907 r
.72316 .09802 .72533 .10128 .73008 .09951 .72791 .09625 Metetra
.664 .741 .907 r
.72791 .09625 .73008 .09951 .73484 .09775 .73267 .09448 Metetra
.664 .741 .907 r
.73267 .09448 .73484 .09775 .73961 .09598 .73745 .0927 Metetra
.664 .741 .907 r
.73745 .0927 .73961 .09598 .74438 .0942 .74223 .09092 Metetra
.664 .741 .907 r
.74223 .09092 .74438 .0942 .74916 .09243 .74701 .08914 Metetra
.664 .741 .907 r
.10947 .32267 .11226 .32527 .11605 .32386 .11326 .32126 Metetra
.664 .741 .907 r
.11326 .32126 .11605 .32386 .11984 .32245 .11706 .31984 Metetra
.664 .741 .907 r
.11706 .31984 .11984 .32245 .12365 .32104 .12087 .31842 Metetra
.664 .741 .907 r
.12087 .31842 .12365 .32104 .12745 .31962 .12468 .317 Metetra
.664 .741 .907 r
.12468 .317 .12745 .31962 .13127 .3182 .12849 .31558 Metetra
.664 .741 .907 r
.12849 .31558 .13127 .3182 .13508 .31678 .13231 .31415 Metetra
.664 .741 .907 r
.13231 .31415 .13508 .31678 .13891 .31536 .13614 .31273 Metetra
.664 .741 .907 r
.13614 .31273 .13891 .31536 .14274 .31393 .13998 .3113 Metetra
.664 .741 .907 r
.13998 .3113 .14274 .31393 .14658 .31251 .14381 .30987 Metetra
.664 .741 .907 r
.14381 .30987 .14658 .31251 .15042 .31108 .14766 .30843 Metetra
.664 .741 .907 r
.14766 .30843 .15042 .31108 .15426 .30965 .15151 .307 Metetra
.664 .741 .907 r
.15151 .307 .15426 .30965 .15812 .30821 .15537 .30556 Metetra
.664 .741 .907 r
.15537 .30556 .15812 .30821 .16198 .30678 .15923 .30412 Metetra
.664 .741 .907 r
.15923 .30412 .16198 .30678 .16584 .30534 .1631 .30268 Metetra
.664 .741 .907 r
.1631 .30268 .16584 .30534 .16971 .3039 .16697 .30124 Metetra
.664 .741 .907 r
.16697 .30124 .16971 .3039 .17359 .30246 .17085 .29979 Metetra
.664 .741 .907 r
.17085 .29979 .17359 .30246 .17747 .30101 .17474 .29834 Metetra
.664 .741 .907 r
.17474 .29834 .17747 .30101 .18136 .29957 .17863 .29689 Metetra
.664 .741 .907 r
.17863 .29689 .18136 .29957 .18525 .29812 .18253 .29544 Metetra
.664 .741 .907 r
.18253 .29544 .18525 .29812 .18915 .29667 .18643 .29398 Metetra
.946 .682 .503 r
.18643 .29398 .18915 .29667 .19306 .29522 .16537 .52501 Metetra
.42 .198 .468 r
.16537 .52501 .19306 .29522 .17251 .52617 .17379 .48375 Metetra
.774 .529 .565 r
.17379 .48375 .17251 .52617 .18212 .4727 .18243 .43956 Metetra
.733 .499 .573 r
.18243 .43956 .18212 .4727 .19 .43491 .18892 .41518 Metetra
.749 .528 .596 r
.18892 .41518 .19 .43491 .19619 .41288 .19452 .39894 Metetra
.757 .551 .618 r
.19452 .39894 .19619 .41288 .20165 .3978 .19966 .38697 Metetra
.76 .57 .639 r
.19966 .38697 .20165 .3978 .2067 .38649 .20453 .37755 Metetra
.761 .586 .66 r
.20453 .37755 .2067 .38649 .21151 .37749 .20921 .3698 Metetra
.761 .601 .679 r
.20921 .3698 .21151 .37749 .21615 .37003 .21378 .36322 Metetra
.759 .613 .697 r
.21378 .36322 .21615 .37003 .22069 .36365 .21825 .35748 Metetra
.757 .625 .713 r
.21825 .35748 .22069 .36365 .22514 .35807 .22266 .35238 Metetra
.754 .635 .728 r
.22266 .35238 .22514 .35807 .22953 .35309 .22702 .34778 Metetra
.751 .644 .742 r
.22702 .34778 .22953 .35309 .23388 .34858 .23135 .34357 Metetra
.748 .652 .754 r
.23135 .34357 .23388 .34858 .23819 .34445 .23564 .33968 Metetra
.744 .659 .766 r
.23564 .33968 .23819 .34445 .24248 .34062 .23991 .33605 Metetra
.741 .665 .776 r
.23991 .33605 .24248 .34062 .24674 .33705 .24416 .33265 Metetra
.738 .671 .785 r
.24416 .33265 .24674 .33705 .25098 .33369 .24839 .32942 Metetra
.734 .676 .793 r
.24839 .32942 .25098 .33369 .25521 .3305 .25262 .32636 Metetra
.731 .68 .801 r
.25262 .32636 .25521 .3305 .25943 .32747 .25683 .32343 Metetra
.728 .684 .808 r
.25683 .32343 .25943 .32747 .26364 .32457 .26104 .32062 Metetra
.725 .688 .814 r
.26104 .32062 .26364 .32457 .26785 .32179 .26524 .31791 Metetra
.722 .691 .82 r
.26524 .31791 .26785 .32179 .27205 .3191 .26944 .31529 Metetra
.719 .694 .825 r
.26944 .31529 .27205 .3191 .27624 .31651 .27363 .31276 Metetra
.716 .696 .83 r
.27363 .31276 .27624 .31651 .28044 .31399 .27782 .31029 Metetra
.714 .698 .834 r
.27782 .31029 .28044 .31399 .28463 .31154 .28201 .30789 Metetra
.711 .701 .838 r
.28201 .30789 .28463 .31154 .28882 .30916 .2862 .30555 Metetra
.709 .702 .842 r
.2862 .30555 .28882 .30916 .29301 .30683 .29039 .30326 Metetra
.707 .704 .845 r
.29039 .30326 .29301 .30683 .2972 .30455 .29458 .30101 Metetra
.705 .706 .848 r
.29458 .30101 .2972 .30455 .30139 .30232 .29878 .29881 Metetra
.929 .721 .6 r
.29878 .29881 .30139 .30232 .30558 .30013 .30427 .27841 Metetra
.561 .377 .589 r
.30427 .27841 .30558 .30013 .31103 .27979 .30842 .27663 Metetra
.68 .722 .881 r
.30842 .27663 .31103 .27979 .31518 .27802 .31257 .27486 Metetra
.679 .722 .882 r
.31257 .27486 .31518 .27802 .31934 .27626 .31673 .27311 Metetra
.678 .722 .883 r
.31673 .27311 .31934 .27626 .3235 .27452 .32089 .27137 Metetra
.677 .723 .884 r
.32089 .27137 .3235 .27452 .32766 .27279 .32506 .26965 Metetra
.676 .723 .885 r
.32506 .26965 .32766 .27279 .33183 .27107 .32923 .26793 Metetra
.675 .723 .886 r
.32923 .26793 .33183 .27107 .33601 .26937 .33341 .26623 Metetra
.674 .724 .887 r
.33341 .26623 .33601 .26937 .34019 .26767 .33759 .26454 Metetra
.673 .724 .888 r
.33759 .26454 .34019 .26767 .34437 .26599 .34178 .26286 Metetra
.672 .724 .889 r
.34178 .26286 .34437 .26599 .34856 .26431 .34598 .26118 Metetra
.671 .724 .889 r
.34598 .26118 .34856 .26431 .35276 .26265 .35018 .25952 Metetra
.67 .724 .89 r
.35018 .25952 .35276 .26265 .35696 .26099 .35438 .25786 Metetra
.669 .724 .891 r
.35438 .25786 .35696 .26099 .36117 .25934 .35859 .25621 Metetra
.669 .724 .891 r
.35859 .25621 .36117 .25934 .36538 .2577 .36281 .25457 Metetra
.668 .724 .892 r
.36281 .25457 .36538 .2577 .3696 .25607 .36704 .25293 Metetra
.667 .724 .892 r
.36704 .25293 .3696 .25607 .37383 .25444 .37126 .2513 Metetra
.666 .724 .893 r
.37126 .2513 .37383 .25444 .37806 .25282 .3755 .24968 Metetra
.666 .724 .893 r
.3755 .24968 .37806 .25282 .3823 .2512 .37974 .24806 Metetra
.665 .724 .893 r
.37974 .24806 .3823 .2512 .38654 .2496 .38399 .24645 Metetra
.664 .724 .894 r
.38399 .24645 .38654 .2496 .39079 .24799 .38824 .24485 Metetra
.663 .724 .894 r
.38824 .24485 .39079 .24799 .39505 .2464 .3925 .24325 Metetra
.663 .724 .895 r
.3925 .24325 .39505 .2464 .39931 .24481 .39677 .24166 Metetra
.662 .724 .895 r
.39677 .24166 .39931 .24481 .40358 .24323 .40104 .24007 Metetra
.661 .724 .895 r
.40104 .24007 .40358 .24323 .40786 .24165 .40532 .23849 Metetra
.661 .723 .895 r
.40532 .23849 .40786 .24165 .41214 .24008 .40961 .23691 Metetra
.66 .723 .896 r
.40961 .23691 .41214 .24008 .41643 .23851 .4139 .23534 Metetra
.659 .723 .896 r
.4139 .23534 .41643 .23851 .42072 .23695 .4182 .23377 Metetra
.659 .723 .896 r
.4182 .23377 .42072 .23695 .42502 .2354 .42251 .23221 Metetra
.658 .722 .896 r
.42251 .23221 .42502 .2354 .42933 .23385 .42682 .23066 Metetra
.657 .722 .897 r
.42682 .23066 .42933 .23385 .43365 .2323 .43114 .22911 Metetra
.656 .721 .897 r
.43114 .22911 .43365 .2323 .43797 .23077 .43546 .22757 Metetra
.656 .721 .897 r
.43546 .22757 .43797 .23077 .4423 .22924 .4398 .22603 Metetra
.655 .721 .897 r
.4398 .22603 .4423 .22924 .44663 .22772 .44413 .2245 Metetra
.654 .72 .897 r
.44413 .2245 .44663 .22772 .45097 .2262 .44848 .22298 Metetra
.653 .72 .897 r
.44848 .22298 .45097 .2262 .45532 .22469 .45283 .22146 Metetra
.652 .719 .897 r
.45283 .22146 .45532 .22469 .45968 .22319 .4572 .21995 Metetra
.651 .718 .897 r
.4572 .21995 .45968 .22319 .46404 .22169 .46156 .21844 Metetra
.65 .718 .897 r
.46156 .21844 .46404 .22169 .46841 .22021 .46594 .21695 Metetra
.649 .717 .897 r
.46594 .21695 .46841 .22021 .47279 .21873 .47032 .21546 Metetra
.648 .716 .898 r
.47032 .21546 .47279 .21873 .47718 .21726 .47471 .21398 Metetra
.647 .715 .898 r
.47471 .21398 .47718 .21726 .48157 .2158 .47911 .21251 Metetra
.646 .715 .897 r
.47911 .21251 .48157 .2158 .48597 .21435 .48351 .21105 Metetra
.645 .714 .897 r
.48351 .21105 .48597 .21435 .49038 .21292 .48792 .2096 Metetra
.644 .712 .897 r
.48792 .2096 .49038 .21292 .49479 .21149 .49234 .20816 Metetra
.643 .711 .897 r
.49234 .20816 .49479 .21149 .49921 .21008 .49677 .20673 Metetra
.641 .71 .897 r
.49677 .20673 .49921 .21008 .50364 .20868 .5012 .20532 Metetra
.64 .709 .897 r
.5012 .20532 .50364 .20868 .50808 .20729 .50564 .20392 Metetra
.638 .707 .897 r
.50564 .20392 .50808 .20729 .51253 .20592 .51009 .20253 Metetra
.636 .706 .897 r
.51009 .20253 .51253 .20592 .51693 .22338 .51455 .20116 Metetra
.003 0 .472 r
.51455 .20116 .51693 .22338 .52142 .22245 .51898 .21869 Metetra
.595 .665 .888 r
.51898 .21869 .52142 .22245 .52592 .22155 .52348 .21775 Metetra
.59 .661 .887 r
.52348 .21775 .52592 .22155 .53043 .22071 .52799 .21687 Metetra
.586 .656 .885 r
.52799 .21687 .53043 .22071 .53494 .21991 .53251 .21603 Metetra
.58 .651 .884 r
.53251 .21603 .53494 .21991 .53947 .21918 .53704 .21524 Metetra
.575 .645 .882 r
.53704 .21524 .53947 .21918 .54401 .21851 .54158 .21451 Metetra
.569 .639 .881 r
.54158 .21451 .54401 .21851 .54856 .21791 .54613 .21385 Metetra
.562 .632 .878 r
.54613 .21385 .54856 .21791 .55312 .21739 .5507 .21326 Metetra
.554 .624 .876 r
.5507 .21326 .55312 .21739 .55769 .21697 .55527 .21276 Metetra
.546 .615 .873 r
.55527 .21276 .55769 .21697 .56228 .21665 .55986 .21235 Metetra
.536 .605 .87 r
.55986 .21235 .56228 .21665 .56688 .21644 .56446 .21205 Metetra
.525 .594 .866 r
.56446 .21205 .56688 .21644 .57149 .21638 .56907 .21186 Metetra
.513 .581 .861 r
.56907 .21186 .57149 .21638 .57612 .21647 .5737 .21182 Metetra
.499 .567 .856 r
.5737 .21182 .57612 .21647 .58076 .21674 .57834 .21194 Metetra
.482 .55 .849 r
.57834 .21194 .58076 .21674 .58542 .21724 .583 .21225 Metetra
.464 .53 .841 r
.583 .21225 .58542 .21724 .59011 .21799 .58768 .21279 Metetra
.442 .508 .831 r
.58768 .21279 .59011 .21799 .59481 .21906 .59238 .2136 Metetra
.416 .481 .819 r
.59238 .2136 .59481 .21906 .59954 .22052 .5971 .21475 Metetra
.386 .449 .804 r
.5971 .21475 .59954 .22052 .6043 .22247 .60185 .21629 Metetra
.351 .412 .785 r
.60185 .21629 .6043 .22247 .6091 .22505 .60663 .21836 Metetra
.308 .368 .761 r
.60663 .21836 .6091 .22505 .61394 .22844 .61145 .22108 Metetra
.258 .315 .731 r
.61145 .22108 .61394 .22844 .61884 .23296 .61632 .22469 Metetra
.199 .252 .693 r
.61632 .22469 .61884 .23296 .62382 .23907 .62125 .2295 Metetra
.129 .178 .646 r
.62125 .2295 .62382 .23907 .62892 .24758 .62626 .23604 Metetra
.048 .094 .588 r
.62626 .23604 .62892 .24758 .63419 .26001 .6314 .24523 Metetra
0 0 .518 r
.6314 .24523 .63419 .26001 .63978 .27965 .63675 .25885 Metetra
0 0 .438 r
.63675 .25885 .63978 .27965 .64608 .3157 .64247 .28094 Metetra
0 0 .348 r
.64247 .28094 .64608 .3157 .65318 .36822 .6491 .32367 Metetra
0 0 .433 r
.6491 .32367 .65318 .36822 .64813 .12593 .65575 .36353 Metetra
0 0 .339 r
.65575 .36353 .64813 .12593 .65276 .12421 .6505 .12102 Metetra
.664 .741 .907 r
.6505 .12102 .65276 .12421 .6574 .12248 .65514 .11929 Metetra
.664 .741 .907 r
.65514 .11929 .6574 .12248 .66204 .12075 .65979 .11755 Metetra
.664 .741 .907 r
.65979 .11755 .66204 .12075 .6667 .11902 .66445 .11582 Metetra
.664 .741 .907 r
.66445 .11582 .6667 .11902 .67136 .11729 .66912 .11408 Metetra
.664 .741 .907 r
.66912 .11408 .67136 .11729 .67603 .11555 .67379 .11233 Metetra
.664 .741 .907 r
.67379 .11233 .67603 .11555 .68071 .11381 .67848 .11059 Metetra
.664 .741 .907 r
.67848 .11059 .68071 .11381 .68539 .11207 .68317 .10884 Metetra
.664 .741 .907 r
.68317 .10884 .68539 .11207 .69009 .11032 .68787 .10709 Metetra
.664 .741 .907 r
.68787 .10709 .69009 .11032 .69479 .10857 .69257 .10534 Metetra
.664 .741 .907 r
.69257 .10534 .69479 .10857 .69949 .10682 .69729 .10358 Metetra
.664 .741 .907 r
.69729 .10358 .69949 .10682 .70421 .10507 .70201 .10182 Metetra
.664 .741 .907 r
.70201 .10182 .70421 .10507 .70894 .10331 .70674 .10006 Metetra
.664 .741 .907 r
.70674 .10006 .70894 .10331 .71367 .10155 .71147 .09829 Metetra
.664 .741 .907 r
.71147 .09829 .71367 .10155 .71841 .09979 .71622 .09652 Metetra
.664 .741 .907 r
.71622 .09652 .71841 .09979 .72316 .09802 .72097 .09475 Metetra
.664 .741 .907 r
.72097 .09475 .72316 .09802 .72791 .09625 .72573 .09298 Metetra
.664 .741 .907 r
.72573 .09298 .72791 .09625 .73267 .09448 .7305 .0912 Metetra
.664 .741 .907 r
.7305 .0912 .73267 .09448 .73745 .0927 .73528 .08942 Metetra
.664 .741 .907 r
.73528 .08942 .73745 .0927 .74223 .09092 .74007 .08763 Metetra
.664 .741 .907 r
.74007 .08763 .74223 .09092 .74701 .08914 .74486 .08585 Metetra
.664 .741 .907 r
.10667 .32006 .10947 .32267 .11326 .32126 .11047 .31864 Metetra
.664 .741 .907 r
.11047 .31864 .11326 .32126 .11706 .31984 .11427 .31722 Metetra
.664 .741 .907 r
.11427 .31722 .11706 .31984 .12087 .31842 .11808 .3158 Metetra
.664 .741 .907 r
.11808 .3158 .12087 .31842 .12468 .317 .12189 .31437 Metetra
.664 .741 .907 r
.12189 .31437 .12468 .317 .12849 .31558 .12571 .31295 Metetra
.664 .741 .907 r
.12571 .31295 .12849 .31558 .13231 .31415 .12954 .31152 Metetra
.664 .741 .907 r
.12954 .31152 .13231 .31415 .13614 .31273 .13337 .31009 Metetra
.664 .741 .907 r
.13337 .31009 .13614 .31273 .13998 .3113 .1372 .30866 Metetra
.664 .741 .907 r
.1372 .30866 .13998 .3113 .14381 .30987 .14105 .30722 Metetra
.664 .741 .907 r
.14105 .30722 .14381 .30987 .14766 .30843 .1449 .30578 Metetra
.664 .741 .907 r
.1449 .30578 .14766 .30843 .15151 .307 .14875 .30434 Metetra
.664 .741 .907 r
.14875 .30434 .15151 .307 .15537 .30556 .15261 .3029 Metetra
.664 .741 .907 r
.15261 .3029 .15537 .30556 .15923 .30412 .15647 .30146 Metetra
.664 .741 .907 r
.15647 .30146 .15923 .30412 .1631 .30268 .16035 .30001 Metetra
.664 .741 .907 r
.16035 .30001 .1631 .30268 .16697 .30124 .16422 .29857 Metetra
.664 .741 .907 r
.16422 .29857 .16697 .30124 .17085 .29979 .16811 .29712 Metetra
.664 .741 .907 r
.16811 .29712 .17085 .29979 .17474 .29834 .172 .29566 Metetra
.664 .741 .907 r
.172 .29566 .17474 .29834 .17863 .29689 .17589 .29421 Metetra
.664 .741 .907 r
.17589 .29421 .17863 .29689 .18253 .29544 .17979 .29275 Metetra
.946 .682 .504 r
.17979 .29275 .18253 .29544 .18643 .29398 .15822 .52384 Metetra
.457 .228 .478 r
.15822 .52384 .18643 .29398 .16537 .52501 .1651 .49755 Metetra
.839 .592 .566 r
.1651 .49755 .16537 .52501 .17379 .48375 .17475 .44494 Metetra
.727 .49 .568 r
.17475 .44494 .17379 .48375 .18243 .43956 .18159 .41777 Metetra
.746 .522 .591 r
.18159 .41777 .18243 .43956 .18892 .41518 .18736 .40023 Metetra
.755 .546 .613 r
.18736 .40023 .18892 .41518 .19452 .39894 .1926 .38753 Metetra
.759 .565 .634 r
.1926 .38753 .19452 .39894 .19966 .38697 .19753 .37766 Metetra
.761 .582 .655 r
.19753 .37766 .19966 .38697 .20453 .37755 .20226 .3696 Metetra
.761 .597 .675 r
.20226 .3696 .20453 .37755 .20921 .3698 .20685 .3628 Metetra
.76 .61 .693 r
.20685 .3628 .20921 .3698 .21378 .36322 .21135 .3569 Metetra
.757 .622 .71 r
.21135 .3569 .21378 .36322 .21825 .35748 .21578 .35168 Metetra
.755 .633 .725 r
.21578 .35168 .21825 .35748 .22266 .35238 .22015 .34698 Metetra
.752 .642 .739 r
.22015 .34698 .22266 .35238 .22702 .34778 .22449 .34269 Metetra
.748 .65 .752 r
.22449 .34269 .22702 .34778 .23135 .34357 .22879 .33874 Metetra
.745 .657 .763 r
.22879 .33874 .23135 .34357 .23564 .33968 .23307 .33506 Metetra
.742 .664 .774 r
.23307 .33506 .23564 .33968 .23991 .33605 .23732 .33161 Metetra
.738 .669 .783 r
.23732 .33161 .23991 .33605 .24416 .33265 .24156 .32835 Metetra
.735 .675 .792 r
.24156 .32835 .24416 .33265 .24839 .32942 .24579 .32525 Metetra
.732 .679 .799 r
.24579 .32525 .24839 .32942 .25262 .32636 .25001 .32229 Metetra
.728 .683 .806 r
.25001 .32229 .25262 .32636 .25683 .32343 .25422 .31945 Metetra
.725 .687 .813 r
.25422 .31945 .25683 .32343 .26104 .32062 .25842 .31672 Metetra
.722 .69 .819 r
.25842 .31672 .26104 .32062 .26524 .31791 .26262 .31408 Metetra
.72 .693 .824 r
.26262 .31408 .26524 .31791 .26944 .31529 .26681 .31153 Metetra
.717 .696 .829 r
.26681 .31153 .26944 .31529 .27363 .31276 .27101 .30905 Metetra
.714 .698 .833 r
.27101 .30905 .27363 .31276 .27782 .31029 .2752 .30663 Metetra
.712 .7 .837 r
.2752 .30663 .27782 .31029 .28201 .30789 .27939 .30427 Metetra
.71 .702 .841 r
.27939 .30427 .28201 .30789 .2862 .30555 .28358 .30196 Metetra
.707 .704 .844 r
.28358 .30196 .2862 .30555 .29039 .30326 .28777 .29971 Metetra
.705 .705 .848 r
.28777 .29971 .29039 .30326 .29458 .30101 .29196 .29749 Metetra
.929 .72 .6 r
.29196 .29749 .29458 .30101 .29878 .29881 .2975 .27702 Metetra
.561 .376 .588 r
.2975 .27702 .29878 .29881 .30427 .27841 .30164 .27523 Metetra
.681 .722 .881 r
.30164 .27523 .30427 .27841 .30842 .27663 .3058 .27346 Metetra
.679 .722 .882 r
.3058 .27346 .30842 .27663 .31257 .27486 .30995 .2717 Metetra
.678 .723 .883 r
.30995 .2717 .31257 .27486 .31673 .27311 .31411 .26996 Metetra
.677 .723 .884 r
.31411 .26996 .31673 .27311 .32089 .27137 .31828 .26822 Metetra
.676 .723 .885 r
.31828 .26822 .32089 .27137 .32506 .26965 .32245 .2665 Metetra
.675 .724 .886 r
.32245 .2665 .32506 .26965 .32923 .26793 .32663 .26479 Metetra
.674 .724 .887 r
.32663 .26479 .32923 .26793 .33341 .26623 .33081 .26309 Metetra
.673 .724 .888 r
.33081 .26309 .33341 .26623 .33759 .26454 .33499 .2614 Metetra
.672 .724 .888 r
.33499 .2614 .33759 .26454 .34178 .26286 .33919 .25972 Metetra
.671 .724 .889 r
.33919 .25972 .34178 .26286 .34598 .26118 .34338 .25805 Metetra
.671 .725 .89 r
.34338 .25805 .34598 .26118 .35018 .25952 .34759 .25638 Metetra
.67 .725 .89 r
.34759 .25638 .35018 .25952 .35438 .25786 .3518 .25473 Metetra
.669 .725 .891 r
.3518 .25473 .35438 .25786 .35859 .25621 .35601 .25308 Metetra
.668 .725 .892 r
.35601 .25308 .35859 .25621 .36281 .25457 .36023 .25143 Metetra
.668 .725 .892 r
.36023 .25143 .36281 .25457 .36704 .25293 .36446 .24979 Metetra
.667 .725 .893 r
.36446 .24979 .36704 .25293 .37126 .2513 .36869 .24816 Metetra
.666 .725 .893 r
.36869 .24816 .37126 .2513 .3755 .24968 .37293 .24654 Metetra
.665 .725 .893 r
.37293 .24654 .3755 .24968 .37974 .24806 .37718 .24492 Metetra
.665 .725 .894 r
.37718 .24492 .37974 .24806 .38399 .24645 .38143 .24331 Metetra
.664 .725 .894 r
.38143 .24331 .38399 .24645 .38824 .24485 .38569 .2417 Metetra
.663 .724 .895 r
.38569 .2417 .38824 .24485 .3925 .24325 .38995 .2401 Metetra
.663 .724 .895 r
.38995 .2401 .3925 .24325 .39677 .24166 .39422 .2385 Metetra
.662 .724 .895 r
.39422 .2385 .39677 .24166 .40104 .24007 .3985 .23691 Metetra
.661 .724 .895 r
.3985 .23691 .40104 .24007 .40532 .23849 .40278 .23532 Metetra
.661 .724 .896 r
.40278 .23532 .40532 .23849 .40961 .23691 .40707 .23374 Metetra
.66 .723 .896 r
.40707 .23374 .40961 .23691 .4139 .23534 .41137 .23216 Metetra
.659 .723 .896 r
.41137 .23216 .4139 .23534 .4182 .23377 .41567 .23059 Metetra
.659 .723 .896 r
.41567 .23059 .4182 .23377 .42251 .23221 .41998 .22903 Metetra
.658 .723 .897 r
.41998 .22903 .42251 .23221 .42682 .23066 .4243 .22747 Metetra
.657 .722 .897 r
.4243 .22747 .42682 .23066 .43114 .22911 .42862 .22591 Metetra
.657 .722 .897 r
.42862 .22591 .43114 .22911 .43546 .22757 .43295 .22436 Metetra
.656 .721 .897 r
.43295 .22436 .43546 .22757 .4398 .22603 .43729 .22282 Metetra
.655 .721 .897 r
.43729 .22282 .4398 .22603 .44413 .2245 .44163 .22128 Metetra
.654 .721 .897 r
.44163 .22128 .44413 .2245 .44848 .22298 .44598 .21975 Metetra
.653 .72 .897 r
.44598 .21975 .44848 .22298 .45283 .22146 .45034 .21822 Metetra
.653 .72 .898 r
.45034 .21822 .45283 .22146 .4572 .21995 .4547 .2167 Metetra
.652 .719 .898 r
.4547 .2167 .4572 .21995 .46156 .21844 .45907 .21519 Metetra
.651 .718 .898 r
.45907 .21519 .46156 .21844 .46594 .21695 .46345 .21369 Metetra
.65 .718 .898 r
.46345 .21369 .46594 .21695 .47032 .21546 .46784 .21219 Metetra
.649 .717 .898 r
.46784 .21219 .47032 .21546 .47471 .21398 .47223 .2107 Metetra
.648 .716 .898 r
.47223 .2107 .47471 .21398 .47911 .21251 .47663 .20922 Metetra
.647 .715 .898 r
.47663 .20922 .47911 .21251 .48351 .21105 .48104 .20775 Metetra
.646 .714 .898 r
.48104 .20775 .48351 .21105 .48792 .2096 .48546 .20628 Metetra
.645 .713 .898 r
.48546 .20628 .48792 .2096 .49234 .20816 .48988 .20483 Metetra
.643 .712 .898 r
.48988 .20483 .49234 .20816 .49677 .20673 .49431 .20339 Metetra
.642 .711 .897 r
.49431 .20339 .49677 .20673 .5012 .20532 .49875 .20196 Metetra
.641 .71 .897 r
.49875 .20196 .5012 .20532 .50564 .20392 .50319 .20055 Metetra
.639 .709 .897 r
.50319 .20055 .50564 .20392 .51009 .20253 .50765 .19914 Metetra
.638 .707 .897 r
.50765 .19914 .51009 .20253 .51455 .20116 .51211 .19775 Metetra
.636 .705 .897 r
.51211 .19775 .51455 .20116 .51898 .21869 .51658 .19638 Metetra
.002 0 .471 r
.51658 .19638 .51898 .21869 .52348 .21775 .52103 .21398 Metetra
.594 .664 .888 r
.52103 .21398 .52348 .21775 .52799 .21687 .52555 .21305 Metetra
.589 .66 .886 r
.52555 .21305 .52799 .21687 .53251 .21603 .53007 .21216 Metetra
.584 .655 .885 r
.53007 .21216 .53251 .21603 .53704 .21524 .5346 .21133 Metetra
.579 .65 .884 r
.5346 .21133 .53704 .21524 .54158 .21451 .53915 .21055 Metetra
.574 .644 .882 r
.53915 .21055 .54158 .21451 .54613 .21385 .5437 .20983 Metetra
.567 .637 .88 r
.5437 .20983 .54613 .21385 .5507 .21326 .54827 .20917 Metetra
.56 .63 .878 r
.54827 .20917 .5507 .21326 .55527 .21276 .55284 .2086 Metetra
.552 .622 .875 r
.55284 .2086 .55527 .21276 .55986 .21235 .55743 .20811 Metetra
.544 .613 .872 r
.55743 .20811 .55986 .21235 .56446 .21205 .56203 .20771 Metetra
.534 .603 .869 r
.56203 .20771 .56446 .21205 .56907 .21186 .56664 .20742 Metetra
.523 .591 .865 r
.56664 .20742 .56907 .21186 .5737 .21182 .57127 .20726 Metetra
.51 .578 .86 r
.57127 .20726 .5737 .21182 .57834 .21194 .57591 .20725 Metetra
.496 .563 .854 r
.57591 .20725 .57834 .21194 .583 .21225 .58057 .2074 Metetra
.479 .546 .847 r
.58057 .2074 .583 .21225 .58768 .21279 .58525 .20775 Metetra
.46 .526 .839 r
.58525 .20775 .58768 .21279 .59238 .2136 .58994 .20833 Metetra
.437 .502 .828 r
.58994 .20833 .59238 .2136 .5971 .21475 .59466 .2092 Metetra
.411 .475 .815 r
.59466 .2092 .5971 .21475 .60185 .21629 .5994 .21042 Metetra
.38 .442 .8 r
.5994 .21042 .60185 .21629 .60663 .21836 .60416 .21206 Metetra
.343 .403 .78 r
.60416 .21206 .60663 .21836 .61145 .22108 .60897 .21424 Metetra
.299 .357 .755 r
.60897 .21424 .61145 .22108 .61632 .22469 .61381 .21712 Metetra
.247 .302 .723 r
.61381 .21712 .61632 .22469 .62125 .2295 .6187 .22094 Metetra
.186 .238 .684 r
.6187 .22094 .62125 .2295 .62626 .23604 .62366 .22606 Metetra
.114 .162 .634 r
.62366 .22606 .62626 .23604 .6314 .24523 .62872 .23307 Metetra
.032 .075 .574 r
.62872 .23307 .6314 .24523 .63675 .25885 .63391 .24301 Metetra
0 0 .503 r
.63391 .24301 .63675 .25885 .64247 .28094 .63934 .25799 Metetra
0 0 .421 r
.63934 .25799 .64247 .28094 .6491 .32367 .64522 .28298 Metetra
0 0 .329 r
.64522 .28298 .6491 .32367 .65575 .36353 .65226 .33451 Metetra
.026 0 .475 r
.65226 .33451 .65575 .36353 .6505 .12102 .65834 .35881 Metetra
0 0 .339 r
.65834 .35881 .6505 .12102 .65514 .11929 .65288 .11608 Metetra
.664 .741 .907 r
.65288 .11608 .65514 .11929 .65979 .11755 .65753 .11435 Metetra
.664 .741 .907 r
.65753 .11435 .65979 .11755 .66445 .11582 .6622 .1126 Metetra
.664 .741 .907 r
.6622 .1126 .66445 .11582 .66912 .11408 .66687 .11086 Metetra
.664 .741 .907 r
.66687 .11086 .66912 .11408 .67379 .11233 .67155 .10911 Metetra
.664 .741 .907 r
.67155 .10911 .67379 .11233 .67848 .11059 .67624 .10736 Metetra
.664 .741 .907 r
.67624 .10736 .67848 .11059 .68317 .10884 .68093 .10561 Metetra
.664 .741 .907 r
.68093 .10561 .68317 .10884 .68787 .10709 .68564 .10385 Metetra
.664 .741 .907 r
.68564 .10385 .68787 .10709 .69257 .10534 .69035 .10209 Metetra
.664 .741 .907 r
.69035 .10209 .69257 .10534 .69729 .10358 .69507 .10033 Metetra
.664 .741 .907 r
.69507 .10033 .69729 .10358 .70201 .10182 .6998 .09856 Metetra
.664 .741 .907 r
.6998 .09856 .70201 .10182 .70674 .10006 .70453 .09679 Metetra
.664 .741 .907 r
.70453 .09679 .70674 .10006 .71147 .09829 .70927 .09502 Metetra
.664 .741 .907 r
.70927 .09502 .71147 .09829 .71622 .09652 .71402 .09325 Metetra
.664 .741 .907 r
.71402 .09325 .71622 .09652 .72097 .09475 .71878 .09147 Metetra
.664 .741 .907 r
.71878 .09147 .72097 .09475 .72573 .09298 .72355 .08969 Metetra
.664 .741 .907 r
.72355 .08969 .72573 .09298 .7305 .0912 .72833 .08791 Metetra
.664 .741 .907 r
.72833 .08791 .7305 .0912 .73528 .08942 .73311 .08612 Metetra
.664 .741 .907 r
.73311 .08612 .73528 .08942 .74007 .08763 .7379 .08433 Metetra
.664 .741 .907 r
.7379 .08433 .74007 .08763 .74486 .08585 .7427 .08254 Metetra
.664 .741 .907 r
.10387 .31744 .10667 .32006 .11047 .31864 .10767 .31602 Metetra
.664 .741 .907 r
.10767 .31602 .11047 .31864 .11427 .31722 .11147 .31459 Metetra
.664 .741 .907 r
.11147 .31459 .11427 .31722 .11808 .3158 .11528 .31317 Metetra
.664 .741 .907 r
.11528 .31317 .11808 .3158 .12189 .31437 .1191 .31174 Metetra
.664 .741 .907 r
.1191 .31174 .12189 .31437 .12571 .31295 .12292 .31031 Metetra
.664 .741 .907 r
.12292 .31031 .12571 .31295 .12954 .31152 .12675 .30888 Metetra
.664 .741 .907 r
.12675 .30888 .12954 .31152 .13337 .31009 .13059 .30744 Metetra
.664 .741 .907 r
.13059 .30744 .13337 .31009 .1372 .30866 .13443 .306 Metetra
.664 .741 .907 r
.13443 .306 .1372 .30866 .14105 .30722 .13827 .30457 Metetra
.664 .741 .907 r
.13827 .30457 .14105 .30722 .1449 .30578 .14212 .30312 Metetra
.664 .741 .907 r
.14212 .30312 .1449 .30578 .14875 .30434 .14598 .30168 Metetra
.664 .741 .907 r
.14598 .30168 .14875 .30434 .15261 .3029 .14984 .30024 Metetra
.664 .741 .907 r
.14984 .30024 .15261 .3029 .15647 .30146 .15371 .29879 Metetra
.664 .741 .907 r
.15371 .29879 .15647 .30146 .16035 .30001 .15759 .29734 Metetra
.664 .741 .907 r
.15759 .29734 .16035 .30001 .16422 .29857 .16147 .29589 Metetra
.664 .741 .907 r
.16147 .29589 .16422 .29857 .16811 .29712 .16535 .29443 Metetra
.664 .741 .907 r
.16535 .29443 .16811 .29712 .172 .29566 .16925 .29298 Metetra
.664 .741 .907 r
.16925 .29298 .172 .29566 .17589 .29421 .17314 .29152 Metetra
.945 .682 .505 r
.17314 .29152 .17589 .29421 .17979 .29275 .15105 .52267 Metetra
.498 .262 .488 r
.15105 .52267 .17979 .29275 .15822 .52384 .1559 .51528 Metetra
.919 .676 .555 r
.1559 .51528 .15822 .52384 .1651 .49755 .16693 .45123 Metetra
.719 .48 .563 r
.16693 .45123 .1651 .49755 .17475 .44494 .17419 .42071 Metetra
.743 .515 .586 r
.17419 .42071 .17475 .44494 .18159 .41777 .18016 .40169 Metetra
.753 .54 .608 r
.18016 .40169 .18159 .41777 .18736 .40023 .18551 .38818 Metetra
.758 .561 .63 r
.18551 .38818 .18736 .40023 .1926 .38753 .19051 .37782 Metetra
.76 .578 .651 r
.19051 .37782 .1926 .38753 .19753 .37766 .19529 .36944 Metetra
.761 .594 .671 r
.19529 .36944 .19753 .37766 .20226 .3696 .19991 .36241 Metetra
.76 .607 .689 r
.19991 .36241 .20226 .3696 .20685 .3628 .20444 .35634 Metetra
.758 .619 .706 r
.20444 .35634 .20685 .3628 .21135 .3569 .20888 .35099 Metetra
.755 .63 .722 r
.20888 .35099 .21135 .3569 .21578 .35168 .21327 .34619 Metetra
.752 .64 .736 r
.21327 .34619 .21578 .35168 .22015 .34698 .21762 .34183 Metetra
.749 .648 .749 r
.21762 .34183 .22015 .34698 .22449 .34269 .22193 .33781 Metetra
.746 .656 .761 r
.22193 .33781 .22449 .34269 .22879 .33874 .22621 .33407 Metetra
.742 .662 .771 r
.22621 .33407 .22879 .33874 .23307 .33506 .23048 .33057 Metetra
.739 .668 .781 r
.23048 .33057 .23307 .33506 .23732 .33161 .23472 .32727 Metetra
.735 .673 .79 r
.23472 .32727 .23732 .33161 .24156 .32835 .23895 .32414 Metetra
.732 .678 .798 r
.23895 .32414 .24156 .32835 .24579 .32525 .24317 .32115 Metetra
.729 .682 .805 r
.24317 .32115 .24579 .32525 .25001 .32229 .24739 .31829 Metetra
.726 .686 .811 r
.24739 .31829 .25001 .32229 .25422 .31945 .25159 .31553 Metetra
.723 .689 .817 r
.25159 .31553 .25422 .31945 .25842 .31672 .25579 .31287 Metetra
.72 .692 .823 r
.25579 .31287 .25842 .31672 .26262 .31408 .25999 .3103 Metetra
.717 .695 .828 r
.25999 .3103 .26262 .31408 .26681 .31153 .26418 .3078 Metetra
.715 .697 .832 r
.26418 .3078 .26681 .31153 .27101 .30905 .26837 .30537 Metetra
.712 .7 .836 r
.26837 .30537 .27101 .30905 .2752 .30663 .27256 .30299 Metetra
.71 .702 .84 r
.27256 .30299 .2752 .30663 .27939 .30427 .27675 .30067 Metetra
.708 .704 .844 r
.27675 .30067 .27939 .30427 .28358 .30196 .28094 .2984 Metetra
.706 .705 .847 r
.28094 .2984 .28358 .30196 .28777 .29971 .28514 .29618 Metetra
.928 .72 .601 r
.28514 .29618 .28777 .29971 .29196 .29749 .29072 .27564 Metetra
.561 .376 .588 r
.29072 .27564 .29196 .29749 .2975 .27702 .29486 .27384 Metetra
.681 .722 .88 r
.29486 .27384 .2975 .27702 .30164 .27523 .29901 .27206 Metetra
.68 .722 .882 r
.29901 .27206 .30164 .27523 .3058 .27346 .30317 .27029 Metetra
.679 .723 .883 r
.30317 .27029 .3058 .27346 .30995 .2717 .30733 .26854 Metetra
.677 .723 .884 r
.30733 .26854 .30995 .2717 .31411 .26996 .31149 .2668 Metetra
.676 .723 .885 r
.31149 .2668 .31411 .26996 .31828 .26822 .31566 .26507 Metetra
.675 .724 .886 r
.31566 .26507 .31828 .26822 .32245 .2665 .31983 .26336 Metetra
.675 .724 .887 r
.31983 .26336 .32245 .2665 .32663 .26479 .32401 .26165 Metetra
.674 .724 .888 r
.32401 .26165 .32663 .26479 .33081 .26309 .3282 .25995 Metetra
.673 .724 .888 r
.3282 .25995 .33081 .26309 .33499 .2614 .33239 .25826 Metetra
.672 .725 .889 r
.33239 .25826 .33499 .2614 .33919 .25972 .33658 .25658 Metetra
.671 .725 .89 r
.33658 .25658 .33919 .25972 .34338 .25805 .34078 .25491 Metetra
.67 .725 .89 r
.34078 .25491 .34338 .25805 .34759 .25638 .34499 .25325 Metetra
.67 .725 .891 r
.34499 .25325 .34759 .25638 .3518 .25473 .3492 .25159 Metetra
.669 .725 .892 r
.3492 .25159 .3518 .25473 .35601 .25308 .35342 .24994 Metetra
.668 .725 .892 r
.35342 .24994 .35601 .25308 .36023 .25143 .35765 .24829 Metetra
.667 .725 .893 r
.35765 .24829 .36023 .25143 .36446 .24979 .36188 .24665 Metetra
.667 .725 .893 r
.36188 .24665 .36446 .24979 .36869 .24816 .36611 .24502 Metetra
.666 .725 .893 r
.36611 .24502 .36869 .24816 .37293 .24654 .37036 .24339 Metetra
.665 .725 .894 r
.37036 .24339 .37293 .24654 .37718 .24492 .37461 .24177 Metetra
.665 .725 .894 r
.37461 .24177 .37718 .24492 .38143 .24331 .37886 .24016 Metetra
.664 .725 .895 r
.37886 .24016 .38143 .24331 .38569 .2417 .38312 .23855 Metetra
.663 .725 .895 r
.38312 .23855 .38569 .2417 .38995 .2401 .38739 .23694 Metetra
.663 .725 .895 r
.38739 .23694 .38995 .2401 .39422 .2385 .39167 .23534 Metetra
.662 .724 .895 r
.39167 .23534 .39422 .2385 .3985 .23691 .39595 .23374 Metetra
.661 .724 .896 r
.39595 .23374 .3985 .23691 .40278 .23532 .40023 .23215 Metetra
.661 .724 .896 r
.40023 .23215 .40278 .23532 .40707 .23374 .40453 .23057 Metetra
.66 .724 .896 r
.40453 .23057 .40707 .23374 .41137 .23216 .40883 .22899 Metetra
.659 .724 .896 r
.40883 .22899 .41137 .23216 .41567 .23059 .41313 .22741 Metetra
.659 .723 .897 r
.41313 .22741 .41567 .23059 .41998 .22903 .41745 .22584 Metetra
.658 .723 .897 r
.41745 .22584 .41998 .22903 .4243 .22747 .42177 .22427 Metetra
.657 .723 .897 r
.42177 .22427 .4243 .22747 .42862 .22591 .4261 .22271 Metetra
.657 .722 .897 r
.4261 .22271 .42862 .22591 .43295 .22436 .43043 .22115 Metetra
.656 .722 .897 r
.43043 .22115 .43295 .22436 .43729 .22282 .43477 .2196 Metetra
.655 .722 .897 r
.43477 .2196 .43729 .22282 .44163 .22128 .43912 .21806 Metetra
.655 .721 .898 r
.43912 .21806 .44163 .22128 .44598 .21975 .44347 .21652 Metetra
.654 .721 .898 r
.44347 .21652 .44598 .21975 .45034 .21822 .44783 .21499 Metetra
.653 .72 .898 r
.44783 .21499 .45034 .21822 .4547 .2167 .4522 .21346 Metetra
.652 .72 .898 r
.4522 .21346 .4547 .2167 .45907 .21519 .45658 .21194 Metetra
.651 .719 .898 r
.45658 .21194 .45907 .21519 .46345 .21369 .46096 .21042 Metetra
.65 .718 .898 r
.46096 .21042 .46345 .21369 .46784 .21219 .46535 .20892 Metetra
.649 .718 .898 r
.46535 .20892 .46784 .21219 .47223 .2107 .46975 .20742 Metetra
.649 .717 .898 r
.46975 .20742 .47223 .2107 .47663 .20922 .47415 .20592 Metetra
.648 .716 .898 r
.47415 .20592 .47663 .20922 .48104 .20775 .47857 .20444 Metetra
.646 .715 .898 r
.47857 .20444 .48104 .20775 .48546 .20628 .48299 .20297 Metetra
.645 .714 .898 r
.48299 .20297 .48546 .20628 .48988 .20483 .48741 .2015 Metetra
.644 .713 .898 r
.48741 .2015 .48988 .20483 .49431 .20339 .49185 .20005 Metetra
.643 .712 .898 r
.49185 .20005 .49431 .20339 .49875 .20196 .49629 .1986 Metetra
.642 .711 .898 r
.49629 .1986 .49875 .20196 .50319 .20055 .50074 .19717 Metetra
.64 .71 .897 r
.50074 .19717 .50319 .20055 .50765 .19914 .5052 .19575 Metetra
.639 .708 .897 r
.5052 .19575 .50765 .19914 .51211 .19775 .50966 .19435 Metetra
.637 .707 .897 r
.50966 .19435 .51211 .19775 .51658 .19638 .51414 .19296 Metetra
.635 .705 .897 r
.51414 .19296 .51658 .19638 .52103 .21398 .51862 .19159 Metetra
.001 0 .471 r
.51862 .19159 .52103 .21398 .52555 .21305 .5231 .20925 Metetra
.593 .663 .887 r
.5231 .20925 .52555 .21305 .53007 .21216 .52762 .20832 Metetra
.588 .659 .886 r
.52762 .20832 .53007 .21216 .5346 .21133 .53216 .20744 Metetra
.583 .654 .885 r
.53216 .20744 .5346 .21133 .53915 .21055 .53671 .20661 Metetra
.578 .648 .883 r
.53671 .20661 .53915 .21055 .5437 .20983 .54126 .20584 Metetra
.572 .642 .882 r
.54126 .20584 .5437 .20983 .54827 .20917 .54583 .20512 Metetra
.566 .636 .88 r
.54583 .20512 .54827 .20917 .55284 .2086 .55041 .20448 Metetra
.559 .628 .877 r
.55041 .20448 .55284 .2086 .55743 .20811 .555 .20391 Metetra
.551 .62 .875 r
.555 .20391 .55743 .20811 .56203 .20771 .5596 .20343 Metetra
.542 .611 .872 r
.5596 .20343 .56203 .20771 .56664 .20742 .56421 .20305 Metetra
.532 .601 .868 r
.56421 .20305 .56664 .20742 .57127 .20726 .56884 .20278 Metetra
.52 .589 .864 r
.56884 .20278 .57127 .20726 .57591 .20725 .57348 .20264 Metetra
.507 .575 .859 r
.57348 .20264 .57591 .20725 .58057 .2074 .57814 .20265 Metetra
.492 .56 .853 r
.57814 .20265 .58057 .2074 .58525 .20775 .58281 .20284 Metetra
.475 .542 .845 r
.58281 .20284 .58525 .20775 .58994 .20833 .58751 .20323 Metetra
.455 .521 .836 r
.58751 .20323 .58994 .20833 .59466 .2092 .59222 .20386 Metetra
.432 .497 .826 r
.59222 .20386 .59466 .2092 .5994 .21042 .59695 .20479 Metetra
.405 .468 .812 r
.59695 .20479 .5994 .21042 .60416 .21206 .60171 .20607 Metetra
.373 .434 .796 r
.60171 .20607 .60416 .21206 .60897 .21424 .60649 .20781 Metetra
.335 .394 .775 r
.60649 .20781 .60897 .21424 .61381 .21712 .61132 .21011 Metetra
.29 .347 .748 r
.61132 .21011 .61381 .21712 .6187 .22094 .61618 .21316 Metetra
.236 .29 .715 r
.61618 .21316 .6187 .22094 .62366 .22606 .6211 .21721 Metetra
.173 .223 .674 r
.6211 .21721 .62366 .22606 .62872 .23307 .6261 .22266 Metetra
.1 .145 .623 r
.6261 .22266 .62872 .23307 .63391 .24301 .63119 .23017 Metetra
.016 .057 .56 r
.63119 .23017 .63391 .24301 .63934 .25799 .63644 .24095 Metetra
0 0 .487 r
.63644 .24095 .63934 .25799 .64522 .28298 .64196 .25746 Metetra
0 0 .404 r
.64196 .25746 .64522 .28298 .65226 .33451 .64802 .28595 Metetra
0 0 .308 r
.64802 .28595 .65226 .33451 .65834 .35881 .65563 .34946 Metetra
.263 .282 .693 r
.65563 .34946 .65834 .35881 .65288 .11608 .66093 .35407 Metetra
0 0 .339 r
.66093 .35407 .65288 .11608 .65753 .11435 .65527 .11113 Metetra
.664 .741 .907 r
.65527 .11113 .65753 .11435 .6622 .1126 .65994 .10938 Metetra
.664 .741 .907 r
.65994 .10938 .6622 .1126 .66687 .11086 .66461 .10763 Metetra
.664 .741 .907 r
.66461 .10763 .66687 .11086 .67155 .10911 .6693 .10588 Metetra
.664 .741 .907 r
.6693 .10588 .67155 .10911 .67624 .10736 .67399 .10412 Metetra
.664 .741 .907 r
.67399 .10412 .67624 .10736 .68093 .10561 .67869 .10236 Metetra
.664 .741 .907 r
.67869 .10236 .68093 .10561 .68564 .10385 .6834 .1006 Metetra
.664 .741 .907 r
.6834 .1006 .68564 .10385 .69035 .10209 .68812 .09883 Metetra
.664 .741 .907 r
.68812 .09883 .69035 .10209 .69507 .10033 .69285 .09707 Metetra
.664 .741 .907 r
.69285 .09707 .69507 .10033 .6998 .09856 .69758 .0953 Metetra
.664 .741 .907 r
.69758 .0953 .6998 .09856 .70453 .09679 .70232 .09352 Metetra
.664 .741 .907 r
.70232 .09352 .70453 .09679 .70927 .09502 .70707 .09175 Metetra
.664 .741 .907 r
.70707 .09175 .70927 .09502 .71402 .09325 .71182 .08997 Metetra
.664 .741 .907 r
.71182 .08997 .71402 .09325 .71878 .09147 .71659 .08818 Metetra
.664 .741 .907 r
.71659 .08818 .71878 .09147 .72355 .08969 .72136 .0864 Metetra
.664 .741 .907 r
.72136 .0864 .72355 .08969 .72833 .08791 .72614 .08461 Metetra
.664 .741 .907 r
.72614 .08461 .72833 .08791 .73311 .08612 .73093 .08282 Metetra
.664 .741 .907 r
.73093 .08282 .73311 .08612 .7379 .08433 .73572 .08102 Metetra
.664 .741 .907 r
.73572 .08102 .7379 .08433 .7427 .08254 .74053 .07923 Metetra
.664 .741 .907 r
.10106 .31481 .10387 .31744 .10767 .31602 .10486 .31339 Metetra
.664 .741 .907 r
.10486 .31339 .10767 .31602 .11147 .31459 .10867 .31196 Metetra
.664 .741 .907 r
.10867 .31196 .11147 .31459 .11528 .31317 .11248 .31053 Metetra
.664 .741 .907 r
.11248 .31053 .11528 .31317 .1191 .31174 .1163 .3091 Metetra
.664 .741 .907 r
.1163 .3091 .1191 .31174 .12292 .31031 .12013 .30766 Metetra
.664 .741 .907 r
.12013 .30766 .12292 .31031 .12675 .30888 .12396 .30623 Metetra
.664 .741 .907 r
.12396 .30623 .12675 .30888 .13059 .30744 .1278 .30479 Metetra
.664 .741 .907 r
.1278 .30479 .13059 .30744 .13443 .306 .13164 .30335 Metetra
.664 .741 .907 r
.13164 .30335 .13443 .306 .13827 .30457 .13549 .3019 Metetra
.664 .741 .907 r
.13549 .3019 .13827 .30457 .14212 .30312 .13934 .30046 Metetra
.664 .741 .907 r
.13934 .30046 .14212 .30312 .14598 .30168 .1432 .29901 Metetra
.664 .741 .907 r
.1432 .29901 .14598 .30168 .14984 .30024 .14707 .29756 Metetra
.664 .741 .907 r
.14707 .29756 .14984 .30024 .15371 .29879 .15094 .29611 Metetra
.664 .741 .907 r
.15094 .29611 .15371 .29879 .15759 .29734 .15482 .29466 Metetra
.664 .741 .907 r
.15482 .29466 .15759 .29734 .16147 .29589 .1587 .2932 Metetra
.664 .741 .907 r
.1587 .2932 .16147 .29589 .16535 .29443 .16259 .29174 Metetra
.664 .741 .907 r
.16259 .29174 .16535 .29443 .16925 .29298 .16649 .29028 Metetra
.664 .741 .907 r
.16649 .29028 .16925 .29298 .17314 .29152 .17039 .28882 Metetra
.945 .682 .505 r
.17039 .28882 .17314 .29152 .15105 .52267 .14806 .52012 Metetra
.94 .703 .552 r
.14806 .52012 .15105 .52267 .1559 .51528 .15895 .45864 Metetra
.71 .469 .558 r
.15895 .45864 .1559 .51528 .16693 .45123 .16673 .42404 Metetra
.738 .508 .581 r
.16673 .42404 .16693 .45123 .17419 .42071 .17292 .40332 Metetra
.751 .535 .603 r
.17292 .40332 .17419 .42071 .18016 .40169 .17839 .38893 Metetra
.757 .556 .625 r
.17839 .38893 .18016 .40169 .18551 .38818 .18347 .37803 Metetra
.76 .574 .646 r
.18347 .37803 .18551 .38818 .19051 .37782 .18829 .36931 Metetra
.76 .59 .666 r
.18829 .36931 .19051 .37782 .19529 .36944 .19296 .36204 Metetra
.759 .604 .685 r
.19296 .36204 .19529 .36944 .19991 .36241 .19751 .3558 Metetra
.758 .617 .703 r
.19751 .3558 .19991 .36241 .20444 .35634 .20198 .35031 Metetra
.755 .628 .719 r
.20198 .35031 .20444 .35634 .20888 .35099 .20638 .34541 Metetra
.752 .637 .733 r
.20638 .34541 .20888 .35099 .21327 .34619 .21074 .34096 Metetra
.749 .646 .746 r
.21074 .34096 .21327 .34619 .21762 .34183 .21506 .33688 Metetra
.746 .654 .758 r
.21506 .33688 .21762 .34183 .22193 .33781 .21935 .33309 Metetra
.743 .661 .769 r
.21935 .33309 .22193 .33781 .22621 .33407 .22362 .32954 Metetra
.739 .667 .779 r
.22362 .32954 .22621 .33407 .23048 .33057 .22787 .3262 Metetra
.736 .672 .788 r
.22787 .3262 .23048 .33057 .23472 .32727 .23211 .32303 Metetra
.733 .677 .796 r
.23211 .32303 .23472 .32727 .23895 .32414 .23633 .32002 Metetra
.73 .681 .803 r
.23633 .32002 .23895 .32414 .24317 .32115 .24054 .31713 Metetra
.726 .685 .81 r
.24054 .31713 .24317 .32115 .24739 .31829 .24475 .31435 Metetra
.724 .689 .816 r
.24475 .31435 .24739 .31829 .25159 .31553 .24895 .31167 Metetra
.721 .692 .822 r
.24895 .31167 .25159 .31553 .25579 .31287 .25315 .30907 Metetra
.718 .694 .827 r
.25315 .30907 .25579 .31287 .25999 .3103 .25735 .30655 Metetra
.715 .697 .831 r
.25735 .30655 .25999 .3103 .26418 .3078 .26154 .3041 Metetra
.713 .699 .836 r
.26154 .3041 .26418 .3078 .26837 .30537 .26573 .30172 Metetra
.711 .701 .839 r
.26573 .30172 .26837 .30537 .27256 .30299 .26992 .29938 Metetra
.708 .703 .843 r
.26992 .29938 .27256 .30299 .27675 .30067 .27411 .2971 Metetra
.706 .705 .846 r
.27411 .2971 .27675 .30067 .28094 .2984 .2783 .29486 Metetra
.928 .72 .601 r
.2783 .29486 .28094 .2984 .28514 .29618 .28393 .27426 Metetra
.56 .375 .587 r
.28393 .27426 .28514 .29618 .29072 .27564 .28807 .27245 Metetra
.681 .722 .88 r
.28807 .27245 .29072 .27564 .29486 .27384 .29222 .27067 Metetra
.68 .722 .881 r
.29222 .27067 .29486 .27384 .29901 .27206 .29637 .26889 Metetra
.679 .723 .883 r
.29637 .26889 .29901 .27206 .30317 .27029 .30053 .26713 Metetra
.678 .723 .884 r
.30053 .26713 .30317 .27029 .30733 .26854 .30469 .26539 Metetra
.677 .724 .885 r
.30469 .26539 .30733 .26854 .31149 .2668 .30886 .26365 Metetra
.676 .724 .886 r
.30886 .26365 .31149 .2668 .31566 .26507 .31303 .26193 Metetra
.675 .724 .887 r
.31303 .26193 .31566 .26507 .31983 .26336 .31721 .26021 Metetra
.674 .724 .887 r
.31721 .26021 .31983 .26336 .32401 .26165 .32139 .25851 Metetra
.673 .725 .888 r
.32139 .25851 .32401 .26165 .3282 .25995 .32558 .25681 Metetra
.672 .725 .889 r
.32558 .25681 .3282 .25995 .33239 .25826 .32977 .25512 Metetra
.671 .725 .89 r
.32977 .25512 .33239 .25826 .33658 .25658 .33397 .25344 Metetra
.671 .725 .89 r
.33397 .25344 .33658 .25658 .34078 .25491 .33818 .25177 Metetra
.67 .725 .891 r
.33818 .25177 .34078 .25491 .34499 .25325 .34239 .25011 Metetra
.669 .725 .891 r
.34239 .25011 .34499 .25325 .3492 .25159 .3466 .24845 Metetra
.668 .725 .892 r
.3466 .24845 .3492 .25159 .35342 .24994 .35083 .2468 Metetra
.668 .725 .892 r
.35083 .2468 .35342 .24994 .35765 .24829 .35505 .24515 Metetra
.667 .725 .893 r
.35505 .24515 .35765 .24829 .36188 .24665 .35929 .24351 Metetra
.666 .725 .893 r
.35929 .24351 .36188 .24665 .36611 .24502 .36353 .24188 Metetra
.666 .725 .894 r
.36353 .24188 .36611 .24502 .37036 .24339 .36778 .24025 Metetra
.665 .725 .894 r
.36778 .24025 .37036 .24339 .37461 .24177 .37203 .23862 Metetra
.665 .725 .895 r
.37203 .23862 .37461 .24177 .37886 .24016 .37629 .237 Metetra
.664 .725 .895 r
.37629 .237 .37886 .24016 .38312 .23855 .38055 .23539 Metetra
.663 .725 .895 r
.38055 .23539 .38312 .23855 .38739 .23694 .38482 .23378 Metetra
.663 .725 .895 r
.38482 .23378 .38739 .23694 .39167 .23534 .3891 .23218 Metetra
.662 .725 .896 r
.3891 .23218 .39167 .23534 .39595 .23374 .39339 .23057 Metetra
.661 .725 .896 r
.39339 .23057 .39595 .23374 .40023 .23215 .39768 .22898 Metetra
.661 .724 .896 r
.39768 .22898 .40023 .23215 .40453 .23057 .40198 .22739 Metetra
.66 .724 .896 r
.40198 .22739 .40453 .23057 .40883 .22899 .40628 .2258 Metetra
.659 .724 .897 r
.40628 .2258 .40883 .22899 .41313 .22741 .41059 .22422 Metetra
.659 .724 .897 r
.41059 .22422 .41313 .22741 .41745 .22584 .41491 .22264 Metetra
.658 .723 .897 r
.41491 .22264 .41745 .22584 .42177 .22427 .41923 .22107 Metetra
.658 .723 .897 r
.41923 .22107 .42177 .22427 .4261 .22271 .42356 .2195 Metetra
.657 .723 .897 r
.42356 .2195 .4261 .22271 .43043 .22115 .4279 .21794 Metetra
.656 .722 .898 r
.4279 .21794 .43043 .22115 .43477 .2196 .43225 .21638 Metetra
.656 .722 .898 r
.43225 .21638 .43477 .2196 .43912 .21806 .4366 .21483 Metetra
.655 .722 .898 r
.4366 .21483 .43912 .21806 .44347 .21652 .44096 .21328 Metetra
.654 .721 .898 r
.44096 .21328 .44347 .21652 .44783 .21499 .44532 .21174 Metetra
.653 .721 .898 r
.44532 .21174 .44783 .21499 .4522 .21346 .4497 .21021 Metetra
.653 .72 .898 r
.4497 .21021 .4522 .21346 .45658 .21194 .45408 .20868 Metetra
.652 .719 .898 r
.45408 .20868 .45658 .21194 .46096 .21042 .45846 .20716 Metetra
.651 .719 .898 r
.45846 .20716 .46096 .21042 .46535 .20892 .46286 .20564 Metetra
.65 .718 .898 r
.46286 .20564 .46535 .20892 .46975 .20742 .46726 .20413 Metetra
.649 .717 .898 r
.46726 .20413 .46975 .20742 .47415 .20592 .47167 .20263 Metetra
.648 .717 .898 r
.47167 .20263 .47415 .20592 .47857 .20444 .47609 .20113 Metetra
.647 .716 .898 r
.47609 .20113 .47857 .20444 .48299 .20297 .48051 .19965 Metetra
.646 .715 .898 r
.48051 .19965 .48299 .20297 .48741 .2015 .48494 .19817 Metetra
.645 .714 .898 r
.48494 .19817 .48741 .2015 .49185 .20005 .48938 .1967 Metetra
.644 .713 .898 r
.48938 .1967 .49185 .20005 .49629 .1986 .49382 .19525 Metetra
.642 .712 .898 r
.49382 .19525 .49629 .1986 .50074 .19717 .49828 .1938 Metetra
.641 .711 .898 r
.49828 .1938 .50074 .19717 .5052 .19575 .50274 .19237 Metetra
.64 .709 .898 r
.50274 .19237 .5052 .19575 .50966 .19435 .50721 .19095 Metetra
.638 .708 .897 r
.50721 .19095 .50966 .19435 .51414 .19296 .51169 .18954 Metetra
.636 .706 .897 r
.51169 .18954 .51414 .19296 .51862 .19159 .51617 .18815 Metetra
.635 .705 .897 r
.51617 .18815 .51862 .19159 .5231 .20925 .52067 .18677 Metetra
.001 0 .47 r
.52067 .18677 .5231 .20925 .52762 .20832 .52517 .2045 Metetra
.592 .662 .887 r
.52517 .2045 .52762 .20832 .53216 .20744 .52971 .20357 Metetra
.587 .658 .886 r
.52971 .20357 .53216 .20744 .53671 .20661 .53426 .2027 Metetra
.582 .653 .885 r
.53426 .2027 .53671 .20661 .54126 .20584 .53882 .20187 Metetra
.577 .647 .883 r
.53882 .20187 .54126 .20584 .54583 .20512 .54339 .2011 Metetra
.571 .641 .881 r
.54339 .2011 .54583 .20512 .55041 .20448 .54797 .2004 Metetra
.564 .634 .879 r
.54797 .2004 .55041 .20448 .555 .20391 .55256 .19976 Metetra
.557 .627 .877 r
.55256 .19976 .555 .20391 .5596 .20343 .55716 .19921 Metetra
.549 .618 .874 r
.55716 .19921 .5596 .20343 .56421 .20305 .56178 .19874 Metetra
.54 .609 .871 r
.56178 .19874 .56421 .20305 .56884 .20278 .56641 .19838 Metetra
.529 .598 .867 r
.56641 .19838 .56884 .20278 .57348 .20264 .57105 .19812 Metetra
.518 .586 .863 r
.57105 .19812 .57348 .20264 .57814 .20265 .57571 .19801 Metetra
.504 .572 .857 r
.57571 .19801 .57814 .20265 .58281 .20284 .58038 .19804 Metetra
.489 .556 .851 r
.58038 .19804 .58281 .20284 .58751 .20323 .58507 .19826 Metetra
.472 .538 .843 r
.58507 .19826 .58751 .20323 .59222 .20386 .58978 .19869 Metetra
.451 .516 .834 r
.58978 .19869 .59222 .20386 .59695 .20479 .5945 .19937 Metetra
.427 .491 .823 r
.5945 .19937 .59695 .20479 .60171 .20607 .59925 .20035 Metetra
.399 .462 .809 r
.59925 .20035 .60171 .20607 .60649 .20781 .60403 .20172 Metetra
.366 .427 .791 r
.60403 .20172 .60649 .20781 .61132 .21011 .60884 .20355 Metetra
.327 .385 .769 r
.60884 .20355 .61132 .21011 .61618 .21316 .61368 .20598 Metetra
.281 .336 .742 r
.61368 .20598 .61618 .21316 .6211 .21721 .61857 .20921 Metetra
.225 .277 .707 r
.61857 .20921 .6211 .21721 .6261 .22266 .62352 .2135 Metetra
.161 .209 .664 r
.62352 .2135 .6261 .22266 .63119 .23017 .62854 .2193 Metetra
.085 .129 .611 r
.62854 .2193 .63119 .23017 .63644 .24095 .63368 .22736 Metetra
0 .039 .546 r
.63368 .22736 .63644 .24095 .64196 .25746 .639 .23905 Metetra
0 0 .471 r
.639 .23905 .64196 .25746 .64802 .28595 .64462 .25733 Metetra
0 0 .387 r
.64462 .25733 .64802 .28595 .65563 .34946 .6509 .29007 Metetra
0 0 .384 r
.6509 .29007 .65563 .34946 .66093 .35407 .65849 .35098 Metetra
.979 .682 .367 r
.65849 .35098 .66093 .35407 .65527 .11113 .65299 .1079 Metetra
.664 .741 .907 r
.65299 .1079 .65527 .11113 .65994 .10938 .65767 .10615 Metetra
.664 .741 .907 r
.65767 .10615 .65994 .10938 .66461 .10763 .66235 .10439 Metetra
.664 .741 .907 r
.66235 .10439 .66461 .10763 .6693 .10588 .66704 .10263 Metetra
.664 .741 .907 r
.66704 .10263 .6693 .10588 .67399 .10412 .67174 .10087 Metetra
.664 .741 .907 r
.67174 .10087 .67399 .10412 .67869 .10236 .67645 .09911 Metetra
.664 .741 .907 r
.67645 .09911 .67869 .10236 .6834 .1006 .68116 .09734 Metetra
.664 .741 .907 r
.68116 .09734 .6834 .1006 .68812 .09883 .68589 .09557 Metetra
.664 .741 .907 r
.68589 .09557 .68812 .09883 .69285 .09707 .69062 .0938 Metetra
.664 .741 .907 r
.69062 .0938 .69285 .09707 .69758 .0953 .69535 .09202 Metetra
.664 .741 .907 r
.69535 .09202 .69758 .0953 .70232 .09352 .7001 .09024 Metetra
.664 .741 .907 r
.7001 .09024 .70232 .09352 .70707 .09175 .70485 .08846 Metetra
.664 .741 .907 r
.70485 .08846 .70707 .09175 .71182 .08997 .70961 .08667 Metetra
.664 .741 .907 r
.70961 .08667 .71182 .08997 .71659 .08818 .71438 .08488 Metetra
.664 .741 .907 r
.71438 .08488 .71659 .08818 .72136 .0864 .71916 .08309 Metetra
.664 .741 .907 r
.71916 .08309 .72136 .0864 .72614 .08461 .72395 .0813 Metetra
.664 .741 .907 r
.72395 .0813 .72614 .08461 .73093 .08282 .72874 .0795 Metetra
.664 .741 .907 r
.72874 .0795 .73093 .08282 .73572 .08102 .73354 .0777 Metetra
.664 .741 .907 r
.73354 .0777 .73572 .08102 .74053 .07923 .73835 .0759 Metetra
.664 .741 .907 r
.09824 .31218 .10106 .31481 .10486 .31339 .10204 .31075 Metetra
.664 .741 .907 r
.10204 .31075 .10486 .31339 .10867 .31196 .10585 .30932 Metetra
.664 .741 .907 r
.10585 .30932 .10867 .31196 .11248 .31053 .10967 .30788 Metetra
.664 .741 .907 r
.10967 .30788 .11248 .31053 .1163 .3091 .11349 .30645 Metetra
.664 .741 .907 r
.11349 .30645 .1163 .3091 .12013 .30766 .11732 .30501 Metetra
.664 .741 .907 r
.11732 .30501 .12013 .30766 .12396 .30623 .12116 .30357 Metetra
.664 .741 .907 r
.12116 .30357 .12396 .30623 .1278 .30479 .125 .30213 Metetra
.664 .741 .907 r
.125 .30213 .1278 .30479 .13164 .30335 .12884 .30068 Metetra
.664 .741 .907 r
.12884 .30068 .13164 .30335 .13549 .3019 .1327 .29923 Metetra
.664 .741 .907 r
.1327 .29923 .13549 .3019 .13934 .30046 .13655 .29778 Metetra
.664 .741 .907 r
.13655 .29778 .13934 .30046 .1432 .29901 .14042 .29633 Metetra
.664 .741 .907 r
.14042 .29633 .1432 .29901 .14707 .29756 .14429 .29488 Metetra
.664 .741 .907 r
.14429 .29488 .14707 .29756 .15094 .29611 .14816 .29342 Metetra
.664 .741 .907 r
.14816 .29342 .15094 .29611 .15482 .29466 .15205 .29197 Metetra
.664 .741 .907 r
.15205 .29197 .15482 .29466 .1587 .2932 .15593 .29051 Metetra
.664 .741 .907 r
.15593 .29051 .1587 .2932 .16259 .29174 .15983 .28904 Metetra
.664 .741 .907 r
.15983 .28904 .16259 .29174 .16649 .29028 .16372 .28758 Metetra
.945 .682 .506 r
.16372 .28758 .16649 .29028 .17039 .28882 .14087 .51895 Metetra
.387 .168 .455 r
.14087 .51895 .17039 .28882 .14806 .52012 .15075 .46748 Metetra
.735 .492 .56 r
.15075 .46748 .14806 .52012 .15895 .45864 .15918 .42783 Metetra
.734 .501 .576 r
.15918 .42783 .15895 .45864 .16673 .42404 .16564 .40516 Metetra
.748 .529 .598 r
.16564 .40516 .16673 .42404 .17292 .40332 .17125 .38978 Metetra
.756 .552 .62 r
.17125 .38978 .17292 .40332 .17839 .38893 .1764 .37831 Metetra
.759 .57 .642 r
.1764 .37831 .17839 .38893 .18347 .37803 .18129 .36921 Metetra
.76 .587 .662 r
.18129 .36921 .18347 .37803 .18829 .36931 .18599 .36169 Metetra
.759 .601 .681 r
.18599 .36169 .18829 .36931 .19296 .36204 .19057 .35526 Metetra
.758 .614 .699 r
.19057 .35526 .19296 .36204 .19751 .3558 .19505 .34965 Metetra
.756 .625 .715 r
.19505 .34965 .19751 .3558 .20198 .35031 .19948 .34464 Metetra
.753 .635 .73 r
.19948 .34464 .20198 .35031 .20638 .34541 .20385 .3401 Metetra
.75 .644 .744 r
.20385 .3401 .20638 .34541 .21074 .34096 .20818 .33595 Metetra
.747 .652 .756 r
.20818 .33595 .21074 .34096 .21506 .33688 .21248 .3321 Metetra
.743 .659 .767 r
.21248 .3321 .21506 .33688 .21935 .33309 .21675 .32851 Metetra
.74 .665 .777 r
.21675 .32851 .21935 .33309 .22362 .32954 .22101 .32513 Metetra
.737 .671 .786 r
.22101 .32513 .22362 .32954 .22787 .3262 .22525 .32193 Metetra
.733 .676 .794 r
.22525 .32193 .22787 .3262 .23211 .32303 .22948 .31888 Metetra
.73 .68 .802 r
.22948 .31888 .23211 .32303 .23633 .32002 .23369 .31596 Metetra
.727 .684 .809 r
.23369 .31596 .23633 .32002 .24054 .31713 .2379 .31316 Metetra
.724 .688 .815 r
.2379 .31316 .24054 .31713 .24475 .31435 .24211 .31046 Metetra
.721 .691 .821 r
.24211 .31046 .24475 .31435 .24895 .31167 .24631 .30785 Metetra
.719 .694 .826 r
.24631 .30785 .24895 .31167 .25315 .30907 .2505 .30531 Metetra
.716 .696 .83 r
.2505 .30531 .25315 .30907 .25735 .30655 .2547 .30284 Metetra
.713 .699 .835 r
.2547 .30284 .25735 .30655 .26154 .3041 .25889 .30044 Metetra
.711 .701 .839 r
.25889 .30044 .26154 .3041 .26573 .30172 .26308 .29809 Metetra
.709 .703 .842 r
.26308 .29809 .26573 .30172 .26992 .29938 .26727 .2958 Metetra
.927 .718 .6 r
.26727 .2958 .26992 .29938 .27411 .2971 .27299 .27471 Metetra
.559 .373 .585 r
.27299 .27471 .27411 .2971 .2783 .29486 .27713 .27288 Metetra
.56 .374 .587 r
.27713 .27288 .2783 .29486 .28393 .27426 .28127 .27107 Metetra
.682 .722 .88 r
.28127 .27107 .28393 .27426 .28807 .27245 .28542 .26927 Metetra
.681 .722 .881 r
.28542 .26927 .28807 .27245 .29222 .27067 .28957 .26749 Metetra
.679 .723 .882 r
.28957 .26749 .29222 .27067 .29637 .26889 .29372 .26573 Metetra
.678 .723 .883 r
.29372 .26573 .29637 .26889 .30053 .26713 .29788 .26397 Metetra
.677 .724 .885 r
.29788 .26397 .30053 .26713 .30469 .26539 .30205 .26223 Metetra
.676 .724 .885 r
.30205 .26223 .30469 .26539 .30886 .26365 .30622 .2605 Metetra
.675 .724 .886 r
.30622 .2605 .30886 .26365 .31303 .26193 .31039 .25878 Metetra
.674 .725 .887 r
.31039 .25878 .31303 .26193 .31721 .26021 .31458 .25707 Metetra
.674 .725 .888 r
.31458 .25707 .31721 .26021 .32139 .25851 .31876 .25536 Metetra
.673 .725 .889 r
.31876 .25536 .32139 .25851 .32558 .25681 .32295 .25367 Metetra
.672 .725 .889 r
.32295 .25367 .32558 .25681 .32977 .25512 .32715 .25198 Metetra
.671 .725 .89 r
.32715 .25198 .32977 .25512 .33397 .25344 .33135 .2503 Metetra
.67 .725 .891 r
.33135 .2503 .33397 .25344 .33818 .25177 .33556 .24863 Metetra
.67 .726 .891 r
.33556 .24863 .33818 .25177 .34239 .25011 .33978 .24697 Metetra
.669 .726 .892 r
.33978 .24697 .34239 .25011 .3466 .24845 .344 .24531 Metetra
.668 .726 .892 r
.344 .24531 .3466 .24845 .35083 .2468 .34822 .24365 Metetra
.668 .726 .893 r
.34822 .24365 .35083 .2468 .35505 .24515 .35245 .24201 Metetra
.667 .726 .893 r
.35245 .24201 .35505 .24515 .35929 .24351 .35669 .24036 Metetra
.666 .726 .894 r
.35669 .24036 .35929 .24351 .36353 .24188 .36094 .23873 Metetra
.666 .726 .894 r
.36094 .23873 .36353 .24188 .36778 .24025 .36519 .23709 Metetra
.665 .726 .894 r
.36519 .23709 .36778 .24025 .37203 .23862 .36944 .23547 Metetra
.664 .726 .895 r
.36944 .23547 .37203 .23862 .37629 .237 .37371 .23385 Metetra
.664 .725 .895 r
.37371 .23385 .37629 .237 .38055 .23539 .37797 .23223 Metetra
.663 .725 .895 r
.37797 .23223 .38055 .23539 .38482 .23378 .38225 .23061 Metetra
.663 .725 .896 r
.38225 .23061 .38482 .23378 .3891 .23218 .38653 .22901 Metetra
.662 .725 .896 r
.38653 .22901 .3891 .23218 .39339 .23057 .39082 .2274 Metetra
.661 .725 .896 r
.39082 .2274 .39339 .23057 .39768 .22898 .39512 .2258 Metetra
.661 .725 .897 r
.39512 .2258 .39768 .22898 .40198 .22739 .39942 .22421 Metetra
.66 .725 .897 r
.39942 .22421 .40198 .22739 .40628 .2258 .40373 .22261 Metetra
.66 .724 .897 r
.40373 .22261 .40628 .2258 .41059 .22422 .40804 .22103 Metetra
.659 .724 .897 r
.40804 .22103 .41059 .22422 .41491 .22264 .41236 .21945 Metetra
.658 .724 .897 r
.41236 .21945 .41491 .22264 .41923 .22107 .41669 .21787 Metetra
.658 .723 .897 r
.41669 .21787 .41923 .22107 .42356 .2195 .42103 .21629 Metetra
.657 .723 .898 r
.42103 .21629 .42356 .2195 .4279 .21794 .42537 .21472 Metetra
.656 .723 .898 r
.42537 .21472 .4279 .21794 .43225 .21638 .42972 .21316 Metetra
.656 .722 .898 r
.42972 .21316 .43225 .21638 .4366 .21483 .43407 .2116 Metetra
.655 .722 .898 r
.43407 .2116 .4366 .21483 .44096 .21328 .43844 .21005 Metetra
.654 .722 .898 r
.43844 .21005 .44096 .21328 .44532 .21174 .44281 .2085 Metetra
.654 .721 .898 r
.44281 .2085 .44532 .21174 .4497 .21021 .44718 .20695 Metetra
.653 .721 .898 r
.44718 .20695 .4497 .21021 .45408 .20868 .45157 .20542 Metetra
.652 .72 .898 r
.45157 .20542 .45408 .20868 .45846 .20716 .45596 .20388 Metetra
.651 .719 .898 r
.45596 .20388 .45846 .20716 .46286 .20564 .46036 .20236 Metetra
.65 .719 .898 r
.46036 .20236 .46286 .20564 .46726 .20413 .46476 .20084 Metetra
.65 .718 .898 r
.46476 .20084 .46726 .20413 .47167 .20263 .46918 .19933 Metetra
.649 .717 .898 r
.46918 .19933 .47167 .20263 .47609 .20113 .4736 .19782 Metetra
.648 .717 .898 r
.4736 .19782 .47609 .20113 .48051 .19965 .47802 .19633 Metetra
.647 .716 .898 r
.47802 .19633 .48051 .19965 .48494 .19817 .48246 .19484 Metetra
.646 .715 .898 r
.48246 .19484 .48494 .19817 .48938 .1967 .4869 .19336 Metetra
.644 .714 .898 r
.4869 .19336 .48938 .1967 .49382 .19525 .49135 .19189 Metetra
.643 .713 .898 r
.49135 .19189 .49382 .19525 .49828 .1938 .49581 .19043 Metetra
.642 .712 .898 r
.49581 .19043 .49828 .1938 .50274 .19237 .50028 .18898 Metetra
.641 .711 .898 r
.50028 .18898 .50274 .19237 .50721 .19095 .50475 .18754 Metetra
.639 .709 .898 r
.50475 .18754 .50721 .19095 .51169 .18954 .50923 .18612 Metetra
.638 .708 .897 r
.50923 .18612 .51169 .18954 .51617 .18815 .51372 .18471 Metetra
.636 .706 .897 r
.51372 .18471 .51617 .18815 .52067 .18677 .51822 .18332 Metetra
.634 .704 .897 r
.51822 .18332 .52067 .18677 .52517 .2045 .52272 .18194 Metetra
.549 .366 .586 r
.52272 .18194 .52517 .2045 .52971 .20357 .52724 .18058 Metetra
0 0 .468 r
.52724 .18058 .52971 .20357 .53426 .2027 .53181 .19881 Metetra
.586 .657 .886 r
.53181 .19881 .53426 .2027 .53882 .20187 .53637 .19794 Metetra
.581 .651 .884 r
.53637 .19794 .53882 .20187 .54339 .2011 .54094 .19712 Metetra
.576 .646 .883 r
.54094 .19712 .54339 .2011 .54797 .2004 .54552 .19635 Metetra
.57 .64 .881 r
.54552 .19635 .54797 .2004 .55256 .19976 .55012 .19566 Metetra
.563 .633 .879 r
.55012 .19566 .55256 .19976 .55716 .19921 .55472 .19503 Metetra
.556 .625 .876 r
.55472 .19503 .55716 .19921 .56178 .19874 .55934 .19448 Metetra
.547 .616 .873 r
.55934 .19448 .56178 .19874 .56641 .19838 .56397 .19403 Metetra
.538 .607 .87 r
.56397 .19403 .56641 .19838 .57105 .19812 .56861 .19368 Metetra
.527 .596 .866 r
.56861 .19368 .57105 .19812 .57571 .19801 .57327 .19345 Metetra
.515 .583 .861 r
.57327 .19345 .57571 .19801 .58038 .19804 .57794 .19335 Metetra
.502 .569 .856 r
.57794 .19335 .58038 .19804 .58507 .19826 .58263 .19341 Metetra
.486 .553 .849 r
.58263 .19341 .58507 .19826 .58978 .19869 .58733 .19366 Metetra
.468 .534 .841 r
.58733 .19366 .58978 .19869 .5945 .19937 .59206 .19413 Metetra
.447 .511 .832 r
.59206 .19413 .5945 .19937 .59925 .20035 .5968 .19486 Metetra
.422 .486 .82 r
.5968 .19486 .59925 .20035 .60403 .20172 .60157 .19591 Metetra
.394 .455 .805 r
.60157 .19591 .60403 .20172 .60884 .20355 .60636 .19735 Metetra
.36 .419 .787 r
.60636 .19735 .60884 .20355 .61368 .20598 .61119 .19928 Metetra
.319 .376 .764 r
.61119 .19928 .61368 .20598 .61857 .20921 .61606 .20185 Metetra
.271 .325 .735 r
.61606 .20185 .61857 .20921 .62352 .2135 .62097 .20525 Metetra
.214 .265 .699 r
.62097 .20525 .62352 .2135 .62854 .2193 .62595 .2098 Metetra
.148 .194 .654 r
.62595 .2098 .62854 .2193 .63368 .22736 .63101 .21598 Metetra
.071 .112 .599 r
.63101 .21598 .63368 .22736 .639 .23905 .6362 .22463 Metetra
0 .02 .532 r
.6362 .22463 .639 .23905 .64462 .25733 .64158 .23734 Metetra
0 0 .456 r
.64158 .23734 .64462 .25733 .6509 .29007 .64732 .25765 Metetra
0 0 .37 r
.64732 .25765 .6509 .29007 .65849 .35098 .65387 .29568 Metetra
0 0 .416 r
.65387 .29568 .65849 .35098 .65299 .1079 .6611 .3462 Metetra
0 0 .337 r
.6611 .3462 .65299 .1079 .65767 .10615 .65539 .1029 Metetra
.664 .741 .907 r
.65539 .1029 .65767 .10615 .66235 .10439 .66008 .10114 Metetra
.664 .741 .907 r
.66008 .10114 .66235 .10439 .66704 .10263 .66478 .09938 Metetra
.664 .741 .907 r
.66478 .09938 .66704 .10263 .67174 .10087 .66948 .09761 Metetra
.664 .741 .907 r
.66948 .09761 .67174 .10087 .67645 .09911 .6742 .09584 Metetra
.664 .741 .907 r
.6742 .09584 .67645 .09911 .68116 .09734 .67891 .09407 Metetra
.664 .741 .907 r
.67891 .09407 .68116 .09734 .68589 .09557 .68364 .09229 Metetra
.664 .741 .907 r
.68364 .09229 .68589 .09557 .69062 .0938 .68838 .09051 Metetra
.664 .741 .907 r
.68838 .09051 .69062 .0938 .69535 .09202 .69312 .08873 Metetra
.664 .741 .907 r
.69312 .08873 .69535 .09202 .7001 .09024 .69787 .08695 Metetra
.664 .741 .907 r
.69787 .08695 .7001 .09024 .70485 .08846 .70263 .08516 Metetra
.664 .741 .907 r
.70263 .08516 .70485 .08846 .70961 .08667 .7074 .08337 Metetra
.664 .741 .907 r
.7074 .08337 .70961 .08667 .71438 .08488 .71218 .08158 Metetra
.664 .741 .907 r
.71218 .08158 .71438 .08488 .71916 .08309 .71696 .07978 Metetra
.664 .741 .907 r
.71696 .07978 .71916 .08309 .72395 .0813 .72175 .07798 Metetra
.664 .741 .907 r
.72175 .07798 .72395 .0813 .72874 .0795 .72655 .07618 Metetra
.664 .741 .907 r
.72655 .07618 .72874 .0795 .73354 .0777 .73136 .07437 Metetra
.664 .741 .907 r
.73136 .07437 .73354 .0777 .73835 .0759 .73617 .07256 Metetra
.664 .741 .907 r
.09541 .30954 .09824 .31218 .10204 .31075 .09922 .3081 Metetra
.664 .741 .907 r
.09922 .3081 .10204 .31075 .10585 .30932 .10303 .30667 Metetra
.664 .741 .907 r
.10303 .30667 .10585 .30932 .10967 .30788 .10685 .30523 Metetra
.664 .741 .907 r
.10685 .30523 .10967 .30788 .11349 .30645 .11068 .30379 Metetra
.664 .741 .907 r
.11068 .30379 .11349 .30645 .11732 .30501 .11451 .30235 Metetra
.664 .741 .907 r
.11451 .30235 .11732 .30501 .12116 .30357 .11835 .3009 Metetra
.664 .741 .907 r
.11835 .3009 .12116 .30357 .125 .30213 .12219 .29946 Metetra
.664 .741 .907 r
.12219 .29946 .125 .30213 .12884 .30068 .12604 .29801 Metetra
.664 .741 .907 r
.12604 .29801 .12884 .30068 .1327 .29923 .1299 .29656 Metetra
.664 .741 .907 r
.1299 .29656 .1327 .29923 .13655 .29778 .13376 .2951 Metetra
.664 .741 .907 r
.13376 .2951 .13655 .29778 .14042 .29633 .13763 .29365 Metetra
.664 .741 .907 r
.13763 .29365 .14042 .29633 .14429 .29488 .1415 .29219 Metetra
.664 .741 .907 r
.1415 .29219 .14429 .29488 .14816 .29342 .14538 .29073 Metetra
.664 .741 .907 r
.14538 .29073 .14816 .29342 .15205 .29197 .14926 .28927 Metetra
.664 .741 .907 r
.14926 .28927 .15205 .29197 .15593 .29051 .15315 .2878 Metetra
.664 .741 .907 r
.15315 .2878 .15593 .29051 .15983 .28904 .15705 .28634 Metetra
.945 .681 .507 r
.15705 .28634 .15983 .28904 .16372 .28758 .13368 .51777 Metetra
.419 .194 .464 r
.13368 .51777 .16372 .28758 .14087 .51895 .14228 .47818 Metetra
.783 .538 .565 r
.14228 .47818 .14087 .51895 .15075 .46748 .15154 .43216 Metetra
.728 .493 .571 r
.15154 .43216 .15075 .46748 .15918 .42783 .15831 .40722 Metetra
.746 .524 .593 r
.15831 .40722 .15918 .42783 .16564 .40516 .16407 .39074 Metetra
.754 .547 .616 r
.16407 .39074 .16564 .40516 .17125 .38978 .16932 .37865 Metetra
.758 .566 .637 r
.16932 .37865 .17125 .38978 .1764 .37831 .17426 .36916 Metetra
.759 .583 .658 r
.17426 .36916 .1764 .37831 .18129 .36921 .179 .36137 Metetra
.759 .598 .677 r
.179 .36137 .18129 .36921 .18599 .36169 .18361 .35475 Metetra
.758 .611 .696 r
.18361 .35475 .18599 .36169 .19057 .35526 .18812 .34899 Metetra
.756 .623 .712 r
.18812 .34899 .19057 .35526 .19505 .34965 .19256 .34387 Metetra
.753 .633 .727 r
.19256 .34387 .19505 .34965 .19948 .34464 .19694 .33925 Metetra
.75 .642 .741 r
.19694 .33925 .19948 .34464 .20385 .3401 .20128 .33503 Metetra
.747 .65 .754 r
.20128 .33503 .20385 .3401 .20818 .33595 .20559 .33112 Metetra
.744 .658 .765 r
.20559 .33112 .20818 .33595 .21248 .3321 .20988 .32748 Metetra
.74 .664 .775 r
.20988 .32748 .21248 .3321 .21675 .32851 .21414 .32406 Metetra
.737 .67 .784 r
.21414 .32406 .21675 .32851 .22101 .32513 .21838 .32083 Metetra
.734 .675 .793 r
.21838 .32083 .22101 .32513 .22525 .32193 .22261 .31775 Metetra
.731 .679 .8 r
.22261 .31775 .22525 .32193 .22948 .31888 .22683 .3148 Metetra
.728 .683 .807 r
.22683 .3148 .22948 .31888 .23369 .31596 .23105 .31198 Metetra
.725 .687 .814 r
.23105 .31198 .23369 .31596 .2379 .31316 .23525 .30925 Metetra
.722 .69 .819 r
.23525 .30925 .2379 .31316 .24211 .31046 .23945 .30662 Metetra
.719 .693 .825 r
.23945 .30662 .24211 .31046 .24631 .30785 .24365 .30407 Metetra
.716 .696 .829 r
.24365 .30407 .24631 .30785 .2505 .30531 .24784 .30159 Metetra
.714 .698 .834 r
.24784 .30159 .2505 .30531 .2547 .30284 .25203 .29917 Metetra
.712 .7 .838 r
.25203 .29917 .2547 .30284 .25889 .30044 .25623 .29681 Metetra
.709 .702 .842 r
.25623 .29681 .25889 .30044 .26308 .29809 .26042 .2945 Metetra
.927 .718 .6 r
.26042 .2945 .26308 .29809 .26727 .2958 .26619 .27335 Metetra
.559 .372 .585 r
.26619 .27335 .26727 .2958 .27299 .27471 .27032 .27151 Metetra
.683 .721 .878 r
.27032 .27151 .27299 .27471 .27713 .27288 .27446 .26969 Metetra
.682 .722 .879 r
.27446 .26969 .27713 .27288 .28127 .27107 .27861 .26788 Metetra
.681 .722 .881 r
.27861 .26788 .28127 .27107 .28542 .26927 .28276 .26609 Metetra
.68 .723 .882 r
.28276 .26609 .28542 .26927 .28957 .26749 .28691 .26432 Metetra
.679 .723 .883 r
.28691 .26432 .28957 .26749 .29372 .26573 .29107 .26256 Metetra
.678 .724 .884 r
.29107 .26256 .29372 .26573 .29788 .26397 .29523 .26081 Metetra
.677 .724 .885 r
.29523 .26081 .29788 .26397 .30205 .26223 .2994 .25907 Metetra
.676 .724 .886 r
.2994 .25907 .30205 .26223 .30622 .2605 .30357 .25734 Metetra
.675 .725 .887 r
.30357 .25734 .30622 .2605 .31039 .25878 .30775 .25563 Metetra
.674 .725 .888 r
.30775 .25563 .31039 .25878 .31458 .25707 .31194 .25392 Metetra
.673 .725 .889 r
.31194 .25392 .31458 .25707 .31876 .25536 .31612 .25222 Metetra
.672 .725 .889 r
.31612 .25222 .31876 .25536 .32295 .25367 .32032 .25052 Metetra
.672 .726 .89 r
.32032 .25052 .32295 .25367 .32715 .25198 .32452 .24884 Metetra
.671 .726 .891 r
.32452 .24884 .32715 .25198 .33135 .2503 .32873 .24716 Metetra
.67 .726 .891 r
.32873 .24716 .33135 .2503 .33556 .24863 .33294 .24549 Metetra
.669 .726 .892 r
.33294 .24549 .33556 .24863 .33978 .24697 .33716 .24382 Metetra
.669 .726 .892 r
.33716 .24382 .33978 .24697 .344 .24531 .34138 .24216 Metetra
.668 .726 .893 r
.34138 .24216 .344 .24531 .34822 .24365 .34561 .24051 Metetra
.667 .726 .893 r
.34561 .24051 .34822 .24365 .35245 .24201 .34984 .23886 Metetra
.667 .726 .894 r
.34984 .23886 .35245 .24201 .35669 .24036 .35409 .23721 Metetra
.666 .726 .894 r
.35409 .23721 .35669 .24036 .36094 .23873 .35833 .23557 Metetra
.666 .726 .894 r
.35833 .23557 .36094 .23873 .36519 .23709 .36259 .23394 Metetra
.665 .726 .895 r
.36259 .23394 .36519 .23709 .36944 .23547 .36685 .23231 Metetra
.664 .726 .895 r
.36685 .23231 .36944 .23547 .37371 .23385 .37112 .23068 Metetra
.664 .726 .895 r
.37112 .23068 .37371 .23385 .37797 .23223 .37539 .22906 Metetra
.663 .726 .896 r
.37539 .22906 .37797 .23223 .38225 .23061 .37967 .22745 Metetra
.663 .726 .896 r
.37967 .22745 .38225 .23061 .38653 .22901 .38395 .22583 Metetra
.662 .725 .896 r
.38395 .22583 .38653 .22901 .39082 .2274 .38825 .22422 Metetra
.661 .725 .897 r
.38825 .22422 .39082 .2274 .39512 .2258 .39255 .22262 Metetra
.661 .725 .897 r
.39255 .22262 .39512 .2258 .39942 .22421 .39685 .22102 Metetra
.66 .725 .897 r
.39685 .22102 .39942 .22421 .40373 .22261 .40116 .21942 Metetra
.66 .725 .897 r
.40116 .21942 .40373 .22261 .40804 .22103 .40548 .21783 Metetra
.659 .724 .897 r
.40548 .21783 .40804 .22103 .41236 .21945 .40981 .21624 Metetra
.658 .724 .898 r
.40981 .21624 .41236 .21945 .41669 .21787 .41414 .21466 Metetra
.658 .724 .898 r
.41414 .21466 .41669 .21787 .42103 .21629 .41848 .21308 Metetra
.657 .724 .898 r
.41848 .21308 .42103 .21629 .42537 .21472 .42283 .2115 Metetra
.657 .723 .898 r
.42283 .2115 .42537 .21472 .42972 .21316 .42718 .20993 Metetra
.656 .723 .898 r
.42718 .20993 .42972 .21316 .43407 .2116 .43154 .20837 Metetra
.655 .722 .898 r
.43154 .20837 .43407 .2116 .43844 .21005 .43591 .2068 Metetra
.655 .722 .898 r
.43591 .2068 .43844 .21005 .44281 .2085 .44028 .20525 Metetra
.654 .722 .898 r
.44028 .20525 .44281 .2085 .44718 .20695 .44466 .2037 Metetra
.653 .721 .898 r
.44466 .2037 .44718 .20695 .45157 .20542 .44905 .20215 Metetra
.652 .721 .898 r
.44905 .20215 .45157 .20542 .45596 .20388 .45345 .20061 Metetra
.652 .72 .899 r
.45345 .20061 .45596 .20388 .46036 .20236 .45785 .19907 Metetra
.651 .719 .899 r
.45785 .19907 .46036 .20236 .46476 .20084 .46226 .19755 Metetra
.65 .719 .899 r
.46226 .19755 .46476 .20084 .46918 .19933 .46668 .19602 Metetra
.649 .718 .899 r
.46668 .19602 .46918 .19933 .4736 .19782 .4711 .19451 Metetra
.648 .717 .899 r
.4711 .19451 .4736 .19782 .47802 .19633 .47553 .193 Metetra
.647 .717 .899 r
.47553 .193 .47802 .19633 .48246 .19484 .47997 .1915 Metetra
.646 .716 .898 r
.47997 .1915 .48246 .19484 .4869 .19336 .48442 .19001 Metetra
.645 .715 .898 r
.48442 .19001 .4869 .19336 .49135 .19189 .48887 .18853 Metetra
.644 .714 .898 r
.48887 .18853 .49135 .19189 .49581 .19043 .49334 .18705 Metetra
.643 .713 .898 r
.49334 .18705 .49581 .19043 .50028 .18898 .49781 .18559 Metetra
.642 .712 .898 r
.49781 .18559 .50028 .18898 .50475 .18754 .50228 .18414 Metetra
.64 .71 .898 r
.50228 .18414 .50475 .18754 .50923 .18612 .50677 .1827 Metetra
.639 .709 .898 r
.50677 .1827 .50923 .18612 .51372 .18471 .51126 .18128 Metetra
.637 .707 .897 r
.51126 .18128 .51372 .18471 .51822 .18332 .51576 .17986 Metetra
.635 .706 .897 r
.51576 .17986 .51822 .18332 .52272 .18194 .52027 .17847 Metetra
.634 .704 .897 r
.52027 .17847 .52272 .18194 .52724 .18058 .52479 .17709 Metetra
.632 .702 .897 r
.52479 .17709 .52724 .18058 .53181 .19881 .52932 .17573 Metetra
0 0 .468 r
.52932 .17573 .53181 .19881 .53637 .19794 .53391 .19403 Metetra
.585 .656 .885 r
.53391 .19403 .53637 .19794 .54094 .19712 .53849 .19316 Metetra
.58 .65 .884 r
.53849 .19316 .54094 .19712 .54552 .19635 .54307 .19234 Metetra
.574 .645 .882 r
.54307 .19234 .54552 .19635 .55012 .19566 .54767 .19158 Metetra
.568 .638 .88 r
.54767 .19158 .55012 .19566 .55472 .19503 .55228 .19089 Metetra
.562 .631 .878 r
.55228 .19089 .55472 .19503 .55934 .19448 .5569 .19027 Metetra
.554 .623 .876 r
.5569 .19027 .55934 .19448 .56397 .19403 .56153 .18974 Metetra
.545 .615 .873 r
.56153 .18974 .56397 .19403 .56861 .19368 .56617 .1893 Metetra
.536 .605 .869 r
.56617 .1893 .56861 .19368 .57327 .19345 .57083 .18896 Metetra
.525 .593 .865 r
.57083 .18896 .57327 .19345 .57794 .19335 .5755 .18875 Metetra
.513 .581 .86 r
.5755 .18875 .57794 .19335 .58263 .19341 .58019 .18867 Metetra
.499 .566 .855 r
.58019 .18867 .58263 .19341 .58733 .19366 .58489 .18876 Metetra
.483 .549 .848 r
.58489 .18876 .58733 .19366 .59206 .19413 .58961 .18904 Metetra
.464 .529 .839 r
.58961 .18904 .59206 .19413 .5968 .19486 .59435 .18955 Metetra
.443 .507 .829 r
.59435 .18955 .5968 .19486 .60157 .19591 .59911 .19033 Metetra
.418 .48 .817 r
.59911 .19033 .60157 .19591 .60636 .19735 .6039 .19144 Metetra
.388 .448 .802 r
.6039 .19144 .60636 .19735 .61119 .19928 .60871 .19296 Metetra
.353 .411 .783 r
.60871 .19296 .61119 .19928 .61606 .20185 .61356 .195 Metetra
.311 .367 .759 r
.61356 .195 .61606 .20185 .62097 .20525 .61845 .19771 Metetra
.262 .314 .729 r
.61845 .19771 .62097 .20525 .62595 .2098 .62339 .20131 Metetra
.203 .252 .691 r
.62339 .20131 .62595 .2098 .63101 .21598 .62839 .20612 Metetra
.135 .179 .644 r
.62839 .20612 .63101 .21598 .6362 .22463 .63349 .2127 Metetra
.056 .096 .586 r
.63349 .2127 .6362 .22463 .64158 .23734 .63873 .222 Metetra
0 .002 .518 r
.63873 .222 .64158 .23734 .64732 .25765 .64419 .23585 Metetra
0 0 .44 r
.64419 .23585 .64732 .25765 .65387 .29568 .65006 .25852 Metetra
0 0 .353 r
.65006 .25852 .65387 .29568 .6611 .3462 .65695 .30322 Metetra
0 0 .435 r
.65695 .30322 .6611 .3462 .65539 .1029 .66372 .34139 Metetra
0 0 .337 r
.66372 .34139 .65539 .1029 .66008 .10114 .65781 .09788 Metetra
.664 .741 .907 r
.65781 .09788 .66008 .10114 .66478 .09938 .66251 .09611 Metetra
.664 .741 .907 r
.66251 .09611 .66478 .09938 .66948 .09761 .66722 .09434 Metetra
.664 .741 .907 r
.66722 .09434 .66948 .09761 .6742 .09584 .67193 .09257 Metetra
.664 .741 .907 r
.67193 .09257 .6742 .09584 .67891 .09407 .67666 .09079 Metetra
.664 .741 .907 r
.67666 .09079 .67891 .09407 .68364 .09229 .68139 .08901 Metetra
.664 .741 .907 r
.68139 .08901 .68364 .09229 .68838 .09051 .68613 .08722 Metetra
.664 .741 .907 r
.68613 .08722 .68838 .09051 .69312 .08873 .69088 .08543 Metetra
.664 .741 .907 r
.69088 .08543 .69312 .08873 .69787 .08695 .69564 .08364 Metetra
.664 .741 .907 r
.69564 .08364 .69787 .08695 .70263 .08516 .7004 .08185 Metetra
.664 .741 .907 r
.7004 .08185 .70263 .08516 .7074 .08337 .70518 .08006 Metetra
.664 .741 .907 r
.70518 .08006 .7074 .08337 .71218 .08158 .70996 .07826 Metetra
.664 .741 .907 r
.70996 .07826 .71218 .08158 .71696 .07978 .71475 .07645 Metetra
.664 .741 .907 r
.71475 .07645 .71696 .07978 .72175 .07798 .71954 .07465 Metetra
.664 .741 .907 r
.71954 .07465 .72175 .07798 .72655 .07618 .72435 .07284 Metetra
.664 .741 .907 r
.72435 .07284 .72655 .07618 .73136 .07437 .72916 .07103 Metetra
.664 .741 .907 r
.72916 .07103 .73136 .07437 .73617 .07256 .73398 .06921 Metetra
.664 .741 .907 r
.09257 .30689 .09541 .30954 .09922 .3081 .09638 .30545 Metetra
.664 .741 .907 r
.09638 .30545 .09922 .3081 .10303 .30667 .1002 .30401 Metetra
.664 .741 .907 r
.1002 .30401 .10303 .30667 .10685 .30523 .10403 .30257 Metetra
.664 .741 .907 r
.10403 .30257 .10685 .30523 .11068 .30379 .10786 .30113 Metetra
.664 .741 .907 r
.10786 .30113 .11068 .30379 .11451 .30235 .11169 .29968 Metetra
.664 .741 .907 r
.11169 .29968 .11451 .30235 .11835 .3009 .11553 .29823 Metetra
.664 .741 .907 r
.11553 .29823 .11835 .3009 .12219 .29946 .11938 .29678 Metetra
.664 .741 .907 r
.11938 .29678 .12219 .29946 .12604 .29801 .12323 .29533 Metetra
.664 .741 .907 r
.12323 .29533 .12604 .29801 .1299 .29656 .12709 .29387 Metetra
.664 .741 .907 r
.12709 .29387 .1299 .29656 .13376 .2951 .13096 .29242 Metetra
.664 .741 .907 r
.13096 .29242 .13376 .2951 .13763 .29365 .13483 .29096 Metetra
.664 .741 .907 r
.13483 .29096 .13763 .29365 .1415 .29219 .1387 .28949 Metetra
.664 .741 .907 r
.1387 .28949 .1415 .29219 .14538 .29073 .14258 .28803 Metetra
.664 .741 .907 r
.14258 .28803 .14538 .29073 .14926 .28927 .14647 .28656 Metetra
.664 .741 .907 r
.14647 .28656 .14926 .28927 .15315 .2878 .15037 .2851 Metetra
.944 .681 .508 r
.15037 .2851 .15315 .2878 .15705 .28634 .12647 .51659 Metetra
.454 .224 .474 r
.12647 .51659 .15705 .28634 .13368 .51777 .13346 .49139 Metetra
.845 .599 .566 r
.13346 .49139 .13368 .51777 .14228 .47818 .14379 .43713 Metetra
.722 .484 .566 r
.14379 .43713 .14228 .47818 .15154 .43216 .15092 .40953 Metetra
.743 .518 .589 r
.15092 .40953 .15154 .43216 .15831 .40722 .15686 .39183 Metetra
.752 .542 .611 r
.15686 .39183 .15831 .40722 .16407 .39074 .16221 .37905 Metetra
.757 .562 .633 r
.16221 .37905 .16407 .39074 .16932 .37865 .16721 .36914 Metetra
.759 .579 .654 r
.16721 .36914 .16932 .37865 .17426 .36916 .172 .36107 Metetra
.759 .595 .674 r
.172 .36107 .17426 .36916 .179 .36137 .17664 .35425 Metetra
.758 .608 .692 r
.17664 .35425 .179 .36137 .18361 .35475 .18117 .34834 Metetra
.756 .62 .709 r
.18117 .34834 .18361 .35475 .18812 .34899 .18563 .34311 Metetra
.753 .631 .724 r
.18563 .34311 .18812 .34899 .19256 .34387 .19003 .3384 Metetra
.751 .64 .738 r
.19003 .3384 .19256 .34387 .19694 .33925 .19438 .33411 Metetra
.747 .649 .751 r
.19438 .33411 .19694 .33925 .20128 .33503 .1987 .33015 Metetra
.744 .656 .763 r
.1987 .33015 .20128 .33503 .20559 .33112 .20299 .32646 Metetra
.741 .663 .773 r
.20299 .32646 .20559 .33112 .20988 .32748 .20725 .32299 Metetra
.738 .668 .783 r
.20725 .32299 .20988 .32748 .21414 .32406 .2115 .31972 Metetra
.734 .674 .791 r
.2115 .31972 .21414 .32406 .21838 .32083 .21574 .31661 Metetra
.731 .678 .799 r
.21574 .31661 .21838 .32083 .22261 .31775 .21996 .31364 Metetra
.728 .682 .806 r
.21996 .31364 .22261 .31775 .22683 .3148 .22418 .31079 Metetra
.725 .686 .812 r
.22418 .31079 .22683 .3148 .23105 .31198 .22839 .30805 Metetra
.722 .69 .818 r
.22839 .30805 .23105 .31198 .23525 .30925 .23259 .3054 Metetra
.72 .693 .824 r
.23259 .3054 .23525 .30925 .23945 .30662 .23679 .30282 Metetra
.717 .695 .828 r
.23679 .30282 .23945 .30662 .24365 .30407 .24098 .30033 Metetra
.714 .698 .833 r
.24098 .30033 .24365 .30407 .24784 .30159 .24517 .29789 Metetra
.712 .7 .837 r
.24517 .29789 .24784 .30159 .25203 .29917 .24936 .29552 Metetra
.71 .702 .841 r
.24936 .29552 .25203 .29917 .25623 .29681 .25356 .2932 Metetra
.926 .717 .6 r
.25356 .2932 .25623 .29681 .26042 .2945 .25937 .27198 Metetra
.558 .371 .584 r
.25937 .27198 .26042 .2945 .26619 .27335 .26351 .27013 Metetra
.684 .721 .878 r
.26351 .27013 .26619 .27335 .27032 .27151 .26765 .2683 Metetra
.683 .722 .879 r
.26765 .2683 .27032 .27151 .27446 .26969 .27179 .26649 Metetra
.681 .722 .881 r
.27179 .26649 .27446 .26969 .27861 .26788 .27594 .2647 Metetra
.68 .723 .882 r
.27594 .2647 .27861 .26788 .28276 .26609 .28009 .26292 Metetra
.679 .723 .883 r
.28009 .26292 .28276 .26609 .28691 .26432 .28424 .26115 Metetra
.678 .724 .884 r
.28424 .26115 .28691 .26432 .29107 .26256 .28841 .25939 Metetra
.677 .724 .885 r
.28841 .25939 .29107 .26256 .29523 .26081 .29257 .25765 Metetra
.676 .724 .886 r
.29257 .25765 .29523 .26081 .2994 .25907 .29674 .25592 Metetra
.675 .725 .887 r
.29674 .25592 .2994 .25907 .30357 .25734 .30092 .25419 Metetra
.674 .725 .888 r
.30092 .25419 .30357 .25734 .30775 .25563 .3051 .25247 Metetra
.673 .725 .889 r
.3051 .25247 .30775 .25563 .31194 .25392 .30929 .25077 Metetra
.673 .726 .889 r
.30929 .25077 .31194 .25392 .31612 .25222 .31348 .24907 Metetra
.672 .726 .89 r
.31348 .24907 .31612 .25222 .32032 .25052 .31768 .24738 Metetra
.671 .726 .891 r
.31768 .24738 .32032 .25052 .32452 .24884 .32188 .24569 Metetra
.67 .726 .891 r
.32188 .24569 .32452 .24884 .32873 .24716 .32609 .24401 Metetra
.67 .726 .892 r
.32609 .24401 .32873 .24716 .33294 .24549 .33031 .24234 Metetra
.669 .726 .892 r
.33031 .24234 .33294 .24549 .33716 .24382 .33453 .24067 Metetra
.668 .726 .893 r
.33453 .24067 .33716 .24382 .34138 .24216 .33876 .23901 Metetra
.668 .726 .893 r
.33876 .23901 .34138 .24216 .34561 .24051 .34299 .23735 Metetra
.667 .726 .894 r
.34299 .23735 .34561 .24051 .34984 .23886 .34723 .2357 Metetra
.667 .726 .894 r
.34723 .2357 .34984 .23886 .35409 .23721 .35147 .23406 Metetra
.666 .726 .894 r
.35147 .23406 .35409 .23721 .35833 .23557 .35573 .23242 Metetra
.665 .726 .895 r
.35573 .23242 .35833 .23557 .36259 .23394 .35998 .23078 Metetra
.665 .726 .895 r
.35998 .23078 .36259 .23394 .36685 .23231 .36425 .22915 Metetra
.664 .726 .895 r
.36425 .22915 .36685 .23231 .37112 .23068 .36852 .22752 Metetra
.664 .726 .896 r
.36852 .22752 .37112 .23068 .37539 .22906 .3728 .22589 Metetra
.663 .726 .896 r
.3728 .22589 .37539 .22906 .37967 .22745 .37708 .22427 Metetra
.663 .726 .896 r
.37708 .22427 .37967 .22745 .38395 .22583 .38137 .22265 Metetra
.662 .726 .897 r
.38137 .22265 .38395 .22583 .38825 .22422 .38567 .22104 Metetra
.661 .726 .897 r
.38567 .22104 .38825 .22422 .39255 .22262 .38997 .21943 Metetra
.661 .725 .897 r
.38997 .21943 .39255 .22262 .39685 .22102 .39428 .21783 Metetra
.66 .725 .897 r
.39428 .21783 .39685 .22102 .40116 .21942 .39859 .21623 Metetra
.66 .725 .897 r
.39859 .21623 .40116 .21942 .40548 .21783 .40292 .21463 Metetra
.659 .725 .898 r
.40292 .21463 .40548 .21783 .40981 .21624 .40725 .21303 Metetra
.659 .724 .898 r
.40725 .21303 .40981 .21624 .41414 .21466 .41158 .21144 Metetra
.658 .724 .898 r
.41158 .21144 .41414 .21466 .41848 .21308 .41593 .20986 Metetra
.657 .724 .898 r
.41593 .20986 .41848 .21308 .42283 .2115 .42028 .20828 Metetra
.657 .724 .898 r
.42028 .20828 .42283 .2115 .42718 .20993 .42464 .2067 Metetra
.656 .723 .898 r
.42464 .2067 .42718 .20993 .43154 .20837 .429 .20513 Metetra
.656 .723 .898 r
.429 .20513 .43154 .20837 .43591 .2068 .43337 .20356 Metetra
.655 .722 .898 r
.43337 .20356 .43591 .2068 .44028 .20525 .43775 .20199 Metetra
.654 .722 .899 r
.43775 .20199 .44028 .20525 .44466 .2037 .44213 .20043 Metetra
.653 .722 .899 r
.44213 .20043 .44466 .2037 .44905 .20215 .44653 .19888 Metetra
.653 .721 .899 r
.44653 .19888 .44905 .20215 .45345 .20061 .45093 .19733 Metetra
.652 .721 .899 r
.45093 .19733 .45345 .20061 .45785 .19907 .45533 .19579 Metetra
.651 .72 .899 r
.45533 .19579 .45785 .19907 .46226 .19755 .45975 .19425 Metetra
.65 .719 .899 r
.45975 .19425 .46226 .19755 .46668 .19602 .46417 .19272 Metetra
.65 .719 .899 r
.46417 .19272 .46668 .19602 .4711 .19451 .4686 .19119 Metetra
.649 .718 .899 r
.4686 .19119 .4711 .19451 .47553 .193 .47303 .18967 Metetra
.648 .717 .899 r
.47303 .18967 .47553 .193 .47997 .1915 .47748 .18816 Metetra
.647 .716 .899 r
.47748 .18816 .47997 .1915 .48442 .19001 .48193 .18666 Metetra
.646 .716 .899 r
.48193 .18666 .48442 .19001 .48887 .18853 .48639 .18517 Metetra
.645 .715 .899 r
.48639 .18517 .48887 .18853 .49334 .18705 .49085 .18368 Metetra
.644 .714 .898 r
.49085 .18368 .49334 .18705 .49781 .18559 .49533 .1822 Metetra
.642 .713 .898 r
.49533 .1822 .49781 .18559 .50228 .18414 .49981 .18074 Metetra
.641 .711 .898 r
.49981 .18074 .50228 .18414 .50677 .1827 .5043 .17928 Metetra
.64 .71 .898 r
.5043 .17928 .50677 .1827 .51126 .18128 .5088 .17784 Metetra
.638 .709 .898 r
.5088 .17784 .51126 .18128 .51576 .17986 .5133 .17641 Metetra
.637 .707 .898 r
.5133 .17641 .51576 .17986 .52027 .17847 .51782 .175 Metetra
.635 .706 .897 r
.51782 .175 .52027 .17847 .52479 .17709 .52234 .1736 Metetra
.633 .704 .897 r
.52234 .1736 .52479 .17709 .52932 .17573 .52687 .17222 Metetra
.631 .702 .897 r
.52687 .17222 .52932 .17573 .53391 .19403 .53141 .17086 Metetra
0 0 .467 r
.53141 .17086 .53391 .19403 .53849 .19316 .53603 .18922 Metetra
.584 .655 .885 r
.53603 .18922 .53849 .19316 .54307 .19234 .54062 .18836 Metetra
.579 .649 .884 r
.54062 .18836 .54307 .19234 .54767 .19158 .54522 .18754 Metetra
.573 .643 .882 r
.54522 .18754 .54767 .19158 .55228 .19089 .54983 .18679 Metetra
.567 .637 .88 r
.54983 .18679 .55228 .19089 .5569 .19027 .55445 .18611 Metetra
.56 .63 .878 r
.55445 .18611 .5569 .19027 .56153 .18974 .55908 .1855 Metetra
.552 .622 .875 r
.55908 .1855 .56153 .18974 .56617 .1893 .56373 .18497 Metetra
.544 .613 .872 r
.56373 .18497 .56617 .1893 .57083 .18896 .56838 .18454 Metetra
.534 .602 .868 r
.56838 .18454 .57083 .18896 .5755 .18875 .57306 .18422 Metetra
.523 .591 .864 r
.57306 .18422 .5755 .18875 .58019 .18867 .57774 .18403 Metetra
.511 .578 .859 r
.57774 .18403 .58019 .18867 .58489 .18876 .58244 .18397 Metetra
.496 .563 .853 r
.58244 .18397 .58489 .18876 .58961 .18904 .58716 .18409 Metetra
.48 .545 .846 r
.58716 .18409 .58961 .18904 .59435 .18955 .5919 .1844 Metetra
.461 .525 .837 r
.5919 .1844 .59435 .18955 .59911 .19033 .59665 .18495 Metetra
.438 .502 .827 r
.59665 .18495 .59911 .19033 .6039 .19144 .60143 .18578 Metetra
.413 .474 .814 r
.60143 .18578 .6039 .19144 .60871 .19296 .60624 .18696 Metetra
.382 .441 .798 r
.60624 .18696 .60871 .19296 .61356 .195 .61107 .18857 Metetra
.346 .403 .778 r
.61107 .18857 .61356 .195 .61845 .19771 .61594 .19071 Metetra
.303 .357 .753 r
.61594 .19071 .61845 .19771 .62339 .20131 .62085 .19357 Metetra
.252 .303 .722 r
.62085 .19357 .62339 .20131 .62839 .20612 .62582 .19736 Metetra
.192 .239 .682 r
.62582 .19736 .62839 .20612 .63349 .2127 .63085 .20246 Metetra
.122 .164 .633 r
.63085 .20246 .63349 .2127 .63873 .222 .63599 .20948 Metetra
.042 .079 .574 r
.63599 .20948 .63873 .222 .64419 .23585 .64128 .21947 Metetra
0 0 .504 r
.64128 .21947 .64419 .23585 .65006 .25852 .64682 .23459 Metetra
0 0 .425 r
.64682 .23459 .65006 .25852 .65695 .30322 .65285 .26004 Metetra
0 0 .336 r
.65285 .26004 .65695 .30322 .66372 .34139 .66019 .31339 Metetra
.029 0 .479 r
.66019 .31339 .66372 .34139 .65781 .09788 .66636 .33656 Metetra
0 0 .337 r
.66636 .33656 .65781 .09788 .66251 .09611 .66023 .09284 Metetra
.664 .741 .907 r
.66023 .09284 .66251 .09611 .66722 .09434 .66495 .09106 Metetra
.664 .741 .907 r
.66495 .09106 .66722 .09434 .67193 .09257 .66967 .08928 Metetra
.664 .741 .907 r
.66967 .08928 .67193 .09257 .67666 .09079 .6744 .0875 Metetra
.664 .741 .907 r
.6744 .0875 .67666 .09079 .68139 .08901 .67914 .08571 Metetra
.664 .741 .907 r
.67914 .08571 .68139 .08901 .68613 .08722 .68388 .08392 Metetra
.664 .741 .907 r
.68388 .08392 .68613 .08722 .69088 .08543 .68864 .08213 Metetra
.664 .741 .907 r
.68864 .08213 .69088 .08543 .69564 .08364 .6934 .08033 Metetra
.664 .741 .907 r
.6934 .08033 .69564 .08364 .7004 .08185 .69817 .07853 Metetra
.664 .741 .907 r
.69817 .07853 .7004 .08185 .70518 .08006 .70295 .07673 Metetra
.664 .741 .907 r
.70295 .07673 .70518 .08006 .70996 .07826 .70774 .07493 Metetra
.664 .741 .907 r
.70774 .07493 .70996 .07826 .71475 .07645 .71253 .07312 Metetra
.664 .741 .907 r
.71253 .07312 .71475 .07645 .71954 .07465 .71733 .07131 Metetra
.664 .741 .907 r
.71733 .07131 .71954 .07465 .72435 .07284 .72214 .06949 Metetra
.664 .741 .907 r
.72214 .06949 .72435 .07284 .72916 .07103 .72696 .06768 Metetra
.664 .741 .907 r
.72696 .06768 .72916 .07103 .73398 .06921 .73179 .06586 Metetra
.664 .741 .907 r
.08973 .30423 .09257 .30689 .09638 .30545 .09354 .30279 Metetra
.664 .741 .907 r
.09354 .30279 .09638 .30545 .1002 .30401 .09737 .30135 Metetra
.664 .741 .907 r
.09737 .30135 .1002 .30401 .10403 .30257 .10119 .2999 Metetra
.664 .741 .907 r
.10119 .2999 .10403 .30257 .10786 .30113 .10503 .29845 Metetra
.664 .741 .907 r
.10503 .29845 .10786 .30113 .11169 .29968 .10886 .297 Metetra
.664 .741 .907 r
.10886 .297 .11169 .29968 .11553 .29823 .11271 .29555 Metetra
.664 .741 .907 r
.11271 .29555 .11553 .29823 .11938 .29678 .11656 .2941 Metetra
.664 .741 .907 r
.11656 .2941 .11938 .29678 .12323 .29533 .12041 .29264 Metetra
.664 .741 .907 r
.12041 .29264 .12323 .29533 .12709 .29387 .12428 .29118 Metetra
.664 .741 .907 r
.12428 .29118 .12709 .29387 .13096 .29242 .12814 .28972 Metetra
.664 .741 .907 r
.12814 .28972 .13096 .29242 .13483 .29096 .13202 .28826 Metetra
.664 .741 .907 r
.13202 .28826 .13483 .29096 .1387 .28949 .1359 .28679 Metetra
.664 .741 .907 r
.1359 .28679 .1387 .28949 .14258 .28803 .13978 .28532 Metetra
.664 .741 .907 r
.13978 .28532 .14258 .28803 .14647 .28656 .14367 .28385 Metetra
.944 .681 .509 r
.14367 .28385 .14647 .28656 .15037 .2851 .11925 .51542 Metetra
.494 .257 .484 r
.11925 .51542 .15037 .2851 .12647 .51659 .12414 .50813 Metetra
.918 .676 .557 r
.12414 .50813 .12647 .51659 .13346 .49139 .13592 .44286 Metetra
.715 .475 .561 r
.13592 .44286 .13346 .49139 .14379 .43713 .14348 .41212 Metetra
.739 .511 .584 r
.14348 .41212 .14379 .43713 .15092 .40953 .14962 .39305 Metetra
.75 .537 .607 r
.14962 .39305 .15092 .40953 .15686 .39183 .15507 .37953 Metetra
.756 .558 .629 r
.15507 .37953 .15686 .39183 .16221 .37905 .16015 .36917 Metetra
.758 .576 .65 r
.16015 .36917 .16221 .37905 .16721 .36914 .16498 .36079 Metetra
.759 .591 .67 r
.16498 .36079 .16721 .36914 .172 .36107 .16965 .35377 Metetra
.758 .605 .688 r
.16965 .35377 .172 .36107 .17664 .35425 .17421 .34771 Metetra
.756 .618 .706 r
.17421 .34771 .17664 .35425 .18117 .34834 .17869 .34236 Metetra
.754 .629 .721 r
.17869 .34236 .18117 .34834 .18563 .34311 .1831 .33756 Metetra
.751 .638 .736 r
.1831 .33756 .18563 .34311 .19003 .3384 .18747 .33319 Metetra
.748 .647 .749 r
.18747 .33319 .19003 .3384 .19438 .33411 .19179 .32917 Metetra
.745 .654 .76 r
.19179 .32917 .19438 .33411 .1987 .33015 .19609 .32543 Metetra
.741 .661 .771 r
.19609 .32543 .1987 .33015 .20299 .32646 .20036 .32193 Metetra
.738 .667 .781 r
.20036 .32193 .20299 .32646 .20725 .32299 .20462 .31862 Metetra
.735 .673 .789 r
.20462 .31862 .20725 .32299 .2115 .31972 .20886 .31548 Metetra
.732 .677 .797 r
.20886 .31548 .2115 .31972 .21574 .31661 .21308 .31248 Metetra
.729 .682 .805 r
.21308 .31248 .21574 .31661 .21996 .31364 .2173 .30961 Metetra
.726 .685 .811 r
.2173 .30961 .21996 .31364 .22418 .31079 .22151 .30684 Metetra
.723 .689 .817 r
.22151 .30684 .22418 .31079 .22839 .30805 .22571 .30417 Metetra
.72 .692 .823 r
.22571 .30417 .22839 .30805 .23259 .3054 .22991 .30158 Metetra
.717 .695 .828 r
.22991 .30158 .23259 .3054 .23679 .30282 .23411 .29907 Metetra
.715 .697 .832 r
.23411 .29907 .23679 .30282 .24098 .30033 .2383 .29662 Metetra
.712 .7 .836 r
.2383 .29662 .24098 .30033 .24517 .29789 .24249 .29423 Metetra
.71 .702 .84 r
.24249 .29423 .24517 .29789 .24936 .29552 .24668 .2919 Metetra
.926 .717 .6 r
.24668 .2919 .24936 .29552 .25356 .2932 .25255 .27061 Metetra
.558 .371 .583 r
.25255 .27061 .25356 .2932 .25937 .27198 .25668 .26876 Metetra
.684 .721 .877 r
.25668 .26876 .25937 .27198 .26351 .27013 .26082 .26692 Metetra
.683 .722 .879 r
.26082 .26692 .26351 .27013 .26765 .2683 .26496 .26511 Metetra
.682 .722 .88 r
.26496 .26511 .26765 .2683 .27179 .26649 .26911 .2633 Metetra
.68 .723 .882 r
.26911 .2633 .27179 .26649 .27594 .2647 .27326 .26152 Metetra
.679 .723 .883 r
.27326 .26152 .27594 .2647 .28009 .26292 .27741 .25974 Metetra
.678 .724 .884 r
.27741 .25974 .28009 .26292 .28424 .26115 .28157 .25798 Metetra
.677 .724 .885 r
.28157 .25798 .28424 .26115 .28841 .25939 .28573 .25623 Metetra
.676 .725 .886 r
.28573 .25623 .28841 .25939 .29257 .25765 .2899 .25449 Metetra
.675 .725 .887 r
.2899 .25449 .29257 .25765 .29674 .25592 .29408 .25276 Metetra
.675 .725 .888 r
.29408 .25276 .29674 .25592 .30092 .25419 .29826 .25104 Metetra
.674 .725 .888 r
.29826 .25104 .30092 .25419 .3051 .25247 .30244 .24932 Metetra
.673 .726 .889 r
.30244 .24932 .3051 .25247 .30929 .25077 .30663 .24762 Metetra
.672 .726 .89 r
.30663 .24762 .30929 .25077 .31348 .24907 .31083 .24592 Metetra
.672 .726 .89 r
.31083 .24592 .31348 .24907 .31768 .24738 .31503 .24423 Metetra
.671 .726 .891 r
.31503 .24423 .31768 .24738 .32188 .24569 .31924 .24254 Metetra
.67 .726 .892 r
.31924 .24254 .32188 .24569 .32609 .24401 .32345 .24086 Metetra
.669 .726 .892 r
.32345 .24086 .32609 .24401 .33031 .24234 .32767 .23919 Metetra
.669 .726 .893 r
.32767 .23919 .33031 .24234 .33453 .24067 .33189 .23752 Metetra
.668 .727 .893 r
.33189 .23752 .33453 .24067 .33876 .23901 .33613 .23586 Metetra
.668 .727 .894 r
.33613 .23586 .33876 .23901 .34299 .23735 .34036 .2342 Metetra
.667 .727 .894 r
.34036 .2342 .34299 .23735 .34723 .2357 .34461 .23255 Metetra
.666 .727 .894 r
.34461 .23255 .34723 .2357 .35147 .23406 .34885 .2309 Metetra
.666 .727 .895 r
.34885 .2309 .35147 .23406 .35573 .23242 .35311 .22925 Metetra
.665 .727 .895 r
.35311 .22925 .35573 .23242 .35998 .23078 .35737 .22761 Metetra
.665 .727 .895 r
.35737 .22761 .35998 .23078 .36425 .22915 .36164 .22598 Metetra
.664 .726 .896 r
.36164 .22598 .36425 .22915 .36852 .22752 .36591 .22435 Metetra
.664 .726 .896 r
.36591 .22435 .36852 .22752 .3728 .22589 .3702 .22272 Metetra
.663 .726 .896 r
.3702 .22272 .3728 .22589 .37708 .22427 .37448 .22109 Metetra
.663 .726 .897 r
.37448 .22109 .37708 .22427 .38137 .22265 .37878 .21947 Metetra
.662 .726 .897 r
.37878 .21947 .38137 .22265 .38567 .22104 .38308 .21785 Metetra
.661 .726 .897 r
.38308 .21785 .38567 .22104 .38997 .21943 .38738 .21624 Metetra
.661 .726 .897 r
.38738 .21624 .38997 .21943 .39428 .21783 .3917 .21463 Metetra
.66 .726 .897 r
.3917 .21463 .39428 .21783 .39859 .21623 .39602 .21302 Metetra
.66 .725 .898 r
.39602 .21302 .39859 .21623 .40292 .21463 .40035 .21142 Metetra
.659 .725 .898 r
.40035 .21142 .40292 .21463 .40725 .21303 .40468 .20982 Metetra
.659 .725 .898 r
.40468 .20982 .40725 .21303 .41158 .21144 .40902 .20823 Metetra
.658 .725 .898 r
.40902 .20823 .41158 .21144 .41593 .20986 .41337 .20663 Metetra
.658 .724 .898 r
.41337 .20663 .41593 .20986 .42028 .20828 .41772 .20505 Metetra
.657 .724 .898 r
.41772 .20505 .42028 .20828 .42464 .2067 .42208 .20346 Metetra
.656 .724 .898 r
.42208 .20346 .42464 .2067 .429 .20513 .42645 .20188 Metetra
.656 .723 .899 r
.42645 .20188 .429 .20513 .43337 .20356 .43083 .20031 Metetra
.655 .723 .899 r
.43083 .20031 .43337 .20356 .43775 .20199 .43521 .19874 Metetra
.654 .722 .899 r
.43521 .19874 .43775 .20199 .44213 .20043 .4396 .19717 Metetra
.654 .722 .899 r
.4396 .19717 .44213 .20043 .44653 .19888 .444 .19561 Metetra
.653 .722 .899 r
.444 .19561 .44653 .19888 .45093 .19733 .4484 .19405 Metetra
.652 .721 .899 r
.4484 .19405 .45093 .19733 .45533 .19579 .45281 .1925 Metetra
.652 .72 .899 r
.45281 .1925 .45533 .19579 .45975 .19425 .45723 .19095 Metetra
.651 .72 .899 r
.45723 .19095 .45975 .19425 .46417 .19272 .46165 .18941 Metetra
.65 .719 .899 r
.46165 .18941 .46417 .19272 .4686 .19119 .46609 .18787 Metetra
.649 .719 .899 r
.46609 .18787 .4686 .19119 .47303 .18967 .47053 .18634 Metetra
.648 .718 .899 r
.47053 .18634 .47303 .18967 .47748 .18816 .47498 .18482 Metetra
.647 .717 .899 r
.47498 .18482 .47748 .18816 .48193 .18666 .47943 .18331 Metetra
.646 .716 .899 r
.47943 .18331 .48193 .18666 .48639 .18517 .48389 .1818 Metetra
.645 .715 .899 r
.48389 .1818 .48639 .18517 .49085 .18368 .48836 .1803 Metetra
.644 .714 .899 r
.48836 .1803 .49085 .18368 .49533 .1822 .49284 .17881 Metetra
.643 .713 .899 r
.49284 .17881 .49533 .1822 .49981 .18074 .49733 .17733 Metetra
.642 .712 .898 r
.49733 .17733 .49981 .18074 .5043 .17928 .50182 .17587 Metetra
.641 .711 .898 r
.50182 .17587 .5043 .17928 .5088 .17784 .50633 .17441 Metetra
.639 .71 .898 r
.50633 .17441 .5088 .17784 .5133 .17641 .51084 .17296 Metetra
.638 .708 .898 r
.51084 .17296 .5133 .17641 .51782 .175 .51535 .17153 Metetra
.636 .707 .898 r
.51535 .17153 .51782 .175 .52234 .1736 .51988 .17011 Metetra
.635 .705 .897 r
.51988 .17011 .52234 .1736 .52687 .17222 .52441 .16871 Metetra
.633 .703 .897 r
.52441 .16871 .52687 .17222 .53141 .17086 .52896 .16733 Metetra
.631 .701 .897 r
.52896 .16733 .53141 .17086 .53603 .18922 .53351 .16596 Metetra
0 0 .467 r
.53351 .16596 .53603 .18922 .54062 .18836 .53816 .1844 Metetra
.583 .654 .885 r
.53816 .1844 .54062 .18836 .54522 .18754 .54276 .18353 Metetra
.578 .648 .883 r
.54276 .18353 .54522 .18754 .54983 .18679 .54737 .18273 Metetra
.572 .642 .881 r
.54737 .18273 .54983 .18679 .55445 .18611 .55199 .18198 Metetra
.566 .636 .879 r
.55199 .18198 .55445 .18611 .55908 .1855 .55663 .1813 Metetra
.559 .628 .877 r
.55663 .1813 .55908 .1855 .56373 .18497 .56128 .1807 Metetra
.551 .62 .874 r
.56128 .1807 .56373 .18497 .56838 .18454 .56594 .18019 Metetra
.542 .611 .871 r
.56594 .18019 .56838 .18454 .57306 .18422 .57061 .17977 Metetra
.532 .6 .867 r
.57061 .17977 .57306 .18422 .57774 .18403 .57529 .17946 Metetra
.521 .588 .863 r
.57529 .17946 .57774 .18403 .58244 .18397 .57999 .17928 Metetra
.508 .575 .858 r
.57999 .17928 .58244 .18397 .58716 .18409 .58471 .17926 Metetra
.493 .559 .852 r
.58471 .17926 .58716 .18409 .5919 .1844 .58944 .1794 Metetra
.477 .542 .844 r
.58944 .1794 .5919 .1844 .59665 .18495 .5942 .17975 Metetra
.457 .521 .835 r
.5942 .17975 .59665 .18495 .60143 .18578 .59897 .18034 Metetra
.434 .497 .824 r
.59897 .18034 .60143 .18578 .60624 .18696 .60377 .18122 Metetra
.407 .468 .811 r
.60377 .18122 .60624 .18696 .61107 .18857 .60859 .18246 Metetra
.376 .435 .794 r
.60859 .18246 .61107 .18857 .61594 .19071 .61344 .18415 Metetra
.339 .395 .773 r
.61344 .18415 .61594 .19071 .62085 .19357 .61833 .18641 Metetra
.295 .348 .747 r
.61833 .18641 .62085 .19357 .62582 .19736 .62327 .18942 Metetra
.242 .292 .714 r
.62327 .18942 .62582 .19736 .63085 .20246 .62826 .19342 Metetra
.181 .226 .673 r
.62826 .19342 .63085 .20246 .63599 .20948 .63333 .19883 Metetra
.109 .149 .623 r
.63333 .19883 .63599 .20948 .64128 .21947 .63851 .2063 Metetra
.027 .063 .562 r
.63851 .2063 .64128 .21947 .64682 .23459 .64386 .21706 Metetra
0 0 .49 r
.64386 .21706 .64682 .23459 .65285 .26004 .64949 .23362 Metetra
0 0 .41 r
.64949 .23362 .65285 .26004 .66019 .31339 .65571 .26235 Metetra
0 0 .318 r
.65571 .26235 .66019 .31339 .66636 .33656 .66362 .32725 Metetra
.266 .287 .697 r
.66362 .32725 .66636 .33656 .66023 .09284 .66901 .33171 Metetra
0 0 .337 r
.66901 .33171 .66023 .09284 .66495 .09106 .66267 .08777 Metetra
.664 .741 .907 r
.66267 .08777 .66495 .09106 .66967 .08928 .66739 .08599 Metetra
.664 .741 .907 r
.66739 .08599 .66967 .08928 .6744 .0875 .67213 .0842 Metetra
.664 .741 .907 r
.67213 .0842 .6744 .0875 .67914 .08571 .67687 .0824 Metetra
.664 .741 .907 r
.67687 .0824 .67914 .08571 .68388 .08392 .68163 .08061 Metetra
.664 .741 .907 r
.68163 .08061 .68388 .08392 .68864 .08213 .68639 .07881 Metetra
.664 .741 .907 r
.68639 .07881 .68864 .08213 .6934 .08033 .69115 .07701 Metetra
.664 .741 .907 r
.69115 .07701 .6934 .08033 .69817 .07853 .69593 .0752 Metetra
.664 .741 .907 r
.69593 .0752 .69817 .07853 .70295 .07673 .70071 .0734 Metetra
.664 .741 .907 r
.70071 .0734 .70295 .07673 .70774 .07493 .70551 .07159 Metetra
.664 .741 .907 r
.70551 .07159 .70774 .07493 .71253 .07312 .71031 .06977 Metetra
.664 .741 .907 r
.71031 .06977 .71253 .07312 .71733 .07131 .71511 .06796 Metetra
.664 .741 .907 r
.71511 .06796 .71733 .07131 .72214 .06949 .71993 .06614 Metetra
.664 .741 .907 r
.71993 .06614 .72214 .06949 .72696 .06768 .72475 .06431 Metetra
.664 .741 .907 r
.72475 .06431 .72696 .06768 .73179 .06586 .72959 .06249 Metetra
.664 .741 .907 r
.08688 .30157 .08973 .30423 .09354 .30279 .0907 .30012 Metetra
.664 .741 .907 r
.0907 .30012 .09354 .30279 .09737 .30135 .09452 .29868 Metetra
.664 .741 .907 r
.09452 .29868 .09737 .30135 .10119 .2999 .09835 .29723 Metetra
.664 .741 .907 r
.09835 .29723 .10119 .2999 .10503 .29845 .10219 .29577 Metetra
.664 .741 .907 r
.10219 .29577 .10503 .29845 .10886 .297 .10603 .29432 Metetra
.664 .741 .907 r
.10603 .29432 .10886 .297 .11271 .29555 .10988 .29286 Metetra
.664 .741 .907 r
.10988 .29286 .11271 .29555 .11656 .2941 .11373 .29141 Metetra
.664 .741 .907 r
.11373 .29141 .11656 .2941 .12041 .29264 .11759 .28994 Metetra
.664 .741 .907 r
.11759 .28994 .12041 .29264 .12428 .29118 .12145 .28848 Metetra
.664 .741 .907 r
.12145 .28848 .12428 .29118 .12814 .28972 .12533 .28702 Metetra
.664 .741 .907 r
.12533 .28702 .12814 .28972 .13202 .28826 .1292 .28555 Metetra
.664 .741 .907 r
.1292 .28555 .13202 .28826 .1359 .28679 .13309 .28408 Metetra
.664 .741 .907 r
.13309 .28408 .1359 .28679 .13978 .28532 .13697 .28261 Metetra
.664 .741 .907 r
.13697 .28261 .13978 .28532 .14367 .28385 .14087 .28113 Metetra
.944 .681 .509 r
.14087 .28113 .14367 .28385 .11925 .51542 .1162 .51284 Metetra
.938 .702 .553 r
.1162 .51284 .11925 .51542 .12414 .50813 .12789 .44953 Metetra
.706 .464 .556 r
.12789 .44953 .12414 .50813 .13592 .44286 .13597 .41504 Metetra
.735 .505 .579 r
.13597 .41504 .13592 .44286 .14348 .41212 .14233 .39441 Metetra
.748 .532 .602 r
.14233 .39441 .14348 .41212 .14962 .39305 .14791 .38008 Metetra
.755 .554 .624 r
.14791 .38008 .14962 .39305 .15507 .37953 .15306 .36923 Metetra
.758 .572 .646 r
.15306 .36923 .15507 .37953 .16015 .36917 .15795 .36054 Metetra
.758 .588 .666 r
.15795 .36054 .16015 .36917 .16498 .36079 .16266 .3533 Metetra
.758 .602 .685 r
.16266 .3533 .16498 .36079 .16965 .35377 .16724 .34708 Metetra
.756 .615 .702 r
.16724 .34708 .16965 .35377 .17421 .34771 .17173 .34161 Metetra
.754 .626 .718 r
.17173 .34161 .17421 .34771 .17869 .34236 .17616 .33672 Metetra
.751 .636 .733 r
.17616 .33672 .17869 .34236 .1831 .33756 .18054 .33228 Metetra
.748 .645 .746 r
.18054 .33228 .1831 .33756 .18747 .33319 .18488 .3282 Metetra
.745 .653 .758 r
.18488 .3282 .18747 .33319 .19179 .32917 .18918 .32441 Metetra
.742 .66 .769 r
.18918 .32441 .19179 .32917 .19609 .32543 .19346 .32086 Metetra
.739 .666 .779 r
.19346 .32086 .19609 .32543 .20036 .32193 .19772 .31752 Metetra
.735 .671 .788 r
.19772 .31752 .20036 .32193 .20462 .31862 .20196 .31435 Metetra
.732 .676 .796 r
.20196 .31435 .20462 .31862 .20886 .31548 .20619 .31132 Metetra
.729 .681 .803 r
.20619 .31132 .20886 .31548 .21308 .31248 .21041 .30842 Metetra
.726 .685 .81 r
.21041 .30842 .21308 .31248 .2173 .30961 .21463 .30564 Metetra
.723 .688 .816 r
.21463 .30564 .2173 .30961 .22151 .30684 .21883 .30294 Metetra
.72 .691 .822 r
.21883 .30294 .22151 .30684 .22571 .30417 .22303 .30034 Metetra
.718 .694 .827 r
.22303 .30034 .22571 .30417 .22991 .30158 .22723 .29781 Metetra
.715 .697 .831 r
.22723 .29781 .22991 .30158 .23411 .29907 .23142 .29535 Metetra
.713 .699 .835 r
.23142 .29535 .23411 .29907 .2383 .29662 .23561 .29295 Metetra
.711 .701 .839 r
.23561 .29295 .2383 .29662 .24249 .29423 .23981 .2906 Metetra
.926 .716 .601 r
.23981 .2906 .24249 .29423 .24668 .2919 .24572 .26925 Metetra
.558 .37 .583 r
.24572 .26925 .24668 .2919 .25255 .27061 .24985 .26739 Metetra
.685 .721 .877 r
.24985 .26739 .25255 .27061 .25668 .26876 .25398 .26555 Metetra
.683 .722 .879 r
.25398 .26555 .25668 .26876 .26082 .26692 .25812 .26372 Metetra
.682 .722 .88 r
.25812 .26372 .26082 .26692 .26496 .26511 .26227 .26191 Metetra
.681 .723 .881 r
.26227 .26191 .26496 .26511 .26911 .2633 .26642 .26012 Metetra
.68 .723 .883 r
.26642 .26012 .26911 .2633 .27326 .26152 .27057 .25834 Metetra
.679 .724 .884 r
.27057 .25834 .27326 .26152 .27741 .25974 .27472 .25657 Metetra
.678 .724 .885 r
.27472 .25657 .27741 .25974 .28157 .25798 .27889 .25481 Metetra
.677 .725 .886 r
.27889 .25481 .28157 .25798 .28573 .25623 .28305 .25306 Metetra
.676 .725 .887 r
.28305 .25306 .28573 .25623 .2899 .25449 .28723 .25133 Metetra
.675 .725 .887 r
.28723 .25133 .2899 .25449 .29408 .25276 .2914 .2496 Metetra
.674 .726 .888 r
.2914 .2496 .29408 .25276 .29826 .25104 .29559 .24788 Metetra
.673 .726 .889 r
.29559 .24788 .29826 .25104 .30244 .24932 .29978 .24617 Metetra
.673 .726 .89 r
.29978 .24617 .30244 .24932 .30663 .24762 .30397 .24446 Metetra
.672 .726 .89 r
.30397 .24446 .30663 .24762 .31083 .24592 .30817 .24276 Metetra
.671 .726 .891 r
.30817 .24276 .31083 .24592 .31503 .24423 .31237 .24107 Metetra
.67 .727 .892 r
.31237 .24107 .31503 .24423 .31924 .24254 .31658 .23939 Metetra
.67 .727 .892 r
.31658 .23939 .31924 .24254 .32345 .24086 .3208 .23771 Metetra
.669 .727 .893 r
.3208 .23771 .32345 .24086 .32767 .23919 .32502 .23603 Metetra
.669 .727 .893 r
.32502 .23603 .32767 .23919 .33189 .23752 .32925 .23436 Metetra
.668 .727 .894 r
.32925 .23436 .33189 .23752 .33613 .23586 .33349 .2327 Metetra
.667 .727 .894 r
.33349 .2327 .33613 .23586 .34036 .2342 .33773 .23104 Metetra
.667 .727 .894 r
.33773 .23104 .34036 .2342 .34461 .23255 .34197 .22939 Metetra
.666 .727 .895 r
.34197 .22939 .34461 .23255 .34885 .2309 .34623 .22773 Metetra
.666 .727 .895 r
.34623 .22773 .34885 .2309 .35311 .22925 .35049 .22609 Metetra
.665 .727 .895 r
.35049 .22609 .35311 .22925 .35737 .22761 .35475 .22444 Metetra
.665 .727 .896 r
.35475 .22444 .35737 .22761 .36164 .22598 .35902 .2228 Metetra
.664 .727 .896 r
.35902 .2228 .36164 .22598 .36591 .22435 .3633 .22117 Metetra
.664 .727 .896 r
.3633 .22117 .36591 .22435 .3702 .22272 .36759 .21954 Metetra
.663 .727 .897 r
.36759 .21954 .3702 .22272 .37448 .22109 .37188 .21791 Metetra
.662 .726 .897 r
.37188 .21791 .37448 .22109 .37878 .21947 .37618 .21628 Metetra
.662 .726 .897 r
.37618 .21628 .37878 .21947 .38308 .21785 .38048 .21466 Metetra
.661 .726 .897 r
.38048 .21466 .38308 .21785 .38738 .21624 .38479 .21304 Metetra
.661 .726 .897 r
.38479 .21304 .38738 .21624 .3917 .21463 .38911 .21143 Metetra
.66 .726 .898 r
.38911 .21143 .3917 .21463 .39602 .21302 .39343 .20982 Metetra
.66 .726 .898 r
.39343 .20982 .39602 .21302 .40035 .21142 .39777 .20821 Metetra
.659 .725 .898 r
.39777 .20821 .40035 .21142 .40468 .20982 .4021 .2066 Metetra
.659 .725 .898 r
.4021 .2066 .40468 .20982 .40902 .20823 .40645 .205 Metetra
.658 .725 .898 r
.40645 .205 .40902 .20823 .41337 .20663 .4108 .20341 Metetra
.658 .725 .898 r
.4108 .20341 .41337 .20663 .41772 .20505 .41516 .20181 Metetra
.657 .724 .899 r
.41516 .20181 .41772 .20505 .42208 .20346 .41952 .20022 Metetra
.657 .724 .899 r
.41952 .20022 .42208 .20346 .42645 .20188 .4239 .19863 Metetra
.656 .724 .899 r
.4239 .19863 .42645 .20188 .43083 .20031 .42828 .19705 Metetra
.655 .723 .899 r
.42828 .19705 .43083 .20031 .43521 .19874 .43266 .19547 Metetra
.655 .723 .899 r
.43266 .19547 .43521 .19874 .4396 .19717 .43706 .1939 Metetra
.654 .722 .899 r
.43706 .1939 .4396 .19717 .444 .19561 .44146 .19233 Metetra
.653 .722 .899 r
.44146 .19233 .444 .19561 .4484 .19405 .44586 .19076 Metetra
.653 .722 .899 r
.44586 .19076 .4484 .19405 .45281 .1925 .45028 .1892 Metetra
.652 .721 .899 r
.45028 .1892 .45281 .1925 .45723 .19095 .4547 .18764 Metetra
.651 .72 .899 r
.4547 .18764 .45723 .19095 .46165 .18941 .45913 .18609 Metetra
.651 .72 .899 r
.45913 .18609 .46165 .18941 .46609 .18787 .46357 .18455 Metetra
.65 .719 .899 r
.46357 .18455 .46609 .18787 .47053 .18634 .46801 .18301 Metetra
.649 .719 .899 r
.46801 .18301 .47053 .18634 .47498 .18482 .47247 .18148 Metetra
.648 .718 .899 r
.47247 .18148 .47498 .18482 .47943 .18331 .47693 .17995 Metetra
.647 .717 .899 r
.47693 .17995 .47943 .18331 .48389 .1818 .48139 .17843 Metetra
.646 .716 .899 r
.48139 .17843 .48389 .1818 .48836 .1803 .48587 .17692 Metetra
.645 .715 .899 r
.48587 .17692 .48836 .1803 .49284 .17881 .49035 .17542 Metetra
.644 .714 .899 r
.49035 .17542 .49284 .17881 .49733 .17733 .49484 .17393 Metetra
.643 .713 .899 r
.49484 .17393 .49733 .17733 .50182 .17587 .49934 .17245 Metetra
.642 .712 .898 r
.49934 .17245 .50182 .17587 .50633 .17441 .50385 .17097 Metetra
.64 .711 .898 r
.50385 .17097 .50633 .17441 .51084 .17296 .50836 .16951 Metetra
.639 .71 .898 r
.50836 .16951 .51084 .17296 .51535 .17153 .51288 .16807 Metetra
.637 .708 .898 r
.51288 .16807 .51535 .17153 .51988 .17011 .51741 .16663 Metetra
.636 .707 .898 r
.51741 .16663 .51988 .17011 .52441 .16871 .52195 .16521 Metetra
.634 .705 .897 r
.52195 .16521 .52441 .16871 .52896 .16733 .5265 .16381 Metetra
.632 .703 .897 r
.5265 .16381 .52896 .16733 .53351 .16596 .53105 .16242 Metetra
.63 .701 .897 r
.53105 .16242 .53351 .16596 .53816 .1844 .53562 .16105 Metetra
0 0 .466 r
.53562 .16105 .53816 .1844 .54276 .18353 .54029 .17955 Metetra
.582 .653 .885 r
.54029 .17955 .54276 .18353 .54737 .18273 .54491 .17869 Metetra
.577 .647 .883 r
.54491 .17869 .54737 .18273 .55199 .18198 .54953 .17789 Metetra
.571 .641 .881 r
.54953 .17789 .55199 .18198 .55663 .1813 .55417 .17715 Metetra
.565 .634 .879 r
.55417 .17715 .55663 .1813 .56128 .1807 .55882 .17648 Metetra
.557 .627 .876 r
.55882 .17648 .56128 .1807 .56594 .18019 .56348 .17588 Metetra
.549 .618 .874 r
.56348 .17588 .56594 .18019 .57061 .17977 .56815 .17538 Metetra
.54 .609 .87 r
.56815 .17538 .57061 .17977 .57529 .17946 .57284 .17497 Metetra
.53 .598 .867 r
.57284 .17497 .57529 .17946 .57999 .17928 .57754 .17468 Metetra
.519 .586 .862 r
.57754 .17468 .57999 .17928 .58471 .17926 .58226 .17452 Metetra
.506 .572 .857 r
.58226 .17452 .58471 .17926 .58944 .1794 .58699 .17452 Metetra
.491 .556 .85 r
.58699 .17452 .58944 .1794 .5942 .17975 .59174 .17469 Metetra
.473 .538 .843 r
.59174 .17469 .5942 .17975 .59897 .18034 .59651 .17507 Metetra
.453 .517 .833 r
.59651 .17507 .59897 .18034 .60377 .18122 .6013 .1757 Metetra
.43 .492 .822 r
.6013 .1757 .60377 .18122 .60859 .18246 .60611 .17664 Metetra
.402 .462 .808 r
.60611 .17664 .60859 .18246 .61344 .18415 .61095 .17795 Metetra
.37 .428 .79 r
.61095 .17795 .61344 .18415 .61833 .18641 .61583 .17973 Metetra
.332 .387 .769 r
.61583 .17973 .61833 .18641 .62327 .18942 .62074 .1821 Metetra
.286 .338 .741 r
.62074 .1821 .62327 .18942 .62826 .19342 .6257 .18526 Metetra
.233 .28 .707 r
.6257 .18526 .62826 .19342 .63333 .19883 .63072 .18949 Metetra
.169 .213 .664 r
.63072 .18949 .63333 .19883 .63851 .2063 .63582 .19521 Metetra
.096 .135 .612 r
.63582 .19521 .63851 .2063 .64386 .21706 .64105 .20318 Metetra
.013 .046 .549 r
.64105 .20318 .64386 .21706 .64949 .23362 .64645 .21478 Metetra
0 0 .476 r
.64645 .21478 .64949 .23362 .65571 .26235 .65219 .23296 Metetra
0 0 .395 r
.65219 .23296 .65571 .26235 .66362 .32725 .65863 .26562 Metetra
0 0 .382 r
.65863 .26562 .66362 .32725 .66901 .33171 .66654 .32854 Metetra
.978 .681 .358 r
.66654 .32854 .66901 .33171 .66267 .08777 .66038 .08447 Metetra
.664 .741 .907 r
.66038 .08447 .66267 .08777 .66739 .08599 .66511 .08268 Metetra
.664 .741 .907 r
.66511 .08268 .66739 .08599 .67213 .0842 .66985 .08088 Metetra
.664 .741 .907 r
.66985 .08088 .67213 .0842 .67687 .0824 .6746 .07909 Metetra
.664 .741 .907 r
.6746 .07909 .67687 .0824 .68163 .08061 .67936 .07729 Metetra
.664 .741 .907 r
.67936 .07729 .68163 .08061 .68639 .07881 .68413 .07548 Metetra
.664 .741 .907 r
.68413 .07548 .68639 .07881 .69115 .07701 .6889 .07367 Metetra
.664 .741 .907 r
.6889 .07367 .69115 .07701 .69593 .0752 .69368 .07186 Metetra
.664 .741 .907 r
.69368 .07186 .69593 .0752 .70071 .0734 .69847 .07005 Metetra
.664 .741 .907 r
.69847 .07005 .70071 .0734 .70551 .07159 .70327 .06824 Metetra
.664 .741 .907 r
.70327 .06824 .70551 .07159 .71031 .06977 .70807 .06642 Metetra
.664 .741 .907 r
.70807 .06642 .71031 .06977 .71511 .06796 .71289 .06459 Metetra
.664 .741 .907 r
.71289 .06459 .71511 .06796 .71993 .06614 .71771 .06277 Metetra
.664 .741 .907 r
.71771 .06277 .71993 .06614 .72475 .06431 .72254 .06094 Metetra
.664 .741 .907 r
.72254 .06094 .72475 .06431 .72959 .06249 .72738 .05911 Metetra
.664 .741 .907 r
.08402 .2989 .08688 .30157 .0907 .30012 .08784 .29745 Metetra
.664 .741 .907 r
.08784 .29745 .0907 .30012 .09452 .29868 .09167 .296 Metetra
.664 .741 .907 r
.09167 .296 .09452 .29868 .09835 .29723 .0955 .29454 Metetra
.664 .741 .907 r
.0955 .29454 .09835 .29723 .10219 .29577 .09934 .29309 Metetra
.664 .741 .907 r
.09934 .29309 .10219 .29577 .10603 .29432 .10319 .29163 Metetra
.664 .741 .907 r
.10319 .29163 .10603 .29432 .10988 .29286 .10704 .29017 Metetra
.664 .741 .907 r
.10704 .29017 .10988 .29286 .11373 .29141 .11089 .28871 Metetra
.664 .741 .907 r
.11089 .28871 .11373 .29141 .11759 .28994 .11476 .28724 Metetra
.664 .741 .907 r
.11476 .28724 .11759 .28994 .12145 .28848 .11862 .28577 Metetra
.664 .741 .907 r
.11862 .28577 .12145 .28848 .12533 .28702 .1225 .2843 Metetra
.664 .741 .907 r
.1225 .2843 .12533 .28702 .1292 .28555 .12638 .28283 Metetra
.664 .741 .907 r
.12638 .28283 .1292 .28555 .13309 .28408 .13026 .28136 Metetra
.664 .741 .907 r
.13026 .28136 .13309 .28408 .13697 .28261 .13416 .27988 Metetra
.943 .681 .51 r
.13416 .27988 .13697 .28261 .14087 .28113 .10896 .51166 Metetra
.371 .152 .446 r
.10896 .51166 .14087 .28113 .1162 .51284 .11967 .45737 Metetra
.727 .483 .558 r
.11967 .45737 .1162 .51284 .12789 .44953 .12839 .41832 Metetra
.731 .498 .575 r
.12839 .41832 .12789 .44953 .13597 .41504 .13501 .39592 Metetra
.746 .527 .598 r
.13501 .39592 .13597 .41504 .14233 .39441 .14073 .38071 Metetra
.753 .549 .62 r
.14073 .38071 .14233 .39441 .14791 .38008 .14596 .36934 Metetra
.757 .568 .642 r
.14596 .36934 .14791 .38008 .15306 .36923 .1509 .36032 Metetra
.758 .585 .662 r
.1509 .36032 .15306 .36923 .15795 .36054 .15564 .35285 Metetra
.758 .599 .681 r
.15564 .35285 .15795 .36054 .16266 .3533 .16025 .34646 Metetra
.756 .612 .699 r
.16025 .34646 .16266 .3533 .16724 .34708 .16477 .34087 Metetra
.754 .624 .715 r
.16477 .34087 .16724 .34708 .17173 .34161 .16921 .33589 Metetra
.752 .634 .73 r
.16921 .33589 .17173 .34161 .17616 .33672 .1736 .33137 Metetra
.749 .643 .744 r
.1736 .33137 .17616 .33672 .18054 .33228 .17795 .32722 Metetra
.745 .651 .756 r
.17795 .32722 .18054 .33228 .18488 .3282 .18226 .32338 Metetra
.742 .658 .767 r
.18226 .32338 .18488 .3282 .18918 .32441 .18655 .31979 Metetra
.739 .665 .777 r
.18655 .31979 .18918 .32441 .19346 .32086 .19081 .31641 Metetra
.736 .67 .786 r
.19081 .31641 .19346 .32086 .19772 .31752 .19506 .31321 Metetra
.733 .675 .794 r
.19506 .31321 .19772 .31752 .20196 .31435 .19929 .31016 Metetra
.73 .68 .802 r
.19929 .31016 .20196 .31435 .20619 .31132 .20352 .30724 Metetra
.727 .684 .809 r
.20352 .30724 .20619 .31132 .21041 .30842 .20773 .30443 Metetra
.724 .687 .815 r
.20773 .30443 .21041 .30842 .21463 .30564 .21194 .30172 Metetra
.721 .691 .821 r
.21194 .30172 .21463 .30564 .21883 .30294 .21614 .2991 Metetra
.718 .694 .826 r
.21614 .2991 .21883 .30294 .22303 .30034 .22034 .29655 Metetra
.716 .696 .83 r
.22034 .29655 .22303 .30034 .22723 .29781 .22453 .29407 Metetra
.713 .699 .835 r
.22453 .29407 .22723 .29781 .23142 .29535 .22872 .29166 Metetra
.925 .715 .599 r
.22872 .29166 .23142 .29535 .23561 .29295 .23475 .26978 Metetra
.557 .368 .581 r
.23475 .26978 .23561 .29295 .23981 .2906 .23887 .26789 Metetra
.557 .369 .582 r
.23887 .26789 .23981 .2906 .24572 .26925 .24301 .26602 Metetra
.685 .721 .877 r
.24301 .26602 .24572 .26925 .24985 .26739 .24714 .26417 Metetra
.684 .722 .878 r
.24714 .26417 .24985 .26739 .25398 .26555 .25128 .26234 Metetra
.682 .722 .88 r
.25128 .26234 .25398 .26555 .25812 .26372 .25542 .26052 Metetra
.681 .723 .881 r
.25542 .26052 .25812 .26372 .26227 .26191 .25957 .25872 Metetra
.68 .723 .882 r
.25957 .25872 .26227 .26191 .26642 .26012 .26372 .25693 Metetra
.679 .724 .884 r
.26372 .25693 .26642 .26012 .27057 .25834 .26787 .25516 Metetra
.678 .724 .885 r
.26787 .25516 .27057 .25834 .27472 .25657 .27203 .25339 Metetra
.677 .725 .886 r
.27203 .25339 .27472 .25657 .27889 .25481 .2762 .25164 Metetra
.676 .725 .886 r
.2762 .25164 .27889 .25481 .28305 .25306 .28037 .2499 Metetra
.675 .725 .887 r
.28037 .2499 .28305 .25306 .28723 .25133 .28454 .24816 Metetra
.674 .726 .888 r
.28454 .24816 .28723 .25133 .2914 .2496 .28872 .24644 Metetra
.674 .726 .889 r
.28872 .24644 .2914 .2496 .29559 .24788 .29291 .24472 Metetra
.673 .726 .89 r
.29291 .24472 .29559 .24788 .29978 .24617 .2971 .24301 Metetra
.672 .726 .89 r
.2971 .24301 .29978 .24617 .30397 .24446 .3013 .24131 Metetra
.671 .727 .891 r
.3013 .24131 .30397 .24446 .30817 .24276 .3055 .23961 Metetra
.671 .727 .891 r
.3055 .23961 .30817 .24276 .31237 .24107 .30971 .23792 Metetra
.67 .727 .892 r
.30971 .23792 .31237 .24107 .31658 .23939 .31392 .23623 Metetra
.67 .727 .893 r
.31392 .23623 .31658 .23939 .3208 .23771 .31814 .23455 Metetra
.669 .727 .893 r
.31814 .23455 .3208 .23771 .32502 .23603 .32237 .23288 Metetra
.668 .727 .893 r
.32237 .23288 .32502 .23603 .32925 .23436 .3266 .2312 Metetra
.668 .727 .894 r
.3266 .2312 .32925 .23436 .33349 .2327 .33084 .22954 Metetra
.667 .727 .894 r
.33084 .22954 .33349 .2327 .33773 .23104 .33509 .22788 Metetra
.667 .727 .895 r
.33509 .22788 .33773 .23104 .34197 .22939 .33934 .22622 Metetra
.666 .727 .895 r
.33934 .22622 .34197 .22939 .34623 .22773 .34359 .22457 Metetra
.666 .727 .895 r
.34359 .22457 .34623 .22773 .35049 .22609 .34786 .22292 Metetra
.665 .727 .896 r
.34786 .22292 .35049 .22609 .35475 .22444 .35213 .22127 Metetra
.664 .727 .896 r
.35213 .22127 .35475 .22444 .35902 .2228 .3564 .21963 Metetra
.664 .727 .896 r
.3564 .21963 .35902 .2228 .3633 .22117 .36068 .21799 Metetra
.663 .727 .897 r
.36068 .21799 .3633 .22117 .36759 .21954 .36497 .21635 Metetra
.663 .727 .897 r
.36497 .21635 .36759 .21954 .37188 .21791 .36927 .21472 Metetra
.662 .727 .897 r
.36927 .21472 .37188 .21791 .37618 .21628 .37357 .21309 Metetra
.662 .727 .897 r
.37357 .21309 .37618 .21628 .38048 .21466 .37788 .21146 Metetra
.661 .726 .897 r
.37788 .21146 .38048 .21466 .38479 .21304 .38219 .20984 Metetra
.661 .726 .898 r
.38219 .20984 .38479 .21304 .38911 .21143 .38651 .20822 Metetra
.66 .726 .898 r
.38651 .20822 .38911 .21143 .39343 .20982 .39084 .20661 Metetra
.66 .726 .898 r
.39084 .20661 .39343 .20982 .39777 .20821 .39518 .20499 Metetra
.659 .726 .898 r
.39518 .20499 .39777 .20821 .4021 .2066 .39952 .20338 Metetra
.659 .725 .898 r
.39952 .20338 .4021 .2066 .40645 .205 .40387 .20177 Metetra
.658 .725 .898 r
.40387 .20177 .40645 .205 .4108 .20341 .40822 .20017 Metetra
.658 .725 .899 r
.40822 .20017 .4108 .20341 .41516 .20181 .41259 .19857 Metetra
.657 .725 .899 r
.41259 .19857 .41516 .20181 .41952 .20022 .41696 .19697 Metetra
.657 .724 .899 r
.41696 .19697 .41952 .20022 .4239 .19863 .42133 .19538 Metetra
.656 .724 .899 r
.42133 .19538 .4239 .19863 .42828 .19705 .42572 .19379 Metetra
.656 .724 .899 r
.42572 .19379 .42828 .19705 .43266 .19547 .43011 .1922 Metetra
.655 .723 .899 r
.43011 .1922 .43266 .19547 .43706 .1939 .43451 .19062 Metetra
.654 .723 .899 r
.43451 .19062 .43706 .1939 .44146 .19233 .43891 .18904 Metetra
.654 .722 .899 r
.43891 .18904 .44146 .19233 .44586 .19076 .44332 .18747 Metetra
.653 .722 .899 r
.44332 .18747 .44586 .19076 .45028 .1892 .44774 .1859 Metetra
.652 .722 .899 r
.44774 .1859 .45028 .1892 .4547 .18764 .45217 .18434 Metetra
.652 .721 .899 r
.45217 .18434 .4547 .18764 .45913 .18609 .4566 .18278 Metetra
.651 .72 .899 r
.4566 .18278 .45913 .18609 .46357 .18455 .46104 .18122 Metetra
.65 .72 .899 r
.46104 .18122 .46357 .18455 .46801 .18301 .46549 .17967 Metetra
.649 .719 .899 r
.46549 .17967 .46801 .18301 .47247 .18148 .46995 .17813 Metetra
.649 .718 .899 r
.46995 .17813 .47247 .18148 .47693 .17995 .47441 .1766 Metetra
.648 .718 .899 r
.47441 .1766 .47693 .17995 .48139 .17843 .47889 .17507 Metetra
.647 .717 .899 r
.47889 .17507 .48139 .17843 .48587 .17692 .48336 .17354 Metetra
.646 .716 .899 r
.48336 .17354 .48587 .17692 .49035 .17542 .48785 .17203 Metetra
.645 .715 .899 r
.48785 .17203 .49035 .17542 .49484 .17393 .49235 .17052 Metetra
.644 .714 .899 r
.49235 .17052 .49484 .17393 .49934 .17245 .49685 .16903 Metetra
.643 .713 .899 r
.49685 .16903 .49934 .17245 .50385 .17097 .50136 .16754 Metetra
.641 .712 .899 r
.50136 .16754 .50385 .17097 .50836 .16951 .50588 .16606 Metetra
.64 .711 .898 r
.50588 .16606 .50836 .16951 .51288 .16807 .5104 .1646 Metetra
.639 .709 .898 r
.5104 .1646 .51288 .16807 .51741 .16663 .51494 .16315 Metetra
.637 .708 .898 r
.51494 .16315 .51741 .16663 .52195 .16521 .51948 .16171 Metetra
.635 .706 .898 r
.51948 .16171 .52195 .16521 .5265 .16381 .52403 .16029 Metetra
.634 .705 .897 r
.52403 .16029 .5265 .16381 .53105 .16242 .52859 .15888 Metetra
.632 .703 .897 r
.52859 .15888 .53105 .16242 .53562 .16105 .53316 .15749 Metetra
.63 .701 .897 r
.53316 .15749 .53562 .16105 .54029 .17955 .53774 .15612 Metetra
.544 .36 .581 r
.53774 .15612 .54029 .17955 .54491 .17869 .54232 .15477 Metetra
0 0 .464 r
.54232 .15477 .54491 .17869 .54953 .17789 .54707 .17383 Metetra
.576 .646 .883 r
.54707 .17383 .54953 .17789 .55417 .17715 .55171 .17303 Metetra
.57 .64 .881 r
.55171 .17303 .55417 .17715 .55882 .17648 .55636 .17229 Metetra
.563 .633 .878 r
.55636 .17229 .55882 .17648 .56348 .17588 .56102 .17163 Metetra
.556 .625 .876 r
.56102 .17163 .56348 .17588 .56815 .17538 .5657 .17104 Metetra
.548 .617 .873 r
.5657 .17104 .56815 .17538 .57284 .17497 .57038 .17055 Metetra
.539 .607 .87 r
.57038 .17055 .57284 .17497 .57754 .17468 .57509 .17015 Metetra
.528 .596 .866 r
.57509 .17015 .57754 .17468 .58226 .17452 .5798 .16988 Metetra
.517 .584 .861 r
.5798 .16988 .58226 .17452 .58699 .17452 .58453 .16974 Metetra
.503 .569 .855 r
.58453 .16974 .58699 .17452 .59174 .17469 .58928 .16975 Metetra
.488 .553 .849 r
.58928 .16975 .59174 .17469 .59651 .17507 .59405 .16995 Metetra
.47 .534 .841 r
.59405 .16995 .59651 .17507 .6013 .1757 .59883 .17037 Metetra
.45 .512 .831 r
.59883 .17037 .6013 .1757 .60611 .17664 .60364 .17105 Metetra
.426 .487 .819 r
.60364 .17105 .60611 .17664 .61095 .17795 .60847 .17204 Metetra
.397 .456 .805 r
.60847 .17204 .61095 .17795 .61583 .17973 .61333 .17342 Metetra
.364 .421 .786 r
.61333 .17342 .61583 .17973 .62074 .1821 .61822 .17529 Metetra
.325 .378 .764 r
.61822 .17529 .62074 .1821 .6257 .18526 .62316 .17778 Metetra
.278 .328 .735 r
.62316 .17778 .6257 .18526 .63072 .18949 .62814 .1811 Metetra
.223 .269 .7 r
.62814 .1811 .63072 .18949 .63582 .19521 .63319 .18556 Metetra
.158 .2 .655 r
.63319 .18556 .63582 .19521 .64105 .20318 .63833 .19162 Metetra
.084 .12 .601 r
.63833 .19162 .64105 .20318 .64645 .21478 .6436 .20013 Metetra
0 .03 .537 r
.6436 .20013 .64645 .21478 .65219 .23296 .64908 .21265 Metetra
0 0 .462 r
.64908 .21265 .65219 .23296 .65863 .26562 .65493 .23266 Metetra
0 0 .38 r
.65493 .23266 .65863 .26562 .66654 .32854 .66163 .2701 Metetra
0 0 .411 r
.66163 .2701 .66654 .32854 .66038 .08447 .66921 .32365 Metetra
0 0 .335 r
.66921 .32365 .66038 .08447 .66511 .08268 .66282 .07936 Metetra
.664 .741 .907 r
.66282 .07936 .66511 .08268 .66985 .08088 .66757 .07756 Metetra
.664 .741 .907 r
.66757 .07756 .66985 .08088 .6746 .07909 .67233 .07576 Metetra
.664 .741 .907 r
.67233 .07576 .6746 .07909 .67936 .07729 .67709 .07395 Metetra
.664 .741 .907 r
.67709 .07395 .67936 .07729 .68413 .07548 .68186 .07214 Metetra
.664 .741 .907 r
.68186 .07214 .68413 .07548 .6889 .07367 .68664 .07033 Metetra
.664 .741 .907 r
.68664 .07033 .6889 .07367 .69368 .07186 .69143 .06852 Metetra
.664 .741 .907 r
.69143 .06852 .69368 .07186 .69847 .07005 .69622 .0667 Metetra
.664 .741 .907 r
.69622 .0667 .69847 .07005 .70327 .06824 .70102 .06487 Metetra
.664 .741 .907 r
.70102 .06487 .70327 .06824 .70807 .06642 .70583 .06305 Metetra
.664 .741 .907 r
.70583 .06305 .70807 .06642 .71289 .06459 .71065 .06122 Metetra
.664 .741 .907 r
.71065 .06122 .71289 .06459 .71771 .06277 .71548 .05939 Metetra
.664 .741 .907 r
.71548 .05939 .71771 .06277 .72254 .06094 .72032 .05756 Metetra
.664 .741 .907 r
.72032 .05756 .72254 .06094 .72738 .05911 .72516 .05572 Metetra
.664 .741 .907 r
.08115 .29622 .08402 .2989 .08784 .29745 .08498 .29477 Metetra
.664 .741 .907 r
.08498 .29477 .08784 .29745 .09167 .296 .08881 .29331 Metetra
.664 .741 .907 r
.08881 .29331 .09167 .296 .0955 .29454 .09264 .29185 Metetra
.664 .741 .907 r
.09264 .29185 .0955 .29454 .09934 .29309 .09649 .29039 Metetra
.664 .741 .907 r
.09649 .29039 .09934 .29309 .10319 .29163 .10033 .28893 Metetra
.664 .741 .907 r
.10033 .28893 .10319 .29163 .10704 .29017 .10419 .28747 Metetra
.664 .741 .907 r
.10419 .28747 .10704 .29017 .11089 .28871 .10805 .286 Metetra
.664 .741 .907 r
.10805 .286 .11089 .28871 .11476 .28724 .11191 .28453 Metetra
.664 .741 .907 r
.11191 .28453 .11476 .28724 .11862 .28577 .11579 .28306 Metetra
.664 .741 .907 r
.11579 .28306 .11862 .28577 .1225 .2843 .11966 .28159 Metetra
.664 .741 .907 r
.11966 .28159 .1225 .2843 .12638 .28283 .12355 .28011 Metetra
.664 .741 .907 r
.12355 .28011 .12638 .28283 .13026 .28136 .12744 .27863 Metetra
.943 .681 .511 r
.12744 .27863 .13026 .28136 .13416 .27988 .10171 .51047 Metetra
.401 .176 .454 r
.10171 .51047 .13416 .27988 .10896 .51166 .11121 .46669 Metetra
.768 .523 .563 r
.11121 .46669 .10896 .51166 .11967 .45737 .12073 .42202 Metetra
.726 .49 .57 r
.12073 .42202 .11967 .45737 .12839 .41832 .12764 .39761 Metetra
.743 .521 .593 r
.12764 .39761 .12839 .41832 .13501 .39592 .13351 .38142 Metetra
.752 .545 .616 r
.13351 .38142 .13501 .39592 .14073 .38071 .13883 .3695 Metetra
.756 .564 .637 r
.13883 .3695 .14073 .38071 .14596 .36934 .14383 .36013 Metetra
.758 .581 .658 r
.14383 .36013 .14596 .36934 .1509 .36032 .14861 .35242 Metetra
.757 .596 .678 r
.14861 .35242 .1509 .36032 .15564 .35285 .15325 .34586 Metetra
.756 .61 .696 r
.15325 .34586 .15564 .35285 .16025 .34646 .15779 .34014 Metetra
.754 .622 .712 r
.15779 .34014 .16025 .34646 .16477 .34087 .16225 .33505 Metetra
.752 .632 .727 r
.16225 .33505 .16477 .34087 .16921 .33589 .16665 .33046 Metetra
.749 .641 .741 r
.16665 .33046 .16921 .33589 .1736 .33137 .17101 .32625 Metetra
.746 .649 .754 r
.17101 .32625 .1736 .33137 .17795 .32722 .17533 .32236 Metetra
.743 .657 .765 r
.17533 .32236 .17795 .32722 .18226 .32338 .17962 .31873 Metetra
.739 .663 .775 r
.17962 .31873 .18226 .32338 .18655 .31979 .1839 .31531 Metetra
.736 .669 .785 r
.1839 .31531 .18655 .31979 .19081 .31641 .18815 .31208 Metetra
.733 .674 .793 r
.18815 .31208 .19081 .31641 .19506 .31321 .19239 .309 Metetra
.73 .679 .801 r
.19239 .309 .19506 .31321 .19929 .31016 .19661 .30605 Metetra
.727 .683 .807 r
.19661 .30605 .19929 .31016 .20352 .30724 .20083 .30322 Metetra
.724 .687 .814 r
.20083 .30322 .20352 .30724 .20773 .30443 .20504 .30049 Metetra
.721 .69 .819 r
.20504 .30049 .20773 .30443 .21194 .30172 .20924 .29785 Metetra
.719 .693 .825 r
.20924 .29785 .21194 .30172 .21614 .2991 .21344 .29529 Metetra
.716 .696 .83 r
.21344 .29529 .21614 .2991 .22034 .29655 .21763 .2928 Metetra
.714 .698 .834 r
.21763 .2928 .22034 .29655 .22453 .29407 .22183 .29037 Metetra
.925 .714 .6 r
.22183 .29037 .22453 .29407 .22872 .29166 .2279 .26842 Metetra
.556 .367 .58 r
.2279 .26842 .22872 .29166 .23475 .26978 .23202 .26652 Metetra
.687 .72 .875 r
.23202 .26652 .23475 .26978 .23887 .26789 .23615 .26465 Metetra
.685 .721 .876 r
.23615 .26465 .23887 .26789 .24301 .26602 .24029 .26279 Metetra
.684 .722 .878 r
.24029 .26279 .24301 .26602 .24714 .26417 .24442 .26095 Metetra
.683 .722 .88 r
.24442 .26095 .24714 .26417 .25128 .26234 .24856 .25913 Metetra
.681 .723 .881 r
.24856 .25913 .25128 .26234 .25542 .26052 .25271 .25732 Metetra
.68 .723 .882 r
.25271 .25732 .25542 .26052 .25957 .25872 .25686 .25553 Metetra
.679 .724 .883 r
.25686 .25553 .25957 .25872 .26372 .25693 .26101 .25375 Metetra
.678 .724 .884 r
.26101 .25375 .26372 .25693 .26787 .25516 .26517 .25198 Metetra
.677 .725 .885 r
.26517 .25198 .26787 .25516 .27203 .25339 .26933 .25022 Metetra
.676 .725 .886 r
.26933 .25022 .27203 .25339 .2762 .25164 .2735 .24847 Metetra
.676 .725 .887 r
.2735 .24847 .2762 .25164 .28037 .2499 .27767 .24673 Metetra
.675 .726 .888 r
.27767 .24673 .28037 .2499 .28454 .24816 .28185 .245 Metetra
.674 .726 .889 r
.28185 .245 .28454 .24816 .28872 .24644 .28603 .24328 Metetra
.673 .726 .889 r
.28603 .24328 .28872 .24644 .29291 .24472 .29022 .24156 Metetra
.672 .726 .89 r
.29022 .24156 .29291 .24472 .2971 .24301 .29442 .23985 Metetra
.672 .727 .891 r
.29442 .23985 .2971 .24301 .3013 .24131 .29862 .23815 Metetra
.671 .727 .891 r
.29862 .23815 .3013 .24131 .3055 .23961 .30283 .23645 Metetra
.67 .727 .892 r
.30283 .23645 .3055 .23961 .30971 .23792 .30704 .23476 Metetra
.67 .727 .892 r
.30704 .23476 .30971 .23792 .31392 .23623 .31126 .23307 Metetra
.669 .727 .893 r
.31126 .23307 .31392 .23623 .31814 .23455 .31548 .23139 Metetra
.669 .727 .893 r
.31548 .23139 .31814 .23455 .32237 .23288 .31971 .22971 Metetra
.668 .727 .894 r
.31971 .22971 .32237 .23288 .3266 .2312 .32395 .22804 Metetra
.668 .727 .894 r
.32395 .22804 .3266 .2312 .33084 .22954 .32819 .22637 Metetra
.667 .727 .895 r
.32819 .22637 .33084 .22954 .33509 .22788 .33244 .22471 Metetra
.666 .727 .895 r
.33244 .22471 .33509 .22788 .33934 .22622 .33669 .22305 Metetra
.666 .727 .895 r
.33669 .22305 .33934 .22622 .34359 .22457 .34095 .22139 Metetra
.665 .727 .896 r
.34095 .22139 .34359 .22457 .34786 .22292 .34522 .21974 Metetra
.665 .727 .896 r
.34522 .21974 .34786 .22292 .35213 .22127 .34949 .21809 Metetra
.664 .727 .896 r
.34949 .21809 .35213 .22127 .3564 .21963 .35377 .21645 Metetra
.664 .727 .897 r
.35377 .21645 .3564 .21963 .36068 .21799 .35806 .2148 Metetra
.663 .727 .897 r
.35806 .2148 .36068 .21799 .36497 .21635 .36235 .21316 Metetra
.663 .727 .897 r
.36235 .21316 .36497 .21635 .36927 .21472 .36665 .21153 Metetra
.662 .727 .897 r
.36665 .21153 .36927 .21472 .37357 .21309 .37095 .20989 Metetra
.662 .727 .897 r
.37095 .20989 .37357 .21309 .37788 .21146 .37527 .20826 Metetra
.661 .727 .898 r
.37527 .20826 .37788 .21146 .38219 .20984 .37959 .20663 Metetra
.661 .727 .898 r
.37959 .20663 .38219 .20984 .38651 .20822 .38391 .20501 Metetra
.66 .726 .898 r
.38391 .20501 .38651 .20822 .39084 .20661 .38824 .20339 Metetra
.66 .726 .898 r
.38824 .20339 .39084 .20661 .39518 .20499 .39258 .20177 Metetra
.659 .726 .898 r
.39258 .20177 .39518 .20499 .39952 .20338 .39693 .20015 Metetra
.659 .726 .899 r
.39693 .20015 .39952 .20338 .40387 .20177 .40128 .19854 Metetra
.658 .726 .899 r
.40128 .19854 .40387 .20177 .40822 .20017 .40564 .19693 Metetra
.658 .725 .899 r
.40564 .19693 .40822 .20017 .41259 .19857 .41001 .19532 Metetra
.657 .725 .899 r
.41001 .19532 .41259 .19857 .41696 .19697 .41438 .19372 Metetra
.657 .725 .899 r
.41438 .19372 .41696 .19697 .42133 .19538 .41876 .19212 Metetra
.656 .724 .899 r
.41876 .19212 .42133 .19538 .42572 .19379 .42315 .19052 Metetra
.656 .724 .899 r
.42315 .19052 .42572 .19379 .43011 .1922 .42755 .18893 Metetra
.655 .724 .899 r
.42755 .18893 .43011 .1922 .43451 .19062 .43195 .18734 Metetra
.655 .723 .899 r
.43195 .18734 .43451 .19062 .43891 .18904 .43636 .18576 Metetra
.654 .723 .899 r
.43636 .18576 .43891 .18904 .44332 .18747 .44077 .18417 Metetra
.653 .722 .899 r
.44077 .18417 .44332 .18747 .44774 .1859 .4452 .1826 Metetra
.653 .722 .899 r
.4452 .1826 .44774 .1859 .45217 .18434 .44963 .18102 Metetra
.652 .721 .899 r
.44963 .18102 .45217 .18434 .4566 .18278 .45407 .17945 Metetra
.651 .721 .9 r
.45407 .17945 .4566 .18278 .46104 .18122 .45851 .17789 Metetra
.651 .72 .899 r
.45851 .17789 .46104 .18122 .46549 .17967 .46297 .17633 Metetra
.65 .72 .899 r
.46297 .17633 .46549 .17967 .46995 .17813 .46743 .17478 Metetra
.649 .719 .899 r
.46743 .17478 .46995 .17813 .47441 .1766 .47189 .17323 Metetra
.648 .718 .899 r
.47189 .17323 .47441 .1766 .47889 .17507 .47637 .17169 Metetra
.647 .718 .899 r
.47637 .17169 .47889 .17507 .48336 .17354 .48085 .17016 Metetra
.646 .717 .899 r
.48085 .17016 .48336 .17354 .48785 .17203 .48535 .16863 Metetra
.645 .716 .899 r
.48535 .16863 .48785 .17203 .49235 .17052 .48984 .16712 Metetra
.644 .715 .899 r
.48984 .16712 .49235 .17052 .49685 .16903 .49435 .16561 Metetra
.643 .714 .899 r
.49435 .16561 .49685 .16903 .50136 .16754 .49887 .16411 Metetra
.642 .713 .899 r
.49887 .16411 .50136 .16754 .50588 .16606 .50339 .16262 Metetra
.641 .712 .899 r
.50339 .16262 .50588 .16606 .5104 .1646 .50792 .16114 Metetra
.64 .71 .898 r
.50792 .16114 .5104 .1646 .51494 .16315 .51246 .15967 Metetra
.638 .709 .898 r
.51246 .15967 .51494 .16315 .51948 .16171 .517 .15821 Metetra
.637 .708 .898 r
.517 .15821 .51948 .16171 .52403 .16029 .52156 .15677 Metetra
.635 .706 .898 r
.52156 .15677 .52403 .16029 .52859 .15888 .52612 .15534 Metetra
.633 .704 .897 r
.52612 .15534 .52859 .15888 .53316 .15749 .5307 .15393 Metetra
.631 .702 .897 r
.5307 .15393 .53316 .15749 .53774 .15612 .53528 .15254 Metetra
.629 .7 .897 r
.53528 .15254 .53774 .15612 .54232 .15477 .53987 .15117 Metetra
.627 .698 .896 r
.53987 .15117 .54232 .15477 .54707 .17383 .54446 .14982 Metetra
0 0 .464 r
.54446 .14982 .54707 .17383 .55171 .17303 .54924 .16894 Metetra
.575 .645 .882 r
.54924 .16894 .55171 .17303 .55636 .17229 .55389 .16815 Metetra
.569 .638 .88 r
.55389 .16815 .55636 .17229 .56102 .17163 .55856 .16742 Metetra
.562 .631 .878 r
.55856 .16742 .56102 .17163 .5657 .17104 .56323 .16676 Metetra
.555 .624 .875 r
.56323 .16676 .5657 .17104 .57038 .17055 .56792 .16618 Metetra
.546 .615 .872 r
.56792 .16618 .57038 .17055 .57509 .17015 .57263 .16569 Metetra
.537 .605 .869 r
.57263 .16569 .57509 .17015 .5798 .16988 .57734 .16531 Metetra
.526 .594 .865 r
.57734 .16531 .5798 .16988 .58453 .16974 .58207 .16505 Metetra
.514 .581 .86 r
.58207 .16505 .58453 .16974 .58928 .16975 .58682 .16493 Metetra
.501 .566 .854 r
.58682 .16493 .58928 .16975 .59405 .16995 .59158 .16497 Metetra
.485 .55 .847 r
.59158 .16497 .59405 .16995 .59883 .17037 .59636 .1652 Metetra
.467 .53 .839 r
.59636 .1652 .59883 .17037 .60364 .17105 .60116 .16565 Metetra
.446 .508 .829 r
.60116 .16565 .60364 .17105 .60847 .17204 .60599 .16637 Metetra
.421 .481 .817 r
.60599 .16637 .60847 .17204 .61333 .17342 .61084 .16742 Metetra
.392 .45 .801 r
.61084 .16742 .61333 .17342 .61822 .17529 .61572 .16887 Metetra
.358 .414 .782 r
.61572 .16887 .61822 .17529 .62316 .17778 .62063 .17083 Metetra
.317 .37 .759 r
.62063 .17083 .62316 .17778 .62814 .1811 .62559 .17345 Metetra
.27 .319 .729 r
.62559 .17345 .62814 .1811 .63319 .18556 .6306 .17694 Metetra
.213 .258 .692 r
.6306 .17694 .63319 .18556 .63833 .19162 .63568 .18163 Metetra
.147 .187 .646 r
.63568 .18163 .63833 .19162 .6436 .20013 .64086 .18806 Metetra
.071 .105 .59 r
.64086 .18806 .6436 .20013 .64908 .21265 .64617 .19714 Metetra
0 .014 .524 r
.64617 .19714 .64908 .21265 .65493 .23266 .65172 .21067 Metetra
0 0 .449 r
.65172 .21067 .65493 .23266 .66163 .2701 .6577 .23279 Metetra
0 0 .365 r
.6577 .23279 .66163 .2701 .66921 .32365 .66473 .27612 Metetra
0 0 .426 r
.66473 .27612 .66921 .32365 .66282 .07936 .67188 .31872 Metetra
0 0 .335 r
.67188 .31872 .66282 .07936 .66757 .07756 .66528 .07423 Metetra
.664 .741 .907 r
.66528 .07423 .66757 .07756 .67233 .07576 .67004 .07242 Metetra
.664 .741 .907 r
.67004 .07242 .67233 .07576 .67709 .07395 .67481 .07061 Metetra
.664 .741 .907 r
.67481 .07061 .67709 .07395 .68186 .07214 .67959 .06879 Metetra
.664 .741 .907 r
.67959 .06879 .68186 .07214 .68664 .07033 .68437 .06698 Metetra
.664 .741 .907 r
.68437 .06698 .68664 .07033 .69143 .06852 .68916 .06516 Metetra
.664 .741 .907 r
.68916 .06516 .69143 .06852 .69622 .0667 .69396 .06333 Metetra
.664 .741 .907 r
.69396 .06333 .69622 .0667 .70102 .06487 .69877 .0615 Metetra
.664 .741 .907 r
.69877 .0615 .70102 .06487 .70583 .06305 .70359 .05967 Metetra
.664 .741 .907 r
.70359 .05967 .70583 .06305 .71065 .06122 .70841 .05784 Metetra
.664 .741 .907 r
.70841 .05784 .71065 .06122 .71548 .05939 .71325 .056 Metetra
.664 .741 .907 r
.71325 .056 .71548 .05939 .72032 .05756 .71809 .05416 Metetra
.664 .741 .907 r
.71809 .05416 .72032 .05756 .72516 .05572 .72294 .05232 Metetra
.664 .741 .907 r
.07828 .29354 .08115 .29622 .08498 .29477 .0821 .29208 Metetra
.664 .741 .907 r
.0821 .29208 .08498 .29477 .08881 .29331 .08594 .29062 Metetra
.664 .741 .907 r
.08594 .29062 .08881 .29331 .09264 .29185 .08978 .28916 Metetra
.664 .741 .907 r
.08978 .28916 .09264 .29185 .09649 .29039 .09362 .28769 Metetra
.664 .741 .907 r
.09362 .28769 .09649 .29039 .10033 .28893 .09747 .28623 Metetra
.664 .741 .907 r
.09747 .28623 .10033 .28893 .10419 .28747 .10133 .28476 Metetra
.664 .741 .907 r
.10133 .28476 .10419 .28747 .10805 .286 .1052 .28329 Metetra
.664 .741 .907 r
.1052 .28329 .10805 .286 .11191 .28453 .10906 .28181 Metetra
.664 .741 .907 r
.10906 .28181 .11191 .28453 .11579 .28306 .11294 .28034 Metetra
.664 .741 .907 r
.11294 .28034 .11579 .28306 .11966 .28159 .11682 .27886 Metetra
.664 .741 .907 r
.11682 .27886 .11966 .28159 .12355 .28011 .12071 .27738 Metetra
.942 .681 .512 r
.12071 .27738 .12355 .28011 .12744 .27863 .09445 .50928 Metetra
.433 .203 .464 r
.09445 .50928 .12744 .27863 .10171 .51047 .10245 .47793 Metetra
.82 .574 .567 r
.10245 .47793 .10171 .51047 .11121 .46669 .11297 .42621 Metetra
.72 .482 .566 r
.11297 .42621 .11121 .46669 .12073 .42202 .12023 .39949 Metetra
.74 .516 .589 r
.12023 .39949 .12073 .42202 .12764 .39761 .12626 .38223 Metetra
.75 .54 .611 r
.12626 .38223 .12764 .39761 .13351 .38142 .13168 .36971 Metetra
.755 .561 .633 r
.13168 .36971 .13351 .38142 .13883 .3695 .13674 .35996 Metetra
.757 .578 .654 r
.13674 .35996 .13883 .3695 .14383 .36013 .14157 .352 Metetra
.757 .593 .674 r
.14157 .352 .14383 .36013 .14861 .35242 .14624 .34526 Metetra
.756 .607 .692 r
.14624 .34526 .14861 .35242 .15325 .34586 .1508 .33941 Metetra
.754 .619 .709 r
.1508 .33941 .15325 .34586 .15779 .34014 .15528 .33423 Metetra
.752 .63 .725 r
.15528 .33423 .15779 .34014 .16225 .33505 .15969 .32955 Metetra
.749 .639 .739 r
.15969 .32955 .16225 .33505 .16665 .33046 .16406 .32528 Metetra
.746 .648 .751 r
.16406 .32528 .16665 .33046 .17101 .32625 .16839 .32134 Metetra
.743 .655 .763 r
.16839 .32134 .17101 .32625 .17533 .32236 .17269 .31766 Metetra
.74 .662 .773 r
.17269 .31766 .17533 .32236 .17962 .31873 .17697 .31421 Metetra
.737 .668 .783 r
.17697 .31421 .17962 .31873 .1839 .31531 .18122 .31094 Metetra
.734 .673 .791 r
.18122 .31094 .1839 .31531 .18815 .31208 .18547 .30784 Metetra
.73 .678 .799 r
.18547 .30784 .18815 .31208 .19239 .309 .18969 .30487 Metetra
.727 .682 .806 r
.18969 .30487 .19239 .309 .19661 .30605 .19391 .30201 Metetra
.725 .686 .813 r
.19391 .30201 .19661 .30605 .20083 .30322 .19812 .29927 Metetra
.722 .689 .818 r
.19812 .29927 .20083 .30322 .20504 .30049 .20233 .29661 Metetra
.719 .692 .824 r
.20233 .29661 .20504 .30049 .20924 .29785 .20653 .29403 Metetra
.717 .695 .829 r
.20653 .29403 .20924 .29785 .21344 .29529 .21072 .29153 Metetra
.714 .698 .833 r
.21072 .29153 .21344 .29529 .21763 .2928 .21492 .28909 Metetra
.924 .714 .6 r
.21492 .28909 .21763 .2928 .22183 .29037 .22104 .26707 Metetra
.556 .366 .58 r
.22104 .26707 .22183 .29037 .2279 .26842 .22516 .26516 Metetra
.687 .72 .874 r
.22516 .26516 .2279 .26842 .23202 .26652 .22929 .26328 Metetra
.686 .721 .876 r
.22929 .26328 .23202 .26652 .23615 .26465 .23342 .26141 Metetra
.684 .721 .878 r
.23342 .26141 .23615 .26465 .24029 .26279 .23756 .25957 Metetra
.683 .722 .879 r
.23756 .25957 .24029 .26279 .24442 .26095 .2417 .25774 Metetra
.682 .723 .881 r
.2417 .25774 .24442 .26095 .24856 .25913 .24584 .25593 Metetra
.681 .723 .882 r
.24584 .25593 .24856 .25913 .25271 .25732 .24999 .25413 Metetra
.68 .724 .883 r
.24999 .25413 .25271 .25732 .25686 .25553 .25414 .25234 Metetra
.679 .724 .884 r
.25414 .25234 .25686 .25553 .26101 .25375 .25829 .25057 Metetra
.678 .725 .885 r
.25829 .25057 .26101 .25375 .26517 .25198 .26245 .2488 Metetra
.677 .725 .886 r
.26245 .2488 .26517 .25198 .26933 .25022 .26662 .24705 Metetra
.676 .726 .887 r
.26662 .24705 .26933 .25022 .2735 .24847 .27079 .2453 Metetra
.675 .726 .888 r
.27079 .2453 .2735 .24847 .27767 .24673 .27497 .24356 Metetra
.674 .726 .889 r
.27497 .24356 .27767 .24673 .28185 .245 .27915 .24183 Metetra
.674 .726 .889 r
.27915 .24183 .28185 .245 .28603 .24328 .28334 .24011 Metetra
.673 .727 .89 r
.28334 .24011 .28603 .24328 .29022 .24156 .28753 .2384 Metetra
.672 .727 .891 r
.28753 .2384 .29022 .24156 .29442 .23985 .29173 .23669 Metetra
.671 .727 .891 r
.29173 .23669 .29442 .23985 .29862 .23815 .29593 .23498 Metetra
.671 .727 .892 r
.29593 .23498 .29862 .23815 .30283 .23645 .30014 .23329 Metetra
.67 .727 .892 r
.30014 .23329 .30283 .23645 .30704 .23476 .30436 .23159 Metetra
.67 .727 .893 r
.30436 .23159 .30704 .23476 .31126 .23307 .30858 .22991 Metetra
.669 .727 .893 r
.30858 .22991 .31126 .23307 .31548 .23139 .31281 .22822 Metetra
.668 .728 .894 r
.31281 .22822 .31548 .23139 .31971 .22971 .31704 .22655 Metetra
.668 .728 .894 r
.31704 .22655 .31971 .22971 .32395 .22804 .32128 .22487 Metetra
.667 .728 .895 r
.32128 .22487 .32395 .22804 .32819 .22637 .32553 .2232 Metetra
.667 .728 .895 r
.32553 .2232 .32819 .22637 .33244 .22471 .32978 .22154 Metetra
.666 .728 .895 r
.32978 .22154 .33244 .22471 .33669 .22305 .33404 .21987 Metetra
.666 .728 .896 r
.33404 .21987 .33669 .22305 .34095 .22139 .3383 .21822 Metetra
.665 .728 .896 r
.3383 .21822 .34095 .22139 .34522 .21974 .34257 .21656 Metetra
.665 .728 .896 r
.34257 .21656 .34522 .21974 .34949 .21809 .34685 .21491 Metetra
.664 .728 .897 r
.34685 .21491 .34949 .21809 .35377 .21645 .35113 .21326 Metetra
.664 .728 .897 r
.35113 .21326 .35377 .21645 .35806 .2148 .35542 .21161 Metetra
.663 .727 .897 r
.35542 .21161 .35806 .2148 .36235 .21316 .35972 .20997 Metetra
.663 .727 .897 r
.35972 .20997 .36235 .21316 .36665 .21153 .36402 .20833 Metetra
.662 .727 .898 r
.36402 .20833 .36665 .21153 .37095 .20989 .36833 .20669 Metetra
.662 .727 .898 r
.36833 .20669 .37095 .20989 .37527 .20826 .37265 .20505 Metetra
.661 .727 .898 r
.37265 .20505 .37527 .20826 .37959 .20663 .37697 .20342 Metetra
.661 .727 .898 r
.37697 .20342 .37959 .20663 .38391 .20501 .3813 .20179 Metetra
.661 .727 .898 r
.3813 .20179 .38391 .20501 .38824 .20339 .38564 .20017 Metetra
.66 .727 .898 r
.38564 .20017 .38824 .20339 .39258 .20177 .38998 .19854 Metetra
.66 .726 .899 r
.38998 .19854 .39258 .20177 .39693 .20015 .39433 .19692 Metetra
.659 .726 .899 r
.39433 .19692 .39693 .20015 .40128 .19854 .39869 .1953 Metetra
.659 .726 .899 r
.39869 .1953 .40128 .19854 .40564 .19693 .40305 .19369 Metetra
.658 .726 .899 r
.40305 .19369 .40564 .19693 .41001 .19532 .40742 .19207 Metetra
.658 .725 .899 r
.40742 .19207 .41001 .19532 .41438 .19372 .4118 .19046 Metetra
.657 .725 .899 r
.4118 .19046 .41438 .19372 .41876 .19212 .41618 .18886 Metetra
.657 .725 .899 r
.41618 .18886 .41876 .19212 .42315 .19052 .42058 .18725 Metetra
.656 .724 .899 r
.42058 .18725 .42315 .19052 .42755 .18893 .42498 .18565 Metetra
.655 .724 .899 r
.42498 .18565 .42755 .18893 .43195 .18734 .42938 .18406 Metetra
.655 .724 .9 r
.42938 .18406 .43195 .18734 .43636 .18576 .4338 .18246 Metetra
.654 .723 .9 r
.4338 .18246 .43636 .18576 .44077 .18417 .43822 .18087 Metetra
.654 .723 .9 r
.43822 .18087 .44077 .18417 .4452 .1826 .44264 .17929 Metetra
.653 .722 .9 r
.44264 .17929 .4452 .1826 .44963 .18102 .44708 .17771 Metetra
.652 .722 .9 r
.44708 .17771 .44963 .18102 .45407 .17945 .45152 .17613 Metetra
.652 .721 .9 r
.45152 .17613 .45407 .17945 .45851 .17789 .45597 .17456 Metetra
.651 .721 .9 r
.45597 .17456 .45851 .17789 .46297 .17633 .46043 .17299 Metetra
.65 .72 .9 r
.46043 .17299 .46297 .17633 .46743 .17478 .4649 .17143 Metetra
.65 .72 .9 r
.4649 .17143 .46743 .17478 .47189 .17323 .46937 .16987 Metetra
.649 .719 .9 r
.46937 .16987 .47189 .17323 .47637 .17169 .47385 .16832 Metetra
.648 .718 .9 r
.47385 .16832 .47637 .17169 .48085 .17016 .47834 .16677 Metetra
.647 .718 .899 r
.47834 .16677 .48085 .17016 .48535 .16863 .48283 .16524 Metetra
.646 .717 .899 r
.48283 .16524 .48535 .16863 .48984 .16712 .48733 .16371 Metetra
.645 .716 .899 r
.48733 .16371 .48984 .16712 .49435 .16561 .49185 .16218 Metetra
.644 .715 .899 r
.49185 .16218 .49435 .16561 .49887 .16411 .49636 .16067 Metetra
.643 .714 .899 r
.49636 .16067 .49887 .16411 .50339 .16262 .50089 .15916 Metetra
.642 .713 .899 r
.50089 .15916 .50339 .16262 .50792 .16114 .50543 .15767 Metetra
.641 .712 .899 r
.50543 .15767 .50792 .16114 .51246 .15967 .50997 .15619 Metetra
.639 .71 .898 r
.50997 .15619 .51246 .15967 .517 .15821 .51452 .15471 Metetra
.638 .709 .898 r
.51452 .15471 .517 .15821 .52156 .15677 .51908 .15325 Metetra
.636 .707 .898 r
.51908 .15325 .52156 .15677 .52612 .15534 .52365 .15181 Metetra
.635 .706 .898 r
.52365 .15181 .52612 .15534 .5307 .15393 .52822 .15038 Metetra
.633 .704 .897 r
.52822 .15038 .5307 .15393 .53528 .15254 .53281 .14896 Metetra
.631 .702 .897 r
.53281 .14896 .53528 .15254 .53987 .15117 .5374 .14757 Metetra
.629 .7 .896 r
.5374 .14757 .53987 .15117 .54446 .14982 .54201 .14619 Metetra
.626 .698 .896 r
.54201 .14619 .54446 .14982 .54924 .16894 .54662 .14484 Metetra
0 0 .463 r
.54662 .14484 .54924 .16894 .55389 .16815 .55142 .16403 Metetra
.574 .644 .882 r
.55142 .16403 .55389 .16815 .55856 .16742 .55609 .16324 Metetra
.568 .637 .88 r
.55609 .16324 .55856 .16742 .56323 .16676 .56077 .16252 Metetra
.561 .63 .877 r
.56077 .16252 .56323 .16676 .56792 .16618 .56546 .16186 Metetra
.553 .622 .875 r
.56546 .16186 .56792 .16618 .57263 .16569 .57016 .16129 Metetra
.545 .613 .872 r
.57016 .16129 .57263 .16569 .57734 .16531 .57488 .16082 Metetra
.535 .603 .868 r
.57488 .16082 .57734 .16531 .58207 .16505 .57961 .16045 Metetra
.525 .592 .864 r
.57961 .16045 .58207 .16505 .58682 .16493 .58435 .16021 Metetra
.512 .579 .859 r
.58435 .16021 .58682 .16493 .59158 .16497 .58912 .1601 Metetra
.498 .564 .853 r
.58912 .1601 .59158 .16497 .59636 .1652 .59389 .16016 Metetra
.482 .546 .846 r
.59389 .16016 .59636 .1652 .60116 .16565 .59869 .16042 Metetra
.464 .527 .837 r
.59869 .16042 .60116 .16565 .60599 .16637 .60351 .16091 Metetra
.442 .503 .827 r
.60351 .16091 .60599 .16637 .61084 .16742 .60835 .16167 Metetra
.417 .476 .814 r
.60835 .16167 .61084 .16742 .61572 .16887 .61322 .16277 Metetra
.387 .444 .798 r
.61322 .16277 .61572 .16887 .62063 .17083 .61812 .1643 Metetra
.352 .406 .778 r
.61812 .1643 .62063 .17083 .62559 .17345 .62305 .16635 Metetra
.31 .362 .754 r
.62305 .16635 .62559 .17345 .6306 .17694 .62803 .1691 Metetra
.261 .309 .723 r
.62803 .1691 .6306 .17694 .63568 .18163 .63307 .17277 Metetra
.203 .246 .685 r
.63307 .17277 .63568 .18163 .64086 .18806 .63818 .17772 Metetra
.136 .173 .637 r
.63818 .17772 .64086 .18806 .64617 .19714 .6434 .18452 Metetra
.058 .09 .579 r
.6434 .18452 .64617 .19714 .65172 .21067 .64877 .19422 Metetra
0 0 .512 r
.64877 .19422 .65172 .21067 .6577 .23279 .6544 .20887 Metetra
0 0 .435 r
.6544 .20887 .6577 .23279 .66473 .27612 .66053 .23341 Metetra
0 0 .35 r
.66053 .23341 .66473 .27612 .67188 .31872 .66796 .28414 Metetra
.003 0 .454 r
.66796 .28414 .67188 .31872 .66528 .07423 .67458 .31378 Metetra
0 0 .335 r
.67458 .31378 .66528 .07423 .67004 .07242 .66775 .06907 Metetra
.664 .741 .907 r
.66775 .06907 .67004 .07242 .67481 .07061 .67252 .06726 Metetra
.664 .741 .907 r
.67252 .06726 .67481 .07061 .67959 .06879 .6773 .06544 Metetra
.664 .741 .907 r
.6773 .06544 .67959 .06879 .68437 .06698 .68209 .06361 Metetra
.664 .741 .907 r
.68209 .06361 .68437 .06698 .68916 .06516 .68689 .06178 Metetra
.664 .741 .907 r
.68689 .06178 .68916 .06516 .69396 .06333 .6917 .05995 Metetra
.664 .741 .907 r
.6917 .05995 .69396 .06333 .69877 .0615 .69651 .05812 Metetra
.664 .741 .907 r
.69651 .05812 .69877 .0615 .70359 .05967 .70134 .05628 Metetra
.664 .741 .907 r
.70134 .05628 .70359 .05967 .70841 .05784 .70617 .05445 Metetra
.664 .741 .907 r
.70617 .05445 .70841 .05784 .71325 .056 .71101 .0526 Metetra
.664 .741 .907 r
.71101 .0526 .71325 .056 .71809 .05416 .71585 .05076 Metetra
.664 .741 .907 r
.71585 .05076 .71809 .05416 .72294 .05232 .72071 .04891 Metetra
.664 .741 .907 r
.07539 .29084 .07828 .29354 .0821 .29208 .07922 .28938 Metetra
.664 .741 .907 r
.07922 .28938 .0821 .29208 .08594 .29062 .08306 .28792 Metetra
.664 .741 .907 r
.08306 .28792 .08594 .29062 .08978 .28916 .0869 .28645 Metetra
.664 .741 .907 r
.0869 .28645 .08978 .28916 .09362 .28769 .09075 .28498 Metetra
.664 .741 .907 r
.09075 .28498 .09362 .28769 .09747 .28623 .09461 .28351 Metetra
.664 .741 .907 r
.09461 .28351 .09747 .28623 .10133 .28476 .09847 .28204 Metetra
.664 .741 .907 r
.09847 .28204 .10133 .28476 .1052 .28329 .10233 .28056 Metetra
.664 .741 .907 r
.10233 .28056 .1052 .28329 .10906 .28181 .10621 .27909 Metetra
.664 .741 .907 r
.10621 .27909 .10906 .28181 .11294 .28034 .11008 .27761 Metetra
.664 .741 .907 r
.11008 .27761 .11294 .28034 .11682 .27886 .11397 .27612 Metetra
.942 .681 .512 r
.11397 .27612 .11682 .27886 .12071 .27738 .08718 .5081 Metetra
.469 .234 .474 r
.08718 .5081 .12071 .27738 .09445 .50928 .09329 .49175 Metetra
.882 .638 .565 r
.09329 .49175 .09445 .50928 .10245 .47793 .1051 .43098 Metetra
.713 .474 .561 r
.1051 .43098 .10245 .47793 .11297 .42621 .11277 .40159 Metetra
.737 .51 .585 r
.11277 .40159 .11297 .42621 .12023 .39949 .11899 .38313 Metetra
.748 .536 .607 r
.11899 .38313 .12023 .39949 .12626 .38223 .12451 .36996 Metetra
.754 .557 .629 r
.12451 .36996 .12626 .38223 .13168 .36971 .12963 .35982 Metetra
.756 .575 .651 r
.12963 .35982 .13168 .36971 .13674 .35996 .13451 .3516 Metetra
.757 .59 .671 r
.13451 .3516 .13674 .35996 .14157 .352 .13921 .34468 Metetra
.756 .604 .689 r
.13921 .34468 .14157 .352 .14624 .34526 .1438 .33869 Metetra
.754 .617 .706 r
.1438 .33869 .14624 .34526 .1508 .33941 .14829 .3334 Metetra
.752 .628 .722 r
.14829 .3334 .1508 .33941 .15528 .33423 .15272 .32865 Metetra
.75 .638 .736 r
.15272 .32865 .15528 .33423 .15969 .32955 .1571 .32431 Metetra
.747 .646 .749 r
.1571 .32431 .15969 .32955 .16406 .32528 .16144 .32032 Metetra
.743 .654 .761 r
.16144 .32032 .16406 .32528 .16839 .32134 .16575 .3166 Metetra
.74 .661 .772 r
.16575 .3166 .16839 .32134 .17269 .31766 .17003 .31311 Metetra
.737 .667 .781 r
.17003 .31311 .17269 .31766 .17697 .31421 .17429 .30981 Metetra
.734 .672 .79 r
.17429 .30981 .17697 .31421 .18122 .31094 .17854 .30667 Metetra
.731 .677 .798 r
.17854 .30667 .18122 .31094 .18547 .30784 .18277 .30368 Metetra
.728 .681 .805 r
.18277 .30368 .18547 .30784 .18969 .30487 .18699 .30081 Metetra
.725 .685 .812 r
.18699 .30081 .18969 .30487 .19391 .30201 .1912 .29804 Metetra
.722 .689 .817 r
.1912 .29804 .19391 .30201 .19812 .29927 .19541 .29536 Metetra
.72 .692 .823 r
.19541 .29536 .19812 .29927 .20233 .29661 .19961 .29277 Metetra
.717 .695 .828 r
.19961 .29277 .20233 .29661 .20653 .29403 .20381 .29025 Metetra
.715 .697 .832 r
.20381 .29025 .20653 .29403 .21072 .29153 .208 .2878 Metetra
.924 .713 .6 r
.208 .2878 .21072 .29153 .21492 .28909 .21417 .26571 Metetra
.555 .366 .579 r
.21417 .26571 .21492 .28909 .22104 .26707 .2183 .2638 Metetra
.687 .72 .874 r
.2183 .2638 .22104 .26707 .22516 .26516 .22242 .26191 Metetra
.686 .721 .876 r
.22242 .26191 .22516 .26516 .22929 .26328 .22655 .26004 Metetra
.685 .721 .877 r
.22655 .26004 .22929 .26328 .23342 .26141 .23068 .25819 Metetra
.683 .722 .879 r
.23068 .25819 .23342 .26141 .23756 .25957 .23482 .25635 Metetra
.682 .723 .88 r
.23482 .25635 .23756 .25957 .2417 .25774 .23896 .25453 Metetra
.681 .723 .882 r
.23896 .25453 .2417 .25774 .24584 .25593 .24311 .25273 Metetra
.68 .724 .883 r
.24311 .25273 .24584 .25593 .24999 .25413 .24726 .25093 Metetra
.679 .724 .884 r
.24726 .25093 .24999 .25413 .25414 .25234 .25141 .24915 Metetra
.678 .725 .885 r
.25141 .24915 .25414 .25234 .25829 .25057 .25557 .24738 Metetra
.677 .725 .886 r
.25557 .24738 .25829 .25057 .26245 .2488 .25973 .24562 Metetra
.676 .726 .887 r
.25973 .24562 .26245 .2488 .26662 .24705 .2639 .24387 Metetra
.675 .726 .888 r
.2639 .24387 .26662 .24705 .27079 .2453 .26808 .24213 Metetra
.675 .726 .889 r
.26808 .24213 .27079 .2453 .27497 .24356 .27226 .24039 Metetra
.674 .726 .889 r
.27226 .24039 .27497 .24356 .27915 .24183 .27644 .23867 Metetra
.673 .727 .89 r
.27644 .23867 .27915 .24183 .28334 .24011 .28063 .23694 Metetra
.672 .727 .891 r
.28063 .23694 .28334 .24011 .28753 .2384 .28483 .23523 Metetra
.672 .727 .891 r
.28483 .23523 .28753 .2384 .29173 .23669 .28903 .23352 Metetra
.671 .727 .892 r
.28903 .23352 .29173 .23669 .29593 .23498 .29324 .23182 Metetra
.67 .727 .892 r
.29324 .23182 .29593 .23498 .30014 .23329 .29745 .23012 Metetra
.67 .728 .893 r
.29745 .23012 .30014 .23329 .30436 .23159 .30167 .22843 Metetra
.669 .728 .893 r
.30167 .22843 .30436 .23159 .30858 .22991 .3059 .22674 Metetra
.669 .728 .894 r
.3059 .22674 .30858 .22991 .31281 .22822 .31013 .22506 Metetra
.668 .728 .894 r
.31013 .22506 .31281 .22822 .31704 .22655 .31436 .22338 Metetra
.668 .728 .895 r
.31436 .22338 .31704 .22655 .32128 .22487 .31861 .2217 Metetra
.667 .728 .895 r
.31861 .2217 .32128 .22487 .32553 .2232 .32286 .22003 Metetra
.667 .728 .895 r
.32286 .22003 .32553 .2232 .32978 .22154 .32711 .21836 Metetra
.666 .728 .896 r
.32711 .21836 .32978 .22154 .33404 .21987 .33137 .21669 Metetra
.666 .728 .896 r
.33137 .21669 .33404 .21987 .3383 .21822 .33564 .21503 Metetra
.665 .728 .896 r
.33564 .21503 .3383 .21822 .34257 .21656 .33992 .21337 Metetra
.665 .728 .897 r
.33992 .21337 .34257 .21656 .34685 .21491 .3442 .21172 Metetra
.664 .728 .897 r
.3442 .21172 .34685 .21491 .35113 .21326 .34849 .21006 Metetra
.664 .728 .897 r
.34849 .21006 .35113 .21326 .35542 .21161 .35278 .20841 Metetra
.663 .728 .897 r
.35278 .20841 .35542 .21161 .35972 .20997 .35708 .20677 Metetra
.663 .728 .898 r
.35708 .20677 .35972 .20997 .36402 .20833 .36139 .20512 Metetra
.662 .728 .898 r
.36139 .20512 .36402 .20833 .36833 .20669 .3657 .20348 Metetra
.662 .727 .898 r
.3657 .20348 .36833 .20669 .37265 .20505 .37002 .20184 Metetra
.661 .727 .898 r
.37002 .20184 .37265 .20505 .37697 .20342 .37435 .2002 Metetra
.661 .727 .898 r
.37435 .2002 .37697 .20342 .3813 .20179 .37868 .19857 Metetra
.661 .727 .898 r
.37868 .19857 .3813 .20179 .38564 .20017 .38302 .19694 Metetra
.66 .727 .899 r
.38302 .19694 .38564 .20017 .38998 .19854 .38737 .19531 Metetra
.66 .727 .899 r
.38737 .19531 .38998 .19854 .39433 .19692 .39172 .19368 Metetra
.659 .726 .899 r
.39172 .19368 .39433 .19692 .39869 .1953 .39609 .19206 Metetra
.659 .726 .899 r
.39609 .19206 .39869 .1953 .40305 .19369 .40045 .19043 Metetra
.658 .726 .899 r
.40045 .19043 .40305 .19369 .40742 .19207 .40483 .18882 Metetra
.658 .726 .899 r
.40483 .18882 .40742 .19207 .4118 .19046 .40921 .1872 Metetra
.657 .725 .899 r
.40921 .1872 .4118 .19046 .41618 .18886 .4136 .18559 Metetra
.657 .725 .899 r
.4136 .18559 .41618 .18886 .42058 .18725 .418 .18398 Metetra
.656 .725 .9 r
.418 .18398 .42058 .18725 .42498 .18565 .4224 .18237 Metetra
.656 .724 .9 r
.4224 .18237 .42498 .18565 .42938 .18406 .42681 .18076 Metetra
.655 .724 .9 r
.42681 .18076 .42938 .18406 .4338 .18246 .43123 .17916 Metetra
.655 .724 .9 r
.43123 .17916 .4338 .18246 .43822 .18087 .43565 .17757 Metetra
.654 .723 .9 r
.43565 .17757 .43822 .18087 .44264 .17929 .44008 .17597 Metetra
.653 .723 .9 r
.44008 .17597 .44264 .17929 .44708 .17771 .44452 .17438 Metetra
.653 .722 .9 r
.44452 .17438 .44708 .17771 .45152 .17613 .44897 .1728 Metetra
.652 .722 .9 r
.44897 .1728 .45152 .17613 .45597 .17456 .45343 .17122 Metetra
.651 .721 .9 r
.45343 .17122 .45597 .17456 .46043 .17299 .45789 .16964 Metetra
.651 .721 .9 r
.45789 .16964 .46043 .17299 .4649 .17143 .46236 .16807 Metetra
.65 .72 .9 r
.46236 .16807 .4649 .17143 .46937 .16987 .46683 .1665 Metetra
.649 .72 .9 r
.46683 .1665 .46937 .16987 .47385 .16832 .47132 .16494 Metetra
.648 .719 .9 r
.47132 .16494 .47385 .16832 .47834 .16677 .47581 .16338 Metetra
.648 .718 .9 r
.47581 .16338 .47834 .16677 .48283 .16524 .48031 .16184 Metetra
.647 .717 .9 r
.48031 .16184 .48283 .16524 .48733 .16371 .48482 .16029 Metetra
.646 .717 .9 r
.48482 .16029 .48733 .16371 .49185 .16218 .48933 .15876 Metetra
.645 .716 .899 r
.48933 .15876 .49185 .16218 .49636 .16067 .49386 .15723 Metetra
.644 .715 .899 r
.49386 .15723 .49636 .16067 .50089 .15916 .49839 .15571 Metetra
.643 .714 .899 r
.49839 .15571 .50089 .15916 .50543 .15767 .50293 .1542 Metetra
.641 .713 .899 r
.50293 .1542 .50543 .15767 .50997 .15619 .50747 .1527 Metetra
.64 .711 .899 r
.50747 .1527 .50997 .15619 .51452 .15471 .51203 .15122 Metetra
.639 .71 .899 r
.51203 .15122 .51452 .15471 .51908 .15325 .51659 .14974 Metetra
.637 .709 .898 r
.51659 .14974 .51908 .15325 .52365 .15181 .52117 .14828 Metetra
.636 .707 .898 r
.52117 .14828 .52365 .15181 .52822 .15038 .52575 .14683 Metetra
.634 .705 .898 r
.52575 .14683 .52822 .15038 .53281 .14896 .53034 .14539 Metetra
.632 .704 .897 r
.53034 .14539 .53281 .14896 .5374 .14757 .53493 .14398 Metetra
.63 .702 .897 r
.53493 .14398 .5374 .14757 .54201 .14619 .53954 .14258 Metetra
.628 .699 .896 r
.53954 .14258 .54201 .14619 .54662 .14484 .54415 .1412 Metetra
.626 .697 .896 r
.54415 .1412 .54662 .14484 .55142 .16403 .54878 .13984 Metetra
0 0 .463 r
.54878 .13984 .55142 .16403 .55609 .16324 .55361 .1591 Metetra
.573 .643 .881 r
.55361 .1591 .55609 .16324 .56077 .16252 .55829 .15832 Metetra
.567 .636 .879 r
.55829 .15832 .56077 .16252 .56546 .16186 .56299 .15759 Metetra
.56 .629 .877 r
.56299 .15759 .56546 .16186 .57016 .16129 .56769 .15695 Metetra
.552 .621 .874 r
.56769 .15695 .57016 .16129 .57488 .16082 .57241 .15639 Metetra
.543 .611 .871 r
.57241 .15639 .57488 .16082 .57961 .16045 .57714 .15592 Metetra
.534 .601 .867 r
.57714 .15592 .57961 .16045 .58435 .16021 .58189 .15556 Metetra
.523 .589 .863 r
.58189 .15556 .58435 .16021 .58912 .1601 .58665 .15533 Metetra
.51 .576 .858 r
.58665 .15533 .58912 .1601 .59389 .16016 .59142 .15525 Metetra
.496 .561 .852 r
.59142 .15525 .59389 .16016 .59869 .16042 .59622 .15533 Metetra
.479 .543 .844 r
.59622 .15533 .59869 .16042 .60351 .16091 .60103 .15562 Metetra
.46 .523 .835 r
.60103 .15562 .60351 .16091 .60835 .16167 .60587 .15614 Metetra
.438 .499 .824 r
.60587 .15614 .60835 .16167 .61322 .16277 .61073 .15695 Metetra
.412 .471 .811 r
.61073 .15695 .61322 .16277 .61812 .1643 .61561 .15811 Metetra
.382 .438 .795 r
.61561 .15811 .61812 .1643 .62305 .16635 .62053 .15971 Metetra
.346 .399 .774 r
.62053 .15971 .62305 .16635 .62803 .1691 .62549 .16186 Metetra
.303 .353 .749 r
.62549 .16186 .62803 .1691 .63307 .17277 .63049 .16474 Metetra
.253 .299 .717 r
.63049 .16474 .63307 .17277 .63818 .17772 .63556 .16859 Metetra
.193 .235 .677 r
.63556 .16859 .63818 .17772 .6434 .18452 .6407 .17381 Metetra
.125 .16 .628 r
.6407 .17381 .6434 .18452 .64877 .19422 .64596 .18102 Metetra
.046 .076 .568 r
.64596 .18102 .64877 .19422 .6544 .20887 .65138 .19138 Metetra
0 0 .499 r
.65138 .19138 .6544 .20887 .66053 .23341 .6571 .20728 Metetra
0 0 .422 r
.6571 .20728 .66053 .23341 .66796 .28414 .6634 .23461 Metetra
0 0 .336 r
.6634 .23461 .66796 .28414 .67458 .31378 .67136 .29488 Metetra
.088 .069 .538 r
.67136 .29488 .67458 .31378 .66775 .06907 .67728 .3088 Metetra
0 0 .335 r
.67728 .3088 .66775 .06907 .67252 .06726 .67023 .06389 Metetra
.664 .741 .907 r
.67023 .06389 .67252 .06726 .6773 .06544 .67502 .06207 Metetra
.664 .741 .907 r
.67502 .06207 .6773 .06544 .68209 .06361 .67981 .06024 Metetra
.664 .741 .907 r
.67981 .06024 .68209 .06361 .68689 .06178 .68462 .0584 Metetra
.664 .741 .907 r
.68462 .0584 .68689 .06178 .6917 .05995 .68943 .05657 Metetra
.664 .741 .907 r
.68943 .05657 .6917 .05995 .69651 .05812 .69425 .05473 Metetra
.664 .741 .907 r
.69425 .05473 .69651 .05812 .70134 .05628 .69908 .05289 Metetra
.664 .741 .907 r
.69908 .05289 .70134 .05628 .70617 .05445 .70391 .05104 Metetra
.664 .741 .907 r
.70391 .05104 .70617 .05445 .71101 .0526 .70876 .04919 Metetra
.664 .741 .907 r
.70876 .04919 .71101 .0526 .71585 .05076 .71361 .04734 Metetra
.664 .741 .907 r
.71361 .04734 .71585 .05076 .72071 .04891 .71847 .04549 Metetra
.664 .741 .907 r
.0725 .28814 .07539 .29084 .07922 .28938 .07634 .28668 Metetra
.664 .741 .907 r
.07634 .28668 .07922 .28938 .08306 .28792 .08018 .28521 Metetra
.664 .741 .907 r
.08018 .28521 .08306 .28792 .0869 .28645 .08402 .28374 Metetra
.664 .741 .907 r
.08402 .28374 .0869 .28645 .09075 .28498 .08787 .28227 Metetra
.664 .741 .907 r
.08787 .28227 .09075 .28498 .09461 .28351 .09173 .28079 Metetra
.664 .741 .907 r
.09173 .28079 .09461 .28351 .09847 .28204 .0956 .27931 Metetra
.664 .741 .907 r
.0956 .27931 .09847 .28204 .10233 .28056 .09947 .27783 Metetra
.664 .741 .907 r
.09947 .27783 .10233 .28056 .10621 .27909 .10334 .27635 Metetra
.664 .741 .907 r
.10334 .27635 .10621 .27909 .11008 .27761 .10722 .27487 Metetra
.942 .681 .513 r
.10722 .27487 .11008 .27761 .11397 .27612 .0799 .50691 Metetra
.502 .261 .482 r
.0799 .50691 .11397 .27612 .08718 .5081 .08406 .5055 Metetra
.937 .7 .553 r
.08406 .5055 .08718 .5081 .09329 .49175 .09711 .43643 Metetra
.706 .464 .556 r
.09711 .43643 .09329 .49175 .1051 .43098 .10525 .40391 Metetra
.734 .504 .58 r
.10525 .40391 .1051 .43098 .11277 .40159 .11168 .38413 Metetra
.746 .531 .603 r
.11168 .38413 .11277 .40159 .11899 .38313 .11732 .37027 Metetra
.753 .553 .625 r
.11732 .37027 .11899 .38313 .12451 .36996 .12251 .35971 Metetra
.756 .571 .647 r
.12251 .35971 .12451 .36996 .12963 .35982 .12743 .35121 Metetra
.757 .587 .667 r
.12743 .35121 .12963 .35982 .13451 .3516 .13217 .3441 Metetra
.756 .602 .686 r
.13217 .3441 .13451 .3516 .13921 .34468 .13678 .33797 Metetra
.755 .614 .703 r
.13678 .33797 .13921 .34468 .1438 .33869 .1413 .33258 Metetra
.752 .626 .719 r
.1413 .33258 .1438 .33869 .14829 .3334 .14574 .32774 Metetra
.75 .636 .734 r
.14574 .32774 .14829 .3334 .15272 .32865 .15013 .32334 Metetra
.747 .645 .747 r
.15013 .32334 .15272 .32865 .1571 .32431 .15448 .31929 Metetra
.744 .652 .759 r
.15448 .31929 .1571 .32431 .16144 .32032 .15879 .31553 Metetra
.741 .659 .77 r
.15879 .31553 .16144 .32032 .16575 .3166 .16308 .312 Metetra
.737 .666 .78 r
.16308 .312 .16575 .3166 .17003 .31311 .16735 .30867 Metetra
.734 .671 .788 r
.16735 .30867 .17003 .31311 .17429 .30981 .1716 .30551 Metetra
.731 .676 .796 r
.1716 .30551 .17429 .30981 .17854 .30667 .17583 .30249 Metetra
.728 .68 .804 r
.17583 .30249 .17854 .30667 .18277 .30368 .18006 .2996 Metetra
.725 .684 .81 r
.18006 .2996 .18277 .30368 .18699 .30081 .18427 .29681 Metetra
.723 .688 .816 r
.18427 .29681 .18699 .30081 .1912 .29804 .18848 .29412 Metetra
.72 .691 .822 r
.18848 .29412 .1912 .29804 .19541 .29536 .19268 .29151 Metetra
.717 .694 .827 r
.19268 .29151 .19541 .29536 .19961 .29277 .19688 .28898 Metetra
.923 .712 .599 r
.19688 .28898 .19961 .29277 .20381 .29025 .20318 .2663 Metetra
.554 .363 .577 r
.20318 .2663 .20381 .29025 .208 .2878 .2073 .26436 Metetra
.555 .365 .578 r
.2073 .26436 .208 .2878 .21417 .26571 .21142 .26244 Metetra
.688 .72 .874 r
.21142 .26244 .21417 .26571 .2183 .2638 .21554 .26054 Metetra
.686 .72 .876 r
.21554 .26054 .2183 .2638 .22242 .26191 .21967 .25866 Metetra
.685 .721 .877 r
.21967 .25866 .22242 .26191 .22655 .26004 .2238 .25681 Metetra
.684 .722 .879 r
.2238 .25681 .22655 .26004 .23068 .25819 .22794 .25497 Metetra
.682 .723 .88 r
.22794 .25497 .23068 .25819 .23482 .25635 .23208 .25314 Metetra
.681 .723 .881 r
.23208 .25314 .23482 .25635 .23896 .25453 .23622 .25133 Metetra
.68 .724 .883 r
.23622 .25133 .23896 .25453 .24311 .25273 .24037 .24953 Metetra
.679 .724 .884 r
.24037 .24953 .24311 .25273 .24726 .25093 .24452 .24774 Metetra
.678 .725 .885 r
.24452 .24774 .24726 .25093 .25141 .24915 .24868 .24597 Metetra
.677 .725 .886 r
.24868 .24597 .25141 .24915 .25557 .24738 .25284 .2442 Metetra
.676 .726 .887 r
.25284 .2442 .25557 .24738 .25973 .24562 .25701 .24244 Metetra
.676 .726 .888 r
.25701 .24244 .25973 .24562 .2639 .24387 .26118 .24069 Metetra
.675 .726 .888 r
.26118 .24069 .2639 .24387 .26808 .24213 .26536 .23895 Metetra
.674 .727 .889 r
.26536 .23895 .26808 .24213 .27226 .24039 .26954 .23722 Metetra
.673 .727 .89 r
.26954 .23722 .27226 .24039 .27644 .23867 .27373 .23549 Metetra
.673 .727 .891 r
.27373 .23549 .27644 .23867 .28063 .23694 .27792 .23377 Metetra
.672 .727 .891 r
.27792 .23377 .28063 .23694 .28483 .23523 .28212 .23206 Metetra
.671 .727 .892 r
.28212 .23206 .28483 .23523 .28903 .23352 .28632 .23035 Metetra
.671 .728 .892 r
.28632 .23035 .28903 .23352 .29324 .23182 .29054 .22865 Metetra
.67 .728 .893 r
.29054 .22865 .29324 .23182 .29745 .23012 .29475 .22695 Metetra
.67 .728 .893 r
.29475 .22695 .29745 .23012 .30167 .22843 .29898 .22526 Metetra
.669 .728 .894 r
.29898 .22526 .30167 .22843 .3059 .22674 .3032 .22357 Metetra
.668 .728 .894 r
.3032 .22357 .3059 .22674 .31013 .22506 .30744 .22188 Metetra
.668 .728 .895 r
.30744 .22188 .31013 .22506 .31436 .22338 .31168 .2202 Metetra
.667 .728 .895 r
.31168 .2202 .31436 .22338 .31861 .2217 .31593 .21852 Metetra
.667 .728 .895 r
.31593 .21852 .31861 .2217 .32286 .22003 .32018 .21685 Metetra
.666 .728 .896 r
.32018 .21685 .32286 .22003 .32711 .21836 .32444 .21518 Metetra
.666 .728 .896 r
.32444 .21518 .32711 .21836 .33137 .21669 .3287 .21351 Metetra
.666 .728 .896 r
.3287 .21351 .33137 .21669 .33564 .21503 .33298 .21184 Metetra
.665 .728 .897 r
.33298 .21184 .33564 .21503 .33992 .21337 .33725 .21018 Metetra
.665 .728 .897 r
.33725 .21018 .33992 .21337 .3442 .21172 .34154 .20852 Metetra
.664 .728 .897 r
.34154 .20852 .3442 .21172 .34849 .21006 .34583 .20687 Metetra
.664 .728 .897 r
.34583 .20687 .34849 .21006 .35278 .20841 .35013 .20521 Metetra
.663 .728 .898 r
.35013 .20521 .35278 .20841 .35708 .20677 .35443 .20356 Metetra
.663 .728 .898 r
.35443 .20356 .35708 .20677 .36139 .20512 .35874 .20191 Metetra
.662 .728 .898 r
.35874 .20191 .36139 .20512 .3657 .20348 .36306 .20027 Metetra
.662 .728 .898 r
.36306 .20027 .3657 .20348 .37002 .20184 .36739 .19862 Metetra
.661 .728 .898 r
.36739 .19862 .37002 .20184 .37435 .2002 .37172 .19698 Metetra
.661 .727 .898 r
.37172 .19698 .37435 .2002 .37868 .19857 .37606 .19534 Metetra
.661 .727 .899 r
.37606 .19534 .37868 .19857 .38302 .19694 .3804 .1937 Metetra
.66 .727 .899 r
.3804 .1937 .38302 .19694 .38737 .19531 .38475 .19207 Metetra
.66 .727 .899 r
.38475 .19207 .38737 .19531 .39172 .19368 .38911 .19044 Metetra
.659 .727 .899 r
.38911 .19044 .39172 .19368 .39609 .19206 .39348 .18881 Metetra
.659 .726 .899 r
.39348 .18881 .39609 .19206 .40045 .19043 .39785 .18718 Metetra
.658 .726 .899 r
.39785 .18718 .40045 .19043 .40483 .18882 .40223 .18555 Metetra
.658 .726 .899 r
.40223 .18555 .40483 .18882 .40921 .1872 .40661 .18393 Metetra
.657 .726 .9 r
.40661 .18393 .40921 .1872 .4136 .18559 .41101 .18231 Metetra
.657 .725 .9 r
.41101 .18231 .4136 .18559 .418 .18398 .41541 .18069 Metetra
.656 .725 .9 r
.41541 .18069 .418 .18398 .4224 .18237 .41981 .17908 Metetra
.656 .725 .9 r
.41981 .17908 .4224 .18237 .42681 .18076 .42423 .17747 Metetra
.655 .724 .9 r
.42423 .17747 .42681 .18076 .43123 .17916 .42865 .17586 Metetra
.655 .724 .9 r
.42865 .17586 .43123 .17916 .43565 .17757 .43308 .17426 Metetra
.654 .724 .9 r
.43308 .17426 .43565 .17757 .44008 .17597 .43752 .17265 Metetra
.654 .723 .9 r
.43752 .17265 .44008 .17597 .44452 .17438 .44196 .17106 Metetra
.653 .723 .9 r
.44196 .17106 .44452 .17438 .44897 .1728 .44641 .16946 Metetra
.652 .722 .9 r
.44641 .16946 .44897 .1728 .45343 .17122 .45087 .16787 Metetra
.652 .722 .9 r
.45087 .16787 .45343 .17122 .45789 .16964 .45534 .16629 Metetra
.651 .721 .9 r
.45534 .16629 .45789 .16964 .46236 .16807 .45981 .1647 Metetra
.65 .721 .9 r
.45981 .1647 .46236 .16807 .46683 .1665 .46429 .16313 Metetra
.65 .72 .9 r
.46429 .16313 .46683 .1665 .47132 .16494 .46878 .16156 Metetra
.649 .72 .9 r
.46878 .16156 .47132 .16494 .47581 .16338 .47328 .15999 Metetra
.648 .719 .9 r
.47328 .15999 .47581 .16338 .48031 .16184 .47778 .15843 Metetra
.647 .718 .9 r
.47778 .15843 .48031 .16184 .48482 .16029 .48229 .15688 Metetra
.646 .717 .9 r
.48229 .15688 .48482 .16029 .48933 .15876 .48681 .15533 Metetra
.646 .716 .9 r
.48681 .15533 .48933 .15876 .49386 .15723 .49134 .15379 Metetra
.645 .716 .899 r
.49134 .15379 .49386 .15723 .49839 .15571 .49588 .15226 Metetra
.643 .715 .899 r
.49588 .15226 .49839 .15571 .50293 .1542 .50042 .15074 Metetra
.642 .714 .899 r
.50042 .15074 .50293 .1542 .50747 .1527 .50497 .14922 Metetra
.641 .712 .899 r
.50497 .14922 .50747 .1527 .51203 .15122 .50953 .14772 Metetra
.64 .711 .899 r
.50953 .14772 .51203 .15122 .51659 .14974 .5141 .14623 Metetra
.639 .71 .899 r
.5141 .14623 .51659 .14974 .52117 .14828 .51868 .14475 Metetra
.637 .708 .898 r
.51868 .14475 .52117 .14828 .52575 .14683 .52326 .14328 Metetra
.636 .707 .898 r
.52326 .14328 .52575 .14683 .53034 .14539 .52785 .14182 Metetra
.634 .705 .898 r
.52785 .14182 .53034 .14539 .53493 .14398 .53246 .14039 Metetra
.632 .703 .897 r
.53246 .14039 .53493 .14398 .53954 .14258 .53707 .13897 Metetra
.63 .701 .897 r
.53707 .13897 .53954 .14258 .54415 .1412 .54169 .13756 Metetra
.628 .699 .896 r
.54169 .13756 .54415 .1412 .54878 .13984 .54631 .13618 Metetra
.625 .697 .896 r
.54631 .13618 .54878 .13984 .55361 .1591 .55095 .13483 Metetra
.54 .354 .577 r
.55095 .13483 .55361 .1591 .55829 .15832 .5556 .13349 Metetra
0 0 .46 r
.5556 .13349 .55829 .15832 .56299 .15759 .56051 .15337 Metetra
.565 .635 .879 r
.56051 .15337 .56299 .15759 .56769 .15695 .56522 .15265 Metetra
.558 .627 .876 r
.56522 .15265 .56769 .15695 .57241 .15639 .56993 .15201 Metetra
.551 .619 .874 r
.56993 .15201 .57241 .15639 .57714 .15592 .57467 .15146 Metetra
.542 .61 .87 r
.57467 .15146 .57714 .15592 .58189 .15556 .57941 .151 Metetra
.532 .599 .866 r
.57941 .151 .58189 .15556 .58665 .15533 .58417 .15065 Metetra
.521 .587 .862 r
.58417 .15065 .58665 .15533 .59142 .15525 .58895 .15044 Metetra
.508 .574 .857 r
.58895 .15044 .59142 .15525 .59622 .15533 .59374 .15037 Metetra
.493 .558 .85 r
.59374 .15037 .59622 .15533 .60103 .15562 .59855 .15048 Metetra
.477 .54 .843 r
.59855 .15048 .60103 .15562 .60587 .15614 .60339 .15079 Metetra
.457 .519 .833 r
.60339 .15079 .60587 .15614 .61073 .15695 .60824 .15135 Metetra
.434 .494 .822 r
.60824 .15135 .61073 .15695 .61561 .15811 .61311 .15221 Metetra
.408 .466 .808 r
.61311 .15221 .61561 .15811 .62053 .15971 .61802 .15343 Metetra
.377 .432 .791 r
.61802 .15343 .62053 .15971 .62549 .16186 .62296 .1551 Metetra
.34 .392 .77 r
.62296 .1551 .62549 .16186 .63049 .16474 .62794 .15736 Metetra
.296 .345 .743 r
.62794 .15736 .63049 .16474 .63556 .16859 .63297 .16037 Metetra
.244 .289 .71 r
.63297 .16037 .63556 .16859 .6407 .17381 .63806 .16441 Metetra
.184 .223 .669 r
.63806 .16441 .6407 .17381 .64596 .18102 .64323 .1699 Metetra
.113 .147 .618 r
.64323 .1699 .64596 .18102 .65138 .19138 .64853 .17754 Metetra
.034 .062 .557 r
.64853 .17754 .65138 .19138 .6571 .20728 .65402 .18863 Metetra
0 0 .487 r
.65402 .18863 .6571 .20728 .6634 .23461 .65983 .2059 Metetra
0 0 .409 r
.65983 .2059 .6634 .23461 .67136 .29488 .66634 .23652 Metetra
0 0 .339 r
.66634 .23652 .67136 .29488 .67728 .3088 .6748 .30556 Metetra
.645 .763 .934 r
.6748 .30556 .67728 .3088 .67023 .06389 .68 .3038 Metetra
0 0 .335 r
.68 .3038 .67023 .06389 .67502 .06207 .67272 .05869 Metetra
.664 .741 .907 r
.67272 .05869 .67502 .06207 .67981 .06024 .67752 .05685 Metetra
.664 .741 .907 r
.67752 .05685 .67981 .06024 .68462 .0584 .68233 .05501 Metetra
.664 .741 .907 r
.68233 .05501 .68462 .0584 .68943 .05657 .68715 .05317 Metetra
.664 .741 .907 r
.68715 .05317 .68943 .05657 .69425 .05473 .69198 .05132 Metetra
.664 .741 .907 r
.69198 .05132 .69425 .05473 .69908 .05289 .69681 .04948 Metetra
.664 .741 .907 r
.69681 .04948 .69908 .05289 .70391 .05104 .70165 .04763 Metetra
.664 .741 .907 r
.70165 .04763 .70391 .05104 .70876 .04919 .7065 .04577 Metetra
.664 .741 .907 r
.7065 .04577 .70876 .04919 .71361 .04734 .71136 .04391 Metetra
.664 .741 .907 r
.71136 .04391 .71361 .04734 .71847 .04549 .71623 .04205 Metetra
.664 .741 .907 r
.0696 .28544 .0725 .28814 .07634 .28668 .07344 .28396 Metetra
.664 .741 .907 r
.07344 .28396 .07634 .28668 .08018 .28521 .07728 .28249 Metetra
.664 .741 .907 r
.07728 .28249 .08018 .28521 .08402 .28374 .08113 .28102 Metetra
.664 .741 .907 r
.08113 .28102 .08402 .28374 .08787 .28227 .08499 .27954 Metetra
.664 .741 .907 r
.08499 .27954 .08787 .28227 .09173 .28079 .08885 .27806 Metetra
.664 .741 .907 r
.08885 .27806 .09173 .28079 .0956 .27931 .09272 .27658 Metetra
.664 .741 .907 r
.09272 .27658 .0956 .27931 .09947 .27783 .09659 .2751 Metetra
.664 .741 .907 r
.09659 .2751 .09947 .27783 .10334 .27635 .10047 .27361 Metetra
.664 .741 .907 r
.10047 .27361 .10334 .27635 .10722 .27487 .10435 .27212 Metetra
.942 .681 .513 r
.10435 .27212 .10722 .27487 .0799 .50691 .07677 .5043 Metetra
.936 .701 .558 r
.07677 .5043 .0799 .50691 .08406 .5055 .08897 .4427 Metetra
.703 .46 .553 r
.08897 .4427 .08406 .5055 .09711 .43643 .09767 .4065 Metetra
.73 .498 .576 r
.09767 .4065 .09711 .43643 .10525 .40391 .10434 .38525 Metetra
.744 .526 .599 r
.10434 .38525 .10525 .40391 .11168 .38413 .1101 .37063 Metetra
.751 .549 .622 r
.1101 .37063 .11168 .38413 .11732 .37027 .11537 .35963 Metetra
.755 .568 .643 r
.11537 .35963 .11732 .37027 .12251 .35971 .12034 .35084 Metetra
.756 .584 .664 r
.12034 .35084 .12251 .35971 .12743 .35121 .12512 .34353 Metetra
.756 .599 .683 r
.12512 .34353 .12743 .35121 .13217 .3441 .12975 .33726 Metetra
.755 .612 .7 r
.12975 .33726 .13217 .3441 .13678 .33797 .13429 .33176 Metetra
.753 .624 .717 r
.13429 .33176 .13678 .33797 .1413 .33258 .13875 .32684 Metetra
.75 .634 .731 r
.13875 .32684 .1413 .33258 .14574 .32774 .14315 .32237 Metetra
.747 .643 .745 r
.14315 .32237 .14574 .32774 .15013 .32334 .14751 .31827 Metetra
.744 .651 .757 r
.14751 .31827 .15013 .32334 .15448 .31929 .15183 .31446 Metetra
.741 .658 .768 r
.15183 .31446 .15448 .31929 .15879 .31553 .15612 .3109 Metetra
.738 .664 .778 r
.15612 .3109 .15879 .31553 .16308 .312 .1604 .30753 Metetra
.735 .67 .787 r
.1604 .30753 .16308 .312 .16735 .30867 .16465 .30434 Metetra
.732 .675 .795 r
.16465 .30434 .16735 .30867 .1716 .30551 .16889 .3013 Metetra
.729 .68 .803 r
.16889 .3013 .1716 .30551 .17583 .30249 .17311 .29839 Metetra
.726 .684 .809 r
.17311 .29839 .17583 .30249 .18006 .2996 .17733 .29558 Metetra
.723 .687 .815 r
.17733 .29558 .18006 .2996 .18427 .29681 .18154 .29287 Metetra
.72 .691 .821 r
.18154 .29287 .18427 .29681 .18848 .29412 .18574 .29025 Metetra
.718 .694 .826 r
.18574 .29025 .18848 .29412 .19268 .29151 .18994 .2877 Metetra
.923 .711 .599 r
.18994 .2877 .19268 .29151 .19688 .28898 .19629 .26496 Metetra
.554 .363 .576 r
.19629 .26496 .19688 .28898 .20318 .2663 .20041 .263 Metetra
.69 .718 .871 r
.20041 .263 .20318 .2663 .2073 .26436 .20453 .26108 Metetra
.688 .719 .873 r
.20453 .26108 .2073 .26436 .21142 .26244 .20865 .25917 Metetra
.686 .72 .875 r
.20865 .25917 .21142 .26244 .21554 .26054 .21278 .25729 Metetra
.685 .721 .877 r
.21278 .25729 .21554 .26054 .21967 .25866 .21691 .25543 Metetra
.684 .722 .878 r
.21691 .25543 .21967 .25866 .2238 .25681 .22104 .25358 Metetra
.683 .723 .88 r
.22104 .25358 .2238 .25681 .22794 .25497 .22518 .25175 Metetra
.681 .723 .881 r
.22518 .25175 .22794 .25497 .23208 .25314 .22932 .24993 Metetra
.68 .724 .883 r
.22932 .24993 .23208 .25314 .23622 .25133 .23347 .24812 Metetra
.679 .724 .884 r
.23347 .24812 .23622 .25133 .24037 .24953 .23762 .24633 Metetra
.678 .725 .885 r
.23762 .24633 .24037 .24953 .24452 .24774 .24177 .24455 Metetra
.678 .725 .886 r
.24177 .24455 .24452 .24774 .24868 .24597 .24593 .24278 Metetra
.677 .726 .887 r
.24593 .24278 .24868 .24597 .25284 .2442 .2501 .24102 Metetra
.676 .726 .888 r
.2501 .24102 .25284 .2442 .25701 .24244 .25427 .23926 Metetra
.675 .726 .888 r
.25427 .23926 .25701 .24244 .26118 .24069 .25844 .23752 Metetra
.674 .727 .889 r
.25844 .23752 .26118 .24069 .26536 .23895 .26262 .23578 Metetra
.674 .727 .89 r
.26262 .23578 .26536 .23895 .26954 .23722 .26681 .23405 Metetra
.673 .727 .89 r
.26681 .23405 .26954 .23722 .27373 .23549 .271 .23232 Metetra
.672 .727 .891 r
.271 .23232 .27373 .23549 .27792 .23377 .2752 .2306 Metetra
.672 .728 .892 r
.2752 .2306 .27792 .23377 .28212 .23206 .2794 .22889 Metetra
.671 .728 .892 r
.2794 .22889 .28212 .23206 .28632 .23035 .28361 .22718 Metetra
.67 .728 .893 r
.28361 .22718 .28632 .23035 .29054 .22865 .28783 .22548 Metetra
.67 .728 .893 r
.28783 .22548 .29054 .22865 .29475 .22695 .29205 .22378 Metetra
.669 .728 .894 r
.29205 .22378 .29475 .22695 .29898 .22526 .29627 .22208 Metetra
.669 .728 .894 r
.29627 .22208 .29898 .22526 .3032 .22357 .3005 .22039 Metetra
.668 .728 .894 r
.3005 .22039 .3032 .22357 .30744 .22188 .30474 .2187 Metetra
.668 .728 .895 r
.30474 .2187 .30744 .22188 .31168 .2202 .30899 .21702 Metetra
.667 .728 .895 r
.30899 .21702 .31168 .2202 .31593 .21852 .31324 .21534 Metetra
.667 .728 .896 r
.31324 .21534 .31593 .21852 .32018 .21685 .31749 .21366 Metetra
.666 .728 .896 r
.31749 .21366 .32018 .21685 .32444 .21518 .32176 .21199 Metetra
.666 .728 .896 r
.32176 .21199 .32444 .21518 .3287 .21351 .32603 .21032 Metetra
.665 .728 .896 r
.32603 .21032 .3287 .21351 .33298 .21184 .3303 .20865 Metetra
.665 .728 .897 r
.3303 .20865 .33298 .21184 .33725 .21018 .33459 .20699 Metetra
.665 .728 .897 r
.33459 .20699 .33725 .21018 .34154 .20852 .33887 .20532 Metetra
.664 .728 .897 r
.33887 .20532 .34154 .20852 .34583 .20687 .34317 .20366 Metetra
.664 .728 .898 r
.34317 .20366 .34583 .20687 .35013 .20521 .34747 .20201 Metetra
.663 .728 .898 r
.34747 .20201 .35013 .20521 .35443 .20356 .35178 .20035 Metetra
.663 .728 .898 r
.35178 .20035 .35443 .20356 .35874 .20191 .35609 .1987 Metetra
.662 .728 .898 r
.35609 .1987 .35874 .20191 .36306 .20027 .36042 .19705 Metetra
.662 .728 .898 r
.36042 .19705 .36306 .20027 .36739 .19862 .36474 .1954 Metetra
.661 .728 .899 r
.36474 .1954 .36739 .19862 .37172 .19698 .36908 .19375 Metetra
.661 .728 .899 r
.36908 .19375 .37172 .19698 .37606 .19534 .37342 .19211 Metetra
.661 .728 .899 r
.37342 .19211 .37606 .19534 .3804 .1937 .37777 .19046 Metetra
.66 .727 .899 r
.37777 .19046 .3804 .1937 .38475 .19207 .38213 .18882 Metetra
.66 .727 .899 r
.38213 .18882 .38475 .19207 .38911 .19044 .38649 .18719 Metetra
.659 .727 .899 r
.38649 .18719 .38911 .19044 .39348 .18881 .39086 .18555 Metetra
.659 .727 .899 r
.39086 .18555 .39348 .18881 .39785 .18718 .39523 .18392 Metetra
.658 .727 .899 r
.39523 .18392 .39785 .18718 .40223 .18555 .39962 .18229 Metetra
.658 .726 .9 r
.39962 .18229 .40223 .18555 .40661 .18393 .40401 .18066 Metetra
.658 .726 .9 r
.40401 .18066 .40661 .18393 .41101 .18231 .40841 .17903 Metetra
.657 .726 .9 r
.40841 .17903 .41101 .18231 .41541 .18069 .41281 .17741 Metetra
.657 .725 .9 r
.41281 .17741 .41541 .18069 .41981 .17908 .41722 .17579 Metetra
.656 .725 .9 r
.41722 .17579 .41981 .17908 .42423 .17747 .42164 .17417 Metetra
.656 .725 .9 r
.42164 .17417 .42423 .17747 .42865 .17586 .42607 .17255 Metetra
.655 .725 .9 r
.42607 .17255 .42865 .17586 .43308 .17426 .4305 .17094 Metetra
.655 .724 .9 r
.4305 .17094 .43308 .17426 .43752 .17265 .43494 .16933 Metetra
.654 .724 .9 r
.43494 .16933 .43752 .17265 .44196 .17106 .43939 .16772 Metetra
.653 .723 .9 r
.43939 .16772 .44196 .17106 .44641 .16946 .44385 .16612 Metetra
.653 .723 .9 r
.44385 .16612 .44641 .16946 .45087 .16787 .44831 .16452 Metetra
.652 .722 .9 r
.44831 .16452 .45087 .16787 .45534 .16629 .45278 .16293 Metetra
.652 .722 .9 r
.45278 .16293 .45534 .16629 .45981 .1647 .45726 .16134 Metetra
.651 .721 .9 r
.45726 .16134 .45981 .1647 .46429 .16313 .46174 .15975 Metetra
.65 .721 .9 r
.46174 .15975 .46429 .16313 .46878 .16156 .46624 .15817 Metetra
.649 .72 .9 r
.46624 .15817 .46878 .16156 .47328 .15999 .47074 .15659 Metetra
.649 .719 .9 r
.47074 .15659 .47328 .15999 .47778 .15843 .47525 .15502 Metetra
.648 .719 .9 r
.47525 .15502 .47778 .15843 .48229 .15688 .47976 .15346 Metetra
.647 .718 .9 r
.47976 .15346 .48229 .15688 .48681 .15533 .48429 .1519 Metetra
.646 .717 .9 r
.48429 .1519 .48681 .15533 .49134 .15379 .48882 .15035 Metetra
.645 .716 .9 r
.48882 .15035 .49134 .15379 .49588 .15226 .49336 .1488 Metetra
.644 .715 .9 r
.49336 .1488 .49588 .15226 .50042 .15074 .49791 .14727 Metetra
.643 .714 .899 r
.49791 .14727 .50042 .15074 .50497 .14922 .50246 .14574 Metetra
.642 .713 .899 r
.50246 .14574 .50497 .14922 .50953 .14772 .50703 .14422 Metetra
.641 .712 .899 r
.50703 .14422 .50953 .14772 .5141 .14623 .5116 .14271 Metetra
.64 .711 .899 r
.5116 .14271 .5141 .14623 .51868 .14475 .51618 .14122 Metetra
.638 .71 .899 r
.51618 .14122 .51868 .14475 .52326 .14328 .52077 .13973 Metetra
.637 .708 .898 r
.52077 .13973 .52326 .14328 .52785 .14182 .52537 .13826 Metetra
.635 .707 .898 r
.52537 .13826 .52785 .14182 .53246 .14039 .52997 .1368 Metetra
.633 .705 .898 r
.52997 .1368 .53246 .14039 .53707 .13897 .53459 .13536 Metetra
.632 .703 .897 r
.53459 .13536 .53707 .13897 .54169 .13756 .53921 .13393 Metetra
.63 .701 .897 r
.53921 .13393 .54169 .13756 .54631 .13618 .54384 .13253 Metetra
.627 .699 .896 r
.54384 .13253 .54631 .13618 .55095 .13483 .54848 .13114 Metetra
.625 .696 .896 r
.54848 .13114 .55095 .13483 .5556 .13349 .55313 .12978 Metetra
.622 .693 .895 r
.55313 .12978 .5556 .13349 .56051 .15337 .55779 .12845 Metetra
0 0 .46 r
.55779 .12845 .56051 .15337 .56522 .15265 .56274 .14839 Metetra
.564 .634 .878 r
.56274 .14839 .56522 .15265 .56993 .15201 .56746 .14768 Metetra
.557 .626 .876 r
.56746 .14768 .56993 .15201 .57467 .15146 .57219 .14705 Metetra
.549 .617 .873 r
.57219 .14705 .57467 .15146 .57941 .151 .57694 .1465 Metetra
.54 .608 .87 r
.57694 .1465 .57941 .151 .58417 .15065 .5817 .14605 Metetra
.53 .597 .866 r
.5817 .14605 .58417 .15065 .58895 .15044 .58647 .14572 Metetra
.519 .585 .861 r
.58647 .14572 .58895 .15044 .59374 .15037 .59127 .14552 Metetra
.506 .571 .855 r
.59127 .14552 .59374 .15037 .59855 .15048 .59607 .14547 Metetra
.491 .555 .849 r
.59607 .14547 .59855 .15048 .60339 .15079 .6009 .1456 Metetra
.474 .536 .841 r
.6009 .1456 .60339 .15079 .60824 .15135 .60575 .14595 Metetra
.454 .515 .831 r
.60575 .14595 .60824 .15135 .61311 .15221 .61062 .14654 Metetra
.431 .49 .82 r
.61062 .14654 .61311 .15221 .61802 .15343 .61551 .14744 Metetra
.404 .461 .805 r
.61551 .14744 .61802 .15343 .62296 .1551 .62044 .14872 Metetra
.371 .426 .788 r
.62044 .14872 .62296 .1551 .62794 .15736 .6254 .15048 Metetra
.334 .385 .766 r
.6254 .15048 .62794 .15736 .63297 .16037 .6304 .15283 Metetra
.289 .336 .738 r
.6304 .15283 .63297 .16037 .63806 .16441 .63545 .15599 Metetra
.236 .279 .704 r
.63545 .15599 .63806 .16441 .64323 .1699 .64057 .16023 Metetra
.174 .212 .661 r
.64057 .16023 .64323 .1699 .64853 .17754 .64578 .16601 Metetra
.102 .134 .609 r
.64578 .16601 .64853 .17754 .65402 .18863 .65113 .17411 Metetra
.022 .048 .547 r
.65113 .17411 .65402 .18863 .65983 .2059 .65668 .18598 Metetra
0 0 .475 r
.65668 .18598 .65983 .2059 .66634 .23652 .6626 .20478 Metetra
0 0 .396 r
.6626 .20478 .66634 .23652 .6748 .30556 .66934 .23927 Metetra
0 0 .403 r
.66934 .23927 .6748 .30556 .68 .3038 .67752 .30054 Metetra
.978 .678 .346 r
.67752 .30054 .68 .3038 .67272 .05869 .67042 .05529 Metetra
.664 .741 .907 r
.67042 .05529 .67272 .05869 .67752 .05685 .67523 .05345 Metetra
.664 .741 .907 r
.67523 .05345 .67752 .05685 .68233 .05501 .68004 .05161 Metetra
.664 .741 .907 r
.68004 .05161 .68233 .05501 .68715 .05317 .68486 .04976 Metetra
.664 .741 .907 r
.68486 .04976 .68715 .05317 .69198 .05132 .6897 .04791 Metetra
.664 .741 .907 r
.6897 .04791 .69198 .05132 .69681 .04948 .69454 .04606 Metetra
.664 .741 .907 r
.69454 .04606 .69681 .04948 .70165 .04763 .69938 .0442 Metetra
.664 .741 .907 r
.69938 .0442 .70165 .04763 .7065 .04577 .70424 .04234 Metetra
.664 .741 .907 r
.70424 .04234 .7065 .04577 .71136 .04391 .7091 .04048 Metetra
.664 .741 .907 r
.7091 .04048 .71136 .04391 .71623 .04205 .71398 .03861 Metetra
.664 .741 .907 r
.06669 .28272 .0696 .28544 .07344 .28396 .07053 .28125 Metetra
.664 .741 .907 r
.07053 .28125 .07344 .28396 .07728 .28249 .07438 .27977 Metetra
.664 .741 .907 r
.07438 .27977 .07728 .28249 .08113 .28102 .07823 .27829 Metetra
.664 .741 .907 r
.07823 .27829 .08113 .28102 .08499 .27954 .08209 .27681 Metetra
.664 .741 .907 r
.08209 .27681 .08499 .27954 .08885 .27806 .08596 .27533 Metetra
.664 .741 .907 r
.08596 .27533 .08885 .27806 .09272 .27658 .08983 .27384 Metetra
.664 .741 .907 r
.08983 .27384 .09272 .27658 .09659 .2751 .0937 .27235 Metetra
.664 .741 .907 r
.0937 .27235 .09659 .2751 .10047 .27361 .09759 .27086 Metetra
.941 .681 .514 r
.09759 .27086 .10047 .27361 .10435 .27212 .06947 .50311 Metetra
.365 .143 .439 r
.06947 .50311 .10435 .27212 .07677 .5043 .08065 .44997 Metetra
.734 .49 .558 r
.08065 .44997 .07677 .5043 .08897 .4427 .09003 .40938 Metetra
.725 .491 .572 r
.09003 .40938 .08897 .4427 .09767 .4065 .09696 .38649 Metetra
.742 .522 .595 r
.09696 .38649 .09767 .4065 .10434 .38525 .10286 .37105 Metetra
.75 .545 .618 r
.10286 .37105 .10434 .38525 .1101 .37063 .10821 .35957 Metetra
.754 .564 .639 r
.10821 .35957 .1101 .37063 .11537 .35963 .11324 .35049 Metetra
.756 .581 .66 r
.11324 .35049 .11537 .35963 .12034 .35084 .11805 .34297 Metetra
.756 .596 .68 r
.11805 .34297 .12034 .35084 .12512 .34353 .12271 .33656 Metetra
.755 .61 .698 r
.12271 .33656 .12512 .34353 .12975 .33726 .12727 .33094 Metetra
.753 .621 .714 r
.12727 .33094 .12975 .33726 .13429 .33176 .13174 .32594 Metetra
.75 .632 .729 r
.13174 .32594 .13429 .33176 .13875 .32684 .13616 .3214 Metetra
.747 .641 .743 r
.13616 .3214 .13875 .32684 .14315 .32237 .14053 .31725 Metetra
.744 .649 .755 r
.14053 .31725 .14315 .32237 .14751 .31827 .14486 .31339 Metetra
.741 .657 .766 r
.14486 .31339 .14751 .31827 .15183 .31446 .14916 .30979 Metetra
.738 .663 .776 r
.14916 .30979 .15183 .31446 .15612 .3109 .15343 .30639 Metetra
.735 .669 .785 r
.15343 .30639 .15612 .3109 .1604 .30753 .15769 .30318 Metetra
.732 .674 .794 r
.15769 .30318 .1604 .30753 .16465 .30434 .16193 .30011 Metetra
.729 .679 .801 r
.16193 .30011 .16465 .30434 .16889 .3013 .16616 .29717 Metetra
.726 .683 .808 r
.16616 .29717 .16889 .3013 .17311 .29839 .17038 .29435 Metetra
.723 .687 .814 r
.17038 .29435 .17311 .29839 .17733 .29558 .17459 .29162 Metetra
.721 .69 .82 r
.17459 .29162 .17733 .29558 .18154 .29287 .1788 .28899 Metetra
.718 .693 .825 r
.1788 .28899 .18154 .29287 .18574 .29025 .183 .28642 Metetra
.922 .711 .599 r
.183 .28642 .18574 .29025 .18994 .2877 .1894 .26361 Metetra
.554 .362 .576 r
.1894 .26361 .18994 .2877 .19629 .26496 .19352 .26165 Metetra
.69 .718 .871 r
.19352 .26165 .19629 .26496 .20041 .263 .19764 .25972 Metetra
.688 .719 .873 r
.19764 .25972 .20041 .263 .20453 .26108 .20176 .25781 Metetra
.687 .72 .875 r
.20176 .25781 .20453 .26108 .20865 .25917 .20588 .25592 Metetra
.685 .721 .877 r
.20588 .25592 .20865 .25917 .21278 .25729 .21001 .25404 Metetra
.684 .722 .878 r
.21001 .25404 .21278 .25729 .21691 .25543 .21414 .25219 Metetra
.683 .723 .88 r
.21414 .25219 .21691 .25543 .22104 .25358 .21828 .25035 Metetra
.682 .723 .881 r
.21828 .25035 .22104 .25358 .22518 .25175 .22242 .24853 Metetra
.681 .724 .882 r
.22242 .24853 .22518 .25175 .22932 .24993 .22656 .24672 Metetra
.68 .724 .883 r
.22656 .24672 .22932 .24993 .23347 .24812 .23071 .24492 Metetra
.679 .725 .885 r
.23071 .24492 .23347 .24812 .23762 .24633 .23486 .24313 Metetra
.678 .725 .886 r
.23486 .24313 .23762 .24633 .24177 .24455 .23902 .24136 Metetra
.677 .726 .887 r
.23902 .24136 .24177 .24455 .24593 .24278 .24318 .23959 Metetra
.676 .726 .887 r
.24318 .23959 .24593 .24278 .2501 .24102 .24735 .23783 Metetra
.675 .726 .888 r
.24735 .23783 .2501 .24102 .25427 .23926 .25152 .23608 Metetra
.675 .727 .889 r
.25152 .23608 .25427 .23926 .25844 .23752 .2557 .23434 Metetra
.674 .727 .89 r
.2557 .23434 .25844 .23752 .26262 .23578 .25989 .2326 Metetra
.673 .727 .89 r
.25989 .2326 .26262 .23578 .26681 .23405 .26408 .23087 Metetra
.673 .727 .891 r
.26408 .23087 .26681 .23405 .271 .23232 .26827 .22915 Metetra
.672 .728 .892 r
.26827 .22915 .271 .23232 .2752 .2306 .27247 .22743 Metetra
.671 .728 .892 r
.27247 .22743 .2752 .2306 .2794 .22889 .27668 .22571 Metetra
.671 .728 .893 r
.27668 .22571 .2794 .22889 .28361 .22718 .28089 .224 Metetra
.67 .728 .893 r
.28089 .224 .28361 .22718 .28783 .22548 .28511 .2223 Metetra
.67 .728 .894 r
.28511 .2223 .28783 .22548 .29205 .22378 .28933 .2206 Metetra
.669 .728 .894 r
.28933 .2206 .29205 .22378 .29627 .22208 .29356 .2189 Metetra
.669 .728 .894 r
.29356 .2189 .29627 .22208 .3005 .22039 .2978 .21721 Metetra
.668 .729 .895 r
.2978 .21721 .3005 .22039 .30474 .2187 .30204 .21552 Metetra
.668 .729 .895 r
.30204 .21552 .30474 .2187 .30899 .21702 .30629 .21384 Metetra
.667 .729 .896 r
.30629 .21384 .30899 .21702 .31324 .21534 .31054 .21215 Metetra
.667 .729 .896 r
.31054 .21215 .31324 .21534 .31749 .21366 .3148 .21047 Metetra
.666 .729 .896 r
.3148 .21047 .31749 .21366 .32176 .21199 .31907 .2088 Metetra
.666 .729 .896 r
.31907 .2088 .32176 .21199 .32603 .21032 .32334 .20712 Metetra
.665 .729 .897 r
.32334 .20712 .32603 .21032 .3303 .20865 .32762 .20545 Metetra
.665 .729 .897 r
.32762 .20545 .3303 .20865 .33459 .20699 .33191 .20378 Metetra
.664 .729 .897 r
.33191 .20378 .33459 .20699 .33887 .20532 .3362 .20212 Metetra
.664 .729 .898 r
.3362 .20212 .33887 .20532 .34317 .20366 .3405 .20045 Metetra
.664 .728 .898 r
.3405 .20045 .34317 .20366 .34747 .20201 .34481 .19879 Metetra
.663 .728 .898 r
.34481 .19879 .34747 .20201 .35178 .20035 .34912 .19713 Metetra
.663 .728 .898 r
.34912 .19713 .35178 .20035 .35609 .1987 .35344 .19547 Metetra
.662 .728 .898 r
.35344 .19547 .35609 .1987 .36042 .19705 .35776 .19382 Metetra
.662 .728 .899 r
.35776 .19382 .36042 .19705 .36474 .1954 .36209 .19217 Metetra
.662 .728 .899 r
.36209 .19217 .36474 .1954 .36908 .19375 .36643 .19051 Metetra
.661 .728 .899 r
.36643 .19051 .36908 .19375 .37342 .19211 .37078 .18886 Metetra
.661 .728 .899 r
.37078 .18886 .37342 .19211 .37777 .19046 .37513 .18722 Metetra
.66 .728 .899 r
.37513 .18722 .37777 .19046 .38213 .18882 .37949 .18557 Metetra
.66 .727 .899 r
.37949 .18557 .38213 .18882 .38649 .18719 .38386 .18393 Metetra
.659 .727 .899 r
.38386 .18393 .38649 .18719 .39086 .18555 .38823 .18229 Metetra
.659 .727 .9 r
.38823 .18229 .39086 .18555 .39523 .18392 .39261 .18065 Metetra
.659 .727 .9 r
.39261 .18065 .39523 .18392 .39962 .18229 .397 .17901 Metetra
.658 .727 .9 r
.397 .17901 .39962 .18229 .40401 .18066 .4014 .17738 Metetra
.658 .726 .9 r
.4014 .17738 .40401 .18066 .40841 .17903 .4058 .17574 Metetra
.657 .726 .9 r
.4058 .17574 .40841 .17903 .41281 .17741 .41021 .17411 Metetra
.657 .726 .9 r
.41021 .17411 .41281 .17741 .41722 .17579 .41462 .17249 Metetra
.656 .726 .9 r
.41462 .17249 .41722 .17579 .42164 .17417 .41905 .17086 Metetra
.656 .725 .9 r
.41905 .17086 .42164 .17417 .42607 .17255 .42348 .16924 Metetra
.655 .725 .9 r
.42348 .16924 .42607 .17255 .4305 .17094 .42791 .16762 Metetra
.655 .725 .9 r
.42791 .16762 .4305 .17094 .43494 .16933 .43236 .166 Metetra
.654 .724 .9 r
.43236 .166 .43494 .16933 .43939 .16772 .43681 .16439 Metetra
.654 .724 .9 r
.43681 .16439 .43939 .16772 .44385 .16612 .44127 .16278 Metetra
.653 .723 .9 r
.44127 .16278 .44385 .16612 .44831 .16452 .44574 .16117 Metetra
.653 .723 .9 r
.44574 .16117 .44831 .16452 .45278 .16293 .45021 .15956 Metetra
.652 .722 .9 r
.45021 .15956 .45278 .16293 .45726 .16134 .4547 .15797 Metetra
.651 .722 .9 r
.4547 .15797 .45726 .16134 .46174 .15975 .45919 .15637 Metetra
.651 .721 .9 r
.45919 .15637 .46174 .15975 .46624 .15817 .46368 .15478 Metetra
.65 .721 .9 r
.46368 .15478 .46624 .15817 .47074 .15659 .46819 .15319 Metetra
.649 .72 .9 r
.46819 .15319 .47074 .15659 .47525 .15502 .4727 .15161 Metetra
.648 .719 .9 r
.4727 .15161 .47525 .15502 .47976 .15346 .47722 .15004 Metetra
.648 .719 .9 r
.47722 .15004 .47976 .15346 .48429 .1519 .48175 .14847 Metetra
.647 .718 .9 r
.48175 .14847 .48429 .1519 .48882 .15035 .48629 .1469 Metetra
.646 .717 .9 r
.48629 .1469 .48882 .15035 .49336 .1488 .49083 .14535 Metetra
.645 .716 .9 r
.49083 .14535 .49336 .1488 .49791 .14727 .49539 .1438 Metetra
.644 .715 .9 r
.49539 .1438 .49791 .14727 .50246 .14574 .49995 .14226 Metetra
.643 .714 .899 r
.49995 .14226 .50246 .14574 .50703 .14422 .50451 .14072 Metetra
.642 .713 .899 r
.50451 .14072 .50703 .14422 .5116 .14271 .50909 .1392 Metetra
.641 .712 .899 r
.50909 .1392 .5116 .14271 .51618 .14122 .51368 .13769 Metetra
.639 .711 .899 r
.51368 .13769 .51618 .14122 .52077 .13973 .51827 .13618 Metetra
.638 .709 .899 r
.51827 .13618 .52077 .13973 .52537 .13826 .52287 .13469 Metetra
.636 .708 .898 r
.52287 .13469 .52537 .13826 .52997 .1368 .52748 .13322 Metetra
.635 .706 .898 r
.52748 .13322 .52997 .1368 .53459 .13536 .5321 .13176 Metetra
.633 .705 .898 r
.5321 .13176 .53459 .13536 .53921 .13393 .53673 .13031 Metetra
.631 .703 .897 r
.53673 .13031 .53921 .13393 .54384 .13253 .54136 .12888 Metetra
.629 .701 .897 r
.54136 .12888 .54384 .13253 .54848 .13114 .54601 .12747 Metetra
.627 .698 .896 r
.54601 .12747 .54848 .13114 .55313 .12978 .55066 .12608 Metetra
.624 .696 .896 r
.55066 .12608 .55313 .12978 .55779 .12845 .55533 .12472 Metetra
.622 .693 .895 r
.55533 .12472 .55779 .12845 .56274 .14839 .56 .12338 Metetra
0 0 .459 r
.56 .12338 .56274 .14839 .56746 .14768 .56497 .1434 Metetra
.563 .632 .878 r
.56497 .1434 .56746 .14768 .57219 .14705 .56971 .14269 Metetra
.556 .625 .875 r
.56971 .14269 .57219 .14705 .57694 .1465 .57446 .14206 Metetra
.548 .616 .872 r
.57446 .14206 .57694 .1465 .5817 .14605 .57922 .14152 Metetra
.539 .606 .869 r
.57922 .14152 .5817 .14605 .58647 .14572 .58399 .14108 Metetra
.529 .595 .865 r
.58399 .14108 .58647 .14572 .59127 .14552 .58879 .14076 Metetra
.517 .583 .86 r
.58879 .14076 .59127 .14552 .59607 .14547 .59359 .14058 Metetra
.504 .568 .854 r
.59359 .14058 .59607 .14547 .6009 .1456 .59842 .14055 Metetra
.489 .552 .847 r
.59842 .14055 .6009 .1456 .60575 .14595 .60326 .1407 Metetra
.471 .533 .839 r
.60326 .1407 .60575 .14595 .61062 .14654 .60813 .14108 Metetra
.451 .511 .829 r
.60813 .14108 .61062 .14654 .61551 .14744 .61301 .14171 Metetra
.427 .485 .817 r
.61301 .14171 .61551 .14744 .62044 .14872 .61793 .14266 Metetra
.399 .455 .803 r
.61793 .14266 .62044 .14872 .6254 .15048 .62287 .144 Metetra
.366 .42 .784 r
.62287 .144 .6254 .15048 .6304 .15283 .62785 .14583 Metetra
.327 .377 .761 r
.62785 .14583 .6304 .15283 .63545 .15599 .63288 .14829 Metetra
.282 .328 .733 r
.63288 .14829 .63545 .15599 .64057 .16023 .63795 .15159 Metetra
.227 .269 .697 r
.63795 .15159 .64057 .16023 .64578 .16601 .6431 .15604 Metetra
.164 .2 .653 r
.6431 .15604 .64578 .16601 .65113 .17411 .64835 .16212 Metetra
.092 .122 .599 r
.64835 .16212 .65113 .17411 .65668 .18598 .65374 .17071 Metetra
.01 .034 .536 r
.65374 .17071 .65668 .18598 .6626 .20478 .65936 .18342 Metetra
0 0 .463 r
.65936 .18342 .6626 .20478 .66934 .23927 .6654 .20395 Metetra
0 0 .384 r
.6654 .20395 .66934 .23927 .67752 .30054 .67242 .24305 Metetra
0 0 .411 r
.67242 .24305 .67752 .30054 .67042 .05529 .68025 .2955 Metetra
0 0 .333 r
.68025 .2955 .67042 .05529 .67523 .05345 .67292 .05005 Metetra
.664 .741 .907 r
.67292 .05005 .67523 .05345 .68004 .05161 .67774 .0482 Metetra
.664 .741 .907 r
.67774 .0482 .68004 .05161 .68486 .04976 .68257 .04634 Metetra
.664 .741 .907 r
.68257 .04634 .68486 .04976 .6897 .04791 .68741 .04449 Metetra
.664 .741 .907 r
.68741 .04449 .6897 .04791 .69454 .04606 .69225 .04263 Metetra
.664 .741 .907 r
.69225 .04263 .69454 .04606 .69938 .0442 .69711 .04076 Metetra
.664 .741 .907 r
.69711 .04076 .69938 .0442 .70424 .04234 .70197 .0389 Metetra
.664 .741 .907 r
.70197 .0389 .70424 .04234 .7091 .04048 .70684 .03703 Metetra
.664 .741 .907 r
.70684 .03703 .7091 .04048 .71398 .03861 .71172 .03516 Metetra
.664 .741 .907 r
.06378 .28 .06669 .28272 .07053 .28125 .06762 .27852 Metetra
.664 .741 .907 r
.06762 .27852 .07053 .28125 .07438 .27977 .07147 .27704 Metetra
.664 .741 .907 r
.07147 .27704 .07438 .27977 .07823 .27829 .07533 .27555 Metetra
.664 .741 .907 r
.07533 .27555 .07823 .27829 .08209 .27681 .07919 .27407 Metetra
.664 .741 .907 r
.07919 .27407 .08209 .27681 .08596 .27533 .08306 .27258 Metetra
.664 .741 .907 r
.08306 .27258 .08596 .27533 .08983 .27384 .08693 .27109 Metetra
.664 .741 .907 r
.08693 .27109 .08983 .27384 .0937 .27235 .09081 .2696 Metetra
.941 .681 .515 r
.09081 .2696 .0937 .27235 .09759 .27086 .06215 .50191 Metetra
.393 .167 .447 r
.06215 .50191 .09759 .27086 .06947 .50311 .07211 .45848 Metetra
.773 .527 .563 r
.07211 .45848 .06947 .50311 .08065 .44997 .08231 .41259 Metetra
.721 .484 .568 r
.08231 .41259 .08065 .44997 .09003 .40938 .08954 .38785 Metetra
.739 .517 .591 r
.08954 .38785 .09003 .40938 .09696 .38649 .09559 .37153 Metetra
.749 .541 .614 r
.09559 .37153 .09696 .38649 .10286 .37105 .10103 .35955 Metetra
.753 .561 .636 r
.10103 .35955 .10286 .37105 .10821 .35957 .10611 .35015 Metetra
.755 .578 .657 r
.10611 .35015 .10821 .35957 .11324 .35049 .11097 .34242 Metetra
.755 .594 .676 r
.11097 .34242 .11324 .35049 .11805 .34297 .11566 .33586 Metetra
.754 .607 .695 r
.11566 .33586 .11805 .34297 .12271 .33656 .12023 .33013 Metetra
.753 .619 .711 r
.12023 .33013 .12271 .33656 .12727 .33094 .12473 .32504 Metetra
.75 .63 .727 r
.12473 .32504 .12727 .33094 .13174 .32594 .12916 .32043 Metetra
.748 .639 .74 r
.12916 .32043 .13174 .32594 .13616 .3214 .13353 .31622 Metetra
.745 .648 .753 r
.13353 .31622 .13616 .3214 .14053 .31725 .13787 .31232 Metetra
.742 .655 .764 r
.13787 .31232 .14053 .31725 .14486 .31339 .14218 .30868 Metetra
.739 .662 .775 r
.14218 .30868 .14486 .31339 .14916 .30979 .14646 .30525 Metetra
.735 .668 .784 r
.14646 .30525 .14916 .30979 .15343 .30639 .15072 .30201 Metetra
.732 .673 .792 r
.15072 .30201 .15343 .30639 .15769 .30318 .15497 .29892 Metetra
.729 .678 .8 r
.15497 .29892 .15769 .30318 .16193 .30011 .1592 .29596 Metetra
.727 .682 .807 r
.1592 .29596 .16193 .30011 .16616 .29717 .16342 .29312 Metetra
.724 .686 .813 r
.16342 .29312 .16616 .29717 .17038 .29435 .16763 .29037 Metetra
.721 .689 .819 r
.16763 .29037 .17038 .29435 .17459 .29162 .17184 .28772 Metetra
.718 .693 .824 r
.17184 .28772 .17459 .29162 .1788 .28899 .17604 .28515 Metetra
.922 .71 .6 r
.17604 .28515 .1788 .28899 .183 .28642 .1825 .26226 Metetra
.553 .361 .575 r
.1825 .26226 .183 .28642 .1894 .26361 .18661 .2603 Metetra
.69 .718 .871 r
.18661 .2603 .1894 .26361 .19352 .26165 .19073 .25835 Metetra
.689 .719 .873 r
.19073 .25835 .19352 .26165 .19764 .25972 .19485 .25644 Metetra
.687 .72 .875 r
.19485 .25644 .19764 .25972 .20176 .25781 .19897 .25454 Metetra
.686 .721 .876 r
.19897 .25454 .20176 .25781 .20588 .25592 .2031 .25266 Metetra
.684 .722 .878 r
.2031 .25266 .20588 .25592 .21001 .25404 .20723 .2508 Metetra
.683 .723 .879 r
.20723 .2508 .21001 .25404 .21414 .25219 .21136 .24896 Metetra
.682 .723 .881 r
.21136 .24896 .21414 .25219 .21828 .25035 .2155 .24713 Metetra
.681 .724 .882 r
.2155 .24713 .21828 .25035 .22242 .24853 .21964 .24532 Metetra
.68 .724 .883 r
.21964 .24532 .22242 .24853 .22656 .24672 .22379 .24351 Metetra
.679 .725 .884 r
.22379 .24351 .22656 .24672 .23071 .24492 .22794 .24172 Metetra
.678 .725 .885 r
.22794 .24172 .23071 .24492 .23486 .24313 .2321 .23994 Metetra
.677 .726 .886 r
.2321 .23994 .23486 .24313 .23902 .24136 .23626 .23817 Metetra
.676 .726 .887 r
.23626 .23817 .23902 .24136 .24318 .23959 .24042 .2364 Metetra
.676 .726 .888 r
.24042 .2364 .24318 .23959 .24735 .23783 .24459 .23464 Metetra
.675 .727 .889 r
.24459 .23464 .24735 .23783 .25152 .23608 .24877 .2329 Metetra
.674 .727 .89 r
.24877 .2329 .25152 .23608 .2557 .23434 .25295 .23115 Metetra
.673 .727 .89 r
.25295 .23115 .2557 .23434 .25989 .2326 .25714 .22942 Metetra
.673 .728 .891 r
.25714 .22942 .25989 .2326 .26408 .23087 .26133 .22769 Metetra
.672 .728 .891 r
.26133 .22769 .26408 .23087 .26827 .22915 .26553 .22597 Metetra
.672 .728 .892 r
.26553 .22597 .26827 .22915 .27247 .22743 .26973 .22425 Metetra
.671 .728 .893 r
.26973 .22425 .27247 .22743 .27668 .22571 .27394 .22253 Metetra
.67 .728 .893 r
.27394 .22253 .27668 .22571 .28089 .224 .27816 .22082 Metetra
.67 .728 .894 r
.27816 .22082 .28089 .224 .28511 .2223 .28238 .21912 Metetra
.669 .728 .894 r
.28238 .21912 .28511 .2223 .28933 .2206 .28661 .21742 Metetra
.669 .729 .894 r
.28661 .21742 .28933 .2206 .29356 .2189 .29084 .21572 Metetra
.668 .729 .895 r
.29084 .21572 .29356 .2189 .2978 .21721 .29508 .21403 Metetra
.668 .729 .895 r
.29508 .21403 .2978 .21721 .30204 .21552 .29933 .21233 Metetra
.667 .729 .896 r
.29933 .21233 .30204 .21552 .30629 .21384 .30358 .21065 Metetra
.667 .729 .896 r
.30358 .21065 .30629 .21384 .31054 .21215 .30784 .20896 Metetra
.666 .729 .896 r
.30784 .20896 .31054 .21215 .3148 .21047 .3121 .20728 Metetra
.666 .729 .896 r
.3121 .20728 .3148 .21047 .31907 .2088 .31637 .2056 Metetra
.666 .729 .897 r
.31637 .2056 .31907 .2088 .32334 .20712 .32065 .20392 Metetra
.665 .729 .897 r
.32065 .20392 .32334 .20712 .32762 .20545 .32493 .20225 Metetra
.665 .729 .897 r
.32493 .20225 .32762 .20545 .33191 .20378 .32922 .20058 Metetra
.664 .729 .898 r
.32922 .20058 .33191 .20378 .3362 .20212 .33352 .19891 Metetra
.664 .729 .898 r
.33352 .19891 .3362 .20212 .3405 .20045 .33782 .19724 Metetra
.664 .729 .898 r
.33782 .19724 .3405 .20045 .34481 .19879 .34213 .19557 Metetra
.663 .729 .898 r
.34213 .19557 .34481 .19879 .34912 .19713 .34645 .19391 Metetra
.663 .729 .898 r
.34645 .19391 .34912 .19713 .35344 .19547 .35077 .19225 Metetra
.662 .728 .899 r
.35077 .19225 .35344 .19547 .35776 .19382 .3551 .19059 Metetra
.662 .728 .899 r
.3551 .19059 .35776 .19382 .36209 .19217 .35944 .18893 Metetra
.662 .728 .899 r
.35944 .18893 .36209 .19217 .36643 .19051 .36378 .18727 Metetra
.661 .728 .899 r
.36378 .18727 .36643 .19051 .37078 .18886 .36813 .18562 Metetra
.661 .728 .899 r
.36813 .18562 .37078 .18886 .37513 .18722 .37249 .18397 Metetra
.66 .728 .899 r
.37249 .18397 .37513 .18722 .37949 .18557 .37685 .18231 Metetra
.66 .728 .899 r
.37685 .18231 .37949 .18557 .38386 .18393 .38122 .18067 Metetra
.659 .728 .9 r
.38122 .18067 .38386 .18393 .38823 .18229 .3856 .17902 Metetra
.659 .727 .9 r
.3856 .17902 .38823 .18229 .39261 .18065 .38999 .17737 Metetra
.659 .727 .9 r
.38999 .17737 .39261 .18065 .397 .17901 .39438 .17573 Metetra
.658 .727 .9 r
.39438 .17573 .397 .17901 .4014 .17738 .39878 .17409 Metetra
.658 .727 .9 r
.39878 .17409 .4014 .17738 .4058 .17574 .40318 .17245 Metetra
.657 .726 .9 r
.40318 .17245 .4058 .17574 .41021 .17411 .4076 .17081 Metetra
.657 .726 .9 r
.4076 .17081 .41021 .17411 .41462 .17249 .41202 .16918 Metetra
.656 .726 .9 r
.41202 .16918 .41462 .17249 .41905 .17086 .41644 .16755 Metetra
.656 .726 .9 r
.41644 .16755 .41905 .17086 .42348 .16924 .42088 .16592 Metetra
.655 .725 .9 r
.42088 .16592 .42348 .16924 .42791 .16762 .42532 .16429 Metetra
.655 .725 .9 r
.42532 .16429 .42791 .16762 .43236 .166 .42977 .16266 Metetra
.654 .725 .9 r
.42977 .16266 .43236 .166 .43681 .16439 .43423 .16104 Metetra
.654 .724 .9 r
.43423 .16104 .43681 .16439 .44127 .16278 .43869 .15942 Metetra
.653 .724 .9 r
.43869 .15942 .44127 .16278 .44574 .16117 .44316 .15781 Metetra
.653 .723 .9 r
.44316 .15781 .44574 .16117 .45021 .15956 .44764 .1562 Metetra
.652 .723 .9 r
.44764 .1562 .45021 .15956 .4547 .15797 .45213 .15459 Metetra
.652 .722 .9 r
.45213 .15459 .4547 .15797 .45919 .15637 .45662 .15298 Metetra
.651 .722 .9 r
.45662 .15298 .45919 .15637 .46368 .15478 .46113 .15138 Metetra
.65 .721 .9 r
.46113 .15138 .46368 .15478 .46819 .15319 .46564 .14979 Metetra
.65 .721 .9 r
.46564 .14979 .46819 .15319 .4727 .15161 .47015 .1482 Metetra
.649 .72 .9 r
.47015 .1482 .4727 .15161 .47722 .15004 .47468 .14661 Metetra
.648 .719 .9 r
.47468 .14661 .47722 .15004 .48175 .14847 .47921 .14503 Metetra
.647 .719 .9 r
.47921 .14503 .48175 .14847 .48629 .1469 .48375 .14345 Metetra
.647 .718 .9 r
.48375 .14345 .48629 .1469 .49083 .14535 .4883 .14188 Metetra
.646 .717 .9 r
.4883 .14188 .49083 .14535 .49539 .1438 .49286 .14032 Metetra
.645 .716 .9 r
.49286 .14032 .49539 .1438 .49995 .14226 .49742 .13877 Metetra
.644 .715 .9 r
.49742 .13877 .49995 .14226 .50451 .14072 .50199 .13722 Metetra
.643 .714 .9 r
.50199 .13722 .50451 .14072 .50909 .1392 .50658 .13568 Metetra
.641 .713 .899 r
.50658 .13568 .50909 .1392 .51368 .13769 .51116 .13416 Metetra
.64 .712 .899 r
.51116 .13416 .51368 .13769 .51827 .13618 .51576 .13264 Metetra
.639 .711 .899 r
.51576 .13264 .51827 .13618 .52287 .13469 .52037 .13113 Metetra
.638 .709 .899 r
.52037 .13113 .52287 .13469 .52748 .13322 .52498 .12964 Metetra
.636 .708 .898 r
.52498 .12964 .52748 .13322 .5321 .13176 .52961 .12816 Metetra
.634 .706 .898 r
.52961 .12816 .5321 .13176 .53673 .13031 .53424 .12669 Metetra
.633 .704 .898 r
.53424 .12669 .53673 .13031 .54136 .12888 .53888 .12524 Metetra
.631 .702 .897 r
.53888 .12524 .54136 .12888 .54601 .12747 .54353 .12381 Metetra
.629 .7 .897 r
.54353 .12381 .54601 .12747 .55066 .12608 .54819 .12239 Metetra
.626 .698 .896 r
.54819 .12239 .55066 .12608 .55533 .12472 .55285 .121 Metetra
.624 .695 .896 r
.55285 .121 .55533 .12472 .56 .12338 .55753 .11963 Metetra
.621 .692 .895 r
.55753 .11963 .56 .12338 .56497 .1434 .56222 .11829 Metetra
0 0 .459 r
.56222 .11829 .56497 .1434 .56971 .14269 .56722 .13838 Metetra
.562 .631 .878 r
.56722 .13838 .56971 .14269 .57446 .14206 .57197 .13767 Metetra
.555 .623 .875 r
.57197 .13767 .57446 .14206 .57922 .14152 .57673 .13705 Metetra
.547 .614 .872 r
.57673 .13705 .57922 .14152 .58399 .14108 .58151 .13652 Metetra
.537 .605 .868 r
.58151 .13652 .58399 .14108 .58879 .14076 .5863 .13609 Metetra
.527 .593 .864 r
.5863 .13609 .58879 .14076 .59359 .14058 .59111 .13578 Metetra
.515 .581 .859 r
.59111 .13578 .59359 .14058 .59842 .14055 .59593 .13561 Metetra
.502 .566 .853 r
.59593 .13561 .59842 .14055 .60326 .1407 .60077 .1356 Metetra
.486 .549 .846 r
.60077 .1356 .60326 .1407 .60813 .14108 .60563 .13578 Metetra
.468 .53 .838 r
.60563 .13578 .60813 .14108 .61301 .14171 .61051 .13618 Metetra
.447 .507 .827 r
.61051 .13618 .61301 .14171 .61793 .14266 .61542 .13685 Metetra
.423 .481 .815 r
.61542 .13685 .61793 .14266 .62287 .144 .62035 .13785 Metetra
.395 .45 .8 r
.62035 .13785 .62287 .144 .62785 .14583 .62532 .13925 Metetra
.361 .413 .781 r
.62532 .13925 .62785 .14583 .63288 .14829 .63032 .14116 Metetra
.321 .37 .757 r
.63032 .14116 .63288 .14829 .63795 .15159 .63536 .14373 Metetra
.274 .319 .727 r
.63536 .14373 .63795 .15159 .6431 .15604 .64047 .14718 Metetra
.219 .259 .69 r
.64047 .14718 .6431 .15604 .64835 .16212 .64565 .15184 Metetra
.155 .189 .645 r
.64565 .15184 .64835 .16212 .65374 .17071 .65093 .15825 Metetra
.081 .109 .59 r
.65093 .15825 .65374 .17071 .65936 .18342 .65637 .16735 Metetra
0 .02 .525 r
.65637 .16735 .65936 .18342 .6654 .20395 .66207 .18099 Metetra
0 0 .452 r
.66207 .18099 .6654 .20395 .67242 .24305 .66824 .20345 Metetra
0 0 .371 r
.66824 .20345 .67242 .24305 .68025 .2955 .67559 .24812 Metetra
0 0 .425 r
.67559 .24812 .68025 .2955 .67292 .05005 .68299 .29043 Metetra
0 0 .333 r
.68299 .29043 .67292 .05005 .67774 .0482 .67544 .04477 Metetra
.664 .741 .907 r
.67544 .04477 .67774 .0482 .68257 .04634 .68027 .04291 Metetra
.664 .741 .907 r
.68027 .04291 .68257 .04634 .68741 .04449 .68512 .04105 Metetra
.664 .741 .907 r
.68512 .04105 .68741 .04449 .69225 .04263 .68997 .03918 Metetra
.664 .741 .907 r
.68997 .03918 .69225 .04263 .69711 .04076 .69483 .03732 Metetra
.664 .741 .907 r
.69483 .03732 .69711 .04076 .70197 .0389 .69969 .03544 Metetra
.664 .741 .907 r
.69969 .03544 .70197 .0389 .70684 .03703 .70457 .03357 Metetra
.664 .741 .907 r
.70457 .03357 .70684 .03703 .71172 .03516 .70945 .03169 Metetra
.664 .741 .907 r
.06085 .27727 .06378 .28 .06762 .27852 .0647 .27578 Metetra
.664 .741 .907 r
.0647 .27578 .06762 .27852 .07147 .27704 .06855 .2743 Metetra
.664 .741 .907 r
.06855 .2743 .07147 .27704 .07533 .27555 .07241 .27281 Metetra
.664 .741 .907 r
.07241 .27281 .07533 .27555 .07919 .27407 .07628 .27132 Metetra
.664 .741 .907 r
.07628 .27132 .07919 .27407 .08306 .27258 .08015 .26983 Metetra
.664 .741 .907 r
.08015 .26983 .08306 .27258 .08693 .27109 .08403 .26834 Metetra
.94 .681 .516 r
.08403 .26834 .08693 .27109 .09081 .2696 .05483 .50071 Metetra
.424 .192 .457 r
.05483 .50071 .09081 .2696 .06215 .50191 .0633 .46855 Metetra
.819 .573 .567 r
.0633 .46855 .06215 .50191 .07211 .45848 .07451 .41618 Metetra
.715 .477 .563 r
.07451 .41618 .07211 .45848 .08231 .41259 .08208 .38936 Metetra
.737 .512 .587 r
.08208 .38936 .08231 .41259 .08954 .38785 .0883 .37208 Metetra
.747 .537 .61 r
.0883 .37208 .08954 .38785 .09559 .37153 .09383 .35956 Metetra
.752 .557 .632 r
.09383 .35956 .09559 .37153 .10103 .35955 .09898 .34983 Metetra
.755 .575 .653 r
.09898 .34983 .10103 .35955 .10611 .35015 .10387 .34188 Metetra
.755 .591 .673 r
.10387 .34188 .10611 .35015 .11097 .34242 .10859 .33516 Metetra
.754 .605 .692 r
.10859 .33516 .11097 .34242 .11566 .33586 .11319 .32932 Metetra
.753 .617 .709 r
.11319 .32932 .11566 .33586 .12023 .33013 .1177 .32413 Metetra
.751 .628 .724 r
.1177 .32413 .12023 .33013 .12473 .32504 .12214 .31946 Metetra
.748 .638 .738 r
.12214 .31946 .12473 .32504 .12916 .32043 .12653 .31519 Metetra
.745 .646 .751 r
.12653 .31519 .12916 .32043 .13353 .31622 .13088 .31125 Metetra
.742 .654 .763 r
.13088 .31125 .13353 .31622 .13787 .31232 .13519 .30757 Metetra
.739 .661 .773 r
.13519 .30757 .13787 .31232 .14218 .30868 .13948 .30411 Metetra
.736 .667 .783 r
.13948 .30411 .14218 .30868 .14646 .30525 .14375 .30084 Metetra
.733 .672 .791 r
.14375 .30084 .14646 .30525 .15072 .30201 .14799 .29772 Metetra
.73 .677 .799 r
.14799 .29772 .15072 .30201 .15497 .29892 .15223 .29474 Metetra
.727 .681 .806 r
.15223 .29474 .15497 .29892 .1592 .29596 .15645 .29188 Metetra
.724 .685 .812 r
.15645 .29188 .1592 .29596 .16342 .29312 .16067 .28912 Metetra
.721 .689 .818 r
.16067 .28912 .16342 .29312 .16763 .29037 .16487 .28645 Metetra
.719 .692 .824 r
.16487 .28645 .16763 .29037 .17184 .28772 .16908 .28386 Metetra
.921 .71 .6 r
.16908 .28386 .17184 .28772 .17604 .28515 .17559 .26092 Metetra
.553 .36 .574 r
.17559 .26092 .17604 .28515 .1825 .26226 .1797 .25894 Metetra
.69 .718 .87 r
.1797 .25894 .1825 .26226 .18661 .2603 .18382 .25699 Metetra
.689 .719 .872 r
.18382 .25699 .18661 .2603 .19073 .25835 .18794 .25507 Metetra
.687 .72 .874 r
.18794 .25507 .19073 .25835 .19485 .25644 .19206 .25317 Metetra
.686 .721 .876 r
.19206 .25317 .19485 .25644 .19897 .25454 .19618 .25128 Metetra
.685 .722 .878 r
.19618 .25128 .19897 .25454 .2031 .25266 .20031 .24942 Metetra
.683 .723 .879 r
.20031 .24942 .2031 .25266 .20723 .2508 .20444 .24757 Metetra
.682 .723 .881 r
.20444 .24757 .20723 .2508 .21136 .24896 .20858 .24573 Metetra
.681 .724 .882 r
.20858 .24573 .21136 .24896 .2155 .24713 .21272 .24391 Metetra
.68 .724 .883 r
.21272 .24391 .2155 .24713 .21964 .24532 .21686 .2421 Metetra
.679 .725 .884 r
.21686 .2421 .21964 .24532 .22379 .24351 .22101 .24031 Metetra
.678 .725 .885 r
.22101 .24031 .22379 .24351 .22794 .24172 .22517 .23852 Metetra
.677 .726 .886 r
.22517 .23852 .22794 .24172 .2321 .23994 .22932 .23674 Metetra
.677 .726 .887 r
.22932 .23674 .2321 .23994 .23626 .23817 .23349 .23497 Metetra
.676 .727 .888 r
.23349 .23497 .23626 .23817 .24042 .2364 .23766 .23321 Metetra
.675 .727 .889 r
.23766 .23321 .24042 .2364 .24459 .23464 .24183 .23146 Metetra
.674 .727 .889 r
.24183 .23146 .24459 .23464 .24877 .2329 .24601 .22971 Metetra
.674 .727 .89 r
.24601 .22971 .24877 .2329 .25295 .23115 .25019 .22797 Metetra
.673 .728 .891 r
.25019 .22797 .25295 .23115 .25714 .22942 .25438 .22624 Metetra
.672 .728 .891 r
.25438 .22624 .25714 .22942 .26133 .22769 .25858 .22451 Metetra
.672 .728 .892 r
.25858 .22451 .26133 .22769 .26553 .22597 .26278 .22278 Metetra
.671 .728 .892 r
.26278 .22278 .26553 .22597 .26973 .22425 .26699 .22106 Metetra
.671 .728 .893 r
.26699 .22106 .26973 .22425 .27394 .22253 .2712 .21935 Metetra
.67 .729 .893 r
.2712 .21935 .27394 .22253 .27816 .22082 .27542 .21764 Metetra
.67 .729 .894 r
.27542 .21764 .27816 .22082 .28238 .21912 .27965 .21593 Metetra
.669 .729 .894 r
.27965 .21593 .28238 .21912 .28661 .21742 .28388 .21423 Metetra
.669 .729 .895 r
.28388 .21423 .28661 .21742 .29084 .21572 .28811 .21253 Metetra
.668 .729 .895 r
.28811 .21253 .29084 .21572 .29508 .21403 .29236 .21084 Metetra
.668 .729 .895 r
.29236 .21084 .29508 .21403 .29933 .21233 .29661 .20914 Metetra
.667 .729 .896 r
.29661 .20914 .29933 .21233 .30358 .21065 .30086 .20745 Metetra
.667 .729 .896 r
.30086 .20745 .30358 .21065 .30784 .20896 .30512 .20576 Metetra
.666 .729 .896 r
.30512 .20576 .30784 .20896 .3121 .20728 .30939 .20408 Metetra
.666 .729 .897 r
.30939 .20408 .3121 .20728 .31637 .2056 .31367 .2024 Metetra
.665 .729 .897 r
.31367 .2024 .31637 .2056 .32065 .20392 .31795 .20072 Metetra
.665 .729 .897 r
.31795 .20072 .32065 .20392 .32493 .20225 .32224 .19904 Metetra
.665 .729 .898 r
.32224 .19904 .32493 .20225 .32922 .20058 .32653 .19736 Metetra
.664 .729 .898 r
.32653 .19736 .32922 .20058 .33352 .19891 .33083 .19569 Metetra
.664 .729 .898 r
.33083 .19569 .33352 .19891 .33782 .19724 .33514 .19402 Metetra
.663 .729 .898 r
.33514 .19402 .33782 .19724 .34213 .19557 .33945 .19235 Metetra
.663 .729 .898 r
.33945 .19235 .34213 .19557 .34645 .19391 .34377 .19068 Metetra
.663 .729 .899 r
.34377 .19068 .34645 .19391 .35077 .19225 .3481 .18901 Metetra
.662 .729 .899 r
.3481 .18901 .35077 .19225 .3551 .19059 .35243 .18735 Metetra
.662 .729 .899 r
.35243 .18735 .3551 .19059 .35944 .18893 .35677 .18569 Metetra
.662 .729 .899 r
.35677 .18569 .35944 .18893 .36378 .18727 .36112 .18403 Metetra
.661 .728 .899 r
.36112 .18403 .36378 .18727 .36813 .18562 .36547 .18237 Metetra
.661 .728 .899 r
.36547 .18237 .36813 .18562 .37249 .18397 .36983 .18071 Metetra
.66 .728 .9 r
.36983 .18071 .37249 .18397 .37685 .18231 .3742 .17905 Metetra
.66 .728 .9 r
.3742 .17905 .37685 .18231 .38122 .18067 .37858 .1774 Metetra
.66 .728 .9 r
.37858 .1774 .38122 .18067 .3856 .17902 .38296 .17574 Metetra
.659 .728 .9 r
.38296 .17574 .3856 .17902 .38999 .17737 .38735 .17409 Metetra
.659 .727 .9 r
.38735 .17409 .38999 .17737 .39438 .17573 .39175 .17244 Metetra
.658 .727 .9 r
.39175 .17244 .39438 .17573 .39878 .17409 .39615 .1708 Metetra
.658 .727 .9 r
.39615 .1708 .39878 .17409 .40318 .17245 .40056 .16915 Metetra
.658 .727 .9 r
.40056 .16915 .40318 .17245 .4076 .17081 .40498 .16751 Metetra
.657 .726 .9 r
.40498 .16751 .4076 .17081 .41202 .16918 .4094 .16587 Metetra
.657 .726 .9 r
.4094 .16587 .41202 .16918 .41644 .16755 .41383 .16423 Metetra
.656 .726 .9 r
.41383 .16423 .41644 .16755 .42088 .16592 .41827 .16259 Metetra
.656 .726 .9 r
.41827 .16259 .42088 .16592 .42532 .16429 .42272 .16096 Metetra
.655 .725 .901 r
.42272 .16096 .42532 .16429 .42977 .16266 .42717 .15932 Metetra
.655 .725 .901 r
.42717 .15932 .42977 .16266 .43423 .16104 .43163 .15769 Metetra
.654 .725 .901 r
.43163 .15769 .43423 .16104 .43869 .15942 .4361 .15607 Metetra
.654 .724 .901 r
.4361 .15607 .43869 .15942 .44316 .15781 .44058 .15444 Metetra
.653 .724 .901 r
.44058 .15444 .44316 .15781 .44764 .1562 .44506 .15282 Metetra
.653 .723 .901 r
.44506 .15282 .44764 .1562 .45213 .15459 .44955 .15121 Metetra
.652 .723 .901 r
.44955 .15121 .45213 .15459 .45662 .15298 .45405 .14959 Metetra
.651 .722 .901 r
.45405 .14959 .45662 .15298 .46113 .15138 .45856 .14798 Metetra
.651 .722 .901 r
.45856 .14798 .46113 .15138 .46564 .14979 .46307 .14638 Metetra
.65 .721 .901 r
.46307 .14638 .46564 .14979 .47015 .1482 .46759 .14478 Metetra
.649 .721 .9 r
.46759 .14478 .47015 .1482 .47468 .14661 .47212 .14318 Metetra
.649 .72 .9 r
.47212 .14318 .47468 .14661 .47921 .14503 .47666 .14159 Metetra
.648 .719 .9 r
.47666 .14159 .47921 .14503 .48375 .14345 .48121 .14 Metetra
.647 .719 .9 r
.48121 .14 .48375 .14345 .4883 .14188 .48576 .13842 Metetra
.646 .718 .9 r
.48576 .13842 .4883 .14188 .49286 .14032 .49032 .13685 Metetra
.645 .717 .9 r
.49032 .13685 .49286 .14032 .49742 .13877 .49489 .13528 Metetra
.644 .716 .9 r
.49489 .13528 .49742 .13877 .50199 .13722 .49947 .13372 Metetra
.643 .715 .9 r
.49947 .13372 .50199 .13722 .50658 .13568 .50405 .13217 Metetra
.642 .714 .9 r
.50405 .13217 .50658 .13568 .51116 .13416 .50865 .13062 Metetra
.641 .713 .899 r
.50865 .13062 .51116 .13416 .51576 .13264 .51325 .12909 Metetra
.64 .712 .899 r
.51325 .12909 .51576 .13264 .52037 .13113 .51786 .12757 Metetra
.639 .71 .899 r
.51786 .12757 .52037 .13113 .52498 .12964 .52248 .12606 Metetra
.637 .709 .899 r
.52248 .12606 .52498 .12964 .52961 .12816 .52711 .12456 Metetra
.636 .707 .898 r
.52711 .12456 .52961 .12816 .53424 .12669 .53174 .12307 Metetra
.634 .706 .898 r
.53174 .12307 .53424 .12669 .53888 .12524 .53639 .1216 Metetra
.632 .704 .898 r
.53639 .1216 .53888 .12524 .54353 .12381 .54104 .12014 Metetra
.63 .702 .897 r
.54104 .12014 .54353 .12381 .54819 .12239 .5457 .11871 Metetra
.628 .7 .897 r
.5457 .11871 .54819 .12239 .55285 .121 .55037 .11729 Metetra
.626 .698 .896 r
.55037 .11729 .55285 .121 .55753 .11963 .55506 .1159 Metetra
.624 .695 .896 r
.55506 .1159 .55753 .11963 .56222 .11829 .55975 .11453 Metetra
.621 .692 .895 r
.55975 .11453 .56222 .11829 .56722 .13838 .56445 .11318 Metetra
0 0 .459 r
.56445 .11318 .56722 .13838 .57197 .13767 .56948 .13333 Metetra
.561 .63 .877 r
.56948 .13333 .57197 .13767 .57673 .13705 .57425 .13263 Metetra
.554 .622 .874 r
.57425 .13263 .57673 .13705 .58151 .13652 .57902 .13202 Metetra
.545 .613 .871 r
.57902 .13202 .58151 .13652 .5863 .13609 .58382 .13149 Metetra
.536 .603 .867 r
.58382 .13149 .5863 .13609 .59111 .13578 .58862 .13107 Metetra
.525 .591 .863 r
.58862 .13107 .59111 .13578 .59593 .13561 .59344 .13077 Metetra
.513 .578 .858 r
.59344 .13077 .59593 .13561 .60077 .1356 .59828 .13062 Metetra
.5 .563 .852 r
.59828 .13062 .60077 .1356 .60563 .13578 .60314 .13063 Metetra
.484 .546 .845 r
.60314 .13063 .60563 .13578 .61051 .13618 .60802 .13083 Metetra
.466 .526 .836 r
.60802 .13083 .61051 .13618 .61542 .13685 .61291 .13126 Metetra
.444 .503 .825 r
.61291 .13126 .61542 .13685 .62035 .13785 .61784 .13197 Metetra
.419 .476 .813 r
.61784 .13197 .62035 .13785 .62532 .13925 .62279 .13301 Metetra
.39 .445 .797 r
.62279 .13301 .62532 .13925 .63032 .14116 .62777 .13447 Metetra
.356 .407 .777 r
.62777 .13447 .63032 .14116 .63536 .14373 .6328 .13647 Metetra
.315 .363 .752 r
.6328 .13647 .63536 .14373 .64047 .14718 .63787 .13915 Metetra
.267 .31 .722 r
.63787 .13915 .64047 .14718 .64565 .15184 .643 .14276 Metetra
.211 .249 .684 r
.643 .14276 .64565 .15184 .65093 .15825 .64821 .14764 Metetra
.145 .178 .637 r
.64821 .14764 .65093 .15825 .65637 .16735 .65353 .15438 Metetra
.07 .096 .58 r
.65353 .15438 .65637 .16735 .66207 .18099 .65902 .16403 Metetra
0 .007 .514 r
.65902 .16403 .66207 .18099 .66824 .20345 .6648 .17867 Metetra
0 0 .44 r
.6648 .17867 .66824 .20345 .67559 .24812 .67112 .20332 Metetra
0 0 .359 r
.67112 .20332 .67559 .24812 .68299 .29043 .67888 .25483 Metetra
0 0 .451 r
.67888 .25483 .68299 .29043 .67544 .04477 .68575 .28533 Metetra
0 0 .333 r
.68575 .28533 .67544 .04477 .68027 .04291 .67797 .03947 Metetra
.664 .741 .907 r
.67797 .03947 .68027 .04291 .68512 .04105 .68281 .0376 Metetra
.664 .741 .907 r
.68281 .0376 .68512 .04105 .68997 .03918 .68767 .03573 Metetra
.664 .741 .907 r
.68767 .03573 .68997 .03918 .69483 .03732 .69254 .03386 Metetra
.664 .741 .907 r
.69254 .03386 .69483 .03732 .69969 .03544 .69741 .03198 Metetra
.664 .741 .907 r
.69741 .03198 .69969 .03544 .70457 .03357 .70229 .0301 Metetra
.664 .741 .907 r
.70229 .0301 .70457 .03357 .70945 .03169 .70718 .02821 Metetra
.664 .741 .907 r
.05792 .27453 .06085 .27727 .0647 .27578 .06177 .27304 Metetra
.664 .741 .907 r
.06177 .27304 .0647 .27578 .06855 .2743 .06563 .27155 Metetra
.664 .741 .907 r
.06563 .27155 .06855 .2743 .07241 .27281 .06949 .27006 Metetra
.664 .741 .907 r
.06949 .27006 .07241 .27281 .07628 .27132 .07336 .26857 Metetra
.664 .741 .907 r
.07336 .26857 .07628 .27132 .08015 .26983 .07723 .26707 Metetra
.94 .681 .517 r
.07723 .26707 .08015 .26983 .08403 .26834 .04749 .49951 Metetra
.458 .221 .466 r
.04749 .49951 .08403 .26834 .05483 .50071 .05413 .48066 Metetra
.873 .629 .566 r
.05413 .48066 .05483 .50071 .0633 .46855 .06661 .4202 Metetra
.709 .469 .559 r
.06661 .4202 .0633 .46855 .07451 .41618 .07458 .39101 Metetra
.734 .506 .583 r
.07458 .39101 .07451 .41618 .08208 .38936 .08098 .37268 Metetra
.745 .533 .606 r
.08098 .37268 .08208 .38936 .0883 .37208 .08662 .35961 Metetra
.751 .554 .629 r
.08662 .35961 .0883 .37208 .09383 .35956 .09182 .34953 Metetra
.754 .572 .65 r
.09182 .34953 .09383 .35956 .09898 .34983 .09676 .34135 Metetra
.755 .588 .67 r
.09676 .34135 .09898 .34983 .10387 .34188 .10151 .33446 Metetra
.754 .602 .689 r
.10151 .33446 .10387 .34188 .10859 .33516 .10613 .3285 Metetra
.753 .615 .706 r
.10613 .3285 .10859 .33516 .11319 .32932 .11066 .32323 Metetra
.751 .626 .722 r
.11066 .32323 .11319 .32932 .1177 .32413 .11512 .31849 Metetra
.748 .636 .736 r
.11512 .31849 .1177 .32413 .12214 .31946 .11952 .31417 Metetra
.745 .645 .749 r
.11952 .31417 .12214 .31946 .12653 .31519 .12387 .31017 Metetra
.742 .653 .761 r
.12387 .31017 .12653 .31519 .13088 .31125 .12819 .30646 Metetra
.739 .66 .771 r
.12819 .30646 .13088 .31125 .13519 .30757 .13249 .30297 Metetra
.736 .666 .781 r
.13249 .30297 .13519 .30757 .13948 .30411 .13676 .29966 Metetra
.733 .671 .79 r
.13676 .29966 .13948 .30411 .14375 .30084 .14101 .29653 Metetra
.73 .676 .798 r
.14101 .29653 .14375 .30084 .14799 .29772 .14525 .29353 Metetra
.727 .681 .805 r
.14525 .29353 .14799 .29772 .15223 .29474 .14947 .29065 Metetra
.724 .685 .811 r
.14947 .29065 .15223 .29474 .15645 .29188 .15369 .28787 Metetra
.722 .688 .817 r
.15369 .28787 .15645 .29188 .16067 .28912 .1579 .28519 Metetra
.921 .708 .599 r
.1579 .28519 .16067 .28912 .16487 .28645 .16455 .26158 Metetra
.552 .358 .572 r
.16455 .26158 .16487 .28645 .16908 .28386 .16867 .25957 Metetra
.552 .36 .574 r
.16867 .25957 .16908 .28386 .17559 .26092 .17278 .25759 Metetra
.691 .718 .87 r
.17278 .25759 .17559 .26092 .1797 .25894 .17689 .25563 Metetra
.689 .719 .872 r
.17689 .25563 .1797 .25894 .18382 .25699 .18101 .2537 Metetra
.688 .72 .874 r
.18101 .2537 .18382 .25699 .18794 .25507 .18513 .25179 Metetra
.686 .721 .876 r
.18513 .25179 .18794 .25507 .19206 .25317 .18925 .2499 Metetra
.685 .722 .877 r
.18925 .2499 .19206 .25317 .19618 .25128 .19338 .24803 Metetra
.684 .722 .879 r
.19338 .24803 .19618 .25128 .20031 .24942 .19751 .24618 Metetra
.682 .723 .88 r
.19751 .24618 .20031 .24942 .20444 .24757 .20164 .24434 Metetra
.681 .724 .882 r
.20164 .24434 .20444 .24757 .20858 .24573 .20578 .24251 Metetra
.68 .724 .883 r
.20578 .24251 .20858 .24573 .21272 .24391 .20992 .2407 Metetra
.679 .725 .884 r
.20992 .2407 .21272 .24391 .21686 .2421 .21407 .23889 Metetra
.678 .725 .885 r
.21407 .23889 .21686 .2421 .22101 .24031 .21822 .2371 Metetra
.678 .726 .886 r
.21822 .2371 .22101 .24031 .22517 .23852 .22238 .23532 Metetra
.677 .726 .887 r
.22238 .23532 .22517 .23852 .22932 .23674 .22654 .23354 Metetra
.676 .727 .888 r
.22654 .23354 .22932 .23674 .23349 .23497 .23071 .23178 Metetra
.675 .727 .889 r
.23071 .23178 .23349 .23497 .23766 .23321 .23488 .23002 Metetra
.675 .727 .889 r
.23488 .23002 .23766 .23321 .24183 .23146 .23906 .22827 Metetra
.674 .727 .89 r
.23906 .22827 .24183 .23146 .24601 .22971 .24324 .22652 Metetra
.673 .728 .891 r
.24324 .22652 .24601 .22971 .25019 .22797 .24743 .22478 Metetra
.673 .728 .891 r
.24743 .22478 .25019 .22797 .25438 .22624 .25162 .22305 Metetra
.672 .728 .892 r
.25162 .22305 .25438 .22624 .25858 .22451 .25582 .22132 Metetra
.671 .728 .892 r
.25582 .22132 .25858 .22451 .26278 .22278 .26003 .2196 Metetra
.671 .728 .893 r
.26003 .2196 .26278 .22278 .26699 .22106 .26424 .21788 Metetra
.67 .729 .893 r
.26424 .21788 .26699 .22106 .2712 .21935 .26845 .21616 Metetra
.67 .729 .894 r
.26845 .21616 .2712 .21935 .27542 .21764 .27268 .21445 Metetra
.669 .729 .894 r
.27268 .21445 .27542 .21764 .27965 .21593 .2769 .21274 Metetra
.669 .729 .895 r
.2769 .21274 .27965 .21593 .28388 .21423 .28114 .21104 Metetra
.668 .729 .895 r
.28114 .21104 .28388 .21423 .28811 .21253 .28538 .20934 Metetra
.668 .729 .895 r
.28538 .20934 .28811 .21253 .29236 .21084 .28963 .20764 Metetra
.667 .729 .896 r
.28963 .20764 .29236 .21084 .29661 .20914 .29388 .20594 Metetra
.667 .729 .896 r
.29388 .20594 .29661 .20914 .30086 .20745 .29814 .20425 Metetra
.667 .729 .896 r
.29814 .20425 .30086 .20745 .30512 .20576 .3024 .20256 Metetra
.666 .729 .897 r
.3024 .20256 .30512 .20576 .30939 .20408 .30668 .20087 Metetra
.666 .729 .897 r
.30668 .20087 .30939 .20408 .31367 .2024 .31095 .19919 Metetra
.665 .729 .897 r
.31095 .19919 .31367 .2024 .31795 .20072 .31524 .19751 Metetra
.665 .729 .898 r
.31524 .19751 .31795 .20072 .32224 .19904 .31953 .19582 Metetra
.665 .729 .898 r
.31953 .19582 .32224 .19904 .32653 .19736 .32383 .19414 Metetra
.664 .729 .898 r
.32383 .19414 .32653 .19736 .33083 .19569 .32813 .19247 Metetra
.664 .729 .898 r
.32813 .19247 .33083 .19569 .33514 .19402 .33244 .19079 Metetra
.663 .729 .898 r
.33244 .19079 .33514 .19402 .33945 .19235 .33676 .18912 Metetra
.663 .729 .899 r
.33676 .18912 .33945 .19235 .34377 .19068 .34109 .18744 Metetra
.663 .729 .899 r
.34109 .18744 .34377 .19068 .3481 .18901 .34542 .18577 Metetra
.662 .729 .899 r
.34542 .18577 .3481 .18901 .35243 .18735 .34975 .1841 Metetra
.662 .729 .899 r
.34975 .1841 .35243 .18735 .35677 .18569 .3541 .18244 Metetra
.662 .729 .899 r
.3541 .18244 .35677 .18569 .36112 .18403 .35845 .18077 Metetra
.661 .729 .899 r
.35845 .18077 .36112 .18403 .36547 .18237 .36281 .17911 Metetra
.661 .728 .9 r
.36281 .17911 .36547 .18237 .36983 .18071 .36717 .17744 Metetra
.66 .728 .9 r
.36717 .17744 .36983 .18071 .3742 .17905 .37155 .17578 Metetra
.66 .728 .9 r
.37155 .17578 .3742 .17905 .37858 .1774 .37593 .17412 Metetra
.66 .728 .9 r
.37593 .17412 .37858 .1774 .38296 .17574 .38031 .17246 Metetra
.659 .728 .9 r
.38031 .17246 .38296 .17574 .38735 .17409 .3847 .17081 Metetra
.659 .728 .9 r
.3847 .17081 .38735 .17409 .39175 .17244 .38911 .16915 Metetra
.658 .727 .9 r
.38911 .16915 .39175 .17244 .39615 .1708 .39351 .1675 Metetra
.658 .727 .9 r
.39351 .1675 .39615 .1708 .40056 .16915 .39793 .16585 Metetra
.658 .727 .9 r
.39793 .16585 .40056 .16915 .40498 .16751 .40235 .1642 Metetra
.657 .727 .9 r
.40235 .1642 .40498 .16751 .4094 .16587 .40678 .16255 Metetra
.657 .726 .901 r
.40678 .16255 .4094 .16587 .41383 .16423 .41121 .1609 Metetra
.656 .726 .901 r
.41121 .1609 .41383 .16423 .41827 .16259 .41566 .15926 Metetra
.656 .726 .901 r
.41566 .15926 .41827 .16259 .42272 .16096 .42011 .15762 Metetra
.655 .726 .901 r
.42011 .15762 .42272 .16096 .42717 .15932 .42457 .15598 Metetra
.655 .725 .901 r
.42457 .15598 .42717 .15932 .43163 .15769 .42903 .15434 Metetra
.654 .725 .901 r
.42903 .15434 .43163 .15769 .4361 .15607 .43351 .15271 Metetra
.654 .725 .901 r
.43351 .15271 .4361 .15607 .44058 .15444 .43799 .15107 Metetra
.653 .724 .901 r
.43799 .15107 .44058 .15444 .44506 .15282 .44247 .14944 Metetra
.653 .724 .901 r
.44247 .14944 .44506 .15282 .44955 .15121 .44697 .14782 Metetra
.652 .723 .901 r
.44697 .14782 .44955 .15121 .45405 .14959 .45147 .1462 Metetra
.652 .723 .901 r
.45147 .1462 .45405 .14959 .45856 .14798 .45598 .14458 Metetra
.651 .722 .901 r
.45598 .14458 .45856 .14798 .46307 .14638 .4605 .14296 Metetra
.651 .722 .901 r
.4605 .14296 .46307 .14638 .46759 .14478 .46503 .14135 Metetra
.65 .721 .901 r
.46503 .14135 .46759 .14478 .47212 .14318 .46956 .13974 Metetra
.649 .721 .901 r
.46956 .13974 .47212 .14318 .47666 .14159 .4741 .13814 Metetra
.648 .72 .901 r
.4741 .13814 .47666 .14159 .48121 .14 .47865 .13654 Metetra
.648 .719 .9 r
.47865 .13654 .48121 .14 .48576 .13842 .48321 .13495 Metetra
.647 .718 .9 r
.48321 .13495 .48576 .13842 .49032 .13685 .48778 .13337 Metetra
.646 .718 .9 r
.48778 .13337 .49032 .13685 .49489 .13528 .49235 .13179 Metetra
.645 .717 .9 r
.49235 .13179 .49489 .13528 .49947 .13372 .49693 .13021 Metetra
.644 .716 .9 r
.49693 .13021 .49947 .13372 .50405 .13217 .50152 .12865 Metetra
.643 .715 .9 r
.50152 .12865 .50405 .13217 .50865 .13062 .50612 .12709 Metetra
.642 .714 .9 r
.50612 .12709 .50865 .13062 .51325 .12909 .51073 .12554 Metetra
.641 .713 .899 r
.51073 .12554 .51325 .12909 .51786 .12757 .51534 .124 Metetra
.64 .712 .899 r
.51534 .124 .51786 .12757 .52248 .12606 .51997 .12248 Metetra
.638 .71 .899 r
.51997 .12248 .52248 .12606 .52711 .12456 .5246 .12096 Metetra
.637 .709 .899 r
.5246 .12096 .52711 .12456 .53174 .12307 .52924 .11945 Metetra
.635 .707 .898 r
.52924 .11945 .53174 .12307 .53639 .1216 .53389 .11796 Metetra
.634 .706 .898 r
.53389 .11796 .53639 .1216 .54104 .12014 .53854 .11649 Metetra
.632 .704 .898 r
.53854 .11649 .54104 .12014 .5457 .11871 .54321 .11503 Metetra
.63 .702 .897 r
.54321 .11503 .5457 .11871 .55037 .11729 .54789 .11359 Metetra
.628 .7 .897 r
.54789 .11359 .55037 .11729 .55506 .1159 .55257 .11217 Metetra
.626 .697 .896 r
.55257 .11217 .55506 .1159 .55975 .11453 .55727 .11077 Metetra
.623 .694 .895 r
.55727 .11077 .55975 .11453 .56445 .11318 .56197 .10939 Metetra
.62 .692 .895 r
.56197 .10939 .56445 .11318 .56948 .13333 .56669 .10805 Metetra
.536 .347 .573 r
.56669 .10805 .56948 .13333 .57425 .13263 .57141 .10673 Metetra
0 0 .456 r
.57141 .10673 .57425 .13263 .57902 .13202 .57653 .12757 Metetra
.553 .621 .874 r
.57653 .12757 .57902 .13202 .58382 .13149 .58132 .12696 Metetra
.544 .611 .87 r
.58132 .12696 .58382 .13149 .58862 .13107 .58613 .12644 Metetra
.535 .601 .867 r
.58613 .12644 .58862 .13107 .59344 .13077 .59095 .12603 Metetra
.524 .589 .862 r
.59095 .12603 .59344 .13077 .59828 .13062 .59579 .12574 Metetra
.512 .576 .857 r
.59579 .12574 .59828 .13062 .60314 .13063 .60064 .1256 Metetra
.498 .561 .851 r
.60064 .1256 .60314 .13063 .60802 .13083 .60552 .12563 Metetra
.481 .543 .843 r
.60552 .12563 .60802 .13083 .61291 .13126 .61041 .12585 Metetra
.463 .523 .834 r
.61041 .12585 .61291 .13126 .61784 .13197 .61533 .12631 Metetra
.441 .499 .823 r
.61533 .12631 .61784 .13197 .62279 .13301 .62027 .12706 Metetra
.416 .472 .81 r
.62027 .12706 .62279 .13301 .62777 .13447 .62524 .12815 Metetra
.386 .439 .794 r
.62524 .12815 .62777 .13447 .6328 .13647 .63024 .12968 Metetra
.351 .401 .773 r
.63024 .12968 .6328 .13647 .63787 .13915 .63529 .13176 Metetra
.309 .355 .748 r
.63529 .13176 .63787 .13915 .643 .14276 .64038 .13455 Metetra
.26 .302 .716 r
.64038 .13455 .643 .14276 .64821 .14764 .64554 .13832 Metetra
.203 .239 .677 r
.64554 .13832 .64821 .14764 .65353 .15438 .65078 .14343 Metetra
.136 .166 .629 r
.65078 .14343 .65353 .15438 .65902 .16403 .65615 .15053 Metetra
.06 .084 .571 r
.65615 .15053 .65902 .16403 .6648 .17867 .6617 .16076 Metetra
0 0 .504 r
.6617 .16076 .6648 .17867 .67112 .20332 .66755 .17649 Metetra
0 0 .429 r
.66755 .17649 .67112 .20332 .67888 .25483 .67404 .20363 Metetra
0 0 .347 r
.67404 .20363 .67888 .25483 .68575 .28533 .68232 .26367 Metetra
.064 .04 .516 r
.68232 .26367 .68575 .28533 .67797 .03947 .68853 .28021 Metetra
0 0 .333 r
.68853 .28021 .67797 .03947 .68281 .0376 .6805 .03415 Metetra
.664 .741 .907 r
.6805 .03415 .68281 .0376 .68767 .03573 .68537 .03227 Metetra
.664 .741 .907 r
.68537 .03227 .68767 .03573 .69254 .03386 .69024 .03039 Metetra
.664 .741 .907 r
.69024 .03039 .69254 .03386 .69741 .03198 .69512 .0285 Metetra
.664 .741 .907 r
.69512 .0285 .69741 .03198 .70229 .0301 .70001 .02662 Metetra
.664 .741 .907 r
.70001 .02662 .70229 .0301 .70718 .02821 .7049 .02473 Metetra
.664 .741 .907 r
.05498 .27178 .05792 .27453 .06177 .27304 .05883 .27029 Metetra
.664 .741 .907 r
.05883 .27029 .06177 .27304 .06563 .27155 .06269 .2688 Metetra
.664 .741 .907 r
.06269 .2688 .06563 .27155 .06949 .27006 .06656 .2673 Metetra
.664 .741 .907 r
.06656 .2673 .06949 .27006 .07336 .26857 .07043 .2658 Metetra
.94 .681 .518 r
.07043 .2658 .07336 .26857 .07723 .26707 .04015 .49831 Metetra
.494 .252 .476 r
.04015 .49831 .07723 .26707 .04749 .49951 .0445 .49548 Metetra
.931 .693 .557 r
.0445 .49548 .04749 .49951 .05413 .48066 .05861 .42472 Metetra
.702 .46 .555 r
.05861 .42472 .05413 .48066 .06661 .4202 .06703 .39283 Metetra
.731 .501 .579 r
.06703 .39283 .06661 .4202 .07458 .39101 .07363 .37336 Metetra
.744 .528 .603 r
.07363 .37336 .07458 .39101 .08098 .37268 .07938 .35968 Metetra
.75 .55 .625 r
.07938 .35968 .08098 .37268 .08662 .35961 .08465 .34924 Metetra
.753 .569 .647 r
.08465 .34924 .08662 .35961 .09182 .34953 .08964 .34082 Metetra
.754 .585 .667 r
.08964 .34082 .09182 .34953 .09676 .34135 .09442 .33377 Metetra
.754 .6 .686 r
.09442 .33377 .09676 .34135 .10151 .33446 .09907 .32769 Metetra
.753 .613 .703 r
.09907 .32769 .10151 .33446 .10613 .3285 .10361 .32233 Metetra
.751 .624 .719 r
.10361 .32233 .10613 .3285 .11066 .32323 .10808 .31752 Metetra
.748 .634 .734 r
.10808 .31752 .11066 .32323 .11512 .31849 .11249 .31313 Metetra
.746 .643 .747 r
.11249 .31313 .11512 .31849 .11952 .31417 .11686 .3091 Metetra
.743 .651 .759 r
.11686 .3091 .11952 .31417 .12387 .31017 .12119 .30534 Metetra
.74 .658 .77 r
.12119 .30534 .12387 .31017 .12819 .30646 .12548 .30182 Metetra
.736 .665 .78 r
.12548 .30182 .12819 .30646 .13249 .30297 .12976 .29849 Metetra
.733 .67 .788 r
.12976 .29849 .13249 .30297 .13676 .29966 .13402 .29533 Metetra
.73 .675 .797 r
.13402 .29533 .13676 .29966 .14101 .29653 .13826 .29231 Metetra
.728 .68 .804 r
.13826 .29231 .14101 .29653 .14525 .29353 .14249 .28941 Metetra
.725 .684 .81 r
.14249 .28941 .14525 .29353 .14947 .29065 .1467 .28661 Metetra
.722 .688 .816 r
.1467 .28661 .14947 .29065 .15369 .28787 .15091 .28392 Metetra
.92 .708 .599 r
.15091 .28392 .15369 .28787 .1579 .28519 .15763 .26024 Metetra
.551 .357 .571 r
.15763 .26024 .1579 .28519 .16455 .26158 .16174 .25822 Metetra
.693 .716 .867 r
.16174 .25822 .16455 .26158 .16867 .25957 .16585 .25623 Metetra
.691 .718 .869 r
.16585 .25623 .16867 .25957 .17278 .25759 .16996 .25427 Metetra
.689 .719 .872 r
.16996 .25427 .17278 .25759 .17689 .25563 .17408 .25233 Metetra
.688 .72 .874 r
.17408 .25233 .17689 .25563 .18101 .2537 .1782 .25042 Metetra
.686 .721 .876 r
.1782 .25042 .18101 .2537 .18513 .25179 .18232 .24852 Metetra
.685 .722 .877 r
.18232 .24852 .18513 .25179 .18925 .2499 .18644 .24664 Metetra
.684 .722 .879 r
.18644 .24664 .18925 .2499 .19338 .24803 .19057 .24478 Metetra
.683 .723 .88 r
.19057 .24478 .19338 .24803 .19751 .24618 .1947 .24294 Metetra
.682 .724 .882 r
.1947 .24294 .19751 .24618 .20164 .24434 .19884 .24111 Metetra
.681 .724 .883 r
.19884 .24111 .20164 .24434 .20578 .24251 .20298 .23929 Metetra
.68 .725 .884 r
.20298 .23929 .20578 .24251 .20992 .2407 .20712 .23748 Metetra
.679 .725 .885 r
.20712 .23748 .20992 .2407 .21407 .23889 .21127 .23568 Metetra
.678 .726 .886 r
.21127 .23568 .21407 .23889 .21822 .2371 .21543 .23389 Metetra
.677 .726 .887 r
.21543 .23389 .21822 .2371 .22238 .23532 .21959 .23211 Metetra
.676 .727 .888 r
.21959 .23211 .22238 .23532 .22654 .23354 .22375 .23034 Metetra
.675 .727 .889 r
.22375 .23034 .22654 .23354 .23071 .23178 .22792 .22858 Metetra
.675 .727 .889 r
.22792 .22858 .23071 .23178 .23488 .23002 .2321 .22682 Metetra
.674 .728 .89 r
.2321 .22682 .23488 .23002 .23906 .22827 .23628 .22507 Metetra
.673 .728 .891 r
.23628 .22507 .23906 .22827 .24324 .22652 .24046 .22333 Metetra
.673 .728 .891 r
.24046 .22333 .24324 .22652 .24743 .22478 .24465 .22159 Metetra
.672 .728 .892 r
.24465 .22159 .24743 .22478 .25162 .22305 .24885 .21986 Metetra
.672 .728 .892 r
.24885 .21986 .25162 .22305 .25582 .22132 .25305 .21813 Metetra
.671 .729 .893 r
.25305 .21813 .25582 .22132 .26003 .2196 .25726 .21641 Metetra
.671 .729 .893 r
.25726 .21641 .26003 .2196 .26424 .21788 .26147 .21469 Metetra
.67 .729 .894 r
.26147 .21469 .26424 .21788 .26845 .21616 .26569 .21297 Metetra
.67 .729 .894 r
.26569 .21297 .26845 .21616 .27268 .21445 .26992 .21126 Metetra
.669 .729 .895 r
.26992 .21126 .27268 .21445 .2769 .21274 .27415 .20955 Metetra
.669 .729 .895 r
.27415 .20955 .2769 .21274 .28114 .21104 .27839 .20784 Metetra
.668 .729 .895 r
.27839 .20784 .28114 .21104 .28538 .20934 .28264 .20614 Metetra
.668 .729 .896 r
.28264 .20614 .28538 .20934 .28963 .20764 .28689 .20444 Metetra
.667 .729 .896 r
.28689 .20444 .28963 .20764 .29388 .20594 .29114 .20274 Metetra
.667 .729 .896 r
.29114 .20274 .29388 .20594 .29814 .20425 .29541 .20105 Metetra
.666 .73 .897 r
.29541 .20105 .29814 .20425 .3024 .20256 .29968 .19935 Metetra
.666 .73 .897 r
.29968 .19935 .3024 .20256 .30668 .20087 .30395 .19766 Metetra
.666 .73 .897 r
.30395 .19766 .30668 .20087 .31095 .19919 .30823 .19597 Metetra
.665 .73 .897 r
.30823 .19597 .31095 .19919 .31524 .19751 .31252 .19429 Metetra
.665 .73 .898 r
.31252 .19429 .31524 .19751 .31953 .19582 .31682 .1926 Metetra
.664 .73 .898 r
.31682 .1926 .31953 .19582 .32383 .19414 .32112 .19092 Metetra
.664 .729 .898 r
.32112 .19092 .32383 .19414 .32813 .19247 .32543 .18924 Metetra
.664 .729 .898 r
.32543 .18924 .32813 .19247 .33244 .19079 .32974 .18756 Metetra
.663 .729 .899 r
.32974 .18756 .33244 .19079 .33676 .18912 .33406 .18588 Metetra
.663 .729 .899 r
.33406 .18588 .33676 .18912 .34109 .18744 .33839 .1842 Metetra
.663 .729 .899 r
.33839 .1842 .34109 .18744 .34542 .18577 .34273 .18253 Metetra
.662 .729 .899 r
.34273 .18253 .34542 .18577 .34975 .1841 .34707 .18085 Metetra
.662 .729 .899 r
.34707 .18085 .34975 .1841 .3541 .18244 .35142 .17918 Metetra
.662 .729 .899 r
.35142 .17918 .3541 .18244 .35845 .18077 .35577 .17751 Metetra
.661 .729 .9 r
.35577 .17751 .35845 .18077 .36281 .17911 .36014 .17584 Metetra
.661 .729 .9 r
.36014 .17584 .36281 .17911 .36717 .17744 .36451 .17417 Metetra
.66 .729 .9 r
.36451 .17417 .36717 .17744 .37155 .17578 .36888 .17251 Metetra
.66 .728 .9 r
.36888 .17251 .37155 .17578 .37593 .17412 .37327 .17084 Metetra
.66 .728 .9 r
.37327 .17084 .37593 .17412 .38031 .17246 .37766 .16918 Metetra
.659 .728 .9 r
.37766 .16918 .38031 .17246 .3847 .17081 .38205 .16751 Metetra
.659 .728 .9 r
.38205 .16751 .3847 .17081 .38911 .16915 .38646 .16585 Metetra
.659 .728 .9 r
.38646 .16585 .38911 .16915 .39351 .1675 .39087 .16419 Metetra
.658 .728 .9 r
.39087 .16419 .39351 .1675 .39793 .16585 .39529 .16253 Metetra
.658 .727 .901 r
.39529 .16253 .39793 .16585 .40235 .1642 .39971 .16088 Metetra
.657 .727 .901 r
.39971 .16088 .40235 .1642 .40678 .16255 .40415 .15922 Metetra
.657 .727 .901 r
.40415 .15922 .40678 .16255 .41121 .1609 .40859 .15757 Metetra
.657 .727 .901 r
.40859 .15757 .41121 .1609 .41566 .15926 .41304 .15592 Metetra
.656 .726 .901 r
.41304 .15592 .41566 .15926 .42011 .15762 .41749 .15427 Metetra
.656 .726 .901 r
.41749 .15427 .42011 .15762 .42457 .15598 .42195 .15262 Metetra
.655 .726 .901 r
.42195 .15262 .42457 .15598 .42903 .15434 .42642 .15098 Metetra
.655 .725 .901 r
.42642 .15098 .42903 .15434 .43351 .15271 .4309 .14934 Metetra
.654 .725 .901 r
.4309 .14934 .43351 .15271 .43799 .15107 .43539 .1477 Metetra
.654 .725 .901 r
.43539 .1477 .43799 .15107 .44247 .14944 .43988 .14606 Metetra
.653 .724 .901 r
.43988 .14606 .44247 .14944 .44697 .14782 .44438 .14443 Metetra
.653 .724 .901 r
.44438 .14443 .44697 .14782 .45147 .1462 .44889 .14279 Metetra
.652 .723 .901 r
.44889 .14279 .45147 .1462 .45598 .14458 .4534 .14117 Metetra
.652 .723 .901 r
.4534 .14117 .45598 .14458 .4605 .14296 .45792 .13954 Metetra
.651 .722 .901 r
.45792 .13954 .4605 .14296 .46503 .14135 .46246 .13792 Metetra
.65 .722 .901 r
.46246 .13792 .46503 .14135 .46956 .13974 .46699 .1363 Metetra
.65 .721 .901 r
.46699 .1363 .46956 .13974 .4741 .13814 .47154 .13469 Metetra
.649 .72 .901 r
.47154 .13469 .4741 .13814 .47865 .13654 .47609 .13308 Metetra
.648 .72 .901 r
.47609 .13308 .47865 .13654 .48321 .13495 .48066 .13148 Metetra
.647 .719 .901 r
.48066 .13148 .48321 .13495 .48778 .13337 .48523 .12988 Metetra
.647 .718 .9 r
.48523 .12988 .48778 .13337 .49235 .13179 .4898 .12829 Metetra
.646 .718 .9 r
.4898 .12829 .49235 .13179 .49693 .13021 .49439 .12671 Metetra
.645 .717 .9 r
.49439 .12671 .49693 .13021 .50152 .12865 .49899 .12513 Metetra
.644 .716 .9 r
.49899 .12513 .50152 .12865 .50612 .12709 .50359 .12356 Metetra
.643 .715 .9 r
.50359 .12356 .50612 .12709 .51073 .12554 .5082 .12199 Metetra
.642 .714 .9 r
.5082 .12199 .51073 .12554 .51534 .124 .51282 .12044 Metetra
.641 .713 .899 r
.51282 .12044 .51534 .124 .51997 .12248 .51745 .1189 Metetra
.639 .711 .899 r
.51745 .1189 .51997 .12248 .5246 .12096 .52208 .11736 Metetra
.638 .71 .899 r
.52208 .11736 .5246 .12096 .52924 .11945 .52673 .11584 Metetra
.637 .709 .899 r
.52673 .11584 .52924 .11945 .53389 .11796 .53138 .11433 Metetra
.635 .707 .898 r
.53138 .11433 .53389 .11796 .53854 .11649 .53604 .11283 Metetra
.633 .705 .898 r
.53604 .11283 .53854 .11649 .54321 .11503 .54071 .11135 Metetra
.632 .703 .898 r
.54071 .11135 .54321 .11503 .54789 .11359 .54539 .10989 Metetra
.63 .701 .897 r
.54539 .10989 .54789 .11359 .55257 .11217 .55008 .10844 Metetra
.628 .699 .897 r
.55008 .10844 .55257 .11217 .55727 .11077 .55478 .10702 Metetra
.625 .697 .896 r
.55478 .10702 .55727 .11077 .56197 .10939 .55949 .10561 Metetra
.623 .694 .895 r
.55949 .10561 .56197 .10939 .56669 .10805 .56421 .10424 Metetra
.62 .691 .895 r
.56421 .10424 .56669 .10805 .57141 .10673 .56893 .10289 Metetra
.617 .688 .894 r
.56893 .10289 .57141 .10673 .57653 .12757 .57367 .10157 Metetra
0 0 .456 r
.57367 .10157 .57653 .12757 .58132 .12696 .57883 .12248 Metetra
.552 .619 .873 r
.57883 .12248 .58132 .12696 .58613 .12644 .58363 .12187 Metetra
.543 .61 .87 r
.58363 .12187 .58613 .12644 .59095 .12603 .58846 .12136 Metetra
.533 .599 .866 r
.58846 .12136 .59095 .12603 .59579 .12574 .59329 .12096 Metetra
.522 .587 .861 r
.59329 .12096 .59579 .12574 .60064 .1256 .59815 .12068 Metetra
.51 .574 .856 r
.59815 .12068 .60064 .1256 .60552 .12563 .60302 .12056 Metetra
.495 .558 .85 r
.60302 .12056 .60552 .12563 .61041 .12585 .60791 .1206 Metetra
.479 .54 .842 r
.60791 .1206 .61041 .12585 .61533 .12631 .61282 .12085 Metetra
.46 .52 .833 r
.61282 .12085 .61533 .12631 .62027 .12706 .61775 .12134 Metetra
.438 .496 .821 r
.61775 .12134 .62027 .12706 .62524 .12815 .62271 .12212 Metetra
.412 .467 .808 r
.62271 .12212 .62524 .12815 .63024 .12968 .6277 .12326 Metetra
.381 .434 .791 r
.6277 .12326 .63024 .12968 .63529 .13176 .63273 .12486 Metetra
.346 .395 .77 r
.63273 .12486 .63529 .13176 .64038 .13455 .63779 .12702 Metetra
.303 .348 .743 r
.63779 .12702 .64038 .13455 .64554 .13832 .64291 .12993 Metetra
.253 .293 .711 r
.64291 .12993 .64554 .13832 .65078 .14343 .6481 .13386 Metetra
.194 .229 .67 r
.6481 .13386 .65078 .14343 .65615 .15053 .65338 .13921 Metetra
.127 .155 .621 r
.65338 .13921 .65615 .15053 .6617 .16076 .65878 .14668 Metetra
.05 .072 .562 r
.65878 .14668 .6617 .16076 .66755 .17649 .66439 .15754 Metetra
0 0 .493 r
.66439 .15754 .66755 .17649 .67404 .20363 .67034 .17447 Metetra
0 0 .418 r
.67034 .17447 .67404 .20363 .68232 .26367 .67702 .20444 Metetra
0 0 .335 r
.67702 .20444 .68232 .26367 .68853 .28021 .68595 .27538 Metetra
.52 .604 .878 r
.68595 .27538 .68853 .28021 .6805 .03415 .69132 .27506 Metetra
0 0 .333 r
.69132 .27506 .6805 .03415 .68537 .03227 .68306 .02879 Metetra
.664 .741 .907 r
.68306 .02879 .68537 .03227 .69024 .03039 .68793 .02691 Metetra
.664 .741 .907 r
.68793 .02691 .69024 .03039 .69512 .0285 .69282 .02502 Metetra
.664 .741 .907 r
.69282 .02502 .69512 .0285 .70001 .02662 .69771 .02312 Metetra
.664 .741 .907 r
.69771 .02312 .70001 .02662 .7049 .02473 .70261 .02123 Metetra
.664 .741 .907 r
.05203 .26903 .05498 .27178 .05883 .27029 .05589 .26753 Metetra
.664 .741 .907 r
.05589 .26753 .05883 .27029 .06269 .2688 .05975 .26603 Metetra
.664 .741 .907 r
.05975 .26603 .06269 .2688 .06656 .2673 .06362 .26453 Metetra
.664 .741 .907 r
.06362 .26453 .06656 .2673 .07043 .2658 .06749 .26303 Metetra
.94 .681 .518 r
.06749 .26303 .07043 .2658 .04015 .49831 .03694 .49568 Metetra
.934 .699 .559 r
.03694 .49568 .04015 .49831 .0445 .49548 .0505 .42982 Metetra
.694 .45 .55 r
.0505 .42982 .0445 .49548 .05861 .42472 .05943 .39483 Metetra
.727 .495 .576 r
.05943 .39483 .05861 .42472 .06703 .39283 .06625 .37411 Metetra
.742 .524 .599 r
.06625 .37411 .06703 .39283 .07363 .37336 .07212 .35979 Metetra
.749 .547 .622 r
.07212 .35979 .07363 .37336 .07938 .35968 .07747 .34897 Metetra
.753 .566 .643 r
.07747 .34897 .07938 .35968 .08465 .34924 .0825 .34031 Metetra
.754 .583 .664 r
.0825 .34031 .08465 .34924 .08964 .34082 .08732 .33309 Metetra
.754 .598 .683 r
.08732 .33309 .08964 .34082 .09442 .33377 .09199 .32688 Metetra
.753 .611 .701 r
.09199 .32688 .09442 .33377 .09907 .32769 .09655 .32143 Metetra
.751 .622 .717 r
.09655 .32143 .09907 .32769 .10361 .32233 .10104 .31654 Metetra
.748 .633 .732 r
.10104 .31654 .10361 .32233 .10808 .31752 .10546 .3121 Metetra
.746 .642 .745 r
.10546 .3121 .10808 .31752 .11249 .31313 .10983 .30802 Metetra
.743 .65 .757 r
.10983 .30802 .11249 .31313 .11686 .3091 .11417 .30422 Metetra
.74 .657 .768 r
.11417 .30422 .11686 .3091 .12119 .30534 .11847 .30067 Metetra
.737 .664 .778 r
.11847 .30067 .12119 .30534 .12548 .30182 .12275 .29731 Metetra
.734 .669 .787 r
.12275 .29731 .12548 .30182 .12976 .29849 .12701 .29413 Metetra
.731 .675 .795 r
.12701 .29413 .12976 .29849 .13402 .29533 .13126 .29108 Metetra
.728 .679 .803 r
.13126 .29108 .13402 .29533 .13826 .29231 .13549 .28817 Metetra
.725 .683 .809 r
.13549 .28817 .13826 .29231 .14249 .28941 .13971 .28536 Metetra
.722 .687 .816 r
.13971 .28536 .14249 .28941 .1467 .28661 .14392 .28264 Metetra
.92 .707 .599 r
.14392 .28264 .1467 .28661 .15091 .28392 .15069 .2589 Metetra
.551 .357 .571 r
.15069 .2589 .15091 .28392 .15763 .26024 .1548 .25687 Metetra
.693 .716 .867 r
.1548 .25687 .15763 .26024 .16174 .25822 .15891 .25487 Metetra
.691 .717 .869 r
.15891 .25487 .16174 .25822 .16585 .25623 .16302 .25291 Metetra
.69 .719 .871 r
.16302 .25291 .16585 .25623 .16996 .25427 .16713 .25096 Metetra
.688 .72 .873 r
.16713 .25096 .16996 .25427 .17408 .25233 .17125 .24904 Metetra
.687 .721 .875 r
.17125 .24904 .17408 .25233 .1782 .25042 .17537 .24714 Metetra
.685 .722 .877 r
.17537 .24714 .1782 .25042 .18232 .24852 .17949 .24526 Metetra
.684 .722 .879 r
.17949 .24526 .18232 .24852 .18644 .24664 .18362 .24339 Metetra
.683 .723 .88 r
.18362 .24339 .18644 .24664 .19057 .24478 .18775 .24154 Metetra
.682 .724 .881 r
.18775 .24154 .19057 .24478 .1947 .24294 .19188 .2397 Metetra
.681 .724 .883 r
.19188 .2397 .1947 .24294 .19884 .24111 .19602 .23788 Metetra
.68 .725 .884 r
.19602 .23788 .19884 .24111 .20298 .23929 .20017 .23607 Metetra
.679 .725 .885 r
.20017 .23607 .20298 .23929 .20712 .23748 .20431 .23426 Metetra
.678 .726 .886 r
.20431 .23426 .20712 .23748 .21127 .23568 .20847 .23247 Metetra
.677 .726 .887 r
.20847 .23247 .21127 .23568 .21543 .23389 .21262 .23069 Metetra
.676 .727 .888 r
.21262 .23069 .21543 .23389 .21959 .23211 .21679 .22891 Metetra
.676 .727 .888 r
.21679 .22891 .21959 .23211 .22375 .23034 .22095 .22714 Metetra
.675 .727 .889 r
.22095 .22714 .22375 .23034 .22792 .22858 .22513 .22538 Metetra
.674 .728 .89 r
.22513 .22538 .22792 .22858 .2321 .22682 .2293 .22363 Metetra
.674 .728 .891 r
.2293 .22363 .2321 .22682 .23628 .22507 .23349 .22188 Metetra
.673 .728 .891 r
.23349 .22188 .23628 .22507 .24046 .22333 .23768 .22014 Metetra
.672 .728 .892 r
.23768 .22014 .24046 .22333 .24465 .22159 .24187 .2184 Metetra
.672 .729 .892 r
.24187 .2184 .24465 .22159 .24885 .21986 .24607 .21667 Metetra
.671 .729 .893 r
.24607 .21667 .24885 .21986 .25305 .21813 .25028 .21494 Metetra
.671 .729 .893 r
.25028 .21494 .25305 .21813 .25726 .21641 .25449 .21321 Metetra
.67 .729 .894 r
.25449 .21321 .25726 .21641 .26147 .21469 .25871 .21149 Metetra
.67 .729 .894 r
.25871 .21149 .26147 .21469 .26569 .21297 .26293 .20977 Metetra
.669 .729 .895 r
.26293 .20977 .26569 .21297 .26992 .21126 .26716 .20806 Metetra
.669 .729 .895 r
.26716 .20806 .26992 .21126 .27415 .20955 .27139 .20635 Metetra
.668 .729 .895 r
.27139 .20635 .27415 .20955 .27839 .20784 .27564 .20464 Metetra
.668 .73 .896 r
.27564 .20464 .27839 .20784 .28264 .20614 .27988 .20294 Metetra
.668 .73 .896 r
.27988 .20294 .28264 .20614 .28689 .20444 .28414 .20123 Metetra
.667 .73 .896 r
.28414 .20123 .28689 .20444 .29114 .20274 .2884 .19953 Metetra
.667 .73 .897 r
.2884 .19953 .29114 .20274 .29541 .20105 .29267 .19784 Metetra
.666 .73 .897 r
.29267 .19784 .29541 .20105 .29968 .19935 .29694 .19614 Metetra
.666 .73 .897 r
.29694 .19614 .29968 .19935 .30395 .19766 .30122 .19445 Metetra
.666 .73 .897 r
.30122 .19445 .30395 .19766 .30823 .19597 .3055 .19275 Metetra
.665 .73 .898 r
.3055 .19275 .30823 .19597 .31252 .19429 .3098 .19106 Metetra
.665 .73 .898 r
.3098 .19106 .31252 .19429 .31682 .1926 .3141 .18937 Metetra
.664 .73 .898 r
.3141 .18937 .31682 .1926 .32112 .19092 .3184 .18769 Metetra
.664 .73 .898 r
.3184 .18769 .32112 .19092 .32543 .18924 .32271 .186 Metetra
.664 .73 .899 r
.32271 .186 .32543 .18924 .32974 .18756 .32703 .18432 Metetra
.663 .73 .899 r
.32703 .18432 .32974 .18756 .33406 .18588 .33136 .18264 Metetra
.663 .73 .899 r
.33136 .18264 .33406 .18588 .33839 .1842 .33569 .18096 Metetra
.663 .729 .899 r
.33569 .18096 .33839 .1842 .34273 .18253 .34003 .17928 Metetra
.662 .729 .899 r
.34003 .17928 .34273 .18253 .34707 .18085 .34438 .1776 Metetra
.662 .729 .899 r
.34438 .1776 .34707 .18085 .35142 .17918 .34873 .17592 Metetra
.662 .729 .9 r
.34873 .17592 .35142 .17918 .35577 .17751 .35309 .17424 Metetra
.661 .729 .9 r
.35309 .17424 .35577 .17751 .36014 .17584 .35746 .17257 Metetra
.661 .729 .9 r
.35746 .17257 .36014 .17584 .36451 .17417 .36183 .1709 Metetra
.661 .729 .9 r
.36183 .1709 .36451 .17417 .36888 .17251 .36621 .16922 Metetra
.66 .729 .9 r
.36621 .16922 .36888 .17251 .37327 .17084 .3706 .16755 Metetra
.66 .729 .9 r
.3706 .16755 .37327 .17084 .37766 .16918 .37499 .16588 Metetra
.659 .728 .9 r
.37499 .16588 .37766 .16918 .38205 .16751 .37939 .16421 Metetra
.659 .728 .9 r
.37939 .16421 .38205 .16751 .38646 .16585 .3838 .16255 Metetra
.659 .728 .9 r
.3838 .16255 .38646 .16585 .39087 .16419 .38822 .16088 Metetra
.658 .728 .901 r
.38822 .16088 .39087 .16419 .39529 .16253 .39264 .15922 Metetra
.658 .728 .901 r
.39264 .15922 .39529 .16253 .39971 .16088 .39707 .15755 Metetra
.658 .727 .901 r
.39707 .15755 .39971 .16088 .40415 .15922 .40151 .15589 Metetra
.657 .727 .901 r
.40151 .15589 .40415 .15922 .40859 .15757 .40595 .15423 Metetra
.657 .727 .901 r
.40595 .15423 .40859 .15757 .41304 .15592 .41041 .15258 Metetra
.656 .727 .901 r
.41041 .15258 .41304 .15592 .41749 .15427 .41487 .15092 Metetra
.656 .726 .901 r
.41487 .15092 .41749 .15427 .42195 .15262 .41933 .14926 Metetra
.655 .726 .901 r
.41933 .14926 .42195 .15262 .42642 .15098 .42381 .14761 Metetra
.655 .726 .901 r
.42381 .14761 .42642 .15098 .4309 .14934 .42829 .14596 Metetra
.655 .725 .901 r
.42829 .14596 .4309 .14934 .43539 .1477 .43278 .14431 Metetra
.654 .725 .901 r
.43278 .14431 .43539 .1477 .43988 .14606 .43728 .14267 Metetra
.654 .725 .901 r
.43728 .14267 .43988 .14606 .44438 .14443 .44178 .14103 Metetra
.653 .724 .901 r
.44178 .14103 .44438 .14443 .44889 .14279 .44629 .13939 Metetra
.652 .724 .901 r
.44629 .13939 .44889 .14279 .4534 .14117 .45081 .13775 Metetra
.652 .723 .901 r
.45081 .13775 .4534 .14117 .45792 .13954 .45534 .13612 Metetra
.651 .723 .901 r
.45534 .13612 .45792 .13954 .46246 .13792 .45987 .13448 Metetra
.651 .722 .901 r
.45987 .13448 .46246 .13792 .46699 .1363 .46442 .13286 Metetra
.65 .722 .901 r
.46442 .13286 .46699 .1363 .47154 .13469 .46897 .13124 Metetra
.649 .721 .901 r
.46897 .13124 .47154 .13469 .47609 .13308 .47353 .12962 Metetra
.649 .72 .901 r
.47353 .12962 .47609 .13308 .48066 .13148 .47809 .128 Metetra
.648 .72 .901 r
.47809 .128 .48066 .13148 .48523 .12988 .48267 .12639 Metetra
.647 .719 .901 r
.48267 .12639 .48523 .12988 .4898 .12829 .48725 .12479 Metetra
.646 .718 .9 r
.48725 .12479 .4898 .12829 .49439 .12671 .49184 .12319 Metetra
.646 .717 .9 r
.49184 .12319 .49439 .12671 .49899 .12513 .49644 .1216 Metetra
.645 .717 .9 r
.49644 .1216 .49899 .12513 .50359 .12356 .50105 .12002 Metetra
.644 .716 .9 r
.50105 .12002 .50359 .12356 .5082 .12199 .50566 .11844 Metetra
.643 .715 .9 r
.50566 .11844 .5082 .12199 .51282 .12044 .51029 .11687 Metetra
.642 .714 .9 r
.51029 .11687 .51282 .12044 .51745 .1189 .51492 .11531 Metetra
.64 .712 .899 r
.51492 .11531 .51745 .1189 .52208 .11736 .51956 .11376 Metetra
.639 .711 .899 r
.51956 .11376 .52208 .11736 .52673 .11584 .52421 .11223 Metetra
.638 .71 .899 r
.52421 .11223 .52673 .11584 .53138 .11433 .52887 .1107 Metetra
.636 .708 .899 r
.52887 .1107 .53138 .11433 .53604 .11283 .53353 .10918 Metetra
.635 .707 .898 r
.53353 .10918 .53604 .11283 .54071 .11135 .53821 .10768 Metetra
.633 .705 .898 r
.53821 .10768 .54071 .11135 .54539 .10989 .54289 .1062 Metetra
.631 .703 .898 r
.54289 .1062 .54539 .10989 .55008 .10844 .54759 .10473 Metetra
.629 .701 .897 r
.54759 .10473 .55008 .10844 .55478 .10702 .55229 .10328 Metetra
.627 .699 .897 r
.55229 .10328 .55478 .10702 .55949 .10561 .557 .10185 Metetra
.625 .696 .896 r
.557 .10185 .55949 .10561 .56421 .10424 .56172 .10044 Metetra
.622 .694 .895 r
.56172 .10044 .56421 .10424 .56893 .10289 .56645 .09906 Metetra
.619 .691 .894 r
.56645 .09906 .56893 .10289 .57367 .10157 .5712 .0977 Metetra
.616 .687 .894 r
.5712 .0977 .57367 .10157 .57883 .12248 .57595 .09638 Metetra
0 0 .455 r
.57595 .09638 .57883 .12248 .58363 .12187 .58113 .11736 Metetra
.55 .618 .873 r
.58113 .11736 .58363 .12187 .58846 .12136 .58596 .11676 Metetra
.542 .608 .869 r
.58596 .11676 .58846 .12136 .59329 .12096 .5908 .11625 Metetra
.532 .598 .865 r
.5908 .11625 .59329 .12096 .59815 .12068 .59565 .11586 Metetra
.521 .586 .86 r
.59565 .11586 .59815 .12068 .60302 .12056 .60052 .1156 Metetra
.508 .572 .855 r
.60052 .1156 .60302 .12056 .60791 .1206 .6054 .11549 Metetra
.493 .556 .848 r
.6054 .11549 .60791 .1206 .61282 .12085 .61031 .11555 Metetra
.477 .538 .84 r
.61031 .11555 .61282 .12085 .61775 .12134 .61524 .11582 Metetra
.457 .516 .831 r
.61524 .11582 .61775 .12134 .62271 .12212 .62019 .11634 Metetra
.435 .492 .819 r
.62019 .11634 .62271 .12212 .6277 .12326 .62517 .11716 Metetra
.408 .463 .805 r
.62517 .11716 .6277 .12326 .63273 .12486 .63018 .11835 Metetra
.377 .429 .788 r
.63018 .11835 .63273 .12486 .63779 .12702 .63522 .12001 Metetra
.34 .388 .766 r
.63522 .12001 .63779 .12702 .64291 .12993 .64031 .12226 Metetra
.297 .341 .739 r
.64031 .12226 .64291 .12993 .6481 .13386 .64546 .12529 Metetra
.246 .285 .705 r
.64546 .12529 .6481 .13386 .65338 .13921 .65067 .12939 Metetra
.186 .219 .663 r
.65067 .12939 .65338 .13921 .65878 .14668 .65598 .13499 Metetra
.117 .144 .613 r
.65598 .13499 .65878 .14668 .66439 .15754 .66143 .14285 Metetra
.04 .06 .552 r
.66143 .14285 .66439 .15754 .67034 .17447 .6671 .15437 Metetra
0 0 .483 r
.6671 .15437 .67034 .17447 .67702 .20444 .67315 .1726 Metetra
0 0 .407 r
.67315 .1726 .67702 .20444 .68595 .27538 .68006 .20583 Metetra
0 0 .394 r
.68006 .20583 .68595 .27538 .69132 .27506 .68882 .2717 Metetra
.977 .675 .334 r
.68882 .2717 .69132 .27506 .68306 .02879 .68074 .02531 Metetra
.664 .741 .907 r
.68074 .02531 .68306 .02879 .68793 .02691 .68562 .02342 Metetra
.664 .741 .907 r
.68562 .02342 .68793 .02691 .69282 .02502 .69051 .02152 Metetra
.664 .741 .907 r
.69051 .02152 .69282 .02502 .69771 .02312 .69541 .01962 Metetra
.664 .741 .907 r
.69541 .01962 .69771 .02312 .70261 .02123 .70032 .01772 Metetra
.664 .741 .907 r
.04907 .26626 .05203 .26903 .05589 .26753 .05293 .26476 Metetra
.664 .741 .907 r
.05293 .26476 .05589 .26753 .05975 .26603 .0568 .26326 Metetra
.664 .741 .907 r
.0568 .26326 .05975 .26603 .06362 .26453 .06067 .26176 Metetra
.939 .681 .519 r
.06067 .26176 .06362 .26453 .06749 .26303 .02957 .49448 Metetra
.335 .115 .423 r
.02957 .49448 .06749 .26303 .03694 .49568 .04224 .43559 Metetra
.716 .471 .554 r
.04224 .43559 .03694 .49568 .0505 .42982 .05178 .39702 Metetra
.723 .489 .572 r
.05178 .39702 .0505 .42982 .05943 .39483 .05884 .37494 Metetra
.739 .52 .595 r
.05884 .37494 .05943 .39483 .06625 .37411 .06484 .35993 Metetra
.748 .543 .618 r
.06484 .35993 .06625 .37411 .07212 .35979 .07026 .34871 Metetra
.752 .563 .64 r
.07026 .34871 .07212 .35979 .07747 .34897 .07534 .3398 Metetra
.754 .58 .661 r
.07534 .3398 .07747 .34897 .0825 .34031 .0802 .3324 Metetra
.754 .595 .68 r
.0802 .3324 .0825 .34031 .08732 .33309 .0849 .32607 Metetra
.753 .609 .698 r
.0849 .32607 .08732 .33309 .09199 .32688 .08948 .32052 Metetra
.751 .62 .715 r
.08948 .32052 .09199 .32688 .09655 .32143 .09398 .31556 Metetra
.749 .631 .73 r
.09398 .31556 .09655 .32143 .10104 .31654 .09841 .31107 Metetra
.746 .64 .743 r
.09841 .31107 .10104 .31654 .10546 .3121 .1028 .30694 Metetra
.743 .649 .755 r
.1028 .30694 .10546 .3121 .10983 .30802 .10714 .3031 Metetra
.74 .656 .767 r
.10714 .3031 .10983 .30802 .11417 .30422 .11145 .29951 Metetra
.737 .663 .777 r
.11145 .29951 .11417 .30422 .11847 .30067 .11574 .29613 Metetra
.734 .668 .786 r
.11574 .29613 .11847 .30067 .12275 .29731 .12 .29292 Metetra
.731 .674 .794 r
.12 .29292 .12275 .29731 .12701 .29413 .12425 .28986 Metetra
.728 .678 .802 r
.12425 .28986 .12701 .29413 .13126 .29108 .12848 .28692 Metetra
.725 .683 .808 r
.12848 .28692 .13126 .29108 .13549 .28817 .1327 .2841 Metetra
.723 .686 .815 r
.1327 .2841 .13549 .28817 .13971 .28536 .13692 .28137 Metetra
.919 .707 .599 r
.13692 .28137 .13971 .28536 .14392 .28264 .14374 .25756 Metetra
.55 .356 .57 r
.14374 .25756 .14392 .28264 .15069 .2589 .14785 .25552 Metetra
.693 .716 .866 r
.14785 .25552 .15069 .2589 .1548 .25687 .15196 .25352 Metetra
.692 .717 .869 r
.15196 .25352 .1548 .25687 .15891 .25487 .15607 .25154 Metetra
.69 .718 .871 r
.15607 .25154 .15891 .25487 .16302 .25291 .16018 .24959 Metetra
.688 .72 .873 r
.16018 .24959 .16302 .25291 .16713 .25096 .1643 .24766 Metetra
.687 .721 .875 r
.1643 .24766 .16713 .25096 .17125 .24904 .16841 .24576 Metetra
.686 .721 .877 r
.16841 .24576 .17125 .24904 .17537 .24714 .17254 .24387 Metetra
.684 .722 .878 r
.17254 .24387 .17537 .24714 .17949 .24526 .17666 .242 Metetra
.683 .723 .88 r
.17666 .242 .17949 .24526 .18362 .24339 .18079 .24014 Metetra
.682 .724 .881 r
.18079 .24014 .18362 .24339 .18775 .24154 .18492 .2383 Metetra
.681 .724 .882 r
.18492 .2383 .18775 .24154 .19188 .2397 .18906 .23647 Metetra
.68 .725 .884 r
.18906 .23647 .19188 .2397 .19602 .23788 .1932 .23465 Metetra
.679 .725 .885 r
.1932 .23465 .19602 .23788 .20017 .23607 .19734 .23285 Metetra
.678 .726 .886 r
.19734 .23285 .20017 .23607 .20431 .23426 .20149 .23105 Metetra
.677 .726 .887 r
.20149 .23105 .20431 .23426 .20847 .23247 .20565 .22926 Metetra
.677 .727 .887 r
.20565 .22926 .20847 .23247 .21262 .23069 .20981 .22748 Metetra
.676 .727 .888 r
.20981 .22748 .21262 .23069 .21679 .22891 .21398 .22571 Metetra
.675 .727 .889 r
.21398 .22571 .21679 .22891 .22095 .22714 .21815 .22394 Metetra
.674 .728 .89 r
.21815 .22394 .22095 .22714 .22513 .22538 .22232 .22218 Metetra
.674 .728 .89 r
.22232 .22218 .22513 .22538 .2293 .22363 .2265 .22043 Metetra
.673 .728 .891 r
.2265 .22043 .2293 .22363 .23349 .22188 .23069 .21868 Metetra
.673 .728 .892 r
.23069 .21868 .23349 .22188 .23768 .22014 .23488 .21694 Metetra
.672 .729 .892 r
.23488 .21694 .23768 .22014 .24187 .2184 .23908 .2152 Metetra
.671 .729 .893 r
.23908 .2152 .24187 .2184 .24607 .21667 .24328 .21347 Metetra
.671 .729 .893 r
.24328 .21347 .24607 .21667 .25028 .21494 .24749 .21174 Metetra
.67 .729 .894 r
.24749 .21174 .25028 .21494 .25449 .21321 .25171 .21001 Metetra
.67 .729 .894 r
.25171 .21001 .25449 .21321 .25871 .21149 .25593 .20829 Metetra
.669 .729 .895 r
.25593 .20829 .25871 .21149 .26293 .20977 .26015 .20657 Metetra
.669 .729 .895 r
.26015 .20657 .26293 .20977 .26716 .20806 .26439 .20486 Metetra
.669 .73 .895 r
.26439 .20486 .26716 .20806 .27139 .20635 .26863 .20314 Metetra
.668 .73 .896 r
.26863 .20314 .27139 .20635 .27564 .20464 .27287 .20143 Metetra
.668 .73 .896 r
.27287 .20143 .27564 .20464 .27988 .20294 .27712 .19973 Metetra
.667 .73 .896 r
.27712 .19973 .27988 .20294 .28414 .20123 .28138 .19802 Metetra
.667 .73 .897 r
.28138 .19802 .28414 .20123 .2884 .19953 .28565 .19632 Metetra
.667 .73 .897 r
.28565 .19632 .2884 .19953 .29267 .19784 .28992 .19462 Metetra
.666 .73 .897 r
.28992 .19462 .29267 .19784 .29694 .19614 .29419 .19292 Metetra
.666 .73 .897 r
.29419 .19292 .29694 .19614 .30122 .19445 .29848 .19122 Metetra
.665 .73 .898 r
.29848 .19122 .30122 .19445 .3055 .19275 .30277 .18953 Metetra
.665 .73 .898 r
.30277 .18953 .3055 .19275 .3098 .19106 .30706 .18783 Metetra
.665 .73 .898 r
.30706 .18783 .3098 .19106 .3141 .18937 .31137 .18614 Metetra
.664 .73 .898 r
.31137 .18614 .3141 .18937 .3184 .18769 .31568 .18445 Metetra
.664 .73 .899 r
.31568 .18445 .3184 .18769 .32271 .186 .31999 .18276 Metetra
.664 .73 .899 r
.31999 .18276 .32271 .186 .32703 .18432 .32432 .18107 Metetra
.663 .73 .899 r
.32432 .18107 .32703 .18432 .33136 .18264 .32865 .17939 Metetra
.663 .73 .899 r
.32865 .17939 .33136 .18264 .33569 .18096 .33298 .1777 Metetra
.663 .73 .899 r
.33298 .1777 .33569 .18096 .34003 .17928 .33732 .17602 Metetra
.662 .73 .899 r
.33732 .17602 .34003 .17928 .34438 .1776 .34168 .17433 Metetra
.662 .729 .9 r
.34168 .17433 .34438 .1776 .34873 .17592 .34603 .17265 Metetra
.662 .729 .9 r
.34603 .17265 .34873 .17592 .35309 .17424 .3504 .17097 Metetra
.661 .729 .9 r
.3504 .17097 .35309 .17424 .35746 .17257 .35477 .16929 Metetra
.661 .729 .9 r
.35477 .16929 .35746 .17257 .36183 .1709 .35914 .16761 Metetra
.661 .729 .9 r
.35914 .16761 .36183 .1709 .36621 .16922 .36353 .16593 Metetra
.66 .729 .9 r
.36353 .16593 .36621 .16922 .3706 .16755 .36792 .16426 Metetra
.66 .729 .9 r
.36792 .16426 .3706 .16755 .37499 .16588 .37232 .16258 Metetra
.66 .729 .9 r
.37232 .16258 .37499 .16588 .37939 .16421 .37673 .16091 Metetra
.659 .728 .901 r
.37673 .16091 .37939 .16421 .3838 .16255 .38114 .15923 Metetra
.659 .728 .901 r
.38114 .15923 .3838 .16255 .38822 .16088 .38556 .15756 Metetra
.658 .728 .901 r
.38556 .15756 .38822 .16088 .39264 .15922 .38999 .15589 Metetra
.658 .728 .901 r
.38999 .15589 .39264 .15922 .39707 .15755 .39442 .15422 Metetra
.658 .728 .901 r
.39442 .15422 .39707 .15755 .40151 .15589 .39886 .15256 Metetra
.657 .727 .901 r
.39886 .15256 .40151 .15589 .40595 .15423 .40331 .15089 Metetra
.657 .727 .901 r
.40331 .15089 .40595 .15423 .41041 .15258 .40777 .14922 Metetra
.656 .727 .901 r
.40777 .14922 .41041 .15258 .41487 .15092 .41223 .14756 Metetra
.656 .727 .901 r
.41223 .14756 .41487 .15092 .41933 .14926 .4167 .1459 Metetra
.656 .726 .901 r
.4167 .1459 .41933 .14926 .42381 .14761 .42118 .14424 Metetra
.655 .726 .901 r
.42118 .14424 .42381 .14761 .42829 .14596 .42567 .14258 Metetra
.655 .726 .901 r
.42567 .14258 .42829 .14596 .43278 .14431 .43016 .14093 Metetra
.654 .725 .901 r
.43016 .14093 .43278 .14431 .43728 .14267 .43466 .13927 Metetra
.654 .725 .901 r
.43466 .13927 .43728 .14267 .44178 .14103 .43917 .13762 Metetra
.653 .725 .901 r
.43917 .13762 .44178 .14103 .44629 .13939 .44369 .13597 Metetra
.653 .724 .901 r
.44369 .13597 .44629 .13939 .45081 .13775 .44821 .13433 Metetra
.652 .724 .901 r
.44821 .13433 .45081 .13775 .45534 .13612 .45275 .13268 Metetra
.652 .723 .901 r
.45275 .13268 .45534 .13612 .45987 .13448 .45729 .13104 Metetra
.651 .723 .901 r
.45729 .13104 .45987 .13448 .46442 .13286 .46183 .12941 Metetra
.651 .722 .901 r
.46183 .12941 .46442 .13286 .46897 .13124 .46639 .12778 Metetra
.65 .722 .901 r
.46639 .12778 .46897 .13124 .47353 .12962 .47095 .12615 Metetra
.649 .721 .901 r
.47095 .12615 .47353 .12962 .47809 .128 .47552 .12452 Metetra
.649 .72 .901 r
.47552 .12452 .47809 .128 .48267 .12639 .4801 .1229 Metetra
.648 .72 .901 r
.4801 .1229 .48267 .12639 .48725 .12479 .48469 .12129 Metetra
.647 .719 .901 r
.48469 .12129 .48725 .12479 .49184 .12319 .48928 .11968 Metetra
.646 .718 .901 r
.48928 .11968 .49184 .12319 .49644 .1216 .49389 .11808 Metetra
.645 .717 .9 r
.49389 .11808 .49644 .1216 .50105 .12002 .4985 .11648 Metetra
.644 .716 .9 r
.4985 .11648 .50105 .12002 .50566 .11844 .50312 .11489 Metetra
.643 .716 .9 r
.50312 .11489 .50566 .11844 .51029 .11687 .50775 .11331 Metetra
.642 .715 .9 r
.50775 .11331 .51029 .11687 .51492 .11531 .51238 .11173 Metetra
.641 .713 .9 r
.51238 .11173 .51492 .11531 .51956 .11376 .51703 .11017 Metetra
.64 .712 .9 r
.51703 .11017 .51956 .11376 .52421 .11223 .52168 .10861 Metetra
.639 .711 .899 r
.52168 .10861 .52421 .11223 .52887 .1107 .52634 .10707 Metetra
.638 .71 .899 r
.52634 .10707 .52887 .1107 .53353 .10918 .53102 .10553 Metetra
.636 .708 .899 r
.53102 .10553 .53353 .10918 .53821 .10768 .5357 .10401 Metetra
.635 .707 .898 r
.5357 .10401 .53821 .10768 .54289 .1062 .54038 .10251 Metetra
.633 .705 .898 r
.54038 .10251 .54289 .1062 .54759 .10473 .54508 .10101 Metetra
.631 .703 .898 r
.54508 .10101 .54759 .10473 .55229 .10328 .54979 .09954 Metetra
.629 .701 .897 r
.54979 .09954 .55229 .10328 .557 .10185 .55451 .09808 Metetra
.627 .698 .896 r
.55451 .09808 .557 .10185 .56172 .10044 .55923 .09665 Metetra
.624 .696 .896 r
.55923 .09665 .56172 .10044 .56645 .09906 .56397 .09524 Metetra
.622 .693 .895 r
.56397 .09524 .56645 .09906 .5712 .0977 .56871 .09385 Metetra
.619 .69 .894 r
.56871 .09385 .5712 .0977 .57595 .09638 .57347 .0925 Metetra
.616 .687 .893 r
.57347 .0925 .57595 .09638 .58113 .11736 .57823 .09117 Metetra
0 0 .455 r
.57823 .09117 .58113 .11736 .58596 .11676 .58345 .11222 Metetra
.549 .617 .872 r
.58345 .11222 .58596 .11676 .5908 .11625 .58829 .11162 Metetra
.54 .607 .869 r
.58829 .11162 .5908 .11625 .59565 .11586 .59314 .11112 Metetra
.53 .596 .864 r
.59314 .11112 .59565 .11586 .60052 .1156 .59801 .11074 Metetra
.519 .584 .86 r
.59801 .11074 .60052 .1156 .6054 .11549 .6029 .11049 Metetra
.506 .57 .854 r
.6029 .11049 .6054 .11549 .61031 .11555 .6078 .11039 Metetra
.491 .553 .847 r
.6078 .11039 .61031 .11555 .61524 .11582 .61273 .11047 Metetra
.474 .535 .839 r
.61273 .11047 .61524 .11582 .62019 .11634 .61767 .11076 Metetra
.455 .513 .829 r
.61767 .11076 .62019 .11634 .62517 .11716 .62264 .11131 Metetra
.432 .488 .817 r
.62264 .11131 .62517 .11716 .63018 .11835 .62764 .11217 Metetra
.405 .458 .803 r
.62764 .11217 .63018 .11835 .63522 .12001 .63267 .11342 Metetra
.373 .423 .784 r
.63267 .11342 .63522 .12001 .64031 .12226 .63773 .11514 Metetra
.335 .382 .762 r
.63773 .11514 .64031 .12226 .64546 .12529 .64284 .11748 Metetra
.291 .334 .734 r
.64284 .11748 .64546 .12529 .65067 .12939 .64801 .12063 Metetra
.239 .276 .699 r
.64801 .12063 .65067 .12939 .65598 .13499 .65326 .1249 Metetra
.178 .21 .657 r
.65326 .1249 .65598 .13499 .66143 .14285 .6586 .13076 Metetra
.108 .133 .604 r
.6586 .13076 .66143 .14285 .6671 .15437 .6641 .13903 Metetra
.03 .048 .543 r
.6641 .13903 .6671 .15437 .67315 .1726 .66983 .15126 Metetra
0 0 .473 r
.66983 .15126 .67315 .1726 .68006 .20583 .676 .17093 Metetra
0 0 .397 r
.676 .17093 .68006 .20583 .68882 .2717 .68316 .20793 Metetra
0 0 .404 r
.68316 .20793 .68882 .2717 .68074 .02531 .69162 .26651 Metetra
0 0 .331 r
.69162 .26651 .68074 .02531 .68562 .02342 .6833 .01991 Metetra
.664 .741 .907 r
.6833 .01991 .68562 .02342 .69051 .02152 .6882 .01801 Metetra
.664 .741 .907 r
.6882 .01801 .69051 .02152 .69541 .01962 .6931 .01611 Metetra
.664 .741 .907 r
.6931 .01611 .69541 .01962 .70032 .01772 .69802 .0142 Metetra
.664 .741 .907 r
.04611 .26349 .04907 .26626 .05293 .26476 .04997 .26199 Metetra
.664 .741 .907 r
.04997 .26199 .05293 .26476 .0568 .26326 .05384 .26048 Metetra
.939 .68 .519 r
.05384 .26048 .0568 .26326 .06067 .26176 .0222 .49327 Metetra
.36 .135 .431 r
.0222 .49327 .06067 .26176 .02957 .49448 .03381 .44218 Metetra
.745 .5 .559 r
.03381 .44218 .02957 .49448 .04224 .43559 .04407 .39943 Metetra
.719 .483 .568 r
.04407 .39943 .04224 .43559 .05178 .39702 .0514 .37584 Metetra
.737 .515 .592 r
.0514 .37584 .05178 .39702 .05884 .37494 .05754 .36011 Metetra
.746 .54 .615 r
.05754 .36011 .05884 .37494 .06484 .35993 .06304 .34847 Metetra
.751 .56 .637 r
.06304 .34847 .06484 .35993 .07026 .34871 .06818 .33929 Metetra
.753 .577 .658 r
.06818 .33929 .07026 .34871 .07534 .3398 .07307 .33172 Metetra
.753 .593 .677 r
.07307 .33172 .07534 .3398 .0802 .3324 .07779 .32526 Metetra
.753 .606 .696 r
.07779 .32526 .0802 .3324 .0849 .32607 .0824 .31962 Metetra
.751 .619 .712 r
.0824 .31962 .0849 .32607 .08948 .32052 .08691 .31458 Metetra
.749 .629 .727 r
.08691 .31458 .08948 .32052 .09398 .31556 .09136 .31003 Metetra
.746 .639 .741 r
.09136 .31003 .09398 .31556 .09841 .31107 .09575 .30585 Metetra
.743 .647 .754 r
.09575 .30585 .09841 .31107 .1028 .30694 .1001 .30198 Metetra
.74 .655 .765 r
.1001 .30198 .1028 .30694 .10714 .3031 .10442 .29836 Metetra
.737 .661 .775 r
.10442 .29836 .10714 .3031 .11145 .29951 .10871 .29495 Metetra
.734 .667 .785 r
.10871 .29495 .11145 .29951 .11574 .29613 .11298 .29171 Metetra
.731 .673 .793 r
.11298 .29171 .11574 .29613 .12 .29292 .11723 .28863 Metetra
.728 .678 .801 r
.11723 .28863 .12 .29292 .12425 .28986 .12146 .28568 Metetra
.726 .682 .808 r
.12146 .28568 .12425 .28986 .12848 .28692 .12569 .28284 Metetra
.723 .686 .814 r
.12569 .28284 .12848 .28692 .1327 .2841 .1299 .28009 Metetra
.919 .707 .6 r
.1299 .28009 .1327 .2841 .13692 .28137 .13678 .25621 Metetra
.55 .355 .57 r
.13678 .25621 .13692 .28137 .14374 .25756 .14089 .25417 Metetra
.694 .716 .866 r
.14089 .25417 .14374 .25756 .14785 .25552 .145 .25216 Metetra
.692 .717 .868 r
.145 .25216 .14785 .25552 .15196 .25352 .14911 .25018 Metetra
.69 .718 .871 r
.14911 .25018 .15196 .25352 .15607 .25154 .15322 .24822 Metetra
.689 .719 .873 r
.15322 .24822 .15607 .25154 .16018 .24959 .15733 .24629 Metetra
.687 .72 .875 r
.15733 .24629 .16018 .24959 .1643 .24766 .16145 .24437 Metetra
.686 .721 .877 r
.16145 .24437 .1643 .24766 .16841 .24576 .16557 .24248 Metetra
.685 .722 .878 r
.16557 .24248 .16841 .24576 .17254 .24387 .16969 .2406 Metetra
.683 .723 .88 r
.16969 .2406 .17254 .24387 .17666 .242 .17382 .23874 Metetra
.682 .724 .881 r
.17382 .23874 .17666 .242 .18079 .24014 .17795 .2369 Metetra
.681 .724 .882 r
.17795 .2369 .18079 .24014 .18492 .2383 .18208 .23506 Metetra
.68 .725 .883 r
.18208 .23506 .18492 .2383 .18906 .23647 .18622 .23324 Metetra
.679 .725 .885 r
.18622 .23324 .18906 .23647 .1932 .23465 .19037 .23143 Metetra
.678 .726 .886 r
.19037 .23143 .1932 .23465 .19734 .23285 .19451 .22962 Metetra
.678 .726 .886 r
.19451 .22962 .19734 .23285 .20149 .23105 .19867 .22783 Metetra
.677 .727 .887 r
.19867 .22783 .20149 .23105 .20565 .22926 .20283 .22605 Metetra
.676 .727 .888 r
.20283 .22605 .20565 .22926 .20981 .22748 .20699 .22427 Metetra
.675 .727 .889 r
.20699 .22427 .20981 .22748 .21398 .22571 .21116 .2225 Metetra
.675 .728 .89 r
.21116 .2225 .21398 .22571 .21815 .22394 .21533 .22074 Metetra
.674 .728 .89 r
.21533 .22074 .21815 .22394 .22232 .22218 .21951 .21898 Metetra
.673 .728 .891 r
.21951 .21898 .22232 .22218 .2265 .22043 .22369 .21723 Metetra
.673 .728 .892 r
.22369 .21723 .2265 .22043 .23069 .21868 .22788 .21548 Metetra
.672 .729 .892 r
.22788 .21548 .23069 .21868 .23488 .21694 .23208 .21374 Metetra
.672 .729 .893 r
.23208 .21374 .23488 .21694 .23908 .2152 .23628 .212 Metetra
.671 .729 .893 r
.23628 .212 .23908 .2152 .24328 .21347 .24049 .21027 Metetra
.671 .729 .894 r
.24049 .21027 .24328 .21347 .24749 .21174 .2447 .20854 Metetra
.67 .729 .894 r
.2447 .20854 .24749 .21174 .25171 .21001 .24892 .20681 Metetra
.67 .729 .895 r
.24892 .20681 .25171 .21001 .25593 .20829 .25314 .20509 Metetra
.669 .73 .895 r
.25314 .20509 .25593 .20829 .26015 .20657 .25737 .20337 Metetra
.669 .73 .895 r
.25737 .20337 .26015 .20657 .26439 .20486 .26161 .20165 Metetra
.668 .73 .896 r
.26161 .20165 .26439 .20486 .26863 .20314 .26585 .19993 Metetra
.668 .73 .896 r
.26585 .19993 .26863 .20314 .27287 .20143 .2701 .19822 Metetra
.668 .73 .896 r
.2701 .19822 .27287 .20143 .27712 .19973 .27436 .19651 Metetra
.667 .73 .897 r
.27436 .19651 .27712 .19973 .28138 .19802 .27862 .19481 Metetra
.667 .73 .897 r
.27862 .19481 .28138 .19802 .28565 .19632 .28289 .1931 Metetra
.666 .73 .897 r
.28289 .1931 .28565 .19632 .28992 .19462 .28716 .1914 Metetra
.666 .73 .897 r
.28716 .1914 .28992 .19462 .29419 .19292 .29144 .18969 Metetra
.666 .73 .898 r
.29144 .18969 .29419 .19292 .29848 .19122 .29573 .18799 Metetra
.665 .73 .898 r
.29573 .18799 .29848 .19122 .30277 .18953 .30002 .18629 Metetra
.665 .73 .898 r
.30002 .18629 .30277 .18953 .30706 .18783 .30432 .1846 Metetra
.665 .73 .898 r
.30432 .1846 .30706 .18783 .31137 .18614 .30863 .1829 Metetra
.664 .73 .899 r
.30863 .1829 .31137 .18614 .31568 .18445 .31294 .18121 Metetra
.664 .73 .899 r
.31294 .18121 .31568 .18445 .31999 .18276 .31726 .17951 Metetra
.664 .73 .899 r
.31726 .17951 .31999 .18276 .32432 .18107 .32159 .17782 Metetra
.663 .73 .899 r
.32159 .17782 .32432 .18107 .32865 .17939 .32592 .17613 Metetra
.663 .73 .899 r
.32592 .17613 .32865 .17939 .33298 .1777 .33026 .17444 Metetra
.663 .73 .899 r
.33026 .17444 .33298 .1777 .33732 .17602 .33461 .17275 Metetra
.662 .73 .9 r
.33461 .17275 .33732 .17602 .34168 .17433 .33897 .17106 Metetra
.662 .73 .9 r
.33897 .17106 .34168 .17433 .34603 .17265 .34333 .16938 Metetra
.662 .73 .9 r
.34333 .16938 .34603 .17265 .3504 .17097 .34769 .16769 Metetra
.661 .729 .9 r
.34769 .16769 .3504 .17097 .35477 .16929 .35207 .166 Metetra
.661 .729 .9 r
.35207 .166 .35477 .16929 .35914 .16761 .35645 .16432 Metetra
.661 .729 .9 r
.35645 .16432 .35914 .16761 .36353 .16593 .36084 .16264 Metetra
.66 .729 .9 r
.36084 .16264 .36353 .16593 .36792 .16426 .36524 .16096 Metetra
.66 .729 .9 r
.36524 .16096 .36792 .16426 .37232 .16258 .36964 .15927 Metetra
.66 .729 .901 r
.36964 .15927 .37232 .16258 .37673 .16091 .37405 .15759 Metetra
.659 .729 .901 r
.37405 .15759 .37673 .16091 .38114 .15923 .37847 .15592 Metetra
.659 .728 .901 r
.37847 .15592 .38114 .15923 .38556 .15756 .38289 .15424 Metetra
.659 .728 .901 r
.38289 .15424 .38556 .15756 .38999 .15589 .38732 .15256 Metetra
.658 .728 .901 r
.38732 .15256 .38999 .15589 .39442 .15422 .39176 .15089 Metetra
.658 .728 .901 r
.39176 .15089 .39442 .15422 .39886 .15256 .39621 .14921 Metetra
.657 .728 .901 r
.39621 .14921 .39886 .15256 .40331 .15089 .40066 .14754 Metetra
.657 .727 .901 r
.40066 .14754 .40331 .15089 .40777 .14922 .40512 .14587 Metetra
.657 .727 .901 r
.40512 .14587 .40777 .14922 .41223 .14756 .40959 .1442 Metetra
.656 .727 .901 r
.40959 .1442 .41223 .14756 .4167 .1459 .41407 .14253 Metetra
.656 .727 .901 r
.41407 .14253 .4167 .1459 .42118 .14424 .41855 .14086 Metetra
.655 .726 .901 r
.41855 .14086 .42118 .14424 .42567 .14258 .42304 .13919 Metetra
.655 .726 .901 r
.42304 .13919 .42567 .14258 .43016 .14093 .42754 .13753 Metetra
.655 .726 .901 r
.42754 .13753 .43016 .14093 .43466 .13927 .43205 .13587 Metetra
.654 .725 .901 r
.43205 .13587 .43466 .13927 .43917 .13762 .43656 .13421 Metetra
.654 .725 .901 r
.43656 .13421 .43917 .13762 .44369 .13597 .44108 .13255 Metetra
.653 .725 .901 r
.44108 .13255 .44369 .13597 .44821 .13433 .44561 .1309 Metetra
.653 .724 .901 r
.44561 .1309 .44821 .13433 .45275 .13268 .45014 .12925 Metetra
.652 .724 .901 r
.45014 .12925 .45275 .13268 .45729 .13104 .45469 .1276 Metetra
.651 .723 .901 r
.45469 .1276 .45729 .13104 .46183 .12941 .45924 .12595 Metetra
.651 .723 .901 r
.45924 .12595 .46183 .12941 .46639 .12778 .4638 .12431 Metetra
.65 .722 .901 r
.4638 .12431 .46639 .12778 .47095 .12615 .46837 .12267 Metetra
.65 .722 .901 r
.46837 .12267 .47095 .12615 .47552 .12452 .47294 .12104 Metetra
.649 .721 .901 r
.47294 .12104 .47552 .12452 .4801 .1229 .47753 .11941 Metetra
.648 .72 .901 r
.47753 .11941 .4801 .1229 .48469 .12129 .48212 .11778 Metetra
.648 .72 .901 r
.48212 .11778 .48469 .12129 .48928 .11968 .48672 .11616 Metetra
.647 .719 .901 r
.48672 .11616 .48928 .11968 .49389 .11808 .49133 .11455 Metetra
.646 .718 .901 r
.49133 .11455 .49389 .11808 .4985 .11648 .49594 .11294 Metetra
.645 .717 .9 r
.49594 .11294 .4985 .11648 .50312 .11489 .50057 .11133 Metetra
.644 .716 .9 r
.50057 .11133 .50312 .11489 .50775 .11331 .5052 .10974 Metetra
.643 .715 .9 r
.5052 .10974 .50775 .11331 .51238 .11173 .50984 .10815 Metetra
.642 .714 .9 r
.50984 .10815 .51238 .11173 .51703 .11017 .51449 .10657 Metetra
.641 .713 .9 r
.51449 .10657 .51703 .11017 .52168 .10861 .51915 .105 Metetra
.64 .712 .9 r
.51915 .105 .52168 .10861 .52634 .10707 .52382 .10343 Metetra
.639 .711 .899 r
.52382 .10343 .52634 .10707 .53102 .10553 .52849 .10188 Metetra
.637 .709 .899 r
.52849 .10188 .53102 .10553 .5357 .10401 .53318 .10034 Metetra
.636 .708 .899 r
.53318 .10034 .5357 .10401 .54038 .10251 .53787 .09882 Metetra
.634 .706 .898 r
.53787 .09882 .54038 .10251 .54508 .10101 .54257 .09731 Metetra
.633 .705 .898 r
.54257 .09731 .54508 .10101 .54979 .09954 .54728 .09581 Metetra
.631 .703 .897 r
.54728 .09581 .54979 .09954 .55451 .09808 .552 .09433 Metetra
.629 .7 .897 r
.552 .09433 .55451 .09808 .55923 .09665 .55673 .09287 Metetra
.627 .698 .896 r
.55673 .09287 .55923 .09665 .56397 .09524 .56147 .09143 Metetra
.624 .696 .896 r
.56147 .09143 .56397 .09524 .56871 .09385 .56622 .09002 Metetra
.621 .693 .895 r
.56622 .09002 .56871 .09385 .57347 .0925 .57098 .08863 Metetra
.618 .69 .894 r
.57098 .08863 .57347 .0925 .57823 .09117 .57575 .08727 Metetra
.615 .686 .893 r
.57575 .08727 .57823 .09117 .58345 .11222 .58053 .08594 Metetra
0 0 .455 r
.58053 .08594 .58345 .11222 .58829 .11162 .58578 .10705 Metetra
.548 .615 .871 r
.58578 .10705 .58829 .11162 .59314 .11112 .59064 .10646 Metetra
.539 .605 .868 r
.59064 .10646 .59314 .11112 .59801 .11074 .59551 .10597 Metetra
.529 .594 .864 r
.59551 .10597 .59801 .11074 .6029 .11049 .60039 .10559 Metetra
.518 .582 .859 r
.60039 .10559 .6029 .11049 .6078 .11039 .60529 .10535 Metetra
.504 .567 .853 r
.60529 .10535 .6078 .11039 .61273 .11047 .61021 .10526 Metetra
.489 .551 .846 r
.61021 .10526 .61273 .11047 .61767 .11076 .61515 .10536 Metetra
.472 .532 .837 r
.61515 .10536 .61767 .11076 .62264 .11131 .62011 .10568 Metetra
.452 .51 .827 r
.62011 .10568 .62264 .11131 .62764 .11217 .6251 .10626 Metetra
.428 .484 .815 r
.6251 .10626 .62764 .11217 .63267 .11342 .63012 .10716 Metetra
.401 .454 .8 r
.63012 .10716 .63267 .11342 .63773 .11514 .63517 .10845 Metetra
.368 .418 .781 r
.63517 .10845 .63773 .11514 .64284 .11748 .64025 .11024 Metetra
.33 .376 .758 r
.64025 .11024 .64284 .11748 .64801 .12063 .64539 .11267 Metetra
.285 .326 .729 r
.64539 .11267 .64801 .12063 .65326 .1249 .65059 .11595 Metetra
.232 .268 .694 r
.65059 .11595 .65326 .1249 .6586 .13076 .65586 .12039 Metetra
.17 .2 .65 r
.65586 .12039 .6586 .13076 .6641 .13903 .66124 .12652 Metetra
.1 .123 .596 r
.66124 .12652 .6641 .13903 .66983 .15126 .66679 .13522 Metetra
.021 .037 .534 r
.66679 .13522 .66983 .15126 .676 .17093 .67259 .14821 Metetra
0 0 .463 r
.67259 .14821 .676 .17093 .68316 .20793 .67888 .16945 Metetra
0 0 .387 r
.67888 .16945 .68316 .20793 .69162 .26651 .68633 .21086 Metetra
0 0 .412 r
.68633 .21086 .69162 .26651 .6833 .01991 .69444 .26128 Metetra
0 0 .331 r
.69444 .26128 .6833 .01991 .6882 .01801 .68588 .01449 Metetra
.664 .741 .907 r
.68588 .01449 .6882 .01801 .6931 .01611 .69079 .01258 Metetra
.664 .741 .907 r
.69079 .01258 .6931 .01611 .69802 .0142 .69571 .01067 Metetra
.664 .741 .907 r
.04313 .26072 .04611 .26349 .04997 .26199 .047 .25921 Metetra
.938 .68 .52 r
.047 .25921 .04997 .26199 .05384 .26048 .01481 .49206 Metetra
.386 .157 .439 r
.01481 .49206 .05384 .26048 .0222 .49327 .0252 .44973 Metetra
.78 .534 .563 r
.0252 .44973 .0222 .49327 .03381 .44218 .0363 .40207 Metetra
.714 .477 .564 r
.0363 .40207 .03381 .44218 .04407 .39943 .04393 .37683 Metetra
.735 .511 .588 r
.04393 .37683 .04407 .39943 .0514 .37584 .05021 .36032 Metetra
.745 .536 .611 r
.05021 .36032 .0514 .37584 .05754 .36011 .05581 .34825 Metetra
.75 .557 .634 r
.05581 .34825 .05754 .36011 .06304 .34847 .061 .33879 Metetra
.753 .575 .655 r
.061 .33879 .06304 .34847 .06818 .33929 .06593 .33104 Metetra
.753 .59 .675 r
.06593 .33104 .06818 .33929 .07307 .33172 .07068 .32445 Metetra
.752 .604 .693 r
.07068 .32445 .07307 .33172 .07779 .32526 .0753 .31871 Metetra
.751 .617 .71 r
.0753 .31871 .07779 .32526 .0824 .31962 .07983 .3136 Metetra
.749 .628 .725 r
.07983 .3136 .0824 .31962 .08691 .31458 .08429 .30899 Metetra
.746 .637 .739 r
.08429 .30899 .08691 .31458 .09136 .31003 .08869 .30476 Metetra
.743 .646 .752 r
.08869 .30476 .09136 .31003 .09575 .30585 .09305 .30085 Metetra
.741 .654 .764 r
.09305 .30085 .09575 .30585 .1001 .30198 .09738 .2972 Metetra
.738 .66 .774 r
.09738 .2972 .1001 .30198 .10442 .29836 .10167 .29376 Metetra
.735 .667 .783 r
.10167 .29376 .10442 .29836 .10871 .29495 .10594 .2905 Metetra
.732 .672 .792 r
.10594 .2905 .10871 .29495 .11298 .29171 .1102 .2874 Metetra
.729 .677 .8 r
.1102 .2874 .11298 .29171 .11723 .28863 .11444 .28443 Metetra
.726 .681 .807 r
.11444 .28443 .11723 .28863 .12146 .28568 .11866 .28157 Metetra
.918 .705 .598 r
.11866 .28157 .12146 .28568 .12569 .28284 .12571 .25696 Metetra
.549 .353 .567 r
.12571 .25696 .12569 .28284 .1299 .28009 .12982 .25487 Metetra
.549 .354 .569 r
.12982 .25487 .1299 .28009 .13678 .25621 .13392 .25282 Metetra
.694 .715 .865 r
.13392 .25282 .13678 .25621 .14089 .25417 .13803 .2508 Metetra
.692 .717 .868 r
.13803 .2508 .14089 .25417 .145 .25216 .14214 .24881 Metetra
.69 .718 .87 r
.14214 .24881 .145 .25216 .14911 .25018 .14625 .24685 Metetra
.689 .719 .873 r
.14625 .24685 .14911 .25018 .15322 .24822 .15036 .24491 Metetra
.687 .72 .874 r
.15036 .24491 .15322 .24822 .15733 .24629 .15448 .24299 Metetra
.686 .721 .876 r
.15448 .24299 .15733 .24629 .16145 .24437 .15859 .24109 Metetra
.685 .722 .878 r
.15859 .24109 .16145 .24437 .16557 .24248 .16271 .23921 Metetra
.684 .723 .879 r
.16271 .23921 .16557 .24248 .16969 .2406 .16684 .23734 Metetra
.682 .724 .881 r
.16684 .23734 .16969 .2406 .17382 .23874 .17097 .23549 Metetra
.681 .724 .882 r
.17097 .23549 .17382 .23874 .17795 .2369 .1751 .23365 Metetra
.68 .725 .883 r
.1751 .23365 .17795 .2369 .18208 .23506 .17924 .23183 Metetra
.679 .725 .884 r
.17924 .23183 .18208 .23506 .18622 .23324 .18338 .23001 Metetra
.679 .726 .885 r
.18338 .23001 .18622 .23324 .19037 .23143 .18753 .2282 Metetra
.678 .726 .886 r
.18753 .2282 .19037 .23143 .19451 .22962 .19168 .2264 Metetra
.677 .727 .887 r
.19168 .2264 .19451 .22962 .19867 .22783 .19583 .22461 Metetra
.676 .727 .888 r
.19583 .22461 .19867 .22783 .20283 .22605 .19999 .22283 Metetra
.676 .727 .889 r
.19999 .22283 .20283 .22605 .20699 .22427 .20416 .22106 Metetra
.675 .728 .89 r
.20416 .22106 .20699 .22427 .21116 .2225 .20833 .21929 Metetra
.674 .728 .89 r
.20833 .21929 .21116 .2225 .21533 .22074 .21251 .21753 Metetra
.674 .728 .891 r
.21251 .21753 .21533 .22074 .21951 .21898 .21669 .21577 Metetra
.673 .729 .892 r
.21669 .21577 .21951 .21898 .22369 .21723 .22087 .21402 Metetra
.672 .729 .892 r
.22087 .21402 .22369 .21723 .22788 .21548 .22507 .21227 Metetra
.672 .729 .893 r
.22507 .21227 .22788 .21548 .23208 .21374 .22927 .21053 Metetra
.671 .729 .893 r
.22927 .21053 .23208 .21374 .23628 .212 .23347 .20879 Metetra
.671 .729 .894 r
.23347 .20879 .23628 .212 .24049 .21027 .23768 .20706 Metetra
.67 .729 .894 r
.23768 .20706 .24049 .21027 .2447 .20854 .2419 .20533 Metetra
.67 .73 .894 r
.2419 .20533 .2447 .20854 .24892 .20681 .24612 .2036 Metetra
.669 .73 .895 r
.24612 .2036 .24892 .20681 .25314 .20509 .25035 .20188 Metetra
.669 .73 .895 r
.25035 .20188 .25314 .20509 .25737 .20337 .25458 .20016 Metetra
.669 .73 .896 r
.25458 .20016 .25737 .20337 .26161 .20165 .25882 .19844 Metetra
.668 .73 .896 r
.25882 .19844 .26161 .20165 .26585 .19993 .26307 .19672 Metetra
.668 .73 .896 r
.26307 .19672 .26585 .19993 .2701 .19822 .26732 .19501 Metetra
.667 .73 .897 r
.26732 .19501 .2701 .19822 .27436 .19651 .27158 .19329 Metetra
.667 .73 .897 r
.27158 .19329 .27436 .19651 .27862 .19481 .27585 .19158 Metetra
.667 .73 .897 r
.27585 .19158 .27862 .19481 .28289 .1931 .28012 .18987 Metetra
.666 .73 .897 r
.28012 .18987 .28289 .1931 .28716 .1914 .2844 .18817 Metetra
.666 .73 .898 r
.2844 .18817 .28716 .1914 .29144 .18969 .28868 .18646 Metetra
.666 .73 .898 r
.28868 .18646 .29144 .18969 .29573 .18799 .29297 .18476 Metetra
.665 .73 .898 r
.29297 .18476 .29573 .18799 .30002 .18629 .29727 .18306 Metetra
.665 .73 .898 r
.29727 .18306 .30002 .18629 .30432 .1846 .30157 .18135 Metetra
.665 .73 .899 r
.30157 .18135 .30432 .1846 .30863 .1829 .30588 .17966 Metetra
.664 .73 .899 r
.30588 .17966 .30863 .1829 .31294 .18121 .3102 .17796 Metetra
.664 .73 .899 r
.3102 .17796 .31294 .18121 .31726 .17951 .31453 .17626 Metetra
.664 .73 .899 r
.31453 .17626 .31726 .17951 .32159 .17782 .31886 .17456 Metetra
.663 .73 .899 r
.31886 .17456 .32159 .17782 .32592 .17613 .32319 .17287 Metetra
.663 .73 .9 r
.32319 .17287 .32592 .17613 .33026 .17444 .32754 .17117 Metetra
.663 .73 .9 r
.32754 .17117 .33026 .17444 .33461 .17275 .33189 .16948 Metetra
.662 .73 .9 r
.33189 .16948 .33461 .17275 .33897 .17106 .33625 .16779 Metetra
.662 .73 .9 r
.33625 .16779 .33897 .17106 .34333 .16938 .34061 .16609 Metetra
.662 .73 .9 r
.34061 .16609 .34333 .16938 .34769 .16769 .34499 .1644 Metetra
.661 .73 .9 r
.34499 .1644 .34769 .16769 .35207 .166 .34937 .16271 Metetra
.661 .73 .9 r
.34937 .16271 .35207 .166 .35645 .16432 .35375 .16102 Metetra
.661 .729 .9 r
.35375 .16102 .35645 .16432 .36084 .16264 .35814 .15933 Metetra
.66 .729 .901 r
.35814 .15933 .36084 .16264 .36524 .16096 .36254 .15765 Metetra
.66 .729 .901 r
.36254 .15765 .36524 .16096 .36964 .15927 .36695 .15596 Metetra
.66 .729 .901 r
.36695 .15596 .36964 .15927 .37405 .15759 .37137 .15427 Metetra
.659 .729 .901 r
.37137 .15427 .37405 .15759 .37847 .15592 .37579 .15259 Metetra
.659 .729 .901 r
.37579 .15259 .37847 .15592 .38289 .15424 .38022 .15091 Metetra
.659 .729 .901 r
.38022 .15091 .38289 .15424 .38732 .15256 .38465 .14922 Metetra
.658 .728 .901 r
.38465 .14922 .38732 .15256 .39176 .15089 .3891 .14754 Metetra
.658 .728 .901 r
.3891 .14754 .39176 .15089 .39621 .14921 .39355 .14586 Metetra
.658 .728 .901 r
.39355 .14586 .39621 .14921 .40066 .14754 .398 .14418 Metetra
.657 .728 .901 r
.398 .14418 .40066 .14754 .40512 .14587 .40247 .1425 Metetra
.657 .727 .901 r
.40247 .1425 .40512 .14587 .40959 .1442 .40694 .14082 Metetra
.656 .727 .901 r
.40694 .14082 .40959 .1442 .41407 .14253 .41142 .13915 Metetra
.656 .727 .901 r
.41142 .13915 .41407 .14253 .41855 .14086 .41591 .13747 Metetra
.656 .727 .901 r
.41591 .13747 .41855 .14086 .42304 .13919 .42041 .1358 Metetra
.655 .726 .901 r
.42041 .1358 .42304 .13919 .42754 .13753 .42491 .13413 Metetra
.655 .726 .901 r
.42491 .13413 .42754 .13753 .43205 .13587 .42942 .13246 Metetra
.654 .726 .901 r
.42942 .13246 .43205 .13587 .43656 .13421 .43394 .13079 Metetra
.654 .725 .901 r
.43394 .13079 .43656 .13421 .44108 .13255 .43846 .12913 Metetra
.653 .725 .901 r
.43846 .12913 .44108 .13255 .44561 .1309 .443 .12747 Metetra
.653 .724 .901 r
.443 .12747 .44561 .1309 .45014 .12925 .44754 .1258 Metetra
.652 .724 .901 r
.44754 .1258 .45014 .12925 .45469 .1276 .45209 .12415 Metetra
.652 .724 .901 r
.45209 .12415 .45469 .1276 .45924 .12595 .45664 .12249 Metetra
.651 .723 .901 r
.45664 .12249 .45924 .12595 .4638 .12431 .46121 .12084 Metetra
.651 .723 .901 r
.46121 .12084 .4638 .12431 .46837 .12267 .46578 .11919 Metetra
.65 .722 .901 r
.46578 .11919 .46837 .12267 .47294 .12104 .47036 .11755 Metetra
.649 .721 .901 r
.47036 .11755 .47294 .12104 .47753 .11941 .47495 .11591 Metetra
.649 .721 .901 r
.47495 .11591 .47753 .11941 .48212 .11778 .47954 .11427 Metetra
.648 .72 .901 r
.47954 .11427 .48212 .11778 .48672 .11616 .48415 .11264 Metetra
.647 .72 .901 r
.48415 .11264 .48672 .11616 .49133 .11455 .48876 .11101 Metetra
.647 .719 .901 r
.48876 .11101 .49133 .11455 .49594 .11294 .49338 .10939 Metetra
.646 .718 .901 r
.49338 .10939 .49594 .11294 .50057 .11133 .49801 .10777 Metetra
.645 .717 .901 r
.49801 .10777 .50057 .11133 .5052 .10974 .50265 .10616 Metetra
.644 .716 .9 r
.50265 .10616 .5052 .10974 .50984 .10815 .50729 .10456 Metetra
.643 .715 .9 r
.50729 .10456 .50984 .10815 .51449 .10657 .51195 .10297 Metetra
.642 .714 .9 r
.51195 .10297 .51449 .10657 .51915 .105 .51661 .10138 Metetra
.641 .713 .9 r
.51661 .10138 .51915 .105 .52382 .10343 .52128 .0998 Metetra
.64 .712 .9 r
.52128 .0998 .52382 .10343 .52849 .10188 .52596 .09824 Metetra
.638 .711 .899 r
.52596 .09824 .52849 .10188 .53318 .10034 .53065 .09668 Metetra
.637 .709 .899 r
.53065 .09668 .53318 .10034 .53787 .09882 .53535 .09513 Metetra
.636 .708 .899 r
.53535 .09513 .53787 .09882 .54257 .09731 .54005 .0936 Metetra
.634 .706 .898 r
.54005 .0936 .54257 .09731 .54728 .09581 .54477 .09208 Metetra
.632 .704 .898 r
.54477 .09208 .54728 .09581 .552 .09433 .54949 .09058 Metetra
.63 .702 .897 r
.54949 .09058 .552 .09433 .55673 .09287 .55423 .0891 Metetra
.628 .7 .897 r
.55423 .0891 .55673 .09287 .56147 .09143 .55897 .08763 Metetra
.626 .698 .896 r
.55897 .08763 .56147 .09143 .56622 .09002 .56372 .08619 Metetra
.624 .695 .896 r
.56372 .08619 .56622 .09002 .57098 .08863 .56849 .08477 Metetra
.621 .692 .895 r
.56849 .08477 .57098 .08863 .57575 .08727 .57326 .08337 Metetra
.618 .689 .894 r
.57326 .08337 .57575 .08727 .58053 .08594 .57804 .08201 Metetra
.615 .686 .893 r
.57804 .08201 .58053 .08594 .58578 .10705 .58284 .08068 Metetra
.531 .34 .567 r
.58284 .08068 .58578 .10705 .59064 .10646 .58764 .07939 Metetra
0 0 .452 r
.58764 .07939 .59064 .10646 .59551 .10597 .593 .10127 Metetra
.538 .604 .867 r
.593 .10127 .59551 .10597 .60039 .10559 .59788 .10078 Metetra
.528 .593 .863 r
.59788 .10078 .60039 .10559 .60529 .10535 .60278 .10041 Metetra
.516 .58 .858 r
.60278 .10041 .60529 .10535 .61021 .10526 .6077 .10018 Metetra
.503 .565 .852 r
.6077 .10018 .61021 .10526 .61515 .10536 .61263 .10011 Metetra
.487 .548 .845 r
.61263 .10011 .61515 .10536 .62011 .10568 .61759 .10023 Metetra
.47 .529 .836 r
.61759 .10023 .62011 .10568 .6251 .10626 .62257 .10057 Metetra
.449 .506 .826 r
.62257 .10057 .6251 .10626 .63012 .10716 .62758 .10118 Metetra
.425 .48 .813 r
.62758 .10118 .63012 .10716 .63517 .10845 .63261 .10212 Metetra
.397 .449 .797 r
.63261 .10212 .63517 .10845 .64025 .11024 .63768 .10346 Metetra
.364 .413 .778 r
.63768 .10346 .64025 .11024 .64539 .11267 .64279 .10532 Metetra
.325 .37 .754 r
.64279 .10532 .64539 .11267 .65059 .11595 .64795 .10784 Metetra
.279 .319 .725 r
.64795 .10784 .65059 .11595 .65586 .12039 .65317 .11124 Metetra
.225 .26 .688 r
.65317 .11124 .65586 .12039 .66124 .12652 .65848 .11587 Metetra
.163 .191 .643 r
.65848 .11587 .66124 .12652 .66679 .13522 .6639 .12227 Metetra
.091 .112 .589 r
.6639 .12227 .66679 .13522 .67259 .14821 .66949 .13142 Metetra
.012 .025 .525 r
.66949 .13142 .67259 .14821 .67888 .16945 .67537 .14523 Metetra
0 0 .454 r
.67537 .14523 .67888 .16945 .68633 .21086 .68179 .1682 Metetra
0 0 .377 r
.68179 .1682 .68633 .21086 .69444 .26128 .68959 .21481 Metetra
0 0 .426 r
.68959 .21481 .69444 .26128 .68588 .01449 .69727 .25603 Metetra
0 0 .331 r
.69727 .25603 .68588 .01449 .69079 .01258 .68847 .00904 Metetra
.664 .741 .907 r
.68847 .00904 .69079 .01258 .69571 .01067 .69339 .00712 Metetra
.938 .68 .521 r
.04015 .25793 .04313 .26072 .047 .25921 .00741 .49084 Metetra
.415 .181 .448 r
.00741 .49084 .047 .25921 .01481 .49206 .01634 .45848 Metetra
.82 .574 .567 r
.01634 .45848 .01481 .49206 .0252 .44973 .02846 .40498 Metetra
.709 .47 .56 r
.02846 .40498 .0252 .44973 .0363 .40207 .03643 .37791 Metetra
.732 .506 .585 r
.03643 .37791 .0363 .40207 .04393 .37683 .04287 .36056 Metetra
.743 .532 .608 r
.04287 .36056 .04393 .37683 .05021 .36032 .04855 .34804 Metetra
.749 .554 .631 r
.04855 .34804 .05021 .36032 .05581 .34825 .0538 .3383 Metetra
.752 .572 .652 r
.0538 .3383 .05581 .34825 .061 .33879 .05877 .33036 Metetra
.753 .588 .672 r
.05877 .33036 .061 .33879 .06593 .33104 .06355 .32364 Metetra
.752 .602 .691 r
.06355 .32364 .06593 .33104 .07068 .32445 .0682 .3178 Metetra
.751 .615 .708 r
.0682 .3178 .07068 .32445 .0753 .31871 .07274 .31262 Metetra
.749 .626 .723 r
.07274 .31262 .0753 .31871 .07983 .3136 .07722 .30794 Metetra
.746 .636 .737 r
.07722 .30794 .07983 .3136 .08429 .30899 .08163 .30367 Metetra
.744 .645 .75 r
.08163 .30367 .08429 .30899 .08869 .30476 .086 .29972 Metetra
.741 .652 .762 r
.086 .29972 .08869 .30476 .09305 .30085 .09033 .29604 Metetra
.738 .659 .773 r
.09033 .29604 .09305 .30085 .09738 .2972 .09463 .29257 Metetra
.735 .666 .782 r
.09463 .29257 .09738 .2972 .10167 .29376 .0989 .28929 Metetra
.732 .671 .791 r
.0989 .28929 .10167 .29376 .10594 .2905 .10316 .28617 Metetra
.729 .676 .799 r
.10316 .28617 .10594 .2905 .1102 .2874 .1074 .28318 Metetra
.726 .68 .806 r
.1074 .28318 .1102 .2874 .11444 .28443 .11163 .2803 Metetra
.918 .704 .599 r
.11163 .2803 .11444 .28443 .11866 .28157 .11874 .25562 Metetra
.548 .352 .566 r
.11874 .25562 .11866 .28157 .12571 .25696 .12284 .25352 Metetra
.696 .714 .862 r
.12284 .25352 .12571 .25696 .12982 .25487 .12695 .25146 Metetra
.694 .715 .865 r
.12695 .25146 .12982 .25487 .13392 .25282 .13105 .24944 Metetra
.692 .717 .868 r
.13105 .24944 .13392 .25282 .13803 .2508 .13516 .24744 Metetra
.691 .718 .87 r
.13516 .24744 .13803 .2508 .14214 .24881 .13927 .24548 Metetra
.689 .719 .872 r
.13927 .24548 .14214 .24881 .14625 .24685 .14338 .24353 Metetra
.688 .72 .874 r
.14338 .24353 .14625 .24685 .15036 .24491 .14749 .24161 Metetra
.686 .721 .876 r
.14749 .24161 .15036 .24491 .15448 .24299 .15161 .2397 Metetra
.685 .722 .878 r
.15161 .2397 .15448 .24299 .15859 .24109 .15573 .23782 Metetra
.684 .723 .879 r
.15573 .23782 .15859 .24109 .16271 .23921 .15985 .23594 Metetra
.683 .723 .881 r
.15985 .23594 .16271 .23921 .16684 .23734 .16398 .23409 Metetra
.682 .724 .882 r
.16398 .23409 .16684 .23734 .17097 .23549 .16811 .23224 Metetra
.681 .725 .883 r
.16811 .23224 .17097 .23549 .1751 .23365 .17224 .23041 Metetra
.68 .725 .884 r
.17224 .23041 .1751 .23365 .17924 .23183 .17638 .22859 Metetra
.679 .726 .885 r
.17638 .22859 .17924 .23183 .18338 .23001 .18053 .22678 Metetra
.678 .726 .886 r
.18053 .22678 .18338 .23001 .18753 .2282 .18467 .22498 Metetra
.677 .727 .887 r
.18467 .22498 .18753 .2282 .19168 .2264 .18883 .22318 Metetra
.676 .727 .888 r
.18883 .22318 .19168 .2264 .19583 .22461 .19299 .2214 Metetra
.676 .727 .889 r
.19299 .2214 .19583 .22461 .19999 .22283 .19715 .21962 Metetra
.675 .728 .889 r
.19715 .21962 .19999 .22283 .20416 .22106 .20132 .21785 Metetra
.674 .728 .89 r
.20132 .21785 .20416 .22106 .20833 .21929 .20549 .21608 Metetra
.674 .728 .891 r
.20549 .21608 .20833 .21929 .21251 .21753 .20967 .21432 Metetra
.673 .729 .891 r
.20967 .21432 .21251 .21753 .21669 .21577 .21386 .21256 Metetra
.673 .729 .892 r
.21386 .21256 .21669 .21577 .22087 .21402 .21805 .21081 Metetra
.672 .729 .893 r
.21805 .21081 .22087 .21402 .22507 .21227 .22224 .20907 Metetra
.672 .729 .893 r
.22224 .20907 .22507 .21227 .22927 .21053 .22645 .20732 Metetra
.671 .729 .894 r
.22645 .20732 .22927 .21053 .23347 .20879 .23065 .20558 Metetra
.671 .73 .894 r
.23065 .20558 .23347 .20879 .23768 .20706 .23487 .20385 Metetra
.67 .73 .894 r
.23487 .20385 .23768 .20706 .2419 .20533 .23909 .20212 Metetra
.67 .73 .895 r
.23909 .20212 .2419 .20533 .24612 .2036 .24331 .20039 Metetra
.669 .73 .895 r
.24331 .20039 .24612 .2036 .25035 .20188 .24754 .19866 Metetra
.669 .73 .896 r
.24754 .19866 .25035 .20188 .25458 .20016 .25178 .19694 Metetra
.668 .73 .896 r
.25178 .19694 .25458 .20016 .25882 .19844 .25603 .19522 Metetra
.668 .73 .896 r
.25603 .19522 .25882 .19844 .26307 .19672 .26028 .1935 Metetra
.668 .73 .897 r
.26028 .1935 .26307 .19672 .26732 .19501 .26453 .19178 Metetra
.667 .73 .897 r
.26453 .19178 .26732 .19501 .27158 .19329 .2688 .19007 Metetra
.667 .73 .897 r
.2688 .19007 .27158 .19329 .27585 .19158 .27306 .18835 Metetra
.666 .73 .897 r
.27306 .18835 .27585 .19158 .28012 .18987 .27734 .18664 Metetra
.666 .73 .898 r
.27734 .18664 .28012 .18987 .2844 .18817 .28162 .18493 Metetra
.666 .73 .898 r
.28162 .18493 .2844 .18817 .28868 .18646 .28591 .18322 Metetra
.665 .731 .898 r
.28591 .18322 .28868 .18646 .29297 .18476 .29021 .18152 Metetra
.665 .731 .898 r
.29021 .18152 .29297 .18476 .29727 .18306 .29451 .17981 Metetra
.665 .731 .899 r
.29451 .17981 .29727 .18306 .30157 .18135 .29882 .17811 Metetra
.664 .73 .899 r
.29882 .17811 .30157 .18135 .30588 .17966 .30313 .1764 Metetra
.664 .73 .899 r
.30313 .1764 .30588 .17966 .3102 .17796 .30745 .1747 Metetra
.664 .73 .899 r
.30745 .1747 .3102 .17796 .31453 .17626 .31178 .173 Metetra
.663 .73 .899 r
.31178 .173 .31453 .17626 .31886 .17456 .31612 .1713 Metetra
.663 .73 .9 r
.31612 .1713 .31886 .17456 .32319 .17287 .32046 .1696 Metetra
.663 .73 .9 r
.32046 .1696 .32319 .17287 .32754 .17117 .32481 .1679 Metetra
.663 .73 .9 r
.32481 .1679 .32754 .17117 .33189 .16948 .32916 .1662 Metetra
.662 .73 .9 r
.32916 .1662 .33189 .16948 .33625 .16779 .33352 .1645 Metetra
.662 .73 .9 r
.33352 .1645 .33625 .16779 .34061 .16609 .33789 .16281 Metetra
.662 .73 .9 r
.33789 .16281 .34061 .16609 .34499 .1644 .34227 .16111 Metetra
.661 .73 .9 r
.34227 .16111 .34499 .1644 .34937 .16271 .34665 .15941 Metetra
.661 .73 .9 r
.34665 .15941 .34937 .16271 .35375 .16102 .35104 .15772 Metetra
.661 .73 .901 r
.35104 .15772 .35375 .16102 .35814 .15933 .35544 .15603 Metetra
.66 .73 .901 r
.35544 .15603 .35814 .15933 .36254 .15765 .35984 .15433 Metetra
.66 .729 .901 r
.35984 .15433 .36254 .15765 .36695 .15596 .36426 .15264 Metetra
.66 .729 .901 r
.36426 .15264 .36695 .15596 .37137 .15427 .36867 .15095 Metetra
.659 .729 .901 r
.36867 .15095 .37137 .15427 .37579 .15259 .3731 .14926 Metetra
.659 .729 .901 r
.3731 .14926 .37579 .15259 .38022 .15091 .37753 .14757 Metetra
.659 .729 .901 r
.37753 .14757 .38022 .15091 .38465 .14922 .38197 .14588 Metetra
.658 .729 .901 r
.38197 .14588 .38465 .14922 .3891 .14754 .38642 .14419 Metetra
.658 .728 .901 r
.38642 .14419 .3891 .14754 .39355 .14586 .39088 .1425 Metetra
.658 .728 .901 r
.39088 .1425 .39355 .14586 .398 .14418 .39534 .14082 Metetra
.657 .728 .901 r
.39534 .14082 .398 .14418 .40247 .1425 .39981 .13913 Metetra
.657 .728 .901 r
.39981 .13913 .40247 .1425 .40694 .14082 .40429 .13745 Metetra
.657 .727 .901 r
.40429 .13745 .40694 .14082 .41142 .13915 .40877 .13576 Metetra
.656 .727 .901 r
.40877 .13576 .41142 .13915 .41591 .13747 .41326 .13408 Metetra
.656 .727 .901 r
.41326 .13408 .41591 .13747 .42041 .1358 .41776 .1324 Metetra
.655 .727 .901 r
.41776 .1324 .42041 .1358 .42491 .13413 .42227 .13072 Metetra
.655 .726 .902 r
.42227 .13072 .42491 .13413 .42942 .13246 .42678 .12905 Metetra
.655 .726 .902 r
.42678 .12905 .42942 .13246 .43394 .13079 .43131 .12737 Metetra
.654 .726 .902 r
.43131 .12737 .43394 .13079 .43846 .12913 .43584 .1257 Metetra
.654 .725 .902 r
.43584 .1257 .43846 .12913 .443 .12747 .44037 .12403 Metetra
.653 .725 .902 r
.44037 .12403 .443 .12747 .44754 .1258 .44492 .12236 Metetra
.653 .724 .901 r
.44492 .12236 .44754 .1258 .45209 .12415 .44947 .12069 Metetra
.652 .724 .901 r
.44947 .12069 .45209 .12415 .45664 .12249 .45403 .11903 Metetra
.652 .724 .901 r
.45403 .11903 .45664 .12249 .46121 .12084 .4586 .11736 Metetra
.651 .723 .901 r
.4586 .11736 .46121 .12084 .46578 .11919 .46318 .11571 Metetra
.651 .723 .901 r
.46318 .11571 .46578 .11919 .47036 .11755 .46776 .11405 Metetra
.65 .722 .901 r
.46776 .11405 .47036 .11755 .47495 .11591 .47236 .1124 Metetra
.649 .721 .901 r
.47236 .1124 .47495 .11591 .47954 .11427 .47696 .11075 Metetra
.649 .721 .901 r
.47696 .11075 .47954 .11427 .48415 .11264 .48157 .10911 Metetra
.648 .72 .901 r
.48157 .10911 .48415 .11264 .48876 .11101 .48618 .10747 Metetra
.647 .719 .901 r
.48618 .10747 .48876 .11101 .49338 .10939 .49081 .10584 Metetra
.646 .719 .901 r
.49081 .10584 .49338 .10939 .49801 .10777 .49544 .10421 Metetra
.646 .718 .901 r
.49544 .10421 .49801 .10777 .50265 .10616 .50009 .10259 Metetra
.645 .717 .901 r
.50009 .10259 .50265 .10616 .50729 .10456 .50474 .10097 Metetra
.644 .716 .9 r
.50474 .10097 .50729 .10456 .51195 .10297 .50939 .09936 Metetra
.643 .715 .9 r
.50939 .09936 .51195 .10297 .51661 .10138 .51406 .09776 Metetra
.642 .714 .9 r
.51406 .09776 .51661 .10138 .52128 .0998 .51874 .09617 Metetra
.641 .713 .9 r
.51874 .09617 .52128 .0998 .52596 .09824 .52342 .09459 Metetra
.639 .712 .9 r
.52342 .09459 .52596 .09824 .53065 .09668 .52811 .09301 Metetra
.638 .71 .899 r
.52811 .09301 .53065 .09668 .53535 .09513 .53282 .09145 Metetra
.637 .709 .899 r
.53282 .09145 .53535 .09513 .54005 .0936 .53753 .0899 Metetra
.635 .708 .899 r
.53753 .0899 .54005 .0936 .54477 .09208 .54225 .08836 Metetra
.634 .706 .898 r
.54225 .08836 .54477 .09208 .54949 .09058 .54698 .08684 Metetra
.632 .704 .898 r
.54698 .08684 .54949 .09058 .55423 .0891 .55171 .08533 Metetra
.63 .702 .897 r
.55171 .08533 .55423 .0891 .55897 .08763 .55646 .08384 Metetra
.628 .7 .897 r
.55646 .08384 .55897 .08763 .56372 .08619 .56122 .08237 Metetra
.626 .697 .896 r
.56122 .08237 .56372 .08619 .56849 .08477 .56599 .08092 Metetra
.623 .695 .896 r
.56599 .08092 .56849 .08477 .57326 .08337 .57076 .07949 Metetra
.621 .692 .895 r
.57076 .07949 .57326 .08337 .57804 .08201 .57555 .0781 Metetra
.618 .689 .894 r
.57555 .0781 .57804 .08201 .58284 .08068 .58035 .07673 Metetra
.614 .685 .893 r
.58035 .07673 .58284 .08068 .58764 .07939 .58516 .07539 Metetra
.61 .681 .892 r
.58516 .07539 .58764 .07939 .593 .10127 .58997 .0741 Metetra
0 0 .452 r
.58997 .0741 .593 .10127 .59788 .10078 .59536 .09605 Metetra
.537 .602 .867 r
.59536 .09605 .59788 .10078 .60278 .10041 .60026 .09557 Metetra
.526 .591 .862 r
.60026 .09557 .60278 .10041 .6077 .10018 .60518 .09521 Metetra
.515 .578 .857 r
.60518 .09521 .6077 .10018 .61263 .10011 .61011 .09499 Metetra
.501 .563 .851 r
.61011 .09499 .61263 .10011 .61759 .10023 .61507 .09493 Metetra
.485 .546 .843 r
.61507 .09493 .61759 .10023 .62257 .10057 .62004 .09507 Metetra
.467 .526 .835 r
.62004 .09507 .62257 .10057 .62758 .10118 .62504 .09543 Metetra
.447 .503 .824 r
.62504 .09543 .62758 .10118 .63261 .10212 .63006 .09607 Metetra
.422 .476 .811 r
.63006 .09607 .63261 .10212 .63768 .10346 .63512 .09705 Metetra
.394 .445 .795 r
.63512 .09705 .63768 .10346 .64279 .10532 .64021 .09844 Metetra
.36 .408 .775 r
.64021 .09844 .64279 .10532 .64795 .10784 .64534 .10037 Metetra
.32 .364 .751 r
.64534 .10037 .64795 .10784 .65317 .11124 .65052 .10298 Metetra
.273 .312 .72 r
.65052 .10298 .65317 .11124 .65848 .11587 .65577 .10651 Metetra
.219 .251 .682 r
.65577 .10651 .65848 .11587 .6639 .12227 .66111 .11133 Metetra
.155 .181 .636 r
.66111 .11133 .6639 .12227 .66949 .13142 .66657 .11802 Metetra
.083 .102 .581 r
.66657 .11802 .66949 .13142 .67537 .14523 .67221 .12763 Metetra
.003 .014 .516 r
.67221 .12763 .67537 .14523 .68179 .1682 .67817 .14231 Metetra
0 0 .444 r
.67817 .14231 .68179 .1682 .68959 .21481 .68474 .1672 Metetra
0 0 .368 r
.68474 .1672 .68959 .21481 .69727 .25603 .69296 .21999 Metetra
0 0 .449 r
.69296 .21999 .69727 .25603 .68847 .00904 .70012 .25075 Metetra
0 0 .331 r
.70012 .25075 .68847 .00904 .69339 .00712 .69107 .00357 Metetra
.445 .207 .457 r
0 .48963 .04015 .25793 .00741 .49084 .0072 .4687 Metetra
.865 .621 .568 r
.0072 .4687 .00741 .49084 .01634 .45848 .02055 .40817 Metetra
.704 .463 .557 r
.02055 .40817 .01634 .45848 .02846 .40498 .02889 .37908 Metetra
.73 .502 .582 r
.02889 .37908 .02846 .40498 .03643 .37791 .0355 .36085 Metetra
.742 .529 .605 r
.0355 .36085 .03643 .37791 .04287 .36056 .04128 .34784 Metetra
.748 .55 .628 r
.04128 .34784 .04287 .36056 .04855 .34804 .04659 .33781 Metetra
.751 .569 .649 r
.04659 .33781 .04855 .34804 .0538 .3383 .0516 .32968 Metetra
.752 .586 .669 r
.0516 .32968 .0538 .3383 .05877 .33036 .05641 .32282 Metetra
.752 .6 .688 r
.05641 .32282 .05877 .33036 .06355 .32364 .06108 .31688 Metetra
.751 .613 .705 r
.06108 .31688 .06355 .32364 .0682 .3178 .06565 .31163 Metetra
.749 .624 .721 r
.06565 .31163 .0682 .3178 .07274 .31262 .07013 .30689 Metetra
.746 .634 .736 r
.07013 .30689 .07274 .31262 .07722 .30794 .07455 .30258 Metetra
.744 .643 .749 r
.07455 .30258 .07722 .30794 .08163 .30367 .07893 .29859 Metetra
.741 .651 .76 r
.07893 .29859 .08163 .30367 .086 .29972 .08326 .29487 Metetra
.738 .658 .771 r
.08326 .29487 .086 .29972 .09033 .29604 .08757 .29138 Metetra
.735 .665 .781 r
.08757 .29138 .09033 .29604 .09463 .29257 .09185 .28807 Metetra
.732 .67 .79 r
.09185 .28807 .09463 .29257 .0989 .28929 .09611 .28493 Metetra
.729 .675 .798 r
.09611 .28493 .0989 .28929 .10316 .28617 .10036 .28192 Metetra
.726 .68 .805 r
.10036 .28192 .10316 .28617 .1074 .28318 .10459 .27903 Metetra
.917 .704 .599 r
.10459 .27903 .1074 .28318 .11163 .2803 .11175 .25428 Metetra
.548 .351 .566 r
.11175 .25428 .11163 .2803 .11874 .25562 .11586 .25217 Metetra
.696 .713 .862 r
.11586 .25217 .11874 .25562 .12284 .25352 .11996 .25011 Metetra
.694 .715 .865 r
.11996 .25011 .12284 .25352 .12695 .25146 .12407 .24808 Metetra
.693 .716 .867 r
.12407 .24808 .12695 .25146 .13105 .24944 .12817 .24608 Metetra
.691 .718 .87 r
.12817 .24608 .13105 .24944 .13516 .24744 .13228 .2441 Metetra
.689 .719 .872 r
.13228 .2441 .13516 .24744 .13927 .24548 .13639 .24215 Metetra
.688 .72 .874 r
.13639 .24215 .13927 .24548 .14338 .24353 .1405 .24022 Metetra
.686 .721 .876 r
.1405 .24022 .14338 .24353 .14749 .24161 .14461 .23831 Metetra
.685 .722 .877 r
.14461 .23831 .14749 .24161 .15161 .2397 .14873 .23642 Metetra
.684 .723 .879 r
.14873 .23642 .15161 .2397 .15573 .23782 .15285 .23454 Metetra
.683 .723 .88 r
.15285 .23454 .15573 .23782 .15985 .23594 .15698 .23268 Metetra
.682 .724 .882 r
.15698 .23268 .15985 .23594 .16398 .23409 .16111 .23083 Metetra
.681 .725 .883 r
.16111 .23083 .16398 .23409 .16811 .23224 .16524 .229 Metetra
.68 .725 .884 r
.16524 .229 .16811 .23224 .17224 .23041 .16938 .22717 Metetra
.679 .726 .885 r
.16938 .22717 .17224 .23041 .17638 .22859 .17352 .22536 Metetra
.678 .726 .886 r
.17352 .22536 .17638 .22859 .18053 .22678 .17766 .22355 Metetra
.677 .727 .887 r
.17766 .22355 .18053 .22678 .18467 .22498 .18182 .22175 Metetra
.677 .727 .888 r
.18182 .22175 .18467 .22498 .18883 .22318 .18597 .21996 Metetra
.676 .727 .889 r
.18597 .21996 .18883 .22318 .19299 .2214 .19013 .21818 Metetra
.675 .728 .889 r
.19013 .21818 .19299 .2214 .19715 .21962 .1943 .2164 Metetra
.675 .728 .89 r
.1943 .2164 .19715 .21962 .20132 .21785 .19847 .21463 Metetra
.674 .728 .891 r
.19847 .21463 .20132 .21785 .20549 .21608 .20265 .21286 Metetra
.673 .729 .891 r
.20265 .21286 .20549 .21608 .20967 .21432 .20683 .2111 Metetra
.673 .729 .892 r
.20683 .2111 .20967 .21432 .21386 .21256 .21102 .20935 Metetra
.672 .729 .892 r
.21102 .20935 .21386 .21256 .21805 .21081 .21521 .2076 Metetra
.672 .729 .893 r
.21521 .2076 .21805 .21081 .22224 .20907 .21941 .20585 Metetra
.671 .729 .893 r
.21941 .20585 .22224 .20907 .22645 .20732 .22362 .20411 Metetra
.671 .73 .894 r
.22362 .20411 .22645 .20732 .23065 .20558 .22783 .20237 Metetra
.67 .73 .894 r
.22783 .20237 .23065 .20558 .23487 .20385 .23205 .20063 Metetra
.67 .73 .895 r
.23205 .20063 .23487 .20385 .23909 .20212 .23627 .1989 Metetra
.669 .73 .895 r
.23627 .1989 .23909 .20212 .24331 .20039 .2405 .19717 Metetra
.669 .73 .896 r
.2405 .19717 .24331 .20039 .24754 .19866 .24473 .19544 Metetra
.669 .73 .896 r
.24473 .19544 .24754 .19866 .25178 .19694 .24898 .19372 Metetra
.668 .73 .896 r
.24898 .19372 .25178 .19694 .25603 .19522 .25322 .19199 Metetra
.668 .73 .897 r
.25322 .19199 .25603 .19522 .26028 .1935 .25748 .19027 Metetra
.667 .73 .897 r
.25748 .19027 .26028 .1935 .26453 .19178 .26174 .18855 Metetra
.667 .731 .897 r
.26174 .18855 .26453 .19178 .2688 .19007 .266 .18684 Metetra
.667 .731 .897 r
.266 .18684 .2688 .19007 .27306 .18835 .27028 .18512 Metetra
.666 .731 .898 r
.27028 .18512 .27306 .18835 .27734 .18664 .27456 .1834 Metetra
.666 .731 .898 r
.27456 .1834 .27734 .18664 .28162 .18493 .27884 .18169 Metetra
.666 .731 .898 r
.27884 .18169 .28162 .18493 .28591 .18322 .28313 .17998 Metetra
.665 .731 .898 r
.28313 .17998 .28591 .18322 .29021 .18152 .28743 .17827 Metetra
.665 .731 .899 r
.28743 .17827 .29021 .18152 .29451 .17981 .29174 .17656 Metetra
.665 .731 .899 r
.29174 .17656 .29451 .17981 .29882 .17811 .29605 .17485 Metetra
.664 .731 .899 r
.29605 .17485 .29882 .17811 .30313 .1764 .30037 .17314 Metetra
.664 .731 .899 r
.30037 .17314 .30313 .1764 .30745 .1747 .30469 .17144 Metetra
.664 .731 .899 r
.30469 .17144 .30745 .1747 .31178 .173 .30903 .16973 Metetra
.663 .731 .9 r
.30903 .16973 .31178 .173 .31612 .1713 .31337 .16802 Metetra
.663 .731 .9 r
.31337 .16802 .31612 .1713 .32046 .1696 .31771 .16632 Metetra
.663 .73 .9 r
.31771 .16632 .32046 .1696 .32481 .1679 .32206 .16462 Metetra
.663 .73 .9 r
.32206 .16462 .32481 .1679 .32916 .1662 .32642 .16291 Metetra
.662 .73 .9 r
.32642 .16291 .32916 .1662 .33352 .1645 .33079 .16121 Metetra
.662 .73 .9 r
.33079 .16121 .33352 .1645 .33789 .16281 .33516 .15951 Metetra
.662 .73 .9 r
.33516 .15951 .33789 .16281 .34227 .16111 .33954 .15781 Metetra
.661 .73 .9 r
.33954 .15781 .34227 .16111 .34665 .15941 .34393 .15611 Metetra
.661 .73 .901 r
.34393 .15611 .34665 .15941 .35104 .15772 .34833 .15441 Metetra
.661 .73 .901 r
.34833 .15441 .35104 .15772 .35544 .15603 .35273 .15271 Metetra
.66 .73 .901 r
.35273 .15271 .35544 .15603 .35984 .15433 .35714 .15101 Metetra
.66 .73 .901 r
.35714 .15101 .35984 .15433 .36426 .15264 .36155 .14931 Metetra
.66 .729 .901 r
.36155 .14931 .36426 .15264 .36867 .15095 .36597 .14761 Metetra
.659 .729 .901 r
.36597 .14761 .36867 .15095 .3731 .14926 .3704 .14592 Metetra
.659 .729 .901 r
.3704 .14592 .3731 .14926 .37753 .14757 .37484 .14422 Metetra
.659 .729 .901 r
.37484 .14422 .37753 .14757 .38197 .14588 .37929 .14253 Metetra
.659 .729 .901 r
.37929 .14253 .38197 .14588 .38642 .14419 .38374 .14083 Metetra
.658 .729 .901 r
.38374 .14083 .38642 .14419 .39088 .1425 .3882 .13914 Metetra
.658 .728 .901 r
.3882 .13914 .39088 .1425 .39534 .14082 .39267 .13744 Metetra
.657 .728 .901 r
.39267 .13744 .39534 .14082 .39981 .13913 .39714 .13575 Metetra
.657 .728 .901 r
.39714 .13575 .39981 .13913 .40429 .13745 .40162 .13406 Metetra
.657 .728 .902 r
.40162 .13406 .40429 .13745 .40877 .13576 .40611 .13237 Metetra
.656 .728 .902 r
.40611 .13237 .40877 .13576 .41326 .13408 .41061 .13068 Metetra
.656 .727 .902 r
.41061 .13068 .41326 .13408 .41776 .1324 .41511 .12899 Metetra
.656 .727 .902 r
.41511 .12899 .41776 .1324 .42227 .13072 .41962 .12731 Metetra
.655 .727 .902 r
.41962 .12731 .42227 .13072 .42678 .12905 .42414 .12562 Metetra
.655 .726 .902 r
.42414 .12562 .42678 .12905 .43131 .12737 .42867 .12394 Metetra
.654 .726 .902 r
.42867 .12394 .43131 .12737 .43584 .1257 .4332 .12226 Metetra
.654 .726 .902 r
.4332 .12226 .43584 .1257 .44037 .12403 .43775 .12058 Metetra
.654 .725 .902 r
.43775 .12058 .44037 .12403 .44492 .12236 .4423 .1189 Metetra
.653 .725 .902 r
.4423 .1189 .44492 .12236 .44947 .12069 .44685 .11723 Metetra
.653 .724 .902 r
.44685 .11723 .44947 .12069 .45403 .11903 .45142 .11555 Metetra
.652 .724 .902 r
.45142 .11555 .45403 .11903 .4586 .11736 .45599 .11388 Metetra
.652 .724 .902 r
.45599 .11388 .4586 .11736 .46318 .11571 .46057 .11221 Metetra
.651 .723 .901 r
.46057 .11221 .46318 .11571 .46776 .11405 .46516 .11055 Metetra
.65 .723 .901 r
.46516 .11055 .46776 .11405 .47236 .1124 .46976 .10889 Metetra
.65 .722 .901 r
.46976 .10889 .47236 .1124 .47696 .11075 .47437 .10723 Metetra
.649 .721 .901 r
.47437 .10723 .47696 .11075 .48157 .10911 .47898 .10558 Metetra
.648 .721 .901 r
.47898 .10558 .48157 .10911 .48618 .10747 .4836 .10393 Metetra
.648 .72 .901 r
.4836 .10393 .48618 .10747 .49081 .10584 .48823 .10228 Metetra
.647 .719 .901 r
.48823 .10228 .49081 .10584 .49544 .10421 .49287 .10064 Metetra
.646 .719 .901 r
.49287 .10064 .49544 .10421 .50009 .10259 .49752 .09901 Metetra
.645 .718 .901 r
.49752 .09901 .50009 .10259 .50474 .10097 .50217 .09738 Metetra
.645 .717 .901 r
.50217 .09738 .50474 .10097 .50939 .09936 .50683 .09576 Metetra
.644 .716 .9 r
.50683 .09576 .50939 .09936 .51406 .09776 .51151 .09414 Metetra
.643 .715 .9 r
.51151 .09414 .51406 .09776 .51874 .09617 .51619 .09253 Metetra
.642 .714 .9 r
.51619 .09253 .51874 .09617 .52342 .09459 .52087 .09094 Metetra
.64 .713 .9 r
.52087 .09094 .52342 .09459 .52811 .09301 .52557 .08935 Metetra
.639 .712 .9 r
.52557 .08935 .52811 .09301 .53282 .09145 .53028 .08777 Metetra
.638 .71 .899 r
.53028 .08777 .53282 .09145 .53753 .0899 .53499 .0862 Metetra
.637 .709 .899 r
.53499 .0862 .53753 .0899 .54225 .08836 .53972 .08464 Metetra
.635 .707 .899 r
.53972 .08464 .54225 .08836 .54698 .08684 .54445 .08309 Metetra
.633 .706 .898 r
.54445 .08309 .54698 .08684 .55171 .08533 .54919 .08157 Metetra
.632 .704 .898 r
.54919 .08157 .55171 .08533 .55646 .08384 .55395 .08005 Metetra
.63 .702 .897 r
.55395 .08005 .55646 .08384 .56122 .08237 .55871 .07856 Metetra
.628 .7 .897 r
.55871 .07856 .56122 .08237 .56599 .08092 .56348 .07708 Metetra
.625 .697 .896 r
.56348 .07708 .56599 .08092 .57076 .07949 .56826 .07563 Metetra
.623 .694 .896 r
.56826 .07563 .57076 .07949 .57555 .0781 .57305 .0742 Metetra
.62 .691 .895 r
.57305 .0742 .57555 .0781 .58035 .07673 .57785 .07279 Metetra
.617 .688 .894 r
.57785 .07279 .58035 .07673 .58516 .07539 .58266 .07142 Metetra
.614 .684 .893 r
.58266 .07142 .58516 .07539 .58997 .0741 .58749 .07008 Metetra
.61 .68 .892 r
.58749 .07008 .58997 .0741 .59536 .09605 .59232 .06878 Metetra
0 0 .451 r
.59232 .06878 .59536 .09605 .60026 .09557 .59775 .09081 Metetra
.536 .601 .866 r
.59775 .09081 .60026 .09557 .60518 .09521 .60266 .09033 Metetra
.525 .589 .861 r
.60266 .09033 .60518 .09521 .61011 .09499 .60759 .08998 Metetra
.513 .576 .856 r
.60759 .08998 .61011 .09499 .61507 .09493 .61254 .08977 Metetra
.499 .561 .85 r
.61254 .08977 .61507 .09493 .62004 .09507 .61751 .08973 Metetra
.483 .543 .842 r
.61751 .08973 .62004 .09507 .62504 .09543 .62251 .08988 Metetra
.465 .523 .833 r
.62251 .08988 .62504 .09543 .63006 .09607 .62752 .09027 Metetra
.444 .5 .822 r
.62752 .09027 .63006 .09607 .63512 .09705 .63256 .09093 Metetra
.419 .472 .809 r
.63256 .09093 .63512 .09705 .64021 .09844 .63764 .09195 Metetra
.39 .44 .792 r
.63764 .09195 .64021 .09844 .64534 .10037 .64275 .09339 Metetra
.356 .402 .772 r
.64275 .09339 .64534 .10037 .65052 .10298 .6479 .09539 Metetra
.315 .358 .747 r
.6479 .09539 .65052 .10298 .65577 .10651 .65311 .09809 Metetra
.268 .305 .715 r
.65311 .09809 .65577 .10651 .66111 .11133 .65839 .10176 Metetra
.212 .243 .677 r
.65839 .10176 .66111 .11133 .66657 .11802 .66376 .10677 Metetra
.147 .172 .629 r
.66376 .10677 .66657 .11802 .67221 .12763 .66926 .11375 Metetra
.074 .092 .573 r
.66926 .11375 .67221 .12763 .67817 .14231 .67496 .12386 Metetra
0 .004 .508 r
.67496 .12386 .67817 .14231 .68474 .1672 .681 .13946 Metetra
0 0 .435 r
.681 .13946 .68474 .1672 .69296 .21999 .68773 .16649 Metetra
0 0 .358 r
.68773 .16649 .69296 .21999 .70012 .25075 .69645 .22673 Metetra
.047 .02 .5 r
.69645 .22673 .70012 .25075 .69107 .00357 .70298 .24544 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09549 .2323 m
.1002 .23687 L
s
[(-0.04)] .08608 .22315 1 .97179 Mshowa
.21633 .18498 m
.22084 .18975 L
s
[(-0.02)] .20731 .17545 .94563 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.47614 .08324 m
.48017 .08842 L
s
[(0.02)] .46808 .07289 .77884 1 Mshowa
.61605 .02846 m
.6198 .03385 L
s
[(0.04)] .60856 .01769 .69544 1 Mshowa
.125 Mabswid
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.18558 .19702 m
.18832 .19985 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.51046 .06981 m
.51284 .07294 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.06616 .24378 m
.06901 .2465 L
s
.03716 .25514 m
.04004 .25782 L
s
.65216 .01432 m
.65436 .01759 L
s
.68874 0 m
.69089 .0033 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[153]:=",
  ImageSize->{287, 232.75},
  ImageMargins->{{0, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O0000j2000`400?l00000o`00003ooooooolP
ooooo`00oooooolPooooo`00oooooolPooooo`00oooooolPooooo`00oooooolPooooo`00oooooolP
ooooo`00oooooolPooooo`00oooooolPooooo`00oooooolPooooo`00oooooolPooooo`00Woooool2
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol0001[ooooo`00W_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0J_oo
ool009kooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Go0000
Joooool009kooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00;ooooo00?o0000ooooooooool04?ooool2o`0005Sooooo002Nooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00000?ooooo`?o000000?ooooo
o`000?l00000Eoooool009kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`;o00003Oooool2o`0000Cooooo0_l0001Gooooo`00Woooool2o`0000[ooooo0_l00005
ooooo`03o`000?oooooooooo00Sooooo0ol00006ooooo`?o0000E_ooool00;_ooooo0ol00007oooo
o`Co0000E_ooool00;Sooooo0ol00002ooooo`03o`000?oooooooooo00Gooooo1Ol0001Eooooo`00
]Oooool3o`0000gooooo1_l0001Dooooo`00/oooool2o`0000oooooo1?l000000onY_NSo0000o`00
001Dooooo`00/?ooool4o`00013ooooo2?l0000>ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`?o0000=_ooool00:kooooo0_l00004ooooo`03o`000?oooooooooo00gooooo1Ol000001?nY
_NSo0000o`000?l0000<ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0=Ooo
ool00:_ooooo0ol0000Fooooo`Wo00001Oooool5o`0000;ooooo00Co0000oooooooooooo00001ooo
ool5o`0003Kooooo001jooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5
o`0001[ooooo0_l0000Hooooo`Ko000000GoZKgXo`000?l0003oZKgXo`00000;ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo0000=oooool007Wooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Oooooo0ol00002
ooooo`03o`000?oooooooooo01Gooooo3?l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool00000=oooool007Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo01Gooooo0_l0000Looooo`So000000GoZKgXo`000?l0003o
ZKgXo`00000:ooooo`04o`000?ooooooooooo`0000Wooooo0_l0000gooooo`00NOooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04Oooool3
o`0001kooooo3_l0000:ooooo`;o00002oooool00ol0003oooooooooo`0eooooo`00NOooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`0>ooooo`?o00007oooool9o`000004ojVmj?l0003o0000ojVmj0;o0000Coooool007Wooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool02oooool3o`0000?ooooo00?o0000ooooooooool07?ooool@o`0004kooooo001joooo
o`;o00002_ooool2o`0000?ooooo0ol0000;ooooo`?o00009Oooool:o`000003ojVmj?l0003o0000
00Co0000COooool009Oooooo0_l0000Cooooo`;o00004ooooolBo`0004cooooo002Dooooo`?o0000
0_ooool00ol0003oooooooooo`0=ooooo`Go00004oooool:o`000004ojVmj?l0003o0000ojVmj0;o
000000?oZKgXo`000?ooool0Boooool009;ooooo0_l0000Booooo`?o000000?oW[3Uo`000?l00000
0ol0000AoooooaCo0000Boooool008oooooo0ol0000@ooooo`go00004?ooool:o`000003ojVmj?l0
003o000000Go000000?oZKgXo`000?l00000Boooool008gooooo0ol0000?ooooo`Oo000000GoX;;U
o`000?l0003o0000oif_i004o`00013ooooo5_l0001:ooooo`00R_ooool3o`0000?ooooo00?o0000
ooooooooool02Oooool3o`000004oj>ei_l0003o0000oj6di@go00003oooool:o`000004ojVmj?l0
003o0000ojVmj0;o000000?oZKgXo`000?l000001?l00019ooooo`00R?ooool2o`0000oooooo1ol0
00001?nR]NKo0000o`000?nQ/nD3o`000003oijaiOl0003o0000017o00001?oooolHo`0004Sooooo
001Wooooo`;o00007?ooool3o`0000oooooo0_l000001?nT]nKo0000o`000?nS]^H;o`000005oij`
i?l0003o0000o`000?n7Ei404?l00002ooooo`go000000CoZKgXo`000?l0003oZKgX0_l000001OnY
_NSo0000o`000?nY_NSo000004Sooooo001Vooooo`04o`000?ooooooooooo`0001Wooooo0_l00002
ooooo`03o`000?oooooooooo00Wooooo1ol000001?nT]^Ko0000o`000?nS]^H2o`000005oj:diOl0
003o0000o`000?nP/^D01ol000000on7Ei7o0000o`00000=o`000003oe1K_ol0003o000001Wo0000
Aoooool006Kooooo00Co0000oooooooooooo00005_ooool3o`0000kooooo0_l000001?nU^>Ko0000
o`000?nU]nH>o`000003oinbiOl0003o000000Co000000?oQeNAo`000?n9V]d01?l000001OmlS=So
0000o`000?l0003oK7[@00;o000000?oG6S6o`000?l000005Ol000001?nY_NSo0000o`000?nY_NP2
o`0004Oooooo001Vooooo`04o`000?ooooooooooo`0001?ooooo0ol0000=ooooo`Co000000CoYKSV
o`000?l0003oYKSV0_l000001?nT]nKo0000o`000?nT]^H3o`000004oj:ei_l0003o0000oj6ciAgo
000000?o=Sj]o`000?l000005ol00016ooooo`00I_ooool01?l0003oooooooooool0000Aooooo`;o
000000?oooooo`000?l000002oooool2o`000003ojJii_l0003o000001;o000000GoXK?Uo`000?l0
003o0000oijai@0Bo`000006oei[aol0003o0000odMA^Ol0003o>42^2ol000001?nY_NSo0000o`00
0?nY_NP<o`0004Gooooo001Vooooo`04o`000?ooooooooooo`0000kooooo0ol0000>ooooo`;o0000
00CoY[WVo`000?l0003oY[SV0_l000000onU^>Ko0000o`000004o`000004ojBgi_l0003o0000oj>f
iP;o000000?oX[CUo`000?l000002ol000000on<WMoo0000o`000008o`000003ofMecOl0003o0000
023o0000AOooool006Oooooo0_l0000=ooooo`;o00003OoooolGo`000004oj>ei_l0003o0000oj:d
i@?o000000?oX;;Uo`000?l000002Ol000000on5U]co0000o`000003o`000003ofmmdOl0003o0000
00Go000000?o>dBao`000?l000002_l000001?nY_NSo0000o`000?nY_NP2o`000003ojVmj?l0003o
000000So0000A?ooool007?ooooo0ol0000=ooooo`;o000000?oYkWVo`000?l000001ol000001?nV
^>Ko0000o`000?nU^>H2o`000003ojFgi_l0003o000000co000000GoWk7Uo`000?l0003o0000ohUH
TP0@o`000003oeMSa?l0003o000001Wo000000CoZKgXo`000?l0003oZKgX0_l00014ooooo`00LOoo
ool2o`0000?ooooo00?o0000ooooooooool02?ooool2o`000004ojNii_l0003o0000ojNiiP;o0000
00CoY[WVo`000?l0003oY[WV2Ol000001?nT]nKo0000o`000?nT]^H6o`000003oj6ciOl0003o0000
00Go000000?oRERBo`000?l000003?l000000omQKl[o0000o`000002o`000003oce6/_l0003o0000
00ko000000CoZKgXo`000?l0003oZKgX0_l000001?nY_NSo0000o`000?nY_NP6o`0000gooooo0_l0
0004ooooo`04o`000?ooooooooooooooo`Go00009_ooool006kooooo0ol0000=ooooob?o000000?o
XK?Uo`000?l000001?l000000on9F9;o0000o`00000:o`000003ofYhcol0003o0000023o000000Go
ZKgXo`000?l0003oZKgXo`00000<ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00009_ooool006cooooo0_l0000=oooooa;o000000CoY[SVo`000?l0003oYKSV0_l000001?nU
]nKo0000o`000?nT]nH3o`000004oj>fi_l0003o0000oj:diAGo000000?oLH3Co`000?l000000ol0
00001Om?F[oo0000od1;]_l0003o;cRY01;o000000?oZKgXo`000?l000002ol00004ooooo`Go0000
0_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo02Kooooo001Yooooo`?o0000
00?oooooo`000?ooool02OoooolLo`000004ojFgi_l0003o0000ojBfiPKo000000?oX[CUo`000?l0
00002_l000000on9V]ko0000o`000002o`000003ogb<f?l0003o000000Co000000?oFfS6o`000?l0
00008Ol000000onY_NSo0000o`00000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool09Oooool006Oooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo0_l000001?nX^^Ko
0000o`000?nX^^H2o`000004ojNji_l0003o0000ojNiiP;o000000CoYkWVo`000?l0003oYkWV0_l0
00001?nV^NKo0000o`000?nV^>H2o`000003ojFhi_l0003o000002;o000000?oIG?<o`000?l00000
9ol0000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Voooo
o`00=Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol0000Jooooo`?o
00003?oooolHo`000004ojJhi_l0003o0000ojJhiP;o000000CoYKSVo`000?l0003oYKOV1_l00000
0onS]NGo0000o`00000Ko`000003odIA^_l0003o=Sn_01Co000000?oZKgXo`000?l000002?l00000
0onY_NSo0000o`000002o`0000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000002Kooooo000dooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000Gooooo`?o000000?oooooo`000?ooool02Ooooom7o`00
0003oe=P`_l0003o000002Ko00002_ooool2o`0000Wooooo0ol0000Wooooo`00;Oooool5o`0000;o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo01Gooooo0_l0000=ooooo`;o000000CoZ;[Vo`000?l0003oZ;[V0_l000001?nX^^Ko0000o`00
0?nX^^H2o`000004ojRji_l0003o0000ojNjiP;o000000CoYkWVo`000?l0003oYkWV0_l000001?nW
^NKo0000o`000?nV^>H2o`000003ojJhi_l0003o000000Co000000CoY;OVo`000?l0003oXkKV1_l0
00000onQ/nGo0000o`000006o`000003ohfNgol0003o000000Oo000000?oKgkBo`000?l000005Ol0
00001?nY_NSo0000o`000?nY_NP2o`000004ojVmj?l0003o0000ojVmj0go0000?_ooool003Cooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
017ooooo0ol0000=oooooago000000CoY[WVo`000?l0003oY[SV0_l000000onV^>Ko0000o`000007
o`000004oj>eiOl0003o0000oj:di@ko000000?oQIKLo`000?l000007Ol000000onY_NSo0000o`00
000:o`000004ojVmj?l0003o0000ojVmj0Ko0000?Oooool003Cooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool03_ooool3o`00
00cooooo7?l000000onW^NKo0000o`00000:o`000004ojFgi_l0003o0000ojBfiR7o000000GoBeRn
o`000?llAkCo0000obTcY`0Ao`000004ojVmj?l0003o0000ojVmj0;o000000?oZKgXo`000?l00000
3?l0000mooooo`00=?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`0;ooooo`?o00000oooool00ol0003oooooooooo`06oooo
o`So000000CoZK[Vo`000?l0003oZK[V0_l000001?nX^^Ko0000o`000?nX^^H2o`000004ojRji_l0
003o0000ojRjiP;o000000CoYkWVo`000?l0003oYkWV0_l000001?nW^NKo0000o`000?nV^>H2o`00
0003ojJhi_l0003o000000Oo000000CoY;KVo`000?l0003oXkGU0ol000000onQ/nGo0000o`00000B
o`000003ofYid?l0003o000001Ko000000?oZKgXo`000?l000001ol000001?nY_NSo0000o`000?nY
_NP2o`000003ojVmj?l0003o000000Go0000??ooool003Gooooo0_l0000:ooooo`;o00000oooool3
o`0000cooooo0_l0000=ooooo`;o000000CoZK_Vo`000?l0003oZK[V=_l000000on;G9Co0000o`00
0002o`000003ohnQh?l0003o000002Go000000CoZKgXo`000?l0003oZKgX0_l000000onY_NSo0000
o`000007o`000004ojVmj?l0003o0000ojVmj0;o0000??ooool005;ooooo0ol0000<ooooo`_o0000
00?oZK[Vo`000?l000003_l000001?nX^NKo0000o`000?nW^NH2o`000004ojNii_l0003o0000ojNi
iPWo000000CoYKOVo`000?l0003oYKOV0_l000000onT]^Go0000o`00000>o`000003ohbMgol0003o
000000_o000000GoDEk2o`000?m2CkWo0000oc4l[@0Ko`000004ojVmj?l0003o0000ojVmj0;o0000
00?oZKgXo`000?l000001_l0000kooooo`00D?ooool2o`0000?ooooo00?o0000ooooooooool01ooo
ool2o`000003ojZki_l0003o000000_o000000CoZK[Vo`000?l0003oZK[V0_l000001?nX^^Ko0000
o`000?nX^^H2o`000004ojRji_l0003o0000ojRiiP;o000000CoYkWVo`000?l0003oYkWV0_l00000
1?nW^NKo0000o`000?nV^>H2o`000003ojJhi_l0003o000000Oo000000?oY;KUo`000?l000004?l0
00000on4U]co0000o`00000Po`000004ojVmj?l0003o0000ojVmj0co000000CoZKgXo`000?l0003o
ZKgX0_l000000onY_NSo0000ooooo`0iooooo`00COooool3o`0000cooooo2?l000000onY^^Ko0000
o`00000Yo`000004ojFgi_l0003o0000ojBfiPKo000000?oX[CUo`000?l00000>?l000001?nY_NSo
0000o`000?nY_NP<o`0003[ooooo001;ooooo`?o00003?ooool=o`000004ojVji_l0003o0000ojVj
iQ3o000000CoZ;[Vo`000?l0003oZ;WV0_l000001?nW^NKo0000o`000?nW^NH2o`000004ojNhi_l0
003o0000ojJhiPWo000000CoY;KUo`000?l0003oXkGU2Ol000000onCYN;o0000o`00000>o`000006
of1_bol0003o0000odUF_Ol0003o>DBc4_l000001?nY_NSo0000o`000?nY_NP?o`000004ojVmj?l0
003o0000ojVmj0Go0000>Oooool004Sooooo0ol00003ooooo`03o`000?oooooooooo00Kooooo1Ol0
00001?nZ^^Go0000o`000?nZ^^D2o`000003ojZjiOl0003o000000So000000CoZK[Vo`000?l0003o
ZK[V5?l000000onW^NKo0000o`00000Ko`000003oi6ShOl0003o000002co000000CoZKgXo`000?l0
003oZKgX4Ol0000hooooo`005Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Co
oooo0ol0000Kooooo`?o00003Oooool2o`000004oj^jiOl0003o0000ojZjiASo000000?oZK[Vo`00
0?l000002ol000000onW^NKo0000o`00000:o`000004ojJgi_l0003o0000ojFgi@;o000000?oY;KU
o`000?l000003_l000000on=Wn3o0000o`00000Ro`000004ojVmj?l0003o0000ojVmj0co000000Co
ZKgXo`000?l0003oZKgX2_l0000gooooo`005?ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool06?ooool2o`0000kooooo4_l000001?nZ^^Go
0000o`000?nZ^^D2o`000003ojVjiOl0003o000000So000000CoZK[Vo`000?l0003oZ;[V0_l00000
1?nX^NKo0000o`000?nX^NH2o`000004ojNii_l0003o0000ojNiiP;o000000CoYkSVo`000?l0003o
Y[SV9_l000000omJJLSo0000o`00000Mo`000003ojVmj?l0003o000000go000000CoZKgXo`000?l0
003oZKgX0_l0000gooooo`003Oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01Ol0
003oooooooooool0003ooooo00Go00005_ooool3o`0000;ooooo00?o0000ooooooooool02?ooool:
o`000004oj^jiOl0003o0000ojZji@;o000000CoZ[[Uo`000?l0003oZ[[U:_l000001?nV]nGo0000
o`000?nU]nD6o`000003oj>diOl0003o000000co000000?oQiWMo`000?l000000_l000000omhRMOo
0000o`00000Ko`000003ojVmj?l0003o000000[o000000CoZKgXo`000?l0003oZKgX3_l0000foooo
o`005?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool00ol0003oooooooooo`0Cooooo`;o00003Oooool5o`000004oj^ji?l0003o0000oj^ji@;o0000
00CoZk[Uo`000?l0003oZk[U3ol000001?nY^^Go0000o`000?nY^^D2o`000004ojVjiOl0003o0000
ojVji@[o000000CoZ;WUo`000?l0003oYkWU0_l000001?nW^>Go0000o`000?nW^>D9o`000004ojFf
iOl0003o0000ojBfi@Wo000000?oU:ORo`000?l000004_l000000om5Dkco0000o`00000Ho`000004
ojVmj?l0003o0000ojVmj0co000000?oZKgXo`000?l000001ol0000fooooo`005?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000004_ooool3
o`0000gooooo0_l000001?n/^^Co0000o`000?n[^^@2o`000003oj^ji?l0003o000000[o000000Co
Z[[Uo`000?l0003oZ[[U0_l000001?nZ^^Go0000o`000?nZ^^D2o`000003ojZjiOl0003o000001Oo
000000?oYkSUo`000?l000003ol000000on=GiOo0000o`00000Do`000004ofMgcol0003o0000oe=R
a27o000000CoZKgXo`000?l0003oZKgX3ol000000onY_NSo0000o`00000eooooo`005?ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000@ooooo`;o00000_oo
ool00ol0003oooooooooo`09ooooo`;o000000Co[;[To`000?l0003o[;[T2Ol000001?n[^^Co0000
o`000?n[^^D2o`000004oj^jiOl0003o0000oj^ji@oo000000CoZK[Uo`000?l0003oZK[U0_l00000
1?nY^NGo0000o`000?nX^NDDo`000004ojFgiOl0003o0000ojFfi@Go000000?oSEnGo`000?l00000
1Ol000000onBY>7o0000o`00000Do`000003ob8]Y?l0003o000001;o000000CoZKgXo`000?l0003o
ZKgX3?l000000onY_NSo0000o`00000<o`0003Cooooo000Eooooo`;o00002_ooool2o`0000Gooooo
00?o0000ooooooooool02oooool3o`0000kooooo0_l000000on/^^Co0000o`000004o`000004ojbj
i?l0003o0000oj^ji0;o000000CoZk[To`000?l0003oZk[T2Ol000001?n[^^Go0000o`000?nZ^^D2
o`000004ojZjiOl0003o0000ojZji@;o000000CoZK[Uo`000?l0003oZK[U2_l000001?nX^NGo0000
o`000?nX^ND2o`000004ojNiiOl0003o0000ojNhi@;o000000CoYkSUo`000?l0003oY[OU2ol00000
0on=GiOo0000o`000007o`000003ohnQh?l0003o000000oo000000?o?4Zgo`000?l000006_l00000
1?nY_NSo0000o`000?nY_NP<o`000003ojVmj?l0003o000000Oo00002?ooool2o`0002[ooooo000d
ooooo`;o00003_ooool7o`000004ojbjhol0003o0000ojbji0;o000000?o[;[To`000?l000002_l0
00001?n[^^Co0000o`000?n[^^@2o`000004oj^jiOl0003o0000ojZjiBOo000000CoYKOUo`000?l0
003oYKKU2?l000000onHZ^?o0000o`000005o`000003ohjPh?l0003o000000Ko000000?oLX?Eo`00
0?l000009ol000001?nY_NSo0000o`000?nY_NPBo`0000Kooooo00Co0000oooooooooooo0000:Ooo
ool0037ooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo1Ol000001?n]^^?o0000o`000?n]
^^<2o`000003ojbjhol0003o000000Oo000000Co[;[To`000?l0003oZk[T0_l000000on[^^Co0000
o`00000:o`000004ojZjiOl0003o0000ojZji@;o000000CoZ[[Uo`000?l0003oZK[U0_l000001?nY
^NGo0000o`000?nY^ND7o`000004ojRiiOl0003o0000ojRhi@;o000000CoYkSUo`000?l0003oYkSU
2Ol000000onT]^Go0000o`000006o`000003oiNYhol0003o000000[o000000?oOHkJo`000?l00000
7ol000001?nY_NSo0000o`000?nY_NP2o`000003ojVmj?l0003o000000[o000000?oZKgXo`000?l0
00003?l00005ooooo`04o`000?ooooooooooo`0002Wooooo000_ooooo`;o00003_ooool2o`000004
ojfih_l0003o0000ojfihP;o000000?o[K[So`000?l000001ol000001?n/^^?o0000o`000?n/^^@2
o`000003ojbji?l0003o000000[o000000CoZk[To`000?l0003oZk[T0_l000000onZ^^Go0000o`00
000io`000003ohFGgOl0003o000000Ko000000CoGFg;o`000?l0003oA5>l8?l000001?nY_NSo0000
o`000?nY_NP<o`000003ojVmj?l0003o000000Oo00001Oooool01?l0003oooooooooool0000Yoooo
o`00;?ooool3o`0000kooooo0_l000001?n^^N;o0000o`000?n^^N89o`000004ojfjhol0003o0000
ojbjh`oo000000?oZk[To`000?l000003Ol000001?nZ^^Go0000o`000?nZ^ND2o`000004ojViiOl0
003o0000ojVii@;o000000?oZKWUo`000?l000002?l000000onW^>Go0000o`00000:o`000003ojBf
iOl0003o000000Oo000000?oUJORo`000?l000005_l000000olM:J;o0000o`00000Bo`000003ojVm
j?l0003o000000[o000000CoZKgXo`000?l0003oZKgX3?l000000onY_NSo0000o`000003o`0000Co
oooo00Co0000oooooooooooo0000:Oooool002Wooooo0ol00002ooooo`03o`000?oooooooooo00[o
oooo0_l000001?n^^N7o0000o`000?n^^N46o`000004ojfih_l0003o0000ojfihPOo000000?o[K[S
o`000?l000001Ol000000on/^^?o0000o`000005o`000003oj^ji?l0003o000000Go000000CoZk[T
o`000?l0003oZ[[T0_l000000onZ^NCo0000o`00000Go`000003ojNgiOl0003o000002Co000000?o
BUW0o`000?l000007?l000000onY_NSo0000o`00000:o`000004ojVmj?l0003o0000ojVmj0ko0000
0oooool01?l0003oooooooooool0000Yooooo`009oooool2o`00013ooooo0_l000001?n_^>3o0000
o`000?n_^N43o`000004ojjihOl0003o0000ojjih@;o000000?o[[WRo`000?l000000_l000000on]
^N;o0000o`00000=o`000003ojbjhol0003o000000Go000000?oZk[To`000?l000003Ol000001?nZ
^NGo0000o`000?nY^ND2o`000004ojViiOl0003o0000ojVii@;o000000?oZ;SUo`000?l000003?l0
00000onU]^Go0000o`00000;o`000003oi>Uh_l0003o000000_o000000?oJgcBo`000?l000009_l0
00000onY_NSo0000o`00000:o`000004ojVmj?l0003o0000ojVmj0Wo00001?ooool2o`0002[ooooo
000Tooooo`?o00004?ooool2o`000003ok2hgol0003o000000Co000000Co[kSPo`000?l0003o[[WQ
4Ol000001?n]^N?o0000o`000?n]^N<?o`000003oj^ii?l0003o000000Go000000CoZ[WTo`000?l0
003oZ[WT4ol000001?nW^>Go0000o`000?nW]nD2o`000003ojJgiOl0003o000000oo000000?oTZCQ
o`000?l00000>?l000000onY_NSo0000o`00000:o`000004ojVmj?l0003o0000ojVmj0Go0000;ooo
ool002;ooooo0_l00002ooooo`03o`000?oooooooooo00cooooo1_l000001?n`^=oo0000o`000?n_
^=l2o`000003ojnhh?l0003o000000Oo000000?o[[WQo`000?l000000_l000001?n^^N;o0000o`00
0?n]^N8<o`000004ojbihol0003o0000ojbihaOo000000CoZKWTo`000?l0003oZKWU0_l000001?nX
^>Go0000o`000?nX^>D;o`000003ojFfiOl0003o000000Ko000000?oV:[So`000?l000003ol00000
1?m^Om?o0000o`000?mLKL/2o`000003od9B_?l0003o000002_o000000?oZKgXo`000?l000002_l0
00000onY_NSo0000o`000002o`0002kooooo000Oooooo`?o00004?ooool5o`000003ok6gg_l0003o
/KON00;o000000Co/;ONo`000?l0003o/;SO1_l000000on_^>3o0000o`000005o`000003ojjihOl0
003o000000Oo000000Co[KWRo`000?l0003o[KWR0_l000000on/^N?o0000o`00000:o`000003oj^i
i?l0003o000000So000000CoZ[WTo`000?l0003oZKWT3Ol000001?nW^>Go0000o`000?nW]nD2o`00
0003ojJgiOl0003o000000[o000000?oV:WSo`000?l000001?l000000on=Wn3o0000o`00000[o`00
0003ojVmj?l0003o000000oo000000CoZKgXo`000?l0003oZKgX3?l0000^ooooo`007_ooool3o`00
013ooooo00Go0000ohaIT?l0003o0000ok:fg004o`000004ok6ggOl0003o0000ok6ggP?o000000Co
/;SOo`000?l0003o/;SO1?l000000on_^>3o0000o`00000:o`000004ojjih_l0003o0000ojfihPWo
000000Co[;WSo`000?l0003o[;WS0_l000000on/^N?o0000o`00000Bo`000004ojVhi?l0003o0000
ojRhi1?o000000?oVjgSo`000?l000002ol000000on9Vmko0000o`00000^o`000003ojVmj?l0003o
000000oo000000CoZKgXo`000?l0003oZKgX2?l0000]ooooo`005oooool2o`0000Gooooo1?l00000
0ooooooo0000ooooo`0<ooooo`04o`000?n<FI3o0000ohaJT0;o000000?oS5ZAo`000?n<FY401Ol0
00001?na]mgo0000o`000?n`]mh4o`000003ok2hgol0003o000000;o000000?o[kSPo`000?l00000
0_l000001?n^^>7o0000o`000?n^^N46o`000004ojfih_l0003o0000ojfihP;o000000Co[KWRo`00
0?l0003o[;WS1_l000001?n/^N?o0000o`000?n[^N<2o`000003oj^ii?l0003o000000Go000000Co
Z[WTo`000?l0003oZKWT0_l000001?nY^>Co0000o`000?nX^>@7o`000004ojNgi?l0003o0000ojJg
i2?o000000?o>TVgo`000?l000005Ol000000onY_NSo0000o`00000=o`000003ojVmj?l0003o0000
00oo000000?oZKgXo`000?l000001Ol0000/ooooo`005_ooool01?l0003oooooooooool00004oooo
o`Oo000000?oooooo`000?ooool02Oooool01?l0003oS5V@o`000?n<FY02o`000003ohaJTOl0003o
S5ZA00;o000000?oSE^Bo`000?n=Fi800_l000000on=G9;o0000oheLTP0;o`000003ojnhh?l0003o
000000Oo000000Co[[WQo`000?l0003o[KWR2Ol000001?n/^N?o0000o`000?n/^N<2o`000003ojbi
hol0003o000005oo000000?oZKgXo`000?l000007?l000001?nY_NSo0000o`000?nY_NP2o`0002co
oooo000Fooooo`04o`000?ooooooooooo`0000Cooooo0_l000000oo`[XGo0000oo2^Q@05o`000003
ooooool0003ooooo00Kooooo2ol000000on=Fi;o0000oheKTP02o`000003oheLT_l0003oSEbB00;o
000000?oSEbCo`000?n=G9<00_l000000on>GI?o0000ohiMU006o`000004ojnhh?l0003o0000ojjh
h@;o000000Go[[SQo`000?l0003o0000ojjih@02o`000004ojfih_l0003o0000ojfihPWo000000Co
[;WSo`000?l0003oZkWS0_l000000on[^N?o0000o`000005o`000004ojZhi?l0003o0000ojVhi0;o
000000CoZKSTo`000?l0003oZ;ST1ol000000onV]^Co0000o`000006o`000003oiZ/hol0003o0000
00;o000000?oUJORo`000?l000003Ol000001?mVN=3o0000o`000?m@H/DTo`000003ojVmj?l0003o
000001ko0000:oooool001Kooooo00Co0000oooooooooooo00000oooool3o`000003oo2^QOl0003o
l:j500;o000000?ol:j4o`000?l000001Ol000000ooooooo0000ooooo`0<o`000003oheKT_l0003o
000000Oo000000?oSEbCo`000?n=G9<00_l000000on>GI?o0000ohiMU002o`000006ohiMU?l0003o
0000ohiNU?l0003oSUjE1_l000001?n^^>7o0000o`000?n^^>49o`000004ojfih_l0003o0000ojbi
hP;o000000?o[;WSo`000?l000007?l000000onV]^Co0000o`00000Po`000003oc51/_l0003o0000
027o000000?oZKgXo`000?l000007?l0000[ooooo`005_ooool01?l0003oooooooooool00003oooo
o`Ko000000?ol:j4o`000?o`[X@00_l000001?o`[XCo0000o`000?o`[X@?o`000003on^dVOl0003o
000000So000000?oSEbCo`000?l000001ol000001_n>GICo0000o`000?n>GYCo0000ohiNU@;o0000
00?oSUjEo`000?n?GiD00_l000000on?GiKo0000o`000004o`000004ojfhhOl0003o0000ojfhhPWo
000000Co[;WSo`000?l0003oZkSS0_l000000on[^>?o0000o`000005o`000004ojVhi?l0003o0000
ojVhi0;o000000CoZ;STo`000?l0003oZ;OT2Ol000001OnM[^?o0000o`000?l0003oVZcS00Go0000
00?oTjGQo`000?l00000:Ol000000onY_NSo0000o`00000?o`000003ojVmj?l0003o000001So0000
:_ooool001Kooooo00Co0000oooooooooooo00000oooool2o`000003oo2^QOl0003ol:j500Ko0000
00Sol:j4o`000?l0003ol:j4o`000?o`[X?o0000oo2^P`;o000000?ojkBIo`000?o[]9T00_l00000
1Oo[]9Wo0000on^dVOl0003ojkBI00Wo000000?ok;JIo`000?l000002?l000000on>GICo0000o`00
0005o`000003ohiNUOl0003oSenE00;o000000?oSenFo`000?n?GiH00_l000000on?H9Ko0000o`00
0007o`000004ojfhh_l0003o0000ojbhhP;o000000?o[;SRo`000?l00000:?l000000onBY>7o0000
o`00000Zo`000004ojVmj?l0003o0000ojVmj0ko000000?oZKgXo`000?l000005ol0000Yooooo`00
5oooool2o`0000Cooooo0_l000000oo`[XGo0000oo2^Q@02o`000003oo2^Q?l0003ol:j400Co0000
00?ol:j4o`000?o`[X<01?l000000oo[]9Wo0000on^dV@02o`000005on^dVOl0003ojkBIo`000?o[
]9T00_l000002?o[]IWo0000o`000?o[]IWo0000onbeVOl0003ok;JI2_l000000on>GICo0000o`00
0005o`000003ohiNUOl0003o000000Oo000000?oSf2Fo`000?n?H9H00_l000001?n?HIOo0000o`00
0?n@HIL9o`000004ojbhh_l0003o0000oj^hh`;o000000CoZkSSo`000?l0003oZkSS1?l000001?nY
^>?o0000o`000?nY]n<2o`000004ojRgi?l0003o0000ojNgi0Ko000000?oWJkSo`000?l000007?l0
00000olW=jgo0000o`00000Ko`000003ojVmj?l0003o000000oo000000?oZKgXo`000?l000004ol0
000Xooooo`007Oooool2o`000003oo2^QOl0003ol:j500;o000000Col:j4o`000?l0003ol:j41_l0
00000onj[<co0000okZ]c002o`000003okV^c_l0003o^Jk>00;o000000?o^Jo@o`000?l000000ol0
00002?o[]IWo0000o`000?o[]IWo0000onbeVOl0003ok;JI0_l000002?o/]YWo0000o`000?o/]YWo
0000onbfVOl0003ok;JI1ol000000oo]]iWo0000o`000008o`000003ohmPU_l0003o000000Go0000
00?oT66Go`000?n@HIL00_l000001?n@HYSo0000o`000?n@HYPKo`000003oi1SVOl0003o000000Ko
000000?oVJ[Ro`000?l000000ol000000onAXn7o0000o`000007o`000003ogF7eol0003o000000Co
000000?o@eFoo`000?l000008ol000000onY_NSo0000o`00000<o`000003ojVmj?l0003o0000017o
0000:?ooool001gooooo0_l000000oo`[XGo0000oo2^Q@02o`000004oo2^Q?l0003o0000oo2^Q0;o
000000Kol:j4o`000?l0003o^j_:o`000?nkZlX2o`000003okZ]c?l0003o^Zg=00Go000000Ko^Jo?
o`000?l0003o^;3Ao`000?nh/=42o`000003okNad_l0003o000000?o000000?ok;JIo`000?l00000
0_l000000oo/]YWo0000onbfV@03o`000005onfgVOl0003okKNIo`000?o]]iT02Ol000000oo]^9Wo
0000o`000006o`000003oi1QUol0003o000000Go000000?oT6:Ho`000?n@HYP00_l000001?n@HYSo
0000o`000?n@HiT2o`000003oj^hhol0003o000000Go000000CoZKOSo`000?l0003oZ;OS0_l00000
0onX]^?o0000o`000018o`000003ojVmj?l0003o000001oo00009oooool001gooooo0_l000000oo`
[XGo0000oo2^Q@02o`000004oo2^Q?l0003o0000oo2^Q0Co000000Go_:[7o`000?nlZ/So0000okbZ
b005o`000006ok^/bol0003o0000okZ^cOl0003o^Zk>0_l000000oni[loo0000o`000003o`000003
okR`d_l0003o^;3B00;o000000?o]k7Co`000?ng/M@01_l000001_nf/mKo0000o`000?o]]iWo0000
onfgV@;o000000SokKNIo`000?l0003okKRIo`000?o]^9Wo0000onfhV@Oo000000?ok[VIo`000?l0
00001_l000000on@HYSo0000o`000002o`000006oi1RV?l0003o0000oi1SVOl0003oTF>I5_l00000
0onL[N?o0000o`000008o`000003ohnQh?l0003o000000co000000?oBUc3o`000?l000005_l00000
0onY_NSo0000o`00000?o`000003ojVmj?l0003o000001ko00009_ooool001cooooo2?l000001?o`
[XCo0000o`000?o`[X@3o`000003okbXaOl0003o_:S500Go000000?o^j_9o`000?nkZlT00_l00000
0onj[<co0000okZ]c005o`000008okV^c_l0003o0000okV_d?l0003o^K3@o`000?nh/=46o`000003
okNbe?l0003o]k;D00;o000000?o][?Fo`000?l000001?l000000oo]]iWo0000okBdf002o`000003
onfhVOl0003okKRI00;o000000KokKRIo`000?l0003ok[VIo`000?o^^IT7o`000003onjiVOl0003o
000000?o000000KoT6:Ho`000?l0003oT6>Io`000?nAHiT2o`000006oi5SVOl0003o0000oi5TVOl0
003oTFBJ0ol000000onY]n?o0000o`00000Eo`000003oh^Mgol0003o000000go000000?o9cR^o`00
0?l000006?l000000onY_NSo0000o`00000<o`000003ojVmj?l0003o000000oo000000?oZKgXo`00
0?l000002_l00008ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000oooooo0008oooo
o`?o00001?ooool2o`0000Cooooo0_l00005ooooo`_o000000Kol:j4o`000?l0003o_JK2o`000?nm
Y/<2o`000008okfW`ol0003o0000okbYa_l0003o_:W7o`000?nlZ/L2o`000004ok^[b_l0003o0000
ok^/bP;o000000?o^Zg=o`000?nj[/d00_l000000oni[loo0000okV_c`03o`000003okR`dOl0003o
^;3B00;o000000?o]k7Co`000?ng/M<00ol000001?nf/]Go0000o`000?nf/mH4o`000003okFdf?l0
003o000000Co000000?okKRIo`000?nc]MX00_l000001?o^^IWo0000o`000?o^^IT2o`000003onji
V_l0003ok[VI00Co000000Cok[ZIo`000?l0003okkZJ1Ol000001_nAHiWo0000o`000?nAI9Wo0000
oi5TVP;o000000?oTFBJo`000?l000001Ol000001OnO[n?o0000o`000?l0003oW:gS00Co000000?o
V:SRo`000?l000003ol000000omNLLko0000o`00000Jo`000004oiI/X?l0003o0000oiI/X0;o0000
00?oUVbQo`000?l00000:_l00006ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00003oooool000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo0_l000000oo`[XGo0000oo2^Q@08o`000003okjT_ol0003o
000000;o000000So_ZG1o`000?l0003o_JO4o`000?nmZ<Co0000okfXa@Go000000So_:_8o`000?l0
003o^jc;o`000?nk[<_o0000ok^]b`Ko000000Go^Jo@o`000?ni[m3o0000okV`d006o`000003okNb
e?l0003o]k;D00;o000000?o][;Fo`000?l000001_l000001?nd]=So0000o`000?nd]=T8o`000004
ok:efol0003o0000onjiV@;o000000?ok[VIo`000?o^^YT00_l000000oo_^Y[o0000o`000002o`00
0003onnjVOl0003okkZI00Ko000000GoTFBJo`000?l0003o0000oi5TVP0ko`000004oiI/X?l0003o
0000oiI/X0;o000000?oUVbQo`000?nFKJ400ol000000onFKJ7o0000oiI]X@0To`0000Kooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`0?ooooo`002Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`000003
oo2^QOl0003ol:j500;o000000?ol:j4o`000?o`[X@01Ol000002?nnXkgo0000o`000?nnYL7o0000
okjV`Ol0003o_ZK11Ol000001OnmZLGo0000okfYa_l0003o_:W600;o000000?o_:_9o`000?l00000
0ol000000onj[Lco0000okZ]c@02o`000003okZ_col0003o^Jo?00?o000000?o^;3Ao`000?nh/=40
0_l000000onh/M?o0000okNad`03o`000006okJbeOl0003o0000okJce_l0003o][?F0_l000001One
/mOo0000o`000?l0003o];CI00;o000000?o/kCJo`000?nc]=X01_l000001?na]M_o0000o`000?o^
^YT5o`000005onnjV_l0003okkZIo`000?o_^YT01Ol000001?o_^i[o0000o`000?nAI9X5o`000005
oin_hol0003o0000o`000?nL[>801?l000000onGZ>;o0000o`00000>o`000003of=fd?l0003o0000
00Co000000?o7BnXo`000?l000004ol000001?od`Y[o0000o`000?od`YX3o`000003oiI/XOl0003o
UVfQ00?o000000?oUVfQo`000?l000000ol000001?nGKZ;o0000o`000?nGKZ8No`0000Gooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooooooo`0>ooooo`002Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`000003
oo2^QOl0003ol:j500;o000000?ol:j4o`000?l000000_l000000onoX;Wo0000oknP^@02o`000005
okjS_Ol0003o_Z>no`000?nnY;h00_l000002?nnYKoo0000o`000?nmYl?o0000okfW`ol0003o_JS4
0_l000001?nlZLOo0000o`000?nlZ/L2o`000005ok^/b_l0003o^jc;o`000?nk[</01Ol000001_nj
[/ko0000o`000?ni[m3o0000okV`d0Ko000000?o]k;Do`000?ng/]@00_l000000onf/]Go0000o`00
0003o`000004okFceol0003o0000okBdf0Ko000000?o/kCJo`000?nb]=X00_l000000onb]M_o0000
o`000004o`000006ok2eg?l0003o0000onnjVOl0003okkZI0ol000001Oo_^i[o0000onnkV_l0003o
kk^J02Co000000?o?E2mo`000?l000005_l000001?od`Y[o0000o`000?od`YX2o`000003ooC3V_l0
003om<>J00?o000000Com<>Jo`000?l0003oUVfQ0ol000001_nGKZ;o0000o`000?nGKZ;o0000oiM^
XP?o000000?oUfnRo`000?nGKj805ol00004ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000?ooooo`002Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`000003oo2^QOl0003ol:j500;o0000
00Gol:j4o`000?o0W;Co0000ol2M]@02o`000005oknP^Ol0003o_j6jo`000?noXKX01Ol000001onn
YKoo0000okjU`?l0003o_ZG0o`000?nnY/401Ol000000onmZLGo0000okfYa@02o`000003okb[b?l0
003o000000?o000000?o^jg<o`000?nk[L`00_l000000onj[/ko0000okZ_c`03o`000003okV`dOl0
003o^;3A00;o000000?o^;7Co`000?l000000ol000001_ng/]Go0000o`000?nf/mKo0000okJcePKo
000000?o];CIo`000?l000000_l000000onc]=[o0000o`000004o`000004ok6efol0003o0000ok2e
g0Ko000000Ko[kGMo`000?l0003okk^Jo`000?o_^iXko`000003ojfliOl0003o000000Oo000000Oo
m<>Jo`000?l0003o0000ooC3V_l0003om<>J00Go000000GomLBJo`000?l0003o0000oiM^XP03o`00
0003oiM_X_l0003oUfnR00;o000000OoUfnSo`000?l0003o0000oiQ_Xol0003oV6nS00oo00000ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000003oooool000Sooooo
0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool7o`00
000;oo2^Q?l0003o`9bdo`000?o0WKGo0000ol2M]Ol0003o`9jfo`000?o0W[L00_l000002_o0WkSo
0000o`000?noX[co0000oknS_?l0003o_j>mo`000?noY;h3o`000005okjV`_l0003o_ZO2o`000?nn
Yl<00_l000001?nmZLKo0000o`000?nmZ/L2o`000005okb/bOl0003o^jc:o`000?nk[</01Ol00000
1_nj[/ko0000o`000?ni[m3o0000okV`d0?o000000Ko^;7Bo`000?l0003o]k7Co`000?ng/]@6o`00
0003okFceol0003o]K?G00;o000000?o];CHo`000?l000001_l000000onb]=[o0000o`000004o`00
0004ok2eg?l0003o0000ok2eg0;o000000?o[kGMo`000?l000001_l000000on?Hi[o0000o`000004
o`000003oib/h_l0003o000000;o000000?oUZOQo`000?l000005?l000000olC9J;o0000o`00000C
o`000003ojfliOl0003o000000Oo000000?o[;cUo`000?l000002_l000001?oea9[o0000o`000?oe
a9X2o`000005ooG5V_l0003o0000o`000?nGKj<00ol000000onHKj?o0000oiQ_X`02o`000007oiQ`
Xol0003o0000o`000?nHL:Co0000oiQ`Y006o`0000Cooooo0_l00009ooooo`?o00004?ooool000Wo
oooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`Wo000000Oo`9V`o`000?o0
V[3o0000ol2J/Ol0003o`9^b00Go000000Oo`9nho`000?o0X;So0000ol2P^Ol0003o_j6j00Go0000
00Go_jFoo`000?noYKoo0000okjU`002o`000006okjX`ol0003o0000okfXa?l0003o_JW50_l00000
0onlZlSo0000o`000003o`000005ok^]bol0003o^jg<o`000?nk[L`01_l000000oni/=7o0000okV`
d@05o`000004okNadol0003o0000okNbe@So000000Ko];?Ho`000?l0003o/kCIo`000?nc]=T4o`00
0003ok:dfol0003o/KCK00;o000000?o/KCKo`000?l000001?l000000on_]=go0000o`000004o`00
0005ohmSV_l0003o0000o`000?n?HiX0@?l000000on/_>Go0000o`000007o`000005ojbmi_l0003o
0000o`000?oea9X00_l000001?oeaI[o0000o`000?ofaIX2o`000004ooK5V_l0003o0000ooK6VP?o
000000OoV72So`000?l0003o0000oiQ`Y?l0003oV72T00;o000000CoV76To`000?l0003o00008_oo
ool001_ooooo2?l000001_o0UZ_o0000o`000?o0V[3o0000ol2J/@Co000000Oo`9bco`000?o0W;?o
0000ol2M]?l0003o`9fe00Go000000Go_j:ko`000?noX[_o0000oknS_002o`000003okjU`?l0003o
000000;o000000?o_ZO2o`000?nnYl800_l000001?nmZLGo0000o`000?nmZ/H2o`000005okb/bOl0
003o_:c:o`000?nl[<X00ol000000onj[/go0000okZ^c@02o`000003okV_col0003o000000?o0000
00?o^;7Bo`000?nh/M800_l000001ong/]Co0000o`000?l0003o][;Fo`000?nf/]H00_l000000one
/mOo0000o`000004o`000003ok>dfOl0003o000000Wo000000Co/;CLo`000?l0003o[kCL1ol00000
0on?Hi[o0000ohmSVP03o`000003ohmSVol0003o000001Co000000?o?e>no`000?l000009Ol00000
0on/_>Go0000o`000007o`000003ojbmi_l0003o000000So000000Com/FJo`000?l0003om/JJ0_l0
00000oofaY[o0000ooK6VP03o`000005ooK6V_l0003o0000o`000?nHLJ@01?l0000Qooooo`006ooo
ool8o`000005ol2FZol0003o`9J/o`000?o0Uj`00_l000000oo1V:ko0000ol6I[P02o`000003ol2L
/ol0003o`9fd00Co000000Oo`9jfo`000?o0WkOo0000ol2P^?l0003o`:2h00Go000000Go_jBno`00
0?noYKko0000oknU_`02o`000006okjW`ol0003o0000okjXa?l0003o_ZW40_l000000onmZlOo0000
o`000003o`000005ok^]bol0003o^jg<o`000?nk[L`00ol000000onj[loo0000okZ_c`02o`000003
okV`dOl0003o000000?o000000Co]k7Co`000?l0003o][;E1Ol000001?ne/mOo0000o`000?nd/mP6
o`000003ok:df_l0003o000000;o000000?o/KCKo`000?l000001ol000000oo^^Y[o0000onjjVP06
o`000003ohmSVol0003oSV>K02_o000000?o[KcUo`000?l000006_l000000on/_NKo0000o`00000B
o`000004ooK6V_l0003o0000ooO7V@;o000000?oV76To`000?l000008Oooool001_ooooo0_l00000
0oo`[XGo0000oo2^Q@02o`000003ol2AY_l0003o000000Go000000Go`IR^o`000?o1VJko0000ol6I
[`04o`000005ol6K/Ol0003o`Ibbo`000?o1W;<00_l000000oo0X;So0000ol2P^002o`000005ol2Q
^_l0003o`::jo`000?o0X[/00_l000000onoYKoo0000o`000002o`000003oknV`Ol0003o_ZO200;o
000000Ko_JW5o`000?l0003o_J[6o`000?nmZ/L2o`000003okb/bOl0003o000000?o000000Go^jk=
o`000?nj[/go0000okZ^cP03o`000006okV`d?l0003o0000okRad_l0003o^;7B0ol000001_ng/]Co
0000o`000?nf/]Ko0000okJbePKo000000Co/k?Ho`000?l0003o/[CI3Ol000000oo^^Y[o0000onjj
VP05o`000004onjjVol0003o0000ohiSV`;o000000?oSV:Ko`000?l00000:?l000000on]_>Go0000
o`00000Jo`000003ojbmi_l0003o000001[o00008?ooool001_ooooo0_l000000oo`[XGo0000oo2^
Q@02o`00000<ol2AY_l0003o0000ol2CYol0003o`9>Xo`000?o1U:Wo0000ol6EZOl0003o`IFZ0_l0
00002_o1Ujco0000o`000?o1Vk7o0000ol6L/_l0003o`Ibco`000?o1WK<4o`000003ol6O]_l0003o
`Ing00;o000000?o`::ko`000?l000000_l000001OnoY;go0000oknT__l0003o_jFn00Go000000?o
_ZS4o`000?nnZL@00_l000001?nmZlOo0000o`000?nlZlP2o`000003ok^]bol0003o^jg<00Go0000
00?o^Zo?o`000?nj[ll00_l000001oni/=7o0000o`000?l0003o]k7Co`000?ng/M<00_l000001onf
/]Go0000o`000?l0003o]K?Fo`000?ne/mL00_l000001Ond/mSo0000o`000?l0003o/[?I013o0000
00Kok[ZJo`000?l0003ok[ZKo`000?o^^Y/3o`000004ohiRVol0003o0000oheRVbWo000000?o[KcU
o`000?l000001ol000000on]_>Go0000o`00000/o`0001oooooo000Kooooo`[o000000Go`9>Wo`00
0?o0TjSo0000ol6DZ@06o`000009ol6G[?l0003o`IR]o`000?o1V:ko0000ol6I[_l0003o`IZ_00;o
000000So`I^ao`000?l0003o`Info`000?o1WkOo0000ol6P]`;o000000Go`:6io`000?o0X[[o0000
ol2R^P02o`000008oknU__l0003o0000oknV`?l0003o_jK1o`000?noYl42o`000006okjYaOl0003o
0000okfZa_l0003o_J[60_l000001?nl[<Wo0000o`000?nl[L/2o`000003ok^^cOl0003o^Zk=00Go
000000Co^K3@o`000?l0003o^;7B1Ol000000onf/]Co0000o`000006o`000003okBcf?l0003o0000
00oo000000OoY:gMo`000?l0003o0000onjjVol0003ok[ZK00?o000000KoSV:Ko`000?l0003oSF:K
o`000?n<HI/Ro`000003ojjli?l0003o000000Co000000?o[KcUo`000?l000001ol000000on]_>Go
0000o`00000Zo`0001oooooo0005ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`Ko0000
00Wo_hbPo`000?noSJ7o0000okn>X_l0003o`8nSo`000?o0T:<00_l000001Oo0TJGo0000ol6BY_l0
003o`I>W00;o000000?o`IR]o`000?o1V:h01_l000001oo1Vk7o0000ol6L/_l0003o`Ibbo`000?o1
WK<00_l000000oo1W[Go0000ol6O]P02o`000003ol2R^_l0003o000000;o000000Go`:Bmo`000?o0
Y;go0000ol2U_P05o`000003okjX`ol0003o_ZW400;o000000Ko_J_7o`000?l0003o_J_8o`000?nl
[<T2o`000004ok^]c?l0003o0000ok^^c@;o000000?o^Zo?o`000?nj[ll00ol000000onh/=7o0000
okRadP02o`000005okNadol0003o0000o`000?nf/]D02?l000000onc/mSo0000o`000004o`000004
ojV_g?l0003o0000ojN^g@?o000000?oY:cMo`000?l000001Ol000000oo^^Y_o0000onfjW003o`00
0003ohaQVol0003o000000[o000000?o<TNho`000?l00000@?l000000on/_NKo0000o`00000?o`00
01kooooo0006ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`Ko000000Wo_hbPo`000?noSJ7o0000okn>X_l0003o`8nSo`00
0?o0T:<00_l000002Oo0TJGo0000ol6BY_l0003o`I>Wo`000?o1TjSo0000ol6DZ002o`000009ol6F
Z_l0003o`IN[o`000?o1Ujco0000ol6H[Ol0003o`YV^00Go000000Go`Ijeo`000?o1WkKo0000ol6O
]`02o`000005ol6Q^?l0003o`J:io`000?o1X[X00_l000002?o0YKko0000o`000?noY/3o0000oknV
`Ol0003o_jO11Ol000000onnZ/Ko0000okfZa`05o`000003okb]bol0003o_:g;00So000000?o^K3@
o`000?l000000ol000000ong/M?o0000o`000009o`000003ok>bf?l0003o000000ko000000OoX:WM
o`000?l0003o0000onjjVol0003okKZL00;o000000Gok;VLo`000?l0003o0000ohUOV`05o`000003
oeY_cOl0003o000003?o000000?o[;gUo`000?l000004?l000000on/_NKo0000o`00000>o`0001go
oooo0007ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`Go000000Go_HNJo`000?nnR9_o0000okj9W006o`000005okn<Wol0003o
`8fQo`000?o0SZ400_l000000oo1TjSo0000o`000002o`000007ol6FZ_l0003o`IN[o`000?o1Ujco
0000ol6H[@04o`000007ol:J/?l0003o`Y^ao`000?o2W;;o0000ol:M/P02o`000003ol:N]?l0003o
`Ine00;o000000?o`J:jo`000?l000000_l000000oo0Y;co0000ol2T_@05o`000005oknX`ol0003o
_ZS3o`000?nnZL@00ol000001OnmZlSo0000okf/b?l0003o_:c900?o000000?o^jk<o`000?nk[/d0
0_l000001?nj[loo0000o`000?ni/=08o`000004okJae?l0003o0000okFbePgo000000?oYjgLo`00
0?l000001Ol000000onOZ=go0000o`000002o`000004onfjW?l0003o0000onbiW0?o000000?oREnK
o`000?l000008Ol000000on^_>Co0000o`00000Go`000003ojbmiOl0003o0000023o00007?ooool0
00Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool5o`000005okf7V_l0003o_XRKo`000?nnRI`00_l000002onoRiko0000
okn<Wol0003o_hbOo`000?o0SJ7o0000ol2>XOl0003o`8nR00;o000000Wo`I6To`000?o1TZGo0000
ol6CY_l0003o`I>Wo`000?o2U:P00_l000001Oo2UZ[o0000ol:GZol0003o`YR/00;o000000?o`Ybb
o`000?l000000_l000001Oo2W[Co0000ol6O]Ol0003o`Inf00;o000000Go`J6ho`000?o1X[Wo0000
ol6R^P02o`000006ol6S^ol0003o0000ol2V_ol0003o_jO01Ol000000onnZ/Go0000okjZaP05o`00
0003okb]b_l0003o_:g;00Go000000?o^Zo>o`000?l000001_l000000ong/M?o0000okNad`03o`00
0003okFaeOl0003o000000?o000000Co[:oJo`000?l0003oZZkK5Ol000001Oo[^9go0000o`000?l0
003oQUfJ01_o000000?o[[cTo`000?l000001?l000000on^_>Co0000o`000004o`000003ojfliOl0
003o000001Oo000000?o[;gVo`000?l000004?l000000on/_NKo0000o`000004o`0001cooooo0005
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo0_l000002?o`[XGo0000o`000?nmQi[o0000okj8Vol0003o_XVL0_l0
00002onoRiko0000okn<Wol0003o_hbOo`000?o0SJ7o0000ol2>XOl0003o`8nR00;o000000Wo`I6T
o`000?o1TZGo0000ol6CY_l0003o`I>Wo`000?o2U:P00_l000001Oo2UZ[o0000ol:GZol0003o`YR/
00Co000000Oo`YZ_o`000?o2Vk3o0000ol:L/Ol0003o`Ybb00;o000000?o`Yjdo`000?o2WkD00_l0
00002?o1X[[o0000o`000?o1Xk_o0000ol6T_?l0003o`:Fm0_l000001_o0Y[oo0000o`000?noZ<?o
0000oknY``;o000000?o_ZW5o`000?nnZ/H00_l000001?nm[<Wo0000o`000?nl[LX4o`000007ok^^
cOl0003o0000o`000?ni[m3o0000okV`d002o`000003okR`d_l0003o000000?o000000?o][7Do`00
0?l000003?l000001OnTZmco0000o`000?l0003oX:SL00Go000000?oUZ7Lo`000?l000000_l00000
1Oo[^9go0000onZgW_l0003oQUfJ00Go000000?o=dblo`000?l000005Ol000000on^_>Co0000o`00
0004o`000003ojjli?l0003o000000Co000000?o[KcUo`000?l00000<?l0000Kooooo`001Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`co000000?o_h^No`000?noS9l02Ol000001Oo0S9oo0000ol2=Wol0003o`HjQ
00Ko000000Go`Y:Uo`000?o2TjKo0000ol:DY`02o`000008ol:FZOl0003o0000ol:J[ol0003o`Y^`
o`000?o2W;44o`000003ol:N]?l0003o`Yne00Co000000?o`Z6ho`000?o1X[T01?l000001_o1Y;co
0000o`000?o0Y/3o0000ol2W`@;o000000?o_jS2o`000?noZ<<00_l000000onnZlKo0000o`000005
o`000004okb]bol0003o0000ok^^c0;o000000?o^Zo?o`000?l000000ol000000onh/=;o0000okN`
dP07o`000004ojb^fOl0003o0000ojZ]fP;o000000?oZ:cKo`000?l000004Ol000001OoZ]iko0000
o`000?l0003oPe^J02_o000000?o[KcUo`000?l000001?l000000on]_>Go0000o`00000Go`000003
ojbmi_l0003o000000go00006oooool000Kooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo
3?l000001OnmQISo0000okf6VOl0003o_XNJ00;o000000_o_hVLo`000?noRYgo0000okn;W_l0003o
`8bOo`000?o0SIoo0000ol6>X@02o`000009ol6@Xol0003o`I6To`000?o2TZGo0000ol:CY_l0003o
`YBW00;o000000Oo`YJYo`000?o2Uj[o0000ol:HZol0003o`YR/00;o000000Go`YZ^o`000?o2Vjoo
0000ol:L/@02o`000005ol:M/ol0003o`Yjdo`000?o2WkD00_l000001_o2XKOo0000o`000?o1Y;co
0000ol6T_0Co000000?o`:Joo`000?o0Yl001ol000000onnZ/Ko0000o`000003o`000003okb]b_l0
003o_:g;00?o000000?o^Zo>o`000?nj[ll02Ol000001?n^[]So0000o`000?n/[]T8o`000005ojBZ
fol0003o0000o`000?nOYm/01Ol000000onDW]_o0000o`000006o`000003onNdX?l0003o000000;o
000000?o<DNio`000?l000005ol000000on__>?o0000o`00000Ko`000003ojfmiOl0003o000001oo
00006_ooool001Wooooo2?l000002OnlPYKo0000okb3Uol0003o_HFHo`000?nmQYWo0000okj7VP02
o`00000;okn9W?l0003o_hZMo`000?noRiko0000ol2<Wol0003o`8fOo`000?o1SZ400_l000001?o1
T:?o0000o`000?o1SIl6o`000006ol:AY?l0003o0000ol:GZ_l0003o`YR[1?l000000oo2VZko0000
ol:K[`04o`000005ol:M/ol0003o`Yjdo`000?o2WkD00_l000001Oo2XKOo0000ol:Q^?l0003o`Z:i
00;o000000Go`J>ko`000?o1Y;co0000ol6U_@05o`000003oknX`ol0003o_jW300?o000000?o_J_7
o`000?nm[<P01Ol000000onk[/co0000ok^^c@03o`000003okV_d?l0003o^Jo@00Go000000?o[ZkG
o`000?l000000_l000001?nZ[MWo0000o`000?nX[=X3o`000005ojBYfol0003o0000o`000?nNY]/0
1Ol000000onCWM_o0000o`000005o`000003onNdX?l0003o000001Oo000000?o[kcSo`000?l00000
1?l000000on__>?o0000o`00000[o`000003ojbmi_l0003o000000ko00002?ooool2o`0000Cooooo
00?o0000ooooooooool00oooool3o`0000;ooooo000Iooooo`Co000000_o^X2Do`000?nkPIGo0000
okb2U_l0003o_8>Go`000?nmQISo0000okf6V@04o`000005okn9W?l0003o_hZMo`000?noRih01ol0
00001Oo0Rigo0000ol2<W_l0003o`HfO00;o000000Wo`HnRo`000?o2T:?o0000ol:AY?l0003o`Y:U
o`000?o2TjH00_l000001Oo2UZSo0000ol>GZOl0003o`iR[00;o000000Oo`iV]o`000?o3VZko0000
ol>K[ol0003o`ib`00;o000000Go`ijco`000?o3WkCo0000ol:O]@02o`000004ol:Q]ol0003o0000
ol6T_0Co000000?o`JJoo`000?o0Yl001Ol000000onnZ/Go0000okjZaP02o`000003okf[aol0003o
_Jc800;o000000Co_:g;o`000?l0003o^jk<0_l000001?ni[loo0000o`000?nGJI/9o`000003ojZ/
fOl0003o0000037o000000?o[kcSo`000?l000001?l000000on__>?o0000o`00000jo`0000Oooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`01ooooo`006Oooool4o`000003okZ0
U?l0003o^h6E00_o000000Go_8>Fo`000?nmQ9Oo0000okf5V002o`00000;okj7V_l0003o_hVKo`00
0?noRYco0000ol2;WOl0003o`8bNo`000?o1SIl00_l000001Oo1Sj;o0000ol:@Xol0003o`Y6T00Ko
000000Go`YJXo`000?o3UjWo0000ol>HZ`02o`000005ol>I[Ol0003o`iZ^o`000?o3Vjl01?l00000
0oo3W[?o0000ol>O]004o`000003ol:Q]ol0003o000000Co000000?o`ZBko`000?o1YK`00_l00000
1_o1Y[ko0000o`000?noZ<;o0000oknY``;o000000?o_Z[5o`000?nnZ/H01Ol000000onl[L[o0000
okb]b`06o`000003ok2]eOl0003o/:gE00So000000?oZ:_Io`000?l000001Ol000000onMYM[o0000
o`00000>o`000003ogUCV?l0003o000001Oo000000?o/;cSo`000?l000002?l000000on^_>Co0000
o`000004o`000003ojjli?l0003o000001Co000000?o[KgUo`000?l000005ol00006ooooo`04o`00
0?ooooooooooo`0000Oooooo1Ol00002ooooo`006Oooool01Ol0003oLCAdo`000?l0003o^X2D00go
000000Go_8>Fo`000?nmQ9Oo0000okf5V002o`000005okj7V_l0003o_hVKo`000?noRY`01ol00000
1Oo0RYco0000ol6<WOl0003o`HfN00;o000000Wo`XnQo`000?o2T:;o0000ol:AXol0003o`Y:To`00
0?o3TjH00_l000001Oo3UZSo0000ol>GZOl0003o`iR[00;o000000Go`iZ]o`000?o3Vjko0000ol>L
[`02o`000005ol>M/_l0003o0000o`000?o3Wk@00_l000001Oo3XKOo0000ol:R^?l0003o`Z:i00?o
000000Go`JJno`000?o1Ykoo0000ol2W`002o`000003oknX`_l0003o_jW300?o000000?o_J_7o`00
0?nm[<P03_l000001?n^[=Ko0000o`000?n/[=L3o`000003ojRZf?l0003o000001Co000000?oh:jS
o`000?l00000<ol000000on]_NGo0000o`00000Do`000003ojbmi_l0003o000000go000000?ooooo
o`000?ooool01?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000?ooooo
000Iooooo`03o`000?ma=7Co000000go000000Oo^h6Eo`000?nlPiKo0000okf4Uol0003o_HFH00;o
000000Go_XNJo`000?noRI_o0000okn:W007o`000005ol2:W?l0003o`HbMo`000?o1SIh00_l00000
1oo2Sj7o0000ol:@X_l0003o`Y6So`000?o2TZ@01?l000000oo3UZSo0000ol>GZ@04o`000004ol>J
[Ol0003o0000ol>HZ`Co000000?oa9^_o`000?o3W;000_l000001_o3W[;o0000o`000?o2X[So0000
ol:R^@;o000000?o`ZBko`000?o2YK`01?l000000oo1Ykoo0000ol2W`003o`000003okjZaOl0003o
_Z[600;o000000Co_J_7o`000?l0003o_:g:1?l000001?nb[=;o0000o`000?n`[=@2o`000003ojj/
eOl0003o000000Ko000000?oY:SIo`000?l000000_l000000onLXm[o0000o`00001[o`0000Gooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`000003ooooo`001Oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool8o`00000;okQkTOl0003o^GfBo`000?njOY?o0000ok^0U?l0003o
^h6Eo`000?nlPiH01Ol000001OnkPICo0000okb2UOl0003o_HBF00;o000000_o_XJIo`000?noR9[o
0000okn9Vol0003o`8ZLo`000?o1S9go0000ol6=WP03o`000003ol6;W?l0003o`HfN00Co000000Go
`Y2Ro`000?o3TJ?o0000ol>CY002o`000005ol>EYol0003o`iJXo`000?o3UjT01?l000000oo4VZgo
0000olBK[`04o`000003ol>N/_l0003o`inc00Co000000?o`j:go`000?o3X[P00_l000001Oo2Y;_o
0000ol:U_?l0003o`ZFm00?o000000?o`:S2o`000?noZL<00_l000000onnZ/Go0000okjZaP05o`00
0003okB/dOl0003o/jcA00Oo000000Go[:_Fo`000?l0003o0000ojRYf002o`000003ojBWf?l0003o
000000;o000000?oW:;Io`000?l000007ol000001Onb^n7o0000o`000?l0003o/K_Q00[o000000?o
[kcSo`000?l000006?l000000on]_NGo0000o`00000Oo`0000Cooooo00Co0000oooooooooooo0000
2Oooool2o`0000?ooooo0004ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo1_l000002onfNY3o0000okQkTOl0003o
^GfBo`000?njOY?o0000ok^0U?l0003o^h6E00Oo000000Go^h6Do`000?nlPYGo0000okf4UP02o`00
0005okj6VOl0003o_hRJo`000?noRI/01ol000001Oo0RY_o0000ol6;W?l0003o`HfN00;o000000Oo
`XnPo`000?o2T:;o0000ol>AXol0003o`i>T00;o000000?o`iFWo`000?o3UZP01Ol000000oo4UjSo
0000olBHZP02o`000005olBJ[Ol0003oa9^^o`000?o4W:l00_l000001Oo4W[;o0000olBO/ol0003o
`j2d00;o000000?o`j:go`000?o3X[P01Ol000000oo1Ykoo0000ol6W`002o`000003ol2X`_l0003o
_jW300Oo000000Go]:c@o`000?l0003o0000ok6[dP02o`000004ojn[e?l0003o0000ojbZeA[o0000
00?of:RUo`000?l000004Ol000001Onb^n7o0000o`000?l0003o/KcQ00?o000000?o/;cRo`000?l0
00001?l000000on__>?o0000o`000008o`000003ojjli?l0003o000002go00001Oooool2o`0000_o
oooo00?o0000ooooooooool00Oooool000Sooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooooooo`Go000000Wo]GR?o`000?nfNY3o0000okQk
TOl0003o^GfBo`000?njOY<02ol000001OnkPICo0000okb2UOl0003o_HBF00;o000000?o_XJIo`00
0?noR9X01ol000001oo0R9[o0000ol2:Vol0003o`H^Lo`000?o1SIh00_l000001?o2Sj3o0000o`00
0?o2SId4o`000005ol>AXOl0003o0000o`000?o3Tj@00_l000000oo4UZOo0000olBGZ004o`000005
olBJ[Ol0003oa9^^o`000?o4W:l00_l000000oo4W[;o0000olBO/`04o`000003ol>R]ol0003o`j:h
00;o000000?o`ZBko`000?o2YK`01?l000000oo1Ykoo0000ol6W`00:o`000004okB[d?l0003o0000
ok:[d@So000000CoZ:SGo`000?l0003oY:KG1?l000000onJX=So0000o`00000;o`000003ocmA_Ol0
003o000002Oo000000?o[kcSo`000?l00000<ol0000Eooooo`001_ooool2o`0000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`?o000000Oo]7J>o`000?neN8oo
0000okIjT?l0003o^7^A00_o000000Oo^GfBo`000?njOi?o0000ok^1U?l0003o_8:E00Go000000?o
_86Do`000?nmPYD00_l000001OnnQYOo0000okn7VOl0003o`8RJ00Oo000000Go`HZKo`000?o1Rico
0000ol:=W@06o`000003ol>BXol0003o`i>T00?o000000[oa9>So`000?l0003oa9FVo`000?o4UZOo
0000olBHZOl0003oa9V[0_l000000oo4Vjgo0000olBL[`02o`000005olBN/Ol0003oa9nco`000?o4
X;@00_l000000oo3X[Oo0000ol>S^002o`000005ol:T^ol0003o`ZFlo`000?o2Y[d01ol000001?nh
Z/co0000o`000?neZlh2o`000005ok>[d?l0003o0000o`000?n`Z]800_l000001On]ZMCo0000o`00
0?l0003oZ:OF00oo000000?oLX3Bo`000?l000005?l000000onc^moo0000o`00000Ro`000003ojjm
i?l0003o000002Oo00005?ooool000Sooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`0:o`000?ooooooooooooooool0003oLCAdo`000?ndMXko0000okEhS`go0000
00Oo^7^Ao`000?niOI;o0000okYoTol0003o^h6D00Go000000Go^gnCo`000?nlPICo0000okf2U@02
o`000005okj6Uol0003o_hNIo`000?o0R9X01ol000000oo1RY_o0000ol6;W004o`000004ol>?X?l0
003o0000ol:=W@Co000000?o`i6Ro`000?o4Tj<00_l000001Oo4UJKo0000olBFYol0003oa9RY00Co
000000?oa9^]o`000?o4W:l00ol000000oo5W:ko0000olBM/002o`000003olBO/ol0003oa:2d00;o
000000Co`j:go`000?l0003o`ZFl1?l000001oo1Ykoo0000oi]/Vol0003o^JW:o`000?nhZL/01_l0
00001?ncZ]3o0000o`000?n`ZM88o`000003oj>Ue_l0003o000000?o000000?oUI_Go`000?l00000
2Ol000000oljC[co0000o`00000jo`000003ojjmiOl0003o000002;o00004oooool000Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000oooool01?l0003oLCAdo`000?ndMXh=o`000005okMjT?l0003o^7^Ao`000?niOI802Ol0
00001OnkOi?o0000okb1U?l0003o_H:E00;o000000?o_XJGo`000?noQiT01Ol000001OnoQiSo0000
ol28VOl0003o`HZK00Go000000Go`HZJo`000?o2S9co0000ol:=W@02o`00000;ol>@X?l0003o`i6R
o`000?o4Tj?o0000olBAXOl0003oa9:Ro`000?o4Tj@00_l000001Oo4UZOo0000olFGZ?l0003oaIVZ
00;o000000?oaI^]o`000?o5W:h01?l000000oo4Wk?o0000olBP]002o`000003ol>R]ol0003o`j>h
00;o000000?o`jBko`000?o2YK`01Ol000001OnjZLSo0000o`000?l0003o]jW<00;o000000?o]:[>
o`000?l000001?l000001On]Z=;o0000o`000?l0003oZ:KE00?o000000?oXJ?Fo`000?l000004?l0
00000oo:W:So0000o`00000Qo`000005ok2lh_l0003o0000o`000?n`_><0=_l0000Cooooo`001Ooo
ool3o`0000Cooooo0_l00004ooooo`;o00001?ooool00ol0003oLCAdo`00000<o`000005okEhSol0
003o]gZ@o`000?nhNi402Ol000001oniOI7o0000ok]oTol0003o_86Do`000?nmPYD00_l000001?nn
QYOo0000o`000?nlPY@2o`000003okj5Uol0003o_hNH00Wo000000Go`HZJo`000?o2S9co0000ol:=
W@02o`000003ol>@X?l0003o000000?o000000Goa96Qo`000?o4TZ;o0000olBCY002o`000003olBF
Yol0003oaINX00Go000000SoaIVYo`000?l0003oaI^]o`000?o5W:ko0000olFM/0;o000000?oa9nc
o`000?o4X;@00_l000000oo4X[Oo0000ol>S^005o`000007ok^Xa_l0003o0000o`000?nhZL[o0000
okNYb`03o`000004okBYc_l0003o0000ok6Yd0;o000000?o[JSBo`000?l000004ol000000om8F/;o
0000o`00000Do`000005okBkgol0003o0000o`000?nc^n000ol000001Onb_>7o0000o`000?l0003o
/KcR00ko000000?o[kcSo`000?l00000;ol0000Booooo`006?ooool7o`000003okioSol0003o0000
00?o000000Go/gF>o`000?neN8oo0000okMjT009o`000007okQkT?l0003o^GfAo`000?nkOi?o0000
okb1U003o`000005okYnT_l0003o^h2Co`000?nlPY@00_l000000onnQIOo0000o`000007o`000003
ol68VOl0003o`HZJ00Go000000?o`X^Ko`000?o2S9`00_l000001Oo3Sioo0000olBAXOl0003oa9:R
00?o000000?oa9:Ro`000?o4Tj<00_l000001Oo5UZKo0000olFGZ?l0003oaIVY00;o000000?oaI^]
o`000?o5W:h01?l000001oo4Wk?o0000o`000?l0003oaJ2co`000?o4XK@02?l000001?nkYlGo0000
o`000?niZ<P3o`000004okFYc?l0003o0000ok:XcPOo000000GoZ:GCo`000?l0003o0000oj2Qe@0V
o`000003okBkgol0003o000004So00004_ooool001Oooooo2?l000002OnnOhoo0000o`000?l0003o
/G><o`000?ncMHko0000okEhS`09o`000005okIiSol0003o^7^@o`000?niOI401ol000001OnjOY;o
0000ok^0Tol0003o_8:D00Go000000So_H6Do`000?l0003o_hFFo`000?o0QiSo0000ol68V@Oo0000
00?o`X^Ko`000?o2S9`00_l000001?o3Sioo0000o`000?o3SYd2o`000005olBAX?l0003oa9:Ro`00
0?o4Tj<00_l000000oo5UZKo0000o`000003o`000003olFHZ?l0003oaIVY00;o000000?oaI^]o`00
0?o5W:h01?l000000oo5X;?o0000olBQ]005o`000003okfV`_l0003o_JK300;o000000Co^ZO6o`00
0?l0003o^JS80_l000000onfZ<_o0000o`000002o`000004ok2Wd?l0003o0000ojbVd@;o000000?o
Z:CCo`000?l000003_l000000om6F<7o0000o`00000Vo`000003ok6lh_l0003o000003Wo00004Ooo
ool001Oooooo2?l000001onnOhoo0000okMhSOl0003o/G><o`000?ncMHh02ol000000onfNHoo0000
okQkT009o`000003okYnT_l0003o000000Go000000?o^gnBo`000?nmPI@00_l000001OnoQIKo0000
ol27V?l0003o`HRI00Go000000?o`HVIo`000?o2Ri/01Ol000000oo3S9_o0000ol>>W@02o`000003
olBAX?l0003oa9:R00?o000000?oaI:Qo`000?o5Tj<00_l000001Oo5UZKo0000olFHZ?l0003oaIVY
00;o000000WoaI^]o`000?l0003o0000olJL[Ol0003oaIf^o`000?o5W[000_l000001_o5X;?o0000
o`000?noY;ko0000okjU`0Go000000Co^ZO6o`000?l0003o^:S90ol000001?ncYlco0000o`000?n`
Yll9o`000003oibMe?l0003o000003So000000Go/;cSo`000?l0003o0000ok2mh`0bo`00013ooooo
000Gooooo`03o`000?ma=7Co000000Go000000Go_Wn?o`000?ngN8go0000ok5cS007o`000007ok]m
S_l0003o0000o`000?ndMXko0000okIiS`09o`000005okQkT?l0003o0000o`000?nkP9<00ol00000
1OnjOI7o0000ok]oT_l0003o_H6D00;o000000?o_hFFo`000?o0QiP01Ol000000oo0QiSo0000ol69
V@05o`000005ol::V_l0003o`hbKo`000?o3SYd00ol000002?o3SIco0000o`000?o4T9oo0000olFB
XOl0003oaI>S0ol000000oo5U:?o0000olFEY002o`000003olJHZ?l0003oaYVY00;o000000?oaYb]
o`000?o5WJh02?l000001oo0Xkco0000o`000?l0003o_JK2o`000?nlY/<01Ol000001?ngYlSo0000
o`000?ndYl/4o`000004ojfUd?l0003o0000ojRSd@Co000000?oVicDo`000?l000001ol000000omD
I<Ko0000o`00000Po`000005ok>lh?l0003o0000o`000?nb_>404_l000000on__NCo0000o`00000Z
o`00013ooooo000Gooooo`03o`000?ma=7Co000000Co00000_nnOhl00ol0003o]gR=o`000008o`00
0005ok]mS_l0003o/gF=o`000?ndMXh03Ol000000onjOY;o0000o`000003o`000005okYmTOl0003o
^gnBo`000?nmPI@00_l000001?noQIKo0000o`000?nmPY<2o`000005okn6U_l0003o`8NHo`000?o1
RIT00ol000000oo1R9So0000ol::VP05o`000003ol><V_l0003o`hfL00;o000000?oa92Oo`000?o5
TZ400ol000001Oo5TZ7o0000olFDXol0003oaIFT00;o000000OoaYRXo`000?l0003o0000olJHZ?l0
003oaYZZ00;o000000?oaYb]o`000?o6WJl00ol000001oo1X[Wo0000o`000?l0003o_ZBoo`000?nn
YL000ol000000onjY/Go0000okVVaP06o`000004ok6VcOl0003o0000ojfTcbgo000000Go][_Mo`00
0?l0003o0000okBkg`15o`00013ooooo0004ooooo`?o00000oooool2o`0000Cooooo0_l00005oooo
o`Oo00000_nnOhl;o`000005ok]mS_l0003o/gF=o`000?ndMXh01Ol000001onjNhko0000o`000?l0
003o]gV?o`000?nhNi001ol000000onjOI7o0000ok]oTP05o`000003ok]oT_l0003o_H:C00;o0000
00?o_hJFo`000?o0QiP00ol000001Oo0QYOo0000ol68V?l0003o`XZJ00Go000000?o`hbJo`000?o3
SI`00ol000000oo4SIco0000olB?W@02o`000003olFBXOl0003oaIBS00?o000000?oaYBSo`000?o6
UZ@00_l000000oo6V:So0000olJJZP02o`000003olJL[Ol0003o000000?o000000Ko`J:io`000?l0
003o`:>lo`000?noXkd3o`000003okbU`_l0003o^jG400?o000000?o]jK8o`000?neY/T02?l00000
0onUX=7o0000o`000004o`000003ohZ?d_l0003o000000?o000000?oDf?5o`000?l000003ol00000
1?nk^MSo0000o`000?nj^]T5o`000005okNkg?l0003o0000o`000?nf^mh05Ol000000ona_N?o0000
o`00000`o`0000oooooo0005ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol000001?o7R93o0000okioSonnOhl:o`00
00;o^gf>00?o0000ok=eSOl000002?l000000ondMXko0000okMiS`09o`000003okYmTOl0003o0000
00?o000000Go^WfAo`000?nkOi;o0000okf2T`02o`000004okn6U_l0003o0000okj2U0;o000000?o
`8JGo`000?o1R9P01Ol000000oo2RYWo0000o`000003o`000005ol>;V_l0003oa8fLo`000?o4Sid0
0ol000003?o5Sigo0000o`000?o5TZ7o0000olJDXol0003oaYJTo`000?o6U:?o0000olJFY@;o0000
00?oaYVXo`000?o6VZX01_l000000oo2XKSo0000o`000003o`000003okjT_ol0003o_JG100;o0000
00Co^jG3o`000?l0003o]jG70ol000001?nbY<_o0000o`000?n]Xld3o`000003ojBOd?l0003o0000
023o000000?o^[[Jo`000?l000000ol000000ong^mco0000o`00000Oo`000003ojnmi?l0003o0000
02Go00004?ooool000;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool6o`000003olN8T?l0003o_Wn?00?o000000?o/G><o`000?l000001Ol00002
ok]mSPWo000000?o^W^>o`000?ndMXh02Ol000000onhNY3o0000okYmT@05o`000005okYmTOl0003o
^gnBo`000?nmPY<00ol000000onlP9;o0000okj2U002o`000004ol26Uol0003o0000okn4U0;o0000
00?o`HRGo`000?o2RYT01Ol000000oo3Ri[o0000olB=W003o`000003olB=Vol0003oaHnM00;o0000
00?oaI:Qo`000?l000000ol000000oo6U:?o0000olJFY@02o`000003olJIZ?l0003o000000?o0000
00?o`ijbo`000?o3Wk@00_l000001_o2XKOo0000o`000?noXkco0000okjS_@;o000000Co_JC0o`00
0?l0003o^JG40ol000001?ndYLWo0000o`000?n`Y<`?o`000003of5^bOl0003o0000013o000000Co
_KSEo`000?l0003o_;WG1Ol000000oni^]_o0000o`000008o`000005okFlgol0003o0000o`000?nc
_>00>Ol00003ooooo`03o`000?oooooooooo00gooooo0002ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`Co000000GodI:A
o`000?l0003o0000okioS`03o`000003ok5cS?l0003o000000?o000000?oaHJ@o`000?nkOHh02Ol0
0002okYkSP03o`000?ndMXko000000Co000000Go_7f?o`000?l0003o0000okQjT007o`000003okYm
TOl0003o^gnB00?o000000Go^WfAo`000?nlP9;o0000okj2U003o`000003okf1Tol0003o_hBD00;o
000000?o`HRGo`000?o2RYT00ol000000oo2RISo0000ol>;VP05o`000003olB=Vol0003oaHnM00?o
000000KoaI2Mo`000?l0003oaY>Qo`000?o6U:<3o`000003olNEXol0003oaiNU00Co000000?o`ijb
o`000?o3Wk@00_l000000oo2XKOo0000ol6Q^@04o`000004okjS_Ol0003o0000ok^T`@;o000000Co
^JC4o`000?l0003o]JC71?l000001On[XLgo0000o`000?l0003oX9c@023o000000?o_;[Ho`000?nk
^]P02_l000000onf_=ko0000o`00000jo`0000Kooooo00?o0000ooooooooool03Oooool000?ooooo
00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000og4dM?l0003o0000om6BT@03o`000003okioSol0003o000000Oo000000?oaHJ@
o`000?nkOHh02Ol00002okYkSPOo000000?o_7f?o`000?neN8h02Ol000000onjOI7o0000o`000003
o`000005okYmTOl0003o_82Bo`000?nnPY@00ol000000onmPI?o0000okn4U002o`000009ol68Uol0
003o0000o`000?o1QiOo0000ol:9V?l0003o`h^J00?o000000?o`hbJo`000?o4SI/00ol000000oo5
SY_o0000olF@W@02o`000007olJCXOl0003o0000o`000?o6U:7o0000olNEX`03o`000005olNFY?l0
003o0000o`000?o4WJl00_l000000oo3W[?o0000ol>O]002o`000003ol6Q^?l0003o`:6i00Go0000
00?o^j?1o`000?l000001?l000001?naX/Wo0000o`000?n[X<`No`000003ol2hd_l0003o000000Ko
000000?o^k[Io`000?l000001?l000000onh^mco0000o`00000io`0000Wooooo00?o0000oooooooo
ool03Oooool000Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000oooool2o`000003omfNTOl0003odI:A00?o000000?o_Wn?o`000?l000002ol000000onc
MHgo0000o`000005o`0000;o^W^>1ol000000onlOHoo0000okEhSP07o`000003okQjSol0003o0000
00Go000000?o^WfAo`000?nlP9800ol000001OnkOY7o0000okf1Tol0003o_hBD00?o000000Ko_X>C
o`000?l0003o`HNGo`000?o2RIP3o`000003ol>9V?l0003o`hbJ00Go000000OoaHjKo`000?l0003o
0000olF>Vol0003oaY2M00;o000000OoaYBQo`000?l0003o0000olNDX_l0003oaiJT00?o000000Co
a9f_o`000?l0003o`ijc1?l000000oo1XKSo0000ol2Q^@02o`000003okjR_?l0003o_J:n00?o0000
00Co^:?3o`000?l0003o/j?72?l000000onJUloo0000o`00000Fo`000004ol:gd?l0003o0000oknh
d`;o000000?o_[WEo`000?l000001_l000000oni^m_o0000o`000008o`000003okFlgol0003o0000
02go00003?ooool00ol0003oooooooooo`0=ooooo`001Oooool00ol0003oooooooooo`02ooooo`;o
00001?ooool2o`0000Cooooo0_l000000ooMWY7o0000o`00000?o`000003ok]mS_l0003o/gF=00Go
000000?oa8F@o`000?njNhh01ol00002okamS`03o`000?neN8ko000000;o000000GoaXN@o`000?ni
Nhoo0000okQjS`07o`000003okYmTOl0003o000000?o000000?o^gjAo`000?nmPI<00ol000000onm
P9;o0000okj3T`02o`000004ol67Uol0003o0000ol25U0;o000000?o`hVHo`000?o3S9X00ol00000
0oo4S9Wo0000olF>V`03o`000003olF>Vol0003oaY2M00?o000000CoaY6No`000?l0003oaiBR1?l0
00001_o5VZ_o0000o`000?o5W:ko0000olBM/0;o000000?o`indo`000?o2WkH00_l000000oo0XKWo
0000oknQ^P03o`000003okZS`Ol0003o^J;200?o000000Go/Z77o`000?l0003o0000ojRMc00So`00
0003okjje_l0003o_K[G00go000000?o][cNo`000?l00000;?l0000?ooooo`03o`000?oooooooooo
00gooooo000Fooooo`Ko000000?oooooo`000?l000001ol000000ooATY7o0000o`000009o`000003
olB5T?l0003o^W^>00Oo00000_nlOHl5o`000003olJ7T?l0003o^G^?00Oo000000?o^7Z?o`000?nj
OI401Ol000000onkOY7o0000o`000003o`000003okf0T_l0003o_X>C00?o000000?o_X:Co`000?o0
QI@00_l000001?o3RISo0000o`000?o2QiH2o`000003olB<VOl0003o000000?o000000OoaHjKo`00
0?l0003o0000olJ?W?l0003oaY6N00?o000000?oai:No`000?l000001Ol000001_o5VZco0000o`00
0?o4WJoo0000olBM/@;o000000?o`Yneo`000?o1X;L00ol000000onmX[go0000ok^R_`03o`000004
okFQa?l0003o0000ojnOb1go000000CoaKK;o`000?l0003o`kO?2ol000000onk^mWo0000o`000004
o`000003okRlgOl0003o000000co000000?o/kgQo`000?l000007Ol0000Aooooo`03o`000?oooooo
oooo00gooooo000Fooooo`Oo000000?o_Wn?o`000?l000000_l000000oo^/Hko0000omnQT00;o`00
0005om6BTOl0003o0000o`000?njNhh01ol000000onlOHoo0000o`000004o`000003olJ7T?l0003o
^G^?00Oo000000?o^7Z?o`000?l000001Ol000000onkOY7o0000o`000003o`000003okf0T_l0003o
_X>C00?o000000?o_X:Co`000?o0QI@00ol000000oo0QICo0000ol:7UP03o`000006ol:8U_l0003o
0000olB<V_l0003oaHjK0ol000001oo6Sico0000olJAW_l0003oaY2Lo`000?o7TYh00ol000000oo6
V:So0000olJIZ@04o`000003olBM[ol0003oa9fa00;o000000?o`Yneo`000?o1X;L00_l000000ono
XK[o0000okjQ_003o`000004okRQ`_l0003o0000ok:PaPCo000000?oXi[;o`000?l000005_l00000
1?o7]<So0000o`000?o5]ld2o`000004ol:hd?l0003o0000ol2id`_o000000?o^KcKo`000?l00000
2?l000000one_Moo0000o`00000Oo`0001Gooooo00?o0000ooooooooool03Oooool001Kooooo2_l0
00001Oo_/Xoo0000onjaS_l0003ogj6@00_o000000GodI:Ao`000?l0003o0000okYkSP05o`000003
olR9T?l0003o_7f?00Ko000000?oaXN@o`000?niNhl00ol000001Oo=SY3o0000okj0Sol0003o^7Z?
00Go000000?o^G^@o`000?nkOY401Ol000003onmP9;o0000o`000?l0003o_7nAo`000?nnPY?o0000
ol25U?l0003o_X:Bo`000?o0QICo0000ol:7UP03o`000004ol:8U_l0003o0000olB<VP?o000000?o
aHfJo`000?o6Si`00ol000000oo6T9co0000olNBWP03o`000009olJHZ?l0003o0000o`000?o6VJWo
0000olJJZol0003oaI^]00;o000000?oa9f`o`000?l000000_l000000oo1WkKo0000ol2P^003o`00
0003okZQ_ol0003o000000Co000000Go[9g8o`000?l0003o0000oijFc009o`000003oaT_Z_l0003o
000000Wo000000CobK?4o`000?l0003oakG90_l000001?o4]lko0000o`000?o2^M42o`000003ol2j
e?l0003o0000037o00006Oooool00ol0003oooooooooo`0<ooooo`005Oooool9o`000005ooooool0
003okk:?o`000?o^/Hh01_l000000onkOHko0000o`000004o`000005om6BTOl0003o0000o`000?nj
Nhh01Ol000000oo8RI3o0000okamS`05o`0000;oaXN@1Ol000000oo=SY3o0000okj0S`07o`000003
okUkT?l0003o000000Go000000Oo_H2Bo`000?l0003o0000okaoTOl0003o_X:C00?o000000?o_X:B
o`000?o0QI@00ol000000oo1QICo0000ol:8UP03o`000004ol>8U_l0003o0000olF=VP;o000000Co
aHbHo`000?l0003oaY2L1?l000000oo6U:;o0000olJFY@02o`000003olJIZOl0003oaYZ[00Ko0000
00?oa9f`o`000?o3WK801Ol000001?nmX;_o0000o`000?niWkh2o`000005ok>O`ol0003o0000o`00
0?nXVlP06Ol000001?o9]<Ko0000o`000?o6]//Ao`000003okZlfol0003o000000Co000000?o]kgN
o`000?l000007_l0000Jooooo`03o`000?oooooooooo00cooooo000Eooooo`go000000?ok[6>o`00
0?l000001Ol000001Oo_/hko0000onncSOl0003ohJ>@00go000000?o_7f?o`000?l000000ol00000
0oo6Qi3o0000o`000004o`000003olf>T?l0003o_X2?00Go000000?o`8:@o`000?l000001Ol00000
0onjOI3o0000o`000003o`000003okaoTOl0003o000000?o000000?o_X:Bo`000?o0QI@00ol00000
0oo1QICo0000ol:8UP03o`000007ol>8U_l0003o0000o`000?o4RIOo0000olF<V003o`00000;olJ=
VOl0003o0000o`000?o6U:;o0000olJFYOl0003oaiJSo`000?o6UjH00_l000000oo6VZ[o0000olFK
[002o`000003olBM/?l0003o`ifb00;o000000?o`Info`000?noWkP00ol000000oniWkko0000okNO
`00Mo`000006ol^b`_l0003o0000olReaol0003ob;K90_l000001?o5^<go0000o`000?o3^M42o`00
0004ol6je?l0003o0000oknkePWo000000?o^KgMo`000?l000002?l000000ond_N7o0000o`00000A
o`0000Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`005Oooool3o`00
0004ooooool0003o0000ooooo`ko000000?okk>>o`000?o_/hd02ol000001OoHVI3o0000o`000?l0
003o_7f?00Go000000?oaXN@o`000?l000001?l000000oo=SY3o0000o`000005o`000003ol22T?l0
003o000000?o000000?o_X2@o`000?njOI001Ol000000onlOi7o0000o`000003o`000003okj2T_l0
003o000000?o000000Oo`HFDo`000?l0003o0000ol66U?l0003o`hRF00?o000000Ooa8VGo`000?l0
003o0000olF;Uol0003oaXfI00Co000000KoaY:Oo`000?l0003oaiJSo`000?o6UjH2o`000007olJJ
Z_l0003o0000o`000?o5VZ_o0000olFK[@02o`000003ol>M/Ol0003o`Yjc00?o000000?o_9nko`00
0?njWkd00ol000001OnaW<?o0000o`000?l0003oXiK801Go000000Koc[2mo`000?l0003obk?3o`00
0?o:]LD2o`000004olNgb_l0003o0000olFic`_o000000?o_;cIo`000?l000007ol00007ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00004ooooool0003o0000o`0000Co
oooo0_l00004ooooo`;o00001oooool02ol0003oooooo`000?l0003oooooo`000?oooooo0000onnb
Sol0003ok[6>00So000000?okk>>o`000?o_/hd05Ol000000oo6Qi3o0000o`000003o`0000;ocHj@
3Ol000000onnP93o0000o`000005o`000003okaoTOl0003o000000?o000000Go_X:Bo`000?l0003o
0000okn3TP05o`000007ol66U?l0003o0000o`000?o2QiCo0000olB9U`03o`000003olF;Uol0003o
000000;o000000?oaY2Mo`000?o6TYl00_l000001oo7UZ?o0000o`000?l0003oaiNUo`000?o6V:L0
0_l000000oo5VZ_o0000olFK[@02o`000003ol>M/Ol0003o`Yjc00;o000000?o_ijgo`000?nmW[T0
0ol000001?neWL3o0000o`000?n]V/@Io`000003olfb_ol0003o000000;o000000?ob[K7o`000?l0
00000_l000001?o6^Lgo0000o`000?o4^]42o`000003ol6ke?l0003o000001Go000000?o];kQo`00
0?l000002Ol0000:ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00005
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Oooooo00[o0000ooooooooooooooooo`000?oooooo0000onnbSol0003ok[6>0_l00000
0ooooooo0000ooooo`05o`000003onncSOl0003o0000017o000000?oeYN@o`000?o6Qi001Ol00000
0oo=SY3o0000o`00000<o`000003okj0T?l0003o000000?o000000?o^Wb@o`000?l000000ol00000
0onlOi7o0000o`000003o`000003okn3T_l0003o000000?o000000Oo`HJDo`000?l0003o0000ol:7
U?l0003oa8VG00?o000000?oaH^Go`000?l000000_l000001oo6T9go0000olJBWol0003oai:No`00
0?o7Tj000_l000001oo7UjGo0000olJHYol0003oaiRVo`000?o6VJP00_l000000oo5Vjgo0000olBL
[`02o`000003ol:M/ol0003o`9fe00?o000000?o^Ifmo`000?l000001_l000000onBRlSo0000o`00
000?o`000003om2^]ol0003od;2i00Co000000?oc;C3o`000?l000000_l000001?o8^<[o0000o`00
0?o6^/l2o`000004ol>kd_l0003o0000ol6le@;o000000Co_[cHo`000?l0003o_KgJ6Ol0000=oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool000Cooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l000000oo_/hko
0000o`000006o`000003ooooool0003o000000go000000?oaXN@o`000?l000000ol000000oo=SY3o
0000o`000002o`000003onRYS_l0003odI:A00Oo000000?o_X2@o`000?l000000ol000000onjO93o
0000o`000003o`000003okaoTOl0003o000000?o000000Go_h>Bo`000?l0003o0000okn3TP05o`00
0007ol:7U?l0003o0000o`000?o3R9Go0000olF;U`04o`00000;olJ@WOl0003o0000o`000?o7TYko
0000olNCX?l0003oai>Oo`000?o7UJ800_l000000oo7V:Ko0000olJIZ002o`000005olFK[Ol0003o
a9b_o`000?o4Vjl01Ol000001?nlWKWo0000o`000?ngW;d3o`000003ojRGa?l0003o000000Ko0000
00?o=dNfo`000?l000003Ol000000oo?/Kco0000o`000002o`000003olbfaOl0003obkO700;o0000
00?ob;W<o`000?l000003ol000000onj_Mco0000o`00000?o`00017ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0<ooooo`001?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool01oooool2o`0000Wooooo00Oo0000ooooool0
003o0000onncS_l0003okk>=00Co000000Goooooo`000?oooooo0000oo2cS@0Co`000003olf>T?l0
003o000000;o000000?oj:V>o`000?oATY400ol000001OoWZHko0000oln@TOl0003o_X2@00Go0000
00Go^Wb@o`000?l0003o0000ol63T005o`000003okaoTOl0003o000000?o000000?o_h>Bo`000?l0
00001ol000001Oo3R9Go0000o`000?l0003oa8VF00Co000000?oaY2Lo`000?o7TYh00ol000000oo7
Tioo0000olNEXP03o`000006olNFXol0003o0000olJIZ?l0003oaYZZ0_l000001_o4Vjoo0000o`00
0?o1W;?o0000oknL]@?o000000?o]ibmo`000?ncV[h05ol000001ooB[K?o0000o`000?l0003od;6j
o`000?o@/kd01Ol000000oo:^<Wo0000olVib`02o`000004olJkcol0003o0000ol>ld`;o000000Co
`KgFo`000?l0003o_[gH0_l000000onm_M[o0000o`00000?o`0001?ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0;ooooo`001?l00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0:ooooo`?o000000Woooooo`000?oo
oooo0000ooooool0003oooooo`000?o`/hd04Ol000000ooRXhoo0000olf>T004o`000003onRYS_l0
003o000000?o000000?oijV>o`000?o?T9401Ol000000oo9Ri7o0000o`000003o`000003ol63T?l0
003o000000?o000000?o_7nAo`000?l000000ol000001OnoPi;o0000o`000?l0003o`8BC00Go0000
00Oo`hREo`000?l0003o0000olB9U_l0003oUf>C00;o000000OoaY2Lo`000?o7TYko0000olNAWOl0
003oai>O00?o000000?oaiBQo`000?o7UZ<00_l000001Oo6VJSo0000o`000?l0003oaYVZ00;o0000
00?o`i^^o`000?o2Vk400ol000000onjW;Wo0000okNK^`04o`000003oj6Aa?l0003o000001;o0000
00?odjfao`000?l000001?l000001_o?];oo0000o`000?o=]lGo0000olbib0;o000000?ob;[=o`00
0?l000005ol000000onf_^3o0000o`00000Fooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02oooool00003o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00Ko0000ooooool0003oooooo`00
0?ooool3o`000007ooooool0003oooooo`000?oooooo0000oo2cS@09o`000003on:SSol0003o0000
00Co000000?oj:V>o`000?l000000ol000000ooWZHko0000o`000005o`000003olV;TOl0003o0000
00?o000000?o`H>@o`000?l000000ol000001OnlOi7o0000o`000?l0003o_H2A00Go000000Oo`8BC
o`000?l0003o0000ol65Tol0003o`hRE00?o000000?oa8VFo`000?nGHi<00ol000002_o6SIWo0000
o`000?o7TIgo0000olNCWol0003oai>No`000?o7U:43o`000006olNFXol0003o0000olJHYol0003o
aYVZ0_l000000oo3Vjko0000ol:K/@02o`000003okjK]Ol0003o^i^g00Co000000?oZ9C1o`000?l0
00004ol000001ooC[K7o0000om>_]?l0003odk6go`000?oB/kX01ol000000oo;^/[o0000o`000002
o`000004olJld?l0003o0000ol>me0;o000000Co`KgGo`000?l0003o_[kI0_l000000onl_]_o0000
o`000008o`0001Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`001Ol0
0003ooooo`;o00001?ooool2o`0000kooooo00?o0000ooooooooool04_ooool02_l0003oooooo`00
0?oooooo0000ooooool0003oooooo`000?o`/hd@o`000003onRYS_l0003o000000?o000000?oijV>
o`000?l000002ol000001Oo1Pi3o0000o`000?l0003oahRA00Go000000?o_H2Ao`000?l000000ol0
00001Oo0Q9?o0000o`000?l0003o`HFC00?o000000Go`hNDo`000?o4RIKo0000oiMST`03o`000005
olJ=VOl0003o0000o`000?o7SiX00_l000000oo7Tiko0000o`000003o`000005olNFXol0003o0000
o`000?o7Uj@00_l000000oo5VJWo0000olBJ[002o`000003ol6K/?l0003o_i^c00?o000000Go]9Rk
o`000?l0003o0000oj6@`P04o`000003oe]Q__l0003o000000_o000000?oeZVZo`000?l000002ol0
00000oo=^LKo0000olbjb@02o`000003olVlc_l0003o000001;o00007Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00_ooooo000Oooooo`03o`000?oooooooooo01Gooooo00[o0000
ooooool0003oooooo`000?o`/hgo0000ooooool0003ooooo0ol000000ooa/hco0000o`000005o`00
0003onRYS_l0003o000000Co000000?oijV>o`000?l000000ol000000ooQXXoo0000o`000003o`00
0003omFFT?l0003o000000?o000000?oahRAo`000?l000000ol000001onmP97o0000o`000?l0003o
_X6Ao`000?o0Q9<00ol000001Oo1QI?o0000o`000?l0003o`hND00Go000000OoaH^Go`000?o6SIWo
0000olJ=V?l0003oahnJ00;o000000Goai>No`000?l0003o0000olRDX003o`000003olRFX_l0003o
aiNT00;o000000?oaIVYo`000?o4VZ`00_l000000oo1Vk3o0000oknK/`02o`000003okVI]ol0003o
000001Go000000_oeZVZo`000?oF[:go0000omF^/Ol0003oeK2do`000?oD/kSo0000om>e^`02o`00
0003om2h`_l0003o000000;o000000?obk_;o`000?l000000_l000001?o6_M;o0000o`000?o3_]D9
o`000003ok^ogOl0003ooooo01kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;
ooooo`008?ooool2o`0001[ooooo0_l000001ooooooo0000ooooool0003ol;B>o`000?oa/h`01ol0
00000ooXZHko0000o`000003o`000003onNYS_l0003o000000Co000000?ohJ:?o`000?l000000ol0
00000ooEUY3o0000o`000007o`000003olb=TOl0003o000000?o000000Oo_X6Ao`000?l0003o0000
okn2TOl0003o`HFC00?o000000?o`hNDo`000?l000000ol000002oo5RiOo0000o`000?l0003oaXfH
o`000?o7Si[o0000olN>VOl0003oai2K00?o000000[ob9:Mo`000?l0003ob9JRo`000?o7UjCo0000
olNGY?l0003oaYRW0_l000000oo4VJco0000ol:J[P02o`000005okfI/ol0003o0000o`000?n`UK/0
9Ol000000oo>^lSo0000olblb`02o`000003olRmd?l0003o000000;o000000Goa;oEo`000?l0003o
0000ol2of@02o`000003okjofol0003o0000027ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0;ooooo`008_ooool00ol0003oooooooooo`0Jooooo`04o`000?oooooo0000oo2dSP;o
000000Soooooo`000?l0003ol;F>o`000?oa]8co0000onRYSPGo000000?oijV>o`000?l000005?l0
00000oo<SI7o0000o`000007o`000004okn2TOl0003o0000olV;T@;o000000?o`hNDo`000?l00000
0ol000002oo5RiOo0000o`000?l0003oaXfHo`000?o7Si[o0000olN>VOl0003oai2K00?o000000Go
b9:Mo`000?l0003o0000olRDW`02o`000003olNGY?l0003oaYRW00;o000000?oa9V/o`000?l00000
0_l000001?nmVK?o0000o`000?nfUkP3o`000003oj2=_ol0003o0000013o000000_of:RVo`000?oH
ZjWo0000omR^[Ol0003oek2ao`000?oF/kGo0000omJe^@02o`000005om:i`Ol0003odK[4o`000?o?
_<L01?l000001?o9_/oo0000o`000?o6_m<8o`0002Cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0;ooooo`008oooool00ol0003oooooooooo`0Looooo`04o`000?oooooo0000oooo
o`;o000000Gol;F>o`000?oa]8co0000onRYSP03o`000003oo6dRol0003oijV>013o000000?oh:6?
o`000?l000001ol000001?o>Si7o0000o`000?o/[H`2o`000004okn2TOl0003o0000olV;T@?o0000
00Koa8JAo`000?l0003oa8REo`000?o5RiL3o`000005olJ=V?l0003o0000o`000?o7SYT00ol00000
1oo8T9_o0000olRBWOl0003ob9:Mo`000?o8U9l01_l000001_o6V:Oo0000o`000?o3VJco0000ol6I
[P;o000000Co^iRco`000?l0003o/9Bj8_l000000ooD^/3o0000o`000004o`000003olbncOl0003o
000000?o000000GoaL3Eo`000?l0003o`/3Ho`00000Vooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02_ooool002Cooooo00?o0000ooooooooool08Oooool3o`000003ooooool0003o
oooo00;o000000?olKB;o`000?oWZHh00_l000000ooa]Hgo0000oo:dR`0Eo`000004olj?TOl0003o
0000onb]S0;o000000Co_h:Ao`000?l0003obH^A0ol000001?o4QY7o0000o`000?o4R9D3o`000003
olF:U_l0003oaXfH00?o000000GoahjIo`000?l0003o0000olR@V`03o`000005olRBWOl0003o0000
o`000?o8U9l00_l000000oo7UjCo0000olJHY`02o`000003ol>I[?l0003o000000;o000000?o^iRc
o`000?ngU[H06?l000002OoJZjKo0000omZ^Z_l0003of[6_o`000?oI/k?o0000omRf]`06o`000003
om6maol0003ockk:00Co000000?obL3Bo`000?l000000ol0000Xooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool02_ooool002Gooooo0_l0000Uooooo`03o`000?oooooo000000;o0000
00Goooooo`000?oooooo0000oo6eS@0Go`000004olj?TOl0003o0000onb]S0;o000000Co_h:Ao`00
0?l0003obH^A0ol000001?o4QY7o0000o`000?o4R9D3o`000004olF:U_l0003o0000olF9U@?o0000
00CoaXbFo`000?l0003ob92K0ol000001Oo8TYgo0000o`000?l0003ob9BO00?o000000Kob9FQo`00
0?l0003oaYNWo`000?o4V:T2o`000003oknH[ol0003o_9Na00Go000000?oTh>oo`000?l000003ol0
00000ooJYj;o0000o`00000;o`000005omJk_ol0003oe;c3o`000?oB_/L01?l000001Oo;`<oo0000
o`000?o8`MCo000002_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00
9oooool00ol0003oooooooooo`0Tooooo`08o`000?oooooo0000ooooool0003oooooo`000?oa]Hd5
o`000003oo:eS?l0003o000000Wo000000?oj:R=o`000?l000000ol000001?o>Si7o0000o`000?o/
[H`3o`000003onRYSOl0003obH^A00?o000000Coa8JAo`000?l0003oa8RE0ol000001?o5RYKo0000
o`000?o5RID3o`000005olJ<U_l0003o0000o`000?o7SYP01?l000001oo8TYco0000olRDWol0003o
b9BOo`000?o8UJ400_l000001Oo6UjOo0000o`000?l0003o`iNZ00;o000000Go_9Nao`000?l0003o
0000ojV?^P0Ho`000007omb^Yol0003og;6/o`000?oK];7o0000omZg]P0=o`000003ol[1d_l0003o
oooo02cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`00:?ooool00ol0
003oooooooooo`0Yooooo`?o000000Goooooo`000?oooooo0000oo:eS003o`000003oo6fSOl0003o
l[B:00Go000000?oj:R=o`000?l000000ol000001?o>Si7o0000o`000?o/[H`3o`000005onRYSOl0
003o0000o`000?oQXHl01Ol000002oo;SI?o0000o`000?l0003o`hJCo`000?o5RIGo0000olF9U?l0
003oaXbF00?o000000?oahjHo`000?l000000_l000002oo8TYco0000o`000?l0003ob9BOo`000?o8
UJ7o0000olREXOl0003oaiJT00;o000000?o`iNZo`000?l000000ol000001?nbT[Ko0000o`000?nO
R;/Do`000003omf[X_l0003o000000oo000000?odL7:o`000?l000000_l0000^ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool0;?ooool0
2_l0003oooooo`000?ob]Hco0000ooooool0003olKJ=o`000?ob]8X3o`000003oo:eR_l0003o0000
00?o000000?ok:f<o`000?l000000_l000001Oo/[Hco0000o`000?l0003oj:V=00?o000000OohJ6?
o`000?l0003o0000olZ>U?l0003obhfC00?o000000Go`hJCo`000?l0003o0000olF9U003o`000005
olJ;U_l0003o0000o`000?o7SYL00ol000001?o8T9Wo0000o`000?o8U9l3o`000005olREXOl0003o
aiJTo`000?o6UZ@00_l000001?o2UZ[o0000o`000?niU;8Fo`000003ombVWOl0003o000000Co0000
00?og[:Zo`000?oM]Zl00ol000002_oK_;Wo0000omVn__l0003oeko3o`000?oD`LOo0000om;2bol0
000aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool002[ooooo0_l0000_
ooooo`;o000000?oooooo`000?oa]Xd00ol000000ooa]hoo0000oo:eRP05o`000005onb]S?l0003o
0000o`000?o/[H`00_l000000ooc]X[o0000onRYS@03o`000007on6QSol0003o0000o`000?o:SYCo
0000ol^=T`03o`000005ol>6Tol0003o0000o`000?o5RI@00ol000001Oo6RiKo0000o`000?l0003o
ahjG00?o000000Gob92Io`000?l0003o0000olVBW002o`000005olREXOl0003o0000o`000?o6UZ@0
0_l000000oo2UZ[o0000okjE[@03o`000003ojZ=]ol0003o000000oo000000?ofj:Io`000?l00000
1?l000000ooO[jCo0000o`000008o`000006om^o__l0003of<73o`000?oE`lSo0000<oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo000/ooooo`03o`000?oooooooooo033o
oooo1?l000000ooa]hoo0000oo:eRP03o`000004oo:eRol0003o0000oo6hTP;o000000Cok:f<o`00
0?l0003olkJ:2Ol000000oo:SYCo0000ol^=T`03o`000003ol>6Tol0003o000000Go000000goaX^F
o`000?l0003o0000olN>Uol0003ob8jGo`000?o8T9Wo0000olV@VOl0003obI:L00?o000000Kob9BN
o`000?l0003oaYJTo`000?o5UJD2o`000004okjE[Ol0003o0000ok>A/Q;o000000?ofj:Io`000?l0
00000_l000000ooOZioo0000o`000002o`000003on6dZ?l0003o000000_o0000=?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo000]ooooo`03o`000?oooooooooo03?ooooo
0ol000001?oooooo0000o`000?ob]H/2o`000004oo6hT_l0003o0000onb]S0;o000000?olkJ:o`00
0?l000001ol000001Oo:SYCo0000o`000?l0003ogInA00Wo000001?oaX^Fo`000?o6RiGo0000olN>
Uol0003ob8jGo`000?o8T9Wo0000olV@VOl0003obI:Lo`000?o9TYco0000olRDW_l0003ob9BO00;o
000000?oaIFUo`000?o3UJP00_l000001?nkTjko0000o`000?n[S;DCo`000003omnVV_l0003o0000
00;o000000?oh[2Ro`000?l000000_l000001OoR^Jgo0000o`000?l0003ogl2i00Go0000=Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo000^ooooo`03o`000?oooooooooo
03Kooooo0_l000001?ob]H_o0000o`000?oa^982o`000004onb]S?l0003o0000oo>fRPWo000000Go
bXjDo`000?l0003o0000omfOT@07o`000005olF8Tol0003oaX^Fo`000?o6RiD00ol000001Oo8SYOo
0000o`000?l0003obI2I00?o000000GobI:Lo`000?l0003o0000olRDW`02o`000003olFEYOl0003o
`iFX00;o000000?o^i>^o`000?ndT;401Ol000000old>j_o0000o`00000<o`000003omnVV_l0003o
000000Go000000?oi;JVo`000?l000001?l000001?oP`[[o0000omg4`?l0000gooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02Oooool002oooooo00?o0000ooooooooool0=oooool0
0ol0003oooooo`000004o`000003oo6hTOl0003olkJ:00?o000000?olkJ9o`000?l000000ol00000
1Oo:SYCo0000o`000?l0003ogInA00?o000000Goci:Co`000?l0003o0000olF8T`03o`000005olJ;
UOl0003o0000o`000?o8SYL00ol000001Oo9T9Wo0000o`000?l0003obI:L00?o000000Gob9BOo`00
0?o8Tioo0000olJDXP02o`000003ol6DZ?l0003o_9:/01?o000000?ogJ:Eo`000?l000000_l00000
1?oR[9co0000o`000?oU/Yl4o`000003onFl[?l0003ohl2c00Co0000>Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo000`ooooo`;o0000>oooool01?l0003oooooo`000?oa
^943o`000003oo:hT?l0003olkJ900?o000000?olkF8o`000?l000000ol000001OoMWi7o0000o`00
0?l0003oci:C00?o000000GoaHRCo`000?l0003o0000olJ;U@04o`000005olN;U?l0003o0000o`00
0?o8SYL01?l000001oo9TYco0000o`000?l0003ob9>Oo`000?o6U:800_l000000oo1U:So0000o`00
000Co`000003omfRUOl0003o000000Go000000CoiK:Oo`000?l0003oikRU1?l000001?oU`kCo0000
o`000?l0000iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool003;ooooo
00?o0000ooooooooool0>oooool2o`000003ooooool0003ol[R@00?o000000?ol[N=o`000?l00000
2Ol000001Oo?TY?o0000omnRTOl0003oaHRC00Co000000GofI^Co`000?l0003o0000olN;U003o`00
0003olR>Uol0003o000000?o000000CobI6Io`000?l0003ob9>O0ol000001?o5U:?o0000o`000?nm
TZT2o`000005ojb9/Ol0003o0000o`000?m8B:h04_l000000ooU[IWo0000o`000003o`000003onVk
Y?l0003o000000Co0000>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
000cooooo`03o`000?oooooooooo03kooooo1?l000000oob]hgo0000o`000003o`000003oo>gRol0
003o000000Go000000Cogj:Ao`000?l0003olK>;0ol000002ooIVi?o0000o`000?l0003oah^Do`00
0?o<T9Co0000olR>Uol0003obHjG00?o000000GobI6Io`000?l0003o0000olVBW@02o`000006olFD
Xol0003o0000okfBZOl0003o]Xj]6_l000000ooX]9ko0000o`000007o`0003cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`00=?ooool00ol0003oooooooooo`0nooooo`Oo
000000?ol[ZCo`000?l000000ol000001Ooc]H[o0000o`000?l0003ogj:A00;o000000OolK>;o`00
0?l0003o0000omVKTol0003oiJRA00?o000000Goc92Do`000?l0003o0000olV>U`03o`000005olVA
VOl0003obI6Jo`000?o9TYd01?l000000oo3TZCo0000okjAY`0To`0003kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`00=Oooool2o`0003oooooo2Ol000001Oo^`:;o0000
o`000?l0003olKbF00?o000000GolkV?o`000?l0003o0000ooBhR`03o`000005onFXTOl0003o0000
o`000?o<T9@00ol000002oo9SYOo0000olV?Uol0003obI6Io`000?o9TI[o0000olVBWOl0003ob9:M
00;o000000?o`i:To`000?nnTJL01?l000000on4Kk?o0000o`00000Eo`000005on^gW?l0003o0000
o`000?o_`jD00ol0000nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
03Oooooo00?o0000ooooooooool0?_ooool;o`000005oo6lU_l0003o0000o`000?oc^Hl00ol00000
1Ood^8_o0000o`000?l0003oiJRA00?o000000Ooc92Do`000?l0003o0000olV>Uol0003obHnG00?o
000000GobI6Jo`000?l0003o0000olRBW@03o`000003olBBX_l0003o000000;o000000?oW7jbo`00
0?l000005ol000000oo^^i_o0000o`000003o`00043ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`00>?ooool00ol0003oooooooooo`0nooooo`co000000?okL:Wo`000?oc
^Hl00ol000001Ood^8_o0000o`000?l0003oiJRA00?o000000?oc92Do`000?oCUi@00ol000001Oo9
SiOo0000o`000?l0003obI6J00?o000000Gob9:Mo`000?o7TYko0000olBBXP02o`000003okR=Z?l0
003o000001oo0000@Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000i
ooooo`03o`000?oooooooooo03kooooo3ol000000oob_9Ko0000o`000009o`000005om>GU?l0003o
0000o`000?o9SiL01?l000000oo:SiOo0000o`000002o`000003olNBW_l0003oa9:R00;o000000Co
^8fXo`000?l0003oVgf`3ol000000ooQXY3o0000o`00000<o`0004;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`08ooooo`00>_ooool00ol0003oooooooooo`0noooooa;o000000?o
lkV>o`000?l000001Ol000000ooCUiCo0000o`000002o`000005on6UU?l0003o0000o`000?o:SiL0
1?l000001Oo7TYko0000o`000?l0003o`I2S00;o000000?o[HN/o`000?l000003_l000000ooQXY3o
0000o`000009o`000003ooO;W_l0003o000004;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`08ooooo`00>oooool2o`0003oooooo1ol00007ooooo`Co000000Goj<Jco`000?l0003o
0000oo:mU`03o`00000;ooBiS_l0003o0000o`000?oQYICo0000onN/Tol0003obXnGo`000?o:T9P0
0ol000001_o8TIco0000o`000?o1T:?o0000okZ=YQGo000000?ojZf>o`000?l000001ol00014oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool003gooooo00?o0000oooooooo
ool0?Oooool2o`0000gooooo017o0000ooooool0003o0000olC:g_l0003ol[fGo`000?o`_igo0000
ooBiS_l0003olk^@o`000?oQYICo0000onN/T`03o`000005olZ@V?l0003ocYFIo`000?o8TI`00_l0
00000oo1T:?o0000o`00000Eo`000003onZ]S_l0003o000000Oo0000AOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo000nooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool03_ooool00ol0003oooooo`000003o`000005oo2oWOl0003o0000o`000?oc^i000ol0
00002ooW[9?o0000o`000?l0003obY2Ho`000?o>UIWo0000olRAW?l0003oaY2M00;o000000?o^hbT
o`000?l000007Ol00015ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool0
03oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Booooo`Ko000000?olk^@o`00
0?l000001ol000001Oo>UIWo0000o`000?l0003oaY2M00;o000000Co^hbTo`000?l0003oVWV]3ol0
00000ooTY8go0000o`000009o`0004Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`07ooooo`00@?ooool2o`0003_ooooo00?o0000ooooooooool05Oooool9o`000005onfcT_l0003o
0000o`000?o>UIT00ol000000oo6T9go0000o`000002o`000003ojn5Z?l0003o000000ko000000Go
i:B=o`000?l0003o0000onn`R`07o`0004Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`00@_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Oooooo2?l0
00001Ooa_i_o0000o`000?l0003olkbC00Co000000?oa92No`000?nlS:804Ol000000ooTY8go0000
o`000009o`0004Wooooo00Go0000ooooooooooooooooo`000009ooooo`00@oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo01[ooooo1Ol000001ooa_i_o0000ono2X_l0003olkbCo`00
0?ob_iX00_l000000oo4T9ko0000okb<XP0Fo`000003ooBfR?l0003o000000?o0000B_ooool01Ol0
003ooooooooooooooooo000000Wooooo0014ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool07?ooool00ol0003oooooo`000006o`000004oo:oV_l0003o0000olB@WQWo000000?on;^4
o`000?l000000_l0001;ooooo`04o`000?ooooooooooo`0000Wooooo0015ooooo`;o0000=_ooool0
0ol0003oooooooooo`0Pooooo`Oo000000?ok/>Vo`000?o``Il01?l000000om[FJco0000o`00000F
o`0004cooooo00?o0000ooooool000002Oooool004Oooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Qooooo`So000000Col<6Oo`000?l0003obJFd6_l0001<ooooo`04o`000?oooooo
ooooo`0000Sooooo0018ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool08oooool0
0ol0003oooooo`00000Po`0004kooooo00?o0000ooooool000002?ooool004Wooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Vooooob3o0000Coooool2o`0000Sooooo001:ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0:OoooolNo`0004kooooo0ol00008ooooo`00
Boooool2o`0002oooooo00?o0000ooooooooool0:ooooolLo`0004[ooooo1?l0000;ooooo`00COoo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02kooooo6?l00017ooooo`Co00003ooo
ool004kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0_oooooaOo0000@oooool4
o`0001?ooooo001?ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<OoooolEo`00
043ooooo0ol0000Gooooo`00D?ooool2o`0002[ooooo00?o0000ooooooooool0<ooooolBo`0003go
oooo1?l0000Jooooo`00D_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Gooooo
2?l000000oof]hCo0000o`000005o`0003Wooooo1?l0000Nooooo`00Doooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo03Oooooo1_l000000oof]hCo0000o`000005o`0003Gooooo1?l0
000Rooooo`00E?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo1Ol00000
0oof]hCo0000o`000005o`00037ooooo1?l0000Vooooo`00EOooool2o`0002Gooooo00?o0000oooo
ooooool0>Oooool<o`0002gooooo1?l0000Zooooo`00Eoooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo03[ooooo1?l000000ooc_iOo0000o`000004o`0002Wooooo1?l0000^ooooo`00
F?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03_ooooo0ol000000ooc_iOo0000
o`000003o`0002Kooooo1?l0000booooo`00FOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo03cooooo0_l000000ooc_iOo0000o`000003o`0002?ooooo0ol0000fooooo`00F_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03cooooo2?l0000Oooooo`Co0000>Oooool0
05_ooooo0_l0000Oooooo`03o`000?oooooooooo03cooooo2?l0000Kooooo`Co0000?Oooool005go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0mooooo`Oo00005oooool4o`00047o
oooo001Nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0?_ooool6o`0001?ooooo
1?l00015ooooo`00Goooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo043ooooo1?l0
000?ooooo`Co0000BOooool0063ooooo0_l0000Jooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool02oooool4o`0004gooooo001Rooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0Boooool4o`00057ooooo001Sooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0B?ooool3o`0005Gooooo001Tooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
A?ooool4o`0005Sooooo001Uooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@?oo
ool4o`0005cooooo001Vooooo`;o00005?ooool00ol0003oooooooooo`0looooo`Co0000H?ooool0
06Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0hooooo`Co0000I?ooool006Wo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`Co0000J?ooool006[ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`Co0000K?ooool006_ooooo0_l0
000>ooooo`03o`000?oooooooooo02gooooo1?l0001`ooooo`00KOooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo02[ooooo0ol0001dooooo`00K_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02Kooooo1?l0001gooooo`00Koooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02;ooooo1?l0001kooooo`00L?ooool2o`0000Wooooo00?o0000ooooooooool0
7_ooool4o`0007oooooo001booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_oo
ool4o`0008?ooooo001cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4
o`0008Oooooo001dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`00
08_ooooo001eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`0008oo
oooo001fooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`?o0000Toooool007Sooooo00Co
0000oooooooooooo00002Oooool4o`0009Kooooo001iooooo`03o`000?oooooo000000Gooooo1?l0
002Jooooo`00N_ooool2o`000003ooooool0003o000000;o0000W_ooool007_ooooo0_l0002Roooo
o`00oooooolPooooo`00oooooolPooooo`00oooooolPooooo`00oooooolPooooo`00oooooolPoooo
o`00oooooolPooooo`00oooooolPooooo`00oooooolPooooo`00oooooolPooooo`00\
\>"],
  ImageRangeCache->{{{0, 286}, {231.75, 0}} -> {-0.0784293, 0.014033, \
0.0037007, 0.0037007}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ContourPlot[GeometricIntensity[ys,d], {ys,-.05,.05}, {d,-.5, \
.5},PlotPoints->200,PlotRange->{0,500}, Contours->20, \
ColorFunction->Function[Hue[.65-#*(.65),1,#*.9+.1]]];\
\>", "Input",
  CellLabel->"In[154]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 9.61538 0.5 0.961538 [
[.11538 -0.0125 -15 -9 ]
[.11538 -0.0125 15 0 ]
[.30769 -0.0125 -15 -9 ]
[.30769 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -12 -9 ]
[.69231 -0.0125 12 0 ]
[.88462 -0.0125 -12 -9 ]
[.88462 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11538 -24 -4.5 ]
[-0.0125 .11538 0 4.5 ]
[-0.0125 .30769 -24 -4.5 ]
[-0.0125 .30769 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .69231 -18 -4.5 ]
[-0.0125 .69231 0 4.5 ]
[-0.0125 .88462 -18 -4.5 ]
[-0.0125 .88462 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-0.04)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-0.02)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(0.02)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(0.04)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.06731 0 m
.06731 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11538 m
.00625 .11538 L
s
[(-0.4)] -0.0125 .11538 1 0 Mshowa
0 .30769 m
.00625 .30769 L
s
[(-0.2)] -0.0125 .30769 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .69231 m
.00625 .69231 L
s
[(0.2)] -0.0125 .69231 1 0 Mshowa
0 .88462 m
.00625 .88462 L
s
[(0.4)] -0.0125 .88462 1 0 Mshowa
.125 Mabswid
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .25962 m
.00375 .25962 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .74038 m
.00375 .74038 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .06731 m
.00375 .06731 L
s
0 .01923 m
.00375 .01923 L
s
0 .93269 m
.00375 .93269 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.25962 .99625 m
.25962 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.74038 .99625 m
.74038 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.06731 .99625 m
.06731 1 L
s
.01923 .99625 m
.01923 1 L
s
.93269 .99625 m
.93269 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .06731 m
1 .06731 L
s
.99625 .01923 m
1 .01923 L
s
.99625 .93269 m
1 .93269 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.91 .355 0 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.865 .506 0 r
.01923 .02136 m
.02036 .02406 L
.02406 .02678 L
.02651 .02889 L
.02889 .03127 L
.03165 .03373 L
.03373 .0358 L
.03676 .03856 L
.03856 .04035 L
.04186 .04339 L
.03963 .04822 L
.04339 .05198 L
.04507 .05305 L
.04822 .0562 L
.05034 .05789 L
.05305 .06059 L
.05554 .06272 L
.05789 .06505 L
.06071 .06755 L
.06272 .06955 L
.06584 .07238 L
.06336 .07721 L
.06755 .0814 L
.06905 .08204 L
.07238 .08537 L
.0744 .08688 L
.07721 .08968 L
.07965 .09171 L
.08204 .0941 L
.08484 .09654 L
.08688 .09857 L
.09 .10137 L
.08776 .1062 L
.09171 .11015 L
.09336 .11104 L
.09654 .11421 L
.09871 .11587 L
.10137 .11852 L
.10396 .1207 L
.1062 .12293 L
.10916 .12553 L
.10641 .13036 L
.11104 .13499 L
.1125 .1352 L
.11587 .13855 L
.11792 .14003 L
.1207 .14279 L
.12321 .14486 L
.12553 .14716 L
.12844 .14969 L
.12582 .15452 L
.13036 .15907 L
.13188 .15935 L
.1352 .16266 L
.13731 .16419 L
.14003 .16689 L
.14261 .16902 L
.14486 .17125 L
.14785 .17385 L
.14579 .17868 L
.14969 .18258 L
.15146 .18351 L
.15452 .18656 L
.15685 .18835 L
.15935 .19083 L
.16214 .19318 L
.16419 .19521 L
.16737 .19801 L
.1657 .20284 L
.16902 .20614 L
.17118 .20767 L
.17385 .21033 L
.17651 .2125 L
.17868 .21466 L
.18177 .21734 L
.18008 .22217 L
.18351 .2256 L
.18561 .227 L
.18835 .22972 L
.19097 .23183 L
.19318 .23403 L
.19624 .23666 L
.19461 .2415 L
.19801 .24489 L
.20015 .24633 L
.20284 .24901 L
.20551 .25116 L
.20767 .25331 L
.21079 .25599 L
.20929 .26082 L
.2125 .26403 L
.21479 .26566 L
.21734 .26819 L
.22013 .27049 L
.2183 .27532 L
.22217 .27918 L
.22406 .28015 L
.227 .28307 L
.2295 .28498 L
.23183 .2873 L
.23483 .28981 L
.23334 .29465 L
.23666 .29795 L
.2389 .29948 L
.2415 .30206 L
.24428 .30431 L
.24261 .30914 L
.24633 .31285 L
.24834 .31397 L
.25116 .31678 L
.25377 .31881 L
.25186 .32364 L
.25599 .32777 L
.25782 .32847 L
.26082 .33146 L
.26331 .3333 L
.26566 .33563 L
.26866 .33813 L
.26737 .34296 L
.27049 .34607 L
.27289 .3478 L
.27532 .3502 L
.27827 .35263 L
.27698 .35746 L
.28015 .36061 L
.28254 .36229 L
.28498 .36472 L
.28792 .36712 L
.28668 .37196 L
.28981 .37507 L
.29223 .37679 L
.29024 .38162 L
.29465 .38602 L
.29644 .38645 L
.29948 .38947 L
.30197 .39128 L
.30035 .39612 L
.30431 .40007 L
.30627 .40095 L
.30914 .4038 L
.31176 .40578 L
.3104 .41061 L
.31397 .41417 L
.31613 .41544 L
.31881 .4181 L
.32158 .42027 L
.32042 .42511 L
.32364 .42831 L
.32602 .42994 L
.32447 .43477 L
.32847 .43876 L
.33043 .4396 L
.3333 .44245 L
.33595 .44443 L
.33473 .44927 L
.33813 .45272 L
.34027 .4541 L
.33883 .45893 L
.34296 .46306 L
.34477 .46376 L
.3478 .46677 L
.35023 .46859 L
.34923 .47342 L
.35263 .47681 L
.35481 .47826 L
.35362 .48309 L
.35746 .48692 L
.35939 .48792 L
.35758 .49275 L
.36229 .49746 L
.36397 .49758 L
.36712 .50072 L
.36947 .50242 L
.36854 .50725 L
.37196 .51064 L
.37413 .51208 L
.37311 .51691 L
.37679 .52057 L
.3788 .52174 L
.37766 .52658 L
.38162 .53052 L
.38349 .53141 L
.38218 .53624 L
.38645 .54051 L
.3882 .54107 L
.39128 .54413 L
.39367 .5459 L
.39293 .55073 L
.39612 .55389 L
.39842 .55557 L
.39769 .5604 L
.40095 .56363 L
.4032 .56523 L
.40248 .57006 L
.40578 .57334 L
.408 .57489 L
.4073 .57973 L
.41061 .58302 L
.41281 .58456 L
.41214 .58939 L
.41544 .59267 L
.41765 .59422 L
.41701 .59905 L
.41565 .60388 L
.42027 .60851 L
.4219 .60872 L
.42088 .61355 L
.42511 .61777 L
.42681 .61838 L
.42597 .62321 L
.42994 .62716 L
.43174 .62804 L
.43103 .63288 L
.43477 .6366 L
.43667 .63771 L
.43607 .64254 L
.4396 .64605 L
.4416 .64737 L
.44109 .6522 L
.44024 .65704 L
.44443 .66122 L
.44609 .66187 L
.44547 .6667 L
.44927 .67047 L
.45108 .67153 L
.45059 .67636 L
.44975 .68119 L
.4541 .68554 L
.45565 .68603 L
.45511 .69086 L
.45893 .69466 L
.46067 .69569 L
.46027 .70052 L
.45967 .70535 L
.46376 .70943 L
.46533 .71019 L
.46493 .71502 L
.4643 .71985 L
.46859 .72414 L
.47004 .72468 L
.46966 .72951 L
.46906 .73434 L
.47342 .73871 L
.47478 .73918 L
.47445 .74401 L
.47396 .74884 L
.47826 .75313 L
.47955 .75367 L
.47928 .7585 L
.47893 .76334 L
.48309 .7675 L
.48432 .76817 L
.48411 .773 L
.48387 .77783 L
.48354 .78266 L
.48792 .78707 L
.48888 .7875 L
.48871 .79233 L
.48853 .79716 L
.48831 .80199 L
.49275 .8065 L
.49338 .80682 L
.49326 .81165 L
.49314 .81649 L
.49303 .82132 L
.49293 .82615 L
.49282 .83098 L
.49398 .83581 L
.49332 .84065 L
.49282 .84548 L
.49275 .84621 L
.49219 .85031 L
.49163 .85514 L
.49111 .85997 L
.4906 .8648 L
.49003 .86964 L
.48935 .87447 L
.48865 .8793 L
.48806 .88413 L
.48792 .88593 L
.48774 .88896 L
.48751 .8938 L
.48735 .89863 L
.48728 .90346 L
.4873 .90829 L
.48742 .91312 L
.48767 .91796 L
.48792 .92124 L
.48807 .92279 L
.48862 .92762 L
.48936 .93245 L
.49037 .93728 L
.49184 .94211 L
.49275 .94431 L
.49405 .94695 L
.49758 .95112 L
.50242 .95112 L
.50596 .94695 L
.50725 .94433 L
.50817 .94211 L
.50963 .93728 L
.51064 .93245 L
.51139 .92762 L
.51194 .92279 L
.51208 .92129 L
.51233 .91796 L
.51258 .91312 L
.51271 .90829 L
.51273 .90346 L
.51265 .89863 L
.51249 .8938 L
.51226 .88896 L
.51208 .88586 L
.51194 .88413 L
.51136 .8793 L
.51065 .87447 L
.50998 .86964 L
.5094 .8648 L
.50889 .85997 L
.50837 .85514 L
.50782 .85031 L
.50725 .84619 L
.50718 .84548 L
.50668 .84065 L
.50603 .83581 L
.50718 .83098 L
.50707 .82615 L
.50697 .82132 L
.50686 .81649 L
.50674 .81165 L
.50662 .80682 L
.50725 .8065 L
.51169 .80199 L
.51147 .79716 L
.51129 .79233 L
.51112 .7875 L
.51208 .78707 L
.51646 .78266 L
.51613 .77783 L
.51589 .773 L
.51568 .76817 L
.51691 .7675 L
.52107 .76334 L
.52072 .7585 L
.52045 .75367 L
.52174 .75313 L
.52604 .74884 L
.52555 .74401 L
.52522 .73918 L
.52658 .73871 L
.53094 .73434 L
.53034 .72951 L
.52996 .72468 L
.53141 .72414 L
.5357 .71985 L
.53507 .71502 L
.53467 .71019 L
.53624 .70943 L
.54033 .70535 L
.53973 .70052 L
.53933 .69569 L
.54107 .69466 L
.54489 .69086 L
.54435 .68603 L
.5459 .68554 L
.55025 .68119 L
.54941 .67636 L
.54892 .67153 L
.55073 .67047 L
.55453 .6667 L
.55391 .66187 L
.55557 .66122 L
.55976 .65704 L
.55891 .6522 L
.5584 .64737 L
.5604 .64605 L
.56393 .64254 L
.56333 .63771 L
.56523 .6366 L
.56897 .63288 L
.56826 .62804 L
.57006 .62716 L
.57403 .62321 L
.57319 .61838 L
.57489 .61777 L
.57912 .61355 L
.5781 .60872 L
.57973 .60851 L
.58435 .60388 L
.58299 .59905 L
.58235 .59422 L
.58456 .59267 L
.58786 .58939 L
.58719 .58456 L
.58939 .58302 L
.5927 .57973 L
.592 .57489 L
.59422 .57334 L
.59752 .57006 L
.5968 .56523 L
.59905 .56363 L
.60231 .5604 L
.60158 .55557 L
.60388 .55389 L
.60707 .55073 L
.60633 .5459 L
.60872 .54413 L
.6118 .54107 L
.61355 .54051 L
.61782 .53624 L
.61651 .53141 L
.61838 .53052 L
.62234 .52658 L
.6212 .52174 L
.62321 .52057 L
.62689 .51691 L
.62587 .51208 L
.62804 .51064 L
.63146 .50725 L
.63053 .50242 L
.63288 .50072 L
.63603 .49758 L
.63771 .49746 L
.64242 .49275 L
.64061 .48792 L
.64254 .48692 L
.64638 .48309 L
.64519 .47826 L
.64737 .47681 L
.65077 .47342 L
.64977 .46859 L
.6522 .46677 L
.65523 .46376 L
.65704 .46306 L
.66117 .45893 L
.65973 .4541 L
.66187 .45272 L
.66527 .44927 L
.66405 .44443 L
.6667 .44245 L
.66957 .4396 L
.67153 .43876 L
.67553 .43477 L
.67398 .42994 L
.67636 .42831 L
.67958 .42511 L
.67842 .42027 L
.68119 .4181 L
.68387 .41544 L
.68603 .41417 L
.6896 .41061 L
.68824 .40578 L
.69086 .4038 L
.69373 .40095 L
.69569 .40007 L
.69965 .39612 L
.69803 .39128 L
.70052 .38947 L
.70356 .38645 L
.70535 .38602 L
.70976 .38162 L
.70777 .37679 L
.71019 .37507 L
.71332 .37196 L
.71208 .36712 L
.71502 .36472 L
.71746 .36229 L
.71985 .36061 L
.72302 .35746 L
.72173 .35263 L
.72468 .3502 L
.72711 .3478 L
.72951 .34607 L
.73263 .34296 L
.73134 .33813 L
.73434 .33563 L
.73669 .3333 L
.73918 .33146 L
.74218 .32847 L
.74401 .32777 L
.74814 .32364 L
.74623 .31881 L
.74884 .31678 L
.75166 .31397 L
.75367 .31285 L
.75739 .30914 L
.75572 .30431 L
.7585 .30206 L
.7611 .29948 L
.76334 .29795 L
.76666 .29465 L
.76517 .28981 L
.76817 .2873 L
.7705 .28498 L
.773 .28307 L
.77594 .28015 L
.77783 .27918 L
.7817 .27532 L
.77987 .27049 L
.78266 .26819 L
.78521 .26566 L
.7875 .26403 L
.79071 .26082 L
.78921 .25599 L
.79233 .25331 L
.79449 .25116 L
.79716 .24901 L
.79985 .24633 L
.80199 .24489 L
.80539 .2415 L
.80376 .23666 L
.80682 .23403 L
.80903 .23183 L
.81165 .22972 L
.81439 .227 L
.81649 .2256 L
.81992 .22217 L
.81823 .21734 L
.82132 .21466 L
.82349 .2125 L
.82615 .21033 L
.82882 .20767 L
.83098 .20614 L
.8343 .20284 L
.83263 .19801 L
.83581 .19521 L
.83786 .19318 L
.84065 .19083 L
.84315 .18835 L
.84548 .18656 L
.84854 .18351 L
.85031 .18258 L
.85421 .17868 L
.85215 .17385 L
.85514 .17125 L
.85739 .16902 L
.85997 .16689 L
.86269 .16419 L
.8648 .16266 L
.86812 .15935 L
.86964 .15907 L
.87418 .15452 L
.87156 .14969 L
.87447 .14716 L
.87679 .14486 L
.8793 .14279 L
.88208 .14003 L
.88413 .13855 L
.8875 .1352 L
.88896 .13499 L
.89359 .13036 L
.89084 .12553 L
.8938 .12293 L
.89604 .1207 L
.89863 .11852 L
.90129 .11587 L
.90346 .11421 L
.90664 .11104 L
.90829 .11015 L
.91224 .1062 L
.91 .10137 L
.91312 .09857 L
.91516 .09654 L
.91796 .0941 L
.92035 .09171 L
.92279 .08968 L
.9256 .08688 L
.92762 .08537 L
.93095 .08204 L
.93245 .0814 L
.93664 .07721 L
.93416 .07238 L
.93728 .06955 L
.93929 .06755 L
.94211 .06505 L
.94446 .06272 L
.94695 .06059 L
.94966 .05789 L
.95178 .0562 L
.95493 .05305 L
.95661 .05198 L
.96037 .04822 L
.95814 .04339 L
.96144 .04035 L
.96324 .03856 L
.96627 .0358 L
.96835 .03373 L
.97111 .03127 L
.97349 .02889 L
.97594 .02678 L
.97964 .02406 L
.98077 .02136 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .02136 m
.02036 .02406 L
.02406 .02678 L
.02651 .02889 L
.02889 .03127 L
.03165 .03373 L
.03373 .0358 L
.03676 .03856 L
.03856 .04035 L
.04186 .04339 L
.03963 .04822 L
.04339 .05198 L
.04507 .05305 L
.04822 .0562 L
.05034 .05789 L
.05305 .06059 L
.05554 .06272 L
.05789 .06505 L
.06071 .06755 L
.06272 .06955 L
.06584 .07238 L
.06336 .07721 L
.06755 .0814 L
.06905 .08204 L
.07238 .08537 L
.0744 .08688 L
.07721 .08968 L
.07965 .09171 L
.08204 .0941 L
.08484 .09654 L
.08688 .09857 L
.09 .10137 L
.08776 .1062 L
.09171 .11015 L
.09336 .11104 L
.09654 .11421 L
.09871 .11587 L
.10137 .11852 L
.10396 .1207 L
.1062 .12293 L
.10916 .12553 L
.10641 .13036 L
.11104 .13499 L
.1125 .1352 L
.11587 .13855 L
.11792 .14003 L
.1207 .14279 L
.12321 .14486 L
.12553 .14716 L
.12844 .14969 L
Mistroke
.12582 .15452 L
.13036 .15907 L
.13188 .15935 L
.1352 .16266 L
.13731 .16419 L
.14003 .16689 L
.14261 .16902 L
.14486 .17125 L
.14785 .17385 L
.14579 .17868 L
.14969 .18258 L
.15146 .18351 L
.15452 .18656 L
.15685 .18835 L
.15935 .19083 L
.16214 .19318 L
.16419 .19521 L
.16737 .19801 L
.1657 .20284 L
.16902 .20614 L
.17118 .20767 L
.17385 .21033 L
.17651 .2125 L
.17868 .21466 L
.18177 .21734 L
.18008 .22217 L
.18351 .2256 L
.18561 .227 L
.18835 .22972 L
.19097 .23183 L
.19318 .23403 L
.19624 .23666 L
.19461 .2415 L
.19801 .24489 L
.20015 .24633 L
.20284 .24901 L
.20551 .25116 L
.20767 .25331 L
.21079 .25599 L
.20929 .26082 L
.2125 .26403 L
.21479 .26566 L
.21734 .26819 L
.22013 .27049 L
.2183 .27532 L
.22217 .27918 L
.22406 .28015 L
.227 .28307 L
.2295 .28498 L
.23183 .2873 L
Mistroke
.23483 .28981 L
.23334 .29465 L
.23666 .29795 L
.2389 .29948 L
.2415 .30206 L
.24428 .30431 L
.24261 .30914 L
.24633 .31285 L
.24834 .31397 L
.25116 .31678 L
.25377 .31881 L
.25186 .32364 L
.25599 .32777 L
.25782 .32847 L
.26082 .33146 L
.26331 .3333 L
.26566 .33563 L
.26866 .33813 L
.26737 .34296 L
.27049 .34607 L
.27289 .3478 L
.27532 .3502 L
.27827 .35263 L
.27698 .35746 L
.28015 .36061 L
.28254 .36229 L
.28498 .36472 L
.28792 .36712 L
.28668 .37196 L
.28981 .37507 L
.29223 .37679 L
.29024 .38162 L
.29465 .38602 L
.29644 .38645 L
.29948 .38947 L
.30197 .39128 L
.30035 .39612 L
.30431 .40007 L
.30627 .40095 L
.30914 .4038 L
.31176 .40578 L
.3104 .41061 L
.31397 .41417 L
.31613 .41544 L
.31881 .4181 L
.32158 .42027 L
.32042 .42511 L
.32364 .42831 L
.32602 .42994 L
.32447 .43477 L
Mistroke
.32847 .43876 L
.33043 .4396 L
.3333 .44245 L
.33595 .44443 L
.33473 .44927 L
.33813 .45272 L
.34027 .4541 L
.33883 .45893 L
.34296 .46306 L
.34477 .46376 L
.3478 .46677 L
.35023 .46859 L
.34923 .47342 L
.35263 .47681 L
.35481 .47826 L
.35362 .48309 L
.35746 .48692 L
.35939 .48792 L
.35758 .49275 L
.36229 .49746 L
.36397 .49758 L
.36712 .50072 L
.36947 .50242 L
.36854 .50725 L
.37196 .51064 L
.37413 .51208 L
.37311 .51691 L
.37679 .52057 L
.3788 .52174 L
.37766 .52658 L
.38162 .53052 L
.38349 .53141 L
.38218 .53624 L
.38645 .54051 L
.3882 .54107 L
.39128 .54413 L
.39367 .5459 L
.39293 .55073 L
.39612 .55389 L
.39842 .55557 L
.39769 .5604 L
.40095 .56363 L
.4032 .56523 L
.40248 .57006 L
.40578 .57334 L
.408 .57489 L
.4073 .57973 L
.41061 .58302 L
.41281 .58456 L
.41214 .58939 L
Mistroke
.41544 .59267 L
.41765 .59422 L
.41701 .59905 L
.41565 .60388 L
.42027 .60851 L
.4219 .60872 L
.42088 .61355 L
.42511 .61777 L
.42681 .61838 L
.42597 .62321 L
.42994 .62716 L
.43174 .62804 L
.43103 .63288 L
.43477 .6366 L
.43667 .63771 L
.43607 .64254 L
.4396 .64605 L
.4416 .64737 L
.44109 .6522 L
.44024 .65704 L
.44443 .66122 L
.44609 .66187 L
.44547 .6667 L
.44927 .67047 L
.45108 .67153 L
.45059 .67636 L
.44975 .68119 L
.4541 .68554 L
.45565 .68603 L
.45511 .69086 L
.45893 .69466 L
.46067 .69569 L
.46027 .70052 L
.45967 .70535 L
.46376 .70943 L
.46533 .71019 L
.46493 .71502 L
.4643 .71985 L
.46859 .72414 L
.47004 .72468 L
.46966 .72951 L
.46906 .73434 L
.47342 .73871 L
.47478 .73918 L
.47445 .74401 L
.47396 .74884 L
.47826 .75313 L
.47955 .75367 L
.47928 .7585 L
.47893 .76334 L
Mistroke
.48309 .7675 L
.48432 .76817 L
.48411 .773 L
.48387 .77783 L
.48354 .78266 L
.48792 .78707 L
.48888 .7875 L
.48871 .79233 L
.48853 .79716 L
.48831 .80199 L
.49275 .8065 L
.49338 .80682 L
.49326 .81165 L
.49314 .81649 L
.49303 .82132 L
.49293 .82615 L
.49282 .83098 L
.49398 .83581 L
.49332 .84065 L
.49282 .84548 L
.49275 .84621 L
.49219 .85031 L
.49163 .85514 L
.49111 .85997 L
.4906 .8648 L
.49003 .86964 L
.48935 .87447 L
.48865 .8793 L
.48806 .88413 L
.48792 .88593 L
.48774 .88896 L
.48751 .8938 L
.48735 .89863 L
.48728 .90346 L
.4873 .90829 L
.48742 .91312 L
.48767 .91796 L
.48792 .92124 L
.48807 .92279 L
.48862 .92762 L
.48936 .93245 L
.49037 .93728 L
.49184 .94211 L
.49275 .94431 L
.49405 .94695 L
.49758 .95112 L
.50242 .95112 L
.50596 .94695 L
.50725 .94433 L
.50817 .94211 L
Mistroke
.50963 .93728 L
.51064 .93245 L
.51139 .92762 L
.51194 .92279 L
.51208 .92129 L
.51233 .91796 L
.51258 .91312 L
.51271 .90829 L
.51273 .90346 L
.51265 .89863 L
.51249 .8938 L
.51226 .88896 L
.51208 .88586 L
.51194 .88413 L
.51136 .8793 L
.51065 .87447 L
.50998 .86964 L
.5094 .8648 L
.50889 .85997 L
.50837 .85514 L
.50782 .85031 L
.50725 .84619 L
.50718 .84548 L
.50668 .84065 L
.50603 .83581 L
.50718 .83098 L
.50707 .82615 L
.50697 .82132 L
.50686 .81649 L
.50674 .81165 L
.50662 .80682 L
.50725 .8065 L
.51169 .80199 L
.51147 .79716 L
.51129 .79233 L
.51112 .7875 L
.51208 .78707 L
.51646 .78266 L
.51613 .77783 L
.51589 .773 L
.51568 .76817 L
.51691 .7675 L
.52107 .76334 L
.52072 .7585 L
.52045 .75367 L
.52174 .75313 L
.52604 .74884 L
.52555 .74401 L
.52522 .73918 L
.52658 .73871 L
Mistroke
.53094 .73434 L
.53034 .72951 L
.52996 .72468 L
.53141 .72414 L
.5357 .71985 L
.53507 .71502 L
.53467 .71019 L
.53624 .70943 L
.54033 .70535 L
.53973 .70052 L
.53933 .69569 L
.54107 .69466 L
.54489 .69086 L
.54435 .68603 L
.5459 .68554 L
.55025 .68119 L
.54941 .67636 L
.54892 .67153 L
.55073 .67047 L
.55453 .6667 L
.55391 .66187 L
.55557 .66122 L
.55976 .65704 L
.55891 .6522 L
.5584 .64737 L
.5604 .64605 L
.56393 .64254 L
.56333 .63771 L
.56523 .6366 L
.56897 .63288 L
.56826 .62804 L
.57006 .62716 L
.57403 .62321 L
.57319 .61838 L
.57489 .61777 L
.57912 .61355 L
.5781 .60872 L
.57973 .60851 L
.58435 .60388 L
.58299 .59905 L
.58235 .59422 L
.58456 .59267 L
.58786 .58939 L
.58719 .58456 L
.58939 .58302 L
.5927 .57973 L
.592 .57489 L
.59422 .57334 L
.59752 .57006 L
.5968 .56523 L
Mistroke
.59905 .56363 L
.60231 .5604 L
.60158 .55557 L
.60388 .55389 L
.60707 .55073 L
.60633 .5459 L
.60872 .54413 L
.6118 .54107 L
.61355 .54051 L
.61782 .53624 L
.61651 .53141 L
.61838 .53052 L
.62234 .52658 L
.6212 .52174 L
.62321 .52057 L
.62689 .51691 L
.62587 .51208 L
.62804 .51064 L
.63146 .50725 L
.63053 .50242 L
.63288 .50072 L
.63603 .49758 L
.63771 .49746 L
.64242 .49275 L
.64061 .48792 L
.64254 .48692 L
.64638 .48309 L
.64519 .47826 L
.64737 .47681 L
.65077 .47342 L
.64977 .46859 L
.6522 .46677 L
.65523 .46376 L
.65704 .46306 L
.66117 .45893 L
.65973 .4541 L
.66187 .45272 L
.66527 .44927 L
.66405 .44443 L
.6667 .44245 L
.66957 .4396 L
.67153 .43876 L
.67553 .43477 L
.67398 .42994 L
.67636 .42831 L
.67958 .42511 L
.67842 .42027 L
.68119 .4181 L
.68387 .41544 L
.68603 .41417 L
Mistroke
.6896 .41061 L
.68824 .40578 L
.69086 .4038 L
.69373 .40095 L
.69569 .40007 L
.69965 .39612 L
.69803 .39128 L
.70052 .38947 L
.70356 .38645 L
.70535 .38602 L
.70976 .38162 L
.70777 .37679 L
.71019 .37507 L
.71332 .37196 L
.71208 .36712 L
.71502 .36472 L
.71746 .36229 L
.71985 .36061 L
.72302 .35746 L
.72173 .35263 L
.72468 .3502 L
.72711 .3478 L
.72951 .34607 L
.73263 .34296 L
.73134 .33813 L
.73434 .33563 L
.73669 .3333 L
.73918 .33146 L
.74218 .32847 L
.74401 .32777 L
.74814 .32364 L
.74623 .31881 L
.74884 .31678 L
.75166 .31397 L
.75367 .31285 L
.75739 .30914 L
.75572 .30431 L
.7585 .30206 L
.7611 .29948 L
.76334 .29795 L
.76666 .29465 L
.76517 .28981 L
.76817 .2873 L
.7705 .28498 L
.773 .28307 L
.77594 .28015 L
.77783 .27918 L
.7817 .27532 L
.77987 .27049 L
.78266 .26819 L
Mistroke
.78521 .26566 L
.7875 .26403 L
.79071 .26082 L
.78921 .25599 L
.79233 .25331 L
.79449 .25116 L
.79716 .24901 L
.79985 .24633 L
.80199 .24489 L
.80539 .2415 L
.80376 .23666 L
.80682 .23403 L
.80903 .23183 L
.81165 .22972 L
.81439 .227 L
.81649 .2256 L
.81992 .22217 L
.81823 .21734 L
.82132 .21466 L
.82349 .2125 L
.82615 .21033 L
.82882 .20767 L
.83098 .20614 L
.8343 .20284 L
.83263 .19801 L
.83581 .19521 L
.83786 .19318 L
.84065 .19083 L
.84315 .18835 L
.84548 .18656 L
.84854 .18351 L
.85031 .18258 L
.85421 .17868 L
.85215 .17385 L
.85514 .17125 L
.85739 .16902 L
.85997 .16689 L
.86269 .16419 L
.8648 .16266 L
.86812 .15935 L
.86964 .15907 L
.87418 .15452 L
.87156 .14969 L
.87447 .14716 L
.87679 .14486 L
.8793 .14279 L
.88208 .14003 L
.88413 .13855 L
.8875 .1352 L
.88896 .13499 L
Mistroke
.89359 .13036 L
.89084 .12553 L
.8938 .12293 L
.89604 .1207 L
.89863 .11852 L
.90129 .11587 L
.90346 .11421 L
.90664 .11104 L
.90829 .11015 L
.91224 .1062 L
.91 .10137 L
.91312 .09857 L
.91516 .09654 L
.91796 .0941 L
.92035 .09171 L
.92279 .08968 L
.9256 .08688 L
.92762 .08537 L
.93095 .08204 L
.93245 .0814 L
.93664 .07721 L
.93416 .07238 L
.93728 .06955 L
.93929 .06755 L
.94211 .06505 L
.94446 .06272 L
.94695 .06059 L
.94966 .05789 L
.95178 .0562 L
.95493 .05305 L
.95661 .05198 L
.96037 .04822 L
.95814 .04339 L
.96144 .04035 L
.96324 .03856 L
.96627 .0358 L
.96835 .03373 L
.97111 .03127 L
.97349 .02889 L
.97594 .02678 L
.97964 .02406 L
.98077 .02136 L
Mfstroke
.82 .64 0 r
.01923 .02145 m
.02028 .02406 L
.02406 .02689 L
.02638 .02889 L
.02889 .0314 L
.0315 .03373 L
.03373 .03595 L
.03659 .03856 L
.03856 .04052 L
.04167 .04339 L
.03957 .04822 L
.04339 .05204 L
.04498 .05305 L
.04822 .05629 L
.05023 .05789 L
.05305 .0607 L
.05541 .06272 L
.05789 .06518 L
.06055 .06755 L
.06272 .0697 L
.06567 .07238 L
.06333 .07721 L
.06755 .08143 L
.06897 .08204 L
.07238 .08545 L
.07429 .08688 L
.07721 .08979 L
.07952 .09171 L
.08204 .09423 L
.08469 .09654 L
.08688 .09872 L
.08983 .10137 L
.08771 .1062 L
.09171 .1102 L
.09328 .11104 L
.09654 .11429 L
.09859 .11587 L
.10137 .11864 L
.10382 .1207 L
.1062 .12307 L
.109 .12553 L
.1064 .13036 L
.11104 .135 L
.11243 .1352 L
.11587 .13863 L
.11782 .14003 L
.1207 .1429 L
.12308 .14486 L
.12553 .1473 L
.12828 .14969 L
.1258 .15452 L
.13036 .15908 L
.1318 .15935 L
.1352 .16274 L
.1372 .16419 L
.14003 .167 L
.14247 .16902 L
.14486 .17139 L
.14769 .17385 L
.14574 .17868 L
.14969 .18263 L
.15137 .18351 L
.15452 .18665 L
.15673 .18835 L
.15935 .19096 L
.16199 .19318 L
.16419 .19536 L
.16719 .19801 L
.16563 .20284 L
.16902 .20622 L
.17107 .20767 L
.17385 .21044 L
.17637 .2125 L
.17868 .21481 L
.1816 .21734 L
.18 .22217 L
.18351 .22567 L
.1855 .227 L
.18835 .22983 L
.19083 .23183 L
.19318 .23417 L
.19607 .23666 L
.19453 .2415 L
.19801 .24496 L
.20004 .24633 L
.20284 .24912 L
.20537 .25116 L
.20767 .25345 L
.21062 .25599 L
.2092 .26082 L
.2125 .26411 L
.21467 .26566 L
.21734 .26831 L
.21998 .27049 L
.21825 .27532 L
.22217 .27923 L
.22397 .28015 L
.227 .28317 L
.22937 .28498 L
.23183 .28743 L
.23466 .28981 L
.23326 .29465 L
.23666 .29803 L
.23878 .29948 L
.2415 .30217 L
.24413 .30431 L
.24256 .30914 L
.24633 .31291 L
.24823 .31397 L
.25116 .31689 L
.25363 .31881 L
.25182 .32364 L
.25599 .3278 L
.25772 .32847 L
.26082 .33155 L
.26318 .3333 L
.26566 .33576 L
.2685 .33813 L
.26728 .34296 L
.27049 .34616 L
.27277 .3478 L
.27532 .35033 L
.27811 .35263 L
.2769 .35746 L
.28015 .3607 L
.28241 .36229 L
.28498 .36485 L
.28776 .36712 L
.28659 .37196 L
.28981 .37516 L
.2921 .37679 L
.29022 .38162 L
.29465 .38604 L
.29635 .38645 L
.29948 .38956 L
.30184 .39128 L
.30031 .39612 L
.30431 .40011 L
.30616 .40095 L
.30914 .40391 L
.31162 .40578 L
.31033 .41061 L
.31397 .41424 L
.31602 .41544 L
.31881 .41821 L
.32143 .42027 L
.32034 .42511 L
.32364 .42839 L
.3259 .42994 L
.32442 .43477 L
.32847 .43881 L
.33033 .4396 L
.3333 .44255 L
.33581 .44443 L
.33466 .44927 L
.33813 .4528 L
.34015 .4541 L
.33879 .45893 L
.34296 .4631 L
.34466 .46376 L
.3478 .46687 L
.35009 .46859 L
.34915 .47342 L
.35263 .47689 L
.35469 .47826 L
.35356 .48309 L
.35746 .48698 L
.35928 .48792 L
.35757 .49275 L
.36229 .49747 L
.36387 .49758 L
.36712 .50081 L
.36933 .50242 L
.36846 .50725 L
.37196 .51072 L
.374 .51208 L
.37304 .51691 L
.37679 .52064 L
.37868 .52174 L
.37761 .52658 L
.38162 .53057 L
.38338 .53141 L
.38214 .53624 L
.38645 .54054 L
.3881 .54107 L
.39128 .54423 L
.39353 .5459 L
.39284 .55073 L
.39612 .55399 L
.39829 .55557 L
.3976 .5604 L
.40095 .56372 L
.40307 .56523 L
.40239 .57006 L
.40578 .57343 L
.40787 .57489 L
.40721 .57973 L
.41061 .58311 L
.41268 .58456 L
.41205 .58939 L
.41544 .59276 L
.41752 .59422 L
.41692 .59905 L
.41563 .60388 L
.42027 .60853 L
.42181 .60872 L
.42084 .61355 L
.42511 .61781 L
.42671 .61838 L
.42592 .62321 L
.42994 .62722 L
.43163 .62804 L
.43096 .63288 L
.43477 .63666 L
.43655 .63771 L
.43599 .64254 L
.4396 .64613 L
.44148 .64737 L
.441 .6522 L
.4402 .65704 L
.44443 .66126 L
.44599 .66187 L
.44541 .6667 L
.44927 .67054 L
.45097 .67153 L
.45051 .67636 L
.44972 .68119 L
.4541 .68557 L
.45556 .68603 L
.45505 .69086 L
.45893 .69472 L
.46056 .69569 L
.46018 .70052 L
.45962 .70535 L
.46376 .70948 L
.46523 .71019 L
.46485 .71502 L
.46426 .71985 L
.46859 .72418 L
.46994 .72468 L
.46959 .72951 L
.46902 .73434 L
.47342 .73874 L
.47469 .73918 L
.47438 .74401 L
.47393 .74884 L
.47826 .75317 L
.47946 .75367 L
.4792 .7585 L
.47888 .76334 L
.48309 .76756 L
.48423 .76817 L
.48403 .773 L
.4838 .77783 L
.4835 .78266 L
.48792 .78711 L
.48879 .7875 L
.48864 .79233 L
.48847 .79716 L
.48827 .80199 L
.49275 .80655 L
.49329 .80682 L
.49318 .81165 L
.49307 .81649 L
.49298 .82132 L
.49289 .82615 L
.4928 .83098 L
.49346 .83581 L
.49288 .84065 L
.49275 .84189 L
.4922 .84548 L
.49146 .85031 L
.49096 .85514 L
.49039 .85997 L
.48977 .8648 L
.489 .86964 L
.48808 .87447 L
.48792 .87535 L
.48755 .8793 L
.48715 .88413 L
.48681 .88896 L
.48652 .8938 L
.48631 .89863 L
.48618 .90346 L
.48615 .90829 L
.48621 .91312 L
.48638 .91796 L
.48667 .92279 L
.48711 .92762 L
.48772 .93245 L
.48792 .93375 L
.48852 .93728 L
.48955 .94211 L
.49101 .94695 L
.49275 .95081 L
.49326 .95178 L
.49735 .95661 L
.49758 .95675 L
.50242 .95675 L
.50265 .95661 L
.50674 .95178 L
.50725 .95082 L
.50899 .94695 L
.51045 .94211 L
.51149 .93728 L
.51208 .93378 L
.51228 .93245 L
.51289 .92762 L
.51333 .92279 L
.51363 .91796 L
.5138 .91312 L
.51386 .90829 L
.51382 .90346 L
.51369 .89863 L
.51348 .8938 L
.5132 .88896 L
.51285 .88413 L
.51245 .8793 L
.51208 .87531 L
.51192 .87447 L
.511 .86964 L
.51023 .8648 L
.50962 .85997 L
.50904 .85514 L
.50855 .85031 L
.5078 .84548 L
.50725 .84186 L
.50712 .84065 L
.50654 .83581 L
.5072 .83098 L
.50711 .82615 L
.50702 .82132 L
.50693 .81649 L
.50682 .81165 L
.50671 .80682 L
.50725 .80655 L
.51173 .80199 L
.51153 .79716 L
.51136 .79233 L
.51121 .7875 L
.51208 .78711 L
.5165 .78266 L
.5162 .77783 L
.51597 .773 L
.51577 .76817 L
.51691 .76756 L
.52112 .76334 L
.5208 .7585 L
.52054 .75367 L
.52174 .75317 L
.52607 .74884 L
.52562 .74401 L
.52531 .73918 L
.52658 .73874 L
.53098 .73434 L
.53041 .72951 L
.53006 .72468 L
.53141 .72418 L
.53574 .71985 L
.53515 .71502 L
.53477 .71019 L
.53624 .70948 L
.54038 .70535 L
.53982 .70052 L
.53944 .69569 L
.54107 .69472 L
.54495 .69086 L
.54444 .68603 L
.5459 .68557 L
.55028 .68119 L
.54949 .67636 L
.54903 .67153 L
.55073 .67054 L
.55459 .6667 L
.55401 .66187 L
.55557 .66126 L
.5598 .65704 L
.559 .6522 L
.55852 .64737 L
.5604 .64613 L
.56401 .64254 L
.56345 .63771 L
.56523 .63666 L
.56904 .63288 L
.56837 .62804 L
.57006 .62722 L
.57408 .62321 L
.57329 .61838 L
.57489 .61781 L
.57916 .61355 L
.57819 .60872 L
.57973 .60853 L
.58437 .60388 L
.58308 .59905 L
.58248 .59422 L
.58456 .59276 L
.58795 .58939 L
.58732 .58456 L
.58939 .58311 L
.59279 .57973 L
.59213 .57489 L
.59422 .57343 L
.59761 .57006 L
.59693 .56523 L
.59905 .56372 L
.6024 .5604 L
.60171 .55557 L
.60388 .55399 L
.60716 .55073 L
.60647 .5459 L
.60872 .54423 L
.6119 .54107 L
.61355 .54054 L
.61786 .53624 L
.61662 .53141 L
.61838 .53057 L
.62239 .52658 L
.62132 .52174 L
.62321 .52064 L
.62696 .51691 L
.626 .51208 L
.62804 .51072 L
.63154 .50725 L
.63067 .50242 L
.63288 .50081 L
.63613 .49758 L
.63771 .49747 L
.64243 .49275 L
.64072 .48792 L
.64254 .48698 L
.64644 .48309 L
.64531 .47826 L
.64737 .47689 L
.65085 .47342 L
.64991 .46859 L
.6522 .46687 L
.65534 .46376 L
.65704 .4631 L
.66121 .45893 L
.65985 .4541 L
.66187 .4528 L
.66534 .44927 L
.66419 .44443 L
.6667 .44255 L
.66967 .4396 L
.67153 .43881 L
.67558 .43477 L
.6741 .42994 L
.67636 .42839 L
.67966 .42511 L
.67857 .42027 L
.68119 .41821 L
.68398 .41544 L
.68603 .41424 L
.68967 .41061 L
.68838 .40578 L
.69086 .40391 L
.69384 .40095 L
.69569 .40011 L
.69969 .39612 L
.69816 .39128 L
.70052 .38956 L
.70365 .38645 L
.70535 .38604 L
.70978 .38162 L
.7079 .37679 L
.71019 .37516 L
.71341 .37196 L
.71224 .36712 L
.71502 .36485 L
.71759 .36229 L
.71985 .3607 L
.7231 .35746 L
.72189 .35263 L
.72468 .35033 L
.72723 .3478 L
.72951 .34616 L
.73272 .34296 L
.7315 .33813 L
.73434 .33576 L
.73682 .3333 L
.73918 .33155 L
.74228 .32847 L
.74401 .3278 L
.74818 .32364 L
.74637 .31881 L
.74884 .31689 L
.75177 .31397 L
.75367 .31291 L
.75744 .30914 L
.75587 .30431 L
.7585 .30217 L
.76122 .29948 L
.76334 .29803 L
.76674 .29465 L
.76534 .28981 L
.76817 .28743 L
.77063 .28498 L
.773 .28317 L
.77603 .28015 L
.77783 .27923 L
.78175 .27532 L
.78002 .27049 L
.78266 .26831 L
.78533 .26566 L
.7875 .26411 L
.7908 .26082 L
.78938 .25599 L
.79233 .25345 L
.79463 .25116 L
.79716 .24912 L
.79996 .24633 L
.80199 .24496 L
.80547 .2415 L
.80393 .23666 L
.80682 .23417 L
.80917 .23183 L
.81165 .22983 L
.8145 .227 L
.81649 .22567 L
.82 .22217 L
.8184 .21734 L
.82132 .21481 L
.82363 .2125 L
.82615 .21044 L
.82893 .20767 L
.83098 .20622 L
.83437 .20284 L
.83281 .19801 L
.83581 .19536 L
.83801 .19318 L
.84065 .19096 L
.84327 .18835 L
.84548 .18665 L
.84863 .18351 L
.85031 .18263 L
.85426 .17868 L
.85231 .17385 L
.85514 .17139 L
.85753 .16902 L
.85997 .167 L
.8628 .16419 L
.8648 .16274 L
.8682 .15935 L
.86964 .15908 L
.8742 .15452 L
.87172 .14969 L
.87447 .1473 L
.87692 .14486 L
.8793 .1429 L
.88218 .14003 L
.88413 .13863 L
.88757 .1352 L
.88896 .135 L
.8936 .13036 L
.891 .12553 L
.8938 .12307 L
.89618 .1207 L
.89863 .11864 L
.90141 .11587 L
.90346 .11429 L
.90672 .11104 L
.90829 .1102 L
.91229 .1062 L
.91017 .10137 L
.91312 .09872 L
.91531 .09654 L
.91796 .09423 L
.92048 .09171 L
.92279 .08979 L
.92571 .08688 L
.92762 .08545 L
.93103 .08204 L
.93245 .08143 L
.93667 .07721 L
.93433 .07238 L
.93728 .0697 L
.93945 .06755 L
.94211 .06518 L
.94459 .06272 L
.94695 .0607 L
.94977 .05789 L
.95178 .05629 L
.95502 .05305 L
.95661 .05204 L
.96043 .04822 L
.95833 .04339 L
.96144 .04052 L
.96341 .03856 L
.96627 .03595 L
.9685 .03373 L
.97111 .0314 L
.97362 .02889 L
.97594 .02689 L
.97972 .02406 L
.98077 .02145 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .02145 m
.02028 .02406 L
.02406 .02689 L
.02638 .02889 L
.02889 .0314 L
.0315 .03373 L
.03373 .03595 L
.03659 .03856 L
.03856 .04052 L
.04167 .04339 L
.03957 .04822 L
.04339 .05204 L
.04498 .05305 L
.04822 .05629 L
.05023 .05789 L
.05305 .0607 L
.05541 .06272 L
.05789 .06518 L
.06055 .06755 L
.06272 .0697 L
.06567 .07238 L
.06333 .07721 L
.06755 .08143 L
.06897 .08204 L
.07238 .08545 L
.07429 .08688 L
.07721 .08979 L
.07952 .09171 L
.08204 .09423 L
.08469 .09654 L
.08688 .09872 L
.08983 .10137 L
.08771 .1062 L
.09171 .1102 L
.09328 .11104 L
.09654 .11429 L
.09859 .11587 L
.10137 .11864 L
.10382 .1207 L
.1062 .12307 L
.109 .12553 L
.1064 .13036 L
.11104 .135 L
.11243 .1352 L
.11587 .13863 L
.11782 .14003 L
.1207 .1429 L
.12308 .14486 L
.12553 .1473 L
.12828 .14969 L
Mistroke
.1258 .15452 L
.13036 .15908 L
.1318 .15935 L
.1352 .16274 L
.1372 .16419 L
.14003 .167 L
.14247 .16902 L
.14486 .17139 L
.14769 .17385 L
.14574 .17868 L
.14969 .18263 L
.15137 .18351 L
.15452 .18665 L
.15673 .18835 L
.15935 .19096 L
.16199 .19318 L
.16419 .19536 L
.16719 .19801 L
.16563 .20284 L
.16902 .20622 L
.17107 .20767 L
.17385 .21044 L
.17637 .2125 L
.17868 .21481 L
.1816 .21734 L
.18 .22217 L
.18351 .22567 L
.1855 .227 L
.18835 .22983 L
.19083 .23183 L
.19318 .23417 L
.19607 .23666 L
.19453 .2415 L
.19801 .24496 L
.20004 .24633 L
.20284 .24912 L
.20537 .25116 L
.20767 .25345 L
.21062 .25599 L
.2092 .26082 L
.2125 .26411 L
.21467 .26566 L
.21734 .26831 L
.21998 .27049 L
.21825 .27532 L
.22217 .27923 L
.22397 .28015 L
.227 .28317 L
.22937 .28498 L
.23183 .28743 L
Mistroke
.23466 .28981 L
.23326 .29465 L
.23666 .29803 L
.23878 .29948 L
.2415 .30217 L
.24413 .30431 L
.24256 .30914 L
.24633 .31291 L
.24823 .31397 L
.25116 .31689 L
.25363 .31881 L
.25182 .32364 L
.25599 .3278 L
.25772 .32847 L
.26082 .33155 L
.26318 .3333 L
.26566 .33576 L
.2685 .33813 L
.26728 .34296 L
.27049 .34616 L
.27277 .3478 L
.27532 .35033 L
.27811 .35263 L
.2769 .35746 L
.28015 .3607 L
.28241 .36229 L
.28498 .36485 L
.28776 .36712 L
.28659 .37196 L
.28981 .37516 L
.2921 .37679 L
.29022 .38162 L
.29465 .38604 L
.29635 .38645 L
.29948 .38956 L
.30184 .39128 L
.30031 .39612 L
.30431 .40011 L
.30616 .40095 L
.30914 .40391 L
.31162 .40578 L
.31033 .41061 L
.31397 .41424 L
.31602 .41544 L
.31881 .41821 L
.32143 .42027 L
.32034 .42511 L
.32364 .42839 L
.3259 .42994 L
.32442 .43477 L
Mistroke
.32847 .43881 L
.33033 .4396 L
.3333 .44255 L
.33581 .44443 L
.33466 .44927 L
.33813 .4528 L
.34015 .4541 L
.33879 .45893 L
.34296 .4631 L
.34466 .46376 L
.3478 .46687 L
.35009 .46859 L
.34915 .47342 L
.35263 .47689 L
.35469 .47826 L
.35356 .48309 L
.35746 .48698 L
.35928 .48792 L
.35757 .49275 L
.36229 .49747 L
.36387 .49758 L
.36712 .50081 L
.36933 .50242 L
.36846 .50725 L
.37196 .51072 L
.374 .51208 L
.37304 .51691 L
.37679 .52064 L
.37868 .52174 L
.37761 .52658 L
.38162 .53057 L
.38338 .53141 L
.38214 .53624 L
.38645 .54054 L
.3881 .54107 L
.39128 .54423 L
.39353 .5459 L
.39284 .55073 L
.39612 .55399 L
.39829 .55557 L
.3976 .5604 L
.40095 .56372 L
.40307 .56523 L
.40239 .57006 L
.40578 .57343 L
.40787 .57489 L
.40721 .57973 L
.41061 .58311 L
.41268 .58456 L
.41205 .58939 L
Mistroke
.41544 .59276 L
.41752 .59422 L
.41692 .59905 L
.41563 .60388 L
.42027 .60853 L
.42181 .60872 L
.42084 .61355 L
.42511 .61781 L
.42671 .61838 L
.42592 .62321 L
.42994 .62722 L
.43163 .62804 L
.43096 .63288 L
.43477 .63666 L
.43655 .63771 L
.43599 .64254 L
.4396 .64613 L
.44148 .64737 L
.441 .6522 L
.4402 .65704 L
.44443 .66126 L
.44599 .66187 L
.44541 .6667 L
.44927 .67054 L
.45097 .67153 L
.45051 .67636 L
.44972 .68119 L
.4541 .68557 L
.45556 .68603 L
.45505 .69086 L
.45893 .69472 L
.46056 .69569 L
.46018 .70052 L
.45962 .70535 L
.46376 .70948 L
.46523 .71019 L
.46485 .71502 L
.46426 .71985 L
.46859 .72418 L
.46994 .72468 L
.46959 .72951 L
.46902 .73434 L
.47342 .73874 L
.47469 .73918 L
.47438 .74401 L
.47393 .74884 L
.47826 .75317 L
.47946 .75367 L
.4792 .7585 L
.47888 .76334 L
Mistroke
.48309 .76756 L
.48423 .76817 L
.48403 .773 L
.4838 .77783 L
.4835 .78266 L
.48792 .78711 L
.48879 .7875 L
.48864 .79233 L
.48847 .79716 L
.48827 .80199 L
.49275 .80655 L
.49329 .80682 L
.49318 .81165 L
.49307 .81649 L
.49298 .82132 L
.49289 .82615 L
.4928 .83098 L
.49346 .83581 L
.49288 .84065 L
.49275 .84189 L
.4922 .84548 L
.49146 .85031 L
.49096 .85514 L
.49039 .85997 L
.48977 .8648 L
.489 .86964 L
.48808 .87447 L
.48792 .87535 L
.48755 .8793 L
.48715 .88413 L
.48681 .88896 L
.48652 .8938 L
.48631 .89863 L
.48618 .90346 L
.48615 .90829 L
.48621 .91312 L
.48638 .91796 L
.48667 .92279 L
.48711 .92762 L
.48772 .93245 L
.48792 .93375 L
.48852 .93728 L
.48955 .94211 L
.49101 .94695 L
.49275 .95081 L
.49326 .95178 L
.49735 .95661 L
.49758 .95675 L
.50242 .95675 L
.50265 .95661 L
Mistroke
.50674 .95178 L
.50725 .95082 L
.50899 .94695 L
.51045 .94211 L
.51149 .93728 L
.51208 .93378 L
.51228 .93245 L
.51289 .92762 L
.51333 .92279 L
.51363 .91796 L
.5138 .91312 L
.51386 .90829 L
.51382 .90346 L
.51369 .89863 L
.51348 .8938 L
.5132 .88896 L
.51285 .88413 L
.51245 .8793 L
.51208 .87531 L
.51192 .87447 L
.511 .86964 L
.51023 .8648 L
.50962 .85997 L
.50904 .85514 L
.50855 .85031 L
.5078 .84548 L
.50725 .84186 L
.50712 .84065 L
.50654 .83581 L
.5072 .83098 L
.50711 .82615 L
.50702 .82132 L
.50693 .81649 L
.50682 .81165 L
.50671 .80682 L
.50725 .80655 L
.51173 .80199 L
.51153 .79716 L
.51136 .79233 L
.51121 .7875 L
.51208 .78711 L
.5165 .78266 L
.5162 .77783 L
.51597 .773 L
.51577 .76817 L
.51691 .76756 L
.52112 .76334 L
.5208 .7585 L
.52054 .75367 L
.52174 .75317 L
Mistroke
.52607 .74884 L
.52562 .74401 L
.52531 .73918 L
.52658 .73874 L
.53098 .73434 L
.53041 .72951 L
.53006 .72468 L
.53141 .72418 L
.53574 .71985 L
.53515 .71502 L
.53477 .71019 L
.53624 .70948 L
.54038 .70535 L
.53982 .70052 L
.53944 .69569 L
.54107 .69472 L
.54495 .69086 L
.54444 .68603 L
.5459 .68557 L
.55028 .68119 L
.54949 .67636 L
.54903 .67153 L
.55073 .67054 L
.55459 .6667 L
.55401 .66187 L
.55557 .66126 L
.5598 .65704 L
.559 .6522 L
.55852 .64737 L
.5604 .64613 L
.56401 .64254 L
.56345 .63771 L
.56523 .63666 L
.56904 .63288 L
.56837 .62804 L
.57006 .62722 L
.57408 .62321 L
.57329 .61838 L
.57489 .61781 L
.57916 .61355 L
.57819 .60872 L
.57973 .60853 L
.58437 .60388 L
.58308 .59905 L
.58248 .59422 L
.58456 .59276 L
.58795 .58939 L
.58732 .58456 L
.58939 .58311 L
.59279 .57973 L
Mistroke
.59213 .57489 L
.59422 .57343 L
.59761 .57006 L
.59693 .56523 L
.59905 .56372 L
.6024 .5604 L
.60171 .55557 L
.60388 .55399 L
.60716 .55073 L
.60647 .5459 L
.60872 .54423 L
.6119 .54107 L
.61355 .54054 L
.61786 .53624 L
.61662 .53141 L
.61838 .53057 L
.62239 .52658 L
.62132 .52174 L
.62321 .52064 L
.62696 .51691 L
.626 .51208 L
.62804 .51072 L
.63154 .50725 L
.63067 .50242 L
.63288 .50081 L
.63613 .49758 L
.63771 .49747 L
.64243 .49275 L
.64072 .48792 L
.64254 .48698 L
.64644 .48309 L
.64531 .47826 L
.64737 .47689 L
.65085 .47342 L
.64991 .46859 L
.6522 .46687 L
.65534 .46376 L
.65704 .4631 L
.66121 .45893 L
.65985 .4541 L
.66187 .4528 L
.66534 .44927 L
.66419 .44443 L
.6667 .44255 L
.66967 .4396 L
.67153 .43881 L
.67558 .43477 L
.6741 .42994 L
.67636 .42839 L
.67966 .42511 L
Mistroke
.67857 .42027 L
.68119 .41821 L
.68398 .41544 L
.68603 .41424 L
.68967 .41061 L
.68838 .40578 L
.69086 .40391 L
.69384 .40095 L
.69569 .40011 L
.69969 .39612 L
.69816 .39128 L
.70052 .38956 L
.70365 .38645 L
.70535 .38604 L
.70978 .38162 L
.7079 .37679 L
.71019 .37516 L
.71341 .37196 L
.71224 .36712 L
.71502 .36485 L
.71759 .36229 L
.71985 .3607 L
.7231 .35746 L
.72189 .35263 L
.72468 .35033 L
.72723 .3478 L
.72951 .34616 L
.73272 .34296 L
.7315 .33813 L
.73434 .33576 L
.73682 .3333 L
.73918 .33155 L
.74228 .32847 L
.74401 .3278 L
.74818 .32364 L
.74637 .31881 L
.74884 .31689 L
.75177 .31397 L
.75367 .31291 L
.75744 .30914 L
.75587 .30431 L
.7585 .30217 L
.76122 .29948 L
.76334 .29803 L
.76674 .29465 L
.76534 .28981 L
.76817 .28743 L
.77063 .28498 L
.773 .28317 L
.77603 .28015 L
Mistroke
.77783 .27923 L
.78175 .27532 L
.78002 .27049 L
.78266 .26831 L
.78533 .26566 L
.7875 .26411 L
.7908 .26082 L
.78938 .25599 L
.79233 .25345 L
.79463 .25116 L
.79716 .24912 L
.79996 .24633 L
.80199 .24496 L
.80547 .2415 L
.80393 .23666 L
.80682 .23417 L
.80917 .23183 L
.81165 .22983 L
.8145 .227 L
.81649 .22567 L
.82 .22217 L
.8184 .21734 L
.82132 .21481 L
.82363 .2125 L
.82615 .21044 L
.82893 .20767 L
.83098 .20622 L
.83437 .20284 L
.83281 .19801 L
.83581 .19536 L
.83801 .19318 L
.84065 .19096 L
.84327 .18835 L
.84548 .18665 L
.84863 .18351 L
.85031 .18263 L
.85426 .17868 L
.85231 .17385 L
.85514 .17139 L
.85753 .16902 L
.85997 .167 L
.8628 .16419 L
.8648 .16274 L
.8682 .15935 L
.86964 .15908 L
.8742 .15452 L
.87172 .14969 L
.87447 .1473 L
.87692 .14486 L
.8793 .1429 L
Mistroke
.88218 .14003 L
.88413 .13863 L
.88757 .1352 L
.88896 .135 L
.8936 .13036 L
.891 .12553 L
.8938 .12307 L
.89618 .1207 L
.89863 .11864 L
.90141 .11587 L
.90346 .11429 L
.90672 .11104 L
.90829 .1102 L
.91229 .1062 L
.91017 .10137 L
.91312 .09872 L
.91531 .09654 L
.91796 .09423 L
.92048 .09171 L
.92279 .08979 L
.92571 .08688 L
.92762 .08545 L
.93103 .08204 L
.93245 .08143 L
.93667 .07721 L
.93433 .07238 L
.93728 .0697 L
.93945 .06755 L
.94211 .06518 L
.94459 .06272 L
.94695 .0607 L
.94977 .05789 L
.95178 .05629 L
.95502 .05305 L
.95661 .05204 L
.96043 .04822 L
.95833 .04339 L
.96144 .04052 L
.96341 .03856 L
.96627 .03595 L
.9685 .03373 L
.97111 .0314 L
.97362 .02889 L
.97594 .02689 L
.97972 .02406 L
.98077 .02145 L
Mfstroke
.775 .756 0 r
.01923 .02155 m
.02021 .02406 L
.02406 .027 L
.02625 .02889 L
.02889 .03153 L
.03135 .03373 L
.03373 .03609 L
.03643 .03856 L
.03856 .04068 L
.04149 .04339 L
.03951 .04822 L
.04339 .0521 L
.04489 .05305 L
.04822 .05638 L
.05012 .05789 L
.05305 .06081 L
.05528 .06272 L
.05789 .06531 L
.0604 .06755 L
.06272 .06986 L
.0655 .07238 L
.06329 .07721 L
.06755 .08147 L
.06889 .08204 L
.07238 .08553 L
.07419 .08688 L
.07721 .08989 L
.07939 .09171 L
.08204 .09435 L
.08454 .09654 L
.08688 .09887 L
.08966 .10137 L
.08766 .1062 L
.09171 .11025 L
.09319 .11104 L
.09654 .11438 L
.09848 .11587 L
.10137 .11875 L
.10368 .1207 L
.1062 .12321 L
.10884 .12553 L
.10639 .13036 L
.11104 .13501 L
.11235 .1352 L
.11587 .13871 L
.11771 .14003 L
.1207 .14301 L
.12295 .14486 L
.12553 .14743 L
.12813 .14969 L
.12579 .15452 L
.13036 .1591 L
.13172 .15935 L
.1352 .16282 L
.13709 .16419 L
.14003 .16711 L
.14234 .16902 L
.14486 .17153 L
.14752 .17385 L
.14569 .17868 L
.14969 .18268 L
.15128 .18351 L
.15452 .18675 L
.15661 .18835 L
.15935 .19108 L
.16184 .19318 L
.16419 .19551 L
.16702 .19801 L
.16555 .20284 L
.16902 .2063 L
.17095 .20767 L
.17385 .21056 L
.17623 .2125 L
.17868 .21495 L
.18143 .21734 L
.17993 .22217 L
.18351 .22574 L
.18539 .227 L
.18835 .22994 L
.19069 .23183 L
.19318 .23431 L
.19591 .23666 L
.19446 .2415 L
.19801 .24504 L
.19992 .24633 L
.20284 .24923 L
.20522 .25116 L
.20767 .25359 L
.21045 .25599 L
.20912 .26082 L
.2125 .2642 L
.21455 .26566 L
.21734 .26843 L
.21983 .27049 L
.2182 .27532 L
.22217 .27928 L
.22387 .28015 L
.227 .28327 L
.22924 .28498 L
.23183 .28756 L
.2345 .28981 L
.23319 .29465 L
.23666 .29811 L
.23867 .29948 L
.2415 .30229 L
.24398 .30431 L
.2425 .30914 L
.24633 .31296 L
.24813 .31397 L
.25116 .31699 L
.25349 .31881 L
.25179 .32364 L
.25599 .32784 L
.25763 .32847 L
.26082 .33165 L
.26304 .3333 L
.26566 .33589 L
.26834 .33813 L
.26719 .34296 L
.27049 .34625 L
.27264 .3478 L
.27532 .35046 L
.27795 .35263 L
.27681 .35746 L
.28015 .36079 L
.28228 .36229 L
.28498 .36497 L
.2876 .36712 L
.2865 .37196 L
.28981 .37525 L
.29197 .37679 L
.2902 .38162 L
.29465 .38607 L
.29626 .38645 L
.29948 .38966 L
.30171 .39128 L
.30026 .39612 L
.30431 .40016 L
.30606 .40095 L
.30914 .40401 L
.31148 .40578 L
.31027 .41061 L
.31397 .41431 L
.3159 .41544 L
.31881 .41832 L
.32129 .42027 L
.32025 .42511 L
.32364 .42847 L
.32577 .42994 L
.32438 .43477 L
.32847 .43885 L
.33023 .4396 L
.3333 .44266 L
.33567 .44443 L
.33459 .44927 L
.33813 .45288 L
.34003 .4541 L
.33875 .45893 L
.34296 .46314 L
.34456 .46376 L
.3478 .46698 L
.34995 .46859 L
.34907 .47342 L
.35263 .47697 L
.35456 .47826 L
.3535 .48309 L
.35746 .48703 L
.35917 .48792 L
.35757 .49275 L
.36229 .49748 L
.36378 .49758 L
.36712 .50091 L
.3692 .50242 L
.36838 .50725 L
.37196 .5108 L
.37388 .51208 L
.37298 .51691 L
.37679 .52071 L
.37857 .52174 L
.37756 .52658 L
.38162 .53062 L
.38328 .53141 L
.38211 .53624 L
.38645 .54057 L
.388 .54107 L
.39128 .54433 L
.39339 .5459 L
.39274 .55073 L
.39612 .55409 L
.39816 .55557 L
.39751 .5604 L
.40095 .56382 L
.40294 .56523 L
.4023 .57006 L
.40578 .57352 L
.40774 .57489 L
.40712 .57973 L
.41061 .5832 L
.41256 .58456 L
.41196 .58939 L
.41544 .59285 L
.41739 .59422 L
.41683 .59905 L
.41562 .60388 L
.42027 .60854 L
.42171 .60872 L
.4208 .61355 L
.42511 .61785 L
.42661 .61838 L
.42587 .62321 L
.42994 .62727 L
.43152 .62804 L
.4309 .63288 L
.43477 .63673 L
.43644 .63771 L
.43591 .64254 L
.4396 .64621 L
.44136 .64737 L
.44091 .6522 L
.44016 .65704 L
.44443 .6613 L
.44589 .66187 L
.44535 .6667 L
.44927 .6706 L
.45085 .67153 L
.45043 .67636 L
.44969 .68119 L
.4541 .6856 L
.45546 .68603 L
.45498 .69086 L
.45893 .69479 L
.46045 .69569 L
.46009 .70052 L
.45957 .70535 L
.46376 .70953 L
.46513 .71019 L
.46478 .71502 L
.46422 .71985 L
.46859 .72422 L
.46984 .72468 L
.46951 .72951 L
.46899 .73434 L
.47342 .73878 L
.47459 .73918 L
.4743 .74401 L
.47389 .74884 L
.47826 .75321 L
.47936 .75367 L
.47913 .7585 L
.47882 .76334 L
.48309 .76761 L
.48413 .76817 L
.48394 .773 L
.48374 .77783 L
.48346 .78266 L
.48792 .78715 L
.4887 .7875 L
.48856 .79233 L
.48841 .79716 L
.48823 .80199 L
.49275 .80659 L
.4932 .80682 L
.4931 .81165 L
.49301 .81649 L
.49292 .82132 L
.49284 .82615 L
.49278 .83098 L
.49292 .83581 L
.49275 .83729 L
.49218 .84065 L
.49136 .84548 L
.49055 .85031 L
.4901 .85514 L
.48938 .85997 L
.48845 .8648 L
.48792 .86689 L
.48759 .86964 L
.48704 .87447 L
.48654 .8793 L
.48609 .88413 L
.48569 .88896 L
.48536 .8938 L
.4851 .89863 L
.48492 .90346 L
.48483 .90829 L
.48482 .91312 L
.48492 .91796 L
.48513 .92279 L
.48546 .92762 L
.48594 .93245 L
.48658 .93728 L
.48742 .94211 L
.48792 .94443 L
.48849 .94695 L
.48987 .95178 L
.49197 .95661 L
.49275 .95791 L
.49541 .96144 L
.49758 .96308 L
.50242 .96308 L
.50459 .96144 L
.50725 .95792 L
.50803 .95661 L
.51013 .95178 L
.51151 .94695 L
.51208 .94445 L
.51258 .94211 L
.51343 .93728 L
.51407 .93245 L
.51454 .92762 L
.51488 .92279 L
.51508 .91796 L
.51518 .91312 L
.51518 .90829 L
.51508 .90346 L
.5149 .89863 L
.51464 .8938 L
.51431 .88896 L
.51392 .88413 L
.51346 .8793 L
.51296 .87447 L
.51241 .86964 L
.51208 .86685 L
.51156 .8648 L
.51063 .85997 L
.50991 .85514 L
.50946 .85031 L
.50864 .84548 L
.50782 .84065 L
.50725 .83726 L
.50708 .83581 L
.50722 .83098 L
.50716 .82615 L
.50708 .82132 L
.50699 .81649 L
.5069 .81165 L
.5068 .80682 L
.50725 .80659 L
.51177 .80199 L
.51159 .79716 L
.51144 .79233 L
.5113 .7875 L
.51208 .78715 L
.51654 .78266 L
.51626 .77783 L
.51606 .773 L
.51587 .76817 L
.51691 .76761 L
.52118 .76334 L
.52087 .7585 L
.52064 .75367 L
.52174 .75321 L
.52611 .74884 L
.5257 .74401 L
.52541 .73918 L
.52658 .73878 L
.53101 .73434 L
.53049 .72951 L
.53016 .72468 L
.53141 .72422 L
.53578 .71985 L
.53522 .71502 L
.53487 .71019 L
.53624 .70953 L
.54043 .70535 L
.53991 .70052 L
.53955 .69569 L
.54107 .69479 L
.54502 .69086 L
.54454 .68603 L
.5459 .6856 L
.55031 .68119 L
.54957 .67636 L
.54915 .67153 L
.55073 .6706 L
.55465 .6667 L
.55411 .66187 L
.55557 .6613 L
.55984 .65704 L
.55909 .6522 L
.55864 .64737 L
.5604 .64621 L
.56409 .64254 L
.56356 .63771 L
.56523 .63673 L
.5691 .63288 L
.56848 .62804 L
.57006 .62727 L
.57413 .62321 L
.57339 .61838 L
.57489 .61785 L
.5792 .61355 L
.57829 .60872 L
.57973 .60854 L
.58438 .60388 L
.58317 .59905 L
.58261 .59422 L
.58456 .59285 L
.58804 .58939 L
.58744 .58456 L
.58939 .5832 L
.59288 .57973 L
.59226 .57489 L
.59422 .57352 L
.5977 .57006 L
.59706 .56523 L
.59905 .56381 L
.60249 .5604 L
.60184 .55557 L
.60388 .55409 L
.60726 .55073 L
.60661 .5459 L
.60872 .54433 L
.612 .54107 L
.61355 .54057 L
.61789 .53624 L
.61672 .53141 L
.61838 .53062 L
.62244 .52658 L
.62143 .52174 L
.62321 .52071 L
.62702 .51691 L
.62612 .51208 L
.62804 .5108 L
.63162 .50725 L
.6308 .50242 L
.63288 .50091 L
.63622 .49758 L
.63771 .49748 L
.64243 .49275 L
.64083 .48792 L
.64254 .48703 L
.6465 .48309 L
.64544 .47826 L
.64737 .47697 L
.65093 .47342 L
.65005 .46859 L
.6522 .46698 L
.65544 .46376 L
.65704 .46314 L
.66125 .45893 L
.65997 .4541 L
.66187 .45288 L
.66541 .44927 L
.66433 .44443 L
.6667 .44266 L
.66977 .4396 L
.67153 .43885 L
.67562 .43477 L
.67423 .42994 L
.67636 .42847 L
.67975 .42511 L
.67871 .42027 L
.68119 .41832 L
.6841 .41544 L
.68603 .41431 L
.68973 .41061 L
.68852 .40578 L
.69086 .40401 L
.69394 .40095 L
.69569 .40016 L
.69974 .39612 L
.69829 .39128 L
.70052 .38966 L
.70374 .38645 L
.70535 .38607 L
.7098 .38162 L
.70802 .37679 L
.71019 .37525 L
.7135 .37196 L
.7124 .36712 L
.71502 .36497 L
.71772 .36229 L
.71985 .36079 L
.72319 .35746 L
.72205 .35263 L
.72468 .35046 L
.72736 .3478 L
.72951 .34625 L
.73281 .34296 L
.73166 .33813 L
.73434 .33589 L
.73696 .3333 L
.73918 .33165 L
.74237 .32847 L
.74401 .32784 L
.74821 .32364 L
.74651 .31881 L
.74884 .31699 L
.75187 .31397 L
.75367 .31296 L
.7575 .30914 L
.75602 .30431 L
.7585 .30229 L
.76133 .29948 L
.76334 .29811 L
.76681 .29465 L
.7655 .28981 L
.76817 .28756 L
.77076 .28498 L
.773 .28327 L
.77613 .28015 L
.77783 .27928 L
.7818 .27532 L
.78017 .27049 L
.78266 .26843 L
.78545 .26566 L
.7875 .2642 L
.79088 .26082 L
.78955 .25599 L
.79233 .25359 L
.79477 .25116 L
.79716 .24923 L
.80008 .24633 L
.80199 .24504 L
.80554 .2415 L
.80409 .23666 L
.80682 .23431 L
.80931 .23183 L
.81165 .22994 L
.81461 .227 L
.81649 .22574 L
.82007 .22217 L
.81857 .21734 L
.82132 .21495 L
.82377 .2125 L
.82615 .21056 L
.82905 .20767 L
.83098 .2063 L
.83445 .20284 L
.83298 .19801 L
.83581 .19551 L
.83816 .19318 L
.84065 .19108 L
.84339 .18835 L
.84548 .18675 L
.84872 .18351 L
.85031 .18268 L
.85431 .17868 L
.85248 .17385 L
.85514 .17153 L
.85766 .16902 L
.85997 .16711 L
.86291 .16419 L
.8648 .16282 L
.86828 .15935 L
.86964 .1591 L
.87421 .15452 L
.87187 .14969 L
.87447 .14743 L
.87705 .14486 L
.8793 .14301 L
.88229 .14003 L
.88413 .13871 L
.88765 .1352 L
.88896 .13501 L
.89361 .13036 L
.89116 .12553 L
.8938 .12321 L
.89632 .1207 L
.89863 .11875 L
.90152 .11587 L
.90346 .11438 L
.90681 .11104 L
.90829 .11025 L
.91234 .1062 L
.91034 .10137 L
.91312 .09887 L
.91546 .09654 L
.91796 .09435 L
.92061 .09171 L
.92279 .08989 L
.92581 .08688 L
.92762 .08553 L
.93111 .08204 L
.93245 .08147 L
.93671 .07721 L
.9345 .07238 L
.93728 .06986 L
.9396 .06755 L
.94211 .06531 L
.94472 .06272 L
.94695 .06081 L
.94988 .05789 L
.95178 .05638 L
.95511 .05305 L
.95661 .0521 L
.96049 .04822 L
.95851 .04339 L
.96144 .04068 L
.96357 .03856 L
.96627 .03609 L
.96865 .03373 L
.97111 .03153 L
.97375 .02889 L
.97594 .027 L
.97979 .02406 L
.98077 .02155 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .02155 m
.02021 .02406 L
.02406 .027 L
.02625 .02889 L
.02889 .03153 L
.03135 .03373 L
.03373 .03609 L
.03643 .03856 L
.03856 .04068 L
.04149 .04339 L
.03951 .04822 L
.04339 .0521 L
.04489 .05305 L
.04822 .05638 L
.05012 .05789 L
.05305 .06081 L
.05528 .06272 L
.05789 .06531 L
.0604 .06755 L
.06272 .06986 L
.0655 .07238 L
.06329 .07721 L
.06755 .08147 L
.06889 .08204 L
.07238 .08553 L
.07419 .08688 L
.07721 .08989 L
.07939 .09171 L
.08204 .09435 L
.08454 .09654 L
.08688 .09887 L
.08966 .10137 L
.08766 .1062 L
.09171 .11025 L
.09319 .11104 L
.09654 .11438 L
.09848 .11587 L
.10137 .11875 L
.10368 .1207 L
.1062 .12321 L
.10884 .12553 L
.10639 .13036 L
.11104 .13501 L
.11235 .1352 L
.11587 .13871 L
.11771 .14003 L
.1207 .14301 L
.12295 .14486 L
.12553 .14743 L
.12813 .14969 L
Mistroke
.12579 .15452 L
.13036 .1591 L
.13172 .15935 L
.1352 .16282 L
.13709 .16419 L
.14003 .16711 L
.14234 .16902 L
.14486 .17153 L
.14752 .17385 L
.14569 .17868 L
.14969 .18268 L
.15128 .18351 L
.15452 .18675 L
.15661 .18835 L
.15935 .19108 L
.16184 .19318 L
.16419 .19551 L
.16702 .19801 L
.16555 .20284 L
.16902 .2063 L
.17095 .20767 L
.17385 .21056 L
.17623 .2125 L
.17868 .21495 L
.18143 .21734 L
.17993 .22217 L
.18351 .22574 L
.18539 .227 L
.18835 .22994 L
.19069 .23183 L
.19318 .23431 L
.19591 .23666 L
.19446 .2415 L
.19801 .24504 L
.19992 .24633 L
.20284 .24923 L
.20522 .25116 L
.20767 .25359 L
.21045 .25599 L
.20912 .26082 L
.2125 .2642 L
.21455 .26566 L
.21734 .26843 L
.21983 .27049 L
.2182 .27532 L
.22217 .27928 L
.22387 .28015 L
.227 .28327 L
.22924 .28498 L
.23183 .28756 L
Mistroke
.2345 .28981 L
.23319 .29465 L
.23666 .29811 L
.23867 .29948 L
.2415 .30229 L
.24398 .30431 L
.2425 .30914 L
.24633 .31296 L
.24813 .31397 L
.25116 .31699 L
.25349 .31881 L
.25179 .32364 L
.25599 .32784 L
.25763 .32847 L
.26082 .33165 L
.26304 .3333 L
.26566 .33589 L
.26834 .33813 L
.26719 .34296 L
.27049 .34625 L
.27264 .3478 L
.27532 .35046 L
.27795 .35263 L
.27681 .35746 L
.28015 .36079 L
.28228 .36229 L
.28498 .36497 L
.2876 .36712 L
.2865 .37196 L
.28981 .37525 L
.29197 .37679 L
.2902 .38162 L
.29465 .38607 L
.29626 .38645 L
.29948 .38966 L
.30171 .39128 L
.30026 .39612 L
.30431 .40016 L
.30606 .40095 L
.30914 .40401 L
.31148 .40578 L
.31027 .41061 L
.31397 .41431 L
.3159 .41544 L
.31881 .41832 L
.32129 .42027 L
.32025 .42511 L
.32364 .42847 L
.32577 .42994 L
.32438 .43477 L
Mistroke
.32847 .43885 L
.33023 .4396 L
.3333 .44266 L
.33567 .44443 L
.33459 .44927 L
.33813 .45288 L
.34003 .4541 L
.33875 .45893 L
.34296 .46314 L
.34456 .46376 L
.3478 .46698 L
.34995 .46859 L
.34907 .47342 L
.35263 .47697 L
.35456 .47826 L
.3535 .48309 L
.35746 .48703 L
.35917 .48792 L
.35757 .49275 L
.36229 .49748 L
.36378 .49758 L
.36712 .50091 L
.3692 .50242 L
.36838 .50725 L
.37196 .5108 L
.37388 .51208 L
.37298 .51691 L
.37679 .52071 L
.37857 .52174 L
.37756 .52658 L
.38162 .53062 L
.38328 .53141 L
.38211 .53624 L
.38645 .54057 L
.388 .54107 L
.39128 .54433 L
.39339 .5459 L
.39274 .55073 L
.39612 .55409 L
.39816 .55557 L
.39751 .5604 L
.40095 .56382 L
.40294 .56523 L
.4023 .57006 L
.40578 .57352 L
.40774 .57489 L
.40712 .57973 L
.41061 .5832 L
.41256 .58456 L
.41196 .58939 L
Mistroke
.41544 .59285 L
.41739 .59422 L
.41683 .59905 L
.41562 .60388 L
.42027 .60854 L
.42171 .60872 L
.4208 .61355 L
.42511 .61785 L
.42661 .61838 L
.42587 .62321 L
.42994 .62727 L
.43152 .62804 L
.4309 .63288 L
.43477 .63673 L
.43644 .63771 L
.43591 .64254 L
.4396 .64621 L
.44136 .64737 L
.44091 .6522 L
.44016 .65704 L
.44443 .6613 L
.44589 .66187 L
.44535 .6667 L
.44927 .6706 L
.45085 .67153 L
.45043 .67636 L
.44969 .68119 L
.4541 .6856 L
.45546 .68603 L
.45498 .69086 L
.45893 .69479 L
.46045 .69569 L
.46009 .70052 L
.45957 .70535 L
.46376 .70953 L
.46513 .71019 L
.46478 .71502 L
.46422 .71985 L
.46859 .72422 L
.46984 .72468 L
.46951 .72951 L
.46899 .73434 L
.47342 .73878 L
.47459 .73918 L
.4743 .74401 L
.47389 .74884 L
.47826 .75321 L
.47936 .75367 L
.47913 .7585 L
.47882 .76334 L
Mistroke
.48309 .76761 L
.48413 .76817 L
.48394 .773 L
.48374 .77783 L
.48346 .78266 L
.48792 .78715 L
.4887 .7875 L
.48856 .79233 L
.48841 .79716 L
.48823 .80199 L
.49275 .80659 L
.4932 .80682 L
.4931 .81165 L
.49301 .81649 L
.49292 .82132 L
.49284 .82615 L
.49278 .83098 L
.49292 .83581 L
.49275 .83729 L
.49218 .84065 L
.49136 .84548 L
.49055 .85031 L
.4901 .85514 L
.48938 .85997 L
.48845 .8648 L
.48792 .86689 L
.48759 .86964 L
.48704 .87447 L
.48654 .8793 L
.48609 .88413 L
.48569 .88896 L
.48536 .8938 L
.4851 .89863 L
.48492 .90346 L
.48483 .90829 L
.48482 .91312 L
.48492 .91796 L
.48513 .92279 L
.48546 .92762 L
.48594 .93245 L
.48658 .93728 L
.48742 .94211 L
.48792 .94443 L
.48849 .94695 L
.48987 .95178 L
.49197 .95661 L
.49275 .95791 L
.49541 .96144 L
.49758 .96308 L
.50242 .96308 L
Mistroke
.50459 .96144 L
.50725 .95792 L
.50803 .95661 L
.51013 .95178 L
.51151 .94695 L
.51208 .94445 L
.51258 .94211 L
.51343 .93728 L
.51407 .93245 L
.51454 .92762 L
.51488 .92279 L
.51508 .91796 L
.51518 .91312 L
.51518 .90829 L
.51508 .90346 L
.5149 .89863 L
.51464 .8938 L
.51431 .88896 L
.51392 .88413 L
.51346 .8793 L
.51296 .87447 L
.51241 .86964 L
.51208 .86685 L
.51156 .8648 L
.51063 .85997 L
.50991 .85514 L
.50946 .85031 L
.50864 .84548 L
.50782 .84065 L
.50725 .83726 L
.50708 .83581 L
.50722 .83098 L
.50716 .82615 L
.50708 .82132 L
.50699 .81649 L
.5069 .81165 L
.5068 .80682 L
.50725 .80659 L
.51177 .80199 L
.51159 .79716 L
.51144 .79233 L
.5113 .7875 L
.51208 .78715 L
.51654 .78266 L
.51626 .77783 L
.51606 .773 L
.51587 .76817 L
.51691 .76761 L
.52118 .76334 L
.52087 .7585 L
Mistroke
.52064 .75367 L
.52174 .75321 L
.52611 .74884 L
.5257 .74401 L
.52541 .73918 L
.52658 .73878 L
.53101 .73434 L
.53049 .72951 L
.53016 .72468 L
.53141 .72422 L
.53578 .71985 L
.53522 .71502 L
.53487 .71019 L
.53624 .70953 L
.54043 .70535 L
.53991 .70052 L
.53955 .69569 L
.54107 .69479 L
.54502 .69086 L
.54454 .68603 L
.5459 .6856 L
.55031 .68119 L
.54957 .67636 L
.54915 .67153 L
.55073 .6706 L
.55465 .6667 L
.55411 .66187 L
.55557 .6613 L
.55984 .65704 L
.55909 .6522 L
.55864 .64737 L
.5604 .64621 L
.56409 .64254 L
.56356 .63771 L
.56523 .63673 L
.5691 .63288 L
.56848 .62804 L
.57006 .62727 L
.57413 .62321 L
.57339 .61838 L
.57489 .61785 L
.5792 .61355 L
.57829 .60872 L
.57973 .60854 L
.58438 .60388 L
.58317 .59905 L
.58261 .59422 L
.58456 .59285 L
.58804 .58939 L
.58744 .58456 L
Mistroke
.58939 .5832 L
.59288 .57973 L
.59226 .57489 L
.59422 .57352 L
.5977 .57006 L
.59706 .56523 L
.59905 .56381 L
.60249 .5604 L
.60184 .55557 L
.60388 .55409 L
.60726 .55073 L
.60661 .5459 L
.60872 .54433 L
.612 .54107 L
.61355 .54057 L
.61789 .53624 L
.61672 .53141 L
.61838 .53062 L
.62244 .52658 L
.62143 .52174 L
.62321 .52071 L
.62702 .51691 L
.62612 .51208 L
.62804 .5108 L
.63162 .50725 L
.6308 .50242 L
.63288 .50091 L
.63622 .49758 L
.63771 .49748 L
.64243 .49275 L
.64083 .48792 L
.64254 .48703 L
.6465 .48309 L
.64544 .47826 L
.64737 .47697 L
.65093 .47342 L
.65005 .46859 L
.6522 .46698 L
.65544 .46376 L
.65704 .46314 L
.66125 .45893 L
.65997 .4541 L
.66187 .45288 L
.66541 .44927 L
.66433 .44443 L
.6667 .44266 L
.66977 .4396 L
.67153 .43885 L
.67562 .43477 L
.67423 .42994 L
Mistroke
.67636 .42847 L
.67975 .42511 L
.67871 .42027 L
.68119 .41832 L
.6841 .41544 L
.68603 .41431 L
.68973 .41061 L
.68852 .40578 L
.69086 .40401 L
.69394 .40095 L
.69569 .40016 L
.69974 .39612 L
.69829 .39128 L
.70052 .38966 L
.70374 .38645 L
.70535 .38607 L
.7098 .38162 L
.70802 .37679 L
.71019 .37525 L
.7135 .37196 L
.7124 .36712 L
.71502 .36497 L
.71772 .36229 L
.71985 .36079 L
.72319 .35746 L
.72205 .35263 L
.72468 .35046 L
.72736 .3478 L
.72951 .34625 L
.73281 .34296 L
.73166 .33813 L
.73434 .33589 L
.73696 .3333 L
.73918 .33165 L
.74237 .32847 L
.74401 .32784 L
.74821 .32364 L
.74651 .31881 L
.74884 .31699 L
.75187 .31397 L
.75367 .31296 L
.7575 .30914 L
.75602 .30431 L
.7585 .30229 L
.76133 .29948 L
.76334 .29811 L
.76681 .29465 L
.7655 .28981 L
.76817 .28756 L
.77076 .28498 L
Mistroke
.773 .28327 L
.77613 .28015 L
.77783 .27928 L
.7818 .27532 L
.78017 .27049 L
.78266 .26843 L
.78545 .26566 L
.7875 .2642 L
.79088 .26082 L
.78955 .25599 L
.79233 .25359 L
.79477 .25116 L
.79716 .24923 L
.80008 .24633 L
.80199 .24504 L
.80554 .2415 L
.80409 .23666 L
.80682 .23431 L
.80931 .23183 L
.81165 .22994 L
.81461 .227 L
.81649 .22574 L
.82007 .22217 L
.81857 .21734 L
.82132 .21495 L
.82377 .2125 L
.82615 .21056 L
.82905 .20767 L
.83098 .2063 L
.83445 .20284 L
.83298 .19801 L
.83581 .19551 L
.83816 .19318 L
.84065 .19108 L
.84339 .18835 L
.84548 .18675 L
.84872 .18351 L
.85031 .18268 L
.85431 .17868 L
.85248 .17385 L
.85514 .17153 L
.85766 .16902 L
.85997 .16711 L
.86291 .16419 L
.8648 .16282 L
.86828 .15935 L
.86964 .1591 L
.87421 .15452 L
.87187 .14969 L
.87447 .14743 L
Mistroke
.87705 .14486 L
.8793 .14301 L
.88229 .14003 L
.88413 .13871 L
.88765 .1352 L
.88896 .13501 L
.89361 .13036 L
.89116 .12553 L
.8938 .12321 L
.89632 .1207 L
.89863 .11875 L
.90152 .11587 L
.90346 .11438 L
.90681 .11104 L
.90829 .11025 L
.91234 .1062 L
.91034 .10137 L
.91312 .09887 L
.91546 .09654 L
.91796 .09435 L
.92061 .09171 L
.92279 .08989 L
.92581 .08688 L
.92762 .08553 L
.93111 .08204 L
.93245 .08147 L
.93671 .07721 L
.9345 .07238 L
.93728 .06986 L
.9396 .06755 L
.94211 .06531 L
.94472 .06272 L
.94695 .06081 L
.94988 .05789 L
.95178 .05638 L
.95511 .05305 L
.95661 .0521 L
.96049 .04822 L
.95851 .04339 L
.96144 .04068 L
.96357 .03856 L
.96627 .03609 L
.96865 .03373 L
.97111 .03153 L
.97375 .02889 L
.97594 .027 L
.97979 .02406 L
.98077 .02155 L
Mfstroke
.606 .73 0 r
.01923 .02166 m
.02014 .02406 L
.02406 .02711 L
.02612 .02889 L
.02889 .03166 L
.03121 .03373 L
.03373 .03624 L
.03627 .03856 L
.03856 .04084 L
.04131 .04339 L
.03946 .04822 L
.04339 .05215 L
.0448 .05305 L
.04822 .05647 L
.05001 .05789 L
.05305 .06092 L
.05515 .06272 L
.05789 .06545 L
.06025 .06755 L
.06272 .07001 L
.06533 .07238 L
.06326 .07721 L
.06755 .0815 L
.06881 .08204 L
.07238 .08561 L
.07408 .08688 L
.07721 .09 L
.07926 .09171 L
.08204 .09448 L
.08439 .09654 L
.08688 .09902 L
.08949 .10137 L
.08762 .1062 L
.09171 .11029 L
.0931 .11104 L
.09654 .11447 L
.09837 .11587 L
.10137 .11886 L
.10355 .1207 L
.1062 .12335 L
.10868 .12553 L
.10638 .13036 L
.11104 .13502 L
.11227 .1352 L
.11587 .13878 L
.1176 .14003 L
.1207 .14312 L
.12281 .14486 L
.12553 .14757 L
.12797 .14969 L
.12577 .15452 L
.13036 .15911 L
.13164 .15935 L
.1352 .1629 L
.13698 .16419 L
.14003 .16722 L
.1422 .16902 L
.14486 .17166 L
.14736 .17385 L
.14564 .17868 L
.14969 .18273 L
.15119 .18351 L
.15452 .18684 L
.15649 .18835 L
.15935 .1912 L
.16169 .19318 L
.16419 .19566 L
.16685 .19801 L
.16547 .20284 L
.16902 .20638 L
.17084 .20767 L
.17385 .21067 L
.17608 .2125 L
.17868 .21509 L
.18126 .21734 L
.17986 .22217 L
.18351 .22582 L
.18528 .227 L
.18835 .23005 L
.19055 .23183 L
.19318 .23445 L
.19574 .23666 L
.19438 .2415 L
.19801 .24511 L
.19981 .24633 L
.20284 .24934 L
.20508 .25116 L
.20767 .25373 L
.21028 .25599 L
.20903 .26082 L
.2125 .26428 L
.21443 .26566 L
.21734 .26855 L
.21969 .27049 L
.21815 .27532 L
.22217 .27934 L
.22377 .28015 L
.227 .28337 L
.22911 .28498 L
.23183 .28769 L
.23434 .28981 L
.23311 .29465 L
.23666 .29819 L
.23855 .29948 L
.2415 .30241 L
.24383 .30431 L
.24244 .30914 L
.24633 .31302 L
.24802 .31397 L
.25116 .3171 L
.25336 .31881 L
.25175 .32364 L
.25599 .32788 L
.25753 .32847 L
.26082 .33174 L
.26291 .3333 L
.26566 .33602 L
.26818 .33813 L
.2671 .34296 L
.27049 .34634 L
.27251 .3478 L
.27532 .35058 L
.27779 .35263 L
.27672 .35746 L
.28015 .36087 L
.28216 .36229 L
.28498 .3651 L
.28745 .36712 L
.28641 .37196 L
.28981 .37534 L
.29185 .37679 L
.29017 .38162 L
.29465 .38609 L
.29616 .38645 L
.29948 .38975 L
.30158 .39128 L
.30021 .39612 L
.30431 .4002 L
.30596 .40095 L
.30914 .40411 L
.31134 .40578 L
.3102 .41061 L
.31397 .41437 L
.31579 .41544 L
.31881 .41844 L
.32114 .42027 L
.32017 .42511 L
.32364 .42856 L
.32565 .42994 L
.32434 .43477 L
.32847 .4389 L
.33012 .4396 L
.3333 .44276 L
.33553 .44443 L
.33451 .44927 L
.33813 .45296 L
.33991 .4541 L
.33871 .45893 L
.34296 .46318 L
.34446 .46376 L
.3478 .46708 L
.34981 .46859 L
.34899 .47342 L
.35263 .47705 L
.35444 .47826 L
.35345 .48309 L
.35746 .48709 L
.35906 .48792 L
.35756 .49275 L
.36229 .49748 L
.36368 .49758 L
.36712 .50101 L
.36906 .50242 L
.3683 .50725 L
.37196 .51089 L
.37375 .51208 L
.37291 .51691 L
.37679 .52077 L
.37845 .52174 L
.37751 .52658 L
.38162 .53067 L
.38317 .53141 L
.38208 .53624 L
.38645 .54061 L
.3879 .54107 L
.39128 .54444 L
.39325 .5459 L
.39265 .55073 L
.39612 .55418 L
.39802 .55557 L
.39742 .5604 L
.40095 .56391 L
.40281 .56523 L
.40221 .57006 L
.40578 .57361 L
.40761 .57489 L
.40703 .57973 L
.41061 .58329 L
.41243 .58456 L
.41187 .58939 L
.41544 .59294 L
.41726 .59422 L
.41673 .59905 L
.41561 .60388 L
.42027 .60855 L
.42162 .60872 L
.42077 .61355 L
.42511 .61788 L
.42651 .61838 L
.42581 .62321 L
.42994 .62732 L
.43141 .62804 L
.43083 .63288 L
.43477 .6368 L
.43632 .63771 L
.43583 .64254 L
.4396 .64629 L
.44124 .64737 L
.44081 .6522 L
.44012 .65704 L
.44443 .66134 L
.44578 .66187 L
.44528 .6667 L
.44927 .67067 L
.45074 .67153 L
.45034 .67636 L
.44966 .68119 L
.4541 .68563 L
.45536 .68603 L
.45492 .69086 L
.45893 .69486 L
.46034 .69569 L
.46001 .70052 L
.45952 .70535 L
.46376 .70958 L
.46502 .71019 L
.4647 .71502 L
.46419 .71985 L
.46859 .72425 L
.46974 .72468 L
.46944 .72951 L
.46896 .73434 L
.47342 .73881 L
.4745 .73918 L
.47423 .74401 L
.47385 .74884 L
.47826 .75326 L
.47927 .75367 L
.47905 .7585 L
.47877 .76334 L
.48309 .76767 L
.48403 .76817 L
.48386 .773 L
.48367 .77783 L
.48342 .78266 L
.48792 .78719 L
.48861 .7875 L
.48848 .79233 L
.48834 .79716 L
.48819 .80199 L
.49275 .80664 L
.49312 .80682 L
.49302 .81165 L
.49294 .81649 L
.49286 .82132 L
.4928 .82615 L
.49276 .83098 L
.49275 .83231 L
.4921 .83581 L
.49121 .84065 L
.49032 .84548 L
.48944 .85031 L
.48885 .85514 L
.48792 .85907 L
.48779 .85997 L
.48711 .8648 L
.48647 .86964 L
.48587 .87447 L
.48532 .8793 L
.48482 .88413 L
.48438 .88896 L
.484 .8938 L
.48369 .89863 L
.48346 .90346 L
.48331 .90829 L
.48325 .91312 L
.48327 .91796 L
.4834 .92279 L
.48364 .92762 L
.48399 .93245 L
.48448 .93728 L
.48513 .94211 L
.48598 .94695 L
.48707 .95178 L
.48792 .95483 L
.48843 .95661 L
.4902 .96144 L
.49275 .96576 L
.49312 .96627 L
.49758 .97023 L
.50242 .97023 L
.50689 .96627 L
.50725 .96577 L
.5098 .96144 L
.51157 .95661 L
.51208 .95485 L
.51294 .95178 L
.51403 .94695 L
.51487 .94211 L
.51552 .93728 L
.51601 .93245 L
.51637 .92762 L
.5166 .92279 L
.51673 .91796 L
.51676 .91312 L
.51669 .90829 L
.51654 .90346 L
.51631 .89863 L
.51601 .8938 L
.51563 .88896 L
.51519 .88413 L
.51469 .8793 L
.51413 .87447 L
.51353 .86964 L
.51289 .8648 L
.51222 .85997 L
.51208 .85903 L
.51116 .85514 L
.51057 .85031 L
.50969 .84548 L
.5088 .84065 L
.5079 .83581 L
.50725 .83229 L
.50724 .83098 L
.5072 .82615 L
.50714 .82132 L
.50706 .81649 L
.50698 .81165 L
.50689 .80682 L
.50725 .80664 L
.51181 .80199 L
.51166 .79716 L
.51152 .79233 L
.51139 .7875 L
.51208 .78719 L
.51658 .78266 L
.51633 .77783 L
.51614 .773 L
.51597 .76817 L
.51691 .76767 L
.52123 .76334 L
.52095 .7585 L
.52073 .75367 L
.52174 .75326 L
.52615 .74884 L
.52577 .74401 L
.5255 .73918 L
.52658 .73881 L
.53104 .73434 L
.53056 .72951 L
.53026 .72468 L
.53141 .72425 L
.53581 .71985 L
.5353 .71502 L
.53498 .71019 L
.53624 .70959 L
.54048 .70535 L
.53999 .70052 L
.53966 .69569 L
.54107 .69486 L
.54508 .69086 L
.54464 .68603 L
.5459 .68563 L
.55034 .68119 L
.54966 .67636 L
.54926 .67153 L
.55073 .67067 L
.55472 .6667 L
.55422 .66187 L
.55557 .66134 L
.55988 .65704 L
.55919 .6522 L
.55876 .64737 L
.5604 .64629 L
.56417 .64254 L
.56368 .63771 L
.56523 .6368 L
.56917 .63288 L
.56859 .62804 L
.57006 .62732 L
.57419 .62321 L
.57349 .61838 L
.57489 .61788 L
.57923 .61355 L
.57838 .60872 L
.57973 .60855 L
.58439 .60388 L
.58327 .59905 L
.58274 .59422 L
.58456 .59294 L
.58813 .58939 L
.58757 .58456 L
.58939 .58329 L
.59297 .57973 L
.59239 .57489 L
.59422 .57361 L
.59779 .57006 L
.59719 .56523 L
.59905 .56391 L
.60258 .5604 L
.60198 .55557 L
.60388 .55418 L
.60735 .55073 L
.60675 .5459 L
.60872 .54444 L
.6121 .54107 L
.61355 .54061 L
.61792 .53624 L
.61683 .53141 L
.61838 .53067 L
.62249 .52658 L
.62155 .52174 L
.62321 .52077 L
.62709 .51691 L
.62625 .51208 L
.62804 .51089 L
.6317 .50725 L
.63094 .50242 L
.63288 .50101 L
.63632 .49758 L
.63771 .49748 L
.64244 .49275 L
.64094 .48792 L
.64254 .48709 L
.64655 .48309 L
.64556 .47826 L
.64737 .47705 L
.65101 .47342 L
.65019 .46859 L
.6522 .46708 L
.65554 .46376 L
.65704 .46318 L
.66129 .45893 L
.66009 .4541 L
.66187 .45296 L
.66549 .44927 L
.66447 .44443 L
.6667 .44276 L
.66988 .4396 L
.67153 .4389 L
.67566 .43477 L
.67435 .42994 L
.67636 .42856 L
.67983 .42511 L
.67886 .42027 L
.68119 .41844 L
.68421 .41544 L
.68603 .41437 L
.6898 .41061 L
.68866 .40578 L
.69086 .40411 L
.69404 .40095 L
.69569 .4002 L
.69979 .39612 L
.69842 .39128 L
.70052 .38975 L
.70384 .38645 L
.70535 .38609 L
.70983 .38162 L
.70815 .37679 L
.71019 .37534 L
.71359 .37196 L
.71255 .36712 L
.71502 .3651 L
.71784 .36229 L
.71985 .36087 L
.72328 .35746 L
.72221 .35263 L
.72468 .35058 L
.72749 .3478 L
.72951 .34634 L
.7329 .34296 L
.73182 .33813 L
.73434 .33602 L
.73709 .3333 L
.73918 .33174 L
.74247 .32847 L
.74401 .32788 L
.74825 .32364 L
.74664 .31881 L
.74884 .3171 L
.75198 .31397 L
.75367 .31302 L
.75756 .30914 L
.75617 .30431 L
.7585 .30241 L
.76145 .29948 L
.76334 .29819 L
.76689 .29465 L
.76566 .28981 L
.76817 .28769 L
.77089 .28498 L
.773 .28337 L
.77623 .28015 L
.77783 .27934 L
.78185 .27532 L
.78031 .27049 L
.78266 .26855 L
.78557 .26566 L
.7875 .26428 L
.79097 .26082 L
.78972 .25599 L
.79233 .25373 L
.79492 .25116 L
.79716 .24934 L
.80019 .24633 L
.80199 .24511 L
.80562 .2415 L
.80426 .23666 L
.80682 .23445 L
.80945 .23183 L
.81165 .23005 L
.81472 .227 L
.81649 .22582 L
.82014 .22217 L
.81874 .21734 L
.82132 .21509 L
.82392 .2125 L
.82615 .21067 L
.82916 .20767 L
.83098 .20638 L
.83453 .20284 L
.83315 .19801 L
.83581 .19566 L
.83831 .19318 L
.84065 .1912 L
.84351 .18835 L
.84548 .18684 L
.84881 .18351 L
.85031 .18273 L
.85436 .17868 L
.85264 .17385 L
.85514 .17166 L
.8578 .16902 L
.85997 .16722 L
.86302 .16419 L
.8648 .1629 L
.86836 .15935 L
.86964 .15911 L
.87423 .15452 L
.87203 .14969 L
.87447 .14757 L
.87719 .14486 L
.8793 .14312 L
.8824 .14003 L
.88413 .13878 L
.88773 .1352 L
.88896 .13502 L
.89362 .13036 L
.89132 .12553 L
.8938 .12335 L
.89645 .1207 L
.89863 .11886 L
.90163 .11587 L
.90346 .11447 L
.9069 .11104 L
.90829 .11029 L
.91238 .1062 L
.91051 .10137 L
.91312 .09902 L
.91561 .09654 L
.91796 .09448 L
.92074 .09171 L
.92279 .09 L
.92592 .08688 L
.92762 .08561 L
.93119 .08204 L
.93245 .0815 L
.93674 .07721 L
.93467 .07238 L
.93728 .07001 L
.93975 .06755 L
.94211 .06545 L
.94485 .06272 L
.94695 .06092 L
.94999 .05789 L
.95178 .05647 L
.9552 .05305 L
.95661 .05215 L
.96054 .04822 L
.95869 .04339 L
.96144 .04084 L
.96373 .03856 L
.96627 .03624 L
.96879 .03373 L
.97111 .03166 L
.97388 .02889 L
.97594 .02711 L
.97986 .02406 L
.98077 .02166 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .02166 m
.02014 .02406 L
.02406 .02711 L
.02612 .02889 L
.02889 .03166 L
.03121 .03373 L
.03373 .03624 L
.03627 .03856 L
.03856 .04084 L
.04131 .04339 L
.03946 .04822 L
.04339 .05215 L
.0448 .05305 L
.04822 .05647 L
.05001 .05789 L
.05305 .06092 L
.05515 .06272 L
.05789 .06545 L
.06025 .06755 L
.06272 .07001 L
.06533 .07238 L
.06326 .07721 L
.06755 .0815 L
.06881 .08204 L
.07238 .08561 L
.07408 .08688 L
.07721 .09 L
.07926 .09171 L
.08204 .09448 L
.08439 .09654 L
.08688 .09902 L
.08949 .10137 L
.08762 .1062 L
.09171 .11029 L
.0931 .11104 L
.09654 .11447 L
.09837 .11587 L
.10137 .11886 L
.10355 .1207 L
.1062 .12335 L
.10868 .12553 L
.10638 .13036 L
.11104 .13502 L
.11227 .1352 L
.11587 .13878 L
.1176 .14003 L
.1207 .14312 L
.12281 .14486 L
.12553 .14757 L
.12797 .14969 L
Mistroke
.12577 .15452 L
.13036 .15911 L
.13164 .15935 L
.1352 .1629 L
.13698 .16419 L
.14003 .16722 L
.1422 .16902 L
.14486 .17166 L
.14736 .17385 L
.14564 .17868 L
.14969 .18273 L
.15119 .18351 L
.15452 .18684 L
.15649 .18835 L
.15935 .1912 L
.16169 .19318 L
.16419 .19566 L
.16685 .19801 L
.16547 .20284 L
.16902 .20638 L
.17084 .20767 L
.17385 .21067 L
.17608 .2125 L
.17868 .21509 L
.18126 .21734 L
.17986 .22217 L
.18351 .22582 L
.18528 .227 L
.18835 .23005 L
.19055 .23183 L
.19318 .23445 L
.19574 .23666 L
.19438 .2415 L
.19801 .24511 L
.19981 .24633 L
.20284 .24934 L
.20508 .25116 L
.20767 .25373 L
.21028 .25599 L
.20903 .26082 L
.2125 .26428 L
.21443 .26566 L
.21734 .26855 L
.21969 .27049 L
.21815 .27532 L
.22217 .27934 L
.22377 .28015 L
.227 .28337 L
.22911 .28498 L
.23183 .28769 L
Mistroke
.23434 .28981 L
.23311 .29465 L
.23666 .29819 L
.23855 .29948 L
.2415 .30241 L
.24383 .30431 L
.24244 .30914 L
.24633 .31302 L
.24802 .31397 L
.25116 .3171 L
.25336 .31881 L
.25175 .32364 L
.25599 .32788 L
.25753 .32847 L
.26082 .33174 L
.26291 .3333 L
.26566 .33602 L
.26818 .33813 L
.2671 .34296 L
.27049 .34634 L
.27251 .3478 L
.27532 .35058 L
.27779 .35263 L
.27672 .35746 L
.28015 .36087 L
.28216 .36229 L
.28498 .3651 L
.28745 .36712 L
.28641 .37196 L
.28981 .37534 L
.29185 .37679 L
.29017 .38162 L
.29465 .38609 L
.29616 .38645 L
.29948 .38975 L
.30158 .39128 L
.30021 .39612 L
.30431 .4002 L
.30596 .40095 L
.30914 .40411 L
.31134 .40578 L
.3102 .41061 L
.31397 .41437 L
.31579 .41544 L
.31881 .41844 L
.32114 .42027 L
.32017 .42511 L
.32364 .42856 L
.32565 .42994 L
.32434 .43477 L
Mistroke
.32847 .4389 L
.33012 .4396 L
.3333 .44276 L
.33553 .44443 L
.33451 .44927 L
.33813 .45296 L
.33991 .4541 L
.33871 .45893 L
.34296 .46318 L
.34446 .46376 L
.3478 .46708 L
.34981 .46859 L
.34899 .47342 L
.35263 .47705 L
.35444 .47826 L
.35345 .48309 L
.35746 .48709 L
.35906 .48792 L
.35756 .49275 L
.36229 .49748 L
.36368 .49758 L
.36712 .50101 L
.36906 .50242 L
.3683 .50725 L
.37196 .51089 L
.37375 .51208 L
.37291 .51691 L
.37679 .52077 L
.37845 .52174 L
.37751 .52658 L
.38162 .53067 L
.38317 .53141 L
.38208 .53624 L
.38645 .54061 L
.3879 .54107 L
.39128 .54444 L
.39325 .5459 L
.39265 .55073 L
.39612 .55418 L
.39802 .55557 L
.39742 .5604 L
.40095 .56391 L
.40281 .56523 L
.40221 .57006 L
.40578 .57361 L
.40761 .57489 L
.40703 .57973 L
.41061 .58329 L
.41243 .58456 L
.41187 .58939 L
Mistroke
.41544 .59294 L
.41726 .59422 L
.41673 .59905 L
.41561 .60388 L
.42027 .60855 L
.42162 .60872 L
.42077 .61355 L
.42511 .61788 L
.42651 .61838 L
.42581 .62321 L
.42994 .62732 L
.43141 .62804 L
.43083 .63288 L
.43477 .6368 L
.43632 .63771 L
.43583 .64254 L
.4396 .64629 L
.44124 .64737 L
.44081 .6522 L
.44012 .65704 L
.44443 .66134 L
.44578 .66187 L
.44528 .6667 L
.44927 .67067 L
.45074 .67153 L
.45034 .67636 L
.44966 .68119 L
.4541 .68563 L
.45536 .68603 L
.45492 .69086 L
.45893 .69486 L
.46034 .69569 L
.46001 .70052 L
.45952 .70535 L
.46376 .70958 L
.46502 .71019 L
.4647 .71502 L
.46419 .71985 L
.46859 .72425 L
.46974 .72468 L
.46944 .72951 L
.46896 .73434 L
.47342 .73881 L
.4745 .73918 L
.47423 .74401 L
.47385 .74884 L
.47826 .75326 L
.47927 .75367 L
.47905 .7585 L
.47877 .76334 L
Mistroke
.48309 .76767 L
.48403 .76817 L
.48386 .773 L
.48367 .77783 L
.48342 .78266 L
.48792 .78719 L
.48861 .7875 L
.48848 .79233 L
.48834 .79716 L
.48819 .80199 L
.49275 .80664 L
.49312 .80682 L
.49302 .81165 L
.49294 .81649 L
.49286 .82132 L
.4928 .82615 L
.49276 .83098 L
.49275 .83231 L
.4921 .83581 L
.49121 .84065 L
.49032 .84548 L
.48944 .85031 L
.48885 .85514 L
.48792 .85907 L
.48779 .85997 L
.48711 .8648 L
.48647 .86964 L
.48587 .87447 L
.48532 .8793 L
.48482 .88413 L
.48438 .88896 L
.484 .8938 L
.48369 .89863 L
.48346 .90346 L
.48331 .90829 L
.48325 .91312 L
.48327 .91796 L
.4834 .92279 L
.48364 .92762 L
.48399 .93245 L
.48448 .93728 L
.48513 .94211 L
.48598 .94695 L
.48707 .95178 L
.48792 .95483 L
.48843 .95661 L
.4902 .96144 L
.49275 .96576 L
.49312 .96627 L
.49758 .97023 L
Mistroke
.50242 .97023 L
.50689 .96627 L
.50725 .96577 L
.5098 .96144 L
.51157 .95661 L
.51208 .95485 L
.51294 .95178 L
.51403 .94695 L
.51487 .94211 L
.51552 .93728 L
.51601 .93245 L
.51637 .92762 L
.5166 .92279 L
.51673 .91796 L
.51676 .91312 L
.51669 .90829 L
.51654 .90346 L
.51631 .89863 L
.51601 .8938 L
.51563 .88896 L
.51519 .88413 L
.51469 .8793 L
.51413 .87447 L
.51353 .86964 L
.51289 .8648 L
.51222 .85997 L
.51208 .85903 L
.51116 .85514 L
.51057 .85031 L
.50969 .84548 L
.5088 .84065 L
.5079 .83581 L
.50725 .83229 L
.50724 .83098 L
.5072 .82615 L
.50714 .82132 L
.50706 .81649 L
.50698 .81165 L
.50689 .80682 L
.50725 .80664 L
.51181 .80199 L
.51166 .79716 L
.51152 .79233 L
.51139 .7875 L
.51208 .78719 L
.51658 .78266 L
.51633 .77783 L
.51614 .773 L
.51597 .76817 L
.51691 .76767 L
Mistroke
.52123 .76334 L
.52095 .7585 L
.52073 .75367 L
.52174 .75326 L
.52615 .74884 L
.52577 .74401 L
.5255 .73918 L
.52658 .73881 L
.53104 .73434 L
.53056 .72951 L
.53026 .72468 L
.53141 .72425 L
.53581 .71985 L
.5353 .71502 L
.53498 .71019 L
.53624 .70959 L
.54048 .70535 L
.53999 .70052 L
.53966 .69569 L
.54107 .69486 L
.54508 .69086 L
.54464 .68603 L
.5459 .68563 L
.55034 .68119 L
.54966 .67636 L
.54926 .67153 L
.55073 .67067 L
.55472 .6667 L
.55422 .66187 L
.55557 .66134 L
.55988 .65704 L
.55919 .6522 L
.55876 .64737 L
.5604 .64629 L
.56417 .64254 L
.56368 .63771 L
.56523 .6368 L
.56917 .63288 L
.56859 .62804 L
.57006 .62732 L
.57419 .62321 L
.57349 .61838 L
.57489 .61788 L
.57923 .61355 L
.57838 .60872 L
.57973 .60855 L
.58439 .60388 L
.58327 .59905 L
.58274 .59422 L
.58456 .59294 L
Mistroke
.58813 .58939 L
.58757 .58456 L
.58939 .58329 L
.59297 .57973 L
.59239 .57489 L
.59422 .57361 L
.59779 .57006 L
.59719 .56523 L
.59905 .56391 L
.60258 .5604 L
.60198 .55557 L
.60388 .55418 L
.60735 .55073 L
.60675 .5459 L
.60872 .54444 L
.6121 .54107 L
.61355 .54061 L
.61792 .53624 L
.61683 .53141 L
.61838 .53067 L
.62249 .52658 L
.62155 .52174 L
.62321 .52077 L
.62709 .51691 L
.62625 .51208 L
.62804 .51089 L
.6317 .50725 L
.63094 .50242 L
.63288 .50101 L
.63632 .49758 L
.63771 .49748 L
.64244 .49275 L
.64094 .48792 L
.64254 .48709 L
.64655 .48309 L
.64556 .47826 L
.64737 .47705 L
.65101 .47342 L
.65019 .46859 L
.6522 .46708 L
.65554 .46376 L
.65704 .46318 L
.66129 .45893 L
.66009 .4541 L
.66187 .45296 L
.66549 .44927 L
.66447 .44443 L
.6667 .44276 L
.66988 .4396 L
.67153 .4389 L
Mistroke
.67566 .43477 L
.67435 .42994 L
.67636 .42856 L
.67983 .42511 L
.67886 .42027 L
.68119 .41844 L
.68421 .41544 L
.68603 .41437 L
.6898 .41061 L
.68866 .40578 L
.69086 .40411 L
.69404 .40095 L
.69569 .4002 L
.69979 .39612 L
.69842 .39128 L
.70052 .38975 L
.70384 .38645 L
.70535 .38609 L
.70983 .38162 L
.70815 .37679 L
.71019 .37534 L
.71359 .37196 L
.71255 .36712 L
.71502 .3651 L
.71784 .36229 L
.71985 .36087 L
.72328 .35746 L
.72221 .35263 L
.72468 .35058 L
.72749 .3478 L
.72951 .34634 L
.7329 .34296 L
.73182 .33813 L
.73434 .33602 L
.73709 .3333 L
.73918 .33174 L
.74247 .32847 L
.74401 .32788 L
.74825 .32364 L
.74664 .31881 L
.74884 .3171 L
.75198 .31397 L
.75367 .31302 L
.75756 .30914 L
.75617 .30431 L
.7585 .30241 L
.76145 .29948 L
.76334 .29819 L
.76689 .29465 L
.76566 .28981 L
Mistroke
.76817 .28769 L
.77089 .28498 L
.773 .28337 L
.77623 .28015 L
.77783 .27934 L
.78185 .27532 L
.78031 .27049 L
.78266 .26855 L
.78557 .26566 L
.7875 .26428 L
.79097 .26082 L
.78972 .25599 L
.79233 .25373 L
.79492 .25116 L
.79716 .24934 L
.80019 .24633 L
.80199 .24511 L
.80562 .2415 L
.80426 .23666 L
.80682 .23445 L
.80945 .23183 L
.81165 .23005 L
.81472 .227 L
.81649 .22582 L
.82014 .22217 L
.81874 .21734 L
.82132 .21509 L
.82392 .2125 L
.82615 .21067 L
.82916 .20767 L
.83098 .20638 L
.83453 .20284 L
.83315 .19801 L
.83581 .19566 L
.83831 .19318 L
.84065 .1912 L
.84351 .18835 L
.84548 .18684 L
.84881 .18351 L
.85031 .18273 L
.85436 .17868 L
.85264 .17385 L
.85514 .17166 L
.8578 .16902 L
.85997 .16722 L
.86302 .16419 L
.8648 .1629 L
.86836 .15935 L
.86964 .15911 L
.87423 .15452 L
Mistroke
.87203 .14969 L
.87447 .14757 L
.87719 .14486 L
.8793 .14312 L
.8824 .14003 L
.88413 .13878 L
.88773 .1352 L
.88896 .13502 L
.89362 .13036 L
.89132 .12553 L
.8938 .12335 L
.89645 .1207 L
.89863 .11886 L
.90163 .11587 L
.90346 .11447 L
.9069 .11104 L
.90829 .11029 L
.91238 .1062 L
.91051 .10137 L
.91312 .09902 L
.91561 .09654 L
.91796 .09448 L
.92074 .09171 L
.92279 .09 L
.92592 .08688 L
.92762 .08561 L
.93119 .08204 L
.93245 .0815 L
.93674 .07721 L
.93467 .07238 L
.93728 .07001 L
.93975 .06755 L
.94211 .06545 L
.94485 .06272 L
.94695 .06092 L
.94999 .05789 L
.95178 .05647 L
.9552 .05305 L
.95661 .05215 L
.96054 .04822 L
.95869 .04339 L
.96144 .04084 L
.96373 .03856 L
.96627 .03624 L
.96879 .03373 L
.97111 .03166 L
.97388 .02889 L
.97594 .02711 L
.97986 .02406 L
.98077 .02166 L
Mistroke
Mfstroke
.435 .685 0 r
.01923 .02176 m
.02007 .02406 L
.02406 .02722 L
.02599 .02889 L
.02889 .03179 L
.03106 .03373 L
.03373 .03639 L
.0361 .03856 L
.03856 .041 L
.04113 .04339 L
.0394 .04822 L
.04339 .05221 L
.04472 .05305 L
.04822 .05655 L
.0499 .05789 L
.05305 .06104 L
.05502 .06272 L
.05789 .06558 L
.0601 .06755 L
.06272 .07016 L
.06516 .07238 L
.06322 .07721 L
.06755 .08154 L
.06873 .08204 L
.07238 .08569 L
.07398 .08688 L
.07721 .09011 L
.07913 .09171 L
.08204 .09461 L
.08424 .09654 L
.08688 .09916 L
.08932 .10137 L
.08757 .1062 L
.09171 .11034 L
.09302 .11104 L
.09654 .11455 L
.09825 .11587 L
.10137 .11898 L
.10341 .1207 L
.1062 .12348 L
.10852 .12553 L
.10636 .13036 L
.11104 .13503 L
.11219 .1352 L
.11587 .13886 L
.11749 .14003 L
.1207 .14323 L
.12268 .14486 L
.12553 .1477 L
.12782 .14969 L
.12576 .15452 L
.13036 .15913 L
.13156 .15935 L
.1352 .16298 L
.13687 .16419 L
.14003 .16734 L
.14206 .16902 L
.14486 .1718 L
.14721 .17385 L
.14559 .17868 L
.14969 .18278 L
.15109 .18351 L
.15452 .18693 L
.15636 .18835 L
.15935 .19133 L
.16154 .19318 L
.16419 .19581 L
.16668 .19801 L
.16539 .20284 L
.16902 .20646 L
.17073 .20767 L
.17385 .21079 L
.17594 .2125 L
.17868 .21523 L
.1811 .21734 L
.17978 .22217 L
.18351 .22589 L
.18517 .227 L
.18835 .23016 L
.19041 .23183 L
.19318 .23459 L
.19558 .23666 L
.19431 .2415 L
.19801 .24519 L
.1997 .24633 L
.20284 .24946 L
.20494 .25116 L
.20767 .25388 L
.21012 .25599 L
.20895 .26082 L
.2125 .26437 L
.21431 .26566 L
.21734 .26867 L
.21954 .27049 L
.21809 .27532 L
.22217 .27939 L
.22367 .28015 L
.227 .28347 L
.22897 .28498 L
.23183 .28783 L
.23418 .28981 L
.23303 .29465 L
.23666 .29827 L
.23843 .29948 L
.2415 .30253 L
.24369 .30431 L
.24238 .30914 L
.24633 .31308 L
.24792 .31397 L
.25116 .3172 L
.25322 .31881 L
.25171 .32364 L
.25599 .32792 L
.25744 .32847 L
.26082 .33184 L
.26278 .3333 L
.26566 .33616 L
.26802 .33813 L
.26701 .34296 L
.27049 .34643 L
.27239 .3478 L
.27532 .35071 L
.27764 .35263 L
.27664 .35746 L
.28015 .36096 L
.28203 .36229 L
.28498 .36522 L
.28729 .36712 L
.28632 .37196 L
.28981 .37543 L
.29172 .37679 L
.29015 .38162 L
.29465 .38611 L
.29607 .38645 L
.29948 .38985 L
.30145 .39128 L
.30017 .39612 L
.30431 .40025 L
.30586 .40095 L
.30914 .40421 L
.31121 .40578 L
.31013 .41061 L
.31397 .41444 L
.31568 .41544 L
.31881 .41855 L
.32099 .42027 L
.32008 .42511 L
.32364 .42865 L
.32552 .42994 L
.32429 .43477 L
.32847 .43894 L
.33002 .4396 L
.3333 .44286 L
.33539 .44443 L
.33443 .44927 L
.33813 .45304 L
.33979 .4541 L
.33867 .45893 L
.34296 .46322 L
.34436 .46376 L
.3478 .46718 L
.34968 .46859 L
.3489 .47342 L
.35263 .47714 L
.35431 .47826 L
.35339 .48309 L
.35746 .48715 L
.35895 .48792 L
.35755 .49275 L
.36229 .49749 L
.36359 .49758 L
.36712 .5011 L
.36893 .50242 L
.36822 .50725 L
.37196 .51097 L
.37363 .51208 L
.37284 .51691 L
.37679 .52084 L
.37834 .52174 L
.37746 .52658 L
.38162 .53073 L
.38306 .53141 L
.38204 .53624 L
.38645 .54064 L
.3878 .54107 L
.39128 .54454 L
.39311 .5459 L
.39255 .55073 L
.39612 .55428 L
.39789 .55557 L
.39732 .5604 L
.40095 .564 L
.40268 .56523 L
.40212 .57006 L
.40578 .5737 L
.40748 .57489 L
.40694 .57973 L
.41061 .58338 L
.4123 .58456 L
.41178 .58939 L
.41544 .59303 L
.41713 .59422 L
.41664 .59905 L
.4156 .60388 L
.42027 .60856 L
.42152 .60872 L
.42073 .61355 L
.42511 .61792 L
.42641 .61838 L
.42576 .62321 L
.42994 .62738 L
.4313 .62804 L
.43076 .63288 L
.43477 .63687 L
.43621 .63771 L
.43575 .64254 L
.4396 .64637 L
.44111 .64737 L
.44072 .6522 L
.44008 .65704 L
.44443 .66138 L
.44568 .66187 L
.44521 .6667 L
.44927 .67074 L
.45063 .67153 L
.45026 .67636 L
.44963 .68119 L
.4541 .68566 L
.45526 .68603 L
.45485 .69086 L
.45893 .69492 L
.46022 .69569 L
.45992 .70052 L
.45947 .70535 L
.46376 .70964 L
.46492 .71019 L
.46462 .71502 L
.46415 .71985 L
.46859 .72429 L
.46965 .72468 L
.46937 .72951 L
.46893 .73434 L
.47342 .73885 L
.4744 .73918 L
.47416 .74401 L
.47381 .74884 L
.47826 .7533 L
.47917 .75367 L
.47897 .7585 L
.47872 .76334 L
.48309 .76772 L
.48393 .76817 L
.48377 .773 L
.4836 .77783 L
.48338 .78266 L
.48792 .78723 L
.48852 .7875 L
.4884 .79233 L
.48828 .79716 L
.48814 .80199 L
.49275 .80668 L
.49303 .80682 L
.49294 .81165 L
.49287 .81649 L
.49281 .82132 L
.49276 .82615 L
.49275 .82687 L
.49271 .83098 L
.49095 .83581 L
.48999 .84065 L
.48904 .84548 L
.48811 .85031 L
.48792 .85133 L
.4873 .85514 L
.48653 .85997 L
.4858 .8648 L
.48511 .86964 L
.48446 .87447 L
.48386 .8793 L
.48331 .88413 L
.48309 .88626 L
.48284 .88896 L
.48244 .8938 L
.4821 .89863 L
.48182 .90346 L
.48162 .90829 L
.48148 .91312 L
.48143 .91796 L
.48147 .92279 L
.48161 .92762 L
.48185 .93245 L
.4822 .93728 L
.48269 .94211 L
.48309 .94526 L
.48333 .94695 L
.48414 .95178 L
.48517 .95661 L
.48648 .96144 L
.48792 .96559 L
.48816 .96627 L
.49028 .97111 L
.49275 .97454 L
.49401 .97594 L
.49758 .97839 L
.50242 .97839 L
.506 .97594 L
.50725 .97455 L
.50972 .97111 L
.51185 .96627 L
.51208 .9656 L
.51352 .96144 L
.51483 .95661 L
.51586 .95178 L
.51668 .94695 L
.51691 .94531 L
.51732 .94211 L
.5178 .93728 L
.51816 .93245 L
.5184 .92762 L
.51853 .92279 L
.51857 .91796 L
.51852 .91312 L
.51839 .90829 L
.51818 .90346 L
.51791 .89863 L
.51757 .8938 L
.51717 .88896 L
.51691 .8862 L
.5167 .88413 L
.51615 .8793 L
.51555 .87447 L
.5149 .86964 L
.5142 .8648 L
.51347 .85997 L
.51271 .85514 L
.51208 .85129 L
.5119 .85031 L
.51097 .84548 L
.51002 .84065 L
.50906 .83581 L
.50729 .83098 L
.50725 .82685 L
.50724 .82615 L
.50719 .82132 L
.50713 .81649 L
.50706 .81165 L
.50697 .80682 L
.50725 .80668 L
.51186 .80199 L
.51172 .79716 L
.5116 .79233 L
.51148 .7875 L
.51208 .78723 L
.51662 .78266 L
.5164 .77783 L
.51623 .773 L
.51607 .76817 L
.51691 .76772 L
.52128 .76334 L
.52103 .7585 L
.52083 .75367 L
.52174 .7533 L
.52619 .74884 L
.52584 .74401 L
.5256 .73918 L
.52658 .73885 L
.53107 .73434 L
.53063 .72951 L
.53035 .72468 L
.53141 .72429 L
.53585 .71985 L
.53538 .71502 L
.53508 .71019 L
.53624 .70964 L
.54053 .70535 L
.54008 .70052 L
.53978 .69569 L
.54107 .69492 L
.54515 .69086 L
.54474 .68603 L
.5459 .68566 L
.55037 .68119 L
.54974 .67636 L
.54937 .67153 L
.55073 .67074 L
.55479 .6667 L
.55432 .66187 L
.55557 .66138 L
.55992 .65704 L
.55928 .6522 L
.55889 .64737 L
.5604 .64637 L
.56425 .64254 L
.56379 .63771 L
.56523 .63687 L
.56924 .63288 L
.5687 .62804 L
.57006 .62738 L
.57424 .62321 L
.57359 .61838 L
.57489 .61792 L
.57927 .61355 L
.57848 .60872 L
.57973 .60856 L
.5844 .60388 L
.58336 .59905 L
.58287 .59422 L
.58456 .59303 L
.58822 .58939 L
.5877 .58456 L
.58939 .58338 L
.59306 .57973 L
.59252 .57489 L
.59422 .5737 L
.59788 .57006 L
.59732 .56523 L
.59905 .564 L
.60268 .5604 L
.60211 .55557 L
.60388 .55428 L
.60745 .55073 L
.60689 .5459 L
.60872 .54454 L
.6122 .54107 L
.61355 .54064 L
.61796 .53624 L
.61694 .53141 L
.61838 .53073 L
.62254 .52658 L
.62166 .52174 L
.62321 .52084 L
.62716 .51691 L
.62637 .51208 L
.62804 .51097 L
.63178 .50725 L
.63107 .50242 L
.63288 .5011 L
.63641 .49758 L
.63771 .49749 L
.64245 .49275 L
.64105 .48792 L
.64254 .48715 L
.64661 .48309 L
.64569 .47826 L
.64737 .47714 L
.6511 .47342 L
.65032 .46859 L
.6522 .46718 L
.65564 .46376 L
.65704 .46322 L
.66133 .45893 L
.66021 .4541 L
.66187 .45304 L
.66557 .44927 L
.66461 .44443 L
.6667 .44286 L
.66998 .4396 L
.67153 .43894 L
.67571 .43477 L
.67448 .42994 L
.67636 .42865 L
.67992 .42511 L
.67901 .42027 L
.68119 .41855 L
.68432 .41544 L
.68603 .41444 L
.68987 .41061 L
.68879 .40578 L
.69086 .40421 L
.69414 .40095 L
.69569 .40025 L
.69983 .39612 L
.69855 .39128 L
.70052 .38985 L
.70393 .38645 L
.70535 .38611 L
.70985 .38162 L
.70828 .37679 L
.71019 .37543 L
.71368 .37196 L
.71271 .36712 L
.71502 .36522 L
.71797 .36229 L
.71985 .36096 L
.72336 .35746 L
.72236 .35263 L
.72468 .35071 L
.72761 .3478 L
.72951 .34643 L
.73299 .34296 L
.73198 .33813 L
.73434 .33616 L
.73722 .3333 L
.73918 .33184 L
.74256 .32847 L
.74401 .32792 L
.74829 .32364 L
.74678 .31881 L
.74884 .3172 L
.75208 .31397 L
.75367 .31308 L
.75762 .30914 L
.75631 .30431 L
.7585 .30253 L
.76157 .29948 L
.76334 .29827 L
.76697 .29465 L
.76582 .28981 L
.76817 .28783 L
.77103 .28498 L
.773 .28347 L
.77633 .28015 L
.77783 .27939 L
.78191 .27532 L
.78046 .27049 L
.78266 .26867 L
.78569 .26566 L
.7875 .26437 L
.79105 .26082 L
.78988 .25599 L
.79233 .25388 L
.79506 .25116 L
.79716 .24946 L
.8003 .24633 L
.80199 .24519 L
.80569 .2415 L
.80442 .23666 L
.80682 .23459 L
.80959 .23183 L
.81165 .23016 L
.81483 .227 L
.81649 .22589 L
.82022 .22217 L
.8189 .21734 L
.82132 .21523 L
.82406 .2125 L
.82615 .21078 L
.82927 .20767 L
.83098 .20646 L
.83461 .20284 L
.83332 .19801 L
.83581 .19581 L
.83845 .19318 L
.84065 .19133 L
.84364 .18835 L
.84548 .18693 L
.84891 .18351 L
.85031 .18278 L
.85441 .17868 L
.85279 .17385 L
.85514 .1718 L
.85794 .16902 L
.85997 .16734 L
.86313 .16419 L
.8648 .16298 L
.86844 .15935 L
.86964 .15913 L
.87424 .15452 L
.87218 .14969 L
.87447 .1477 L
.87732 .14486 L
.8793 .14323 L
.88251 .14003 L
.88413 .13886 L
.88781 .1352 L
.88896 .13503 L
.89364 .13036 L
.89148 .12553 L
.8938 .12348 L
.89659 .1207 L
.89863 .11898 L
.90175 .11587 L
.90346 .11455 L
.90698 .11104 L
.90829 .11034 L
.91243 .1062 L
.91068 .10137 L
.91312 .09916 L
.91576 .09654 L
.91796 .09461 L
.92087 .09171 L
.92279 .09011 L
.92602 .08688 L
.92762 .08569 L
.93127 .08204 L
.93245 .08154 L
.93678 .07721 L
.93484 .07238 L
.93728 .07016 L
.9399 .06755 L
.94211 .06558 L
.94498 .06272 L
.94695 .06104 L
.9501 .05789 L
.95178 .05655 L
.95528 .05305 L
.95661 .05221 L
.9606 .04822 L
.95886 .04339 L
.96144 .041 L
.9639 .03856 L
.96627 .03639 L
.96894 .03373 L
.97111 .03179 L
.97401 .02889 L
.97594 .02722 L
.97993 .02406 L
.98077 .02176 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .02176 m
.02007 .02406 L
.02406 .02722 L
.02599 .02889 L
.02889 .03179 L
.03106 .03373 L
.03373 .03639 L
.0361 .03856 L
.03856 .041 L
.04113 .04339 L
.0394 .04822 L
.04339 .05221 L
.04472 .05305 L
.04822 .05655 L
.0499 .05789 L
.05305 .06104 L
.05502 .06272 L
.05789 .06558 L
.0601 .06755 L
.06272 .07016 L
.06516 .07238 L
.06322 .07721 L
.06755 .08154 L
.06873 .08204 L
.07238 .08569 L
.07398 .08688 L
.07721 .09011 L
.07913 .09171 L
.08204 .09461 L
.08424 .09654 L
.08688 .09916 L
.08932 .10137 L
.08757 .1062 L
.09171 .11034 L
.09302 .11104 L
.09654 .11455 L
.09825 .11587 L
.10137 .11898 L
.10341 .1207 L
.1062 .12348 L
.10852 .12553 L
.10636 .13036 L
.11104 .13503 L
.11219 .1352 L
.11587 .13886 L
.11749 .14003 L
.1207 .14323 L
.12268 .14486 L
.12553 .1477 L
.12782 .14969 L
Mistroke
.12576 .15452 L
.13036 .15913 L
.13156 .15935 L
.1352 .16298 L
.13687 .16419 L
.14003 .16734 L
.14206 .16902 L
.14486 .1718 L
.14721 .17385 L
.14559 .17868 L
.14969 .18278 L
.15109 .18351 L
.15452 .18693 L
.15636 .18835 L
.15935 .19133 L
.16154 .19318 L
.16419 .19581 L
.16668 .19801 L
.16539 .20284 L
.16902 .20646 L
.17073 .20767 L
.17385 .21079 L
.17594 .2125 L
.17868 .21523 L
.1811 .21734 L
.17978 .22217 L
.18351 .22589 L
.18517 .227 L
.18835 .23016 L
.19041 .23183 L
.19318 .23459 L
.19558 .23666 L
.19431 .2415 L
.19801 .24519 L
.1997 .24633 L
.20284 .24946 L
.20494 .25116 L
.20767 .25388 L
.21012 .25599 L
.20895 .26082 L
.2125 .26437 L
.21431 .26566 L
.21734 .26867 L
.21954 .27049 L
.21809 .27532 L
.22217 .27939 L
.22367 .28015 L
.227 .28347 L
.22897 .28498 L
.23183 .28783 L
Mistroke
.23418 .28981 L
.23303 .29465 L
.23666 .29827 L
.23843 .29948 L
.2415 .30253 L
.24369 .30431 L
.24238 .30914 L
.24633 .31308 L
.24792 .31397 L
.25116 .3172 L
.25322 .31881 L
.25171 .32364 L
.25599 .32792 L
.25744 .32847 L
.26082 .33184 L
.26278 .3333 L
.26566 .33616 L
.26802 .33813 L
.26701 .34296 L
.27049 .34643 L
.27239 .3478 L
.27532 .35071 L
.27764 .35263 L
.27664 .35746 L
.28015 .36096 L
.28203 .36229 L
.28498 .36522 L
.28729 .36712 L
.28632 .37196 L
.28981 .37543 L
.29172 .37679 L
.29015 .38162 L
.29465 .38611 L
.29607 .38645 L
.29948 .38985 L
.30145 .39128 L
.30017 .39612 L
.30431 .40025 L
.30586 .40095 L
.30914 .40421 L
.31121 .40578 L
.31013 .41061 L
.31397 .41444 L
.31568 .41544 L
.31881 .41855 L
.32099 .42027 L
.32008 .42511 L
.32364 .42865 L
.32552 .42994 L
.32429 .43477 L
Mistroke
.32847 .43894 L
.33002 .4396 L
.3333 .44286 L
.33539 .44443 L
.33443 .44927 L
.33813 .45304 L
.33979 .4541 L
.33867 .45893 L
.34296 .46322 L
.34436 .46376 L
.3478 .46718 L
.34968 .46859 L
.3489 .47342 L
.35263 .47714 L
.35431 .47826 L
.35339 .48309 L
.35746 .48715 L
.35895 .48792 L
.35755 .49275 L
.36229 .49749 L
.36359 .49758 L
.36712 .5011 L
.36893 .50242 L
.36822 .50725 L
.37196 .51097 L
.37363 .51208 L
.37284 .51691 L
.37679 .52084 L
.37834 .52174 L
.37746 .52658 L
.38162 .53073 L
.38306 .53141 L
.38204 .53624 L
.38645 .54064 L
.3878 .54107 L
.39128 .54454 L
.39311 .5459 L
.39255 .55073 L
.39612 .55428 L
.39789 .55557 L
.39732 .5604 L
.40095 .564 L
.40268 .56523 L
.40212 .57006 L
.40578 .5737 L
.40748 .57489 L
.40694 .57973 L
.41061 .58338 L
.4123 .58456 L
.41178 .58939 L
Mistroke
.41544 .59303 L
.41713 .59422 L
.41664 .59905 L
.4156 .60388 L
.42027 .60856 L
.42152 .60872 L
.42073 .61355 L
.42511 .61792 L
.42641 .61838 L
.42576 .62321 L
.42994 .62738 L
.4313 .62804 L
.43076 .63288 L
.43477 .63687 L
.43621 .63771 L
.43575 .64254 L
.4396 .64637 L
.44111 .64737 L
.44072 .6522 L
.44008 .65704 L
.44443 .66138 L
.44568 .66187 L
.44521 .6667 L
.44927 .67074 L
.45063 .67153 L
.45026 .67636 L
.44963 .68119 L
.4541 .68566 L
.45526 .68603 L
.45485 .69086 L
.45893 .69492 L
.46022 .69569 L
.45992 .70052 L
.45947 .70535 L
.46376 .70964 L
.46492 .71019 L
.46462 .71502 L
.46415 .71985 L
.46859 .72429 L
.46965 .72468 L
.46937 .72951 L
.46893 .73434 L
.47342 .73885 L
.4744 .73918 L
.47416 .74401 L
.47381 .74884 L
.47826 .7533 L
.47917 .75367 L
.47897 .7585 L
.47872 .76334 L
Mistroke
.48309 .76772 L
.48393 .76817 L
.48377 .773 L
.4836 .77783 L
.48338 .78266 L
.48792 .78723 L
.48852 .7875 L
.4884 .79233 L
.48828 .79716 L
.48814 .80199 L
.49275 .80668 L
.49303 .80682 L
.49294 .81165 L
.49287 .81649 L
.49281 .82132 L
.49276 .82615 L
.49275 .82687 L
.49271 .83098 L
.49095 .83581 L
.48999 .84065 L
.48904 .84548 L
.48811 .85031 L
.48792 .85133 L
.4873 .85514 L
.48653 .85997 L
.4858 .8648 L
.48511 .86964 L
.48446 .87447 L
.48386 .8793 L
.48331 .88413 L
.48309 .88626 L
.48284 .88896 L
.48244 .8938 L
.4821 .89863 L
.48182 .90346 L
.48162 .90829 L
.48148 .91312 L
.48143 .91796 L
.48147 .92279 L
.48161 .92762 L
.48185 .93245 L
.4822 .93728 L
.48269 .94211 L
.48309 .94526 L
.48333 .94695 L
.48414 .95178 L
.48517 .95661 L
.48648 .96144 L
.48792 .96559 L
.48816 .96627 L
Mistroke
.49028 .97111 L
.49275 .97454 L
.49401 .97594 L
.49758 .97839 L
.50242 .97839 L
.506 .97594 L
.50725 .97455 L
.50972 .97111 L
.51185 .96627 L
.51208 .9656 L
.51352 .96144 L
.51483 .95661 L
.51586 .95178 L
.51668 .94695 L
.51691 .94531 L
.51732 .94211 L
.5178 .93728 L
.51816 .93245 L
.5184 .92762 L
.51853 .92279 L
.51857 .91796 L
.51852 .91312 L
.51839 .90829 L
.51818 .90346 L
.51791 .89863 L
.51757 .8938 L
.51717 .88896 L
.51691 .8862 L
.5167 .88413 L
.51615 .8793 L
.51555 .87447 L
.5149 .86964 L
.5142 .8648 L
.51347 .85997 L
.51271 .85514 L
.51208 .85129 L
.5119 .85031 L
.51097 .84548 L
.51002 .84065 L
.50906 .83581 L
.50729 .83098 L
.50725 .82685 L
.50724 .82615 L
.50719 .82132 L
.50713 .81649 L
.50706 .81165 L
.50697 .80682 L
.50725 .80668 L
.51186 .80199 L
.51172 .79716 L
Mistroke
.5116 .79233 L
.51148 .7875 L
.51208 .78723 L
.51662 .78266 L
.5164 .77783 L
.51623 .773 L
.51607 .76817 L
.51691 .76772 L
.52128 .76334 L
.52103 .7585 L
.52083 .75367 L
.52174 .7533 L
.52619 .74884 L
.52584 .74401 L
.5256 .73918 L
.52658 .73885 L
.53107 .73434 L
.53063 .72951 L
.53035 .72468 L
.53141 .72429 L
.53585 .71985 L
.53538 .71502 L
.53508 .71019 L
.53624 .70964 L
.54053 .70535 L
.54008 .70052 L
.53978 .69569 L
.54107 .69492 L
.54515 .69086 L
.54474 .68603 L
.5459 .68566 L
.55037 .68119 L
.54974 .67636 L
.54937 .67153 L
.55073 .67074 L
.55479 .6667 L
.55432 .66187 L
.55557 .66138 L
.55992 .65704 L
.55928 .6522 L
.55889 .64737 L
.5604 .64637 L
.56425 .64254 L
.56379 .63771 L
.56523 .63687 L
.56924 .63288 L
.5687 .62804 L
.57006 .62738 L
.57424 .62321 L
.57359 .61838 L
Mistroke
.57489 .61792 L
.57927 .61355 L
.57848 .60872 L
.57973 .60856 L
.5844 .60388 L
.58336 .59905 L
.58287 .59422 L
.58456 .59303 L
.58822 .58939 L
.5877 .58456 L
.58939 .58338 L
.59306 .57973 L
.59252 .57489 L
.59422 .5737 L
.59788 .57006 L
.59732 .56523 L
.59905 .564 L
.60268 .5604 L
.60211 .55557 L
.60388 .55428 L
.60745 .55073 L
.60689 .5459 L
.60872 .54454 L
.6122 .54107 L
.61355 .54064 L
.61796 .53624 L
.61694 .53141 L
.61838 .53073 L
.62254 .52658 L
.62166 .52174 L
.62321 .52084 L
.62716 .51691 L
.62637 .51208 L
.62804 .51097 L
.63178 .50725 L
.63107 .50242 L
.63288 .5011 L
.63641 .49758 L
.63771 .49749 L
.64245 .49275 L
.64105 .48792 L
.64254 .48715 L
.64661 .48309 L
.64569 .47826 L
.64737 .47714 L
.6511 .47342 L
.65032 .46859 L
.6522 .46718 L
.65564 .46376 L
.65704 .46322 L
Mistroke
.66133 .45893 L
.66021 .4541 L
.66187 .45304 L
.66557 .44927 L
.66461 .44443 L
.6667 .44286 L
.66998 .4396 L
.67153 .43894 L
.67571 .43477 L
.67448 .42994 L
.67636 .42865 L
.67992 .42511 L
.67901 .42027 L
.68119 .41855 L
.68432 .41544 L
.68603 .41444 L
.68987 .41061 L
.68879 .40578 L
.69086 .40421 L
.69414 .40095 L
.69569 .40025 L
.69983 .39612 L
.69855 .39128 L
.70052 .38985 L
.70393 .38645 L
.70535 .38611 L
.70985 .38162 L
.70828 .37679 L
.71019 .37543 L
.71368 .37196 L
.71271 .36712 L
.71502 .36522 L
.71797 .36229 L
.71985 .36096 L
.72336 .35746 L
.72236 .35263 L
.72468 .35071 L
.72761 .3478 L
.72951 .34643 L
.73299 .34296 L
.73198 .33813 L
.73434 .33616 L
.73722 .3333 L
.73918 .33184 L
.74256 .32847 L
.74401 .32792 L
.74829 .32364 L
.74678 .31881 L
.74884 .3172 L
.75208 .31397 L
Mistroke
.75367 .31308 L
.75762 .30914 L
.75631 .30431 L
.7585 .30253 L
.76157 .29948 L
.76334 .29827 L
.76697 .29465 L
.76582 .28981 L
.76817 .28783 L
.77103 .28498 L
.773 .28347 L
.77633 .28015 L
.77783 .27939 L
.78191 .27532 L
.78046 .27049 L
.78266 .26867 L
.78569 .26566 L
.7875 .26437 L
.79105 .26082 L
.78988 .25599 L
.79233 .25388 L
.79506 .25116 L
.79716 .24946 L
.8003 .24633 L
.80199 .24519 L
.80569 .2415 L
.80442 .23666 L
.80682 .23459 L
.80959 .23183 L
.81165 .23016 L
.81483 .227 L
.81649 .22589 L
.82022 .22217 L
.8189 .21734 L
.82132 .21523 L
.82406 .2125 L
.82615 .21078 L
.82927 .20767 L
.83098 .20646 L
.83461 .20284 L
.83332 .19801 L
.83581 .19581 L
.83845 .19318 L
.84065 .19133 L
.84364 .18835 L
.84548 .18693 L
.84891 .18351 L
.85031 .18278 L
.85441 .17868 L
.85279 .17385 L
Mistroke
.85514 .1718 L
.85794 .16902 L
.85997 .16734 L
.86313 .16419 L
.8648 .16298 L
.86844 .15935 L
.86964 .15913 L
.87424 .15452 L
.87218 .14969 L
.87447 .1477 L
.87732 .14486 L
.8793 .14323 L
.88251 .14003 L
.88413 .13886 L
.88781 .1352 L
.88896 .13503 L
.89364 .13036 L
.89148 .12553 L
.8938 .12348 L
.89659 .1207 L
.89863 .11898 L
.90175 .11587 L
.90346 .11455 L
.90698 .11104 L
.90829 .11034 L
.91243 .1062 L
.91068 .10137 L
.91312 .09916 L
.91576 .09654 L
.91796 .09461 L
.92087 .09171 L
.92279 .09011 L
.92602 .08688 L
.92762 .08569 L
.93127 .08204 L
.93245 .08154 L
.93678 .07721 L
.93484 .07238 L
.93728 .07016 L
.9399 .06755 L
.94211 .06558 L
.94498 .06272 L
.94695 .06104 L
.9501 .05789 L
.95178 .05655 L
.95528 .05305 L
.95661 .05221 L
.9606 .04822 L
.95886 .04339 L
.96144 .041 L
Mistroke
.9639 .03856 L
.96627 .03639 L
.96894 .03373 L
.97111 .03179 L
.97401 .02889 L
.97594 .02722 L
.97993 .02406 L
.98077 .02176 L
Mfstroke
.955 .186 0 r
.01923 .02126 m
.02043 .02406 L
.02406 .02666 L
.02664 .02889 L
.02889 .03114 L
.0318 .03373 L
.03373 .03565 L
.03693 .03856 L
.03856 .04018 L
.04204 .04339 L
.03968 .04822 L
.04339 .05193 L
.04515 .05305 L
.04822 .05612 L
.05045 .05789 L
.05305 .06048 L
.05568 .06272 L
.05789 .06492 L
.06086 .06755 L
.06272 .0694 L
.06602 .07238 L
.0634 .07721 L
.06755 .08137 L
.06913 .08204 L
.07238 .08529 L
.07451 .08688 L
.07721 .08958 L
.07978 .09171 L
.08204 .09397 L
.08499 .09654 L
.08688 .09841 L
.09017 .10137 L
.0878 .1062 L
.09171 .11011 L
.09345 .11104 L
.09654 .11412 L
.09882 .11587 L
.10137 .11841 L
.1041 .1207 L
.1062 .1228 L
.10932 .12553 L
.10642 .13036 L
.11104 .13498 L
.11258 .1352 L
.11587 .13848 L
.11803 .14003 L
.1207 .14269 L
.12335 .14486 L
.12553 .14703 L
.1286 .14969 L
.12583 .15452 L
.13036 .15905 L
.13196 .15935 L
.1352 .16258 L
.13742 .16419 L
.14003 .16678 L
.14275 .16902 L
.14486 .17111 L
.14801 .17385 L
.14583 .17868 L
.14969 .18253 L
.15156 .18351 L
.15452 .18647 L
.15698 .18835 L
.15935 .19071 L
.16229 .19318 L
.16419 .19506 L
.16755 .19801 L
.16578 .20284 L
.16902 .20607 L
.17129 .20767 L
.17385 .21022 L
.17665 .2125 L
.17868 .21452 L
.18194 .21734 L
.18015 .22217 L
.18351 .22552 L
.18572 .227 L
.18835 .22961 L
.19111 .23183 L
.19318 .23389 L
.19641 .23666 L
.19468 .2415 L
.19801 .24481 L
.20026 .24633 L
.20284 .24889 L
.20565 .25116 L
.20767 .25316 L
.21096 .25599 L
.20937 .26082 L
.2125 .26394 L
.21491 .26566 L
.21734 .26807 L
.22029 .27049 L
.21835 .27532 L
.22217 .27913 L
.22416 .28015 L
.227 .28297 L
.22964 .28498 L
.23183 .28716 L
.23499 .28981 L
.23342 .29465 L
.23666 .29788 L
.23902 .29948 L
.2415 .30194 L
.24443 .30431 L
.24267 .30914 L
.24633 .31279 L
.24844 .31397 L
.25116 .31667 L
.25391 .31881 L
.2519 .32364 L
.25599 .32773 L
.25792 .32847 L
.26082 .33136 L
.26344 .3333 L
.26566 .3355 L
.26883 .33813 L
.26745 .34296 L
.27049 .34598 L
.27302 .3478 L
.27532 .35007 L
.27843 .35263 L
.27707 .35746 L
.28015 .36052 L
.28266 .36229 L
.28498 .36459 L
.28808 .36712 L
.28677 .37196 L
.28981 .37499 L
.29236 .37679 L
.29027 .38162 L
.29465 .386 L
.29654 .38645 L
.29948 .38937 L
.30211 .39128 L
.3004 .39612 L
.30431 .40002 L
.30637 .40095 L
.30914 .4037 L
.3119 .40578 L
.31046 .41061 L
.31397 .41411 L
.31624 .41544 L
.31881 .41798 L
.32173 .42027 L
.3205 .42511 L
.32364 .42822 L
.32615 .42994 L
.32451 .43477 L
.32847 .43872 L
.33053 .4396 L
.3333 .44235 L
.33609 .44443 L
.33481 .44927 L
.33813 .45265 L
.34039 .4541 L
.33887 .45893 L
.34296 .46302 L
.34487 .46376 L
.3478 .46667 L
.35037 .46859 L
.34931 .47342 L
.35263 .47673 L
.35493 .47826 L
.35367 .48309 L
.35746 .48686 L
.3595 .48792 L
.35759 .49275 L
.36229 .49746 L
.36406 .49758 L
.36712 .50062 L
.3696 .50242 L
.36862 .50725 L
.37196 .51056 L
.37425 .51208 L
.37318 .51691 L
.37679 .52051 L
.37891 .52174 L
.37771 .52658 L
.38162 .53047 L
.3836 .53141 L
.38221 .53624 L
.38645 .54048 L
.3883 .54107 L
.39128 .54403 L
.3938 .5459 L
.39303 .55073 L
.39612 .5538 L
.39856 .55557 L
.39778 .5604 L
.40095 .56354 L
.40333 .56523 L
.40257 .57006 L
.40578 .57325 L
.40813 .57489 L
.40738 .57973 L
.41061 .58293 L
.41294 .58456 L
.41223 .58939 L
.41544 .59258 L
.41778 .59422 L
.4171 .59905 L
.41566 .60388 L
.42027 .6085 L
.422 .60872 L
.42091 .61355 L
.42511 .61773 L
.42692 .61838 L
.42602 .62321 L
.42994 .62711 L
.43184 .62804 L
.4311 .63288 L
.43477 .63653 L
.43678 .63771 L
.43614 .64254 L
.4396 .64597 L
.44172 .64737 L
.44118 .6522 L
.44028 .65704 L
.44443 .66118 L
.44619 .66187 L
.44554 .6667 L
.44927 .67041 L
.45119 .67153 L
.45067 .67636 L
.44978 .68119 L
.4541 .6855 L
.45575 .68603 L
.45518 .69086 L
.45893 .69459 L
.46078 .69569 L
.46035 .70052 L
.45972 .70535 L
.46376 .70938 L
.46544 .71019 L
.46501 .71502 L
.46433 .71985 L
.46859 .7241 L
.47013 .72468 L
.46973 .72951 L
.46909 .73434 L
.47342 .73868 L
.47488 .73918 L
.47452 .74401 L
.474 .74884 L
.47826 .75309 L
.47965 .75367 L
.47936 .7585 L
.47898 .76334 L
.48309 .76745 L
.48442 .76817 L
.48419 .773 L
.48393 .77783 L
.48358 .78266 L
.48792 .78703 L
.48897 .7875 L
.48879 .79233 L
.48859 .79716 L
.48835 .80199 L
.49275 .80646 L
.49346 .80682 L
.49333 .81165 L
.49321 .81649 L
.49309 .82132 L
.49297 .82615 L
.49285 .83098 L
.49449 .83581 L
.49375 .84065 L
.49318 .84548 L
.49275 .85031 L
.49275 .85033 L
.49218 .85514 L
.49168 .85997 L
.49122 .8648 L
.49074 .86964 L
.49019 .87447 L
.4896 .8793 L
.48896 .88413 L
.48864 .88896 L
.48842 .8938 L
.48828 .89863 L
.48825 .90346 L
.48833 .90829 L
.48853 .91312 L
.48887 .91796 L
.48935 .92279 L
.49003 .92762 L
.49098 .93245 L
.49238 .93728 L
.49275 .93829 L
.49445 .94211 L
.49758 .94606 L
.50242 .94606 L
.50556 .94211 L
.50725 .9383 L
.50763 .93728 L
.50902 .93245 L
.50997 .92762 L
.51065 .92279 L
.51114 .91796 L
.51147 .91312 L
.51167 .90829 L
.51175 .90346 L
.51172 .89863 L
.51159 .8938 L
.51136 .88896 L
.51104 .88413 L
.51041 .8793 L
.50981 .87447 L
.50927 .86964 L
.50878 .8648 L
.50832 .85997 L
.50782 .85514 L
.50725 .85031 L
.50725 .8503 L
.50682 .84548 L
.50625 .84065 L
.50552 .83581 L
.50715 .83098 L
.50703 .82615 L
.50691 .82132 L
.50679 .81649 L
.50667 .81165 L
.50654 .80682 L
.50725 .80646 L
.51165 .80199 L
.51141 .79716 L
.51121 .79233 L
.51103 .7875 L
.51208 .78703 L
.51642 .78266 L
.51607 .77783 L
.51581 .773 L
.51558 .76817 L
.51691 .76745 L
.52102 .76334 L
.52064 .7585 L
.52035 .75367 L
.52174 .75309 L
.526 .74884 L
.52548 .74401 L
.52512 .73918 L
.52658 .73868 L
.53091 .73434 L
.53027 .72951 L
.52987 .72468 L
.53141 .7241 L
.53567 .71985 L
.53499 .71502 L
.53456 .71019 L
.53624 .70938 L
.54028 .70535 L
.53965 .70052 L
.53922 .69569 L
.54107 .69459 L
.54482 .69086 L
.54425 .68603 L
.5459 .6855 L
.55022 .68119 L
.54933 .67636 L
.54881 .67153 L
.55073 .67041 L
.55446 .6667 L
.55381 .66187 L
.55557 .66118 L
.55972 .65704 L
.55882 .6522 L
.55828 .64737 L
.5604 .64597 L
.56386 .64254 L
.56322 .63771 L
.56523 .63653 L
.5689 .63288 L
.56816 .62804 L
.57006 .62711 L
.57398 .62321 L
.57308 .61838 L
.57489 .61773 L
.57909 .61355 L
.578 .60872 L
.57973 .6085 L
.58434 .60388 L
.5829 .59905 L
.58222 .59422 L
.58456 .59258 L
.58777 .58939 L
.58706 .58456 L
.58939 .58293 L
.59262 .57973 L
.59187 .57489 L
.59422 .57325 L
.59743 .57006 L
.59667 .56523 L
.59905 .56354 L
.60222 .5604 L
.60144 .55557 L
.60388 .5538 L
.60697 .55073 L
.6062 .5459 L
.60872 .54403 L
.6117 .54107 L
.61355 .54048 L
.61779 .53624 L
.6164 .53141 L
.61838 .53047 L
.62229 .52658 L
.62108 .52174 L
.62321 .52051 L
.62682 .51691 L
.62575 .51208 L
.62804 .51056 L
.63138 .50725 L
.6304 .50242 L
.63288 .50062 L
.63594 .49758 L
.63771 .49746 L
.64241 .49275 L
.6405 .48792 L
.64254 .48686 L
.64633 .48309 L
.64507 .47826 L
.64737 .47673 L
.65069 .47342 L
.64963 .46859 L
.6522 .46667 L
.65513 .46376 L
.65704 .46302 L
.66113 .45893 L
.65961 .4541 L
.66187 .45265 L
.66519 .44927 L
.66391 .44443 L
.6667 .44235 L
.66947 .4396 L
.67153 .43872 L
.67549 .43477 L
.67385 .42994 L
.67636 .42822 L
.6795 .42511 L
.67827 .42027 L
.68119 .41798 L
.68376 .41544 L
.68603 .41411 L
.68954 .41061 L
.6881 .40578 L
.69086 .4037 L
.69363 .40095 L
.69569 .40002 L
.6996 .39612 L
.69789 .39128 L
.70052 .38937 L
.70346 .38645 L
.70535 .386 L
.70973 .38162 L
.70764 .37679 L
.71019 .37499 L
.71323 .37196 L
.71192 .36712 L
.71502 .36459 L
.71734 .36229 L
.71985 .36052 L
.72293 .35746 L
.72157 .35263 L
.72468 .35007 L
.72698 .3478 L
.72951 .34598 L
.73255 .34296 L
.73117 .33813 L
.73434 .3355 L
.73656 .3333 L
.73918 .33136 L
.74208 .32847 L
.74401 .32773 L
.7481 .32364 L
.74609 .31881 L
.74884 .31667 L
.75156 .31397 L
.75367 .31279 L
.75733 .30914 L
.75557 .30431 L
.7585 .30194 L
.76098 .29948 L
.76334 .29788 L
.76658 .29465 L
.76501 .28981 L
.76817 .28716 L
.77036 .28498 L
.773 .28297 L
.77584 .28015 L
.77783 .27913 L
.78165 .27532 L
.77971 .27049 L
.78266 .26807 L
.78509 .26566 L
.7875 .26394 L
.79063 .26082 L
.78904 .25599 L
.79233 .25316 L
.79435 .25116 L
.79716 .24889 L
.79974 .24633 L
.80199 .24481 L
.80532 .2415 L
.80359 .23666 L
.80682 .23389 L
.80889 .23183 L
.81165 .22961 L
.81428 .227 L
.81649 .22552 L
.81985 .22217 L
.81806 .21734 L
.82132 .21452 L
.82335 .2125 L
.82615 .21022 L
.82871 .20767 L
.83098 .20607 L
.83422 .20284 L
.83245 .19801 L
.83581 .19506 L
.83771 .19318 L
.84065 .19071 L
.84302 .18835 L
.84548 .18647 L
.84844 .18351 L
.85031 .18253 L
.85417 .17868 L
.85199 .17385 L
.85514 .17111 L
.85725 .16902 L
.85997 .16678 L
.86258 .16419 L
.8648 .16258 L
.86804 .15935 L
.86964 .15905 L
.87417 .15452 L
.8714 .14969 L
.87447 .14703 L
.87665 .14486 L
.8793 .14269 L
.88197 .14003 L
.88413 .13848 L
.88742 .1352 L
.88896 .13498 L
.89358 .13036 L
.89068 .12553 L
.8938 .1228 L
.8959 .1207 L
.89863 .11841 L
.90118 .11587 L
.90346 .11412 L
.90655 .11104 L
.90829 .11011 L
.9122 .1062 L
.90983 .10137 L
.91312 .09841 L
.91501 .09654 L
.91796 .09397 L
.92022 .09171 L
.92279 .08958 L
.92549 .08688 L
.92762 .08529 L
.93087 .08204 L
.93245 .08137 L
.9366 .07721 L
.93398 .07238 L
.93245 .07113 L
.92793 .07238 L
.92762 .07421 L
.92683 .07721 L
.92279 .07914 L
.9212 .08204 L
.91796 .0849 L
.91663 .08688 L
.91312 .09064 L
.91228 .09171 L
.90829 .09639 L
.90818 .09654 L
.90374 .10137 L
.90346 .10283 L
.90228 .1062 L
.89863 .10815 L
.89694 .11104 L
.8938 .11401 L
.89253 .11587 L
.88896 .11986 L
.88832 .1207 L
.8842 .12553 L
.88413 .12612 L
.88389 .13036 L
.8793 .13174 L
.87748 .1352 L
.87447 .13772 L
.87296 .14003 L
.86964 .14368 L
.86874 .14486 L
.8648 .14964 L
.86477 .14969 L
.86445 .15452 L
.85997 .15574 L
.85803 .15935 L
.85514 .16182 L
.85359 .16419 L
.85031 .16788 L
.84946 .16902 L
.84551 .17385 L
.84548 .17403 L
.844 .17868 L
.84065 .18016 L
.83865 .18351 L
.83581 .18633 L
.83432 .18835 L
.83098 .1925 L
.83048 .19318 L
.82637 .19801 L
.82615 .19873 L
.82395 .20284 L
.82132 .20502 L
.81937 .20767 L
.81649 .21129 L
.8156 .2125 L
.81172 .21734 L
.81165 .21757 L
.80935 .22217 L
.80682 .22396 L
.80491 .227 L
.80199 .23033 L
.80091 .23183 L
.79717 .23666 L
.79716 .23671 L
.7947 .2415 L
.79233 .24319 L
.79008 .24633 L
.7875 .24966 L
.78643 .25116 L
.78271 .25599 L
.78266 .25614 L
.78005 .26082 L
.77783 .26272 L
.77576 .26566 L
.773 .26929 L
.77216 .27049 L
.77098 .27532 L
.76817 .27589 L
.76563 .28015 L
.76334 .28257 L
.76166 .28498 L
.7585 .28923 L
.75811 .28981 L
.75553 .29465 L
.75367 .29598 L
.75126 .29948 L
.74884 .30274 L
.74778 .30431 L
.74608 .30914 L
.74401 .30953 L
.74134 .31397 L
.73918 .3164 L
.73756 .31881 L
.73434 .32327 L
.7341 .32364 L
.73127 .32847 L
.72951 .33022 L
.72745 .3333 L
.72468 .33719 L
.72406 .33813 L
.72127 .34296 L
.71985 .34421 L
.71748 .3478 L
.71502 .35128 L
.71413 .35263 L
.71133 .35746 L
.71019 .35839 L
.70763 .36229 L
.70535 .36555 L
.70434 .36712 L
.70149 .37196 L
.70052 .37276 L
.69791 .37679 L
.69569 .38002 L
.69467 .38162 L
.6918 .38645 L
.69086 .38733 L
.68834 .39128 L
.68603 .3947 L
.68514 .39612 L
.68227 .40095 L
.68119 .40212 L
.6789 .40578 L
.67636 .4096 L
.67574 .41061 L
.67266 .41544 L
.67153 .41714 L
.66959 .42027 L
.6667 .42472 L
.66647 .42511 L
.66347 .42994 L
.66187 .43239 L
.66042 .43477 L
.65757 .4396 L
.65704 .44005 L
.65243 .44443 L
.6522 .44478 L
.64943 .44927 L
.64737 .4525 L
.6464 .4541 L
.64339 .45893 L
.64254 .46027 L
.64042 .46376 L
.63771 .4681 L
.63741 .46859 L
.63448 .47342 L
.63288 .476 L
.63153 .47826 L
.62858 .48309 L
.62804 .48395 L
.62568 .48792 L
.62321 .49197 L
.62275 .49275 L
.61988 .49758 L
.61838 .50005 L
.617 .50242 L
.61412 .50725 L
.61355 .5082 L
.61129 .51208 L
.60872 .5164 L
.60842 .51691 L
.60562 .52174 L
.60388 .52467 L
.60279 .52658 L
.59999 .53141 L
.59905 .533 L
.59721 .53624 L
.59441 .54107 L
.59422 .54139 L
.59166 .5459 L
.58939 .54983 L
.58888 .55073 L
.58615 .55557 L
.58456 .55833 L
.5834 .5604 L
.58067 .56523 L
.57973 .56688 L
.57795 .57006 L
.57522 .57489 L
.57489 .57546 L
.57252 .57973 L
.57006 .58407 L
.56979 .58456 L
.5671 .58939 L
.56523 .5927 L
.56439 .59422 L
.56168 .59905 L
.5604 .60132 L
.55897 .60388 L
.55625 .60872 L
.55557 .60991 L
.55353 .61355 L
.55077 .61838 L
.55073 .61844 L
.54802 .62321 L
.5459 .62686 L
.54523 .62804 L
.54241 .63288 L
.54107 .63511 L
.53954 .63771 L
.5366 .64254 L
.53624 .64311 L
.5336 .64737 L
.53141 .65076 L
.53048 .6522 L
.5272 .65704 L
.52658 .65792 L
.52374 .66187 L
.52174 .66442 L
.51993 .6667 L
.51691 .67004 L
.51554 .67153 L
.51208 .67457 L
.50997 .67636 L
.50725 .67776 L
.50242 .67941 L
.49758 .67941 L
.49275 .67776 L
.49003 .67636 L
.48792 .67457 L
.48446 .67153 L
.48309 .67004 L
.48007 .6667 L
.47826 .66441 L
.47626 .66187 L
.47342 .65792 L
.4728 .65704 L
.46952 .6522 L
.46859 .65076 L
.4664 .64737 L
.46376 .64311 L
.4634 .64254 L
.46046 .63771 L
.45893 .63511 L
.45759 .63288 L
.45477 .62804 L
.4541 .62686 L
.45198 .62321 L
.44927 .61844 L
.44923 .61838 L
.44647 .61355 L
.44443 .60991 L
.44375 .60872 L
.44103 .60388 L
.4396 .60132 L
.43832 .59905 L
.43561 .59422 L
.43477 .5927 L
.4329 .58939 L
.43021 .58456 L
.42994 .58407 L
.42748 .57973 L
.42511 .57546 L
.42479 .57489 L
.42205 .57006 L
.42027 .56687 L
.41933 .56523 L
.4166 .5604 L
.41544 .55833 L
.41385 .55557 L
.41112 .55073 L
.41061 .54983 L
.40834 .5459 L
.40578 .54139 L
.4056 .54107 L
.40279 .53624 L
.40095 .533 L
.40001 .53141 L
.39721 .52658 L
.39612 .52467 L
.39438 .52174 L
.39158 .51691 L
.39128 .5164 L
.38871 .51208 L
.38645 .50819 L
.38588 .50725 L
.383 .50242 L
.38162 .50005 L
.38012 .49758 L
.37725 .49275 L
.37679 .49197 L
.37432 .48792 L
.37196 .48395 L
.37142 .48309 L
.36847 .47826 L
.36712 .476 L
.36552 .47342 L
.36259 .46859 L
.36229 .4681 L
.35958 .46376 L
.35746 .46027 L
.35661 .45893 L
.35361 .4541 L
.35263 .4525 L
.35057 .44927 L
.3478 .44478 L
.34758 .44443 L
.34296 .44005 L
.34244 .4396 L
.33958 .43477 L
.33813 .43239 L
.33653 .42994 L
.33353 .42511 L
.3333 .42472 L
.33041 .42027 L
.32847 .41714 L
.32734 .41544 L
.32427 .41061 L
.32364 .4096 L
.3211 .40578 L
.31881 .40212 L
.31773 .40095 L
.31486 .39612 L
.31397 .3947 L
.31166 .39128 L
.30914 .38733 L
.3082 .38645 L
.30533 .38162 L
.30431 .38002 L
.30209 .37679 L
.29948 .37276 L
.29851 .37196 L
.29566 .36712 L
.29465 .36555 L
.29237 .36229 L
.28981 .35839 L
.28867 .35746 L
.28587 .35263 L
.28498 .35128 L
.28253 .3478 L
.28015 .34421 L
.27873 .34296 L
.27594 .33813 L
.27532 .33719 L
.27255 .3333 L
.27049 .33022 L
.26873 .32847 L
.2659 .32364 L
.26566 .32327 L
.26244 .31881 L
.26082 .3164 L
.25866 .31397 L
.25599 .30953 L
.25392 .30914 L
.25222 .30431 L
.25116 .30274 L
.24874 .29948 L
.24633 .29598 L
.24447 .29465 L
.24189 .28981 L
.2415 .28923 L
.23834 .28498 L
.23666 .28257 L
.23437 .28015 L
.23183 .27589 L
.22902 .27532 L
.22784 .27049 L
.227 .26929 L
.22424 .26566 L
.22217 .26272 L
.21995 .26082 L
.21734 .25614 L
.2173 .25599 L
.21357 .25116 L
.2125 .24966 L
.20992 .24633 L
.20767 .24319 L
.2053 .2415 L
.20284 .2367 L
.20283 .23666 L
.19909 .23183 L
.19801 .23033 L
.19509 .227 L
.19318 .22396 L
.19065 .22217 L
.18835 .21757 L
.18828 .21734 L
.1844 .2125 L
.18351 .21129 L
.18063 .20767 L
.17868 .20502 L
.17605 .20284 L
.17385 .19873 L
.17364 .19801 L
.16952 .19318 L
.16902 .1925 L
.16568 .18835 L
.16419 .18633 L
.16135 .18351 L
.15935 .18015 L
.156 .17868 L
.15452 .17403 L
.15449 .17385 L
.15054 .16902 L
.14969 .16788 L
.14641 .16419 L
.14486 .16182 L
.14197 .15935 L
.14003 .15574 L
.13555 .15452 L
.13523 .14969 L
.1352 .14964 L
.13126 .14486 L
.13036 .14368 L
.12704 .14003 L
.12553 .13772 L
.12252 .1352 L
.1207 .13174 L
.11611 .13036 L
.11587 .12612 L
.11581 .12553 L
.11168 .1207 L
.11104 .11986 L
.10747 .11587 L
.1062 .11401 L
.10306 .11104 L
.10137 .10814 L
.09772 .1062 L
.09654 .10283 L
.09626 .10137 L
.09183 .09654 L
.09171 .09639 L
.08772 .09171 L
.08688 .09064 L
.08337 .08688 L
.08204 .0849 L
.0788 .08204 L
.07721 .07914 L
.07317 .07721 L
.07238 .07421 L
.07207 .07238 L
.06755 .07113 L
.06754 .06755 L
.06334 .06272 L
.06272 .06194 L
.05899 .05789 L
.05789 .05631 L
.05449 .05305 L
.05305 .05068 L
.04947 .04822 L
.04822 .04568 L
.04766 .04339 L
.04339 .04128 L
.04313 .03856 L
.03857 .03373 L
.03856 .03371 L
.03431 .02889 L
.03373 .02819 L
.02989 .02406 L
.02889 .02358 L
.02537 .01923 L
.01923 .01923 L
F
0 g
.01923 .02126 m
.02043 .02406 L
.02406 .02666 L
.02664 .02889 L
.02889 .03114 L
.0318 .03373 L
.03373 .03565 L
.03693 .03856 L
.03856 .04018 L
.04204 .04339 L
.03968 .04822 L
.04339 .05193 L
.04515 .05305 L
.04822 .05612 L
.05045 .05789 L
.05305 .06048 L
.05568 .06272 L
.05789 .06492 L
.06086 .06755 L
.06272 .0694 L
.06602 .07238 L
.0634 .07721 L
.06755 .08137 L
.06913 .08204 L
.07238 .08529 L
.07451 .08688 L
.07721 .08958 L
.07978 .09171 L
.08204 .09397 L
.08499 .09654 L
.08688 .09841 L
.09017 .10137 L
.0878 .1062 L
.09171 .11011 L
.09345 .11104 L
.09654 .11412 L
.09882 .11587 L
.10137 .11841 L
.1041 .1207 L
.1062 .1228 L
.10932 .12553 L
.10642 .13036 L
.11104 .13498 L
.11258 .1352 L
.11587 .13848 L
.11803 .14003 L
.1207 .14269 L
.12335 .14486 L
.12553 .14703 L
.1286 .14969 L
Mistroke
.12583 .15452 L
.13036 .15905 L
.13196 .15935 L
.1352 .16258 L
.13742 .16419 L
.14003 .16678 L
.14275 .16902 L
.14486 .17111 L
.14801 .17385 L
.14583 .17868 L
.14969 .18253 L
.15156 .18351 L
.15452 .18647 L
.15698 .18835 L
.15935 .19071 L
.16229 .19318 L
.16419 .19506 L
.16755 .19801 L
.16578 .20284 L
.16902 .20607 L
.17129 .20767 L
.17385 .21022 L
.17665 .2125 L
.17868 .21452 L
.18194 .21734 L
.18015 .22217 L
.18351 .22552 L
.18572 .227 L
.18835 .22961 L
.19111 .23183 L
.19318 .23389 L
.19641 .23666 L
.19468 .2415 L
.19801 .24481 L
.20026 .24633 L
.20284 .24889 L
.20565 .25116 L
.20767 .25316 L
.21096 .25599 L
.20937 .26082 L
.2125 .26394 L
.21491 .26566 L
.21734 .26807 L
.22029 .27049 L
.21835 .27532 L
.22217 .27913 L
.22416 .28015 L
.227 .28297 L
.22964 .28498 L
.23183 .28716 L
Mistroke
.23499 .28981 L
.23342 .29465 L
.23666 .29788 L
.23902 .29948 L
.2415 .30194 L
.24443 .30431 L
.24267 .30914 L
.24633 .31279 L
.24844 .31397 L
.25116 .31667 L
.25391 .31881 L
.2519 .32364 L
.25599 .32773 L
.25792 .32847 L
.26082 .33136 L
.26344 .3333 L
.26566 .3355 L
.26883 .33813 L
.26745 .34296 L
.27049 .34598 L
.27302 .3478 L
.27532 .35007 L
.27843 .35263 L
.27707 .35746 L
.28015 .36052 L
.28266 .36229 L
.28498 .36459 L
.28808 .36712 L
.28677 .37196 L
.28981 .37499 L
.29236 .37679 L
.29027 .38162 L
.29465 .386 L
.29654 .38645 L
.29948 .38937 L
.30211 .39128 L
.3004 .39612 L
.30431 .40002 L
.30637 .40095 L
.30914 .4037 L
.3119 .40578 L
.31046 .41061 L
.31397 .41411 L
.31624 .41544 L
.31881 .41798 L
.32173 .42027 L
.3205 .42511 L
.32364 .42822 L
.32615 .42994 L
.32451 .43477 L
Mistroke
.32847 .43872 L
.33053 .4396 L
.3333 .44235 L
.33609 .44443 L
.33481 .44927 L
.33813 .45265 L
.34039 .4541 L
.33887 .45893 L
.34296 .46302 L
.34487 .46376 L
.3478 .46667 L
.35037 .46859 L
.34931 .47342 L
.35263 .47673 L
.35493 .47826 L
.35367 .48309 L
.35746 .48686 L
.3595 .48792 L
.35759 .49275 L
.36229 .49746 L
.36406 .49758 L
.36712 .50062 L
.3696 .50242 L
.36862 .50725 L
.37196 .51056 L
.37425 .51208 L
.37318 .51691 L
.37679 .52051 L
.37891 .52174 L
.37771 .52658 L
.38162 .53047 L
.3836 .53141 L
.38221 .53624 L
.38645 .54048 L
.3883 .54107 L
.39128 .54403 L
.3938 .5459 L
.39303 .55073 L
.39612 .5538 L
.39856 .55557 L
.39778 .5604 L
.40095 .56354 L
.40333 .56523 L
.40257 .57006 L
.40578 .57325 L
.40813 .57489 L
.40738 .57973 L
.41061 .58293 L
.41294 .58456 L
.41223 .58939 L
Mistroke
.41544 .59258 L
.41778 .59422 L
.4171 .59905 L
.41566 .60388 L
.42027 .6085 L
.422 .60872 L
.42091 .61355 L
.42511 .61773 L
.42692 .61838 L
.42602 .62321 L
.42994 .62711 L
.43184 .62804 L
.4311 .63288 L
.43477 .63653 L
.43678 .63771 L
.43614 .64254 L
.4396 .64597 L
.44172 .64737 L
.44118 .6522 L
.44028 .65704 L
.44443 .66118 L
.44619 .66187 L
.44554 .6667 L
.44927 .67041 L
.45119 .67153 L
.45067 .67636 L
.44978 .68119 L
.4541 .6855 L
.45575 .68603 L
.45518 .69086 L
.45893 .69459 L
.46078 .69569 L
.46035 .70052 L
.45972 .70535 L
.46376 .70938 L
.46544 .71019 L
.46501 .71502 L
.46433 .71985 L
.46859 .7241 L
.47013 .72468 L
.46973 .72951 L
.46909 .73434 L
.47342 .73868 L
.47488 .73918 L
.47452 .74401 L
.474 .74884 L
.47826 .75309 L
.47965 .75367 L
.47936 .7585 L
.47898 .76334 L
Mistroke
.48309 .76745 L
.48442 .76817 L
.48419 .773 L
.48393 .77783 L
.48358 .78266 L
.48792 .78703 L
.48897 .7875 L
.48879 .79233 L
.48859 .79716 L
.48835 .80199 L
.49275 .80646 L
.49346 .80682 L
.49333 .81165 L
.49321 .81649 L
.49309 .82132 L
.49297 .82615 L
.49285 .83098 L
.49449 .83581 L
.49375 .84065 L
.49318 .84548 L
.49275 .85031 L
.49275 .85033 L
.49218 .85514 L
.49168 .85997 L
.49122 .8648 L
.49074 .86964 L
.49019 .87447 L
.4896 .8793 L
.48896 .88413 L
.48864 .88896 L
.48842 .8938 L
.48828 .89863 L
.48825 .90346 L
.48833 .90829 L
.48853 .91312 L
.48887 .91796 L
.48935 .92279 L
.49003 .92762 L
.49098 .93245 L
.49238 .93728 L
.49275 .93829 L
.49445 .94211 L
.49758 .94606 L
.50242 .94606 L
.50556 .94211 L
.50725 .9383 L
.50763 .93728 L
.50902 .93245 L
.50997 .92762 L
.51065 .92279 L
Mistroke
.51114 .91796 L
.51147 .91312 L
.51167 .90829 L
.51175 .90346 L
.51172 .89863 L
.51159 .8938 L
.51136 .88896 L
.51104 .88413 L
.51041 .8793 L
.50981 .87447 L
.50927 .86964 L
.50878 .8648 L
.50832 .85997 L
.50782 .85514 L
.50725 .85031 L
.50725 .8503 L
.50682 .84548 L
.50625 .84065 L
.50552 .83581 L
.50715 .83098 L
.50703 .82615 L
.50691 .82132 L
.50679 .81649 L
.50667 .81165 L
.50654 .80682 L
.50725 .80646 L
.51165 .80199 L
.51141 .79716 L
.51121 .79233 L
.51103 .7875 L
.51208 .78703 L
.51642 .78266 L
.51607 .77783 L
.51581 .773 L
.51558 .76817 L
.51691 .76745 L
.52102 .76334 L
.52064 .7585 L
.52035 .75367 L
.52174 .75309 L
.526 .74884 L
.52548 .74401 L
.52512 .73918 L
.52658 .73868 L
.53091 .73434 L
.53027 .72951 L
.52987 .72468 L
.53141 .7241 L
.53567 .71985 L
.53499 .71502 L
Mistroke
.53456 .71019 L
.53624 .70938 L
.54028 .70535 L
.53965 .70052 L
.53922 .69569 L
.54107 .69459 L
.54482 .69086 L
.54425 .68603 L
.5459 .6855 L
.55022 .68119 L
.54933 .67636 L
.54881 .67153 L
.55073 .67041 L
.55446 .6667 L
.55381 .66187 L
.55557 .66118 L
.55972 .65704 L
.55882 .6522 L
.55828 .64737 L
.5604 .64597 L
.56386 .64254 L
.56322 .63771 L
.56523 .63653 L
.5689 .63288 L
.56816 .62804 L
.57006 .62711 L
.57398 .62321 L
.57308 .61838 L
.57489 .61773 L
.57909 .61355 L
.578 .60872 L
.57973 .6085 L
.58434 .60388 L
.5829 .59905 L
.58222 .59422 L
.58456 .59258 L
.58777 .58939 L
.58706 .58456 L
.58939 .58293 L
.59262 .57973 L
.59187 .57489 L
.59422 .57325 L
.59743 .57006 L
.59667 .56523 L
.59905 .56354 L
.60222 .5604 L
.60144 .55557 L
.60388 .5538 L
.60697 .55073 L
.6062 .5459 L
Mistroke
.60872 .54403 L
.6117 .54107 L
.61355 .54048 L
.61779 .53624 L
.6164 .53141 L
.61838 .53047 L
.62229 .52658 L
.62108 .52174 L
.62321 .52051 L
.62682 .51691 L
.62575 .51208 L
.62804 .51056 L
.63138 .50725 L
.6304 .50242 L
.63288 .50062 L
.63594 .49758 L
.63771 .49746 L
.64241 .49275 L
.6405 .48792 L
.64254 .48686 L
.64633 .48309 L
.64507 .47826 L
.64737 .47673 L
.65069 .47342 L
.64963 .46859 L
.6522 .46667 L
.65513 .46376 L
.65704 .46302 L
.66113 .45893 L
.65961 .4541 L
.66187 .45265 L
.66519 .44927 L
.66391 .44443 L
.6667 .44235 L
.66947 .4396 L
.67153 .43872 L
.67549 .43477 L
.67385 .42994 L
.67636 .42822 L
.6795 .42511 L
.67827 .42027 L
.68119 .41798 L
.68376 .41544 L
.68603 .41411 L
.68954 .41061 L
.6881 .40578 L
.69086 .4037 L
.69363 .40095 L
.69569 .40002 L
.6996 .39612 L
Mistroke
.69789 .39128 L
.70052 .38937 L
.70346 .38645 L
.70535 .386 L
.70973 .38162 L
.70764 .37679 L
.71019 .37499 L
.71323 .37196 L
.71192 .36712 L
.71502 .36459 L
.71734 .36229 L
.71985 .36052 L
.72293 .35746 L
.72157 .35263 L
.72468 .35007 L
.72698 .3478 L
.72951 .34598 L
.73255 .34296 L
.73117 .33813 L
.73434 .3355 L
.73656 .3333 L
.73918 .33136 L
.74208 .32847 L
.74401 .32773 L
.7481 .32364 L
.74609 .31881 L
.74884 .31667 L
.75156 .31397 L
.75367 .31279 L
.75733 .30914 L
.75557 .30431 L
.7585 .30194 L
.76098 .29948 L
.76334 .29788 L
.76658 .29465 L
.76501 .28981 L
.76817 .28716 L
.77036 .28498 L
.773 .28297 L
.77584 .28015 L
.77783 .27913 L
.78165 .27532 L
.77971 .27049 L
.78266 .26807 L
.78509 .26566 L
.7875 .26394 L
.79063 .26082 L
.78904 .25599 L
.79233 .25316 L
.79435 .25116 L
Mistroke
.79716 .24889 L
.79974 .24633 L
.80199 .24481 L
.80532 .2415 L
.80359 .23666 L
.80682 .23389 L
.80889 .23183 L
.81165 .22961 L
.81428 .227 L
.81649 .22552 L
.81985 .22217 L
.81806 .21734 L
.82132 .21452 L
.82335 .2125 L
.82615 .21022 L
.82871 .20767 L
.83098 .20607 L
.83422 .20284 L
.83245 .19801 L
.83581 .19506 L
.83771 .19318 L
.84065 .19071 L
.84302 .18835 L
.84548 .18647 L
.84844 .18351 L
.85031 .18253 L
.85417 .17868 L
.85199 .17385 L
.85514 .17111 L
.85725 .16902 L
.85997 .16678 L
.86258 .16419 L
.8648 .16258 L
.86804 .15935 L
.86964 .15905 L
.87417 .15452 L
.8714 .14969 L
.87447 .14703 L
.87665 .14486 L
.8793 .14269 L
.88197 .14003 L
.88413 .13848 L
.88742 .1352 L
.88896 .13498 L
.89358 .13036 L
.89068 .12553 L
.8938 .1228 L
.8959 .1207 L
.89863 .11841 L
.90118 .11587 L
Mistroke
.90346 .11412 L
.90655 .11104 L
.90829 .11011 L
.9122 .1062 L
.90983 .10137 L
.91312 .09841 L
.91501 .09654 L
.91796 .09397 L
.92022 .09171 L
.92279 .08958 L
.92549 .08688 L
.92762 .08529 L
.93087 .08204 L
.93245 .08137 L
.9366 .07721 L
.93398 .07238 L
.93245 .07113 L
.92793 .07238 L
.92762 .07421 L
.92683 .07721 L
.92279 .07914 L
.9212 .08204 L
.91796 .0849 L
.91663 .08688 L
.91312 .09064 L
.91228 .09171 L
.90829 .09639 L
.90818 .09654 L
.90374 .10137 L
.90346 .10283 L
.90228 .1062 L
.89863 .10815 L
.89694 .11104 L
.8938 .11401 L
.89253 .11587 L
.88896 .11986 L
.88832 .1207 L
.8842 .12553 L
.88413 .12612 L
.88389 .13036 L
.8793 .13174 L
.87748 .1352 L
.87447 .13772 L
.87296 .14003 L
.86964 .14368 L
.86874 .14486 L
.8648 .14964 L
.86477 .14969 L
.86445 .15452 L
.85997 .15574 L
Mistroke
.85803 .15935 L
.85514 .16182 L
.85359 .16419 L
.85031 .16788 L
.84946 .16902 L
.84551 .17385 L
.84548 .17403 L
.844 .17868 L
.84065 .18016 L
.83865 .18351 L
.83581 .18633 L
.83432 .18835 L
.83098 .1925 L
.83048 .19318 L
.82637 .19801 L
.82615 .19873 L
.82395 .20284 L
.82132 .20502 L
.81937 .20767 L
.81649 .21129 L
.8156 .2125 L
.81172 .21734 L
.81165 .21757 L
.80935 .22217 L
.80682 .22396 L
.80491 .227 L
.80199 .23033 L
.80091 .23183 L
.79717 .23666 L
.79716 .23671 L
.7947 .2415 L
.79233 .24319 L
.79008 .24633 L
.7875 .24966 L
.78643 .25116 L
.78271 .25599 L
.78266 .25614 L
.78005 .26082 L
.77783 .26272 L
.77576 .26566 L
.773 .26929 L
.77216 .27049 L
.77098 .27532 L
.76817 .27589 L
.76563 .28015 L
.76334 .28257 L
.76166 .28498 L
.7585 .28923 L
.75811 .28981 L
.75553 .29465 L
Mistroke
.75367 .29598 L
.75126 .29948 L
.74884 .30274 L
.74778 .30431 L
.74608 .30914 L
.74401 .30953 L
.74134 .31397 L
.73918 .3164 L
.73756 .31881 L
.73434 .32327 L
.7341 .32364 L
.73127 .32847 L
.72951 .33022 L
.72745 .3333 L
.72468 .33719 L
.72406 .33813 L
.72127 .34296 L
.71985 .34421 L
.71748 .3478 L
.71502 .35128 L
.71413 .35263 L
.71133 .35746 L
.71019 .35839 L
.70763 .36229 L
.70535 .36555 L
.70434 .36712 L
.70149 .37196 L
.70052 .37276 L
.69791 .37679 L
.69569 .38002 L
.69467 .38162 L
.6918 .38645 L
.69086 .38733 L
.68834 .39128 L
.68603 .3947 L
.68514 .39612 L
.68227 .40095 L
.68119 .40212 L
.6789 .40578 L
.67636 .4096 L
.67574 .41061 L
.67266 .41544 L
.67153 .41714 L
.66959 .42027 L
.6667 .42472 L
.66647 .42511 L
.66347 .42994 L
.66187 .43239 L
.66042 .43477 L
.65757 .4396 L
Mistroke
.65704 .44005 L
.65243 .44443 L
.6522 .44478 L
.64943 .44927 L
.64737 .4525 L
.6464 .4541 L
.64339 .45893 L
.64254 .46027 L
.64042 .46376 L
.63771 .4681 L
.63741 .46859 L
.63448 .47342 L
.63288 .476 L
.63153 .47826 L
.62858 .48309 L
.62804 .48395 L
.62568 .48792 L
.62321 .49197 L
.62275 .49275 L
.61988 .49758 L
.61838 .50005 L
.617 .50242 L
.61412 .50725 L
.61355 .5082 L
.61129 .51208 L
.60872 .5164 L
.60842 .51691 L
.60562 .52174 L
.60388 .52467 L
.60279 .52658 L
.59999 .53141 L
.59905 .533 L
.59721 .53624 L
.59441 .54107 L
.59422 .54139 L
.59166 .5459 L
.58939 .54983 L
.58888 .55073 L
.58615 .55557 L
.58456 .55833 L
.5834 .5604 L
.58067 .56523 L
.57973 .56688 L
.57795 .57006 L
.57522 .57489 L
.57489 .57546 L
.57252 .57973 L
.57006 .58407 L
.56979 .58456 L
.5671 .58939 L
Mistroke
.56523 .5927 L
.56439 .59422 L
.56168 .59905 L
.5604 .60132 L
.55897 .60388 L
.55625 .60872 L
.55557 .60991 L
.55353 .61355 L
.55077 .61838 L
.55073 .61844 L
.54802 .62321 L
.5459 .62686 L
.54523 .62804 L
.54241 .63288 L
.54107 .63511 L
.53954 .63771 L
.5366 .64254 L
.53624 .64311 L
.5336 .64737 L
.53141 .65076 L
.53048 .6522 L
.5272 .65704 L
.52658 .65792 L
.52374 .66187 L
.52174 .66442 L
.51993 .6667 L
.51691 .67004 L
.51554 .67153 L
.51208 .67457 L
.50997 .67636 L
.50725 .67776 L
.50242 .67941 L
.49758 .67941 L
.49275 .67776 L
.49003 .67636 L
.48792 .67457 L
.48446 .67153 L
.48309 .67004 L
.48007 .6667 L
.47826 .66441 L
.47626 .66187 L
.47342 .65792 L
.4728 .65704 L
.46952 .6522 L
.46859 .65076 L
.4664 .64737 L
.46376 .64311 L
.4634 .64254 L
.46046 .63771 L
.45893 .63511 L
Mistroke
.45759 .63288 L
.45477 .62804 L
.4541 .62686 L
.45198 .62321 L
.44927 .61844 L
.44923 .61838 L
.44647 .61355 L
.44443 .60991 L
.44375 .60872 L
.44103 .60388 L
.4396 .60132 L
.43832 .59905 L
.43561 .59422 L
.43477 .5927 L
.4329 .58939 L
.43021 .58456 L
.42994 .58407 L
.42748 .57973 L
.42511 .57546 L
.42479 .57489 L
.42205 .57006 L
.42027 .56687 L
.41933 .56523 L
.4166 .5604 L
.41544 .55833 L
.41385 .55557 L
.41112 .55073 L
.41061 .54983 L
.40834 .5459 L
.40578 .54139 L
.4056 .54107 L
.40279 .53624 L
.40095 .533 L
.40001 .53141 L
.39721 .52658 L
.39612 .52467 L
.39438 .52174 L
.39158 .51691 L
.39128 .5164 L
.38871 .51208 L
.38645 .50819 L
.38588 .50725 L
.383 .50242 L
.38162 .50005 L
.38012 .49758 L
.37725 .49275 L
.37679 .49197 L
.37432 .48792 L
.37196 .48395 L
.37142 .48309 L
Mistroke
.36847 .47826 L
.36712 .476 L
.36552 .47342 L
.36259 .46859 L
.36229 .4681 L
.35958 .46376 L
.35746 .46027 L
.35661 .45893 L
.35361 .4541 L
.35263 .4525 L
.35057 .44927 L
.3478 .44478 L
.34758 .44443 L
.34296 .44005 L
.34244 .4396 L
.33958 .43477 L
.33813 .43239 L
.33653 .42994 L
.33353 .42511 L
.3333 .42472 L
.33041 .42027 L
.32847 .41714 L
.32734 .41544 L
.32427 .41061 L
.32364 .4096 L
.3211 .40578 L
.31881 .40212 L
.31773 .40095 L
.31486 .39612 L
.31397 .3947 L
.31166 .39128 L
.30914 .38733 L
.3082 .38645 L
.30533 .38162 L
.30431 .38002 L
.30209 .37679 L
.29948 .37276 L
.29851 .37196 L
.29566 .36712 L
.29465 .36555 L
.29237 .36229 L
.28981 .35839 L
.28867 .35746 L
.28587 .35263 L
.28498 .35128 L
.28253 .3478 L
.28015 .34421 L
.27873 .34296 L
.27594 .33813 L
.27532 .33719 L
Mistroke
.27255 .3333 L
.27049 .33022 L
.26873 .32847 L
.2659 .32364 L
.26566 .32327 L
.26244 .31881 L
.26082 .3164 L
.25866 .31397 L
.25599 .30953 L
.25392 .30914 L
.25222 .30431 L
.25116 .30274 L
.24874 .29948 L
.24633 .29598 L
.24447 .29465 L
.24189 .28981 L
.2415 .28923 L
.23834 .28498 L
.23666 .28257 L
.23437 .28015 L
.23183 .27589 L
.22902 .27532 L
.22784 .27049 L
.227 .26929 L
.22424 .26566 L
.22217 .26272 L
.21995 .26082 L
.21734 .25614 L
.2173 .25599 L
.21357 .25116 L
.2125 .24966 L
.20992 .24633 L
.20767 .24319 L
.2053 .2415 L
.20284 .2367 L
.20283 .23666 L
.19909 .23183 L
.19801 .23033 L
.19509 .227 L
.19318 .22396 L
.19065 .22217 L
.18835 .21757 L
.18828 .21734 L
.1844 .2125 L
.18351 .21129 L
.18063 .20767 L
.17868 .20502 L
.17605 .20284 L
.17385 .19873 L
.17364 .19801 L
Mistroke
.16952 .19318 L
.16902 .1925 L
.16568 .18835 L
.16419 .18633 L
.16135 .18351 L
.15935 .18015 L
.156 .17868 L
.15452 .17403 L
.15449 .17385 L
.15054 .16902 L
.14969 .16788 L
.14641 .16419 L
.14486 .16182 L
.14197 .15935 L
.14003 .15574 L
.13555 .15452 L
.13523 .14969 L
.1352 .14964 L
.13126 .14486 L
.13036 .14368 L
.12704 .14003 L
.12553 .13772 L
.12252 .1352 L
.1207 .13174 L
.11611 .13036 L
.11587 .12612 L
.11581 .12553 L
.11168 .1207 L
.11104 .11986 L
.10747 .11587 L
.1062 .11401 L
.10306 .11104 L
.10137 .10814 L
.09772 .1062 L
.09654 .10283 L
.09626 .10137 L
.09183 .09654 L
.09171 .09639 L
.08772 .09171 L
.08688 .09064 L
.08337 .08688 L
.08204 .0849 L
.0788 .08204 L
.07721 .07914 L
.07317 .07721 L
.07238 .07421 L
.07207 .07238 L
.06755 .07113 L
.06754 .06755 L
.06334 .06272 L
Mistroke
.06272 .06194 L
.05899 .05789 L
.05789 .05631 L
.05449 .05305 L
.05305 .05068 L
.04947 .04822 L
.04822 .04568 L
.04766 .04339 L
.04339 .04128 L
.04313 .03856 L
.03857 .03373 L
.03856 .03371 L
.03431 .02889 L
.03373 .02819 L
.02989 .02406 L
.02889 .02358 L
.02537 .01923 L
Mfstroke
1 0 0 r
.01923 .02117 m
.02051 .02406 L
.02406 .02655 L
.02677 .02889 L
.02889 .03101 L
.03195 .03373 L
.03373 .0355 L
.0371 .03856 L
.03856 .04001 L
.04224 .04339 L
.03974 .04822 L
.04339 .05187 L
.04524 .05305 L
.04822 .05603 L
.05057 .05789 L
.05305 .06037 L
.05581 .06272 L
.05789 .06478 L
.06102 .06755 L
.06272 .06924 L
.06619 .07238 L
.06343 .07721 L
.06755 .08133 L
.0692 .08204 L
.07238 .08521 L
.07461 .08688 L
.07721 .08947 L
.07991 .09171 L
.08204 .09384 L
.08515 .09654 L
.08688 .09826 L
.09035 .10137 L
.08785 .1062 L
.09171 .11006 L
.09353 .11104 L
.09654 .11403 L
.09894 .11587 L
.10137 .11829 L
.10424 .1207 L
.1062 .12266 L
.10949 .12553 L
.10643 .13036 L
.11104 .13497 L
.11265 .1352 L
.11587 .1384 L
.11814 .14003 L
.1207 .14258 L
.12348 .14486 L
.12553 .14689 L
.12876 .14969 L
.12585 .15452 L
.13036 .15904 L
.13203 .15935 L
.1352 .16251 L
.13753 .16419 L
.14003 .16667 L
.14289 .16902 L
.14486 .17097 L
.14818 .17385 L
.14588 .17868 L
.14969 .18249 L
.15165 .18351 L
.15452 .18638 L
.1571 .18835 L
.15935 .19059 L
.16244 .19318 L
.16419 .19491 L
.16773 .19801 L
.16586 .20284 L
.16902 .20599 L
.17141 .20767 L
.17385 .2101 L
.1768 .2125 L
.17868 .21438 L
.18211 .21734 L
.18022 .22217 L
.18351 .22545 L
.18583 .227 L
.18835 .2295 L
.19125 .23183 L
.19318 .23375 L
.19658 .23666 L
.19476 .2415 L
.19801 .24474 L
.20037 .24633 L
.20284 .24878 L
.2058 .25116 L
.20767 .25302 L
.21114 .25599 L
.20945 .26082 L
.2125 .26386 L
.21503 .26566 L
.21734 .26795 L
.22044 .27049 L
.2184 .27532 L
.22217 .27908 L
.22426 .28015 L
.227 .28287 L
.22977 .28498 L
.23183 .28703 L
.23516 .28981 L
.2335 .29465 L
.23666 .2978 L
.23914 .29948 L
.2415 .30182 L
.24458 .30431 L
.24273 .30914 L
.24633 .31273 L
.24855 .31397 L
.25116 .31657 L
.25405 .31881 L
.25193 .32364 L
.25599 .32769 L
.25801 .32847 L
.26082 .33126 L
.26357 .3333 L
.26566 .33536 L
.26899 .33813 L
.26754 .34296 L
.27049 .34589 L
.27315 .3478 L
.27532 .34994 L
.27859 .35263 L
.27716 .35746 L
.28015 .36044 L
.28279 .36229 L
.28498 .36447 L
.28824 .36712 L
.28685 .37196 L
.28981 .3749 L
.29249 .37679 L
.29029 .38162 L
.29465 .38597 L
.29663 .38645 L
.29948 .38928 L
.30224 .39128 L
.30044 .39612 L
.30431 .39997 L
.30647 .40095 L
.30914 .4036 L
.31204 .40578 L
.31053 .41061 L
.31397 .41404 L
.31636 .41544 L
.31881 .41787 L
.32188 .42027 L
.32059 .42511 L
.32364 .42814 L
.32628 .42994 L
.32455 .43477 L
.32847 .43868 L
.33063 .4396 L
.3333 .44224 L
.33623 .44443 L
.33488 .44927 L
.33813 .45257 L
.34051 .4541 L
.3389 .45893 L
.34296 .46298 L
.34497 .46376 L
.3478 .46657 L
.35051 .46859 L
.34939 .47342 L
.35263 .47664 L
.35506 .47826 L
.35373 .48309 L
.35746 .48681 L
.35961 .48792 L
.3576 .49275 L
.36229 .49745 L
.36416 .49758 L
.36712 .50053 L
.36974 .50242 L
.3687 .50725 L
.37196 .51048 L
.37438 .51208 L
.37324 .51691 L
.37679 .52044 L
.37903 .52174 L
.37776 .52658 L
.38162 .53042 L
.3837 .53141 L
.38224 .53624 L
.38645 .54044 L
.3884 .54107 L
.39128 .54393 L
.39394 .5459 L
.39312 .55073 L
.39612 .5537 L
.39869 .55557 L
.39787 .5604 L
.40095 .56345 L
.40347 .56523 L
.40266 .57006 L
.40578 .57316 L
.40826 .57489 L
.40747 .57973 L
.41061 .58284 L
.41307 .58456 L
.41232 .58939 L
.41544 .59249 L
.41791 .59422 L
.4172 .59905 L
.41567 .60388 L
.42027 .60849 L
.4221 .60872 L
.42095 .61355 L
.42511 .6177 L
.42702 .61838 L
.42608 .62321 L
.42994 .62706 L
.43195 .62804 L
.43116 .63288 L
.43477 .63646 L
.4369 .63771 L
.43622 .64254 L
.4396 .64589 L
.44184 .64737 L
.44127 .6522 L
.44032 .65704 L
.44443 .66114 L
.44629 .66187 L
.4456 .6667 L
.44927 .67034 L
.4513 .67153 L
.45076 .67636 L
.44981 .68119 L
.4541 .68547 L
.45585 .68603 L
.45524 .69086 L
.45893 .69452 L
.46089 .69569 L
.46044 .70052 L
.45977 .70535 L
.46376 .70933 L
.46554 .71019 L
.46508 .71502 L
.46437 .71985 L
.46859 .72407 L
.47023 .72468 L
.4698 .72951 L
.46912 .73434 L
.47342 .73864 L
.47497 .73918 L
.47459 .74401 L
.47404 .74884 L
.47826 .75305 L
.47974 .75367 L
.47943 .7585 L
.47903 .76334 L
.48309 .7674 L
.48452 .76817 L
.48428 .773 L
.48399 .77783 L
.48362 .78266 L
.48792 .78699 L
.48906 .7875 L
.48887 .79233 L
.48865 .79716 L
.4884 .80199 L
.49275 .80641 L
.49354 .80682 L
.49341 .81165 L
.49327 .81649 L
.49314 .82132 L
.49301 .82615 L
.49287 .83098 L
.49499 .83581 L
.49417 .84065 L
.49354 .84548 L
.49306 .85031 L
.49275 .85431 L
.49266 .85514 L
.49216 .85997 L
.49172 .8648 L
.49129 .86964 L
.49083 .87447 L
.49032 .8793 L
.48976 .88413 L
.48947 .88896 L
.48927 .8938 L
.48917 .89863 L
.48918 .90346 L
.48931 .90829 L
.48956 .91312 L
.48997 .91796 L
.49057 .92279 L
.49143 .92762 L
.4927 .93245 L
.49275 .93262 L
.49455 .93728 L
.49758 .94149 L
.50242 .9415 L
.50545 .93728 L
.50725 .93263 L
.50731 .93245 L
.50858 .92762 L
.50943 .92279 L
.51003 .91796 L
.51044 .91312 L
.5107 .90829 L
.51083 .90346 L
.51083 .89863 L
.51074 .8938 L
.51054 .88896 L
.51024 .88413 L
.50968 .8793 L
.50918 .87447 L
.50871 .86964 L
.50828 .8648 L
.50784 .85997 L
.50734 .85514 L
.50725 .85428 L
.50695 .85031 L
.50647 .84548 L
.50584 .84065 L
.50501 .83581 L
.50713 .83098 L
.50699 .82615 L
.50686 .82132 L
.50673 .81649 L
.50659 .81165 L
.50646 .80682 L
.50725 .80641 L
.5116 .80199 L
.51135 .79716 L
.51113 .79233 L
.51094 .7875 L
.51208 .78699 L
.51638 .78266 L
.51601 .77783 L
.51572 .773 L
.51548 .76817 L
.51691 .7674 L
.52097 .76334 L
.52057 .7585 L
.52026 .75367 L
.52174 .75305 L
.52596 .74884 L
.52541 .74401 L
.52503 .73918 L
.52658 .73864 L
.53088 .73434 L
.5302 .72951 L
.52977 .72468 L
.53141 .72407 L
.53563 .71985 L
.53492 .71502 L
.53446 .71019 L
.53624 .70933 L
.54023 .70535 L
.53956 .70052 L
.53911 .69569 L
.54107 .69452 L
.54476 .69086 L
.54415 .68603 L
.5459 .68547 L
.55019 .68119 L
.54924 .67636 L
.5487 .67153 L
.55073 .67034 L
.5544 .6667 L
.55371 .66187 L
.55557 .66114 L
.55968 .65704 L
.55873 .6522 L
.55816 .64737 L
.5604 .64589 L
.56378 .64254 L
.5631 .63771 L
.56523 .63646 L
.56884 .63288 L
.56805 .62804 L
.57006 .62706 L
.57392 .62321 L
.57298 .61838 L
.57489 .6177 L
.57905 .61355 L
.5779 .60872 L
.57973 .60849 L
.58433 .60388 L
.5828 .59905 L
.58209 .59422 L
.58456 .59249 L
.58768 .58939 L
.58693 .58456 L
.58939 .58284 L
.59253 .57973 L
.59174 .57489 L
.59422 .57316 L
.59734 .57006 L
.59653 .56523 L
.59905 .56345 L
.60213 .5604 L
.60131 .55557 L
.60388 .5537 L
.60688 .55073 L
.60606 .5459 L
.60872 .54393 L
.6116 .54107 L
.61355 .54044 L
.61776 .53624 L
.6163 .53141 L
.61838 .53042 L
.62224 .52658 L
.62097 .52174 L
.62321 .52044 L
.62676 .51691 L
.62562 .51208 L
.62804 .51048 L
.6313 .50725 L
.63026 .50242 L
.63288 .50053 L
.63584 .49758 L
.63771 .49745 L
.6424 .49275 L
.64039 .48792 L
.64254 .48681 L
.64627 .48309 L
.64494 .47826 L
.64737 .47664 L
.65061 .47342 L
.64949 .46859 L
.6522 .46657 L
.65503 .46376 L
.65704 .46298 L
.6611 .45893 L
.65949 .4541 L
.66187 .45257 L
.66512 .44927 L
.66377 .44443 L
.6667 .44224 L
.66937 .4396 L
.67153 .43868 L
.67545 .43477 L
.67372 .42994 L
.67636 .42814 L
.67941 .42511 L
.67812 .42027 L
.68119 .41787 L
.68364 .41544 L
.68603 .41404 L
.68947 .41061 L
.68796 .40578 L
.69086 .4036 L
.69353 .40095 L
.69569 .39997 L
.69956 .39612 L
.69776 .39128 L
.70052 .38928 L
.70337 .38645 L
.70535 .38597 L
.70971 .38162 L
.70751 .37679 L
.71019 .3749 L
.71315 .37196 L
.71176 .36712 L
.71502 .36446 L
.71721 .36229 L
.71985 .36044 L
.72284 .35746 L
.72141 .35263 L
.72468 .34994 L
.72685 .3478 L
.72951 .34589 L
.73246 .34296 L
.731 .33813 L
.73434 .33536 L
.73643 .3333 L
.73918 .33126 L
.74199 .32847 L
.74401 .32769 L
.74807 .32364 L
.74595 .31881 L
.74884 .31657 L
.75145 .31397 L
.75367 .31273 L
.75727 .30914 L
.75542 .30431 L
.7585 .30182 L
.76086 .29948 L
.76334 .2978 L
.7665 .29465 L
.76484 .28981 L
.76817 .28703 L
.77023 .28498 L
.773 .28287 L
.77574 .28015 L
.77783 .27908 L
.7816 .27532 L
.77956 .27049 L
.78266 .26795 L
.78497 .26566 L
.7875 .26386 L
.79055 .26082 L
.78886 .25599 L
.79233 .25302 L
.7942 .25116 L
.79716 .24878 L
.79963 .24633 L
.80199 .24474 L
.80524 .2415 L
.80342 .23666 L
.80682 .23375 L
.80875 .23183 L
.81165 .2295 L
.81417 .227 L
.81649 .22545 L
.81978 .22217 L
.81789 .21734 L
.82132 .21438 L
.8232 .2125 L
.82615 .2101 L
.82859 .20767 L
.83098 .20599 L
.83414 .20284 L
.83227 .19801 L
.83098 .19408 L
.82677 .19801 L
.82615 .19994 L
.82465 .20284 L
.82132 .20619 L
.82026 .20767 L
.81649 .21243 L
.81643 .2125 L
.81211 .21734 L
.81165 .21882 L
.81005 .22217 L
.80682 .22518 L
.80569 .227 L
.80199 .23152 L
.80177 .23183 L
.79755 .23666 L
.79716 .23799 L
.79545 .2415 L
.79233 .24445 L
.79102 .24633 L
.7875 .25089 L
.78731 .25116 L
.7831 .25599 L
.78266 .25746 L
.78089 .26082 L
.77783 .26402 L
.77671 .26566 L
.77302 .27049 L
.773 .27056 L
.77149 .27532 L
.76817 .27725 L
.7665 .28015 L
.76334 .28389 L
.7626 .28498 L
.75872 .28981 L
.7585 .2906 L
.75648 .29465 L
.75367 .29736 L
.75225 .29948 L
.74884 .3041 L
.7487 .30431 L
.74693 .30914 L
.74401 .31097 L
.74227 .31397 L
.73918 .31781 L
.73852 .31881 L
.73797 .32364 L
.73434 .32473 L
.73228 .32847 L
.72951 .33168 L
.72846 .3333 L
.72482 .33813 L
.72468 .33866 L
.72239 .34296 L
.71985 .34572 L
.71851 .3478 L
.71506 .35263 L
.71502 .35278 L
.71256 .35746 L
.71019 .35995 L
.70869 .36229 L
.70535 .3671 L
.70534 .36712 L
.70278 .37196 L
.70052 .37436 L
.69899 .37679 L
.69976 .38162 L
.69569 .38162 L
.69308 .38645 L
.69086 .38899 L
.68943 .39128 L
.68881 .39612 L
.68603 .39636 L
.6835 .40095 L
.68119 .40383 L
.68 .40578 L
.67798 .41061 L
.67636 .41133 L
.67383 .41544 L
.67153 .4189 L
.6707 .42027 L
.66821 .42511 L
.6667 .42653 L
.66464 .42994 L
.66187 .43421 L
.66153 .43477 L
.65901 .4396 L
.65704 .44159 L
.65393 .44443 L
.6522 .44712 L
.65091 .44927 L
.64788 .4541 L
.64737 .45489 L
.64493 .45893 L
.64254 .46273 L
.64192 .46376 L
.63899 .46859 L
.63771 .47063 L
.63605 .47342 L
.63308 .47826 L
.63288 .47859 L
.63021 .48309 L
.62804 .48662 L
.62729 .48792 L
.62441 .49275 L
.62321 .49472 L
.62155 .49758 L
.61866 .50242 L
.61838 .50288 L
.61585 .50725 L
.61355 .51111 L
.613 .51208 L
.6102 .51691 L
.60872 .51942 L
.6074 .52174 L
.6046 .52658 L
.60388 .52779 L
.60184 .53141 L
.59905 .53623 L
.59905 .53624 L
.59633 .54107 L
.59422 .54474 L
.59358 .5459 L
.59087 .55073 L
.58939 .55331 L
.58815 .55557 L
.58544 .5604 L
.58456 .56195 L
.58276 .56523 L
.58006 .57006 L
.57973 .57065 L
.57741 .57489 L
.57489 .57941 L
.57472 .57973 L
.57209 .58456 L
.57006 .58821 L
.56943 .58939 L
.56679 .59422 L
.56523 .59704 L
.56415 .59905 L
.56151 .60388 L
.5604 .6059 L
.55888 .60872 L
.55623 .61355 L
.55557 .61474 L
.5536 .61838 L
.55092 .62321 L
.55073 .62355 L
.54828 .62804 L
.5459 .63229 L
.54558 .63288 L
.54289 .63771 L
.54107 .64088 L
.54014 .64254 L
.53736 .64737 L
.53624 .64927 L
.53453 .6522 L
.53159 .65704 L
.53141 .65733 L
.52859 .66187 L
.52658 .66493 L
.52542 .6667 L
.52201 .67153 L
.52174 .67189 L
.51831 .67636 L
.51691 .67797 L
.514 .68119 L
.51208 .68291 L
.50803 .68603 L
.50725 .68641 L
.50242 .68823 L
.49758 .68823 L
.49275 .68641 L
.49197 .68603 L
.48792 .6829 L
.48601 .68119 L
.48309 .67797 L
.48169 .67636 L
.47826 .67189 L
.47799 .67153 L
.47458 .6667 L
.47342 .66493 L
.47141 .66187 L
.46859 .65733 L
.46841 .65704 L
.46547 .6522 L
.46376 .64926 L
.46264 .64737 L
.45986 .64254 L
.45893 .64088 L
.45711 .63771 L
.45442 .63288 L
.4541 .63228 L
.45172 .62804 L
.44927 .62355 L
.44908 .62321 L
.4464 .61838 L
.44443 .61474 L
.44377 .61355 L
.44112 .60872 L
.4396 .6059 L
.43849 .60388 L
.43585 .59905 L
.43477 .59704 L
.43321 .59422 L
.43057 .58939 L
.42994 .58821 L
.42791 .58456 L
.42528 .57973 L
.42511 .57941 L
.42259 .57489 L
.42027 .57065 L
.41994 .57006 L
.41724 .56523 L
.41544 .56195 L
.41456 .5604 L
.41185 .55557 L
.41061 .55331 L
.40913 .55073 L
.40642 .5459 L
.40578 .54474 L
.40367 .54107 L
.40096 .53624 L
.40095 .53622 L
.39816 .53141 L
.39612 .52779 L
.3954 .52658 L
.3926 .52174 L
.39128 .51942 L
.3898 .51691 L
.387 .51208 L
.38645 .51111 L
.38415 .50725 L
.38162 .50288 L
.38134 .50242 L
.37845 .49758 L
.37679 .49472 L
.37559 .49275 L
.37271 .48792 L
.37196 .48662 L
.36979 .48309 L
.36712 .47859 L
.36692 .47826 L
.36395 .47342 L
.36229 .47063 L
.36101 .46859 L
.35808 .46376 L
.35746 .46273 L
.35507 .45893 L
.35263 .45489 L
.35212 .4541 L
.34909 .44927 L
.3478 .44712 L
.34607 .44443 L
.34296 .44159 L
.34099 .4396 L
.33847 .43477 L
.33813 .43421 L
.33536 .42994 L
.3333 .42653 L
.33179 .42511 L
.3293 .42027 L
.32847 .4189 L
.32617 .41544 L
.32364 .41133 L
.32202 .41061 L
.32 .40578 L
.31881 .40383 L
.3165 .40095 L
.31397 .39636 L
.31119 .39612 L
.31057 .39128 L
.30914 .38899 L
.30692 .38645 L
.30431 .38162 L
.30024 .38162 L
.30101 .37679 L
.29948 .37436 L
.29722 .37196 L
.29466 .36712 L
.29465 .3671 L
.29131 .36229 L
.28981 .35995 L
.28744 .35746 L
.28498 .35278 L
.28494 .35263 L
.28149 .3478 L
.28015 .34572 L
.27761 .34296 L
.27532 .33866 L
.27518 .33813 L
.27154 .3333 L
.27049 .33168 L
.26772 .32847 L
.26566 .32473 L
.26203 .32364 L
.26148 .31881 L
.26082 .31781 L
.25773 .31397 L
.25599 .31096 L
.25307 .30914 L
.2513 .30431 L
.25116 .3041 L
.24775 .29948 L
.24633 .29736 L
.24352 .29465 L
.2415 .29059 L
.24128 .28981 L
.2374 .28498 L
.23666 .28389 L
.2335 .28015 L
.23183 .27724 L
.22851 .27532 L
.227 .27056 L
.22698 .27049 L
.22329 .26566 L
.22217 .26402 L
.21911 .26082 L
.21734 .25746 L
.2169 .25599 L
.21269 .25116 L
.2125 .25089 L
.20898 .24633 L
.20767 .24445 L
.20455 .2415 L
.20284 .23799 L
.20245 .23666 L
.19823 .23183 L
.19801 .23152 L
.19431 .227 L
.19318 .22518 L
.18995 .22217 L
.18835 .21882 L
.18789 .21734 L
.18357 .2125 L
.18351 .21243 L
.17974 .20767 L
.17868 .20619 L
.17535 .20284 L
.17385 .19994 L
.17324 .19801 L
.16902 .19408 L
.16889 .19318 L
.16483 .18835 L
.16419 .18745 L
.16064 .18351 L
.15935 .18131 L
.15564 .17868 L
.15452 .17556 L
.15413 .17385 L
.14975 .16902 L
.14969 .16894 L
.1457 .16419 L
.14486 .16291 L
.14134 .15935 L
.14003 .15686 L
.13549 .15452 L
.1352 .15149 L
.13487 .14969 L
.13048 .14486 L
.13036 .1447 L
.12636 .14003 L
.12553 .13877 L
.12193 .1352 L
.1207 .13283 L
.11607 .13036 L
.11587 .12768 L
.11546 .12553 L
.11104 .12522 L
.11099 .1207 L
.1068 .11587 L
.1062 .11501 L
.10246 .11104 L
.10137 .10918 L
.09743 .1062 L
.09654 .10392 L
.09588 .10137 L
.09171 .09972 L
.09144 .09654 L
.08698 .09171 L
.08688 .09158 L
.08274 .08688 L
.08204 .08586 L
.07826 .08204 L
.07721 .08015 L
.073 .07721 L
.07238 .07516 L
.07169 .07238 L
.06755 .07136 L
.06722 .06755 L
.06272 .06276 L
.06268 .06272 L
.05836 .05789 L
.05789 .05722 L
.05394 .05305 L
.05305 .05162 L
.04911 .04822 L
.04822 .0465 L
.04725 .04339 L
.04339 .04184 L
.04278 .03856 L
.03856 .0341 L
.03826 .03373 L
.03373 .02895 L
.03368 .02889 L
.02929 .02406 L
.02889 .02386 L
.02482 .01923 L
.01923 .01923 L
F
0 g
.01923 .02117 m
.02051 .02406 L
.02406 .02655 L
.02677 .02889 L
.02889 .03101 L
.03195 .03373 L
.03373 .0355 L
.0371 .03856 L
.03856 .04001 L
.04224 .04339 L
.03974 .04822 L
.04339 .05187 L
.04524 .05305 L
.04822 .05603 L
.05057 .05789 L
.05305 .06037 L
.05581 .06272 L
.05789 .06478 L
.06102 .06755 L
.06272 .06924 L
.06619 .07238 L
.06343 .07721 L
.06755 .08133 L
.0692 .08204 L
.07238 .08521 L
.07461 .08688 L
.07721 .08947 L
.07991 .09171 L
.08204 .09384 L
.08515 .09654 L
.08688 .09826 L
.09035 .10137 L
.08785 .1062 L
.09171 .11006 L
.09353 .11104 L
.09654 .11403 L
.09894 .11587 L
.10137 .11829 L
.10424 .1207 L
.1062 .12266 L
.10949 .12553 L
.10643 .13036 L
.11104 .13497 L
.11265 .1352 L
.11587 .1384 L
.11814 .14003 L
.1207 .14258 L
.12348 .14486 L
.12553 .14689 L
.12876 .14969 L
Mistroke
.12585 .15452 L
.13036 .15904 L
.13203 .15935 L
.1352 .16251 L
.13753 .16419 L
.14003 .16667 L
.14289 .16902 L
.14486 .17097 L
.14818 .17385 L
.14588 .17868 L
.14969 .18249 L
.15165 .18351 L
.15452 .18638 L
.1571 .18835 L
.15935 .19059 L
.16244 .19318 L
.16419 .19491 L
.16773 .19801 L
.16586 .20284 L
.16902 .20599 L
.17141 .20767 L
.17385 .2101 L
.1768 .2125 L
.17868 .21438 L
.18211 .21734 L
.18022 .22217 L
.18351 .22545 L
.18583 .227 L
.18835 .2295 L
.19125 .23183 L
.19318 .23375 L
.19658 .23666 L
.19476 .2415 L
.19801 .24474 L
.20037 .24633 L
.20284 .24878 L
.2058 .25116 L
.20767 .25302 L
.21114 .25599 L
.20945 .26082 L
.2125 .26386 L
.21503 .26566 L
.21734 .26795 L
.22044 .27049 L
.2184 .27532 L
.22217 .27908 L
.22426 .28015 L
.227 .28287 L
.22977 .28498 L
.23183 .28703 L
Mistroke
.23516 .28981 L
.2335 .29465 L
.23666 .2978 L
.23914 .29948 L
.2415 .30182 L
.24458 .30431 L
.24273 .30914 L
.24633 .31273 L
.24855 .31397 L
.25116 .31657 L
.25405 .31881 L
.25193 .32364 L
.25599 .32769 L
.25801 .32847 L
.26082 .33126 L
.26357 .3333 L
.26566 .33536 L
.26899 .33813 L
.26754 .34296 L
.27049 .34589 L
.27315 .3478 L
.27532 .34994 L
.27859 .35263 L
.27716 .35746 L
.28015 .36044 L
.28279 .36229 L
.28498 .36447 L
.28824 .36712 L
.28685 .37196 L
.28981 .3749 L
.29249 .37679 L
.29029 .38162 L
.29465 .38597 L
.29663 .38645 L
.29948 .38928 L
.30224 .39128 L
.30044 .39612 L
.30431 .39997 L
.30647 .40095 L
.30914 .4036 L
.31204 .40578 L
.31053 .41061 L
.31397 .41404 L
.31636 .41544 L
.31881 .41787 L
.32188 .42027 L
.32059 .42511 L
.32364 .42814 L
.32628 .42994 L
.32455 .43477 L
Mistroke
.32847 .43868 L
.33063 .4396 L
.3333 .44224 L
.33623 .44443 L
.33488 .44927 L
.33813 .45257 L
.34051 .4541 L
.3389 .45893 L
.34296 .46298 L
.34497 .46376 L
.3478 .46657 L
.35051 .46859 L
.34939 .47342 L
.35263 .47664 L
.35506 .47826 L
.35373 .48309 L
.35746 .48681 L
.35961 .48792 L
.3576 .49275 L
.36229 .49745 L
.36416 .49758 L
.36712 .50053 L
.36974 .50242 L
.3687 .50725 L
.37196 .51048 L
.37438 .51208 L
.37324 .51691 L
.37679 .52044 L
.37903 .52174 L
.37776 .52658 L
.38162 .53042 L
.3837 .53141 L
.38224 .53624 L
.38645 .54044 L
.3884 .54107 L
.39128 .54393 L
.39394 .5459 L
.39312 .55073 L
.39612 .5537 L
.39869 .55557 L
.39787 .5604 L
.40095 .56345 L
.40347 .56523 L
.40266 .57006 L
.40578 .57316 L
.40826 .57489 L
.40747 .57973 L
.41061 .58284 L
.41307 .58456 L
.41232 .58939 L
Mistroke
.41544 .59249 L
.41791 .59422 L
.4172 .59905 L
.41567 .60388 L
.42027 .60849 L
.4221 .60872 L
.42095 .61355 L
.42511 .6177 L
.42702 .61838 L
.42608 .62321 L
.42994 .62706 L
.43195 .62804 L
.43116 .63288 L
.43477 .63646 L
.4369 .63771 L
.43622 .64254 L
.4396 .64589 L
.44184 .64737 L
.44127 .6522 L
.44032 .65704 L
.44443 .66114 L
.44629 .66187 L
.4456 .6667 L
.44927 .67034 L
.4513 .67153 L
.45076 .67636 L
.44981 .68119 L
.4541 .68547 L
.45585 .68603 L
.45524 .69086 L
.45893 .69452 L
.46089 .69569 L
.46044 .70052 L
.45977 .70535 L
.46376 .70933 L
.46554 .71019 L
.46508 .71502 L
.46437 .71985 L
.46859 .72407 L
.47023 .72468 L
.4698 .72951 L
.46912 .73434 L
.47342 .73864 L
.47497 .73918 L
.47459 .74401 L
.47404 .74884 L
.47826 .75305 L
.47974 .75367 L
.47943 .7585 L
.47903 .76334 L
Mistroke
.48309 .7674 L
.48452 .76817 L
.48428 .773 L
.48399 .77783 L
.48362 .78266 L
.48792 .78699 L
.48906 .7875 L
.48887 .79233 L
.48865 .79716 L
.4884 .80199 L
.49275 .80641 L
.49354 .80682 L
.49341 .81165 L
.49327 .81649 L
.49314 .82132 L
.49301 .82615 L
.49287 .83098 L
.49499 .83581 L
.49417 .84065 L
.49354 .84548 L
.49306 .85031 L
.49275 .85431 L
.49266 .85514 L
.49216 .85997 L
.49172 .8648 L
.49129 .86964 L
.49083 .87447 L
.49032 .8793 L
.48976 .88413 L
.48947 .88896 L
.48927 .8938 L
.48917 .89863 L
.48918 .90346 L
.48931 .90829 L
.48956 .91312 L
.48997 .91796 L
.49057 .92279 L
.49143 .92762 L
.4927 .93245 L
.49275 .93262 L
.49455 .93728 L
.49758 .94149 L
.50242 .9415 L
.50545 .93728 L
.50725 .93263 L
.50731 .93245 L
.50858 .92762 L
.50943 .92279 L
.51003 .91796 L
.51044 .91312 L
Mistroke
.5107 .90829 L
.51083 .90346 L
.51083 .89863 L
.51074 .8938 L
.51054 .88896 L
.51024 .88413 L
.50968 .8793 L
.50918 .87447 L
.50871 .86964 L
.50828 .8648 L
.50784 .85997 L
.50734 .85514 L
.50725 .85428 L
.50695 .85031 L
.50647 .84548 L
.50584 .84065 L
.50501 .83581 L
.50713 .83098 L
.50699 .82615 L
.50686 .82132 L
.50673 .81649 L
.50659 .81165 L
.50646 .80682 L
.50725 .80641 L
.5116 .80199 L
.51135 .79716 L
.51113 .79233 L
.51094 .7875 L
.51208 .78699 L
.51638 .78266 L
.51601 .77783 L
.51572 .773 L
.51548 .76817 L
.51691 .7674 L
.52097 .76334 L
.52057 .7585 L
.52026 .75367 L
.52174 .75305 L
.52596 .74884 L
.52541 .74401 L
.52503 .73918 L
.52658 .73864 L
.53088 .73434 L
.5302 .72951 L
.52977 .72468 L
.53141 .72407 L
.53563 .71985 L
.53492 .71502 L
.53446 .71019 L
.53624 .70933 L
Mistroke
.54023 .70535 L
.53956 .70052 L
.53911 .69569 L
.54107 .69452 L
.54476 .69086 L
.54415 .68603 L
.5459 .68547 L
.55019 .68119 L
.54924 .67636 L
.5487 .67153 L
.55073 .67034 L
.5544 .6667 L
.55371 .66187 L
.55557 .66114 L
.55968 .65704 L
.55873 .6522 L
.55816 .64737 L
.5604 .64589 L
.56378 .64254 L
.5631 .63771 L
.56523 .63646 L
.56884 .63288 L
.56805 .62804 L
.57006 .62706 L
.57392 .62321 L
.57298 .61838 L
.57489 .6177 L
.57905 .61355 L
.5779 .60872 L
.57973 .60849 L
.58433 .60388 L
.5828 .59905 L
.58209 .59422 L
.58456 .59249 L
.58768 .58939 L
.58693 .58456 L
.58939 .58284 L
.59253 .57973 L
.59174 .57489 L
.59422 .57316 L
.59734 .57006 L
.59653 .56523 L
.59905 .56345 L
.60213 .5604 L
.60131 .55557 L
.60388 .5537 L
.60688 .55073 L
.60606 .5459 L
.60872 .54393 L
.6116 .54107 L
Mistroke
.61355 .54044 L
.61776 .53624 L
.6163 .53141 L
.61838 .53042 L
.62224 .52658 L
.62097 .52174 L
.62321 .52044 L
.62676 .51691 L
.62562 .51208 L
.62804 .51048 L
.6313 .50725 L
.63026 .50242 L
.63288 .50053 L
.63584 .49758 L
.63771 .49745 L
.6424 .49275 L
.64039 .48792 L
.64254 .48681 L
.64627 .48309 L
.64494 .47826 L
.64737 .47664 L
.65061 .47342 L
.64949 .46859 L
.6522 .46657 L
.65503 .46376 L
.65704 .46298 L
.6611 .45893 L
.65949 .4541 L
.66187 .45257 L
.66512 .44927 L
.66377 .44443 L
.6667 .44224 L
.66937 .4396 L
.67153 .43868 L
.67545 .43477 L
.67372 .42994 L
.67636 .42814 L
.67941 .42511 L
.67812 .42027 L
.68119 .41787 L
.68364 .41544 L
.68603 .41404 L
.68947 .41061 L
.68796 .40578 L
.69086 .4036 L
.69353 .40095 L
.69569 .39997 L
.69956 .39612 L
.69776 .39128 L
.70052 .38928 L
Mistroke
.70337 .38645 L
.70535 .38597 L
.70971 .38162 L
.70751 .37679 L
.71019 .3749 L
.71315 .37196 L
.71176 .36712 L
.71502 .36446 L
.71721 .36229 L
.71985 .36044 L
.72284 .35746 L
.72141 .35263 L
.72468 .34994 L
.72685 .3478 L
.72951 .34589 L
.73246 .34296 L
.731 .33813 L
.73434 .33536 L
.73643 .3333 L
.73918 .33126 L
.74199 .32847 L
.74401 .32769 L
.74807 .32364 L
.74595 .31881 L
.74884 .31657 L
.75145 .31397 L
.75367 .31273 L
.75727 .30914 L
.75542 .30431 L
.7585 .30182 L
.76086 .29948 L
.76334 .2978 L
.7665 .29465 L
.76484 .28981 L
.76817 .28703 L
.77023 .28498 L
.773 .28287 L
.77574 .28015 L
.77783 .27908 L
.7816 .27532 L
.77956 .27049 L
.78266 .26795 L
.78497 .26566 L
.7875 .26386 L
.79055 .26082 L
.78886 .25599 L
.79233 .25302 L
.7942 .25116 L
.79716 .24878 L
.79963 .24633 L
Mistroke
.80199 .24474 L
.80524 .2415 L
.80342 .23666 L
.80682 .23375 L
.80875 .23183 L
.81165 .2295 L
.81417 .227 L
.81649 .22545 L
.81978 .22217 L
.81789 .21734 L
.82132 .21438 L
.8232 .2125 L
.82615 .2101 L
.82859 .20767 L
.83098 .20599 L
.83414 .20284 L
.83227 .19801 L
.83098 .19408 L
.82677 .19801 L
.82615 .19994 L
.82465 .20284 L
.82132 .20619 L
.82026 .20767 L
.81649 .21243 L
.81643 .2125 L
.81211 .21734 L
.81165 .21882 L
.81005 .22217 L
.80682 .22518 L
.80569 .227 L
.80199 .23152 L
.80177 .23183 L
.79755 .23666 L
.79716 .23799 L
.79545 .2415 L
.79233 .24445 L
.79102 .24633 L
.7875 .25089 L
.78731 .25116 L
.7831 .25599 L
.78266 .25746 L
.78089 .26082 L
.77783 .26402 L
.77671 .26566 L
.77302 .27049 L
.773 .27056 L
.77149 .27532 L
.76817 .27725 L
.7665 .28015 L
.76334 .28389 L
Mistroke
.7626 .28498 L
.75872 .28981 L
.7585 .2906 L
.75648 .29465 L
.75367 .29736 L
.75225 .29948 L
.74884 .3041 L
.7487 .30431 L
.74693 .30914 L
.74401 .31097 L
.74227 .31397 L
.73918 .31781 L
.73852 .31881 L
.73797 .32364 L
.73434 .32473 L
.73228 .32847 L
.72951 .33168 L
.72846 .3333 L
.72482 .33813 L
.72468 .33866 L
.72239 .34296 L
.71985 .34572 L
.71851 .3478 L
.71506 .35263 L
.71502 .35278 L
.71256 .35746 L
.71019 .35995 L
.70869 .36229 L
.70535 .3671 L
.70534 .36712 L
.70278 .37196 L
.70052 .37436 L
.69899 .37679 L
.69976 .38162 L
.69569 .38162 L
.69308 .38645 L
.69086 .38899 L
.68943 .39128 L
.68881 .39612 L
.68603 .39636 L
.6835 .40095 L
.68119 .40383 L
.68 .40578 L
.67798 .41061 L
.67636 .41133 L
.67383 .41544 L
.67153 .4189 L
.6707 .42027 L
.66821 .42511 L
.6667 .42653 L
Mistroke
.66464 .42994 L
.66187 .43421 L
.66153 .43477 L
.65901 .4396 L
.65704 .44159 L
.65393 .44443 L
.6522 .44712 L
.65091 .44927 L
.64788 .4541 L
.64737 .45489 L
.64493 .45893 L
.64254 .46273 L
.64192 .46376 L
.63899 .46859 L
.63771 .47063 L
.63605 .47342 L
.63308 .47826 L
.63288 .47859 L
.63021 .48309 L
.62804 .48662 L
.62729 .48792 L
.62441 .49275 L
.62321 .49472 L
.62155 .49758 L
.61866 .50242 L
.61838 .50288 L
.61585 .50725 L
.61355 .51111 L
.613 .51208 L
.6102 .51691 L
.60872 .51942 L
.6074 .52174 L
.6046 .52658 L
.60388 .52779 L
.60184 .53141 L
.59905 .53623 L
.59905 .53624 L
.59633 .54107 L
.59422 .54474 L
.59358 .5459 L
.59087 .55073 L
.58939 .55331 L
.58815 .55557 L
.58544 .5604 L
.58456 .56195 L
.58276 .56523 L
.58006 .57006 L
.57973 .57065 L
.57741 .57489 L
.57489 .57941 L
Mistroke
.57472 .57973 L
.57209 .58456 L
.57006 .58821 L
.56943 .58939 L
.56679 .59422 L
.56523 .59704 L
.56415 .59905 L
.56151 .60388 L
.5604 .6059 L
.55888 .60872 L
.55623 .61355 L
.55557 .61474 L
.5536 .61838 L
.55092 .62321 L
.55073 .62355 L
.54828 .62804 L
.5459 .63229 L
.54558 .63288 L
.54289 .63771 L
.54107 .64088 L
.54014 .64254 L
.53736 .64737 L
.53624 .64927 L
.53453 .6522 L
.53159 .65704 L
.53141 .65733 L
.52859 .66187 L
.52658 .66493 L
.52542 .6667 L
.52201 .67153 L
.52174 .67189 L
.51831 .67636 L
.51691 .67797 L
.514 .68119 L
.51208 .68291 L
.50803 .68603 L
.50725 .68641 L
.50242 .68823 L
.49758 .68823 L
.49275 .68641 L
.49197 .68603 L
.48792 .6829 L
.48601 .68119 L
.48309 .67797 L
.48169 .67636 L
.47826 .67189 L
.47799 .67153 L
.47458 .6667 L
.47342 .66493 L
.47141 .66187 L
Mistroke
.46859 .65733 L
.46841 .65704 L
.46547 .6522 L
.46376 .64926 L
.46264 .64737 L
.45986 .64254 L
.45893 .64088 L
.45711 .63771 L
.45442 .63288 L
.4541 .63228 L
.45172 .62804 L
.44927 .62355 L
.44908 .62321 L
.4464 .61838 L
.44443 .61474 L
.44377 .61355 L
.44112 .60872 L
.4396 .6059 L
.43849 .60388 L
.43585 .59905 L
.43477 .59704 L
.43321 .59422 L
.43057 .58939 L
.42994 .58821 L
.42791 .58456 L
.42528 .57973 L
.42511 .57941 L
.42259 .57489 L
.42027 .57065 L
.41994 .57006 L
.41724 .56523 L
.41544 .56195 L
.41456 .5604 L
.41185 .55557 L
.41061 .55331 L
.40913 .55073 L
.40642 .5459 L
.40578 .54474 L
.40367 .54107 L
.40096 .53624 L
.40095 .53622 L
.39816 .53141 L
.39612 .52779 L
.3954 .52658 L
.3926 .52174 L
.39128 .51942 L
.3898 .51691 L
.387 .51208 L
.38645 .51111 L
.38415 .50725 L
Mistroke
.38162 .50288 L
.38134 .50242 L
.37845 .49758 L
.37679 .49472 L
.37559 .49275 L
.37271 .48792 L
.37196 .48662 L
.36979 .48309 L
.36712 .47859 L
.36692 .47826 L
.36395 .47342 L
.36229 .47063 L
.36101 .46859 L
.35808 .46376 L
.35746 .46273 L
.35507 .45893 L
.35263 .45489 L
.35212 .4541 L
.34909 .44927 L
.3478 .44712 L
.34607 .44443 L
.34296 .44159 L
.34099 .4396 L
.33847 .43477 L
.33813 .43421 L
.33536 .42994 L
.3333 .42653 L
.33179 .42511 L
.3293 .42027 L
.32847 .4189 L
.32617 .41544 L
.32364 .41133 L
.32202 .41061 L
.32 .40578 L
.31881 .40383 L
.3165 .40095 L
.31397 .39636 L
.31119 .39612 L
.31057 .39128 L
.30914 .38899 L
.30692 .38645 L
.30431 .38162 L
.30024 .38162 L
.30101 .37679 L
.29948 .37436 L
.29722 .37196 L
.29466 .36712 L
.29465 .3671 L
.29131 .36229 L
.28981 .35995 L
Mistroke
.28744 .35746 L
.28498 .35278 L
.28494 .35263 L
.28149 .3478 L
.28015 .34572 L
.27761 .34296 L
.27532 .33866 L
.27518 .33813 L
.27154 .3333 L
.27049 .33168 L
.26772 .32847 L
.26566 .32473 L
.26203 .32364 L
.26148 .31881 L
.26082 .31781 L
.25773 .31397 L
.25599 .31096 L
.25307 .30914 L
.2513 .30431 L
.25116 .3041 L
.24775 .29948 L
.24633 .29736 L
.24352 .29465 L
.2415 .29059 L
.24128 .28981 L
.2374 .28498 L
.23666 .28389 L
.2335 .28015 L
.23183 .27724 L
.22851 .27532 L
.227 .27056 L
.22698 .27049 L
.22329 .26566 L
.22217 .26402 L
.21911 .26082 L
.21734 .25746 L
.2169 .25599 L
.21269 .25116 L
.2125 .25089 L
.20898 .24633 L
.20767 .24445 L
.20455 .2415 L
.20284 .23799 L
.20245 .23666 L
.19823 .23183 L
.19801 .23152 L
.19431 .227 L
.19318 .22518 L
.18995 .22217 L
.18835 .21882 L
Mistroke
.18789 .21734 L
.18357 .2125 L
.18351 .21243 L
.17974 .20767 L
.17868 .20619 L
.17535 .20284 L
.17385 .19994 L
.17324 .19801 L
.16902 .19408 L
.16889 .19318 L
.16483 .18835 L
.16419 .18745 L
.16064 .18351 L
.15935 .18131 L
.15564 .17868 L
.15452 .17556 L
.15413 .17385 L
.14975 .16902 L
.14969 .16894 L
.1457 .16419 L
.14486 .16291 L
.14134 .15935 L
.14003 .15686 L
.13549 .15452 L
.1352 .15149 L
.13487 .14969 L
.13048 .14486 L
.13036 .1447 L
.12636 .14003 L
.12553 .13877 L
.12193 .1352 L
.1207 .13283 L
.11607 .13036 L
.11587 .12768 L
.11546 .12553 L
.11104 .12522 L
.11099 .1207 L
.1068 .11587 L
.1062 .11501 L
.10246 .11104 L
.10137 .10918 L
.09743 .1062 L
.09654 .10392 L
.09588 .10137 L
.09171 .09972 L
.09144 .09654 L
.08698 .09171 L
.08688 .09158 L
.08274 .08688 L
.08204 .08586 L
Mistroke
.07826 .08204 L
.07721 .08015 L
.073 .07721 L
.07238 .07516 L
.07169 .07238 L
.06755 .07136 L
.06722 .06755 L
.06272 .06276 L
.06268 .06272 L
.05836 .05789 L
.05789 .05722 L
.05394 .05305 L
.05305 .05162 L
.04911 .04822 L
.04822 .0465 L
.04725 .04339 L
.04339 .04184 L
.04278 .03856 L
.03856 .0341 L
.03826 .03373 L
.03373 .02895 L
.03368 .02889 L
.02929 .02406 L
.02889 .02386 L
.02482 .01923 L
Mfstroke
.282 .64 0 r
.01923 .02187 m
.02 .02406 L
.02406 .02733 L
.02587 .02889 L
.02889 .03192 L
.03091 .03373 L
.03373 .03653 L
.03594 .03856 L
.03856 .04116 L
.04096 .04339 L
.03934 .04822 L
.04339 .05227 L
.04463 .05305 L
.04822 .05664 L
.04979 .05789 L
.05305 .06115 L
.05489 .06272 L
.05789 .06571 L
.05995 .06755 L
.06272 .0703 L
.065 .07238 L
.06319 .07721 L
.06755 .08157 L
.06866 .08204 L
.07238 .08577 L
.07387 .08688 L
.07721 .09021 L
.079 .09171 L
.08204 .09474 L
.0841 .09654 L
.08688 .09931 L
.08916 .10137 L
.08752 .1062 L
.09171 .11039 L
.09293 .11104 L
.09654 .11464 L
.09814 .11587 L
.10137 .11909 L
.10327 .1207 L
.1062 .12362 L
.10837 .12553 L
.10635 .13036 L
.11104 .13505 L
.11212 .1352 L
.11587 .13894 L
.11738 .14003 L
.1207 .14333 L
.12255 .14486 L
.12553 .14783 L
.12766 .14969 L
.12574 .15452 L
.13036 .15915 L
.13148 .15935 L
.1352 .16306 L
.13676 .16419 L
.14003 .16745 L
.14193 .16902 L
.14486 .17194 L
.14705 .17385 L
.14554 .17868 L
.14969 .18283 L
.151 .18351 L
.15452 .18703 L
.15624 .18835 L
.15935 .19145 L
.1614 .19318 L
.16419 .19595 L
.16651 .19801 L
.16531 .20284 L
.16902 .20655 L
.17061 .20767 L
.17385 .2109 L
.1758 .2125 L
.17868 .21537 L
.18094 .21734 L
.17971 .22217 L
.18351 .22596 L
.18506 .227 L
.18835 .23027 L
.19027 .23183 L
.19318 .23473 L
.19542 .23666 L
.19423 .2415 L
.19801 .24526 L
.19959 .24633 L
.20284 .24957 L
.2048 .25116 L
.20767 .25402 L
.20995 .25599 L
.20886 .26082 L
.2125 .26445 L
.21419 .26566 L
.21734 .26879 L
.21939 .27049 L
.21804 .27532 L
.22217 .27944 L
.22357 .28015 L
.227 .28357 L
.22884 .28498 L
.23183 .28796 L
.23403 .28981 L
.23295 .29465 L
.23666 .29835 L
.23831 .29948 L
.2415 .30265 L
.24354 .30431 L
.24232 .30914 L
.24633 .31314 L
.24781 .31397 L
.25116 .31731 L
.25308 .31881 L
.25167 .32364 L
.25599 .32795 L
.25734 .32847 L
.26082 .33194 L
.26265 .3333 L
.26566 .33629 L
.26786 .33813 L
.26692 .34296 L
.27049 .34652 L
.27226 .3478 L
.27532 .35084 L
.27748 .35263 L
.27655 .35746 L
.28015 .36105 L
.28191 .36229 L
.28498 .36535 L
.28714 .36712 L
.28623 .37196 L
.28981 .37552 L
.29159 .37679 L
.29013 .38162 L
.29465 .38614 L
.29597 .38645 L
.29948 .38994 L
.30132 .39128 L
.30012 .39612 L
.30431 .4003 L
.30575 .40095 L
.30914 .40432 L
.31107 .40578 L
.31007 .41061 L
.31397 .41451 L
.31556 .41544 L
.31881 .41867 L
.32085 .42027 L
.32 .42511 L
.32364 .42873 L
.3254 .42994 L
.32425 .43477 L
.32847 .43899 L
.32992 .4396 L
.3333 .44297 L
.33525 .44443 L
.33436 .44927 L
.33813 .45311 L
.33966 .4541 L
.33863 .45893 L
.34296 .46326 L
.34426 .46376 L
.3478 .46729 L
.34954 .46859 L
.34882 .47342 L
.35263 .47722 L
.35419 .47826 L
.35333 .48309 L
.35746 .48721 L
.35884 .48792 L
.35754 .49275 L
.36229 .4975 L
.36349 .49758 L
.36712 .5012 L
.3688 .50242 L
.36814 .50725 L
.37196 .51105 L
.3735 .51208 L
.37278 .51691 L
.37679 .52091 L
.37822 .52174 L
.37741 .52658 L
.38162 .53078 L
.38295 .53141 L
.38201 .53624 L
.38645 .54068 L
.38769 .54107 L
.39128 .54464 L
.39297 .5459 L
.39245 .55073 L
.39612 .55438 L
.39775 .55557 L
.39723 .5604 L
.40095 .5641 L
.40254 .56523 L
.40203 .57006 L
.40578 .57379 L
.40735 .57489 L
.40685 .57973 L
.41061 .58347 L
.41217 .58456 L
.41169 .58939 L
.41544 .59313 L
.417 .59422 L
.41655 .59905 L
.41558 .60388 L
.42027 .60858 L
.42142 .60872 L
.42069 .61355 L
.42511 .61796 L
.4263 .61838 L
.42571 .62321 L
.42994 .62743 L
.4312 .62804 L
.4307 .63288 L
.43477 .63694 L
.43609 .63771 L
.43567 .64254 L
.4396 .64646 L
.44099 .64737 L
.44063 .6522 L
.44004 .65704 L
.44443 .66142 L
.44558 .66187 L
.44515 .6667 L
.44927 .67081 L
.45051 .67153 L
.45017 .67636 L
.44959 .68119 L
.4541 .6857 L
.45516 .68603 L
.45479 .69086 L
.45893 .69499 L
.46011 .69569 L
.45983 .70052 L
.45942 .70535 L
.46376 .70969 L
.46481 .71019 L
.46454 .71502 L
.46411 .71985 L
.46859 .72433 L
.46955 .72468 L
.46929 .72951 L
.46889 .73434 L
.47342 .73888 L
.4743 .73918 L
.47408 .74401 L
.47376 .74884 L
.47826 .75334 L
.47907 .75367 L
.47889 .7585 L
.47867 .76334 L
.48309 .76778 L
.48382 .76817 L
.48369 .773 L
.48354 .77783 L
.48334 .78266 L
.48792 .78728 L
.48842 .7875 L
.48832 .79233 L
.48822 .79716 L
.4881 .80199 L
.49275 .80673 L
.49293 .80682 L
.49286 .81165 L
.4928 .81649 L
.49275 .82084 L
.49274 .82132 L
.49266 .82615 L
.49265 .83098 L
.4895 .83581 L
.48848 .84065 L
.48792 .84334 L
.48752 .84548 L
.48664 .85031 L
.48579 .85514 L
.48497 .85997 L
.48419 .8648 L
.48344 .86964 L
.48309 .87207 L
.48277 .87447 L
.48216 .8793 L
.4816 .88413 L
.48108 .88896 L
.48062 .8938 L
.48022 .89863 L
.47989 .90346 L
.47962 .90829 L
.47942 .91312 L
.47929 .91796 L
.47925 .92279 L
.47929 .92762 L
.47942 .93245 L
.47965 .93728 L
.48 .94211 L
.48047 .94695 L
.48107 .95178 L
.48184 .95661 L
.48279 .96144 L
.48309 .96274 L
.48397 .96627 L
.48544 .97111 L
.48735 .97594 L
.48792 .97714 L
.48971 .98077 L
.01923 .98077 L
F
0 g
.01923 .02187 m
.02 .02406 L
.02406 .02733 L
.02587 .02889 L
.02889 .03192 L
.03091 .03373 L
.03373 .03653 L
.03594 .03856 L
.03856 .04116 L
.04096 .04339 L
.03934 .04822 L
.04339 .05227 L
.04463 .05305 L
.04822 .05664 L
.04979 .05789 L
.05305 .06115 L
.05489 .06272 L
.05789 .06571 L
.05995 .06755 L
.06272 .0703 L
.065 .07238 L
.06319 .07721 L
.06755 .08157 L
.06866 .08204 L
.07238 .08577 L
.07387 .08688 L
.07721 .09021 L
.079 .09171 L
.08204 .09474 L
.0841 .09654 L
.08688 .09931 L
.08916 .10137 L
.08752 .1062 L
.09171 .11039 L
.09293 .11104 L
.09654 .11464 L
.09814 .11587 L
.10137 .11909 L
.10327 .1207 L
.1062 .12362 L
.10837 .12553 L
.10635 .13036 L
.11104 .13505 L
.11212 .1352 L
.11587 .13894 L
.11738 .14003 L
.1207 .14333 L
.12255 .14486 L
.12553 .14783 L
.12766 .14969 L
Mistroke
.12574 .15452 L
.13036 .15915 L
.13148 .15935 L
.1352 .16306 L
.13676 .16419 L
.14003 .16745 L
.14193 .16902 L
.14486 .17194 L
.14705 .17385 L
.14554 .17868 L
.14969 .18283 L
.151 .18351 L
.15452 .18703 L
.15624 .18835 L
.15935 .19145 L
.1614 .19318 L
.16419 .19595 L
.16651 .19801 L
.16531 .20284 L
.16902 .20655 L
.17061 .20767 L
.17385 .2109 L
.1758 .2125 L
.17868 .21537 L
.18094 .21734 L
.17971 .22217 L
.18351 .22596 L
.18506 .227 L
.18835 .23027 L
.19027 .23183 L
.19318 .23473 L
.19542 .23666 L
.19423 .2415 L
.19801 .24526 L
.19959 .24633 L
.20284 .24957 L
.2048 .25116 L
.20767 .25402 L
.20995 .25599 L
.20886 .26082 L
.2125 .26445 L
.21419 .26566 L
.21734 .26879 L
.21939 .27049 L
.21804 .27532 L
.22217 .27944 L
.22357 .28015 L
.227 .28357 L
.22884 .28498 L
.23183 .28796 L
Mistroke
.23403 .28981 L
.23295 .29465 L
.23666 .29835 L
.23831 .29948 L
.2415 .30265 L
.24354 .30431 L
.24232 .30914 L
.24633 .31314 L
.24781 .31397 L
.25116 .31731 L
.25308 .31881 L
.25167 .32364 L
.25599 .32795 L
.25734 .32847 L
.26082 .33194 L
.26265 .3333 L
.26566 .33629 L
.26786 .33813 L
.26692 .34296 L
.27049 .34652 L
.27226 .3478 L
.27532 .35084 L
.27748 .35263 L
.27655 .35746 L
.28015 .36105 L
.28191 .36229 L
.28498 .36535 L
.28714 .36712 L
.28623 .37196 L
.28981 .37552 L
.29159 .37679 L
.29013 .38162 L
.29465 .38614 L
.29597 .38645 L
.29948 .38994 L
.30132 .39128 L
.30012 .39612 L
.30431 .4003 L
.30575 .40095 L
.30914 .40432 L
.31107 .40578 L
.31007 .41061 L
.31397 .41451 L
.31556 .41544 L
.31881 .41867 L
.32085 .42027 L
.32 .42511 L
.32364 .42873 L
.3254 .42994 L
.32425 .43477 L
Mistroke
.32847 .43899 L
.32992 .4396 L
.3333 .44297 L
.33525 .44443 L
.33436 .44927 L
.33813 .45311 L
.33966 .4541 L
.33863 .45893 L
.34296 .46326 L
.34426 .46376 L
.3478 .46729 L
.34954 .46859 L
.34882 .47342 L
.35263 .47722 L
.35419 .47826 L
.35333 .48309 L
.35746 .48721 L
.35884 .48792 L
.35754 .49275 L
.36229 .4975 L
.36349 .49758 L
.36712 .5012 L
.3688 .50242 L
.36814 .50725 L
.37196 .51105 L
.3735 .51208 L
.37278 .51691 L
.37679 .52091 L
.37822 .52174 L
.37741 .52658 L
.38162 .53078 L
.38295 .53141 L
.38201 .53624 L
.38645 .54068 L
.38769 .54107 L
.39128 .54464 L
.39297 .5459 L
.39245 .55073 L
.39612 .55438 L
.39775 .55557 L
.39723 .5604 L
.40095 .5641 L
.40254 .56523 L
.40203 .57006 L
.40578 .57379 L
.40735 .57489 L
.40685 .57973 L
.41061 .58347 L
.41217 .58456 L
.41169 .58939 L
Mistroke
.41544 .59313 L
.417 .59422 L
.41655 .59905 L
.41558 .60388 L
.42027 .60858 L
.42142 .60872 L
.42069 .61355 L
.42511 .61796 L
.4263 .61838 L
.42571 .62321 L
.42994 .62743 L
.4312 .62804 L
.4307 .63288 L
.43477 .63694 L
.43609 .63771 L
.43567 .64254 L
.4396 .64646 L
.44099 .64737 L
.44063 .6522 L
.44004 .65704 L
.44443 .66142 L
.44558 .66187 L
.44515 .6667 L
.44927 .67081 L
.45051 .67153 L
.45017 .67636 L
.44959 .68119 L
.4541 .6857 L
.45516 .68603 L
.45479 .69086 L
.45893 .69499 L
.46011 .69569 L
.45983 .70052 L
.45942 .70535 L
.46376 .70969 L
.46481 .71019 L
.46454 .71502 L
.46411 .71985 L
.46859 .72433 L
.46955 .72468 L
.46929 .72951 L
.46889 .73434 L
.47342 .73888 L
.4743 .73918 L
.47408 .74401 L
.47376 .74884 L
.47826 .75334 L
.47907 .75367 L
.47889 .7585 L
.47867 .76334 L
Mistroke
.48309 .76778 L
.48382 .76817 L
.48369 .773 L
.48354 .77783 L
.48334 .78266 L
.48792 .78728 L
.48842 .7875 L
.48832 .79233 L
.48822 .79716 L
.4881 .80199 L
.49275 .80673 L
.49293 .80682 L
.49286 .81165 L
.4928 .81649 L
.49275 .82084 L
.49274 .82132 L
.49266 .82615 L
.49265 .83098 L
.4895 .83581 L
.48848 .84065 L
.48792 .84334 L
.48752 .84548 L
.48664 .85031 L
.48579 .85514 L
.48497 .85997 L
.48419 .8648 L
.48344 .86964 L
.48309 .87207 L
.48277 .87447 L
.48216 .8793 L
.4816 .88413 L
.48108 .88896 L
.48062 .8938 L
.48022 .89863 L
.47989 .90346 L
.47962 .90829 L
.47942 .91312 L
.47929 .91796 L
.47925 .92279 L
.47929 .92762 L
.47942 .93245 L
.47965 .93728 L
.48 .94211 L
.48047 .94695 L
.48107 .95178 L
.48184 .95661 L
.48279 .96144 L
.48309 .96274 L
.48397 .96627 L
.48544 .97111 L
Mistroke
.48735 .97594 L
.48792 .97714 L
.48971 .98077 L
Mfstroke
.146 .595 0 r
.01923 .02199 m
.01993 .02406 L
.02406 .02744 L
.02574 .02889 L
.02889 .03205 L
.03077 .03373 L
.03373 .03668 L
.03578 .03856 L
.03856 .04133 L
.04079 .04339 L
.03929 .04822 L
.04339 .05232 L
.04454 .05305 L
.04822 .05673 L
.04967 .05789 L
.05305 .06126 L
.05475 .06272 L
.05789 .06584 L
.05981 .06755 L
.06272 .07045 L
.06483 .07238 L
.06315 .07721 L
.06755 .08161 L
.06858 .08204 L
.07238 .08585 L
.07376 .08688 L
.07721 .09032 L
.07888 .09171 L
.08204 .09487 L
.08395 .09654 L
.08688 .09946 L
.08899 .10137 L
.08747 .1062 L
.09171 .11044 L
.09284 .11104 L
.09654 .11473 L
.09802 .11587 L
.10137 .11921 L
.10314 .1207 L
.1062 .12376 L
.10821 .12553 L
.10634 .13036 L
.11104 .13506 L
.11204 .1352 L
.11587 .13902 L
.11727 .14003 L
.1207 .14344 L
.12242 .14486 L
.12553 .14796 L
.12751 .14969 L
.12572 .15452 L
.13036 .15916 L
.1314 .15935 L
.1352 .16314 L
.13664 .16419 L
.14003 .16756 L
.14179 .16902 L
.14486 .17208 L
.14689 .17385 L
.14549 .17868 L
.14969 .18288 L
.15091 .18351 L
.15452 .18712 L
.15612 .18835 L
.15935 .19157 L
.16125 .19318 L
.16419 .1961 L
.16634 .19801 L
.16523 .20284 L
.16902 .20663 L
.1705 .20767 L
.17385 .21101 L
.17566 .2125 L
.17868 .21551 L
.18077 .21734 L
.17964 .22217 L
.18351 .22604 L
.18495 .227 L
.18835 .23039 L
.19013 .23183 L
.19318 .23486 L
.19526 .23666 L
.19416 .2415 L
.19801 .24534 L
.19947 .24633 L
.20284 .24968 L
.20466 .25116 L
.20767 .25416 L
.20979 .25599 L
.20878 .26082 L
.2125 .26454 L
.21407 .26566 L
.21734 .26891 L
.21924 .27049 L
.21799 .27532 L
.22217 .27949 L
.22347 .28015 L
.227 .28367 L
.22871 .28498 L
.23183 .28809 L
.23387 .28981 L
.23287 .29465 L
.23666 .29843 L
.2382 .29948 L
.2415 .30277 L
.24339 .30431 L
.24226 .30914 L
.24633 .3132 L
.2477 .31397 L
.25116 .31742 L
.25294 .31881 L
.25163 .32364 L
.25599 .32799 L
.25724 .32847 L
.26082 .33204 L
.26252 .3333 L
.26566 .33642 L
.2677 .33813 L
.26683 .34296 L
.27049 .34661 L
.27213 .3478 L
.27532 .35097 L
.27733 .35263 L
.27646 .35746 L
.28015 .36114 L
.28178 .36229 L
.28498 .36548 L
.28698 .36712 L
.28614 .37196 L
.28981 .37561 L
.29147 .37679 L
.2901 .38162 L
.29465 .38616 L
.29588 .38645 L
.29948 .39004 L
.30118 .39128 L
.30007 .39612 L
.30431 .40035 L
.30565 .40095 L
.30914 .40442 L
.31093 .40578 L
.31 .41061 L
.31397 .41457 L
.31545 .41544 L
.31881 .41878 L
.3207 .42027 L
.31991 .42511 L
.32364 .42882 L
.32527 .42994 L
.3242 .43477 L
.32847 .43903 L
.32981 .4396 L
.3333 .44307 L
.33511 .44443 L
.33428 .44927 L
.33813 .45319 L
.33954 .4541 L
.33858 .45893 L
.34296 .46331 L
.34415 .46376 L
.3478 .46739 L
.3494 .46859 L
.34874 .47342 L
.35263 .4773 L
.35406 .47826 L
.35327 .48309 L
.35746 .48727 L
.35873 .48792 L
.35754 .49275 L
.36229 .49751 L
.36339 .49758 L
.36712 .5013 L
.36866 .50242 L
.36805 .50725 L
.37196 .51114 L
.37338 .51208 L
.37271 .51691 L
.37679 .52098 L
.3781 .52174 L
.37736 .52658 L
.38162 .53083 L
.38284 .53141 L
.38198 .53624 L
.38645 .54071 L
.38759 .54107 L
.39128 .54475 L
.39283 .5459 L
.39236 .55073 L
.39612 .55448 L
.39762 .55557 L
.39714 .5604 L
.40095 .56419 L
.40241 .56523 L
.40194 .57006 L
.40578 .57389 L
.40722 .57489 L
.40676 .57973 L
.41061 .58356 L
.41203 .58456 L
.4116 .58939 L
.41544 .59322 L
.41686 .59422 L
.41645 .59905 L
.41557 .60388 L
.42027 .60859 L
.42132 .60872 L
.42065 .61355 L
.42511 .618 L
.4262 .61838 L
.42565 .62321 L
.42994 .62749 L
.43108 .62804 L
.43063 .63288 L
.43477 .63701 L
.43597 .63771 L
.43559 .64254 L
.4396 .64654 L
.44087 .64737 L
.44054 .6522 L
.44 .65704 L
.44443 .66147 L
.44547 .66187 L
.44508 .6667 L
.44927 .67087 L
.4504 .67153 L
.45009 .67636 L
.44956 .68119 L
.4541 .68573 L
.45506 .68603 L
.45472 .69086 L
.45893 .69506 L
.46 .69569 L
.45974 .70052 L
.45937 .70535 L
.46376 .70974 L
.46471 .71019 L
.46446 .71502 L
.46407 .71985 L
.46859 .72437 L
.46944 .72468 L
.46921 .72951 L
.46886 .73434 L
.47342 .73892 L
.4742 .73918 L
.474 .74401 L
.47372 .74884 L
.47826 .75338 L
.47897 .75367 L
.47881 .7585 L
.47861 .76334 L
.48309 .76783 L
.48372 .76817 L
.4836 .773 L
.48347 .77783 L
.4833 .78266 L
.48792 .78732 L
.48833 .7875 L
.48824 .79233 L
.48815 .79716 L
.48806 .80199 L
.49275 .80678 L
.49284 .80682 L
.49278 .81165 L
.49275 .81404 L
.49269 .81649 L
.49259 .82132 L
.49254 .82615 L
.49259 .83098 L
.48792 .83484 L
.48772 .83581 L
.48673 .84065 L
.48576 .84548 L
.48482 .85031 L
.48391 .85514 L
.48309 .85972 L
.48305 .85997 L
.48226 .8648 L
.4815 .86964 L
.48079 .87447 L
.48013 .8793 L
.47951 .88413 L
.47894 .88896 L
.47842 .8938 L
.47826 .89545 L
.47797 .89863 L
.47758 .90346 L
.47725 .90829 L
.47698 .91312 L
.47678 .91796 L
.47666 .92279 L
.4766 .92762 L
.47663 .93245 L
.47675 .93728 L
.47696 .94211 L
.47727 .94695 L
.47769 .95178 L
.47824 .95661 L
.47826 .95671 L
.47894 .96144 L
.47979 .96627 L
.48083 .97111 L
.48211 .97594 L
.48309 .97905 L
.48367 .98077 L
.01923 .98077 L
F
0 g
.01923 .02199 m
.01993 .02406 L
.02406 .02744 L
.02574 .02889 L
.02889 .03205 L
.03077 .03373 L
.03373 .03668 L
.03578 .03856 L
.03856 .04133 L
.04079 .04339 L
.03929 .04822 L
.04339 .05232 L
.04454 .05305 L
.04822 .05673 L
.04967 .05789 L
.05305 .06126 L
.05475 .06272 L
.05789 .06584 L
.05981 .06755 L
.06272 .07045 L
.06483 .07238 L
.06315 .07721 L
.06755 .08161 L
.06858 .08204 L
.07238 .08585 L
.07376 .08688 L
.07721 .09032 L
.07888 .09171 L
.08204 .09487 L
.08395 .09654 L
.08688 .09946 L
.08899 .10137 L
.08747 .1062 L
.09171 .11044 L
.09284 .11104 L
.09654 .11473 L
.09802 .11587 L
.10137 .11921 L
.10314 .1207 L
.1062 .12376 L
.10821 .12553 L
.10634 .13036 L
.11104 .13506 L
.11204 .1352 L
.11587 .13902 L
.11727 .14003 L
.1207 .14344 L
.12242 .14486 L
.12553 .14796 L
.12751 .14969 L
Mistroke
.12572 .15452 L
.13036 .15916 L
.1314 .15935 L
.1352 .16314 L
.13664 .16419 L
.14003 .16756 L
.14179 .16902 L
.14486 .17208 L
.14689 .17385 L
.14549 .17868 L
.14969 .18288 L
.15091 .18351 L
.15452 .18712 L
.15612 .18835 L
.15935 .19157 L
.16125 .19318 L
.16419 .1961 L
.16634 .19801 L
.16523 .20284 L
.16902 .20663 L
.1705 .20767 L
.17385 .21101 L
.17566 .2125 L
.17868 .21551 L
.18077 .21734 L
.17964 .22217 L
.18351 .22604 L
.18495 .227 L
.18835 .23039 L
.19013 .23183 L
.19318 .23486 L
.19526 .23666 L
.19416 .2415 L
.19801 .24534 L
.19947 .24633 L
.20284 .24968 L
.20466 .25116 L
.20767 .25416 L
.20979 .25599 L
.20878 .26082 L
.2125 .26454 L
.21407 .26566 L
.21734 .26891 L
.21924 .27049 L
.21799 .27532 L
.22217 .27949 L
.22347 .28015 L
.227 .28367 L
.22871 .28498 L
.23183 .28809 L
Mistroke
.23387 .28981 L
.23287 .29465 L
.23666 .29843 L
.2382 .29948 L
.2415 .30277 L
.24339 .30431 L
.24226 .30914 L
.24633 .3132 L
.2477 .31397 L
.25116 .31742 L
.25294 .31881 L
.25163 .32364 L
.25599 .32799 L
.25724 .32847 L
.26082 .33204 L
.26252 .3333 L
.26566 .33642 L
.2677 .33813 L
.26683 .34296 L
.27049 .34661 L
.27213 .3478 L
.27532 .35097 L
.27733 .35263 L
.27646 .35746 L
.28015 .36114 L
.28178 .36229 L
.28498 .36548 L
.28698 .36712 L
.28614 .37196 L
.28981 .37561 L
.29147 .37679 L
.2901 .38162 L
.29465 .38616 L
.29588 .38645 L
.29948 .39004 L
.30118 .39128 L
.30007 .39612 L
.30431 .40035 L
.30565 .40095 L
.30914 .40442 L
.31093 .40578 L
.31 .41061 L
.31397 .41457 L
.31545 .41544 L
.31881 .41878 L
.3207 .42027 L
.31991 .42511 L
.32364 .42882 L
.32527 .42994 L
.3242 .43477 L
Mistroke
.32847 .43903 L
.32981 .4396 L
.3333 .44307 L
.33511 .44443 L
.33428 .44927 L
.33813 .45319 L
.33954 .4541 L
.33858 .45893 L
.34296 .46331 L
.34415 .46376 L
.3478 .46739 L
.3494 .46859 L
.34874 .47342 L
.35263 .4773 L
.35406 .47826 L
.35327 .48309 L
.35746 .48727 L
.35873 .48792 L
.35754 .49275 L
.36229 .49751 L
.36339 .49758 L
.36712 .5013 L
.36866 .50242 L
.36805 .50725 L
.37196 .51114 L
.37338 .51208 L
.37271 .51691 L
.37679 .52098 L
.3781 .52174 L
.37736 .52658 L
.38162 .53083 L
.38284 .53141 L
.38198 .53624 L
.38645 .54071 L
.38759 .54107 L
.39128 .54475 L
.39283 .5459 L
.39236 .55073 L
.39612 .55448 L
.39762 .55557 L
.39714 .5604 L
.40095 .56419 L
.40241 .56523 L
.40194 .57006 L
.40578 .57389 L
.40722 .57489 L
.40676 .57973 L
.41061 .58356 L
.41203 .58456 L
.4116 .58939 L
Mistroke
.41544 .59322 L
.41686 .59422 L
.41645 .59905 L
.41557 .60388 L
.42027 .60859 L
.42132 .60872 L
.42065 .61355 L
.42511 .618 L
.4262 .61838 L
.42565 .62321 L
.42994 .62749 L
.43108 .62804 L
.43063 .63288 L
.43477 .63701 L
.43597 .63771 L
.43559 .64254 L
.4396 .64654 L
.44087 .64737 L
.44054 .6522 L
.44 .65704 L
.44443 .66147 L
.44547 .66187 L
.44508 .6667 L
.44927 .67087 L
.4504 .67153 L
.45009 .67636 L
.44956 .68119 L
.4541 .68573 L
.45506 .68603 L
.45472 .69086 L
.45893 .69506 L
.46 .69569 L
.45974 .70052 L
.45937 .70535 L
.46376 .70974 L
.46471 .71019 L
.46446 .71502 L
.46407 .71985 L
.46859 .72437 L
.46944 .72468 L
.46921 .72951 L
.46886 .73434 L
.47342 .73892 L
.4742 .73918 L
.474 .74401 L
.47372 .74884 L
.47826 .75338 L
.47897 .75367 L
.47881 .7585 L
.47861 .76334 L
Mistroke
.48309 .76783 L
.48372 .76817 L
.4836 .773 L
.48347 .77783 L
.4833 .78266 L
.48792 .78732 L
.48833 .7875 L
.48824 .79233 L
.48815 .79716 L
.48806 .80199 L
.49275 .80678 L
.49284 .80682 L
.49278 .81165 L
.49275 .81404 L
.49269 .81649 L
.49259 .82132 L
.49254 .82615 L
.49259 .83098 L
.48792 .83484 L
.48772 .83581 L
.48673 .84065 L
.48576 .84548 L
.48482 .85031 L
.48391 .85514 L
.48309 .85972 L
.48305 .85997 L
.48226 .8648 L
.4815 .86964 L
.48079 .87447 L
.48013 .8793 L
.47951 .88413 L
.47894 .88896 L
.47842 .8938 L
.47826 .89545 L
.47797 .89863 L
.47758 .90346 L
.47725 .90829 L
.47698 .91312 L
.47678 .91796 L
.47666 .92279 L
.4766 .92762 L
.47663 .93245 L
.47675 .93728 L
.47696 .94211 L
.47727 .94695 L
.47769 .95178 L
.47824 .95661 L
.47826 .95671 L
.47894 .96144 L
.47979 .96627 L
Mistroke
.48083 .97111 L
.48211 .97594 L
.48309 .97905 L
.48367 .98077 L
Mfstroke
.028 .55 0 r
.01923 .02211 m
.01987 .02406 L
.02406 .02756 L
.02561 .02889 L
.02889 .03218 L
.03062 .03373 L
.03373 .03682 L
.03562 .03856 L
.03856 .04149 L
.04061 .04339 L
.03923 .04822 L
.04339 .05238 L
.04445 .05305 L
.04822 .05682 L
.04956 .05789 L
.05305 .06137 L
.05462 .06272 L
.05789 .06597 L
.05966 .06755 L
.06272 .0706 L
.06467 .07238 L
.06312 .07721 L
.06755 .08164 L
.06849 .08204 L
.07238 .08593 L
.07366 .08688 L
.07721 .09043 L
.07875 .09171 L
.08204 .095 L
.0838 .09654 L
.08688 .09961 L
.08883 .10137 L
.08743 .1062 L
.09171 .11048 L
.09275 .11104 L
.09654 .11482 L
.09791 .11587 L
.10137 .11932 L
.103 .1207 L
.1062 .1239 L
.10805 .12553 L
.10633 .13036 L
.11104 .13507 L
.11196 .1352 L
.11587 .1391 L
.11717 .14003 L
.1207 .14355 L
.12228 .14486 L
.12553 .1481 L
.12736 .14969 L
.12571 .15452 L
.13036 .15918 L
.13132 .15935 L
.1352 .16323 L
.13653 .16419 L
.14003 .16767 L
.14165 .16902 L
.14486 .17221 L
.14673 .17385 L
.14544 .17868 L
.14969 .18293 L
.15081 .18351 L
.15452 .18722 L
.15599 .18835 L
.15935 .1917 L
.1611 .19318 L
.16419 .19625 L
.16617 .19801 L
.16514 .20284 L
.16902 .20671 L
.17038 .20767 L
.17385 .21113 L
.17552 .2125 L
.17868 .21565 L
.18061 .21734 L
.17956 .22217 L
.18351 .22612 L
.18484 .227 L
.18835 .2305 L
.18999 .23183 L
.19318 .235 L
.19509 .23666 L
.19408 .2415 L
.19801 .24542 L
.19936 .24633 L
.20284 .2498 L
.20452 .25116 L
.20767 .2543 L
.20962 .25599 L
.20869 .26082 L
.2125 .26463 L
.21394 .26566 L
.21734 .26904 L
.21909 .27049 L
.21794 .27532 L
.22217 .27954 L
.22337 .28015 L
.227 .28377 L
.22858 .28498 L
.23183 .28822 L
.23371 .28981 L
.23279 .29465 L
.23666 .29852 L
.23808 .29948 L
.2415 .30289 L
.24325 .30431 L
.2422 .30914 L
.24633 .31327 L
.2476 .31397 L
.25116 .31752 L
.2528 .31881 L
.2516 .32364 L
.25599 .32803 L
.25715 .32847 L
.26082 .33213 L
.26239 .3333 L
.26566 .33655 L
.26754 .33813 L
.26674 .34296 L
.27049 .3467 L
.27201 .3478 L
.27532 .35109 L
.27717 .35263 L
.27637 .35746 L
.28015 .36123 L
.28166 .36229 L
.28498 .3656 L
.28683 .36712 L
.28605 .37196 L
.28981 .3757 L
.29134 .37679 L
.29008 .38162 L
.29465 .38618 L
.29578 .38645 L
.29948 .39013 L
.30105 .39128 L
.30003 .39612 L
.30431 .40039 L
.30555 .40095 L
.30914 .40453 L
.31079 .40578 L
.30993 .41061 L
.31397 .41464 L
.31534 .41544 L
.31881 .4189 L
.32055 .42027 L
.31982 .42511 L
.32364 .42891 L
.32514 .42994 L
.32416 .43477 L
.32847 .43908 L
.32971 .4396 L
.3333 .44318 L
.33497 .44443 L
.33421 .44927 L
.33813 .45327 L
.33942 .4541 L
.33854 .45893 L
.34296 .46335 L
.34405 .46376 L
.3478 .4675 L
.34926 .46859 L
.34865 .47342 L
.35263 .47739 L
.35394 .47826 L
.35322 .48309 L
.35746 .48733 L
.35862 .48792 L
.35753 .49275 L
.36229 .49751 L
.36329 .49758 L
.36712 .5014 L
.36852 .50242 L
.36797 .50725 L
.37196 .51122 L
.37325 .51208 L
.37264 .51691 L
.37679 .52105 L
.37799 .52174 L
.3773 .52658 L
.38162 .53089 L
.38273 .53141 L
.38194 .53624 L
.38645 .54074 L
.38749 .54107 L
.39128 .54485 L
.39269 .5459 L
.39226 .55073 L
.39612 .55458 L
.39748 .55557 L
.39704 .5604 L
.40095 .56429 L
.40228 .56523 L
.40185 .57006 L
.40578 .57398 L
.40708 .57489 L
.40667 .57973 L
.41061 .58366 L
.4119 .58456 L
.4115 .58939 L
.41544 .59331 L
.41673 .59422 L
.41636 .59905 L
.41556 .60388 L
.42027 .6086 L
.42122 .60872 L
.42062 .61355 L
.42511 .61803 L
.42609 .61838 L
.4256 .62321 L
.42994 .62754 L
.43097 .62804 L
.43056 .63288 L
.43477 .63708 L
.43586 .63771 L
.43551 .64254 L
.4396 .64662 L
.44074 .64737 L
.44044 .6522 L
.43996 .65704 L
.44443 .66151 L
.44537 .66187 L
.44501 .6667 L
.44927 .67094 L
.45028 .67153 L
.45 .67636 L
.44953 .68119 L
.4541 .68576 L
.45495 .68603 L
.45465 .69086 L
.45893 .69513 L
.45988 .69569 L
.45965 .70052 L
.45932 .70535 L
.46376 .70979 L
.4646 .71019 L
.46438 .71502 L
.46404 .71985 L
.46859 .72441 L
.46934 .72468 L
.46914 .72951 L
.46882 .73434 L
.47342 .73895 L
.4741 .73918 L
.47393 .74401 L
.47368 .74884 L
.47826 .75342 L
.47887 .75367 L
.47873 .7585 L
.47856 .76334 L
.48309 .76789 L
.48362 .76817 L
.48351 .773 L
.4834 .77783 L
.48326 .78266 L
.48792 .78736 L
.48823 .7875 L
.48816 .79233 L
.48808 .79716 L
.48801 .80199 L
.49274 .80682 L
.49261 .81165 L
.49251 .81649 L
.49243 .82132 L
.48792 .82552 L
.48778 .82615 L
.48667 .83098 L
.4856 .83581 L
.48455 .84065 L
.48352 .84548 L
.48309 .84757 L
.48255 .85031 L
.48164 .85514 L
.48075 .85997 L
.4799 .8648 L
.47909 .86964 L
.47833 .87447 L
.47826 .87492 L
.47762 .8793 L
.47696 .88413 L
.47635 .88896 L
.47579 .8938 L
.47527 .89863 L
.47481 .90346 L
.47441 .90829 L
.47407 .91312 L
.47378 .91796 L
.47357 .92279 L
.47342 .92746 L
.47342 .92762 L
.47335 .93245 L
.47335 .93728 L
.47342 .94183 L
.47343 .94211 L
.4736 .94695 L
.47387 .95178 L
.47423 .95661 L
.47471 .96144 L
.47531 .96627 L
.47604 .97111 L
.47693 .97594 L
.47801 .98077 L
.01923 .98077 L
F
0 g
.01923 .02211 m
.01987 .02406 L
.02406 .02756 L
.02561 .02889 L
.02889 .03218 L
.03062 .03373 L
.03373 .03682 L
.03562 .03856 L
.03856 .04149 L
.04061 .04339 L
.03923 .04822 L
.04339 .05238 L
.04445 .05305 L
.04822 .05682 L
.04956 .05789 L
.05305 .06137 L
.05462 .06272 L
.05789 .06597 L
.05966 .06755 L
.06272 .0706 L
.06467 .07238 L
.06312 .07721 L
.06755 .08164 L
.06849 .08204 L
.07238 .08593 L
.07366 .08688 L
.07721 .09043 L
.07875 .09171 L
.08204 .095 L
.0838 .09654 L
.08688 .09961 L
.08883 .10137 L
.08743 .1062 L
.09171 .11048 L
.09275 .11104 L
.09654 .11482 L
.09791 .11587 L
.10137 .11932 L
.103 .1207 L
.1062 .1239 L
.10805 .12553 L
.10633 .13036 L
.11104 .13507 L
.11196 .1352 L
.11587 .1391 L
.11717 .14003 L
.1207 .14355 L
.12228 .14486 L
.12553 .1481 L
.12736 .14969 L
Mistroke
.12571 .15452 L
.13036 .15918 L
.13132 .15935 L
.1352 .16323 L
.13653 .16419 L
.14003 .16767 L
.14165 .16902 L
.14486 .17221 L
.14673 .17385 L
.14544 .17868 L
.14969 .18293 L
.15081 .18351 L
.15452 .18722 L
.15599 .18835 L
.15935 .1917 L
.1611 .19318 L
.16419 .19625 L
.16617 .19801 L
.16514 .20284 L
.16902 .20671 L
.17038 .20767 L
.17385 .21113 L
.17552 .2125 L
.17868 .21565 L
.18061 .21734 L
.17956 .22217 L
.18351 .22612 L
.18484 .227 L
.18835 .2305 L
.18999 .23183 L
.19318 .235 L
.19509 .23666 L
.19408 .2415 L
.19801 .24542 L
.19936 .24633 L
.20284 .2498 L
.20452 .25116 L
.20767 .2543 L
.20962 .25599 L
.20869 .26082 L
.2125 .26463 L
.21394 .26566 L
.21734 .26904 L
.21909 .27049 L
.21794 .27532 L
.22217 .27954 L
.22337 .28015 L
.227 .28377 L
.22858 .28498 L
.23183 .28822 L
Mistroke
.23371 .28981 L
.23279 .29465 L
.23666 .29852 L
.23808 .29948 L
.2415 .30289 L
.24325 .30431 L
.2422 .30914 L
.24633 .31327 L
.2476 .31397 L
.25116 .31752 L
.2528 .31881 L
.2516 .32364 L
.25599 .32803 L
.25715 .32847 L
.26082 .33213 L
.26239 .3333 L
.26566 .33655 L
.26754 .33813 L
.26674 .34296 L
.27049 .3467 L
.27201 .3478 L
.27532 .35109 L
.27717 .35263 L
.27637 .35746 L
.28015 .36123 L
.28166 .36229 L
.28498 .3656 L
.28683 .36712 L
.28605 .37196 L
.28981 .3757 L
.29134 .37679 L
.29008 .38162 L
.29465 .38618 L
.29578 .38645 L
.29948 .39013 L
.30105 .39128 L
.30003 .39612 L
.30431 .40039 L
.30555 .40095 L
.30914 .40453 L
.31079 .40578 L
.30993 .41061 L
.31397 .41464 L
.31534 .41544 L
.31881 .4189 L
.32055 .42027 L
.31982 .42511 L
.32364 .42891 L
.32514 .42994 L
.32416 .43477 L
Mistroke
.32847 .43908 L
.32971 .4396 L
.3333 .44318 L
.33497 .44443 L
.33421 .44927 L
.33813 .45327 L
.33942 .4541 L
.33854 .45893 L
.34296 .46335 L
.34405 .46376 L
.3478 .4675 L
.34926 .46859 L
.34865 .47342 L
.35263 .47739 L
.35394 .47826 L
.35322 .48309 L
.35746 .48733 L
.35862 .48792 L
.35753 .49275 L
.36229 .49751 L
.36329 .49758 L
.36712 .5014 L
.36852 .50242 L
.36797 .50725 L
.37196 .51122 L
.37325 .51208 L
.37264 .51691 L
.37679 .52105 L
.37799 .52174 L
.3773 .52658 L
.38162 .53089 L
.38273 .53141 L
.38194 .53624 L
.38645 .54074 L
.38749 .54107 L
.39128 .54485 L
.39269 .5459 L
.39226 .55073 L
.39612 .55458 L
.39748 .55557 L
.39704 .5604 L
.40095 .56429 L
.40228 .56523 L
.40185 .57006 L
.40578 .57398 L
.40708 .57489 L
.40667 .57973 L
.41061 .58366 L
.4119 .58456 L
.4115 .58939 L
Mistroke
.41544 .59331 L
.41673 .59422 L
.41636 .59905 L
.41556 .60388 L
.42027 .6086 L
.42122 .60872 L
.42062 .61355 L
.42511 .61803 L
.42609 .61838 L
.4256 .62321 L
.42994 .62754 L
.43097 .62804 L
.43056 .63288 L
.43477 .63708 L
.43586 .63771 L
.43551 .64254 L
.4396 .64662 L
.44074 .64737 L
.44044 .6522 L
.43996 .65704 L
.44443 .66151 L
.44537 .66187 L
.44501 .6667 L
.44927 .67094 L
.45028 .67153 L
.45 .67636 L
.44953 .68119 L
.4541 .68576 L
.45495 .68603 L
.45465 .69086 L
.45893 .69513 L
.45988 .69569 L
.45965 .70052 L
.45932 .70535 L
.46376 .70979 L
.4646 .71019 L
.46438 .71502 L
.46404 .71985 L
.46859 .72441 L
.46934 .72468 L
.46914 .72951 L
.46882 .73434 L
.47342 .73895 L
.4741 .73918 L
.47393 .74401 L
.47368 .74884 L
.47826 .75342 L
.47887 .75367 L
.47873 .7585 L
.47856 .76334 L
Mistroke
.48309 .76789 L
.48362 .76817 L
.48351 .773 L
.4834 .77783 L
.48326 .78266 L
.48792 .78736 L
.48823 .7875 L
.48816 .79233 L
.48808 .79716 L
.48801 .80199 L
.49274 .80682 L
.49261 .81165 L
.49251 .81649 L
.49243 .82132 L
.48792 .82552 L
.48778 .82615 L
.48667 .83098 L
.4856 .83581 L
.48455 .84065 L
.48352 .84548 L
.48309 .84757 L
.48255 .85031 L
.48164 .85514 L
.48075 .85997 L
.4799 .8648 L
.47909 .86964 L
.47833 .87447 L
.47826 .87492 L
.47762 .8793 L
.47696 .88413 L
.47635 .88896 L
.47579 .8938 L
.47527 .89863 L
.47481 .90346 L
.47441 .90829 L
.47407 .91312 L
.47378 .91796 L
.47357 .92279 L
.47342 .92746 L
.47342 .92762 L
.47335 .93245 L
.47335 .93728 L
.47342 .94183 L
.47343 .94211 L
.4736 .94695 L
.47387 .95178 L
.47423 .95661 L
.47471 .96144 L
.47531 .96627 L
.47604 .97111 L
Mistroke
.47693 .97594 L
.47801 .98077 L
Mfstroke
0 .505 .073 r
.01923 .02223 m
.0198 .02406 L
.02406 .02767 L
.02547 .02889 L
.02889 .03231 L
.03048 .03373 L
.03373 .03697 L
.03546 .03856 L
.03856 .04165 L
.04044 .04339 L
.03917 .04822 L
.04339 .05244 L
.04436 .05305 L
.04822 .05691 L
.04945 .05789 L
.05305 .06149 L
.05449 .06272 L
.05789 .06611 L
.05951 .06755 L
.06272 .07075 L
.0645 .07238 L
.06308 .07721 L
.06755 .08168 L
.06841 .08204 L
.07238 .08601 L
.07355 .08688 L
.07721 .09054 L
.07862 .09171 L
.08204 .09513 L
.08365 .09654 L
.08688 .09976 L
.08866 .10137 L
.08738 .1062 L
.09171 .11053 L
.09266 .11104 L
.09654 .11491 L
.09779 .11587 L
.10137 .11944 L
.10286 .1207 L
.1062 .12403 L
.1079 .12553 L
.10632 .13036 L
.11104 .13508 L
.11188 .1352 L
.11587 .13918 L
.11706 .14003 L
.1207 .14366 L
.12215 .14486 L
.12553 .14823 L
.1272 .14969 L
.12569 .15452 L
.13036 .15919 L
.13124 .15935 L
.1352 .16331 L
.13642 .16419 L
.14003 .16779 L
.14152 .16902 L
.14486 .17235 L
.14657 .17385 L
.14539 .17868 L
.14969 .18298 L
.15072 .18351 L
.15452 .18731 L
.15587 .18835 L
.15935 .19182 L
.16096 .19318 L
.16419 .1964 L
.16601 .19801 L
.16506 .20284 L
.16902 .20679 L
.17027 .20767 L
.17385 .21125 L
.17538 .2125 L
.17868 .2158 L
.18045 .21734 L
.17949 .22217 L
.18351 .22619 L
.18473 .227 L
.18835 .23061 L
.18986 .23183 L
.19318 .23514 L
.19493 .23666 L
.194 .2415 L
.19801 .2455 L
.19925 .24633 L
.20284 .24991 L
.20438 .25116 L
.20767 .25444 L
.20946 .25599 L
.2086 .26082 L
.2125 .26472 L
.21382 .26566 L
.21734 .26916 L
.21895 .27049 L
.21789 .27532 L
.22217 .2796 L
.22326 .28015 L
.227 .28388 L
.22844 .28498 L
.23183 .28836 L
.23355 .28981 L
.2327 .29465 L
.23666 .2986 L
.23796 .29948 L
.2415 .30301 L
.2431 .30431 L
.24214 .30914 L
.24633 .31333 L
.24749 .31397 L
.25116 .31763 L
.25266 .31881 L
.25156 .32364 L
.25599 .32807 L
.25705 .32847 L
.26082 .33223 L
.26226 .3333 L
.26566 .33669 L
.26738 .33813 L
.26664 .34296 L
.27049 .3468 L
.27188 .3478 L
.27532 .35122 L
.27701 .35263 L
.27628 .35746 L
.28015 .36132 L
.28153 .36229 L
.28498 .36573 L
.28667 .36712 L
.28596 .37196 L
.28981 .3758 L
.29121 .37679 L
.29006 .38162 L
.29465 .38621 L
.29568 .38645 L
.29948 .39023 L
.30092 .39128 L
.29998 .39612 L
.30431 .40044 L
.30544 .40095 L
.30914 .40463 L
.31065 .40578 L
.30986 .41061 L
.31397 .41471 L
.31522 .41544 L
.31881 .41901 L
.32041 .42027 L
.31974 .42511 L
.32364 .42899 L
.32502 .42994 L
.32411 .43477 L
.32847 .43912 L
.3296 .4396 L
.3333 .44328 L
.33483 .44443 L
.33413 .44927 L
.33813 .45335 L
.33929 .4541 L
.3385 .45893 L
.34296 .46339 L
.34394 .46376 L
.3478 .4676 L
.34912 .46859 L
.34857 .47342 L
.35263 .47747 L
.35381 .47826 L
.35316 .48309 L
.35746 .48739 L
.3585 .48792 L
.35752 .49275 L
.36229 .49752 L
.36319 .49758 L
.36712 .5015 L
.36839 .50242 L
.36788 .50725 L
.37196 .51131 L
.37312 .51208 L
.37257 .51691 L
.37679 .52112 L
.37787 .52174 L
.37725 .52658 L
.38162 .53094 L
.38262 .53141 L
.38191 .53624 L
.38645 .54078 L
.38738 .54107 L
.39128 .54496 L
.39255 .5459 L
.39216 .55073 L
.39612 .55468 L
.39734 .55557 L
.39695 .5604 L
.40095 .56438 L
.40214 .56523 L
.40175 .57006 L
.40578 .57408 L
.40695 .57489 L
.40657 .57973 L
.41061 .58375 L
.41177 .58456 L
.41141 .58939 L
.41544 .59341 L
.41659 .59422 L
.41626 .59905 L
.41554 .60388 L
.42027 .60862 L
.42112 .60872 L
.42058 .61355 L
.42511 .61807 L
.42599 .61838 L
.42554 .62321 L
.42994 .6276 L
.43086 .62804 L
.43049 .63288 L
.43477 .63715 L
.43574 .63771 L
.43542 .64254 L
.4396 .64671 L
.44061 .64737 L
.44035 .6522 L
.43991 .65704 L
.44443 .66155 L
.44526 .66187 L
.44494 .6667 L
.44927 .67101 L
.45016 .67153 L
.44991 .67636 L
.4495 .68119 L
.4541 .6858 L
.45485 .68603 L
.45458 .69086 L
.45893 .6952 L
.45976 .69569 L
.45956 .70052 L
.45927 .70535 L
.46376 .70984 L
.46449 .71019 L
.4643 .71502 L
.464 .71985 L
.46859 .72445 L
.46924 .72468 L
.46906 .72951 L
.46879 .73434 L
.47342 .73899 L
.474 .73918 L
.47385 .74401 L
.47364 .74884 L
.47826 .75347 L
.47876 .75367 L
.47865 .7585 L
.4785 .76334 L
.48309 .76795 L
.48351 .76817 L
.48342 .773 L
.48333 .77783 L
.48322 .78266 L
.48792 .7874 L
.48813 .7875 L
.48807 .79233 L
.48802 .79716 L
.48797 .80199 L
.49249 .80682 L
.49238 .81165 L
.48792 .81505 L
.48755 .81649 L
.48634 .82132 L
.48516 .82615 L
.48399 .83098 L
.48309 .83483 L
.48287 .83581 L
.48179 .84065 L
.48075 .84548 L
.47974 .85031 L
.47876 .85514 L
.47826 .8577 L
.47783 .85997 L
.47694 .8648 L
.4761 .86964 L
.47529 .87447 L
.47452 .8793 L
.4738 .88413 L
.47342 .88675 L
.47312 .88896 L
.4725 .8938 L
.47193 .89863 L
.4714 .90346 L
.47093 .90829 L
.47051 .91312 L
.47014 .91796 L
.46983 .92279 L
.46959 .92762 L
.46941 .93245 L
.4693 .93728 L
.46925 .94211 L
.46928 .94695 L
.46939 .95178 L
.46959 .95661 L
.46988 .96144 L
.47026 .96627 L
.47075 .97111 L
.47135 .97594 L
.47208 .98077 L
.01923 .98077 L
F
0 g
.01923 .02223 m
.0198 .02406 L
.02406 .02767 L
.02547 .02889 L
.02889 .03231 L
.03048 .03373 L
.03373 .03697 L
.03546 .03856 L
.03856 .04165 L
.04044 .04339 L
.03917 .04822 L
.04339 .05244 L
.04436 .05305 L
.04822 .05691 L
.04945 .05789 L
.05305 .06149 L
.05449 .06272 L
.05789 .06611 L
.05951 .06755 L
.06272 .07075 L
.0645 .07238 L
.06308 .07721 L
.06755 .08168 L
.06841 .08204 L
.07238 .08601 L
.07355 .08688 L
.07721 .09054 L
.07862 .09171 L
.08204 .09513 L
.08365 .09654 L
.08688 .09976 L
.08866 .10137 L
.08738 .1062 L
.09171 .11053 L
.09266 .11104 L
.09654 .11491 L
.09779 .11587 L
.10137 .11944 L
.10286 .1207 L
.1062 .12403 L
.1079 .12553 L
.10632 .13036 L
.11104 .13508 L
.11188 .1352 L
.11587 .13918 L
.11706 .14003 L
.1207 .14366 L
.12215 .14486 L
.12553 .14823 L
.1272 .14969 L
Mistroke
.12569 .15452 L
.13036 .15919 L
.13124 .15935 L
.1352 .16331 L
.13642 .16419 L
.14003 .16779 L
.14152 .16902 L
.14486 .17235 L
.14657 .17385 L
.14539 .17868 L
.14969 .18298 L
.15072 .18351 L
.15452 .18731 L
.15587 .18835 L
.15935 .19182 L
.16096 .19318 L
.16419 .1964 L
.16601 .19801 L
.16506 .20284 L
.16902 .20679 L
.17027 .20767 L
.17385 .21125 L
.17538 .2125 L
.17868 .2158 L
.18045 .21734 L
.17949 .22217 L
.18351 .22619 L
.18473 .227 L
.18835 .23061 L
.18986 .23183 L
.19318 .23514 L
.19493 .23666 L
.194 .2415 L
.19801 .2455 L
.19925 .24633 L
.20284 .24991 L
.20438 .25116 L
.20767 .25444 L
.20946 .25599 L
.2086 .26082 L
.2125 .26472 L
.21382 .26566 L
.21734 .26916 L
.21895 .27049 L
.21789 .27532 L
.22217 .2796 L
.22326 .28015 L
.227 .28388 L
.22844 .28498 L
.23183 .28836 L
Mistroke
.23355 .28981 L
.2327 .29465 L
.23666 .2986 L
.23796 .29948 L
.2415 .30301 L
.2431 .30431 L
.24214 .30914 L
.24633 .31333 L
.24749 .31397 L
.25116 .31763 L
.25266 .31881 L
.25156 .32364 L
.25599 .32807 L
.25705 .32847 L
.26082 .33223 L
.26226 .3333 L
.26566 .33669 L
.26738 .33813 L
.26664 .34296 L
.27049 .3468 L
.27188 .3478 L
.27532 .35122 L
.27701 .35263 L
.27628 .35746 L
.28015 .36132 L
.28153 .36229 L
.28498 .36573 L
.28667 .36712 L
.28596 .37196 L
.28981 .3758 L
.29121 .37679 L
.29006 .38162 L
.29465 .38621 L
.29568 .38645 L
.29948 .39023 L
.30092 .39128 L
.29998 .39612 L
.30431 .40044 L
.30544 .40095 L
.30914 .40463 L
.31065 .40578 L
.30986 .41061 L
.31397 .41471 L
.31522 .41544 L
.31881 .41901 L
.32041 .42027 L
.31974 .42511 L
.32364 .42899 L
.32502 .42994 L
.32411 .43477 L
Mistroke
.32847 .43912 L
.3296 .4396 L
.3333 .44328 L
.33483 .44443 L
.33413 .44927 L
.33813 .45335 L
.33929 .4541 L
.3385 .45893 L
.34296 .46339 L
.34394 .46376 L
.3478 .4676 L
.34912 .46859 L
.34857 .47342 L
.35263 .47747 L
.35381 .47826 L
.35316 .48309 L
.35746 .48739 L
.3585 .48792 L
.35752 .49275 L
.36229 .49752 L
.36319 .49758 L
.36712 .5015 L
.36839 .50242 L
.36788 .50725 L
.37196 .51131 L
.37312 .51208 L
.37257 .51691 L
.37679 .52112 L
.37787 .52174 L
.37725 .52658 L
.38162 .53094 L
.38262 .53141 L
.38191 .53624 L
.38645 .54078 L
.38738 .54107 L
.39128 .54496 L
.39255 .5459 L
.39216 .55073 L
.39612 .55468 L
.39734 .55557 L
.39695 .5604 L
.40095 .56438 L
.40214 .56523 L
.40175 .57006 L
.40578 .57408 L
.40695 .57489 L
.40657 .57973 L
.41061 .58375 L
.41177 .58456 L
.41141 .58939 L
Mistroke
.41544 .59341 L
.41659 .59422 L
.41626 .59905 L
.41554 .60388 L
.42027 .60862 L
.42112 .60872 L
.42058 .61355 L
.42511 .61807 L
.42599 .61838 L
.42554 .62321 L
.42994 .6276 L
.43086 .62804 L
.43049 .63288 L
.43477 .63715 L
.43574 .63771 L
.43542 .64254 L
.4396 .64671 L
.44061 .64737 L
.44035 .6522 L
.43991 .65704 L
.44443 .66155 L
.44526 .66187 L
.44494 .6667 L
.44927 .67101 L
.45016 .67153 L
.44991 .67636 L
.4495 .68119 L
.4541 .6858 L
.45485 .68603 L
.45458 .69086 L
.45893 .6952 L
.45976 .69569 L
.45956 .70052 L
.45927 .70535 L
.46376 .70984 L
.46449 .71019 L
.4643 .71502 L
.464 .71985 L
.46859 .72445 L
.46924 .72468 L
.46906 .72951 L
.46879 .73434 L
.47342 .73899 L
.474 .73918 L
.47385 .74401 L
.47364 .74884 L
.47826 .75347 L
.47876 .75367 L
.47865 .7585 L
.4785 .76334 L
Mistroke
.48309 .76795 L
.48351 .76817 L
.48342 .773 L
.48333 .77783 L
.48322 .78266 L
.48792 .7874 L
.48813 .7875 L
.48807 .79233 L
.48802 .79716 L
.48797 .80199 L
.49249 .80682 L
.49238 .81165 L
.48792 .81505 L
.48755 .81649 L
.48634 .82132 L
.48516 .82615 L
.48399 .83098 L
.48309 .83483 L
.48287 .83581 L
.48179 .84065 L
.48075 .84548 L
.47974 .85031 L
.47876 .85514 L
.47826 .8577 L
.47783 .85997 L
.47694 .8648 L
.4761 .86964 L
.47529 .87447 L
.47452 .8793 L
.4738 .88413 L
.47342 .88675 L
.47312 .88896 L
.4725 .8938 L
.47193 .89863 L
.4714 .90346 L
.47093 .90829 L
.47051 .91312 L
.47014 .91796 L
.46983 .92279 L
.46959 .92762 L
.46941 .93245 L
.4693 .93728 L
.46925 .94211 L
.46928 .94695 L
.46939 .95178 L
.46959 .95661 L
.46988 .96144 L
.47026 .96627 L
.47075 .97111 L
.47135 .97594 L
Mistroke
.47208 .98077 L
Mfstroke
0 .46 .156 r
.01923 .02236 m
.01974 .02406 L
.02406 .02778 L
.02534 .02889 L
.02889 .03244 L
.03033 .03373 L
.03373 .03712 L
.0353 .03856 L
.03856 .04181 L
.04026 .04339 L
.03911 .04822 L
.04339 .0525 L
.04427 .05305 L
.04822 .05701 L
.04933 .05789 L
.05305 .0616 L
.05436 .06272 L
.05789 .06624 L
.05936 .06755 L
.06272 .07091 L
.06434 .07238 L
.06305 .07721 L
.06755 .08171 L
.06833 .08204 L
.07238 .08609 L
.07344 .08688 L
.07721 .09065 L
.07849 .09171 L
.08204 .09526 L
.0835 .09654 L
.08688 .09991 L
.0885 .10137 L
.08733 .1062 L
.09171 .11058 L
.09257 .11104 L
.09654 .115 L
.09768 .11587 L
.10137 .11956 L
.10272 .1207 L
.1062 .12417 L
.10774 .12553 L
.10631 .13036 L
.11104 .13509 L
.1118 .1352 L
.11587 .13926 L
.11694 .14003 L
.1207 .14378 L
.12201 .14486 L
.12553 .14837 L
.12705 .14969 L
.12568 .15452 L
.13036 .15921 L
.13115 .15935 L
.1352 .16339 L
.1363 .16419 L
.14003 .1679 L
.14138 .16902 L
.14486 .17249 L
.14641 .17385 L
.14534 .17868 L
.14969 .18303 L
.15062 .18351 L
.15452 .18741 L
.15574 .18835 L
.15935 .19195 L
.16081 .19318 L
.16419 .19655 L
.16584 .19801 L
.16498 .20284 L
.16902 .20687 L
.17015 .20767 L
.17385 .21136 L
.17524 .2125 L
.17868 .21594 L
.18028 .21734 L
.17941 .22217 L
.18351 .22627 L
.18461 .227 L
.18835 .23073 L
.18971 .23183 L
.19318 .23528 L
.19477 .23666 L
.19392 .2415 L
.19801 .24557 L
.19913 .24633 L
.20284 .25003 L
.20424 .25116 L
.20767 .25459 L
.20929 .25599 L
.20852 .26082 L
.2125 .2648 L
.2137 .26566 L
.21734 .26928 L
.2188 .27049 L
.21783 .27532 L
.22217 .27965 L
.22316 .28015 L
.227 .28398 L
.22831 .28498 L
.23183 .28849 L
.23339 .28981 L
.23262 .29465 L
.23666 .29868 L
.23784 .29948 L
.2415 .30313 L
.24295 .30431 L
.24208 .30914 L
.24633 .31339 L
.24738 .31397 L
.25116 .31774 L
.25252 .31881 L
.25152 .32364 L
.25599 .32811 L
.25695 .32847 L
.26082 .33233 L
.26212 .3333 L
.26566 .33682 L
.26722 .33813 L
.26655 .34296 L
.27049 .34689 L
.27175 .3478 L
.27532 .35135 L
.27686 .35263 L
.27619 .35746 L
.28015 .36141 L
.2814 .36229 L
.28498 .36586 L
.28651 .36712 L
.28587 .37196 L
.28981 .37589 L
.29108 .37679 L
.29003 .38162 L
.29465 .38623 L
.29559 .38645 L
.29948 .39033 L
.30078 .39128 L
.29993 .39612 L
.30431 .40049 L
.30533 .40095 L
.30914 .40474 L
.31051 .40578 L
.30979 .41061 L
.31397 .41478 L
.3151 .41544 L
.31881 .41913 L
.32026 .42027 L
.31965 .42511 L
.32364 .42908 L
.32489 .42994 L
.32407 .43477 L
.32847 .43917 L
.3295 .4396 L
.3333 .44339 L
.33469 .44443 L
.33405 .44927 L
.33813 .45344 L
.33917 .4541 L
.33846 .45893 L
.34296 .46343 L
.34383 .46376 L
.3478 .46771 L
.34897 .46859 L
.34848 .47342 L
.35263 .47756 L
.35368 .47826 L
.3531 .48309 L
.35746 .48745 L
.35839 .48792 L
.35752 .49275 L
.36229 .49753 L
.36309 .49758 L
.36712 .5016 L
.36825 .50242 L
.3678 .50725 L
.37196 .5114 L
.37299 .51208 L
.3725 .51691 L
.37679 .52119 L
.37775 .52174 L
.3772 .52658 L
.38162 .53099 L
.38251 .53141 L
.38188 .53624 L
.38645 .54081 L
.38728 .54107 L
.39128 .54507 L
.39241 .5459 L
.39206 .55073 L
.39612 .55478 L
.3972 .55557 L
.39685 .5604 L
.40095 .56448 L
.402 .56523 L
.40166 .57006 L
.40578 .57417 L
.40681 .57489 L
.40648 .57973 L
.41061 .58385 L
.41163 .58456 L
.41131 .58939 L
.41544 .59351 L
.41646 .59422 L
.41616 .59905 L
.41553 .60388 L
.42027 .60863 L
.42102 .60872 L
.42054 .61355 L
.42511 .61811 L
.42588 .61838 L
.42549 .62321 L
.42994 .62766 L
.43075 .62804 L
.43042 .63288 L
.43477 .63722 L
.43561 .63771 L
.43534 .64254 L
.4396 .64679 L
.44048 .64737 L
.44025 .6522 L
.43987 .65704 L
.44443 .66159 L
.44515 .66187 L
.44488 .6667 L
.44927 .67108 L
.45004 .67153 L
.44982 .67636 L
.44946 .68119 L
.4541 .68583 L
.45474 .68603 L
.45451 .69086 L
.45893 .69527 L
.45964 .69569 L
.45947 .70052 L
.45922 .70535 L
.46376 .7099 L
.46438 .71019 L
.46421 .71502 L
.46396 .71985 L
.46859 .72449 L
.46913 .72468 L
.46898 .72951 L
.46876 .73434 L
.47342 .73902 L
.4739 .73918 L
.47377 .74401 L
.4736 .74884 L
.47826 .75351 L
.47866 .75367 L
.47856 .7585 L
.47845 .76334 L
.48309 .76801 L
.4834 .76817 L
.48333 .773 L
.48326 .77783 L
.48318 .78266 L
.48792 .78745 L
.48803 .7875 L
.48799 .79233 L
.48795 .79716 L
.48792 .80199 L
.48792 .80294 L
.48684 .80682 L
.48552 .81165 L
.48422 .81649 L
.48309 .8208 L
.48296 .82132 L
.48174 .82615 L
.48054 .83098 L
.47938 .83581 L
.47826 .84059 L
.47824 .84065 L
.47716 .84548 L
.47611 .85031 L
.47509 .85514 L
.4741 .85997 L
.47342 .8634 L
.47316 .8648 L
.47226 .86964 L
.47139 .87447 L
.47057 .8793 L
.46979 .88413 L
.46904 .88896 L
.46859 .89205 L
.46835 .8938 L
.4677 .89863 L
.4671 .90346 L
.46654 .90829 L
.46604 .91312 L
.46558 .91796 L
.46518 .92279 L
.46483 .92762 L
.46454 .93245 L
.46431 .93728 L
.46414 .94211 L
.46404 .94695 L
.464 .95178 L
.46403 .95661 L
.46414 .96144 L
.46433 .96627 L
.4646 .97111 L
.46496 .97594 L
.46542 .98077 L
.01923 .98077 L
F
0 g
.01923 .02236 m
.01974 .02406 L
.02406 .02778 L
.02534 .02889 L
.02889 .03244 L
.03033 .03373 L
.03373 .03712 L
.0353 .03856 L
.03856 .04181 L
.04026 .04339 L
.03911 .04822 L
.04339 .0525 L
.04427 .05305 L
.04822 .05701 L
.04933 .05789 L
.05305 .0616 L
.05436 .06272 L
.05789 .06624 L
.05936 .06755 L
.06272 .07091 L
.06434 .07238 L
.06305 .07721 L
.06755 .08171 L
.06833 .08204 L
.07238 .08609 L
.07344 .08688 L
.07721 .09065 L
.07849 .09171 L
.08204 .09526 L
.0835 .09654 L
.08688 .09991 L
.0885 .10137 L
.08733 .1062 L
.09171 .11058 L
.09257 .11104 L
.09654 .115 L
.09768 .11587 L
.10137 .11956 L
.10272 .1207 L
.1062 .12417 L
.10774 .12553 L
.10631 .13036 L
.11104 .13509 L
.1118 .1352 L
.11587 .13926 L
.11694 .14003 L
.1207 .14378 L
.12201 .14486 L
.12553 .14837 L
.12705 .14969 L
Mistroke
.12568 .15452 L
.13036 .15921 L
.13115 .15935 L
.1352 .16339 L
.1363 .16419 L
.14003 .1679 L
.14138 .16902 L
.14486 .17249 L
.14641 .17385 L
.14534 .17868 L
.14969 .18303 L
.15062 .18351 L
.15452 .18741 L
.15574 .18835 L
.15935 .19195 L
.16081 .19318 L
.16419 .19655 L
.16584 .19801 L
.16498 .20284 L
.16902 .20687 L
.17015 .20767 L
.17385 .21136 L
.17524 .2125 L
.17868 .21594 L
.18028 .21734 L
.17941 .22217 L
.18351 .22627 L
.18461 .227 L
.18835 .23073 L
.18971 .23183 L
.19318 .23528 L
.19477 .23666 L
.19392 .2415 L
.19801 .24557 L
.19913 .24633 L
.20284 .25003 L
.20424 .25116 L
.20767 .25459 L
.20929 .25599 L
.20852 .26082 L
.2125 .2648 L
.2137 .26566 L
.21734 .26928 L
.2188 .27049 L
.21783 .27532 L
.22217 .27965 L
.22316 .28015 L
.227 .28398 L
.22831 .28498 L
.23183 .28849 L
Mistroke
.23339 .28981 L
.23262 .29465 L
.23666 .29868 L
.23784 .29948 L
.2415 .30313 L
.24295 .30431 L
.24208 .30914 L
.24633 .31339 L
.24738 .31397 L
.25116 .31774 L
.25252 .31881 L
.25152 .32364 L
.25599 .32811 L
.25695 .32847 L
.26082 .33233 L
.26212 .3333 L
.26566 .33682 L
.26722 .33813 L
.26655 .34296 L
.27049 .34689 L
.27175 .3478 L
.27532 .35135 L
.27686 .35263 L
.27619 .35746 L
.28015 .36141 L
.2814 .36229 L
.28498 .36586 L
.28651 .36712 L
.28587 .37196 L
.28981 .37589 L
.29108 .37679 L
.29003 .38162 L
.29465 .38623 L
.29559 .38645 L
.29948 .39033 L
.30078 .39128 L
.29993 .39612 L
.30431 .40049 L
.30533 .40095 L
.30914 .40474 L
.31051 .40578 L
.30979 .41061 L
.31397 .41478 L
.3151 .41544 L
.31881 .41913 L
.32026 .42027 L
.31965 .42511 L
.32364 .42908 L
.32489 .42994 L
.32407 .43477 L
Mistroke
.32847 .43917 L
.3295 .4396 L
.3333 .44339 L
.33469 .44443 L
.33405 .44927 L
.33813 .45344 L
.33917 .4541 L
.33846 .45893 L
.34296 .46343 L
.34383 .46376 L
.3478 .46771 L
.34897 .46859 L
.34848 .47342 L
.35263 .47756 L
.35368 .47826 L
.3531 .48309 L
.35746 .48745 L
.35839 .48792 L
.35752 .49275 L
.36229 .49753 L
.36309 .49758 L
.36712 .5016 L
.36825 .50242 L
.3678 .50725 L
.37196 .5114 L
.37299 .51208 L
.3725 .51691 L
.37679 .52119 L
.37775 .52174 L
.3772 .52658 L
.38162 .53099 L
.38251 .53141 L
.38188 .53624 L
.38645 .54081 L
.38728 .54107 L
.39128 .54507 L
.39241 .5459 L
.39206 .55073 L
.39612 .55478 L
.3972 .55557 L
.39685 .5604 L
.40095 .56448 L
.402 .56523 L
.40166 .57006 L
.40578 .57417 L
.40681 .57489 L
.40648 .57973 L
.41061 .58385 L
.41163 .58456 L
.41131 .58939 L
Mistroke
.41544 .59351 L
.41646 .59422 L
.41616 .59905 L
.41553 .60388 L
.42027 .60863 L
.42102 .60872 L
.42054 .61355 L
.42511 .61811 L
.42588 .61838 L
.42549 .62321 L
.42994 .62766 L
.43075 .62804 L
.43042 .63288 L
.43477 .63722 L
.43561 .63771 L
.43534 .64254 L
.4396 .64679 L
.44048 .64737 L
.44025 .6522 L
.43987 .65704 L
.44443 .66159 L
.44515 .66187 L
.44488 .6667 L
.44927 .67108 L
.45004 .67153 L
.44982 .67636 L
.44946 .68119 L
.4541 .68583 L
.45474 .68603 L
.45451 .69086 L
.45893 .69527 L
.45964 .69569 L
.45947 .70052 L
.45922 .70535 L
.46376 .7099 L
.46438 .71019 L
.46421 .71502 L
.46396 .71985 L
.46859 .72449 L
.46913 .72468 L
.46898 .72951 L
.46876 .73434 L
.47342 .73902 L
.4739 .73918 L
.47377 .74401 L
.4736 .74884 L
.47826 .75351 L
.47866 .75367 L
.47856 .7585 L
.47845 .76334 L
Mistroke
.48309 .76801 L
.4834 .76817 L
.48333 .773 L
.48326 .77783 L
.48318 .78266 L
.48792 .78745 L
.48803 .7875 L
.48799 .79233 L
.48795 .79716 L
.48792 .80199 L
.48792 .80294 L
.48684 .80682 L
.48552 .81165 L
.48422 .81649 L
.48309 .8208 L
.48296 .82132 L
.48174 .82615 L
.48054 .83098 L
.47938 .83581 L
.47826 .84059 L
.47824 .84065 L
.47716 .84548 L
.47611 .85031 L
.47509 .85514 L
.4741 .85997 L
.47342 .8634 L
.47316 .8648 L
.47226 .86964 L
.47139 .87447 L
.47057 .8793 L
.46979 .88413 L
.46904 .88896 L
.46859 .89205 L
.46835 .8938 L
.4677 .89863 L
.4671 .90346 L
.46654 .90829 L
.46604 .91312 L
.46558 .91796 L
.46518 .92279 L
.46483 .92762 L
.46454 .93245 L
.46431 .93728 L
.46414 .94211 L
.46404 .94695 L
.464 .95178 L
.46403 .95661 L
.46414 .96144 L
.46433 .96627 L
.4646 .97111 L
Mistroke
.46496 .97594 L
.46542 .98077 L
Mfstroke
0 .415 .222 r
.01923 .0225 m
.01968 .02406 L
.02406 .0279 L
.02521 .02889 L
.02889 .03257 L
.03018 .03373 L
.03373 .03727 L
.03514 .03856 L
.03856 .04197 L
.04009 .04339 L
.03905 .04822 L
.04339 .05256 L
.04417 .05305 L
.04822 .0571 L
.04922 .05789 L
.05305 .06172 L
.05422 .06272 L
.05789 .06638 L
.0592 .06755 L
.06272 .07106 L
.06417 .07238 L
.06301 .07721 L
.06755 .08175 L
.06825 .08204 L
.07238 .08617 L
.07333 .08688 L
.07721 .09076 L
.07835 .09171 L
.08204 .09539 L
.08335 .09654 L
.08688 .10006 L
.08833 .10137 L
.08728 .1062 L
.09171 .11063 L
.09248 .11104 L
.09654 .11509 L
.09756 .11587 L
.10137 .11968 L
.10258 .1207 L
.1062 .12431 L
.10758 .12553 L
.1063 .13036 L
.11104 .1351 L
.11172 .1352 L
.11587 .13934 L
.11683 .14003 L
.1207 .14389 L
.12188 .14486 L
.12553 .14851 L
.12689 .14969 L
.12566 .15452 L
.13036 .15923 L
.13107 .15935 L
.1352 .16347 L
.13619 .16419 L
.14003 .16802 L
.14124 .16902 L
.14486 .17263 L
.14625 .17385 L
.14529 .17868 L
.14969 .18308 L
.15052 .18351 L
.15452 .18751 L
.15562 .18835 L
.15935 .19208 L
.16066 .19318 L
.16419 .1967 L
.16567 .19801 L
.1649 .20284 L
.16902 .20696 L
.17003 .20767 L
.17385 .21148 L
.17509 .2125 L
.17868 .21608 L
.18012 .21734 L
.17933 .22217 L
.18351 .22635 L
.1845 .227 L
.18835 .23084 L
.18957 .23183 L
.19318 .23543 L
.19461 .23666 L
.19385 .2415 L
.19801 .24565 L
.19901 .24633 L
.20284 .25015 L
.20409 .25116 L
.20767 .25473 L
.20912 .25599 L
.20843 .26082 L
.2125 .26489 L
.21358 .26566 L
.21734 .26941 L
.21865 .27049 L
.21778 .27532 L
.22217 .2797 L
.22306 .28015 L
.227 .28408 L
.22817 .28498 L
.23183 .28863 L
.23323 .28981 L
.23254 .29465 L
.23666 .29877 L
.23771 .29948 L
.2415 .30325 L
.2428 .30431 L
.24201 .30914 L
.24633 .31345 L
.24727 .31397 L
.25116 .31785 L
.25238 .31881 L
.25148 .32364 L
.25599 .32815 L
.25685 .32847 L
.26082 .33243 L
.26199 .3333 L
.26566 .33696 L
.26706 .33813 L
.26646 .34296 L
.27049 .34699 L
.27162 .3478 L
.27532 .35149 L
.2767 .35263 L
.2761 .35746 L
.28015 .3615 L
.28127 .36229 L
.28498 .36599 L
.28636 .36712 L
.28578 .37196 L
.28981 .37598 L
.29095 .37679 L
.29001 .38162 L
.29465 .38626 L
.29549 .38645 L
.29948 .39043 L
.30065 .39128 L
.29988 .39612 L
.30431 .40054 L
.30523 .40095 L
.30914 .40485 L
.31037 .40578 L
.30973 .41061 L
.31397 .41485 L
.31499 .41544 L
.31881 .41925 L
.32011 .42027 L
.31956 .42511 L
.32364 .42917 L
.32476 .42994 L
.32402 .43477 L
.32847 .43922 L
.32939 .4396 L
.3333 .4435 L
.33455 .44443 L
.33397 .44927 L
.33813 .45352 L
.33904 .4541 L
.33842 .45893 L
.34296 .46347 L
.34373 .46376 L
.3478 .46782 L
.34883 .46859 L
.3484 .47342 L
.35263 .47765 L
.35355 .47826 L
.35304 .48309 L
.35746 .48751 L
.35827 .48792 L
.35751 .49275 L
.36229 .49754 L
.36299 .49758 L
.36712 .50171 L
.36811 .50242 L
.36771 .50725 L
.37196 .51148 L
.37286 .51208 L
.37243 .51691 L
.37679 .52126 L
.37762 .52174 L
.37714 .52658 L
.38162 .53105 L
.38239 .53141 L
.38184 .53624 L
.38645 .54085 L
.38717 .54107 L
.39128 .54518 L
.39226 .5459 L
.39196 .55073 L
.39612 .55488 L
.39706 .55557 L
.39675 .5604 L
.40095 .56458 L
.40186 .56523 L
.40156 .57006 L
.40578 .57427 L
.40668 .57489 L
.40638 .57973 L
.41061 .58394 L
.41149 .58456 L
.41122 .58939 L
.41544 .59361 L
.41632 .59422 L
.41606 .59905 L
.41552 .60388 L
.42027 .60864 L
.42091 .60872 L
.4205 .61355 L
.42511 .61815 L
.42577 .61838 L
.42543 .62321 L
.42994 .62771 L
.43063 .62804 L
.43035 .63288 L
.43477 .63729 L
.43549 .63771 L
.43526 .64254 L
.4396 .64688 L
.44035 .64737 L
.44015 .6522 L
.43983 .65704 L
.44443 .66164 L
.44504 .66187 L
.44481 .6667 L
.44927 .67116 L
.44992 .67153 L
.44973 .67636 L
.44943 .68119 L
.4541 .68586 L
.45464 .68603 L
.45444 .69086 L
.45893 .69535 L
.45952 .69569 L
.45937 .70052 L
.45917 .70535 L
.46376 .70995 L
.46427 .71019 L
.46413 .71502 L
.46392 .71985 L
.46859 .72453 L
.46902 .72468 L
.4689 .72951 L
.46872 .73434 L
.47342 .73906 L
.47379 .73918 L
.47369 .74401 L
.47356 .74884 L
.47826 .75355 L
.47855 .75367 L
.47848 .7585 L
.47839 .76334 L
.48309 .76806 L
.48329 .76817 L
.48324 .773 L
.48319 .77783 L
.48314 .78266 L
.48792 .78749 L
.48793 .7875 L
.48792 .79227 L
.48786 .79233 L
.48781 .79716 L
.4878 .80199 L
.48309 .80469 L
.48248 .80682 L
.48111 .81165 L
.47978 .81649 L
.47846 .82132 L
.47826 .82209 L
.47719 .82615 L
.47595 .83098 L
.47474 .83581 L
.47355 .84065 L
.47342 .84118 L
.47241 .84548 L
.4713 .85031 L
.47023 .85514 L
.46918 .85997 L
.46859 .86277 L
.46818 .8648 L
.46721 .86964 L
.46628 .87447 L
.46539 .8793 L
.46453 .88413 L
.46376 .88868 L
.46371 .88896 L
.46294 .8938 L
.46221 .89863 L
.46152 .90346 L
.46088 .90829 L
.46028 .91312 L
.45972 .91796 L
.45921 .92279 L
.45893 .92573 L
.45876 .92762 L
.45835 .93245 L
.458 .93728 L
.4577 .94211 L
.45745 .94695 L
.45726 .95178 L
.45714 .95661 L
.45707 .96144 L
.45707 .96627 L
.45714 .97111 L
.45728 .97594 L
.4575 .98077 L
.01923 .98077 L
F
0 g
.01923 .0225 m
.01968 .02406 L
.02406 .0279 L
.02521 .02889 L
.02889 .03257 L
.03018 .03373 L
.03373 .03727 L
.03514 .03856 L
.03856 .04197 L
.04009 .04339 L
.03905 .04822 L
.04339 .05256 L
.04417 .05305 L
.04822 .0571 L
.04922 .05789 L
.05305 .06172 L
.05422 .06272 L
.05789 .06638 L
.0592 .06755 L
.06272 .07106 L
.06417 .07238 L
.06301 .07721 L
.06755 .08175 L
.06825 .08204 L
.07238 .08617 L
.07333 .08688 L
.07721 .09076 L
.07835 .09171 L
.08204 .09539 L
.08335 .09654 L
.08688 .10006 L
.08833 .10137 L
.08728 .1062 L
.09171 .11063 L
.09248 .11104 L
.09654 .11509 L
.09756 .11587 L
.10137 .11968 L
.10258 .1207 L
.1062 .12431 L
.10758 .12553 L
.1063 .13036 L
.11104 .1351 L
.11172 .1352 L
.11587 .13934 L
.11683 .14003 L
.1207 .14389 L
.12188 .14486 L
.12553 .14851 L
.12689 .14969 L
Mistroke
.12566 .15452 L
.13036 .15923 L
.13107 .15935 L
.1352 .16347 L
.13619 .16419 L
.14003 .16802 L
.14124 .16902 L
.14486 .17263 L
.14625 .17385 L
.14529 .17868 L
.14969 .18308 L
.15052 .18351 L
.15452 .18751 L
.15562 .18835 L
.15935 .19208 L
.16066 .19318 L
.16419 .1967 L
.16567 .19801 L
.1649 .20284 L
.16902 .20696 L
.17003 .20767 L
.17385 .21148 L
.17509 .2125 L
.17868 .21608 L
.18012 .21734 L
.17933 .22217 L
.18351 .22635 L
.1845 .227 L
.18835 .23084 L
.18957 .23183 L
.19318 .23543 L
.19461 .23666 L
.19385 .2415 L
.19801 .24565 L
.19901 .24633 L
.20284 .25015 L
.20409 .25116 L
.20767 .25473 L
.20912 .25599 L
.20843 .26082 L
.2125 .26489 L
.21358 .26566 L
.21734 .26941 L
.21865 .27049 L
.21778 .27532 L
.22217 .2797 L
.22306 .28015 L
.227 .28408 L
.22817 .28498 L
.23183 .28863 L
Mistroke
.23323 .28981 L
.23254 .29465 L
.23666 .29877 L
.23771 .29948 L
.2415 .30325 L
.2428 .30431 L
.24201 .30914 L
.24633 .31345 L
.24727 .31397 L
.25116 .31785 L
.25238 .31881 L
.25148 .32364 L
.25599 .32815 L
.25685 .32847 L
.26082 .33243 L
.26199 .3333 L
.26566 .33696 L
.26706 .33813 L
.26646 .34296 L
.27049 .34699 L
.27162 .3478 L
.27532 .35149 L
.2767 .35263 L
.2761 .35746 L
.28015 .3615 L
.28127 .36229 L
.28498 .36599 L
.28636 .36712 L
.28578 .37196 L
.28981 .37598 L
.29095 .37679 L
.29001 .38162 L
.29465 .38626 L
.29549 .38645 L
.29948 .39043 L
.30065 .39128 L
.29988 .39612 L
.30431 .40054 L
.30523 .40095 L
.30914 .40485 L
.31037 .40578 L
.30973 .41061 L
.31397 .41485 L
.31499 .41544 L
.31881 .41925 L
.32011 .42027 L
.31956 .42511 L
.32364 .42917 L
.32476 .42994 L
.32402 .43477 L
Mistroke
.32847 .43922 L
.32939 .4396 L
.3333 .4435 L
.33455 .44443 L
.33397 .44927 L
.33813 .45352 L
.33904 .4541 L
.33842 .45893 L
.34296 .46347 L
.34373 .46376 L
.3478 .46782 L
.34883 .46859 L
.3484 .47342 L
.35263 .47765 L
.35355 .47826 L
.35304 .48309 L
.35746 .48751 L
.35827 .48792 L
.35751 .49275 L
.36229 .49754 L
.36299 .49758 L
.36712 .50171 L
.36811 .50242 L
.36771 .50725 L
.37196 .51148 L
.37286 .51208 L
.37243 .51691 L
.37679 .52126 L
.37762 .52174 L
.37714 .52658 L
.38162 .53105 L
.38239 .53141 L
.38184 .53624 L
.38645 .54085 L
.38717 .54107 L
.39128 .54518 L
.39226 .5459 L
.39196 .55073 L
.39612 .55488 L
.39706 .55557 L
.39675 .5604 L
.40095 .56458 L
.40186 .56523 L
.40156 .57006 L
.40578 .57427 L
.40668 .57489 L
.40638 .57973 L
.41061 .58394 L
.41149 .58456 L
.41122 .58939 L
Mistroke
.41544 .59361 L
.41632 .59422 L
.41606 .59905 L
.41552 .60388 L
.42027 .60864 L
.42091 .60872 L
.4205 .61355 L
.42511 .61815 L
.42577 .61838 L
.42543 .62321 L
.42994 .62771 L
.43063 .62804 L
.43035 .63288 L
.43477 .63729 L
.43549 .63771 L
.43526 .64254 L
.4396 .64688 L
.44035 .64737 L
.44015 .6522 L
.43983 .65704 L
.44443 .66164 L
.44504 .66187 L
.44481 .6667 L
.44927 .67116 L
.44992 .67153 L
.44973 .67636 L
.44943 .68119 L
.4541 .68586 L
.45464 .68603 L
.45444 .69086 L
.45893 .69535 L
.45952 .69569 L
.45937 .70052 L
.45917 .70535 L
.46376 .70995 L
.46427 .71019 L
.46413 .71502 L
.46392 .71985 L
.46859 .72453 L
.46902 .72468 L
.4689 .72951 L
.46872 .73434 L
.47342 .73906 L
.47379 .73918 L
.47369 .74401 L
.47356 .74884 L
.47826 .75355 L
.47855 .75367 L
.47848 .7585 L
.47839 .76334 L
Mistroke
.48309 .76806 L
.48329 .76817 L
.48324 .773 L
.48319 .77783 L
.48314 .78266 L
.48792 .78749 L
.48793 .7875 L
.48792 .79227 L
.48786 .79233 L
.48781 .79716 L
.4878 .80199 L
.48309 .80469 L
.48248 .80682 L
.48111 .81165 L
.47978 .81649 L
.47846 .82132 L
.47826 .82209 L
.47719 .82615 L
.47595 .83098 L
.47474 .83581 L
.47355 .84065 L
.47342 .84118 L
.47241 .84548 L
.4713 .85031 L
.47023 .85514 L
.46918 .85997 L
.46859 .86277 L
.46818 .8648 L
.46721 .86964 L
.46628 .87447 L
.46539 .8793 L
.46453 .88413 L
.46376 .88868 L
.46371 .88896 L
.46294 .8938 L
.46221 .89863 L
.46152 .90346 L
.46088 .90829 L
.46028 .91312 L
.45972 .91796 L
.45921 .92279 L
.45893 .92573 L
.45876 .92762 L
.45835 .93245 L
.458 .93728 L
.4577 .94211 L
.45745 .94695 L
.45726 .95178 L
.45714 .95661 L
.45707 .96144 L
Mistroke
.45707 .96627 L
.45714 .97111 L
.45728 .97594 L
.4575 .98077 L
Mfstroke
0 .37 .27 r
.01923 .02265 m
.01962 .02406 L
.02406 .02802 L
.02508 .02889 L
.02889 .03271 L
.03003 .03373 L
.03373 .03742 L
.03497 .03856 L
.03856 .04214 L
.03991 .04339 L
.03899 .04822 L
.04339 .05262 L
.04408 .05305 L
.04822 .05719 L
.0491 .05789 L
.05305 .06184 L
.05408 .06272 L
.05789 .06651 L
.05905 .06755 L
.06272 .07121 L
.064 .07238 L
.06298 .07721 L
.06755 .08179 L
.06817 .08204 L
.07238 .08626 L
.07322 .08688 L
.07721 .09087 L
.07822 .09171 L
.08204 .09553 L
.0832 .09654 L
.08688 .10021 L
.08816 .10137 L
.08723 .1062 L
.09171 .11068 L
.09239 .11104 L
.09654 .11518 L
.09744 .11587 L
.10137 .1198 L
.10244 .1207 L
.1062 .12446 L
.10742 .12553 L
.10628 .13036 L
.11104 .13511 L
.11164 .1352 L
.11587 .13942 L
.11672 .14003 L
.1207 .144 L
.12174 .14486 L
.12553 .14864 L
.12673 .14969 L
.12564 .15452 L
.13036 .15924 L
.13099 .15935 L
.1352 .16356 L
.13607 .16419 L
.14003 .16814 L
.1411 .16902 L
.14486 .17277 L
.14609 .17385 L
.14523 .17868 L
.14969 .18314 L
.15042 .18351 L
.15452 .18761 L
.15549 .18835 L
.15935 .19221 L
.1605 .19318 L
.16419 .19685 L
.16549 .19801 L
.16481 .20284 L
.16902 .20704 L
.16991 .20767 L
.17385 .2116 L
.17495 .2125 L
.17868 .21623 L
.17995 .21734 L
.17925 .22217 L
.18351 .22642 L
.18438 .227 L
.18835 .23096 L
.18943 .23183 L
.19318 .23557 L
.19444 .23666 L
.19377 .2415 L
.19801 .24573 L
.1989 .24633 L
.20284 .25027 L
.20395 .25116 L
.20767 .25488 L
.20896 .25599 L
.20834 .26082 L
.2125 .26498 L
.21345 .26566 L
.21734 .26953 L
.21849 .27049 L
.21773 .27532 L
.22217 .27976 L
.22295 .28015 L
.227 .28419 L
.22804 .28498 L
.23183 .28877 L
.23307 .28981 L
.23245 .29465 L
.23666 .29885 L
.23759 .29948 L
.2415 .30337 L
.24265 .30431 L
.24195 .30914 L
.24633 .31351 L
.24716 .31397 L
.25116 .31797 L
.25224 .31881 L
.25144 .32364 L
.25599 .32819 L
.25675 .32847 L
.26082 .33254 L
.26185 .3333 L
.26566 .33709 L
.2669 .33813 L
.26636 .34296 L
.27049 .34708 L
.27149 .3478 L
.27532 .35162 L
.27654 .35263 L
.27601 .35746 L
.28015 .3616 L
.28114 .36229 L
.28498 .36612 L
.2862 .36712 L
.28568 .37196 L
.28981 .37608 L
.29082 .37679 L
.28999 .38162 L
.29465 .38628 L
.29539 .38645 L
.29948 .39053 L
.30051 .39128 L
.29983 .39612 L
.30431 .40059 L
.30512 .40095 L
.30914 .40496 L
.31023 .40578 L
.30966 .41061 L
.31397 .41492 L
.31487 .41544 L
.31881 .41937 L
.31996 .42027 L
.31947 .42511 L
.32364 .42926 L
.32463 .42994 L
.32397 .43477 L
.32847 .43926 L
.32928 .4396 L
.3333 .44361 L
.3344 .44443 L
.33389 .44927 L
.33813 .4536 L
.33891 .4541 L
.33838 .45893 L
.34296 .46352 L
.34362 .46376 L
.3478 .46793 L
.34868 .46859 L
.34831 .47342 L
.35263 .47774 L
.35342 .47826 L
.35298 .48309 L
.35746 .48757 L
.35815 .48792 L
.3575 .49275 L
.36229 .49754 L
.36289 .49758 L
.36712 .50181 L
.36796 .50242 L
.36762 .50725 L
.37196 .51157 L
.37273 .51208 L
.37236 .51691 L
.37679 .52134 L
.3775 .52174 L
.37709 .52658 L
.38162 .5311 L
.38228 .53141 L
.38181 .53624 L
.38645 .54088 L
.38706 .54107 L
.39128 .54529 L
.39211 .5459 L
.39185 .55073 L
.39612 .55499 L
.39691 .55557 L
.39665 .5604 L
.40095 .56468 L
.40172 .56523 L
.40147 .57006 L
.40578 .57437 L
.40654 .57489 L
.40629 .57973 L
.41061 .58404 L
.41135 .58456 L
.41112 .58939 L
.41544 .59371 L
.41618 .59422 L
.41596 .59905 L
.41551 .60388 L
.42027 .60865 L
.42081 .60872 L
.42046 .61355 L
.42511 .61819 L
.42566 .61838 L
.42538 .62321 L
.42994 .62777 L
.43051 .62804 L
.43028 .63288 L
.43477 .63737 L
.43537 .63771 L
.43517 .64254 L
.4396 .64697 L
.44022 .64737 L
.44005 .6522 L
.43979 .65704 L
.44443 .66168 L
.44493 .66187 L
.44474 .6667 L
.44927 .67123 L
.44979 .67153 L
.44964 .67636 L
.4494 .68119 L
.4541 .6859 L
.45453 .68603 L
.45437 .69086 L
.45893 .69542 L
.45939 .69569 L
.45928 .70052 L
.45911 .70535 L
.46376 .71001 L
.46415 .71019 L
.46404 .71502 L
.46388 .71985 L
.46859 .72457 L
.46892 .72468 L
.46882 .72951 L
.46869 .73434 L
.47342 .73909 L
.47368 .73918 L
.47361 .74401 L
.47352 .74884 L
.47826 .7536 L
.47844 .75367 L
.47839 .7585 L
.47834 .76334 L
.48309 .76812 L
.48317 .76817 L
.48314 .773 L
.48311 .77783 L
.48309 .78266 L
.48309 .78539 L
.48241 .7875 L
.48088 .79233 L
.47937 .79716 L
.47826 .80079 L
.47789 .80199 L
.47645 .80682 L
.47502 .81165 L
.47363 .81649 L
.47342 .81719 L
.47227 .82132 L
.47093 .82615 L
.46963 .83098 L
.46859 .83489 L
.46835 .83581 L
.46711 .84065 L
.4659 .84548 L
.46472 .85031 L
.46376 .85434 L
.46357 .85514 L
.46246 .85997 L
.46138 .8648 L
.46034 .86964 L
.45933 .87447 L
.45893 .87641 L
.45835 .8793 L
.45741 .88413 L
.45651 .88896 L
.45564 .8938 L
.45482 .89863 L
.4541 .90302 L
.45403 .90346 L
.45328 .90829 L
.45257 .91312 L
.45191 .91796 L
.45128 .92279 L
.4507 .92762 L
.45017 .93245 L
.44968 .93728 L
.44927 .94177 L
.44924 .94211 L
.44884 .94695 L
.4485 .95178 L
.44821 .95661 L
.44797 .96144 L
.44778 .96627 L
.44765 .97111 L
.44759 .97594 L
.44758 .98077 L
.01923 .98077 L
F
0 g
.01923 .02265 m
.01962 .02406 L
.02406 .02802 L
.02508 .02889 L
.02889 .03271 L
.03003 .03373 L
.03373 .03742 L
.03497 .03856 L
.03856 .04214 L
.03991 .04339 L
.03899 .04822 L
.04339 .05262 L
.04408 .05305 L
.04822 .05719 L
.0491 .05789 L
.05305 .06184 L
.05408 .06272 L
.05789 .06651 L
.05905 .06755 L
.06272 .07121 L
.064 .07238 L
.06298 .07721 L
.06755 .08179 L
.06817 .08204 L
.07238 .08626 L
.07322 .08688 L
.07721 .09087 L
.07822 .09171 L
.08204 .09553 L
.0832 .09654 L
.08688 .10021 L
.08816 .10137 L
.08723 .1062 L
.09171 .11068 L
.09239 .11104 L
.09654 .11518 L
.09744 .11587 L
.10137 .1198 L
.10244 .1207 L
.1062 .12446 L
.10742 .12553 L
.10628 .13036 L
.11104 .13511 L
.11164 .1352 L
.11587 .13942 L
.11672 .14003 L
.1207 .144 L
.12174 .14486 L
.12553 .14864 L
.12673 .14969 L
Mistroke
.12564 .15452 L
.13036 .15924 L
.13099 .15935 L
.1352 .16356 L
.13607 .16419 L
.14003 .16814 L
.1411 .16902 L
.14486 .17277 L
.14609 .17385 L
.14523 .17868 L
.14969 .18314 L
.15042 .18351 L
.15452 .18761 L
.15549 .18835 L
.15935 .19221 L
.1605 .19318 L
.16419 .19685 L
.16549 .19801 L
.16481 .20284 L
.16902 .20704 L
.16991 .20767 L
.17385 .2116 L
.17495 .2125 L
.17868 .21623 L
.17995 .21734 L
.17925 .22217 L
.18351 .22642 L
.18438 .227 L
.18835 .23096 L
.18943 .23183 L
.19318 .23557 L
.19444 .23666 L
.19377 .2415 L
.19801 .24573 L
.1989 .24633 L
.20284 .25027 L
.20395 .25116 L
.20767 .25488 L
.20896 .25599 L
.20834 .26082 L
.2125 .26498 L
.21345 .26566 L
.21734 .26953 L
.21849 .27049 L
.21773 .27532 L
.22217 .27976 L
.22295 .28015 L
.227 .28419 L
.22804 .28498 L
.23183 .28877 L
Mistroke
.23307 .28981 L
.23245 .29465 L
.23666 .29885 L
.23759 .29948 L
.2415 .30337 L
.24265 .30431 L
.24195 .30914 L
.24633 .31351 L
.24716 .31397 L
.25116 .31797 L
.25224 .31881 L
.25144 .32364 L
.25599 .32819 L
.25675 .32847 L
.26082 .33254 L
.26185 .3333 L
.26566 .33709 L
.2669 .33813 L
.26636 .34296 L
.27049 .34708 L
.27149 .3478 L
.27532 .35162 L
.27654 .35263 L
.27601 .35746 L
.28015 .3616 L
.28114 .36229 L
.28498 .36612 L
.2862 .36712 L
.28568 .37196 L
.28981 .37608 L
.29082 .37679 L
.28999 .38162 L
.29465 .38628 L
.29539 .38645 L
.29948 .39053 L
.30051 .39128 L
.29983 .39612 L
.30431 .40059 L
.30512 .40095 L
.30914 .40496 L
.31023 .40578 L
.30966 .41061 L
.31397 .41492 L
.31487 .41544 L
.31881 .41937 L
.31996 .42027 L
.31947 .42511 L
.32364 .42926 L
.32463 .42994 L
.32397 .43477 L
Mistroke
.32847 .43926 L
.32928 .4396 L
.3333 .44361 L
.3344 .44443 L
.33389 .44927 L
.33813 .4536 L
.33891 .4541 L
.33838 .45893 L
.34296 .46352 L
.34362 .46376 L
.3478 .46793 L
.34868 .46859 L
.34831 .47342 L
.35263 .47774 L
.35342 .47826 L
.35298 .48309 L
.35746 .48757 L
.35815 .48792 L
.3575 .49275 L
.36229 .49754 L
.36289 .49758 L
.36712 .50181 L
.36796 .50242 L
.36762 .50725 L
.37196 .51157 L
.37273 .51208 L
.37236 .51691 L
.37679 .52134 L
.3775 .52174 L
.37709 .52658 L
.38162 .5311 L
.38228 .53141 L
.38181 .53624 L
.38645 .54088 L
.38706 .54107 L
.39128 .54529 L
.39211 .5459 L
.39185 .55073 L
.39612 .55499 L
.39691 .55557 L
.39665 .5604 L
.40095 .56468 L
.40172 .56523 L
.40147 .57006 L
.40578 .57437 L
.40654 .57489 L
.40629 .57973 L
.41061 .58404 L
.41135 .58456 L
.41112 .58939 L
Mistroke
.41544 .59371 L
.41618 .59422 L
.41596 .59905 L
.41551 .60388 L
.42027 .60865 L
.42081 .60872 L
.42046 .61355 L
.42511 .61819 L
.42566 .61838 L
.42538 .62321 L
.42994 .62777 L
.43051 .62804 L
.43028 .63288 L
.43477 .63737 L
.43537 .63771 L
.43517 .64254 L
.4396 .64697 L
.44022 .64737 L
.44005 .6522 L
.43979 .65704 L
.44443 .66168 L
.44493 .66187 L
.44474 .6667 L
.44927 .67123 L
.44979 .67153 L
.44964 .67636 L
.4494 .68119 L
.4541 .6859 L
.45453 .68603 L
.45437 .69086 L
.45893 .69542 L
.45939 .69569 L
.45928 .70052 L
.45911 .70535 L
.46376 .71001 L
.46415 .71019 L
.46404 .71502 L
.46388 .71985 L
.46859 .72457 L
.46892 .72468 L
.46882 .72951 L
.46869 .73434 L
.47342 .73909 L
.47368 .73918 L
.47361 .74401 L
.47352 .74884 L
.47826 .7536 L
.47844 .75367 L
.47839 .7585 L
.47834 .76334 L
Mistroke
.48309 .76812 L
.48317 .76817 L
.48314 .773 L
.48311 .77783 L
.48309 .78266 L
.48309 .78539 L
.48241 .7875 L
.48088 .79233 L
.47937 .79716 L
.47826 .80079 L
.47789 .80199 L
.47645 .80682 L
.47502 .81165 L
.47363 .81649 L
.47342 .81719 L
.47227 .82132 L
.47093 .82615 L
.46963 .83098 L
.46859 .83489 L
.46835 .83581 L
.46711 .84065 L
.4659 .84548 L
.46472 .85031 L
.46376 .85434 L
.46357 .85514 L
.46246 .85997 L
.46138 .8648 L
.46034 .86964 L
.45933 .87447 L
.45893 .87641 L
.45835 .8793 L
.45741 .88413 L
.45651 .88896 L
.45564 .8938 L
.45482 .89863 L
.4541 .90302 L
.45403 .90346 L
.45328 .90829 L
.45257 .91312 L
.45191 .91796 L
.45128 .92279 L
.4507 .92762 L
.45017 .93245 L
.44968 .93728 L
.44927 .94177 L
.44924 .94211 L
.44884 .94695 L
.4485 .95178 L
.44821 .95661 L
.44797 .96144 L
Mistroke
.44778 .96627 L
.44765 .97111 L
.44759 .97594 L
.44758 .98077 L
Mfstroke
0 .325 .301 r
.01923 .0228 m
.01956 .02406 L
.02406 .02814 L
.02494 .02889 L
.02889 .03285 L
.02988 .03373 L
.03373 .03757 L
.03481 .03856 L
.03856 .0423 L
.03973 .04339 L
.03893 .04822 L
.04339 .05268 L
.04399 .05305 L
.04822 .05729 L
.04898 .05789 L
.05305 .06196 L
.05395 .06272 L
.05789 .06665 L
.05889 .06755 L
.06272 .07137 L
.06383 .07238 L
.06294 .07721 L
.06755 .08182 L
.06808 .08204 L
.07238 .08634 L
.0731 .08688 L
.07721 .09098 L
.07808 .09171 L
.08204 .09566 L
.08304 .09654 L
.08688 .10037 L
.08799 .10137 L
.08718 .1062 L
.09171 .11073 L
.0923 .11104 L
.09654 .11528 L
.09732 .11587 L
.10137 .11992 L
.1023 .1207 L
.1062 .1246 L
.10726 .12553 L
.10627 .13036 L
.11104 .13513 L
.11156 .1352 L
.11587 .1395 L
.1166 .14003 L
.1207 .14412 L
.1216 .14486 L
.12553 .14878 L
.12657 .14969 L
.12563 .15452 L
.13036 .15926 L
.1309 .15935 L
.1352 .16364 L
.13595 .16419 L
.14003 .16826 L
.14095 .16902 L
.14486 .17292 L
.14593 .17385 L
.14518 .17868 L
.14969 .18319 L
.15032 .18351 L
.15452 .18771 L
.15536 .18835 L
.15935 .19234 L
.16035 .19318 L
.16419 .19701 L
.16532 .19801 L
.16473 .20284 L
.16902 .20713 L
.16979 .20767 L
.17385 .21172 L
.1748 .2125 L
.17868 .21638 L
.17978 .21734 L
.17918 .22217 L
.18351 .2265 L
.18426 .227 L
.18835 .23108 L
.18928 .23183 L
.19318 .23572 L
.19427 .23666 L
.19369 .2415 L
.19801 .24582 L
.19878 .24633 L
.20284 .25039 L
.2038 .25116 L
.20767 .25503 L
.20879 .25599 L
.20825 .26082 L
.2125 .26508 L
.21332 .26566 L
.21734 .26966 L
.21834 .27049 L
.21767 .27532 L
.22217 .27981 L
.22285 .28015 L
.227 .2843 L
.2279 .28498 L
.23183 .28891 L
.2329 .28981 L
.23237 .29465 L
.23666 .29894 L
.23747 .29948 L
.2415 .3035 L
.24249 .30431 L
.24189 .30914 L
.24633 .31358 L
.24705 .31397 L
.25116 .31808 L
.2521 .31881 L
.2514 .32364 L
.25599 .32823 L
.25664 .32847 L
.26082 .33264 L
.26171 .3333 L
.26566 .33723 L
.26673 .33813 L
.26627 .34296 L
.27049 .34718 L
.27135 .3478 L
.27532 .35175 L
.27637 .35263 L
.27591 .35746 L
.28015 .36169 L
.28101 .36229 L
.28498 .36626 L
.28603 .36712 L
.28559 .37196 L
.28981 .37618 L
.29068 .37679 L
.28996 .38162 L
.29465 .3863 L
.29529 .38645 L
.29948 .39063 L
.30037 .39128 L
.29978 .39612 L
.30431 .40064 L
.30501 .40095 L
.30914 .40507 L
.31008 .40578 L
.30959 .41061 L
.31397 .41499 L
.31475 .41544 L
.31881 .41949 L
.3198 .42027 L
.31938 .42511 L
.32364 .42936 L
.32449 .42994 L
.32393 .43477 L
.32847 .43931 L
.32917 .4396 L
.3333 .44372 L
.33425 .44443 L
.33381 .44927 L
.33813 .45369 L
.33878 .4541 L
.33833 .45893 L
.34296 .46356 L
.34351 .46376 L
.3478 .46805 L
.34853 .46859 L
.34822 .47342 L
.35263 .47783 L
.35328 .47826 L
.35292 .48309 L
.35746 .48763 L
.35803 .48792 L
.35749 .49275 L
.36229 .49755 L
.36278 .49758 L
.36712 .50192 L
.36782 .50242 L
.36754 .50725 L
.37196 .51166 L
.37259 .51208 L
.37229 .51691 L
.37679 .52141 L
.37737 .52174 L
.37703 .52658 L
.38162 .53116 L
.38216 .53141 L
.38177 .53624 L
.38645 .54092 L
.38695 .54107 L
.39128 .5454 L
.39196 .5459 L
.39175 .55073 L
.39612 .5551 L
.39677 .55557 L
.39655 .5604 L
.40095 .56479 L
.40158 .56523 L
.40137 .57006 L
.40578 .57447 L
.40639 .57489 L
.40619 .57973 L
.41061 .58414 L
.41121 .58456 L
.41102 .58939 L
.41544 .59381 L
.41604 .59422 L
.41586 .59905 L
.41549 .60388 L
.42027 .60867 L
.4207 .60872 L
.42042 .61355 L
.42511 .61823 L
.42555 .61838 L
.42532 .62321 L
.42994 .62783 L
.43039 .62804 L
.43021 .63288 L
.43477 .63744 L
.43524 .63771 L
.43508 .64254 L
.4396 .64706 L
.44008 .64737 L
.43995 .6522 L
.43975 .65704 L
.44443 .66172 L
.44481 .66187 L
.44466 .6667 L
.44927 .6713 L
.44967 .67153 L
.44955 .67636 L
.44936 .68119 L
.4541 .68593 L
.45442 .68603 L
.4543 .69086 L
.45893 .69549 L
.45927 .69569 L
.45918 .70052 L
.45906 .70535 L
.46376 .71006 L
.46403 .71019 L
.46395 .71502 L
.46384 .71985 L
.46859 .72461 L
.4688 .72468 L
.46874 .72951 L
.46865 .73434 L
.47342 .73913 L
.47357 .73918 L
.47353 .74401 L
.47347 .74884 L
.47826 .75364 L
.47833 .75367 L
.4783 .7585 L
.47828 .76334 L
.48301 .76817 L
.48297 .773 L
.47826 .7748 L
.47721 .77783 L
.47556 .78266 L
.47394 .7875 L
.47342 .78903 L
.47234 .79233 L
.47077 .79716 L
.46922 .80199 L
.46859 .80398 L
.4677 .80682 L
.46621 .81165 L
.46475 .81649 L
.46376 .81979 L
.46331 .82132 L
.4619 .82615 L
.46052 .83098 L
.45917 .83581 L
.45893 .83669 L
.45785 .84065 L
.45656 .84548 L
.45529 .85031 L
.4541 .85498 L
.45406 .85514 L
.45286 .85997 L
.45168 .8648 L
.45054 .86964 L
.44944 .87447 L
.44927 .87522 L
.44836 .8793 L
.44732 .88413 L
.44631 .88896 L
.44533 .8938 L
.44443 .89841 L
.44439 .89863 L
.44349 .90346 L
.44262 .90829 L
.44178 .91312 L
.44099 .91796 L
.44023 .92279 L
.4396 .92699 L
.43951 .92762 L
.43883 .93245 L
.43819 .93728 L
.43759 .94211 L
.43703 .94695 L
.43652 .95178 L
.43605 .95661 L
.43562 .96144 L
.43524 .96627 L
.43491 .97111 L
.43477 .97339 L
.43463 .97594 L
.43439 .98077 L
.01923 .98077 L
F
0 g
.01923 .0228 m
.01956 .02406 L
.02406 .02814 L
.02494 .02889 L
.02889 .03285 L
.02988 .03373 L
.03373 .03757 L
.03481 .03856 L
.03856 .0423 L
.03973 .04339 L
.03893 .04822 L
.04339 .05268 L
.04399 .05305 L
.04822 .05729 L
.04898 .05789 L
.05305 .06196 L
.05395 .06272 L
.05789 .06665 L
.05889 .06755 L
.06272 .07137 L
.06383 .07238 L
.06294 .07721 L
.06755 .08182 L
.06808 .08204 L
.07238 .08634 L
.0731 .08688 L
.07721 .09098 L
.07808 .09171 L
.08204 .09566 L
.08304 .09654 L
.08688 .10037 L
.08799 .10137 L
.08718 .1062 L
.09171 .11073 L
.0923 .11104 L
.09654 .11528 L
.09732 .11587 L
.10137 .11992 L
.1023 .1207 L
.1062 .1246 L
.10726 .12553 L
.10627 .13036 L
.11104 .13513 L
.11156 .1352 L
.11587 .1395 L
.1166 .14003 L
.1207 .14412 L
.1216 .14486 L
.12553 .14878 L
.12657 .14969 L
Mistroke
.12563 .15452 L
.13036 .15926 L
.1309 .15935 L
.1352 .16364 L
.13595 .16419 L
.14003 .16826 L
.14095 .16902 L
.14486 .17292 L
.14593 .17385 L
.14518 .17868 L
.14969 .18319 L
.15032 .18351 L
.15452 .18771 L
.15536 .18835 L
.15935 .19234 L
.16035 .19318 L
.16419 .19701 L
.16532 .19801 L
.16473 .20284 L
.16902 .20713 L
.16979 .20767 L
.17385 .21172 L
.1748 .2125 L
.17868 .21638 L
.17978 .21734 L
.17918 .22217 L
.18351 .2265 L
.18426 .227 L
.18835 .23108 L
.18928 .23183 L
.19318 .23572 L
.19427 .23666 L
.19369 .2415 L
.19801 .24582 L
.19878 .24633 L
.20284 .25039 L
.2038 .25116 L
.20767 .25503 L
.20879 .25599 L
.20825 .26082 L
.2125 .26508 L
.21332 .26566 L
.21734 .26966 L
.21834 .27049 L
.21767 .27532 L
.22217 .27981 L
.22285 .28015 L
.227 .2843 L
.2279 .28498 L
.23183 .28891 L
Mistroke
.2329 .28981 L
.23237 .29465 L
.23666 .29894 L
.23747 .29948 L
.2415 .3035 L
.24249 .30431 L
.24189 .30914 L
.24633 .31358 L
.24705 .31397 L
.25116 .31808 L
.2521 .31881 L
.2514 .32364 L
.25599 .32823 L
.25664 .32847 L
.26082 .33264 L
.26171 .3333 L
.26566 .33723 L
.26673 .33813 L
.26627 .34296 L
.27049 .34718 L
.27135 .3478 L
.27532 .35175 L
.27637 .35263 L
.27591 .35746 L
.28015 .36169 L
.28101 .36229 L
.28498 .36626 L
.28603 .36712 L
.28559 .37196 L
.28981 .37618 L
.29068 .37679 L
.28996 .38162 L
.29465 .3863 L
.29529 .38645 L
.29948 .39063 L
.30037 .39128 L
.29978 .39612 L
.30431 .40064 L
.30501 .40095 L
.30914 .40507 L
.31008 .40578 L
.30959 .41061 L
.31397 .41499 L
.31475 .41544 L
.31881 .41949 L
.3198 .42027 L
.31938 .42511 L
.32364 .42936 L
.32449 .42994 L
.32393 .43477 L
Mistroke
.32847 .43931 L
.32917 .4396 L
.3333 .44372 L
.33425 .44443 L
.33381 .44927 L
.33813 .45369 L
.33878 .4541 L
.33833 .45893 L
.34296 .46356 L
.34351 .46376 L
.3478 .46805 L
.34853 .46859 L
.34822 .47342 L
.35263 .47783 L
.35328 .47826 L
.35292 .48309 L
.35746 .48763 L
.35803 .48792 L
.35749 .49275 L
.36229 .49755 L
.36278 .49758 L
.36712 .50192 L
.36782 .50242 L
.36754 .50725 L
.37196 .51166 L
.37259 .51208 L
.37229 .51691 L
.37679 .52141 L
.37737 .52174 L
.37703 .52658 L
.38162 .53116 L
.38216 .53141 L
.38177 .53624 L
.38645 .54092 L
.38695 .54107 L
.39128 .5454 L
.39196 .5459 L
.39175 .55073 L
.39612 .5551 L
.39677 .55557 L
.39655 .5604 L
.40095 .56479 L
.40158 .56523 L
.40137 .57006 L
.40578 .57447 L
.40639 .57489 L
.40619 .57973 L
.41061 .58414 L
.41121 .58456 L
.41102 .58939 L
Mistroke
.41544 .59381 L
.41604 .59422 L
.41586 .59905 L
.41549 .60388 L
.42027 .60867 L
.4207 .60872 L
.42042 .61355 L
.42511 .61823 L
.42555 .61838 L
.42532 .62321 L
.42994 .62783 L
.43039 .62804 L
.43021 .63288 L
.43477 .63744 L
.43524 .63771 L
.43508 .64254 L
.4396 .64706 L
.44008 .64737 L
.43995 .6522 L
.43975 .65704 L
.44443 .66172 L
.44481 .66187 L
.44466 .6667 L
.44927 .6713 L
.44967 .67153 L
.44955 .67636 L
.44936 .68119 L
.4541 .68593 L
.45442 .68603 L
.4543 .69086 L
.45893 .69549 L
.45927 .69569 L
.45918 .70052 L
.45906 .70535 L
.46376 .71006 L
.46403 .71019 L
.46395 .71502 L
.46384 .71985 L
.46859 .72461 L
.4688 .72468 L
.46874 .72951 L
.46865 .73434 L
.47342 .73913 L
.47357 .73918 L
.47353 .74401 L
.47347 .74884 L
.47826 .75364 L
.47833 .75367 L
.4783 .7585 L
.47828 .76334 L
Mistroke
.48301 .76817 L
.48297 .773 L
.47826 .7748 L
.47721 .77783 L
.47556 .78266 L
.47394 .7875 L
.47342 .78903 L
.47234 .79233 L
.47077 .79716 L
.46922 .80199 L
.46859 .80398 L
.4677 .80682 L
.46621 .81165 L
.46475 .81649 L
.46376 .81979 L
.46331 .82132 L
.4619 .82615 L
.46052 .83098 L
.45917 .83581 L
.45893 .83669 L
.45785 .84065 L
.45656 .84548 L
.45529 .85031 L
.4541 .85498 L
.45406 .85514 L
.45286 .85997 L
.45168 .8648 L
.45054 .86964 L
.44944 .87447 L
.44927 .87522 L
.44836 .8793 L
.44732 .88413 L
.44631 .88896 L
.44533 .8938 L
.44443 .89841 L
.44439 .89863 L
.44349 .90346 L
.44262 .90829 L
.44178 .91312 L
.44099 .91796 L
.44023 .92279 L
.4396 .92699 L
.43951 .92762 L
.43883 .93245 L
.43819 .93728 L
.43759 .94211 L
.43703 .94695 L
.43652 .95178 L
.43605 .95661 L
.43562 .96144 L
Mistroke
.43524 .96627 L
.43491 .97111 L
.43477 .97339 L
.43463 .97594 L
.43439 .98077 L
Mfstroke
0 .246 .28 r
.01923 .02296 m
.01951 .02406 L
.02406 .02826 L
.0248 .02889 L
.02889 .03298 L
.02972 .03373 L
.03373 .03772 L
.03464 .03856 L
.03856 .04247 L
.03955 .04339 L
.03887 .04822 L
.04339 .05274 L
.04389 .05305 L
.04822 .05738 L
.04886 .05789 L
.05305 .06208 L
.05381 .06272 L
.05789 .06679 L
.05874 .06755 L
.06272 .07153 L
.06366 .07238 L
.0629 .07721 L
.06755 .08186 L
.068 .08204 L
.07238 .08643 L
.07299 .08688 L
.07721 .0911 L
.07795 .09171 L
.08204 .0958 L
.08289 .09654 L
.08688 .10052 L
.08782 .10137 L
.08713 .1062 L
.09171 .11078 L
.0922 .11104 L
.09654 .11537 L
.09719 .11587 L
.10137 .12004 L
.10215 .1207 L
.1062 .12475 L
.10709 .12553 L
.10626 .13036 L
.11104 .13514 L
.11147 .1352 L
.11587 .13959 L
.11649 .14003 L
.1207 .14424 L
.12146 .14486 L
.12553 .14893 L
.12641 .14969 L
.12561 .15452 L
.13036 .15927 L
.13082 .15935 L
.1352 .16373 L
.13583 .16419 L
.14003 .16838 L
.14081 .16902 L
.14486 .17306 L
.14576 .17385 L
.14513 .17868 L
.14969 .18324 L
.15022 .18351 L
.15452 .18781 L
.15523 .18835 L
.15935 .19247 L
.16019 .19318 L
.16419 .19716 L
.16514 .19801 L
.16464 .20284 L
.16902 .20722 L
.16967 .20767 L
.17385 .21185 L
.17465 .2125 L
.17868 .21653 L
.17961 .21734 L
.1791 .22217 L
.18351 .22658 L
.18415 .227 L
.18835 .2312 L
.18914 .23183 L
.19318 .23587 L
.1941 .23666 L
.1936 .2415 L
.19801 .2459 L
.19865 .24633 L
.20284 .25051 L
.20365 .25116 L
.20767 .25518 L
.20861 .25599 L
.20816 .26082 L
.2125 .26517 L
.21319 .26566 L
.21734 .26979 L
.21818 .27049 L
.21762 .27532 L
.22217 .27987 L
.22274 .28015 L
.227 .28441 L
.22776 .28498 L
.23183 .28905 L
.23274 .28981 L
.23228 .29465 L
.23666 .29902 L
.23734 .29948 L
.2415 .30363 L
.24234 .30431 L
.24183 .30914 L
.24633 .31364 L
.24693 .31397 L
.25116 .31819 L
.25195 .31881 L
.25136 .32364 L
.25599 .32827 L
.25654 .32847 L
.26082 .33275 L
.26157 .3333 L
.26566 .33737 L
.26656 .33813 L
.26617 .34296 L
.27049 .34728 L
.27121 .3478 L
.27532 .35189 L
.27621 .35263 L
.27582 .35746 L
.28015 .36179 L
.28087 .36229 L
.28498 .36639 L
.28587 .36712 L
.28549 .37196 L
.28981 .37627 L
.29054 .37679 L
.28994 .38162 L
.29465 .38633 L
.29519 .38645 L
.29948 .39074 L
.30023 .39128 L
.29973 .39612 L
.30431 .40069 L
.3049 .40095 L
.30914 .40518 L
.30993 .40578 L
.30951 .41061 L
.31397 .41507 L
.31462 .41544 L
.31881 .41961 L
.31965 .42027 L
.31929 .42511 L
.32364 .42945 L
.32436 .42994 L
.32388 .43477 L
.32847 .43936 L
.32906 .4396 L
.3333 .44383 L
.3341 .44443 L
.33373 .44927 L
.33813 .45377 L
.33865 .4541 L
.33829 .45893 L
.34296 .4636 L
.34339 .46376 L
.3478 .46816 L
.34838 .46859 L
.34813 .47342 L
.35263 .47792 L
.35315 .47826 L
.35285 .48309 L
.35746 .48769 L
.35791 .48792 L
.35749 .49275 L
.36229 .49756 L
.36268 .49758 L
.36712 .50203 L
.36767 .50242 L
.36745 .50725 L
.37196 .51175 L
.37245 .51208 L
.37221 .51691 L
.37679 .52148 L
.37724 .52174 L
.37698 .52658 L
.38162 .53122 L
.38204 .53141 L
.38174 .53624 L
.38645 .54095 L
.38684 .54107 L
.39128 .54551 L
.39181 .5459 L
.39164 .55073 L
.39612 .55521 L
.39662 .55557 L
.39645 .5604 L
.40095 .56489 L
.40143 .56523 L
.40127 .57006 L
.40578 .57457 L
.40625 .57489 L
.40609 .57973 L
.41061 .58424 L
.41107 .58456 L
.41092 .58939 L
.41544 .59391 L
.41589 .59422 L
.41575 .59905 L
.41548 .60388 L
.42027 .60868 L
.42059 .60872 L
.42038 .61355 L
.42511 .61827 L
.42543 .61838 L
.42526 .62321 L
.42994 .62789 L
.43027 .62804 L
.43013 .63288 L
.43477 .63752 L
.43511 .63771 L
.43499 .64254 L
.4396 .64715 L
.43994 .64737 L
.43985 .6522 L
.4397 .65704 L
.44443 .66177 L
.4447 .66187 L
.44459 .6667 L
.44927 .67138 L
.44954 .67153 L
.44946 .67636 L
.44933 .68119 L
.4541 .68596 L
.4543 .68603 L
.45423 .69086 L
.45893 .69557 L
.45914 .69569 L
.45908 .70052 L
.45901 .70535 L
.46376 .71012 L
.46391 .71019 L
.46387 .71502 L
.4638 .71985 L
.46859 .72465 L
.46869 .72468 L
.46866 .72951 L
.46862 .73434 L
.47342 .73916 L
.47346 .73918 L
.47344 .74401 L
.47343 .74884 L
.47342 .75333 L
.47329 .75367 L
.47144 .7585 L
.46962 .76334 L
.46859 .76607 L
.46781 .76817 L
.46604 .773 L
.46428 .77783 L
.46376 .77927 L
.46255 .78266 L
.46084 .7875 L
.45916 .79233 L
.45893 .79298 L
.4575 .79716 L
.45586 .80199 L
.45425 .80682 L
.4541 .80729 L
.45267 .81165 L
.45111 .81649 L
.44958 .82132 L
.44927 .8223 L
.44807 .82615 L
.44659 .83098 L
.44513 .83581 L
.44443 .83817 L
.4437 .84065 L
.4423 .84548 L
.44093 .85031 L
.4396 .85508 L
.43958 .85514 L
.43827 .85997 L
.43698 .8648 L
.43572 .86964 L
.43477 .87334 L
.43448 .87447 L
.43328 .8793 L
.43211 .88413 L
.43097 .88896 L
.42994 .89343 L
.42986 .8938 L
.42877 .89863 L
.42773 .90346 L
.42671 .90829 L
.42572 .91312 L
.42511 .91622 L
.42477 .91796 L
.42385 .92279 L
.42296 .92762 L
.42211 .93245 L
.42129 .93728 L
.42051 .94211 L
.42027 .94363 L
.41977 .94695 L
.41906 .95178 L
.41839 .95661 L
.41775 .96144 L
.41716 .96627 L
.4166 .97111 L
.41609 .97594 L
.41561 .98077 L
.01923 .98077 L
F
0 g
.01923 .02296 m
.01951 .02406 L
.02406 .02826 L
.0248 .02889 L
.02889 .03298 L
.02972 .03373 L
.03373 .03772 L
.03464 .03856 L
.03856 .04247 L
.03955 .04339 L
.03887 .04822 L
.04339 .05274 L
.04389 .05305 L
.04822 .05738 L
.04886 .05789 L
.05305 .06208 L
.05381 .06272 L
.05789 .06679 L
.05874 .06755 L
.06272 .07153 L
.06366 .07238 L
.0629 .07721 L
.06755 .08186 L
.068 .08204 L
.07238 .08643 L
.07299 .08688 L
.07721 .0911 L
.07795 .09171 L
.08204 .0958 L
.08289 .09654 L
.08688 .10052 L
.08782 .10137 L
.08713 .1062 L
.09171 .11078 L
.0922 .11104 L
.09654 .11537 L
.09719 .11587 L
.10137 .12004 L
.10215 .1207 L
.1062 .12475 L
.10709 .12553 L
.10626 .13036 L
.11104 .13514 L
.11147 .1352 L
.11587 .13959 L
.11649 .14003 L
.1207 .14424 L
.12146 .14486 L
.12553 .14893 L
.12641 .14969 L
Mistroke
.12561 .15452 L
.13036 .15927 L
.13082 .15935 L
.1352 .16373 L
.13583 .16419 L
.14003 .16838 L
.14081 .16902 L
.14486 .17306 L
.14576 .17385 L
.14513 .17868 L
.14969 .18324 L
.15022 .18351 L
.15452 .18781 L
.15523 .18835 L
.15935 .19247 L
.16019 .19318 L
.16419 .19716 L
.16514 .19801 L
.16464 .20284 L
.16902 .20722 L
.16967 .20767 L
.17385 .21185 L
.17465 .2125 L
.17868 .21653 L
.17961 .21734 L
.1791 .22217 L
.18351 .22658 L
.18415 .227 L
.18835 .2312 L
.18914 .23183 L
.19318 .23587 L
.1941 .23666 L
.1936 .2415 L
.19801 .2459 L
.19865 .24633 L
.20284 .25051 L
.20365 .25116 L
.20767 .25518 L
.20861 .25599 L
.20816 .26082 L
.2125 .26517 L
.21319 .26566 L
.21734 .26979 L
.21818 .27049 L
.21762 .27532 L
.22217 .27987 L
.22274 .28015 L
.227 .28441 L
.22776 .28498 L
.23183 .28905 L
Mistroke
.23274 .28981 L
.23228 .29465 L
.23666 .29902 L
.23734 .29948 L
.2415 .30363 L
.24234 .30431 L
.24183 .30914 L
.24633 .31364 L
.24693 .31397 L
.25116 .31819 L
.25195 .31881 L
.25136 .32364 L
.25599 .32827 L
.25654 .32847 L
.26082 .33275 L
.26157 .3333 L
.26566 .33737 L
.26656 .33813 L
.26617 .34296 L
.27049 .34728 L
.27121 .3478 L
.27532 .35189 L
.27621 .35263 L
.27582 .35746 L
.28015 .36179 L
.28087 .36229 L
.28498 .36639 L
.28587 .36712 L
.28549 .37196 L
.28981 .37627 L
.29054 .37679 L
.28994 .38162 L
.29465 .38633 L
.29519 .38645 L
.29948 .39074 L
.30023 .39128 L
.29973 .39612 L
.30431 .40069 L
.3049 .40095 L
.30914 .40518 L
.30993 .40578 L
.30951 .41061 L
.31397 .41507 L
.31462 .41544 L
.31881 .41961 L
.31965 .42027 L
.31929 .42511 L
.32364 .42945 L
.32436 .42994 L
.32388 .43477 L
Mistroke
.32847 .43936 L
.32906 .4396 L
.3333 .44383 L
.3341 .44443 L
.33373 .44927 L
.33813 .45377 L
.33865 .4541 L
.33829 .45893 L
.34296 .4636 L
.34339 .46376 L
.3478 .46816 L
.34838 .46859 L
.34813 .47342 L
.35263 .47792 L
.35315 .47826 L
.35285 .48309 L
.35746 .48769 L
.35791 .48792 L
.35749 .49275 L
.36229 .49756 L
.36268 .49758 L
.36712 .50203 L
.36767 .50242 L
.36745 .50725 L
.37196 .51175 L
.37245 .51208 L
.37221 .51691 L
.37679 .52148 L
.37724 .52174 L
.37698 .52658 L
.38162 .53122 L
.38204 .53141 L
.38174 .53624 L
.38645 .54095 L
.38684 .54107 L
.39128 .54551 L
.39181 .5459 L
.39164 .55073 L
.39612 .55521 L
.39662 .55557 L
.39645 .5604 L
.40095 .56489 L
.40143 .56523 L
.40127 .57006 L
.40578 .57457 L
.40625 .57489 L
.40609 .57973 L
.41061 .58424 L
.41107 .58456 L
.41092 .58939 L
Mistroke
.41544 .59391 L
.41589 .59422 L
.41575 .59905 L
.41548 .60388 L
.42027 .60868 L
.42059 .60872 L
.42038 .61355 L
.42511 .61827 L
.42543 .61838 L
.42526 .62321 L
.42994 .62789 L
.43027 .62804 L
.43013 .63288 L
.43477 .63752 L
.43511 .63771 L
.43499 .64254 L
.4396 .64715 L
.43994 .64737 L
.43985 .6522 L
.4397 .65704 L
.44443 .66177 L
.4447 .66187 L
.44459 .6667 L
.44927 .67138 L
.44954 .67153 L
.44946 .67636 L
.44933 .68119 L
.4541 .68596 L
.4543 .68603 L
.45423 .69086 L
.45893 .69557 L
.45914 .69569 L
.45908 .70052 L
.45901 .70535 L
.46376 .71012 L
.46391 .71019 L
.46387 .71502 L
.4638 .71985 L
.46859 .72465 L
.46869 .72468 L
.46866 .72951 L
.46862 .73434 L
.47342 .73916 L
.47346 .73918 L
.47344 .74401 L
.47343 .74884 L
.47342 .75333 L
.47329 .75367 L
.47144 .7585 L
.46962 .76334 L
Mistroke
.46859 .76607 L
.46781 .76817 L
.46604 .773 L
.46428 .77783 L
.46376 .77927 L
.46255 .78266 L
.46084 .7875 L
.45916 .79233 L
.45893 .79298 L
.4575 .79716 L
.45586 .80199 L
.45425 .80682 L
.4541 .80729 L
.45267 .81165 L
.45111 .81649 L
.44958 .82132 L
.44927 .8223 L
.44807 .82615 L
.44659 .83098 L
.44513 .83581 L
.44443 .83817 L
.4437 .84065 L
.4423 .84548 L
.44093 .85031 L
.4396 .85508 L
.43958 .85514 L
.43827 .85997 L
.43698 .8648 L
.43572 .86964 L
.43477 .87334 L
.43448 .87447 L
.43328 .8793 L
.43211 .88413 L
.43097 .88896 L
.42994 .89343 L
.42986 .8938 L
.42877 .89863 L
.42773 .90346 L
.42671 .90829 L
.42572 .91312 L
.42511 .91622 L
.42477 .91796 L
.42385 .92279 L
.42296 .92762 L
.42211 .93245 L
.42129 .93728 L
.42051 .94211 L
.42027 .94363 L
.41977 .94695 L
.41906 .95178 L
Mistroke
.41839 .95661 L
.41775 .96144 L
.41716 .96627 L
.4166 .97111 L
.41609 .97594 L
.41561 .98077 L
Mfstroke
0 .161 .235 r
.01923 .02314 m
.01945 .02406 L
.02406 .02838 L
.02466 .02889 L
.02889 .03313 L
.02957 .03373 L
.03373 .03788 L
.03447 .03856 L
.03856 .04265 L
.03936 .04339 L
.03881 .04822 L
.04339 .0528 L
.04379 .05305 L
.04822 .05748 L
.04874 .05789 L
.05305 .0622 L
.05366 .06272 L
.05789 .06694 L
.05857 .06755 L
.06272 .07169 L
.06348 .07238 L
.06287 .07721 L
.06755 .0819 L
.06791 .08204 L
.07238 .08651 L
.07287 .08688 L
.07721 .09121 L
.07781 .09171 L
.08204 .09594 L
.08273 .09654 L
.08688 .10069 L
.08764 .10137 L
.08708 .1062 L
.09171 .11083 L
.09211 .11104 L
.09654 .11547 L
.09707 .11587 L
.10137 .12017 L
.102 .1207 L
.1062 .1249 L
.10693 .12553 L
.10625 .13036 L
.11104 .13515 L
.11139 .1352 L
.11587 .13967 L
.11637 .14003 L
.1207 .14436 L
.12131 .14486 L
.12553 .14907 L
.12624 .14969 L
.1256 .15452 L
.13036 .15929 L
.13073 .15935 L
.1352 .16382 L
.13571 .16419 L
.14003 .1685 L
.14066 .16902 L
.14486 .17321 L
.14559 .17385 L
.14508 .17868 L
.14969 .18329 L
.15012 .18351 L
.15452 .18791 L
.15509 .18835 L
.15935 .1926 L
.16004 .19318 L
.16419 .19732 L
.16496 .19801 L
.16455 .20284 L
.16902 .2073 L
.16955 .20767 L
.17385 .21197 L
.1745 .2125 L
.17868 .21668 L
.17944 .21734 L
.17902 .22217 L
.18351 .22666 L
.18402 .227 L
.18835 .23132 L
.18899 .23183 L
.19318 .23602 L
.19393 .23666 L
.19352 .2415 L
.19801 .24598 L
.19853 .24633 L
.20284 .25063 L
.20349 .25116 L
.20767 .25533 L
.20843 .25599 L
.20806 .26082 L
.2125 .26526 L
.21306 .26566 L
.21734 .26992 L
.21802 .27049 L
.21756 .27532 L
.22217 .27992 L
.22263 .28015 L
.227 .28452 L
.22761 .28498 L
.23183 .2892 L
.23256 .28981 L
.2322 .29465 L
.23666 .29911 L
.23721 .29948 L
.2415 .30376 L
.24218 .30431 L
.24176 .30914 L
.24633 .31371 L
.24682 .31397 L
.25116 .31831 L
.2518 .31881 L
.25132 .32364 L
.25599 .32831 L
.25644 .32847 L
.26082 .33285 L
.26143 .3333 L
.26566 .33752 L
.26639 .33813 L
.26607 .34296 L
.27049 .34738 L
.27108 .3478 L
.27532 .35203 L
.27604 .35263 L
.27572 .35746 L
.28015 .36188 L
.28073 .36229 L
.28498 .36653 L
.2857 .36712 L
.28539 .37196 L
.28981 .37637 L
.29041 .37679 L
.28991 .38162 L
.29465 .38635 L
.29508 .38645 L
.29948 .39084 L
.30009 .39128 L
.29968 .39612 L
.30431 .40074 L
.30479 .40095 L
.30914 .4053 L
.30978 .40578 L
.30944 .41061 L
.31397 .41514 L
.3145 .41544 L
.31881 .41974 L
.31949 .42027 L
.3192 .42511 L
.32364 .42954 L
.32422 .42994 L
.32383 .43477 L
.32847 .43941 L
.32895 .4396 L
.3333 .44395 L
.33395 .44443 L
.33365 .44927 L
.33813 .45386 L
.33851 .4541 L
.33825 .45893 L
.34296 .46365 L
.34328 .46376 L
.3478 .46828 L
.34822 .46859 L
.34804 .47342 L
.35263 .47801 L
.353 .47826 L
.35279 .48309 L
.35746 .48776 L
.35779 .48792 L
.35748 .49275 L
.36229 .49757 L
.36257 .49758 L
.36712 .50214 L
.36752 .50242 L
.36735 .50725 L
.37196 .51185 L
.37231 .51208 L
.37214 .51691 L
.37679 .52156 L
.37711 .52174 L
.37692 .52658 L
.38162 .53127 L
.38192 .53141 L
.3817 .53624 L
.38645 .54099 L
.38672 .54107 L
.39128 .54563 L
.39165 .5459 L
.39153 .55073 L
.39612 .55532 L
.39646 .55557 L
.39635 .5604 L
.40095 .565 L
.40128 .56523 L
.40117 .57006 L
.40578 .57467 L
.4061 .57489 L
.40599 .57973 L
.41061 .58435 L
.41092 .58456 L
.41082 .58939 L
.41544 .59402 L
.41574 .59422 L
.41565 .59905 L
.41547 .60388 L
.42027 .60869 L
.42048 .60872 L
.42035 .61355 L
.42511 .61831 L
.42531 .61838 L
.4252 .62321 L
.42994 .62795 L
.43014 .62804 L
.43006 .63288 L
.43477 .63759 L
.43497 .63771 L
.4349 .64254 L
.4396 .64724 L
.4398 .64737 L
.43974 .6522 L
.43966 .65704 L
.44443 .66181 L
.44458 .66187 L
.44452 .6667 L
.44927 .67145 L
.4494 .67153 L
.44936 .67636 L
.4493 .68119 L
.4541 .686 L
.45419 .68603 L
.45415 .69086 L
.45893 .69565 L
.45901 .69569 L
.45898 .70052 L
.45895 .70535 L
.46376 .71017 L
.46379 .71019 L
.46378 .71502 L
.46376 .71985 L
.46854 .72468 L
.46376 .72576 L
.46214 .72951 L
.46008 .73434 L
.45893 .73706 L
.45804 .73918 L
.45602 .74401 L
.4541 .74864 L
.45401 .74884 L
.45203 .75367 L
.45008 .7585 L
.44927 .76052 L
.44814 .76334 L
.44622 .76817 L
.44443 .77273 L
.44433 .773 L
.44246 .77783 L
.44061 .78266 L
.4396 .78531 L
.43878 .7875 L
.43697 .79233 L
.43519 .79716 L
.43477 .7983 L
.43343 .80199 L
.43169 .80682 L
.42997 .81165 L
.42994 .81176 L
.42828 .81649 L
.42661 .82132 L
.42511 .82575 L
.42497 .82615 L
.42335 .83098 L
.42175 .83581 L
.42027 .84035 L
.42018 .84065 L
.41863 .84548 L
.41711 .85031 L
.41561 .85514 L
.41544 .85568 L
.41413 .85997 L
.41269 .8648 L
.41126 .86964 L
.41061 .87188 L
.40987 .87447 L
.40849 .8793 L
.40715 .88413 L
.40583 .88896 L
.40578 .88916 L
.40454 .8938 L
.40328 .89863 L
.40204 .90346 L
.40095 .90782 L
.40083 .90829 L
.39965 .91312 L
.3985 .91796 L
.39737 .92279 L
.39628 .92762 L
.39612 .92835 L
.39521 .93245 L
.39418 .93728 L
.39317 .94211 L
.39219 .94695 L
.39128 .9516 L
.39125 .95178 L
.39034 .95661 L
.38945 .96144 L
.3886 .96627 L
.38779 .97111 L
.387 .97594 L
.38645 .97945 L
.38625 .98077 L
.01923 .98077 L
F
0 g
.01923 .02314 m
.01945 .02406 L
.02406 .02838 L
.02466 .02889 L
.02889 .03313 L
.02957 .03373 L
.03373 .03788 L
.03447 .03856 L
.03856 .04265 L
.03936 .04339 L
.03881 .04822 L
.04339 .0528 L
.04379 .05305 L
.04822 .05748 L
.04874 .05789 L
.05305 .0622 L
.05366 .06272 L
.05789 .06694 L
.05857 .06755 L
.06272 .07169 L
.06348 .07238 L
.06287 .07721 L
.06755 .0819 L
.06791 .08204 L
.07238 .08651 L
.07287 .08688 L
.07721 .09121 L
.07781 .09171 L
.08204 .09594 L
.08273 .09654 L
.08688 .10069 L
.08764 .10137 L
.08708 .1062 L
.09171 .11083 L
.09211 .11104 L
.09654 .11547 L
.09707 .11587 L
.10137 .12017 L
.102 .1207 L
.1062 .1249 L
.10693 .12553 L
.10625 .13036 L
.11104 .13515 L
.11139 .1352 L
.11587 .13967 L
.11637 .14003 L
.1207 .14436 L
.12131 .14486 L
.12553 .14907 L
.12624 .14969 L
Mistroke
.1256 .15452 L
.13036 .15929 L
.13073 .15935 L
.1352 .16382 L
.13571 .16419 L
.14003 .1685 L
.14066 .16902 L
.14486 .17321 L
.14559 .17385 L
.14508 .17868 L
.14969 .18329 L
.15012 .18351 L
.15452 .18791 L
.15509 .18835 L
.15935 .1926 L
.16004 .19318 L
.16419 .19732 L
.16496 .19801 L
.16455 .20284 L
.16902 .2073 L
.16955 .20767 L
.17385 .21197 L
.1745 .2125 L
.17868 .21668 L
.17944 .21734 L
.17902 .22217 L
.18351 .22666 L
.18402 .227 L
.18835 .23132 L
.18899 .23183 L
.19318 .23602 L
.19393 .23666 L
.19352 .2415 L
.19801 .24598 L
.19853 .24633 L
.20284 .25063 L
.20349 .25116 L
.20767 .25533 L
.20843 .25599 L
.20806 .26082 L
.2125 .26526 L
.21306 .26566 L
.21734 .26992 L
.21802 .27049 L
.21756 .27532 L
.22217 .27992 L
.22263 .28015 L
.227 .28452 L
.22761 .28498 L
.23183 .2892 L
Mistroke
.23256 .28981 L
.2322 .29465 L
.23666 .29911 L
.23721 .29948 L
.2415 .30376 L
.24218 .30431 L
.24176 .30914 L
.24633 .31371 L
.24682 .31397 L
.25116 .31831 L
.2518 .31881 L
.25132 .32364 L
.25599 .32831 L
.25644 .32847 L
.26082 .33285 L
.26143 .3333 L
.26566 .33752 L
.26639 .33813 L
.26607 .34296 L
.27049 .34738 L
.27108 .3478 L
.27532 .35203 L
.27604 .35263 L
.27572 .35746 L
.28015 .36188 L
.28073 .36229 L
.28498 .36653 L
.2857 .36712 L
.28539 .37196 L
.28981 .37637 L
.29041 .37679 L
.28991 .38162 L
.29465 .38635 L
.29508 .38645 L
.29948 .39084 L
.30009 .39128 L
.29968 .39612 L
.30431 .40074 L
.30479 .40095 L
.30914 .4053 L
.30978 .40578 L
.30944 .41061 L
.31397 .41514 L
.3145 .41544 L
.31881 .41974 L
.31949 .42027 L
.3192 .42511 L
.32364 .42954 L
.32422 .42994 L
.32383 .43477 L
Mistroke
.32847 .43941 L
.32895 .4396 L
.3333 .44395 L
.33395 .44443 L
.33365 .44927 L
.33813 .45386 L
.33851 .4541 L
.33825 .45893 L
.34296 .46365 L
.34328 .46376 L
.3478 .46828 L
.34822 .46859 L
.34804 .47342 L
.35263 .47801 L
.353 .47826 L
.35279 .48309 L
.35746 .48776 L
.35779 .48792 L
.35748 .49275 L
.36229 .49757 L
.36257 .49758 L
.36712 .50214 L
.36752 .50242 L
.36735 .50725 L
.37196 .51185 L
.37231 .51208 L
.37214 .51691 L
.37679 .52156 L
.37711 .52174 L
.37692 .52658 L
.38162 .53127 L
.38192 .53141 L
.3817 .53624 L
.38645 .54099 L
.38672 .54107 L
.39128 .54563 L
.39165 .5459 L
.39153 .55073 L
.39612 .55532 L
.39646 .55557 L
.39635 .5604 L
.40095 .565 L
.40128 .56523 L
.40117 .57006 L
.40578 .57467 L
.4061 .57489 L
.40599 .57973 L
.41061 .58435 L
.41092 .58456 L
.41082 .58939 L
Mistroke
.41544 .59402 L
.41574 .59422 L
.41565 .59905 L
.41547 .60388 L
.42027 .60869 L
.42048 .60872 L
.42035 .61355 L
.42511 .61831 L
.42531 .61838 L
.4252 .62321 L
.42994 .62795 L
.43014 .62804 L
.43006 .63288 L
.43477 .63759 L
.43497 .63771 L
.4349 .64254 L
.4396 .64724 L
.4398 .64737 L
.43974 .6522 L
.43966 .65704 L
.44443 .66181 L
.44458 .66187 L
.44452 .6667 L
.44927 .67145 L
.4494 .67153 L
.44936 .67636 L
.4493 .68119 L
.4541 .686 L
.45419 .68603 L
.45415 .69086 L
.45893 .69565 L
.45901 .69569 L
.45898 .70052 L
.45895 .70535 L
.46376 .71017 L
.46379 .71019 L
.46378 .71502 L
.46376 .71985 L
.46854 .72468 L
.46376 .72576 L
.46214 .72951 L
.46008 .73434 L
.45893 .73706 L
.45804 .73918 L
.45602 .74401 L
.4541 .74864 L
.45401 .74884 L
.45203 .75367 L
.45008 .7585 L
.44927 .76052 L
Mistroke
.44814 .76334 L
.44622 .76817 L
.44443 .77273 L
.44433 .773 L
.44246 .77783 L
.44061 .78266 L
.4396 .78531 L
.43878 .7875 L
.43697 .79233 L
.43519 .79716 L
.43477 .7983 L
.43343 .80199 L
.43169 .80682 L
.42997 .81165 L
.42994 .81176 L
.42828 .81649 L
.42661 .82132 L
.42511 .82575 L
.42497 .82615 L
.42335 .83098 L
.42175 .83581 L
.42027 .84035 L
.42018 .84065 L
.41863 .84548 L
.41711 .85031 L
.41561 .85514 L
.41544 .85568 L
.41413 .85997 L
.41269 .8648 L
.41126 .86964 L
.41061 .87188 L
.40987 .87447 L
.40849 .8793 L
.40715 .88413 L
.40583 .88896 L
.40578 .88916 L
.40454 .8938 L
.40328 .89863 L
.40204 .90346 L
.40095 .90782 L
.40083 .90829 L
.39965 .91312 L
.3985 .91796 L
.39737 .92279 L
.39628 .92762 L
.39612 .92835 L
.39521 .93245 L
.39418 .93728 L
.39317 .94211 L
.39219 .94695 L
Mistroke
.39128 .9516 L
.39125 .95178 L
.39034 .95661 L
.38945 .96144 L
.3886 .96627 L
.38779 .97111 L
.387 .97594 L
.38645 .97945 L
.38625 .98077 L
Mfstroke
0 .093 .19 r
.01923 .02333 m
.01939 .02406 L
.02406 .0285 L
.02452 .02889 L
.02889 .03327 L
.02941 .03373 L
.03373 .03804 L
.03429 .03856 L
.03856 .04282 L
.03917 .04339 L
.03875 .04822 L
.04339 .05286 L
.0437 .05305 L
.04822 .05758 L
.04861 .05789 L
.05305 .06232 L
.05352 .06272 L
.05789 .06708 L
.05841 .06755 L
.06272 .07185 L
.0633 .07238 L
.06283 .07721 L
.06755 .08193 L
.06782 .08204 L
.07238 .0866 L
.07275 .08688 L
.07721 .09133 L
.07766 .09171 L
.08204 .09609 L
.08256 .09654 L
.08688 .10085 L
.08746 .10137 L
.08703 .1062 L
.09171 .11088 L
.09201 .11104 L
.09654 .11556 L
.09694 .11587 L
.10137 .1203 L
.10185 .1207 L
.1062 .12505 L
.10675 .12553 L
.10624 .13036 L
.11104 .13516 L
.1113 .1352 L
.11587 .13976 L
.11625 .14003 L
.1207 .14448 L
.12117 .14486 L
.12553 .14922 L
.12607 .14969 L
.12558 .15452 L
.13036 .15931 L
.13064 .15935 L
.1352 .16391 L
.13559 .16419 L
.14003 .16862 L
.14051 .16902 L
.14486 .17337 L
.14542 .17385 L
.14502 .17868 L
.14969 .18335 L
.15002 .18351 L
.15452 .18802 L
.15495 .18835 L
.15935 .19274 L
.15987 .19318 L
.16419 .19749 L
.16478 .19801 L
.16446 .20284 L
.16902 .20739 L
.16942 .20767 L
.17385 .2121 L
.17434 .2125 L
.17868 .21684 L
.17926 .21734 L
.17893 .22217 L
.18351 .22675 L
.1839 .227 L
.18835 .23144 L
.18883 .23183 L
.19318 .23617 L
.19375 .23666 L
.19344 .2415 L
.19801 .24607 L
.1984 .24633 L
.20284 .25076 L
.20334 .25116 L
.20767 .25549 L
.20825 .25599 L
.20797 .26082 L
.2125 .26536 L
.21293 .26566 L
.21734 .27006 L
.21786 .27049 L
.21751 .27532 L
.22217 .27998 L
.22252 .28015 L
.227 .28463 L
.22747 .28498 L
.23183 .28934 L
.23239 .28981 L
.23211 .29465 L
.23666 .2992 L
.23708 .29948 L
.2415 .30389 L
.24201 .30431 L
.2417 .30914 L
.24633 .31377 L
.2467 .31397 L
.25116 .31843 L
.25165 .31881 L
.25128 .32364 L
.25599 .32835 L
.25633 .32847 L
.26082 .33296 L
.26129 .3333 L
.26566 .33767 L
.26622 .33813 L
.26597 .34296 L
.27049 .34748 L
.27093 .3478 L
.27532 .35218 L
.27587 .35263 L
.27562 .35746 L
.28015 .36198 L
.28059 .36229 L
.28498 .36668 L
.28553 .36712 L
.28529 .37196 L
.28981 .37647 L
.29026 .37679 L
.28989 .38162 L
.29465 .38638 L
.29498 .38645 L
.29948 .39095 L
.29994 .39128 L
.29963 .39612 L
.30431 .40079 L
.30467 .40095 L
.30914 .40541 L
.30963 .40578 L
.30937 .41061 L
.31397 .41521 L
.31437 .41544 L
.31881 .41987 L
.31932 .42027 L
.3191 .42511 L
.32364 .42964 L
.32408 .42994 L
.32378 .43477 L
.32847 .43945 L
.32883 .4396 L
.3333 .44407 L
.3338 .44443 L
.33356 .44927 L
.33813 .45395 L
.33837 .4541 L
.3382 .45893 L
.34296 .46369 L
.34316 .46376 L
.3478 .4684 L
.34806 .46859 L
.34795 .47342 L
.35263 .47811 L
.35286 .47826 L
.35273 .48309 L
.35746 .48782 L
.35766 .48792 L
.35747 .49275 L
.36229 .49757 L
.36246 .49758 L
.36712 .50225 L
.36736 .50242 L
.36726 .50725 L
.37196 .51194 L
.37217 .51208 L
.37206 .51691 L
.37679 .52164 L
.37698 .52174 L
.37687 .52658 L
.38162 .53133 L
.38179 .53141 L
.38167 .53624 L
.38645 .54102 L
.3866 .54107 L
.39128 .54575 L
.39149 .5459 L
.39142 .55073 L
.39612 .55543 L
.39631 .55557 L
.39624 .5604 L
.40095 .56511 L
.40113 .56523 L
.40106 .57006 L
.40578 .57478 L
.40594 .57489 L
.40589 .57973 L
.41061 .58445 L
.41076 .58456 L
.41071 .58939 L
.41544 .59412 L
.41559 .59422 L
.41554 .59905 L
.41545 .60388 L
.42027 .60871 L
.42037 .60872 L
.42031 .61355 L
.42511 .61835 L
.42519 .61838 L
.42515 .62321 L
.42994 .62801 L
.43002 .62804 L
.42998 .63288 L
.43477 .63767 L
.43484 .63771 L
.43481 .64254 L
.4396 .64734 L
.43966 .64737 L
.43964 .6522 L
.43961 .65704 L
.44443 .66186 L
.44446 .66187 L
.44444 .6667 L
.44927 .67153 L
.44927 .67153 L
.44927 .67635 L
.44926 .67636 L
.44926 .68119 L
.44443 .68261 L
.44273 .68603 L
.44034 .69086 L
.4396 .69236 L
.43797 .69569 L
.43561 .70052 L
.43477 .70226 L
.43328 .70535 L
.43096 .71019 L
.42994 .71233 L
.42866 .71502 L
.42638 .71985 L
.42511 .72256 L
.42411 .72468 L
.42187 .72951 L
.42027 .73297 L
.41964 .73434 L
.41743 .73918 L
.41544 .74357 L
.41525 .74401 L
.41308 .74884 L
.41093 .75367 L
.41061 .75438 L
.40879 .7585 L
.40668 .76334 L
.40578 .76541 L
.40459 .76817 L
.40251 .773 L
.40095 .77668 L
.40046 .77783 L
.39843 .78266 L
.39641 .7875 L
.39612 .78821 L
.39442 .79233 L
.39244 .79716 L
.39128 .80001 L
.39049 .80199 L
.38855 .80682 L
.38664 .81165 L
.38645 .81213 L
.38474 .81649 L
.38287 .82132 L
.38162 .82458 L
.38102 .82615 L
.37919 .83098 L
.37738 .83581 L
.37679 .8374 L
.37559 .84065 L
.37382 .84548 L
.37208 .85031 L
.37196 .85065 L
.37035 .85514 L
.36865 .85997 L
.36712 .86436 L
.36697 .8648 L
.36531 .86964 L
.36367 .87447 L
.36229 .8786 L
.36206 .8793 L
.36047 .88413 L
.3589 .88896 L
.35746 .89346 L
.35735 .8938 L
.35583 .89863 L
.35433 .90346 L
.35286 .90829 L
.35263 .90904 L
.3514 .91312 L
.34998 .91796 L
.34857 .92279 L
.3478 .92549 L
.34719 .92762 L
.34583 .93245 L
.3445 .93728 L
.3432 .94211 L
.34296 .94298 L
.34191 .94695 L
.34066 .95178 L
.33943 .95661 L
.33822 .96144 L
.33813 .9618 L
.33704 .96627 L
.33589 .97111 L
.33476 .97594 L
.33366 .98077 L
.01923 .98077 L
F
0 g
.01923 .02333 m
.01939 .02406 L
.02406 .0285 L
.02452 .02889 L
.02889 .03327 L
.02941 .03373 L
.03373 .03804 L
.03429 .03856 L
.03856 .04282 L
.03917 .04339 L
.03875 .04822 L
.04339 .05286 L
.0437 .05305 L
.04822 .05758 L
.04861 .05789 L
.05305 .06232 L
.05352 .06272 L
.05789 .06708 L
.05841 .06755 L
.06272 .07185 L
.0633 .07238 L
.06283 .07721 L
.06755 .08193 L
.06782 .08204 L
.07238 .0866 L
.07275 .08688 L
.07721 .09133 L
.07766 .09171 L
.08204 .09609 L
.08256 .09654 L
.08688 .10085 L
.08746 .10137 L
.08703 .1062 L
.09171 .11088 L
.09201 .11104 L
.09654 .11556 L
.09694 .11587 L
.10137 .1203 L
.10185 .1207 L
.1062 .12505 L
.10675 .12553 L
.10624 .13036 L
.11104 .13516 L
.1113 .1352 L
.11587 .13976 L
.11625 .14003 L
.1207 .14448 L
.12117 .14486 L
.12553 .14922 L
.12607 .14969 L
Mistroke
.12558 .15452 L
.13036 .15931 L
.13064 .15935 L
.1352 .16391 L
.13559 .16419 L
.14003 .16862 L
.14051 .16902 L
.14486 .17337 L
.14542 .17385 L
.14502 .17868 L
.14969 .18335 L
.15002 .18351 L
.15452 .18802 L
.15495 .18835 L
.15935 .19274 L
.15987 .19318 L
.16419 .19749 L
.16478 .19801 L
.16446 .20284 L
.16902 .20739 L
.16942 .20767 L
.17385 .2121 L
.17434 .2125 L
.17868 .21684 L
.17926 .21734 L
.17893 .22217 L
.18351 .22675 L
.1839 .227 L
.18835 .23144 L
.18883 .23183 L
.19318 .23617 L
.19375 .23666 L
.19344 .2415 L
.19801 .24607 L
.1984 .24633 L
.20284 .25076 L
.20334 .25116 L
.20767 .25549 L
.20825 .25599 L
.20797 .26082 L
.2125 .26536 L
.21293 .26566 L
.21734 .27006 L
.21786 .27049 L
.21751 .27532 L
.22217 .27998 L
.22252 .28015 L
.227 .28463 L
.22747 .28498 L
.23183 .28934 L
Mistroke
.23239 .28981 L
.23211 .29465 L
.23666 .2992 L
.23708 .29948 L
.2415 .30389 L
.24201 .30431 L
.2417 .30914 L
.24633 .31377 L
.2467 .31397 L
.25116 .31843 L
.25165 .31881 L
.25128 .32364 L
.25599 .32835 L
.25633 .32847 L
.26082 .33296 L
.26129 .3333 L
.26566 .33767 L
.26622 .33813 L
.26597 .34296 L
.27049 .34748 L
.27093 .3478 L
.27532 .35218 L
.27587 .35263 L
.27562 .35746 L
.28015 .36198 L
.28059 .36229 L
.28498 .36668 L
.28553 .36712 L
.28529 .37196 L
.28981 .37647 L
.29026 .37679 L
.28989 .38162 L
.29465 .38638 L
.29498 .38645 L
.29948 .39095 L
.29994 .39128 L
.29963 .39612 L
.30431 .40079 L
.30467 .40095 L
.30914 .40541 L
.30963 .40578 L
.30937 .41061 L
.31397 .41521 L
.31437 .41544 L
.31881 .41987 L
.31932 .42027 L
.3191 .42511 L
.32364 .42964 L
.32408 .42994 L
.32378 .43477 L
Mistroke
.32847 .43945 L
.32883 .4396 L
.3333 .44407 L
.3338 .44443 L
.33356 .44927 L
.33813 .45395 L
.33837 .4541 L
.3382 .45893 L
.34296 .46369 L
.34316 .46376 L
.3478 .4684 L
.34806 .46859 L
.34795 .47342 L
.35263 .47811 L
.35286 .47826 L
.35273 .48309 L
.35746 .48782 L
.35766 .48792 L
.35747 .49275 L
.36229 .49757 L
.36246 .49758 L
.36712 .50225 L
.36736 .50242 L
.36726 .50725 L
.37196 .51194 L
.37217 .51208 L
.37206 .51691 L
.37679 .52164 L
.37698 .52174 L
.37687 .52658 L
.38162 .53133 L
.38179 .53141 L
.38167 .53624 L
.38645 .54102 L
.3866 .54107 L
.39128 .54575 L
.39149 .5459 L
.39142 .55073 L
.39612 .55543 L
.39631 .55557 L
.39624 .5604 L
.40095 .56511 L
.40113 .56523 L
.40106 .57006 L
.40578 .57478 L
.40594 .57489 L
.40589 .57973 L
.41061 .58445 L
.41076 .58456 L
.41071 .58939 L
Mistroke
.41544 .59412 L
.41559 .59422 L
.41554 .59905 L
.41545 .60388 L
.42027 .60871 L
.42037 .60872 L
.42031 .61355 L
.42511 .61835 L
.42519 .61838 L
.42515 .62321 L
.42994 .62801 L
.43002 .62804 L
.42998 .63288 L
.43477 .63767 L
.43484 .63771 L
.43481 .64254 L
.4396 .64734 L
.43966 .64737 L
.43964 .6522 L
.43961 .65704 L
.44443 .66186 L
.44446 .66187 L
.44444 .6667 L
.44927 .67153 L
.44927 .67153 L
.44927 .67635 L
.44926 .67636 L
.44926 .68119 L
.44443 .68261 L
.44273 .68603 L
.44034 .69086 L
.4396 .69236 L
.43797 .69569 L
.43561 .70052 L
.43477 .70226 L
.43328 .70535 L
.43096 .71019 L
.42994 .71233 L
.42866 .71502 L
.42638 .71985 L
.42511 .72256 L
.42411 .72468 L
.42187 .72951 L
.42027 .73297 L
.41964 .73434 L
.41743 .73918 L
.41544 .74357 L
.41525 .74401 L
.41308 .74884 L
.41093 .75367 L
Mistroke
.41061 .75438 L
.40879 .7585 L
.40668 .76334 L
.40578 .76541 L
.40459 .76817 L
.40251 .773 L
.40095 .77668 L
.40046 .77783 L
.39843 .78266 L
.39641 .7875 L
.39612 .78821 L
.39442 .79233 L
.39244 .79716 L
.39128 .80001 L
.39049 .80199 L
.38855 .80682 L
.38664 .81165 L
.38645 .81213 L
.38474 .81649 L
.38287 .82132 L
.38162 .82458 L
.38102 .82615 L
.37919 .83098 L
.37738 .83581 L
.37679 .8374 L
.37559 .84065 L
.37382 .84548 L
.37208 .85031 L
.37196 .85065 L
.37035 .85514 L
.36865 .85997 L
.36712 .86436 L
.36697 .8648 L
.36531 .86964 L
.36367 .87447 L
.36229 .8786 L
.36206 .8793 L
.36047 .88413 L
.3589 .88896 L
.35746 .89346 L
.35735 .8938 L
.35583 .89863 L
.35433 .90346 L
.35286 .90829 L
.35263 .90904 L
.3514 .91312 L
.34998 .91796 L
.34857 .92279 L
.3478 .92549 L
.34719 .92762 L
Mistroke
.34583 .93245 L
.3445 .93728 L
.3432 .94211 L
.34296 .94298 L
.34191 .94695 L
.34066 .95178 L
.33943 .95661 L
.33822 .96144 L
.33813 .9618 L
.33704 .96627 L
.33589 .97111 L
.33476 .97594 L
.33366 .98077 L
Mfstroke
0 .043 .145 r
.01923 .02355 m
.01934 .02406 L
.02406 .02863 L
.02437 .02889 L
.02889 .03342 L
.02924 .03373 L
.03373 .03821 L
.03411 .03856 L
.03856 .04301 L
.03897 .04339 L
.03869 .04822 L
.04339 .05293 L
.0436 .05305 L
.04822 .05768 L
.04849 .05789 L
.05305 .06245 L
.05337 .06272 L
.05789 .06723 L
.05824 .06755 L
.06272 .07202 L
.06311 .07238 L
.06279 .07721 L
.06755 .08197 L
.06773 .08204 L
.07238 .08669 L
.07263 .08688 L
.07721 .09146 L
.07752 .09171 L
.08204 .09623 L
.0824 .09654 L
.08688 .10102 L
.08727 .10137 L
.08698 .1062 L
.09171 .11093 L
.09191 .11104 L
.09654 .11566 L
.09681 .11587 L
.10137 .12043 L
.1017 .1207 L
.1062 .1252 L
.10658 .12553 L
.10623 .13036 L
.11104 .13517 L
.11121 .1352 L
.11587 .13985 L
.11612 .14003 L
.1207 .1446 L
.12102 .14486 L
.12553 .14937 L
.1259 .14969 L
.12556 .15452 L
.13036 .15932 L
.13055 .15935 L
.1352 .164 L
.13546 .16419 L
.14003 .16875 L
.14035 .16902 L
.14486 .17352 L
.14524 .17385 L
.14497 .17868 L
.14969 .1834 L
.14991 .18351 L
.15452 .18812 L
.15481 .18835 L
.15935 .19288 L
.15971 .19318 L
.16419 .19766 L
.16459 .19801 L
.16437 .20284 L
.16902 .20749 L
.16929 .20767 L
.17385 .21223 L
.17418 .2125 L
.17868 .217 L
.17907 .21734 L
.17885 .22217 L
.18351 .22683 L
.18378 .227 L
.18835 .23157 L
.18868 .23183 L
.19318 .23633 L
.19356 .23666 L
.19335 .2415 L
.19801 .24615 L
.19828 .24633 L
.20284 .25089 L
.20318 .25116 L
.20767 .25565 L
.20807 .25599 L
.20787 .26082 L
.2125 .26545 L
.21279 .26566 L
.21734 .2702 L
.21769 .27049 L
.21745 .27532 L
.22217 .28004 L
.2224 .28015 L
.227 .28474 L
.22732 .28498 L
.23183 .2895 L
.23221 .28981 L
.23202 .29465 L
.23666 .29929 L
.23694 .29948 L
.2415 .30403 L
.24185 .30431 L
.24163 .30914 L
.24633 .31384 L
.24658 .31397 L
.25116 .31855 L
.25149 .31881 L
.25124 .32364 L
.25599 .32839 L
.25622 .32847 L
.26082 .33307 L
.26114 .3333 L
.26566 .33782 L
.26604 .33813 L
.26587 .34296 L
.27049 .34758 L
.27079 .3478 L
.27532 .35232 L
.27569 .35263 L
.27552 .35746 L
.28015 .36208 L
.28045 .36229 L
.28498 .36682 L
.28535 .36712 L
.28519 .37196 L
.28981 .37658 L
.29012 .37679 L
.28986 .38162 L
.29465 .3864 L
.29487 .38645 L
.29948 .39106 L
.29979 .39128 L
.29958 .39612 L
.30431 .40084 L
.30455 .40095 L
.30914 .40553 L
.30947 .40578 L
.30929 .41061 L
.31397 .41529 L
.31424 .41544 L
.31881 .42 L
.31916 .42027 L
.319 .42511 L
.32364 .42974 L
.32394 .42994 L
.32374 .43477 L
.32847 .4395 L
.32871 .4396 L
.3333 .44419 L
.33364 .44443 L
.33348 .44927 L
.33813 .45404 L
.33823 .4541 L
.33816 .45893 L
.34296 .46373 L
.34304 .46376 L
.3478 .46852 L
.3479 .46859 L
.34785 .47342 L
.35263 .4782 L
.35271 .47826 L
.35266 .48309 L
.35746 .48789 L
.35753 .48792 L
.35746 .49275 L
.36229 .49758 L
.36235 .49758 L
.36712 .50236 L
.3672 .50242 L
.36717 .50725 L
.37196 .51204 L
.37202 .51208 L
.37199 .51691 L
.37679 .52171 L
.37684 .52174 L
.37681 .52658 L
.38162 .53139 L
.38166 .53141 L
.38163 .53624 L
.38645 .54106 L
.38648 .54107 L
.39128 .54587 L
.39132 .5459 L
.39131 .55073 L
.39612 .55555 L
.39614 .55557 L
.39613 .5604 L
.40095 .56522 L
.40096 .56523 L
.40096 .57006 L
.40578 .57489 L
.40579 .57489 L
.40578 .57973 L
.4106 .58456 L
.40578 .58589 L
.40362 .58939 L
.40095 .59374 L
.40065 .59422 L
.3977 .59905 L
.39612 .60165 L
.39476 .60388 L
.39183 .60872 L
.39128 .60962 L
.38892 .61355 L
.38645 .61767 L
.38602 .61838 L
.38314 .62321 L
.38162 .62578 L
.38028 .62804 L
.37743 .63288 L
.37679 .63396 L
.37459 .63771 L
.37196 .64222 L
.37177 .64254 L
.36896 .64737 L
.36712 .65055 L
.36617 .6522 L
.3634 .65704 L
.36229 .65896 L
.36063 .66187 L
.35789 .6667 L
.35746 .66746 L
.35516 .67153 L
.35263 .67603 L
.35244 .67636 L
.34974 .68119 L
.3478 .6847 L
.34706 .68603 L
.34439 .69086 L
.34296 .69345 L
.34174 .69569 L
.3391 .70052 L
.33813 .7023 L
.33648 .70535 L
.33387 .71019 L
.3333 .71125 L
.33128 .71502 L
.32871 .71985 L
.32847 .7203 L
.32615 .72468 L
.32364 .72946 L
.32361 .72951 L
.32108 .73434 L
.31881 .73872 L
.31857 .73918 L
.31608 .74401 L
.31397 .74811 L
.3136 .74884 L
.31114 .75367 L
.30914 .75761 L
.30869 .7585 L
.30626 .76334 L
.30431 .76724 L
.30385 .76817 L
.30145 .773 L
.29948 .77701 L
.29907 .77783 L
.29671 .78266 L
.29465 .78691 L
.29436 .7875 L
.29203 .79233 L
.28981 .79697 L
.28972 .79716 L
.28743 .80199 L
.28515 .80682 L
.28498 .80717 L
.28289 .81165 L
.28064 .81649 L
.28015 .81755 L
.27842 .82132 L
.27621 .82615 L
.27532 .8281 L
.27401 .83098 L
.27184 .83581 L
.27049 .83883 L
.26968 .84065 L
.26754 .84548 L
.26566 .84977 L
.26542 .85031 L
.26331 .85514 L
.26123 .85997 L
.26082 .86091 L
.25916 .8648 L
.25711 .86964 L
.25599 .87228 L
.25508 .87447 L
.25306 .8793 L
.25116 .8839 L
.25106 .88413 L
.24909 .88896 L
.24713 .8938 L
.24633 .89578 L
.24519 .89863 L
.24326 .90346 L
.2415 .90795 L
.24136 .90829 L
.23948 .91312 L
.23761 .91796 L
.23666 .92042 L
.23576 .92279 L
.23393 .92762 L
.23213 .93245 L
.23183 .93324 L
.23034 .93728 L
.22857 .94211 L
.227 .94643 L
.22682 .94695 L
.22508 .95178 L
.22337 .95661 L
.22217 .96004 L
.22168 .96144 L
.22001 .96627 L
.21836 .97111 L
.21734 .97412 L
.21673 .97594 L
.21511 .98077 L
.01923 .98077 L
F
0 g
.01923 .02355 m
.01934 .02406 L
.02406 .02863 L
.02437 .02889 L
.02889 .03342 L
.02924 .03373 L
.03373 .03821 L
.03411 .03856 L
.03856 .04301 L
.03897 .04339 L
.03869 .04822 L
.04339 .05293 L
.0436 .05305 L
.04822 .05768 L
.04849 .05789 L
.05305 .06245 L
.05337 .06272 L
.05789 .06723 L
.05824 .06755 L
.06272 .07202 L
.06311 .07238 L
.06279 .07721 L
.06755 .08197 L
.06773 .08204 L
.07238 .08669 L
.07263 .08688 L
.07721 .09146 L
.07752 .09171 L
.08204 .09623 L
.0824 .09654 L
.08688 .10102 L
.08727 .10137 L
.08698 .1062 L
.09171 .11093 L
.09191 .11104 L
.09654 .11566 L
.09681 .11587 L
.10137 .12043 L
.1017 .1207 L
.1062 .1252 L
.10658 .12553 L
.10623 .13036 L
.11104 .13517 L
.11121 .1352 L
.11587 .13985 L
.11612 .14003 L
.1207 .1446 L
.12102 .14486 L
.12553 .14937 L
.1259 .14969 L
Mistroke
.12556 .15452 L
.13036 .15932 L
.13055 .15935 L
.1352 .164 L
.13546 .16419 L
.14003 .16875 L
.14035 .16902 L
.14486 .17352 L
.14524 .17385 L
.14497 .17868 L
.14969 .1834 L
.14991 .18351 L
.15452 .18812 L
.15481 .18835 L
.15935 .19288 L
.15971 .19318 L
.16419 .19766 L
.16459 .19801 L
.16437 .20284 L
.16902 .20749 L
.16929 .20767 L
.17385 .21223 L
.17418 .2125 L
.17868 .217 L
.17907 .21734 L
.17885 .22217 L
.18351 .22683 L
.18378 .227 L
.18835 .23157 L
.18868 .23183 L
.19318 .23633 L
.19356 .23666 L
.19335 .2415 L
.19801 .24615 L
.19828 .24633 L
.20284 .25089 L
.20318 .25116 L
.20767 .25565 L
.20807 .25599 L
.20787 .26082 L
.2125 .26545 L
.21279 .26566 L
.21734 .2702 L
.21769 .27049 L
.21745 .27532 L
.22217 .28004 L
.2224 .28015 L
.227 .28474 L
.22732 .28498 L
.23183 .2895 L
Mistroke
.23221 .28981 L
.23202 .29465 L
.23666 .29929 L
.23694 .29948 L
.2415 .30403 L
.24185 .30431 L
.24163 .30914 L
.24633 .31384 L
.24658 .31397 L
.25116 .31855 L
.25149 .31881 L
.25124 .32364 L
.25599 .32839 L
.25622 .32847 L
.26082 .33307 L
.26114 .3333 L
.26566 .33782 L
.26604 .33813 L
.26587 .34296 L
.27049 .34758 L
.27079 .3478 L
.27532 .35232 L
.27569 .35263 L
.27552 .35746 L
.28015 .36208 L
.28045 .36229 L
.28498 .36682 L
.28535 .36712 L
.28519 .37196 L
.28981 .37658 L
.29012 .37679 L
.28986 .38162 L
.29465 .3864 L
.29487 .38645 L
.29948 .39106 L
.29979 .39128 L
.29958 .39612 L
.30431 .40084 L
.30455 .40095 L
.30914 .40553 L
.30947 .40578 L
.30929 .41061 L
.31397 .41529 L
.31424 .41544 L
.31881 .42 L
.31916 .42027 L
.319 .42511 L
.32364 .42974 L
.32394 .42994 L
.32374 .43477 L
Mistroke
.32847 .4395 L
.32871 .4396 L
.3333 .44419 L
.33364 .44443 L
.33348 .44927 L
.33813 .45404 L
.33823 .4541 L
.33816 .45893 L
.34296 .46373 L
.34304 .46376 L
.3478 .46852 L
.3479 .46859 L
.34785 .47342 L
.35263 .4782 L
.35271 .47826 L
.35266 .48309 L
.35746 .48789 L
.35753 .48792 L
.35746 .49275 L
.36229 .49758 L
.36235 .49758 L
.36712 .50236 L
.3672 .50242 L
.36717 .50725 L
.37196 .51204 L
.37202 .51208 L
.37199 .51691 L
.37679 .52171 L
.37684 .52174 L
.37681 .52658 L
.38162 .53139 L
.38166 .53141 L
.38163 .53624 L
.38645 .54106 L
.38648 .54107 L
.39128 .54587 L
.39132 .5459 L
.39131 .55073 L
.39612 .55555 L
.39614 .55557 L
.39613 .5604 L
.40095 .56522 L
.40096 .56523 L
.40096 .57006 L
.40578 .57489 L
.40579 .57489 L
.40578 .57973 L
.4106 .58456 L
.40578 .58589 L
.40362 .58939 L
Mistroke
.40095 .59374 L
.40065 .59422 L
.3977 .59905 L
.39612 .60165 L
.39476 .60388 L
.39183 .60872 L
.39128 .60962 L
.38892 .61355 L
.38645 .61767 L
.38602 .61838 L
.38314 .62321 L
.38162 .62578 L
.38028 .62804 L
.37743 .63288 L
.37679 .63396 L
.37459 .63771 L
.37196 .64222 L
.37177 .64254 L
.36896 .64737 L
.36712 .65055 L
.36617 .6522 L
.3634 .65704 L
.36229 .65896 L
.36063 .66187 L
.35789 .6667 L
.35746 .66746 L
.35516 .67153 L
.35263 .67603 L
.35244 .67636 L
.34974 .68119 L
.3478 .6847 L
.34706 .68603 L
.34439 .69086 L
.34296 .69345 L
.34174 .69569 L
.3391 .70052 L
.33813 .7023 L
.33648 .70535 L
.33387 .71019 L
.3333 .71125 L
.33128 .71502 L
.32871 .71985 L
.32847 .7203 L
.32615 .72468 L
.32364 .72946 L
.32361 .72951 L
.32108 .73434 L
.31881 .73872 L
.31857 .73918 L
.31608 .74401 L
Mistroke
.31397 .74811 L
.3136 .74884 L
.31114 .75367 L
.30914 .75761 L
.30869 .7585 L
.30626 .76334 L
.30431 .76724 L
.30385 .76817 L
.30145 .773 L
.29948 .77701 L
.29907 .77783 L
.29671 .78266 L
.29465 .78691 L
.29436 .7875 L
.29203 .79233 L
.28981 .79697 L
.28972 .79716 L
.28743 .80199 L
.28515 .80682 L
.28498 .80717 L
.28289 .81165 L
.28064 .81649 L
.28015 .81755 L
.27842 .82132 L
.27621 .82615 L
.27532 .8281 L
.27401 .83098 L
.27184 .83581 L
.27049 .83883 L
.26968 .84065 L
.26754 .84548 L
.26566 .84977 L
.26542 .85031 L
.26331 .85514 L
.26123 .85997 L
.26082 .86091 L
.25916 .8648 L
.25711 .86964 L
.25599 .87228 L
.25508 .87447 L
.25306 .8793 L
.25116 .8839 L
.25106 .88413 L
.24909 .88896 L
.24713 .8938 L
.24633 .89578 L
.24519 .89863 L
.24326 .90346 L
.2415 .90795 L
.24136 .90829 L
Mistroke
.23948 .91312 L
.23761 .91796 L
.23666 .92042 L
.23576 .92279 L
.23393 .92762 L
.23213 .93245 L
.23183 .93324 L
.23034 .93728 L
.22857 .94211 L
.227 .94643 L
.22682 .94695 L
.22508 .95178 L
.22337 .95661 L
.22217 .96004 L
.22168 .96144 L
.22001 .96627 L
.21836 .97111 L
.21734 .97412 L
.21673 .97594 L
.21511 .98077 L
Mfstroke
0 .01 .1 r
.01923 .70969 m
.02307 .70535 L
.02406 .70485 L
.02838 .70052 L
.02889 .70001 L
.03373 .69998 L
.03801 .69569 L
.03856 .69514 L
.04283 .69086 L
.04339 .6903 L
.04765 .68603 L
.04822 .68546 L
.05248 .68119 L
.05305 .68062 L
.0573 .67636 L
.05789 .67578 L
.06272 .67575 L
.06692 .67153 L
.06755 .67091 L
.07175 .6667 L
.07238 .66606 L
.07657 .66187 L
.07721 .66122 L
.08139 .65704 L
.08204 .65638 L
.08622 .6522 L
.08688 .65154 L
.09171 .65151 L
.09584 .64737 L
.09654 .64667 L
.10066 .64254 L
.10137 .64183 L
.10549 .63771 L
.1062 .63699 L
.11031 .63288 L
.11104 .63215 L
.11587 .63212 L
.11993 .62804 L
.1207 .62728 L
.12476 .62321 L
.12553 .62244 L
.12958 .61838 L
.13036 .6176 L
.1344 .61355 L
.1352 .61276 L
.13923 .60872 L
.14003 .60792 L
.14486 .60789 L
.14885 .60388 L
.14969 .60305 L
.15368 .59905 L
.15452 .59821 L
.1585 .59422 L
.15935 .59336 L
.16332 .58939 L
.16419 .58852 L
.16815 .58456 L
.16902 .58368 L
.17385 .58365 L
.17777 .57973 L
.17868 .57881 L
.18259 .57489 L
.18351 .57397 L
.18742 .57006 L
.18835 .56913 L
.19224 .56523 L
.19318 .56429 L
.19801 .56426 L
.20187 .5604 L
.20284 .55942 L
.20669 .55557 L
.20767 .55458 L
.21151 .55073 L
.2125 .54974 L
.21634 .5459 L
.21734 .5449 L
.22116 .54107 L
.22217 .54006 L
.227 .54003 L
.23079 .53624 L
.23183 .53519 L
.23561 .53141 L
.23666 .53035 L
.24043 .52658 L
.2415 .52551 L
.24526 .52174 L
.24633 .52067 L
.25116 .52064 L
.25488 .51691 L
.25599 .5158 L
.25971 .51208 L
.26082 .51096 L
.26453 .50725 L
.26566 .50612 L
.26935 .50242 L
.27049 .50128 L
.27418 .49758 L
.27532 .49644 L
.28015 .49641 L
.2838 .49275 L
.28498 .49157 L
.28863 .48792 L
.28981 .48673 L
.29345 .48309 L
.29465 .48189 L
.29827 .47826 L
.29948 .47705 L
.3031 .47342 L
.30431 .47221 L
.30914 .47218 L
.31272 .46859 L
.31397 .46734 L
.31755 .46376 L
.31881 .4625 L
.32237 .45893 L
.32364 .45766 L
.3272 .4541 L
.32847 .45282 L
.3333 .45279 L
.33339 .44927 L
.33347 .44443 L
.3333 .44431 L
.32859 .4396 L
.32847 .43955 L
.32369 .43477 L
.32379 .42994 L
.32364 .42984 L
.31891 .42511 L
.31898 .42027 L
.31881 .42014 L
.31411 .41544 L
.31397 .41536 L
.30922 .41061 L
.30931 .40578 L
.30914 .40565 L
.30443 .40095 L
.30431 .40089 L
.29953 .39612 L
.29964 .39128 L
.29948 .39117 L
.29476 .38645 L
.29465 .38643 L
.28984 .38162 L
.28997 .37679 L
.28981 .37668 L
.28509 .37196 L
.28517 .36712 L
.28498 .36697 L
.2803 .36229 L
.28015 .36219 L
.27542 .35746 L
.27551 .35263 L
.27532 .35247 L
.27064 .3478 L
.27049 .34769 L
.26576 .34296 L
.26585 .33813 L
.26566 .33797 L
.26098 .3333 L
.26082 .33319 L
.25611 .32847 L
.25599 .32843 L
.2512 .32364 L
.25133 .31881 L
.25116 .31868 L
.24645 .31397 L
.24633 .31391 L
.24156 .30914 L
.24167 .30431 L
.2415 .30417 L
.23681 .29948 L
.23666 .29938 L
.23193 .29465 L
.23202 .28981 L
.23183 .28965 L
.22716 .28498 L
.227 .28486 L
.22229 .28015 L
.22217 .28009 L
.21739 .27532 L
.21752 .27049 L
.21734 .27034 L
.21265 .26566 L
.2125 .26555 L
.20777 .26082 L
.20787 .25599 L
.20767 .25582 L
.20301 .25116 L
.20284 .25102 L
.19814 .24633 L
.19801 .24624 L
.19327 .2415 L
.19337 .23666 L
.19318 .23649 L
.18851 .23183 L
.18835 .2317 L
.18365 .227 L
.18351 .22691 L
.17877 .22217 L
.17888 .21734 L
.17868 .21716 L
.17402 .2125 L
.17385 .21237 L
.16916 .20767 L
.16902 .20758 L
.16428 .20284 L
.16439 .19801 L
.16419 .19783 L
.15953 .19318 L
.15935 .19303 L
.15467 .18835 L
.15452 .18823 L
.1498 .18351 L
.14969 .18346 L
.14491 .17868 L
.14505 .17385 L
.14486 .17368 L
.14019 .16902 L
.14003 .16888 L
.13533 .16419 L
.1352 .16409 L
.13046 .15935 L
.13036 .15934 L
.12555 .15452 L
.12572 .14969 L
.12553 .14953 L
.12086 .14486 L
.1207 .14473 L
.116 .14003 L
.11587 .13994 L
.11113 .1352 L
.11104 .13518 L
.10622 .13036 L
.10639 .12553 L
.1062 .12537 L
.10154 .1207 L
.10137 .12056 L
.09668 .11587 L
.09654 .11576 L
.09181 .11104 L
.09171 .11098 L
.08693 .1062 L
.08708 .10137 L
.08688 .10119 L
.08222 .09654 L
.08204 .09638 L
.07737 .09171 L
.07721 .09158 L
.07251 .08688 L
.07238 .08678 L
.06764 .08204 L
.06755 .08201 L
.06276 .07721 L
.06292 .07238 L
.06272 .0722 L
.05807 .06755 L
.05789 .06739 L
.05321 .06272 L
.05305 .06258 L
.04836 .05789 L
.04822 .05778 L
.04349 .05305 L
.04339 .05299 L
.03862 .04822 L
.03877 .04339 L
.03856 .04319 L
.03392 .03856 L
.03373 .03838 L
.02907 .03373 L
.02889 .03357 L
.02422 .02889 L
.02406 .02876 L
.01928 .02406 L
.01923 .02379 L
F
0 g
.01923 .70969 m
.02307 .70535 L
.02406 .70485 L
.02838 .70052 L
.02889 .70001 L
.03373 .69998 L
.03801 .69569 L
.03856 .69514 L
.04283 .69086 L
.04339 .6903 L
.04765 .68603 L
.04822 .68546 L
.05248 .68119 L
.05305 .68062 L
.0573 .67636 L
.05789 .67578 L
.06272 .67575 L
.06692 .67153 L
.06755 .67091 L
.07175 .6667 L
.07238 .66606 L
.07657 .66187 L
.07721 .66122 L
.08139 .65704 L
.08204 .65638 L
.08622 .6522 L
.08688 .65154 L
.09171 .65151 L
.09584 .64737 L
.09654 .64667 L
.10066 .64254 L
.10137 .64183 L
.10549 .63771 L
.1062 .63699 L
.11031 .63288 L
.11104 .63215 L
.11587 .63212 L
.11993 .62804 L
.1207 .62728 L
.12476 .62321 L
.12553 .62244 L
.12958 .61838 L
.13036 .6176 L
.1344 .61355 L
.1352 .61276 L
.13923 .60872 L
.14003 .60792 L
.14486 .60789 L
.14885 .60388 L
.14969 .60305 L
Mistroke
.15368 .59905 L
.15452 .59821 L
.1585 .59422 L
.15935 .59336 L
.16332 .58939 L
.16419 .58852 L
.16815 .58456 L
.16902 .58368 L
.17385 .58365 L
.17777 .57973 L
.17868 .57881 L
.18259 .57489 L
.18351 .57397 L
.18742 .57006 L
.18835 .56913 L
.19224 .56523 L
.19318 .56429 L
.19801 .56426 L
.20187 .5604 L
.20284 .55942 L
.20669 .55557 L
.20767 .55458 L
.21151 .55073 L
.2125 .54974 L
.21634 .5459 L
.21734 .5449 L
.22116 .54107 L
.22217 .54006 L
.227 .54003 L
.23079 .53624 L
.23183 .53519 L
.23561 .53141 L
.23666 .53035 L
.24043 .52658 L
.2415 .52551 L
.24526 .52174 L
.24633 .52067 L
.25116 .52064 L
.25488 .51691 L
.25599 .5158 L
.25971 .51208 L
.26082 .51096 L
.26453 .50725 L
.26566 .50612 L
.26935 .50242 L
.27049 .50128 L
.27418 .49758 L
.27532 .49644 L
.28015 .49641 L
.2838 .49275 L
Mistroke
.28498 .49157 L
.28863 .48792 L
.28981 .48673 L
.29345 .48309 L
.29465 .48189 L
.29827 .47826 L
.29948 .47705 L
.3031 .47342 L
.30431 .47221 L
.30914 .47218 L
.31272 .46859 L
.31397 .46734 L
.31755 .46376 L
.31881 .4625 L
.32237 .45893 L
.32364 .45766 L
.3272 .4541 L
.32847 .45282 L
.3333 .45279 L
.33339 .44927 L
.33347 .44443 L
.3333 .44431 L
.32859 .4396 L
.32847 .43955 L
.32369 .43477 L
.32379 .42994 L
.32364 .42984 L
.31891 .42511 L
.31898 .42027 L
.31881 .42014 L
.31411 .41544 L
.31397 .41536 L
.30922 .41061 L
.30931 .40578 L
.30914 .40565 L
.30443 .40095 L
.30431 .40089 L
.29953 .39612 L
.29964 .39128 L
.29948 .39117 L
.29476 .38645 L
.29465 .38643 L
.28984 .38162 L
.28997 .37679 L
.28981 .37668 L
.28509 .37196 L
.28517 .36712 L
.28498 .36697 L
.2803 .36229 L
.28015 .36219 L
Mistroke
.27542 .35746 L
.27551 .35263 L
.27532 .35247 L
.27064 .3478 L
.27049 .34769 L
.26576 .34296 L
.26585 .33813 L
.26566 .33797 L
.26098 .3333 L
.26082 .33319 L
.25611 .32847 L
.25599 .32843 L
.2512 .32364 L
.25133 .31881 L
.25116 .31868 L
.24645 .31397 L
.24633 .31391 L
.24156 .30914 L
.24167 .30431 L
.2415 .30417 L
.23681 .29948 L
.23666 .29938 L
.23193 .29465 L
.23202 .28981 L
.23183 .28965 L
.22716 .28498 L
.227 .28486 L
.22229 .28015 L
.22217 .28009 L
.21739 .27532 L
.21752 .27049 L
.21734 .27034 L
.21265 .26566 L
.2125 .26555 L
.20777 .26082 L
.20787 .25599 L
.20767 .25582 L
.20301 .25116 L
.20284 .25102 L
.19814 .24633 L
.19801 .24624 L
.19327 .2415 L
.19337 .23666 L
.19318 .23649 L
.18851 .23183 L
.18835 .2317 L
.18365 .227 L
.18351 .22691 L
.17877 .22217 L
.17888 .21734 L
Mistroke
.17868 .21716 L
.17402 .2125 L
.17385 .21237 L
.16916 .20767 L
.16902 .20758 L
.16428 .20284 L
.16439 .19801 L
.16419 .19783 L
.15953 .19318 L
.15935 .19303 L
.15467 .18835 L
.15452 .18823 L
.1498 .18351 L
.14969 .18346 L
.14491 .17868 L
.14505 .17385 L
.14486 .17368 L
.14019 .16902 L
.14003 .16888 L
.13533 .16419 L
.1352 .16409 L
.13046 .15935 L
.13036 .15934 L
.12555 .15452 L
.12572 .14969 L
.12553 .14953 L
.12086 .14486 L
.1207 .14473 L
.116 .14003 L
.11587 .13994 L
.11113 .1352 L
.11104 .13518 L
.10622 .13036 L
.10639 .12553 L
.1062 .12537 L
.10154 .1207 L
.10137 .12056 L
.09668 .11587 L
.09654 .11576 L
.09181 .11104 L
.09171 .11098 L
.08693 .1062 L
.08708 .10137 L
.08688 .10119 L
.08222 .09654 L
.08204 .09638 L
.07737 .09171 L
.07721 .09158 L
.07251 .08688 L
.07238 .08678 L
Mistroke
.06764 .08204 L
.06755 .08201 L
.06276 .07721 L
.06292 .07238 L
.06272 .0722 L
.05807 .06755 L
.05789 .06739 L
.05321 .06272 L
.05305 .06258 L
.04836 .05789 L
.04822 .05778 L
.04349 .05305 L
.04339 .05299 L
.03862 .04822 L
.03877 .04339 L
.03856 .04319 L
.03392 .03856 L
.03373 .03838 L
.02907 .03373 L
.02889 .03357 L
.02422 .02889 L
.02406 .02876 L
.01928 .02406 L
.01923 .02379 L
Mfstroke
.865 .506 0 r
.97393 .01923 m
.97111 .02328 L
.96936 .02406 L
.96627 .02715 L
.96481 .02889 L
.96144 .03269 L
.96058 .03373 L
.95661 .03824 L
.95635 .03856 L
.95193 .04339 L
.95178 .04431 L
.95007 .04822 L
.94695 .04953 L
.94477 .05305 L
.94211 .05519 L
.94022 .05789 L
.93728 .06085 L
.93575 .06272 L
.93245 .06652 L
.93161 .06755 L
.92762 .07219 L
.92746 .07238 L
.92663 .07721 L
.92279 .07795 L
.92045 .08204 L
.91796 .08372 L
.91581 .08688 L
.91312 .0895 L
.91134 .09171 L
.90829 .09527 L
.90727 .09654 L
.90346 .10105 L
.9032 .10137 L
.90191 .1062 L
.89863 .10691 L
.89611 .11104 L
.8938 .11279 L
.89167 .11587 L
.88896 .11868 L
.88736 .1207 L
.88413 .12456 L
.88337 .12553 L
.88385 .13036 L
.8793 .13046 L
.87662 .1352 L
.87447 .13645 L
.87207 .14003 L
.86964 .14244 L
.86775 .14486 L
.8648 .14843 L
.86383 .14969 L
.85997 .15442 L
.85989 .15452 L
.85708 .15935 L
.85514 .16051 L
.85266 .16419 L
.85031 .1666 L
.84846 .16902 L
.84548 .17269 L
.84459 .17385 L
.8435 .17868 L
.84065 .17879 L
.83764 .18351 L
.83581 .18499 L
.83326 .18835 L
.83098 .19118 L
.82948 .19318 L
.82615 .19737 L
.82567 .19801 L
.82279 .20284 L
.82132 .20362 L
.81827 .20767 L
.81649 .20991 L
.81456 .2125 L
.81165 .2162 L
.81082 .21734 L
.80798 .22217 L
.80682 .22252 L
.80386 .227 L
.80199 .22891 L
.79984 .23183 L
.79716 .23529 L
.79616 .23666 L
.79305 .2415 L
.79233 .2417 L
.78894 .24633 L
.7875 .24819 L
.78535 .25116 L
.78266 .25467 L
.78172 .25599 L
.7785 .26082 L
.77783 .26119 L
.77461 .26566 L
.773 .26777 L
.77107 .27049 L
.76817 .27436 L
.76749 .27532 L
.76431 .28015 L
.76334 .28099 L
.76051 .28498 L
.7585 .28767 L
.75701 .28981 L
.75367 .29436 L
.75347 .29465 L
.75006 .29948 L
.74884 .30112 L
.74663 .30431 L
.74401 .3079 L
.74316 .30914 L
.73996 .31397 L
.73918 .31473 L
.73637 .31881 L
.73434 .3216 L
.73296 .32364 L
.72954 .32847 L
.72951 .32849 L
.72623 .3333 L
.72468 .33546 L
.72288 .33813 L
.71985 .34245 L
.7195 .34296 L
.71622 .3478 L
.71502 .3495 L
.71293 .35263 L
.71019 .35658 L
.7096 .35746 L
.70635 .36229 L
.70535 .36372 L
.70311 .36712 L
.70052 .3709 L
.69983 .37196 L
.69661 .37679 L
.69569 .37813 L
.69342 .38162 L
.69086 .38541 L
.69019 .38645 L
.68702 .39128 L
.68603 .39275 L
.68387 .39612 L
.68119 .40013 L
.68068 .40095 L
.67756 .40578 L
.67636 .40758 L
.67445 .41061 L
.67153 .41507 L
.6713 .41544 L
.66825 .42027 L
.6667 .42264 L
.66517 .42511 L
.66207 .42994 L
.66187 .43025 L
.65907 .43477 L
.65704 .43796 L
.65535 .4396 L
.6522 .44184 L
.6507 .44443 L
.64763 .44927 L
.64737 .44967 L
.64462 .4541 L
.64254 .45738 L
.64158 .45893 L
.63857 .46376 L
.63771 .46513 L
.63559 .46859 L
.63288 .47294 L
.63258 .47342 L
.62963 .47826 L
.62804 .48082 L
.62667 .48309 L
.62372 .48792 L
.62321 .48874 L
.6208 .49275 L
.61838 .49672 L
.61787 .49758 L
.61497 .50242 L
.61355 .50476 L
.61208 .50725 L
.60918 .51208 L
.60872 .51285 L
.60633 .51691 L
.60388 .521 L
.60345 .52174 L
.60061 .52658 L
.59905 .5292 L
.59777 .53141 L
.59494 .53624 L
.59422 .53745 L
.59212 .54107 L
.58939 .54574 L
.5893 .5459 L
.58651 .55073 L
.58456 .55407 L
.5837 .55557 L
.58091 .5604 L
.57973 .56244 L
.57813 .56523 L
.57534 .57006 L
.57489 .57082 L
.57257 .57489 L
.57006 .57922 L
.56977 .57973 L
.567 .58456 L
.56523 .58761 L
.56421 .58939 L
.56142 .59422 L
.5604 .59598 L
.55863 .59905 L
.5558 .60388 L
.55557 .60428 L
.55298 .60872 L
.55073 .6125 L
.55012 .61355 L
.54723 .61838 L
.5459 .62057 L
.54431 .62321 L
.54132 .62804 L
.54107 .62844 L
.53829 .63288 L
.53624 .63603 L
.53515 .63771 L
.53189 .64254 L
.53141 .64323 L
.52849 .64737 L
.52658 .64992 L
.52484 .6522 L
.52174 .65594 L
.52082 .65704 L
.51691 .66111 L
.51617 .66187 L
.51208 .66524 L
.51023 .6667 L
.50725 .66812 L
.50242 .66961 L
.49758 .66961 L
.49275 .66812 L
.48977 .6667 L
.48792 .66524 L
.48383 .66187 L
.48309 .66111 L
.47918 .65704 L
.47826 .65594 L
.47516 .6522 L
.47342 .64992 L
.47151 .64737 L
.46859 .64323 L
.46811 .64254 L
.46485 .63771 L
.46376 .63603 L
.46172 .63288 L
.45893 .62844 L
.45868 .62804 L
.45569 .62321 L
.4541 .62057 L
.45277 .61838 L
.44989 .61355 L
.44927 .61249 L
.44702 .60872 L
.44443 .60428 L
.4442 .60388 L
.44138 .59905 L
.4396 .59597 L
.43858 .59422 L
.43579 .58939 L
.43477 .58761 L
.433 .58456 L
.43023 .57973 L
.42994 .57922 L
.42743 .57489 L
.42511 .57082 L
.42466 .57006 L
.42187 .56523 L
.42027 .56244 L
.41909 .5604 L
.4163 .55557 L
.41544 .55407 L
.41349 .55073 L
.4107 .5459 L
.41061 .54574 L
.40788 .54107 L
.40578 .53745 L
.40506 .53624 L
.40223 .53141 L
.40095 .5292 L
.39939 .52658 L
.39655 .52174 L
.39612 .521 L
.39367 .51691 L
.39128 .51285 L
.39082 .51208 L
.38792 .50725 L
.38645 .50476 L
.38503 .50242 L
.38213 .49758 L
.38162 .49672 L
.3792 .49275 L
.37679 .48874 L
.37628 .48792 L
.37333 .48309 L
.37196 .48082 L
.37037 .47826 L
.36742 .47342 L
.36712 .47294 L
.36441 .46859 L
.36229 .46513 L
.36143 .46376 L
.35842 .45893 L
.35746 .45737 L
.35538 .4541 L
.35263 .44967 L
.35237 .44927 L
.3493 .44443 L
.3478 .44184 L
.34465 .4396 L
.34296 .43796 L
.34094 .43477 L
.33813 .43025 L
.33793 .42994 L
.33483 .42511 L
.3333 .42264 L
.33175 .42027 L
.3287 .41544 L
.32847 .41507 L
.32555 .41061 L
.32364 .40758 L
.32244 .40578 L
.31932 .40095 L
.31881 .40013 L
.31613 .39612 L
.31397 .39275 L
.31298 .39128 L
.30981 .38645 L
.30914 .38541 L
.30658 .38162 L
.30431 .37813 L
.30339 .37679 L
.30017 .37196 L
.29948 .3709 L
.29689 .36712 L
.29465 .36372 L
.29365 .36229 L
.2904 .35746 L
.28981 .35658 L
.28707 .35263 L
.28498 .3495 L
.28378 .3478 L
.2805 .34296 L
.28015 .34245 L
.27712 .33813 L
.27532 .33546 L
.27377 .3333 L
.27049 .32849 L
.27046 .32847 L
.26704 .32364 L
.26566 .3216 L
.26363 .31881 L
.26082 .31473 L
.26004 .31397 L
.25684 .30914 L
.25599 .3079 L
.25337 .30431 L
.25116 .30112 L
.24994 .29948 L
.24653 .29465 L
.24633 .29436 L
.243 .28981 L
.2415 .28767 L
.23949 .28498 L
.23666 .28099 L
.23569 .28015 L
.23251 .27532 L
.23183 .27436 L
.22893 .27049 L
.227 .26777 L
.22539 .26566 L
.22217 .26119 L
.2215 .26082 L
.21828 .25599 L
.21734 .25467 L
.21465 .25116 L
.2125 .24819 L
.21106 .24633 L
.20767 .2417 L
.20695 .2415 L
.20384 .23666 L
.20284 .23529 L
.20016 .23183 L
.19801 .22891 L
.19614 .227 L
.19318 .22252 L
.19202 .22217 L
.18919 .21734 L
.18835 .2162 L
.18544 .2125 L
.18351 .20991 L
.18173 .20767 L
.17868 .20362 L
.17721 .20284 L
.17433 .19801 L
.17385 .19737 L
.17052 .19318 L
.16902 .19118 L
.16674 .18835 L
.16419 .18499 L
.16236 .18351 L
.15935 .17879 L
.1565 .17868 L
.15541 .17385 L
.15452 .17269 L
.15155 .16902 L
.14969 .1666 L
.14734 .16419 L
.14486 .16051 L
.14293 .15935 L
.14011 .15452 L
.14003 .15442 L
.13617 .14969 L
.1352 .14843 L
.13225 .14486 L
.13036 .14244 L
.12793 .14003 L
.12553 .13645 L
.12338 .1352 L
.1207 .13046 L
.11615 .13036 L
.11663 .12553 L
.11587 .12456 L
.11264 .1207 L
.11104 .11868 L
.10833 .11587 L
.1062 .11279 L
.1039 .11104 L
.10137 .10691 L
.09809 .1062 L
.0968 .10137 L
.09654 .10105 L
.09273 .09654 L
.09171 .09527 L
.08866 .09171 L
.08688 .0895 L
.08419 .08688 L
.08204 .08372 L
.07955 .08204 L
.07721 .07795 L
.07337 .07721 L
.07254 .07238 L
.07238 .07219 L
.06839 .06755 L
.06755 .06652 L
.06425 .06272 L
.06272 .06085 L
.05978 .05789 L
.05789 .05519 L
.05523 .05305 L
.05305 .04953 L
.04993 .04822 L
.04822 .04431 L
.04807 .04339 L
.04365 .03856 L
.04339 .03824 L
.03942 .03373 L
.03856 .03269 L
.03519 .02889 L
.03373 .02715 L
.03064 .02406 L
.02889 .02328 L
.02607 .01923 L
F
0 g
.97393 .01923 m
.97111 .02328 L
.96936 .02406 L
.96627 .02715 L
.96481 .02889 L
.96144 .03269 L
.96058 .03373 L
.95661 .03824 L
.95635 .03856 L
.95193 .04339 L
.95178 .04431 L
.95007 .04822 L
.94695 .04953 L
.94477 .05305 L
.94211 .05519 L
.94022 .05789 L
.93728 .06085 L
.93575 .06272 L
.93245 .06652 L
.93161 .06755 L
.92762 .07219 L
.92746 .07238 L
.92663 .07721 L
.92279 .07795 L
.92045 .08204 L
.91796 .08372 L
.91581 .08688 L
.91312 .0895 L
.91134 .09171 L
.90829 .09527 L
.90727 .09654 L
.90346 .10105 L
.9032 .10137 L
.90191 .1062 L
.89863 .10691 L
.89611 .11104 L
.8938 .11279 L
.89167 .11587 L
.88896 .11868 L
.88736 .1207 L
.88413 .12456 L
.88337 .12553 L
.88385 .13036 L
.8793 .13046 L
.87662 .1352 L
.87447 .13645 L
.87207 .14003 L
.86964 .14244 L
.86775 .14486 L
.8648 .14843 L
Mistroke
.86383 .14969 L
.85997 .15442 L
.85989 .15452 L
.85708 .15935 L
.85514 .16051 L
.85266 .16419 L
.85031 .1666 L
.84846 .16902 L
.84548 .17269 L
.84459 .17385 L
.8435 .17868 L
.84065 .17879 L
.83764 .18351 L
.83581 .18499 L
.83326 .18835 L
.83098 .19118 L
.82948 .19318 L
.82615 .19737 L
.82567 .19801 L
.82279 .20284 L
.82132 .20362 L
.81827 .20767 L
.81649 .20991 L
.81456 .2125 L
.81165 .2162 L
.81082 .21734 L
.80798 .22217 L
.80682 .22252 L
.80386 .227 L
.80199 .22891 L
.79984 .23183 L
.79716 .23529 L
.79616 .23666 L
.79305 .2415 L
.79233 .2417 L
.78894 .24633 L
.7875 .24819 L
.78535 .25116 L
.78266 .25467 L
.78172 .25599 L
.7785 .26082 L
.77783 .26119 L
.77461 .26566 L
.773 .26777 L
.77107 .27049 L
.76817 .27436 L
.76749 .27532 L
.76431 .28015 L
.76334 .28099 L
.76051 .28498 L
Mistroke
.7585 .28767 L
.75701 .28981 L
.75367 .29436 L
.75347 .29465 L
.75006 .29948 L
.74884 .30112 L
.74663 .30431 L
.74401 .3079 L
.74316 .30914 L
.73996 .31397 L
.73918 .31473 L
.73637 .31881 L
.73434 .3216 L
.73296 .32364 L
.72954 .32847 L
.72951 .32849 L
.72623 .3333 L
.72468 .33546 L
.72288 .33813 L
.71985 .34245 L
.7195 .34296 L
.71622 .3478 L
.71502 .3495 L
.71293 .35263 L
.71019 .35658 L
.7096 .35746 L
.70635 .36229 L
.70535 .36372 L
.70311 .36712 L
.70052 .3709 L
.69983 .37196 L
.69661 .37679 L
.69569 .37813 L
.69342 .38162 L
.69086 .38541 L
.69019 .38645 L
.68702 .39128 L
.68603 .39275 L
.68387 .39612 L
.68119 .40013 L
.68068 .40095 L
.67756 .40578 L
.67636 .40758 L
.67445 .41061 L
.67153 .41507 L
.6713 .41544 L
.66825 .42027 L
.6667 .42264 L
.66517 .42511 L
.66207 .42994 L
Mistroke
.66187 .43025 L
.65907 .43477 L
.65704 .43796 L
.65535 .4396 L
.6522 .44184 L
.6507 .44443 L
.64763 .44927 L
.64737 .44967 L
.64462 .4541 L
.64254 .45738 L
.64158 .45893 L
.63857 .46376 L
.63771 .46513 L
.63559 .46859 L
.63288 .47294 L
.63258 .47342 L
.62963 .47826 L
.62804 .48082 L
.62667 .48309 L
.62372 .48792 L
.62321 .48874 L
.6208 .49275 L
.61838 .49672 L
.61787 .49758 L
.61497 .50242 L
.61355 .50476 L
.61208 .50725 L
.60918 .51208 L
.60872 .51285 L
.60633 .51691 L
.60388 .521 L
.60345 .52174 L
.60061 .52658 L
.59905 .5292 L
.59777 .53141 L
.59494 .53624 L
.59422 .53745 L
.59212 .54107 L
.58939 .54574 L
.5893 .5459 L
.58651 .55073 L
.58456 .55407 L
.5837 .55557 L
.58091 .5604 L
.57973 .56244 L
.57813 .56523 L
.57534 .57006 L
.57489 .57082 L
.57257 .57489 L
.57006 .57922 L
Mistroke
.56977 .57973 L
.567 .58456 L
.56523 .58761 L
.56421 .58939 L
.56142 .59422 L
.5604 .59598 L
.55863 .59905 L
.5558 .60388 L
.55557 .60428 L
.55298 .60872 L
.55073 .6125 L
.55012 .61355 L
.54723 .61838 L
.5459 .62057 L
.54431 .62321 L
.54132 .62804 L
.54107 .62844 L
.53829 .63288 L
.53624 .63603 L
.53515 .63771 L
.53189 .64254 L
.53141 .64323 L
.52849 .64737 L
.52658 .64992 L
.52484 .6522 L
.52174 .65594 L
.52082 .65704 L
.51691 .66111 L
.51617 .66187 L
.51208 .66524 L
.51023 .6667 L
.50725 .66812 L
.50242 .66961 L
.49758 .66961 L
.49275 .66812 L
.48977 .6667 L
.48792 .66524 L
.48383 .66187 L
.48309 .66111 L
.47918 .65704 L
.47826 .65594 L
.47516 .6522 L
.47342 .64992 L
.47151 .64737 L
.46859 .64323 L
.46811 .64254 L
.46485 .63771 L
.46376 .63603 L
.46172 .63288 L
.45893 .62844 L
Mistroke
.45868 .62804 L
.45569 .62321 L
.4541 .62057 L
.45277 .61838 L
.44989 .61355 L
.44927 .61249 L
.44702 .60872 L
.44443 .60428 L
.4442 .60388 L
.44138 .59905 L
.4396 .59597 L
.43858 .59422 L
.43579 .58939 L
.43477 .58761 L
.433 .58456 L
.43023 .57973 L
.42994 .57922 L
.42743 .57489 L
.42511 .57082 L
.42466 .57006 L
.42187 .56523 L
.42027 .56244 L
.41909 .5604 L
.4163 .55557 L
.41544 .55407 L
.41349 .55073 L
.4107 .5459 L
.41061 .54574 L
.40788 .54107 L
.40578 .53745 L
.40506 .53624 L
.40223 .53141 L
.40095 .5292 L
.39939 .52658 L
.39655 .52174 L
.39612 .521 L
.39367 .51691 L
.39128 .51285 L
.39082 .51208 L
.38792 .50725 L
.38645 .50476 L
.38503 .50242 L
.38213 .49758 L
.38162 .49672 L
.3792 .49275 L
.37679 .48874 L
.37628 .48792 L
.37333 .48309 L
.37196 .48082 L
.37037 .47826 L
Mistroke
.36742 .47342 L
.36712 .47294 L
.36441 .46859 L
.36229 .46513 L
.36143 .46376 L
.35842 .45893 L
.35746 .45737 L
.35538 .4541 L
.35263 .44967 L
.35237 .44927 L
.3493 .44443 L
.3478 .44184 L
.34465 .4396 L
.34296 .43796 L
.34094 .43477 L
.33813 .43025 L
.33793 .42994 L
.33483 .42511 L
.3333 .42264 L
.33175 .42027 L
.3287 .41544 L
.32847 .41507 L
.32555 .41061 L
.32364 .40758 L
.32244 .40578 L
.31932 .40095 L
.31881 .40013 L
.31613 .39612 L
.31397 .39275 L
.31298 .39128 L
.30981 .38645 L
.30914 .38541 L
.30658 .38162 L
.30431 .37813 L
.30339 .37679 L
.30017 .37196 L
.29948 .3709 L
.29689 .36712 L
.29465 .36372 L
.29365 .36229 L
.2904 .35746 L
.28981 .35658 L
.28707 .35263 L
.28498 .3495 L
.28378 .3478 L
.2805 .34296 L
.28015 .34245 L
.27712 .33813 L
.27532 .33546 L
.27377 .3333 L
Mistroke
.27049 .32849 L
.27046 .32847 L
.26704 .32364 L
.26566 .3216 L
.26363 .31881 L
.26082 .31473 L
.26004 .31397 L
.25684 .30914 L
.25599 .3079 L
.25337 .30431 L
.25116 .30112 L
.24994 .29948 L
.24653 .29465 L
.24633 .29436 L
.243 .28981 L
.2415 .28767 L
.23949 .28498 L
.23666 .28099 L
.23569 .28015 L
.23251 .27532 L
.23183 .27436 L
.22893 .27049 L
.227 .26777 L
.22539 .26566 L
.22217 .26119 L
.2215 .26082 L
.21828 .25599 L
.21734 .25467 L
.21465 .25116 L
.2125 .24819 L
.21106 .24633 L
.20767 .2417 L
.20695 .2415 L
.20384 .23666 L
.20284 .23529 L
.20016 .23183 L
.19801 .22891 L
.19614 .227 L
.19318 .22252 L
.19202 .22217 L
.18919 .21734 L
.18835 .2162 L
.18544 .2125 L
.18351 .20991 L
.18173 .20767 L
.17868 .20362 L
.17721 .20284 L
.17433 .19801 L
.17385 .19737 L
.17052 .19318 L
Mistroke
.16902 .19118 L
.16674 .18835 L
.16419 .18499 L
.16236 .18351 L
.15935 .17879 L
.1565 .17868 L
.15541 .17385 L
.15452 .17269 L
.15155 .16902 L
.14969 .1666 L
.14734 .16419 L
.14486 .16051 L
.14293 .15935 L
.14011 .15452 L
.14003 .15442 L
.13617 .14969 L
.1352 .14843 L
.13225 .14486 L
.13036 .14244 L
.12793 .14003 L
.12553 .13645 L
.12338 .1352 L
.1207 .13046 L
.11615 .13036 L
.11663 .12553 L
.11587 .12456 L
.11264 .1207 L
.11104 .11868 L
.10833 .11587 L
.1062 .11279 L
.1039 .11104 L
.10137 .10691 L
.09809 .1062 L
.0968 .10137 L
.09654 .10105 L
.09273 .09654 L
.09171 .09527 L
.08866 .09171 L
.08688 .0895 L
.08419 .08688 L
.08204 .08372 L
.07955 .08204 L
.07721 .07795 L
.07337 .07721 L
.07254 .07238 L
.07238 .07219 L
.06839 .06755 L
.06755 .06652 L
.06425 .06272 L
.06272 .06085 L
Mistroke
.05978 .05789 L
.05789 .05519 L
.05523 .05305 L
.05305 .04953 L
.04993 .04822 L
.04822 .04431 L
.04807 .04339 L
.04365 .03856 L
.04339 .03824 L
.03942 .03373 L
.03856 .03269 L
.03519 .02889 L
.03373 .02715 L
.03064 .02406 L
.02889 .02328 L
.02607 .01923 L
Mfstroke
.82 .64 0 r
.97285 .01923 m
.97111 .02296 L
.96833 .02406 L
.96627 .02587 L
.9637 .02889 L
.96144 .03144 L
.9595 .03373 L
.95661 .03701 L
.9553 .03856 L
.95178 .04259 L
.9511 .04339 L
.94695 .04818 L
.94691 .04822 L
.94355 .05305 L
.94211 .05385 L
.93914 .05789 L
.93728 .05952 L
.93462 .06272 L
.93245 .0652 L
.93051 .06755 L
.92762 .07089 L
.92639 .07238 L
.92279 .07659 L
.92227 .07721 L
.91892 .08204 L
.91796 .08232 L
.91463 .08688 L
.91312 .08811 L
.91017 .09171 L
.90829 .0939 L
.90614 .09654 L
.90346 .0997 L
.9021 .10137 L
.89863 .1055 L
.89806 .1062 L
.89448 .11104 L
.8938 .11134 L
.89048 .11587 L
.88896 .11724 L
.88618 .1207 L
.88413 .12314 L
.88222 .12553 L
.8793 .12904 L
.87825 .13036 L
.87447 .13496 L
.87428 .1352 L
.87074 .14003 L
.86964 .14094 L
.86653 .14486 L
.8648 .14695 L
.86265 .14969 L
.85997 .15295 L
.85875 .15452 L
.85514 .15897 L
.85484 .15935 L
.8513 .16419 L
.85031 .16505 L
.84722 .16902 L
.84548 .17115 L
.84339 .17385 L
.84065 .17727 L
.83956 .17868 L
.83581 .18339 L
.83572 .18351 L
.83198 .18835 L
.83098 .18958 L
.82823 .19318 L
.82615 .19579 L
.82446 .19801 L
.82132 .202 L
.82069 .20284 L
.81695 .20767 L
.81649 .20826 L
.81327 .2125 L
.81165 .21456 L
.80957 .21734 L
.80682 .22087 L
.80585 .22217 L
.80222 .227 L
.80199 .2272 L
.79853 .23183 L
.79716 .2336 L
.79489 .23666 L
.79233 .24 L
.79123 .2415 L
.78757 .24633 L
.7875 .24643 L
.78401 .25116 L
.78266 .25292 L
.78043 .25599 L
.77783 .25943 L
.77682 .26082 L
.77323 .26566 L
.773 .26596 L
.76972 .27049 L
.76817 .27255 L
.76618 .27532 L
.76334 .27915 L
.76263 .28015 L
.75911 .28498 L
.7585 .2858 L
.75565 .28981 L
.75367 .29249 L
.75215 .29465 L
.74884 .2992 L
.74865 .29948 L
.74523 .30431 L
.74401 .30598 L
.7418 .30914 L
.73918 .31277 L
.73835 .31397 L
.73493 .31881 L
.73434 .31961 L
.73156 .32364 L
.72951 .3265 L
.72816 .32847 L
.72476 .3333 L
.72468 .33341 L
.72145 .33813 L
.71985 .34039 L
.71811 .34296 L
.71502 .34739 L
.71475 .3478 L
.71146 .35263 L
.71019 .35446 L
.70817 .35746 L
.70535 .36155 L
.70486 .36229 L
.70161 .36712 L
.70052 .36871 L
.69837 .37196 L
.69569 .3759 L
.69511 .37679 L
.6919 .38162 L
.69086 .38315 L
.6887 .38645 L
.68603 .39045 L
.68548 .39128 L
.68232 .39612 L
.68119 .3978 L
.67917 .40095 L
.67636 .4052 L
.67599 .40578 L
.67288 .41061 L
.67153 .41266 L
.66977 .41544 L
.6667 .42017 L
.66663 .42027 L
.66358 .42511 L
.66187 .42775 L
.6605 .42994 L
.65742 .43477 L
.65704 .43538 L
.6522 .43922 L
.65157 .4396 L
.64858 .44443 L
.64737 .44632 L
.64551 .44927 L
.64254 .45393 L
.64244 .4541 L
.6394 .45893 L
.63771 .4616 L
.63636 .46376 L
.63333 .46859 L
.63288 .46932 L
.63033 .47342 L
.62804 .47708 L
.62733 .47826 L
.62434 .48309 L
.62321 .4849 L
.62137 .48792 L
.61839 .49275 L
.61838 .49277 L
.61545 .49758 L
.61355 .50068 L
.6125 .50242 L
.60957 .50725 L
.60872 .50865 L
.60665 .51208 L
.60388 .51665 L
.60373 .51691 L
.60084 .52174 L
.59905 .5247 L
.59794 .52658 L
.59505 .53141 L
.59422 .53278 L
.59217 .53624 L
.58939 .54089 L
.58928 .54107 L
.58643 .5459 L
.58456 .54903 L
.58356 .55073 L
.58069 .55557 L
.57973 .55719 L
.57784 .5604 L
.57496 .56523 L
.57489 .56535 L
.57211 .57006 L
.57006 .5735 L
.56924 .57489 L
.56637 .57973 L
.56523 .58162 L
.56348 .58456 L
.56058 .58939 L
.5604 .58969 L
.55767 .59422 L
.55557 .59767 L
.55473 .59905 L
.55176 .60388 L
.55073 .60553 L
.54876 .60872 L
.5459 .61322 L
.5457 .61355 L
.54259 .61838 L
.54107 .62068 L
.53939 .62321 L
.53624 .62782 L
.53608 .62804 L
.53265 .63288 L
.53141 .63455 L
.52902 .63771 L
.52658 .64075 L
.52511 .64254 L
.52174 .64629 L
.52074 .64737 L
.51691 .65101 L
.51558 .6522 L
.51208 .65473 L
.50805 .65704 L
.50725 .65732 L
.50242 .65865 L
.49758 .65865 L
.49275 .65732 L
.49195 .65704 L
.48792 .65473 L
.48442 .6522 L
.48309 .651 L
.47926 .64737 L
.47826 .64629 L
.47489 .64254 L
.47342 .64075 L
.47098 .63771 L
.46859 .63455 L
.46735 .63288 L
.46392 .62804 L
.46376 .62782 L
.46061 .62321 L
.45893 .62067 L
.45741 .61838 L
.45431 .61355 L
.4541 .61322 L
.45124 .60872 L
.44927 .60553 L
.44824 .60388 L
.44527 .59905 L
.44443 .59767 L
.44233 .59422 L
.4396 .58968 L
.43942 .58939 L
.43652 .58456 L
.43477 .58162 L
.43364 .57973 L
.43076 .57489 L
.42994 .5735 L
.42789 .57006 L
.42511 .56535 L
.42504 .56523 L
.42216 .5604 L
.42027 .55719 L
.41931 .55557 L
.41644 .55073 L
.41544 .54903 L
.41357 .5459 L
.41072 .54107 L
.41061 .54089 L
.40783 .53624 L
.40578 .53278 L
.40495 .53141 L
.40206 .52658 L
.40095 .5247 L
.39916 .52174 L
.39627 .51691 L
.39612 .51665 L
.39335 .51208 L
.39128 .50864 L
.39043 .50725 L
.3875 .50242 L
.38645 .50068 L
.38455 .49758 L
.38162 .49277 L
.38161 .49275 L
.37863 .48792 L
.37679 .4849 L
.37566 .48309 L
.37268 .47826 L
.37196 .47708 L
.36967 .47342 L
.36712 .46932 L
.36667 .46859 L
.36364 .46376 L
.36229 .4616 L
.3606 .45893 L
.35757 .4541 L
.35746 .45393 L
.35449 .44927 L
.35263 .44632 L
.35142 .44443 L
.34843 .4396 L
.3478 .43922 L
.34296 .43538 L
.34258 .43477 L
.3395 .42994 L
.33813 .42775 L
.33642 .42511 L
.33337 .42027 L
.3333 .42017 L
.33023 .41544 L
.32847 .41266 L
.32712 .41061 L
.32401 .40578 L
.32364 .4052 L
.32083 .40095 L
.31881 .3978 L
.31768 .39612 L
.31452 .39128 L
.31397 .39044 L
.3113 .38645 L
.30914 .38315 L
.3081 .38162 L
.30489 .37679 L
.30431 .3759 L
.30163 .37196 L
.29948 .36871 L
.29839 .36712 L
.29514 .36229 L
.29465 .36155 L
.29183 .35746 L
.28981 .35446 L
.28854 .35263 L
.28525 .3478 L
.28498 .34739 L
.2819 .34296 L
.28015 .34039 L
.27855 .33813 L
.27532 .33341 L
.27524 .3333 L
.27184 .32847 L
.27049 .3265 L
.26844 .32364 L
.26566 .31961 L
.26507 .31881 L
.26166 .31397 L
.26082 .31277 L
.2582 .30914 L
.25599 .30597 L
.25477 .30431 L
.25135 .29948 L
.25116 .2992 L
.24785 .29465 L
.24633 .29249 L
.24435 .28981 L
.2415 .2858 L
.24089 .28498 L
.23737 .28015 L
.23666 .27915 L
.23382 .27532 L
.23183 .27255 L
.23028 .27049 L
.227 .26596 L
.22677 .26566 L
.22318 .26082 L
.22217 .25942 L
.21957 .25599 L
.21734 .25292 L
.21599 .25116 L
.2125 .24643 L
.21243 .24633 L
.20877 .2415 L
.20767 .24 L
.20511 .23666 L
.20284 .2336 L
.20147 .23183 L
.19801 .2272 L
.19778 .227 L
.19415 .22217 L
.19318 .22087 L
.19043 .21734 L
.18835 .21456 L
.18673 .2125 L
.18351 .20826 L
.18305 .20767 L
.17932 .20284 L
.17868 .202 L
.17554 .19801 L
.17385 .19579 L
.17177 .19318 L
.16902 .18958 L
.16802 .18835 L
.16428 .18351 L
.16419 .18339 L
.16044 .17868 L
.15935 .17726 L
.15661 .17385 L
.15452 .17115 L
.15279 .16902 L
.14969 .16505 L
.1487 .16419 L
.14516 .15935 L
.14486 .15897 L
.14125 .15452 L
.14003 .15295 L
.13735 .14969 L
.1352 .14695 L
.13347 .14486 L
.13036 .14094 L
.12926 .14003 L
.12572 .1352 L
.12553 .13496 L
.12175 .13036 L
.1207 .12904 L
.11778 .12553 L
.11587 .12314 L
.11382 .1207 L
.11104 .11724 L
.10952 .11587 L
.1062 .11134 L
.10552 .11104 L
.10194 .1062 L
.10137 .1055 L
.0979 .10137 L
.09654 .0997 L
.09386 .09654 L
.09171 .0939 L
.08983 .09171 L
.08688 .08811 L
.08537 .08688 L
.08204 .08232 L
.08108 .08204 L
.07773 .07721 L
.07721 .07659 L
.07361 .07238 L
.07238 .07089 L
.06949 .06755 L
.06755 .0652 L
.06538 .06272 L
.06272 .05952 L
.06086 .05789 L
.05789 .05384 L
.05645 .05305 L
.05309 .04822 L
.05305 .04818 L
.0489 .04339 L
.04822 .04258 L
.0447 .03856 L
.04339 .03701 L
.0405 .03373 L
.03856 .03144 L
.0363 .02889 L
.03373 .02587 L
.03167 .02406 L
.02889 .02296 L
.02715 .01923 L
F
0 g
.97285 .01923 m
.97111 .02296 L
.96833 .02406 L
.96627 .02587 L
.9637 .02889 L
.96144 .03144 L
.9595 .03373 L
.95661 .03701 L
.9553 .03856 L
.95178 .04259 L
.9511 .04339 L
.94695 .04818 L
.94691 .04822 L
.94355 .05305 L
.94211 .05385 L
.93914 .05789 L
.93728 .05952 L
.93462 .06272 L
.93245 .0652 L
.93051 .06755 L
.92762 .07089 L
.92639 .07238 L
.92279 .07659 L
.92227 .07721 L
.91892 .08204 L
.91796 .08232 L
.91463 .08688 L
.91312 .08811 L
.91017 .09171 L
.90829 .0939 L
.90614 .09654 L
.90346 .0997 L
.9021 .10137 L
.89863 .1055 L
.89806 .1062 L
.89448 .11104 L
.8938 .11134 L
.89048 .11587 L
.88896 .11724 L
.88618 .1207 L
.88413 .12314 L
.88222 .12553 L
.8793 .12904 L
.87825 .13036 L
.87447 .13496 L
.87428 .1352 L
.87074 .14003 L
.86964 .14094 L
.86653 .14486 L
.8648 .14695 L
Mistroke
.86265 .14969 L
.85997 .15295 L
.85875 .15452 L
.85514 .15897 L
.85484 .15935 L
.8513 .16419 L
.85031 .16505 L
.84722 .16902 L
.84548 .17115 L
.84339 .17385 L
.84065 .17727 L
.83956 .17868 L
.83581 .18339 L
.83572 .18351 L
.83198 .18835 L
.83098 .18958 L
.82823 .19318 L
.82615 .19579 L
.82446 .19801 L
.82132 .202 L
.82069 .20284 L
.81695 .20767 L
.81649 .20826 L
.81327 .2125 L
.81165 .21456 L
.80957 .21734 L
.80682 .22087 L
.80585 .22217 L
.80222 .227 L
.80199 .2272 L
.79853 .23183 L
.79716 .2336 L
.79489 .23666 L
.79233 .24 L
.79123 .2415 L
.78757 .24633 L
.7875 .24643 L
.78401 .25116 L
.78266 .25292 L
.78043 .25599 L
.77783 .25943 L
.77682 .26082 L
.77323 .26566 L
.773 .26596 L
.76972 .27049 L
.76817 .27255 L
.76618 .27532 L
.76334 .27915 L
.76263 .28015 L
.75911 .28498 L
Mistroke
.7585 .2858 L
.75565 .28981 L
.75367 .29249 L
.75215 .29465 L
.74884 .2992 L
.74865 .29948 L
.74523 .30431 L
.74401 .30598 L
.7418 .30914 L
.73918 .31277 L
.73835 .31397 L
.73493 .31881 L
.73434 .31961 L
.73156 .32364 L
.72951 .3265 L
.72816 .32847 L
.72476 .3333 L
.72468 .33341 L
.72145 .33813 L
.71985 .34039 L
.71811 .34296 L
.71502 .34739 L
.71475 .3478 L
.71146 .35263 L
.71019 .35446 L
.70817 .35746 L
.70535 .36155 L
.70486 .36229 L
.70161 .36712 L
.70052 .36871 L
.69837 .37196 L
.69569 .3759 L
.69511 .37679 L
.6919 .38162 L
.69086 .38315 L
.6887 .38645 L
.68603 .39045 L
.68548 .39128 L
.68232 .39612 L
.68119 .3978 L
.67917 .40095 L
.67636 .4052 L
.67599 .40578 L
.67288 .41061 L
.67153 .41266 L
.66977 .41544 L
.6667 .42017 L
.66663 .42027 L
.66358 .42511 L
.66187 .42775 L
Mistroke
.6605 .42994 L
.65742 .43477 L
.65704 .43538 L
.6522 .43922 L
.65157 .4396 L
.64858 .44443 L
.64737 .44632 L
.64551 .44927 L
.64254 .45393 L
.64244 .4541 L
.6394 .45893 L
.63771 .4616 L
.63636 .46376 L
.63333 .46859 L
.63288 .46932 L
.63033 .47342 L
.62804 .47708 L
.62733 .47826 L
.62434 .48309 L
.62321 .4849 L
.62137 .48792 L
.61839 .49275 L
.61838 .49277 L
.61545 .49758 L
.61355 .50068 L
.6125 .50242 L
.60957 .50725 L
.60872 .50865 L
.60665 .51208 L
.60388 .51665 L
.60373 .51691 L
.60084 .52174 L
.59905 .5247 L
.59794 .52658 L
.59505 .53141 L
.59422 .53278 L
.59217 .53624 L
.58939 .54089 L
.58928 .54107 L
.58643 .5459 L
.58456 .54903 L
.58356 .55073 L
.58069 .55557 L
.57973 .55719 L
.57784 .5604 L
.57496 .56523 L
.57489 .56535 L
.57211 .57006 L
.57006 .5735 L
.56924 .57489 L
Mistroke
.56637 .57973 L
.56523 .58162 L
.56348 .58456 L
.56058 .58939 L
.5604 .58969 L
.55767 .59422 L
.55557 .59767 L
.55473 .59905 L
.55176 .60388 L
.55073 .60553 L
.54876 .60872 L
.5459 .61322 L
.5457 .61355 L
.54259 .61838 L
.54107 .62068 L
.53939 .62321 L
.53624 .62782 L
.53608 .62804 L
.53265 .63288 L
.53141 .63455 L
.52902 .63771 L
.52658 .64075 L
.52511 .64254 L
.52174 .64629 L
.52074 .64737 L
.51691 .65101 L
.51558 .6522 L
.51208 .65473 L
.50805 .65704 L
.50725 .65732 L
.50242 .65865 L
.49758 .65865 L
.49275 .65732 L
.49195 .65704 L
.48792 .65473 L
.48442 .6522 L
.48309 .651 L
.47926 .64737 L
.47826 .64629 L
.47489 .64254 L
.47342 .64075 L
.47098 .63771 L
.46859 .63455 L
.46735 .63288 L
.46392 .62804 L
.46376 .62782 L
.46061 .62321 L
.45893 .62067 L
.45741 .61838 L
.45431 .61355 L
Mistroke
.4541 .61322 L
.45124 .60872 L
.44927 .60553 L
.44824 .60388 L
.44527 .59905 L
.44443 .59767 L
.44233 .59422 L
.4396 .58968 L
.43942 .58939 L
.43652 .58456 L
.43477 .58162 L
.43364 .57973 L
.43076 .57489 L
.42994 .5735 L
.42789 .57006 L
.42511 .56535 L
.42504 .56523 L
.42216 .5604 L
.42027 .55719 L
.41931 .55557 L
.41644 .55073 L
.41544 .54903 L
.41357 .5459 L
.41072 .54107 L
.41061 .54089 L
.40783 .53624 L
.40578 .53278 L
.40495 .53141 L
.40206 .52658 L
.40095 .5247 L
.39916 .52174 L
.39627 .51691 L
.39612 .51665 L
.39335 .51208 L
.39128 .50864 L
.39043 .50725 L
.3875 .50242 L
.38645 .50068 L
.38455 .49758 L
.38162 .49277 L
.38161 .49275 L
.37863 .48792 L
.37679 .4849 L
.37566 .48309 L
.37268 .47826 L
.37196 .47708 L
.36967 .47342 L
.36712 .46932 L
.36667 .46859 L
.36364 .46376 L
Mistroke
.36229 .4616 L
.3606 .45893 L
.35757 .4541 L
.35746 .45393 L
.35449 .44927 L
.35263 .44632 L
.35142 .44443 L
.34843 .4396 L
.3478 .43922 L
.34296 .43538 L
.34258 .43477 L
.3395 .42994 L
.33813 .42775 L
.33642 .42511 L
.33337 .42027 L
.3333 .42017 L
.33023 .41544 L
.32847 .41266 L
.32712 .41061 L
.32401 .40578 L
.32364 .4052 L
.32083 .40095 L
.31881 .3978 L
.31768 .39612 L
.31452 .39128 L
.31397 .39044 L
.3113 .38645 L
.30914 .38315 L
.3081 .38162 L
.30489 .37679 L
.30431 .3759 L
.30163 .37196 L
.29948 .36871 L
.29839 .36712 L
.29514 .36229 L
.29465 .36155 L
.29183 .35746 L
.28981 .35446 L
.28854 .35263 L
.28525 .3478 L
.28498 .34739 L
.2819 .34296 L
.28015 .34039 L
.27855 .33813 L
.27532 .33341 L
.27524 .3333 L
.27184 .32847 L
.27049 .3265 L
.26844 .32364 L
.26566 .31961 L
Mistroke
.26507 .31881 L
.26166 .31397 L
.26082 .31277 L
.2582 .30914 L
.25599 .30597 L
.25477 .30431 L
.25135 .29948 L
.25116 .2992 L
.24785 .29465 L
.24633 .29249 L
.24435 .28981 L
.2415 .2858 L
.24089 .28498 L
.23737 .28015 L
.23666 .27915 L
.23382 .27532 L
.23183 .27255 L
.23028 .27049 L
.227 .26596 L
.22677 .26566 L
.22318 .26082 L
.22217 .25942 L
.21957 .25599 L
.21734 .25292 L
.21599 .25116 L
.2125 .24643 L
.21243 .24633 L
.20877 .2415 L
.20767 .24 L
.20511 .23666 L
.20284 .2336 L
.20147 .23183 L
.19801 .2272 L
.19778 .227 L
.19415 .22217 L
.19318 .22087 L
.19043 .21734 L
.18835 .21456 L
.18673 .2125 L
.18351 .20826 L
.18305 .20767 L
.17932 .20284 L
.17868 .202 L
.17554 .19801 L
.17385 .19579 L
.17177 .19318 L
.16902 .18958 L
.16802 .18835 L
.16428 .18351 L
.16419 .18339 L
Mistroke
.16044 .17868 L
.15935 .17726 L
.15661 .17385 L
.15452 .17115 L
.15279 .16902 L
.14969 .16505 L
.1487 .16419 L
.14516 .15935 L
.14486 .15897 L
.14125 .15452 L
.14003 .15295 L
.13735 .14969 L
.1352 .14695 L
.13347 .14486 L
.13036 .14094 L
.12926 .14003 L
.12572 .1352 L
.12553 .13496 L
.12175 .13036 L
.1207 .12904 L
.11778 .12553 L
.11587 .12314 L
.11382 .1207 L
.11104 .11724 L
.10952 .11587 L
.1062 .11134 L
.10552 .11104 L
.10194 .1062 L
.10137 .1055 L
.0979 .10137 L
.09654 .0997 L
.09386 .09654 L
.09171 .0939 L
.08983 .09171 L
.08688 .08811 L
.08537 .08688 L
.08204 .08232 L
.08108 .08204 L
.07773 .07721 L
.07721 .07659 L
.07361 .07238 L
.07238 .07089 L
.06949 .06755 L
.06755 .0652 L
.06538 .06272 L
.06272 .05952 L
.06086 .05789 L
.05789 .05384 L
.05645 .05305 L
.05309 .04822 L
Mistroke
.05305 .04818 L
.0489 .04339 L
.04822 .04258 L
.0447 .03856 L
.04339 .03701 L
.0405 .03373 L
.03856 .03144 L
.0363 .02889 L
.03373 .02587 L
.03167 .02406 L
.02889 .02296 L
.02715 .01923 L
Mfstroke
.775 .756 0 r
.97073 .01923 m
.96665 .02406 L
.96627 .02433 L
.96233 .02889 L
.96144 .0299 L
.95816 .03373 L
.95661 .03548 L
.95398 .03856 L
.95178 .04107 L
.94981 .04339 L
.94695 .04667 L
.94564 .04822 L
.94211 .05228 L
.94147 .05305 L
.93732 .05789 L
.93728 .05791 L
.93322 .06272 L
.93245 .0636 L
.92913 .06755 L
.92762 .0693 L
.92504 .07238 L
.92279 .07501 L
.92095 .07721 L
.91796 .08073 L
.91686 .08204 L
.91312 .08646 L
.91278 .08688 L
.90874 .09171 L
.90829 .09223 L
.90473 .09654 L
.90346 .09804 L
.90072 .10137 L
.89863 .10385 L
.89671 .1062 L
.8938 .10968 L
.89269 .11104 L
.88896 .11552 L
.88868 .11587 L
.88473 .1207 L
.88413 .12141 L
.88079 .12553 L
.8793 .12732 L
.87686 .13036 L
.87447 .13325 L
.87291 .1352 L
.86964 .13919 L
.86897 .14003 L
.86505 .14486 L
.8648 .14515 L
.86119 .14969 L
.85997 .15117 L
.85732 .15452 L
.85514 .1572 L
.85344 .15935 L
.85031 .16323 L
.84956 .16419 L
.84571 .16902 L
.84548 .1693 L
.84191 .17385 L
.84065 .17542 L
.8381 .17868 L
.83581 .18154 L
.83429 .18351 L
.83098 .18769 L
.83048 .18835 L
.8267 .19318 L
.82615 .19387 L
.82296 .19801 L
.82132 .20009 L
.81922 .20284 L
.81649 .20632 L
.81546 .20767 L
.81171 .2125 L
.81165 .21258 L
.80803 .21734 L
.80682 .21889 L
.80435 .22217 L
.80199 .22522 L
.80065 .227 L
.79716 .23156 L
.79696 .23183 L
.79332 .23666 L
.79233 .23796 L
.78969 .2415 L
.7875 .24438 L
.78606 .24633 L
.78266 .25082 L
.78241 .25116 L
.77883 .25599 L
.77783 .25731 L
.77526 .26082 L
.773 .26383 L
.77167 .26566 L
.76817 .27037 L
.76808 .27049 L
.76457 .27532 L
.76334 .27697 L
.76104 .28015 L
.7585 .28359 L
.75751 .28498 L
.75399 .28981 L
.75367 .29024 L
.75052 .29465 L
.74884 .29695 L
.74704 .29948 L
.74401 .30367 L
.74356 .30431 L
.74012 .30914 L
.73918 .31045 L
.7367 .31397 L
.73434 .31726 L
.73327 .31881 L
.72985 .32364 L
.72951 .3241 L
.72648 .32847 L
.72468 .331 L
.7231 .3333 L
.71985 .33792 L
.71971 .33813 L
.71638 .34296 L
.71502 .34491 L
.71305 .3478 L
.71019 .35192 L
.70971 .35263 L
.70641 .35746 L
.70535 .35899 L
.70313 .36229 L
.70052 .3661 L
.69984 .36712 L
.69658 .37196 L
.69569 .37326 L
.69334 .37679 L
.69086 .38046 L
.6901 .38162 L
.68688 .38645 L
.68603 .38772 L
.68369 .39128 L
.68119 .39502 L
.68048 .39612 L
.67731 .40095 L
.67636 .40238 L
.67416 .40578 L
.67153 .40978 L
.671 .41061 L
.66788 .41544 L
.6667 .41725 L
.66477 .42027 L
.66187 .42476 L
.66165 .42511 L
.65858 .42994 L
.65704 .43234 L
.65565 .43477 L
.6522 .43785 L
.649 .4396 L
.64737 .44229 L
.646 .44443 L
.64289 .44927 L
.64254 .4498 L
.6398 .4541 L
.63771 .45736 L
.63672 .45893 L
.63364 .46376 L
.63288 .46496 L
.63059 .46859 L
.62804 .47261 L
.62753 .47342 L
.6245 .47826 L
.62321 .4803 L
.62147 .48309 L
.61845 .48792 L
.61838 .48803 L
.61545 .49275 L
.61355 .4958 L
.61245 .49758 L
.60945 .50242 L
.60872 .5036 L
.60648 .50725 L
.60388 .51144 L
.60349 .51208 L
.60053 .51691 L
.59905 .5193 L
.59757 .52174 L
.5946 .52658 L
.59422 .52719 L
.59165 .53141 L
.58939 .5351 L
.5887 .53624 L
.58575 .54107 L
.58456 .54302 L
.5828 .5459 L
.57984 .55073 L
.57973 .55093 L
.5769 .55557 L
.57489 .55882 L
.57393 .5604 L
.57097 .56523 L
.57006 .56669 L
.56799 .57006 L
.56523 .5745 L
.56499 .57489 L
.56198 .57973 L
.5604 .58223 L
.55894 .58456 L
.55587 .58939 L
.55557 .58985 L
.55276 .59422 L
.55073 .59732 L
.5496 .59905 L
.54638 .60388 L
.5459 .60459 L
.54309 .60872 L
.54107 .61159 L
.53969 .61355 L
.53624 .61826 L
.53615 .61838 L
.53244 .62321 L
.53141 .62449 L
.52847 .62804 L
.52658 .6302 L
.52412 .63288 L
.52174 .63524 L
.5191 .63771 L
.51691 .6395 L
.51262 .64254 L
.51208 .64285 L
.50725 .64515 L
.50242 .64633 L
.49758 .64633 L
.49275 .64515 L
.48792 .64285 L
.48738 .64254 L
.48309 .6395 L
.4809 .63771 L
.47826 .63524 L
.47588 .63288 L
.47342 .63019 L
.47153 .62804 L
.46859 .62449 L
.46756 .62321 L
.46385 .61838 L
.46376 .61826 L
.46031 .61355 L
.45893 .61159 L
.45691 .60872 L
.4541 .60459 L
.45362 .60388 L
.4504 .59905 L
.44927 .59732 L
.44724 .59422 L
.44443 .58985 L
.44414 .58939 L
.44106 .58456 L
.4396 .58223 L
.43802 .57973 L
.43501 .57489 L
.43477 .5745 L
.43201 .57006 L
.42994 .56669 L
.42904 .56523 L
.42607 .5604 L
.42511 .55882 L
.4231 .55557 L
.42027 .55093 L
.42016 .55073 L
.4172 .5459 L
.41544 .54301 L
.41425 .54107 L
.4113 .53624 L
.41061 .5351 L
.40835 .53141 L
.40578 .52719 L
.4054 .52658 L
.40244 .52174 L
.40095 .5193 L
.39947 .51691 L
.39651 .51208 L
.39612 .51144 L
.39353 .50725 L
.39128 .5036 L
.39055 .50242 L
.38755 .49758 L
.38645 .49579 L
.38455 .49275 L
.38162 .48803 L
.38155 .48792 L
.37853 .48309 L
.37679 .4803 L
.3755 .47826 L
.37247 .47342 L
.37196 .47261 L
.36941 .46859 L
.36712 .46496 L
.36636 .46376 L
.36329 .45893 L
.36229 .45736 L
.3602 .4541 L
.35746 .4498 L
.35712 .44927 L
.354 .44443 L
.35263 .44229 L
.351 .4396 L
.3478 .43785 L
.34436 .43477 L
.34296 .43234 L
.34142 .42994 L
.33835 .42511 L
.33813 .42476 L
.33523 .42027 L
.3333 .41725 L
.33212 .41544 L
.329 .41061 L
.32847 .40978 L
.32584 .40578 L
.32364 .40237 L
.32269 .40095 L
.31952 .39612 L
.31881 .39502 L
.31631 .39128 L
.31397 .38771 L
.31312 .38645 L
.30991 .38162 L
.30914 .38046 L
.30666 .37679 L
.30431 .37326 L
.30342 .37196 L
.30016 .36712 L
.29948 .3661 L
.29687 .36229 L
.29465 .35899 L
.29359 .35746 L
.29029 .35263 L
.28981 .35192 L
.28695 .3478 L
.28498 .34491 L
.28362 .34296 L
.28029 .33813 L
.28015 .33792 L
.2769 .3333 L
.27532 .331 L
.27352 .32847 L
.27049 .3241 L
.27015 .32364 L
.26673 .31881 L
.26566 .31726 L
.2633 .31397 L
.26082 .31045 L
.25988 .30914 L
.25644 .30431 L
.25599 .30367 L
.25296 .29948 L
.25116 .29694 L
.24948 .29465 L
.24633 .29024 L
.24601 .28981 L
.24249 .28498 L
.2415 .28359 L
.23896 .28015 L
.23666 .27697 L
.23543 .27532 L
.23192 .27049 L
.23183 .27037 L
.22833 .26566 L
.227 .26383 L
.22474 .26082 L
.22217 .25731 L
.22117 .25599 L
.21759 .25116 L
.21734 .25082 L
.21394 .24633 L
.2125 .24438 L
.21031 .2415 L
.20767 .23796 L
.20668 .23666 L
.20304 .23183 L
.20284 .23156 L
.19935 .227 L
.19801 .22521 L
.19565 .22217 L
.19318 .21889 L
.19197 .21734 L
.18835 .21258 L
.18829 .2125 L
.18454 .20767 L
.18351 .20632 L
.18078 .20284 L
.17868 .20009 L
.17704 .19801 L
.17385 .19387 L
.1733 .19318 L
.16952 .18835 L
.16902 .18769 L
.16571 .18351 L
.16419 .18154 L
.1619 .17868 L
.15935 .17542 L
.15809 .17385 L
.15452 .1693 L
.15429 .16902 L
.15044 .16419 L
.14969 .16323 L
.14656 .15935 L
.14486 .15719 L
.14268 .15452 L
.14003 .15117 L
.13881 .14969 L
.1352 .14515 L
.13495 .14486 L
.13103 .14003 L
.13036 .13919 L
.12709 .1352 L
.12553 .13325 L
.12315 .13036 L
.1207 .12732 L
.11921 .12553 L
.11587 .12141 L
.11527 .1207 L
.11132 .11587 L
.11104 .11552 L
.10731 .11104 L
.1062 .10968 L
.10329 .1062 L
.10137 .10385 L
.09928 .10137 L
.09654 .09804 L
.09527 .09654 L
.09171 .09223 L
.09126 .09171 L
.08722 .08688 L
.08688 .08646 L
.08314 .08204 L
.08204 .08072 L
.07905 .07721 L
.07721 .07501 L
.07496 .07238 L
.07238 .0693 L
.07087 .06755 L
.06755 .0636 L
.06678 .06272 L
.06272 .05791 L
.06268 .05789 L
.05853 .05305 L
.05789 .05228 L
.05437 .04822 L
.05305 .04667 L
.05019 .04339 L
.04822 .04107 L
.04602 .03856 L
.04339 .03548 L
.04184 .03373 L
.03856 .0299 L
.03767 .02889 L
.03373 .02433 L
.03335 .02406 L
.02927 .01923 L
F
0 g
.97073 .01923 m
.96665 .02406 L
.96627 .02433 L
.96233 .02889 L
.96144 .0299 L
.95816 .03373 L
.95661 .03548 L
.95398 .03856 L
.95178 .04107 L
.94981 .04339 L
.94695 .04667 L
.94564 .04822 L
.94211 .05228 L
.94147 .05305 L
.93732 .05789 L
.93728 .05791 L
.93322 .06272 L
.93245 .0636 L
.92913 .06755 L
.92762 .0693 L
.92504 .07238 L
.92279 .07501 L
.92095 .07721 L
.91796 .08073 L
.91686 .08204 L
.91312 .08646 L
.91278 .08688 L
.90874 .09171 L
.90829 .09223 L
.90473 .09654 L
.90346 .09804 L
.90072 .10137 L
.89863 .10385 L
.89671 .1062 L
.8938 .10968 L
.89269 .11104 L
.88896 .11552 L
.88868 .11587 L
.88473 .1207 L
.88413 .12141 L
.88079 .12553 L
.8793 .12732 L
.87686 .13036 L
.87447 .13325 L
.87291 .1352 L
.86964 .13919 L
.86897 .14003 L
.86505 .14486 L
.8648 .14515 L
.86119 .14969 L
Mistroke
.85997 .15117 L
.85732 .15452 L
.85514 .1572 L
.85344 .15935 L
.85031 .16323 L
.84956 .16419 L
.84571 .16902 L
.84548 .1693 L
.84191 .17385 L
.84065 .17542 L
.8381 .17868 L
.83581 .18154 L
.83429 .18351 L
.83098 .18769 L
.83048 .18835 L
.8267 .19318 L
.82615 .19387 L
.82296 .19801 L
.82132 .20009 L
.81922 .20284 L
.81649 .20632 L
.81546 .20767 L
.81171 .2125 L
.81165 .21258 L
.80803 .21734 L
.80682 .21889 L
.80435 .22217 L
.80199 .22522 L
.80065 .227 L
.79716 .23156 L
.79696 .23183 L
.79332 .23666 L
.79233 .23796 L
.78969 .2415 L
.7875 .24438 L
.78606 .24633 L
.78266 .25082 L
.78241 .25116 L
.77883 .25599 L
.77783 .25731 L
.77526 .26082 L
.773 .26383 L
.77167 .26566 L
.76817 .27037 L
.76808 .27049 L
.76457 .27532 L
.76334 .27697 L
.76104 .28015 L
.7585 .28359 L
.75751 .28498 L
Mistroke
.75399 .28981 L
.75367 .29024 L
.75052 .29465 L
.74884 .29695 L
.74704 .29948 L
.74401 .30367 L
.74356 .30431 L
.74012 .30914 L
.73918 .31045 L
.7367 .31397 L
.73434 .31726 L
.73327 .31881 L
.72985 .32364 L
.72951 .3241 L
.72648 .32847 L
.72468 .331 L
.7231 .3333 L
.71985 .33792 L
.71971 .33813 L
.71638 .34296 L
.71502 .34491 L
.71305 .3478 L
.71019 .35192 L
.70971 .35263 L
.70641 .35746 L
.70535 .35899 L
.70313 .36229 L
.70052 .3661 L
.69984 .36712 L
.69658 .37196 L
.69569 .37326 L
.69334 .37679 L
.69086 .38046 L
.6901 .38162 L
.68688 .38645 L
.68603 .38772 L
.68369 .39128 L
.68119 .39502 L
.68048 .39612 L
.67731 .40095 L
.67636 .40238 L
.67416 .40578 L
.67153 .40978 L
.671 .41061 L
.66788 .41544 L
.6667 .41725 L
.66477 .42027 L
.66187 .42476 L
.66165 .42511 L
.65858 .42994 L
Mistroke
.65704 .43234 L
.65565 .43477 L
.6522 .43785 L
.649 .4396 L
.64737 .44229 L
.646 .44443 L
.64289 .44927 L
.64254 .4498 L
.6398 .4541 L
.63771 .45736 L
.63672 .45893 L
.63364 .46376 L
.63288 .46496 L
.63059 .46859 L
.62804 .47261 L
.62753 .47342 L
.6245 .47826 L
.62321 .4803 L
.62147 .48309 L
.61845 .48792 L
.61838 .48803 L
.61545 .49275 L
.61355 .4958 L
.61245 .49758 L
.60945 .50242 L
.60872 .5036 L
.60648 .50725 L
.60388 .51144 L
.60349 .51208 L
.60053 .51691 L
.59905 .5193 L
.59757 .52174 L
.5946 .52658 L
.59422 .52719 L
.59165 .53141 L
.58939 .5351 L
.5887 .53624 L
.58575 .54107 L
.58456 .54302 L
.5828 .5459 L
.57984 .55073 L
.57973 .55093 L
.5769 .55557 L
.57489 .55882 L
.57393 .5604 L
.57097 .56523 L
.57006 .56669 L
.56799 .57006 L
.56523 .5745 L
.56499 .57489 L
Mistroke
.56198 .57973 L
.5604 .58223 L
.55894 .58456 L
.55587 .58939 L
.55557 .58985 L
.55276 .59422 L
.55073 .59732 L
.5496 .59905 L
.54638 .60388 L
.5459 .60459 L
.54309 .60872 L
.54107 .61159 L
.53969 .61355 L
.53624 .61826 L
.53615 .61838 L
.53244 .62321 L
.53141 .62449 L
.52847 .62804 L
.52658 .6302 L
.52412 .63288 L
.52174 .63524 L
.5191 .63771 L
.51691 .6395 L
.51262 .64254 L
.51208 .64285 L
.50725 .64515 L
.50242 .64633 L
.49758 .64633 L
.49275 .64515 L
.48792 .64285 L
.48738 .64254 L
.48309 .6395 L
.4809 .63771 L
.47826 .63524 L
.47588 .63288 L
.47342 .63019 L
.47153 .62804 L
.46859 .62449 L
.46756 .62321 L
.46385 .61838 L
.46376 .61826 L
.46031 .61355 L
.45893 .61159 L
.45691 .60872 L
.4541 .60459 L
.45362 .60388 L
.4504 .59905 L
.44927 .59732 L
.44724 .59422 L
.44443 .58985 L
Mistroke
.44414 .58939 L
.44106 .58456 L
.4396 .58223 L
.43802 .57973 L
.43501 .57489 L
.43477 .5745 L
.43201 .57006 L
.42994 .56669 L
.42904 .56523 L
.42607 .5604 L
.42511 .55882 L
.4231 .55557 L
.42027 .55093 L
.42016 .55073 L
.4172 .5459 L
.41544 .54301 L
.41425 .54107 L
.4113 .53624 L
.41061 .5351 L
.40835 .53141 L
.40578 .52719 L
.4054 .52658 L
.40244 .52174 L
.40095 .5193 L
.39947 .51691 L
.39651 .51208 L
.39612 .51144 L
.39353 .50725 L
.39128 .5036 L
.39055 .50242 L
.38755 .49758 L
.38645 .49579 L
.38455 .49275 L
.38162 .48803 L
.38155 .48792 L
.37853 .48309 L
.37679 .4803 L
.3755 .47826 L
.37247 .47342 L
.37196 .47261 L
.36941 .46859 L
.36712 .46496 L
.36636 .46376 L
.36329 .45893 L
.36229 .45736 L
.3602 .4541 L
.35746 .4498 L
.35712 .44927 L
.354 .44443 L
.35263 .44229 L
Mistroke
.351 .4396 L
.3478 .43785 L
.34436 .43477 L
.34296 .43234 L
.34142 .42994 L
.33835 .42511 L
.33813 .42476 L
.33523 .42027 L
.3333 .41725 L
.33212 .41544 L
.329 .41061 L
.32847 .40978 L
.32584 .40578 L
.32364 .40237 L
.32269 .40095 L
.31952 .39612 L
.31881 .39502 L
.31631 .39128 L
.31397 .38771 L
.31312 .38645 L
.30991 .38162 L
.30914 .38046 L
.30666 .37679 L
.30431 .37326 L
.30342 .37196 L
.30016 .36712 L
.29948 .3661 L
.29687 .36229 L
.29465 .35899 L
.29359 .35746 L
.29029 .35263 L
.28981 .35192 L
.28695 .3478 L
.28498 .34491 L
.28362 .34296 L
.28029 .33813 L
.28015 .33792 L
.2769 .3333 L
.27532 .331 L
.27352 .32847 L
.27049 .3241 L
.27015 .32364 L
.26673 .31881 L
.26566 .31726 L
.2633 .31397 L
.26082 .31045 L
.25988 .30914 L
.25644 .30431 L
.25599 .30367 L
.25296 .29948 L
Mistroke
.25116 .29694 L
.24948 .29465 L
.24633 .29024 L
.24601 .28981 L
.24249 .28498 L
.2415 .28359 L
.23896 .28015 L
.23666 .27697 L
.23543 .27532 L
.23192 .27049 L
.23183 .27037 L
.22833 .26566 L
.227 .26383 L
.22474 .26082 L
.22217 .25731 L
.22117 .25599 L
.21759 .25116 L
.21734 .25082 L
.21394 .24633 L
.2125 .24438 L
.21031 .2415 L
.20767 .23796 L
.20668 .23666 L
.20304 .23183 L
.20284 .23156 L
.19935 .227 L
.19801 .22521 L
.19565 .22217 L
.19318 .21889 L
.19197 .21734 L
.18835 .21258 L
.18829 .2125 L
.18454 .20767 L
.18351 .20632 L
.18078 .20284 L
.17868 .20009 L
.17704 .19801 L
.17385 .19387 L
.1733 .19318 L
.16952 .18835 L
.16902 .18769 L
.16571 .18351 L
.16419 .18154 L
.1619 .17868 L
.15935 .17542 L
.15809 .17385 L
.15452 .1693 L
.15429 .16902 L
.15044 .16419 L
.14969 .16323 L
Mistroke
.14656 .15935 L
.14486 .15719 L
.14268 .15452 L
.14003 .15117 L
.13881 .14969 L
.1352 .14515 L
.13495 .14486 L
.13103 .14003 L
.13036 .13919 L
.12709 .1352 L
.12553 .13325 L
.12315 .13036 L
.1207 .12732 L
.11921 .12553 L
.11587 .12141 L
.11527 .1207 L
.11132 .11587 L
.11104 .11552 L
.10731 .11104 L
.1062 .10968 L
.10329 .1062 L
.10137 .10385 L
.09928 .10137 L
.09654 .09804 L
.09527 .09654 L
.09171 .09223 L
.09126 .09171 L
.08722 .08688 L
.08688 .08646 L
.08314 .08204 L
.08204 .08072 L
.07905 .07721 L
.07721 .07501 L
.07496 .07238 L
.07238 .0693 L
.07087 .06755 L
.06755 .0636 L
.06678 .06272 L
.06272 .05791 L
.06268 .05789 L
.05853 .05305 L
.05789 .05228 L
.05437 .04822 L
.05305 .04667 L
.05019 .04339 L
.04822 .04107 L
.04602 .03856 L
.04339 .03548 L
.04184 .03373 L
.03856 .0299 L
Mistroke
.03767 .02889 L
.03373 .02433 L
.03335 .02406 L
.02927 .01923 L
Mfstroke
.606 .73 0 r
.96919 .01923 m
.96627 .02248 L
.96496 .02406 L
.96144 .02807 L
.96073 .02889 L
.95661 .03362 L
.95652 .03373 L
.95234 .03856 L
.95178 .0392 L
.94819 .04339 L
.94695 .04481 L
.94403 .04822 L
.94211 .05043 L
.93988 .05305 L
.93728 .05606 L
.93573 .05789 L
.93245 .0617 L
.93159 .06272 L
.92762 .06736 L
.92746 .06755 L
.92337 .07238 L
.92279 .07306 L
.9193 .07721 L
.91796 .07878 L
.91523 .08204 L
.91312 .08452 L
.91116 .08688 L
.90829 .09027 L
.9071 .09171 L
.90346 .09603 L
.90304 .09654 L
.89901 .10137 L
.89863 .10183 L
.89502 .1062 L
.8938 .10766 L
.89102 .11104 L
.88896 .1135 L
.88703 .11587 L
.88413 .11936 L
.88304 .1207 L
.8793 .12523 L
.87906 .12553 L
.87512 .13036 L
.87447 .13115 L
.8712 .1352 L
.86964 .13709 L
.86727 .14003 L
.8648 .14304 L
.86335 .14486 L
.85997 .14901 L
.85943 .14969 L
.85555 .15452 L
.85514 .15502 L
.85169 .15935 L
.85031 .16106 L
.84783 .16419 L
.84548 .16711 L
.84398 .16902 L
.84065 .17318 L
.84012 .17385 L
.8363 .17868 L
.83581 .17929 L
.83251 .18351 L
.83098 .18543 L
.82872 .18835 L
.82615 .19159 L
.82492 .19318 L
.82132 .19777 L
.82113 .19801 L
.81739 .20284 L
.81649 .20399 L
.81366 .20767 L
.81165 .21024 L
.80992 .2125 L
.80682 .2165 L
.80619 .21734 L
.80248 .22217 L
.80199 .2228 L
.79881 .227 L
.79716 .22914 L
.79513 .23183 L
.79233 .2355 L
.79145 .23666 L
.78779 .2415 L
.7875 .24189 L
.78418 .24633 L
.78266 .24832 L
.78055 .25116 L
.77783 .25477 L
.77693 .25599 L
.77333 .26082 L
.773 .26126 L
.76976 .26566 L
.76817 .26778 L
.76619 .27049 L
.76334 .27434 L
.76262 .27532 L
.75908 .28015 L
.7585 .28093 L
.75556 .28498 L
.75367 .28756 L
.75205 .28981 L
.74884 .29421 L
.74853 .29465 L
.74505 .29948 L
.74401 .30091 L
.74159 .30431 L
.73918 .30765 L
.73812 .30914 L
.73467 .31397 L
.73434 .31442 L
.73125 .31881 L
.72951 .32124 L
.72783 .32364 L
.72468 .32808 L
.72441 .32847 L
.72104 .3333 L
.71985 .33498 L
.71767 .33813 L
.71502 .34191 L
.71429 .34296 L
.71095 .3478 L
.71019 .34889 L
.70763 .35263 L
.70535 .35591 L
.7043 .35746 L
.70099 .36229 L
.70052 .36297 L
.69771 .36712 L
.69569 .37008 L
.69443 .37196 L
.69116 .37679 L
.69086 .37723 L
.68793 .38162 L
.68603 .38444 L
.68469 .38645 L
.68146 .39128 L
.68119 .39168 L
.67827 .39612 L
.67636 .39899 L
.67508 .40095 L
.6719 .40578 L
.67153 .40633 L
.66875 .41061 L
.6667 .41374 L
.6656 .41544 L
.66246 .42027 L
.66187 .42119 L
.65936 .42511 L
.65704 .4287 L
.65625 .42994 L
.65337 .43477 L
.6522 .43586 L
.64737 .43693 L
.64593 .4396 L
.64277 .44443 L
.64254 .44478 L
.63963 .44927 L
.63771 .45222 L
.63649 .4541 L
.63336 .45893 L
.63288 .45968 L
.63025 .46376 L
.62804 .46718 L
.62714 .46859 L
.62404 .47342 L
.62321 .47472 L
.62096 .47826 L
.61838 .48228 L
.61787 .48309 L
.6148 .48792 L
.61355 .48988 L
.61173 .49275 L
.60872 .49749 L
.60866 .49758 L
.60561 .50242 L
.60388 .50513 L
.60255 .50725 L
.5995 .51208 L
.59905 .51279 L
.59646 .51691 L
.59422 .52045 L
.59341 .52174 L
.59036 .52658 L
.58939 .52811 L
.58731 .53141 L
.58456 .53576 L
.58426 .53624 L
.5812 .54107 L
.57973 .54339 L
.57814 .5459 L
.57505 .55073 L
.57489 .55098 L
.57197 .55557 L
.57006 .55852 L
.56886 .5604 L
.56572 .56523 L
.56523 .56598 L
.56256 .57006 L
.5604 .57333 L
.55937 .57489 L
.55612 .57973 L
.55557 .58055 L
.55284 .58456 L
.55073 .58758 L
.54947 .58939 L
.54602 .59422 L
.5459 .59439 L
.54247 .59905 L
.54107 .6009 L
.53878 .60388 L
.53624 .60706 L
.53489 .60872 L
.53141 .61278 L
.53073 .61355 L
.52658 .61796 L
.52617 .61838 L
.52174 .62251 L
.52095 .62321 L
.51691 .62633 L
.51439 .62804 L
.51208 .6293 L
.50725 .63134 L
.50242 .63238 L
.49758 .63238 L
.49275 .63134 L
.48792 .6293 L
.48562 .62804 L
.48309 .62633 L
.47905 .62321 L
.47826 .62251 L
.47384 .61838 L
.47342 .61796 L
.46927 .61355 L
.46859 .61277 L
.46511 .60872 L
.46376 .60706 L
.46122 .60388 L
.45893 .6009 L
.45753 .59905 L
.4541 .59438 L
.45398 .59422 L
.45053 .58939 L
.44927 .58758 L
.44717 .58456 L
.44443 .58055 L
.44388 .57973 L
.44063 .57489 L
.4396 .57333 L
.43744 .57006 L
.43477 .56598 L
.43428 .56523 L
.43114 .5604 L
.42994 .55852 L
.42803 .55557 L
.42511 .55098 L
.42495 .55073 L
.42186 .5459 L
.42027 .54339 L
.4188 .54107 L
.41574 .53624 L
.41544 .53576 L
.41269 .53141 L
.41061 .52811 L
.40964 .52658 L
.40659 .52174 L
.40578 .52045 L
.40354 .51691 L
.40095 .51278 L
.4005 .51208 L
.39745 .50725 L
.39612 .50513 L
.39439 .50242 L
.39134 .49758 L
.39128 .49749 L
.38827 .49275 L
.38645 .48987 L
.3852 .48792 L
.38213 .48309 L
.38162 .48228 L
.37904 .47826 L
.37679 .47471 L
.37596 .47342 L
.37286 .46859 L
.37196 .46718 L
.36975 .46376 L
.36712 .45968 L
.36664 .45893 L
.36351 .4541 L
.36229 .45221 L
.36037 .44927 L
.35746 .44478 L
.35723 .44443 L
.35407 .4396 L
.35263 .43692 L
.3478 .43586 L
.34664 .43477 L
.34376 .42994 L
.34296 .42869 L
.34064 .42511 L
.33813 .42119 L
.33754 .42027 L
.3344 .41544 L
.3333 .41373 L
.33125 .41061 L
.32847 .40633 L
.3281 .40578 L
.32492 .40095 L
.32364 .39898 L
.32173 .39612 L
.31881 .39168 L
.31854 .39128 L
.31531 .38645 L
.31397 .38444 L
.31207 .38162 L
.30914 .37723 L
.30884 .37679 L
.30557 .37196 L
.30431 .37008 L
.30229 .36712 L
.29948 .36297 L
.29901 .36229 L
.2957 .35746 L
.29465 .35591 L
.29238 .35263 L
.28981 .34889 L
.28905 .3478 L
.28571 .34296 L
.28498 .34191 L
.28233 .33813 L
.28015 .33498 L
.27896 .3333 L
.27559 .32847 L
.27532 .32808 L
.27217 .32364 L
.27049 .32123 L
.26875 .31881 L
.26566 .31442 L
.26534 .31397 L
.26188 .30914 L
.26082 .30765 L
.25841 .30431 L
.25599 .30091 L
.25495 .29948 L
.25147 .29465 L
.25116 .29421 L
.24795 .28981 L
.24633 .28755 L
.24444 .28498 L
.2415 .28093 L
.24092 .28015 L
.23738 .27532 L
.23666 .27434 L
.23381 .27049 L
.23183 .26778 L
.23024 .26566 L
.227 .26126 L
.22667 .26082 L
.22307 .25599 L
.22217 .25477 L
.21945 .25116 L
.21734 .24832 L
.21583 .24633 L
.2125 .24189 L
.21221 .2415 L
.20855 .23666 L
.20767 .2355 L
.20487 .23183 L
.20284 .22914 L
.20119 .227 L
.19801 .2228 L
.19752 .22217 L
.19381 .21734 L
.19318 .2165 L
.19008 .2125 L
.18835 .21023 L
.18634 .20767 L
.18351 .20399 L
.18261 .20284 L
.17887 .19801 L
.17868 .19777 L
.17508 .19318 L
.17385 .19159 L
.17129 .18835 L
.16902 .18543 L
.16749 .18351 L
.16419 .17929 L
.1637 .17868 L
.15988 .17385 L
.15935 .17318 L
.15602 .16902 L
.15452 .16711 L
.15217 .16419 L
.14969 .16106 L
.14831 .15935 L
.14486 .15502 L
.14446 .15452 L
.14057 .14969 L
.14003 .14901 L
.13665 .14486 L
.1352 .14304 L
.13273 .14003 L
.13036 .13709 L
.1288 .1352 L
.12553 .13115 L
.12488 .13036 L
.12094 .12553 L
.1207 .12523 L
.11696 .1207 L
.11587 .11936 L
.11297 .11587 L
.11104 .1135 L
.10898 .11104 L
.1062 .10766 L
.10498 .1062 L
.10137 .10183 L
.10099 .10137 L
.09696 .09654 L
.09654 .09603 L
.0929 .09171 L
.09171 .09027 L
.08884 .08688 L
.08688 .08452 L
.08477 .08204 L
.08204 .07878 L
.0807 .07721 L
.07721 .07306 L
.07663 .07238 L
.07254 .06755 L
.07238 .06736 L
.06841 .06272 L
.06755 .0617 L
.06427 .05789 L
.06272 .05606 L
.06012 .05305 L
.05789 .05042 L
.05597 .04822 L
.05305 .04481 L
.05181 .04339 L
.04822 .0392 L
.04766 .03856 L
.04348 .03373 L
.04339 .03362 L
.03927 .02889 L
.03856 .02807 L
.03504 .02406 L
.03373 .02247 L
.03081 .01923 L
F
0 g
.96919 .01923 m
.96627 .02248 L
.96496 .02406 L
.96144 .02807 L
.96073 .02889 L
.95661 .03362 L
.95652 .03373 L
.95234 .03856 L
.95178 .0392 L
.94819 .04339 L
.94695 .04481 L
.94403 .04822 L
.94211 .05043 L
.93988 .05305 L
.93728 .05606 L
.93573 .05789 L
.93245 .0617 L
.93159 .06272 L
.92762 .06736 L
.92746 .06755 L
.92337 .07238 L
.92279 .07306 L
.9193 .07721 L
.91796 .07878 L
.91523 .08204 L
.91312 .08452 L
.91116 .08688 L
.90829 .09027 L
.9071 .09171 L
.90346 .09603 L
.90304 .09654 L
.89901 .10137 L
.89863 .10183 L
.89502 .1062 L
.8938 .10766 L
.89102 .11104 L
.88896 .1135 L
.88703 .11587 L
.88413 .11936 L
.88304 .1207 L
.8793 .12523 L
.87906 .12553 L
.87512 .13036 L
.87447 .13115 L
.8712 .1352 L
.86964 .13709 L
.86727 .14003 L
.8648 .14304 L
.86335 .14486 L
.85997 .14901 L
Mistroke
.85943 .14969 L
.85555 .15452 L
.85514 .15502 L
.85169 .15935 L
.85031 .16106 L
.84783 .16419 L
.84548 .16711 L
.84398 .16902 L
.84065 .17318 L
.84012 .17385 L
.8363 .17868 L
.83581 .17929 L
.83251 .18351 L
.83098 .18543 L
.82872 .18835 L
.82615 .19159 L
.82492 .19318 L
.82132 .19777 L
.82113 .19801 L
.81739 .20284 L
.81649 .20399 L
.81366 .20767 L
.81165 .21024 L
.80992 .2125 L
.80682 .2165 L
.80619 .21734 L
.80248 .22217 L
.80199 .2228 L
.79881 .227 L
.79716 .22914 L
.79513 .23183 L
.79233 .2355 L
.79145 .23666 L
.78779 .2415 L
.7875 .24189 L
.78418 .24633 L
.78266 .24832 L
.78055 .25116 L
.77783 .25477 L
.77693 .25599 L
.77333 .26082 L
.773 .26126 L
.76976 .26566 L
.76817 .26778 L
.76619 .27049 L
.76334 .27434 L
.76262 .27532 L
.75908 .28015 L
.7585 .28093 L
.75556 .28498 L
Mistroke
.75367 .28756 L
.75205 .28981 L
.74884 .29421 L
.74853 .29465 L
.74505 .29948 L
.74401 .30091 L
.74159 .30431 L
.73918 .30765 L
.73812 .30914 L
.73467 .31397 L
.73434 .31442 L
.73125 .31881 L
.72951 .32124 L
.72783 .32364 L
.72468 .32808 L
.72441 .32847 L
.72104 .3333 L
.71985 .33498 L
.71767 .33813 L
.71502 .34191 L
.71429 .34296 L
.71095 .3478 L
.71019 .34889 L
.70763 .35263 L
.70535 .35591 L
.7043 .35746 L
.70099 .36229 L
.70052 .36297 L
.69771 .36712 L
.69569 .37008 L
.69443 .37196 L
.69116 .37679 L
.69086 .37723 L
.68793 .38162 L
.68603 .38444 L
.68469 .38645 L
.68146 .39128 L
.68119 .39168 L
.67827 .39612 L
.67636 .39899 L
.67508 .40095 L
.6719 .40578 L
.67153 .40633 L
.66875 .41061 L
.6667 .41374 L
.6656 .41544 L
.66246 .42027 L
.66187 .42119 L
.65936 .42511 L
.65704 .4287 L
Mistroke
.65625 .42994 L
.65337 .43477 L
.6522 .43586 L
.64737 .43693 L
.64593 .4396 L
.64277 .44443 L
.64254 .44478 L
.63963 .44927 L
.63771 .45222 L
.63649 .4541 L
.63336 .45893 L
.63288 .45968 L
.63025 .46376 L
.62804 .46718 L
.62714 .46859 L
.62404 .47342 L
.62321 .47472 L
.62096 .47826 L
.61838 .48228 L
.61787 .48309 L
.6148 .48792 L
.61355 .48988 L
.61173 .49275 L
.60872 .49749 L
.60866 .49758 L
.60561 .50242 L
.60388 .50513 L
.60255 .50725 L
.5995 .51208 L
.59905 .51279 L
.59646 .51691 L
.59422 .52045 L
.59341 .52174 L
.59036 .52658 L
.58939 .52811 L
.58731 .53141 L
.58456 .53576 L
.58426 .53624 L
.5812 .54107 L
.57973 .54339 L
.57814 .5459 L
.57505 .55073 L
.57489 .55098 L
.57197 .55557 L
.57006 .55852 L
.56886 .5604 L
.56572 .56523 L
.56523 .56598 L
.56256 .57006 L
.5604 .57333 L
Mistroke
.55937 .57489 L
.55612 .57973 L
.55557 .58055 L
.55284 .58456 L
.55073 .58758 L
.54947 .58939 L
.54602 .59422 L
.5459 .59439 L
.54247 .59905 L
.54107 .6009 L
.53878 .60388 L
.53624 .60706 L
.53489 .60872 L
.53141 .61278 L
.53073 .61355 L
.52658 .61796 L
.52617 .61838 L
.52174 .62251 L
.52095 .62321 L
.51691 .62633 L
.51439 .62804 L
.51208 .6293 L
.50725 .63134 L
.50242 .63238 L
.49758 .63238 L
.49275 .63134 L
.48792 .6293 L
.48562 .62804 L
.48309 .62633 L
.47905 .62321 L
.47826 .62251 L
.47384 .61838 L
.47342 .61796 L
.46927 .61355 L
.46859 .61277 L
.46511 .60872 L
.46376 .60706 L
.46122 .60388 L
.45893 .6009 L
.45753 .59905 L
.4541 .59438 L
.45398 .59422 L
.45053 .58939 L
.44927 .58758 L
.44717 .58456 L
.44443 .58055 L
.44388 .57973 L
.44063 .57489 L
.4396 .57333 L
.43744 .57006 L
Mistroke
.43477 .56598 L
.43428 .56523 L
.43114 .5604 L
.42994 .55852 L
.42803 .55557 L
.42511 .55098 L
.42495 .55073 L
.42186 .5459 L
.42027 .54339 L
.4188 .54107 L
.41574 .53624 L
.41544 .53576 L
.41269 .53141 L
.41061 .52811 L
.40964 .52658 L
.40659 .52174 L
.40578 .52045 L
.40354 .51691 L
.40095 .51278 L
.4005 .51208 L
.39745 .50725 L
.39612 .50513 L
.39439 .50242 L
.39134 .49758 L
.39128 .49749 L
.38827 .49275 L
.38645 .48987 L
.3852 .48792 L
.38213 .48309 L
.38162 .48228 L
.37904 .47826 L
.37679 .47471 L
.37596 .47342 L
.37286 .46859 L
.37196 .46718 L
.36975 .46376 L
.36712 .45968 L
.36664 .45893 L
.36351 .4541 L
.36229 .45221 L
.36037 .44927 L
.35746 .44478 L
.35723 .44443 L
.35407 .4396 L
.35263 .43692 L
.3478 .43586 L
.34664 .43477 L
.34376 .42994 L
.34296 .42869 L
.34064 .42511 L
Mistroke
.33813 .42119 L
.33754 .42027 L
.3344 .41544 L
.3333 .41373 L
.33125 .41061 L
.32847 .40633 L
.3281 .40578 L
.32492 .40095 L
.32364 .39898 L
.32173 .39612 L
.31881 .39168 L
.31854 .39128 L
.31531 .38645 L
.31397 .38444 L
.31207 .38162 L
.30914 .37723 L
.30884 .37679 L
.30557 .37196 L
.30431 .37008 L
.30229 .36712 L
.29948 .36297 L
.29901 .36229 L
.2957 .35746 L
.29465 .35591 L
.29238 .35263 L
.28981 .34889 L
.28905 .3478 L
.28571 .34296 L
.28498 .34191 L
.28233 .33813 L
.28015 .33498 L
.27896 .3333 L
.27559 .32847 L
.27532 .32808 L
.27217 .32364 L
.27049 .32123 L
.26875 .31881 L
.26566 .31442 L
.26534 .31397 L
.26188 .30914 L
.26082 .30765 L
.25841 .30431 L
.25599 .30091 L
.25495 .29948 L
.25147 .29465 L
.25116 .29421 L
.24795 .28981 L
.24633 .28755 L
.24444 .28498 L
.2415 .28093 L
Mistroke
.24092 .28015 L
.23738 .27532 L
.23666 .27434 L
.23381 .27049 L
.23183 .26778 L
.23024 .26566 L
.227 .26126 L
.22667 .26082 L
.22307 .25599 L
.22217 .25477 L
.21945 .25116 L
.21734 .24832 L
.21583 .24633 L
.2125 .24189 L
.21221 .2415 L
.20855 .23666 L
.20767 .2355 L
.20487 .23183 L
.20284 .22914 L
.20119 .227 L
.19801 .2228 L
.19752 .22217 L
.19381 .21734 L
.19318 .2165 L
.19008 .2125 L
.18835 .21023 L
.18634 .20767 L
.18351 .20399 L
.18261 .20284 L
.17887 .19801 L
.17868 .19777 L
.17508 .19318 L
.17385 .19159 L
.17129 .18835 L
.16902 .18543 L
.16749 .18351 L
.16419 .17929 L
.1637 .17868 L
.15988 .17385 L
.15935 .17318 L
.15602 .16902 L
.15452 .16711 L
.15217 .16419 L
.14969 .16106 L
.14831 .15935 L
.14486 .15502 L
.14446 .15452 L
.14057 .14969 L
.14003 .14901 L
.13665 .14486 L
Mistroke
.1352 .14304 L
.13273 .14003 L
.13036 .13709 L
.1288 .1352 L
.12553 .13115 L
.12488 .13036 L
.12094 .12553 L
.1207 .12523 L
.11696 .1207 L
.11587 .11936 L
.11297 .11587 L
.11104 .1135 L
.10898 .11104 L
.1062 .10766 L
.10498 .1062 L
.10137 .10183 L
.10099 .10137 L
.09696 .09654 L
.09654 .09603 L
.0929 .09171 L
.09171 .09027 L
.08884 .08688 L
.08688 .08452 L
.08477 .08204 L
.08204 .07878 L
.0807 .07721 L
.07721 .07306 L
.07663 .07238 L
.07254 .06755 L
.07238 .06736 L
.06841 .06272 L
.06755 .0617 L
.06427 .05789 L
.06272 .05606 L
.06012 .05305 L
.05789 .05042 L
.05597 .04822 L
.05305 .04481 L
.05181 .04339 L
.04822 .0392 L
.04766 .03856 L
.04348 .03373 L
.04339 .03362 L
.03927 .02889 L
.03856 .02807 L
.03504 .02406 L
.03373 .02247 L
.03081 .01923 L
Mfstroke
.435 .685 0 r
.96725 .01923 m
.96627 .02028 L
.96303 .02406 L
.96144 .02586 L
.95881 .02889 L
.95661 .03141 L
.95461 .03373 L
.95178 .03696 L
.95041 .03856 L
.94695 .04254 L
.94621 .04339 L
.94211 .04813 L
.94203 .04822 L
.93789 .05305 L
.93728 .05375 L
.93375 .05789 L
.93245 .05939 L
.92962 .06272 L
.92762 .06505 L
.9255 .06755 L
.92279 .07072 L
.92139 .07238 L
.91796 .07641 L
.91728 .07721 L
.91318 .08204 L
.91312 .08212 L
.90913 .08688 L
.90829 .08786 L
.90508 .09171 L
.90346 .09362 L
.90103 .09654 L
.89863 .0994 L
.89699 .10137 L
.8938 .10519 L
.89296 .1062 L
.88896 .111 L
.88894 .11104 L
.88495 .11587 L
.88413 .11685 L
.88098 .1207 L
.8793 .12272 L
.87701 .12553 L
.87447 .12861 L
.87304 .13036 L
.86964 .13451 L
.86909 .1352 L
.86515 .14003 L
.8648 .14045 L
.86124 .14486 L
.85997 .14641 L
.85734 .14969 L
.85514 .15239 L
.85344 .15452 L
.85031 .15839 L
.84954 .15935 L
.84567 .16419 L
.84548 .16442 L
.84182 .16902 L
.84065 .17048 L
.83798 .17385 L
.83581 .17656 L
.83415 .17868 L
.83098 .18267 L
.83032 .18351 L
.82651 .18835 L
.82615 .1888 L
.82273 .19318 L
.82132 .19496 L
.81895 .19801 L
.81649 .20115 L
.81518 .20284 L
.81165 .20736 L
.81141 .20767 L
.80768 .2125 L
.80682 .21361 L
.80396 .21734 L
.80199 .21988 L
.80024 .22217 L
.79716 .22618 L
.79653 .227 L
.79284 .23183 L
.79233 .23251 L
.78918 .23666 L
.7875 .23887 L
.78552 .2415 L
.78266 .24526 L
.78186 .24633 L
.77822 .25116 L
.77783 .25168 L
.77461 .25599 L
.773 .25814 L
.77101 .26082 L
.76817 .26462 L
.7674 .26566 L
.76382 .27049 L
.76334 .27114 L
.76026 .27532 L
.7585 .27769 L
.75671 .28015 L
.75367 .28427 L
.75316 .28498 L
.74964 .28981 L
.74884 .2909 L
.74613 .29465 L
.74401 .29755 L
.74263 .29948 L
.73918 .30424 L
.73913 .30431 L
.73567 .30914 L
.73434 .31098 L
.73221 .31397 L
.72951 .31774 L
.72876 .31881 L
.72533 .32364 L
.72468 .32455 L
.72192 .32847 L
.71985 .33139 L
.71851 .3333 L
.71511 .33813 L
.71502 .33827 L
.71175 .34296 L
.71019 .3452 L
.70839 .3478 L
.70535 .35216 L
.70503 .35263 L
.70171 .35746 L
.70052 .35917 L
.69839 .36229 L
.69569 .36622 L
.69508 .36712 L
.69179 .37196 L
.69086 .37331 L
.68851 .37679 L
.68603 .38045 L
.68524 .38162 L
.68199 .38645 L
.68119 .38764 L
.67876 .39128 L
.67636 .39487 L
.67554 .39612 L
.67233 .40095 L
.67153 .40215 L
.66914 .40578 L
.6667 .40947 L
.66596 .41061 L
.66279 .41544 L
.66187 .41685 L
.65964 .42027 L
.65704 .42428 L
.6565 .42511 L
.65338 .42994 L
.6522 .43216 L
.64737 .43365 L
.64475 .43477 L
.64254 .43862 L
.64189 .4396 L
.63868 .44443 L
.63771 .4459 L
.63548 .44927 L
.63288 .4532 L
.63228 .4541 L
.6291 .45893 L
.62804 .46052 L
.62592 .46376 L
.62321 .46787 L
.62274 .46859 L
.61957 .47342 L
.61838 .47524 L
.61641 .47826 L
.61355 .48262 L
.61324 .48309 L
.61009 .48792 L
.60872 .49002 L
.60694 .49275 L
.60388 .49742 L
.60378 .49758 L
.60063 .50242 L
.59905 .50482 L
.59747 .50725 L
.59431 .51208 L
.59422 .51221 L
.59115 .51691 L
.58939 .51959 L
.58798 .52174 L
.58479 .52658 L
.58456 .52693 L
.5816 .53141 L
.57973 .53423 L
.57839 .53624 L
.57516 .54107 L
.57489 .54147 L
.57192 .5459 L
.57006 .54863 L
.56864 .55073 L
.56532 .55557 L
.56523 .55569 L
.56196 .5604 L
.5604 .56262 L
.55855 .56523 L
.55557 .56938 L
.55507 .57006 L
.55151 .57489 L
.55073 .57593 L
.54786 .57973 L
.5459 .58223 L
.54407 .58456 L
.54107 .58823 L
.5401 .58939 L
.53624 .59385 L
.53591 .59422 L
.53141 .59903 L
.53139 .59905 L
.52658 .60369 L
.52637 .60388 L
.52174 .60776 L
.5205 .60872 L
.51691 .61113 L
.51254 .61355 L
.51208 .61375 L
.50725 .61554 L
.50242 .61644 L
.49758 .61644 L
.49275 .61554 L
.48792 .61375 L
.48746 .61355 L
.48309 .61113 L
.4795 .60872 L
.47826 .60775 L
.47363 .60388 L
.47342 .60369 L
.46862 .59905 L
.46859 .59903 L
.46409 .59422 L
.46376 .59385 L
.4599 .58939 L
.45893 .58822 L
.45594 .58456 L
.4541 .58223 L
.45215 .57973 L
.44927 .57593 L
.44849 .57489 L
.44493 .57006 L
.44443 .56938 L
.44145 .56523 L
.4396 .56262 L
.43804 .5604 L
.43477 .55569 L
.43468 .55557 L
.43137 .55073 L
.42994 .54863 L
.42808 .5459 L
.42511 .54147 L
.42484 .54107 L
.42161 .53624 L
.42027 .53423 L
.4184 .53141 L
.41544 .52693 L
.41521 .52658 L
.41202 .52174 L
.41061 .51959 L
.40885 .51691 L
.40578 .51221 L
.40569 .51208 L
.40253 .50725 L
.40095 .50482 L
.39937 .50242 L
.39622 .49758 L
.39612 .49742 L
.39307 .49275 L
.39128 .49002 L
.38991 .48792 L
.38676 .48309 L
.38645 .48262 L
.38359 .47826 L
.38162 .47524 L
.38043 .47342 L
.37726 .46859 L
.37679 .46787 L
.37408 .46376 L
.37196 .46052 L
.3709 .45893 L
.36772 .4541 L
.36712 .45319 L
.36452 .44927 L
.36229 .4459 L
.36132 .44443 L
.35811 .4396 L
.35746 .43862 L
.35525 .43477 L
.35263 .43365 L
.3478 .43216 L
.34662 .42994 L
.3435 .42511 L
.34296 .42427 L
.34036 .42027 L
.33813 .41685 L
.33721 .41544 L
.33405 .41061 L
.3333 .40947 L
.33086 .40578 L
.32847 .40214 L
.32767 .40095 L
.32446 .39612 L
.32364 .39487 L
.32124 .39128 L
.31881 .38763 L
.31801 .38645 L
.31476 .38162 L
.31397 .38045 L
.31149 .37679 L
.30914 .37331 L
.30821 .37196 L
.30493 .36712 L
.30431 .36622 L
.30161 .36229 L
.29948 .35917 L
.2983 .35746 L
.29497 .35263 L
.29465 .35216 L
.29161 .3478 L
.28981 .3452 L
.28825 .34296 L
.28498 .33827 L
.28489 .33813 L
.28149 .3333 L
.28015 .33139 L
.27808 .32847 L
.27532 .32454 L
.27467 .32364 L
.27124 .31881 L
.27049 .31774 L
.26779 .31397 L
.26566 .31097 L
.26433 .30914 L
.26087 .30431 L
.26082 .30424 L
.25737 .29948 L
.25599 .29755 L
.25387 .29465 L
.25116 .2909 L
.25037 .28981 L
.24684 .28498 L
.24633 .28427 L
.24329 .28015 L
.2415 .27769 L
.23974 .27532 L
.23666 .27114 L
.23618 .27049 L
.2326 .26566 L
.23183 .26462 L
.22899 .26082 L
.227 .25813 L
.22539 .25599 L
.22217 .25168 L
.22178 .25116 L
.21814 .24633 L
.21734 .24526 L
.21448 .2415 L
.2125 .23887 L
.21082 .23666 L
.20767 .2325 L
.20716 .23183 L
.20347 .227 L
.20284 .22617 L
.19976 .22217 L
.19801 .21988 L
.19604 .21734 L
.19318 .2136 L
.19232 .2125 L
.18859 .20767 L
.18835 .20736 L
.18482 .20284 L
.18351 .20115 L
.18105 .19801 L
.17868 .19496 L
.17727 .19318 L
.17385 .1888 L
.17349 .18835 L
.16968 .18351 L
.16902 .18267 L
.16585 .17868 L
.16419 .17656 L
.16202 .17385 L
.15935 .17048 L
.15818 .16902 L
.15452 .16442 L
.15434 .16419 L
.15046 .15935 L
.14969 .15839 L
.14656 .15452 L
.14486 .15239 L
.14266 .14969 L
.14003 .14641 L
.13876 .14486 L
.1352 .14044 L
.13485 .14003 L
.13092 .1352 L
.13036 .13451 L
.12696 .13036 L
.12553 .12861 L
.12299 .12553 L
.1207 .12272 L
.11902 .1207 L
.11587 .11685 L
.11505 .11587 L
.11106 .11104 L
.11104 .111 L
.10704 .1062 L
.1062 .10519 L
.10301 .10137 L
.10137 .0994 L
.09897 .09654 L
.09654 .09362 L
.09493 .09171 L
.09171 .08786 L
.09087 .08688 L
.08688 .08212 L
.08682 .08204 L
.08272 .07721 L
.08204 .07641 L
.07862 .07238 L
.07721 .07072 L
.0745 .06755 L
.07238 .06505 L
.07038 .06272 L
.06755 .05939 L
.06625 .05789 L
.06272 .05375 L
.06212 .05305 L
.05797 .04822 L
.05789 .04812 L
.05379 .04339 L
.05305 .04254 L
.0496 .03856 L
.04822 .03696 L
.0454 .03373 L
.04339 .03141 L
.04119 .02889 L
.03856 .02586 L
.03697 .02406 L
.03373 .02028 L
.03275 .01923 L
F
0 g
.96725 .01923 m
.96627 .02028 L
.96303 .02406 L
.96144 .02586 L
.95881 .02889 L
.95661 .03141 L
.95461 .03373 L
.95178 .03696 L
.95041 .03856 L
.94695 .04254 L
.94621 .04339 L
.94211 .04813 L
.94203 .04822 L
.93789 .05305 L
.93728 .05375 L
.93375 .05789 L
.93245 .05939 L
.92962 .06272 L
.92762 .06505 L
.9255 .06755 L
.92279 .07072 L
.92139 .07238 L
.91796 .07641 L
.91728 .07721 L
.91318 .08204 L
.91312 .08212 L
.90913 .08688 L
.90829 .08786 L
.90508 .09171 L
.90346 .09362 L
.90103 .09654 L
.89863 .0994 L
.89699 .10137 L
.8938 .10519 L
.89296 .1062 L
.88896 .111 L
.88894 .11104 L
.88495 .11587 L
.88413 .11685 L
.88098 .1207 L
.8793 .12272 L
.87701 .12553 L
.87447 .12861 L
.87304 .13036 L
.86964 .13451 L
.86909 .1352 L
.86515 .14003 L
.8648 .14045 L
.86124 .14486 L
.85997 .14641 L
Mistroke
.85734 .14969 L
.85514 .15239 L
.85344 .15452 L
.85031 .15839 L
.84954 .15935 L
.84567 .16419 L
.84548 .16442 L
.84182 .16902 L
.84065 .17048 L
.83798 .17385 L
.83581 .17656 L
.83415 .17868 L
.83098 .18267 L
.83032 .18351 L
.82651 .18835 L
.82615 .1888 L
.82273 .19318 L
.82132 .19496 L
.81895 .19801 L
.81649 .20115 L
.81518 .20284 L
.81165 .20736 L
.81141 .20767 L
.80768 .2125 L
.80682 .21361 L
.80396 .21734 L
.80199 .21988 L
.80024 .22217 L
.79716 .22618 L
.79653 .227 L
.79284 .23183 L
.79233 .23251 L
.78918 .23666 L
.7875 .23887 L
.78552 .2415 L
.78266 .24526 L
.78186 .24633 L
.77822 .25116 L
.77783 .25168 L
.77461 .25599 L
.773 .25814 L
.77101 .26082 L
.76817 .26462 L
.7674 .26566 L
.76382 .27049 L
.76334 .27114 L
.76026 .27532 L
.7585 .27769 L
.75671 .28015 L
.75367 .28427 L
Mistroke
.75316 .28498 L
.74964 .28981 L
.74884 .2909 L
.74613 .29465 L
.74401 .29755 L
.74263 .29948 L
.73918 .30424 L
.73913 .30431 L
.73567 .30914 L
.73434 .31098 L
.73221 .31397 L
.72951 .31774 L
.72876 .31881 L
.72533 .32364 L
.72468 .32455 L
.72192 .32847 L
.71985 .33139 L
.71851 .3333 L
.71511 .33813 L
.71502 .33827 L
.71175 .34296 L
.71019 .3452 L
.70839 .3478 L
.70535 .35216 L
.70503 .35263 L
.70171 .35746 L
.70052 .35917 L
.69839 .36229 L
.69569 .36622 L
.69508 .36712 L
.69179 .37196 L
.69086 .37331 L
.68851 .37679 L
.68603 .38045 L
.68524 .38162 L
.68199 .38645 L
.68119 .38764 L
.67876 .39128 L
.67636 .39487 L
.67554 .39612 L
.67233 .40095 L
.67153 .40215 L
.66914 .40578 L
.6667 .40947 L
.66596 .41061 L
.66279 .41544 L
.66187 .41685 L
.65964 .42027 L
.65704 .42428 L
.6565 .42511 L
Mistroke
.65338 .42994 L
.6522 .43216 L
.64737 .43365 L
.64475 .43477 L
.64254 .43862 L
.64189 .4396 L
.63868 .44443 L
.63771 .4459 L
.63548 .44927 L
.63288 .4532 L
.63228 .4541 L
.6291 .45893 L
.62804 .46052 L
.62592 .46376 L
.62321 .46787 L
.62274 .46859 L
.61957 .47342 L
.61838 .47524 L
.61641 .47826 L
.61355 .48262 L
.61324 .48309 L
.61009 .48792 L
.60872 .49002 L
.60694 .49275 L
.60388 .49742 L
.60378 .49758 L
.60063 .50242 L
.59905 .50482 L
.59747 .50725 L
.59431 .51208 L
.59422 .51221 L
.59115 .51691 L
.58939 .51959 L
.58798 .52174 L
.58479 .52658 L
.58456 .52693 L
.5816 .53141 L
.57973 .53423 L
.57839 .53624 L
.57516 .54107 L
.57489 .54147 L
.57192 .5459 L
.57006 .54863 L
.56864 .55073 L
.56532 .55557 L
.56523 .55569 L
.56196 .5604 L
.5604 .56262 L
.55855 .56523 L
.55557 .56938 L
Mistroke
.55507 .57006 L
.55151 .57489 L
.55073 .57593 L
.54786 .57973 L
.5459 .58223 L
.54407 .58456 L
.54107 .58823 L
.5401 .58939 L
.53624 .59385 L
.53591 .59422 L
.53141 .59903 L
.53139 .59905 L
.52658 .60369 L
.52637 .60388 L
.52174 .60776 L
.5205 .60872 L
.51691 .61113 L
.51254 .61355 L
.51208 .61375 L
.50725 .61554 L
.50242 .61644 L
.49758 .61644 L
.49275 .61554 L
.48792 .61375 L
.48746 .61355 L
.48309 .61113 L
.4795 .60872 L
.47826 .60775 L
.47363 .60388 L
.47342 .60369 L
.46862 .59905 L
.46859 .59903 L
.46409 .59422 L
.46376 .59385 L
.4599 .58939 L
.45893 .58822 L
.45594 .58456 L
.4541 .58223 L
.45215 .57973 L
.44927 .57593 L
.44849 .57489 L
.44493 .57006 L
.44443 .56938 L
.44145 .56523 L
.4396 .56262 L
.43804 .5604 L
.43477 .55569 L
.43468 .55557 L
.43137 .55073 L
.42994 .54863 L
Mistroke
.42808 .5459 L
.42511 .54147 L
.42484 .54107 L
.42161 .53624 L
.42027 .53423 L
.4184 .53141 L
.41544 .52693 L
.41521 .52658 L
.41202 .52174 L
.41061 .51959 L
.40885 .51691 L
.40578 .51221 L
.40569 .51208 L
.40253 .50725 L
.40095 .50482 L
.39937 .50242 L
.39622 .49758 L
.39612 .49742 L
.39307 .49275 L
.39128 .49002 L
.38991 .48792 L
.38676 .48309 L
.38645 .48262 L
.38359 .47826 L
.38162 .47524 L
.38043 .47342 L
.37726 .46859 L
.37679 .46787 L
.37408 .46376 L
.37196 .46052 L
.3709 .45893 L
.36772 .4541 L
.36712 .45319 L
.36452 .44927 L
.36229 .4459 L
.36132 .44443 L
.35811 .4396 L
.35746 .43862 L
.35525 .43477 L
.35263 .43365 L
.3478 .43216 L
.34662 .42994 L
.3435 .42511 L
.34296 .42427 L
.34036 .42027 L
.33813 .41685 L
.33721 .41544 L
.33405 .41061 L
.3333 .40947 L
.33086 .40578 L
Mistroke
.32847 .40214 L
.32767 .40095 L
.32446 .39612 L
.32364 .39487 L
.32124 .39128 L
.31881 .38763 L
.31801 .38645 L
.31476 .38162 L
.31397 .38045 L
.31149 .37679 L
.30914 .37331 L
.30821 .37196 L
.30493 .36712 L
.30431 .36622 L
.30161 .36229 L
.29948 .35917 L
.2983 .35746 L
.29497 .35263 L
.29465 .35216 L
.29161 .3478 L
.28981 .3452 L
.28825 .34296 L
.28498 .33827 L
.28489 .33813 L
.28149 .3333 L
.28015 .33139 L
.27808 .32847 L
.27532 .32454 L
.27467 .32364 L
.27124 .31881 L
.27049 .31774 L
.26779 .31397 L
.26566 .31097 L
.26433 .30914 L
.26087 .30431 L
.26082 .30424 L
.25737 .29948 L
.25599 .29755 L
.25387 .29465 L
.25116 .2909 L
.25037 .28981 L
.24684 .28498 L
.24633 .28427 L
.24329 .28015 L
.2415 .27769 L
.23974 .27532 L
.23666 .27114 L
.23618 .27049 L
.2326 .26566 L
.23183 .26462 L
Mistroke
.22899 .26082 L
.227 .25813 L
.22539 .25599 L
.22217 .25168 L
.22178 .25116 L
.21814 .24633 L
.21734 .24526 L
.21448 .2415 L
.2125 .23887 L
.21082 .23666 L
.20767 .2325 L
.20716 .23183 L
.20347 .227 L
.20284 .22617 L
.19976 .22217 L
.19801 .21988 L
.19604 .21734 L
.19318 .2136 L
.19232 .2125 L
.18859 .20767 L
.18835 .20736 L
.18482 .20284 L
.18351 .20115 L
.18105 .19801 L
.17868 .19496 L
.17727 .19318 L
.17385 .1888 L
.17349 .18835 L
.16968 .18351 L
.16902 .18267 L
.16585 .17868 L
.16419 .17656 L
.16202 .17385 L
.15935 .17048 L
.15818 .16902 L
.15452 .16442 L
.15434 .16419 L
.15046 .15935 L
.14969 .15839 L
.14656 .15452 L
.14486 .15239 L
.14266 .14969 L
.14003 .14641 L
.13876 .14486 L
.1352 .14044 L
.13485 .14003 L
.13092 .1352 L
.13036 .13451 L
.12696 .13036 L
.12553 .12861 L
Mistroke
.12299 .12553 L
.1207 .12272 L
.11902 .1207 L
.11587 .11685 L
.11505 .11587 L
.11106 .11104 L
.11104 .111 L
.10704 .1062 L
.1062 .10519 L
.10301 .10137 L
.10137 .0994 L
.09897 .09654 L
.09654 .09362 L
.09493 .09171 L
.09171 .08786 L
.09087 .08688 L
.08688 .08212 L
.08682 .08204 L
.08272 .07721 L
.08204 .07641 L
.07862 .07238 L
.07721 .07072 L
.0745 .06755 L
.07238 .06505 L
.07038 .06272 L
.06755 .05939 L
.06625 .05789 L
.06272 .05375 L
.06212 .05305 L
.05797 .04822 L
.05789 .04812 L
.05379 .04339 L
.05305 .04254 L
.0496 .03856 L
.04822 .03696 L
.0454 .03373 L
.04339 .03141 L
.04119 .02889 L
.03856 .02586 L
.03697 .02406 L
.03373 .02028 L
.03275 .01923 L
Mfstroke
.282 .64 0 r
.96486 .01923 m
.96144 .0231 L
.96062 .02406 L
.95661 .02864 L
.95639 .02889 L
.95217 .03373 L
.95178 .03418 L
.94798 .03856 L
.94695 .03974 L
.94379 .04339 L
.94211 .04532 L
.93962 .04822 L
.93728 .05092 L
.93545 .05305 L
.93245 .05653 L
.93129 .05789 L
.92762 .06216 L
.92714 .06272 L
.92301 .06755 L
.92279 .06781 L
.9189 .07238 L
.91796 .07349 L
.9148 .07721 L
.91312 .07918 L
.91071 .08204 L
.90829 .08489 L
.90663 .08688 L
.90346 .09062 L
.90255 .09171 L
.89863 .09637 L
.89849 .09654 L
.89445 .10137 L
.8938 .10215 L
.89042 .1062 L
.88896 .10795 L
.88641 .11104 L
.88413 .11377 L
.8824 .11587 L
.8793 .1196 L
.8784 .1207 L
.87447 .12546 L
.87441 .12553 L
.87045 .13036 L
.86964 .13135 L
.8665 .1352 L
.8648 .13725 L
.86255 .14003 L
.85997 .14318 L
.85862 .14486 L
.85514 .14913 L
.85469 .14969 L
.85079 .15452 L
.85031 .15511 L
.8469 .15935 L
.84548 .16111 L
.84302 .16419 L
.84065 .16714 L
.83915 .16902 L
.83581 .17318 L
.83529 .17385 L
.83144 .17868 L
.83098 .17926 L
.82762 .18351 L
.82615 .18536 L
.8238 .18835 L
.82132 .19149 L
.82 .19318 L
.81649 .19764 L
.8162 .19801 L
.81242 .20284 L
.81165 .20382 L
.80866 .20767 L
.80682 .21003 L
.80491 .2125 L
.80199 .21626 L
.80116 .21734 L
.79743 .22217 L
.79716 .22252 L
.79373 .227 L
.79233 .22882 L
.79003 .23183 L
.7875 .23514 L
.78634 .23666 L
.78266 .24148 L
.78265 .2415 L
.779 .24633 L
.77783 .24787 L
.77536 .25116 L
.773 .25428 L
.77172 .25599 L
.76817 .26072 L
.76809 .26082 L
.76449 .26566 L
.76334 .26719 L
.76089 .27049 L
.7585 .2737 L
.75731 .27532 L
.75373 .28015 L
.75367 .28023 L
.75019 .28498 L
.74884 .28681 L
.74664 .28981 L
.74401 .29341 L
.74311 .29465 L
.73959 .29948 L
.73918 .30005 L
.7361 .30431 L
.73434 .30673 L
.73261 .30914 L
.72951 .31343 L
.72913 .31397 L
.72567 .31881 L
.72468 .32018 L
.72223 .32364 L
.71985 .32697 L
.71879 .32847 L
.71536 .3333 L
.71502 .33379 L
.71196 .33813 L
.71019 .34065 L
.70857 .34296 L
.70535 .34755 L
.70518 .3478 L
.70182 .35263 L
.70052 .35449 L
.69847 .35746 L
.69569 .36146 L
.69512 .36229 L
.6918 .36712 L
.69086 .36849 L
.68849 .37196 L
.68603 .37555 L
.68518 .37679 L
.6819 .38162 L
.68119 .38265 L
.67863 .38645 L
.67636 .3898 L
.67537 .39128 L
.67212 .39612 L
.67153 .39699 L
.6689 .40095 L
.6667 .40423 L
.66567 .40578 L
.66247 .41061 L
.66187 .41152 L
.65928 .41544 L
.65704 .41885 L
.6561 .42027 L
.65294 .42511 L
.6522 .42622 L
.65011 .42994 L
.64737 .43205 L
.64254 .43055 L
.63994 .43477 L
.63771 .43803 L
.63664 .4396 L
.63335 .44443 L
.63288 .44513 L
.63007 .44927 L
.62804 .45224 L
.62679 .4541 L
.62351 .45893 L
.62321 .45936 L
.62024 .46376 L
.61838 .46649 L
.61696 .46859 L
.61368 .47342 L
.61355 .47363 L
.61041 .47826 L
.60872 .48075 L
.60714 .48309 L
.60388 .48787 L
.60385 .48792 L
.60057 .49275 L
.59905 .49497 L
.59727 .49758 L
.59422 .50204 L
.59397 .50242 L
.59065 .50725 L
.58939 .50908 L
.58732 .51208 L
.58456 .51606 L
.58397 .51691 L
.5806 .52174 L
.57973 .52298 L
.5772 .52658 L
.57489 .52982 L
.57376 .53141 L
.57029 .53624 L
.57006 .53655 L
.56677 .54107 L
.56523 .54315 L
.56319 .5459 L
.5604 .5496 L
.55953 .55073 L
.55579 .55557 L
.55557 .55585 L
.55195 .5604 L
.55073 .56188 L
.54796 .56523 L
.5459 .56764 L
.5438 .57006 L
.54107 .57309 L
.5394 .57489 L
.53624 .57815 L
.53466 .57973 L
.53141 .58279 L
.52943 .58456 L
.52658 .58693 L
.52336 .58939 L
.52174 .59051 L
.51691 .59346 L
.51553 .59422 L
.51208 .59574 L
.50725 .59729 L
.50242 .59807 L
.49758 .59807 L
.49275 .59729 L
.48792 .59574 L
.48447 .59422 L
.48309 .59346 L
.47826 .59051 L
.47665 .58939 L
.47342 .58693 L
.47057 .58456 L
.46859 .58279 L
.46534 .57973 L
.46376 .57815 L
.46061 .57489 L
.45893 .57308 L
.4562 .57006 L
.4541 .56764 L
.45204 .56523 L
.44927 .56188 L
.44805 .5604 L
.44443 .55585 L
.44421 .55557 L
.44047 .55073 L
.4396 .5496 L
.43681 .5459 L
.43477 .54315 L
.43323 .54107 L
.42994 .53655 L
.42971 .53624 L
.42624 .53141 L
.42511 .52982 L
.4228 .52658 L
.42027 .52298 L
.4194 .52174 L
.41603 .51691 L
.41544 .51606 L
.41268 .51208 L
.41061 .50908 L
.40935 .50725 L
.40603 .50242 L
.40578 .50204 L
.40273 .49758 L
.40095 .49497 L
.39943 .49275 L
.39615 .48792 L
.39612 .48787 L
.39287 .48309 L
.39128 .48075 L
.38959 .47826 L
.38645 .47362 L
.38632 .47342 L
.38304 .46859 L
.38162 .46649 L
.37977 .46376 L
.37679 .45936 L
.37649 .45893 L
.37321 .4541 L
.37196 .45224 L
.36993 .44927 L
.36712 .44513 L
.36665 .44443 L
.36336 .4396 L
.36229 .43803 L
.36006 .43477 L
.35746 .43055 L
.35263 .43205 L
.34989 .42994 L
.3478 .42622 L
.34707 .42511 L
.3439 .42027 L
.34296 .41884 L
.34072 .41544 L
.33813 .41151 L
.33753 .41061 L
.33433 .40578 L
.3333 .40423 L
.33111 .40095 L
.32847 .39699 L
.32788 .39612 L
.32463 .39128 L
.32364 .3898 L
.32137 .38645 L
.31881 .38265 L
.3181 .38162 L
.31482 .37679 L
.31397 .37555 L
.31151 .37196 L
.30914 .36848 L
.3082 .36712 L
.30488 .36229 L
.30431 .36146 L
.30154 .35746 L
.29948 .35448 L
.29818 .35263 L
.29482 .3478 L
.29465 .34754 L
.29144 .34296 L
.28981 .34065 L
.28804 .33813 L
.28498 .33378 L
.28464 .3333 L
.28121 .32847 L
.28015 .32696 L
.27778 .32364 L
.27532 .32018 L
.27433 .31881 L
.27087 .31397 L
.27049 .31343 L
.26739 .30914 L
.26566 .30672 L
.2639 .30431 L
.26082 .30005 L
.26041 .29948 L
.25689 .29465 L
.25599 .29341 L
.25336 .28981 L
.25116 .2868 L
.24982 .28498 L
.24633 .28023 L
.24627 .28015 L
.24269 .27532 L
.2415 .2737 L
.23911 .27049 L
.23666 .26719 L
.23551 .26566 L
.23191 .26082 L
.23183 .26071 L
.22828 .25599 L
.227 .25428 L
.22465 .25116 L
.22217 .24787 L
.221 .24633 L
.21735 .2415 L
.21734 .24148 L
.21366 .23666 L
.2125 .23514 L
.20997 .23183 L
.20767 .22882 L
.20627 .227 L
.20284 .22252 L
.20257 .22217 L
.19884 .21734 L
.19801 .21626 L
.19509 .2125 L
.19318 .21003 L
.19134 .20767 L
.18835 .20382 L
.18758 .20284 L
.1838 .19801 L
.18351 .19764 L
.18 .19318 L
.17868 .19149 L
.1762 .18835 L
.17385 .18536 L
.17238 .18351 L
.16902 .17926 L
.16856 .17868 L
.16472 .17385 L
.16419 .17318 L
.16085 .16902 L
.15935 .16714 L
.15698 .16419 L
.15452 .16111 L
.1531 .15935 L
.14969 .15511 L
.14922 .15452 L
.14531 .14969 L
.14486 .14913 L
.14138 .14486 L
.14003 .14318 L
.13745 .14003 L
.1352 .13725 L
.1335 .1352 L
.13036 .13135 L
.12955 .13036 L
.12559 .12553 L
.12553 .12546 L
.1216 .1207 L
.1207 .1196 L
.1176 .11587 L
.11587 .11376 L
.11359 .11104 L
.11104 .10795 L
.10958 .1062 L
.1062 .10215 L
.10555 .10137 L
.10151 .09654 L
.10137 .09637 L
.09745 .09171 L
.09654 .09062 L
.09338 .08688 L
.09171 .08489 L
.08929 .08204 L
.08688 .07918 L
.0852 .07721 L
.08204 .07349 L
.0811 .07238 L
.07721 .06781 L
.07699 .06755 L
.07286 .06272 L
.07238 .06216 L
.06871 .05789 L
.06755 .05653 L
.06455 .05305 L
.06272 .05092 L
.06038 .04822 L
.05789 .04532 L
.05621 .04339 L
.05305 .03974 L
.05202 .03856 L
.04822 .03418 L
.04783 .03373 L
.04361 .02889 L
.04339 .02864 L
.03938 .02406 L
.03856 .0231 L
.03514 .01923 L
F
0 g
.96486 .01923 m
.96144 .0231 L
.96062 .02406 L
.95661 .02864 L
.95639 .02889 L
.95217 .03373 L
.95178 .03418 L
.94798 .03856 L
.94695 .03974 L
.94379 .04339 L
.94211 .04532 L
.93962 .04822 L
.93728 .05092 L
.93545 .05305 L
.93245 .05653 L
.93129 .05789 L
.92762 .06216 L
.92714 .06272 L
.92301 .06755 L
.92279 .06781 L
.9189 .07238 L
.91796 .07349 L
.9148 .07721 L
.91312 .07918 L
.91071 .08204 L
.90829 .08489 L
.90663 .08688 L
.90346 .09062 L
.90255 .09171 L
.89863 .09637 L
.89849 .09654 L
.89445 .10137 L
.8938 .10215 L
.89042 .1062 L
.88896 .10795 L
.88641 .11104 L
.88413 .11377 L
.8824 .11587 L
.8793 .1196 L
.8784 .1207 L
.87447 .12546 L
.87441 .12553 L
.87045 .13036 L
.86964 .13135 L
.8665 .1352 L
.8648 .13725 L
.86255 .14003 L
.85997 .14318 L
.85862 .14486 L
.85514 .14913 L
Mistroke
.85469 .14969 L
.85079 .15452 L
.85031 .15511 L
.8469 .15935 L
.84548 .16111 L
.84302 .16419 L
.84065 .16714 L
.83915 .16902 L
.83581 .17318 L
.83529 .17385 L
.83144 .17868 L
.83098 .17926 L
.82762 .18351 L
.82615 .18536 L
.8238 .18835 L
.82132 .19149 L
.82 .19318 L
.81649 .19764 L
.8162 .19801 L
.81242 .20284 L
.81165 .20382 L
.80866 .20767 L
.80682 .21003 L
.80491 .2125 L
.80199 .21626 L
.80116 .21734 L
.79743 .22217 L
.79716 .22252 L
.79373 .227 L
.79233 .22882 L
.79003 .23183 L
.7875 .23514 L
.78634 .23666 L
.78266 .24148 L
.78265 .2415 L
.779 .24633 L
.77783 .24787 L
.77536 .25116 L
.773 .25428 L
.77172 .25599 L
.76817 .26072 L
.76809 .26082 L
.76449 .26566 L
.76334 .26719 L
.76089 .27049 L
.7585 .2737 L
.75731 .27532 L
.75373 .28015 L
.75367 .28023 L
.75019 .28498 L
Mistroke
.74884 .28681 L
.74664 .28981 L
.74401 .29341 L
.74311 .29465 L
.73959 .29948 L
.73918 .30005 L
.7361 .30431 L
.73434 .30673 L
.73261 .30914 L
.72951 .31343 L
.72913 .31397 L
.72567 .31881 L
.72468 .32018 L
.72223 .32364 L
.71985 .32697 L
.71879 .32847 L
.71536 .3333 L
.71502 .33379 L
.71196 .33813 L
.71019 .34065 L
.70857 .34296 L
.70535 .34755 L
.70518 .3478 L
.70182 .35263 L
.70052 .35449 L
.69847 .35746 L
.69569 .36146 L
.69512 .36229 L
.6918 .36712 L
.69086 .36849 L
.68849 .37196 L
.68603 .37555 L
.68518 .37679 L
.6819 .38162 L
.68119 .38265 L
.67863 .38645 L
.67636 .3898 L
.67537 .39128 L
.67212 .39612 L
.67153 .39699 L
.6689 .40095 L
.6667 .40423 L
.66567 .40578 L
.66247 .41061 L
.66187 .41152 L
.65928 .41544 L
.65704 .41885 L
.6561 .42027 L
.65294 .42511 L
.6522 .42622 L
Mistroke
.65011 .42994 L
.64737 .43205 L
.64254 .43055 L
.63994 .43477 L
.63771 .43803 L
.63664 .4396 L
.63335 .44443 L
.63288 .44513 L
.63007 .44927 L
.62804 .45224 L
.62679 .4541 L
.62351 .45893 L
.62321 .45936 L
.62024 .46376 L
.61838 .46649 L
.61696 .46859 L
.61368 .47342 L
.61355 .47363 L
.61041 .47826 L
.60872 .48075 L
.60714 .48309 L
.60388 .48787 L
.60385 .48792 L
.60057 .49275 L
.59905 .49497 L
.59727 .49758 L
.59422 .50204 L
.59397 .50242 L
.59065 .50725 L
.58939 .50908 L
.58732 .51208 L
.58456 .51606 L
.58397 .51691 L
.5806 .52174 L
.57973 .52298 L
.5772 .52658 L
.57489 .52982 L
.57376 .53141 L
.57029 .53624 L
.57006 .53655 L
.56677 .54107 L
.56523 .54315 L
.56319 .5459 L
.5604 .5496 L
.55953 .55073 L
.55579 .55557 L
.55557 .55585 L
.55195 .5604 L
.55073 .56188 L
.54796 .56523 L
Mistroke
.5459 .56764 L
.5438 .57006 L
.54107 .57309 L
.5394 .57489 L
.53624 .57815 L
.53466 .57973 L
.53141 .58279 L
.52943 .58456 L
.52658 .58693 L
.52336 .58939 L
.52174 .59051 L
.51691 .59346 L
.51553 .59422 L
.51208 .59574 L
.50725 .59729 L
.50242 .59807 L
.49758 .59807 L
.49275 .59729 L
.48792 .59574 L
.48447 .59422 L
.48309 .59346 L
.47826 .59051 L
.47665 .58939 L
.47342 .58693 L
.47057 .58456 L
.46859 .58279 L
.46534 .57973 L
.46376 .57815 L
.46061 .57489 L
.45893 .57308 L
.4562 .57006 L
.4541 .56764 L
.45204 .56523 L
.44927 .56188 L
.44805 .5604 L
.44443 .55585 L
.44421 .55557 L
.44047 .55073 L
.4396 .5496 L
.43681 .5459 L
.43477 .54315 L
.43323 .54107 L
.42994 .53655 L
.42971 .53624 L
.42624 .53141 L
.42511 .52982 L
.4228 .52658 L
.42027 .52298 L
.4194 .52174 L
.41603 .51691 L
Mistroke
.41544 .51606 L
.41268 .51208 L
.41061 .50908 L
.40935 .50725 L
.40603 .50242 L
.40578 .50204 L
.40273 .49758 L
.40095 .49497 L
.39943 .49275 L
.39615 .48792 L
.39612 .48787 L
.39287 .48309 L
.39128 .48075 L
.38959 .47826 L
.38645 .47362 L
.38632 .47342 L
.38304 .46859 L
.38162 .46649 L
.37977 .46376 L
.37679 .45936 L
.37649 .45893 L
.37321 .4541 L
.37196 .45224 L
.36993 .44927 L
.36712 .44513 L
.36665 .44443 L
.36336 .4396 L
.36229 .43803 L
.36006 .43477 L
.35746 .43055 L
.35263 .43205 L
.34989 .42994 L
.3478 .42622 L
.34707 .42511 L
.3439 .42027 L
.34296 .41884 L
.34072 .41544 L
.33813 .41151 L
.33753 .41061 L
.33433 .40578 L
.3333 .40423 L
.33111 .40095 L
.32847 .39699 L
.32788 .39612 L
.32463 .39128 L
.32364 .3898 L
.32137 .38645 L
.31881 .38265 L
.3181 .38162 L
.31482 .37679 L
Mistroke
.31397 .37555 L
.31151 .37196 L
.30914 .36848 L
.3082 .36712 L
.30488 .36229 L
.30431 .36146 L
.30154 .35746 L
.29948 .35448 L
.29818 .35263 L
.29482 .3478 L
.29465 .34754 L
.29144 .34296 L
.28981 .34065 L
.28804 .33813 L
.28498 .33378 L
.28464 .3333 L
.28121 .32847 L
.28015 .32696 L
.27778 .32364 L
.27532 .32018 L
.27433 .31881 L
.27087 .31397 L
.27049 .31343 L
.26739 .30914 L
.26566 .30672 L
.2639 .30431 L
.26082 .30005 L
.26041 .29948 L
.25689 .29465 L
.25599 .29341 L
.25336 .28981 L
.25116 .2868 L
.24982 .28498 L
.24633 .28023 L
.24627 .28015 L
.24269 .27532 L
.2415 .2737 L
.23911 .27049 L
.23666 .26719 L
.23551 .26566 L
.23191 .26082 L
.23183 .26071 L
.22828 .25599 L
.227 .25428 L
.22465 .25116 L
.22217 .24787 L
.221 .24633 L
.21735 .2415 L
.21734 .24148 L
.21366 .23666 L
Mistroke
.2125 .23514 L
.20997 .23183 L
.20767 .22882 L
.20627 .227 L
.20284 .22252 L
.20257 .22217 L
.19884 .21734 L
.19801 .21626 L
.19509 .2125 L
.19318 .21003 L
.19134 .20767 L
.18835 .20382 L
.18758 .20284 L
.1838 .19801 L
.18351 .19764 L
.18 .19318 L
.17868 .19149 L
.1762 .18835 L
.17385 .18536 L
.17238 .18351 L
.16902 .17926 L
.16856 .17868 L
.16472 .17385 L
.16419 .17318 L
.16085 .16902 L
.15935 .16714 L
.15698 .16419 L
.15452 .16111 L
.1531 .15935 L
.14969 .15511 L
.14922 .15452 L
.14531 .14969 L
.14486 .14913 L
.14138 .14486 L
.14003 .14318 L
.13745 .14003 L
.1352 .13725 L
.1335 .1352 L
.13036 .13135 L
.12955 .13036 L
.12559 .12553 L
.12553 .12546 L
.1216 .1207 L
.1207 .1196 L
.1176 .11587 L
.11587 .11376 L
.11359 .11104 L
.11104 .10795 L
.10958 .1062 L
.1062 .10215 L
Mistroke
.10555 .10137 L
.10151 .09654 L
.10137 .09637 L
.09745 .09171 L
.09654 .09062 L
.09338 .08688 L
.09171 .08489 L
.08929 .08204 L
.08688 .07918 L
.0852 .07721 L
.08204 .07349 L
.0811 .07238 L
.07721 .06781 L
.07699 .06755 L
.07286 .06272 L
.07238 .06216 L
.06871 .05789 L
.06755 .05653 L
.06455 .05305 L
.06272 .05092 L
.06038 .04822 L
.05789 .04532 L
.05621 .04339 L
.05305 .03974 L
.05202 .03856 L
.04822 .03418 L
.04783 .03373 L
.04361 .02889 L
.04339 .02864 L
.03938 .02406 L
.03856 .0231 L
.03514 .01923 L
Mfstroke
.146 .595 0 r
.96184 .01923 m
.96144 .01967 L
.95759 .02406 L
.95661 .02518 L
.95336 .02889 L
.95178 .0307 L
.94914 .03373 L
.94695 .03623 L
.94492 .03856 L
.94211 .04178 L
.94072 .04339 L
.93728 .04735 L
.93653 .04822 L
.93245 .05293 L
.93235 .05305 L
.92819 .05789 L
.92762 .05854 L
.92404 .06272 L
.92279 .06417 L
.9199 .06755 L
.91796 .06982 L
.91577 .07238 L
.91312 .07548 L
.91165 .07721 L
.90829 .08116 L
.90754 .08204 L
.90346 .08686 L
.90345 .08688 L
.89937 .09171 L
.89863 .09259 L
.89531 .09654 L
.8938 .09833 L
.89125 .10137 L
.88896 .1041 L
.88721 .1062 L
.88413 .10988 L
.88317 .11104 L
.8793 .11569 L
.87915 .11587 L
.87515 .1207 L
.87447 .12152 L
.87116 .12553 L
.86964 .12737 L
.86718 .13036 L
.8648 .13324 L
.8632 .1352 L
.85997 .13913 L
.85924 .14003 L
.8553 .14486 L
.85514 .14505 L
.85137 .14969 L
.85031 .15099 L
.84745 .15452 L
.84548 .15695 L
.84354 .15935 L
.84065 .16294 L
.83965 .16419 L
.83581 .16895 L
.83576 .16902 L
.83189 .17385 L
.83098 .17499 L
.82804 .17868 L
.82615 .18105 L
.82419 .18351 L
.82132 .18713 L
.82036 .18835 L
.81653 .19318 L
.81649 .19324 L
.81273 .19801 L
.81165 .19938 L
.80894 .20284 L
.80682 .20554 L
.80516 .20767 L
.80199 .21173 L
.80139 .2125 L
.79763 .21734 L
.79716 .21794 L
.79389 .22217 L
.79233 .22419 L
.79016 .227 L
.7875 .23046 L
.78644 .23183 L
.78273 .23666 L
.78266 .23675 L
.77905 .2415 L
.77783 .24309 L
.77537 .24633 L
.773 .24944 L
.7717 .25116 L
.76817 .25583 L
.76804 .25599 L
.76441 .26082 L
.76334 .26225 L
.76078 .26566 L
.7585 .26869 L
.75717 .27049 L
.75367 .27517 L
.75356 .27532 L
.74998 .28015 L
.74884 .28168 L
.7464 .28498 L
.74401 .28822 L
.74284 .28981 L
.73929 .29465 L
.73918 .2948 L
.73576 .29948 L
.73434 .3014 L
.73223 .30431 L
.72951 .30805 L
.72872 .30914 L
.72522 .31397 L
.72468 .31472 L
.72174 .31881 L
.71985 .32143 L
.71827 .32364 L
.71502 .32818 L
.71481 .32847 L
.71137 .3333 L
.71019 .33496 L
.70794 .33813 L
.70535 .34177 L
.70452 .34296 L
.70111 .3478 L
.70052 .34863 L
.69772 .35263 L
.69569 .35552 L
.69434 .35746 L
.69097 .36229 L
.69086 .36245 L
.68762 .36712 L
.68603 .36942 L
.68428 .37196 L
.68119 .37643 L
.68095 .37679 L
.67764 .38162 L
.67636 .38348 L
.67433 .38645 L
.67153 .39056 L
.67104 .39128 L
.66777 .39612 L
.6667 .39769 L
.66451 .40095 L
.66187 .40486 L
.66125 .40578 L
.65802 .41061 L
.65704 .41207 L
.65479 .41544 L
.6522 .41933 L
.65158 .42027 L
.64838 .42511 L
.64737 .42725 L
.64254 .42822 L
.63771 .42912 L
.63641 .42994 L
.633 .43477 L
.63288 .43495 L
.62959 .4396 L
.62804 .4418 L
.62619 .44443 L
.62321 .44864 L
.62277 .44927 L
.61936 .4541 L
.61838 .45548 L
.61595 .45893 L
.61355 .46231 L
.61252 .46376 L
.60909 .46859 L
.60872 .46912 L
.60565 .47342 L
.60388 .47589 L
.6022 .47826 L
.59905 .48264 L
.59873 .48309 L
.59524 .48792 L
.59422 .48933 L
.59174 .49275 L
.58939 .49597 L
.58821 .49758 L
.58464 .50242 L
.58456 .50253 L
.58105 .50725 L
.57973 .50901 L
.57741 .51208 L
.57489 .51538 L
.57372 .51691 L
.57006 .52162 L
.56996 .52174 L
.56614 .52658 L
.56523 .52771 L
.56223 .53141 L
.5604 .53363 L
.55821 .53624 L
.55557 .53933 L
.55406 .54107 L
.55073 .5448 L
.54973 .5459 L
.5459 .54998 L
.54518 .55073 L
.54107 .55484 L
.54033 .55557 L
.53624 .55934 L
.53504 .5604 L
.53141 .56342 L
.52909 .56523 L
.52658 .56704 L
.5219 .57006 L
.52174 .57015 L
.51691 .57271 L
.51208 .57466 L
.51154 .57489 L
.50725 .57599 L
.50242 .57665 L
.49758 .57665 L
.49275 .57599 L
.48846 .57489 L
.48792 .57466 L
.48309 .57271 L
.47826 .57015 L
.4781 .57006 L
.47342 .56704 L
.47091 .56523 L
.46859 .56342 L
.46496 .5604 L
.46376 .55934 L
.45968 .55557 L
.45893 .55484 L
.45482 .55073 L
.4541 .54998 L
.45027 .5459 L
.44927 .54479 L
.44595 .54107 L
.44443 .53933 L
.44179 .53624 L
.4396 .53362 L
.43777 .53141 L
.43477 .52771 L
.43386 .52658 L
.43004 .52174 L
.42994 .52162 L
.42629 .51691 L
.42511 .51537 L
.42259 .51208 L
.42027 .509 L
.41895 .50725 L
.41544 .50253 L
.41536 .50242 L
.4118 .49758 L
.41061 .49596 L
.40826 .49275 L
.40578 .48933 L
.40476 .48792 L
.40127 .48309 L
.40095 .48263 L
.3978 .47826 L
.39612 .47589 L
.39435 .47342 L
.39128 .46911 L
.39091 .46859 L
.38748 .46376 L
.38645 .46231 L
.38406 .45893 L
.38162 .45548 L
.38064 .4541 L
.37723 .44927 L
.37679 .44864 L
.37382 .44443 L
.37196 .44179 L
.37041 .4396 L
.36712 .43494 L
.367 .43477 L
.36359 .42994 L
.36229 .42912 L
.35746 .42822 L
.35263 .42725 L
.35163 .42511 L
.34843 .42027 L
.3478 .41932 L
.34521 .41544 L
.34296 .41207 L
.34199 .41061 L
.33875 .40578 L
.33813 .40486 L
.3355 .40095 L
.3333 .39769 L
.33223 .39612 L
.32896 .39128 L
.32847 .39056 L
.32567 .38645 L
.32364 .38347 L
.32237 .38162 L
.31905 .37679 L
.31881 .37643 L
.31572 .37196 L
.31397 .36942 L
.31238 .36712 L
.30914 .36245 L
.30903 .36229 L
.30566 .35746 L
.30431 .35552 L
.30228 .35263 L
.29948 .34863 L
.29889 .3478 L
.29549 .34296 L
.29465 .34177 L
.29206 .33813 L
.28981 .33496 L
.28863 .3333 L
.28519 .32847 L
.28498 .32817 L
.28173 .32364 L
.28015 .32143 L
.27826 .31881 L
.27532 .31472 L
.27478 .31397 L
.27128 .30914 L
.27049 .30804 L
.26777 .30431 L
.26566 .3014 L
.26425 .29948 L
.26082 .29479 L
.26071 .29465 L
.25716 .28981 L
.25599 .28822 L
.2536 .28498 L
.25116 .28168 L
.25002 .28015 L
.24644 .27532 L
.24633 .27517 L
.24283 .27049 L
.2415 .26869 L
.23922 .26566 L
.23666 .26224 L
.23559 .26082 L
.23196 .25599 L
.23183 .25583 L
.2283 .25116 L
.227 .24944 L
.22463 .24633 L
.22217 .24308 L
.22095 .2415 L
.21734 .23675 L
.21727 .23666 L
.21356 .23183 L
.2125 .23046 L
.20984 .227 L
.20767 .22419 L
.20611 .22217 L
.20284 .21794 L
.20237 .21734 L
.19861 .2125 L
.19801 .21173 L
.19484 .20767 L
.19318 .20554 L
.19106 .20284 L
.18835 .19938 L
.18727 .19801 L
.18351 .19324 L
.18347 .19318 L
.17964 .18835 L
.17868 .18713 L
.17581 .18351 L
.17385 .18105 L
.17196 .17868 L
.16902 .17498 L
.16811 .17385 L
.16424 .16902 L
.16419 .16895 L
.16036 .16419 L
.15935 .16294 L
.15646 .15935 L
.15452 .15695 L
.15255 .15452 L
.14969 .15099 L
.14863 .14969 L
.14486 .14505 L
.14471 .14486 L
.14076 .14003 L
.14003 .13913 L
.1368 .1352 L
.1352 .13324 L
.13282 .13036 L
.13036 .12737 L
.12884 .12553 L
.12553 .12152 L
.12485 .1207 L
.12085 .11587 L
.1207 .11569 L
.11683 .11104 L
.11587 .10988 L
.11279 .1062 L
.11104 .1041 L
.10875 .10137 L
.1062 .09833 L
.10469 .09654 L
.10137 .09259 L
.10063 .09171 L
.09655 .08688 L
.09654 .08686 L
.09246 .08204 L
.09171 .08116 L
.08835 .07721 L
.08688 .07548 L
.08423 .07238 L
.08204 .06981 L
.0801 .06755 L
.07721 .06417 L
.07596 .06272 L
.07238 .05854 L
.07181 .05789 L
.06765 .05305 L
.06755 .05293 L
.06347 .04822 L
.06272 .04735 L
.05928 .04339 L
.05789 .04178 L
.05508 .03856 L
.05305 .03623 L
.05086 .03373 L
.04822 .03069 L
.04664 .02889 L
.04339 .02518 L
.04241 .02406 L
.03856 .01967 L
.03816 .01923 L
F
0 g
.96184 .01923 m
.96144 .01967 L
.95759 .02406 L
.95661 .02518 L
.95336 .02889 L
.95178 .0307 L
.94914 .03373 L
.94695 .03623 L
.94492 .03856 L
.94211 .04178 L
.94072 .04339 L
.93728 .04735 L
.93653 .04822 L
.93245 .05293 L
.93235 .05305 L
.92819 .05789 L
.92762 .05854 L
.92404 .06272 L
.92279 .06417 L
.9199 .06755 L
.91796 .06982 L
.91577 .07238 L
.91312 .07548 L
.91165 .07721 L
.90829 .08116 L
.90754 .08204 L
.90346 .08686 L
.90345 .08688 L
.89937 .09171 L
.89863 .09259 L
.89531 .09654 L
.8938 .09833 L
.89125 .10137 L
.88896 .1041 L
.88721 .1062 L
.88413 .10988 L
.88317 .11104 L
.8793 .11569 L
.87915 .11587 L
.87515 .1207 L
.87447 .12152 L
.87116 .12553 L
.86964 .12737 L
.86718 .13036 L
.8648 .13324 L
.8632 .1352 L
.85997 .13913 L
.85924 .14003 L
.8553 .14486 L
.85514 .14505 L
Mistroke
.85137 .14969 L
.85031 .15099 L
.84745 .15452 L
.84548 .15695 L
.84354 .15935 L
.84065 .16294 L
.83965 .16419 L
.83581 .16895 L
.83576 .16902 L
.83189 .17385 L
.83098 .17499 L
.82804 .17868 L
.82615 .18105 L
.82419 .18351 L
.82132 .18713 L
.82036 .18835 L
.81653 .19318 L
.81649 .19324 L
.81273 .19801 L
.81165 .19938 L
.80894 .20284 L
.80682 .20554 L
.80516 .20767 L
.80199 .21173 L
.80139 .2125 L
.79763 .21734 L
.79716 .21794 L
.79389 .22217 L
.79233 .22419 L
.79016 .227 L
.7875 .23046 L
.78644 .23183 L
.78273 .23666 L
.78266 .23675 L
.77905 .2415 L
.77783 .24309 L
.77537 .24633 L
.773 .24944 L
.7717 .25116 L
.76817 .25583 L
.76804 .25599 L
.76441 .26082 L
.76334 .26225 L
.76078 .26566 L
.7585 .26869 L
.75717 .27049 L
.75367 .27517 L
.75356 .27532 L
.74998 .28015 L
.74884 .28168 L
Mistroke
.7464 .28498 L
.74401 .28822 L
.74284 .28981 L
.73929 .29465 L
.73918 .2948 L
.73576 .29948 L
.73434 .3014 L
.73223 .30431 L
.72951 .30805 L
.72872 .30914 L
.72522 .31397 L
.72468 .31472 L
.72174 .31881 L
.71985 .32143 L
.71827 .32364 L
.71502 .32818 L
.71481 .32847 L
.71137 .3333 L
.71019 .33496 L
.70794 .33813 L
.70535 .34177 L
.70452 .34296 L
.70111 .3478 L
.70052 .34863 L
.69772 .35263 L
.69569 .35552 L
.69434 .35746 L
.69097 .36229 L
.69086 .36245 L
.68762 .36712 L
.68603 .36942 L
.68428 .37196 L
.68119 .37643 L
.68095 .37679 L
.67764 .38162 L
.67636 .38348 L
.67433 .38645 L
.67153 .39056 L
.67104 .39128 L
.66777 .39612 L
.6667 .39769 L
.66451 .40095 L
.66187 .40486 L
.66125 .40578 L
.65802 .41061 L
.65704 .41207 L
.65479 .41544 L
.6522 .41933 L
.65158 .42027 L
.64838 .42511 L
Mistroke
.64737 .42725 L
.64254 .42822 L
.63771 .42912 L
.63641 .42994 L
.633 .43477 L
.63288 .43495 L
.62959 .4396 L
.62804 .4418 L
.62619 .44443 L
.62321 .44864 L
.62277 .44927 L
.61936 .4541 L
.61838 .45548 L
.61595 .45893 L
.61355 .46231 L
.61252 .46376 L
.60909 .46859 L
.60872 .46912 L
.60565 .47342 L
.60388 .47589 L
.6022 .47826 L
.59905 .48264 L
.59873 .48309 L
.59524 .48792 L
.59422 .48933 L
.59174 .49275 L
.58939 .49597 L
.58821 .49758 L
.58464 .50242 L
.58456 .50253 L
.58105 .50725 L
.57973 .50901 L
.57741 .51208 L
.57489 .51538 L
.57372 .51691 L
.57006 .52162 L
.56996 .52174 L
.56614 .52658 L
.56523 .52771 L
.56223 .53141 L
.5604 .53363 L
.55821 .53624 L
.55557 .53933 L
.55406 .54107 L
.55073 .5448 L
.54973 .5459 L
.5459 .54998 L
.54518 .55073 L
.54107 .55484 L
.54033 .55557 L
Mistroke
.53624 .55934 L
.53504 .5604 L
.53141 .56342 L
.52909 .56523 L
.52658 .56704 L
.5219 .57006 L
.52174 .57015 L
.51691 .57271 L
.51208 .57466 L
.51154 .57489 L
.50725 .57599 L
.50242 .57665 L
.49758 .57665 L
.49275 .57599 L
.48846 .57489 L
.48792 .57466 L
.48309 .57271 L
.47826 .57015 L
.4781 .57006 L
.47342 .56704 L
.47091 .56523 L
.46859 .56342 L
.46496 .5604 L
.46376 .55934 L
.45968 .55557 L
.45893 .55484 L
.45482 .55073 L
.4541 .54998 L
.45027 .5459 L
.44927 .54479 L
.44595 .54107 L
.44443 .53933 L
.44179 .53624 L
.4396 .53362 L
.43777 .53141 L
.43477 .52771 L
.43386 .52658 L
.43004 .52174 L
.42994 .52162 L
.42629 .51691 L
.42511 .51537 L
.42259 .51208 L
.42027 .509 L
.41895 .50725 L
.41544 .50253 L
.41536 .50242 L
.4118 .49758 L
.41061 .49596 L
.40826 .49275 L
.40578 .48933 L
Mistroke
.40476 .48792 L
.40127 .48309 L
.40095 .48263 L
.3978 .47826 L
.39612 .47589 L
.39435 .47342 L
.39128 .46911 L
.39091 .46859 L
.38748 .46376 L
.38645 .46231 L
.38406 .45893 L
.38162 .45548 L
.38064 .4541 L
.37723 .44927 L
.37679 .44864 L
.37382 .44443 L
.37196 .44179 L
.37041 .4396 L
.36712 .43494 L
.367 .43477 L
.36359 .42994 L
.36229 .42912 L
.35746 .42822 L
.35263 .42725 L
.35163 .42511 L
.34843 .42027 L
.3478 .41932 L
.34521 .41544 L
.34296 .41207 L
.34199 .41061 L
.33875 .40578 L
.33813 .40486 L
.3355 .40095 L
.3333 .39769 L
.33223 .39612 L
.32896 .39128 L
.32847 .39056 L
.32567 .38645 L
.32364 .38347 L
.32237 .38162 L
.31905 .37679 L
.31881 .37643 L
.31572 .37196 L
.31397 .36942 L
.31238 .36712 L
.30914 .36245 L
.30903 .36229 L
.30566 .35746 L
.30431 .35552 L
.30228 .35263 L
Mistroke
.29948 .34863 L
.29889 .3478 L
.29549 .34296 L
.29465 .34177 L
.29206 .33813 L
.28981 .33496 L
.28863 .3333 L
.28519 .32847 L
.28498 .32817 L
.28173 .32364 L
.28015 .32143 L
.27826 .31881 L
.27532 .31472 L
.27478 .31397 L
.27128 .30914 L
.27049 .30804 L
.26777 .30431 L
.26566 .3014 L
.26425 .29948 L
.26082 .29479 L
.26071 .29465 L
.25716 .28981 L
.25599 .28822 L
.2536 .28498 L
.25116 .28168 L
.25002 .28015 L
.24644 .27532 L
.24633 .27517 L
.24283 .27049 L
.2415 .26869 L
.23922 .26566 L
.23666 .26224 L
.23559 .26082 L
.23196 .25599 L
.23183 .25583 L
.2283 .25116 L
.227 .24944 L
.22463 .24633 L
.22217 .24308 L
.22095 .2415 L
.21734 .23675 L
.21727 .23666 L
.21356 .23183 L
.2125 .23046 L
.20984 .227 L
.20767 .22419 L
.20611 .22217 L
.20284 .21794 L
.20237 .21734 L
.19861 .2125 L
Mistroke
.19801 .21173 L
.19484 .20767 L
.19318 .20554 L
.19106 .20284 L
.18835 .19938 L
.18727 .19801 L
.18351 .19324 L
.18347 .19318 L
.17964 .18835 L
.17868 .18713 L
.17581 .18351 L
.17385 .18105 L
.17196 .17868 L
.16902 .17498 L
.16811 .17385 L
.16424 .16902 L
.16419 .16895 L
.16036 .16419 L
.15935 .16294 L
.15646 .15935 L
.15452 .15695 L
.15255 .15452 L
.14969 .15099 L
.14863 .14969 L
.14486 .14505 L
.14471 .14486 L
.14076 .14003 L
.14003 .13913 L
.1368 .1352 L
.1352 .13324 L
.13282 .13036 L
.13036 .12737 L
.12884 .12553 L
.12553 .12152 L
.12485 .1207 L
.12085 .11587 L
.1207 .11569 L
.11683 .11104 L
.11587 .10988 L
.11279 .1062 L
.11104 .1041 L
.10875 .10137 L
.1062 .09833 L
.10469 .09654 L
.10137 .09259 L
.10063 .09171 L
.09655 .08688 L
.09654 .08686 L
.09246 .08204 L
.09171 .08116 L
Mistroke
.08835 .07721 L
.08688 .07548 L
.08423 .07238 L
.08204 .06981 L
.0801 .06755 L
.07721 .06417 L
.07596 .06272 L
.07238 .05854 L
.07181 .05789 L
.06765 .05305 L
.06755 .05293 L
.06347 .04822 L
.06272 .04735 L
.05928 .04339 L
.05789 .04178 L
.05508 .03856 L
.05305 .03623 L
.05086 .03373 L
.04822 .03069 L
.04664 .02889 L
.04339 .02518 L
.04241 .02406 L
.03856 .01967 L
.03816 .01923 L
Mfstroke
.028 .55 0 r
.95795 .01923 m
.95661 .02073 L
.95369 .02406 L
.95178 .02623 L
.94944 .02889 L
.94695 .03173 L
.9452 .03373 L
.94211 .03725 L
.94097 .03856 L
.93728 .04279 L
.93676 .04339 L
.93255 .04822 L
.93245 .04834 L
.92837 .05305 L
.92762 .05391 L
.92419 .05789 L
.92279 .05951 L
.92002 .06272 L
.91796 .06512 L
.91587 .06755 L
.91312 .07074 L
.91172 .07238 L
.90829 .07639 L
.90759 .07721 L
.90347 .08204 L
.90346 .08206 L
.89936 .08688 L
.89863 .08774 L
.89527 .09171 L
.8938 .09345 L
.89119 .09654 L
.88896 .09917 L
.88712 .10137 L
.88413 .10492 L
.88306 .1062 L
.8793 .11068 L
.87901 .11104 L
.87497 .11587 L
.87447 .11647 L
.87095 .1207 L
.86964 .12228 L
.86694 .12553 L
.8648 .12811 L
.86294 .13036 L
.85997 .13396 L
.85895 .1352 L
.85514 .13983 L
.85498 .14003 L
.85102 .14486 L
.85031 .14572 L
.84707 .14969 L
.84548 .15164 L
.84313 .15452 L
.84065 .15758 L
.83921 .15935 L
.83581 .16354 L
.83529 .16419 L
.83139 .16902 L
.83098 .16952 L
.8275 .17385 L
.82615 .17553 L
.82363 .17868 L
.82132 .18156 L
.81976 .18351 L
.81649 .18762 L
.81591 .18835 L
.81207 .19318 L
.81165 .1937 L
.80825 .19801 L
.80682 .19981 L
.80443 .20284 L
.80199 .20594 L
.80063 .20767 L
.79716 .21209 L
.79684 .2125 L
.79306 .21734 L
.79233 .21828 L
.7893 .22217 L
.7875 .22448 L
.78555 .227 L
.78266 .23072 L
.7818 .23183 L
.77808 .23666 L
.77783 .23698 L
.77436 .2415 L
.773 .24327 L
.77066 .24633 L
.76817 .24959 L
.76697 .25116 L
.76334 .25593 L
.76329 .25599 L
.75963 .26082 L
.7585 .26231 L
.75598 .26566 L
.75367 .26871 L
.75234 .27049 L
.74884 .27514 L
.74871 .27532 L
.7451 .28015 L
.74401 .28161 L
.7415 .28498 L
.73918 .2881 L
.73791 .28981 L
.73434 .29462 L
.73433 .29465 L
.73077 .29948 L
.72951 .30118 L
.72721 .30431 L
.72468 .30776 L
.72367 .30914 L
.72015 .31397 L
.71985 .31438 L
.71663 .31881 L
.71502 .32103 L
.71313 .32364 L
.71019 .32771 L
.70964 .32847 L
.70617 .3333 L
.70535 .33443 L
.7027 .33813 L
.70052 .34118 L
.69925 .34296 L
.69581 .3478 L
.69569 .34796 L
.69238 .35263 L
.69086 .35478 L
.68897 .35746 L
.68603 .36163 L
.68556 .36229 L
.68217 .36712 L
.68119 .36852 L
.67879 .37196 L
.67636 .37544 L
.67543 .37679 L
.67207 .38162 L
.67153 .3824 L
.66873 .38645 L
.6667 .38939 L
.6654 .39128 L
.66208 .39612 L
.66187 .39642 L
.65877 .40095 L
.65704 .40349 L
.65547 .40578 L
.6522 .41059 L
.65219 .41061 L
.64892 .41544 L
.64737 .41772 L
.64565 .42027 L
.64254 .425 L
.64243 .42511 L
.63771 .42801 L
.63422 .42511 L
.63288 .42442 L
.62971 .42511 L
.62804 .42841 L
.62691 .42994 L
.62332 .43477 L
.62321 .43492 L
.61973 .4396 L
.61838 .4414 L
.61612 .44443 L
.61355 .44786 L
.61249 .44927 L
.60885 .4541 L
.60872 .45428 L
.60519 .45893 L
.60388 .46065 L
.60151 .46376 L
.59905 .46697 L
.5978 .46859 L
.59422 .47321 L
.59406 .47342 L
.59028 .47826 L
.58939 .47938 L
.58645 .48309 L
.58456 .48546 L
.58258 .48792 L
.57973 .49143 L
.57864 .49275 L
.57489 .49727 L
.57463 .49758 L
.57053 .50242 L
.57006 .50296 L
.56633 .50725 L
.56523 .50848 L
.562 .51208 L
.5604 .51382 L
.5575 .51691 L
.55557 .51893 L
.55281 .52174 L
.55073 .52379 L
.54784 .52658 L
.5459 .52838 L
.54252 .53141 L
.54107 .53265 L
.53666 .53624 L
.53624 .53657 L
.53141 .5401 L
.52998 .54107 L
.52658 .54321 L
.52174 .54587 L
.52168 .5459 L
.51691 .54804 L
.51208 .5497 L
.50777 .55073 L
.50725 .55081 L
.50242 .55138 L
.49758 .55138 L
.49275 .55081 L
.49223 .55073 L
.48792 .5497 L
.48309 .54804 L
.47832 .5459 L
.47826 .54587 L
.47342 .54321 L
.47002 .54107 L
.46859 .5401 L
.46376 .53656 L
.46334 .53624 L
.45893 .53264 L
.45749 .53141 L
.4541 .52838 L
.45216 .52658 L
.44927 .52379 L
.4472 .52174 L
.44443 .51893 L
.4425 .51691 L
.4396 .51382 L
.43801 .51208 L
.43477 .50848 L
.43367 .50725 L
.42994 .50296 L
.42947 .50242 L
.42537 .49758 L
.42511 .49726 L
.42136 .49275 L
.42027 .49142 L
.41742 .48792 L
.41544 .48546 L
.41355 .48309 L
.41061 .47938 L
.40972 .47826 L
.40594 .47342 L
.40578 .47321 L
.4022 .46859 L
.40095 .46696 L
.39849 .46376 L
.39612 .46065 L
.39481 .45893 L
.39128 .45428 L
.39115 .4541 L
.38751 .44927 L
.38645 .44786 L
.38388 .44443 L
.38162 .4414 L
.38028 .4396 L
.37679 .43491 L
.37668 .43477 L
.37309 .42994 L
.37196 .4284 L
.37029 .42511 L
.36712 .42442 L
.36578 .42511 L
.36229 .42801 L
.35757 .42511 L
.35746 .425 L
.35435 .42027 L
.35263 .41772 L
.35109 .41544 L
.34782 .41061 L
.3478 .41058 L
.34453 .40578 L
.34296 .40348 L
.34123 .40095 L
.33813 .39642 L
.33793 .39612 L
.3346 .39128 L
.3333 .38939 L
.33127 .38645 L
.32847 .3824 L
.32793 .38162 L
.32458 .37679 L
.32364 .37544 L
.32121 .37196 L
.31881 .36852 L
.31783 .36712 L
.31444 .36229 L
.31397 .36163 L
.31103 .35746 L
.30914 .35478 L
.30762 .35263 L
.30431 .34796 L
.30419 .3478 L
.30075 .34296 L
.29948 .34118 L
.2973 .33813 L
.29465 .33443 L
.29384 .3333 L
.29036 .32847 L
.28981 .32771 L
.28687 .32364 L
.28498 .32103 L
.28337 .31881 L
.28015 .31438 L
.27986 .31397 L
.27633 .30914 L
.27532 .30776 L
.27279 .30431 L
.27049 .30118 L
.26924 .29948 L
.26567 .29465 L
.26566 .29462 L
.2621 .28981 L
.26082 .2881 L
.2585 .28498 L
.25599 .28161 L
.2549 .28015 L
.25129 .27532 L
.25116 .27514 L
.24766 .27049 L
.24633 .26871 L
.24402 .26566 L
.2415 .26231 L
.24037 .26082 L
.23671 .25599 L
.23666 .25593 L
.23303 .25116 L
.23183 .24959 L
.22934 .24633 L
.227 .24327 L
.22564 .2415 L
.22217 .23698 L
.22193 .23666 L
.2182 .23183 L
.21734 .23072 L
.21446 .227 L
.2125 .22448 L
.2107 .22217 L
.20767 .21827 L
.20694 .21734 L
.20316 .2125 L
.20284 .21209 L
.19937 .20767 L
.19801 .20594 L
.19557 .20284 L
.19318 .1998 L
.19176 .19801 L
.18835 .1937 L
.18793 .19318 L
.18409 .18835 L
.18351 .18762 L
.18024 .18351 L
.17868 .18156 L
.17637 .17868 L
.17385 .17553 L
.1725 .17385 L
.16902 .16952 L
.16861 .16902 L
.16471 .16419 L
.16419 .16354 L
.1608 .15935 L
.15935 .15758 L
.15687 .15452 L
.15452 .15164 L
.15293 .14969 L
.14969 .14572 L
.14898 .14486 L
.14502 .14003 L
.14486 .13983 L
.14105 .1352 L
.14003 .13396 L
.13706 .13036 L
.1352 .12811 L
.13306 .12553 L
.13036 .12228 L
.12905 .1207 L
.12553 .11647 L
.12503 .11587 L
.12099 .11104 L
.1207 .11068 L
.11695 .1062 L
.11587 .10492 L
.11288 .10137 L
.11104 .09917 L
.10881 .09654 L
.1062 .09345 L
.10473 .09171 L
.10137 .08774 L
.10064 .08688 L
.09654 .08205 L
.09653 .08204 L
.09241 .07721 L
.09171 .07639 L
.08828 .07238 L
.08688 .07074 L
.08413 .06755 L
.08204 .06512 L
.07998 .06272 L
.07721 .05951 L
.07581 .05789 L
.07238 .05391 L
.07164 .05305 L
.06755 .04834 L
.06745 .04822 L
.06324 .04339 L
.06272 .04279 L
.05903 .03856 L
.05789 .03725 L
.0548 .03373 L
.05305 .03173 L
.05056 .02889 L
.04822 .02623 L
.04631 .02406 L
.04339 .02073 L
.04205 .01923 L
F
0 g
.95795 .01923 m
.95661 .02073 L
.95369 .02406 L
.95178 .02623 L
.94944 .02889 L
.94695 .03173 L
.9452 .03373 L
.94211 .03725 L
.94097 .03856 L
.93728 .04279 L
.93676 .04339 L
.93255 .04822 L
.93245 .04834 L
.92837 .05305 L
.92762 .05391 L
.92419 .05789 L
.92279 .05951 L
.92002 .06272 L
.91796 .06512 L
.91587 .06755 L
.91312 .07074 L
.91172 .07238 L
.90829 .07639 L
.90759 .07721 L
.90347 .08204 L
.90346 .08206 L
.89936 .08688 L
.89863 .08774 L
.89527 .09171 L
.8938 .09345 L
.89119 .09654 L
.88896 .09917 L
.88712 .10137 L
.88413 .10492 L
.88306 .1062 L
.8793 .11068 L
.87901 .11104 L
.87497 .11587 L
.87447 .11647 L
.87095 .1207 L
.86964 .12228 L
.86694 .12553 L
.8648 .12811 L
.86294 .13036 L
.85997 .13396 L
.85895 .1352 L
.85514 .13983 L
.85498 .14003 L
.85102 .14486 L
.85031 .14572 L
Mistroke
.84707 .14969 L
.84548 .15164 L
.84313 .15452 L
.84065 .15758 L
.83921 .15935 L
.83581 .16354 L
.83529 .16419 L
.83139 .16902 L
.83098 .16952 L
.8275 .17385 L
.82615 .17553 L
.82363 .17868 L
.82132 .18156 L
.81976 .18351 L
.81649 .18762 L
.81591 .18835 L
.81207 .19318 L
.81165 .1937 L
.80825 .19801 L
.80682 .19981 L
.80443 .20284 L
.80199 .20594 L
.80063 .20767 L
.79716 .21209 L
.79684 .2125 L
.79306 .21734 L
.79233 .21828 L
.7893 .22217 L
.7875 .22448 L
.78555 .227 L
.78266 .23072 L
.7818 .23183 L
.77808 .23666 L
.77783 .23698 L
.77436 .2415 L
.773 .24327 L
.77066 .24633 L
.76817 .24959 L
.76697 .25116 L
.76334 .25593 L
.76329 .25599 L
.75963 .26082 L
.7585 .26231 L
.75598 .26566 L
.75367 .26871 L
.75234 .27049 L
.74884 .27514 L
.74871 .27532 L
.7451 .28015 L
.74401 .28161 L
Mistroke
.7415 .28498 L
.73918 .2881 L
.73791 .28981 L
.73434 .29462 L
.73433 .29465 L
.73077 .29948 L
.72951 .30118 L
.72721 .30431 L
.72468 .30776 L
.72367 .30914 L
.72015 .31397 L
.71985 .31438 L
.71663 .31881 L
.71502 .32103 L
.71313 .32364 L
.71019 .32771 L
.70964 .32847 L
.70617 .3333 L
.70535 .33443 L
.7027 .33813 L
.70052 .34118 L
.69925 .34296 L
.69581 .3478 L
.69569 .34796 L
.69238 .35263 L
.69086 .35478 L
.68897 .35746 L
.68603 .36163 L
.68556 .36229 L
.68217 .36712 L
.68119 .36852 L
.67879 .37196 L
.67636 .37544 L
.67543 .37679 L
.67207 .38162 L
.67153 .3824 L
.66873 .38645 L
.6667 .38939 L
.6654 .39128 L
.66208 .39612 L
.66187 .39642 L
.65877 .40095 L
.65704 .40349 L
.65547 .40578 L
.6522 .41059 L
.65219 .41061 L
.64892 .41544 L
.64737 .41772 L
.64565 .42027 L
.64254 .425 L
Mistroke
.64243 .42511 L
.63771 .42801 L
.63422 .42511 L
.63288 .42442 L
.62971 .42511 L
.62804 .42841 L
.62691 .42994 L
.62332 .43477 L
.62321 .43492 L
.61973 .4396 L
.61838 .4414 L
.61612 .44443 L
.61355 .44786 L
.61249 .44927 L
.60885 .4541 L
.60872 .45428 L
.60519 .45893 L
.60388 .46065 L
.60151 .46376 L
.59905 .46697 L
.5978 .46859 L
.59422 .47321 L
.59406 .47342 L
.59028 .47826 L
.58939 .47938 L
.58645 .48309 L
.58456 .48546 L
.58258 .48792 L
.57973 .49143 L
.57864 .49275 L
.57489 .49727 L
.57463 .49758 L
.57053 .50242 L
.57006 .50296 L
.56633 .50725 L
.56523 .50848 L
.562 .51208 L
.5604 .51382 L
.5575 .51691 L
.55557 .51893 L
.55281 .52174 L
.55073 .52379 L
.54784 .52658 L
.5459 .52838 L
.54252 .53141 L
.54107 .53265 L
.53666 .53624 L
.53624 .53657 L
.53141 .5401 L
.52998 .54107 L
Mistroke
.52658 .54321 L
.52174 .54587 L
.52168 .5459 L
.51691 .54804 L
.51208 .5497 L
.50777 .55073 L
.50725 .55081 L
.50242 .55138 L
.49758 .55138 L
.49275 .55081 L
.49223 .55073 L
.48792 .5497 L
.48309 .54804 L
.47832 .5459 L
.47826 .54587 L
.47342 .54321 L
.47002 .54107 L
.46859 .5401 L
.46376 .53656 L
.46334 .53624 L
.45893 .53264 L
.45749 .53141 L
.4541 .52838 L
.45216 .52658 L
.44927 .52379 L
.4472 .52174 L
.44443 .51893 L
.4425 .51691 L
.4396 .51382 L
.43801 .51208 L
.43477 .50848 L
.43367 .50725 L
.42994 .50296 L
.42947 .50242 L
.42537 .49758 L
.42511 .49726 L
.42136 .49275 L
.42027 .49142 L
.41742 .48792 L
.41544 .48546 L
.41355 .48309 L
.41061 .47938 L
.40972 .47826 L
.40594 .47342 L
.40578 .47321 L
.4022 .46859 L
.40095 .46696 L
.39849 .46376 L
.39612 .46065 L
.39481 .45893 L
Mistroke
.39128 .45428 L
.39115 .4541 L
.38751 .44927 L
.38645 .44786 L
.38388 .44443 L
.38162 .4414 L
.38028 .4396 L
.37679 .43491 L
.37668 .43477 L
.37309 .42994 L
.37196 .4284 L
.37029 .42511 L
.36712 .42442 L
.36578 .42511 L
.36229 .42801 L
.35757 .42511 L
.35746 .425 L
.35435 .42027 L
.35263 .41772 L
.35109 .41544 L
.34782 .41061 L
.3478 .41058 L
.34453 .40578 L
.34296 .40348 L
.34123 .40095 L
.33813 .39642 L
.33793 .39612 L
.3346 .39128 L
.3333 .38939 L
.33127 .38645 L
.32847 .3824 L
.32793 .38162 L
.32458 .37679 L
.32364 .37544 L
.32121 .37196 L
.31881 .36852 L
.31783 .36712 L
.31444 .36229 L
.31397 .36163 L
.31103 .35746 L
.30914 .35478 L
.30762 .35263 L
.30431 .34796 L
.30419 .3478 L
.30075 .34296 L
.29948 .34118 L
.2973 .33813 L
.29465 .33443 L
.29384 .3333 L
.29036 .32847 L
Mistroke
.28981 .32771 L
.28687 .32364 L
.28498 .32103 L
.28337 .31881 L
.28015 .31438 L
.27986 .31397 L
.27633 .30914 L
.27532 .30776 L
.27279 .30431 L
.27049 .30118 L
.26924 .29948 L
.26567 .29465 L
.26566 .29462 L
.2621 .28981 L
.26082 .2881 L
.2585 .28498 L
.25599 .28161 L
.2549 .28015 L
.25129 .27532 L
.25116 .27514 L
.24766 .27049 L
.24633 .26871 L
.24402 .26566 L
.2415 .26231 L
.24037 .26082 L
.23671 .25599 L
.23666 .25593 L
.23303 .25116 L
.23183 .24959 L
.22934 .24633 L
.227 .24327 L
.22564 .2415 L
.22217 .23698 L
.22193 .23666 L
.2182 .23183 L
.21734 .23072 L
.21446 .227 L
.2125 .22448 L
.2107 .22217 L
.20767 .21827 L
.20694 .21734 L
.20316 .2125 L
.20284 .21209 L
.19937 .20767 L
.19801 .20594 L
.19557 .20284 L
.19318 .1998 L
.19176 .19801 L
.18835 .1937 L
.18793 .19318 L
Mistroke
.18409 .18835 L
.18351 .18762 L
.18024 .18351 L
.17868 .18156 L
.17637 .17868 L
.17385 .17553 L
.1725 .17385 L
.16902 .16952 L
.16861 .16902 L
.16471 .16419 L
.16419 .16354 L
.1608 .15935 L
.15935 .15758 L
.15687 .15452 L
.15452 .15164 L
.15293 .14969 L
.14969 .14572 L
.14898 .14486 L
.14502 .14003 L
.14486 .13983 L
.14105 .1352 L
.14003 .13396 L
.13706 .13036 L
.1352 .12811 L
.13306 .12553 L
.13036 .12228 L
.12905 .1207 L
.12553 .11647 L
.12503 .11587 L
.12099 .11104 L
.1207 .11068 L
.11695 .1062 L
.11587 .10492 L
.11288 .10137 L
.11104 .09917 L
.10881 .09654 L
.1062 .09345 L
.10473 .09171 L
.10137 .08774 L
.10064 .08688 L
.09654 .08205 L
.09653 .08204 L
.09241 .07721 L
.09171 .07639 L
.08828 .07238 L
.08688 .07074 L
.08413 .06755 L
.08204 .06512 L
.07998 .06272 L
.07721 .05951 L
Mistroke
.07581 .05789 L
.07238 .05391 L
.07164 .05305 L
.06755 .04834 L
.06745 .04822 L
.06324 .04339 L
.06272 .04279 L
.05903 .03856 L
.05789 .03725 L
.0548 .03373 L
.05305 .03173 L
.05056 .02889 L
.04822 .02623 L
.04631 .02406 L
.04339 .02073 L
.04205 .01923 L
Mfstroke
0 .505 .073 r
.9528 .01923 m
.95178 .02038 L
.94853 .02406 L
.94695 .02585 L
.94426 .02889 L
.94211 .03133 L
.94 .03373 L
.93728 .03682 L
.93576 .03856 L
.93245 .04233 L
.93153 .04339 L
.92762 .04786 L
.9273 .04822 L
.92309 .05305 L
.92279 .05341 L
.9189 .05789 L
.91796 .05897 L
.91471 .06272 L
.91312 .06455 L
.91054 .06755 L
.90829 .07015 L
.90638 .07238 L
.90346 .07577 L
.90222 .07721 L
.89863 .08141 L
.89808 .08204 L
.89395 .08688 L
.8938 .08706 L
.88984 .09171 L
.88896 .09274 L
.88574 .09654 L
.88413 .09843 L
.88164 .10137 L
.8793 .10414 L
.87756 .1062 L
.87447 .10988 L
.87349 .11104 L
.86964 .11563 L
.86944 .11587 L
.86539 .1207 L
.8648 .1214 L
.86136 .12553 L
.85997 .12719 L
.85734 .13036 L
.85514 .13301 L
.85333 .1352 L
.85031 .13884 L
.84933 .14003 L
.84548 .14469 L
.84534 .14486 L
.84137 .14969 L
.84065 .15057 L
.83741 .15452 L
.83581 .15647 L
.83346 .15935 L
.83098 .16239 L
.82952 .16419 L
.82615 .16833 L
.82559 .16902 L
.82168 .17385 L
.82132 .1743 L
.81778 .17868 L
.81649 .18028 L
.81389 .18351 L
.81165 .18629 L
.81001 .18835 L
.80682 .19232 L
.80614 .19318 L
.80229 .19801 L
.80199 .19838 L
.79845 .20284 L
.79716 .20446 L
.79462 .20767 L
.79233 .21057 L
.7908 .2125 L
.7875 .21669 L
.78699 .21734 L
.7832 .22217 L
.78266 .22285 L
.77942 .227 L
.77783 .22903 L
.77565 .23183 L
.773 .23523 L
.77189 .23666 L
.76817 .24146 L
.76814 .2415 L
.76441 .24633 L
.76334 .24771 L
.76068 .25116 L
.7585 .25399 L
.75697 .25599 L
.75367 .2603 L
.75327 .26082 L
.74959 .26566 L
.74884 .26663 L
.74591 .27049 L
.74401 .273 L
.74225 .27532 L
.73918 .27938 L
.7386 .28015 L
.73496 .28498 L
.73434 .2858 L
.73133 .28981 L
.72951 .29224 L
.72772 .29465 L
.72468 .29872 L
.72411 .29948 L
.72052 .30431 L
.71985 .30522 L
.71694 .30914 L
.71502 .31175 L
.71337 .31397 L
.71019 .3183 L
.70982 .31881 L
.70627 .32364 L
.70535 .32489 L
.70274 .32847 L
.70052 .33151 L
.69922 .3333 L
.6957 .33813 L
.69569 .33815 L
.69221 .34296 L
.69086 .34483 L
.68872 .3478 L
.68603 .35153 L
.68524 .35263 L
.68177 .35746 L
.68119 .35827 L
.67832 .36229 L
.67636 .36503 L
.67487 .36712 L
.67153 .37182 L
.67144 .37196 L
.66802 .37679 L
.6667 .37865 L
.6646 .38162 L
.66187 .3855 L
.6612 .38645 L
.65781 .39128 L
.65704 .39238 L
.65442 .39612 L
.6522 .39929 L
.65105 .40095 L
.64769 .40578 L
.64737 .40623 L
.64433 .41061 L
.64254 .4132 L
.64099 .41544 L
.63771 .42019 L
.63767 .42027 L
.63288 .42168 L
.63049 .42027 L
.62804 .41875 L
.62321 .41605 L
.62063 .42027 L
.61838 .42308 L
.61676 .42511 L
.61355 .42909 L
.61287 .42994 L
.60894 .43477 L
.60872 .43505 L
.60498 .4396 L
.60388 .44093 L
.60099 .44443 L
.59905 .44675 L
.59694 .44927 L
.59422 .45247 L
.59284 .4541 L
.58939 .4581 L
.58867 .45893 L
.58456 .46362 L
.58443 .46376 L
.5801 .46859 L
.57973 .46901 L
.57567 .47342 L
.57489 .47425 L
.57111 .47826 L
.57006 .47934 L
.56639 .48309 L
.56523 .48425 L
.56148 .48792 L
.5604 .48895 L
.55632 .49275 L
.55557 .49343 L
.55084 .49758 L
.55073 .49767 L
.5459 .50164 L
.54491 .50242 L
.54107 .50531 L
.53833 .50725 L
.53624 .50865 L
.53141 .51165 L
.53067 .51208 L
.52658 .51428 L
.52174 .51651 L
.52078 .51691 L
.51691 .51832 L
.51208 .51969 L
.50725 .52062 L
.50242 .52108 L
.49758 .52108 L
.49275 .52062 L
.48792 .51969 L
.48309 .51832 L
.47923 .51691 L
.47826 .51651 L
.47342 .51428 L
.46933 .51208 L
.46859 .51165 L
.46376 .50865 L
.46167 .50725 L
.45893 .5053 L
.45509 .50242 L
.4541 .50164 L
.44927 .49767 L
.44917 .49758 L
.44443 .49343 L
.44368 .49275 L
.4396 .48895 L
.43852 .48792 L
.43477 .48424 L
.43361 .48309 L
.42994 .47934 L
.4289 .47826 L
.42511 .47425 L
.42433 .47342 L
.42027 .469 L
.4199 .46859 L
.41557 .46376 L
.41544 .46362 L
.41133 .45893 L
.41061 .4581 L
.40716 .4541 L
.40578 .45247 L
.40306 .44927 L
.40095 .44675 L
.39902 .44443 L
.39612 .44093 L
.39502 .4396 L
.39128 .43504 L
.39106 .43477 L
.38713 .42994 L
.38645 .42909 L
.38324 .42511 L
.38162 .42308 L
.37937 .42027 L
.37679 .41605 L
.37196 .41875 L
.36951 .42027 L
.36712 .42168 L
.36233 .42027 L
.36229 .42019 L
.35901 .41544 L
.35746 .4132 L
.35567 .41061 L
.35263 .40623 L
.35232 .40578 L
.34895 .40095 L
.3478 .39929 L
.34558 .39612 L
.34296 .39238 L
.3422 .39128 L
.3388 .38645 L
.33813 .3855 L
.3354 .38162 L
.3333 .37864 L
.33199 .37679 L
.32856 .37196 L
.32847 .37182 L
.32513 .36712 L
.32364 .36503 L
.32168 .36229 L
.31881 .35826 L
.31823 .35746 L
.31476 .35263 L
.31397 .35153 L
.31129 .3478 L
.30914 .34482 L
.3078 .34296 L
.30431 .33815 L
.3043 .33813 L
.30079 .3333 L
.29948 .3315 L
.29726 .32847 L
.29465 .32489 L
.29373 .32364 L
.29019 .31881 L
.28981 .3183 L
.28663 .31397 L
.28498 .31174 L
.28306 .30914 L
.28015 .30521 L
.27948 .30431 L
.27589 .29948 L
.27532 .29871 L
.27228 .29465 L
.27049 .29224 L
.26867 .28981 L
.26566 .2858 L
.26504 .28498 L
.2614 .28015 L
.26082 .27938 L
.25775 .27532 L
.25599 .27299 L
.25409 .27049 L
.25116 .26663 L
.25041 .26566 L
.24673 .26082 L
.24633 .2603 L
.24303 .25599 L
.2415 .25399 L
.23932 .25116 L
.23666 .24771 L
.2356 .24633 L
.23186 .2415 L
.23183 .24146 L
.22812 .23666 L
.227 .23523 L
.22436 .23183 L
.22217 .22902 L
.22059 .227 L
.21734 .22285 L
.21681 .22217 L
.21301 .21734 L
.2125 .21669 L
.2092 .2125 L
.20767 .21056 L
.20538 .20767 L
.20284 .20446 L
.20156 .20284 L
.19801 .19838 L
.19771 .19801 L
.19386 .19318 L
.19318 .19232 L
.18999 .18835 L
.18835 .18629 L
.18611 .18351 L
.18351 .18028 L
.18222 .17868 L
.17868 .17429 L
.17832 .17385 L
.17441 .16902 L
.17385 .16833 L
.17048 .16419 L
.16902 .16239 L
.16654 .15935 L
.16419 .15647 L
.16259 .15452 L
.15935 .15057 L
.15863 .14969 L
.15466 .14486 L
.15452 .14469 L
.15067 .14003 L
.14969 .13884 L
.14667 .1352 L
.14486 .13301 L
.14266 .13036 L
.14003 .12719 L
.13864 .12553 L
.1352 .1214 L
.13461 .1207 L
.13057 .11587 L
.13036 .11563 L
.12651 .11104 L
.12553 .10987 L
.12244 .1062 L
.1207 .10414 L
.11836 .10137 L
.11587 .09843 L
.11426 .09654 L
.11104 .09274 L
.11016 .09171 L
.1062 .08706 L
.10605 .08688 L
.10192 .08204 L
.10137 .08141 L
.09778 .07721 L
.09654 .07577 L
.09363 .07238 L
.09171 .07015 L
.08946 .06755 L
.08688 .06455 L
.08529 .06272 L
.08204 .05897 L
.0811 .05789 L
.07721 .0534 L
.07691 .05305 L
.0727 .04822 L
.07238 .04786 L
.06848 .04339 L
.06755 .04233 L
.06424 .03856 L
.06272 .03682 L
.06 .03373 L
.05789 .03132 L
.05574 .02889 L
.05305 .02585 L
.05148 .02406 L
.04822 .02038 L
.0472 .01923 L
F
0 g
.9528 .01923 m
.95178 .02038 L
.94853 .02406 L
.94695 .02585 L
.94426 .02889 L
.94211 .03133 L
.94 .03373 L
.93728 .03682 L
.93576 .03856 L
.93245 .04233 L
.93153 .04339 L
.92762 .04786 L
.9273 .04822 L
.92309 .05305 L
.92279 .05341 L
.9189 .05789 L
.91796 .05897 L
.91471 .06272 L
.91312 .06455 L
.91054 .06755 L
.90829 .07015 L
.90638 .07238 L
.90346 .07577 L
.90222 .07721 L
.89863 .08141 L
.89808 .08204 L
.89395 .08688 L
.8938 .08706 L
.88984 .09171 L
.88896 .09274 L
.88574 .09654 L
.88413 .09843 L
.88164 .10137 L
.8793 .10414 L
.87756 .1062 L
.87447 .10988 L
.87349 .11104 L
.86964 .11563 L
.86944 .11587 L
.86539 .1207 L
.8648 .1214 L
.86136 .12553 L
.85997 .12719 L
.85734 .13036 L
.85514 .13301 L
.85333 .1352 L
.85031 .13884 L
.84933 .14003 L
.84548 .14469 L
.84534 .14486 L
Mistroke
.84137 .14969 L
.84065 .15057 L
.83741 .15452 L
.83581 .15647 L
.83346 .15935 L
.83098 .16239 L
.82952 .16419 L
.82615 .16833 L
.82559 .16902 L
.82168 .17385 L
.82132 .1743 L
.81778 .17868 L
.81649 .18028 L
.81389 .18351 L
.81165 .18629 L
.81001 .18835 L
.80682 .19232 L
.80614 .19318 L
.80229 .19801 L
.80199 .19838 L
.79845 .20284 L
.79716 .20446 L
.79462 .20767 L
.79233 .21057 L
.7908 .2125 L
.7875 .21669 L
.78699 .21734 L
.7832 .22217 L
.78266 .22285 L
.77942 .227 L
.77783 .22903 L
.77565 .23183 L
.773 .23523 L
.77189 .23666 L
.76817 .24146 L
.76814 .2415 L
.76441 .24633 L
.76334 .24771 L
.76068 .25116 L
.7585 .25399 L
.75697 .25599 L
.75367 .2603 L
.75327 .26082 L
.74959 .26566 L
.74884 .26663 L
.74591 .27049 L
.74401 .273 L
.74225 .27532 L
.73918 .27938 L
.7386 .28015 L
Mistroke
.73496 .28498 L
.73434 .2858 L
.73133 .28981 L
.72951 .29224 L
.72772 .29465 L
.72468 .29872 L
.72411 .29948 L
.72052 .30431 L
.71985 .30522 L
.71694 .30914 L
.71502 .31175 L
.71337 .31397 L
.71019 .3183 L
.70982 .31881 L
.70627 .32364 L
.70535 .32489 L
.70274 .32847 L
.70052 .33151 L
.69922 .3333 L
.6957 .33813 L
.69569 .33815 L
.69221 .34296 L
.69086 .34483 L
.68872 .3478 L
.68603 .35153 L
.68524 .35263 L
.68177 .35746 L
.68119 .35827 L
.67832 .36229 L
.67636 .36503 L
.67487 .36712 L
.67153 .37182 L
.67144 .37196 L
.66802 .37679 L
.6667 .37865 L
.6646 .38162 L
.66187 .3855 L
.6612 .38645 L
.65781 .39128 L
.65704 .39238 L
.65442 .39612 L
.6522 .39929 L
.65105 .40095 L
.64769 .40578 L
.64737 .40623 L
.64433 .41061 L
.64254 .4132 L
.64099 .41544 L
.63771 .42019 L
.63767 .42027 L
Mistroke
.63288 .42168 L
.63049 .42027 L
.62804 .41875 L
.62321 .41605 L
.62063 .42027 L
.61838 .42308 L
.61676 .42511 L
.61355 .42909 L
.61287 .42994 L
.60894 .43477 L
.60872 .43505 L
.60498 .4396 L
.60388 .44093 L
.60099 .44443 L
.59905 .44675 L
.59694 .44927 L
.59422 .45247 L
.59284 .4541 L
.58939 .4581 L
.58867 .45893 L
.58456 .46362 L
.58443 .46376 L
.5801 .46859 L
.57973 .46901 L
.57567 .47342 L
.57489 .47425 L
.57111 .47826 L
.57006 .47934 L
.56639 .48309 L
.56523 .48425 L
.56148 .48792 L
.5604 .48895 L
.55632 .49275 L
.55557 .49343 L
.55084 .49758 L
.55073 .49767 L
.5459 .50164 L
.54491 .50242 L
.54107 .50531 L
.53833 .50725 L
.53624 .50865 L
.53141 .51165 L
.53067 .51208 L
.52658 .51428 L
.52174 .51651 L
.52078 .51691 L
.51691 .51832 L
.51208 .51969 L
.50725 .52062 L
.50242 .52108 L
Mistroke
.49758 .52108 L
.49275 .52062 L
.48792 .51969 L
.48309 .51832 L
.47923 .51691 L
.47826 .51651 L
.47342 .51428 L
.46933 .51208 L
.46859 .51165 L
.46376 .50865 L
.46167 .50725 L
.45893 .5053 L
.45509 .50242 L
.4541 .50164 L
.44927 .49767 L
.44917 .49758 L
.44443 .49343 L
.44368 .49275 L
.4396 .48895 L
.43852 .48792 L
.43477 .48424 L
.43361 .48309 L
.42994 .47934 L
.4289 .47826 L
.42511 .47425 L
.42433 .47342 L
.42027 .469 L
.4199 .46859 L
.41557 .46376 L
.41544 .46362 L
.41133 .45893 L
.41061 .4581 L
.40716 .4541 L
.40578 .45247 L
.40306 .44927 L
.40095 .44675 L
.39902 .44443 L
.39612 .44093 L
.39502 .4396 L
.39128 .43504 L
.39106 .43477 L
.38713 .42994 L
.38645 .42909 L
.38324 .42511 L
.38162 .42308 L
.37937 .42027 L
.37679 .41605 L
.37196 .41875 L
.36951 .42027 L
.36712 .42168 L
Mistroke
.36233 .42027 L
.36229 .42019 L
.35901 .41544 L
.35746 .4132 L
.35567 .41061 L
.35263 .40623 L
.35232 .40578 L
.34895 .40095 L
.3478 .39929 L
.34558 .39612 L
.34296 .39238 L
.3422 .39128 L
.3388 .38645 L
.33813 .3855 L
.3354 .38162 L
.3333 .37864 L
.33199 .37679 L
.32856 .37196 L
.32847 .37182 L
.32513 .36712 L
.32364 .36503 L
.32168 .36229 L
.31881 .35826 L
.31823 .35746 L
.31476 .35263 L
.31397 .35153 L
.31129 .3478 L
.30914 .34482 L
.3078 .34296 L
.30431 .33815 L
.3043 .33813 L
.30079 .3333 L
.29948 .3315 L
.29726 .32847 L
.29465 .32489 L
.29373 .32364 L
.29019 .31881 L
.28981 .3183 L
.28663 .31397 L
.28498 .31174 L
.28306 .30914 L
.28015 .30521 L
.27948 .30431 L
.27589 .29948 L
.27532 .29871 L
.27228 .29465 L
.27049 .29224 L
.26867 .28981 L
.26566 .2858 L
.26504 .28498 L
Mistroke
.2614 .28015 L
.26082 .27938 L
.25775 .27532 L
.25599 .27299 L
.25409 .27049 L
.25116 .26663 L
.25041 .26566 L
.24673 .26082 L
.24633 .2603 L
.24303 .25599 L
.2415 .25399 L
.23932 .25116 L
.23666 .24771 L
.2356 .24633 L
.23186 .2415 L
.23183 .24146 L
.22812 .23666 L
.227 .23523 L
.22436 .23183 L
.22217 .22902 L
.22059 .227 L
.21734 .22285 L
.21681 .22217 L
.21301 .21734 L
.2125 .21669 L
.2092 .2125 L
.20767 .21056 L
.20538 .20767 L
.20284 .20446 L
.20156 .20284 L
.19801 .19838 L
.19771 .19801 L
.19386 .19318 L
.19318 .19232 L
.18999 .18835 L
.18835 .18629 L
.18611 .18351 L
.18351 .18028 L
.18222 .17868 L
.17868 .17429 L
.17832 .17385 L
.17441 .16902 L
.17385 .16833 L
.17048 .16419 L
.16902 .16239 L
.16654 .15935 L
.16419 .15647 L
.16259 .15452 L
.15935 .15057 L
.15863 .14969 L
Mistroke
.15466 .14486 L
.15452 .14469 L
.15067 .14003 L
.14969 .13884 L
.14667 .1352 L
.14486 .13301 L
.14266 .13036 L
.14003 .12719 L
.13864 .12553 L
.1352 .1214 L
.13461 .1207 L
.13057 .11587 L
.13036 .11563 L
.12651 .11104 L
.12553 .10987 L
.12244 .1062 L
.1207 .10414 L
.11836 .10137 L
.11587 .09843 L
.11426 .09654 L
.11104 .09274 L
.11016 .09171 L
.1062 .08706 L
.10605 .08688 L
.10192 .08204 L
.10137 .08141 L
.09778 .07721 L
.09654 .07577 L
.09363 .07238 L
.09171 .07015 L
.08946 .06755 L
.08688 .06455 L
.08529 .06272 L
.08204 .05897 L
.0811 .05789 L
.07721 .0534 L
.07691 .05305 L
.0727 .04822 L
.07238 .04786 L
.06848 .04339 L
.06755 .04233 L
.06424 .03856 L
.06272 .03682 L
.06 .03373 L
.05789 .03132 L
.05574 .02889 L
.05305 .02585 L
.05148 .02406 L
.04822 .02038 L
.0472 .01923 L
Mistroke
Mfstroke
0 .46 .156 r
.9458 .01923 m
.94211 .02337 L
.9415 .02406 L
.93728 .0288 L
.9372 .02889 L
.93292 .03373 L
.93245 .03426 L
.92865 .03856 L
.92762 .03973 L
.9244 .04339 L
.92279 .04522 L
.92015 .04822 L
.91796 .05072 L
.91591 .05305 L
.91312 .05624 L
.91169 .05789 L
.90829 .06178 L
.90747 .06272 L
.90346 .06733 L
.90327 .06755 L
.89908 .07238 L
.89863 .07291 L
.8949 .07721 L
.8938 .0785 L
.89074 .08204 L
.88896 .0841 L
.88658 .08688 L
.88413 .08973 L
.88243 .09171 L
.8793 .09537 L
.8783 .09654 L
.87447 .10103 L
.87418 .10137 L
.87007 .1062 L
.86964 .10671 L
.86597 .11104 L
.8648 .11241 L
.86188 .11587 L
.85997 .11813 L
.8578 .1207 L
.85514 .12386 L
.85374 .12553 L
.85031 .12962 L
.84968 .13036 L
.84564 .1352 L
.84548 .13539 L
.84161 .14003 L
.84065 .14119 L
.83759 .14486 L
.83581 .147 L
.83359 .14969 L
.83098 .15284 L
.82959 .15452 L
.82615 .15869 L
.8256 .15935 L
.82163 .16419 L
.82132 .16456 L
.81767 .16902 L
.81649 .17046 L
.81372 .17385 L
.81165 .17638 L
.80978 .17868 L
.80682 .18231 L
.80585 .18351 L
.80199 .18827 L
.80193 .18835 L
.79803 .19318 L
.79716 .19425 L
.79413 .19801 L
.79233 .20026 L
.79025 .20284 L
.7875 .20628 L
.78638 .20767 L
.78266 .21232 L
.78252 .2125 L
.77867 .21734 L
.77783 .21839 L
.77483 .22217 L
.773 .22448 L
.77101 .227 L
.76817 .2306 L
.76719 .23183 L
.76339 .23666 L
.76334 .23673 L
.7596 .2415 L
.7585 .24289 L
.75582 .24633 L
.75367 .24907 L
.75205 .25116 L
.74884 .25528 L
.74829 .25599 L
.74454 .26082 L
.74401 .26151 L
.7408 .26566 L
.73918 .26776 L
.73708 .27049 L
.73434 .27404 L
.73336 .27532 L
.72966 .28015 L
.72951 .28034 L
.72596 .28498 L
.72468 .28666 L
.72228 .28981 L
.71985 .29301 L
.71861 .29465 L
.71502 .29938 L
.71495 .29948 L
.7113 .30431 L
.71019 .30578 L
.70766 .30914 L
.70535 .3122 L
.70402 .31397 L
.70052 .31865 L
.7004 .31881 L
.69679 .32364 L
.69569 .32512 L
.69319 .32847 L
.69086 .33161 L
.6896 .3333 L
.68603 .33813 L
.68602 .33813 L
.68245 .34296 L
.68119 .34467 L
.67889 .3478 L
.67636 .35123 L
.67533 .35263 L
.67179 .35746 L
.67153 .35781 L
.66826 .36229 L
.6667 .36442 L
.66473 .36712 L
.66187 .37105 L
.66121 .37196 L
.6577 .37679 L
.65704 .3777 L
.6542 .38162 L
.6522 .38437 L
.6507 .38645 L
.64737 .39106 L
.64721 .39128 L
.64373 .39612 L
.64254 .39777 L
.64026 .40095 L
.63771 .4045 L
.63679 .40578 L
.63333 .41061 L
.63288 .41124 L
.6309 .41544 L
.62804 .41589 L
.62733 .41544 L
.62321 .41267 L
.62035 .41061 L
.61838 .40916 L
.61381 .40578 L
.61355 .40559 L
.61038 .40578 L
.60872 .40722 L
.60787 .41061 L
.60388 .41499 L
.60347 .41544 L
.59905 .42021 L
.59899 .42027 L
.59444 .42511 L
.59422 .42533 L
.58979 .42994 L
.58939 .43034 L
.58502 .43477 L
.58456 .43523 L
.58011 .4396 L
.57973 .43998 L
.57504 .44443 L
.57489 .44457 L
.57006 .449 L
.56976 .44927 L
.56523 .45324 L
.56423 .4541 L
.5604 .45729 L
.55836 .45893 L
.55557 .46112 L
.55205 .46376 L
.55073 .46471 L
.5459 .46806 L
.54509 .46859 L
.54107 .47113 L
.53714 .47342 L
.53624 .47392 L
.53141 .47641 L
.52733 .47826 L
.52658 .47857 L
.52174 .4804 L
.51691 .48188 L
.51208 .483 L
.51172 .48309 L
.50725 .48375 L
.50242 .48413 L
.49758 .48413 L
.49275 .48375 L
.48828 .48309 L
.48792 .483 L
.48309 .48188 L
.47826 .4804 L
.47342 .47857 L
.47267 .47826 L
.46859 .47641 L
.46376 .47392 L
.46286 .47342 L
.45893 .47113 L
.45491 .46859 L
.4541 .46806 L
.44927 .46471 L
.44796 .46376 L
.44443 .46111 L
.44164 .45893 L
.4396 .45728 L
.43577 .4541 L
.43477 .45324 L
.43024 .44927 L
.42994 .44899 L
.42511 .44457 L
.42496 .44443 L
.42027 .43997 L
.41989 .4396 L
.41544 .43523 L
.41498 .43477 L
.41061 .43034 L
.41022 .42994 L
.40578 .42533 L
.40556 .42511 L
.40101 .42027 L
.40095 .42021 L
.39654 .41544 L
.39612 .41498 L
.39214 .41061 L
.39128 .40722 L
.38962 .40578 L
.38645 .40559 L
.38619 .40578 L
.38162 .40916 L
.37965 .41061 L
.37679 .41267 L
.37267 .41544 L
.37196 .41589 L
.36911 .41544 L
.36712 .41123 L
.36668 .41061 L
.36321 .40578 L
.36229 .40449 L
.35975 .40095 L
.35746 .39777 L
.35627 .39612 L
.35279 .39128 L
.35263 .39106 L
.3493 .38645 L
.3478 .38437 L
.34581 .38162 L
.34296 .3777 L
.3423 .37679 L
.33879 .37196 L
.33813 .37105 L
.33527 .36712 L
.3333 .36442 L
.33175 .36229 L
.32847 .35781 L
.32821 .35746 L
.32467 .35263 L
.32364 .35123 L
.32111 .3478 L
.31881 .34466 L
.31755 .34296 L
.31398 .33813 L
.31397 .33812 L
.3104 .3333 L
.30914 .33161 L
.30681 .32847 L
.30431 .32511 L
.30321 .32364 L
.2996 .31881 L
.29948 .31864 L
.29598 .31397 L
.29465 .3122 L
.29235 .30914 L
.28981 .30578 L
.28871 .30431 L
.28506 .29948 L
.28498 .29938 L
.28139 .29465 L
.28015 .29301 L
.27772 .28981 L
.27532 .28666 L
.27404 .28498 L
.27049 .28034 L
.27035 .28015 L
.26664 .27532 L
.26566 .27404 L
.26292 .27049 L
.26082 .26776 L
.2592 .26566 L
.25599 .26151 L
.25546 .26082 L
.25171 .25599 L
.25116 .25528 L
.24796 .25116 L
.24633 .24907 L
.24418 .24633 L
.2415 .24289 L
.2404 .2415 L
.23666 .23673 L
.23661 .23666 L
.23281 .23183 L
.23183 .23059 L
.22899 .227 L
.227 .22448 L
.22517 .22217 L
.22217 .21839 L
.22133 .21734 L
.21748 .2125 L
.21734 .21232 L
.21362 .20767 L
.2125 .20628 L
.20975 .20284 L
.20767 .20025 L
.20587 .19801 L
.20284 .19425 L
.20197 .19318 L
.19807 .18835 L
.19801 .18827 L
.19415 .18351 L
.19318 .18231 L
.19022 .17868 L
.18835 .17637 L
.18628 .17385 L
.18351 .17046 L
.18233 .16902 L
.17868 .16456 L
.17837 .16419 L
.1744 .15935 L
.17385 .15869 L
.17041 .15452 L
.16902 .15283 L
.16642 .14969 L
.16419 .147 L
.16241 .14486 L
.15935 .14118 L
.15839 .14003 L
.15452 .13539 L
.15436 .1352 L
.15032 .13036 L
.14969 .12962 L
.14626 .12553 L
.14486 .12386 L
.1422 .1207 L
.14003 .11812 L
.13812 .11587 L
.1352 .11241 L
.13403 .11104 L
.13036 .10671 L
.12993 .1062 L
.12582 .10137 L
.12553 .10103 L
.1217 .09654 L
.1207 .09537 L
.11757 .09171 L
.11587 .08973 L
.11342 .08688 L
.11104 .0841 L
.10927 .08204 L
.1062 .07849 L
.1051 .07721 L
.10137 .0729 L
.10092 .07238 L
.09673 .06755 L
.09654 .06733 L
.09253 .06272 L
.09171 .06178 L
.08831 .05789 L
.08688 .05624 L
.08409 .05305 L
.08204 .05072 L
.07985 .04822 L
.07721 .04522 L
.07561 .04339 L
.07238 .03973 L
.07135 .03856 L
.06755 .03426 L
.06708 .03373 L
.0628 .02889 L
.06272 .0288 L
.05851 .02406 L
.05789 .02336 L
.0542 .01923 L
F
0 g
.9458 .01923 m
.94211 .02337 L
.9415 .02406 L
.93728 .0288 L
.9372 .02889 L
.93292 .03373 L
.93245 .03426 L
.92865 .03856 L
.92762 .03973 L
.9244 .04339 L
.92279 .04522 L
.92015 .04822 L
.91796 .05072 L
.91591 .05305 L
.91312 .05624 L
.91169 .05789 L
.90829 .06178 L
.90747 .06272 L
.90346 .06733 L
.90327 .06755 L
.89908 .07238 L
.89863 .07291 L
.8949 .07721 L
.8938 .0785 L
.89074 .08204 L
.88896 .0841 L
.88658 .08688 L
.88413 .08973 L
.88243 .09171 L
.8793 .09537 L
.8783 .09654 L
.87447 .10103 L
.87418 .10137 L
.87007 .1062 L
.86964 .10671 L
.86597 .11104 L
.8648 .11241 L
.86188 .11587 L
.85997 .11813 L
.8578 .1207 L
.85514 .12386 L
.85374 .12553 L
.85031 .12962 L
.84968 .13036 L
.84564 .1352 L
.84548 .13539 L
.84161 .14003 L
.84065 .14119 L
.83759 .14486 L
.83581 .147 L
Mistroke
.83359 .14969 L
.83098 .15284 L
.82959 .15452 L
.82615 .15869 L
.8256 .15935 L
.82163 .16419 L
.82132 .16456 L
.81767 .16902 L
.81649 .17046 L
.81372 .17385 L
.81165 .17638 L
.80978 .17868 L
.80682 .18231 L
.80585 .18351 L
.80199 .18827 L
.80193 .18835 L
.79803 .19318 L
.79716 .19425 L
.79413 .19801 L
.79233 .20026 L
.79025 .20284 L
.7875 .20628 L
.78638 .20767 L
.78266 .21232 L
.78252 .2125 L
.77867 .21734 L
.77783 .21839 L
.77483 .22217 L
.773 .22448 L
.77101 .227 L
.76817 .2306 L
.76719 .23183 L
.76339 .23666 L
.76334 .23673 L
.7596 .2415 L
.7585 .24289 L
.75582 .24633 L
.75367 .24907 L
.75205 .25116 L
.74884 .25528 L
.74829 .25599 L
.74454 .26082 L
.74401 .26151 L
.7408 .26566 L
.73918 .26776 L
.73708 .27049 L
.73434 .27404 L
.73336 .27532 L
.72966 .28015 L
.72951 .28034 L
Mistroke
.72596 .28498 L
.72468 .28666 L
.72228 .28981 L
.71985 .29301 L
.71861 .29465 L
.71502 .29938 L
.71495 .29948 L
.7113 .30431 L
.71019 .30578 L
.70766 .30914 L
.70535 .3122 L
.70402 .31397 L
.70052 .31865 L
.7004 .31881 L
.69679 .32364 L
.69569 .32512 L
.69319 .32847 L
.69086 .33161 L
.6896 .3333 L
.68603 .33813 L
.68602 .33813 L
.68245 .34296 L
.68119 .34467 L
.67889 .3478 L
.67636 .35123 L
.67533 .35263 L
.67179 .35746 L
.67153 .35781 L
.66826 .36229 L
.6667 .36442 L
.66473 .36712 L
.66187 .37105 L
.66121 .37196 L
.6577 .37679 L
.65704 .3777 L
.6542 .38162 L
.6522 .38437 L
.6507 .38645 L
.64737 .39106 L
.64721 .39128 L
.64373 .39612 L
.64254 .39777 L
.64026 .40095 L
.63771 .4045 L
.63679 .40578 L
.63333 .41061 L
.63288 .41124 L
.6309 .41544 L
.62804 .41589 L
.62733 .41544 L
Mistroke
.62321 .41267 L
.62035 .41061 L
.61838 .40916 L
.61381 .40578 L
.61355 .40559 L
.61038 .40578 L
.60872 .40722 L
.60787 .41061 L
.60388 .41499 L
.60347 .41544 L
.59905 .42021 L
.59899 .42027 L
.59444 .42511 L
.59422 .42533 L
.58979 .42994 L
.58939 .43034 L
.58502 .43477 L
.58456 .43523 L
.58011 .4396 L
.57973 .43998 L
.57504 .44443 L
.57489 .44457 L
.57006 .449 L
.56976 .44927 L
.56523 .45324 L
.56423 .4541 L
.5604 .45729 L
.55836 .45893 L
.55557 .46112 L
.55205 .46376 L
.55073 .46471 L
.5459 .46806 L
.54509 .46859 L
.54107 .47113 L
.53714 .47342 L
.53624 .47392 L
.53141 .47641 L
.52733 .47826 L
.52658 .47857 L
.52174 .4804 L
.51691 .48188 L
.51208 .483 L
.51172 .48309 L
.50725 .48375 L
.50242 .48413 L
.49758 .48413 L
.49275 .48375 L
.48828 .48309 L
.48792 .483 L
.48309 .48188 L
Mistroke
.47826 .4804 L
.47342 .47857 L
.47267 .47826 L
.46859 .47641 L
.46376 .47392 L
.46286 .47342 L
.45893 .47113 L
.45491 .46859 L
.4541 .46806 L
.44927 .46471 L
.44796 .46376 L
.44443 .46111 L
.44164 .45893 L
.4396 .45728 L
.43577 .4541 L
.43477 .45324 L
.43024 .44927 L
.42994 .44899 L
.42511 .44457 L
.42496 .44443 L
.42027 .43997 L
.41989 .4396 L
.41544 .43523 L
.41498 .43477 L
.41061 .43034 L
.41022 .42994 L
.40578 .42533 L
.40556 .42511 L
.40101 .42027 L
.40095 .42021 L
.39654 .41544 L
.39612 .41498 L
.39214 .41061 L
.39128 .40722 L
.38962 .40578 L
.38645 .40559 L
.38619 .40578 L
.38162 .40916 L
.37965 .41061 L
.37679 .41267 L
.37267 .41544 L
.37196 .41589 L
.36911 .41544 L
.36712 .41123 L
.36668 .41061 L
.36321 .40578 L
.36229 .40449 L
.35975 .40095 L
.35746 .39777 L
.35627 .39612 L
Mistroke
.35279 .39128 L
.35263 .39106 L
.3493 .38645 L
.3478 .38437 L
.34581 .38162 L
.34296 .3777 L
.3423 .37679 L
.33879 .37196 L
.33813 .37105 L
.33527 .36712 L
.3333 .36442 L
.33175 .36229 L
.32847 .35781 L
.32821 .35746 L
.32467 .35263 L
.32364 .35123 L
.32111 .3478 L
.31881 .34466 L
.31755 .34296 L
.31398 .33813 L
.31397 .33812 L
.3104 .3333 L
.30914 .33161 L
.30681 .32847 L
.30431 .32511 L
.30321 .32364 L
.2996 .31881 L
.29948 .31864 L
.29598 .31397 L
.29465 .3122 L
.29235 .30914 L
.28981 .30578 L
.28871 .30431 L
.28506 .29948 L
.28498 .29938 L
.28139 .29465 L
.28015 .29301 L
.27772 .28981 L
.27532 .28666 L
.27404 .28498 L
.27049 .28034 L
.27035 .28015 L
.26664 .27532 L
.26566 .27404 L
.26292 .27049 L
.26082 .26776 L
.2592 .26566 L
.25599 .26151 L
.25546 .26082 L
.25171 .25599 L
Mistroke
.25116 .25528 L
.24796 .25116 L
.24633 .24907 L
.24418 .24633 L
.2415 .24289 L
.2404 .2415 L
.23666 .23673 L
.23661 .23666 L
.23281 .23183 L
.23183 .23059 L
.22899 .227 L
.227 .22448 L
.22517 .22217 L
.22217 .21839 L
.22133 .21734 L
.21748 .2125 L
.21734 .21232 L
.21362 .20767 L
.2125 .20628 L
.20975 .20284 L
.20767 .20025 L
.20587 .19801 L
.20284 .19425 L
.20197 .19318 L
.19807 .18835 L
.19801 .18827 L
.19415 .18351 L
.19318 .18231 L
.19022 .17868 L
.18835 .17637 L
.18628 .17385 L
.18351 .17046 L
.18233 .16902 L
.17868 .16456 L
.17837 .16419 L
.1744 .15935 L
.17385 .15869 L
.17041 .15452 L
.16902 .15283 L
.16642 .14969 L
.16419 .147 L
.16241 .14486 L
.15935 .14118 L
.15839 .14003 L
.15452 .13539 L
.15436 .1352 L
.15032 .13036 L
.14969 .12962 L
.14626 .12553 L
.14486 .12386 L
Mistroke
.1422 .1207 L
.14003 .11812 L
.13812 .11587 L
.1352 .11241 L
.13403 .11104 L
.13036 .10671 L
.12993 .1062 L
.12582 .10137 L
.12553 .10103 L
.1217 .09654 L
.1207 .09537 L
.11757 .09171 L
.11587 .08973 L
.11342 .08688 L
.11104 .0841 L
.10927 .08204 L
.1062 .07849 L
.1051 .07721 L
.10137 .0729 L
.10092 .07238 L
.09673 .06755 L
.09654 .06733 L
.09253 .06272 L
.09171 .06178 L
.08831 .05789 L
.08688 .05624 L
.08409 .05305 L
.08204 .05072 L
.07985 .04822 L
.07721 .04522 L
.07561 .04339 L
.07238 .03973 L
.07135 .03856 L
.06755 .03426 L
.06708 .03373 L
.0628 .02889 L
.06272 .0288 L
.05851 .02406 L
.05789 .02336 L
.0542 .01923 L
Mfstroke
0 .415 .222 r
.93591 .01923 m
.93245 .02307 L
.93157 .02406 L
.92762 .02847 L
.92724 .02889 L
.92292 .03373 L
.92279 .03387 L
.91861 .03856 L
.91796 .03929 L
.91431 .04339 L
.91312 .04473 L
.91003 .04822 L
.90829 .05018 L
.90575 .05305 L
.90346 .05565 L
.90149 .05789 L
.89863 .06114 L
.89724 .06272 L
.8938 .06663 L
.89299 .06755 L
.88896 .07215 L
.88876 .07238 L
.88454 .07721 L
.88413 .07768 L
.88033 .08204 L
.8793 .08323 L
.87613 .08688 L
.87447 .0888 L
.87195 .09171 L
.86964 .09438 L
.86777 .09654 L
.8648 .09997 L
.8636 .10137 L
.85997 .10559 L
.85945 .1062 L
.8553 .11104 L
.85514 .11122 L
.85117 .11587 L
.85031 .11687 L
.84704 .1207 L
.84548 .12254 L
.84293 .12553 L
.84065 .12822 L
.83883 .13036 L
.83581 .13392 L
.83474 .1352 L
.83098 .13964 L
.83066 .14003 L
.82659 .14486 L
.82615 .14538 L
.82253 .14969 L
.82132 .15113 L
.81848 .15452 L
.81649 .15691 L
.81444 .15935 L
.81165 .1627 L
.81041 .16419 L
.80682 .16851 L
.8064 .16902 L
.80239 .17385 L
.80199 .17433 L
.7984 .17868 L
.79716 .18018 L
.79441 .18351 L
.79233 .18604 L
.79044 .18835 L
.7875 .19193 L
.78647 .19318 L
.78266 .19783 L
.78252 .19801 L
.77857 .20284 L
.77783 .20375 L
.77464 .20767 L
.773 .20969 L
.77072 .2125 L
.76817 .21565 L
.7668 .21734 L
.76334 .22163 L
.7629 .22217 L
.75901 .227 L
.7585 .22763 L
.75512 .23183 L
.75367 .23364 L
.75125 .23666 L
.74884 .23968 L
.74739 .2415 L
.74401 .24573 L
.74353 .24633 L
.73969 .25116 L
.73918 .25181 L
.73586 .25599 L
.73434 .2579 L
.73203 .26082 L
.72951 .26401 L
.72821 .26566 L
.72468 .27014 L
.72441 .27049 L
.72061 .27532 L
.71985 .27629 L
.71682 .28015 L
.71502 .28246 L
.71304 .28498 L
.71019 .28864 L
.70927 .28981 L
.70551 .29465 L
.70535 .29485 L
.70175 .29948 L
.70052 .30107 L
.69801 .30431 L
.69569 .30731 L
.69427 .30914 L
.69086 .31356 L
.69054 .31397 L
.68682 .31881 L
.68603 .31983 L
.6831 .32364 L
.68119 .32612 L
.67939 .32847 L
.67636 .33242 L
.67569 .3333 L
.672 .33813 L
.67153 .33874 L
.66831 .34296 L
.6667 .34507 L
.66462 .3478 L
.66187 .35142 L
.66094 .35263 L
.65727 .35746 L
.65704 .35777 L
.6536 .36229 L
.6522 .36414 L
.64994 .36712 L
.64737 .37051 L
.64628 .37196 L
.64262 .37679 L
.64254 .37689 L
.63896 .38162 L
.63771 .38328 L
.63531 .38645 L
.63288 .38967 L
.63165 .39128 L
.62804 .39606 L
.628 .39612 L
.62435 .40095 L
.62321 .40245 L
.62186 .40578 L
.61838 .40618 L
.61783 .40578 L
.61355 .40254 L
.60872 .40308 L
.60609 .40095 L
.60388 .39914 L
.60024 .39612 L
.59905 .39513 L
.59445 .39128 L
.59422 .39109 L
.59014 .39128 L
.58939 .39347 L
.58635 .39612 L
.58456 .39766 L
.58064 .40095 L
.57973 .4017 L
.57489 .4056 L
.57466 .40578 L
.57006 .40933 L
.56835 .41061 L
.56523 .41288 L
.56159 .41544 L
.5604 .41625 L
.55557 .41942 L
.55421 .42027 L
.55073 .42238 L
.54593 .42511 L
.5459 .42512 L
.54107 .42762 L
.53624 .42988 L
.5361 .42994 L
.53141 .43188 L
.52658 .43361 L
.52284 .43477 L
.52174 .43507 L
.51691 .43625 L
.51208 .43714 L
.50725 .43774 L
.50242 .43803 L
.49758 .43803 L
.49275 .43774 L
.48792 .43714 L
.48309 .43625 L
.47826 .43507 L
.47717 .43477 L
.47342 .43361 L
.46859 .43188 L
.4639 .42994 L
.46376 .42988 L
.45893 .42762 L
.4541 .42512 L
.45408 .42511 L
.44927 .42238 L
.44579 .42027 L
.44443 .41942 L
.4396 .41625 L
.43841 .41544 L
.43477 .41288 L
.43165 .41061 L
.42994 .40933 L
.42534 .40578 L
.42511 .4056 L
.42027 .4017 L
.41936 .40095 L
.41544 .39765 L
.41365 .39612 L
.41061 .39346 L
.40986 .39128 L
.40578 .39109 L
.40555 .39128 L
.40095 .39513 L
.39976 .39612 L
.39612 .39914 L
.39391 .40095 L
.39128 .40308 L
.38645 .40254 L
.38217 .40578 L
.38162 .40617 L
.37814 .40578 L
.37679 .40244 L
.37566 .40095 L
.372 .39612 L
.37196 .39605 L
.36835 .39128 L
.36712 .38966 L
.3647 .38645 L
.36229 .38327 L
.36104 .38162 L
.35746 .37688 L
.35739 .37679 L
.35373 .37196 L
.35263 .3705 L
.35007 .36712 L
.3478 .36413 L
.3464 .36229 L
.34296 .35776 L
.34273 .35746 L
.33906 .35263 L
.33813 .35141 L
.33538 .3478 L
.3333 .34507 L
.3317 .34296 L
.32847 .33874 L
.32801 .33813 L
.32431 .3333 L
.32364 .33242 L
.32061 .32847 L
.31881 .32612 L
.3169 .32364 L
.31397 .31983 L
.31319 .31881 L
.30946 .31397 L
.30914 .31356 L
.30573 .30914 L
.30431 .3073 L
.30199 .30431 L
.29948 .30106 L
.29825 .29948 L
.29465 .29484 L
.29449 .29465 L
.29073 .28981 L
.28981 .28864 L
.28696 .28498 L
.28498 .28245 L
.28318 .28015 L
.28015 .27628 L
.27939 .27532 L
.2756 .27049 L
.27532 .27014 L
.27179 .26566 L
.27049 .26401 L
.26797 .26082 L
.26566 .25789 L
.26415 .25599 L
.26082 .2518 L
.26031 .25116 L
.25647 .24633 L
.25599 .24573 L
.25262 .2415 L
.25116 .23967 L
.24875 .23666 L
.24633 .23364 L
.24488 .23183 L
.2415 .22762 L
.241 .227 L
.2371 .22217 L
.23666 .22162 L
.2332 .21734 L
.23183 .21565 L
.22929 .2125 L
.227 .20969 L
.22536 .20767 L
.22217 .20375 L
.22143 .20284 L
.21749 .19801 L
.21734 .19783 L
.21353 .19318 L
.2125 .19192 L
.20957 .18835 L
.20767 .18604 L
.20559 .18351 L
.20284 .18018 L
.20161 .17868 L
.19801 .17433 L
.19761 .17385 L
.19361 .16902 L
.19318 .1685 L
.18959 .16419 L
.18835 .16269 L
.18556 .15935 L
.18351 .1569 L
.18152 .15452 L
.17868 .15113 L
.17747 .14969 L
.17385 .14537 L
.17342 .14486 L
.16935 .14003 L
.16902 .13964 L
.16527 .1352 L
.16419 .13392 L
.16117 .13036 L
.15935 .12822 L
.15707 .12553 L
.15452 .12253 L
.15296 .1207 L
.14969 .11687 L
.14884 .11587 L
.14486 .11122 L
.1447 .11104 L
.14056 .1062 L
.14003 .10559 L
.1364 .10137 L
.1352 .09997 L
.13223 .09654 L
.13036 .09437 L
.12806 .09171 L
.12553 .08879 L
.12387 .08688 L
.1207 .08323 L
.11967 .08204 L
.11587 .07768 L
.11546 .07721 L
.11124 .07238 L
.11104 .07215 L
.10701 .06755 L
.1062 .06663 L
.10277 .06272 L
.10137 .06113 L
.09851 .05789 L
.09654 .05565 L
.09425 .05305 L
.09171 .05018 L
.08997 .04822 L
.08688 .04473 L
.08569 .04339 L
.08204 .03929 L
.08139 .03856 L
.07721 .03387 L
.07708 .03373 L
.07277 .02889 L
.07238 .02846 L
.06844 .02406 L
.06755 .02307 L
.0641 .01923 L
F
0 g
.93591 .01923 m
.93245 .02307 L
.93157 .02406 L
.92762 .02847 L
.92724 .02889 L
.92292 .03373 L
.92279 .03387 L
.91861 .03856 L
.91796 .03929 L
.91431 .04339 L
.91312 .04473 L
.91003 .04822 L
.90829 .05018 L
.90575 .05305 L
.90346 .05565 L
.90149 .05789 L
.89863 .06114 L
.89724 .06272 L
.8938 .06663 L
.89299 .06755 L
.88896 .07215 L
.88876 .07238 L
.88454 .07721 L
.88413 .07768 L
.88033 .08204 L
.8793 .08323 L
.87613 .08688 L
.87447 .0888 L
.87195 .09171 L
.86964 .09438 L
.86777 .09654 L
.8648 .09997 L
.8636 .10137 L
.85997 .10559 L
.85945 .1062 L
.8553 .11104 L
.85514 .11122 L
.85117 .11587 L
.85031 .11687 L
.84704 .1207 L
.84548 .12254 L
.84293 .12553 L
.84065 .12822 L
.83883 .13036 L
.83581 .13392 L
.83474 .1352 L
.83098 .13964 L
.83066 .14003 L
.82659 .14486 L
.82615 .14538 L
Mistroke
.82253 .14969 L
.82132 .15113 L
.81848 .15452 L
.81649 .15691 L
.81444 .15935 L
.81165 .1627 L
.81041 .16419 L
.80682 .16851 L
.8064 .16902 L
.80239 .17385 L
.80199 .17433 L
.7984 .17868 L
.79716 .18018 L
.79441 .18351 L
.79233 .18604 L
.79044 .18835 L
.7875 .19193 L
.78647 .19318 L
.78266 .19783 L
.78252 .19801 L
.77857 .20284 L
.77783 .20375 L
.77464 .20767 L
.773 .20969 L
.77072 .2125 L
.76817 .21565 L
.7668 .21734 L
.76334 .22163 L
.7629 .22217 L
.75901 .227 L
.7585 .22763 L
.75512 .23183 L
.75367 .23364 L
.75125 .23666 L
.74884 .23968 L
.74739 .2415 L
.74401 .24573 L
.74353 .24633 L
.73969 .25116 L
.73918 .25181 L
.73586 .25599 L
.73434 .2579 L
.73203 .26082 L
.72951 .26401 L
.72821 .26566 L
.72468 .27014 L
.72441 .27049 L
.72061 .27532 L
.71985 .27629 L
.71682 .28015 L
Mistroke
.71502 .28246 L
.71304 .28498 L
.71019 .28864 L
.70927 .28981 L
.70551 .29465 L
.70535 .29485 L
.70175 .29948 L
.70052 .30107 L
.69801 .30431 L
.69569 .30731 L
.69427 .30914 L
.69086 .31356 L
.69054 .31397 L
.68682 .31881 L
.68603 .31983 L
.6831 .32364 L
.68119 .32612 L
.67939 .32847 L
.67636 .33242 L
.67569 .3333 L
.672 .33813 L
.67153 .33874 L
.66831 .34296 L
.6667 .34507 L
.66462 .3478 L
.66187 .35142 L
.66094 .35263 L
.65727 .35746 L
.65704 .35777 L
.6536 .36229 L
.6522 .36414 L
.64994 .36712 L
.64737 .37051 L
.64628 .37196 L
.64262 .37679 L
.64254 .37689 L
.63896 .38162 L
.63771 .38328 L
.63531 .38645 L
.63288 .38967 L
.63165 .39128 L
.62804 .39606 L
.628 .39612 L
.62435 .40095 L
.62321 .40245 L
.62186 .40578 L
.61838 .40618 L
.61783 .40578 L
.61355 .40254 L
.60872 .40308 L
Mistroke
.60609 .40095 L
.60388 .39914 L
.60024 .39612 L
.59905 .39513 L
.59445 .39128 L
.59422 .39109 L
.59014 .39128 L
.58939 .39347 L
.58635 .39612 L
.58456 .39766 L
.58064 .40095 L
.57973 .4017 L
.57489 .4056 L
.57466 .40578 L
.57006 .40933 L
.56835 .41061 L
.56523 .41288 L
.56159 .41544 L
.5604 .41625 L
.55557 .41942 L
.55421 .42027 L
.55073 .42238 L
.54593 .42511 L
.5459 .42512 L
.54107 .42762 L
.53624 .42988 L
.5361 .42994 L
.53141 .43188 L
.52658 .43361 L
.52284 .43477 L
.52174 .43507 L
.51691 .43625 L
.51208 .43714 L
.50725 .43774 L
.50242 .43803 L
.49758 .43803 L
.49275 .43774 L
.48792 .43714 L
.48309 .43625 L
.47826 .43507 L
.47717 .43477 L
.47342 .43361 L
.46859 .43188 L
.4639 .42994 L
.46376 .42988 L
.45893 .42762 L
.4541 .42512 L
.45408 .42511 L
.44927 .42238 L
.44579 .42027 L
Mistroke
.44443 .41942 L
.4396 .41625 L
.43841 .41544 L
.43477 .41288 L
.43165 .41061 L
.42994 .40933 L
.42534 .40578 L
.42511 .4056 L
.42027 .4017 L
.41936 .40095 L
.41544 .39765 L
.41365 .39612 L
.41061 .39346 L
.40986 .39128 L
.40578 .39109 L
.40555 .39128 L
.40095 .39513 L
.39976 .39612 L
.39612 .39914 L
.39391 .40095 L
.39128 .40308 L
.38645 .40254 L
.38217 .40578 L
.38162 .40617 L
.37814 .40578 L
.37679 .40244 L
.37566 .40095 L
.372 .39612 L
.37196 .39605 L
.36835 .39128 L
.36712 .38966 L
.3647 .38645 L
.36229 .38327 L
.36104 .38162 L
.35746 .37688 L
.35739 .37679 L
.35373 .37196 L
.35263 .3705 L
.35007 .36712 L
.3478 .36413 L
.3464 .36229 L
.34296 .35776 L
.34273 .35746 L
.33906 .35263 L
.33813 .35141 L
.33538 .3478 L
.3333 .34507 L
.3317 .34296 L
.32847 .33874 L
.32801 .33813 L
Mistroke
.32431 .3333 L
.32364 .33242 L
.32061 .32847 L
.31881 .32612 L
.3169 .32364 L
.31397 .31983 L
.31319 .31881 L
.30946 .31397 L
.30914 .31356 L
.30573 .30914 L
.30431 .3073 L
.30199 .30431 L
.29948 .30106 L
.29825 .29948 L
.29465 .29484 L
.29449 .29465 L
.29073 .28981 L
.28981 .28864 L
.28696 .28498 L
.28498 .28245 L
.28318 .28015 L
.28015 .27628 L
.27939 .27532 L
.2756 .27049 L
.27532 .27014 L
.27179 .26566 L
.27049 .26401 L
.26797 .26082 L
.26566 .25789 L
.26415 .25599 L
.26082 .2518 L
.26031 .25116 L
.25647 .24633 L
.25599 .24573 L
.25262 .2415 L
.25116 .23967 L
.24875 .23666 L
.24633 .23364 L
.24488 .23183 L
.2415 .22762 L
.241 .227 L
.2371 .22217 L
.23666 .22162 L
.2332 .21734 L
.23183 .21565 L
.22929 .2125 L
.227 .20969 L
.22536 .20767 L
.22217 .20375 L
.22143 .20284 L
Mistroke
.21749 .19801 L
.21734 .19783 L
.21353 .19318 L
.2125 .19192 L
.20957 .18835 L
.20767 .18604 L
.20559 .18351 L
.20284 .18018 L
.20161 .17868 L
.19801 .17433 L
.19761 .17385 L
.19361 .16902 L
.19318 .1685 L
.18959 .16419 L
.18835 .16269 L
.18556 .15935 L
.18351 .1569 L
.18152 .15452 L
.17868 .15113 L
.17747 .14969 L
.17385 .14537 L
.17342 .14486 L
.16935 .14003 L
.16902 .13964 L
.16527 .1352 L
.16419 .13392 L
.16117 .13036 L
.15935 .12822 L
.15707 .12553 L
.15452 .12253 L
.15296 .1207 L
.14969 .11687 L
.14884 .11587 L
.14486 .11122 L
.1447 .11104 L
.14056 .1062 L
.14003 .10559 L
.1364 .10137 L
.1352 .09997 L
.13223 .09654 L
.13036 .09437 L
.12806 .09171 L
.12553 .08879 L
.12387 .08688 L
.1207 .08323 L
.11967 .08204 L
.11587 .07768 L
.11546 .07721 L
.11124 .07238 L
.11104 .07215 L
Mistroke
.10701 .06755 L
.1062 .06663 L
.10277 .06272 L
.10137 .06113 L
.09851 .05789 L
.09654 .05565 L
.09425 .05305 L
.09171 .05018 L
.08997 .04822 L
.08688 .04473 L
.08569 .04339 L
.08204 .03929 L
.08139 .03856 L
.07721 .03387 L
.07708 .03373 L
.07277 .02889 L
.07238 .02846 L
.06844 .02406 L
.06755 .02307 L
.0641 .01923 L
Mfstroke
0 .37 .27 r
.92124 .01923 m
.91796 .02284 L
.91685 .02406 L
.91312 .02816 L
.91246 .02889 L
.90829 .03349 L
.90808 .03373 L
.90371 .03856 L
.90346 .03884 L
.89936 .04339 L
.89863 .0442 L
.89501 .04822 L
.8938 .04958 L
.89068 .05305 L
.88896 .05496 L
.88635 .05789 L
.88413 .06037 L
.88203 .06272 L
.8793 .06578 L
.87773 .06755 L
.87447 .07121 L
.87343 .07238 L
.86964 .07666 L
.86914 .07721 L
.86487 .08204 L
.8648 .08211 L
.8606 .08688 L
.85997 .08759 L
.85634 .09171 L
.85514 .09307 L
.85209 .09654 L
.85031 .09857 L
.84786 .10137 L
.84548 .10409 L
.84363 .1062 L
.84065 .10962 L
.83941 .11104 L
.83581 .11517 L
.8352 .11587 L
.831 .1207 L
.83098 .12072 L
.82681 .12553 L
.82615 .1263 L
.82263 .13036 L
.82132 .13189 L
.81846 .1352 L
.81649 .13749 L
.8143 .14003 L
.81165 .14311 L
.81015 .14486 L
.80682 .14874 L
.80601 .14969 L
.80199 .15439 L
.80188 .15452 L
.79775 .15935 L
.79716 .16005 L
.79364 .16419 L
.79233 .16573 L
.78953 .16902 L
.7875 .17142 L
.78543 .17385 L
.78266 .17712 L
.78135 .17868 L
.77783 .18284 L
.77727 .18351 L
.77319 .18835 L
.773 .18858 L
.76913 .19318 L
.76817 .19433 L
.76508 .19801 L
.76334 .20009 L
.76103 .20284 L
.7585 .20587 L
.757 .20767 L
.75367 .21166 L
.75297 .2125 L
.74894 .21734 L
.74884 .21746 L
.74493 .22217 L
.74401 .22328 L
.74092 .227 L
.73918 .22911 L
.73693 .23183 L
.73434 .23496 L
.73293 .23666 L
.72951 .24081 L
.72895 .2415 L
.72497 .24633 L
.72468 .24668 L
.721 .25116 L
.71985 .25256 L
.71704 .25599 L
.71502 .25846 L
.71308 .26082 L
.71019 .26436 L
.70913 .26566 L
.70535 .27027 L
.70518 .27049 L
.70124 .27532 L
.70052 .2762 L
.6973 .28015 L
.69569 .28213 L
.69337 .28498 L
.69086 .28807 L
.68944 .28981 L
.68603 .29402 L
.68552 .29465 L
.6816 .29948 L
.68119 .29998 L
.67769 .30431 L
.67636 .30594 L
.67377 .30914 L
.67153 .31191 L
.66986 .31397 L
.6667 .31788 L
.66595 .31881 L
.66204 .32364 L
.66187 .32385 L
.65813 .32847 L
.65704 .32983 L
.65423 .3333 L
.6522 .3358 L
.65032 .33813 L
.64737 .34177 L
.6464 .34296 L
.64254 .34774 L
.64249 .3478 L
.63857 .35263 L
.63771 .35369 L
.63465 .35746 L
.63288 .35964 L
.63072 .36229 L
.62804 .36558 L
.62679 .36712 L
.62321 .3715 L
.62284 .37196 L
.61889 .37679 L
.61838 .3774 L
.61492 .38162 L
.61355 .38329 L
.61094 .38645 L
.60872 .38914 L
.60694 .39128 L
.60388 .39586 L
.59905 .39209 L
.5981 .39128 L
.59422 .38799 L
.59245 .38645 L
.58939 .38378 L
.58456 .38406 L
.58182 .38162 L
.57973 .37975 L
.57643 .37679 L
.57489 .37541 L
.57108 .37196 L
.57006 .37104 L
.56575 .36712 L
.56523 .36665 L
.56043 .36229 L
.5604 .36227 L
.55615 .36229 L
.55557 .36261 L
.55073 .36675 L
.54992 .36712 L
.5459 .36891 L
.54107 .37087 L
.53816 .37196 L
.53624 .37263 L
.53141 .37419 L
.52658 .37553 L
.52174 .37666 L
.52113 .37679 L
.51691 .37757 L
.51208 .37825 L
.50725 .37871 L
.50242 .37894 L
.49758 .37894 L
.49275 .37871 L
.48792 .37825 L
.48309 .37757 L
.47887 .37679 L
.47826 .37666 L
.47342 .37553 L
.46859 .37419 L
.46376 .37263 L
.46185 .37196 L
.45893 .37087 L
.4541 .3689 L
.45008 .36712 L
.44927 .36675 L
.44443 .3626 L
.44385 .36229 L
.4396 .36227 L
.43957 .36229 L
.43477 .36665 L
.43425 .36712 L
.42994 .37104 L
.42892 .37196 L
.42511 .37541 L
.42357 .37679 L
.42027 .37975 L
.41818 .38162 L
.41544 .38406 L
.41061 .38378 L
.40755 .38645 L
.40578 .38799 L
.4019 .39128 L
.40095 .39209 L
.39612 .39585 L
.39306 .39128 L
.39128 .38913 L
.38907 .38645 L
.38645 .38328 L
.38509 .38162 L
.38162 .3774 L
.38112 .37679 L
.37717 .37196 L
.37679 .37149 L
.37322 .36712 L
.37196 .36557 L
.36928 .36229 L
.36712 .35964 L
.36536 .35746 L
.36229 .35369 L
.36143 .35263 L
.35752 .3478 L
.35746 .34773 L
.3536 .34296 L
.35263 .34176 L
.34969 .33813 L
.3478 .33579 L
.34578 .3333 L
.34296 .32982 L
.34187 .32847 L
.33813 .32385 L
.33796 .32364 L
.33405 .31881 L
.3333 .31787 L
.33014 .31397 L
.32847 .3119 L
.32623 .30914 L
.32364 .30594 L
.32232 .30431 L
.31881 .29997 L
.3184 .29948 L
.31448 .29465 L
.31397 .29402 L
.31056 .28981 L
.30914 .28807 L
.30663 .28498 L
.30431 .28213 L
.3027 .28015 L
.29948 .27619 L
.29877 .27532 L
.29482 .27049 L
.29465 .27027 L
.29088 .26566 L
.28981 .26435 L
.28693 .26082 L
.28498 .25845 L
.28297 .25599 L
.28015 .25256 L
.279 .25116 L
.27532 .24668 L
.27503 .24633 L
.27105 .2415 L
.27049 .24081 L
.26707 .23666 L
.26566 .23495 L
.26308 .23183 L
.26082 .22911 L
.25908 .227 L
.25599 .22328 L
.25507 .22217 L
.25116 .21746 L
.25106 .21734 L
.24704 .2125 L
.24633 .21165 L
.24301 .20767 L
.2415 .20586 L
.23897 .20284 L
.23666 .20008 L
.23492 .19801 L
.23183 .19432 L
.23087 .19318 L
.227 .18857 L
.22681 .18835 L
.22274 .18351 L
.22217 .18284 L
.21866 .17868 L
.21734 .17712 L
.21457 .17385 L
.2125 .17141 L
.21047 .16902 L
.20767 .16572 L
.20637 .16419 L
.20284 .16005 L
.20225 .15935 L
.19813 .15452 L
.19801 .15438 L
.19399 .14969 L
.19318 .14874 L
.18985 .14486 L
.18835 .1431 L
.1857 .14003 L
.18351 .13749 L
.18154 .1352 L
.17868 .13188 L
.17737 .13036 L
.17385 .1263 L
.17319 .12553 L
.16902 .12072 L
.169 .1207 L
.1648 .11587 L
.16419 .11516 L
.16059 .11104 L
.15935 .10962 L
.15637 .1062 L
.15452 .10409 L
.15215 .10137 L
.14969 .09857 L
.14791 .09654 L
.14486 .09307 L
.14366 .09171 L
.14003 .08758 L
.1394 .08688 L
.1352 .08211 L
.13514 .08204 L
.13086 .07721 L
.13036 .07665 L
.12657 .07238 L
.12553 .07121 L
.12228 .06755 L
.1207 .06578 L
.11797 .06272 L
.11587 .06036 L
.11365 .05789 L
.11104 .05496 L
.10933 .05305 L
.1062 .04957 L
.10499 .04822 L
.10137 .0442 L
.10064 .04339 L
.09654 .03884 L
.09629 .03856 L
.09192 .03373 L
.09171 .03349 L
.08754 .02889 L
.08688 .02816 L
.08316 .02406 L
.08204 .02284 L
.07876 .01923 L
F
0 g
.92124 .01923 m
.91796 .02284 L
.91685 .02406 L
.91312 .02816 L
.91246 .02889 L
.90829 .03349 L
.90808 .03373 L
.90371 .03856 L
.90346 .03884 L
.89936 .04339 L
.89863 .0442 L
.89501 .04822 L
.8938 .04958 L
.89068 .05305 L
.88896 .05496 L
.88635 .05789 L
.88413 .06037 L
.88203 .06272 L
.8793 .06578 L
.87773 .06755 L
.87447 .07121 L
.87343 .07238 L
.86964 .07666 L
.86914 .07721 L
.86487 .08204 L
.8648 .08211 L
.8606 .08688 L
.85997 .08759 L
.85634 .09171 L
.85514 .09307 L
.85209 .09654 L
.85031 .09857 L
.84786 .10137 L
.84548 .10409 L
.84363 .1062 L
.84065 .10962 L
.83941 .11104 L
.83581 .11517 L
.8352 .11587 L
.831 .1207 L
.83098 .12072 L
.82681 .12553 L
.82615 .1263 L
.82263 .13036 L
.82132 .13189 L
.81846 .1352 L
.81649 .13749 L
.8143 .14003 L
.81165 .14311 L
.81015 .14486 L
Mistroke
.80682 .14874 L
.80601 .14969 L
.80199 .15439 L
.80188 .15452 L
.79775 .15935 L
.79716 .16005 L
.79364 .16419 L
.79233 .16573 L
.78953 .16902 L
.7875 .17142 L
.78543 .17385 L
.78266 .17712 L
.78135 .17868 L
.77783 .18284 L
.77727 .18351 L
.77319 .18835 L
.773 .18858 L
.76913 .19318 L
.76817 .19433 L
.76508 .19801 L
.76334 .20009 L
.76103 .20284 L
.7585 .20587 L
.757 .20767 L
.75367 .21166 L
.75297 .2125 L
.74894 .21734 L
.74884 .21746 L
.74493 .22217 L
.74401 .22328 L
.74092 .227 L
.73918 .22911 L
.73693 .23183 L
.73434 .23496 L
.73293 .23666 L
.72951 .24081 L
.72895 .2415 L
.72497 .24633 L
.72468 .24668 L
.721 .25116 L
.71985 .25256 L
.71704 .25599 L
.71502 .25846 L
.71308 .26082 L
.71019 .26436 L
.70913 .26566 L
.70535 .27027 L
.70518 .27049 L
.70124 .27532 L
.70052 .2762 L
Mistroke
.6973 .28015 L
.69569 .28213 L
.69337 .28498 L
.69086 .28807 L
.68944 .28981 L
.68603 .29402 L
.68552 .29465 L
.6816 .29948 L
.68119 .29998 L
.67769 .30431 L
.67636 .30594 L
.67377 .30914 L
.67153 .31191 L
.66986 .31397 L
.6667 .31788 L
.66595 .31881 L
.66204 .32364 L
.66187 .32385 L
.65813 .32847 L
.65704 .32983 L
.65423 .3333 L
.6522 .3358 L
.65032 .33813 L
.64737 .34177 L
.6464 .34296 L
.64254 .34774 L
.64249 .3478 L
.63857 .35263 L
.63771 .35369 L
.63465 .35746 L
.63288 .35964 L
.63072 .36229 L
.62804 .36558 L
.62679 .36712 L
.62321 .3715 L
.62284 .37196 L
.61889 .37679 L
.61838 .3774 L
.61492 .38162 L
.61355 .38329 L
.61094 .38645 L
.60872 .38914 L
.60694 .39128 L
.60388 .39586 L
.59905 .39209 L
.5981 .39128 L
.59422 .38799 L
.59245 .38645 L
.58939 .38378 L
.58456 .38406 L
Mistroke
.58182 .38162 L
.57973 .37975 L
.57643 .37679 L
.57489 .37541 L
.57108 .37196 L
.57006 .37104 L
.56575 .36712 L
.56523 .36665 L
.56043 .36229 L
.5604 .36227 L
.55615 .36229 L
.55557 .36261 L
.55073 .36675 L
.54992 .36712 L
.5459 .36891 L
.54107 .37087 L
.53816 .37196 L
.53624 .37263 L
.53141 .37419 L
.52658 .37553 L
.52174 .37666 L
.52113 .37679 L
.51691 .37757 L
.51208 .37825 L
.50725 .37871 L
.50242 .37894 L
.49758 .37894 L
.49275 .37871 L
.48792 .37825 L
.48309 .37757 L
.47887 .37679 L
.47826 .37666 L
.47342 .37553 L
.46859 .37419 L
.46376 .37263 L
.46185 .37196 L
.45893 .37087 L
.4541 .3689 L
.45008 .36712 L
.44927 .36675 L
.44443 .3626 L
.44385 .36229 L
.4396 .36227 L
.43957 .36229 L
.43477 .36665 L
.43425 .36712 L
.42994 .37104 L
.42892 .37196 L
.42511 .37541 L
.42357 .37679 L
Mistroke
.42027 .37975 L
.41818 .38162 L
.41544 .38406 L
.41061 .38378 L
.40755 .38645 L
.40578 .38799 L
.4019 .39128 L
.40095 .39209 L
.39612 .39585 L
.39306 .39128 L
.39128 .38913 L
.38907 .38645 L
.38645 .38328 L
.38509 .38162 L
.38162 .3774 L
.38112 .37679 L
.37717 .37196 L
.37679 .37149 L
.37322 .36712 L
.37196 .36557 L
.36928 .36229 L
.36712 .35964 L
.36536 .35746 L
.36229 .35369 L
.36143 .35263 L
.35752 .3478 L
.35746 .34773 L
.3536 .34296 L
.35263 .34176 L
.34969 .33813 L
.3478 .33579 L
.34578 .3333 L
.34296 .32982 L
.34187 .32847 L
.33813 .32385 L
.33796 .32364 L
.33405 .31881 L
.3333 .31787 L
.33014 .31397 L
.32847 .3119 L
.32623 .30914 L
.32364 .30594 L
.32232 .30431 L
.31881 .29997 L
.3184 .29948 L
.31448 .29465 L
.31397 .29402 L
.31056 .28981 L
.30914 .28807 L
.30663 .28498 L
Mistroke
.30431 .28213 L
.3027 .28015 L
.29948 .27619 L
.29877 .27532 L
.29482 .27049 L
.29465 .27027 L
.29088 .26566 L
.28981 .26435 L
.28693 .26082 L
.28498 .25845 L
.28297 .25599 L
.28015 .25256 L
.279 .25116 L
.27532 .24668 L
.27503 .24633 L
.27105 .2415 L
.27049 .24081 L
.26707 .23666 L
.26566 .23495 L
.26308 .23183 L
.26082 .22911 L
.25908 .227 L
.25599 .22328 L
.25507 .22217 L
.25116 .21746 L
.25106 .21734 L
.24704 .2125 L
.24633 .21165 L
.24301 .20767 L
.2415 .20586 L
.23897 .20284 L
.23666 .20008 L
.23492 .19801 L
.23183 .19432 L
.23087 .19318 L
.227 .18857 L
.22681 .18835 L
.22274 .18351 L
.22217 .18284 L
.21866 .17868 L
.21734 .17712 L
.21457 .17385 L
.2125 .17141 L
.21047 .16902 L
.20767 .16572 L
.20637 .16419 L
.20284 .16005 L
.20225 .15935 L
.19813 .15452 L
.19801 .15438 L
Mistroke
.19399 .14969 L
.19318 .14874 L
.18985 .14486 L
.18835 .1431 L
.1857 .14003 L
.18351 .13749 L
.18154 .1352 L
.17868 .13188 L
.17737 .13036 L
.17385 .1263 L
.17319 .12553 L
.16902 .12072 L
.169 .1207 L
.1648 .11587 L
.16419 .11516 L
.16059 .11104 L
.15935 .10962 L
.15637 .1062 L
.15452 .10409 L
.15215 .10137 L
.14969 .09857 L
.14791 .09654 L
.14486 .09307 L
.14366 .09171 L
.14003 .08758 L
.1394 .08688 L
.1352 .08211 L
.13514 .08204 L
.13086 .07721 L
.13036 .07665 L
.12657 .07238 L
.12553 .07121 L
.12228 .06755 L
.1207 .06578 L
.11797 .06272 L
.11587 .06036 L
.11365 .05789 L
.11104 .05496 L
.10933 .05305 L
.1062 .04957 L
.10499 .04822 L
.10137 .0442 L
.10064 .04339 L
.09654 .03884 L
.09629 .03856 L
.09192 .03373 L
.09171 .03349 L
.08754 .02889 L
.08688 .02816 L
.08316 .02406 L
Mistroke
.08204 .02284 L
.07876 .01923 L
Mfstroke
0 .325 .301 r
.89807 .01923 m
.8938 .02383 L
.89358 .02406 L
.88909 .02889 L
.88896 .02903 L
.88461 .03373 L
.88413 .03424 L
.88014 .03856 L
.8793 .03947 L
.87568 .04339 L
.87447 .0447 L
.87123 .04822 L
.86964 .04995 L
.86678 .05305 L
.8648 .05521 L
.86235 .05789 L
.85997 .06048 L
.85792 .06272 L
.85514 .06575 L
.8535 .06755 L
.85031 .07104 L
.84909 .07238 L
.84548 .07634 L
.84469 .07721 L
.84065 .08165 L
.84029 .08204 L
.8359 .08688 L
.83581 .08697 L
.83152 .09171 L
.83098 .09231 L
.82715 .09654 L
.82615 .09765 L
.82279 .10137 L
.82132 .103 L
.81843 .1062 L
.81649 .10836 L
.81408 .11104 L
.81165 .11373 L
.80974 .11587 L
.80682 .11912 L
.8054 .1207 L
.80199 .12451 L
.80107 .12553 L
.79716 .12991 L
.79675 .13036 L
.79244 .1352 L
.79233 .13532 L
.78813 .14003 L
.7875 .14074 L
.78383 .14486 L
.78266 .14617 L
.77953 .14969 L
.77783 .15161 L
.77524 .15452 L
.773 .15705 L
.77096 .15935 L
.76817 .16251 L
.76668 .16419 L
.76334 .16797 L
.76241 .16902 L
.7585 .17344 L
.75814 .17385 L
.75388 .17868 L
.75367 .17892 L
.74963 .18351 L
.74884 .18441 L
.74537 .18835 L
.74401 .1899 L
.74112 .19318 L
.73918 .19539 L
.73688 .19801 L
.73434 .2009 L
.73264 .20284 L
.72951 .20641 L
.7284 .20767 L
.72468 .21192 L
.72417 .2125 L
.71994 .21734 L
.71985 .21743 L
.71571 .22217 L
.71502 .22295 L
.71148 .227 L
.71019 .22848 L
.70725 .23183 L
.70535 .234 L
.70302 .23666 L
.70052 .23953 L
.6988 .2415 L
.69569 .24505 L
.69457 .24633 L
.69086 .25057 L
.69035 .25116 L
.68612 .25599 L
.68603 .2561 L
.68189 .26082 L
.68119 .26161 L
.67765 .26566 L
.67636 .26713 L
.67342 .27049 L
.67153 .27263 L
.66917 .27532 L
.6667 .27813 L
.66493 .28015 L
.66187 .28363 L
.66067 .28498 L
.65704 .28911 L
.65641 .28981 L
.6522 .29457 L
.65214 .29465 L
.64786 .29948 L
.64737 .30003 L
.64356 .30431 L
.64254 .30546 L
.63926 .30914 L
.63771 .31088 L
.63494 .31397 L
.63288 .31627 L
.6306 .31881 L
.62804 .32164 L
.62624 .32364 L
.62321 .32698 L
.62186 .32847 L
.61838 .33229 L
.61746 .3333 L
.61355 .33757 L
.61303 .33813 L
.60872 .34281 L
.60857 .34296 L
.60408 .3478 L
.60388 .348 L
.59954 .35263 L
.59905 .35315 L
.59497 .35746 L
.59422 .35824 L
.59034 .36229 L
.58939 .36328 L
.58566 .36712 L
.58456 .36826 L
.58092 .37196 L
.57973 .37616 L
.57489 .37231 L
.57449 .37196 L
.57006 .36798 L
.56912 .36712 L
.56523 .36357 L
.56384 .36229 L
.5604 .35912 L
.55557 .35926 L
.55363 .35746 L
.55073 .35475 L
.54847 .35263 L
.5459 .35022 L
.54333 .3478 L
.54107 .34567 L
.53822 .34296 L
.53624 .34109 L
.53312 .33813 L
.53141 .33651 L
.52658 .33657 L
.52315 .3333 L
.52174 .33196 L
.51809 .32847 L
.51691 .32734 L
.51304 .32364 L
.51208 .32271 L
.50801 .31881 L
.50725 .31808 L
.50242 .31796 L
.49758 .31796 L
.49275 .31808 L
.49199 .31881 L
.48792 .32271 L
.48695 .32364 L
.48309 .32734 L
.48191 .32847 L
.47826 .33196 L
.47685 .3333 L
.47342 .33657 L
.46859 .33651 L
.46688 .33813 L
.46376 .34109 L
.46178 .34296 L
.45893 .34567 L
.45667 .3478 L
.4541 .35022 L
.45153 .35263 L
.44927 .35475 L
.44637 .35746 L
.44443 .35926 L
.4396 .35912 L
.43616 .36229 L
.43477 .36357 L
.43088 .36712 L
.42994 .36797 L
.42551 .37196 L
.42511 .37231 L
.42027 .37616 L
.41909 .37196 L
.41544 .36825 L
.41435 .36712 L
.41061 .36327 L
.40967 .36229 L
.40578 .35823 L
.40504 .35746 L
.40095 .35314 L
.40047 .35263 L
.39612 .34799 L
.39593 .3478 L
.39144 .34296 L
.39128 .3428 L
.38698 .33813 L
.38645 .33756 L
.38255 .3333 L
.38162 .33228 L
.37815 .32847 L
.37679 .32697 L
.37377 .32364 L
.37196 .32163 L
.36941 .31881 L
.36712 .31626 L
.36507 .31397 L
.36229 .31087 L
.36075 .30914 L
.35746 .30545 L
.35644 .30431 L
.35263 .30002 L
.35215 .29948 L
.34787 .29465 L
.3478 .29456 L
.3436 .28981 L
.34296 .2891 L
.33934 .28498 L
.33813 .28362 L
.33508 .28015 L
.3333 .27813 L
.33083 .27532 L
.32847 .27263 L
.32659 .27049 L
.32364 .26712 L
.32235 .26566 L
.31881 .26161 L
.31812 .26082 L
.31397 .25609 L
.31389 .25599 L
.30966 .25116 L
.30914 .25057 L
.30543 .24633 L
.30431 .24504 L
.30121 .2415 L
.29948 .23952 L
.29698 .23666 L
.29465 .23399 L
.29276 .23183 L
.28981 .22847 L
.28853 .227 L
.28498 .22295 L
.2843 .22217 L
.28015 .21743 L
.28007 .21734 L
.27584 .2125 L
.27532 .21191 L
.2716 .20767 L
.27049 .2064 L
.26737 .20284 L
.26566 .20089 L
.26313 .19801 L
.26082 .19539 L
.25888 .19318 L
.25599 .18989 L
.25463 .18835 L
.25116 .1844 L
.25038 .18351 L
.24633 .17891 L
.24612 .17868 L
.24186 .17385 L
.2415 .17344 L
.23759 .16902 L
.23666 .16797 L
.23332 .16419 L
.23183 .1625 L
.22904 .15935 L
.227 .15705 L
.22476 .15452 L
.22217 .1516 L
.22047 .14969 L
.21734 .14616 L
.21618 .14486 L
.2125 .14074 L
.21187 .14003 L
.20767 .13532 L
.20757 .1352 L
.20325 .13036 L
.20284 .1299 L
.19893 .12553 L
.19801 .1245 L
.1946 .1207 L
.19318 .11911 L
.19027 .11587 L
.18835 .11373 L
.18592 .11104 L
.18351 .10836 L
.18157 .1062 L
.17868 .10299 L
.17722 .10137 L
.17385 .09764 L
.17285 .09654 L
.16902 .0923 L
.16848 .09171 L
.16419 .08697 L
.1641 .08688 L
.15971 .08204 L
.15935 .08165 L
.15532 .07721 L
.15452 .07634 L
.15092 .07238 L
.14969 .07104 L
.1465 .06755 L
.14486 .06575 L
.14208 .06272 L
.14003 .06047 L
.13766 .05789 L
.1352 .0552 L
.13322 .05305 L
.13036 .04995 L
.12878 .04822 L
.12553 .0447 L
.12432 .04339 L
.1207 .03946 L
.11986 .03856 L
.11587 .03424 L
.11539 .03373 L
.11104 .02903 L
.11091 .02889 L
.10643 .02406 L
.1062 .02382 L
.10193 .01923 L
F
0 g
.89807 .01923 m
.8938 .02383 L
.89358 .02406 L
.88909 .02889 L
.88896 .02903 L
.88461 .03373 L
.88413 .03424 L
.88014 .03856 L
.8793 .03947 L
.87568 .04339 L
.87447 .0447 L
.87123 .04822 L
.86964 .04995 L
.86678 .05305 L
.8648 .05521 L
.86235 .05789 L
.85997 .06048 L
.85792 .06272 L
.85514 .06575 L
.8535 .06755 L
.85031 .07104 L
.84909 .07238 L
.84548 .07634 L
.84469 .07721 L
.84065 .08165 L
.84029 .08204 L
.8359 .08688 L
.83581 .08697 L
.83152 .09171 L
.83098 .09231 L
.82715 .09654 L
.82615 .09765 L
.82279 .10137 L
.82132 .103 L
.81843 .1062 L
.81649 .10836 L
.81408 .11104 L
.81165 .11373 L
.80974 .11587 L
.80682 .11912 L
.8054 .1207 L
.80199 .12451 L
.80107 .12553 L
.79716 .12991 L
.79675 .13036 L
.79244 .1352 L
.79233 .13532 L
.78813 .14003 L
.7875 .14074 L
.78383 .14486 L
Mistroke
.78266 .14617 L
.77953 .14969 L
.77783 .15161 L
.77524 .15452 L
.773 .15705 L
.77096 .15935 L
.76817 .16251 L
.76668 .16419 L
.76334 .16797 L
.76241 .16902 L
.7585 .17344 L
.75814 .17385 L
.75388 .17868 L
.75367 .17892 L
.74963 .18351 L
.74884 .18441 L
.74537 .18835 L
.74401 .1899 L
.74112 .19318 L
.73918 .19539 L
.73688 .19801 L
.73434 .2009 L
.73264 .20284 L
.72951 .20641 L
.7284 .20767 L
.72468 .21192 L
.72417 .2125 L
.71994 .21734 L
.71985 .21743 L
.71571 .22217 L
.71502 .22295 L
.71148 .227 L
.71019 .22848 L
.70725 .23183 L
.70535 .234 L
.70302 .23666 L
.70052 .23953 L
.6988 .2415 L
.69569 .24505 L
.69457 .24633 L
.69086 .25057 L
.69035 .25116 L
.68612 .25599 L
.68603 .2561 L
.68189 .26082 L
.68119 .26161 L
.67765 .26566 L
.67636 .26713 L
.67342 .27049 L
.67153 .27263 L
Mistroke
.66917 .27532 L
.6667 .27813 L
.66493 .28015 L
.66187 .28363 L
.66067 .28498 L
.65704 .28911 L
.65641 .28981 L
.6522 .29457 L
.65214 .29465 L
.64786 .29948 L
.64737 .30003 L
.64356 .30431 L
.64254 .30546 L
.63926 .30914 L
.63771 .31088 L
.63494 .31397 L
.63288 .31627 L
.6306 .31881 L
.62804 .32164 L
.62624 .32364 L
.62321 .32698 L
.62186 .32847 L
.61838 .33229 L
.61746 .3333 L
.61355 .33757 L
.61303 .33813 L
.60872 .34281 L
.60857 .34296 L
.60408 .3478 L
.60388 .348 L
.59954 .35263 L
.59905 .35315 L
.59497 .35746 L
.59422 .35824 L
.59034 .36229 L
.58939 .36328 L
.58566 .36712 L
.58456 .36826 L
.58092 .37196 L
.57973 .37616 L
.57489 .37231 L
.57449 .37196 L
.57006 .36798 L
.56912 .36712 L
.56523 .36357 L
.56384 .36229 L
.5604 .35912 L
.55557 .35926 L
.55363 .35746 L
.55073 .35475 L
Mistroke
.54847 .35263 L
.5459 .35022 L
.54333 .3478 L
.54107 .34567 L
.53822 .34296 L
.53624 .34109 L
.53312 .33813 L
.53141 .33651 L
.52658 .33657 L
.52315 .3333 L
.52174 .33196 L
.51809 .32847 L
.51691 .32734 L
.51304 .32364 L
.51208 .32271 L
.50801 .31881 L
.50725 .31808 L
.50242 .31796 L
.49758 .31796 L
.49275 .31808 L
.49199 .31881 L
.48792 .32271 L
.48695 .32364 L
.48309 .32734 L
.48191 .32847 L
.47826 .33196 L
.47685 .3333 L
.47342 .33657 L
.46859 .33651 L
.46688 .33813 L
.46376 .34109 L
.46178 .34296 L
.45893 .34567 L
.45667 .3478 L
.4541 .35022 L
.45153 .35263 L
.44927 .35475 L
.44637 .35746 L
.44443 .35926 L
.4396 .35912 L
.43616 .36229 L
.43477 .36357 L
.43088 .36712 L
.42994 .36797 L
.42551 .37196 L
.42511 .37231 L
.42027 .37616 L
.41909 .37196 L
.41544 .36825 L
.41435 .36712 L
Mistroke
.41061 .36327 L
.40967 .36229 L
.40578 .35823 L
.40504 .35746 L
.40095 .35314 L
.40047 .35263 L
.39612 .34799 L
.39593 .3478 L
.39144 .34296 L
.39128 .3428 L
.38698 .33813 L
.38645 .33756 L
.38255 .3333 L
.38162 .33228 L
.37815 .32847 L
.37679 .32697 L
.37377 .32364 L
.37196 .32163 L
.36941 .31881 L
.36712 .31626 L
.36507 .31397 L
.36229 .31087 L
.36075 .30914 L
.35746 .30545 L
.35644 .30431 L
.35263 .30002 L
.35215 .29948 L
.34787 .29465 L
.3478 .29456 L
.3436 .28981 L
.34296 .2891 L
.33934 .28498 L
.33813 .28362 L
.33508 .28015 L
.3333 .27813 L
.33083 .27532 L
.32847 .27263 L
.32659 .27049 L
.32364 .26712 L
.32235 .26566 L
.31881 .26161 L
.31812 .26082 L
.31397 .25609 L
.31389 .25599 L
.30966 .25116 L
.30914 .25057 L
.30543 .24633 L
.30431 .24504 L
.30121 .2415 L
.29948 .23952 L
Mistroke
.29698 .23666 L
.29465 .23399 L
.29276 .23183 L
.28981 .22847 L
.28853 .227 L
.28498 .22295 L
.2843 .22217 L
.28015 .21743 L
.28007 .21734 L
.27584 .2125 L
.27532 .21191 L
.2716 .20767 L
.27049 .2064 L
.26737 .20284 L
.26566 .20089 L
.26313 .19801 L
.26082 .19539 L
.25888 .19318 L
.25599 .18989 L
.25463 .18835 L
.25116 .1844 L
.25038 .18351 L
.24633 .17891 L
.24612 .17868 L
.24186 .17385 L
.2415 .17344 L
.23759 .16902 L
.23666 .16797 L
.23332 .16419 L
.23183 .1625 L
.22904 .15935 L
.227 .15705 L
.22476 .15452 L
.22217 .1516 L
.22047 .14969 L
.21734 .14616 L
.21618 .14486 L
.2125 .14074 L
.21187 .14003 L
.20767 .13532 L
.20757 .1352 L
.20325 .13036 L
.20284 .1299 L
.19893 .12553 L
.19801 .1245 L
.1946 .1207 L
.19318 .11911 L
.19027 .11587 L
.18835 .11373 L
.18592 .11104 L
Mistroke
.18351 .10836 L
.18157 .1062 L
.17868 .10299 L
.17722 .10137 L
.17385 .09764 L
.17285 .09654 L
.16902 .0923 L
.16848 .09171 L
.16419 .08697 L
.1641 .08688 L
.15971 .08204 L
.15935 .08165 L
.15532 .07721 L
.15452 .07634 L
.15092 .07238 L
.14969 .07104 L
.1465 .06755 L
.14486 .06575 L
.14208 .06272 L
.14003 .06047 L
.13766 .05789 L
.1352 .0552 L
.13322 .05305 L
.13036 .04995 L
.12878 .04822 L
.12553 .0447 L
.12432 .04339 L
.1207 .03946 L
.11986 .03856 L
.11587 .03424 L
.11539 .03373 L
.11104 .02903 L
.11091 .02889 L
.10643 .02406 L
.1062 .02382 L
.10193 .01923 L
Mfstroke
0 .246 .28 r
.85987 .01923 m
.85514 .02385 L
.85067 .02406 L
.85031 .02443 L
.84586 .02889 L
.84548 .02928 L
.84105 .03373 L
.84065 .03413 L
.83623 .03856 L
.83581 .03898 L
.83142 .04339 L
.83098 .04383 L
.82977 .04822 L
.82615 .04868 L
.82511 .05305 L
.82132 .05698 L
.82044 .05789 L
.81649 .06199 L
.81578 .06272 L
.81165 .067 L
.81113 .06755 L
.80682 .07202 L
.80647 .07238 L
.80199 .07704 L
.80182 .07721 L
.79718 .08204 L
.79716 .08206 L
.79253 .08688 L
.79233 .08709 L
.78789 .09171 L
.7875 .09212 L
.78325 .09654 L
.78266 .09715 L
.77861 .10137 L
.77783 .10218 L
.77397 .1062 L
.773 .10722 L
.76934 .11104 L
.76817 .11225 L
.7647 .11587 L
.76334 .11729 L
.76006 .1207 L
.7585 .12232 L
.75543 .12553 L
.75367 .12736 L
.75079 .13036 L
.74884 .13239 L
.74615 .1352 L
.74401 .13743 L
.74151 .14003 L
.73918 .14246 L
.73687 .14486 L
.73434 .14748 L
.73222 .14969 L
.72951 .15251 L
.72757 .15452 L
.72468 .15753 L
.72292 .15935 L
.71985 .16254 L
.71826 .16419 L
.71502 .16755 L
.7136 .16902 L
.71019 .17255 L
.70893 .17385 L
.70535 .17754 L
.70425 .17868 L
.70052 .18253 L
.69956 .18351 L
.69569 .1875 L
.69487 .18835 L
.69086 .19246 L
.69016 .19318 L
.68603 .19741 L
.68544 .19801 L
.68119 .20235 L
.68071 .20284 L
.67636 .20727 L
.67597 .20767 L
.67153 .21218 L
.67121 .2125 L
.6667 .21706 L
.66643 .21734 L
.66187 .22193 L
.66163 .22217 L
.65704 .22677 L
.65681 .227 L
.6522 .2316 L
.65197 .23183 L
.64737 .23639 L
.6471 .23666 L
.64254 .24116 L
.6422 .2415 L
.63771 .2459 L
.63727 .24633 L
.63288 .25061 L
.63231 .25116 L
.62804 .25528 L
.62731 .25599 L
.62321 .25992 L
.62226 .26082 L
.61838 .26451 L
.61717 .26566 L
.61355 .26906 L
.61203 .27049 L
.60872 .27357 L
.60682 .27532 L
.60388 .27802 L
.60156 .28015 L
.59905 .28243 L
.59622 .28498 L
.59422 .28677 L
.5908 .28981 L
.58939 .29106 L
.58528 .29465 L
.58456 .29527 L
.57973 .29942 L
.57966 .29948 L
.57489 .3035 L
.57392 .30431 L
.57006 .30749 L
.56804 .30914 L
.56523 .3114 L
.56199 .31397 L
.5604 .31523 L
.55576 .31881 L
.55557 .31895 L
.55073 .32258 L
.54929 .32364 L
.5459 .32609 L
.54255 .32847 L
.54107 .3295 L
.53624 .33278 L
.53545 .3333 L
.53141 .3334 L
.52658 .33351 L
.52635 .3333 L
.52174 .32894 L
.52125 .32847 L
.51691 .32435 L
.51617 .32364 L
.51208 .31973 L
.51112 .31881 L
.50725 .31509 L
.50242 .31492 L
.49758 .31492 L
.49275 .31509 L
.48888 .31881 L
.48792 .31973 L
.48383 .32364 L
.48309 .32434 L
.47875 .32847 L
.47826 .32894 L
.47365 .3333 L
.47342 .33351 L
.46859 .3334 L
.46458 .3333 L
.46376 .33276 L
.45893 .32948 L
.45748 .32847 L
.4541 .32608 L
.45073 .32364 L
.44927 .32256 L
.44443 .31894 L
.44426 .31881 L
.4396 .31521 L
.43803 .31397 L
.43477 .31139 L
.43198 .30914 L
.42994 .30748 L
.4261 .30431 L
.42511 .30348 L
.42036 .29948 L
.42027 .29941 L
.41544 .29526 L
.41474 .29465 L
.41061 .29104 L
.40922 .28981 L
.40578 .28676 L
.4038 .28498 L
.40095 .28241 L
.39846 .28015 L
.39612 .27801 L
.39319 .27532 L
.39128 .27355 L
.38799 .27049 L
.38645 .26905 L
.38284 .26566 L
.38162 .2645 L
.37775 .26082 L
.37679 .2599 L
.37271 .25599 L
.37196 .25527 L
.3677 .25116 L
.36712 .2506 L
.36274 .24633 L
.36229 .24589 L
.35781 .2415 L
.35746 .24115 L
.35291 .23666 L
.35263 .23638 L
.34804 .23183 L
.3478 .23159 L
.3432 .227 L
.34296 .22676 L
.33838 .22217 L
.33813 .22192 L
.33358 .21734 L
.3333 .21705 L
.3288 .2125 L
.32847 .21217 L
.32404 .20767 L
.32364 .20726 L
.3193 .20284 L
.31881 .20234 L
.31457 .19801 L
.31397 .1974 L
.30985 .19318 L
.30914 .19245 L
.30514 .18835 L
.30431 .18749 L
.30045 .18351 L
.29948 .18252 L
.29576 .17868 L
.29465 .17753 L
.29108 .17385 L
.28981 .17254 L
.28641 .16902 L
.28498 .16754 L
.28175 .16419 L
.28015 .16253 L
.27709 .15935 L
.27532 .15752 L
.27243 .15452 L
.27049 .1525 L
.26778 .14969 L
.26566 .14748 L
.26314 .14486 L
.26082 .14245 L
.2585 .14003 L
.25599 .13742 L
.25386 .1352 L
.25116 .13239 L
.24922 .13036 L
.24633 .12735 L
.24458 .12553 L
.2415 .12232 L
.23994 .1207 L
.23666 .11728 L
.23531 .11587 L
.23183 .11224 L
.23067 .11104 L
.227 .10721 L
.22604 .1062 L
.22217 .10218 L
.2214 .10137 L
.21734 .09714 L
.21676 .09654 L
.2125 .09211 L
.21212 .09171 L
.20767 .08708 L
.20748 .08688 L
.20284 .08205 L
.20283 .08204 L
.19818 .07721 L
.19801 .07703 L
.19353 .07238 L
.19318 .07201 L
.18888 .06755 L
.18835 .06699 L
.18422 .06272 L
.18351 .06198 L
.17956 .05789 L
.17868 .05697 L
.1749 .05305 L
.17385 .04868 L
.17023 .04822 L
.16902 .04383 L
.16858 .04339 L
.16419 .03898 L
.16377 .03856 L
.15935 .03413 L
.15896 .03373 L
.15452 .02928 L
.15414 .02889 L
.14969 .02443 L
.14933 .02406 L
.14486 .02385 L
.14013 .01923 L
F
0 g
.85987 .01923 m
.85514 .02385 L
.85067 .02406 L
.85031 .02443 L
.84586 .02889 L
.84548 .02928 L
.84105 .03373 L
.84065 .03413 L
.83623 .03856 L
.83581 .03898 L
.83142 .04339 L
.83098 .04383 L
.82977 .04822 L
.82615 .04868 L
.82511 .05305 L
.82132 .05698 L
.82044 .05789 L
.81649 .06199 L
.81578 .06272 L
.81165 .067 L
.81113 .06755 L
.80682 .07202 L
.80647 .07238 L
.80199 .07704 L
.80182 .07721 L
.79718 .08204 L
.79716 .08206 L
.79253 .08688 L
.79233 .08709 L
.78789 .09171 L
.7875 .09212 L
.78325 .09654 L
.78266 .09715 L
.77861 .10137 L
.77783 .10218 L
.77397 .1062 L
.773 .10722 L
.76934 .11104 L
.76817 .11225 L
.7647 .11587 L
.76334 .11729 L
.76006 .1207 L
.7585 .12232 L
.75543 .12553 L
.75367 .12736 L
.75079 .13036 L
.74884 .13239 L
.74615 .1352 L
.74401 .13743 L
.74151 .14003 L
Mistroke
.73918 .14246 L
.73687 .14486 L
.73434 .14748 L
.73222 .14969 L
.72951 .15251 L
.72757 .15452 L
.72468 .15753 L
.72292 .15935 L
.71985 .16254 L
.71826 .16419 L
.71502 .16755 L
.7136 .16902 L
.71019 .17255 L
.70893 .17385 L
.70535 .17754 L
.70425 .17868 L
.70052 .18253 L
.69956 .18351 L
.69569 .1875 L
.69487 .18835 L
.69086 .19246 L
.69016 .19318 L
.68603 .19741 L
.68544 .19801 L
.68119 .20235 L
.68071 .20284 L
.67636 .20727 L
.67597 .20767 L
.67153 .21218 L
.67121 .2125 L
.6667 .21706 L
.66643 .21734 L
.66187 .22193 L
.66163 .22217 L
.65704 .22677 L
.65681 .227 L
.6522 .2316 L
.65197 .23183 L
.64737 .23639 L
.6471 .23666 L
.64254 .24116 L
.6422 .2415 L
.63771 .2459 L
.63727 .24633 L
.63288 .25061 L
.63231 .25116 L
.62804 .25528 L
.62731 .25599 L
.62321 .25992 L
.62226 .26082 L
Mistroke
.61838 .26451 L
.61717 .26566 L
.61355 .26906 L
.61203 .27049 L
.60872 .27357 L
.60682 .27532 L
.60388 .27802 L
.60156 .28015 L
.59905 .28243 L
.59622 .28498 L
.59422 .28677 L
.5908 .28981 L
.58939 .29106 L
.58528 .29465 L
.58456 .29527 L
.57973 .29942 L
.57966 .29948 L
.57489 .3035 L
.57392 .30431 L
.57006 .30749 L
.56804 .30914 L
.56523 .3114 L
.56199 .31397 L
.5604 .31523 L
.55576 .31881 L
.55557 .31895 L
.55073 .32258 L
.54929 .32364 L
.5459 .32609 L
.54255 .32847 L
.54107 .3295 L
.53624 .33278 L
.53545 .3333 L
.53141 .3334 L
.52658 .33351 L
.52635 .3333 L
.52174 .32894 L
.52125 .32847 L
.51691 .32435 L
.51617 .32364 L
.51208 .31973 L
.51112 .31881 L
.50725 .31509 L
.50242 .31492 L
.49758 .31492 L
.49275 .31509 L
.48888 .31881 L
.48792 .31973 L
.48383 .32364 L
.48309 .32434 L
Mistroke
.47875 .32847 L
.47826 .32894 L
.47365 .3333 L
.47342 .33351 L
.46859 .3334 L
.46458 .3333 L
.46376 .33276 L
.45893 .32948 L
.45748 .32847 L
.4541 .32608 L
.45073 .32364 L
.44927 .32256 L
.44443 .31894 L
.44426 .31881 L
.4396 .31521 L
.43803 .31397 L
.43477 .31139 L
.43198 .30914 L
.42994 .30748 L
.4261 .30431 L
.42511 .30348 L
.42036 .29948 L
.42027 .29941 L
.41544 .29526 L
.41474 .29465 L
.41061 .29104 L
.40922 .28981 L
.40578 .28676 L
.4038 .28498 L
.40095 .28241 L
.39846 .28015 L
.39612 .27801 L
.39319 .27532 L
.39128 .27355 L
.38799 .27049 L
.38645 .26905 L
.38284 .26566 L
.38162 .2645 L
.37775 .26082 L
.37679 .2599 L
.37271 .25599 L
.37196 .25527 L
.3677 .25116 L
.36712 .2506 L
.36274 .24633 L
.36229 .24589 L
.35781 .2415 L
.35746 .24115 L
.35291 .23666 L
.35263 .23638 L
Mistroke
.34804 .23183 L
.3478 .23159 L
.3432 .227 L
.34296 .22676 L
.33838 .22217 L
.33813 .22192 L
.33358 .21734 L
.3333 .21705 L
.3288 .2125 L
.32847 .21217 L
.32404 .20767 L
.32364 .20726 L
.3193 .20284 L
.31881 .20234 L
.31457 .19801 L
.31397 .1974 L
.30985 .19318 L
.30914 .19245 L
.30514 .18835 L
.30431 .18749 L
.30045 .18351 L
.29948 .18252 L
.29576 .17868 L
.29465 .17753 L
.29108 .17385 L
.28981 .17254 L
.28641 .16902 L
.28498 .16754 L
.28175 .16419 L
.28015 .16253 L
.27709 .15935 L
.27532 .15752 L
.27243 .15452 L
.27049 .1525 L
.26778 .14969 L
.26566 .14748 L
.26314 .14486 L
.26082 .14245 L
.2585 .14003 L
.25599 .13742 L
.25386 .1352 L
.25116 .13239 L
.24922 .13036 L
.24633 .12735 L
.24458 .12553 L
.2415 .12232 L
.23994 .1207 L
.23666 .11728 L
.23531 .11587 L
.23183 .11224 L
Mistroke
.23067 .11104 L
.227 .10721 L
.22604 .1062 L
.22217 .10218 L
.2214 .10137 L
.21734 .09714 L
.21676 .09654 L
.2125 .09211 L
.21212 .09171 L
.20767 .08708 L
.20748 .08688 L
.20284 .08205 L
.20283 .08204 L
.19818 .07721 L
.19801 .07703 L
.19353 .07238 L
.19318 .07201 L
.18888 .06755 L
.18835 .06699 L
.18422 .06272 L
.18351 .06198 L
.17956 .05789 L
.17868 .05697 L
.1749 .05305 L
.17385 .04868 L
.17023 .04822 L
.16902 .04383 L
.16858 .04339 L
.16419 .03898 L
.16377 .03856 L
.15935 .03413 L
.15896 .03373 L
.15452 .02928 L
.15414 .02889 L
.14969 .02443 L
.14933 .02406 L
.14486 .02385 L
.14013 .01923 L
Mfstroke
0 .161 .235 r
.85766 .01923 m
.85514 .02093 L
.85031 .02106 L
.84813 .02406 L
.84548 .02672 L
.8433 .02889 L
.84065 .03155 L
.83847 .03373 L
.83581 .03639 L
.83364 .03856 L
.83098 .04122 L
.82881 .04339 L
.82615 .04605 L
.82132 .04618 L
.81928 .04822 L
.81649 .05102 L
.81445 .05305 L
.81165 .05585 L
.80961 .05789 L
.80682 .06068 L
.80478 .06272 L
.80199 .06551 L
.79716 .06564 L
.79525 .06755 L
.79233 .07047 L
.79041 .07238 L
.7875 .0753 L
.78558 .07721 L
.78266 .08013 L
.78075 .08204 L
.77783 .08496 L
.77592 .08688 L
.773 .08979 L
.76817 .08992 L
.76637 .09171 L
.76334 .09475 L
.76154 .09654 L
.7585 .09958 L
.75671 .10137 L
.75367 .10441 L
.75187 .1062 L
.74884 .10923 L
.74704 .11104 L
.74401 .11406 L
.73918 .11418 L
.73749 .11587 L
.73434 .11901 L
.73265 .1207 L
.72951 .12384 L
.72781 .12553 L
.72468 .12866 L
.72298 .13036 L
.71985 .13349 L
.71502 .1336 L
.71342 .1352 L
.71019 .13843 L
.70858 .14003 L
.70535 .14325 L
.70375 .14486 L
.70052 .14808 L
.69891 .14969 L
.69569 .1529 L
.69407 .15452 L
.69086 .15773 L
.68603 .15783 L
.6845 .15935 L
.68119 .16266 L
.67966 .16419 L
.67636 .16748 L
.67482 .16902 L
.67153 .1723 L
.66998 .17385 L
.6667 .17712 L
.66513 .17868 L
.66187 .18194 L
.65704 .18204 L
.65556 .18351 L
.6522 .18686 L
.65071 .18835 L
.64737 .19168 L
.64587 .19318 L
.64254 .1965 L
.64102 .19801 L
.63771 .20131 L
.63288 .20141 L
.63143 .20284 L
.62804 .20622 L
.62658 .20767 L
.62321 .21103 L
.62173 .2125 L
.61838 .21585 L
.61688 .21734 L
.61355 .22066 L
.61203 .22217 L
.60872 .22547 L
.60388 .22555 L
.60243 .227 L
.59905 .23036 L
.59757 .23183 L
.59422 .23517 L
.59271 .23666 L
.58939 .23997 L
.58785 .2415 L
.58456 .24477 L
.58299 .24633 L
.57973 .24958 L
.57489 .24965 L
.57337 .25116 L
.57006 .25445 L
.56851 .25599 L
.56523 .25924 L
.56364 .26082 L
.5604 .26404 L
.55877 .26566 L
.55557 .26883 L
.55073 .2689 L
.54913 .27049 L
.5459 .27368 L
.54425 .27532 L
.54107 .27847 L
.53937 .28015 L
.53624 .28325 L
.53449 .28498 L
.53141 .28804 L
.52961 .28981 L
.52658 .29281 L
.52174 .29286 L
.51993 .29465 L
.51691 .29763 L
.51504 .29948 L
.51208 .3024 L
.51014 .30431 L
.50725 .30717 L
.50524 .30914 L
.50242 .31221 L
.49758 .31221 L
.49476 .30914 L
.49275 .30717 L
.48986 .30431 L
.48792 .3024 L
.48496 .29948 L
.48309 .29763 L
.48007 .29465 L
.47826 .29286 L
.47342 .29281 L
.47039 .28981 L
.46859 .28803 L
.46551 .28498 L
.46376 .28325 L
.46063 .28015 L
.45893 .27847 L
.45575 .27532 L
.4541 .27368 L
.45087 .27049 L
.44927 .26889 L
.44443 .26883 L
.44123 .26566 L
.4396 .26404 L
.43636 .26082 L
.43477 .25924 L
.43149 .25599 L
.42994 .25445 L
.42663 .25116 L
.42511 .24965 L
.42027 .24958 L
.41701 .24633 L
.41544 .24477 L
.41215 .2415 L
.41061 .23997 L
.40729 .23666 L
.40578 .23517 L
.40243 .23183 L
.40095 .23036 L
.39757 .227 L
.39612 .22555 L
.39128 .22547 L
.38797 .22217 L
.38645 .22066 L
.38312 .21734 L
.38162 .21585 L
.37827 .2125 L
.37679 .21103 L
.37342 .20767 L
.37196 .20622 L
.36857 .20284 L
.36712 .20141 L
.36229 .20131 L
.35898 .19801 L
.35746 .1965 L
.35413 .19318 L
.35263 .19168 L
.34929 .18835 L
.3478 .18686 L
.34444 .18351 L
.34296 .18204 L
.33813 .18194 L
.33487 .17868 L
.3333 .17712 L
.33002 .17385 L
.32847 .1723 L
.32518 .16902 L
.32364 .16748 L
.32034 .16419 L
.31881 .16266 L
.3155 .15935 L
.31397 .15783 L
.30914 .15773 L
.30593 .15452 L
.30431 .1529 L
.30109 .14969 L
.29948 .14808 L
.29625 .14486 L
.29465 .14325 L
.29142 .14003 L
.28981 .13843 L
.28658 .1352 L
.28498 .1336 L
.28015 .13349 L
.27702 .13036 L
.27532 .12866 L
.27219 .12553 L
.27049 .12384 L
.26735 .1207 L
.26566 .11901 L
.26251 .11587 L
.26082 .11418 L
.25599 .11406 L
.25296 .11104 L
.25116 .10923 L
.24813 .1062 L
.24633 .10441 L
.24329 .10137 L
.2415 .09958 L
.23846 .09654 L
.23666 .09475 L
.23363 .09171 L
.23183 .08992 L
.227 .08979 L
.22408 .08688 L
.22217 .08496 L
.21925 .08204 L
.21734 .08013 L
.21442 .07721 L
.2125 .0753 L
.20959 .07238 L
.20767 .07047 L
.20475 .06755 L
.20284 .06564 L
.19801 .06551 L
.19522 .06272 L
.19318 .06068 L
.19039 .05789 L
.18835 .05585 L
.18555 .05305 L
.18351 .05102 L
.18072 .04822 L
.17868 .04618 L
.17385 .04605 L
.17119 .04339 L
.16902 .04122 L
.16636 .03856 L
.16419 .03639 L
.16153 .03373 L
.15935 .03155 L
.1567 .02889 L
.15452 .02672 L
.15187 .02406 L
.14969 .02106 L
.14486 .02093 L
.14234 .01923 L
F
0 g
.85766 .01923 m
.85514 .02093 L
.85031 .02106 L
.84813 .02406 L
.84548 .02672 L
.8433 .02889 L
.84065 .03155 L
.83847 .03373 L
.83581 .03639 L
.83364 .03856 L
.83098 .04122 L
.82881 .04339 L
.82615 .04605 L
.82132 .04618 L
.81928 .04822 L
.81649 .05102 L
.81445 .05305 L
.81165 .05585 L
.80961 .05789 L
.80682 .06068 L
.80478 .06272 L
.80199 .06551 L
.79716 .06564 L
.79525 .06755 L
.79233 .07047 L
.79041 .07238 L
.7875 .0753 L
.78558 .07721 L
.78266 .08013 L
.78075 .08204 L
.77783 .08496 L
.77592 .08688 L
.773 .08979 L
.76817 .08992 L
.76637 .09171 L
.76334 .09475 L
.76154 .09654 L
.7585 .09958 L
.75671 .10137 L
.75367 .10441 L
.75187 .1062 L
.74884 .10923 L
.74704 .11104 L
.74401 .11406 L
.73918 .11418 L
.73749 .11587 L
.73434 .11901 L
.73265 .1207 L
.72951 .12384 L
.72781 .12553 L
Mistroke
.72468 .12866 L
.72298 .13036 L
.71985 .13349 L
.71502 .1336 L
.71342 .1352 L
.71019 .13843 L
.70858 .14003 L
.70535 .14325 L
.70375 .14486 L
.70052 .14808 L
.69891 .14969 L
.69569 .1529 L
.69407 .15452 L
.69086 .15773 L
.68603 .15783 L
.6845 .15935 L
.68119 .16266 L
.67966 .16419 L
.67636 .16748 L
.67482 .16902 L
.67153 .1723 L
.66998 .17385 L
.6667 .17712 L
.66513 .17868 L
.66187 .18194 L
.65704 .18204 L
.65556 .18351 L
.6522 .18686 L
.65071 .18835 L
.64737 .19168 L
.64587 .19318 L
.64254 .1965 L
.64102 .19801 L
.63771 .20131 L
.63288 .20141 L
.63143 .20284 L
.62804 .20622 L
.62658 .20767 L
.62321 .21103 L
.62173 .2125 L
.61838 .21585 L
.61688 .21734 L
.61355 .22066 L
.61203 .22217 L
.60872 .22547 L
.60388 .22555 L
.60243 .227 L
.59905 .23036 L
.59757 .23183 L
.59422 .23517 L
Mistroke
.59271 .23666 L
.58939 .23997 L
.58785 .2415 L
.58456 .24477 L
.58299 .24633 L
.57973 .24958 L
.57489 .24965 L
.57337 .25116 L
.57006 .25445 L
.56851 .25599 L
.56523 .25924 L
.56364 .26082 L
.5604 .26404 L
.55877 .26566 L
.55557 .26883 L
.55073 .2689 L
.54913 .27049 L
.5459 .27368 L
.54425 .27532 L
.54107 .27847 L
.53937 .28015 L
.53624 .28325 L
.53449 .28498 L
.53141 .28804 L
.52961 .28981 L
.52658 .29281 L
.52174 .29286 L
.51993 .29465 L
.51691 .29763 L
.51504 .29948 L
.51208 .3024 L
.51014 .30431 L
.50725 .30717 L
.50524 .30914 L
.50242 .31221 L
.49758 .31221 L
.49476 .30914 L
.49275 .30717 L
.48986 .30431 L
.48792 .3024 L
.48496 .29948 L
.48309 .29763 L
.48007 .29465 L
.47826 .29286 L
.47342 .29281 L
.47039 .28981 L
.46859 .28803 L
.46551 .28498 L
.46376 .28325 L
.46063 .28015 L
Mistroke
.45893 .27847 L
.45575 .27532 L
.4541 .27368 L
.45087 .27049 L
.44927 .26889 L
.44443 .26883 L
.44123 .26566 L
.4396 .26404 L
.43636 .26082 L
.43477 .25924 L
.43149 .25599 L
.42994 .25445 L
.42663 .25116 L
.42511 .24965 L
.42027 .24958 L
.41701 .24633 L
.41544 .24477 L
.41215 .2415 L
.41061 .23997 L
.40729 .23666 L
.40578 .23517 L
.40243 .23183 L
.40095 .23036 L
.39757 .227 L
.39612 .22555 L
.39128 .22547 L
.38797 .22217 L
.38645 .22066 L
.38312 .21734 L
.38162 .21585 L
.37827 .2125 L
.37679 .21103 L
.37342 .20767 L
.37196 .20622 L
.36857 .20284 L
.36712 .20141 L
.36229 .20131 L
.35898 .19801 L
.35746 .1965 L
.35413 .19318 L
.35263 .19168 L
.34929 .18835 L
.3478 .18686 L
.34444 .18351 L
.34296 .18204 L
.33813 .18194 L
.33487 .17868 L
.3333 .17712 L
.33002 .17385 L
.32847 .1723 L
Mistroke
.32518 .16902 L
.32364 .16748 L
.32034 .16419 L
.31881 .16266 L
.3155 .15935 L
.31397 .15783 L
.30914 .15773 L
.30593 .15452 L
.30431 .1529 L
.30109 .14969 L
.29948 .14808 L
.29625 .14486 L
.29465 .14325 L
.29142 .14003 L
.28981 .13843 L
.28658 .1352 L
.28498 .1336 L
.28015 .13349 L
.27702 .13036 L
.27532 .12866 L
.27219 .12553 L
.27049 .12384 L
.26735 .1207 L
.26566 .11901 L
.26251 .11587 L
.26082 .11418 L
.25599 .11406 L
.25296 .11104 L
.25116 .10923 L
.24813 .1062 L
.24633 .10441 L
.24329 .10137 L
.2415 .09958 L
.23846 .09654 L
.23666 .09475 L
.23363 .09171 L
.23183 .08992 L
.227 .08979 L
.22408 .08688 L
.22217 .08496 L
.21925 .08204 L
.21734 .08013 L
.21442 .07721 L
.2125 .0753 L
.20959 .07238 L
.20767 .07047 L
.20475 .06755 L
.20284 .06564 L
.19801 .06551 L
.19522 .06272 L
Mistroke
.19318 .06068 L
.19039 .05789 L
.18835 .05585 L
.18555 .05305 L
.18351 .05102 L
.18072 .04822 L
.17868 .04618 L
.17385 .04605 L
.17119 .04339 L
.16902 .04122 L
.16636 .03856 L
.16419 .03639 L
.16153 .03373 L
.15935 .03155 L
.1567 .02889 L
.15452 .02672 L
.15187 .02406 L
.14969 .02106 L
.14486 .02093 L
.14234 .01923 L
Mfstroke
0 .093 .19 r
.85548 .01923 m
.85514 .0194 L
.85031 .01945 L
.84592 .02406 L
.84548 .0245 L
.84108 .02889 L
.84065 .02933 L
.83625 .03373 L
.83581 .03416 L
.83141 .03856 L
.83098 .03899 L
.82658 .04339 L
.82615 .04382 L
.82132 .04392 L
.81701 .04822 L
.81649 .04875 L
.81217 .05305 L
.81165 .05357 L
.80734 .05789 L
.80682 .0584 L
.8025 .06272 L
.80199 .06323 L
.79716 .06332 L
.79293 .06755 L
.79233 .06815 L
.78809 .07238 L
.7875 .07297 L
.78325 .07721 L
.78266 .0778 L
.77841 .08204 L
.77783 .08262 L
.77357 .08688 L
.773 .08745 L
.76817 .08754 L
.76399 .09171 L
.76334 .09236 L
.75915 .09654 L
.7585 .09719 L
.75431 .10137 L
.75367 .10201 L
.74947 .1062 L
.74884 .10684 L
.74463 .11104 L
.74401 .11166 L
.73918 .11174 L
.73504 .11587 L
.73434 .11656 L
.7302 .1207 L
.72951 .12139 L
.72536 .12553 L
.72468 .12621 L
.72052 .13036 L
.71985 .13103 L
.71502 .13111 L
.71092 .1352 L
.71019 .13593 L
.70607 .14003 L
.70535 .14075 L
.70123 .14486 L
.70052 .14556 L
.69638 .14969 L
.69569 .15038 L
.69154 .15452 L
.69086 .1552 L
.68603 .15527 L
.68193 .15935 L
.68119 .16009 L
.67708 .16419 L
.67636 .1649 L
.67223 .16902 L
.67153 .16972 L
.66738 .17385 L
.6667 .17453 L
.66253 .17868 L
.66187 .17935 L
.65704 .17941 L
.65291 .18351 L
.6522 .18422 L
.64806 .18835 L
.64737 .18903 L
.64321 .19318 L
.64254 .19384 L
.63835 .19801 L
.63771 .19865 L
.63288 .19871 L
.62872 .20284 L
.62804 .20352 L
.62387 .20767 L
.62321 .20832 L
.61901 .2125 L
.61838 .21313 L
.61415 .21734 L
.61355 .21793 L
.60928 .22217 L
.60872 .22273 L
.60388 .22278 L
.59964 .227 L
.59905 .22758 L
.59477 .23183 L
.59422 .23238 L
.5899 .23666 L
.58939 .23717 L
.58503 .2415 L
.58456 .24197 L
.58016 .24633 L
.57973 .24676 L
.57489 .2468 L
.57049 .25116 L
.57006 .25159 L
.56561 .25599 L
.56523 .25637 L
.56073 .26082 L
.5604 .26115 L
.55585 .26566 L
.55557 .26593 L
.55073 .26596 L
.54616 .27049 L
.5459 .27074 L
.54126 .27532 L
.54107 .27551 L
.53636 .28015 L
.53624 .28027 L
.53146 .28498 L
.53141 .28504 L
.52658 .28976 L
.52174 .2898 L
.51927 .28981 L
.51691 .29441 L
.51208 .29059 L
.50725 .29092 L
.50242 .29108 L
.49758 .29108 L
.49275 .29092 L
.48792 .2906 L
.48309 .29441 L
.4807 .28981 L
.47826 .2898 L
.47342 .28976 L
.46859 .28504 L
.46854 .28498 L
.46376 .28027 L
.46364 .28015 L
.45893 .27551 L
.45874 .27532 L
.4541 .27074 L
.45384 .27049 L
.44927 .26596 L
.44443 .26593 L
.44415 .26566 L
.4396 .26115 L
.43927 .26082 L
.43477 .25637 L
.43439 .25599 L
.42994 .25159 L
.42951 .25116 L
.42511 .2468 L
.42027 .24676 L
.41984 .24633 L
.41544 .24197 L
.41497 .2415 L
.41061 .23717 L
.4101 .23666 L
.40578 .23238 L
.40523 .23183 L
.40095 .22758 L
.40036 .227 L
.39612 .22278 L
.39128 .22273 L
.39072 .22217 L
.38645 .21793 L
.38585 .21734 L
.38162 .21313 L
.38099 .2125 L
.37679 .20832 L
.37613 .20767 L
.37196 .20352 L
.37128 .20284 L
.36712 .19871 L
.36229 .19865 L
.36165 .19801 L
.35746 .19384 L
.35679 .19318 L
.35263 .18903 L
.35194 .18835 L
.3478 .18422 L
.34708 .18351 L
.34296 .17941 L
.33813 .17935 L
.33747 .17868 L
.3333 .17453 L
.33262 .17385 L
.32847 .16972 L
.32777 .16902 L
.32364 .1649 L
.32292 .16419 L
.31881 .16009 L
.31807 .15935 L
.31397 .15527 L
.30914 .1552 L
.30846 .15452 L
.30431 .15038 L
.30362 .14969 L
.29948 .14556 L
.29877 .14486 L
.29465 .14075 L
.29393 .14003 L
.28981 .13593 L
.28908 .1352 L
.28498 .13111 L
.28015 .13103 L
.27948 .13036 L
.27532 .12621 L
.27464 .12553 L
.27049 .12139 L
.2698 .1207 L
.26566 .11656 L
.26496 .11587 L
.26082 .11174 L
.25599 .11166 L
.25537 .11104 L
.25116 .10684 L
.25053 .1062 L
.24633 .10201 L
.24569 .10137 L
.2415 .09719 L
.24085 .09654 L
.23666 .09236 L
.23601 .09171 L
.23183 .08754 L
.227 .08745 L
.22643 .08688 L
.22217 .08263 L
.22159 .08204 L
.21734 .0778 L
.21675 .07721 L
.2125 .07297 L
.21191 .07238 L
.20767 .06815 L
.20707 .06755 L
.20284 .06332 L
.19801 .06323 L
.1975 .06272 L
.19318 .0584 L
.19266 .05789 L
.18835 .05357 L
.18783 .05305 L
.18351 .04875 L
.18299 .04822 L
.17868 .04392 L
.17385 .04382 L
.17342 .04339 L
.16902 .03899 L
.16859 .03856 L
.16419 .03416 L
.16375 .03373 L
.15935 .02933 L
.15892 .02889 L
.15452 .0245 L
.15408 .02406 L
.14969 .01945 L
.14486 .0194 L
.14452 .01923 L
F
0 g
.85548 .01923 m
.85514 .0194 L
.85031 .01945 L
.84592 .02406 L
.84548 .0245 L
.84108 .02889 L
.84065 .02933 L
.83625 .03373 L
.83581 .03416 L
.83141 .03856 L
.83098 .03899 L
.82658 .04339 L
.82615 .04382 L
.82132 .04392 L
.81701 .04822 L
.81649 .04875 L
.81217 .05305 L
.81165 .05357 L
.80734 .05789 L
.80682 .0584 L
.8025 .06272 L
.80199 .06323 L
.79716 .06332 L
.79293 .06755 L
.79233 .06815 L
.78809 .07238 L
.7875 .07297 L
.78325 .07721 L
.78266 .0778 L
.77841 .08204 L
.77783 .08262 L
.77357 .08688 L
.773 .08745 L
.76817 .08754 L
.76399 .09171 L
.76334 .09236 L
.75915 .09654 L
.7585 .09719 L
.75431 .10137 L
.75367 .10201 L
.74947 .1062 L
.74884 .10684 L
.74463 .11104 L
.74401 .11166 L
.73918 .11174 L
.73504 .11587 L
.73434 .11656 L
.7302 .1207 L
.72951 .12139 L
.72536 .12553 L
Mistroke
.72468 .12621 L
.72052 .13036 L
.71985 .13103 L
.71502 .13111 L
.71092 .1352 L
.71019 .13593 L
.70607 .14003 L
.70535 .14075 L
.70123 .14486 L
.70052 .14556 L
.69638 .14969 L
.69569 .15038 L
.69154 .15452 L
.69086 .1552 L
.68603 .15527 L
.68193 .15935 L
.68119 .16009 L
.67708 .16419 L
.67636 .1649 L
.67223 .16902 L
.67153 .16972 L
.66738 .17385 L
.6667 .17453 L
.66253 .17868 L
.66187 .17935 L
.65704 .17941 L
.65291 .18351 L
.6522 .18422 L
.64806 .18835 L
.64737 .18903 L
.64321 .19318 L
.64254 .19384 L
.63835 .19801 L
.63771 .19865 L
.63288 .19871 L
.62872 .20284 L
.62804 .20352 L
.62387 .20767 L
.62321 .20832 L
.61901 .2125 L
.61838 .21313 L
.61415 .21734 L
.61355 .21793 L
.60928 .22217 L
.60872 .22273 L
.60388 .22278 L
.59964 .227 L
.59905 .22758 L
.59477 .23183 L
.59422 .23238 L
Mistroke
.5899 .23666 L
.58939 .23717 L
.58503 .2415 L
.58456 .24197 L
.58016 .24633 L
.57973 .24676 L
.57489 .2468 L
.57049 .25116 L
.57006 .25159 L
.56561 .25599 L
.56523 .25637 L
.56073 .26082 L
.5604 .26115 L
.55585 .26566 L
.55557 .26593 L
.55073 .26596 L
.54616 .27049 L
.5459 .27074 L
.54126 .27532 L
.54107 .27551 L
.53636 .28015 L
.53624 .28027 L
.53146 .28498 L
.53141 .28504 L
.52658 .28976 L
.52174 .2898 L
.51927 .28981 L
.51691 .29441 L
.51208 .29059 L
.50725 .29092 L
.50242 .29108 L
.49758 .29108 L
.49275 .29092 L
.48792 .2906 L
.48309 .29441 L
.4807 .28981 L
.47826 .2898 L
.47342 .28976 L
.46859 .28504 L
.46854 .28498 L
.46376 .28027 L
.46364 .28015 L
.45893 .27551 L
.45874 .27532 L
.4541 .27074 L
.45384 .27049 L
.44927 .26596 L
.44443 .26593 L
.44415 .26566 L
.4396 .26115 L
Mistroke
.43927 .26082 L
.43477 .25637 L
.43439 .25599 L
.42994 .25159 L
.42951 .25116 L
.42511 .2468 L
.42027 .24676 L
.41984 .24633 L
.41544 .24197 L
.41497 .2415 L
.41061 .23717 L
.4101 .23666 L
.40578 .23238 L
.40523 .23183 L
.40095 .22758 L
.40036 .227 L
.39612 .22278 L
.39128 .22273 L
.39072 .22217 L
.38645 .21793 L
.38585 .21734 L
.38162 .21313 L
.38099 .2125 L
.37679 .20832 L
.37613 .20767 L
.37196 .20352 L
.37128 .20284 L
.36712 .19871 L
.36229 .19865 L
.36165 .19801 L
.35746 .19384 L
.35679 .19318 L
.35263 .18903 L
.35194 .18835 L
.3478 .18422 L
.34708 .18351 L
.34296 .17941 L
.33813 .17935 L
.33747 .17868 L
.3333 .17453 L
.33262 .17385 L
.32847 .16972 L
.32777 .16902 L
.32364 .1649 L
.32292 .16419 L
.31881 .16009 L
.31807 .15935 L
.31397 .15527 L
.30914 .1552 L
.30846 .15452 L
Mistroke
.30431 .15038 L
.30362 .14969 L
.29948 .14556 L
.29877 .14486 L
.29465 .14075 L
.29393 .14003 L
.28981 .13593 L
.28908 .1352 L
.28498 .13111 L
.28015 .13103 L
.27948 .13036 L
.27532 .12621 L
.27464 .12553 L
.27049 .12139 L
.2698 .1207 L
.26566 .11656 L
.26496 .11587 L
.26082 .11174 L
.25599 .11166 L
.25537 .11104 L
.25116 .10684 L
.25053 .1062 L
.24633 .10201 L
.24569 .10137 L
.2415 .09719 L
.24085 .09654 L
.23666 .09236 L
.23601 .09171 L
.23183 .08754 L
.227 .08745 L
.22643 .08688 L
.22217 .08263 L
.22159 .08204 L
.21734 .0778 L
.21675 .07721 L
.2125 .07297 L
.21191 .07238 L
.20767 .06815 L
.20707 .06755 L
.20284 .06332 L
.19801 .06323 L
.1975 .06272 L
.19318 .0584 L
.19266 .05789 L
.18835 .05357 L
.18783 .05305 L
.18351 .04875 L
.18299 .04822 L
.17868 .04392 L
.17385 .04382 L
Mistroke
.17342 .04339 L
.16902 .03899 L
.16859 .03856 L
.16419 .03416 L
.16375 .03373 L
.15935 .02933 L
.15892 .02889 L
.15452 .0245 L
.15408 .02406 L
.14969 .01945 L
.14486 .0194 L
.14452 .01923 L
Mfstroke
.282 .64 0 r
.98077 .02187 m
.98 .02406 L
.97594 .02733 L
.97413 .02889 L
.97111 .03192 L
.96909 .03373 L
.96627 .03653 L
.96406 .03856 L
.96144 .04116 L
.95904 .04339 L
.96066 .04822 L
.95661 .05227 L
.95537 .05305 L
.95178 .05664 L
.95021 .05789 L
.94695 .06115 L
.94511 .06272 L
.94211 .06571 L
.94005 .06755 L
.93728 .0703 L
.935 .07238 L
.93681 .07721 L
.93245 .08157 L
.93134 .08204 L
.92762 .08577 L
.92613 .08688 L
.92279 .09021 L
.921 .09171 L
.91796 .09474 L
.9159 .09654 L
.91312 .09931 L
.91084 .10137 L
.91248 .1062 L
.90829 .11039 L
.90707 .11104 L
.90346 .11464 L
.90186 .11587 L
.89863 .11909 L
.89673 .1207 L
.8938 .12362 L
.89163 .12553 L
.89365 .13036 L
.88896 .13505 L
.88788 .1352 L
.88413 .13894 L
.88262 .14003 L
.8793 .14333 L
.87745 .14486 L
.87447 .14783 L
.87234 .14969 L
.87426 .15452 L
.86964 .15915 L
.86852 .15935 L
.8648 .16306 L
.86324 .16419 L
.85997 .16745 L
.85807 .16902 L
.85514 .17194 L
.85295 .17385 L
.85446 .17868 L
.85031 .18283 L
.849 .18351 L
.84548 .18703 L
.84376 .18835 L
.84065 .19145 L
.8386 .19318 L
.83581 .19595 L
.83349 .19801 L
.83469 .20284 L
.83098 .20655 L
.82939 .20767 L
.82615 .2109 L
.8242 .2125 L
.82132 .21537 L
.81906 .21734 L
.82029 .22217 L
.81649 .22596 L
.81494 .227 L
.81165 .23027 L
.80973 .23183 L
.80682 .23473 L
.80458 .23666 L
.80577 .2415 L
.80199 .24526 L
.80041 .24633 L
.79716 .24957 L
.7952 .25116 L
.79233 .25402 L
.79005 .25599 L
.79114 .26082 L
.7875 .26445 L
.78581 .26566 L
.78266 .26879 L
.78061 .27049 L
.78196 .27532 L
.77783 .27944 L
.77643 .28015 L
.773 .28357 L
.77116 .28498 L
.76817 .28796 L
.76597 .28981 L
.76705 .29465 L
.76334 .29835 L
.76169 .29948 L
.7585 .30265 L
.75646 .30431 L
.75768 .30914 L
.75367 .31314 L
.75219 .31397 L
.74884 .31731 L
.74692 .31881 L
.74833 .32364 L
.74401 .32795 L
.74266 .32847 L
.73918 .33194 L
.73735 .3333 L
.73434 .33629 L
.73214 .33813 L
.73308 .34296 L
.72951 .34652 L
.72774 .3478 L
.72468 .35084 L
.72252 .35263 L
.72345 .35746 L
.71985 .36105 L
.71809 .36229 L
.71502 .36535 L
.71286 .36712 L
.71377 .37196 L
.71019 .37552 L
.70841 .37679 L
.70987 .38162 L
.70535 .38614 L
.70403 .38645 L
.70052 .38994 L
.69868 .39128 L
.69988 .39612 L
.69569 .4003 L
.69425 .40095 L
.69086 .40432 L
.68893 .40578 L
.68993 .41061 L
.68603 .41451 L
.68444 .41544 L
.68119 .41867 L
.67915 .42027 L
.68 .42511 L
.67636 .42873 L
.6746 .42994 L
.67575 .43477 L
.67153 .43899 L
.67008 .4396 L
.6667 .44297 L
.66475 .44443 L
.66564 .44927 L
.66187 .45311 L
.66034 .4541 L
.66137 .45893 L
.65704 .46326 L
.65574 .46376 L
.6522 .46729 L
.65046 .46859 L
.65118 .47342 L
.64737 .47722 L
.64581 .47826 L
.64667 .48309 L
.64254 .48721 L
.64116 .48792 L
.64246 .49275 L
.63771 .4975 L
.63651 .49758 L
.63288 .5012 L
.6312 .50242 L
.63186 .50725 L
.62804 .51105 L
.6265 .51208 L
.62722 .51691 L
.62321 .52091 L
.62178 .52174 L
.62259 .52658 L
.61838 .53078 L
.61705 .53141 L
.61799 .53624 L
.61355 .54068 L
.61231 .54107 L
.60872 .54464 L
.60703 .5459 L
.60755 .55073 L
.60388 .55438 L
.60225 .55557 L
.60277 .5604 L
.59905 .5641 L
.59746 .56523 L
.59797 .57006 L
.59422 .57379 L
.59265 .57489 L
.59315 .57973 L
.58939 .58347 L
.58783 .58456 L
.58831 .58939 L
.58456 .59313 L
.583 .59422 L
.58345 .59905 L
.58442 .60388 L
.57973 .60858 L
.57858 .60872 L
.57931 .61355 L
.57489 .61796 L
.5737 .61838 L
.57429 .62321 L
.57006 .62743 L
.5688 .62804 L
.5693 .63288 L
.56523 .63694 L
.56391 .63771 L
.56433 .64254 L
.5604 .64646 L
.55901 .64737 L
.55937 .6522 L
.55996 .65704 L
.55557 .66142 L
.55442 .66187 L
.55485 .6667 L
.55073 .67081 L
.54949 .67153 L
.54983 .67636 L
.55041 .68119 L
.5459 .6857 L
.54484 .68603 L
.54522 .69086 L
.54107 .69499 L
.53989 .69569 L
.54017 .70052 L
.54058 .70535 L
.53624 .70969 L
.53519 .71019 L
.53546 .71502 L
.53589 .71985 L
.53141 .72433 L
.53045 .72468 L
.53071 .72951 L
.53111 .73434 L
.52658 .73888 L
.5257 .73918 L
.52592 .74401 L
.52624 .74884 L
.52174 .75334 L
.52093 .75367 L
.52111 .7585 L
.52133 .76334 L
.51691 .76778 L
.51618 .76817 L
.51631 .773 L
.51646 .77783 L
.51666 .78266 L
.51208 .78728 L
.51158 .7875 L
.51168 .79233 L
.51178 .79716 L
.5119 .80199 L
.50725 .80673 L
.50707 .80682 L
.50714 .81165 L
.5072 .81649 L
.50725 .82081 L
.50726 .82132 L
.50734 .82615 L
.50735 .83098 L
.51051 .83581 L
.51153 .84065 L
.51208 .84331 L
.51248 .84548 L
.51336 .85031 L
.51421 .85514 L
.51503 .85997 L
.51582 .8648 L
.51656 .86964 L
.51691 .87203 L
.51724 .87447 L
.51785 .8793 L
.51841 .88413 L
.51892 .88896 L
.51938 .8938 L
.51978 .89863 L
.52012 .90346 L
.52039 .90829 L
.52059 .91312 L
.52072 .91796 L
.52076 .92279 L
.52072 .92762 L
.52059 .93245 L
.52035 .93728 L
.52001 .94211 L
.51954 .94695 L
.51893 .95178 L
.51817 .95661 L
.51721 .96144 L
.51691 .96277 L
.51604 .96627 L
.51457 .97111 L
.51266 .97594 L
.51208 .97716 L
.51029 .98077 L
.98077 .98077 L
F
0 g
.98077 .02187 m
.98 .02406 L
.97594 .02733 L
.97413 .02889 L
.97111 .03192 L
.96909 .03373 L
.96627 .03653 L
.96406 .03856 L
.96144 .04116 L
.95904 .04339 L
.96066 .04822 L
.95661 .05227 L
.95537 .05305 L
.95178 .05664 L
.95021 .05789 L
.94695 .06115 L
.94511 .06272 L
.94211 .06571 L
.94005 .06755 L
.93728 .0703 L
.935 .07238 L
.93681 .07721 L
.93245 .08157 L
.93134 .08204 L
.92762 .08577 L
.92613 .08688 L
.92279 .09021 L
.921 .09171 L
.91796 .09474 L
.9159 .09654 L
.91312 .09931 L
.91084 .10137 L
.91248 .1062 L
.90829 .11039 L
.90707 .11104 L
.90346 .11464 L
.90186 .11587 L
.89863 .11909 L
.89673 .1207 L
.8938 .12362 L
.89163 .12553 L
.89365 .13036 L
.88896 .13505 L
.88788 .1352 L
.88413 .13894 L
.88262 .14003 L
.8793 .14333 L
.87745 .14486 L
.87447 .14783 L
.87234 .14969 L
Mistroke
.87426 .15452 L
.86964 .15915 L
.86852 .15935 L
.8648 .16306 L
.86324 .16419 L
.85997 .16745 L
.85807 .16902 L
.85514 .17194 L
.85295 .17385 L
.85446 .17868 L
.85031 .18283 L
.849 .18351 L
.84548 .18703 L
.84376 .18835 L
.84065 .19145 L
.8386 .19318 L
.83581 .19595 L
.83349 .19801 L
.83469 .20284 L
.83098 .20655 L
.82939 .20767 L
.82615 .2109 L
.8242 .2125 L
.82132 .21537 L
.81906 .21734 L
.82029 .22217 L
.81649 .22596 L
.81494 .227 L
.81165 .23027 L
.80973 .23183 L
.80682 .23473 L
.80458 .23666 L
.80577 .2415 L
.80199 .24526 L
.80041 .24633 L
.79716 .24957 L
.7952 .25116 L
.79233 .25402 L
.79005 .25599 L
.79114 .26082 L
.7875 .26445 L
.78581 .26566 L
.78266 .26879 L
.78061 .27049 L
.78196 .27532 L
.77783 .27944 L
.77643 .28015 L
.773 .28357 L
.77116 .28498 L
.76817 .28796 L
Mistroke
.76597 .28981 L
.76705 .29465 L
.76334 .29835 L
.76169 .29948 L
.7585 .30265 L
.75646 .30431 L
.75768 .30914 L
.75367 .31314 L
.75219 .31397 L
.74884 .31731 L
.74692 .31881 L
.74833 .32364 L
.74401 .32795 L
.74266 .32847 L
.73918 .33194 L
.73735 .3333 L
.73434 .33629 L
.73214 .33813 L
.73308 .34296 L
.72951 .34652 L
.72774 .3478 L
.72468 .35084 L
.72252 .35263 L
.72345 .35746 L
.71985 .36105 L
.71809 .36229 L
.71502 .36535 L
.71286 .36712 L
.71377 .37196 L
.71019 .37552 L
.70841 .37679 L
.70987 .38162 L
.70535 .38614 L
.70403 .38645 L
.70052 .38994 L
.69868 .39128 L
.69988 .39612 L
.69569 .4003 L
.69425 .40095 L
.69086 .40432 L
.68893 .40578 L
.68993 .41061 L
.68603 .41451 L
.68444 .41544 L
.68119 .41867 L
.67915 .42027 L
.68 .42511 L
.67636 .42873 L
.6746 .42994 L
.67575 .43477 L
Mistroke
.67153 .43899 L
.67008 .4396 L
.6667 .44297 L
.66475 .44443 L
.66564 .44927 L
.66187 .45311 L
.66034 .4541 L
.66137 .45893 L
.65704 .46326 L
.65574 .46376 L
.6522 .46729 L
.65046 .46859 L
.65118 .47342 L
.64737 .47722 L
.64581 .47826 L
.64667 .48309 L
.64254 .48721 L
.64116 .48792 L
.64246 .49275 L
.63771 .4975 L
.63651 .49758 L
.63288 .5012 L
.6312 .50242 L
.63186 .50725 L
.62804 .51105 L
.6265 .51208 L
.62722 .51691 L
.62321 .52091 L
.62178 .52174 L
.62259 .52658 L
.61838 .53078 L
.61705 .53141 L
.61799 .53624 L
.61355 .54068 L
.61231 .54107 L
.60872 .54464 L
.60703 .5459 L
.60755 .55073 L
.60388 .55438 L
.60225 .55557 L
.60277 .5604 L
.59905 .5641 L
.59746 .56523 L
.59797 .57006 L
.59422 .57379 L
.59265 .57489 L
.59315 .57973 L
.58939 .58347 L
.58783 .58456 L
.58831 .58939 L
Mistroke
.58456 .59313 L
.583 .59422 L
.58345 .59905 L
.58442 .60388 L
.57973 .60858 L
.57858 .60872 L
.57931 .61355 L
.57489 .61796 L
.5737 .61838 L
.57429 .62321 L
.57006 .62743 L
.5688 .62804 L
.5693 .63288 L
.56523 .63694 L
.56391 .63771 L
.56433 .64254 L
.5604 .64646 L
.55901 .64737 L
.55937 .6522 L
.55996 .65704 L
.55557 .66142 L
.55442 .66187 L
.55485 .6667 L
.55073 .67081 L
.54949 .67153 L
.54983 .67636 L
.55041 .68119 L
.5459 .6857 L
.54484 .68603 L
.54522 .69086 L
.54107 .69499 L
.53989 .69569 L
.54017 .70052 L
.54058 .70535 L
.53624 .70969 L
.53519 .71019 L
.53546 .71502 L
.53589 .71985 L
.53141 .72433 L
.53045 .72468 L
.53071 .72951 L
.53111 .73434 L
.52658 .73888 L
.5257 .73918 L
.52592 .74401 L
.52624 .74884 L
.52174 .75334 L
.52093 .75367 L
.52111 .7585 L
.52133 .76334 L
Mistroke
.51691 .76778 L
.51618 .76817 L
.51631 .773 L
.51646 .77783 L
.51666 .78266 L
.51208 .78728 L
.51158 .7875 L
.51168 .79233 L
.51178 .79716 L
.5119 .80199 L
.50725 .80673 L
.50707 .80682 L
.50714 .81165 L
.5072 .81649 L
.50725 .82081 L
.50726 .82132 L
.50734 .82615 L
.50735 .83098 L
.51051 .83581 L
.51153 .84065 L
.51208 .84331 L
.51248 .84548 L
.51336 .85031 L
.51421 .85514 L
.51503 .85997 L
.51582 .8648 L
.51656 .86964 L
.51691 .87203 L
.51724 .87447 L
.51785 .8793 L
.51841 .88413 L
.51892 .88896 L
.51938 .8938 L
.51978 .89863 L
.52012 .90346 L
.52039 .90829 L
.52059 .91312 L
.52072 .91796 L
.52076 .92279 L
.52072 .92762 L
.52059 .93245 L
.52035 .93728 L
.52001 .94211 L
.51954 .94695 L
.51893 .95178 L
.51817 .95661 L
.51721 .96144 L
.51691 .96277 L
.51604 .96627 L
.51457 .97111 L
Mistroke
.51266 .97594 L
.51208 .97716 L
.51029 .98077 L
Mfstroke
.146 .595 0 r
.98077 .02199 m
.98007 .02406 L
.97594 .02744 L
.97426 .02889 L
.97111 .03205 L
.96923 .03373 L
.96627 .03668 L
.96422 .03856 L
.96144 .04133 L
.95921 .04339 L
.96071 .04822 L
.95661 .05232 L
.95546 .05305 L
.95178 .05673 L
.95033 .05789 L
.94695 .06126 L
.94525 .06272 L
.94211 .06584 L
.94019 .06755 L
.93728 .07045 L
.93517 .07238 L
.93685 .07721 L
.93245 .08161 L
.93142 .08204 L
.92762 .08585 L
.92624 .08688 L
.92279 .09032 L
.92112 .09171 L
.91796 .09487 L
.91605 .09654 L
.91312 .09946 L
.91101 .10137 L
.91253 .1062 L
.90829 .11044 L
.90716 .11104 L
.90346 .11473 L
.90198 .11587 L
.89863 .11921 L
.89686 .1207 L
.8938 .12376 L
.89179 .12553 L
.89366 .13036 L
.88896 .13506 L
.88796 .1352 L
.88413 .13902 L
.88272 .14003 L
.8793 .14344 L
.87758 .14486 L
.87447 .14796 L
.87249 .14969 L
.87428 .15452 L
.86964 .15916 L
.8686 .15935 L
.8648 .16314 L
.86336 .16419 L
.85997 .16756 L
.85821 .16902 L
.85514 .17208 L
.85311 .17385 L
.85451 .17868 L
.85031 .18288 L
.84909 .18351 L
.84548 .18712 L
.84388 .18835 L
.84065 .19157 L
.83875 .19318 L
.83581 .1961 L
.83366 .19801 L
.83477 .20284 L
.83098 .20663 L
.8295 .20767 L
.82615 .21101 L
.82434 .2125 L
.82132 .21551 L
.81923 .21734 L
.82036 .22217 L
.81649 .22604 L
.81505 .227 L
.81165 .23039 L
.80987 .23183 L
.80682 .23486 L
.80474 .23666 L
.80584 .2415 L
.80199 .24534 L
.80053 .24633 L
.79716 .24968 L
.79534 .25116 L
.79233 .25416 L
.79021 .25599 L
.79122 .26082 L
.7875 .26454 L
.78593 .26566 L
.78266 .26891 L
.78076 .27049 L
.78201 .27532 L
.77783 .27949 L
.77653 .28015 L
.773 .28367 L
.77129 .28498 L
.76817 .28809 L
.76613 .28981 L
.76713 .29465 L
.76334 .29843 L
.7618 .29948 L
.7585 .30277 L
.75661 .30431 L
.75774 .30914 L
.75367 .3132 L
.7523 .31397 L
.74884 .31742 L
.74706 .31881 L
.74837 .32364 L
.74401 .32799 L
.74276 .32847 L
.73918 .33204 L
.73748 .3333 L
.73434 .33642 L
.7323 .33813 L
.73317 .34296 L
.72951 .34661 L
.72787 .3478 L
.72468 .35097 L
.72267 .35263 L
.72354 .35746 L
.71985 .36114 L
.71822 .36229 L
.71502 .36548 L
.71302 .36712 L
.71386 .37196 L
.71019 .37561 L
.70853 .37679 L
.7099 .38162 L
.70535 .38616 L
.70412 .38645 L
.70052 .39004 L
.69882 .39128 L
.69993 .39612 L
.69569 .40035 L
.69435 .40095 L
.69086 .40442 L
.68907 .40578 L
.69 .41061 L
.68603 .41457 L
.68455 .41544 L
.68119 .41878 L
.6793 .42027 L
.68009 .42511 L
.67636 .42882 L
.67473 .42994 L
.6758 .43477 L
.67153 .43903 L
.67019 .4396 L
.6667 .44307 L
.66489 .44443 L
.66572 .44927 L
.66187 .45319 L
.66046 .4541 L
.66142 .45893 L
.65704 .46331 L
.65585 .46376 L
.6522 .46739 L
.6506 .46859 L
.65126 .47342 L
.64737 .4773 L
.64594 .47826 L
.64673 .48309 L
.64254 .48727 L
.64127 .48792 L
.64246 .49275 L
.63771 .49751 L
.63661 .49758 L
.63288 .5013 L
.63134 .50242 L
.63195 .50725 L
.62804 .51114 L
.62662 .51208 L
.62729 .51691 L
.62321 .52098 L
.6219 .52174 L
.62264 .52658 L
.61838 .53083 L
.61716 .53141 L
.61802 .53624 L
.61355 .54071 L
.61241 .54107 L
.60872 .54475 L
.60717 .5459 L
.60764 .55073 L
.60388 .55448 L
.60238 .55557 L
.60286 .5604 L
.59905 .56419 L
.59759 .56523 L
.59806 .57006 L
.59422 .57389 L
.59278 .57489 L
.59324 .57973 L
.58939 .58356 L
.58797 .58456 L
.5884 .58939 L
.58456 .59322 L
.58314 .59422 L
.58355 .59905 L
.58443 .60388 L
.57973 .60859 L
.57868 .60872 L
.57935 .61355 L
.57489 .618 L
.5738 .61838 L
.57435 .62321 L
.57006 .62749 L
.56892 .62804 L
.56937 .63288 L
.56523 .63701 L
.56403 .63771 L
.56441 .64254 L
.5604 .64654 L
.55913 .64737 L
.55946 .6522 L
.56 .65704 L
.55557 .66147 L
.55453 .66187 L
.55492 .6667 L
.55073 .67087 L
.5496 .67153 L
.54991 .67636 L
.55044 .68119 L
.5459 .68573 L
.54494 .68603 L
.54528 .69086 L
.54107 .69506 L
.54 .69569 L
.54026 .70052 L
.54063 .70535 L
.53624 .70974 L
.53529 .71019 L
.53554 .71502 L
.53593 .71985 L
.53141 .72437 L
.53056 .72468 L
.53079 .72951 L
.53114 .73434 L
.52658 .73892 L
.5258 .73918 L
.526 .74401 L
.52628 .74884 L
.52174 .75338 L
.52103 .75367 L
.52119 .7585 L
.52139 .76334 L
.51691 .76783 L
.51628 .76817 L
.5164 .773 L
.51653 .77783 L
.5167 .78266 L
.51208 .78732 L
.51167 .7875 L
.51176 .79233 L
.51185 .79716 L
.51194 .80199 L
.50725 .80678 L
.50716 .80682 L
.50722 .81165 L
.50725 .81402 L
.50731 .81649 L
.50741 .82132 L
.50746 .82615 L
.50741 .83098 L
.51208 .83481 L
.51229 .83581 L
.51328 .84065 L
.51425 .84548 L
.51519 .85031 L
.51609 .85514 L
.51691 .85968 L
.51696 .85997 L
.51775 .8648 L
.5185 .86964 L
.51921 .87447 L
.51988 .8793 L
.5205 .88413 L
.52107 .88896 L
.52159 .8938 L
.52174 .89538 L
.52204 .89863 L
.52243 .90346 L
.52276 .90829 L
.52302 .91312 L
.52322 .91796 L
.52335 .92279 L
.5234 .92762 L
.52337 .93245 L
.52326 .93728 L
.52305 .94211 L
.52274 .94695 L
.52231 .95178 L
.52176 .95661 L
.52174 .95676 L
.52107 .96144 L
.52022 .96627 L
.51917 .97111 L
.5179 .97594 L
.51691 .97907 L
.51633 .98077 L
.98077 .98077 L
F
0 g
.98077 .02199 m
.98007 .02406 L
.97594 .02744 L
.97426 .02889 L
.97111 .03205 L
.96923 .03373 L
.96627 .03668 L
.96422 .03856 L
.96144 .04133 L
.95921 .04339 L
.96071 .04822 L
.95661 .05232 L
.95546 .05305 L
.95178 .05673 L
.95033 .05789 L
.94695 .06126 L
.94525 .06272 L
.94211 .06584 L
.94019 .06755 L
.93728 .07045 L
.93517 .07238 L
.93685 .07721 L
.93245 .08161 L
.93142 .08204 L
.92762 .08585 L
.92624 .08688 L
.92279 .09032 L
.92112 .09171 L
.91796 .09487 L
.91605 .09654 L
.91312 .09946 L
.91101 .10137 L
.91253 .1062 L
.90829 .11044 L
.90716 .11104 L
.90346 .11473 L
.90198 .11587 L
.89863 .11921 L
.89686 .1207 L
.8938 .12376 L
.89179 .12553 L
.89366 .13036 L
.88896 .13506 L
.88796 .1352 L
.88413 .13902 L
.88272 .14003 L
.8793 .14344 L
.87758 .14486 L
.87447 .14796 L
.87249 .14969 L
Mistroke
.87428 .15452 L
.86964 .15916 L
.8686 .15935 L
.8648 .16314 L
.86336 .16419 L
.85997 .16756 L
.85821 .16902 L
.85514 .17208 L
.85311 .17385 L
.85451 .17868 L
.85031 .18288 L
.84909 .18351 L
.84548 .18712 L
.84388 .18835 L
.84065 .19157 L
.83875 .19318 L
.83581 .1961 L
.83366 .19801 L
.83477 .20284 L
.83098 .20663 L
.8295 .20767 L
.82615 .21101 L
.82434 .2125 L
.82132 .21551 L
.81923 .21734 L
.82036 .22217 L
.81649 .22604 L
.81505 .227 L
.81165 .23039 L
.80987 .23183 L
.80682 .23486 L
.80474 .23666 L
.80584 .2415 L
.80199 .24534 L
.80053 .24633 L
.79716 .24968 L
.79534 .25116 L
.79233 .25416 L
.79021 .25599 L
.79122 .26082 L
.7875 .26454 L
.78593 .26566 L
.78266 .26891 L
.78076 .27049 L
.78201 .27532 L
.77783 .27949 L
.77653 .28015 L
.773 .28367 L
.77129 .28498 L
.76817 .28809 L
Mistroke
.76613 .28981 L
.76713 .29465 L
.76334 .29843 L
.7618 .29948 L
.7585 .30277 L
.75661 .30431 L
.75774 .30914 L
.75367 .3132 L
.7523 .31397 L
.74884 .31742 L
.74706 .31881 L
.74837 .32364 L
.74401 .32799 L
.74276 .32847 L
.73918 .33204 L
.73748 .3333 L
.73434 .33642 L
.7323 .33813 L
.73317 .34296 L
.72951 .34661 L
.72787 .3478 L
.72468 .35097 L
.72267 .35263 L
.72354 .35746 L
.71985 .36114 L
.71822 .36229 L
.71502 .36548 L
.71302 .36712 L
.71386 .37196 L
.71019 .37561 L
.70853 .37679 L
.7099 .38162 L
.70535 .38616 L
.70412 .38645 L
.70052 .39004 L
.69882 .39128 L
.69993 .39612 L
.69569 .40035 L
.69435 .40095 L
.69086 .40442 L
.68907 .40578 L
.69 .41061 L
.68603 .41457 L
.68455 .41544 L
.68119 .41878 L
.6793 .42027 L
.68009 .42511 L
.67636 .42882 L
.67473 .42994 L
.6758 .43477 L
Mistroke
.67153 .43903 L
.67019 .4396 L
.6667 .44307 L
.66489 .44443 L
.66572 .44927 L
.66187 .45319 L
.66046 .4541 L
.66142 .45893 L
.65704 .46331 L
.65585 .46376 L
.6522 .46739 L
.6506 .46859 L
.65126 .47342 L
.64737 .4773 L
.64594 .47826 L
.64673 .48309 L
.64254 .48727 L
.64127 .48792 L
.64246 .49275 L
.63771 .49751 L
.63661 .49758 L
.63288 .5013 L
.63134 .50242 L
.63195 .50725 L
.62804 .51114 L
.62662 .51208 L
.62729 .51691 L
.62321 .52098 L
.6219 .52174 L
.62264 .52658 L
.61838 .53083 L
.61716 .53141 L
.61802 .53624 L
.61355 .54071 L
.61241 .54107 L
.60872 .54475 L
.60717 .5459 L
.60764 .55073 L
.60388 .55448 L
.60238 .55557 L
.60286 .5604 L
.59905 .56419 L
.59759 .56523 L
.59806 .57006 L
.59422 .57389 L
.59278 .57489 L
.59324 .57973 L
.58939 .58356 L
.58797 .58456 L
.5884 .58939 L
Mistroke
.58456 .59322 L
.58314 .59422 L
.58355 .59905 L
.58443 .60388 L
.57973 .60859 L
.57868 .60872 L
.57935 .61355 L
.57489 .618 L
.5738 .61838 L
.57435 .62321 L
.57006 .62749 L
.56892 .62804 L
.56937 .63288 L
.56523 .63701 L
.56403 .63771 L
.56441 .64254 L
.5604 .64654 L
.55913 .64737 L
.55946 .6522 L
.56 .65704 L
.55557 .66147 L
.55453 .66187 L
.55492 .6667 L
.55073 .67087 L
.5496 .67153 L
.54991 .67636 L
.55044 .68119 L
.5459 .68573 L
.54494 .68603 L
.54528 .69086 L
.54107 .69506 L
.54 .69569 L
.54026 .70052 L
.54063 .70535 L
.53624 .70974 L
.53529 .71019 L
.53554 .71502 L
.53593 .71985 L
.53141 .72437 L
.53056 .72468 L
.53079 .72951 L
.53114 .73434 L
.52658 .73892 L
.5258 .73918 L
.526 .74401 L
.52628 .74884 L
.52174 .75338 L
.52103 .75367 L
.52119 .7585 L
.52139 .76334 L
Mistroke
.51691 .76783 L
.51628 .76817 L
.5164 .773 L
.51653 .77783 L
.5167 .78266 L
.51208 .78732 L
.51167 .7875 L
.51176 .79233 L
.51185 .79716 L
.51194 .80199 L
.50725 .80678 L
.50716 .80682 L
.50722 .81165 L
.50725 .81402 L
.50731 .81649 L
.50741 .82132 L
.50746 .82615 L
.50741 .83098 L
.51208 .83481 L
.51229 .83581 L
.51328 .84065 L
.51425 .84548 L
.51519 .85031 L
.51609 .85514 L
.51691 .85968 L
.51696 .85997 L
.51775 .8648 L
.5185 .86964 L
.51921 .87447 L
.51988 .8793 L
.5205 .88413 L
.52107 .88896 L
.52159 .8938 L
.52174 .89538 L
.52204 .89863 L
.52243 .90346 L
.52276 .90829 L
.52302 .91312 L
.52322 .91796 L
.52335 .92279 L
.5234 .92762 L
.52337 .93245 L
.52326 .93728 L
.52305 .94211 L
.52274 .94695 L
.52231 .95178 L
.52176 .95661 L
.52174 .95676 L
.52107 .96144 L
.52022 .96627 L
Mistroke
.51917 .97111 L
.5179 .97594 L
.51691 .97907 L
.51633 .98077 L
Mfstroke
.028 .55 0 r
.98077 .02211 m
.98013 .02406 L
.97594 .02756 L
.97439 .02889 L
.97111 .03218 L
.96938 .03373 L
.96627 .03682 L
.96438 .03856 L
.96144 .04149 L
.95939 .04339 L
.96077 .04822 L
.95661 .05238 L
.95555 .05305 L
.95178 .05682 L
.95044 .05789 L
.94695 .06137 L
.94538 .06272 L
.94211 .06597 L
.94034 .06755 L
.93728 .0706 L
.93533 .07238 L
.93688 .07721 L
.93245 .08164 L
.93151 .08204 L
.92762 .08593 L
.92634 .08688 L
.92279 .09043 L
.92125 .09171 L
.91796 .095 L
.9162 .09654 L
.91312 .09961 L
.91117 .10137 L
.91257 .1062 L
.90829 .11048 L
.90725 .11104 L
.90346 .11482 L
.90209 .11587 L
.89863 .11932 L
.897 .1207 L
.8938 .1239 L
.89195 .12553 L
.89367 .13036 L
.88896 .13507 L
.88804 .1352 L
.88413 .1391 L
.88283 .14003 L
.8793 .14355 L
.87772 .14486 L
.87447 .1481 L
.87264 .14969 L
.87429 .15452 L
.86964 .15918 L
.86868 .15935 L
.8648 .16323 L
.86347 .16419 L
.85997 .16767 L
.85835 .16902 L
.85514 .17221 L
.85327 .17385 L
.85456 .17868 L
.85031 .18293 L
.84919 .18351 L
.84548 .18722 L
.84401 .18835 L
.84065 .1917 L
.8389 .19318 L
.83581 .19625 L
.83383 .19801 L
.83486 .20284 L
.83098 .20671 L
.82962 .20767 L
.82615 .21113 L
.82448 .2125 L
.82132 .21565 L
.81939 .21734 L
.82044 .22217 L
.81649 .22612 L
.81516 .227 L
.81165 .2305 L
.81001 .23183 L
.80682 .235 L
.80491 .23666 L
.80592 .2415 L
.80199 .24542 L
.80064 .24633 L
.79716 .2498 L
.79548 .25116 L
.79233 .2543 L
.79038 .25599 L
.79131 .26082 L
.7875 .26463 L
.78606 .26566 L
.78266 .26904 L
.78091 .27049 L
.78206 .27532 L
.77783 .27954 L
.77663 .28015 L
.773 .28377 L
.77142 .28498 L
.76817 .28822 L
.76629 .28981 L
.76721 .29465 L
.76334 .29852 L
.76192 .29948 L
.7585 .30289 L
.75675 .30431 L
.7578 .30914 L
.75367 .31327 L
.7524 .31397 L
.74884 .31752 L
.7472 .31881 L
.7484 .32364 L
.74401 .32803 L
.74285 .32847 L
.73918 .33213 L
.73761 .3333 L
.73434 .33655 L
.73246 .33813 L
.73326 .34296 L
.72951 .3467 L
.72799 .3478 L
.72468 .35109 L
.72283 .35263 L
.72363 .35746 L
.71985 .36123 L
.71834 .36229 L
.71502 .3656 L
.71317 .36712 L
.71395 .37196 L
.71019 .3757 L
.70866 .37679 L
.70992 .38162 L
.70535 .38618 L
.70422 .38645 L
.70052 .39013 L
.69895 .39128 L
.69997 .39612 L
.69569 .40039 L
.69445 .40095 L
.69086 .40453 L
.68921 .40578 L
.69007 .41061 L
.68603 .41464 L
.68466 .41544 L
.68119 .4189 L
.67945 .42027 L
.68018 .42511 L
.67636 .42891 L
.67486 .42994 L
.67584 .43477 L
.67153 .43908 L
.67029 .4396 L
.6667 .44318 L
.66503 .44443 L
.66579 .44927 L
.66187 .45327 L
.66058 .4541 L
.66146 .45893 L
.65704 .46335 L
.65595 .46376 L
.6522 .4675 L
.65074 .46859 L
.65135 .47342 L
.64737 .47739 L
.64606 .47826 L
.64678 .48309 L
.64254 .48733 L
.64138 .48792 L
.64247 .49275 L
.63771 .49751 L
.63671 .49758 L
.63288 .5014 L
.63148 .50242 L
.63203 .50725 L
.62804 .51122 L
.62675 .51208 L
.62736 .51691 L
.62321 .52105 L
.62201 .52174 L
.6227 .52658 L
.61838 .53089 L
.61727 .53141 L
.61806 .53624 L
.61355 .54074 L
.61251 .54107 L
.60872 .54485 L
.60731 .5459 L
.60774 .55073 L
.60388 .55458 L
.60252 .55557 L
.60296 .5604 L
.59905 .56429 L
.59772 .56523 L
.59815 .57006 L
.59422 .57398 L
.59292 .57489 L
.59333 .57973 L
.58939 .58366 L
.5881 .58456 L
.5885 .58939 L
.58456 .59331 L
.58327 .59422 L
.58364 .59905 L
.58444 .60388 L
.57973 .6086 L
.57878 .60872 L
.57938 .61355 L
.57489 .61803 L
.57391 .61838 L
.5744 .62321 L
.57006 .62754 L
.56903 .62804 L
.56944 .63288 L
.56523 .63708 L
.56414 .63771 L
.56449 .64254 L
.5604 .64662 L
.55926 .64737 L
.55956 .6522 L
.56004 .65704 L
.55557 .66151 L
.55463 .66187 L
.55499 .6667 L
.55073 .67094 L
.54972 .67153 L
.55 .67636 L
.55047 .68119 L
.5459 .68576 L
.54505 .68603 L
.54535 .69086 L
.54107 .69513 L
.54012 .69569 L
.54035 .70052 L
.54068 .70535 L
.53624 .70979 L
.5354 .71019 L
.53562 .71502 L
.53596 .71985 L
.53141 .72441 L
.53066 .72468 L
.53086 .72951 L
.53118 .73434 L
.52658 .73895 L
.5259 .73918 L
.52607 .74401 L
.52632 .74884 L
.52174 .75342 L
.52113 .75367 L
.52127 .7585 L
.52144 .76334 L
.51691 .76789 L
.51639 .76817 L
.51649 .773 L
.5166 .77783 L
.51674 .78266 L
.51208 .78736 L
.51177 .7875 L
.51184 .79233 L
.51192 .79716 L
.51199 .80199 L
.50726 .80682 L
.50739 .81165 L
.5075 .81649 L
.50757 .82132 L
.51208 .82549 L
.51223 .82615 L
.51333 .83098 L
.51441 .83581 L
.51546 .84065 L
.51649 .84548 L
.51691 .84754 L
.51745 .85031 L
.51837 .85514 L
.51926 .85997 L
.5201 .8648 L
.52091 .86964 L
.52168 .87447 L
.52174 .87487 L
.52239 .8793 L
.52304 .88413 L
.52366 .88896 L
.52422 .8938 L
.52474 .89863 L
.52519 .90346 L
.5256 .90829 L
.52594 .91312 L
.52622 .91796 L
.52644 .92279 L
.52658 .92709 L
.52659 .92762 L
.52666 .93245 L
.52666 .93728 L
.52658 .94211 L
.52658 .94212 L
.5264 .94695 L
.52614 .95178 L
.52578 .95661 L
.5253 .96144 L
.5247 .96627 L
.52397 .97111 L
.52307 .97594 L
.522 .98077 L
.98077 .98077 L
F
0 g
.98077 .02211 m
.98013 .02406 L
.97594 .02756 L
.97439 .02889 L
.97111 .03218 L
.96938 .03373 L
.96627 .03682 L
.96438 .03856 L
.96144 .04149 L
.95939 .04339 L
.96077 .04822 L
.95661 .05238 L
.95555 .05305 L
.95178 .05682 L
.95044 .05789 L
.94695 .06137 L
.94538 .06272 L
.94211 .06597 L
.94034 .06755 L
.93728 .0706 L
.93533 .07238 L
.93688 .07721 L
.93245 .08164 L
.93151 .08204 L
.92762 .08593 L
.92634 .08688 L
.92279 .09043 L
.92125 .09171 L
.91796 .095 L
.9162 .09654 L
.91312 .09961 L
.91117 .10137 L
.91257 .1062 L
.90829 .11048 L
.90725 .11104 L
.90346 .11482 L
.90209 .11587 L
.89863 .11932 L
.897 .1207 L
.8938 .1239 L
.89195 .12553 L
.89367 .13036 L
.88896 .13507 L
.88804 .1352 L
.88413 .1391 L
.88283 .14003 L
.8793 .14355 L
.87772 .14486 L
.87447 .1481 L
.87264 .14969 L
Mistroke
.87429 .15452 L
.86964 .15918 L
.86868 .15935 L
.8648 .16323 L
.86347 .16419 L
.85997 .16767 L
.85835 .16902 L
.85514 .17221 L
.85327 .17385 L
.85456 .17868 L
.85031 .18293 L
.84919 .18351 L
.84548 .18722 L
.84401 .18835 L
.84065 .1917 L
.8389 .19318 L
.83581 .19625 L
.83383 .19801 L
.83486 .20284 L
.83098 .20671 L
.82962 .20767 L
.82615 .21113 L
.82448 .2125 L
.82132 .21565 L
.81939 .21734 L
.82044 .22217 L
.81649 .22612 L
.81516 .227 L
.81165 .2305 L
.81001 .23183 L
.80682 .235 L
.80491 .23666 L
.80592 .2415 L
.80199 .24542 L
.80064 .24633 L
.79716 .2498 L
.79548 .25116 L
.79233 .2543 L
.79038 .25599 L
.79131 .26082 L
.7875 .26463 L
.78606 .26566 L
.78266 .26904 L
.78091 .27049 L
.78206 .27532 L
.77783 .27954 L
.77663 .28015 L
.773 .28377 L
.77142 .28498 L
.76817 .28822 L
Mistroke
.76629 .28981 L
.76721 .29465 L
.76334 .29852 L
.76192 .29948 L
.7585 .30289 L
.75675 .30431 L
.7578 .30914 L
.75367 .31327 L
.7524 .31397 L
.74884 .31752 L
.7472 .31881 L
.7484 .32364 L
.74401 .32803 L
.74285 .32847 L
.73918 .33213 L
.73761 .3333 L
.73434 .33655 L
.73246 .33813 L
.73326 .34296 L
.72951 .3467 L
.72799 .3478 L
.72468 .35109 L
.72283 .35263 L
.72363 .35746 L
.71985 .36123 L
.71834 .36229 L
.71502 .3656 L
.71317 .36712 L
.71395 .37196 L
.71019 .3757 L
.70866 .37679 L
.70992 .38162 L
.70535 .38618 L
.70422 .38645 L
.70052 .39013 L
.69895 .39128 L
.69997 .39612 L
.69569 .40039 L
.69445 .40095 L
.69086 .40453 L
.68921 .40578 L
.69007 .41061 L
.68603 .41464 L
.68466 .41544 L
.68119 .4189 L
.67945 .42027 L
.68018 .42511 L
.67636 .42891 L
.67486 .42994 L
.67584 .43477 L
Mistroke
.67153 .43908 L
.67029 .4396 L
.6667 .44318 L
.66503 .44443 L
.66579 .44927 L
.66187 .45327 L
.66058 .4541 L
.66146 .45893 L
.65704 .46335 L
.65595 .46376 L
.6522 .4675 L
.65074 .46859 L
.65135 .47342 L
.64737 .47739 L
.64606 .47826 L
.64678 .48309 L
.64254 .48733 L
.64138 .48792 L
.64247 .49275 L
.63771 .49751 L
.63671 .49758 L
.63288 .5014 L
.63148 .50242 L
.63203 .50725 L
.62804 .51122 L
.62675 .51208 L
.62736 .51691 L
.62321 .52105 L
.62201 .52174 L
.6227 .52658 L
.61838 .53089 L
.61727 .53141 L
.61806 .53624 L
.61355 .54074 L
.61251 .54107 L
.60872 .54485 L
.60731 .5459 L
.60774 .55073 L
.60388 .55458 L
.60252 .55557 L
.60296 .5604 L
.59905 .56429 L
.59772 .56523 L
.59815 .57006 L
.59422 .57398 L
.59292 .57489 L
.59333 .57973 L
.58939 .58366 L
.5881 .58456 L
.5885 .58939 L
Mistroke
.58456 .59331 L
.58327 .59422 L
.58364 .59905 L
.58444 .60388 L
.57973 .6086 L
.57878 .60872 L
.57938 .61355 L
.57489 .61803 L
.57391 .61838 L
.5744 .62321 L
.57006 .62754 L
.56903 .62804 L
.56944 .63288 L
.56523 .63708 L
.56414 .63771 L
.56449 .64254 L
.5604 .64662 L
.55926 .64737 L
.55956 .6522 L
.56004 .65704 L
.55557 .66151 L
.55463 .66187 L
.55499 .6667 L
.55073 .67094 L
.54972 .67153 L
.55 .67636 L
.55047 .68119 L
.5459 .68576 L
.54505 .68603 L
.54535 .69086 L
.54107 .69513 L
.54012 .69569 L
.54035 .70052 L
.54068 .70535 L
.53624 .70979 L
.5354 .71019 L
.53562 .71502 L
.53596 .71985 L
.53141 .72441 L
.53066 .72468 L
.53086 .72951 L
.53118 .73434 L
.52658 .73895 L
.5259 .73918 L
.52607 .74401 L
.52632 .74884 L
.52174 .75342 L
.52113 .75367 L
.52127 .7585 L
.52144 .76334 L
Mistroke
.51691 .76789 L
.51639 .76817 L
.51649 .773 L
.5166 .77783 L
.51674 .78266 L
.51208 .78736 L
.51177 .7875 L
.51184 .79233 L
.51192 .79716 L
.51199 .80199 L
.50726 .80682 L
.50739 .81165 L
.5075 .81649 L
.50757 .82132 L
.51208 .82549 L
.51223 .82615 L
.51333 .83098 L
.51441 .83581 L
.51546 .84065 L
.51649 .84548 L
.51691 .84754 L
.51745 .85031 L
.51837 .85514 L
.51926 .85997 L
.5201 .8648 L
.52091 .86964 L
.52168 .87447 L
.52174 .87487 L
.52239 .8793 L
.52304 .88413 L
.52366 .88896 L
.52422 .8938 L
.52474 .89863 L
.52519 .90346 L
.5256 .90829 L
.52594 .91312 L
.52622 .91796 L
.52644 .92279 L
.52658 .92709 L
.52659 .92762 L
.52666 .93245 L
.52666 .93728 L
.52658 .94211 L
.52658 .94212 L
.5264 .94695 L
.52614 .95178 L
.52578 .95661 L
.5253 .96144 L
.5247 .96627 L
.52397 .97111 L
Mistroke
.52307 .97594 L
.522 .98077 L
Mfstroke
0 .505 .073 r
.98077 .02223 m
.9802 .02406 L
.97594 .02767 L
.97453 .02889 L
.97111 .03231 L
.96952 .03373 L
.96627 .03697 L
.96454 .03856 L
.96144 .04165 L
.95956 .04339 L
.96083 .04822 L
.95661 .05244 L
.95564 .05305 L
.95178 .05691 L
.95055 .05789 L
.94695 .06149 L
.94551 .06272 L
.94211 .06611 L
.94049 .06755 L
.93728 .07075 L
.9355 .07238 L
.93692 .07721 L
.93245 .08168 L
.93159 .08204 L
.92762 .08601 L
.92645 .08688 L
.92279 .09054 L
.92138 .09171 L
.91796 .09513 L
.91635 .09654 L
.91312 .09976 L
.91134 .10137 L
.91262 .1062 L
.90829 .11053 L
.90734 .11104 L
.90346 .11491 L
.90221 .11587 L
.89863 .11944 L
.89714 .1207 L
.8938 .12403 L
.8921 .12553 L
.89368 .13036 L
.88896 .13508 L
.88812 .1352 L
.88413 .13918 L
.88294 .14003 L
.8793 .14366 L
.87785 .14486 L
.87447 .14823 L
.8728 .14969 L
.87431 .15452 L
.86964 .15919 L
.86876 .15935 L
.8648 .16331 L
.86358 .16419 L
.85997 .16779 L
.85848 .16902 L
.85514 .17235 L
.85343 .17385 L
.85461 .17868 L
.85031 .18298 L
.84928 .18351 L
.84548 .18731 L
.84413 .18835 L
.84065 .19182 L
.83904 .19318 L
.83581 .1964 L
.83399 .19801 L
.83494 .20284 L
.83098 .20679 L
.82973 .20767 L
.82615 .21125 L
.82462 .2125 L
.82132 .2158 L
.81955 .21734 L
.82051 .22217 L
.81649 .22619 L
.81527 .227 L
.81165 .23061 L
.81014 .23183 L
.80682 .23514 L
.80507 .23666 L
.806 .2415 L
.80199 .2455 L
.80075 .24633 L
.79716 .24991 L
.79562 .25116 L
.79233 .25444 L
.79054 .25599 L
.7914 .26082 L
.7875 .26472 L
.78618 .26566 L
.78266 .26916 L
.78105 .27049 L
.78211 .27532 L
.77783 .2796 L
.77674 .28015 L
.773 .28388 L
.77156 .28498 L
.76817 .28836 L
.76645 .28981 L
.7673 .29465 L
.76334 .2986 L
.76204 .29948 L
.7585 .30301 L
.7569 .30431 L
.75786 .30914 L
.75367 .31333 L
.75251 .31397 L
.74884 .31763 L
.74734 .31881 L
.74844 .32364 L
.74401 .32807 L
.74295 .32847 L
.73918 .33223 L
.73774 .3333 L
.73434 .33669 L
.73262 .33813 L
.73336 .34296 L
.72951 .3468 L
.72812 .3478 L
.72468 .35122 L
.72299 .35263 L
.72372 .35746 L
.71985 .36132 L
.71847 .36229 L
.71502 .36573 L
.71333 .36712 L
.71404 .37196 L
.71019 .3758 L
.70879 .37679 L
.70994 .38162 L
.70535 .38621 L
.70432 .38645 L
.70052 .39023 L
.69908 .39128 L
.70002 .39612 L
.69569 .40044 L
.69456 .40095 L
.69086 .40463 L
.68935 .40578 L
.69014 .41061 L
.68603 .41471 L
.68478 .41544 L
.68119 .41901 L
.67959 .42027 L
.68026 .42511 L
.67636 .42899 L
.67498 .42994 L
.67589 .43477 L
.67153 .43912 L
.6704 .4396 L
.6667 .44328 L
.66517 .44443 L
.66587 .44927 L
.66187 .45335 L
.66071 .4541 L
.6615 .45893 L
.65704 .46339 L
.65606 .46376 L
.6522 .4676 L
.65088 .46859 L
.65143 .47342 L
.64737 .47747 L
.64619 .47826 L
.64684 .48309 L
.64254 .48739 L
.6415 .48792 L
.64248 .49275 L
.63771 .49752 L
.63681 .49758 L
.63288 .5015 L
.63161 .50242 L
.63212 .50725 L
.62804 .51131 L
.62688 .51208 L
.62743 .51691 L
.62321 .52112 L
.62213 .52174 L
.62275 .52658 L
.61838 .53094 L
.61738 .53141 L
.61809 .53624 L
.61355 .54078 L
.61262 .54107 L
.60872 .54496 L
.60745 .5459 L
.60784 .55073 L
.60388 .55468 L
.60266 .55557 L
.60305 .5604 L
.59905 .56438 L
.59786 .56523 L
.59825 .57006 L
.59422 .57408 L
.59305 .57489 L
.59343 .57973 L
.58939 .58375 L
.58823 .58456 L
.58859 .58939 L
.58456 .59341 L
.58341 .59422 L
.58374 .59905 L
.58446 .60388 L
.57973 .60862 L
.57888 .60872 L
.57942 .61355 L
.57489 .61807 L
.57401 .61838 L
.57446 .62321 L
.57006 .6276 L
.56914 .62804 L
.56951 .63288 L
.56523 .63715 L
.56426 .63771 L
.56458 .64254 L
.5604 .64671 L
.55939 .64737 L
.55965 .6522 L
.56009 .65704 L
.55557 .66155 L
.55474 .66187 L
.55506 .6667 L
.55073 .67101 L
.54984 .67153 L
.55009 .67636 L
.5505 .68119 L
.5459 .6858 L
.54515 .68603 L
.54542 .69086 L
.54107 .6952 L
.54024 .69569 L
.54044 .70052 L
.54073 .70535 L
.53624 .70984 L
.53551 .71019 L
.5357 .71502 L
.536 .71985 L
.53141 .72445 L
.53076 .72468 L
.53094 .72951 L
.53121 .73434 L
.52658 .73899 L
.526 .73918 L
.52615 .74401 L
.52636 .74884 L
.52174 .75347 L
.52124 .75367 L
.52135 .7585 L
.5215 .76334 L
.51691 .76795 L
.51649 .76817 L
.51658 .773 L
.51667 .77783 L
.51678 .78266 L
.51208 .7874 L
.51187 .7875 L
.51193 .79233 L
.51198 .79716 L
.51203 .80199 L
.50751 .80682 L
.50762 .81165 L
.51208 .81502 L
.51245 .81649 L
.51366 .82132 L
.51485 .82615 L
.51601 .83098 L
.51691 .83479 L
.51714 .83581 L
.51821 .84065 L
.51926 .84548 L
.52027 .85031 L
.52125 .85514 L
.52174 .85766 L
.52218 .85997 L
.52306 .8648 L
.52391 .86964 L
.52472 .87447 L
.52549 .8793 L
.52621 .88413 L
.52658 .88669 L
.52688 .88896 L
.52751 .8938 L
.52808 .89863 L
.52861 .90346 L
.52908 .90829 L
.5295 .91312 L
.52987 .91796 L
.53017 .92279 L
.53042 .92762 L
.5306 .93245 L
.53071 .93728 L
.53076 .94211 L
.53072 .94695 L
.53061 .95178 L
.53042 .95661 L
.53013 .96144 L
.52975 .96627 L
.52926 .97111 L
.52866 .97594 L
.52793 .98077 L
.98077 .98077 L
F
0 g
.98077 .02223 m
.9802 .02406 L
.97594 .02767 L
.97453 .02889 L
.97111 .03231 L
.96952 .03373 L
.96627 .03697 L
.96454 .03856 L
.96144 .04165 L
.95956 .04339 L
.96083 .04822 L
.95661 .05244 L
.95564 .05305 L
.95178 .05691 L
.95055 .05789 L
.94695 .06149 L
.94551 .06272 L
.94211 .06611 L
.94049 .06755 L
.93728 .07075 L
.9355 .07238 L
.93692 .07721 L
.93245 .08168 L
.93159 .08204 L
.92762 .08601 L
.92645 .08688 L
.92279 .09054 L
.92138 .09171 L
.91796 .09513 L
.91635 .09654 L
.91312 .09976 L
.91134 .10137 L
.91262 .1062 L
.90829 .11053 L
.90734 .11104 L
.90346 .11491 L
.90221 .11587 L
.89863 .11944 L
.89714 .1207 L
.8938 .12403 L
.8921 .12553 L
.89368 .13036 L
.88896 .13508 L
.88812 .1352 L
.88413 .13918 L
.88294 .14003 L
.8793 .14366 L
.87785 .14486 L
.87447 .14823 L
.8728 .14969 L
Mistroke
.87431 .15452 L
.86964 .15919 L
.86876 .15935 L
.8648 .16331 L
.86358 .16419 L
.85997 .16779 L
.85848 .16902 L
.85514 .17235 L
.85343 .17385 L
.85461 .17868 L
.85031 .18298 L
.84928 .18351 L
.84548 .18731 L
.84413 .18835 L
.84065 .19182 L
.83904 .19318 L
.83581 .1964 L
.83399 .19801 L
.83494 .20284 L
.83098 .20679 L
.82973 .20767 L
.82615 .21125 L
.82462 .2125 L
.82132 .2158 L
.81955 .21734 L
.82051 .22217 L
.81649 .22619 L
.81527 .227 L
.81165 .23061 L
.81014 .23183 L
.80682 .23514 L
.80507 .23666 L
.806 .2415 L
.80199 .2455 L
.80075 .24633 L
.79716 .24991 L
.79562 .25116 L
.79233 .25444 L
.79054 .25599 L
.7914 .26082 L
.7875 .26472 L
.78618 .26566 L
.78266 .26916 L
.78105 .27049 L
.78211 .27532 L
.77783 .2796 L
.77674 .28015 L
.773 .28388 L
.77156 .28498 L
.76817 .28836 L
Mistroke
.76645 .28981 L
.7673 .29465 L
.76334 .2986 L
.76204 .29948 L
.7585 .30301 L
.7569 .30431 L
.75786 .30914 L
.75367 .31333 L
.75251 .31397 L
.74884 .31763 L
.74734 .31881 L
.74844 .32364 L
.74401 .32807 L
.74295 .32847 L
.73918 .33223 L
.73774 .3333 L
.73434 .33669 L
.73262 .33813 L
.73336 .34296 L
.72951 .3468 L
.72812 .3478 L
.72468 .35122 L
.72299 .35263 L
.72372 .35746 L
.71985 .36132 L
.71847 .36229 L
.71502 .36573 L
.71333 .36712 L
.71404 .37196 L
.71019 .3758 L
.70879 .37679 L
.70994 .38162 L
.70535 .38621 L
.70432 .38645 L
.70052 .39023 L
.69908 .39128 L
.70002 .39612 L
.69569 .40044 L
.69456 .40095 L
.69086 .40463 L
.68935 .40578 L
.69014 .41061 L
.68603 .41471 L
.68478 .41544 L
.68119 .41901 L
.67959 .42027 L
.68026 .42511 L
.67636 .42899 L
.67498 .42994 L
.67589 .43477 L
Mistroke
.67153 .43912 L
.6704 .4396 L
.6667 .44328 L
.66517 .44443 L
.66587 .44927 L
.66187 .45335 L
.66071 .4541 L
.6615 .45893 L
.65704 .46339 L
.65606 .46376 L
.6522 .4676 L
.65088 .46859 L
.65143 .47342 L
.64737 .47747 L
.64619 .47826 L
.64684 .48309 L
.64254 .48739 L
.6415 .48792 L
.64248 .49275 L
.63771 .49752 L
.63681 .49758 L
.63288 .5015 L
.63161 .50242 L
.63212 .50725 L
.62804 .51131 L
.62688 .51208 L
.62743 .51691 L
.62321 .52112 L
.62213 .52174 L
.62275 .52658 L
.61838 .53094 L
.61738 .53141 L
.61809 .53624 L
.61355 .54078 L
.61262 .54107 L
.60872 .54496 L
.60745 .5459 L
.60784 .55073 L
.60388 .55468 L
.60266 .55557 L
.60305 .5604 L
.59905 .56438 L
.59786 .56523 L
.59825 .57006 L
.59422 .57408 L
.59305 .57489 L
.59343 .57973 L
.58939 .58375 L
.58823 .58456 L
.58859 .58939 L
Mistroke
.58456 .59341 L
.58341 .59422 L
.58374 .59905 L
.58446 .60388 L
.57973 .60862 L
.57888 .60872 L
.57942 .61355 L
.57489 .61807 L
.57401 .61838 L
.57446 .62321 L
.57006 .6276 L
.56914 .62804 L
.56951 .63288 L
.56523 .63715 L
.56426 .63771 L
.56458 .64254 L
.5604 .64671 L
.55939 .64737 L
.55965 .6522 L
.56009 .65704 L
.55557 .66155 L
.55474 .66187 L
.55506 .6667 L
.55073 .67101 L
.54984 .67153 L
.55009 .67636 L
.5505 .68119 L
.5459 .6858 L
.54515 .68603 L
.54542 .69086 L
.54107 .6952 L
.54024 .69569 L
.54044 .70052 L
.54073 .70535 L
.53624 .70984 L
.53551 .71019 L
.5357 .71502 L
.536 .71985 L
.53141 .72445 L
.53076 .72468 L
.53094 .72951 L
.53121 .73434 L
.52658 .73899 L
.526 .73918 L
.52615 .74401 L
.52636 .74884 L
.52174 .75347 L
.52124 .75367 L
.52135 .7585 L
.5215 .76334 L
Mistroke
.51691 .76795 L
.51649 .76817 L
.51658 .773 L
.51667 .77783 L
.51678 .78266 L
.51208 .7874 L
.51187 .7875 L
.51193 .79233 L
.51198 .79716 L
.51203 .80199 L
.50751 .80682 L
.50762 .81165 L
.51208 .81502 L
.51245 .81649 L
.51366 .82132 L
.51485 .82615 L
.51601 .83098 L
.51691 .83479 L
.51714 .83581 L
.51821 .84065 L
.51926 .84548 L
.52027 .85031 L
.52125 .85514 L
.52174 .85766 L
.52218 .85997 L
.52306 .8648 L
.52391 .86964 L
.52472 .87447 L
.52549 .8793 L
.52621 .88413 L
.52658 .88669 L
.52688 .88896 L
.52751 .8938 L
.52808 .89863 L
.52861 .90346 L
.52908 .90829 L
.5295 .91312 L
.52987 .91796 L
.53017 .92279 L
.53042 .92762 L
.5306 .93245 L
.53071 .93728 L
.53076 .94211 L
.53072 .94695 L
.53061 .95178 L
.53042 .95661 L
.53013 .96144 L
.52975 .96627 L
.52926 .97111 L
.52866 .97594 L
Mistroke
.52793 .98077 L
Mfstroke
0 .46 .156 r
.98077 .02236 m
.98026 .02406 L
.97594 .02778 L
.97466 .02889 L
.97111 .03244 L
.96967 .03373 L
.96627 .03712 L
.9647 .03856 L
.96144 .04181 L
.95974 .04339 L
.96089 .04822 L
.95661 .0525 L
.95573 .05305 L
.95178 .05701 L
.95067 .05789 L
.94695 .0616 L
.94564 .06272 L
.94211 .06624 L
.94064 .06755 L
.93728 .07091 L
.93566 .07238 L
.93695 .07721 L
.93245 .08171 L
.93167 .08204 L
.92762 .08609 L
.92656 .08688 L
.92279 .09065 L
.92151 .09171 L
.91796 .09526 L
.9165 .09654 L
.91312 .09991 L
.9115 .10137 L
.91267 .1062 L
.90829 .11058 L
.90743 .11104 L
.90346 .115 L
.90232 .11587 L
.89863 .11956 L
.89728 .1207 L
.8938 .12417 L
.89226 .12553 L
.89369 .13036 L
.88896 .13509 L
.8882 .1352 L
.88413 .13926 L
.88306 .14003 L
.8793 .14378 L
.87799 .14486 L
.87447 .14837 L
.87295 .14969 L
.87432 .15452 L
.86964 .15921 L
.86885 .15935 L
.8648 .16339 L
.8637 .16419 L
.85997 .1679 L
.85862 .16902 L
.85514 .17249 L
.85359 .17385 L
.85466 .17868 L
.85031 .18303 L
.84938 .18351 L
.84548 .18741 L
.84426 .18835 L
.84065 .19195 L
.83919 .19318 L
.83581 .19655 L
.83416 .19801 L
.83502 .20284 L
.83098 .20687 L
.82985 .20767 L
.82615 .21136 L
.82476 .2125 L
.82132 .21594 L
.81972 .21734 L
.82059 .22217 L
.81649 .22627 L
.81539 .227 L
.81165 .23073 L
.81029 .23183 L
.80682 .23528 L
.80523 .23666 L
.80608 .2415 L
.80199 .24557 L
.80087 .24633 L
.79716 .25003 L
.79576 .25116 L
.79233 .25459 L
.79071 .25599 L
.79148 .26082 L
.7875 .2648 L
.7863 .26566 L
.78266 .26928 L
.7812 .27049 L
.78217 .27532 L
.77783 .27965 L
.77684 .28015 L
.773 .28398 L
.77169 .28498 L
.76817 .28849 L
.76661 .28981 L
.76738 .29465 L
.76334 .29868 L
.76216 .29948 L
.7585 .30313 L
.75705 .30431 L
.75792 .30914 L
.75367 .31339 L
.75262 .31397 L
.74884 .31774 L
.74748 .31881 L
.74848 .32364 L
.74401 .32811 L
.74305 .32847 L
.73918 .33233 L
.73788 .3333 L
.73434 .33682 L
.73278 .33813 L
.73345 .34296 L
.72951 .34689 L
.72825 .3478 L
.72468 .35135 L
.72314 .35263 L
.72381 .35746 L
.71985 .36141 L
.7186 .36229 L
.71502 .36586 L
.71349 .36712 L
.71413 .37196 L
.71019 .37589 L
.70892 .37679 L
.70997 .38162 L
.70535 .38623 L
.70441 .38645 L
.70052 .39033 L
.69922 .39128 L
.70007 .39612 L
.69569 .40049 L
.69467 .40095 L
.69086 .40474 L
.68949 .40578 L
.69021 .41061 L
.68603 .41478 L
.6849 .41544 L
.68119 .41913 L
.67974 .42027 L
.68035 .42511 L
.67636 .42908 L
.67511 .42994 L
.67593 .43477 L
.67153 .43917 L
.6705 .4396 L
.6667 .44339 L
.66531 .44443 L
.66595 .44927 L
.66187 .45344 L
.66083 .4541 L
.66154 .45893 L
.65704 .46343 L
.65617 .46376 L
.6522 .46771 L
.65103 .46859 L
.65152 .47342 L
.64737 .47756 L
.64632 .47826 L
.6469 .48309 L
.64254 .48745 L
.64161 .48792 L
.64248 .49275 L
.63771 .49753 L
.63691 .49758 L
.63288 .5016 L
.63175 .50242 L
.6322 .50725 L
.62804 .5114 L
.62701 .51208 L
.6275 .51691 L
.62321 .52119 L
.62225 .52174 L
.6228 .52658 L
.61838 .53099 L
.61749 .53141 L
.61812 .53624 L
.61355 .54081 L
.61272 .54107 L
.60872 .54507 L
.60759 .5459 L
.60794 .55073 L
.60388 .55478 L
.6028 .55557 L
.60315 .5604 L
.59905 .56448 L
.598 .56523 L
.59834 .57006 L
.59422 .57417 L
.59319 .57489 L
.59352 .57973 L
.58939 .58385 L
.58837 .58456 L
.58869 .58939 L
.58456 .59351 L
.58354 .59422 L
.58384 .59905 L
.58447 .60388 L
.57973 .60863 L
.57898 .60872 L
.57946 .61355 L
.57489 .61811 L
.57412 .61838 L
.57451 .62321 L
.57006 .62766 L
.56925 .62804 L
.56958 .63288 L
.56523 .63722 L
.56439 .63771 L
.56466 .64254 L
.5604 .64679 L
.55952 .64737 L
.55975 .6522 L
.56013 .65704 L
.55557 .66159 L
.55485 .66187 L
.55512 .6667 L
.55073 .67108 L
.54996 .67153 L
.55018 .67636 L
.55054 .68119 L
.5459 .68583 L
.54526 .68603 L
.54549 .69086 L
.54107 .69527 L
.54036 .69569 L
.54053 .70052 L
.54078 .70535 L
.53624 .7099 L
.53562 .71019 L
.53579 .71502 L
.53604 .71985 L
.53141 .72449 L
.53087 .72468 L
.53102 .72951 L
.53124 .73434 L
.52658 .73902 L
.5261 .73918 L
.52623 .74401 L
.5264 .74884 L
.52174 .75351 L
.52134 .75367 L
.52144 .7585 L
.52155 .76334 L
.51691 .76801 L
.5166 .76817 L
.51667 .773 L
.51674 .77783 L
.51682 .78266 L
.51208 .78745 L
.51197 .7875 L
.51201 .79233 L
.51205 .79716 L
.51208 .80199 L
.51208 .80291 L
.51317 .80682 L
.51449 .81165 L
.51578 .81649 L
.51691 .82076 L
.51705 .82132 L
.51827 .82615 L
.51947 .83098 L
.52063 .83581 L
.52174 .84055 L
.52176 .84065 L
.52285 .84548 L
.5239 .85031 L
.52492 .85514 L
.52591 .85997 L
.52658 .86335 L
.52685 .8648 L
.52775 .86964 L
.52862 .87447 L
.52944 .8793 L
.53022 .88413 L
.53096 .88896 L
.53141 .89199 L
.53166 .8938 L
.53231 .89863 L
.53291 .90346 L
.53346 .90829 L
.53397 .91312 L
.53442 .91796 L
.53483 .92279 L
.53517 .92762 L
.53547 .93245 L
.5357 .93728 L
.53587 .94211 L
.53597 .94695 L
.53601 .95178 L
.53598 .95661 L
.53587 .96144 L
.53568 .96627 L
.53541 .97111 L
.53505 .97594 L
.53459 .98077 L
.98077 .98077 L
F
0 g
.98077 .02236 m
.98026 .02406 L
.97594 .02778 L
.97466 .02889 L
.97111 .03244 L
.96967 .03373 L
.96627 .03712 L
.9647 .03856 L
.96144 .04181 L
.95974 .04339 L
.96089 .04822 L
.95661 .0525 L
.95573 .05305 L
.95178 .05701 L
.95067 .05789 L
.94695 .0616 L
.94564 .06272 L
.94211 .06624 L
.94064 .06755 L
.93728 .07091 L
.93566 .07238 L
.93695 .07721 L
.93245 .08171 L
.93167 .08204 L
.92762 .08609 L
.92656 .08688 L
.92279 .09065 L
.92151 .09171 L
.91796 .09526 L
.9165 .09654 L
.91312 .09991 L
.9115 .10137 L
.91267 .1062 L
.90829 .11058 L
.90743 .11104 L
.90346 .115 L
.90232 .11587 L
.89863 .11956 L
.89728 .1207 L
.8938 .12417 L
.89226 .12553 L
.89369 .13036 L
.88896 .13509 L
.8882 .1352 L
.88413 .13926 L
.88306 .14003 L
.8793 .14378 L
.87799 .14486 L
.87447 .14837 L
.87295 .14969 L
Mistroke
.87432 .15452 L
.86964 .15921 L
.86885 .15935 L
.8648 .16339 L
.8637 .16419 L
.85997 .1679 L
.85862 .16902 L
.85514 .17249 L
.85359 .17385 L
.85466 .17868 L
.85031 .18303 L
.84938 .18351 L
.84548 .18741 L
.84426 .18835 L
.84065 .19195 L
.83919 .19318 L
.83581 .19655 L
.83416 .19801 L
.83502 .20284 L
.83098 .20687 L
.82985 .20767 L
.82615 .21136 L
.82476 .2125 L
.82132 .21594 L
.81972 .21734 L
.82059 .22217 L
.81649 .22627 L
.81539 .227 L
.81165 .23073 L
.81029 .23183 L
.80682 .23528 L
.80523 .23666 L
.80608 .2415 L
.80199 .24557 L
.80087 .24633 L
.79716 .25003 L
.79576 .25116 L
.79233 .25459 L
.79071 .25599 L
.79148 .26082 L
.7875 .2648 L
.7863 .26566 L
.78266 .26928 L
.7812 .27049 L
.78217 .27532 L
.77783 .27965 L
.77684 .28015 L
.773 .28398 L
.77169 .28498 L
.76817 .28849 L
Mistroke
.76661 .28981 L
.76738 .29465 L
.76334 .29868 L
.76216 .29948 L
.7585 .30313 L
.75705 .30431 L
.75792 .30914 L
.75367 .31339 L
.75262 .31397 L
.74884 .31774 L
.74748 .31881 L
.74848 .32364 L
.74401 .32811 L
.74305 .32847 L
.73918 .33233 L
.73788 .3333 L
.73434 .33682 L
.73278 .33813 L
.73345 .34296 L
.72951 .34689 L
.72825 .3478 L
.72468 .35135 L
.72314 .35263 L
.72381 .35746 L
.71985 .36141 L
.7186 .36229 L
.71502 .36586 L
.71349 .36712 L
.71413 .37196 L
.71019 .37589 L
.70892 .37679 L
.70997 .38162 L
.70535 .38623 L
.70441 .38645 L
.70052 .39033 L
.69922 .39128 L
.70007 .39612 L
.69569 .40049 L
.69467 .40095 L
.69086 .40474 L
.68949 .40578 L
.69021 .41061 L
.68603 .41478 L
.6849 .41544 L
.68119 .41913 L
.67974 .42027 L
.68035 .42511 L
.67636 .42908 L
.67511 .42994 L
.67593 .43477 L
Mistroke
.67153 .43917 L
.6705 .4396 L
.6667 .44339 L
.66531 .44443 L
.66595 .44927 L
.66187 .45344 L
.66083 .4541 L
.66154 .45893 L
.65704 .46343 L
.65617 .46376 L
.6522 .46771 L
.65103 .46859 L
.65152 .47342 L
.64737 .47756 L
.64632 .47826 L
.6469 .48309 L
.64254 .48745 L
.64161 .48792 L
.64248 .49275 L
.63771 .49753 L
.63691 .49758 L
.63288 .5016 L
.63175 .50242 L
.6322 .50725 L
.62804 .5114 L
.62701 .51208 L
.6275 .51691 L
.62321 .52119 L
.62225 .52174 L
.6228 .52658 L
.61838 .53099 L
.61749 .53141 L
.61812 .53624 L
.61355 .54081 L
.61272 .54107 L
.60872 .54507 L
.60759 .5459 L
.60794 .55073 L
.60388 .55478 L
.6028 .55557 L
.60315 .5604 L
.59905 .56448 L
.598 .56523 L
.59834 .57006 L
.59422 .57417 L
.59319 .57489 L
.59352 .57973 L
.58939 .58385 L
.58837 .58456 L
.58869 .58939 L
Mistroke
.58456 .59351 L
.58354 .59422 L
.58384 .59905 L
.58447 .60388 L
.57973 .60863 L
.57898 .60872 L
.57946 .61355 L
.57489 .61811 L
.57412 .61838 L
.57451 .62321 L
.57006 .62766 L
.56925 .62804 L
.56958 .63288 L
.56523 .63722 L
.56439 .63771 L
.56466 .64254 L
.5604 .64679 L
.55952 .64737 L
.55975 .6522 L
.56013 .65704 L
.55557 .66159 L
.55485 .66187 L
.55512 .6667 L
.55073 .67108 L
.54996 .67153 L
.55018 .67636 L
.55054 .68119 L
.5459 .68583 L
.54526 .68603 L
.54549 .69086 L
.54107 .69527 L
.54036 .69569 L
.54053 .70052 L
.54078 .70535 L
.53624 .7099 L
.53562 .71019 L
.53579 .71502 L
.53604 .71985 L
.53141 .72449 L
.53087 .72468 L
.53102 .72951 L
.53124 .73434 L
.52658 .73902 L
.5261 .73918 L
.52623 .74401 L
.5264 .74884 L
.52174 .75351 L
.52134 .75367 L
.52144 .7585 L
.52155 .76334 L
Mistroke
.51691 .76801 L
.5166 .76817 L
.51667 .773 L
.51674 .77783 L
.51682 .78266 L
.51208 .78745 L
.51197 .7875 L
.51201 .79233 L
.51205 .79716 L
.51208 .80199 L
.51208 .80291 L
.51317 .80682 L
.51449 .81165 L
.51578 .81649 L
.51691 .82076 L
.51705 .82132 L
.51827 .82615 L
.51947 .83098 L
.52063 .83581 L
.52174 .84055 L
.52176 .84065 L
.52285 .84548 L
.5239 .85031 L
.52492 .85514 L
.52591 .85997 L
.52658 .86335 L
.52685 .8648 L
.52775 .86964 L
.52862 .87447 L
.52944 .8793 L
.53022 .88413 L
.53096 .88896 L
.53141 .89199 L
.53166 .8938 L
.53231 .89863 L
.53291 .90346 L
.53346 .90829 L
.53397 .91312 L
.53442 .91796 L
.53483 .92279 L
.53517 .92762 L
.53547 .93245 L
.5357 .93728 L
.53587 .94211 L
.53597 .94695 L
.53601 .95178 L
.53598 .95661 L
.53587 .96144 L
.53568 .96627 L
.53541 .97111 L
Mistroke
.53505 .97594 L
.53459 .98077 L
Mfstroke
0 .415 .222 r
.98077 .0225 m
.98032 .02406 L
.97594 .0279 L
.97479 .02889 L
.97111 .03257 L
.96982 .03373 L
.96627 .03727 L
.96486 .03856 L
.96144 .04197 L
.95991 .04339 L
.96095 .04822 L
.95661 .05256 L
.95583 .05305 L
.95178 .0571 L
.95078 .05789 L
.94695 .06172 L
.94578 .06272 L
.94211 .06638 L
.9408 .06755 L
.93728 .07106 L
.93583 .07238 L
.93699 .07721 L
.93245 .08175 L
.93175 .08204 L
.92762 .08617 L
.92667 .08688 L
.92279 .09076 L
.92165 .09171 L
.91796 .09539 L
.91665 .09654 L
.91312 .10006 L
.91167 .10137 L
.91272 .1062 L
.90829 .11063 L
.90752 .11104 L
.90346 .11509 L
.90244 .11587 L
.89863 .11968 L
.89742 .1207 L
.8938 .12431 L
.89242 .12553 L
.8937 .13036 L
.88896 .1351 L
.88828 .1352 L
.88413 .13934 L
.88317 .14003 L
.8793 .14389 L
.87812 .14486 L
.87447 .14851 L
.87311 .14969 L
.87434 .15452 L
.86964 .15923 L
.86893 .15935 L
.8648 .16347 L
.86381 .16419 L
.85997 .16802 L
.85876 .16902 L
.85514 .17263 L
.85375 .17385 L
.85471 .17868 L
.85031 .18308 L
.84948 .18351 L
.84548 .18751 L
.84438 .18835 L
.84065 .19208 L
.83934 .19318 L
.83581 .1967 L
.83433 .19801 L
.8351 .20284 L
.83098 .20696 L
.82997 .20767 L
.82615 .21148 L
.82491 .2125 L
.82132 .21608 L
.81988 .21734 L
.82067 .22217 L
.81649 .22635 L
.8155 .227 L
.81165 .23084 L
.81043 .23183 L
.80682 .23543 L
.80539 .23666 L
.80615 .2415 L
.80199 .24565 L
.80099 .24633 L
.79716 .25015 L
.79591 .25116 L
.79233 .25473 L
.79088 .25599 L
.79157 .26082 L
.7875 .26489 L
.78642 .26566 L
.78266 .26941 L
.78135 .27049 L
.78222 .27532 L
.77783 .2797 L
.77694 .28015 L
.773 .28408 L
.77183 .28498 L
.76817 .28863 L
.76677 .28981 L
.76746 .29465 L
.76334 .29877 L
.76229 .29948 L
.7585 .30325 L
.7572 .30431 L
.75799 .30914 L
.75367 .31345 L
.75273 .31397 L
.74884 .31785 L
.74762 .31881 L
.74852 .32364 L
.74401 .32815 L
.74315 .32847 L
.73918 .33243 L
.73801 .3333 L
.73434 .33696 L
.73294 .33813 L
.73354 .34296 L
.72951 .34699 L
.72838 .3478 L
.72468 .35149 L
.7233 .35263 L
.7239 .35746 L
.71985 .3615 L
.71873 .36229 L
.71502 .36599 L
.71364 .36712 L
.71422 .37196 L
.71019 .37598 L
.70905 .37679 L
.70999 .38162 L
.70535 .38626 L
.70451 .38645 L
.70052 .39043 L
.69935 .39128 L
.70012 .39612 L
.69569 .40054 L
.69477 .40095 L
.69086 .40485 L
.68963 .40578 L
.69027 .41061 L
.68603 .41485 L
.68501 .41544 L
.68119 .41925 L
.67989 .42027 L
.68044 .42511 L
.67636 .42917 L
.67524 .42994 L
.67598 .43477 L
.67153 .43922 L
.67061 .4396 L
.6667 .4435 L
.66545 .44443 L
.66603 .44927 L
.66187 .45352 L
.66096 .4541 L
.66158 .45893 L
.65704 .46347 L
.65627 .46376 L
.6522 .46782 L
.65117 .46859 L
.6516 .47342 L
.64737 .47765 L
.64645 .47826 L
.64696 .48309 L
.64254 .48751 L
.64173 .48792 L
.64249 .49275 L
.63771 .49754 L
.63701 .49758 L
.63288 .50171 L
.63189 .50242 L
.63229 .50725 L
.62804 .51148 L
.62714 .51208 L
.62757 .51691 L
.62321 .52126 L
.62238 .52174 L
.62286 .52658 L
.61838 .53105 L
.61761 .53141 L
.61816 .53624 L
.61355 .54085 L
.61283 .54107 L
.60872 .54518 L
.60774 .5459 L
.60804 .55073 L
.60388 .55488 L
.60294 .55557 L
.60325 .5604 L
.59905 .56458 L
.59814 .56523 L
.59844 .57006 L
.59422 .57427 L
.59333 .57489 L
.59362 .57973 L
.58939 .58394 L
.58851 .58456 L
.58878 .58939 L
.58456 .59361 L
.58368 .59422 L
.58394 .59905 L
.58448 .60388 L
.57973 .60864 L
.57909 .60872 L
.5795 .61355 L
.57489 .61815 L
.57423 .61838 L
.57457 .62321 L
.57006 .62771 L
.56937 .62804 L
.56965 .63288 L
.56523 .63729 L
.56451 .63771 L
.56474 .64254 L
.5604 .64688 L
.55965 .64737 L
.55985 .6522 L
.56017 .65704 L
.55557 .66164 L
.55496 .66187 L
.55519 .6667 L
.55073 .67116 L
.55008 .67153 L
.55027 .67636 L
.55057 .68119 L
.5459 .68586 L
.54536 .68603 L
.54556 .69086 L
.54107 .69535 L
.54048 .69569 L
.54063 .70052 L
.54083 .70535 L
.53624 .70995 L
.53573 .71019 L
.53587 .71502 L
.53608 .71985 L
.53141 .72453 L
.53098 .72468 L
.5311 .72951 L
.53128 .73434 L
.52658 .73906 L
.52621 .73918 L
.52631 .74401 L
.52644 .74884 L
.52174 .75355 L
.52145 .75367 L
.52152 .7585 L
.52161 .76334 L
.51691 .76806 L
.51671 .76817 L
.51676 .773 L
.51681 .77783 L
.51686 .78266 L
.51208 .78749 L
.51207 .7875 L
.51208 .79227 L
.51214 .79233 L
.51219 .79716 L
.5122 .80199 L
.51691 .80465 L
.51753 .80682 L
.5189 .81165 L
.52023 .81649 L
.52155 .82132 L
.52174 .82205 L
.52282 .82615 L
.52406 .83098 L
.52527 .83581 L
.52646 .84065 L
.52658 .84114 L
.5276 .84548 L
.52871 .85031 L
.52978 .85514 L
.53083 .85997 L
.53141 .86273 L
.53183 .8648 L
.5328 .86964 L
.53373 .87447 L
.53462 .8793 L
.53548 .88413 L
.53624 .88862 L
.5363 .88896 L
.53707 .8938 L
.5378 .89863 L
.53849 .90346 L
.53913 .90829 L
.53973 .91312 L
.54029 .91796 L
.5408 .92279 L
.54107 .92562 L
.54125 .92762 L
.54166 .93245 L
.54201 .93728 L
.54231 .94211 L
.54256 .94695 L
.54275 .95178 L
.54287 .95661 L
.54294 .96144 L
.54294 .96627 L
.54287 .97111 L
.54273 .97594 L
.54251 .98077 L
.98077 .98077 L
F
0 g
.98077 .0225 m
.98032 .02406 L
.97594 .0279 L
.97479 .02889 L
.97111 .03257 L
.96982 .03373 L
.96627 .03727 L
.96486 .03856 L
.96144 .04197 L
.95991 .04339 L
.96095 .04822 L
.95661 .05256 L
.95583 .05305 L
.95178 .0571 L
.95078 .05789 L
.94695 .06172 L
.94578 .06272 L
.94211 .06638 L
.9408 .06755 L
.93728 .07106 L
.93583 .07238 L
.93699 .07721 L
.93245 .08175 L
.93175 .08204 L
.92762 .08617 L
.92667 .08688 L
.92279 .09076 L
.92165 .09171 L
.91796 .09539 L
.91665 .09654 L
.91312 .10006 L
.91167 .10137 L
.91272 .1062 L
.90829 .11063 L
.90752 .11104 L
.90346 .11509 L
.90244 .11587 L
.89863 .11968 L
.89742 .1207 L
.8938 .12431 L
.89242 .12553 L
.8937 .13036 L
.88896 .1351 L
.88828 .1352 L
.88413 .13934 L
.88317 .14003 L
.8793 .14389 L
.87812 .14486 L
.87447 .14851 L
.87311 .14969 L
Mistroke
.87434 .15452 L
.86964 .15923 L
.86893 .15935 L
.8648 .16347 L
.86381 .16419 L
.85997 .16802 L
.85876 .16902 L
.85514 .17263 L
.85375 .17385 L
.85471 .17868 L
.85031 .18308 L
.84948 .18351 L
.84548 .18751 L
.84438 .18835 L
.84065 .19208 L
.83934 .19318 L
.83581 .1967 L
.83433 .19801 L
.8351 .20284 L
.83098 .20696 L
.82997 .20767 L
.82615 .21148 L
.82491 .2125 L
.82132 .21608 L
.81988 .21734 L
.82067 .22217 L
.81649 .22635 L
.8155 .227 L
.81165 .23084 L
.81043 .23183 L
.80682 .23543 L
.80539 .23666 L
.80615 .2415 L
.80199 .24565 L
.80099 .24633 L
.79716 .25015 L
.79591 .25116 L
.79233 .25473 L
.79088 .25599 L
.79157 .26082 L
.7875 .26489 L
.78642 .26566 L
.78266 .26941 L
.78135 .27049 L
.78222 .27532 L
.77783 .2797 L
.77694 .28015 L
.773 .28408 L
.77183 .28498 L
.76817 .28863 L
Mistroke
.76677 .28981 L
.76746 .29465 L
.76334 .29877 L
.76229 .29948 L
.7585 .30325 L
.7572 .30431 L
.75799 .30914 L
.75367 .31345 L
.75273 .31397 L
.74884 .31785 L
.74762 .31881 L
.74852 .32364 L
.74401 .32815 L
.74315 .32847 L
.73918 .33243 L
.73801 .3333 L
.73434 .33696 L
.73294 .33813 L
.73354 .34296 L
.72951 .34699 L
.72838 .3478 L
.72468 .35149 L
.7233 .35263 L
.7239 .35746 L
.71985 .3615 L
.71873 .36229 L
.71502 .36599 L
.71364 .36712 L
.71422 .37196 L
.71019 .37598 L
.70905 .37679 L
.70999 .38162 L
.70535 .38626 L
.70451 .38645 L
.70052 .39043 L
.69935 .39128 L
.70012 .39612 L
.69569 .40054 L
.69477 .40095 L
.69086 .40485 L
.68963 .40578 L
.69027 .41061 L
.68603 .41485 L
.68501 .41544 L
.68119 .41925 L
.67989 .42027 L
.68044 .42511 L
.67636 .42917 L
.67524 .42994 L
.67598 .43477 L
Mistroke
.67153 .43922 L
.67061 .4396 L
.6667 .4435 L
.66545 .44443 L
.66603 .44927 L
.66187 .45352 L
.66096 .4541 L
.66158 .45893 L
.65704 .46347 L
.65627 .46376 L
.6522 .46782 L
.65117 .46859 L
.6516 .47342 L
.64737 .47765 L
.64645 .47826 L
.64696 .48309 L
.64254 .48751 L
.64173 .48792 L
.64249 .49275 L
.63771 .49754 L
.63701 .49758 L
.63288 .50171 L
.63189 .50242 L
.63229 .50725 L
.62804 .51148 L
.62714 .51208 L
.62757 .51691 L
.62321 .52126 L
.62238 .52174 L
.62286 .52658 L
.61838 .53105 L
.61761 .53141 L
.61816 .53624 L
.61355 .54085 L
.61283 .54107 L
.60872 .54518 L
.60774 .5459 L
.60804 .55073 L
.60388 .55488 L
.60294 .55557 L
.60325 .5604 L
.59905 .56458 L
.59814 .56523 L
.59844 .57006 L
.59422 .57427 L
.59333 .57489 L
.59362 .57973 L
.58939 .58394 L
.58851 .58456 L
.58878 .58939 L
Mistroke
.58456 .59361 L
.58368 .59422 L
.58394 .59905 L
.58448 .60388 L
.57973 .60864 L
.57909 .60872 L
.5795 .61355 L
.57489 .61815 L
.57423 .61838 L
.57457 .62321 L
.57006 .62771 L
.56937 .62804 L
.56965 .63288 L
.56523 .63729 L
.56451 .63771 L
.56474 .64254 L
.5604 .64688 L
.55965 .64737 L
.55985 .6522 L
.56017 .65704 L
.55557 .66164 L
.55496 .66187 L
.55519 .6667 L
.55073 .67116 L
.55008 .67153 L
.55027 .67636 L
.55057 .68119 L
.5459 .68586 L
.54536 .68603 L
.54556 .69086 L
.54107 .69535 L
.54048 .69569 L
.54063 .70052 L
.54083 .70535 L
.53624 .70995 L
.53573 .71019 L
.53587 .71502 L
.53608 .71985 L
.53141 .72453 L
.53098 .72468 L
.5311 .72951 L
.53128 .73434 L
.52658 .73906 L
.52621 .73918 L
.52631 .74401 L
.52644 .74884 L
.52174 .75355 L
.52145 .75367 L
.52152 .7585 L
.52161 .76334 L
Mistroke
.51691 .76806 L
.51671 .76817 L
.51676 .773 L
.51681 .77783 L
.51686 .78266 L
.51208 .78749 L
.51207 .7875 L
.51208 .79227 L
.51214 .79233 L
.51219 .79716 L
.5122 .80199 L
.51691 .80465 L
.51753 .80682 L
.5189 .81165 L
.52023 .81649 L
.52155 .82132 L
.52174 .82205 L
.52282 .82615 L
.52406 .83098 L
.52527 .83581 L
.52646 .84065 L
.52658 .84114 L
.5276 .84548 L
.52871 .85031 L
.52978 .85514 L
.53083 .85997 L
.53141 .86273 L
.53183 .8648 L
.5328 .86964 L
.53373 .87447 L
.53462 .8793 L
.53548 .88413 L
.53624 .88862 L
.5363 .88896 L
.53707 .8938 L
.5378 .89863 L
.53849 .90346 L
.53913 .90829 L
.53973 .91312 L
.54029 .91796 L
.5408 .92279 L
.54107 .92562 L
.54125 .92762 L
.54166 .93245 L
.54201 .93728 L
.54231 .94211 L
.54256 .94695 L
.54275 .95178 L
.54287 .95661 L
.54294 .96144 L
Mistroke
.54294 .96627 L
.54287 .97111 L
.54273 .97594 L
.54251 .98077 L
Mfstroke
0 .37 .27 r
.98077 .02265 m
.98038 .02406 L
.97594 .02802 L
.97492 .02889 L
.97111 .03271 L
.96997 .03373 L
.96627 .03742 L
.96503 .03856 L
.96144 .04214 L
.96009 .04339 L
.96101 .04822 L
.95661 .05262 L
.95592 .05305 L
.95178 .05719 L
.9509 .05789 L
.94695 .06184 L
.94592 .06272 L
.94211 .06651 L
.94095 .06755 L
.93728 .07121 L
.936 .07238 L
.93702 .07721 L
.93245 .08179 L
.93183 .08204 L
.92762 .08626 L
.92678 .08688 L
.92279 .09087 L
.92178 .09171 L
.91796 .09553 L
.9168 .09654 L
.91312 .10021 L
.91184 .10137 L
.91277 .1062 L
.90829 .11068 L
.90761 .11104 L
.90346 .11518 L
.90256 .11587 L
.89863 .1198 L
.89756 .1207 L
.8938 .12446 L
.89258 .12553 L
.89372 .13036 L
.88896 .13511 L
.88836 .1352 L
.88413 .13942 L
.88328 .14003 L
.8793 .144 L
.87826 .14486 L
.87447 .14864 L
.87327 .14969 L
.87436 .15452 L
.86964 .15924 L
.86901 .15935 L
.8648 .16356 L
.86393 .16419 L
.85997 .16814 L
.8589 .16902 L
.85514 .17277 L
.85391 .17385 L
.85477 .17868 L
.85031 .18314 L
.84958 .18351 L
.84548 .18761 L
.84451 .18835 L
.84065 .19221 L
.8395 .19318 L
.83581 .19685 L
.83451 .19801 L
.83519 .20284 L
.83098 .20704 L
.83009 .20767 L
.82615 .2116 L
.82505 .2125 L
.82132 .21623 L
.82005 .21734 L
.82075 .22217 L
.81649 .22642 L
.81562 .227 L
.81165 .23096 L
.81057 .23183 L
.80682 .23557 L
.80556 .23666 L
.80623 .2415 L
.80199 .24573 L
.8011 .24633 L
.79716 .25027 L
.79605 .25116 L
.79233 .25488 L
.79104 .25599 L
.79166 .26082 L
.7875 .26498 L
.78655 .26566 L
.78266 .26953 L
.78151 .27049 L
.78227 .27532 L
.77783 .27976 L
.77705 .28015 L
.773 .28419 L
.77196 .28498 L
.76817 .28877 L
.76693 .28981 L
.76755 .29465 L
.76334 .29885 L
.76241 .29948 L
.7585 .30337 L
.75735 .30431 L
.75805 .30914 L
.75367 .31351 L
.75284 .31397 L
.74884 .31797 L
.74776 .31881 L
.74856 .32364 L
.74401 .32819 L
.74325 .32847 L
.73918 .33254 L
.73815 .3333 L
.73434 .33709 L
.7331 .33813 L
.73364 .34296 L
.72951 .34708 L
.72851 .3478 L
.72468 .35162 L
.72346 .35263 L
.72399 .35746 L
.71985 .3616 L
.71886 .36229 L
.71502 .36612 L
.7138 .36712 L
.71432 .37196 L
.71019 .37608 L
.70918 .37679 L
.71001 .38162 L
.70535 .38628 L
.70461 .38645 L
.70052 .39053 L
.69949 .39128 L
.70017 .39612 L
.69569 .40059 L
.69488 .40095 L
.69086 .40496 L
.68977 .40578 L
.69034 .41061 L
.68603 .41492 L
.68513 .41544 L
.68119 .41937 L
.68004 .42027 L
.68053 .42511 L
.67636 .42926 L
.67537 .42994 L
.67603 .43477 L
.67153 .43926 L
.67072 .4396 L
.6667 .44361 L
.6656 .44443 L
.66611 .44927 L
.66187 .4536 L
.66109 .4541 L
.66162 .45893 L
.65704 .46352 L
.65638 .46376 L
.6522 .46793 L
.65132 .46859 L
.65169 .47342 L
.64737 .47774 L
.64658 .47826 L
.64702 .48309 L
.64254 .48757 L
.64185 .48792 L
.6425 .49275 L
.63771 .49754 L
.63711 .49758 L
.63288 .50181 L
.63204 .50242 L
.63238 .50725 L
.62804 .51157 L
.62727 .51208 L
.62764 .51691 L
.62321 .52134 L
.6225 .52174 L
.62291 .52658 L
.61838 .5311 L
.61772 .53141 L
.61819 .53624 L
.61355 .54088 L
.61294 .54107 L
.60872 .54529 L
.60789 .5459 L
.60815 .55073 L
.60388 .55499 L
.60309 .55557 L
.60335 .5604 L
.59905 .56468 L
.59828 .56523 L
.59853 .57006 L
.59422 .57437 L
.59346 .57489 L
.59371 .57973 L
.58939 .58404 L
.58865 .58456 L
.58888 .58939 L
.58456 .59371 L
.58382 .59422 L
.58404 .59905 L
.58449 .60388 L
.57973 .60865 L
.57919 .60872 L
.57954 .61355 L
.57489 .61819 L
.57434 .61838 L
.57462 .62321 L
.57006 .62777 L
.56949 .62804 L
.56972 .63288 L
.56523 .63737 L
.56463 .63771 L
.56483 .64254 L
.5604 .64697 L
.55978 .64737 L
.55995 .6522 L
.56021 .65704 L
.55557 .66168 L
.55507 .66187 L
.55526 .6667 L
.55073 .67123 L
.55021 .67153 L
.55036 .67636 L
.5506 .68119 L
.5459 .6859 L
.54547 .68603 L
.54563 .69086 L
.54107 .69542 L
.54061 .69569 L
.54072 .70052 L
.54089 .70535 L
.53624 .71001 L
.53585 .71019 L
.53596 .71502 L
.53612 .71985 L
.53141 .72457 L
.53108 .72468 L
.53118 .72951 L
.53131 .73434 L
.52658 .73909 L
.52632 .73918 L
.52639 .74401 L
.52648 .74884 L
.52174 .7536 L
.52156 .75367 L
.52161 .7585 L
.52166 .76334 L
.51691 .76812 L
.51683 .76817 L
.51686 .773 L
.51689 .77783 L
.51691 .78266 L
.51691 .78536 L
.5176 .7875 L
.51913 .79233 L
.52064 .79716 L
.52174 .80075 L
.52212 .80199 L
.52357 .80682 L
.52499 .81165 L
.52638 .81649 L
.52658 .81715 L
.52775 .82132 L
.52908 .82615 L
.53038 .83098 L
.53141 .83484 L
.53166 .83581 L
.5329 .84065 L
.53411 .84548 L
.53529 .85031 L
.53624 .85429 L
.53644 .85514 L
.53755 .85997 L
.53863 .8648 L
.53967 .86964 L
.54069 .87447 L
.54107 .87635 L
.54166 .8793 L
.5426 .88413 L
.5435 .88896 L
.54437 .8938 L
.54519 .89863 L
.5459 .90295 L
.54598 .90346 L
.54673 .90829 L
.54744 .91312 L
.5481 .91796 L
.54873 .92279 L
.54931 .92762 L
.54984 .93245 L
.55033 .93728 L
.55073 .94163 L
.55078 .94211 L
.55117 .94695 L
.55151 .95178 L
.55181 .95661 L
.55204 .96144 L
.55223 .96627 L
.55236 .97111 L
.55243 .97594 L
.55243 .98077 L
.98077 .98077 L
F
0 g
.98077 .02265 m
.98038 .02406 L
.97594 .02802 L
.97492 .02889 L
.97111 .03271 L
.96997 .03373 L
.96627 .03742 L
.96503 .03856 L
.96144 .04214 L
.96009 .04339 L
.96101 .04822 L
.95661 .05262 L
.95592 .05305 L
.95178 .05719 L
.9509 .05789 L
.94695 .06184 L
.94592 .06272 L
.94211 .06651 L
.94095 .06755 L
.93728 .07121 L
.936 .07238 L
.93702 .07721 L
.93245 .08179 L
.93183 .08204 L
.92762 .08626 L
.92678 .08688 L
.92279 .09087 L
.92178 .09171 L
.91796 .09553 L
.9168 .09654 L
.91312 .10021 L
.91184 .10137 L
.91277 .1062 L
.90829 .11068 L
.90761 .11104 L
.90346 .11518 L
.90256 .11587 L
.89863 .1198 L
.89756 .1207 L
.8938 .12446 L
.89258 .12553 L
.89372 .13036 L
.88896 .13511 L
.88836 .1352 L
.88413 .13942 L
.88328 .14003 L
.8793 .144 L
.87826 .14486 L
.87447 .14864 L
.87327 .14969 L
Mistroke
.87436 .15452 L
.86964 .15924 L
.86901 .15935 L
.8648 .16356 L
.86393 .16419 L
.85997 .16814 L
.8589 .16902 L
.85514 .17277 L
.85391 .17385 L
.85477 .17868 L
.85031 .18314 L
.84958 .18351 L
.84548 .18761 L
.84451 .18835 L
.84065 .19221 L
.8395 .19318 L
.83581 .19685 L
.83451 .19801 L
.83519 .20284 L
.83098 .20704 L
.83009 .20767 L
.82615 .2116 L
.82505 .2125 L
.82132 .21623 L
.82005 .21734 L
.82075 .22217 L
.81649 .22642 L
.81562 .227 L
.81165 .23096 L
.81057 .23183 L
.80682 .23557 L
.80556 .23666 L
.80623 .2415 L
.80199 .24573 L
.8011 .24633 L
.79716 .25027 L
.79605 .25116 L
.79233 .25488 L
.79104 .25599 L
.79166 .26082 L
.7875 .26498 L
.78655 .26566 L
.78266 .26953 L
.78151 .27049 L
.78227 .27532 L
.77783 .27976 L
.77705 .28015 L
.773 .28419 L
.77196 .28498 L
.76817 .28877 L
Mistroke
.76693 .28981 L
.76755 .29465 L
.76334 .29885 L
.76241 .29948 L
.7585 .30337 L
.75735 .30431 L
.75805 .30914 L
.75367 .31351 L
.75284 .31397 L
.74884 .31797 L
.74776 .31881 L
.74856 .32364 L
.74401 .32819 L
.74325 .32847 L
.73918 .33254 L
.73815 .3333 L
.73434 .33709 L
.7331 .33813 L
.73364 .34296 L
.72951 .34708 L
.72851 .3478 L
.72468 .35162 L
.72346 .35263 L
.72399 .35746 L
.71985 .3616 L
.71886 .36229 L
.71502 .36612 L
.7138 .36712 L
.71432 .37196 L
.71019 .37608 L
.70918 .37679 L
.71001 .38162 L
.70535 .38628 L
.70461 .38645 L
.70052 .39053 L
.69949 .39128 L
.70017 .39612 L
.69569 .40059 L
.69488 .40095 L
.69086 .40496 L
.68977 .40578 L
.69034 .41061 L
.68603 .41492 L
.68513 .41544 L
.68119 .41937 L
.68004 .42027 L
.68053 .42511 L
.67636 .42926 L
.67537 .42994 L
.67603 .43477 L
Mistroke
.67153 .43926 L
.67072 .4396 L
.6667 .44361 L
.6656 .44443 L
.66611 .44927 L
.66187 .4536 L
.66109 .4541 L
.66162 .45893 L
.65704 .46352 L
.65638 .46376 L
.6522 .46793 L
.65132 .46859 L
.65169 .47342 L
.64737 .47774 L
.64658 .47826 L
.64702 .48309 L
.64254 .48757 L
.64185 .48792 L
.6425 .49275 L
.63771 .49754 L
.63711 .49758 L
.63288 .50181 L
.63204 .50242 L
.63238 .50725 L
.62804 .51157 L
.62727 .51208 L
.62764 .51691 L
.62321 .52134 L
.6225 .52174 L
.62291 .52658 L
.61838 .5311 L
.61772 .53141 L
.61819 .53624 L
.61355 .54088 L
.61294 .54107 L
.60872 .54529 L
.60789 .5459 L
.60815 .55073 L
.60388 .55499 L
.60309 .55557 L
.60335 .5604 L
.59905 .56468 L
.59828 .56523 L
.59853 .57006 L
.59422 .57437 L
.59346 .57489 L
.59371 .57973 L
.58939 .58404 L
.58865 .58456 L
.58888 .58939 L
Mistroke
.58456 .59371 L
.58382 .59422 L
.58404 .59905 L
.58449 .60388 L
.57973 .60865 L
.57919 .60872 L
.57954 .61355 L
.57489 .61819 L
.57434 .61838 L
.57462 .62321 L
.57006 .62777 L
.56949 .62804 L
.56972 .63288 L
.56523 .63737 L
.56463 .63771 L
.56483 .64254 L
.5604 .64697 L
.55978 .64737 L
.55995 .6522 L
.56021 .65704 L
.55557 .66168 L
.55507 .66187 L
.55526 .6667 L
.55073 .67123 L
.55021 .67153 L
.55036 .67636 L
.5506 .68119 L
.5459 .6859 L
.54547 .68603 L
.54563 .69086 L
.54107 .69542 L
.54061 .69569 L
.54072 .70052 L
.54089 .70535 L
.53624 .71001 L
.53585 .71019 L
.53596 .71502 L
.53612 .71985 L
.53141 .72457 L
.53108 .72468 L
.53118 .72951 L
.53131 .73434 L
.52658 .73909 L
.52632 .73918 L
.52639 .74401 L
.52648 .74884 L
.52174 .7536 L
.52156 .75367 L
.52161 .7585 L
.52166 .76334 L
Mistroke
.51691 .76812 L
.51683 .76817 L
.51686 .773 L
.51689 .77783 L
.51691 .78266 L
.51691 .78536 L
.5176 .7875 L
.51913 .79233 L
.52064 .79716 L
.52174 .80075 L
.52212 .80199 L
.52357 .80682 L
.52499 .81165 L
.52638 .81649 L
.52658 .81715 L
.52775 .82132 L
.52908 .82615 L
.53038 .83098 L
.53141 .83484 L
.53166 .83581 L
.5329 .84065 L
.53411 .84548 L
.53529 .85031 L
.53624 .85429 L
.53644 .85514 L
.53755 .85997 L
.53863 .8648 L
.53967 .86964 L
.54069 .87447 L
.54107 .87635 L
.54166 .8793 L
.5426 .88413 L
.5435 .88896 L
.54437 .8938 L
.54519 .89863 L
.5459 .90295 L
.54598 .90346 L
.54673 .90829 L
.54744 .91312 L
.5481 .91796 L
.54873 .92279 L
.54931 .92762 L
.54984 .93245 L
.55033 .93728 L
.55073 .94163 L
.55078 .94211 L
.55117 .94695 L
.55151 .95178 L
.55181 .95661 L
.55204 .96144 L
Mistroke
.55223 .96627 L
.55236 .97111 L
.55243 .97594 L
.55243 .98077 L
Mfstroke
0 .325 .301 r
.98077 .0228 m
.98044 .02406 L
.97594 .02814 L
.97506 .02889 L
.97111 .03285 L
.97012 .03373 L
.96627 .03757 L
.96519 .03856 L
.96144 .0423 L
.96027 .04339 L
.96107 .04822 L
.95661 .05268 L
.95601 .05305 L
.95178 .05729 L
.95102 .05789 L
.94695 .06196 L
.94605 .06272 L
.94211 .06665 L
.94111 .06755 L
.93728 .07137 L
.93617 .07238 L
.93706 .07721 L
.93245 .08182 L
.93192 .08204 L
.92762 .08634 L
.9269 .08688 L
.92279 .09098 L
.92192 .09171 L
.91796 .09566 L
.91696 .09654 L
.91312 .10037 L
.91201 .10137 L
.91282 .1062 L
.90829 .11073 L
.9077 .11104 L
.90346 .11528 L
.90268 .11587 L
.89863 .11992 L
.8977 .1207 L
.8938 .1246 L
.89274 .12553 L
.89373 .13036 L
.88896 .13513 L
.88844 .1352 L
.88413 .1395 L
.8834 .14003 L
.8793 .14412 L
.8784 .14486 L
.87447 .14878 L
.87343 .14969 L
.87437 .15452 L
.86964 .15926 L
.8691 .15935 L
.8648 .16364 L
.86405 .16419 L
.85997 .16826 L
.85905 .16902 L
.85514 .17292 L
.85407 .17385 L
.85482 .17868 L
.85031 .18319 L
.84968 .18351 L
.84548 .18771 L
.84464 .18835 L
.84065 .19234 L
.83965 .19318 L
.83581 .19701 L
.83468 .19801 L
.83527 .20284 L
.83098 .20713 L
.83021 .20767 L
.82615 .21172 L
.8252 .2125 L
.82132 .21638 L
.82022 .21734 L
.82082 .22217 L
.81649 .2265 L
.81574 .227 L
.81165 .23108 L
.81072 .23183 L
.80682 .23572 L
.80573 .23666 L
.80631 .2415 L
.80199 .24582 L
.80122 .24633 L
.79716 .25039 L
.7962 .25116 L
.79233 .25503 L
.79121 .25599 L
.79175 .26082 L
.7875 .26508 L
.78668 .26566 L
.78266 .26966 L
.78166 .27049 L
.78233 .27532 L
.77783 .27981 L
.77715 .28015 L
.773 .2843 L
.7721 .28498 L
.76817 .28891 L
.7671 .28981 L
.76763 .29465 L
.76334 .29894 L
.76253 .29948 L
.7585 .3035 L
.75751 .30431 L
.75811 .30914 L
.75367 .31358 L
.75295 .31397 L
.74884 .31808 L
.7479 .31881 L
.7486 .32364 L
.74401 .32823 L
.74336 .32847 L
.73918 .33264 L
.73829 .3333 L
.73434 .33723 L
.73327 .33813 L
.73373 .34296 L
.72951 .34718 L
.72865 .3478 L
.72468 .35175 L
.72363 .35263 L
.72409 .35746 L
.71985 .36169 L
.71899 .36229 L
.71502 .36626 L
.71397 .36712 L
.71441 .37196 L
.71019 .37618 L
.70932 .37679 L
.71004 .38162 L
.70535 .3863 L
.70471 .38645 L
.70052 .39063 L
.69963 .39128 L
.70022 .39612 L
.69569 .40064 L
.69499 .40095 L
.69086 .40507 L
.68992 .40578 L
.69041 .41061 L
.68603 .41499 L
.68525 .41544 L
.68119 .41949 L
.6802 .42027 L
.68062 .42511 L
.67636 .42936 L
.67551 .42994 L
.67607 .43477 L
.67153 .43931 L
.67083 .4396 L
.6667 .44372 L
.66575 .44443 L
.66619 .44927 L
.66187 .45369 L
.66122 .4541 L
.66167 .45893 L
.65704 .46356 L
.65649 .46376 L
.6522 .46805 L
.65147 .46859 L
.65178 .47342 L
.64737 .47783 L
.64672 .47826 L
.64708 .48309 L
.64254 .48763 L
.64197 .48792 L
.64251 .49275 L
.63771 .49755 L
.63722 .49758 L
.63288 .50192 L
.63218 .50242 L
.63246 .50725 L
.62804 .51166 L
.62741 .51208 L
.62771 .51691 L
.62321 .52141 L
.62263 .52174 L
.62297 .52658 L
.61838 .53116 L
.61784 .53141 L
.61823 .53624 L
.61355 .54092 L
.61305 .54107 L
.60872 .5454 L
.60804 .5459 L
.60825 .55073 L
.60388 .5551 L
.60323 .55557 L
.60345 .5604 L
.59905 .56479 L
.59842 .56523 L
.59863 .57006 L
.59422 .57447 L
.59361 .57489 L
.59381 .57973 L
.58939 .58414 L
.58879 .58456 L
.58898 .58939 L
.58456 .59381 L
.58396 .59422 L
.58414 .59905 L
.58451 .60388 L
.57973 .60867 L
.5793 .60872 L
.57958 .61355 L
.57489 .61823 L
.57445 .61838 L
.57468 .62321 L
.57006 .62783 L
.56961 .62804 L
.56979 .63288 L
.56523 .63744 L
.56476 .63771 L
.56492 .64254 L
.5604 .64706 L
.55992 .64737 L
.56005 .6522 L
.56025 .65704 L
.55557 .66172 L
.55519 .66187 L
.55534 .6667 L
.55073 .6713 L
.55033 .67153 L
.55045 .67636 L
.55064 .68119 L
.5459 .68593 L
.54558 .68603 L
.5457 .69086 L
.54107 .69549 L
.54073 .69569 L
.54082 .70052 L
.54094 .70535 L
.53624 .71006 L
.53597 .71019 L
.53605 .71502 L
.53616 .71985 L
.53141 .72461 L
.5312 .72468 L
.53126 .72951 L
.53135 .73434 L
.52658 .73913 L
.52643 .73918 L
.52647 .74401 L
.52653 .74884 L
.52174 .75364 L
.52167 .75367 L
.5217 .7585 L
.52172 .76334 L
.51699 .76817 L
.51703 .773 L
.52174 .77476 L
.5228 .77783 L
.52445 .78266 L
.52608 .7875 L
.52658 .78899 L
.52767 .79233 L
.52924 .79716 L
.53079 .80199 L
.53141 .80394 L
.53231 .80682 L
.5338 .81165 L
.53526 .81649 L
.53624 .81975 L
.5367 .82132 L
.53811 .82615 L
.53949 .83098 L
.54084 .83581 L
.54107 .83664 L
.54216 .84065 L
.54346 .84548 L
.54472 .85031 L
.5459 .85493 L
.54596 .85514 L
.54716 .85997 L
.54833 .8648 L
.54947 .86964 L
.55058 .87447 L
.55073 .87516 L
.55165 .8793 L
.5527 .88413 L
.5537 .88896 L
.55468 .8938 L
.55557 .89834 L
.55562 .89863 L
.55653 .90346 L
.5574 .90829 L
.55823 .91312 L
.55902 .91796 L
.55978 .92279 L
.5604 .9269 L
.5605 .92762 L
.56118 .93245 L
.56182 .93728 L
.56242 .94211 L
.56298 .94695 L
.56349 .95178 L
.56396 .95661 L
.56439 .96144 L
.56477 .96627 L
.5651 .97111 L
.56523 .97316 L
.56539 .97594 L
.56562 .98077 L
.98077 .98077 L
F
0 g
.98077 .0228 m
.98044 .02406 L
.97594 .02814 L
.97506 .02889 L
.97111 .03285 L
.97012 .03373 L
.96627 .03757 L
.96519 .03856 L
.96144 .0423 L
.96027 .04339 L
.96107 .04822 L
.95661 .05268 L
.95601 .05305 L
.95178 .05729 L
.95102 .05789 L
.94695 .06196 L
.94605 .06272 L
.94211 .06665 L
.94111 .06755 L
.93728 .07137 L
.93617 .07238 L
.93706 .07721 L
.93245 .08182 L
.93192 .08204 L
.92762 .08634 L
.9269 .08688 L
.92279 .09098 L
.92192 .09171 L
.91796 .09566 L
.91696 .09654 L
.91312 .10037 L
.91201 .10137 L
.91282 .1062 L
.90829 .11073 L
.9077 .11104 L
.90346 .11528 L
.90268 .11587 L
.89863 .11992 L
.8977 .1207 L
.8938 .1246 L
.89274 .12553 L
.89373 .13036 L
.88896 .13513 L
.88844 .1352 L
.88413 .1395 L
.8834 .14003 L
.8793 .14412 L
.8784 .14486 L
.87447 .14878 L
.87343 .14969 L
Mistroke
.87437 .15452 L
.86964 .15926 L
.8691 .15935 L
.8648 .16364 L
.86405 .16419 L
.85997 .16826 L
.85905 .16902 L
.85514 .17292 L
.85407 .17385 L
.85482 .17868 L
.85031 .18319 L
.84968 .18351 L
.84548 .18771 L
.84464 .18835 L
.84065 .19234 L
.83965 .19318 L
.83581 .19701 L
.83468 .19801 L
.83527 .20284 L
.83098 .20713 L
.83021 .20767 L
.82615 .21172 L
.8252 .2125 L
.82132 .21638 L
.82022 .21734 L
.82082 .22217 L
.81649 .2265 L
.81574 .227 L
.81165 .23108 L
.81072 .23183 L
.80682 .23572 L
.80573 .23666 L
.80631 .2415 L
.80199 .24582 L
.80122 .24633 L
.79716 .25039 L
.7962 .25116 L
.79233 .25503 L
.79121 .25599 L
.79175 .26082 L
.7875 .26508 L
.78668 .26566 L
.78266 .26966 L
.78166 .27049 L
.78233 .27532 L
.77783 .27981 L
.77715 .28015 L
.773 .2843 L
.7721 .28498 L
.76817 .28891 L
Mistroke
.7671 .28981 L
.76763 .29465 L
.76334 .29894 L
.76253 .29948 L
.7585 .3035 L
.75751 .30431 L
.75811 .30914 L
.75367 .31358 L
.75295 .31397 L
.74884 .31808 L
.7479 .31881 L
.7486 .32364 L
.74401 .32823 L
.74336 .32847 L
.73918 .33264 L
.73829 .3333 L
.73434 .33723 L
.73327 .33813 L
.73373 .34296 L
.72951 .34718 L
.72865 .3478 L
.72468 .35175 L
.72363 .35263 L
.72409 .35746 L
.71985 .36169 L
.71899 .36229 L
.71502 .36626 L
.71397 .36712 L
.71441 .37196 L
.71019 .37618 L
.70932 .37679 L
.71004 .38162 L
.70535 .3863 L
.70471 .38645 L
.70052 .39063 L
.69963 .39128 L
.70022 .39612 L
.69569 .40064 L
.69499 .40095 L
.69086 .40507 L
.68992 .40578 L
.69041 .41061 L
.68603 .41499 L
.68525 .41544 L
.68119 .41949 L
.6802 .42027 L
.68062 .42511 L
.67636 .42936 L
.67551 .42994 L
.67607 .43477 L
Mistroke
.67153 .43931 L
.67083 .4396 L
.6667 .44372 L
.66575 .44443 L
.66619 .44927 L
.66187 .45369 L
.66122 .4541 L
.66167 .45893 L
.65704 .46356 L
.65649 .46376 L
.6522 .46805 L
.65147 .46859 L
.65178 .47342 L
.64737 .47783 L
.64672 .47826 L
.64708 .48309 L
.64254 .48763 L
.64197 .48792 L
.64251 .49275 L
.63771 .49755 L
.63722 .49758 L
.63288 .50192 L
.63218 .50242 L
.63246 .50725 L
.62804 .51166 L
.62741 .51208 L
.62771 .51691 L
.62321 .52141 L
.62263 .52174 L
.62297 .52658 L
.61838 .53116 L
.61784 .53141 L
.61823 .53624 L
.61355 .54092 L
.61305 .54107 L
.60872 .5454 L
.60804 .5459 L
.60825 .55073 L
.60388 .5551 L
.60323 .55557 L
.60345 .5604 L
.59905 .56479 L
.59842 .56523 L
.59863 .57006 L
.59422 .57447 L
.59361 .57489 L
.59381 .57973 L
.58939 .58414 L
.58879 .58456 L
.58898 .58939 L
Mistroke
.58456 .59381 L
.58396 .59422 L
.58414 .59905 L
.58451 .60388 L
.57973 .60867 L
.5793 .60872 L
.57958 .61355 L
.57489 .61823 L
.57445 .61838 L
.57468 .62321 L
.57006 .62783 L
.56961 .62804 L
.56979 .63288 L
.56523 .63744 L
.56476 .63771 L
.56492 .64254 L
.5604 .64706 L
.55992 .64737 L
.56005 .6522 L
.56025 .65704 L
.55557 .66172 L
.55519 .66187 L
.55534 .6667 L
.55073 .6713 L
.55033 .67153 L
.55045 .67636 L
.55064 .68119 L
.5459 .68593 L
.54558 .68603 L
.5457 .69086 L
.54107 .69549 L
.54073 .69569 L
.54082 .70052 L
.54094 .70535 L
.53624 .71006 L
.53597 .71019 L
.53605 .71502 L
.53616 .71985 L
.53141 .72461 L
.5312 .72468 L
.53126 .72951 L
.53135 .73434 L
.52658 .73913 L
.52643 .73918 L
.52647 .74401 L
.52653 .74884 L
.52174 .75364 L
.52167 .75367 L
.5217 .7585 L
.52172 .76334 L
Mistroke
.51699 .76817 L
.51703 .773 L
.52174 .77476 L
.5228 .77783 L
.52445 .78266 L
.52608 .7875 L
.52658 .78899 L
.52767 .79233 L
.52924 .79716 L
.53079 .80199 L
.53141 .80394 L
.53231 .80682 L
.5338 .81165 L
.53526 .81649 L
.53624 .81975 L
.5367 .82132 L
.53811 .82615 L
.53949 .83098 L
.54084 .83581 L
.54107 .83664 L
.54216 .84065 L
.54346 .84548 L
.54472 .85031 L
.5459 .85493 L
.54596 .85514 L
.54716 .85997 L
.54833 .8648 L
.54947 .86964 L
.55058 .87447 L
.55073 .87516 L
.55165 .8793 L
.5527 .88413 L
.5537 .88896 L
.55468 .8938 L
.55557 .89834 L
.55562 .89863 L
.55653 .90346 L
.5574 .90829 L
.55823 .91312 L
.55902 .91796 L
.55978 .92279 L
.5604 .9269 L
.5605 .92762 L
.56118 .93245 L
.56182 .93728 L
.56242 .94211 L
.56298 .94695 L
.56349 .95178 L
.56396 .95661 L
.56439 .96144 L
Mistroke
.56477 .96627 L
.5651 .97111 L
.56523 .97316 L
.56539 .97594 L
.56562 .98077 L
Mfstroke
0 .246 .28 r
.98077 .02296 m
.98049 .02406 L
.97594 .02826 L
.9752 .02889 L
.97111 .03298 L
.97028 .03373 L
.96627 .03772 L
.96536 .03856 L
.96144 .04247 L
.96045 .04339 L
.96113 .04822 L
.95661 .05274 L
.95611 .05305 L
.95178 .05738 L
.95114 .05789 L
.94695 .06208 L
.94619 .06272 L
.94211 .06679 L
.94126 .06755 L
.93728 .07153 L
.93634 .07238 L
.9371 .07721 L
.93245 .08186 L
.932 .08204 L
.92762 .08643 L
.92701 .08688 L
.92279 .0911 L
.92205 .09171 L
.91796 .0958 L
.91711 .09654 L
.91312 .10052 L
.91218 .10137 L
.91287 .1062 L
.90829 .11078 L
.9078 .11104 L
.90346 .11537 L
.90281 .11587 L
.89863 .12004 L
.89785 .1207 L
.8938 .12475 L
.89291 .12553 L
.89374 .13036 L
.88896 .13514 L
.88853 .1352 L
.88413 .13959 L
.88351 .14003 L
.8793 .14424 L
.87854 .14486 L
.87447 .14893 L
.87359 .14969 L
.87439 .15452 L
.86964 .15927 L
.86918 .15935 L
.8648 .16373 L
.86417 .16419 L
.85997 .16838 L
.85919 .16902 L
.85514 .17306 L
.85424 .17385 L
.85487 .17868 L
.85031 .18324 L
.84978 .18351 L
.84548 .18781 L
.84477 .18835 L
.84065 .19247 L
.83981 .19318 L
.83581 .19716 L
.83486 .19801 L
.83536 .20284 L
.83098 .20722 L
.83033 .20767 L
.82615 .21185 L
.82535 .2125 L
.82132 .21653 L
.82039 .21734 L
.8209 .22217 L
.81649 .22658 L
.81585 .227 L
.81165 .2312 L
.81086 .23183 L
.80682 .23587 L
.8059 .23666 L
.8064 .2415 L
.80199 .2459 L
.80135 .24633 L
.79716 .25051 L
.79635 .25116 L
.79233 .25518 L
.79139 .25599 L
.79184 .26082 L
.7875 .26517 L
.78681 .26566 L
.78266 .26979 L
.78182 .27049 L
.78238 .27532 L
.77783 .27987 L
.77726 .28015 L
.773 .28441 L
.77224 .28498 L
.76817 .28905 L
.76726 .28981 L
.76772 .29465 L
.76334 .29902 L
.76266 .29948 L
.7585 .30363 L
.75766 .30431 L
.75817 .30914 L
.75367 .31364 L
.75307 .31397 L
.74884 .31819 L
.74805 .31881 L
.74864 .32364 L
.74401 .32827 L
.74346 .32847 L
.73918 .33275 L
.73843 .3333 L
.73434 .33737 L
.73344 .33813 L
.73383 .34296 L
.72951 .34728 L
.72879 .3478 L
.72468 .35189 L
.72379 .35263 L
.72418 .35746 L
.71985 .36179 L
.71913 .36229 L
.71502 .36639 L
.71413 .36712 L
.71451 .37196 L
.71019 .37627 L
.70946 .37679 L
.71006 .38162 L
.70535 .38633 L
.70481 .38645 L
.70052 .39074 L
.69977 .39128 L
.70027 .39612 L
.69569 .40069 L
.6951 .40095 L
.69086 .40518 L
.69007 .40578 L
.69049 .41061 L
.68603 .41507 L
.68538 .41544 L
.68119 .41961 L
.68035 .42027 L
.68071 .42511 L
.67636 .42945 L
.67564 .42994 L
.67612 .43477 L
.67153 .43936 L
.67094 .4396 L
.6667 .44383 L
.6659 .44443 L
.66627 .44927 L
.66187 .45377 L
.66135 .4541 L
.66171 .45893 L
.65704 .4636 L
.65661 .46376 L
.6522 .46816 L
.65162 .46859 L
.65187 .47342 L
.64737 .47792 L
.64685 .47826 L
.64715 .48309 L
.64254 .48769 L
.64209 .48792 L
.64251 .49275 L
.63771 .49756 L
.63732 .49758 L
.63288 .50203 L
.63233 .50242 L
.63255 .50725 L
.62804 .51175 L
.62755 .51208 L
.62779 .51691 L
.62321 .52148 L
.62276 .52174 L
.62302 .52658 L
.61838 .53122 L
.61796 .53141 L
.61826 .53624 L
.61355 .54095 L
.61316 .54107 L
.60872 .54551 L
.60819 .5459 L
.60836 .55073 L
.60388 .55521 L
.60338 .55557 L
.60355 .5604 L
.59905 .56489 L
.59857 .56523 L
.59873 .57006 L
.59422 .57457 L
.59375 .57489 L
.59391 .57973 L
.58939 .58424 L
.58893 .58456 L
.58908 .58939 L
.58456 .59391 L
.58411 .59422 L
.58425 .59905 L
.58452 .60388 L
.57973 .60868 L
.57941 .60872 L
.57962 .61355 L
.57489 .61827 L
.57457 .61838 L
.57474 .62321 L
.57006 .62789 L
.56973 .62804 L
.56987 .63288 L
.56523 .63752 L
.56489 .63771 L
.56501 .64254 L
.5604 .64715 L
.56006 .64737 L
.56015 .6522 L
.5603 .65704 L
.55557 .66177 L
.5553 .66187 L
.55541 .6667 L
.55073 .67138 L
.55046 .67153 L
.55054 .67636 L
.55067 .68119 L
.5459 .68596 L
.5457 .68603 L
.54577 .69086 L
.54107 .69557 L
.54086 .69569 L
.54092 .70052 L
.54099 .70535 L
.53624 .71012 L
.53609 .71019 L
.53613 .71502 L
.5362 .71985 L
.53141 .72465 L
.53131 .72468 L
.53134 .72951 L
.53138 .73434 L
.52658 .73916 L
.52654 .73918 L
.52656 .74401 L
.52657 .74884 L
.52658 .75328 L
.52672 .75367 L
.52857 .7585 L
.5304 .76334 L
.53141 .76603 L
.5322 .76817 L
.53398 .773 L
.53574 .77783 L
.53624 .77922 L
.53747 .78266 L
.53918 .7875 L
.54086 .79233 L
.54107 .79293 L
.54252 .79716 L
.54415 .80199 L
.54576 .80682 L
.5459 .80724 L
.54735 .81165 L
.54891 .81649 L
.55044 .82132 L
.55073 .82225 L
.55195 .82615 L
.55343 .83098 L
.55488 .83581 L
.55557 .83811 L
.55631 .84065 L
.55771 .84548 L
.55909 .85031 L
.5604 .85502 L
.56043 .85514 L
.56175 .85997 L
.56304 .8648 L
.5643 .86964 L
.56523 .87328 L
.56553 .87447 L
.56673 .8793 L
.56791 .88413 L
.56905 .88896 L
.57006 .89336 L
.57016 .8938 L
.57124 .89863 L
.57229 .90346 L
.57331 .90829 L
.57429 .91312 L
.57489 .91614 L
.57525 .91796 L
.57617 .92279 L
.57705 .92762 L
.5779 .93245 L
.57872 .93728 L
.5795 .94211 L
.57973 .94353 L
.58025 .94695 L
.58096 .95178 L
.58163 .95661 L
.58226 .96144 L
.58286 .96627 L
.58341 .97111 L
.58393 .97594 L
.58441 .98077 L
.98077 .98077 L
F
0 g
.98077 .02296 m
.98049 .02406 L
.97594 .02826 L
.9752 .02889 L
.97111 .03298 L
.97028 .03373 L
.96627 .03772 L
.96536 .03856 L
.96144 .04247 L
.96045 .04339 L
.96113 .04822 L
.95661 .05274 L
.95611 .05305 L
.95178 .05738 L
.95114 .05789 L
.94695 .06208 L
.94619 .06272 L
.94211 .06679 L
.94126 .06755 L
.93728 .07153 L
.93634 .07238 L
.9371 .07721 L
.93245 .08186 L
.932 .08204 L
.92762 .08643 L
.92701 .08688 L
.92279 .0911 L
.92205 .09171 L
.91796 .0958 L
.91711 .09654 L
.91312 .10052 L
.91218 .10137 L
.91287 .1062 L
.90829 .11078 L
.9078 .11104 L
.90346 .11537 L
.90281 .11587 L
.89863 .12004 L
.89785 .1207 L
.8938 .12475 L
.89291 .12553 L
.89374 .13036 L
.88896 .13514 L
.88853 .1352 L
.88413 .13959 L
.88351 .14003 L
.8793 .14424 L
.87854 .14486 L
.87447 .14893 L
.87359 .14969 L
Mistroke
.87439 .15452 L
.86964 .15927 L
.86918 .15935 L
.8648 .16373 L
.86417 .16419 L
.85997 .16838 L
.85919 .16902 L
.85514 .17306 L
.85424 .17385 L
.85487 .17868 L
.85031 .18324 L
.84978 .18351 L
.84548 .18781 L
.84477 .18835 L
.84065 .19247 L
.83981 .19318 L
.83581 .19716 L
.83486 .19801 L
.83536 .20284 L
.83098 .20722 L
.83033 .20767 L
.82615 .21185 L
.82535 .2125 L
.82132 .21653 L
.82039 .21734 L
.8209 .22217 L
.81649 .22658 L
.81585 .227 L
.81165 .2312 L
.81086 .23183 L
.80682 .23587 L
.8059 .23666 L
.8064 .2415 L
.80199 .2459 L
.80135 .24633 L
.79716 .25051 L
.79635 .25116 L
.79233 .25518 L
.79139 .25599 L
.79184 .26082 L
.7875 .26517 L
.78681 .26566 L
.78266 .26979 L
.78182 .27049 L
.78238 .27532 L
.77783 .27987 L
.77726 .28015 L
.773 .28441 L
.77224 .28498 L
.76817 .28905 L
Mistroke
.76726 .28981 L
.76772 .29465 L
.76334 .29902 L
.76266 .29948 L
.7585 .30363 L
.75766 .30431 L
.75817 .30914 L
.75367 .31364 L
.75307 .31397 L
.74884 .31819 L
.74805 .31881 L
.74864 .32364 L
.74401 .32827 L
.74346 .32847 L
.73918 .33275 L
.73843 .3333 L
.73434 .33737 L
.73344 .33813 L
.73383 .34296 L
.72951 .34728 L
.72879 .3478 L
.72468 .35189 L
.72379 .35263 L
.72418 .35746 L
.71985 .36179 L
.71913 .36229 L
.71502 .36639 L
.71413 .36712 L
.71451 .37196 L
.71019 .37627 L
.70946 .37679 L
.71006 .38162 L
.70535 .38633 L
.70481 .38645 L
.70052 .39074 L
.69977 .39128 L
.70027 .39612 L
.69569 .40069 L
.6951 .40095 L
.69086 .40518 L
.69007 .40578 L
.69049 .41061 L
.68603 .41507 L
.68538 .41544 L
.68119 .41961 L
.68035 .42027 L
.68071 .42511 L
.67636 .42945 L
.67564 .42994 L
.67612 .43477 L
Mistroke
.67153 .43936 L
.67094 .4396 L
.6667 .44383 L
.6659 .44443 L
.66627 .44927 L
.66187 .45377 L
.66135 .4541 L
.66171 .45893 L
.65704 .4636 L
.65661 .46376 L
.6522 .46816 L
.65162 .46859 L
.65187 .47342 L
.64737 .47792 L
.64685 .47826 L
.64715 .48309 L
.64254 .48769 L
.64209 .48792 L
.64251 .49275 L
.63771 .49756 L
.63732 .49758 L
.63288 .50203 L
.63233 .50242 L
.63255 .50725 L
.62804 .51175 L
.62755 .51208 L
.62779 .51691 L
.62321 .52148 L
.62276 .52174 L
.62302 .52658 L
.61838 .53122 L
.61796 .53141 L
.61826 .53624 L
.61355 .54095 L
.61316 .54107 L
.60872 .54551 L
.60819 .5459 L
.60836 .55073 L
.60388 .55521 L
.60338 .55557 L
.60355 .5604 L
.59905 .56489 L
.59857 .56523 L
.59873 .57006 L
.59422 .57457 L
.59375 .57489 L
.59391 .57973 L
.58939 .58424 L
.58893 .58456 L
.58908 .58939 L
Mistroke
.58456 .59391 L
.58411 .59422 L
.58425 .59905 L
.58452 .60388 L
.57973 .60868 L
.57941 .60872 L
.57962 .61355 L
.57489 .61827 L
.57457 .61838 L
.57474 .62321 L
.57006 .62789 L
.56973 .62804 L
.56987 .63288 L
.56523 .63752 L
.56489 .63771 L
.56501 .64254 L
.5604 .64715 L
.56006 .64737 L
.56015 .6522 L
.5603 .65704 L
.55557 .66177 L
.5553 .66187 L
.55541 .6667 L
.55073 .67138 L
.55046 .67153 L
.55054 .67636 L
.55067 .68119 L
.5459 .68596 L
.5457 .68603 L
.54577 .69086 L
.54107 .69557 L
.54086 .69569 L
.54092 .70052 L
.54099 .70535 L
.53624 .71012 L
.53609 .71019 L
.53613 .71502 L
.5362 .71985 L
.53141 .72465 L
.53131 .72468 L
.53134 .72951 L
.53138 .73434 L
.52658 .73916 L
.52654 .73918 L
.52656 .74401 L
.52657 .74884 L
.52658 .75328 L
.52672 .75367 L
.52857 .7585 L
.5304 .76334 L
Mistroke
.53141 .76603 L
.5322 .76817 L
.53398 .773 L
.53574 .77783 L
.53624 .77922 L
.53747 .78266 L
.53918 .7875 L
.54086 .79233 L
.54107 .79293 L
.54252 .79716 L
.54415 .80199 L
.54576 .80682 L
.5459 .80724 L
.54735 .81165 L
.54891 .81649 L
.55044 .82132 L
.55073 .82225 L
.55195 .82615 L
.55343 .83098 L
.55488 .83581 L
.55557 .83811 L
.55631 .84065 L
.55771 .84548 L
.55909 .85031 L
.5604 .85502 L
.56043 .85514 L
.56175 .85997 L
.56304 .8648 L
.5643 .86964 L
.56523 .87328 L
.56553 .87447 L
.56673 .8793 L
.56791 .88413 L
.56905 .88896 L
.57006 .89336 L
.57016 .8938 L
.57124 .89863 L
.57229 .90346 L
.57331 .90829 L
.57429 .91312 L
.57489 .91614 L
.57525 .91796 L
.57617 .92279 L
.57705 .92762 L
.5779 .93245 L
.57872 .93728 L
.5795 .94211 L
.57973 .94353 L
.58025 .94695 L
.58096 .95178 L
Mistroke
.58163 .95661 L
.58226 .96144 L
.58286 .96627 L
.58341 .97111 L
.58393 .97594 L
.58441 .98077 L
Mfstroke
0 .161 .235 r
.98077 .02314 m
.98055 .02406 L
.97594 .02838 L
.97534 .02889 L
.97111 .03313 L
.97043 .03373 L
.96627 .03788 L
.96553 .03856 L
.96144 .04265 L
.96064 .04339 L
.96119 .04822 L
.95661 .0528 L
.95621 .05305 L
.95178 .05748 L
.95126 .05789 L
.94695 .0622 L
.94634 .06272 L
.94211 .06694 L
.94143 .06755 L
.93728 .07169 L
.93652 .07238 L
.93713 .07721 L
.93245 .0819 L
.93209 .08204 L
.92762 .08651 L
.92713 .08688 L
.92279 .09121 L
.92219 .09171 L
.91796 .09594 L
.91727 .09654 L
.91312 .10069 L
.91236 .10137 L
.91292 .1062 L
.90829 .11083 L
.90789 .11104 L
.90346 .11547 L
.90293 .11587 L
.89863 .12017 L
.898 .1207 L
.8938 .1249 L
.89307 .12553 L
.89375 .13036 L
.88896 .13515 L
.88861 .1352 L
.88413 .13967 L
.88363 .14003 L
.8793 .14436 L
.87869 .14486 L
.87447 .14907 L
.87376 .14969 L
.8744 .15452 L
.86964 .15929 L
.86927 .15935 L
.8648 .16382 L
.86429 .16419 L
.85997 .1685 L
.85934 .16902 L
.85514 .17321 L
.85441 .17385 L
.85492 .17868 L
.85031 .18329 L
.84988 .18351 L
.84548 .18791 L
.84491 .18835 L
.84065 .1926 L
.83996 .19318 L
.83581 .19732 L
.83504 .19801 L
.83545 .20284 L
.83098 .2073 L
.83045 .20767 L
.82615 .21197 L
.8255 .2125 L
.82132 .21668 L
.82056 .21734 L
.82098 .22217 L
.81649 .22666 L
.81598 .227 L
.81165 .23132 L
.81101 .23183 L
.80682 .23602 L
.80607 .23666 L
.80648 .2415 L
.80199 .24598 L
.80147 .24633 L
.79716 .25063 L
.79651 .25116 L
.79233 .25533 L
.79157 .25599 L
.79194 .26082 L
.7875 .26526 L
.78694 .26566 L
.78266 .26992 L
.78198 .27049 L
.78244 .27532 L
.77783 .27992 L
.77737 .28015 L
.773 .28452 L
.77239 .28498 L
.76817 .2892 L
.76744 .28981 L
.7678 .29465 L
.76334 .29911 L
.76279 .29948 L
.7585 .30376 L
.75782 .30431 L
.75824 .30914 L
.75367 .31371 L
.75318 .31397 L
.74884 .31831 L
.7482 .31881 L
.74868 .32364 L
.74401 .32831 L
.74356 .32847 L
.73918 .33285 L
.73857 .3333 L
.73434 .33752 L
.73361 .33813 L
.73393 .34296 L
.72951 .34738 L
.72892 .3478 L
.72468 .35203 L
.72396 .35263 L
.72428 .35746 L
.71985 .36188 L
.71927 .36229 L
.71502 .36653 L
.7143 .36712 L
.71461 .37196 L
.71019 .37637 L
.70959 .37679 L
.71009 .38162 L
.70535 .38635 L
.70492 .38645 L
.70052 .39084 L
.69991 .39128 L
.70032 .39612 L
.69569 .40074 L
.69521 .40095 L
.69086 .4053 L
.69022 .40578 L
.69056 .41061 L
.68603 .41514 L
.6855 .41544 L
.68119 .41974 L
.68051 .42027 L
.6808 .42511 L
.67636 .42954 L
.67578 .42994 L
.67617 .43477 L
.67153 .43941 L
.67105 .4396 L
.6667 .44395 L
.66605 .44443 L
.66635 .44927 L
.66187 .45386 L
.66149 .4541 L
.66175 .45893 L
.65704 .46365 L
.65672 .46376 L
.6522 .46828 L
.65178 .46859 L
.65196 .47342 L
.64737 .47801 L
.647 .47826 L
.64721 .48309 L
.64254 .48776 L
.64221 .48792 L
.64252 .49275 L
.63771 .49757 L
.63743 .49758 L
.63288 .50214 L
.63248 .50242 L
.63265 .50725 L
.62804 .51185 L
.62769 .51208 L
.62786 .51691 L
.62321 .52156 L
.62289 .52174 L
.62308 .52658 L
.61838 .53127 L
.61808 .53141 L
.6183 .53624 L
.61355 .54099 L
.61328 .54107 L
.60872 .54563 L
.60835 .5459 L
.60847 .55073 L
.60388 .55532 L
.60354 .55557 L
.60365 .5604 L
.59905 .565 L
.59872 .56523 L
.59883 .57006 L
.59422 .57467 L
.5939 .57489 L
.59401 .57973 L
.58939 .58435 L
.58908 .58456 L
.58918 .58939 L
.58456 .59402 L
.58426 .59422 L
.58435 .59905 L
.58453 .60388 L
.57973 .60869 L
.57952 .60872 L
.57965 .61355 L
.57489 .61831 L
.57469 .61838 L
.5748 .62321 L
.57006 .62795 L
.56986 .62804 L
.56994 .63288 L
.56523 .63759 L
.56503 .63771 L
.5651 .64254 L
.5604 .64724 L
.5602 .64737 L
.56026 .6522 L
.56034 .65704 L
.55557 .66181 L
.55542 .66187 L
.55548 .6667 L
.55073 .67145 L
.5506 .67153 L
.55064 .67636 L
.5507 .68119 L
.5459 .686 L
.54581 .68603 L
.54585 .69086 L
.54107 .69565 L
.54099 .69569 L
.54102 .70052 L
.54105 .70535 L
.53624 .71017 L
.53621 .71019 L
.53622 .71502 L
.53624 .71985 L
.53146 .72468 L
.53624 .72571 L
.53788 .72951 L
.53994 .73434 L
.54107 .73701 L
.54198 .73918 L
.544 .74401 L
.5459 .74859 L
.54601 .74884 L
.54799 .75367 L
.54994 .7585 L
.55073 .76047 L
.55188 .76334 L
.5538 .76817 L
.55557 .77268 L
.55569 .773 L
.55756 .77783 L
.55941 .78266 L
.5604 .78526 L
.56124 .7875 L
.56305 .79233 L
.56483 .79716 L
.56523 .79825 L
.56659 .80199 L
.56833 .80682 L
.57005 .81165 L
.57006 .8117 L
.57174 .81649 L
.57341 .82132 L
.57489 .82569 L
.57505 .82615 L
.57667 .83098 L
.57827 .83581 L
.57973 .84029 L
.57984 .84065 L
.58139 .84548 L
.58291 .85031 L
.58441 .85514 L
.58456 .85561 L
.58589 .85997 L
.58733 .8648 L
.58876 .86964 L
.58939 .87181 L
.59015 .87447 L
.59153 .8793 L
.59287 .88413 L
.59419 .88896 L
.59422 .88909 L
.59548 .8938 L
.59674 .89863 L
.59798 .90346 L
.59905 .90774 L
.59919 .90829 L
.60037 .91312 L
.60152 .91796 L
.60265 .92279 L
.60374 .92762 L
.60388 .92826 L
.60481 .93245 L
.60584 .93728 L
.60685 .94211 L
.60783 .94695 L
.60872 .9515 L
.60877 .95178 L
.60968 .95661 L
.61057 .96144 L
.61142 .96627 L
.61223 .97111 L
.61302 .97594 L
.61355 .97932 L
.61377 .98077 L
.98077 .98077 L
F
0 g
.98077 .02314 m
.98055 .02406 L
.97594 .02838 L
.97534 .02889 L
.97111 .03313 L
.97043 .03373 L
.96627 .03788 L
.96553 .03856 L
.96144 .04265 L
.96064 .04339 L
.96119 .04822 L
.95661 .0528 L
.95621 .05305 L
.95178 .05748 L
.95126 .05789 L
.94695 .0622 L
.94634 .06272 L
.94211 .06694 L
.94143 .06755 L
.93728 .07169 L
.93652 .07238 L
.93713 .07721 L
.93245 .0819 L
.93209 .08204 L
.92762 .08651 L
.92713 .08688 L
.92279 .09121 L
.92219 .09171 L
.91796 .09594 L
.91727 .09654 L
.91312 .10069 L
.91236 .10137 L
.91292 .1062 L
.90829 .11083 L
.90789 .11104 L
.90346 .11547 L
.90293 .11587 L
.89863 .12017 L
.898 .1207 L
.8938 .1249 L
.89307 .12553 L
.89375 .13036 L
.88896 .13515 L
.88861 .1352 L
.88413 .13967 L
.88363 .14003 L
.8793 .14436 L
.87869 .14486 L
.87447 .14907 L
.87376 .14969 L
Mistroke
.8744 .15452 L
.86964 .15929 L
.86927 .15935 L
.8648 .16382 L
.86429 .16419 L
.85997 .1685 L
.85934 .16902 L
.85514 .17321 L
.85441 .17385 L
.85492 .17868 L
.85031 .18329 L
.84988 .18351 L
.84548 .18791 L
.84491 .18835 L
.84065 .1926 L
.83996 .19318 L
.83581 .19732 L
.83504 .19801 L
.83545 .20284 L
.83098 .2073 L
.83045 .20767 L
.82615 .21197 L
.8255 .2125 L
.82132 .21668 L
.82056 .21734 L
.82098 .22217 L
.81649 .22666 L
.81598 .227 L
.81165 .23132 L
.81101 .23183 L
.80682 .23602 L
.80607 .23666 L
.80648 .2415 L
.80199 .24598 L
.80147 .24633 L
.79716 .25063 L
.79651 .25116 L
.79233 .25533 L
.79157 .25599 L
.79194 .26082 L
.7875 .26526 L
.78694 .26566 L
.78266 .26992 L
.78198 .27049 L
.78244 .27532 L
.77783 .27992 L
.77737 .28015 L
.773 .28452 L
.77239 .28498 L
.76817 .2892 L
Mistroke
.76744 .28981 L
.7678 .29465 L
.76334 .29911 L
.76279 .29948 L
.7585 .30376 L
.75782 .30431 L
.75824 .30914 L
.75367 .31371 L
.75318 .31397 L
.74884 .31831 L
.7482 .31881 L
.74868 .32364 L
.74401 .32831 L
.74356 .32847 L
.73918 .33285 L
.73857 .3333 L
.73434 .33752 L
.73361 .33813 L
.73393 .34296 L
.72951 .34738 L
.72892 .3478 L
.72468 .35203 L
.72396 .35263 L
.72428 .35746 L
.71985 .36188 L
.71927 .36229 L
.71502 .36653 L
.7143 .36712 L
.71461 .37196 L
.71019 .37637 L
.70959 .37679 L
.71009 .38162 L
.70535 .38635 L
.70492 .38645 L
.70052 .39084 L
.69991 .39128 L
.70032 .39612 L
.69569 .40074 L
.69521 .40095 L
.69086 .4053 L
.69022 .40578 L
.69056 .41061 L
.68603 .41514 L
.6855 .41544 L
.68119 .41974 L
.68051 .42027 L
.6808 .42511 L
.67636 .42954 L
.67578 .42994 L
.67617 .43477 L
Mistroke
.67153 .43941 L
.67105 .4396 L
.6667 .44395 L
.66605 .44443 L
.66635 .44927 L
.66187 .45386 L
.66149 .4541 L
.66175 .45893 L
.65704 .46365 L
.65672 .46376 L
.6522 .46828 L
.65178 .46859 L
.65196 .47342 L
.64737 .47801 L
.647 .47826 L
.64721 .48309 L
.64254 .48776 L
.64221 .48792 L
.64252 .49275 L
.63771 .49757 L
.63743 .49758 L
.63288 .50214 L
.63248 .50242 L
.63265 .50725 L
.62804 .51185 L
.62769 .51208 L
.62786 .51691 L
.62321 .52156 L
.62289 .52174 L
.62308 .52658 L
.61838 .53127 L
.61808 .53141 L
.6183 .53624 L
.61355 .54099 L
.61328 .54107 L
.60872 .54563 L
.60835 .5459 L
.60847 .55073 L
.60388 .55532 L
.60354 .55557 L
.60365 .5604 L
.59905 .565 L
.59872 .56523 L
.59883 .57006 L
.59422 .57467 L
.5939 .57489 L
.59401 .57973 L
.58939 .58435 L
.58908 .58456 L
.58918 .58939 L
Mistroke
.58456 .59402 L
.58426 .59422 L
.58435 .59905 L
.58453 .60388 L
.57973 .60869 L
.57952 .60872 L
.57965 .61355 L
.57489 .61831 L
.57469 .61838 L
.5748 .62321 L
.57006 .62795 L
.56986 .62804 L
.56994 .63288 L
.56523 .63759 L
.56503 .63771 L
.5651 .64254 L
.5604 .64724 L
.5602 .64737 L
.56026 .6522 L
.56034 .65704 L
.55557 .66181 L
.55542 .66187 L
.55548 .6667 L
.55073 .67145 L
.5506 .67153 L
.55064 .67636 L
.5507 .68119 L
.5459 .686 L
.54581 .68603 L
.54585 .69086 L
.54107 .69565 L
.54099 .69569 L
.54102 .70052 L
.54105 .70535 L
.53624 .71017 L
.53621 .71019 L
.53622 .71502 L
.53624 .71985 L
.53146 .72468 L
.53624 .72571 L
.53788 .72951 L
.53994 .73434 L
.54107 .73701 L
.54198 .73918 L
.544 .74401 L
.5459 .74859 L
.54601 .74884 L
.54799 .75367 L
.54994 .7585 L
.55073 .76047 L
Mistroke
.55188 .76334 L
.5538 .76817 L
.55557 .77268 L
.55569 .773 L
.55756 .77783 L
.55941 .78266 L
.5604 .78526 L
.56124 .7875 L
.56305 .79233 L
.56483 .79716 L
.56523 .79825 L
.56659 .80199 L
.56833 .80682 L
.57005 .81165 L
.57006 .8117 L
.57174 .81649 L
.57341 .82132 L
.57489 .82569 L
.57505 .82615 L
.57667 .83098 L
.57827 .83581 L
.57973 .84029 L
.57984 .84065 L
.58139 .84548 L
.58291 .85031 L
.58441 .85514 L
.58456 .85561 L
.58589 .85997 L
.58733 .8648 L
.58876 .86964 L
.58939 .87181 L
.59015 .87447 L
.59153 .8793 L
.59287 .88413 L
.59419 .88896 L
.59422 .88909 L
.59548 .8938 L
.59674 .89863 L
.59798 .90346 L
.59905 .90774 L
.59919 .90829 L
.60037 .91312 L
.60152 .91796 L
.60265 .92279 L
.60374 .92762 L
.60388 .92826 L
.60481 .93245 L
.60584 .93728 L
.60685 .94211 L
.60783 .94695 L
Mistroke
.60872 .9515 L
.60877 .95178 L
.60968 .95661 L
.61057 .96144 L
.61142 .96627 L
.61223 .97111 L
.61302 .97594 L
.61355 .97932 L
.61377 .98077 L
Mfstroke
0 .093 .19 r
.98077 .02333 m
.98061 .02406 L
.97594 .0285 L
.97548 .02889 L
.97111 .03327 L
.97059 .03373 L
.96627 .03804 L
.96571 .03856 L
.96144 .04282 L
.96083 .04339 L
.96125 .04822 L
.95661 .05286 L
.9563 .05305 L
.95178 .05758 L
.95139 .05789 L
.94695 .06232 L
.94648 .06272 L
.94211 .06708 L
.94159 .06755 L
.93728 .07185 L
.9367 .07238 L
.93717 .07721 L
.93245 .08193 L
.93218 .08204 L
.92762 .0866 L
.92725 .08688 L
.92279 .09133 L
.92234 .09171 L
.91796 .09609 L
.91744 .09654 L
.91312 .10085 L
.91254 .10137 L
.91297 .1062 L
.90829 .11088 L
.90799 .11104 L
.90346 .11556 L
.90306 .11587 L
.89863 .1203 L
.89815 .1207 L
.8938 .12505 L
.89325 .12553 L
.89376 .13036 L
.88896 .13516 L
.8887 .1352 L
.88413 .13976 L
.88375 .14003 L
.8793 .14448 L
.87883 .14486 L
.87447 .14922 L
.87393 .14969 L
.87442 .15452 L
.86964 .15931 L
.86936 .15935 L
.8648 .16391 L
.86441 .16419 L
.85997 .16862 L
.85949 .16902 L
.85514 .17337 L
.85458 .17385 L
.85498 .17868 L
.85031 .18335 L
.84998 .18351 L
.84548 .18802 L
.84505 .18835 L
.84065 .19274 L
.84013 .19318 L
.83581 .19749 L
.83522 .19801 L
.83554 .20284 L
.83098 .20739 L
.83058 .20767 L
.82615 .2121 L
.82566 .2125 L
.82132 .21684 L
.82074 .21734 L
.82107 .22217 L
.81649 .22675 L
.8161 .227 L
.81165 .23144 L
.81117 .23183 L
.80682 .23617 L
.80625 .23666 L
.80656 .2415 L
.80199 .24607 L
.8016 .24633 L
.79716 .25076 L
.79666 .25116 L
.79233 .25549 L
.79175 .25599 L
.79203 .26082 L
.7875 .26536 L
.78707 .26566 L
.78266 .27006 L
.78214 .27049 L
.78249 .27532 L
.77783 .27998 L
.77748 .28015 L
.773 .28463 L
.77253 .28498 L
.76817 .28934 L
.76761 .28981 L
.76789 .29465 L
.76334 .2992 L
.76292 .29948 L
.7585 .30389 L
.75799 .30431 L
.7583 .30914 L
.75367 .31377 L
.7533 .31397 L
.74884 .31843 L
.74835 .31881 L
.74872 .32364 L
.74401 .32835 L
.74367 .32847 L
.73918 .33296 L
.73871 .3333 L
.73434 .33767 L
.73378 .33813 L
.73403 .34296 L
.72951 .34748 L
.72907 .3478 L
.72468 .35218 L
.72413 .35263 L
.72438 .35746 L
.71985 .36198 L
.71941 .36229 L
.71502 .36668 L
.71447 .36712 L
.71471 .37196 L
.71019 .37647 L
.70974 .37679 L
.71011 .38162 L
.70535 .38638 L
.70502 .38645 L
.70052 .39095 L
.70006 .39128 L
.70037 .39612 L
.69569 .40079 L
.69533 .40095 L
.69086 .40541 L
.69037 .40578 L
.69063 .41061 L
.68603 .41521 L
.68563 .41544 L
.68119 .41987 L
.68068 .42027 L
.6809 .42511 L
.67636 .42964 L
.67592 .42994 L
.67622 .43477 L
.67153 .43945 L
.67117 .4396 L
.6667 .44407 L
.6662 .44443 L
.66644 .44927 L
.66187 .45395 L
.66163 .4541 L
.6618 .45893 L
.65704 .46369 L
.65684 .46376 L
.6522 .4684 L
.65194 .46859 L
.65205 .47342 L
.64737 .47811 L
.64714 .47826 L
.64727 .48309 L
.64254 .48782 L
.64234 .48792 L
.64253 .49275 L
.63771 .49757 L
.63754 .49758 L
.63288 .50225 L
.63264 .50242 L
.63274 .50725 L
.62804 .51194 L
.62783 .51208 L
.62794 .51691 L
.62321 .52164 L
.62302 .52174 L
.62313 .52658 L
.61838 .53133 L
.61821 .53141 L
.61833 .53624 L
.61355 .54102 L
.6134 .54107 L
.60872 .54575 L
.60851 .5459 L
.60858 .55073 L
.60388 .55543 L
.60369 .55557 L
.60376 .5604 L
.59905 .56511 L
.59887 .56523 L
.59894 .57006 L
.59422 .57478 L
.59406 .57489 L
.59411 .57973 L
.58939 .58445 L
.58924 .58456 L
.58929 .58939 L
.58456 .59412 L
.58441 .59422 L
.58446 .59905 L
.58455 .60388 L
.57973 .60871 L
.57963 .60872 L
.57969 .61355 L
.57489 .61835 L
.57481 .61838 L
.57485 .62321 L
.57006 .62801 L
.56998 .62804 L
.57002 .63288 L
.56523 .63767 L
.56516 .63771 L
.56519 .64254 L
.5604 .64734 L
.56034 .64737 L
.56036 .6522 L
.56039 .65704 L
.55557 .66186 L
.55554 .66187 L
.55556 .6667 L
.55073 .67153 L
.55073 .67153 L
.55073 .67635 L
.55074 .67636 L
.55074 .68119 L
.55557 .68255 L
.55729 .68603 L
.55969 .69086 L
.5604 .69231 L
.56206 .69569 L
.56441 .70052 L
.56523 .70221 L
.56675 .70535 L
.56907 .71019 L
.57006 .71227 L
.57137 .71502 L
.57365 .71985 L
.57489 .7225 L
.57591 .72468 L
.57816 .72951 L
.57973 .73291 L
.58038 .73434 L
.58259 .73918 L
.58456 .74351 L
.58478 .74401 L
.58695 .74884 L
.5891 .75367 L
.58939 .75432 L
.59123 .7585 L
.59335 .76334 L
.59422 .76535 L
.59544 .76817 L
.59751 .773 L
.59905 .77662 L
.59957 .77783 L
.6016 .78266 L
.60362 .7875 L
.60388 .78814 L
.60561 .79233 L
.60759 .79716 L
.60872 .79995 L
.60954 .80199 L
.61147 .80682 L
.61339 .81165 L
.61355 .81206 L
.61528 .81649 L
.61715 .82132 L
.61838 .82451 L
.61901 .82615 L
.62084 .83098 L
.62265 .83581 L
.62321 .83733 L
.62444 .84065 L
.6262 .84548 L
.62795 .85031 L
.62804 .85057 L
.62967 .85514 L
.63138 .85997 L
.63288 .86428 L
.63306 .8648 L
.63472 .86964 L
.63635 .87447 L
.63771 .87852 L
.63797 .8793 L
.63956 .88413 L
.64113 .88896 L
.64254 .89338 L
.64267 .8938 L
.64419 .89863 L
.64569 .90346 L
.64717 .90829 L
.64737 .90896 L
.64862 .91312 L
.65005 .91796 L
.65146 .92279 L
.6522 .92539 L
.65284 .92762 L
.65419 .93245 L
.65552 .93728 L
.65683 .94211 L
.65704 .94288 L
.65811 .94695 L
.65937 .95178 L
.6606 .95661 L
.66181 .96144 L
.66187 .96169 L
.66299 .96627 L
.66414 .97111 L
.66527 .97594 L
.66637 .98077 L
.98077 .98077 L
F
0 g
.98077 .02333 m
.98061 .02406 L
.97594 .0285 L
.97548 .02889 L
.97111 .03327 L
.97059 .03373 L
.96627 .03804 L
.96571 .03856 L
.96144 .04282 L
.96083 .04339 L
.96125 .04822 L
.95661 .05286 L
.9563 .05305 L
.95178 .05758 L
.95139 .05789 L
.94695 .06232 L
.94648 .06272 L
.94211 .06708 L
.94159 .06755 L
.93728 .07185 L
.9367 .07238 L
.93717 .07721 L
.93245 .08193 L
.93218 .08204 L
.92762 .0866 L
.92725 .08688 L
.92279 .09133 L
.92234 .09171 L
.91796 .09609 L
.91744 .09654 L
.91312 .10085 L
.91254 .10137 L
.91297 .1062 L
.90829 .11088 L
.90799 .11104 L
.90346 .11556 L
.90306 .11587 L
.89863 .1203 L
.89815 .1207 L
.8938 .12505 L
.89325 .12553 L
.89376 .13036 L
.88896 .13516 L
.8887 .1352 L
.88413 .13976 L
.88375 .14003 L
.8793 .14448 L
.87883 .14486 L
.87447 .14922 L
.87393 .14969 L
Mistroke
.87442 .15452 L
.86964 .15931 L
.86936 .15935 L
.8648 .16391 L
.86441 .16419 L
.85997 .16862 L
.85949 .16902 L
.85514 .17337 L
.85458 .17385 L
.85498 .17868 L
.85031 .18335 L
.84998 .18351 L
.84548 .18802 L
.84505 .18835 L
.84065 .19274 L
.84013 .19318 L
.83581 .19749 L
.83522 .19801 L
.83554 .20284 L
.83098 .20739 L
.83058 .20767 L
.82615 .2121 L
.82566 .2125 L
.82132 .21684 L
.82074 .21734 L
.82107 .22217 L
.81649 .22675 L
.8161 .227 L
.81165 .23144 L
.81117 .23183 L
.80682 .23617 L
.80625 .23666 L
.80656 .2415 L
.80199 .24607 L
.8016 .24633 L
.79716 .25076 L
.79666 .25116 L
.79233 .25549 L
.79175 .25599 L
.79203 .26082 L
.7875 .26536 L
.78707 .26566 L
.78266 .27006 L
.78214 .27049 L
.78249 .27532 L
.77783 .27998 L
.77748 .28015 L
.773 .28463 L
.77253 .28498 L
.76817 .28934 L
Mistroke
.76761 .28981 L
.76789 .29465 L
.76334 .2992 L
.76292 .29948 L
.7585 .30389 L
.75799 .30431 L
.7583 .30914 L
.75367 .31377 L
.7533 .31397 L
.74884 .31843 L
.74835 .31881 L
.74872 .32364 L
.74401 .32835 L
.74367 .32847 L
.73918 .33296 L
.73871 .3333 L
.73434 .33767 L
.73378 .33813 L
.73403 .34296 L
.72951 .34748 L
.72907 .3478 L
.72468 .35218 L
.72413 .35263 L
.72438 .35746 L
.71985 .36198 L
.71941 .36229 L
.71502 .36668 L
.71447 .36712 L
.71471 .37196 L
.71019 .37647 L
.70974 .37679 L
.71011 .38162 L
.70535 .38638 L
.70502 .38645 L
.70052 .39095 L
.70006 .39128 L
.70037 .39612 L
.69569 .40079 L
.69533 .40095 L
.69086 .40541 L
.69037 .40578 L
.69063 .41061 L
.68603 .41521 L
.68563 .41544 L
.68119 .41987 L
.68068 .42027 L
.6809 .42511 L
.67636 .42964 L
.67592 .42994 L
.67622 .43477 L
Mistroke
.67153 .43945 L
.67117 .4396 L
.6667 .44407 L
.6662 .44443 L
.66644 .44927 L
.66187 .45395 L
.66163 .4541 L
.6618 .45893 L
.65704 .46369 L
.65684 .46376 L
.6522 .4684 L
.65194 .46859 L
.65205 .47342 L
.64737 .47811 L
.64714 .47826 L
.64727 .48309 L
.64254 .48782 L
.64234 .48792 L
.64253 .49275 L
.63771 .49757 L
.63754 .49758 L
.63288 .50225 L
.63264 .50242 L
.63274 .50725 L
.62804 .51194 L
.62783 .51208 L
.62794 .51691 L
.62321 .52164 L
.62302 .52174 L
.62313 .52658 L
.61838 .53133 L
.61821 .53141 L
.61833 .53624 L
.61355 .54102 L
.6134 .54107 L
.60872 .54575 L
.60851 .5459 L
.60858 .55073 L
.60388 .55543 L
.60369 .55557 L
.60376 .5604 L
.59905 .56511 L
.59887 .56523 L
.59894 .57006 L
.59422 .57478 L
.59406 .57489 L
.59411 .57973 L
.58939 .58445 L
.58924 .58456 L
.58929 .58939 L
Mistroke
.58456 .59412 L
.58441 .59422 L
.58446 .59905 L
.58455 .60388 L
.57973 .60871 L
.57963 .60872 L
.57969 .61355 L
.57489 .61835 L
.57481 .61838 L
.57485 .62321 L
.57006 .62801 L
.56998 .62804 L
.57002 .63288 L
.56523 .63767 L
.56516 .63771 L
.56519 .64254 L
.5604 .64734 L
.56034 .64737 L
.56036 .6522 L
.56039 .65704 L
.55557 .66186 L
.55554 .66187 L
.55556 .6667 L
.55073 .67153 L
.55073 .67153 L
.55073 .67635 L
.55074 .67636 L
.55074 .68119 L
.55557 .68255 L
.55729 .68603 L
.55969 .69086 L
.5604 .69231 L
.56206 .69569 L
.56441 .70052 L
.56523 .70221 L
.56675 .70535 L
.56907 .71019 L
.57006 .71227 L
.57137 .71502 L
.57365 .71985 L
.57489 .7225 L
.57591 .72468 L
.57816 .72951 L
.57973 .73291 L
.58038 .73434 L
.58259 .73918 L
.58456 .74351 L
.58478 .74401 L
.58695 .74884 L
.5891 .75367 L
Mistroke
.58939 .75432 L
.59123 .7585 L
.59335 .76334 L
.59422 .76535 L
.59544 .76817 L
.59751 .773 L
.59905 .77662 L
.59957 .77783 L
.6016 .78266 L
.60362 .7875 L
.60388 .78814 L
.60561 .79233 L
.60759 .79716 L
.60872 .79995 L
.60954 .80199 L
.61147 .80682 L
.61339 .81165 L
.61355 .81206 L
.61528 .81649 L
.61715 .82132 L
.61838 .82451 L
.61901 .82615 L
.62084 .83098 L
.62265 .83581 L
.62321 .83733 L
.62444 .84065 L
.6262 .84548 L
.62795 .85031 L
.62804 .85057 L
.62967 .85514 L
.63138 .85997 L
.63288 .86428 L
.63306 .8648 L
.63472 .86964 L
.63635 .87447 L
.63771 .87852 L
.63797 .8793 L
.63956 .88413 L
.64113 .88896 L
.64254 .89338 L
.64267 .8938 L
.64419 .89863 L
.64569 .90346 L
.64717 .90829 L
.64737 .90896 L
.64862 .91312 L
.65005 .91796 L
.65146 .92279 L
.6522 .92539 L
.65284 .92762 L
Mistroke
.65419 .93245 L
.65552 .93728 L
.65683 .94211 L
.65704 .94288 L
.65811 .94695 L
.65937 .95178 L
.6606 .95661 L
.66181 .96144 L
.66187 .96169 L
.66299 .96627 L
.66414 .97111 L
.66527 .97594 L
.66637 .98077 L
Mfstroke
0 .043 .145 r
.98077 .02355 m
.98066 .02406 L
.97594 .02863 L
.97563 .02889 L
.97111 .03342 L
.97076 .03373 L
.96627 .03821 L
.96589 .03856 L
.96144 .04301 L
.96103 .04339 L
.96131 .04822 L
.95661 .05293 L
.9564 .05305 L
.95178 .05768 L
.95151 .05789 L
.94695 .06245 L
.94663 .06272 L
.94211 .06723 L
.94176 .06755 L
.93728 .07202 L
.93689 .07238 L
.93721 .07721 L
.93245 .08197 L
.93227 .08204 L
.92762 .08669 L
.92737 .08688 L
.92279 .09146 L
.92248 .09171 L
.91796 .09623 L
.9176 .09654 L
.91312 .10102 L
.91273 .10137 L
.91302 .1062 L
.90829 .11093 L
.90809 .11104 L
.90346 .11566 L
.90319 .11587 L
.89863 .12043 L
.8983 .1207 L
.8938 .1252 L
.89342 .12553 L
.89377 .13036 L
.88896 .13517 L
.88879 .1352 L
.88413 .13985 L
.88388 .14003 L
.8793 .1446 L
.87898 .14486 L
.87447 .14937 L
.8741 .14969 L
.87444 .15452 L
.86964 .15932 L
.86945 .15935 L
.8648 .164 L
.86454 .16419 L
.85997 .16875 L
.85965 .16902 L
.85514 .17352 L
.85476 .17385 L
.85503 .17868 L
.85031 .1834 L
.85009 .18351 L
.84548 .18812 L
.84519 .18835 L
.84065 .19288 L
.84029 .19318 L
.83581 .19766 L
.83541 .19801 L
.83563 .20284 L
.83098 .20749 L
.83071 .20767 L
.82615 .21223 L
.82582 .2125 L
.82132 .217 L
.82093 .21734 L
.82115 .22217 L
.81649 .22683 L
.81622 .227 L
.81165 .23157 L
.81132 .23183 L
.80682 .23633 L
.80644 .23666 L
.80665 .2415 L
.80199 .24615 L
.80172 .24633 L
.79716 .25089 L
.79682 .25116 L
.79233 .25565 L
.79193 .25599 L
.79213 .26082 L
.7875 .26545 L
.78721 .26566 L
.78266 .2702 L
.78231 .27049 L
.78255 .27532 L
.77783 .28004 L
.7776 .28015 L
.773 .28474 L
.77268 .28498 L
.76817 .2895 L
.76779 .28981 L
.76798 .29465 L
.76334 .29929 L
.76306 .29948 L
.7585 .30403 L
.75815 .30431 L
.75837 .30914 L
.75367 .31384 L
.75342 .31397 L
.74884 .31855 L
.74851 .31881 L
.74876 .32364 L
.74401 .32839 L
.74378 .32847 L
.73918 .33307 L
.73886 .3333 L
.73434 .33782 L
.73396 .33813 L
.73413 .34296 L
.72951 .34758 L
.72921 .3478 L
.72468 .35232 L
.72431 .35263 L
.72448 .35746 L
.71985 .36208 L
.71955 .36229 L
.71502 .36682 L
.71465 .36712 L
.71481 .37196 L
.71019 .37658 L
.70988 .37679 L
.71014 .38162 L
.70535 .3864 L
.70513 .38645 L
.70052 .39106 L
.70021 .39128 L
.70042 .39612 L
.69569 .40084 L
.69545 .40095 L
.69086 .40553 L
.69053 .40578 L
.69071 .41061 L
.68603 .41529 L
.68576 .41544 L
.68119 .42 L
.68084 .42027 L
.681 .42511 L
.67636 .42974 L
.67606 .42994 L
.67626 .43477 L
.67153 .4395 L
.67129 .4396 L
.6667 .44419 L
.66636 .44443 L
.66652 .44927 L
.66187 .45404 L
.66177 .4541 L
.66184 .45893 L
.65704 .46373 L
.65696 .46376 L
.6522 .46852 L
.6521 .46859 L
.65215 .47342 L
.64737 .4782 L
.64729 .47826 L
.64734 .48309 L
.64254 .48789 L
.64247 .48792 L
.64254 .49275 L
.63771 .49758 L
.63765 .49758 L
.63288 .50236 L
.6328 .50242 L
.63283 .50725 L
.62804 .51204 L
.62798 .51208 L
.62801 .51691 L
.62321 .52171 L
.62316 .52174 L
.62319 .52658 L
.61838 .53139 L
.61834 .53141 L
.61837 .53624 L
.61355 .54106 L
.61352 .54107 L
.60872 .54587 L
.60868 .5459 L
.60869 .55073 L
.60388 .55555 L
.60386 .55557 L
.60387 .5604 L
.59905 .56522 L
.59904 .56523 L
.59904 .57006 L
.59422 .57489 L
.59421 .57489 L
.59422 .57973 L
.5894 .58456 L
.59422 .58582 L
.59642 .58939 L
.59905 .59367 L
.59939 .59422 L
.60234 .59905 L
.60388 .60158 L
.60528 .60388 L
.60821 .60872 L
.60872 .60956 L
.61112 .61355 L
.61355 .6176 L
.61402 .61838 L
.6169 .62321 L
.61838 .62571 L
.61976 .62804 L
.62261 .63288 L
.62321 .63389 L
.62545 .63771 L
.62804 .64215 L
.62827 .64254 L
.63108 .64737 L
.63288 .65048 L
.63387 .6522 L
.63664 .65704 L
.63771 .65889 L
.63941 .66187 L
.64215 .6667 L
.64254 .66738 L
.64488 .67153 L
.64737 .67596 L
.6476 .67636 L
.6503 .68119 L
.6522 .68462 L
.65298 .68603 L
.65565 .69086 L
.65704 .69338 L
.6583 .69569 L
.66094 .70052 L
.66187 .70223 L
.66356 .70535 L
.66617 .71019 L
.6667 .71117 L
.66876 .71502 L
.67133 .71985 L
.67153 .72022 L
.67389 .72468 L
.67636 .72938 L
.67643 .72951 L
.67896 .73434 L
.68119 .73864 L
.68147 .73918 L
.68396 .74401 L
.68603 .74803 L
.68644 .74884 L
.6889 .75367 L
.69086 .75753 L
.69135 .7585 L
.69378 .76334 L
.69569 .76716 L
.69619 .76817 L
.69859 .773 L
.70052 .77692 L
.70097 .77783 L
.70333 .78266 L
.70535 .78683 L
.70568 .7875 L
.70801 .79233 L
.71019 .79688 L
.71032 .79716 L
.71261 .80199 L
.71489 .80682 L
.71502 .80709 L
.71715 .81165 L
.7194 .81649 L
.71985 .81746 L
.72163 .82132 L
.72384 .82615 L
.72468 .82801 L
.72603 .83098 L
.7282 .83581 L
.72951 .83874 L
.73036 .84065 L
.7325 .84548 L
.73434 .84968 L
.73462 .85031 L
.73673 .85514 L
.73881 .85997 L
.73918 .86082 L
.74088 .8648 L
.74293 .86964 L
.74401 .87219 L
.74497 .87447 L
.74698 .8793 L
.74884 .8838 L
.74898 .88413 L
.75095 .88896 L
.75291 .8938 L
.75367 .89568 L
.75485 .89863 L
.75678 .90346 L
.7585 .90784 L
.75868 .90829 L
.76056 .91312 L
.76243 .91796 L
.76334 .92032 L
.76428 .92279 L
.76611 .92762 L
.76791 .93245 L
.76817 .93313 L
.7697 .93728 L
.77147 .94211 L
.773 .94632 L
.77322 .94695 L
.77496 .95178 L
.77667 .95661 L
.77783 .95993 L
.77836 .96144 L
.78003 .96627 L
.78168 .97111 L
.78266 .974 L
.78331 .97594 L
.78493 .98077 L
.98077 .98077 L
F
0 g
.98077 .02355 m
.98066 .02406 L
.97594 .02863 L
.97563 .02889 L
.97111 .03342 L
.97076 .03373 L
.96627 .03821 L
.96589 .03856 L
.96144 .04301 L
.96103 .04339 L
.96131 .04822 L
.95661 .05293 L
.9564 .05305 L
.95178 .05768 L
.95151 .05789 L
.94695 .06245 L
.94663 .06272 L
.94211 .06723 L
.94176 .06755 L
.93728 .07202 L
.93689 .07238 L
.93721 .07721 L
.93245 .08197 L
.93227 .08204 L
.92762 .08669 L
.92737 .08688 L
.92279 .09146 L
.92248 .09171 L
.91796 .09623 L
.9176 .09654 L
.91312 .10102 L
.91273 .10137 L
.91302 .1062 L
.90829 .11093 L
.90809 .11104 L
.90346 .11566 L
.90319 .11587 L
.89863 .12043 L
.8983 .1207 L
.8938 .1252 L
.89342 .12553 L
.89377 .13036 L
.88896 .13517 L
.88879 .1352 L
.88413 .13985 L
.88388 .14003 L
.8793 .1446 L
.87898 .14486 L
.87447 .14937 L
.8741 .14969 L
Mistroke
.87444 .15452 L
.86964 .15932 L
.86945 .15935 L
.8648 .164 L
.86454 .16419 L
.85997 .16875 L
.85965 .16902 L
.85514 .17352 L
.85476 .17385 L
.85503 .17868 L
.85031 .1834 L
.85009 .18351 L
.84548 .18812 L
.84519 .18835 L
.84065 .19288 L
.84029 .19318 L
.83581 .19766 L
.83541 .19801 L
.83563 .20284 L
.83098 .20749 L
.83071 .20767 L
.82615 .21223 L
.82582 .2125 L
.82132 .217 L
.82093 .21734 L
.82115 .22217 L
.81649 .22683 L
.81622 .227 L
.81165 .23157 L
.81132 .23183 L
.80682 .23633 L
.80644 .23666 L
.80665 .2415 L
.80199 .24615 L
.80172 .24633 L
.79716 .25089 L
.79682 .25116 L
.79233 .25565 L
.79193 .25599 L
.79213 .26082 L
.7875 .26545 L
.78721 .26566 L
.78266 .2702 L
.78231 .27049 L
.78255 .27532 L
.77783 .28004 L
.7776 .28015 L
.773 .28474 L
.77268 .28498 L
.76817 .2895 L
Mistroke
.76779 .28981 L
.76798 .29465 L
.76334 .29929 L
.76306 .29948 L
.7585 .30403 L
.75815 .30431 L
.75837 .30914 L
.75367 .31384 L
.75342 .31397 L
.74884 .31855 L
.74851 .31881 L
.74876 .32364 L
.74401 .32839 L
.74378 .32847 L
.73918 .33307 L
.73886 .3333 L
.73434 .33782 L
.73396 .33813 L
.73413 .34296 L
.72951 .34758 L
.72921 .3478 L
.72468 .35232 L
.72431 .35263 L
.72448 .35746 L
.71985 .36208 L
.71955 .36229 L
.71502 .36682 L
.71465 .36712 L
.71481 .37196 L
.71019 .37658 L
.70988 .37679 L
.71014 .38162 L
.70535 .3864 L
.70513 .38645 L
.70052 .39106 L
.70021 .39128 L
.70042 .39612 L
.69569 .40084 L
.69545 .40095 L
.69086 .40553 L
.69053 .40578 L
.69071 .41061 L
.68603 .41529 L
.68576 .41544 L
.68119 .42 L
.68084 .42027 L
.681 .42511 L
.67636 .42974 L
.67606 .42994 L
.67626 .43477 L
Mistroke
.67153 .4395 L
.67129 .4396 L
.6667 .44419 L
.66636 .44443 L
.66652 .44927 L
.66187 .45404 L
.66177 .4541 L
.66184 .45893 L
.65704 .46373 L
.65696 .46376 L
.6522 .46852 L
.6521 .46859 L
.65215 .47342 L
.64737 .4782 L
.64729 .47826 L
.64734 .48309 L
.64254 .48789 L
.64247 .48792 L
.64254 .49275 L
.63771 .49758 L
.63765 .49758 L
.63288 .50236 L
.6328 .50242 L
.63283 .50725 L
.62804 .51204 L
.62798 .51208 L
.62801 .51691 L
.62321 .52171 L
.62316 .52174 L
.62319 .52658 L
.61838 .53139 L
.61834 .53141 L
.61837 .53624 L
.61355 .54106 L
.61352 .54107 L
.60872 .54587 L
.60868 .5459 L
.60869 .55073 L
.60388 .55555 L
.60386 .55557 L
.60387 .5604 L
.59905 .56522 L
.59904 .56523 L
.59904 .57006 L
.59422 .57489 L
.59421 .57489 L
.59422 .57973 L
.5894 .58456 L
.59422 .58582 L
.59642 .58939 L
Mistroke
.59905 .59367 L
.59939 .59422 L
.60234 .59905 L
.60388 .60158 L
.60528 .60388 L
.60821 .60872 L
.60872 .60956 L
.61112 .61355 L
.61355 .6176 L
.61402 .61838 L
.6169 .62321 L
.61838 .62571 L
.61976 .62804 L
.62261 .63288 L
.62321 .63389 L
.62545 .63771 L
.62804 .64215 L
.62827 .64254 L
.63108 .64737 L
.63288 .65048 L
.63387 .6522 L
.63664 .65704 L
.63771 .65889 L
.63941 .66187 L
.64215 .6667 L
.64254 .66738 L
.64488 .67153 L
.64737 .67596 L
.6476 .67636 L
.6503 .68119 L
.6522 .68462 L
.65298 .68603 L
.65565 .69086 L
.65704 .69338 L
.6583 .69569 L
.66094 .70052 L
.66187 .70223 L
.66356 .70535 L
.66617 .71019 L
.6667 .71117 L
.66876 .71502 L
.67133 .71985 L
.67153 .72022 L
.67389 .72468 L
.67636 .72938 L
.67643 .72951 L
.67896 .73434 L
.68119 .73864 L
.68147 .73918 L
.68396 .74401 L
Mistroke
.68603 .74803 L
.68644 .74884 L
.6889 .75367 L
.69086 .75753 L
.69135 .7585 L
.69378 .76334 L
.69569 .76716 L
.69619 .76817 L
.69859 .773 L
.70052 .77692 L
.70097 .77783 L
.70333 .78266 L
.70535 .78683 L
.70568 .7875 L
.70801 .79233 L
.71019 .79688 L
.71032 .79716 L
.71261 .80199 L
.71489 .80682 L
.71502 .80709 L
.71715 .81165 L
.7194 .81649 L
.71985 .81746 L
.72163 .82132 L
.72384 .82615 L
.72468 .82801 L
.72603 .83098 L
.7282 .83581 L
.72951 .83874 L
.73036 .84065 L
.7325 .84548 L
.73434 .84968 L
.73462 .85031 L
.73673 .85514 L
.73881 .85997 L
.73918 .86082 L
.74088 .8648 L
.74293 .86964 L
.74401 .87219 L
.74497 .87447 L
.74698 .8793 L
.74884 .8838 L
.74898 .88413 L
.75095 .88896 L
.75291 .8938 L
.75367 .89568 L
.75485 .89863 L
.75678 .90346 L
.7585 .90784 L
.75868 .90829 L
Mistroke
.76056 .91312 L
.76243 .91796 L
.76334 .92032 L
.76428 .92279 L
.76611 .92762 L
.76791 .93245 L
.76817 .93313 L
.7697 .93728 L
.77147 .94211 L
.773 .94632 L
.77322 .94695 L
.77496 .95178 L
.77667 .95661 L
.77783 .95993 L
.77836 .96144 L
.78003 .96627 L
.78168 .97111 L
.78266 .974 L
.78331 .97594 L
.78493 .98077 L
Mfstroke
0 .01 .1 r
.98077 .70969 m
.97693 .70535 L
.97594 .70485 L
.97162 .70052 L
.97111 .70001 L
.96627 .69998 L
.96199 .69569 L
.96144 .69514 L
.95717 .69086 L
.95661 .6903 L
.95235 .68603 L
.95178 .68546 L
.94752 .68119 L
.94695 .68062 L
.9427 .67636 L
.94211 .67578 L
.93728 .67575 L
.93308 .67153 L
.93245 .67091 L
.92825 .6667 L
.92762 .66606 L
.92343 .66187 L
.92279 .66122 L
.91861 .65704 L
.91796 .65638 L
.91379 .6522 L
.91312 .65154 L
.90829 .65151 L
.90416 .64737 L
.90346 .64667 L
.89934 .64254 L
.89863 .64183 L
.89451 .63771 L
.8938 .63699 L
.88969 .63288 L
.88896 .63215 L
.88413 .63212 L
.88007 .62804 L
.8793 .62728 L
.87524 .62321 L
.87447 .62244 L
.87042 .61838 L
.86964 .6176 L
.8656 .61355 L
.8648 .61276 L
.86077 .60872 L
.85997 .60792 L
.85514 .60789 L
.85115 .60388 L
.85031 .60305 L
.84633 .59905 L
.84548 .5982 L
.8415 .59422 L
.84065 .59336 L
.83668 .58939 L
.83581 .58852 L
.83186 .58456 L
.83098 .58368 L
.82615 .58365 L
.82223 .57973 L
.82132 .57881 L
.81741 .57489 L
.81649 .57397 L
.81258 .57006 L
.81165 .56913 L
.80776 .56523 L
.80682 .56429 L
.80199 .56426 L
.79813 .5604 L
.79716 .55942 L
.79331 .55557 L
.79233 .55458 L
.78849 .55073 L
.7875 .54974 L
.78366 .5459 L
.78266 .5449 L
.77884 .54107 L
.77783 .54006 L
.773 .54003 L
.76921 .53624 L
.76817 .53519 L
.76439 .53141 L
.76334 .53035 L
.75957 .52658 L
.7585 .52551 L
.75474 .52174 L
.75367 .52067 L
.74884 .52064 L
.74512 .51691 L
.74401 .5158 L
.74029 .51208 L
.73918 .51096 L
.73547 .50725 L
.73434 .50612 L
.73065 .50242 L
.72951 .50128 L
.72582 .49758 L
.72468 .49644 L
.71985 .49641 L
.7162 .49275 L
.71502 .49157 L
.71137 .48792 L
.71019 .48673 L
.70655 .48309 L
.70535 .48189 L
.70173 .47826 L
.70052 .47705 L
.6969 .47342 L
.69569 .47221 L
.69086 .47218 L
.68728 .46859 L
.68603 .46734 L
.68245 .46376 L
.68119 .4625 L
.67763 .45893 L
.67636 .45766 L
.6728 .4541 L
.67153 .45282 L
.6667 .45279 L
.66661 .44927 L
.66653 .44443 L
.6667 .44431 L
.67141 .4396 L
.67153 .43955 L
.67631 .43477 L
.67621 .42994 L
.67636 .42984 L
.68109 .42511 L
.68102 .42027 L
.68119 .42014 L
.68589 .41544 L
.68603 .41536 L
.69078 .41061 L
.69069 .40578 L
.69086 .40565 L
.69557 .40095 L
.69569 .40089 L
.70047 .39612 L
.70036 .39128 L
.70052 .39117 L
.70524 .38645 L
.70535 .38643 L
.71016 .38162 L
.71003 .37679 L
.71019 .37668 L
.71491 .37196 L
.71483 .36712 L
.71502 .36697 L
.7197 .36229 L
.71985 .36219 L
.72458 .35746 L
.72449 .35263 L
.72468 .35247 L
.72936 .3478 L
.72951 .34769 L
.73424 .34296 L
.73415 .33813 L
.73434 .33797 L
.73902 .3333 L
.73918 .33319 L
.74389 .32847 L
.74401 .32843 L
.7488 .32364 L
.74867 .31881 L
.74884 .31868 L
.75355 .31397 L
.75367 .31391 L
.75844 .30914 L
.75833 .30431 L
.7585 .30417 L
.76319 .29948 L
.76334 .29938 L
.76807 .29465 L
.76798 .28981 L
.76817 .28965 L
.77284 .28498 L
.773 .28486 L
.77771 .28015 L
.77783 .28009 L
.78261 .27532 L
.78248 .27049 L
.78266 .27034 L
.78735 .26566 L
.7875 .26555 L
.79223 .26082 L
.79213 .25599 L
.79233 .25582 L
.79699 .25116 L
.79716 .25102 L
.80186 .24633 L
.80199 .24624 L
.80673 .2415 L
.80663 .23666 L
.80682 .23649 L
.81149 .23183 L
.81165 .2317 L
.81635 .227 L
.81649 .22691 L
.82123 .22217 L
.82112 .21734 L
.82132 .21716 L
.82598 .2125 L
.82615 .21237 L
.83084 .20767 L
.83098 .20758 L
.83572 .20284 L
.83561 .19801 L
.83581 .19783 L
.84047 .19318 L
.84065 .19303 L
.84533 .18835 L
.84548 .18823 L
.8502 .18351 L
.85031 .18346 L
.85509 .17868 L
.85495 .17385 L
.85514 .17368 L
.85981 .16902 L
.85997 .16888 L
.86467 .16419 L
.8648 .16409 L
.86954 .15935 L
.86964 .15934 L
.87445 .15452 L
.87428 .14969 L
.87447 .14953 L
.87914 .14486 L
.8793 .14473 L
.884 .14003 L
.88413 .13994 L
.88887 .1352 L
.88896 .13518 L
.89378 .13036 L
.89361 .12553 L
.8938 .12537 L
.89846 .1207 L
.89863 .12056 L
.90332 .11587 L
.90346 .11576 L
.90819 .11104 L
.90829 .11098 L
.91307 .1062 L
.91292 .10137 L
.91312 .10119 L
.91778 .09654 L
.91796 .09638 L
.92263 .09171 L
.92279 .09158 L
.92749 .08688 L
.92762 .08678 L
.93236 .08204 L
.93245 .08201 L
.93724 .07721 L
.93708 .07238 L
.93728 .0722 L
.94193 .06755 L
.94211 .06739 L
.94679 .06272 L
.94695 .06258 L
.95164 .05789 L
.95178 .05778 L
.95651 .05305 L
.95661 .05299 L
.96138 .04822 L
.96123 .04339 L
.96144 .04319 L
.96608 .03856 L
.96627 .03838 L
.97093 .03373 L
.97111 .03357 L
.97578 .02889 L
.97594 .02876 L
.98072 .02406 L
.98077 .02379 L
F
0 g
.98077 .70969 m
.97693 .70535 L
.97594 .70485 L
.97162 .70052 L
.97111 .70001 L
.96627 .69998 L
.96199 .69569 L
.96144 .69514 L
.95717 .69086 L
.95661 .6903 L
.95235 .68603 L
.95178 .68546 L
.94752 .68119 L
.94695 .68062 L
.9427 .67636 L
.94211 .67578 L
.93728 .67575 L
.93308 .67153 L
.93245 .67091 L
.92825 .6667 L
.92762 .66606 L
.92343 .66187 L
.92279 .66122 L
.91861 .65704 L
.91796 .65638 L
.91379 .6522 L
.91312 .65154 L
.90829 .65151 L
.90416 .64737 L
.90346 .64667 L
.89934 .64254 L
.89863 .64183 L
.89451 .63771 L
.8938 .63699 L
.88969 .63288 L
.88896 .63215 L
.88413 .63212 L
.88007 .62804 L
.8793 .62728 L
.87524 .62321 L
.87447 .62244 L
.87042 .61838 L
.86964 .6176 L
.8656 .61355 L
.8648 .61276 L
.86077 .60872 L
.85997 .60792 L
.85514 .60789 L
.85115 .60388 L
.85031 .60305 L
Mistroke
.84633 .59905 L
.84548 .5982 L
.8415 .59422 L
.84065 .59336 L
.83668 .58939 L
.83581 .58852 L
.83186 .58456 L
.83098 .58368 L
.82615 .58365 L
.82223 .57973 L
.82132 .57881 L
.81741 .57489 L
.81649 .57397 L
.81258 .57006 L
.81165 .56913 L
.80776 .56523 L
.80682 .56429 L
.80199 .56426 L
.79813 .5604 L
.79716 .55942 L
.79331 .55557 L
.79233 .55458 L
.78849 .55073 L
.7875 .54974 L
.78366 .5459 L
.78266 .5449 L
.77884 .54107 L
.77783 .54006 L
.773 .54003 L
.76921 .53624 L
.76817 .53519 L
.76439 .53141 L
.76334 .53035 L
.75957 .52658 L
.7585 .52551 L
.75474 .52174 L
.75367 .52067 L
.74884 .52064 L
.74512 .51691 L
.74401 .5158 L
.74029 .51208 L
.73918 .51096 L
.73547 .50725 L
.73434 .50612 L
.73065 .50242 L
.72951 .50128 L
.72582 .49758 L
.72468 .49644 L
.71985 .49641 L
.7162 .49275 L
Mistroke
.71502 .49157 L
.71137 .48792 L
.71019 .48673 L
.70655 .48309 L
.70535 .48189 L
.70173 .47826 L
.70052 .47705 L
.6969 .47342 L
.69569 .47221 L
.69086 .47218 L
.68728 .46859 L
.68603 .46734 L
.68245 .46376 L
.68119 .4625 L
.67763 .45893 L
.67636 .45766 L
.6728 .4541 L
.67153 .45282 L
.6667 .45279 L
.66661 .44927 L
.66653 .44443 L
.6667 .44431 L
.67141 .4396 L
.67153 .43955 L
.67631 .43477 L
.67621 .42994 L
.67636 .42984 L
.68109 .42511 L
.68102 .42027 L
.68119 .42014 L
.68589 .41544 L
.68603 .41536 L
.69078 .41061 L
.69069 .40578 L
.69086 .40565 L
.69557 .40095 L
.69569 .40089 L
.70047 .39612 L
.70036 .39128 L
.70052 .39117 L
.70524 .38645 L
.70535 .38643 L
.71016 .38162 L
.71003 .37679 L
.71019 .37668 L
.71491 .37196 L
.71483 .36712 L
.71502 .36697 L
.7197 .36229 L
.71985 .36219 L
Mistroke
.72458 .35746 L
.72449 .35263 L
.72468 .35247 L
.72936 .3478 L
.72951 .34769 L
.73424 .34296 L
.73415 .33813 L
.73434 .33797 L
.73902 .3333 L
.73918 .33319 L
.74389 .32847 L
.74401 .32843 L
.7488 .32364 L
.74867 .31881 L
.74884 .31868 L
.75355 .31397 L
.75367 .31391 L
.75844 .30914 L
.75833 .30431 L
.7585 .30417 L
.76319 .29948 L
.76334 .29938 L
.76807 .29465 L
.76798 .28981 L
.76817 .28965 L
.77284 .28498 L
.773 .28486 L
.77771 .28015 L
.77783 .28009 L
.78261 .27532 L
.78248 .27049 L
.78266 .27034 L
.78735 .26566 L
.7875 .26555 L
.79223 .26082 L
.79213 .25599 L
.79233 .25582 L
.79699 .25116 L
.79716 .25102 L
.80186 .24633 L
.80199 .24624 L
.80673 .2415 L
.80663 .23666 L
.80682 .23649 L
.81149 .23183 L
.81165 .2317 L
.81635 .227 L
.81649 .22691 L
.82123 .22217 L
.82112 .21734 L
Mistroke
.82132 .21716 L
.82598 .2125 L
.82615 .21237 L
.83084 .20767 L
.83098 .20758 L
.83572 .20284 L
.83561 .19801 L
.83581 .19783 L
.84047 .19318 L
.84065 .19303 L
.84533 .18835 L
.84548 .18823 L
.8502 .18351 L
.85031 .18346 L
.85509 .17868 L
.85495 .17385 L
.85514 .17368 L
.85981 .16902 L
.85997 .16888 L
.86467 .16419 L
.8648 .16409 L
.86954 .15935 L
.86964 .15934 L
.87445 .15452 L
.87428 .14969 L
.87447 .14953 L
.87914 .14486 L
.8793 .14473 L
.884 .14003 L
.88413 .13994 L
.88887 .1352 L
.88896 .13518 L
.89378 .13036 L
.89361 .12553 L
.8938 .12537 L
.89846 .1207 L
.89863 .12056 L
.90332 .11587 L
.90346 .11576 L
.90819 .11104 L
.90829 .11098 L
.91307 .1062 L
.91292 .10137 L
.91312 .10119 L
.91778 .09654 L
.91796 .09638 L
.92263 .09171 L
.92279 .09158 L
.92749 .08688 L
.92762 .08678 L
Mistroke
.93236 .08204 L
.93245 .08201 L
.93724 .07721 L
.93708 .07238 L
.93728 .0722 L
.94193 .06755 L
.94211 .06739 L
.94679 .06272 L
.94695 .06258 L
.95164 .05789 L
.95178 .05778 L
.95651 .05305 L
.95661 .05299 L
.96138 .04822 L
.96123 .04339 L
.96144 .04319 L
.96608 .03856 L
.96627 .03838 L
.97093 .03373 L
.97111 .03357 L
.97578 .02889 L
.97594 .02876 L
.98072 .02406 L
.98077 .02379 L
Mfstroke
1 0 0 r
.88896 .12522 m
.89051 .12553 L
.89357 .13036 L
.88896 .13497 L
.88735 .1352 L
.88413 .1384 L
.88186 .14003 L
.8793 .14258 L
.87652 .14486 L
.87447 .14689 L
.87124 .14969 L
.87415 .15452 L
.86964 .15904 L
.86796 .15935 L
.8648 .16251 L
.86247 .16419 L
.85997 .16667 L
.85711 .16902 L
.85514 .17097 L
.85182 .17385 L
.85412 .17868 L
.85031 .18249 L
.84835 .18351 L
.84548 .18638 L
.8429 .18835 L
.84065 .19059 L
.83756 .19318 L
.83581 .19491 L
.83111 .19318 L
.83517 .18835 L
.83581 .18745 L
.83936 .18351 L
.84065 .18131 L
.84436 .17868 L
.84548 .17556 L
.84587 .17385 L
.85025 .16902 L
.85031 .16894 L
.8543 .16419 L
.85514 .16291 L
.85866 .15935 L
.85997 .15686 L
.86451 .15452 L
.8648 .15149 L
.86513 .14969 L
.86952 .14486 L
.86964 .1447 L
.87364 .14003 L
.87447 .13877 L
.87807 .1352 L
.8793 .13283 L
.88393 .13036 L
.88413 .12768 L
.88454 .12553 L
F
0 g
.88896 .12522 m
.89051 .12553 L
.89357 .13036 L
.88896 .13497 L
.88735 .1352 L
.88413 .1384 L
.88186 .14003 L
.8793 .14258 L
.87652 .14486 L
.87447 .14689 L
.87124 .14969 L
.87415 .15452 L
.86964 .15904 L
.86796 .15935 L
.8648 .16251 L
.86247 .16419 L
.85997 .16667 L
.85711 .16902 L
.85514 .17097 L
.85182 .17385 L
.85412 .17868 L
.85031 .18249 L
.84835 .18351 L
.84548 .18638 L
.8429 .18835 L
.84065 .19059 L
.83756 .19318 L
.83581 .19491 L
.83111 .19318 L
.83517 .18835 L
.83581 .18745 L
.83936 .18351 L
.84065 .18131 L
.84436 .17868 L
.84548 .17556 L
.84587 .17385 L
.85025 .16902 L
.85031 .16894 L
.8543 .16419 L
.85514 .16291 L
.85866 .15935 L
.85997 .15686 L
.86451 .15452 L
.8648 .15149 L
.86513 .14969 L
.86952 .14486 L
.86964 .1447 L
.87364 .14003 L
.87447 .13877 L
.87807 .1352 L
Mistroke
.8793 .13283 L
.88393 .13036 L
.88413 .12768 L
.88454 .12553 L
.88896 .12522 L
Mfstroke
1 0 0 r
.90829 .09972 m
.90965 .10137 L
.91215 .1062 L
.90829 .11006 L
.90647 .11104 L
.90346 .11403 L
.90106 .11587 L
.89863 .11829 L
.89576 .1207 L
.8938 .12266 L
.88901 .1207 L
.8932 .11587 L
.8938 .11501 L
.89754 .11104 L
.89863 .10918 L
.90257 .1062 L
.90346 .10392 L
.90412 .10137 L
F
0 g
.90829 .09972 m
.90965 .10137 L
.91215 .1062 L
.90829 .11006 L
.90647 .11104 L
.90346 .11403 L
.90106 .11587 L
.89863 .11829 L
.89576 .1207 L
.8938 .12266 L
.88901 .1207 L
.8932 .11587 L
.8938 .11501 L
.89754 .11104 L
.89863 .10918 L
.90257 .1062 L
.90346 .10392 L
.90412 .10137 L
.90829 .09972 L
s
1 0 0 r
.93245 .07136 m
.93381 .07238 L
.93657 .07721 L
.93245 .08133 L
.9308 .08204 L
.92762 .08521 L
.92539 .08688 L
.92279 .08947 L
.92009 .09171 L
.91796 .09384 L
.91485 .09654 L
.91312 .09826 L
.90856 .09654 L
.91302 .09171 L
.91312 .09158 L
.91727 .08688 L
.91796 .08586 L
.92174 .08204 L
.92279 .08015 L
.927 .07721 L
.92762 .07516 L
.92831 .07238 L
F
0 g
.93245 .07136 m
.93381 .07238 L
.93657 .07721 L
.93245 .08133 L
.9308 .08204 L
.92762 .08521 L
.92539 .08688 L
.92279 .08947 L
.92009 .09171 L
.91796 .09384 L
.91485 .09654 L
.91312 .09826 L
.90856 .09654 L
.91302 .09171 L
.91312 .09158 L
.91727 .08688 L
.91796 .08586 L
.92174 .08204 L
.92279 .08015 L
.927 .07721 L
.92762 .07516 L
.92831 .07238 L
.93245 .07136 L
s
.955 .186 0 r
.95661 .04128 m
.95796 .04339 L
.96032 .04822 L
.95661 .05193 L
.95485 .05305 L
.95178 .05612 L
.94955 .05789 L
.94695 .06048 L
.94432 .06272 L
.94211 .06492 L
.93914 .06755 L
.93728 .0694 L
.93246 .06755 L
.93666 .06272 L
.93728 .06194 L
.94101 .05789 L
.94211 .05631 L
.94551 .05305 L
.94695 .05068 L
.95053 .04822 L
.95178 .04568 L
.95234 .04339 L
F
0 g
.95661 .04128 m
.95796 .04339 L
.96032 .04822 L
.95661 .05193 L
.95485 .05305 L
.95178 .05612 L
.94955 .05789 L
.94695 .06048 L
.94432 .06272 L
.94211 .06492 L
.93914 .06755 L
.93728 .0694 L
.93246 .06755 L
.93666 .06272 L
.93728 .06194 L
.94101 .05789 L
.94211 .05631 L
.94551 .05305 L
.94695 .05068 L
.95053 .04822 L
.95178 .04568 L
.95234 .04339 L
.95661 .04128 L
s
1 0 0 r
.93728 .06276 m
.93898 .06755 L
.93728 .06924 L
.93278 .06755 L
F
0 g
.93728 .06276 m
.93898 .06755 L
.93728 .06924 L
.93278 .06755 L
.93728 .06276 L
s
1 0 0 r
.95661 .04184 m
.95776 .04339 L
.96026 .04822 L
.95661 .05187 L
.95476 .05305 L
.95178 .05603 L
.94943 .05789 L
.94695 .06037 L
.94419 .06272 L
.94211 .06478 L
.93732 .06272 L
.94164 .05789 L
.94211 .05722 L
.94606 .05305 L
.94695 .05162 L
.95089 .04822 L
.95178 .0465 L
.95275 .04339 L
F
0 g
.95661 .04184 m
.95776 .04339 L
.96026 .04822 L
.95661 .05187 L
.95476 .05305 L
.95178 .05603 L
.94943 .05789 L
.94695 .06037 L
.94419 .06272 L
.94211 .06478 L
.93732 .06272 L
.94164 .05789 L
.94211 .05722 L
.94606 .05305 L
.94695 .05162 L
.95089 .04822 L
.95178 .0465 L
.95275 .04339 L
.95661 .04184 L
s
.955 .186 0 r
.98077 .02126 m
.97957 .02406 L
.97594 .02666 L
.97336 .02889 L
.97111 .03114 L
.9682 .03373 L
.96627 .03565 L
.96307 .03856 L
.96144 .04018 L
.95687 .03856 L
.96143 .03373 L
.96144 .03371 L
.96569 .02889 L
.96627 .02819 L
.97011 .02406 L
.97111 .02358 L
.97463 .01923 L
.98077 .01923 L
F
0 g
.98077 .02126 m
.97957 .02406 L
.97594 .02666 L
.97336 .02889 L
.97111 .03114 L
.9682 .03373 L
.96627 .03565 L
.96307 .03856 L
.96144 .04018 L
.95687 .03856 L
.96143 .03373 L
.96144 .03371 L
.96569 .02889 L
.96627 .02819 L
.97011 .02406 L
.97111 .02358 L
.97463 .01923 L
s
1 0 0 r
.96144 .0341 m
.9629 .03856 L
.96144 .04001 L
.95722 .03856 L
F
0 g
.96144 .0341 m
.9629 .03856 L
.96144 .04001 L
.95722 .03856 L
.96144 .0341 L
s
1 0 0 r
.96627 .02895 m
.96805 .03373 L
.96627 .0355 L
.96174 .03373 L
F
0 g
.96627 .02895 m
.96805 .03373 L
.96627 .0355 L
.96174 .03373 L
.96627 .02895 L
s
1 0 0 r
.98077 .02117 m
.97949 .02406 L
.97594 .02655 L
.97323 .02889 L
.97111 .03101 L
.96632 .02889 L
.97071 .02406 L
.97111 .02386 L
.97518 .01923 L
.98077 .01923 L
F
0 g
.98077 .02117 m
.97949 .02406 L
.97594 .02655 L
.97323 .02889 L
.97111 .03101 L
.96632 .02889 L
.97071 .02406 L
.97111 .02386 L
.97518 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[154]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00<_ooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0ol0000Mooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00000_ooool5o`0002?ooooo0_l0000Vooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00000_ooool5o`0001gooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`?o00005Oooool0037ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0002;ooooo00Co0000oooooooooooo00009?oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00007?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool05?ooool002[ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000oooooooooooo0000ooooo`05o`0001Gooooo1Ol00002ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Rooooo`04o`000?oooooooooo
o`0002Cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo01cooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo
00Go00005Oooool0037ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool0000Toooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`03o`000?oooooooooo01Cooooo000aooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`00000Mooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooo
oooo00009?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooo`00000Fooooo`00<Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo0_l0000Mooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooo
oooo00009?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool2o`0001Kooooo000booooo`;o00002_ooool2o`0000Gooooo00?o0000oooooooo
ool07?ooool2o`0000[ooooo0_l00003ooooo`?o00009?ooool2o`0002Kooooo0_l0000:ooooo`;o
00000oooool3o`0001kooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`0Dooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006oooooooo`0000Go
00000Oooool001_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00_ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Kooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0ooooool1ooooo`7o00000Oooool001_ooooo0_l00004ooooo`Oo000000Coooooo`000?oo
oooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo1?l0002eoooo
o`?o00002Oooool00ol0003oooooooooo`03ooooo`08o`000?ooooooooooooooool0003oooooo`00
0?ooool7o`0000Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`02ooooo`?o000000?o
a/40o`000?l000000_l00002o`214P03o`000?l0MBOo000000?o06Xh00?o0000o`1NAOl0GTD00ol0
GTD00ol0003o05==o`1CC@07o`1CC@?o0000]?l05c03o`0000Wo05==00?o0000o`1NAOl0GTD00ol0
GTD01ol0003o06Xho`1Z>?l0JSSo0000o`1e9ol000000_l0PA83o`000003ofn_0?l0003o000000;o
00001?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo2ol00002o`1e9`04o`00
0?l0JSSo06Xho`0000Go05i50_l0000:o`1CC@;o0000/_l05c03o`0000[o05==00?o0000o`1NAOl0
GTD00ol0GTD02?l0003o06Xho`1Z>?l0JSSo0000o`1e9ol0003o084B2Ol00004ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_ooool00ol00QWo0000o`000009o`0000;o07DW00?o0000
o`1Z>?l0JSP00_l00005o`1NA@03o`000?l0Ddgo05==00So05==0_l0002`o`0G<0;o00002_l0Ddd2
o`0000Go05i500?o0000o`1Z>?l0JSP00_l000000ol0MBOo0000o`000009o`0000Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`02ooooo`;o008I0_l000000ooo003o0000o`000004o`00
0005o`214_l0003o07DWo`1e9ol000000ol0JSP00ol0003o05i5o`1NA@03o`1NA@03o`000?l0Ddgo
05==00So05==0ol0002]o`0G<0;o00002_l0Ddd00ol0003o05i5o`1NA@03o`1NA@;o00000_l0JSP2
o`000003o`1e9ol0003o084B00Wo000000?o008Iooooooooool00oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00;ooooo1?l00QT00ol0003oo`00o`000005o`000005o`214_l0003o07DW
o`1e9ol000000ol0JSP00ol0003o05i5o`1NA@03o`1NA@03o`000?l0Ddgo05==00So05==0ol0002Z
o`0G<0?o00002_l0Ddd00ol0003o05i5o`1NA@03o`1NA@05o`000?l0JSSo06Xho`1Z>?l000000_l0
MBL00ol0003o084Bo`000005o`000003ool00?l0003o000000;o008I1Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;ooooo1?l00QT4o`000003oi^j0?l0003o000000;o000000Co084B
o`000?l0MBOo00000ol0JSP00ol0003o05i5o`1NA@03o`1NA@03o`000?l0Ddgo05==00Wo05==0_l0
002Zo`0G<003o`000?l0?TOo000000[o05==00?o0000o`1NAOl0GTD00ol0GTD01Ol0003o06Xho`1Z
>?l0JSSo000000;o07DW1?l000000om8X`3o0000o`000003o`0000?o008I1Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo1Ol00QT7o`000006o`N<0?l0003o0000o`000?l0MBOo
00000ol0JSP00ol0003o05i5o`1NA@03o`1NA@03o`000?l0Ddgo05==00Wo05==0ol0002Vo`0G<0Co
00002_l0Ddd00ol0003o05i5o`1NA@03o`1NA@06o`000?l0JSSo06Xho`1Z>?l0003o07DW0_l00000
0ol0PA;o0000o`000006o`0000Co008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo1Ol00QT00ol0003oo`00o`000009o`000003o`1e9ol0003o000000;o06Xh00?o0000o`1N
AOl0GTD00ol0GTD2o`0000Wo05==0_l000000ol0?TOo0000o`00002So`0G<004o`000?l0?TOo0000
o`0000[o05==00?o0000o`1NAOl0GTD00ol0GTD01_l0003o06Xho`1Z>?l0JSSo0000o`1e9`[o0000
00?oo`00o`000?l00QT00ol00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool6o`026@03o`000?oo003oo`0000Oo000000Co084Bo`000?l0MBOo00000ol0JSP00ol0003o05i5
o`1NA@03o`1NA@03o`000?l0Ddgo05==00So05==00?o0000o`0nAol000000_l0002Po`0G<0?o0000
00?o03i7o`000?l0Ddd02Ol0Ddd00ol0003o05i5o`1NA@03o`1NA@05o`000?l0JSSo06Xho`1Z>?l0
00000_l0MBL2o`000003o`N<0?l0003o000000Co000000?oo`00o`000?l00QT01?l00QT5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_ooool7o`026@;o000000?oo`00o`000?l00000
0ol000001_l7S03o0000o`000?l0003o07DWo`0000?o06Xh00?o0000o`1NAOl0GTD00ol0GTD00ol0
003o05==o`1CC@08o`1CC@03o`000?l0?TOo03i700;o0000W_l05c02o`0000;o03i700?o0000o`1C
COl0Ddd02?l0Ddd00ol0003o05i5o`1NA@03o`1NA@;o00000_l0JSP00ol0003o07DWo`000002o`00
0003o`N<0?l0003o000000?o000000?oo`00o`000?l000001_l00QT5ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_ooool8o`026@Go000000CoKjl0o`000?l0003o00000_l0PA800ol0
003o07DWo`000003o`1Z>003o`000?l0GTGo05i500?o05i500?o0000o`1CCOl0Ddd02?l0Ddd01?l0
003o03i7o`0nAol0002No`0G<004o`000?l0?TOo03i7o`0000[o05==00?o0000o`1NAOl0GTD00ol0
GTD01Ol0003o06Xho`1Z>?l0JSSo000000;o07DW00Go0000o`214_l0003o0000obFH0004o`000003
ool00?l0003o000000Ko008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
2Ol00QT9o`000004o`214_l0003o07DWo`0000?o06Xh0_l00005o`1NA@03o`000?l0Ddgo05==00So
05==00?o0000o`0nAol000000ol0002Io`0G<0?o000000?o03i7o`000?l000002Ol0Ddd00ol0003o
05i5o`1NA@03o`1NA@;o00000ol0JSP01?l0003o07DWo`000?l0PA8:o`0000Oo008I1Oooool1o`00
007ooooo000Kooooo`;o00000oooool:o`026@Wo000000?o084Bo`000?l0MBL00_l00002o`1Z>003
o`000?l0GTGo05i500Co05i500?o0000o`1CCOl0Ddd02?l0Ddd01?l0003o03i7o`0nAol0?TL2o`00
09Ko01L`0_l00003o`0nA`03o`000?l0Ddgo05==00So05==00?o0000o`1NAOl0GTD01?l0GTD02_l0
003o06Xho`1Z>?l0JSSo0000o`1e9ol0003o084Bo`000?l7S007o`0000Wo008I1?ooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo2ol00QT9o`000005o`214_l0003o07DWo`1e9ol0
00000_l0JSP2o`0000Go05i500?o0000o`1CCOl0Ddd02?l0Ddd01?l0003o03i7o`0nAol0?TL2o`00
09Co01L`0_l00003o`0nA`03o`000?l0Ddgo05==00So05==0_l00005o`1NA@03o`000?l0JSSo06Xh
00;o000000?o07DWo`000?l0PA802Ol0000:o`026@Gooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`02ooooo`_o008I00?o0000ool00?oo00001ol000001Ol0PA;o0000o`1e9ol0MBOo0000
00?o06Xh00?o0000o`1NAOl0GTD00ol0GTD00ol0003o05==o`1CC@08o`1CC@04o`000?l0?TOo03i7
o`0nA`;o0000T_l05c02o`0000?o03i700?o0000o`1CCOl0Ddd02?l0Ddd00ol0003o05i5o`1NA@03
o`1NA@;o00000_l0JSP01Ol0003o07DWo`1e9ol0003o084B00So000000?oo`00o`000?l00QT02Ol0
0QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool;o`026@?o000000Ooo`00
o`000?l0003o0000odRS0?l0003o1h`000;o00000_l0MBL01Ol0003o06Xho`1Z>?l0JSSo000000Go
05i500?o0000o`1CCOl0Ddd02?l0Ddd00ol0003o03i7o`000002o`0nA`03o`000?l05c3o01L`093o
01L`00Co0000o`0nAol0?TOo03i70_l0000:o`1CC@03o`000?l0GTGo05i500?o05i500Go0000o`1Z
>?l0JSSo06Xho`000002o`1e9`;o000000?o1h`0o`000?l000000ol00002ool000;o00002_l00QT5
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool<o`026@[o000000Go084Bo`00
0?l0003o07DWo`000003o`1Z>003o`000?l0GTGo05i500?o05i500?o0000o`1CCOl0Ddd02?l0Ddd2
o`0000?o03i70_l0002?o`0G<003o`000?l0?TOo03i700;o03i700?o0000o`1CCOl0Ddd02?l0Ddd0
0ol0003o05i5o`1NA@03o`1NA@05o`000?l0JSSo06Xho`1Z>?l000000_l0MBL00ol0003o084Bo`00
0006o`000003ool00?l0003o000000_o008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00;ooooo3_l00QT00ol0003oo`00o`000006o`000005o`214_l0003o07DWo`1e9ol000000ol0
JSP00ol0003o05i5o`1NA@03o`1NA@03o`000?l0Ddgo05==00Wo05==00Co0000o`0nAol0?TOo03i7
0ol0002:o`0G<0?o00000ol0?TL2o`0000[o05==00?o0000o`1NAOl0GTD00ol0GTD01Ol0003o06Xh
o`1Z>?l0JSSo000000;o07DW00?o0000o`214_l000001_l000000ooo003o0000o`00000<o`026@Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`oo008I00?o0000ool00?l00000
2?l00002o`1e9`05o`000?l0JSSo06Xho`1Z>?l000001Ol0GTD2o`0000[o05==00Co0000o`0nAol0
?TOo03i70ol00028o`0G<0?o00000ol0?TL00ol0003o05==o`1CC@08o`1CC@;o00001Ol0GTD01Ol0
003o06Xho`1Z>?l0JSSo000000;o07DW00?o0000o`214_l000001_l000000ooo003o0000o`026@0=
o`026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooa3o008I2Ol000001Ol0
PA;o0000o`1e9ol0MBOo000000?o06Xh00?o0000o`1NAOl0GTD01?l0GTD00ol0003o05==o`1CC@08
o`1CC@03o`000?l0?TOo03i700;o03i70_l00026o`0G<0;o00001?l0?TL00ol0003o05==o`1CC@08
o`1CC@03o`000?l0GTGo05i500Co05i500Co0000o`1Z>?l0JSSo06Xh0_l000000ol0MBOo0000o`21
4P09o`0000oo008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo4?l00QT2
o`000003ool00?l0003o000000;o000000Co9IP0o`000?l0003o00000ol0MBL01Ol0003o06Xho`1Z
>?l0JSSo000000Go05i500?o0000o`1CCOl0Ddd02?l0Ddd00ol0003o03i7o`0nA`03o`0nA`;o0000
QOl05c000ol0003o03i7o`0nA`03o`0nA`03o`000?l0Ddgo05==00So05==00?o0000o`1NAOl0GTD0
1?l0GTD01?l0003o06Xho`1Z>?l00003o`1e9`;o000000?o1h`0o`000?l000001_l0000?o`026@Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooa7o008I0_l000000ooo003o0000
o`000006o`0000;o07DW00Co0000o`1Z>?l0JSSo06Xh0_l00005o`1NA@03o`000?l0Ddgo05==00So
05==00?o0000o`0nAol0?TL00ol0?TL2o`0008;o01L`0_l00005o`0nA`03o`000?l0Ddgo05==00So
05==00?o0000o`1NAOl0GTD00ol0GTD2o`0000?o06Xh00?o0000o`1e9ol0MBL02?l000000ooo003o
0000o`00000@o`026@Gooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool3o`0000Cooooo00?o0000ooooooooool00_oooolAo`026@;o000000?oo`00o`000?l00000
1?l000001_l7S03o0000o`000?l0003o07DWo`0000?o06Xh00?o0000o`1NAOl0GTD01?l0GTD00ol0
003o05==o`1CC@08o`1CC@;o00001?l0?TL2o`00083o01L`0_l00004o`0nA`;o00002_l0Ddd00ol0
003o05i5o`1NA@04o`1NA@05o`000?l0JSSo06Xho`1Z>?l000000_l0MBL00ol0003o084Bo`000006
o`0000;oo`0000?o0000o`026Ol00QT03_l00QT5ooooo`7o00000Oooool000Oooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo4ol00QT0
0ol0003oo`00o`000007o`000003o`214_l0003o07DW00;o00000_l0JSP00ol0003o05i5o`1NA@04
o`1NA@03o`000?l0Ddgo05==00Wo05==00?o0000o`0nAol0?TL00_l0?TL4o`0007_o01L`0ol00004
o`0nA`03o`000?l0Ddgo05==00Wo05==00?o0000o`1NAOl0GTD01?l0GTD01_l0003o06Xho`1Z>?l0
JSSo0000o`1e9`;o000000?o084Bo`000?l000001Ol000000ooo003o0000o`00000Ao`026@Gooooo
0Ol00001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00004ooooo`;o0000
0ooooolDo`026@03o`000?oo003o000000Go000000Ko1h`0o`000?l0PA;o0000o`1e9ol00003o`1Z
>0;o00001Ol0GTD00ol0003o05==o`1CC@09o`1CC@03o`000?l0?TOo03i700;o03i71?l0001io`0G
<0?o00001?l0?TL00ol0003o05==o`1CC@09o`1CC@03o`000?l0GTGo05i500Co05i500Go0000o`1Z
>?l0JSSo06Xho`000002o`1e9`Wo000000?oo`00o`000?l00QT04_l00QT4ooooo`;o00000Oooool0
00Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo00;ooooo5?l00QT2o`000003ool00?l0003o000000?o000000Co1h`0o`000?l0PA;o0000
0_l0MBL01?l0003o06Xho`1Z>?l0JSP2o`0000Go05i500?o0000o`1CCOl0Ddd02?l0Ddd00ol0003o
03i7o`0nA`05o`0nA`03o`000?l05c3o01L`07Ko01L`00?o0000o`0nAol0?TL01Ol0?TL00ol0003o
05==o`1CC@08o`1CC@03o`000?l0GTGo05i500Co05i500?o0000o`1Z>?l0JSP00_l0JSP01_l0003o
07DWo`000?l0PA;o0000o`N<00So00004ol00QT5ooooo`7o00000Oooool000Oooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00;ooooo5Ol00QT2
o`000003ool00?l0003o000000Go000000?o084Bo`000?l0MBL00_l00003o`1Z>003o`000?l0GTGo
05i500?o05i500?o0000o`1CCOl0Ddd02Ol0Ddd00ol0003o03i7o`0nA`04o`0nA`;o0000M_l05c02
o`0000Ko03i700?o0000o`1CCOl0Ddd02Ol0Ddd00ol0003o05i5o`1NA@03o`1NA@04o`000?l0JSSo
06Xho`1Z>0;o000000Go07DWo`000?l0PA;o0000o`N<0008o`0001Co008I1Oooool1o`00007ooooo
0007ooooo`04o`000?ooooooooooo`0000Wooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo
5_l00QT8o`000004o`N<0?l0003o084Bo`0000;o07DW00Go0000o`1Z>?l0JSSo06Xho`000005o`1N
A@03o`000?l0Ddgo05==00Wo05==0_l00005o`0nA`;o0000M?l05c02o`0000Go03i70_l0000;o`1C
C@03o`000?l0GTGo05i500?o05i500?o0000o`1Z>?l0JSP00_l0JSP01_l0003o07DWo`000?l0PA;o
0000o`N<00So00005Ol00QT5ooooo`7o00000Oooool000Sooooo0_l0000;ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_oooolFo`026@;o000000?oo`00o`000?l000001?l00000
1Ol7S03o0000o`214_l0003o07DW00;o00000ol0JSP00ol0003o05i5o`1NA@03o`1NA@;o00002_l0
Ddd00ol0003o03i7o`0nA`04o`0nA`Co0000K_l05c04o`0000Ko03i700?o0000o`1CCOl0Ddd02?l0
Ddd2o`0000Go05i500?o0000o`1Z>?l0JSP00_l0JSP00ol0003o07DWo`000002o`000003o`N<0?l0
003o000000Co00000_oo00000ol0003o008Io`026@0Co`026@Gooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`02oooooaSo008I00?o0000ool00?l000001ol000000ol0PA;o0000o`1e9`02
o`0000;o06Xh0_l00006o`1NA@03o`000?l0Ddgo05==00So05==0_l00005o`0nA`Co0000K?l05c04
o`0000Go03i70_l0000:o`1CC@03o`000?l0GTGo05i500Co05i50_l00002o`1Z>0;o000000?o07DW
o`000?l0PA802?l000000ooo003o0000o`00000Fo`026@Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`02oooooaSo008I0_l000000ooo003o0000om6S0003o`0000;o1h`00_l00002o`1e
9`05o`000?l0JSSo06Xho`1Z>?l000001_l0GTD00ol0003o05==o`1CC@09o`1CC@03o`000?l0?TOo
03i700Ko03i700?o0000o`0G<?l05c00J_l05c000ol0003o03i7o`0nA`06o`0nA`03o`000?l0Ddgo
05==00Wo05==00?o0000o`1NAOl0GTD01?l0GTD01Ol0003o06Xho`1Z>?l0JSSo000000;o07DW00Co
0000o`214_l0003o1h`01Ol000000ooo003o0000o`00000Go`026@Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02oooooaWo008I0_l000000ooo003o0000o`000003o`000004o`N<0?l0
003o084Bo`0000;o07DW00Co0000o`1Z>?l0JSSo06Xh0_l00005o`1NA@03o`000?l0Ddgo05==00Wo
05==00?o0000o`0nAol0?TL01Ol0?TL2o`0006[o01L`0_l00007o`0nA`03o`000?l0Ddgo05==00Wo
05==00?o0000o`1NAOl0GTD00ol0GTD2o`0000?o06Xh00Oo0000o`1e9ol0MBOo0000o`214_l0003o
1h`000So00006?l00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolJo`02
6@;o000000?oo`00o`000?l000001Ol000001Ol0PA;o0000o`1e9ol0MBOo000000?o06Xh00?o0000
o`1NAOl0GTD01?l0GTD00ol0003o05==o`1CC@09o`1CC@03o`000?l0?TOo03i700Ko03i70_l0001W
o`0G<003o`000?l0?TOo03i700Ko03i700?o0000o`1CCOl0Ddd02Ol0Ddd00ol0003o05i5o`1NA@04
o`1NA@05o`000?l0JSSo06Xho`1Z>?l000000_l0MBL01?l0003o084Bo`000?l7S008o`0001Wo008I
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo6ol00QT2o`000003ool00?l0
003o000000?o000000Co1h`0o`000?l0PA;o00000_l0MBL01Ol0003o06Xho`1Z>?l0JSSo000000Ko
05i500?o0000o`1CCOl0Ddd02Ol0Ddd00ol0003o03i7o`0nA`06o`0nA`;o0000I?l05c03o`0000Oo
03i700?o0000o`1CCOl0Ddd02Ol0Ddd00ol0003o05i5o`1NA@04o`1NA@05o`000?l0JSSo06Xho`1Z
>?l000000_l0MBL01?l0003o084Bo`000?l7S005o`000003ool00?l0003o000001[o008I1Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo6ol00QT00ol0003oo`00ool00006o`00
0005o`N<0?l0003o084Bo`000?l0MBL00_l00003o`1Z>003o`000?l0GTGo05i500?o05i50_l0000;
o`1CC@03o`000?l0?TOo03i700Ko03i70_l0001Ro`0G<0;o00002?l0?TL00ol0003o05==o`1CC@09
o`1CC@;o00001Ol0GTD01?l0003o06Xho`1Z>?l0JSP2o`000005o`1e9ol0003o084Bo`000?l7S000
1_l00002ool00003o`000?l00QWo008I01So008I1Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo7?l00QT2o`000004ool00?l0003o0000oi^j00Co000000Go084Bo`000?l0MBOo
07DWo`000003o`1Z>003o`000?l0GTGo05i500Go05i500?o0000o`1CCOl0Ddd02Ol0Ddd00ol0003o
03i7o`0nA`06o`0nA`;o0000H?l05c02o`0000So03i700?o0000o`1CCOl0Ddd02Ol0Ddd00ol0003o
05i5o`1NA@05o`1NA@05o`000?l0JSSo06Xho`1Z>?l000000_l0MBL00ol0003o084Bo`000002o`00
0004odRS0?l0003o0000o`0000?oo`0000?o0000o`026Ol00QT06?l00QT5ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_oooolMo`026@So000000Co1h`0o`000?l0003o00000_l0MBL0
1Ol0003o06Xho`1Z>?l0JSSo000000Ko05i50_l0000;o`1CC@03o`000?l0?TOo03i700Oo03i70_l0
001Mo`0G<003o`000?l0?TOo03i700Oo03i700?o0000o`1CCOl0Ddd02Ol0Ddd2o`0000Ko05i500Go
0000o`1Z>?l0JSSo06Xho`000002o`1e9`?o000000?o1h`0o`000?l000001ol0000Ko`026@Gooooo
0Ol00001ooooo`006oooool2o`0000?ooooo7_l00QT00ol0003oo`00o`000007o`000005o`214_l0
003o07DWo`1e9ol000000ol0JSP2o`0000Go05i500?o0000o`1CCOl0Ddd02Ol0Ddd2o`0000Wo03i7
0_l0001Jo`0G<0?o00002?l0?TL2o`0000_o05==00?o0000o`1NAOl0GTD00ol0GTD2o`0000?o06Xh
00Oo0000o`1e9ol0MBOo0000o`214_l0003o1h`000Ko000000?oo`00o`000?l00QT07?l00QT4oooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool00_oooolOo`026@;o000000?oo`00o`000?l0
00000_l000001OlUV03o0000o`000?l0PA;o000000;o07DW00Go0000o`1Z>?l0JSSo06Xho`000006
o`1NA@03o`000?l0Ddgo05==00[o05==00?o0000o`0nAol0?TL01ol0?TL2o`0005So01L`0_l00009
o`0nA`03o`000?l0Ddgo05==00[o05==00?o0000o`1NAOl0GTD01?l0GTD01Ol0003o06Xho`1Z>?l0
JSSo000000;o07DW00?o0000o`214_l000002Ol0000No`026@Gooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`02ooooob3o008I0_l000000ooo003o0000o`000002o`000003obFH0?l0003o
000000;o00000_l0MBL01Ol0003o06Xho`1Z>?l0JSSo000000Ko05i50_l0000;o`1CC@03o`000?l0
?TOo03i700Oo03i70_l0001Fo`0G<0;o00002Ol0?TL00ol0003o05==o`1CC@0:o`1CC@03o`000?l0
GTGo05i500Co05i500Go0000o`1Z>?l0JSSo06Xho`000002o`1e9`?o000000?o1h`0o`000?l00000
0ol000000ooo003o0000o`00000Oo`026@Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`02ooooob3o008I0_l000000ooo003o0000o`000005o`0000;o084B00?o0000o`1e9ol000001?l0
JSP00ol0003o05i5o`1NA@04o`1NA@03o`000?l0Ddgo05==00[o05==00?o0000o`0nAol0?TL01ol0
?TL00ol0003o01L`o`0G<01Do`0G<003o`000?l0?TOo03i700Oo03i700?o0000o`1CCOl0Ddd02_l0
Ddd00ol0003o05i5o`1NA@04o`1NA@03o`000?l0JSSo06Xh00;o06Xh00?o0000o`1e9ol000000_l0
PA83o`000005odRS0?l0003o0000o`000?oo00000_l0000Oo`026@Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooob3o008I0_l000000ooo003o0000o`000006o`000005o`214_l0
003o07DWo`1e9ol000001?l0JSP00ol0003o05i5o`1NA@04o`1NA@03o`000?l0Ddgo05==00[o05==
00?o0000o`0nAol0?TL01ol0?TL3o`00053o01L`0ol0000:o`0nA`03o`000?l0Ddgo05==00Wo05==
00?o0000o`1NAOl0GTD01Ol0GTD01Ol0003o06Xho`1Z>?l0JSSo000000;o07DW00?o0000o`214_l0
00001ol00002ool00003o`000?l00QWo008I01go008I1Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo8_l00QT00ol0003oo`00o`000004o`000005obFH0?l0003o0000o`214_l0
00000_l0MBL01?l0003o06Xho`1Z>?l0JSP2o`0000Ko05i500?o0000o`1CCOl0Ddd02_l0Ddd00ol0
003o03i7o`0nA`07o`0nA`?o0000C_l05c04o`0000So03i70_l0000;o`1CC@03o`000?l0GTGo05i5
00Co05i50_l00003o`1Z>007o`000?l0MBOo07DWo`000?l0PA;o0000o`N<0006o`000003ool00?l0
003o0000023o008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo8ol00QT:
o`000005o`214_l0003o07DWo`1e9ol000001?l0JSP00ol0003o05i5o`1NA@04o`1NA@03o`000?l0
Ddgo05==00[o05==00?o0000o`0nAol0?TL02?l0?TL2o`0004co01L`0_l0000:o`0nA`03o`000?l0
Ddgo05==00[o05==00?o0000o`1NAOl0GTD01?l0GTD00ol0003o06Xho`1Z>002o`1Z>007o`000?l0
MBOo07DWo`000?l0PA;o0000o`N<0006o`000003ool00?l0003o008I027o008I1Oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo9?l00QT2o`000003ool00?l0003o000000Go0000
00Go084Bo`000?l0MBOo07DWo`000004o`1Z>003o`000?l0GTGo05i500?o05i50_l0000<o`1CC@03
o`000?l0?TOo03i700So03i70_l0001:o`0G<0;o00002_l0?TL00ol0003o05==o`1CC@0:o`1CC@;o
00001Ol0GTD00ol0003o06Xho`1Z>002o`1Z>007o`000?l0MBOo07DWo`000?l0PA;o0000o`N<0008
o`0002?o008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo9?l00QT2o`00
0003ool00?l0003o000000;o000000Go9IP0o`000?l0003o084Bo`000002o`1e9`03o`000?l0JSSo
06Xh00;o06Xh00?o0000o`1NAOl0GTD01?l0GTD00ol0003o05==o`1CC@0:o`1CC@03o`000?l0?TOo
03i700[o03i700?o0000o`0G<?l05c00A_l05c02o`0000_o03i700?o0000o`1CCOl0Ddd02_l0Ddd0
0ol0003o05i5o`1NA@04o`1NA@03o`000?l0JSSo06Xh00;o06Xh00Go0000o`1e9ol0MBOo0000o`21
4P02o`000003obFH0?l0003o000000;o000000?om2l0o`000?l000008ol00QT5ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_oooolUo`026@;o000000?oo`00o`000?l000001Ol00000
1Ol0PA;o0000o`000?l0MBOo000000Co06Xh00?o0000o`1NAOl0GTD01?l0GTD2o`0000_o05==0_l0
000:o`0nA`?o0000A?l05c03o`0000_o03i700?o0000o`1CCOl0Ddd02Ol0Ddd2o`0000Ko05i500?o
0000o`1Z>?l0JSP00_l0JSP01Ol0003o07DWo`000?l0003o084B00Oo000000?oo`00o`000?l00000
9?l00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolUo`026@;o000000?o
o`00o`000?l000000ol000001OlUV03o0000o`000?l0PA;o000000;o07DW00?o0000o`1Z>?l0JSP0
0_l0JSP00ol0003o05i5o`1NA@04o`1NA@03o`000?l0Ddgo05==00_o05==00?o0000o`0nAol0?TL0
2?l0?TL3o`0004;o01L`0ol0000:o`0nA`;o00003?l0Ddd00ol0003o05i5o`1NA@04o`1NA@03o`00
0?l0JSSo06Xh00;o06Xh00Oo0000o`1e9ol0MBOo0000o`214_l0003o1h`000Ko000000?oo`00o`00
0?l000009?l00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolWo`026@03
o`000?oo003o000000Oo000000Go084Bo`000?l0MBOo07DWo`000003o`1Z>0;o00001_l0GTD00ol0
003o05==o`1CC@0;o`1CC@03o`000?l0?TOo03i700Wo03i70ol0000no`0G<0?o00002ol0?TL00ol0
003o05==o`1CC@0;o`1CC@03o`000?l0GTGo05i500Co05i50_l00003o`1Z>007o`000?l0MBOo07DW
o`000?l0PA;o0000o`N<0006o`000003ool00?l0003o000002Go008I1Oooool1o`00007ooooo000K
ooooo`;o00000ooooolXo`026@So000000Co1h`0o`000?l0PA;o00000_l0MBL00ol0003o06Xho`1Z
>002o`1Z>003o`000?l0GTGo05i500Co05i500?o0000o`1CCOl0Ddd02ol0Ddd00ol0003o03i7o`0n
A`0:o`0nA`;o0000??l05c03o`0000_o03i700?o0000o`1CCOl0Ddd02ol0Ddd00ol0003o05i5o`1N
A@04o`1NA@03o`000?l0JSSo06Xh00;o06Xh00Oo0000o`1e9ol0MBOo0000o`214_l0003o1h`000So
00009ol00QT4ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_oooolXo`026@;o0000
00?oo`00o`000?l000000ol000001?l7S03o0000o`214_l00003o`1e9`05o`000?l0JSSo06Xho`1Z
>?l000001_l0GTD00ol0003o05==o`1CC@0;o`1CC@03o`000?l0?TOo03i700_o03i700?o0000o`0G
<?l05c00>_l05c000ol0003o03i7o`0nA`0;o`0nA`03o`000?l0Ddgo05==00_o05==00?o0000o`1N
AOl0GTD01?l0GTD01Ol0003o06Xho`1Z>?l0JSSo000000?o07DW00Co0000o`214_l0003o1h`02?l0
000Wo`026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobWo008I0_l00000
0ooo003o0000o`000005o`000005o`214_l0003o07DWo`1e9ol000001?l0JSP00ol0003o05i5o`1N
A@04o`1NA@;o00003?l0Ddd2o`0000_o03i70_l0000jo`0G<0;o00003?l0?TL00ol0003o05==o`1C
C@0;o`1CC@03o`000?l0GTGo05i500Co05i500?o0000o`1Z>?l0JSP00_l0JSP01Ol0003o07DWo`1e
9ol0003o084B00[o0000:?l00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
oolYo`026@;o000000?oo`00o`000?l000001?l000001?l7S03o0000o`214_l00002o`1e9`03o`00
0?l0JSSo06Xh00;o06Xh00?o0000o`1NAOl0GTD01Ol0GTD00ol0003o05==o`1CC@0;o`1CC@03o`00
0?l0?TOo03i700Wo03i71?l0000do`0G<0Co00002ol0?TL2o`0000co05==0_l00006o`1NA@03o`00
0?l0JSSo06Xh00;o06Xh00Oo0000o`1e9ol0MBOo0000o`214_l0003o1h`000Ko00000_oo00000ol0
003o008Io`026@0Vo`026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooob[o
008I0_l000000ooo003o0000o`000004o`000004o`N<0?l0003o084Bo`0000;o07DW00?o0000o`1Z
>?l0JSP00_l0JSP00ol0003o05i5o`1NA@05o`1NA@03o`000?l0Ddgo05==00_o05==00?o0000o`0n
Aol0?TL02Ol0?TL4o`0003;o01L`1?l0000;o`0nA`03o`000?l0Ddgo05==00_o05==00?o0000o`1N
AOl0GTD01Ol0GTD00ol0003o06Xho`1Z>002o`1Z>007o`000?l0MBOo07DWo`000?l0PA;o0000o`N<
0006o`000003ool00?l0003o000002Wo008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00;ooooo;?l00QT00ol0003oo`00o`000007o`000005o`214_l0003o07DWo`1e9ol000000ol0
JSP2o`0000Ko05i50_l0000=o`1CC@03o`000?l0?TOo03i700_o03i70_l0000`o`0G<0;o00003Ol0
?TL00ol0003o05==o`1CC@0;o`1CC@;o00001_l0GTD2o`0000?o06Xh00Go0000o`1e9ol0MBOo0000
o`214P08o`000003ool00?l0003o008I02[o008I1Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo;?l00QT4o`000004olK10?l0003o0000o`0000;o1h`00_l00003o`1e9`03o`00
0?l0JSSo06Xh00;o06Xh00?o0000o`1NAOl0GTD01?l0GTD00ol0003o05==o`1CC@0;o`1CC@03o`00
0?l0?TOo03i700co03i700?o0000o`0G<?l05c00;_l05c000ol0003o03i7o`0nA`0<o`0nA`03o`00
0?l0Ddgo05==00_o05==00?o0000o`1NAOl0GTD01?l0GTD00ol0003o06Xho`1Z>002o`1Z>004o`00
0?l0MBOo07DWo`1e9`;o00000_l7S003o`000003olK10?l0003o000000;o0000:ol00QT5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_ooool]o`026@So000000Co1h`0o`000?l0PA;o
00000_l0MBL00ol0003o06Xho`1Z>002o`1Z>003o`000?l0GTGo05i500Go05i50_l0000<o`1CC@;o
00003?l0?TL2o`0002ko01L`0_l0000=o`0nA`03o`000?l0Ddgo05==00_o05==00?o0000o`1NAOl0
GTD01Ol0GTD00ol0003o06Xho`1Z>002o`1Z>007o`000?l0MBOo07DWo`000?l0PA;o0000o`N<0008
o`0002co008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo;Ol00QT00ol0
003oo`00ool00008o`000005o`214_l0003o07DWo`1e9ol000001?l0JSP00ol0003o05i5o`1NA@05
o`1NA@03o`000?l0Ddgo05==00co05==00?o0000o`0nAol0?TL02_l0?TL3o`0002[o01L`0ol0000<
o`0nA`;o00003Ol0Ddd00ol0003o05i5o`1NA@05o`1NA@03o`000?l0JSSo06Xh00;o06Xh00Go0000
o`1e9ol0MBOo0000o`214P08o`0000;oo`0000?o0000o`026Ol00QT0:_l00QT5ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_ooool^o`026@;o000000?oo`00o`000?l000001?l00000
1?l7S03o0000o`214_l00002o`1e9`03o`000?l0JSSo06Xh00;o06Xh00?o0000o`1NAOl0GTD01Ol0
GTD00ol0003o05==o`1CC@0<o`1CC@03o`000?l0?TOo03i700_o03i70ol0000Vo`0G<0Co00003?l0
?TL00ol0003o05==o`1CC@0<o`1CC@03o`000?l0GTGo05i500Go05i500?o0000o`1Z>?l0JSP00_l0
JSP01ol0003o07DWo`1e9ol0003o084Bo`000?l7S0001_l000000ooo003o0000o`00000]o`026@Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooboo008I00?o0000ool00?oo0000
0ol000001?m8X`3o0000o`000?l00002o`214P03o`000?l0MBOo000000Co06Xh00?o0000o`1NAOl0
GTD01_l0GTD00ol0003o05==o`1CC@0<o`1CC@03o`000?l0?TOo03i700_o03i70_l0000Vo`0G<0;o
00003Ol0?TL00ol0003o05==o`1CC@0<o`1CC@03o`000?l0GTGo05i500Ko05i500?o0000o`1Z>?l0
JSP00_l0JSP00ol0003o07DWo`000002o`214P?o000000CoB:<0o`000?l0003o00000_oo00000ol0
003o008Io`026@0/o`026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooboo
008I2Ol000001?l7S03o0000o`214_l00002o`1e9`03o`000?l0JSSo06Xh00;o06Xh00?o0000o`1N
AOl0GTD01Ol0GTD00ol0003o05==o`1CC@0<o`1CC@03o`000?l0?TOo03i700go03i70_l0000So`0G
<0;o00003_l0?TL00ol0003o05==o`1CC@0<o`1CC@03o`000?l0GTGo05i500Go05i500?o0000o`1Z
>?l0JSP00_l0JSP01ol0003o07DWo`1e9ol0003o084Bo`000?l7S0002Ol0000^o`026@Gooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`02oooooc7o008I2?l000001?l7S03o0000o`214_l0
0002o`1e9`;o00000ol0JSP2o`0000Ko05i500?o0000o`1CCOl0Ddd03?l0Ddd2o`0000ko03i70_l0
000Po`0G<0;o00003ol0?TL00ol0003o05==o`1CC@0<o`1CC@03o`000?l0GTGo05i500Co05i50_l0
0003o`1Z>0;o00000_l0MBL01?l0003o084Bo`000?l7S006o`000003ool00?l0003o008I02oo008I
1Oooool1o`00007ooooo000Kooooo`;o00000ooooolao`026@03o`000?oo003oo`0000Ko000000Co
1h`0o`000?l0PA;o00000_l0MBL00ol0003o06Xho`1Z>002o`1Z>003o`000?l0GTGo05i500Go05i5
0_l0000>o`1CC@03o`000?l0?TOo03i700co03i70_l0000No`0G<0;o00003_l0?TL2o`0000ko05==
00?o0000o`1NAOl0GTD01Ol0GTD00ol0003o06Xho`1Z>002o`1Z>007o`000?l0MBOo07DWo`000?l0
PA;o0000o`N<0006o`0000;oo`0000?o0000o`026Ol00QT0;_l00QT4ooooo`;o00000Oooool001_o
oooo00?o0000ooooooooool00_oooolbo`026@Wo000000Co1h`0o`000?l0PA;o00000_l0MBL00ol0
003o06Xho`1Z>002o`1Z>003o`000?l0GTGo05i500Go05i500?o0000o`1CCOl0Ddd03Ol0Ddd00ol0
003o03i7o`0nA`0<o`0nA`?o00006_l05c03o`0000ko03i700?o0000o`1CCOl0Ddd03Ol0Ddd00ol0
003o05i5o`1NA@05o`1NA@03o`000?l0JSSo06Xh00;o06Xh00Oo0000o`1e9ol0MBOo0000o`214_l0
003o1h`000Oo000000?oo`00o`000?l00QT0<?l00QT5ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_oooolco`026@03o`000?oo003o000000Co000000Go9IP0o`000?l0003o084Bo`00
0003o`1e9`03o`000?l0JSSo06Xh00;o06Xh00?o0000o`1NAOl0GTD01Ol0GTD00ol0003o05==o`1C
C@0=o`1CC@03o`000?l0?TOo03i700co03i70ol0000Io`0G<0;o00003_l0?TL00ol0003o05==o`1C
C@0=o`1CC@03o`000?l0GTGo05i500Go05i500?o0000o`1Z>?l0JSP00_l0JSP01_l0003o07DWo`1e
9ol0MBOo0000o`214P;o000000?o9IP0o`000?l000000ol000000ooo003o0000o`026@0ao`026@Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooc?o008I0_l000000ooo003o0000
o`000004o`000003o`N<0?l0003o084B00;o000000?o07DWo`000?l0JSP00ol0JSP00ol0003o05i5
o`1NA@06o`1NA@03o`000?l0Ddgo05==00co05==0_l0000?o`0nA`;o00005_l05c02o`0000oo03i7
0_l0000>o`1CC@;o00001ol0GTD00ol0003o06Xho`1Z>002o`1Z>007o`000?l0MBOo0000o`000?l0
PA;o0000o`N<0006o`000003ool00?l0003o000003;o008I1Oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo<ol00QT00ol0003oo`00ool00007o`000004o`N<0?l0003o084Bo`00
00;o07DW00?o0000o`1Z>?l0JSP00_l0JSP2o`0000Oo05i500?o0000o`1CCOl0Ddd03Ol0Ddd2o`00
00ko03i70_l0000Do`0G<0;o00003ol0?TL00ol0003o05==o`1CC@0=o`1CC@03o`000?l0GTGo05i5
00Ko05i500?o0000o`1Z>?l0JSP00_l0JSP01ol0003o07DWo`1e9ol0003o084Bo`000?l7S0001ol0
0002ool00003o`000?l00QWo008I033o008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00;ooooo=?l00QT2o`000003ool00?l0003o000000Oo000000Go084Bo`000?l0MBOo07DWo`00
0004o`1Z>003o`000?l0GTGo05i500Go05i50_l0000?o`1CC@03o`000?l0?TOo03i700go03i70_l0
000Bo`0G<0;o00003ol0?TL00ol0003o05==o`1CC@0=o`1CC@;o00001ol0GTD00ol0003o06Xho`1Z
>002o`1Z>004o`000?l0MBOo07DWo`0000;o084B2?l000000ooo003o0000o`00000co`026@Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooocKo008I00?o0000ool00?l000001_l0
00001?l7S03o0000o`214_l00002o`1e9`03o`000?l0JSSo06Xh00;o06Xh00?o0000o`1NAOl0GTD0
1_l0GTD00ol0003o05==o`1CC@0=o`1CC@;o00003_l0?TL3o`0000oo01L`0_l0000?o`0nA`03o`00
0?l0Ddgo05==00go05==0_l00007o`1NA@03o`000?l0JSSo06Xh00;o06Xh00Co0000o`1e9ol0MBOo
00000_l0PA82o`000003obFH0?l0003o000000?o000000?oo`00o`000?l00QT0=?l00QT5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_oooolfo`026@Wo000000Co1h`0o`000?l0PA;o
00000ol0MBL00ol0003o06Xho`1Z>002o`1Z>003o`000?l0GTGo05i500Ko05i500?o0000o`1CCOl0
Ddd03Ol0Ddd00ol0003o03i7o`0nA`0=o`0nA`;o00003_l05c02o`0000oo03i700?o0000o`1CCOl0
Ddd03Ol0Ddd00ol0003o05i5o`1NA@06o`1NA@03o`000?l0JSSo06Xh00;o06Xh00So0000o`1e9ol0
MBOo07DWo`000?l0PA;o0000o`N<00Wo0000=Ol00QT5ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_oooolgo`026@Wo000000Co1h`0o`000?l0PA;o00000_l0MBL00ol0003o06Xho`1Z
>002o`1Z>003o`000?l0GTGo05i500Ko05i500?o0000o`1CCOl0Ddd03_l0Ddd00ol0003o03i7o`0n
A`0=o`0nA`co000000Co01L`o`000?l0003o00003ol0?TL00ol0003o05==o`1CC@0>o`1CC@03o`00
0?l0GTGo05i500Ko05i500?o0000o`1Z>?l0JSP00_l0JSP01Ol0003o07DWo`1e9ol0003o084B00?o
000000?o9IP0o`000?l000001Ol0000fo`026@Gooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`02ooooocOo008I00?o0000ool00?oo00001Ol000000olUV03o0000o`000002o`214P04o`00
0?l0MBOo07DWo`0000Co06Xh00?o0000o`1NAOl0GTD01_l0GTD00ol0003o05==o`1CC@0>o`1CC@;o
00003ol0?TL2o`0000So02Tl0_l0000?o`0nA`;o00004?l0Ddd00ol0003o05i5o`1NA@06o`1NA@03
o`000?l0JSSo06Xh00;o06Xh00Co0000o`1e9ol0MBOo00000_l0PA88o`0000;oo`0000?o0000o`02
6Ol00QT0=?l00QT5ooooo`7o00000Oooool000Sooooo0_l00004ooooo`04o`000?oooooooooooooo
o`Go00001?ooool00ol0003oooooooooo`02ooooocSo008I0_l000000ooo003o0000o`000003o`00
0003obFH0?l0003o000000;o084B00?o0000o`1e9ol0MBL00_l00003o`1Z>0;o00001ol0GTD00ol0
003o05==o`1CC@0?o`1CC@03o`000?l0?TOo03i700go03i70_l00006o`0Y?0;o00003ol0?TL00ol0
003o05==o`1CC@0?o`1CC@03o`000?l0GTGo05i500Ko05i500?o0000o`1Z>?l0JSP00_l0JSP01?l0
003o07DWo`1e9ol00002o`214P;o000000?o9IP0o`000?l000000ol000000ooo003o0000o`00000g
o`026@Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00_oooolio`026@;o000000?oo`00o`000?l000001_l0
0002o`214P04o`000?l0MBOo07DWo`0000Co06Xh00?o0000o`1NAOl0GTD01_l0GTD00ol0003o05==
o`1CC@0?o`1CC@03o`000?l0?TOo03i700go03i70_l00004o`0Y?0;o00003ol0?TL00ol0003o05==
o`1CC@0?o`1CC@03o`000?l0GTGo05i500Ko05i500?o0000o`1Z>?l0JSP00_l0JSP01?l0003o07DW
o`1e9ol00002o`214P03o`000?l7S03o000000Go000000?oo`00o`000?l00000>?l00QT5ooooo`7o
00000Oooool000Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Co
oooo0_l00003ooooocWo008I0_l000001Ooo003o0000o`000?l0003oKjl000Co00000_l0PA801Ol0
003o07DWo`1e9ol0MBOo000000Co06Xh00?o0000o`1NAOl0GTD01_l0GTD00ol0003o05==o`1CC@0?
o`1CC@03o`000?l0?TOo03i700ko03i700Co0000o`0Y??l0:Cco00004?l0?TL00ol0003o05==o`1C
C@0@o`1CC@03o`000?l0GTGo05i500Go05i500?o0000o`1Z>?l0JSP00_l0JSP01Ol0003o07DWo`1e
9ol0MBOo000000;o084B1?l000001Om_[`3o0000o`000?l0003oo`0000;o0000>?l00QT4ooooo`;o
00000Oooool000Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo>Ol00QT2o`000003ool00?l0003o000000Go000000Go1h`0o`000?l0
003o084Bo`000002o`1e9`03o`000?l0JSSo06Xh00;o06Xh0_l00007o`1NA@;o00004Ol0Ddd2o`00
00ko03i71?l0000>o`0nA`;o00004Ol0Ddd2o`0000Oo05i50_l00004o`1Z>005o`000?l0MBOo07DW
o`000?l0PA800_l000000ol7S03o0000o`000005o`000003ool00?l0003o000003So008I1Oooool1
o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo>ol00QT2o`000003ool00?l0003o000000Co000000Go
1h`0o`000?l0PA;o084Bo`000002o`1e9`03o`000?l0JSSo06Xh00;o06Xh00?o0000o`1NAOl0GTD0
1ol0GTD00ol0003o05==o`1CC@0?o`1CC@;o00003Ol0?TL4o`0000go03i70_l0000Ao`1CC@;o0000
2?l0GTD00ol0003o06Xho`1Z>002o`1Z>008o`000?l0MBOo07DWo`1e9ol0003o084Bo`000?l7S006
o`000003ool00?l0003o000003[o008I1Oooool1o`00007ooooo0007ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo??l0
0QT9o`000005o`N<0?l0003o084Bo`214_l000000_l0MBL00ol0003o06Xho`1Z>002o`1Z>003o`00
0?l0GTGo05i500Oo05i500?o0000o`1CCOl0Ddd04?l0Ddd00ol0003o03i7o`0nA`08o`0nA`So0000
2_l0?TL00ol0003o05==o`1CC@0@o`1CC@03o`000?l0GTGo05i500Oo05i500?o0000o`1Z>?l0JSP0
0_l0JSP02?l0003o07DWo`1e9ol0MBOo0000o`214_l0003o1h`02Ol0000ko`026@Gooooo0Ol00001
ooooo`002?ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo??l00QT00ol0
003oo`00ool00007o`000004o`N<0?l0003o084Bo`0000?o07DW00?o0000o`1Z>?l0JSP00_l0JSP2
o`0000Oo05i50_l0000Bo`1CC@;o00001ol0?TL2o`0000Ko05i50_l00007o`0nA`;o00004_l0Ddd2
o`0000So05i500?o0000o`1Z>?l0JSP00_l0JSP02?l0003o07DWo`1e9ol0MBOo0000o`214_l0003o
1h`01ol00002ool00003o`000?l00QWo008I03Wo008I1Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo??l00QT2o`0000;oo`001Ol000000olUV03o0000o`000002o`214P05o`00
0?l0MBOo07DWo`1e9ol000001?l0JSP00ol0003o05i5o`1NA@07o`1NA@03o`000?l0Ddgo05==017o
05==00?o0000o`0nAol0?TL01?l0?TL00ol0003o05i5o`1NA@06o`1NA@03o`000?l0?TOo03i700Co
03i700?o0000o`1CCOl0Ddd04_l0Ddd00ol0003o05i5o`1NA@07o`1NA@03o`000?l0JSSo06Xh00;o
06Xh00Co0000o`1e9ol0MBOo00000_l0PA82o`000003obFH0?l0003o000000?o00000_oo0002o`00
03_o008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo?Ol00QT2o`000003
ool00?l0003o000000Go000000?o1h`0o`000?l000000_l00002o`1e9`03o`000?l0JSSo06Xh00?o
06Xh00?o0000o`1NAOl0GTD01_l0GTD00ol0003o05==o`1CC@0Bo`1CC@03o`000?l0?TOo03i700;o
03i70_l00008o`1NA@;o00001?l0?TL2o`0001?o05==00?o0000o`1NAOl0GTD01_l0GTD2o`0000Co
06Xh00?o0000o`1e9ol0MBL00_l000000ol0PA;o0000o`N<0007o`000003ool00?l0003o000003co
008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo?_l00QT:o`000004o`N<
0?l0003o084Bo`0000?o07DW00?o0000o`1Z>?l0JSP00ol0JSP00ol0003o05i5o`1NA@06o`1NA@03
o`000?l0Ddgo05==01;o05==1Ol0000;o`1NA@Co00005?l0Ddd00ol0003o05i5o`1NA@06o`1NA@;o
00001?l0JSP02?l0003o07DWo`1e9ol0MBOo0000o`214_l0003o1h`02_l0000mo`026@Gooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`02oooood3o008I2Ol000000ol7S03o0000o`214P02
o`0000;o07DW00?o0000o`1Z>?l0JSP00ol0JSP00ol0003o05i5o`1NA@06o`1NA@03o`000?l0Ddgo
05==01;o05==0ol0000<o`1NA@?o00005?l0Ddd00ol0003o05i5o`1NA@07o`1NA@03o`000?l0JSSo
06Xh00;o06Xh00Ko0000o`1e9ol0MBOo07DWo`000?l0PA83o`000003obFH0?l0003o000000?o0000
00?oo`00o`000?l00QT0?_l00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
oom0o`026@03o`000?oo003oo`0000Go000000Ko9IP0o`000?l7S03o0000o`214_l00003o`1e9`03
o`000?l0JSSo06Xh00;o06Xh0_l00008o`1NA@03o`000?l0Ddgo05==013o05==00?o0000o`1NAOl0
GTD04?l0GTD00ol0003o05==o`1CC@0@o`1CC@03o`000?l0GTGo05i500Oo05i500?o0000o`1Z>?l0
JSP00_l0JSP02?l0003o07DWo`1e9ol0MBOo0000o`214_l0003o1h`01ol00002ool00003o`000?l0
0QWo008I03go008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo@?l00QT2
o`000003ool00?l0003o000000?o000000Co9IP0o`000?l7S03o00000_l0PA801?l0003o07DWo`1e
9ol00005o`1Z>003o`000?l0GTGo05i500Oo05i500?o0000o`1CCOl0Ddd03_l0Ddd00ol0003o05i5
o`1NA@0Bo`1NA@03o`000?l0Ddgo05==00oo05==00?o0000o`1NAOl0GTD01ol0GTD00ol0003o06Xh
o`1Z>002o`1Z>00:o`000?l0MBOo07DWo`1e9ol0003o084Bo`000?l7S03o0000obFH00?o000000?o
gH40o`000?oo00000_l0000oo`026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02
oooood7o008I0_l000000ooo003o0000o`000005o`000003o`N<0?l0003o084B00;o00000_l0MBL0
0ol0003o06Xho`1Z>003o`1Z>003o`000?l0GTGo05i500Oo05i500?o0000o`1CCOl0Ddd03?l0Ddd0
0ol0003o05i5o`1NA@0Do`1NA@03o`000?l0Ddgo05==00co05==0_l00009o`1NA@03o`000?l0JSSo
06Xh00;o06Xh00?o0000o`1e9ol0MBL00_l00002o`214P;o000000?o9IP0o`000?l000000ol00000
0ooo003o0000o`000010o`026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooo
od;o008I0_l000000ooo003o0000o`000003o`000003obFH0?l0003o000000;o084B00Go0000o`1e
9ol0MBOo07DWo`000005o`1Z>003o`000?l0GTGo05i500Oo05i500?o0000o`1CCOl0Ddd02Ol0Ddd2
o`0001So05i50_l0000;o`1CC@03o`000?l0GTGo05i500Oo05i50_l00004o`1Z>0;o00000_l0MBL0
0ol0003o084Bo`214P08o`000003ool00?l0003o0000047o008I1Oooool1o`00007ooooo000Koooo
o`;o00000ooooom2o`026@;o000000?oo`00o`000?l000001?l000001_lUV03o0000o`000?l0003o
084Bo`0000?o07DW00?o0000o`1Z>?l0JSP00ol0JSP00ol0003o05i5o`1NA@07o`1NA@03o`000?l0
Ddgo05==00So05==00?o0000o`1NAOl0GTD06?l0GTD00ol0003o05==o`1CC@08o`1CC@03o`000?l0
GTGo05i500So05i500?o0000o`1Z>?l0JSP00_l0JSP01Ol0003o07DWo`1e9ol0MBOo000000;o084B
00?o0000o`N<0?l000001_l000000ooo003o0000o`000011o`026@Cooooo0_l00001ooooo`006ooo
ool00ol0003oooooooooo`02oooood?o008I0_l000000ooo003o0000o`000005o`000005o`N<0?l0
003o084Bo`214_l000000ol0MBL00ol0003o06Xho`1Z>002o`1Z>0;o00002Ol0GTD00ol0003o05==
o`1CC@04o`1CC@?o00007?l0GTD3o`0000Ko05==00?o0000o`1NAOl0GTD02?l0GTD00ol0003o06Xh
o`1Z>002o`1Z>005o`000?l0MBOo07DWo`1e9ol000000_l0PA800ol0003o1h`0o`000006o`000003
ool00?l0003o000004;o008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
A?l00QT4o`000003om6S0?l0003o000000;o00000_l7S0000ol0003o084Bo`000003o`1e9`03o`00
0?l0JSSo06Xh00?o06Xh00?o0000o`1NAOl0GTD01ol0GTD00ol0003o05==o`1CC@04o`1CC@03o`00
0?l0JSSo000001co05i500Co0000o`1Z>?l0003o00001Ol0Ddd00ol0003o05i5o`1NA@07o`1NA@03
o`000?l0JSSo06Xh00?o06Xh00Oo0000o`1e9ol0MBOo07DWo`000?l0PA;o000000;o1h`00ol00000
0onK^P3o0000o`000003o`0004?o008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;oooooAOl00QT;o`0000;o084B00Go0000o`1e9ol0MBOo07DWo`000005o`1Z>003o`000?l0GTGo
05i500Oo05i50_l00002o`1CC@;o00000ol0JSP3o`0001Ko05i50ol00003o`1Z>0;o00000ol0Ddd0
0ol0003o05i5o`1NA@07o`1NA@03o`000?l0JSSo06Xh00?o06Xh00Go0000o`1e9ol0MBOo07DWo`00
0002o`214P03o`000?l7S03o000000Ko000000?oo`00o`000?l00QT0@ol00QT5ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_oooom5o`026@03o`000?oo003oo`0000Oo000000Go1h`0
o`000?l0PA;o084Bo`000003o`1e9`03o`000?l0JSSo06Xh00?o06Xh00?o0000o`1NAOl0GTD02?l0
GTD3o`0000Oo06Xh1?l0000>o`1NA@Co00001ol0JSP2o`000003o`1CCOl0003o05i500So05i50_l0
0005o`1Z>003o`000?l0MBOo07DW00;o000000?o084Bo`000?l7S0001ol00002ool00003o`000?l0
0QWo008I04;o008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;oooooA_l00QT2
o`000003ool00?l0003o000000;o000000GoB:<0o`000?l0003o1h`0o`000002o`214P05o`000?l0
MBOo07DWo`1e9ol000001Ol0JSP00ol0003o05i5o`1NA@07o`1NA@;o00003?l0JSP3o`0000So05i5
0ol0000<o`1Z>0;o00002Ol0GTD00ol0003o06Xho`1Z>004o`1Z>003o`000?l0MBOo07DW00;o0000
00Go084Bo`000?l7S03o0000obFH0008o`0004Go008I1Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;oooooA_l00QT00ol0003oo`00ool00006o`000004obFH0?l0003o0000o`0000;o
084B00Co0000o`1e9ol0MBOo00001_l0JSP00ol0003o05i5o`1NA@05o`1NA@;o00004?l0JSP8o`00
013o06Xh0_l00007o`1NA@03o`000?l0JSSo06Xh00Co06Xh00Ko0000o`1e9ol0MBOo07DWo`000?l0
PA83o`000003obFH0?l0003o000000Co00000_oo00000ol0003o008Io`026@13o`026@Gooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`02ooooodKo008I00Co0000ool00?oo003oo`000ol0
00001?m_[`3o0000o`000?l00002o`N<0003o`000?l0PA;o000000?o07DW00?o0000o`1Z>?l0JSP0
0ol0JSP00ol0003o05i5o`1NA@03o`1NA@?o0000:ol0JSP2o`0000Go05i500?o0000o`1Z>?l0JSP0
0ol0JSP01Ol0003o07DWo`1e9ol0MBOo000000;o084B00Go0000o`N<0?l0003o0000odRS0004o`00
00?oo`0000?o0000o`026Ol00QT0@ol00QT5ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00_oooom7o`026@Wo000000Ko9IP0o`000?l7S03o0000o`214_l00003o`1e9`;o00001Ol0JSP0
1?l0003o05i5o`1NAOl0GTD2o`0002oo06Xh00Go0000o`1NAOl0GTGo05i5o`000005o`1Z>0;o0000
0ol0MBL01_l0003o084Bo`000?l7S03o0000obFH00Ko000000?oo`00o`000?l00000A_l00QT5oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom9o`026@03o`000?oo003o000000Go
000000Ko9IP0o`000?l7S03o0000o`214_l00003o`1e9`03o`000?l0JSSo06Xh00Co06Xh00?o0000
o`1NAOl000000_l0000^o`1Z>0Go00001_l0JSP01_l0003o07DWo`1e9ol0MBOo0000o`214P;o0000
00?o1h`0o`000?l000001Ol000000ooo003o0000o`000017o`026@Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooodWo008I00?o0000ool00?oo00002Ol00002o`214P04o`000?l0
MBOo07DWo`1e9`;o00001Ol0JSP2o`0000;o07DW00?o0000o`1Z>?l0JSP0:_l0JSP00ol0003o07DW
o`1e9`03o`0000Go06Xh00Go0000o`1e9ol0MBOo07DWo`000002o`214P03o`000?l7S03o000000Oo
000000?oo`00o`000?l00000Aol00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_oooom:o`026@03o`000?oo003oo`0000Oo000000Go1h`0o`000?l0PA;o084Bo`000003o`1e9`03
o`000?l0JSSo06Xh00;o06Xh0_l00004o`1e9`;o0000:?l0JSP3o`0000Co07DW00?o0000o`1Z>?l0
JSP00_l0JSP01?l0003o07DWo`1e9ol0MBL2o`000003o`214_l0003o1h`000Oo00000_oo0002o`00
04So008I1Oooool1o`00007ooooo000Kooooo`;o00000ooooom:o`026@;o00000_oo0004o`000004
odRS0?l0003o0000o`0000?o084B00Ko0000o`1e9ol0MBOo07DWo`000?l0JSP2o`0000Oo07DW00?o
0000o`1Z>?l0JSP09_l0JSP00ol0003o07DWo`1e9`05o`1e9`;o00000_l0JSP01?l0003o07DWo`1e
9ol00003o`214P;o000000?o9IP0o`000?l000001?l000000ooo003o0000o`000019o`026@Cooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`02oooood_o008I0_l000000ooo003o0000o`00
0005o`000005o`N<0?l0003o084Bo`214_l000000ol0MBL4o`0000So07DW00?o0000o`1Z>?l0JSP0
9?l0JSP00ol0003o07DWo`1e9`06o`1e9`Co00000ol0MBL01Ol0003o084Bo`214_l0003o1h`000;o
000000?oB:<0o`000?l000000_l000000ooo003o0000o`00001:o`026@Gooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`02oooood_o008I00?o0000ool00?oo00002?l000001Ol7S03o0000
o`214_l0PA;o000000;o07DW0_l00002o`214P03o`000?l0MBOo07DW00Ko07DW0_l0000Ro`1Z>0;o
00002Ol0MBL00ol0003o084Bo`000002o`000006o`1e9ol0003o084Bo`214_l0003o1h`02?l00002
ool00003o`000?l00QWo008I04So008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;oooooC?l00QT2o`000003ool00?l0003o000000Co000000Co9IP0o`000?l7S03o00000_l0PA83
o`0000Co084B00?o0000o`1e9ol0MBL01ol0MBL2o`0001ko06Xh0_l00009o`1e9`;o00001?l0PA83
o`000005o`214_l0003o0000o`000?lUV0001_l000000ooo003o0000o`00001;o`026@Gooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`02ooooodko008I00?o0000ool00?l000001ol00000
1_l7S03o0000o`214_l0003o1h`0o`0000Go084B00?o0000o`1e9ol0MBL02?l0MBL00ol0003o06Xh
o`1Z>00Jo`1Z>003o`000?l0MBOo07DW00So07DW0_l00004o`214P06o`000?l7S03o0000o`214_l0
003o1h`02?l000000ooo003o0000o`00001<o`026@Gooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`02ooooodko008I00?o0000ool00?l000001Ol000001OlUV03o0000o`N<0?l7S03o0000
00?o1h`000?o0000o`214_l0PA800_l0PA800ol0003o07DWo`1e9`09o`1e9`?o00005ol0JSP2o`00
00_o07DW00?o0000o`214_l0PA800_l0PA801Ol0003o1h`0o`N<0?l7S03o000000;o1h`000Go0000
obFH0?l0003o0000oi^j0003o`000003ool00?l0003o000004co008I1Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;oooooC_l00QT2o`000003ool00?l0003o000000Wo00000_l7S000
0ol0003o084Bo`214P03o`214P03o`000?l0MBOo07DW00[o07DW0_l0000Do`1Z>0;o00003?l0MBL0
0ol0003o084Bo`214P03o`214P03o`000?l7S03o1h`000_o000000Coo`00o`000?l0003o0000C?l0
0QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom?o`026@03o`000?oo003o
o`0000So000000?o9IP0o`000?l000000_l7S0000ol0003o084Bo`214P03o`214P03o`000?l0MBOo
07DW00_o07DW0ol0000>o`1Z>0?o00003Ol0MBL00ol0003o084Bo`214P03o`214P08o`000?l7S03o
1h`0o`N<0?l0003o9IP0o`000?m8X`06o`0000;oo`0000?o0000o`026Ol00QT0C?l00QT5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_oooom?o`026@04o`000?oo003oo`00ool000Ko
000000GoB:<0o`000?lUV03o9IP0o`000002o`N<0003o`000?l0PA;o084B00?o084B0_l0000>o`1e
9`;o00002_l0JSP2o`0000ko07DW0_l00005o`214P08o`000?l7S03o1h`0o`N<0?l0003o9IP0o`00
0?m8X`07o`0000;oo`0000?o0000o`026Ol00QT0C?l00QT5ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool00_oooom@o`026@;o000000?oo`00o`000?l000001Ol000001?m8X`3o0000obFH
0?l00003o`N<0003o`000?l0PA;o084B00Co084B00?o0000o`1e9ol0MBL03Ol0MBL:o`0000oo07DW
00?o0000o`214_l0PA801?l0PA802?l0003o1h`0o`N<0?l7S03o0000obFH0?l0003oB:<01ol00002
ool00003o`000?l00QWo008I04go008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;oooooD?l00QT2o`0000;oo`001_l000001Om8X`3o0000obFH0?lUV03o000000?o1h`000?o0000
o`214_l0PA800ol0PA82o`0002Ko07DW0_l00006o`214P04o`000?l7S03o1h`0o`0000;o9IP000?o
0000odRS0?l000001Ol00002ool000;o0000Col00QT5ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_oooomAo`026@;o00000_oo0006o`000004odRS0?l0003o9IP0o`0000?o1h`00_l0
0005o`214P03o`000?l0MBOo07DW02Co07DW00?o0000o`214_l0PA800ol0PA82o`0000?o1h`000Co
0000obFH0?l0003oB:<01ol000000ooo003o0000o`00001@o`026@Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02oooooe7o008I0_l00002ool000Go000000KoKjl0o`000?m8X`3o0000
obFH0?l00003o`N<0003o`000?l0PA;o084B00Co084B0_l0000Ro`1e9`;o00001_l0PA801_l0003o
1h`0o`N<0?l7S03o0000obFH00?o000000?oKjl0o`000?l000000ol00002ool000;o0000D?l00QT5
ooooo`7o00000Oooool001_ooooo0_l00003oooooe3o008I0_l000001?l02bGo0000ool00?oo0007
o`000004odRS0?l0003o9IP0o`0000?o1h`000?o0000o`214_l0PA801Ol0PA800ol0003o07DWo`1e
9`0No`1e9`03o`000?l0PA;o084B00Go084B00Go0000o`N<0?l7S03o1h`0o`000002obFH00So0000
0_oo0004o`0004oo008I1?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00;oooooC_l0
0QT2o`0000?o00/U00Co0000ool00?oo003oo`001_l000001Om8X`3o0000obFH0?lUV03o000000?o
1h`00_l00006o`214P03o`000?l0MBOo07DW01co07DW00?o0000o`214_l0PA801Ol0PA801Ol0003o
1h`0o`N<0?l7S03o000000;o9IP000?o0000odRS0?l000001Ol00003ool000;o00000_l02bD2o`00
04go008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;oooooC_l00QT00ol0003o
00/Uo`0;9@02o`0;9@;o00000ooo0004o`000004ofn_0?l0003oB:<0o`0000;o9IP000Go0000o`N<
0?l7S03o1h`0o`000007o`214P03o`000?l0MBOo07DW01[o07DW00?o0000o`214_l0PA801_l0PA80
1ol0003o1h`0o`N<0?l7S03o0000obFH0?l000000_m8X`06o`0000?oo`0000?o0000o`0;9Ol02bD0
0ol02bD00ol0003o008Io`026@1:o`026@Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`02ooooodgo008I00?o0000o`0;9Ol02bD01?l02bD2o`0000;oo`002?l00002obFH0003o`000?l7
S03o1h`000;o1h`000?o0000o`214_l0PA801Ol0PA82o`0001So07DW0_l00007o`214P;o00000ol7
S0000ol0003o9IP0obFH0008o`0000;oo`000_l00006o`0;9@03o`000?l00QWo008I04[o008I1Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;oooooC?l00QT00ol0003o00/Uo`0;9@06
o`0;9@;o000000?oo`00o`000?l000001Ol000001Om8X`3o0000obFH0?lUV03o000000Co1h`000?o
0000o`214_l0PA801_l0PA800ol0003o07DWo`1e9`0Do`1e9`03o`000?l0PA;o084B00Ko084B00?o
0000o`N<0?l7S0000_l7S0001Ol0003o9IP0obFH0?l0003oB:<000Oo000000?oo`00o`000?l00000
2?l02bD00ol0003o008Io`026@19o`026@Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`02ooooodWo008I0ol00009o`0;9@04o`000?oo003oo`00ool000Co000000GoVkX0o`000?l0003o
B:<0o`000002obFH0003o`000?l7S03o1h`000;o1h`000?o0000o`214_l0PA801_l0PA82o`0001;o
07DW0_l00008o`214P03o`000?l7S03o1h`000;o1h`000Oo0000obFH0?lUV03o0000odRS0?l0003o
Kjl000Go00000ooo00000ol0003o00/Uo`0;9@07o`0;9@?o0000B?l00QT5ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_oooom8o`026@;o00003?l02bD2o`0000;oo`001Ol000001?m_
[`3o0000odRS0?l00002obFH0003o`000?l7S03o1h`000;o1h`000?o0000o`214_l0PA801ol0PA82
o`0000ko07DW0_l00009o`214P03o`000?l7S03o1h`000;o1h`000?o0000obFH0?lUV0000ol00000
0om_[`3o0000o`000003o`0000;oo`000_l0000=o`0;9@03o`000?l00QWo008I04Go008I1Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;oooooAol00QT00ol0003o00/Uo`0;9@0<o`0;
9@;o00000_oo0005o`000004ofn_0?l0003oB:<0o`0000;o9IP000?o0000o`N<0?l7S0000_l7S000
0ol0003o084Bo`214P09o`214P?o00002?l0MBL3o`0000_o084B00?o0000o`N<0?l7S0000_l7S000
1ol0003o9IP0obFH0?l0003oB:<0o`000?m_[`001Ol00002ool000;o00003_l02bD00ol0003o008I
o`026@14o`026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooodOo008I00?o
0000o`0;9Ol02bD03?l02bD2o`0000?oo`001Ol000001?m_[`3o0000odRS0?l00002obFH00;o0000
0ol7S002o`0000co084B2?l0000<o`214P;o00001?l7S0001ol0003o9IP0obFH0?l0003oB:<0o`00
0?m_[`001Ol00004ool00003o`000?l02bGo00/U00co00/U00?o0000o`026Ol00QT0A?l00QT5oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom6o`026@03o`000?l02bGo00/U00oo
00/U00?o0000ool00?oo00001_l000001?m_[`3o0000odRS0?l00002obFH0003o`000?l7S03o1h`0
00?o1h`000?o0000o`214_l0PA807?l0PA82o`0000Co1h`000Co0000obFH0?lUV03o00000_m8X`07
o`0000;oo`000_l0000@o`0;9@03o`000?l00QWo008I04?o008I1Oooool1o`00007ooooo000Doooo
o`;o00001Oooool00ol0003oooooooooo`02ooooodCo008I0_l0000Bo`0;9@04o`000?oo003oo`00
ool000Oo00000_m8X`001?l0003o9IP0obFH0?l00005o`N<0003o`000?l0PA;o084B01[o084B00?o
0000o`N<0?l7S0000ol7S0001?l0003o9IP0obFH0?l00002odRS00Oo00000ooo0002o`00017o00/U
0_l00013o`026@Gooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00;ooooo@_l00QT2o`0001Go00/U00Co0000ool00?oo003oo`001ol000000om8X`3o
0000o`000002obFH0003o`000?l7S03o1h`000?o1h`000?o0000o`214_l0PA806?l0PA800ol0003o
1h`0o`N<0003o`N<0003o`000?lUV03o9IP000;o000000?oB:<0o`000?m_[`001_l00002ool00003
o`000?l02bGo00/U01?o00/U0_l00011o`026@Gooooo0Ol00001ooooo`004oooool01?l0003ooooo
ooooool00004ooooo`;o00000ooooom1o`026@03o`000?l02bGo00/U01Go00/U0_l00002ool000Co
000000?oVkX0o`000?l000000_m8X`001?l0003o9IP0obFH0?l00005o`N<00;o00006?l0PA82o`00
00Go1h`000Co0000obFH0?lUV03o00000_m8X`000ol0003oKjl0o`000004o`0000;oo`000_l0000G
o`0;9@03o`000?l00QWo008I03ko008I1?ooool2o`00007ooooo000Cooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool00_oooom1o`026@03o`000?l02bGo00/U01Ko00/U0_l00002
ool000Oo00000_m8X`001?l0003o9IP0obFH0?l00006o`N<00;o00005?l0PA82o`0000Ko1h`000Ko
0000obFH0?lUV03o9IP0o`000?m8X`07o`0000;oo`000_l0000Ho`0;9@03o`000?l00QWo008I03ko
008I1Oooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool00_ooooloo`026@;o00006Ol02bD01?l0003oo`00ool00?oo0006o`000005ofn_0?l0003oB:<0
odRS0?l000000_lUV002o`0000Ko1h`000?o0000o`214_l0PA804?l0PA82o`0000Go1h`00_l00002
obFH00;o000000?oB:<0o`000?m_[`001_l00003ool00003o`000?l02bGo00/U01Oo00/U0_l0000n
o`026@Gooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo?_l00QT00ol0003o00/Uo`0;9@0Jo`0;9@;o00000_oo0006o`000004ofn_0?l0003o
B:<0o`0000?o9IP000?o0000o`N<0?l7S0001Ol7S002o`0000ko084B0_l00007o`N<0008o`000?lU
V03o9IP0obFH0?l0003oB:<0o`000?m_[`06o`0000;oo`000_l0000Lo`0;9@03o`000?l00QWo008I
03_o008I1Oooool1o`00007ooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`02ooooocgo
008I00?o0000o`0;9Ol02bD06ol02bD2o`0000;oo`000_l000001?oMP@3o0000o`000?l00002ofn_
0003o`000?m8X`3o000000?o9IP000?o0000o`N<0?l7S0001_l7S002o`0000[o084B0_l00008o`N<
0005o`000?lUV03o9IP0obFH0?l000000_m8X`000ol0003oKjl0o`000005o`0000;oo`000_l0000M
o`0;9@03o`000?l00QWo008I03[o008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo>ol00QT3o`0001go00/U0ol00002ool000Ko000000CoKjl0o`000?m8X`3o00001?lUV000
0ol0003o1h`0o`N<0006o`N<00Go00000_l0PA85o`0000So1h`000?o0000obFH0?lUV0000_lUV000
1?l0003oB:<0o`000?m_[`06o`0000?oo`000_l0000Mo`0;9@?o0000>_l00QT5ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_ooooljo`026@03o`000?l02bGo00/U023o00/U00Co0000
ool00?oo003oo`001?l000001_nK^P3o0000ofn_0?l0003oB:<0o`0000Co9IP000?o0000o`N<0?l7
S0002_l7S002o`0000co1h`000?o0000obFH0?lUV0000_lUV0001_l0003oB:<0o`000?m_[`3o0000
oi^j00Co00000ooo0002o`00027o00/U00?o0000o`026Ol00QT0=ol00QT5ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_oooolio`026@03o`000?l02bGo00/U027o00/U00Co0000ool0
0?oo003oo`001Ol000001OnK^P3o0000ofn_0?l0003oB:<000;o00000olUV002o`0001Ko1h`00_l0
0003obFH00;o00000_m8X`000ol0003oKjl0o`000005o`0000?oo`000_l0000Ro`0;9@03o`000?l0
0QWo008I03Ko008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo>?l00QT0
0ol0003o00/Uo`0;9@0So`0;9@04o`000?oo003oo`00ool000Ko000000GoKjl0o`000?m8X`3oB:<0
o`000005obFH0003o`000?l7S03o1h`001?o1h`000?o0000obFH0?lUV0000_lUV0001Ol0003oB:<0
odRS0?l0003oKjl000Ko00000ooo0002o`0002Co00/U00?o0000o`026Ol00QT0=Ol00QT5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_oooolgo`026@03o`000?l02bGo00/U02Co00/U
00Co0000ool00?oo003oo`001?l000001?o6`@3o0000o`000?l00003odRS0003o`000?lUV03o9IP0
00;o9IP000?o0000o`N<0?l7S0004_l7S0000ol0003o9IP0obFH0002obFH0004o`000?m8X`3oB:<0
odRS00;o000000?oVkX0o`000?l000000ol00003ool00003o`000?l02bGo00/U02Co00/U00?o0000
o`026Ol00QT0=?l00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolgo`02
6@03o`000?l02bGo00/U02Co00/U00?o0000ool00?oo00000_oo0006o`000004ofn_0?l0003oB:<0
odRS00;o00001?lUV0000ol0003o1h`0o`N<000@o`N<0003o`000?lUV03o9IP000;o9IP00_l00002
odRS0005o`000?m_[`3o0000o`000?o6`@000ol00004ool00003o`000?l02bGo00/U02Co00/U00?o
0000o`026Ol00QT0=?l00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooold
o`026@?o0000:?l02bD2o`0000?oo`001_l000000om_[`3o0000o`000002odRS0003o`000?lUV03o
9IP000;o9IP00ol0000<o`N<00?o00001OlUV0001Ol0003oB:<0o`000?l0003oKjl000Oo00000ooo
00000ol0003o00/Uo`0;9@0Vo`0;9@?o0000<ol00QT5ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_oooolco`026@03o`000?l02bGo00/U02[o00/U0_l00002ool000Go000000CoVkX0
o`000?m_[`3o00000_m8X`02o`0000Ko9IP000?o0000o`N<0?l7S0002?l7S0000ol0003o9IP0obFH
0004obFH00;o00000_m8X`001?l0003oKjl0o`000?nK^P05o`0000;oo`000_l0000/o`0;9@03o`00
0?l00QWo008I033o008I1Oooool1o`00007ooooo000Kooooo`;o00000ooooolbo`026@03o`000?l0
2bGo00/U02_o00/U0_l00003ool000Oo000000?oKjl0o`000?m8X`000_m8X`000ol0003o9IP0obFH
0004obFH00[o00001_lUV0001_l0003oB:<0odRS0?m8X`3o0000ofn_00Oo00000ooo0002o`0002go
00/U00?o0000o`026Ol00QT0;ol00QT4ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0
0_oooolao`026@03o`000?l02bGo00/U02go00/U0_l00002ool00003o`000?oXFP3o000000;o0000
00CoVkX0o`000?m_[`3o00001?m8X`000ol0003o9IP0obFH000BobFH0003o`000?m8X`3oB:<000;o
B:<000Co0000ofn_0?l0003oVkX01Ol00003ool000;o0000;_l02bD00ol0003o008Io`026@0^o`02
6@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooc3o008I00?o0000o`0;9Ol0
2bD0;ol02bD01?l0003oo`00ool00?oo0005o`000004oi^j0?l0003oKjl0o`0000?oB:<000?o0000
obFH0?lUV0004_lUV0001_l0003oB:<0odRS0?m8X`3o0000ofn_00Oo00000ooo0002o`00033o00/U
00?o0000o`026Ol00QT0;Ol00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool_o`026@03o`000?l02bGo00/U033o00/U00Co0000ool00?oo003oo`001?l000001_o6`@3o0000
o`000?l0003oKjl0o`0000?oB:<000?o0000obFH0?lUV0004?lUV0001_l0003oB:<0odRS0?m8X`3o
0000ofn_00?o000000?oa/40o`000?l000000_l00003ool000;o0000<Ol02bD00ol0003o008Io`02
6@0/o`026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobgo008I0_l0000d
o`0;9@;o00000_oo0007o`0000;oKjl000Co0000odRS0?m8X`3oB:<00_l0000>obFH00;o00000om8
X`000ol0003oKjl0ofn_0007o`0000?oo`000_l0000co`0;9@;o0000;?l00QT5ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_ooool[o`026@;o0000=_l02bD00ol0003oo`00ool00002
ool000Go000000GoVkX0o`000?m_[`3oKjl0o`000004odRS00;o00002_lUV002o`0000CoB:<000Go
0000ofn_0?m_[`3o0000oi^j0005o`0000Coo`0000?o0000o`0;9Ol02bD0=?l02bD2o`0002[o008I
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo:_l00QT00ol0003o00/Uo`0;
9@0fo`0;9@;o00000ooo0003o`000004om6S0?l0003o0000o`0000?oKjl000?o0000odRS0?m8X`00
0om8X`000ol0003o9IP0obFH0006obFH0003o`000?m8X`3oB:<000?oB:<000Co0000ofn_0?m_[`3o
Kjl00ol000001?oAX`3o0000o`000?l00003ool000;o0000>?l02bD00ol0003o008Io`026@0Wo`02
6@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooob[o008I00?o0000o`0;9Ol0
2bD0=ol02bD2o`0000;oo`001_l000001?nK^P3o0000ofn_0?m_[`02o`0000GoB:<02?l00005odRS
00;o00000_m_[`001Ol0003oVkX0o`000?l0003odJ<000?o00000_oo0002o`0003Wo00/U00?o0000
o`026Ol00QT09ol00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolYo`02
6@03o`000?l02bGo00/U03So00/U0_l00003ool000Ko000000?oVkX0o`000?l000000_m_[`000ol0
003oB:<0odRS000?odRS0005o`000?m_[`3o0000o`000?nK^P001_l00004ool00003o`000?l02bGo
00/U03So00/U00?o0000o`026Ol00QT09_l00QT5ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool00_oooolVo`026@?o0000>ol02bD3o`0000?oo`001?l000001?o6`@3o0000oi^j0?l00002
ofn_00;o00003_m8X`02o`0000;oKjl000Co0000oi^j0?l0003oa/401?l00003ool000?o0000>ol0
2bD3o`0002Go008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo9Ol00QT0
0ol0003o00/Uo`0;9@0lo`0;9@?o00000ooo0007o`000003oi^j0?l0003oKjl000;oKjl000?o0000
odRS0?m8X`002_m8X`001_l0003oKjl0ofn_0?m_[`3o0000oi^j00Oo00000ooo0002o`000003o`0G
<?l0003o00/U03co00/U00?o0000o`026Ol00QT08_l00QT5ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool00_oooolTo`026@03o`000?l02bGo00/U03co00/U00?o0000o`0G<?l05c000_l0
0003ool000Co000000Goa/40o`000?nK^P3oVkX0o`000003ofn_00;o00002?m8X`02o`0000?oKjl0
00Go0000oi^j0?nK^P3o0000olK10003o`000003oo@_0?l0003oo`0000;oo`000_l000000ol05c3o
0000o`0;9@0mo`0;9@03o`000?l00QWo008I027o008I1Oooool1o`00007ooooo000Kooooo`;o0000
0ooooolTo`026@03o`000?l02bGo00/U03co00/U00Go0000o`0G<?l05c3o01L`o`000003ool000Go
000000Coa/40o`000?nK^P3o00001Om_[`03o`0000;oB:<01?l00004ofn_0003o`000?nK^P3o0000
00Ko00000ooo0002o`0000;o01L`00?o0000o`0;9Ol02bD0??l02bD00ol0003o008Io`026@0Qo`02
6@Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`02ooooob?o008I00?o0000o`0;9Ol0
2bD0??l02bD00ol0003o01L`o`0G<002o`0G<003o`000?oo003oo`0000;oo`000ol000001OoAX`3o
0000olK10?l0003oVkX000;o00001_m_[`02o`0000KoKjl00_l000001OnK^P3o0000o`000?l0003o
dJ<000?o00001?oo00000ol0003o01L`o`0G<002o`0G<0;o0000?Ol02bD2o`00027o008I1Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo8Ol00QT2o`0003ko00/U0_l00004o`0G
<003o`000?oo003oo`0000?oo`000ol000000ooAX`3o0000o`000003oi^j0003o`000?m_[`3oKjl0
00[oKjl000Co0000oi^j0?nK^P3oVkX01ol00004ool000;o00001?l05c000ol0003o00/Uo`0;9@0m
o`0;9@03o`000?l00QWo008I01ko008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo7ol00QT2o`0003oo00/U00?o0000o`0G<?l05c001Ol05c000ol0003oo`00ool00002ool0
00Go000000?oa/40o`000?l000000_nK^P000ol0003oKjl0ofn_0008ofn_0006o`000?nK^P3oVkX0
oi^j0?l0003oa/401Ol00004ool00003o`000?l05c3o01L`00Go01L`00?o0000o`0;9Ol02bD0?Ol0
2bD2o`0001ko008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo7_l00QT0
0ol0003o00/Uo`0;9@0oo`0;9@03o`000?l05c3o01L`00Go01L`00?o0000ool00?oo00000_oo0004
o`000004om6S0?l0003oa/40o`0000?oVkX000?o0000ofn_0?m_[`001_m_[`002?l0003oVkX0oi^j
0?nK^P3o0000olK10?l0003odJ<01?l00004ool00003o`000?l05c3o01L`00Go01L`00?o0000o`0;
9Ol02bD0?ol02bD00ol0003o008Io`026@0Ko`026@Gooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`02oooooako008I00?o0000o`0;9Ol02bD0?ol02bD00ol0003o01L`o`0G<005o`0G<003
o`000?oo003oo`0000?oo`001Ol00002olK10004o`000?nK^P3oVkX0oi^j00So00000onK^P02o`00
0004olK10?l0003o0000omf100;o00001Ooo00000ol0003o01L`o`0G<005o`0G<003o`000?l02bGo
00/U03oo00/U0_l0000Lo`026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooo
oaco008I0_l00011o`0;9@03o`000?l05c3o01L`00Oo01L`0_l00004ool000Go00000_o6`@000ol0
003oVkX0oi^j000:oi^j0003o`000?o6`@3oa/4000Go00001Ooo00000ol0003o01L`o`0G<007o`0G
<003o`000?l02bGo00/U043o00/U00?o0000o`026Ol00QT06Ol00QT5ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_oooolKo`026@03o`000?l02bGo00/U043o00/U00?o0000o`0G<?l0
5c002?l05c000ol0003oo`00ool00003ool000Co000000GodJ<0o`000?o6`@3oa/40o`00000:oi^j
0005o`000?o6`@3oa/40o`000?oAX`001?l00005ool00003o`000?l05c3o01L`00So01L`00?o0000
o`0;9Ol02bD0@?l02bD00ol0003o008Io`026@0Ho`026@Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`02oooooa[o008I00?o0000o`0;9Ol02bD0@?l02bD2o`0000_o01L`0_l00004ool0
00Co000000CodJ<0o`000?o6`@3oa/400_l00006oi^j00;o00000_o6`@000ol0003odJ<0o`000003
o`0000Coo`000_l0000;o`0G<0;o0000@_l02bD00ol0003o008Io`026@0Go`026@Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`02oooooaSo008I0_l00013o`0;9@03o`000?l05c3o01L`
00[o01L`0_l00005ool000?o00000_oAX`000ol0003oa/40olK10008o`0000;oa/4000?o0000om6S
0?oAX`000ol00005ool000;o00003?l05c000ol0003o00/Uo`0;9@11o`0;9@?o00005_l00QT5oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolGo`026@03o`000?l02bGo00/U04?o
00/U00?o0000o`0G<?l05c002_l05c02o`0000Goo`001?l000000ooAX`3o0000o`00000:olK100;o
000000?odJ<0o`000?l000000_l00005ool000;o00003?l05c02o`0004Co00/U00?o0000o`026Ol0
0QT05?l00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolFo`026@03o`00
0?l02bGo00/U04?o00/U00?o0000o`0G<?l05c003Ol05c000ol0003oo`00ool00002ool000?o0000
00GogH40o`000?oAX`3odJ<0o`000008olK100;o000000?odJ<0o`000?oMP@000ol00004ool000;o
00003_l05c000ol0003o00/Uo`0;9@13o`0;9@03o`000?l00QWo008I01?o008I1Oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo5Ol00QT00ol0003o00/Uo`0;9@13o`0;9@03o`00
0?l05c3o01L`00ko01L`00?o0000ool00?oo00000ooo0003o`000004omf10?l0003odJ<0om6S00;o
00001?o6`@02o`0000;odJ<000?o0000omf10?l000000_l00005ool00003o`000?l05c3o01L`00ko
01L`00?o0000o`0;9Ol02bD0@ol02bD00ol0003o008Io`026@0Bo`026@Gooooo0Ol00001ooooo`00
6oooool2o`0000?ooooo5?l00QT00ol0003o00/Uo`0;9@14o`0;9@03o`000?l05c3o01L`00oo01L`
00?o0000ool00?oo00000ooo0003o`000003omf10?l0003odJ<000;odJ<01?l00003om6S0003o`00
0?oMP@3o000000;o00001Ooo00000ol0003o01L`o`0G<00@o`0G<003o`000?l02bGo00/U04?o00/U
0_l0000Bo`026@Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`02oooooa7o008I0ol0
0016o`0;9@03o`000?l05c3o01L`013o01L`00?o0000ool00?oo00000ooo0002o`000004onQJ0?l0
003ogH40o`0000SodJ<000Co0000omf10?l0003oj5X00_l00005ool00003o`000?l05c3o01L`013o
01L`00?o0000o`0;9Ol02bD0AOl02bD2o`00013o008I1Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo4Ol00QT00ol0003o00/Uo`0;9@16o`0;9@03o`000?l05c3o01L`013o01L`
00?o0000ool00?oo00001?oo0003o`0000;ogH4000?o0000om6S0?oAX`001?oAX`02o`000005omf1
0?l0003o0000oo@_0?l000001Ooo00000ol0003o01L`o`0G<00@o`0G<003o`000?l02bGo00/U04Ko
00/U00?o0000o`026Ol00QT03_l00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_ooool@o`026@03o`000?l02bGo00/U04Ko00/U00?o0000o`0G<?l05c004Ol05c000ol0003oo`00
ool00004ool00004o`000?od;`3o0000o`0000;ogH401_l00002omf100Co00001_oo00000ol0003o
01L`o`0G<00Ao`0G<003o`000?l02bGo00/U04Ko00/U00?o0000o`026Ol00QT03Ol00QT5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_ooool?o`026@03o`000?l02bGo00/U04Ko00/U
00?o0000o`0G<?l05c004ol05c02o`0000Goo`000_l000000ooXFP3o0000omf10007omf10004o`00
0?oXFP3o0000o`0000Koo`0000?o0000o`0G<?l05c004ol05c000ol0003o00/Uo`0;9@16o`0;9@;o
00003Ol00QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool=o`026@;o0000
BOl02bD00ol0003o01L`o`0G<00Co`0G<003o`000?oo003oo`0000Goo`000_l000000ooXFP3o0000
o`000004omf100;o000000?oj5X0o`000?l000001ooo00000ol0003o01L`o`0G<00Co`0G<003o`00
0?l02bGo00/U04So00/U00?o0000o`026Ol00QT02_l00QT5ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool00_ooool<o`026@03o`000?l02bGo00/U04Wo00/U00?o0000o`0G<?l05c004ol0
5c03o`0000Goo`0000?o0000oo@_0?l000000_oXFP04o`0000;oj5X000?o0000oo@_0?l000001_oo
0002o`0001Ko01L`00?o0000o`0;9Ol02bD0B?l02bD00ol0003o008Io`026@09o`026@Gooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`02ooooo`co008I00?o0000o`0;9Ol02bD0B?l02bD0
0ol0003o01L`o`0G<00Eo`0G<0;o00001_oo00000ol0003om2l0o`000006onQJ00?o00001_oo0002
o`0001Oo01L`00?o0000o`0;9Ol02bD0B?l02bD00ol0003o008Io`026@09o`026@Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`02ooooo`[o008I0_l0001:o`0;9@03o`000?l05c3o01L`
01Ko01L`0_l00007ool00004o`000?od;`3o0000o`0000;oj5X00_l000000ood;`3o0000ool00006
ool000;o00006?l05c000ol0003o00/Uo`0;9@18o`0;9@?o00002?l00QT5ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_ooool8o`026@;o0000C?l02bD00ol0003o01L`o`0G<00Fo`0G
<0;o00002?oo00000ol0003om2l0oo@_0002o`0000;om2l000?o0000ool00?oo00001_oo0002o`00
01Wo01L`00?o0000o`0;9Ol02bD0B_l02bD00ol0003o008Io`026@05o`026@Gooooo0Ol00001oooo
o`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo
00;ooooo1ol00QT00ol0003o00/Uo`0;9@1;o`0;9@03o`000?l05c3o01L`01Ko01L`00Co0000o`0Y
??l0:Cco00001ooo0002o`0000Com2l00_l00007ool000;o000000?o02Tlo`000?l05c005ol05c00
0ol0003o00/Uo`0;9@1;o`0;9@03o`000?l00QWo008I00Co008I1Oooool1o`00007ooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`02ooooo`Oo008I00?o0000o`0;9Ol02bD0Bol02bD00ol0003o01L`o`0G<00Fo`0G<004o`000?l0
:Cco02Tlo`0000Woo`001?l00009ool00004o`000?l0:Cco02Tlo`0001So01L`00?o0000o`0;9Ol0
2bD0Bol02bD00ol0003o008Io`026@04o`026@Gooooo0Ol00001ooooo`001oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`Ko008I00?o0000o`0;9Ol0
2bD0Bol02bD00ol0003o01L`o`0G<00Fo`0G<005o`000?l0:Cco02Tlo`0Y??l000005_oo00001Ol0
003o02Tlo`0Y??l0:Cco000001So01L`00?o0000o`0;9Ol02bD0Bol02bD00ol0003o008Io`026@03
o`026@Cooooo0_l00001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool5o`026@03o`000?l02bGo00/U04_o00/U00?o0000
o`0G<?l05c005_l05c000ol0003o02Tlo`0Y?003o`0Y?003o`000?oo003oo`0001;oo`0000?o0000
o`0Y??l0:C`00ol0:C`00ol0003o01L`o`0G<00Fo`0G<003o`000?l02bGo00/U04_o00/U0_l00003
o`026@Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`02ooooo`;o008I0ol0001>o`0;9@03o`000?l0
5c3o01L`01Ko01L`00?o0000o`0Y??l0:C`00ol0:C`00ol0003oo`00ool0000Bool00003o`000?l0
:Cco02Tl00?o02Tl00?o0000o`0G<?l05c005_l05c000ol0003o00/Uo`0;9@1=o`0;9@;o000000?o
008Iooooooooool00oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o008Io`000?l02bD0
Col02bD2o`0001Oo01L`0_l00005o`0Y?003o`000?oo003oo`0001;oo`0000?o0000o`0Y??l0:C`0
0ol0:C`2o`0001So01L`00?o0000o`0;9Ol02bD0C_l02bD00ol0003oooooooooo`03ooooo`7o0000
0Oooool000Sooooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`03o`026Ol0
003o00/U04oo00/U00?o0000o`0G<?l05c005_l05c000ol0003o02Tlo`0Y?004o`0Y?0;o00004_oo
0002o`0000Ko02Tl00?o0000o`0G<?l05c005_l05c000ol0003o00/Uo`0;9@1>o`0;9@03o`000?oo
oooooooo00?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`03o`000?l02bGo
00/U04ko00/U00?o0000o`0G<?l05c005_l05c02o`0000Oo02Tl0_l0000Aool00003o`000?l0:Cco
02Tl00Go02Tl0_l0000Ho`0G<003o`000?l02bGo00/U04ko00/U00?o0000ooooooooool00_ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;oooooDOl02bD00ol0003o01L`o`0G<00Fo`0G
<003o`000?l0:Cco02Tl00Ko02Tl00?o0000ool00?oo00004?oo00000ol0003o02Tlo`0Y?006o`0Y
?003o`000?l05c3o01L`01Ko01L`00?o0000o`0;9Ol02bD0C_l02bD5ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_oooom@o`0;9@03o`000?l05c3o01L`01Ko01L`00?o0000o`0Y??l0
:C`01ol0:C`00ol0003oo`00ool0000@ool00003o`000?l0:Cco02Tl00Oo02Tl00?o0000o`0G<?l0
5c005_l05c000ol0003o00/Uo`0;9@1=o`0;9@Gooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`02ooooodoo00/U00?o0000o`0G<?l05c005ol05c000ol0003o02Tlo`0Y?008o`0Y?0;o0000
3_oo0002o`0000[o02Tl00?o0000o`0G<?l05c005ol05c000ol0003o00/Uo`0;9@1<o`0;9@Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooodoo00/U00?o0000o`0G<?l05c005ol0
5c000ol0003o02Tlo`0Y?007o`0Y?0?o00003_oo0003o`0000Wo02Tl00?o0000o`0G<?l05c005ol0
5c000ol0003o00/Uo`0;9@1<o`0;9@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02
ooooodoo00/U00?o0000o`0G<?l05c005_l05c000ol0003o02Tlo`0Y?008o`0Y?0?o00003_oo0003
o`0000[o02Tl00?o0000o`0G<?l05c005_l05c000ol0003o00/Uo`0;9@1<o`0;9@Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`02ooooodko00/U00?o0000o`0G<?l05c005ol05c000ol0
003o02Tlo`0Y?007o`0Y?004o`000?l0?TOo0000o`0000koo`000_l000000ol0?TOo0000o`0Y?008
o`0Y?003o`000?l05c3o01L`01Oo01L`00?o0000o`0;9Ol02bD0Bol02bD5ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_oooom=o`0;9@;o00006?l05c000ol0003o02Tlo`0Y?008o`0Y
?005o`000?l0?TOo03i7o`0nAol000003?oo0002o`0000;o03i700?o0000o`0Y??l0:C`02?l0:C`0
0ol0003o01L`o`0G<00Go`0G<003o`000?l02bGo00/U04[o00/U1Oooool1o`00007ooooo000Koooo
o`;o00000ooooom=o`0;9@03o`000?l05c3o01L`01Oo01L`00?o0000o`0Y??l0:C`01ol0:C`00ol0
003o03i7o`0nA`02o`0nA`03o`000?oo003oo`0000[oo`0000?o0000o`0nAol0?TL00_l0?TL00ol0
003o02Tlo`0Y?008o`0Y?003o`000?l05c3o01L`01Ko01L`00?o0000o`0;9Ol02bD0B_l02bD4oooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool00_oooom=o`0;9@03o`000?l05c3o01L`01Oo
01L`00?o0000o`0Y??l0:C`01ol0:C`00ol0003o03i7o`0nA`02o`0nA`03o`000?oo003oo`0000[o
o`0000?o0000o`0nAol0?TL00_l0?TL00ol0003o02Tlo`0Y?008o`0Y?003o`000?l05c3o01L`01Ko
01L`00?o0000o`0;9Ol02bD0B_l02bD5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_oooom<o`0;9@03o`000?l05c3o01L`01Oo01L`00?o0000o`0Y??l0:C`02?l0:C`00ol0003o03i7
o`0nA`02o`0nA`03o`000?oo003oo`0000[oo`0000?o0000o`0nAol0?TL00_l0?TL2o`0000Wo02Tl
00?o0000o`0G<?l05c005ol05c000ol0003o00/Uo`0;9@19o`0;9@Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooodco00/U00?o0000o`0G<?l05c005_l05c000ol0003o02Tlo`0Y
?008o`0Y?003o`000?l0?TOo03i700?o03i70_l0000:ool000;o00001Ol0?TL00ol0003o02Tlo`0Y
?008o`0Y?003o`000?l05c3o01L`01Oo01L`00?o0000o`0;9Ol02bD0B?l02bD5ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_oooom;o`0;9@03o`000?l05c3o01L`01Oo01L`00?o0000
o`0Y??l0:C`02?l0:C`00ol0003o03i7o`0nA`02o`0nA`03o`000?l0Ddgo000000[oo`0000?o0000
o`1CCOl000001Ol0?TL00ol0003o02Tlo`0Y?007o`0Y?003o`000?l05c3o01L`01Oo01L`00?o0000
o`0;9Ol02bD0B?l02bD5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom:o`0;
9@03o`000?l05c3o01L`01Oo01L`00?o0000o`0Y??l0:C`02?l0:C`00ol0003o03i7o`0nA`03o`0n
A`03o`000?l0Ddgo000000[oo`0000?o0000o`1CCOl000001Ol0?TL00ol0003o02Tlo`0Y?008o`0Y
?003o`000?l05c3o01L`01Oo01L`00?o0000o`0;9Ol02bD0Aol02bD5ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_oooom:o`0;9@03o`000?l05c3o01L`01Oo01L`00?o0000o`0Y??l0
:C`02?l0:C`00ol0003o03i7o`0nA`02o`0nA`04o`000?l0Ddgo05==o`0000[oo`0000Co0000o`1C
COl0Ddgo00001?l0?TL00ol0003o02Tlo`0Y?008o`0Y?003o`000?l05c3o01L`01Oo01L`00?o0000
o`0;9Ol02bD0Aol02bD5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom:o`0;
9@03o`000?l05c3o01L`01Oo01L`00?o0000o`0Y??l0:C`02?l0:C`00ol0003o03i7o`0nA`02o`0n
A`04o`000?l0Ddgo05==o`1CC@;o00001ooo00001Ol0003o05==o`1CCOl0Ddgo000000Go03i700?o
0000o`0Y??l0:C`01ol0:C`00ol0003o01L`o`0G<00Go`0G<003o`000?l02bGo00/U04Oo00/U1Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;oooooBOl02bD00ol0003o01L`o`0G<00G
o`0G<003o`000?l0:Cco02Tl00So02Tl00?o0000o`0nAol0?TL00ol0?TL00ol0003o05==o`1CC@02
o`0000Soo`000_l00002o`1CC@03o`000?l0?TOo03i700?o03i700?o0000o`0Y??l0:C`02?l0:C`0
0ol0003o01L`o`0G<00Go`0G<003o`000?l02bGo00/U04Ko00/U1Oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00;oooooB?l02bD2o`0001Wo01L`00?o0000o`0Y??l0:C`02?l0:C`00ol0
003o03i7o`0nA`02o`0nA`04o`000?l0Ddgo05==o`1CC@;o00002?oo0002o`0000?o05==00?o0000
o`0nAol0?TL00ol0?TL00ol0003o02Tlo`0Y?007o`0Y?003o`000?l05c3o01L`01So01L`00?o0000
o`0;9Ol02bD0AOl02bD5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom8o`0;
9@03o`000?l05c3o01L`01So01L`00?o0000o`0Y??l0:C`02?l0:C`00ol0003o03i7o`0nA`02o`0n
A`04o`000?l0Ddgo05==o`1CC@;o00002?oo0002o`0000?o05==00?o0000o`0nAol0?TL00ol0?TL0
0ol0003o02Tlo`0Y?007o`0Y?003o`000?l05c3o01L`01So01L`00?o0000o`0;9Ol02bD0AOl02bD5
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom8o`0;9@03o`000?l05c3o01L`
01Oo01L`00?o0000o`0Y??l0:C`02?l0:C`00ol0003o03i7o`0nA`03o`0nA`06o`000?l0Ddgo05==
o`000?l0GTGo00002?oo00000ol0003o05i5o`000002o`1CC@03o`000?l0?TOo03i700?o03i700?o
0000o`0Y??l0:C`02?l0:C`00ol0003o01L`o`0G<00Go`0G<003o`000?l02bGo00/U04Go00/U1Ooo
ool1o`00007ooooo000Kooooo`;o00000ooooom7o`0;9@03o`000?l05c3o01L`01So01L`00?o0000
o`0Y??l0:C`02?l0:C`00ol0003o03i7o`0nA`02o`0nA`06o`000?l0Ddgo05==o`1CCOl0003o05i5
0ol00004ool000?o000000?o05i5o`000?l0Ddd00_l0Ddd00ol0003o03i7o`0nA`02o`0nA`03o`00
0?l0:Cco02Tl00So02Tl0_l0000Io`0G<003o`000?l02bGo00/U04Co00/U1?ooool2o`00007ooooo
000Kooooo`03o`000?oooooooooo00;oooooAol02bD00ol0003o01L`o`0G<00Go`0G<003o`000?l0
:Cco02Tl00So02Tl00?o0000o`0nAol0?TL00ol0?TL01?l0003o05==o`1CCOl00002o`1NA@?o0000
1?oo0002o`000004o`1Z>?l0003o05i5o`0000;o05==00?o0000o`0nAol0?TL00ol0?TL00ol0003o
02Tlo`0Y?008o`0Y?003o`000?l05c3o01L`01So01L`00?o0000o`0;9Ol02bD0@ol02bD5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_oooom6o`0;9@03o`000?l05c3o01L`01So01L`
00?o0000o`0Y??l0:C`02?l0:C`00ol0003o03i7o`0nA`03o`0nA`07o`000?l0Ddgo05==o`000?l0
GTGo0000o`1Z>002o`0000Goo`0000Go0000o`1Z>?l0003o05i5o`000003o`1CC@03o`000?l0?TOo
03i700;o03i700?o0000o`0Y??l0:C`02?l0:C`00ol0003o01L`o`0G<00Ho`0G<003o`000?l02bGo
00/U04?o00/U1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;oooooA_l02bD00ol0
003o01L`o`0G<00Go`0G<003o`000?l0:Cco02Tl00Wo02Tl00?o0000o`0nAol0?TL00ol0?TL01ol0
003o05==o`1CCOl0003o05i5o`000?l0JSP00_l00005ool00005o`000?l0JSSo0000o`1NAOl00000
0ol0Ddd00ol0003o03i7o`0nA`02o`0nA`03o`000?l0:Cco02Tl00Wo02Tl00?o0000o`0G<?l05c00
5ol05c000ol0003o00/Uo`0;9@13o`0;9@Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`02ooooodGo00/U00?o0000o`0G<?l05c006?l05c000ol0003o02Tlo`0Y?008o`0Y?003o`000?l0
?TOo03i700?o03i700?o0000o`1CCOl0Ddd00_l000000ol0GTGo0000o`000002o`0000Coo`001?l0
0002o`1NA@04o`000?l0Ddgo05==o`0000Go03i700?o0000o`0Y??l0:C`02?l0:C`00ol0003o01L`
o`0G<00Ho`0G<003o`000?l02bGo00/U04;o00/U1Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;oooooAOl02bD00ol0003o01L`o`0G<00Ho`0G<003o`000?l0:Cco02Tl00So02Tl00?o
0000o`0nAol0?TL00ol0?TL01ol0003o05==o`1CCOl0003o05i5o`000?l0JSP00_l000001?l0PA;o
0000ool00?oo0004o`000004o`1Z>?l0003o05i5o`0000;o05==00?o0000o`0nAol0?TL00ol0?TL0
0ol0003o02Tlo`0Y?009o`0Y?003o`000?l05c3o01L`01Oo01L`00?o0000o`0;9Ol02bD0@_l02bD5
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom4o`0;9@03o`000?l05c3o01L`
01So01L`00?o0000o`0Y??l0:C`02?l0:C`00ol0003o03i7o`0nA`03o`0nA`08o`000?l0Ddgo05==
o`1CCOl0003o05i5o`000?l0JSP4o`0000;oo`001?l000001?l0JSSo0000o`1NAOl00003o`1CC@03
o`000?l0?TOo03i700?o03i700?o0000o`0Y??l0:C`02?l0:C`00ol0003o01L`o`0G<00Ho`0G<003
o`000?l02bGo00/U047o00/U1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
A?l02bD00ol0003o01L`o`0G<00Ho`0G<003o`000?l0:Cco02Tl00So02Tl00?o0000o`0nAol0?TL0
0ol0?TL01?l0003o05==o`1CCOl00002o`1NA@Co000000Co1h`0o`000?oo003oo`001_l00002o`1N
A@04o`000?l0Ddgo05==o`0000Go03i700?o0000o`0Y??l0:C`02?l0:C`00ol0003o01L`o`0G<00I
o`0G<003o`000?l02bGo00/U043o00/U1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo@ol02bD00ol0003o01L`o`0G<00Io`0G<003o`000?l0:Cco02Tl00So02Tl00?o0000o`0n
Aol0?TL00ol0?TL01?l0003o05==o`1CCOl00002o`1NA@Co000000Co1h`0o`000?oo003oo`001_l0
0002o`1NA@04o`000?l0Ddgo05==o`0000Go03i700?o0000o`0Y??l0:C`02?l0:C`00ol0003o01L`
o`0G<00Io`0G<003o`000?l02bGo00/U043o00/U1Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo@ol02bD00ol0003o01L`o`0G<00Ho`0G<003o`000?l0:Cco02Tl00Wo02Tl00?o
0000o`0nAol0?TL00_l0?TL02?l0003o05==o`1CCOl0Ddgo0000o`1NAOl0003o06Xh1Ol00002ool0
00Go000000Co06Xho`000?l0GTGo00000ol0Ddd00ol0003o03i7o`0nA`03o`0nA`03o`000?l0:Cco
02Tl00So02Tl00?o0000o`0G<?l05c006?l05c000ol0003o00/Uo`0;9@10o`0;9@Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`02oooood;o00/U00?o0000o`0G<?l05c006Ol05c000ol0
003o02Tlo`0Y?008o`0Y?003o`000?l0?TOo03i700?o03i700So0000o`1CCOl0Ddgo05==o`000?l0
GTGo0000o`1Z>0?o000000Ko9IP0o`000?oo003oo`00o`000?lUV003o`000004o`1Z>?l0003o05i5
o`0000?o05==00?o0000o`0nAol0?TL00ol0?TL00ol0003o02Tlo`0Y?008o`0Y?003o`000?l05c3o
01L`01Wo01L`00?o0000o`0;9Ol02bD0?ol02bD5ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool00_oooom2o`0;9@03o`000?l05c3o01L`01So01L`00?o0000o`0Y??l0:C`02Ol0:C`00ol0
003o03i7o`0nA`03o`0nA`04o`000?l0Ddgo05==o`0000;o05i50_l000000ol0MBOo0000o`000002
o`0000;oo`001ol00002o`1NA@04o`000?l0Ddgo05==o`0000Go03i700?o0000o`0Y??l0:C`02Ol0
:C`00ol0003o01L`o`0G<00Ho`0G<003o`000?l02bGo00/U03oo00/U1Oooool1o`00007ooooo000K
ooooo`;o00000ooooom1o`0;9@03o`000?l05c3o01L`01Wo01L`00?o0000o`0Y??l0:C`02?l0:C`0
0ol0003o03i7o`0nA`03o`0nA`08o`000?l0Ddgo05==o`1CCOl0003o05i5o`000?l0JSP6o`0000;o
o`001_l000001?l0JSSo0000o`1NAOl00003o`1CC@03o`000?l0?TOo03i700?o03i700?o0000o`0Y
??l0:C`02?l0:C`00ol0003o01L`o`0G<00Io`0G<003o`000?l02bGo00/U03ko00/U1?ooool2o`00
007ooooo000Kooooo`03o`000?oooooooooo00;ooooo@Ol02bD00ol0003o01L`o`0G<00Io`0G<003
o`000?l0:Cco02Tl00So02Tl00?o0000o`0nAol0?TL00ol0?TL02?l0003o05==o`1CCOl0Ddgo0000
o`1NAOl0003o06Xh1_l00002ool000Ko000000Co06Xho`000?l0GTGo00000ol0Ddd00ol0003o03i7
o`0nA`03o`0nA`03o`000?l0:Cco02Tl00Wo02Tl00?o0000o`0G<?l05c006?l05c000ol0003o00/U
o`0;9@0no`0;9@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooood7o00/U00?o
0000o`0G<?l05c006?l05c000ol0003o02Tlo`0Y?009o`0Y?003o`000?l0?TOo03i700?o03i700So
0000o`1CCOl0Ddgo05==o`000?l0GTGo0000o`1Z>0Ko00000_oo0006o`000005o`1Z>?l0003o05i5
o`1NAOl000000_l0Ddd00ol0003o03i7o`0nA`03o`0nA`03o`000?l0:Cco02Tl00Wo02Tl00?o0000
o`0G<?l05c006?l05c000ol0003o00/Uo`0;9@0no`0;9@Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`02oooood3o00/U00?o0000o`0G<?l05c006Ol05c000ol0003o02Tlo`0Y?008o`0Y
?003o`000?l0?TOo03i700Co03i700Co0000o`1CCOl0Ddgo00000_l0GTD2o`000003o`1e9ol0003o
000000?o00000_oo0005o`000003o`1e9ol0003o000000;o05i500Go0000o`1CCOl0Ddgo05==o`00
0005o`0nA`03o`000?l0:Cco02Tl00So02Tl00?o0000o`0G<?l05c006Ol05c000ol0003o00/Uo`0;
9@0mo`0;9@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooood3o00/U00?o0000
o`0G<?l05c006?l05c000ol0003o02Tlo`0Y?009o`0Y?003o`000?l0?TOo03i700?o03i700So0000
o`1CCOl0Ddgo05==o`000?l0GTGo0000o`1Z>0Oo00000_oo0007o`000004o`1Z>?l0003o05i5o`00
00?o05==00?o0000o`0nAol0?TL00ol0?TL00ol0003o02Tlo`0Y?009o`0Y?003o`000?l05c3o01L`
01So01L`00?o0000o`0;9Ol02bD0?Ol02bD5ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00_ooooloo`0;9@03o`000?l05c3o01L`01Wo01L`00?o0000o`0Y??l0:C`02Ol0:C`00ol0003o
03i7o`0nA`03o`0nA`08o`000?l0Ddgo05==o`1CCOl0003o05i5o`000?l0JSP7o`0000;oo`001ol0
00001?l0JSSo0000o`1NAOl00003o`1CC@03o`000?l0?TOo03i700?o03i70_l0000:o`0Y?003o`00
0?l05c3o01L`01Wo01L`00?o0000o`0;9Ol02bD0??l02bD5ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool00_ooooloo`0;9@03o`000?l05c3o01L`01Wo01L`00?o0000o`0Y??l0:C`02Ol0
:C`00ol0003o03i7o`0nA`03o`0nA`08o`000?l0Ddgo05==o`1CCOl0003o05i5o`000?l0JSP7o`00
00;oo`001ol000001?l0JSSo0000o`1NAOl00003o`1CC@03o`000?l0?TOo03i700Co03i700?o0000
o`0Y??l0:C`02?l0:C`00ol0003o01L`o`0G<00Io`0G<003o`000?l02bGo00/U03co00/U1Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo?_l02bD2o`0001[o01L`00?o0000o`0Y
??l0:C`02Ol0:C`00ol0003o03i7o`0nA`04o`0nA`04o`000?l0Ddgo05==o`0000;o05i52Ol00003
ool000Go000000?o07DWo`000?l000000_l0GTD01Ol0003o05==o`1CCOl0Ddgo000000Go03i700?o
0000o`0Y??l0:C`02Ol0:C`00ol0003o01L`o`0G<00Io`0G<003o`000?l02bGo00/U03_o00/U1Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo?_l02bD00ol0003o01L`o`0G<00I
o`0G<003o`000?l0:Cco02Tl00Wo02Tl00?o0000o`0nAol0?TL00ol0?TL01Ol0003o05==o`1CCOl0
Ddgo000000;o05i50_l000000ol0MBOo0000o`000003o`0000Coo`001ol000001?l0JSSo0000o`1N
AOl00003o`1CC@03o`000?l0?TOo03i700?o03i700?o0000o`0Y??l0:C`02Ol0:C`00ol0003o01L`
o`0G<00Io`0G<003o`000?l02bGo00/U03_o00/U1Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo?_l02bD00ol0003o01L`o`0G<00Io`0G<003o`000?l0:Cco02Tl00Wo02Tl00?o
0000o`0nAol0?TL00ol0?TL02?l0003o05==o`1CCOl0Ddgo0000o`1NAOl0003o06Xh1ol00004ool0
00Oo000000Co06Xho`000?l0GTGo00000ol0Ddd00ol0003o03i7o`0nA`04o`0nA`03o`000?l0:Cco
02Tl00Wo02Tl00?o0000o`0G<?l05c006Ol05c000ol0003o00/Uo`0;9@0jo`0;9@Gooooo0Ol00001
ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000oooo
ooooool00_oooolmo`0;9@03o`000?l05c3o01L`01Wo01L`00?o0000o`0Y??l0:C`02Ol0:C`00ol0
003o03i7o`0nA`04o`0nA`04o`000?l0Ddgo05==o`0000;o05i500?o0000o`1Z>?l000001_l00004
ool000Oo000000Go06Xho`000?l0GTGo05i5o`000002o`1CC@;o00001Ol0?TL00ol0003o02Tlo`0Y
?009o`0Y?003o`000?l05c3o01L`01Wo01L`00?o0000o`0;9Ol02bD0>_l02bD5ooooo`7o00000Ooo
ool000Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo?Ol02bD00ol0003o01L`o`0G<00Io`0G<003o`000?l0:Cco02Tl00Wo02Tl00?o
0000o`0nAol0?TL01?l0?TL01?l0003o05==o`1CCOl00002o`1NA@03o`000?l0JSSo000000Ko0000
1?oo0007o`000005o`1Z>?l0003o05i5o`1NAOl000000ol0Ddd00ol0003o03i7o`0nA`03o`0nA`03
o`000?l0:Cco02Tl00Wo02Tl00?o0000o`0G<?l05c006Ol05c000ol0003o00/Uo`0;9@0jo`0;9@Go
oooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`Go00001?ooool00ol0003o
ooooooooo`02ooooocco00/U00?o0000o`0G<?l05c006_l05c000ol0003o02Tlo`0Y?009o`0Y?003
o`000?l0?TOo03i700?o03i700Go0000o`1CCOl0Ddgo05==o`000002o`1NA@03o`000?l0JSSo0000
00Ko00001?oo0006o`000003o`1e9ol0003o000000;o05i500Go0000o`1CCOl0Ddgo05==o`000005
o`0nA`03o`000?l0:Cco02Tl00Wo02Tl00?o0000o`0G<?l05c006_l05c000ol0003o00/Uo`0;9@0i
o`0;9@Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Gooooo0_l00003ooooocco00/U00?o0000o`0G<?l05c006Ol05c000ol0003o02Tlo`0Y
?009o`0Y?003o`000?l0?TOo03i700Co03i700Go0000o`1CCOl0Ddgo05==o`000002o`1NA@;o0000
00?o07DWo`000?l000001?l00004ool000Ko000000Ko07DWo`000?l0JSSo0000o`1NAOl00003o`1C
C@03o`000?l0?TOo03i700Co03i700?o0000o`0Y??l0:C`02Ol0:C`00ol0003o01L`o`0G<00Io`0G
<003o`000?l02bGo00/U03Wo00/U1?ooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02oooooc_o00/U00?o0000o`0G
<?l05c006_l05c000ol0003o02Tlo`0Y?009o`0Y?003o`000?l0?TOo03i700Co03i700[o0000o`1C
COl0Ddgo05==o`000?l0GTGo0000o`1Z>?l0003o07DW1_l00004ool000So000000Go06Xho`000?l0
GTGo05i5o`000002o`1CC@03o`000?l0?TOo03i700Co03i700?o0000o`0Y??l0:C`02Ol0:C`00ol0
003o01L`o`0G<00Jo`0G<003o`000?l02bGo00/U03So00/U1Oooool1o`00007ooooo0007ooooo`04
o`000?ooooooooooo`0000Wooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo>ol02bD00ol0
003o01L`o`0G<00Jo`0G<003o`000?l0:Cco02Tl00Wo02Tl00?o0000o`0nAol0?TL00ol0?TL01Ol0
003o05==o`1CCOl0Ddgo000000;o05i500?o0000o`1Z>?l000001ol00004ool000So000000Go06Xh
o`000?l0GTGo05i5o`000003o`1CC@03o`000?l0?TOo03i700?o03i700?o0000o`0Y??l0:C`02_l0
:C`00ol0003o01L`o`0G<00Io`0G<003o`000?l02bGo00/U03So00/U1Oooool1o`00007ooooo0008
ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo>ol02bD0
0ol0003o01L`o`0G<00Jo`0G<003o`000?l0:Cco02Tl00Wo02Tl00?o0000o`0nAol0?TL00ol0?TL0
1Ol0003o05==o`1CCOl0Ddgo000000;o05i500?o0000o`1Z>?l000001ol00004ool000So000000Go
06Xho`000?l0GTGo05i5o`000003o`1CC@03o`000?l0?TOo03i700?o03i700?o0000o`0Y??l0:C`0
2_l0:C`00ol0003o01L`o`0G<00Io`0G<003o`000?l02bGo00/U03So00/U1Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo>_l02bD00ol0003o01L`o`0G<00Jo`0G<003o`000?l0
:Cco02Tl00Wo02Tl00?o0000o`0nAol0?TL01?l0?TL01Ol0003o05==o`1CCOl0Ddgo000000;o05i5
00?o0000o`1Z>?l000001ol00004ool000So000000Go06Xho`000?l0GTGo05i5o`000003o`1CC@03
o`000?l0?TOo03i700Co03i700?o0000o`0Y??l0:C`02Ol0:C`00ol0003o01L`o`0G<00Jo`0G<003
o`000?l02bGo00/U03Oo00/U1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
>_l02bD00ol0003o01L`o`0G<00Jo`0G<003o`000?l0:Cco02Tl00Wo02Tl00?o0000o`0nAol0?TL0
1?l0?TL01Ol0003o05==o`1CCOl0Ddgo000000;o05i500?o0000o`1Z>?l000001ol00004ool000Oo
000000?o07DWo`000?l000000_l0GTD01Ol0003o05==o`1CCOl0Ddgo000000Ko03i700?o0000o`0Y
??l0:C`02Ol0:C`00ol0003o01L`o`0G<00Jo`0G<003o`000?l02bGo00/U03Oo00/U1Oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00;ooooo>Ol02bD00ol0003o01L`o`0G<00Jo`0G<003
o`000?l0:Cco02Tl00[o02Tl00?o0000o`0nAol0?TL01?l0?TL02_l0003o05==o`1CCOl0Ddgo0000
o`1NAOl0003o06Xho`000?l0MBL7o`0000Coo`001ol000001_l0MBOo0000o`1Z>?l0003o05i5o`00
00Co05==00?o0000o`0nAol0?TL00ol0?TL00ol0003o02Tlo`0Y?00:o`0Y?003o`000?l05c3o01L`
01[o01L`00?o0000o`0;9Ol02bD0=_l02bD5ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00_oooolio`0;9@03o`000?l05c3o01L`01[o01L`00?o0000o`0Y??l0:C`02_l0:C`00ol0003o
03i7o`0nA`03o`0nA`05o`000?l0Ddgo05==o`1CCOl000000_l0GTD01?l0003o06Xho`000?l0MBL7
o`0000Coo`001ol000001?l0MBOo0000o`1Z>?l00002o`1NA@05o`000?l0Ddgo05==o`1CCOl00000
1_l0?TL00ol0003o02Tlo`0Y?009o`0Y?003o`000?l05c3o01L`01[o01L`00?o0000o`0;9Ol02bD0
=_l02bD5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolio`0;9@03o`000?l0
5c3o01L`01[o01L`00?o0000o`0Y??l0:C`02_l0:C`00ol0003o03i7o`0nA`03o`0nA`05o`000?l0
Ddgo05==o`1CCOl000000_l0GTD01?l0003o06Xho`000?l0MBL7o`0000Coo`001ol000001?l0MBOo
0000o`1Z>?l00002o`1NA@05o`000?l0Ddgo05==o`1CCOl000001_l0?TL00ol0003o02Tlo`0Y?009
o`0Y?003o`000?l05c3o01L`01[o01L`00?o0000o`0;9Ol02bD0=_l02bD5ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_oooolho`0;9@03o`000?l05c3o01L`01_o01L`00?o0000o`0Y
??l0:C`02Ol0:C`00ol0003o03i7o`0nA`04o`0nA`05o`000?l0Ddgo05==o`1CCOl000000_l0GTD0
1?l0003o06Xho`000?l0MBL7o`0000Coo`001ol000001?l0MBOo0000o`1Z>?l00002o`1NA@05o`00
0?l0Ddgo05==o`1CCOl000001_l0?TL00ol0003o02Tlo`0Y?00:o`0Y?003o`000?l05c3o01L`01[o
01L`00?o0000o`0;9Ol02bD0=Ol02bD5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_oooolho`0;9@03o`000?l05c3o01L`01[o01L`00?o0000o`0Y??l0:C`02_l0:C`00ol0003o03i7
o`0nA`04o`0nA`05o`000?l0Ddgo05==o`1CCOl000000_l0GTD01?l0003o06Xho`000?l0MBL7o`00
00Coo`001_l000001Ol0PA;o0000o`000?l0JSSo000000;o05i500Go0000o`1CCOl0Ddgo05==o`00
0006o`0nA`03o`000?l0:Cco02Tl00[o02Tl00?o0000o`0G<?l05c006_l05c000ol0003o00/Uo`0;
9@0eo`0;9@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooocOo00/U00?o0000
o`0G<?l05c006ol05c000ol0003o02Tlo`0Y?00:o`0Y?003o`000?l0?TOo03i700Co03i700Go0000
o`1CCOl0Ddgo05==o`000002o`1NA@05o`000?l0JSSo0000o`000?l0PA801_l00004ool000Ko0000
00Go084Bo`000?l0003o06Xho`000002o`1NA@03o`000?l0Ddgo05==00;o05==00?o0000o`0nAol0
?TL00ol0?TL2o`0000_o02Tl00?o0000o`0G<?l05c006ol05c000ol0003o00/Uo`0;9@0do`0;9@Go
oooo0Ol00001ooooo`006oooool2o`0000?ooooo=ol02bD00ol0003o01L`o`0G<00Ko`0G<003o`00
0?l0:Cco02Tl00Wo02Tl00?o0000o`0nAol0?TL01?l0?TL00ol0003o05==o`1CC@02o`1CC@05o`00
0?l0GTGo05i5o`000?l0JSP00_l000000ol0PA;o0000o`000005o`0000;oo`001_l000001?l7S03o
0000o`000?l00002o`1Z>003o`000?l0GTGo000000Co05==00?o0000o`0nAol0?TL01?l0?TL00ol0
003o02Tlo`0Y?00:o`0Y?003o`000?l05c3o01L`01[o01L`00?o0000o`0;9Ol02bD0=?l02bD4oooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool00_oooolgo`0;9@03o`000?l05c3o01L`01_o
01L`00?o0000o`0Y??l0:C`02Ol0:C`00ol0003o03i7o`0nA`04o`0nA`03o`000?l0Ddgo05==00;o
05==00Go0000o`1NAOl0GTGo0000o`1Z>002o`000003o`214_l0003o000000Go00000_oo0006o`00
0004o`N<0?l0003o0000o`0000;o06Xh00?o0000o`1NAOl000001?l0Ddd00ol0003o03i7o`0nA`04
o`0nA`03o`000?l0:Cco02Tl00[o02Tl00?o0000o`0G<?l05c006_l05c000ol0003o00/Uo`0;9@0d
o`0;9@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooocOo00/U00?o0000o`0G
<?l05c006_l05c000ol0003o02Tlo`0Y?00:o`0Y?003o`000?l0?TOo03i700Co03i700?o0000o`1C
COl0Ddd00_l0Ddd00ol0003o05i5o`000002o`1Z>0;o000000?o084Bo`000?l000001Ol00002ool0
00Ko000000Co1h`0o`000?l0003o00000_l0JSP01?l0003o05i5o`1NAOl00003o`1CC@03o`000?l0
?TOo03i700Co03i700?o0000o`0Y??l0:C`02_l0:C`00ol0003o01L`o`0G<00Ko`0G<003o`000?l0
2bGo00/U03?o00/U1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo=_l02bD0
0ol0003o01L`o`0G<00Ko`0G<003o`000?l0:Cco02Tl00[o02Tl00?o0000o`0nAol0?TL01?l0?TL0
1Ol0003o05==o`1CCOl0Ddgo000000;o05i500?o0000o`1Z>?l0JSP00_l000000ol0PA;o0000o`00
000@o`000004o`1e9ol0003o06Xho`0000;o05i500Go0000o`1CCOl0Ddgo05==o`000006o`0nA`03
o`000?l0:Cco02Tl00[o02Tl00?o0000o`0G<?l05c006ol05c000ol0003o00/Uo`0;9@0co`0;9@Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooocKo00/U00?o0000o`0G<?l05c00
6ol05c000ol0003o02Tlo`0Y?00:o`0Y?003o`000?l0?TOo03i700Co03i700Go0000o`1CCOl0Ddgo
05==o`000002o`1NA@03o`000?l0JSSo06Xh00;o000000?o084Bo`000?l000003Ol000001ol7S03o
0000o`000?l0MBOo0000o`1Z>?l000000_l0GTD01Ol0003o05==o`1CCOl0Ddgo000000Oo03i700?o
0000o`0Y??l0:C`02_l0:C`00ol0003o01L`o`0G<00Jo`0G<003o`000?l02bGo00/U03?o00/U1Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo=Ol02bD00ol0003o01L`o`0G<00K
o`0G<003o`000?l0:Cco02Tl00[o02Tl00?o0000o`0nAol0?TL01Ol0?TL01Ol0003o05==o`1CCOl0
Ddgo000000;o05i500Ko0000o`1Z>?l0003o07DWo`000?l0PA8?o`000007o`N<0?l0003o0000o`1e
9ol0003o06Xho`000002o`1NA@03o`000?l0Ddgo05==00;o05==00?o0000o`0nAol0?TL01?l0?TL0
0ol0003o02Tlo`0Y?00:o`0Y?003o`000?l05c3o01L`01_o01L`00?o0000o`0;9Ol02bD0<_l02bD5
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooooleo`0;9@03o`000?l05c3o01L`
01_o01L`00?o0000o`0Y??l0:C`02_l0:C`00ol0003o03i7o`0nA`05o`0nA`05o`000?l0Ddgo05==
o`1CCOl000000_l0GTD01_l0003o06Xho`000?l0MBOo0000o`214POo00000_oMP@06o`000007o`N<
0?l0003o0000o`1e9ol0003o06Xho`000002o`1NA@03o`000?l0Ddgo05==00;o05==00?o0000o`0n
Aol0?TL01?l0?TL00ol0003o02Tlo`0Y?00:o`0Y?003o`000?l05c3o01L`01_o01L`00?o0000o`0;
9Ol02bD0<_l02bD5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooooleo`0;9@03
o`000?l05c3o01L`01_o01L`00?o0000o`0Y??l0:C`02_l0:C`00ol0003o03i7o`0nA`04o`0nA`03
o`000?l0Ddgo05==00;o05==00Wo0000o`1NAOl0GTGo0000o`1Z>?l0003o07DWo`000?l0PA804?l0
00001_l0PA;o0000o`1e9ol0003o06Xho`0000;o05i500?o0000o`1CCOl0Ddd00_l0Ddd00ol0003o
03i7o`0nA`04o`0nA`03o`000?l0:Cco02Tl00[o02Tl00?o0000o`0G<?l05c006ol05c000ol0003o
00/Uo`0;9@0bo`0;9@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooocCo00/U
00?o0000o`0G<?l05c007?l05c000ol0003o02Tlo`0Y?00:o`0Y?003o`000?l0?TOo03i700Co03i7
00?o0000o`1CCOl0Ddd00_l0Ddd02Ol0003o05i5o`1NAOl0003o06Xho`000?l0MBOo0000o`214P0@
o`000006o`214_l0003o07DWo`000?l0JSSo00000_l0GTD00ol0003o05==o`1CC@02o`1CC@03o`00
0?l0?TOo03i700Co03i700?o0000o`0Y??l0:C`02ol0:C`00ol0003o01L`o`0G<00Ko`0G<003o`00
0?l02bGo00/U037o00/U1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo=?l0
2bD00ol0003o01L`o`0G<00Ko`0G<003o`000?l0:Cco02Tl00_o02Tl00?o0000o`0nAol0?TL01?l0
?TL00ol0003o05==o`1CC@02o`1CC@09o`000?l0GTGo05i5o`000?l0JSSo0000o`1e9ol0003o084B
00Go000000KoVkX0o`000?o6`@3oa/40o`000?nK^P05o`000006o`214_l0003o07DWo`000?l0JSSo
00000_l0GTD00ol0003o05==o`1CC@02o`1CC@03o`000?l0?TOo03i700Co03i700?o0000o`0Y??l0
:C`02ol0:C`00ol0003o01L`o`0G<00Ko`0G<003o`000?l02bGo00/U037o00/U1Oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo<ol02bD00ol0003o01L`o`0G<00Lo`0G<003o`00
0?l0:Cco02Tl00[o02Tl00?o0000o`0nAol0?TL01Ol0?TL00ol0003o05==o`1CC@02o`1CC@09o`00
0?l0GTGo05i5o`000?l0JSSo0000o`1e9ol0003o084B00;o000000Go9IP0o`000?l0003o0000oi^j
0002o`000004oi^j0?l0003o0000odRS00?o000000Ko084Bo`000?l0MBOo0000o`1Z>?l00002o`1N
A@03o`000?l0Ddgo05==00;o05==00?o0000o`0nAol0?TL01Ol0?TL00ol0003o02Tlo`0Y?00:o`0Y
?003o`000?l05c3o01L`01co01L`00?o0000o`0;9Ol02bD0<?l02bD5ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_oooolco`0;9@03o`000?l05c3o01L`01co01L`00?o0000o`0Y??l0
:C`02_l0:C`00ol0003o03i7o`0nA`05o`0nA`03o`000?l0Ddgo05==00;o05==00Wo0000o`1NAOl0
GTGo0000o`1Z>?l0003o07DWo`000?l0PA800_l000001OlUV03o0000o`000?m_[`3o000000;oVkX0
00Co0000ofn_0?l0003oB:<00ol000001_l0PA;o0000o`1e9ol0003o06Xho`0000;o05i500?o0000
o`1CCOl0Ddd00_l0Ddd00ol0003o03i7o`0nA`05o`0nA`03o`000?l0:Cco02Tl00[o02Tl00?o0000
o`0G<?l05c007?l05c000ol0003o00/Uo`0;9@0`o`0;9@Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`02oooooc?o00/U00?o0000o`0G<?l05c007?l05c000ol0003o02Tlo`0Y?00:o`0Y
?003o`000?l0?TOo03i700Go03i700?o0000o`1CCOl0Ddd00_l0Ddd02ol0003o05i5o`1NAOl0003o
06Xho`000?l0MBOo0000o`214_l0003o1h`000?o000000?oKjl0o`000?l000000_l000001?m_[`3o
0000o`000?lUV002o`000006o`214_l0003o07DWo`000?l0JSSo00000ol0GTD01Ol0003o05==o`1C
COl0Ddgo000000Oo03i700?o0000o`0Y??l0:C`02_l0:C`00ol0003o01L`o`0G<00Lo`0G<003o`00
0?l02bGo00/U033o00/U1Oooool1o`00007ooooo000Kooooo`;o00000ooooolco`0;9@03o`000?l0
5c3o01L`01_o01L`00?o0000o`0Y??l0:C`02ol0:C`00ol0003o03i7o`0nA`05o`0nA`03o`000?l0
Ddgo05==00;o05==00Co0000o`1NAOl0GTGo00000_l0JSP01Ol0003o07DWo`000?l0003o1h`000;o
000000?oB:<0o`000?m_[`000om_[`003?l0003oB:<0o`000?l0003o1h`0o`000?l0PA;o0000o`1e
9ol0003o06Xho`0000?o05i500Go0000o`1CCOl0Ddgo05==o`000007o`0nA`03o`000?l0:Cco02Tl
00_o02Tl00?o0000o`0G<?l05c007?l05c000ol0003o00/Uo`0;9@0_o`0;9@Cooooo0_l00001oooo
o`006oooool00ol0003oooooooooo`3oooooo`7ooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`3oooooo`7ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool06oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00;ooooo0Ol00001ooooo`006oooooooo`0000Go00000Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0629143, -0.599351, \
0.000400575, 0.00400575}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DensityPlot[GeometricIntensity[ys,d], {ys,-.05,.05}, {d,-.5, .65}, \
PlotPoints->200, PlotRange->{0,260}, \
ColorFunction->Function[Hue[.65-#*(.65),1,#*.9+.1]], Mesh->False];\
\>", "Input",
  CellLabel->"In[155]:=",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 9.61538 0.437291 0.83612 [
[.11538 -0.0125 -15 -9 ]
[.11538 -0.0125 15 0 ]
[.30769 -0.0125 -15 -9 ]
[.30769 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -12 -9 ]
[.69231 -0.0125 12 0 ]
[.88462 -0.0125 -12 -9 ]
[.88462 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10284 -24 -4.5 ]
[-0.0125 .10284 0 4.5 ]
[-0.0125 .27007 -24 -4.5 ]
[-0.0125 .27007 0 4.5 ]
[-0.0125 .43729 -6 -4.5 ]
[-0.0125 .43729 0 4.5 ]
[-0.0125 .60452 -18 -4.5 ]
[-0.0125 .60452 0 4.5 ]
[-0.0125 .77174 -18 -4.5 ]
[-0.0125 .77174 0 4.5 ]
[-0.0125 .93896 -18 -4.5 ]
[-0.0125 .93896 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-0.04)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-0.02)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(0.02)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(0.04)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.06731 0 m
.06731 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10284 m
.00625 .10284 L
s
[(-0.4)] -0.0125 .10284 1 0 Mshowa
0 .27007 m
.00625 .27007 L
s
[(-0.2)] -0.0125 .27007 1 0 Mshowa
0 .43729 m
.00625 .43729 L
s
[(0)] -0.0125 .43729 1 0 Mshowa
0 .60452 m
.00625 .60452 L
s
[(0.2)] -0.0125 .60452 1 0 Mshowa
0 .77174 m
.00625 .77174 L
s
[(0.4)] -0.0125 .77174 1 0 Mshowa
0 .93896 m
.00625 .93896 L
s
[(0.6)] -0.0125 .93896 1 0 Mshowa
.125 Mabswid
0 .14465 m
.00375 .14465 L
s
0 .18645 m
.00375 .18645 L
s
0 .22826 m
.00375 .22826 L
s
0 .31187 m
.00375 .31187 L
s
0 .35368 m
.00375 .35368 L
s
0 .39548 m
.00375 .39548 L
s
0 .4791 m
.00375 .4791 L
s
0 .5209 m
.00375 .5209 L
s
0 .56271 m
.00375 .56271 L
s
0 .64632 m
.00375 .64632 L
s
0 .68813 m
.00375 .68813 L
s
0 .72993 m
.00375 .72993 L
s
0 .81355 m
.00375 .81355 L
s
0 .85535 m
.00375 .85535 L
s
0 .89716 m
.00375 .89716 L
s
0 .06104 m
.00375 .06104 L
s
0 .01923 m
.00375 .01923 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.25962 .99625 m
.25962 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.74038 .99625 m
.74038 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.06731 .99625 m
.06731 1 L
s
.01923 .99625 m
.01923 1 L
s
.93269 .99625 m
.93269 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .10284 m
1 .10284 L
s
.99375 .27007 m
1 .27007 L
s
.99375 .43729 m
1 .43729 L
s
.99375 .60452 m
1 .60452 L
s
.99375 .77174 m
1 .77174 L
s
.99375 .93896 m
1 .93896 L
s
.125 Mabswid
.99625 .14465 m
1 .14465 L
s
.99625 .18645 m
1 .18645 L
s
.99625 .22826 m
1 .22826 L
s
.99625 .31187 m
1 .31187 L
s
.99625 .35368 m
1 .35368 L
s
.99625 .39548 m
1 .39548 L
s
.99625 .4791 m
1 .4791 L
s
.99625 .5209 m
1 .5209 L
s
.99625 .56271 m
1 .56271 L
s
.99625 .64632 m
1 .64632 L
s
.99625 .68813 m
1 .68813 L
s
.99625 .72993 m
1 .72993 L
s
.99625 .81355 m
1 .81355 L
s
.99625 .85535 m
1 .85535 L
s
.99625 .89716 m
1 .89716 L
s
.99625 .06104 m
1 .06104 L
s
.99625 .01923 m
1 .01923 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FB1200E95A00DA8A00CEAC00C4C400A1BC0085B500
6EAF005BA9004AA4003CA000309C002698001C95001492000D8F00068C00018A00008804
00850800830D00564B00554B00544C00534C00524D00524D00514D00514D00504E004F4E
004F4E004E4E004D4E004C4D004B4D004A4D00494C00494C00484B00474B00464B00464A
00454A00444A00444A004349004249004249004148004148004048004048003F48003F47
003F47003E47003E47003D47003D46003D46003C46003C46003C46003C46003B46003B45
003B45003B45003A45003A45003A45003A45003A45003945003945003945003944003944
003944003944003944003844003844003844003844003844003844003844003844003844
003844003844003844003844003844003844003844003844003844003844003844003844
003844003844003844003844003844003944003944003944003944003944003945003945
003945003A45003A45003A45003A45003A45003B45003B45003B45003B46003C46003C46
003C46003C46003D46003D46003D47003E47003E47003F47003F47003F48004048004048
00414800414800424900424900434900444A00444A00454A00464A00464B00474B00484B
00494C004A4C004A4D004B4D004C4D004D4E004E4E004F4E004F4E00504E00514D00514D
00524D00534D00534C00544C00554B00564B00830D008508008804018A00068C000D8F00
1492001C9500269800309C003CA0004AA4005BA9006EAF0085B500A1BC00C4C400CEAC00
DA8A00E95A00FB1200FF0000FF0000FF0000FF0000FF0000
000219FF0000FF0000FF0000FF0000FF0000FB1100E95900DA8900CFAB00C5C400A3BC00
86B5006FAF005CA9004BA4003DA000319C002698001D95001592000D8F00078C00018A00
00880300860800840C00821000554B00544C00534C00534C00524D00514D00514D00504E
00504E004F4E004F4E004E4E004D4E004C4D004B4D004A4C00494C00484C00474B00474B
00464B00454A00454A00444A004349004349004249004249004148004148004048004048
003F48003F47003F47003E47003E47003E47003D47003D46003D46003C46003C46003C46
003C46003B46003B45003B45003B45003A45003A45003A45003A45003A45003A45003945
003945003945003945003944003944003944003944003944003944003944003944003844
003844003844003844003844003844003844003844003844003844003944003944003944
003944003944003944003944003944003945003945003945003945003A45003A45003A45
003A45003A45003A45003B45003B45003B45003B46003C46003C46003C46003C46003D46
003D46003D47003E47003E47003E47003F47003F47003F48004048004048004148004148
00424900424900434900434900444A00454A00454A00464B00474B00474B00484C00494C
004A4C004B4D004C4D004D4E004E4E004F4E004F4E00504E00504E00514D00514D00524D
00534C00534C00544C00554B00821000840C008608008803018A00078C000D8F00159200
1D9500269800319C003DA0004BA4005CA9006FAF0086B500A3BC00C5C400CFAB00DA8900
E95900FB1100FF0000FF0000FF0000FF0000FF0000000219
000219000219FF0000FF0000FF0000FF0000FF0000FC1000E95800DB8800CFAA00C5C300
A4BD0087B50070AF005CAA004CA5003EA000329C002799001E95001592000E8F00088D00
028A0000880300860700840C00821000554B00544C00544C00534C00524D00524D00514D
00504E00504E004F4E004F4E004E4E004D4E004C4D004B4D004A4D00494C00494C00484B
00474B00464B00464A00454A00444A00444A004349004349004249004249004148004148
004048004048003F48003F47003F47003E47003E47003E47003D47003D46003D46003C46
003C46003C46003C46003B46003B46003B45003B45003B45003B45003A45003A45003A45
003A45003A45003A45003A45003A45003945003945003945003945003945003945003944
003944003944003944003944003944003944003944003944003944003945003945003945
003945003945003945003A45003A45003A45003A45003A45003A45003A45003A45003B45
003B45003B45003B45003B46003B46003C46003C46003C46003C46003D46003D46003D47
003E47003E47003E47003F47003F47003F48004048004048004148004148004249004249
00434900434900444A00444A00454A00464A00464B00474B00484B00494C00494C004A4D
004B4D004C4D004D4E004E4E004F4E004F4E00504E00504E00514D00524D00524D00534C
00544C00544C00554B00821000840C008607008803028A00088D000E8F001592001E9500
279900329C003EA0004CA5005CAA0070AF0087B500A4BD00C5C300CFAA00DB8800E95800
FC1000FF0000FF0000FF0000FF0000FF0000000219000219
000219000219000219FF0000FF0000FF0000FF0000FF0000FC0F00E95700DB8800CFAA00
C5C300A5BD0088B60071AF005DAA004DA5003EA000329C002899001E95001692000F9000
088D00028A0000880200860700840B00820F00801300544C00544C00534C00524D00524D
00514D00504D00504E004F4E004F4E004E4E004E4E004D4E004C4D004B4D004A4C00494C
00484C00474B00474B00464B00454A00454A00444A00444A004349004349004249004249
004148004148004048004048003F48003F47003F47003E47003E47003E47003D47003D47
003D46003D46003C46003C46003C46003C46003C46003B46003B46003B45003B45003B45
003B45003A45003A45003A45003A45003A45003A45003A45003A45003A45003A45003A45
003A45003A45003A45003A45003A45003A45003A45003A45003A45003A45003A45003A45
003A45003A45003A45003A45003A45003A45003A45003B45003B45003B45003B45003B46
003B46003C46003C46003C46003C46003C46003D46003D46003D47003D47003E47003E47
003E47003F47003F47003F48004048004048004148004148004249004249004349004349
00444A00444A00454A00454A00464B00474B00474B00484C00494C004A4C004B4D004C4D
004D4E004E4E004E4E004F4E004F4E00504E00504D00514D00524D00524D00534C00544C
00544C00801300820F00840B008607008802028A00088D000F90001692001E9500289900
329C003EA0004DA5005DAA0071AF0088B600A5BD00C5C300CFAA00DB8800E95700FC0F00
FF0000FF0000FF0000FF0000FF0000000219000219000219
000219000219000219000219FF0000FF0000FF0000FF0000FF0000FC0F00E95700DB8700
CFA900C5C200A5BD0089B60071B0005EAA004DA5003FA100339D002899001F9600179300
0F9000098D00038B0000880200860600840B00820F00811300554B00544C00534C00524D
00524D00514D00514D00504E00504E004F4E004F4E004E4E004D4E004C4D004B4D004A4D
00494C00494C00484B00474B00464B00464B00454A00454A00444A004349004349004249
004249004149004148004148004048004048003F48003F47003F47003E47003E47003E47
003E47003D47003D46003D46003D46003C46003C46003C46003C46003C46003B46003B46
003B46003B45003B45003B45003B45003B45003B45003A45003A45003A45003A45003A45
003A45003A45003A45003A45003A45003A45003A45003A45003A45003A45003A45003A45
003A45003B45003B45003B45003B45003B45003B45003B46003B46003B46003C46003C46
003C46003C46003C46003D46003D46003D46003D47003E47003E47003E47003E47003F47
003F47003F4800404800404800414800414800424900424900424900434900434900444A
00454A00454A00464B00464B00474B00484B00494C00494C004A4D004B4D004C4D004D4E
004E4E004F4E004F4E00504E00504E00514D00514D00524D00524D00534C00544C00554B
00811300820F00840B008607008802038B00098D000F90001793001F9600289900339D00
3FA1004DA5005EAA0071B00089B600A5BD00C5C200CFA900DB8700E95700FC0F00FF0000
FF0000FF0000FF0000FF0000000219000219000219000219
000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FC0E00EA5600
DB8700CFA900C6C200A6BD008AB60072B0005FAA004EA50040A100339D002999001F9600
179300109000098D00038B0000890100860600840A00830E00811200554B00544C00534C
00534C00524D00514D00514D00504E00504E004F4E004F4E004E4E004D4E004C4D004B4D
004B4D004A4C00494C00484C00484B00474B00464B00464A00454A00444A00444A004349
004349004249004249004149004148004148004048004048004048003F48003F47003F47
003E47003E47003E47003E47003D47003D46003D46003D46003C46003C46003C46003C46
003C46003C46003C46003B46003B46003B46003B46003B45003B45003B45003B45003B45
003B45003B45003B45003B45003B45003B45003B45003B45003B45003B45003B45003B45
003B45003B46003B46003B46003B46003C46003C46003C46003C46003C46003C46003C46
003D46003D46003D46003D47003E47003E47003E47003E47003F47003F47003F48004048
00404800404800414800414800414900424900424900434900434900444A00444A00454A
00464A00464B00474B00484B00484C00494C004A4C004B4D004C4D004C4D004D4E004E4E
004F4E004F4E00504E00504E00514D00514D00524D00534C00534C00544C00554B008112
00830E00840A008606008901038B00098D001090001793001F9600299900339D0040A100
4EA5005FAA0072B0008AB600A6BD00C6C200CFA900DB8700EA5600FC0E00FF0000FF0000
FF0000FF0000FF0000000219000219000219000219000219
000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FC0F00
EA5600DB8700CFA900C6C100A7BD008AB60073B0005FAA004FA50040A100349D00299900
2096001893001090000A8E00048B0000890100870600850A00830E008112007F1500544C
00544C00534C00524D00524D00514D00504D00504E004F4E004F4E004E4E004E4E004D4E
004C4D004B4D004A4D00494C00494C00484C00474B00474B00464B00454A00454A00444A
00444A004349004349004249004249004249004148004148004048004048004048003F48
003F47003F47003F47003E47003E47003E47003E47003D47003D47003D46003D46003D46
003D46003C46003C46003C46003C46003C46003C46003C46003C46003C46003C46003B46
003B46003B46003B46003B46003B46003B46003B46003B46003B46003C46003C46003C46
003C46003C46003C46003C46003C46003C46003C46003D46003D46003D46003D46003D47
003D47003E47003E47003E47003E47003F47003F47003F47003F48004048004048004048
00414800414800424900424900424900434900434900444A00444A00454A00454A00464B
00474B00474B00484C00494C00494C004A4D004B4D004C4D004D4E004E4E004E4E004F4E
004F4E00504E00504D00514D00524D00524D00534C00544C00544C007F1500811200830E
00850A008706008901048B000A8E00109000189300209600299900349D0040A1004FA500
5FAA0073B0008AB600A7BD00C6C100CFA900DB8700EA5600FC0F00FF0000FF0000FF0000
FF0000FF0000000219000219000219000219000219000219
000219000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000
FC0F00EA5600DB8600D0A800C6C100A7BE008BB60073B00060AB004FA60041A100359D00
2A9A002096001893001190000A8E00048B0000890000870500850A00830E008111008015
00544C00544C00534C00524D00524D00514D00514D00504E00504E004F4E004F4E004E4E
004D4E004C4D004B4D004B4D004A4C00494C00484C00484B00474B00464B00464B00454A
00454A00444A00444A004349004349004249004249004249004148004148004048004048
004048004048003F48003F47003F47003F47003E47003E47003E47003E47003E47003D47
003D47003D46003D46003D46003D46003D46003C46003C46003C46003C46003C46003C46
003C46003C46003C46003C46003C46003C46003C46003C46003C46003C46003C46003C46
003C46003C46003D46003D46003D46003D46003D46003D47003D47003E47003E47003E47
003E47003E47003F47003F47003F47003F48004048004048004048004048004148004148
00424900424900424900434900434900444A00444A00454A00454A00464B00464B00474B
00484B00484C00494C004A4C004B4D004B4D004C4D004D4E004E4E004F4E004F4E00504E
00504E00514D00514D00524D00524D00534C00544C00544C00801500811100830E00850A
008705008900048B000A8E001190001893002096002A9A00359D0041A1004FA60060AB00
73B0008BB600A7BE00C6C100D0A800DB8600EA5600FC0F00FF0000FF0000FF0000FF0000
FF0000000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219FF0000FF0000FF0000FF0000
FF0000FC1000EA5600DB8600D0A800C6C100A8BE008BB60074B00060AB0050A60041A100
359D002A9A002196001993001191000B8E00058B0000890000870500850900830D008111
008014007E1700544C00534C00534D00524D00514D00514D00504E00504E004F4E004F4E
004E4E004E4E004D4E004C4D004B4D004A4D004A4C00494C00484C00474B00474B00464B
00464A00454A00454A00444A00444A004349004349004249004249004249004148004148
004148004048004048004048004048003F48003F47003F47003F47003E47003E47003E47
003E47003E47003E47003D47003D47003D47003D46003D46003D46003D46003D46003D46
003D46003D46003D46003D46003D46003D46003D46003D46003D46003D46003D46003D46
003D46003D46003D47003D47003D47003E47003E47003E47003E47003E47003E47003F47
003F47003F47003F48004048004048004048004048004148004148004148004249004249
00424900434900434900444A00444A00454A00454A00464B00464B00474B00474B00484C
00494C004A4C004A4D004B4D004C4D004D4E004E4E004E4E004F4E004F4E00504E00504E
00514D00514D00524D00534D00534C00544C007E1700801400811100830D008509008705
008900058B000A8E001191001993002196002A9A00359D0041A10050A60060AB0074B000
8BB600A8BE00C6C100D0A800DB8600EA5600FC1000FF0000FF0000FF0000FF0000FF0000
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219FF0000FF0000FF0000
FF0000FF0000FC1100E95700DB8600D0A800C6C100A8BE008CB70074B00061AB0050A600
42A200369E002B9A002197001994001291000B8E00058C0000890000870400850900830D
008210008014007E1700544C00534C00534C00524D00524D00514D00504D00504E004F4E
004F4E004F4E004E4E004D4E004C4D004B4D004B4D004A4C00494C00494C00484B00474B
00474B00464B00464A00454A00454A00444A00444A004349004349004249004249004249
004149004148004148004148004048004048004048004048003F48003F47003F47003F47
003F47003E47003E47003E47003E47003E47003E47003E47003E47003E47003D47003D47
003D47003D47003D47003D47003D47003D47003D47003D47003D47003D47003E47003E47
003E47003E47003E47003E47003E47003E47003E47003F47003F47003F47003F47003F48
004048004048004048004048004148004148004148004149004249004249004249004349
00434900444A00444A00454A00454A00464A00464B00474B00474B00484B00494C00494C
004A4C004B4D004C4D004C4D004D4E004E4E004F4E004F4E004F4E00504E00504D00514D
00524D00524D00534C00534C00544C007E1700801400821000830D008509008704008900
058C000B8E001291001994002197002B9A00369E0042A20050A60061AB0074B0008CB700
A8BE00C6C100D0A800DB8600E95700FC1100FF0000FF0000FF0000FF0000FF0000000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219FF0000FF0000
FF0000FF0000FF0000FB1200E95700DB8700D0A800C6C100A8BE008CB70075B00061AB00
51A60042A200369E002B9A002297001994001291000B8E00058C00008A00008704008508
00840C008210008014007F1700544C00544C00534C00524D00524D00514D00514D00504E
00504E004F4E004F4E004E4E004E4E004D4E004C4D004B4D004A4D004A4C00494C00484C
00484B00474B00474B00464B00464A00454A00454A00444A00444A004349004349004349
004249004249004249004148004148004148004148004048004048004048004048003F48
003F48003F47003F47003F47003F47003F47003E47003E47003E47003E47003E47003E47
003E47003E47003E47003E47003E47003E47003E47003E47003E47003E47003E47003E47
003E47003E47003F47003F47003F47003F47003F47003F48003F48004048004048004048
00404800414800414800414800414800424900424900424900434900434900434900444A
00444A00454A00454A00464A00464B00474B00474B00484B00484C00494C004A4C004A4D
004B4D004C4D004D4E004E4E004E4E004F4E004F4E00504E00504E00514D00514D00524D
00524D00534C00544C00544C007F1700801400821000840C008508008704008A00058C00
0B8E001291001994002297002B9A00369E0042A20051A60061AB0075B0008CB700A8BE00
C6C100D0A800DB8700E95700FB1200FF0000FF0000FF0000FF0000FF0000000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219FF0000
FF0000FF0000FF0000FF0000FB1300E95800DB8700D0A800C6C100A9BE008CB70075B100
62AB0051A60043A200369E002C9A002297001A94001291000C8E00068C00008A00008803
00860800840C008210008013007F16007D1900544C00534C00524D00524D00514D00514D
00504E00504E004F4E004F4E004F4E004E4E004D4E004C4D004C4D004B4D004A4C00494C
00494C00484C00484B00474B00474B00464B00464A00454A00454A00444A00444A004349
004349004349004249004249004249004249004148004148004148004148004048004048
004048004048004048004048003F48003F48003F47003F47003F47003F47003F47003F47
003F47003F47003F47003F47003F47003F47003F47003F47003F47003F47003F47003F47
003F47003F47003F48003F48004048004048004048004048004048004048004148004148
00414800414800424900424900424900424900434900434900434900444A00444A00454A
00454A00464A00464B00474B00474B00484B00484C00494C00494C004A4C004B4D004C4D
004C4D004D4E004E4E004F4E004F4E004F4E00504E00504E00514D00514D00524D00524D
00534C00544C007D19007F1600801300821000840C008608008803008A00068C000C8E00
1291001A94002297002C9A00369E0043A20051A60062AB0075B1008CB700A9BE00C6C100
D0A800DB8700E95800FB1300FF0000FF0000FF0000FF0000FF0000000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
FF0000FF0000FF0000FF0000FF0000FA1500E95900DB8700D0A800C6C100A9BE008DB700
75B10062AB0051A60043A200379E002C9A002397001A94001391000C8F00068C00018A00
00880300860800840C00820F008113007F16007D1900544C00534C00534C00524D00524D
00514D00514D00504E00504E004F4E004F4E004E4E004E4E004D4E004C4D004B4D004B4D
004A4C00494C00494C00484C00484B00474B00474B00464B00464A00454A00454A00444A
00444A00444A004349004349004349004249004249004249004249004148004148004148
004148004148004048004048004048004048004048004048004048004048004048003F48
003F48003F48003F48003F48003F48003F48003F48003F48003F48004048004048004048
004048004048004048004048004048004048004148004148004148004148004148004249
00424900424900424900434900434900434900444A00444A00444A00454A00454A00464A
00464B00474B00474B00484B00484C00494C00494C004A4C004B4D004B4D004C4D004D4E
004E4E004E4E004F4E004F4E00504E00504E00514D00514D00524D00524D00534C00534C
00544C007D19007F1600811300820F00840C008608008803018A00068C000C8F00139100
1A94002397002C9A00379E0043A20051A60062AB0075B1008DB700A9BE00C6C100CFA900
DB8700E95900FA1500FF0000FF0000FF0000FF0000FF0000000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219FF0000FF0000FF0000FF0000FF0000FA1700E95A00DB8800CFA900C6C100A9BE00
8DB70076B10062AB0052A60043A200379E002C9A002397001B94001391000D8F00078C00
018A0000880300860700840B00820F008112007F16007E18007C1B00534C00534C00524D
00524D00514D00514D00504E00504E004F4E004F4E004F4E004E4E004D4E004D4E004C4D
004B4D004A4D004A4C00494C00494C00484C00484B00474B00474B00464B00464A00454A
00454A00444A00444A00444A004349004349004349004349004249004249004249004249
004249004148004148004148004148004148004148004148004048004048004048004048
004048004048004048004048004048004048004048004048004048004048004048004048
004148004148004148004148004148004148004148004249004249004249004249004249
00434900434900434900434900444A00444A00444A00454A00454A00464A00464B00474B
00474B00484B00484C00494C00494C004A4C004A4D004B4D004C4D004D4E004D4E004E4E
004F4E004F4E004F4E00504E00504E00514D00514D00524D00524D00534C00534C007C1B
007E18007F1600811200820F00840B008607008803018A00078C000D8F001391001B9400
2397002C9A00379E0043A20052A60062AB0076B1008DB700A9BE00C6C100CFA900DB8800
E95A00FA1700FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219FF0000FF0000FF0000FF0000FF0000F91900E85B00DB8900CFA900C6C100
A9BE008DB70076B10062AB0052A70044A200389E002D9B002397001B94001492000D8F00
078C00028A0000880200860700840B00830F008112007F15007E18007C1B00544C00534C
00524D00524D00514D00514D00504D00504E00504E004F4E004F4E004E4E004E4E004D4E
004C4D004C4D004B4D004A4D004A4C00494C00494C00484C00484B00474B00474B00464B
00464B00454A00454A00454A00444A00444A00444A004349004349004349004349004249
004249004249004249004249004249004149004148004148004148004148004148004148
004148004148004148004148004148004148004148004148004148004148004148004148
004148004148004149004249004249004249004249004249004249004349004349004349
00434900444A00444A00444A00454A00454A00454A00464B00464B00474B00474B00484B
00484C00494C00494C004A4C004A4D004B4D004C4D004C4D004D4E004E4E004E4E004F4E
004F4E00504E00504E00504D00514D00514D00524D00524D00534C00544C007C1B007E18
007F1500811200830F00840B008607008802028A00078C000D8F001491001B9400239700
2D9B00389E0044A20052A60062AB0076B1008DB700A8BE00C6C100CFA900DA8900E85B00
F91900FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219FF0000FF0000FF0000FF0000FF0000F91B00E85D00DA8900CFAA00
C6C100A8BE008DB70076B10063AB0052A70044A200389E002D9B002497001B9400149200
0D8F00078D00028A0000880200860600840A00830E008112008015007E18007D1A00544C
00534C00534D00524D00524D00514D00514D00504E00504E004F4E004F4E004F4E004E4E
004D4E004D4E004C4D004B4D004B4D004A4C004A4C00494C00494C00484C00484B00474B
00474B00464B00464B00464A00454A00454A00454A00444A00444A00444A004449004349
004349004349004349004349004249004249004249004249004249004249004249004249
004249004249004249004249004249004249004249004249004249004249004249004249
00424900424900424900424900434900434900434900434900434900444900444A00444A
00444A00454A00454A00454A00464A00464B00464B00474B00474B00484B00484C00494C
00494C004A4C004A4C004B4D004B4D004C4D004D4E004D4E004E4E004F4E004F4E004F4E
00504E00504E00514D00514D00524D00524D00534D00534C00544C007D1A007E18008015
00811200830E00840A008606008802028A00078D000D8F001492001B94002497002D9B00
389E0044A20052A70063AB0076B1008DB700A8BE00C6C100CFAA00DA8900E85D00F91B00
FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219FF0000FF0000FF0000FF0000FF0000F81E00E75E00DA8A00
CFAA00C6C200A8BE008DB70076B10063AB0052A70044A200389E002D9B002498001C9500
1492000E8F00088D00028B0000880200860600850A00830E008111008014007E17007D1A
007C1D00534C00534C00524D00524D00514D00514D00504D00504E00504E004F4E004F4E
004E4E004E4E004D4E004D4E004C4D004B4D004B4D004A4C004A4C00494C00494C00484C
00484B00474B00474B00464B00464B00464B00454A00454A00454A00454A00444A00444A
00444A00444A004449004349004349004349004349004349004349004349004349004249
004249004249004249004249004249004249004249004249004249004349004349004349
00434900434900434900434900434900444900444A00444A00444A00444A00454A00454A
00454A00454A00464B00464B00464B00474B00474B00484B00484C00494C00494C004A4C
004A4C004B4D004B4D004C4D004D4E004D4E004E4E004E4E004F4E004F4E00504E00504E
00504D00514D00514D00524D00524D00534C00534C007C1D007D1A007E17008014008111
00830E00850A008606008802028B00088D000E8F001492001C95002498002D9B00389E00
44A20052A70063AB0076B1008DB700A8BE00C6C200CFAA00DA8A00E75E00F81E00FF0000
FF0000FF0000FF0000FF0000000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000F82100E76000
DA8B00CFAB00C5C200A8BE008CB70076B10063AB0052A70045A200389E002E9B00249800
1C95001592000E8F00088D00038B0000890100870600850A00830D008111008014007E17
007D1A007C1C00544C00534C00524D00524D00514D00514D00514D00504E00504E004F4E
004F4E004F4E004E4E004E4E004D4E004C4D004C4D004B4D004B4D004A4C004A4C00494C
00494C00484C00484B00474B00474B00474B00464B00464B00464B00454A00454A00454A
00454A00454A00444A00444A00444A00444A00444A00444A004349004349004349004349
004349004349004349004349004349004349004349004349004349004349004349004349
00444A00444A00444A00444A00444A00444A00454A00454A00454A00454A00454A00464B
00464B00464B00474B00474B00474B00484B00484C00494C00494C004A4C004A4C004B4D
004B4D004C4D004C4D004D4E004E4E004E4E004F4E004F4E004F4E00504E00504E00514D
00514D00514D00524D00524D00534C00544C007C1C007D1A007E1700801400811100830D
00850A008706008901038B00088D000E8F001592001C95002498002E9B00389E0045A200
52A70063AB0076B1008CB700A8BE00C5C200CFAB00DA8B00E76000F82100FF0000FF0000
FF0000FF0000FF0000000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000F72400
E66100D98C00CEAB00C5C200A7BE008CB70076B10063AB0053A70045A200399F002E9B00
2598001C95001592000E8F00088D00038B0000890100870500850900830D008211008014
007F17007D19007C1C007B1E00534C00534C00524D00524D00514D00514D00504E00504E
00504E004F4E004F4E004F4E004E4E004E4E004D4E004C4D004C4D004B4D004B4D004A4C
004A4C00494C00494C00484C00484C00484B00474B00474B00474B00464B00464B00464B
00464A00454A00454A00454A00454A00454A00454A00444A00444A00444A00444A00444A
00444A00444A00444A00444A00444A00444A00444A00444A00444A00444A00444A00444A
00444A00454A00454A00454A00454A00454A00454A00464A00464B00464B00464B00474B
00474B00474B00484B00484C00484C00494C00494C004A4C004A4C004B4D004B4D004C4D
004C4D004D4E004E4E004E4E004F4E004F4E004F4E00504E00504E00504E00514D00514D
00524D00524D00534C00534C007B1E007C1C007D19007F1700801400821100830D008509
008705008901038B00088D000E8F001592001C95002598002E9B00399F0045A20053A700
63AB0076B1008CB700A7BE00C5C200CEAB00D98C00E66100F72400FF0000FF0000FF0000
FF0000FF0000000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000
F62700E66300D98E00CEAC00C5C300A7BD008CB70076B10063AB0053A70045A200399F00
2E9B002598001D95001592000F9000098D00038B0000890000870500850900830D008210
008013007F16007D19007C1B007B1E00534C00534C00524D00524D00514D00514D00514D
00504E00504E004F4E004F4E004F4E004E4E004E4E004D4E004D4E004C4D004C4D004B4D
004B4D004A4C004A4C00494C00494C00494C00484C00484B00484B00474B00474B00474B
00464B00464B00464B00464B00464A00454A00454A00454A00454A00454A00454A00454A
00454A00454A00454A00454A00454A00454A00454A00454A00454A00454A00454A00454A
00454A00454A00454A00464A00464B00464B00464B00464B00474B00474B00474B00484B
00484B00484C00494C00494C00494C004A4C004A4C004B4D004B4D004C4D004C4D004D4E
004D4E004E4E004E4E004F4E004F4E004F4E00504E00504E00514D00514D00514D00524D
00524D00534C00534C007B1E007C1B007D19007F1600801300821000830D008509008705
008901038B00098D000F90001592001D95002598002E9B00399F0045A20053A70063AB00
76B1008CB700A7BD00C5C300CEAC00D98E00E66300F62700FF0000FF0000FF0000FF0000
FF0000000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000
FF0000F52A00E56500D88F00CEAD00C5C300A6BD008CB70075B10063AB0053A70045A300
399F002E9B002598001D95001692000F9000098D00048B0000890000870500850900840C
008210008013007F16007E19007C1B007B1D00544C00534C00534D00524D00524D00514D
00514D00504D00504E00504E004F4E004F4E004F4E004E4E004E4E004D4E004D4E004C4D
004C4D004B4D004B4D004A4D004A4C00494C00494C00494C00484C00484C00484B00484B
00474B00474B00474B00474B00464B00464B00464B00464B00464B00464B00464B00464A
00464A00464A00464A00464A00464A00464A00464A00464A00464A00464B00464B00464B
00464B00464B00464B00464B00474B00474B00474B00474B00484B00484B00484C00484C
00494C00494C004A4C004A4C004A4D004B4D004B4D004C4D004C4D004D4E004D4E004E4E
004E4E004F4E004F4E004F4E00504E00504E00504D00514D00514D00524D00524D00534D
00534C00544C007B1D007C1B007E19007F1600801300821000840C008509008705008900
048B00098D000F90001692001D95002598002E9B00399F0045A30053A70063AB0075B100
8CB700A6BD00C5C300CEAD00D88F00E56500F52A00FF0000FF0000FF0000FF0000FF0000
FF0000000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219FF0000FF0000FF0000FF0000
FF0000FF0000F42E00E56700D89000CEAE00C5C400A5BD008BB60075B10063AB0053A700
45A300399F002F9B002598001D95001692000F9000098D00048B00008900008704008508
00840C00820F008113007F16007E18007C1B007B1D007A1F00534C00534C00524D00524D
00514D00514D00514D00504E00504E00504E004F4E004F4E004F4E004E4E004E4E004D4E
004D4E004C4D004C4D004B4D004B4D004A4D004A4C004A4C00494C00494C00494C00484C
00484C00484C00484B00484B00474B00474B00474B00474B00474B00474B00474B00464B
00464B00464B00464B00464B00464B00464B00464B00464B00464B00474B00474B00474B
00474B00474B00474B00474B00484B00484B00484C00484C00484C00494C00494C00494C
004A4C004A4C004A4D004B4D004B4D004C4D004C4D004D4E004D4E004E4E004E4E004F4E
004F4E004F4E00504E00504E00504E00514D00514D00514D00524D00524D00534C00534C
007A1F007B1D007C1B007E18007F1600811300820F00840C008508008704008900048B00
098D000F90001692001D95002598002F9B00399F0045A30053A70063AB0075B1008BB600
A5BD00C5C400CEAE00D89000E56800F42E00FF0000FF0000FF0000FF0000FF0000FF0000
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219FF0000FF0000FF0000
FF0000FF0000FF0000F33100E46A00D89200CDAF00C4C400A5BD008BB60075B10062AB00
53A70045A300399F002F9B002698001D95001692001090000A8E00048B00008900008704
00860800840C00820F008112007F15007E18007D1A007B1D007A1F00534C00534C00524D
00524D00524D00514D00514D00504D00504E00504E004F4E004F4E004F4E004F4E004E4E
004E4E004D4E004D4E004C4D004C4D004C4D004B4D004B4D004A4D004A4C004A4C00494C
00494C00494C00494C00484C00484C00484C00484B00484B00484B00484B00474B00474B
00474B00474B00474B00474B00474B00474B00474B00474B00474B00474B00484B00484B
00484B00484B00484C00484C00484C00494C00494C00494C00494C004A4C004A4C004A4D
004B4D004B4D004C4D004C4D004C4D004D4E004D4E004E4E004E4E004F4E004F4E004F4E
004F4E00504E00504E00504D00514D00514D00524D00524D00524D00534C00534C007A1F
007B1D007D1A007E18007F1500811200820F00840C008608008704008900048B000A8E00
1090001692001D95002698002F9B00399F0045A30053A70062AB0075B1008BB600A5BD00
C4C400CDAF00D89200E46A00F33100FF0000FF0000FF0000FF0000FF0000FF0000000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219FF0000FF0000
FF0000FF0000FF0000FF0000F33500E36C00D79300CDB000C3C400A4BD008AB60075B000
62AB0053A70045A300399F002F9B002698001E95001693001090000A8E00058C00008900
00880400860800840B00820F008112007F15007E18007D1A007C1C007A1F00792100534C
00534C00524D00524D00514D00514D00514D00504E00504E00504E004F4E004F4E004F4E
004F4E004E4E004E4E004D4E004D4E004D4E004C4D004C4D004B4D004B4D004B4D004A4D
004A4C004A4C004A4C00494C00494C00494C00494C00494C00494C00484C00484C00484C
00484C00484C00484C00484C00484C00484C00484C00484C00484C00484C00484C00494C
00494C00494C00494C00494C00494C004A4C004A4C004A4C004A4D004B4D004B4D004B4D
004C4D004C4D004D4E004D4E004D4E004E4E004E4E004F4E004F4E004F4E004F4E00504E
00504E00504E00514D00514D00514D00524D00524D00534C00534C007921007A1F007C1C
007D1A007E18007F1500811200820F00840B008608008804008900058C000A8E00109000
1693001E95002698002F9B00399F0045A30053A70062AB0075B0008AB600A4BD00C3C400
CDB000D79300E36C00F33500FF0000FF0000FF0000FF0000FF0000FF0000000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219FF0000
FF0000FF0000FF0000FF0000FF0000F23800E36E00D79500CCB100C2C400A3BC008AB600
74B00062AB0053A70045A300399F002F9B002698001E95001793001090000A8E00058C00
008A0000880300860700840B00830E008112008014007E17007D1A007C1C007B1E007A20
00534C00534C00524D00524D00524D00514D00514D00514D00504E00504E00504E004F4E
004F4E004F4E004F4E004E4E004E4E004E4E004D4E004D4E004C4D004C4D004C4D004B4D
004B4D004B4D004B4D004A4D004A4C004A4C004A4C004A4C00494C00494C00494C00494C
00494C00494C00494C00494C00494C00494C00494C00494C00494C00494C00494C00494C
004A4C004A4C004A4C004A4C004A4D004B4D004B4D004B4D004B4D004C4D004C4D004C4D
004D4E004D4E004E4E004E4E004E4E004F4E004F4E004F4E004F4E00504E00504E00504E
00514D00514D00514D00524D00524D00524D00534C00534C007A20007B1E007C1C007D1A
007E1700801400811200830E00840B008607008803008A00058C000A8E00109000179300
1E95002698002F9B00399F0045A30053A70062AB0074B00089B600A3BC00C2C400CCB100
D79500E36E00F23900FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
FF0000FF0000FF0000FF0000FF0000FF0000F13C00E27100D69600CCB200C1C400A2BC00
89B60074B00062AB0052A70045A300399F002F9B002698001E95001793001090000B8E00
058C00008A0000880300860700840B00830E008111008014007F17007D19007C1C007B1E
007A2000544C00534C00534C00524D00524D00514D00514D00514D00504D00504E00504E
00504E004F4E004F4E004F4E004F4E004E4E004E4E004E4E004D4E004D4E004D4E004C4D
004C4D004C4D004C4D004B4D004B4D004B4D004B4D004B4D004A4D004A4D004A4C004A4C
004A4C004A4C004A4C004A4C004A4C004A4C004A4C004A4C004A4C004A4C004A4D004A4D
004B4D004B4D004B4D004B4D004B4D004C4D004C4D004C4D004C4D004D4E004D4E004D4E
004E4E004E4E004E4E004F4E004F4E004F4E004F4E00504E00504E00504E00504D00514D
00514D00514D00524D00524D00534C00534C00544C007A20007B1E007C1C007D19007E17
00801400811100830E00840B008607008803008A00058C000B8E001090001793001E9500
2698002F9B00399F0045A30052A70062AB0074B00089B600A2BC00C1C400CCB200D69600
E27100F13C00FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219FF0000FF0000FF0000FF0000FF0000FF0000F04000E17300D59800CCB300BFC300
A1BC0088B60073B00061AB0052A70045A300399F002F9B002698001E9500179300119000
0B8E00068C00018A0000880300860700850A00830E008111008014007F16007D19007C1B
007B1D007A1F00792100534C00534C00524D00524D00524D00514D00514D00514D00504D
00504E00504E00504E004F4E004F4E004F4E004F4E004F4E004E4E004E4E004E4E004D4E
004D4E004D4E004D4E004C4D004C4D004C4D004C4D004B4D004B4D004B4D004B4D004B4D
004B4D004B4D004B4D004B4D004B4D004B4D004B4D004B4D004B4D004B4D004B4D004B4D
004B4D004C4D004C4D004C4D004C4D004D4E004D4E004D4E004D4E004E4E004E4E004E4E
004F4E004F4E004F4E004F4E004F4E00504E00504E00504E00504D00514D00514D00514D
00524D00524D00524D00534C00534C007921007A1F007B1D007C1B007D19007F16008014
00811100830E00850A008607008803018A00068C000B8E001190001793001E9500269800
2F9B00399F0045A30052A70061AB0073B00088B600A1BC00BFC300CCB300D59800E17300
F04000FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219FF0000FF0000FF0000FF0000FF0000FF0000EF4400E07600D59A00CBB400
BEC300A0BC0087B50073B00061AB0052A70045A300399F002F9B002698001E9600179300
1190000B8E00068C00018A0000880200860600850A00830D008211008013007F16007E19
007C1B007B1D007A1F00792100544C00534C00534C00524D00524D00524D00514D00514D
00514D00504D00504E00504E00504E004F4E004F4E004F4E004F4E004F4E004F4E004E4E
004E4E004E4E004E4E004D4E004D4E004D4E004D4E004C4D004C4D004C4D004C4D004C4D
004C4D004C4D004C4D004C4D004C4D004C4D004C4D004C4D004C4D004C4D004C4D004C4D
004C4D004D4E004D4E004D4E004D4E004E4E004E4E004E4E004E4E004F4E004F4E004F4E
004F4E004F4E004F4E00504E00504E00504E00504D00514D00514D00514D00524D00524D
00524D00534C00534C00544C007921007A1F007B1D007C1B007E19007F16008013008211
00830D00850A008606008802018A00068C000B8E001190001793001E96002698002F9B00
399F0045A30052A70061AB0073B00087B500A0BC00BEC300CBB400D59A00E07600EF4400
FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219FF0000FF0000FF0000FF0000FF0000FF0200ED4800E07900D49B00
CBB500BCC3009FBB0087B50072B00061AB0052A60045A200399F002F9B002798001F9600
1893001191000B8E00068C00018A0000880200870600850A00830D008210008013007F16
007E18007D1B007B1D007A1F00792100782200534C00534C00534D00524D00524D00524D
00514D00514D00514D00504D00504E00504E00504E00504E004F4E004F4E004F4E004F4E
004F4E004F4E004E4E004E4E004E4E004E4E004E4E004D4E004D4E004D4E004D4E004D4E
004D4E004D4E004D4E004D4E004D4E004D4E004D4E004D4E004D4E004D4E004D4E004D4E
004D4E004E4E004E4E004E4E004E4E004E4E004F4E004F4E004F4E004F4E004F4E004F4E
00504E00504E00504E00504E00504D00514D00514D00514D00524D00524D00524D00534D
00534C00534C007822007921007A1F007B1D007D1B007E18007F1600801300821000830D
00850A008706008802018A00068C000B8E001191001893001F96002798002F9B00399F00
45A20052A60061AB0072B00087B5009FBB00BCC300CBB500D49B00E07900ED4800FF0200
FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219FF0000FF0000FF0000FF0000FF0000FD0900EC4C00DF7B00
D49D00CAB600BBC2009EBB0086B50072B00060AB0052A60045A200399F002F9C00279800
1F96001893001191000C8E00068C00028A0000880200870600850900830D008210008113
007F15007E18007D1A007C1C007B1E007A2000792200544C00534C00534C00524D00524D
00524D00524D00514D00514D00514D00504D00504E00504E00504E00504E004F4E004F4E
004F4E004F4E004F4E004F4E004F4E004F4E004E4E004E4E004E4E004E4E004E4E004E4E
004E4E004E4E004E4E004E4E004E4E004E4E004E4E004E4E004E4E004E4E004E4E004E4E
004E4E004E4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E00504E00504E
00504E00504E00504D00514D00514D00514D00524D00524D00524D00524D00534C00534C
00544C007922007A20007B1E007C1C007D1A007E18007F1500811300821000830D008509
008706008802028A00068C000C8E001191001893001F96002798002F9C00399F0045A200
52A60060AB0072B00086B5009EBB00BBC200CAB600D49D00DF7B00EC4C00FD0900FF0000
FF0000FF0000FF0000FF0000000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FC0F00EB5000
DE7E00D39F00CAB800B9C2009DBB0085B50071AF0060AB0051A60045A200399F002F9C00
2798001F96001893001291000C8E00078C00028A0000890100870500850900840C00820F
008112007F15007E17007D1A007C1C007B1E007A2000792200544C00534C00534C00534C
00524D00524D00524D00524D00514D00514D00514D00514D00504E00504E00504E00504E
00504E004F4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E
004F4E004F4E004E4E004E4E004E4E004E4E004F4E004F4E004F4E004F4E004F4E004F4E
004F4E004F4E004F4E004F4E004F4E004F4E004F4E00504E00504E00504E00504E00504E
00514D00514D00514D00514D00524D00524D00524D00524D00534C00534C00534C00544C
007922007A20007B1E007C1C007D1A007E17007F1500811200820F00840C008509008705
008901028A00078C000C8E001291001893001F96002798002F9C00399F0045A20051A600
60AB0071AF0085B5009DBB00B9C200CAB800D39F00DE7E00EB5100FC0F00FF0000FF0000
FF0000FF0000FF0000000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000FA1600
EA5500DD8100D2A100C9B900B7C1009BBB0084B50070AF0060AB0051A60044A200399F00
2F9C002799001F96001893001291000C8F00078C00028B0000890100870500850900840C
00820F008112008015007E17007D19007C1B007B1D007A1F00792100782300544C00534C
00534C00534C00524D00524D00524D00524D00514D00514D00514D00514D00504D00504E
00504E00504E00504E00504E00504E004F4E004F4E004F4E004F4E004F4E004F4E004F4E
004F4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E
004F4E004F4E004F4E00504E00504E00504E00504E00504E00504E00504D00514D00514D
00514D00514D00524D00524D00524D00524D00534C00534C00534C00544C007823007921
007A1F007B1E007C1B007D19007E1700801500811200820F00840C008509008705008901
028B00078C000C8F001291001893001F96002799002F9C00399F0044A20051A6005FAB00
70AF0084B5009BBB00B7C100C9B900D2A100DD8100EA5500FA1600FF0000FF0000FF0000
FF0000FF0000FF0000000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000
F91C00E95900DC8400D2A300C9BA00B6C1009ABA0083B40070AF005FAA0051A60044A200
399F002F9C002799001F96001893001291000C8F00078D00038B00008901008705008508
00840C00820F008112008014007F17007D19007C1B007B1D007A1F00792100782200544C
00544C00534C00534C00534C00524D00524D00524D00524D00514D00514D00514D00514D
00514D00504D00504E00504E00504E00504E00504E00504E00504E00504E00504E004F4E
004F4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E004F4E00504E00504E00504E
00504E00504E00504E00504E00504E00504E00504D00514D00514D00514D00514D00514D
00524D00524D00524D00524D00534C00534C00534C00544C00544C007822007921007A1F
007B1D007C1B007D19007F1700801400811200820F00840C008508008705008901038B00
078D000C8F001291001893001F96002799002F9C00399F0044A20051A6005FAA0070AF00
83B4009ABA00B5C100C9BA00D2A300DC8400E95900F91C00FF0000FF0000FF0000FF0000
FF0000FF0000000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000
FF0000F72300E85D00DB8600D1A500C8BC00B4C10099BA0082B4006FAF005FAA0050A600
44A200399F002F9C002799001F96001893001291000D8F00078D00038B00008900008704
00860800840B00830E008111008014007F16007E19007D1B007B1D007A1F007920007922
00544C00544C00544C00534C00534C00534C00524D00524D00524D00524D00514D00514D
00514D00514D00514D00514D00514D00504D00504E00504E00504E00504E00504E00504E
00504E00504E00504E00504E00504E00504E00504E00504E00504E00504E00504E00504E
00504E00504E00504D00514D00514D00514D00514D00514D00514D00514D00524D00524D
00524D00524D00534C00534C00534C00544C00544C00544C007922007920007A1F007B1D
007D1B007E19007F1600801400811100830E00840B008608008704008900038B00078D00
0D8F001291001893001F96002799002F9C00399F0044A20050A6005FAA006FAF0082B400
99BA00B4C100C8BC00D1A500DB8600E85D00F72300FF0000FF0000FF0000FF0000FF0000
FF0000000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219FF0000FF0000FF0000FF0000
FF0000FF0000F62900E76100DA8900D0A700C8BD00B2C00097BA0081B4006EAF005EAA00
50A60044A200399F002F9C002799001F96001993001291000D8F00088D00038B00008900
00870400860800840B00830E008111008013007F16007E18007D1A007C1C007B1E007A20
00792100782300544C00544C00534C00534C00534C00534C00524D00524D00524D00524D
00524D00514D00514D00514D00514D00514D00514D00514D00514D00514D00504D00504D
00504D00504E00504E00504E00504E00504E00504E00504D00504D00504D00514D00514D
00514D00514D00514D00514D00514D00514D00514D00524D00524D00524D00524D00524D
00534C00534C00534C00534C00544C00544C007823007921007A20007B1E007C1C007D1A
007E18007F1600801300811100830E00840B008608008704008900038B00088D000D8F00
1291001993001F96002799002F9B00399F0044A20050A6005EAA006EAF0081B40097BA00
B2C000C8BD00D0A700DA8900E76100F62900FF0000FF0000FF0000FF0000FF0000FF0000
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219FF0000FF0000FF0000
FF0000FF0000FF0000F42F00E56500D98C00CFA900C7BE00B0C00096B90080B4006DAE00
5DAA0050A60043A200399F002F9B002799001F96001993001391000D8F00088D00038B00
00890000880400860700840B00830E008210008013007F15007E18007D1A007C1C007B1E
007A1F00792100782300544C00544C00544C00544C00534C00534C00534C00534D00524D
00524D00524D00524D00524D00524D00514D00514D00514D00514D00514D00514D00514D
00514D00514D00514D00514D00514D00514D00514D00514D00514D00514D00514D00514D
00514D00514D00514D00524D00524D00524D00524D00524D00524D00534D00534C00534C
00534C00544C00544C00544C00544C007823007921007A1F007B1E007C1C007D1A007E18
007F1500801300821000830E00840B008607008804008900038B00088D000D8F00139100
1993001F96002799002F9B00399F0043A20050A6005DAA006DAE0080B40096B900B0C000
C7BE00CFA900D98C00E56500F42F00FF0000FF0000FF0000FF0000FF0000FF0000000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219FF0000FF0000
FF0000FF0000FF0000FF0000F23500E46900D98F00CFAB00C6C000AEBF0095B9007FB300
6DAE005DAA004FA60043A200399F002F9B002799002096001993001391000D8F00088D00
048B0000890000880300860700850A00830D008210008113007F15007E17007D19007C1B
007B1D007A1F00792100782200782300544C00544C00544C00544C00534C00534C00534C
00534C00524D00524D00524D00524D00524D00524D00524D00524D00524D00514D00514D
00514D00514D00514D00514D00514D00514D00514D00514D00514D00514D00524D00524D
00524D00524D00524D00524D00524D00524D00534D00534C00534C00534C00534C00544C
00544C00544C00544C007823007822007921007A1F007B1D007C1B007D19007E17007F15
00811300821000830D00850A008607008803008900048B00088D000D8F00139100199300
2096002799002F9B00399F0043A2004FA6005DAA006DAE007FB30094B900AEBF00C6C000
CFAB00D98F00E46900F23500FF0000FF0000FF0000FF0000FF0000FF0000000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219FF0000
FF0000FF0000FF0000FF0000FF0000F13B00E36D00D89200CEAD00C6C100ACBF0093B800
7EB3006CAE005CAA004FA60043A200399F002F9B002799002096001994001391000E8F00
098D00048B0000890000880300860700850A00830D008210008112008015007E17007D19
007C1B007B1D007A1E007A2000792200782300554B00544C00544C00544C00544C00534C
00534C00534C00534C00534C00534D00524D00524D00524D00524D00524D00524D00524D
00524D00524D00524D00524D00524D00524D00524D00524D00524D00524D00524D00524D
00524D00524D00524D00534D00534C00534C00534C00534C00534C00544C00544C00544C
00544C00554B007823007922007A20007A1E007B1D007C1B007D19007E17008015008112
00821000830D00850A008607008803008900048B00098D000E8F00139100199400209600
2799002F9B00399F0043A2004FA6005CAA006CAE007EB30093B800ACBF00C6C100CEAD00
D89200E36D00F13B00FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
FF0000FF0000FF0000FF0000FF0000FF0000EF4100E27100D79400CDAE00C5C300AABE00
92B8007DB3006BAE005CA9004EA50043A200389E002F9B00279900209600199400139100
0E8F00098D00048B00008A0000880300860600850900840C00820F008112008014007F16
007E18007D1A007C1C007B1E007A2000792100782200554B00554B00544C00544C00544C
00544C00544C00534C00534C00534C00534C00534C00534C00534D00534D00524D00524D
00524D00524D00524D00524D00524D00524D00524D00524D00524D00524D00534D00534D
00534C00534C00534C00534C00534C00534C00544C00544C00544C00544C00544C00554B
00554B007822007921007A20007B1E007C1C007D1A007E18007F1600801400811200820F
00840C008509008606008803008A00048B00098D000E8F00139100199400209600279900
2F9B00389E0043A2004EA5005CA9006BAE007DB30092B800AABE00C5C300CDAF00D79400
E27100EF4100FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
FF0000FF0000FF0000FF0000FF0000FF0000FE0600EE4700E17500D69700CDB000C5C400
A8BE0090B8007CB2006AAE005BA9004EA50042A200389E002F9B00279900209600199400
1391000E8F00098D00058C00018A0000880200870600850900840C00820F008111008014
007F16007E18007D1A007C1C007B1D007A1F00792100792200782300554B00554B00554B
00544C00544C00544C00544C00544C00534C00534C00534C00534C00534C00534C00534C
00534C00534C00534C00534C00534C00534C00534C00534C00534C00534C00534C00534C
00534C00534C00534C00544C00544C00544C00544C00544C00554B00554B00554B007823
007922007921007A1F007B1D007C1C007D1A007E18007F1600801400811100820F00840C
008509008706008802008A00058C00098D000E8F001391001994002096002799002F9B00
389E0042A2004EA5005BA9006AAE007CB20090B800A8BE00C5C400CDB000D69700E17500
EE4700FE0600FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219FF0000FF0000FF0000FF0000FF0000FF0000FC0E00EC4D00DF7900D59A00CCB200
C3C400A6BD008FB7007BB20069AD005AA9004EA50042A200389E002F9B00279900209600
1994001491000E8F00098D00058C00018A0000880200870500850900840C00830E008111
008013007F15007E17007D19007C1B007B1D007A1F007A2000792100782300554B00554B
00554B00554B00554C00544C00544C00544C00544C00544C00544C00544C00534C00534C
00534C00534C00534C00534C00534C00534C00534C00534C00534C00534C00544C00544C
00544C00544C00544C00544C00544C00554C00554B00554B00554B00554B007823007921
007A20007A1F007B1D007C1B007D19007E18007F1500801300811100830E00840C008509
008705008802018A00058C00098D000E8F001491001994002096002799002F9B00389E00
42A2004DA5005AA90069AD007BB2008FB700A6BD00C3C400CCB200D59A00DF7900EC4D00
FC0E00FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219FF0000FF0000FF0000FF0000FF0000FF0000FA1700EB5300DE7D00D49D00
CBB400C0C300A4BD008DB70079B20068AD005AA9004DA50042A200389E002F9B00279900
2096001A94001492000E8F000A8E00058C00018A0000880200870500860800840B00830E
008210008113007F15007E17007D19007C1B007C1C007B1E007A1F007921007822007823
00564B00554B00554B00554B00554B00554B00544C00544C00544C00544C00544C00544C
00544C00544C00544C00544C00544C00544C00544C00544C00544C00544C00544C00544C
00544C00544C00554B00554B00554B00554B00554B00564B007823007822007921007A1F
007B1E007C1C007C1B007D19007E17007F1500811300821000830E00840B008608008705
008802018A00058C000A8E000E8F001492001A94002096002799002F9B00389E0042A200
4DA5005AA90068AD0079B2008DB700A4BD00C0C300CBB400D49D00DE7D00EB5300FA1700
FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000F81F00E95800DD8100
D39F00CAB600BDC300A2BC008CB70078B10068AD0059A9004DA50042A100389E002F9B00
2799002096001A94001492000F90000A8E00068C00028A0000890100870500860800840B
00830D008210008112008014007F16007E18007D1A007C1C007B1D007A1F007920007922
00782300564B00564B00554B00554B00554B00554B00554B00554B00554B00554B00554C
00544C00544C00544C00544C00544C00544C00544C00544C00554C00554B00554B00554B
00554B00554B00554B00554B00554B00564B00564B007823007922007920007A1F007B1D
007C1C007D1A007E18007F1600801400811200821000830D00840B008608008705008901
028A00068C000A8E000F90001492001A94002096002799002F9B00389E0042A1004DA500
59A90068AD0078B1008CB700A2BC00BDC300CAB600D39F00DD8100E95800F81F00FF0000
FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000F62700E85E00
DC8500D2A200C9B800BBC200A0BC008AB60077B10067AD0059A8004CA50041A100389E00
2F9B002799002096001A94001492000F90000A8E00068C00028A00008901008704008607
00850A00830D00820F008112008014007F16007E18007D1A007C1B007B1D007B1E007A20
00792100782200564B00564B00564B00564B00564B00554B00554B00554B00554B00554B
00554B00554B00554B00554B00554B00554B00554B00554B00554B00554B00554B00554B
00554B00564B00564B00564B00564B00564B007822007921007A20007B1E007B1D007C1B
007D1A007E18007F1600801400811200820F00830D00850A008607008704008901028A00
068C000A8E000F90001492001A94002096002799002F9B00389E0041A1004CA50059A800
67AD0077B1008AB600A0BC00BBC200C9B800D2A200DC8500E85E00F62700FF0000FF0000
FF0000FF0000FF0000FF0000000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000F42F00
E66300DB8800D1A500C9BA00B8C2009EBB0089B60076B10066AC0058A8004CA50041A100
379E002F9B002799002096001A94001492000F90000B8E00068C00028B00008900008804
00860700850A00840C00820F008111008013007F15007E17007D19007D1B007C1C007B1E
007A1F00792000792100782300574A00564A00564B00564B00564B00564B00564B00564B
00564B00564B00554B00554B00554B00554B00564B00564B00564B00564B00564B00564B
00564B00564B00564A00574A007823007921007920007A1F007B1E007C1C007D1B007D19
007E17007F1500801300811100820F00840C00850A008607008804008900028B00068C00
0B8E000F90001492001A94002096002799002F9B00379E0041A1004CA50058A80066AC00
76B10089B6009EBB00B8C200C9BA00D1A500DB8800E66300F42F00FF0000FF0000FF0000
FF0000FF0000FF0000000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000
F23700E56800D98C00D0A700C8BC00B6C1009CBB0087B50075B00065AC0057A8004BA400
41A100379E002F9B002799002096001A94001592001090000B8E00078C00038B00008900
00880300860600850900840C00830E008211008113008015007F17007E18007D1A007C1C
007B1D007B1E007A2000792100792200574A00574A00574A00564A00564A00564B00564B
00564B00564B00564B00564B00564B00564B00564B00564B00564B00564B00564A00564A
00574A00574A00574A007922007921007A20007B1E007B1D007C1C007D1A007E18007F17
00801500811300821100830E00840C008509008606008803008900038B00078C000B8E00
1090001592001A94002096002799002F9B00379E0041A1004BA40057A80065AC0075B000
87B5009CBB00B6C100C8BC00D0A700D98C00E56800F23700FF0000FF0000FF0000FF0000
FF0000FF0000000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000
FF0000F03E00E36D00D89000CFAA00C7BE00B3C0009ABA0085B50074B00064AC0057A800
4BA40040A100379E002F9B002799002196001A94001592001090000B8E00078C00038B00
00890000880300870600850900840B00830E008210008112008014007F16007E18007D19
007C1B007C1C007B1E007A1F007A2000792100782200574A00574A00574A00574A00574A
00574A00574A00574A00574A00574A00574A00574A00574A00574A00574A00574A00574A
00574A007822007921007A20007A1F007B1E007C1C007C1B007D19007E18007F16008014
00811200821000830E00840B008509008706008803008900038B00078C000B8E00109000
1592001A94002196002799002F9B00379E0040A1004BA40057A80064AC0074B00085B500
9ABA00B3C000C7BE00CFAA00D89000E36D00F03E00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000
FF0000FE0700EE4500E27200D79300CEAC00C6C000B1C00098BA0084B50072B00063AC00
56A8004AA40040A100379E002F9B002799002196001B94001592001090000C8E00078D00
038B00008A0000880200870500860800840B00830D008210008112008014007F15007E17
007E19007D1A007C1C007B1D007B1E007A1F00792000792100584A00584A00574A00574A
00574A00574A00574A00574A00574A00574A00574A00574A00574A00574A00584A00584A
007921007920007A1F007B1E007B1D007C1C007D1A007E19007E17007F15008014008112
00821000830D00840B008608008705008802008A00038B00078D000C8E00109000159200
1B94002196002799002F9B00379E0040A1004AA40056A80063AC0072B00084B50098BA00
B1C000C6C000CEAC00D79300E27200EE4500FE0700FF0000FF0000FF0000FF0000FF0000
FF0000000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219FF0000FF0000FF0000FF0000
FF0000FF0000FB1100EC4C00E07700D69600CDAF00C6C100AEBF0096B90082B40071B000
62AB0055A8004AA40040A100379E002F9B002799002196001B94001592001090000C8E00
088D00048B00008A0000880200870500860800850A00830D00820F008111008013008015
007F16007E18007D1A007C1B007C1C007B1D007A1F007A20007921005849005849005849
00584900584A00584A00584A00584A00584A00584A005849005849005849005849007921
007A20007A1F007B1D007C1C007C1B007D1A007E18007F1600801500801300811100820F
00830D00850A008608008705008802008A00048B00088D000C8E001090001592001B9400
2196002799002F9B00379E0040A1004AA40055A80062AB0071B00082B40096B900AEBF00
C6C100CDAF00D69600E07700EC4C00FB1100FF0000FF0000FF0000FF0000FF0000FF0000
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219FF0000FF0000FF0000
FF0000FF0000FF0000F91B00EB5300DF7B00D59A00CCB100C5C300ACBF0095B90081B400
70AF0062AB0055A70049A4003FA100379E002F9B002799002196001B9400169200119000
0C8F00088D00048B00018A0000890100870400860700850A00840C00830E008210008112
008014007F16007E17007E19007D1A007C1B007B1D007B1E007A1F007A20007921005949
005949005849005849005849005849005849005849005949005949007921007A20007A1F
007B1E007B1D007C1B007D1A007E19007E17007F1600801400811200821000830E00840C
00850A008607008704008901018A00048B00088D000C8F001190001692001B9400219600
2799002F9B00379E003FA10049A40055A70062AB0070AF0081B40095B900ABBF00C5C300
CCB100D59A00DF7B00EB5300F91B00FF0000FF0000FF0000FF0000FF0000FF0000000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219FF0000FF0000
FF0000FF0000FF0000FF0000F72400E95900DD8000D49D00CBB300C4C400A9BE0093B800
80B3006FAF0061AB0054A70049A4003FA100369E002F9B002799002196001B9400169200
1191000D8F00098D00058C00018A0000890100880400860600850900840B00830E008210
008112008013007F15007F17007E18007D19007D1B007C1C007B1D007B1E007A1F007A20
005949005949005949005949005949005949005949005949007A20007A1F007B1E007B1D
007C1C007D1B007D19007E18007F17007F1500801300811200821000830E00840B008509
008606008704008901018A00058C00098D000D8F001191001692001B9400219600279900
2F9B00369E003FA10049A40054A70061AB006FAF0080B30093B800A9BE00C4C400CBB300
D49D00DD8000E95900F72400FF0000FF0000FF0000FF0000FF0000FF0000000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219FF0000FF0000
FF0000FF0000FF0000FF0000FF0000F42D00E75F00DC8400D3A000CAB600C0C400A7BD00
91B8007EB3006EAF0060AB0054A70049A4003FA100369E002F9B002899002197001B9400
1692001191000D8F00098D00058C00028A0000890000880300870600850800840B00830D
00820F008111008113008014007F16007E17007E18007D1A007C1B007C1C007B1D007B1E
007A1F007A1F005A48005A48005A48005A48007A1F007A1F007B1E007B1D007C1C007C1B
007D1A007E18007E17007F1600801400811300811100820F00830D00840B008508008706
008803008900028A00058C00098D000D8F001191001692001B94002197002899002F9B00
369E003FA10049A40054A70060AB006EAF007EB30091B800A7BD00C0C300CAB600D3A000
DC8400E75F00F42D00FF0000FF0000FF0000FF0000FF0000FF0000FF0000000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219FF0000
FF0000FF0000FF0000FF0000FF0000FF0000F23600E56500DB8800D1A300CAB800BDC300
A4BD008FB7007DB3006DAE005FAA0053A70048A4003FA100369E002F9B00289900219700
1C95001793001291000E8F000A8E00068C00028B0000890000880300870500860800850A
00840C00830E008210008112008013007F15007F16007E18007D19007D1A007C1B007C1C
007B1D007B1E007A1E005A48005A48007A1E007B1E007B1D007C1C007C1B007D1A007D19
007E18007F16007F1500801300811200821000830E00840C00850A008608008705008803
008900028B00068C000A8E000E8F001291001793001C95002197002899002F9B00369E00
3FA10048A40053A7005FAA006DAE007DB3008FB700A4BD00BDC300CAB800D1A300DB8800
E56500F23600FF0000FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
FF0000FF0000FF0000FF0000FF0000FF0000FF0000F03E00E46B00D98D00D0A600C9BA00
BAC200A2BC008DB7007BB2006CAE005EAA0052A70048A3003FA000369E002F9B00289900
2297001C95001793001291000E8F000A8E00068C00038B00008A00008802008705008607
00850900840B00830D00820F008111008112008014007F15007F17007E18007D19007D1A
007C1B007C1C007C1D007B1D007B1D007C1D007C1C007C1B007D1A007D19007E18007F17
007F1500801400811200811100820F00830D00840B008509008607008705008802008A00
038B00068C000A8E000E8F001291001793001C95002297002899002F9B00369E003FA000
48A30052A7005EAA006CAE007BB2008DB700A2BC00BAC200C9BA00D0A600D98D00E46B00
F03E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219FF0000FF0000FF0000FF0000FF0000FF0000FD0B00EE4600E27100D89100CFA900
C8BC00B7C100A0BC008BB6007AB2006BAE005EAA0052A60048A3003EA000369E002F9B00
2899002297001C95001793001391000E8F000B8E00078C00048B00018A00008901008704
00860600850800840B00840D00830E008210008112008013008014007F16007F17007E18
007D19007D1A329C00329C00329C00329C00007D1A007D19007E18007F17007F16008014
00801300811200821000830E00840D00840B008508008606008704008901018A00048B00
078C000B8E000E8F001391001793001C95002297002899002F9B00369E003EA00048A300
52A6005EAA006BAE007AB2008BB600A0BC00B7C100C8BC00CFA900D89100E27100EE4600
FD0B00FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219FF0000FF0000FF0000FF0000FF0000FF0000FA1600EC4E00E07600D79400
CEAC00C7BE00B4C1009DBB008AB60079B2006AAD005DAA0051A60047A3003EA000369E00
2F9B002899002297001D95001893001391000F90000B8E00088D00048B00018A00008900
00880300870500860800850A00840C00830D00820F008211008112008013008015007F16
007F17369E00369E00369E00369E00369E00369E00007F17007F16008015008013008112
00821100820F00830D00840C00850A008608008705008803008900018A00048B00088D00
0B8E000F90001391001893001D95002297002899002F9B00369E003EA00047A30051A600
5DAA006AAD0079B2008AB6009DBB00B4C100C7BE00CEAC00D79400E07600EC4E00FA1600
FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219FF0000FF0000FF0000FF0000FF0000FF0000FF0000F82100EA5500DF7B00
D59800CDAF00C6C000B2C0009BBA0088B60077B10069AD005CAA0051A60047A3003EA000
369E002F9B002899002297001D95001893001492001090000C8E00088D00058C00028A00
00890000880200870500860700850900840B00840C00830E0082100081110081123B9F00
3B9F003A9F003A9F003A9F003A9F003A9F003A9F003B9F003B9F00008112008111008210
00830E00840C00840B008509008607008705008802008900028A00058C00088D000C8E00
1090001491001893001D95002297002899002F9B00369E003EA00047A30051A6005CAA00
69AD0077B10088B6009BBA00B2C000C6C000CDAF00D59800DF7B00EA5500F82100FF0000
FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000FF0000F52B00E85C00
DD8000D49C00CCB100C5C200AFBF0099BA0086B50076B10068AD005BA90050A60047A300
3EA000369E002F9B002999002397001D95001993001492001090000C8F00098D00068C00
038B00008A0000890100880400870600860800850A00840B00830D00830E41A10040A100
3FA1003FA1003FA1003EA0003EA0003FA1003FA1003FA10040A10041A10000830E00830D
00840B00850A008608008706008804008901008A00038B00068C00098D000C8F00109000
1492001993001D95002397002999002F9B00369E003EA00047A30050A6005BA90068AD00
76B10086B50099BA00AFBF00C5C200CCB100D49C00DD8000E85C00F52B00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000FF0000F33400
E66200DC8500D39F00CBB400C5C400ACBF0097B90085B50075B00067AD005BA90050A600
46A3003EA000369E002F9B002999002397001E95001994001592001190000D8F000A8E00
078C00048B00018A0000890000880300870500860700850900850A47A30046A30045A200
44A20044A20043A20043A20043A20043A20044A20044A20045A20046A30047A30000850A
008509008607008705008803008900018A00048B00078C000A8E000D8F00119000159200
1994001E95002397002999002F9B00369E003EA00046A30050A6005BA90067AD0075B000
85B50097B900ACBF00C5C400CBB400D39F00DC8500E66200F33400FF0000FF0000FF0000
FF0000FF0000FF0000FF0000000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000FF0200
F03D00E46900DA8900D2A200CAB600C2C400A9BE0095B90083B40074B00066AC005AA900
50A60046A3003EA000369E002F9B002999002397001E96001A94001592001191000E8F00
0A8E00078D00058B00028A000089000088020087044FA5004DA5004CA5004BA4004AA400
49A40048A40048A40048A30048A30048A40048A40049A4004AA4004BA4004CA5004DA500
4FA500008704008802008900028A00058B00078D000A8E000E8F001191001592001A9400
1E95002397002999002F9B00369E003EA00046A30050A6005AA90066AC0074B00083B400
95B900A9BE00C2C400CAB600D2A200DA8900E46900F03D00FF0200FF0000FF0000FF0000
FF0000FF0000FF0000000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000
FC0E00EE4600E36F00D98E00D1A600C9B900BEC300A7BD0093B80082B40072B00065AC00
5AA9004FA60046A3003EA000369E00309C002999002498001F96001A9400169200129100
0F90000B8E00088D00058C00038B00008A0056A80054A70052A70051A60050A6004FA600
4EA5004EA5004DA5004DA5004DA5004DA5004EA5004EA5004FA60050A60051A60052A700
54A70056A800008A00038B00058C00088D000B8E000F90001291001692001A94001F9600
249800299900309C00369E003EA00046A3004FA6005AA90065AC0072B00081B40093B800
A7BD00BEC300C9B900D1A600D98E00E36F00EE4600FC0E00FF0000FF0000FF0000FF0000
FF0000FF0000000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000
FF0000F91A00EC4E00E17400D79200CFA900C8BB00BBC200A4BD0091B80080B40071B000
64AC0059A9004FA60046A3003EA000369E00309C002A9A002498001F96001B9400179300
1391000F90000C8F00098D0060AB005EAA005CA9005AA90058A80056A80055A70054A700
53A70053A70052A70052A70052A70052A70053A70053A70054A70055A70056A80058A800
5AA9005CA9005EAA0060AB00098D000C8F000F90001391001793001B94001F9600249800
2A9A00309C00369E003EA00046A3004FA60059A90064AC0071B00080B40091B800A4BD00
BBC200C8BB00CFA900D79200E17400EC4E00F91A00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000
FF0000FF0000F72500EA5500DF7A00D69600CEAC00C8BD00B8C200A2BC008FB7007FB300
70AF0064AC0059A8004FA60046A3003EA000379E00309C002A9A002598002096001C9400
1793001492001090006AAD0067AD0064AC0062AB0060AB005EAA005CAA005BA9005AA900
59A90058A80058A80058A80058A80058A80058A80059A9005AA9005BA9005CAA005EAA00
60AB0062AB0064AC0067AD006AAD001090001492001793001C94002096002598002A9A00
309C00379E003EA00046A3004FA60059A80064AC0070AF007FB3008FB700A2BC00B8C200
C8BD00CEAC00D69600DF7A00EA5500F72500FF0000FF0000FF0000FF0000FF0000FF0000
FF0000000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219FF0000FF0000FF0000FF0000
FF0000FF0000FF0000F42F00E85D00DE7F00D59A00CDAE00C7BF00B5C100A0BC008DB700
7DB3006FAF0063AC0058A8004EA50046A3003EA000379E00319C002B9A00269800219600
1C950018930074B00071AF006DAE006AAE0068AD0066AC0064AC0062AB0061AB005FAB00
5FAA005EAA005DAA005DAA005DAA005DAA005EAA005FAA005FAB0061AB0062AB0064AC00
66AC0068AD006AAE006DAE0071AF0074B0001893001C95002196002698002B9A00319C00
379E003EA00046A3004EA50058A80063AC006FAF007DB3008DB700A0BC00B5C100C7BF00
CDAE00D59A00DE7F00E85D00F42F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219FF0000FF0000FF0000
FF0000FF0000FF0000FF0000F23900E66400DC8400D49D00CCB100C6C100B2C0009EBB00
8CB7007CB2006EAF0062AB0058A8004EA50046A3003EA000379E00319C002B9A00269800
85B50080B3007CB20078B10074B00071B0006EAF006CAE006AAE0068AD0067AD0065AC00
64AC0064AC0063AC0063AC0063AC0063AC0064AC0064AC0065AC0067AD0068AD006AAE00
6CAE006EAF0071B00074B00078B1007CB20080B30085B5002698002B9A00319C00379E00
3EA00046A3004EA50058A80062AB006EAF007CB2008CB7009EBB00B2C000C6C100CCB100
D49D00DC8400E66400F23900FF0000FF0000FF0000FF0000FF0000FF0000FF0000000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FD0B00EF4200E46A00DA8900D2A100CBB400C5C300B0C000
9BBB008AB6007BB2006EAF0062AB0058A8004EA50046A3003EA000389E00329C0093B800
8DB70088B60083B4007FB3007CB20078B10075B10073B00071AF006FAF006DAE006CAE00
6BAE006AAD0069AD0069AD0069AD0069AD006AAD006BAE006CAE006DAE006FAF0071AF00
73B00075B10078B1007CB2007FB30083B40088B6008DB70093B800319C00389E003EA000
46A3004EA50058A80062AB006EAF007BB2008AB6009BBB00AFBF00C5C300CBB400D2A100
DA8900E46A00EF4200FD0B00FF0000FF0000FF0000FF0000FF0000FF0000FF0000000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FA1700ED4A00E27000D98D00D1A400CAB600C4C400
ADBF0099BA0089B6007AB2006DAE0061AB0057A8004EA50046A300AABE00A3BC009CBB00
96B90090B8008BB70087B50083B40080B3007DB3007AB20077B10075B10074B00072B000
71AF0070AF0070AF006FAF006FAF0070AF0070AF0071AF0072B00074B00075B10077B100
7AB2007DB30080B30083B40087B5008BB70090B80096B9009CBB00A3BC00AABE0046A300
4EA50057A80061AB006DAE007AB20089B60099BA00ADBF00C4C400CAB600D1A400D98D00
E27000ED4A00FA1800FF0000FF0000FF0000FF0000FF0000FF0000FF0000000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219FF0000
FF0000FF0000FF0000FF0000FF0000FF0000F72300EB5200E07600D89200D0A700C9B900
C0C300AABE0098BA0087B50079B2006CAE0061AB0057A800BFC300B6C100ADBF00A6BD00
9FBC0099BA0094B9008FB8008BB60087B50084B50081B4007FB3007CB3007BB20079B200
78B10077B10076B10076B10076B10076B10077B10078B10079B2007BB2007CB3007FB300
81B40084B50087B5008BB6008FB80094B90099BA009FBC00A6BD00ADBF00B6C100BFC300
57A80061AB006CAE0079B20087B50097BA00AABE00C0C300C9B900D0A700D89200E07600
EB5200F72300FF0000FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
FF0000FF0000FF0000FF0000FF0000FF0000FF0000F42E00E95A00DF7C00D69600CFAA00
C8BB00BDC300A8BE0096B90086B50078B1006CAE00C9BB00C6C100C1C400B8C200B0C000
A9BE00A3BC009DBB0098BA0093B9008FB8008CB70089B60086B50084B40082B40080B400
7FB3007EB3007DB3007DB3007DB3007DB3007EB3007FB30080B40082B40084B40086B500
89B6008CB7008FB80093B90098BA009DBB00A3BC00A9BE00B0C000B8C200C1C400C6C100
C9BB006CAE0078B10086B50096B900A8BE00BDC300C8BB00CFAA00D69600DF7C00E95A00
F42E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F23800E76100DD8100D59900
CEAD00C8BD00BAC200A6BD0094B900D2A100CFAA00CCB200C9B900C7BF00C4C400BBC200
B4C100ADBF00A7BD00A1BC009CBB0098BA0094B90091B8008EB7008BB60089B60087B500
86B50085B50084B50084B50084B50084B50085B50086B50087B50089B6008BB6008EB700
91B80094B90098BA009CBB00A1BC00A7BD00ADBF00B4C100BBC200C4C400C7BF00C9B900
CCB200CFAA00D2A10094B900A6BD00BAC200C8BD00CEAD00D59A00DD8100E76100F23800
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219FF0000FF0000FF0000FF0000FF0000FF0000FF0000FC0D00EF4100E56800DB8600
D49D00CDB000C7BF00B7C100DA8A00D69600D2A100CFAA00CCB100CAB800C7BE00C5C300
BFC300B7C100B1C000ABBE00A5BD00A1BC009DBB0099BA0096B90093B90091B8008FB700
8EB7008DB7008CB7008CB7008CB7008CB7008DB7008EB7008FB70091B80093B90096B900
99BA009DBB00A1BC00A5BD00ABBE00B1C000B7C100BFC300C5C300C7BE00CAB800CCB100
CFAA00D2A100D69600DA8A00B7C100C7BF00CDB000D49D00DB8600E56800EF4100FC0D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219FF0000FF0000FF0000FF0000FF0000FF0000FF0000F91A00ED4A00E36E00
DA8A00D2A100E95900E36C00DE7D00DA8A00D69600D3A000D0A800CDB000CAB600C8BC00
C6C100C2C400BBC200B5C100AFBF00AABE00A6BD00A2BC009EBB009CBB0099BA0097BA00
96B90094B90094B90093B90093B90094B90094B90096B90097BA0099BA009CBB009EBB00
A2BC00A6BD00AABE00AFBF00B5C100BBC200C2C400C6C100C8BC00CAB600CDB000D0A800
D3A000D69600DA8A00DE7D00E36C00E95900D2A100DA8A00E36E00ED4A00F91A00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F62500EB5200
E17400F52900EE4400E85B00E36D00DE7D00DA8A00D69500D39F00D0A700CDAE00CBB500
C9BA00C7BF00C5C300BFC300B9C200B4C100AFBF00ABBE00A7BE00A4BD00A2BC00A0BC00
9EBB009DBB009CBB009BBB009BBB009CBB009DBB009EBB00A0BC00A2BC00A4BD00A7BE00
ABBE00AFBF00B4C100B9C200BFC300C5C300C7BF00C9BA00CBB500CDAE00D0A700D39F00
D69500DA8A00DE7D00E36D00E85B00EE4400F52900E17400EB5200F62500FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F43000
FF0000FC0D00F52D00EE4700E85C00E36E00DE7D00DA8900D79400D39E00D1A600CEAD00
CCB300C9B800C8BD00C6C100C4C400BEC300B9C200B5C100B1C000ADBF00ABBE00A8BE00
A7BD00A5BD00A4BD00A4BD00A4BD00A4BD00A5BD00A7BD00A8BE00ABBE00ADBF00B1C000
B5C100B9C200BEC300C4C400C6C100C8BD00C9B800CCB300CEAD00D1A600D39E00D79400
DA8900DE7D00E36E00E85C00EE4700F52D00FC0D00FF0000F43000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FB1100F43000ED4800E85D00E36E00DE7C00DB8900D79300D49C00D1A400
CFAB00CCB100CAB600C9BB00C7BE00C5C200C4C400BFC300BBC200B7C100B4C100B2C000
B0C000AEBF00ADBF00ADBF00ADBF00ADBF00AEBF00B0C000B2C000B4C100B7C100BBC200
BFC300C4C400C5C200C7BE00C9BB00CAB600CCB100CFAB00D1A400D49C00D79300DB8900
DE7C00E36E00E85D00ED4800F43000FB1100FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FA1500F33200ED4A00E85D00E36E00DF7C00DB8800D79200D49B00
D2A200CFA900CDAE00CBB300CAB800C8BC00C7BF00C6C200C5C400C1C400BEC300BBC200
B9C200B8C100B7C100B6C100B6C100B7C100B8C100B9C200BBC200BEC300C1C400C5C400
C6C200C7BF00C8BC00CAB800CBB400CDAF00CFA900D2A200D49B00D79200DB8800DF7C00
E36E00E85D00ED4A00F33200FA1500FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000F91900F33500ED4B00E75E00E36E00DF7B00DB8600D89000
D59900D3A000D0A600CEAC00CCB100CBB500C9B900C8BC00C7BE00C6C100C5C200C5C400
C3C400C1C400C0C300C0C300C0C300C0C300C1C400C3C400C5C400C5C200C6C100C7BE00
C8BC00C9B900CBB500CCB100CEAC00D0A600D3A000D59900D89000DB8600DF7B00E36E00
E75E00ED4B00F33500F91900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000F91C00F23700EC4C00E75E00E36D00DF7A00DC8500
D98F00D69700D39E00D1A400CFA900CEAE00CCB200CBB500CAB800C9BB00C8BD00C7BE00
C6C000C6C100C6C100C6C200C6C200C6C100C6C100C6C000C7BE00C8BD00C9BB00CAB800
CBB500CCB200CEAE00CFA900D1A400D39E00D69700D98F00DC8500DF7A00E36D00E75E00
EC4C00F23700F91C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219001F35001F36FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0100F81F00F23800EC4D00E75E00E36C00E07900
DC8300D98C00D79400D49B00D2A100D0A600CFAA00CDAE00CCB100CBB400CAB600C9B800
C9BA00C8BB00C8BB00C8BC00C8BC00C8BB00C8BB00C9BA00C9B800CAB600CBB400CCB100
CDAE00CFAA00D0A600D2A100D49B00D79400D98C00DC8300E07900E36C00E75E00EC4D00
F23800F81F00FF0100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000001F36001F35000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219001E35001F35001F36001F36FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FE0500F72200F13900EC4D00E85D00E46B00
E07700DD8100DA8A00D89200D59800D39E00D2A300D0A700CFAA00CEAD00CDB000CCB200
CBB300CBB400CBB500CBB600CBB600CBB500CBB400CBB300CCB200CDB000CEAD00CFAA00
D0A700D2A300D39E00D59800D89200DA8A00DD8100E07700E46B00E85D00EC4D00F13900
F72200FE0500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000001F36001F36001F35001E35000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219001E35001F35001F36001F36002036002036FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FD0800F72400F13A00EC4D00E85D00
E46A00E17500DE7F00DB8700D98F00D69500D59A00D39F00D2A300D0A600CFA900CFAB00
CEAD00CEAE00CDAF00CDAF00CDAF00CDAF00CEAE00CEAD00CFAB00CFA900D0A600D2A300
D39F00D59A00D69500D98F00DB8700DE7F00E17500E46A00E85D00EC4D00F13A00F72400
FD0800FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
002036002036001F36001F36001F35001E35000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
001E35001E35001F35001F36001F36002036002036002137002137FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FD0B00F72500F13A00EC4C00
E85B00E56800E17300DE7C00DC8400DA8B00D89100D69600D59A00D39E00D2A100D1A300
D1A500D0A700D0A800D0A800D0A800D0A800D0A700D1A500D1A300D2A100D39E00D59A00
D69600D89100DA8B00DC8400DE7C00E17300E56800E85B00EC4C00F13A00F72500FD0B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000002137
002137002036002036001F36001F36001F35001E35001E35000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219001E35
001E35001E35001F35001F36002036002036002037002137002137FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FC0D00F62600F13A00
ED4B00E95A00E56600E27000DF7900DD8100DB8700D98D00D89200D69600D59900D49C00
D39E00D39F00D3A000D2A100D2A100D3A000D39F00D39E00D49C00D59900D69600D89200
D98D00DB8700DD8100DF7900E27000E56600E95A00ED4B00F13A00F62600FC0D00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000002137
002137002037002036002036001F36001F35001E35001E35001E35000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219001E35001E35
001E35001F35001F36002036002036002037002137002137002237002238FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FC0F00F62600
F13A00ED4A00E95800E66300E36D00E07600DE7D00DC8300DB8800D98D00D89000D79300
D69500D69700D59800D59900D59900D59800D69700D69500D79300D89000D98D00DB8800
DC8300DE7D00E07600E36D00E66300E95800ED4A00F13A00F62600FC0F00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000002238002237
002137002137002037002036002036001F36001F35001E35001E35001E35000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219001D34001E35001E35001E35
001F35001F36002036002036002036002137002137002237002238002338002338FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FC1000
F62600F23900ED4800EA5500E76000E46A00E27200E07900DE7E00DC8300DB8700DA8A00
D98D00D98F00D89000D89000D89000D89000D98F00D98D00DA8A00DB8700DC8300DE7E00
E07900E27200E46A00E76000EA5500ED4800F23900F62600FC1000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000002338002338002238
002237002137002137002036002036002036001F36001F35001E35001E35001E35001D34
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219001D34001E35001E35001E35001F35
001F36001F36002036002036002137002137002237002238002338002338002439FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FB1100F62600F23700EE4600EB5200E85D00E56600E36D00E17400DF7900DE7D00DD8100
DC8300DC8600DB8700DB8700DB8700DB8700DC8600DC8400DD8100DE7D00DF7900E17400
E36D00E56600E85D00EB5200EE4600F23700F62600FB1100FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000002439002338002338
002238002237002137002137002036002036001F36001F36001F35001E35001E35001E35
001D34000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219001D34001D34001E35001E35001E35001F35001F36
001F36002036002036002137002137002137002238002238002338002338002439002539
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FB1100F72500F23500EF4300EC4F00E95900E76100E56800E36E00E17300E07700
DF7A00DF7C00DE7D00DE7E00DE7E00DE7D00DF7C00DF7A00E07700E17300E36E00E56800
E76100E95900EC4F00EF4300F23500F72500FB1100FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000002539002439002338002338
002238002238002137002137002137002036002036001F36001F36001F35001E35001E35
001E35001D34001D34000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219001D34001D34001E35001E35001E35001F35001F36001F36
002036002036002137002137002137002237002238002338002338002439002439002539
00263AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FC1000F72300F33200F03F00ED4B00EA5400E85C00E66200E56700E36C00
E26F00E27100E17300E17400E17400E17300E27100E26F00E36C00E56700E66200E85C00
EA5400ED4B00F03F00F33200F72300FC1000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000263A002539002439002439002338
002338002238002237002137002137002137002036002036001F36001F36001F35001E35
001E35001E35001D34001D34000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219001D34001D34001D35001E35001E35001E35001F36001F36002036
00203600203700213700213700223700223800233800233800243900243900253900253A
00263AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FC0F00F82000F42F00F13B00EE4600EC4E00EA5600E85B00E76000
E66400E56600E46800E46900E46900E46800E56600E66400E76000E85B00EA5600EC4E00
EE4600F13B00F42F00F82000FC0F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000263A00253A002539002439002439
002338002338002238002237002137002137002037002036002036001F36001F36001F35
001E35001E35001D35001D34001D34000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219001C34001D34001D34001D35001E35001E35001E35001F35001F36002036002036
00203700213700213700223700223800233800233800243900243900253900253A00263A
00273A00273BFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FD0C00F91D00F52B00F23600F04000EE4800EC4E00EA5400
E95800E85B00E85D00E85E00E85E00E85D00E85B00E95800EA5400EC4E00EE4800F04000
F23600F52B00F91D00FD0C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000273B00273A00263A00253A002539002439
002439002338002338002238002237002137002137002037002036002036001F36001F35
001E35001E35001E35001D35001D34001D34001C34000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
001C34001D34001D34001D34001E35001E35001E35001F35001F36002036002036002036
00213700213700223700223800233800233800243900243900253900253A00263A00263A
00273B00283B00283BFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FD0900FA1900F62600F43100F13900EF4100EE4600
ED4B00EC4E00EB5000EB5100EB5100EB5000EC4E00ED4B00EE4600EF4100F13900F43100
F62600FA1900FD0900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000283B00283B00273B00263A00263A00253A002539
002439002439002338002338002238002237002137002137002036002036002036001F36
001F35001E35001E35001E35001D34001D34001D34001C34000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219001C34001C34
001D34001D34001D34001E35001E35001E35001F35001F36001F36002036002036002137
00213700223700223800223800233800233800243900253900253900263A00263A00273B
00283B00283B00293CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FE0500FB1400F82000F52A00F33200F23800
F03D00EF4100EF4300EF4400EF4400EF4300EF4100F03D00F23800F33200F52A00F82000
FB1400FE0500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000293C00283B00283B00273B00263A00263A002539
002539002439002338002338002238002238002237002137002137002036002036001F36
001F36001F35001E35001E35001E35001D34001D34001D34001C34001C34000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219001C34001C34001D34
001D34001D34001E35001E35001E35001F35001F36001F36002036002036002137002137
00213700223700223800233800233800243900243900253900263A00263A00273B00273B
00283B00293C00293C002A3DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FC0E00FA1900F72200F62900
F42E00F33200F33500F23600F23600F33500F33200F42E00F62900F72200FA1900FC0E00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000002A3D00293C00293C00283B00273B00273B00263A00263A
002539002439002439002338002338002238002237002137002137002137002036002036
001F36001F36001F35001E35001E35001E35001D34001D34001D34001C34001C34000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219001C33001C34001D34001D34
001D34001E35001E35001E35001F35001F36001F36002036002036002137002137002137
00223700223800233800233800243900243900253900253A00263A00273A00273B00283B
00293C00293C002A3C002B3DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FE0700FC1000FA1800
F81E00F72300F62600F62700F62700F62600F72300F81E00FA1800FC1000FE0700FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000002B3D002A3C00293C00293C00283B00273B00273A00263A
00253A002539002439002439002338002338002238002237002137002137002137002036
002036001F36001F36001F35001E35001E35001E35001D34001D34001D34001C34001C34
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219001C33001C33001C34001C34001D34001D34
001D35001E35001E35001E35001F35001F36002036002036002037002137002137002237
00223800233800233800243900243900253900253A00263A00263A00273B00283B00283C
00293C002A3C002B3D002B3D002C3EFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FE0700
FC0E00FB1200FA1600FA1700FA1700FA1600FB1200FC0E00FE0700FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000002C3E002B3D002B3D002A3C00293C00283C00283B00273B00273A
00263A00253A002539002439002439002338002338002238002237002137002137002037
002036002036001F36001F35001E35001E35001E35001D35001D34001D34001C34001C34
001C33001C33000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219001C33001C33001C34001C34001D34001D34001D35
001E35001E35001E35001F35001F36002036002036002036002137002137002237002238
00233800233800243900243900253900253A00263A00263A00273B00283B00283B00293C
002A3C002A3D002B3D002C3E002D3E002E3FFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0100FE0400FE0600FE0600FE0400FF0100FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000002E3F002D3E002C3E002B3D002A3D002A3C00293C00283B00283B00273B
00263A00263A00253A002539002439002439002338002338002238002237002137002137
002036002036002036001F36001F35001E35001E35001E35001D35001D34001D34001C34
001C34001C33001C33000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219001C33001C33001C34001C34001D34001D34001D34001E35
001E35001E35001F35001F36001F36002036002036002137002137002237002238002238
00233800233800243900253900253900263A00263A00273B00273B00283B00293C002A3C
002A3D002B3D002C3D002D3E002E3E002F3FFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000002F3F002E3E002D3E002C3D002B3D002A3D002A3C00293C00283B00273B
00273B00263A00263A002539002539002439002338002338002238002238002237002137
002137002036002036001F36001F36001F35001E35001E35001E35001D34001D34001D34
001C34001C34001C33001C33000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219001B33001B33001C33001C34001C34001D34001D34001D34001E35001E35
001E35001F35001F36001F36002036002036002137002137002137002237002238002338
00233800243900243900253900263A00263A00273A00273B00283B00293C00293C002A3C
002B3D002C3D002D3E002D3E002E3F002F3F003040FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000003040002F3F002E3F002D3E002D3E002C3D002B3D002A3C00293C00293C00283B
00273B00273A00263A00263A002539002439002439002338002338002238002237002137
002137002137002036002036001F36001F36001F35001E35001E35001E35001D34001D34
001D34001C34001C34001C33001B33001B33000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219001B33001B33001C33001C34001C34001D34001D34001D34001E35001E35001E35
001F35001F36001F36002036002036002137002137002137002237002238002338002338
00243900243900253900253A00263A00273A00273B00283B00293C00293C002A3C002B3D
002B3D002C3E002D3E002E3F002F3F003040003140FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000003140003040002F3F002E3F002D3E002C3E002B3D002B3D002A3C00293C00293C
00283B00273B00273A00263A00253A002539002439002439002338002338002238002237
002137002137002137002036002036001F36001F36001F35001E35001E35001E35001D34
001D34001D34001C34001C34001C33001B33001B33000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219001B33
001B33001B33001C33001C33001C34001D34001D34001D34001D35001E35001E35001F35
001F36001F36002036002036002037002137002137002237002238002338002338002439
00243900253900253A00263A00263A00273B00283B00283B00293C002A3C002A3D002B3D
002C3E002D3E002E3F002F3F003040003140003241003341FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
003341003241003140003040002F3F002E3F002D3E002C3E002B3D002B3D002A3C00293C
00283B00283B00273B00263A00263A00253A002539002439002439002338002338002238
002237002137002137002037002036002036001F36001F36001F35001E35001E35001D35
001D34001D34001D34001C34001C33001C33001B33001B33001B33000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219001B33001B33
001B33001C33001C33001C34001C34001D34001D34001D35001E35001E35001E35001F35
001F36002036002036002036002137002137002237002238002338002338002439002439
00253900253A00263A00263A00273B00283B00283B00293C002A3C002A3D002B3D002C3D
002D3E002E3E002E3F002F3F003040003141003341003442003542FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000003542
003442003341003141003040002F3F002E3F002E3E002D3E002C3D002B3D002A3D002A3C
00293C00283B00283B00273B00263A00263A00253A002539002439002439002338002338
002238002237002137002137002036002036002036001F36001F35001E35001E35001E35
001D35001D34001D34001C34001C34001C33001C33001B33001B33001B33000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219001B33001B33001B33
001C33001C33001C34001C34001D34001D34001D34001E35001E35001E35001F35001F36
001F36002036002036002137002137002237002238002238002338002338002439002439
00253900263A00263A00273A00273B00283B00293C00293C002A3C002B3D002C3D002C3E
002D3E002E3F002F3F003040003140003241003342003542003643FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000003643
003542003342003241003140003040002F3F002E3F002D3E002C3E002C3D002B3D002A3C
00293C00293C00283B00273B00273A00263A00263A002539002439002439002338002338
002238002238002237002137002137002036002036001F36001F36001F35001E35001E35
001E35001D34001D34001D34001C34001C34001C33001C33001B33001B33001B33000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219001A32001B33001B33001B33001B33
001C33001C34001C34001D34001D34001D34001E35001E35001E35001F35001F36001F36
002036002036002137002137002137002237002238002338002338002439002439002539
00253A00263A00273A00273B00283B00293C00293C002A3C002B3D002B3D002C3E002D3E
002E3F002F3F003040003140003241003341003442003543003743003844FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000003844003743
003543003442003341003241003140003040002F3F002E3F002D3E002C3E002B3D002B3D
002A3C00293C00293C00283B00273B00273A00263A00253A002539002439002439002338
002338002238002237002137002137002137002036002036001F36001F36001F35001E35
001E35001E35001D34001D34001D34001C34001C34001C33001B33001B33001B33001B33
001A32000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219001A32001B33001B33001B33001B33001C33
001C34001C34001D34001D34001D34001E35001E35001E35001F35001F36001F36002036
00203600203700213700213700223700223800233800233800243900243900253900253A
00263A00263A00273B00283B00283B00293C002A3C002A3D002B3D002C3E002D3E002E3F
002F3F003040003140003241003341003442003542003643003844003944FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000003945003844
003643003542003442003341003241003140003040002F3F002E3F002D3E002C3E002B3D
002A3D002A3C00293C00283B00283B00273B00263A00263A00253A002539002439002439
002338002338002238002237002137002137002037002036002036001F36001F36001F35
001E35001E35001E35001D34001D34001D34001C34001C34001C33001B33001B33001B33
001B33001A32000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219001A32001A32001B33001B33001B33001B33001C33001C33
001C34001D34001D34001D34001D35001E35001E35001E35001F35001F36002036002036
00203700213700213700223700223800233800233800243900243900253900253A00263A
00263A00273B00283B00283B00293C002A3C002A3D002B3D002C3D002D3E002E3E002E3F
002F3F003040003140003241003442003542003643003744003944003A45003C46FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000003C46003A45003944
003744003643003542003442003241003141003040002F3F002E3F002E3E002D3E002C3D
002B3D002A3D002A3C00293C00283B00283B00273B00263A00263A00253A002539002439
002439002338002338002238002237002137002137002037002036002036001F36001F35
001E35001E35001E35001D35001D34001D34001D34001C34001C33001C33001B33001B33
001B33001B33001A32001A32000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219001A32001A32001B32001B33001B33001B33001C33001C33001C34
001C34001D34001D34001D35001E35001E35001E35001F35001F36002036002036002036
00213700213700223700223800223800233800233800243900243900253900263A00263A
00273A00273B00283B00293C00293C002A3C002B3D002C3D002C3E002D3E002E3F002F3F
003040003140003241003341003442003643003743003844003A45003B46003D46FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000003D46003B46003A45
003844003743003643003442003341003241003140003040002F3F002E3F002D3E002C3E
002C3D002B3D002A3C00293C00293C00283B00273B00273A00263A00263A002539002439
002439002338002338002238002238002237002137002137002036002036002036001F36
001F35001E35001E35001E35001D35001D34001D34001C34001C34001C33001C33001B33
001B33001B33001B32001A32001A32000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219001A32001A32001A32001B33001B33001B33001C33001C33001C34001C34
001D34001D34001D34001E35001E35001E35001F35001F36001F36002036002036002137
00213700213700223700223800233800233800243900243900253900253A00263A00273A
00273B00283B00283C00293C002A3C002B3D002B3D002C3E002D3E002E3F002F3F003040
003140003241003341003442003543003643003844003945003B45003C46003E47004048
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000004048003E47003C46003B45
003945003844003643003543003442003341003241003140003040002F3F002E3F002D3E
002C3E002B3D002B3D002A3C00293C00283C00283B00273B00273A00263A00253A002539
002439002439002338002338002238002237002137002137002137002036002036001F36
001F36001F35001E35001E35001E35001D34001D34001D34001C34001C34001C33001C33
001B33001B33001B33001A32001A32001A32000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
001A32001A32001A32001A32001B33001B33001B33001B33001C33001C34001C34001D34
001D34001D34001E35001E35001E35001F35001F36001F36002036002036002137002137
00213700223700223800233800233800243900243900253900253A00263A00263A00273B
00283B00283B00293C002A3C002A3D002B3D002C3E002D3E002E3E002F3F002F3F003040
003141003341003442003542003643003744003944003A45003C46003D47003F47004148
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000004148003F47003D47003C46
003A45003944003744003643003542003442003341003141003040002F3F002F3F002E3E
002D3E002C3E002B3D002A3D002A3C00293C00283B00283B00273B00263A00263A00253A
002539002439002439002338002338002238002237002137002137002137002036002036
001F36001F36001F35001E35001E35001E35001D34001D34001D34001C34001C34001C33
001B33001B33001B33001B33001A32001A32001A32001A32000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219001A32
001A32001A32001A32001B33001B33001B33001B33001C33001C34001C34001D34001D34
001D34001E35001E35001E35001F35001F36001F36002036002036002037002137002137
00223700223800233800233800243900243900253900253A00263A00263A00273B00273B
00283B00293C00293C002A3D002B3D002C3D002D3E002D3E002E3F002F3F003040003140
003241003342003442003643003743003844003A45003B46003D46003F47004048004249
00444AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000444A004249004048003F47003D46
003B46003A45003844003743003643003442003342003241003140003040002F3F002E3F
002D3E002D3E002C3D002B3D002A3D002A3C00293C00283B00273B00273B00263A00263A
00253A002539002439002439002338002338002238002237002137002137002037002036
002036001F36001F36001F35001E35001E35001E35001D34001D34001D34001C34001C34
001C33001B33001B33001B33001B33001A32001A32001A32001A32000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219001932001A32001A32
001A32001A32001B33001B33001B33001B33001C33001C33001C34001D34001D34001D34
001D35001E35001E35001E35001F35001F36002036002036002036002137002137002237
00223800223800233800233800243900243900253900263A00263A00273A00273B00283B
00293C00293C002A3C002B3D002C3D002C3E002D3E002E3F002F3F003040003140003241
003341003442003543003743003844003945003B45003C46003E4700404800424900444A
00464A00484BFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000484C00464A00444A004249004048003E47
003C46003B45003945003844003743003543003442003341003241003140003040002F3F
002E3F002D3E002C3E002C3D002B3D002A3C00293C00293C00283B00273B00273A00263A
00263A002539002439002439002338002338002238002238002237002137002137002036
002036002036001F36001F35001E35001E35001E35001D35001D34001D34001D34001C34
001C33001C33001B33001B33001B33001B33001A32001A32001A32001A32001932000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219001932001A32001A32001A32
001A32001B32001B33001B33001B33001C33001C33001C34001C34001D34001D34001D34
001E35001E35001E35001F35001F36001F36002036002036002137002137002137002237
00223800233800233800243900243900253900253A00263A00273A00273B00283B00283B
00293C002A3C002B3D002B3D002C3E002D3E002E3F002F3F003040003140003241003341
003442003542003643003744003944003A45003C46003D47003F4700414800434900454A
00474B00494CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000494C00474B00454A004349004148003F47
003D47003C46003A45003944003744003643003542003442003341003241003140003040
002F3F002E3F002D3E002C3E002B3D002B3D002A3C00293C00283B00283B00273B00273A
00263A00253A002539002439002439002338002338002238002237002137002137002137
002036002036001F36001F36001F35001E35001E35001E35001D34001D34001D34001C34
001C34001C33001C33001B33001B33001B33001B32001A32001A32001A32001A32001932
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219001932001932001A32001A32001A32
001A32001B33001B33001B33001C33001C33001C34001C34001D34001D34001D34001E35
001E35001E35001F35001F36001F36002036002036002137002137002137002237002238
00233800233800243900243900253900253A00263A00263A00273B00283B00283B00293C
002A3C002A3D002B3D002C3D002D3E002D3E002E3F002F3F003040003140003241003342
003542003643003743003844003A45003B46003D46003F4700404800424900444A00464B
00494C004B4D004E4EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000004E4E004B4D00494C00464B00444A004249004048
003F47003D46003B46003A45003844003743003643003542003342003241003140003040
002F3F002E3F002E3E002D3E002C3D002B3D002A3D002A3C00293C00283B00283B00273B
00263A00263A00253A002539002439002439002338002338002238002237002137002137
002137002036002036001F36001F36001F35001E35001E35001E35001D34001D34001D34
001C34001C34001C33001C33001B33001B33001B33001A32001A32001A32001A32001A32
001932000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219000219001931001932001932001A32001A32001A32001A32
001B33001B33001B33001B33001C33001C34001C34001D34001D34001D34001E35001E35
001E35001F35001F36001F36002036002036002037002137002137002237002238002338
00233800243900243900253900253900263A00263A00273B00273B00283B00293C00293C
002A3C002B3D002C3D002C3E002D3E002E3F002F3F003040003140003241003341003442
003543003743003844003945003B45003C46003E4700404800424900434900464A00484B
004A4C004D4E004F4EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000004F4E004D4E004A4D00484B00464A004349004249
004048003E47003C46003B45003945003844003743003543003442003341003241003140
003040002F3F002E3F002D3E002C3E002C3D002B3D002A3C00293C00293C00283B00273B
00273B00263A00263A002539002539002439002439002338002338002238002237002137
002137002037002036002036001F36001F36001F35001E35001E35001E35001D34001D34
001D34001C34001C34001C33001B33001B33001B33001B33001A32001A32001A32001A32
001932001932001931000219000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219000219000219001931001932001932001A32001A32001A32001A32001B33
001B33001B33001B33001C33001C34001C34001D34001D34001D34001D35001E35001E35
001E35001F35001F36002036002036002036002137002137002237002238002238002338
00233800243900243900253900253A00263A00273A00273B00283B00293C00293C002A3C
002B3D002B3D002C3E002D3E002E3F002F3F003040003140003241003341003442003542
003643003744003944003A45003C46003D47003F4700414800434900454A00474B00494C
004C4D004E4E00504E00514DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000514D00504E004E4E004C4D00494C00474B00454A004349
004148003F47003D47003C46003A45003944003744003643003542003442003341003241
003140003040002F3F002E3F002D3E002C3E002B3D002B3D002A3C00293C00293C00283B
00273B00273A00263A00253A002539002439002439002338002338002238002238002237
002137002137002036002036002036001F36001F35001E35001E35001E35001D35001D34
001D34001D34001C34001C34001C33001B33001B33001B33001B33001A32001A32001A32
001A32001932001932001931000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219000219001931001931001931001932001A32001A32001A32001A32001B33001B33
001B33001B33001C33001C33001C34001C34001D34001D34001D34001E35001E35001E35
001F35001F36001F36002036002036002137002137002137002237002238002338002338
00243900243900253900253A00263A00263A00273B00283B00283B00293C002A3C002A3D
002B3D002C3E002D3E002E3E002E3F002F3F003040003140003241003342003542003643
003743003844003A45003B46003D46003E4700404800424900444A00464B00484C004B4D
004D4E004F4E00504D00524DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000524D00504D004F4E004D4E004B4D00484C00464B00444A
004249004048003E47003D46003B46003A45003844003743003643003542003342003241
003140003040002F3F002E3F002E3E002D3E002C3E002B3D002A3D002A3C00293C00283B
00283B00273B00263A00263A00253A002539002439002439002338002338002238002237
002137002137002137002036002036001F36001F36001F35001E35001E35001E35001D34
001D34001D34001C34001C34001C33001C33001B33001B33001B33001B33001A32001A32
001A32001A32001932001931001931001931000219000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
000219001931001931001931001932001A32001A32001A32001A32001A32001B33001B33
001B33001C33001C33001C34001C34001D34001D34001D34001E35001E35001E35001F35
001F36001F36002036002036002137002137002137002237002238002338002338002439
00243900253900253A00263A00263A00273B00273B00283B00293C00293C002A3D002B3D
002C3D002C3E002D3E002E3F002F3F003040003140003241003341003442003543003743
003844003945003B45003C46003E4700404800414900434900454A00484B004A4C004C4D
004F4E00504E00514D00534D00544CFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000544C00534D00514D00504E004F4E004C4D004A4C00484B00454A
004349004149004048003E47003C46003B45003945003844003743003543003442003341
003241003140003040002F3F002E3F002D3E002C3E002C3D002B3D002A3D00293C00293C
00283B00273B00273B00263A00263A00253A002539002439002439002338002338002238
002237002137002137002137002036002036001F36001F36001F35001E35001E35001E35
001D34001D34001D34001C34001C34001C33001C33001B33001B33001B33001A32001A32
001A32001A32001A32001932001931001931001931000219000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219000219000219
001931001931001931001932001932001A32001A32001A32001A32001B33001B33001B33
001B33001C33001C34001C34001D34001D34001D34001E35001E35001E35001F35001F36
001F36002036002036002037002137002137002237002238002338002338002338002439
00243900253900263A00263A00273A00273B00283B00293C00293C002A3C002B3D002B3D
002C3E002D3E002E3F002F3F003040003140003241003341003442003542003643003744
003944003A45003C46003D47003F4700414800434900454A00474B00494C004B4D004E4E
004F4E00514D00524D00534C00554BFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000554B00534C00524D00514D004F4E004E4E004B4D00494C00474B
00454A004349004148003F47003D47003C46003A45003944003744003643003542003442
003341003241003140003040002F3F002E3F002D3E002C3E002B3D002B3D002A3C00293C
00293C00283B00273B00273A00263A00263A002539002439002439002338002338002338
002238002237002137002137002037002036002036001F36001F36001F35001E35001E35
001E35001D34001D34001D34001C34001C34001C33001B33001B33001B33001B33001A32
001A32001A32001A32001932001932001931001931001931000219000219000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219000219001831001931
001931001931001932001932001A32001A32001A32001A32001B33001B33001B33001B33
001C33001C34001C34001D34001D34001D34001D35001E35001E35001E35001F35001F36
002036002036002036002137002137002237002238002238002338002338002439002439
00253900253A00263A00273A00273B00283B00283B00293C002A3C002A3D002B3D002C3E
002D3E002E3E002E3F002F3F003040003140003241003342003542003643003743003844
003A45003B46003D46003E4700404800424900444A00464B00484C004B4D004D4E004F4E
00504E00514D00534C00544C00564BFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000564B00544C00534C00514D00504E004F4E004D4E004B4D00484C
00464B00444A004249004048003E47003D46003B46003A45003844003743003643003542
003342003241003140003040002F3F002E3F002E3E002D3E002C3E002B3D002A3D002A3C
00293C00283B00283B00273B00273A00263A00253A002539002439002439002338002338
002238002238002237002137002137002036002036002036001F36001F35001E35001E35
001E35001D35001D34001D34001D34001C34001C34001C33001B33001B33001B33001B33
001A32001A32001A32001A32001932001932001931001931001931001831000219000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219000219000219001831001931001931
001931001932001932001A32001A32001A32001A32001B33001B33001B33001B33001C33
001C33001C34001C34001D34001D34001D34001E35001E35001E35001F35001F36001F36
002036002036002137002137002137002237002238002338002338002439002439002539
00253A00263A00263A00273B00283B00283B00293C002A3C002A3D002B3D002C3D002C3E
002D3E002E3F002F3F003040003140003241003341003442003543003743003844003945
003B45003C46003E47003F4800414800434900454A00474B004A4C004C4D004E4E00504E
00514D00524D00544C00554B00574A005949FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000594900574A00554B00544C00524D00514D00504E004E4E004C4D004A4C
00474B00454A004349004148003F48003E47003C46003B45003945003844003743003543
003442003341003241003140003040002F3F002E3F002D3E002C3E002C3D002B3D002A3D
002A3C00293C00283B00283B00273B00263A00263A00253A002539002439002439002338
002338002238002237002137002137002137002036002036001F36001F36001F35001E35
001E35001E35001D34001D34001D34001C34001C34001C33001C33001B33001B33001B33
001B33001A32001A32001A32001A32001932001932001931001931001931001831000219
000219000219000219000219000219000219000219000219
000219000219000219000219000219000219000219001831001831001831001931001931
001931001932001A32001A32001A32001A32001B32001B33001B33001B33001C33001C33
001C34001C34001D34001D34001D34001E35001E35001E35001F35001F36001F36002036
002036002037002137002137002237002238002338002338002439002439002539002539
00263A00263A00273A00273B00283B00293C00293C002A3C002B3D002B3D002C3E002D3E
002E3F002F3F003040003140003241003341003442003542003643003744003944003A45
003C46003D46003F4700414800424900444A00464B00494C004B4D004E4E004F4E00504D
00524D00534C00554B00564B005849005A48FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000005A4800584900564B00554B00534C00524D00504D004F4E004E4E004B4D
00494C00464B00444A004249004148003F47003D46003C46003A45003944003744003643
003542003442003341003241003140003040002F3F002E3F002D3E002C3E002B3D002B3D
002A3C00293C00293C00283B00273B00273B00263A00263A002539002539002439002439
002338002338002238002237002137002137002037002036002036001F36001F36001F35
001E35001E35001E35001D34001D34001D34001C34001C34001C33001C33001B33001B33
001B33001B32001A32001A32001A32001A32001932001931001931001931001831001831
001831000219000219000219000219000219000219000219
000219000219000219000219000219000219001831001831001831001931001931001931
001932001932001A32001A32001A32001A32001B33001B33001B33001B33001C33001C34
001C34001D34001D34001D34001E35001E35001E35001F35001F36001F36002036002036
00203600213700213700223700223800223800233800233800243900243900253900253A
00263A00273A00273B00283B00283B00293C002A3C002A3D002B3D002C3E002D3E002E3E
002E3F002F3F003040003140003241003342003442003643003743003844003A45003B45
003D46003E4700404800424900444A00464A00484B004A4C004D4E004F4E00504E00514D
00534D00544C00564B00574A005949005B47005D46FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000005D46005B4700594900574A00564B00544C00534D00514D00504E004F4E004D4E
004A4C00484B00464A00444A004249004048003E47003D46003B45003A45003844003743
003643003442003342003241003140003040002F3F002E3F002E3E002D3E002C3E002B3D
002A3D002A3C00293C00283B00283B00273B00273A00263A00253A002539002439002439
002338002338002238002238002237002137002137002036002036002036001F36001F36
001F35001E35001E35001E35001D34001D34001D34001C34001C34001C33001B33001B33
001B33001B33001A32001A32001A32001A32001932001932001931001931001931001831
001831001831000219000219000219000219000219000219
000219000219000219000219000219001831001831001831001931001931001931001932
001932001A32001A32001A32001A32001B33001B33001B33001B33001C33001C34001C34
001D34001D34001D34001D35001E35001E35001E35001F35001F36001F36002036002036
00213700213700213700223700223800233800233800243900243900253900253A00263A
00263A00273B00283B00283B00293C002A3C002A3D002B3D002C3D002C3E002D3E002E3F
002F3F003040003140003241003341003442003543003643003844003944003A45003C46
003E47003F4700414800434900454A00474B00494C004C4D004E4E004F4E00514D00524D
00534C00554B00574A005849005A48005C46005E45FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000005E45005C46005A4800584900574A00554B00534C00524D00514D004F4E004E4E
004C4D00494C00474B00454A004349004148003F47003E47003C46003A45003944003844
003643003543003442003341003241003140003040002F3F002E3F002D3E002C3E002C3D
002B3D002A3D002A3C00293C00283B00283B00273B00263A00263A00253A002539002439
002439002338002338002238002237002137002137002137002036002036001F36001F36
001F35001E35001E35001E35001D35001D34001D34001D34001C34001C34001C33001B33
001B33001B33001B33001A32001A32001A32001A32001932001932001931001931001931
001831001831001831000219000219000219000219000219
000219000219000219001830001831001831001831001931001931001931001932001932
001A32001A32001A32001A32001B33001B33001B33001B33001C33001C33001C34001C34
001D34001D34001D34001E35001E35001E35001F35001F36001F36002036002036002137
00213700213700223700223800233800233800243900243900253900253900263A00263A
00273B00273B00283B00293C00293C002A3C002B3D002B3D002C3E002D3E002E3F002F3F
003040003140003241003341003442003542003643003744003944003A45003B46003D46
003F4700404800424900444A00464B00484C004B4D004D4E004F4E00504E00514D00534C
00544C00564B00574A005949005B47005D45006043006241FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
006241006043005D45005B4700594900574A00564B00544C00534C00514D00504E004F4E
004D4E004B4D00484C00464B00444A004249004048003F47003D46003B46003A45003944
003744003643003542003442003341003241003140003040002F3F002E3F002D3E002C3E
002B3D002B3D002A3C00293C00293C00283B00273B00273B00263A00263A00253A002539
002439002439002338002338002238002237002137002137002137002036002036001F36
001F36001F35001E35001E35001E35001D34001D34001D34001C34001C34001C33001C33
001B33001B33001B33001B33001A32001A32001A32001A32001932001932001931001931
001931001831001831001831001830000219000219000219
000219000219001830001831001831001831001831001931001931001931001932001A32
001A32001A32001A32001B32001B33001B33001B33001C33001C33001C34001C34001D34
001D34001D34001E35001E35001E35001F35001F36001F36002036002036002037002137
00213700223700223800233800233800233800243900243900253900253A00263A00273A
00273B00283B00283B00293C002A3C002A3D002B3D002C3E002D3E002E3E002E3F002F3F
003040003140003241003342003442003643003743003844003945003B45003C46003E47
00404800414800434900454A00474B004A4C004C4D004E4E00504E00514D00524D00544C
00554B00574A005849005A48005C46005F44006142006440FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
006440006142005F44005C46005A4800584900574A00554B00544C00524D00514D00504E
004E4E004C4D004A4C00474B00454A004349004148004048003E47003C46003B45003945
003844003743003643003442003342003241003140003040002F3F002E3F002E3E002D3E
002C3E002B3D002A3D002A3C00293C00283B00283B00273B00273A00263A00253A002539
002439002439002338002338002338002238002237002137002137002037002036002036
001F36001F36001F35001E35001E35001E35001D34001D34001D34001C34001C34001C33
001C33001B33001B33001B33001B32001A32001A32001A32001A32001932001931001931
001931001831001831001831001831001830000219000219
001730001830001831001831001831001831001931001931001931001932001932001A32
001A32001A32001A32001B33001B33001B33001B33001C33001C34001C34001D34001D34
001D34001D35001E35001E35001E35001F35001F36002036002036002036002137002137
00213700223800223800233800233800243900243900253900253A00263A00263A00273B
00283B00283B00293C002A3C002A3D002B3D002C3D002C3E002D3E002E3F002F3F003040
003140003241003341003442003542003643003844003944003A45003C46003D47003F47
00414800424900444A00464B00494C004B4D004E4E004F4E00504E00524D00534C00544C
00564B00584A005948005B47005E4500604300624100653E00683AFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000683A
00653E006241006043005E45005B4700594800584A00564B00544C00534C00524D00504E
004F4E004E4E004B4D00494C00464B00444A004249004148003F47003D47003C46003A45
003944003844003643003542003442003341003241003140003040002F3F002E3F002D3E
002C3E002C3D002B3D002A3D002A3C00293C00283B00283B00273B00263A00263A00253A
002539002439002439002338002338002238002238002237002137002137002036002036
002036001F36001F35001E35001E35001E35001D35001D34001D34001D34001C34001C34
001C33001B33001B33001B33001B33001A32001A32001A32001A32001A32001932001931
001931001931001831001831001831001831001830001730
001830001830001831001831001831001931001931001931001932001932001A32001A32
001A32001A32001B33001B33001B33001B33001C33001C33001C34001C34001D34001D34
001D35001E35001E35001E35001F35001F36001F36002036002036002137002137002137
00223700223800233800233800243900243900253900253A00263A00263A00273B00273B
00283B00293C00293C002A3C002B3D002B3D002C3E002D3E002E3F002F3F003040003040
003141003241003442003542003643003743003844003A45003B46003D46003E47004048
00424900444A00464A00484B004A4C004C4D004F4E00504E00514D00524D00544C00554B
00574A005949005B48005D46005F4400614200643F00673C006A38FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000006A38
00673C00643F006142005F44005D46005B4800594900574A00554B00544C00524D00514D
00504E004F4E004C4D004A4C00484B00464A00444A004249004048003E47003D46003B46
003A45003844003743003643003542003442003241003141003140003040002F3F002E3F
002D3E002C3E002B3D002B3D002A3C00293C00293C00283B00273B00273B00263A00263A
00253A002539002439002439002338002338002238002237002137002137002137002036
002036001F36001F36001F35001E35001E35001E35001D35001D34001D34001D34001C34
001C33001C33001B33001B33001B33001B33001A32001A32001A32001A32001932001932
001931001931001931001831001831001831001830001830
001830001831001831001831001931001931001931001932001932001A32001A32001A32
001A32001B33001B33001B33001B33001C33001C33001C34001C34001D34001D34001D34
001E35001E35001E35001F35001F36001F36002036002036002037002137002137002237
00223800233800233800233800243900243900253900253A00263A00273A00273B00283B
00283B00293C002A3C002A3D002B3D002C3E002D3E002E3E002E3F002F3F003040003140
003241003341003442003543003743003844003945003B45003C46003E47003F47004148
00434900454A00474B00494C004B4D004E4E004F4E00504D00524D00534C00554B00564B
00584A005A48005C47005E4500604300624100653E00683A006B36FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000006B36
00683A00653E006241006043005E45005C47005A4800584A00564B00554B00534C00524D
00504D004F4E004E4E004B4D00494C00474B00454A004349004148003F47003E47003C46
003B45003945003844003743003543003442003341003241003140003040002F3F002E3F
002E3E002D3E002C3E002B3D002A3D002A3C00293C00283B00283B00273B00273A00263A
00253A002539002439002439002338002338002338002238002237002137002137002037
002036002036001F36001F36001F35001E35001E35001E35001D34001D34001D34001C34
001C34001C33001C33001B33001B33001B33001B33001A32001A32001A32001A32001932
001932001931001931001931001831001831001831001830
001831001831001831001831001931001931001931001932001A32001A32001A32001A32
001A32001B33001B33001B33001C33001C33001C34001C34001D34001D34001D34001E35
001E35001E35001F35001F35001F36002036002036002036002137002137002237002238
00223800233800233800243900243900253900253A00263A00263A00273B00283B00283B
00293C00293C002A3D002B3D002C3D002C3E002D3E002E3F002F3F003040003140003241
003341003442003542003643003744003944003A45003B46003D46003F47004048004249
00444A00464B00484C004A4D004D4E004F4E00504E00514D00534D00544C00554B00574A
005949005B48005D46005F4400614200643F00673C006A38006D3400712EFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000712E006D34
006A3800673C00643F006142005F44005D46005B4800594900574A00554B00544C00534D
00514D00504E004F4E004D4E004A4D00484C00464B00444A004249004048003F47003D46
003B46003A45003944003744003643003542003442003341003241003140003040002F3F
002E3F002D3E002C3E002C3D002B3D002A3D002A3C00293C00283B00283B00273B00263A
00263A00253A002539002439002439002338002338002238002238002237002137002137
002036002036002036001F36001F36001F35001E35001E35001E35001D34001D34001D34
001C34001C34001C33001C33001B33001B33001B33001A32001A32001A32001A32001A32
001932001931001931001931001831001831001831001831
001831001831001831001931001931001931001932001932001A32001A32001A32001A32
001B33001B33001B33001B33001C33001C34001C34001D34001D34001D34001D35001E35
001E35001E35001F35001F36001F36002036002036002137002137002137002237002238
00233800233800243900243900253900253A00263A00263A00273B00273B00283B00293C
00293C002A3C002B3D002B3D002C3E002D3E002E3F002F3F002F3F003040003140003241
003342003442003643003743003844003945003B45003C46003E47004048004148004349
00454A00474B00494C004C4D004E4E004F4E00514D00524D00534C00554B00564A005849
005A48005C47005E4500604300624100653E00683A006B36006F3100732BFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000732B006F31
006B3600683A00653E006341006043005E45005C47005A4800584900564A00554B00534C
00524D00514D004F4E004E4E004C4D00494C00474B00454A004349004148004048003E47
003C46003B45003945003844003743003643003442003342003241003140003040002F3F
002F3F002E3F002D3E002C3E002B3D002B3D002A3C00293C00293C00283B00273B00273B
00263A00263A00253A002539002439002439002338002338002238002237002137002137
002137002036002036001F36001F36001F35001E35001E35001E35001D35001D34001D34
001D34001C34001C34001C33001B33001B33001B33001B33001A32001A32001A32001A32
001932001932001931001931001931001831001831001831
001831001831001931001931001931001932001932001A32001A32001A32001A32001B33
001B33001B33001B33001C33001C33001C34001C34001D34001D34001D34001E35001E35
001E35001F35001F36001F36002036002036002037002137002137002237002238002338
00233800233800243900243900253900253A00263A00273A00273B00283B00283B00293C
002A3C002A3D002B3D002C3D002D3E002D3E002E3F002F3F003040003140003241003341
003442003543003643003844003944003A45003C46003D47003F4700404800424900444A
00464B00484C004B4D004D4E004F4E00504E00514D00534C00544C00564B00574A005949
005B47005D46005F4400614200643F00673C006A38006D3400712E007527007A1FFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000007A1F00752700712E
006D34006A3800673C00643F006142005F44005D46005B4700594900574A00564B00544C
00534C00514D00504E004F4E004D4E004B4D00484C00464B00444A004249004148003F47
003D47003C46003A45003944003844003643003543003442003341003241003140003040
002F3F002E3F002D3E002D3E002C3D002B3D002A3D002A3C00293C00283B00283B00273B
00273A00263A00253A002539002439002439002338002338002338002238002237002137
002137002037002036002036001F36001F36001F35001E35001E35001E35001D34001D34
001D34001C34001C34001C33001C33001B33001B33001B33001B33001A32001A32001A32
001A32001932001932001931001931001931001831001831
001831001931001931001931001932001932001A32001A32001A32001A32001B33001B33
001B33001B33001C33001C33001C34001C34001D34001D34001D34001E35001E35001E35
001F35001F36001F36002036002036002036002137002137002237002238002238002338
00233800243900243900253900253A00263A00263A00273B00283B00283B00293C00293C
002A3C002B3D002C3D002C3E002D3E002E3F002F3F003040003140003241003341003442
003542003643003743003844003A45003B45003D46003E4700404800424900434900454A
00474B004A4C004C4D004E4E00504E00514D00524D00534C00554B00564A005849005A48
005C47005E4500604300634100653E00683A006B36006F3100732B007824007D1AFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000007D1A00782400732B
006F31006B3600683A00653E006341006043005E45005C47005A4800584900564A00554B
00534C00524D00514D00504E004E4E004C4D004A4C00474B00454A004349004249004048
003E47003D46003B45003A45003844003743003643003542003442003341003241003140
003040002F3F002E3F002D3E002C3E002C3D002B3D002A3C00293C00293C00283B00283B
00273B00263A00263A00253A002539002439002439002338002338002238002238002237
002137002137002036002036002036001F36001F36001F35001E35001E35001E35001D34
001D34001D34001C34001C34001C33001C33001B33001B33001B33001B33001A32001A32
001A32001A32001932001932001931001931001931001831
001831001931001931001931001932001A32001A32001A32001A32001A32001B33001B33
001B33001B33001C33001C34001C34001D34001D34001D34001D35001E35001E35001E35
001F35001F36001F36002036002036002137002137002137002237002238002338002338
00243900243900253900253900263A00263A00273A00273B00283B00293C00293C002A3C
002B3D002B3D002C3E002D3E002E3E002E3F002F3F003040003140003241003341003442
003543003743003844003945003A45003C46003D47003F4700414800434900444A00464B
00494C004B4D004D4E004F4E00504E00514D00534C00544C00564B00574A005949005B47
005D46005F4400614200643F00673C006A38006D3400712F007528007A1F008015FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000008015007A1F007528
00712F006D34006A3800673C00643F006142005F44005D46005B4700594900574A00564B
00544C00534C00514D00504E004F4E004D4E004B4D00494C00464B00444A004349004148
003F47003D47003C46003B45003945003844003743003543003442003341003241003140
003040002F3F002E3F002E3E002D3E002C3E002B3D002B3D002A3C00293C00293C00283B
00273B00273A00263A00263A00253A002539002439002439002338002338002238002237
002137002137002137002036002036001F36001F36001F35001E35001E35001E35001D35
001D34001D34001D34001C34001C34001C33001B33001B33001B33001B33001A32001A32
001A32001A32001A32001932001931001931001931001831
001931001931001931001932001932001A32001A32001A32001A32001B33001B33001B33
001B33001C33001C33001C34001C34001D34001D34001D34001E35001E35001E35001F35
001F36001F36002036002036002037002137002137002237002238002338002338002338
00243900243900253900253A00263A00273A00273B00283B00283B00293C002A3C002A3D
002B3D002C3D002D3E002D3E002E3F002F3F003040003140003241003341003442003542
003643003744003944003A45003B46003D46003E4700404800424900444A00464A00484B
004A4C004C4D004E4E00504E00514D00524D00534C00554B00564A005849005A48005C47
005E4500604300624100653E00683A006B36006F3200732C007724007C1B00820F008900
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000890000820F007C1B007724
00732C006F32006B3600683A00653E006341006043005E45005C47005A4800584900564A
00554B00534C00524D00514D00504E004E4E004C4D004A4C00484B00464A00444A004249
004048003E47003D46003B46003A45003944003744003643003542003442003341003241
003140003040002F3F002E3F002D3E002D3E002C3D002B3D002A3D002A3C00293C00283B
00283B00273B00273A00263A00253A002539002439002439002338002338002338002238
002237002137002137002037002036002036001F36001F36001F35001E35001E35001E35
001D34001D34001D34001C34001C34001C33001C33001B33001B33001B33001B33001A32
001A32001A32001A32001932001932001931001931001931
001931001931001932001932001A32001A32001A32001A32001B33001B33001B33001B33
001C33001C33001C34001C34001D34001D34001D34001E35001E35001E35001F35001F36
001F36002036002036002036002137002137002237002238002238002338002338002439
00243900253900253A00263A00263A00273B00273B00283B00293C00293C002A3C002B3D
002B3D002C3E002D3E002E3F002F3F003040003040003141003241003342003442003643
003743003844003945003B45003C46003E47003F4800414800434900454A00474B00494C
004B4D004E4E004F4E00504E00524D00534C00544C00564B00574A005949005B47005D46
005F4400614200643F00663C006939006D3400712F007528007920007F16008509078D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000078D00008509007F16007920
00752800712F006D34006A3900663C00643F006142005F44005D46005B4700594900574A
00564B00544C00534C00524D00504E004F4E004E4E004B4D00494C00474B00454A004349
004148003F48003E47003C46003B45003945003844003743003643003442003342003241
003141003040003040002F3F002E3F002D3E002C3E002B3D002B3D002A3C00293C00293C
00283B00273B00273B00263A00263A00253A002539002439002439002338002338002238
002238002237002137002137002036002036002036001F36001F36001F35001E35001E35
001E35001D34001D34001D34001C34001C34001C33001C33001B33001B33001B33001B33
001A32001A32001A32001A32001932001932001931001931
001931001931001932001A32001A32001A32001A32001A32001B33001B33001B33001B33
001C33001C34001C34001D34001D34001D34001D35001E35001E35001E35001F35001F36
001F36002036002036002137002137002137002237002238002338002338002439002439
00253900253900263A00263A00273A00273B00283B00283C00293C002A3C002A3D002B3D
002C3E002D3E002D3E002E3F002F3F003040003140003241003341003442003542003643
003744003944003A45003C46003D46003F4700404800424900444A00464B00484B004A4C
004C4D004F4E00504E00514D00524D00544C00554B00574A005849005A48005C47005E45
00604300624100653E00683B006B37006E3200722C007725007C1C008211008802109000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000109000008802008211007C1C
00772500722C006F32006B3700683B00653E006241006043005E45005C47005A48005849
00574A00554B00544C00524D00514D00504E004F4E004C4D004A4C00484B00464B00444A
004249004048003F47003D46003C46003A45003944003844003643003542003442003341
003241003140003040002F3F002E3F002D3E002D3E002C3E002B3D002A3D002A3C00293C
00283C00283B00273B00273A00263A00263A002539002539002439002439002338002338
002238002237002137002137002137002036002036001F36001F36001F35001E35001E35
001E35001D35001D34001D34001D34001C34001C34001C33001C33001B33001B33001B33
001A32001A32001A32001A32001A32001932001931001931
001931001932001A32001A32001A32001A32001A32001B33001B33001B33001B33001C33
001C34001C34001D34001D34001D34001D35001E35001E35001E35001F35001F36001F36
002036002036002037002137002137002237002238002338002338002338002439002439
00253900253A00263A00263A00273B00283B00283B00293C002A3C002A3D002B3D002C3D
002C3E002D3E002E3F002F3F003040003140003241003341003442003542003643003743
003844003A45003B45003C46003E47003F4800414800434900454A00474B00494C004B4D
004E4E004F4E00504E00524D00534C00544C00564B00574A005949005B47005D46005F44
00614200643F00663C006939006D3500702F007429007921007E1800840B048B001A9400
389E00FF0000FF0000FF0000FF0000FF0000FF0000389E001A9400048B0000840B007E17
00792100742900702F006D3500693900663C00643F006142005F44005D46005B47005949
00574A00564B00544C00534C00524D00504E004F4E004E4E004B4D00494C00474B00454A
004349004148003F48003E47003C46003B45003A45003844003743003643003542003442
003341003241003140003040002F3F002E3F002D3E002C3E002C3D002B3D002A3D002A3C
00293C00283B00283B00273B00263A00263A00253A002539002439002439002338002338
002338002238002237002137002137002037002036002036001F36001F36001F35001E35
001E35001E35001D35001D34001D34001D34001C34001C34001C33001B33001B33001B33
001B33001A32001A32001A32001A32001A32001932001931
001932001932001A32001A32001A32001A32001B33001B33001B33001B33001C33001C33
001C34001C34001D34001D34001D34001E35001E35001E35001F35001F36001F36002036
002036002036002137002137002237002238002238002338002338002439002439002539
00253A00263A00263A00273B00273B00283B00293C00293C002A3C002B3D002B3D002C3E
002D3E002E3E002E3F002F3F003040003140003241003341003442003543003643003844
003944003A45003C46003D47003F4700404800424900444A00464B00484C004A4C004D4E
004F4E00504E00514D00524D00544C00554B00574A005849005A48005C47005E45006043
00624100653E00683B006B37006E3200722D007626007B1D0081130087050C8F00259800
47A300FF0000FF0000FF0000FF0000FF0000FF000047A3002598000C8F00008705008113
007B1D00762600722D006E32006B3700683B00653E006241006043005E45005C47005A48
00584900574A00554B00544C00524D00514D00504E004F4E004D4E004A4D00484C00464B
00444A004249004048003F47003D47003C46003A45003944003844003643003543003442
003341003241003140003040002F3F002E3F002E3E002D3E002C3E002B3D002B3D002A3C
00293C00293C00283B00273B00273B00263A00263A00253A002539002439002439002338
002338002238002238002237002137002137002036002036002036001F36001F36001F35
001E35001E35001E35001D34001D34001D34001C34001C34001C33001C33001B33001B33
001B33001B33001A32001A32001A32001A32001932001932
001932001A32001A32001A32001A32001B32001B33001B33001B33001C33001C33001C34
001C34001D34001D34001D34001D35001E35001E35001E35001F35001F36001F36002036
002036002137002137002137002237002238002338002338002439002439002539002539
00263A00263A00273A00273B00283B00283B00293C002A3C002A3D002B3D002C3D002D3E
002D3E002E3F002F3F003040003140003241003341003442003542003643003744003844
003A45003B45003C46003E4700404800414800434900454A00474B00494C004B4D004E4E
004F4E00504E00524D00534C00544C00564B00574A005949005B47005D46005F44006142
00634000663D006939006C3500703000742A007823007D1900830D018A00159200319C00
57A800FF0000FF0000FF0000FF0000FF0000FF000057A800319C00159200018A0000830D
007D1900782200742A007030006C3500693900663D006340006142005F44005D46005B47
00594900574A00564B00544C00534C00524D00504E004F4E004E4E004B4D00494C00474B
00454A004349004148004048003E47003D46003B45003A45003844003744003643003542
003442003341003241003140003040002F3F002E3F002D3E002D3E002C3D002B3D002A3D
002A3C00293C00283B00283B00273B00273A00263A00263A002539002539002439002439
002338002338002238002237002137002137002137002036002036001F36001F36001F35
001E35001E35001E35001E35001D34001D34001D34001C34001C34001C33001C33001B33
001B33001B33001B32001A32001A32001A32001A32001932
001A32001A32001A32001A32001A32001B33001B33001B33001B33001C33001C34001C34
001D34001D34001D34001D35001E35001E35001E35001F35001F36001F36002036002036
00203700213700213700223700223800223800233800233800243900243900253900253A
00263A00263A00273B00283B00283B00293C00293C002A3C002B3D002B3D002C3E002D3E
002E3F002F3F002F3F003040003140003241003342003442003543003743003844003944
003A45003C46003D47003F4700414800424900444A00464B00484C004A4D004D4E004F4E
00504E00514D00524D00544C00554B00564A005849005A48005C47005E45006043006241
00653E00673B006A38006E3300712E007627007A1F008015008608088D001F96003EA000
6AAD00ACBF00FF0000FF0000FF0000FF0000ACBF006AAD003EA0001F9600088D00008608
008015007A1F00762700712E006E33006A3800673B00653E006241006043005E45005C47
005A4800584900564A00554B00544C00524D00514D00504E004F4E004D4E004A4D00484C
00464B00444A004249004148003F47003D47003C46003A45003945003844003743003543
003442003342003241003140003040002F3F002F3F002E3F002D3E002C3E002B3D002B3D
002A3C00293C00293C00283B00283B00273B00263A00263A00253A002539002439002439
002338002338002238002238002237002137002137002037002036002036001F36001F36
001F35001E35001E35001E35001D35001D34001D34001D34001C34001C34001C33001B33
001B33001B33001B33001A32001A32001A32001A32001A32
001A32001A32001A32001A32001B33001B33001B33001B33001C33001C33001C34001C34
001D34001D34001D34001E35001E35001E35001F35001F36001F36002036002036002036
00213700213700213700223700223800233800233800243900243900253900253A00263A
00263A00273A00273B00283B00293C00293C002A3C002A3D002B3D002C3E002D3E002D3E
002E3F002F3F003040003140003241003341003442003542003643003744003944003A45
003B46003D46003E4700404800414900434900454A00474B00494C004B4D004E4E004F4E
00504E00524D00534C00544C00564B00574A005949005B48005D46005F44006142006340
00663D00693A006C36006F3100732B007724007C1B0082100089011090002999004CA500
7FB300C6C100FF0000FF0000FF0000FF0000C6C0007FB3004CA5002A9900109000008901
008210007C1B00772400732B006F31006C3600693A00663D006340006142005F44005D46
005B4800594900574A00564B00544C00534C00524D00504D004F4E004E4E004B4D00494C
00474B00454A004349004149004048003E47003D46003B46003A45003944003744003643
003542003442003341003241003140003040002F3F002E3F002D3E002D3E002C3E002B3D
002A3D002A3C00293C00293C00283B00273B00273A00263A00263A00253A002539002439
002439002338002338002238002237002137002137002137002036002036002036001F36
001F36001F35001E35001E35001E35001D34001D34001D34001C34001C34001C33001C33
001B33001B33001B33001B33001A32001A32001A32001A32
001A32001A32001A32001B33001B33001B33001B33001C33001C33001C34001C34001D34
001D34001D34001D35001E35001E35001E35001F35001F36001F36002036002036002137
00213700213700223700223800233800233800233900243900243900253900253A00263A
00273A00273B00283B00283B00293C002A3C002A3D002B3D002C3D002C3E002D3E002E3F
002F3F003040003040003141003241003342003442003643003743003844003945003B45
003C46003D47003F4700414800424900444A00464B00484C004A4D004D4E004F4E00504E
00514D00524D00544C00554B00564A005849005A48005C47005D4500604300624100643F
00673C006A38006D3400712F007528007920007F1700840B048B00199400359D005CAA00
96B900CEAC00FF0000FF0000FF0000FF0000CEAC0096B9005CAA00359D00199400048B00
00840A007F1700792000752800712F006D34006A3800673C00643F006241006043005D45
005C47005A4800584900564A00554B00544C00524D00514D00504E004F4E004D4E004A4D
00484C00464B00444A004249004148003F47003D47003C46003B45003945003844003743
003643003442003342003241003141003040003040002F3F002E3F002D3E002C3E002C3D
002B3D002A3D002A3C00293C00283B00283B00273B00273A00263A00253A002539002439
002439002439002338002338002238002237002137002137002137002036002036001F36
001F36001F35001E35001E35001E35001D35001D34001D34001D34001C34001C34001C33
001C33001B33001B33001B33001B33001A32001A32001A32
001A32001A32001A32001B33001B33001B33001B33001C33001C34001C34001D34001D34
001D34001D35001E35001E35001E35001F35001F36001F36002036002036002037002137
00213700223700223800223800233800233800243900243900253900253A00263A00263A
00273B00273B00283B00293C00293C002A3C002B3D002B3D002C3E002D3E002E3E002E3F
002F3F003040003140003241003341003442003542003643003744003944003A45003B46
003D46003E4700404800414900434900454A00474B00494C004B4D004E4E004F4E00504E
00524D00534C00544C00564B00574A005949005B48005C46005E4400614300634000653D
00683A006B36006F3200722C007725007B1D0081120087050B8E0022970041A1006EAF00
B0C000D79400FF0000FF0000FF0000FF0000D79400B0C0006EAF0042A1002297000B8E00
008705008112007B1D00772500722C006F32006B3600683A00653D006340006143005E44
005C46005B4800594900574A00564B00544C00534C00524D00504E004F4E004E4E004B4D
00494C00474B00454A004349004249004048003E47003D46003B46003A45003944003744
003643003542003442003341003241003140003040002F3F002E3F002E3E002D3E002C3E
002B3D002B3D002A3C00293C00293C00283B00273B00273B00263A00263A00253A002539
002439002439002338002338002238002238002237002137002137002037002036002036
001F36001F36001F35001E35001E35001E35001D35001D34001D34001D34001C34001C34
001C33001B33001B33001B33001B33001A32001A32001A32
001A32001A32001B33001B33001B33001B33001C33001C33001C34001C34001D34001D34
001D34001E35001E35001E35001F35001F36001F36002036002036002036002137002137
00213700223700223800233800233800243900243900253900253900263A00263A00273A
00273B00283B00283B00293C002A3C002A3D002B3D002C3D002C3E002D3E002E3F002F3F
003040003140003241003341003442003542003643003743003844003945003B45003C46
003D47003F4700414800424900444A00464B00484C004A4D004D4E004F4E00504E00514D
00524D00534C00554B00564A00584A005A48005B47005D45005F4400624200643F00673C
006939006D3500703000742A007822007D1900830E008A001391002C9A004FA60081B400
C6C000E07800FF0000FF0000FF0000FF0000E07700C6C00081B4004FA6002C9A00139100
008A0000830E007D1900782200742A007030006D3500693900673C00643F006242005F44
005D45005B47005A4800584900564A00554B00534C00524D00514D00504E004F4E004D4E
004A4D00484C00464B00444A004249004148003F47003E47003C46003B45003945003844
003743003643003542003442003341003241003140003040002F3F002E3F002D3E002C3E
002C3D002B3D002A3D002A3C00293C00283B00283B00273B00273A00263A00263A002539
002539002439002439002338002338002238002237002137002137002137002036002036
002036001F36001F36001F35001E35001E35001E35001D34001D34001D34001C34001C34
001C33001C33001B33001B33001B33001B33001A32001A32
001A32001B33001B33001B33001B33001C33001C33001C34001C34001D34001D34001D34
001D35001E35001E35001E35001F35001F36001F36002036002036002137002137002137
00223700223800233800233800233800243900243900253900253A00263A00263A00273B
00283B00283B00293C00293C002A3C002B3D002B3D002C3E002D3E002E3E002E3F002F3F
003040003140003241003341003442003543003643003744003944003A45003B46003D46
003E4700404800424900434900454A00474B00494C004B4D004E4E004F4E00504E00514D
00534C00544C00564B00574A005949005A48005C46005E4500604300634100653E00683B
006B37006E3300722D007627007A1F007F15008509068C001B9400379E005EAA0096B900
CDAE00EA5600FF0000FF0000FF0000FF0000EA5500CDAE0096B9005EAA00379E001B9400
068C00008509007F15007A1F00762700722D006E33006B3700683B00653E006341006043
005E45005C46005A4800594900574A00564B00544C00534C00514D00504E004F4E004E4E
004B4D00494C00474B00454A004349004249004048003E47003D46003B46003A45003944
003744003643003543003442003341003241003140003040002F3F002E3F002E3E002D3E
002C3E002B3D002B3D002A3C00293C00293C00283B00283B00273B00263A00263A00253A
002539002439002439002338002338002338002238002237002137002137002137002036
002036001F36001F36001F35001E35001E35001E35001D35001D34001D34001D34001C34
001C34001C33001C33001B33001B33001B33001B33001A32
001A32001B33001B33001B33001B33001C33001C34001C34001D34001D34001D34001D34
001E35001E35001E35001F35001F36001F36002036002036002037002137002137002237
00223800223800233800233800243900243900253900253A00263A00263A00273A00273B
00283B00283C00293C002A3C002A3D002B3D002C3D002D3E002D3E002E3F002F3F003040
003140003241003341003442003542003643003743003844003945003B45003C46003E47
003F4700414800424900444A00464B00484C004A4D004D4E004F4E00504E00514D00524D
00534C00554B00564B00584A005948005B47005D46005F4400614200643F00663D006939
006C35006F3100732B007724007C1B0081110088030D8F0024970043A2006EAF00ADBF00
D59900F42D00FF0000FF0000FF0000FF0000F52D00D59900AEBF006EAF0043A200249700
0D8F00008803008211007C1B00772400732B006F31006C3500693900663D00643F006142
005F44005D46005B4700594800584A00564B00554B00534C00524D00514D00504E004F4E
004D4E004A4D00484C00464B00444A004249004148003F47003E47003C46003B45003945
003844003743003643003542003442003341003241003140003040002F3F002E3F002D3E
002D3E002C3D002B3D002A3D002A3C00293C00283C00283B00273B00273A00263A00263A
00253A002539002439002439002338002338002238002238002237002137002137002037
002036002036001F36001F36001F35001E35001E35001E35001D34001D34001D34001D34
001C34001C34001C33001B33001B33001B33001B33001A32
001B33001B33001B33001B33001C33001C33001C34001C34001D34001D34001D34001E35
001E35001E35001F35001F35001F36002036002036002036002137002137002137002237
00223800233800233800243900243900243900253900253A00263A00273A00273B00283B
00283B00293C00293C002A3C002B3D002C3D002C3E002D3E002E3F002F3F002F3F003040
003140003241003341003442003543003643003844003944003A45003B46003D46003E47
00404800424900434900454A00474B00494C004B4D004E4E004F4E00504E00514D00534C
00544C00554B00574A005849005A48005C47005E4500604300624100653E00673B006A38
006D3400712F007528007921007E1800840C018A001492002D9B004FA6007FB300C5C300
DD8100FF0000FF0000FF0000FF0000FF0000FF0000DD8100C5C3007FB3004FA6002D9B00
149200018A0000840C007E1800792100752800712F006D34006A3800673B00653E006241
006043005E45005C47005A4800584900574A00554B00544C00534C00514D00504E004F4E
004E4E004B4D00494C00474B00454A004349004249004048003E47003D46003B46003A45
003944003844003643003543003442003341003241003140003040002F3F002F3F002E3F
002D3E002C3E002C3D002B3D002A3C00293C00293C00283B00283B00273B00273A00263A
00253A002539002439002439002439002338002338002238002237002137002137002137
002036002036002036001F36001F35001F35001E35001E35001E35001D34001D34001D34
001C34001C34001C33001C33001B33001B33001B33001B33
001B33001B33001B33001C33001C33001C34001C34001D34001D34001D34001D35001E35
001E35001E35001F35001F36001F36002036002036002037002137002137002237002238
00223800233800233800243900243900253900253A00263A00263A00273B00273B00283B
00293C00293C002A3C002B3D002B3D002C3E002D3E002D3E002E3F002F3F003040003140
003241003341003442003542003643003743003844003945003B45003C46003E47003F47
00414800424900444A00464B00484C004A4D004C4D004F4E00504E00514D00524D00534C
00554B00564B00584A005949005B47005D46005F4400614200634000663D00683A006B36
006F3200722C007626007B1E008014008608078D001C9400379E005CAA0092B800CBB400
E56500FF0000FF0000FF0000FF0000FF0000FF0000E56500CBB40092B8005CAA00379E00
1C9500078D00008608008014007B1E00762600722C006F32006B3600683A00663D006340
006142005F44005D46005B4700594900584A00564B00554B00534C00524D00514D00504E
004F4E004C4E004A4D00484C00464B00444A004249004148003F47003E47003C46003B45
003945003844003743003643003542003442003341003241003140003040002F3F002E3F
002D3E002D3E002C3E002B3D002B3D002A3C00293C00293C00283B00273B00273B00263A
00263A00253A002539002439002439002338002338002238002238002237002137002137
002037002036002036001F36001F36001F35001E35001E35001E35001D35001D34001D34
001D34001C34001C34001C33001C33001B33001B33001B33
001B33001B33001B33001C33001C34001C34001C34001D34001D34001D34001E35001E35
001E35001F35001F36001F36002036002036002036002137002137002137002237002238
00233800233800243900243900253900253900263A00263A00273A00273B00283B00283B
00293C002A3C002A3D002B3D002C3D002C3E002D3E002E3F002F3F002F3F003040003140
003241003341003442003543003643003844003944003A45003B46003D46003E47004048
00424900434900454A00474B00494C004B4D004E4E004F4E00504E00514D00534D00544C
00554B00574A005849005A48005C47005E4500604300624100643F00673C006939006D35
00703000742A007823007D1B0082100088030D8F0024970041A1006BAE00A6BD00D2A300
EE4600FF0000FF0000FF0000FF0000FF0000FF0000EE4600D2A300A6BD006BAE0041A100
2497000D8F00008803008210007D1B00782300742A007030006D35006A3900673C00643F
006241006043005E45005C47005A4800584900574A00554B00544C00534D00514D00504E
004F4E004E4E004B4D00494C00474B00454A004349004249004048003E47003D46003B46
003A45003944003844003643003543003442003341003241003140003040002F3F002F3F
002E3F002D3E002C3E002C3D002B3D002A3D002A3C00293C00283B00283B00273B00273A
00263A00263A002539002539002439002439002338002338002238002237002137002137
002137002036002036002036001F36001F36001F35001E35001E35001E35001D34001D34
001D34001C34001C34001C34001C33001B33001B33001B33
001B33001B33001C33001C33001C34001C34001D34001D34001D34001E35001E35001E35
001E35001F35001F36001F36002036002036002137002137002137002237002238002338
00233800233800243900243900253900253A00263A00263A00273B00273B00283B00293C
00293C002A3C002B3D002B3D002C3E002D3E002D3E002E3F002F3F003040003140003241
003341003442003542003643003743003844003945003B45003C46003E47003F47004148
00424900444A00464B00484C004A4C004C4D004E4E00504E00514D00524D00534C00544C
00564B00574A005949005B48005C46005E4500604300634000653E00683B006B37006E33
00712E007528007920007E1700840C018A001492002C9A004CA50079B200BBC200D89000
F72300FF0000FF0000FF0000FF0000FF0000FF0000F72200D88F00BBC2007AB2004CA500
2C9A00149200018A0000840C007E1700792000752800712E006E33006B3700683B00653E
006340006043005E45005C46005B4800594900574A00564B00544C00534C00524D00514D
00504E004E4E004C4D004A4C00484C00464B00444A004249004148003F47003E47003C46
003B45003945003844003743003643003542003442003341003241003140003040002F3F
002E3F002D3E002D3E002C3E002B3D002B3D002A3C00293C00293C00283B00273B00273B
00263A00263A00253A002539002439002439002338002338002338002238002237002137
002137002137002036002036001F36001F36001F35001E35001E35001E35001E35001D34
001D34001D34001C34001C34001C33001C33001B33001B33
001B33001C33001C33001C34001C34001D34001D34001D34001D35001E35001E35001E35
001F35001F36001F36002036002036002037002137002137002237002238002238002338
00233800243900243900253900253A00263A00263A00273A00273B00283B00283B00293C
002A3C002A3D002B3D002C3D002C3E002D3E002E3F002F3F003040003040003140003241
003342003442003543003643003844003944003A45003B46003D46003E47004048004149
00434900454A00474B00494C004B4D004D4E004F4E00504E00514D00524D00544C00554B
00564A005849005A48005B47005D46005F4400614200643F00663D00693A006C36006F31
00732C007725007B1D008014008608078C001B9400359D0058A80089B600C8BD00DF7B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000DF7A00C8BD0089B60058A800
359D001B9400078C00008608008014007B1D00772500732C006F31006C3600693A00663D
00643F006142005F44005D46005B47005A4800584900564A00554B00544C00524D00514D
00504E004F4E004D4E004B4D00494C00474B00454A004349004149004048003E47003D46
003B46003A45003944003844003643003543003442003342003241003140003040003040
002F3F002E3F002D3E002C3E002C3D002B3D002A3D002A3C00293C00283B00283B00273B
00273A00263A00263A00253A002539002439002439002338002338002238002238002237
002137002137002037002036002036001F36001F36001F35001E35001E35001E35001D35
001D34001D34001D34001C34001C34001C33001C33001B33
001B33001C33001C33001C34001C34001D34001D34001D34001E35001E35001E35001F35
001F36001F36002036002036002036002137002137002137002237002238002338002338
00233900243900243900253900253A00263A00263A00273B00283B00283B00293C00293C
002A3C002B3D002B3D002C3E002D3E002E3E002E3F002F3F003040003140003241003341
003442003542003643003743003844003945003B45003C46003E47003F47004148004249
00444A00464B00484B004A4C004C4D004E4E004F4E00514D00524D00534C00544C00564B
00574A005949005A48005C46005E4500604300624100653E00673C006A38006D3400702F
00742A007823007D1A0082100088030C8F002297003EA00064AC009ABA00CDB000E66300
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000E66300CDB0009ABA0064AC00
3EA0002297000C8F00008803008210007D1A00782300742A00702F006D34006A3800673C
00653E006241006043005E45005C46005A4800594900574A00564B00544C00534C00524D
00514D004F4E004E4E004C4D004A4C00484B00464B00444A004249004148003F47003E47
003C46003B45003945003844003743003643003542003442003341003241003140003040
002F3F002E3F002E3E002D3E002C3E002B3D002B3D002A3C00293C00293C00283B00283B
00273B00263A00263A00253A002539002439002439002439002338002338002238002237
002137002137002137002036002036002036001F36001F36001F35001E35001E35001E35
001D34001D34001D34001C34001C34001C33001C33001B33
001C33001C33001C34001C34001D34001D34001D34001D35001E35001E35001E35001F35
001F36001F36002036002036002037002137002137002237002238002238002338002338
00243900243900253900253A00263A00263A00273A00273B00283B00283C00293C002A3C
002A3D002B3D002C3D002C3E002D3E002E3F002F3F003040003040003141003241003342
003442003543003643003844003944003A45003B46003D46003E47004048004149004349
00454A00474B00494C004B4D004D4E004F4E00504E00514D00524D00534C00554B00564B
00584A005949005B47005D46005F4400614200634000653D00683A006B37006E3300712E
007528007920007E1700840C008A0012910029990047A30070AF00ABBE00D2A100ED4B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000ED4A00D2A100ABBE0071AF00
47A300299900129100018A0000840C007E17007A2000752800712E006E33006B3700683A
00653D006340006142005F44005D46005B4700594900584A00564B00554B00534C00524D
00514D00504E004F4E004D4E004B4D00494C00474B00454A004349004149004048003E47
003D46003B46003A45003944003844003643003543003442003342003241003141003040
003040002F3F002E3F002D3E002C3E002C3D002B3D002A3D002A3C00293C00283C00283B
00273B00273B00263A00263A00253A002539002439002439002338002338002238002238
002237002137002137002037002036002036001F36001F36001F35001E35001E35001E35
001E35001D34001D34001D34001C34001C34001C33001C33
001C33001C34001C34001D34001D34001D34001D35001E35001E35001E35001F35001F36
001F36002036002036002036002137002137002137002237002238002338002338002439
00243900243900253900253A00263A00273A00273B00283B00283B00293C00293C002A3C
002B3D002B3D002C3E002D3E002E3E002E3F002F3F003040003140003241003341003442
003542003643003743003844003945003B45003C46003D47003F4700414800424900444A
00464B00484B004A4C004C4D004E4E004F4E00504D00524D00534C00544C00554B00574A
005849005A48005C47005E45005F4400624100643F00663C006939006C35006F3100732C
007725007B1E008014008508058C00189300309C0051A6007DB300BDC300D79200F43000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F43000D79200BDC3007DB300
51A600309C00189300058C00008508008014007B1E00772500732C006F31006C35006939
00663C00643F006241006043005E45005C47005A4800584900574A00554B00544C00534C
00524D00504D004F4E004E4E004C4D004A4C00484B00464B00444A004249004148003F47
003D47003C46003B45003945003844003743003643003542003442003341003241003140
003040002F3F002E3F002E3E002D3E002C3E002B3D002B3D002A3C00293C00293C00283B
00283B00273B00273A00263A00253A002539002439002439002439002338002338002238
002237002137002137002137002036002036002036001F36001F36001F35001E35001E35
001E35001D35001D34001D34001D34001C34001C34001C33
001C33001C34001C34001D34001D34001D34001E35001E35001E35001E35001F35001F36
001F36002036002036002137002137002137002237002238002338002338002338002439
00243900253900253A00263A00263A00273B00273B00283B00293C00293C002A3C002A3D
002B3D002C3D002C3E002D3E002E3F002F3F003040003040003141003241003342003442
003543003643003844003944003A45003B46003D46003E4700404800414800434900454A
00474B00494C004B4D004D4E004F4E00504E00514D00524D00534C00554B00564B00574A
005949005B48005C46005E4500604300624100653E00673B006A38006D3400702F00742A
007823007C1B0081110087040A8E001E9500389E005BA9008BB600C7BE00DD8200FB1400
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FB1400DD8200C7BE008BB600
5BA900389E001E95000A8E00008704008111007C1B00782300742A00702F006D34006A38
00673B00653E006241006043005E45005C46005B4800594900574A00564B00554B00534C
00524D00514D00504E004F4E004D4E004B4D00494C00474B00454A004349004148004048
003E47003D46003B46003A45003944003844003643003543003442003342003241003141
003040003040002F3F002E3F002D3E002C3E002C3D002B3D002A3D002A3C00293C00293C
00283B00273B00273B00263A00263A00253A002539002439002439002338002338002338
002238002237002137002137002137002036002036001F36001F36001F35001E35001E35
001E35001E35001D34001D34001D34001C34001C34001C33
001C34001C34001D34001D34001D34001D35001E35001E35001E35001F35001F36001F36
002036002036002037002137002137002237002238002238002338002338002439002439
00253900253900263A00263A00273A00273B00283B00283B00293C00293C002A3C002B3D
002B3D002C3E002D3E002E3E002E3F002F3F003040003140003241003341003442003542
003643003743003844003945003B45003C46003D47003F4700404800424900444A00464A
00474B00494C004C4D004E4E004F4E00504E00514D00534D00544C00554B00574A005849
005A48005B47005D46005F4400614200634000663D00683A006B37006E3300712E007528
007921007E1800830E0089000F900024980040A10065AC0098BA00CBB400E27100FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000E27100CBB40098BA00
65AC0040A1002498000F900000890000830D007E1800792100752800712E006E33006B37
00683A00663D006340006142005F44005D46005B47005A4800584900574A00554B00544C
00534D00514D00504E004F4E004E4E004C4D00494C00474B00464A00444A004249004048
003F47003D47003C46003B45003945003844003743003643003542003442003341003241
003140003040002F3F002E3F002E3E002D3E002C3E002B3D002B3D002A3C00293C00293C
00283B00283B00273B00273A00263A00263A002539002539002439002439002338002338
002238002238002237002137002137002037002036002036001F36001F36001F35001E35
001E35001E35001D35001D34001D34001D34001C34001C34
001C34001C34001D34001D34001D34001E35001E35001E35001F35001F36001F36002036
002036002036002137002137002137002237002238002338002338002338002439002439
00253900253A00263A00263A00273B00273B00283B00293C00293C002A3C002A3D002B3D
002C3D002D3E002D3E002E3F002F3F003040003040003141003241003342003442003543
003643003844003944003A45003B46003D46003E4700404800414800434900454A00464B
00484C004A4D004D4E004F4E00504E00514D00524D00534C00544C00564B00574A005949
005A48005C47005E4500604300624100643F00663C006939006C35006F3100732C007626
007B1E007F1500850A038B001492002A9A0048A3006FAF00A6BD00CFAA00E76000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000E76000CFA900A6BD00
6FAF0048A3002A9A00149200038B0000850A007F15007B1E00762600732C006F31006C35
00693900663C00643F006241006043005E45005C47005A4800594900574A00564B00544C
00534C00524D00514D00504E004F4E004D4E004A4D00484C00464B00454A004349004148
004048003E47003D46003B46003A45003944003844003643003543003442003342003241
003141003040003040002F3F002E3F002D3E002D3E002C3D002B3D002A3D002A3C00293C
00293C00283B00273B00273B00263A00263A00253A002539002439002439002338002338
002338002238002237002137002137002137002036002036002036001F36001F36001F35
001E35001E35001E35001D34001D34001D34001C34001C34
001C34001D34001D34001D34001E35001E35001E35001E35001F35001F36001F36002036
002036002037002137002137002237002238002238002338002338002439002439002539
00253900263A00263A00273A00273B00283B00283B00293C00293C002A3C002B3D002B3D
002C3E002D3E002E3E002E3F002F3F003040003140003241003341003442003542003643
003743003844003945003B45003C46003D47003F4700404800424900444900454A00474B
00494C004B4D004D4E004F4E00504E00514D00524D00544C00554B00564B00584A005949
005B47005D46005E4400604300634100653E00673B006A38006D3400703000742A007824
007C1C008112008607078C00199400319C0050A60079B200B3C000D39F00EC4F00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EC4F00D39F00B3C000
79B20050A600319C00199400078C00008607008112007C1C00782400742A007030006D34
006A3800673B00653E006341006043005E44005D46005B4700594900584A00564B00554B
00544C00524D00514D00504E004F4E004E4E004B4D00494C00474B00454A004449004249
004048003F47003D47003C46003B45003945003844003743003643003542003442003341
003241003140003040002F3F002E3F002E3E002D3E002C3E002B3D002B3D002A3C00293C
00293C00283B00283B00273B00273A00263A00263A002539002539002439002439002338
002338002238002238002237002137002137002037002036002036001F36001F36001F35
001E35001E35001E35001E35001D34001D34001D34001C34
001D34001D34001D34001D35001E35001E35001E35001F35001F36001F36002036002036
002036002137002137002137002237002238002338002338002338002439002439002539
00253A00263A00263A00273B00273B00283B00293C00293C002A3C002A3D002B3D002C3D
002D3E002D3E002E3F002F3F003040003040003140003241003341003442003543003643
003744003944003A45003B46003C46003E47003F4800414800434900444A00464B00484C
004A4C004C4D004E4E004F4E00504D00524D00534C00544C00554B00574A005849005A48
005B47005D46005F4400614200634000663D00683A006B37006E3300712E007528007922
007D1900820F0088030B8E001E9500379E0058A80083B400C1C400D79400F03F00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F03F00D79400C1C400
84B40058A800379E001E95000B8E0000880300820F007D1900792200752800712E006E33
006B3700683A00663D006340006142005F44005D45005B47005A4800584900574A00554B
00544C00534C00524D00504D004F4E004E4E004C4D004A4C00484C00464B00444A004349
004148003F48003E47003C46003B46003A45003944003744003643003543003442003341
003241003141003040003040002F3F002E3F002D3E002D3E002C3D002B3D002A3D002A3C
00293C00293C00283B00273B00273B00263A00263A00253A002539002439002439002338
002338002338002238002237002137002137002137002036002036002036001F36001F36
001F35001E35001E35001E35001D35001D34001D34001D34
001D34001D34001D34001E35001E35001E35001E35001F35001F36001F36002036002036
00203700213700213700223700223800223800233800233800243900243900253900253A
00263A00263A00273A00273B00283B00283B00293C002A3C002A3C002B3D002B3D002C3E
002D3E002E3E002E3F002F3F003040003140003241003341003442003542003643003743
003844003945003A45003C46003D46003F4700404800424900434900454A00474B00494C
004B4D004D4E004F4E00504E00514D00524D00534C00554C00564B00574A005949005A48
005C46005E4500604300624100643F00663C006939006C36006F3100722C007627007A1F
007E1700840D0089000F90002397003DA0005FAA008DB700C7BF00DA8A00F42F00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F42F00DA8A00C7BF00
8EB70060AB003DA0002397000F900000890000840C007E17007A1F00762600722C006F31
006C3600693900663C00643F006241006043005E45005C46005A4800594900574A00564B
00554C00534C00524D00514D00504E004F4E004D4E004B4D00494C00474B00454A004349
004249004048003F47003D46003C46003A45003945003844003743003643003542003442
003341003241003140003040002F3F002E3F002E3E002D3E002C3E002B3D002B3D002A3C
002A3C00293C00283B00283B00273B00273A00263A00263A00253A002539002439002439
002338002338002238002238002237002137002137002137002036002036001F36001F36
001F35001E35001E35001E35001E35001D34001D34001D34
001D34001D34001D35001E35001E35001E35001F35001F36001F36002036002036002036
00213700213700213700223700223800233800233800243900243900243900253900253A
00263A00263A00273B00273B00283B00293C00293C002A3C002A3D002B3D002C3D002D3E
002D3E002E3F002F3F003040003040003140003241003341003442003543003643003744
003944003A45003B45003C46003E47003F4700414800424900444A00464B00484B004A4C
004C4D004E4E004F4E00504E00514D00524D00544C00554B00564A00584A005949005B47
005D46005E4400604300634100653E00673B006A38006D3400703000732B007725007B1D
00801400850A038B0013910028990043A20067AD0097BA00C9B900DD8000F82000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F82000DD8000C9B800
97BA0067AD0044A200289900139100038B0000850A008014007B1D00772500732B007030
006D34006A3800673B00653E006341006043005E44005D46005B4700594900584A00564A
00554B00544C00524D00514D00504E004F4E004E4E004C4D004A4C00484B00464B00444A
004249004148003F47003E47003C46003B45003A45003944003744003643003543003442
003341003241003140003040003040002F3F002E3F002D3E002D3E002C3D002B3D002A3D
002A3C00293C00293C00283B00273B00273B00263A00263A00253A002539002439002439
002439002338002338002238002237002137002137002137002036002036002036001F36
001F36001F35001E35001E35001E35001D35001D34001D34
001D34001D34001E35001E35001E35001F35001F35001F36001F36002036002036002137
00213700213700223700223800223800233800233800243900243900253900253A00263A
00263A00273A00273B00283B00283B00293C002A3C002A3C002B3D002B3D002C3E002D3E
002E3E002E3F002F3F003040003140003241003341003442003542003643003743003844
003944003A45003C46003D46003E4700404800414800434900454A00474B00484C004A4D
004D4E004F4E00504E00514D00524D00534C00544C00554B00574A005849005A48005C47
005D45005F4400614200634000663D00683A006B37006E3300712F007429007823007C1B
008112008607068C001793002D9B0049A4006FAF00A0BC00CCB200E07600FB1400FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FB1300E07600CCB200
A1BC006FAF004AA4002D9B00179300068C00008607008112007C1B00782300742900712F
006E33006B3700683A00663D006340006142005F44005D45005C47005A4800584900574A
00554B00544C00534C00524D00514D00504E004F4E004D4E004B4D00484C00474B00454A
004349004149004048003E47003D46003C46003A45003944003844003743003643003542
003442003341003241003140003040002F3F002E3F002E3E002D3E002C3E002B3D002B3D
002A3D002A3C00293C00283B00283B00273B00273A00263A00263A00253A002539002439
002439002338002338002238002238002237002137002137002137002036002036001F36
001F36001F35001F35001E35001E35001E35001D34001D34
001D34001D35001E35001E35001E35001F35001F36001F36002036002036002037002137
00213700213700223700223800233800233800243900243900243900253900253A00263A
00263A00273B00273B00283B00293C00293C002A3C002A3D002B3D002C3D002C3E002D3E
002E3F002F3F003040003040003140003241003341003442003542003643003744003844
003A45003B45003C46003E47003F4700404800424900444A00454A00474B00494C004B4D
004D4E004F4E00504E00514D00524D00534C00554B00564B00574A005949005A48005C46
005E4500604300624100643F00663D00693A006B36006E3200722D007528007921007D19
0082100087040A8E001B9400329C004FA60076B100A9BE00CEAC00E36E00FD0900FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FD0800E36E00CEAC00
A9BE0076B1004FA600329C001C94000A8E0000870400820F007D1900792100752800722D
006E32006B3600693A00663D00643F006241006043005E45005C46005A4800594900574A
00564B00554B00534C00524D00514D00504E004F4E004E4E004B4D00494C00474B00454A
00444A004249004048003F47003E47003C46003B45003A45003844003744003643003542
003442003341003241003140003040003040002F3F002E3F002D3E002D3E002C3D002B3D
002A3D002A3C00293C00293C00283B00273B00273B00263A00263A00253A002539002439
002439002439002338002338002238002237002137002137002137002037002036002036
001F36001F36001F35001E35001E35001E35001D35001D34
001D34001E35001E35001E35001F35001F36001F36002036002036002036002137002137
00213700223700223800233800233800233800243900243900253900253A00263A00263A
00273A00273B00283B00283B00293C002A3C002A3C002B3D002B3D002C3E002D3E002E3E
002E3F002F3F003040003140003241003341003442003542003643003743003844003944
003A45003B46003D46003E4700404800414800434900444A00464B00484C004A4C004C4D
004E4E004F4E00504D00514D00534D00544C00554B00564A00584A005948005B47005D46
005E4400604300624100653E00673C006A39006C35006F3100732C007626007A1F007E17
00830D0089010D8F001F9600379E0055A7007CB300B1C000D0A600E56700FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000E56700D0A600
B1C0007CB30055A700379E001F96000D8F0000890100830D007E17007A1F00762600732C
006F31006C35006A3900673C00653E006241006043005E44005D46005B4700594800584A
00564A00554B00544C00534C00514D00504D004F4E004E4E004C4D004A4C00484C00464B
00444A004349004148004048003E47003D46003B46003A45003944003844003743003643
003542003442003341003241003140003040002F3F002E3F002E3E002D3E002C3E002B3D
002B3D002A3C002A3C00293C00283B00283B00273B00273A00263A00263A00253A002539
002439002439002338002338002338002238002237002137002137002137002036002036
002036001F36001F36001F35001E35001E35001E35001D34
001E35001E35001E35001E35001F35001F36001F36002036002036002037002137002137
00223700223700223800233800233800243900243900243900253900253A00263A00263A
00273B00273B00283B00293C00293C002A3C002A3D002B3D002C3D002C3E002D3E002E3F
002F3F003040003040003140003241003341003442003542003643003743003844003945
003B45003C46003D47003F4700404800424900434900454A00474B00494C004B4D004D4E
004F4E00504E00514D00524D00534C00544C00564B00574A005849005A48005B47005D46
005F4400614200634000653E00683B006A38006D3400703000732B007725007B1D007F15
00840B018A001090002397003B9F005AA90083B400B9C200D2A100E76100FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000E76100D2A100
B9C20083B4005AA9003B9F00239700109000018A0000840B007F15007B1D00772500732B
007030006D34006A3800683B00653E006340006142005F44005D46005B47005A48005849
00574A00564B00544C00534C00524D00514D00504E004F4E004D4E004B4D00494C00474B
00454A004349004249004048003F47003D47003C46003B45003945003844003744003643
003542003442003341003241003140003040003040002F3F002E3F002D3E002C3E002C3D
002B3D002A3D002A3C00293C00293C00283B00273B00273B00263A00263A00253A002539
002439002439002439002338002338002238002238002237002137002137002037002036
002036001F36001F36001F35001E35001E35001E35001E35
001E35001E35001E35001F35001F36001F36002036002036002036002137002137002137
00223700223800233800233800233800243900243900253900253A00263A00263A00273A
00273B00283B00283B00293C002A3C002A3C002B3D002B3D002C3E002D3E002E3E002E3F
002F3F003040003140003241003241003342003442003543003643003844003944003A45
003B46003C46003E47003F4800414800424900444A00464B00484B004A4C004C4D004E4E
004F4E00504E00514D00524D00534C00554B00564B00574A005949005A48005C46005E45
00604300624200643F00663D00683A006B37006E3300712E007429007823007C1C008013
008508038B001391002798003FA1005FAA0088B600BFC300D49D00E85C00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000E85C00D49D00
BFC30088B6005FAA003FA100279900139100038B00008508008013007C1C007823007429
00712E006E33006B3700683A00663D00643F006242006043005E45005C46005A48005949
00574A00564B00554B00534C00524D00514D00504E004F4E004E4E004C4D004A4C00484B
00464B00444A004249004148003F48003E47003D46003B46003A45003944003844003643
003543003442003342003341003241003140003040002F3F002E3F002E3E002D3E002C3E
002B3D002B3D002A3C002A3C00293C00283B00283B00273B00273A00263A00263A00253A
002539002439002439002338002338002338002238002237002137002137002137002036
002036002036001F36001F36001F35001E35001E35001E35
001E35001E35001E35001F35001F36001F36002036002036002037002137002137002237
00223800223800233800233800243900243900243900253900253A00263A00263A00273B
00273B00283B00293C00293C002A3C002A3D002B3D002C3D002C3E002D3E002E3F002F3F
002F3F003040003140003241003341003442003542003643003743003844003945003A45
003C46003D46003E4700404800414900434900454A00464B00484C004A4D004C4D004E4E
004F4E00504D00524D00534C00544C00554B00564A00584A005949005B47005D46005E45
00604300624100643F00673C006939006C36006F3200722D007528007922007D1A008111
008606068C001692002A9A0043A20063AC008DB700C4C400D59A00E95900FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000E95900D59A00
C4C4008DB70064AC0043A2002A9A00169200068C00008606008111007D1A007922007528
00722D006F32006C3600693900673C00643F006241006043005E45005D46005B47005949
00584A00564A00554B00544C00534C00524D00504D004F4E004E4E004C4D004A4D00484C
00464B00454A004349004149004048003E47003D46003C46003A45003945003844003743
003643003542003442003341003241003140003040002F3F002F3F002E3F002D3E002C3E
002C3D002B3D002A3D002A3C00293C00293C00283B00273B00273B00263A00263A00253A
002539002439002439002439002338002338002238002238002237002137002137002037
002036002036001F36001F36001F35001E35001E35001E35
001E35001E35001F35001F36001F36002036002036002036002137002137002137002237
00223800233800233800233800243900243900253900253A00263A00263A00273A00273B
00283B00283B00293C00293C002A3C002B3D002B3D002C3E002D3E002D3E002E3F002F3F
003040003140003141003241003342003442003543003643003744003944003A45003B45
003C46003E47003F4700404800424900444A00454A00474B00494C004B4D004D4E004F4E
00504E00514D00524D00534C00544C00564B00574A005849005A48005B47005D46005F44
00614200634000653E00673B006A38006C35006F3100722C007627007A20007E1800820F
008704088D001993002D9B0047A30067AD0091B800C5C200D69800E95800FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000E95800D69700
C5C20092B80067AD0047A3002D9B00199300088D0000870400820F007E18007A20007627
00722C006F31006C35006A3800673B00653E006340006142005F44005D46005B47005A48
00584900574A00564B00544C00534C00524D00514D00504E004F4E004D4E004B4D00494C
00474B00454A00444A004249004048003F47003E47003C46003B45003A45003944003744
003643003543003442003342003241003141003140003040002F3F002E3F002D3E002D3E
002C3E002B3D002B3D002A3C00293C00293C00283B00283B00273B00273A00263A00263A
00253A002539002439002439002338002338002338002238002237002137002137002137
002036002036002036001F36001F36001F35001E35001E35
001E35001E35001F35001F36001F36002036002036002037002137002137002237002238
00223800233800233800243900243900243900253900253A00263A00263A00273B00273B
00283B00293C00293C002A3C002A3D002B3D002C3D002C3E002D3E002E3F002F3F002F3F
003040003140003241003341003442003542003643003743003844003944003A45003B46
003D46003E4700404800414800434900444A00464B00484B004A4C004C4D004E4E004F4E
00504E00514D00524D00534C00554B00564B00574A005949005A48005C47005E45005F44
00614200634000653D00683B006A38006D3400703000732B007725007A1F007F1700830D
0088020B8E001B9400309C004AA4006BAE0095B900C6C000D69600E95800FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000E95800D69600
C6C00095B9006BAE004AA400309C001B94000B8E0000880200830D007F17007A1F007725
00732B007030006D34006A3800683B00653D006340006142005F44005E45005C47005A48
00594900574A00564B00554B00534C00524D00514D00504E004F4E004E4E004C4D004A4C
00484B00464B00444A004349004148004048003E47003D46003B46003A45003944003844
003743003643003542003442003341003241003140003040002F3F002F3F002E3F002D3E
002C3E002C3D002B3D002A3D002A3C00293C00293C00283B00273B00273B00263A00263A
00253A002539002439002439002439002338002338002238002238002237002137002137
002037002036002036001F36001F36001F35001E35001E35
001E35001F35001F36001F36002036002036002036002137002137002137002237002238
00233800233800233800243900243900253900253A00263A00263A00273A00273B00283B
00283B00293C00293C002A3C002B3D002B3D002C3E002D3E002D3E002E3F002F3F003040
003140003141003241003341003442003542003643003744003844003945003B45003C46
003D47003F4700404800424900434900454A00474B00494C004A4D004D4E004E4E004F4E
00504D00524D00534C00544C00554B00564A00584A005949005B48005C46005E45006043
00624100643F00663D00683A006B37006E3300712F00742A007724007B1D007F1500840C
0089000D8F001E9500339D004DA5006EAF0098BA00C7BF00D69600E95A00FF0300FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0300E95A00D69600
C7BF0098BA006EAF004DA500339D001E95000D8F0000890000840C007F15007B1D007724
00742A00712F006E33006B3700683A00663D00643F006241006043005E45005C46005B48
00594900584A00564A00554B00544C00534C00524D00504D004F4E004E4E004D4E004B4D
00494C00474B00454A004349004249004048003F47003D47003C46003B45003A45003844
003744003643003542003442003341003241003141003140003040002F3F002E3F002D3E
002D3E002C3E002B3D002B3D002A3C00293C00293C00283B00283B00273B00273A00263A
00263A00253A002539002439002439002338002338002338002238002237002137002137
002137002036002036002036001F36001F36001F35001E35
001F35001F35001F36001F36002036002036002037002137002137002237002238002238
00233800233800243900243900243900253900253A00263A00263A00273B00273B00283B
00293C00293C002A3C002A3D002B3D002C3D002C3E002D3E002E3F002E3F002F3F003040
003140003241003341003442003542003643003743003844003944003A45003B46003C46
003E47003F4700414800424900444A00464A00474B00494C004B4D004D4E004F4E00504E
00514D00524D00534C00544C00554B00574A005849005A48005B47005D46005E44006043
00624100643F00673C006939006B36006E3200712E007429007823007C1C00801400850A
018A000F9000209600359D004FA60070AF009ABA00C7BE00D69600E85D00FD0C00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FD0C00E85D00D69600
C7BE009ABA0070AF004FA600359D002096000F9000018A0000850A008014007C1C007823
00742900712E006E32006B3600693900673C00643F006241006043005E44005D46005B47
005A4800584900574A00554B00544C00534C00524D00514D00504E004F4E004D4E004B4D
00494C00474B00464A00444A004249004148003F47003E47003C46003B46003A45003944
003844003743003643003542003442003341003241003140003040002F3F002E3F002E3F
002D3E002C3E002C3D002B3D002A3D002A3C00293C00293C00283B00273B00273B00263A
00263A00253A002539002439002439002439002338002338002238002238002237002137
002137002037002036002036001F36001F36001F35001F35
001F35001F36001F36002036002036002036002137002137002137002237002238002338
00233800233800243900243900253900253A00263A00263A00273A00273B00283B00283B
00293C00293C002A3C002B3D002B3D002C3E002D3E002D3E002E3F002F3F003040003040
003140003241003341003442003542003643003743003844003945003A45003C46003D46
003E4700404800414800434900444A00464B00484C004A4C004C4D004E4E004F4E00504E
00514D00524D00534C00554B00564B00574A005949005A48005C47005D46005F44006142
00634000653E00673C006939006C35006F3100722D007528007922007C1B008112008508
028B00119000229700379E0051A60072B0009BBA00C7BE00D59800E66100FA1600FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FA1600E66100D69800
C7BE009BBA0072B00051A600379E00229700119000028B00008508008112007C1B007922
00752800722D006F31006C3500693900673C00653E006340006142005F44005D46005C47
005A4800594900574A00564B00554B00534C00524D00514D00504E004F4E004E4E004C4D
004A4C00484C00464B00444A004349004148004048003E47003D46003C46003A45003945
003844003743003643003542003442003341003241003140003040003040002F3F002E3F
002D3E002D3E002C3E002B3D002B3D002A3C00293C00293C00283B00283B00273B00273A
00263A00263A00253A002539002439002439002338002338002338002238002237002137
002137002137002036002036002036001F36001F36001F35
001F35001F36001F36002036002036002037002137002137002237002238002238002338
00233800243900243900243900253900253A00263A00263A00273B00273B00283B00293C
00293C002A3C002A3D002B3D002C3D002C3E002D3E002E3E002E3F002F3F003040003140
003241003241003342003442003543003643003744003944003A45003B45003C46003D47
003F4700404800424900434900454A00474B00494C004B4D004D4E004E4E004F4E00504D
00514D00534D00544C00554B00564B00584A005949005A48005C47005E45005F44006142
00634000653E00683B006A38006D35006F3100722C007627007921007D1A008111008607
048B00129100239700399F0053A70073B0009BBB00C7BF00D59A00E56700F72200FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F72200E56700D59A00
C7BF009BBB0073B00053A700399F00249700129100048B00008607008111007D1A007921
00762700722C006F31006D35006A3800683B00653E006340006142005F44005E45005C47
005A4800594900584A00564B00554B00544C00534D00514D00504D004F4E004E4E004D4E
004B4D00494C00474B00454A004349004249004048003F47003D47003C46003B45003A45
003944003744003643003543003442003342003241003241003140003040002F3F002E3F
002E3E002D3E002C3E002C3D002B3D002A3D002A3C00293C00293C00283B00273B00273B
00263A00263A00253A002539002439002439002439002338002338002238002238002237
002137002137002037002036002036001F36001F36001F35
001F36001F36002036002036002036002137002137002137002237002238002338002338
00233800243900243900253900253A00263A00263A00273A00273B00283B00283B00293C
00293C002A3C002B3D002B3D002C3D002D3E002D3E002E3F002F3F002F3F003040003140
003241003341003442003542003643003743003844003944003A45003B46003D46003E47
003F4800414800424900444A00464A00474B00494C004B4D004D4E004F4E00504E00514D
00524D00534C00544C00554B00574A005849005949005B47005C46005E45006043006241
00643F00663D00683A006A37006D3400703000732B007626007A20007E18008210008706
058C001491002598003A9F0054A70073B0009BBA00C6C000D49D00E36D00F42E00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F42E00E36D00D49D00
C6C0009BBA0073B00054A7003A9F00259800149100058C00008706008210007E18007A20
00762600732B007030006D34006B3700683A00663D00643F006241006043005E45005C46
005B4700594900584900574A00554B00544C00534C00524D00514D00504E004F4E004D4E
004B4D00494C00474B00464A00444A004249004148003F48003E47003D46003B46003A45
003944003844003743003643003542003442003341003241003140003040002F3F002F3F
002E3F002D3E002D3E002C3D002B3D002B3D002A3C00293C00293C00283B00283B00273B
00273A00263A00263A00253A002539002439002439002338002338002338002238002237
002137002137002137002036002036002036001F36001F36
001F36001F36002036002036002037002137002137002237002238002238002338002338
00243900243900243900253900253A00263A00263A00273B00273B00283B00283C00293C
002A3C002A3D002B3D002B3D002C3E002D3E002E3E002E3F002F3F003040003140003141
003241003341003442003542003643003744003844003945003B45003C46003D46003E47
00404800414800434900454A00464B00484C004A4C004C4D004E4E004F4E00504E00514D
00524D00534C00544C00564B00574A005849005A48005B47005D46005E44006043006241
00643F00663D00693A006B37006E3300702F00732A007725007A1F007E1700820F008705
068C001592002698003B9F0054A70073B00099BA00C5C200D2A100E17500F13B00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F13B00E17500D2A100
C5C20099BA0073B00054A7003B9F00269800159200068C0000870500820F007E17007A1F
00772500732A00702F006E33006B3700693A00663D00643F006241006043005E44005D46
005B47005A4800584900574A00564B00544C00534C00524D00514D00504E004F4E004E4E
004C4D004A4C00484C00464B00454A004349004148004048003E47003D46003C46003B45
003945003844003744003643003542003442003341003241003141003140003040002F3F
002E3F002E3E002D3E002C3E002B3D002B3D002A3D002A3C00293C00283C00283B00273B
00273B00263A00263A00253A002539002439002439002439002338002338002238002238
002237002137002137002037002036002036001F36001F36
001F36002036002036002036002137002137002137002237002238002338002338002338
00243900243900253900253A00263A00263A00273A00273B00283B00283B00293C00293C
002A3C002A3D002B3D002C3D002C3E002D3E002E3F002F3F002F3F003040003140003241
003341003442003542003643003743003844003944003A45003B45003C46003E47003F47
00404800424900434900454A00474B00494C004A4D004C4D004E4E004F4E00504E00514D
00524D00544C00554B00564B00574A005949005A48005C47005D46005F44006142006341
00653E00673C006939006B36006E3300712E00742A007724007B1E007F1700830E008804
078D001692002798003B9F0054A70072B00097BA00C4C400D1A500DE7D00ED4900FD0900
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FD0900ED4900DE7C00D1A500
C5C40097BA0072B00054A7003B9F00279800169200078D0000880400830E007F17007B1E
00772400742A00712E006E33006B3600693900673C00653E006341006142005F44005D46
005C47005A4800594900574A00564B00554B00544C00524D00514D00504E004F4E004E4E
004C4E004A4D00494C00474B00454A004349004249004048003F47003E47003C46003B45
003A45003944003844003743003643003542003442003341003241003140003040002F3F
002F3F002E3F002D3E002C3E002C3D002B3D002A3D002A3C00293C00293C00283B00283B
00273B00273A00263A00263A00253A002539002439002439002338002338002338002238
002237002137002137002137002036002036002036001F36
001F36002036002036002037002137002137002237002238002238002338002338002439
00243900243900253900253A00263A00263A00273B00273B00283B00283B00293C002A3C
002A3C002B3D002B3D002C3E002D3E002D3E002E3F002F3F003040003040003140003241
003341003442003542003643003743003844003945003A45003B46003D46003E47003F48
00414800424900444A00464A00474B00494C004B4D004D4E004F4E00504E00514D00524D
00534C00544C00554B00564A00584A005949005A48005C47005E45005F44006142006340
00653E00673C006939006C36006E3200712E007429007824007B1D007F1600830D008803
088D001692002799003B9F0054A70071AF0095B900C0C300CFAA00DC8500EA5600F81F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F81F00EA5600DC8500CFAA00
C0C30095B90071AF0054A7003B9F00279900169300088D0000880300830D007F16007B1D
00782300742900712E006E32006C3600693900673C00653E006340006142005F44005E45
005C47005A4800594900584A00564A00554B00544C00534C00524D00514D00504E004F4E
004D4E004B4D00494C00474B00464A00444A004249004148003F48003E47003D46003B46
003A45003945003844003743003643003542003442003341003241003140003040003040
002F3F002E3F002D3E002D3E002C3E002B3D002B3D002A3C002A3C00293C00283B00283B
00273B00273B00263A00263A00253A002539002439002439002439002338002338002238
002238002237002137002137002037002036002036001F36
002036002036002036002137002137002137002237002238002338002338002338002439
00243900253900253900263A00263A00273A00273B00283B00283B00293C00293C002A3C
002A3D002B3D002C3D002C3E002D3E002E3F002E3F002F3F003040003140003241003241
003342003442003543003643003744003844003A45003B45003C46003D47003F47004048
00414800434900444A00464B00484B004A4C004C4D004E4E004F4E00504E00514D00524D
00534C00544C00554B00574A005849005949005B47005C46005E45006043006142006340
00653E00673B006A38006C35006F3100722D007528007823007C1C007F1500840C008802
098D001793002799003B9F0053A7006FAF0091B800BAC200CDAF00D98D00E66400F33300
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F33300E66400D98D00CDAF00
BAC20091B8006FAF0053A7003B9F00279900179300098D0000880200840C007F15007C1C
00782300752800722D006F31006C35006A3800683B00653E006340006142006043005E45
005C46005B4700594900584900574A00554B00544C00534C00524D00514D00504E004F4E
004E4E004C4D004A4C00484B00464B00444A004349004148004048003F47003D47003C46
003B45003A45003844003744003643003543003442003342003241003241003140003040
002F3F002E3F002E3F002D3E002C3E002C3D002B3D002A3D002A3C00293C00293C00283B
00283B00273B00273A00263A00263A002539002539002439002439002338002338002338
002238002237002137002137002137002036002036002036
002036002036002037002137002137002237002238002238002338002338002439002439
00243900253900253A00263A00263A00273A00273B00283B00283B00293C00293C002A3C
002B3D002B3D002C3E002D3E002D3E002E3F002F3F002F3F003040003140003241003341
003442003542003643003743003844003944003A45003B45003C46003E47003F47004048
00424900434900454A00474B00484C004A4D004C4D004E4E004F4E00504E00514D00524D
00534C00544C00564B00574A005849005A48005B47005D46005E4500604300624100643F
00663D00683B006A38006D35006F3100722D007528007822007C1C00801400840C008802
098D001793002799003B9F0052A6006DAE008DB700B4C100CBB500D69600E27100EE4700
F91A00FF0000FF0000FF0000FF0000FF0000FF0000F91A00EE4700E27100D69600CBB400
B4C1008DB7006DAE0052A6003B9F00279900179300098D0000880200840C008014007C1C
00782200752800722D006F31006D35006A3800683B00663D00643F006241006043005E45
005D46005B47005A4800584900574A00564B00544C00534C00524D00514D00504E004F4E
004E4E004C4D004A4D00484C00474B00454A004349004249004048003F47003E47003C46
003B45003A45003944003844003743003643003542003442003341003241003140003040
002F3F002F3F002E3F002D3E002D3E002C3E002B3D002B3D002A3C00293C00293C00283B
00283B00273B00273A00263A00263A00253A002539002439002439002439002338002338
002238002238002237002137002137002037002036002036
002036002036002137002137002137002237002238002238002338002338002439002439
00253900253900253A00263A00263A00273B00273B00283B00293C00293C002A3C002A3D
002B3D002C3D002C3E002D3E002E3E002E3F002F3F003040003140003141003241003341
003442003542003643003743003844003945003A45003C46003D46003E47003F48004148
00424900444A00454A00474B00494C004B4D004D4E004F4E004F4E00504D00514D00534D
00544C00554B00564B00574A005949005A48005B47005D46005F4400604300624100643F
00663D00683A006B37006D3400703000722C007527007922007C1B00801400840B008901
098D001793002799003A9F0050A6006AAE0089B600ADBF00C9BA00D39E00DE7E00E95900
F33300FC0E00FF0000FF0000FF0000FF0000FC0E00F33300E95900DE7E00D39E00C9BA00
ADBF0089B6006AAE0050A6003A9F00279900179300098D0000890100840B008014007C1B
00792200752700722C007030006D34006B3700683A00663D00643F006241006043005F44
005D46005B47005A4800594900574A00564B00554B00544C00534D00514D00504D004F4E
004F4E004D4E004B4D00494C00474B00464A00444A004249004148003F48003E47003D46
003C46003A45003945003844003743003643003542003442003341003241003141003140
003040002F3F002E3F002E3E002D3E002C3E002C3D002B3D002A3D002A3C00293C00293C
00283B00273B00273B00263A00263A00253A002539002539002439002439002338002338
002238002238002237002137002137002137002036002036
002036002037002137002137002237002237002238002338002338002338002439002439
00253900253A00263A00263A00273A00273B00283B00283B00293C00293C002A3C002B3D
002B3D002C3D002C3E002D3E002E3F002F3F002F3F003040003140003241003341003342
003442003543003643003744003844003A45003B45003C46003D47003E47004048004148
00434900444A00464B00484B004A4C004B4D004D4E004F4E00504E00514D00524D00534C
00544C00554B00564B00584A005949005A48005C47005D45005F4400614200624100643F
00663C00693A006B37006D3400703000732C007627007921007C1B00801300840B008901
098D00179300269800389F004EA50067AD0084B500A6BD00C6C000D0A700DA8A00E46A00
ED4A00F52B00FB1300FE0600FE0600FB1300F52B00ED4A00E46A00DA8A00D0A700C6C000
A6BD0084B50067AD004EA500389F00269800179300098D0000890100840B008013007C1B
00792100762700732C007030006D34006B3700693A00663C00643F006241006142005F44
005D45005C47005A4800594900584A00564B00554B00544C00534C00524D00514D00504E
004F4E004D4E004B4D004A4C00484B00464B00444A004349004148004048003E47003D47
003C46003B45003A45003844003744003643003543003442003342003341003241003140
003040002F3F002F3F002E3F002D3E002C3E002C3D002B3D002B3D002A3C00293C00293C
00283B00283B00273B00273A00263A00263A00253A002539002439002439002338002338
002338002238002237002237002137002137002037002036
002036002137002137002137002237002238002238002338002338002439002439002539
00253900253A00263A00263A00273B00273B00283B00283C00293C002A3C002A3D002B3D
002B3D002C3E002D3E002D3E002E3F002F3F003040003040003140003241003341003442
003542003643003743003844003944003A45003B45003C46003E47003F47004048004249
00434900454A00464B00484C004A4C004C4D004E4E004F4E00504E00514D00524D00534C
00544C00554B00574A00584A005949005B48005C47005E45005F4400614200634000653E
00673C006939006B37006E3300703000732B007626007921007D1A00801300840B008901
098D00169200259800379E004BA50063AC007FB3009EBB00C2C400CDAF00D69600DF7B00
E75F00EE4500F33100F62700F62700F33100EE4500E75F00DF7A00D69600CDAF00C2C400
9EBB007FB30063AC004BA500379E00259800169200098D0000890100840B008013007D1A
00792100762600732B007030006E33006B3700693900673C00653E006340006142005F44
005E45005C46005B4800594900584A00574A00554B00544C00534C00524D00514D00504E
004F4E004E4E004C4D004A4C00484C00464B00454A004349004249004048003F47003E47
003C46003B45003A45003944003844003743003643003542003442003341003241003140
003040003040002F3F002E3F002D3E002D3E002C3E002B3D002B3D002A3D002A3C00293C
00283C00283B00273B00273B00263A00263A00253A002539002539002439002439002338
002338002238002238002237002137002137002137002036
002037002137002137002237002237002238002338002338002338002439002439002539
00253A00263A00263A00273A00273B00283B00283B00293C00293C002A3C002A3D002B3D
002C3D002C3E002D3E002E3E002E3F002F3F003040003140003141003241003341003442
003542003643003743003844003945003A45003B46003D46003E47003F48004148004249
00444A00454A00474B00494C004B4D004C4D004E4E004F4E00504E00514D00524D00534C
00544C00564B00574A005849005948005B47005C46005E45005F4400614200634000653E
00673C006939006B36006E3300702F00732B007626007921007D1A00801300840B008901
098D00159200249800359D0049A4005FAA0079B20097B900B8C100CAB700D2A100DA8900
E27200E85C00EC4C00EF4300EF4300EC4C00E85C00E27200DA8900D2A100CAB700B8C100
97B90079B2005FAA0049A400359D00249800169200098D0000890100840B008013007D1A
00792100762600732B00702F006E33006B3600693900673C00653E006340006142005F44
005E45005C46005B4700594800584900574A00564B00544C00534C00524D00514D00504E
004F4E004E4E004C4E004B4D00494C00474B00454A00444A004249004148003F48003E47
003D46003B46003A45003945003844003743003643003542003442003341003241003141
003140003040002F3F002E3F002E3E002D3E002C3E002C3D002B3D002A3D002A3C00293C
00293C00283B00283B00273B00273A00263A00263A00253A002539002439002439002338
002338002338002238002237002237002137002137002037
002137002137002137002237002238002238002338002338002439002439002439002539
00253A00263A00263A00273B00273B00283B00283B00293C00293C002A3C002B3D002B3D
002C3E002D3E002D3E002E3F002F3F002F3F003040003140003241003341003442003442
003543003643003744003844003A45003B45003C46003D46003E47004048004148004349
00444A00464B00474B00494C004B4D004D4E004F4E00504E00504D00514D00524D00544C
00554B00564B00574A005849005A48005B47005D46005E4500604300614200634000653E
00673B006939006C36006E3300712F00732B007626007920007D1A00801300840B008901
088D00159200239700339D0046A3005BA90073B0008FB700ADBF00C7BF00CEAC00D69700
DC8300E27100E66300E85C00E85C00E66300E27100DC8300D69700CEAC00C7BF00ADBF00
8FB70073B0005BA90046A300339D00239700159200088D0000890100840B008013007D1A
00792000762600732B00712F006E33006C3600693900673B00653E006340006142006043
005E45005D46005B47005A4800584900574A00564B00554B00544C00524D00514D00504D
00504E004F4E004D4E004B4D00494C00474B00464B00444A004349004148004048003E47
003D46003C46003B45003A45003844003744003643003543003442003442003341003241
003140003040002F3F002F3F002E3F002D3E002D3E002C3E002B3D002B3D002A3C00293C
00293C00283B00283B00273B00273B00263A00263A00253A002539002439002439002439
002338002338002238002238002237002137002137002137
002137002137002137002237002238002338002338002338002439002439002539002539
00263A00263A00273A00273B00283B00283B00293C00293C002A3C002A3D002B3D002C3D
002C3E002D3E002D3E002E3F002F3F003040003040003140003241003341003442003542
003643003743003844003944003A45003B45003C46003D47003F47004048004249004349
00454A00464B00484B004A4C004C4D004D4E004F4E00504E00514D00524D00534C00544C
00554B00564B00574A005949005A48005B47005D46005E4500604300624100634000653E
00673B006A39006C36006E3200712F00742A007626007A20007D1A00801300840B008802
088D00149100219700319C0043A20057A8006DAE0087B500A2BC00C0C300CBB600D1A400
D79300DC8300E07800E27200E27200E07800DC8300D79300D1A400CBB600C0C300A3BC00
87B5006DAE0057A80043A200319C00219700149100088D0000880200840B008013007D1A
007A2000762600742A00712F006E32006C36006A3900673B00653E006340006241006043
005E45005D46005B47005A4800594900574A00564B00554B00544C00534C00524D00514D
00504E004F4E004D4E004C4D004A4C00484B00464B00454A004349004249004048003F47
003D47003C46003B45003A45003944003844003743003643003542003442003341003241
003140003040003040002F3F002E3F002D3E002D3E002C3E002C3D002B3D002A3D002A3C
00293C00293C00283B00283B00273B00273A00263A00263A002539002539002439002439
002338002338002338002238002237002137002137002137
00213700213700223700223800223800233800233800243900243900243900253900253A
00263A00263A00273A00273B00283B00283B00293C00293C002A3C002B3D002B3D002C3D
002C3E002D3E002E3F002E3F002F3F003040003140003241003241003341003442003542
003643003743003844003945003A45003B46003D46003E47003F47004148004249004349
00454A00474B00484C004A4C004C4D004E4E004F4E00504E00514D00524D00534C00544C
00554B00564B00584A005949005A48005C47005D46005F4400604300624100643F00663D
00683B006A38006C35006E3200712E00742A007725007A20007D1A00801300840B008802
078C001291001F96002E9B003FA10052A70067AD007FB30098BA00B3C000C7BF00CDAF00
D2A100D79400DA8B00DC8500DC8500DA8A00D79400D2A100CDAF00C7BF00B3C00098BA00
7FB30067AD0052A7003FA1002E9B001F9600129100078C0000880200840B008013007D1A
007A2000772500742A00712E006E32006C35006A3800683B00663D00643F006241006043
005F44005D46005C47005A4800594900584A00564B00554B00544C00534C00524D00514D
00504E004F4E004E4E004C4D004A4C00484C00474B00454A004349004249004148003F47
003E47003D46003B46003A45003945003844003743003643003542003442003341003241
003241003140003040002F3F002E3F002E3F002D3E002C3E002C3D002B3D002B3D002A3C
00293C00293C00283B00283B00273B00273A00263A00263A00253A002539002439002439
002439002338002338002238002238002237002137002137
00213700213700223700223800233800233800233800243900243900253900253900253A
00263A00263A00273B00273B00283B00283C00293C002A3C002A3C002B3D002B3D002C3E
002D3E002D3E002E3F002F3F002F3F003040003140003241003341003442003442003543
003643003744003844003945003B45003C46003D46003E4700404800414800424900444A
00454A00474B00494C004B4D004C4D004E4E004F4E00504E00514D00524D00534C00544C
00554B00564A00584A005949005A48005C47005D46005F4400604300624100643F00663D
00683B006A38006C35006F3200712E00742A007725007A20007D1A00801300840C008803
068C001190001D95002C9A003CA0004DA50061AB0077B1008EB700A6BD00BFC300C9BA00
CEAE00D2A300D49B00D69700D69700D49B00D2A300CEAE00C9BA00BFC300A6BD008EB700
77B10061AB004DA5003CA0002C9A001D9500119000068C0000880300840C008013007D1A
007A2000772500742A00712E006F32006C35006A3800683B00663D00643F006241006043
005F44005D45005C47005A4800594900584A00574A00554B00544C00534C00524D00514D
00504E004F4E004E4E004C4D004B4D00494C00474B00454A00444A004249004148004048
003E47003D46003C46003B45003945003844003744003643003543003442003442003341
003241003140003040002F3F002F3F002E3F002D3E002D3E002C3E002B3D002B3D002A3C
002A3C00293C00283C00283B00273B00273B00263A00263A00253A002539002539002439
002439002338002338002338002238002237002137002137
00213700223700223800223800233800233800233900243900243900253900253A00263A
00263A00273A00273B00283B00283B00293C00293C002A3C002A3D002B3D002C3D002C3E
002D3E002E3E002E3F002F3F003040003040003140003241003341003442003542003643
003743003844003944003A45003B45003C46003D47003F4700404800414800434900444A
00464B00474B00494C004B4D004D4E004F4E004F4E00504E00514D00524D00534C00544C
00564B00574A005849005949005B48005C47005D45005F4400614200624100643F00663D
00683B006A38006C35006F3200712E00742A007725007A20007D1A00801400840C008704
058C000F90001B9400299900389E0048A4005BA9006FAF0084B5009ABA00B0C000C5C400
C9B900CDB000CFA900D1A600D1A600CFA900CDB000C9B900C5C400B0C0009ABA0084B500
6FAF005BA90049A400389E002999001B94000F9000058C0000870400840C008014007D1A
007A2000772500742A00712E006F32006C35006A3800683B00663D00643F006241006142
005F44005D45005C47005B4800594900584900574A00564B00544C00534C00524D00514D
00504E004F4E004F4E004D4E004B4D00494C00474B00464B00444A004349004148004048
003F47003D47003C46003B45003A45003944003844003743003643003542003442003341
003241003140003040003040002F3F002E3F002E3E002D3E002C3E002C3D002B3D002A3D
002A3C00293C00293C00283B00283B00273B00273A00263A00263A00253A002539002439
002439002439002338002338002238002238002237002137
00213700223700223800223800233800233800243900243900253900253900253A00263A
00263A00273B00273B00283B00283B00293C00293C002A3C002B3D002B3D002C3D002C3E
002D3E002E3F002E3F002F3F003040003140003241003241003341003442003542003643
003743003844003944003A45003B46003C46003E47003F4700404800424900434900454A
00464B00484B004A4C004B4D004D4E004F4E00504E00514D00514D00524D00544C00554B
00564B00574A005849005948005B47005C46005E45005F4400614200624100643F00663D
00683A006A38006C35006F3200712E00742A007625007920007D1B00801400830D008705
038B000E8F00199400269800349D0044A20055A70067AD007AB2008EB700A2BC00B5C100
C5C400C8BC00CAB600CBB300CBB300CAB600C8BC00C5C400B5C100A2BC008EB7007AB200
67AD0055A70044A200349D002698001994000E8F00038B0000870500830D008014007D1B
00792000772500742A00712E006F32006C35006A3800683A00663D00643F006241006142
005F44005E45005C46005B4700594800584900574A00564B00554B00544C00524D00514D
00514D00504E004F4E004D4E004B4D004A4C00484B00464B00454A004349004249004048
003F47003E47003C46003B46003A45003944003844003743003643003542003442003341
003241003241003140003040002F3F002E3F002E3F002D3E002C3E002C3D002B3D002B3D
002A3C00293C00293C00283B00283B00273B00273B00263A00263A00253A002539002539
002439002439002338002338002238002238002237002137
00223700223700223800233800233800233800243900243900253900253A00263A00263A
00273A00273B00273B00283B00293C00293C002A3C002A3D002B3D002B3D002C3E002D3E
002D3E002E3F002F3F002F3F003040003140003241003341003342003442003543003643
003744003844003945003A45003C46003D46003E47003F4800414800424900434900454A
00474B00484C004A4C004C4D004E4E004F4E00504E00514D00524D00534C00544C00554B
00564B00574A005849005A48005B47005C46005E45005F4400614200634100643F00663D
00683A006A38006C35006F3200712E00742A007626007921007C1B00801500830E008706
028A000C8E00179300239700309C003FA1004EA5005FAA0071AF0083B40094B900A5BD00
B4C100C1C400C6C200C7BF00C7BF00C6C200C1C400B4C100A5BD0094B90083B40071AF00
5FAA004EA5003FA100309C002397001793000C8E00028A0000870600830E008015007C1B
00792100762600742A00712E006F32006C35006A3800683A00663D00643F006341006142
005F44005E45005C46005B47005A4800584900574A00564B00554B00544C00534C00524D
00514D00504E004F4E004E4E004C4D004A4C00484C00474B00454A004349004249004148
003F48003E47003D46003C46003A45003945003844003744003643003543003442003342
003341003241003140003040002F3F002F3F002E3F002D3E002D3E002C3E002B3D002B3D
002A3D002A3C00293C00293C00283B00273B00273B00273A00263A00263A00253A002539
002439002439002338002338002338002238002237002237
00223700223800223800233800233800243900243900243900253900253A00263A00263A
00273A00273B00283B00283B00293C00293C002A3C002A3D002B3D002C3D002C3E002D3E
002E3E002E3F002F3F003040003040003140003241003341003442003542003643003743
003844003944003A45003B45003C46003D46003E4700404800414800424900444A00454A
00474B00494C004A4D004C4D004E4E004F4E00504E00514D00524D00534C00544C00554B
00564B00574A005849005A48005B47005C46005E45005F4400614200634000643F00663C
00683A006A38006C35006F3200712E00742A007626007921007C1B007F1500830F008607
008A000A8E001492002096002C9A003A9F0048A40058A80068AD0078B10088B60097B900
A4BD00AFBF00B7C100BBC200BBC200B7C100AFBF00A4BD0097B90088B60078B10068AD00
58A80048A4003A9F002C9A002096001492000A8E00008A0000860700830F007F15007C1B
00792100762600742A00712E006F32006C35006A3800683A00663C00643F006340006142
005F44005E45005C46005B47005A4800584900574A00564B00554B00544C00534C00524D
00514D00504E004F4E004E4E004C4D004A4D00494C00474B00454A00444A004249004148
004048003E47003D46003C46003B45003A45003944003844003743003643003542003442
003341003241003140003040003040002F3F002E3F002E3E002D3E002C3E002C3D002B3D
002A3D002A3C00293C00293C00283B00283B00273B00273A00263A00263A00253A002539
002439002439002439002338002338002238002238002237
00223700223800233800233800233800243900243900253900253900253A00263A00263A
00273B00273B00283B00283B00293C00293C002A3C002B3D002B3D002C3D002C3E002D3E
002E3F002E3F002F3F003040003140003141003241003341003442003542003643003743
003844003944003A45003B45003C46003D47003F4700404800414800434900444A00464B
00474B00494C004B4D004D4E004E4E004F4E00504E00514D00524D00534C00544C00554B
00564B00574A005949005A48005B47005D46005E4500604300614200634000653E00663C
00683A006A38006C35006F3200712E00742A007626007921007C1C007F1600820F008608
008900088D001291001C9500289900359D0042A20050A6005FAA006DAE007CB20089B600
95B9009EBB00A5BD00A9BE00A9BE00A5BD009EBB0095B90089B6007CB2006DAE005FAA00
50A60042A200359D002899001C9500129100088D0000890000860800820F007F16007C1C
00792100762600742A00712E006F32006C35006A3800683A00663C00653E006340006142
006043005E45005D46005B47005A4800594900574A00564B00554B00544C00534C00524D
00514D00504E004F4E004E4E004D4E004B4D00494C00474B00464B00444A004349004148
004048003F47003D47003C46003B45003A45003944003844003743003643003542003442
003341003241003141003140003040002F3F002E3F002E3F002D3E002C3E002C3D002B3D
002B3D002A3C00293C00293C00283B00283B00273B00273B00263A00263A00253A002539
002539002439002439002338002338002338002238002237
00223800223800233800233800243900243900243900253900253A00263A00263A00273A
00273B00283B00283B00293C00293C002A3C002A3D002B3D002B3D002C3E002D3E002D3E
002E3F002F3F002F3F003040003140003241003341003342003442003543003643003743
003844003945003A45003B46003C46003E47003F4700404800424900434900454A00464B
00484B00494C004B4D004D4E004F4E004F4E00504E00514D00524D00534C00544C00554B
00564A00584A005949005A48005B47005D46005E4500604300614200634000653E00663C
00683A006A38006C35006F3200712E00732B007626007922007B1D007E1700821100850A
008802068C000F9000199400249800309C003CA00049A40056A80064AC0070AF007CB200
87B5008FB70095B90098BA0098BA0095B9008FB70087B5007CB30070AF0064AC0056A800
49A4003CA000309C002498001994000F9000068C00008802008509008210007E17007C1D
00792200762600732B00712E006F32006C35006A3800683A00663C00653E006340006142
006043005E45005D46005B47005A4800594900584A00564A00554B00544C00534C00524D
00514D00504E004F4E004F4E004D4E004B4D00494C00484B00464B00454A004349004249
004048003F47003E47003C46003B46003A45003945003844003743003643003543003442
003342003341003241003140003040002F3F002F3F002E3F002D3E002D3E002C3E002B3D
002B3D002A3D002A3C00293C00293C00283B00283B00273B00273A00263A00263A00253A
002539002439002439002439002338002338002238002238
00223800223800233800233800243900243900243900253900253A00263A00263A00273A
00273B00283B00283B00293C00293C002A3C002A3D002B3D002C3D002C3E002D3E002E3E
002E3F002F3F003040003040003140003241003341003442003542003543003643003744
003844003945003A45003C46003D46003E47003F4700414800424900434900454A00464B
00484C004A4C004B4D004D4E004F4E00504E00504D00514D00524D00534C00544C00554B
00574A00584A005949005A48005B47005D46005E4500604300614200634000653E00663C
00683A006A38006C35006F3200712F00732B007627007822007B1D007E1800811200840B
008804048B000C8F001692002096002B9A00369E0042A2004EA5005AA90066AC0070AF00
79B20081B40086B50089B60089B60086B50081B40079B20070AF0066AC005AA9004EA500
42A200369E002B9A002096001692000C8F00048B0000880300840B008112007E18007B1D
00782200762700732B00712F006F32006C35006A3800683A00663C00653E006340006142
006043005E45005D46005B47005A4800594900584A00574A00554B00544C00534C00524D
00514D00504D00504E004F4E004D4E004B4D004A4C00484C00464B00454A004349004249
004148003F48003E47003D46003C46003A45003945003844003744003643003543003542
003442003341003241003140003040003040002F3F002E3F002E3E002D3E002C3E002C3D
002B3D002A3D002A3C00293C00293C00283B00283B00273B00273A00263A00263A00253A
002539002439002439002439002338002338002238002238
00223800233800233800233800243900243900253900253900263A00263A00263A00273B
00273B00283B00283B00293C00293C002A3C002B3D002B3D002C3D002C3E002D3E002E3F
002E3F002F3F003040003140003141003241003341003442003542003643003743003844
003944003A45003B45003C46003D46003E4700404800414800424900444A00454A00474B
00484C004A4C004C4D004E4E004F4E00504E00514D00514D00524D00534C00544C00564B
00574A00584A005949005A48005C47005D46005E4500604300614200634000653E00663C
00683A006A38006C35006E3200712F00732B007527007823007B1E007E1900811300840C
008705018A000A8E001391001C9500269800319C003CA00047A30051A6005CA90065AC00
6DAE0074B00078B1007BB2007BB20078B10074B0006DAE0065AC005CA90051A60047A300
3CA000319C002698001C95001391000A8E00018A0000870500840C008113007E19007B1E
00782300752700732B00712F006E32006C35006A3800683A00663C00653E006340006142
006043005E45005D46005C47005A4800594900584A00574A00564B00544C00534C00524D
00524D00514D00504E004F4E004E4E004C4D004A4C00484C00474B00454A00444A004249
004148004048003E47003D46003C46003B45003A45003944003844003743003643003542
003442003341003241003141003140003040002F3F002E3F002E3F002D3E002C3E002C3D
002B3D002B3D002A3C00293C00293C00283B00283B00273B00273B00263A00263A00263A
002539002539002439002439002338002338002338002238
00223800233800233800243900243900243900253900253A00263A00263A00273A00273B
00283B00283B00293C00293C002A3C002A3D002B3D002B3D002C3E002D3E002D3E002E3F
002F3F002F3F003040003140003241003241003342003442003542003643003743003844
003944003A45003B45003C46003D47003F4700404800414800434900444A00454A00474B
00494C004A4D004C4D004E4E004F4E00504E00514D00524D00534D00544C00554B00564B
00574A005849005949005A48005C47005D46005E4400604300614200634000653E00663C
00683A006A38006C35006E3200702F00732C007528007823007A1F007D1A00801400830E
008607008900078C000F90001893002297002B9A00359D003FA10049A40052A7005BA900
62AB0068AD006CAE006EAF006EAF006CAE0068AD0062AB005BA90052A70049A4003FA100
359D002B9A002297001893000F9000078C0000890000860700830E008014007D1A007A1F
00782300752800732C00702F006E32006C35006A3800683A00663C00653E006340006142
006043005E44005D46005C47005A4800594900584900574A00564B00554B00544C00534D
00524D00514D00504E004F4E004E4E004C4D004A4D00494C00474B00454A00444A004349
004148004048003F47003D47003C46003B45003A45003944003844003743003643003542
003442003342003241003241003140003040002F3F002F3F002E3F002D3E002D3E002C3E
002B3D002B3D002A3D002A3C00293C00293C00283B00283B00273B00273A00263A00263A
00253A002539002439002439002439002338002338002238
00233800233800233800243900243900253900253900253A00263A00263A00273B00273B
00283B00283B00293C00293C002A3C002A3D002B3D002C3D002C3E002D3E002D3E002E3F
002F3F003040003040003140003241003341003342003442003543003643003744003844
003945003A45003B46003C46003E47003F4700404800414900434900444A00464B00474B
00494C004B4D004C4D004E4E004F4E00504E00514D00524D00534C00544C00554B00564B
00574A005849005949005A48005C47005D46005E4400604300614200634000653E00663C
00683A006A38006C35006E3200702F00732C007528007724007A20007D1B007F1500820F
008509008802048B000C8F001492001D95002698002F9B00389E0041A10049A40051A600
57A8005CAA0060AB0062AB0062AB0060AB005CAA0057A80051A60049A40041A100389E00
2F9B002698001D95001492000C8F00048B0000880200850900820F007F15007D1B007A20
00772400752800732C00702F006E32006C35006A3800683A00663C00653E006340006142
006043005E44005D46005C47005A4800594900584900574A00564B00554B00544C00534C
00524D00514D00504E004F4E004E4E004C4D004B4D00494C00474B00464B00444A004349
004149004048003F47003E47003C46003B46003A45003945003844003744003643003543
003442003342003341003241003140003040003040002F3F002E3F002E3E002D3E002C3E
002C3D002B3D002A3D002A3C00293C00293C00283B00283B00273B00273B00263A00263A
00253A002539002539002439002439002338002338002338
00233800233800233800243900243900253900253A00263A00263A00263A00273B00273B
00283B00283B00293C00293C002A3C002B3D002B3D002C3D002C3E002D3E002E3F002E3F
002F3F003040003140003140003241003341003442003542003543003643003744003844
003945003A45003C46003D46003E47003F4700404800424900434900454A00464B00484B
00494C004B4D004D4E004E4E004F4E00504E00514D00524D00534C00544C00554B00564B
00574A005849005949005A48005C47005D46005E4400604300614200634000653E00663C
00683A006A38006C36006E3300703000722C007529007725007920007C1C007F17008111
00840B008704018A00098D00109000189300219600299900319C00399F0041A10048A300
4DA50052A70055A70057A80057A80055A70052A7004DA50048A30041A100399F00319C00
299900219600199300109000098D00018A0000870400840B008111007F17007C1C007920
00772500752900722C007030006E33006C36006A3800683A00663C00653E006340006142
006043005E44005D46005C47005B4800594900584900574A00564B00554B00544C00534C
00524D00514D00504E004F4E004E4E004D4E004B4D00494C00484B00464B00454A004349
004249004048003F47003E47003D46003C46003A45003945003844003744003643003543
003542003442003341003241003140003140003040002F3F002E3F002E3F002D3E002C3E
002C3D002B3D002B3D002A3C00293C00293C00283B00283B00273B00273B00263A00263A
00263A00253A002539002439002439002338002338002338
00233800233800243900243900243900253900253A00263A00263A00273A00273B00283B
00283B00293C00293C002A3C002A3D002B3D002B3D002C3E002D3E002D3E002E3F002F3F
002F3F003040003140003141003241003341003442003542003643003743003844003944
003A45003B45003C46003D46003E47003F4800414800424900434900454A00464B00484B
00494C004B4D004D4E004E4E004F4E00504E00514D00524D00534C00544C00554B00564B
00574A005849005949005B48005C47005D46005F4400604300614200634000653E00663D
00683A006A38006C36006E3300703000722D007429007626007921007B1D007E18008113
00830D008607008900068C000D8F001492001C95002397002B9A00329C00399F003FA100
44A20048A4004BA4004DA5004DA5004BA40048A40044A2003FA100399F00329C002B9A00
2397001C95001492000D8F00068C0000890000860700830D008113007E18007B1D007921
00762600742900722D007030006E33006C36006A3800683A00663D00653E006340006142
006043005F44005D46005C47005B4800594900584900574A00564B00554B00544C00534C
00524D00514D00504E004F4E004E4E004D4E004B4D00494C00484B00464B00454A004349
004249004148003F48003E47003D46003C46003B45003A45003944003844003743003643
003542003442003341003241003141003140003040002F3F002F3F002E3F002D3E002D3E
002C3E002B3D002B3D002A3D002A3C00293C00293C00283B00283B00273B00273A00263A
00263A00253A002539002439002439002439002338002338
00233800233800243900243900253900253900253A00263A00263A00273B00273B00283B
00283B00293C00293C002A3C002A3D002B3D002C3D002C3E002D3E002D3E002E3F002F3F
002F3F003040003140003241003241003342003442003542003643003743003844003944
003A45003B45003C46003D46003E4700404800414800424900444A00454A00474B00484C
004A4C004B4D004D4E004F4E004F4E00504E00514D00524D00534C00544C00554B00564B
00574A005849005948005B48005C47005D46005F4400604300614200634000643F00663D
00683B006A38006C36006D33006F3100722D00742A007626007822007B1E007D19008014
00820F008509008803028B00098D001090001793001E95002598002B9A00319C00379E00
3CA0003FA10042A10043A20043A20042A1003FA1003CA000379E00319C002B9A00259800
1E9500179300109000098D00028B0000880300850900820F008014007D19007B1E007822
00762600742A00722D006F31006D33006C36006A3800683B00663D00643E006340006142
006043005F44005D46005C47005B4800594800584900574A00564B00554B00544C00534C
00524D00514D00504E004F4E004F4E004D4E004B4D004A4C00484C00474B00454A00444A
004249004148004048003E47003D46003C46003B45003A45003944003844003743003643
003542003442003342003241003241003140003040002F3F002F3F002E3F002D3E002D3E
002C3E002C3D002B3D002A3D002A3C00293C00293C00283B00283B00273B00273B00263A
00263A00253A002539002539002439002439002338002338
00233800233800243900243900253900253A00263A00263A00263A00273B00273B00283B
00283B00293C00293C002A3C002B3D002B3D002C3D002C3E002D3E002E3E002E3F002F3F
003040003040003140003241003341003342003442003543003643003743003844003944
003A45003B46003C46003D47003F4700404800414800424900444A00454A00474B00484C
004A4C004C4D004D4E004F4E00504E00504E00514D00524D00534C00544C00554B00564B
00574A005849005948005B48005C47005D46005E4400604300614200634000643F00663D
00683B006939006B36006D34006F3100712E00732B007527007823007A1F007D1B007F16
00811100840B008706008900058C000C8E001291001993001F96002598002A9A002F9B00
339D00379E00399F003A9F003A9F00399F00379E00339D002F9B002A9A002598001F9600
1993001291000C8E00068C0000890000870600840B008111007F16007D1B007A1F007823
00762700732B00712E006F31006D34006B3600693900683B00663D00643F006340006142
006043005E44005D46005C47005B4800594800584900574A00564B00554B00544C00534C
00524D00514D00504D00504E004F4E004D4E004C4D004A4C00484C00474B00454A00444A
004249004148004048003F47003D47003C46003B46003A45003944003844003743003643
003543003442003442003341003241003140003040003040002F3F002E3F002E3E002D3E
002C3E002C3D002B3D002B3D002A3C00293C00293C00283B00283B00273B00273B00263A
00263A00263A00253A002539002439002439002338002338
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[155]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00<_ooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0ol0000Mooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00000_ooool5o`0002?ooooo0_l0000Vooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00000_ooool5o`0001gooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`?o00005Oooool0037ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0002;ooooo00Co0000oooooooooooo00009?oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00007?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool05?ooool002[ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000oooooooooooo0000ooooo`05o`0001Gooooo1Ol00002ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Rooooo`04o`000?oooooooooo
o`0002Cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo01cooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo
00Go00005Oooool0037ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool0000Toooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`03o`000?oooooooooo01Cooooo000aooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`00000Mooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooo
oooo00009?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooo`00000Fooooo`00<Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo0_l0000Mooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooo
oooo00009?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool2o`0001Kooooo000booooo`;o00002_ooool2o`0000Gooooo00?o0000oooooooo
ool07?ooool2o`0000[ooooo0_l00003ooooo`?o00009?ooool2o`0002Kooooo0_l0000:ooooo`;o
00000oooool3o`0001kooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`0Dooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006oooooooo`0000Go
00000Oooool001_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00_ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Kooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0ooooool1ooooo`7o00000Oooool001_ooooo0_l0003oooooo`7ooooo0_l00001ooooo`00
6oooool00ol0003oooooooooo`02ooooo`H0o`0000H0na800>UJ003YFP00fXX00<j/0034a0020:6l
000308Fe001^[`00FjT00080BZ@000<0?:00032L000VV0000P0LU@000`0DTP003Hl000J<0002006:
000300281000Q@P008<=008005I;00<005E;001DC000Dd`00`00DTd2001AC@80051>0P00Cdh01P00
CTh004e>001=CP00C4d004]=001:C@<004U<00H004Q;0017B`00AT/004I;0016BP00ADX20014BP80
04=90P00@TT30011B080041800@003m8000oA`00?dL003m70P00?TL2000mA`8003e61@00?4H00`00
>dH003]5000kA@02000kA@H003Y51000>DD6000iA24003Q41P00>D@4000iA@H003Y51000>dD00`00
>dH003a6000lAP03000lAP8003e60P00?DL2000nA`<003m700<003m80010B000@4P00`00@DP20012
B@8004=90P00A4X01`00ADX004I:0016B`00AT/004M;0018B`00BD`00P00BT`00`00BTd004]=001<
C@02001=CP03001>CP00Cdh004m>0080051>0P00DDd01P00DTd005==001CC@00Dd`005A<001EB`80
05I;00<008<=00252000R0@00P01RP000`06S0003Hl001BB000201bE000302JH000`W000?:000080
BZ@000<0FjT006j_0025]@000P2Q_0000`34a000cZ`00=Z:00020>UJ00030?/B003o0000o`0000@0
o`001Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo00<0008I0?l0003o0000
103o00020?/A00030>UI003JR@00cj/00080aL@000<0Xk`008Je001_[`000P1LZ@000`1;Y000?J00
036L000202JH000301fE000ETP003Hl000801h`000<00HX000280`00QPP00P00Q0`00`00PQ0005E;
001DC003001CC004001BC@00DDd0055=001AC@80051>0`00Cdh00`00CTh004e>001<C@02001;C@03
001:C000BD`004Q<00<004M;00<004I;0015BP00ADX00P00A4X20013B@<004990P00@DP30010B003
000oB000?dL003m700@003i700@003e7000mAP00?DH003e61@00?4H00`00>dH003]5000kA@02000k
A@L003Y51@00>DD:000iA0d003Q42P00>D@5000iA@L003Y51000>dD00`00>dH003a6000lAP03000l
AP<003e600<003e7000nA`00?TL00P00?TL2000oA`04000oB000@4P004180010B08004580`00@TT2
0013B@8004A:0P00ADX01`00AT/004M;0017B`00Ad/004Q<0019C000BT`00P00Bdd00`00C4d004e>
001>CP03001?CP80051>0`00DDd01`00DTd005=<001CC000Dd`005A<001EB`00PQ000P00Q0`00`00
QPP008P3006:000200N<000300f?000ETP007ID000809YP000<0<I`003fP001;Y0000P1LZ@000`1_
[`00Q[D00:>l00020<G400030<n[003JR@00jET00080na401P3o00000`000QWoooooooooo`03oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool200026@L0o`0000<0o1000>UH003K
R0000P3?ZP000`35``00Y;d008Ne0002072_000305bZ001<Y@00?Z000080<Y`000<09iT001jE000E
TP000P0>S`000`08S@000XX000280`0200261`0300243000PQ0005E;00<005A<00D005=<001BC@00
DTd0059=001AC@02001@CP<004m>00H004i>001=CP00C4d004a=001;C@00BTd30019C0040018B`00
Ad/004I;0016BP8004E:0P00A4X30013B@8004990`00@DP20010B004000oB000?dL003m7000oA`@0
03i700<003e7000mAP00?DH01@00?4H3000kAPD003]52P00>TD7000iA@d003U41`00>DD:000jA@D0
03]50`00>dH5000lAP8003e600<003e7000nA`00?TL00P00?TL3000oA`03000oB000@4P0041800<0
04580P00@TT30013B@8004A:0P00ADX01000ATX004I;0017B`00B4/30019C006001:C@00Bdd004a=
001<C@00CDh004i>0`00Cdh2001@CP05001AC@00DTd0059=001BC@00Dd`00`00E4`00`00ED/0088@
0024300200261`0300280`02RP0028d000803Xl000<05I8001jE000WV@000P0bW0000`0nX000C:D0
05bZ0002072_000308Ne002T_@00aL<00080cjX000<0fhP00>UH003l40001`3o000200026@Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`80008I1`3o00000`3l4000jEP00=^8
00020<nZ00030<G3002T_@00QkD00080L:l000<0G:X004bU000nX0000P0bW0000`0WV@007YD001FB
000200j?000300R=0002RP0008P3008008H700<008@<00224000ED/00`00E4`01@00Dd`0059=001B
C@00DTd0055=0080051>0`00Cdh01P00CTh004e>001<C@00C4d004]=001:C@<004U<00@004Q;0017
B`00AT/004I:0P00ADX20014BP<004=90P00@TT30011B080041800@003m8000oA`00?dL003m71000
?TL00`00?DL003e6000mAP05000lAP<003]61@00>dD:000jA@L003U53@00>D@7000iA@X003Y51@00
>dD3000kAPD003a60P00?DH00`00?DL003i7000nA`02000nA`<003m700<003m80010B000@4P00`00
@DP20012B@<004=90P00A4X20015BP040016BP00AT/004M;0018B`<004U<00H004Y=001;C@00C4d0
04a=001=CP00CTh3001?CP80051>00D0055=001BC@00DTd0059=001CC003001DC003001EB`00PQ00
08@<008008H700<008P300::0008S@000P0>S`000`0ETP007YD002NI000203:L000303jP001<Y@00
G:X00080L:l000<0QkD00:Bm0035``000P3?ZP000`3KR000jEP00?`@00070?l00080008I1Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo10000QT60?l000070?`?003YE`00fhP0
0=^8003?ZP00aL<00:Fm000208Rf0003076_001MZP00CJD00080?Z0000<0<Y`002RI000NU@000P0F
TP000`0?T00028d000::000200280P0300261`00Q0/0088?0080080C0P00E4`01P00Dd`0059=001B
C@00DTd0055=001@C@80051>0P00Cdh3001>CP03001=CP00C4d004]=008004Y<00@004U<0018C000
Ad/004M;0P00AT/20015BP<004A:0P00@dT30012B@8004580`00@4P00`00?dP003m7000oA`04000n
A`<003e70P00?DH6000lAP<003]61@00>dDU000jA@D003]50`00>dH6000lAP8003e60`00?DL4000n
A`8003m700@003m80010B000@4P004180P00@DP30012B@8004=90`00A4X20015BP8004I;0P00Ad/0
1`00B4`004U<001:C000BT`004]=001<C@00CDh00`00CTh2001?CP80051>00<0051=001AC@00DTd0
0P00DTd00`00Dd`005A<001DC00200204`0300223`00Q0/008H7008008P200<00XX000R=000?T000
0P0FTP000`0NU@00:9T003:L000203jP000304fU001MZP00LJl00080R;H000<0YKd00<G3003?ZP00
0P3KR0000`3YE`00o0l00?l000050?l000@0008I1Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo1@000QT60?l000060?`?003YE`00jEL00=^7003?Z@00aL800P2U_@000`29]P00
LK0005jZ000204fU000303nQ000cW@00:9T000807iH000<05i<000n@0009S@000P03R`000`00R080
08H600242`0200223`0300214`00ED/005A<008005=<0P00DTd3001AC@80051>0`00Cdh00`00CTh0
04e>001<C@02001;C@04001:C@00BD`004U<0018B`8004M;0P00AT/30015BP030014BP00@dT004=9
00<0049900@004590011B000@DP004580P00@4P01000?dP003m7000oA`00?dL5000nA`03000mA`00
?DH003e6008003e61P00?4H4000kAPL003]55`00>TD7000kA@@003]61P00?4H4000mAP03000mA`00
?TL003i700<003i70`00?dL00`00?dP004180010B0030011B0@004990P00@dT01000A4X004E:0015
BP00ADX20016B`8004M;00@004Q;0019C000BD`004Y=0P00Bdd00`00C4d004e>001>CP03001?CP80
051>0`00DDd2001BC@8005=<00<005A<001EB`00PA<00P00PPl00`00Q0/008H700280P0200>;0003
00V=000?T0005i<000807iH000<0:9T003>M000oX@000P1=Y@000`1NZP00LK0008Vf00020:Fm0003
0<G2003?Z@00fhL00080jEL000<0o0l00?l0003o0000103o000500026@Gooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`02ooooo`H0008I1P3o00020?`>00030>YF003KQ`00cjT00080a/80
00<0Y[d008Zf001b/0000P1OZP000`1>Y@00@:4003>M000202VI000301nF000GT`00490000802Hd0
00<00h/000290@00QPH00P00Q0X00`00P`h0084B001EB`02001DC08005=<00@0059=001AC@00DDd0
055=0P00D4h3001?CP04001>CP00CDh004a=001<C@8004]=00L004Y<0019C000B4`004Q<0018B`00
Ad/004I;008004I:00<004E:0014BP00A4X00`00@dT20012B@8004590P00@DP40010B004000oB000
?dL003m7000oA`D003i700<003e7000mAP00?DH00P00?DH8000lAPD003]65`00>dD5000kAPP003a6
1000?DH00`00?DL003i7000nA`03000nA`<003m700<003m80010B000@4P00P00@4P20011B0800459
0P00@TT30013B@8004A:00H004E:0016BP00ATX004I;0017B`00B4/20018C0030019C000BT`004]=
00<004a=00<004e>001>CP00Cdh00P00Cdh2001@CP<0055=00<0059=001CC000Dd`00P00E4`00`00
ED/0084B00233P0200242P0300261P00R@400h/000802Hd000<0490001NC000OUP000P0YV@000`0c
W@00@:4004jU000205nZ000307:`002:]P00Y[d00080a/8000<0cjT00=^7003ZEP000P3l3P060?l0
00H0008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1`000QT70?l00003
0?`?003ZEP00fhL00080cjT000<0a/400:Nm002:]P000P1c/0000`1OZP00CjD0042Q000203BM0003
02VI000PUP0069<00080490000<02Xh000B;0000R@400P00Q`H00`00Q@X008<>00214P02001o5@80
05A<00H005=<001BC@00DTd0059=001AC@00D4d2001@CP8004m>0`00CTh01000CDh004a=001;C@00
BTd30019C0050018C000Ad/004M;0017B`00AT/00P00ADX30014BP8004=91000@TT30011B0<00418
0P00?dP3000oA`D003i70`00?DL5000mAP`003a63@00>dH<000lAPD003e60`00?DL5000nA`<003m7
0P00?dP30010B0<004581000@TT20013B@<004A:0P00ADX01@00AT/004M;0017B`00Ad/004Q<00<0
04U<00@004Y=001;C@00C4d004e>0`00CTh2001?CP80051>00<0051=001AC@00DTd00P00DTd00`00
Dd`005A<001DC002001o5@0300214P00P`h008D:008008L600<008T100B;000:SP000P0@T0000`0H
T`0089H002VI000203BM0003042Q001?Y@00GjX00080Lk0000<0R[H00:Nm0036`@000P3?Z@000`3K
Q`00jUH00?`?00070?l000L0008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo1`000QT70?l000030?`?003ZEP00fhL00080cjT000<0a/400:Nm002:]P000P1c/0000`1OZP00
CjD0042Q000203BM000302VI000PUP0069<00080490000<02Xh000B;0000R@400P00Q`H00`00Q@X0
08<>00214P02001o5@8005A<00H005=<001BC@00DTd0059=001AC@00D4d2001@CP8004m>0`00CTh0
1000CDh004a=001;C@00BTd30019C0050018C000Ad/004M;0017B`00AT/00P00ADX30014BP8004=9
1000@TT30011B0<004180P00?dP3000oA`D003i70`00?DL5000mAP`003a63@00>dH<000lAPD003e6
0`00?DL5000nA`<003m70P00?dP30010B0<004581000@TT20013B@<004A:0P00ADX01@00AT/004M;
0017B`00Ad/004Q<00<004U<00@004Y=001;C@00C4d004e>0`00CTh2001?CP80051>00<0051=001A
C@00DTd00P00DTd00`00Dd`005A<001DC002001o5@0300214P00P`h008D:008008L600<008T100B;
000:SP000P0@T0000`0HT`0089H002VI000203BM0003042Q001?Y@00GjX00080Lk0000<0R[H00:Nm
0036`@000P3?Z@000`3KQ`00jUH00?`?00070?l000L0008I1Oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo2@000QT60?l000070?`?003ZEP00fhH00=^6003@Z000a/400:Nn0002
08^f000307>`001PZ`00CjH00080@J4000<0=Id002ZJ000PUP000P0HT`000`0AT0002Xh000B;0002
0029000300271@00Q@X008<>0080084A00<0080E001DC000E4`00P00Dd`2001BC@<0055=0P00D4h3
001?CP03001>CP00CDh004a=00<004]=00<004Y<0019C000B4`00P00B4/00`00Ad/004I;0016B`03
0015BP8004A:0`00@dT40012B@8004581@00@4P00`00?dP003m7000oA`02000oA`H003i70`00?DL6
000mAQT003a61P00?DH3000mA`H003i71000?dL00`00?dP004180010B0030010B08004581000@TT3
0013B@8004A:0`00ADX20016B`060017B`00B4/004Q;0018C000BD`004Y<0`00Bdd00`00C4d004e>
001>CP03001?CP80051>0`00DDd2001BC@8005=<0P00E4`01P00P1D0084A00214@00P`h008D:0027
1@8008T000<018/000Z>000AT0000P0HT`000`0PUP00:YX003FM0002046Q000304nV001PZ`00Lk00
0080RkH000<0Ykh00<K1003@Z0000P3KQP000`3ZEP00o0l00?l000050?l000T0008I1Oooool1o`00
007ooooo000Kooooo`;o00000oooool:00026@H0o`0000H0o1000>YF003ZEP00fhH00=2X0036`@02
0:Rn000308^f001d/000H:/00080D:H000<0@J4003FM000ZVP000P0QUP000`0IT`004I4000^>0002
00F;000300290000Q`D008D9008008<=00<0084A00205000OQL00P00E4`00`00Dd`005==001BC@03
001AC@80051>0`00Cdh2001>CP06001=CP00C4d004a=001;C@00BTd004Y<0P00BD`00`00B4`004M;
0017B`020016B`030016BP00ADX004E:00<004A:0P00@dT40012B@@004581@00@4P00`00?dP003m7
000oA`02000oA`L003i71000?DLI000mAP@003e71`00?TL4000oA`03000oB000@4P0041800<00418
1000@DP40012B@8004=90`00A4X20015BP<004I;0P00Ad/01P00B4`004U<0019C000BT`004Y=001;
C@8004a=00<004e>001>CP00CTh00`00Cdh2001@CP<0055=00<0059=001CC@00Dd`00P00E4`00`00
OQL0080D00214@0200233@0300252@00Q`D008T000801H/000<02Xh0016A000IT`000P0QUP000`0Z
VP00=Id0046Q0002052V0003062[001d/000RkH00080Z;h000<0a/400=2X003KQP000P3ZEP000`3l
4000o`000?l000040?l000X0008I1?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo2`000QT60?l00080o14000<0jEL00=^6003@Z0000P36`@000`2X_P00S;L007B`0002066[0003
052V0012XP00=Yh00080:iX000<08IL001VD000BT@000P0;SP000`05S00008T00027100200252@03
00233@00PQ00080D008007hG00<005A<001CC000Dd`00`00DTd01000DDd0051=001@CP00D4h3001?
CP04001>CP00CDh004e>001<C@8004]=0P00BT`20019C0060018B`00Ad/004M;0017B`00AT/004I:
0`00ADX20014BP<004=91000@TT00`00@DT004580011B0020011B0D0041800<003m8000oA`00?dL0
0`00?dL;000nA`l003e72`00?TL5000oA`03000oB000@4P0041800<004181000@DP00`00@DT00499
0012B@020012B@<004=90P00A4X30015BP030016BP00AT/004M;008004M;00<004Q;0019C000BD`0
0P00BT`00`00Bdd004a=001<C@02001=CP04001>CP00Cdh004m>001?CP80051>00<0051=001AC@00
DTd00P00DTd2001CC006001DC000OQL007hG00205000PQ0008<=0P00Q@T00`00Q`@008T000F<0002
00^>000301:A000IU0008IL00080:iX000<0=Yh004:R001@YP000P1QZ`000`1d/000S;L00:Rn0002
0<K100030=2X003KQP00jEL00080o1401P3o000;00026@Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`02ooooo``0008I1`3o00000`3k4P00jEL00=^700020=2X00030<K1002X_P00S;L0
0080MK0000<0HJ/0056V0012XP000P0fWP000`0[VP008YL001VD000201:A000300^>0005S00008X0
008008L400<008D800243000PQ000P00P1@00`00OaL005A<001DC002001CC080059=0`00DDd2001@
CP8004m>0`00CTh01`00CDh004a=001;C@00Bdd004Y=001:C000BD`00P00B4`00`00B4/004M;0017
B`020016B`030016BP00ADX004E:00<004A:1000@dT30012B@D004581@00@4P3000oB0H003m76@00
?TL6000oA`<003m81@00@4P50011B0<004991000@dT30014BP8004E:00<004I:0016B`00AT/00P00
Ad/01P00B4/004Q<0018C000BD`004Y<001:C@8004]=00<004a=001=CP00CTh00P00CTh2001?CP80
051>0`00DDd2001BC@8005=<0P00E4`01P00OaL0080D00205000PQ0008@<0025208008L400<008X0
00F<000;SP000P0BT@000`0IU0008YL002^J000203JN000304:R001AYP00HJ/00080MK0000<0S;L0
0:Rn0036`@000P3@Z0000`3KQ`00jEL00?/B00070?l000`0008I1Oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00;ooooo30000QT70?l000030?/B003YE`00fhL00080d:P000<0a/400:Rn
002<]`000P1e/0000`1QZ`00DJH004:R000203JN000302^J000RU`006I@000804Y4000<02hh000F<
0000RP000P00Q`@00`00Q@P008@<0022400200205003001o5`00E4`005A<008005=<0P00DTd3001A
C@80051>0P00Cdh3001>CP07001=CP00C4d004]=001;C@00BTd004Y<0019C0020018C0030018B`00
Ad/004M;008004I;00<004I:0015BP00ADX00`00A4X40013B@<004991@00@DP50010B0<003m81P00
?dLI000nA`H003m70`00?dP50010B0D004580`00@TT40013B@<004A:0P00ADX00`00ATX004I;0016
B`020017B`060018B`00B4`004Q<0019C000BT`004Y=0P00Bdd00`00C4d004e>001>CP02001>CP80
04m>0P00D4h3001AC@80059=0P00Dd`2001DC006001o5`00P1@0080D00224000Q0`008D80P00Q`@0
0`00RP001H`000^>000201:A000301VD000RU`00:iX00080=Yh000<0@Z80056V001QZ`000P1e/000
0`2<]`00Z;h00<K100020=2X00030=^7003YE`00na8000L0o`0030000QT5ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_ooool>00026@H0o`0000L0na<00>UH003KQ`00fhL00=2X0036
`@00ZKh00080S;L000<0MK4006:[001AYP000P13XP000`0fWP00;9X002:G000201ZD000301:A000<
SP001X`0008008X000<008P300262000Q0`00P00PQ000`00P1<007lF001m6@02001DC003001CC000
DTd0059=00<0055=0P00D4h4001?CP03001>CP00CDh004a=008004a=00<004]=001:C000BD`00P00
BD`00`00B4`004Q;0017B`020017B`030016B`00ATX004E:008004E:0P00A4X40013B@D004991@00
@DP80010B08003m86@00?dL2000oB0P004181@00@DP50012B@@004=90P00A4X30015BP030016BP00
AT/004M;008004M;00<004Q;0018C000BD`00P00BD`00`00BT`004]=001<C@02001<C@03001=CP00
CTh004m>00<004m>0P00D4h3001AC@80059=00H005=<001DC000E4`007dI001o5P00P1<200224003
00243000QPP008P3008008X000<01X`000b>000BT@000P0JU0000`0RU`00;9X003JN000204>R0003
056V001RZ`00MK400080S;L000<0ZKh00<K1003@Z0000P3KQ`000`3YF000na<00?l000050?l000h0
008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo3`000QT60?l000060?XE
003YF@00jET00=^7003@Z000a/400P2Y_P000`2=]`00MK4006:[0002056V000304>R000gWP00;9X0
00808iL000<06Y@001>A000<S`000P06S0000`01RP0008P3002620020024300300223`00PA<007lF
008007dI00<005A<001CC000Dd`00`00DTd2001AC@<0051>0P00Cdh3001>CP03001=CP00C4d004]=
008004]=00<004Y<0019C000BD`00P00B4`00`00B4/004M;0017B`020016B`030016BP00ADX004E:
00@004A:1000@dT50012B@H004582`00@4P=000oB0/004181P00@DP50012B@@004=91000A4X20015
BP030016BP00AT/004I;008004M;00<004Q;0018C000B4`00P00BD`01P00BT`004]=001;C@00Bdd0
04a=001=CP<004i>0P00Cdh3001@CP80055=0`00DTd2001CC006001DC000OAT007dI001o5P00PA<0
088?0P00Q0`00`00QPP008P3006:000200J<000300b?000CT@006Y@000808iL000<0;9X003NN0013
XP000P1AYP000`1RZ`00MK4008fg00020:Vn00030<K1003?Z@00fhL00080jET000<0nQD00?l0003o
0000103o000?00026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooa00008I
1P3o00020?XG00030>UJ003KR000cjT00080a/4000<0ZKh008fg001f/@000P1RZ`000`1BYP00@j80
03NN000202bJ000302>G000KU0004i4000803Hl000<01h`0006:0000R0<00P00QPL00`00Q0/0088?
00214P02001o5P03001n6000O1/005=<008005=<0P00DTd2001AC@<0051>1000Cdh00`00CTh004e>
001=CP02001<C@03001;C@00BTd004Y<00<004U<00<004Q<0018B`00Ad/00P00Ad/00`00AT/004I:
0015BP020015BP@004A:1@00@dT60012B@T004584`00@4P90011B0H004991@00@dT40014BP<004E:
00<004I:0016B`00Ad/00P00Ad/00`00B4/004Q<0019C0020019C003001:C000BTd004]=008004a=
0P00CDh00`00CTh004m>001?CP02001?CP<0051>0P00DDd2001BC@<005=<00L007`K001n6000OaH0
07lF00214P00PPl008@;008008H700<008P3006:0007S0000P0=S`000`0CT@006i@002>G000202bJ
000303NN0013XP00DZH00080HZ/000<0M[4008fg002Y_P000P36`@000`3?Z@00fhP00>UJ00020?XG
00H0o`0040000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolA00026@L0
o`0000<0nAT00>QK003KR@000P3?Z@000`36`@00ZKh008fg000207Ja000306:[001BY`00A:800080
>9h000<0;I/002>G000KU0000P0DTP000`0=S`001h`000::000200280P0300261`00Q0/008<?0080
084B00<007lE001n6000O1/00P00E4`00`00Dd`0059=001BC@03001AC@03001@C@00D4h0051>00<0
04m>0P00CTh2001=CP8004a=00@004]=001:C@00BTd004Y<0P00BD`20018C0030018B`00Ad/004M;
00<004I;1000ADX30014BPD004=92000@TT00`00@DT004580011B00G0011B0030011B@00@TT00499
00H004991@00@dT30014BP@004E:0`00AT/20017B`030018B`00B4`004Q<008004U<00@004Y<001:
C@00BTd004]=0P00C4d2001=CP8004i>0`00Cdh2001@CP04001@C@00DDd0055=001AC@80059=00H0
05=<001DC000E4`007`K001n6000OaD200214P0300233`00Q0/008H7008008P200<00XX000N<000=
S`000P0DT@000`0KU0008iL002fK000203RN000304BR001BYP00HZ/00080M[4000<0SKL00:Rn0036
`@000P3?Z@000`3JR@00j5/00?TI00070?l00140008I1Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo4@000QT70?l000030?TI003XF`00fhT00080cjT000<0a/400:Vn002=]`00
0P1f/@000`1RZ`00DZL004BR000203RN000302fK000SU`006i@00080598000<03Hl000N<0002RP00
0P00R0800`00QPL008@;00233`0200214P03001o5@00OQP007`K008005A<00<005=<001BC@00DTd0
0`00DDd00`00D4d0051>001@CP03001?CP8004i>0P00CDh2001<C@04001;C@00BTd004Y=001:C080
04U<0P00B4`00`00B4/004M;0017B`030016B`@004E:0`00A4X50013B@P0049900<004590011B000
@DP05`00@DP00`00@DT004990012B@060012B@D004=90`00A4X40015BP<004I;0P00Ad/00`00B4/0
04Q<0018C0020019C004001:C000BTd004Y=001;C@8004a=0P00CDh2001>CP<004m>0P00D4h01000
D4d0055=001AC@00DDd2001BC@06001CC000E4`005A<001l6`00OQP007lE0P00PA800`00P`l008@;
00261`0200280P0300::0007S0003Hl00080594000<06i@002>G000]V`000P0hWP000`14XP00DZH0
06:[000207Ja000308fg002X_P00a/400080cjT000<0fXT00>QK003i6@001`3o000A00026@Gooooo
0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o
0000ooooooooool00_oooolC00026@H0o`0000L0nA/00>QM003JR@00fXT00<nZ0036`@00Z;h00080
SKL000<0M[4006>[001BY`000P14XP000`0hWP00;I/002BG000201^D000301BB000=S`001hd00080
0XX000<008P200261P00Q0X00P00P`h00`00PA80080E001n6002001m6P03001DC000Dd`005==00<0
059=0P00DDd3001@CP<004m>0P00CTh2001=CP04001<C@00Bdd004]=001;C@8004Y<0`00BD`00`00
B4`004Q;0017B`020017B`8004I;0P00ATX30015BP@004A:00<004A90013B@00@dT01@00@dTM0012
B@L004=900<004A90014BP00A4X00P00A4X30015BP8004I:0P00AT/30017B`030018B`00B4`004U<
008004U<0P00BT`3001;C@03001<C@00CDh004e>008004i>0`00Cdh3001@CP80055=0`00DTd00`00
Ddd005=<001DC002001m6P03001n6000P1D0084B008008<>00<008@:00261P00R0800P02RP000`07
S@003Hl001BB000201^D000302BG000]V`00>9h00080A:8000<0DZL006>[001f/@000P2=]`000`2X
_P00a/400<nZ00020=Z900030>QM003i6`00o`0000D0o`004`000QT5ooooo`7o00000Oooool000Oo
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo50000QT60?l000060?PN003WGP00ieh00=Z:003?ZP00a/800P2X_P000`2=]`00M[4006>[
000205:W000304BR000hWP00;I/0008099P000<079D001BB000>S`000P08S@000`02R`0008P20026
1P0200252P0300233P00PA40080D008007hG00@007dJ001l7@00Dd`005=<0`00DTd2001AC@80051=
0P00D4h3001?CP8004i>0`00CDh00`00C4d004]=001;C@03001:C08004U<0P00B4`00`00B4/004M;
0017B`040016B`D004E:1@00A4X00`00A4T004=90013B@080013B@d004992P00@dT00`00A4T004A:
0014BP030014BPD004E:1000AT/20017B`030018B`00B4`004Q<008004U<0`00BT`2001;C@04001<
C@00CDh004e>001=CP8004i>0`00Cdh2001@CP80051=0P00DDd3001BC@8005=<00L007`M001m6P00
OQL007hG00205000PA4008<>008008D:00<008H600280P02R`000P08S@000`0>S`00598001bE0002
02BH000302fK000hWP00A:800080DZL000<0Hj/007Ja002=]`000P2X_P000`36`P00cjX00=Z:0002
0>MN00030?PN003o0000o`0000@0o`0050000QT5ooooo`7o00000Oooool000Go00000_ooool01?l0
003oooooooooool00007ooooo`Go00001?ooool2o`0000?ooooo5@000QT60?l00080n24000<0if00
0=Z;003?Z`000P35`P000`2X_P00S;L007Ja000206>[000305:W0015XP00>9h00080;Y/000<099P0
01bE000ETP000P0>S`000`08S@000h/000290@0200271P0300252P00P`d0084A0080080D00@007hG
001m6P00O1`005A<0P00Dd`2001BC@@0055=0P00D4h4001?CP<004i>00<004e>001<C@00C4d00`00
Bdd2001:C0<004U<00<004Q<0018B`00Ad/00`00Ad/40016B`H004E:2000A4XC0013B@P004A:1P00
ADX40016B`@004M;00<004Q;0018C000BD`00P00BD`2001:C0<004]=0P00C4d01000CDh004i>001>
CP00CTh4001?CP80051>1000DDd2001BC@8005=<00@005A<001l7000OAX007hG0P00P1@00`00PA40
08<=00252P0200271P0300290@03R`0028d000803Xl000<05I8001bE000TV0000P0^V`000`0hWP00
AJ8005:W000206>[000307Ja002<]`00Z;h00080aL8000<0cj/00=Z;003WH0000P3h8@060?l001D0
008I1?ooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`02oooooaH0008I1`3o00000`3g9000iV400=V<00020<j[
00030<G2002W_P00S;L00080M[4000<0Hj/005>W0015XP000P0iW`000`0^V`009IP001bE000201FB
000300j?0008S@000h/0008008T100<008L500252@00P`d00P00PQ401000P1@007lG001m6@00O1`2
001k7P8005=<0`00DTd2001AC@@0051>1000Cdh2001>CP04001=CP00C4d004a=001<C@8004]=0`00
BT`20019C0<004Q<00<004Q;0017B`00Ad/00P00Ad/40016B`030016BP00ADX004E:00D004E:5`00
A4X70015BP030016BP00AT/004I;008004I;1000Ad/01000B4/004Q<0018C000B4`20019C0<004Y<
0P00Bdd3001<C@03001=CP00CTh004i>00@004m>1000D4h2001AC@<0059=0P00Dd`2001k7P04001l
7000OAT007lG00205080088A00<008<=00252@00Q`D00P00R@400`03R`0028d000j?000201FB0003
01bE000UV000;Y/00080>Il000<0AJ8005>W001SZ`000P1f/@000`2<]`00Ykh00<G200020<j[0003
0=V<003VH@00mb@000L0o`005P000QT5ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00;ooooo5P000QT70?l00003
0?LT003VH@00fH`00080cZ/000<0aL800:Nn002<]`000P1f/@000`1SZ`00DjL004FR000203VO0003
02jK000UV00079D000805I8000<03Xl000R=0003R`000P00R@400`00Q`D008D900233@0200224@04
00205000OaL007dI001l708007/N0P00Dd`3001BC@80055=1000D4h4001?CP8004i>00@004e>001<
C@00C4d004a=0P00Bdd3001:C08004U<0`00B4`00`00B4/004M;0017B`020017B`@004I;00<004I:
0015BP00ADX01@00ADXG0014BPL004E:00<004I:0016B`00AT/00P00AT/40017B`040018B`00B4`0
04Q<0018C08004U<0`00BT`2001;C@<004a=00<004e>001>CP00CTh01000Cdh4001@CP80055=0`00
DTd2001CC08007/N00@007`L001m6@00OaL0080D0P00PQ400`00P`d008D900271@0200290@0300>;
0008S@003Xl000805I8000<079D002FH000^V`000P0iW`000`15XP00DjL006>[000207Ja000308bg
002W_P00aL800080cZ/000<0fH`00>IQ003g90001`3o000F00026@Gooooo0Ol00001ooooo`001ooo
ool01?l0003oooooooooool00009ooooo`;o00001Oooool00ol0003oooooooooo`02oooooaP0008I
1P3o00001`3f9`00iV<00=V>003ISP00cZ`00<G3002W_@000P2<]`000`1f/@00Hj/005>W000204FR
000303VO000^V`009IP000807ID000<05I8000n@0009S@000P03R`000`00R@0008L500252@020023
3@0400224000P1<007lF001m6@8007`K00<007/N001CC000Dd`00`00DTd4001AC@80051>1000Cdh2
001>CP<004e>0P00C4d3001;C@8004Y<1000BD`01000B4`004Q;0018B`00B4/40017B`D004I;00<0
04I:0015BP00ADX06@00ADX00`00ATX004I;0016B`030016B`@004M;0`00B4/00`00B4`004U<0019
C0020019C08004Y<0`00Bdd2001<C@<004e>0P00CTh4001?CP80051>1000DDd3001BC@8005=<00L0
07/N001l6`00O1/007dI001o5P00P1<0088@008008<=00<008D900271@00R@400P03R`000`09S@00
3i0001FB000201fE000302FH000^V`00>Il00080AJ8000<0DjL006>[001f/@000P2<]`000`2W_@00
aL<00<j/00020=V>00030>IS003f9`00o`0000D0o`0060000QT5ooooo`7o00000Oooool000Sooooo
0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oooolH00026@L0o`00
00H0mBX00>EU003UI@00f8l00<j]0035``020:Jm000308bg001e/@00Hj/00080DjL000<0AJ<003VO
000^V`000P0UV0000`0MU@005Y8000n@000200V=000300B;0000R@0008L5008008D900@008@<0022
4000P1<007lF0P00OQT00`00O1/007/M001DC002001CC003001CC@00DTd0059=00<0055=00@0051=
001@CP00D4h0051>0`00Cdh3001>CP8004e>0`00C4d2001;C@8004Y=00<004Y<0019C000BD`00P00
BD`20018C0<004Q;1@00Ad/80016B`d004I:2000AT/50017B`<004Q;0P00B4`30019C08004Y<0P00
BTd2001;C@<004a=0P00CDh3001>CP<004m>0`00D4h01000D4d0055=001AC@00DDd2001BC@06001C
C@00Dd`005=<001DC000Nad007`K0P00OQT01000OaH0080C00224000Q0`200252@0300271@00R@00
18/000802Hd000<03i0001JB000MU@000P0UV0000`0^V`00>Il004FS000205>W000306>[001e/@00
S;L00080Y[d000<0aL<00<j]003HS`000P3UI@000`3e:P00o`000?l000050?l001P0008I1Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo6@000QT70?l00080m2h000<0iFL00=R@
003>[P000P35a0000`2U_@00RkH007Fa000206>[000305>W0015X`00>Il00080;i/000<09IP001fE
000FTP000P0?T0000`09S@0018/0002900020027100400252000Q0`0088?00214`8007lF00<007hH
001l6`00Nad00P00NQl2001CC0<0059=0`00DDd4001@CP@004m>0P00CTh3001=CP8004a=0`00Bdd0
1000BTd004Y<001:C000BT`30019C0@004Q<0`00B4/80017B`d004I;2000Ad/30018B`@004Q<0`00
BD`3001:C004001:C@00Bdd004]=001;C@8004a=0`00CDh2001>CP@004m>1000D4h3001AC@<0059=
0P00Dd`2001j7`03001k7@00O1/007hH008007lF00@0084C00223`00Q0`008D80P00Q`@00`00R@00
18/000V=000200n@000301JB000MU@009IP00080;i/000<0>Il004FS001CY`000P1SZ`000`1e/@00
RkH00:Fm00020<G400030<j^003HT000iFP00080m2h01`3o000I00026@Gooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`02oooooaX0008I203o00000`3c<@00i6X00=RB00020<f_00030<C4
002U_@00RkH00080MK4000<0HZ/005>W0015X`000P0iW`000`0_V`009YP001fE000201JB0003012@
000:SP0018/0008008T000@008L400262000Q0`0088?0P00PA800`00OaD007hH001m6P02001k7@03
001j7`00Dd`005=<00@0059=0`00DDd00`00D4d0051>001@CP05001?CP<004i>0P00CDh4001<C@<0
04]=00<004Y=001:C000BT`01@00BD`40018C0D004Q;3`00Ad/50018B`@004Q<1@00BD`2001:C004
001:C@00Bdd004]=001;C@@004a=0P00CDh3001>CPD004m>0P00D4h01000D4d0055=001AC@00DDd4
001BC@8005=<00H007XO001k7@00Nad007dJ001n6000OaD200214P0400223`00Q0`008H800271080
08T000<018/000Z>000@T0000P0FTP000`0MU@009YP002nK000203VO000304FS001CY`00HZ/00080
MK4000<0RkH00:Fm0034a0000P3=[`000`3HTP00i6X00?<a00080?l001X0008I1Oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo6P000QT80?l000030?<a003TJP00f9800080cJl0
00<0a<@00:Fm002;]P000P1e/@000`1RZ`00DjL004FS000203VO000302nK000VV0007ID000805Y80
00<0490000Z>0004R`000P00R@001000Q`@008H800243000PPl200214P03001o5@00OQP007dJ0080
07/M00<007XO001CC000Dd`01000DTd3001AC@03001@C@00D4h0051>00D004m>0`00CTh2001=CP@0
04a=0`00Bdd00`00BTd004Y<001:C0050019C0@004Q<1@00B4/?0017B`D004Q;1000B4`50019C080
04Y<00@004Y=001;C@00Bdd004]=1000C4d2001=CP<004i>1@00Cdh2001@CP04001@C@00DDd0055=
001AC@@0059=0P00Dd`01P00NQl007/M001k7@00OAX007hH001o5@80084B00@0088?00243000QPP0
08L40P00R@000`04R`002Xh0012@000201JB000301fE000VV000;i/00080>Il000<0AJ<005>W001R
Z`000P1e/@000`2;]P00YKd00<C400020<f_00030=RB003TJP00lc4000P0o`006P000QT5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_oooolK00026@P0o`0000L0lcD00>=/003GT`00
ei<00<f`0033a000Y;d00080R[H000<0MK0006:[001CY`000P15X`000`0iW`00;i/002JH000201jE
000301JC000@T0002Xh000801H`000@008T000281000QPP008@;0P00PPl00`00PA8007lE001n6002
001m6P03001l7000NQl007TQ00<005=<0P00DTd4001AC@@0051>1@00Cdh2001>CP@004e>0`00C4d3
001;C@8004Y=0`00BT`80019C14004Q<2000BD`3001:C08004Y=0`00Bdd3001<C@@004e>0P00CTh5
001?CP@0051>1000DDd2001BC@<005=<00<007TQ001j7`00O1`00P00OAX00`00OQP007lE00214P02
00223`0400242`00QPP008P4002900801H`000<02Xh0012@000FT`000P0NU@000`0VV000;i/003VO
000204FS000305>W001RZ`00MK000080R[H000<0Y;d00<?4003=/0000P3GT`000`3SK000lcD00?l0
00070?l001/0008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo7@000QT7
0?l000060?8h003SKP00hfh00=NE003</@00`/@00P2S_0000`2:]P00M;0006:[000205>W000304FS
000iW`00;i/000809YP000<07YD001NC000@T0000P0:SP001005S00008X000280`00QPL200242`03
00233P00PA80080D008007hG00<007dJ001l7000Nah00P00NR02001CC0@0059=1000DDd3001@CPD0
04m>1000CTh3001=CP<004a=1@00Bdd2001:C@D004Y<4`00BD`5001:C08004Y=1@00Bdd3001<C@<0
04e>1000CTh5001?CP<0051>1000DDd4001BC@8005=<0P00NR000`00Nah007`L001m6P02001n5`03
00205000PA8008<>008008@;00@008H700280`00RP001H`00P0:SP000`0@T0005i<001jE000202JH
000302nK000iW`00AJ<00080DjL000<0HZ/007B`0029]P000P2S_0000`32a000c;400=NE00020>=^
00030?8i003o0000o`0000D0o`007@000QT5ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00_oooolN00026@L0o`000P3a?0000`3RL@00eYH00<bb00020<7400030::l0029]P00M;000080
HZ/000<0DZL004FS000iW`000P0_V`000`0VV0007YD001NC0002012@000400^>0005S00008X00028
0`8008H700<008@;00233P00PA400P00P1@00`00OaL007dI001l7002001k7P03001j8000E4`005=<
008005=<0P00DTd4001AC@03001@C@00D4h0051>0080051>1@00Cdh4001>CP<004e>1@00C4d7001;
C@8004Y=3`00BT`2001:C@L004]=1@00C4d3001=CP@004i>1@00Cdh4001@CP03001@C@00DDd0055=
0080055=0P00DTd3001CC007001DC000NR0007/N001k7P00O1`007dI001n5`020020500300214@00
P`h008@;008008H700@008P3002:0005S0002hh00P0@T0000`0GT`007YD002JH000202nK000303VO
0015X`00DZL00080HZ/000<0M;0008Vf002R_0000P31a0000`3</P00eYH00>9a00020?4l00L0o`00
7P000QT5ooooo`7o00000Oooool001_ooooo0_l00003oooooal0008I203o00000`3`@000hG<00=FH
00020<bc00030;o3002Q_000R;H00080Lk0000<0HJ/005:W0015X`000P0iW`000`0_V`009YP001jE
000201NC0004016@000;SP001X`0006:008008P300<008H700252P00P`h00P00PA400`00P1@007lF
001m6@02001l6`03001k7@00NQl007TQ00<005=<1000DTd3001AC@80051=0`00D4h7001?CP<004i>
1@00CDh5001<CAL004]=1@00C4d5001=CP<004i>1`00Cdh3001@CP80051=0`00DDd4001BC@<005=<
00<007TQ001j7`00Nad00P00O1/00`00OAT007lF0020500200214@0300233P00Q@X008H7008008P3
00@00HX000J<000;SP004I000P0GT`000`0NU@009YP002nK000203VO000304FS001BY`00HJ/00080
Lk0000<0R;H00:6l002o``000P3</`000`3EV000hG<00?1000080?l001l0008I1?ooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo7`000QT80?l000030?10003QL`00eIP00080c;<0
00<0_l<00:6l0028]P000P1c/0000`1QZ`00DZL004FS000203VO000302nK000VV0007YD000805i<0
00@04I0000^>0006S0000HX00P00R0<00`00QPL008D:00233P0200214@0300205000OaH007dI0080
07`K00<007/M001j7`00NB400`00Dd`4001BC@<0055=0P00D4d3001@CPL004m>0`00CTh5001=CPD0
04a=5`00Bdd5001<C@D004e>0`00CTh7001?CP<0051>0P00D4d3001AC@@0059=0`00Dd`00`00NB40
07XO001k7@02001l6`03001m6@00OaH0080D0080084A00<008<>00252P00QPL00P00R0<01001RP00
1X`000^>000AT00201NC000301jE000VV000;i/00080>Il000<0AJ<005:W001QZ`000P1c/0000`28
]P00XK`00;o300020<bc00030=FH003QL`00l40000P0o`007`000QT5ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_oooolP00026@P0o`0000L0kd@00>1f003EVP00eIX00<^d002n``00
X;`00080QkD000<0Lk00066[001BY`000P15X`000`0iW`00;i/002JH000201jF000401NC000AT000
2hh000J<00800HX000<008P200261P00Q@X00P00P`d00`00PQ40080C001o5P02001n6@03001l6`00
Nad007XO008007TQ00<005A<001CC000Dd`01000DTd4001AC@03001@C@00D4h0051>0080051>1`00
Cdh5001>CPD004e>5`00C4d5001=CPD004i>1`00Cdh4001@CP03001@C@00DDd0055=0080055=1000
DTd2001CC006001DC000NB4007TQ001j7`00Nad007`K0P00OQT00`00OaH0080C00224@0200233@03
00252P00QPH008P200800HX000@01X`000^>000AT0005i<00P0NUP000`0VV000;i/003VO000204FS
000305:W001QZ`00Lk000080QkD000<0X;`00;k3003;]0000P3EVP000`3PMP00kd@00?l000070?l0
0200008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo8P000QT60?l00007
0?l2003]B000h7T00>1i003DV`00bkD00;c3000209nk000308Ne001b/000HJ/00080DZH000<0AJ80
03VO000_V`000P0WV000100OUP0069<0016A000;SP0200J<0003006:0000R08008L6008008D:00<0
08<=00224000P1<00P00OaH00`00OQP007dK001k7@02001j7`03001i8@00N28005=<008005=<00<0
05==001BC@00DTd00P00DTd3001AC@80051=1@00D4h7001?CPH004i>5`00CDh6001>CPL004m>1@00
D4h2001@C@<0055=1000DTd01P00Ddd005=<001CC000Dd`007PR001i8@8007XO00<007/M001m6`00
OQP00P00OaH00`00P1<0088@00233@0200252P0300271P00R0800HX000801X`000@02hh0016A000H
T`007iH00P0WV0000`0_V`00>Il004FR000205:V0003066[001b/000QkD00080Wk/000<0_<<00<^e
003DV`000P3PN@000`3]B000o`800?l000050?l00280008I1Oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo8`000QT60?l000060?d9003/C000k4`00=mk003DW@00b[H00P2k`P00
0`2N^`00Q[D007:`0002062[000305:V0015XP00>Il00080;i`000@09iP001nF000HT`004I400P0<
SP000`06S0000XX000280P0200271P0300252@00P`d0088@0080084C00<007lE001n6000OAX00P00
O1`00`00Nah007XP001i8P02001DC08005=<1@00DTd4001AC@03001@C@00D4h0051>00<0051>2P00
CdhI001>CPX004m>1@00D4h00`00D4d0055=001AC@02001AC@D0059=0P00Dd`2001DC003001i8P00
NR0007/N008007`L00<007dJ001n6000OaD00P00PA<00`00PQ0008<=00252@0200271P0300280P02
RP001X`0008038h000@04I4001RC000OUP009iP00P0_W0000`0iW`00AJ8005:V0002062[000307:`
0026]@00W[/00080^l8000<0b[H00=BM003ON`000P3/C0000`3m2@00o`000?l000040?l002<0008I
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo90000QT60?l00080o0l000<0
je000=in003CW`000P3:^0000`2i`P00WK/008Fe0002076_0003062[001AYP00AJ800080>Il000@0
;i`002NH000OUP0069<00P0BT@000`0<SP001h`000::000200290@0300271@00Q@T008@<0080088?
00<0084B001o5@00OQL00P00OAX00`00O1`007/N001j8002001i8P03001DC000Dd`005=<008005=<
1@00DTd5001AC@H0051>4000Cdh5001>CQ0004m>1P00D4h5001AC@D0059=1000Dd`01P00E4`007TR
001i8P00NR0007/N001l708007dJ00<007hG001o5@00PA800P00PPl00`00Q0`008D900271@020029
0@0300::0007S00038h000804Y4000@069<001nF000WV000;i`00P0iW`000`15XP00DJH0062[0002
076_000308Fe002M^`00^L800080b[P000<0dil00=in003[D@000P3l3`060?l002@0008I1Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo90000QT60?l00080o0l000<0je000=in
003CW`000P3:^0000`2i`P00WK/008Fe0002076_0003062[001AYP00AJ800080>Il000@0;i`002NH
000OUP0069<00P0BT@000`0<SP001h`000::000200290@0300271@00Q@T008@<0080088?00<0084B
001o5@00OQL00P00OAX00`00O1`007/N001j8002001i8P03001DC000Dd`005=<008005=<1@00DTd5
001AC@H0051>4000Cdh5001>CQ0004m>1P00D4h5001AC@D0059=1000Dd`01P00E4`007TR001i8P00
NR0007/N001l708007dJ00<007hG001o5@00PA800P00PPl00`00Q0`008D900271@0200290@0300::
0007S00038h000804Y4000@069<001nF000WV000;i`00P0iW`000`15XP00DJH0062[0002076_0003
08Fe002M^`00^L800080b[P000<0dil00=in003[D@000P3l3`060?l002@0008I1Oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo90000QT80?l000030?XF003ZE@00gH400080dZ40
00<0bKT00;O1002K^`000P24]@000`1`[`00H:/0056V000204BR000403VO000_W0009iT001nF0080
69<000<04Y4000b?0007S0000P02R`000`00R@4008L500252@020024300300223`00PA80080E0080
07hG00<007dI001l6`00Nad00P00NQl00`00NB4007PS001DC004001CC0D0059=1@00DDd00`00D4d0
051>001@CP06001@CQ/004m>2000D4h00`00D4d0055=001AC@03001AC@D0059=1000Dd`00`00E4`0
07PS001i8@02001j7`03001k7P00O1/007dI008007hG00<0080E00214P00PPl00P00Q0`00`00Q@T0
08L500290@0200:;000300N<000<S`004Y40008069<000@07iH002NI000_W000>Il00P14XP000`1A
YP00Gj/0072_000208Be000309^k002g`@00bKT00080dZ4000<0gH400>YE003j5P00203o000T0002
6@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobD0008I203o00001`3i7000
jET00=b4003LQ000dZ<00<Vj002f`@000P2J^P000`23]000L:l005nZ0002056V000404BR000iW`00
;i`002NI00807iH000<069<001:A000<S`000P07S@000`03R`0008T100271@020025200300243000
PPl0084B0080080D00<007lG001m6@00O1/00P00Nad00`00NQl007TQ001h8P03001DC0@005=<1@00
DTd6001AC@03001@C@00D4h0051>00T0051>3@00Cdh;001@CP03001@C@00DDd0055=00@0055=1@00
DTd4001CC0<005A<00<007PR001i8@00NQl00P00Nad00`00O1/007dI001o5`020020500300214P00
PPl008@<008008D800<008L500290@03R`000P07S@000`0<S`004Y4001RC000201nF000402NI000_
W000>Il004BR0080DJH000<0GjX0072_0023]0000P2J^P000`2e`@00bKX00=:S00020=b400030>UI
003i7000o`0000L0o`009@000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
oolW00026@L0o`0000H0mb<00>QM003XG@00fhH00=6U0038_0020;C1000309Vj0022]000Kjl00080
GjX000@0D:H004BR000iW`00;i`00P0WV@000`0OUP0069<001:A000200f?000300N=0003R`0008T0
008008L400<008H800242`00P`h00P00PA400`00P1@007lF001n6@02001m6`03001k7@00NQl007TP
008007TR0`00E4`4001CC0D0059=2@00DDd00`00D4d0051>001@CP0G001@CP03001@C@00DDd0055=
00L0055=1@00DTd4001CC0<005A<0P00NB800`00NB0007XO001k7@02001m6`03001n6@00OaH0080D
0080084A00<008<>00242`00QPP00P00Q`@00`00R@000h/000N=000200f?000301:A000HT`007iH0
00809iT000@0;i`003VO0014XP00D:H00P1OZP000`1_[`00P[@009Vj00020;C100030<Rl003AY@00
fhH00080j5d000<0mb<00?l0003o00001@3o000W00026@Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`02ooooobP0008I1`3o00020?HY00030>MQ003JR@00d:L00080b;d000<0//0009Nj
0021]0000P1^[`00101NZP00D:H004BR000iW`0202nL000302NI000OUP006I<000804Y4000<03Hl0
00R=0003R`000P00R@000`00Q`@008H800242`0200233P0300214@00P1<007lF008007hH00<007dJ
001l7000Nah00P00NR000`00NB4007PS001DC002001DC0D005=<1P00DTd;001AC@@0051=1`00D4h4
001@C@/0055=1P00DTd5001CC0<005A<00L007PS001i8@00NR0007XP001k7P00O1`007dJ008007hH
00<007lF00204`00PA400P00P`h00`00Q0/008H8002710020029000300>;0008S@003Hl000804Y40
00<06I<001nF000WV@000P0_V`00100iW`00A:80052V001NZP0206j_0003086d002G^P00//000080
b;d000<0d:L00=Z9003WH@000P3f:@070?l002P0008I1Oooool1o`00007ooooo000Kooooo`;o0000
0ooooolX00026@L0o`000P3f:@000`3WH@00fXT00=2W00020<Rm00030;;0002G^P00PK@00080KZl0
00@0GZX0052V0014XP00>Il00P0_W0000`0WV@007iH001VC000201:A000300f?0008S@000h/00080
08T000<008L400262000Q0/00P00P`h00`00PA40080C001o5P02001n6003001m6P00O1`007/N0080
07XP00<007TQ001h8`00E4`00P00E4`5001CC0H0059=2`00DDd4001@C@L0051>1000D4d;001AC@H0
059=1@00Dd`3001DC007001h8`00NB4007XP001j8000Nah007`L001m6P02001n6003001o5P00P1<0
084A008008<>00<008@;00262000Q`@00P00R@000`03R`0028d000f?000201:A000301VC000OUP00
9iT00080;i/000@0>Il004BR001@YP00GZX00P1^[`000`21]000UkX00;;000020<Rm00030=2W003J
R@00if400080mRT01`3o000X00026@Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`02
ooooobT0008I203o00000`3d;`00iFD00=V<00020<nY00030<Nn002``000U[T00080P;@000@0KJh0
05fZ001@YP00@j800P0iW`000`0_V`009iT001nF000201VC000301>A000=S`0028d000800h/000<0
08T000281000QPL00P00Q0/00`00P`h0088@00204`02001o5@03001n6000OAX007`L008007/N00<0
07XO001i8@00N2<01@00E4`4001CC003001CC@00DTd0059=00H0059=6`00DDd8001BC@03001CC@00
Dd`005=<008005=<1@00E4`00`00N2<007TQ001j7`02001k7P03001l7000OAX007hH008007lE00<0
080C00224000P`h00P00Q0/00`00QPL008P40029000200>;000300R=000=S`004i4000806I<000<0
7iH002NI000_V`000P0iW`001013XP00D:H005fZ001][P02082d000309Ji002``000akh00080cjT0
00<0fH`00>EU003d;`00203o000Y00026@Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`02ooooobX0008I203o00001`3b=@00i6T00=V?003IS`00cj/00<K0002^_`000P2E^@00101o/`00
KJh005fZ001?YP0204>R000303VO000_V`009iT0008089H000<06I<001>A000=S`000P08S@000`04
R`0008T000280`0200261`0300252P00P`d0088@0080084C00<007lE001n5`00OAT00P00O1/00`00
Nad007XO001i8@02001h8P03001h8`00E4`005A<00<005A<1@00Dd`;001BC@l0055=2P00DTd00`00
Ddd005=<001CC003001CC0D005A<00H007PS001h8P00N28007TQ001j7`00Nad2001l6`03001m6@00
OQL007lE0080084C00<0088@00233@00Q@X00P00QPL00`00R0<008T000B;000200R=000300f?000C
T@006I<0008089H000<09iT002nK000iW`000P13XP00101?YP00GJX006f^001o/`0209Bi00030:jo
0036`000cj/00080fHl000<0i6T00?8e003o00001`3o000Z00026@Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooob`0008I1`3o00001P3a>`00hfd00>=]003HTP00cZd00<K10080
[;l000@0TkP007jc001/[P00G:X00P1?YP000`13XP00>Il002nK000202NI0003022F000IU0004i40
00803Xl000<02Hd000B;0000R@000P00R0<00`00QPL008D:00233@020022400300214P00P1D007hG
008007dI00<007`K001k7@00NQh00P00NR000`00NB8007PS001EB`05001DC0L005=<00<005==001B
C@00DTd06@00DTd00`00Ddd005=<001CC005001CC0D005A<00<005E;001h8`00NB800P00NR000`00
NQh007/M001l6`02001m6@03001n5`00P1D0084B0080088@00<008<=00252P00QPL00P00R0<00`00
R@0018/000V=000200j?000301>A000IU00089H000809iT000<0;i/003VO0013XP000P1?YP00101L
ZP00K:h007jc002C^0020:bo00030<K1003>[@00f9800080hfd000<0lC/00?l0003o00001@3o000/
00026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobd0008I1`3o00020>m1
00030>9a003GU000cJh00080aL<000@0Z[h009:h001m/`00Jjh00P1LZ@000`1>Y@00@j8003RN0002
02nK000302NI000PUP006I@000804i4000<03Xl000V=0004R`000P00RP000`00R0<008H600252@02
0024300300223`00PA80080D008007lF00<007hH001m6P00O1`00P00Nah00`00NR0007TQ001h8P03
001EB`H005A<2000Dd`2001CC@l0059=0P00Ddd8001CC0H005A<0`00ED/00`00N28007TQ001j8002
001k7P03001l7000OAX007hH008007lF00<0080D00214P00PPl00P00Q0`00`00Q@T008H600280`02
002:000300B;0009S@003Xl000804i4000<06I@0022F000WV@000P0_V`000`0hWP00@j8004jU0002
05bY000406^^001m/`00T[P00:Zn0080aL<000<0cJl00=ND003RL@000P3_@@070?l002d0008I1Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo;@000QT70?l00080kd4000<0hW40
0=ND003=[P000P35``00102Z_P00T[P007fc001[[P0205bY000304jU0013XP00>9h00080;i/000<0
9iT0022F000IU0000P0CT@000`0>S`002Hd000B;0002002:000300280`00QPH008D9008008@<00<0
088?00214P00P1@00P00OaH00`00OQP007dJ001l7002001k7P03001j8000NB4007PR00<005E;1P00
E4`8001CC08005==3`00DTd2001CC@P005=<1P00E4`3001EB`03001h8P00NB4007XP008007/N00<0
07`L001m6P00OQP00P00OaH00`00P1@0084B00223`020024300300252@00QPH008P3008008X000<0
18/000V=000>S`000P0CT@000`0IU00089H002NI000202nK000303RN0013XP00CZD00080G:T000@0
Jjh007fc002B^000Z[h00P35``000`3=[`00ei@00>9a00020>m100L0o`00;@000QT5ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_ooool]00026@L0o`000P3n1P000`3^A`00hGD00=JG
00020<f`00040<G4002X_P00T;P007bb0080JZh000<0FjT004jU0012XP000P0hWP000`0_V`009iT0
022F000201VD000301>A000>S`002Hd000801H`000<00HX000280P00Q`H00P00Q@T00`00Q0`0088?
00214@0200205003001o5P00OQP007dJ008007`L00<007/M001j7`00NB400P00NB800`00N2<005E;
001EB`02001EB`H005A<6`00Dd`6001DC0@005E;00H007PS001i8P00NB8007TQ001j7`00Nad2001l
7003001m6P00OQP007lF0080080D00<0084A00223`00Q0`00P00Q@T00`00Q`H008P2002:000200F<
000300V=000>S`004i4000806I@000<089H002NI000_V`000P0hWP000`12XP00CZD005^Y000206Z^
000407bb002@^000Z;h00<G40080cK0000<0eYL00>5e003^A`000P3n1P070?l002d0008I1Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo;P000QT80?l000030?`>003/C@00ggT0
0080eIX000@0c;800<?4002V_@00SkL00P1k/P000`1Y[@00FZT004jU000204:R000303RN000_V`00
9iT0008089H000<06I@001BA000>S`000P09S@000`05S0000HX000280P0200271@0300252@00Q0`0
08<>0080084A00<0080C001o5@00OQL00P00OAT00`00O1/007/M001j7`02001j8003001i8@00N2<0
05E;00@005E;00<005E<001DC000E4`01`00E4`?001CC0T005A<00<005E<001EB`00ED/00`00ED/0
1`00N2<007TQ001j8000NR0007XO001k7@00O1/00P00OAT00`00OQP007lE00204`0200214@030023
3P00Q0`008D9008008L500<008P2006:0005S0000P09S@000`0>S`00594001VD0002022F000302NI
000_V`00>9h00080@Z8000<0CJD005ZY001Y[@000P1k/P00102?]`00Y[d00<?4003</P020=FJ0003
0=mi003/C@00o0h000P0o`00;P000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_ooool_00026@P0o`0000P0nQL00>]C003NO@00gWd00=BM003;]000`<<00:Bm0080SKL000<0NK80
06R]001JZ@000P1=Y@000`12XP00>9h002nK000202NI0003022F000JU000598000803Xl000<02Xh0
00F<0001RP000P00R0800`00Q`D008H800242`0200233P0300224000PA<007lE008007hG00<007dI
001l6`00O1`00P00Nah00`00NQl007TQ001h8P02001h8`03001FB`00ED/005E;00@005E;6@00E4`6
001EB`06001FB`00N2<007PS001h8P00NB4007XO0P00Nah00`00O1`007`K001m6@02001n5`03001o
5@00PA<0088@008008<>00<008@;00262000Q`D00P00R0800`01RP001H`000Z>000200j?000301BB
000JU00089H000809iT000<0;i/003RN0012XP000P1=Y@000`1JZ@00J:d007Vb000208fg00040:Bm
0030``00bk@00=BM0080gWd000<0je<00?XG003o00001`3o000_00026@Gooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`02oooooc40008I1`3o00001`3h7`00jEP00>UH003MP@00dil00<Zf
002m``000P2R_0000`2<]`00N;4006R]000205VY000304fU0012X@00>9h00080;i/000<09iT0022F
000JU0000P0DTP000`0?T0002Xh000J<000200::000300290@00Q`D008H8008008@;00<008<=0022
4000PA800P00P1@00`00OaH007hH001m6P02001l7003001k7@00NQl007TP008007TR00<007PS001F
B`00ET/02P00ED/2001EC0T005A<0P00ED`:001EB`8005I;00H007PS001i8P00NB8007TP001j7`00
Nad2001l7003001m6P00OQP007lF0080080D00<0084B00224000P`d00P00Q0/00`00QPP008L50029
0@0200::000300J<000:SP003i000080598000<06Y@0022F000WV@000P0_V`000`0hWP00@Z4004fU
000205VY000306R]001h/@00S;L00080X[`000@0_L<00<Zf003CW`00gH400P3YF0000`3h7`00o`00
0?l000050?l00340008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo<@00
0QT70?l000070?PO003YF000jEP00=f1003CW`00b[H00;g300020::l000308bg001h/@00J:d00080
FJT000<0CJD004:Q000hWP000P0_V`000`0WV@0089H001ZD000201BB000300n@000:SP001X`00080
0XX000<008T100271@00QPP00P00Q0/00`00P`d0088@00214P0200205003001o5P00OQP007dJ0080
07`L00<007/M001j7`00NB000P00NB800`00N2<005I;001FB`0:001EB`8005E<2@00E4`2001EC0X0
05E;0P00ET/01P00N2<007TR001i8P00NB0007XO001k7@8007`L00<007dJ001n6000OaH00P00P1@0
0`00PA80088@00233@0200242`0300262000Q`D008T100800XX000<01X`000Z>000?T0000P0DTP00
0`0JU00089H002NI000202nK000303RN0012X@00CJD00080FJT000<0J:d007Ra002<]`000P2R_000
102m``00b[H00=>O003MP@020>UH00030?PO003o0000o`0000D0o`00<@000QT5ooooo`7o00000Ooo
ool001_ooooo0_l00003oooooc80008I1`3o00020?HW00040>QN003LQ@00dZ800<Vh0080^l8000<0
X;`008Zf001g/@000P1W[@000`1IZ000C:D0046Q000203RN000302nK000WV@0089H000806Y@000<0
598000n@000:SP000P06S0000`02RP0008T10027100200261`0300252P00P`d0088?0080084B00<0
080D001o5P00OQP00P00OAX00`00O1/007/M001k7P02001j8003001i8@00N28005I;00D005I;5`00
ED/6001FB`07001h8P00NB4007XP001j8000Nah007/M001l6`02001m6P03001n6000OaH0080D0080
084B00<0088?00233@00Q@X00P00QPL00`00Q`@008T100::000200J<000300Z>000?T00059800080
6Y@000<089H002NI000_V`000P0hWP000`11X@00C:D005VX000206N]000307Na002:]P00X;`00080
^l8000@0bKP00=:R003LQ@00j5h00P3f9`070?l00380008I1?ooool2o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo<`000QT80?l000040?@_003VH`00fhP00=6U0080bKX000<0^<8009jk
0029]P000P1f/@000`1V[000F:P004bU0002046Q000303NN000_V`009iT0008089H000<06Y@001BB
000?T0000P0;SP000`06S0000X/0002900020028100300261`00Q@X008@<0080088?00<0084A0020
4`00OaD00P00OQL00`00OAT007dK001l7002001k7P03001j7`00NB0007TQ008007PS00<005M:001F
BP00ET/02@00ET/5001EB`X005I;00L005I:001GBP00N2<007PS001i8@00NB0007XO008007/N00<0
07`L001m6`00OAT00P00OQL00`00OaD0080C00214@0200223`0300243000Q@X008H7008008P400<0
08T000:;0006S0000P0;SP000`0?T000598001ZD0002022F000302NI000_V`00=ih00080@J4000<0
C:D005RX001V[0000P1f/@000`29]P00W[/00;S200020<Vj00040=6U003KR000iV<00?@_00P0o`00
<`000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooold00026@P0o`0000<0
lSL00>EX003IS0000P3@Y`000`38_000]/4009bk000208Ne000307F`001U[000EjP00080Bj@000<0
@J4003NN000_V`000P0WV@000`0PUP006Y@001FB0002012@000300^>0007S0000h/0008008T000<0
08P300261P00Q@T00P00Q0`00`00P`h0088A00214`0200205@03001o5`00OQP007dJ008007`L00<0
07/M001k7P00NR000P00NB400`00NB8005M:001GBP02001GBP8005I:3`00ET/2001FBP@005M:00H0
07TR001i8@00NB4007XP001k7P00Nad2001l7003001m6P00OQP007lG0080080E00<0084C00224@00
P`h00P00Q0`00`00Q@T008H600280`020029000300>;0007S0002hh00080490000<05I8001ZD000P
UP000P0WV@000`0_V`00=ih0046Q000204^T000305NX001U[000MK000080QkD000<0W;/00;K10038
_0000P3@Y`000`3IS000iFP00?8g00080?l003@0008I1Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo=0000QT90?l000070?0n003SK@00f9000=R@003?ZP00akh00;?0000209Zj
000308Fe001d/000I:`00080EjP000<0Bj@0042Q000gWP000P0_V`000`0WV@008IH001ZD000201FB
0003012@000;SP001h`000800h/000<008T000280`00Q`H00P00Q@T00`00Q0/008<>002240020021
4P0300205000OaH007hH008007dI00<007`K001l7000Nah00P00NQl00`00NR0007TQ001h8P0G001G
BP03001h8P00NB4007XP008007XO00<007/N001l7000O1/00P00OAT00`00OQP007lF002050020021
4P0300224000P`h008@;008008D900<008L600280`00R@000P03R`000`07S0002hh0012@000201FB
000301ZD000QUP009iT00080;i/000<0=ih0042Q001;Y0000P1GZ0000`1T[000M;0008Fe000209Zj
00030;?00037_P00cjX00080f90000<0hfd00?0n003o0000203o000d00026@Gooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`02oooooc@0008I2@3o00001`3`?P00hfd00=R@003HT000cjX0
0<Nn002c`0000P2J^P000`25]@00M;0006B/000205NX000304^T0010X@00=ih00080;i/000<09iT0
026F000JU0000P0ETP000`0@T0002hh000N<000200>;000300290000R0<008L6008008D900<008@;
00233P00PQ000P00PA800`00P1@007lF001n6002001m6@03001l6`00O1`007/N008007XO00<007XP
001i8@00N2805`00EdX00`00N28007TQ001j8002001j7`03001k7P00O1`007`K008007dI00<007hH
001o5P00P1@00P00PA800`00PQ0008<>00242`0200252@0300271P00R0<008T000800h/000<01h`0
00^>000@T0000P0ETP000`0JU0008IH002NI000202nK000303NN0010X@00Bj@00080EjP000<0I:`0
07B`0025]@000P2J^P000`2c`000akh00<nZ00020=R@00030>=]003`?P00o`0000P0o`00=0000QT5
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolf00026@L0o`0000L0oPL00>i5
003RLP00hW800=NC003>[000a/000080/L0000<0V;X008Be001b/0000P1S[0000`1FZ000BZ@0042Q
000203NN000302nK000WV@008IH000806i@000<05I80012@000<SP000P07S@000`03R`0008X00028
0P0200271@0300262000Q0/008<=0080088@00<0084B00205000OaD00P00OQL00`00OQT007dJ001l
7002001k7@03001k7P00NQl007TP008007TQ0P00F4X?001GBP8005Q:0P00NB400`00NB0007XO001k
7P02001k7@03001l7000OAX007hI008007hG00<007lE00205000PA800P00PQ000`00P`d008@;0026
200200271@0300280P00RP000h/000801hd000<038h0012@000ETP000P0KU0000`0QUP009iT002nK
000203NN0003042Q001:Y000EZP00080Hj`000<0L[0008Be002H^P000P2a`0000`36`000cZ`00=NC
00020>9b00030>i5003n1`00o`0000H0o`00=P000QT5ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_oooolg00026@L0o`0000H0na400>a<003/C000h7L00=JF003=[`020<K100030:jo
002F^@00P[@00080LK0000<0HZ/005FX001:Y0000P10X@000`0gWP00;i/002NI0002026F000301^D
000ETP004900008038h000<028d000B;0000RP000P00R0800`00Q`D008H800252P0200233@030022
3`00PA40080C0080080E00<007lF001n6000OAX00P00O1/00`00O1`007/M001j7`02001j8003001i
8@00F4T005Q900<005Q91`00F4X5001HB@06001i8@00NR0007XP001j7`00Nad007`L0P00O1/00`00
OAX007hH001o5P0200205@0300204`00PA40088?008008<=00<008D:00262000Q`D00P00R0800`00
RP0018/000R=000200b>0003012@000ETP006i@000808IH000<09iT002nK000gWP000P10X@000`1:
Y000EJP006:[0002076`000308:d002F^@00[[l00080a/4000<0cJl00=JF003PM`000P3/C0000`3k
4@00o`000?l000050?l003L0008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo>0000QT70?l00080nA/000<0je<00=mk003EVP000P3</@000`35``00[;l009Fi0002086d0003
072_001RZ`00EJL00080BJ@000<0?j4003NN000_V`000P0WV@000`0QUP006i@001JB0002016@0003
00b?0008S@0018/000800HX000<008T100271000QPL00P00Q@X00`00Q0`008<>0022400200214P03
00205000OaH007hG008007hI00<007dJ001l6`00Nad00P00Nah00`00NQl007XP001i8@03001IB@L0
05Q90`00FDT00`00NB4007XP001j7`02001k7P03001k7@00O1/007dJ008007hI00<007hG001o5P00
P1@00P00PA800`00PQ0008<>0024300200252P0300261`00Q`@008T100800HX000<018/000R=000<
S`000P0AT0000`0FTP006i@0026F000202NI000302nK000gWP00?j400080BJ@000<0EJL006:[001`
[`000P21]0000`2E^@00Zkl00<G300020<ba00030=FJ003ON`00je<00080nA/01`3o000h00026@Go
oooo0Ol00001ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`03
o`000?oooooooooo00;ooooo>@000QT80?l000030?LT003YF@00gH000080e9d000<0bk<00<C4002Y
_P000P2C^0000`20/`00Kjl0066[000205BW000304VT000oX@00=Yh00080;i/000<09iT0026F000K
U0000P0FTP000`0AT@003Hl000V=000200F<0003006:0000R@4008P4008008H600<008D900242`00
P`h00P00PQ000`00PA80080C001o5@02001o5`03001n6000OAT007dK008007`L00<007/M001k7P00
NQl00P00NR09001IB@8007XP00<007XO001k7P00Nad00P00O1`00`00OA/007dI001n6002001o5`03
001o5@00P1<0084B0080088@00<008<>00242`00Q@T00P00QPH00`00Q`@008T1006:000200F<0003
00V=000=S`004I4000805Y8000<06i@0026F000WV@000P0_V`000`0fWP00?j4004VT000205BW0003
066[001_[`00P;<00080TkP000<0ZKh00<C4003;/`000P3DW@000`3MP000jET00?LT00080?l003T0
008I1Oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`02ooooocT0008I203o00000`3g9000jET00=f000020=BM
00030<^c0034a000ZKh00080TkP000<0P;<006n_001QZ`000P1DY`000`19Y000?j4003JN000202nK
000302NI000QUP006i@000805Y8000<04I4000f?0009S@000P05S0000`01RP0008T1002810020026
1P0300252@00Q0/008<>0080088@00<0084B00204`00OaD00P00OaL00`00OQP007dI001m6`02001l
7003001k7@00Nah007XO008007XP2@00FDT2001j8003001j7`00Nah007/M008007`L00<007dK001m
6@00OQP00P00OaL00`00OaD0080C00214P020022400300233P00Q0/008D9008008H600<008L40029
0@01RP000P05S0000`09S@003Hl0016A000201JB000301^D000QUP009iT00080;i/000<0=Yh003nQ
0019Y0000P1DY`000`1QZ`00Kjl0082c000209>h00030:Vn0034a000bk<00080e9d000<0gH000>UI
003g9000203o000i00026@Gooooo0Ol00001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool01?ooool2o`0000?ooooo>@000QT90?l000070?@]003WG`00g8@0
0=b4003CX000b[H00<3400020:Nm0003096h001n/`00KZl00080H:/000<0E:L004VT000oX@000P0f
WP000`0_V`00:9T0026G000201^D000301JB000AT@003Hl000802Hd000<01H`000::0000R@000P00
R0<00`00Q`H008D800242`0200233@0300223`00PA40084C0080080D00<007lF001n5`00OQP00P00
OAX00`00O1/007`L001k7@02001k7P8007XO1@00FTP2001j7`8007/N00<007/M001l7000O1/00P00
OAX00`00OQP007hG001o5P020020500300214`00PA40088?008008<=00<008@;00252000Q`H00P00
R0<00`00R@000XX000F<000200V=000300f?000AT@005Y8000806i@000<08IL002RI000_V`000P0f
WP000`0oX@00BJ@005BW0002062[000306j_001n/`00TKP00080Ykd000<0`<<00<Zf003CX0000P3L
Q0000`3WG`00m2d00?l000080?l003T0008I1?ooool2o`00007ooooo0007ooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooooc/0008I203o
00001P3b=P00iFD00>EU003KR000dJ<00<Zh0080_L<000<0Y;d008ng001m/`000P1][P000`1OZP00
DjL004RT000203nQ000303JN000_V`00:9T000808IL000<079D001NC000BT@000P0>S`000`0:SP00
1X`000:;00020029000300280`00Q`D008H8008008D:00<008@<00233P00PQ000P00PA800`00P1<0
07lE001o5P02001n6003001m6@00OAX007`K008007`L00<007/M001k7P00NQh00`00FTP00`00NQh0
07/N001k7@02001l7003001l6`00OAX007dI008007hH00<007lF001o5@00P1<00P00PA800`00PQ00
08<>0024300200252P0300262000Q`D008P3008008T000<00X/000J<000:SP000P0>S`000`0BT@00
5i<001bE0002026G000302RI000_V`00=Yh00080?j4000<0B:@005>W001OZP000P1][P000`1m/`00
SkL00:Bm00020;g300030<Zh003AX`00fhP00080iFD000<0lSH00?l0003o00001P3o000k00026@Go
oooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`02oooooc`0008I203o00020?0n00030>A[003IS@00d:H0
0080bKX000<0^/800::l002=]`000P1k/P000`1/[P00GZX005:W000204RS000303nP000fWP00;i/0
0080:9T000<08YL001bE000GT`000P0BT@000`0>S`002Xh000J<000200>;0003002:0000R08008L5
008008H700<008D900242`00P`d00P00PPl00`00PA40084B00205002001o5@03001o5`00OQP007dI
008007dJ00<007`K001l7000O1d00`00Nad00`00O1d007`L001l6`02001m6P03001m6@00OQP007lG
008007lE00<0080D00214P00PA400P00PPl00`00P`d008@;00252@0200261`0300271@00R08008X0
00800h/000<01X`000Z>000>S`000P0BT@000`0GT`0079D002:G000202RI000302nK000fWP00?j00
0080B:<000<0DZL005jZ001/[P000P1k/P000`2=]`00X[`00;[200020<Vj00030=2V003IS@00i6/0
0080l3h0203o000l00026@Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooocd0008I1`3o0002
0?d;00030>i6003RL@00f9400080cjT000<0b;`00;O1002P_0000P2;]P000`1j/P00Jjh005jZ0002
05:V000304RS000nX000=Yh00080;i/000<0:9T002:G000LU@000P0GT`000`0CT@003Xl000^>0002
00N<000300B;0001RP0008T1008008L400<008H600252000Q0/00P00Q0d00`00P`h0088@00214P02
00204`0300205000OaH007lG008007hH00<007dI001m6P0bW000100bW0001`00OAX007dI001n6000
OQP007lG001o5P00P1@00P00P1<00`00PA80088@00233P0200243@0300242`00Q@P008H6008008L4
00<008T1006:0004R`000P07S0000`0;SP003Xl001>A000201NC000301bE000RU`00:9T00080;i/0
00<0=Yh003jP0018X`000P1BYP000`1NZP00Jjh007Zb000208^f00030:2l002g`@00b;`00080cjT0
00<0f9400>9a003^AP000P3m2`070?l003d0008I1Oooool1o`00007ooooo0008ooooo`;o00002Ooo
ool3o`0000Gooooo00?o0000ooooooooool00_oooolm00026@L0o`000P3m2`000`3^AP00hW400=RA
00020<nY00030<Rl002g`@00X;`00080RkH000<0N[8006^^001NZP000P1BYP000`18X`00?Z0003JN
000202nK000302RI000RU`0079D000805i<000<04i4000j?000;SP000P07S0000`04R`000HX00029
0@020027100300261P00Q@P008@;008008@=00<008<>00224000PA800P00P1<00`00P1@007lF001o
5`02001n6003001m6@00OAX0<Y`000@0<Y`000L007dJ001m6@00OQP007hH001o5`00OaH0080D0080
080C00<0084B00224000P`h00P00Q0d00`00Q0/008D800261P020027100300290@01RP0018/00080
1h`000<02hh000j?000CT@000P0GT`000`0LU@008YL002RI000202nK000303JN000nX000B:<00080
DZH000<0GZX006^^001j/P000P2;]P000`2P_000]l400<Rl00020<nY00030=RA003RL@00kTH00080
o@/01`3o000m00026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooch0008I
203o00000`3j5P00k4h00>1f00020=ND00030<j/0037_P00]<400080WK/000<0R[H007Vb001Z[@00
0P1MZP000`1AYP00Aj<003jP000203JN000302nK000XV@008YL000807ID000<069<001>A000?T000
0P0;SP000`08S@0018/0006:00020029000300280`00Q`D008H8008008D:00<008@<00233@00PPl0
0P00PQ400`00PA80080C00205@02001o5P03001o5`0fWP00=Yh000D0=Yh000H007lG001o5P00OaH0
080E00204`00PA8200224@0300223`00P`d008@<008008D:00<008H800271@00R0<00P00R@000`01
RP0018/000R=000200^>000300n@000CT@0069<000807ID000<08YL002RI000_V`000P0fWP000`0n
X000Aj<0056V000205fZ000306Z]001i/P00R[H00080WK/000<0]<400<Nn003>[0000P3GU0000`3P
MP00k4h00?XF00080?l003h0008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo?P000QT90?l000070?PQ003ZE@00gg/00=mk003EV000cJl00<K000020;;0000309^j0028]P00
Mk400080JJd000<0G:X0056V0017X`000P0nX0000`0fWP00;i/002RI000202:G000301fE000HT`00
59800080490000<038h000R=0005S0000P02RP000`00R@0008P200271@0200261`0300252@00Q0/0
08@<008008<>00<0088@00214@00PA800`0kW`0703ZO00<0>il000<0084B00214@00PQ000P00P`h0
0`00Q0`008@;00252@0200261`0300271@00R08008T000800XX000<01H`000R=000<SP000P0@T000
0`0DT@0069<001fE000202:G000302RI000_V`00=Yh00080?Z0000<0Aj<0056V001LZP000P1Y[@00
0`1g/@00R;H009^j00020;;000030<K0003=[`00eIP00080gg/000<0jUD00?PQ003o0000203o000n
00026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooocl0008I2@3o00001P3e
:`00j5`00>QL003MP000e9`00<ba0080aL8000<0[kl009Vj0026]@000P1f/@000`1X[@00FjT0052V
000204NS000303jP000fWP00;i/00080:IT000<08iL001fE000IT`000P0DTP000`0@T00038l000V=
000200J<000300>;0000RP0008T1008008P400<008L600262000Q@X00P00Q0/00`00P`d008<>046Q
0002042Q00<0?j400`0nX00303nQ0080@:4000<0@J4000233P00P`d00P00Q0/00`00Q@X008H80027
1P020028100300290@00RP000h/000801X`000<02Hd000b?000@T0000P0DTP000`0IT`007ID002>G
000202VI000302nK000fWP00?Z000080Aj<000<0D:H005^Y001X[@000P1f/@000`26]@00VKX00:no
00020<G200030<ba003DW000gH000080j5`000<0mB/00?l0003o00001`3o000o00026@Gooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`02oooood40008I203o00020?<d00030>IR003LQ@00
dil00080bk@000<0aL@00:bo002G^@000P25]@000`1e/000Ijd005^Y0002052V000304JS000nX000
=Yh00080;i/000<0:IT002>G000NU@000P0IU0000`0ETP004I0000f?000200Z>000300N<0004R`00
0HX0008008T000<008P300271@00QPL00P00Q@T00`00Q@X0Aj<004JS000204FR0080A:801@13XP02
04BR0080AJ8000<0AZ<004NS0000Q@X00P00Q@T00`00QPL008L500280`0200290003006:0004R`00
1h`000802Xh000<03Hl0016@000ETP000P0IU0000`0NU@008iL002VI000202nK000303JN000nX000
AZ<00080D:H000<0FjT006N]001e/0000P25]@000`2G^@00[;l00<G400020<^d00030=>O003LQ@00
iV800080lc@0203o001100026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooo
od40008I203o00020?<d00030>IR003LQ@00dil00080bk@000<0aL@00:bo002G^@000P25]@000`1e
/000Ijd005^Y0002052V000304JS000nX000=Yh00080;i/000<0:IT002>G000NU@000P0IU0000`0E
TP004I0000f?000200Z>000300N<0004R`000HX0008008T000<008P300271@00QPL00P00Q@T00`00
Q@X0Aj<004JS000204FR0080A:801@13XP0204BR0080AJ8000<0AZ<004NS0000Q@X00P00Q@T00`00
QPL008L500280`0200290003006:0004R`001h`000802Xh000<03Hl0016@000ETP000P0IU0000`0N
U@008iL002VI000202nK000303JN000nX000AZ<00080D:H000<0FjT006N]001e/0000P25]@000`2G
^@00[;l00<G400020<^d00030=>O003LQ@00iV800080lc@0203o001100026@Gooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`02oooood80008I1`3o00020?l200030?0m003TJ@00fXT00080
dZ8000<0b[H00<;4002Y_P000P2E^@000`23]000M;0006J/000205ZY0003052V0016X`00?Z000080
=Yh000<0;i/002VI000SU`000P0NUP000`0JU0005I80016A000200j?000300Z>0007S@001H/00080
0XX000<008T000280P00Q`@00P1?Y@000`1=Y@00C:D004^T000204ZT000304VT0018Y000B:@000<0
B:<00P18Y0001P19Y000BZ@004ZT001;Y000C:D004fU0080CjD000<008L400280P00R@000P02RP00
0`05R`001hd000Z>000200j?0003016A000ETP006Y@000807YD000<08iL002VI000_V`000P0fWP00
0`0nX000AZ<0052V000205ZY000306J/001d/000Pk@00080UKT000<0ZKh00<;4003:]P000P3BXP00
0`3JR@00i6T00?0m00020?l200L0o`00@P000QT5ooooo`7o00000Oooool001_ooooo0_l00003oooo
od<0008I203o00000`3l3P00kTH00>=_00020=V>00030=6V0039^@00_/<00080Ykd000<0TkP008:d
001b/0000P1U[0000`1JZ@00CjH004JS000203jP000303JN000`W000:IT0008099P000<07iH001ZD
000FTP000P0BT@000`0?T0002hh000R=000200F<000300>;0000RP00EZP00080E:L000<0DZL0056V
001@YP000P1?YP0204jU00D0CJD00P1>Y@0204nV0003052V001AYP00DZL00080E:L000<0EZP0002:
0003R`000P05S0000`08S@002hh000n@000201:A000301JB000JU0007iH0008099P000<0:IT0032L
000fWP000P0nX0000`16X`00CjH005ZY000206F/000307:`0021]000TkP00080Ykd000<0_/<00<Vi
003AYP000P3ISP000`3SK`00kTH00?`>00080?l004<0008I1?ooool2o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo@`000QT90?l000070?TJ003/CP00hG@00>5d003GTP00cjT00<Rk0002
0;_200030:Bm002A^000P;@00080LK0000<0I:`005VY001?YP000P16X`000`0nX000=Yh0032L0002
02ZJ000302BH000OUP006i@000805i<000<04i4000n@000<S`000P09S@000`1PZ`00GZX005bY0002
05ZY000305RX001FZ000EJL00080E:L00P1CY`0505:W0080DjL00P1DY`000`1EY`00EZP005RX0002
05ZY000305bY001NZP00H:/000802Hd000<038l000n@000CT@000P0GT`000`0KU0007iH002BH0002
02ZJ0003032L000fWP00?Z000080AZ<000<0CjH005VY001T[0000P1a/0000`20]000TKP00:Bm0002
0;_200030<Rk003?Z@00ei800080hG@000<0k4h00?TJ003o0000203o001300026@Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`02oooood@0008I2@3o00001P3g9@00jUD00>YE003ONP00
eYH00<j/0080b;d000<0^<800::l002?]`000P1o/`000`1`[`00I:`005VX000204nV000304JS000n
X000=ih00080<9`000<0:YX002FH000PUP000P0LU0000`0GT`005980012@000206Z]000306N]001T
[000HZ/00080H:/000<0GZX005bZ001KZ@000P1JZ@000`1IZ@00F:P005RX000505RX000605VY001J
Z@00FZT005^Y001LZP00GZX00P1PZ`000`1RZ`00I:`006N]000206Z]0003012@000DTP005i<00080
79@000<089H002FH000ZVP000P0`W0000`0gWP00?Z0004JS000204nV000305VX001T[000L:l00080
Ok<000<0SkL00::l002h`P000P38_@000`3>[000eYH00=mj00020>YE00030?LU003o0000o`0000L0
o`00A0000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom400026@T0o`00
00H0mbD00>YE003ZE@00ggX00=JF003>[0020<Rm00030;S2002R_000SkL00080Ok<000<0L:l006B/
001IZ0000P1?YP000`16X`00?Z0003NN0002032L000302ZJ000UV00089H0008079@000<05i<001BB
000@T0000P1Z[@000`1W[@00I:`006:[0002062[000305jZ001LZP00FjT00080FZT000<0FJT005RX
001HZ0001@1HZ0001P1IZ@00FZT005ZY001KZ@00G:X005jZ0080H:/000<0HZ/006B/001W[@000P1Z
[@000`0@T000598001NC000201bD0003022F000UV000:YX00080<9`000<0=ih003jP0016X`000P1?
YP000`1IZ000I:`0072_000207nc000308ng002R_000^<800080b;d000<0cZ`00=JF003ONP000P3Z
E@000`3g9@00o`000?l000070?l004@0008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00;oooooAP000QT80?l00080m2l000<0j5d00=io003EVP000P3=[P000`37_`00]L400:2l0002
08fg000307fc001_[`00Hj`00080F:P000<0CZD004JS000nX0000P0gWP000`0aW000:iX002JH0002
026F000301bE000HT`00M;000080LJl000<0KJh006Z^001X[@000P1V[0000`1T[000HZ/0066[0002
05n[000305nZ001NZP00GJX000@0GJX000L0GZX005nZ001OZ`00Gj/0066[001RZ`00I:`00080IZ`0
00<0J:d006Z^001][P000P1a[`000`1d/00069<001bE0002026F000302JH000[VP00<I`00080=ih0
00<0?Z0004JS001>Y@000P1HZ0000`1S[000Kjl007fc000208fg00030:2l002e`@00akl00080cJh0
00<0eIX00=io003XG@000P3d;`080?l004H0008I1Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;oooooA`000QT90?l000030?8i003VI000g8@00080e9d000<0c;400<K1002b`0000P2N
^`000`2<]`00O;8006j_000206:[000305RX001>Y@00AZ<00080?Z0000<0=ih0036L000[VP000P0V
V0000`25]@00P;<007bb000207Ra000307B`001a/000KZl00080K:h000<0JZh006R]001W[@000P1U
[00206B/00D0Hj`00P1T[00206F/000306N]001X[@00JZh00080K:h000<0KZl0076`001d/0000P1h
/@000`1l/P00P;<008Fe000202JH000302^J000aW000=ih00080?Z0000<0AZ<004jU001HZ0000P1R
Z`000`1^[`00O;8008bg000209jk00030;;00036`@00c;400080e9d000<0g8@00>IT003b>@002@3o
001700026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooodL0008I2@3o0000
0`3m2`00kd800>AZ00020=Z900030=:Q003;]000aL<00080/<0000<0Vk/008Zf001k/P000P1^[`00
0`1RZ`00F:P004jU000204JS000303jP000hWP00<Y`00080TkP000<0SKL008Rf0023]0000P1o/`00
0`1l/P00N;4007Fa000207>`0003076_001_[`00KJh00080K:h000<0Jjh006Z]001Y[@00101Y[@00
1`1Z[@00Jjh006b^001/[P00KJh006n_001a[`000P1c/0000`1e/@00N;4007bb000207nc000308>d
0028]P00SKL00080TkP000<0<I`003RN000nX0000P16X`000`1>Y@00F:P006:[000206j_000307^b
002:]P00Vk/00080[kl000<0aL<00<^d003BX@000P3JR@000`3TJP00kd800?d;00090?l004L0008I
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;oooooB0000QT90?l000070?XG003]
BP00hW000>9`003IS@00dJ@00<Zf00020<C400030:fo002I^P00RKH00080N[8000<0KJh0066[001G
Z0000P1>Y@000`16X`00Z[h00:>l000209bk000309Ji002@^000RkL00080QkD000<0Pk@0082c001m
/`000P1j/P000`1g/@00MK4007B`000207:`0003076_001`[`00L:l000<0Kjl00P1`[`001P1a[`00
L[0007:`001d/000MK4007Na0080N[8000<0OK<0082c0023]0000P27]@000`2;]`00T;P009Ji0002
09bk00030:>l002Z_P00AZ<00080CZD000<0EjP0066[001][P000P1j/P000`29]P00VKX00:fo0002
0<C400030<Zf003AY000fHd00080hW0000<0kDX00?XH003o0000203o001800026@Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`02ooooodP0008I2@3o00001`3j5`00kDX00>9`003RL000
fHd00=6T003:]P000P34a0000`2]_`00VKX008Vf000207Zb000306f^001QZ`00EjP00080CZD000<0
AZ<00:Zn002S_0000P2L^`000`2F^@00T;P008^g000208Ne000308>d0020/`00OK<00080N[8000<0
Mk4007Fa001d/0000P1b/0000`1a[`00L:l0072_000306n_0080L:l000H0LJl007:`001b/000M;00
07Fa001g/@0207Zb000307fc0020/`00Pk@00080QkD000<0RkL0092h002F^@000P2L^`000`2S_000
Z[h004JS000204jU000305NX001QZ`00KJh00080N[8000<0RKH009Vj002]_`000P34a0000`3:]P00
dJ@00=V=00020>9`00030>e:003j6000o`0000P0o`00B0000QT5ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool00_oooom900026@T0o`0000H0mb<00>]B003[DP00h7H00=RB003@Y`020<Vi
00030<33002Z_P00V;X00080QkD000<0NK8006b^001QZ`000P1GZ0000`2o``00]/400:fo00020:Jm
000309nl002I^P00U;T00080SkP000<0RkH008Ne0024]@000P21]0000`1o/`00O;<007^b000207Vb
000307Ra001g/@00M[4000@0M[4000L0Mk4007Ra001i/P00NK8007^b001l/`00Ok<00080PK@000<0
Q;D008Ne002;]P000P2?^0000`2D^@00VKX009nl00020:Jm00030:fo002f`@00_l<00080EjP000<0
HJ/006b^001i/P000P27]@000`2G^P00Z[h00<3300020<Vi00030=2W003HTP00h7H00080je8000<0
mb<00?l0003o00001`3o001900026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02
oooood/0008I203o00020?@^00030>UJ003OO000eYH00080cjX000<0b;/00;g3002X_P000P2F^@00
0`26]@00N;4006b^00020<Vk00030<K10031a000^<800080/<0000<0ZKh00:>l002M^`000P2H^P00
0`2C^@00SkP008bg000208Vf000308Je0024]000P[@00080P;@000<0Ok<007jc001m/`00101m/`00
1`1n/`00Ok<0082d0020]000P[@008Bd0026]@000P29]P000`2<]`00SkP009>i000209Rj000309fk
002S_000ZKh00080/<0000<0^<800<740036`@000P39^`000`1/[P00N;4008Je000209Ji00030:Rn
002m``00b;/00080cjX000<0eYH00=ml003YFP000P3d;P080?l004/0008I1Oooool1o`00007ooooo
000Kooooo`;o00000ooooom;00026@X0o`0000<0lSP00>MQ003MP@000P3EV@000`3>[@00b;d00;[2
00020:Jm000309Bi003BX@00cjX00080c;8000<0bKT00<No0034a0000P2k`P000`2d`@00[Kl00:Nm
00020:6l000309bk002H^P00U;T00080TKP000<0S[L008^f0029]P000P27]@000`26]@00QKD008Be
000408Be000708Fe0026]@00QkD008Ne0029]P00RkH008jg0002096h000309Bi002H^P00W;/00080
XK`000<0Ykd00:fo002d`@000P2k`P000`34a000akl00<Vi00020<bb00030<nZ003BX@00U;T00080
Y[d000<0^/800<Rm003>[@000P3EVP000`3MP@00if400?8h000:0?l004/0008I1?ooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo00;oooooC0000QT90?l000030?`=003_@@00iFP00080fhH0
00<0e9d00<f`0037_`000P2g`@000`3JRP00eYH00=:Q00020<nZ00030<ba003:^000akh00080aL<0
00<0_l<00;O1002a`0000P2[_P000`2U_@00XK`009fk000209Vj000309Ji002C^@00TKP00080SkL0
00<0S[L008fg002<]`00102<]`001`2=]`00S[L008ng002?]`00TKP009>i002F^@000P2I^P000`2M
^`00XK`00:Fm00020:^n00030;70002g`@00_l<00080aL<000<0akh00<Zh003</@000P3?ZP000`3B
X@00eYH00=Z:00020;O100030<No003=/000e9d00080fhH000<0iFP00>m1003l3@002@3o001<0002
6@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooood`0008I2@3o00000`3l3@00
kd400>EX00020=^600030=BM003=/000akl00080]l4000<0fXX00=JF003BX@000P3?ZP000`3</@00
b[P00<Nn00020<G300030;o3002g`@00/L000080Zkh000<0YKd00:6l002M^`000P2I^P000`2F^@00
TkT0096h000208ng000308jg002=]`00S;L000@0S;L000L0SKL008jg002?]`00SkL0096h002C^@00
U[T00080VKX000<0WK/00:6l002U_@000P2[_P000`2a`000]l400;o300020<G300030<Nn003:^000
c;400080cjX000<0dZ400=JF003JRP000P2g`@000`37_`00cK000=BM00020=^600030>EX003_@@00
o0d000T0o`00C0000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom=0002
6@T0o`0000L0nAX00>e:003SKP00hfh00=Z:003BX@00jET00080hf`000<0gWd00=Z:003FUP000P3C
X0000`3@Z000cK000<Zf00020<Rl00030<K10032a000^l800080]L4000<0[kl00:Zn002V_@000P2R
_0000`2N^`00W;/009Vj000209Nj000309Ji002D^@00U;T000<0TkT00P2D^@001P2F^@00UkX009Nj
002I^P00W;/009jk0080X[`000<0Y[d00:Zn002__`000P2e`@000`2k`P00`/@00<K100020<Rl0003
0<Zf003=/000d:P00080dj0000<0eYH00=Z:003NO@000P3SK0000`3YF@00dZ400=Z:00020>=^0003
0>e:003i6P00o`0000P0o`00C@000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_oooom=00026@X0o`0000H0mRD00>]B003[DP00hG@00?DY003^A0020>QK00030>=]003NO@00fXX0
0080eYD000<0dil00=2W003=[P000P3;]@000`39^P00akl00<G300020;o300030;W2002d`@00[kl0
0080Zkh000<0Ykh00:Bm002R_0000P2P_0000`2N^`00WK/009bk000309^k000309bk002M^`00W[/0
0080X;`000<0X[`00:Bm002W_P000P2[_P000`2__`00]<400;W200020;o300030<G30037_`00bKX0
0080bkD000<0cJh00=2W003CW`000P3FU@000`3JRP00gWd00>=]00020>QK00030>i4003e:@00hG@0
0080je8000<0mRD00?l0003o0000203o001=00026@Gooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`02ooooodh0008I2P3o00020?@`00030?l0003l3@00mBd00080kTL000<0j5`00>=^003N
O@000P3JR@000`3GU000dih00=6V00020<j]00030<bc0039^000b;d00080a/4000<0a<@00;k3002i
`P000P2e`@000`2a`000[Kl00:^n00020:Rn00030:Nm002U_@00Y;d000@0Y;d000L0YKd00:Nm002X
_P00Z;h00:^n002]_`00/L000080]L4000<0^L800;k30034a0000P36`@000`38_@00bKP00<bc0002
0<j]00030=6V003CWP00ei@00080fXT000<0gWd00>=^003XG0000P3^A`000`3e;@00o0d00?l00002
0?@`00X0o`00CP000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom@0002
6@`0o`0000H0na400?@`003d<000kDP00>QM003SKP020=il00030=^9003GT`00e9`00080dJ@000<0
cj/00<ba003:]P000P39^`000`37_P00aL800<C400020;o300030;_2002g`@00]<400080//0000<0
/<000:jo002]_`00102]_`001`2^_`00/<000;;0002b`000]<400;O1002k`P000P2o``000`34a000
aL800<Nn00020<Vk00030<Zf003</@00cj/00080dJ@000<0e9`00=NC003KR@000P3NO0000`3SKP00
j5d00>e800020?@`00030?/A003o0000o`0000X0o`00D0000QT5ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool00_oooom@00026@`0o`0000H0na400?@`003d<000kDP00>QM003SKP020=il
00030=^9003GT`00e9`00080dJ@000<0cj/00<ba003:]P000P39^`000`37_P00aL800<C400020;o3
00030;_2002g`@00]<400080//0000<0/<000:jo002]_`00102]_`001`2^_`00/<000;;0002b`000
]<400;O1002k`P000P2o``000`34a000aL800<Nn00020<Vk00030<Zf003</@00cj/00080dJ@000<0
e9`00=NC003KR@000P3NO0000`3SKP00j5d00>e800020?@`00030?/A003o0000o`0000X0o`00D000
0QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooomA00026@`0o`000P3j5@00
0`3c<P00kDX00>QM00020>=^00030=ml003KR000ei800080e9/000<0dZ800<nY003=[P000P3;/`00
0`3:^000b;`00<No00020<K200030<G40031a000_/<00080^l8000<0^L800;S1002g`@000`2f`@00
0`2g`@00^<400;W200020;_200030;k30031a000aL@00080a/8000<0akl00<Rl003:^0000P3;]000
0`3=[`00cjT00=:R00020=BK00030=NB003KR000gg`00080hfh000<0j5d00>e:003c<P000P3j5@0<
0?l00540008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;oooooD@000QT>0?l0
00030?TI003c=@00kD/00080ieh000<0hfh00=mk003KQP000P3HT0000`3EV@00dj000=2V00020<j/
00030<ba003;]@00bKT00080b;`000<0akh00<K10035`P000P35a0000`33a000`L@00<3300040<33
00070<740033a000aL@00<G40035`P00a/400<Nn00020<Rl00030<Vi003;]@00c;400080cZ`000<0
d:H00=>P003EV@000P3HT0000`3KQP00gg/00>=^00020>MN00030>e;003c=@00nAT000h0o`00D@00
0QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooomB00026@h0o`0000L0nA`0
0?8g003/C000k4`00>MN003SK@00ggX00080g8D000<0fHl00=JG003CWP000P3AY0000`3?Z@00cZh0
0<bb00020<^e00030<Zh0039^`00b;d00080akh000<0a/000<K10036`@000`36`P020<K100060<K0
0037_P00akh00<Rm0039^`00b[P00P3;]@000`3</P00cZh00<nY00020=6T00030=>N003FU`00fHl0
0080g8D000<0ggX00>=]003WGP000P3/C0000`3b=`00nA`00?l0000=0?l00580008I1Oooool1o`00
007ooooo000Kooooo`;o00000ooooomA00026@03000O=@007cH0o`0000`0o`0000L0o`400?PO003b
>000lSP00>a=003WGP00hf`00080h7T000<0g8<00=V<003GU0000P3DV`000`3BX@00d:H00<nZ0002
0<f^00030<ba003;]000b[H00080bKP000<0bKX00<Rk0038^`000`38_0020<Rk00060<Vj0039^000
bKP00<Zf003;]000c;400P3=[P000`3?ZP00d:H00=:Q00020=BK00030=ND003IS000g8<00080h7T0
00<0hf`00>MN003/C@000P3b>0000`3h7`00o`400?l0000<0?l00003000O=P007cD0008I0500008I
1?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00;oooooD@000QT00`007cD001lf0?l0
000<0?l000070?l1003h7`00lSP00?8h003/C@00ieh00>=/00020>1i00030=b3003IS000ei@00080
e9/000<0dZ400=2V003?ZP000P3=[P000`3</@00bk@00<Zf00020<Vh00030<Vj0038^`00b;/000<0
b;`00P38^`001P39^P00bKP00<Vh003:]P00bk@00<ba0080cJh000<0cjX00=2V003BX@000P3DV`00
0`3GU000fH`00=b300020>1i00030>=/003WGP00k4d00080lSP000<0n1l00?l1003o0000303o0000
0`007cH001le00026@1@00026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooo
odh0008I0P007SD00`007cD001lf000O=P0>0?l000060?h5003g8P00mb800?4i003/C@00j5d00P3T
J`000`3PM`00gH400=Z:00020=RB00030=FH003CWP00dZ<00080d:L000<0cjX00<j]003=/0000P3<
/P000`3;/`00bk@00<^e00030<^f00030<^e003;]000bk<00080c;8000<0cK000<j]003?ZP000P3@
Y`000`3BX`00dih00=FH00020=RB00030=Z:003MP@00h7L00080i6/000<0j5d00>a=003a>@000P3g
8P000`3n1@00o`000?l0000<0?l0008001lf00<001le000N=@007SD0CP000QT5ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_oooom=00026@03000N=@007cD001le008001lf0`0083H=
0?l00080o@P000<0mb@00?4j003/C@000P3XG@000`3TJP00hGD00=io00020=^700030=V?003FU@00
eIX00080dil000<0dZ<00=2V003?Z@000P3?Z`000`3>[@00cZh00<f_00040<f_00070<j^003>[@00
cj/00<n[003?Z@00d:H00=:S00020=>O00030=FJ003FU@00fHl00080fhL000<0gWl00>5e003TJP00
0P3XG@000`3/C@00lCX00?LT00020?d800d0o`000`0083H2000O=P8001le00<001he00026@000QT0
B`000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom;00026@8001he00@0
01le000O=P007cH001lf0P0083H3000Q=`h0o`0000<0o@/00?LU003a>P000P3/C0000`3XF`00iFP0
0>5c00020=il00030=b4003JR`00f9400080eYH000<0eIX00=>N003BX@000P3AX`000`3AY@00d:L0
0=2X00040=2X00070=2W003AY@00dJ<00=6S003BX@00dih00=FJ00020=JF00030=RA003JR`00g8@0
0080gW`000<0hG<00>EX003XF`000P3/C0000`3a>P00mbD00?d;000>0?l000<0024g0P0083H3000O
=P03000O=@007SD001he04/0008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
ooooB@000QT4000N=@03000O=@007cH001lf0080020f00@0020g000Q=`008CL0024g3`3o00001`3l
3@00mRH00?4j003a>P00kD/00>UJ003UIP000P3RL0000`3ON@00gH400=^700020=V=00030=RB003F
UP00eIT00080e9`000<0dih00=>O003CX0000`3BX@000`3CX000dil00=>N00020=BL00030=FI003F
UP00f9800080fHd000<0fhL00=f1003ON@000P3RL0000`3UIP00jEX00>e;00020?4j00030?HV003l
3@00o`0000h0o`000`008CL00`0083L0020f000P=P02000O=P03000O=@007SD001he008001heB@00
0QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooom900026@@001he00<001le
000O=P007cH00P0083H0100083L0024g000Q=`008CL?0?l000070?`=003f9P00lCX00?4j003]B`00
jEX00>EV00020>9`00030=mi003MP@00fhL00080fHd000<0f9800=JF003EV@000P3DW0000`3CWP00
dil00=>P00030=:Q00030=>P003CW`00dih00080e9`000<0eIT00=JF003HTP000P3IS@000`3KQ`00
gH400=mi00020>9`00030>EV003YFP00kD/00080lCX000<0mRH00?`=003o00003P3o0003000Q=`03
000P=`0083H0020f008001lf00<001le000N=@007SD00P007SE900026@Gooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`02ooooodP0008I10007SD00`007cD001lf000P=P02000P=P06000P
=`008CL0024g000Q=`008SL0028h3`3o00001P3l3`00mRH00?HV003a>P00kDX00>UH0080iV<000<0
hfd00>1f003NO@000P3LP`000`3KR000fHd00=R@00020=NC00030=JE003FU`00eIP000<0eIT000<0
eIP00=JG003FU@000P3GT`000`3HT000fHd00=^800020=b300030=im003PMP00hfd00080iV<000<0
jEP00>e:003a>P000P3f9P000`3l3`00o`000?l0000=0?l00003000R>0008SL0024g0080024g00H0
020g000P=P0083H0020f000O=P007cD4000N=DP0008I1Oooool1o`00007ooooo000Dooooo`;o0000
1Oooool00ol0003oooooooooo`02ooooodH0008I00<001dd000N=@007SD00P007SD00`007cD001lf
000P=P03000P=P80024g0P008SL00`008SP002<h000S>00?0?l00080o10000<0mRH00?8i003]B000
0P3ZE@000`3WH000i6X00>9b00020>1i00030=in003LP`00fhL00080fXX000<0fHd00=V?003HT000
103HT0001`3IS`00fHd00=Z:003JRP00fhL00=b3003NOP000P3PN@000`3RLP00i6X00>MP00020>YE
00030>e8003b>@00mRH00080o1003`3o0002000S>003000R>0008SL0028g0080024g100083H00`00
7cH001le000N=@03000N=@03000M=0000QT0008I04@0008I1Oooool1o`00007ooooo000Cooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oooom400026@8001dd0`007SD2000O
=@8001lf0`0083H2000Q=`03000R=`008SP0028h008002<h00<002@i0?l0003o00003`3o00000`3k
4@00mRH00?8g00020>i600030>]B003XG@00iFH00080hfd000<0hG@00=mi003NO@000P3MP@000`3L
P`00g8H00=^700040=^700070=b6003LQ000gH400=f1003NO@00ggT00>5d00020>=]00030>EV003X
G@00je800080kTH000<0lSL00?HV003k4@004@3o00000`0093T002<h000S>002000R>003000R=`00
8CL0024g00<0020f0P007cH2000O=@<001he0P007CA400026@Gooooo0Ol00001ooooo`004oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo@P000QT2000M=0@001he00@0
01le000O=P007cH001lf0P0083H4000Q=`<0028h0P008cP00`0093T002Di000U>@0@0?l000070?/A
003g9@00lSD00?8e003_@`00k4l00>UI00020>MQ00030>EX003SKP00hG<00080h7L000<0ggX00=ml
003NO@000`3NOP000`3NO@00gg`00=mj00020>1g00030>5c003SKP00iFP00080if4000<0jET00>a?
003_@`000P3b=@000`3g9@00na400?l0000?0?l0008002Di00<002@i000S>0008cP00`008SP4000Q
=`80020f0`007cH00`007cD001he000N=@02000N=@8001dd@P000QT5ooooo`7o00000Oooool001?o
oooo00Co0000oooooooooooo00001?ooool2o`0000?ooooo@P000QT2000M=0@001he00@001le000O
=P007cH001lf0P0083H4000Q=`<0028h0P008cP00`0093T002Di000U>@0@0?l000070?/A003g9@00
lSD00?8e003_@`00k4l00>UI00020>MQ00030>EX003SKP00hG<00080h7L000<0ggX00=ml003NO@00
0`3NOP000`3NO@00gg`00=mj00020>1g00030>5c003SKP00iFP00080if4000<0jET00>a?003_@`00
0P3b=@000`3g9@00na400?l0000?0?l0008002Di00<002@i000S>0008cP00`008SP4000Q=`80020f
0`007cH00`007cD001he000N=@02000N=@8001dd@P000QT4ooooo`;o00000Oooool001?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooood40008I0P007C@4000N=@04000O
=@007cH001lf000O=P80020f10008CL00`008SL0028h000S>002000S>08002@i0P009CT00`009SX0
o`000?l0000>0?l000060?`@003g8`00mb<00?<b003`?`00kD/00P3ZE0000`3XG000iV800>EW0002
0>=/00030>9_003RL@00hG<000<0hG@000<0hG<00>9a003RK`000P3SK0000`3UI`00iV800>QL0002
0>YD00030>e;003`?`00lc800080mb<000<0o1000?l0003o00003P3o00000`009SX002Di000U>@02
000T>@<002<h00<0028h000R=`008CL00`008CL2000P=P<001lf00<001le000N=@007SD00P007SD2
000M=440008I1Oooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00_oooolo00026@<001dd00<001de000N=@007SD00P007SD2000O=P<0020f00H0020g
000Q=`008CL0024g000R=`008SP3000S>08002@i00@002Di000U>P009CX002Hj4@3o00020?`?0003
0?PP003d;`00lC/00080kTH000<0k4h00>YF003XF`000P3WH0000`3VI000iFH00>AX00030>AY0003
0>AX003UIP00iV@00080if0000<0j5/00>YF003/CP000P3^AP000`3a>`00m2l00?PP00020?`?0140
o`0000@002Hj000U>P009CX002Di0P0093T3000S>003000R>0008SL0024g0080024g00@0020g000P
=P0083H0020f0P007cH01@007cD001he000N=@007SD001de00<001dd?`000QT5ooooo`7o00000Ooo
ool001Cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo?@000QT01@0073@001dd000M=000
7C@001de00@001he00<001le000O=P0083H00P0083H00`0083L0024g000Q=`02000R=`03000R>000
8cP002<h00<002@i00H002Di000U>P009SX002Hj000W>P009c/B0?l000030?d<003i7@00mB/00080
lSH000<0l4000>i8003/CP000P3ZE0000`3YF000j5/00>QM00030>QN00030>QM003XF`00jEP00080
jU@000<0k4h00>i8003`@0000P3b=P000`3e:`00nAd00?d<000B0?l00006000W>`009cX002Hj000V
>P009CX002Di0`0093T2000S>003000R>0008SL0028g0080024g00H0020g000P=P0083H0020f000O
=P007cD4000N=@05000M=@007C@001dd000M=00073@0?@000QT5ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool00_ooooll00026@03000L=0007C@001dd008001dd0`007SD2000O=@03000O
=P0083H0020f0080020f0P008CL00`008SL0028h000R>002000S>0<002@i00<002Di000U>P009SX0
0P009SX00`009c/002Pk000X>`0B0?l000070?d9003j6@00mRH00?HV003d<@00lCT00>m100020>i6
00030>e;003/CP00je0000<0je4000<0je000>a>003]B`000P3^AP000`3_@@00lCT00?@a00020?HV
00030?XI003m2@00o`000140o`000P00:3/01P009c/002Hj000V>P009SX002Dj000U>@<002@i0P00
8cP2000R>003000R=`008CL0024g00@0020f00<001lf000O=@007cD00`007SD4000M=003000L=000
0QT0008I03X0008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo?0000QT0
0`0073@001dd000M=002000M=0<001he0P007cD00`007cH0020f000P=P02000P=P80024g00<0028g
000R>0008SP00P008cP3000T>@03000U>@009CX002Hj008002Hj00<002Lk000X>`00:3/04P3o0000
1`3m2@00nQT00?HV003f9P00m3400?4i003_@@000P3^AP000`3]B`00k4h00>]@00030>]A00030>]@
003/CP00kD/00080kTH000<0kd400?4i003d<@000P3f9P000`3j6@00o@T00?l0000A0?l0008002Pk
00H002Lk000V>P009SX002Hj000U>P009CT3000T>@8002<h0P008SP00`008SL0024g000Q=`04000P
=P03000O=P007cD001le00<001he10007C@00`0073@0008I00026@0j00026@Gooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`02ooooocT0008I0`0073@3000M=0@001he00@001le000O=P00
7cH001lf0P0083H3000Q=`04000R=`008SP0028h000R>08002<h00@002@i000U>@009CT002Di0P00
9SX2000W>`8002Pk00<002Tl0?l0003o00004@3o00001P3n1@00na@00?/D003h8000mBX00?<b0080
lSP000<0l3d00>m1003_@`000`3_A0000`3_@`00kd400?0m00020?8h00030?<b003e:P00n2000080
na@000<0oPD00?l0003o00004@3o00000`00:C`002Pk000X>`02000W>`8002Hj0`009CT00`0093T0
02<h000S>003000R>004000R=`008CL0024g000Q=`80020f0`007cH00`007cD001he000N=@02000N
=@<001dd0`0073@i00026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooocP0
008I0`0073@3000M=0@001he00@001le000O=P007cH001lf0P0083H4000Q=`03000R=`008SP002<h
008002<h0P0093T2000U>@8002Hj0`009c/00`00:3/002Tl000Y?002000Z?A@0o`0000<0o0h00?XI
003g8P000P3f:@000`3d;P00lc800?<e00030?8f00030?<e003c<P00m2h00080mRT000<0mb800?XI
003l3P00503o0002000Z?@8002Tl00@002Pk000W>`009c/002Lk0P009SX2000U>@8002@i0`008cP0
0`008SP0028g000Q=`03000Q=`80020f0`007cH00`007cD001he000N=@02000N=@<001dd0`0073@h
00026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooocL0008I00<001`c000L
=0007C@00`007C@4000N=@03000O=@007cH001lf00<0020f10008CL00`008SL0028h000S>002000S
>08002@i00H002Di000U>P009CX002Hj000W>P009c/2000X>`8002Tl00<002Xl000[?@00:cd05@3o
00001`3n1`00o1000?XH003j6000n1h00?LS003f9P000`3f9`000`3f9P00mb<00?PN00020?XH0003
0?`@003n1`00o`0001@0o`000P00:cd00`00:S`002Tl000Y?002000X>`03000W>`009cX002Hj0080
02Dj00<002Di000T>@0093T00`008cP00`008SP0028g000Q=`03000Q=`<0020f0P007cH00`007cD0
01he000N=@02000N=@@001dd0P0073@g00026@Gooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`02oooooc@0008I0`0073<2000L=0<001dd00<001de000N=@007SD00P007SD00`007cD001lf
000P=P02000P=P03000P=`008CL0024g0080028g00<0028h000S>0008cP00`0093T00`009CT002Dj
000V>P02000V>P06000W>`00:3/002Pl000X?000:C`002Xl0`00:cd00`00;3h0o`000?l0000D0?l0
0080oPL000<0o0h00?/B003j5P000`3j5`000`3j5P00na800?`>00020?h701H0o`0000H002`n000[
?@00:cd002/m000Z?000:C`2000X?003000X>`009c/002Lj008002Hj00<002Dj000U>@0093T00P00
93T2000S>003000R>0008SL0028g0080024g00H0020g000P=P0083H0020f000O=P007cD4000N=@04
000M=@007C@001dd000M=08001`d0`0073<d00026@Gooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`02oooooc@0008I0`0073<2000L=0<001dd00<001de000N=@007SD00P007SD00`007cD0
01lf000P=P02000P=P03000P=`008CL0024g0080028g00<0028h000S>0008cP00`0093T00`009CT0
02Dj000V>P02000V>P06000W>`00:3/002Pl000X?000:C`002Xl0`00:cd00`00;3h0o`000?l0000D
0?l00080oPL000<0o0h00?/B003j5P000`3j5`000`3j5P00na800?`>00020?h701H0o`0000H002`n
000[?@00:cd002/m000Z?000:C`2000X?003000X>`009c/002Lj008002Hj00<002Dj000U>@0093T0
0P0093T2000S>003000R>0008SL0028g0080024g00H0020g000P=P0083H0020f000O=P007cD4000N
=@04000M=@007C@001dd000M=08001`d0`0073<d00026@Gooooo0Ol00001ooooo`006oooool2o`00
00?ooooo<`000QT3000L<`8001`d0`007C@010007CD001he000N=@007SD2000O=@03000O=P0083H0
020f0080020f0P008CL00`008SL0028h000R>002000S>0<002@i00<002Di000U>P009SX00P009SX0
0`009c/002Pk000X>`02000Y?003000Z?000:Sd002/m008002`n00<002dn000^?`3o00005`3o0000
0`3o0@00oP@00?h600020?h600030?h4003o0@00o`0001L0o`0000L002ho000]?P00;3h002`n000[
?@00:Sd002Xl008002Tl0P00:3/01P009c/002Hj000V>P009SX002Dj000U>@<002@i0P008cP2000R
>003000R=`008CL0024g00@0020f00<001lf000O=@007cD00`007SD010007CD001dd000M=0007C@2
000L=0<001`c<`000QT4ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_oooolb0002
6@8001`c0`0073@4000M=0<001he00@001le000O=P007cH001lf0P0083H3000Q=`04000R=`008SP0
028h000R>08002<h00@002@i000U>@009CT002Di0P009SX3000W>`07000X>`00:C`002Xl000Z?000
:Sd002/m000/?@02000]?P03000^?P00;cl0o`0003H0o`0000L002lo000^?P00;Ch002dn000/?@00
:cd002Xm008002Xl00<002Tl000X>`009c/00P009c/2000V>P<002Di00<002@i000S>0008cP00`00
8SP010008SL0024g000Q=`008CL2000P=P<001lf00@001le000N=@007SD001he10007C@3000L=080
01`c<P000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool_00026@<001/c
00@001`c000L=00073@001`d0`007C@4000N=@04000O=@007cH001lf000O=P80020f10008CL00`00
8SL0028h000S>002000S>08002@i0P009CT2000V>P04000W>P009c/002Lk000X>`8002Tl0P00:S`0
0`00:cd002`m000]?P02000]?P03000^?`00;cl0031003D0o`0000<00310000_?`00;Sl00`00;Ch0
1000;3d002/m000Z?000:S`2000Y?004000X>`009c/002Lk000W>P8002Hj0P009CT2000T>@<002<h
00<0028h000R=`008CL00`008CL2000P=P<001lf00<001le000N=@007SD00P007SD3000M=0<001`d
00@001`c000K<`006c<001/c;`000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_ooool^00026@<001/c00<001`c000L=00073@010007C@4000N=@03000O=@007cH001lf00<0020f
10008CL00`008SL0028h000S>002000S>08002@i00H002Di000U>P009CX002Hj000W>P009c/2000X
>`8002Tl00H002Xl000[?@00:cd002/m000/?P00;Ch2000^?`03000_?`00<400035003D0o`0000<0
0350000`@000;cl00P00;Sl00`00;Ch002`n000[?@02000[?@03000Z?000:C`002Tl008002Pk00<0
02Lk000W>P009SX00P009CX00`009CT002@i000T>@03000S>003000R>0008SL0024g00<0024g0`00
83H2000O=P03000O=@007SD001he008001he10007C@2000L=004000L<`006c<001/c000K<bh0008I
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo;P000QT3000K<`03000L<`00
73@001`d00@001dd10007SD00`007cD001lf000O=P03000P=P@0024g00<0028g000R>0008cP00P00
8cP2000T>@06000U>@009CX002Dj000V>P009cX002Lk0P00:3/2000Y?006000Z?000:cd002/m000[
?@00;3h002dn0P00;Sl00`00;cl00310000a@00e0?l00003000a@000<40002lo008002ho00<002dn
000/?P00:cd00P00:cd00`00:S`002Tl000Y?002000X>`03000W>`009cX002Hj008002Dj00<002Di
000T>@0093T00`008cP00`008SP0028g000Q=`03000Q=`<0020f0P007cH00`007cD001he000N=@02
000N=@@001dd0P0073@0100073<001/c000K<`006c<^00026@Gooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`02ooooob`0008I0`006c<3000L<`03000L=0007C@001dd008001dd00D001de
000N=@007SD001he000O=@02000O=P<0020f00<0020g000Q=`008CL00P008SL00`008SP002<h000S
>003000T>@03000U>@009CX002Hj008002Hj00L002Lk000X>`00:3/002Pk000Y?000:S`002Xm0080
02/m00<002`n000]?P00;Sl00P00;cl00`00<4000350000b@@02000c@C40o`000P00<d400`00<T40
0350000`@002000_?`03000^?`00;Ch002`n00<002/m00<002Xl000Y?000:3/00P00:3/01P009c/0
02Hj000V>P009SX002Dj000U>@<002@i0P008cP00`008SP0028g000R=`02000Q=`04000P=`0083H0
020f000P=P8001lf00D001le000N=@007SD001he000M=@04000M=004000L=00073<001`c000L<`<0
01/c;0000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolZ00026@@001/c
0`0073<2000L=0<001dd00<001de000N=@007SD00P007SD00`007cD001lf000P=P03000P=P80024g
00<0028g000R>0008SP00P008cP3000T>@03000U>@009CX002Hj008002Hj00<002Lk000X>`00:3/0
0P00:C`00`00:S`002Xm000[?@02000/?@03000]?P00;Sh002ho008002lo00<00310000a@@00<d40
0P00=4800`00=D80o`000?l0000]0?l00006000e@P00=48003A2000c@@00<D4003100P00;cl00`00
;Sl002hn000]?P02000/?@03000[?@00:Sd002Xl008002Tl0P00:3/01P009c/002Hj000V>P009SX0
02Dj000U>@<002@i0P008cP2000R>003000R=`008CL0024g00@0020f00<001lf000O=@007SD00`00
7SD010007CD001dd000M=0007C@2000L=0<001`c10006c<Z00026@Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooobT0008I10006c<2000L<`<001`d10007C@3000N=@8001le0P00
7cH2000P=P<0024g00@0028g000R>0008SP0028h0P008cP3000T>@03000U>@009SX002Hj008002Lj
00<002Lk000X>`00:C`00P00:C`00`00:S`002/m000/?@02000/?P03000]?P00;Sl002lo00800310
00<00350000b@@00<d800P00=D800`00=T<0o`000?l0000]0?l00006000f@`00=D8003E2000c@P00
<T4003500P00<4000`00;cl002ho000]?P02000/?P03000/?@00:cd002Xl00<002Tl00@002Pk000W
>`009cX002Lj0P009SX010009CT002@i000T>@0093T2000S>0<0028h00@0028g000Q=`008CL0024g
0P0083H2000O=P8001le0`007SD4000M=0<001`d0P0073<4000K<bT0008I1Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo9`000QT00`006S8001/c000K<`03000K<`04000L<`00
73@001`d000L=0<001dd10007SD010007cD001lf000O=P007cH2000P=P@0024g00<0028g000R>000
8cP00P008cP2000T>@8002Di00<002Dj000V>P009cX00P009c/00`00:3/002Tl000Y?002000Z?080
02/m00H002`n000]?P00;Ch002ho000_?`00<402000a@003000b@@00<d4003A2008003E300<003M3
000hA03o0000;03o00001`00>4@003M3000e@`00=D<003A2000c@@00<T400P00<D000`00<40002lo
000^?`02000]?P03000/?P00:cd002/m008002Xl0P00:C`01P00:3/002Lk000W>`009cX002Hj000U
>P8002Di0P0093T3000S>003000R>0008SL0024g00<0024g0P0083H3000O=P03000O=@007SD001he
008001he0`007C@3000L=003000L<`006c<001/c00<001/c00<001Xb00026@000QT09@000QT5oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolW00026@03000J<P006c<001/c00<0
01/c00@001`c000L=00073@001`d0`007C@4000N=@04000O=@007cH001lf000O=P80020f10008CL0
0`008SL0028h000S>002000S>08002@i0P009CT00`009CX002Hj000W>P02000W>`03000X>`00:C`0
02Tl008002Xl0P00:cd01P00;3h002dn000]?P00;Sl002lo000`@080035000<00391000c@@00=480
0P00=D<00`00=d<003Q40?l0000/0?l00007000hA000=d<003E3000e@`00=48003=1000b@@02000a
@003000`@000;cl002ho008002dn00<002`n000[?@00:cd00P00:S`2000Y?006000X>`009c/002Lk
000W>P009SX002Dj0P009CT2000T>@<002<h00<0028h000R=`008CL00`008CL2000P=P<001lf00<0
01le000N=@007SD00P007SD3000M=0<001`d00<001`c000K<`006c<00`006c<00`006S80008I0002
6@0U00026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobD0008I0P006S85
000K<`03000L<`0073@001`d00@001dd10007SD010007cD001lf000O=P007cH2000P=P06000P=`00
8CL0024g000Q=`008SL0028h0`008cP2000T>@03000U>@009CX002Dj008002Hj00H002Lk000X>`00
:3/002Pk000Y?000:S`2000Z?@03000[?@00;3h002dn008002ho00<002lo000`@000<D000P00<T40
0`00<d4003A2000e@P02000f@`03000hA000>D@0o`0002`0o`0000L003U5000hA000=T<003I3000e
@P00=48003=10080039100<00350000`@000;cl00P00;Sl00`00;Ch002`n000[?@02000Z?@03000Z
?000:C`002Pk008002Pk00<002Lk000V>P009SX00P009CX00`009CT002@i000T>@03000S>003000R
>0008SL0024g0080024g00<0020g000P=P0083H00`007cH00`007cD001he000N=@02000N=@@001dd
0P0073@00`0073<001/c000K<`03000K<`8001Xb9@000QT5ooooo`7o00000Oooool001_ooooo0_l0
0003ooooob<0008I0P006S85000K<`<001`c00<001`d000M=0007C@00P007C@00`007CD001he000N
=@02000N=@03000O=@007cH0020f0080020f00<0020g000Q=`008CL00P008SL00`008SP002<h000S
>003000T>@03000U>@009CX002Hj008002Hj00L002Lk000X>`00:3/002Pk000Y?000:S`002Xm0080
02/m00<002`m000]?P00;Sh00P00;Sl00`00;cl00310000a@002000b@@03000d@P00=D8003I30080
03M400<003U4000jA@00?4H0:`3o00000`00?4H003Y5000iA002000gA003000f@`00=D8003A20080
039100<00351000`@000;cl00P00;Sl00`00;Sh002dn000/?@02000[?@03000Z?@00:S`002Tl00<0
02Pk00H002Lk000V>P009SX002Hj000U>P009CT3000T>@8002<h00<0028h000R=`008SL00P008CL0
1P0083L0020f000P=P0083H001lf000O=@@001he00<001de000M=0007C@00P007C@0100073@001`c
000L<`0073<5000K<`8001Xb8`000QT4ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0
0_oooolR00026@8001Xb00<001/b000K<`006c<00P006c<3000L<`8001`d0`007C@00`007CD001he
000N=@02000N=@03000O=@007cH0020f00<0020f0P008CL010008SL0028h000R>0008SP2000S>0<0
02@i00L002Di000V>P009SX002Hj000W>P009c/002Pk00<002Tl00L002Xl000[?@00;3d002`m000/
?P00;Ch002ho008002lo00<00310000a@000<T400P00<d400`00=48003I3000g@`02000hA003000j
A@00>dH003e602/0o`0000<003e6000kAP00>TD00P00>4@00`00=d<003I3000d@P02000c@@03000b
@@00<D000310008002lo00<002ho000]?P00;3h00P00;3d00`00:cd002Xl000Y?002000Y?003000X
>`009c/002Lj00<002Hj00@002Di000T>@0093T002@i0P008cP3000R>003000R=`008CL0024g00@0
020f00<001lf000O=@007SD00`007SD010007CD001dd000M=0007C@2000L=0<001`c10006c<00`00
6c8001Xb000J<P0R00026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooob00
008I10006S84000K<`8001`c0`0073@4000M=0<001he0P007cD2000O=P<0020f0`008CL00`008SL0
028h000R>002000S>0<002@i00<002Di000U>P009SX00P009cX00`009c/002Pk000X?002000Y?003
000Z?000:cd002/m008002`n00<002dn000^?`00;cl00P00<4000`00<D000391000c@@02000d@P03
000e@`00=T<003Q4008003U500<003]5000lAP00?TL00P00@4PW0?l00080041800<003i7000lAP00
>dD00P00>DD00`00>4@003I3000e@`02000d@P03000c@@00<T4003500080031000<002lo000^?`00
;Ch00P00;3h2000[?@06000Z?000:C`002Tl000X?000:3/002Lk0P009cX00`009SX002Dj000U>@03
000T>@8002<h0P008SP010008SL0024g000Q=`008CL3000P=P8001lf0P007cD3000N=@@001dd0`00
73@2000L<`@001/c10006S8P00026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02
ooooob00008I10006S84000K<`8001`c0`0073@4000M=0<001he0P007cD2000O=P<0020f0`008CL0
0`008SL0028h000R>002000S>0<002@i00<002Di000U>P009SX00P009cX00`009c/002Pk000X?002
000Y?003000Z?000:cd002/m008002`n00<002dn000^?`00;cl00P00<4000`00<D000391000c@@02
000d@P03000e@`00=T<003Q4008003U500<003]5000lAP00?TL00P00@4PW0?l00080041800<003i7
000lAP00>dD00P00>DD00`00>4@003I3000e@`02000d@P03000c@@00<T4003500080031000<002lo
000^?`00;Ch00P00;3h2000[?@06000Z?000:C`002Tl000X?000:3/002Lk0P009cX00`009SX002Dj
000U>@03000T>@8002<h0P008SP010008SL0024g000Q=`008CL3000P=P8001lf0P007cD3000N=@@0
01dd0`0073@2000L<`@001/c10006S8P00026@Gooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`02oooooah0008I1@006S85000K<`04000L<`0073@001`d000L=0<001dd10007SD010007cD0
01lf000O=P007cH2000P=P@0024g00<0028g000R>0008cP00P008cP2000T>@8002Di00<002Dj000V
>P009SX00P009c/2000X>`06000Y?000:S`002Xl000Z?@00:cd002`n0P00;Ch00`00;Sh002lo000_
?`02000`@003000a@@00<d4003A2008003E200<003I3000gA000>D@00P00>TD00`00?4H003e7000o
A`020011B2L0o`000P00@DP00`00?dL003e7000lAP02000jA@03000iA000=d@003I3008003E200<0
03A2000c@@00<D400P00<402000_?`06000^?P00;Ch002dn000/?P00:cd002Xm0P00:S`00`00:C`0
02Pk000X>`02000W>`8002Hj00<002Dj000U>@009CT00P0093T3000S>003000R>0008SL0024g00<0
024g0P0083H3000O=P03000O=@007SD001he008001he0`007C@3000L=003000L<`006c<001/c00<0
01/c1@006S8N00026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooad0008I
1@006S85000K<`03000L<`0073@001`d00@001dd10007SD010007cD001lf000O=P007cH2000P=P06
000P=`008CL0024g000Q=`008SL0028h0`008cP2000T>@03000U>@009CX002Dj008002Hj0`009c/0
0`00:3/002Tl000Y?002000Z?@03000[?@00;3d002dn008002dn00<002ho000_?`00<4000P00<D00
0`00<T4003=2000d@P02000f@`03000g@`00>4@003Y5008003]600<003e6000oA`00@4P00P00@TT0
0`00A4X0o`000?l0000S0?l000060014BP00@TT004990010B000?dL003e60P00>dH00`00>TD003Q4
000g@`02000f@`03000d@P00<d8003910080035000<00310000_?`00;Sl00`00;Ch01`00;3d002/m
000Z?@00:Sd002Xl000Y?000:3/00`009c/2000V>P8002Dj00<002Di000T>@0093T00`008cP00`00
8SP0028g000Q=`02000Q=`03000P=`0083H0020f00<001lf00<001le000N=@007SD00P007SD4000M
=08001`d00<001`c000K<`006c<00`006c<5000J<Qd0008I1Oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo6P000QT00`006C8001Xb000J<P03000J<PD001/c0`0073<00`0073@0
01dd000M=002000M=003000M=@007SD001he008001he00<001le000O=P0083H00`0083H3000Q=`03
000R=`008SP0028h00<002<h0P0093T01P009CT002Hj000V>P009SX002Lj000W>`8002Pk0P00:C`0
1P00:S`002/m000[?@00;3d002`n000]?P8002ho00<002lo000`@000<D000P00<T400`00<d4003A2
000e@`02000g@`03000hA000>DD003]5008003a600<003i70010B000@TT00P00A4X00`00ATX004Q;
0?l0000R0?l000070018C000ATX004A:0014BP00@TT00418000nA`02000lAP03000kA@00>DD003Q4
008003M300<003E3000d@P00<d400P00<T400`00<D000310000_?`02000^?`03000]?P00;3h002`m
008002/m00<002Xl000Y?000:C`00P00:3/00`009c/002Lj000V>P02000V>P03000U>@0093T002@i
00<002<h0P008SP010008SL0024g000Q=`008CL4000P=P03000O=P007cD001he00<001he00<001de
000M=0007C@00P007C@0100073@001`c000L<`0073<5000K<`D001Xb00<001Tb00026@000QT06000
0QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolI00026@03000I<P006S80
01Xb00<001Xb00<001/b000K<`006c<00P006c<3000L<`8001`d10007C@4000N=@03000O=@007cH0
01lf00<0020f10008CL010008SL0028h000S>0008cP3000T>@06000U>@009CX002Hj000V>P009cX0
02Lk0`00:3/00`00:C`002Xl000[?@02000[?@03000/?P00;Ch002ho008002lo00<00310000a@000
<T400P00<d400`00=48003E2000f@`02000gA003000iA000>TD003a6008003e700<003m70011B000
@dT00P00ADX00`00Ad/004U<0?l0000R0?l000070019C000Ad/004E:0015BP00@dT00458000oA`02
000mA`03000lAP00>TD003U4008003M400<003I3000e@P00=4800P00<d400`00<T400350000`@002
000_?`03000^?`00;Ch002`n00<002/m00<002Xl000Y?000:3/00P00:3/01P009c/002Lj000V>P00
9SX002Dj000U>@<002@i0P008cP00`008SP0028g000Q=`03000Q=`<0020f0P007cH00`007cD001he
000N=@02000N=@@001dd0P0073@3000L<`@001/c00<001/b000J<P006S800`006S800`006C80008I
00026@0G00026@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaT0008I00<0
01Tb000J<P006S800`006S800`006c8001/c000K<`02000K<`<001`c0P0073@4000M=0@001he00<0
01le000O=P007cH00`0083H4000Q=`04000R=`008SP002<h000S>0<002@i00H002Di000U>P009SX0
02Hj000W>P009c/3000X>`03000Y?000:S`002/m008002/m00<002`n000]?P00;Sl00P00;cl00`00
<4000350000b@@02000c@@03000d@P00=D8003I3008003M400<003U4000jA@00?4H00P00?DL00`00
?dL004580013B@020015BP030017B`00BD`0o`000280o`0000L004U<0017B`00ADX004E:0013B@00
@DP003m7008003e700<003a6000jA@00>D@00P00=d@00`00=T<003E2000d@P02000c@@03000b@@00
<D000310008002lo00<002ho000]?P00;3h00`00:cd00`00:S`002Tl000X>`02000X>`06000W>`00
9cX002Hj000V>P009CX002Di0`0093T2000S>003000R>0008SL0024g00<0024g0`0083H2000O=P03
000O=@007SD001he008001he10007C@2000L=0<001`c10006c<00`006c8001Xb000J<P03000J<P03
000I<P000QT0008I01L0008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
60000QT2000I<PD001Xb10006c<2000L<`<001`d10007C@3000N=@8001le0P007cH3000P=P<0024g
0P008SL00`008SP002<h000S>003000T>@03000U>@009CX002Hj008002Hj00<002Lk000X>`00:3/0
0P00:C`00`00:S`002Xm000[?@02000/?@8002dn00H002ho000_?`00;cl00310000a@000<T42000c
@P03000e@P00=T<003M3008003Q400<003Y5000kAP00?DH00P00?dL00`00@4P004990014BP020016
B`030019C000Bdd004i>0240o`0000<004i>001;C@00BD`00P00AT/00`00A4X004990010B002000o
A`03000mAP00>dH003Y5008003Q400<003M3000f@`00=D800P00<d800`00<T400350000`@002000_
?`03000^?`00;Sh002dn008002`m00<002/m000Z?@00:S`00P00:C`2000X>`06000W>`009SX002Hj
000V>P009CX002Di0`0093T2000S>003000R>0008SL0028g00<0024g0`0083H2000O=P8001le0`00
7SD4000M=0<001`d0P0073<4000K<`H001Xb00<001Tb00026@000QT05P000QT5ooooo`7o00000Ooo
ool001_ooooo0_l00003oooooaD0008I00@001Ta000I<P006C8001Tb1@006S85000K<`04000L<`00
73@001`d000L=0<001dd10007SD010007cD001lf000O=P007cH2000P=P80020g0P008CL00`008SL0
028h000R>002000S>08002@i0`009CT2000V>P<002Lk00L002Pk000Y?000:C`002Tl000Z?000:cd0
02`m008002`n00<002dn000^?`00;cl00P00<4000`00<D000391000c@@02000d@P03000e@`00=d<0
03Q4008003U500<003]5000lAP00?TL00P00@4P00`00@TT004=90016BP020018B`03001:C000CDh0
04m>0240o`0000<004m>001=CP00BTd00P00B4/00`00ATX004=90012B@020010B003000nA`00?4H0
03]5008003U500<003Q4000g@`00=D<00P00=4800`00<d400391000a@002000`@003000_?`00;Sl0
02dn008002`n00<002`m000[?@00:S`00`00:C`01000:3/002Lk000W>`009c/2000V>P<002Di0P00
93T2000S>080028h00<0028g000Q=`008CL00P0083L2000P=P<001lf00<001le000N=@007SD00P00
7SD3000M=0<001`d00<001`c000K<`006c<00`006c<5000J<P<001Tb00<001Ta00026@000QT04`00
0QT4ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_oooolD00026@04000I<@006C80
01Tb000I<PD001Xb1@006c<00`0073<001`d000L=004000M=003000M=@007SD001he008001he00<0
01le000O=P007cH00`0083H3000Q=`04000R=`008SP0028h000R>08002<h0P0093T2000U>@03000U
>P009SX002Lj008002Lk00<002Pk000Y?000:C`00P00:S`2000[?@06000/?P00;Ch002dn000^?`00
;cl003100P00<D000`00<T4003=1000d@P02000e@P03000f@`00=d@003U4008003Y500<003a6000m
A`00?dL00P00@DP00`00@dT004E:0017B`020019C003001<C@00CTh0051>0080055=7@3o0002001A
C@03001@CP00CTh004a=008004U<00<004M;0015BP00@dT00P00@DP00`00?dL003e7000lAP02000j
A@03000iA000=d@003I3008003E200<003A2000c@@00<T400P00<D000`00<40002lo000^?`02000]
?P03000/?P00:cd002/m008002Xl0P00:C`01P00:3/002Lk000W>`009cX002Hj000U>P8002Di0P00
93T2000S>0<0028h00@0028g000Q=`008CL0024g0`0083H2000O=P03000O=@007SD001he008001he
00<001de000M=0007C@00P007C@2000L=003000L<`006c<001/c00<001/c1@006S83000I<P03000I
<@000QT0008I0180008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo4@00
0QT4000I<@03000I<P006S8001Xb00<001Xb1@006c<3000L<`8001`d10007C@4000N=@04000O=@00
7cH001lf000O=P80020f10008CL00`008SL0028h000S>002000S>08002@i00<002Di000U>P009CX0
0P009SX01P009c/002Pk000X>`00:3/002Tl000Z?08002Xm00<002/m000/?P00;Ch00P00;Sh00`00
;Sl002lo000`@002000a@003000b@@00<d8003E2008003I300<003M3000hA000>TD00P00>dH00`00
?DH003i70010B0020012B@030014BP00AT/004Q<008004]=00<004e>001?CP00D4d00P00DTdM0?l0
0080059=00<0051=001?CP00CDh00P00Bdd00`00B4`004I;0014BP020012B@030010B000?TL003e6
008003]600<003Y5000hA000=d<00P00=T<00`00=D8003=2000b@@02000a@003000`@000;cl002ho
008002hn00<002dn000/?P00:cd00P00:Sd00`00:S`002Tl000X>`02000X>`03000W>`009SX002Hj
008002Dj00<002Di000T>@0093T00`008cP00`008SP0028g000Q=`03000Q=`80020f0`007cH00`00
7cD001he000N=@02000N=@@001dd0P0073@3000L<`D001/c1@006S800`006C8001Ta000I<@02000I
<A40008I1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo4@000QT4000I<@03
000I<P006S8001Xb00<001Xb1@006c<3000L<`8001`d10007C@4000N=@04000O=@007cH001lf000O
=P80020f10008CL00`008SL0028h000S>002000S>08002@i00<002Di000U>P009CX00P009SX01P00
9c/002Pk000X>`00:3/002Tl000Z?08002Xm00<002/m000/?P00;Ch00P00;Sh00`00;Sl002lo000`
@002000a@003000b@@00<d8003E2008003I300<003M3000hA000>TD00P00>dH00`00?DH003i70010
B0020012B@030014BP00AT/004Q<008004]=00<004e>001?CP00D4d00P00DTdM0?l00080059=00<0
051=001?CP00CDh00P00Bdd00`00B4`004I;0014BP020012B@030010B000?TL003e6008003]600<0
03Y5000hA000=d<00P00=T<00`00=D8003=2000b@@02000a@003000`@000;cl002ho008002hn00<0
02dn000/?P00:cd00P00:Sd00`00:S`002Tl000X>`02000X>`03000W>`009SX002Hj008002Dj00<0
02Di000T>@0093T00`008cP00`008SP0028g000Q=`03000Q=`80020f0`007cH00`007cD001he000N
=@02000N=@@001dd0P0073@3000L<`D001/c1@006S800`006C8001Ta000I<@02000I<A40008I1Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo40000QT4000I<@03000I<P006S80
01Xb00@001Xb10006c<3000L<`8001`d10007C@4000N=@03000O=@007cH001lf00<0020f10008CL0
0`008SL0028h000S>002000S>08002@i00<002Di000U>P009SX00P009SX2000W>`8002Pk0P00:C`0
1P00:Sd002/m000[?@00;3d002`n000]?P8002ho00<002lo000`@000<D000P00<T400`00<d4003A2
000e@`02000g@`03000hA000>DD003]5008003a600<003i70010B000@DT00P00@dT00`00ADX004Q;
001:C002001<C@03001?CP00D4h0055=008005==00<005A<0?l0003o00006@3o00001P00E4`005==
001CC@00DDd0051>001?CP8004a=00<004Y<0018B`00ADX00P00@dT00`00@DT00418000nA`02000l
AP03000kA@00>DD003Q4008003M300<003E3000d@P00<d400P00<T400`00<D000310000_?`02000^
?`03000]?P00;3h002`m008002/m00<002Xm000Y?000:C`00P00:3/2000W>`<002Hj00@002Dj000U
>@0093T002@i0`008cP00`008SP0028g000Q=`03000Q=`<0020f0P007cH00`007cD001he000N=@02
000N=@@001dd0P0073@3000L<`@001/c1P006S800`006C8001Ta000I<@02000I<A00008I1Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo3`000QT4000I<@8001Tb1@006S85000K
<`04000L<`0073@001`d000L=0@001dd0`007SD2000O=@8001lf0`0083H00`0083L0024g000Q=`02
000R=`03000R>0008cP002<h008002<h0P0093T01`009CT002Hj000V>P009SX002Lj000W>`00:3/0
0`00:C`01`00:S`002/m000[?@00:cd002`n000]?P00;Sl00P00;cl00`00<4000350000b@@02000c
@@03000d@P00=D8003I3008003M400<003U4000jA@00?4H00P00?DL00`00?dL004580013B@020015
BP030017B`00BD`004]=008004i>00<004m>001AC@00DTd00P00Dd`00`00ED/0o`000?l0000I0?l0
0006001EB`00Dd`005=<001BC@00DDd004m>0P00CTh00`00Bdd004U<0017B`020015BP030013B@00
@DP003m7008003e700<003a6000jA@00>D@00P00=d@00`00=T<003E2000d@P02000c@@03000b@@00
<D000310008002lo00<002ho000]?P00;3h00`00:cd01`00:S`002Tl000Y?000:C`002Pk000W>`00
9cX00`009SX00`009CT002@i000T>@04000S>003000R>0008SL0028g0080024g00@0020g000P=P00
83H0020f0P007cH2000O=@<001he10007C@3000L=003000L<`006c<001/c00<001/c1@006S82000I
<P@001Ta3`000QT5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool<00026@80
01Pa0`006C43000I<PD001Xb1@006c<0100073<001`d000L=00073@3000M=08001de0`007SD2000O
=@03000O=P0083H0020f0080020f0P008CL010008SL0028h000R>0008SP2000S>0<002@i00<002Di
000U>P009SX00P009cX00`009c/002Pk000X>`02000Y?003000Z?000:Sd002/m008002`n00<002dn
000^?P00;Sl00P00;cl00`00<4000350000b@@02000c@P03000e@P00=T<003M3008003Q400<003Y5
000kAP00?DH00P00?TL00`00@4P004990014BP020016B`030018C000Bdd004e>008004m>00<0051>
001AC@00Dd`00P00E4`00`00ET/0o`000?l0000I0?l00006001FB`00E4`005A<001CC000DDd0051>
0P00Cdh00`00CDh004]=0018C0020016B`030014BP00@TT00418008003i700<003e6000kAP00>TD0
0P00>4@00`00=d<003I3000e@P02000c@P03000b@@00<D000310008002lo00<002ho000^?P00;Ch0
0P00;3h00`00:cd002Xm000Z?002000Y?08002Pk00H002Lk000W>P009cX002Hj000U>P009CT3000T
>@8002<h0`008SP00`008SL0024g000Q=`04000P=P03000O=P007cD001le00<001he0P007CD3000M
=0<001`d00<001`c000K<`006c<00`006c<5000J<P<001Tb0`006C42000H<@`0008I1Oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00;ooooo2`000QT00`00634001Ta000I<@02000I<@<0
01Tb1@006S85000K<`8001`c0`0073@3000M=0@001he00@001le000O=P007cH001lf0P0083H4000Q
=`03000R=`008SP0028h008002<h0`0093T010009CT002Dj000V>P009SX2000W>`8002Pk00H002Tl
000Z?000:S`002Xm000[?@00;3d2000/?P03000]?P00;Sl002lo0080031000<00350000b@@00<d40
0P00=4800`00=D<003M3000hA002000iA@03000kA@00?4H003i7008003m800<004580013B@00ADX0
0P00Ad/00`00BT`004a=001>CP02001@CP03001AC@00DTd005A<008005E;00<005M:001IB@3o0000
603o00001`00FDT005M:001EB`00ED/005A<001BC@00DDd00P00D4h00`00CTh004a=001:C0020017
B`030015BP00@dT00458008003m800<003i7000lAP00>dD00P00>DD00`00>4@003M3000e@`02000d
@P03000c@@00<T4003500080031000<002lo000^?`00;Ch00P00;3h00`00;3d002/m000Z?@02000Z
?003000Y?000:3/002Pk008002Lk0P009SX00`009CX002Di000T>@02000T>@8002<h0P008SP00`00
8SL0024g000Q=`02000Q=`80020f0`007cH00`007cD001he000N=@02000N=@<001dd0`0073@2000L
<`D001/c1@006S83000I<P@001Ta00<001Pa00026@000QT02@000QT5ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_ooool;00026@03000H<@006C4001Ta008001Ta0`006C85000J<PD0
01/c0P0073<3000L=0<001dd10007SD010007cD001lf000O=P007cH2000P=P@0024g00<0028g000R
>0008SP00P008cP3000T>@04000U>@009CX002Hj000V>P8002Lk0P00:3/01P00:C`002Xl000Z?000
:Sd002/m000/?@8002`n00<002dn000^?`00;cl00P00<4000`00<D000391000c@@02000d@P03000e
@`00=d<003Q4008003U500<003]5000lAP00?TL00P00?dP00`00@DP004=90015BP020017B`03001:
C000C4d004i>0080051>00<0055=001BC@00E4`00P00ED/00`00EdX005U90?l0000H0?l00007001I
B@00EdX005E;001EB`00E4`0059=001AC@02001@CP03001>CP00C4d004Y<008004M;00<004E:0013
B@00@DP00P00?dP00`00?TL003a6000kA@02000iA@03000hA000=d<003E3008003A200<003=1000b
@@00<D000P00<4000`00;cl002ho000]?P02000/?P03000/?@00:cd002Xm008002Xl00<002Tl000X
>`00:3/00P009c/2000V>P03000U>P009CT002@i008002@i0P008cP2000R>003000R=`008CL0024g
0080024g0P0083H3000O=P03000O=@007SD001he008001he0`007C@3000L=08001`c1@006c<5000J
<P<001Tb10006C400`006340008I00026@0900026@Gooooo0Ol00001ooooo`002?ooool2o`0000Co
oooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo00;ooooo2@000QT3000H
<@@001Ta00<001Tb000J<P006S800`006S82000K<P<001/c0`0073<2000L=0@001dd10007SD01000
7cD001lf000O=P007cH2000P=P06000P=`008CL0024g000Q=`008SL0028h0`008cP2000T>@<002Di
0P009SX010009cX002Lk000W>`00:3/2000Y?08002Xl0P00:cd01P00;3h002dn000]?P00;Sl002lo
000`@080035000<00391000c@@00=4800P00=D800`00=T<003M4000iA002000jA@03000lAP00?DH0
03m70080045800<004990014BP00AT/00P00BD`00`00Bdd004i>001?CP02001@C@03001BC@00Dd`0
05E;008005I;00<005Q9001JB03o0000603o00001`00FTP005Q9001FB`00ET/005E;001CC000DTd0
0P00D4d00`00Cdh004i>001;C@020019C0030016B`00A4X004990080045800<003m7000mAP00?4H0
0P00>TD00`00>D@003M4000f@`02000e@P03000d@P00<d4003910080035000<00310000_?`00;Sl0
0P00;Ch00`00;3h002/m000[?@02000Z?08002Tl00@002Pk000W>`009c/002Lk0P009SX3000U>@80
02@i0`008cP00`008SP0028g000Q=`02000Q=`03000P=`0083H0020f00<001lf00<001le000N=@00
7SD00P007SD4000M=08001`d0`0073<3000K<`8001/b1@006S800`006C8001Ta000I<@02000I<@<0
01Pa2@000QT5ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00;ooooo1`000QT4000H<@@001Ta0P006C85000J
<PD001/c0P0073<2000L=0@001dd10007SD00`007cD001lf000O=P04000P=P<0024g00<0028g000R
>0008SP00`008cP2000T>@8002Di00@002Dj000V>P009cX002Lk0`00:3/01`00:C`002Xl000Z?@00
:Sd002/m000/?P00;Ch00P00;Sh00`00;Sl002lo000`@002000a@003000b@@00<d8003A2008003I3
00<003M3000hA000>TD00P00>dD00`00?DH003i70010B0020012B@030014BP00ATX004Q;008004Y<
00<004e>001?CP00D4h00P00DDd00`00Ddd005A<001FB`02001GBP03001IB@00FdL005e601L0o`00
00<005e6001KA`00FDT00P00EdX00`00ET/005A<001CC@02001AC@03001@CP00Cdh004e>008004Y<
00<004Q;0016BP00A4X00P00@TT00`00@4P003i7000mAP02000kA@03000jA@00>4@003M3008003I3
00<003A2000c@P00<T400P00<D000`00<40002lo000^?`02000^?P03000]?P00;3h002/m008002Xm
00<002Xl000Y?000:3/00P00:3/010009c/002Lj000V>P009CX2000U>@8002@i0`008cP2000R>004
000R=`008CL0024g000Q=`@0020f0P007cH00`007cD001he000N=@02000N=@@001dd0P0073@2000L
<`D001/c1@006S82000I<P@001Ta1000634700026@Gooooo0Ol00001ooooo`001oooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`H0008I10006344000I
<@8001Tb1@006S85000K<`04000L<`0073@001`d000L=0@001dd00<001de000N=@007SD00P007SD0
0`007cD001lf000O=P03000P=P@0024g00<0028g000R>0008cP00P008cP2000T>@03000U>@009CX0
02Dj008002Hj00L002Lk000X>`00:3/002Pk000Y?000:S`002Xm008002/m00<002`m000/?P00;Ch0
0P00;Sl00`00;cl00310000a@002000b@@03000c@@00=48003E3008003I300<003Q4000iA000>TD0
0P00?4H00`00?TL003m70011B0020013B@030015BP00Ad/004U<008004a=00<004i>001?CP00DDd0
0P00DTd00`00Dd`005E;001GBP02001HB@03001JB000G4H005i501L0o`0000<005i5001LAP00FTP0
0P00F4T00`00EdX005E;001CC002001BC@03001AC@00Cdh004i>008004a=00<004U<0017B`00ADX0
0P00@dT00`00@DP003m7000nA`02000lAP03000jA@00>D@003Q4008003I300<003E3000d@P00<d40
0P00<T400`00<D000310000_?`02000^?`03000]?P00;3h002`m008002/m00<002Xm000Z?000:C`0
0`00:3/00`009c/002Hj000V>P02000U>P03000U>@0093T002@i00<002<h00<0028h000R=`008CL0
0`008CL3000P=P8001lf00<001le000N=@007SD00P007SD00`007CD001dd000M=002000M=0<001`d
00<001`c000K<`006c<00`006c<5000J<P8001Tb10006C44000H<@H0008I1?ooool2o`00007ooooo
0007ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`@0008I00<001P`000H<@0063400P006343000I<@<001Tb1@006S85000K<`8001`c
0`0073@4000M=0<001he0P007cD2000O=P<0020f0`008CL2000R=`03000R>0008cP002<h00<002@i
0P009CT3000V>P8002Lk00D002Pk000Y?000:C`002Tl000Z?003000[?@03000/?P00;Ch002ho0080
02lo00<00310000a@000<T400P00<d400`00=48003E2000f@`02000gA003000iA000>TD003]60080
03e600<003m70010B000@TT00P00A4X00`00AT/004Q<001;C@02001=CP03001?CP00D4h0055=0080
05=<00<005A<001FB`00EdX00P00FDT00`00FdL005e5001P@`02001R@A<0o`000P00HT400`00H4<0
05e5001KA`02001IB@03001GBP00ET/005A<008005=<00<0055=001@CP00Cdh00P00CDh00`00Bdd0
04Q<0016B`020014BP030012B@00@4P003m7008003e600<003]6000jA@00>D@00P00=d@00`00=T<0
03E2000d@P02000c@@03000b@@00<D000310008002lo00<002ho000]?P00;3h00`00:cd01@00:S`0
02Tl000Y?000:C`002Pk008002Lk0`009SX00`009CX002Di000T>@02000T>@8002<h00<0028h000R
=`008SL00`008CL3000P=P8001lf0P007cD3000N=@@001dd0`0073@2000L<`D001/c1@006S83000I
<P<001Ta100063400`006300008I00026@0200026@Gooooo0Ol00001ooooo`001oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02
ooooo`@0008I00<001P`000H<@0063400P006343000I<@<001Tb1@006S85000K<`8001`c0`0073@4
000M=0<001he0P007cD2000O=P<0020f0`008CL2000R=`03000R>0008cP002<h00<002@i0P009CT3
000V>P8002Lk00D002Pk000Y?000:C`002Tl000Z?003000[?@03000/?P00;Ch002ho008002lo00<0
0310000a@000<T400P00<d400`00=48003E2000f@`02000gA003000iA000>TD003]6008003e600<0
03m70010B000@TT00P00A4X00`00AT/004Q<001;C@02001=CP03001?CP00D4h0055=008005=<00<0
05A<001FB`00EdX00P00FDT00`00FdL005e5001P@`02001R@A<0o`000P00HT400`00H4<005e5001K
A`02001IB@03001GBP00ET/005A<008005=<00<0055=001@CP00Cdh00P00CDh00`00Bdd004Q<0016
B`020014BP030012B@00@4P003m7008003e600<003]6000jA@00>D@00P00=d@00`00=T<003E2000d
@P02000c@@03000b@@00<D000310008002lo00<002ho000]?P00;3h00`00:cd01@00:S`002Tl000Y
?000:C`002Pk008002Lk0`009SX00`009CX002Di000T>@02000T>@8002<h00<0028h000R=`008SL0
0`008CL3000P=P8001lf0P007cD3000N=@@001dd0`0073@2000L<`D001/c1@006S83000I<P<001Ta
100063400`006300008I00026@0200026@Gooooo0Ol00001ooooo`001oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`80
008I0P006305000H<@<001Ta0P006C85000J<P03000K<P006c<001/c008001/c0P0073<3000L=0<0
01dd10007SD010007cD001lf000O=P007cH2000P=P80020g0P008CL00`008SL0028h000R>003000S
>0<002@i00H002Di000U>P009SX002Hj000W>P009c/2000X>`8002Tl00<002Xl000Z?@00:cd00P00
;3h00`00;Ch002hn000^?`02000_?`03000`@000<D000391008003=200<003A2000f@`00=d<00P00
>4@00`00>DD003]5000lAP02000nA`030010B000@DP004=9008004E:00<004M;001:C000C4d00P00
CTh00`00D4h0055=001BC@02001DC003001EB`00EdX005Q9008005Y800<005a6001OA000HD800P00
I40C0?l0008006A000<00652001OA000G4H00P00FTP00`00F4T005M:001EB`02001DC003001BC@00
DDd0051>008004i>00<004a=001:C000Ad/00P00ADX00`00@dT004580010B002000nA`03000lAP00
>dD003U5008003Q400<003M3000f@`00=4800P00<d800`00<T400350000`@002000_?`03000^?`00
;Sh002dn008002`n00<002/m000Z?@00:S`00P00:C`2000X>`06000W>`009cX002Hj000V>P009CX0
02Di0`0093T3000S>080028h00<0028g000Q=`008CL00P0083L2000P=P<001lf00<001le000N=@00
7SD00P007SD3000M=0<001`d0P0073<4000K<`03000K<P006S8001Xb00<001Xb0P006C83000I<@D0
01Pa0P00630200026@Gooooo0Ol00001ooooo`002?ooool2o`0000Wooooo0ol00005ooooo`03o`00
0?oooooooooo00;ooooo00<001L`000H<000634010006344000I<@<001Tb1@006S85000K<`03000L
<`0073@001`d00@001dd00<001de000N=@007SD00P007SD00`007cD001lf000O=P03000P=P@0024g
0`008SP2000S>0<002@i00<002Di000U>P009SX00P009SX010009c/002Pk000X>`00:C`2000Z?003
000Z?@00:cd002`m008002`n00<002dn000^?`00;cl00P00<4000`00<D000391000c@@02000d@P03
000e@P00=T<003Q4008003U400<003Y5000lAP00?DL00P00?dL00`00@DP004990014BP020016B`03
0019C000Bdd004i>008004m>00<0051>001BC@00Dd`00P00E4`00`00ET/005Q:001IB002001KA`03
001NA@00H4<00691008006Dn00<006Pj0?l0003o00003`3o00001P00J3X006Dn001U?P00HT400613
001NA@8005]700<005U8001HBP00ET/00P00E4`00`00Dd`0059=001@CP02001?CP03001>CP00Bdd0
04U<008004I;00<004A:0012B@00@DP00P00?dL00`00?DL003a6000jA@02000iA003000hA000=T<0
03E2008003A200<003=1000b@@00<D000P00<4000`00;cl002ho000]?P02000/?P03000/?@00:cd0
02Xm008002Xl00@002Tl000X>`00:3/002Lk0`009SX00`009CX002Di000T>@02000T>@8002<h0`00
8SP010008SL0024g000Q=`008CL3000P=P8001lf00<001le000N=@007SD00P007SD00`007CD001dd
000M=002000M=08001`d00<001`c000K<`006c<00`006c<7000J<P03000I<P006C4001Ta008001Ta
1@0063400`00630001L`ooooo`04ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool2000H<0@001Pa10006C42000I<PD001Xb1@006c<3000L<`8001`d0`007C@00`007CD001he000N
=@02000N=@04000O=@007cH001lf000O=P80020f10008CL00`008SL0028h000S>002000S>08002@i
0P009CT00`009CX002Hj000V>P03000W>`03000X>`00:C`002Tl008002Xl0P00:cd01@00;3h002dn
000]?P00;Sl002lo00<0031000<00351000b@@00=4800P00=D800`00=T<003M3000hA002000jA@03
000kAP00?DH003i70080041800<004990014BP00ATX00P00B4/00`00BT`004a=001?CP02001@CP03
001AC@00DTd005A<008005E;00<005M:001IB@00FdP00P00GDH00`00Gd@00652001T?`02001W?003
001Z>03o0000o`0000l0o`0000H006Xh001W?000Ic`006@o001Q@P00Gd@2001MAP03001KB000FDT0
05M:008005E;00<005A<001BC@00DDd00P00D4h00`00Cdh004a=001:C0020018B`030016BP00A4X0
04990080041800<003i7000mAP00>dH00P00>TD00`00>4@003M3000f@`02000e@P03000d@P00<T40
03510080035000<00310000_?`00;Sl00P00;Ch00`00;3h002/m000[?@02000Z?08002Tl00@002Pk
000W>`009c/002Lk0P009SX00`009CX002Di000U>@02000T>@<002<h00<0028h000R=`008CL00`00
8CL2000P=P<001lf00<001le000N=@007SD00P007SD00`007CD001dd000M=002000M=004000L=000
73<001`c000L<`D001/c1@006S82000I<P@001Ta10006342000H<0Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooo`03000H<000634001Pa008001Pa10006C42000I<PD001Xb1@00
6c<3000L<`8001`d10007C@4000N=@03000O=@007cH001lf00<0020f00H0020g000Q=`008CL0024g
000R=`008SP4000S>08002@i0P009CT00`009CX002Hj000W>P02000W>`8002Pk00L002Tl000Z?000
:Sd002Xm000[?@00;3h002dn008002hn00<002ho000_?`00<4000P00<D000`00<T4003=1000d@P02
000e@`03000g@`00>4@003U5008003]500<003a6000nA`00?dL00P00@DP00`00@dT004E:0017B`02
0019C003001;C@00CTh004m>0080051=00<0059=001CC000ED/00P00ET/00`00F4X005Y8001LA`02
001NA@03001P@`00HT4006Dn008006Pj00<006/f0?l0003o00003`3o00001P00JcH006Pj001X>P00
ICh00691001P@`8005i500<005a7001JB000F4X00P00ET/00`00ED/005=<001BC@02001@C@03001?
CP00CTh004]=008004U<00<004M;0015BP00@dT00P00@DP00`00?dL003i7000lAP02000kA@03000i
A@00>4@003M3008003E300<003A2000c@@00<T400P00<D000`00<40002lo000^?`02000^?P03000]
?P00;3h002/m008002Xm00@002Xl000Y?000:3/002Pk0P009c/00`009cX002Hj000U>P02000U>@80
02@i10008cP00`008SP0028g000Q=`02000Q=`04000P=`0083H0020f000P=P8001lf00<001le000N
=@007SD00P007SD4000M=08001`d0`0073<5000K<`D001Xb0P006C84000I<@@001Pa00<001P`oooo
ooooool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo00<001P`000H<@00
63400P006344000I<@8001Tb1@006S85000K<`<001`c0P0073@4000M=0@001he00<001le000O=P00
7cH00`0083H01P0083L0024g000Q=`008CL0028g000R>0@002<h0P0093T2000U>@03000U>P009SX0
02Lj008002Lk0P00:3/01`00:C`002Xl000Z?@00:Sd002/m000/?P00;Ch00P00;Sh00`00;Sl002lo
000`@002000a@003000b@@00<d4003A2008003E300<003M3000hA000>DD00P00>dD00`00?4H003i7
000oA`020011B0030013B@00ADX004M;008004U<00<004]=001>CP00Cdh00P00D4d00`00DTd005=<
001EB`02001FB`03001HBP00FTP005a7008005i500<00613001R@@00ICh00P00J3X00`00JcH0o`00
0?l0000?0?l00006001[=P00J3X006Pj001U?P00HT4006130P00GTD00`00G4L005Y8001HBP02001F
B`03001EB`00Dd`0059=0080051=00<004m>001>CP00Bdd00P00BD`00`00Ad/004E:0013B@020011
B003000oA`00?TL003a6008003]500<003U5000hA000=d<00P00=D<00`00=48003=1000b@@02000a
@003000`@000;cl002ho008002hn00<002dn000/?P00:cd00P00:Sd01000:S`002Tl000X>`00:3/2
000W>`03000W>P009SX002Dj008002Di0P0093T4000S>003000R>0008SL0024g0080024g00@0020g
000P=P0083H0020f0P007cH00`007cD001he000N=@02000N=@@001dd0P0073@3000L<`D001/c1@00
6S82000I<P@001Ta100063400`00633oooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_ooool5000H<@@001Ta00<001Tb000J<P006S8010006S84000K<`8001`c0`0073@4
000M=0<001he0`007cD00`007cH0020f000P=P02000P=P80024g0P008SL2000R>0<002<h0P0093T0
0`009CT002Dj000U>P02000V>P04000W>`00:3/002Pk000X>`8002Tl00H002Xm000[?@00:cd002`m
000/?P00;Ch2000^?`03000_?`00<40003500080039100<003=1000d@P00=D800P00=T<00`00=d@0
03U4000jA@02000kAP03000mAP00?dL004180080049900<004A:0016B`00B4`00P00BTd00`00CDh0
04m>001@CP02001AC@03001CC@00E4`005E;008005M:00<005U9001KB000GDH00P00Gd@00`00HD80
06@o001W?002001Z>003001]=000LBh0o`0000h0o`0000L0074^001]=000JSP006Xh001W?000I3l0
0652008005m400<005e6001KB000FDT00P00EdX00`00ED/005A<001CC@02001AC@03001@CP00Cdh0
04e>008004Y=00<004Q<0016B`00A4X00P00@TT00`00@4P003m7000mAP02000kAP03000jA@00>D@0
03M4008003I300<003E2000d@P00<d400P00<T400`00<D000310000_?`02000^?`03000]?P00;3h0
02`m008002/m00<002Xm000Z?000:C`00`00:3/00`009c/002Hj000V>P02000U>P03000U>@0093T0
02@i00<002<h0P008SP2000R=`80024g100083H2000O=P8001le0`007SD4000M=0<001`d0P0073<4
000K<`H001Xb00<001Tb000I<@006C400P006C45000H<@Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`02ooooo`@001Pa0`006C43000I<PD001Xb1@006c<0100073<001`d000L=00073@3
000M=08001de0`007SD2000O=@8001lf0`0083H3000Q=`80028g00<0028h000S>0008cP00`0093T0
0`009CT002Dj000V>P02000V>P8002Lk0P00:3/2000Y?007000Z?000:cd002/m000[?@00;3h002dn
000^?`03000_?`07000`@000<D000391000b@@00<d8003A2000f@`02000g@`03000hA000>DD003]5
008003a600<003i70010B000@DP00P00@dT00`00ADX004M;0019C002001<C@03001>CP00Cdh0055=
0080059=00<005=<001EB`00ETX00P00F4T00`00FTP005a7001NA@02001P@`03001R@@00ICh006Pj
008006/f00<006la001c:`3o00003P3o00001`00Lb/006la001[=P00JcH006Pj001U?P00Hd400P00
H4<00`00GTD005a7001JB002001HB@03001FBP00ED/005=<0080059=00<0055=001?CP00CTh00P00
C4d00`00BD`004M;0015BP020013B@030011B000@4P003i7008003a600<003]5000iA@00>4@00P00
=d<00`00=T<003A2000c@P02000b@@03000a@000<40002lo008002lo00<002ho000]?P00;3h00`00
:cd00`00:S`002Tl000Y?002000X>`8002Lk0`009SX00`009CX002Di000T>@02000T>@8002<h00<0
028h000R=`008SL00`008CL3000P=P8001lf0P007cD3000N=@8001de0`007C@3000L=003000L<`00
6c<001/c00<001/c1@006S83000I<P<001Ta10006345ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_ooool2000H<@@001Ta0`006C85000J<PD001/c0P0073<3000L=0<001dd10007SD0
10007cD001lf000O=P007cH2000P=P80020g0P008CL00`008SL0028h000R>003000S>0<002@i00H0
02Di000U>P009SX002Hj000W>P009c/3000X>`04000Y?000:S`002Xm000[?@8002`m0P00;Ch01P00
;Sl002lo000_?`00<4000350000b@@8003=100<003A2000e@`00=T<00P00>4@00`00>D@003Y5000l
AP02000mA`03000oA`00@4P00499008004A:00<004I;0018C000Bdd00P00CDh00`00Cdh0051>001A
C@02001CC003001DC000ET/005M:008005U900<005]7001MAP00Gd@00P00HD800`00I3l006Ll001Z
>002001]=003001a;P00MBL007XO00d0o`0000<007XO001e9`00LBh00P00KC@00`00JSP006Ll001T
?`02001Q@P03001OA000GDH005]7008005U900<005M:001FB`00E4`00P00Dd`00`00DDd0051>001?
CP02001=CP03001;C@00B4`004I;008004A:00<004990011B000?dL00P00?DL00`00?4H003Y5000i
A002000hA003000f@`00=D<003A2008003=100<00391000a@000<4000P00;cl00`00;Sl002dn000]
?P02000/?@04000[?@00:Sd002Xl000Y?0<002Pk00H002Lk000W>P009SX002Hj000U>P009CT3000T
>@<002<h0P008SP00`008SL0024g000Q=`02000P=`80020f0`007cH00`007cD001he000N=@02000N
=@<001dd0`0073@2000L<`D001/c1@006S83000I<P@001Ta0P006345ooooo`7o00000Oooool001_o
oooo0_l00003ooooo`03000H<@006C4001Ta008001Ta0P006C85000J<PD001/c0`0073<2000L=0@0
01dd10007SD010007cD001lf000O=P007cH3000P=P<0024g00@0028g000R>0008SP0028h0P008cP3
000T>@03000U>@009CX002Hj008002Hj00<002Lk000X>`00:3/00`00:C`00`00:S`002/m000/?@02
000/?P03000]?P00;Sl002lo0080031000<00350000b@@00<d400P00=4800`00=D8003I3000g@`02
000hA003000jA@00>dD003e6008003i700<004180012B@00@dT00P00ADX00`00Ad/004Y<001<C@02
001>CP03001@CP00DDd0059=008005=<00<005E;001FBP00F4T00P00FTP00`00G4L005i5001P@`02
001S@@03001U?P00J3X006/f008006la00<007<[001h9000OAX03@3o00000`00OAX007PT001c:`02
001_<@03001[=P00J3X006Dn008006=100<00613001NA@00G4L00P00FTP00`00F4T005I:001EB`02
001CC003001BC@00DDd0051>008004i>00<004a=001:C000Ad/00P00ADX00`00@dT004990010B002
000nA`03000mAP00>dD003Y5008003Q400<003M3000f@`00=D800P00=4800`00<d400391000a@002
000`@003000_?`00;Sl002dn008002`n00<002`m000[?@00:S`00`00:C`2000X>`06000W>`009SX0
02Hj000V>P009CX002Di0`0093T2000S>0<0028h00@0028g000Q=`008CL0024g0`0083H3000O=P03
000O=@007SD001he008001he10007C@2000L=0<001`c1@006c<5000J<P8001Tb10006C400`00637o
ooooooooo`02ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_ooool00`00634001Ta
000I<@02000I<@8001Tb1@006S85000K<`<001`c0P0073@4000M=0@001he00@001le000O=P007cH0
01lf0`0083H3000Q=`04000R=`008SP0028h000R>08002<h0`0093T00`009CT002Dj000V>P02000V
>P03000W>`00:3/002Pk00<002Tl00<002Xl000[?@00;3d00P00;3h00`00;Ch002ho000_?`02000`
@003000a@000<T4003=1008003A200<003E2000f@`00=d<00P00>4@00`00>TD003]5000mAP02000n
A`030010B000@TT004=9008004E:00<004M;001:C000C4d00P00CTh00`00D4h0055=001BC@02001C
C003001EB`00ETX005Q9008005Y800<005a7001NA@00H4<00P00Hd400`00ICh006Pj001[=P02001_
<@03001c:`00N2@007dJ00d0o`0000<007dJ001h9000Lb/00P00Kc400`00JcH006Pj001U?P02001S
@@03001P@`00GTD005a7008005Y800<005Q9001FBP00ED/00P00Dd`00`00DTd0055=001@CP02001>
CP03001<C@00BT`004M;008004E:00<004=90012B@00@4P00P00?TL00`00?DH003]5000jA@02000h
A003000g@`00=T<003E2008003A200<003=1000b@@00<D000P00<4000`00;cl002ho000]?P02000/
?P03000/?@00:cd002Xl00<002Tl0P00:3/01P009c/002Hj000V>P009SX002Dj000U>@<002@i0P00
8cP3000R>004000R=`008CL0024g000Q=`<0020f0`007cH00`007cD001he000N=@02000N=@@001dd
0P0073@3000L<`D001/c1@006S82000I<P@001Ta00<001Paooooooooool00oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00<001Pa000I<@006C400P006C400`006C8001Xb000J
<P04000J<PD001/c0P0073<2000L=0@001dd00<001de000N=@007SD00P007SD010007cD001lf000O
=P007cH2000P=P@0024g00<0028g000R>0008cP00P008cP2000T>@<002Di0P009SX2000W>P03000W
>`00:3/002Tl008002Tl00@002Xl000[?@00:cd002`n0P00;Ch00`00;Sh002ho000_?`02000`@003
000a@000<T4003=1008003A200<003E3000g@`00>4@00P00>DD00`00>TD003a6000mA`02000oA`03
0011B000@dT004A:008004I;00<004U<001;C@00CDh00P00Cdh00`00D4h0055=001CC002001DC003
001FB`00EdX005U9008005]700<005e6001OA000HD800P00I3l00`00Ic`006Xh001]=002001a;`03
001e:000NQl0080E00d0o`0000<0080E001j7`00MBP00P00LBl00`00KC@006Xh001W?002001T?`03
001Q@P00Gd@005e6008005]700<005U9001GBP00ET/00P00E4`00`00Dd`0055=001@CP02001?CP03
001=CP00Bdd004U<008004I;00<004A:0013B@00@DP00P00?dL00`00?DL003a6000kA@02000iA@03
000hA000=d<003E3008003A200<003=1000b@@00<D000P00<4000`00;cl002ho000^?P02000]?P04
000/?P00:cd002/m000Z?0<002Tl00@002Pk000W>`009cX002Lj0P009SX00`009CX002Di000U>@02
000T>@<002<h00<0028h000R=`008CL00`008CL2000P=P<001lf00<001le000N=@007SD00P007SD0
0`007CD001dd000M=002000M=08001`d0P0073<5000K<`H001Xb00<001Tb000I<@006C400P006C40
0`00637oooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool4000I
<@8001Tb1@006S85000K<`<001`c0P0073@4000M=0@001he00<001le000O=P007cH00`0083H01P00
83L0024g000Q=`008CL0028g000R>0@002<h0P0093T2000U>@03000U>P009SX002Lj008002Lk0P00
:3/01P00:C`002Xl000Z?000:Sd002/m000/?@<002dn00<002ho000_?`00<4000P00<D000`00<T40
03=1000d@P02000e@P03000f@`00=d@003U4008003Y500<003]6000mAP00?TL00P00@4P00`00@TT0
04A:0016BP020018B`03001:C000C4d004i>0080051>00<0055=001BC@00Dd`00P00ED/00`00ETX0
05Q9001JB002001LA`03001NA@00H4<00691008006Dn00<006Pj001[=P00Kc800P00Lb`00`00Mb@0
07`K00223`02002900T0o`000P00R@000`00PPl007`K001g9002001c;003001_<P00JcH006Pj0080
06Dn00<006=1001P@`00GTD00P00G4L00`00FTP005Q9001FBP02001EB`03001CC000DTd0055=0080
051>00<004i>001<C@00BT`00P00B4/00`00ATX004A:0012B@020010B003000nA`00?DH003]60080
03Y500<003U4000gA000=T<00P00=D800`00=48003=1000b@@02000a@003000`@000;cl002ho00<0
02dn00<002`m000[?@00:Sd00P00:S`00`00:C`002Pk000X>`02000W>`03000W>P009SX002Dj0080
02Di0P0093T4000S>003000R>0008SL0024g0080024g00@0020g000P=P0083H0020f0P007cH00`00
7cD001he000N=@02000N=@@001dd0P0073@3000L<`D001/c1@006S82000I<P@001Ta1Oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00;ooooo0P006C43000I<PD001Xb1@006c<2000L<`<0
01`d10007C@3000N=@8001le0P007cH4000P=P80024g0P008SL2000R>0<002<h0P0093T00`009CT0
02Dj000U>P02000V>P<002Lk00<002Pk000Y?000:C`00P00:S`2000[?@05000/?P00;Ch002ho000^
?`00;cl00P00<402000a@@03000b@@00<d8003A2008003I300<003M3000hA000>DD00P00>dD00`00
?4H003i7000oB0020011B0030013B@00ADX004M;008004U<00<004]=001>CP00Cdh00P00D4h00`00
DTd005=<001DC002001FB`03001GBP00FDT005]7008005e600<005m4001Q@P00I3l00P00IS`00`00
JCT006dd001a;`02001e:003001i8000OaH008D900801hd02@3o000200N=000300252@00OaH007TP
008007DX00<0074_001]=000JST00P00IS`00`00I3l00652001OA002001MAP03001KA`00FDT005M:
008005I;00<005A<001CC000DTd00P00D4h00`00Cdh004i>001;C@020019C0030017B`00ADX004=9
0080045800<003m8000nA`00?4H00P00>dD00`00>DD003Q4000g@`02000f@`03000d@P00<d800391
008003510P00<4001@00;cl002ho000^?`00;Ch002`n008002/m0P00:S`2000Y?004000X>`009c/0
02Lk000W>`8002Hj0P009CX00`009CT002@i000T>@03000S>080028h0P008SL2000Q=`@0020f0P00
7cH2000O=@<001he10007C@3000L=08001`c1@006c<5000J<P<001Tb0P006C45ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_ooool2000I<@8001Tb1P006S85000K<`04000L<`0073@0
01`d000L=0<001dd0P007CD3000N=@8001le0P007cH3000P=P<0024g0P008SL00`008SP002<h000S
>003000T>@8002Di0`009SX01`009cX002Lk000X>`00:3/002Pl000Y?000:S`00P00:Sd01000:cd0
02`n000]?P00;Ch2000^?`03000_?`00<40003500080039100<003=1000d@P00=D800P00=T<00`00
=d@003U4000jA@02000lAP03000mAP00?dL004180080049900<004A:0016B`00B4/00P00BT`00`00
C4d004m>001@CP02001AC@03001BC@00E4`005E;008005M:00<005Q9001JB000G4L00P00GTD00`00
H4<00691001U?P02001X>`03001[=`00KS80078/008007LU00<007`L00224@00R0800P0@T0090?l0
0080490000<008P200224@00O1`00P00MbD00`00LR`006lb001[=`02001X>`03001U?P00HT400613
008005i500<005a7001JB000F4T00P00EdX00`00ED/005A<001BC@02001AC@03001@CP00Cdh004a=
008004Y<00<004Q;0016B`00A4X00P00@TT00`00@4P003m7000mAP02000lAP03000jA@00>D@003Q4
008003I300<003E2000d@P00<d400P00<T400`00<D000310000_?`02000^?`8002dn00L002`n000[
?@00:Sd002Xm000Z?000:C`002Pl008002Pk00<002Lk000W>P009SX00P009SX2000U>@<002@i0P00
8cP00`008SP0028g000R=`03000Q=`<0020f0P007cH2000O=@<001he0P007CD3000M=0<001`d0P00
73<4000K<`H001Xb0P006C82000I<@Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02
ooooo`8001Ta0P006C86000J<PD001/c00@001`c000L=00073@001`d0`007C@2000M=@<001he0P00
7cD2000O=P<0020f0`008CL2000R=`03000R>0008cP002<h00<002@i0P009CT3000V>P07000W>P00
9c/002Pk000X>`00:3`002Tl000Z?002000Z?@04000[?@00;3h002dn000]?P8002ho00<002lo000`
@000<D000P00<T400`00<d4003A2000e@P02000f@`03000gA000>D@003Y5008003a600<003e6000o
A`00@4P00P00@TT00`00A4X004I;0018B`02001:C003001<C@00Cdh0051>0080055=00<0059=001D
C000ED/00P00EdX00`00F4T005Y8001LA`02001NA@03001P@`00HT4006Dn008006Pk00<006/g001^
<P00LR`00P00MbD00`00O1`0088A00280P02012@00T0o`000P0@T0000`00R080088A001l7002001g
9@03001b;000Kc8006/g008006Pk00<006Dn001R@@00H4<00P00GTD00`00G4L005Y8001HB@02001G
BP03001EB`00E4`0059=0080055=00<0051>001?CP00C4d00P00BT`00`00B4/004I;0014BP020012
B@030010B000?dL003e6008003a600<003Y5000iA000>4@00P00=T<00`00=D8003A2000c@@02000b
@@03000a@000<40002lo008002ho0P00;Ch01`00;3h002/m000Z?@00:Sd002Xl000Y?000:3`00P00
:3/00`009c/002Lj000V>P02000V>P8002Di0`0093T2000S>003000R>0008SL0028g00<0024g0`00
83H2000O=P8001le0`007SD2000M=@<001dd0`0073@2000L<`@001/c1P006S82000I<P8001Ta1Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo00<001Ta000I<P006S801P006S85
000K<`03000L<`0073@001`d00@001dd00<001de000N=@007SD00P007SD010007cD001lf000O=P00
7cH2000P=P80020g0P008CL00`008SL0028h000R>003000S>0<002@i00<002Di000U>P009SX00P00
9SX01`009c/002Pk000X>`00:3/002Tl000Z?000:Sd00P00:cd01000;3d002`n000]?P00;Sl2000_
?`03000`@000<D000391008003=100<003A2000e@P00=T<00P00=d<00`00>4@003Y5000kA@02000l
AP03000nA`00?dP00458008004=900<004E:0017B`00BD`00P00Bdd00`00CTh004m>001@CP02001B
C@03001CC000E4`005I;008005M:00<005U9001KA`00GDH00P00Gd@00`00HD8006@o001V?002001Y
>@03001]=@00L2l007@Y008007TQ00<007hH00242`04R`000P0JU0000`0hWP00o`000?l000050?l0
000603RN000JU0006Y@000B;0000Q0/007hG0P00NB400`00M2T0070_001]=@02001Y>@03001V?000
I3l00652008005m400<005e6001KA`00FDT00P00EdX00`00ET/005A<001CC002001BC@03001@CP00
Cdh004i>008004]=00<004U<0017B`00ADX00P00@dT00`00@DP003m8000nA`02000lAP03000kA@00
>TD003Q4008003M300<003I3000e@P00=4800P00<d400`00<T400350000`@002000_?`04000^?`00
;Ch002`n000/?@8002/m00<002Xm000Z?000:C`00`00:3/01P009c/002Hj000V>P009SX002Dj000U
>@<002@i0`008cP2000R>003000R=`008CL0024g0080020g0P0083H3000O=P03000O=@007SD001he
008001he00<001de000M=0007C@00P007C@2000L=003000L<`006c<001/c00<001/c1`006S800`00
6C8001Taooooo`04ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool2000I<PD0
01Xb1@006c<3000L<`8001`d10007C@4000N=@04000O=@007cH001lf000O=P<0020f0`008CL01000
8SL0028h000R>0008SP2000S>0<002@i00<002Di000U>P009SX00P009SX2000W>`05000X>`00:C`0
02Tl000Y?000:S`00`00:cd01000;3h002dn000^?P00;Sl2000_?`03000`@000<D000391008003=1
00<003A2000e@`00=T<00P00>4@00`00>D@003Y5000lAP02000mA`03000oA`00@4P00499008004A:
00<004I;0018C000BT`00P00CDh00`00Cdh0051>001AC@02001BC@03001DC000ED/005M:008005Q9
00<005Y8001LA`00GTD00P00H4<00`00HT4006Dn001X>`02001[=`03001^<P00LRd007HV008007/M
00<0084C00271@0<S`000P0UV0000`17X`00o`000?l000050?l0000604NS000UV0009IP000b?0000
Q`D0084C0P00Nad00`00MRH0078]001^<P02001[=`03001X>`00ICh006910080061300<005i5001L
A`00FTP00P00F4T00`00EdX005E;001DC002001BC@03001AC@00D4h004m>008004e>00<004Y=0018
C000AT/00P00A4X00`00@TT00418000oA`02000mA`03000lAP00>TD003U4008003Q400<003I3000e
@`00=4800P00<d400`00<T400350000`@002000_?`04000^?`00;Sh002dn000/?P<002/m00D002Xl
000Y?000:C`002Tl000X>`02000W>`<002Hj00<002Dj000U>@0093T00P0093T2000S>0<0028h00@0
028g000Q=`008CL0024g0`0083H3000O=P03000O=@007SD001he008001he10007C@2000L=0<001`c
1@006c<5000J<P8001Tb1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo00<0
01Tb000J<P006S800`006S800`006c8001/c000K<`02000K<`<001`c0P0073@4000M=003000M=@00
7SD001he008001he00@001le000O=P007cH001lf0P0083H4000Q=`03000R=`008SP002<h008002<h
0P0093T3000U>@8002Hj0P009cX00`009c/002Pk000X>`02000Y?003000Z?000:Sd002/m008002`m
0P00;Ch01`00;Sl002lo000`@000<4000350000b@@00<d400P00=4800`00=D8003I3000gA002000h
A003000jA@00>dD003a6008003i700<004180011B000@dT00P00ADX00`00Ad/004U<001;C@02001>
CP03001?CP00D4h0059=008005=<00<005A<001FB`00EdX00P00FDT00`00FdL005e6001OA002001Q
@P03001S@000ISd006Ti008006`e00<0070`001d:P00N2<00P00OAT00`00P`d00HX001FB0002036L
000305NX003o0000o`0000D0o`0000H0EjP0036L000aW0005I80006:0000P`d2001m6@03001h8P00
M2X0070`008006`e00<006Ti001V?@00Hd000P00HD800`00Gd@005e6001KA`02001IB@03001GBP00
ET/005A<008005=<00<0059=001@CP00Cdh00P00CTh00`00Bdd004U<0017B`020015BP030013B@00
@DP00418008003i700<003e6000kA@00>TD00P00>4@00`00=d@003I3000e@P02000d@P03000c@@00
<T4003500080031000@002lo000^?`00;Ch002dn0P00;3d00`00:cd002Xm000Z?002000Y?08002Pk
00<002Lk000W>P009cX00P009SX3000U>@8002@i0`008cP00`008SP0028g000Q=`03000Q=`80020f
0`007cH00`007cD001he000N=@03000N=@@001dd0P0073@3000L<`@001/c00<001/b000J<P006S80
0`006S800`006C;oooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool6000J<PD001/c00@001`c000L=00073@001`d10007C@00`007CD001he000N=@02000N=@03000O
=@007cH001lf00<0020f00D0020g000Q=`008CL0024g000R=`02000R>0<002<h0P0093T2000U>@03
000U>P009SX002Hj008002Lk0P00:3/3000Y?003000Z?000:cd002/m008002`n00@002dn000^?`00
;cl002lo0P00<4000`00<D000391000c@P02000d@P03000e@`00=d<003Q4008003U400<003Y5000l
AP00?DL00P00?dL00`00@DP004990014BP020016B`030018C000BTd004e>008004m>00<0051>001A
C@00DTd00P00E4`00`00ED/005I:001HB@02001JB003001LA`00GTD006130080069100<006Dn001W
>`00JSP00P00KS<00`00LBh007HW001j7`0200205@0300262008S@007iH00080?Z0000<0JZd00:bo
003o0000103o00001`2/_`00JZd003jP000nX0007iH000R=0000QPP00P00P1D00`00NQl007HW001a
;P02001^<`03001Z>000Ic/006Dn0080069100<00613001NA@00G4L00P00FTP00`00F4T005I:001E
B`02001DC003001BC@00DDd0051>008004m>00<004e>001:C@00B4`00P00AT/00`00A4X004990011
B002000oA`03000mA`00?4H003Y5008003U500<003Q4000g@`00=D<00P00=4800`00<d800391000a
@002000`@08002lo00@002ho000]?P00;3h002`n0P00:cd01000:S`002Tl000Y?000:C`2000X>`80
02Lk0P009SX00`009CX002Di000U>@02000T>@<002<h0P008SP01@008SL0024g000Q=`008CL0020g
00<0020f0P007cH00`007cD001he000N=@02000N=@03000M=@007C@001dd008001dd0`0073@00`00
73<001/c000K<`03000K<`H001Xb1Oooool1o`00007ooooo000Kooooo`;o00000oooool6000J<PD0
01/c00@001`c000L=00073@001`d10007C@00`007CD001he000N=@02000N=@03000O=@007cH001lf
00<0020f00D0020g000Q=`008CL0024g000R=`02000R>0<002<h0P0093T2000U>@03000U>P009SX0
02Hj008002Lk0P00:3/3000Y?003000Z?000:cd002/m008002`n00@002dn000^?`00;cl002lo0P00
<4000`00<D000391000c@P02000d@P03000e@`00=d<003Q4008003U400<003Y5000lAP00?DL00P00
?dL00`00@DP004990014BP020016B`030018C000BTd004e>008004m>00<0051>001AC@00DTd00P00
E4`00`00ED/005I:001HB@02001JB003001LA`00GTD006130080069100<006Dn001W>`00JSP00P00
KS<00`00LBh007HW001j7`0200205@0300262008S@007iH00080?Z0000<0JZd00:bo003o0000103o
00001`2/_`00JZd003jP000nX0007iH000R=0000QPP00P00P1D00`00NQl007HW001a;P02001^<`03
001Z>000Ic/006Dn0080069100<00613001NA@00G4L00P00FTP00`00F4T005I:001EB`02001DC003
001BC@00DDd0051>008004m>00<004e>001:C@00B4`00P00AT/00`00A4X004990011B002000oA`03
000mA`00?4H003Y5008003U500<003Q4000g@`00=D<00P00=4800`00<d800391000a@002000`@080
02lo00@002ho000]?P00;3h002`n0P00:cd01000:S`002Tl000Y?000:C`2000X>`8002Lk0P009SX0
0`009CX002Di000U>@02000T>@<002<h0P008SP01@008SL0024g000Q=`008CL0020g00<0020f0P00
7cH00`007cD001he000N=@02000N=@03000M=@007C@001dd008001dd0`0073@00`0073<001/c000K
<`03000K<`H001Xb1?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1@006S85
000K<`8001`c0`0073@4000M=0<001he0P007cD2000O=P@0020f10008CL00`008SL0028h000S>002
000S>08002@i00<002Di000U>P009CX00P009SX010009cX002Lk000W>`00:3/2000Y?08002Xl00<0
02Xm000[?@00;3h00`00;Ch00`00;Sl002lo000`@002000a@003000b@@00<d4003A2008003E200<0
03I3000gA000>D@00P00>TD00`00>dH003e6000nA`020010B0030011B@00@dT004E:008004M;00<0
04U<001;C@00CTh00P00Cdh00`00D4h0059=001CC002001DC003001FB`00EdX005U9008005]800<0
05e6001OA000HD800P00Hd000`00ISd006Tj001/=P02001_<@03001c:`00Mb@007`K0080088@00<0
08T1012@000YV@000P1<Y@000`1o/`00a/400?l000040?l000070<K0001o/`00C:D004bU000ZV@00
490000290@0200224003001l6`00Mb@007<[008006la00<006`f001Y>P00ISd00P00Hd000`00HD80
05m4001MAP02001KB003001IB@00EdX005I;008005A<00<005=<001BC@00D4d00P00Cdh00`00CTh0
04]=0019C0020017B`030015BP00@dT004590080041800<003i7000mAP00>dH00P00>TD00`00>D@0
03M4000f@`02000e@P03000d@P00<d4003910080035000<00310000_?`00;Sl00`00;Ch00`00;3h0
02/m000Z?@02000Z?08002Tl00@002Pk000W>`009c/002Lj0P009SX2000U>P03000U>@0093T002@i
00<002<h00<0028h000R=`008CL00`008CL4000P=P8001lf0P007cD3000N=@@001dd0`0073@2000L
<`D001/c1@006S85ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool4000J<PD0
01/c0P0073<3000L=0<001dd0P007CD3000N=@8001le0P007cH3000P=P<0024g0P008SL00`008SP0
02<h000S>002000S>@8002@i00H002Di000U>P009CX002Hj000W>P009c/3000X>`07000Y?000:S`0
02Xm000Z?@00:cd002`m000/?P02000]?P04000^?`00;cl00310000`@080035100<00391000c@P00
=4800P00=T<00`00=d<003Q4000iA@02000kA@03000lAP00?DL003m70080045800<004990014BP00
AT/00P00B4`00`00BTd004e>001?CP02001@CP03001AC@00DTd005A<008005E;00<005I:001HB@00
FTP00P00G4L00`00GDD00613001R@@02001T?`03001W?000JSP006dd0080074_00<007DX001i8000
OaL00P00Q0/00`04R`006I@003FM000205bZ000309Ji003>[000o`0000@0o`0000L0cZ`009Ji001L
ZP00G:X003FM000IU00018/0008008@:00<007lG001i8000MBP00P00LBl00`00KC@006Xh001W?002
001T?`03001R@@00H4<005e5008005a700<005Y8001HB@00ETX00P00ED/00`00E4`0059=001AC@02
001@CP03001?CP00CDh004Y=008004Q<00<004I;0014BP00@TT00P00@DP00`00?dL003e7000lAP02
000kA@03000iA@00>4@003M3008003I300<003A2000c@P00<T400P00<D42000`@007000_?`00;Sl0
02dn000]?P00;3h002`m000[?@02000Z?@03000Z?000:C`002Pk008002Pk00<002Lk000W>P009SX0
0P009CX00`009CT002@i000T>@02000T>@8002<h00<0028h000R=`008SL00`008CL3000P=P8001lf
0P007cD3000N=@8001de0`007C@3000L=08001`c1@006c<4000J<PGooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooo`@001Xb1@006c<00`0073<001`d000L=004000M=003000M=@00
7SD001he008001he00@001le000O=P007cH001lf0P0083H2000P=`80024g00@0028g000R>0008SP0
028h0P008cP3000T>@03000U>@009CX002Hj008002Hj0P009c/2000X>`8002Tl00H002Xl000[?@00
:cd002/m000/?P00;Ch2000^?P04000^?`00;cl00310000a@080039100<003=1000d@P00=D800P00
=T<00`00=d@003U4000jA@02000kAP03000mAP00?TL004180080045900<004=90015BP00Ad/00P00
BD`00`00Bdd004i>001?CP02001@CP03001BC@00Dd`005A<008005I;00<005M:001IB@00FdP00P00
G4H00`00GT@00653001S@002001U?@03001X>P00JcH006lb0080078/00<007LU001k7@00PA800P00
Q`D00`0;SP008YL0046Q000206j_00030;30003GU000o`0000@0o`0000L0ei@00;30001^[`00KZl0
04:Q000RU`002hh0008008L500<0084B001k7@00MbD00P00LR`00`00Kc8006/f001X>P02001U?@03
001S@000HD<005i4008005a600<005]8001IB@00EdX00P00ET/00`00E4`005=<001BC@02001@CP03
001?CP00CTh004]=008004U<00<004M;0015BP00@dT00P00@TT00`00@4P003i7000mAP02000kAP03
000jA@00>D@003M4008003I300<003E2000d@P00<d400P00<T401000<D000310000_?`00;Sl2000^
?P03000]?P00;3h002/m008002/m00<002Xl000Y?000:C`00P00:3/2000W>`<002Hj00<002Dj000U
>@0093T00P0093T2000S>0<0028h00<0028g000Q=`008CL00P0083L2000P=P<001lf00<001le000N
=@007SD00P007SD00`007CD001dd000M=002000M=08001`d00<001`c000K<`006c<00`006c<4000J
<PGooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`8001Xb1@006c<3000L<`80
01`d10007C@4000N=@04000O=@007cH001lf000O=P<0020f10008CL00`008SL0028h000R>002000S
>0<002@i0P009CT3000V>P03000W>P009c/002Pk008002Pk00<002Tl000Z?000:Sd00P00:cd00`00
;3d002`n000]?P02000^?`04000_?`00<4000350000b@@8003=100<003A2000e@P00=T<00P00=d<0
0`00>4@003U5000kA@02000lAP03000mA`00?dL004580080049900<004A:0016B`00B4`00P00BTd0
0`00CDh004m>001@CP02001AC@03001BC@00Dd`005E;008005I:00<005Q:001JB000FdL00P00GDD0
0`00Gd@00692001T?`02001W?003001Y>@00KCD0070`008007@Z00<007PR001m6@00P`h00P00RP00
0`0CT@00;9X004nV0002086d00030<K0003PN000o`0000@0o`0000L0h7L00<K00021]000PK@004nV
000/VP004i40008008X000<008<>001m6@00N2800P00M2X00`00L30006de001Y>@02001W?003001T
?`00HT8005m4008005e500<005]7001JB000F4T00P00ETX00`00ED/005=<001BC@02001AC@03001@
CP00Cdh004e>008004Y=00<004Q<0016B`00A4X00P00@TT00`00@DP003m7000nA`02000lAP03000k
A@00>DD003Q4008003M300<003I3000e@P00=4800P00<d401000<T400350000`@000;cl2000^?`03
000]?P00;3h002`m008002/m00<002Xm000Z?000:C`00`00:3/00`009c/002Lj000V>P02000V>P80
02Di0`0093T2000S>080028h00<0028g000Q=`008CL00P008CL3000P=P<001lf00<001le000N=@00
7SD00P007SD4000M=08001`d0`0073<5000K<`8001Xb1Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo0P006S85000K<`<001`c0P0073@4000M=0@001he00@001le000O=P007cH0
01lf0`0083H4000Q=`03000R=`008SP0028h008002<h0`0093T2000U>@<002Hj00<002Lj000W>`00
:3/00P00:3/00`00:C`002Xl000Z?@02000[?@03000/?@00;3h002dn008002ho00@002lo000`@000
<D0003910P00<d400`00=48003E2000f@`02000g@`03000hA000>DD003]5008003a600<003e7000o
A`00@DP00P00@TT00`00A4X004I;0018C002001:C@03001=CP00Cdh0051>0080055=00<0059=001C
C000ED/00P00ETX00`00F4X005Y8001KA`02001MA@03001OA000HT8006@o008006Ll00<006Ti001]
=@00L3000P00M2X00`00N28007dI00233P02002:000301>A000/VP00CjH00080PK@000<0a/000>1h
003o0000103o00001`3PM`00a/00086d0021]000CjH002bJ000CT@000P00RP000`00P`h007dI001h
8P02001d:P03001`<000KCD006Ti008006Ll00<006@o001R@P00Gd@00P00GDD00`00FdL005Y8001H
B@02001FBP03001EB`00Dd`0059=0080055=00<0051>001?CP00CDh00P00BTd00`00B4`004I;0014
BP020012B@030011B000?dL003i7008003a600<003]5000iA@00>4@00P00=d<00`00=T<003E2000d
@P02000c@@04000b@@00<D000310000_?`8002ho00<002dn000/?P00;3d00P00:cd00`00:Sd002Xl
000Y?003000X>`03000W>`009cX002Hj008002Hj0P009CT3000T>@8002<h0P008SP00`008SL0024g
000Q=`02000Q=`<0020f0`007cH00`007cD001he000N=@02000N=@@001dd0P0073@3000L<`D001/c
0P006S85ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool00`006S8001/c000K
<`03000K<`<001`c0P0073@4000M=003000M=@007SD001he008001he00@001le000O=P007cH001lf
0P0083H4000Q=`03000R=`008SP002<h00<002<h0`0093T00`009CT002Dj000V>P02000V>P03000W
>`00:3/002Pk00<002Tl00L002Xl000[?@00:cd002/m000/?P00;Ch002hn008002ho00@002lo000`
@000<D0003910P00<d400`00=48003E3000f@`02000gA003000iA000>TD003]6008003e600<003i7
0010B000@TT00P00@dT00`00ADX004M;0019C002001;C@03001>CP00Cdh0051>0080055=00<005=<
001DC000ET/00P00EdX00`00FDT005Y8001LAP02001NA@03001P@`00Hd4006Dn008006Pk00<006/g
001^<`00LRd00P00MRL00`00NQl007lE00252@0200J<000301^D000gWP00GZX00080U[T000<0cJh0
0>YF003o0000103o00001`3ZE@00cJh009Ji002F^@00GZX003NN000KU0000P06S0000`00Q@T007lE
001j7`02001f9`03001b;@00KS<006/g008006Pk00<006Dn001S@@00H4<00P00GTD00`00G4H005Y8
001IB@02001GBP03001FB`00E4`005=<0080055=00<0051>001?CP00CTh00P00Bdd00`00BD`004M;
0015BP020013B@030012B@00@4P003i7008003e600<003]6000jA@00>D@00P00=d@00`00=T<003E3
000d@P02000c@@04000b@@00<D000310000_?`8002ho00<002hn000]?P00;3h00`00:cd01000:S`0
02Tl000Y?000:C`2000X>`06000W>`009SX002Hj000V>P009CX002Di0`0093T4000S>003000R>000
8SL0024g00<0024g0P0083H3000O=P03000O=@007SD001he008001he00<001de000M=0007C@00P00
7C@2000L=0<001`c1@006c<00`006S;oooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_ooool00`006S8001/c000K<`03000K<`04000L<`0073@001`d000L=0D001dd1000
7SD00`007cD001lf000O=P03000P=P05000P=`008CL0024g000Q=`008SL00P008SP3000S>08002@i
0P009CT00`009CX002Hj000V>P02000W>P03000W>`00:3/002Pl008002Tl00<002Xl000Z?@00:cd0
0P00;3d2000]?P07000^?`00;cl002lo000`@000<D000391000c@@02000d@P03000e@P00=T<003M3
008003Q400<003U5000kA@00?4H00P00?TL00`00?dL004580012B@020014BP030016B`00B4`004Y=
008004e>00<004m>001@CP00DDd00P00DTd00`00Dd`005E;001FB`02001HBP03001IB000FdL005e6
008005m400<00652001T?`00ISd00P00JCT00`00K3D006la001c:`02001g9003001l6`00PA4008P3
00803Hl000<099L004>R001^[`000P2]_`000`3EV@00m2d00?l000040?l000070?D]003EV@00[[l0
0:jo001^[`00@j8002BG000200f?000300280`00PQ4007`K008007LT00<007<[001_<@00K3D00P00
JCT00`00ISd006@o001Q@P02001OA003001MAP00FdL005U8008005Q:00<005I;001EB`00Dd`00P00
DTd00`00DDd0051>001?CP02001=CP03001:C@00B4`004I;008004A:00<004990011B000?dL00P00
?TL00`00?4H003]5000iA@02000hA003000g@`00=T<003E2008003A200@003=1000b@@00<D000310
0P00;cl00`00;Sl002dn000]?P02000/?@03000[?@00:Sd002Xl008002Tl00<002Pl000X>`009c/0
0P009cX2000V>P03000U>P009CT002Di008002@i0`008cP2000R>005000R=`008CL0024g000Q=`00
83L00`0083H2000O=P03000O=@007SD001he008001he1@007C@3000L=003000L<`006c<001/c00<0
01/c00<001Xbooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
1@006c<2000L<`<001`d10007C@3000N=@<001le00<001lf000P=P0083H00P0083H4000Q=`03000R
=`008SP002<h008002<h0`0093T2000U>@03000U>P009SX002Lj008002Lk0P00:3/3000Y?003000Z
?000:cd002`m008002`n00<002dn000^?`00;cl00P00;cl01000<4000350000b@@00<d42000d@P03
000e@`00=T<003Q4008003U400<003Y5000kAP00?DH00P00?TL00`00@4P004990013B@020015BP03
0017B`00BD`004]=008004i>00<004m>001@CP00DDd00P00Dd`00`00E4`005E;001GBP02001HB@03
001JB000G4L005i50080061300<00691001U?P00Ic/00P00JSP00`00KC@0074_001e:002001i8@03
001n6000Q0`00HX00080598000<0;I/004nV001o/`000P35``000`3MP@00o`000?l000050?l00006
0=f10035``00aL<007nc001?YP00;I/00P0DTP000`01RP0008@<001n6002001i8@03001e:000LBl0
06dd008006Xh00<006Lk001U?P00HT400P00H4<00`00GTD005a7001JB002001HB@03001GBP00ED/0
05A<008005=<00<0055=001@CP00Cdh00P00CTh00`00Bdd004U<0017B`020015BP030013B@00@TT0
0418008003i700<003e6000kAP00>TD00P00>D@00`00>4@003I3000e@`02000d@P04000c@@00<T40
0350000`@0<002lo00L002ho000]?P00;3h002`n000/?@00:cd002Xl00<002Tl0P00:3/2000W>`03
000W>P009SX002Dj008002Di0`0093T3000S>003000R>0008SL0024g00<0024g100083H010007cH0
01le000O=@007cD3000N=@@001dd0`0073@2000L<`D001/c1Oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo10006c<2000L<`<001`d0`007C@2000M=@<001he0P007cD2000O=P<0
020f00<0020g000Q=`008CL00P008SL2000R>0<002<h0P0093T00`009CT002Dj000U>P02000V>P<0
02Lk00<002Pk000Y?000:C`00P00:S`2000[?@06000/?P00;Ch002dn000]?P00;Sl002lo0P00<400
1000<D000391000c@@00=482000e@P03000f@`00=d<003Q4008003U500<003]5000lAP00?TL00P00
?dL00`00@DP004990014BP020016B`030018C000BTd004a=008004m>00<0051>001AC@00DTd00P00
Dd`00`00ED/005I;001HBP02001IB@03001KA`00GDH005m40080065200<006=0001V?@00J3X00P00
JcH00`00Kc80078/001f9P02001k7P0300205000QPP01hd0008079@000<0=ih005bZ002B^0000P3;
]0000`3UI@00o`000?l000050?l000060>EU003;]000bk@009:h001LZP00=ih00P0LU@000`07S@00
08H800205002001k7P03001f9P00LR`006lb008006/f00<006Pj001V?@00Hd000P00HD800`00Gd@0
05e6001KA`02001IB@03001HBP00ET/005E;008005=<00<0059=001AC@00D4h00P00Cdh00`00C4h0
04Y=0018C0020016B`030014BP00@TT00458008003m700<003i7000lAP00>dD00P00>DD00`00>4@0
03M3000f@`02000e@P04000d@P00<d400391000a@080031000<002lo000^?`00;Ch00P00;Ch00`00
;3h002/m000[?@02000Z?08002Tl00@002Pk000W>`009c/002Lk0P009SX2000U>P03000U>@0093T0
02@i00<002<h0P008SP2000R=`80024g00@0020g000P=P0083H0020f0P007cH2000O=@<001he0P00
7CD3000M=0<001`d0P0073<4000K<`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02
ooooo`@001/c0P0073<3000L=0<001dd0P007CD3000N=@8001le0P007cH3000P=P03000P=`008CL0
024g0080028g0P008SP3000S>08002@i00<002Di000U>P009CX00P009SX3000W>`03000X>`00:C`0
02Tl008002Xl0P00:cd01P00;3h002dn000]?P00;Ch002ho000_?`80031000@00350000b@@00<d40
03A20P00=D800`00=T<003M3000hA002000iA@03000kA@00?4H003i7008003m700<004580012B@00
A4X00P00AT/00`00B4`004Y=001<C@02001?CP03001@CP00DDd0059=008005=<00<005E;001FB`00
F4X00P00FDT00`00FdL005e6001OA002001Q@P03001S@000ISd006Pj008006/f00<006lb001b;000
MRH00P00Nah00`00P1@008H800N=000201bD000303NN001LZP00T[P00080bk@000<0iFD00?l0003o
00001@3o00001P3UI@00bk@00<^d002B^000G:X003NN008079D000<01hd000262000P1@00P00Nah0
0`00MRH0078/001_<P02001[=P03001X>P00ISd006=00080065200<005m4001MAP00FdL00P00FDT0
0`00F4X005I;001EB`02001CC003001BC@00DDd0051>008004m>00<004a>001:C@00B4`00P00AT/0
0`00A4X004990011B002000oA`03000nA`00?4H003]5008003U500<003Q4000g@`00=T<00P00=D80
1000=48003=1000b@@00<D02000`@003000_?`00;Sl002dn008002dn00<002`n000[?@00:cd00P00
:S`2000Y?004000X>`009c/002Lk000W>`8002Hj0P009CX00`009CT002@i000T>@03000S>080028h
0P008SL2000Q=`04000P=`0083H0020f000P=P8001lf0P007cD3000N=@8001de0`007C@3000L=080
01`c10006c<5ooooo`7o00000Oooool001_ooooo0_l00003ooooo`@001/c00<001`c000L=00073@0
0P0073@3000M=0@001he00@001le000O=P007cH001lf100083H3000Q=`80028g00<0028h000S>000
8cP00`0093T2000U>@<002Hj00<002Lj000W>`00:3/00P00:3/01`00:C`002Xl000Z?@00:Sd002/m
000/?@00;3h00P00;Ch00`00;Sl002lo000_?`02000`@004000a@000<T4003=1000d@P8003E300<0
03I3000hA000>D@00P00>TD00`00>dH003e6000nA`020010B0030012B@00@dT004E:008004M;00<0
04U<001;C@00CTh00P00Cdh00`00D4h0055=001CC@02001DC003001EB`00EdX005Q9008005Y800<0
05a7001NA@00H4<00P00HT400`00I3l006Ll001Y>@02001]=@03001`<000M2X007PS008007dK00<0
088@00280`0=S`000P0TU`000`11X@00Jjh00:Jm00020=:S00030>i6003o0000o`0000D0o`0000H0
kTH00=:S003BX`00Y[d006^^0011X@0202BG000300f?0000R0<0088@008007dK00<007PS001d:P00
L3000P00KCD00`00JST006Ll001T?`02001R@@03001P@`00GTD005a7008005Y800<005Q9001GBP00
ED/00P00E4`00`00Ddd0055=001@CP02001?CP03001>CP00Bdd004U<008004M;00<004E:0013B@00
@TT00P00@4P00`00?TL003e6000kAP02000jA@03000iA000>4@003I3008003E300@003A2000c@@00
<T4003500P00<402000_?`06000^?`00;Ch002dn000/?P00;3d002/m0P00:Sd00`00:S`002Tl000X
>`02000X>`03000W>`009cX002Hj008002Hj0P009CT3000T>@8002<h00<0028h000R=`008SL00`00
8CL4000P=P<001lf00<001le000N=@007SD00P007SD3000M=0@001`d00<001`c000K<`006c<00P00
6c<4ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_ooool2000K<`<001`c0P0073@4
000M=0D001he00@001le000O=P007cH001lf0P0083H4000Q=`03000R=`008SP0028h00<002<h0`00
93T00`009CT002Dj000V>P02000V>P8002Lk0P00:3/2000Y?005000Z?000:cd002/m000[?@00;3h0
0`00;Ch00`00;Sl002lo000`@002000a@004000b@@00<d4003A2000e@P8003I300<003M3000hA000
>DD00P00>dD00`00?4H003i7000oA`020011B0030012B@00A4X004I;008004Q<00<004Y<001<C@00
CTh00P00D4h00`00DDd0059=001CC002001DC003001FB`00EdX005U9008005]800<005a6001NA@00
H4<00P00Hd000`00ICh006Pk001[=`02001^<`03001a;P00MBP007TP008007hG00<008@<006:000D
TP000P0/VP000`1<Y@00NK800;_200020=R@00030?LS003o0000o`0000D0o`0000H0mb800=R?003H
S`00^l8007Zb001<Y@0202bJ000301BB0001RP0008@<008007hG00<007TP001e:000LBh00P00KS<0
0`00JcL006Pk001U?P02001S@003001P@`00GTD005a6008005]800<005U9001GBP00ET/00P00E4`0
0`00Dd`0059=001AC@02001@CP03001>CP00C4d004Y<008004Q<00<004I;0014BP00@TT00P00@DP0
0`00?dL003i7000lAP02000kA@03000iA@00>4@003M3008003I300@003E2000d@P00<d4003910P00
<D000`00<40002lo000^?`03000]?P05000/?P00:cd002/m000[?@00:S`00P00:C`2000X>`8002Lk
0`009SX00`009CX002Di000T>@02000T>@<002<h0P008SP00`008SL0024g000Q=`02000Q=`80020f
0`007cH00`007cD001he000N=@03000N=@@001dd0P0073@3000L<`8001/c1Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo00@001/c000L<`0073<001`c0P0073@4000M=003000M
=@007SD001he008001he00@001le000O=P007cH001lf0P0083H01@0083L0024g000Q=`008CL0028g
00<0028h0P008cP3000T>@03000U>@009CX002Hj008002Hj00<002Lj000W>`00:3/00P00:3/00`00
:C`002Xl000Z?@02000[?@03000/?@00;3h002dn008002ho00<002lo000`@000<4000P00<D001000
<T4003=2000d@P00=D<2000f@`03000hA000>D@003Y5008003]600<003e6000nA`00@4P00P00@DT0
0`00@dT004E:0017B`020019C003001;C@00CDh004m>0080051>00<0055=001BC@00E4`00P00ED/0
0`00ETX005Q9001JB002001KA`03001MAP00Gd@00652008006@o00<006Hm001Y>P00K3H00P00Kc40
0`00Lb`007LU001k7@020020500300262007S0006i@00080=Id000<0F:P008Vf0038_@000P3ON`09
0?l00080ggX000<0b;d008Vf001HZ0000P0eW@000`0KU0001h`00026200200205003001k7@00MbD0
07</008006la00<006`f001Y>P00ISd00P00I3l00`00HD8005m4001MAP02001KA`03001JB000F4T0
05I:008005E;00<005A<001BC@00DDd00P00D4h00`00Cdh004e>001;C@020019C0030017B`00ADX0
04=90080045900<00418000nA`00?DH00P00>dH00`00>TD003U4000hA002000f@`04000e@`00=480
03=2000b@@8003500P00<4001P00;cl002ho000^?`00;Ch002`n000/?@8002/m00<002Xm000Z?000
:C`00`00:3/00`009c/002Lj000V>P02000V>P03000U>P009CT002@i008002@i0P008cP3000R>005
000R=`008CL0024g000Q=`0083L00P0083H3000O=P03000O=@007SD001he008001he00<001de000M
=0007C@00P007C@2000L=0<001`c00<001/cooooooooool00oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo00@001/c000L<`0073<001`c0P0073@4000M=0@001he00<001le000O
=P007cH0100083H4000Q=`03000R=`008SP002<h008002<h00H002<i000T>@0093T002@i000U>@00
9CX3000V>P03000W>`00:3/002Pk00<002Tl00L002Xl000[?@00:cd002/m000/?P00;Ch002hn0080
02ho00<002lo000`@000<D000P00<T401000<d4003A2000e@P00=T<2000g@`03000hA000>DD003]5
008003a600<003i7000oA`00@DP00P00@TT00`00A4X004I;0018B`02001:C003001<C@00CTh004m>
0080055=00<0059=001CC000E4`00P00ET/00`00EdX005U9001JB002001LAP03001NA@00H4<00691
008006Dn00<006Ll001Z>000KC@00P00L2l00`00M2X007PS001m6P020022400300280`0<S`008YL0
0080?Z0000<0I:`009Zj003=/0000P3VH`090?l00080iV<000<0cK0009Zj001T[0000P0nX0000`0R
U`0038l000280`0200224003001m6P00N2<007@Z0080070_00<006dd001Z>000Ic`00P00ICh00`00
HT400613001NA@02001LAP03001JB000FDT005M:008005I;00<005A<001CC000DTd00P00DDd00`00
Cdh004i>001<C@02001:C0030018B`00AT/004A:0080049900<00458000oA`00?TL00P00?4H00`00
>dD003U5000hA002000g@`04000f@`00=D8003A2000c@@80039100<00350000`@000;cl00P00;Sl0
0`00;Sh002dn000/?P03000[?@04000Z?000:C`002Tl000Y?08002Pk00H002Lk000V>P009SX002Hj
000U>P009CT4000T>@<002<h00<0028h000R=`008CL00`008CL4000P=P8001lf00<001le000N=@00
7SD00P007SD4000M=08001`d0`0073<00`006c?oooooooooo`03ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool00_ooool010006c<001`c000L<`0073<2000L=0@001dd10007SD00`007cD0
01lf000O=P04000P=P@0024g00<0028g000R>0008cP00P008cP01P008cT002@i000T>@0093T002Di
000U>P<002Hj00<002Lk000X>`00:3/00`00:C`01`00:S`002/m000[?@00:cd002`n000]?P00;Sh0
0P00;Sl00`00;cl00310000a@002000b@@04000c@@00=48003E2000f@`8003M300<003Q4000iA@00
>dD00P00?4H00`00?TL003m70011B0020012B@030014BP00AT/004Q;008004Y<00<004a=001>CP00
Cdh00P00DDd00`00DTd005=<001DC002001FB`03001GBP00FDT005Y8008005a600<005i5001P@`00
HT400P00ICh00`00Ic`006Xh001]=002001`;`03001d:P00N2<007dJ0080088@00<008P300b?000R
U`000P0nX0000`1T[000V[X00<f`00020>IS00T0o`000P3VH`000`3=/000V[X006B/000203jP0003
02:G000<S`0008P30080088@00<007dJ001h8`00M2X00P00L2l00`00KC@006Xh001W?002001U?P03
001R@@00H4<005i5008005a600<005Y8001IB@00EdX00P00ET/00`00E4`005=<001BC@02001AC@03
001?CP00CTh004a=008004Y<00<004Q;0016B`00A4X00P00@TT00`00@DP003m7000nA`02000lAP03
000kA@00>DD003Q4008003M300@003I3000e@P00=48003=10P00<T400`00<D000310000_?`02000^
?`03000^?P00;Ch002`n00<002/m00@002Xl000Y?000:C`002Tl0P00:3/01P009c/002Hj000V>P00
9SX002Dj000U>@@002@i0`008cP00`008SP0028g000Q=`03000Q=`@0020f0P007cH00`007cD001he
000N=@02000N=@@001dd0P0073@3000L<`03000K<ooooooooooo00?ooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooo`8001`c0`0073@4000M=003000M=@007SD001he008001he00<0
01le000O=P007cH00`0083H01@0083L0024g000Q=`008CL0028g0080028h0`008cP2000T>@8002Di
00<002Dj000V>P009SX00P009cX00`009c/002Pk000X?002000Y?003000Z?000:Sd002/m008002`m
00<002`n000]?P00;Sl00P00;cl2000`@007000a@@00<T400391000c@P00=48003E3000f@`02000h
A003000iA000>TD003]6008003e600<003i70010B000@DT00P00@dT00`00ADX004M;0019C002001;
C@03001=CP00Cdh0051>0080055=00<0059=001CC000ED/00P00ET/00`00F4X005U9001KA`02001M
AP03001OA000HD8006=0008006Dm00<006Pj001[=`00KS<00P00LBh00`00MBP007TP001n5`020024
3003002:000BT@00:IT00080Aj<000<0L:l00:^n003BX@000P3]B`090?l00080kDX000<0dZ400:^n
001a[`000P17X`000`0YV@004Y40006:000200243003001n5`00NR0007DX0080074^00<006hc001[
=`00J3X00P00ICd00`00Hd000652001OA002001MAP03001KA`00FDT005Q:008005I;00<005E;001C
C000DTd00P00DDd00`00D4h004m>001=CP02001;C@030019C000Ad/004E:008004=900<004590010
B000?TL00P00?DH00`00>dH003Y5000iA002000hA004000f@`00=D<003A2000c@P80039100<00351
000`@000<4000P00;cl00`00;Sl002dn000/?P02000/?@03000[?@00:Sd002Xl008002Tl00<002Pl
000X>`009c/00P009c/2000V>P03000U>P009CT002Di008002@i0`008cP2000R>005000R=`008CL0
024g000Q=`0083L00`0083H2000O=P03000O=@007SD001he00<001he10007C@3000L=08001`c1Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo00@001`c000L=00073@001`d0`00
7C@2000M=@<001he0P007cD2000O=P@0020f10008CL00`008SL0028h000S>002000S>0<002@i0P00
9CT00`009CX002Hj000W>P02000W>`8002Pk0`00:C`00`00:S`002/m000[?@02000/?P03000]?P00
;Sh002ho008002lo00<00310000a@000<T400P00<d401000=48003E2000f@`00=d<2000hA003000i
A@00>dD003a6008003e700<003m70011B000@TT00P00A4X00`00AT/004Q;001:C002001<C@03001>
CP00Cdh0051=0080059=00<005=<001DC000ED/00P00EdX00`00F4T005Y8001LA`02001NA@03001O
A000HT4006@o008006Hl00<006Ti001/=@00Kc400P00Lb`00`00MbD007/N002050020025200300F<
000HT`00<9`00080DJH000<0OK<00;g3003GTP000P3d<0090?l00080m30000<0ei800;g3001m/`00
0P1AYP000`0`W00069<000F<00020025200300205000Nah007LU008007</00<006la001/=@00JCT0
0P00IS`00`00I3l00691001P@`02001NA@03001LA`00FTP005Q9008005M:00<005E;001DC000Dd`0
0P00DTd00`00D4d004m>001>CP02001<C@03001:C000B4/004I;008004A:00<004990011B000?dL0
0P00?DL00`00?4H003]5000iA@02000hA004000g@`00=T<003E2000d@P8003=100<00391000a@000
<4000P00;cl00`00;Sl002hn000]?P02000/?P8002/m00@002Xl000Y?000:C`002Tl0P00:3/2000W
>`03000W>P009SX002Dj008002Di0`0093T3000S>003000R>0008SL0024g00<0024g100083H2000O
=P8001le0`007SD2000M=@<001dd0`0073@00`0073?oooooooooo`03ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_ooool0100073<001`d000L=00073@3000M=0D001he0P007cD2000O
=P<0020f0`008CL2000R=`03000R>0008cP002<h008002<h0P0093T00`009CT002Dj000U>P02000V
>P<002Lk00<002Pk000Y?000:C`00P00:S`00`00:Sd002/m000/?@02000/?P03000]?P00;Sl002lo
00<0031000P00351000b@@00<d8003=2000d@P00=D<003I3000hA08003U400<003Y5000kAP00?DH0
0P00?TL00`00@4P004580013B@020015BP030017B`00BD`004]=008004e>00<004m>001@CP00DDd0
0P00DTd00`00Dd`005E;001FB`02001GBP03001IB@00FdP005a6008005i500<00613001R@@00ICh0
0P00Ic/00`00JSP006dd001`;`02001d:P03001h8`00O1/0084A008008L400<02Xh001jE000hWP00
0P1KZ@000`2;]P00akh00=f200020?/D00T0o`000P3k50000`3MPP00akh008^f000205^Y000303RN
000NU@002Xh0008008L400<0084A001l6`00N2<00P00M2X00`00L2l006dd001Z>002001W>`03001U
?P00HT400613008005i500<005a6001KB000FDT00P00EdX00`00ET/005E;001CC002001BC@03001A
C@00D4h004m>008004e>00<004]=0019C000Ad/00P00ADX00`00@dT004580010B002000nA`03000m
AP00>dH003Y5008003U400@003Q4000f@`00=D<003A20P00<d800`00<T400351000`@002000`@003
000_?`00;Sl002dn008002`n00<002`m000[?@00:Sd00P00:S`2000Y?004000X>`009c/002Lk000W
>`8002Hj0P009CX00`009CT002@i000T>@04000S>003000R>0008SL0028g00<0024g0`0083H2000O
=P8001le1@007SD3000M=0<001`d00<001`cooooooooool00oooool1o`00007ooooo0008ooooo`;o
00001?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`80
01`d10007C@00`007CD001he000N=@02000N=@04000O=@007cH001lf000O=P80020f0P0083L2000Q
=`04000R=`008SP0028h000R>08002<h0`0093T2000U>@<002Hj00<002Lj000W>`00:3/00P00:3/2
000Y?08002Xl0P00:cd01P00;3h002dn000]?P00;Sh002ho000_?`80031000<00350000b@@00<d40
0P00=4801000=D8003I3000g@`00>4@2000iA@03000kA@00?4H003e7008003m700<004180012B@00
A4X00P00ATX00`00Ad/004U<001<C@02001>CP03001?CP00D4h0055=008005==00<005A<001EB`00
EdX00P00F4T00`00FTP005]7001MAP02001OA003001Q@P00Hd0006Hm008006Pj00<006/g001^<`00
LBh00P00MBP00`00NB4007hH00233P020029000300n@000TV000@:400080IJ`000<0V;X00<^d003R
L@003@3o00000`3RL@00bk@009Rj000206F/0003042Q000TV0003i00008008T000<008<=001n6000
NB400P00MBP00`00LBh006hc001[=`02001X>P03001V?@00Hd000652008005m400<005e6001KA`00
FTP00P00F4T00`00EdX005E;001DC002001CC@03001AC@00D4h004m>008004i>00<004a=0019C000
Ad/00P00ATX00`00A4X004990010B002000oA`03000mA`00?4H003]5008003U500@003Q4000g@`00
=T<003E20P00=4800`00<d400391000a@002000`@003000_?`00;Sl002hn008002dn00<002`n000[
?@00:cd00P00:S`2000Y?0<002Pk00<002Lk000W>P009SX00P009SX2000U>@<002@i0P008cP3000R
>003000R=`008CL0024g0080020g0P0083H3000O=P03000O=@007SD001he008001he00<001de000M
=0007C@00P007C@2000L=0Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2000L=0@001dd00<001de000N
=@007SD00P007SD010007cD001lf000O=P007cH2000P=P80020g0P008CL010008SL0028h000R>000
8SP2000S>0<002@i0P009CT3000V>P03000W>P009c/002Pk008002Pk0P00:C`2000Z?08002/m00H0
02`n000]?P00;Ch002hn000^?`00;cl2000`@003000a@000<T4003=1008003A200@003E2000f@`00
=d<003Q40P00>DD00`00>dD003a6000mA`02000oA`030010B000@TT004A:008004I:00<004M;0019
C000C4d00P00CTh00`00Cdh0051>001AC@02001CC@03001DC000ED/005M:008005Q900<005Y8001K
A`00GDH00P00Gd@00`00HD8006=0001V?@02001X>P03001[=`00KS<0074^008007DX00<007TQ001n
6000P`h00P00R@000`0?T00099P0042Q000206F/000309Rj003;]000hW4000d0o`0000<0hW400<^d
002H^P000P1U[0000`10X@0099P000n@00020029000300233@00OQP007TQ008007DX00<0074^001^
<`00JcL00P00J3X00`00ISd006=0001Q@P02001OA003001MAP00FdL005Y8008005Q900<005M:001E
B`00E4`00P00Ddd00`00DDd0051>001?CP02001>CP03001<C@00BD`004M;008004I:00<004A:0012
B@00@4P00P00?dL00`00?DL003a6000kA@02000iA@04000hA000=d<003I3000e@P8003A200<003=1
000b@@00<D000P00<4000`00;cl002ho000^?P02000]?P03000/?P00:cd002/m008002Xl0P00:C`3
000X>`03000W>`009cX002Hj008002Hj0P009CT3000T>@8002<h0`008SP00`008SL0024g000Q=`02
000P=`80020f0`007cH00`007cD001he000N=@02000N=@03000M=@007C@001dd008001dd0P0073@5
ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo00?o0000
ooooooooool00_ooool2000L=0@001dd10007SD010007cD001lf000O=P007cH3000P=P@0024g00<0
028g000R>0008SP00`008cP3000T>@03000U>@009CX002Hj008002Hj0P009c/2000X>`8002Tl00D0
02Xl000Z?@00:Sd002/m000/?@03000]?P03000^?`00;cl003100080031000<00351000b@@00<d80
0P00=4801000=D<003I3000hA000>D@2000jA@03000kAP00?DH003i70080041800<004580013B@00
ADX00P00AT/00`00B4`004Y=001=CP02001?CP03001@CP00DDd0059=008005=<00<005A<001FB`00
EdX00P00FDT00`00FTP005a7001NA@02001P@`03001R@@00I3l006Hl008006Ti00<006`e001_<@00
Lb`00P00MRH00`00Nah007lE00252P0200>;000301BB000ZVP00B:<00080Kjl000<0Y[d00<nZ003W
H0003@3o00000`3WH000cjT00:Jm000206n_000304RS000ZVP00598000800h/000<008D:001o5@00
Nah00P00MRH00`00Lb`006la001/=@02001Y>@03001V?000I3l006910080061300<005i5001LA`00
FTP00P00FDT00`00EdX005I;001DC002001CC003001BC@00DDd0051>008004m>00<004e>001:C@00
B4`00P00AT/00`00ADX004=90011B0020010B003000nA`00?DH003]6008003Y500@003U4000hA000
=T<003E30P00=4800`00<d800391000a@@03000`@003000_?`00;Sl002dn008002dn00D002`m000[
?@00:Sd002Xm000Z?002000Y?08002Pk0P009c/3000V>P03000U>P009CT002@i008002@i0`008cP2
000R>003000R=`008CL0024g0080024g0`0083H3000O=P03000O=@007SD001he008001he10007C@2
000L=0Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Gooooo0_l00003ooooo`03000L=0007C@001dd008001dd1@007SD010007cD001lf000O
=P007cH2000P=P05000P=`008CL0024g000Q=`008SL00`008SP2000S>0<002@i0P009CT3000V>P03
000W>P009c/002Pk008002Pk0P00:C`01P00:S`002/m000[?@00:cd002`n000]?P8002hn00<002ho
000_?`00<4000P00<D000`00<T4003=1000d@P02000e@P04000f@`00=d<003Q4000iA@8003]500<0
03a6000mA`00?dL00P00@4P00`00@TT004A90015BP020017B`030019C000Bdd004e>008004m>00<0
051>001AC@00DTd00P00E4`00`00ED/005I;001HBP02001IB@03001KA`00GDH005i40080061300<0
06=1001U?P00Ic/00P00JSP00`00KC@0070`001d:P02001h9003001l7000PA8008H700801h`000<0
6I@0036L001@YP000P1i/P000`2c`000dil00>a?000=0?l000030>a?003CW`00/l000080NK8000<0
D:H0036L000IU0000P07S0000`00QPL0084B001l7002001h9003001d:P00L30006dd008006Xh00<0
06Lk001U?P00Hd400P00H4<00`00GT@005e6001KA`02001IB@03001HBP00ET/005E;008005A<00<0
059=001AC@00D4h00P00Cdh00`00CTh004]=0019C0020017B`030015BP00A4T004990080041800<0
03m7000mA`00?4H00P00>dD01000>DD003Q4000g@`00=T<2000e@P03000d@P00<d40039100800350
00<00310000_?`00;Sl00P00;Sh00`00;Ch002`n000[?@02000[?@03000Z?000:C`002Tl00<002Pk
00<002Lk000W>P009SX00P009SX2000U>@<002@i0P008cP3000R>005000R=`008CL0024g000Q=`00
83L00P0083H3000O=P03000O=@007SD001he00<001he10007C@00`0073Coooooooooo`02ooooo`;o
00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00;ooooo10007C@00`007CD001he000N=@02000N=@03000O=@007cH001lf00@0
020f10008CL00`008SL0028h000S>003000S>0<002@i00<002Di000U>P009SX00P009SX2000W>`06
000X>`00:C`002Tl000Y?000:S`002Xm0P00:cd00`00;3d002dn000]?P02000^?`03000_?`00<400
03100080035000<00391000c@@00=4800P00=D<01000=T<003M4000iA000>TD2000kAP03000lAP00
?TL003m80080045800<004=90014BP00AT/00P00B4`00`00BT`004a=001>CP02001?CP03001@C@00
DTd005=<008005A<00<005E;001GBP00F4T00P00FTP00`00FdL005e6001OA002001Q@P03001S@000
ISd006Pj008006/g00<006hc001a;P00MBP00P00NB800`00OAT0088?00280`0200^>000301jE000g
WP00F:P00080Pk@000<0`L@00=ND003`?`003@3o00000`3`?`00ei@00<74000208Bd000305RX000g
WP007YD000802hh000<008P300223`00OAT00P00NB800`00MBP0074^001^<`02001[=`03001X>P00
ISd006=00080065200<005m4001MA@00FdL00P00FTP00`00F4T005M:001EB`02001DC003001CC000
DTd0051=008004m>00<004i>001<C@00BT`00P00B4`00`00AT/004A:0013B@020011B003000oB000
?TL003a6008003]600@003Y5000iA000=d@003I30P00=D<00`00=48003=1000b@@02000a@@800310
00<002lo000^?`00;Sl00P00;Ch01@00;3d002/m000[?@00:Sd002Xl00<002Tl00<002Pk000W>`00
9c/00`009SX00`009CX002Di000T>@02000T>@@002<h00<0028h000R=`008CL00`008CL4000P=P80
01lf00<001le000N=@007SD00P007SD00`007CD001dd000M=002000M=0Gooooo0Ol00001ooooo`00
1oooool01?l0003oooooooooool00009ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`@0
01dd1@007SD00`007cD001lf000O=P03000P=P05000P=`008CL0024g000Q=`008SL00P008SP3000S
>08002@i0P009CT00`009CX002Hj000V>P02000W>P03000W>`00:3/002Pk008002Tl0P00:S`3000[
?@03000/?P00;Ch002hn008002ho00<002lo000`@000<D000P00<T400`00<d4003A2000e@P02000f
@`04000g@`00>4@003U5000jA@8003a600<003e6000oA`00@4P00P00@TT00`00@dT004E:0017B`02
0019C003001;C@00CDh004m>0080051>00<0055=001BC@00Dd`00P00ED`00`00ET/005M:001IB@02
001JB003001LAP00GTD006130080069100<006@o001V?000JCT00P00K3H00`00Kc40078/001f9`02
001j7`03001n5`00Q0d008T000803i0000<08iL003fP001OZP000P2=]`000`37_`00fXX00?@_000=
0?l000030?@_003JRP00akl00080S[L000<0H:/003fP000SU`000P0?T0000`00R@0008@<001n5`02
001j7`03001f9P00LR`006la008006`f00<006Ti001V?000I3l00P00HT400`00H4<005i5001LAP02
001JB003001IB@00EdX005I;008005E<00<005=<001BC@00DDd00P00D4h00`00Cdh004e>001;C@02
0019C0030017B`00ADX004=90080049900<00418000oA`00?DH00P00?4H01000>TD003U5000hA000
=d<2000f@`03000e@P00=48003=10080039100<00350000`@000;cl00P00;Sl00`00;Sh002dn000/
?P03000[?@8002Xl0P00:C`2000X>`03000W>`009cX002Lj008002Hj00<002Dj000U>@009CT00P00
93T3000S>080028h00<0028g000Q=`008CL00P008CL3000P=P8001lf00<001le000N=@007SD00`00
7SD4000M=0Gooooo0Ol00001ooooo`002?ooool2o`0000_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`@001dd1@007SD00`007cD001lf000O=P03000P=P05000P=`008CL0
024g000Q=`008SL00P008SP3000S>08002@i0P009CT00`009CX002Hj000V>P02000W>P03000W>`00
:3/002Pk008002Tl0P00:S`3000[?@03000/?P00;Ch002hn008002ho00<002lo000`@000<D000P00
<T400`00<d4003A2000e@P02000f@`04000g@`00>4@003U5000jA@8003a600<003e6000oA`00@4P0
0P00@TT00`00@dT004E:0017B`020019C003001;C@00CDh004m>0080051>00<0055=001BC@00Dd`0
0P00ED`00`00ET/005M:001IB@02001JB003001LAP00GTD006130080069100<006@o001V?000JCT0
0P00K3H00`00Kc40078/001f9`02001j7`03001n5`00Q0d008T000803i0000<08iL003fP001OZP00
0P2=]`000`37_`00fXX00?@_000=0?l000030?@_003JRP00akl00080S[L000<0H:/003fP000SU`00
0P0?T0000`00R@0008@<001n5`02001j7`03001f9P00LR`006la008006`f00<006Ti001V?000I3l0
0P00HT400`00H4<005i5001LAP02001JB003001IB@00EdX005I;008005E<00<005=<001BC@00DDd0
0P00D4h00`00Cdh004e>001;C@020019C0030017B`00ADX004=90080049900<00418000oA`00?DH0
0P00?4H01000>TD003U5000hA000=d<2000f@`03000e@P00=48003=10080039100<00350000`@000
;cl00P00;Sl00`00;Sh002dn000/?P03000[?@8002Xl0P00:C`2000X>`03000W>`009cX002Lj0080
02Hj00<002Dj000U>@009CT00P0093T3000S>080028h00<0028g000Q=`008CL00P008CL3000P=P80
01lf00<001le000N=@007SD00`007SD4000M=0Gooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`02ooooo`8001dd0P007CD3000N=@8001le0P007cH4000P=P@0024g00<0028g000R>0008cP0
0P008cP3000T>@8002Di00<002Dj000V>P009SX00`009c/01`00:3/002Tl000Y?000:C`002Xl000Z
?@00:cd00P00;3d2000]?P03000^?`00;cl002lo0080031000H00350000b@@00<T4003=1000d@P00
=D<2000f@`04000gA000>D@003Y5000kA@8003a600<003i7000oA`00@DP00P00@TT00`00A4X004I;
0018B`02001:C003001<C@00CTh004m>0080051>00<0055=001BC@00E4`00P00ED/00`00ETX005Q:
001IB@02001KA`03001MAP00GT@00613008006=100<006Dn001W>`00JSP00P00KC@00`00L30007<[
001g9@02001k7@0300205000Q@X00h/000804i4000<0:9T004>R001W[@000P2G^P000`39^@00gH00
0?PP000=0?l000030?PP003MP000bKP00080UkX000<0Ijd004BR000XV@000P0CT@000`03R`0008D:
00205002001k7@03001g9@00Lb/0070`008006dd00<006Xh001W>`00ICh00P00Hd400`00H4<005i4
001MAP02001KA`03001IB@00F4X005I:008005E;00<005A<001BC@00DDd00P00D4h00`00Cdh004i>
001<C@02001:C0030018B`00AT/004A:0080049900<00458000oA`00?TL00P00?4H01000>dD003Y5
000iA000=d@2000f@`03000e@`00=48003=10080039100<00350000`@000<4000P00;cl00`00;Sl0
02dn000]?P02000/?@03000[?@00:Sd002Xl00<002Tl00@002Pk000W>`009c/002Lk0P009SX00`00
9CX002Di000U>@03000T>@<002<h00<0028h000R=`008CL00`008CL4000P=P8001lf0P007cD3000N
=@8001de0P007C@5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool2000M=0@0
01he0`007cD2000O=P<0020f0`008CL2000R=`80028h0`008cP2000T>@03000U>@009CX002Dj0080
02Hj00<002Lj000W>`009c/00P00:3/01000:C`002Xl000Z?000:S`2000[?@8002`n00<002dn000^
?P00;Sl00P00;cl00`00<4000350000b@@02000c@@03000d@P00=D8003I3008003M300@003Q4000i
A000>TD003a60P00?DH00`00?TL004180011B0020013B@030015BP00Ad/004Q<008004Y=00<004e>
001?CP00D4h00P00DDd00`00DTd005=<001DC002001EB`03001GBP00F4T005Y8008005a700<005e5
001OA000HD800P00Hd000`00ISd006Pj001[=`02001^<`03001a;`00M2T007PS008007`K00<0084B
00261`06S0000P0GT`000`0]V`00BJ@006n_00020:2l00030<bb003PMP00na@000d0o`0000<0na<0
0>1f003</P000P2Q_0000`1_[`00BZ@002fK000201NC000300J<0000QPL0084B008007`K00<007PS
001d:@00LBl00P00KS<00`00JcL006Pj001V?@02001S@003001Q@P00Gd@005e5008005a700<005Y8
001HB@00EdX00P00ED/00`00E4`005=<001BC@02001AC@03001@CP00Cdh004e>008004]=00<004Q<
0017B`00ADX00P00@dT00`00@DT00418000nA`02000mAP04000lAP00>TD003U4000hA08003M300<0
03I3000e@P00=4800P00<d400`00<T400350000`@002000_?`03000^?`00;Sh002dn008002`n0P00
:cd01000:Sd002Xl000Z?000:C`2000X>`8002Lk00<002Lj000V>P009SX00P009CX00`009CT002@i
000T>@03000S>080028h0P008SL3000Q=`<0020f0P007cH3000O=@@001he0P007C@5ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_ooool00`007C@001de000N=@03000N=@04000O=@00
7cH001lf000O=P80020f0P0083L3000Q=`80028g00<0028h000S>0008cP0100093T00`009CT002Dj
000U>P02000V>P<002Lk00<002Pk000Y?000:C`00P00:S`00`00:Sd002/m000/?@02000/?P03000]
?P00;Sl002lo00<0031000L00350000b@@00<d4003=1000d@P00=D8003I3008003M400@003Q4000j
A@00>dD003a60P00?TL00`00?dL004180012B@020014BP030015BP00Ad/004U<008004]=00<004e>
001?CP00D4h00P00DDd00`00DTd005=<001EB`02001FB`03001GBP00FDT005Y8008005a600<005i5
001P@`00HT400P00I3l00`00ISd006Tj001[=P02001^<P03001b;@00MBP007TQ008007dI00<0088@
0027100:SP000P0KU0000`0bW000CjH007Ja00020:Vn00030<j/003SKP00o@T000d0o`0000<0o@P0
0>=^003>[0000P2Y_P000`1f/@00CjH003:L000201bD000300Z>0000Q`@0088?008007dI00<007TQ
001e:000LRd00P00KS800`00JcH006Tj001V?@02001T?`03001R@@00H4<005i5008005a600<005Y8
001IB@00EdX00P00ET/00`00ED/005=<001BC@02001AC@03001@CP00Cdh004i>008004]=00<004U<
0017B`00ADX00P00A4X00`00@TT00418000oA`02000nA`04000lAP00>dD003Y5000hA08003M400<0
03I3000e@P00=4800P00<d400`00<T400350000`@002000`@003000_?`00;Sl002dn008002dn00<0
02`m000[?@00:Sd00P00:S`2000Y?004000X>`009c/002Lk000W>`8002Hj0P009CX00`009CT002@i
000T>@02000T>@8002<h00<0028h000R=`008SL00`008CL2000P=`80020f0`007cH00`007cD001he
000N=@02000N=@03000M=@007CCooooo00Cooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`02ooooo`03000M=0007SD001he008001he00@001le000O=P007cH001lf0`0083H4000Q=`03000R
=`008SP0028h00<002<h0`0093T00`009CT002Dj000V>P02000V>P03000W>P009c/002Pk008002Pk
00@002Tl000Z?000:S`002Xl0P00:cd01P00;3h002dn000]?P00;Sh002ho000_?`80031000<00350
000b@@00<d400P00=4800`00=D8003I3000g@`02000hA004000iA000>TD003]6000mAP8003i700<0
04180011B000@dT00P00A4X00`00AT/004Q<001:C002001<C@03001>CP00Cdh0051=0080055=00<0
05==001DC000ED/00P00ETX00`00F4X005U8001KA`02001MAP03001NA000H4<00691008006Dn00<0
06Ll001Z>@00K3D00P00Kc400`00Lb`007HV001j7`02001n5`0300233@00R@403Hl000807iH000<0
=ih005FW001l/`000P2a`0000`3@YP00iFL00?l0000>0?l000070>EW003@YP00/L000;70001l/`00
EJL003NN000201nF000300f?0000R@4008<=008007hG00<007XO001f9P00Lb`00P00Kc400`00K3D0
06Xi001W?002001U?P03001R@@00H4<005i4008005e600<005]7001IB000F4X00P00ETX00`00ED/0
05A<001CC002001AC@03001@C@00Cdh004i>008004a=00<004Y<0018C000AT/00P00A4X00`00@dT0
04580010B002000nA`04000mAP00>dH003Y5000iA08003Q400<003M3000f@`00=D800P00=4800`00
<d400391000a@002000`@003000_?`00;Sl002hn008002dn00<002`n000[?@00:cd00`00:S`01P00
:C`002Pk000X>`00:3/002Lk000W>P<002Hj00<002Dj000U>@0093T00P0093T3000S>080028h00<0
028g000Q=`008CL00P008CL3000P=P<001lf00<001le000N=@007SD00P007SD00`007CCooooooooo
o`03ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool00`007C@001he000N=@02
000N=@04000O=@007cH001lf000O=P<0020f10008CL00`008SL0028h000R>003000S>0<002@i00<0
02Di000U>P009SX00P009SX00`009cX002Lk000X>`02000X>`04000Y?000:S`002Xl000Z?08002/m
00H002`n000]?P00;Ch002hn000^?`00;cl2000`@003000a@000<T4003=1008003A200<003E2000f
@`00=d<00P00>4@01000>D@003Y5000kAP00?DH2000nA`030010B000@DP004=9008004A:00<004I;
0018C000BT`00P00C4d00`00CTh004m>001@C@02001AC@03001CC@00E4`005E;008005I:00<005Q:
001IB000FdL00P00GDH00`00GT@00613001R@@02001U?P03001W?000JST006`e008006la00<007</
001f9P00NQl00P00OQL00`00P`d008T100f?000201nF000303NN001EY`00O;<00080/L0000<0d:H0
0>EW003o00003P3o00001`3UI`00d:H00;70002a`000O;<005FW000gWP000P0OUP000`0=S`0008T1
00233@02001n5`03001j7`00MRH007</008006la00<006`e001Z>@00Ic`00P00ICh00`00HT400613
001NA002001MAP03001KA`00FDP005Q:008005I:00<005E;001DC000Dd`00P00DDd00`00D4d004m>
001>CP02001<C@03001:C000B4`004I;008004A:00<004=90011B000@4P00P00?TL01000?DH003]6
000jA@00>D@2000hA003000g@`00=T<003E2008003A200<003=1000b@@00<D000P00<4000`00;cl0
02ho000^?P02000]?P03000/?P00:cd002/m00<002Xl00H002Tl000X>`00:3/002Pk000W>`009cX3
000V>P03000U>P009CT002@i008002@i0`008cP2000R>003000R=`008CL0024g0080024g0`0083H3
000O=P03000O=@007SD001he008001he00<001ddooooooooool00oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00;ooooo1@007SD010007cD001lf000O=P007cH2000P=P04000P=`008CL0
024g000Q=`80028g0P008SP2000S>0@002@i00<002Di000U>P009SX00P009SX2000W>`8002Pk0P00
:C`01P00:S`002Xm000Z?@00:cd002`m000/?P8002dn00<002ho000_?`00<4000P00<4000`00<D00
0391000c@@02000d@P03000e@P00=T<003M3008003Q400@003U5000kA@00?4H003e70P00?dL00`00
@4P004990013B@020015BP030017B`00BD`004]=008004e>00<004m>001@CP00DDd00P00DTd00`00
Dd`005A<001FB`02001GBP03001HB@00FTP005]7008005e600<005m4001Q@P00Hd000P00ICh00`00
J3/006Xh001]=002001`<003001c:`00MbD007/M008007lE00<008@;006:000@T0000P0SU`000`0k
W`00FZT008>d00020;W200030=:Q003WH@00o`0000h0o`0000L0if400=:Q002i`P00^L8008>d001J
Z@00>il000808iL000<04900006:0000Q0/00P00OaD00`00Nad007LU001c:`02001`<003001]=000
JSP006Pk008006Dn00<006=0001Q@P00Gd@00P00GDH00`00FdL005Y8001HB@02001GBP03001FB`00
E4`005=<0080059=00<0055=001@CP00Cdh00P00CDh00`00Bdd004U<0017B`020015BP030013B@00
@TT00418008003m700@003e7000lAP00>dD003U50P00>4@00`00=d@003I3000e@P02000d@P03000c
@@00<T40035000<0031000L002lo000^?`00;Ch002dn000/?P00;3d002/m008002Xm00<002Xl000Y
?000:C`00P00:3/2000W>`<002Hj00<002Dj000U>@0093T00`0093T2000S>0<0028h00D0028g000Q
=`008CL0024g000P=`02000P=P<001lf00<001le000N=@007SD00`007SD5ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_ooool4000N=@03000O=@007cH001lf00@0020f10008CL00`00
8SL0028h000S>003000S>0<002@i00<002Di000U>P009SX00P009SX00`009cX002Lk000X>`02000X
>`03000Y?000:S`002Xl00<002/m00L002`n000]?P00;Sh002hn000^?`00;cl00310008003500P00
<T401P00<d8003A2000d@P00=D<003I3000hA08003U400@003Y5000kAP00?4H003i70P00?dP00`00
@DP004990014BP020016B`030018B`00BT`004a=008004i>00<004m>001@CP00DDd00P00DTd00`00
Dd`005E;001FB`02001GBP03001IB@00FTP005a6008005i500<00613001R@P00I3l00P00ISd00`00
J3X006/g001^<`02001a;P03001d:@00N2<007`L0080080C00<008D800>;000CT@000P0WV0000`0o
X@00GjX008Rf00020;o300030=BM003XG000o`0000h0o`0000L0j5`00=BM002o``00_l<008Rf001O
ZP00?j4000809iT000<04i4000>;0000Q@P00P00P1<00`00O1`007PS001d:@02001a;P03001^<`00
JcL006Pj008006Hm00<006@o001R@P00H4<00P00GTD00`00G4H005Y8001IB@02001GBP03001FB`00
ED/005=<0080059=00<0055=001@CP00Cdh00P00CTh00`00C4d004Y<0018B`020016B`030014BP00
@TT00458008003m800@003i7000mAP00>dH003Y50P00>D@00`00>4@003I3000e@`02000d@P03000c
@P00<d4003910080035000<00310000_?`00;Sl00P00;Sh00`00;Ch002`n000[?@02000[?@8002Xl
00H002Tl000X>`00:3/002Pk000W>`009cX3000V>P03000U>P009CT002@i008002@i10008cP00`00
8SP0028g000Q=`03000Q=`@0020f0P007cH00`007cD001he000N=@02000N=@Gooooo0Ol00001oooo
o`006oooool2o`0000?ooooo10007SD00`007cD001lf000O=P03000P=P05000P=`008CL0024g000Q
=`008SL00P008SP3000S>0@002@i00<002Di000U>P009SX00P009SX2000W>`06000X>`00:C`002Tl
000Y?000:S`002Xm0P00:cd00`00;3d002`n000]?P02000^?`8002lo00H00310000a@000<D000391
000c@@00=482000e@P03000f@`00=d<003Q4008003U500@003Y5000lAP00?DH003i70P00@4P00`00
@DT004=90015BP020016B`030018C000BTd004a=008004i>00<004m>001@C@00DTd00P00Dd`00`00
E4`005E;001FBP02001HBP03001IB@00FdL005e6008005i500<00613001R@@00I3l00P00Ic`00`00
JCT006`f001_<P02001b;@03001e:000NB8007dJ0080084A00<008H600J<000FTP000P0ZVP000`13
XP00Hj`008fg00020<C400030=FJ003YF@00o`0000h0o`0000L0jET00=FJ0034a000a<@008fg001T
[000@j800080:YX000<05Y8000J<0000QPH00P00PA400`00OAX007TR001e:002001b;@03001_<P00
K3H006Ti008006Ll00<006@o001R@@00H4<00P00GTD00`00GDH005]7001IB@02001HBP03001FBP00
ED/005A<008005=<00<0059=001@C@00Cdh00P00CTh00`00C4d004Y=0018C0020016B`030015BP00
@dT004590080041800@003i7000mAP00?4H003Y50P00>DD00`00>4@003M3000f@`02000e@P03000d
@P00<d4003910080035000<00310000_?`00;cl00P00;Sl00`00;Ch002`n000/?@02000[?@03000Z
?@00:S`002Tl008002Tl00<002Pk000W>`009c/00`009SX00`009CX002Di000T>@03000T>@<002<h
0P008SP01@008SL0024g000Q=`008CL0020g00<0020f0P007cH00`007cD001he000N=@02000N=@Co
oooo0_l00001ooooo`006oooool00ol0003oooooooooo`02ooooo`8001he0P007cD2000O=P@0020f
10008CL00`008SL0028h000S>003000S>08002@i0P009CT00`009CX002Hj000V>P02000W>P03000W
>`00:3/002Pk00<002Tl00D002Xl000[?@00:cd002/m000/?P02000]?P8002ho00<002lo000`@000
<D000P00<D400`00<T4003=2000d@P02000e@`03000f@`00=d@003U4008003Y500@003]5000lAP00
?TL003m70P00@4P00`00@TT004A:0015BP020017B`030019C000Bdd004e>008004m>00<0051>001A
C@00DTd00P00Dd`00`00E4`005I;001GBP02001HB@03001JB000FdL005e6008005m400<00652001S
@000ICh00P00Ic/00`00JSP006`e001_<@02001b;003001f9`00NR0007hH0080088?00<008L400R=
000IT`000P0]V`000`17X`00Ijd0096h00020<G200030=JH003YF000o`0000h0o`0000L0jEP00=JG
0035`P00aL8009:h001W[@00Aj<00080;I/000<06I<000R=0000Q`@00P00PPl00`00OQP007XP001f
9`02001b;003001_<@00K3D006Xh008006Lk00<006Dn001S@000HD800P00Gd@00`00GDH005]7001J
B002001HB@03001GBP00ET/005A<008005=<00<0059=001AC@00D4h00P00Cdh00`00CDh004]=0019
C0020017B`030015BP00A4X004990080041800@003m7000nA`00?4H003]50P00>TD00`00>D@003M4
000f@`02000e@`03000d@P00<d8003910080035100<00350000`@000;cl00P00;Sl2000]?P05000/
?P00:cd002/m000[?@00:S`00`00:C`2000X>`03000W>`009cX002Lj008002Hj00<002Dj000U>@00
9CT00P0093T4000S>003000R>0008SL0024g00<0024g100083H2000O=P8001le0P007SD5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_ooool2000N=@8001le0P007cH4000P=P@0024g
00<0028g000R>0008cP00`008cP2000T>@8002Di00<002Dj000V>P009SX00P009cX00`009c/002Pk
000X>`03000Y?005000Z?000:cd002/m000[?@00;3h00P00;Ch2000^?`03000_?`00<40003500080
035100<00391000c@P00=4800P00=D<00`00=T<003M4000iA002000jA@04000kA@00?4H003i7000o
A`80041800<004990014BP00ADX00P00Ad/00`00BD`004]=001=CP02001?CP03001@CP00DDd0059=
008005=<00<005A<001FB`00EdX00P00F4T00`00FTP005]7001MAP02001OA003001Q@P00Hd0006Dn
008006Lk00<006Xh001/=@00Kc400P00LR`00`00MRL007XP001n600200223`0300271008S@006I<0
0080;I/000<0Aj<006N]002A^0000P35`P000`3FV000jEP00?l0000>0?l000070>UH003FU`00aL80
0<G2002B^000Ijd004NS000202fK000301VC0008S@0008L40080088?00<007hH001j8000MRL00P00
LR`00`00Kc4006`e001Z>002001W>`03001U?P00Hd000652008005m400<005e6001KA`00FTP00P00
F4T00`00EdX005I;001DC002001CC003001BC@00DDd0051>008004m>00<004e>001;C@00BD`00P00
Ad/00`00ADX004A:0012B@020010B004000oA`00?TL003a6000kA@8003Y500<003U4000gA000=T<0
0P00=D<00`00=48003=2000b@@02000a@@03000a@000<40002lo008002ho0P00;Ch01@00;3h002/m
000[?@00:cd002Xl00<002Tl0P00:3/00`009c/002Lj000W>P02000V>P03000U>P009CT002Di0080
02@i10008cP00`008SP0028g000Q=`03000Q=`@0020f0P007cH2000O=@8001he1Oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo0P007SD2000O=@8001lf0`0083H00`0083L0024g
000Q=`02000R=`80028h0`008cP3000T>@8002Di00<002Dj000V>P009SX00`009c/01`00:3/002Tl
000Y?000:C`002Xl000Z?@00:cd00P00;3d00`00;3h002dn000^?`03000_?`07000`@000<D000391
000b@@00<d4003A2000e@P02000f@`03000g@`00>4@003U4008003Y500@003]6000mAP00?TL00418
0P00@DP00`00@dT004A:0016B`020018B`03001:C000C4d004i>008004m>00<0051>001AC@00DTd0
0P00Dd`00`00ED/005I;001GBP02001IB@03001JB000G4L005i5008005m400<00652001S@000ICd0
0P00J3/00`00JSP006dd001`<002001c:`03001g9@00NQl007lG008008<=00<008P200^>000KU000
0P0`W0000`1:Y000Jjh009Fi00020<K000030=JF003YF000o`0000h0o`0000L0jEP00=JF0036`000
a/0009Fi001[[P00BZ@00080<9`000<06i@000^>0000R0800P00P`d00`00OaL007XO001g9@02001c
:`03001`<000KC@006Xh008006Pk00<006Dm001S@000HD800P00Gd@00`00GTD005a7001JB002001I
B@03001GBP00ET/005E;008005=<00<0059=001AC@00D4h00P00Cdh00`00CTh004a=001:C0020018
B`030016B`00A4X004=90080045800@00418000nA`00?DH003]60P00>TD00`00>D@003Q4000g@`02
000f@`03000e@P00=48003=10080039100<00350000`@000;cl00P00;cl00`00;Sl002dn000/?P02
000/?@03000[?@00:Sd002Xl00<002Tl00@002Pk000W>`009c/002Lk0P009SX00`009CX002Di000U
>@03000T>@<002<h0P008SP2000R=`80024g00@0020g000P=P0083H0020f0P007cH2000O=@8001he
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo00<001he000O=@007cH00P00
7cH4000P=P<0024g0P008SL00`008SP002<h000S>002000S>08002@i00<002Di000U>P009CX00P00
9SX00`009cX002Lk000W>`02000X>`<002Tl00<002Xl000[?@00:cd00P00;3h2000]?P06000^?`00
;cl002lo000`@000<D0003510P00<T400`00<d4003A2000e@P02000f@`03000gA000>4@003U50080
03]500@003a6000mA`00?dL004180P00@TT00`00@dT004E:0017B`020019C003001:C@00CDh004i>
008004m>00<0051=001BC@00Dd`00P00E4`00`00ED/005I:001HBP02001IB@03001KB000G4H005i5
0080061300<00691001T?`00ISd00P00J3X00`00JcL006hc001a;`02001d:P03001g9000Nad007lE
008008@<00<008T000f?000NU@000P0cW@000`1=Y@00KZl009Rj00020<No00030=JF003YFP00o`<0
00d0o`0000<0o`<00>UJ003FUP000P37_`000`2H^P00KZl004fU000203>M000301jE000=S`0008T0
008008@<00<007lE001k7@00Mb@00P00M2X00`00LBl006hc001[=`02001X>P03001V?@00I3l00691
0080061300<005i5001LAP00FdP00P00FDT00`00F4X005I:001EB`02001DC003001CC000DTd0051=
008004m>00<004i>001=CP00Bdd00P00BD`00`00Ad/004E:0013B@020012B@040010B000?dL003e7
000lAP8003]500<003Y5000hA000=d@00P00=T<00`00=D8003A2000c@@02000b@@03000a@@00<D00
0310008002lo00<002ho000]?P00;Ch00P00;3h2000[?@04000Z?000:C`002Tl000Y?08002Pk0P00
9c/00`009cX002Hj000V>P02000U>P03000U>@0093T002@i00@002<h00<0028h000R=`008SL00`00
8CL4000P=P<001lf00<001le000N=Oooool01?ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00;ooooo0P007cD3000O=P80020f0P0083L2000Q=`04000R=`008SP0028h000R>08002<h1000
93T00`009CT002Dj000U>P02000V>P<002Lk00<002Pk000Y?000:C`00P00:S`00`00:Sd002/m000/
?@02000/?P03000]?P00;Sl002ho008002lo00<00310000a@000<T400P00<d400`00=48003E2000f
@`02000g@`03000hA000>D@003Y5008003]600@003a6000nA`00?dL004580P00@TT00`00A4X004I:
0017B`020019C003001;C@00CDh004m>0080051>00<0055=001BC@00Dd`00P00E4`00`00ED/005M:
001HB@02001JB003001KA`00GDH005i40080061300<00691001T?`00Ic`00P00JCT00`00JcH006hb
001a;P02001d:@03001h8`00O1`0080D008008D:00<00HX000n@000PUP000P0eW@000`1?YP00L:l0
09Zj00020<Nn00030=JF003XG@00o@`000d0o`0000<0o@`00>QM003FUP000P37_P000`2J^P00L:l0
04nV000203FM0003022F000?T0000HX0008008D:00<0080D001l7000N2<00P00M2T00`00LBh006hb
001[=P02001Y>@03001W?000I3l006910080061300<005i4001MAP00FdL00P00FTP00`00F4T005M:
001EB`02001DC003001CC000DTd0055=0080051>00<004m>001=CP00Bdd00P00BD`00`00Ad/004I:
0014BP020012B@040011B000?dL003i7000lAP8003]600<003Y5000iA000>4@00P00=d<00`00=T<0
03E2000d@P02000c@@03000b@@00<D000310008002lo0P00;Sl01P00;Ch002`n000/?P00;3d002/m
000Z?@8002Xl0P00:C`01000:3/002Lk000W>`009c/2000V>P8002Dj00<002Di000T>@0093T00P00
93T2000S>0<0028h00<0028g000Q=`008CL00P0083L2000P=P<001lf0P007cD5ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_ooool010007cD001lf000O=P007cH3000P=P@0024g00<0
028g000R>0008SP00`008cP3000T>@03000U>@009CX002Hj008002Hj00<002Lj000W>`00:3/00P00
:3/2000Y?08002Xl0P00:cd01P00;3h002dn000]?P00;Ch002ho000_?`<0031000L00350000b@@00
<d4003=1000d@P00=D8003I3008003M300<003Q4000iA@00>TD00P00?4H01000?DH003i70010B000
@DP20013B@030014BP00AT/004Q<008004Y<00<004a=001>CP00Cdh00P00D4h00`00DDd0059=001C
C002001EB`03001FB`00EdX005U9008005Y800<005a7001MAP00Gd@00P00HD800`00Hd0006Dn001W
?002001Y>@03001/=@00Kc40078]008007DX00<007TR001l6`00PA800P00Q@P00`02R`004I0002:G
000203NN0003056V001b/000VkX00080akh000<0eIP00>IQ003j5P003@3o00000`3j5P00iV400=JH
00020<Nn000309^j001b/000DJH00080=ih000<08YL0016@0002R`000P00Q@P00`00PA8007`K001i
8P02001e:003001b;@00Kc4006`e008006Ti00<006Ll001U?P00Hd000P00HD800`00Gd@005e6001L
A`02001JB003001IB@00EdX005I;008005E;00<005=<001BC@00DDd00P00D4h00`00Cdh004i>001<
C@02001:C0030018C000AT/004A:008004=900@004580010B000?TL003e60P00?4H00`00>TD003U5
000hA002000g@`03000f@`00=D8003A2008003=100<00391000a@000<4000P00<4000`00;cl002ho
000]?P02000]?P03000/?P00:cd002/m008002Xl0P00:C`3000X>`03000W>`009cX002Hj008002Hj
00<002Dj000U>@0093T00P0093T3000S>080028h00<0028g000Q=`008CL00P008CL3000P=P<001lf
00<001leooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo00@0
01le000O=P007cH001lf0`0083H4000Q=`03000R=`008SP0028h00<002<h0`0093T00`009CT002Dj
000V>P02000V>P03000W>P009c/002Pk008002Pk0P00:C`2000Z?08002/m00H002`n000]?P00;Ch0
02dn000^?`00;cl3000`@007000a@000<T4003=1000c@@00=48003E2000f@`02000g@`03000hA000
>DD003Y5008003a600@003e6000nA`00@4P004580P00@dT00`00A4X004I;0018C002001:C003001<
C@00CTh004m>0080051>00<0055=001BC@00Dd`00P00ED/00`00ET/005M:001IB@02001JB003001L
A`00GDH005m40080065200<006=0001U?P00Ic`00P00JCT00`00K3D006la001b;@02001e:003001i
8P00O1/0084B008008D800<00X/0016@000RU`000P0gWP000`1AYP00L[0009^j00020<Nn00030=FH
003VH@00nQH000d0o`0000<0nQH00>IQ003FV0000P37_P000`2K^P00L[00056V000203NN000302:G
000AT0000X/0008008D800<0084B001l6`00NB800P00MBP00`00LRd006la001/=@02001Y>@03001W
?000ICh006=00080065200<005m4001MAP00G4L00P00FTP00`00FDT005M:001FB`02001EB`03001C
C000DTd0055=0080051>00<004m>001>CP00C4d00P00BT`00`00B4`004I;0014BP020013B@040011
B000@4P003i7000mAP8003a600<003Y5000iA@00>4@00P00=d<00`00=T<003E2000d@P02000c@@03
000b@@00<D0003100080031000<002lo000^?`00;Ch00P00;Ch00`00;3h002/m000[?@02000Z?080
02Tl0`00:3/00`009c/002Lj000V>P02000V>P03000U>P009CT002@i008002@i0`008cP2000R>003
000R=`008CL0024g0080024g0`0083H3000O=P03000O=Ooooooooooo00?ooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`02ooooo`04000O=@007cH001lf000O=P80020f00D0020g000Q=`00
8CL0024g000R=`03000R>08002<h100093T00`009CT002Dj000V>P02000V>P8002Lk0P00:3/2000Y
?006000Z?000:Sd002Xm000[?@00;3d002`n0P00;Ch00`00;Sh002ho000_?`02000`@003000a@000
<T400391008003=200<003A2000e@`00=T<00P00=d@00`00>D@003Y5000kA@02000lAP04000mA`00
?dL004180012B@8004=900<004E:0017B`00BD`00P00Bdd00`00CDh004i>001?CP02001@C@03001A
C@00Ddd005A<008005E;00<005I;001HBP00FDT00P00FTP00`00G4L005i5001OA002001Q@P03001S
@000ICh006Pk008006Xh00<006de001_<@00LR`00P00MRL00`00NB4007dJ00214@0200261`0300B;
000BT@008iL00080>Il000<0DjL007>`002K^`000P37_`000`3EVP00iFL00?LR000=0?l000030?LR
003UI`00eIX00080akl000<0Vk/007>`001CY`000P0iW`000`0TU`004Y4000B;000200261`030021
4@00OAX007TQ008007HW00<0078/001_<@00KCD00P00JSP00`00J3/006Dn001S@002001Q@P03001O
A000GTD005a7008005Y800<005U9001HBP00ET/00P00ED/00`00E4`005==001AC@02001@C@03001?
CP00CTh004e>008004]=00<004U<0017B`00ADX00P00@dT01000@TT00418000oA`00?DL2000lAP03
000kA@00>TD003U4008003M400<003I3000e@`00=4800P00<d82000b@@06000a@000<4000310000_
?`00;Sl002hn0P00;Ch00`00;3h002`m000[?@02000Z?@03000Z?000:C`002Tl008002Pk0P009c/3
000V>P03000U>P009CT002@i00<002@i0P008cP3000R>005000R=`008CL0024g000Q=`0083L00P00
83H3000O=P03000O=Ooooooooooo00?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02
ooooo`8001lf100083H4000Q=`03000R=`008SP002<h00<002<h0`0093T00`009CT002Dj000V>P02
000V>P03000W>P009c/002Pk008002Pk0P00:C`01@00:S`002/m000[?@00:cd002`m00<002dn00<0
02ho000_?`00;cl00P00<4000`00<D000391000c@@02000d@P03000e@P00=T<003M3008003Q400<0
03U4000jA@00>dH00P00?DH01000?TL003m80011B000@TT20014BP030016BP00Ad/004U<008004]=
00<004e>001?CP00D4h00P00DDd00`00DTd005=<001DC002001EB`03001GBP00F4T005U9008005]7
00<005a6001NA@00H4<00P00HT400`00I3l006Hm001X>P02001Z=`03001]=000L30007<[008007HV
00<007XP001n6000PQ000P00Q`H00`05S000594002FH000203ZO000305BW001c/000VkX00080a/00
00<0e9d00>=]003d;P003@3o00000`3d;P00hfd00=BM00020<K0000309^j001c/000E:L00080>Yl0
00<09IP001BA0005S0000P00Q`H00`00PQ0007hH001j8002001f9P03001c:`00L30006dd008006/g
00<006Pj001V?@00I3l00P00HT400`00H4<005i5001LAP02001KA`03001IB@00F4T005M:008005E;
00<005A<001CC000DTd00P00DDd00`00D4h004m>001=CP02001;C@030019C000Ad/004I:008004A:
00@004990011B000?dP003i70P00?DH00`00>dH003Y5000iA002000hA003000g@`00=T<003E20080
03A200<003=1000b@@00<D000P00<402000_?`05000^?`00;Ch002dn000]?P00;3d00`00:cd00`00
:S`002Tl000Y?003000X>`03000W>`009cX002Hj008002Hj00<002Dj000U>@0093T00P0093T4000S
>003000R>0008SL0024g00<0024g100083H2000O=PGooooo0Ol00001ooooo`006oooool2o`0000?o
oooo0P007cH3000P=P05000P=`008CL0024g000Q=`008SL00P008SP3000S>0@002@i00<002Di000U
>P009SX00P009SX2000W>`06000X>`00:3`002Pl000Y?000:S`002Xm0`00:cd01`00;3h002dn000^
?P00;Sh002ho000_?`00<4000P00<D000`00<D400391000c@@02000d@P03000e@P00=T<003M40080
03Q400<003U5000kA@00?4H00P00?DH01000?TL004180011B000@dT20015BP030016B`00B4`004Y<
008004a=00<004i>001?CP00D4h00P00DDd00`00DTd005=<001DC002001FB`03001GBP00F4T005Y8
008005]700<005e6001NA000H4<00P00HT400`00I3l006Hm001Y>P02001[=`03001^<`00L2l007<Z
008007LU00<007XO001n5`00PPl00P00Q`D00`06S0005I8002JH000203^O000305BW001c/000VKX0
0080aL8000<0dZ400>5e003a>`003@3o00000`3a>`00hGD00=:Q00020<G2000309Vj001c/000E:L0
0080>il000<09YP001FB0006S0000P00Q`D00`00PPl007hG001j7`02001g9@03001c:P00L2l006hc
008006/g00<006Tj001V?@00I3l00P00HT400`00H4<005i4001MAP02001KA`03001JB000F4T005M:
008005I;00<005A<001CC000DTd00P00DDd00`00D4h004m>001>CP02001<C@03001:C000B4`004I;
008004E:00@004=90011B000@4P003i70P00?DH00`00?4H003]5000iA@02000hA003000gA000=T<0
03E2008003A200<003=1000b@@00<D400P00<D000`00<40002lo000^?`02000^?P03000]?P00;3h0
02/m008002/m00<002Xm000Z?000:C`00P00:3`00`00:3/002Lk000W>`03000V>P03000U>P009CT0
02@i00<002@i0`008cP2000R>005000R=`008CL0024g000Q=`0083L00`0083H2000O=PCooooo0_l0
0001ooooo`006oooool00ol0003oooooooooo`02ooooo`03000O=P0083H0020f0080020f10008CL0
0`008SL0028h000S>003000S>08002@i0P009CT00`009CX002Hj000V>P02000W>P03000W>`00:3/0
02Pk00<002Tl00L002Xl000Z?@00:cd002/m000/?@00;3h002dn008002ho0P00;cl01P00<4000350
000a@000<T4003=1000d@P8003E200<003I3000g@`00>4@00P00>D@00`00>TD003]5000lAP02000n
A`04000oA`00@4P004990013B@8004E:00<004M;0019C000BTd00P00C4d00`00CTh004m>001@CP02
001AC@03001BC@00E4`005E;008005I;00<005M:001IB@00FTP00P00G4L00`00GDH005m4001Q@P02
001S@@03001U?P00Ic`006Ti008006/f00<006hc001a;P00M2X00P00Mb@00`00Nah007lG00233P02
0028100300N=000FTP009iP00080>il000<0E:L007:`002G^P000P34a0000`3AY@00gWd00>e90002
0?d900T0o`000P3m2@000`3]B@00gW`00=6U00020<G4000309Nj001b/000E:L00080>il000<09iP0
01JB0007S@000P00R0@00`00P`h007lG001k7P02001g9003001d:P00LBh006hc008006/f00<006Ti
001W?000ICh00P00Hd400`00HD8005m4001MAP02001LA`03001JB000FDT005M:008005I;00<005E;
001DC000DTd00P00DDd00`00D4h004m>001>CP02001<CP03001:C@00BD`004M;008004E:00@004=9
0012B@00@4P003m70P00?TL00`00?4H003]5000jA@02000iA003000hA000=d<003I3008003E200<0
03A2000c@@00<T400P00<D000`00<40002lo000_?`02000^?`03000]?P00;3h002`m008002/m00<0
02Xm000Z?000:C`00P00:C`2000X>`03000W>`009cX002Lj008002Hj00<002Dj000U>@009CT00P00
93T4000S>003000R>0008SL0024g00<0024g100083H00`007cKoooooooooo`03ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_ooool00`007cH0020f000P=P02000P=P@0024g00<0028g
000R>0008cP00`008cP2000T>@8002Di00<002Dj000V>P009SX00P009cX00`009c/002Pk000X>`03
000Y?007000Z?000:Sd002/m000[?@00;3d002`n000]?P02000^?`8002lo00H00310000a@000<D00
0391000c@@00=482000e@P03000f@`00=d<003Q4008003U400<003Y5000kA@00?4H00P00?TL01000
?dL004180012B@00@dT20015BP030017B`00BD`004Y=008004a=00<004i>001?CP00D4h00P00DDd0
0`00DTd005A<001EB`02001FB`03001GBP00FDT005Y8008005a700<005e6001OA000HD800P00Hd40
0`00ICh006Ll001Y>@02001[=P03001^<`00LBh007@Z008007LT00<007/N001o5`00P`h00P00R0@0
0`07S@005Y8002NH000203^O000305BW001b/000UkX00080a<@000<0dJD00=im003]B@000P3m2@09
0?l00080o@T000<0kDT00=il003AY@000P35a0000`2G^P00L[0005BW000203^O000302NH000FTP00
1hd0008008P400<008<>001o5`00Nah00P00Mb@00`00M2X0074^001^<`02001[=P03001Y>@00Ic`0
06Dn008006=100<00652001OA000GDH00P00G4L00`00FTP005U9001GBP02001FB`03001EB`00E4`0
059=0080055=00<0051>001?CP00CTh00P00C4h00`00BTd004U<0017B`020015BP040013B@00@TT0
0418000oA`8003i700<003a6000kA@00>TD00P00>D@00`00>4@003M3000f@`02000e@P03000d@P00
<d4003910080035000<00310000_?`00;cl00P00;Sl00`00;Ch002`n000/?@02000[?@03000Z?@00
:S`002Tl008002Tl0P00:3/00`009c/002Lj000W>P02000V>P03000U>P009CT002Di008002@i1000
8cP00`008SP0028g000Q=`03000Q=`@0020f00<001lfooooooooool00oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;ooooo00D001lf000P=P0083H0020f000P=`02000Q=`80028g0P00
8SP3000S>0<002@i0P009CT00`009CX002Hj000V>P03000W>`8002Pk0P00:C`2000Z?0<002/m00<0
02`n000]?P00;Ch00P00;Sl00`00;cl00310000`@002000a@003000b@@00<d4003A2008003E200<0
03I3000g@`00>4@00P00>DD00`00>TD003]6000mAP02000nA`04000oB000@DP004990014BP8004I:
00<004M;0019C000Bdd00P00CDh00`00Cdh0051>001AC@02001BC@03001CC000E4`005E;008005I:
00<005Q:001IB@00FTP00P00G4L00`00GTD005m4001Q@P02001S@003001U?P00Ic`006Ti008006`f
00<006hb001a;P00M2T00P00N2@00`00Nad007lF00233@0200280`0300R=000FTP009iT00080>il0
00<0E:L0076_002E^@000P30``000`3?ZP00g8D00>YF00020?PO00T0o`000P3h7`000`3ZEP00g8D0
0<nZ00020<33000309Fi001a[`00E:L00080>il000<09iT001JC0008S@000P00R0<00`00P`d007lF
001k7@02001h8`03001d:@00LBh006hb008006`f00<006Ti001W?000ICh00P00Hd000`00HD8005m4
001NA@02001LA`03001JB000FDT005Q:008005I:00<005E;001DC000Dd`00P00DTd00`00DDd0051>
001?CP02001=CP03001;C@00BD`004M;008004I:00@004A:0012B@00@DP003m80P00?TL00`00?DH0
03]6000jA@02000iA@03000hA000=d<003I3008003E200<003A2000c@@00<T400P00<D02000`@003
000_?`00;Sl002ho008002dn00@002`n000[?@00:cd002/m0P00:S`2000Y?08002Pk0`009c/2000V
>P03000U>P009CT002Di00<002@i0`008cP2000R>080028g0P008CL01@0083L0020f000P=P0083H0
01lf00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`@0020f0`008CL2000R
=`03000R>0008cP002<h008002<h0P0093T3000U>@8002Hj00<002Lj000W>`009c/00P00:3/3000Y
?003000Z?000:Sd002/m008002`m00<002`n000]?P00;Sl00P00;Sl00`00;cl00310000a@003000b
@@07000c@P00=48003E3000e@`00=T<003M4000hA002000jA@03000kA@00?4H003e7008003m700@0
04180011B000@dT004A:0P00AT/00`00B4/004Y<001<C@02001>CP03001?CP00D4h0055=0080059=
00<005=<001DC000ED/00P00EdX00`00F4T005U9001KA`02001LAP03001NA@00H4<00652008006=0
00<006Dn001W>`00JSP00P00K3D00`00Kc40078]001e:002001h8`03001l7000OaD008@<008008P2
00<02Hd001NC000WV@000P0kW`000`1CY`00Kjl0096h00020;[200030<f_003IS@00iV@00080lc<0
2@3o00020?<c00030>IT003IS@00cJl00080^/8000<0TKP006n_001CY`000P0kW`000`0WV@005i<0
00V=000200280P0300243000OaD007`L008007PS00<007DX001b;@00Kc400P00K3D00`00JSP006Pk
001U?P02001S@003001Q@P00H4<005i5008005a600<005]7001IB@00F4T00P00EdX00`00ED/005A<
001CC002001BC@03001AC@00D4h004m>008004i>00<004a=001:C000B4/00P00AT/01000A4X004=9
0011B000@4P2000oA`03000mA`00?4H003]5008003Y500<003Q4000gA000=T<00P00=D<00`00=480
03=2000b@@02000b@@03000a@000<40002lo00<002ho00L002dn000/?P00;3d002`m000[?@00:Sd0
02Xl00<002Tl0P00:3/2000W>`03000W>P009SX002Hj00<002Di0P0093T4000S>003000R>0008SL0
028g00<0024g100083H5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool2000P
=P80020g0P008CL010008SL0028h000R>0008SP2000S>0@002@i00<002Di000U>P009CX00P009SX0
0`009cX002Lk000W>`02000X>`<002Tl00<002Xl000[?@00:cd00P00;3h2000]?P06000^?`00;cl0
02lo000_?`00<40003500P00<T400`00<d4003A2000e@P02000f@`03000g@`00>4@003U4008003Y5
00<003]5000lAP00?TL00P00?dL01000@4P004990013B@00ADX20017B`030018C000BTd004a=0080
04i>00<004m>001@CP00DDd00P00DTd00`00Dd`005A<001FB`02001GBP03001HB@00FTP005]70080
05e600<005i5001P@`00HT400P00I3l00`00ISd006Pk001Z>002001]=@03001_<@00LRd007DX0080
07PR00<007`L00205000Q0`00P00R0800`09S@005i<002NI000203^O000305:V001][P00SKL00080
]<4000<0bkD00=JF003RL@000P3^A`000`3i6P00o`000?l000050?l000060?TJ003^A`00kTL00>9a
003FUP00bk@00P2d`@000`2=]`00KJh005:V000203^O000302NI000GT`002Hd0008008P200<008@<
00205000O1`00P00N2800`00MBP0078]001_<@02001]=@03001Z>000J3/006Hm008006@o00<00691
001P@`00GTD00P00GDH00`00FdL005Y8001HB@02001GBP03001FB`00E4`005=<0080059=00<0055=
001@CP00Cdh00P00CTh00`00C4d004Y=0018C0020017B`040015BP00@dT004990010B08003m700<0
03i7000lAP00>dD00P00>TD00`00>D@003Q4000g@`02000f@`03000e@P00=48003=10080039100<0
0350000`@000;cl00P00;cl00`00;Sl002dn000]?P02000/?P8002/m00@002Xl000Y?000:C`002Tl
0P00:3/2000W>`03000W>P009SX002Hj008002Dj00<002Di000T>@0093T00P0093T2000S>0<0028h
00<0028g000Q=`008CL00P0083L2000P=PGooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`02ooooo`80020f10008CL010008SL0028h000R>0008SP2000S>0<002@i0P009CT2000U>P8002Hj
0`009c/00`00:3/002Tl000Y?002000Z?003000Z?@00:cd002`m008002`n00<002dn000^?P00;Sl0
0P00;cl00`00<4000350000a@@02000b@@03000c@@00=48003E2008003I300<003M3000hA000>DD0
0P00>TD00`00?4H003e6000nA`02000oB0040011B000@TT004A:0015BP8004M;00<004U<001;C@00
CDh00`00Cdh01`00D4d0055=001CC@00Ddd005A<001EB`00ET/00P00EdX00`00FDT005Y8001KA`02
001MAP03001OA000H4<00691008006@o00<006Hm001X>P00JcL00P00KC@00`00L300078/001e9`02
001i8P03001l6`00P1@008@;008008T100<02Hd001NC000WV@000P0jW`000`1@YP00JZh008Vf0002
0:fo00030<Vj003CWP00gWh00080jET000<0lc<00?`>003o0000103o00001`3l3P00lc<00>UI003Y
F@00gWh00=>N0039^P000P2]_`000`29]P00JZh0052V000203ZO000302NI000GT`002Hd0008008T1
00<008@;00205000O1/00P00NB800`00MBL0078/001`<002001]=003001[=`00J3X006Hm008006@o
00<00691001P@`00Gd@00P00GDH00`00FdL005Y8001IB@02001GBP03001FB`00ED/005A<008005==
00<0055=001@C@00Cdh00P00Cdh00`00CDh004]=0019C0020017B`040016BP00A4X004990011B080
03m800<003i7000mAP00?4H00P00>TD00`00>DD003Q4000g@`02000f@`03000e@P00=48003=10080
039100<00351000a@000<4000P00;cl00`00;Sl002hn000]?P02000/?P03000/?@00:cd002Xm0080
02Xl0P00:C`01000:3/002Lk000W>`009c/2000V>P8002Dj0P009CT3000T>@8002<h0`008SP00`00
8SL0024g000Q=`02000Q=`80020f1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo0P0083H4000Q=`04000R=`008SP0028h000R>08002<h0`0093T2000U>@8002Dj0P009SX3000W
>`03000X>`00:C`002Tl008002Xl00<002Xm000[?@00;3d00P00;3h00`00;Ch002hn000^?`02000_
?`03000`@000<D0003510080039100<003=1000d@P00=D800P00=T<00`00=d<003Q4000iA@02000j
A@03000lAP00?DH003i7008003m800@004580012B@00A4X004E:0P00Ad/00`00BD`004]=001=CP03
001?CP07001@C@00DDd005==001CC@00E4`005E;001FB`02001GBP03001IB@00FTP005]7008005e6
00<005m4001P@`00HT400P00I3l00`00ISd006Pj001[=`02001]=003001`<000LR`007DW008007TR
00<007`K00205000Q0/00P00R@400`09S@005i<002NI000203ZO0003052V001Z[P00RKH00080[Kl0
00<0bKX00=>N003NOP000P3YF@000`3c<`00o0h00?l000040?l000070?`>003c<`00jET00>UI003N
OP00dih00<Vj00020:fo000308Vf001Z[P00D:H00080>Yl000<09iT001NC0009S@000P00R@400`00
Q0/0080D001l6`02001i8P03001e9`00LR`0070`008006dd00<006/g001X>P00ISd00P00I3l00`00
HT400613001OA002001MAP03001KA`00FTP005U9008005M:00<005I;001EB`00E4`00P00Ddd00`00
DDd0051=001?CP02001?CP03001=CP00Bdd004U<008004M;00@004I:0014BP00@TT004580P00?dP0
0`00?TL003e6000lAP02000jA@03000iA@00>4@003M3008003I300<003E2000d@P00<d400P00<T40
0`00<D400350000`@002000_?`03000^?`00;Sh002dn008002`n00<002`m000[?@00:Sd00P00:S`2
000Y?004000X>`009c/002Lk000W>`8002Hj0P009CX2000U>@<002@i0P008cP3000R>003000R=`00
8CL0024g0080024g0P0083H5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool0
0`0083H0020g000Q=`02000Q=`80028g0P008SP3000S>0<002@i00<002Di000U>P009SX00P009SX0
0`009cX002Lk000X>`02000X>`8002Tl0P00:S`2000[?@05000/?@00;3h002`n000]?P00;Sl00`00
;cl00`00<4000350000b@@02000c@@03000c@P00=48003E3008003I300<003M4000hA000>TD00P00
>dD00`00?4H003e7000nA`020010B0040011B000@dT004A:0016B`8004Q;00<004Y<001;C@00CDh0
0P00Cdh00`00D4h0055=001BC@02001CC003001DC000ED/005I;008005Q:00<005U9001JB000G4L0
0P00GDD00`00Gd@00652001R@@02001T?`03001V?000JCX006/g008006dd00<0070`001c;000MRL0
0P00NB400`00O1/0080C00242`0200290@0300V=000GT`009YP00080>9l000<0CZD006N]0024]@00
0P2V_@000`36`000d:L00=Z:00020>AZ00030>e:003e:`00na<000<0oPH000<0na<00?D[003]BP00
0P3TJP000`3JRP00d:L00<K000020:Jm000308Be001W[@00CZD00080>9l000<09YP001NC0009S@00
0P00R@400`00Q0/0080C001l6`02001i8@03001f9`00Lb`0070`008006dd00<006/g001Y>P00IS`0
0P00I3l00`00HT400652001OA002001MA@03001LA`00FTP005U9008005Q:00<005I;001EB`00E4`0
0P00Dd`00`00DTd0055=001@CP02001?CP03001=CP00Bdd004Y<008004Q;00@004I;0014BP00@dT0
04580P00@4P00`00?TL003e7000lAP02000kA@03000jA@00>4@003M4008003I300<003E3000d@P00
<d800P00<d400`00<T400350000`@003000_?`05000^?`00;Ch002`n000/?P00;3d00P00:cd2000Z
?08002Tl0`00:3/00`009c/002Lj000V>P02000V>P03000U>P009CT002@i008002@i0`008cP2000R
>080028g0`008CL00`0083L0020fooooo`04ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00_ooool00`0083H0024g000Q=`02000Q=`04000R=`008SP0028h000R>08002<h0`0093T2000U
>@04000U>P009SX002Hj000V>P8002Lk0P00:3/00`00:3`002Tl000Z?002000Z?@8002/m00H002`n
000]?P00;Ch002dn000^?`00;cl3000`@007000a@000<T4003=1000c@@00=48003E2000f@`02000g
@`03000hA000>D@003Y5008003]500<003a6000nA`00?dL00P00@4P01000@TT004=90015BP00AT/2
0018C003001:C000C4d004i>008004m>00<0051>001AC@00DTd00P00Dd`00`00E4`005E;001GBP02
001HBP03001IB@00FdP005a7008005i500<005m4001Q@P00Hd000P00ICh00`00Ic`006Ti001[=`02
001^<`03001`<000Lb/007HV008007TQ00<007dJ00204`00Q0/00P00R@400`09S@005Y8002FH0002
03NN000304^U001S[000Ok<00080W[/000<0`/@00<f_003FUP000P3ON`000`3WG`00kTD00?<a0003
0?HW00030?<a003^A@00iel00080ggX000<0eYH00<f_0032a0000P2N^`000`1o/`00Hj`004^U0002
03NN000302FH000FTP002Hd0008008T100<008@;00204`00OAX00P00NB400`00MRH007<[001`<002
001^<`03001[=`00JCT006Ll008006Dn00<006=0001Q@P00Gd@00P00GTD00`00G4H005]8001IB@02
001HBP03001GBP00ED/005A<008005=<00<0059=001AC@00D4h00P00Cdh00`00CTh004a=001:C002
0018C0040016B`00ADX004=90012B@80041800<003m7000nA`00?4H00P00>dD00`00>TD003U4000h
A002000g@`03000f@`00=D8003A2008003=100<00391000a@000<4000P00<4000`00;cl002ho000]
?P02000]?P03000/?P00:cd002/m008002Xm00<002Xl000Y?000:3`00P00:3/2000W>`<002Hj00<0
02Dj000U>@009CT00`0093T2000S>0<0028h00<0028g000Q=`008CL00P008CL00`0083Kooooooooo
o`03ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool0100083L0024g000Q=`00
8CL2000R=`03000R>0008cP002<h008002<h0`0093T00`009CT002Dj000V>P02000V>P03000W>P00
9c/002Pk008002Pk0P00:C`01P00:S`002Xm000Z?@00:cd002`m000/?P8002dn00<002hn000^?`00
;cl00P00<4000`00<D000351000b@@02000c@@03000d@P00=D8003I3008003M300<003Q4000iA@00
>TD00P00>dH00`00?DH003i7000oB0020011B0040012B@00A4X004E:0017B`8004U<00<004]=001<
C@00CTh00P00Cdh00`00D4h0055=001BC@02001CC003001DC000ET/005M:008005Q900<005U8001K
A`00G4H00P00GTD00`00Gd@00652001S@002001U?P03001W?000JCT006/f008006hc00<0070_001c
:`00MRH00P00NB400`00OAX0080C00242`0200290@0300V=000ETP0099P00080=Id000<0BJ@005nZ
001i/P000P2G^@000`2h`@00b[L00=:Q00020=Z900030>9b003XG000k4`000<0kd<000<0k4`00>QL
003RLP000P3JR@000`3BX@00b[L00;S1000209Ni000307Vb001OZP00BJ@00080=Id000<099P001JB
0009S@000P00R@400`00Q0/0080C001m6P02001i8@03001f9P00Lb/0070_008006hc00<006/f001Y
>@00Ic`00P00ICh00`00Hd000652001OA002001NA@03001LAP00FdL005U8008005Q900<005M:001F
B`00E4`00P00Dd`00`00DTd0055=001@CP02001?CP03001>CP00C4h004]=008004U<00@004M;0015
BP00A4X004990P00@DP00`00?dP003i7000mAP02000kAP03000jA@00>DD003Q4008003M300<003I3
000e@P00=4800P00<d400`00<T400351000a@002000`@003000_?`00;Sl002hn008002dn00<002`n
000/?@00:cd00P00:Sd00`00:S`002Tl000Y?003000X>`03000W>`009cX002Hj008002Hj00<002Dj
000U>@0093T00P0093T4000S>003000R>0008SL0028g00<0024g00<0020gooooooooool00oooool1
o`00007ooooo000Kooooo`;o00000oooool4000Q=`03000R=`008SP0028h00<002<h100093T00`00
9CT002Dj000V>P02000V>P8002Lk0`00:3/2000Y?005000Z?000:cd002/m000[?@00;3h00`00;Ch0
0`00;Sl002lo000_?`02000`@003000a@000<T4003=100<003A200L003E3000f@`00=d@003M4000h
A000>TD003]5008003a600<003e6000nA`00@4P00P00@DP01000@dT004A:0016B`00Ad/20019C003
001;C@00CDh004m>0080051>00<0051=001AC@00DTd00P00E4`00`00ED/005I;001GBP02001HB@03
001JB000FdL005e6008005i500<00613001Q@P00Hd000P00ICh00`00Ic/006Ti001/=P02001^<`03
001a;`00Lb/007HV008007TP00<007dJ00204`00Q0/00P00R@400`08S@005I8002>G000203>M0003
04JS001KZ@00Lk000080SkL000<0[Kl00<No003>[0000P3FU`000`3LP`00hW400>IS00030>QL0003
0>IS003RL@00g8<00080eYL000<0cZ`00<No002]_`000P2?]`000`1c/000FjT004JS000203>M0003
02>G000ETP0028d0008008T100<008@;00204`00OAX00P00NB000`00MRH007<[001a;`02001^<`03
001/=P00JCT006Lk008006Dn00<006=0001Q@P00H4<00P00GTD00`00GDH005]7001JB002001HB@03
001GBP00ET/005E;008005A<00<0059=001AC@00D4d00P00D4h00`00Cdh004e>001;C@020019C004
0017B`00AT/004A:0013B@80045800<00418000nA`00?DH00P00?4H00`00>dD003Y5000hA002000g
A003000f@`00=D<003A2008003A200<003=1000b@@00<D000P00<402000_?`05000^?`00;Ch002dn
000]?P00;3h00`00:cd00`00:S`002Tl000Y?003000X>`8002Lk0`009SX00`009CX002Di000T>@03
000T>@<002<h0P008SP00`008SL0024g000Q=`02000Q=`Cooooo0_l00001ooooo`006oooool00ol0
003oooooooooo`02ooooo`@0024g00<0028g000R>0008SP00`008cP4000T>@03000U>@009CX002Hj
008002Hj0P009c/3000X>`8002Tl00D002Xl000[?@00:cd002/m000/?P03000]?P03000^?`00;cl0
02lo0080031000<00350000b@@00<d400`00=4801`00=D<003I3000gA000=d@003Q4000jA@00>dD0
0P00?4H00`00?DH003i70010B0020011B0040013B@00A4X004I;0017B`8004U<00<004]=001=CP00
Cdh00P00D4h00`00D4d0055=001BC@02001DC003001EB`00ET/005M:008005Q900<005Y8001KA`00
GDH00P00GTD00`00H4<00652001S@002001U?P03001W>`00JCT006`f008006hc00<0074_001c:`00
MRH00P00NB000`00OAX0080C00242`0200290@0300R=000ETP008iL00080<id000<0AZ<005^Y001c
/0000P2?]`000`2]_`00akl00<j/00020=JG00030=b3003RL@00iV<000<0j5`000<0iV<00>9a003L
P`000P3FU`000`3>[000akl00:fo000208ng000307>`001KZ@00AZ<00080<id000<08iL001FB0008
S@000P00R@400`00Q0/0080C001m6P02001i8003001f9P00Lb/0074_008006hc00<006`f001Y>@00
Ic/00P00ICh00`00Hd000652001P@`02001NA@03001MAP00FdL005Y8008005Q900<005M:001FB`00
ED/00P00E4`00`00DTd0055=001@C@02001@CP03001?CP00CDh004]=008004U<00@004M;0016B`00
A4X004=90P00@DP00`00@4P003i7000mAP02000lAP03000kA@00>TD003Q4008003M400<003I3000e
@`00=4800P00=4800`00<d400391000a@002000`@08002lo00D002ho000]?P00;Ch002dn000/?P03
000[?@03000Z?000:C`002Tl00<002Pk0P009c/3000V>P03000U>P009CT002@i00<002@i0`008cP2
000R>003000R=`008CL0024g0080024g1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo10008CL00`008SL0028h000S>003000S>08002@i0`009CT2000V>P8002Lj00<002Lk000X
>`00:3/00`00:C`01P00:S`002Xm000[?@00:cd002`m000/?P<002dn00<002ho000_?`00<4000P00
<4000`00<D000391000c@@02000d@P03000e@P00=T<003M3008003Q400<003U4000jA@00>dD00P00
?4H00`00?DL003m70010B0020012B@040013B@00ADX004I;0018B`8004Y<00<004a=001=CP00Cdh0
0P00D4h00`00DDd0059=001CC002001DC003001EB`00ET/005M:008005U900<005Y8001KA`00GDH0
0P00GTD00`00H4<00691001S@002001U?P03001W>`00JST006`f008006hb00<0074_001d:P00MRH0
0P00NR000`00OAX0080C00242`0200280P0300R=000DT@008IL00080<I`000<0@j8005NX001][P00
0P27]@000`2R_000`<<00<^f00020=6T00030=NC003LP`00h7P000<0hW8000<0h7P00=b3003GT`00
0P3AY0000`3;]P00`<<00:>l000208Ne000306f^001GZ000@j800080<I`000<08IL001BA0008S@00
0P00R0800`00Q0/0080C001m6P02001j8003001f9P00M2X0074_008006hb00<006`f001Z>@00Ic/0
0P00ICh00`00Hd000691001P@`02001NA@03001MAP00FdL005Y8008005U900<005M:001FB`00ED/0
0P00E4`00`00Dd`0059=001AC@02001@CP03001?CP00CDh004a=008004Y<00@004Q;0016B`00ADX0
04=90P00@TT00`00@4P003m7000mA`02000lAP03000kA@00>TD003U4008003Q400<003M3000f@`00
=D800P00=4800`00<d400391000a@003000`@003000_?`00;Sl002dn008002dn00H002`n000/?@00
:cd002/m000Z?@00:S`3000Y?08002Pk00<002Lk000W>P009cX00P009SX3000U>@8002@i10008cP0
0`008SP0028g000Q=`03000Q=`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooo
o`80024g0P008SL2000R>0<002<h0`0093T2000U>@03000U>P009SX002Hj008002Lj00<002Lk000X
>`00:3/00`00:C`01`00:S`002/m000[?@00:cd002`m000/?P00;Ch00`00;Sl01000;cl00310000a
@000<D02000b@@06000c@@00=48003A2000e@P00=T<003M30P00>4@00`00>DD003Y5000kAP02000m
AP03000nA`00?dL004580080049900@004=90015BP00Ad/004Q<0P00BT`00`00C4d004i>001?CP02
001@CP03001AC@00DTd005=<008005A<00<005E;001FB`00F4X00P00FDT00`00FTP005a7001MAP02
001OA003001P@`00HT4006@o008006Hm00<006Pk001Z>000K3D00P00KS800`00LBh007@Z001g9@02
001j8003001m6P00P1<008@;008008P200<01h`001:A000OUP000P0^V`000`0oX@00DZL006N]0002
07nc000309Rj002c`000akl00080cJl000<0dZ400=ND003JR`000`3LQ@000`3JRP00ei@00=:Q0002
0<f_00030<No002c`000V;X00080Ok<000<0Ijd005:W000oX@000P0^V`000`0OUP004Y4000N<0002
00280P0300242`00P1<007dJ008007XP00<007LU001d:P00LBh00P00KS800`00K3D006Xh001X>`02
001V?@03001T?`00HT400613008005m400<005e6001LA`00FTP00P00FDT00`00F4X005I;001EB`02
001DC003001CC000DTd0055=0080051>00<004m>001>CP00C4d00P00BT`01000B4`004M;0015BP00
@dT20012B@030011B000?dL003i7008003e600<003]6000jA@00>DD00P00>4@00`00=d<003I3000e
@P02000d@P03000c@@00<T4003910080035000<00310000_?`00;Sl00P00;Sl00`00;Ch002`n000/
?@03000[?@04000Z?000:C`002Tl000Y?08002Pk00<002Lk000W>P009cX00P009SX00`009CX002Di
000U>@03000T>@<002<h0P008SP2000R=`80024g1Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo0P008CL2000R=`03000R>0008cP002<h008002<h0P0093T3000U>@03000U>P00
9SX002Hj00<002Lk00@002Pk000X?000:C`002Tl0P00:S`3000[?@03000/?P00;Ch002dn008002ho
0P00;cl01@00<4000350000a@000<T4003=100<003A200<003E3000f@`00=d@00P00>4@00`00>DD0
03]5000lAP02000mAP03000nA`00@4P004580080049900@004A:0015BP00Ad/004U<0P00Bdd00`00
C4d004i>001?CP02001@CP03001AC@00DTd005=<008005A<00<005E;001FBP00F4X00P00FDT00`00
FTP005a7001MAP02001OA003001P@`00HT4006@o008006Hm00<006Pk001Z>000K3D00P00Kc800`00
LBh007@Z001g9@02001j8003001m6P00P1<008@<008008P300<01X`0016@000MU@000P0/VP000`0l
X000CJD0066[000207Na000308jg002V_@00_l<00080bKX000<0cZh00=:S003DV`000`3FU`000`3D
V`00dZ<00<j^00020<Vj00030;o3002V_@00S[L00080Mk4000<0HJ/004fU000lX0000P0/VP000`0M
U@004I0000J<000200280`0300243000P1<007dJ008007XP00<007LU001d:P00LBh00P00Kc800`00
K3D006Xh001X>`02001V?@03001T?`00HT400613008005m400<005e5001LA`00FTP00P00FDT00`00
F4X005M:001EB`02001DC003001CC000DTd0055=0080051>00<004m>001>CP00C4d00P00Bdd01000
BD`004M;0015BP00A4X20012B@030011B000@4P003i7008003e600<003a6000kA@00>DD00P00>4@0
0`00=d@003I3000e@`03000d@P05000c@@00<T400350000a@000<4000P00;cl2000^?`8002dn00@0
02`n000[?@00:cd002/m0P00:S`2000Y?003000X?000:3/002Lk008002Lk0P009SX010009CX002Di
000U>@009CT2000T>@@002<h00<0028h000R=`008SL00P008CL5ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool00_ooool00`008CL0028g000R>002000R>08002<h0P008cT2000T>@03000U
>@009CX002Dj008002Hj00<002Lj000W>`009c/00P00:3/3000Y?003000Z?000:Sd002/m008002`m
00<002`n000]?P00;Sh00P00;Sl00`00;cl00310000`@002000a@003000b@@00<d4003A2008003E2
00<003I3000g@`00>4@00P00>D@00`00>TD003]5000lAP02000mA`03000oA`00@4P00458008004=9
00@004A:0016B`00Ad/004U<0P00Bdd00`00CDh004m>001?CP02001@CP03001AC@00DTd005=<0080
05A<00<005I;001GBP00F4T00P00FDT00`00FdP005a7001MA@02001OA003001Q@P00HT4006@o0080
06Hm00<006Pk001Z>000K3D00P00Kc800`00LBh007@Z001g9@02001j8003001m6P00P1@008@<0080
08L400<01H`000n@000KU0000P0YV@000`0hWP00B:@005^Y000206n_000308Be002J^P00/<000080
aL@000<0bKT00<f`003?Z@000`3AYP000`3?Z@00cK000<Vi00020<G400030;30002J^P00Q;D00080
Kjl000<0FjT004VT000hWP000P0YV@000`0KU0003i0000F<00020027100300243000P1@007dJ0080
07XP00<007LU001d:P00LBh00P00Kc800`00K3D006Xh001X>`02001V?@03001T?`00HT4006520080
05m400<005e5001LA`00FdP00P00FDT00`00F4T005M:001FB`02001DC003001CC000DTd0055=0080
051>0P00Cdh01`00CDh004]=001;C@00BD`004M;0016B`00A4X00P00@dT00`00@DP00418000oA`02
000mA`03000lAP00>dD003Y5008003U400<003Q4000g@`00=T<00P00=D800`00=48003=1000b@@02
000a@080031000H002lo000^?`00;Sl002hn000]?P00;3h2000/?@03000[?@00:Sd002Xl00<002Tl
0P00:3/2000W>`03000W>P009SX002Hj008002Dj00<002Di000T>@0093T00P0093T2000S>0<0028h
00<0028g000Q=oooool01?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo00<0
024g000R=`008SP00P008SP2000S>08002<i0P0093T00`009CT002Dj000U>P02000V>P03000W>P00
9c/002Lk008002Pk0`00:C`00`00:S`002Xm000[?@02000/?@03000/?P00;Ch002hn008002ho00<0
02lo000`@000<4000P00<D000`00<T4003=1000d@P02000e@P03000f@`00=d<003Q4008003U400<0
03Y5000kA@00?4H00P00?DL00`00?dL004180011B0020013B@040014BP00AT/004M;0019C08004]=
00<004e>001?CP00Cdh00P00D4h00`00DDd0059=001CC002001DC003001FB`00EdX005Q9008005U9
00<005]8001LA`00GDD00P00Gd@00`00HD800691001T?`02001V?@03001X>`00JSP006`e008006lb
00<0074^001d:P00MbD00P00NR000`00OAX0080D002430020027100300F<000?T0006i@00080:IT0
00<0>9h004RT001KZ@000P1_[`000`24]@00V[X00;3000020<G400030<Vi003=/000cjT000<0dJH0
00<0cjT00<f`0039^@000P35a0000`2``000V[X008Be000206n_000305^Y0019Y000>9h00080:IT0
00<06i@000n@0005S0000P00Q`@00`00Q0`0080D001m6P02001j8003001g9@00M2X0074^008006lb
00<006`e001Z>000J3/00P00ISd00`00I3l00691001Q@P02001OA003001MA@00G4L005]8008005U9
00<005Q9001GBP00ET/00P00E4`00`00Dd`0059=001AC@02001@CP8004m>00L004e>001;C@00Bdd0
04U<0017B`00AT/004A:008004=900<004580010B000?dL00P00?DL00`00?4H003]5000jA@02000i
A003000hA000=d<003I3008003E200<003A2000c@@00<T400P00<D02000`@006000_?`00;Sl002ho
000^?P00;Ch002`n0P00;3d00`00:cd002Xm000Z?003000Y?08002Pk0P009c/00`009cX002Hj000V
>P02000U>P03000U>@0093T002@i008002@i0P008cP3000R>003000R=`008COooooo00Cooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`02ooooo`03000Q=`008SL0028h0080028h0P008cP3
000T>@8002Di0P009CX2000V>P<002Lk0P00:3/3000Y?003000Z?000:cd002/m008002`m00<002`n
000]?P00;Sl00P00;Sl00`00;cl00310000a@003000b@@07000c@@00=48003E2000e@P00=T<003M3
000hA002000iA003000jA@00>dH003a6008003i700<003m70010B000@TT00P00@dT01000ADX004I;
0018B`00BT`2001;C@03001=CP00Cdh0051>00<0055=00L0059=001DC000ED/005E;001FB`00EdX0
05Q9008005U800<005]7001LAP00GTD00P00Gd@00`00HD800691001T?`02001V?@03001X>P00JSP0
06`e008006lb00<0074^001d:P00MRD00P00NB000`00OA/0080D00233@0200271@0300>;000>S`00
6I@000809YP000<0=9d004BR001EY`000P1W[@000`1j/P00S[L00::l00020;G100030<G40038_000
b[H000<0bk<000<0b[H00<Rl0035a0000P2e`@000`2R_000S[L007Zb000206N]000305FW0014XP00
=9d000809YP000<06I@000j?0003R`000P00Q`D00`00P`d0080D001m6`02001i8003001g9@00M2X0
074^008006lb00<006`e001Z>000J3X00P00ISd00`00I3l00691001Q@P02001OA003001NA@00G4H0
05]7008005U800<005Q9001GBP00ET/00P00ED/00`00E4`0059=001AC@02001AC@03001@CP00Cdh0
04e>008004]=00@004Y<0018B`00AT/004E:0P00@dT00`00@TT00418000oA`02000nA`03000lAP00
>dH003Y5008003U400<003Q4000g@`00=T<00P00=D800`00=48003=1000b@@02000b@@03000a@000
<40002lo00<002ho00@002dn000/?P00;3d002`m0P00:cd01000:S`002Tl000Y?000:C`2000X>`<0
02Lk0P009SX2000U>P8002Di0`0093T2000S>0<0028h00<0028g000Q=oooool01?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo0P008SL2000R>0<002<h0`0093T00`009CT002Dj
000V>P02000V>P05000W>P009c/002Lk000W>`00:3/00P00:C`2000Z?003000Z?@00:cd002/m0080
02`n0P00;Ch01P00;Sl002lo000_?`00;cl00310000a@080039100<003=1000c@P00=4800P00=D<0
0`00=T<003M4000hA002000iA@03000jA@00?4H003e6008003i700<003m80011B000@TT00P00@dT0
1000ADX004M;0018C000BT`2001<C@03001>CP00Cdh0051>0080055=00<0059=001CC000E4`00P00
ED/00`00ET/005M:001HB@02001JB003001KA`00G4H005i5008005m400<00652001S@@00I3l00P00
ISd00`00J3X006Xh001/=@02001_<P03001a;P00M2X007HV008007TQ00<007`K00205@00P`h00P00
Q`H00`02RP0038h001NC000202>G0003032L000oX@00CZD00080GjX000<0LJl008>d002D^@000P2U
_@000`2d`@00`L@00<K200030<No00030<K20031a000]<400080YKd000<0U;T008>d001a[`000P1O
ZP000`1>Y@00?j40032L000202>G000301NC000<SP000XX0008008L600<008<>00205@00O1/00P00
NB400`00MRH007@Z001a;P02001_<P03001/=@00JSP006Pj008006Hm00<006@o001S@@00HD800P00
Gd@00`00GTD005a6001KA`02001JB003001HB@00EdX005I;008005E;00<005A<001CC000DTd00P00
DDd00`00D4h004m>001>CP02001<C@04001:C000B4`004M;0015BP8004=900<004990011B000?dP0
0P00?TL00`00?DH003a6000jA@02000iA@03000hA000=d@003I3008003E300<003A2000c@P00<d40
0P00<T400`00<D000310000_?`02000_?`03000^?`00;Ch002dn008002`n0P00:cd00`00:Sd002Xl
000Z?002000Y?005000X>`009c/002Lk000W>`009cX00`009SX00`009CX002Di000T>@02000T>@<0
02<h0P008SP2000R=`Gooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool3o`0000Gooooo00?o0000ooooooooool00_ooool010008SL0028h000R>0008SP2000S>0@0
02@i00<002Di000U>P009SX00P009SX00`009cX002Lk000X>`02000X>`8002Tl0P00:S`00`00:Sd0
02/m000/?@02000/?P03000]?P00;Sh002ho008002lo0P00<4001P00<D000391000b@@00<d4003A2
000e@P8003I300<003M3000hA000>D@00P00>TD00`00>dD003a6000mAP02000nA`030010B000@DP0
0499008004A:00@004E:0017B`00BD`004Y=0P00C4d00`00CTh004m>001@CP02001AC@03001BC@00
Dd`005A<008005E;00<005I;001GBP00F4T00P00FTP00`00FdL005a6001NA@02001OA003001Q@P00
Hd0006@o008006Hl00<006Pj001Z>000K3D00P00Kc800`00LBh007@Z001f9P02001i8@03001l6`00
OaD008<?008008H700<008X000Z>000DTP000P0PUP000`0/VP00>Yl004RT000205RX000306R]001h
/@00R;H00080UkT000<0Y;d00:no002g`@000`2k`P000`2g`@00[kl00:Bm000209Ni000308Rf001h
/@00J:d00080F:P000<0B:@003ZO000/VP000P0PUP000`0DTP002Xh0002:000200261`0300233`00
OaD007`K008007TQ00<007HV001d:P00LBh00P00Kc800`00K3D006Xh001X>P02001V?003001T?`00
Hd000652008005m400<005i5001LAP00FdL00P00FTP00`00F4T005M:001FB`02001EB`03001DC000
Dd`0059=0080055=00<0051>001?CP00CTh00P00C4d01000BTd004U<0017B`00ADX20014BP030012
B@00@DP00418008003i700<003e6000lAP00>dD00P00>TD00`00>D@003Q4000g@`02000f@`03000e
@P00=48003=10080039100<00350000`@000<4000P00;cl00`00;Sl002hn000]?P02000/?P03000/
?@00:cd002Xm008002Xl0P00:C`3000X>`03000W>`009cX002Hj008002Hj00<002Dj000U>@0093T0
0`0093T2000S>0<0028h00<0028gooooooooool00oooool1o`00007ooooo0007ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;o
oooo00<0028g000R>0008cP00`008cP3000T>@8002Di00@002Dj000V>P009SX002Hj0P009c/3000X
>`8002Tl0P00:S`2000[?@04000/?@00;3h002`n000]?P8002ho0P00;cl00`00<4000350000a@@02
000b@@03000c@@00=48003E2008003I300<003M3000hA000>D@00P00>TD00`00>dD003a6000mA`02
000oA`030010B000@DP004=9008004A:00@004I;0017B`00BD`004]=0P00CDh00`00CTh004m>001@
CP02001AC@03001BC@00Dd`005A<008005E;00<005I;001GBP00FDT00P00FTP00`00FdL005e6001N
A@02001P@`03001Q@P00Hd0006Dn008006Hl00<006Pj001Z>000K3D00P00Kc800`00LBh007@Z001f
9P02001i8@03001l7000OaH0088?008008H800<008T000R=000BT@000P0LU@000`0XV@00=Id004:R
0002052V000305nZ001][P00O;800080RKH000<0UKT009jk002U_@000`2Y_P000`2U_@00W[/009Fi
000208Vf000307bb001][P00GjX00080D:H000<0@Z8003FM000XV@000P0LU@000`0BT@0028d00029
00020026200300223`00OaH007`L008007TQ00<007HV001d:P00LBh00P00Kc800`00K3D006Xh001X
>P02001V?003001U?P00Hd0006520080061300<005i5001MAP00FdL00P00FTP00`00FDT005M:001F
B`02001EB`03001DC000Dd`0059=0080055=00<0051>001?CP00CTh00P00CDh01000Bdd004U<0017
B`00AT/20014BP030013B@00@DP00418008003m700<003e7000lAP00>dD00P00>TD00`00>D@003Q4
000g@`02000f@`03000e@P00=48003=10080039100<00351000a@000<4000P00;cl2000^?`04000]
?P00;3h002`n000/?@8002/m0P00:S`2000Y?0<002Pk0P009c/3000V>P03000U>P009CT002Di00<0
02@i10008cP00`008SP0028gooooo`04ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003ooooo`03000R=`008SP002<h
00<002<h0`0093T2000U>@04000U>P009SX002Hj000V>P8002Lk0`00:3/2000Y?08002Xl0P00:cd0
1000;3d002`n000/?P00;Ch2000^?`8002lo00<00310000a@000<D400P00<T400`00<d4003A2000e
@P02000f@`03000g@`00>4@003U4008003Y500<003]5000lAP00?DL00P00?dL00`00@4P004580013
B@020014BP040016B`00Ad/004U<001;C@8004e>00<004i>001?CP00D4h00P00DDd00`00DTd005=<
001DC002001EB`03001FB`00EdX005U9008005Y800<005]7001MAP00GTD00P00H4<00`00HD8006=0
001U?P02001V?003001X>P00JSP006`e008006lb00<0074^001d:P00MRH00P00NB400`00O1`007lF
00223`020026200300290008S@004Y40008079D000<0:9T003FM0012XP000P1@YP000`1OZP00KJh0
07bb000208Vf000309Fi002N^`00YKd000<0ZKh000<0YKd009jk002E^@000P29]P000`1l/P00KJh0
05nZ0002052V000304:R000eW@00:9T0008079D000<04Y4000R=0000R@000P00QPP00`00PPl007lF
001l7002001i8@03001f9P00M2X0074^008006lb00<006`e001Z>000J3X00P00IS`00`00ICh006=0
001Q@P02001P@`03001NA@00GDH005]7008005Y800<005U9001GBP00ET/00P00ED/00`00E4`005=<
001BC@02001AC@03001@CP00Cdh004i>008004e>00@004]=0019C000Ad/004I;0P00A4X00`00@dT0
04580010B002000oA`03000mA`00?4H003]5008003Y500<003U4000hA000=d<00P00=T<00`00=D80
03A2000c@@02000b@@03000a@@00<D000310008002lo0P00;Sl01000;Ch002`n000/?P00;3d2000[
?@8002Xl0P00:C`3000X>`8002Lk0`009SX00`009CX002Di000U>@03000T>@@002<h00<0028h000R
=oooool00oooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005oooo
o`03o`000?oooooooooo00;ooooo0P008SP3000S>0@002@i00<002Di000U>P009SX00P009SX00`00
9cX002Lk000X>`02000X>`8002Tl00<002Xl000Z?@00:Sd00P00:cd01@00;3h002dn000]?P00;Ch0
02ho00<002lo00<00310000a@000<T400P00<d400`00<d8003A2000e@`02000f@`03000g@`00>4@0
03U5008003Y500<003]6000lAP00?TL00P00?dL00`00@4P004990013B@020015BP040016B`00B4/0
04U<001;C@8004e>0P00Cdh01P00D4h0055=001AC@00DTd005=<001DC08005E;00<005I:001HBP00
FDT00P00FTP00`00FdL005e6001NA@02001P@`03001Q@P00Hd0006Dn008006Hl00<006Pj001Z>000
K3D00P00Kc800`00LBh007<[001f9P02001i8P03001k7@00OQL0088A008008D:00<008P200J<000?
T0000P0IU0000`0TV000<9`003bP000204VT000305JX001T[000L:l00080O;8000<0QkD008ng002E
^@000`2H^P000`2E^@00SkL008Ne000207bc0003072_001T[000EZP00080BJ@000<0?:00032L000T
V0000P0IU0000`0?T0001X`000280P0200252@0300224000OQL007`M008007TR00<007HV001c:`00
LBh00P00Kc800`00K3D006Xh001X>P02001V?003001U?P00Hd0006520080061300<005i5001MAP00
FdL00P00FTP00`00FDT005Q:001FBP02001EB`03001DC000Dd`0059=0080055=00<0051>001?CP00
Cdh00P00CDh01000Bdd004U<0018B`00AT/20015BP030013B@00@TT00418008003m700<003i7000l
AP00>dH00P00>TD00`00>DD003Q4000g@`02000f@`03000e@`00=48003=2008003=100<00391000a
@000<4000`00;cl01@00;Sl002dn000]?P00;Ch002`n008002/m0P00:Sd00`00:S`002Tl000Y?003
000X>`03000W>`009cX002Hj008002Hj00<002Dj000U>@0093T00`0093T3000S>080028h1Oooool1
o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`80028h0`008cP4000T>@03000U>@009CX002Hj008002Hj00<002Lj
000W>`00:3/00P00:3/2000Y?006000Z?000:Sd002Xm000[?@00;3d002`n0P00;Ch00`00;Sh002ho
000_?`03000`@007000a@000<T4003=1000c@@00=48003E2000e@`02000f@`03000gA000>4@003U5
008003Y500<003a6000mAP00?TL00P00?dL00`00@DP004990013B@020015BP040016B`00B4`004Y<
001;C@8004e>00<004m>001@CP00D4d00P00DDd00`00DTd005=<001DC002001EB`03001GBP00F4X0
05U9008005Y800<005]7001MAP00GTD00P00H4<00`00HD8006=0001U?P02001V?003001X>P00JSP0
06`e008006lb00<0074_001c:`00MRL00P00N2800`00Nad007hH00214P0200242`0300281004R`00
38l000805Y8000<089H002^J000fWP000P12XP000`1>Y@00FZT006J/0002072_000307Vb0021]000
Q[D000<0RKH000<0Q[D0086d001i/P000P1`[`000`1V[000FZT004jU000204:R000303JN000[VP00
89H000805Y8000<038l000B;0000R0<00P00Q0/00`00PA8007hH001k7@02001h8P03001f9`00Lb/0
074_008006lb00<006`e001Z>000J3X00P00IS`00`00ICh006=0001Q@P02001P@`03001NA@00GDH0
05]7008005Y800<005U9001HBP00EdX00P00ED/00`00E4`005=<001BC@02001AC@03001@C@00D4h0
04m>008004e>00@004]=001:C000B4`004I;0P00ADX00`00@dT004990011B002000oB003000nA`00
?DH003a6008003Y500<003U5000hA000=d@00P00=T<00`00=D<003E2000d@P02000c@@03000b@@00
<D0003100080031000<002lo000^?`00;Sh00P00;Ch00`00;3h002`m000[?@02000Z?@03000Z?000
:C`002Tl00<002Pk00<002Lk000W>P009SX00P009SX00`009CX002Di000T>@03000T>@<002<h0P00
8SP5ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00<0028h000S>0008cP00P008cP2000T>@<002Di1000
9SX2000W>`<002Pk0P00:C`01P00:S`002/m000[?@00:cd002`m000/?P8002dn0P00;Sl01P00;cl0
0310000`@000<D000351000b@@8003=100<003A2000e@P00=T<00P00=d<00`00>4@003U4000jA@02
000kA@03000lAP00?DH003i70080041800<004580012B@00A4X00P00ADX01000Ad/004Q<001:C000
C4d2001>CP03001?CP00D4h0055=0080055=00<0059=001CC000E4`00P00ET/00`00EdX005Q:001I
B@02001JB003001LA`00GDH005i50080061300<00652001S@000ICh00P00IS`00`00J3X006Xh001/
=@02001^<P03001a;`00Lb/007DW008007PS00<007/N001n6@00PA<00P00Q0`00`00Q`D00HX000Z>
000201>A000301bE000VV000<I`00080?:0000<0Aj<0056V001LZ@000P1U[0000`1][P00M;0007Ra
000307^b000307Ra001d/000KJh00080IJ`000<0G:T0056V0017X`000P0lX0000`0aW0009YP001bE
000201>A000300Z>0001RP0008L5008008@<00<0084C001n6@00Nah00P00N2<00`00MBL007<[001a
;`02001^<P03001/=@00JSP006Pj008006Hl00<006Dn001S@000HD800P00H4<00`00GTD005e6001L
A`02001JB003001IB@00F4X005M:008005I;00<005A<001CC000DTd00P00DTd00`00DDd0051>001?
CP02001>CP04001<C@00BT`004Q<0017B`8004E:00<004A:0012B@00@DP00P00@4P00`00?TL003e6
000lAP02000kA@03000jA@00>D@003Q4008003M300<003I3000e@P00=4800P00<d400`00<T400351
000a@002000`@003000_?`00;Sl002ho008002dn00<002`n000/?@00:cd00P00:cd00`00:S`002Tl
000Y?003000X>`8002Lk10009SX3000U>@8002@i10008cP00`008SSoooooooooo`03ooooo`7o0000
0Oooool000Sooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`04000R>000
8cP002<h000S>0<002@i0P009CT00`009CX002Hj000V>P02000W>P03000W>`00:3/002Pk00<002Tl
00<002Xl000Z?@00:cd00P00:cd01@00;3h002dn000]?P00;Ch002ho008002lo0P00<4000`00<D00
0391000b@@02000c@P03000d@P00=D8003I3008003M300<003Q4000iA000>TD00P00>dD00`00?4H0
03e7000oA`020010B0030011B000@dT004A:008004E:00@004M;0019C000BTd004a=0P00CTh00`00
Cdh0051>001AC@02001BC@03001CC@00E4`005E;008005I;00<005M:001HB@00FDT00P00FTP00`00
G4L005e6001NA002001P@`03001Q@P00Hd0006Dn008006Hl00<006Pj001Z>000K3D00P00KS800`00
L2l007</001e:002001h8`03001j7`00OAX0080D008008<>00<008H700290007S0000P0?T0000`0H
T`008YL002^J000203FM000303nQ0019Y000DZL00080FjT000<0HZ/006R]001/[P000`1^[`000`1/
[P00J:d006:[000205^Y000305:W0019Y000?j400080=Id000<0:iX002:G000HT`000P0?T0000`07
S00008T000261`0200233P0300205000OAX007XO008007PS00<007DX001c;000L2l00P00KS800`00
K3D006Xh001X>P02001V?003001U?P00Hd0006520080061300<005i4001MAP00G4L00P00FTP00`00
FDT005Q9001GBP02001FB`03001EB`00E4`005==0080059=00<0055=001@CP00Cdh00P00CTh01000
C4d004Y=0019C000Ad/20015BP030014BP00@dT004580080041800<003m7000mA`00?4H00P00>dD0
0`00>TD003U4000hA002000g@`03000f@`00=D8003A2008003=20P00<T400`00<D000310000`@002
000_?`05000^?`00;Ch002dn000]?P00;3h00`00:cd00`00:Sd002Xl000Y?002000Y?08002Pk00<0
02Lk000W>P009cX00P009SX00`009CX002Di000U>@03000T>@<002<h00<0028hooooooooool00ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo00@0028h000S>0008cP002<h0`00
93T2000U>@03000U>P009SX002Hj008002Lj00<002Lk000X>`00:3/00`00:C`00`00:S`002Xm000[
?@02000[?@05000/?P00;Ch002dn000]?P00;Sl00P00;cl2000`@003000a@000<T400391008003=2
00<003A2000e@P00=T<00P00=d<00`00>4@003U4000jA@02000kA@03000lAP00?DL003m700800418
00<004580013B@00A4X00P00ADX01000Ad/004U<001:C@00C4d2001>CP03001?CP00D4h0055=0080
059=00<005==001DC000ED/00P00ET/00`00EdX005Q9001IB@02001JB003001LA`00GDH005i40080
061300<00652001S@000ICh00P00IS`00`00J3X006Xh001/=@02001^<P03001`;`00Lb`007DX0080
07PS00<007XO001m6P00P1@00P00P`h00`00QPL008T000N<000200n@000301RC000RU`00:iX00080
=Id000<0?j4004VT001BY`000P1KZ@000`1RZ`00J:d006b^000306j_000306b^001X[@00HZ/00080
FjT000<0DZL004VT000oX@000P0eW@000`0[VP008YL001RC000200n@000300N<0000R@0008H70080
08<>00<0080D001m6P00NQl00P00N2<00`00MBP007</001`;`02001^<P03001/=@00JSP006Pj0080
06Hl00<006Dn001S@000HD800P00H4<00`00GT@005e6001LA`02001JB003001IB@00F4T005M:0080
05I;00<005E;001DC000Ddd00P00DTd00`00DDd0051>001?CP02001>CP04001<C@00BTd004U<0017
B`8004E:00<004A:0013B@00@DP00P00@4P00`00?dL003e7000lAP02000kA@03000jA@00>D@003Q4
008003M300<003I3000e@P00=4800P00<d82000b@@03000a@000<4000310008002lo00D002ho000]
?P00;Ch002dn000/?P03000[?@03000Z?@00:S`002Tl008002Tl0P00:3/00`009c/002Lj000W>P02
000V>P03000U>P009CT002Di00<002@i0`008cP00`008SSoooooooooo`03ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_ooool4000S>08002@i0`009CT00`009CX002Hj000V>P03000W
>`8002Pk0`00:C`01P00:S`002Xm000[?@00:cd002`m000/?P<002dn00<002ho000_?`00<4000P00
<4000`00<D000391000c@@02000c@P03000d@P00=D<003I3008003M400<003Q4000iA@00>TD00P00
>dH00`00?4H003i7000oA`020010B0030011B@00@dT004A:008004I;00@004M;0019C000Bdd004a=
0P00CTh00`00Cdh0051>001AC@02001BC@03001CC000E4`005E;008005I;00<005M:001HB@00FDT0
0P00FTP00`00G4L005e6001NA002001P@`03001Q@P00Hd0006Dn008006Hl00<006Pj001Z>000K3D0
0P00KS800`00L2l007</001e:002001g9003001j8000OA/007lE0080088?00<008D900280P04R`00
0P0<S`000`0DTP007ID002JH000202nK000303RN0011X@00BJ@00080DJH000<0EjP005bZ001PZ`00
0`1RZ`000`1PZ`00G:X005NX0002056V000304VT0011X@00>9h00080;i/000<09YP001fE000DTP00
0P0<S`000`04R`0008P200252@0200223`03001o5@00OA/007XP008007LT00<007DX001c;000L2l0
0P00KS800`00K3D006Xh001X>P02001V?003001U?P00Hd0006520080061300<005i4001MAP00G4L0
0P00FTP00`00FDT005Q9001GBP02001FB`03001EB`00E4`005=<0080059=00<0055=001@CP00Cdh0
0P00CTh01000C4d004]=0019C000Ad/20016B`030014BP00@dT004590080041800<003m7000nA`00
?4H00P00>dH00`00>TD003U5000hA002000gA003000f@`00=D<003A2008003=200<003=1000b@@00
<D000`00<4001`00;cl002ho000^?P00;Sh002dn000/?P00;3d00P00:cd00`00:Sd002Xl000Y?002
000Y?08002Pk0`009c/2000V>P04000U>P009CT002Di000U>@8002@i10008cP5ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_ooool4000S>08002@i00<002Di000U>P009CX00`009SX3
000W>`8002Pk0`00:C`01`00:S`002/m000[?@00:cd002`m000/?P00;Ch00`00;Sl00`00;cl00310
000a@002000a@007000b@@00<d4003A2000d@P00=D8003E3000f@`02000gA003000hA000>DD003Y5
008003a600<003e6000nA`00?dL00P00@4P00`00@TT004=90015BP020016B`040018B`00BD`004]=
001=CP8004i>00<004m>001@CP00DDd00P00DTd00`00Dd`005A<001EB`02001FB`03001GBP00F4T0
05U9008005Y800<005a7001MAP00GT@00P00H4<00`00HD8006=0001U?P02001V?003001X>P00JSP0
06`f008006hc00<0070`001b;000MBT00P00MbD00`00NB0007`L001o5`0200214@0300242`00Q`@0
0HX000802Hd000<0490001RC000QUP000P0YV@000`0aW000>Il0046Q000204RS000304fU001BY`00
EJL000<0EjP000<0EJL005:W001=Y@000P18X`000`11X@00>Il0036L000202VI0003026F000IT`00
490000802Hd000<00HX000271000Q0/00P00PA400`00OaL007`L001i8002001g9@03001e:@00LR`0
070`008006hc00<006`f001Z>000J3X00P00IS`00`00ICh006=0001Q@P02001P@`03001NA000GDH0
05a7008005]800<005U9001HB@00EdX00P00ET/00`00ED/005A<001CC002001BC@03001AC@00D4h0
04m>008004i>00@004e>001;C@00BD`004Q;0P00AT/00`00ADX004=90012B@020010B003000oA`00
?TL003e6008003a600<003Y5000iA@00>4@00P00=d@00`00=T<003E3000e@P02000d@P03000c@@00
<T4003500080035000<00310000_?`00;Sl00P00;Sl00`00;Ch002`n000/?@03000[?@04000Z?000
:C`002Tl000Y?08002Pk0`009c/3000V>P8002Dj00<002Di000T>@0093T010008cP5ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_ooool2000S>0@002@i00<002Di000U>P009CX00P00
9SX00`009cX002Lk000W>`02000X>`<002Tl00<002Xl000Z?@00:cd00P00:cd00`00;3h002dn000]
?P02000^?`8002lo00H00310000a@000<D000351000b@@00<d42000d@P03000e@P00=T<003M30080
03Q400<003U4000jA@00>dD00P00?4H00`00?DH003i7000oB0020011B0030012B@00@dT004E:0080
04I;00@004Q;0019C000Bdd004e>0P00CTh00`00Cdh0051>001AC@02001BC@03001CC000E4`005E;
008005I;00<005M:001HB@00FDT00P00FdP00`00G4L005e6001OA002001P@`03001Q@P00Hd0006Dn
008006Hm00<006Pj001Z>000K3H00P00KS<00`00L300078]001d:@02001f9P03001i8@00Nad007hH
0080084C00<008<=00261`00R@000P06S0000`0=S`00598001bE000202>G000302^J000bW000>Il0
0080?j4000<0A:8004RT001;Y0000`1=Y@000`1;Y000B:@004BR000203nQ000303VO000bW000:iX0
00808iL000<079D001BB000=S`000P06S0000`00R@0008H700233@0200214`03001n6000Nad007TQ
008007HV00<007@Y001b;@00L3000P00KS<00`00K3H006Xh001X>P02001V?@03001U?P00Hd000652
0080061300<005m4001MAP00G4L00P00FdP00`00FDT005Q9001GBP02001FB`03001EB`00E4`005=<
0080059=00<0055=001@CP00Cdh00P00CTh01000CDh004]=0019C000B4/20016B`030015BP00@dT0
04990080045800<003m8000nA`00?DH00P00?4H00`00>dD003Y5000iA002000hA003000g@`00=T<0
03E2008003A200<003=1000b@@00<D400P00<D000`00<40002lo000_?`02000^?`8002dn00H002`n
000[?@00:cd002/m000Z?@00:S`3000Y?08002Pk0P009c/00`009cX002Hj000V>P02000U>P03000U
>@0093T002@i008002@i0P008cP5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool2000S>0<002@i0P009CT2000U>P8002Hj0`009c/2000X>`<002Tl00<002Xl000Z?@00:cd00P00
;3d00`00;3h002dn000]?P02000^?`8002lo00<00310000a@000<D000P00<T401P00<d8003A2000d
@P00=D8003I3000g@`8003Q400<003U4000jA@00>dD00P00?4H00`00?DH003i70010B0020011B003
0012B@00A4X004E:008004M;00@004Q<001:C000Bdd004e>0`00Cdh01`00D4h0055=001BC@00DTd0
05=<001DC000ED/00P00ET/00`00EdX005Q9001IB002001KB003001LA`00GDH005m40080061300<0
0652001S@000I3l00P00ISd00`00J3/006Xh001/=P02001]<`03001_<@00LRd007@Z008007HV00<0
07PR001k7P00OAT00P00P1@00`00PPl008D900280`0200:;000300V=000@T0005i<000807YD000<0
9IP002^J000aW0000P0gWP000`0lX000?j4004:Q000304>R000304:Q000oX@00?:000080=ih000<0
<I`002^J000UV0000P0NU@000`0GT`00490000V=000200:;000300280`00Q@T0088?0080080D00<0
07dI001k7P00N2800P00MRH00`00M2X0078]001_<@02001]<`03001/=P00JSP006Pk008006Hm00<0
06@n001S@000HD800P00H4<00`00Gd@005e6001LA`02001KB003001IB000F4T005M:008005I;00<0
05E;001DC000Dd`00P00DTd00`00DDd0051>001?CP02001?CP04001=CP00Bdd004Y<0018C08004M;
00<004E:0014BP00@TT00P00@DP00`00@4P003i7000mAP02000lAP03000kA@00>TD003U4008003Q4
00<003M3000f@`00=D800P00=4800`00<d800391000b@@02000a@003000`@000;cl002lo008002ho
0P00;Ch01P00;3h002`m000/?@00:cd002Xm000Z?0<002Tl0P00:3/3000W>`8002Hj0P009CX2000U
>@<002@i0P008cP5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool2000S>0<0
02@i0P009CT2000U>P8002Hj0`009c/2000X>`<002Tl00<002Xl000Z?@00:cd00P00;3d00`00;3h0
02dn000]?P02000^?`8002lo00<00310000a@000<D000P00<T401P00<d8003A2000d@P00=D8003I3
000g@`8003Q400<003U4000jA@00>dD00P00?4H00`00?DH003i70010B0020011B0030012B@00A4X0
04E:008004M;00@004Q<001:C000Bdd004e>0`00Cdh01`00D4h0055=001BC@00DTd005=<001DC000
ED/00P00ET/00`00EdX005Q9001IB002001KB003001LA`00GDH005m40080061300<00652001S@000
I3l00P00ISd00`00J3/006Xh001/=P02001]<`03001_<@00LRd007@Z008007HV00<007PR001k7P00
OAT00P00P1@00`00PPl008D900280`0200:;000300V=000@T0005i<000807YD000<09IP002^J000a
W0000P0gWP000`0lX000?j4004:Q000304>R000304:Q000oX@00?:000080=ih000<0<I`002^J000U
V0000P0NU@000`0GT`00490000V=000200:;000300280`00Q@T0088?0080080D00<007dI001k7P00
N2800P00MRH00`00M2X0078]001_<@02001]<`03001/=P00JSP006Pk008006Hm00<006@n001S@000
HD800P00H4<00`00Gd@005e6001LA`02001KB003001IB000F4T005M:008005I;00<005E;001DC000
Dd`00P00DTd00`00DDd0051>001?CP02001?CP04001=CP00Bdd004Y<0018C08004M;00<004E:0014
BP00@TT00P00@DP00`00@4P003i7000mAP02000lAP03000kA@00>TD003U4008003Q400<003M3000f
@`00=D800P00=4800`00<d800391000b@@02000a@003000`@000;cl002lo008002ho0P00;Ch01P00
;3h002`m000/?@00:cd002Xm000Z?0<002Tl0P00:3/3000W>`8002Hj0P009CX2000U>@<002@i0P00
8cP5ooooo`7o00000Oooool001_ooooo0_l00003ooooo`8002<h0`0093T00`009CT002Dj000V>P03
000V>P<002Lk0P00:3/3000Y?003000Z?000:cd002/m008002`m00<002`n000]?P00;Sh00P00;Sl0
0`00;cl00310000`@002000a@003000b@@00<d4003=2008003A200<003E3000f@`00=d<00P00>4@0
0`00>D@003Y5000kAP02000lAP03000mA`00?dL004180080045800<004990014BP00ADX00P00Ad/0
1000B4`004Y<001<C@00CDh2001?CP80051>00H0055=001BC@00DTd005=<001DC000ED/2001FB`03
001GBP00F4T005U8008005]800<005a7001MAP00GT@00P00H4<00`00HD8006=0001T?`02001V?@03
001X>`00JCT006/f008006dd00<006la001a;P00Lb/00P00MBL00`00N2<007XO001m6`02001o5P03
00214@00Q0/008L6008008T000<01H`000b>000BT@000P0IT`000`0OUP009IP002ZJ000202nK0003
03>M000gWP00>Il000<0>Yl000<0>Il003NN000cW@000P0_V`000`0ZVP009IP001nF000201VC0003
01:A000<SP001X`0008008T000<008L600242`00PA400P00OaH00`00OA/007XO001h8`02001f9`03
001c:`00LBh006la008006dd00<006/f001Y>@00J3/00P00ISd00`00I3l006=0001Q@P02001P@`03
001NA000GDH005a7008005]800<005U8001HB@00EdX00P00ET/00`00ED/005A<001CC002001BC@03
001AC@00D4d0051>008004m>00@004e>001<C@00BT`004Q<0P00Ad/00`00ADX004A:0012B@020011
B0030010B000?dL003e7008003a600<003]6000jA@00>D@00P00>4@00`00=d<003I3000e@`03000d
@P04000c@@00<T400350000a@080031000H002lo000^?`00;Sl002hn000]?P00;3h2000/?@8002/m
00@002Xl000Y?000:C`002Tl0P00:3/3000W>`@002Hj00<002Dj000U>@0093T00P0093T2000S>0Co
oooo0_l00001ooooo`006oooool00ol0003oooooooooo`3oooooo`7ooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`3oooooo`7ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00;ooooo0Ol00001ooooo`006oooooooo`0000Go00000Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0629143, -0.614253, \
0.000400575, 0.00460661}},
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG2.3", "AOG2."}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. ABCD Matrix Calculations: FindABCDMatrix", "Section",
  CellTags->{"AOG0.", "3", "AOG3."}],

Cell[CellGroupData[{

Cell["3.1 Overview", "Subsection",
  CellTags->{"AOG0.", "3.1", "AOG3.", "AOG3.1"}],

Cell[CellGroupData[{

Cell["?FindABCDMatrix ", "Input",
  CellLabel->"In[156]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],

Cell[BoxData[
    \("FindABCDMatrix[opticalsystem, assumptions, options] is a function that \
finds the symbolic or numerical ABCD-matrix representation of the optical \
system.\n\nFindABCDMatrix internally calls SymbolicTrace.\n\nSee also \
SymbolicTrace"\)], "Print",
  CellTags->{"Info3312043331-3736878", "AOG3.", "AOG3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[FindABCDMatrix]", "Input",
  CellLabel->"In[157]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],

Cell[BoxData[
    \({Simplify \[Rule] Automatic, ParentFunction \[Rule] FindABCDMatrix, 
      SymbolicRefractiveModels \[Rule] Automatic, 
      NormalizeSurfaceNormal \[Rule] True, MaxByteCount \[Rule] 20000, 
      ByteCountLimit \[Rule] 20000000, RunningCommentary \[Rule] False, 
      TimeConstraint \[Rule] 10, ChopThreshold \[Rule] 1\/100000000, 
      MatrixForm \[Rule] Automatic, EliminateCrossTerms \[Rule] True, 
      ReportedParameters \[Rule] Automatic, 
      ReportedSurfaces \[Rule] {\(-1\)}, NumericalResults \[Rule] False, 
      DecomposeABCD \[Rule] False, ComplexABCD \[Rule] False, 
      ABCDConstruction \[Rule] Automatic, SkipSimplify \[Rule] {}, 
      FilterTrace \[Rule] False, Precision \[Rule] 16}\)], "Output",
  CellLabel->"Out[157]=",
  CellTags->{"AOG3.", "AOG3.1"}]
}, Open  ]],

Cell["\<\
opticalsystemreflected = {
GaussianBeam[40.,.01,SymbolicIntensity->100,SymbolicWaveLength->\[Lambda],\
NumberOfRays->6],
Move[PlanoConvexLens[{f,100},{a,50},{t,10},DesignWaveLength->.532],{d1,50}],
Move[Mirror[{b,20}],175,-45],
Move[Screen[50],{175,50},90]};\
\>", "Input",
  CellLabel->"In[158]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[opticalsystemreflected,PlotType->TopView];", "Input",
  CellLabel->"In[159]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4371 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0242721 0.00462541 0.195421 0.00462541 [
[.27867 .05295 -5.03125 -6 ]
[.27867 .05295 5.03125 6 ]
[.78204 .14374 -6.4375 -6 ]
[.78204 .14374 6.4375 6 ]
[.97619 .42669 -4.75 -6 ]
[.97619 .42669 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .4371 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.2852 .07979 m
.3018 .07979 L
.3018 .11833 L
.26825 .11833 L
.2852 .07979 L
F
.26825 .11833 m
.3018 .11833 L
.3018 .15688 L
.25865 .15688 L
.26825 .11833 L
F
.25865 .15688 m
.3018 .15688 L
.3018 .19542 L
.25554 .19542 L
.25865 .15688 L
F
.25554 .19542 m
.3018 .19542 L
.3018 .23397 L
.25865 .23397 L
.25554 .19542 L
F
.25865 .23397 m
.3018 .23397 L
.3018 .27251 L
.26825 .27251 L
.25865 .23397 L
F
.26825 .27251 m
.3018 .27251 L
.3018 .31106 L
.2852 .31106 L
.26825 .27251 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.2852 .07979 m
.26825 .11833 L
.25865 .15688 L
.25554 .19542 L
.25865 .23397 L
.26825 .27251 L
.2852 .31106 L
.3018 .31106 L
.3018 .27251 L
.3018 .23397 L
.3018 .19542 L
.3018 .15688 L
.3018 .11833 L
.3018 .07979 L
.2852 .07979 L
s
.5 g
.2852 .19542 m
.3018 .19542 L
.3018 .19542 L
.26825 .19542 L
.2852 .19542 L
F
.26825 .19542 m
.3018 .19542 L
.3018 .19542 L
.25865 .19542 L
.26825 .19542 L
F
.25865 .19542 m
.3018 .19542 L
.3018 .19542 L
.25554 .19542 L
.25865 .19542 L
F
.25554 .19542 m
.3018 .19542 L
.3018 .19542 L
.25865 .19542 L
.25554 .19542 L
F
.25865 .19542 m
.3018 .19542 L
.3018 .19542 L
.26825 .19542 L
.25865 .19542 L
F
.26825 .19542 m
.3018 .19542 L
.3018 .19542 L
.2852 .19542 L
.26825 .19542 L
F
0 g
.2852 .19542 m
.26825 .19542 L
.25865 .19542 L
.25554 .19542 L
.25865 .19542 L
.26825 .19542 L
.2852 .19542 L
.3018 .19542 L
.3018 .19542 L
.3018 .19542 L
.3018 .19542 L
.3018 .19542 L
.3018 .19542 L
.3018 .19542 L
.2852 .19542 L
s
.2852 .31106 m
.3018 .31106 L
.3018 .30712 L
.2852 .30712 L
.2852 .31106 L
s
.2852 .30712 m
.3018 .30712 L
.3018 .29556 L
.2852 .29556 L
.2852 .30712 L
s
.2852 .29556 m
.3018 .29556 L
.3018 .27719 L
.2852 .27719 L
.2852 .29556 L
s
.2852 .27719 m
.3018 .27719 L
.3018 .25324 L
.2852 .25324 L
.2852 .27719 L
s
.2852 .25324 m
.3018 .25324 L
.3018 .22535 L
.2852 .22535 L
.2852 .25324 L
s
.2852 .22535 m
.3018 .22535 L
.3018 .19542 L
.2852 .19542 L
.2852 .22535 L
s
.2852 .19542 m
.3018 .19542 L
.3018 .16549 L
.2852 .16549 L
.2852 .19542 L
s
.2852 .16549 m
.3018 .16549 L
.3018 .1376 L
.2852 .1376 L
.2852 .16549 L
s
.2852 .1376 m
.3018 .1376 L
.3018 .11365 L
.2852 .11365 L
.2852 .1376 L
s
.2852 .11365 m
.3018 .11365 L
.3018 .09528 L
.2852 .09528 L
.2852 .11365 L
s
.2852 .09528 m
.3018 .09528 L
.3018 .08373 L
.2852 .08373 L
.2852 .09528 L
s
.2852 .08373 m
.3018 .08373 L
.3018 .07979 L
.2852 .07979 L
.2852 .08373 L
s
.2852 .07979 m
.3018 .07979 L
.3018 .08373 L
.2852 .08373 L
.2852 .07979 L
s
.2852 .08373 m
.3018 .08373 L
.3018 .09528 L
.2852 .09528 L
.2852 .08373 L
s
.2852 .09528 m
.3018 .09528 L
.3018 .11365 L
.2852 .11365 L
.2852 .09528 L
s
.2852 .11365 m
.3018 .11365 L
.3018 .1376 L
.2852 .1376 L
.2852 .11365 L
s
.2852 .1376 m
.3018 .1376 L
.3018 .16549 L
.2852 .16549 L
.2852 .1376 L
s
.2852 .16549 m
.3018 .16549 L
.3018 .19542 L
.2852 .19542 L
.2852 .16549 L
s
.2852 .19542 m
.3018 .19542 L
.3018 .22535 L
.2852 .22535 L
.2852 .19542 L
s
.2852 .22535 m
.3018 .22535 L
.3018 .25324 L
.2852 .25324 L
.2852 .22535 L
s
.2852 .25324 m
.3018 .25324 L
.3018 .27719 L
.2852 .27719 L
.2852 .25324 L
s
.2852 .27719 m
.3018 .27719 L
.3018 .29556 L
.2852 .29556 L
.2852 .27719 L
s
.2852 .29556 m
.3018 .29556 L
.3018 .30712 L
.2852 .30712 L
.2852 .29556 L
s
.2852 .30712 m
.3018 .30712 L
.3018 .31106 L
.2852 .31106 L
.2852 .30712 L
s
.5 g
.80101 .16271 m
.80101 .16271 L
.81191 .17362 L
.81191 .17362 L
.80101 .16271 L
F
.81191 .17362 m
.81191 .17362 L
.82282 .18452 L
.82282 .18452 L
.81191 .17362 L
F
.82282 .18452 m
.82282 .18452 L
.83372 .19542 L
.83372 .19542 L
.82282 .18452 L
F
.83372 .19542 m
.83372 .19542 L
.84462 .20632 L
.84462 .20632 L
.83372 .19542 L
F
.84462 .20632 m
.84462 .20632 L
.85552 .21723 L
.85552 .21723 L
.84462 .20632 L
F
.85552 .21723 m
.85552 .21723 L
.86643 .22813 L
.86643 .22813 L
.85552 .21723 L
F
0 g
.80101 .16271 m
.81191 .17362 L
.82282 .18452 L
.83372 .19542 L
.84462 .20632 L
.85552 .21723 L
.86643 .22813 L
.86643 .22813 L
.85552 .21723 L
.84462 .20632 L
.83372 .19542 L
.82282 .18452 L
.81191 .17362 L
.80101 .16271 L
.80101 .16271 L
s
.5 g
.83372 .19542 m
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
F
.83372 .19542 m
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
F
.83372 .19542 m
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
F
.83372 .19542 m
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
F
.83372 .19542 m
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
F
.83372 .19542 m
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
F
0 g
.83372 .19542 m
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
s
.5 g
.83372 .19542 m
.84462 .20632 L
.84425 .20595 L
.83372 .19542 L
.83372 .19542 L
F
.84462 .20632 m
.85552 .21723 L
.85478 .21648 L
.84425 .20595 L
.84462 .20632 L
F
.85552 .21723 m
.86643 .22813 L
.86531 .22701 L
.85478 .21648 L
.85552 .21723 L
F
.83372 .19542 m
.84425 .20595 L
.84316 .20486 L
.83372 .19542 L
.83372 .19542 L
F
.84425 .20595 m
.85478 .21648 L
.8526 .2143 L
.84316 .20486 L
.84425 .20595 L
F
.85478 .21648 m
.86531 .22701 L
.86204 .22375 L
.8526 .2143 L
.85478 .21648 L
F
.83372 .19542 m
.84316 .20486 L
.84143 .20313 L
.83372 .19542 L
.83372 .19542 L
F
.84316 .20486 m
.8526 .2143 L
.84914 .21084 L
.84143 .20313 L
.84316 .20486 L
F
.8526 .2143 m
.86204 .22375 L
.85685 .21855 L
.84914 .21084 L
.8526 .2143 L
F
.83372 .19542 m
.84143 .20313 L
.83917 .20087 L
.83372 .19542 L
.83372 .19542 L
F
.84143 .20313 m
.84914 .21084 L
.84462 .20632 L
.83917 .20087 L
.84143 .20313 L
F
.84914 .21084 m
.85685 .21855 L
.85007 .21177 L
.84462 .20632 L
.84914 .21084 L
F
.83372 .19542 m
.83917 .20087 L
.83654 .19824 L
.83372 .19542 L
.83372 .19542 L
F
.83917 .20087 m
.84462 .20632 L
.83936 .20106 L
.83654 .19824 L
.83917 .20087 L
F
.84462 .20632 m
.85007 .21177 L
.84218 .20389 L
.83936 .20106 L
.84462 .20632 L
F
.83372 .19542 m
.83654 .19824 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
F
.83654 .19824 m
.83936 .20106 L
.83372 .19542 L
.83372 .19542 L
.83654 .19824 L
F
.83936 .20106 m
.84218 .20389 L
.83372 .19542 L
.83372 .19542 L
.83936 .20106 L
F
.83372 .19542 m
.83372 .19542 L
.8309 .1926 L
.83372 .19542 L
.83372 .19542 L
F
.83372 .19542 m
.83372 .19542 L
.82808 .18978 L
.8309 .1926 L
.83372 .19542 L
F
.83372 .19542 m
.83372 .19542 L
.82525 .18696 L
.82808 .18978 L
.83372 .19542 L
F
.83372 .19542 m
.8309 .1926 L
.82827 .18997 L
.83372 .19542 L
.83372 .19542 L
F
.8309 .1926 m
.82808 .18978 L
.82282 .18452 L
.82827 .18997 L
.8309 .1926 L
F
.82808 .18978 m
.82525 .18696 L
.81737 .17907 L
.82282 .18452 L
.82808 .18978 L
F
.83372 .19542 m
.82827 .18997 L
.82601 .18771 L
.83372 .19542 L
.83372 .19542 L
F
.82827 .18997 m
.82282 .18452 L
.8183 .18 L
.82601 .18771 L
.82827 .18997 L
F
.82282 .18452 m
.81737 .17907 L
.81059 .17229 L
.8183 .18 L
.82282 .18452 L
F
.83372 .19542 m
.82601 .18771 L
.82428 .18598 L
.83372 .19542 L
.83372 .19542 L
F
.82601 .18771 m
.8183 .18 L
.81484 .17654 L
.82428 .18598 L
.82601 .18771 L
F
.8183 .18 m
.81059 .17229 L
.80539 .1671 L
.81484 .17654 L
.8183 .18 L
F
.83372 .19542 m
.82428 .18598 L
.82319 .18489 L
.83372 .19542 L
.83372 .19542 L
F
.82428 .18598 m
.81484 .17654 L
.81266 .17436 L
.82319 .18489 L
.82428 .18598 L
F
.81484 .17654 m
.80539 .1671 L
.80213 .16383 L
.81266 .17436 L
.81484 .17654 L
F
.83372 .19542 m
.82319 .18489 L
.82282 .18452 L
.83372 .19542 L
.83372 .19542 L
F
.82319 .18489 m
.81266 .17436 L
.81191 .17362 L
.82282 .18452 L
.82319 .18489 L
F
.81266 .17436 m
.80213 .16383 L
.80101 .16271 L
.81191 .17362 L
.81266 .17436 L
F
.83372 .19542 m
.82282 .18452 L
.82319 .18489 L
.83372 .19542 L
.83372 .19542 L
F
.82282 .18452 m
.81191 .17362 L
.81266 .17436 L
.82319 .18489 L
.82282 .18452 L
F
.81191 .17362 m
.80101 .16271 L
.80213 .16383 L
.81266 .17436 L
.81191 .17362 L
F
.83372 .19542 m
.82319 .18489 L
.82428 .18598 L
.83372 .19542 L
.83372 .19542 L
F
.82319 .18489 m
.81266 .17436 L
.81484 .17654 L
.82428 .18598 L
.82319 .18489 L
F
.81266 .17436 m
.80213 .16383 L
.80539 .1671 L
.81484 .17654 L
.81266 .17436 L
F
.83372 .19542 m
.82428 .18598 L
.82601 .18771 L
.83372 .19542 L
.83372 .19542 L
F
.82428 .18598 m
.81484 .17654 L
.8183 .18 L
.82601 .18771 L
.82428 .18598 L
F
.81484 .17654 m
.80539 .1671 L
.81059 .17229 L
.8183 .18 L
.81484 .17654 L
F
.83372 .19542 m
.82601 .18771 L
.82827 .18997 L
.83372 .19542 L
.83372 .19542 L
F
.82601 .18771 m
.8183 .18 L
.82282 .18452 L
.82827 .18997 L
.82601 .18771 L
F
.8183 .18 m
.81059 .17229 L
.81737 .17907 L
.82282 .18452 L
.8183 .18 L
F
.83372 .19542 m
.82827 .18997 L
.8309 .1926 L
.83372 .19542 L
.83372 .19542 L
F
.82827 .18997 m
.82282 .18452 L
.82808 .18978 L
.8309 .1926 L
.82827 .18997 L
F
.82282 .18452 m
.81737 .17907 L
.82525 .18696 L
.82808 .18978 L
.82282 .18452 L
F
.83372 .19542 m
.8309 .1926 L
.83372 .19542 L
.83372 .19542 L
.83372 .19542 L
F
.8309 .1926 m
.82808 .18978 L
.83372 .19542 L
.83372 .19542 L
.8309 .1926 L
F
.82808 .18978 m
.82525 .18696 L
.83372 .19542 L
.83372 .19542 L
.82808 .18978 L
F
.83372 .19542 m
.83372 .19542 L
.83654 .19824 L
.83372 .19542 L
.83372 .19542 L
F
.83372 .19542 m
.83372 .19542 L
.83936 .20106 L
.83654 .19824 L
.83372 .19542 L
F
.83372 .19542 m
.83372 .19542 L
.84218 .20389 L
.83936 .20106 L
.83372 .19542 L
F
.83372 .19542 m
.83654 .19824 L
.83917 .20087 L
.83372 .19542 L
.83372 .19542 L
F
.83654 .19824 m
.83936 .20106 L
.84462 .20632 L
.83917 .20087 L
.83654 .19824 L
F
.83936 .20106 m
.84218 .20389 L
.85007 .21177 L
.84462 .20632 L
.83936 .20106 L
F
.83372 .19542 m
.83917 .20087 L
.84143 .20313 L
.83372 .19542 L
.83372 .19542 L
F
.83917 .20087 m
.84462 .20632 L
.84914 .21084 L
.84143 .20313 L
.83917 .20087 L
F
.84462 .20632 m
.85007 .21177 L
.85685 .21855 L
.84914 .21084 L
.84462 .20632 L
F
.83372 .19542 m
.84143 .20313 L
.84316 .20486 L
.83372 .19542 L
.83372 .19542 L
F
.84143 .20313 m
.84914 .21084 L
.8526 .2143 L
.84316 .20486 L
.84143 .20313 L
F
.84914 .21084 m
.85685 .21855 L
.86204 .22375 L
.8526 .2143 L
.84914 .21084 L
F
.83372 .19542 m
.84316 .20486 L
.84425 .20595 L
.83372 .19542 L
.83372 .19542 L
F
.84316 .20486 m
.8526 .2143 L
.85478 .21648 L
.84425 .20595 L
.84316 .20486 L
F
.8526 .2143 m
.86204 .22375 L
.86531 .22701 L
.85478 .21648 L
.8526 .2143 L
F
.83372 .19542 m
.84425 .20595 L
.84462 .20632 L
.83372 .19542 L
.83372 .19542 L
F
.84425 .20595 m
.85478 .21648 L
.85552 .21723 L
.84462 .20632 L
.84425 .20595 L
F
.85478 .21648 m
.86531 .22701 L
.86643 .22813 L
.85552 .21723 L
.85478 .21648 L
F
0 g
.86643 .22813 m
.86531 .22701 L
.86204 .22375 L
.85685 .21855 L
.85007 .21177 L
.84218 .20389 L
.83372 .19542 L
.82525 .18696 L
.81737 .17907 L
.81059 .17229 L
.80539 .1671 L
.80213 .16383 L
.80101 .16271 L
.80213 .16383 L
.80539 .1671 L
.81059 .17229 L
.81737 .17907 L
.82525 .18696 L
.83372 .19542 L
.84218 .20389 L
.85007 .21177 L
.85685 .21855 L
.86204 .22375 L
.86531 .22701 L
.86643 .22813 L
s
.94935 .42669 m
.91081 .42669 L
.87226 .42669 L
.83372 .42669 L
.79517 .42669 L
.75663 .42669 L
.71808 .42669 L
.71808 .42669 L
.75663 .42669 L
.79517 .42669 L
.83372 .42669 L
.87226 .42669 L
.91081 .42669 L
.94935 .42669 L
.94935 .42669 L
s
.83372 .42669 m
.83372 .42669 L
.83372 .42669 L
.83372 .42669 L
.83372 .42669 L
.83372 .42669 L
.83372 .42669 L
.83372 .42669 L
.83372 .42669 L
.83372 .42669 L
.83372 .42669 L
.83372 .42669 L
.83372 .42669 L
.83372 .42669 L
.83372 .42669 L
s
.71808 .42669 m
.72202 .42669 L
.73358 .42669 L
.75195 .42669 L
.7759 .42669 L
.80379 .42669 L
.83372 .42669 L
.86365 .42669 L
.89154 .42669 L
.91549 .42669 L
.93386 .42669 L
.94541 .42669 L
.94935 .42669 L
.94541 .42669 L
.93386 .42669 L
.91549 .42669 L
.89154 .42669 L
.86365 .42669 L
.83372 .42669 L
.80379 .42669 L
.7759 .42669 L
.75195 .42669 L
.73358 .42669 L
.72202 .42669 L
.71808 .42669 L
s
.039 .916 .04 r
.02411 .08441 m
.28313 .08363 L
s
% Start of user PostScript
-0.0359997 -23.9999 55.9643 -24.1679 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.28313 .08363 Mdot
.039 .916 .04 r
.5 Mabswid
.02425 .15842 m
.25845 .15818 L
s
% Start of user PostScript
-0.004 -8. 50.6276 -8.05063 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.25845 .15818 Mdot
.039 .916 .04 r
.5 Mabswid
.02425 .23242 m
.25845 .23266 L
s
% Start of user PostScript
-0.004 8. 50.6276 8.05063 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.25845 .23266 Mdot
.039 .916 .04 r
.5 Mabswid
.02411 .30643 m
.28313 .30721 L
s
% Start of user PostScript
-0.0359997 23.9999 55.9643 24.1679 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.28313 .30721 Mdot
.039 .916 .04 r
.5 Mabswid
.28313 .08363 m
.3018 .08685 L
s
% Start of user PostScript
55.9643 -24.1679 60. -23.4718 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.3018 .08685 Mdot
.039 .916 .04 r
.5 Mabswid
.25845 .15818 m
.3018 .16047 L
s
% Start of user PostScript
50.6276 -8.05063 60. -7.55576 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.3018 .16047 Mdot
.039 .916 .04 r
.5 Mabswid
.25845 .23266 m
.3018 .23037 L
s
% Start of user PostScript
50.6276 8.05063 60. 7.55576 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.3018 .23037 Mdot
.039 .916 .04 r
.5 Mabswid
.28313 .30721 m
.3018 .30399 L
s
% Start of user PostScript
55.9643 24.1679 60. 23.4718 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.3018 .30399 Mdot
.039 .916 .04 r
.5 Mabswid
.3018 .16047 m
.84219 .2039 L
s
% Start of user PostScript
60. -7.55576 176.832 1.83209 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.84219 .2039 Mdot
.039 .916 .04 r
.5 Mabswid
.3018 .23037 m
.82651 .18821 L
s
% Start of user PostScript
60. 7.55576 173.44 -1.55956 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82651 .18821 Mdot
.039 .916 .04 r
.5 Mabswid
.3018 .30399 m
.80721 .16891 L
s
% Start of user PostScript
60. 23.4718 169.269 -5.73119 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.80721 .16891 Mdot
.039 .916 .04 r
.5 Mabswid
.84219 .2039 m
.8601 .42669 L
s
% Start of user PostScript
176.832 1.83209 180.703 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.8601 .42669 Mdot
.039 .916 .04 r
.5 Mabswid
.82651 .18821 m
.80734 .42669 L
s
% Start of user PostScript
173.44 -1.55956 169.297 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.80734 .42669 Mdot
.039 .916 .04 r
.5 Mabswid
.80721 .16891 m
.73832 .42669 L
s
% Start of user PostScript
169.269 -5.73119 154.374 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.73832 .42669 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .01041 m
.02381 .01041 L
s
0 0 0 r
2 Mabswid
.02381 .01041 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .38044 m
.02381 .38044 L
s
0 0 0 r
2 Mabswid
.02381 .38044 Mdot
gsave
.27867 .05295 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78204 .14374 -67.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
71.875 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .42669 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .4371 L
0 .4371 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[159]:=",
  ImageSize->{288, 125.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000OB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`002_ooool2o`000?oooooo5Oooool000[ooooo0_l0003ooooooaGooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo001>ooooo`Ko0000c?ooool004oooooo
00Go0000ooooooooooooooooo`00003<ooooo`00Coooool00ol0003oooooooooo`3>ooooo`00Cooo
ool00ol0003oooooooooo`3>ooooo`00Coooool00ol0003oooooooooo`3>ooooo`00Coooool00ol0
003oooooooooo`3>ooooo`00C_ooool3o`000<oooooo003oooooob7ooooo001@ooooo`;o2NX:c_oo
ool004_ooooo0ol9jPX2ooooo`Co2NX:c?ooool004cooooo2_l9jPX3o`000<Oooooo000:ooooodgo
2NX:0_l00037ooooo`00C?ooool;o`WZ2P;o0000aoooool004_ooooo0_l9jPX5ooooo`;o00001?mo
Ogl00ol0003oooooooooo`35ooooo`00DOooool00ol0003oOgmoo`000005o`000<Oooooo001Aoooo
o`03o`000?moOgoo000000CoOgmo00?o0000ooooooooool0aOooool0053ooooo00Co0000ogmoOomo
Ogoo00001?moOgl00ol0003oooooooooo`35ooooo`00D?ooool01?l0003oOgmoogmoOol00004ogmo
O`03o`000?oooooooooo0<Gooooo001@ooooo`04o`000?moOgooOgmoo`0000CoOgmo00?o0000oooo
ooooool0aOooool004oooooo00Co0000ogmoOomoOgooOgmo1_l00037ooooo`00Coooool01Ol0003o
OgmoogmoOomoOgoo000000CoOgmo00?o0000ooooooooool0aOooool004kooooo00?o0000ogmoOomo
Ogl00_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo0<Gooooo001>ooooo`03o`00
0?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`35ooooo`00C_oo
ool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0aOoo
ool004gooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooo
oooo0<Gooooo001=ooooo`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0
003oooooooooo`35ooooo`00COooool00ol0003oOgmoogmoO`03ogmoO`Ko0000P?ooool3o`000003
ooooool0003ooooo00?o0000?_ooool004gooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmo
ogmoO`02ogmoO`03o`000?oooooooooo07oooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0mooooo`00COooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00;oOgmo
00?o0000ooooooooool0Ooooool01ol0003oooooo`000?oooooo0000ooooool00000?oooool004co
oooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo07oo
oooo00Oo0000ooooool0003oooooo`000?oooooo000003oooooo0014ooooo`?o2NX:1Oooool01?l0
003oOgmoogmoOomoOgl3o`WZ2P03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0Ooooool2
o`0000?ooooo0_l0000oooooo`00AOooool6o`WZ2P;o00001?moOgl6o`WZ2P03ogmoOol0003ooooo
083ooooo0_l00003ooooo`;o0000?oooool000[ooooo@Ol9jPX00ol0003o2NX:o`WZ2P09o`WZ2P03
o`000?l9jP[o2NX:00Go2NX:N_ooool2o`0000Gooooo0_l0000nooooo`00AOooool5o`WZ2P;ooooo
00?o0000ogmoOomoOgl00_moOgl5o`WZ2P03ogmoOol0003o000000Kooooo3Ol9jPYgooooo`03o`00
0?oooooooooo03[ooooo0014ooooo`;o2NX:1_ooool01?l0003oOgmoogmoOomoOgl2o`WZ2P03ogmo
Ool0003o000000Co00004oooool<o`WZ2Vcooooo0_l0000jooooo`00C?ooool00ol0003oOgmoogmo
O`04ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool07Oooool=o`WZ2UOooooo2?l9
jPX00ol0003o2NX:ooooo`0iooooo`00C?ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgoo
Ogmo00;oOgmo00?o0000ooooooooool0:_ooool<o`WZ2Tkooooo1Ol9jPX00ooooooo2NX:o`00000i
ooooo`00Boooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000oooo
ooooool0=_ooool=o`WZ2Sgooooo1ol9jPX3ooooo`03o`WZ2_l0003o000003Sooooo001;ooooo`03
o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`13ooooo`co
2NX:;_ooool3o`WZ2P?ooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo00;o0000=oooool004_ooooo
00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo04oooooo
3Ol9jPXMooooo`Co2NX:1Oooool00ol9jP[oooooooooo`02ooooo`Go2NX:0_ooool00ol0003ooooo
ooooo`0dooooo`00Boooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00;oOgmo00?o
0000ooooooooool0G?ooool<o`WZ2Pgooooo1?l9jPX?ooooo`Ko2NX:00?o0000o`WZ2_ooool0=?oo
ool004_ooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooo
oooo06Sooooo3Ol9jPX8oooooa7o2NX:00?o0000o`WZ2_l00000=?ooool004_ooooo3_l0001_oooo
oaCo2NX:1oooool6o`WZ2P04ooooool9jP[oooooo`0003?ooooo001;ooooo`03o`000?moOgooOgmo
00GoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1Tooooo`go2NX:4?oooolAo`WZ
2P03o`000?oooooooooo033ooooo001;ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomo
Ogl00_moOgl00ol0003oooooooooo`1Hooooo`co2NX:0_ooool4o`WZ2Qkooooo00?o2NX:oooooooo
ool00_ooool7o`WZ2P03o`000?oooooooooo02kooooo001;ooooo`03o`000?moOgooOgmo00GoOgmo
00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1<ooooo`co2NX:2_ooool4o`WZ2R7ooooo
00?o2NX:ooooooooool00_ooool5o`WZ2P;ooooo00?o2NX:o`000?ooool0;oooool004_ooooo00?o
0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo043ooooo3?l9
jPXBooooo`Co2NX:9Oooool01?l9jP[oooooooooooooool2o`WZ2P;ooooo00Oo2NX:oooooooooooo
ooooo`WZ2_oooooo000002oooooo001;ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomo
Ogl00_moOgl00ol0003oooooooooo`0dooooo`co2NX:6_ooool4o`WZ2RWooooo00?o2NX:oooooooo
ool01Oooool02?l9jP[ooooooooooooooooo2NX:oooooomoOgoo0000;_ooool004cooooo00?o0000
ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo02Sooooo3?l9jPXS
ooooo`?o2NX:;?ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00_l0000]ooooo`00C?ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo
00;oOgmo00?o0000ooooooooool06oooool=o`WZ2R_ooooo1?l9jPX_ooooo`03o`WZ2_oooooooooo
00Gooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooooooooooool2o`0002cooooo0014oooo
o`?o2NX:1Oooool01?l0003oOgmoogmoOomoOgl3o`WZ2PKo00004Oooool<o`WZ2SCooooo1?l9jPXc
ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`000?oooooooooo02Wooooo0015ooooo`Ko2NX:00?oooooo`000?moOgl00omoOgl6o`WZ
2P;o00001Oooool<o`WZ2Scooooo1?l9jPXgooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo000:oooood7o
2NX:00?o0000o`WZ2_l9jPX02Ol9jPX00ol0003o2NX:o`WZ2P04o`WZ2TCooooo1?l9jPXjooooo`03
o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0^ooooo`00
AOooool5o`WZ2P03ooooool0003o000000CoOgmo1Ol9jPX2ogmoO`03o`000?oooooooooo04?ooooo
1?l9jPXnooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`0^ooooo`00A?ooool2o`WZ2PKooooo00Co0000ogmoOomoOgooOgmo0_l9jPX00omoOgoo0000
ogmoO`03ogmoO`03o`000?oooooooooo043ooooo0ol9jPY2ooooo`03o`WZ2_oooooooooo00Kooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0^ooooo`00C?ooool00ol0003oOgmoogmo
O`04ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0??ooool4o`WZ2TGooooo00?o
2NX:ooooooooool01_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo02kooooo001<
ooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`0h
ooooo`Co2NX:B?ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool0;_ooool004gooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`02ogmo
O`03o`000?oooooooooo03Cooooo1?l9jPY<ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`0^ooooo`00COooool00ol0003oOgmoogmoO`03ogmoO`Ko
0000<_ooool4o`WZ2U3ooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo02kooooo001=ooooo`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl0
0_moOgl00ol0003oooooooooo`0]ooooo`?o2NX:Doooool00ol9jP[oooooooooo`08ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool0;_ooool004gooooo00?o0000ogmoOomoOgl00omo
Ogl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo02Wooooo1?l9jPYFooooo`03o`WZ2_oo
oooooooo00Sooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0^ooooo`00COooool0
0ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool09Oooool4
o`WZ2U[ooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo02kooooo001>ooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0
003oooooooooo`0Qooooo`Co2NX:G_ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool0;_ooool004kooooo00?o0000ogmoOomoOgl00_moOgl00ol0003o
OgmoogmoO`02ogmoO`03o`000?oooooooooo01gooooo1?l9jPYQooooo`03o`WZ2_oooooooooo00So
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0^ooooo`00C_ooool00ol0003oOgmo
ogmoO`02ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool06_ooool3o`WZ2VGooooo
00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo02gooooo
001>ooooo`03o`000?moOgooOgmo00;oOgmo1_l0000Hooooo`Co2NX:J?ooool00ol9jP[ooooooooo
o`08ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool0;Oooool004oooooo00Go0000
ogmoOomoOgooOgmoo`000004ogmoO`03o`000?oooooooooo01;ooooo1?l9jPY[ooooo`03o`WZ2_oo
oooooooo00Wooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0]ooooo`00Coooool0
1Ol0003oOgmoogmoOomoOgoo000000CoOgmo00?o0000ooooooooool03_ooool4o`WZ2Voooooo00?o
2NX:ooooooooool02Oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo02gooooo001@
ooooo`04o`000?moOgooOgmoo`0000CoOgmo00?o0000ooooooooool02_ooool4o`WZ2W?ooooo00?o
2NX:ooooooooool02Oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo02gooooo001@
ooooo`04o`000?moOgooOgmoo`0000CoOgmo00?o0000ooooooooool01oooool3o`WZ2WOooooo00?o
2NX:ooooooooool02Oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo02gooooo001A
ooooo`03o`000?moOgoo000000Go00001Oooool4o`WZ2WWooooo00?o2NX:ooooooooool02_ooool0
0ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo02gooooo001;ooooo`?o2NX:0oooool00ol0
003oOgmoo`000004ogmoO`03o`000?oooooo2NX:00?o2NX:OOooool00ol9jP[oooooooooo`0:oooo
o`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool0;Oooool004cooooo2ol9jPX00ol0003o
2NX:o`WZ2P21ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool01Oooool00ol9jP[o
ooooooooo`0]ooooo`002_oooom=o`WZ2P;o0000POooool00ol9jP[oooooooooo`0;ooooo`03o`WZ
2_oooooooooo00Gooooo00?o2NX:ooooooooool0;Oooool004cooooo1Ol9jPX01?oooooo2NX:o`WZ
2_l9jPX4o`00087ooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ
2_oooooooooo02gooooo001;ooooo`;o2NX:1?ooool2o`WZ2XOooooo00?o2NX:ooooooooool02_oo
ool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo02gooooo001@ooooo`03o`WZ2_oooooo
oooo08Oooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooo
oooo02cooooo003Iooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool01oooool00ol9
jP[oooooooooo`0/ooooo`00fOooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo00Oo
oooo00?o2NX:ooooooooool0;?ooool00=Wooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooo
ooooo`07ooooo`03o`WZ2_oooooooooo02cooooo003Hooooo`03o`WZ2_oooooooooo00cooooo00?o
2NX:ooooooooool01oooool00ol9jP[oooooooooo`0/ooooo`00f?ooool00ol9jP[oooooooooo`0<
ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool0;?ooool00=Sooooo00?o2NX:oooo
ooooool03?ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo02cooooo003Hooooo`03
o`WZ2_oooooooooo00cooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0/ooooo`00
eoooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool0
;?ooool00=Oooooo00?o2NX:ooooooooool03Oooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oo
oooooooo02cooooo003Gooooo`03o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool01oooool0
0ol9jP[oooooooooo`0/ooooo`00e_ooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo
00Sooooo00?o2NX:ooooooooool0;?ooool00=Kooooo00?o2NX:ooooooooool03Oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo02_ooooo003Fooooo`03o`WZ2_oooooooooo00gooooo
00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0[ooooo`00e_ooool00ol9jP[ooooooooo
o`0=ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool0:oooool00=Gooooo00?o2NX:
ooooooooool03_ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo02_ooooo003Eoooo
o`03o`WZ2_oooooooooo00kooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0[oooo
o`002_ooool2o`000<Wooooo00?o2NX:ooooooooool03_ooool00ol9jP[oooooooooo`09ooooo`03
o`WZ2_oooooooooo02_ooooo000:ooooo`;o0000bOooool00ol9jP[oooooooooo`0>ooooo`03o`WZ
2_oooooooooo00Wooooo00?o2NX:ooooooooool0:oooool00=Cooooo00?o2NX:ooooooooool03ooo
ool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo02_ooooo003Dooooo`03o`WZ2_oooooo
oooo00oooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0[ooooo`00e?ooool00ol9
jP[oooooooooo`0?ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool0:oooool00=;o
oooo0_l9jPX?ooooo`04o`WZ2_ooooooooooo`WZ2P_ooooo00Co2NX:oooooooooooo2NX::_ooool0
0=;ooooo0_l9jPX00ooooooo2NX:ooooo`0<ooooo`03o`WZ2_oooooooooo00;o2NX:2Oooool2o`WZ
2P;ooooo00?o2NX:ooooooooool0:?ooool00=;ooooo1?l9jPX=ooooo`Go2NX:2Oooool2o`WZ2P03
ooooool9jP[o2NX:02[ooooo003Booooo`?o2NX:3oooool4o`WZ2PWooooo1?l9jPX[ooooo`00d_oo
ool3o`WZ2Poooooo0ol9jPX;ooooo`?o2NX::oooool00=7ooooo0ol9jPX@ooooo`?o2NX:2oooool3
o`WZ2R_ooooo003Aooooo`;o2NX:4Oooool3o`WZ2P_ooooo0ol9jPXMooooo`?o00002oooool00=7o
oooo0_l9jPXBooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool07?ooool01?l0003o
ooooooooool0000:ooooo`00c?oooom1o`0000Sooooo00?o0000ooooooooool02?ooool00=7ooooo
0_l0000Aooooo`;o00003Oooool2o`0001kooooo0_l0000;ooooo`00oooooolCooooo`03o`000?oo
oooooooo00_ooooo003ooooooa?ooooo00Co0000oooooooooooo00002_ooool00?oooooo5?ooool3
o`0000[ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {124.875, 0}} -> {-8.5087, -42.2499, 0.776026, \
0.776026}},
  CellTags->{"AOG3.", "AOG3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[opticalsystemreflected,{f>0},MatrixForm->True]\
\>", "Input",
  CellLabel->"In[160]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(\(-0.9984247383017905`\)\ d1\^2 + 
                    d1\ \((\(\(224.64556611790286`\)\(\[InvisibleSpace]\)\) - 
                          0.34116124085556565`\ t)\) + 
                    f\ \((\(-224.822713213163`\) + f + 
                          0.3414302678560861`\ t)\)\)\/\(f\ \
\@\(0.9984247383017905`\ d1\^2 - 1.9984241174503379`\ d1\ f + f\^2\)\)\), \
\(\(\(-0.9984247383017905`\)\ d1\^3 + 
                    f\^2\ \((\(\(225.`\)\(\[InvisibleSpace]\)\) - 
                          0.3416995070012418`\ t)\) + 
                    d1\^2\ \((\(\(224.64556611790286`\)\(\[InvisibleSpace]\)\)\
 + 0.9992120587251689`\ f - 0.34116124085556565`\ t)\) + 
                    d1\ f\ \((\(-449.645426426326`\) + 
                          0.6828605357121722`\ t)\)\)\/\(f\ \
\@\(0.9984247383017905`\ d1\^2 - 1.9984241174503379`\ d1\ f + f\^2\)\)\)},
            {\(\(0.9984247383017907`\ d1 - 
                    0.9992120587251692`\ f\)\/\(f\ \@\(0.9984247383017905`\ \
d1\^2 - 1.9984241174503379`\ d1\ f + f\^2\)\)\), \(\(1.0000000000000004`\ \
\@\(0.9984247383017905`\ d1\^2 - 1.9984241174503379`\ d1\ f + f\^2\)\)\/f\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[160]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[opticalsystemreflected,{f>0},MatrixForm->True,DecomposeABCD->\
True]\
\>", "Input",
  CellLabel->"In[161]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      "1", \(\(\@\((\(-0.9992120587251689`\)\ d1 + f)\)\^2\ \
\((0.9984247383017905`\ d1\^2 - 1.9984241174503379`\ d1\ f + f\^2)\)\^\(3/2\)\
\ \((\(-0.9984247383017905`\)\ d1\^2 + 
                                  d1\ \((\(\(174.72432920281332`\)\(\
\[InvisibleSpace]\)\) - 0.34116124085556565`\ t)\) + 
                                  f\ \((\(-174.86211027690456`\) + f + 
                                        0.3414302678560861`\ t)\))\)\ \
\((\(-0.9984247383017905`\)\ d1\^3 + 
                                  f\^2\ \((\(\(225.`\)\(\[InvisibleSpace]\)\) \
- 0.3416995070012418`\ t)\) + 
                                  d1\^2\ \((\(\(224.64556611790286`\)\(\
\[InvisibleSpace]\)\) + 0.9992120587251689`\ f - 0.34116124085556565`\ t)\) + 
                                  d1\ f\ \((\(-449.645426426326`\) + 
                                        0.6828605357121722`\ t)\))\) - \
\((\(-0.9992120587251689`\)\ d1 + f)\)\^2\ \((0.9984247383017905`\ d1\^2 - 
                                  1.9984241174503379`\ d1\ f + 
                                  f\^2)\)\ \((\(-0.9984247383017905`\)\ d1\^2 \
+ d1\ \((\(\(224.64556611790286`\)\(\[InvisibleSpace]\)\) - 
                                        0.34116124085556565`\ t)\) + 
                                  f\ \((\(-224.822713213163`\) + f + 
                                        0.3414302678560861`\ t)\))\)\ \
\((\(-0.9984247383017905`\)\ d1\^3 + 
                                  f\^2\ \((\(\(175.`\)\(\[InvisibleSpace]\)\) \
- 0.3416995070012418`\ t)\) + 
                                  d1\^2\ \((\(\(174.72432920281332`\)\(\
\[InvisibleSpace]\)\) + 0.9992120587251689`\ f - 0.34116124085556565`\ t)\) + 
                                  d1\ f\ \((\(-349.7242205538091`\) + 
                                        0.6828605357121722`\ t)\))\)\)\/\(\((\
\(-0.9992120587251689`\)\ d1 + f)\)\^4\ \((0.9984247383017907`\ d1\^2\ f\^2 - 
                                1.9984241174503388`\ d1\ f\^3 + 
                                1.0000000000000004`\ f\^4)\)\)\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {
                      "0", \(\(0.9984247383017915`\ d1\^2 - 
                            1.9984241174503388`\ d1\ f + 
                            1.0000000000000004`\ \
f\^2\)\/\(0.9984247383017905`\ d1\^2 - 1.9984241174503379`\ d1\ f + f\^2\)\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      "1", \(\(\(-0.9984247383017905`\)\ d1\^3 + 
                            f\^2\ \((\(\(175.`\)\(\[InvisibleSpace]\)\) - 
                                  1.`\ t)\) + 
                            d1\^2\ \((\(\(174.7243292028133`\)\(\
\[InvisibleSpace]\)\) + 1.9984241174503379`\ f - 0.9984247383017903`\ t)\) + 
                            d1\ f\ \((\(-349.7242205538091`\) - 1.`\ f + 
                                  1.9984241174503379`\ \
t)\)\)\/\(0.9984247383017906`\ d1\^2 - 1.9984241174503379`\ d1\ f + 
                            f\^2\)\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(\((0.4326768843989378`\ d1\^2 - 0.8660361544294465`\ \
d1\ f + 0.43335953908240804`\ f\^2)\)\^\(3/2\)\ \((0.4319953050752434`\ d1\^4 \
- 1.7293438416922178`\ d1\^3\ f + 2.596061306393626`\ d1\^2\ f\^2 - 
                                1.7320723088588932`\ d1\ f\^3 + 
                                0.43335953908240804`\ \
f\^4)\)\)\/\(\((0.9984247383017905`\ d1\^2 - 1.9984241174503379`\ d1\ f + \
f\^2)\)\^\(3/2\)\ \((0.12323996546074067`\ d1\^4 - 
                                0.4933485915611333`\ d1\^3\ f + 
                                0.7406064417255414`\ d1\^2\ f\^2 - 
                                0.49412697085236934`\ d1\ f\^3 + 
                                0.1236291552272684`\ f\^4)\)\)\), \
\(\(\((\(-0.6577817908690828`\)\ d1 + 
                                0.6583004929987581`\ f)\)\ \
\((\(-0.6567456124081474`\)\ d1\^3 + 1.9717904923386749`\ d1\^2\ f - 
                                1.9733453726072487`\ d1\ f\^2 + 
                                
                                0.6583004929987581`\ f\^3)\)\ \
\((\(\((0.4326768843989378`\ d1\^2 - 0.8660361544294465`\ d1\ f + \
0.43335953908240804`\ f\^2)\)\^\(3/2\)\ \((0.12323996546074067`\ d1\^4 - \
0.4933485915611333`\ d1\^3\ f + 0.7406064417255414`\ d1\^2\ f\^2 - \
0.49412697085236934`\ d1\ f\^3 + 0.1236291552272684`\ \
f\^4)\)\)\/\((0.9984247383017905`\ d1\^2 - 1.9984241174503379`\ d1\ f + f\^2)\
\)\^\(3/2\) - \(\((0.4326768843989378`\ d1\^2 - 0.8660361544294465`\ d1\ f + \
0.43335953908240804`\ f\^2)\)\^3\ \((0.4319953050752434`\ d1\^4 - \
1.7293438416922178`\ d1\^3\ f + 2.596061306393626`\ d1\^2\ f\^2 - \
1.7320723088588932`\ d1\ f\^3 + 0.43335953908240804`\ \
f\^4)\)\)\/\((0.9984247383017905`\ d1\^2 - 1.9984241174503379`\ d1\ f + f\^2)\
\)\^3)\)\ t\)\/\((0.12323996546074067`\ d1\^4 - 0.4933485915611333`\ d1\^3\ f \
+ 0.7406064417255414`\ d1\^2\ f\^2 - 0.49412697085236934`\ d1\ f\^3 + \
0.1236291552272684`\ f\^4)\)\^2\)},
                    {
                      "0", \(\(0.9984247383017905`\ d1\^2 - 
                            1.9984241174503379`\ d1\ f + 
                            1.`\ f\^2\)\/\(\@\(0.4326768843989378`\ d1\^2 - \
0.8660361544294465`\ d1\ f + 0.43335953908240804`\ f\^2\)\ \
\@\(0.9984247383017905`\ d1\^2 - 1.9984241174503379`\ d1\ f + f\^2\)\)\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      "1", \(\(\((\(-0.6577817908690828`\)\ d1 + 
                                0.6583004929987581`\ f)\)\ \
\((0.4326768843989378`\ d1\^2 - 0.8660361544294465`\ d1\ f + \
0.43335953908240804`\ f\^2)\)\^\(3/2\)\ \((\(-0.6567456124081474`\)\ d1\^3\ f\
\ t + 1.9717904923386749`\ d1\^2\ f\^2\ t - 
                                1.9733453726072487`\ d1\ f\^3\ t + 
                                0.6583004929987583`\ f\^4\ t)\)\)\/\(f\ \
\((0.9984247383017905`\ d1\^2 - 1.9984241174503379`\ d1\ f + f\^2)\)\^\(3/2\)\
\ \((0.12323996546074067`\ d1\^4 - 0.4933485915611333`\ d1\^3\ f + 
                                0.7406064417255414`\ d1\^2\ f\^2 - 
                                0.49412697085236934`\ d1\ f\^3 + 
                                0.1236291552272684`\ f\^4)\)\)\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(\(-0.6577817908690828`\)\ d1 + 
                            0.6583004929987581`\ f\)\/\@\(0.4326768843989378`\
\ d1\^2 - 0.8660361544294465`\ d1\ f + 0.43335953908240804`\ f\^2\)\), \(d1\ \
\((\(-0.6577817908690828`\)\ d1 + 
                            0.6583004929987581`\ f)\)\ \
\((\(0.6577817908690828`\ d1 - 0.6583004929987581`\ \
f\)\/\(0.4326768843989378`\ d1\^2 - 0.8660361544294465`\ d1\ f + \
0.43335953908240804`\ f\^2\) + 
                            1\/\@\(0.4326768843989378`\ d1\^2 - \
0.8660361544294465`\ d1\ f + 0.43335953908240804`\ f\^2\))\)\)},
                    {\(\(0.4326768843989378`\ d1 - 
                            0.43301807721472324`\ f\)\/\(f\ \
\@\(0.4326768843989378`\ d1\^2 - 0.8660361544294465`\ d1\ f + \
0.43335953908240804`\ f\^2\)\)\), \(\(0.6577817908690828`\ d1 + \
\@\(0.4326768843989378`\ d1\^2 - 0.8660361544294465`\ d1\ f + \
0.43335953908240804`\ f\^2\)\)\/f\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      "1", \(\(d1\ \((\(-0.6577817908690828`\)\ d1 + 
                                0.6583004929987581`\ \
f)\)\)\/\@\(0.4326768843989378`\ d1\^2 - 0.8660361544294465`\ d1\ f + \
0.43335953908240804`\ f\^2\)\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        MatrixForm[ {{1, 0}, {0, 1}}], 
        MatrixForm[ {{1, 
          Times[ 
            Power[ 
              Plus[ 
                Times[ -0.99921205872516894, d1], f], -4], 
            Power[ 
              Plus[ 
                Times[ 0.99842473830179068, 
                  Power[ d1, 2], 
                  Power[ f, 2]], 
                Times[ -1.9984241174503388, d1, 
                  Power[ f, 3]], 
                Times[ 1.0000000000000004, 
                  Power[ f, 4]]], -1], 
            Plus[ 
              Times[ 
                Power[ 
                  Power[ 
                    Plus[ 
                      Times[ -0.99921205872516894, d1], f], 2], 
                  Rational[ 1, 2]], 
                Power[ 
                  Plus[ 
                    Times[ 0.99842473830179046, 
                      Power[ d1, 2]], 
                    Times[ -1.9984241174503379, d1, f], 
                    Power[ f, 2]], 
                  Rational[ 3, 2]], 
                Plus[ 
                  Times[ -0.99842473830179046, 
                    Power[ d1, 2]], 
                  Times[ d1, 
                    Plus[ 174.72432920281332, 
                      Times[ -0.34116124085556565, t]]], 
                  Times[ f, 
                    Plus[ -174.86211027690456, f, 
                      Times[ 0.3414302678560861, t]]]], 
                Plus[ 
                  Times[ -0.99842473830179046, 
                    Power[ d1, 3]], 
                  Times[ 
                    Power[ f, 2], 
                    Plus[ 225.0, 
                      Times[ -0.3416995070012418, t]]], 
                  Times[ 
                    Power[ d1, 2], 
                    Plus[ 224.64556611790286, 
                      Times[ 0.99921205872516894, f], 
                      Times[ -0.34116124085556565, t]]], 
                  Times[ d1, f, 
                    Plus[ -449.64542642632603, 
                      Times[ 0.6828605357121722, t]]]]], 
              Times[ -1, 
                Power[ 
                  Plus[ 
                    Times[ -0.99921205872516894, d1], f], 2], 
                Plus[ 
                  Times[ 0.99842473830179046, 
                    Power[ d1, 2]], 
                  Times[ -1.9984241174503379, d1, f], 
                  Power[ f, 2]], 
                Plus[ 
                  Times[ -0.99842473830179046, 
                    Power[ d1, 2]], 
                  Times[ d1, 
                    Plus[ 224.64556611790286, 
                      Times[ -0.34116124085556565, t]]], 
                  Times[ f, 
                    Plus[ -224.82271321316301, f, 
                      Times[ 0.3414302678560861, t]]]], 
                Plus[ 
                  Times[ -0.99842473830179046, 
                    Power[ d1, 3]], 
                  Times[ 
                    Power[ f, 2], 
                    Plus[ 175.0, 
                      Times[ -0.3416995070012418, t]]], 
                  Times[ 
                    Power[ d1, 2], 
                    Plus[ 174.72432920281332, 
                      Times[ 0.99921205872516894, f], 
                      Times[ -0.34116124085556565, t]]], 
                  Times[ d1, f, 
                    Plus[ -349.72422055380912, 
                      Times[ 0.6828605357121722, t]]]]]]]}, {0, 1}}], 
        MatrixForm[ {{1, 0}, {0, 
          Times[ 
            Power[ 
              Plus[ 
                Times[ 0.99842473830179046, 
                  Power[ d1, 2]], 
                Times[ -1.9984241174503379, d1, f], 
                Power[ f, 2]], -1], 
            Plus[ 
              Times[ 0.99842473830179146, 
                Power[ d1, 2]], 
              Times[ -1.9984241174503388, d1, f], 
              Times[ 1.0000000000000004, 
                Power[ f, 2]]]]}}], 
        MatrixForm[ {{1, 
          Times[ 
            Power[ 
              Plus[ 
                Times[ 0.99842473830179057, 
                  Power[ d1, 2]], 
                Times[ -1.9984241174503379, d1, f], 
                Power[ f, 2]], -1], 
            Plus[ 
              Times[ -0.99842473830179046, 
                Power[ d1, 3]], 
              Times[ 
                Power[ f, 2], 
                Plus[ 175.0, 
                  Times[ -1.0, t]]], 
              Times[ 
                Power[ d1, 2], 
                Plus[ 174.72432920281329, 
                  Times[ 1.9984241174503379, f], 
                  Times[ -0.99842473830179035, t]]], 
              Times[ d1, f, 
                Plus[ -349.72422055380912, 
                  Times[ -1.0, f], 
                  Times[ 1.9984241174503379, t]]]]]}, {0, 1}}], 
        MatrixForm[ {{
          Times[ 
            Power[ 
              Plus[ 
                Times[ 0.43267688439893781, 
                  Power[ d1, 2]], 
                Times[ -0.86603615442944648, d1, f], 
                Times[ 0.43335953908240804, 
                  Power[ f, 2]]], 
              Rational[ 3, 2]], 
            Power[ 
              Plus[ 
                Times[ 0.99842473830179046, 
                  Power[ d1, 2]], 
                Times[ -1.9984241174503379, d1, f], 
                Power[ f, 2]], 
              Rational[ -3, 2]], 
            Power[ 
              Plus[ 
                Times[ 0.12323996546074067, 
                  Power[ d1, 4]], 
                Times[ -0.49334859156113331, 
                  Power[ d1, 3], f], 
                Times[ 0.74060644172554135, 
                  Power[ d1, 2], 
                  Power[ f, 2]], 
                Times[ -0.49412697085236934, d1, 
                  Power[ f, 3]], 
                Times[ 0.1236291552272684, 
                  Power[ f, 4]]], -1], 
            Plus[ 
              Times[ 0.43199530507524342, 
                Power[ d1, 4]], 
              Times[ -1.7293438416922178, 
                Power[ d1, 3], f], 
              Times[ 2.5960613063936262, 
                Power[ d1, 2], 
                Power[ f, 2]], 
              Times[ -1.7320723088588932, d1, 
                Power[ f, 3]], 
              Times[ 0.43335953908240804, 
                Power[ f, 4]]]], 
          Times[ 
            Plus[ 
              Times[ -0.65778179086908284, d1], 
              Times[ 0.65830049299875815, f]], 
            Plus[ 
              Times[ -0.65674561240814744, 
                Power[ d1, 3]], 
              Times[ 1.9717904923386749, 
                Power[ d1, 2], f], 
              Times[ -1.9733453726072487, d1, 
                Power[ f, 2]], 
              Times[ 0.65830049299875815, 
                Power[ f, 3]]], 
            Power[ 
              Plus[ 
                Times[ 0.12323996546074067, 
                  Power[ d1, 4]], 
                Times[ -0.49334859156113331, 
                  Power[ d1, 3], f], 
                Times[ 0.74060644172554135, 
                  Power[ d1, 2], 
                  Power[ f, 2]], 
                Times[ -0.49412697085236934, d1, 
                  Power[ f, 3]], 
                Times[ 0.1236291552272684, 
                  Power[ f, 4]]], -2], 
            Plus[ 
              Times[ 
                Power[ 
                  Plus[ 
                    Times[ 0.43267688439893781, 
                      Power[ d1, 2]], 
                    Times[ -0.86603615442944648, d1, f], 
                    Times[ 0.43335953908240804, 
                      Power[ f, 2]]], 
                  Rational[ 3, 2]], 
                Power[ 
                  Plus[ 
                    Times[ 0.99842473830179046, 
                      Power[ d1, 2]], 
                    Times[ -1.9984241174503379, d1, f], 
                    Power[ f, 2]], 
                  Rational[ -3, 2]], 
                Plus[ 
                  Times[ 0.12323996546074067, 
                    Power[ d1, 4]], 
                  Times[ -0.49334859156113331, 
                    Power[ d1, 3], f], 
                  Times[ 0.74060644172554135, 
                    Power[ d1, 2], 
                    Power[ f, 2]], 
                  Times[ -0.49412697085236934, d1, 
                    Power[ f, 3]], 
                  Times[ 0.1236291552272684, 
                    Power[ f, 4]]]], 
              Times[ -1, 
                Power[ 
                  Plus[ 
                    Times[ 0.43267688439893781, 
                      Power[ d1, 2]], 
                    Times[ -0.86603615442944648, d1, f], 
                    Times[ 0.43335953908240804, 
                      Power[ f, 2]]], 3], 
                Power[ 
                  Plus[ 
                    Times[ 0.99842473830179046, 
                      Power[ d1, 2]], 
                    Times[ -1.9984241174503379, d1, f], 
                    Power[ f, 2]], -3], 
                Plus[ 
                  Times[ 0.43199530507524342, 
                    Power[ d1, 4]], 
                  Times[ -1.7293438416922178, 
                    Power[ d1, 3], f], 
                  Times[ 2.5960613063936262, 
                    Power[ d1, 2], 
                    Power[ f, 2]], 
                  Times[ -1.7320723088588932, d1, 
                    Power[ f, 3]], 
                  Times[ 0.43335953908240804, 
                    Power[ f, 4]]]]], t]}, {0, 
          Times[ 
            Power[ 
              Plus[ 
                Times[ 0.43267688439893781, 
                  Power[ d1, 2]], 
                Times[ -0.86603615442944648, d1, f], 
                Times[ 0.43335953908240804, 
                  Power[ f, 2]]], 
              Rational[ -1, 2]], 
            Power[ 
              Plus[ 
                Times[ 0.99842473830179046, 
                  Power[ d1, 2]], 
                Times[ -1.9984241174503379, d1, f], 
                Power[ f, 2]], 
              Rational[ -1, 2]], 
            Plus[ 
              Times[ 0.99842473830179046, 
                Power[ d1, 2]], 
              Times[ -1.9984241174503379, d1, f], 
              Times[ 1.0, 
                Power[ f, 2]]]]}}], 
        MatrixForm[ {{1, 
          Times[ 
            Plus[ 
              Times[ -0.65778179086908284, d1], 
              Times[ 0.65830049299875815, f]], 
            Power[ f, -1], 
            Power[ 
              Plus[ 
                Times[ 0.43267688439893781, 
                  Power[ d1, 2]], 
                Times[ -0.86603615442944648, d1, f], 
                Times[ 0.43335953908240804, 
                  Power[ f, 2]]], 
              Rational[ 3, 2]], 
            Power[ 
              Plus[ 
                Times[ 0.99842473830179046, 
                  Power[ d1, 2]], 
                Times[ -1.9984241174503379, d1, f], 
                Power[ f, 2]], 
              Rational[ -3, 2]], 
            Power[ 
              Plus[ 
                Times[ 0.12323996546074067, 
                  Power[ d1, 4]], 
                Times[ -0.49334859156113331, 
                  Power[ d1, 3], f], 
                Times[ 0.74060644172554135, 
                  Power[ d1, 2], 
                  Power[ f, 2]], 
                Times[ -0.49412697085236934, d1, 
                  Power[ f, 3]], 
                Times[ 0.1236291552272684, 
                  Power[ f, 4]]], -1], 
            Plus[ 
              Times[ -0.65674561240814744, 
                Power[ d1, 3], f, t], 
              Times[ 1.9717904923386749, 
                Power[ d1, 2], 
                Power[ f, 2], t], 
              Times[ -1.9733453726072487, d1, 
                Power[ f, 3], t], 
              Times[ 0.65830049299875826, 
                Power[ f, 4], t]]]}, {0, 1}}], 
        MatrixForm[ {{
          Times[ 
            Plus[ 
              Times[ -0.65778179086908284, d1], 
              Times[ 0.65830049299875815, f]], 
            Power[ 
              Plus[ 
                Times[ 0.43267688439893781, 
                  Power[ d1, 2]], 
                Times[ -0.86603615442944648, d1, f], 
                Times[ 0.43335953908240804, 
                  Power[ f, 2]]], 
              Rational[ -1, 2]]], 
          Times[ d1, 
            Plus[ 
              Times[ -0.65778179086908284, d1], 
              Times[ 0.65830049299875815, f]], 
            Plus[ 
              Times[ 
                Plus[ 
                  Times[ 0.65778179086908284, d1], 
                  Times[ -0.65830049299875815, f]], 
                Power[ 
                  Plus[ 
                    Times[ 0.43267688439893781, 
                      Power[ d1, 2]], 
                    Times[ -0.86603615442944648, d1, f], 
                    Times[ 0.43335953908240804, 
                      Power[ f, 2]]], -1]], 
              Power[ 
                Plus[ 
                  Times[ 0.43267688439893781, 
                    Power[ d1, 2]], 
                  Times[ -0.86603615442944648, d1, f], 
                  Times[ 0.43335953908240804, 
                    Power[ f, 2]]], 
                Rational[ -1, 2]]]]}, {
          Times[ 
            Plus[ 
              Times[ 0.43267688439893781, d1], 
              Times[ -0.43301807721472324, f]], 
            Power[ f, -1], 
            Power[ 
              Plus[ 
                Times[ 0.43267688439893781, 
                  Power[ d1, 2]], 
                Times[ -0.86603615442944648, d1, f], 
                Times[ 0.43335953908240804, 
                  Power[ f, 2]]], 
              Rational[ -1, 2]]], 
          Times[ 
            Power[ f, -1], 
            Plus[ 
              Times[ 0.65778179086908284, d1], 
              Power[ 
                Plus[ 
                  Times[ 0.43267688439893781, 
                    Power[ d1, 2]], 
                  Times[ -0.86603615442944648, d1, f], 
                  Times[ 0.43335953908240804, 
                    Power[ f, 2]]], 
                Rational[ 1, 2]]]]}}], 
        MatrixForm[ {{1, 
          Times[ d1, 
            Plus[ 
              Times[ -0.65778179086908284, d1], 
              Times[ 0.65830049299875815, f]], 
            Power[ 
              Plus[ 
                Times[ 0.43267688439893781, 
                  Power[ d1, 2]], 
                Times[ -0.86603615442944648, d1, f], 
                Times[ 0.43335953908240804, 
                  Power[ f, 2]]], 
              Rational[ -1, 2]]]}, {0, 1}}]}, TableDirections -> 
        Row]]], "Output",
  CellLabel->"Out[161]//TableForm=",
  CellTags->{"AOG3.", "AOG3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[opticalsystemreflected,MatrixForm->True,DecomposeABCD->True,\
NumericalResults->True]\
\>", "Input",
  CellLabel->"In[162]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.0000000000000002`", "0"},
                    {"0", "1.`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "49.99999999999998`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.9999999999999998`", "0"},
                    {"0", "1.0000000000000004`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "114.99999999999999`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.5190631187965498`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "9.999999999999998`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {\(-0.00657781790869083`\), "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50.`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        MatrixForm[ {{1.0000000000000002, 0}, {0, 1.0}}], 
        MatrixForm[ {{1, 49.999999999999979}, {0, 1}}], 
        MatrixForm[ {{0.99999999999999978, 0}, {0, 1.0000000000000004}}], 
        MatrixForm[ {{1, 114.99999999999999}, {0, 1}}], 
        MatrixForm[ {{1.0, 0}, {0, 1.5190631187965498}}], 
        MatrixForm[ {{1, 9.9999999999999982}, {0, 1}}], 
        MatrixForm[ {{1.0, 0}, {-0.0065778179086908297, 
          0.65830049299875815}}], 
        MatrixForm[ {{1, 50.0}, {0, 1}}]}, TableDirections -> Row]]], "Output",\

  CellLabel->"Out[162]//TableForm=",
  CellTags->{"AOG3.", "AOG3.1"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG3."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2 SphericalMirror Examples", "Subsection",
  CellTags->{"AOG0.", "3.2", "AOG3.", "AOG3.2"}],

Cell["\<\
opticalsystem = {
\tMove[LineOfRays[40,IntrinsicMedium->Vacuum],{d1,-70}],
\tSphericalMirror[{R,-100},50],
\tMove[Screen[25],{d2,-50}]};\
\>", "Input",
  CellLabel->"In[12]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[opticalsystem,PlotType->TopView];", "Input",
  CellLabel->"In[13]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74857 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.0136054 0.390612 0.0136054 [
[.97619 .01782 -6.4375 -6 ]
[.97619 .01782 6.4375 6 ]
[.29592 .18789 -4.75 -6 ]
[.29592 .18789 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .74857 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.93299 .05048 m
.93299 .05048 L
.95716 .16385 L
.95716 .16385 L
.93299 .05048 L
F
.95716 .16385 m
.95716 .16385 L
.97146 .27723 L
.97146 .27723 L
.95716 .16385 L
F
.97146 .27723 m
.97146 .27723 L
.97619 .39061 L
.97619 .39061 L
.97146 .27723 L
F
.97619 .39061 m
.97619 .39061 L
.97146 .50399 L
.97146 .50399 L
.97619 .39061 L
F
.97146 .50399 m
.97146 .50399 L
.95716 .61737 L
.95716 .61737 L
.97146 .50399 L
F
.95716 .61737 m
.95716 .61737 L
.93299 .73075 L
.93299 .73075 L
.95716 .61737 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.93299 .05048 m
.95716 .16385 L
.97146 .27723 L
.97619 .39061 L
.97146 .50399 L
.95716 .61737 L
.93299 .73075 L
.93299 .73075 L
.95716 .61737 L
.97146 .50399 L
.97619 .39061 L
.97146 .27723 L
.95716 .16385 L
.93299 .05048 L
.93299 .05048 L
s
.5 g
.93299 .39061 m
.93299 .39061 L
.95716 .39061 L
.95716 .39061 L
.93299 .39061 L
F
.95716 .39061 m
.95716 .39061 L
.97146 .39061 L
.97146 .39061 L
.95716 .39061 L
F
.97146 .39061 m
.97146 .39061 L
.97619 .39061 L
.97619 .39061 L
.97146 .39061 L
F
.97619 .39061 m
.97619 .39061 L
.97146 .39061 L
.97146 .39061 L
.97619 .39061 L
F
.97146 .39061 m
.97146 .39061 L
.95716 .39061 L
.95716 .39061 L
.97146 .39061 L
F
.95716 .39061 m
.95716 .39061 L
.93299 .39061 L
.93299 .39061 L
.95716 .39061 L
F
0 g
.93299 .39061 m
.95716 .39061 L
.97146 .39061 L
.97619 .39061 L
.97146 .39061 L
.95716 .39061 L
.93299 .39061 L
.93299 .39061 L
.95716 .39061 L
.97146 .39061 L
.97619 .39061 L
.97146 .39061 L
.95716 .39061 L
.93299 .39061 L
.93299 .39061 L
s
.5 g
.97619 .39061 m
.97146 .50399 L
.97146 .50013 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .50399 m
.95716 .61737 L
.95716 .60964 L
.97146 .50013 L
.97146 .50399 L
F
.95716 .61737 m
.93299 .73075 L
.93299 .71916 L
.95716 .60964 L
.95716 .61737 L
F
.97619 .39061 m
.97146 .50013 L
.97146 .4888 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .50013 m
.95716 .60964 L
.95716 .58699 L
.97146 .4888 L
.97146 .50013 L
F
.95716 .60964 m
.93299 .71916 L
.93299 .68518 L
.95716 .58699 L
.95716 .60964 L
F
.97619 .39061 m
.97146 .4888 L
.97146 .47078 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .4888 m
.95716 .58699 L
.95716 .55095 L
.97146 .47078 L
.97146 .4888 L
F
.95716 .58699 m
.93299 .68518 L
.93299 .63112 L
.95716 .55095 L
.95716 .58699 L
F
.97619 .39061 m
.97146 .47078 L
.97146 .4473 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .47078 m
.95716 .55095 L
.95716 .50399 L
.97146 .4473 L
.97146 .47078 L
F
.95716 .55095 m
.93299 .63112 L
.93299 .56068 L
.95716 .50399 L
.95716 .55095 L
F
.97619 .39061 m
.97146 .4473 L
.97146 .41996 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .4473 m
.95716 .50399 L
.95716 .4493 L
.97146 .41996 L
.97146 .4473 L
F
.95716 .50399 m
.93299 .56068 L
.93299 .47865 L
.95716 .4493 L
.95716 .50399 L
F
.97619 .39061 m
.97146 .41996 L
.97146 .39061 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .41996 m
.95716 .4493 L
.95716 .39061 L
.97146 .39061 L
.97146 .41996 L
F
.95716 .4493 m
.93299 .47865 L
.93299 .39061 L
.95716 .39061 L
.95716 .4493 L
F
.97619 .39061 m
.97146 .39061 L
.97146 .36127 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .39061 m
.95716 .39061 L
.95716 .33192 L
.97146 .36127 L
.97146 .39061 L
F
.95716 .39061 m
.93299 .39061 L
.93299 .30258 L
.95716 .33192 L
.95716 .39061 L
F
.97619 .39061 m
.97146 .36127 L
.97146 .33392 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .36127 m
.95716 .33192 L
.95716 .27723 L
.97146 .33392 L
.97146 .36127 L
F
.95716 .33192 m
.93299 .30258 L
.93299 .22054 L
.95716 .27723 L
.95716 .33192 L
F
.97619 .39061 m
.97146 .33392 L
.97146 .31044 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .33392 m
.95716 .27723 L
.95716 .23027 L
.97146 .31044 L
.97146 .33392 L
F
.95716 .27723 m
.93299 .22054 L
.93299 .1501 L
.95716 .23027 L
.95716 .27723 L
F
.97619 .39061 m
.97146 .31044 L
.97146 .29242 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .31044 m
.95716 .23027 L
.95716 .19423 L
.97146 .29242 L
.97146 .31044 L
F
.95716 .23027 m
.93299 .1501 L
.93299 .09605 L
.95716 .19423 L
.95716 .23027 L
F
.97619 .39061 m
.97146 .29242 L
.97146 .2811 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .29242 m
.95716 .19423 L
.95716 .17158 L
.97146 .2811 L
.97146 .29242 L
F
.95716 .19423 m
.93299 .09605 L
.93299 .06207 L
.95716 .17158 L
.95716 .19423 L
F
.97619 .39061 m
.97146 .2811 L
.97146 .27723 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .2811 m
.95716 .17158 L
.95716 .16385 L
.97146 .27723 L
.97146 .2811 L
F
.95716 .17158 m
.93299 .06207 L
.93299 .05048 L
.95716 .16385 L
.95716 .17158 L
F
.97619 .39061 m
.97146 .27723 L
.97146 .2811 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .27723 m
.95716 .16385 L
.95716 .17158 L
.97146 .2811 L
.97146 .27723 L
F
.95716 .16385 m
.93299 .05048 L
.93299 .06207 L
.95716 .17158 L
.95716 .16385 L
F
.97619 .39061 m
.97146 .2811 L
.97146 .29242 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .2811 m
.95716 .17158 L
.95716 .19423 L
.97146 .29242 L
.97146 .2811 L
F
.95716 .17158 m
.93299 .06207 L
.93299 .09605 L
.95716 .19423 L
.95716 .17158 L
F
.97619 .39061 m
.97146 .29242 L
.97146 .31044 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .29242 m
.95716 .19423 L
.95716 .23027 L
.97146 .31044 L
.97146 .29242 L
F
.95716 .19423 m
.93299 .09605 L
.93299 .1501 L
.95716 .23027 L
.95716 .19423 L
F
.97619 .39061 m
.97146 .31044 L
.97146 .33392 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .31044 m
.95716 .23027 L
.95716 .27723 L
.97146 .33392 L
.97146 .31044 L
F
.95716 .23027 m
.93299 .1501 L
.93299 .22054 L
.95716 .27723 L
.95716 .23027 L
F
.97619 .39061 m
.97146 .33392 L
.97146 .36127 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .33392 m
.95716 .27723 L
.95716 .33192 L
.97146 .36127 L
.97146 .33392 L
F
.95716 .27723 m
.93299 .22054 L
.93299 .30258 L
.95716 .33192 L
.95716 .27723 L
F
.97619 .39061 m
.97146 .36127 L
.97146 .39061 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .36127 m
.95716 .33192 L
.95716 .39061 L
.97146 .39061 L
.97146 .36127 L
F
.95716 .33192 m
.93299 .30258 L
.93299 .39061 L
.95716 .39061 L
.95716 .33192 L
F
.97619 .39061 m
.97146 .39061 L
.97146 .41996 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .39061 m
.95716 .39061 L
.95716 .4493 L
.97146 .41996 L
.97146 .39061 L
F
.95716 .39061 m
.93299 .39061 L
.93299 .47865 L
.95716 .4493 L
.95716 .39061 L
F
.97619 .39061 m
.97146 .41996 L
.97146 .4473 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .41996 m
.95716 .4493 L
.95716 .50399 L
.97146 .4473 L
.97146 .41996 L
F
.95716 .4493 m
.93299 .47865 L
.93299 .56068 L
.95716 .50399 L
.95716 .4493 L
F
.97619 .39061 m
.97146 .4473 L
.97146 .47078 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .4473 m
.95716 .50399 L
.95716 .55095 L
.97146 .47078 L
.97146 .4473 L
F
.95716 .50399 m
.93299 .56068 L
.93299 .63112 L
.95716 .55095 L
.95716 .50399 L
F
.97619 .39061 m
.97146 .47078 L
.97146 .4888 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .47078 m
.95716 .55095 L
.95716 .58699 L
.97146 .4888 L
.97146 .47078 L
F
.95716 .55095 m
.93299 .63112 L
.93299 .68518 L
.95716 .58699 L
.95716 .55095 L
F
.97619 .39061 m
.97146 .4888 L
.97146 .50013 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .4888 m
.95716 .58699 L
.95716 .60964 L
.97146 .50013 L
.97146 .4888 L
F
.95716 .58699 m
.93299 .68518 L
.93299 .71916 L
.95716 .60964 L
.95716 .58699 L
F
.97619 .39061 m
.97146 .50013 L
.97146 .50399 L
.97619 .39061 L
.97619 .39061 L
F
.97146 .50013 m
.95716 .60964 L
.95716 .61737 L
.97146 .50399 L
.97146 .50013 L
F
.95716 .60964 m
.93299 .71916 L
.93299 .73075 L
.95716 .61737 L
.95716 .60964 L
F
0 g
.93299 .73075 m
.93299 .71916 L
.93299 .68518 L
.93299 .63112 L
.93299 .56068 L
.93299 .47865 L
.93299 .39061 L
.93299 .30258 L
.93299 .22054 L
.93299 .1501 L
.93299 .09605 L
.93299 .06207 L
.93299 .05048 L
.93299 .06207 L
.93299 .09605 L
.93299 .1501 L
.93299 .22054 L
.93299 .30258 L
.93299 .39061 L
.93299 .47865 L
.93299 .56068 L
.93299 .63112 L
.93299 .68518 L
.93299 .71916 L
.93299 .73075 L
s
.29592 .22054 m
.29592 .27723 L
.29592 .33392 L
.29592 .39061 L
.29592 .4473 L
.29592 .50399 L
.29592 .56068 L
.29592 .56068 L
.29592 .50399 L
.29592 .4473 L
.29592 .39061 L
.29592 .33392 L
.29592 .27723 L
.29592 .22054 L
.29592 .22054 L
s
.29592 .39061 m
.29592 .39061 L
.29592 .39061 L
.29592 .39061 L
.29592 .39061 L
.29592 .39061 L
.29592 .39061 L
.29592 .39061 L
.29592 .39061 L
.29592 .39061 L
.29592 .39061 L
.29592 .39061 L
.29592 .39061 L
.29592 .39061 L
.29592 .39061 L
s
.29592 .56068 m
.29592 .55489 L
.29592 .5379 L
.29592 .51087 L
.29592 .47565 L
.29592 .43463 L
.29592 .39061 L
.29592 .3466 L
.29592 .30558 L
.29592 .27036 L
.29592 .24333 L
.29592 .22634 L
.29592 .22054 L
.29592 .22634 L
.29592 .24333 L
.29592 .27036 L
.29592 .30558 L
.29592 .3466 L
.29592 .39061 L
.29592 .43463 L
.29592 .47565 L
.29592 .51087 L
.29592 .5379 L
.29592 .55489 L
.29592 .56068 L
s
.039 .916 .04 r
.02381 .1185 m
.9487 .1185 L
s
% Start of user PostScript
-70. -20. -2.02041 -20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.9487 .1185 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .39061 m
.97619 .39061 L
s
% Start of user PostScript
-70. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .39061 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .66272 m
.9487 .66272 L
s
% Start of user PostScript
-70. 20. -2.02041 20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.9487 .66272 Mdot
.039 .916 .04 r
.5 Mabswid
.9487 .1185 m
.29592 .39659 L
s
% Start of user PostScript
-2.02041 -20. -50. 0.43922 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.29592 .39659 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .39061 m
.29592 .39061 L
s
% Start of user PostScript
0 0 -50. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.29592 .39061 Mdot
.039 .916 .04 r
.5 Mabswid
.9487 .66272 m
.29592 .38464 L
s
% Start of user PostScript
-2.02041 20. -50. -0.43922 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.29592 .38464 Mdot
gsave
.97619 .01782 -67.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
71.875 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29592 .18789 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .74857 L
0 .74857 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{288, 215.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolCooooo`?o000000?o
ooooo`000?ooool00ol00005ooooo`00oooooolDooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01?ooool00?oooooo5?ooool01ol0003oooooo`000?oooooo0000ooooool00000
1_ooool00?oooooo5?ooool01ol0003oooooo`000?oooooo0000ooooool000001_ooool00?oooooo
5?ooool2o`0000?ooooo0_l00006ooooo`00oooooolDooooo`;o00000oooool2o`0000Kooooo003o
oooooa?ooooo0_l00005ooooo`;o00001Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo3?ooool00ol0003oooooooooo`0Booooo`00ooooool<oooo
o`03o`000?oooooooooo01;ooooo003oooooo`cooooo00?o0000ooooooooool04_ooool00?oooooo
3?ooool00ol0003oooooooooo`0Booooo`00ooooool<ooooo`;o00004oooool00?oooooo3?ooool2
o`0001?ooooo003oooooo`cooooo0_l0000Cooooo`00ooooool<ooooo`;o00004oooool00?oooooo
3?ooool2o`0001?ooooo003oooooo`cooooo00?o0000ogmoOol000004_ooool00?oooooo3?ooool0
0ol0003oOgmoo`00000Booooo`00ooooool<ooooo`03o`000?moOgoo000001;ooooo003oooooo`co
oooo00?o0000ogmoOol000004_ooool00?oooooo3?ooool00ol0003oOgmoo`00000Booooo`00oooo
ool<ooooo`03o`000?moOgoo000001;ooooo003oooooo`cooooo00Co0000ogmoOomoOgoo00004Ooo
ool00?oooooo3?ooool01?l0003oOgmoogmoOol0000Aooooo`00ooooool<ooooo`04o`000?moOgoo
Ogmoo`00017ooooo003oooooo`Sooooo0ol9jPX01Ooooooo0000ogmoOomoOgoo0000017ooooo003o
ooooo`Wooooo1_l9jPX3o`0000oooooo0007oooooooo2NX:2_l9jPX00ol0003oooooooooo`0=oooo
o`00ooooool9ooooo`Ko2NX:00?oOgmoo`000?ooool03oooool00?oooooo2?ooool4o`WZ2P05o`00
0?moOgooOgmoogmoOol000004?ooool00?oooooo2?ooool2o`WZ2P;ooooo00Go0000ogmoOomoOgoo
Ogmoo`00000@ooooo`00ooooool5ooooo`?o2NX:1?ooool01Ol0003oOgmoogmoOomoOgoo0000013o
oooo003oooooo`?ooooo0_l9jPX7ooooo`05o`000?moOgooOgmoogmoOol000004?ooool00?oooooo
0Oooool2o`WZ2PWooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`0=ooooo`00oOoo
ool3o`WZ2P_ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`0=ooooo`00noooool2
o`WZ2Pkooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`0=ooooo`00nOooool2o`WZ
2Q3ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`0=ooooo`00m_ooool3o`WZ2Q;o
oooo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`0=ooooo`00m?ooool2o`WZ2QGooooo
00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0<ooooo`00l_ooool2o`WZ2QOooooo00?o
0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0<ooooo`00koooool3o`WZ2QWooooo00?o0000
ogmoOomoOgl00omoOgl00ol0003oooooooooo`0<ooooo`00kOooool2o`WZ2Qcooooo00?o0000ogmo
OomoOgl00omoOgl00ol0003oooooooooo`0<ooooo`00joooool2o`WZ2Qkooooo00?o0000ogmoOomo
Ogl00omoOgl00ol0003oooooooooo`0<ooooo`00j?ooool3o`WZ2R3ooooo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`0<ooooo`00Doooool3o`00093ooooo0_l9jPXSooooo`03o`000?mo
OgooOgmo00CoOgmo00?o0000ooooooooool02oooool005?ooooo00Co0000oooooooooooo0000S?oo
ool3o`WZ2RGooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`0;ooooo`00E_ooool0
0ol0003oooooooooo`28ooooo`;o2NX::?ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooo
oooo00_ooooo001Dooooo`;o0000ROooool2o`WZ2R[ooooo00?o0000ogmoOomoOgl01?moOgl00ol0
003oooooooooo`0;ooooo`00Doooool00ol0003oooooooooo`26ooooo`?o2NX:;?ooool00ol0003o
OgmoogmoO`04ogmoO`03o`000?oooooooooo00_ooooo001Cooooo`04o`000?ooooooooooo`0008?o
oooo0_l9jPX_ooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool02oooool005Cooooo
0ol00021ooooo`;o2NX:<Oooool00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo00_ooooo
003Eooooo`?o2NX:<oooool00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00[ooooo003C
ooooo`;o2NX:=_ooool00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00[ooooo003Aoooo
o`;o2NX:>?ooool00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00[ooooo003>ooooo`?o
2NX:>_ooool00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00[ooooo003<ooooo`;o2NX:
?Oooool00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00[ooooo001Eooooo`03o`000?oo
oooooooo07;ooooo0_l9jPXoooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ooooooooool02_oo
ool005Gooooo00?o0000ooooooooool0Koooool3o`WZ2T7ooooo00?o0000ogmoOomoOgl01_moOgl0
0ol0003oooooooooo`09ooooo`00EOooool00ol0003oooooooooo`1]ooooo`;o2NX:A?ooool00ol0
003oOgmoogmoO`06ogmoO`03o`000?oooooooooo00Wooooo001Eooooo`03o`000?oooooooooo06[o
oooo0ol9jPY6ooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool02Oooool005Gooooo
00?o0000ooooooooool0J?ooool2o`WZ2TWooooo00?o0000ogmoOomoOgl01_moOgl00ol0003ooooo
ooooo`09ooooo`00EOooool00ol0003oooooooooo`1Vooooo`;o2NX:Boooool00ol0003oOgmoogmo
O`06ogmoO`03o`000?oooooooooo00Wooooo001Eooooo`03o`000?oooooooooo06?ooooo0ol9jPY=
ooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool02Oooool005Gooooo00?o0000oooo
ooooool0HOooool2o`WZ2U3ooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`08oooo
o`00EOooool00ol0003oooooooooo`1Oooooo`;o2NX:D_ooool00ol0003oOgmoogmoO`07ogmoO`03
o`000?oooooooooo00Sooooo001Eooooo`03o`000?oooooooooo05cooooo0ol9jPYDooooo`03o`00
0?moOgooOgmo00OoOgmo00?o0000ooooooooool02?ooool005Gooooo00?o0000ooooooooool0F_oo
ool2o`WZ2UOooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`08ooooo`00EOooool0
0ol0003oooooooooo`1Hooooo`;o2NX:FOooool00ol0003oOgmoogmoO`07ogmoO`03o`000?oooooo
oooo00Sooooo001Eooooo`03o`000?oooooooooo05Gooooo0ol9jPYKooooo`03o`000?moOgooOgmo
00OoOgmo00?o0000ooooooooool02?ooool005Gooooo00?o0000ooooooooool0Doooool2o`WZ2Uko
oooo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`08ooooo`00EOooool00ol0003ooooo
ooooo`1Aooooo`;o2NX:H?ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?oooooooooo00Oooooo
001Eooooo`03o`000?oooooooooo04kooooo0ol9jPYRooooo`03o`000?moOgooOgmo00SoOgmo00?o
0000ooooooooool01oooool005Gooooo00?o0000ooooooooool0C?ooool2o`WZ2VGooooo00?o0000
ogmoOomoOgl02?moOgl00ol0003oooooooooo`07ooooo`00EOooool00ol0003oooooooooo`1:oooo
o`;o2NX:Ioooool00ol0003oOgmoogmoO`08ogmoO`03o`000?oooooooooo00Oooooo001Eooooo`03
o`000?oooooooooo04Oooooo0ol9jPYYooooo`03o`000?moOgooOgmo00SoOgmo00?o0000oooooooo
ool01oooool005Gooooo00?o0000ooooooooool0AOooool2o`WZ2Vcooooo00?o0000ogmoOomoOgl0
2?moOgl00ol0003oooooooooo`07ooooo`00EOooool00ol0003oooooooooo`12ooooo`?o2NX:K_oo
ool00ol0003oOgmoogmoO`08ogmoO`03o`000?oooooooooo00Oooooo001Eooooo`03o`000?oooooo
oooo043ooooo0_l9jPYaooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ooooooooool01oooool0
05Gooooo00?o0000ooooooooool0?_ooool2o`WZ2W?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0
003oooooooooo`07ooooo`00EOooool00ol0003oooooooooo`0kooooo`?o2NX:MOooool00ol0003o
OgmoogmoO`08ogmoO`03o`000?oooooooooo00Oooooo001Eooooo`03o`000?oooooooooo03Wooooo
0_l9jPYhooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ooooooooool01oooool005Gooooo00?o
0000ooooooooool0=oooool2o`WZ2W[ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003ooooooooo
o`07ooooo`00EOooool00ol0003oooooooooo`0dooooo`?o2NX:O?ooool00ol0003oOgmoogmoO`08
ogmoO`03o`000?oooooooooo00Oooooo001Eooooo`03o`000?oooooooooo03;ooooo0_l9jPYooooo
o`03o`000?moOgooOgmo00SoOgmo00?o0000ooooooooool01oooool005Gooooo00?o0000oooooooo
ool0<?ooool2o`WZ2X7ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oooooooooo`07ooooo`00
EOooool00ol0003oooooooooo`0]ooooo`?o2NX:Poooool00ol0003oOgmoogmoO`08ogmoO`03o`00
0?oooooooooo00Oooooo001Eooooo`03o`000?oooooooooo02_ooooo0_l9jPZ6ooooo`03o`000?mo
OgooOgmo00SoOgmo00?o0000ooooooooool01oooool005Gooooo00?o0000ooooooooool0:Oooool2
o`WZ2XSooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oooooooooo`07ooooo`00EOooool00ol0
003oooooooooo`0Vooooo`?o2NX:R_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?oooooooooo
00Oooooo001Eooooo`03o`000?oooooooooo02Cooooo0_l9jPZ=ooooo`03o`000?moOgooOgmo00Wo
Ogmo00?o0000ooooooooool01_ooool005Gooooo00?o0000ooooooooool08Oooool3o`WZ2Xoooooo
00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`06ooooo`00EOooool00ol0003ooooooooo
o`0Oooooo`;o2NX:T_ooool00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00Kooooo001E
ooooo`03o`000?oooooooooo01gooooo0_l9jPZDooooo`03o`000?moOgooOgmo00WoOgmo00?o0000
ooooooooool01_ooool005Gooooo00?o0000ooooooooool06_ooool3o`WZ2YKooooo00?o0000ogmo
OomoOgl02OmoOgl00ol0003oooooooooo`06ooooo`00EOooool00ol0003oooooooooo`0Hooooo`;o
2NX:VOooool00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00Kooooo001Eooooo`03o`00
0?oooooooooo01Kooooo0_l9jPZKooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool0
1_ooool005Gooooo00?o0000ooooooooool04oooool3o`WZ2Ygooooo00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oooooooooo`06ooooo`00EOooool00ol0003oooooooooo`0Aooooo`;o2NX:X?ooool0
0ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00Kooooo001Eooooo`03o`000?oooooooooo
00oooooo0_l9jPZRooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool01_ooool005Go
oooo00?o0000ooooooooool03?ooool3o`WZ2ZCooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003o
ooooooooo`06ooooo`00EOooool00ol0003oooooooooo`0:ooooo`;o2NX:Yoooool00ol0003oOgmo
ogmoO`09ogmoO`03o`000?oooooooooo00Kooooo001Eooooo`03o`000?oooooooooo00;ooooo0_l9
jPX4ooooo`;o2NX:ZOooool00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00Kooooo001D
ooooo`;o00000oooool7o`WZ2Z_ooooo00Co0000ogmoOomoOgooOgmo0ol9jPX5ogmoO`03o`000?oo
oooooooo00Kooooo001Dooooo`;o00001ol9jPZ^ooooo`03o`000?moOgooOgmo00;oOgmo1_l9jPX0
0omoOgoo0000ooooo`07ooooo`001ooooom=o`WZ2P;o0000`_l9jPX8ooooo`00E?ooool2o`0000So
2NX:[Oooool00ol0003oOgmoogmoO`02ogmoO`Go2NX:00?oOgmoo`000?l000002?ooool005Cooooo
0_l00005o`WZ2P03ooooool9jP[o2NX:0:gooooo00Co0000ogmoOomoOgooOgmo0_l9jPX6ogmoO`03
o`000?oooooooooo00Kooooo001Dooooo`;o00001?ooool2o`WZ2P;ooooo0ol9jPZZooooo`03o`00
0?moOgooOgmo00WoOgmo00?o0000ooooooooool01_ooool005Gooooo00?o0000ooooooooool00ooo
ool00ol9jP[oooooooooo`03ooooo`;o2NX:Z?ooool00ol0003oOgmoogmoO`09ogmoO`03o`000?oo
oooooooo00Kooooo001Eooooo`03o`000?oooooooooo00_ooooo0_l9jPZVooooo`03o`000?moOgoo
Ogmo00WoOgmo00?o0000ooooooooool01_ooool005Gooooo00?o0000ooooooooool03Oooool3o`WZ
2Z?ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`06ooooo`00EOooool00ol0003o
ooooooooo`0@ooooo`;o2NX:XOooool00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00Ko
oooo001Eooooo`03o`000?oooooooooo01;ooooo0_l9jPZOooooo`03o`000?moOgooOgmo00WoOgmo
00?o0000ooooooooool01_ooool005Gooooo00?o0000ooooooooool05?ooool3o`WZ2Ycooooo00?o
0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`06ooooo`00EOooool00ol0003oooooooooo`0G
ooooo`;o2NX:V_ooool00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00Kooooo001Eoooo
o`03o`000?oooooooooo01Wooooo0_l9jPZHooooo`03o`000?moOgooOgmo00WoOgmo00?o0000oooo
ooooool01_ooool005Gooooo00?o0000ooooooooool06oooool3o`WZ2YGooooo00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oooooooooo`06ooooo`00EOooool00ol0003oooooooooo`0Nooooo`;o2NX:
Toooool00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00Kooooo001Eooooo`03o`000?oo
oooooooo023ooooo0_l9jPZAooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool01_oo
ool005Gooooo00?o0000ooooooooool08_ooool3o`WZ2Xkooooo00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oooooooooo`06ooooo`00EOooool00ol0003oooooooooo`0Uooooo`;o2NX:S?ooool00ol0
003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00Kooooo001Eooooo`03o`000?oooooooooo02Oo
oooo0ol9jPZ9ooooo`03o`000?moOgooOgmo00WoOgmo2Oooool005Gooooo00?o0000ooooooooool0
:_ooool2o`WZ2XOooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oooooooooo`07ooooo`00EOoo
ool00ol0003oooooooooo`0/ooooo`;o2NX:QOooool00ol0003oOgmoogmoO`08ogmoO`03o`000?oo
oooooooo00Oooooo001Eooooo`03o`000?oooooooooo02kooooo0ol9jPZ2ooooo`03o`000?moOgoo
Ogmo00SoOgmo00?o0000ooooooooool01oooool005Gooooo00?o0000ooooooooool0<Oooool2o`WZ
2X3ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oooooooooo`07ooooo`00EOooool00ol0003o
ooooooooo`0cooooo`;o2NX:O_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?oooooooooo00Oo
oooo001Eooooo`03o`000?oooooooooo03Gooooo0ol9jPYkooooo`03o`000?moOgooOgmo00SoOgmo
00?o0000ooooooooool01oooool005Gooooo00?o0000ooooooooool0>?ooool2o`WZ2WWooooo00?o
0000ogmoOomoOgl02?moOgl00ol0003oooooooooo`07ooooo`00EOooool00ol0003oooooooooo`0j
ooooo`;o2NX:Moooool00ol0003oOgmoogmoO`08ogmoO`03o`000?oooooooooo00Oooooo001Eoooo
o`03o`000?oooooooooo03cooooo0ol9jPYdooooo`03o`000?moOgooOgmo00SoOgmo00?o0000oooo
ooooool01oooool005Gooooo00?o0000ooooooooool0?oooool2o`WZ2W;ooooo00?o0000ogmoOomo
Ogl02?moOgl00ol0003oooooooooo`07ooooo`00EOooool00ol0003oooooooooo`11ooooo`;o2NX:
L?ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?oooooooooo00Oooooo001Eooooo`03o`000?oo
oooooooo04?ooooo0ol9jPY]ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ooooooooool01ooo
ool005Gooooo00?o0000ooooooooool0A_ooool2o`WZ2V_ooooo00?o0000ogmoOomoOgl02?moOgl0
0ol0003oooooooooo`07ooooo`00EOooool00ol0003oooooooooo`18ooooo`?o2NX:J?ooool00ol0
003oOgmoogmoO`08ogmoO`03o`000?oooooooooo00Oooooo001Eooooo`03o`000?oooooooooo04_o
oooo0_l9jPYVooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ooooooooool01oooool005Gooooo
00?o0000ooooooooool0COooool2o`WZ2VCooooo00?o0000ogmoOomoOgl02?moOgl00ol0003ooooo
ooooo`07ooooo`00EOooool00ol0003oooooooooo`1?ooooo`?o2NX:HOooool00ol0003oOgmoogmo
O`08ogmoO`03o`000?oooooooooo00Oooooo001Eooooo`03o`000?oooooooooo05;ooooo0_l9jPYO
ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ooooooooool01oooool005Gooooo00?o0000oooo
ooooool0E?ooool2o`WZ2Ugooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oooooooooo`07oooo
o`00EOooool00ol0003oooooooooo`1Fooooo`?o2NX:F_ooool00ol0003oOgmoogmoO`08ogmoO`[o
oooo001Eooooo`03o`000?oooooooooo05Wooooo0_l9jPYHooooo`03o`000?moOgooOgmo00OoOgmo
00?o0000ooooooooool02?ooool005Gooooo00?o0000ooooooooool0Foooool2o`WZ2UKooooo00?o
0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`08ooooo`00EOooool00ol0003oooooooooo`1M
ooooo`?o2NX:Doooool00ol0003oOgmoogmoO`07ogmoO`03o`000?oooooooooo00Sooooo001Eoooo
o`03o`000?oooooooooo063ooooo0_l9jPYAooooo`03o`000?moOgooOgmo00OoOgmo00?o0000oooo
ooooool02?ooool005Gooooo00?o0000ooooooooool0H_ooool2o`WZ2Toooooo00?o0000ogmoOomo
Ogl01omoOgl00ol0003oooooooooo`08ooooo`00EOooool00ol0003oooooooooo`1Tooooo`?o2NX:
C?ooool00ol0003oOgmoogmoO`07ogmoO`03o`000?oooooooooo00Sooooo001Eooooo`03o`000?oo
oooooooo06Oooooo0_l9jPY:ooooo`03o`000?moOgooOgmo00OoOgmo2oooool005Gooooo00?o0000
ooooooooool0JOooool2o`WZ2TSooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`09
ooooo`00EOooool00ol0003oooooooooo`1[ooooo`?o2NX:AOooool00ol0003oOgmoogmoO`06ogmo
O`03o`000?oooooooooo00Wooooo001Eooooo`03o`000?oooooooooo06kooooo0_l9jPY3ooooo`03
o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool02Oooool005Gooooo00?o0000ooooooooool0
L?ooool3o`WZ2T3ooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`09ooooo`00EOoo
ool00ol0003oooooooooo`1cooooo`;o2NX:?_ooool00ol0003oOgmoogmoO`06ogmoO`03o`000?oo
oooooooo00Wooooo003=ooooo`;o2NX:??ooool00ol0003oOgmoogmoO`06ogmoO`cooooo003?oooo
o`?o2NX:>Oooool00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00[ooooo003Booooo`;o
2NX:=oooool00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00[ooooo003Dooooo`;o2NX:
=Oooool00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00[ooooo003Fooooo`?o2NX:<_oo
ool00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00[ooooo003Iooooo`;o2NX:<?ooool0
0ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo00[ooooo003Kooooo`;o2NX:;_ooool00ol0
003oOgmoogmoO`05ogmoO`gooooo003Mooooo`?o2NX::oooool00ol0003oOgmoogmoO`04ogmoO`03
o`000?oooooooooo00_ooooo003Pooooo`;o2NX::Oooool00ol0003oOgmoogmoO`04ogmoO`03o`00
0?oooooooooo00_ooooo003Rooooo`;o2NX:9oooool00ol0003oOgmoogmoO`04ogmoO`03o`000?oo
oooooooo00_ooooo003Tooooo`?o2NX:9?ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooo
oooo00_ooooo003Wooooo`;o2NX:8_ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo
00_ooooo003Yooooo`?o2NX:7oooool00ol0003oOgmoogmoO`04ogmoO`03o`000?oooooooooo00_o
oooo003/ooooo`;o2NX:7Oooool00ol0003oOgmoogmoO`04ogmoO`kooooo003^ooooo`;o2NX:6ooo
ool00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo00cooooo003`ooooo`?o2NX:6?ooool0
0ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo00cooooo003cooooo`;o2NX:5_ooool00ol0
003oOgmoogmoO`03ogmoO`03o`000?oooooooooo00cooooo003eooooo`;o2NX:5?ooool00ol0003o
OgmoogmoO`03ogmoO`03o`000?oooooooooo00cooooo003gooooo`?o2NX:4Oooool00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo00cooooo003jooooo`;o2NX:3oooool00ol0003oOgmoogmo
O`03ogmoO`oooooo003looooo`;o2NX:3Oooool00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooo
oooo00gooooo003nooooo`?o2NX:2_ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo
00gooooo003oooooo`;ooooo0_l9jPX8ooooo`03o`000?moOgooOgmo00;oOgmo00?o0000oooooooo
ool03Oooool00?oooooo1?ooool2o`WZ2PKooooo00?o0000ogmoOomoOgl00_moOgl00ol0003ooooo
ooooo`0=ooooo`00ooooool6ooooo`?o2NX:0oooool00ol0003oOgmoogmoO`02ogmoOa3ooooo003o
ooooo`Wooooo0_l9jPX00ooooooo0000ogmoO`02ogmoO`03o`000?oooooooooo00kooooo003ooooo
o`Sooooo1Ol9jPX3ogmoO`03o`000?oooooooooo00kooooo003oooooo`Wooooo1ol9jPX2o`0000oo
oooo0007oooooooo2NX:2_l9jPX00ol0003oooooooooo`0=ooooo`00ooooool9ooooo`Go2NX:0_mo
OglAooooo`00ooooool8ooooo`;o2NX:0_ooool01?l0003oOgmoogmoOol0000Aooooo`00ooooool<
ooooo`04o`000?moOgooOgmoo`00017ooooo003oooooo`cooooo00Co0000ogmoOomoOgoo00004Ooo
ool00?oooooo3?ooool01?l0003oOgmoogmoOol0000Aooooo`00ooooool<ooooo`04o`000?moOgoo
Ogmoo`00017ooooo003oooooo`cooooo00?o0000ogmoOomoOgl04_ooool00?oooooo3?ooool00ol0
003oOgmoo`00000Booooo`00ooooool<ooooo`03o`000?moOgoo000001;ooooo003oooooo`cooooo
00?o0000ogmoOol000004_ooool00?oooooo3?ooool00ol0003oOgmoo`00000Booooo`00ooooool<
ooooo`03o`000?moOgoooooo01;ooooo003oooooo`cooooo0_l0000Cooooo`00ooooool<ooooo`;o
00004oooool00?oooooo3?ooool2o`0001?ooooo003oooooo`cooooo0_l0000Cooooo`00ooooool<
ooooo`03o`000?oooooooooo01;ooooo003oooooo`cooooo00?o0000ooooooooool04_ooool00?oo
oooo3?ooool00ol0003oooooooooo`0Booooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {214.562, 0}} -> {-71.9554, -28.9457, \
0.257529, 0.257529}},
  CellTags->{"AOG3.", "AOG3.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
result = FindABCDMatrix[opticalsystem,{R<0,d1<0,d2<0},ABCDConstruction->\
Horizontal]\
\>", "Input",
  CellLabel->"In[17]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(-1\) + \(2\ d2\)\/R\), \(d1 + d2 - \(2\ d1\ d2\)\/R\)},
            {\(-\(2\/R\)\), \(\(-1\) + \(2\ d1\)\/R\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[17]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplify[result/.{d1->0,d2->0},{R<0}]", "Input",
  CellLabel->"In[18]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1\), "0"},
            {\(-\(2\/R\)\), \(-1\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[18]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.2"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG3."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3 PlanoConvexLens Examples", "Subsection",
  CellTags->{"AOG0.", "3.3", "AOG3.", "AOG3.3", "AOG3.3.1"}],

Cell[CellGroupData[{

Cell["Simple lens", "Subsubsection",
  CellTags->{"AOG3.3.1", "AOG3.3", "3.3.1", "AOG3."}],

Cell["\<\
opticalsystem = {
Move[LineOfRays[40,SymbolicIntensity->100,SymbolicWaveLength->\[Lambda]], \
{-d1,-50}],
PlanoConvexLens[{f,100},{a,50},{t,10},DesignWaveLength->.532],
Move[Screen[50],{d2+t,100}]};\
\>", "Input",
  CellLabel->"In[19]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[opticalsystem,PlotType->TopView];", "Input",
  CellLabel->"In[20]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.192698 0.00634921 [
[.37302 .00857 -5.03125 -6 ]
[.37302 .00857 5.03125 6 ]
[.97619 .00857 -4.75 -6 ]
[.97619 .00857 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .36 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.38198 .03397 m
.40476 .03397 L
.40476 .08688 L
.35871 .08688 L
.38198 .03397 L
F
.35871 .08688 m
.40476 .08688 L
.40476 .13979 L
.34554 .13979 L
.35871 .08688 L
F
.34554 .13979 m
.40476 .13979 L
.40476 .1927 L
.34127 .1927 L
.34554 .13979 L
F
.34127 .1927 m
.40476 .1927 L
.40476 .24561 L
.34554 .24561 L
.34127 .1927 L
F
.34554 .24561 m
.40476 .24561 L
.40476 .29852 L
.35871 .29852 L
.34554 .24561 L
F
.35871 .29852 m
.40476 .29852 L
.40476 .35143 L
.38198 .35143 L
.35871 .29852 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.38198 .03397 m
.35871 .08688 L
.34554 .13979 L
.34127 .1927 L
.34554 .24561 L
.35871 .29852 L
.38198 .35143 L
.40476 .35143 L
.40476 .29852 L
.40476 .24561 L
.40476 .1927 L
.40476 .13979 L
.40476 .08688 L
.40476 .03397 L
.38198 .03397 L
s
.5 g
.38198 .1927 m
.40476 .1927 L
.40476 .1927 L
.35871 .1927 L
.38198 .1927 L
F
.35871 .1927 m
.40476 .1927 L
.40476 .1927 L
.34554 .1927 L
.35871 .1927 L
F
.34554 .1927 m
.40476 .1927 L
.40476 .1927 L
.34127 .1927 L
.34554 .1927 L
F
.34127 .1927 m
.40476 .1927 L
.40476 .1927 L
.34554 .1927 L
.34127 .1927 L
F
.34554 .1927 m
.40476 .1927 L
.40476 .1927 L
.35871 .1927 L
.34554 .1927 L
F
.35871 .1927 m
.40476 .1927 L
.40476 .1927 L
.38198 .1927 L
.35871 .1927 L
F
0 g
.38198 .1927 m
.35871 .1927 L
.34554 .1927 L
.34127 .1927 L
.34554 .1927 L
.35871 .1927 L
.38198 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.38198 .1927 L
s
.38198 .35143 m
.40476 .35143 L
.40476 .34602 L
.38198 .34602 L
.38198 .35143 L
s
.38198 .34602 m
.40476 .34602 L
.40476 .33016 L
.38198 .33016 L
.38198 .34602 L
s
.38198 .33016 m
.40476 .33016 L
.40476 .30494 L
.38198 .30494 L
.38198 .33016 L
s
.38198 .30494 m
.40476 .30494 L
.40476 .27206 L
.38198 .27206 L
.38198 .30494 L
s
.38198 .27206 m
.40476 .27206 L
.40476 .23378 L
.38198 .23378 L
.38198 .27206 L
s
.38198 .23378 m
.40476 .23378 L
.40476 .1927 L
.38198 .1927 L
.38198 .23378 L
s
.38198 .1927 m
.40476 .1927 L
.40476 .15162 L
.38198 .15162 L
.38198 .1927 L
s
.38198 .15162 m
.40476 .15162 L
.40476 .11333 L
.38198 .11333 L
.38198 .15162 L
s
.38198 .11333 m
.40476 .11333 L
.40476 .08046 L
.38198 .08046 L
.38198 .11333 L
s
.38198 .08046 m
.40476 .08046 L
.40476 .05523 L
.38198 .05523 L
.38198 .08046 L
s
.38198 .05523 m
.40476 .05523 L
.40476 .03938 L
.38198 .03938 L
.38198 .05523 L
s
.38198 .03938 m
.40476 .03938 L
.40476 .03397 L
.38198 .03397 L
.38198 .03938 L
s
.38198 .03397 m
.40476 .03397 L
.40476 .03938 L
.38198 .03938 L
.38198 .03397 L
s
.38198 .03938 m
.40476 .03938 L
.40476 .05523 L
.38198 .05523 L
.38198 .03938 L
s
.38198 .05523 m
.40476 .05523 L
.40476 .08046 L
.38198 .08046 L
.38198 .05523 L
s
.38198 .08046 m
.40476 .08046 L
.40476 .11333 L
.38198 .11333 L
.38198 .08046 L
s
.38198 .11333 m
.40476 .11333 L
.40476 .15162 L
.38198 .15162 L
.38198 .11333 L
s
.38198 .15162 m
.40476 .15162 L
.40476 .1927 L
.38198 .1927 L
.38198 .15162 L
s
.38198 .1927 m
.40476 .1927 L
.40476 .23378 L
.38198 .23378 L
.38198 .1927 L
s
.38198 .23378 m
.40476 .23378 L
.40476 .27206 L
.38198 .27206 L
.38198 .23378 L
s
.38198 .27206 m
.40476 .27206 L
.40476 .30494 L
.38198 .30494 L
.38198 .27206 L
s
.38198 .30494 m
.40476 .30494 L
.40476 .33016 L
.38198 .33016 L
.38198 .30494 L
s
.38198 .33016 m
.40476 .33016 L
.40476 .34602 L
.38198 .34602 L
.38198 .33016 L
s
.38198 .34602 m
.40476 .34602 L
.40476 .35143 L
.38198 .35143 L
.38198 .34602 L
s
.97619 .03397 m
.97619 .08688 L
.97619 .13979 L
.97619 .1927 L
.97619 .24561 L
.97619 .29852 L
.97619 .35143 L
.97619 .35143 L
.97619 .29852 L
.97619 .24561 L
.97619 .1927 L
.97619 .13979 L
.97619 .08688 L
.97619 .03397 L
.97619 .03397 L
s
.97619 .1927 m
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
s
.97619 .35143 m
.97619 .34602 L
.97619 .33016 L
.97619 .30494 L
.97619 .27206 L
.97619 .23378 L
.97619 .1927 L
.97619 .15162 L
.97619 .11333 L
.97619 .08046 L
.97619 .05523 L
.97619 .03938 L
.97619 .03397 L
.97619 .03938 L
.97619 .05523 L
.97619 .08046 L
.97619 .11333 L
.97619 .15162 L
.97619 .1927 L
.97619 .23378 L
.97619 .27206 L
.97619 .30494 L
.97619 .33016 L
.97619 .34602 L
.97619 .35143 L
s
.039 .916 .04 r
.02381 .06571 m
.36669 .06571 L
s
% Start of user PostScript
-50. -20. 4.0044 -20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.36669 .06571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1927 m
.34127 .1927 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .31968 m
.36669 .31968 L
s
% Start of user PostScript
-50. 20. 4.0044 20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.36669 .31968 Mdot
.039 .916 .04 r
.5 Mabswid
.36669 .06571 m
.40476 .07104 L
s
% Start of user PostScript
4.0044 -20. 10. -19.1614 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .07104 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .1927 m
.40476 .1927 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.36669 .31968 m
.40476 .31436 L
s
% Start of user PostScript
4.0044 20. 10. 19.1614 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .31436 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .07104 m
.97619 .19404 L
s
% Start of user PostScript
10. -19.1614 100. 0.210584 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19404 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .1927 m
.97619 .1927 L
s
% Start of user PostScript
10. 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .31436 m
.97619 .19136 L
s
% Start of user PostScript
10. 19.1614 100. -0.210584 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19136 Mdot
gsave
.37302 .00857 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00857 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .36 L
0 .36 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{288, 103.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ib000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00JOooool6o`000:7ooooo0ol0
000=ooooo`00J_ooool01Ol0003ooooooooooooooooo00000:7ooooo00Co0000oooooooooooo0000
3?ooool006[ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0:ooooo`00J_ooool0
0ol0003oooooooooo`2Tooooo`;o00003Oooool006[ooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`0=ooooo`00J_ooool00ol0003oooooooooo`2Sooooo`04o`000?ooooooooooo`00
00cooooo001Yooooo`?o0000YOooool3o`0000cooooo003oooooob7ooooo003oooooob7ooooo001_
ooooo`Oo0000W?ooool00ol0003oooooooooo`0;ooooo`00Koooool7o`0009cooooo00?o0000oooo
ooooool02oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000oooooooo
ool02oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
2oooool006gooooo00?o0000ogmoOol000001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00_ooooo001]ooooo`03o`000?moOgoo000000GoOgmo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0;ooooo`00K?ooool00ol0003oOgmoogmoO`07o`0009cooooo00?o0000oooo
ooooool02oooool006;ooooo0ol9jPX7ooooo`04o`000?l9jP[o2NX:o`0000GoOgmo00?o0000oooo
ooooool0V_ooool00ol0003oooooooooo`0;ooooo`00Hoooool6o`WZ2P03ooooool0003o000000;o
Ogmo1?l9jPX3ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool000cooooo
JOl9jPX00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Sooooo`Go2NX:0_oo
ool01?l0003oOgmoogmoOomoOgl6o`WZ2P04o`000?l9jP[o2NX:o`WZ2Y[ooooo00?o0000oooooooo
ool02oooool006;ooooo0_l9jPX6ooooo`03o`000?moOgooOgmo00Co2NX:0omoOgl2o`0000;ooooo
1Ol9jPZEooooo`03o`000?oooooooooo00_ooooo001Yooooo`03o`000?moOgooOgmo00?oOgmo00?o
0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`05ooooo`Go2NX:T?ooool00ol0003ooooooooo
o`0;ooooo`00JOooool00ol0003oOgmoogmoO`03ogmoO`Oo00003?ooool4o`WZ2Xcooooo00?o0000
ooooooooool02oooool006Sooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo00kooooo1Ol9jPZ7ooooo`03o`000?oooooooooo00_ooooo001Xooooo`03
o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0Cooooo`Co
2NX:Poooool00ol0003oooooooooo`0;ooooo`00J?ooool00ol0003oOgmoogmoO`04ogmoO`03o`00
0?moOgooOgmo00?oOgmo00?o0000ooooooooool05oooool5o`WZ2Wkooooo00?o0000ooooooooool0
2oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oo
oooooooo01cooooo1Ol9jPYiooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgoo
Ogmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0Qooooo`Co2NX:MOooool0
0ol0003oooooooooo`0;ooooo`00Ioooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo
00?oOgmo00?o0000ooooooooool09Oooool5o`WZ2W3ooooo00?o0000ooooooooool02oooool006Oo
oooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo02[o
oooo1?l9jPY/ooooo`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00GoOgmo
00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0^ooooo`Go2NX:Ioooool00ol0003ooooo
ooooo`0;ooooo`00I_ooool00ol0003oOgmoogmoO`06ogmoO`Oo0000=Oooool5o`WZ2V;ooooo00?o
0000ooooooooool02oooool006Kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo03Sooooo1?l9jPYNooooo`03o`000?oooooooooo00_ooooo001Voooo
o`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0loooo
o`Go2NX:FOooool00ol0003oooooooooo`0;ooooo`00I_ooool00ol0003oOgmoogmoO`06ogmoO`03
o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0@Oooool5o`WZ2UCooooo00?o0000oooooooo
ool02oooool006Kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`00
0?oooooooooo04Kooooo1?l9jPY@ooooo`03o`000?oooooooooo00_ooooo001Uooooo`03o`000?mo
OgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1:ooooo`Go2NX:Booo
ool00ol0003oooooooooo`0;ooooo`00IOooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ooooooooool0Coooool4o`WZ2TOooooo00?o0000ooooooooool02oooool0
06Gooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo
05?ooooo1Ol9jPY2ooooo`03o`000?oooooooooo00_ooooo001Uooooo`03o`000?moOgooOgmo00Oo
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1Hooooo`Go2NX:?Oooool00ol0003o
ooooooooo`0;ooooo`00IOooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00?oOgmo
00?o0000ooooooooool0GOooool4o`WZ2SWooooo00?o0000ooooooooool02oooool006Gooooo00?o
0000ogmoOomoOgl01omoOgl7o`0006?ooooo1Ol9jPXdooooo`03o`000?oooooooooo00_ooooo001T
ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1V
ooooo`Go2NX:;oooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmo
O`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0Joooool4o`WZ2R_ooooo00?o0000oooo
ooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo06oooooo1Ol9jPXVooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`00
0?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1dooooo`Co2NX:
8_ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?mo
OgooOgmo00?oOgmo00?o0000ooooooooool0N?ooool5o`WZ2Qgooooo00?o0000ooooooooool02ooo
ool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo07gooooo1Ol9jPXHooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`000?moOgooOgmo
00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`22ooooo`Co2NX:5?ooool00ol0
003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmoogmoO`09ogmoO`03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0Q_ooool5o`WZ2POooooo0_l9jPX6ooooo`03o`000?oooooooooo00_o
oooo001Kooooo`?o2NX:1Oooool00ol0003oOgmoogmoO`07ogmoO`?o2NX:1OmoOgl00ol0003ooooo
ooooo`2;ooooo`Co2NX:0oooool4o`WZ2PCooooo00?o0000ooooooooool02oooool005cooooo1_l9
jPX00ooooooo0000ogmoO`09ogmoO`Ko2NX:00?oOgmoo`000?ooool0T?ooool:o`WZ2P03ooooool0
003ooooo00cooooo000<ooooofSo2NX:00?o0000o`WZ2_l9jPX0V_l9jPX2o`0000gooooo001Loooo
o`Go2NX:0_ooool2o`0000WoOgmo1Ol9jPX00omoOgoo0000o`00002Dooooo`Oo2NX:0_l0000=oooo
o`00Foooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01omoOgl2o`WZ2P03o`000?moOgooOgmo00?o
Ogmo00?o0000ooooooooool0S_ooool9o`WZ2P?ooooo00?o0000ooooooooool02oooool006?ooooo
00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo08[ooooo
1?l9jPX5ooooo`;o2NX:1Oooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmoogmo
O`09ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0QOooool5o`WZ2PSooooo00?o
2NX:ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08
ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0POooool4o`WZ2QGooooo00?o0000
ooooooooool02oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo07cooooo1Ol9jPXIooooo`03o`000?oooooooooo00_ooooo001Tooooo`03
o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1gooooo`Go
2NX:7_ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmoO`03o`00
0?moOgooOgmo00?oOgmo00?o0000ooooooooool0Loooool4o`WZ2R?ooooo00?o0000ooooooooool0
2oooool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oo
oooooooo06kooooo1Ol9jPXWooooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`000?moOgoo
Ogmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1Zooooo`Co2NX:;?ooool0
0ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo
00?oOgmo00?o0000ooooooooool0IOooool5o`WZ2S3ooooo00?o0000ooooooooool02oooool006Go
oooo00?o0000ogmoOomoOgl01omoOgl7o`0006;ooooo1Ol9jPXeooooo`03o`000?oooooooooo00_o
oooo001Uooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`1Looooo`Co2NX:>_ooool00ol0003oooooooooo`0;ooooo`00IOooool00ol0003oOgmoogmo
O`07ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0Eoooool5o`WZ2Skooooo00?o
0000ooooooooool02oooool006Gooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo05;ooooo1Ol9jPY3ooooo`03o`000?oooooooooo00_ooooo001Uoooo
o`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1>oooo
o`Co2NX:B?ooool00ol0003oooooooooo`0;ooooo`00IOooool00ol0003oOgmoogmoO`07ogmoO`03
o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0BOooool5o`WZ2Tcooooo00?o0000oooooooo
ool02oooool006Kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`00
0?oooooooooo04Gooooo1?l9jPYAooooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?mo
OgooOgmo00KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`10ooooo`Go2NX:EOoo
ool00ol0003oooooooooo`0;ooooo`00I_ooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ooooooooool0>oooool5o`WZ2U[ooooo00?o0000ooooooooool02oooool0
06Kooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo
03Oooooo1?l9jPYOooooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?moOgooOgmo00Ko
Ogmo1ol0000dooooo`Go2NX:Hoooool00ol0003oooooooooo`0;ooooo`00Ioooool00ol0003oOgmo
ogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0;Oooool5o`WZ2VSooooo
00?o0000ooooooooool02oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmo
O`03ogmoO`03o`000?oooooooooo02Wooooo1?l9jPY]ooooo`03o`000?oooooooooo00_ooooo001W
ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0T
ooooo`Go2NX:LOooool00ol0003oooooooooo`0;ooooo`00Ioooool00ol0003oOgmoogmoO`05ogmo
O`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool08?ooool4o`WZ2WKooooo00?o0000oooo
ooooool02oooool006Oooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo01_ooooo1Ol9jPYjooooo`03o`000?oooooooooo00_ooooo001Xooooo`03o`00
0?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0Fooooo`Go2NX:
Ooooool00ol0003oooooooooo`0;ooooo`00J?ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?mo
OgooOgmo00?oOgmo00?o0000ooooooooool04_ooool4o`WZ2XCooooo00?o0000ooooooooool02ooo
ool006Sooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo00gooooo1Ol9jPZ8ooooo`03o`000?oooooooooo00_ooooo001Xooooo`03o`000?moOgooOgmo
00CoOgmo1ol0000;ooooo`Co2NX:SOooool00ol0003oooooooooo`0;ooooo`00JOooool00ol0003o
OgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool01?ooool5o`WZ2Y7o
oooo00?o0000ooooooooool02oooool006;ooooo0ol9jPX4ooooo`04o`000?moOgooOgmoogmoO`Go
2NX:0_moOgl2o`000003ooooool9jP[o2NX:00?o2NX:U_ooool00ol0003oooooooooo`0;ooooo`00
Hoooool6o`WZ2P03ooooool0003oOgmo00;oOgmo1_l9jPX00ol0003o2NX:o`WZ2P2Kooooo`03o`00
0?oooooooooo00_ooooo000<ooooofSo2NX:00?oOgmoo`000?ooool0Voooool00ol0003ooooooooo
o`0;ooooo`00Hoooool5o`WZ2P;ooooo0_l00002ogmoO`?o2NX:1?moOgl00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo00_ooooo001Rooooo`;o2NX:1oooool01Ol0003oOgmoo`WZ2_moOgoo
000000GoOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00K?ooool00ol0
003oOgmoogmoO`07o`0009cooooo00?o0000ooooooooool02oooool006cooooo00Co0000ogmoOomo
Ogoo00001OmoOgl00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001]ooooo`03
o`000?moOgoo000000GoOgmo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00
KOooool00ol0003oOgmoo`000005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
2oooool006kooooo0_l00005ogmoO`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02ooo
ool006kooooo2?l0002Looooo`03o`000?oooooooooo00_ooooo001_ooooo`Oo0000W?ooool00ol0
003oooooooooo`0;ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {102.625, 0}} -> {-57.2027, -32.4375, \
0.572841, 0.572841}},
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[opticalsystem,{f>0},MatrixForm->True, DecomposeABCD->True, \
ABCDConstruction->Horizontal]\
\>", "Input",
  CellLabel->"In[21]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d2"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(1.0000000000000002`\ t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(0.6577817908690828`\/f\)\), "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        MatrixForm[ {{1, 0}, {0, 1}}], 
        MatrixForm[ {{1, d2}, {0, 1}}], 
        MatrixForm[ {{1.0, 0}, {0, 1.51906311879655}}], 
        MatrixForm[ {{1, 
          Times[ 1.0000000000000002, t]}, {0, 1}}], 
        MatrixForm[ {{1, 0}, {
          Times[ -0.65778179086908284, 
            Power[ f, -1]], 0.65830049299875815}}], 
        MatrixForm[ {{1, d1}, {0, 1}}]}, TableDirections -> Row]]], "Output",
  CellLabel->"Out[21]//TableForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
SymbolicTrace[opticalsystem,{f>0},MatrixForm->True, DecomposeABCD->True, \
ABCDConstruction->Horizontal]\
\>", "Input",
  CellLabel->"In[22]:=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],

Cell[BoxData[
    \({SymbolicOpticalLength \[Rule] 
        1.0002694514570802`\ d1 + 1.0002694514570802`\ d2 + 
          1.5194724325673066`\ t, SymbolicRayEnd \[Rule] {d2 + t, 0, 0}, 
      SymbolicRayTilt \[Rule] {1, 0, 0}, 
      SymbolicSurfaceCoordinates \[Rule] {0, 0}, 
      SymbolicIntensity \[Rule] 100, 
      SymbolicSurfaceBoundary \[Rule] {50, 50}, 
      SymbolicOffAxis \[Rule] {0, 0}, 
      SymbolicTranslationVector \[Rule] {d2 + t, 0, 0}, 
      SymbolicRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
      SymbolicWaveLength \[Rule] \[Lambda], 
      SymbolicSurfaceNormalFunction \[Rule] {1, 0, 0}}\)], "Output",
  CellLabel->"Out[22]=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[opticalsystem,{f>0,a>0,d1>0,t>0,d2>0}, MatrixForm->True, \
DecomposeABCD->True, 
\tComplexABCD->True, ABCDConstruction->Horizontal]\
\>", "Input",
  CellLabel->"In[23]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(\[ImaginaryI]\ \[Lambda]\)\/\(625\ \[Pi]\)\)\), 
                      "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d2"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(4\ \[ImaginaryI]\ \[Lambda]\)\/\(a\^2\ \
\[Pi]\)\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(1.0000000000000002`\ t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(4\ \[ImaginaryI]\ \[Lambda]\)\/\(a\^2\ \
\[Pi]\)\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(0.6577817908690828`\/f\)\), "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        MatrixForm[ {{1, 0}, {
          Times[ 
            Complex[ 0, 
              Rational[ -1, 625]], 
            Power[ Pi, -1], \[Lambda]], 1}}], 
        MatrixForm[ {{1, 0}, {0, 1}}], 
        MatrixForm[ {{1, d2}, {0, 1}}], 
        MatrixForm[ {{1, 0}, {
          Times[ 
            Complex[ 0, -4], 
            Power[ a, -2], 
            Power[ Pi, -1], \[Lambda]], 1}}], 
        MatrixForm[ {{1.0, 0}, {0, 1.51906311879655}}], 
        MatrixForm[ {{1, 
          Times[ 1.0000000000000002, t]}, {0, 1}}], 
        MatrixForm[ {{1, 0}, {
          Times[ 
            Complex[ 0, -4], 
            Power[ a, -2], 
            Power[ Pi, -1], \[Lambda]], 1}}], 
        MatrixForm[ {{1, 0}, {
          Times[ -0.65778179086908284, 
            Power[ f, -1]], 0.65830049299875815}}], 
        MatrixForm[ {{1, d1}, {0, 1}}]}, TableDirections -> Row]]], "Output",
  CellLabel->"Out[23]//TableForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG3.3", "AOG3."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Off-axis lens", "Subsubsection",
  CellTags->{"AOG3.3.2", "AOG3.3", "3.3.2", "AOG3."}],

Cell["\<\
offaxisopticalsystem = {
Move[LineOfRays[40,SymbolicIntensity->100,SymbolicWaveLength->\[Lambda]], \
{-d1,-50}],
PlanoConvexLens[{f,100},{a,50},{t,20},DesignWaveLength->.532,OffAxis->{10,0}],\

Move[Screen[50],{d2+t,100}]};\
\>", "Input",
  CellLabel->"In[24]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[offaxisopticalsystem,PlotType->TopView];", "Input",
  CellLabel->"In[25]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .428 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.195587 0.00634921 [
[.40476 .01019 -5.03125 -6 ]
[.40476 .01019 5.03125 6 ]
[.97619 .01019 -4.75 -6 ]
[.97619 .01019 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .428 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.35532 .10035 m
.46825 .10035 L
.46825 .15326 L
.344 .15326 L
.35532 .10035 L
F
.344 .15326 m
.46825 .15326 L
.46825 .20617 L
.34144 .20617 L
.344 .15326 L
F
.34144 .20617 m
.46825 .20617 L
.46825 .25908 L
.34744 .25908 L
.34144 .20617 L
F
.34744 .25908 m
.46825 .25908 L
.46825 .31199 L
.36249 .31199 L
.34744 .25908 L
F
.36249 .31199 m
.46825 .31199 L
.46825 .3649 L
.38804 .3649 L
.36249 .31199 L
F
.38804 .3649 m
.46825 .3649 L
.46825 .41781 L
.42737 .41781 L
.38804 .3649 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.35532 .10035 m
.344 .15326 L
.34144 .20617 L
.34744 .25908 L
.36249 .31199 L
.38804 .3649 L
.42737 .41781 L
.46825 .41781 L
.46825 .3649 L
.46825 .31199 L
.46825 .25908 L
.46825 .20617 L
.46825 .15326 L
.46825 .10035 L
.35532 .10035 L
s
.5 g
.38903 .25908 m
.46825 .25908 L
.46825 .25908 L
.36523 .25908 L
.38903 .25908 L
F
.36523 .25908 m
.46825 .25908 L
.46825 .25908 L
.35179 .25908 L
.36523 .25908 L
F
.35179 .25908 m
.46825 .25908 L
.46825 .25908 L
.34744 .25908 L
.35179 .25908 L
F
.34744 .25908 m
.46825 .25908 L
.46825 .25908 L
.35179 .25908 L
.34744 .25908 L
F
.35179 .25908 m
.46825 .25908 L
.46825 .25908 L
.36523 .25908 L
.35179 .25908 L
F
.36523 .25908 m
.46825 .25908 L
.46825 .25908 L
.38903 .25908 L
.36523 .25908 L
F
0 g
.38903 .25908 m
.36523 .25908 L
.35179 .25908 L
.34744 .25908 L
.35179 .25908 L
.36523 .25908 L
.38903 .25908 L
.46825 .25908 L
.46825 .25908 L
.46825 .25908 L
.46825 .25908 L
.46825 .25908 L
.46825 .25908 L
.46825 .25908 L
.38903 .25908 L
s
.42737 .41781 m
.46825 .41781 L
.46825 .4124 L
.42597 .4124 L
.42737 .41781 L
s
.42597 .4124 m
.46825 .4124 L
.46825 .39654 L
.42189 .39654 L
.42597 .4124 L
s
.42189 .39654 m
.46825 .39654 L
.46825 .37132 L
.41555 .37132 L
.42189 .39654 L
s
.41555 .37132 m
.46825 .37132 L
.46825 .33844 L
.4075 .33844 L
.41555 .37132 L
s
.4075 .33844 m
.46825 .33844 L
.46825 .30016 L
.39844 .30016 L
.4075 .33844 L
s
.39844 .30016 m
.46825 .30016 L
.46825 .25908 L
.38903 .25908 L
.39844 .30016 L
s
.38903 .25908 m
.46825 .25908 L
.46825 .218 L
.37993 .218 L
.38903 .25908 L
s
.37993 .218 m
.46825 .218 L
.46825 .17971 L
.3717 .17971 L
.37993 .218 L
s
.3717 .17971 m
.46825 .17971 L
.46825 .14684 L
.36481 .14684 L
.3717 .17971 L
s
.36481 .14684 m
.46825 .14684 L
.46825 .12162 L
.35962 .12162 L
.36481 .14684 L
s
.35962 .12162 m
.46825 .12162 L
.46825 .10576 L
.35641 .10576 L
.35962 .12162 L
s
.35641 .10576 m
.46825 .10576 L
.46825 .10035 L
.35532 .10035 L
.35641 .10576 L
s
.35532 .10035 m
.46825 .10035 L
.46825 .10576 L
.35641 .10576 L
.35532 .10035 L
s
.35641 .10576 m
.46825 .10576 L
.46825 .12162 L
.35962 .12162 L
.35641 .10576 L
s
.35962 .12162 m
.46825 .12162 L
.46825 .14684 L
.36481 .14684 L
.35962 .12162 L
s
.36481 .14684 m
.46825 .14684 L
.46825 .17971 L
.3717 .17971 L
.36481 .14684 L
s
.3717 .17971 m
.46825 .17971 L
.46825 .218 L
.37993 .218 L
.3717 .17971 L
s
.37993 .218 m
.46825 .218 L
.46825 .25908 L
.38903 .25908 L
.37993 .218 L
s
.38903 .25908 m
.46825 .25908 L
.46825 .30016 L
.39844 .30016 L
.38903 .25908 L
s
.39844 .30016 m
.46825 .30016 L
.46825 .33844 L
.4075 .33844 L
.39844 .30016 L
s
.4075 .33844 m
.46825 .33844 L
.46825 .37132 L
.41555 .37132 L
.4075 .33844 L
s
.41555 .37132 m
.46825 .37132 L
.46825 .39654 L
.42189 .39654 L
.41555 .37132 L
s
.42189 .39654 m
.46825 .39654 L
.46825 .4124 L
.42597 .4124 L
.42189 .39654 L
s
.42597 .4124 m
.46825 .4124 L
.46825 .41781 L
.42737 .41781 L
.42597 .4124 L
s
.97619 .03686 m
.97619 .08977 L
.97619 .14268 L
.97619 .19559 L
.97619 .2485 L
.97619 .30141 L
.97619 .35432 L
.97619 .35432 L
.97619 .30141 L
.97619 .2485 L
.97619 .19559 L
.97619 .14268 L
.97619 .08977 L
.97619 .03686 L
.97619 .03686 L
s
.97619 .19559 m
.97619 .19559 L
.97619 .19559 L
.97619 .19559 L
.97619 .19559 L
.97619 .19559 L
.97619 .19559 L
.97619 .19559 L
.97619 .19559 L
.97619 .19559 L
.97619 .19559 L
.97619 .19559 L
.97619 .19559 L
.97619 .19559 L
.97619 .19559 L
s
.97619 .35432 m
.97619 .34891 L
.97619 .33305 L
.97619 .30783 L
.97619 .27495 L
.97619 .23667 L
.97619 .19559 L
.97619 .1545 L
.97619 .11622 L
.97619 .08335 L
.97619 .05812 L
.97619 .04227 L
.97619 .03686 L
.97619 .04227 L
.97619 .05812 L
.97619 .08335 L
.97619 .11622 L
.97619 .1545 L
.97619 .19559 L
.97619 .23667 L
.97619 .27495 L
.97619 .30783 L
.97619 .33305 L
.97619 .34891 L
.97619 .35432 L
s
.039 .916 .04 r
.02381 .0686 m
.97619 .0686 L
s
% Start of user PostScript
-50. -20. 100. -20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .0686 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19559 m
.34127 .19559 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .19559 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .32257 m
.36669 .32257 L
s
% Start of user PostScript
-50. 20. 4.0044 20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.36669 .32257 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .19559 m
.46825 .19559 L
s
% Start of user PostScript
0 0 20. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46825 .19559 Mdot
.039 .916 .04 r
.5 Mabswid
.36669 .32257 m
.46825 .30837 L
s
% Start of user PostScript
4.0044 20. 20. 17.7627 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46825 .30837 Mdot
.039 .916 .04 r
.5 Mabswid
.46825 .19559 m
.97619 .19559 L
s
% Start of user PostScript
20. 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19559 Mdot
.039 .916 .04 r
.5 Mabswid
.46825 .30837 m
.97619 .19904 L
s
% Start of user PostScript
20. 17.7627 100. 0.543145 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19904 Mdot
gsave
.40476 .01019 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .01019 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .428 L
0 .428 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[25]:=",
  ImageSize->{288, 123.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Nb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00LOooool6o`0009_ooooo0ol0
000;ooooo`00L_ooool01Ol0003ooooooooooooooooo000009_ooooo00Co0000oooooooooooo0000
2_ooool007;ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`08ooooo`00L_ooool0
0ol0003oooooooooo`2Nooooo`;o00002oooool007;ooooo00?o0000ooooooooool0WOooool00ol0
003oooooooooo`0;ooooo`00L_ooool00ol0003oooooooooo`2Mooooo`04o`000?ooooooooooo`00
00[ooooo001aooooo`?o0000Woooool3o`0000[ooooo003oooooob7ooooo003oooooob7ooooo003o
oooooaGooooo00?o0000ooooooooool02Oooool00?oooooo5?ooool00ol0003oooooooooo`0:oooo
o`00oooooolDooooo`03o`000?oooooooooo00[ooooo003ooooooaCooooo00?o0000ooooooooool0
2_ooool00?oooooo5?ooool00ol0003oooooooooo`0:ooooo`00oooooolDooooo`03o`000?oooooo
oooo00[ooooo003ooooooaCooooo00?o0000ooooooooool02_ooool00?oooooo5?ooool00ol0003o
ooooooooo`0:ooooo`00ooooool<ooooo`?o2NX:1Oooool00ol0003oooooooooo`0:ooooo`00oooo
ool=ooooo`Ko2NX:00?oooooo`000?l000002oooool000_oooooool9jPX9o`WZ2P;o00002oooool0
0?oooooo3Oooool5o`WZ2P;ooooo00?o0000ooooooooool02_ooool00?oooooo3?ooool2o`WZ2PKo
oooo00?o0000ooooooooool02_ooool00?oooooo5?ooool00ol0003oooooooooo`0:ooooo`00oooo
oolDooooo`03o`000?oooooooooo00[ooooo003ooooooaCooooo00?o0000ooooooooool02_ooool0
0?oooooo5?ooool00ol0003oooooooooo`0:ooooo`00oooooolDooooo`03o`000?oooooooooo00[o
oooo001Wooooob3o0000S?ooool00ol0003oooooooooo`0:ooooo`00Ioooool00ol0003oOgmoogmo
O`0LogmoO`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02_ooool006Oooooo8?l0002<
ooooo`03o`000?oooooooooo00[ooooo001Vooooo`;o00007_moOgl00ol0003oooooooooo`2:oooo
o`03o`000?oooooooooo00[ooooo001Vooooo`;o00007_moOgl00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo00[ooooo001Vooooo`03o`000?moOgoo000001goOgmo00?o0000ooooooooool0
R_ooool00ol0003oooooooooo`0:ooooo`00I_ooool00ol0003oOgmoo`00000No`0008cooooo00?o
0000ooooooooool02_ooool006Kooooo00?o0000ogmoOol000007OmoOgl00ol0003oooooooooo`2:
ooooo`03o`000?oooooooooo00[ooooo001Uooooo`04o`000?moOgooOgmoo`0001goOgmo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0:ooooo`00IOooool01?l0003oOgmoogmoOol0000M
ogmoO`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02_ooool006Gooooo00Go0000ogmo
OomoOgooOgmoo`00000LogmoO`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02_ooool0
06Gooooo00Go0000ogmoOomoOgooOgmoo`00000LogmoO`03o`000?oooooooooo08[ooooo00?o0000
ooooooooool02_ooool006Gooooo00Go0000ogmoOomoOgooOgmoo`00000LogmoO`03o`000?oooooo
oooo08[ooooo00?o0000ooooooooool02_ooool006Cooooo00?o0000ogmoOomoOgl00_moOglNo`00
08cooooo00?o0000ooooooooool02_ooool006Cooooo00?o0000ogmoOomoOgl00_moOgl00ol0003o
OgmoogmoO`0JogmoO`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02_ooool006Cooooo
00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0JogmoO`03o`000?oooooooooo08[ooooo
00?o0000ooooooooool02_ooool006Cooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmo
O`0IogmoO`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02_ooool006Cooooo00?o0000
ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`0IogmoO`03o`000?oooooooooo08[ooooo00?o0000
ooooooooool02_ooool006Cooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`0Iogmo
O`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02_ooool006Cooooo00?o0000ogmoOomo
Ogl00omoOgl00ol0003oOgmoogmoO`0IogmoO`03o`000?oooooooooo08[ooooo00?o0000oooooooo
ool02_ooool006Cooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`0IogmoO`03o`00
0?oooooooooo08[ooooo00?o0000ooooooooool02_ooool006Cooooo00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oOgmoogmoO`0HogmoO`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02_oo
ool006Cooooo00?o0000ogmoOomoOgl01?moOglLo`0008cooooo00?o0000ooooooooool02_ooool0
06?ooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`0HogmoO`03o`000?oooooooooo
08[ooooo00?o0000ooooooooool02_ooool006?ooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003o
OgmoogmoO`0HogmoO`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02_ooool005_ooooo
0ol9jPX5ooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl03omoOgl3o`WZ2PGoOgmo
00?o0000ooooooooool0P_ooool3o`WZ2PGooooo00?o0000ooooooooool02_ooool005cooooo1_l9
jPX2o`0000SoOgmo00?o0000ogmoOomoOgl04?moOgl6o`WZ2P03ogmoOol0003o000008Cooooo1_l9
jPX00ooooooo0000o`00000;ooooo`002ooooomGo`WZ2P03o`000?l9jP[o2NX:0:ko2NX:0_l0000;
ooooo`00G?ooool5o`WZ2P;ooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`0?ogmo
O`Go2NX:0_moOgl00ol0003oooooooooo`22ooooo`So2NX:0_l0000;ooooo`00Foooool2o`WZ2PKo
oooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`0>ogmoO`;o2NX:1_moOgl00ol0003o
ooooooooo`22ooooo`Oo2NX:00?oooooo`000?ooool02oooool006?ooooo00?o0000ogmoOomoOgl0
1omoOgl00ol0003oOgmoogmoO`0FogmoO`03o`000?oooooooooo07kooooo1Ol9jPX00ooooooo2NX:
o`WZ2P04ooooo`03o`000?oooooooooo00[ooooo001Sooooo`03o`000?moOgooOgmo00OoOgmo00?o
0000ogmoOomoOgl05_moOgl00ol0003oooooooooo`1jooooo`Co2NX:1Oooool00ol9jP[ooooooooo
o`04ooooo`03o`000?oooooooooo00[ooooo001Sooooo`03o`000?moOgooOgmo00SoOgmo00?o0000
ogmoOomoOgl05OmoOgl00ol0003oooooooooo`1eooooo`Go2NX:4?ooool00ol0003oooooooooo`0:
ooooo`00Hoooool00ol0003oOgmoogmoO`08ogmoOaWo0000L_ooool5o`WZ2QGooooo00?o0000oooo
ooooool02_ooool006Cooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`0EogmoO`03
o`000?oooooooooo06_ooooo1Ol9jPXJooooo`03o`000?oooooooooo00[ooooo001Tooooo`03o`00
0?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl05OmoOgl00ol0003oooooooooo`1Wooooo`Co2NX:
7oooool00ol0003oooooooooo`0:ooooo`00I?ooool00ol0003oOgmoogmoO`07ogmoO`03o`000?mo
OgooOgmo01GoOgmo00?o0000ooooooooool0H_ooool5o`WZ2R?ooooo00?o0000ooooooooool02_oo
ool006Cooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`0DogmoO`03o`000?oooooo
oooo05gooooo1Ol9jPXXooooo`03o`000?oooooooooo00[ooooo001Tooooo`03o`000?moOgooOgmo
00SoOgmo00?o0000ogmoOomoOgl05?moOgl00ol0003oooooooooo`1Iooooo`Co2NX:;Oooool00ol0
003oooooooooo`0:ooooo`00I?ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo01Co
Ogmo00?o0000ooooooooool0E?ooool5o`WZ2S7ooooo00?o0000ooooooooool02_ooool006Cooooo
00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`0DogmoO`03o`000?oooooooooo04oooooo
1Ol9jPXfooooo`03o`000?oooooooooo00[ooooo001Uooooo`03o`000?moOgooOgmo00OoOgmo00?o
0000ogmoOomoOgl05?moOgl00ol0003oooooooooo`1;ooooo`Co2NX:>oooool00ol0003ooooooooo
o`0:ooooo`00IOooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo01?oOgmo00?o0000
ooooooooool0A_ooool5o`WZ2Soooooo00?o0000ooooooooool02_ooool006Gooooo00?o0000ogmo
OomoOgl02?moOgl00ol0003oOgmoogmoO`0CogmoO`03o`000?oooooooooo047ooooo1Ol9jPY4oooo
o`03o`000?oooooooooo00[ooooo001Uooooob;o0000?_ooool5o`WZ2TWooooo00?o0000oooooooo
ool02_ooool006Gooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`0CogmoO`03o`00
0?oooooooooo03Sooooo1?l9jPY>ooooo`03o`000?oooooooooo00[ooooo001Uooooo`03o`000?mo
OgooOgmo00SoOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`0cooooo`Go2NX:D_oo
ool00ol0003oooooooooo`0:ooooo`00I_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgoo
Ogmo01;oOgmo00?o0000ooooooooool0;_ooool5o`WZ2UOooooo00?o0000ooooooooool02_ooool0
06Kooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`0BogmoO`03o`000?oooooooooo
02[ooooo1?l9jPYLooooo`03o`000?oooooooooo00[ooooo001Vooooo`03o`000?moOgooOgmo00So
Ogmo00?o0000ogmoOomoOgl04_moOgl00ol0003oooooooooo`0Uooooo`Go2NX:H?ooool00ol0003o
ooooooooo`0:ooooo`00I_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo01;oOgmo
00?o0000ooooooooool08?ooool5o`WZ2VGooooo00?o0000ooooooooool02_ooool006Oooooo00?o
0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo01cooooo1?l9
jPYZooooo`03o`000?oooooooooo00[ooooo001Wooooo`03o`000?moOgooOgmo00SoOgmo00?o0000
ogmoOomoOgl04OmoOgl00ol0003oooooooooo`0Gooooo`Go2NX:K_ooool00ol0003oooooooooo`0:
ooooo`00Ioooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo017oOgmo00?o0000oooo
ooooool04_ooool5o`WZ2W?ooooo00?o0000ooooooooool02_ooool006Sooooo00?o0000ogmoOomo
Ogl01omoOgl00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo00gooooo1Ol9jPYhooooo`03
o`000?oooooooooo00[ooooo001Xooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl0
4?moOgl00ol0003oooooooooo`09ooooo`Co2NX:OOooool00ol0003oooooooooo`0:ooooo`00J?oo
ool00ol0003oOgmoogmoO`08ogmoOaCo00001_ooool5o`WZ2X7ooooo00?o0000ooooooooool02_oo
ool006Sooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`08ogmoO`Go2NX:0omoOgl0
0ol0003oooooo`WZ2P04o`WZ2XKooooo00?o0000ooooooooool02_ooool006Wooooo00?o0000ogmo
OomoOgl01omoOgl00ol0003oOgmoogmoO`09ogmoO`Wo2NX:Roooool00ol0003oooooooooo`0:oooo
o`00JOooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00KoOgmo2Ol9jPX00omoOgoo
0000o`00002;ooooo`03o`000?oooooooooo00[ooooo001Rooooo`?o2NX:1?ooool00ol0003oOgmo
ogmoO`08ogmoO`03o`000?l9jP[o2NX:00Go2NX:0omoOgl3o`WZ2PCoOgmo00?o0000ooooooooool0
R_ooool00ol0003oooooooooo`0:ooooo`00Hoooool6o`WZ2P03ooooool0003oOgmo00;oOgmo1ol9
jPX9ogmoO`03o`WZ2_moOgooOgmo00GoOgmo00?o0000ooooooooool0R_ooool00ol0003ooooooooo
o`0:ooooo`002ooooomNo`WZ2P03o`000?l9jP[o2NX:00;o2NX:1_moOgl00ol0003oOgmoogmoO`0?
ogmoO`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02_ooool006?ooooo1Ol9jPX01?oo
oooo0000o`000?l00008ogmoO`03o`000?moOgooOgmo00ooOgmo00?o0000ooooooooool0R_ooool0
0ol0003oooooooooo`0:ooooo`00H_ooool2o`WZ2POooooo00?o0000ogmoOomoOgl01_moOgl00ol0
003oOgmoogmoO`0?ogmoO`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02_ooool006co
oooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?oooooooooo08[o
oooo00?o0000ooooooooool02_ooool006cooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmo
ogmoO`0>ogmoO`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02_ooool006gooooo00?o
0000ogmoOomoOgl01OmoOglBo`0008cooooo00?o0000ooooooooool02_ooool006gooooo00?o0000
ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?oooooooooo08[ooooo00?o0000
ooooooooool02_ooool006gooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0=ogmo
O`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02_ooool006kooooo00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oOgmoogmoO`0=ogmoO`03o`000?oooooooooo08[ooooo00?o0000oooooooo
ool02_ooool006kooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`0=ogmoO`03o`00
0?oooooooooo08[ooooo0_l0000;ooooo`00Koooool00ol0003oOgmoogmoO`05ogmoO`03o`000?mo
OgooOgmo00coOgmo00?o0000ooooooooool0Uoooool006oooooo00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oOgmoogmoO`0<ogmoO`03o`000?oooooooooo09Oooooo001`ooooo`03o`000?moOgooOgmo
00CoOgmo00?o0000ogmoOomoOgl03?moOgl00ol0003oooooooooo`2Gooooo`00L?ooool00ol0003o
OgmoogmoO`05ogmoO`03o`000?moOgooOgmo00_oOgmo00?o0000ooooooooool0Uoooool0077ooooo
00?o0000ogmoOomoOgl01?moOgl?o`0009Wooooo001booooo`03o`000?moOgooOgmo00?oOgmo00?o
0000ogmoOomoOgl02omoOgl00ol0003oooooooooo`2Gooooo`00Loooool00ol0003oOgmoogmoO`02
ogmoO`03o`000?moOgooOgmo00_oOgmo00?o0000ooooooooool0Uoooool007?ooooo00?o0000ogmo
OomoOgl00_moOgl00ol0003oOgmoogmoO`0;ogmoO`03o`000?oooooooooo09Oooooo001dooooo`03
o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl02_moOgl00ol0003oooooooooo`2Gooooo`00
MOooool01Ol0003oOgmoogmoOomoOgoo000000coOgmo00?o0000ooooooooool0Uoooool007Kooooo
00Co0000ogmoOomoOgoo00003?moOgl00ol0003oooooooooo`2Gooooo`00M_ooool00ol0003oOgmo
ogmoO`0>o`0009Wooooo001gooooo`03o`000?moOgoo000000coOgmo00?o0000ooooooooool0Uooo
ool007Sooooo0_l0000<ogmoO`03o`000?oooooooooo09Oooooo001hooooo`03o`000?moOgoo0000
00_oOgmo00?o0000ooooooooool0Uoooool007Wooooo3_l0002Iooooo`00N_ooool00ol0003oOgmo
ogmoO`09ogmoO`03o`000?oooooooooo09Oooooo001kooooo`co0000VOooool00?oooooo8Oooool0
0?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {122.25, 0}} -> {-56.2312, -32.5968, 0.56607, \
0.56607}},
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[offaxisopticalsystem,{f>0,a>0,d1>0,t>0,d2>0}, \
MatrixForm->True, DecomposeABCD->True, ComplexABCD->True]\
\>", "Input",
  CellLabel->"In[26]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(\[ImaginaryI]\ \[Lambda]\)\/\(625\ \[Pi]\)\)\), 
                      "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d2"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(4\ \[ImaginaryI]\ \((\(-800\) + 
                                  a\^2)\)\ \[Lambda]\)\/\(a\^4\ \[Pi]\)\)\), 
                      "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(1.0000000000000002`\ t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(4\ \[ImaginaryI]\ \((\(-800\) + 
                                  a\^2)\)\ \[Lambda]\)\/\(a\^4\ \[Pi]\)\)\), 
                      "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(0.6577817908690828`\/f\)\), "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(\[ImaginaryI]\ \[Lambda]\)\/\(625\ \[Pi]\)\)\), 
                      "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d2"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(4\ \[ImaginaryI]\ \[Lambda]\)\/\(a\^2\ \
\[Pi]\)\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(1.0000000000000002`\ t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(4\ \[ImaginaryI]\ \[Lambda]\)\/\(a\^2\ \
\[Pi]\)\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(0.6577817908690828`\/f\)\), "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Row, TableAlignments -> 
          Center]]]], "Output",
  CellLabel->"Out[26]//TableForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
result0 = FindABCDMatrix[offaxisopticalsystem,{f>0,a>0,d1>0,t>0,d2>0}, \
MatrixForm->False, DecomposeABCD->True, ComplexABCD->True, \
ABCDConstruction->Horizontal]\
\>", "Input",
  CellLabel->"In[27]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],

Cell[BoxData[
    \({{ABCDCenterPoint \[Rule] {0, 0, 0}, 
        ABCDMatrix \[Rule] {{1, d1}, {0, 1}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}}, {ABCDCenterPoint \[Rule] {0, 0, 0}, 
        ABCDMatrix \[Rule] {{1, 0}, {\(-\(0.6577817908690828`\/f\)\), 
              0.6583004929987581`}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}}, {ABCDCenterPoint \[Rule] {0, 0, 0}, 
        ABCDMatrix \[Rule] {{1, 
              0}, {\(-\(\(4\ \[ImaginaryI]\ \((\(-800\) + 
                          a\^2)\)\ \[Lambda]\)\/\(a\^4\ \[Pi]\)\)\), 1}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}}, {ABCDCenterPoint \[Rule] {t, 0, 0}, 
        ABCDMatrix \[Rule] {{1, 1.0000000000000002`\ t}, {0, 1}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}}, {ABCDCenterPoint \[Rule] {t, 0, 0}, 
        ABCDMatrix \[Rule] {{1.`, 0}, {0, 1.51906311879655`}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}}, {ABCDCenterPoint \[Rule] {t, 0, 0}, 
        ABCDMatrix \[Rule] {{1, 
              0}, {\(-\(\(4\ \[ImaginaryI]\ \((\(-800\) + 
                          a\^2)\)\ \[Lambda]\)\/\(a\^4\ \[Pi]\)\)\), 1}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}}, {ABCDCenterPoint \[Rule] {d2 + t, 0, 0}, 
        ABCDMatrix \[Rule] {{1, d2}, {0, 1}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}}, {ABCDCenterPoint \[Rule] {d2 + t, 0, 0}, 
        ABCDMatrix \[Rule] {{1, 0}, {0, 1}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}}, {ABCDCenterPoint \[Rule] {d2 + t, 0, 0}, 
        ABCDMatrix \[Rule] {{1, 
              0}, {\(-\(\(\[ImaginaryI]\ \[Lambda]\)\/\(625\ \[Pi]\)\)\), 
              1}}, ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}}}\)], "Output",
  CellLabel->"Out[27]=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[offaxisopticalsystem,{f>0,a>0,d1>0,t>0,d2>0}, \
MatrixForm->True, ABCDConstruction->Horizontal]\
\>", "Input",
  CellLabel->"In[28]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(\(-0.9992120587251689`\)\ d2 + f - 
                    0.6577817908690828`\ t\)\/f\), \(d2 + \(d1\ \
\((\(-0.9992120587251689`\)\ d2 + f - 0.6577817908690828`\ t)\)\)\/f + 
                0.6583004929987581`\ t\)},
            {\(-\(0.9992120587251689`\/f\)\), \(1 - \(0.9992120587251689`\ d1\
\)\/f\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[28]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG3.3", "AOG3."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cylindrical lens", "Subsubsection",
  CellTags->{"AOG3.3.3", "AOG3.3", "3.3.3", "AOG3."}],

Cell["\<\
gaussiansystem3D = {
GaussianBeam[{1,1},{.1,.1},SymbolicIntensity->100,SymbolicWaveLength->\
\[Lambda]],
Move[PlanoConvexCylindricalLens[{f,100},{{a,50},{b,40}},{t,10},\
DesignWaveLength->.532],{d1,50}],
Move[Screen[{{h,30},{v,50}}],{d2+t,100}, TwistAngle->30]};\
\>", "Input",
  CellLabel->"In[29]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell["\<\
gaussiansystem = {
GaussianBeam[1,.1,SymbolicIntensity->100,SymbolicWaveLength->\[Lambda]],
Move[PlanoConvexCylindricalLens[{f,100},{{a,50},{b,40}},{t,10},\
DesignWaveLength->.532],{d1,50}],
Move[Screen[{{h,30},{v,50}}],{d2+t,100}, TwistAngle->30]};\
\>", "Input",
  CellLabel->"In[30]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[CellGroupData[{

Cell["FindABCDMatrix[gaussiansystem3D,{f>0},MatrixForm->True]", "Input",
  CellLabel->"In[31]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(0.9992120587251689`\ d1 - 0.9992120587251689`\ d2 + 
                            f - 0.6577817908690828`\ t\)\/f\), \
\(\(0.9992120587251689`\ d1\^2 - 0.9992120587251689`\ d1\ d2 + d2\ f - 
                            0.6577817908690828`\ d1\ t + 
                            0.6583004929987583`\ f\ t\)\/f\)},
                    {\(-\(0.9992120587251688`\/f\)\), \(1 - \
\(0.9992120587251688`\ d1\)\/f\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(d2 + 0.6583004929987581`\ t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      TableForm[ {
        MatrixForm[ {{
          Times[ 
            Power[ f, -1], 
            Plus[ 
              Times[ 0.99921205872516894, d1], 
              Times[ -0.99921205872516894, d2], f, 
              Times[ -0.65778179086908284, t]]], 
          Times[ 
            Power[ f, -1], 
            Plus[ 
              Times[ 0.99921205872516894, 
                Power[ d1, 2]], 
              Times[ -0.99921205872516894, d1, d2], 
              Times[ d2, f], 
              Times[ -0.65778179086908284, d1, t], 
              Times[ 0.65830049299875826, f, t]]]}, {
          Times[ -0.99921205872516883, 
            Power[ f, -1]], 
          Plus[ 1, 
            Times[ -0.99921205872516883, d1, 
              Power[ f, -1]]]}}], 
        MatrixForm[ {{1, 
          Plus[ d2, 
            Times[ 0.65830049299875815, t]]}, {0, 1}}]}, TableAlignments -> 
        Center]]], "Output",
  CellLabel->"Out[31]//TableForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindABCDMatrix[gaussiansystem,{f>0},MatrixForm->True]", "Input",
  CellLabel->"In[32]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(0.9992120587251689`\ d1 - 0.9992120587251689`\ d2 + f - 
                    0.6577817908690828`\ t\)\/f\), \(\(0.9992120587251689`\ \
d1\^2 - 0.9992120587251689`\ d1\ d2 + d2\ f - 0.6577817908690828`\ d1\ t + 
                    0.6583004929987583`\ f\ t\)\/f\)},
            {\(-\(0.9992120587251688`\/f\)\), \(1 - \(0.9992120587251688`\ d1\
\)\/f\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[32]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell["\<\
cylindricalsystem = {
Move[LineOfRays[40,SymbolicIntensity->100,SymbolicWaveLength->\[Lambda], \
IntrinsicMedium->Vacuum], {-d1,-50}],
PlanoConvexCylindricalLens[{f,100},{{a,50},{b,40}},{t,10},DesignWaveLength->1/\
2, ComponentMedium->3/2],
Move[Screen[{{h,30},{v,50}}],{d2+t,100}, TwistAngle->30]};\
\>", "Input",
  CellLabel->"In[47]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[cylindricalsystem];", "Input",
  CellLabel->"In[34]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .7181 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0218919 1.02189 -0.130911 1.02189 [
[ 0 0 0 0 ]
[ 1 .7181 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .7181 L
0 .7181 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.42448 .37334 m
.46461 .39156 L
s
.46461 .39156 m
.48197 .38601 L
s
.46461 .39156 m
.46444 .42148 L
s
.48197 .38601 m
.45975 .36191 L
s
.48192 .41596 m
.48197 .38601 L
s
.46444 .42148 m
.48192 .41596 L
s
.46444 .42148 m
.46426 .45181 L
s
.39143 .35228 m
.42448 .37334 L
s
.42448 .37334 m
.45975 .36191 L
s
.48187 .44633 m
.48192 .41596 L
s
.45975 .36191 m
.43705 .33729 L
s
.46426 .45181 m
.48187 .44633 L
s
.39143 .35228 m
.43705 .33729 L
s
.4231 .46469 m .48182 .47712 L .46409 .48257 L .656 .751 .92 r
F
0 g
.46391 .51377 m
.46409 .48257 L
s
.46414 .47338 m
.46426 .45181 L
s
.4231 .46469 m .45912 .45348 L .48182 .47712 L .656 .751 .92 r
F
0 g
.48177 .50836 m
.48182 .47712 L
s
.039 .916 .04 r
.18163 .55171 m
.43855 .47219 L
s
0 g
.48182 .47712 m
.48187 .44633 L
s
.46409 .48257 m
.48182 .47712 L
s
0 0 0 r
2 Mabswid
.43855 .47219 Mdot
.36462 .32855 m .41333 .34253 L .36373 .35884 L .544 .324 .532 r
F
0 g
.5 Mabswid
.38933 .35042 m
.39143 .35228 L
s
.36462 .32855 m .41387 .31214 L .41333 .34253 L .544 .324 .532 r
F
0 g
.34388 .30209 m
.36462 .32855 L
s
.36462 .32855 m
.41387 .31214 L
s
.41387 .31214 m
.43705 .33729 L
s
.46391 .51377 m
.48177 .50836 L
s
.46391 .51377 m
.46373 .54541 L
s
.38932 .44403 m .45912 .45348 L .4231 .46469 L .656 .751 .92 r
F
.039 .916 .04 r
.43855 .47219 m
.46597 .46061 L
s
0 g
.4231 .46469 m
.46409 .48257 L
s
.48172 .54005 m
.48177 .50836 L
s
.039 .916 .04 r
.46597 .46061 m
.89906 .24789 L
s
0 0 0 r
2 Mabswid
.46597 .46061 Mdot
0 g
.5 Mabswid
.39019 .28645 m
.41387 .31214 L
s
.38932 .44403 m .43593 .42932 L .45912 .45348 L .656 .751 .92 r
F
0 g
.45912 .45348 m
.48182 .47712 L
s
.36373 .35884 m .41278 .37336 L .36282 .38957 L .544 .324 .532 r
F
.36373 .35884 m .41333 .34253 L .41278 .37336 L F
0 g
.36373 .35884 m
.36462 .32855 L
s
.41333 .34253 m
.41387 .31214 L
s
.46373 .54541 m
.48172 .54005 L
s
.46373 .54541 m
.46355 .57751 L
s
.48167 .57219 m
.48172 .54005 L
s
.36191 .42074 m .43593 .42932 L .38932 .44403 L .656 .751 .92 r
F
0 g
.38932 .44403 m
.4231 .46469 L
s
.32965 .27265 m
.34388 .30209 L
s
.34388 .30209 m
.39019 .28645 L
s
.36282 .38957 m .41222 .40463 L .36191 .42074 L .544 .324 .532 r
F
.36282 .38957 m .41278 .37336 L .41222 .40463 L F
0 g
.36282 .38957 m
.36373 .35884 L
s
.41278 .37336 m
.41333 .34253 L
s
.46355 .57751 m
.48167 .57219 L
s
.46355 .57751 m
.42166 .56003 L
s
.45846 .54907 m
.48167 .57219 L
s
.36191 .42074 m .41222 .40463 L .43593 .42932 L .656 .751 .92 r
F
0 g
.43593 .42932 m
.45912 .45348 L
s
.39019 .28645 m
.36598 .2602 L
s
.36191 .42074 m .41166 .43637 L .36098 .45237 L .544 .324 .532 r
F
0 g
.3888 .44359 m
.38932 .44403 L
s
.36191 .42074 m .41222 .40463 L .41166 .43637 L .544 .324 .532 r
F
.34068 .39476 m .41222 .40463 L .36191 .42074 L .656 .751 .92 r
F
.039 .916 .04 r
.12065 .49798 m
.36191 .42074 L
s
0 g
.36258 .39778 m
.36282 .38957 L
s
0 0 0 r
2 Mabswid
.36191 .42074 Mdot
0 g
.5 Mabswid
.42166 .56003 m
.45846 .54907 L
s
.42166 .56003 m
.38713 .53983 L
s
.32308 .23967 m
.32965 .27265 L
s
.32965 .27265 m
.36598 .2602 L
s
.43475 .52544 m
.45846 .54907 L
s
.36598 .2602 m
.34124 .23336 L
s
.34068 .39476 m .38799 .3794 L .41222 .40463 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.41222 .40463 Mdot
.039 .916 .04 r
.5 Mabswid
.41222 .40463 m
.89957 .24861 L
s
.36191 .42074 m
.41222 .40463 L
s
0 g
.41222 .40463 m
.41278 .37336 L
s
.41222 .40463 m
.43593 .42932 L
s
.36098 .45237 m .41108 .46858 L .36003 .48447 L .544 .324 .532 r
F
.36098 .45237 m .41166 .43637 L .41108 .46858 L F
0 g
.36098 .45237 m
.36191 .42074 L
s
.41166 .43637 m
.41222 .40463 L
s
.38713 .53983 m
.43475 .52544 L
s
.32609 .36583 m .38799 .3794 L .34068 .39476 L .656 .751 .92 r
F
0 g
.34068 .39476 m
.36191 .42074 L
s
.36003 .48447 m .4105 .50127 L .35907 .51704 L .544 .324 .532 r
F
0 g
.35907 .51704 m
.38713 .53983 L
s
.36003 .48447 m .41108 .46858 L .4105 .50127 L .544 .324 .532 r
F
0 g
.36003 .48447 m
.36098 .45237 L
s
.41108 .46858 m
.41166 .43637 L
s
.35907 .51704 m
.36003 .48447 L
s
.34124 .23336 m
.32308 .23967 L
s
.32185 .27046 m
.32308 .23967 L
s
.4105 .50127 m
.43475 .52544 L
s
.32609 .36583 m .36322 .35359 L .38799 .3794 L .656 .751 .92 r
F
0 g
.38799 .3794 m
.41222 .40463 L
s
.34124 .23336 m
.34014 .26418 L
s
.4105 .50127 m
.41108 .46858 L
s
.35907 .51704 m
.4105 .50127 L
s
.33734 .49161 m
.35907 .51704 L
s
.95091 .266 m
.91529 .39714 L
s
.88486 .1097 m
.95091 .266 L
s
.3206 .3017 m
.32185 .27046 L
s
.32185 .27046 m
.34014 .26418 L
s
.31932 .33342 m .36322 .35359 L .32609 .36583 L .656 .751 .92 r
F
0 g
.32609 .36583 m
.34068 .39476 L
s
.34014 .26418 m
.33902 .29545 L
s
.3857 .47656 m
.4105 .50127 L
s
.31932 .33342 m .33788 .32721 L .36322 .35359 L .656 .751 .92 r
F
0 g
.33788 .32721 m
.36322 .35359 L
s
.039 .916 .04 r
.05652 .44147 m
.32234 .35333 L
s
0 g
.36322 .35359 m
.38799 .3794 L
s
.31932 .33342 m
.32609 .36583 L
s
.039 .916 .04 r
.32234 .35333 m
.35569 .34576 L
s
0 0 0 r
2 Mabswid
.32234 .35333 Mdot
0 g
.5 Mabswid
.31932 .33342 m
.3206 .3017 L
s
.3206 .3017 m
.33902 .29545 L
s
.91819 .18856 m
.91819 .18856 L
s
.91819 .18856 m
.91215 .20802 L
s
.039 .916 .04 r
.35569 .34576 m
.90007 .24933 L
s
0 0 0 r
2 Mabswid
.35569 .34576 Mdot
0 g
.5 Mabswid
.33788 .32721 m
.33902 .29545 L
s
.33734 .49161 m
.3857 .47656 L
s
.33734 .49161 m
.32237 .46327 L
s
.31803 .36561 m
.31932 .33342 L
s
.31932 .33342 m
.33788 .32721 L
s
.84253 .22929 m
.88486 .1097 L
s
.36033 .45128 m
.3857 .47656 L
s
.33673 .35944 m
.33788 .32721 L
s
.91215 .20802 m
.90595 .22803 L
s
.31672 .3983 m
.31803 .36561 L
s
.31803 .36561 m
.33673 .35944 L
s
.32237 .46327 m
.36033 .45128 L
s
.32237 .46327 m
.31539 .4315 L
s
.33673 .35944 m
.33556 .39218 L
s
.33437 .42541 m
.36033 .45128 L
s
.31539 .4315 m
.31672 .3983 L
s
.31672 .3983 m
.33556 .39218 L
s
.33556 .39218 m
.33437 .42541 L
s
.90595 .22803 m
.89957 .24861 L
s
.33437 .42541 m
.31539 .4315 L
s
.93386 .32878 m
.9225 .30222 L
s
.93386 .32878 m
.93386 .32878 L
s
.9225 .30222 m
.91107 .2755 L
s
.91107 .2755 m
.89957 .24861 L
s
0 0 0 r
2 Mabswid
.90007 .24933 Mdot
.89957 .24861 Mdot
0 g
.5 Mabswid
.893 .26979 m
.89957 .24861 L
s
.89957 .24861 m
.88799 .22154 L
s
0 0 0 r
2 Mabswid
.89906 .24789 Mdot
0 g
.5 Mabswid
.88799 .22154 m
.87634 .19431 L
s
.87634 .19431 m
.86461 .1669 L
s
.86461 .1669 m
.86461 .1669 L
s
.893 .26979 m
.88624 .29159 L
s
.88624 .29159 m
.87927 .31404 L
s
.91529 .39714 m
.84253 .22929 L
s
.87927 .31404 m
.87927 .31404 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 206.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000cR000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oOooool00ol0003oooooooooo`0Pooooo`00oOooool00ol0003oooooooooo`0Pooooo`00
o?ooool00ol0003oooooo`00000Qooooo`00o?ooool00ol0003oooooo`00000Qooooo`00o?ooool0
0ol0003oooooo`00000Qooooo`00noooool01Ol0003ooooooooooooooooo0000023ooooo003koooo
o`05o`000?ooooooooooooooool000008?ooool00?_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Mooooo`00n_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01go
oooo003jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00?[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`00nOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01cooooo003iooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06oooool00?Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`00
n?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo003hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool06_ooool00?Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Iooooo`00moooool2o`0000_ooooo00?o0000ooooooooool06Oooool00?Oo
oooo0_l0000;ooooo`03o`000?oooooooooo01Wooooo003fooooo`04o`000?ooooooooooo`0000_o
oooo00?o0000ooooooooool06?ooool00?Kooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`0Hooooo`00m_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooooooo
ool05oooool00?Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`;o0000
6?ooool00?Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01Kooooo003eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Fooooo`00m?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo0_l0000Hooooo`00m?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooool000005oooool00?Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooo000001Oooooo003cooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000001Kooooo003cooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000001Kooooo
003cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Cooooo003booooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo003boooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01?ooooo003booooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo003aooooo`03o`00
0?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01;o
oooo003aooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo017ooooo001Oooooo`Co0000Soooool00ol0003oooooooooo`0;ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool04Oooool005cooooo0ol00003ooooo`;o0000
S_ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool04Oooool005cooooo00?o0000ooooooooool00oooool00ol0003oooooo`00002>ooooo`03o`00
0?oooooooooo00_ooooo0_l0000:ooooo`03o`000?oooooooooo013ooooo001Looooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo0000SOooool00ol0003oooooooooo`0;ooooo`;o0000
2_ooool00ol0003oooooooooo`0@ooooo`00G?ooool2o`0000Cooooo00Go0000oooooooooooooooo
o`00002<ooooo`03o`000?oooooooooo00Wooooo0_l9jPX2o`0000_ooooo00?o0000ooooooooool0
3oooool005cooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0R_oo
ool00ol0003oooooooooo`03ooooo`Ko2NX:00?oooooo`000?l000002oooool00ol0003ooooooooo
o`0?ooooo`00G?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`29
ooooo`03o`000?l9jP[o2NX:00Oo2NX:0oooool00ol0003oooooo`00000;ooooo`03o`000?oooooo
oooo00kooooo001Looooo`;o00000oooool00ol0003oooooooooo`04ooooo`;o0000Q?ooool6o`WZ
2P03ooooool0003ooooo00Go2NX:1Oooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo
00kooooo001Looooo`;o00000_ooool2o`0000?ooooo0ol000000ooooooo0000ooooo`1nooooo`Go
2NX:1_ooool01?l9jP[o0000o`WZ2_ooool2o`WZ2POooooo00?o0000ooooool000002oooool00ol0
003oooooooooo`0>ooooo`00G?ooool4o`000003ooooool0003o000000;o00001Oooool00ol0003o
ooooooooo`1fooooo`Ko2NX:2?ooool3o`WZ2P;ooooo00?o0000o`WZ2_ooool01oooool01Ol0003o
oooooooooooooooo000000_ooooo00?o0000ooooooooool03Oooool005cooooo00?o0000ooooool0
00000ol00009ooooo`03o`000?oooooooooo073ooooo1Ol9jPX;ooooo`?o2NX:0oooool2o`WZ2P03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo
00gooooo001Looooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Yooooo`Ko2NX:3Oooool3o`WZ2PCooooo0_l9jPX2ooooo`03o`000?oooooooooo00Oo
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00gooooo001Looooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Sooooo`Go
2NX:4?ooool3o`WZ2PGooooo0_l9jPX5ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo001Looooo`06o`00
0?ooooooooooo`000?oooooo00003?ooool00ol0003oooooooooo`1Looooo`Ko2NX:4Oooool4o`WZ
2PKooooo0_l9jPX7ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo001Looooo`06o`000?ooooooooooo`00
0?oooooo00003Oooool00ol0003oooooooooo`1Eooooo`Ko2NX:5?ooool3o`WZ2PSooooo0_l9jPX:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00kooooo001Looooo`04o`000?ooooooooooooooo`;o00003?ooool3
o`00057ooooo1Ol9jPXGooooo`?o2NX:2Oooool2o`WZ2Pcooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool0
05cooooo00Co0000oooooooooooooooo0_l00009ooooo`?o00000_ooool00ol0003oooooooooo`19
ooooo`Ko2NX:6Oooool3o`WZ2P[ooooo0_l9jPX?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo001Loooo
o`04o`000?ooooooooooooooo`;o00001Oooool4o`0000Kooooo00?o0000ooooooooool0@oooool5
o`WZ2Qcooooo0ol9jPX;ooooo`;o2NX:4Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`00G?ooool4o`00
0004ooooool0003oooooooooo`?o00002oooool00ol0003oooooooooo`0looooo`Ko2NX:7_ooool3
o`WZ2Pcooooo0_l9jPXCooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo001Looooo`03o`000?oooooooooo
00;ooooo0ol0000?ooooo`03o`000?oooooooooo03Kooooo1Ol9jPXQooooo`?o2NX:3?ooool3o`WZ
2QKooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo013ooooo001Looooo`03o`000?oooooooooo00;ooooo0_l0000Aooooo`03o`000?oooooooooo
02oooooo1_l9jPXSooooo`?o2NX:3Oooool2o`WZ2QWooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo001Looooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`0Xooooo`Ko2NX:9_ooool3o`WZ
2Pkooooo0_l9jPXLooooo`03o`000?oooooo000000_ooooo00Go0000ooooooooooooooooo`00000B
ooooo`00G?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00013ooooo0_l0000T
ooooo`Go2NX::?ooool4o`WZ2Poooooo0_l9jPXNooooo`;o00003?ooool01Ol0003ooooooooooooo
oooo000001;ooooo001Looooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000<ooooo`?o000000?oRe:8o`000?l000007Oooool6o`WZ2R[ooooo0ol9jPXAooooo`;o2NX:8Ooo
ool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0001?ooooo001Kooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000009ooooo`?o00001?n;DXP00ol0003ooooo
o`00000Gooooo`Go2NX:;Oooool3o`WZ2Q;ooooo0_l9jPXSooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooool000004oooool005_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo0ol00007oh]BR004o`000?ooooooooooo`00013ooooo
1_l9jPX_ooooo`?o2NX:4oooool2o`WZ2RGooooo00?o0000ooooooooool02oooool00ol0003ooooo
o`00000Cooooo`00Foooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooo`00
0002o`0000[oRe:800Go0000ooooooooooooooooo`00000:ooooo`Go2NX:<_ooool3o`WZ2QCooooo
0_l9jPXXooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000004oooool005_ooooo00?o
0000ooooool000000_l000000onW`>_o0000ooooo`05ooooo`03o`000?n;DXSoRe:800_oRe:800?o
0000ooooooooool00_ooool01?l0003oooooooooooooool6o`WZ2SCooooo0ol9jPXEooooo`;o2NX:
:_ooool00ol0003oooooooooo`0;ooooo`;o00004oooool005_ooooo0_l00004ojO0j`;o00001Ooo
ool00ol0003oRe:8oh]BR00;oh]BR003o`000?oooooooooo00Ko2NX:=oooool3o`WZ2QKooooo0_l9
jPX]ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool005_ooooo00?o0000
ojO0jonW`>/00onW`>/00ol0003oYl3[o`000004ooooo`03o`000?n;DXSoRe:800WoRe:81Ol9jPX3
ooooo`;o0000=Oooool3o`WZ2QOooooo0_l9jPX_ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04_ooool005_ooooo00?o0000ojO0jonW`>/00onW`>/01?l0003oYl3[ojO0jol00003
ooooo`03o`000?n;DXSoRe:800?oRe:81_l9jPX2oh]BR003o`000?oooooooooo00?o000000?ooooo
o`000?ooool0<Oooool3o`WZ2QSooooo0_l9jPXbooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool04_ooool005_ooooo0_l00004ojO0j`04o`000?nW`>_oYl3[ojO0j`;o000000?ooooo
o`000?l9jPX01?l9jPX8oh]BR0?o00001Oooool00ol0003oooooooooo`0[ooooo`Co2NX:6Oooool2
o`WZ2SCooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`00Foooool2o`00
00?oYl3[00Go0000ojO0jonW`>_oYl3[o`WZ2P02o`0000;o2NX:3On;DXP00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Oooooo0ol9jPXKooooo`;o2NX:=_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01?ooooo001Kooooo`?o000000?oYl3[o`WZ2_l000000ol9jPX3ojO0
j`;o00001_n;DXP00ol0003oRe:8oh]BR004oh]BR003o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08oooool3o`WZ2Qcooooo0_l9jPXiooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04oooool005[ooooo00Oo2NX:o`000?l0003o0000o`WZ2_nW`>_o000000OoYl3[00?o0000
oh]BR?n;DXP02on;DXP00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo0ol9jPXM
ooooo`;o2NX:>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo001Goooo
o`?o2NX:00?oooooo`000?l000000onW`>/00ol0003oYl3[ojO0j`06ojO0j`03o`000?n;DXSoRe:8
00[oRe:800?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`?o2NX:7_ooool2o`WZ
2Skooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`00E?ooool3o`WZ2PCo
oooo00?o0000ooooool000000ol00009ojO0j`03o`000?n;DXSoRe:800WoRe:800?o0000oooooooo
ool02Oooool2o`0001Wooooo0ol9jPXOooooo`;o2NX:@?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Cooooo001Aooooo`?o2NX:1oooool3o`0000;oYl3[00?o0000ojO0jonW`>/0
2?nW`>/00ol0003oRe:8oh]BR008oh]BR003o`000?oooooooooo00Kooooo0ol00002ooooo`03o`00
0?oooooooooo01?ooooo0ol9jPXPooooo`;o2NX:@oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Cooooo001>ooooo`?o2NX:2_ooool00ol0003oooooo`000002ojO0j`03o`000?nW
`>_oYl3[00WoYl3[00?o0000oh]BR?n;DXP01on;DXP2o`0000Gooooo0_l00006ooooo`03o`000?oo
oooooooo00oooooo0ol9jPXQooooo`;o2NX:AOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Gooooo001;ooooo`?o2NX:3Oooool00ol0003oooooo`000002ojO0j`03o`000?nW`>_o
Yl3[00[oYl3[00?o0000oh]BR?n;DXP01_n;DXP01?l0003oooooo`000?ooool3o`0000Wooooo00?o
0000ooooooooool02oooool3o`WZ2R;ooooo0_l9jPY7ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool05Oooool004Sooooo0ol9jPX@ooooo`06o`000?ooooooooooo`000?nW`>_o0000
3OnW`>/00ol0003oRe:8oh]BR005oh]BR003o`000?oooooooooo00;o00003?ooool00ol0003ooooo
ooooo`06ooooo`Co2NX:8oooool2o`WZ2T[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Eooooo`00AOooool3o`WZ2Q?ooooo00Ko0000oooooooooooo0000ojO0jol0000>ojO0j`03
o`000?n;DXSoRe:800CoRe:800?o0000ooooooooool00_ooool3o`0000[ooooo00?o0000oooooooo
ool00_ooool3o`WZ2RGooooo0_l9jPY<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05Oooool004;ooooo0ol9jPXFooooo`04o`000?ooooooooooooooo`;o00003_nW`>/00ol0003o
Re:8oh]BR004oh]BR003o`000?oooooooooo00Gooooo0_l00009ooooo`04o`000?l9jP[o2NX:o`WZ
2RKooooo0_l9jPY?ooooo`04o`000?ooooooooooo`0001Sooooo000oooooo`?o2NX:6?ooool00ol0
003oooooooooo`02ooooo`;o00003onW`>/00ol0003oRe:8oh]BR003oh]BR003o`000?oooooooooo
00Oooooo0_l00005ooooo`?o2NX:00?o0000ooooooooool09?ooool2o`WZ2U7ooooo00Co0000oooo
oooooooo00006?ooool003cooooo0ol9jPXKooooo`03o`000?oooooooooo00?ooooo00?o0000ojO0
jonW`>/03_nW`>/00ol0003oRe:8oh]BR002oh]BR003o`000?oooooooooo00Wooooo0_l00003o`WZ
2P;o000000?oooooo`000?ooool08oooool2o`WZ2UCooooo00?o0000ooooool000006?ooool003Wo
oooo0ol9jPXNooooo`03o`000?oooooooooo00;ooooo0_l0000AojO0j`05o`000?n;DXSoRe:8oh]B
R?l000002_ooool3o`WZ2P03ooooool0003ooooo00?ooooo00?o0000ooooooooool08?ooool2o`WZ
2UKooooo00?o0000ooooool000006?ooool003Kooooo0ol9jPXQooooo`03o`000?oooooo000000;o
000000?oooooo`000?l000004OnW`>/01?l0003oRe:8oh]BR?l00007ooooo`?o2NX:1?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo0_l9jPYHooooo`;o00006Oooool003?o
oooo0ol9jPXTooooo`;o00001?ooool2o`0001;oYl3[00?o0000oh]BR?l000001?ooool3o`WZ2POo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`;o2NX:Foooool00ol0003o
ooooooooo`0Gooooo`00<?ooool3o`WZ2ROooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`00000BojO0j`;o000000Coooooo`WZ2_l9jP[o2NX:2_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01[ooooo0_l9jPYgooooo`00;Oooool3o`WZ2R[ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool0000@ojO0j`;o2NX:00?o0000o`WZ2_ooool03?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Sooooo0_l9jPYiooooo`00:_ooool3o`WZ2Rgooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_oYl3[1?l9jPX2oh]BR0;o
00003Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo0ol9jPYkooooo`00
9oooool3o`WZ2S3ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?nW`>_oYl3[00GoYl3[0ol9jPX6oh]BR003o`000?nW`>_o000000cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Cooooo`;o2NX:O_ooool002Cooooo0ol9jPXcooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oYl3[ojO0j`04o`WZ2PWoRe:800Co
0000ojO0jonW`>_o00002oooool00ol0003oooooooooo`03o`0001?ooooo0_l9jPZ0ooooo`008Ooo
ool3o`WZ2SKooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o2NX:00?o
0000o`WZ2_n;DXP03?n;DXP01Ol0003oYl3[ojO0jonW`>_o000000[ooooo0ol00002ooooo`03o`00
0?oooooooooo00oooooo0_l9jPZ2ooooo`007_ooool3o`WZ2SWooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`WZ2P02o`WZ2P;ooooo0_l0000=oh]BR003o`000?nW`>_oYl3[00;oYl3[00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo0_l9
jPZ4ooooo`006oooool3o`WZ2Scooooo00?o0000ooooooooool01?l000000ol9jP[oooooooooo`03
ooooo`03o`000?n;DXSoRe:800coRe:800?o0000ojO0jonW`>/00onW`>/00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool2o`WZ2XKooooo000Hoooo
o`?o2NX:?oooool3o`0000;o2NX:0_ooool00ol0003oooooooooo`03ooooo`03o`000?n;DXSoRe:8
00coRe:800?o0000ojO0jonW`>/01?nW`>/00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02Oooool2o`WZ2XSooooo000Eooooo`?o2NX:@Oooool00ol9jP[o
0000o`WZ2P06ooooo`03o`000?oooooooooo00;ooooo00?o0000oh]BR?n;DXP03?n;DXP00ol0003o
Yl3[ojO0j`04ojO0j`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`;o2NX:R_ooool001;ooooo0ol9jPY1ooooo`?o2NX:00?oooooo`000?ooool0
1oooool01Ol0003ooooooooooooooooo000000koRe:800?o0000ojO0jonW`>/01OnW`>/00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2o`WZ2Xco
oooo000@ooooo`;o2NX:@Oooool3o`WZ2PGooooo00?o0000ooooooooool01_ooool01?l0003ooooo
ooooool0000>oh]BR003o`000?nW`>_oYl3[00KoYl3[00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l9jPZ>ooooo`00Coooool4o`WZ2PSooooo
00?o0000ooooooooool01oooool00ol0003oooooo`000007oh]BR003o`000?n;DXSoRe:800CoRe:8
00?o0000ojO0jonW`>/01onW`>/00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooooooo0_l9jPZ@ooooo`00C?ooool3o`WZ2Pcooooo00?o0000ooooooooool0
2?ooool2o`0000koRe:800?o0000ojO0jonW`>/02?nW`>/01Ol0003ooooooooooooooooo000000;o
oooo0ol000000ooooooo2NX:o`WZ2P2Booooo`00BOooool3o`WZ2Poooooo00?o0000ooooooooool0
1oooool3o`0000koRe:800?o0000ojO0jonW`>/02OnW`>/00ol0003oooooooooo`03o`0000;ooooo
0_l9jPZDooooo`00A_ooool3o`WZ2Q;ooooo00?o0000ooooooooool00oooool4o`0000;ooooo0_l0
000=oh]BR003o`000?nW`>_oYl3[00[oYl3[0ol00002ooooo`;o2NX:00?o0000ooooooooool0Tooo
ool004?ooooo0ol9jPXFooooo`03o`000?oooooo000000;o00001_ooool00ol0003oRe:8o`00000<
oh]BR0;o00003OnW`>/2o`000004o`WZ2_ooooooooooo`0009Gooooo0010ooooo`?o2NX:6Oooool2
o`0000Wooooo00Co0000oh]BR?n;DXSo00002on;DXP00ol0003oooooo`00000;ojO0j`03o`WZ2_l0
003o000000?ooooo00?o0000ooooooooool0Toooool003gooooo0ol9jPXLooooo`03o`000?oooooo
oooo00Sooooo00Go0000oh]BR?n;DXSoRe:8o`00000:oh]BR003o`000?oooooooooo00;o00001_nW
`>/3o`WZ2P?oYl3[00Co0000oooooooooooo0000UOooool003[ooooo0ol9jPXPooooo`03o`000?oo
oooooooo00Oooooo00?o0000oh]BR?n;DXP00_n;DXP00ol0003oRe:8oh]BR007oh]BR003o`000?oo
oooooooo00;ooooo0ol00003o`WZ2POoYl3[00?o0000ooooool00000UOooool003Kooooo1?l9jPXS
ooooo`03o`000?oooooooooo00Oooooo00?o0000oh]BR?n;DXP00on;DXP00ol0003oRe:8oh]BR006
oh]BR003o`000?oooooooooo00;ooooo0ol9jPX2o`0000WoYl3[0_l0002Eooooo`00<oooool3o`WZ
2RSooooo00?o0000ooooooooool01_ooool00ol0003oRe:8oh]BR003oh]BR0;o00001on;DXP00ol0
003oooooo`WZ2P02o`WZ2P;ooooo0_l000000ooooooo0000o`000007ojO0j`;o0000UOooool0033o
oooo0ol9jPX[ooooo`03o`000?oooooooooo00Kooooo00?o0000oh]BR?n;DXP00ol00002oh]BR003
o`000?n;DXSoRe:800CoRe:800?o0000o`WZ2_ooool02Oooool3o`000006ojO0jol0003o0000o`00
0?oooooo0000UOooool002gooooo0ol9jPX^ooooo`03o`000?oooooooooo00Kooooo0ol00006oh]B
R003o`000?n;DXSoRe:800?oRe:800?o0000ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo09?ooooo000Zooooo`?o2NX:<_ooool00ol0003oooooooooo`02ooooo`Co
00002On;DXP01Ol0003oRe:8oh]BR?n;DXSo000000oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`2Cooooo`009oooool3o`WZ2SGooooo00?o0000ooooool000000_l00003ooooo`03
o`000?n;DXSoRe:800SoRe:800Co0000oh]BR?n;DXSo00003oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo09?ooooo000Tooooo`?o2NX:>Oooool00ol0003oooooooooo`04ooooo`03
o`000?n;DXSoRe:800WoRe:800?o0000oh]BR?l000003oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo09?ooooo000Rooooo`;o2NX:?Oooool01?l0003oooooooooooooool2o`WZ2P03
o`000?n;DXSoRe:800[oRe:80_l0000?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0Toooool006;ooooo00?o0000o`WZ2_l9jPX00_ooool00ol0003oRe:8oh]BR00:oh]BR0;o0000
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09?ooooo001Oooooo`?o2NX:00?o
ooooo`000?ooool00_ooool00ol0003oRe:8oh]BR007oh]BR0?o00000_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Toooool005cooooo0ol9jPX5
ooooo`04o`000?ooooooooooo`0000KoRe:80ol00006ooooo`03o`000?oooooooooo00_ooooo00Co
0000oooooooooooooooo0_l0002Eooooo`00F?ooool4o`WZ2PWooooo00?o0000ooooool000000on;
DXP3o`0000[ooooo00?o0000ooooooooool02_ooool4o`000003ooooool0003ooooo09Cooooo001E
ooooo`?o2NX:3_ooool5o`0000kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo09?ooooo001Booooo`?o2NX:4_ooool2o`00017ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09?ooooo001?ooooo`?o
2NX:5oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2Cooooo`00C?ooool3o`WZ2Q_ooooo00?o0000ooooooooool0
3Oooool3o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Cooooo`00BOoo
ool3o`WZ2Qoooooo0_l0000:ooooo`?o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Toooool004Gooooo1?l9jPXTooooo`03o`000?oooooo
oooo00Cooooo0ol00007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2Cooooo`00@_ooool3o`WZ2RWooooo00?o0000ooooooooool00ol0000;oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Coooo
o`00?oooool3o`WZ2Rgooooo0_l0000?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooooooo0_l0002Eooooo`00??ooool3o`WZ2S;ooooo0_l0000>ooooo`04o`000?oooooooooooooo
o`Co000000?oooooo`000?ooool0U?ooool003Wooooo0ol9jPXgooooo`03o`000?oooooooooo00co
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2Cooooo`00=_ooool3o`WZ2S_o
oooo0_l0000;ooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`2Cooooo`00
=?ooool2o`WZ2T3ooooo0_l00006ooooo`?o00000oooool2o`0000Cooooo00?o0000ooooooooool0
Toooool007Sooooo00?o0000ooooooooool00ol00007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0Toooool007Wooooo0_l0000:ooooo`;o00000oooool00ol0003oooooooooo`2C
ooooo`00Noooool3o`0000Oooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`2Coooo
o`00O_ooool2o`0000Gooooo00Ko0000oooooooooooo0000ooooool0002Eooooo`00P?ooool2o`00
00?ooooo00Co0000oooooooooooooooo0_l0002Eooooo`00P_ooool4o`0000;ooooo0ol0002Eoooo
o`00QOooool3o`0009Sooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {205.812, 0}} -> {0.0207472, 0.128103, \
0.00341439, 0.00341439}},
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindABCDMatrix[cylindricalsystem, {f>0}, MatrixForm->True]", "Input",
  CellLabel->"In[48]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(\(-0.9999999999999998`\)\ d2 + 
                            0.9999999999999998`\ f - 
                            0.6666666666666666`\ t\)\/f\), \
\(\(0.9999999999999998`\ d2\ f + 
                            d1\ \((\(-0.9999999999999998`\)\ d2 + 
                                  0.9999999999999998`\ f - 
                                  0.6666666666666666`\ t)\) + 
                            0.6666666666666664`\ f\ t\)\/f\)},
                    {\(-\(0.9999999999999999`\/f\)\), \(1 - \
\(0.9999999999999999`\ d1\)\/f\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(d1 + d2 + 0.6666666666666665`\ t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      TableForm[ {
        MatrixForm[ {{
          Times[ 
            Power[ f, -1], 
            Plus[ 
              Times[ -0.99999999999999978, d2], 
              Times[ 0.99999999999999978, f], 
              Times[ -0.66666666666666663, t]]], 
          Times[ 
            Power[ f, -1], 
            Plus[ 
              Times[ 0.99999999999999978, d2, f], 
              Times[ d1, 
                Plus[ 
                  Times[ -0.99999999999999978, d2], 
                  Times[ 0.99999999999999978, f], 
                  Times[ -0.66666666666666663, t]]], 
              Times[ 0.66666666666666641, f, t]]]}, {
          Times[ -0.99999999999999989, 
            Power[ f, -1]], 
          Plus[ 1, 
            Times[ -0.99999999999999989, d1, 
              Power[ f, -1]]]}}], 
        MatrixForm[ {{1, 
          Plus[ d1, d2, 
            Times[ 0.66666666666666652, t]]}, {0, 1}}]}, TableAlignments -> 
        Center]]], "Output",
  CellLabel->"Out[48]//TableForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[cylindricalsystem, {f>0}, MatrixForm->True, \
ABCDConstruction->Horizontal]\
\>", "Input",
  CellLabel->"In[49]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(\(-0.9999999999999998`\)\ d2 + 0.9999999999999998`\ f - 
                    0.6666666666666666`\ t\)\/f\), \(\(0.9999999999999998`\ \
d2\ f + d1\ \((\(-0.9999999999999998`\)\ d2 + 0.9999999999999998`\ f - 
                          0.6666666666666666`\ t)\) + 
                    0.6666666666666664`\ f\ t\)\/f\)},
            {\(-\(0.9999999999999999`\/f\)\), \(1 - \(0.9999999999999999`\ d1\
\)\/f\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[49]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[cylindricalsystem, {f>0}, MatrixForm->True, \
ABCDConstruction->Vertical]\
\>", "Input",
  CellLabel->"In[50]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(d1 + d2 + 0.6666666666666665`\ t\)},
            {"0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[50]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[cylindricalsystem, {f>0}, MatrixForm->True, \
DecomposeABCD->True]\
\>", "Input",
  CellLabel->"In[38]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.9999999999999998`", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d2"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(1.0000000000000002`\ t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(0.6577817908690828`\/f\)\), "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d2"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(1.`\ t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Row, TableAlignments -> 
          Center]]]], "Output",
  CellLabel->"Out[38]//TableForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[cylindricalsystem, {f>0}, MatrixForm->True, \
DecomposeABCD->True, ComplexABCD->True]\
\>", "Input",
  CellLabel->"In[39]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(\(\[ImaginaryI]\ \[Lambda]\)\/\(\(-\(\(h\^2\ \
\[Pi]\)\/4\)\) - \(6431727384198601\ \[Pi]\ v\^2\)\/77180728610383204\)\), 
                      "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.9999999999999998`", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d2"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(4\ \[ImaginaryI]\ \[Lambda]\)\/\(a\^2\ \
\[Pi]\)\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(1.0000000000000002`\ t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(4\ \[ImaginaryI]\ \[Lambda]\)\/\(a\^2\ \
\[Pi]\)\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(0.6577817908690828`\/f\)\), "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(\(\[ImaginaryI]\ \
\[Lambda]\)\/\(\(-\(\(6431727384198601\ h\^2\ \[Pi]\)\/77180728610383204\)\) \
- \(\[Pi]\ v\^2\)\/4\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d2"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(4\ \[ImaginaryI]\ \[Lambda]\)\/\(b\^2\ \
\[Pi]\)\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(1.`\ t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(4\ \[ImaginaryI]\ \[Lambda]\)\/\(b\^2\ \
\[Pi]\)\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Row, TableAlignments -> 
          Center]]]], "Output",
  CellLabel->"Out[39]//TableForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[cylindricalsystem, MatrixForm->True, NumericalResults->True]\
\>", "Input",
  CellLabel->"In[40]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.0349309680604394`", "98.32955333300953`"},
                    {\(-0.00999212058725169`\), "0.5003939706374153`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "146.5830049299876`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      TableForm[ {
        MatrixForm[ {{0.034930968060439403, 
          98.329553333009528}, {-0.0099921205872516902, 
          0.50039397063741531}}], 
        MatrixForm[ {{1, 146.5830049299876}, {0, 1}}]}, TableAlignments -> 
        Center]]], "Output",
  CellLabel->"Out[40]//TableForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[cylindricalsystem, MatrixForm->True, NumericalResults->True, \
ComplexABCD->True]\
\>", "Input",
  CellLabel->"In[41]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(\(0.03486489780377067`\)\(\[InvisibleSpace]\)\) - 
                        0.06253301249504632`\ \[ImaginaryI]\), \
\(\(\(98.32624982017609`\)\(\[InvisibleSpace]\)\) - 
                        3.287177751367611`\ \[ImaginaryI]\)},
                    {\(\(-0.010017291764475975`\) - 
                        0.0006783309430928123`\ \[ImaginaryI]\), \
\(\(\(0.49907267992638726`\)\(\[InvisibleSpace]\)\) - 
                        0.07344352588654773`\ \[ImaginaryI]\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(\(0.9998386956624296`\)\(\[InvisibleSpace]\)\) - 
                        0.10021409203392401`\ \[ImaginaryI]\), \
\(\(\(146.57493971310907`\)\(\[InvisibleSpace]\)\) - 
                        5.261528237032599`\ \[ImaginaryI]\)},
                    {\(\(-0.000026035613951740332`\) - 
                        0.0013083272753411346`\ \[ImaginaryI]\), \
\(\(\(0.9986375411738727`\)\(\[InvisibleSpace]\)\) - 
                        0.09156822028155244`\ \[ImaginaryI]\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      TableForm[ {
        MatrixForm[ {{
          Complex[ 0.034864897803770667, -0.062533012495046322], 
          Complex[ 98.326249820176088, -3.287177751367611]}, {
          Complex[ -0.010017291764475975, -0.00067833094309281228], 
          Complex[ 0.49907267992638726, -0.073443525886547734]}}], 
        MatrixForm[ {{
          Complex[ 0.99983869566242956, -0.10021409203392401], 
          Complex[ 146.57493971310907, -5.2615282370325991]}, {
          Complex[ -2.6035613951740332*^-05, -0.0013083272753411346], 
          Complex[ 0.99863754117387271, -0.09156822028155244]}}]}, 
        TableAlignments -> Center]]], "Output",
  CellLabel->"Out[41]//TableForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[cylindricalsystem, MatrixForm->True, NumericalResults->True, \
ComplexABCD->True, DecomposeABCD->True]\
\>", "Input",
  CellLabel->"In[42]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(\(-0.0003907865987302538`\)\ \[ImaginaryI]\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.9999999999999999`", "0"},
                    {"0", "1.`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "89.99999999999999`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(\(-0.0002709453751196427`\)\ \[ImaginaryI]\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "9.999999999999996`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(\(-0.0002709453751196427`\)\ \[ImaginaryI]\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {\(-0.00657781790869083`\), "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50.00000000000001`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(\(-0.00024191551349968094`\)\ \[ImaginaryI]\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "90.`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(\(-0.0004233521486244417`\)\ \[ImaginaryI]\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "9.999999999999998`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(\(-0.0004233521486244417`\)\ \[ImaginaryI]\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50.00000000000001`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Row, TableAlignments -> 
          Center]]]], "Output",
  CellLabel->"Out[42]//TableForm=",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG3.3", "AOG3."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.4 SphericalLens Examples", "Subsection",
  CellTags->{"AOG0.", "3.4", "AOG3.", "AOG3.4"}],

Cell["\<\
opticalsystem = {Move[LineOfRays[40, \
IntrinsicMedium->Vacuum],{{-d1,-50},{y,0}},{s/Degree,0}],
SphericalLens[{R1,100},{R2,-100},50,{t,10},DesignWaveLength->1/2],
Move[Screen[50],{d2,100}]};\
\>", "Input",
  CellLabel->"In[35]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[opticalsystem,PlotType->TopView];", "Input",
  CellLabel->"In[93]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.192698 0.00634921 [
[.37302 .00857 -5.03125 -6 ]
[.37302 .00857 5.03125 6 ]
[.97619 .00857 -4.75 -6 ]
[.97619 .00857 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .36 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.36143 .03397 m
.3846 .03397 L
.39588 .08688 L
.35015 .08688 L
.36143 .03397 L
F
.35015 .08688 m
.39588 .08688 L
.40255 .13979 L
.34348 .13979 L
.35015 .08688 L
F
.34348 .13979 m
.40255 .13979 L
.40476 .1927 L
.34127 .1927 L
.34348 .13979 L
F
.34127 .1927 m
.40476 .1927 L
.40255 .24561 L
.34348 .24561 L
.34127 .1927 L
F
.34348 .24561 m
.40255 .24561 L
.39588 .29852 L
.35015 .29852 L
.34348 .24561 L
F
.35015 .29852 m
.39588 .29852 L
.3846 .35143 L
.36143 .35143 L
.35015 .29852 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.36143 .03397 m
.35015 .08688 L
.34348 .13979 L
.34127 .1927 L
.34348 .24561 L
.35015 .29852 L
.36143 .35143 L
.3846 .35143 L
.39588 .29852 L
.40255 .24561 L
.40476 .1927 L
.40255 .13979 L
.39588 .08688 L
.3846 .03397 L
.36143 .03397 L
s
.5 g
.36143 .1927 m
.3846 .1927 L
.39588 .1927 L
.35015 .1927 L
.36143 .1927 L
F
.35015 .1927 m
.39588 .1927 L
.40255 .1927 L
.34348 .1927 L
.35015 .1927 L
F
.34348 .1927 m
.40255 .1927 L
.40476 .1927 L
.34127 .1927 L
.34348 .1927 L
F
.34127 .1927 m
.40476 .1927 L
.40255 .1927 L
.34348 .1927 L
.34127 .1927 L
F
.34348 .1927 m
.40255 .1927 L
.39588 .1927 L
.35015 .1927 L
.34348 .1927 L
F
.35015 .1927 m
.39588 .1927 L
.3846 .1927 L
.36143 .1927 L
.35015 .1927 L
F
0 g
.36143 .1927 m
.35015 .1927 L
.34348 .1927 L
.34127 .1927 L
.34348 .1927 L
.35015 .1927 L
.36143 .1927 L
.3846 .1927 L
.39588 .1927 L
.40255 .1927 L
.40476 .1927 L
.40255 .1927 L
.39588 .1927 L
.3846 .1927 L
.36143 .1927 L
s
.36143 .35143 m
.3846 .35143 L
.3846 .34602 L
.36143 .34602 L
.36143 .35143 L
s
.36143 .34602 m
.3846 .34602 L
.3846 .33016 L
.36143 .33016 L
.36143 .34602 L
s
.36143 .33016 m
.3846 .33016 L
.3846 .30494 L
.36143 .30494 L
.36143 .33016 L
s
.36143 .30494 m
.3846 .30494 L
.3846 .27206 L
.36143 .27206 L
.36143 .30494 L
s
.36143 .27206 m
.3846 .27206 L
.3846 .23378 L
.36143 .23378 L
.36143 .27206 L
s
.36143 .23378 m
.3846 .23378 L
.3846 .1927 L
.36143 .1927 L
.36143 .23378 L
s
.36143 .1927 m
.3846 .1927 L
.3846 .15162 L
.36143 .15162 L
.36143 .1927 L
s
.36143 .15162 m
.3846 .15162 L
.3846 .11333 L
.36143 .11333 L
.36143 .15162 L
s
.36143 .11333 m
.3846 .11333 L
.3846 .08046 L
.36143 .08046 L
.36143 .11333 L
s
.36143 .08046 m
.3846 .08046 L
.3846 .05523 L
.36143 .05523 L
.36143 .08046 L
s
.36143 .05523 m
.3846 .05523 L
.3846 .03938 L
.36143 .03938 L
.36143 .05523 L
s
.36143 .03938 m
.3846 .03938 L
.3846 .03397 L
.36143 .03397 L
.36143 .03938 L
s
.36143 .03397 m
.3846 .03397 L
.3846 .03938 L
.36143 .03938 L
.36143 .03397 L
s
.36143 .03938 m
.3846 .03938 L
.3846 .05523 L
.36143 .05523 L
.36143 .03938 L
s
.36143 .05523 m
.3846 .05523 L
.3846 .08046 L
.36143 .08046 L
.36143 .05523 L
s
.36143 .08046 m
.3846 .08046 L
.3846 .11333 L
.36143 .11333 L
.36143 .08046 L
s
.36143 .11333 m
.3846 .11333 L
.3846 .15162 L
.36143 .15162 L
.36143 .11333 L
s
.36143 .15162 m
.3846 .15162 L
.3846 .1927 L
.36143 .1927 L
.36143 .15162 L
s
.36143 .1927 m
.3846 .1927 L
.3846 .23378 L
.36143 .23378 L
.36143 .1927 L
s
.36143 .23378 m
.3846 .23378 L
.3846 .27206 L
.36143 .27206 L
.36143 .23378 L
s
.36143 .27206 m
.3846 .27206 L
.3846 .30494 L
.36143 .30494 L
.36143 .27206 L
s
.36143 .30494 m
.3846 .30494 L
.3846 .33016 L
.36143 .33016 L
.36143 .30494 L
s
.36143 .33016 m
.3846 .33016 L
.3846 .34602 L
.36143 .34602 L
.36143 .33016 L
s
.36143 .34602 m
.3846 .34602 L
.3846 .35143 L
.36143 .35143 L
.36143 .34602 L
s
.97619 .03397 m
.97619 .08688 L
.97619 .13979 L
.97619 .1927 L
.97619 .24561 L
.97619 .29852 L
.97619 .35143 L
.97619 .35143 L
.97619 .29852 L
.97619 .24561 L
.97619 .1927 L
.97619 .13979 L
.97619 .08688 L
.97619 .03397 L
.97619 .03397 L
s
.97619 .1927 m
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
s
.97619 .35143 m
.97619 .34602 L
.97619 .33016 L
.97619 .30494 L
.97619 .27206 L
.97619 .23378 L
.97619 .1927 L
.97619 .15162 L
.97619 .11333 L
.97619 .08046 L
.97619 .05523 L
.97619 .03938 L
.97619 .03397 L
.97619 .03938 L
.97619 .05523 L
.97619 .08046 L
.97619 .11333 L
.97619 .15162 L
.97619 .1927 L
.97619 .23378 L
.97619 .27206 L
.97619 .30494 L
.97619 .33016 L
.97619 .34602 L
.97619 .35143 L
s
.039 .916 .04 r
.02381 .06571 m
.3541 .06571 L
s
% Start of user PostScript
-50. -20. 2.02041 -20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.3541 .06571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1927 m
.34127 .1927 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .31968 m
.3541 .31968 L
s
% Start of user PostScript
-50. 20. 2.02041 20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.3541 .31968 Mdot
.039 .916 .04 r
.5 Mabswid
.3541 .06571 m
.39246 .06831 L
s
% Start of user PostScript
2.02041 -20. 8.06223 -19.5908 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.39246 .06831 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .1927 m
.40476 .1927 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.40476 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.3541 .31968 m
.39246 .31708 L
s
% Start of user PostScript
2.02041 20. 8.06223 19.5908 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.39246 .31708 Mdot
.039 .916 .04 r
.5 Mabswid
.39246 .06831 m
.97619 .19045 L
s
% Start of user PostScript
8.06223 -19.5908 100. -0.354055 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19045 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .1927 m
.97619 .1927 L
s
% Start of user PostScript
10. 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.39246 .31708 m
.97619 .19495 L
s
% Start of user PostScript
8.06223 19.5908 100. 0.354055 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19495 Mdot
gsave
.37302 .00857 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00857 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .36 L
0 .36 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{288, 103.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ib000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00JOooool6o`000:7ooooo0ol0
000=ooooo`00J_ooool01Ol0003ooooooooooooooooo00000:7ooooo00Co0000oooooooooooo0000
3?ooool006[ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0:ooooo`00J_ooool0
0ol0003oooooooooo`2Tooooo`;o00003Oooool006[ooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`0=ooooo`00J_ooool00ol0003oooooooooo`2Sooooo`04o`000?ooooooooooo`00
00cooooo001Yooooo`?o0000YOooool3o`0000cooooo003oooooob7ooooo003oooooob7ooooo001Y
ooooo`Oo0000X_ooool00ol0003oooooooooo`0;ooooo`00JOooool7o`000:;ooooo00?o0000oooo
ooooool02oooool006Wooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Pooooo`03
o`000?oooooooooo00_ooooo001Xooooo`;o00001OmoOgl2o`000:7ooooo00?o0000ooooooooool0
2oooool006Sooooo0_l00005ogmoO`;o0000XOooool00ol0003oooooooooo`0;ooooo`00J?ooool2
o`0000GoOgmo0_l0002Qooooo`03o`000?oooooooooo00_ooooo001Xooooo`Wo0000XOooool00ol0
003oooooooooo`0;ooooo`00Goooool3o`WZ2PKooooo0_l00003o`WZ2P;oOgmo0_l0002Qooooo`03
o`000?oooooooooo00_ooooo001Pooooo`Ko2NX:0_l000000omoOgoo0000o`WZ2P05o`WZ2P03ogmo
Ool0003ooooo09oooooo00?o0000ooooooooool02oooool000coooooF_l9jPX00ol0003o2NX:o`WZ
2P0;o`WZ2Ykooooo00?o0000ooooooooool02oooool0063ooooo1Ol9jPX2ooooo`03o`000?moOgoo
000000Go2NX:00Go0000ogmoOol0003o0000ooooo`05o`WZ2YWooooo00?o0000ooooooooool02ooo
ool005oooooo0_l9jPX6ooooo`04o`000?moOgoo2NX:o`WZ2PCoOgmo00?o0000ogmoOol000001ooo
ool5o`WZ2YCooooo00?o0000ooooooooool02oooool006Oooooo00?o0000ogmoOol000001OmoOgl0
0ol0003oOgmoo`00000<ooooo`Go2NX:Soooool00ol0003oooooooooo`0;ooooo`00I_ooool00ol0
003oOgmoogmoO`07o`0000;oOgmo00?o0000ooooooooool03_ooool4o`WZ2X_ooooo00?o0000oooo
ooooool02oooool006Kooooo00Co0000ogmoOomoOgoo00001OmoOgl01?l0003oOgmoogmoOol0000D
ooooo`Go2NX:Q_ooool00ol0003oooooooooo`0;ooooo`00I_ooool01?l0003oOgmoogmoOol00005
ogmoO`04o`000?moOgooOgmoo`0001Wooooo1Ol9jPZ1ooooo`03o`000?oooooooooo00_ooooo001V
ooooo`04o`000?moOgooOgmoo`0000GoOgmo00Co0000ogmoOomoOgoo00007_ooool5o`WZ2Wcooooo
00?o0000ooooooooool02oooool006Kooooo00Co0000ogmoOomoOgoo00001OmoOgl01?l0003oOgmo
ogmoOol0000Sooooo`Co2NX:N?ooool00ol0003oooooooooo`0;ooooo`00I_ooool01?l0003oOgmo
ogmoOol00005ogmoO`04o`000?moOgooOgmoo`0002Oooooo1Ol9jPYcooooo`03o`000?oooooooooo
00_ooooo001Uooooo`05o`000?moOgooOgmoogmoOol000001OmoOgl01Ol0003oOgmoogmoOomoOgoo
000002_ooooo1Ol9jPY^ooooo`03o`000?oooooooooo00_ooooo001Uooooo`05o`000?moOgooOgmo
ogmoOol000001OmoOgl01Ol0003oOgmoogmoOomoOgoo0000033ooooo1?l9jPYZooooo`03o`000?oo
oooooooo00_ooooo001Uooooo`05o`000?moOgooOgmoogmoOol000001OmoOgl01Ol0003oOgmoogmo
OomoOgoo000003Cooooo1Ol9jPYUooooo`03o`000?oooooooooo00_ooooo001Uooooo`04o`000?mo
OgooOgmoogmoO`Oo00000omoOgl00ol0003oooooooooo`0gooooo`Go2NX:H?ooool00ol0003ooooo
ooooo`0;ooooo`00IOooool01Ol0003oOgmoogmoOomoOgoo000000GoOgmo00Go0000ogmoOomoOgoo
Ogmoo`00000nooooo`Go2NX:Foooool00ol0003oooooooooo`0;ooooo`00IOooool01Ol0003oOgmo
ogmoOomoOgoo000000GoOgmo00Go0000ogmoOomoOgooOgmoo`000013ooooo`Co2NX:Eoooool00ol0
003oooooooooo`0;ooooo`00IOooool01Ol0003oOgmoogmoOomoOgoo000000GoOgmo00Go0000ogmo
OomoOgooOgmoo`000017ooooo`Go2NX:D_ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0
003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0
003oooooooooo`19ooooo`Go2NX:COooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003o
OgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003o
ooooooooo`1>ooooo`Go2NX:B?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmo
ogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003ooooo
ooooo`1Cooooo`Co2NX:A?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmo
O`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003ooooooooo
o`1Gooooo`Go2NX:?oooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`02
ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1L
ooooo`Go2NX:>_ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`02ogmo
O`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1Qoooo
o`Go2NX:=Oooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`02ogmoO`Oo
00001?moOgl00ol0003oooooooooo`1Vooooo`Co2NX:<Oooool00ol0003oooooooooo`0;ooooo`00
I?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl0
0_moOgl00ol0003oooooooooo`1Zooooo`Go2NX:;?ooool00ol0003oooooooooo`0;ooooo`00I?oo
ool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_mo
Ogl00ol0003oooooooooo`1_ooooo`Go2NX:9oooool00ol0003oooooooooo`0;ooooo`00I?ooool0
0ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_moOgl0
0ol0003oooooooooo`1dooooo`Co2NX:8oooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0
003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0
003oooooooooo`1hooooo`Go2NX:7_ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003o
OgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003o
ooooooooo`1looooo`Go2NX:6Oooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmo
ogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`21ooooo`Go2NX:5?ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmoogmo
O`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`26ooooo`Co2NX:2?ooool2o`WZ2PKooooo00?o0000ooooooooool02oooool006?ooooo00?o0000
ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000
ooooooooool0R_ooool5o`WZ2P?ooooo1?l9jPX4ooooo`03o`000?oooooooooo00_ooooo001Koooo
o`?o2NX:1Oooool00ol0003oOgmoogmoO`03ogmoO`04o`000?moOgooOgmoogmoO`?o2NX:1OmoOgl0
0ol0003oooooooooo`2?ooooo`Wo2NX:0_ooool00ol0003oooooooooo`0;ooooo`00G?ooool6o`WZ
2P03ooooool0003oOgmo00CoOgmo00?o0000ogmoOomoOgl00_moOgl6o`WZ2P03ogmoOol0003ooooo
09Cooooo1_l9jPX2o`0000gooooo000<ooooofSo2NX:00?o0000o`WZ2_l9jPX0V_l9jPX2o`0000go
oooo001Looooo`Go2NX:0_ooool2o`0000CoOgmo00?o0000ogmoOomoOgl00_moOgl5o`WZ2P03ogmo
Ool0003o000009Cooooo1ol9jPX2o`0000gooooo001Kooooo`;o2NX:1_ooool00ol0003oOgmoogmo
O`03ogmoO`04o`000?moOgooOgmoogmoO`;o2NX:00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`2Booooo`Oo2NX:0_l0000=ooooo`00Hoooool00ol0003oOgmoogmoO`03ogmoO`03o`000?mo
OgooOgmo00?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2>ooooo`Go2NX:00Co
ooooo`WZ2_l9jP[o2NX:0oooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmoogmo
O`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`29ooooo`Go2NX:1Oooool2o`WZ2PGooooo00?o0000ooooooooool02oooool006?ooooo00?o0000
ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000
ooooooooool0QOooool4o`WZ2PWooooo00?o2NX:ooooooooool01Oooool00ol0003oooooooooo`0;
ooooo`00Hoooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmo
OomoOgl00omoOgl00ol0003oooooooooo`20ooooo`Go2NX:5Oooool00ol0003oooooooooo`0;oooo
o`00Hoooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomo
Ogl00omoOgl00ol0003oooooooooo`1kooooo`Go2NX:6_ooool00ol0003oooooooooo`0;ooooo`00
I?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl0
0_moOgl00ol0003oooooooooo`1gooooo`Go2NX:7oooool00ol0003oooooooooo`0;ooooo`00I?oo
ool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_mo
Ogl00ol0003oooooooooo`1cooooo`Co2NX:9?ooool00ol0003oooooooooo`0;ooooo`00I?ooool0
0ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_moOgl0
0ol0003oooooooooo`1^ooooo`Go2NX::?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0
003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0
003oooooooooo`1Yooooo`Go2NX:;Oooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003o
OgmoogmoO`02ogmoO`Oo00001?moOgl00ol0003oooooooooo`1Uooooo`Co2NX:<_ooool00ol0003o
ooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo
00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1Pooooo`Go2NX:=_ooool00ol0003ooooo
ooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o
0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1Kooooo`Go2NX:>oooool00ol0003ooooooooo
o`0;ooooo`00I?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000
ogmoOomoOgl00_moOgl00ol0003oooooooooo`1Fooooo`Go2NX:@?ooool00ol0003oooooooooo`0;
ooooo`00I?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmo
OomoOgl00_moOgl00ol0003oooooooooo`1Booooo`Co2NX:AOooool00ol0003oooooooooo`0;oooo
o`00I?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomo
Ogl00_moOgl00ol0003oooooooooo`1=ooooo`Go2NX:BOooool00ol0003oooooooooo`0;ooooo`00
I?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl0
0_moOgl00ol0003oooooooooo`18ooooo`Go2NX:C_ooool00ol0003oooooooooo`0;ooooo`00I?oo
ool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl00_mo
Ogl00ol0003oooooooooo`13ooooo`Go2NX:Doooool00ol0003oooooooooo`0;ooooo`00IOooool0
1Ol0003oOgmoogmoOomoOgoo000000GoOgmo00Go0000ogmoOomoOgooOgmoo`000012ooooo`Co2NX:
F?ooool00ol0003oooooooooo`0;ooooo`00IOooool01Ol0003oOgmoogmoOomoOgoo000000GoOgmo
00Go0000ogmoOomoOgooOgmoo`00000mooooo`Go2NX:G?ooool00ol0003oooooooooo`0;ooooo`00
IOooool01?l0003oOgmoogmoOomoOgl7o`0000?oOgmo00?o0000ooooooooool0=_ooool5o`WZ2V7o
oooo00?o0000ooooooooool02oooool006Gooooo00Go0000ogmoOomoOgooOgmoo`000005ogmoO`05
o`000?moOgooOgmoogmoOol00000<oooool5o`WZ2VKooooo00?o0000ooooooooool02oooool006Go
oooo00Go0000ogmoOomoOgooOgmoo`000005ogmoO`05o`000?moOgooOgmoogmoOol00000;oooool4
o`WZ2V_ooooo00?o0000ooooooooool02oooool006Gooooo00Go0000ogmoOomoOgooOgmoo`000005
ogmoO`05o`000?moOgooOgmoogmoOol00000:_ooool5o`WZ2Voooooo00?o0000ooooooooool02ooo
ool006Gooooo00Go0000ogmoOomoOgooOgmoo`000005ogmoO`05o`000?moOgooOgmoogmoOol00000
9Oooool5o`WZ2WCooooo00?o0000ooooooooool02oooool006Kooooo00Co0000ogmoOomoOgoo0000
1OmoOgl01?l0003oOgmoogmoOol0000Rooooo`Co2NX:NOooool00ol0003oooooooooo`0;ooooo`00
I_ooool01?l0003oOgmoogmoOol00005ogmoO`04o`000?moOgooOgmoo`0001gooooo1Ol9jPYmoooo
o`03o`000?oooooooooo00_ooooo001Vooooo`04o`000?moOgooOgmoo`0000GoOgmo00Co0000ogmo
OomoOgoo00006?ooool5o`WZ2X;ooooo00?o0000ooooooooool02oooool006Kooooo00Co0000ogmo
OomoOgoo00001OmoOgl01?l0003oOgmoogmoOol0000Cooooo`Go2NX:Qoooool00ol0003ooooooooo
o`0;ooooo`00I_ooool00ol0003oOgmoogmoO`07o`0000;oOgmo00?o0000ooooooooool03Oooool4
o`WZ2Xcooooo00?o0000ooooooooool02oooool006Kooooo00Co0000ogmoOomoOgoo00001OmoOgl0
1?l0003oOgmoogmoOol0000:ooooo`Go2NX:T?ooool00ol0003oooooooooo`0;ooooo`00Goooool3
o`WZ2PGooooo00?o0000ogmoOol9jPX00_l9jPX3ogmoO`03o`000?moOgoo000000Kooooo1Ol9jPZE
ooooo`03o`000?oooooooooo00_ooooo001Pooooo`Ko2NX:00Coooooo`000?moOgoo00001_l9jPX0
0omoOgoo0000o`000005o`WZ2Y[ooooo00?o0000ooooooooool02oooool000coooooF_l9jPX00ol0
003o2NX:o`WZ2P0:o`WZ2Yoooooo00?o0000ooooooooool02oooool0063ooooo1Ol9jPX01_oooooo
0000o`000?moOgoo0000ogmoO`Co2NX:00?o0000ogmoOol00000X?ooool00ol0003oooooooooo`0;
ooooo`00Goooool2o`WZ2PKooooo00?o0000ogmoOol000000_l9jPX3ogmoO`03o`000?moOgoo0000
0:3ooooo00?o0000ooooooooool02oooool006Sooooo2Ol0002Qooooo`03o`000?oooooooooo00_o
oooo001Xooooo`;o00001OmoOgl2o`000:7ooooo00?o0000ooooooooool02oooool006Sooooo0_l0
0005ogmoO`;o0000XOooool00ol0003oooooooooo`0;ooooo`00J?ooool2o`0000GoOgmo0_l0002Q
ooooo`03o`000?oooooooooo00_ooooo001Xooooo`;o00001OmoOgl2o`000:7ooooo00?o0000oooo
ooooool02oooool006Wooooo1ol0002Rooooo`03o`000?oooooooooo00_ooooo001Yooooo`Oo0000
X_ooool00ol0003oooooooooo`0;ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {102.625, 0}} -> {-57.2027, -32.4375, \
0.572841, 0.572841}},
  CellTags->{"AOG3.", "AOG3.4", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[opticalsystem,y,s,{R1>0,R2<0,d1>0,t>0,d2>0,n2>0,n1>0},
\t\t\tSymbolicRefractiveModels->{Vacuum->n1,BK7->n2}, MatrixForm->False]\
\>", "Input",
  CellLabel->"In[36]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],

Cell[BoxData[
    \({ABCDCenterPoint \[Rule] {d2, 0, 0}, 
      ABCDMatrix \[Rule] {{\(n1\ n2\ \((R1 - 2\ t)\)\ \((R2 + t)\) + n1\^2\ t\
\ \((R2 + t)\) + n2\^2\ t\ \((\(-R1\) + R2 + t)\) - d2\ \((n1 - n2)\)\ \((n2\ \
\((R1 - R2 - t)\) + n1\ t)\)\)\/\(n1\ n2\ R1\ R2\), \(d1\ \((n1\ n2\ \((R1 - \
2\ t)\)\ \((R2 + t)\) + n1\^2\ t\ \((R2 + t)\) + n2\^2\ t\ \((\(-R1\) + R2 + \
t)\) - d2\ \((n1 - n2)\)\ \((n2\ \((R1 - R2 - t)\) + n1\ t)\))\) + n1\ R1\ \
\((\((n1 - n2)\)\ t\ \((R2 + t)\) + d2\ \((\(-n1\)\ t + n2\ \((R2 + \
t)\))\))\)\)\/\(n1\ n2\ R1\ R2\)}, {\(-\(\(\((n1 - 
                        n2)\)\ \((n2\ \((R1 - R2 - t)\) + 
                        n1\ t)\)\)\/\(n1\ n2\ R1\ R2\)\)\), \(\(-d1\)\ \((n1 \
- n2)\)\ \((n2\ \((R1 - R2 - t)\) + n1\ t)\) + n1\ R1\ \((\(-n1\)\ t + n2\ \
\((R2 + t)\))\)\)\/\(n1\ n2\ R1\ R2\)}}, 
      ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
      SymbolicIntensity \[Rule] 100, 
      SymbolicOpticalLength \[Rule] d1\ n1 + n1\ \((d2 - t)\) + n2\ t, 
      SymbolicWaveLength \[Rule] 133\/250}\)], "Output",
  CellLabel->"Out[36]=",
  CellTags->{"AOG3.", "AOG3.4", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
result = FindABCDMatrix[opticalsystem,y,s,{R1>0,R2<0,d1>0,t>0,d2>0,n2>0,n1>0},\

\t\t\tSymbolicRefractiveModels->{Vacuum->n1,BK7->n2}, MatrixForm->True]\
\>", "Input",
  CellLabel->"In[37]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(n1\ n2\ \((R1 - 2\ t)\)\ \((R2 + t)\) + 
                    n1\^2\ t\ \((R2 + t)\) + 
                    n2\^2\ t\ \((\(-R1\) + R2 + t)\) - 
                    d2\ \((n1 - n2)\)\ \((n2\ \((R1 - R2 - t)\) + 
                          n1\ t)\)\)\/\(n1\ n2\ R1\ R2\)\), \(\(d1\ \((n1\ n2\
\ \((R1 - 2\ t)\)\ \((R2 + t)\) + n1\^2\ t\ \((R2 + t)\) + 
                          n2\^2\ t\ \((\(-R1\) + R2 + t)\) - 
                          d2\ \((n1 - n2)\)\ \((n2\ \((R1 - R2 - t)\) + 
                                n1\ t)\))\) + 
                    n1\ R1\ \((\((n1 - n2)\)\ t\ \((R2 + t)\) + 
                          d2\ \((\(-n1\)\ t + 
                                n2\ \((R2 + 
                                      t)\))\))\)\)\/\(n1\ n2\ R1\ R2\)\)},
            {\(-\(\(\((n1 - n2)\)\ \((n2\ \((R1 - R2 - t)\) + 
                          n1\ t)\)\)\/\(n1\ n2\ R1\ R2\)\)\), \(\(\(-d1\)\ \
\((n1 - n2)\)\ \((n2\ \((R1 - R2 - t)\) + n1\ t)\) + 
                    n1\ R1\ \((\(-n1\)\ t + 
                          n2\ \((R2 + t)\))\)\)\/\(n1\ n2\ R1\ R2\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[37]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.4", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["result/.{d1->0,t->0,d2->0}", "Input",
  CellLabel->"In[38]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0"},
            {\(-\(\(\((n1 - n2)\)\ \((R1 - R2)\)\)\/\(n1\ R1\ R2\)\)\), "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[38]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.4", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["result/.{d1->0,d2->0}", "Input",
  CellLabel->"In[39]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(n1\ n2\ \((R1 - 2\ t)\)\ \((R2 + t)\) + 
                    n1\^2\ t\ \((R2 + t)\) + 
                    n2\^2\ t\ \((\(-R1\) + R2 + 
                          t)\)\)\/\(n1\ n2\ R1\ R2\)\), \(\(\((n1 - 
                        n2)\)\ t\ \((R2 + t)\)\)\/\(n2\ R2\)\)},
            {\(-\(\(\((n1 - n2)\)\ \((n2\ \((R1 - R2 - t)\) + 
                          n1\ t)\)\)\/\(n1\ n2\ R1\ R2\)\)\), \(\(\(-n1\)\ t \
+ n2\ \((R2 + t)\)\)\/\(n2\ R2\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[39]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.4", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["result/.{d1->d,t->0,d2->0}", "Input",
  CellLabel->"In[40]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "d"},
            {\(-\(\(\((n1 - n2)\)\ \((R1 - 
                          R2)\)\)\/\(n1\ R1\ R2\)\)\), \(\(\(-d\)\ \((n1 - 
                          n2)\)\ n2\ \((R1 - R2)\) + 
                    n1\ n2\ R1\ R2\)\/\(n1\ n2\ R1\ R2\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[40]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.4", "AOG0."}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG3."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.5 ThinLens, and Custom ABCD Input", "Subsection",
  CellTags->{"AOG0.", "3.5", "AOG3.", "AOG3.5"}],

Cell["\<\
thinsystem = {Move[LineOfRays[40],{-d1,-50}],
ThinLens[{f,100},50],
Move[Screen[50],{d2,100}]};\
\>", "Input",
  CellLabel->"In[99]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[thinsystem,PlotType->TopView];", "Input",
  CellLabel->"In[100]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.192698 0.00634921 [
[.34127 .00857 -5.03125 -6 ]
[.34127 .00857 5.03125 6 ]
[.97619 .00857 -4.75 -6 ]
[.97619 .00857 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .36 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .03397 m
.34127 .08688 L
.34127 .13979 L
.34127 .1927 L
.34127 .24561 L
.34127 .29852 L
.34127 .35143 L
.34127 .35143 L
.34127 .29852 L
.34127 .24561 L
.34127 .1927 L
.34127 .13979 L
.34127 .08688 L
.34127 .03397 L
.34127 .03397 L
s
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
s
.34127 .35143 m
.34127 .34602 L
.34127 .33016 L
.34127 .30494 L
.34127 .27206 L
.34127 .23378 L
.34127 .1927 L
.34127 .15162 L
.34127 .11333 L
.34127 .08046 L
.34127 .05523 L
.34127 .03938 L
.34127 .03397 L
.34127 .03938 L
.34127 .05523 L
.34127 .08046 L
.34127 .11333 L
.34127 .15162 L
.34127 .1927 L
.34127 .23378 L
.34127 .27206 L
.34127 .30494 L
.34127 .33016 L
.34127 .34602 L
.34127 .35143 L
s
.97619 .03397 m
.97619 .08688 L
.97619 .13979 L
.97619 .1927 L
.97619 .24561 L
.97619 .29852 L
.97619 .35143 L
.97619 .35143 L
.97619 .29852 L
.97619 .24561 L
.97619 .1927 L
.97619 .13979 L
.97619 .08688 L
.97619 .03397 L
.97619 .03397 L
s
.97619 .1927 m
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
s
.97619 .35143 m
.97619 .34602 L
.97619 .33016 L
.97619 .30494 L
.97619 .27206 L
.97619 .23378 L
.97619 .1927 L
.97619 .15162 L
.97619 .11333 L
.97619 .08046 L
.97619 .05523 L
.97619 .03938 L
.97619 .03397 L
.97619 .03938 L
.97619 .05523 L
.97619 .08046 L
.97619 .11333 L
.97619 .15162 L
.97619 .1927 L
.97619 .23378 L
.97619 .27206 L
.97619 .30494 L
.97619 .33016 L
.97619 .34602 L
.97619 .35143 L
s
.039 .916 .04 r
.02381 .06571 m
.34127 .06571 L
s
% Start of user PostScript
-50. -20. 0 -20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .06571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1927 m
.34127 .1927 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .31968 m
.34127 .31968 L
s
% Start of user PostScript
-50. 20. 0 20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .31968 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .06571 m
.97619 .19145 L
s
% Start of user PostScript
0 -20. 100. -0.196097 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19145 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .1927 m
.97619 .1927 L
s
% Start of user PostScript
0 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .31968 m
.97619 .19394 L
s
% Start of user PostScript
0 20. 100. 0.196097 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19394 Mdot
gsave
.34127 .00857 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00857 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .36 L
0 .36 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[100]:=",
  ImageSize->{288, 103.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ib000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00H?ooool6o`000:[ooooo0ol0
000=ooooo`00HOooool01Ol0003ooooooooooooooooo00000:[ooooo00Co0000oooooooooooo0000
3?ooool0067ooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`0:ooooo`00HOooool0
0ol0003oooooooooo`2]ooooo`;o00003Oooool0067ooooo00?o0000ooooooooool0[?ooool00ol0
003oooooooooo`0=ooooo`00HOooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`00
00cooooo001Pooooo`?o0000[_ooool3o`0000cooooo003oooooob7ooooo003oooooob7ooooo001S
ooooo`;o0000[Oooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`2/oooo
o`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo0:cooooo00?o0000oooooooo
ool02oooool006?ooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0;ooooo`00Hooo
ool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooo
oooo0:cooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0[?ooool00ol0
003oooooooooo`0;ooooo`00Foooool3o`WZ2PGooooo00?o0000ooooooooool0[?ooool00ol0003o
ooooooooo`0;ooooo`00G?ooool6o`WZ2P03ooooool0003o00000:gooooo00?o0000ooooooooool0
2oooool000coooooFol9jPZ[ooooo`03o`000?oooooooooo00_ooooo001Looooo`Go2NX:0_ooool0
1?l0003oooooooooooooool5o`WZ2ZKooooo00?o0000ooooooooool02oooool005_ooooo0_l9jPX6
ooooo`03o`000?oooooooooo00Kooooo1Ol9jPZQooooo`03o`000?oooooooooo00_ooooo001Soooo
o`03o`000?oooooooooo00_ooooo1Ol9jPZLooooo`03o`000?oooooooooo00_ooooo001Sooooo`03
o`000?oooooooooo013ooooo1Ol9jPZGooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`00
0?oooooooooo01Gooooo1Ol9jPZBooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oo
oooooooo01[ooooo1Ol9jPZ=ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooo
oooo01oooooo1_l9jPZ7ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo
02Gooooo1Ol9jPZ2ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo02[o
oooo1Ol9jPYmooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo02oooooo
1Ol9jPYhooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo03Cooooo1Ol9
jPYcooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo03Wooooo1Ol9jPY^
ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo03kooooo1Ol9jPYYoooo
o`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo04?ooooo1_l9jPYSooooo`03
o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo04Wooooo1Ol9jPYNooooo`03o`00
0?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo04kooooo1Ol9jPYIooooo`03o`000?oo
oooooooo00_ooooo001Sooooo`03o`000?oooooooooo05?ooooo1Ol9jPYDooooo`03o`000?oooooo
oooo00_ooooo001Sooooo`03o`000?oooooooooo05Sooooo1Ol9jPY?ooooo`03o`000?oooooooooo
00_ooooo001Sooooo`03o`000?oooooooooo05gooooo1Ol9jPY:ooooo`03o`000?oooooooooo00_o
oooo001Sooooo`03o`000?oooooooooo06;ooooo1_l9jPY4ooooo`03o`000?oooooooooo00_ooooo
001Sooooo`03o`000?oooooooooo06Sooooo1Ol9jPXoooooo`03o`000?oooooooooo00_ooooo001S
ooooo`03o`000?oooooooooo06gooooo1Ol9jPXjooooo`03o`000?oooooooooo00_ooooo001Soooo
o`03o`000?oooooooooo07;ooooo1Ol9jPXeooooo`03o`000?oooooooooo00_ooooo001Sooooo`03
o`000?oooooooooo07Oooooo1Ol9jPX`ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`00
0?oooooooooo07cooooo1Ol9jPX[ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oo
oooooooo087ooooo1Ol9jPXVooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooo
oooo08Kooooo1_l9jPXPooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo
08cooooo1Ol9jPXKooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo097o
oooo1Ol9jPXFooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo09Kooooo
1Ol9jPXAooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo09_ooooo1Ol9
jPX4ooooo`;o2NX:1_ooool00ol0003oooooooooo`0;ooooo`00Foooool3o`WZ2PGooooo00?o0000
ooooooooool0X?ooool9o`WZ2P?ooooo00?o0000ooooooooool02oooool005cooooo1_l9jPX00ooo
oooo0000ooooo`2Vooooo`Oo2NX:00?o0000ooooooooool02oooool000coooooool9jPX6o`WZ2P;o
00003Oooool005cooooo1Ol9jPX2ooooo`;o0000YOooool7o`WZ2P;o00003Oooool005_ooooo0_l9
jPX6ooooo`03o`000?oooooooooo0:Cooooo1ol9jPX00ooooooo0000ooooo`0<ooooo`00Hoooool0
0ol0003oooooooooo`2Oooooo`Go2NX:00Coooooo`WZ2_l9jP[o2NX:1?ooool00ol0003ooooooooo
o`0;ooooo`00Hoooool00ol0003oooooooooo`2Jooooo`Go2NX:1Oooool00ol9jP[oooooooooo`05
ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo09Gooooo1Ol9jPXBoooo
o`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo093ooooo1Ol9jPXGooooo`03
o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo08_ooooo1Ol9jPXLooooo`03o`00
0?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo08Gooooo1_l9jPXQooooo`03o`000?oo
oooooooo00_ooooo001Sooooo`03o`000?oooooooooo083ooooo1Ol9jPXWooooo`03o`000?oooooo
oooo00_ooooo001Sooooo`03o`000?oooooooooo07_ooooo1Ol9jPX/ooooo`03o`000?oooooooooo
00_ooooo001Sooooo`03o`000?oooooooooo07Kooooo1Ol9jPXaooooo`03o`000?oooooooooo00_o
oooo001Sooooo`03o`000?oooooooooo077ooooo1Ol9jPXfooooo`03o`000?oooooooooo00_ooooo
001Sooooo`03o`000?oooooooooo06cooooo1Ol9jPXkooooo`03o`000?oooooooooo00_ooooo001S
ooooo`03o`000?oooooooooo06Oooooo1Ol9jPY0ooooo`03o`000?oooooooooo00_ooooo001Soooo
o`03o`000?oooooooooo067ooooo1_l9jPY5ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03
o`000?oooooooooo05cooooo1Ol9jPY;ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`00
0?oooooooooo05Oooooo1Ol9jPY@ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oo
oooooooo05;ooooo1Ol9jPYEooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooo
oooo04gooooo1Ol9jPYJooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo
04Sooooo1Ol9jPYOooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo04;o
oooo1_l9jPYTooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo03gooooo
1Ol9jPYZooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo03Sooooo1Ol9
jPY_ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo03?ooooo1Ol9jPYd
ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo02kooooo1Ol9jPYioooo
o`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo02Wooooo1Ol9jPYnooooo`03
o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo02Cooooo1Ol9jPZ3ooooo`03o`00
0?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo01kooooo1_l9jPZ8ooooo`03o`000?oo
oooooooo00_ooooo001Sooooo`03o`000?oooooooooo01Wooooo1Ol9jPZ>ooooo`03o`000?oooooo
oooo00_ooooo001Sooooo`03o`000?oooooooooo01Cooooo1Ol9jPZCooooo`03o`000?oooooooooo
00_ooooo001Sooooo`03o`000?oooooooooo00oooooo1Ol9jPZHooooo`03o`000?oooooooooo00_o
oooo001Sooooo`03o`000?oooooooooo00[ooooo1Ol9jPZMooooo`03o`000?oooooooooo00_ooooo
001Kooooo`?o2NX:1Oooool00ol0003oooooooooo`05ooooo`Go2NX:X_ooool00ol0003ooooooooo
o`0;ooooo`00G?ooool6o`WZ2P04ooooool0003oooooooooo`Go2NX:Yoooool00ol0003ooooooooo
o`0;ooooo`003?oooomJo`WZ2Zcooooo00?o0000ooooooooool02oooool005cooooo1Ol9jPX2oooo
o`;o0000[Oooool00ol0003oooooooooo`0;ooooo`00Foooool2o`WZ2PKooooo00?o0000oooooooo
ool0[?ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`2/ooooo`03o`00
0?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool02ooo
ool006?ooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0
003oooooooooo`2/ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo0:co
oooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooo
ooooo`0;ooooo`00Hoooool2o`000:gooooo00?o0000ooooooooool02oooool00?oooooo8Oooool0
0?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {102.625, 0}} -> {-57.2027, -32.4375, \
0.572841, 0.572841}},
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
result = FindABCDMatrix[thinsystem,{f>0,d1>0,d2>0}, \
ABCDConstruction->Horizontal]\
\>", "Input",
  CellLabel->"In[101]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1 - d2\/f\), \(d1 + d2 - \(d1\ d2\)\/f\)},
            {\(-\(1\/f\)\), \(1 - d1\/f\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[101]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["result/.{d1->0,d2->0}", "Input",
  CellLabel->"In[102]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0"},
            {\(-\(1\/f\)\), "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[102]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["result/.{d1->d,d2->0}", "Input",
  CellLabel->"In[103]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "d"},
            {\(-\(1\/f\)\), \(1 - d\/f\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[103]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell["\<\
thicksystem = {Move[LineOfRays[40],{-d1,-50}],
ThickLens[{f,100},50,{t,10}],
Move[Screen[50],{d2,100}]};\
\>", "Input",
  CellLabel->"In[104]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[thicksystem,PlotType->TopView];", "Input",
  CellLabel->"In[105]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.192698 0.00634921 [
[.37302 .00857 -5.03125 -6 ]
[.37302 .00857 5.03125 6 ]
[.97619 .00857 -4.75 -6 ]
[.97619 .00857 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .36 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .03397 m
.34127 .08688 L
.34127 .13979 L
.34127 .1927 L
.34127 .24561 L
.34127 .29852 L
.34127 .35143 L
.34127 .35143 L
.34127 .29852 L
.34127 .24561 L
.34127 .1927 L
.34127 .13979 L
.34127 .08688 L
.34127 .03397 L
.34127 .03397 L
s
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
s
.40476 .03397 m
.40476 .08688 L
.40476 .13979 L
.40476 .1927 L
.40476 .24561 L
.40476 .29852 L
.40476 .35143 L
.40476 .35143 L
.40476 .29852 L
.40476 .24561 L
.40476 .1927 L
.40476 .13979 L
.40476 .08688 L
.40476 .03397 L
.40476 .03397 L
s
.40476 .1927 m
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
.40476 .1927 L
s
.34127 .35143 m
.34127 .34602 L
.34127 .33016 L
.34127 .30494 L
.34127 .27206 L
.34127 .23378 L
.34127 .1927 L
.34127 .15162 L
.34127 .11333 L
.34127 .08046 L
.34127 .05523 L
.34127 .03938 L
.34127 .03397 L
.34127 .03938 L
.34127 .05523 L
.34127 .08046 L
.34127 .11333 L
.34127 .15162 L
.34127 .1927 L
.34127 .23378 L
.34127 .27206 L
.34127 .30494 L
.34127 .33016 L
.34127 .34602 L
.34127 .35143 L
s
.40476 .35143 m
.40476 .34602 L
.40476 .33016 L
.40476 .30494 L
.40476 .27206 L
.40476 .23378 L
.40476 .1927 L
.40476 .15162 L
.40476 .11333 L
.40476 .08046 L
.40476 .05523 L
.40476 .03938 L
.40476 .03397 L
.40476 .03938 L
.40476 .05523 L
.40476 .08046 L
.40476 .11333 L
.40476 .15162 L
.40476 .1927 L
.40476 .23378 L
.40476 .27206 L
.40476 .30494 L
.40476 .33016 L
.40476 .34602 L
.40476 .35143 L
s
.97619 .03397 m
.97619 .08688 L
.97619 .13979 L
.97619 .1927 L
.97619 .24561 L
.97619 .29852 L
.97619 .35143 L
.97619 .35143 L
.97619 .29852 L
.97619 .24561 L
.97619 .1927 L
.97619 .13979 L
.97619 .08688 L
.97619 .03397 L
.97619 .03397 L
s
.97619 .1927 m
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
s
.97619 .35143 m
.97619 .34602 L
.97619 .33016 L
.97619 .30494 L
.97619 .27206 L
.97619 .23378 L
.97619 .1927 L
.97619 .15162 L
.97619 .11333 L
.97619 .08046 L
.97619 .05523 L
.97619 .03938 L
.97619 .03397 L
.97619 .03938 L
.97619 .05523 L
.97619 .08046 L
.97619 .11333 L
.97619 .15162 L
.97619 .1927 L
.97619 .23378 L
.97619 .27206 L
.97619 .30494 L
.97619 .33016 L
.97619 .34602 L
.97619 .35143 L
s
.039 .916 .04 r
.02381 .06571 m
.34127 .06571 L
s
% Start of user PostScript
-50. -20. 0 -20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .06571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1927 m
.34127 .1927 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .31968 m
.34127 .31968 L
s
% Start of user PostScript
-50. 20. 0 20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .31968 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .06571 m
.97619 .17888 L
s
% Start of user PostScript
10. -20. 100. -2.17649 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .17888 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .1927 m
.97619 .1927 L
s
% Start of user PostScript
10. 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .31968 m
.97619 .20652 L
s
% Start of user PostScript
10. 20. 100. 2.17649 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .20652 Mdot
gsave
.37302 .00857 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00857 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .36 L
0 .36 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[105]:=",
  ImageSize->{288, 103.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ib000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00JOooool6o`000:7ooooo0ol0
000=ooooo`00J_ooool01Ol0003ooooooooooooooooo00000:7ooooo00Co0000oooooooooooo0000
3?ooool006[ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0:ooooo`00J_ooool0
0ol0003oooooooooo`2Tooooo`;o00003Oooool006[ooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`0=ooooo`00J_ooool00ol0003oooooooooo`2Sooooo`04o`000?ooooooooooo`00
00cooooo001Yooooo`?o0000YOooool3o`0000cooooo003oooooob7ooooo003oooooob7ooooo001S
ooooo`;o00004?ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Soooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;oooo
o`00Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09[ooooo00?o0000oooooooo
ool02oooool006?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Jooooo`03o`00
0?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0V_oo
ool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo09[ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Kooooo`?o2NX:1Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool005cooooo
1_l9jPX00ooooooo0000o`00000@ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
2oooool000coooooEol9jPX2o`00013ooooo1?l9jPZIooooo`03o`000?oooooooooo00_ooooo001L
ooooo`Go2NX:0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooo`Go2NX:U?oo
ool00ol0003oooooooooo`0;ooooo`00Foooool2o`WZ2PKooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`06ooooo`Go2NX:Soooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo1Ol9jPZ:ooooo`03o`000?oooooooooo
00_ooooo001Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool5o`WZ2XGo
oooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Eooooo`Go2NX:P?ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01[ooooo1Ol9jPYkooooo`03o`000?oooooooooo00_ooooo001S
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool5o`WZ2WKooooo00?o0000
ooooooooool02oooool006?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Toooo
o`Go2NX:LOooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02Wooooo1Ol9jPY/ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0;_ooool5o`WZ2VOooooo00?o0000ooooooooool0
2oooool006?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`Go2NX:H_oo
ool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03Sooooo1Ol9jPYMooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0?Oooool5o`WZ2USooooo00?o0000ooooooooool02oooool006?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`12ooooo`Go2NX:Doooool00ol0003o
ooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Oooooo
1_l9jPY=ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0COooool5o`WZ2TSooooo00?o0000ooooooooool02oooool006?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Booooo`Go2NX:@oooool00ol0003oooooooooo`0;
ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Oooooo1Ol9jPXnoooo
o`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0G?ooool5o`WZ2SWooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1Qooooo`Go2NX:=?ooool00ol0003oooooooooo`0;ooooo`00Hooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Kooooo1Ol9jPX_ooooo`03o`000?oo
oooooooo00_ooooo001Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Joooool5
o`WZ2R[ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1`ooooo`Go2NX:9Oooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo07Gooooo1Ol9jPXPooooo`03o`000?oooooooooo00_o
oooo001Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0N_ooool5o`WZ2Q_ooooo
00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1oooooo`Go2NX:5_ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo08Cooooo1Ol9jPX9ooooo`;o2NX:1_ooool00ol0003oooooooooo`0;
ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Wooooo1Ol9jPX4oooo
o`Co2NX:1?ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo08kooooo2_l9jPX2ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0Toooool6o`WZ2P;o00003Oooool006?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2Booooo`Oo2NX:0_l0000=ooooo`00Foooool3
o`WZ2PGooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Booooo`?o2NX:1Oooool0
0ol0003oooooooooo`0;ooooo`00G?ooool6o`WZ2P03ooooool0003ooooo013ooooo00?o0000oooo
ooooool0Toooool6o`WZ2P03ooooool0003ooooo00cooooo000<oooooeOo2NX:0_l0000@oooooico
2NX:0_l0000=ooooo`00G?ooool5o`WZ2P;ooooo0_l0000@ooooo`03o`000?oooooooooo09?ooooo
1Ol9jPX00ooooooo0000o`00000=ooooo`00Foooool2o`WZ2PKooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2Booooo`;o2NX:1_ooool00ol0003oooooooooo`0;ooooo`00Hoooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool0
06?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Booooo`Oo2NX:0_l0000=oooo
o`00Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09;ooooo1ol9jPX2o`0000go
oooo001Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0SOooool5o`WZ2P;ooooo
0ol9jPX3ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0R?ooool5o`WZ2PKooooo0_l9jPX5ooooo`03o`000?oooooooooo00_ooooo001S
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Poooool5o`WZ2P[ooooo00?o2NX:
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo07kooooo1Ol9jPXGooooo`03o`000?oooooooooo00_ooooo001Sooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0NOooool5o`WZ2Qcooooo00?o0000oooooooo
ool02oooool006?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1dooooo`Go2NX:
8Oooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo06oooooo1Ol9jPXVooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0J_ooool5o`WZ2R_ooooo00?o0000ooooooooool02oooool0
06?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Uooooo`Go2NX:<?ooool00ol0
003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo063o
oooo1Ol9jPXeooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Foooool5o`WZ2S[ooooo00?o0000ooooooooool02oooool006?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Fooooo`Go2NX:?oooool00ol0003ooooooooo
o`0;ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo057ooooo1Ol9jPY4
ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0Boooool6o`WZ2TWooooo00?o0000ooooooooool02oooool006?ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`16ooooo`Go2NX:Coooool00ol0003oooooooooo`0;ooooo`00
Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo047ooooo1Ol9jPYDooooo`03o`00
0?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0??oo
ool5o`WZ2UWooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0gooooo`Go2NX:G_ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03;ooooo1Ol9jPYSooooo`03o`000?oooooooooo
00_ooooo001Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool5o`WZ2VSo
oooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Xooooo`Go2NX:KOooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02?ooooo1Ol9jPYbooooo`03o`000?oooooooooo00_ooooo001S
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool5o`WZ2WOooooo00?o0000
ooooooooool02oooool006?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Ioooo
o`Go2NX:O?ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Cooooo1Ol9jPZ1ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03oooool5o`WZ2XKooooo00?o0000ooooooooool0
2oooool006?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`Go2NX:Rooo
ool00ol0003oooooooooo`0;ooooo`00Foooool3o`WZ2PGooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`05ooooo`Go2NX:T?ooool00ol0003oooooooooo`0;ooooo`00G?ooool6o`WZ
2P03ooooool0003ooooo013ooooo00?o0000ooooooooool01Ol9jPZEooooo`03o`000?oooooooooo
00_ooooo000<oooooeOo2NX:0_l0000@ooooo`?o2NX:V_ooool00ol0003oooooooooo`0;ooooo`00
G?ooool5o`WZ2P;ooooo0_l0000@ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
2oooool005_ooooo0_l9jPX6ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0V_oo
ool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo09[ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool006?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00_ooooo001S
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;
ooooo`00Hoooool2o`00013ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0;oooo
o`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {102.625, 0}} -> {-57.2027, -32.4375, \
0.572841, 0.572841}},
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboPlot[thicksystem,PlotType->TopView];", "Input",
  CellLabel->"In[106]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.166667 0.00634921 [
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .00794 m
.34127 .06085 L
.34127 .11376 L
.34127 .16667 L
.34127 .21958 L
.34127 .27249 L
.34127 .3254 L
.34127 .3254 L
.34127 .27249 L
.34127 .21958 L
.34127 .16667 L
.34127 .11376 L
.34127 .06085 L
.34127 .00794 L
.34127 .00794 L
s
.34127 .16667 m
.34127 .16667 L
.34127 .16667 L
.34127 .16667 L
.34127 .16667 L
.34127 .16667 L
.34127 .16667 L
.34127 .16667 L
.34127 .16667 L
.34127 .16667 L
.34127 .16667 L
.34127 .16667 L
.34127 .16667 L
.34127 .16667 L
.34127 .16667 L
s
.40476 .00794 m
.40476 .06085 L
.40476 .11376 L
.40476 .16667 L
.40476 .21958 L
.40476 .27249 L
.40476 .3254 L
.40476 .3254 L
.40476 .27249 L
.40476 .21958 L
.40476 .16667 L
.40476 .11376 L
.40476 .06085 L
.40476 .00794 L
.40476 .00794 L
s
.40476 .16667 m
.40476 .16667 L
.40476 .16667 L
.40476 .16667 L
.40476 .16667 L
.40476 .16667 L
.40476 .16667 L
.40476 .16667 L
.40476 .16667 L
.40476 .16667 L
.40476 .16667 L
.40476 .16667 L
.40476 .16667 L
.40476 .16667 L
.40476 .16667 L
s
.34127 .3254 m
.34127 .31999 L
.34127 .30413 L
.34127 .27891 L
.34127 .24603 L
.34127 .20775 L
.34127 .16667 L
.34127 .12558 L
.34127 .0873 L
.34127 .05443 L
.34127 .0292 L
.34127 .01335 L
.34127 .00794 L
.34127 .01335 L
.34127 .0292 L
.34127 .05443 L
.34127 .0873 L
.34127 .12558 L
.34127 .16667 L
.34127 .20775 L
.34127 .24603 L
.34127 .27891 L
.34127 .30413 L
.34127 .31999 L
.34127 .3254 L
s
.40476 .3254 m
.40476 .31999 L
.40476 .30413 L
.40476 .27891 L
.40476 .24603 L
.40476 .20775 L
.40476 .16667 L
.40476 .12558 L
.40476 .0873 L
.40476 .05443 L
.40476 .0292 L
.40476 .01335 L
.40476 .00794 L
.40476 .01335 L
.40476 .0292 L
.40476 .05443 L
.40476 .0873 L
.40476 .12558 L
.40476 .16667 L
.40476 .20775 L
.40476 .24603 L
.40476 .27891 L
.40476 .30413 L
.40476 .31999 L
.40476 .3254 L
s
.97619 .00794 m
.97619 .06085 L
.97619 .11376 L
.97619 .16667 L
.97619 .21958 L
.97619 .27249 L
.97619 .3254 L
.97619 .3254 L
.97619 .27249 L
.97619 .21958 L
.97619 .16667 L
.97619 .11376 L
.97619 .06085 L
.97619 .00794 L
.97619 .00794 L
s
.97619 .16667 m
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
.97619 .16667 L
s
.97619 .3254 m
.97619 .31999 L
.97619 .30413 L
.97619 .27891 L
.97619 .24603 L
.97619 .20775 L
.97619 .16667 L
.97619 .12558 L
.97619 .0873 L
.97619 .05443 L
.97619 .0292 L
.97619 .01335 L
.97619 .00794 L
.97619 .01335 L
.97619 .0292 L
.97619 .05443 L
.97619 .0873 L
.97619 .12558 L
.97619 .16667 L
.97619 .20775 L
.97619 .24603 L
.97619 .27891 L
.97619 .30413 L
.97619 .31999 L
.97619 .3254 L
s
.039 .916 .04 r
.02381 .03968 m
.34127 .03968 L
s
0 0 0 r
2.5 Mabswid
.34127 .03968 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16667 m
.34127 .16667 L
s
0 0 0 r
2.5 Mabswid
.34127 .16667 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29365 m
.34127 .29365 L
s
0 0 0 r
2.5 Mabswid
.34127 .29365 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .03968 m
.97619 .15285 L
s
0 0 0 r
2.5 Mabswid
.97619 .15285 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .16667 m
.97619 .16667 L
s
0 0 0 r
2.5 Mabswid
.97619 .16667 Mdot
.039 .916 .04 r
.5 Mabswid
.40476 .29365 m
.97619 .18049 L
s
0 0 0 r
2.5 Mabswid
.97619 .18049 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[106]:=",
  ImageSize->{288, 95.9375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Gb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2Pooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0X?ooool00ol0003oooooooooo`06ooooo`00H_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Kooooo001Rooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`06ooooo`00
H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0
1_ooool006;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Pooooo`03o`000?oo
oooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0X?ooool0
0ol0003oooooooooo`06ooooo`001ooooomJo`WZ2P;o00004Oooool4o`WZ2Yoooooo00?o0000oooo
ooooool01_ooool0067ooooo0_l0000Aooooo`04o`000?ooooooooooooooo`Go2NX:V_ooool00ol0
003oooooooooo`06ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Ko
oooo1Ol9jPZEooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02oooool5o`WZ2Y3ooooo00?o0000ooooooooool01_ooool006;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`Go2NX:Roooool00ol0003ooooooooo
o`06ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo1Ol9jPZ6
ooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06_ooool5o`WZ2X7ooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Oooooo`Go2NX:O?ooool00ol0003oooooooooo`06ooooo`00
H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo1Ol9jPYgooooo`03o`00
0?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:Ooo
ool5o`WZ2W;ooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0^ooooo`Go2NX:KOooool00ol0003oooooooooo`06ooooo`00H_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo1_l9jPYWooooo`03o`000?oooooooooo
00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>Oooool5o`WZ2V;o
oooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0nooooo`Go2NX:GOooool00ol0003oooooooooo`06ooooo`00H_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo04?ooooo1Ol9jPYHooooo`03o`000?oooooooooo00Kooooo001R
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool5o`WZ2U?ooooo00?o0000
ooooooooool01_ooool006;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=oooo
o`Go2NX:C_ooool00ol0003oooooooooo`06ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo05;ooooo1Ol9jPY9ooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0Eoooool5o`WZ2TCooooo00?o0000ooooooooool0
1_ooool006;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Looooo`Go2NX:?ooo
ool00ol0003oooooooooo`06ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo067ooooo1Ol9jPXjooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0I_ooool6o`WZ2SCooooo00?o0000ooooooooool01_ooool006;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1/ooooo`Go2NX:;oooool00ol0003o
ooooooooo`06ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo077ooooo
1Ol9jPXZooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0M_ooool5o`WZ2RGooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1kooooo`Go2NX:8?ooool00ol0003oooooooooo`06
ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo083ooooo1Ol9jPXKoooo
o`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0QOooool5o`WZ2QKooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2:ooooo`Go2NX:4Oooool00ol0003oooooooooo`06ooooo`00H_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08oooooo1Ol9jPX<ooooo`03o`000?oo
oooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0U?ooool5
o`WZ2POooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2Iooooo`Go2NX:0_ooool00ol0003oooooooooo`06ooooo`00H_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo09kooooo00?o2NX:o`000?l000002?ooool006;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2Oooooo`;o00002?ooool006;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Kooooo001R
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`06
ooooo`001ooooomJo`WZ2P;o00004OoooonRo`WZ2P;o00002?ooool0067ooooo0_l0000Aooooo`03
o`000?oooooooooo09oooooo0_l00008ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0:3ooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0WOooool2o`WZ2P;o00002?ooool006;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2Hooooo`Go2NX:0_ooool2o`0000Sooooo001Rooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Toooool5o`WZ2PSooooo00?o0000oooooooo
ool01_ooool006;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2>ooooo`Go2NX:
3Oooool00ol0003oooooooooo`06ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo08Wooooo1Ol9jPXBooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Q?ooool5o`WZ2QOooooo00?o0000ooooooooool01_ooool0
06;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1oooooo`Go2NX:7?ooool00ol0
003oooooooooo`06ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07[o
oooo1Ol9jPXQooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0MOooool5o`WZ2RKooooo00?o0000ooooooooool01_ooool006;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1`ooooo`Go2NX::oooool00ol0003ooooooooo
o`06ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06_ooooo1Ol9jPX`
ooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0IOooool6o`WZ2SGooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1Pooooo`Go2NX:>oooool00ol0003oooooooooo`06ooooo`00
H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05_ooooo1Ol9jPY0ooooo`03o`00
0?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0E_oo
ool5o`WZ2TGooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Aooooo`Go2NX:B_ooool00ol0003oooooooooo`06ooooo`00H_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04cooooo1Ol9jPY?ooooo`03o`000?oooooooooo
00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Aoooool5o`WZ2UCo
oooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`12ooooo`Go2NX:FOooool00ol0003oooooooooo`06ooooo`00H_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03gooooo1Ol9jPYNooooo`03o`000?oooooooooo00Kooooo001R
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>?ooool5o`WZ2V?ooooo00?o0000
ooooooooool01_ooool006;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0boooo
o`Ko2NX:J?ooool00ol0003oooooooooo`06ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02gooooo1Ol9jPY^ooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0:?ooool5o`WZ2W?ooooo00?o0000ooooooooool0
1_ooool006;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Sooooo`Go2NX:N?oo
ool00ol0003oooooooooo`06ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01kooooo1Ol9jPYmooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool06Oooool5o`WZ2X;ooooo00?o0000ooooooooool01_ooool006;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`Go2NX:Qoooool00ol0003o
ooooooooo`06ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
1Ol9jPZ<ooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02_ooool5o`WZ2Y7ooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`05ooooo`Go2NX:U_ooool00ol0003oooooooooo`06
ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Go2NX:Voooool00ol0
003oooooooooo`06ooooo`001ooooomJo`WZ2P;o00004Oooool3o`WZ2Z3ooooo00?o0000oooooooo
ool01_ooool0067ooooo0_l0000Aooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0
1_ooool006;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Pooooo`03o`000?oo
oooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0X?ooool0
0ol0003oooooooooo`06ooooo`00H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0:3ooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2Pooooo`03o`000?oooooooooo00Kooooo001Rooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`06ooooo`00H_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool01_ooool006;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Kooooo001Roooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`06oooo
o`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {94.9375, 0}} -> {-54.3548, -26.2503, \
0.552995, 0.552995}},
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
result = FindABCDMatrix[thicksystem,{f>0,d1>0,t>0,d2>0}, \
ABCDConstruction->Horizontal]\
\>", "Input",
  CellLabel->"In[107]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(\(-d2\) + f + t\)\/f\), \(d2 - 
                t + \(d1\ \((\(-d2\) + f + t)\)\)\/f\)},
            {\(-\(1\/f\)\), \(1 - d1\/f\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[107]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["result/.{d1->0,t->0,d2->0}", "Input",
  CellLabel->"In[108]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0"},
            {\(-\(1\/f\)\), "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[108]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["result/.{d1->0,d2->0}", "Input",
  CellLabel->"In[109]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(f + t\)\/f\), \(-t\)},
            {\(-\(1\/f\)\), "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[109]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["result/.{d1->d,t->0,d2->0}", "Input",
  CellLabel->"In[110]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "d"},
            {\(-\(1\/f\)\), \(1 - d\/f\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[110]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[TextData[{
  "You can enter your own ABCD matrix expressions using ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  "'s built-in ",
  StyleBox["ABCDOptic", "Input"],
  " function."
}], "Text",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell["\<\
abcdsystem = {Move[LineOfRays[40],{-d1,-50}],
ABCDOptic[{{1,0},{{-1/f,-1/100},1}},{a,50}],
Move[Screen[50],{d2,100}]};\
\>", "Input",
  CellLabel->"In[111]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[abcdsystem,PlotType->TopView];", "Input",
  CellLabel->"In[112]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.192698 0.00634921 [
[.34127 .00857 -5.59375 -6 ]
[.34127 .00857 5.59375 6 ]
[.97619 .00857 -4.75 -6 ]
[.97619 .00857 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .36 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.34127 .03397 m
.34127 .03397 L
.34127 .08688 L
.34127 .08688 L
.34127 .03397 L
F
.34127 .08688 m
.34127 .08688 L
.34127 .13979 L
.34127 .13979 L
.34127 .08688 L
F
.34127 .13979 m
.34127 .13979 L
.34127 .1927 L
.34127 .1927 L
.34127 .13979 L
F
.34127 .1927 m
.34127 .1927 L
.34127 .24561 L
.34127 .24561 L
.34127 .1927 L
F
.34127 .24561 m
.34127 .24561 L
.34127 .29852 L
.34127 .29852 L
.34127 .24561 L
F
.34127 .29852 m
.34127 .29852 L
.34127 .35143 L
.34127 .35143 L
.34127 .29852 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .03397 m
.34127 .08688 L
.34127 .13979 L
.34127 .1927 L
.34127 .24561 L
.34127 .29852 L
.34127 .35143 L
.34127 .35143 L
.34127 .29852 L
.34127 .24561 L
.34127 .1927 L
.34127 .13979 L
.34127 .08688 L
.34127 .03397 L
.34127 .03397 L
s
.5 g
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
F
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
F
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
F
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
F
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
F
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
F
0 g
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
s
.97619 .03397 m
.97619 .08688 L
.97619 .13979 L
.97619 .1927 L
.97619 .24561 L
.97619 .29852 L
.97619 .35143 L
.97619 .35143 L
.97619 .29852 L
.97619 .24561 L
.97619 .1927 L
.97619 .13979 L
.97619 .08688 L
.97619 .03397 L
.97619 .03397 L
s
.97619 .1927 m
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
s
.97619 .35143 m
.97619 .34602 L
.97619 .33016 L
.97619 .30494 L
.97619 .27206 L
.97619 .23378 L
.97619 .1927 L
.97619 .15162 L
.97619 .11333 L
.97619 .08046 L
.97619 .05523 L
.97619 .03938 L
.97619 .03397 L
.97619 .03938 L
.97619 .05523 L
.97619 .08046 L
.97619 .11333 L
.97619 .15162 L
.97619 .1927 L
.97619 .23378 L
.97619 .27206 L
.97619 .30494 L
.97619 .33016 L
.97619 .34602 L
.97619 .35143 L
s
.039 .916 .04 r
.02381 .06571 m
.34127 .06571 L
s
% Start of user PostScript
-50. -20. 0 -20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .06571 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1927 m
.34127 .1927 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .31968 m
.34127 .31968 L
s
% Start of user PostScript
-50. 20. 0 20. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .31968 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .06571 m
.97619 .19145 L
s
% Start of user PostScript
0 -20. 100. -0.196097 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19145 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .1927 m
.97619 .1927 L
s
% Start of user PostScript
0 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .31968 m
.97619 .19394 L
s
% Start of user PostScript
0 20. 100. 0.196097 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .19394 Mdot
gsave
.34127 .00857 -66.5938 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
70.188 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00857 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .36 L
0 .36 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[112]:=",
  ImageSize->{288, 103.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Ib000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00H_ooool3o`000:_ooooo0ol0
000=ooooo`00HOooool01Ol0003ooooooooooooooooo00000:[ooooo00Co0000oooooooooooo0000
3?ooool0063ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Zooooo`03o`000?oo
oooooooo00[ooooo001Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Z?ooool2
o`0000gooooo001Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Yoooool00ol0
003oooooooooo`0=ooooo`00HOooool01Ol0003ooooooooooooooooo00000:[ooooo00Co0000oooo
oooooooo00003?ooool006;ooooo0ol0002/ooooo`?o00003?ooool00?oooooo8Oooool00?oooooo
8Oooool006?ooooo0_l0002]ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooo
oooo0:cooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0[?ooool00ol0
003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00_o
oooo001Sooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool02oooool006?ooooo00?o
0000ooooooooool0[?ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`2/
ooooo`03o`000?oooooooooo00_ooooo001Kooooo`?o2NX:1Oooool00ol0003oooooooooo`2/oooo
o`03o`000?oooooooooo00_ooooo001Looooo`Ko2NX:00?oooooo`000?l00000[Oooool00ol0003o
ooooooooo`0;ooooo`003?oooomKo`WZ2Z_ooooo00?o0000ooooooooool02oooool005cooooo1Ol9
jPX2ooooo`04o`000?ooooooooooooooo`Go2NX:Y_ooool00ol0003oooooooooo`0;ooooo`00Fooo
ool2o`WZ2PKooooo00?o0000ooooooooool01_ooool5o`WZ2Z7ooooo00?o0000ooooooooool02ooo
ool006?ooooo00?o0000ooooooooool02oooool5o`WZ2Ycooooo00?o0000ooooooooool02oooool0
06?ooooo00?o0000ooooooooool04?ooool5o`WZ2YOooooo00?o0000ooooooooool02oooool006?o
oooo00?o0000ooooooooool05Oooool5o`WZ2Y;ooooo00?o0000ooooooooool02oooool006?ooooo
00?o0000ooooooooool06_ooool5o`WZ2Xgooooo00?o0000ooooooooool02oooool006?ooooo00?o
0000ooooooooool07oooool6o`WZ2XOooooo00?o0000ooooooooool02oooool006?ooooo00?o0000
ooooooooool09Oooool5o`WZ2X;ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000oooo
ooooool0:_ooool5o`WZ2Wgooooo00?o0000ooooooooool02oooool006?ooooo00?o0000oooooooo
ool0;oooool5o`WZ2WSooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0
=?ooool5o`WZ2W?ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0>Ooo
ool5o`WZ2Vkooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0?_ooool5
o`WZ2VWooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0@oooool6o`WZ
2V?ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0BOooool5o`WZ2Uko
oooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0C_ooool5o`WZ2UWooooo
00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0Doooool5o`WZ2UCooooo00?o
0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0F?ooool5o`WZ2Toooooo00?o0000
ooooooooool02oooool006?ooooo00?o0000ooooooooool0GOooool5o`WZ2T[ooooo00?o0000oooo
ooooool02oooool006?ooooo00?o0000ooooooooool0H_ooool6o`WZ2TCooooo00?o0000oooooooo
ool02oooool006?ooooo00?o0000ooooooooool0J?ooool5o`WZ2Soooooo00?o0000ooooooooool0
2oooool006?ooooo00?o0000ooooooooool0KOooool5o`WZ2S[ooooo00?o0000ooooooooool02ooo
ool006?ooooo00?o0000ooooooooool0L_ooool5o`WZ2SGooooo00?o0000ooooooooool02oooool0
06?ooooo00?o0000ooooooooool0Moooool5o`WZ2S3ooooo00?o0000ooooooooool02oooool006?o
oooo00?o0000ooooooooool0O?ooool5o`WZ2R_ooooo00?o0000ooooooooool02oooool006?ooooo
00?o0000ooooooooool0POooool5o`WZ2RKooooo00?o0000ooooooooool02oooool006?ooooo00?o
0000ooooooooool0Q_ooool6o`WZ2R3ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000
ooooooooool0S?ooool5o`WZ2Q_ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000oooo
ooooool0TOooool5o`WZ2QKooooo00?o0000ooooooooool02oooool006?ooooo00?o0000oooooooo
ool0U_ooool5o`WZ2Q7ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0
Voooool5o`WZ2PCooooo0_l9jPX6ooooo`03o`000?oooooooooo00_ooooo001Kooooo`?o2NX:1Ooo
ool00ol0003oooooooooo`2Pooooo`Wo2NX:0oooool00ol0003oooooooooo`0;ooooo`00G?ooool6
o`WZ2P03ooooool0003ooooo0:Kooooo1ol9jPX00ol0003oooooooooo`0;ooooo`003?ooooooo`WZ
2PKo2NX:0_l0000=ooooo`00G?ooool5o`WZ2P;ooooo0_l0002Uooooo`Oo2NX:0_l0000=ooooo`00
Foooool2o`WZ2PKooooo00?o0000ooooooooool0Y?ooool7o`WZ2P03ooooool0003ooooo00cooooo
001Sooooo`03o`000?oooooooooo09oooooo1Ol9jPX01?oooooo2NX:o`WZ2_l9jPX4ooooo`03o`00
0?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo09[ooooo1Ol9jPX5ooooo`03o`WZ2_oo
oooooooo00Gooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0UOooool5
o`WZ2Q;ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0T?ooool5o`WZ
2QOooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0Roooool5o`WZ2Qco
oooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0QOooool6o`WZ2R7ooooo
00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0P?ooool5o`WZ2ROooooo00?o
0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0Noooool5o`WZ2Rcooooo00?o0000
ooooooooool02oooool006?ooooo00?o0000ooooooooool0M_ooool5o`WZ2S7ooooo00?o0000oooo
ooooool02oooool006?ooooo00?o0000ooooooooool0LOooool5o`WZ2SKooooo00?o0000oooooooo
ool02oooool006?ooooo00?o0000ooooooooool0K?ooool5o`WZ2S_ooooo00?o0000ooooooooool0
2oooool006?ooooo00?o0000ooooooooool0Ioooool5o`WZ2T3ooooo00?o0000ooooooooool02ooo
ool006?ooooo00?o0000ooooooooool0HOooool6o`WZ2TGooooo00?o0000ooooooooool02oooool0
06?ooooo00?o0000ooooooooool0G?ooool5o`WZ2T_ooooo00?o0000ooooooooool02oooool006?o
oooo00?o0000ooooooooool0Eoooool5o`WZ2U3ooooo00?o0000ooooooooool02oooool006?ooooo
00?o0000ooooooooool0D_ooool5o`WZ2UGooooo00?o0000ooooooooool02oooool006?ooooo00?o
0000ooooooooool0COooool5o`WZ2U[ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000
ooooooooool0B?ooool5o`WZ2Uoooooo00?o0000ooooooooool02oooool006?ooooo00?o0000oooo
ooooool0@_ooool6o`WZ2VCooooo00?o0000ooooooooool02oooool006?ooooo00?o0000oooooooo
ool0?Oooool5o`WZ2V[ooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0
>?ooool5o`WZ2Voooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0<ooo
ool5o`WZ2WCooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0;_ooool5
o`WZ2WWooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0:Oooool5o`WZ
2Wkooooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool09?ooool5o`WZ2X?o
oooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool07_ooool6o`WZ2XSooooo
00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool06Oooool5o`WZ2Xkooooo00?o
0000ooooooooool02oooool006?ooooo00?o0000ooooooooool05?ooool5o`WZ2Y?ooooo00?o0000
ooooooooool02oooool006?ooooo00?o0000ooooooooool03oooool5o`WZ2YSooooo00?o0000oooo
ooooool02oooool006?ooooo00?o0000ooooooooool02_ooool5o`WZ2Ygooooo00?o0000oooooooo
ool02oooool005_ooooo0ol9jPX5ooooo`03o`000?oooooooooo00Gooooo1Ol9jPZRooooo`03o`00
0?oooooooooo00_ooooo001Looooo`Ko2NX:00Coooooo`000?oooooooooo1Ol9jPZWooooo`03o`00
0?oooooooooo00_ooooo000<oooooe[o2NX:[?ooool00ol0003oooooooooo`0;ooooo`00G?ooool5
o`WZ2P;ooooo0_l0002]ooooo`03o`000?oooooooooo00_ooooo001Kooooo`;o2NX:1_ooool00ol0
003oooooooooo`2/ooooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?oooooooooo0:co
oooo00?o0000ooooooooool02oooool006?ooooo00?o0000ooooooooool0[?ooool00ol0003ooooo
ooooo`0;ooooo`00Hoooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00_ooooo001S
ooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool02oooool006?ooooo00?o0000oooo
ooooool0[?ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oooooooooo`2/ooooo`03
o`000?oooooooooo00_ooooo001Sooooo`;o0000[Oooool00ol0003oooooooooo`0;ooooo`00oooo
oolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {102.625, 0}} -> {-57.2027, -32.4375, \
0.572841, 0.572841}},
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
result = FindABCDMatrix[abcdsystem,{f>0}, ABCDConstruction->Horizontal]\
\>", "Input",
  CellLabel->"In[113]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1 - d2\/f\), \(d1 + d2 - \(d1\ d2\)\/f\)},
            {\(-\(1\/f\)\), \(1 - d1\/f\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[113]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["result/.{d1->0,d2->0}", "Input",
  CellLabel->"In[114]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0"},
            {\(-\(1\/f\)\), "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[114]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[abcdsystem,{f>0}, ABCDConstruction->Horizontal, \
ComplexABCD->True, DecomposeABCD->True]\
\>", "Input",
  CellLabel->"In[115]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(133\ \[ImaginaryI]\)\/\(156250\ \[Pi]\)\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d2"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(\(266\ \[ImaginaryI]\)\/\(125\ a\^2\ \[Pi]\)\)\), 
                      "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(1\/f\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        MatrixForm[ {{1, 0}, {
          Times[ 
            Complex[ 0, 
              Rational[ -133, 156250]], 
            Power[ Pi, -1]], 1}}], 
        MatrixForm[ {{1, 0}, {0, 1}}], 
        MatrixForm[ {{1, d2}, {0, 1}}], 
        MatrixForm[ {{1, 0}, {
          Times[ 
            Complex[ 0, 
              Rational[ -266, 125]], 
            Power[ a, -2], 
            Power[ Pi, -1]], 1}}], 
        MatrixForm[ {{1, 0}, {
          Times[ -1, 
            Power[ f, -1]], 1}}], 
        MatrixForm[ {{1, d1}, {0, 1}}]}, TableDirections -> Row]]], "Output",
  CellLabel->"Out[115]//TableForm=",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[TextData[{
  StyleBox["ABCDOptic", "Input"],
  " now also works with astigmatic systems."
}], "Text",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell["\<\
abcdsystem = {Move[GridOfRays[40],{-d1,-50}],
ABCDOptic[{{{1,0},{{-1/f1,-1/100},1}},{{1,0},{{-1/f2,-1/200},1}}},{a,50}],
Move[Screen[50],{d2,100}]};\
\>", "Input",
  CellLabel->"In[116]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[abcdsystem];", "Input",
  CellLabel->"In[117]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .67912 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0224888 1.02249 -0.150431 1.02249 [
[ 0 0 0 0 ]
[ 1 .67912 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .67912 L
0 .67912 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.17888 .53386 m
.41798 .45986 L
s
.14853 .50712 m
.38966 .43123 L
s
.09281 .3717 m
.33372 .2905 L
s
.10508 .42555 m
.34712 .34601 L
s
.11741 .4797 m
.36059 .40185 L
s
0 g
.43187 .4739 m
.40862 .4504 L
s
.43187 .4739 m
.43187 .4739 L
s
.36399 .2863 m
.36399 .2863 L
s
.36399 .2863 m
.36288 .32413 L
s
.039 .916 .04 r
.41798 .45986 m
.90302 .22901 L
s
0 0 0 r
2 Mabswid
.41798 .45986 Mdot
0 g
.5 Mabswid
.40862 .4504 m
.38486 .42638 L
s
.039 .916 .04 r
.09797 .50665 m
.3444 .42851 L
s
0 g
.36288 .32413 m
.36174 .36264 L
s
.039 .916 .04 r
.38966 .43123 m
.90261 .22842 L
s
0 0 0 r
2 Mabswid
.38966 .43123 Mdot
0 g
.5 Mabswid
.38486 .42638 m
.36059 .40185 L
s
.36174 .36264 m
.36059 .40185 L
s
.039 .916 .04 r
.33372 .2905 m
.89838 .18628 L
s
0 0 0 r
2 Mabswid
.33372 .2905 Mdot
.039 .916 .04 r
.5 Mabswid
.07792 .53447 m
.32768 .45604 L
s
.34712 .34601 m
.90046 .2072 L
s
0 0 0 r
2 Mabswid
.34712 .34601 Mdot
0 g
.5 Mabswid
.36059 .40185 m
.35942 .44177 L
s
.36059 .40185 m
.33578 .37677 L
s
.039 .916 .04 r
.36059 .40185 m
.90255 .22834 L
s
0 0 0 r
2 Mabswid
.36059 .40185 Mdot
0 g
.5 Mabswid
.35942 .44177 m
.35822 .48244 L
s
.33578 .37677 m
.31042 .35113 L
s
.039 .916 .04 r
.3444 .42851 m
.90466 .24968 L
s
0 0 0 r
2 Mabswid
.3444 .42851 Mdot
0 g
.5 Mabswid
.35822 .48244 m
.357 .52386 L
s
.31042 .35113 m
.28449 .32492 L
s
.357 .52386 m
.357 .52386 L
s
.93503 .20368 m
.9466 .24107 L
s
.92132 .16781 m
.93503 .20368 L
s
.9466 .24107 m
.95532 .27778 L
s
.90626 .13564 m
.92132 .16781 L
s
.039 .916 .04 r
.32768 .45604 m
.90677 .27121 L
s
0 0 0 r
2 Mabswid
.32768 .45604 Mdot
0 g
.5 Mabswid
.95532 .27778 m
.96066 .31159 L
s
.28449 .32492 m
.28449 .32492 L
s
.89076 .10918 m
.90626 .13564 L
s
.96066 .31159 m
.96222 .34037 L
s
.96066 .31159 m
.94173 .28448 L
s
.96066 .31159 m
.96066 .31159 L
s
.89076 .10918 m
.89076 .10918 L
s
.89076 .10918 m
.89462 .14814 L
s
.87578 .09021 m
.89076 .10918 L
s
.96222 .34037 m
.95981 .36218 L
s
.94173 .28448 m
.92237 .25673 L
s
.89462 .14814 m
.89854 .18785 L
s
.86228 .08018 m
.87578 .09021 L
s
.95981 .36218 m
.95345 .37539 L
s
.92237 .25673 m
.90255 .22834 L
s
0 0 0 r
2 Mabswid
.89838 .18628 Mdot
0 g
.5 Mabswid
.89854 .18785 m
.90255 .22834 L
s
.85122 .08005 m
.86228 .08018 L
s
0 0 0 r
2 Mabswid
.90046 .2072 Mdot
0 g
.5 Mabswid
.95345 .37539 m
.94345 .37882 L
s
0 0 0 r
2 Mabswid
.90302 .22901 Mdot
.90261 .22842 Mdot
0 g
.5 Mabswid
.90255 .22834 m
.88226 .19927 L
s
0 0 0 r
2 Mabswid
.90255 .22834 Mdot
0 g
.5 Mabswid
.90663 .26962 m
.90255 .22834 L
s
.84345 .09019 m
.85122 .08005 L
s
0 0 0 r
2 Mabswid
.90466 .24968 Mdot
0 g
.5 Mabswid
.94345 .37882 m
.93037 .37187 L
s
.91079 .31173 m
.90663 .26962 L
s
0 0 0 r
2 Mabswid
.90677 .27121 Mdot
0 g
.5 Mabswid
.88226 .19927 m
.86148 .1695 L
s
.83964 .11023 m
.84345 .09019 L
s
.93037 .37187 m
.91504 .35469 L
s
.91079 .31173 m
.91504 .35469 L
s
.86148 .1695 m
.8402 .13901 L
s
.8402 .13901 m
.83964 .11023 L
s
.91504 .35469 m
.91504 .35469 L
s
.91504 .35469 m
.89854 .32824 L
s
.8402 .13901 m
.8402 .13901 L
s
.84519 .1746 m
.8402 .13901 L
s
.89854 .32824 m
.88209 .2943 L
s
.85434 .21439 m
.84519 .1746 L
s
.88209 .2943 m
.86696 .25535 L
s
.86696 .25535 m
.85434 .21439 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{288, 195.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000`b000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00m?ooool5o`0002Oooooo003cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09?ooool00?;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Sooooo`00lOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02;ooooo003aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00?7ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`00lOooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo023ooooo003`ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool07oooool00?3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Noooo
o`00l?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo003`ooooo`03o`00
0?oooooooooo00cooooo0_l0000Oooooo`00l?ooool00ol0003oooooooooo`0<ooooo`;o00007ooo
ool00?3ooooo00?o0000ooooooooool03?ooool00ol0003oooooo`00000Nooooo`00l?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooo000001kooooo003`ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooool000007Oooool00?3ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
o`00000Mooooo`00l?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0001cooooo
003`ooooo`;o00003_ooool01?l0003oooooooooool0000Looooo`00l?ooool00ol0003ooooooooo
o`0=ooooo`05o`000?ooooooooooooooool000006oooool00?3ooooo0_l0000>ooooo`05o`000?oo
ooooooooooooool000006oooool00?7ooooo0_l0000=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06?ooool00?7ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Oooooo003aooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Gooooo`00lOooool01Ol0003ooooooooooooooooo
000000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`00lOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Fooooo`00l_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`00l_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Eooooo`00l_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`00l_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0D
ooooo`00l_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Dooooo`00loooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooooooo`?o2NX:0_l00007ooooo`03o`000?oooooooooo01?ooooo003cooooo`03
o`000?oooooooooo00?ooooo0_l9jPX00ol0003o2NX:o`WZ2P03ooooo`;o00001oooool00ol0003o
ooooooooo`0Cooooo`00loooool00ol0003o2NX:o`WZ2P03o`WZ2P;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo003^ooooo`Go2NX:00?o
ooooo`000?ooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04_ooool00>Wooooo1Ol9jPX6ooooo`03o`000?oooooooooo00Kooooo00Go0000
ooooooooooooooooo`000009ooooo`03o`000?oooooooooo01;ooooo003Sooooo`Ko2NX:2oooool0
0ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003ooooooooo
o`0Aooooo`00g_ooool5o`WZ2Q7ooooo00?o0000ooooooooool01oooool00ol0003oooooo`WZ2P02
o`0000Wooooo00?o0000ooooooooool04Oooool00=Sooooo1_l9jPXGooooo`03o`000?oooooooooo
00Cooooo0ol9jPX01?l0003oooooo`000?l00009ooooo`03o`000?oooooooooo017ooooo003Coooo
o`Go2NX:7Oooool00ol0003oooooooooo`04o`WZ2P?ooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`0@ooooo`00c_ooool5o`WZ2R7ooooo00Co2NX:o`000?l9jP[o2NX:2?ooool0
0ol0003oooooo`00000:ooooo`03o`000?oooooooooo013ooooo0038ooooo`Ko2NX:8_ooool4o`WZ
2P03ooooool0003ooooo00Wooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`0@oooo
o`00`oooool5o`WZ2RCooooo1?l9jPX6ooooo`03o`000?oooooooooo00Sooooo0_l0000;ooooo`03
o`000?oooooooooo00oooooo002mooooo`Ko2NX:9Oooool4o`WZ2P[ooooo00?o0000ooooooooool0
1oooool2o`WZ2P;o00002_ooool00ol0003oooooooooo`0?ooooo`00^?ooool5o`WZ2ROooooo1?l9
jPX>ooooo`03o`000?oooooooooo00Cooooo1Ol9jPX2o`0000[ooooo00?o0000ooooooooool03ooo
ool00;?ooooo1Ol9jPXXooooo`Co2NX:4_ooool01?l0003oooooooooooooool4o`WZ2P04ooooool9
jP[o2NX:ooooo`;o00002_ooool00ol0003oooooooooo`0?ooooo`00[Oooool6o`WZ2RWooooo1?l9
jPXGooooo`03o`000?l9jP[o2NX:00;o2NX:00?oooooo`WZ2_l9jPX00oooool00ol0003oooooo`00
000:ooooo`03o`000?oooooooooo00kooooo002Xooooo`Go2NX::oooool4o`WZ2QSooooo0ol9jPX0
1?l0003o2NX:ooooooooool2o`WZ2PGooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`0>ooooo`00X_ooool6o`WZ2Rcooooo1?l9jPXIooooo`Ko2NX:00Co0000ooooool9jP[o2NX:
1oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00kooooo002Mooooo`Go2NX:
;_ooool4o`WZ2Q[ooooo0ol9jPX00ooooooo2NX:o`WZ2P02ooooo`03o`WZ2_l0003o2NX:00Sooooo
00?o2NX:o`000?l000000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo
002Hooooo`Go2NX:;oooool4o`WZ2Q_ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX2ooooo`;o2NX:
0_ooool00ol0003oooooooooo`03ooooo`?o2NX:00?oooooo`000?l000000oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00kooooo002Booooo`Ko2NX:<?ooool4o`WZ2Qcooooo0ol9
jPX01?oooooo2NX:o`WZ2_l9jPX3ooooo`;o2NX:1?ooool00ol0003oooooooooo`03o`WZ2PGooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo
002=ooooo`Go2NX:<_ooool4o`WZ2Qgooooo0ol9jPX2ooooo`;o2NX:1?ooool2o`WZ2PKooooo00?o
0000o`WZ2_l9jPX02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03Oooool008Oooooo1_l9jPXcooooo`Co2NX:7Oooool4o`WZ2P;ooooo0ol9jPX4
ooooo`;o2NX:1Oooool3o`WZ2P03ooooool0003ooooo00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0022ooooo`Go2NX:=Oooool4o`WZ
2Qkooooo0ol9jPX4ooooo`;o2NX:1Oooool2o`WZ2PCooooo0ol9jPX4ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00gooooo001mooooo`Go2NX:=_ooool4o`WZ2Qoooooo0ol9jPX4ooooo`?o2NX:1Oooool2o`WZ2P?o
oooo0ol9jPX7ooooo`03o`000?oooooooooo00Oooooo0_l00006ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03Oooool007Oooooo1_l9jPXgooooo`Co2NX:8?ooool3o`WZ2PGooooo
0_l9jPX6ooooo`;o2NX:0_ooool3o`WZ2P_ooooo00?o0000ooooooooool01Oooool00ol9jP[o0000
o`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool007;ooooo1Ol9
jPXjooooo`?o2NX:8Oooool3o`WZ2PGooooo0ol9jPX6ooooo`;o2NX:00Coooooo`WZ2_l9jP[o2NX:
3_ooool00ol0003oooooooooo`02ooooo`?o2NX:00?oooooo`000?ooool01oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00cooooo001/ooooo`Ko2NX:>oooool4o`WZ2R7ooooo0ol9
jPX6ooooo`;o2NX:1oooool5o`WZ2Q7ooooo00?o0000ooooool9jPX00_l9jPX4ooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`00000>ooooo`00Ioooool5o`WZ2Sgooooo1?l9
jPXRooooo`?o2NX:1_ooool3o`WZ2POooooo1?l9jPXCooooo`;o2NX:00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000kooooo001Rooooo`Go2NX:00?o
ooooo`000?ooool0>oooool4o`WZ2R?ooooo0ol9jPX7ooooo`;o2NX:1oooool3o`WZ2QCooooo0ol9
jPX2ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool0000>ooooo`00G_ooool01?l9jP[o0000o`000?l9jPX6ooooo`03o`000?oooooooooo03Kooooo
1?l9jPXTooooo`?o2NX:1oooool3o`WZ2PKooooo0ol9jPXDooooo`?o2NX:1Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00003Oooool005_ooooo
0ol9jPX00ooooooo0000o`000007ooooo`03o`000?oooooooooo03;ooooo1?l9jPXUooooo`?o2NX:
2?ooool2o`WZ2PKooooo1?l9jPXCooooo`?o2NX:2Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooool000003Oooool005Sooooo0ol9jPX=ooooo`03o`000?oo
oooooooo02kooooo1?l9jPXUooooo`Co2NX:2?ooool3o`WZ2PGooooo1Ol9jPXBooooo`?o2NX:3?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000003Ooo
ool005Gooooo0ol9jPX@ooooo`03o`000?oooooooooo02[ooooo1?l9jPXVooooo`?o2NX:2_ooool2
o`WZ2PGooooo0ol9jPX00ooooooo2NX:o`WZ2P0@ooooo`Co2NX:4?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`00D_ooool3o`WZ2Q?ooooo00?o0000oooo
ooooool09_ooool4o`WZ2ROooooo0ol9jPX:ooooo`?o2NX:1?ooool3o`WZ2P;ooooo0_l9jPX?oooo
o`?o2NX:5?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo0_l0000=oooo
o`00Coooool3o`WZ2QKooooo00?o0000ooooooooool08_ooool4o`WZ2RSooooo0ol9jPX:ooooo`?o
2NX:1?ooool3o`WZ2P?ooooo0_l9jPX>ooooo`?o2NX:6?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00[ooooo0_l0000<ooooo`00C?ooool3o`WZ2QWooooo00?o0000ooooooooool0
7_ooool4o`WZ2RWooooo0ol9jPX;ooooo`;o2NX:1?ooool3o`WZ2PCooooo0_l9jPX=ooooo`?o2NX:
6oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool004Wooooo0ol9jPXLooooo`03o`000?oooooooooo01[ooooo1?l9jPXZooooo`?o2NX:2ooo
ool3o`WZ2P?ooooo0ol9jPX5ooooo`;o2NX:3?ooool3o`WZ2Qoooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0016ooooo`?o2NX:7oooool0
0ol0003oooooooooo`0Fooooo`Co2NX::oooool3o`WZ2Pcooooo0_l9jPX3ooooo`?o2NX:1_ooool2
o`WZ2P_ooooo0ol9jPXRooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`00@oooool3o`WZ2R;ooooo00?o0000ooooooooool04_ooool4o`WZ
2Rcooooo0ol9jPX<ooooo`?o2NX:00?oooooo`WZ2_l9jPX00_l9jPX7ooooo`;o2NX:2_ooool3o`WZ
2RKooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo0010ooooo`?o2NX:3_ooool2o`0001Gooooo00?o0000ooooooooool03_ooool4o`WZ2Rgo
oooo0ol9jPX=ooooo`;o2NX:00Coooooo`WZ2_l9jP[o2NX:2?ooool3o`WZ2PSooooo1?l9jPXYoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`00?Oooool3o`WZ2Q;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`Co
2NX:;_ooool3o`WZ2Pgooooo1_l9jPX9ooooo`;o2NX:2?ooool3o`WZ2Rkooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?oooooooooo00[ooooo000jooooo`?o2NX:5_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00Kooooo1?l9jPX^ooooo`Co2NX:3_ooool5o`WZ2P[o
oooo0_l9jPX7ooooo`?o2NX:<Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooo
ooooool02_ooool003Oooooo0ol9jPXJooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool00_ooool4o`WZ2Roooooo0ol9jPX?ooooo`Go2NX:2oooool2o`WZ2PKooooo0ol9jPXeooooo`05
o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0:ooooo`00=?ooool3o`WZ2Qko
oooo00?o0000ooooooooool04?ooool00ol0003o2NX:o`WZ2P02o`WZ2S3ooooo0ol9jPX@ooooo`Co
2NX:3?ooool2o`WZ2PGooooo0ol9jPXiooooo`04o`000?ooooooooooo`0000cooooo00?o0000oooo
ooooool02_ooool0037ooooo0ol9jPXRooooo`03o`000?oooooooooo00cooooo1?l9jPXaooooo`?o
2NX:4?ooool4o`WZ2Pgooooo0_l9jPX4ooooo`?o2NX:??ooool01?l0003oooooooooool0000<oooo
o`03o`000?oooooooooo00[ooooo000^ooooo`?o2NX:9_ooool00ol0003oooooooooo`08ooooo`03
o`WZ2_l0003o000000;ooooo00?o0000ooooooooool0;Oooool3o`WZ2Q7ooooo0ol9jPX>ooooo`;o
2NX:0oooool3o`WZ2T3ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0:ooooo`00
:oooool3o`WZ2R[ooooo00?o0000ooooooooool01?ooool3o`WZ2P03ooooool0003o000000;ooooo
00?o0000ooooooooool0:_ooool3o`WZ2Q7ooooo0ol9jPX?ooooo`;o2NX:0_ooool3o`WZ2T?ooooo
00?o0000ooooool000003?ooool00ol0003oooooooooo`0:ooooo`00:?ooool3o`WZ2Rkooooo00?o
0000ooooooooool00ol9jPX8ooooo`03o`000?oooooooooo02Oooooo0ol9jPXAooooo`?o2NX:4?oo
ool6o`WZ2TOooooo0_l0000<ooooo`03o`000?oooooooooo00[ooooo000Uooooo`?o2NX:<Oooool0
0ol9jP[o0000o`WZ2P0;ooooo`03o`000?oooooooooo02Cooooo0ol9jPX@ooooo`Co2NX:4Oooool4
o`WZ2Tcooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`008_ooool3o`WZ
2S7ooooo0ol9jPX2ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`WZ
2Q3ooooo1Ol9jPXAooooo`?o2NX:D?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo000Oooooo`?o2NX:<Oooool3o`WZ2PKooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Nooooo`?o2NX:4?ooool5o`WZ2Q7ooooo0ol9jPYDooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02_ooool001cooooo0ol9jPXaooooo`?o2NX:2_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01[ooooo1?l9jPX@ooooo`Ko2NX:4?ooool3o`WZ2USooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`006_ooool2o`WZ2S7ooooo0ol9
jPX>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool3o`WZ2Q7ooooo0ol9
jPX00ooooooo2NX:o`WZ2P0@ooooo`Co2NX:Foooool2o`0000Kooooo00?o0000ooooooooool02ooo
ool004[ooooo0ol9jPXBooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05?ooool3
o`WZ2Q7ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX?ooooo`Go2NX:Goooool2o`0000;ooooo0_l0
000>ooooo`00Aoooool3o`WZ2QKooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0A
ooooo`?o2NX:4Oooool3o`WZ2P;ooooo0_l9jPX>ooooo`Co2NX:00?oooooo`WZ2_l9jPX0Hoooool2
o`00013ooooo0014ooooo`?o2NX:6_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00kooooo0ol9jPXAooooo`?o2NX:0_ooool3o`WZ2Pgooooo0ol9jPX3ooooo`;o2NX:Moooool0047o
oooo0ol9jPXNooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool3o`WZ2Q7o
oooo0ol9jPX3ooooo`;o2NX:3Oooool3o`WZ2PCooooo0_l9jPYiooooo`00?_ooool3o`WZ2R;ooooo
00Go0000ooooooooooooooooo`00000:ooooo`?o2NX:4Oooool3o`WZ2P?ooooo0ol9jPX<ooooo`?o
2NX:1Oooool2o`WZ2W_ooooo000kooooo`?o2NX:9_ooool01?l0003oooooooooool00007ooooo`?o
2NX:4Oooool3o`WZ2PCooooo0_l9jPX<ooooo`?o2NX:1_ooool2o`WZ2Wgooooo000hooooo`?o2NX:
:_ooool00ol0003oooooo`000004ooooo`?o2NX:4?ooool4o`WZ2PCooooo0ol9jPX;ooooo`?o2NX:
1oooool2o`WZ2Woooooo000eooooo`?o2NX:;_ooool2o`000004ooooool9jP[o2NX:o`WZ2Q3ooooo
0ol9jPX6ooooo`;o2NX:2oooool3o`WZ2PSooooo0_l9jPZ1ooooo`00<_ooool3o`WZ2S3ooooo0_l9
jPX2o`00013ooooo0ol9jPX6ooooo`?o2NX:2_ooool3o`WZ2PSooooo0ol9jPZ3ooooo`00;oooool3
o`WZ2S3ooooo0ol9jPX2ooooo`;o00003Oooool3o`WZ2PKooooo0ol9jPX9ooooo`Co2NX:2Oooool2
o`WZ2XKooooo000/ooooo`?o2NX:<?ooool3o`WZ2PGooooo00?o0000ooooool000002Oooool3o`WZ
2POooooo0_l9jPX9ooooo`?o2NX:2oooool2o`WZ2XSooooo000Yooooo`?o2NX:<?ooool3o`WZ2PSo
oooo00Co0000oooooooooooo00001Oooool3o`WZ2POooooo0ol9jPX8ooooo`?o2NX:3?ooool2o`WZ
2X[ooooo000Vooooo`?o2NX:<?ooool3o`WZ2P_ooooo00Ko0000ooooooooooooooooo`000?ooool3
o`WZ2PSooooo0_l9jPX8ooooo`?o2NX:3Oooool2o`WZ2Xcooooo000Sooooo`?o2NX:;oooool4o`WZ
2Pkooooo00?o0000ooooooooool00ol9jPX8ooooo`?o2NX:1oooool3o`WZ2Pkooooo0_l9jPZ>oooo
o`008?ooool3o`WZ2Roooooo0ol9jPXBooooo`?o2NX:0oooool00ol0003oooooooooo`03ooooo`;o
2NX:1oooool3o`WZ2Poooooo0_l9jPZ@ooooo`007_ooool2o`WZ2Roooooo0ol9jPX@ooooo`;o0000
0ol9jPX00ol0003oooooooooo`04ooooo`03o`000?oooooo2NX:00;o2NX:1_ooool3o`WZ2Q3ooooo
0_l9jPZBooooo`00C?ooool3o`WZ2Q7ooooo0_l9jPX2o`0000?ooooo00?o0000ooooooooool00ooo
ool2o`WZ2P;o00001?ooool4o`WZ2Q7ooooo0_l9jPZDooooo`00BOooool3o`WZ2Q7ooooo0ol9jPX7
ooooo`03o`000?oooooooooo00?o2NX:0_ooool2o`000004ooooool9jP[o2NX:o`WZ2Q?ooooo0_l9
jPZFooooo`00A_ooool3o`WZ2Q7ooooo0ol9jPX:ooooo`03o`000?l9jP[o2NX:00Gooooo0ol9jPXD
ooooo`;o2NX:V?ooool004;ooooo1?l9jPXAooooo`?o2NX:2_ooool3o`WZ2P03o`000?oooooooooo
00;ooooo0ol9jPX3ooooo`03o`000?oooooooooo00kooooo0ol9jPZJooooo`00?oooool3o`WZ2Q;o
oooo0ol9jPX:ooooo`?o2NX:0oooool00ol0003oooooo`WZ2P02o`WZ2POooooo00?o0000oooooooo
ool02oooool2o`WZ2Ygooooo000looooo`?o2NX:4Oooool4o`WZ2P[ooooo0ol9jPX5ooooo`?o2NX:
2oooool00ol0003oooooooooo`08ooooo`;o2NX:Woooool003Wooooo0ol9jPXAooooo`?o2NX:2ooo
ool3o`WZ2PGooooo0ol9jPX00ooooooo0000ooooo`0<ooooo`03o`000?oooooooooo00Gooooo0_l9
jPZQooooo`00=_ooool3o`WZ2Q7ooooo0ol9jPX:ooooo`Co2NX:0_ooool2o`000004ooooool9jP[o
2NX:o`WZ2PCooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`;o2NX:Xooo
ool003;ooooo1?l9jPXAooooo`?o2NX:2_ooool3o`WZ2PGooooo00Co2NX:o`000?l0003o2NX:1ooo
ool00ol0003oooooooooo`0<ooooo`?o00000_l9jPZUooooo`00;oooool3o`WZ2Q;ooooo0ol9jPX:
ooooo`?o2NX:1Oooool3o`WZ2P_ooooo00?o0000ooooooooool03?ooool00ol9jP[o0000o`00002W
ooooo`00;?ooool3o`WZ2Q;ooooo0ol9jPX:ooooo`?o2NX:1Oooool3o`WZ2Pgooooo00?o0000oooo
ooooool02_ooool3o`WZ2P;ooooo00?o0000ooooooooool0YOooool002Wooooo0ol9jPXAooooo`Co
2NX:2_ooool3o`WZ2PGooooo0ol9jPX@ooooo`03o`000?oooooooooo00Oooooo0ol9jPX6ooooo`03
o`000?oooooooooo0:Cooooo000Vooooo`?o2NX:4Oooool3o`WZ2P_ooooo0ol9jPX4ooooo`Co2NX:
4oooool00ol0003oooooooooo`03ooooo`Co2NX:2_ooool00ol0003oooooo`00002Sooooo`008ooo
ool3o`WZ2Q7ooooo0ol9jPX;ooooo`?o2NX:1?ooool3o`WZ2QOooooo00?o0000ooooooooool00ol9
jPX?ooooo`03o`000?oooooooooo0:;ooooo000Qooooo`;o2NX:4Oooool3o`WZ2P_ooooo0ol9jPX4
ooooo`?o2NX:6_ooool00ol0003o2NX:o`WZ2P2gooooo`00<Oooool3o`WZ2P[ooooo1?l9jPX3oooo
o`Co2NX:6_ooool3o`WZ2P03o`000?oooooooooo0;Oooooo000]ooooo`Co2NX:2_ooool3o`WZ2PCo
oooo0ol9jPXJooooo`Co2NX:0oooool00ol0003oooooooooo`2gooooo`00:_ooool3o`WZ2P_ooooo
0ol9jPX4ooooo`?o2NX:6_ooool3o`WZ2POooooo00?o0000ooooooooool0]oooool002Oooooo0ol9
jPX;ooooo`?o2NX:1?ooool3o`WZ2Q[ooooo0ol9jPX:ooooo`03o`000?oooooooooo0;Oooooo000T
ooooo`?o2NX:2oooool3o`WZ2P?ooooo1?l9jPXIooooo`Co2NX:3Oooool00ol0003oooooooooo`2g
ooooo`008Oooool3o`WZ2P_ooooo0ol9jPX3ooooo`?o2NX:6_ooool3o`WZ2Q7ooooo00?o0000oooo
ooooool0]oooool001kooooo0ol9jPX;ooooo`?o2NX:0oooool3o`WZ2Q[ooooo0ol9jPXDooooo`03
o`000?oooooooooo0;Oooooo000Looooo`;o2NX:3?ooool2o`WZ2P?ooooo0ol9jPXJooooo`?o2NX:
5oooool00ol0003oooooooooo`2gooooo`00:oooool4o`WZ2QWooooo1?l9jPXJooooo`03o`000?oo
oooooooo0;Oooooo000Xooooo`?o2NX:6_ooool3o`WZ2Qkooooo00?o0000ooooooooool0]oooool0
02Gooooo0ol9jPXJooooo`?o2NX:8Oooool00ol0003oooooooooo`2gooooo`008Oooool4o`WZ2QWo
oooo1?l9jPXTooooo`03o`000?oooooooooo0;Oooooo000Nooooo`?o2NX:6_ooool3o`WZ2RSooooo
00?o0000ooooooooool0]oooool001_ooooo0ol9jPXJooooo`?o2NX:iOooool001Sooooo0ol9jPXJ
ooooo`?o2NX:j?ooool001Kooooo0_l9jPXKooooo`;o2NX:joooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {194.562, 0}} -> {0.0211223, 0.147119, \
0.00341376, 0.00341376}},
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["result = FindABCDMatrix[abcdsystem,{f>0}]", "Input",
  CellLabel->"In[118]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1 - d2\/f1\), \(d1 + d2 - \(d1\ d2\)\/f1\)},
                    {\(-\(1\/f1\)\), \(1 - d1\/f1\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1 - d2\/f2\), \(d1 + d2 - \(d1\ d2\)\/f2\)},
                    {\(-\(1\/f2\)\), \(1 - d1\/f2\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      TableForm[ {
        MatrixForm[ {{
          Plus[ 1, 
            Times[ -1, d2, 
              Power[ f1, -1]]], 
          Plus[ d1, d2, 
            Times[ -1, d1, d2, 
              Power[ f1, -1]]]}, {
          Times[ -1, 
            Power[ f1, -1]], 
          Plus[ 1, 
            Times[ -1, d1, 
              Power[ f1, -1]]]}}], 
        MatrixForm[ {{
          Plus[ 1, 
            Times[ -1, d2, 
              Power[ f2, -1]]], 
          Plus[ d1, d2, 
            Times[ -1, d1, d2, 
              Power[ f2, -1]]]}, {
          Times[ -1, 
            Power[ f2, -1]], 
          Plus[ 1, 
            Times[ -1, d1, 
              Power[ f2, -1]]]}}]}, TableAlignments -> Center]]], "Output",
  CellLabel->"Out[118]//TableForm=",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["result/.{d1->0,d2->0}", "Input",
  CellLabel->"In[119]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(1\/f1\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(1\/f2\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      TableForm[ {
        MatrixForm[ {{1, 0}, {
          Times[ -1, 
            Power[ f1, -1]], 1}}], 
        MatrixForm[ {{1, 0}, {
          Times[ -1, 
            Power[ f2, -1]], 1}}]}, TableAlignments -> Center]]], "Output",
  CellLabel->"Out[119]//TableForm=",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG3."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.6 Grating Examples", "Subsection",
  CellTags->{"AOG0.", "3.6", "AOG3.", "AOG3.6"}],

Cell[CellGroupData[{

Cell["?Grating", "Input",
  CellLabel->"In[120]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],

Cell[BoxData[
    \("Grating[gratingfunction, aperture, label, options], \
Grating[gratingfunction, aperture, thickness, label, options], and \
Grating[surfacefunction, gratingfunction, aperture, thickness, label, \
options] denote a diffractive component that splits incoming rays into \
multiple diffracted orders according to the gratingfunction parameter and the \
DiffractedOrders option.\n \nThe thickness parameter refers to the thickness \
dimension of the grating substrate. If no thickness value is given, the \
component is assumed to have no substrate. According to the GratingThickness \
option, the physical grating material may also have a physical thickness \
within a separate refractive emulsion layer. Note that the total thickness of \
the Grating is given by the substrate thickness in addition to the \
GratingThickness parameter. When DoubleSubstrate -> True is specified, the \
grating is sandwiched between two substrates of equal thickness. (Note that \
DoubleSubstrate only applies to flat-surfaced gratings).\n \nThe \
gratingfunction parameter specifies a grating vector either as a \
one-dimensional value, Gy, a two-dimensional list of values, {Gy, Gz}, a \
three-dimensional list of values, {Gx, Gy, Gz}, or a three-dimensional \
function, Function[{s,t}, {Gx[s,t], Gy[s,t], Gz[s,t]}], in which {Gx, Gy, Gz} \
specify the indicated grating directions with the grating surface initially \
oriented parallel to the y-z plane. These vector quantities have units of \
spatial frequency and are given in line pairs per millimeter. A single number \
used in the grating parameter indicates a uniformly distributed grating \
vector pointing in the direction of the y axis. A list of two numbers \
designates a uniformly distributed grating vector whose direction lies within \
the surface plane.\n \nIf you compare results with calculations by hand, \
please keep track of the correspondence of the options VacuumFrequency and \
GratingMedium. Note that VacuumFrequency->False assumes the grating function \
has already incorporated the refractive index of the grating material. \
However, if VacuumFrequency->False is specified, then Rayica will include an \
additional refractive index factor to the grating magnitude.\n \nThe \
user-named label parameter is optional and can be omitted. When it is \
present, its text content is used to identify the object in both the rendered \
graphics and the output cell expression. When it is omitted, Rayica uses the \
default setting of the Labels option with the rendered graphics.\n \nSee \
also: GratingTheory, EfficiencyFunction, GratingMirror, \
SphericalGratingMirror, and Diffraction."\)], "Print",
  CellTags->{"Info3312115087-1929230", "AOG3.", "AOG3.6"}]
}, Open  ]],

Cell["\<\
gratingsystem = {Move[SingleRay[SymbolicWaveLength->\[Lambda], \
IntrinsicMedium->Vacuum],{-d1,-50}],
Grating[{g,200},50,GratingMedium->IntrinsicMedium,GratingThickness->0,\
ComponentMedium->IntrinsicMedium],
Move[Screen[50],{d2,100}]};\
\>", "Input",
  CellLabel->"In[13]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],

Cell[CellGroupData[{

Cell["sol = AnalyzeSystem[gratingsystem,PlotType->TopView];", "Input",
  CellLabel->"In[14]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.00634921 0.192698 0.00634921 [
[.34127 .00857 -5.59375 -6 ]
[.34127 .00857 5.59375 6 ]
[.97619 .00857 -4.75 -6 ]
[.97619 .00857 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .36 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.34127 .03397 m
.34127 .03397 L
.34127 .08688 L
.34127 .08688 L
.34127 .03397 L
F
.34127 .08688 m
.34127 .08688 L
.34127 .13979 L
.34127 .13979 L
.34127 .08688 L
F
.34127 .13979 m
.34127 .13979 L
.34127 .1927 L
.34127 .1927 L
.34127 .13979 L
F
.34127 .1927 m
.34127 .1927 L
.34127 .24561 L
.34127 .24561 L
.34127 .1927 L
F
.34127 .24561 m
.34127 .24561 L
.34127 .29852 L
.34127 .29852 L
.34127 .24561 L
F
.34127 .29852 m
.34127 .29852 L
.34127 .35143 L
.34127 .35143 L
.34127 .29852 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.34127 .03397 m
.34127 .08688 L
.34127 .13979 L
.34127 .1927 L
.34127 .24561 L
.34127 .29852 L
.34127 .35143 L
.34127 .35143 L
.34127 .29852 L
.34127 .24561 L
.34127 .1927 L
.34127 .13979 L
.34127 .08688 L
.34127 .03397 L
.34127 .03397 L
s
.5 g
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
F
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
F
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
F
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
F
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
F
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
F
0 g
.34127 .1927 m
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
.34127 .1927 L
s
.34127 .35143 m
.34127 .34602 L
.34127 .33016 L
.34127 .30494 L
.34127 .27206 L
.34127 .23378 L
.34127 .1927 L
.34127 .15162 L
.34127 .11333 L
.34127 .08046 L
.34127 .05523 L
.34127 .03938 L
.34127 .03397 L
.34127 .03938 L
.34127 .05523 L
.34127 .08046 L
.34127 .11333 L
.34127 .15162 L
.34127 .1927 L
.34127 .23378 L
.34127 .27206 L
.34127 .30494 L
.34127 .33016 L
.34127 .34602 L
.34127 .35143 L
s
.97619 .03397 m
.97619 .08688 L
.97619 .13979 L
.97619 .1927 L
.97619 .24561 L
.97619 .29852 L
.97619 .35143 L
.97619 .35143 L
.97619 .29852 L
.97619 .24561 L
.97619 .1927 L
.97619 .13979 L
.97619 .08688 L
.97619 .03397 L
.97619 .03397 L
s
.97619 .1927 m
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
.97619 .1927 L
s
.97619 .35143 m
.97619 .34602 L
.97619 .33016 L
.97619 .30494 L
.97619 .27206 L
.97619 .23378 L
.97619 .1927 L
.97619 .15162 L
.97619 .11333 L
.97619 .08046 L
.97619 .05523 L
.97619 .03938 L
.97619 .03397 L
.97619 .03938 L
.97619 .05523 L
.97619 .08046 L
.97619 .11333 L
.97619 .15162 L
.97619 .1927 L
.97619 .23378 L
.97619 .27206 L
.97619 .30494 L
.97619 .33016 L
.97619 .34602 L
.97619 .35143 L
s
.039 .916 .04 r
.02381 .1927 m
.34127 .1927 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.34127 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .1927 m
.97619 .1927 L
s
% Start of user PostScript
0 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1927 Mdot
.039 .916 .04 r
.5 Mabswid
.34127 .1927 m
.97619 .26064 L
s
% Start of user PostScript
0 0 100. 10.7007 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .26064 Mdot
gsave
.34127 .00857 -66.5938 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
70.188 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00857 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .36 L
0 .36 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{648, 233.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:80000jB000`400?l00000o`00003ooooooooo
oooooh[ooooo003oooooooooooooR_ooool00?oooooooooooon:ooooo`00oooooooooooooh[ooooo
003Kooooo`?o0000oooooonGooooo`?o00004Oooool00=[ooooo00Go0000ooooooooooooooooo`00
003ooooooiKooooo00Co0000oooooooooooo00004?ooool00=Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3ooooooiOooooo00?o0000ooooooooool03_ooool00=Wooooo00Co0000
oooooooooooooooo0ol0003ooooooiKooooo0_l0000Aooooo`00fOooool00ol0003oooooooooo`3o
oooooiWooooo00?o0000ooooooooool04Oooool00=[ooooo00?o0000ooooooooool00_l0003ooooo
oiKooooo00Co0000oooooooooooo00004?ooool00=_ooooo0_l000000ooooooo0000ooooo`3ooooo
oiKooooo0ol0000@ooooo`00oooooooooooooh[ooooo003oooooooooooooR_ooool00?oooooooooo
oon:ooooo`00oooooooooooooh[ooooo003oooooooooooooR_ooool00?oooooooooooon:ooooo`00
oooooooooooooh[ooooo003oooooooooooooR_ooool00?oooooooooooon:ooooo`00oooooooooooo
oh[ooooo003oooooooooooooR_ooool00=gooooo00?o0000ooooooooool0oooooonGooooo`03o`00
0?oooooooooo00oooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003ooooooooo
o`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool0
0=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03
o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003ooooo
ooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooo
oonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool0
0ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000oooo
ooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013o
oooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOoo
ool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000
ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo
0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKo
oooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`00
0?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003ooooooooo
o`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool0
0=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03
o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003ooooo
ooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooo
oonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool0
0ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000oooo
ooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013o
oooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOoo
ool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000
ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo
0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKo
oooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`00
0?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003ooooooooo
o`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool0
0=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03
o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003ooooo
ooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooo
oonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool0
0ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000oooo
ooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013o
oooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOoo
ool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000
ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo
0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKo
oooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`00
0?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003ooooooooo
o`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool0
0=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03
o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003ooooo
ooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooo
oonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool0
0ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000oooo
ooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013o
oooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOoo
ool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000
ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo
0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKo
oooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`00
0?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003ooooooooo
o`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool0
0=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03
o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003ooooo
ooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooo
oonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool0
0ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000oooo
ooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013o
oooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOoo
ool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000
ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo
0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKo
oooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`00
0?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003ooooooooo
o`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool0
0=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03
o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003ooooo
ooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooo
oonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool0
0ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000oooo
ooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013o
oooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOoo
ool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000
ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo
0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKo
oooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`00
0?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003ooooooooo
o`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool0
0=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03
o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003ooooo
ooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooo
oonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool0
0ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000oooo
ooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013o
oooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00eOoo
ool3o`WZ2PGooooo00?o0000ooooooooool0oooooon>ooooo`?o2NX:1Oooool00ol0003ooooooooo
o`0@ooooo`00e_ooool6o`WZ2P;o0000oooooonAooooo`Ko2NX:00?oooooo`000?l000004Oooool0
017ooooobol9jPX00ol0003o2NX:o`WZ2P3oo`WZ2YOo2NX:0_l0000Aooooo`00e_ooool5o`WZ2P;o
oooo00?o0000ooooooooool00oooool9o`WZ2_ooooooPoooool5o`WZ2P;ooooo00?o0000oooooooo
ool04?ooool00=Gooooo0_l9jPX6ooooo`03o`000?oooooooooo00cooooo2Ol9jP[oooooogWooooo
0_l9jPX6ooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo01Gooooo2Ol9
jP[oooooogSooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool07_ooool:
o`WZ2_ooooooK_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`0Xoooo
o`Wo2NX:oooooomUooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo037o
oooo2Ol9jP[ooooooecooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0
>_ooool:o`WZ2_ooooooD_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003ooooooooo
o`14ooooo`Wo2NX:oooooom9ooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooo
oooo04gooooo2Ol9jP[ooooood3ooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000oooo
ooooool0E_ooool9o`WZ2_oooooo=oooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003o
ooooooooo`1Oooooo`[o2NX:ooooool]ooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`00
0?oooooooooo06Wooooo2Ol9jP[oooooobCooooo00?o0000ooooooooool04?ooool00=gooooo00?o
0000ooooooooool0L_ooool9o`WZ2_oooooo6oooool00ol0003oooooooooo`0@ooooo`00gOooool0
0ol0003oooooooooo`1kooooo`Wo2NX:oooooolBooooo`03o`000?oooooooooo013ooooo003Moooo
o`03o`000?oooooooooo08Cooooo2_l9jP[oooooo`Sooooo00?o0000ooooooooool04?ooool00=go
oooo00?o0000ooooooooool0S_ooool9o`WZ2_kooooo00?o0000ooooooooool04?ooool00=gooooo
00?o0000ooooooooool0Uoooool9o`WZ2_Gooooo00?o0000ooooooooool04?ooool00=gooooo00?o
0000ooooooooool0X?ooool:o`WZ2^_ooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000
ooooooooool0Z_ooool9o`WZ2^;ooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000oooo
ooooool0/oooool9o`WZ2]Wooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000oooooooo
ool0_?ooool9o`WZ2]3ooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0
aOooool:o`WZ2/Kooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0cooo
ool9o`WZ2[gooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0f?ooool9
o`WZ2[Cooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0hOooool9o`WZ
2Z_ooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0j_ooool:o`WZ2Z7o
oooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0m?ooool9o`WZ2YSooooo
00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oOooool9o`WZ2Xoooooo00?o
0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0ooooool7ooooo`[o2NX:QOooool0
0ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooa7ooooo2Ol9jPYloooo
o`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?oooooo6_ooool9o`WZ2W?o
oooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooolSooooo`Wo2NX:
J_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3oooooobcooooo2_l9
jPYPooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?oooooo=_ooool9
o`WZ2UOooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooolooooo
o`Wo2NX:C_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3oooooodSo
oooo2Ol9jPY5ooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?oooooo
DOooool:o`WZ2S_ooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooo
oomKooooo`Wo2NX:<_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3o
ooooofCooooo2Ol9jPXYooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo
0?ooooooKOooool:o`WZ2Qoooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000oooooooo
ool0oooooomgooooo`Wo2NX:3oooool2o`WZ2PGooooo00?o0000ooooooooool04?ooool00=gooooo
00?o0000ooooooooool0oooooon0ooooo`Wo2NX:1_ooool5o`WZ2P;ooooo00?o0000ooooooooool0
4?ooool00=gooooo00?o0000ooooooooool0oooooon9ooooo`go2NX:0_l0000Aooooo`00gOooool0
0ol0003oooooooooo`3oooooohoooooo1ol9jPX2o`00017ooooo003Mooooo`03o`000?oooooooooo
0?ooooooS_ooool4o`WZ2PCooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000oooooooo
ool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?oooooo
U_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o
0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooo
oooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@oooo
o`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo
00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oo
oooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3o
oooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFoooo
o`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003o
ooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool0
4?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003M
ooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0
003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000oooooooo
ool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?oooooo
U_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o
0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooo
oooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@oooo
o`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo
00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oo
oooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3o
oooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFoooo
o`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003o
ooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool0
4?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003M
ooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0
003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000oooooooo
ool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?oooooo
U_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o
0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooo
oooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@oooo
o`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo
00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oo
oooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3o
oooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFoooo
o`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003o
ooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool0
4?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003M
ooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0
003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000oooooooo
ool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?oooooo
U_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o
0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFooooo`03o`000?oooooo
oooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003oooooooooo`0@oooo
o`00gOooool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool04?ooool00=gooooo
00?o0000ooooooooool0oooooonFooooo`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oo
oooooooo0?ooooooU_ooool00ol0003oooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3o
oooooiKooooo00?o0000ooooooooool04?ooool00=gooooo00?o0000ooooooooool0oooooonFoooo
o`03o`000?oooooooooo013ooooo003Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003o
ooooooooo`0@ooooo`00gOooool00ol0003oooooooooo`3ooooooiKooooo0_l0000Aooooo`00oooo
oooooooooh[ooooo003oooooooooooooR_ooool00?oooooooooooon:ooooo`00oooooooooooooh[o
oooo003oooooooooooooR_ooool00001\
\>"],
  ImageRangeCache->{{{0, 647}, {232.125, 0}} -> {-54.1862, -30.4691, \
0.244779, 0.244779}},
  CellTags->{"AOG3.", "AOG3.6", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReadRays[sol,RayEnd]", "Input",
  CellLabel->"In[124]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],

Cell[BoxData[
    \({{0.`, 0.`, 0.`}, {100.`, 0.`, 0.`}, {100.00000000000001`, 
        10.700743754760477`, 0.`}}\)], "Output",
  CellLabel->"Out[124]=",
  CellTags->{"AOG3.", "AOG3.6", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
result = FindABCDMatrix[gratingsystem, \
{\[Lambda]>0,g>0,d1>0,t>0,d2>0},MatrixForm->True, \
SymbolicRefractiveModels->{Vacuum->1}, ABCDConstruction->Horizontal, \
FilterTrace->False]\
\>", "Input",
  CellLabel->"In[11]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", \(d1 + d2\)},
                  {"0", "1"}
                  }], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]], "}"}], ",", 
        RowBox[{"{", 
          TagBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(-\(\@\(1000000 - g\^2\ \[Lambda]\^2\)\/1000\)\), \(\(-\(\
\(d1\ \@\(1000000 - g\^2\ \[Lambda]\^2\)\)\/1000\)\) + \(1000000\ \
d2\)\/\(\(-1000000\) + g\^2\ \[Lambda]\^2\)\)},
                  {"0", \(1000\/\@\(1000000 - g\^2\ \[Lambda]\^2\)\)}
                  }], "\[NoBreak]", ")"}],
            Function[ BoxForm`e$, 
              MatrixForm[ BoxForm`e$]]], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[11]=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["result/.{d1->0,d2->0}", "Input",
  CellLabel->"In[10]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-\(\@\(1000000 - g\^2\ \[Lambda]\^2\)\/1000\)\), "0"},
            {"0", \(1000\/\@\(1000000 - g\^2\ \[Lambda]\^2\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[10]//MatrixForm=",
  CellTags->{"AOG3.", "AOG3.6", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
result = FindABCDMatrix[gratingsystem,{g>0,\[Lambda]>0,d1>0,t>0,d2>0},\
MatrixForm->True, SymbolicRefractiveModels->{Vacuum->1}, \
ABCDConstruction->Horizontal, FilterTrace->True]\
\>", "Input",
  CellLabel->"In[12]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(d1 + d2\)},
            {"0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[12]//MatrixForm=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[gratingsystem, NumericalResults->True,MatrixForm->False, \
FilterTrace->False]\
\>", "Input",
  CellLabel->"In[13]:=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],

Cell[BoxData[
    \({{{ABCDCenterPoint \[Rule] {{100, 0, 0}, {100, 0, 0}}, 
          ABCDMatrix \[Rule] {{{1, 150.`}, {0, 1}}, {{1, 150.`}, {0, 1}}}, 
          ABCDRotationMatrix \[Rule] {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {{1, 
                  0, 0}, {0, 1, 0}, {0, 0, 1}}}, 
          SymbolicIntensity \[Rule] {20, 20}, 
          SymbolicOpticalLength \[Rule] {150.`, 150.`}, 
          SymbolicWaveLength \[Rule] {0.532`, 
              0.532`}}}, {{ABCDCenterPoint \[Rule] {{100, 
                10.700743754760476`, 0}, {100, 10.700743754760476`, 0}}, 
          ABCDMatrix \[Rule] {{{0.9943234081524985`, 
                  150.86122957667538`}, {0, 1.0057089995075637`}}, {{1, 
                  150.57089995075634`}, {0, 1}}}, 
          ABCDRotationMatrix \[Rule] {{{0.9943234081524985`, 
                  0.10639999999999918`, 0}, {\(-0.10639999999999918`\), 
                  0.9943234081524985`, 0}, {0, 0, 1}}, {{0.9943234081524985`, 
                  0.10639999999999918`, 0}, {\(-0.10639999999999918`\), 
                  0.9943234081524985`, 0}, {0, 0, 1}}}, 
          SymbolicIntensity \[Rule] {66.60749892143657`, 66.60749892143657`}, 
          SymbolicOpticalLength \[Rule] {150.57089995075634`, 
              150.57089995075634`}, 
          SymbolicWaveLength \[Rule] {0.532`, 0.532`}}}}\)], "Output",
  CellLabel->"Out[13]=",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG3."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Gaussian Beam Calculations: GaussianTrace", "Section",
  CellTags->{"AOG0.", "4", "AOG4.", "AOG4.1"}],

Cell[CellGroupData[{

Cell["4.1 Overview", "Subsection",
  CellTags->{"AOG0.", "4.1", "AOG4.", "AOG4.1"}],

Cell[CellGroupData[{

Cell["?GaussianTrace", "Input",
  CellLabel->"In[228]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],

Cell[BoxData[
    \("GaussianTrace[opticalsystem, assumptions, options] is a function that \
propagates one or more Gaussian beams through the optical system.\n\n\
GaussianTrace returns the Gaussian beam parameter information for each of the \
surfaces specified in ReportedSurfaces. GaussianTrace internally calls \
FindABCDMatrix.\n\nSee also GaussianPlot."\)], "Print",
  CellTags->{"Info3312043438-4643038", "AOG4.", "AOG4.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[GaussianTrace]", "Input",
  CellLabel->"In[229]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],

Cell[BoxData[
    \({Simplify \[Rule] Automatic, ParentFunction \[Rule] GaussianTrace, 
      SymbolicRefractiveModels \[Rule] Automatic, 
      NormalizeSurfaceNormal \[Rule] True, MaxByteCount \[Rule] 20000, 
      ByteCountLimit \[Rule] 20000000, RunningCommentary \[Rule] False, 
      TimeConstraint \[Rule] 10, ReportedParameters \[Rule] Automatic, 
      ReportedSurfaces \[Rule] All, NumericalResults \[Rule] True, 
      MakeFloatingPoint \[Rule] True, ComplexABCD \[Rule] False, 
      ABCDConstruction \[Rule] Automatic, SkipSimplify \[Rule] {}, 
      FilterTrace \[Rule] False, Precision \[Rule] 16}\)], "Output",
  CellLabel->"Out[229]=",
  CellTags->{"AOG4.", "AOG4.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?GaussianPlot", "Input",
  CellLabel->"In[2]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],

Cell[BoxData[
    \("GaussianPlot[opticalsystem, assumptions, options] is a function that \
propagates and plots one or more Gaussian beams through the optical system.\n\
\nNote that one or more GaussianBeam sources must be present in the system \
before ShowGaussian can produce any results. GaussianPlot has two different \
plotting modes that are governed by the Plot3D option. For Plot3D->True, a \
full three-dimensional representation of the beam curvature together with the \
beam spot size (at 1/e of amplitude) are shown. For Plot3D->False, a paraxial \
depiction of the beam parameters indicated with the RenderedParameters option \
is presented in the form of two-dimensional plots. RenderedParameters takes a \
list containing one or more of the following values: BeamSpotSize, \
BeamCurvature, and ComplexBeamParameter. When Plot3D->True is invoked, then \
RenderedParameters->ComplexBeamParameter is not available. GaussianPlot \
internally calls GaussianTrace. GuassianPlot is also called internally by \
ShowSystem for the rendering of Gaussian beam information by Optica. \n\nSee \
also: GaussianTrace, RenderedParameters, BeamCurvatureFunction, \
BeamCurvatureGraphics, BeamSpotSizeFunction, BeamSpotSizeGraphics, \
ComplexBeamParameterFunction, ComplexBeamParameterGraphics, and \
ShowGaussian."\)], "Print",
  CellTags->{"Info3405686992-9872384", "AOG0.", "AOG4.", "AOG4.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[GaussianPlot]", "Input",
  CellLabel->"In[231]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],

Cell[BoxData[
    \({ParentFunction \[Rule] GaussianPlot, RunningCommentary \[Rule] False, 
      TimeConstraint \[Rule] 10, ComplexABCD \[Rule] False, 
      ABCDConstruction \[Rule] Automatic, 
      RenderedParameters \[Rule] Automatic, RenameLabels \[Rule] {}, 
      Plot3D \[Rule] False, PlotPoints \[Rule] 15, PlotRange \[Rule] All, 
      Boxed \[Rule] False, PlotType \[Rule] Full3D, 
      DisplayFunction \[Rule] \((Display[$Display, #1] &)\), 
      ShowArrows \[Rule] True, HeadCenter \[Rule] 0.75`, 
      HeadLength \[Rule] 8, HeadScaling \[Rule] Absolute, 
      HeadShape \[Rule] Automatic, HeadWidth \[Rule] 0.5`, 
      ZeroShape \[Rule] Automatic, BeamStyle \[Rule] {}, 
      BeamAxisStyle \[Rule] {}, FilterTrace \[Rule] False, 
      SkipSimplify \[Rule] {}}\)], "Output",
  CellLabel->"Out[231]=",
  CellTags->{"AOG4.", "AOG4.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?GaussianBeam", "Input",
  CellLabel->"In[232]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],

Cell[BoxData[
    \("GaussianBeam[beamspotsize, fulldivergence, options] and \
GaussianBeam[complexbeamparameter, options] is a light source that takes \
either the output beam spotsize radius (specified at 1/e^2 of the power \
density peak or 1/e of the electric field amplitude peak in the starting \
plane) and far-field beam fulldivergence (specified as the full angle in \
radians at 1/e^2 of the power density peak or 1/e of the electric field) or \
the complex beam parameter as input and creates an extended point source ray \
model of a Gaussian laser beam.\n \nGaussianBeam uses the FarField option to \
switch between observations carried out in the near-field and far-field. Its \
default setting of FarField -> False assumes that the divergence is low and \
the optical system is in the nearfield of the light source. However, this \
setting must be carefully examined for every optical arrangement.\n \nIn \
addition, GaussianBeam uses the FullForm option to determine whether a \
uniform grid of rays are created or two distinct fans of rays are instead \
constructed. For FullForm->False, GaussianBeam creates either a single \
two-dimensional fan of rays in the x-y plane or two cross-hatched fans of \
rays that lie in the x-y and x-z planes, depending on whether the spotsize \
and fulldivergence or complexbeamparameter contains single numbers or sets of \
two numbers. For FullForm->True, GaussianBeam attempts to construct a uniform \
three-dimensional grid of rays to model the spot size and beam divergence \
behavior. In some instances, however, when the two transverse beam waists \
occur at different locations along the optical axis, then GaussianBeam cannot \
presently construct a full three-dimensional model. In this event, it reverts \
to the FullForm->False behavior.\n \nIn order to generate an elliptical \
Gaussian beam, one needs to specify FullForm->True, provide a list of two \
values for the horizontal and vertical components of either beamspotsize or \
fulldivergence, and specify only the horizontal component of the remaining \
beamspotsize or fulldivergence parameter. In this instance, Rayica will \
automatically calculate the value of the remaining unspecified vertical \
component.\n\nGaussianBeam uses the SpatialScale option to determine the \
spatial units of the beamspotsize input parameter. In its default setting, \
SpatialScale -> 1, the units are taken in millimeters. Note, however, that \
the WaveLength option is not affected by SpatialScale and always takes units \
of microns. \n\nEach input parameter may also take a symbolic setting in \
addition to a numeric value. In such an event, a two-element list of terms, \
{symbolic,numeric}, is given for each symbolic parameter setting. In addition \
to geometric ray tracing, GaussianBeam is also used in symbolic Gaussian beam \
propagation calculations. \n\nNote that the RunningCommentary -> \
True/False/All option can be included with GaussianBeam to observe the \
internal processes involved. \n\nSee also: SpatialScale, FarField, \
SpotSizeFactor, BeamWaist, SymbolicBeamWaist, BeamSpotSize, \
SymbolicBeamSpotSize, BeamCurvature, SymbolicBeamCurvature, BeamDivergence, \
SymbolicBeamDivergence, BeamScaleLength, SymbolicBeamScaleLength, \
ComplexBeamParameter, SymbolicComplexBeamParameter, SingleRay, CircleOfRays, \
ConeOfRays, WedgeOfRays, LineOfRays, GridOfRays, PointOfRays, CustomRays, \
FieldOfRays, and RainbowOfRays."\)], "Print",
  CellTags->{"Info3312043439-7338271", "AOG4.", "AOG4.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[GaussianBeam]", "Input",
  CellLabel->"In[233]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],

Cell[BoxData[
    \({NumberOfRays \[Rule] 3, BirthPoint \[Rule] Automatic, 
      SymbolicBirthPoint \[Rule] BirthPoint, 
      CoordinateSystem \[Rule] CartesianCoordinates, 
      StartAtBirthPoint \[Rule] True, BalancePhaseFront \[Rule] True, 
      BalanceIntensity \[Rule] True, FarField \[Rule] False, 
      FullForm \[Rule] False, SpatialScale \[Rule] 1, 
      SpotSizeFactor \[Rule] 1, MonteCarlo \[Rule] False, 
      SourceOffset \[Rule] {0, 0}, SourceFraction \[Rule] {1, 1}, 
      GridSpacing \[Rule] {#1 &, #1 &}, IntensityFunction \[Rule] Automatic, 
      PolarizationFunction \[Rule] {#1 &, #1 &}, WaveLength \[Rule] 133\/250, 
      SymbolicWaveLength \[Rule] WaveLength, SourceID \[Rule] Automatic, 
      PowerOutput \[Rule] 100, RunningCommentary \[Rule] False}\)], "Output",
  CellLabel->"Out[233]=",
  CellTags->{"AOG4.", "AOG4.1"}]
}, Open  ]],

Cell["\<\
gratingsystem = \
{Move[GaussianBeam[5.,.01,SymbolicWaveLength->\[Lambda],NumberOfRays->3],{-d1,\
-50}],
Grating[{g,400},50,GratingMedium->IntrinsicMedium,GratingThickness->0,\
ComponentMedium->IntrinsicMedium],
Move[Screen[50],{d2,100}]};\
\>", "Input",
  CellLabel->"In[17]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],

Cell[CellGroupData[{

Cell["\<\
sol = AnalyzeSystem[gratingsystem,PlotType->TopView, ShowGaussian->True];\
\>", "Input",
  CellLabel->"In[18]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .37232 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.338824 0.00629789 0.191505 0.00629789 [
[.33882 .00886 -5.59375 -6 ]
[.33882 .00886 5.59375 6 ]
[.96861 .00886 -4.75 -6 ]
[.96861 .00886 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .37232 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.33882 .03406 m
.33882 .03406 L
.33882 .08654 L
.33882 .08654 L
.33882 .03406 L
F
.33882 .08654 m
.33882 .08654 L
.33882 .13902 L
.33882 .13902 L
.33882 .08654 L
F
.33882 .13902 m
.33882 .13902 L
.33882 .19151 L
.33882 .19151 L
.33882 .13902 L
F
.33882 .19151 m
.33882 .19151 L
.33882 .24399 L
.33882 .24399 L
.33882 .19151 L
F
.33882 .24399 m
.33882 .24399 L
.33882 .29647 L
.33882 .29647 L
.33882 .24399 L
F
.33882 .29647 m
.33882 .29647 L
.33882 .34895 L
.33882 .34895 L
.33882 .29647 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.33882 .03406 m
.33882 .08654 L
.33882 .13902 L
.33882 .19151 L
.33882 .24399 L
.33882 .29647 L
.33882 .34895 L
.33882 .34895 L
.33882 .29647 L
.33882 .24399 L
.33882 .19151 L
.33882 .13902 L
.33882 .08654 L
.33882 .03406 L
.33882 .03406 L
s
.5 g
.33882 .19151 m
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
F
.33882 .19151 m
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
F
.33882 .19151 m
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
F
.33882 .19151 m
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
F
.33882 .19151 m
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
F
.33882 .19151 m
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
F
0 g
.33882 .19151 m
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
.33882 .19151 L
s
.33882 .34895 m
.33882 .34359 L
.33882 .32786 L
.33882 .30284 L
.33882 .27023 L
.33882 .23226 L
.33882 .19151 L
.33882 .15075 L
.33882 .11278 L
.33882 .08017 L
.33882 .05515 L
.33882 .03942 L
.33882 .03406 L
.33882 .03942 L
.33882 .05515 L
.33882 .08017 L
.33882 .11278 L
.33882 .15075 L
.33882 .19151 L
.33882 .23226 L
.33882 .27023 L
.33882 .30284 L
.33882 .32786 L
.33882 .34359 L
.33882 .34895 L
s
.96861 .03406 m
.96861 .08654 L
.96861 .13902 L
.96861 .19151 L
.96861 .24399 L
.96861 .29647 L
.96861 .34895 L
.96861 .34895 L
.96861 .29647 L
.96861 .24399 L
.96861 .19151 L
.96861 .13902 L
.96861 .08654 L
.96861 .03406 L
.96861 .03406 L
s
.96861 .19151 m
.96861 .19151 L
.96861 .19151 L
.96861 .19151 L
.96861 .19151 L
.96861 .19151 L
.96861 .19151 L
.96861 .19151 L
.96861 .19151 L
.96861 .19151 L
.96861 .19151 L
.96861 .19151 L
.96861 .19151 L
.96861 .19151 L
.96861 .19151 L
s
.96861 .34895 m
.96861 .34359 L
.96861 .32786 L
.96861 .30284 L
.96861 .27023 L
.96861 .23226 L
.96861 .19151 L
.96861 .15075 L
.96861 .11278 L
.96861 .08017 L
.96861 .05515 L
.96861 .03942 L
.96861 .03406 L
.96861 .03942 L
.96861 .05515 L
.96861 .08017 L
.96861 .11278 L
.96861 .15075 L
.96861 .19151 L
.96861 .23226 L
.96861 .27023 L
.96861 .30284 L
.96861 .32786 L
.96861 .34359 L
.96861 .34895 L
s
.039 .916 .04 r
.02385 .16002 m
.33882 .15844 L
s
% Start of user PostScript
-50.0125 -4.99994 0 -5.24999 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.33882 .15844 Mdot
.039 .916 .04 r
.5 Mabswid
.02393 .19151 m
.33882 .19151 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.33882 .19151 Mdot
.039 .916 .04 r
.5 Mabswid
.02385 .22299 m
.33882 .22457 L
s
% Start of user PostScript
-50.0125 4.99994 0 5.24999 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.33882 .22457 Mdot
.039 .916 .04 r
.5 Mabswid
.33882 .15844 m
.96861 .15529 L
s
% Start of user PostScript
0 -5.24999 100. -5.74998 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.96861 .15529 Mdot
.039 .916 .04 r
.5 Mabswid
.33882 .15844 m
.96861 .29223 L
s
% Start of user PostScript
0 -5.24999 100. 15.9937 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.96861 .29223 Mdot
.039 .916 .04 r
.5 Mabswid
.33882 .19151 m
.96861 .19151 L
s
% Start of user PostScript
0 0 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.96861 .19151 Mdot
.039 .916 .04 r
.5 Mabswid
.33882 .19151 m
.96861 .32867 L
s
% Start of user PostScript
0 0 100. 21.7788 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.96861 .32867 Mdot
.039 .916 .04 r
.5 Mabswid
.33882 .22457 m
.96861 .22772 L
s
% Start of user PostScript
0 5.24999 100. 5.74998 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.96861 .22772 Mdot
gsave
.33882 .00886 -66.5938 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
70.188 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.96861 .00886 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
1 Mabswid
.02393 .22299 m
.04492 .2231 L
.06592 .2232 L
.08691 .22331 L
.1079 .22341 L
.12889 .22352 L
.14989 .22362 L
.17088 .22373 L
.19187 .22383 L
.21287 .22394 L
.23386 .22404 L
.25485 .22415 L
.27584 .22425 L
.29684 .22436 L
.31783 .22446 L
.33882 .22457 L
.35982 .22468 L
.38081 .22478 L
.4018 .22489 L
.4228 .22499 L
.44379 .2251 L
.46478 .2252 L
.48577 .22531 L
.50677 .22541 L
.52776 .22552 L
.54875 .22562 L
.56975 .22573 L
.59074 .22583 L
.61173 .22594 L
.63273 .22604 L
.65372 .22615 L
.67471 .22625 L
.6957 .22636 L
.7167 .22646 L
.73769 .22657 L
.75868 .22667 L
.77968 .22678 L
.80067 .22688 L
.82166 .22699 L
.84265 .22709 L
.86365 .2272 L
.88464 .2273 L
.90563 .22741 L
.92663 .22751 L
.94762 .22762 L
.96861 .22772 L
s
.02393 .16002 m
.04492 .15991 L
.06592 .15981 L
.08691 .1597 L
.1079 .1596 L
.12889 .15949 L
.14989 .15939 L
.17088 .15928 L
.19187 .15918 L
.21287 .15907 L
.23386 .15897 L
.25485 .15886 L
.27584 .15876 L
.29684 .15865 L
.31783 .15855 L
.33882 .15844 L
.35982 .15833 L
.38081 .15823 L
.4018 .15812 L
.4228 .15802 L
.44379 .15791 L
.46478 .15781 L
.48577 .1577 L
.50677 .1576 L
.52776 .15749 L
.54875 .15739 L
.56975 .15728 L
.59074 .15718 L
.61173 .15707 L
.63273 .15697 L
.65372 .15686 L
.67471 .15676 L
.6957 .15665 L
.7167 .15655 L
.73769 .15644 L
.75868 .15634 L
.77968 .15623 L
.80067 .15613 L
.82166 .15602 L
.84265 .15592 L
.86365 .15581 L
.88464 .15571 L
.90563 .1556 L
.92663 .1555 L
.94762 .15539 L
.96861 .15529 L
s
0 0 0 r
.02393 .19151 m
.33882 .19151 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
.33882 .19151 m
.96861 .19151 L
s
% Start of user PostScript
0 0 100. 0 MAarrowhead1
% End of user PostScript
.96861 .19151 m
.96861 .19151 L
s
% Start of user PostScript
100. 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .16316 m
.02382 .16505 L
.02384 .16694 L
.02385 .16883 L
.02386 .17072 L
.02388 .17261 L
.02389 .1745 L
.0239 .17639 L
.0239 .17828 L
.02391 .18017 L
.02392 .18206 L
.02392 .18395 L
.02392 .18584 L
.02393 .18773 L
.02393 .18962 L
.02393 .19151 L
.02393 .19339 L
.02393 .19528 L
.02392 .19717 L
.02392 .19906 L
.02392 .20095 L
.02391 .20284 L
.0239 .20473 L
.0239 .20662 L
.02389 .20851 L
.02388 .2104 L
.02386 .21229 L
.02385 .21418 L
.02384 .21607 L
.02382 .21796 L
.02381 .21985 L
s
.0553 .16302 m
.05531 .16492 L
.05533 .16682 L
.05534 .16872 L
.05535 .17062 L
.05537 .17252 L
.05538 .17442 L
.05538 .17631 L
.05539 .17821 L
.0554 .18011 L
.05541 .18201 L
.05541 .18391 L
.05541 .18581 L
.05542 .18771 L
.05542 .18961 L
.05542 .19151 L
.05542 .1934 L
.05542 .1953 L
.05541 .1972 L
.05541 .1991 L
.05541 .201 L
.0554 .2029 L
.05539 .2048 L
.05538 .2067 L
.05538 .20859 L
.05537 .21049 L
.05535 .21239 L
.05534 .21429 L
.05533 .21619 L
.05531 .21809 L
.0553 .21999 L
s
.08679 .16288 m
.0868 .16479 L
.08682 .1667 L
.08683 .16861 L
.08684 .17051 L
.08685 .17242 L
.08686 .17433 L
.08687 .17624 L
.08688 .17815 L
.08689 .18006 L
.08689 .18196 L
.0869 .18387 L
.0869 .18578 L
.08691 .18769 L
.08691 .1896 L
.08691 .19151 L
.08691 .19341 L
.08691 .19532 L
.0869 .19723 L
.0869 .19914 L
.08689 .20105 L
.08689 .20295 L
.08688 .20486 L
.08687 .20677 L
.08686 .20868 L
.08685 .21059 L
.08684 .2125 L
.08683 .2144 L
.08682 .21631 L
.0868 .21822 L
.08679 .22013 L
s
.11828 .16274 m
.11829 .16466 L
.11831 .16658 L
.11832 .16849 L
.11833 .17041 L
.11834 .17233 L
.11835 .17425 L
.11836 .17616 L
.11837 .17808 L
.11838 .18 L
.11838 .18192 L
.11839 .18383 L
.11839 .18575 L
.1184 .18767 L
.1184 .18959 L
.1184 .19151 L
.1184 .19342 L
.1184 .19534 L
.11839 .19726 L
.11839 .19918 L
.11838 .20109 L
.11838 .20301 L
.11837 .20493 L
.11836 .20685 L
.11835 .20876 L
.11834 .21068 L
.11833 .2126 L
.11832 .21452 L
.11831 .21644 L
.11829 .21835 L
.11828 .22027 L
s
.14976 .1626 m
.14978 .16453 L
.1498 .16645 L
.14981 .16838 L
.14982 .17031 L
.14983 .17223 L
.14984 .17416 L
.14985 .17609 L
.14986 .17802 L
.14987 .17994 L
.14987 .18187 L
.14988 .1838 L
.14988 .18572 L
.14988 .18765 L
.14989 .18958 L
.14989 .19151 L
.14989 .19343 L
.14988 .19536 L
.14988 .19729 L
.14988 .19921 L
.14987 .20114 L
.14987 .20307 L
.14986 .205 L
.14985 .20692 L
.14984 .20885 L
.14983 .21078 L
.14982 .2127 L
.14981 .21463 L
.1498 .21656 L
.14978 .21849 L
.14976 .22041 L
s
.18125 .16246 m
.18127 .16439 L
.18128 .16633 L
.1813 .16827 L
.18131 .1702 L
.18132 .17214 L
.18133 .17408 L
.18134 .17601 L
.18135 .17795 L
.18136 .17989 L
.18136 .18182 L
.18137 .18376 L
.18137 .1857 L
.18137 .18763 L
.18138 .18957 L
.18138 .19151 L
.18138 .19344 L
.18137 .19538 L
.18137 .19732 L
.18137 .19925 L
.18136 .20119 L
.18136 .20312 L
.18135 .20506 L
.18134 .207 L
.18133 .20893 L
.18132 .21087 L
.18131 .21281 L
.1813 .21474 L
.18128 .21668 L
.18127 .21862 L
.18125 .22055 L
s
.21274 .16231 m
.21276 .16426 L
.21277 .16621 L
.21279 .16815 L
.2128 .1701 L
.21281 .17204 L
.21282 .17399 L
.21283 .17594 L
.21284 .17788 L
.21285 .17983 L
.21285 .18178 L
.21286 .18372 L
.21286 .18567 L
.21286 .18761 L
.21287 .18956 L
.21287 .19151 L
.21287 .19345 L
.21286 .1954 L
.21286 .19734 L
.21286 .19929 L
.21285 .20124 L
.21285 .20318 L
.21284 .20513 L
.21283 .20707 L
.21282 .20902 L
.21281 .21097 L
.2128 .21291 L
.21279 .21486 L
.21277 .2168 L
.21276 .21875 L
.21274 .2207 L
s
.24423 .16217 m
.24425 .16413 L
.24426 .16608 L
.24428 .16804 L
.24429 .16999 L
.2443 .17195 L
.24431 .17391 L
.24432 .17586 L
.24433 .17782 L
.24434 .17977 L
.24434 .18173 L
.24435 .18368 L
.24435 .18564 L
.24435 .18759 L
.24435 .18955 L
.24436 .19151 L
.24435 .19346 L
.24435 .19542 L
.24435 .19737 L
.24435 .19933 L
.24434 .20128 L
.24434 .20324 L
.24433 .20519 L
.24432 .20715 L
.24431 .2091 L
.2443 .21106 L
.24429 .21302 L
.24428 .21497 L
.24426 .21693 L
.24425 .21888 L
.24423 .22084 L
s
.27572 .16203 m
.27574 .164 L
.27575 .16596 L
.27577 .16793 L
.27578 .16989 L
.27579 .17186 L
.2758 .17382 L
.27581 .17579 L
.27582 .17775 L
.27583 .17972 L
.27583 .18168 L
.27584 .18365 L
.27584 .18561 L
.27584 .18758 L
.27584 .18954 L
.27584 .19151 L
.27584 .19347 L
.27584 .19544 L
.27584 .1974 L
.27584 .19936 L
.27583 .20133 L
.27583 .20329 L
.27582 .20526 L
.27581 .20722 L
.2758 .20919 L
.27579 .21115 L
.27578 .21312 L
.27577 .21508 L
.27575 .21705 L
.27574 .21901 L
.27572 .22098 L
s
.30721 .16189 m
.30723 .16386 L
.30724 .16584 L
.30725 .16781 L
.30727 .16979 L
.30728 .17176 L
.30729 .17374 L
.3073 .17571 L
.30731 .17768 L
.30731 .17966 L
.30732 .18163 L
.30733 .18361 L
.30733 .18558 L
.30733 .18756 L
.30733 .18953 L
.30733 .19151 L
.30733 .19348 L
.30733 .19545 L
.30733 .19743 L
.30733 .1994 L
.30732 .20138 L
.30731 .20335 L
.30731 .20533 L
.3073 .2073 L
.30729 .20927 L
.30728 .21125 L
.30727 .21322 L
.30725 .2152 L
.30724 .21717 L
.30723 .21915 L
.30721 .22112 L
s
.3387 .16174 m
.33871 .16373 L
.33873 .16571 L
.33874 .1677 L
.33876 .16968 L
.33877 .17166 L
.33878 .17365 L
.33879 .17563 L
.3388 .17762 L
.3388 .1796 L
.33881 .18158 L
.33881 .18357 L
.33882 .18555 L
.33882 .18754 L
.33882 .18952 L
.33882 .19151 L
.33882 .19349 L
.33882 .19547 L
.33882 .19746 L
.33881 .19944 L
.33881 .20143 L
.3388 .20341 L
.3388 .20539 L
.33879 .20738 L
.33878 .20936 L
.33877 .21135 L
.33876 .21333 L
.33874 .21531 L
.33873 .2173 L
.33871 .21928 L
.3387 .22127 L
s
.37019 .1616 m
.3702 .1636 L
.37022 .16559 L
.37023 .16758 L
.37025 .16958 L
.37026 .17157 L
.37027 .17356 L
.37028 .17556 L
.37029 .17755 L
.37029 .17954 L
.3703 .18154 L
.3703 .18353 L
.37031 .18552 L
.37031 .18752 L
.37031 .18951 L
.37031 .19151 L
.37031 .1935 L
.37031 .19549 L
.37031 .19749 L
.3703 .19948 L
.3703 .20147 L
.37029 .20347 L
.37029 .20546 L
.37028 .20745 L
.37027 .20945 L
.37026 .21144 L
.37025 .21343 L
.37023 .21543 L
.37022 .21742 L
.3702 .21941 L
.37019 .22141 L
s
.40168 .16146 m
.40169 .16346 L
.40171 .16547 L
.40172 .16747 L
.40173 .16947 L
.40175 .17148 L
.40176 .17348 L
.40177 .17548 L
.40178 .17748 L
.40178 .17949 L
.40179 .18149 L
.40179 .18349 L
.4018 .1855 L
.4018 .1875 L
.4018 .1895 L
.4018 .19151 L
.4018 .19351 L
.4018 .19551 L
.4018 .19751 L
.40179 .19952 L
.40179 .20152 L
.40178 .20352 L
.40178 .20553 L
.40177 .20753 L
.40176 .20953 L
.40175 .21154 L
.40173 .21354 L
.40172 .21554 L
.40171 .21754 L
.40169 .21955 L
.40168 .22155 L
s
.43316 .16132 m
.43318 .16333 L
.4332 .16534 L
.43321 .16736 L
.43322 .16937 L
.43324 .17138 L
.43325 .17339 L
.43326 .17541 L
.43326 .17742 L
.43327 .17943 L
.43328 .18144 L
.43328 .18346 L
.43329 .18547 L
.43329 .18748 L
.43329 .18949 L
.43329 .19151 L
.43329 .19352 L
.43329 .19553 L
.43329 .19754 L
.43328 .19956 L
.43328 .20157 L
.43327 .20358 L
.43326 .20559 L
.43326 .2076 L
.43325 .20962 L
.43324 .21163 L
.43322 .21364 L
.43321 .21565 L
.4332 .21767 L
.43318 .21968 L
.43316 .22169 L
s
.46465 .16118 m
.46467 .1632 L
.46469 .16522 L
.4647 .16724 L
.46471 .16926 L
.46472 .17129 L
.46474 .17331 L
.46475 .17533 L
.46475 .17735 L
.46476 .17937 L
.46477 .1814 L
.46477 .18342 L
.46478 .18544 L
.46478 .18746 L
.46478 .18948 L
.46478 .19151 L
.46478 .19353 L
.46478 .19555 L
.46478 .19757 L
.46477 .19959 L
.46477 .20161 L
.46476 .20364 L
.46475 .20566 L
.46475 .20768 L
.46474 .2097 L
.46472 .21172 L
.46471 .21375 L
.4647 .21577 L
.46469 .21779 L
.46467 .21981 L
.46465 .22183 L
s
.49614 .16104 m
.49616 .16307 L
.49617 .1651 L
.49619 .16713 L
.4962 .16916 L
.49621 .17119 L
.49622 .17322 L
.49623 .17525 L
.49624 .17729 L
.49625 .17932 L
.49626 .18135 L
.49626 .18338 L
.49627 .18541 L
.49627 .18744 L
.49627 .18947 L
.49627 .19151 L
.49627 .19354 L
.49627 .19557 L
.49627 .1976 L
.49626 .19963 L
.49626 .20166 L
.49625 .20369 L
.49624 .20572 L
.49623 .20776 L
.49622 .20979 L
.49621 .21182 L
.4962 .21385 L
.49619 .21588 L
.49617 .21791 L
.49616 .21994 L
.49614 .22198 L
s
.52763 .16089 m
.52765 .16293 L
.52766 .16497 L
.52768 .16702 L
.52769 .16906 L
.5277 .1711 L
.52771 .17314 L
.52772 .17518 L
.52773 .17722 L
.52774 .17926 L
.52775 .1813 L
.52775 .18334 L
.52776 .18538 L
.52776 .18742 L
.52776 .18946 L
.52776 .19151 L
.52776 .19355 L
.52776 .19559 L
.52776 .19763 L
.52775 .19967 L
.52775 .20171 L
.52774 .20375 L
.52773 .20579 L
.52772 .20783 L
.52771 .20987 L
.5277 .21191 L
.52769 .21395 L
.52768 .21599 L
.52766 .21804 L
.52765 .22008 L
.52763 .22212 L
s
.55912 .16075 m
.55914 .1628 L
.55915 .16485 L
.55917 .1669 L
.55918 .16895 L
.55919 .171 L
.5592 .17305 L
.55921 .1751 L
.55922 .17715 L
.55923 .1792 L
.55924 .18125 L
.55924 .1833 L
.55924 .18535 L
.55925 .1874 L
.55925 .18945 L
.55925 .19151 L
.55925 .19356 L
.55925 .19561 L
.55924 .19766 L
.55924 .19971 L
.55924 .20176 L
.55923 .20381 L
.55922 .20586 L
.55921 .20791 L
.5592 .20996 L
.55919 .21201 L
.55918 .21406 L
.55917 .21611 L
.55915 .21816 L
.55914 .22021 L
.55912 .22226 L
s
.59061 .16061 m
.59063 .16267 L
.59064 .16473 L
.59066 .16679 L
.59067 .16885 L
.59068 .17091 L
.59069 .17297 L
.5907 .17503 L
.59071 .17709 L
.59072 .17915 L
.59072 .18121 L
.59073 .18327 L
.59073 .18533 L
.59074 .18739 L
.59074 .18945 L
.59074 .19151 L
.59074 .19356 L
.59074 .19562 L
.59073 .19768 L
.59073 .19974 L
.59072 .2018 L
.59072 .20386 L
.59071 .20592 L
.5907 .20798 L
.59069 .21004 L
.59068 .2121 L
.59067 .21416 L
.59066 .21622 L
.59064 .21828 L
.59063 .22034 L
.59061 .2224 L
s
.6221 .16047 m
.62211 .16254 L
.62213 .16461 L
.62214 .16668 L
.62216 .16874 L
.62217 .17081 L
.62218 .17288 L
.62219 .17495 L
.6222 .17702 L
.62221 .17909 L
.62221 .18116 L
.62222 .18323 L
.62222 .1853 L
.62223 .18737 L
.62223 .18944 L
.62223 .19151 L
.62223 .19357 L
.62223 .19564 L
.62222 .19771 L
.62222 .19978 L
.62221 .20185 L
.62221 .20392 L
.6222 .20599 L
.62219 .20806 L
.62218 .21013 L
.62217 .2122 L
.62216 .21427 L
.62214 .21633 L
.62213 .2184 L
.62211 .22047 L
.6221 .22254 L
s
.65359 .16033 m
.6536 .16241 L
.65362 .16448 L
.65363 .16656 L
.65365 .16864 L
.65366 .17072 L
.65367 .1728 L
.65368 .17488 L
.65369 .17696 L
.6537 .17903 L
.6537 .18111 L
.65371 .18319 L
.65371 .18527 L
.65372 .18735 L
.65372 .18943 L
.65372 .19151 L
.65372 .19358 L
.65372 .19566 L
.65371 .19774 L
.65371 .19982 L
.6537 .2019 L
.6537 .20398 L
.65369 .20606 L
.65368 .20813 L
.65367 .21021 L
.65366 .21229 L
.65365 .21437 L
.65363 .21645 L
.65362 .21853 L
.6536 .22061 L
.65359 .22268 L
s
.68508 .16018 m
.68509 .16227 L
.68511 .16436 L
.68512 .16645 L
.68514 .16854 L
.68515 .17062 L
.68516 .17271 L
.68517 .1748 L
.68518 .17689 L
.68519 .17898 L
.68519 .18107 L
.6852 .18315 L
.6852 .18524 L
.68521 .18733 L
.68521 .18942 L
.68521 .19151 L
.68521 .19359 L
.68521 .19568 L
.6852 .19777 L
.6852 .19986 L
.68519 .20195 L
.68519 .20403 L
.68518 .20612 L
.68517 .20821 L
.68516 .2103 L
.68515 .21239 L
.68514 .21447 L
.68512 .21656 L
.68511 .21865 L
.68509 .22074 L
.68508 .22283 L
s
.71656 .16004 m
.71658 .16214 L
.7166 .16424 L
.71661 .16634 L
.71663 .16843 L
.71664 .17053 L
.71665 .17263 L
.71666 .17473 L
.71667 .17682 L
.71668 .17892 L
.71668 .18102 L
.71669 .18312 L
.71669 .18521 L
.71669 .18731 L
.7167 .18941 L
.7167 .19151 L
.7167 .1936 L
.71669 .1957 L
.71669 .1978 L
.71669 .1999 L
.71668 .20199 L
.71668 .20409 L
.71667 .20619 L
.71666 .20829 L
.71665 .21038 L
.71664 .21248 L
.71663 .21458 L
.71661 .21667 L
.7166 .21877 L
.71658 .22087 L
.71656 .22297 L
s
.74805 .1599 m
.74807 .16201 L
.74809 .16412 L
.7481 .16622 L
.74811 .16833 L
.74813 .17044 L
.74814 .17254 L
.74815 .17465 L
.74816 .17676 L
.74817 .17886 L
.74817 .18097 L
.74818 .18308 L
.74818 .18518 L
.74818 .18729 L
.74819 .1894 L
.74819 .19151 L
.74819 .19361 L
.74818 .19572 L
.74818 .19783 L
.74818 .19993 L
.74817 .20204 L
.74817 .20415 L
.74816 .20625 L
.74815 .20836 L
.74814 .21047 L
.74813 .21257 L
.74811 .21468 L
.7481 .21679 L
.74809 .2189 L
.74807 .221 L
.74805 .22311 L
s
.77954 .15976 m
.77956 .16188 L
.77958 .16399 L
.77959 .16611 L
.7796 .16823 L
.77962 .17034 L
.77963 .17246 L
.77964 .17457 L
.77965 .17669 L
.77965 .17881 L
.77966 .18092 L
.77967 .18304 L
.77967 .18516 L
.77967 .18727 L
.77968 .18939 L
.77968 .19151 L
.77968 .19362 L
.77967 .19574 L
.77967 .19785 L
.77967 .19997 L
.77966 .20209 L
.77965 .2042 L
.77965 .20632 L
.77964 .20844 L
.77963 .21055 L
.77962 .21267 L
.7796 .21479 L
.77959 .2169 L
.77958 .21902 L
.77956 .22113 L
.77954 .22325 L
s
.81103 .15962 m
.81105 .16174 L
.81106 .16387 L
.81108 .166 L
.81109 .16812 L
.81111 .17025 L
.81112 .17237 L
.81113 .1745 L
.81114 .17662 L
.81114 .17875 L
.81115 .18088 L
.81116 .183 L
.81116 .18513 L
.81116 .18725 L
.81116 .18938 L
.81117 .19151 L
.81116 .19363 L
.81116 .19576 L
.81116 .19788 L
.81116 .20001 L
.81115 .20213 L
.81114 .20426 L
.81114 .20639 L
.81113 .20851 L
.81112 .21064 L
.81111 .21276 L
.81109 .21489 L
.81108 .21702 L
.81106 .21914 L
.81105 .22127 L
.81103 .22339 L
s
.84252 .15948 m
.84254 .16161 L
.84255 .16375 L
.84257 .16588 L
.84258 .16802 L
.84259 .17015 L
.84261 .17229 L
.84262 .17442 L
.84263 .17656 L
.84263 .17869 L
.84264 .18083 L
.84265 .18296 L
.84265 .1851 L
.84265 .18723 L
.84265 .18937 L
.84265 .19151 L
.84265 .19364 L
.84265 .19578 L
.84265 .19791 L
.84265 .20005 L
.84264 .20218 L
.84263 .20432 L
.84263 .20645 L
.84262 .20859 L
.84261 .21072 L
.84259 .21286 L
.84258 .21499 L
.84257 .21713 L
.84255 .21926 L
.84254 .2214 L
.84252 .22353 L
s
.87401 .15933 m
.87403 .16148 L
.87404 .16362 L
.87406 .16577 L
.87407 .16791 L
.87408 .17006 L
.8741 .1722 L
.87411 .17435 L
.87411 .17649 L
.87412 .17864 L
.87413 .18078 L
.87413 .18293 L
.87414 .18507 L
.87414 .18722 L
.87414 .18936 L
.87414 .19151 L
.87414 .19365 L
.87414 .19579 L
.87414 .19794 L
.87413 .20008 L
.87413 .20223 L
.87412 .20437 L
.87411 .20652 L
.87411 .20866 L
.8741 .21081 L
.87408 .21295 L
.87407 .2151 L
.87406 .21724 L
.87404 .21939 L
.87403 .22153 L
.87401 .22368 L
s
.9055 .15919 m
.90551 .16135 L
.90553 .1635 L
.90555 .16566 L
.90556 .16781 L
.90557 .16996 L
.90558 .17212 L
.90559 .17427 L
.9056 .17643 L
.90561 .17858 L
.90562 .18073 L
.90562 .18289 L
.90563 .18504 L
.90563 .1872 L
.90563 .18935 L
.90563 .19151 L
.90563 .19366 L
.90563 .19581 L
.90563 .19797 L
.90562 .20012 L
.90562 .20228 L
.90561 .20443 L
.9056 .20658 L
.90559 .20874 L
.90558 .21089 L
.90557 .21305 L
.90556 .2152 L
.90555 .21736 L
.90553 .21951 L
.90551 .22166 L
.9055 .22382 L
s
.93699 .15905 m
.937 .16121 L
.93702 .16338 L
.93704 .16554 L
.93705 .16771 L
.93706 .16987 L
.93707 .17203 L
.93708 .1742 L
.93709 .17636 L
.9371 .17852 L
.93711 .18069 L
.93711 .18285 L
.93712 .18501 L
.93712 .18718 L
.93712 .18934 L
.93712 .19151 L
.93712 .19367 L
.93712 .19583 L
.93712 .198 L
.93711 .20016 L
.93711 .20232 L
.9371 .20449 L
.93709 .20665 L
.93708 .20881 L
.93707 .21098 L
.93706 .21314 L
.93705 .2153 L
.93704 .21747 L
.93702 .21963 L
.937 .2218 L
.93699 .22396 L
s
.02393 .22299 m
.04525 .2231 L
.06657 .22321 L
.08789 .22331 L
.10921 .22342 L
.13053 .22353 L
.15186 .22363 L
.17318 .22374 L
.1945 .22385 L
.21582 .22395 L
.23714 .22406 L
.25846 .22417 L
.27978 .22427 L
.3011 .22438 L
.32242 .22449 L
.33675 .22415 L
.35756 .22879 L
.37837 .23344 L
.39918 .23808 L
.41999 .24272 L
.4408 .24737 L
.46161 .25201 L
.48242 .25665 L
.50323 .2613 L
.52404 .26594 L
.54485 .27059 L
.56566 .27523 L
.58646 .27987 L
.60727 .28452 L
.62808 .28916 L
.64889 .2938 L
.6697 .29845 L
.69051 .30309 L
.71132 .30774 L
.73213 .31238 L
.75294 .31702 L
.77375 .32167 L
.79456 .32631 L
.81537 .33095 L
.83618 .3356 L
.85699 .34024 L
.8778 .34488 L
.89861 .34953 L
.91942 .35417 L
.94023 .35882 L
.96104 .36346 L
s
.02393 .16002 m
.04525 .15991 L
.06657 .1598 L
.08789 .1597 L
.10921 .15959 L
.13053 .15948 L
.15186 .15938 L
.17318 .15927 L
.1945 .15916 L
.21582 .15906 L
.23714 .15895 L
.25846 .15884 L
.27978 .15874 L
.3011 .15863 L
.32242 .15852 L
.35051 .16096 L
.37137 .16539 L
.39223 .16982 L
.41308 .17425 L
.43394 .17868 L
.45479 .18311 L
.47565 .18754 L
.4965 .19197 L
.51736 .1964 L
.53822 .20083 L
.55907 .20526 L
.57993 .20969 L
.60078 .21412 L
.62164 .21855 L
.6425 .22298 L
.66335 .22741 L
.68421 .23184 L
.70506 .23628 L
.72592 .24071 L
.74678 .24514 L
.76763 .24957 L
.78849 .254 L
.80934 .25843 L
.8302 .26286 L
.85106 .26729 L
.87191 .27172 L
.89277 .27615 L
.91362 .28058 L
.93448 .28501 L
.95533 .28944 L
.97619 .29387 L
s
0 0 0 r
.02393 .19151 m
.33882 .19151 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
.33882 .19151 m
.96861 .32867 L
s
% Start of user PostScript
0 0 100. 21.7788 MAarrowhead1
% End of user PostScript
.96861 .32867 m
.96861 .32867 L
s
% Start of user PostScript
100. 21.7788 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .16316 m
.02382 .16505 L
.02384 .16694 L
.02385 .16883 L
.02386 .17072 L
.02388 .17261 L
.02389 .1745 L
.0239 .17639 L
.0239 .17828 L
.02391 .18017 L
.02392 .18206 L
.02392 .18395 L
.02392 .18584 L
.02393 .18773 L
.02393 .18962 L
.02393 .19151 L
.02393 .19339 L
.02393 .19528 L
.02392 .19717 L
.02392 .19906 L
.02392 .20095 L
.02391 .20284 L
.0239 .20473 L
.0239 .20662 L
.02389 .20851 L
.02388 .2104 L
.02386 .21229 L
.02385 .21418 L
.02384 .21607 L
.02382 .21796 L
.02381 .21985 L
s
.05579 .16302 m
.05581 .16492 L
.05582 .16682 L
.05583 .16872 L
.05585 .17062 L
.05586 .17252 L
.05587 .17441 L
.05588 .17631 L
.05588 .17821 L
.05589 .18011 L
.0559 .18201 L
.0559 .18391 L
.05591 .18581 L
.05591 .18771 L
.05591 .18961 L
.05591 .19151 L
.05591 .1934 L
.05591 .1953 L
.05591 .1972 L
.0559 .1991 L
.0559 .201 L
.05589 .2029 L
.05588 .2048 L
.05588 .2067 L
.05587 .2086 L
.05586 .21049 L
.05585 .21239 L
.05583 .21429 L
.05582 .21619 L
.05581 .21809 L
.05579 .21999 L
s
.08777 .16288 m
.08779 .16479 L
.0878 .16669 L
.08781 .1686 L
.08783 .17051 L
.08784 .17242 L
.08785 .17433 L
.08786 .17624 L
.08787 .17815 L
.08787 .18005 L
.08788 .18196 L
.08788 .18387 L
.08789 .18578 L
.08789 .18769 L
.08789 .1896 L
.08789 .19151 L
.08789 .19341 L
.08789 .19532 L
.08789 .19723 L
.08788 .19914 L
.08788 .20105 L
.08787 .20296 L
.08787 .20487 L
.08786 .20677 L
.08785 .20868 L
.08784 .21059 L
.08783 .2125 L
.08781 .21441 L
.0878 .21632 L
.08779 .21823 L
.08777 .22013 L
s
.11975 .16273 m
.11977 .16465 L
.11978 .16657 L
.1198 .16849 L
.11981 .17041 L
.11982 .17232 L
.11983 .17424 L
.11984 .17616 L
.11985 .17808 L
.11985 .18 L
.11986 .18191 L
.11987 .18383 L
.11987 .18575 L
.11987 .18767 L
.11987 .18959 L
.11987 .19151 L
.11987 .19342 L
.11987 .19534 L
.11987 .19726 L
.11987 .19918 L
.11986 .2011 L
.11985 .20301 L
.11985 .20493 L
.11984 .20685 L
.11983 .20877 L
.11982 .21069 L
.11981 .2126 L
.1198 .21452 L
.11978 .21644 L
.11977 .21836 L
.11975 .22028 L
s
.15173 .16259 m
.15175 .16452 L
.15176 .16644 L
.15178 .16837 L
.15179 .1703 L
.1518 .17223 L
.15181 .17416 L
.15182 .17608 L
.15183 .17801 L
.15184 .17994 L
.15184 .18187 L
.15185 .18379 L
.15185 .18572 L
.15185 .18765 L
.15186 .18958 L
.15186 .19151 L
.15186 .19343 L
.15185 .19536 L
.15185 .19729 L
.15185 .19922 L
.15184 .20114 L
.15184 .20307 L
.15183 .205 L
.15182 .20693 L
.15181 .20885 L
.1518 .21078 L
.15179 .21271 L
.15178 .21464 L
.15176 .21657 L
.15175 .21849 L
.15173 .22042 L
s
.18371 .16245 m
.18373 .16438 L
.18374 .16632 L
.18376 .16826 L
.18377 .17019 L
.18378 .17213 L
.18379 .17407 L
.1838 .17601 L
.18381 .17794 L
.18382 .17988 L
.18382 .18182 L
.18383 .18376 L
.18383 .18569 L
.18383 .18763 L
.18384 .18957 L
.18384 .19151 L
.18384 .19344 L
.18383 .19538 L
.18383 .19732 L
.18383 .19925 L
.18382 .20119 L
.18382 .20313 L
.18381 .20507 L
.1838 .207 L
.18379 .20894 L
.18378 .21088 L
.18377 .21282 L
.18376 .21475 L
.18374 .21669 L
.18373 .21863 L
.18371 .22057 L
s
.2157 .1623 m
.21571 .16425 L
.21573 .1662 L
.21574 .16814 L
.21575 .17009 L
.21576 .17204 L
.21577 .17398 L
.21578 .17593 L
.21579 .17788 L
.2158 .17982 L
.2158 .18177 L
.21581 .18372 L
.21581 .18566 L
.21582 .18761 L
.21582 .18956 L
.21582 .19151 L
.21582 .19345 L
.21582 .1954 L
.21581 .19735 L
.21581 .19929 L
.2158 .20124 L
.2158 .20319 L
.21579 .20513 L
.21578 .20708 L
.21577 .20903 L
.21576 .21097 L
.21575 .21292 L
.21574 .21487 L
.21573 .21682 L
.21571 .21876 L
.2157 .22071 L
s
.24768 .16216 m
.24769 .16411 L
.24771 .16607 L
.24772 .16803 L
.24773 .16998 L
.24775 .17194 L
.24776 .1739 L
.24776 .17585 L
.24777 .17781 L
.24778 .17977 L
.24779 .18172 L
.24779 .18368 L
.2478 .18564 L
.2478 .18759 L
.2478 .18955 L
.2478 .19151 L
.2478 .19346 L
.2478 .19542 L
.2478 .19737 L
.24779 .19933 L
.24779 .20129 L
.24778 .20324 L
.24777 .2052 L
.24776 .20716 L
.24776 .20911 L
.24775 .21107 L
.24773 .21303 L
.24772 .21498 L
.24771 .21694 L
.24769 .2189 L
.24768 .22085 L
s
.27966 .16201 m
.27967 .16398 L
.27969 .16595 L
.2797 .16791 L
.27971 .16988 L
.27973 .17184 L
.27974 .17381 L
.27975 .17578 L
.27975 .17774 L
.27976 .17971 L
.27977 .18167 L
.27977 .18364 L
.27978 .18561 L
.27978 .18757 L
.27978 .18954 L
.27978 .19151 L
.27978 .19347 L
.27978 .19544 L
.27978 .1974 L
.27977 .19937 L
.27977 .20134 L
.27976 .2033 L
.27975 .20527 L
.27975 .20723 L
.27974 .2092 L
.27973 .21117 L
.27971 .21313 L
.2797 .2151 L
.27969 .21706 L
.27967 .21903 L
.27966 .221 L
s
.31164 .16187 m
.31165 .16385 L
.31167 .16582 L
.31168 .1678 L
.3117 .16977 L
.31171 .17175 L
.31172 .17372 L
.31173 .1757 L
.31174 .17768 L
.31174 .17965 L
.31175 .18163 L
.31175 .1836 L
.31176 .18558 L
.31176 .18755 L
.31176 .18953 L
.31176 .19151 L
.31176 .19348 L
.31176 .19546 L
.31176 .19743 L
.31175 .19941 L
.31175 .20138 L
.31174 .20336 L
.31174 .20534 L
.31173 .20731 L
.31172 .20929 L
.31171 .21126 L
.3117 .21324 L
.31168 .21521 L
.31167 .21719 L
.31165 .21917 L
.31164 .22114 L
s
.3497 .16409 m
.34931 .16599 L
.34891 .16789 L
.34851 .16979 L
.34811 .17168 L
.34771 .17358 L
.3473 .17548 L
.3469 .17738 L
.3465 .17928 L
.34609 .18117 L
.34568 .18307 L
.34527 .18497 L
.34487 .18686 L
.34446 .18876 L
.34404 .19066 L
.34363 .19255 L
.34322 .19445 L
.3428 .19634 L
.34239 .19824 L
.34197 .20013 L
.34155 .20203 L
.34114 .20392 L
.34072 .20582 L
.34029 .20771 L
.33987 .2096 L
.33945 .2115 L
.33902 .21339 L
.3386 .21528 L
.33817 .21718 L
.33774 .21907 L
.33732 .22096 L
s
.38098 .17075 m
.38058 .17266 L
.38018 .17457 L
.37978 .17648 L
.37938 .17839 L
.37898 .18029 L
.37857 .1822 L
.37817 .18411 L
.37776 .18601 L
.37735 .18792 L
.37694 .18983 L
.37653 .19173 L
.37612 .19364 L
.37571 .19555 L
.3753 .19745 L
.37488 .19936 L
.37447 .20126 L
.37405 .20317 L
.37363 .20507 L
.37321 .20698 L
.37279 .20888 L
.37237 .21079 L
.37195 .21269 L
.37153 .21459 L
.3711 .2165 L
.37068 .2184 L
.37025 .2203 L
.36982 .2222 L
.36939 .22411 L
.36896 .22601 L
.36853 .22791 L
s
.41226 .17741 m
.41186 .17933 L
.41146 .18125 L
.41106 .18317 L
.41065 .18509 L
.41025 .187 L
.40984 .18892 L
.40943 .19084 L
.40902 .19275 L
.40861 .19467 L
.4082 .19659 L
.40779 .1985 L
.40738 .20042 L
.40696 .20233 L
.40655 .20425 L
.40613 .20616 L
.40571 .20808 L
.40529 .20999 L
.40487 .21191 L
.40445 .21382 L
.40403 .21574 L
.40361 .21765 L
.40318 .21956 L
.40276 .22148 L
.40233 .22339 L
.4019 .2253 L
.40148 .22721 L
.40105 .22913 L
.40062 .23104 L
.40018 .23295 L
.39975 .23486 L
s
.44354 .18407 m
.44314 .186 L
.44273 .18793 L
.44233 .18986 L
.44192 .19179 L
.44152 .19371 L
.44111 .19564 L
.4407 .19757 L
.44029 .19949 L
.43987 .20142 L
.43946 .20334 L
.43905 .20527 L
.43863 .20719 L
.43822 .20912 L
.4378 .21104 L
.43738 .21297 L
.43696 .21489 L
.43654 .21682 L
.43612 .21874 L
.43569 .22067 L
.43527 .22259 L
.43484 .22451 L
.43442 .22644 L
.43399 .22836 L
.43356 .23028 L
.43313 .2322 L
.4327 .23412 L
.43227 .23605 L
.43184 .23797 L
.4314 .23989 L
.43097 .24181 L
s
.47482 .19074 m
.47442 .19267 L
.47401 .19461 L
.4736 .19655 L
.47319 .19849 L
.47278 .20042 L
.47237 .20236 L
.47196 .20429 L
.47155 .20623 L
.47114 .20817 L
.47072 .2101 L
.4703 .21204 L
.46989 .21397 L
.46947 .21591 L
.46905 .21784 L
.46863 .21978 L
.46821 .22171 L
.46778 .22364 L
.46736 .22558 L
.46693 .22751 L
.46651 .22944 L
.46608 .23138 L
.46565 .23331 L
.46522 .23524 L
.46479 .23717 L
.46436 .2391 L
.46393 .24104 L
.46349 .24297 L
.46306 .2449 L
.46262 .24683 L
.46218 .24876 L
s
.5061 .1974 m
.50569 .19934 L
.50529 .20129 L
.50488 .20324 L
.50447 .20519 L
.50405 .20713 L
.50364 .20908 L
.50323 .21102 L
.50281 .21297 L
.5024 .21491 L
.50198 .21686 L
.50156 .2188 L
.50114 .22075 L
.50072 .22269 L
.5003 .22464 L
.49988 .22658 L
.49945 .22852 L
.49903 .23047 L
.4986 .23241 L
.49818 .23435 L
.49775 .2363 L
.49732 .23824 L
.49689 .24018 L
.49645 .24212 L
.49602 .24406 L
.49559 .24601 L
.49515 .24795 L
.49472 .24989 L
.49428 .25183 L
.49384 .25377 L
.4934 .25571 L
s
.53738 .20406 m
.53697 .20602 L
.53656 .20797 L
.53615 .20993 L
.53574 .21189 L
.53532 .21384 L
.53491 .2158 L
.53449 .21775 L
.53408 .21971 L
.53366 .22166 L
.53324 .22362 L
.53282 .22557 L
.5324 .22753 L
.53197 .22948 L
.53155 .23143 L
.53113 .23339 L
.5307 .23534 L
.53027 .23729 L
.52985 .23925 L
.52942 .2412 L
.52899 .24315 L
.52855 .2451 L
.52812 .24705 L
.52769 .24901 L
.52725 .25096 L
.52682 .25291 L
.52638 .25486 L
.52594 .25681 L
.5255 .25876 L
.52506 .26071 L
.52462 .26266 L
s
.56866 .21072 m
.56825 .21269 L
.56784 .21465 L
.56742 .21662 L
.56701 .21859 L
.56659 .22055 L
.56618 .22252 L
.56576 .22448 L
.56534 .22645 L
.56492 .22841 L
.5645 .23037 L
.56408 .23234 L
.56365 .2343 L
.56323 .23627 L
.5628 .23823 L
.56238 .24019 L
.56195 .24215 L
.56152 .24412 L
.56109 .24608 L
.56066 .24804 L
.56022 .25 L
.55979 .25197 L
.55936 .25393 L
.55892 .25589 L
.55848 .25785 L
.55804 .25981 L
.5576 .26177 L
.55716 .26373 L
.55672 .26569 L
.55628 .26765 L
.55584 .26961 L
s
.59994 .21738 m
.59953 .21936 L
.59911 .22133 L
.5987 .22331 L
.59828 .22529 L
.59786 .22726 L
.59744 .22924 L
.59702 .23121 L
.5966 .23318 L
.59618 .23516 L
.59576 .23713 L
.59533 .23911 L
.59491 .24108 L
.59448 .24305 L
.59405 .24503 L
.59362 .247 L
.59319 .24897 L
.59276 .25094 L
.59233 .25291 L
.5919 .25489 L
.59146 .25686 L
.59103 .25883 L
.59059 .2608 L
.59015 .26277 L
.58971 .26474 L
.58927 .26671 L
.58883 .26868 L
.58839 .27065 L
.58794 .27262 L
.5875 .27459 L
.58705 .27656 L
s
.63122 .22404 m
.6308 .22603 L
.63039 .22802 L
.62997 .23 L
.62955 .23199 L
.62913 .23397 L
.62871 .23595 L
.62829 .23794 L
.62787 .23992 L
.62744 .24191 L
.62702 .24389 L
.62659 .24587 L
.62616 .24786 L
.62573 .24984 L
.6253 .25182 L
.62487 .2538 L
.62444 .25579 L
.62401 .25777 L
.62357 .25975 L
.62314 .26173 L
.6227 .26371 L
.62226 .26569 L
.62182 .26767 L
.62138 .26965 L
.62094 .27163 L
.6205 .27361 L
.62006 .27559 L
.61961 .27757 L
.61916 .27955 L
.61872 .28153 L
.61827 .28351 L
s
.6625 .23071 m
.66208 .2327 L
.66166 .2347 L
.66124 .23669 L
.66082 .23869 L
.6604 .24068 L
.65998 .24267 L
.65956 .24467 L
.65913 .24666 L
.6587 .24865 L
.65828 .25065 L
.65785 .25264 L
.65742 .25463 L
.65699 .25663 L
.65656 .25862 L
.65612 .26061 L
.65569 .2626 L
.65525 .26459 L
.65482 .26658 L
.65438 .26857 L
.65394 .27056 L
.6535 .27255 L
.65306 .27454 L
.65262 .27653 L
.65217 .27852 L
.65173 .28051 L
.65128 .2825 L
.65083 .28449 L
.65039 .28648 L
.64994 .28847 L
.64949 .29046 L
s
.69378 .23737 m
.69336 .23937 L
.69294 .24138 L
.69252 .24338 L
.6921 .24539 L
.69167 .24739 L
.69125 .24939 L
.69082 .2514 L
.69039 .2534 L
.68997 .2554 L
.68954 .25741 L
.68911 .25941 L
.68867 .26141 L
.68824 .26341 L
.68781 .26541 L
.68737 .26741 L
.68694 .26942 L
.6865 .27142 L
.68606 .27342 L
.68562 .27542 L
.68518 .27742 L
.68474 .27942 L
.68429 .28142 L
.68385 .28342 L
.6834 .28542 L
.68296 .28742 L
.68251 .28941 L
.68206 .29141 L
.68161 .29341 L
.68116 .29541 L
.6807 .29741 L
s
.72506 .24403 m
.72464 .24604 L
.72422 .24806 L
.72379 .25007 L
.72337 .25209 L
.72294 .2541 L
.72251 .25611 L
.72209 .25813 L
.72166 .26014 L
.72123 .26215 L
.7208 .26416 L
.72036 .26617 L
.71993 .26819 L
.71949 .2702 L
.71906 .27221 L
.71862 .27422 L
.71818 .27623 L
.71774 .27824 L
.7173 .28025 L
.71686 .28226 L
.71642 .28427 L
.71597 .28628 L
.71553 .28829 L
.71508 .2903 L
.71463 .29231 L
.71418 .29432 L
.71373 .29632 L
.71328 .29833 L
.71283 .30034 L
.71238 .30235 L
.71192 .30436 L
s
.75634 .25069 m
.75592 .25271 L
.75549 .25474 L
.75507 .25676 L
.75464 .25879 L
.75421 .26081 L
.75378 .26283 L
.75335 .26485 L
.75292 .26688 L
.75249 .2689 L
.75206 .27092 L
.75162 .27294 L
.75118 .27496 L
.75075 .27698 L
.75031 .27901 L
.74987 .28103 L
.74943 .28305 L
.74899 .28507 L
.74854 .28709 L
.7481 .28911 L
.74765 .29113 L
.74721 .29314 L
.74676 .29516 L
.74631 .29718 L
.74586 .2992 L
.74541 .30122 L
.74496 .30324 L
.74451 .30525 L
.74405 .30727 L
.74359 .30929 L
.74314 .3113 L
s
.78762 .25735 m
.78719 .25939 L
.78677 .26142 L
.78634 .26345 L
.78591 .26549 L
.78548 .26752 L
.78505 .26955 L
.78462 .27158 L
.78418 .27362 L
.78375 .27565 L
.78331 .27768 L
.78288 .27971 L
.78244 .28174 L
.782 .28377 L
.78156 .2858 L
.78112 .28783 L
.78068 .28986 L
.78023 .29189 L
.77979 .29392 L
.77934 .29595 L
.77889 .29798 L
.77844 .30001 L
.77799 .30204 L
.77754 .30406 L
.77709 .30609 L
.77664 .30812 L
.77618 .31015 L
.77573 .31217 L
.77527 .3142 L
.77481 .31623 L
.77435 .31825 L
s
.8189 .26401 m
.81847 .26606 L
.81804 .2681 L
.81761 .27014 L
.81718 .27219 L
.81675 .27423 L
.81632 .27627 L
.81588 .27831 L
.81545 .28035 L
.81501 .28239 L
.81457 .28444 L
.81414 .28648 L
.81369 .28852 L
.81325 .29056 L
.81281 .2926 L
.81237 .29464 L
.81192 .29668 L
.81148 .29872 L
.81103 .30076 L
.81058 .30279 L
.81013 .30483 L
.80968 .30687 L
.80923 .30891 L
.80878 .31095 L
.80832 .31298 L
.80787 .31502 L
.80741 .31706 L
.80695 .31909 L
.80649 .32113 L
.80603 .32317 L
.80557 .3252 L
s
.85018 .27068 m
.84975 .27273 L
.84932 .27478 L
.84889 .27683 L
.84845 .27889 L
.84802 .28094 L
.84759 .28299 L
.84715 .28504 L
.84671 .28709 L
.84627 .28914 L
.84583 .29119 L
.84539 .29324 L
.84495 .29529 L
.84451 .29734 L
.84406 .29939 L
.84362 .30144 L
.84317 .30349 L
.84272 .30554 L
.84227 .30759 L
.84182 .30964 L
.84137 .31169 L
.84092 .31373 L
.84046 .31578 L
.84001 .31783 L
.83955 .31988 L
.83909 .32192 L
.83864 .32397 L
.83818 .32602 L
.83771 .32806 L
.83725 .33011 L
.83679 .33215 L
s
.88146 .27734 m
.88103 .2794 L
.88059 .28146 L
.88016 .28352 L
.87973 .28559 L
.87929 .28765 L
.87885 .28971 L
.87841 .29177 L
.87798 .29383 L
.87753 .29589 L
.87709 .29795 L
.87665 .30001 L
.87621 .30207 L
.87576 .30413 L
.87531 .30619 L
.87487 .30825 L
.87442 .31031 L
.87397 .31237 L
.87352 .31442 L
.87306 .31648 L
.87261 .31854 L
.87215 .3206 L
.8717 .32265 L
.87124 .32471 L
.87078 .32677 L
.87032 .32882 L
.86986 .33088 L
.8694 .33294 L
.86894 .33499 L
.86847 .33705 L
.86801 .3391 L
s
.91274 .284 m
.9123 .28607 L
.91187 .28814 L
.91143 .29021 L
.911 .29229 L
.91056 .29436 L
.91012 .29643 L
.90968 .2985 L
.90924 .30057 L
.9088 .30264 L
.90835 .30471 L
.90791 .30678 L
.90746 .30885 L
.90701 .31092 L
.90656 .31299 L
.90611 .31505 L
.90566 .31712 L
.90521 .31919 L
.90476 .32126 L
.9043 .32333 L
.90385 .32539 L
.90339 .32746 L
.90293 .32953 L
.90247 .33159 L
.90201 .33366 L
.90155 .33573 L
.90109 .33779 L
.90062 .33986 L
.90016 .34192 L
.89969 .34399 L
.89922 .34605 L
s
.94402 .29066 m
.94358 .29274 L
.94315 .29482 L
.94271 .2969 L
.94227 .29899 L
.94183 .30107 L
.94139 .30315 L
.94095 .30523 L
.9405 .30731 L
.94006 .30939 L
.93961 .31147 L
.93916 .31355 L
.93872 .31562 L
.93827 .3177 L
.93782 .31978 L
.93736 .32186 L
.93691 .32394 L
.93646 .32602 L
.936 .32809 L
.93554 .33017 L
.93509 .33225 L
.93463 .33432 L
.93417 .3364 L
.9337 .33848 L
.93324 .34055 L
.93278 .34263 L
.93231 .3447 L
.93185 .34678 L
.93138 .34885 L
.93091 .35093 L
.93044 .353 L
s
0 0 m
1 0 L
1 .37232 L
0 .37232 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{1047.94, 390.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@G0001QR000`400?l00000o`00003ooooooooo
oooooooooooooooooolKooooo`00oooooooooooooooooooooooooolKooooo`00oooooooooooooooo
oooooooooolKooooo`00oooooooooooooooooooooooooolKooooo`00oooooooooooooooooooooooo
oolKooooo`00oooooooooooooooooooooooooolKooooo`00oooooooooooooooooooooooooolKoooo
o`00oooooooooooooooooooooooooolKooooo`00oooooomRooooo`?o0000oooooooooooooi7ooooo
0ol0000Qooooo`00oooooomQooooo`05o`000?ooooooooooooooool00000oooooooooooooi3ooooo
00Co0000oooooooooooo00008?ooool00?ooooooH?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooooooooonAooooo`03o`000?oooooooooo01kooooo003oooooof3ooooo00Co
0000oooooooooooooooo0ol0003oooooooooooooT?ooool2o`00027ooooo003oooooof3ooooo00?o
0000ooooooooool0oooooooooooooi?ooooo00?o0000ooooooooool08Oooool00?ooooooHOooool0
0ol0003oooooooooo`02o`000?oooooooooooon@ooooo`04o`000?ooooooooooo`00023ooooo003o
ooooof;ooooo0_l000000ooooooo0000ooooo`3oooooooooooooT?ooool3o`00023ooooo003ooooo
oooooooooooooooooooooa_ooooo003ooooooooooooooooooooooooooa_ooooo003ooooooooooooo
oooooooooooooa_ooooo003ooooooooooooooooooooooooooa_ooooo003ooooooooooooooooooooo
oooooa_ooooo003ooooooooooooooooooooooooooa_ooooo003ooooooooooooooooooooooooooa_o
oooo003ooooooooooooooooooooooooooa_ooooo003ooooooooooooooooooooooooooa_ooooo003o
oooooooooooooooooooooooooa_ooooo003ooooooooooooooooooooooooooa_ooooo003ooooooooo
oooooooooooooooooa_ooooo003ooooooooooooooooooooooooooa_ooooo003ooooooooooooooooo
oooooooooa_ooooo003ooooooooooooooooooooooooooa_ooooo003ooooooooooooooooooooooooo
oa_ooooo003ooooooooooooooooooooooooooa_ooooo003ooooooooooooooooooooooooooa_ooooo
003ooooooooooooooooooooooooooa_ooooo003ooooooooooooooooooooooooooa_ooooo003ooooo
oooooooooooooooooooooa_ooooo003oooooof?ooooo0_l0003oooooooooooooToooool00ol0003o
ooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`00
0?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o
0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool0
0ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBoooo
o`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;o
oooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3ooooooooooooo
T_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooo
oonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooo
oooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3ooooo
ooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oo
oooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0
oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003ooooooooo
o`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooo
oooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000oooo
ooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003o
ooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`00
0?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o
0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool0
0ol0003oooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSoooo
o`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?o
oooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?oooooo
Hoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooo
oomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003o
ooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool0
0?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Ooooo
o`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oo
oooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool0
7oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003ooooooooo
o`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooo
oooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000oooo
ooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003o
ooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`00
0?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o
0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool0
0ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBoooo
o`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;o
oooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3ooooooooooooo
T_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooo
oonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooo
oooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3ooooo
ooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oo
oooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0
oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003ooooooooo
o`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooo
oooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000oooo
ooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003o
ooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`00
0?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o
0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool0
0ol0003oooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSoooo
o`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?o
oooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?oooooo
Hoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooo
oomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003o
ooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool0
0?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Ooooo
o`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oo
oooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool0
7oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003ooooooooo
o`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooo
oooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000oooo
ooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003o
ooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`00
0?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o
0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool0
0ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBoooo
o`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;o
oooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3ooooooooooooo
T_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooo
oonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooo
oooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3ooooo
ooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oo
oooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0
oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003ooooooooo
o`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooo
oooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000oooo
ooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003o
ooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`00
0?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o
0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool0
0ol0003oooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSoooo
o`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?o
oooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?oooooo
Hoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooo
oomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003o
ooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool0
0?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Ooooo
o`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oo
oooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool0
7oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003ooooooooo
o`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooo
oooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000oooo
ooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003o
ooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`00
0?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o
0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool0
0ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBoooo
o`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;o
oooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3ooooooooooooo
T_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooo
oonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooo
oooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3ooooo
ooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oo
oooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0
oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003ooooooooo
o`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooo
oooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000oooo
ooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003o
ooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`00
0?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o
0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool0
0ol0003oooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooooomSoooo
o`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003oooooof?o
oooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool00?oooooo
Hoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Oooooo`00oooo
oomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oooooo003o
ooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool07oooool0
0?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003oooooooooo`0Ooooo
o`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooooooo01oo
oooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000ooooooooool0
7oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003ooooooooo
o`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`000?oooooo
oooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o0000oooo
ooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool00ol0003o
ooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBooooo`03o`00
0?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooi;ooooo00?o
0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooooooooooT_ooool0
0ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooonBoooo
o`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooooh[o
oooo0ol9jPX5ooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0
oooooooooooooh_ooooo1_l9jPX2o`00027ooooo003oooooof?ooooo00?o0000ooooooooool0oooo
ooo/ooooojKo2NX:8Oooool00?ooooooFoooool3o`WZ2PGooooo00?o0000ooooooooool0oooooolA
oooooooo2NX:4ol9jPYWooooo`Go2NX:0_ooool00ol0003oooooooooo`0Oooooo`00oooooomLoooo
o`Ko2NX:00?oooooo`000?l00000Boooooolo`WZ2_oooooo@oooool2o`WZ2PKooooo00?o0000oooo
ooooool07oooool00>[oooooi_l9jP[ooooooooooooo9oooool00ol0003oooooooooo`0Oooooo`00
9?ooooo/o`WZ2TOooooo2_l9jPX01?oooooo0000ooooooooool5o`WZ2_ooooooYOooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`000?oooooooooo01oooooo000Ioooooe;o2NX:koooool2o`WZ2PGooooo
3_l9jPZiooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol0003ooooo
ooooo`0Oooooo`00oooooomSooooo`03o`WZ2_oooooooooo00Kooooo2?l9jPX@ooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo01gooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo01kooooo00?o0000ooooooooool07oooool007cooooo0_l9jPXOooooo`03o`WZ2_oooooo
2NX:01kooooo00?o2NX:ooooool9jPX07_ooool01?l9jP[oooooooooool9jPXMooooo`04o`WZ2_oo
ooooooooo`WZ2Qgooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool06Oooool00ol9jP[oooooooooo`0>ooooo`Go2NX:2oooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Mooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`000?oooooooooo01oooooo000Iooooo`03o`WZ2_oooooooooo01kooooo
0_l9jPXOooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[ooooo
o`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9
jP[ooooooooooooooooo2NX:01_ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0I
ooooo`03o`WZ2_oooooooooo01?ooooo1_l9jPX5ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000
ooooooooool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOoooo
o`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Noooo
o`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooo
oooooooo2NX:01_ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0Iooooo`03o`WZ
2_oooooooooo00Wooooo00?o2NX:ooooooooool03?ooool7o`WZ2R3ooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool0
7oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oo
oooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_oo
ooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:
01_ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0Iooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool04Oooool6o`WZ2Qcooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool07oooool001Wo
oooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01ko
oooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ
2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01_ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0Iooooo`03o`WZ2_oooooooooo00Sooooo00?o
2NX:ooooooooool04oooool00ol9jP[oooooooooo`06o`WZ2QSooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool07ooo
ool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo
2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_oooooo
ooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01_o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0Iooooo`03o`WZ2_oooooooooo00So
oooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`05ooooo`Ko2NX:4oooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol0003o
ooooooooo`0Oooooo`006Oooool00ol9jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo
00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo
00Co2NX:oooooooooooo2NX:7Oooool01?l9jP[oooooooooool9jPXMooooo`05o`WZ2_oooooooooo
ooooool9jPX06oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo01Wooooo00?o2NX:
ooooooooool02?ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo00[ooooo1Ol9jPX?
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0M
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`000?oooooooooo01oooooo000Iooooo`03o`WZ2_oooooooooo01kooooo0_l9jPXOoooo
o`;o2NX:7oooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:oooo
ool9jPX07_ooool01?l9jP[oooooooooool9jPXMooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Go
2NX:ooooooooooooooooo`WZ2P0Kooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
6Oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool0
3_ooool5o`WZ2P_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool07_oo
ool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_oo
ool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo
2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0K
ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0C
ooooo`Go2NX:1_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Mooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`006Oooool00ol9jP[oooooooooo`0Noooo
o`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Noooo
o`03o`WZ2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:7Oooool01?l9jP[oooooooooool9
jPXMooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool01Ol9jP[ooooooooooooooooo2NX:01_o
oooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo00Wo
oooo00?o2NX:ooooooooool03?ooool5o`WZ2P03ooooool9jP[ooooo01oooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo000Iooooo`03o`WZ
2_oooooooooo01kooooo0_l9jPXOooooo`;o2NX:7oooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ
2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool01?l9jP[oooooooooool9jPXMooooo`04
o`WZ2_ooooooooooo`WZ2Qgooooo00Go2NX:ooooooooooooooooo`WZ2P0Looooo`05o`WZ2_oooooo
ooooooooool9jPX06oooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo01Cooooo00?o
2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0Aooooo`Ko2NX:7?ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool07oooool001Wooooo00?o2NX:
ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:
ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co
2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01cooooo00Go2NX:oooooooo
ooooooooo`WZ2P0Kooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool05?ooool00ol9
jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool01ol9jPXGoooo
o`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Noooo
o`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Noooo
o`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Moooo
o`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Noooo
o`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Noooo
o`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol0003oooooooooo`0Ooooo
o`006Oooool00ol9jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:ooooool9
jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00Co2NX:oooooooo
oooo2NX:7Oooool01?l9jP[oooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX07?oo
ool01Ol9jP[ooooooooooooooooo2NX:01_ooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooo
ooooo`0Dooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool04oooool00ol9jP[ooooo
ooooo`05ooooo`Oo2NX:4_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo
00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo
00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo
00?o2NX:ooooooooool07Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo
00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo
00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo
00?o0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9
jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ
2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[o
oooooooooooooooo2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`03o`WZ2_oooooo
oooo00Oooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooo
oooo01?ooooo00?o2NX:ooooooooool02_ooool7o`WZ2Pgooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo000Iooooo`03o`WZ2_oooooooooo
01kooooo0_l9jPXOooooo`;o2NX:7oooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:
01kooooo00?o2NX:ooooool9jPX07_ooool01?l9jP[oooooooooool9jPXMooooo`04o`WZ2_oooooo
ooooo`WZ2Qgooooo00Go2NX:ooooooooooooooooo`WZ2P0Looooo`05o`WZ2_ooooooooooooooool9
jPX06oooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:oooooooo
ool02?ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo00kooooo1ol9jPX9ooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Mooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`00
6Oooool00ol9jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX0
7_ooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00Co2NX:oooooooooooo
2NX:7Oooool01?l9jP[oooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool0
1Ol9jP[ooooooooooooooooo2NX:01_ooooo00?o2NX:ooooooooool01_ooool00ol9jP[ooooooooo
o`0Eooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool05?ooool00ol9jP[ooooooooo
o`0Cooooo`Ko2NX:1Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXO
ooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0N
ooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooo
oooooooooooo2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`03o`WZ2_oooooooooo
00Kooooo00?o2NX:ooooooooool05Oooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo
01Cooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`0=ooooo`Oo2NX:8?ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo000Iooooo`03o`WZ2_oooooooooo01ko
oooo0_l9jPXOooooo`;o2NX:7oooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01ko
oooo00?o2NX:ooooool9jPX07_ooool01?l9jP[oooooooooool9jPXMooooo`04o`WZ2_oooooooooo
o`WZ2Qgooooo00Go2NX:ooooooooooooooooo`WZ2P0Looooo`05o`WZ2_ooooooooooooooool9jPX0
6oooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:ooooooooool0
1oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool0
4Oooool6o`WZ2Qgooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Mooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`006Ooo
ool00ol9jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_oo
ool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:
7Oooool01?l9jP[oooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool01Ol9
jP[ooooooooooooooooo2NX:01_ooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0E
ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`08
ooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool01_l9jPXHooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ
2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9
jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Ooo
ool01Ol9jP[ooooooooooooooooo2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`03
o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool05Oooool00ol9jP[oooooooooo`06ooooo`03
o`WZ2_oooooooooo01Gooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`0Cooooo`03
o`WZ2_oooooooooo00Gooooo1Ol9jPXDooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000oooooooo
ool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ
2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ
2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo
2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`03o`WZ2_oooooooooo00Gooooo00?o
2NX:ooooooooool05_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo00?o
2NX:ooooooooool01oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00[ooooo1?l9
jPX@ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool07oooool001Wooooo00?o2NX:
ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:
ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co
2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01cooooo00Go2NX:oooooooo
ooooooooo`WZ2P0Kooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool05_ooool00ol9
jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:ooooooooool01oooool00ol9
jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00kooooo1Ol9jPX;ooooo`03o`WZ2_oooooooooo
01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
01kooooo00?o0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoo
oooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[o
ooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool0
1Ol9jP[ooooooooooooooooo2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`03o`WZ
2_oooooooooo00Gooooo00?o2NX:ooooooooool05_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ
2_oooooooooo01Gooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ
2_oooooooooo01?ooooo1Ol9jPX6ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool0
7Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool0
7_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool0
7oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oo
oooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_oo
ooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:
01cooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:
ooooooooool05_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:
ooooooooool01oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:
ooooooooool03Oooool5o`WZ2P03ooooool9jP[ooooo01oooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool07oooool0
01Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:
01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_oooooooooo
o`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01cooooo
00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool05oooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:oooooooo
ool01oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:oooooooo
ool04Oooool7o`WZ2Qcooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool0
7_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX0
7_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooo
oooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ
2P0Kooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool05oooool00ol9jP[ooooooooo
o`05ooooo`03o`WZ2_oooooooooo01Kooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooooooo
o`0Dooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool04oooool00ol9jP[ooooooooo
o`07o`WZ2QOooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo01kooooo00?o0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2
o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool0
0ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:
7Oooool01Ol9jP[ooooooooooooooooo2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0Koooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool05oooool00ol9jP[oooooooooo`05oooo
o`03o`WZ2_oooooooooo01Kooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0Eoooo
o`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`05oooo
o`Oo2NX:4_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0Mooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooo
ooooool07_ooool00ol0003oooooooooo`0Oooooo`006Oooool00ol9jP[oooooooooo`0Nooooo`;o
2NX:7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`03
o`WZ2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:7Oooool01?l9jP[oooooooooool9jPXM
ooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool01Ol9jP[ooooooooooooooooo2NX:01_ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Gooooo`03o`WZ2_oooooooooo00Gooooo
00?o2NX:ooooooooool05_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo
00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00[ooooo
1_l9jPX>ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`000?oooooooooo01oooooo000Iooooo`03o`WZ2_oooooooooo01kooooo0_l9
jPXOooooo`;o2NX:7oooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00?o
2NX:ooooool9jPX07_ooool01?l9jP[oooooooooool9jPXMooooo`04o`WZ2_ooooooooooo`WZ2Qgo
oooo00Go2NX:ooooooooooooooooo`WZ2P0Looooo`05o`WZ2_ooooooooooooooool9jPX04oooool3
o`0000Gooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Hooooo`03o`WZ2_oooooo
oooo00Gooooo00?o2NX:ooooooooool05_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooo
oooo01Gooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooo
oooo00kooooo1ol9jPX9ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Fooooo`?o00001Oooool00ol0003oooooooooo`0Oooooo`006Oooool00ol9
jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool00ol9
jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:7Oooool0
1?l9jP[oooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool01Ol9jP[ooooo
oooooooooooo2NX:01Cooooo1_l000000ooooooo2NX:ooooo`04ooooo`03o`WZ2_oooooooooo01So
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Gooooo`03o`WZ2_oooooooooo00Ko
oooo00?o2NX:ooooooooool05Oooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo01Co
oooo00?o2NX:ooooooooool04oooool6o`WZ2PGooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01Oooooo1_l000000ooooooo0000ooooo`0Pooooo`00
6Oooool00ol9jP[o0000o`00000Oo`000003o`WZ2_l0003o000001ko000000?o2NX:o`000?l00000
7ol000000ol9jP[o0000o`00000No`000003o`WZ2_l0003o000001ko000000?o2NX:o`000?l00000
7ol000000ol9jP[o0000o`00000No`000003o`WZ2_l0003o000001oo000000?o2NX:o`000?l00000
7_l000000ol9jP[o0000o`00000Oo`000003o`WZ2_l0003o000001So000000?o2NX:o`000?l00000
1?l000000ol9jP[o0000o`00000Go`000003o`WZ2_l0003o000000Go000000?o2NX:o`000?l00000
5_l000000ol9jP[o0000o`000007o`000003o`WZ2_l0003o000001Co000000?o2NX:o`000?l00000
2?l000000ol9jP[o0000o`00000>o`0000Co2NX:00?o0000o`WZ2_l000007ol000000ol9jP[o0000
o`00000No`000003o`WZ2_l0003o000001ko000000?o2NX:o`000?l000007_l000000ol9jP[o0000
o`00000No`000003o`WZ2_l0003o000001ko000000?o2NX:o`000?l000007Ol000000ol9jP[o0000
o`00000No`000003o`WZ2_l0003o000001ko000000?o2NX:o`000?l000007_l000000ol9jP[o0000
o`00000No`000003o`WZ2_l0003o000001ko000000?o2NX:o`000?l000007_l000000ol9jP[o0000
o`00000No`000003o`WZ2_l0003o000001oo00008Oooool001Wooooo00?o2NX:ooooooooool07_oo
ool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_oo
ool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo
2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0D
ooooo`Go00000_ooool00ol9jP[o0000ooooo`03o`000003o`WZ2_l0003ooooo01Sooooo00?o2NX:
ooooooooool01?ooool00ol9jP[oooooooooo`0Gooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:
ooooooooool05_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:
ooooooooool02?ooool00ol9jP[oooooooooo`0Aooooo`Go2NX:7_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01Oooooo1Ol000000ooooooo0000o`00000Qooooo`006Oooool00ol9
jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool00ol9
jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:7Oooool0
1?l9jP[oooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool01Ol9jP[ooooo
oooooooooooo2NX:01?ooooo0_l00006ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooool0
00000ol0000Eooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool05oooool00ol9jP[o
ooooooooo`05ooooo`03o`WZ2_oooooooooo01Kooooo00?o2NX:ooooooooool01_ooool00ol9jP[o
ooooooooo`0Eooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool05?ooool00ol9jP[o
ooooooooo`05o`WZ2QWooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Fooooo`;o
00001_ooool00ol0003oooooooooo`0Oooooo`006Oooool00ol9jP[oooooooooo`0Nooooo`;o2NX:
7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ
2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:7Oooool01?l9jP[oooooooooool9jPXMoooo
o`05o`WZ2_ooooooooooooooool9jPX07?ooool01Ol9jP[ooooooooooooooooo2NX:01_ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`Go00004?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo01Sooooo00?o2NX:ooooooooool01Oooool00ol9jP[ooooooooo
o`0Fooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool05Oooool00ol9jP[ooooooooo
o`07ooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool01Oooool5o`WZ2QCooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01gooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo000I
ooooo`03o`WZ2_oooooooooo01kooooo0_l9jPXOooooo`;o2NX:7oooool00ol9jP[oooooo`WZ2P0N
ooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool01?l9jP[oooooooooool9
jPXMooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Go2NX:ooooooooooooooooo`WZ2P0Looooo`05
o`WZ2_ooooooooooooooool9jPX06oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00Wooooo1Ol0000;ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool06?ooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo01Oooooo00?o2NX:ooooooooool01_ooool00ol9
jP[oooooooooo`0Eooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool05?ooool00ol9
jP[oooooooooo`09ooooo`Go2NX:4?ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo
01kooooo00?o0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoo
oooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[o
ooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool0
1Ol9jP[ooooooooooooooooo2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool03_ooool4o`0000Oooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`0Hooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
5oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo01Kooooo00?o2NX:ooooooooool0
1oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00gooooo1_l9jPX;ooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Mooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ
2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`006Ooo
ool00ol9jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_oo
ool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:
7Oooool01?l9jP[oooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool01Ol9
jP[ooooooooooooooooo2NX:01_ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0B
ooooo`Go00000_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo01Sooooo00?o2NX:
ooooooooool01?ooool00ol9jP[oooooooooo`0Gooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:
ooooooooool05_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:
ooooooooool04_ooool6o`WZ2PKooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`000?oooooooooo01oooooo000Iooooo`03o`WZ2_oooooooooo01kooooo0_l9jPXOoooo
o`;o2NX:7oooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:oooo
ool9jPX07_ooool01?l9jP[oooooooooool9jPXMooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Go
2NX:ooooooooooooooooo`WZ2P0Looooo`05o`WZ2_ooooooooooooooool9jPX06oooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooooooo01Oooooo1?l00004ooooo`03o`WZ2_oooooooooo01So
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Gooooo`03o`WZ2_oooooooooo00Go
oooo00?o2NX:ooooooooool05_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Go
oooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0=ooooo`Go2NX:0_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool07oooool001Wooooo
00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo
00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgo
oooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01cooooo00Go2NX:
ooooooooooooooooo`WZ2P0Kooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool00ol9jP[ooooo
o`000003o`000003o`WZ2_oooooooooo01Sooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`0Gooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool05_ooool00ol9jP[ooooo
ooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooo
ooooo`0Booooo`Ko2NX:7Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo
00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01gooooo
00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo
00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo
00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo
000Iooooo`03o`WZ2_oooooooooo01kooooo0_l9jPXOooooo`;o2NX:7oooool00ol9jP[oooooo`WZ
2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool01?l9jP[ooooooooo
ool9jPXMooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Go2NX:ooooooooooooooooo`WZ2P0Loooo
o`05o`WZ2_ooooooooooooooool9jPX06oooool01Ol9jP[ooooooooooooooooo2NX:01cooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooo`000003o`0001Kooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`0Gooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool05_oo
ool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:ooooooooool01ooo
ool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo00Ko2NX:6?ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooooooo
o`0Nooooo`03o`000?oooooooooo01oooooo000Iooooo`03o`WZ2_oooooooooo01kooooo0_l9jPXO
ooooo`;o2NX:7oooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:
ooooool9jPX07_ooool01?l9jP[oooooooooool9jPXMooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo
00Go2NX:ooooooooooooooooo`WZ2P0Looooo`05o`WZ2_ooooooooooooooool9jPX06oooool01Ol9
jP[ooooooooooooooooo2NX:01cooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`Go00004Oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo01Sooooo00?o2NX:
ooooooooool01Oooool00ol9jP[oooooooooo`0Fooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:
ooooooooool05Oooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:
ooooooooool01Oooool6o`WZ2Q?ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0M
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol0003oooooooooo`0O
ooooo`006Oooool00ol9jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:oooo
ool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00Co2NX:oooo
oooooooo2NX:7Oooool01?l9jP[oooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX0
7?ooool01Ol9jP[ooooooooooooooooo2NX:01_ooooo00Co2NX:oooooooooooo2NX:7Oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Sooooo1Ol0000<ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool06?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
01Oooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0Eooooo`03o`WZ2_oooooooooo
00Oooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`09ooooo`Oo2NX:3_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo000Iooooo`03o`WZ2_oooooooooo01ko
oooo0_l9jPXOooooo`;o2NX:7oooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01ko
oooo00?o2NX:ooooool9jPX07_ooool01?l9jP[oooooooooool9jPXMooooo`04o`WZ2_oooooooooo
o`WZ2Qgooooo00Go2NX:ooooooooooooooooo`WZ2P0Looooo`05o`WZ2_ooooooooooooooool9jPX0
6oooool01?l9jP[oooooooooool9jPXMooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool03Oooool4o`0000Sooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Hooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool05oooool00ol9jP[oooooooooo`05ooooo`03
o`WZ2_oooooooooo01Kooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0Dooooo`03
o`WZ2_oooooooooo00kooooo1_l9jPX:ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000oooooooo
ool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ
2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ
2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo
2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo
00Go2NX:ooooooooooooooooo`WZ2P0Dooooo`Go00000oooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo01Sooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Gooooo`03
o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool05_ooool00ol9jP[oooooooooo`06ooooo`03
o`WZ2_oooooooooo01Gooooo00?o2NX:ooooooooool04oooool5o`WZ2PKooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Mooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooooooo
ool07_ooool00ol0003oooooooooo`0Oooooo`006Oooool00ol9jP[oooooooooo`0Nooooo`;o2NX:
7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ
2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:7Oooool01?l9jP[oooooooooool9jPXMoooo
o`05o`WZ2_ooooooooooooooool9jPX07?ooool01Ol9jP[ooooooooooooooooo2NX:01_ooooo00Co
2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01Wooooo1?l00004ooooo`03
o`WZ2_oooooooooo01Wooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Gooooo`03
o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool05_ooool00ol9jP[oooooooooo`06ooooo`03
o`WZ2_oooooooooo01Gooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0>ooooo`Go
2NX:00?oooooo`WZ2_ooool07oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01ko
oooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Mooooo`03o`WZ2_oooooooooo01ko
oooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01ko
oooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01ko
oooo00?o2NX:ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`006Oooool00ol9jP[ooooo
ooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[ooooo
o`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:7Oooool01?l9jP[o
ooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool01Ol9jP[ooooooooooooo
oooo2NX:01_ooooo00?o2NX:ooooool9jPX07_ooool01Ol9jP[ooooooooooooooooo2NX:01cooooo
00?o2NX:o`000?l000000_l000000ol9jP[oooooooooo`0Iooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool06?ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo01Kooooo
00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0Eooooo`03o`WZ2_oooooooooo00Oooooo
00?o2NX:ooooooooool04_ooool5o`WZ2Qkooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool07oooool001Wooooo00?o
2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o
2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo
00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01cooooo00Go2NX:oooo
ooooooooooooo`WZ2P0Kooooo`03o`WZ2_oooooo2NX:01kooooo00Go2NX:ooooooooooooooooo`WZ
2P0Looooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:o`000?l000000ol0000Fooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool06?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo01Oooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0Eooooo`03o`WZ2_oo
oooooooo00Oooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`05o`WZ2QWooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXO
ooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0N
ooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooo
oooooooooooo2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`03o`WZ2_oooooo2NX:
01kooooo00Co2NX:oooooooooooo2NX:7Oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo1?l0000Booooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool06?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo01Oooooo00?o2NX:ooooooooool01Oooool0
0ol9jP[oooooooooo`0Fooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool05?ooool0
0ol9jP[oooooooooo`05ooooo`Co2NX:5Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Mooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`006Oooool00ol9
jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool00ol9
jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:7Oooool0
1?l9jP[oooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool01Ol9jP[ooooo
oooooooooooo2NX:01_ooooo00?o2NX:ooooool9jPX07_ooool01?l9jP[oooooooooool9jPXMoooo
o`05o`WZ2_ooooooooooooooool9jPX02_ooool5o`0000gooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`0Hooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool05oooool0
0ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo01Kooooo00?o2NX:ooooooooool01_ooool0
0ol9jP[oooooooooo`0Eooooo`03o`WZ2_oooooooooo00Wooooo1Ol9jPX@ooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01gooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`000?oooooo
oooo01oooooo000Iooooo`03o`WZ2_oooooooooo01kooooo0_l9jPXOooooo`;o2NX:7oooool00ol9
jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool01?l9
jP[oooooooooool9jPXMooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Go2NX:oooooooooooooooo
o`WZ2P0Looooo`05o`WZ2_ooooooooooooooool9jPX06oooool00ol9jP[oooooo`WZ2P0Nooooo`04
o`WZ2_ooooooooooo`WZ2Qgooooo00Go2NX:ooooooooooooooooo`WZ2P0?ooooo`Co00002Oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo01Wooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`0Gooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool05_ooool0
0ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:ooooooooool03Oooool6
o`WZ2P_ooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ
2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9
jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Ooo
ool01Ol9jP[ooooooooooooooooo2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`03
o`WZ2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo
2NX:01?ooooo1Ol00004ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool06Oooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo01Sooooo00?o2NX:ooooooooool01Oooool0
0ol9jP[oooooooooo`0Fooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool05Oooool0
0ol9jP[oooooooooo`0Booooo`Ko2NX:1_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Mooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo
oooo01kooooo00?o2NX:ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`006Oooool00ol9
jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool00ol9
jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:7Oooool0
1?l9jP[oooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool01Ol9jP[ooooo
oooooooooooo2NX:01_ooooo0_l9jPXOooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Go2NX:oooo
ooooooooooooo`WZ2P0Hooooo`Co000000?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0I
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool06?ooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo01Oooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0E
ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool03Oooool5o`WZ2P;ooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:
ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000
ooooooooool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOoooo
o`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Noooo
o`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooo
oooooooo2NX:01cooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`;o2NX:7oooool01?l9jP[o
ooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX07?ooool5o`000003o`WZ2_oooooo
oooo01Wooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Hooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool05oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooo
oooo01Kooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0Booooo`Go2NX:7_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool07oooool0
01Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:
01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_oooooooooo
o`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01cooooo
00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`;o2NX:7oooool00ol9jP[oooooo`WZ2P0Nooooo`05
o`WZ2_ooooooooooooooool9jPX07?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_l0003o0000
00;o00005oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo01Sooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`0Gooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:oooo
ooooool05_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:oooo
ooooool01Ol9jPXIooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Mooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9
jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol0
003oooooooooo`0Oooooo`006Oooool00ol9jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoo
oooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01ko
oooo00Co2NX:oooooooooooo2NX:7Oooool01?l9jP[oooooooooool9jPXMooooo`05o`WZ2_oooooo
ooooooooool9jPX07?ooool01Ol9jP[ooooooooooooooooo2NX:01_ooooo0_l9jPXOooooo`03o`WZ
2_oooooo2NX:01kooooo00Co2NX:oooooooooooo2NX:7Oooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00;ooooo1?l0000Cooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool06Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo01Oooooo00?o2NX:oooooooo
ool01Oooool00ol9jP[oooooooooo`0Fooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:oooooooo
ool05Oooool00ol9jP[oooooooooo`05ooooo`Go2NX:5?ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool0
7_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX0
7_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooo
oooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01_ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`0Iooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooool9jPX07_ooool0
1?l9jP[oooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX02Oooool5o`0000kooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0Iooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool06?ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo01Kooooo
00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0Eooooo`03o`WZ2_oooooooooo00Wooooo
1_l9jPX?ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[ooooo
ooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol0003ooooo
ooooo`0Oooooo`006Oooool00ol9jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o
2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00Co
2NX:oooooooooooo2NX:7Oooool01?l9jP[oooooooooool9jPXMooooo`05o`WZ2_oooooooooooooo
ool9jPX06oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo01Wooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Go2NX:
ooooooooooooooooo`WZ2P0>ooooo`Co00002_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo01Wooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Hooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool05oooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oo
oooooooo01Gooooo00?o2NX:ooooooooool03_ooool5o`WZ2P_ooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0Mooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_oo
ool00ol9jP[oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo000Iooooo`03o`WZ2_oooooo
oooo01kooooo0_l9jPXOooooo`;o2NX:7oooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo
2NX:01kooooo00?o2NX:ooooool9jPX07_ooool01?l9jP[oooooooooool9jPXMooooo`04o`WZ2_oo
ooooooooo`WZ2Qgooooo00Go2NX:ooooooooooooooooo`WZ2P0Kooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool06Oooool00ol9jP[oooooooooo`0Nooooo`;o2NX:7oooool01?l9jP[o
ooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX04_ooool5o`0000Gooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`0Iooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool06?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo01Oooooo00?o2NX:
ooooooooool01Oooool00ol9jP[oooooooooo`0Fooooo`03o`WZ2_oooooooooo01?ooooo1?l9jPX7
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07Oooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol0003oooooooooo`0O
ooooo`006Oooool00ol9jP[oooooooooo`0Nooooo`;o2NX:7oooool2o`WZ2Qoooooo00?o2NX:oooo
ool9jPX07_ooool00ol9jP[oooooo`WZ2P0Nooooo`03o`WZ2_oooooo2NX:01kooooo00Co2NX:oooo
oooooooo2NX:7Oooool01?l9jP[oooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX0
6oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo01Wooooo00?o2NX:ooooooooool0
7_ooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool01Ol9jP[ooooooooooooooooo2NX:01Oo
oooo1?l000000ooooooo2NX:ooooo`03ooooo`03o`WZ2_oooooooooo01Wooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`0Hooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool05oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo01Kooooo00?o2NX:oooooooo
ool01_ooool00ol9jP[oooooooooo`0>ooooo`Go2NX:0_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03
o`WZ2_oooooooooo01kooooo00?o0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool0
7_ooool2o`WZ2Qoooooo0_l9jPXOooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX0
7_ooool00ol9jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooo
oooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:01_ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`0Hooooo`;o2NX:8?ooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool0
1?l9jP[oooooooooool9jPXLooooo`Go000000?oooooo`WZ2_ooool06_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo01Sooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`0Gooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool05_ooool00ol9jP[ooooooooo
o`06ooooo`03o`WZ2_oooooooooo01?ooooo1Ol9jPXNooooo`03o`WZ2_oooooooooo01gooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o
0000ooooooooool07oooool001Wooooo00?o2NX:ooooooooool07_ooool2o`WZ2Qoooooo0_l9jPXO
ooooo`03o`WZ2_oooooo2NX:01kooooo00?o2NX:ooooool9jPX07_ooool00ol9jP[oooooo`WZ2P0N
ooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooo
oooooooooooo2NX:01_ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0Hooooo`;o
2NX:8?ooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool01?l9jP[oooooooooool9jPXMoooo
o`05o`WZ2_ooooooooooooooool9jPX01?l0000Hooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool06?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo01Oooooo00?o2NX:
ooooooooool01Oooool00ol9jP[oooooooooo`0Fooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:
ooooooooool05Oooool00ol9jP[oooooooooo`05o`WZ2QWooooo00?o2NX:ooooooooool07Oooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool0
0ol0003oooooooooo`0Oooooo`00O?ooool2o`WZ2Qoooooo00?o2NX:ooooool9jPX07_ooool00ol9
jP[oooooo`WZ2P0Nooooo`04o`WZ2_ooooooooooo`WZ2Qgooooo00Co2NX:oooooooooooo2NX:7Ooo
ool01Ol9jP[ooooooooooooooooo2NX:01_ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`0Hooooo`;o2NX:8?ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooo2NX:01kooooo
00Co2NX:oooooooooooo2NX:7Oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo1?l0000Doooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool06Oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo01Oooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0Foooo
o`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool05Oooool00ol9jP[oooooooooo`05oooo
o`Ko2NX:4oooool00ol9jP[oooooooooo`0Mooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo003oooooof?o
oooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0Nooooo`;o2NX:7oooool01?l9jP[o
ooooooooool9jPXMooooo`05o`WZ2_ooooooooooooooool9jPX02?ooool5o`0000oooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`0Iooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool06?ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo01Kooooo00?o2NX:
ooooooooool01_ooool00ol9jP[oooooooooo`0Eooooo`03o`WZ2_oooooooooo00Wooooo1ol9jPX>
ooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[oooooooooo`0N
ooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool07oooool001WoooooDol9jP[^oooo
o`?o2NX:1Oooool00ol0003oooooooooo`0Nooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooo
ooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo00_ooooo1?l0000@oooo
o`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool06?ooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo01Oooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0Eoooo
o`03o`WZ2_oooooooooo00kooooo1ol9jPX9ooooo`03o`WZ2_oooooooooo01gooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:oooo
ooooool07_ooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o0000oooo
ooooool07oooool002Goooook?l9jPY:ooooo`Ko2NX:00?oooooo`000?ooool07oooool00ol9jP[o
ooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[o
ooooooooo`0@ooooo`Go00002oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oo
oooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0/ooooo`Oo2NX:I_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`WZ2_oooooooooo01kooooo00?o2NX:ooooooooool07_ooool00ol9jP[o
ooooooooo`0Nooooo`03o`000?oooooooooo01oooooo003[ooooonKo2NX:6?ooool00ol9jP[ooooo
ooooo`0Eooooo`Co00001_ooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo
00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00kooooo
1ol9jP[ooooood[ooooo00?o0000ooooooooool07oooool00?ooooooG?ooool5o`WZ2P;ooooo0_l0
0005o`WZ2QWooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooocoo2NX:1Ol0
002Vo`WZ2_oooooo?_ooool3o`WZ2PGooooo00?o0000ooooooooool07oooool00?ooooooFoooool2
o`WZ2PKooooo00?o0000ooooooooool01?ooool6o`WZ2Q?ooooo00?o2NX:ooooooooool07oooool0
0ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07_ooool0
0ol0003o2NX:o`000002o`0001kooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0P
ooooo`03o`WZ2_oooooooooo01Ooooooo?l9jPYVooooo`Ko2NX:00?oooooo`000?ooool08?ooool0
0?ooooooHoooool00ol0003oooooooooo`0:ooooo`Go2NX:3_ooool00ol9jP[oooooooooo`0Ooooo
o`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Poooo
o`04o`WZ2_ooooooooooooooo`Co00006_ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooo
oooo01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Mooooo`Go2NX:V?oooonU
o`WZ2R7ooooo003oooooof?ooooo00?o0000ooooooooool03oooool5o`WZ2PWooooo00?o2NX:oooo
ooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooo
ooooool07oooool00ol9jP[oooooooooo`06ooooo`Go00005Oooool00ol9jP[oooooooooo`0Ooooo
o`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Roooo
o`Ko2NX:oooooolaooooo`Go2NX:00?oooooo`000?l000008Oooool00?ooooooHoooool00ol0003o
ooooooooo`0Dooooo`Go2NX:9_ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oo
oooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0;ooooo`Co00004?ooool00ol9jP[o
ooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[o
ooooooooo`0Wooooo`Go2NX:ooooool/ooooo`;o2NX:1_ooool00ol0003oooooooooo`0Oooooo`00
oooooomSooooo`03o`000?oooooooooo01Wooooo1?l9jPXRooooo`03o`WZ2_oooooooooo01oooooo
00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00oooooo
1Ol0000;ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[ooooo
ooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool02_ooool4o`WZ2_oooooo
<?ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo01gooooo1?l9
jPXMooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooooooo
o`0Oooooo`03o`WZ2_oooooooooo01Cooooo1?l00007ooooo`03o`WZ2_oooooooooo01oooooo00?o
2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o
2NX:ooooooooool03_ooool5o`WZ2_oooooo:oooool00ol0003oooooooooo`0Oooooo`00oooooomS
ooooo`03o`000?oooooooooo027ooooo1Ol9jPXHooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:
ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01Sooooo1Ol00002
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0O
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool05?ooool5o`WZ2_oooooo9_ooool0
0ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo02Kooooo1?l9jPXDoooo
o`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Poooo
o`03o`WZ2_oooooooooo01gooooo0_l000000ol9jP[o0000o`00000Oooooo`03o`WZ2_oooooooooo
01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo
01Wooooo1Ol9jP[oooooob7ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003o
ooooooooo`0Zooooo`Go2NX:3oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oo
oooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo00Co
00006oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0Nooooo`Go2NX:oooooolLooooo`03o`000?oooooooooo01oo
oooo003oooooof?ooooo00?o0000ooooooooool0;oooool4o`WZ2P[ooooo00?o2NX:ooooooooool0
8?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool0
7oooool00ol9jP[oooooooooo`05ooooo`Go00005_ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ
2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Rooooo`Ko2NX:
oooooolGooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0<ooo
ool4o`WZ2RSooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool02_ooool4o`00017ooooo00?o2NX:ooooooooool08?oo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool09ooo
ool6o`WZ2_oooooo4_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooo
oooo03Oooooo1Ol9jPXSooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?ooool0
0ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00kooooo1Ol0000<ooooo`03o`WZ2_oooooo
oooo01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooo
oooo01oooooo00?o2NX:ooooooooool02_ooool6o`WZ2_oooooo3Oooool00ol0003oooooooooo`0O
ooooo`00oooooomSooooo`03o`000?oooooooooo03cooooo1?l9jPXOooooo`03o`WZ2_oooooooooo
01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo
01?ooooo1Ol00007ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool03_ooool6o`WZ
2_oooooo2Oooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo043o
oooo1?l9jPXKooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[o
ooooooooo`0Oooooo`03o`WZ2_oooooooooo01Wooooo1?l00003ooooo`03o`WZ2_oooooooooo01oo
oooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oo
oooo00?o2NX:ooooooooool05?ooool5o`WZ2_oooooo1Oooool00ol0003oooooooooo`0Oooooo`00
oooooomSooooo`03o`000?oooooooooo04Cooooo1Ol9jPXEooooo`03o`WZ2_oooooooooo023ooooo
00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01gooooo
0_l000000ol9jP[o0000o`00000Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool0
7oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01Wooooo1Ol9jP[oooooo`03o`00
0?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0BOooool4o`WZ2Q7ooooo00?o
2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o
2NX:ooooooooool07oooool00ol9jP[oooooooooo`04o`0001_ooooo00?o2NX:ooooooooool08?oo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07Ooo
ool5o`WZ2__ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`1=
ooooo`Co2NX:3Oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:
ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00Cooooo1Ol0000F
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0O
ooooo`03o`WZ2_oooooooooo02;ooooo1Ol9jP[fooooo`03o`000?oooooooooo01oooooo003ooooo
of?ooooo00?o0000ooooooooool0DOooool4o`WZ2R_ooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool02Oooool4o`00
01;ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo
023ooooo00?o2NX:ooooooooool09oooool5o`WZ2_7ooooo00?o0000ooooooooool07oooool00?oo
ooooHoooool00ol0003oooooooooo`1Eooooo`Go2NX:9_ooool00ol9jP[oooooooooo`0Oooooo`03
o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0>ooooo`Go
00003Oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00[ooooo1Ol9jP[]ooooo`03
o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0F_ooool4o`WZ2R7ooooo
00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo
00?o2NX:ooooooooool04oooool5o`0000Oooooo00?o2NX:ooooooooool08?ooool00ol9jP[ooooo
ooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooo
ooooo`0>ooooo`Ko2NX:j?ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oo
oooooooo05kooooo1?l9jPXMooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?oo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01Sooooo1?l00003ooooo`03o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool04oooool6o`WZ2^?ooooo00?o0000ooooooooool07ooo
ool00?ooooooHoooool00ol0003oooooooooo`1Rooooo`Go2NX:6?ooool00ol9jP[oooooooooo`0O
ooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0L
ooooo`?o000000?o2NX:o`000?ooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooo
oooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Hooooo`Go2NX:goooool0
0ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo06Oooooo1?l9jPXDoooo
o`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Poooo
o`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooool000000ol0000Looooo`03o`WZ2_oooooooooo
01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo
01kooooo1_l9jP[Iooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000oooooooo
ool0Joooool5o`WZ2Pkooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03
o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`04ooooo`Go
00005oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0Sooooo`Ko2NX:e?ooool00ol0003oooooooooo`0Oooooo`00
oooooomSooooo`03o`000?oooooooooo073ooooo1?l9jPX/ooooo`03o`WZ2_oooooooooo023ooooo
00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00Wooooo
1?l0000Booooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooo
ooooo`0Oooooo`03o`WZ2_oooooooooo02Sooooo1_l9jP[?ooooo`03o`000?oooooooooo01oooooo
003oooooof?ooooo00?o0000ooooooooool0M?ooool4o`WZ2RSooooo00?o2NX:ooooooooool08?oo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool03Ooo
ool5o`0000gooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0;ooooo`Ko2NX:b_oo
ool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo07Sooooo1Ol9jPXS
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0O
ooooo`03o`WZ2_oooooooooo01;ooooo1Ol00008ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:
ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:
ooooooooool03oooool6o`WZ2/Kooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0
003oooooooooo`1mooooo`Co2NX:7oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo
01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Gooooo`Co00001?ooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01Gooooo1Ol9jP[2ooooo`03o`000?oooooooooo
01oooooo003oooooof?ooooo00?o0000ooooooooool0POooool5o`WZ2Q[ooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool07?ooool4o`000003o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[o
ooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool06_ooool5o`WZ2[go
oooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`26ooooo`Co2NX:
5_ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool0
7oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooo000000?o00007Oooool00ol9jP[ooooo
ooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooo
ooooo`0Nooooo`Ko2NX:^?ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oo
oooooooo08[ooooo1?l9jPXBooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07ooo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool00ooo
ool5o`0001Sooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool08oooool6o`WZ2[?ooooo00?o0000ooooooooool07ooo
ool00?ooooooHoooool00ol0003oooooooooo`2>ooooo`Go2NX:3?ooool00ol9jP[oooooooooo`0P
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0O
ooooo`03o`WZ2_oooooooooo00Sooooo1?l0000Cooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:
ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo02Sooooo1_l9jPZ^
ooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0Toooool5o`WZ
2RWooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo
01oooooo00?o2NX:ooooooooool03?ooool5o`0000kooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0:ooooo`Oo2NX:ZOooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03
o`000?oooooooooo09Sooooo1Ol9jPXTooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo017ooooo1Ol00009ooooo`03
o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03
o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool03oooool7o`WZ2ZCooooo00?o0000oooooooo
ool07oooool00?ooooooHoooool00ol0003oooooooooo`2Mooooo`Go2NX:7oooool00ol9jP[ooooo
ooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[ooooo
ooooo`0Fooooo`Co00001Oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo
00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01Gooooo
1ol9jPZOooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0X_oo
ool5o`WZ2Q[ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool06oooool5o`000003o`WZ2_oooooooooo01oooooo00?o
2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o
2NX:ooooooooool06_ooool6o`WZ2Y_ooooo00?o0000ooooooooool07oooool00?ooooooHoooool0
0ol0003oooooooooo`2Wooooo`Go2NX:5?ooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooo
oooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_l0003o
000000;o00007Oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:
ooooooooool07oooool00ol9jP[oooooooooo`0Nooooo`Ko2NX:Uoooool00ol0003oooooooooo`0O
ooooo`00oooooomSooooo`03o`000?oooooooooo0:cooooo1Ol9jPX?ooooo`03o`WZ2_oooooooooo
01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo
01oooooo00?o2NX:ooooooooool00_ooool5o`0001Sooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08oooool6o`WZ
2Y;ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`2aooooo`Co
2NX:2oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00Oooooo1Ol0000Cooooo`03
o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03
o`WZ2_oooooooooo02Sooooo1Ol9jPZ>ooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo
00?o0000ooooooooool0]Oooool4o`WZ2RWooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooo
ooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool03?ooool4o`0000oooooo
00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo
00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0;ooooo`Ko2NX:ROooool00ol0003ooooo
ooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0;Wooooo1Ol9jPXTooooo`03o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo017ooooo1Ol0000:ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07ooo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool04?oo
ool5o`WZ2XGooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`2n
ooooo`Co2NX:7oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:
ooooooooool07oooool00ol9jP[oooooooooo`0Fooooo`Co00001Oooool00ol9jP[oooooooooo`0O
ooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0O
ooooo`03o`WZ2_oooooooooo01Gooooo1Ol9jPZ0ooooo`03o`000?oooooooooo01oooooo003ooooo
of?ooooo00?o0000ooooooooool0`_ooool5o`WZ2Q[ooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool06_ooool5o`00
0003o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Poooo
o`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool06Oooool5o`WZ2Wcooooo00?o0000oooo
ooooool07oooool00?ooooooHoooool00ol0003oooooooooo`37ooooo`Co2NX:5_ooool00ol9jP[o
ooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[o
ooooooooo`0Oooooo`04o`WZ2_l0003o0000o`0001kooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool5o`WZ
2WOooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3;ooooo`Co
2NX:4_ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0Pooooo`04o`WZ2_ooooooooooooooo`Go00006Oooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Tooooo`Go2NX:L_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03
o`000?oooooooooo0<oooooo1Ol9jPX<ooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool01oooool5o`0001Cooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03
o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool0:Oooool6o`WZ2Vcooooo00?o0000oooooooo
ool07oooool00?ooooooHoooool00ol0003oooooooooo`3Dooooo`Co2NX::_ooool00ol9jP[ooooo
ooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooo
ooooo`0<ooooo`Co00003oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo
00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00_ooooo
1ol9jPYWooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0f?oo
ool5o`WZ2RGooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool04?ooool5o`0000[ooooo00?o2NX:ooooooooool07ooo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07ooo
ool00ol9jP[oooooooooo`0@ooooo`Oo2NX:H_ooool00ol0003oooooooooo`0Oooooo`00oooooomS
ooooo`03o`000?oooooooooo0=gooooo1?l9jPXQooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:
ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01Gooooo1?l00006
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0P
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool05Oooool7o`WZ2Ugooooo00?o0000
ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3Qooooo`Co2NX:7Oooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Jooooo`Go000000?oooooo`WZ2_ooool08?ooool00ol9jP[oooooooooo`0Ooooo
o`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Joooo
o`Ko2NX:FOooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0>Go
oooo1Ol9jPXGooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[o
ooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00Co2NX:o`000?l0003o00007oooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Oooooo`Ko2NX:EOooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03
o`000?oooooooooo0>[ooooo1?l9jPXCooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00Co2NX:oooooooo
oooooooo1Ol0000Jooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo02Cooooo1_l9jPY@ooooo`03o`000?oooooooooo
01oooooo003oooooof?ooooo00?o0000ooooooooool0k_ooool4o`WZ2Poooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`06ooooo`Go00005Oooool00ol9jP[oooooooooo`0Oooooo`03
o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Yooooo`Go
2NX:C?ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?;ooooo
1Ol9jPX/ooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooo
ooooo`0Oooooo`03o`WZ2_oooooooooo00_ooooo1?l0000@ooooo`03o`WZ2_oooooooooo01oooooo
00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo
00?o2NX:ooooooooool02oooool5o`WZ2TSooooo00?o0000ooooooooool07oooool00?ooooooHooo
ool00ol0003oooooooooo`3gooooo`Co2NX::?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0?ooooo`Go00002ooo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?oo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo013ooooo1Ol9jPY3ooooo`03o`000?oo
oooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0noooool4o`WZ2RCooooo00?o2NX:
ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:
ooooooooool05?ooool4o`0000Oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0O
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0F
ooooo`Co2NX:?oooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo
0?oooooo1?l9jPXPooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01Wooooo1Ol00002ooooo`03o`WZ2_oooooooooo
01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo
01oooooo00?o2NX:ooooooooool06_ooool5o`WZ2S[ooooo00?o0000ooooooooool07oooool00?oo
ooooHoooool00ol0003oooooooooo`3oooooo`Cooooo1Ol9jPXKooooo`03o`WZ2_oooooooooo01oo
oooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01ko
oooo00Co0000o`WZ2_l0003o00008?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo
01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Nooooo`Ko2NX:=Oooool00ol0
003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooo2Oooool4o`WZ2QKo
oooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oo
oooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`05o`0001[ooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool08oooool6o`WZ2S3ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003ooooo
ooooo`3oooooo`gooooo1?l9jPXBooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool0
7oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool0
1Oooool5o`0001Gooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ
2_oooooooooo023ooooo00?o2NX:ooooooooool0:?ooool6o`WZ2R_ooooo00?o0000ooooooooool0
7oooool00?ooooooHoooool00ol0003oooooooooo`3ooooooa7ooooo1Ol9jPX=ooooo`03o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo023ooooo00?o2NX:ooooooooool02_ooool4o`00017ooooo00?o2NX:ooooooooool07ooo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07ooo
ool00ol9jP[oooooooooo`0<ooooo`Ko2NX:9_ooool00ol0003oooooooooo`0Oooooo`00oooooomS
ooooo`03o`000?oooooooooo0?oooooo5_ooool4o`WZ2R_ooooo00?o2NX:ooooooooool07oooool0
0ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool03oooool5
o`0000cooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooo
oooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Aooooo`Ko2NX:8Oooool0
0ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooo6_ooool5o`WZ
2RKooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo
01oooooo00?o2NX:ooooooooool05?ooool4o`0000Oooooo00?o2NX:ooooooooool08?ooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Fooooo`Ko2NX:7?ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03
o`000?oooooooooo0?oooooo7oooool4o`WZ2R7ooooo00?o2NX:ooooooooool08?ooool00ol9jP[o
ooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool06?ooool5o`0000;o
oooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023o
oooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Jooooo`Ko2NX:6?ooool00ol0003o
ooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooo8oooool4o`WZ2Qgooooo
00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo
00?o2NX:ooooooooool07Oooool2o`000003o`WZ2_l0003o000001oooooo00?o2NX:ooooooooool0
7oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool0
8?ooool5o`WZ2QCooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003ooooooooo
o`3oooooobOooooo1Ol9jPXHooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07ooo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool01?l0
000Kooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooooooo
o`0Oooooo`03o`WZ2_oooooooooo02Gooooo1Ol9jPX7ooooo`;o2NX:1_ooool00ol0003ooooooooo
o`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooo;?ooool5o`WZ2Q?ooooo00?o2NX:
ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:
ooooooooool07oooool00ol9jP[oooooooooo`05ooooo`Go00005_ooool00ol9jP[oooooooooo`0O
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Z
ooooo`Go2NX:0_ooool4o`WZ2PCooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0
003oooooooooo`3ooooooc7ooooo1Ol9jPX=ooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:oooo
ooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooo
ooooool02_ooool4o`00017ooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Ooooo
o`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0<oooo
o`Wo2NX:0_ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oo
oooo=_ooool6o`WZ2RWooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03
o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool03_ooool5o`0000cooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0@ooooo`So2NX:8Oooool00?ooooooHoooool00ol0003ooooo
ooooo`3ooooooccooooo1Ol9jPXTooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool0
8?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01?ooooo1?l00008ooooo`03o`WZ
2_oooooooooo01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ
2_oooooooooo01oooooo00?o2NX:ooooooooool03oooool7o`WZ2P;o00001Ol9jPXLooooo`00oooo
oomSooooo`03o`000?oooooooooo0?oooooo@Oooool5o`WZ2Qoooooo00?o2NX:ooooooooool07ooo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool06?oo
ool5o`0000?ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Gooooo`03o`000?oo
oooooooo00?ooooo0ol9jPXIooooo`00oooooomSooooo`03o`000?oooooooooo0?ooooooA_ooool4
o`WZ2Q_ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooo
oooo01oooooo00?o2NX:ooooooooool07Oooool2o`000003o`WZ2_l0003o0000023ooooo00?o2NX:
ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:
ooooooooool06?ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo
0?ooooooB_ooool5o`WZ2QGooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Ooooo
o`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`04o`00
01cooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo
01oooooo00?o2NX:ooooooooool06?ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03
o`000?oooooooooo0?ooooooCoooool4o`WZ2Q7ooooo00?o2NX:ooooooooool07oooool00ol9jP[o
ooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[o
ooooooooo`04ooooo`Go00005oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oo
oooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Hooooo`03o`000?oooooooooo01oo
oooo003oooooof?ooooo00?o0000ooooooooool0oooooomCooooo`Co2NX:3Oooool00ol9jP[ooooo
ooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[ooooo
ooooo`0Oooooo`03o`WZ2_oooooooooo00Wooooo1?l0000Booooo`03o`WZ2_oooooooooo023ooooo
00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01Sooooo
00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3ooooooeOooooo1?l9
jPX[ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooooooo
o`0Pooooo`03o`WZ2_oooooooooo00gooooo1Ol0000=ooooo`03o`WZ2_oooooooooo01oooooo00?o
2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01Sooooo00?o
0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3ooooooe_ooooo1Ol9jPXV
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0P
ooooo`03o`WZ2_oooooooooo01;ooooo1?l00009ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:
ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01Wooooo00?o0000
ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooof3ooooo1?l9jPXQoooo
o`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Poooo
o`03o`WZ2_oooooooooo01Kooooo1Ol00004ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooo
ooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01Wooooo00?o0000oooo
ooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooofCooooo1?l9jPXMooooo`03
o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Oooooo`03
o`WZ2_oooooooooo01cooooo0ol000000ol9jP[o0000ooooo`0Pooooo`03o`WZ2_oooooooooo01oo
oooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Iooooo`03o`000?oooooooooo01oo
oooo003oooooof?ooooo00?o0000ooooooooool0oooooomXooooo`Go2NX:6?ooool00ol9jP[ooooo
ooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooo
ooooo`0Oooooo`03o`WZ2_oooooo000000?o00007?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ
2_oooooooooo023ooooo00?o2NX:ooooooooool06Oooool00ol0003oooooooooo`0Oooooo`00oooo
oomSooooo`03o`000?oooooooooo0?ooooooKOooool4o`WZ2QCooooo00?o2NX:ooooooooool07ooo
ool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07ooo
ool00ol9jP[oooooooooo`03ooooo`Go00005oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool06_ooool00ol0003oooooooooo`0Oooooo`00oooooomS
ooooo`03o`000?oooooooooo0?ooooooLOooool5o`WZ2Pkooooo00?o2NX:ooooooooool08?ooool0
0ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07oooool0
0ol9jP[oooooooooo`08ooooo`Co00004oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooo
oooo01oooooo00?o2NX:ooooooooool06_ooool00ol0003oooooooooo`0Oooooo`00oooooomSoooo
o`03o`000?oooooooooo0?ooooooM_ooool4o`WZ2Rgooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool03?ooool5o`00
00kooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo
01[ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooog[o
oooo1?l9jPXYooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[o
ooooooooo`0Oooooo`03o`WZ2_oooooooooo01;ooooo1?l00009ooooo`03o`WZ2_oooooooooo023o
oooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Jooooo`03o`000?oooooooooo01oo
oooo003oooooof?ooooo00?o0000ooooooooool0oooooomnooooo`Go2NX:8oooool00ol9jP[ooooo
ooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooo
ooooo`0Fooooo`Go00001?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo
00?o2NX:ooooooooool06oooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oo
oooooooo0?ooooooPoooool4o`WZ2Qoooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooooooo
o`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool06oooool4o`000003o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Kooooo`03o`000?oo
oooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooon7ooooo`Go2NX:6_ooool0
0ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?ooool0
0ol9jP[oooooooooo`0Oooooo`03o`WZ2_l0003o000000;o00007Oooool00ol9jP[oooooooooo`0O
ooooo`03o`WZ2_oooooooooo01_ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0
003oooooooooo`3oooooohcooooo1?l9jPXFooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooo
ooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:oooo
ooooool00_ooool5o`0001Sooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Koooo
o`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooon@ooooo`Co
2NX:4_ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00Sooooo1?l0000Cooooo`03
o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool06oooool00ol0003oooooooooo`0Oooooo`00
oooooomSooooo`03o`000?oooooooooo0?ooooooU?ooool5o`WZ2Pcooooo00?o2NX:ooooooooool0
8?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool0
7oooool00ol9jP[oooooooooo`0<ooooo`Go00003_ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ
2_oooooooooo01cooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003ooooooooo
o`3ooooooiWooooo1?l9jPXZooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?oo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo017ooooo1?l0000:ooooo`03o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`00oooooomS
ooooo`03o`000?oooooooooo0?ooooooWOooool4o`WZ2RKooooo00?o2NX:ooooooooool07oooool0
0ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool05Oooool5
o`0000Gooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Looooo`03o`000?oooooo
oooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooonQooooo`Go2NX:8Oooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9
jP[oooooooooo`0Kooooo`Co000000?o2NX:ooooooooool08?ooool00ol9jP[oooooooooo`0Loooo
o`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooonVooooo`Co
2NX:7Oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_l0003o000000;o00007_ooool00ol9jP[o
ooooooooo`0Looooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0
oooooonZooooo`Co2NX:6?ooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo
00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00;ooooo
1Ol0000Iooooo`03o`WZ2_oooooooooo01cooooo00?o0000ooooooooool07oooool00?ooooooHooo
ool00ol0003oooooooooo`3oooooojkooooo1?l9jPXDooooo`03o`WZ2_oooooooooo01oooooo00?o
2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o
2NX:ooooooooool01oooool4o`0001Cooooo00?o2NX:ooooooooool07Oooool00ol0003ooooooooo
o`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooo/_ooool5o`WZ2Poooooo00?o2NX:
ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:
ooooooooool08?ooool00ol9jP[oooooooooo`0;ooooo`Go00003oooool00ol9jP[oooooooooo`0M
ooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooongoooo
o`Co2NX:;Oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooo
ooooool08?ooool00ol9jP[oooooooooo`0@ooooo`Go00002_ooool00ol9jP[oooooooooo`0Moooo
o`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooonkooooo`Co
2NX::Oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool08?ooool00ol9jP[oooooooooo`0Eooooo`Co00001_ooool00ol9jP[oooooooooo`0Mooooo`03
o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooonoooooo`Go2NX:
8oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool0
7oooool00ol9jP[oooooooooo`0Jooooo`Go000000?oooooo`WZ2_ooool07_ooool00ol0003ooooo
ooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?ooooooa?ooool5o`WZ2Qkooooo00?o
2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o
2NX:ooooooooool07oooool01?l9jP[o0000o`000?l0000Mooooo`03o`000?oooooooooo01oooooo
003oooooof?ooooo00?o0000ooooooooool0ooooooo9ooooo`Go2NX:6Oooool00ol9jP[ooooooooo
o`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooooooo
o`0Oooooo`04o`WZ2_ooooooooooooooo`Go00006?ooool00ol0003oooooooooo`0Oooooo`00oooo
oomSooooo`03o`000?oooooooooo0?ooooooc_ooool6o`WZ2Q?ooooo00?o2NX:ooooooooool07ooo
ool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07ooo
ool00ol9jP[oooooooooo`06ooooo`Co00005?ooool00ol0003oooooooooo`0Oooooo`00oooooomS
ooooo`03o`000?oooooooooo0?ooooooe?ooool5o`WZ2Pgooooo00?o2NX:ooooooooool08?ooool0
0ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08?ooool0
0ol9jP[oooooooooo`0:ooooo`Go00001oooool2o`0000Kooooo00?o0000ooooooooool07oooool0
0?ooooooHoooool00ol0003oooooooooo`3oooooomWooooo1Ol9jPXZooooo`03o`WZ2_oooooooooo
023ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo
013ooooo1Ol00002ooooo`Co00001?ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03
o`000?oooooooooo0?oooooog_ooool5o`WZ2RGooooo00?o2NX:ooooooooool08?ooool00ol9jP[o
ooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool05Oooool8o`0000;o
oooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3oooooon?ooooo
1?l9jPXQooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooo
ooooo`0Oooooo`03o`WZ2_oooooooooo01Sooooo2?l0000Qooooo`00oooooomSooooo`03o`000?oo
oooooooo0?ooooooioooool4o`WZ2Qgooooo00?o2NX:ooooooooool07oooool00ol9jP[ooooooooo
o`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool05oooool9o`00027ooooo003o
ooooof?ooooo00?o0000ooooooooool0ooooooo[ooooo`Go2NX:5oooool00ol9jP[oooooooooo`0P
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0P
ooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0ooooooo`oooo
o`Co2NX:4oooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooo
ooooool07oooool00ol9jP[oooooooooo`0Pooooo`03o`000?oooooooooo01oooooo003oooooof?o
oooo00?o0000ooooooooool0ooooooodooooo`Co2NX:3oooool00ol9jP[oooooooooo`0Pooooo`03
o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0Pooooo`03
o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0ooooooohooooo`Go2NX:
2_ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo00?o2NX:ooooooooool0
7oooool00ol9jP[oooooooooo`0Pooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o
0000ooooooooool0ooooooomooooo`Co2NX::?ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo023ooooo00?o2NX:ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`00oooooomS
ooooo`03o`000?oooooooooo0?ooooooooooool2ooooo`Co2NX:9?ooool00ol9jP[oooooooooo`0O
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08Oooool00ol0003oooooooooo`0O
ooooo`00oooooomSooooo`03o`000?oooooooooo0?ooooooooooool6ooooo`Co2NX:8?ooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08Oooool00ol0
003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?ooooooooooool:ooooo`Go
2NX:6_ooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:oooooooo
ool08Oooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooo
ooooool?ooooo`Co2NX:5_ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo023ooooo
00?o2NX:ooooooooool08Oooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oo
oooooooo0?oooooooooooolCooooo`Co2NX:4_ooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo01oooooo00?o2NX:ooooooooool08_ooool00ol0003oooooooooo`0Oooooo`00oooooomS
ooooo`03o`000?oooooooooo0?oooooooooooolGooooo`Go2NX:3Oooool00ol9jP[oooooooooo`0O
ooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08_ooool00ol0003oooooooooo`0O
ooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooolLooooo`Co2NX::oooool00ol9
jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo02;ooooo00?o0000ooooooooool07oooool00?oo
ooooHoooool00ol0003oooooooooo`3ooooooooooooo8?ooool5o`WZ2RKooooo00?o2NX:oooooooo
ool07oooool00ol9jP[oooooooooo`0Rooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo
00?o0000ooooooooool0ooooooooooooobGooooo1?l9jPXQooooo`03o`WZ2_oooooooooo01oooooo
00?o2NX:ooooooooool08oooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oo
oooooooo0?oooooooooooolYooooo`Co2NX:7Oooool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oo
oooooooo02?ooooo00?o0000ooooooooool07oooool00?ooooooHoooool00ol0003oooooooooo`3o
oooooooooooo;Oooool5o`WZ2QSooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`0S
ooooo`03o`000?oooooooooo01oooooo003oooooof?ooooo00?o0000ooooooooool0oooooooooooo
oc;ooooo1?l9jPXDooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooooooool08oooool00ol0
003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooooooooolfooooo`Go
2NX:3_ooool00ol9jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo02?ooooo00?o0000oooooooo
ool07oooool00?ooooooHoooool00ol0003oooooooooo`3ooooooooooooo>oooool4o`WZ2Rcooooo
00?o2NX:ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`00oooooomSooooo`03o`000?oo
oooooooo0?ooooooooooooloooooo`Co2NX::?ooool00ol9jP[oooooooooo`0Tooooo`03o`000?oo
oooooooo01oooooo003oooooof?ooooo0_l0003oooooooooooooA?ooool5o`WZ2R?ooooo00?o2NX:
ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`00oooooooooooooooooooo[_ooool4o`WZ
2Qoooooo00?o2NX:ooooooooool0A_ooool00?oooooooooooooooooook;ooooo1?l9jPXJooooo`03
o`WZ2_oooooooooo04Oooooo003ooooooooooooooooooonfooooo`Go2NX:5Oooool00ol9jP[ooooo
ooooo`17ooooo`00oooooooooooooooooooo^oooool4o`WZ2Q7ooooo00?o2NX:ooooooooool0Aooo
ool00?oooooooooooooooooookoooooo1?l9jPYGooooo`00oooooooooooooooooooo`oooool5o`WZ
2U;ooooo003oooooooooooooooooooo8ooooo`Go2NX:COooool00?ooooooooooooooooooolgooooo
1_l9jPY7ooooo`00oooooooooooooooooooodoooool5o`WZ2T;ooooo003ooooooooooooooooooooH
ooooo`Go2NX:?Oooool00?ooooooooooooooooooomgooooo1Ol9jPXhooooo`00oooooooooooooooo
ooooh_ooool4o`WZ2SCooooo003ooooooooooooooooooooVooooo`Co2NX:<?ooool00?oooooooooo
ooooooooon[ooooo1Ol9jPX[ooooo`00ooooooooooooooooooookoooool2o`WZ2RWooooo003ooooo
oooooooooooooooooooooa_ooooo003ooooooooooooooooooooooooooa_ooooo003ooooooooooooo
oooooooooooooa_ooooo003ooooooooooooooooooooooooooa_ooooo003ooooooooooooooooooooo
oooooa_ooooo003ooooooooooooooooooooooooooa_ooooo003ooooooooooooooooooooooooooa_o
oooo003ooooooooooooooooooooooooooa_ooooo003ooooooooooooooooooooooooooa_ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 1046.94}, {389.188, 0}} -> {-53.9245, -30.4081, \
0.151903, 0.151903}},
  CellTags->{"AOG4.", "AOG4.1"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Reflected Lens Example", "Subsection",
  CellTags->{"AOG0.", "4.2", "AOG4.", "AOG4.2", "AOG4.2.1"}],

Cell[CellGroupData[{

Cell["Set-up", "Subsubsection",
  CellTags->{"AOG0.", "4.2.1", "AOG4.", "AOG4.2", "AOG4.2.1"}],

Cell["\<\
opticalsystemreflected = {
GaussianBeam[20.,.01,SymbolicWaveLength->\[Lambda],NumberOfRays->6],
Move[PlanoConvexLens[{f,100},{a,50},{t,10},DesignWaveLength->.532],{d1,50}],
Move[Mirror[{b,20}],175,-45],
Move[Screen[50],{175,50},90]};\
\>", "Input",
  CellLabel->"In[24]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[opticalsystemreflected, PlotType->TopView];", "Input",
  CellLabel->"In[21]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .39164 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0240412 0.00463331 0.150645 0.00463331 [
[.27887 .00932 -5.03125 -6 ]
[.27887 .00932 5.03125 6 ]
[.78408 .09986 -6.4375 -6 ]
[.78408 .09986 6.4375 6 ]
[.97619 .38231 -4.75 -6 ]
[.97619 .38231 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .39164 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.28541 .03481 m
.30204 .03481 L
.30204 .07342 L
.26843 .07342 L
.28541 .03481 L
F
.26843 .07342 m
.30204 .07342 L
.30204 .11203 L
.25882 .11203 L
.26843 .07342 L
F
.25882 .11203 m
.30204 .11203 L
.30204 .15065 L
.25571 .15065 L
.25882 .11203 L
F
.25571 .15065 m
.30204 .15065 L
.30204 .18926 L
.25882 .18926 L
.25571 .15065 L
F
.25882 .18926 m
.30204 .18926 L
.30204 .22787 L
.26843 .22787 L
.25882 .18926 L
F
.26843 .22787 m
.30204 .22787 L
.30204 .26648 L
.28541 .26648 L
.26843 .22787 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.28541 .03481 m
.26843 .07342 L
.25882 .11203 L
.25571 .15065 L
.25882 .18926 L
.26843 .22787 L
.28541 .26648 L
.30204 .26648 L
.30204 .22787 L
.30204 .18926 L
.30204 .15065 L
.30204 .11203 L
.30204 .07342 L
.30204 .03481 L
.28541 .03481 L
s
.5 g
.28541 .15065 m
.30204 .15065 L
.30204 .15065 L
.26843 .15065 L
.28541 .15065 L
F
.26843 .15065 m
.30204 .15065 L
.30204 .15065 L
.25882 .15065 L
.26843 .15065 L
F
.25882 .15065 m
.30204 .15065 L
.30204 .15065 L
.25571 .15065 L
.25882 .15065 L
F
.25571 .15065 m
.30204 .15065 L
.30204 .15065 L
.25882 .15065 L
.25571 .15065 L
F
.25882 .15065 m
.30204 .15065 L
.30204 .15065 L
.26843 .15065 L
.25882 .15065 L
F
.26843 .15065 m
.30204 .15065 L
.30204 .15065 L
.28541 .15065 L
.26843 .15065 L
F
0 g
.28541 .15065 m
.26843 .15065 L
.25882 .15065 L
.25571 .15065 L
.25882 .15065 L
.26843 .15065 L
.28541 .15065 L
.30204 .15065 L
.30204 .15065 L
.30204 .15065 L
.30204 .15065 L
.30204 .15065 L
.30204 .15065 L
.30204 .15065 L
.28541 .15065 L
s
.28541 .26648 m
.30204 .26648 L
.30204 .26253 L
.28541 .26253 L
.28541 .26648 L
s
.28541 .26253 m
.30204 .26253 L
.30204 .25096 L
.28541 .25096 L
.28541 .26253 L
s
.28541 .25096 m
.30204 .25096 L
.30204 .23255 L
.28541 .23255 L
.28541 .25096 L
s
.28541 .23255 m
.30204 .23255 L
.30204 .20856 L
.28541 .20856 L
.28541 .23255 L
s
.28541 .20856 m
.30204 .20856 L
.30204 .18062 L
.28541 .18062 L
.28541 .20856 L
s
.28541 .18062 m
.30204 .18062 L
.30204 .15065 L
.28541 .15065 L
.28541 .18062 L
s
.28541 .15065 m
.30204 .15065 L
.30204 .12067 L
.28541 .12067 L
.28541 .15065 L
s
.28541 .12067 m
.30204 .12067 L
.30204 .09273 L
.28541 .09273 L
.28541 .12067 L
s
.28541 .09273 m
.30204 .09273 L
.30204 .06874 L
.28541 .06874 L
.28541 .09273 L
s
.28541 .06874 m
.30204 .06874 L
.30204 .05033 L
.28541 .05033 L
.28541 .06874 L
s
.28541 .05033 m
.30204 .05033 L
.30204 .03876 L
.28541 .03876 L
.28541 .05033 L
s
.28541 .03876 m
.30204 .03876 L
.30204 .03481 L
.28541 .03481 L
.28541 .03876 L
s
.28541 .03481 m
.30204 .03481 L
.30204 .03876 L
.28541 .03876 L
.28541 .03481 L
s
.28541 .03876 m
.30204 .03876 L
.30204 .05033 L
.28541 .05033 L
.28541 .03876 L
s
.28541 .05033 m
.30204 .05033 L
.30204 .06874 L
.28541 .06874 L
.28541 .05033 L
s
.28541 .06874 m
.30204 .06874 L
.30204 .09273 L
.28541 .09273 L
.28541 .06874 L
s
.28541 .09273 m
.30204 .09273 L
.30204 .12067 L
.28541 .12067 L
.28541 .09273 L
s
.28541 .12067 m
.30204 .12067 L
.30204 .15065 L
.28541 .15065 L
.28541 .12067 L
s
.28541 .15065 m
.30204 .15065 L
.30204 .18062 L
.28541 .18062 L
.28541 .15065 L
s
.28541 .18062 m
.30204 .18062 L
.30204 .20856 L
.28541 .20856 L
.28541 .18062 L
s
.28541 .20856 m
.30204 .20856 L
.30204 .23255 L
.28541 .23255 L
.28541 .20856 L
s
.28541 .23255 m
.30204 .23255 L
.30204 .25096 L
.28541 .25096 L
.28541 .23255 L
s
.28541 .25096 m
.30204 .25096 L
.30204 .26253 L
.28541 .26253 L
.28541 .25096 L
s
.28541 .26253 m
.30204 .26253 L
.30204 .26648 L
.28541 .26648 L
.28541 .26253 L
s
.5 g
.80211 .11788 m
.80211 .11788 L
.81303 .1288 L
.81303 .1288 L
.80211 .11788 L
F
.81303 .1288 m
.81303 .1288 L
.82395 .13972 L
.82395 .13972 L
.81303 .1288 L
F
.82395 .13972 m
.82395 .13972 L
.83487 .15065 L
.83487 .15065 L
.82395 .13972 L
F
.83487 .15065 m
.83487 .15065 L
.84579 .16157 L
.84579 .16157 L
.83487 .15065 L
F
.84579 .16157 m
.84579 .16157 L
.85671 .17249 L
.85671 .17249 L
.84579 .16157 L
F
.85671 .17249 m
.85671 .17249 L
.86763 .18341 L
.86763 .18341 L
.85671 .17249 L
F
0 g
.80211 .11788 m
.81303 .1288 L
.82395 .13972 L
.83487 .15065 L
.84579 .16157 L
.85671 .17249 L
.86763 .18341 L
.86763 .18341 L
.85671 .17249 L
.84579 .16157 L
.83487 .15065 L
.82395 .13972 L
.81303 .1288 L
.80211 .11788 L
.80211 .11788 L
s
.5 g
.83487 .15065 m
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
F
.83487 .15065 m
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
F
.83487 .15065 m
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
F
.83487 .15065 m
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
F
.83487 .15065 m
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
F
.83487 .15065 m
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
F
0 g
.83487 .15065 m
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
s
.5 g
.83487 .15065 m
.84579 .16157 L
.84542 .16119 L
.83487 .15065 L
.83487 .15065 L
F
.84579 .16157 m
.85671 .17249 L
.85597 .17174 L
.84542 .16119 L
.84579 .16157 L
F
.85671 .17249 m
.86763 .18341 L
.86652 .18229 L
.85597 .17174 L
.85671 .17249 L
F
.83487 .15065 m
.84542 .16119 L
.84433 .1601 L
.83487 .15065 L
.83487 .15065 L
F
.84542 .16119 m
.85597 .17174 L
.85379 .16956 L
.84433 .1601 L
.84542 .16119 L
F
.85597 .17174 m
.86652 .18229 L
.86324 .17902 L
.85379 .16956 L
.85597 .17174 L
F
.83487 .15065 m
.84433 .1601 L
.84259 .15837 L
.83487 .15065 L
.83487 .15065 L
F
.84433 .1601 m
.85379 .16956 L
.85031 .16609 L
.84259 .15837 L
.84433 .1601 L
F
.85379 .16956 m
.86324 .17902 L
.85804 .17381 L
.85031 .16609 L
.85379 .16956 L
F
.83487 .15065 m
.84259 .15837 L
.84033 .15611 L
.83487 .15065 L
.83487 .15065 L
F
.84259 .15837 m
.85031 .16609 L
.84579 .16157 L
.84033 .15611 L
.84259 .15837 L
F
.85031 .16609 m
.85804 .17381 L
.85125 .16703 L
.84579 .16157 L
.85031 .16609 L
F
.83487 .15065 m
.84033 .15611 L
.8377 .15347 L
.83487 .15065 L
.83487 .15065 L
F
.84033 .15611 m
.84579 .16157 L
.84052 .1563 L
.8377 .15347 L
.84033 .15611 L
F
.84579 .16157 m
.85125 .16703 L
.84335 .15912 L
.84052 .1563 L
.84579 .16157 L
F
.83487 .15065 m
.8377 .15347 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
F
.8377 .15347 m
.84052 .1563 L
.83487 .15065 L
.83487 .15065 L
.8377 .15347 L
F
.84052 .1563 m
.84335 .15912 L
.83487 .15065 L
.83487 .15065 L
.84052 .1563 L
F
.83487 .15065 m
.83487 .15065 L
.83204 .14782 L
.83487 .15065 L
.83487 .15065 L
F
.83487 .15065 m
.83487 .15065 L
.82922 .14499 L
.83204 .14782 L
.83487 .15065 L
F
.83487 .15065 m
.83487 .15065 L
.82639 .14217 L
.82922 .14499 L
.83487 .15065 L
F
.83487 .15065 m
.83204 .14782 L
.82941 .14518 L
.83487 .15065 L
.83487 .15065 L
F
.83204 .14782 m
.82922 .14499 L
.82395 .13972 L
.82941 .14518 L
.83204 .14782 L
F
.82922 .14499 m
.82639 .14217 L
.81849 .13426 L
.82395 .13972 L
.82922 .14499 L
F
.83487 .15065 m
.82941 .14518 L
.82715 .14292 L
.83487 .15065 L
.83487 .15065 L
F
.82941 .14518 m
.82395 .13972 L
.81943 .1352 L
.82715 .14292 L
.82941 .14518 L
F
.82395 .13972 m
.81849 .13426 L
.8117 .12748 L
.81943 .1352 L
.82395 .13972 L
F
.83487 .15065 m
.82715 .14292 L
.82541 .14119 L
.83487 .15065 L
.83487 .15065 L
F
.82715 .14292 m
.81943 .1352 L
.81595 .13173 L
.82541 .14119 L
.82715 .14292 L
F
.81943 .1352 m
.8117 .12748 L
.8065 .12227 L
.81595 .13173 L
.81943 .1352 L
F
.83487 .15065 m
.82541 .14119 L
.82432 .1401 L
.83487 .15065 L
.83487 .15065 L
F
.82541 .14119 m
.81595 .13173 L
.81377 .12955 L
.82432 .1401 L
.82541 .14119 L
F
.81595 .13173 m
.8065 .12227 L
.80322 .119 L
.81377 .12955 L
.81595 .13173 L
F
.83487 .15065 m
.82432 .1401 L
.82395 .13972 L
.83487 .15065 L
.83487 .15065 L
F
.82432 .1401 m
.81377 .12955 L
.81303 .1288 L
.82395 .13972 L
.82432 .1401 L
F
.81377 .12955 m
.80322 .119 L
.80211 .11788 L
.81303 .1288 L
.81377 .12955 L
F
.83487 .15065 m
.82395 .13972 L
.82432 .1401 L
.83487 .15065 L
.83487 .15065 L
F
.82395 .13972 m
.81303 .1288 L
.81377 .12955 L
.82432 .1401 L
.82395 .13972 L
F
.81303 .1288 m
.80211 .11788 L
.80322 .119 L
.81377 .12955 L
.81303 .1288 L
F
.83487 .15065 m
.82432 .1401 L
.82541 .14119 L
.83487 .15065 L
.83487 .15065 L
F
.82432 .1401 m
.81377 .12955 L
.81595 .13173 L
.82541 .14119 L
.82432 .1401 L
F
.81377 .12955 m
.80322 .119 L
.8065 .12227 L
.81595 .13173 L
.81377 .12955 L
F
.83487 .15065 m
.82541 .14119 L
.82715 .14292 L
.83487 .15065 L
.83487 .15065 L
F
.82541 .14119 m
.81595 .13173 L
.81943 .1352 L
.82715 .14292 L
.82541 .14119 L
F
.81595 .13173 m
.8065 .12227 L
.8117 .12748 L
.81943 .1352 L
.81595 .13173 L
F
.83487 .15065 m
.82715 .14292 L
.82941 .14518 L
.83487 .15065 L
.83487 .15065 L
F
.82715 .14292 m
.81943 .1352 L
.82395 .13972 L
.82941 .14518 L
.82715 .14292 L
F
.81943 .1352 m
.8117 .12748 L
.81849 .13426 L
.82395 .13972 L
.81943 .1352 L
F
.83487 .15065 m
.82941 .14518 L
.83204 .14782 L
.83487 .15065 L
.83487 .15065 L
F
.82941 .14518 m
.82395 .13972 L
.82922 .14499 L
.83204 .14782 L
.82941 .14518 L
F
.82395 .13972 m
.81849 .13426 L
.82639 .14217 L
.82922 .14499 L
.82395 .13972 L
F
.83487 .15065 m
.83204 .14782 L
.83487 .15065 L
.83487 .15065 L
.83487 .15065 L
F
.83204 .14782 m
.82922 .14499 L
.83487 .15065 L
.83487 .15065 L
.83204 .14782 L
F
.82922 .14499 m
.82639 .14217 L
.83487 .15065 L
.83487 .15065 L
.82922 .14499 L
F
.83487 .15065 m
.83487 .15065 L
.8377 .15347 L
.83487 .15065 L
.83487 .15065 L
F
.83487 .15065 m
.83487 .15065 L
.84052 .1563 L
.8377 .15347 L
.83487 .15065 L
F
.83487 .15065 m
.83487 .15065 L
.84335 .15912 L
.84052 .1563 L
.83487 .15065 L
F
.83487 .15065 m
.8377 .15347 L
.84033 .15611 L
.83487 .15065 L
.83487 .15065 L
F
.8377 .15347 m
.84052 .1563 L
.84579 .16157 L
.84033 .15611 L
.8377 .15347 L
F
.84052 .1563 m
.84335 .15912 L
.85125 .16703 L
.84579 .16157 L
.84052 .1563 L
F
.83487 .15065 m
.84033 .15611 L
.84259 .15837 L
.83487 .15065 L
.83487 .15065 L
F
.84033 .15611 m
.84579 .16157 L
.85031 .16609 L
.84259 .15837 L
.84033 .15611 L
F
.84579 .16157 m
.85125 .16703 L
.85804 .17381 L
.85031 .16609 L
.84579 .16157 L
F
.83487 .15065 m
.84259 .15837 L
.84433 .1601 L
.83487 .15065 L
.83487 .15065 L
F
.84259 .15837 m
.85031 .16609 L
.85379 .16956 L
.84433 .1601 L
.84259 .15837 L
F
.85031 .16609 m
.85804 .17381 L
.86324 .17902 L
.85379 .16956 L
.85031 .16609 L
F
.83487 .15065 m
.84433 .1601 L
.84542 .16119 L
.83487 .15065 L
.83487 .15065 L
F
.84433 .1601 m
.85379 .16956 L
.85597 .17174 L
.84542 .16119 L
.84433 .1601 L
F
.85379 .16956 m
.86324 .17902 L
.86652 .18229 L
.85597 .17174 L
.85379 .16956 L
F
.83487 .15065 m
.84542 .16119 L
.84579 .16157 L
.83487 .15065 L
.83487 .15065 L
F
.84542 .16119 m
.85597 .17174 L
.85671 .17249 L
.84579 .16157 L
.84542 .16119 L
F
.85597 .17174 m
.86652 .18229 L
.86763 .18341 L
.85671 .17249 L
.85597 .17174 L
F
0 g
.86763 .18341 m
.86652 .18229 L
.86324 .17902 L
.85804 .17381 L
.85125 .16703 L
.84335 .15912 L
.83487 .15065 L
.82639 .14217 L
.81849 .13426 L
.8117 .12748 L
.8065 .12227 L
.80322 .119 L
.80211 .11788 L
.80322 .119 L
.8065 .12227 L
.8117 .12748 L
.81849 .13426 L
.82639 .14217 L
.83487 .15065 L
.84335 .15912 L
.85125 .16703 L
.85804 .17381 L
.86324 .17902 L
.86652 .18229 L
.86763 .18341 L
s
.9507 .38231 m
.91209 .38231 L
.87348 .38231 L
.83487 .38231 L
.79626 .38231 L
.75765 .38231 L
.71904 .38231 L
.71904 .38231 L
.75765 .38231 L
.79626 .38231 L
.83487 .38231 L
.87348 .38231 L
.91209 .38231 L
.9507 .38231 L
.9507 .38231 L
s
.83487 .38231 m
.83487 .38231 L
.83487 .38231 L
.83487 .38231 L
.83487 .38231 L
.83487 .38231 L
.83487 .38231 L
.83487 .38231 L
.83487 .38231 L
.83487 .38231 L
.83487 .38231 L
.83487 .38231 L
.83487 .38231 L
.83487 .38231 L
.83487 .38231 L
s
.71904 .38231 m
.72298 .38231 L
.73456 .38231 L
.75296 .38231 L
.77695 .38231 L
.80489 .38231 L
.83487 .38231 L
.86485 .38231 L
.89279 .38231 L
.91678 .38231 L
.93518 .38231 L
.94676 .38231 L
.9507 .38231 L
.94676 .38231 L
.93518 .38231 L
.91678 .38231 L
.89279 .38231 L
.86485 .38231 L
.83487 .38231 L
.80489 .38231 L
.77695 .38231 L
.75296 .38231 L
.73456 .38231 L
.72298 .38231 L
.71904 .38231 L
s
.039 .916 .04 r
.02381 .05798 m
.27479 .05673 L
s
% Start of user PostScript
-0.049999 -19.9998 54.1182 -20.2706 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.27479 .05673 Mdot
.039 .916 .04 r
.5 Mabswid
.02396 .09505 m
.26239 .09433 L
s
% Start of user PostScript
-0.0179999 -11.9999 51.4419 -12.1543 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.26239 .09433 Mdot
.039 .916 .04 r
.5 Mabswid
.02403 .13211 m
.25644 .13188 L
s
% Start of user PostScript
-0.002 -4. 50.1581 -4.05016 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.25644 .13188 Mdot
.039 .916 .04 r
.5 Mabswid
.02403 .16918 m
.25644 .16941 L
s
% Start of user PostScript
-0.002 4. 50.1581 4.05016 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.25644 .16941 Mdot
.039 .916 .04 r
.5 Mabswid
.02396 .20624 m
.26239 .20696 L
s
% Start of user PostScript
-0.0179999 11.9999 51.4419 12.1543 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.26239 .20696 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .24331 m
.27479 .24457 L
s
% Start of user PostScript
-0.049999 19.9998 54.1182 20.2706 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.27479 .24457 Mdot
.039 .916 .04 r
.5 Mabswid
.27479 .05673 m
.30204 .06051 L
s
% Start of user PostScript
54.1182 -20.2706 60. -19.4541 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30204 .06051 Mdot
.039 .916 .04 r
.5 Mabswid
.26239 .09433 m
.30204 .09749 L
s
% Start of user PostScript
51.4419 -12.1543 60. -11.4718 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30204 .09749 Mdot
.039 .916 .04 r
.5 Mabswid
.25644 .13188 m
.30204 .13307 L
s
% Start of user PostScript
50.1581 -4.05016 60. -3.79381 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30204 .13307 Mdot
.039 .916 .04 r
.5 Mabswid
.25644 .16941 m
.30204 .16822 L
s
% Start of user PostScript
50.1581 4.05016 60. 3.79381 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30204 .16822 Mdot
.039 .916 .04 r
.5 Mabswid
.26239 .20696 m
.30204 .2038 L
s
% Start of user PostScript
51.4419 12.1543 60. 11.4718 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30204 .2038 Mdot
.039 .916 .04 r
.5 Mabswid
.27479 .24457 m
.30204 .24078 L
s
% Start of user PostScript
54.1182 20.2706 60. 19.4541 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30204 .24078 Mdot
.039 .916 .04 r
.5 Mabswid
.30204 .06051 m
.86497 .18074 L
s
% Start of user PostScript
60. -19.4541 181.496 6.49591 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.86497 .18074 Mdot
.039 .916 .04 r
.5 Mabswid
.30204 .09749 m
.84815 .16393 L
s
% Start of user PostScript
60. -11.4718 177.867 2.86653 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.84815 .16393 Mdot
.039 .916 .04 r
.5 Mabswid
.30204 .13307 m
.83853 .1543 L
s
% Start of user PostScript
60. -3.79381 175.79 0.789602 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.83853 .1543 Mdot
.039 .916 .04 r
.5 Mabswid
.30204 .16822 m
.83149 .14727 L
s
% Start of user PostScript
60. 3.79381 174.271 -0.729471 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.83149 .14727 Mdot
.039 .916 .04 r
.5 Mabswid
.30204 .2038 m
.82447 .14024 L
s
% Start of user PostScript
60. 11.4718 172.755 -2.24475 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82447 .14024 Mdot
.039 .916 .04 r
.5 Mabswid
.30204 .24078 m
.81537 .13114 L
s
% Start of user PostScript
60. 19.4541 170.791 -4.20939 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81537 .13114 Mdot
.039 .916 .04 r
.5 Mabswid
.86497 .18074 m
.90802 .38231 L
s
% Start of user PostScript
181.496 6.49591 190.788 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.90802 .38231 Mdot
.039 .916 .04 r
.5 Mabswid
.84815 .16393 m
.87472 .38231 L
s
% Start of user PostScript
177.867 2.86653 183.6 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.87472 .38231 Mdot
.039 .916 .04 r
.5 Mabswid
.83853 .1543 m
.84755 .38231 L
s
% Start of user PostScript
175.79 0.789602 177.738 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.84755 .38231 Mdot
.039 .916 .04 r
.5 Mabswid
.83149 .14727 m
.82219 .38231 L
s
% Start of user PostScript
174.271 -0.729471 172.262 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82219 .38231 Mdot
.039 .916 .04 r
.5 Mabswid
.82447 .14024 m
.79502 .38231 L
s
% Start of user PostScript
172.755 -2.24475 166.4 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.79502 .38231 Mdot
.039 .916 .04 r
.5 Mabswid
.81537 .13114 m
.76172 .38231 L
s
% Start of user PostScript
170.791 -4.20939 159.212 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.76172 .38231 Mdot
gsave
.27887 .00932 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78408 .09986 -67.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
71.875 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .38231 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .39164 L
0 .39164 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{288, 112.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000L2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00DOooool6o`000<Wooooo001B
ooooo`05o`000?ooooooooooooooool00000bOooool005;ooooo00?o0000ooooooooool0boooool0
05;ooooo00?o0000ooooooooool0boooool005;ooooo00?o0000ooooooooool0boooool005;ooooo
00?o0000ooooooooool0boooool0057ooooo0ol0003<ooooo`00oooooolQooooo`00oooooolQoooo
o`00E_ooool5o`000<Gooooo001Fooooo`Go0000aOooool005Gooooo0_l00003ogmoO`03o`000?oo
oooooooo0<?ooooo001;ooooo`?o2NX:1?ooool2o`WZ2P03ooooool0003o000000?oOgmo00?o0000
ooooooooool0`oooool004cooooo2ol9jPX4o`000<Gooooo000booooob3o2NX:00?o0000o`WZ2_l9
jPX01Ol9jPX00ol0003oooooooooo`33ooooo`004?oooolRo`WZ2Q[ooooo1Ol9jPX00ooooooo0000
o`WZ2P09o`WZ2/?ooooo001;ooooo`;o2NX:1Oooool4o`WZ2P04o`000?moOgooOgmoogmoO`;o0000
00?oooooo`WZ2_l9jPX00ol9jPZnooooo`00D_ooool01Ol0003oOgmoogmoOomoOgoo000000?oOgmo
00?o0000ooooooooool01Oooool4o`WZ2[[ooooo001Booooo`04o`000?moOgooOgmoogmoO`Go0000
2oooool5o`WZ2[Gooooo001Aooooo`03o`000?moOgooOgmo00;oOgmo00Go0000ogmoOomoOgooOgmo
o`00000@ooooo`Go2NX:/?ooool0057ooooo00?o0000ogmoOomoOgl00_moOgl01Ol0003oOgmoogmo
OomoOgoo000001Gooooo1?l9jPZ/ooooo`00DOooool00ol0003oOgmoogmoO`02ogmoO`05o`000?mo
OgooOgmoogmoOol000006Oooool5o`WZ2ZOooooo001@ooooo`03o`000?moOgooOgmo00?oOgmo00Go
0000ogmoOomoOgooOgmoo`00000Nooooo`Co2NX:Xoooool004Oooooo1Ol9jPX4ooooo`03o`000?mo
Ogoo2NX:00;o2NX:00?oOgmoo`000?moOgl00_moOgl00ol0003oooooooooo`0Pooooo`Go2NX:W_oo
ool0033ooooo:Ol9jPX2o`0002Oooooo1?l9jPYAooooo`?o000000?oooooo`000?ooool00ol00010
ooooo`004?oooolPo`WZ2QWooooo1Ol9jPX00ooooooo0000o`000003ogmoO`_o2NX:9oooool5o`WZ
2Tgooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0oooooo`00B?ooool3o`WZ
2PGooooo00?o0000ogmoOomoOgl01Ol9jPX2ogmoO`;o00000oooool8o`WZ2RCooooo1Ol9jPY8oooo
o`07o`000?oooooo0000ooooool0003oooooo`000011ooooo`00Aoooool00ol9jP[oooooooooo`05
ooooo`03o`000?moOgooOgmo00;o2NX:0_moOgl01Ol0003oOgmoogmoOomoOgoo000000cooooo2?l9
jPXQooooo`Co2NX:A?ooool01ol0003oooooo`000?oooooo0000ooooool00000@Oooool004oooooo
00?o0000ogmoOomoOgl01?moOgl01Ol0003oOgmoogmoOomoOgoo000001Cooooo2?l9jPXMooooo`Go
2NX:?oooool2o`0000?ooooo0_l00011ooooo`00Coooool00ol0003oOgmoogmoO`04ogmoO`05o`00
0?moOgooOgmoogmoOol000007?ooool9o`WZ2QWooooo1?l9jPXkooooo`;o00000oooool2o`00047o
oooo001?ooooo`03o`000?moOgooOgmo00CoOgmo00Go0000ogmoOomoOgooOgmoo`00000Uooooo`So
2NX:5Oooool5o`WZ2SGooooo0_l00005ooooo`;o0000@?ooool004oooooo00?o0000ogmoOomoOgl0
1?moOgl01Ol0003oOgmoogmoOomoOgoo000002gooooo2?l9jPXBooooo`Go2NX:>Oooool00ol0003o
ooooooooo`0mooooo`00Coooool00ol0003oOgmoogmoO`04ogmoO`Go0000=Oooool8o`WZ2Poooooo
1?l9jPXfooooo`03o`000?oooooooooo03cooooo0016ooooo`?o2NX:1_ooool00ol0003oOgmoogmo
O`03o`WZ2P03ogmoOol0003oOgmo00;oOgmo00?o0000ooooooooool0>oooool8o`WZ2P_ooooo1Ol9
jPXbooooo`03o`000?oooooooooo03_ooooo0017ooooo`Ko2NX:0ol00003ogmoO`Ko2NX:00?oOgmo
o`000?l00000A?ooool8o`WZ2PSooooo1?l9jPXWooooo`Wo2NX:00?o0000ooooooooool0>Oooool0
013ooooo?Ol9jPX00ol0003o2NX:o`WZ2P0Go`WZ2T7ooooo2?l9jPX4ooooo`Go2NX:8oooool6o`WZ
2P03ooooool9jP[o000003_ooooo0017ooooo`Go2NX:0_ooool00ol0003oOgmoogmoO`02ogmoO`Go
2NX:0_moOgl00ol0003oooooooooo`0:oooooaSo2NX:<Oooool8o`WZ2P03ooooool9jP[o2NX:00;o
2NX:6oooool4o`WZ2P03ooooool9jP[o2NX:00Go2NX:00?oooooo`000?l00000>Oooool004Kooooo
0_l9jPX6ooooo`04o`000?moOgooOgmoogmoO`;o2NX:0_moOgl01Ol0003oOgmoogmoOomoOgoo0000
02Cooooo6?l9jPXQooooo`[o2NX:4Oooool5o`WZ2PGooooo2?l9jPX00ol0003o2NX:ooooo`0hoooo
o`00C_ooool00ol0003oOgmoogmoO`05ogmoO`05o`000?moOgooOgmoogmoOol00000??oooolHo`WZ
2Q7ooooo2Ol9jPX5ooooo`Go2NX:1oooool=o`WZ2P;o0000=oooool004kooooo00?o0000ogmoOomo
Ogl01OmoOgl01Ol0003oOgmoogmoOomoOgoo000005Cooooo>?l9jPX00ol0003o2NX:o`00000foooo
o`00C_ooool=o`0006;ooooo8_l9jPX2ooooo`So2NX:0_l0000eooooo`00C_ooool00ol0003oOgmo
ogmoO`05ogmoO`05o`000?moOgooOgmoogmoOol00000A_oooolLo`WZ2PCooooo2?l9jPX7ooooo`Co
2NX:1Oooool@o`WZ2P03o`000?l9jP[ooooo03Cooooo001>ooooo`04o`000?moOgooOgmoogmoO`?o
2NX:00?oOgmoo`000?moOgl00_moOgl00ol0003oooooooooo`0Xoooooaco2NX:6?ooool8o`WZ2Q?o
oooo1Ol9jPX8ooooo`_o2NX:=?ooool004Kooooo0ol9jPX5ooooo`03o`000?moOgooOgmo00;oOgmo
1_l9jPX00omoOgoo0000ooooo`0<oooooago2NX::oooool<o`WZ2Qgooooo1?l9jPX4ooooo`04o`WZ
2_ooooooooooooooo`So2NX:00?o0000ooooooooool0<?ooool004Oooooo1_l9jPX2o`0000GoOgmo
5?l9jPY0ooooo`So2NX:0oooool5o`WZ2RGooooo1Ol9jPX2ooooo`Oo2NX:00?oooooo`WZ2_l00000
<_ooool0013ooooo?Ol9jPX00ol0003o2NX:o`WZ2P08o`WZ2P;oOgmo0_l00014ooooo`So2NX:1_oo
ool5o`WZ2Rkooooo1_l9jPX00ooooooo2NX:ooooo`03o`WZ2P03ooooool0003ooooo033ooooo0017
ooooo`Go2NX:0oooool00ol0003oOgmoogmoO`02o`WZ2P;oOgmo00Go0000ogmoOomoOgooOgmoo`00
000mooooo`So2NX:2_ooool4o`WZ2S?ooooo00Ko2NX:ooooooooooooooooo`WZ2_ooool8o`WZ2P03
o`000?oooooooooo02kooooo0016ooooo`;o2NX:1oooool00ol0003oOgmoogmoO`04ogmoO`05o`00
0?moOgooOgmoogmoOol00000=Oooool8o`WZ2Pgooooo1Ol9jPXfooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool02?l9jPX2o`0002kooooo001?ooooo`03o`000?moOgooOgmo00CoOgmo
1Ol0000/ooooo`Wo2NX:4Oooool4o`WZ2S_ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`08o`WZ2P03o`000?l9jP[o000002gooooo001?ooooo`03o`000?moOgooOgmo00CoOgmo00Go
0000ogmoOomoOgooOgmoo`00000Tooooo`So2NX:5Oooool5o`WZ2Soooooo00?o2NX:ooooooooool0
0_ooool01_l9jP[oooooooooool9jP[oooooo`WZ2P;ooooo00Go2NX:ooooooooooooooooo`WZ2P0^
ooooo`00Coooool00ol0003oOgmoogmoO`04ogmoO`05o`000?moOgooOgmoogmoOol000007?ooool8
o`WZ2QWooooo1?l9jPY4ooooo`05o`WZ2_ooooooooooooooool9jPX00_ooool01?l9jP[ooooooooo
ool9jPX2ooooo`05o`WZ2_ooooooooooooooool9jPX0;_ooool004oooooo00?o0000ogmoOomoOgl0
1?moOgl01Ol0003oOgmoogmoOomoOgoo000001Cooooo2?l9jPXLooooo`Go2NX:B?ooool01Ol9jP[o
oooooooooooooooo2NX:00;ooooo00Co2NX:oooooooooooo2NX:0_ooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo02_ooooo001?ooooo`03o`000?moOgooOgmo00?o2NX:00?oOgmoo`00
0?moOgl00_moOgl00ol0003oooooooooo`09ooooo`Wo2NX:8?ooool4o`WZ2Tcooooo00?o2NX:oooo
ooooool00_ooool01?l9jP[oooooooooool9jPX2ooooo`04o`WZ2_ooooooooooo`WZ2PCooooo00?o
2NX:ooooooooool0:oooool004Oooooo0ol9jPX6ooooo`03o`000?moOgooOgmo00Ko2NX:00?oOgmo
o`000?l000000_ooool8o`WZ2RCooooo1Ol9jPY@ooooo`03o`WZ2_oooooooooo00;ooooo00Co2NX:
oooooooooooo2NX:0_ooool01?l9jP[oooooooooool9jPX4ooooo`03o`WZ2_oooooooooo02_ooooo
000@ooooob7o2NX:5oooool6o`WZ2P03ooooool0003o000000?oOgmo2_l9jPXWooooo`Go2NX:EOoo
ool00ol9jP[oooooooooo`02ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo00Co2NX:oooooooooooo
2NX:1?ooool00ol9jP[oooooooooo`0[ooooo`00<OoooolWo`WZ2P?o00009_ooool4o`WZ2U[ooooo
00?o2NX:ooooooooool00_ooool01?l9jP[oooooooooool9jPX2ooooo`04o`WZ2_ooooooooooo`WZ
2PCooooo00?o2NX:ooooooooool0:oooool004Sooooo1Ol9jPX3ooooo`04o`000?moOgoo2NX:o`WZ
2P;oOgmo00Go0000ogmoOomoOgooOgmoo`00000Qooooo`Go2NX:G_ooool00ol9jP[oooooooooo`02
ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ
2_oooooooooo02[ooooo0017ooooo`;o2NX:1oooool00ol0003oOgmoogmoO`03ogmoO`05o`000?mo
OgooOgmoogmoOol000007Oooool4o`WZ2V;ooooo00?o2NX:ooooooooool00oooool01?l9jP[ooooo
ooooool9jPX3ooooo`04o`WZ2_ooooooooooo`WZ2PCooooo00?o2NX:ooooooooool0:_ooool0057o
oooo00?o0000ogmoOomoOgl00_moOgl01Ol0003oOgmoogmoOomoOgoo000001Sooooo1Ol9jPYVoooo
o`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`04o`WZ2_oooooo
ooooo`WZ2PCooooo00?o2NX:ooooooooool0:_ooool0057ooooo00?o0000ogmoOomoOgl00_moOgl0
1Ol0003oOgmoogmoOomoOgoo000001Cooooo1?l9jPY[ooooo`03o`WZ2_oooooooooo00;ooooo00Go
2NX:ooooooooooooooooo`WZ2P03ooooo`04o`WZ2_ooooooooooo`WZ2PCooooo00?o2NX:oooooooo
ool0:_ooool0057ooooo00?o0000ogmoOomoOgl00_moOgl01Ol0003oOgmoogmoOomoOgoo000000oo
oooo1Ol9jPY_ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03oooo
o`04o`WZ2_ooooooooooo`WZ2PCooooo00?o2NX:ooooooooool0:_ooool0057ooooo00?o0000ogmo
OomoOgl00_moOgl5o`0000[ooooo1Ol9jPYcooooo`03o`WZ2_oooooooooo00?ooooo00Go2NX:oooo
ooooooooooooo`WZ2P03ooooo`04o`WZ2_ooooooooooo`WZ2PGooooo00?o2NX:ooooooooool0:Ooo
ool005;ooooo00Go0000ogmoOomoOgooOgmoo`000003ogmoO`03o`000?oooooooooo00Cooooo1?l9
jPYhooooo`03o`WZ2_oooooooooo00?ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`04o`WZ
2_ooooooooooo`WZ2PGooooo00?o2NX:ooooooooool0:Oooool004_ooooo0ol9jPX4ooooo`Go2NX:
0omoOgl2o`0000Go2NX:O?ooool00ol9jP[oooooooooo`03ooooo`05o`WZ2_ooooooooooooooool9
jPX00oooool01?l9jP[oooooooooool9jPX5ooooo`03o`WZ2_oooooooooo02Wooooo000@ooooob?o
2NX:6Oooool6o`WZ2P03o`000?l9jP[o2NX:00Oo2NX:POooool00ol9jP[oooooooooo`03ooooo`05
o`WZ2_ooooooooooooooool9jPX00oooool01?l9jP[oooooooooool9jPX5ooooo`03o`WZ2_oooooo
oooo02Wooooo000coooooaoo2NX:00?o0000o`WZ2_l9jPX01?l9jPX00omoOgoo0000ooooo`21oooo
o`03o`WZ2_oooooooooo00?ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`05o`WZ2_oooooo
ooooooooool9jPX01?ooool00ol9jP[oooooooooo`0Yooooo`00C?ooool5o`WZ2P;ooooo0ol9jPX5
o`00087ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_oooooo
ooooooooool9jPX00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo02Sooooo001;
ooooo`;o2NX:1Oooool01Ol9jP[oooooo`000?moOgoo000000?oOgmo00?o0000ooooooooool0Oooo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooooooooooooooo
o`WZ2P03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0:?ooool005Cooooo00?o
0000ogmoOol000000omoOgl00ol0003oooooooooo`1oooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`0Xooooo`00EOooool6o`00087ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo02Sooooo001Eooooo`;o00000omoOgl00ol0003ooooooooo
o`1oooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooo
oooooooo2NX:00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Xooooo`00E_oo
ool5o`00083ooooo00?o2NX:ooooooooool01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo
00Go2NX:ooooooooooooooooo`WZ2P06ooooo`03o`WZ2_oooooooooo02Oooooo003Kooooo`03o`WZ
2_oooooooooo00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooooooooooo
ool9jPX01_ooool00ol9jP[oooooooooo`0Wooooo`00foooool00ol9jP[oooooooooo`04ooooo`05
o`WZ2_ooooooooooooooool9jPX01?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool09oooool00=_ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo02Oooooo003Kooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Vooooo`00f_ooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool09_ooool00=[ooooo00?o2NX:
ooooooooool01?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo02Kooooo003Joooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Voooo
o`00f_ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool09_ooool00=Wooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`05ooooo`03o`WZ
2_oooooooooo02Gooooo003Iooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`0Uooooo`00fOooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool09Oooool00=Wooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo02Gooooo003Iooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Uooooo`00f?ooool00ol9jP[ooooo
ooooo`05ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool09?ooool00=Sooooo00?o
2NX:ooooooooool01Oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo02Cooooo003H
ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0T
ooooo`00f?ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:oooo
ooooool09?ooool00=Sooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`05ooooo`03
o`WZ2_oooooooooo02Cooooo003Gooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1Oooool00ol9jP[oooooooooo`0Sooooo`00eoooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Gooooo00?o2NX:ooooooooool08oooool00=Oooooo00?o2NX:ooooooooool01Oooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo02?ooooo003Eooooo`03o`WZ2_oooooo2NX:
00Gooooo00?o2NX:ooooool9jPX00oooool00ol9jP[oooooo`WZ2P06ooooo`03o`WZ2_oooooo2NX:
00?ooooo00?o2NX:ooooool9jPX01Oooool00ol9jP[oooooo`WZ2P0Sooooo`00eOooool00ol9jP[o
ooooo`WZ2P02o`WZ2P?ooooo00_o2NX:ooooool9jP[oooooo`WZ2_oooooo2NX:ooooool9jP[ooooo
o`WZ2P02ooooo`0;o`WZ2_oooooo2NX:ooooool9jP[oooooo`WZ2_oooooo2NX:ooooool9jPX00ooo
ool3o`WZ2P03ooooool9jP[ooooo02;ooooo003Eooooo`Go2NX:0oooool5o`WZ2P03ooooool9jP[o
2NX:00?o2NX:0_ooool5o`WZ2P03ooooool9jP[o2NX:00?o2NX:0oooool5o`WZ2R?ooooo003Eoooo
o`Co2NX:1?ooool4o`WZ2P?ooooo1?l9jPX2ooooo`Co2NX:0oooool4o`WZ2PCooooo1?l9jPXSoooo
o`00eOooool4o`WZ2PCooooo1?l9jPX3ooooo`?o2NX:1?ooool3o`WZ2P?ooooo1?l9jPX4ooooo`Co
2NX:8oooool00=Gooooo0ol9jPX6ooooo`;o2NX:1?ooool3o`WZ2PCooooo0ol9jPX4ooooo`;o2NX:
1_ooool3o`WZ2R?ooooo003Eooooo`;o2NX:1oooool2o`WZ2PCooooo0ol9jPX4ooooo`?o2NX:1?oo
ool2o`WZ2POooooo0_l9jPX@ooooo`?o00004?ooool00=Gooooo0_l9jPX7ooooo`;o2NX:1Oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo0_l9jPX7ooooo`;o2NX:4?ooool0
1?l0003oooooooooool0000?ooooo`00b_ooooloo`0000Oooooo00?o0000ooooooooool03Oooool0
0=Cooooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo0_l00006ooooo`;o00001oooool2o`00
013ooooo0_l0000@ooooo`00ooooool>ooooo`03o`000?oooooooooo013ooooo003oooooo`kooooo
00Co0000oooooooooooo00003oooool00?oooooo3oooool3o`0000oooooo003oooooob7ooooo003o
ooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {111.75, 0}} -> {-13.0854, -35.3446, 0.807044, \
0.807044}},
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[opticalsystemreflected,MatrixForm->True,DecomposeABCD->True,\
NumericalResults->True]\
\>", "Input",
  CellLabel->"In[25]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.9999999999999997`", "0"},
                    {"0", "1.0000000000000002`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50.000000000000014`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-0.9999999999999994`\), \(-229.99999999999986`\)},
                    {"0", \(-0.9999999999999999`\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(-114.99999999999996`\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "9.999999999999998`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {\(-0.00657781790869083`\), "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50.`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        MatrixForm[ {{0.99999999999999967, 0}, {0, 1.0000000000000002}}], 
        MatrixForm[ {{1, 50.000000000000014}, {0, 1}}], 
        MatrixForm[ {{-0.99999999999999944, -229.99999999999986}, {
          0, -0.99999999999999989}}], 
        MatrixForm[ {{1, -114.99999999999996}, {0, 1}}], 
        MatrixForm[ {{1.0, 0}, {0, 1.51906311879655}}], 
        MatrixForm[ {{1, 9.9999999999999982}, {0, 1}}], 
        MatrixForm[ {{1.0, 0}, {-0.0065778179086908297, 
          0.65830049299875815}}], 
        MatrixForm[ {{1, 50.0}, {0, 1}}]}, TableDirections -> Row]]], "Output",\

  CellLabel->"Out[25]//TableForm=",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[opticalsystemreflected,{f>0},MatrixForm->True,DecomposeABCD->\
True,NumericalResults->False,SymbolicRefractiveModels->{Air->1,BK7->3/2}]\
\>", "Input",
  CellLabel->"In[27]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-1\), \(2\ \((\(-175\) + d1 + t)\)\)},
                    {"0", \(-1\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(\(-175\) + d1 + t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", \(3\/2\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "t"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(16650813\/\(25948915\ f\)\)\), \(2\/3\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        MatrixForm[ {{1, 0}, {0, 1}}], 
        MatrixForm[ {{1, 50}, {0, 1}}], 
        MatrixForm[ {{-1, 
          Times[ 2, 
            Plus[ -175, d1, t]]}, {0, -1}}], 
        MatrixForm[ {{1, 
          Plus[ -175, d1, t]}, {0, 1}}], 
        MatrixForm[ {{1, 0}, {0, 
          Rational[ 3, 2]}}], 
        MatrixForm[ {{1, t}, {0, 1}}], 
        MatrixForm[ {{1, 0}, {
          Times[ 
            Rational[ -16650813, 25948915], 
            Power[ f, -1]], 
          Rational[ 2, 3]}}], 
        MatrixForm[ {{1, d1}, {0, 1}}]}, TableDirections -> Row]]], "Output",
  CellLabel->"Out[27]//TableForm=",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianTrace", "Subsubsection",
  CellTags->{"AOG0.", "4.2.2", "AOG4.", "AOG4.2", "AOG4.2.2"}],

Cell[CellGroupData[{

Cell["GaussianTrace[opticalsystemreflected]", "Input",
  CellLabel->"In[238]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.2"}],

Cell[BoxData[
    \({{BeamSpotSize \[Rule] 20.`, BeamDivergence \[Rule] 0.01`, 
        ComplexBeamParameter \[Rule] \(\(3999.994267820059`\)\(\
\[InvisibleSpace]\)\) + 6.771809703999253`\ \[ImaginaryI], 
        BeamWaist \[Rule] 0.033859048519996264`, 
        WaistDistance \[Rule] \(-3999.9942678200596`\), 
        BeamScaleLength \[Rule] 6.771809703999252`, 
        BeamCurvature \[Rule] {\(-4000.005732188155`\), \(-1\)}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {0, 0, 0}, OpticalLength \[Rule] 0, 
        Intensity \[Rule] 100, 
        WaveLength \[Rule] 0.532`}, {BeamSpotSize \[Rule] 
          20.249999646161747`, 
        BeamDivergence \[Rule] \(-0.25981862515242854`\), 
        ComplexBeamParameter \[Rule] \(-155.87796768695574`\) + 
            0.006603715655931384`\ \[ImaginaryI], 
        BeamWaist \[Rule] 0.0008578841613108302`, 
        WaistDistance \[Rule] 155.87796768695574`, 
        BeamScaleLength \[Rule] 0.006603715655931384`, 
        BeamCurvature \[Rule] {155.87796796671984`, \(-1\)}, 
        ABCDMatrix \[Rule] {{1, 
              50.000000000000014`}, {\(-0.00657781790869083`\), 
              0.32940959756421656`}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {49.999999999999986`, 0, 0}, 
        OpticalLength \[Rule] 50.01347257285403`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 0.532`}, {BeamSpotSize \[Rule] 18.95090652164525`, 
        BeamDivergence \[Rule] \(-0.39468089104547893`\), 
        ComplexBeamParameter \[Rule] \(-96.03153804597986`\) + 
            0.004347229271923269`\ \[ImaginaryI], 
        BeamWaist \[Rule] 0.0008578841613108324`, 
        WaistDistance \[Rule] 96.03153804597987`, 
        BeamScaleLength \[Rule] 0.0043472292719232706`, 
        BeamCurvature \[Rule] {96.03153824277358`, \(-1\)}, 
        ABCDMatrix \[Rule] {{0.9342218209130916`, 
              53.294095975642186`}, {\(-0.009992120587251692`\), 
              0.5003939706374153`}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {60.`, 0, 0}, 
        OpticalLength \[Rule] 65.20819689852712`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 0.532`}, {BeamSpotSize \[Rule] 3.743244831193259`, 
        BeamDivergence \[Rule] 0.3946808910454796`, 
        ComplexBeamParameter \[Rule] \(\(18.968461954020135`\)\(\
\[InvisibleSpace]\)\) + 0.004347229271923252`\ \[ImaginaryI], 
        BeamWaist \[Rule] 0.0008578841613108307`, 
        WaistDistance \[Rule] \(-18.968461954020135`\), 
        BeamScaleLength \[Rule] 0.004347229271923254`, 
        BeamCurvature \[Rule] {\(-18.968462950326657`\), \(-1\)}, 
        ABCDMatrix \[Rule] {{\(-0.21487204662085288`\), 
              110.83940259894493`}, {\(-0.009992120587251695`\), 
              0.5003939706374154`}}, 
        ABCDRotationMatrix \[Rule] {{0, 0.9999999999999998`, 0}, {1, 0, 
              0}, {0, 0, \(-1.`\)}}, ABCDCenterPoint \[Rule] {175.`, 0, 0}, 
        OpticalLength \[Rule] 180.23918381609133`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 0.532`}, {BeamSpotSize \[Rule] 
          13.610267036061567`, BeamDivergence \[Rule] 0.3946808910454787`, 
        ComplexBeamParameter \[Rule] \(\(68.96846195402011`\)\(\
\[InvisibleSpace]\)\) + 0.004347229271923272`\ \[ImaginaryI], 
        BeamWaist \[Rule] 0.0008578841613108327`, 
        WaistDistance \[Rule] \(-68.96846195402011`\), 
        BeamScaleLength \[Rule] 0.004347229271923274`, 
        BeamCurvature \[Rule] {\(-68.96846222803525`\), \(-1\)}, 
        ABCDMatrix \[Rule] {{\(-0.7144780759834375`\), 
              135.8591011308157`}, {\(-0.009992120587251695`\), 
              0.5003939706374154`}}, 
        ABCDRotationMatrix \[Rule] {{0, 0.9999999999999998`, 0}, {1, 0, 
              0}, {0, 0, \(-1.`\)}}, 
        ABCDCenterPoint \[Rule] {175.`, 50.`, 0}, 
        OpticalLength \[Rule] 230.25265638894535`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 0.532`}}\)], "Output",
  CellLabel->"Out[238]=",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.2"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianPlot", "Subsubsection",
  CellTags->{"AOG0.", "4.2.3", "AOG4.", "AOG4.2", "AOG4.2.3"}],

Cell[CellGroupData[{

Cell["GaussianPlot[opticalsystemreflected];", "Input",
  CellLabel->"In[29]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0042328 0 0.0264244 [
[.23545 -0.0125 -6 -9 ]
[.23545 -0.0125 6 0 ]
[.44709 -0.0125 -9 -9 ]
[.44709 -0.0125 9 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.87037 -0.0125 -9 -9 ]
[.87037 -0.0125 9 0 ]
[.01131 .13212 -6 -4.5 ]
[.01131 .13212 0 4.5 ]
[.01131 .26424 -12 -4.5 ]
[.01131 .26424 0 4.5 ]
[.01131 .39637 -12 -4.5 ]
[.01131 .39637 0 4.5 ]
[.01131 .52849 -12 -4.5 ]
[.01131 .52849 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23545 0 m
.23545 .00625 L
s
[(50)] .23545 -0.0125 0 1 Mshowa
.44709 0 m
.44709 .00625 L
s
[(100)] .44709 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(150)] .65873 -0.0125 0 1 Mshowa
.87037 0 m
.87037 .00625 L
s
[(200)] .87037 -0.0125 0 1 Mshowa
.125 Mabswid
.06614 0 m
.06614 .00375 L
s
.10847 0 m
.10847 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.19312 0 m
.19312 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.32011 0 m
.32011 .00375 L
s
.36243 0 m
.36243 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.48942 0 m
.48942 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.57407 0 m
.57407 .00375 L
s
.6164 0 m
.6164 .00375 L
s
.70106 0 m
.70106 .00375 L
s
.74339 0 m
.74339 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.82804 0 m
.82804 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.95503 0 m
.95503 .00375 L
s
.99735 0 m
.99735 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .13212 m
.03006 .13212 L
s
[(5)] .01131 .13212 1 0 Mshowa
.02381 .26424 m
.03006 .26424 L
s
[(10)] .01131 .26424 1 0 Mshowa
.02381 .39637 m
.03006 .39637 L
s
[(15)] .01131 .39637 1 0 Mshowa
.02381 .52849 m
.03006 .52849 L
s
[(20)] .01131 .52849 1 0 Mshowa
.125 Mabswid
.02381 .02642 m
.02756 .02642 L
s
.02381 .05285 m
.02756 .05285 L
s
.02381 .07927 m
.02756 .07927 L
s
.02381 .1057 m
.02756 .1057 L
s
.02381 .15855 m
.02756 .15855 L
s
.02381 .18497 m
.02756 .18497 L
s
.02381 .2114 m
.02756 .2114 L
s
.02381 .23782 m
.02756 .23782 L
s
.02381 .29067 m
.02756 .29067 L
s
.02381 .31709 m
.02756 .31709 L
s
.02381 .34352 m
.02756 .34352 L
s
.02381 .36994 m
.02756 .36994 L
s
.02381 .42279 m
.02756 .42279 L
s
.02381 .44922 m
.02756 .44922 L
s
.02381 .47564 m
.02756 .47564 L
s
.02381 .50206 m
.02756 .50206 L
s
.02381 .55491 m
.02756 .55491 L
s
.02381 .58134 m
.02756 .58134 L
s
.02381 .60776 m
.02756 .60776 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .52849 m
.09004 .53056 L
.16227 .53281 L
.19739 .53391 L
.21452 .53444 L
.22263 .53469 L
.23011 .53493 L
.23206 .53499 L
.23388 .53505 L
.23578 .53482 L
.23788 .53312 L
.24631 .52628 L
.26163 .51386 L
.29535 .47912 L
.36182 .39724 L
.43249 .31017 L
.50056 .22631 L
.56603 .14565 L
.60258 .10063 L
.63571 .05981 L
.6523 .03937 L
.66103 .02862 L
.67025 .01726 L
.67833 .00731 L
.68054 .00458 L
.68176 .00308 L
.68292 .00166 L
.68516 .0011 L
.6872 .00362 L
.70279 .02283 L
.7685 .10378 L
.83841 .1899 L
.90572 .27283 L
.97044 .35256 L
.97619 .35964 L
s
0 0 0 r
gsave
.23545 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27778 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76455 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 0 m
.23545 .56185 L
s
.27778 0 m
.27778 .56185 L
s
.76455 0 m
.76455 .56185 L
s
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00C_ooool3o`0000Cooooo0_l0000Xooooo`?o00001?ooool2o`0000Cooooo0_l0000Toooo
o`?o00000oooool3o`0000Cooooo0_l0000Sooooo`Go00000oooool2o`0000Cooooo0_l0000/oooo
o`00COooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
9?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000[ooooo`00DOooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0002_ooooo001Aooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0Yooooo`00COooool4o`0000?ooooo00Co
0000oooooooooooo0000:?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009?ooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000
oooooooooooo00008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000[ooooo`00COooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0002Oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00008oooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002_ooooo001=ooooo`Go00000oooool2o`0002Wooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l0000Uooooo`04o`000?ooooooooooooooo`Go00000oooool2
o`0002Cooooo0ol00004ooooo`;o00001?ooool2o`0002cooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo000JooooojKo00000_l9jPY<o`0001;ooooo000Poooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00?o2NX:ooooool9jPX00_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aoooo
o`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0G_ooool01?l9jP[oooooooooool9jPXAooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo05gooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0>ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`0=ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
5_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo05cooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0<ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo0_l0000aooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Foooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooo
oooo00cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F_ooool00ol9
jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00_ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0FOooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00[o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F?ooool00ol9jP[ooooo
ooooo`0<ooooo`03o`WZ2_oooooooooo00Wooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0F?ooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00Sooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Eoooool00ol9jP[oooooooooo`0>
ooooo`03o`WZ2_oooooooooo00Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0F
ooooo`008?ooool2o`00037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Foooo
o`03o`WZ2_oooooooooo013ooooo00?o2NX:ooooooooool01oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1Eooooo`03o`WZ2_oooooooooo01;ooooo00?o2NX:oooooooo
ool01_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Dooooo`03o`WZ
2_oooooooooo01Cooooo00?o2NX:ooooooooool01Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Dooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:ooooooooool01?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Cooooo`03o`WZ2_oooooo
oooo01Kooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Booooo`03o`WZ2_oooooooooo01Sooooo00?o2NX:ooooooooool00oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Aooooo`03o`WZ2_oooooooooo01[o
oooo00?o2NX:ooooooooool00_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Ko
oooo000Pooooo`;o0000<Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo053ooooo
00?o2NX:ooooooooool07?ooool01Ol9jP[ooooooooooooooooo000003;ooooo00?o0000oooooooo
ool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo053ooooo00?o2NX:ooooooooool07Oooool01?l9jP[oooooooooool0000booooo`03
o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1?ooooo`03o`WZ2_oooooooooo01kooooo00Co2NX:oooooooooooo
0000<_ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0C_ooool00ol9jP[oooooooooo`0Pooooo`03o`WZ
2_oooooo000003;ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04gooooo00?o2NX:ooooooooool08_oo
ool00ol9jP[o0000ooooo`0aooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1<ooooo`03o`WZ2_oooooo
oooo02Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool2o`00
037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1<ooooo`03o`WZ2_oooooooooo
02Cooooo00?o0000o`WZ2_ooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Boooool00ol9jP[o
ooooooooo`0Uooooo`03o`000?l9jP[ooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04[ooooo
00?o2NX:ooooooooool09_ooool00ol0003oooooo`WZ2P0`ooooo`03o`000?oooooooooo01Kooooo
000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`19ooooo`03o`WZ2_oooooooooo02Oooooo00Co0000oooooooooooo2NX:;oooool00ol0003ooooo
ooooo`0Fooooo`006?ooool3o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo04Sooooo00?o2NX:ooooooooool0:?ooool01Ol0003ooooooooo
oooooooo2NX:02kooooo00?o0000ooooooooool05_ooool001Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`17ooooo`03o`WZ2_oooooooooo02Wooooo00?o0000ooooooooool00_ooool00ol9jP[ooooo
ooooo`0[ooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o
2NX:ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`03o`WZ2_oooooooooo02_ooooo00?o
0000ooooooooool05_ooool001_ooooo00?o0000ooooooooool00_ooool3o`00033ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`16ooooo`03o`WZ2_oooooooooo02[ooooo00?o0000
ooooooooool00oooool00ol9jP[oooooooooo`0Zooooo`03o`000?oooooooooo01Kooooo000Goooo
o`Co00001Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0AOooool00ol9jP[oooooooooo`0[ooooo`03o`000?oooooooooo00Cooooo00?o2NX:oooo
ooooool0:Oooool00ol0003oooooooooo`0Fooooo`005oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`14ooooo`03
o`WZ2_oooooooooo02cooooo00?o0000ooooooooool01Oooool00ol9jP[oooooooooo`0Xooooo`03
o`000?oooooooooo01Kooooo000Gooooo`Go00001?ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0@oooool00ol9jP[oooooooooo`0]ooooo`03o`00
0?oooooooooo00Kooooo00?o2NX:ooooooooool09oooool00ol0003oooooooooo`0Fooooo`008?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@ooo
ool00ol9jP[oooooooooo`0]ooooo`03o`000?oooooooooo00Oooooo00?o2NX:ooooooooool09_oo
ool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0@_ooool00ol9jP[oooooooooo`0^ooooo`03o`000?oooooo
oooo00Oooooo00?o2NX:ooooooooool09_ooool00ol0003oooooooooo`0Fooooo`008?ooool2o`00
037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`11ooooo`03o`WZ2_oooooooooo
02oooooo00?o0000ooooooooool02?ooool00ol9jP[oooooooooo`0Uooooo`03o`000?oooooooooo
01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`10ooooo`03o`WZ2_oooooooooo033ooooo00?o0000ooooooooool02Oooool00ol9jP[o
ooooooooo`0Tooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0oooooo`03o`WZ2_oooooooooo037ooooo
00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0Sooooo`03o`000?oooooooooo01Kooooo
000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0nooooo`03o`WZ2_oooooooooo03;ooooo00?o0000ooooooooool02oooool00ol9jP[ooooooooo
o`0Rooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0nooooo`03o`WZ2_oooooooooo03;ooooo00?o0000
ooooooooool02oooool00ol9jP[oooooooooo`0Rooooo`03o`000?oooooooooo01Kooooo000Poooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0moooo
o`03o`WZ2_oooooooooo03?ooooo00?o0000ooooooooool03?ooool00ol9jP[oooooooooo`0Qoooo
o`03o`000?oooooooooo01Kooooo000Pooooo`;o0000<Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo03cooooo00?o2NX:ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`03
o`WZ2_oooooooooo023ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o2NX:ooooooooool0
=Oooool00ol0003oooooooooo`0>ooooo`03o`WZ2_oooooooooo01oooooo00?o0000ooooooooool0
5_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03[ooooo00?o2NX:ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`03o`WZ2_oo
oooooooo01kooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo00?o2NX:ooooooooool0=oooool0
0ol0003oooooooooo`0?ooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool05_ooool0
023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03Sooooo00?o2NX:ooooooooool0>?ooool00ol0003oooooooooo`0@ooooo`03o`WZ2_oooooooooo
01gooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03Sooooo00?o2NX:ooooooooool0>?ooool00ol0003o
ooooooooo`0Aooooo`03o`WZ2_oooooooooo01cooooo00?o0000ooooooooool05_ooool0023ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Oooooo
00?o2NX:ooooooooool0>Oooool00ol0003oooooooooo`0Booooo`03o`WZ2_oooooooooo01_ooooo
00?o0000ooooooooool05_ooool0023ooooo0_l0000aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0=_ooool00ol9jP[oooooooooo`0jooooo`03o`000?oooooooooo01?ooooo00?o
2NX:ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Oooool00ol9jP[oooooooooo`0k
ooooo`03o`000?oooooooooo01?ooooo00?o2NX:ooooooooool06_ooool00ol0003oooooooooo`0F
ooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0=?ooool00ol9jP[oooooooooo`0looooo`03o`000?oooooooooo01Cooooo00?o2NX:oooo
ooooool06Oooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0<oooool00ol9jP[oooooooooo`0mooooo`03
o`000?oooooooooo01Gooooo00?o2NX:ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`00
8?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
<oooool00ol9jP[oooooooooo`0mooooo`03o`000?oooooooooo01Kooooo00?o2NX:ooooooooool0
5oooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0<_ooool00ol9jP[oooooooooo`0nooooo`03o`000?oo
oooooooo01Oooooo00?o2NX:ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`008?ooool2
o`00037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0aooooo`03o`WZ2_oooooo
oooo03oooooo00?o0000ooooooooool05oooool00ol9jP[oooooooooo`0Fooooo`03o`000?oooooo
oooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0`ooooo`03o`WZ2_oooooooooo043ooooo00?o0000ooooooooool06?ooool00ol9
jP[oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`03o`WZ2_oooooooooo047o
oooo00?o0000ooooooooool06Oooool00ol9jP[oooooooooo`0Dooooo`03o`000?oooooooooo01Ko
oooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0_ooooo`03o`WZ2_oooooooooo047ooooo00?o0000ooooooooool06_ooool00ol9jP[ooooo
ooooo`0Cooooo`03o`000?oooooooooo01Kooooo000Booooo`?o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02kooooo00?o
2NX:ooooooooool0@_ooool00ol0003oooooooooo`0Kooooo`03o`WZ2_oooooooooo01;ooooo00?o
0000ooooooooool05_ooool001?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0]ooooo`03o`WZ2_oooooooooo04?ooooo00?o0000ooooooooool06oooool00ol9jP[ooooooooo
o`0Booooo`03o`000?oooooooooo01Kooooo000Cooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0;?ooool00ol9jP[oooooooooo`14ooooo`03o`000?oooooooooo01cooooo00?o
2NX:ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`004oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0:oooool00ol9jP[oooooooooo`15ooooo`03o`000?oooooooooo01gooooo00?o
2NX:ooooooooool04?ooool00ol0003oooooooooo`0Fooooo`004oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02[ooooo00?o2NX:ooooooooool0A_ooool00ol0003ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo00oooooo00?o0000ooooooooool05_ooool001;ooooo0_l00004
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02[ooooo00?o2NX:ooooooooool0A_ooool00ol0003ooooooooo
o`0Oooooo`03o`WZ2_oooooooooo00kooooo00?o0000ooooooooool05_ooool001?ooooo00?o0000
ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02Wooooo00?o2NX:ooooooooool0Aoooool00ol0003oooooooooo`0O
ooooo`03o`WZ2_oooooooooo00kooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Sooooo00?o2NX:oooo
ooooool0B?ooool00ol0003oooooooooo`0Pooooo`03o`WZ2_oooooooooo00gooooo00?o0000oooo
ooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02Oooooo00?o2NX:ooooooooool0BOooool00ol0003oooooooooo`0Qooooo`03
o`WZ2_oooooooooo00cooooo00?o0000ooooooooool05_ooool0023ooooo0_l0000aooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool09_ooool00ol9jP[oooooooooo`1:ooooo`03o`00
0?oooooooooo02;ooooo00?o2NX:ooooooooool02oooool00ol0003oooooooooo`0Fooooo`008?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09_oo
ool00ol9jP[oooooooooo`1:ooooo`03o`000?oooooooooo02?ooooo00?o2NX:ooooooooool02_oo
ool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool09Oooool00ol9jP[oooooooooo`1;ooooo`03o`000?oooooo
oooo02Cooooo00?o2NX:ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09?ooool00ol9
jP[oooooooooo`1<ooooo`03o`000?oooooooooo02Cooooo00?o2NX:ooooooooool02Oooool00ol0
003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08oooool00ol9jP[oooooooooo`1=ooooo`03o`000?oooooooooo02Go
oooo00?o2NX:ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol9jP[ooooo
ooooo`1>ooooo`03o`000?oooooooooo02Kooooo00?o2NX:ooooooooool01oooool00ol0003ooooo
ooooo`0Fooooo`008?ooool2o`00037ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Rooooo`03o`WZ2_oooooooooo04kooooo00?o0000ooooooooool09oooool00ol9jP[ooooooooo
o`06ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`WZ2_oooooooooo04oooooo00?o0000
ooooooooool0:?ooool00ol9jP[oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo000Poooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Poooo
o`03o`WZ2_oooooooooo053ooooo00?o0000ooooooooool0:Oooool00ol9jP[oooooooooo`04oooo
o`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Oooooo`03o`WZ2_oooooooooo057ooooo00?o0000oooooooo
ool0:_ooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`WZ
2_oooooooooo05;ooooo00?o0000ooooooooool0:_ooool00ol9jP[oooooooooo`03ooooo`03o`00
0?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Nooooo`03o`WZ2_oooooooooo05;ooooo00?o0000ooooooooool0:ooo
ool00ol9jP[oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`WZ2_oooooo
oooo05?ooooo00?o0000ooooooooool0;?ooool01Ol9jP[ooooooooooooooooo000001Sooooo000P
ooooo`;o0000<Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o2NX:
ooooooooool0E?ooool00ol0003oooooooooo`0]ooooo`04o`WZ2_ooooooooooo`0001Sooooo000P
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0K
ooooo`03o`WZ2_oooooooooo05Gooooo00?o0000ooooooooool0;_ooool00ol9jP[oooooo`00000H
ooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06_ooool00ol9jP[oooooooooo`1Fooooo`03o`000?oooooooooo02oooooo00?o2NX:o`00
0?ooool05oooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Wooooo00?o2NX:ooooooooool0Eoooool00ol0003oooooooooo`0_ooooo`03
o`WZ2_l0003ooooo01Oooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Iooooo`03o`WZ2_oooooooooo05Oooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool06?ooool00ol9jP[oooooooooo`1Hooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo0_l0000aooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05oooool00ol9jP[oooooooooo`1Iooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o2NX:ooooooooool0F_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`WZ2_oooooooooo05_o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol9jP[ooooo
ooooo`1Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool001;ooooo0ol0
0003ooooo`?o00001Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool05?ooool00ol9jP[oooooooooo`1Looooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool05_ooool001?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01?ooooo00?o2NX:ooooooooool0GOooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo01Kooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool0
0ol9jP[oooooooooo`1Nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0
01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`?o0000<?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o2NX:ooooooooool0Goooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Cooooo`04o`000?oooooooooooooo
o`Co00001Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04Oooool00ol9jP[oooooooooo`1Oooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool05_ooool001;ooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o2NX:oooooooo
ool0H?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Cooooo`04o`00
0?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool03oooool00ol9jP[oooooooooo`1Qooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00kooooo00?o2NX:ooooooooool0H_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`WZ2_oooooooooo06?ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool2o`00037ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`WZ2_oooooooooo06?ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol9jP[oooooooooo`1Toooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o2NX:oooooooo
ool0IOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`WZ
2_oooooooooo06Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool00ol9jP[oooooooooo`1Wooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_oo
ool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o2NX:ooooooooool0Ioooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`WZ2_oooooooooo06Sooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0Fooooo`008?ooool2o`00037ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`WZ2_oooooooooo06Wooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01_ooool00ol9jP[oooooooooo`1Zooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Gooooo00?o2NX:ooooooooool0Joooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`WZ2_oooooooooo06_ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol9jP[oooooooooo`1/oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o2NX:oooooooo
ool0KOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`;o0000
<Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o2NX:ooooooooool0
K_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo2NX:077ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo2NX:L_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool02?ooool00ol0003oooooo`WZ2P1cooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08
ooooo`03o`000?l9jP[ooooo07?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0F
ooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`;o
0000<Oooool00ol0003oooooooooo`07ooooo`03o`WZ2_l0003ooooo07Cooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00Kooooo00?o2NX:ooooool00000MOooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01Ooo
ool01?l9jP[oooooooooool0001eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
5_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`03ooooo`;o2NX:0ooo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_oo
ool0017ooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool05_ooool001;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo033ooooo00Go0000oooooooooooooooo
o`WZ2P06ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Fooooo`004oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0<?ooool01?l0003oooooooooool9jPX7ooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`005?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_oooolJo`WZ2QWooooo00?o0000ooooool9
jPX02?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool05_ooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool05ooooolIo`WZ2P03o`000?l9jP[ooooo00Sooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Aooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool05_ooool001;ooooo0ol00004ooooo`;o00001Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Fooooo`008?ooool2o`00037ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo0?gooooo000Pooooo`03o`00
0?oooooooooo02gooooo1Ol00006ooooo`Go0000LOooool2o`000004ooooool0003o0000o`0002ko
oooo0ol0000Hooooo`008?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0000Oo
oooo00Co0000oooooooooooo0000LOooool01Ol0003ooooooooooooooooo000002oooooo00Co0000
oooooooooooo00005oooool0023ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo07;ooooo00Go0000ooooooooooooooooo`00000booooo`03o`000?oo
oooooooo01Gooooo000Pooooo`;o0000;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo07;ooooo00Go0000ooooooooooooooooo`00000`ooooo`;o00006?ooool0023ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07;ooooo00Go0000
ooooool0003oooooo`00000_ooooo`03o`000?oooooooooo01Sooooo000Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1booooo`;o000000?ooooo
o`000?l00000;oooool01?l0003oooooooooool0000Gooooo`008?ooool00ol0003oooooooooo`0]
ooooo`?o00002?ooool3o`0007?ooooo00Co0000oooooooooooooooo0_l0000_ooooo`?o00005ooo
ool0023ooooo00?o0000ooooooooool0oOooool0023ooooo00?o0000ooooooooool0oOooool0023o
oooo0_l0003nooooo`008?ooool00ol0003oooooooooo`3mooooo`008?ooool00ol0003ooooooooo
o`3mooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00S_oo
ool3o`0008oooooo002?ooooo`03o`000?oooooooooo08kooooo001Zooooo`Co00000oooool3o`00
00?ooooo1?l000001_oooooo0000ooooool0003oooooo`0000Sooooo0ol00003ooooo`?o00000ooo
ool3o`0000Cooooo0_l00009ooooo`?o00000_ooool5o`000003ooooool0003o000000?o00000_oo
ool3o`0006Cooooo001[ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool01?l0003ooooo
ooooool00002ooooo`05o`000?oooooo0000ooooool000002?ooool01?l0003oooooooooool00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo0000Ioooool006_ooooo00Go0000oooooooooooo0000oooo
o`05o`0000;ooooo0ol00002ooooo`05o`000?oooooo0000ooooool000002oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00003_ooool01Ol0
003ooooooooooooooooo000000Gooooo00Co0000oooooooooooooooo1Ol0001Sooooo`00Joooool3
o`0000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00So0000oooooooooooo
0000ooooool0003oooooo`0000Wooooo0_l00003ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool01?l0003oooooooooool0000<ooooo`;o00001?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1Qooooo`00Joooool01?l0
003oooooooooool00002ooooo`?o00000oooool2o`0000?ooooo0_l000000ooooooo0000ooooo`08
ooooo`03o`000?oooooooooo00;ooooo1?l00003ooooo`?o00000_ooool4o`0000Wooooo00?o0000
ooooooooool00_ooool3o`0000?ooooo1Ol00002ooooo`?o0000I?ooool006_ooooo00Co0000oooo
oooooooo00006_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooo0000MOooool006[ooooo1?l0000Looooo`?o00003_ooool00ol0003ooooooooo
o`0:ooooo`?o00000oooool00ol0003oooooooooo`1_ooooo`00oooooolQooooo`00oooooolQoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-31.8099, -1.87767, \
0.974221, 0.156056}},
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
GaussianPlot[opticalsystemreflected, RenderedParameters->BeamCurvature];\
\>", "Input",
  CellLabel->"In[30]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0042328 0.581513 0.000139963 [
[.23545 .56901 -6 -9 ]
[.23545 .56901 6 0 ]
[.44709 .56901 -9 -9 ]
[.44709 .56901 9 0 ]
[.65873 .56901 -9 -9 ]
[.65873 .56901 9 0 ]
[.87037 .56901 -9 -9 ]
[.87037 .56901 9 0 ]
[.01131 .02166 -30 -4.5 ]
[.01131 .02166 0 4.5 ]
[.01131 .16162 -30 -4.5 ]
[.01131 .16162 0 4.5 ]
[.01131 .30159 -30 -4.5 ]
[.01131 .30159 0 4.5 ]
[.01131 .44155 -30 -4.5 ]
[.01131 .44155 0 4.5 ]
[.5 .63053 -74.0625 0 ]
[.5 .63053 74.0625 12 ]
[.23545 -0.03687 -5 -6 ]
[.23545 -0.03687 5 6 ]
[.27778 -0.03687 -5 -6 ]
[.27778 -0.03687 5 6 ]
[.76455 -0.03687 -5 -6 ]
[.76455 -0.03687 5 6 ]
[.97619 -0.03687 -5 -6 ]
[.97619 -0.03687 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23545 .58151 m
.23545 .58776 L
s
[(50)] .23545 .56901 0 1 Mshowa
.44709 .58151 m
.44709 .58776 L
s
[(100)] .44709 .56901 0 1 Mshowa
.65873 .58151 m
.65873 .58776 L
s
[(150)] .65873 .56901 0 1 Mshowa
.87037 .58151 m
.87037 .58776 L
s
[(200)] .87037 .56901 0 1 Mshowa
.125 Mabswid
.06614 .58151 m
.06614 .58526 L
s
.10847 .58151 m
.10847 .58526 L
s
.15079 .58151 m
.15079 .58526 L
s
.19312 .58151 m
.19312 .58526 L
s
.27778 .58151 m
.27778 .58526 L
s
.32011 .58151 m
.32011 .58526 L
s
.36243 .58151 m
.36243 .58526 L
s
.40476 .58151 m
.40476 .58526 L
s
.48942 .58151 m
.48942 .58526 L
s
.53175 .58151 m
.53175 .58526 L
s
.57407 .58151 m
.57407 .58526 L
s
.6164 .58151 m
.6164 .58526 L
s
.70106 .58151 m
.70106 .58526 L
s
.74339 .58151 m
.74339 .58526 L
s
.78571 .58151 m
.78571 .58526 L
s
.82804 .58151 m
.82804 .58526 L
s
.9127 .58151 m
.9127 .58526 L
s
.95503 .58151 m
.95503 .58526 L
s
.99735 .58151 m
.99735 .58526 L
s
.25 Mabswid
0 .58151 m
1 .58151 L
s
.02381 .02166 m
.03006 .02166 L
s
[(-4000)] .01131 .02166 1 0 Mshowa
.02381 .16162 m
.03006 .16162 L
s
[(-3000)] .01131 .16162 1 0 Mshowa
.02381 .30159 m
.03006 .30159 L
s
[(-2000)] .01131 .30159 1 0 Mshowa
.02381 .44155 m
.03006 .44155 L
s
[(-1000)] .01131 .44155 1 0 Mshowa
.125 Mabswid
.02381 .04965 m
.02756 .04965 L
s
.02381 .07765 m
.02756 .07765 L
s
.02381 .10564 m
.02756 .10564 L
s
.02381 .13363 m
.02756 .13363 L
s
.02381 .18962 m
.02756 .18962 L
s
.02381 .21761 m
.02756 .21761 L
s
.02381 .2456 m
.02756 .2456 L
s
.02381 .27359 m
.02756 .27359 L
s
.02381 .32958 m
.02756 .32958 L
s
.02381 .35757 m
.02756 .35757 L
s
.02381 .38557 m
.02756 .38557 L
s
.02381 .41356 m
.02756 .41356 L
s
.02381 .46954 m
.02756 .46954 L
s
.02381 .49754 m
.02756 .49754 L
s
.02381 .52553 m
.02756 .52553 L
s
.02381 .55352 m
.02756 .55352 L
s
.02381 .60951 m
.02756 .60951 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -135.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Radius) show
135.125 13.000 moveto
(Of) show
153.125 13.000 moveto
(Curvature) show
207.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .02166 m
.09004 .01947 L
.16227 .01708 L
.19739 .01592 L
.21452 .01536 L
.22263 .01509 L
.23011 .01484 L
.23206 .01478 L
.23388 .01472 L
.23578 .60332 L
.23788 .60325 L
.24631 .60297 L
.26163 .60246 L
.26598 .60232 L
.27011 .60218 L
.27383 .60206 L
.27593 .60199 L
.27788 .59495 L
.27897 .59491 L
.28016 .59487 L
.28231 .5948 L
.28633 .59467 L
.29535 .59437 L
.36564 .59205 L
.43333 .58981 L
.49843 .58766 L
.56773 .58537 L
.63443 .58316 L
.70533 .58082 L
.77364 .57856 L
.83935 .57638 L
.90926 .57407 L
.97619 .57186 L
s
0 0 0 r
gsave
.23545 -0.03687 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27778 -0.03687 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76455 -0.03687 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 -0.03687 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 0 m
.23545 .60442 L
s
.27778 0 m
.27778 .60442 L
s
.76455 0 m
.76455 .60442 L
s
.97619 0 m
.97619 .60442 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[30]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00Foooool5o`0000Gooooo1Ol0
001_ooooo`;o000000Coooooo`000?l0003o0000;Oooool3o`00017ooooo001Looooo`04o`000?oo
ooooooooo`0000Kooooo00Co0000oooooooooooo0000Koooool01Ol0003ooooooooooooooooo0000
02kooooo00Co0000oooooooooooo00004?ooool005cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1`ooooo`05o`000?ooooooooooooooool00000<Oooool00ol0003oooooooooo`0>
ooooo`00G?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo073ooooo00Go0000oooo
ooooooooooooo`00000_ooooo`;o00004Oooool005cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1`ooooo`05o`000?oooooo0000ooooool00000;_ooool00ol0003oooooooooo`0A
ooooo`00G?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo073ooooo0_l000000ooo
oooo0000o`00000^ooooo`04o`000?ooooooooooo`00013ooooo001Kooooo`?o00001oooool3o`00
077ooooo00Co0000oooooooooooooooo0_l0000^ooooo`?o00004?ooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool002_ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0?ooooo`00:oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool001;ooooo0ol00003ooooo`;o
00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool03oooool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Kooooo6_l9jPX00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`002_ooool5o`000003ooooool0003o0000
00?o00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?oooolIo`WZ2QWooooo00?o2NX:o`000?ooool02?ooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool0013ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0003o
oooo00Sooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00oooooo000Aooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
;oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0?ooooo`004_ooool2o`0000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0;oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0?ooooo`004oooool00ol0003oooooooooo`02ooooo`;o
00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02oooooo00?o2NX:o`000?oo
ool02?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool03oooool002_ooooo00?o0000ooooooooool0;oooool00ol9jP[o0000ooooo`08ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:ooo
ool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`;o0000<?ooool0
0ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0003ooooo
00Sooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00oooooo000[ooooo`03o`000?oooooooooo02oooooo00?o2NX:o`000?ooool02?ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool002_ooooo
00?o0000ooooooooool0;oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003ooooooooo
o`0_ooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo02oooooo00?o2NX:
o`000?ooool02?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool03oooool002_ooooo00?o0000ooooooooool0;oooool00ol9jP[o0000ooooo`08oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?oooo
o`00:oooool2o`00033ooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool002_ooooo00?o0000ooooooooool0
;oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0
003ooooo00Sooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00oooooo000[ooooo`03o`000?oooooooooo02oooooo00?o2NX:o`000?ooool02?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool0
02_ooooo00?o0000ooooooooool0;oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003o
ooooooooo`0_ooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`;o0000<?ooool00ol9jP[o0000
ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0?ooooo`00:oooool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0003ooooo00Sooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[
ooooo`03o`000?oooooooooo02oooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool002_ooooo00?o0000oooo
ooooool0;oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0_ooooo`03
o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo02oooooo00?o2NX:o`000?ooool0
2?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
3oooool002_ooooo00?o0000ooooooooool0;oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool2
o`00033ooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool03oooool002_ooooo00?o0000ooooooooool0;oooool00ol9
jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0003ooooo00So
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oo
oooo000[ooooo`03o`000?oooooooooo02oooooo00?o2NX:o`000?ooool02?ooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool0017ooooo0ol0
0004ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02oooooo00?o
2NX:o`000?ooool02?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool03oooool0013ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo02oooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool000[ooooo1Ol00005ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;oooool00ol9jP[o0000oooo
o`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0?ooooo`004_ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo0ol0000_ooooo`03o`WZ2_l0003ooooo00So
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oo
oooo000Dooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;oooool0
0ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0?ooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0;oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`004Oooool3o`0000Cooooo
0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0;oooool00ol9jP[o0000
ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0?ooooo`00:oooool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0003ooooo00Sooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[
ooooo`03o`000?oooooooooo02oooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool002_ooooo0_l0000`oooo
o`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo02oooooo00?o2NX:o`000?oo
ool02?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool03oooool002_ooooo00?o0000ooooooooool0;oooool00ol9jP[o0000ooooo`08ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:ooo
ool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooo
oooo02oooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool03oooool002_ooooo00?o0000ooooooooool0;oooool00ol9
jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0003ooooo00So
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oo
oooo000[ooooo`;o0000<?ooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003ooooooooo
o`0_ooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo02oooooo00?o2NX:
o`000?ooool02?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool03oooool002_ooooo00?o0000ooooooooool0;oooool00ol9jP[o0000ooooo`08oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?oooo
o`00:oooool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`00
0?oooooooooo02oooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool03oooool002_ooooo00?o0000ooooooooool0;ooo
ool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0?ooooo`00:oooool2o`00033ooooo00?o2NX:o`000?ooool02?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool0
02_ooooo00?o0000ooooooooool0;oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003o
ooooooooo`0_ooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo02oooooo
00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool03oooool002_ooooo00?o0000ooooooooool0;oooool00ol9jP[o0000oooo
o`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0?ooooo`00:oooool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[oooo
o`;o0000<?ooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0_ooooo`03
o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo02oooooo00?o2NX:o`000?ooool0
2?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
3oooool002_ooooo00?o0000ooooooooool0;oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool0
0ol0003oooooooooo`0_ooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000@ooooo`Go00000oooool2o`00
00Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0003ooooo
00Sooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00oooooo000Aooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
;oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0?ooooo`002_ooool5o`0000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool3o`0002oooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool001?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o2NX:o`000?ooool02?oo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03ooo
ool0013ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
02oooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool03oooool0013ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool0017ooooo0ol0
0004ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool03oooool002_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?
ooooo`00:oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`;o
0000<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03ooo
ool002_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool03oooool002_ooooo0_l0000aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo
000[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool002_ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool03oooool002_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`;o0000<Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00oooooo000[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool002_ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool03oooool002_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?oooo
o`00:oooool2o`00037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool002_ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00oooooo000[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool0
017ooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool03oooool001;ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000:ooooo`Go00000oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`?o0000<?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00
4_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool03oooool001;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo00oooooo000Aooooo`;o00001?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000Booooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo
000[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool002_ooooo0_l0000a
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool03oooool002_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00
:oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool03oooool002_ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00oooooo000[ooooo`;o0000<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool03oooool002_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?
ooooo`00:oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool002_ooooo0_l0000aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03ooo
ool002_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0
003oooooooooo`0[ooooo`?o00000_ooool01?l0003oooooo`000?l00006ooooo`03o`000?oooooo
oooo01gooooo0ol00004ooooo`;o00001?ooool2o`0002?ooooo0ol00003ooooo`?o00001?ooool2
o`0001?ooooo00?o0000ooooooooool03Oooool5o`0000?ooooo0_l00004ooooo`;o00004_ooool0
0ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0Zooooo`06o`000?oooooooooo
ooooool0003ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00008oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00017ooooo00?o0000oooooooo
ool03oooool002_ooooo00?o0000ooooooooool0;_ooool01?l0003oooooo`000?l00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Aooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo02kooooo
00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0002?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo000[ooooo`;o0000:oooool4o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00008oooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000
oooooooooooo00004_ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00017ooooo00?o0000oooo
ooooool03oooool002_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`;o
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo0_l00004ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008_ooool2o`0000?ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool0000Booooo`03o`000?oooooooooo00gooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00004Oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0Zooooo`Go
000000?oooooo`000?ooool00_l00006ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool00oooool2o`0000Cooooo0_l0000Tooooo`04o`000?ooooooooooooooo`Go00000oooool2o`00
01?ooooo00?o0000ooooooooool03_ooool3o`0000Cooooo0_l00004ooooo`;o00004_ooool00ol0
003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oo
oooo000[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03oooool002_ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool05ooooolHo`WZ2P03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1[ooooo`Ko2NX:00?o0000
o`WZ2_l9jPX05ol9jPXHooooo`03o`000?oooooooooo00oooooo000Vooooohoo00008Ol9jPXoo`00
00_ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oooolPo`WZ2P?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo000[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0:ooooob3o2NX:Aoooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo
000[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool00ol0003o2NX:o`WZ
2P0:o`WZ2VOooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`00:oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo
033ooooo00?o0000o`WZ2_l9jPX01ol9jPX00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool03oooool002_ooooo0_l0003cooooo`00:oooool00ol0003ooooo
ooooo`3booooo`00:oooool00ol0003oooooooooo`3booooo`00:oooool00ol0003oooooooooo`3b
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00EOooool4o`0000?ooooo0ol00003ooooo`Co000000Koooooo`000?oooooo0000ooooool0
0007ooooo`?o00000_ooool00ol0003oooooo`000003o`0000;ooooo1?l000000ooooooo0000o`00
0003o`0000?ooooo0_l000000ooooooo0000o`000003o`0000Wooooo0ol00002ooooo`Go00002Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Gooooo00?o0000ooooooooool00_oo
ool4o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00004ooooo`?o0000?Ooo
ool005Kooooo00Ko0000oooooooooooo0000ooooool00005ooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooool0003oooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0?_ooool005Kooooo00Go0000oooo
oooooooo0000ooooo`05o`0000;ooooo0ol00002ooooo`05o`000?oooooo0000ooooool000002?oo
ool00ol0003oooooo`000003ooooo`?o00000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool3o`0000Sooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool3
o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo1Ol0000looooo`00E_ooool3o`0000;ooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000;ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000Sooooo0ol00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00002oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l00004ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`05
o`000?ooooooooooooooool00000??ooool005Kooooo00Co0000oooooooooooo00000_ooool3o`00
00?ooooo0_l00003ooooo`;o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool00002
ooooo`;o00001?ooool3o`0000;ooooo0ol00003ooooo`;o000000?oooooo`000?l000000_ooool4
o`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`Co00001oooool00ol0003ooooooooo
o`03ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`000003
ooooool0003o000000;ooooo0_l00003ooooo`Co00000_ooool2o`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000000_ooool3o`0003gooooo001Fooooo`04o`000?ooooooooooo`00
01[ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0001[ooooo
00?o0000ooooooooool0Coooool005Gooooo1?l0000Jooooo`Co00002_ooool2o`0000Cooooo00?o
0000ooooooooool05?ooool3o`0000Gooooo0_l00009ooooo`?o00006_ooool00ol0003ooooooooo
o`1?ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-43.4048, -4598.23, \
0.992057, 30.0021}},
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
GaussianPlot[opticalsystemreflected, \
RenderedParameters->ComplexBeamParameter];\
\>", "Input",
  CellLabel->"In[31]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0042328 0.0441663 0.000139788 [
[.23545 .03167 -6 -9 ]
[.23545 .03167 6 0 ]
[.44709 .03167 -9 -9 ]
[.44709 .03167 9 0 ]
[.65873 .03167 -9 -9 ]
[.65873 .03167 9 0 ]
[.87037 .03167 -9 -9 ]
[.87037 .03167 9 0 ]
[.01131 .18395 -24 -4.5 ]
[.01131 .18395 0 4.5 ]
[.01131 .32374 -24 -4.5 ]
[.01131 .32374 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .60332 -24 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -83.0625 0 ]
[.5 .63053 83.0625 12 ]
[.23545 .66178 -5 -6 ]
[.23545 .66178 5 6 ]
[.27778 .66178 -5 -6 ]
[.27778 .66178 5 6 ]
[.76455 .66178 -5 -6 ]
[.76455 .66178 5 6 ]
[.97619 .66178 -5 -6 ]
[.97619 .66178 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23545 .04417 m
.23545 .05042 L
s
[(50)] .23545 .03167 0 1 Mshowa
.44709 .04417 m
.44709 .05042 L
s
[(100)] .44709 .03167 0 1 Mshowa
.65873 .04417 m
.65873 .05042 L
s
[(150)] .65873 .03167 0 1 Mshowa
.87037 .04417 m
.87037 .05042 L
s
[(200)] .87037 .03167 0 1 Mshowa
.125 Mabswid
.06614 .04417 m
.06614 .04792 L
s
.10847 .04417 m
.10847 .04792 L
s
.15079 .04417 m
.15079 .04792 L
s
.19312 .04417 m
.19312 .04792 L
s
.27778 .04417 m
.27778 .04792 L
s
.32011 .04417 m
.32011 .04792 L
s
.36243 .04417 m
.36243 .04792 L
s
.40476 .04417 m
.40476 .04792 L
s
.48942 .04417 m
.48942 .04792 L
s
.53175 .04417 m
.53175 .04792 L
s
.57407 .04417 m
.57407 .04792 L
s
.6164 .04417 m
.6164 .04792 L
s
.70106 .04417 m
.70106 .04792 L
s
.74339 .04417 m
.74339 .04792 L
s
.78571 .04417 m
.78571 .04792 L
s
.82804 .04417 m
.82804 .04792 L
s
.9127 .04417 m
.9127 .04792 L
s
.95503 .04417 m
.95503 .04792 L
s
.99735 .04417 m
.99735 .04792 L
s
.25 Mabswid
0 .04417 m
1 .04417 L
s
.02381 .18395 m
.03006 .18395 L
s
[(1000)] .01131 .18395 1 0 Mshowa
.02381 .32374 m
.03006 .32374 L
s
[(2000)] .01131 .32374 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(3000)] .01131 .46353 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(4000)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .07212 m
.02756 .07212 L
s
.02381 .10008 m
.02756 .10008 L
s
.02381 .12804 m
.02756 .12804 L
s
.02381 .156 m
.02756 .156 L
s
.02381 .21191 m
.02756 .21191 L
s
.02381 .23987 m
.02756 .23987 L
s
.02381 .26783 m
.02756 .26783 L
s
.02381 .29579 m
.02756 .29579 L
s
.02381 .3517 m
.02756 .3517 L
s
.02381 .37966 m
.02756 .37966 L
s
.02381 .40762 m
.02756 .40762 L
s
.02381 .43557 m
.02756 .43557 L
s
.02381 .49149 m
.02756 .49149 L
s
.02381 .51945 m
.02756 .51945 L
s
.02381 .5474 m
.02756 .5474 L
s
.02381 .57536 m
.02756 .57536 L
s
.02381 .01621 m
.02756 .01621 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -144.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Real) show
93.000 13.000 moveto
(Complex) show
141.000 13.000 moveto
(Beam) show
171.125 13.000 moveto
(Parameter) show
225.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .60332 m
.09004 .60113 L
.16227 .59875 L
.19739 .59759 L
.21452 .59702 L
.22263 .59675 L
.23011 .59651 L
.23206 .59644 L
.23388 .59638 L
.23578 .02237 L
.23788 .0223 L
.24631 .02202 L
.26163 .02151 L
.26598 .02137 L
.27011 .02123 L
.27383 .02111 L
.27593 .02104 L
.27788 .03074 L
.27897 .0307 L
.28016 .03066 L
.28231 .03059 L
.28633 .03046 L
.29535 .03016 L
.36564 .02784 L
.43333 .0256 L
.49843 .02346 L
.56773 .02117 L
.63443 .01896 L
.66839 .01784 L
.70533 .01662 L
.72254 .01605 L
.74081 .01545 L
.74832 .0152 L
.75642 .01494 L
.75867 .01486 L
.76105 .01478 L
.76308 .01472 L
.7653 .04679 L
.76739 .04672 L
.76962 .04665 L
.77364 .04652 L
.84478 .04417 L
.91332 .0419 L
.97619 .03983 L
s
0 0 0 r
gsave
.23545 .66178 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27778 .66178 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76455 .66178 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .66178 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 .02129 m
0 0 rlineto s
.23545 .02129 m
.23545 .61803 L
s
.27778 .02129 m
0 0 rlineto s
.27778 .02129 m
.27778 .61803 L
s
.76455 .02129 m
0 0 rlineto s
.76455 .02129 m
.76455 .61803 L
s
.97619 .02129 m
0 0 rlineto s
.97619 .02129 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[31]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o7oooool0
0ol0003oooooooooo`3nooooo`007oooool00ol0003oooooooooo`0_ooooo`?o00001?ooool2o`00
02[ooooo0ol00004ooooo`;o00001?ooool2o`0002Oooooo0ol00003ooooo`?o00001?ooool2o`00
02Oooooo1Ol00003ooooo`;o00001?ooool2o`00023ooooo000Oooooo`03o`000?oooooooooo02ko
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002[ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Oooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool09Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00007oooool001oooooo00?o0000ooooooooool0<_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001oooooo000Oooooo`03o`000?oo
oooooooo03;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Woooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`09
ooooo`Wo2NX:5Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0Mooooo`007oooool2o`0002oooooo1?l00003ooooo`04o`000?oo
ooooooooo`0002[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`00023ooooo8Ol9jPX8ooooo`03o`WZ2_oooooooooo013ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
7oooool001oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`03ooooo`03o`000?l9
jP[o2NX:00Oo2NX:0_l0000Rooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`03o`00
0?l9jP[o2NX:027o2NX:1_ooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool0000Cooooo`03o`WZ2_l0003ooooo013ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004oooool00ol0003ooooooooo
o`09ooooo`007oooool00ol0003oooooooooo`0^ooooo`Go000000?oooooo`000?ooool00_l00006
ooooo`03o`000?oooooooooo01gooooo4Ol9jPX2o`0002Sooooo00Co0000oooooooooooooooo1Ol0
0003ooooo`;o00005?ooool00ol9jP[o0000ooooo`0Aooooo`?o00001?ooool2o`0000Cooooo0_l0
000Dooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool01oooool00ol0003o2NX:o`WZ2P0Mo`WZ2Ugooooo00?o2NX:o`000?ooool0=?ooool0
0ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo
00?o0000ooooooooool06_oooolIo`WZ2P03o`000?oooooooooo00Wooooo000IooooolKo00007?l9
jPXPo`0000Gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
01oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`09ooooo`007oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Ooooo
o`;o0000=Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
2Oooool001oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`09ooooo`007oooool2o`0003Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool02Oooool001oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`00
7oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo0_l0000eooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oo
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09
ooooo`007oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo0_l0000eooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Ooo
ool001oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo0005ooooo`?o00001?ooool2o`0000Co
oooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wo
oooo0006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool3o`0003Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1koooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo0005
ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wo
oooo0006ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool02Oooool001oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09oooo
o`007oooool2o`0003Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool0
01oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool02Oooool001oooooo0_l0000eooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000O
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1k
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
2Oooool001oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`;o0000=Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wo
oooo000Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool02Oooool001oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`00
7oooool2o`0003Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00Wooooo000Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oo
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`001?ooool5o`0000?ooooo
0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0<oooool00ol9jP[o0000
ooooo`08ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`09ooooo`001Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo03?ooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0
Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo0007ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool3o`0003?ooooo00?o2NX:o`000?ooool02?ooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool000Co
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03?ooooo
00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool02Oooool000Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1k
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool000Gooooo0ol00004oooo
o`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`00
0?ooool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool02Oooool001oooooo00?o0000ooooooooool0<oooool00ol9jP[o0000ooooo`08ooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`00
7oooool00ol0003oooooooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0
Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oo
oooooooo03?ooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo0_l0000dooooo`03o`WZ2_l0003o
oooo00Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00Wooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`000?ooool02?ooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oo
oooo00?o0000ooooooooool0<oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo07_o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003ooooo
ooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o
2NX:o`000?ooool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0<oooool00ol9jP[o0000ooooo`08
ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09
ooooo`007oooool00ol0003oooooooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000oooo
ooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`;o
0000=?ooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo07_ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0cooooo`03o`WZ
2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`000?ooool02?oo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Ooo
ool001oooooo00?o0000ooooooooool0<oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooo
oooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0
003oooooooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03?o
oooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0<oooool00ol9jP[o0000
ooooo`08ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`09ooooo`007oooool2o`0003Cooooo00?o2NX:o`000?ooool02?ooool00ol0003ooooooooo
o`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo00?o0000
ooooooooool0<oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0coooo
o`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`000?oo
ool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool02Oooool001oooooo00?o0000ooooooooool0<oooool00ol9jP[o0000ooooo`08ooooo`03o`00
0?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007ooo
ool00ol0003oooooooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooo
oooo03?ooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool02Oooool001oooooo0_l0000dooooo`03o`WZ2_l0003ooooo
00Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Wooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`000?ooool02?ooool00ol0003o
ooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo
00?o0000ooooooooool0<oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo07_ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003ooooooooo
o`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o2NX:
o`000?ooool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool02Oooool000Gooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo03?ooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1koooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool000Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`000?ooool0
2?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
2Oooool000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0coooo
o`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00Wooooo0006ooooo`;o00000oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool3o`0003?ooooo00?o
2NX:o`000?ooool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool02Oooool000Sooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00Wooooo0004ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o
0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo0005
ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0c
ooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`00
0?ooool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool02Oooool001oooooo00?o0000ooooooooool0<oooool00ol9jP[o0000ooooo`08ooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`00
7oooool00ol0003oooooooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0
Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`;o0000=?oo
ool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0cooooo`03o`WZ2_l0003o
oooo00Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00Wooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`000?ooool02?ooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oo
oooo00?o0000ooooooooool0<oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo07_o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003ooooo
ooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o
2NX:o`000?ooool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0<oooool00ol9jP[o0000ooooo`08
ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09
ooooo`007oooool2o`0003Cooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1koooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo00?o0000oooooooo
ool0<oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo07_ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0cooooo`03o`WZ
2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`000?ooool02?oo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Ooo
ool001oooooo00?o0000ooooooooool0<oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooo
oooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0
003oooooooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03?o
oooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool02Oooool001oooooo0_l0000dooooo`03o`WZ2_l0003ooooo00Sooooo
00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo
000Oooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`000?ooool02?ooool00ol0003ooooooooo
o`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo00?o0000
ooooooooool0<oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0coooo
o`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`000?oo
ool02?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool02Oooool001oooooo00?o0000ooooooooool0<oooool00ol9jP[o0000ooooo`08ooooo`03o`00
0?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007ooo
ool00ol0003oooooooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Oooooo`;o0000=?ooool0
0ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0cooooo`03o`WZ2_l0003ooooo
00Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Wooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o2NX:o`000?ooool02?ooool00ol0003o
ooooooooo`1kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001oooooo
00?o0000ooooooooool0<oooool00ol9jP[o0000ooooo`08ooooo`03o`000?oooooooooo07_ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`007oooool00ol0003ooooooooo
o`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Wooooo0006ooooo`?o00000oooool2o`0000Cooooo0_l00004
ooooo`;o00001Oooool00ol0003oooooooooo`0cooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo0007oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hoooooaco2NX:
00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool02Oooool000Cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooooa_o2NX:7?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`09ooooo`001?ooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool02Oooool000Gooooo00?o0000ooooool000000ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo0006ooooo`;o
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo0007
ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`09ooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00N?ooool3o`000:Gooooo001iooooo`03o`000?oooooooooo
0:Cooooo0018ooooo`?o00000_ooool00ol0003oooooo`000002o`0000?ooooo1?l000000ooooooo
0000o`000003o`0000Wooooo0_l00003ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo0000
00;ooooo0ol00002ooooo`Go00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000007oooo
o`Co00000oooool3o`0000?ooooo1?l000001_oooooo0000ooooool0003oooooo`0000Sooooo0ol0
0004ooooo`Co000000Coooooo`000?l0003o00001?ooool4o`000006ooooool0003oooooo`000?oo
oooo00000_ooool3o`0000Cooooo0_l00003ooooo`?o00000_ooool3o`0003Sooooo0019ooooo`06
o`000?ooooooooooo`000?oooooo00001Oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooo000000Wooooo00Ko0000oooooooooooo0000ooooool00005oooo
o`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000009ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000Kooooo00Ko0000
oooooooooooo0000ooooool00006ooooo`03o`000?oooooooooo03Oooooo0019ooooo`03o`000?oo
oooo000000;ooooo2_l00004ooooo`Ko00001?ooool00ol0003oooooooooo`03ooooo`0;o`000?oo
ooooooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooooooo`Go00000oooool00ol0003oooooooooo`08ooooo`05o`00
0?ooooooooooo`000?ooool01Ol00002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo0000
00Wooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool3o`00
00;ooooo00Ko0000ooooool0003oooooo`000?ooool5o`0000;ooooo0ol000000ooooooo0000o`00
0004o`0000;ooooo00?o0000ooooooooool0:Oooool3o`0000_ooooo0019ooooo`?o00000_ooool0
1ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`0;o`00
0?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooooooool0003ooooo
o`0000Wooooo0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`08o`00
0?ooooooooooo`000?oooooo0000ooooool00009ooooo`?o00000_ooool01?l0003oooooooooool0
0003ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`07o`000?oooooo0000ooooool0
003oooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooooooo
000000;ooooo0_l0000Zooooo`04o`000?ooooooooooo`0000[ooooo0019ooooo`04o`000?oooooo
ooooo`0000;ooooo0ol00002ooooo`?o00001Oooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo00Cooooo0ol00002ooooo`;o000000Coooooo`000?oooooooooo1?l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00002ooooo`;o000000?oooooo`000?l000002?ooool01?l0003ooooo
ooooool00002ooooo`?o00000oooool2o`0000?ooooo0_l000000ooooooo0000ooooo`09ooooo`04
o`000?ooooooooooo`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00?ooooo0_l000000ooooooo0000ooooo`02ooooo`?o00000_ooool4o`0000;ooooo1?l00002oooo
o`;o000000?oooooo`000?l00000:oooool00ol0003oooooooooo`08ooooo`00BOooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000002?ooool01?l0
003oooooooooool0000Eooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00006ooo
ool01?l0003oooooooooool0000Pooooo`;o00000oooool00ol0003oooooooooo`0aooooo`;o0000
2oooool004Sooooo1?l00008ooooo`03o`000?oooooooooo00?ooooo0ol000000ooooooo0000oooo
o`08ooooo`?o00004oooool3o`0001Gooooo1?l0000Kooooo`Co00008Oooool2o`000004ooooool0
003oooooo`0003;ooooo00?o0000ooooooooool02oooool005Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1jooooo`;o000000?oooooo`000?l00000<_ooool01?l0003ooooooooo
ool0000:ooooo`00Doooool3o`0000Oooooo0ol0001kooooo`04o`000?ooooooooooooooo`;o0000
<_ooool3o`0000[ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.1112, -339.939, \
0.919275, 27.8358}},
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0042328 0.014337 0.0869756 [
[.23545 .00184 -6 -9 ]
[.23545 .00184 6 0 ]
[.44709 .00184 -9 -9 ]
[.44709 .00184 9 0 ]
[.65873 .00184 -9 -9 ]
[.65873 .00184 9 0 ]
[.87037 .00184 -9 -9 ]
[.87037 .00184 9 0 ]
[.01131 .10131 -6 -4.5 ]
[.01131 .10131 0 4.5 ]
[.01131 .18829 -6 -4.5 ]
[.01131 .18829 0 4.5 ]
[.01131 .27526 -6 -4.5 ]
[.01131 .27526 0 4.5 ]
[.01131 .36224 -6 -4.5 ]
[.01131 .36224 0 4.5 ]
[.01131 .44921 -6 -4.5 ]
[.01131 .44921 0 4.5 ]
[.01131 .53619 -6 -4.5 ]
[.01131 .53619 0 4.5 ]
[.5 .63053 -98.0625 0 ]
[.5 .63053 98.0625 12 ]
[.23545 .66369 -5 -6 ]
[.23545 .66369 5 6 ]
[.27778 .66369 -5 -6 ]
[.27778 .66369 5 6 ]
[.76455 .66369 -5 -6 ]
[.76455 .66369 5 6 ]
[.97619 .66369 -5 -6 ]
[.97619 .66369 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23545 .01434 m
.23545 .02059 L
s
[(50)] .23545 .00184 0 1 Mshowa
.44709 .01434 m
.44709 .02059 L
s
[(100)] .44709 .00184 0 1 Mshowa
.65873 .01434 m
.65873 .02059 L
s
[(150)] .65873 .00184 0 1 Mshowa
.87037 .01434 m
.87037 .02059 L
s
[(200)] .87037 .00184 0 1 Mshowa
.125 Mabswid
.06614 .01434 m
.06614 .01809 L
s
.10847 .01434 m
.10847 .01809 L
s
.15079 .01434 m
.15079 .01809 L
s
.19312 .01434 m
.19312 .01809 L
s
.27778 .01434 m
.27778 .01809 L
s
.32011 .01434 m
.32011 .01809 L
s
.36243 .01434 m
.36243 .01809 L
s
.40476 .01434 m
.40476 .01809 L
s
.48942 .01434 m
.48942 .01809 L
s
.53175 .01434 m
.53175 .01809 L
s
.57407 .01434 m
.57407 .01809 L
s
.6164 .01434 m
.6164 .01809 L
s
.70106 .01434 m
.70106 .01809 L
s
.74339 .01434 m
.74339 .01809 L
s
.78571 .01434 m
.78571 .01809 L
s
.82804 .01434 m
.82804 .01809 L
s
.9127 .01434 m
.9127 .01809 L
s
.95503 .01434 m
.95503 .01809 L
s
.99735 .01434 m
.99735 .01809 L
s
.25 Mabswid
0 .01434 m
1 .01434 L
s
.02381 .10131 m
.03006 .10131 L
s
[(1)] .01131 .10131 1 0 Mshowa
.02381 .18829 m
.03006 .18829 L
s
[(2)] .01131 .18829 1 0 Mshowa
.02381 .27526 m
.03006 .27526 L
s
[(3)] .01131 .27526 1 0 Mshowa
.02381 .36224 m
.03006 .36224 L
s
[(4)] .01131 .36224 1 0 Mshowa
.02381 .44921 m
.03006 .44921 L
s
[(5)] .01131 .44921 1 0 Mshowa
.02381 .53619 m
.03006 .53619 L
s
[(6)] .01131 .53619 1 0 Mshowa
.125 Mabswid
.02381 .03173 m
.02756 .03173 L
s
.02381 .04913 m
.02756 .04913 L
s
.02381 .06652 m
.02756 .06652 L
s
.02381 .08392 m
.02756 .08392 L
s
.02381 .11871 m
.02756 .11871 L
s
.02381 .1361 m
.02756 .1361 L
s
.02381 .1535 m
.02756 .1535 L
s
.02381 .17089 m
.02756 .17089 L
s
.02381 .20568 m
.02756 .20568 L
s
.02381 .22308 m
.02756 .22308 L
s
.02381 .24047 m
.02756 .24047 L
s
.02381 .25787 m
.02756 .25787 L
s
.02381 .29266 m
.02756 .29266 L
s
.02381 .31005 m
.02756 .31005 L
s
.02381 .32745 m
.02756 .32745 L
s
.02381 .34484 m
.02756 .34484 L
s
.02381 .37963 m
.02756 .37963 L
s
.02381 .39703 m
.02756 .39703 L
s
.02381 .41442 m
.02756 .41442 L
s
.02381 .43182 m
.02756 .43182 L
s
.02381 .46661 m
.02756 .46661 L
s
.02381 .484 m
.02756 .484 L
s
.02381 .5014 m
.02756 .5014 L
s
.02381 .5188 m
.02756 .5188 L
s
.02381 .55359 m
.02756 .55359 L
s
.02381 .57098 m
.02756 .57098 L
s
.02381 .58838 m
.02756 .58838 L
s
.02381 .60577 m
.02756 .60577 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -159.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Imaginary) show
123.000 13.000 moveto
(Complex) show
171.000 13.000 moveto
(Beam) show
201.125 13.000 moveto
(Parameter) show
255.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .60332 m
.09004 .60332 L
.16227 .60332 L
.19739 .60332 L
.21452 .60332 L
.22263 .60332 L
.23011 .60332 L
.23206 .60332 L
.23388 .60332 L
.23578 .01491 L
.23788 .01491 L
.24631 .01491 L
.26163 .01491 L
.26598 .01491 L
.27011 .01491 L
.27383 .01491 L
.27593 .01491 L
.27788 .01472 L
.27897 .01472 L
.28016 .01472 L
.28231 .01472 L
.28633 .01472 L
.29535 .01472 L
.36564 .01472 L
.43333 .01472 L
.49843 .01472 L
.56773 .01472 L
.63443 .01472 L
.66839 .01472 L
.70533 .01472 L
.72254 .01472 L
.74081 .01472 L
.74832 .01472 L
.75642 .01472 L
.75867 .01472 L
.76105 .01472 L
.76308 .01472 L
.7653 .01472 L
.76739 .01472 L
.76962 .01472 L
.77364 .01472 L
.84478 .01472 L
.91332 .01472 L
.97619 .01472 L
s
0 0 0 r
gsave
.23545 .66369 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27778 .66369 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76455 .66369 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .66369 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 .01434 m
0 0 rlineto s
.23545 .01434 m
.23545 .61803 L
s
.27778 .01434 m
0 0 rlineto s
.27778 .01434 m
.27778 .61803 L
s
.76455 .01434 m
0 0 rlineto s
.76455 .01434 m
.76455 .61803 L
s
.97619 .01434 m
0 0 rlineto s
.97619 .01434 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[31]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00Boooool3o`0000Cooooo0_l0000Xooooo`?o00001?ooool2o`0000Cooooo0_l0000Toooo
o`?o00000oooool3o`0000Cooooo0_l0000Tooooo`Go00000oooool2o`0000Cooooo0_l0000^oooo
o`00B_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
9?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000]ooooo`00C_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0002gooooo001>ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0[ooooo`00B_ooool4o`0000?ooooo00Co
0000oooooooooooo0000:?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009?ooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000
oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000]ooooo`00B_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0002Oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00008oooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool0000Sooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002gooooo001:ooooo`Go00000oooool2o`0002Wooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l0000Uooooo`04o`000?ooooooooooooooo`Go00000oooool2
o`0002Gooooo0ol00004ooooo`;o00001?ooool2o`0002kooooo000Looooo`03o`000?oooooooooo
0?oooooo0_ooool001cooooo00?o0000ooooooooool0ooooool2ooooo`007?ooool00ol0003ooooo
ooooo`3oooooo`;ooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool06?oo
ool001Kooooo>ol00009o`WZ2P03o`000?l9jP[o2NX:07Co2NX:00?o0000o`WZ2_l9jPX0<Ol9jPX7
o`0001Cooooo000Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool001co
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`;o0000<_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0Hooooo`007?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Loooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1doooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool2o`0003;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
6?ooool001cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool06?ooool001cooooo0_l0000booooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01So
oooo000Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool06?ooool001cooooo0_l0000booooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Dooooo`?o0000
1Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Eooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`005Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool0
01Gooooo00?o0000ooooooooool01?ooool3o`00037ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01So
oooo000Dooooo`;o00001_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo
000Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0Hooooo`007?ooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1d
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
6?ooool001cooooo0_l0000booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool06?ooool001cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Hooooo`007?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01So
oooo000Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo0_l0
000booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool06?ooool001cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hoooo
o`007?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`;o0000
<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Sooooo000Cooooo`Go00001?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo01Sooooo000Dooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Hooooo`005Oooool00ol0003oooooooooo`04ooooo`?o0000<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Hooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool06?ooool001?ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001Cooooo
0ol00005ooooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool06?ooool001cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hoooo
o`007?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`;o0000
<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool0
01cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool2o`0003;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool06?ooool001cooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Hooooo`007?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000L
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1d
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo0_l0000boooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool06?ooool001Cooooo0ol00005ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
6?ooool001?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool06?ooool001Oooooo00?o0000ooooooooool00_ooool3o`00037ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool06?ooool001Gooooo0_l00005ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool06?ooool001Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo01Sooooo000Cooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Dooooo`?o00001Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`;o0000<_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Hooooo`007?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000L
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1d
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool2o`0003;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool06?ooool001cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool06?ooool001cooooo0_l0000booooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`;o0000<_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0H
ooooo`007?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Eooooo`?o
00001?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Fooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`004ooo
ool5o`0000Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`004oooool0
1?l0003oooooooooool00005ooooo`?o0000<Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`005?ooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool0
01Gooooo0_l00005ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01So
oooo000Looooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool06?ooool001cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hoooo
o`007?ooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool0
01cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool2o`0003;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool06?ooool001cooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Hooooo`007?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000L
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1d
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo0_l0000boooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool06?ooool001Cooooo0ol00005ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
6?ooool001?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool06?ooool001Oooooo00?o0000ooooooooool00_ooool3o`00037ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool06?ooool001Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo01Sooooo000Cooooo`Co00001Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo01Sooooo000Cooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Hooooo`004oooool5o`0000Cooooo0_l0000booooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?oo
ool001cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool06?ooool001cooooo0_l0000booooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo
000Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo01Sooooo000Looooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`00
7?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Hooooo`007?ooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001co
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`005?ooool3o`0000Gooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`004oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`004ooo
ool01Ol0003ooooooooooooooooo000000Cooooo0ol0000aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo
000Cooooo`Co00001Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000C
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0H
ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool06?ooool001Gooooo0_l00005ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool06?ooool001cooooo0_l0000booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Hooooo`007?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01Sooooo000Looooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool06?ooool001cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0H
ooooo`007?ooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1doooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool001cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?oo
ool001cooooo=?l9jPX00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`007?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool06?ooool001cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00A?ooool3o`0001[ooooo
0ol0000Kooooo`?o0000W_ooool004Oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo09gooooo000aooooo`Go000000Koooooo`000?oooooo0000oooo
ool00002ooooo`Co00000_ooool4o`000003ooooool0003o000000?o000000Goooooo`000?l0003o
0000ooooo`02o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00001Oooool00ol0
003oooooooooo`09ooooo`;o00000oooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002
ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000001oooool4
o`0000?ooooo0ol00003ooooo`Co000000Koooooo`000?oooooo0000ooooool00007ooooo`?o0000
1?ooool4o`000004ooooool0003o0000o`0000Cooooo1?l000001_oooooo0000ooooool0003ooooo
o`0000;ooooo0ol00004ooooo`;o00000oooool3o`0000;ooooo0ol0000booooo`00<oooool02ol0
003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`08ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooo`000009ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool01?l0003ooooooooo
ool00002ooooo`05o`000?oooooo0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`07o`000?oooooo0000ooooool0003oooooo`000006ooooo`06o`000?ooooooooooo`000?oo
oooo00001_ooool00ol0003oooooooooo`0aooooo`00<oooool02Ol0003ooooooooooooooooo0000
ooooool0003oooooo`000002ooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooool000001?l000001?oooooo0000ooooooooool7o`0000Gooooo00?o0000ooooool0
00002?ooool00ol0003oooooooooo`03ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oo
oooo0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooooooo
o`Go00000oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooo`000?ooool01Ol00002
ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000Sooooo00?o0000ooooooooool00ooo
ool3o`0000?ooooo00?o0000ooooooooool00oooool6o`000005ooooool0003oooooo`000?ooool0
1Ol00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`03o`000?oooooooooo01Cooooo
0ol0000Jooooo`00<oooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo
00So0000ooooool0003o0000ooooool0003oooooo`0000;ooooo00?o0000ooooooooool00ol00004
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool02ol0003ooooooooooooo
oooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Ko0000oooooooooooo0000ooooool00009ooooo`?o
00000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool02?l0003oooooooooool0
003oooooo`000?oooooo00002?ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool2o`00
00?ooooo0_l000000ooooooo0000ooooo`02o`000006ooooool0003oooooo`000?oooooo00000ooo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000000_ooool2o`0001Go
oooo00Co0000oooooooooooo00006Oooool003?ooooo00Co0000oooooooooooooooo0_l000000ooo
oooo0000ooooo`02ooooo`;o00001?ooool8o`0000;ooooo1Ol00003ooooo`?o00000_ooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001oooool00ol0003oooooooooo`04
ooooo`?o00000_ooool2o`000004ooooool0003oooooooooo`Co00001?ooool00ol0003ooooooooo
o`02ooooo`?o00000_ooool2o`000003ooooool0003o000000Sooooo00Co0000oooooooooooo0000
0_ooool3o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?ooool02?ooool01?l0003ooooo
ooooool00002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`?o
000000?oooooo`000?ooool00_ooool3o`0000;ooooo1?l00003ooooo`?o00000_ooool2o`000003
ooooool0003o000001Kooooo00?o0000ooooooooool05oooool003?ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo
00005Oooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`0001[ooooo00Co0000oooo
oooooooo00003_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool08Ooo
ool2o`0001[ooooo000aooooo`Go00005Oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo01Cooooo0ol0000Cooooo`?o00005Oooool4o`0001[ooooo1?l0000?ooooo`05o`000?oo
oooo0000ooooool000003Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01[ooooo
001>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Loooool2o`000003ooooool0
003o0000033ooooo00Co0000oooooooooooo00006Oooool004gooooo0ol00007ooooo`?o0000M?oo
ool01?l0003oooooooooooooool2o`00033ooooo0ol0000Iooooo`00oooooolQooooo`00oooooolQ
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-27.6215, -0.566645, \
0.965581, 0.0469915}},
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
finalresultreflected = 
\tGaussianPlot[opticalsystemreflected, Plot3D->True, PlotType->TopView]\
\>", "Input",
  CellLabel->"In[32]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0241938 0.00504743 0.184324 0.00837989 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.02419 .35192 m
.03934 .35205 L
.05448 .35217 L
.06962 .3523 L
.08476 .35242 L
.09991 .35255 L
.11505 .35268 L
.13019 .3528 L
.14533 .35293 L
.16047 .35305 L
.17562 .35318 L
.19076 .3533 L
.2059 .35343 L
.22104 .35356 L
.23619 .35368 L
.25133 .35381 L
.26647 .35393 L
.28161 .35293 L
.29675 .34966 L
.3119 .3464 L
.32704 .34313 L
.34218 .33817 L
.35732 .33321 L
.37247 .32825 L
.38761 .32329 L
.40275 .31833 L
.41789 .31336 L
.43304 .3084 L
.44818 .30344 L
.46332 .29848 L
.47846 .29352 L
.4936 .28856 L
.50875 .2836 L
.52389 .27864 L
.53903 .27368 L
.55417 .26871 L
.56932 .26375 L
.58446 .25879 L
.5996 .25383 L
.61474 .24887 L
.62989 .24391 L
.64503 .23895 L
.66017 .23399 L
.67531 .22903 L
.69045 .22406 L
.7056 .2191 L
.72074 .21414 L
.73588 .20918 L
.75102 .20422 L
.76617 .19926 L
Mistroke
.78131 .1943 L
.79645 .18934 L
.81159 .18438 L
.82673 .18923 L
.84188 .19419 L
.85702 .19916 L
.87216 .20412 L
.8873 .20908 L
.90245 .21404 L
.88661 .20108 L
.88362 .22622 L
.88063 .25136 L
.87764 .2765 L
.87466 .30164 L
.87167 .32678 L
.86868 .35192 L
.86569 .37706 L
.8627 .4022 L
.85971 .42734 L
.85673 .45248 L
.85374 .47762 L
.85075 .50276 L
.84776 .5279 L
.84477 .55304 L
.84178 .57818 L
.8388 .60332 L
Mfstroke
.02419 .01673 m
.03934 .0166 L
.05448 .01647 L
.06962 .01635 L
.08476 .01622 L
.09991 .0161 L
.11505 .01597 L
.13019 .01585 L
.14533 .01572 L
.16047 .01559 L
.17562 .01547 L
.19076 .01534 L
.2059 .01522 L
.22104 .01509 L
.23619 .01497 L
.25133 .01484 L
.26647 .01472 L
.28161 .01572 L
.29675 .01899 L
.3119 .02225 L
.32704 .02552 L
.34218 .03048 L
.35732 .03544 L
.37247 .0404 L
.38761 .04536 L
.40275 .05032 L
.41789 .05528 L
.43304 .06025 L
.44818 .06521 L
.46332 .07017 L
.47846 .07513 L
.4936 .08009 L
.50875 .08505 L
.52389 .09001 L
.53903 .09497 L
.55417 .09993 L
.56932 .10489 L
.58446 .10986 L
.5996 .11482 L
.61474 .11978 L
.62989 .12474 L
.64503 .1297 L
.66017 .13466 L
.67531 .13962 L
.69045 .14458 L
.7056 .14954 L
.72074 .15451 L
.73588 .15947 L
.75102 .16443 L
.76617 .16939 L
Mistroke
.78131 .17435 L
.79645 .17931 L
.81159 .18427 L
.82673 .17942 L
.84188 .17445 L
.85702 .16949 L
.87216 .16453 L
.8873 .15957 L
.90245 .15461 L
.92838 .20108 L
.93137 .22622 L
.93436 .25136 L
.93734 .2765 L
.94033 .30164 L
.94332 .32678 L
.94631 .35192 L
.9493 .37706 L
.95228 .4022 L
.95527 .42734 L
.95826 .45248 L
.96125 .47762 L
.96424 .50276 L
.96723 .5279 L
.97021 .55304 L
.9732 .57818 L
.97619 .60332 L
Mfstroke
0 0 0 r
.02419 .18432 m
.27657 .18432 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
.27657 .18432 m
.32704 .18432 L
s
% Start of user PostScript
50. 0 60. 0 MAarrowhead1
% End of user PostScript
.32704 .18432 m
.90749 .18432 L
s
% Start of user PostScript
60. 0 175. 0 MAarrowhead1
% End of user PostScript
.90749 .18432 m
.90749 .60332 L
s
% Start of user PostScript
175. 0 175. 50. MAarrowhead1
% End of user PostScript
.90749 .60332 m
.90749 .60332 L
s
% Start of user PostScript
175. 50. MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .03349 m
.02386 .04354 L
.02391 .0536 L
.02395 .06365 L
.02399 .07371 L
.02402 .08377 L
.02406 .09382 L
.02408 .10388 L
.02411 .11393 L
.02413 .12399 L
.02415 .13404 L
.02417 .1441 L
.02418 .15416 L
.02419 .16421 L
.02419 .17427 L
.02419 .18432 L
.02419 .19438 L
.02419 .20444 L
.02418 .21449 L
.02417 .22455 L
.02415 .2346 L
.02413 .24466 L
.02411 .25472 L
.02408 .26477 L
.02406 .27483 L
.02402 .28488 L
.02399 .29494 L
.02395 .30499 L
.02391 .31505 L
.02386 .32511 L
.02381 .33516 L
s
.04652 .03332 m
.04657 .04338 L
.04662 .05345 L
.04666 .06352 L
.0467 .07359 L
.04674 .08365 L
.04677 .09372 L
.0468 .10379 L
.04682 .11385 L
.04685 .12392 L
.04686 .13399 L
.04688 .14406 L
.04689 .15412 L
.0469 .16419 L
.04691 .17426 L
.04691 .18432 L
.04691 .19439 L
.0469 .20446 L
.04689 .21453 L
.04688 .22459 L
.04686 .23466 L
.04685 .24473 L
.04682 .25479 L
.0468 .26486 L
.04677 .27493 L
.04674 .285 L
.0467 .29506 L
.04666 .30513 L
.04662 .3152 L
.04657 .32526 L
.04652 .33533 L
s
.06924 .03315 m
.06929 .04323 L
.06933 .0533 L
.06937 .06338 L
.06941 .07346 L
.06945 .08354 L
.06948 .09362 L
.06951 .1037 L
.06954 .11377 L
.06956 .12385 L
.06958 .13393 L
.06959 .14401 L
.06961 .15409 L
.06961 .16417 L
.06962 .17425 L
.06962 .18432 L
.06962 .1944 L
.06961 .20448 L
.06961 .21456 L
.06959 .22464 L
.06958 .23472 L
.06956 .2448 L
.06954 .25487 L
.06951 .26495 L
.06948 .27503 L
.06945 .28511 L
.06941 .29519 L
.06937 .30527 L
.06933 .31534 L
.06929 .32542 L
.06924 .3355 L
s
.09195 .03298 m
.092 .04307 L
.09204 .05316 L
.09209 .06325 L
.09213 .07334 L
.09216 .08343 L
.0922 .09352 L
.09222 .10361 L
.09225 .1137 L
.09227 .12379 L
.09229 .13388 L
.09231 .14396 L
.09232 .15405 L
.09233 .16414 L
.09233 .17423 L
.09233 .18432 L
.09233 .19441 L
.09233 .2045 L
.09232 .21459 L
.09231 .22468 L
.09229 .23477 L
.09227 .24486 L
.09225 .25495 L
.09222 .26504 L
.0922 .27513 L
.09216 .28522 L
.09213 .29531 L
.09209 .3054 L
.09204 .31549 L
.092 .32558 L
.09195 .33567 L
s
.11466 .03281 m
.11471 .04291 L
.11476 .05301 L
.1148 .06311 L
.11484 .07321 L
.11488 .08331 L
.11491 .09341 L
.11494 .10352 L
.11496 .11362 L
.11499 .12372 L
.115 .13382 L
.11502 .14392 L
.11503 .15402 L
.11504 .16412 L
.11505 .17422 L
.11505 .18432 L
.11505 .19443 L
.11504 .20453 L
.11503 .21463 L
.11502 .22473 L
.115 .23483 L
.11499 .24493 L
.11496 .25503 L
.11494 .26513 L
.11491 .27523 L
.11488 .28534 L
.11484 .29544 L
.1148 .30554 L
.11476 .31564 L
.11471 .32574 L
.11466 .33584 L
s
.13737 .03264 m
.13742 .04275 L
.13747 .05286 L
.13751 .06297 L
.13755 .07309 L
.13759 .0832 L
.13762 .09331 L
.13765 .10342 L
.13768 .11354 L
.1377 .12365 L
.13772 .13376 L
.13773 .14387 L
.13775 .15399 L
.13775 .1641 L
.13776 .17421 L
.13776 .18432 L
.13776 .19444 L
.13775 .20455 L
.13775 .21466 L
.13773 .22477 L
.13772 .23489 L
.1377 .245 L
.13768 .25511 L
.13765 .26522 L
.13762 .27534 L
.13759 .28545 L
.13755 .29556 L
.13751 .30567 L
.13747 .31579 L
.13742 .3259 L
.13737 .33601 L
s
.16009 .03247 m
.16014 .04259 L
.16018 .05272 L
.16023 .06284 L
.16027 .07296 L
.1603 .08309 L
.16034 .09321 L
.16036 .10333 L
.16039 .11346 L
.16041 .12358 L
.16043 .13371 L
.16045 .14383 L
.16046 .15395 L
.16047 .16408 L
.16047 .1742 L
.16047 .18432 L
.16047 .19445 L
.16047 .20457 L
.16046 .2147 L
.16045 .22482 L
.16043 .23494 L
.16041 .24507 L
.16039 .25519 L
.16036 .26531 L
.16034 .27544 L
.1603 .28556 L
.16027 .29569 L
.16023 .30581 L
.16018 .31593 L
.16014 .32606 L
.16009 .33618 L
s
.1828 .0323 m
.18285 .04243 L
.1829 .05257 L
.18294 .0627 L
.18298 .07284 L
.18302 .08297 L
.18305 .09311 L
.18308 .10324 L
.1831 .11338 L
.18313 .12351 L
.18314 .13365 L
.18316 .14378 L
.18317 .15392 L
.18318 .16405 L
.18319 .17419 L
.18319 .18432 L
.18319 .19446 L
.18318 .20459 L
.18317 .21473 L
.18316 .22486 L
.18314 .235 L
.18313 .24513 L
.1831 .25527 L
.18308 .2654 L
.18305 .27554 L
.18302 .28567 L
.18298 .29581 L
.18294 .30594 L
.1829 .31608 L
.18285 .32622 L
.1828 .33635 L
s
.20551 .03213 m
.20556 .04227 L
.20561 .05242 L
.20565 .06257 L
.20569 .07271 L
.20573 .08286 L
.20576 .09301 L
.20579 .10315 L
.20582 .1133 L
.20584 .12345 L
.20586 .13359 L
.20587 .14374 L
.20589 .15389 L
.20589 .16403 L
.2059 .17418 L
.2059 .18432 L
.2059 .19447 L
.20589 .20462 L
.20589 .21476 L
.20587 .22491 L
.20586 .23506 L
.20584 .2452 L
.20582 .25535 L
.20579 .2655 L
.20576 .27564 L
.20573 .28579 L
.20569 .29593 L
.20565 .30608 L
.20561 .31623 L
.20556 .32637 L
.20551 .33652 L
s
.22823 .03196 m
.22828 .04212 L
.22832 .05227 L
.22837 .06243 L
.22841 .07259 L
.22844 .08275 L
.22847 .0929 L
.2285 .10306 L
.22853 .11322 L
.22855 .12338 L
.22857 .13354 L
.22859 .14369 L
.2286 .15385 L
.22861 .16401 L
.22861 .17417 L
.22861 .18432 L
.22861 .19448 L
.22861 .20464 L
.2286 .2148 L
.22859 .22495 L
.22857 .23511 L
.22855 .24527 L
.22853 .25543 L
.2285 .26559 L
.22847 .27574 L
.22844 .2859 L
.22841 .29606 L
.22837 .30622 L
.22832 .31637 L
.22828 .32653 L
.22823 .33669 L
s
.25094 .03179 m
.25099 .04196 L
.25104 .05213 L
.25108 .0623 L
.25112 .07247 L
.25116 .08263 L
.25119 .0928 L
.25122 .10297 L
.25124 .11314 L
.25127 .12331 L
.25128 .13348 L
.2513 .14365 L
.25131 .15382 L
.25132 .16399 L
.25133 .17416 L
.25133 .18432 L
.25133 .19449 L
.25132 .20466 L
.25131 .21483 L
.2513 .225 L
.25128 .23517 L
.25127 .24534 L
.25124 .25551 L
.25122 .26568 L
.25119 .27585 L
.25116 .28601 L
.25112 .29618 L
.25108 .30635 L
.25104 .31652 L
.25099 .32669 L
.25094 .33686 L
s
.27365 .03162 m
.2737 .0418 L
.27375 .05198 L
.27379 .06216 L
.27383 .07234 L
.27387 .08252 L
.2739 .0927 L
.27393 .10288 L
.27396 .11306 L
.27398 .12324 L
.274 .13342 L
.27401 .1436 L
.27403 .15378 L
.27403 .16396 L
.27404 .17414 L
.27404 .18432 L
.27404 .1945 L
.27403 .20468 L
.27403 .21487 L
.27401 .22505 L
.274 .23523 L
.27398 .24541 L
.27396 .25559 L
.27393 .26577 L
.2739 .27595 L
.27387 .28613 L
.27383 .29631 L
.27379 .30649 L
.27375 .31667 L
.2737 .32685 L
.27365 .33703 L
s
.30324 .03552 m
.3024 .04544 L
.30162 .05536 L
.3009 .06528 L
.30024 .0752 L
.29964 .08512 L
.29909 .09504 L
.2986 .10496 L
.29817 .11488 L
.29779 .1248 L
.29748 .13472 L
.29722 .14464 L
.29701 .15456 L
.29687 .16448 L
.29678 .1744 L
.29675 .18432 L
.29678 .19424 L
.29687 .20416 L
.29701 .21409 L
.29722 .22401 L
.29748 .23393 L
.29779 .24385 L
.29817 .25377 L
.2986 .26369 L
.29909 .27361 L
.29964 .28353 L
.30024 .29345 L
.3009 .30337 L
.30162 .31329 L
.3024 .32321 L
.30324 .33313 L
s
.32576 .03993 m
.32495 .04955 L
.32419 .05918 L
.32349 .06881 L
.32285 .07843 L
.32226 .08806 L
.32173 .09769 L
.32126 .10731 L
.32084 .11694 L
.32047 .12657 L
.32017 .13619 L
.31992 .14582 L
.31972 .15545 L
.31958 .16507 L
.3195 .1747 L
.31947 .18432 L
.3195 .19395 L
.31958 .20358 L
.31972 .2132 L
.31992 .22283 L
.32017 .23246 L
.32047 .24208 L
.32084 .25171 L
.32126 .26134 L
.32173 .27096 L
.32226 .28059 L
.32285 .29021 L
.32349 .29984 L
.32419 .30947 L
.32495 .31909 L
.32576 .32872 L
s
.3561 .04586 m
.35431 .05509 L
.35264 .06432 L
.35109 .07356 L
.34967 .08279 L
.34837 .09202 L
.34719 .10125 L
.34614 .11048 L
.34521 .11971 L
.34441 .12894 L
.34373 .13817 L
.34317 .1474 L
.34274 .15663 L
.34243 .16586 L
.34224 .17509 L
.34218 .18432 L
.34224 .19355 L
.34243 .20279 L
.34274 .21202 L
.34317 .22125 L
.34373 .23048 L
.34441 .23971 L
.34521 .24894 L
.34614 .25817 L
.34719 .2674 L
.34837 .27663 L
.34967 .28586 L
.35109 .29509 L
.35264 .30432 L
.35431 .31355 L
.3561 .32279 L
s
.37814 .05256 m
.37643 .06134 L
.37484 .07013 L
.37337 .07891 L
.37202 .0877 L
.37078 .09648 L
.36966 .10527 L
.36866 .11405 L
.36778 .12283 L
.36701 .13162 L
.36637 .1404 L
.36584 .14919 L
.36542 .15797 L
.36513 .16676 L
.36495 .17554 L
.3649 .18432 L
.36495 .19311 L
.36513 .20189 L
.36542 .21068 L
.36584 .21946 L
.36637 .22825 L
.36701 .23703 L
.36778 .24581 L
.36866 .2546 L
.36966 .26338 L
.37078 .27217 L
.37202 .28095 L
.37337 .28973 L
.37484 .29852 L
.37643 .3073 L
.37814 .31609 L
s
.40018 .05926 m
.39856 .0676 L
.39705 .07593 L
.39565 .08427 L
.39437 .09261 L
.3932 .10095 L
.39213 .10928 L
.39118 .11762 L
.39035 .12596 L
.38962 .1343 L
.38901 .14264 L
.3885 .15097 L
.38811 .15931 L
.38783 .16765 L
.38766 .17599 L
.38761 .18432 L
.38766 .19266 L
.38783 .201 L
.38811 .20934 L
.3885 .21768 L
.38901 .22601 L
.38962 .23435 L
.39035 .24269 L
.39118 .25103 L
.39213 .25936 L
.3932 .2677 L
.39437 .27604 L
.39565 .28438 L
.39705 .29271 L
.39856 .30105 L
.40018 .30939 L
s
.42222 .06596 m
.42069 .07385 L
.41926 .08174 L
.41794 .08963 L
.41672 .09752 L
.41561 .10541 L
.41461 .1133 L
.41371 .12119 L
.41291 .12909 L
.41223 .13698 L
.41164 .14487 L
.41117 .15276 L
.4108 .16065 L
.41053 .16854 L
.41037 .17643 L
.41032 .18432 L
.41037 .19222 L
.41053 .20011 L
.4108 .208 L
.41117 .21589 L
.41164 .22378 L
.41223 .23167 L
.41291 .23956 L
.41371 .24745 L
.41461 .25535 L
.41561 .26324 L
.41672 .27113 L
.41794 .27902 L
.41926 .28691 L
.42069 .2948 L
.42222 .30269 L
s
.44426 .07265 m
.44281 .0801 L
.44147 .08754 L
.44022 .09499 L
.43907 .10243 L
.43802 .10988 L
.43708 .11732 L
.43623 .12477 L
.43548 .13221 L
.43483 .13966 L
.43428 .1471 L
.43383 .15455 L
.43348 .16199 L
.43323 .16943 L
.43309 .17688 L
.43304 .18432 L
.43309 .19177 L
.43323 .19921 L
.43348 .20666 L
.43383 .2141 L
.43428 .22155 L
.43483 .22899 L
.43548 .23644 L
.43623 .24388 L
.43708 .25133 L
.43802 .25877 L
.43907 .26622 L
.44022 .27366 L
.44147 .28111 L
.44281 .28855 L
.44426 .296 L
s
.4663 .07935 m
.46494 .08635 L
.46367 .09335 L
.4625 .10035 L
.46142 .10734 L
.46044 .11434 L
.45955 .12134 L
.45875 .12834 L
.45805 .13534 L
.45744 .14233 L
.45692 .14933 L
.4565 .15633 L
.45617 .16333 L
.45594 .17033 L
.4558 .17733 L
.45575 .18432 L
.4558 .19132 L
.45594 .19832 L
.45617 .20532 L
.4565 .21232 L
.45692 .21932 L
.45744 .22631 L
.45805 .23331 L
.45875 .24031 L
.45955 .24731 L
.46044 .25431 L
.46142 .2613 L
.4625 .2683 L
.46367 .2753 L
.46494 .2823 L
.4663 .2893 L
s
.48834 .08605 m
.48707 .0926 L
.48588 .09915 L
.48478 .1057 L
.48377 .11225 L
.48285 .11881 L
.48202 .12536 L
.48127 .13191 L
.48061 .13846 L
.48004 .14501 L
.47956 .15157 L
.47916 .15812 L
.47886 .16467 L
.47864 .17122 L
.47851 .17777 L
.47846 .18432 L
.47851 .19088 L
.47864 .19743 L
.47886 .20398 L
.47916 .21053 L
.47956 .21708 L
.48004 .22363 L
.48061 .23019 L
.48127 .23674 L
.48202 .24329 L
.48285 .24984 L
.48377 .25639 L
.48478 .26295 L
.48588 .2695 L
.48707 .27605 L
.48834 .2826 L
s
.51038 .09275 m
.50919 .09885 L
.50809 .10496 L
.50707 .11106 L
.50613 .11717 L
.50527 .12327 L
.50449 .12938 L
.50379 .13548 L
.50318 .14159 L
.50265 .14769 L
.5022 .1538 L
.50183 .1599 L
.50154 .16601 L
.50134 .17211 L
.50122 .17822 L
.50118 .18432 L
.50122 .19043 L
.50134 .19653 L
.50154 .20264 L
.50183 .20875 L
.5022 .21485 L
.50265 .22096 L
.50318 .22706 L
.50379 .23317 L
.50449 .23927 L
.50527 .24538 L
.50613 .25148 L
.50707 .25759 L
.50809 .26369 L
.50919 .2698 L
.51038 .2759 L
s
.53242 .09944 m
.53132 .1051 L
.5303 .11076 L
.52935 .11642 L
.52848 .12208 L
.52768 .12774 L
.52696 .1334 L
.52632 .13905 L
.52575 .14471 L
.52525 .15037 L
.52484 .15603 L
.5245 .16169 L
.52423 .16735 L
.52404 .17301 L
.52393 .17867 L
.52389 .18432 L
.52393 .18998 L
.52404 .19564 L
.52423 .2013 L
.5245 .20696 L
.52484 .21262 L
.52525 .21828 L
.52575 .22394 L
.52632 .22959 L
.52696 .23525 L
.52768 .24091 L
.52848 .24657 L
.52935 .25223 L
.5303 .25789 L
.53132 .26355 L
.53242 .26921 L
s
.55446 .10614 m
.55345 .11135 L
.55251 .11656 L
.55163 .12178 L
.55083 .12699 L
.5501 .1322 L
.54943 .13741 L
.54884 .14263 L
.54831 .14784 L
.54786 .15305 L
.54748 .15826 L
.54716 .16348 L
.54692 .16869 L
.54674 .1739 L
.54664 .17911 L
.5466 .18432 L
.54664 .18954 L
.54674 .19475 L
.54692 .19996 L
.54716 .20517 L
.54748 .21039 L
.54786 .2156 L
.54831 .22081 L
.54884 .22602 L
.54943 .23123 L
.5501 .23645 L
.55083 .24166 L
.55163 .24687 L
.55251 .25208 L
.55345 .2573 L
.55446 .26251 L
s
.5765 .11284 m
.57558 .1176 L
.57471 .12237 L
.57391 .12714 L
.57318 .1319 L
.57251 .13667 L
.5719 .14143 L
.57136 .1462 L
.57088 .15096 L
.57047 .15573 L
.57011 .1605 L
.56983 .16526 L
.5696 .17003 L
.56944 .17479 L
.56935 .17956 L
.56932 .18432 L
.56935 .18909 L
.56944 .19386 L
.5696 .19862 L
.56983 .20339 L
.57011 .20815 L
.57047 .21292 L
.57088 .21768 L
.57136 .22245 L
.5719 .22722 L
.57251 .23198 L
.57318 .23675 L
.57391 .24151 L
.57471 .24628 L
.57558 .25104 L
.5765 .25581 L
s
.59854 .11954 m
.5977 .12385 L
.59692 .12817 L
.5962 .13249 L
.59553 .13681 L
.59492 .14113 L
.59437 .14545 L
.59388 .14977 L
.59345 .15409 L
.59307 .15841 L
.59275 .16273 L
.59249 .16705 L
.59229 .17137 L
.59215 .17569 L
.59206 .18 L
.59203 .18432 L
.59206 .18864 L
.59215 .19296 L
.59229 .19728 L
.59249 .2016 L
.59275 .20592 L
.59307 .21024 L
.59345 .21456 L
.59388 .21888 L
.59437 .2232 L
.59492 .22752 L
.59553 .23184 L
.5962 .23616 L
.59692 .24047 L
.5977 .24479 L
.59854 .24911 L
s
.62058 .12623 m
.61983 .13011 L
.61913 .13398 L
.61848 .13785 L
.61788 .14172 L
.61734 .1456 L
.61684 .14947 L
.6164 .15334 L
.61601 .15721 L
.61568 .16109 L
.61539 .16496 L
.61516 .16883 L
.61498 .17271 L
.61485 .17658 L
.61477 .18045 L
.61474 .18432 L
.61477 .1882 L
.61485 .19207 L
.61498 .19594 L
.61516 .19982 L
.61539 .20369 L
.61568 .20756 L
.61601 .21143 L
.6164 .21531 L
.61684 .21918 L
.61734 .22305 L
.61788 .22692 L
.61848 .2308 L
.61913 .23467 L
.61983 .23854 L
.62058 .24242 L
s
.64262 .13293 m
.64196 .13636 L
.64134 .13978 L
.64076 .14321 L
.64023 .14664 L
.63975 .15006 L
.63932 .15349 L
.63893 .15691 L
.63858 .16034 L
.63828 .16377 L
.63803 .16719 L
.63782 .17062 L
.63766 .17405 L
.63755 .17747 L
.63748 .1809 L
.63746 .18432 L
.63748 .18775 L
.63755 .19118 L
.63766 .1946 L
.63782 .19803 L
.63803 .20146 L
.63828 .20488 L
.63858 .20831 L
.63893 .21173 L
.63932 .21516 L
.63975 .21859 L
.64023 .22201 L
.64076 .22544 L
.64134 .22887 L
.64196 .23229 L
.64262 .23572 L
s
.66466 .13963 m
.66408 .14261 L
.66354 .14559 L
.66304 .14857 L
.66259 .15155 L
.66217 .15453 L
.66179 .15751 L
.66145 .16049 L
.66115 .16347 L
.66089 .16645 L
.66067 .16943 L
.66049 .17241 L
.66035 .17538 L
.66025 .17836 L
.66019 .18134 L
.66017 .18432 L
.66019 .1873 L
.66025 .19028 L
.66035 .19326 L
.66049 .19624 L
.66067 .19922 L
.66089 .2022 L
.66115 .20518 L
.66145 .20816 L
.66179 .21114 L
.66217 .21412 L
.66259 .2171 L
.66304 .22008 L
.66354 .22306 L
.66408 .22604 L
.66466 .22902 L
s
.6867 .14632 m
.68621 .14886 L
.68575 .15139 L
.68533 .15392 L
.68494 .15646 L
.68458 .15899 L
.68426 .16152 L
.68397 .16406 L
.68371 .16659 L
.68349 .16912 L
.68331 .17166 L
.68315 .17419 L
.68304 .17672 L
.68295 .17926 L
.6829 .18179 L
.68288 .18432 L
.6829 .18686 L
.68295 .18939 L
.68304 .19192 L
.68315 .19446 L
.68331 .19699 L
.68349 .19952 L
.68371 .20206 L
.68397 .20459 L
.68426 .20712 L
.68458 .20966 L
.68494 .21219 L
.68533 .21472 L
.68575 .21726 L
.68621 .21979 L
.6867 .22232 L
s
.70874 .15302 m
.70834 .15511 L
.70796 .1572 L
.70761 .15928 L
.70729 .16137 L
.70699 .16346 L
.70673 .16554 L
.70649 .16763 L
.70628 .16972 L
.7061 .1718 L
.70595 .17389 L
.70582 .17598 L
.70572 .17806 L
.70565 .18015 L
.70561 .18224 L
.7056 .18432 L
.70561 .18641 L
.70565 .1885 L
.70572 .19058 L
.70582 .19267 L
.70595 .19476 L
.7061 .19684 L
.70628 .19893 L
.70649 .20102 L
.70673 .20311 L
.70699 .20519 L
.70729 .20728 L
.70761 .20937 L
.70796 .21145 L
.70834 .21354 L
.70874 .21563 L
s
.73078 .15972 m
.73046 .16136 L
.73017 .163 L
.72989 .16464 L
.72964 .16628 L
.72941 .16792 L
.7292 .16956 L
.72901 .1712 L
.72885 .17284 L
.72871 .17448 L
.72858 .17612 L
.72849 .17776 L
.72841 .1794 L
.72835 .18104 L
.72832 .18268 L
.72831 .18432 L
.72832 .18596 L
.72835 .1876 L
.72841 .18925 L
.72849 .19089 L
.72858 .19253 L
.72871 .19417 L
.72885 .19581 L
.72901 .19745 L
.7292 .19909 L
.72941 .20073 L
.72964 .20237 L
.72989 .20401 L
.73017 .20565 L
.73046 .20729 L
.73078 .20893 L
s
.75282 .16642 m
.75259 .16761 L
.75238 .1688 L
.75218 .17 L
.75199 .17119 L
.75182 .17239 L
.75167 .17358 L
.75154 .17477 L
.75142 .17597 L
.75131 .17716 L
.75122 .17836 L
.75115 .17955 L
.7511 .18074 L
.75106 .18194 L
.75103 .18313 L
.75102 .18432 L
.75103 .18552 L
.75106 .18671 L
.7511 .18791 L
.75115 .1891 L
.75122 .19029 L
.75131 .19149 L
.75142 .19268 L
.75154 .19387 L
.75167 .19507 L
.75182 .19626 L
.75199 .19746 L
.75218 .19865 L
.75238 .19984 L
.75259 .20104 L
.75282 .20223 L
s
.77486 .17311 m
.77472 .17386 L
.77458 .17461 L
.77446 .17536 L
.77434 .1761 L
.77424 .17685 L
.77414 .1776 L
.77406 .17835 L
.77398 .17909 L
.77392 .17984 L
.77386 .18059 L
.77382 .18133 L
.77378 .18208 L
.77376 .18283 L
.77374 .18358 L
.77374 .18432 L
.77374 .18507 L
.77376 .18582 L
.77378 .18657 L
.77382 .18731 L
.77386 .18806 L
.77392 .18881 L
.77398 .18956 L
.77406 .1903 L
.77414 .19105 L
.77424 .1918 L
.77434 .19254 L
.77446 .19329 L
.77458 .19404 L
.77472 .19479 L
.77486 .19553 L
s
.7969 .17981 m
.79685 .18011 L
.79679 .18041 L
.79674 .18071 L
.79669 .18102 L
.79665 .18132 L
.79661 .18162 L
.79658 .18192 L
.79655 .18222 L
.79652 .18252 L
.7965 .18282 L
.79648 .18312 L
.79647 .18342 L
.79646 .18372 L
.79645 .18402 L
.79645 .18432 L
.79645 .18462 L
.79646 .18493 L
.79647 .18523 L
.79648 .18553 L
.7965 .18583 L
.79652 .18613 L
.79655 .18643 L
.79658 .18673 L
.79661 .18703 L
.79665 .18733 L
.79669 .18763 L
.79674 .18793 L
.79679 .18823 L
.79685 .18854 L
.7969 .18884 L
s
.81894 .18214 m
.81897 .18228 L
.819 .18243 L
.81902 .18258 L
.81905 .18272 L
.81907 .18287 L
.81908 .18301 L
.8191 .18316 L
.81912 .1833 L
.81913 .18345 L
.81914 .1836 L
.81915 .18374 L
.81915 .18389 L
.81916 .18403 L
.81916 .18418 L
.81916 .18432 L
.81916 .18447 L
.81916 .18462 L
.81915 .18476 L
.81915 .18491 L
.81914 .18505 L
.81913 .1852 L
.81912 .18534 L
.8191 .18549 L
.81908 .18564 L
.81907 .18578 L
.81905 .18593 L
.81902 .18607 L
.819 .18622 L
.81897 .18636 L
.81894 .18651 L
s
.84098 .17544 m
.8411 .17603 L
.84121 .17663 L
.84131 .17722 L
.8414 .17781 L
.84148 .1784 L
.84156 .17899 L
.84162 .17959 L
.84168 .18018 L
.84173 .18077 L
.84178 .18136 L
.84181 .18196 L
.84184 .18255 L
.84186 .18314 L
.84187 .18373 L
.84188 .18432 L
.84187 .18492 L
.84186 .18551 L
.84184 .1861 L
.84181 .18669 L
.84178 .18729 L
.84173 .18788 L
.84168 .18847 L
.84162 .18906 L
.84156 .18965 L
.84148 .19025 L
.8414 .19084 L
.84131 .19143 L
.84121 .19202 L
.8411 .19261 L
.84098 .19321 L
s
.86302 .16874 m
.86323 .16978 L
.86341 .17082 L
.86359 .17186 L
.86375 .1729 L
.86389 .17394 L
.86403 .17498 L
.86415 .17601 L
.86425 .17705 L
.86434 .17809 L
.86442 .17913 L
.86448 .18017 L
.86453 .18121 L
.86456 .18225 L
.86458 .18329 L
.86459 .18432 L
.86458 .18536 L
.86456 .1864 L
.86453 .18744 L
.86448 .18848 L
.86442 .18952 L
.86434 .19056 L
.86425 .1916 L
.86415 .19263 L
.86403 .19367 L
.86389 .19471 L
.86375 .19575 L
.86359 .19679 L
.86341 .19783 L
.86323 .19887 L
.86302 .1999 L
s
.88506 .16205 m
.88535 .16353 L
.88562 .16502 L
.88587 .1665 L
.8861 .16799 L
.88631 .16947 L
.8865 .17096 L
.88667 .17244 L
.88682 .17393 L
.88695 .17541 L
.88706 .1769 L
.88714 .17838 L
.88721 .17987 L
.88726 .18135 L
.88729 .18284 L
.8873 .18432 L
.88729 .18581 L
.88726 .18729 L
.88721 .18878 L
.88714 .19026 L
.88706 .19175 L
.88695 .19324 L
.88682 .19472 L
.88667 .19621 L
.8865 .19769 L
.88631 .19918 L
.8861 .20066 L
.88587 .20215 L
.88562 .20363 L
.88535 .20512 L
.88506 .2066 L
s
.92495 .18368 m
.92378 .1843 L
.92262 .18488 L
.92146 .18542 L
.92029 .18591 L
.91913 .18637 L
.91797 .18677 L
.9168 .18714 L
.91564 .18746 L
.91447 .18774 L
.91331 .18798 L
.91215 .18817 L
.91098 .18832 L
.90982 .18843 L
.90866 .18849 L
.90749 .18851 L
.90633 .18849 L
.90517 .18843 L
.904 .18832 L
.90284 .18817 L
.90168 .18798 L
.90051 .18774 L
.89935 .18746 L
.89819 .18714 L
.89702 .18677 L
.89586 .18637 L
.8947 .18591 L
.89353 .18542 L
.89237 .18488 L
.8912 .1843 L
.89004 .18368 L
s
.92898 .22027 m
.92755 .22104 L
.92612 .22175 L
.92468 .22241 L
.92325 .22302 L
.92182 .22358 L
.92039 .22408 L
.91895 .22453 L
.91752 .22493 L
.91609 .22527 L
.91466 .22556 L
.91322 .2258 L
.91179 .22599 L
.91036 .22612 L
.90893 .2262 L
.90749 .22622 L
.90606 .2262 L
.90463 .22612 L
.9032 .22599 L
.90176 .2258 L
.90033 .22556 L
.8989 .22527 L
.89747 .22493 L
.89603 .22453 L
.8946 .22408 L
.89317 .22358 L
.89174 .22302 L
.8903 .22241 L
.88887 .22175 L
.88744 .22104 L
.88601 .22027 L
s
.93301 .25686 m
.93131 .25777 L
.92961 .25862 L
.92791 .25941 L
.92621 .26013 L
.92451 .26079 L
.92281 .26139 L
.9211 .26192 L
.9194 .26239 L
.9177 .2628 L
.916 .26315 L
.9143 .26343 L
.9126 .26365 L
.9109 .26381 L
.9092 .2639 L
.90749 .26393 L
.90579 .2639 L
.90409 .26381 L
.90239 .26365 L
.90069 .26343 L
.89899 .26315 L
.89729 .2628 L
.89558 .26239 L
.89388 .26192 L
.89218 .26139 L
.89048 .26079 L
.88878 .26013 L
.88708 .25941 L
.88538 .25862 L
.88367 .25777 L
.88197 .25686 L
s
.93705 .29345 m
.93508 .29451 L
.93311 .29549 L
.93114 .2964 L
.92917 .29724 L
.9272 .298 L
.92523 .29869 L
.92326 .29931 L
.92129 .29986 L
.91932 .30033 L
.91735 .30073 L
.91537 .30106 L
.9134 .30132 L
.91143 .3015 L
.90946 .30161 L
.90749 .30164 L
.90552 .30161 L
.90355 .3015 L
.90158 .30132 L
.89961 .30106 L
.89764 .30073 L
.89567 .30033 L
.8937 .29986 L
.89173 .29931 L
.88976 .29869 L
.88779 .298 L
.88582 .29724 L
.88385 .2964 L
.88188 .29549 L
.87991 .29451 L
.87794 .29345 L
s
.94108 .33005 m
.93884 .33125 L
.9366 .33236 L
.93436 .3334 L
.93213 .33435 L
.92989 .33522 L
.92765 .336 L
.92541 .33671 L
.92317 .33733 L
.92093 .33786 L
.91869 .33832 L
.91645 .33869 L
.91421 .33898 L
.91197 .33919 L
.90973 .33931 L
.90749 .33935 L
.90525 .33931 L
.90302 .33919 L
.90078 .33898 L
.89854 .33869 L
.8963 .33832 L
.89406 .33786 L
.89182 .33733 L
.88958 .33671 L
.88734 .336 L
.8851 .33522 L
.88286 .33435 L
.88062 .3334 L
.87838 .33236 L
.87614 .33125 L
.8739 .33005 L
s
.94512 .36664 m
.94261 .36798 L
.9401 .36923 L
.93759 .37039 L
.93508 .37146 L
.93258 .37243 L
.93007 .37331 L
.92756 .3741 L
.92505 .37479 L
.92254 .37539 L
.92003 .3759 L
.91753 .37632 L
.91502 .37664 L
.91251 .37688 L
.91 .37702 L
.90749 .37706 L
.90499 .37702 L
.90248 .37688 L
.89997 .37664 L
.89746 .37632 L
.89495 .3759 L
.89244 .37539 L
.88994 .37479 L
.88743 .3741 L
.88492 .37331 L
.88241 .37243 L
.8799 .37146 L
.8774 .37039 L
.87489 .36923 L
.87238 .36798 L
.86987 .36664 L
s
.94915 .40323 m
.94637 .40472 L
.9436 .4061 L
.94082 .40738 L
.93804 .40856 L
.93526 .40964 L
.93249 .41062 L
.92971 .41149 L
.92693 .41226 L
.92416 .41292 L
.92138 .41349 L
.9186 .41395 L
.91583 .41431 L
.91305 .41457 L
.91027 .41472 L
.90749 .41477 L
.90472 .41472 L
.90194 .41457 L
.89916 .41431 L
.89639 .41395 L
.89361 .41349 L
.89083 .41292 L
.88805 .41226 L
.88528 .41149 L
.8825 .41062 L
.87972 .40964 L
.87695 .40856 L
.87417 .40738 L
.87139 .4061 L
.86861 .40472 L
.86584 .40323 L
s
.95318 .43982 m
.95014 .44145 L
.94709 .44297 L
.94405 .44438 L
.941 .44567 L
.93795 .44685 L
.93491 .44792 L
.93186 .44888 L
.92882 .44972 L
.92577 .45046 L
.92272 .45107 L
.91968 .45158 L
.91663 .45197 L
.91359 .45226 L
.91054 .45242 L
.90749 .45248 L
.90445 .45242 L
.9014 .45226 L
.89836 .45197 L
.89531 .45158 L
.89226 .45107 L
.88922 .45046 L
.88617 .44972 L
.88313 .44888 L
.88008 .44792 L
.87703 .44685 L
.87399 .44567 L
.87094 .44438 L
.86789 .44297 L
.86485 .44145 L
.8618 .43982 L
s
.95722 .47641 m
.9539 .47819 L
.95059 .47984 L
.94727 .48137 L
.94396 .48278 L
.94064 .48407 L
.93733 .48523 L
.93401 .48627 L
.9307 .48719 L
.92738 .48799 L
.92407 .48866 L
.92075 .48921 L
.91744 .48964 L
.91412 .48995 L
.91081 .49013 L
.90749 .49019 L
.90418 .49013 L
.90086 .48995 L
.89755 .48964 L
.89423 .48921 L
.89092 .48866 L
.8876 .48799 L
.88429 .48719 L
.88097 .48627 L
.87766 .48523 L
.87434 .48407 L
.87103 .48278 L
.86771 .48137 L
.8644 .47984 L
.86108 .47819 L
.85777 .47641 L
s
.96125 .51301 m
.95767 .51493 L
.95408 .51671 L
.9505 .51837 L
.94692 .51989 L
.94333 .52128 L
.93975 .52254 L
.93617 .52366 L
.93258 .52466 L
.929 .52552 L
.92541 .52624 L
.92183 .52684 L
.91825 .5273 L
.91466 .52764 L
.91108 .52783 L
.90749 .5279 L
.90391 .52783 L
.90033 .52764 L
.89674 .5273 L
.89316 .52684 L
.88957 .52624 L
.88599 .52552 L
.88241 .52466 L
.87882 .52366 L
.87524 .52254 L
.87165 .52128 L
.86807 .51989 L
.86449 .51837 L
.8609 .51671 L
.85732 .51493 L
.85373 .51301 L
s
.96529 .5496 m
.96143 .55166 L
.95758 .55358 L
.95373 .55536 L
.94988 .557 L
.94602 .55849 L
.94217 .55985 L
.93832 .56105 L
.93446 .56212 L
.93061 .56305 L
.92676 .56383 L
.92291 .56447 L
.91905 .56497 L
.9152 .56532 L
.91135 .56554 L
.90749 .56561 L
.90364 .56554 L
.89979 .56532 L
.89594 .56497 L
.89208 .56447 L
.88823 .56383 L
.88438 .56305 L
.88052 .56212 L
.87667 .56105 L
.87282 .55985 L
.86896 .55849 L
.86511 .557 L
.86126 .55536 L
.85741 .55358 L
.85355 .55166 L
.8497 .5496 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`001ooooom=o`WZ2/cooooo001D
ooooo`Co2NX:b?ooool005Sooooo1?l9jP[4ooooo`00G?ooool5o`WZ2[oooooo001Qooooo`?o2NX:
_?ooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo01?ooooo0_l9jPZjooooo`001oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0<ooooo`?o2NX:]oooool0
00Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Kooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`09ooooo`?o2NX:]?ooool000Oo
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Go
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0<ooooo`?o2NX:/Oooool000Oooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo00Kooooo
0ol9jPZ^ooooo`001oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Kooooo00?o
2NX:ooooooooool02Oooool4o`WZ2Z[ooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:
ooooooooool01Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Oooooo0ol9jPZW
ooooo`001oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`0:ooooo`?o2NX:Y?ooool000Oooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`07ooooo`?o2NX:XOooool000Oooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo0ol9jPZNooooo`001ooo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Ooo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01_oo
ool3o`WZ2Y_ooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo0ol9jPZHooooo`001oooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Oooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`06ooooo`Co2NX:U?ooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`?o2NX:TOooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`07ooooo`?o2NX:S_ooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`05ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo0ol9jPZ;ooooo`001oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01_ooool3o`WZ2XSooooo0007oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo0_l9jPZ6ooooo`001oooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`05ooooo`Co
2NX:P_ooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`?o2NX:
Ooooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`06ooooo`;o2NX:OOoo
ool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`04o`WZ2_oooooo
ooooooooo`?o2NX:N_ooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Gooooo1Ol9jPYeooooo`001oooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`?o2NX:L_ooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01_ooool2o`WZ2W3ooooo0007ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool3o`WZ2Vgooooo0007ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01Oooool3o`WZ2V[ooooo0007ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool01?l9jP[oooooooooooooool3o`WZ2VOooooo0007
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`05
ooooo`?o2NX:I?ooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00Co2NX:oooooooooooooooo0ol9jPYQooooo`001oooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`04ooooo`;o2NX:Goooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`04o`WZ2U_ooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool5o`WZ2UOooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`?o2NX:E?ooool000Oooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo0ol9jPYBooooo`001oooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`04o`WZ2Rkooooo0ol9jPXMooooo`001oooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool2o`WZ2PGooooo1?l9jPXXooooo`?o
2NX:0_ooool00ol9jP[oooooooooo`0Kooooo`001oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`04o`WZ
2_ooooooooooooooo`;o2NX:9?ooool3o`WZ2PGooooo00?o2NX:ooooooooool06_ooool000Oooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`?o2NX:7_ooool3o`WZ2P;ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Iooooo`001oooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Ol9jPXEooooo`Co2NX:1_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo01Wooooo0007ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`Co2NX:4?ooool2
o`WZ2P?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo01Sooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o0000o`WZ2_l000001?ooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_l0003o000000?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`;o2NX:0oooool2o`WZ2P_ooooo0ol9jPX5ooooo`03o`WZ2_oooooooooo
00;ooooo0_l000000ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo01Sooooo0007ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:o`000?l000000ol000000ol9jP[oooooooooo`04ooooo`03
o`WZ2_l0003o000000?o000000?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo0ol9jPX4ooooo`Co2NX:0_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00?ooooo00?o0000o`WZ2_l000000ol00003ooooo`03o`WZ2_oooooooooo01Oo
oooo0007ooooo`03o`WZ2_l0003o000000?o000000?o2NX:o`000?l000001?l000000ol9jP[o0000
o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol000000ol9jP[o0000
o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000001?l000000ol9jP[o0000
o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol000000ol9jP[o0000
o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000001?l000000ol9jP[o0000
o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol000000ol9jP[o0000
o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000001?l000000ol9jP[o0000
o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol000000ol9jP[o0000
o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000001?l000000ol9jP[o0000
o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol000000ol9jP[o0000
o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000001?l000000ol9jP[o0000
o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol00002o`WZ2PGo0000
00?o2NX:o`000?l000000ol000000ol9jP[o0000o`000004o`0000;o2NX:1Ol00002ooooo`?o2NX:
5_ooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o0000o`000002o`000003ooooool9
jP[ooooo00Gooooo00?o2NX:o`000?l000000ol000000ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool3o`WZ2P?ooooo0ol9jPX4ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol0003o2NX:o`000004o`WZ2P03o`000?l9
jP[o2NX:00;o2NX:5oooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol0003o2NX:ooooo`04
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:o`000?ooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo0_l9jPX3ooooo`?o2NX:2?ooool3o`WZ2P03ooooool9jP[o
oooo00Cooooo00?o2NX:ooooooooool00_ooool2o`000003o`WZ2_oooooooooo00;ooooo0_l9jPX3
ooooo`03o`WZ2_oooooooooo01Gooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`04ooooo`Co2NX:3_ooool3o`WZ2PCooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`05o`000?ooooooooooooooool9jPX05oooool0
00Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00;ooooo0ol9jPXDooooo`;o2NX:0_ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol9jP[oooooooooo`0Dooooo`001oooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooool9jPX00_l9jPXIooooo`Co
2NX:1?ooool2o`WZ2PGooooo00?o0000ooooooooool00oooool00ol9jP[oooooooooo`0Cooooo`00
1oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`04o`WZ2_ooooooooooooooo`Co2NX:8?ooool7o`WZ2PCo
oooo00?o0000ooooooooool00oooool00ol9jP[oooooooooo`0Cooooo`001oooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`Co2NX::?ooool4o`WZ2P?ooooo00?o0000ooooooooool00oooool00ol9jP[ooooo
ooooo`0Cooooo`001oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool2o`WZ2P?ooooo0ol9jPX/ooooo`04o`WZ2_oooooo2NX:o`WZ2P;ooooo
00?o0000ooooooooool00oooool00ol9jP[oooooooooo`0Cooooo`001oooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool4o`WZ2Rkooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooo`000005ooooo`03o`WZ2_oooooooooo01?ooooo0007
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`?o2NX:<Oooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o2NX:
ooooooooool04oooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00;o2NX:=?ooool3o`WZ2PCooooo00Co0000oooooooooooooooo0ol9jPXE
ooooo`001oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo0ol9jPXfoooo
o`03o`WZ2_oooooooooo00Wo2NX:00?oooooo`WZ2_ooool05?ooool000Oooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooo`WZ2P03o`WZ2SWooooo00?o2NX:ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`WZ2_oooooooooo01?ooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
0_l9jPXmooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol9jP[ooooo
ooooo`0Cooooo`001oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03o`WZ2Soooooo00?o2NX:ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`WZ2_oooooooooo01?ooooo0007ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`Co2NX:@_ooool0
0ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o2NX:ooooooooool04oooool0
00Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`Go2NX:AOooool00ol9
jP[oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o2NX:ooooooooool04_ooool000Oo
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`;o2NX:BOooool00ol9jP[o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o2NX:ooooooooool04_ooool000Oooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03o`WZ2T_ooooo00?o2NX:ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`WZ2_oooooooooo01;ooooo0007ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo0ol9jPY>ooooo`03o`WZ2_oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol9jP[oooooooooo`0Booooo`001oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03o`WZ2U7ooooo0_l9jPX6
ooooo`03o`000?oooooooooo00?ooooo0_l9jPXDooooo`001oooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool3o`WZ2UCooooo1?l9jPX4oooo
o`04o`000?ooooooooooooooo`Co2NX:5?ooool000Oooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooo2NX:00?o2NX:Eoooool01?l9jP[oooooooooooooool9
o`WZ2P;ooooo00?o2NX:ooooooooool04_ooool000Oooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`?o2NX:F_ooool00ol9jP[oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o2NX:ooooooooool04Oooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`03o`WZ2Ugooooo00?o2NX:ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`WZ2_oooooooooo017ooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1Oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo0ol9jPYPooooo`03o`WZ
2_oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol9jP[oooooooooo`0Aooooo`001ooo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03o`WZ2V?ooooo00?o2NX:ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`WZ2_oooooooooo017ooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool01Oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:
ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:
ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`;o2NX:I_ooool00ol9jP[oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o2NX:ooooooooool04Oooool000Oooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01?ooool00ol9jP[oooooooooo`08ooooo`?o2NX:J?ooool00ol9jP[oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o2NX:ooooooooool04Oooool000Oooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`Co2NX:Joooool00ol9jP[oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o2NX:ooooooooool04Oooool000Oooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
2?ooool2o`WZ2Vkooooo00?o2NX:ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`WZ
2_oooooooooo013ooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Gooooo0ol9jPY`ooooo`Co2NX:1_oo
ool00ol0003oooooooooo`03ooooo`Co2NX:4_ooool000Oooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Sooooo1?l9jPYcooooo`03o`WZ2_oooooo
oooo00Co2NX:0oooool01?l0003oooooooooooooool3o`WZ2P;ooooo00?o2NX:ooooooooool04?oo
ool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Gooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo1?l9jPYgooooo`03o`WZ2_oooooooooo00?ooooo2?l9jPX5ooooo`03o`WZ2_oooooo
oooo013ooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01Oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool02?ooool2o`WZ
2W_ooooo00?o2NX:ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`WZ2_oooooooooo
013ooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01Oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Oooool3o`WZ2Wgo
oooo00?o2NX:ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`WZ2_oooooooooo013o
oooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`05ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01Oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00Oooooo1?l9jPZ0ooooo`03o`WZ2_oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol9jP[oooooooooo`0@ooooo`001oooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`05ooooo`;o2NX:Poooool00ol9jP[oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
2NX:ooooooooool03oooool000Oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`06
ooooo`03o`WZ2_oooooooooo00Sooooo0ol9jPZ5ooooo`03o`WZ2_oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol9jP[oooooooooo`0?ooooo`001oooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool01Oooool3o`WZ2XSooooo00?o2NX:oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`WZ2_oooooooooo00oooooo0007ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`05ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool02oooool3o`WZ2X_ooooo00?o2NX:oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`WZ2_oooooooooo00oooooo0007ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`06ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool02?ooool3o`WZ2Xkooooo0ol9jPX8ooooo`03o`00
0?oooooooooo00Kooooo0_l9jPXAooooo`001oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0:ooooo`Co2NX:TOoo
ool00ol9jP[oooooo`WZ2P02o`WZ2PKooooo00?o0000ooooooooool01?ooool2o`WZ2P03ooooool9
jP[ooooo013ooooo0007ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`0@ooooo`?o2NX:UOooool01?l9jP[oooooooooooooool4o`WZ2P?ooooo00?o
0000ooooooooool01?l9jPX3ooooo`03o`WZ2_oooooooooo00oooooo001Nooooo`?o2NX:V?ooool0
0ol9jP[oooooooooo`05ooooo`Ko2NX:2?ooool00ol9jP[oooooooooo`0>ooooo`00Foooool3o`WZ
2Y_ooooo00?o2NX:ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`WZ2_oooooooooo
00kooooo001Gooooo`Co2NX:W_ooool00ol9jP[oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o2NX:ooooooooool03_ooool000Oooooo6Ol9jPXcooooo`Co2NX:X_ooool00ol9jP[ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o2NX:ooooooooool03_ooool0023ooooo<ol9
jPZVooooo`03o`WZ2_oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol9jP[ooooooooo
o`0>ooooo`00nOooool00ol9jP[oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o2NX:
ooooooooool03_ooool00?Wooooo00?o2NX:ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`WZ2_oooooooooo00kooooo003iooooo`03o`WZ2_oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol9jP[oooooooooo`0>ooooo`00n?ooool3o`WZ2PWooooo00?o0000ooooooooool0
1_ooool2o`WZ2P03ooooool9jP[ooooo00kooooo003hooooo`03o`WZ2_oooooooooo00?o2NX:1_oo
ool00ol0003oooooooooo`03ooooo`?o2NX:0oooool00ol9jP[oooooooooo`0=ooooo`00n?ooool0
0ol9jP[oooooooooo`03ooooo`co2NX:1_ooool00ol9jP[oooooooooo`0=ooooo`00n?ooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool03Oooool00?So
oooo00?o2NX:ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`WZ2_oooooooooo00go
oooo003hooooo`03o`WZ2_oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol9jP[ooooo
ooooo`0=ooooo`00n?ooool00ol9jP[oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
2NX:ooooooooool03Oooool00?Oooooo00?o2NX:ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`WZ2_oooooooooo00gooooo003gooooo`03o`WZ2_oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol9jP[oooooooooo`0=ooooo`00moooool00ol9jP[oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o2NX:ooooooooool03Oooool00?Oooooo0ol9jPX:ooooo`03o`00
0?oooooooooo00Sooooo0_l9jPX?ooooo`00moooool01?l9jP[oooooo`WZ2_l9jPX9ooooo`03o`00
0?oooooooooo00Kooooo0_l9jPX00ooooooo2NX:ooooo`0>ooooo`00moooool01?l9jP[ooooooooo
ooooool3o`WZ2PKooooo00?o0000ooooooooool00oooool3o`WZ2P?ooooo00?o2NX:ooooooooool0
3Oooool00?Oooooo00?o2NX:ooooooooool01?ooool<o`WZ2PKooooo00?o2NX:ooooooooool03Ooo
ool00?Kooooo00?o2NX:ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo00cooooo003fooooo`03o`WZ2_oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol9
jP[oooooooooo`0<ooooo`00m_ooool00ol9jP[oooooooooo`0;ooooo`03o`000?oooooooooo00[o
oooo00?o2NX:ooooooooool03?ooool00?Kooooo00?o2NX:ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`WZ2_oooooooooo00cooooo003fooooo`03o`WZ2_oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol9jP[oooooooooo`0<ooooo`00m_ooool00ol9jP[oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool03?ooool00?Kooooo0_l9jPX<oooo
o`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool03?ooool00?Gooooo00Co2NX:ooooool9
jP[o2NX:2oooool00ol0003oooooooooo`08ooooo`;o2NX:00?oooooo`WZ2_ooool03?ooool00?Go
oooo00Co2NX:oooooooooooooooo0ol9jPX8ooooo`03o`000?oooooooooo00Gooooo0ol9jPX3oooo
o`03o`WZ2_oooooooooo00_ooooo003eooooo`03o`WZ2_oooooooooo00Cooooo0ol9jPX5ooooo`03
o`000?oooooooooo00?ooooo0ol9jPX5ooooo`03o`WZ2_oooooooooo00_ooooo003eooooo`03o`WZ
2_oooooooooo00Kooooo3?l9jPX8ooooo`03o`WZ2_oooooooooo00_ooooo003eooooo`03o`WZ2_oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol9jP[oooooooooo`0;ooooo`00mOooool0
0ol9jP[oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o2NX:ooooooooool02oooool0
0?Gooooo00?o2NX:ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`WZ2_oooooooooo
00_ooooo003dooooo`03o`WZ2_oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol9jP[o
ooooooooo`0:ooooo`00m?ooool00ol9jP[oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o2NX:ooooooooool02_ooool00?Cooooo00?o2NX:ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`WZ2_oooooooooo00[ooooo003dooooo`?o2NX:3Oooool00ol0003oooooooooo`0:
ooooo`?o2NX:3?ooool00?Cooooo00?o2NX:ooooooooool00_l9jPX;ooooo`03o`000?oooooooooo
00Sooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00[ooooo003dooooo`03o`WZ2_oooooooooo00;o
oooo0ol9jPX8ooooo`03o`000?oooooooooo00Gooooo0ol9jPX4ooooo`03o`WZ2_oooooooooo00[o
oooo003dooooo`03o`WZ2_oooooooooo00Gooooo1?l9jPX4ooooo`04o`000?ooooooooooooooo`Co
2NX:1oooool00ol9jP[oooooooooo`0:ooooo`00loooool00ol9jP[oooooooooo`0:ooooo`So2NX:
3?ooool00ol9jP[oooooooooo`09ooooo`00loooool00ol9jP[oooooooooo`0>ooooo`03o`000?oo
oooooooo00gooooo00?o2NX:ooooooooool02Oooool00??ooooo00?o2NX:ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`WZ2_oooooooooo00Wooooo003cooooo`03o`WZ2_oooooooooo
00kooooo00?o0000ooooooooool03Oooool00ol9jP[oooooooooo`09ooooo`00loooool00ol9jP[o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o2NX:ooooooooool02Oooool00??ooooo
00?o2NX:ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`WZ2_oooooooooo00Wooooo
003cooooo`;o2NX:3oooool00ol0003oooooooooo`0<ooooo`;o2NX:2oooool00??ooooo00Co2NX:
ooooool9jP[o2NX:3Oooool00ol0003oooooooooo`0:ooooo`;o2NX:00?oooooo`WZ2_ooool02_oo
ool00??ooooo00Co2NX:oooooooooooooooo0_l9jPX;ooooo`03o`000?oooooooooo00Sooooo0_l9
jPX4ooooo`03o`WZ2_oooooooooo00Sooooo003cooooo`03o`WZ2_oooooooooo00?ooooo0ol9jPX8
ooooo`03o`000?oooooooooo00Gooooo0ol9jPX6ooooo`03o`WZ2_oooooooooo00Sooooo003coooo
o`03o`WZ2_oooooooooo00Kooooo1Ol9jPX3ooooo`04o`000?ooooooooooooooo`Co2NX:2Oooool0
0ol9jP[oooooooooo`08ooooo`00loooool00ol9jP[oooooooooo`0;ooooo`Oo2NX:3Oooool00ol9
jP[oooooooooo`08ooooo`00loooool00ol9jP[oooooooooo`0>ooooo`03o`000?oooooooooo00ko
oooo00?o2NX:ooooooooool02?ooool00??ooooo00?o2NX:ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`03o`WZ2_oooooooooo00Sooooo003cooooo`03o`WZ2_oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol9jP[oooooooooo`08ooooo`00l_ooool00ol9jP[oooooooooo`0?
ooooo`03o`000?oooooooooo00oooooo00?o2NX:ooooooooool01oooool00?;ooooo00?o2NX:oooo
ooooool03oooool00ol0003oooooooooo`0?ooooo`03o`WZ2_oooooooooo00Oooooo003booooo`?o
2NX:3oooool00ol0003oooooooooo`0<ooooo`;o2NX:00?oooooo`WZ2_ooool02?ooool00?;ooooo
00Co2NX:oooooooooooo2NX:3_ooool00ol0003oooooooooo`0;ooooo`05o`WZ2_oooooooooooooo
ool9jPX02Oooool00?;ooooo00Co2NX:oooooooooooooooo1?l9jPX:ooooo`03o`000?oooooooooo
00Sooooo0ol9jPX4ooooo`03o`WZ2_oooooooooo00Oooooo003booooo`03o`WZ2_oooooooooo00Go
oooo0ol9jPX7ooooo`03o`000?oooooooooo00Cooooo1?l9jPX7ooooo`03o`WZ2_oooooooooo00Oo
oooo003booooo`03o`WZ2_oooooooooo00Sooooo3_l9jPX;ooooo`03o`WZ2_oooooooooo00Oooooo
003aooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool03oooool00ol9jP[ooooooooo
o`07ooooo`00lOooool00ol9jP[oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o2NX:
ooooooooool01oooool00?7ooooo00?o2NX:ooooooooool03_ooool01Ol0003oooooo`000?oooooo
000000oooooo00?o2NX:ooooooooool01oooool00?7ooooo00?o2NX:ooooooooool03_ooool5o`00
00oooooo00?o2NX:ooooooooool01oooool00?7ooooo00?o2NX:ooooooooool03_ooool5o`0000oo
oooo00?o2NX:ooooooooool01oooool00?7ooooo00?o2NX:ooooooooool03oooool3o`00013ooooo
00?o2NX:ooooooooool01oooool00?7ooooo00?o2NX:ooooooooool03oooool3o`00013ooooo00?o
2NX:ooooooooool01oooool00?3ooooo00?o2NX:ooooooooool04?ooool3o`00017ooooo00?o2NX:
ooooooooool01_ooool00?3ooooo00?o2NX:ooooooooool04?ooool3o`00017ooooo00?o2NX:oooo
ooooool01_ooool00?3ooooo00?o2NX:ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03
o`WZ2_oooooooooo00Kooooo003`ooooo`03o`WZ2_oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol9jP[oooooooooo`06ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.039, -21.9964, 0.692028, \
0.416827}},
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"BeamSpotSizeGraphics", "\[Rule]", 
          RowBox[{"(", 
            TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
              False,
              Editable->False], ")"}]}], ",", 
        RowBox[{"BeamCurvatureGraphics", "\[Rule]", 
          RowBox[{"(", 
            TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
              False,
              Editable->False], ")"}]}], 
        ",", \(BeamSpotSizeFunction \[Rule] \((Which[#1 < 
                  49.999999999999986`, 
                0.033859048519996264`\ \@\(1 + 0.02180672813135181`\ \
\((\(\(3999.9942678200596`\)\(\[InvisibleSpace]\)\) + #1)\)\^2\), #1 \
\[GreaterEqual] 49.999999999999986` && #1 < 60.`, 
                0.0008578841613108302`\ \@\(1 + 22931.014549522304`\ \
\((\(-205.87796768695574`\) + #1)\)\^2\), #1 \[GreaterEqual] 60.` && #1 < 
                    175.`, 0.0008578841613108324`\ \@\(1 + 52914.52588784825`\
\ \((\(-156.03153804597986`\) + #1)\)\^2\), #1 \[GreaterEqual] 175.` && #1 < 
                    225.`, 0.0008578841613108303`\ \@\(1 + 52914.52588784875`\
\ \((\(-156.03153804597986`\) + #1)\)\^2\), #1 \[GreaterEqual] 225.`, 
                0.0008578841613108305`\ \@\(1 + 52914.525887848715`\ \
\((\(-156.03153804597986`\) + #1)\)\^2\)] &)\)\), 
        ",", \(BeamCurvatureFunction \[Rule] \((Which[#1 < 
                  49.999999999999986`, \(-\((\(\(3999.9942678200596`\)\(\
\[InvisibleSpace]\)\) + #1)\)\)\ \((1 + 
                      45.85740666717844`\/\((\(\(3999.9942678200596`\)\(\
\[InvisibleSpace]\)\) + #1)\)\^2)\), #1 \[GreaterEqual] 
                    49.999999999999986` && #1 < 
                    60.`, \(-\((1 + 
                        0.000043609060464393274`\/\((\(-205.87796768695574`\) \
+ #1)\)\^2)\)\)\ \((\(-205.87796768695574`\) + #1)\), #1 \[GreaterEqual] 
                    60.` && #1 < 
                    175.`, \(-\((1 + 
                        0.00001889840234266653`\/\((\(-156.03153804597986`\) \
+ #1)\)\^2)\)\)\ \((\(-156.03153804597986`\) + #1)\), #1 \[GreaterEqual] 
                    175.` && #1 < 
                    225.`, \(-\((1 + 
                        0.00001889840234266635`\/\((\(-156.03153804597986`\) \
+ #1)\)\^2)\)\)\ \((\(-156.03153804597986`\) + #1)\), #1 \[GreaterEqual] 
                  225.`, \(-\((1 + 
                        0.000018898402342666363`\/\((\(-156.03153804597986`\) \
+ #1)\)\^2)\)\)\ \((\(-156.03153804597986`\) + #1)\)] &)\)\), 
        ",", \(ComplexBeamParameterFunction \[Rule] \((Which[#1 < 
                  49.999999999999986`, \((\(\(3999.9942678200596`\)\(\
\[InvisibleSpace]\)\) + 
                      6.771809703999252`\ \[ImaginaryI])\) - #1, #1 \
\[GreaterEqual] 49.999999999999986` && #1 < 
                    60.`, \((\(-105.87796768695576`\) + 
                      0.006603715655931384`\ \[ImaginaryI])\) - #1, #1 \
\[GreaterEqual] 60.` && #1 < 
                    175.`, \((\(-36.03153804597987`\) + 
                      0.0043472292719232706`\ \[ImaginaryI])\) - #1, #1 \
\[GreaterEqual] 175.` && #1 < 
                    225.`, \((\(\(193.96846195402014`\)\(\[InvisibleSpace]\)\)\
 + 0.00434722927192325`\ \[ImaginaryI])\) - #1, #1 \[GreaterEqual] 
                  225.`, \((\(\(293.96846195402014`\)\(\[InvisibleSpace]\)\) \
+ 0.0043472292719232515`\ \[ImaginaryI])\) - #1] &)\)\), 
        ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(PlotDomain \[Rule] {0, 225.`}\)}], "}"}]], "Output",
  CellLabel->"Out[32]=",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowGaussian", "Subsubsection",
  CellTags->{"AOG0.", "4.2.4", "AOG4.", "AOG4.2", "AOG4.2.4"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[opticalsystemreflected,PlotType->TopView,ShowGaussian->True];\
\>", "Input",
  CellLabel->"In[33]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .39158 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0241622 0.00463274 0.150622 0.00463274 [
[.27896 .00932 -5.03125 -6 ]
[.27896 .00932 5.03125 6 ]
[.78412 .09985 -6.4375 -6 ]
[.78412 .09985 6.4375 6 ]
[.97619 .38226 -4.75 -6 ]
[.97619 .38226 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .39158 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.2855 .0348 m
.30213 .0348 L
.30213 .07341 L
.26852 .07341 L
.2855 .0348 L
F
.26852 .07341 m
.30213 .07341 L
.30213 .11202 L
.25892 .11202 L
.26852 .07341 L
F
.25892 .11202 m
.30213 .11202 L
.30213 .15062 L
.2558 .15062 L
.25892 .11202 L
F
.2558 .15062 m
.30213 .15062 L
.30213 .18923 L
.25892 .18923 L
.2558 .15062 L
F
.25892 .18923 m
.30213 .18923 L
.30213 .22783 L
.26852 .22783 L
.25892 .18923 L
F
.26852 .22783 m
.30213 .22783 L
.30213 .26644 L
.2855 .26644 L
.26852 .22783 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.2855 .0348 m
.26852 .07341 L
.25892 .11202 L
.2558 .15062 L
.25892 .18923 L
.26852 .22783 L
.2855 .26644 L
.30213 .26644 L
.30213 .22783 L
.30213 .18923 L
.30213 .15062 L
.30213 .11202 L
.30213 .07341 L
.30213 .0348 L
.2855 .0348 L
s
.5 g
.2855 .15062 m
.30213 .15062 L
.30213 .15062 L
.26852 .15062 L
.2855 .15062 L
F
.26852 .15062 m
.30213 .15062 L
.30213 .15062 L
.25892 .15062 L
.26852 .15062 L
F
.25892 .15062 m
.30213 .15062 L
.30213 .15062 L
.2558 .15062 L
.25892 .15062 L
F
.2558 .15062 m
.30213 .15062 L
.30213 .15062 L
.25892 .15062 L
.2558 .15062 L
F
.25892 .15062 m
.30213 .15062 L
.30213 .15062 L
.26852 .15062 L
.25892 .15062 L
F
.26852 .15062 m
.30213 .15062 L
.30213 .15062 L
.2855 .15062 L
.26852 .15062 L
F
0 g
.2855 .15062 m
.26852 .15062 L
.25892 .15062 L
.2558 .15062 L
.25892 .15062 L
.26852 .15062 L
.2855 .15062 L
.30213 .15062 L
.30213 .15062 L
.30213 .15062 L
.30213 .15062 L
.30213 .15062 L
.30213 .15062 L
.30213 .15062 L
.2855 .15062 L
s
.2855 .26644 m
.30213 .26644 L
.30213 .26249 L
.2855 .26249 L
.2855 .26644 L
s
.2855 .26249 m
.30213 .26249 L
.30213 .25092 L
.2855 .25092 L
.2855 .26249 L
s
.2855 .25092 m
.30213 .25092 L
.30213 .23252 L
.2855 .23252 L
.2855 .25092 L
s
.2855 .23252 m
.30213 .23252 L
.30213 .20853 L
.2855 .20853 L
.2855 .23252 L
s
.2855 .20853 m
.30213 .20853 L
.30213 .1806 L
.2855 .1806 L
.2855 .20853 L
s
.2855 .1806 m
.30213 .1806 L
.30213 .15062 L
.2855 .15062 L
.2855 .1806 L
s
.2855 .15062 m
.30213 .15062 L
.30213 .12065 L
.2855 .12065 L
.2855 .15062 L
s
.2855 .12065 m
.30213 .12065 L
.30213 .09271 L
.2855 .09271 L
.2855 .12065 L
s
.2855 .09271 m
.30213 .09271 L
.30213 .06873 L
.2855 .06873 L
.2855 .09271 L
s
.2855 .06873 m
.30213 .06873 L
.30213 .05032 L
.2855 .05032 L
.2855 .06873 L
s
.2855 .05032 m
.30213 .05032 L
.30213 .03875 L
.2855 .03875 L
.2855 .05032 L
s
.2855 .03875 m
.30213 .03875 L
.30213 .0348 L
.2855 .0348 L
.2855 .03875 L
s
.2855 .0348 m
.30213 .0348 L
.30213 .03875 L
.2855 .03875 L
.2855 .0348 L
s
.2855 .03875 m
.30213 .03875 L
.30213 .05032 L
.2855 .05032 L
.2855 .03875 L
s
.2855 .05032 m
.30213 .05032 L
.30213 .06873 L
.2855 .06873 L
.2855 .05032 L
s
.2855 .06873 m
.30213 .06873 L
.30213 .09271 L
.2855 .09271 L
.2855 .06873 L
s
.2855 .09271 m
.30213 .09271 L
.30213 .12065 L
.2855 .12065 L
.2855 .09271 L
s
.2855 .12065 m
.30213 .12065 L
.30213 .15062 L
.2855 .15062 L
.2855 .12065 L
s
.2855 .15062 m
.30213 .15062 L
.30213 .1806 L
.2855 .1806 L
.2855 .15062 L
s
.2855 .1806 m
.30213 .1806 L
.30213 .20853 L
.2855 .20853 L
.2855 .1806 L
s
.2855 .20853 m
.30213 .20853 L
.30213 .23252 L
.2855 .23252 L
.2855 .20853 L
s
.2855 .23252 m
.30213 .23252 L
.30213 .25092 L
.2855 .25092 L
.2855 .23252 L
s
.2855 .25092 m
.30213 .25092 L
.30213 .26249 L
.2855 .26249 L
.2855 .25092 L
s
.2855 .26249 m
.30213 .26249 L
.30213 .26644 L
.2855 .26644 L
.2855 .26249 L
s
.5 g
.80213 .11786 m
.80213 .11786 L
.81305 .12878 L
.81305 .12878 L
.80213 .11786 L
F
.81305 .12878 m
.81305 .12878 L
.82397 .1397 L
.82397 .1397 L
.81305 .12878 L
F
.82397 .1397 m
.82397 .1397 L
.83489 .15062 L
.83489 .15062 L
.82397 .1397 L
F
.83489 .15062 m
.83489 .15062 L
.84581 .16154 L
.84581 .16154 L
.83489 .15062 L
F
.84581 .16154 m
.84581 .16154 L
.85673 .17246 L
.85673 .17246 L
.84581 .16154 L
F
.85673 .17246 m
.85673 .17246 L
.86765 .18338 L
.86765 .18338 L
.85673 .17246 L
F
0 g
.80213 .11786 m
.81305 .12878 L
.82397 .1397 L
.83489 .15062 L
.84581 .16154 L
.85673 .17246 L
.86765 .18338 L
.86765 .18338 L
.85673 .17246 L
.84581 .16154 L
.83489 .15062 L
.82397 .1397 L
.81305 .12878 L
.80213 .11786 L
.80213 .11786 L
s
.5 g
.83489 .15062 m
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
F
.83489 .15062 m
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
F
.83489 .15062 m
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
F
.83489 .15062 m
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
F
.83489 .15062 m
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
F
.83489 .15062 m
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
F
0 g
.83489 .15062 m
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
s
.5 g
.83489 .15062 m
.84581 .16154 L
.84544 .16117 L
.83489 .15062 L
.83489 .15062 L
F
.84581 .16154 m
.85673 .17246 L
.85599 .17172 L
.84544 .16117 L
.84581 .16154 L
F
.85673 .17246 m
.86765 .18338 L
.86653 .18226 L
.85599 .17172 L
.85673 .17246 L
F
.83489 .15062 m
.84544 .16117 L
.84435 .16008 L
.83489 .15062 L
.83489 .15062 L
F
.84544 .16117 m
.85599 .17172 L
.8538 .16954 L
.84435 .16008 L
.84544 .16117 L
F
.85599 .17172 m
.86653 .18226 L
.86326 .17899 L
.8538 .16954 L
.85599 .17172 L
F
.83489 .15062 m
.84435 .16008 L
.84261 .15834 L
.83489 .15062 L
.83489 .15062 L
F
.84435 .16008 m
.8538 .16954 L
.85033 .16606 L
.84261 .15834 L
.84435 .16008 L
F
.8538 .16954 m
.86326 .17899 L
.85806 .17379 L
.85033 .16606 L
.8538 .16954 L
F
.83489 .15062 m
.84261 .15834 L
.84035 .15608 L
.83489 .15062 L
.83489 .15062 L
F
.84261 .15834 m
.85033 .16606 L
.84581 .16154 L
.84035 .15608 L
.84261 .15834 L
F
.85033 .16606 m
.85806 .17379 L
.85127 .167 L
.84581 .16154 L
.85033 .16606 L
F
.83489 .15062 m
.84035 .15608 L
.83772 .15345 L
.83489 .15062 L
.83489 .15062 L
F
.84035 .15608 m
.84581 .16154 L
.84054 .15627 L
.83772 .15345 L
.84035 .15608 L
F
.84581 .16154 m
.85127 .167 L
.84337 .1591 L
.84054 .15627 L
.84581 .16154 L
F
.83489 .15062 m
.83772 .15345 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
F
.83772 .15345 m
.84054 .15627 L
.83489 .15062 L
.83489 .15062 L
.83772 .15345 L
F
.84054 .15627 m
.84337 .1591 L
.83489 .15062 L
.83489 .15062 L
.84054 .15627 L
F
.83489 .15062 m
.83489 .15062 L
.83207 .1478 L
.83489 .15062 L
.83489 .15062 L
F
.83489 .15062 m
.83489 .15062 L
.82924 .14497 L
.83207 .1478 L
.83489 .15062 L
F
.83489 .15062 m
.83489 .15062 L
.82641 .14214 L
.82924 .14497 L
.83489 .15062 L
F
.83489 .15062 m
.83207 .1478 L
.82943 .14516 L
.83489 .15062 L
.83489 .15062 L
F
.83207 .1478 m
.82924 .14497 L
.82397 .1397 L
.82943 .14516 L
.83207 .1478 L
F
.82924 .14497 m
.82641 .14214 L
.81851 .13424 L
.82397 .1397 L
.82924 .14497 L
F
.83489 .15062 m
.82943 .14516 L
.82717 .1429 L
.83489 .15062 L
.83489 .15062 L
F
.82943 .14516 m
.82397 .1397 L
.81945 .13518 L
.82717 .1429 L
.82943 .14516 L
F
.82397 .1397 m
.81851 .13424 L
.81173 .12746 L
.81945 .13518 L
.82397 .1397 L
F
.83489 .15062 m
.82717 .1429 L
.82544 .14117 L
.83489 .15062 L
.83489 .15062 L
F
.82717 .1429 m
.81945 .13518 L
.81598 .13171 L
.82544 .14117 L
.82717 .1429 L
F
.81945 .13518 m
.81173 .12746 L
.80652 .12225 L
.81598 .13171 L
.81945 .13518 L
F
.83489 .15062 m
.82544 .14117 L
.82434 .14007 L
.83489 .15062 L
.83489 .15062 L
F
.82544 .14117 m
.81598 .13171 L
.8138 .12953 L
.82434 .14007 L
.82544 .14117 L
F
.81598 .13171 m
.80652 .12225 L
.80325 .11898 L
.8138 .12953 L
.81598 .13171 L
F
.83489 .15062 m
.82434 .14007 L
.82397 .1397 L
.83489 .15062 L
.83489 .15062 L
F
.82434 .14007 m
.8138 .12953 L
.81305 .12878 L
.82397 .1397 L
.82434 .14007 L
F
.8138 .12953 m
.80325 .11898 L
.80213 .11786 L
.81305 .12878 L
.8138 .12953 L
F
.83489 .15062 m
.82397 .1397 L
.82434 .14007 L
.83489 .15062 L
.83489 .15062 L
F
.82397 .1397 m
.81305 .12878 L
.8138 .12953 L
.82434 .14007 L
.82397 .1397 L
F
.81305 .12878 m
.80213 .11786 L
.80325 .11898 L
.8138 .12953 L
.81305 .12878 L
F
.83489 .15062 m
.82434 .14007 L
.82544 .14117 L
.83489 .15062 L
.83489 .15062 L
F
.82434 .14007 m
.8138 .12953 L
.81598 .13171 L
.82544 .14117 L
.82434 .14007 L
F
.8138 .12953 m
.80325 .11898 L
.80652 .12225 L
.81598 .13171 L
.8138 .12953 L
F
.83489 .15062 m
.82544 .14117 L
.82717 .1429 L
.83489 .15062 L
.83489 .15062 L
F
.82544 .14117 m
.81598 .13171 L
.81945 .13518 L
.82717 .1429 L
.82544 .14117 L
F
.81598 .13171 m
.80652 .12225 L
.81173 .12746 L
.81945 .13518 L
.81598 .13171 L
F
.83489 .15062 m
.82717 .1429 L
.82943 .14516 L
.83489 .15062 L
.83489 .15062 L
F
.82717 .1429 m
.81945 .13518 L
.82397 .1397 L
.82943 .14516 L
.82717 .1429 L
F
.81945 .13518 m
.81173 .12746 L
.81851 .13424 L
.82397 .1397 L
.81945 .13518 L
F
.83489 .15062 m
.82943 .14516 L
.83207 .1478 L
.83489 .15062 L
.83489 .15062 L
F
.82943 .14516 m
.82397 .1397 L
.82924 .14497 L
.83207 .1478 L
.82943 .14516 L
F
.82397 .1397 m
.81851 .13424 L
.82641 .14214 L
.82924 .14497 L
.82397 .1397 L
F
.83489 .15062 m
.83207 .1478 L
.83489 .15062 L
.83489 .15062 L
.83489 .15062 L
F
.83207 .1478 m
.82924 .14497 L
.83489 .15062 L
.83489 .15062 L
.83207 .1478 L
F
.82924 .14497 m
.82641 .14214 L
.83489 .15062 L
.83489 .15062 L
.82924 .14497 L
F
.83489 .15062 m
.83489 .15062 L
.83772 .15345 L
.83489 .15062 L
.83489 .15062 L
F
.83489 .15062 m
.83489 .15062 L
.84054 .15627 L
.83772 .15345 L
.83489 .15062 L
F
.83489 .15062 m
.83489 .15062 L
.84337 .1591 L
.84054 .15627 L
.83489 .15062 L
F
.83489 .15062 m
.83772 .15345 L
.84035 .15608 L
.83489 .15062 L
.83489 .15062 L
F
.83772 .15345 m
.84054 .15627 L
.84581 .16154 L
.84035 .15608 L
.83772 .15345 L
F
.84054 .15627 m
.84337 .1591 L
.85127 .167 L
.84581 .16154 L
.84054 .15627 L
F
.83489 .15062 m
.84035 .15608 L
.84261 .15834 L
.83489 .15062 L
.83489 .15062 L
F
.84035 .15608 m
.84581 .16154 L
.85033 .16606 L
.84261 .15834 L
.84035 .15608 L
F
.84581 .16154 m
.85127 .167 L
.85806 .17379 L
.85033 .16606 L
.84581 .16154 L
F
.83489 .15062 m
.84261 .15834 L
.84435 .16008 L
.83489 .15062 L
.83489 .15062 L
F
.84261 .15834 m
.85033 .16606 L
.8538 .16954 L
.84435 .16008 L
.84261 .15834 L
F
.85033 .16606 m
.85806 .17379 L
.86326 .17899 L
.8538 .16954 L
.85033 .16606 L
F
.83489 .15062 m
.84435 .16008 L
.84544 .16117 L
.83489 .15062 L
.83489 .15062 L
F
.84435 .16008 m
.8538 .16954 L
.85599 .17172 L
.84544 .16117 L
.84435 .16008 L
F
.8538 .16954 m
.86326 .17899 L
.86653 .18226 L
.85599 .17172 L
.8538 .16954 L
F
.83489 .15062 m
.84544 .16117 L
.84581 .16154 L
.83489 .15062 L
.83489 .15062 L
F
.84544 .16117 m
.85599 .17172 L
.85673 .17246 L
.84581 .16154 L
.84544 .16117 L
F
.85599 .17172 m
.86653 .18226 L
.86765 .18338 L
.85673 .17246 L
.85599 .17172 L
F
0 g
.86765 .18338 m
.86653 .18226 L
.86326 .17899 L
.85806 .17379 L
.85127 .167 L
.84337 .1591 L
.83489 .15062 L
.82641 .14214 L
.81851 .13424 L
.81173 .12746 L
.80652 .12225 L
.80325 .11898 L
.80213 .11786 L
.80325 .11898 L
.80652 .12225 L
.81173 .12746 L
.81851 .13424 L
.82641 .14214 L
.83489 .15062 L
.84337 .1591 L
.85127 .167 L
.85806 .17379 L
.86326 .17899 L
.86653 .18226 L
.86765 .18338 L
s
.95071 .38226 m
.9121 .38226 L
.8735 .38226 L
.83489 .38226 L
.79629 .38226 L
.75768 .38226 L
.71907 .38226 L
.71907 .38226 L
.75768 .38226 L
.79629 .38226 L
.83489 .38226 L
.8735 .38226 L
.9121 .38226 L
.95071 .38226 L
.95071 .38226 L
s
.83489 .38226 m
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
s
.71907 .38226 m
.72302 .38226 L
.73459 .38226 L
.753 .38226 L
.77698 .38226 L
.80492 .38226 L
.83489 .38226 L
.86487 .38226 L
.8928 .38226 L
.91679 .38226 L
.93519 .38226 L
.94676 .38226 L
.95071 .38226 L
.94676 .38226 L
.93519 .38226 L
.91679 .38226 L
.8928 .38226 L
.86487 .38226 L
.83489 .38226 L
.80492 .38226 L
.77698 .38226 L
.753 .38226 L
.73459 .38226 L
.72302 .38226 L
.71907 .38226 L
s
0 0 0 r
gsave
.27896 .00932 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78412 .09985 -67.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
71.875 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .38226 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
1 Mabswid
.02416 .24328 m
.03806 .24335 L
.05196 .24342 L
.06586 .24349 L
.07976 .24355 L
.09365 .24362 L
.10755 .24369 L
.12145 .24376 L
.13535 .24383 L
.14925 .2439 L
.16314 .24397 L
.17704 .24404 L
.19094 .24411 L
.20484 .24418 L
.21874 .24425 L
.23264 .24432 L
.24653 .24439 L
.26043 .24383 L
.27433 .24203 L
.28823 .24022 L
.30213 .23842 L
.31602 .23567 L
.32992 .23293 L
.34382 .23019 L
.35772 .22745 L
.37162 .2247 L
.38552 .22196 L
.39941 .21922 L
.41331 .21648 L
.42721 .21373 L
.44111 .21099 L
.45501 .20825 L
.46891 .2055 L
.4828 .20276 L
.4967 .20002 L
.5106 .19728 L
.5245 .19453 L
.5384 .19179 L
.55229 .18905 L
.56619 .18631 L
.58009 .18356 L
.59399 .18082 L
.60789 .17808 L
.62179 .17533 L
.63568 .17259 L
.64958 .16985 L
.66348 .16711 L
.67738 .16436 L
.69128 .16162 L
.70518 .15888 L
Mistroke
.71907 .15614 L
.73297 .15339 L
.74687 .15065 L
.76077 .15334 L
.77467 .15608 L
.78856 .15882 L
.80246 .16156 L
.81636 .16431 L
.83026 .16705 L
.81572 .15989 L
.81298 .17379 L
.81024 .18768 L
.80749 .20158 L
.80475 .21548 L
.80201 .22938 L
.79927 .24328 L
.79652 .25718 L
.79378 .27107 L
.79104 .28497 L
.7883 .29887 L
.78555 .31277 L
.78281 .32667 L
.78007 .34056 L
.77732 .35446 L
.77458 .36836 L
.77184 .38226 L
Mfstroke
.02416 .05797 m
.03806 .0579 L
.05196 .05783 L
.06586 .05776 L
.07976 .05769 L
.09365 .05762 L
.10755 .05755 L
.12145 .05748 L
.13535 .05741 L
.14925 .05734 L
.16314 .05727 L
.17704 .0572 L
.19094 .05713 L
.20484 .05706 L
.21874 .05699 L
.23264 .05692 L
.24653 .05686 L
.26043 .05741 L
.27433 .05922 L
.28823 .06102 L
.30213 .06283 L
.31602 .06557 L
.32992 .06831 L
.34382 .07106 L
.35772 .0738 L
.37162 .07654 L
.38552 .07928 L
.39941 .08203 L
.41331 .08477 L
.42721 .08751 L
.44111 .09025 L
.45501 .093 L
.46891 .09574 L
.4828 .09848 L
.4967 .10122 L
.5106 .10397 L
.5245 .10671 L
.5384 .10945 L
.55229 .1122 L
.56619 .11494 L
.58009 .11768 L
.59399 .12042 L
.60789 .12317 L
.62179 .12591 L
.63568 .12865 L
.64958 .13139 L
.66348 .13414 L
.67738 .13688 L
.69128 .13962 L
.70518 .14237 L
Mistroke
.71907 .14511 L
.73297 .14785 L
.74687 .15059 L
.76077 .14791 L
.77467 .14517 L
.78856 .14242 L
.80246 .13968 L
.81636 .13694 L
.83026 .13419 L
.85406 .15989 L
.8568 .17379 L
.85955 .18768 L
.86229 .20158 L
.86503 .21548 L
.86778 .22938 L
.87052 .24328 L
.87326 .25718 L
.876 .27107 L
.87875 .28497 L
.88149 .29887 L
.88423 .31277 L
.88697 .32667 L
.88972 .34056 L
.89246 .35446 L
.8952 .36836 L
.89794 .38226 L
Mfstroke
0 0 0 r
.02416 .15062 m
.2558 .15062 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
.2558 .15062 m
.30213 .15062 L
s
% Start of user PostScript
50. 0 60. 0 MAarrowhead1
% End of user PostScript
.30213 .15062 m
.83489 .15062 L
s
% Start of user PostScript
60. 0 175. 0 MAarrowhead1
% End of user PostScript
.83489 .15062 m
.83489 .38226 L
s
% Start of user PostScript
175. 0 175. 50. MAarrowhead1
% End of user PostScript
.83489 .38226 m
.83489 .38226 L
s
% Start of user PostScript
175. 50. MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .06723 m
.02385 .07279 L
.0239 .07835 L
.02394 .08391 L
.02397 .08947 L
.02401 .09503 L
.02404 .10059 L
.02406 .10615 L
.02409 .11171 L
.02411 .11727 L
.02412 .12283 L
.02414 .12838 L
.02415 .13394 L
.02416 .1395 L
.02416 .14506 L
.02416 .15062 L
.02416 .15618 L
.02416 .16174 L
.02415 .1673 L
.02414 .17286 L
.02412 .17842 L
.02411 .18398 L
.02409 .18954 L
.02406 .1951 L
.02404 .20066 L
.02401 .20621 L
.02397 .21177 L
.02394 .21733 L
.0239 .22289 L
.02385 .22845 L
.02381 .23401 L
s
.04466 .06714 m
.0447 .0727 L
.04474 .07827 L
.04478 .08384 L
.04482 .0894 L
.04485 .09497 L
.04488 .10053 L
.04491 .1061 L
.04493 .11166 L
.04495 .11723 L
.04497 .12279 L
.04498 .12836 L
.045 .13393 L
.045 .13949 L
.04501 .14506 L
.04501 .15062 L
.04501 .15619 L
.045 .16175 L
.045 .16732 L
.04498 .17288 L
.04497 .17845 L
.04495 .18402 L
.04493 .18958 L
.04491 .19515 L
.04488 .20071 L
.04485 .20628 L
.04482 .21184 L
.04478 .21741 L
.04474 .22297 L
.0447 .22854 L
.04466 .23411 L
s
.0655 .06705 m
.06555 .07262 L
.06559 .07819 L
.06563 .08376 L
.06567 .08933 L
.0657 .0949 L
.06573 .10048 L
.06576 .10605 L
.06578 .11162 L
.0658 .11719 L
.06582 .12276 L
.06583 .12833 L
.06584 .13391 L
.06585 .13948 L
.06586 .14505 L
.06586 .15062 L
.06586 .15619 L
.06585 .16177 L
.06584 .16734 L
.06583 .17291 L
.06582 .17848 L
.0658 .18405 L
.06578 .18962 L
.06576 .1952 L
.06573 .20077 L
.0657 .20634 L
.06567 .21191 L
.06563 .21748 L
.06559 .22306 L
.06555 .22863 L
.0655 .2342 L
s
.08635 .06695 m
.0864 .07253 L
.08644 .07811 L
.08648 .08369 L
.08651 .08926 L
.08655 .09484 L
.08658 .10042 L
.0866 .106 L
.08663 .11158 L
.08665 .11715 L
.08666 .12273 L
.08668 .12831 L
.08669 .13389 L
.0867 .13947 L
.0867 .14504 L
.0867 .15062 L
.0867 .1562 L
.0867 .16178 L
.08669 .16736 L
.08668 .17293 L
.08666 .17851 L
.08665 .18409 L
.08663 .18967 L
.0866 .19525 L
.08658 .20082 L
.08655 .2064 L
.08651 .21198 L
.08648 .21756 L
.08644 .22314 L
.0864 .22871 L
.08635 .23429 L
s
.1072 .06686 m
.10724 .07244 L
.10729 .07803 L
.10732 .08361 L
.10736 .08919 L
.10739 .09478 L
.10742 .10036 L
.10745 .10595 L
.10747 .11153 L
.10749 .11712 L
.10751 .1227 L
.10753 .12828 L
.10754 .13387 L
.10755 .13945 L
.10755 .14504 L
.10755 .15062 L
.10755 .15621 L
.10755 .16179 L
.10754 .16737 L
.10753 .17296 L
.10751 .17854 L
.10749 .18413 L
.10747 .18971 L
.10745 .1953 L
.10742 .20088 L
.10739 .20647 L
.10736 .21205 L
.10732 .21763 L
.10729 .22322 L
.10724 .2288 L
.1072 .23439 L
s
.12804 .06676 m
.12809 .07235 L
.12813 .07794 L
.12817 .08354 L
.12821 .08913 L
.12824 .09472 L
.12827 .10031 L
.1283 .1059 L
.12832 .11149 L
.12834 .11708 L
.12836 .12267 L
.12837 .12826 L
.12838 .13385 L
.12839 .13944 L
.1284 .14503 L
.1284 .15062 L
.1284 .15621 L
.12839 .1618 L
.12838 .16739 L
.12837 .17298 L
.12836 .17857 L
.12834 .18417 L
.12832 .18976 L
.1283 .19535 L
.12827 .20094 L
.12824 .20653 L
.12821 .21212 L
.12817 .21771 L
.12813 .2233 L
.12809 .22889 L
.12804 .23448 L
s
.14889 .06667 m
.14894 .07227 L
.14898 .07786 L
.14902 .08346 L
.14906 .08906 L
.14909 .09465 L
.14912 .10025 L
.14915 .10585 L
.14917 .11144 L
.14919 .11704 L
.14921 .12264 L
.14922 .12823 L
.14923 .13383 L
.14924 .13943 L
.14924 .14503 L
.14925 .15062 L
.14924 .15622 L
.14924 .16182 L
.14923 .16741 L
.14922 .17301 L
.14921 .17861 L
.14919 .1842 L
.14917 .1898 L
.14915 .1954 L
.14912 .20099 L
.14909 .20659 L
.14906 .21219 L
.14902 .21778 L
.14898 .22338 L
.14894 .22898 L
.14889 .23457 L
s
.16974 .06658 m
.16978 .07218 L
.16983 .07778 L
.16987 .08339 L
.1699 .08899 L
.16994 .09459 L
.16997 .10019 L
.16999 .1058 L
.17002 .1114 L
.17004 .117 L
.17005 .12261 L
.17007 .12821 L
.17008 .13381 L
.17009 .13942 L
.17009 .14502 L
.17009 .15062 L
.17009 .15623 L
.17009 .16183 L
.17008 .16743 L
.17007 .17303 L
.17005 .17864 L
.17004 .18424 L
.17002 .18984 L
.16999 .19545 L
.16997 .20105 L
.16994 .20665 L
.1699 .21226 L
.16987 .21786 L
.16983 .22346 L
.16978 .22906 L
.16974 .23467 L
s
.19059 .06648 m
.19063 .07209 L
.19067 .0777 L
.19071 .08331 L
.19075 .08892 L
.19078 .09453 L
.19081 .10014 L
.19084 .10575 L
.19086 .11136 L
.19088 .11697 L
.1909 .12258 L
.19092 .12818 L
.19093 .13379 L
.19093 .1394 L
.19094 .14501 L
.19094 .15062 L
.19094 .15623 L
.19093 .16184 L
.19093 .16745 L
.19092 .17306 L
.1909 .17867 L
.19088 .18428 L
.19086 .18989 L
.19084 .1955 L
.19081 .20111 L
.19078 .20672 L
.19075 .21232 L
.19071 .21793 L
.19067 .22354 L
.19063 .22915 L
.19059 .23476 L
s
.21143 .06639 m
.21148 .072 L
.21152 .07762 L
.21156 .08324 L
.2116 .08885 L
.21163 .09447 L
.21166 .10008 L
.21169 .1057 L
.21171 .11131 L
.21173 .11693 L
.21175 .12254 L
.21176 .12816 L
.21177 .13378 L
.21178 .13939 L
.21179 .14501 L
.21179 .15062 L
.21179 .15624 L
.21178 .16185 L
.21177 .16747 L
.21176 .17308 L
.21175 .1787 L
.21173 .18432 L
.21171 .18993 L
.21169 .19555 L
.21166 .20116 L
.21163 .20678 L
.2116 .21239 L
.21156 .21801 L
.21152 .22362 L
.21148 .22924 L
.21143 .23486 L
s
.23228 .06629 m
.23232 .07192 L
.23237 .07754 L
.23241 .08316 L
.23244 .08878 L
.23248 .0944 L
.23251 .10003 L
.23253 .10565 L
.23256 .11127 L
.23258 .11689 L
.2326 .12251 L
.23261 .12813 L
.23262 .13376 L
.23263 .13938 L
.23263 .145 L
.23264 .15062 L
.23263 .15624 L
.23263 .16187 L
.23262 .16749 L
.23261 .17311 L
.2326 .17873 L
.23258 .18435 L
.23256 .18997 L
.23253 .1956 L
.23251 .20122 L
.23248 .20684 L
.23244 .21246 L
.23241 .21808 L
.23237 .22371 L
.23232 .22933 L
.23228 .23495 L
s
.25313 .0662 m
.25317 .07183 L
.25321 .07746 L
.25325 .08308 L
.25329 .08871 L
.25332 .09434 L
.25335 .09997 L
.25338 .1056 L
.25341 .11123 L
.25343 .11685 L
.25344 .12248 L
.25346 .12811 L
.25347 .13374 L
.25348 .13937 L
.25348 .14499 L
.25348 .15062 L
.25348 .15625 L
.25348 .16188 L
.25347 .16751 L
.25346 .17313 L
.25344 .17876 L
.25343 .18439 L
.25341 .19002 L
.25338 .19565 L
.25335 .20127 L
.25332 .2069 L
.25329 .21253 L
.25325 .21816 L
.25321 .22379 L
.25317 .22942 L
.25313 .23504 L
s
.28028 .06836 m
.27951 .07384 L
.2788 .07933 L
.27814 .08481 L
.27753 .09029 L
.27697 .09578 L
.27647 .10126 L
.27602 .10675 L
.27563 .11223 L
.27528 .11772 L
.27499 .1232 L
.27475 .12868 L
.27457 .13417 L
.27444 .13965 L
.27436 .14514 L
.27433 .15062 L
.27436 .15611 L
.27444 .16159 L
.27457 .16708 L
.27475 .17256 L
.27499 .17804 L
.27528 .18353 L
.27563 .18901 L
.27602 .1945 L
.27647 .19998 L
.27697 .20547 L
.27753 .21095 L
.27814 .21643 L
.2788 .22192 L
.27951 .2274 L
.28028 .23289 L
s
.30095 .07079 m
.30021 .07612 L
.29951 .08144 L
.29887 .08676 L
.29828 .09208 L
.29774 .0974 L
.29726 .10273 L
.29682 .10805 L
.29643 .11337 L
.2961 .11869 L
.29582 .12401 L
.29559 .12933 L
.29541 .13466 L
.29528 .13998 L
.2952 .1453 L
.29518 .15062 L
.2952 .15594 L
.29528 .16127 L
.29541 .16659 L
.29559 .17191 L
.29582 .17723 L
.2961 .18255 L
.29643 .18787 L
.29682 .1932 L
.29726 .19852 L
.29774 .20384 L
.29828 .20916 L
.29887 .21448 L
.29951 .21981 L
.30021 .22513 L
.30095 .23045 L
s
.3288 .07408 m
.32715 .07918 L
.32562 .08428 L
.3242 .08938 L
.32289 .09449 L
.3217 .09959 L
.32062 .10469 L
.31966 .1098 L
.31881 .1149 L
.31807 .12 L
.31744 .12511 L
.31693 .13021 L
.31654 .13531 L
.31625 .14042 L
.31608 .14552 L
.31602 .15062 L
.31608 .15573 L
.31625 .16083 L
.31654 .16593 L
.31693 .17103 L
.31744 .17614 L
.31807 .18124 L
.31881 .18634 L
.31966 .19145 L
.32062 .19655 L
.3217 .20165 L
.32289 .20676 L
.3242 .21186 L
.32562 .21696 L
.32715 .22207 L
.3288 .22717 L
s
.34903 .07778 m
.34746 .08263 L
.346 .08749 L
.34465 .09235 L
.34341 .0972 L
.34227 .10206 L
.34125 .10692 L
.34033 .11177 L
.33952 .11663 L
.33882 .12148 L
.33822 .12634 L
.33774 .1312 L
.33736 .13605 L
.33709 .14091 L
.33693 .14577 L
.33687 .15062 L
.33693 .15548 L
.33709 .16033 L
.33736 .16519 L
.33774 .17005 L
.33822 .1749 L
.33882 .17976 L
.33952 .18462 L
.34033 .18947 L
.34125 .19433 L
.34227 .19918 L
.34341 .20404 L
.34465 .2089 L
.346 .21375 L
.34746 .21861 L
.34903 .22347 L
s
.36926 .08148 m
.36777 .08609 L
.36639 .0907 L
.3651 .09531 L
.36392 .09992 L
.36285 .10453 L
.36187 .10914 L
.361 .11375 L
.36023 .11836 L
.35957 .12297 L
.359 .12757 L
.35854 .13218 L
.35818 .13679 L
.35792 .1414 L
.35777 .14601 L
.35772 .15062 L
.35777 .15523 L
.35792 .15984 L
.35818 .16445 L
.35854 .16906 L
.359 .17367 L
.35957 .17828 L
.36023 .18289 L
.361 .1875 L
.36187 .19211 L
.36285 .19672 L
.36392 .20133 L
.3651 .20594 L
.36639 .21054 L
.36777 .21515 L
.36926 .21976 L
s
.38949 .08518 m
.38808 .08955 L
.38677 .09391 L
.38556 .09827 L
.38444 .10263 L
.38342 .107 L
.3825 .11136 L
.38167 .11572 L
.38095 .12008 L
.38031 .12445 L
.37978 .12881 L
.37934 .13317 L
.379 .13753 L
.37876 .1419 L
.37862 .14626 L
.37857 .15062 L
.37862 .15498 L
.37876 .15935 L
.379 .16371 L
.37934 .16807 L
.37978 .17243 L
.38031 .1768 L
.38095 .18116 L
.38167 .18552 L
.3825 .18989 L
.38342 .19425 L
.38444 .19861 L
.38556 .20297 L
.38677 .20734 L
.38808 .2117 L
.38949 .21606 L
s
.40972 .08889 m
.40839 .093 L
.40715 .09712 L
.40601 .10123 L
.40495 .10535 L
.40399 .10946 L
.40312 .11358 L
.40234 .1177 L
.40166 .12181 L
.40106 .12593 L
.40056 .13004 L
.40015 .13416 L
.39983 .13827 L
.3996 .14239 L
.39946 .14651 L
.39941 .15062 L
.39946 .15474 L
.3996 .15885 L
.39983 .16297 L
.40015 .16709 L
.40056 .1712 L
.40106 .17532 L
.40166 .17943 L
.40234 .18355 L
.40312 .18766 L
.40399 .19178 L
.40495 .1959 L
.40601 .20001 L
.40715 .20413 L
.40839 .20824 L
.40972 .21236 L
s
.42995 .09259 m
.4287 .09646 L
.42754 .10033 L
.42646 .1042 L
.42547 .10806 L
.42457 .11193 L
.42375 .1158 L
.42302 .11967 L
.42237 .12354 L
.42181 .12741 L
.42134 .13128 L
.42095 .13515 L
.42065 .13902 L
.42043 .14288 L
.4203 .14675 L
.42026 .15062 L
.4203 .15449 L
.42043 .15836 L
.42065 .16223 L
.42095 .1661 L
.42134 .16997 L
.42181 .17384 L
.42237 .1777 L
.42302 .18157 L
.42375 .18544 L
.42457 .18931 L
.42547 .19318 L
.42646 .19705 L
.42754 .20092 L
.4287 .20479 L
.42995 .20866 L
s
.45018 .09629 m
.44901 .09991 L
.44792 .10354 L
.44691 .10716 L
.44598 .11078 L
.44514 .1144 L
.44437 .11802 L
.44369 .12165 L
.44308 .12527 L
.44256 .12889 L
.44212 .13251 L
.44175 .13613 L
.44147 .13976 L
.44127 .14338 L
.44115 .147 L
.44111 .15062 L
.44115 .15424 L
.44127 .15787 L
.44147 .16149 L
.44175 .16511 L
.44212 .16873 L
.44256 .17235 L
.44308 .17598 L
.44369 .1796 L
.44437 .18322 L
.44514 .18684 L
.44598 .19046 L
.44691 .19409 L
.44792 .19771 L
.44901 .20133 L
.45018 .20495 L
s
.47041 .09999 m
.46932 .10337 L
.4683 .10674 L
.46736 .11012 L
.4665 .11349 L
.46571 .11687 L
.465 .12024 L
.46436 .12362 L
.4638 .127 L
.46331 .13037 L
.46289 .13375 L
.46256 .13712 L
.46229 .1405 L
.46211 .14387 L
.46199 .14725 L
.46196 .15062 L
.46199 .154 L
.46211 .15737 L
.46229 .16075 L
.46256 .16412 L
.46289 .1675 L
.46331 .17087 L
.4638 .17425 L
.46436 .17762 L
.465 .181 L
.46571 .18437 L
.4665 .18775 L
.46736 .19112 L
.4683 .1945 L
.46932 .19788 L
.47041 .20125 L
s
.49063 .1037 m
.48963 .10682 L
.48869 .10995 L
.48782 .11308 L
.48701 .11621 L
.48628 .11934 L
.48562 .12247 L
.48503 .12559 L
.48451 .12872 L
.48406 .13185 L
.48367 .13498 L
.48336 .13811 L
.48312 .14124 L
.48294 .14437 L
.48284 .14749 L
.4828 .15062 L
.48284 .15375 L
.48294 .15688 L
.48312 .16001 L
.48336 .16314 L
.48367 .16626 L
.48406 .16939 L
.48451 .17252 L
.48503 .17565 L
.48562 .17878 L
.48628 .18191 L
.48701 .18503 L
.48782 .18816 L
.48869 .19129 L
.48963 .19442 L
.49063 .19755 L
s
.51086 .1074 m
.50993 .11028 L
.50907 .11316 L
.50827 .11604 L
.50753 .11892 L
.50686 .12181 L
.50625 .12469 L
.5057 .12757 L
.50522 .13045 L
.5048 .13333 L
.50445 .13621 L
.50416 .1391 L
.50394 .14198 L
.50378 .14486 L
.50368 .14774 L
.50365 .15062 L
.50368 .1535 L
.50378 .15639 L
.50394 .15927 L
.50416 .16215 L
.50445 .16503 L
.5048 .16791 L
.50522 .17079 L
.5057 .17367 L
.50625 .17656 L
.50686 .17944 L
.50753 .18232 L
.50827 .1852 L
.50907 .18808 L
.50993 .19096 L
.51086 .19385 L
s
.53109 .1111 m
.53024 .11374 L
.52945 .11637 L
.52872 .11901 L
.52804 .12164 L
.52743 .12427 L
.52687 .12691 L
.52637 .12954 L
.52593 .13218 L
.52555 .13481 L
.52523 .13745 L
.52497 .14008 L
.52476 .14272 L
.52462 .14535 L
.52453 .14799 L
.5245 .15062 L
.52453 .15326 L
.52462 .15589 L
.52476 .15853 L
.52497 .16116 L
.52523 .1638 L
.52555 .16643 L
.52593 .16906 L
.52637 .1717 L
.52687 .17433 L
.52743 .17697 L
.52804 .1796 L
.52872 .18224 L
.52945 .18487 L
.53024 .18751 L
.53109 .19014 L
s
.55132 .1148 m
.55055 .11719 L
.54984 .11958 L
.54917 .12197 L
.54856 .12436 L
.548 .12674 L
.5475 .12913 L
.54705 .13152 L
.54665 .13391 L
.5463 .13629 L
.54601 .13868 L
.54577 .14107 L
.54558 .14346 L
.54545 .14585 L
.54537 .14823 L
.54535 .15062 L
.54537 .15301 L
.54545 .1554 L
.54558 .15779 L
.54577 .16017 L
.54601 .16256 L
.5463 .16495 L
.54665 .16734 L
.54705 .16972 L
.5475 .17211 L
.548 .1745 L
.54856 .17689 L
.54917 .17928 L
.54984 .18166 L
.55055 .18405 L
.55132 .18644 L
s
.57155 .11851 m
.57086 .12065 L
.57022 .12279 L
.56962 .12493 L
.56908 .12707 L
.56857 .12921 L
.56812 .13135 L
.56772 .13349 L
.56736 .13563 L
.56705 .13778 L
.56679 .13992 L
.56657 .14206 L
.56641 .1442 L
.56629 .14634 L
.56622 .14848 L
.56619 .15062 L
.56622 .15276 L
.56629 .1549 L
.56641 .15705 L
.56657 .15919 L
.56679 .16133 L
.56705 .16347 L
.56736 .16561 L
.56772 .16775 L
.56812 .16989 L
.56857 .17203 L
.56908 .17417 L
.56962 .17631 L
.57022 .17846 L
.57086 .1806 L
.57155 .18274 L
s
.59178 .12221 m
.59117 .1241 L
.5906 .126 L
.59007 .12789 L
.58959 .12979 L
.58915 .13168 L
.58875 .13357 L
.58839 .13547 L
.58807 .13736 L
.5878 .13926 L
.58757 .14115 L
.58738 .14305 L
.58723 .14494 L
.58712 .14683 L
.58706 .14873 L
.58704 .15062 L
.58706 .15252 L
.58712 .15441 L
.58723 .1563 L
.58738 .1582 L
.58757 .16009 L
.5878 .16199 L
.58807 .16388 L
.58839 .16578 L
.58875 .16767 L
.58915 .16956 L
.58959 .17146 L
.59007 .17335 L
.5906 .17525 L
.59117 .17714 L
.59178 .17903 L
s
.61201 .12591 m
.61148 .12756 L
.61098 .12921 L
.61053 .13085 L
.61011 .1325 L
.60972 .13415 L
.60937 .1358 L
.60906 .13744 L
.60879 .13909 L
.60855 .14074 L
.60835 .14239 L
.60818 .14403 L
.60805 .14568 L
.60796 .14733 L
.60791 .14897 L
.60789 .15062 L
.60791 .15227 L
.60796 .15392 L
.60805 .15556 L
.60818 .15721 L
.60835 .15886 L
.60855 .16051 L
.60879 .16215 L
.60906 .1638 L
.60937 .16545 L
.60972 .1671 L
.61011 .16874 L
.61053 .17039 L
.61098 .17204 L
.61148 .17368 L
.61201 .17533 L
s
.63224 .12961 m
.63179 .13102 L
.63137 .13242 L
.63098 .13382 L
.63062 .13522 L
.63029 .13662 L
.63 .13802 L
.62973 .13942 L
.6295 .14082 L
.6293 .14222 L
.62912 .14362 L
.62898 .14502 L
.62888 .14642 L
.6288 .14782 L
.62875 .14922 L
.62873 .15062 L
.62875 .15202 L
.6288 .15342 L
.62888 .15482 L
.62898 .15622 L
.62912 .15762 L
.6293 .15902 L
.6295 .16043 L
.62973 .16183 L
.63 .16323 L
.63029 .16463 L
.63062 .16603 L
.63098 .16743 L
.63137 .16883 L
.63179 .17023 L
.63224 .17163 L
s
.65247 .13332 m
.6521 .13447 L
.65175 .13562 L
.65143 .13678 L
.65114 .13793 L
.65087 .13909 L
.65062 .14024 L
.6504 .14139 L
.65021 .14255 L
.65004 .1437 L
.6499 .14485 L
.64979 .14601 L
.6497 .14716 L
.64963 .14831 L
.6496 .14947 L
.64958 .15062 L
.6496 .15178 L
.64963 .15293 L
.6497 .15408 L
.64979 .15524 L
.6499 .15639 L
.65004 .15754 L
.65021 .1587 L
.6504 .15985 L
.65062 .161 L
.65087 .16216 L
.65114 .16331 L
.65143 .16447 L
.65175 .16562 L
.6521 .16677 L
.65247 .16793 L
s
.6727 .13702 m
.67241 .13793 L
.67213 .13883 L
.67188 .13974 L
.67165 .14065 L
.67144 .14155 L
.67125 .14246 L
.67108 .14337 L
.67092 .14427 L
.67079 .14518 L
.67068 .14609 L
.67059 .14699 L
.67052 .1479 L
.67047 .14881 L
.67044 .14972 L
.67043 .15062 L
.67044 .15153 L
.67047 .15244 L
.67052 .15334 L
.67059 .15425 L
.67068 .15516 L
.67079 .15606 L
.67092 .15697 L
.67108 .15788 L
.67125 .15878 L
.67144 .15969 L
.67165 .1606 L
.67188 .1615 L
.67213 .16241 L
.67241 .16332 L
.6727 .16422 L
s
.69293 .14072 m
.69272 .14138 L
.69252 .14204 L
.69233 .1427 L
.69217 .14336 L
.69201 .14402 L
.69187 .14468 L
.69175 .14534 L
.69164 .146 L
.69154 .14666 L
.69146 .14732 L
.69139 .14798 L
.69134 .14864 L
.69131 .1493 L
.69128 .14996 L
.69128 .15062 L
.69128 .15128 L
.69131 .15194 L
.69134 .1526 L
.69139 .15326 L
.69146 .15392 L
.69154 .15458 L
.69164 .15524 L
.69175 .1559 L
.69187 .15656 L
.69201 .15722 L
.69217 .15788 L
.69233 .15854 L
.69252 .1592 L
.69272 .15986 L
.69293 .16052 L
s
.71316 .14443 m
.71303 .14484 L
.7129 .14525 L
.71279 .14566 L
.71268 .14608 L
.71258 .14649 L
.7125 .1469 L
.71242 .14732 L
.71235 .14773 L
.71229 .14814 L
.71224 .14856 L
.7122 .14897 L
.71217 .14938 L
.71214 .1498 L
.71213 .15021 L
.71212 .15062 L
.71213 .15104 L
.71214 .15145 L
.71217 .15186 L
.7122 .15227 L
.71224 .15269 L
.71229 .1531 L
.71235 .15351 L
.71242 .15393 L
.7125 .15434 L
.71258 .15475 L
.71268 .15517 L
.71279 .15558 L
.7129 .15599 L
.71303 .15641 L
.71316 .15682 L
s
.73339 .14813 m
.73333 .14829 L
.73328 .14846 L
.73324 .14863 L
.7332 .14879 L
.73316 .14896 L
.73312 .14913 L
.73309 .14929 L
.73306 .14946 L
.73304 .14962 L
.73302 .14979 L
.733 .14996 L
.73299 .15012 L
.73298 .15029 L
.73297 .15046 L
.73297 .15062 L
.73297 .15079 L
.73298 .15095 L
.73299 .15112 L
.733 .15129 L
.73302 .15145 L
.73304 .15162 L
.73306 .15179 L
.73309 .15195 L
.73312 .15212 L
.73316 .15228 L
.7332 .15245 L
.73324 .15262 L
.73328 .15278 L
.73333 .15295 L
.73339 .15312 L
s
.75362 .14941 m
.75364 .14949 L
.75367 .14957 L
.75369 .14966 L
.75371 .14974 L
.75373 .14982 L
.75375 .1499 L
.75376 .14998 L
.75377 .15006 L
.75379 .15014 L
.7538 .15022 L
.7538 .1503 L
.75381 .15038 L
.75382 .15046 L
.75382 .15054 L
.75382 .15062 L
.75382 .1507 L
.75382 .15078 L
.75381 .15086 L
.7538 .15094 L
.7538 .15102 L
.75379 .15111 L
.75377 .15119 L
.75376 .15127 L
.75375 .15135 L
.75373 .15143 L
.75371 .15151 L
.75369 .15159 L
.75367 .15167 L
.75364 .15175 L
.75362 .15183 L
s
.77385 .14571 m
.77395 .14604 L
.77405 .14637 L
.77414 .14669 L
.77423 .14702 L
.7743 .14735 L
.77437 .14768 L
.77443 .148 L
.77449 .14833 L
.77454 .14866 L
.77458 .14899 L
.77461 .14931 L
.77463 .14964 L
.77465 .14997 L
.77466 .15029 L
.77467 .15062 L
.77466 .15095 L
.77465 .15128 L
.77463 .1516 L
.77461 .15193 L
.77458 .15226 L
.77454 .15259 L
.77449 .15291 L
.77443 .15324 L
.77437 .15357 L
.7743 .1539 L
.77423 .15422 L
.77414 .15455 L
.77405 .15488 L
.77395 .15521 L
.77385 .15553 L
s
.79408 .14201 m
.79426 .14258 L
.79443 .14316 L
.79459 .14373 L
.79474 .14431 L
.79487 .14488 L
.795 .14545 L
.7951 .14603 L
.7952 .1466 L
.79528 .14718 L
.79535 .14775 L
.79541 .14833 L
.79546 .1489 L
.79549 .14947 L
.79551 .15005 L
.79551 .15062 L
.79551 .1512 L
.79549 .15177 L
.79546 .15234 L
.79541 .15292 L
.79535 .15349 L
.79528 .15407 L
.7952 .15464 L
.7951 .15522 L
.795 .15579 L
.79487 .15636 L
.79474 .15694 L
.79459 .15751 L
.79443 .15809 L
.79426 .15866 L
.79408 .15924 L
s
.81431 .13831 m
.81457 .13913 L
.81482 .13995 L
.81505 .14077 L
.81526 .14159 L
.81545 .14241 L
.81562 .14323 L
.81578 .14405 L
.81591 .14487 L
.81603 .1457 L
.81613 .14652 L
.81621 .14734 L
.81628 .14816 L
.81632 .14898 L
.81635 .1498 L
.81636 .15062 L
.81635 .15144 L
.81632 .15226 L
.81628 .15309 L
.81621 .15391 L
.81613 .15473 L
.81603 .15555 L
.81591 .15637 L
.81578 .15719 L
.81562 .15801 L
.81545 .15883 L
.81526 .15965 L
.81505 .16047 L
.81482 .1613 L
.81457 .16212 L
.81431 .16294 L
s
.85091 .15027 m
.84984 .15061 L
.84877 .15093 L
.84771 .15123 L
.84664 .1515 L
.84557 .15175 L
.8445 .15198 L
.84344 .15218 L
.84237 .15236 L
.8413 .15251 L
.84023 .15264 L
.83916 .15275 L
.8381 .15283 L
.83703 .15289 L
.83596 .15293 L
.83489 .15294 L
.83382 .15293 L
.83276 .15289 L
.83169 .15283 L
.83062 .15275 L
.82955 .15264 L
.82848 .15251 L
.82742 .15236 L
.82635 .15218 L
.82528 .15198 L
.82421 .15175 L
.82314 .1515 L
.82208 .15123 L
.82101 .15093 L
.81994 .15061 L
.81887 .15027 L
s
.85461 .17049 m
.8533 .17092 L
.85198 .17131 L
.85067 .17168 L
.84935 .17202 L
.84804 .17232 L
.84672 .1726 L
.84541 .17285 L
.8441 .17307 L
.84278 .17326 L
.84147 .17342 L
.84015 .17355 L
.83884 .17365 L
.83752 .17373 L
.83621 .17377 L
.83489 .17379 L
.83358 .17377 L
.83226 .17373 L
.83095 .17365 L
.82963 .17355 L
.82832 .17342 L
.827 .17326 L
.82569 .17307 L
.82437 .17285 L
.82306 .1726 L
.82174 .17232 L
.82043 .17202 L
.81911 .17168 L
.8178 .17131 L
.81649 .17092 L
.81517 .17049 L
s
.85832 .19072 m
.85675 .19123 L
.85519 .1917 L
.85363 .19213 L
.85207 .19253 L
.85051 .1929 L
.84895 .19323 L
.84738 .19352 L
.84582 .19378 L
.84426 .19401 L
.8427 .1942 L
.84114 .19436 L
.83958 .19448 L
.83802 .19456 L
.83645 .19462 L
.83489 .19463 L
.83333 .19462 L
.83177 .19456 L
.83021 .19448 L
.82865 .19436 L
.82708 .1942 L
.82552 .19401 L
.82396 .19378 L
.8224 .19352 L
.82084 .19323 L
.81928 .1929 L
.81771 .19253 L
.81615 .19213 L
.81459 .1917 L
.81303 .19123 L
.81147 .19072 L
s
.86202 .21095 m
.86021 .21154 L
.8584 .21208 L
.85659 .21258 L
.85478 .21305 L
.85298 .21347 L
.85117 .21385 L
.84936 .21419 L
.84755 .21449 L
.84574 .21476 L
.84393 .21498 L
.84213 .21516 L
.84032 .2153 L
.83851 .2154 L
.8367 .21546 L
.83489 .21548 L
.83308 .21546 L
.83127 .2154 L
.82947 .2153 L
.82766 .21516 L
.82585 .21498 L
.82404 .21476 L
.82223 .21449 L
.82042 .21419 L
.81862 .21385 L
.81681 .21347 L
.815 .21305 L
.81319 .21258 L
.81138 .21208 L
.80957 .21154 L
.80777 .21095 L
s
.86572 .23118 m
.86367 .23185 L
.86161 .23246 L
.85956 .23304 L
.8575 .23356 L
.85544 .23404 L
.85339 .23448 L
.85133 .23486 L
.84928 .23521 L
.84722 .2355 L
.84517 .23576 L
.84311 .23596 L
.84106 .23612 L
.839 .23624 L
.83695 .2363 L
.83489 .23633 L
.83284 .2363 L
.83078 .23624 L
.82873 .23612 L
.82667 .23596 L
.82462 .23576 L
.82256 .2355 L
.8205 .23521 L
.81845 .23486 L
.81639 .23448 L
.81434 .23404 L
.81228 .23356 L
.81023 .23304 L
.80817 .23246 L
.80612 .23185 L
.80406 .23118 L
s
.86942 .25141 m
.86712 .25216 L
.86482 .25285 L
.86252 .25349 L
.86022 .25408 L
.85791 .25461 L
.85561 .2551 L
.85331 .25554 L
.85101 .25592 L
.8487 .25625 L
.8464 .25653 L
.8441 .25677 L
.8418 .25694 L
.8395 .25707 L
.83719 .25715 L
.83489 .25718 L
.83259 .25715 L
.83029 .25707 L
.82799 .25694 L
.82568 .25677 L
.82338 .25653 L
.82108 .25625 L
.81878 .25592 L
.81647 .25554 L
.81417 .2551 L
.81187 .25461 L
.80957 .25408 L
.80727 .25349 L
.80496 .25285 L
.80266 .25216 L
.80036 .25141 L
s
.87313 .27164 m
.87058 .27246 L
.86803 .27323 L
.86548 .27394 L
.86293 .27459 L
.86038 .27519 L
.85783 .27573 L
.85528 .27621 L
.85273 .27663 L
.85019 .277 L
.84764 .27731 L
.84509 .27757 L
.84254 .27777 L
.83999 .27791 L
.83744 .27799 L
.83489 .27802 L
.83234 .27799 L
.82979 .27791 L
.82724 .27777 L
.8247 .27757 L
.82215 .27731 L
.8196 .277 L
.81705 .27663 L
.8145 .27621 L
.81195 .27573 L
.8094 .27519 L
.80685 .27459 L
.8043 .27394 L
.80176 .27323 L
.79921 .27246 L
.79666 .27164 L
s
.87683 .29187 m
.87403 .29277 L
.87124 .29361 L
.86844 .29439 L
.86565 .29511 L
.86285 .29576 L
.86005 .29635 L
.85726 .29688 L
.85446 .29735 L
.85167 .29775 L
.84887 .29809 L
.84608 .29837 L
.84328 .29859 L
.84048 .29875 L
.83769 .29884 L
.83489 .29887 L
.8321 .29884 L
.8293 .29875 L
.8265 .29859 L
.82371 .29837 L
.82091 .29809 L
.81812 .29775 L
.81532 .29735 L
.81253 .29688 L
.80973 .29635 L
.80693 .29576 L
.80414 .29511 L
.80134 .29439 L
.79855 .29361 L
.79575 .29277 L
.79295 .29187 L
s
.88053 .3121 m
.87749 .31308 L
.87445 .314 L
.8714 .31484 L
.86836 .31562 L
.86532 .31633 L
.86228 .31698 L
.85923 .31755 L
.85619 .31806 L
.85315 .3185 L
.85011 .31887 L
.84706 .31918 L
.84402 .31941 L
.84098 .31958 L
.83793 .31968 L
.83489 .31972 L
.83185 .31968 L
.82881 .31958 L
.82576 .31941 L
.82272 .31918 L
.81968 .31887 L
.81664 .3185 L
.81359 .31806 L
.81055 .31755 L
.80751 .31698 L
.80447 .31633 L
.80142 .31562 L
.79838 .31484 L
.79534 .314 L
.79229 .31308 L
.78925 .3121 L
s
.88423 .33233 m
.88094 .33339 L
.87766 .33438 L
.87437 .33529 L
.87108 .33614 L
.86779 .3369 L
.8645 .3376 L
.86121 .33822 L
.85792 .33877 L
.85463 .33925 L
.85134 .33965 L
.84805 .33998 L
.84476 .34024 L
.84147 .34042 L
.83818 .34053 L
.83489 .34056 L
.8316 .34053 L
.82831 .34042 L
.82502 .34024 L
.82173 .33998 L
.81844 .33965 L
.81515 .33925 L
.81187 .33877 L
.80858 .33822 L
.80529 .3376 L
.802 .3369 L
.79871 .33614 L
.79542 .33529 L
.79213 .33438 L
.78884 .33339 L
.78555 .33233 L
s
.88794 .35256 m
.8844 .3537 L
.88086 .35476 L
.87733 .35575 L
.87379 .35665 L
.87026 .35748 L
.86672 .35822 L
.86318 .35889 L
.85965 .35948 L
.85611 .36 L
.85257 .36043 L
.84904 .36078 L
.8455 .36106 L
.84196 .36125 L
.83843 .36137 L
.83489 .36141 L
.83136 .36137 L
.82782 .36125 L
.82428 .36106 L
.82075 .36078 L
.81721 .36043 L
.81367 .36 L
.81014 .35948 L
.8066 .35889 L
.80306 .35822 L
.79953 .35748 L
.79599 .35665 L
.79246 .35575 L
.78892 .35476 L
.78538 .3537 L
.78185 .35256 L
s
0 0 m
1 0 L
1 .39158 L
0 .39158 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{288, 112.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000L2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00DOooool6o`000<Wooooo001B
ooooo`05o`000?ooooooooooooooool00000bOooool005;ooooo00?o0000ooooooooool0boooool0
05;ooooo00?o0000ooooooooool0boooool005;ooooo00?o0000ooooooooool0boooool005;ooooo
00?o0000ooooooooool0boooool0057ooooo0ol0003<ooooo`00oooooolQooooo`00oooooolQoooo
o`00E_ooool5o`000<Gooooo001Fooooo`Go0000aOooool005Gooooo0_l00003ogmoO`03o`000?oo
oooooooo0<?ooooo001Eooooo`;o00000omoOgl00ol0003oooooooooo`33ooooo`00E?ooool00ol0
003oOgmoo`000004o`000<Gooooo0012ooooo`co2NX:1_ooool00ol0003oOgmoo`000003ogmoO`03
o`000?oooooooooo0<?ooooo000@oooooc;o2NX:3?ooool8o`WZ2P05o`000?moOgooOgmoogmoOol0
0000aOooool005?ooooo00?o0000ogmoOomoOgl01ol9jP[3ooooo`004?ooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool01Ol0003oOgmoogmo
OomoOgoo000000?oOgmo00?o0000ooooooooool01?l9jPZoooooo`004?ooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool01?l0003oOgmoo`WZ
2_moOgl4o`000003o`WZ2_oooooooooo00Cooooo1ol9jPZhooooo`004?ooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00Go2NX:ooooooooooooooooo`000002ogmoO`03o`WZ
2_moOgoo000000?oOgmo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`Co2NX:
]?ooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`05o`WZ2_oo
ooooooooooooool000000_moOgl00ol9jP[oOgmoo`000003ogmoO`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`Oo2NX:[Oooool0013ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`05o`WZ2_ooooooooooooooool00000
0_moOgl00ol9jP[oOgmoo`000002ogmoO`03o`WZ2_l0003ooooo00Gooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo1?l9jPZYooooo`004?oo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00Co2NX:oooooooooooo0000
0omoOgl00ol9jP[oOgmoo`000002ogmoO`03o`WZ2_l0003ooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0oooool4o`WZ2ZGooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00ooo
ool01?l9jP[oooooooooool00002ogmoO`04o`WZ2_moOgooOgmoo`0000;oOgmo00?o2NX:o`000?oo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`04o`WZ2_ooooooooooooooo`Oo2NX:W_ooool0013o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`04o`WZ2_ooooooooooo`00
00;oOgmo00?o2NX:ogmoOomoOgl00ol000000ol9jP[o0000ooooo`04ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`Co2NX:DOooool3o`00
0003ooooool0003ooooo00?o0000@?ooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`04o`WZ2_ooooooooooo`0000;oOgmo00Co2NX:ogmoOomoOgoo00000_moOgl0
0ol9jP[o0000ooooo`04ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`03ooooo`04o`WZ2_ooooooooooooooo`Co2NX:C_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo03oooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool01?l9jP[oooooooooool00002ogmoO`04o`WZ2_moOgooOgmoo`0000;o
Ogmo00?o2NX:o`000?ooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Oo
2NX:Aoooool01ol0003oooooo`000?oooooo0000ooooool00000@Oooool0013ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo000000?oOgmo00Co2NX:ogmo
OomoOgoo00000_moOgl00ol9jP[o0000ooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`Co2NX:@oooool01ol0003oooooo`000?oo
oooo0000ooooool00000@Oooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooo000000?oOgmo00Co2NX:ogmoOomoOgoo00000_moOgl00ol9jP[o0000
ooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Co2NX:?oooool2o`0000?ooooo0_l00011ooooo`004?oo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooool000000omo
Ogl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_l0003ooooo00?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooo`WZ2P06o`WZ2SSooooo0_l00003ooooo`;o0000@Oooool0013ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo000000?oOgmo00Co
2NX:ogmoOomoOgoo00000_moOgl00ol9jP[o0000ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04o`WZ2S?ooooo0_l00005ooooo`;o0000
@?ooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooo000000?oOgmo00So2NX:ogmoOomoOgoo0000ogmoOol9jP[oOgmoo`0000?ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`02ooooo`;o2NX:1?ooool00ol9jP[oooooo`WZ2P06o`WZ
2SGooooo00?o0000ooooooooool0?Oooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooo000000?oOgmo00?o2NX:ogmoOomoOgl00_l000000ol9jP[o
0000o`000003ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_ooool2o`WZ2P;ooooo1?l9jPXbooooo`03o`000?oooooooooo03co
oooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
o`000003ogmoO`08o`WZ2_moOgooOgmoo`000?moOgoo2NX:ogmoOol00003ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`;o2NX:1?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo2NX:00?o2NX:;oooool00ol0003oooooooooo`0k
ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ool000000omoOgl02?l9jP[oOgmoogmoOol0003oOgmoo`WZ2_moOgoo00000oooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool8o`WZ2RWooooo
00?o0000ooooooooool0>_ooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_l0003oOgmo00?oOgmo00So2NX:ogmoOomoOgoo0000ogmoOol9jP[oOgmoo`00
00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooo`WZ2P03o`WZ2RKooooo00Co0000oooo
ool9jP[o2NX:>?ooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_l0003oOgmo00?oOgmo00So2NX:ogmoOomoOgoo0000ogmoOol9jP[oOgmoo`0000?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool2o`WZ2PCooooo1?l9jPXQooooo`Co2NX:0_ooool00ol9jP[ooooo
ooooo`0eooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:o`000?moOgl00omoOgl02?l9jP[oOgmoogmoOol0003oOgmoo`WZ2_moOgoo00000oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00Co2NX:oooooooooooooooo2?l9jPXA
ooooo`So2NX:00Goooooo`WZ2_ooooooooooo`000002ooooo`03o`WZ2_oooooooooo03Cooooo000@
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`07o`WZ2_ooooooooooooooool0003o2NX:o`000004ooooo`03o`WZ2_l0003oOgmo00;oOgmo
00Wo0000o`WZ2_l0003oOgmoo`000?moOgoo2NX:ogmoOol000000oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool2o`WZ2PCooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo1Ol9jPX:
ooooo`?o2NX:1?ooool00ol9jP[oooooooooo`02o`0000;o2NX:0_ooool01?l0003oooooooooool9
jPXeooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_l0003o000000?o000000?o2NX:
o`000?moOgl00omoOgl00ol9jP[o0000o`000002o`000003o`WZ2_moOgoo000000?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`?o2NX:0oooool4o`WZ2P03ooooool9jP[o
oooo00Cooooo00Co2NX:oooooooooooooooo0_l000000ol9jP[o0000o`000003o`000004ooooool9
jP[oooooo`WZ2S;ooooo000@ooooo`03o`WZ2_l0003o000000;o000000?o2NX:o`000?l000000ol0
00000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000000ol0
00000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000000_l0
00000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000;o000000?o2NX:o`000?l000000ol0
00000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000;o000000?o2NX:o`000?l000000ol0
00000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000000ol0
00000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000000_l0
00000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000;o000000?o2NX:o`000?l000000ol0
00000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000;o000000?o2NX:o`000?l000000ol0
00000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000000_l0
00000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000000_l0
00000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000;o000000?o2NX:o`000?l000000ol0
00000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000000ol0
000:o`WZ2S;ooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:o`000?l000000_l00000
0ooooooo2NX:o`000004ogmoO`03o`WZ2_l0003o000000;o000000?o2NX:ogmoOol000000oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool2
o`WZ2PCooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo1?l9jPX<ooooo`?o2NX:0oooool01Ol9jP[ooooooooooooooooo000000;o2NX:0_l0
0002ooooo`;o00000_ooool00ol9jP[oooooooooo`0`ooooo`004?ooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool01_l9jP[ooooooooooooo
oooo0000o`WZ2PGooooo00?o2NX:o`000?moOgl00_moOgl02Ol0003o2NX:ogmoOomoOgoo0000ogmo
Ool9jP[oOgmoo`000003ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`08o`WZ2Q?ooooo1_l9jPX2o`0000;o2NX:1?ooool00ol0003oooooo`000002
ooooo`03o`WZ2_oooooooooo02oooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[o0000ogmoO`03ogmoO`08o`WZ2_moOgooOgmoo`000?moOgoo2NX:ogmo
Ool00003ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool2o`WZ2PCooooo0ol9jPXSooooo`Co2NX:0_ooool01_l0003ooooo
ooooool0003oooooo`WZ2S7ooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[o0000ogmoO`03ogmoO`08o`WZ2_moOgooOgmoo`000?moOgoo2NX:ogmoOol0
0003ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00?ooooo1Ol9jPXVooooo`07o`WZ2_ooooooooooooooool9jP[o
ooooo`000003ooooo`03o`000?l9jP[ooooo033ooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[o0000ogmoO`03ogmoO`08o`WZ2_moOgooOgmoo`000?mo
Ogoo2NX:ogmoOol00003ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`Oo2NX::_ooool4o`WZ2P;ooooo00?o0000ooooool9jPX00ol9jPXa
ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ool000000omoOgl02?l9jP[oOgmoogmoOol0003oOgmoo`WZ2_moOgoo00000oooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool2o`WZ2PCooooo
00?o2NX:ooooooooool00oooool5o`WZ2S7ooooo00?o2NX:ooooooooool01_l9jPX2ooooo`03o`WZ
2_l0003ooooo02oooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooo`000003ogmoO`08o`WZ2_moOgooOgmoo`000?moOgoo2NX:ogmoOol00003oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00;ooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00_ooool2o`WZ2P03ooooool9jP[o2NX:00;o2NX:=Oooool00ol9jP[oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o2NX:ooooool00000;oooool0013ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo000000?oOgmo00?o2NX:ogmoOomo
Ogl00_l000000ol9jP[o0000o`000003ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool2o`WZ2PCooooo2?l9jPXhooooo`03o`WZ2_oooooooooo00Cooooo00?o0000oooooooo
ool00oooool01?l9jP[oooooo`000?l0000]ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooool000000omoOgl02?l9jP[oOgmoogmoOol0003oOgmo
o`WZ2_moOgoo00001?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooool9jPX00ol9jPXoooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol9jP[oooooooooo`0^ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooool000000omoOgl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_l0
003ooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo0_l9jPX4ooooo`04o`WZ2_ooooooooooooooo`Co2NX:@oooool2o`WZ2PGooooo
00?o0000ooooooooool00_ooool2o`WZ2S3ooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooo`000003ogmoO`04o`WZ2_moOgooOgmoo`0000;oOgmo
00?o2NX:o`000?ooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooo`WZ2P06o`WZ2TOooooo3_l9jPX`ooooo`004?oo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooool000000omo
Ogl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_l0003ooooo00?ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`02ooooo`04o`WZ2_ooooooooooooooo`Co2NX:COooool00ol9jP[o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o2NX:ooooooooool0;Oooool0013ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`04o`WZ2_ooooooooooo`0000;o
Ogmo00Co2NX:ogmoOomoOgoo00000_moOgl00ol9jP[o0000ooooo`03ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooool9jPX01_l9jPYAooooo`03o`WZ2_oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol9jP[oooooooooo`0]ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00?ooooo00Co2NX:oooooooooooo00000_moOgl01?l9jP[oOgmoogmoOol00002
ogmoO`03o`WZ2_l0003ooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?l9jPYHooooo`03o`WZ2_oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol9jP[oooooooooo`0]ooooo`004?ooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00Co2NX:oooooooooooo00000_moOgl0
0ol9jP[oOgmoogmoO`03o`000003o`WZ2_l0003ooooo00Cooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo1?l9jPYLooooo`03o`WZ2_oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol9jP[oooooooooo`0]ooooo`004?ooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00Co2NX:oooooooooooo00000_moOgl0
1?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_l0003ooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`07o`WZ2V3ooooo1?l9jPX4ooooo`04o`000?ooooooooooooooo`Go2NX:
;_ooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`04o`WZ2_oo
ooooooooo`0000?oOgmo00?o2NX:ogmoOol000000_moOgl00ol9jP[o0000ooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00;ooooo1?l9jPYWooooo`04o`WZ2_ooooooooooooooo`So2NX:1?ooool00ol9jP[o
ooooooooo`0/ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00Go2NX:ooooooooooooooooo`000002ogmoO`03o`WZ2_moOgoo000000;oOgmo00?o2NX:o`000?oo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00oooool4o`WZ2V_ooooo00?o2NX:ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`WZ2_oooooooooo02cooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0oooool01Ol9jP[ooooooooooooooooo000000;oOgmo00?o2NX:ogmoOol000000omoOgl00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00Co2NX:oooooooooooooooo1ol9jPY_oooo
o`03o`WZ2_oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol9jP[oooooooooo`0/oooo
o`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00Go2NX:oooooooo
ooooooooo`000002ogmoO`03o`WZ2_moOgoo000000?oOgmo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`Co2NX:MOooool00ol9jP[oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o2NX:ooooooooool0;?ooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`05o`WZ2_ooooooooooooooool000000_moOgl00ol9jP[oOgmoo`000003o`00
0003o`WZ2_oooooooooo00Oooooo0ol9jPYiooooo`;o2NX:1oooool00ol0003oooooooooo`04oooo
o`;o2NX:;_ooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00;ooooo00Go0000ogmoOol9jP[oOgmoo`000003ogmoO`03o`000?oooooo2NX:
00Oo2NX:O?ooool00ol9jP[oooooo`WZ2P0=o`WZ2P03ooooool9jP[ooooo02gooooo001Booooo`06
o`000?moOgooOgmoogmoOol0003oOgmo1?l9jPZ3ooooo`03o`WZ2_oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol9jP[oooooooooo`0[ooooo`004?oooolTo`WZ2QWooooo2ol9jPX2ogmo
O`03o`000?oooooooooo08;ooooo00?o2NX:ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`WZ2_oooooooooo02_ooooo000doooooaWo2NX:1_ooool01?l0003oOgmoogmoOol00003ogmo
O`03o`000?oooooooooo08;ooooo00?o2NX:ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`WZ2_oooooooooo02_ooooo001Dooooo`03o`000?moOgoo000000Co0000Q?ooool00ol9jP[o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o2NX:ooooooooool0:oooool005Cooooo
00?o0000ogmoOol000000omoOgl00ol0003oooooooooo`21ooooo`03o`WZ2_oooooo2NX:00?o2NX:
1Oooool00ol0003oooooooooo`02ooooo`Co2NX:00?oooooo`WZ2_ooool0:oooool005Cooooo00?o
0000ogmoOol000000omoOgl00ol0003oooooooooo`21ooooo`03o`WZ2_oooooooooo00?ooooo2ol9
jPX4ooooo`03o`WZ2_oooooooooo02[ooooo001Eooooo`Ko0000Poooool00ol9jP[oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o2NX:ooooooooool0:_ooool005Gooooo0_l00003ogmo
O`03o`000?oooooooooo087ooooo00?o2NX:ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`WZ2_oooooooooo02[ooooo001Fooooo`Go0000Poooool00ol9jP[oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o2NX:ooooooooool0:Oooool00=kooooo0ol9jPX8ooooo`03o`00
0?oooooooooo00Gooooo1?l9jPX[ooooo`00g_ooool00ol9jP[oooooo`WZ2P06o`WZ2P;ooooo00?o
0000ooooool9jPX01_l9jPX2ooooo`03o`WZ2_oooooooooo02Wooooo003Mooooo`03o`WZ2_oooooo
oooo00Oooooo1Ol9jPX8ooooo`03o`WZ2_oooooooooo02Wooooo003Mooooo`03o`WZ2_oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol9jP[oooooooooo`0Yooooo`00gOooool00ol9jP[o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o2NX:ooooooooool0:Oooool00=gooooo
00?o2NX:ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`WZ2_oooooooooo02Wooooo
003Looooo`03o`WZ2_oooooo2NX:00?o2NX:1oooool00ol0003oooooooooo`04ooooo`Co2NX:00?o
ooooo`WZ2_ooool0:Oooool00=cooooo00?o2NX:ooooooooool00oooool>o`WZ2PGooooo00?o2NX:
ooooooooool0:?ooool00=cooooo00?o2NX:ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`WZ2_oooooooooo02Sooooo003Looooo`03o`WZ2_oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol9jP[oooooooooo`0Xooooo`00foooool00ol9jP[oooooooooo`0;ooooo`03o`00
0?oooooooooo00[ooooo00?o2NX:ooooooooool09oooool00=_ooooo1Ol9jPX9ooooo`03o`000?oo
oooooooo00Kooooo1Ol9jPXYooooo`00foooool00ol9jP[oooooooooo`02ooooo`Go2NX:1?ooool0
1?l0003oooooooooooooool6o`WZ2P?ooooo00?o2NX:ooooooooool09oooool00=_ooooo00?o2NX:
ooooooooool01oooool9o`WZ2PSooooo00?o2NX:ooooooooool09oooool00=_ooooo00?o2NX:oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`WZ2_oooooooooo02Kooooo003Kooooo`03
o`WZ2_oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol9jP[oooooooooo`0Vooooo`00
foooool2o`WZ2Pcooooo00?o0000ooooooooool02Oooool3o`WZ2RSooooo003Jooooo`03o`WZ2_oo
oooooooo00Co2NX:2?ooool00ol0003oooooooooo`05ooooo`Co2NX:0_ooool00ol9jP[ooooooooo
o`0Vooooo`00f_ooool00ol9jP[oooooooooo`04oooooa3o2NX:1_ooool00ol9jP[oooooooooo`0V
ooooo`00f_ooool00ol9jP[oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o2NX:oooo
ooooool09_ooool00=[ooooo00?o2NX:ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`WZ2_oooooooooo02Kooooo003Iooooo`03o`WZ2_oooooooooo00_ooooo00Go0000ooooool0003o
ooooo`00000<ooooo`03o`WZ2_oooooooooo02Gooooo003Iooooo`Go2NX:2Oooool5o`0000Sooooo
1Ol9jPXWooooo`00fOooool00ol9jP[oooooooooo`02ooooo`Go2NX:1?ooool5o`0000?ooooo1Ol9
jPX4ooooo`03o`WZ2_oooooooooo02Gooooo003Iooooo`03o`WZ2_oooooooooo00Oooooo3?l9jPX9
ooooo`03o`WZ2_oooooooooo02Gooooo003Hooooo`03o`WZ2_oooooooooo00gooooo0ol0000>oooo
o`03o`WZ2_oooooooooo02Cooooo003Hooooo`03o`WZ2_oooooooooo00gooooo0ol0000>ooooo`03
o`WZ2_oooooooooo02Cooooo003Hooooo`03o`WZ2_oooooooooo00gooooo0ol0000>ooooo`03o`WZ
2_oooooooooo017ooooo0ol0000@ooooo`00f?ooool00ol9jP[oooooooooo`0>ooooo`03o`000?oo
oooooooo00gooooo00?o2NX:ooooooooool04Oooool01?l0003oooooooooool0000?ooooo`00b_oo
ool>o`000003o`WZ2_l0003o000001ko000000?o2NX:o`000?l000003Ol00007ooooo`03o`000?oo
oooooooo00gooooo003oooooo`oooooo0_l0000@ooooo`00ooooool>ooooo`03o`000?oooooooooo
013ooooo003oooooo`kooooo00Co0000oooooooooooo00003oooool00?oooooo3oooool3o`0000oo
oooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {111.75, 0}} -> {-13.0976, -35.3434, 0.807035, \
0.807035}},
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[opticalsystemreflected,PlotType->TopView,ShowGaussian->True];\
\>", "Input",
  CellLabel->"In[34]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .39159 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0241622 0.00463272 0.150626 0.00463272 [
[.27896 .00932 -5.03125 -6 ]
[.27896 .00932 5.03125 6 ]
[.78411 .09985 -6.4375 -6 ]
[.78411 .09985 6.4375 6 ]
[.97619 .38226 -4.75 -6 ]
[.97619 .38226 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .39159 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.2855 .03481 m
.30213 .03481 L
.30213 .07341 L
.26852 .07341 L
.2855 .03481 L
F
.26852 .07341 m
.30213 .07341 L
.30213 .11202 L
.25891 .11202 L
.26852 .07341 L
F
.25891 .11202 m
.30213 .11202 L
.30213 .15063 L
.2558 .15063 L
.25891 .11202 L
F
.2558 .15063 m
.30213 .15063 L
.30213 .18923 L
.25891 .18923 L
.2558 .15063 L
F
.25891 .18923 m
.30213 .18923 L
.30213 .22784 L
.26852 .22784 L
.25891 .18923 L
F
.26852 .22784 m
.30213 .22784 L
.30213 .26644 L
.2855 .26644 L
.26852 .22784 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.2855 .03481 m
.26852 .07341 L
.25891 .11202 L
.2558 .15063 L
.25891 .18923 L
.26852 .22784 L
.2855 .26644 L
.30213 .26644 L
.30213 .22784 L
.30213 .18923 L
.30213 .15063 L
.30213 .11202 L
.30213 .07341 L
.30213 .03481 L
.2855 .03481 L
s
.5 g
.2855 .15063 m
.30213 .15063 L
.30213 .15063 L
.26852 .15063 L
.2855 .15063 L
F
.26852 .15063 m
.30213 .15063 L
.30213 .15063 L
.25891 .15063 L
.26852 .15063 L
F
.25891 .15063 m
.30213 .15063 L
.30213 .15063 L
.2558 .15063 L
.25891 .15063 L
F
.2558 .15063 m
.30213 .15063 L
.30213 .15063 L
.25891 .15063 L
.2558 .15063 L
F
.25891 .15063 m
.30213 .15063 L
.30213 .15063 L
.26852 .15063 L
.25891 .15063 L
F
.26852 .15063 m
.30213 .15063 L
.30213 .15063 L
.2855 .15063 L
.26852 .15063 L
F
0 g
.2855 .15063 m
.26852 .15063 L
.25891 .15063 L
.2558 .15063 L
.25891 .15063 L
.26852 .15063 L
.2855 .15063 L
.30213 .15063 L
.30213 .15063 L
.30213 .15063 L
.30213 .15063 L
.30213 .15063 L
.30213 .15063 L
.30213 .15063 L
.2855 .15063 L
s
.2855 .26644 m
.30213 .26644 L
.30213 .2625 L
.2855 .2625 L
.2855 .26644 L
s
.2855 .2625 m
.30213 .2625 L
.30213 .25093 L
.2855 .25093 L
.2855 .2625 L
s
.2855 .25093 m
.30213 .25093 L
.30213 .23252 L
.2855 .23252 L
.2855 .25093 L
s
.2855 .23252 m
.30213 .23252 L
.30213 .20853 L
.2855 .20853 L
.2855 .23252 L
s
.2855 .20853 m
.30213 .20853 L
.30213 .1806 L
.2855 .1806 L
.2855 .20853 L
s
.2855 .1806 m
.30213 .1806 L
.30213 .15063 L
.2855 .15063 L
.2855 .1806 L
s
.2855 .15063 m
.30213 .15063 L
.30213 .12065 L
.2855 .12065 L
.2855 .15063 L
s
.2855 .12065 m
.30213 .12065 L
.30213 .09272 L
.2855 .09272 L
.2855 .12065 L
s
.2855 .09272 m
.30213 .09272 L
.30213 .06873 L
.2855 .06873 L
.2855 .09272 L
s
.2855 .06873 m
.30213 .06873 L
.30213 .05032 L
.2855 .05032 L
.2855 .06873 L
s
.2855 .05032 m
.30213 .05032 L
.30213 .03875 L
.2855 .03875 L
.2855 .05032 L
s
.2855 .03875 m
.30213 .03875 L
.30213 .03481 L
.2855 .03481 L
.2855 .03875 L
s
.2855 .03481 m
.30213 .03481 L
.30213 .03875 L
.2855 .03875 L
.2855 .03481 L
s
.2855 .03875 m
.30213 .03875 L
.30213 .05032 L
.2855 .05032 L
.2855 .03875 L
s
.2855 .05032 m
.30213 .05032 L
.30213 .06873 L
.2855 .06873 L
.2855 .05032 L
s
.2855 .06873 m
.30213 .06873 L
.30213 .09272 L
.2855 .09272 L
.2855 .06873 L
s
.2855 .09272 m
.30213 .09272 L
.30213 .12065 L
.2855 .12065 L
.2855 .09272 L
s
.2855 .12065 m
.30213 .12065 L
.30213 .15063 L
.2855 .15063 L
.2855 .12065 L
s
.2855 .15063 m
.30213 .15063 L
.30213 .1806 L
.2855 .1806 L
.2855 .15063 L
s
.2855 .1806 m
.30213 .1806 L
.30213 .20853 L
.2855 .20853 L
.2855 .1806 L
s
.2855 .20853 m
.30213 .20853 L
.30213 .23252 L
.2855 .23252 L
.2855 .20853 L
s
.2855 .23252 m
.30213 .23252 L
.30213 .25093 L
.2855 .25093 L
.2855 .23252 L
s
.2855 .25093 m
.30213 .25093 L
.30213 .2625 L
.2855 .2625 L
.2855 .25093 L
s
.2855 .2625 m
.30213 .2625 L
.30213 .26644 L
.2855 .26644 L
.2855 .2625 L
s
.5 g
.80213 .11787 m
.80213 .11787 L
.81305 .12879 L
.81305 .12879 L
.80213 .11787 L
F
.81305 .12879 m
.81305 .12879 L
.82397 .13971 L
.82397 .13971 L
.81305 .12879 L
F
.82397 .13971 m
.82397 .13971 L
.83489 .15063 L
.83489 .15063 L
.82397 .13971 L
F
.83489 .15063 m
.83489 .15063 L
.84581 .16155 L
.84581 .16155 L
.83489 .15063 L
F
.84581 .16155 m
.84581 .16155 L
.85673 .17246 L
.85673 .17246 L
.84581 .16155 L
F
.85673 .17246 m
.85673 .17246 L
.86765 .18338 L
.86765 .18338 L
.85673 .17246 L
F
0 g
.80213 .11787 m
.81305 .12879 L
.82397 .13971 L
.83489 .15063 L
.84581 .16155 L
.85673 .17246 L
.86765 .18338 L
.86765 .18338 L
.85673 .17246 L
.84581 .16155 L
.83489 .15063 L
.82397 .13971 L
.81305 .12879 L
.80213 .11787 L
.80213 .11787 L
s
.5 g
.83489 .15063 m
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
F
.83489 .15063 m
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
F
.83489 .15063 m
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
F
.83489 .15063 m
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
F
.83489 .15063 m
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
F
.83489 .15063 m
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
F
0 g
.83489 .15063 m
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
s
.5 g
.83489 .15063 m
.84581 .16155 L
.84544 .16117 L
.83489 .15063 L
.83489 .15063 L
F
.84581 .16155 m
.85673 .17246 L
.85598 .17172 L
.84544 .16117 L
.84581 .16155 L
F
.85673 .17246 m
.86765 .18338 L
.86653 .18227 L
.85598 .17172 L
.85673 .17246 L
F
.83489 .15063 m
.84544 .16117 L
.84434 .16008 L
.83489 .15063 L
.83489 .15063 L
F
.84544 .16117 m
.85598 .17172 L
.8538 .16954 L
.84434 .16008 L
.84544 .16117 L
F
.85598 .17172 m
.86653 .18227 L
.86326 .179 L
.8538 .16954 L
.85598 .17172 L
F
.83489 .15063 m
.84434 .16008 L
.84261 .15835 L
.83489 .15063 L
.83489 .15063 L
F
.84434 .16008 m
.8538 .16954 L
.85033 .16607 L
.84261 .15835 L
.84434 .16008 L
F
.8538 .16954 m
.86326 .179 L
.85805 .17379 L
.85033 .16607 L
.8538 .16954 L
F
.83489 .15063 m
.84261 .15835 L
.84035 .15609 L
.83489 .15063 L
.83489 .15063 L
F
.84261 .15835 m
.85033 .16607 L
.84581 .16155 L
.84035 .15609 L
.84261 .15835 L
F
.85033 .16607 m
.85805 .17379 L
.85127 .16701 L
.84581 .16155 L
.85033 .16607 L
F
.83489 .15063 m
.84035 .15609 L
.83771 .15345 L
.83489 .15063 L
.83489 .15063 L
F
.84035 .15609 m
.84581 .16155 L
.84054 .15628 L
.83771 .15345 L
.84035 .15609 L
F
.84581 .16155 m
.85127 .16701 L
.84337 .1591 L
.84054 .15628 L
.84581 .16155 L
F
.83489 .15063 m
.83771 .15345 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
F
.83771 .15345 m
.84054 .15628 L
.83489 .15063 L
.83489 .15063 L
.83771 .15345 L
F
.84054 .15628 m
.84337 .1591 L
.83489 .15063 L
.83489 .15063 L
.84054 .15628 L
F
.83489 .15063 m
.83489 .15063 L
.83206 .1478 L
.83489 .15063 L
.83489 .15063 L
F
.83489 .15063 m
.83489 .15063 L
.82924 .14497 L
.83206 .1478 L
.83489 .15063 L
F
.83489 .15063 m
.83489 .15063 L
.82641 .14215 L
.82924 .14497 L
.83489 .15063 L
F
.83489 .15063 m
.83206 .1478 L
.82943 .14517 L
.83489 .15063 L
.83489 .15063 L
F
.83206 .1478 m
.82924 .14497 L
.82397 .13971 L
.82943 .14517 L
.83206 .1478 L
F
.82924 .14497 m
.82641 .14215 L
.81851 .13425 L
.82397 .13971 L
.82924 .14497 L
F
.83489 .15063 m
.82943 .14517 L
.82717 .1429 L
.83489 .15063 L
.83489 .15063 L
F
.82943 .14517 m
.82397 .13971 L
.81945 .13518 L
.82717 .1429 L
.82943 .14517 L
F
.82397 .13971 m
.81851 .13425 L
.81172 .12746 L
.81945 .13518 L
.82397 .13971 L
F
.83489 .15063 m
.82717 .1429 L
.82543 .14117 L
.83489 .15063 L
.83489 .15063 L
F
.82717 .1429 m
.81945 .13518 L
.81597 .13171 L
.82543 .14117 L
.82717 .1429 L
F
.81945 .13518 m
.81172 .12746 L
.80652 .12226 L
.81597 .13171 L
.81945 .13518 L
F
.83489 .15063 m
.82543 .14117 L
.82434 .14008 L
.83489 .15063 L
.83489 .15063 L
F
.82543 .14117 m
.81597 .13171 L
.81379 .12953 L
.82434 .14008 L
.82543 .14117 L
F
.81597 .13171 m
.80652 .12226 L
.80325 .11898 L
.81379 .12953 L
.81597 .13171 L
F
.83489 .15063 m
.82434 .14008 L
.82397 .13971 L
.83489 .15063 L
.83489 .15063 L
F
.82434 .14008 m
.81379 .12953 L
.81305 .12879 L
.82397 .13971 L
.82434 .14008 L
F
.81379 .12953 m
.80325 .11898 L
.80213 .11787 L
.81305 .12879 L
.81379 .12953 L
F
.83489 .15063 m
.82397 .13971 L
.82434 .14008 L
.83489 .15063 L
.83489 .15063 L
F
.82397 .13971 m
.81305 .12879 L
.81379 .12953 L
.82434 .14008 L
.82397 .13971 L
F
.81305 .12879 m
.80213 .11787 L
.80325 .11898 L
.81379 .12953 L
.81305 .12879 L
F
.83489 .15063 m
.82434 .14008 L
.82543 .14117 L
.83489 .15063 L
.83489 .15063 L
F
.82434 .14008 m
.81379 .12953 L
.81597 .13171 L
.82543 .14117 L
.82434 .14008 L
F
.81379 .12953 m
.80325 .11898 L
.80652 .12226 L
.81597 .13171 L
.81379 .12953 L
F
.83489 .15063 m
.82543 .14117 L
.82717 .1429 L
.83489 .15063 L
.83489 .15063 L
F
.82543 .14117 m
.81597 .13171 L
.81945 .13518 L
.82717 .1429 L
.82543 .14117 L
F
.81597 .13171 m
.80652 .12226 L
.81172 .12746 L
.81945 .13518 L
.81597 .13171 L
F
.83489 .15063 m
.82717 .1429 L
.82943 .14517 L
.83489 .15063 L
.83489 .15063 L
F
.82717 .1429 m
.81945 .13518 L
.82397 .13971 L
.82943 .14517 L
.82717 .1429 L
F
.81945 .13518 m
.81172 .12746 L
.81851 .13425 L
.82397 .13971 L
.81945 .13518 L
F
.83489 .15063 m
.82943 .14517 L
.83206 .1478 L
.83489 .15063 L
.83489 .15063 L
F
.82943 .14517 m
.82397 .13971 L
.82924 .14497 L
.83206 .1478 L
.82943 .14517 L
F
.82397 .13971 m
.81851 .13425 L
.82641 .14215 L
.82924 .14497 L
.82397 .13971 L
F
.83489 .15063 m
.83206 .1478 L
.83489 .15063 L
.83489 .15063 L
.83489 .15063 L
F
.83206 .1478 m
.82924 .14497 L
.83489 .15063 L
.83489 .15063 L
.83206 .1478 L
F
.82924 .14497 m
.82641 .14215 L
.83489 .15063 L
.83489 .15063 L
.82924 .14497 L
F
.83489 .15063 m
.83489 .15063 L
.83771 .15345 L
.83489 .15063 L
.83489 .15063 L
F
.83489 .15063 m
.83489 .15063 L
.84054 .15628 L
.83771 .15345 L
.83489 .15063 L
F
.83489 .15063 m
.83489 .15063 L
.84337 .1591 L
.84054 .15628 L
.83489 .15063 L
F
.83489 .15063 m
.83771 .15345 L
.84035 .15609 L
.83489 .15063 L
.83489 .15063 L
F
.83771 .15345 m
.84054 .15628 L
.84581 .16155 L
.84035 .15609 L
.83771 .15345 L
F
.84054 .15628 m
.84337 .1591 L
.85127 .16701 L
.84581 .16155 L
.84054 .15628 L
F
.83489 .15063 m
.84035 .15609 L
.84261 .15835 L
.83489 .15063 L
.83489 .15063 L
F
.84035 .15609 m
.84581 .16155 L
.85033 .16607 L
.84261 .15835 L
.84035 .15609 L
F
.84581 .16155 m
.85127 .16701 L
.85805 .17379 L
.85033 .16607 L
.84581 .16155 L
F
.83489 .15063 m
.84261 .15835 L
.84434 .16008 L
.83489 .15063 L
.83489 .15063 L
F
.84261 .15835 m
.85033 .16607 L
.8538 .16954 L
.84434 .16008 L
.84261 .15835 L
F
.85033 .16607 m
.85805 .17379 L
.86326 .179 L
.8538 .16954 L
.85033 .16607 L
F
.83489 .15063 m
.84434 .16008 L
.84544 .16117 L
.83489 .15063 L
.83489 .15063 L
F
.84434 .16008 m
.8538 .16954 L
.85598 .17172 L
.84544 .16117 L
.84434 .16008 L
F
.8538 .16954 m
.86326 .179 L
.86653 .18227 L
.85598 .17172 L
.8538 .16954 L
F
.83489 .15063 m
.84544 .16117 L
.84581 .16155 L
.83489 .15063 L
.83489 .15063 L
F
.84544 .16117 m
.85598 .17172 L
.85673 .17246 L
.84581 .16155 L
.84544 .16117 L
F
.85598 .17172 m
.86653 .18227 L
.86765 .18338 L
.85673 .17246 L
.85598 .17172 L
F
0 g
.86765 .18338 m
.86653 .18227 L
.86326 .179 L
.85805 .17379 L
.85127 .16701 L
.84337 .1591 L
.83489 .15063 L
.82641 .14215 L
.81851 .13425 L
.81172 .12746 L
.80652 .12226 L
.80325 .11898 L
.80213 .11787 L
.80325 .11898 L
.80652 .12226 L
.81172 .12746 L
.81851 .13425 L
.82641 .14215 L
.83489 .15063 L
.84337 .1591 L
.85127 .16701 L
.85805 .17379 L
.86326 .179 L
.86653 .18227 L
.86765 .18338 L
s
.95071 .38226 m
.9121 .38226 L
.87349 .38226 L
.83489 .38226 L
.79628 .38226 L
.75768 .38226 L
.71907 .38226 L
.71907 .38226 L
.75768 .38226 L
.79628 .38226 L
.83489 .38226 L
.87349 .38226 L
.9121 .38226 L
.95071 .38226 L
.95071 .38226 L
s
.83489 .38226 m
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
.83489 .38226 L
s
.71907 .38226 m
.72302 .38226 L
.73459 .38226 L
.75299 .38226 L
.77698 .38226 L
.80491 .38226 L
.83489 .38226 L
.86486 .38226 L
.8928 .38226 L
.91678 .38226 L
.93519 .38226 L
.94676 .38226 L
.95071 .38226 L
.94676 .38226 L
.93519 .38226 L
.91678 .38226 L
.8928 .38226 L
.86486 .38226 L
.83489 .38226 L
.80491 .38226 L
.77698 .38226 L
.75299 .38226 L
.73459 .38226 L
.72302 .38226 L
.71907 .38226 L
s
.039 .916 .04 r
.02393 .05797 m
.27488 .05672 L
s
% Start of user PostScript
-0.049999 -19.9998 54.1182 -20.2706 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.27488 .05672 Mdot
.039 .916 .04 r
.5 Mabswid
.02408 .09503 m
.26248 .09432 L
s
% Start of user PostScript
-0.0179999 -11.9999 51.4419 -12.1543 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.26248 .09432 Mdot
.039 .916 .04 r
.5 Mabswid
.02415 .1321 m
.25653 .13186 L
s
% Start of user PostScript
-0.002 -4. 50.1581 -4.05016 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.25653 .13186 Mdot
.039 .916 .04 r
.5 Mabswid
.02415 .16916 m
.25653 .16939 L
s
% Start of user PostScript
-0.002 4. 50.1581 4.05016 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.25653 .16939 Mdot
.039 .916 .04 r
.5 Mabswid
.02408 .20622 m
.26248 .20693 L
s
% Start of user PostScript
-0.0179999 11.9999 51.4419 12.1543 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.26248 .20693 Mdot
.039 .916 .04 r
.5 Mabswid
.02393 .24328 m
.27488 .24453 L
s
% Start of user PostScript
-0.049999 19.9998 54.1182 20.2706 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.27488 .24453 Mdot
.039 .916 .04 r
.5 Mabswid
.27488 .05672 m
.30213 .0605 L
s
% Start of user PostScript
54.1182 -20.2706 60. -19.4541 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30213 .0605 Mdot
.039 .916 .04 r
.5 Mabswid
.26248 .09432 m
.30213 .09748 L
s
% Start of user PostScript
51.4419 -12.1543 60. -11.4718 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30213 .09748 Mdot
.039 .916 .04 r
.5 Mabswid
.25653 .13186 m
.30213 .13305 L
s
% Start of user PostScript
50.1581 -4.05016 60. -3.79381 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30213 .13305 Mdot
.039 .916 .04 r
.5 Mabswid
.25653 .16939 m
.30213 .1682 L
s
% Start of user PostScript
50.1581 4.05016 60. 3.79381 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30213 .1682 Mdot
.039 .916 .04 r
.5 Mabswid
.26248 .20693 m
.30213 .20377 L
s
% Start of user PostScript
51.4419 12.1543 60. 11.4718 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30213 .20377 Mdot
.039 .916 .04 r
.5 Mabswid
.27488 .24453 m
.30213 .24075 L
s
% Start of user PostScript
54.1182 20.2706 60. 19.4541 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30213 .24075 Mdot
.039 .916 .04 r
.5 Mabswid
.30213 .0605 m
.86498 .18072 L
s
% Start of user PostScript
60. -19.4541 181.496 6.49591 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.86498 .18072 Mdot
.039 .916 .04 r
.5 Mabswid
.30213 .09748 m
.84817 .16391 L
s
% Start of user PostScript
60. -11.4718 177.867 2.86653 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.84817 .16391 Mdot
.039 .916 .04 r
.5 Mabswid
.30213 .13305 m
.83855 .15428 L
s
% Start of user PostScript
60. -3.79381 175.79 0.789602 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.83855 .15428 Mdot
.039 .916 .04 r
.5 Mabswid
.30213 .1682 m
.83151 .14725 L
s
% Start of user PostScript
60. 3.79381 174.271 -0.729471 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.83151 .14725 Mdot
.039 .916 .04 r
.5 Mabswid
.30213 .20377 m
.82449 .14023 L
s
% Start of user PostScript
60. 11.4718 172.755 -2.24475 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82449 .14023 Mdot
.039 .916 .04 r
.5 Mabswid
.30213 .24075 m
.81539 .13113 L
s
% Start of user PostScript
60. 19.4541 170.791 -4.20939 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.81539 .13113 Mdot
.039 .916 .04 r
.5 Mabswid
.86498 .18072 m
.90803 .38226 L
s
% Start of user PostScript
181.496 6.49591 190.788 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.90803 .38226 Mdot
.039 .916 .04 r
.5 Mabswid
.84817 .16391 m
.87473 .38226 L
s
% Start of user PostScript
177.867 2.86653 183.6 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.87473 .38226 Mdot
.039 .916 .04 r
.5 Mabswid
.83855 .15428 m
.84757 .38226 L
s
% Start of user PostScript
175.79 0.789602 177.738 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.84757 .38226 Mdot
.039 .916 .04 r
.5 Mabswid
.83151 .14725 m
.82221 .38226 L
s
% Start of user PostScript
174.271 -0.729471 172.262 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.82221 .38226 Mdot
.039 .916 .04 r
.5 Mabswid
.82449 .14023 m
.79505 .38226 L
s
% Start of user PostScript
172.755 -2.24475 166.4 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.79505 .38226 Mdot
.039 .916 .04 r
.5 Mabswid
.81539 .13113 m
.76175 .38226 L
s
% Start of user PostScript
170.791 -4.20939 159.212 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.76175 .38226 Mdot
gsave
.27896 .00932 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78411 .09985 -67.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
71.875 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .38226 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
1 Mabswid
.02416 .24328 m
.03806 .24335 L
.05196 .24342 L
.06586 .24349 L
.07975 .24356 L
.09365 .24363 L
.10755 .2437 L
.12145 .24377 L
.13535 .24384 L
.14925 .24391 L
.16314 .24398 L
.17704 .24404 L
.19094 .24411 L
.20484 .24418 L
.21874 .24425 L
.23263 .24432 L
.24653 .24439 L
.26043 .24384 L
.27433 .24203 L
.28823 .24023 L
.30213 .23842 L
.31602 .23568 L
.32992 .23293 L
.34382 .23019 L
.35772 .22745 L
.37162 .22471 L
.38551 .22196 L
.39941 .21922 L
.41331 .21648 L
.42721 .21374 L
.44111 .21099 L
.45501 .20825 L
.4689 .20551 L
.4828 .20277 L
.4967 .20002 L
.5106 .19728 L
.5245 .19454 L
.53839 .19179 L
.55229 .18905 L
.56619 .18631 L
.58009 .18357 L
.59399 .18082 L
.60788 .17808 L
.62178 .17534 L
.63568 .1726 L
.64958 .16985 L
.66348 .16711 L
.67738 .16437 L
.69127 .16163 L
.70517 .15888 L
Mistroke
.71907 .15614 L
.73297 .1534 L
.74687 .15066 L
.76076 .15334 L
.77466 .15608 L
.78856 .15883 L
.80246 .16157 L
.81636 .16431 L
.83026 .16705 L
.81572 .15989 L
.81298 .17379 L
.81023 .18769 L
.80749 .20159 L
.80475 .21548 L
.802 .22938 L
.79926 .24328 L
.79652 .25718 L
.79378 .27108 L
.79103 .28497 L
.78829 .29887 L
.78555 .31277 L
.78281 .32667 L
.78006 .34057 L
.77732 .35447 L
.77458 .36836 L
.77184 .38226 L
Mfstroke
.02416 .05797 m
.03806 .0579 L
.05196 .05783 L
.06586 .05776 L
.07975 .05769 L
.09365 .05762 L
.10755 .05755 L
.12145 .05749 L
.13535 .05742 L
.14925 .05735 L
.16314 .05728 L
.17704 .05721 L
.19094 .05714 L
.20484 .05707 L
.21874 .057 L
.23263 .05693 L
.24653 .05686 L
.26043 .05742 L
.27433 .05922 L
.28823 .06103 L
.30213 .06283 L
.31602 .06557 L
.32992 .06832 L
.34382 .07106 L
.35772 .0738 L
.37162 .07655 L
.38551 .07929 L
.39941 .08203 L
.41331 .08477 L
.42721 .08752 L
.44111 .09026 L
.45501 .093 L
.4689 .09574 L
.4828 .09849 L
.4967 .10123 L
.5106 .10397 L
.5245 .10671 L
.53839 .10946 L
.55229 .1122 L
.56619 .11494 L
.58009 .11769 L
.59399 .12043 L
.60788 .12317 L
.62178 .12591 L
.63568 .12866 L
.64958 .1314 L
.66348 .13414 L
.67738 .13688 L
.69127 .13963 L
.70517 .14237 L
Mistroke
.71907 .14511 L
.73297 .14785 L
.74687 .1506 L
.76076 .14791 L
.77466 .14517 L
.78856 .14243 L
.80246 .13968 L
.81636 .13694 L
.83026 .1342 L
.85406 .15989 L
.8568 .17379 L
.85954 .18769 L
.86229 .20159 L
.86503 .21548 L
.86777 .22938 L
.87051 .24328 L
.87326 .25718 L
.876 .27108 L
.87874 .28497 L
.88148 .29887 L
.88423 .31277 L
.88697 .32667 L
.88971 .34057 L
.89246 .35447 L
.8952 .36836 L
.89794 .38226 L
Mfstroke
0 0 0 r
.02416 .15063 m
.2558 .15063 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
.2558 .15063 m
.30213 .15063 L
s
% Start of user PostScript
50. 0 60. 0 MAarrowhead1
% End of user PostScript
.30213 .15063 m
.83489 .15063 L
s
% Start of user PostScript
60. 0 175. 0 MAarrowhead1
% End of user PostScript
.83489 .15063 m
.83489 .38226 L
s
% Start of user PostScript
175. 0 175. 50. MAarrowhead1
% End of user PostScript
.83489 .38226 m
.83489 .38226 L
s
% Start of user PostScript
175. 50. MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .06724 m
.02385 .0728 L
.0239 .07836 L
.02394 .08391 L
.02397 .08947 L
.02401 .09503 L
.02404 .10059 L
.02406 .10615 L
.02409 .11171 L
.02411 .11727 L
.02412 .12283 L
.02414 .12839 L
.02415 .13395 L
.02416 .13951 L
.02416 .14507 L
.02416 .15063 L
.02416 .15619 L
.02416 .16174 L
.02415 .1673 L
.02414 .17286 L
.02412 .17842 L
.02411 .18398 L
.02409 .18954 L
.02406 .1951 L
.02404 .20066 L
.02401 .20622 L
.02397 .21178 L
.02394 .21734 L
.0239 .2229 L
.02385 .22846 L
.02381 .23401 L
s
.04466 .06714 m
.0447 .07271 L
.04474 .07827 L
.04478 .08384 L
.04482 .08941 L
.04485 .09497 L
.04488 .10054 L
.04491 .1061 L
.04493 .11167 L
.04495 .11723 L
.04497 .1228 L
.04498 .12836 L
.045 .13393 L
.045 .13949 L
.04501 .14506 L
.04501 .15063 L
.04501 .15619 L
.045 .16176 L
.045 .16732 L
.04498 .17289 L
.04497 .17845 L
.04495 .18402 L
.04493 .18958 L
.04491 .19515 L
.04488 .20072 L
.04485 .20628 L
.04482 .21185 L
.04478 .21741 L
.04474 .22298 L
.0447 .22854 L
.04466 .23411 L
s
.0655 .06705 m
.06555 .07262 L
.06559 .07819 L
.06563 .08376 L
.06567 .08934 L
.0657 .09491 L
.06573 .10048 L
.06576 .10605 L
.06578 .11162 L
.0658 .1172 L
.06582 .12277 L
.06583 .12834 L
.06584 .13391 L
.06585 .13948 L
.06586 .14505 L
.06586 .15063 L
.06586 .1562 L
.06585 .16177 L
.06584 .16734 L
.06583 .17291 L
.06582 .17848 L
.0658 .18406 L
.06578 .18963 L
.06576 .1952 L
.06573 .20077 L
.0657 .20634 L
.06567 .21192 L
.06563 .21749 L
.06559 .22306 L
.06555 .22863 L
.0655 .2342 L
s
.08635 .06696 m
.0864 .07253 L
.08644 .07811 L
.08648 .08369 L
.08651 .08927 L
.08655 .09485 L
.08658 .10042 L
.0866 .106 L
.08663 .11158 L
.08665 .11716 L
.08666 .12274 L
.08668 .12831 L
.08669 .13389 L
.0867 .13947 L
.0867 .14505 L
.0867 .15063 L
.0867 .1562 L
.0867 .16178 L
.08669 .16736 L
.08668 .17294 L
.08666 .17852 L
.08665 .18409 L
.08663 .18967 L
.0866 .19525 L
.08658 .20083 L
.08655 .20641 L
.08651 .21198 L
.08648 .21756 L
.08644 .22314 L
.0864 .22872 L
.08635 .2343 L
s
.1072 .06686 m
.10724 .07245 L
.10729 .07803 L
.10732 .08361 L
.10736 .0892 L
.10739 .09478 L
.10742 .10037 L
.10745 .10595 L
.10747 .11154 L
.10749 .11712 L
.10751 .1227 L
.10753 .12829 L
.10754 .13387 L
.10754 .13946 L
.10755 .14504 L
.10755 .15063 L
.10755 .15621 L
.10754 .16179 L
.10754 .16738 L
.10753 .17296 L
.10751 .17855 L
.10749 .18413 L
.10747 .18972 L
.10745 .1953 L
.10742 .20088 L
.10739 .20647 L
.10736 .21205 L
.10732 .21764 L
.10729 .22322 L
.10724 .22881 L
.1072 .23439 L
s
.12804 .06677 m
.12809 .07236 L
.12813 .07795 L
.12817 .08354 L
.12821 .08913 L
.12824 .09472 L
.12827 .10031 L
.1283 .1059 L
.12832 .11149 L
.12834 .11708 L
.12836 .12267 L
.12837 .12826 L
.12838 .13385 L
.12839 .13944 L
.1284 .14504 L
.1284 .15063 L
.1284 .15622 L
.12839 .16181 L
.12838 .1674 L
.12837 .17299 L
.12836 .17858 L
.12834 .18417 L
.12832 .18976 L
.1283 .19535 L
.12827 .20094 L
.12824 .20653 L
.12821 .21212 L
.12817 .21771 L
.12813 .2233 L
.12809 .22889 L
.12804 .23448 L
s
.14889 .06667 m
.14894 .07227 L
.14898 .07787 L
.14902 .08346 L
.14905 .08906 L
.14909 .09466 L
.14912 .10025 L
.14914 .10585 L
.14917 .11145 L
.14919 .11705 L
.14921 .12264 L
.14922 .12824 L
.14923 .13384 L
.14924 .13943 L
.14924 .14503 L
.14925 .15063 L
.14924 .15622 L
.14924 .16182 L
.14923 .16742 L
.14922 .17301 L
.14921 .17861 L
.14919 .18421 L
.14917 .1898 L
.14914 .1954 L
.14912 .201 L
.14909 .20659 L
.14905 .21219 L
.14902 .21779 L
.14898 .22338 L
.14894 .22898 L
.14889 .23458 L
s
.16974 .06658 m
.16978 .07218 L
.16983 .07779 L
.16987 .08339 L
.1699 .08899 L
.16993 .0946 L
.16996 .1002 L
.16999 .1058 L
.17002 .1114 L
.17004 .11701 L
.17005 .12261 L
.17007 .12821 L
.17008 .13382 L
.17009 .13942 L
.17009 .14502 L
.17009 .15063 L
.17009 .15623 L
.17009 .16183 L
.17008 .16744 L
.17007 .17304 L
.17005 .17864 L
.17004 .18424 L
.17002 .18985 L
.16999 .19545 L
.16996 .20105 L
.16993 .20666 L
.1699 .21226 L
.16987 .21786 L
.16983 .22347 L
.16978 .22907 L
.16974 .23467 L
s
.19058 .06649 m
.19063 .0721 L
.19067 .07771 L
.19071 .08331 L
.19075 .08892 L
.19078 .09453 L
.19081 .10014 L
.19084 .10575 L
.19086 .11136 L
.19088 .11697 L
.1909 .12258 L
.19091 .12819 L
.19093 .1338 L
.19093 .13941 L
.19094 .14502 L
.19094 .15063 L
.19094 .15624 L
.19093 .16184 L
.19093 .16745 L
.19091 .17306 L
.1909 .17867 L
.19088 .18428 L
.19086 .18989 L
.19084 .1955 L
.19081 .20111 L
.19078 .20672 L
.19075 .21233 L
.19071 .21794 L
.19067 .22355 L
.19063 .22916 L
.19058 .23477 L
s
.21143 .06639 m
.21148 .07201 L
.21152 .07762 L
.21156 .08324 L
.2116 .08885 L
.21163 .09447 L
.21166 .10009 L
.21169 .1057 L
.21171 .11132 L
.21173 .11693 L
.21175 .12255 L
.21176 .12816 L
.21177 .13378 L
.21178 .13939 L
.21179 .14501 L
.21179 .15063 L
.21179 .15624 L
.21178 .16186 L
.21177 .16747 L
.21176 .17309 L
.21175 .1787 L
.21173 .18432 L
.21171 .18993 L
.21169 .19555 L
.21166 .20117 L
.21163 .20678 L
.2116 .2124 L
.21156 .21801 L
.21152 .22363 L
.21148 .22924 L
.21143 .23486 L
s
.23228 .0663 m
.23232 .07192 L
.23237 .07754 L
.23241 .08316 L
.23244 .08879 L
.23248 .09441 L
.23251 .10003 L
.23253 .10565 L
.23256 .11127 L
.23258 .1169 L
.23259 .12252 L
.23261 .12814 L
.23262 .13376 L
.23263 .13938 L
.23263 .145 L
.23263 .15063 L
.23263 .15625 L
.23263 .16187 L
.23262 .16749 L
.23261 .17311 L
.23259 .17874 L
.23258 .18436 L
.23256 .18998 L
.23253 .1956 L
.23251 .20122 L
.23248 .20684 L
.23244 .21247 L
.23241 .21809 L
.23237 .22371 L
.23232 .22933 L
.23228 .23495 L
s
.25312 .06621 m
.25317 .07183 L
.25321 .07746 L
.25325 .08309 L
.25329 .08872 L
.25332 .09435 L
.25335 .09997 L
.25338 .1056 L
.2534 .11123 L
.25342 .11686 L
.25344 .12249 L
.25346 .12811 L
.25347 .13374 L
.25348 .13937 L
.25348 .145 L
.25348 .15063 L
.25348 .15625 L
.25348 .16188 L
.25347 .16751 L
.25346 .17314 L
.25344 .17877 L
.25342 .18439 L
.2534 .19002 L
.25338 .19565 L
.25335 .20128 L
.25332 .20691 L
.25329 .21253 L
.25325 .21816 L
.25321 .22379 L
.25317 .22942 L
.25312 .23505 L
s
.28028 .06836 m
.27951 .07385 L
.2788 .07933 L
.27814 .08481 L
.27753 .0903 L
.27697 .09578 L
.27647 .10127 L
.27602 .10675 L
.27562 .11224 L
.27528 .11772 L
.27499 .1232 L
.27475 .12869 L
.27457 .13417 L
.27443 .13966 L
.27436 .14514 L
.27433 .15063 L
.27436 .15611 L
.27443 .16159 L
.27457 .16708 L
.27475 .17256 L
.27499 .17805 L
.27528 .18353 L
.27562 .18902 L
.27602 .1945 L
.27647 .19998 L
.27697 .20547 L
.27753 .21095 L
.27814 .21644 L
.2788 .22192 L
.27951 .22741 L
.28028 .23289 L
s
.30095 .0708 m
.30021 .07612 L
.29951 .08144 L
.29887 .08676 L
.29828 .09209 L
.29774 .09741 L
.29725 .10273 L
.29682 .10805 L
.29643 .11337 L
.2961 .1187 L
.29582 .12402 L
.29559 .12934 L
.29541 .13466 L
.29528 .13998 L
.2952 .1453 L
.29518 .15063 L
.2952 .15595 L
.29528 .16127 L
.29541 .16659 L
.29559 .17191 L
.29582 .17724 L
.2961 .18256 L
.29643 .18788 L
.29682 .1932 L
.29725 .19852 L
.29774 .20384 L
.29828 .20917 L
.29887 .21449 L
.29951 .21981 L
.30021 .22513 L
.30095 .23045 L
s
.3288 .07408 m
.32715 .07918 L
.32562 .08429 L
.3242 .08939 L
.32289 .09449 L
.3217 .0996 L
.32062 .1047 L
.31966 .1098 L
.31881 .1149 L
.31807 .12001 L
.31744 .12511 L
.31693 .13021 L
.31653 .13532 L
.31625 .14042 L
.31608 .14552 L
.31602 .15063 L
.31608 .15573 L
.31625 .16083 L
.31653 .16594 L
.31693 .17104 L
.31744 .17614 L
.31807 .18124 L
.31881 .18635 L
.31966 .19145 L
.32062 .19655 L
.3217 .20166 L
.32289 .20676 L
.3242 .21186 L
.32562 .21697 L
.32715 .22207 L
.3288 .22717 L
s
.34903 .07778 m
.34746 .08264 L
.346 .08749 L
.34465 .09235 L
.34341 .09721 L
.34227 .10206 L
.34125 .10692 L
.34033 .11178 L
.33952 .11663 L
.33882 .12149 L
.33822 .12634 L
.33774 .1312 L
.33736 .13606 L
.33709 .14091 L
.33692 .14577 L
.33687 .15063 L
.33692 .15548 L
.33709 .16034 L
.33736 .16519 L
.33774 .17005 L
.33822 .17491 L
.33882 .17976 L
.33952 .18462 L
.34033 .18948 L
.34125 .19433 L
.34227 .19919 L
.34341 .20404 L
.34465 .2089 L
.346 .21376 L
.34746 .21861 L
.34903 .22347 L
s
.36926 .08148 m
.36777 .08609 L
.36638 .0907 L
.3651 .09531 L
.36392 .09992 L
.36285 .10453 L
.36187 .10914 L
.361 .11375 L
.36023 .11836 L
.35956 .12297 L
.359 .12758 L
.35854 .13219 L
.35818 .1368 L
.35792 .14141 L
.35777 .14602 L
.35772 .15063 L
.35777 .15524 L
.35792 .15984 L
.35818 .16445 L
.35854 .16906 L
.359 .17367 L
.35956 .17828 L
.36023 .18289 L
.361 .1875 L
.36187 .19211 L
.36285 .19672 L
.36392 .20133 L
.3651 .20594 L
.36638 .21055 L
.36777 .21516 L
.36926 .21977 L
s
.38949 .08519 m
.38808 .08955 L
.38677 .09391 L
.38555 .09828 L
.38444 .10264 L
.38342 .107 L
.3825 .11136 L
.38167 .11573 L
.38094 .12009 L
.38031 .12445 L
.37978 .12881 L
.37934 .13318 L
.379 .13754 L
.37876 .1419 L
.37861 .14626 L
.37857 .15063 L
.37861 .15499 L
.37876 .15935 L
.379 .16371 L
.37934 .16808 L
.37978 .17244 L
.38031 .1768 L
.38094 .18116 L
.38167 .18553 L
.3825 .18989 L
.38342 .19425 L
.38444 .19861 L
.38555 .20298 L
.38677 .20734 L
.38808 .2117 L
.38949 .21606 L
s
.40971 .08889 m
.40839 .09301 L
.40715 .09712 L
.40601 .10124 L
.40495 .10535 L
.40399 .10947 L
.40312 .11358 L
.40234 .1177 L
.40166 .12182 L
.40106 .12593 L
.40056 .13005 L
.40015 .13416 L
.39982 .13828 L
.3996 .14239 L
.39946 .14651 L
.39941 .15063 L
.39946 .15474 L
.3996 .15886 L
.39982 .16297 L
.40015 .16709 L
.40056 .1712 L
.40106 .17532 L
.40166 .17944 L
.40234 .18355 L
.40312 .18767 L
.40399 .19178 L
.40495 .1959 L
.40601 .20001 L
.40715 .20413 L
.40839 .20825 L
.40971 .21236 L
s
.42994 .09259 m
.4287 .09646 L
.42753 .10033 L
.42646 .1042 L
.42547 .10807 L
.42456 .11194 L
.42375 .11581 L
.42301 .11967 L
.42237 .12354 L
.42181 .12741 L
.42134 .13128 L
.42095 .13515 L
.42065 .13902 L
.42043 .14289 L
.4203 .14676 L
.42026 .15063 L
.4203 .15449 L
.42043 .15836 L
.42065 .16223 L
.42095 .1661 L
.42134 .16997 L
.42181 .17384 L
.42237 .17771 L
.42301 .18158 L
.42375 .18545 L
.42456 .18931 L
.42547 .19318 L
.42646 .19705 L
.42753 .20092 L
.4287 .20479 L
.42994 .20866 L
s
.45017 .0963 m
.449 .09992 L
.44792 .10354 L
.44691 .10716 L
.44598 .11078 L
.44514 .11441 L
.44437 .11803 L
.44369 .12165 L
.44308 .12527 L
.44256 .12889 L
.44211 .13252 L
.44175 .13614 L
.44147 .13976 L
.44127 .14338 L
.44115 .147 L
.44111 .15063 L
.44115 .15425 L
.44127 .15787 L
.44147 .16149 L
.44175 .16511 L
.44211 .16874 L
.44256 .17236 L
.44308 .17598 L
.44369 .1796 L
.44437 .18322 L
.44514 .18685 L
.44598 .19047 L
.44691 .19409 L
.44792 .19771 L
.449 .20133 L
.45017 .20496 L
s
.4704 .1 m
.46931 .10337 L
.4683 .10675 L
.46736 .11012 L
.4665 .1135 L
.46571 .11687 L
.465 .12025 L
.46436 .12362 L
.46379 .127 L
.46331 .13037 L
.46289 .13375 L
.46255 .13713 L
.46229 .1405 L
.4621 .14388 L
.46199 .14725 L
.46195 .15063 L
.46199 .154 L
.4621 .15738 L
.46229 .16075 L
.46255 .16413 L
.46289 .1675 L
.46331 .17088 L
.46379 .17425 L
.46436 .17763 L
.465 .181 L
.46571 .18438 L
.4665 .18775 L
.46736 .19113 L
.4683 .1945 L
.46931 .19788 L
.4704 .20125 L
s
.49063 .1037 m
.48962 .10683 L
.48868 .10996 L
.48781 .11309 L
.48701 .11621 L
.48628 .11934 L
.48562 .12247 L
.48503 .1256 L
.48451 .12873 L
.48405 .13186 L
.48367 .13498 L
.48336 .13811 L
.48311 .14124 L
.48294 .14437 L
.48284 .1475 L
.4828 .15063 L
.48284 .15375 L
.48294 .15688 L
.48311 .16001 L
.48336 .16314 L
.48367 .16627 L
.48405 .1694 L
.48451 .17252 L
.48503 .17565 L
.48562 .17878 L
.48628 .18191 L
.48701 .18504 L
.48781 .18817 L
.48868 .19129 L
.48962 .19442 L
.49063 .19755 L
s
.51086 .1074 m
.50993 .11028 L
.50907 .11317 L
.50826 .11605 L
.50753 .11893 L
.50685 .12181 L
.50625 .12469 L
.5057 .12757 L
.50522 .13046 L
.5048 .13334 L
.50445 .13622 L
.50416 .1391 L
.50394 .14198 L
.50378 .14486 L
.50368 .14774 L
.50365 .15063 L
.50368 .15351 L
.50378 .15639 L
.50394 .15927 L
.50416 .16215 L
.50445 .16503 L
.5048 .16792 L
.50522 .1708 L
.5057 .17368 L
.50625 .17656 L
.50685 .17944 L
.50753 .18232 L
.50826 .1852 L
.50907 .18809 L
.50993 .19097 L
.51086 .19385 L
s
.53109 .11111 m
.53024 .11374 L
.52945 .11638 L
.52872 .11901 L
.52804 .12164 L
.52743 .12428 L
.52687 .12691 L
.52637 .12955 L
.52593 .13218 L
.52555 .13482 L
.52523 .13745 L
.52496 .14009 L
.52476 .14272 L
.52461 .14536 L
.52453 .14799 L
.5245 .15063 L
.52453 .15326 L
.52461 .1559 L
.52476 .15853 L
.52496 .16116 L
.52523 .1638 L
.52555 .16643 L
.52593 .16907 L
.52637 .1717 L
.52687 .17434 L
.52743 .17697 L
.52804 .17961 L
.52872 .18224 L
.52945 .18488 L
.53024 .18751 L
.53109 .19015 L
s
.55132 .11481 m
.55055 .1172 L
.54983 .11958 L
.54917 .12197 L
.54856 .12436 L
.548 .12675 L
.54749 .12914 L
.54704 .13152 L
.54664 .13391 L
.5463 .1363 L
.54601 .13869 L
.54577 .14107 L
.54558 .14346 L
.54545 .14585 L
.54537 .14824 L
.54534 .15063 L
.54537 .15301 L
.54545 .1554 L
.54558 .15779 L
.54577 .16018 L
.54601 .16257 L
.5463 .16495 L
.54664 .16734 L
.54704 .16973 L
.54749 .17212 L
.548 .1745 L
.54856 .17689 L
.54917 .17928 L
.54983 .18167 L
.55055 .18406 L
.55132 .18644 L
s
.57155 .11851 m
.57086 .12065 L
.57022 .12279 L
.56962 .12493 L
.56907 .12707 L
.56857 .12922 L
.56812 .13136 L
.56771 .1335 L
.56736 .13564 L
.56705 .13778 L
.56679 .13992 L
.56657 .14206 L
.5664 .1442 L
.56629 .14634 L
.56621 .14848 L
.56619 .15063 L
.56621 .15277 L
.56629 .15491 L
.5664 .15705 L
.56657 .15919 L
.56679 .16133 L
.56705 .16347 L
.56736 .16561 L
.56771 .16775 L
.56812 .1699 L
.56857 .17204 L
.56907 .17418 L
.56962 .17632 L
.57022 .17846 L
.57086 .1806 L
.57155 .18274 L
s
.59178 .12221 m
.59117 .12411 L
.5906 .126 L
.59007 .1279 L
.58959 .12979 L
.58914 .13168 L
.58874 .13358 L
.58839 .13547 L
.58807 .13737 L
.5878 .13926 L
.58756 .14116 L
.58737 .14305 L
.58723 .14494 L
.58712 .14684 L
.58706 .14873 L
.58704 .15063 L
.58706 .15252 L
.58712 .15441 L
.58723 .15631 L
.58737 .1582 L
.58756 .1601 L
.5878 .16199 L
.58807 .16389 L
.58839 .16578 L
.58874 .16767 L
.58914 .16957 L
.58959 .17146 L
.59007 .17336 L
.5906 .17525 L
.59117 .17714 L
.59178 .17904 L
s
.61201 .12592 m
.61148 .12756 L
.61098 .12921 L
.61052 .13086 L
.6101 .13251 L
.60972 .13415 L
.60937 .1358 L
.60906 .13745 L
.60878 .13909 L
.60854 .14074 L
.60834 .14239 L
.60818 .14404 L
.60805 .14568 L
.60796 .14733 L
.6079 .14898 L
.60788 .15063 L
.6079 .15227 L
.60796 .15392 L
.60805 .15557 L
.60818 .15722 L
.60834 .15886 L
.60854 .16051 L
.60878 .16216 L
.60906 .1638 L
.60937 .16545 L
.60972 .1671 L
.6101 .16875 L
.61052 .17039 L
.61098 .17204 L
.61148 .17369 L
.61201 .17534 L
s
.63224 .12962 m
.63179 .13102 L
.63137 .13242 L
.63098 .13382 L
.63062 .13522 L
.63029 .13662 L
.62999 .13802 L
.62973 .13942 L
.6295 .14082 L
.62929 .14222 L
.62912 .14362 L
.62898 .14502 L
.62887 .14642 L
.62879 .14783 L
.62875 .14923 L
.62873 .15063 L
.62875 .15203 L
.62879 .15343 L
.62887 .15483 L
.62898 .15623 L
.62912 .15763 L
.62929 .15903 L
.6295 .16043 L
.62973 .16183 L
.62999 .16323 L
.63029 .16463 L
.63062 .16603 L
.63098 .16743 L
.63137 .16883 L
.63179 .17023 L
.63224 .17163 L
s
.65247 .13332 m
.65209 .13447 L
.65175 .13563 L
.65143 .13678 L
.65113 .13794 L
.65086 .13909 L
.65062 .14024 L
.6504 .1414 L
.65021 .14255 L
.65004 .1437 L
.6499 .14486 L
.64978 .14601 L
.64969 .14717 L
.64963 .14832 L
.64959 .14947 L
.64958 .15063 L
.64959 .15178 L
.64963 .15293 L
.64969 .15409 L
.64978 .15524 L
.6499 .15639 L
.65004 .15755 L
.65021 .1587 L
.6504 .15986 L
.65062 .16101 L
.65086 .16216 L
.65113 .16332 L
.65143 .16447 L
.65175 .16562 L
.65209 .16678 L
.65247 .16793 L
s
.6727 .13702 m
.6724 .13793 L
.67213 .13884 L
.67188 .13974 L
.67165 .14065 L
.67144 .14156 L
.67124 .14246 L
.67107 .14337 L
.67092 .14428 L
.67079 .14519 L
.67068 .14609 L
.67059 .147 L
.67052 .14791 L
.67047 .14881 L
.67044 .14972 L
.67043 .15063 L
.67044 .15153 L
.67047 .15244 L
.67052 .15335 L
.67059 .15425 L
.67068 .15516 L
.67079 .15607 L
.67092 .15697 L
.67107 .15788 L
.67124 .15879 L
.67144 .15969 L
.67165 .1606 L
.67188 .16151 L
.67213 .16241 L
.6724 .16332 L
.6727 .16423 L
s
.69293 .14073 m
.69271 .14139 L
.69251 .14205 L
.69233 .14271 L
.69216 .14337 L
.69201 .14403 L
.69187 .14469 L
.69174 .14535 L
.69163 .14601 L
.69154 .14667 L
.69146 .14733 L
.69139 .14799 L
.69134 .14865 L
.6913 .14931 L
.69128 .14997 L
.69127 .15063 L
.69128 .15129 L
.6913 .15195 L
.69134 .15261 L
.69139 .15327 L
.69146 .15393 L
.69154 .15459 L
.69163 .15525 L
.69174 .15591 L
.69187 .15657 L
.69201 .15723 L
.69216 .15789 L
.69233 .15855 L
.69251 .15921 L
.69271 .15987 L
.69293 .16053 L
s
.71316 .14443 m
.71302 .14484 L
.7129 .14526 L
.71278 .14567 L
.71268 .14608 L
.71258 .14649 L
.71249 .14691 L
.71242 .14732 L
.71235 .14773 L
.71229 .14815 L
.71224 .14856 L
.71219 .14897 L
.71216 .14939 L
.71214 .1498 L
.71213 .15021 L
.71212 .15063 L
.71213 .15104 L
.71214 .15145 L
.71216 .15187 L
.71219 .15228 L
.71224 .15269 L
.71229 .1531 L
.71235 .15352 L
.71242 .15393 L
.71249 .15434 L
.71258 .15476 L
.71268 .15517 L
.71278 .15558 L
.7129 .156 L
.71302 .15641 L
.71316 .15682 L
s
.73338 .14813 m
.73333 .1483 L
.73328 .14846 L
.73323 .14863 L
.73319 .1488 L
.73315 .14896 L
.73312 .14913 L
.73309 .1493 L
.73306 .14946 L
.73303 .14963 L
.73301 .14979 L
.733 .14996 L
.73298 .15013 L
.73298 .15029 L
.73297 .15046 L
.73297 .15063 L
.73297 .15079 L
.73298 .15096 L
.73298 .15112 L
.733 .15129 L
.73301 .15146 L
.73303 .15162 L
.73306 .15179 L
.73309 .15196 L
.73312 .15212 L
.73315 .15229 L
.73319 .15246 L
.73323 .15262 L
.73328 .15279 L
.73333 .15295 L
.73338 .15312 L
s
.75361 .14942 m
.75364 .1495 L
.75366 .14958 L
.75369 .14966 L
.75371 .14974 L
.75373 .14982 L
.75374 .1499 L
.75376 .14998 L
.75377 .15006 L
.75378 .15014 L
.75379 .15022 L
.7538 .1503 L
.75381 .15038 L
.75381 .15046 L
.75381 .15055 L
.75382 .15063 L
.75381 .15071 L
.75381 .15079 L
.75381 .15087 L
.7538 .15095 L
.75379 .15103 L
.75378 .15111 L
.75377 .15119 L
.75376 .15127 L
.75374 .15135 L
.75373 .15143 L
.75371 .15151 L
.75369 .15159 L
.75366 .15167 L
.75364 .15175 L
.75361 .15183 L
s
.77384 .14572 m
.77395 .14604 L
.77405 .14637 L
.77414 .1467 L
.77422 .14702 L
.7743 .14735 L
.77437 .14768 L
.77443 .14801 L
.77448 .14833 L
.77453 .14866 L
.77457 .14899 L
.7746 .14932 L
.77463 .14964 L
.77465 .14997 L
.77466 .1503 L
.77466 .15063 L
.77466 .15095 L
.77465 .15128 L
.77463 .15161 L
.7746 .15194 L
.77457 .15226 L
.77453 .15259 L
.77448 .15292 L
.77443 .15325 L
.77437 .15357 L
.7743 .1539 L
.77422 .15423 L
.77414 .15455 L
.77405 .15488 L
.77395 .15521 L
.77384 .15554 L
s
.79407 .14201 m
.79426 .14259 L
.79443 .14316 L
.79459 .14374 L
.79474 .14431 L
.79487 .14488 L
.79499 .14546 L
.7951 .14603 L
.7952 .14661 L
.79528 .14718 L
.79535 .14775 L
.79541 .14833 L
.79545 .1489 L
.79548 .14948 L
.7955 .15005 L
.79551 .15063 L
.7955 .1512 L
.79548 .15177 L
.79545 .15235 L
.79541 .15292 L
.79535 .1535 L
.79528 .15407 L
.7952 .15465 L
.7951 .15522 L
.79499 .15579 L
.79487 .15637 L
.79474 .15694 L
.79459 .15752 L
.79443 .15809 L
.79426 .15867 L
.79407 .15924 L
s
.8143 .13831 m
.81457 .13913 L
.81481 .13995 L
.81504 .14077 L
.81525 .14159 L
.81544 .14242 L
.81562 .14324 L
.81577 .14406 L
.81591 .14488 L
.81603 .1457 L
.81613 .14652 L
.81621 .14734 L
.81627 .14816 L
.81632 .14898 L
.81635 .1498 L
.81636 .15063 L
.81635 .15145 L
.81632 .15227 L
.81627 .15309 L
.81621 .15391 L
.81613 .15473 L
.81603 .15555 L
.81591 .15637 L
.81577 .15719 L
.81562 .15802 L
.81544 .15884 L
.81525 .15966 L
.81504 .16048 L
.81481 .1613 L
.81457 .16212 L
.8143 .16294 L
s
.85091 .15027 m
.84984 .15061 L
.84877 .15093 L
.8477 .15123 L
.84663 .1515 L
.84557 .15175 L
.8445 .15198 L
.84343 .15218 L
.84236 .15236 L
.8413 .15251 L
.84023 .15265 L
.83916 .15275 L
.83809 .15284 L
.83702 .15289 L
.83596 .15293 L
.83489 .15294 L
.83382 .15293 L
.83275 .15289 L
.83168 .15284 L
.83062 .15275 L
.82955 .15265 L
.82848 .15251 L
.82741 .15236 L
.82634 .15218 L
.82528 .15198 L
.82421 .15175 L
.82314 .1515 L
.82207 .15123 L
.82101 .15093 L
.81994 .15061 L
.81887 .15027 L
s
.85461 .1705 m
.85329 .17092 L
.85198 .17132 L
.85066 .17168 L
.84935 .17202 L
.84804 .17233 L
.84672 .1726 L
.84541 .17285 L
.84409 .17307 L
.84278 .17326 L
.84146 .17342 L
.84015 .17356 L
.83883 .17366 L
.83752 .17373 L
.8362 .17377 L
.83489 .17379 L
.83357 .17377 L
.83226 .17373 L
.83094 .17366 L
.82963 .17356 L
.82831 .17342 L
.827 .17326 L
.82568 .17307 L
.82437 .17285 L
.82306 .1726 L
.82174 .17233 L
.82043 .17202 L
.81911 .17168 L
.8178 .17132 L
.81648 .17092 L
.81517 .1705 L
s
.85831 .19073 m
.85675 .19123 L
.85519 .1917 L
.85363 .19214 L
.85207 .19253 L
.8505 .1929 L
.84894 .19323 L
.84738 .19352 L
.84582 .19379 L
.84426 .19401 L
.8427 .1942 L
.84113 .19436 L
.83957 .19448 L
.83801 .19457 L
.83645 .19462 L
.83489 .19464 L
.83333 .19462 L
.83176 .19457 L
.8302 .19448 L
.82864 .19436 L
.82708 .1942 L
.82552 .19401 L
.82396 .19379 L
.8224 .19352 L
.82083 .19323 L
.81927 .1929 L
.81771 .19253 L
.81615 .19214 L
.81459 .1917 L
.81303 .19123 L
.81146 .19073 L
s
.86201 .21096 m
.86021 .21154 L
.8584 .21208 L
.85659 .21259 L
.85478 .21305 L
.85297 .21347 L
.85116 .21385 L
.84936 .2142 L
.84755 .2145 L
.84574 .21476 L
.84393 .21498 L
.84212 .21516 L
.84031 .2153 L
.8385 .2154 L
.8367 .21546 L
.83489 .21548 L
.83308 .21546 L
.83127 .2154 L
.82946 .2153 L
.82765 .21516 L
.82585 .21498 L
.82404 .21476 L
.82223 .2145 L
.82042 .2142 L
.81861 .21385 L
.8168 .21347 L
.815 .21305 L
.81319 .21259 L
.81138 .21208 L
.80957 .21154 L
.80776 .21096 L
s
.86572 .23119 m
.86366 .23185 L
.86161 .23247 L
.85955 .23304 L
.8575 .23356 L
.85544 .23404 L
.85339 .23448 L
.85133 .23487 L
.84927 .23521 L
.84722 .23551 L
.84516 .23576 L
.84311 .23597 L
.84105 .23613 L
.839 .23624 L
.83694 .23631 L
.83489 .23633 L
.83283 .23631 L
.83078 .23624 L
.82872 .23613 L
.82667 .23597 L
.82461 .23576 L
.82256 .23551 L
.8205 .23521 L
.81845 .23487 L
.81639 .23448 L
.81434 .23404 L
.81228 .23356 L
.81022 .23304 L
.80817 .23247 L
.80611 .23185 L
.80406 .23119 L
s
.86942 .25142 m
.86712 .25216 L
.86482 .25285 L
.86251 .25349 L
.86021 .25408 L
.85791 .25462 L
.85561 .2551 L
.8533 .25554 L
.851 .25592 L
.8487 .25626 L
.8464 .25654 L
.8441 .25677 L
.84179 .25695 L
.83949 .25708 L
.83719 .25715 L
.83489 .25718 L
.83259 .25715 L
.83028 .25708 L
.82798 .25695 L
.82568 .25677 L
.82338 .25654 L
.82108 .25626 L
.81877 .25592 L
.81647 .25554 L
.81417 .2551 L
.81187 .25462 L
.80956 .25408 L
.80726 .25349 L
.80496 .25285 L
.80266 .25216 L
.80036 .25142 L
s
.87312 .27165 m
.87057 .27247 L
.86802 .27323 L
.86548 .27394 L
.86293 .27459 L
.86038 .27519 L
.85783 .27573 L
.85528 .27621 L
.85273 .27664 L
.85018 .277 L
.84763 .27732 L
.84508 .27757 L
.84253 .27777 L
.83999 .27791 L
.83744 .278 L
.83489 .27803 L
.83234 .278 L
.82979 .27791 L
.82724 .27777 L
.82469 .27757 L
.82214 .27732 L
.81959 .277 L
.81705 .27664 L
.8145 .27621 L
.81195 .27573 L
.8094 .27519 L
.80685 .27459 L
.8043 .27394 L
.80175 .27323 L
.7992 .27247 L
.79665 .27165 L
s
.87682 .29187 m
.87403 .29278 L
.87123 .29362 L
.86844 .29439 L
.86564 .29511 L
.86285 .29576 L
.86005 .29635 L
.85725 .29688 L
.85446 .29735 L
.85166 .29775 L
.84887 .2981 L
.84607 .29838 L
.84328 .29859 L
.84048 .29875 L
.83768 .29884 L
.83489 .29887 L
.83209 .29884 L
.8293 .29875 L
.8265 .29859 L
.8237 .29838 L
.82091 .2981 L
.81811 .29775 L
.81532 .29735 L
.81252 .29688 L
.80973 .29635 L
.80693 .29576 L
.80413 .29511 L
.80134 .29439 L
.79854 .29362 L
.79575 .29278 L
.79295 .29187 L
s
.88053 .3121 m
.87748 .31309 L
.87444 .314 L
.8714 .31485 L
.86836 .31562 L
.86531 .31634 L
.86227 .31698 L
.85923 .31755 L
.85619 .31806 L
.85314 .3185 L
.8501 .31887 L
.84706 .31918 L
.84402 .31942 L
.84097 .31958 L
.83793 .31969 L
.83489 .31972 L
.83185 .31969 L
.8288 .31958 L
.82576 .31942 L
.82272 .31918 L
.81967 .31887 L
.81663 .3185 L
.81359 .31806 L
.81055 .31755 L
.8075 .31698 L
.80446 .31634 L
.80142 .31562 L
.79838 .31485 L
.79533 .314 L
.79229 .31309 L
.78925 .3121 L
s
.88423 .33233 m
.88094 .33339 L
.87765 .33438 L
.87436 .3353 L
.87107 .33614 L
.86778 .33691 L
.86449 .3376 L
.8612 .33823 L
.85791 .33877 L
.85462 .33925 L
.85134 .33965 L
.84805 .33998 L
.84476 .34024 L
.84147 .34042 L
.83818 .34053 L
.83489 .34057 L
.8316 .34053 L
.82831 .34042 L
.82502 .34024 L
.82173 .33998 L
.81844 .33965 L
.81515 .33925 L
.81186 .33877 L
.80857 .33823 L
.80528 .3376 L
.80199 .33691 L
.7987 .33614 L
.79541 .3353 L
.79212 .33438 L
.78884 .33339 L
.78555 .33233 L
s
.88793 .35256 m
.8844 .3537 L
.88086 .35477 L
.87732 .35575 L
.87379 .35665 L
.87025 .35748 L
.86671 .35823 L
.86318 .3589 L
.85964 .35949 L
.85611 .36 L
.85257 .36043 L
.84903 .36079 L
.8455 .36106 L
.84196 .36126 L
.83842 .36138 L
.83489 .36141 L
.83135 .36138 L
.82782 .36126 L
.82428 .36106 L
.82074 .36079 L
.81721 .36043 L
.81367 .36 L
.81013 .35949 L
.8066 .3589 L
.80306 .35823 L
.79952 .35748 L
.79599 .35665 L
.79245 .35575 L
.78892 .35477 L
.78538 .3537 L
.78184 .35256 L
s
0 0 m
1 0 L
1 .39159 L
0 .39159 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 112.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000L2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00DOooool6o`000<Wooooo001B
ooooo`05o`000?ooooooooooooooool00000bOooool005;ooooo00?o0000ooooooooool0boooool0
05;ooooo00?o0000ooooooooool0boooool005;ooooo00?o0000ooooooooool0boooool005;ooooo
00?o0000ooooooooool0boooool0057ooooo0ol0003<ooooo`00oooooolQooooo`00oooooolQoooo
o`00E_ooool5o`000<Gooooo001Fooooo`Go0000aOooool005Gooooo0_l00003ogmoO`03o`000?oo
oooooooo0<?ooooo001;ooooo`?o2NX:1?ooool2o`WZ2P03ooooool0003o000000?oOgmo00?o0000
ooooooooool0`oooool004cooooo2ol9jPX4o`000<Gooooo000booooob3o2NX:00?o0000o`WZ2_l9
jPX01Ol9jPX00ol0003oooooooooo`33ooooo`004?oooolfo`WZ2PKooooo4Ol9jP[3ooooo`00Booo
ool2o`WZ2PGooooo4?l9jPZnooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool01Ol0003oOgmoogmoOomoOgoo000000?oOgmo00?o
0000ooooooooool01?l9jPX00ooooooo2NX:o`WZ2P02o`WZ2[[ooooo000@ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`04o`000?moOgoo
2NX:ogmoO`Co000000?o2NX:ooooooooool01?ooool:o`WZ2[Gooooo000@ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool01Ol9jP[ooooooooooooooooo000000;oOgmo00?o
2NX:ogmoOol000000omoOgl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo2?l9
jPZ`ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00Go2NX:
ooooooooooooooooo`000002ogmoO`03o`WZ2_moOgoo000000?oOgmo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo2?l9jPZ/ooooo`004?ooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00Go2NX:ooooooooooooooooo`00
0002ogmoO`03o`WZ2_moOgoo000000;oOgmo00?o2NX:o`000?ooool01Oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool6o`WZ2ZOooooo000@
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool01?l9jP[oooooooooool0
0003ogmoO`03o`WZ2_moOgoo000000;oOgmo00?o2NX:o`000?ooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`Ko2NX:Xoooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool5o`WZ2P06ooooool9jP[o
ooooooooool0003oOgmo0ol9jPX01_moOgoo0000ogmoOomoOgoo2NX:o`0000Gooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00oooool01?l9jP[oooooooooooooool7o`WZ2Ykooooo000@ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00oooool01?l9jP[ooooooooooooooolZo`WZ2P03o`000?oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00?ooooo1?l9jPYAooooo`?o000000?oooooo`000?ooool00ol00010ooooo`004?oooolPo`WZ
2P03ooooool9jP[ooooo00Cooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooool9jPX01?l9jPX00ooooooo0000o`000002ogmo
O`co2NX:00?oooooo`WZ2_ooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00?ooooo00Co2NX:oooooooooooooooo1Ol9jPY=ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool0?oooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool4o`WZ2P;ooooo00Co2NX:
oooooooooooo00000_moOgl5o`WZ2P04ogmoOol9jP[o0000o`0000?ooooo2?l9jPX4ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`07o`WZ2TOooooo
00Oo0000ooooool0003oooooo`000?oooooo0000047ooooo000@ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooo`000002ogmoO`;o2NX:0_moOgl01Ol0003o
OgmoogmoOol9jP[o000000Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooo`WZ2P07o`WZ
2P03ooooool9jP[ooooo00Cooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooooooooooool5
o`WZ2T?ooooo00Oo0000ooooool0003oooooo`000?oooooo0000047ooooo000@ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooo`000003ogmoO`04o`WZ2_mo
OgooOgmoo`0000;oOgmo00?o2NX:o`000?ooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool8o`WZ2PCooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooo`WZ2P04o`WZ2Soooooo0_l00003ooooo`;o0000@Oooool0013ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo000000?oOgmo00Co
2NX:ogmoOomoOgoo00000_moOgl00ol9jP[o0000ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooool9jPX02?l9jPX00ooooooo2NX:ooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo2NX:00Ko2NX:
>?ooool2o`0000?ooooo0_l00011ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooool000000omoOgl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ
2_l0003ooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo2?l9jPX4ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`03ooooo`Oo2NX:<oooool2o`0000Gooooo0_l00010ooooo`004?oo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooool000000omo
Ogl02?l9jP[oOgmoogmoOol0003oOgmoo`WZ2_moOgoo00000oooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooo2NX:00Oo2NX:00?oooooo`WZ2_ooool01?ooool00ol9jP[oooooooooo`02oooo
o`;o2NX:1?ooool9o`WZ2SGooooo00?o0000ooooooooool0?Oooool0013ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo000000?oOgmo00?o2NX:ogmoOomo
Ogl00_l000000ol9jP[o0000o`000003ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`So2NX:1?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00;ooooo2?l9jPXbooooo`03o`000?oooooooooo03cooooo000@ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`04o`WZ
2_ooooooooooooooo`?o2NX:1?ooool00ol9jP[oooooo`000002ogmoO`?o2NX:00KoOgmoo`000?mo
Ogoo2NX:ogmoOol00003ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooool9jPX01ol9jPX0
0ooooooo2NX:o`WZ2P04ooooo`04o`WZ2_ooooooooooooooo`So2NX:;oooool00ol0003ooooooooo
o`0kooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`Oo2NX:0_l00003ogmoO`Ko2NX:00?oOgmo
o`000?l000000_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00Co2NX:
oooooooooooooooo2?l9jPX5ooooo`03o`WZ2_oooooooooo00[o2NX:8Oooool9o`WZ2P03o`000?oo
oooooooo03Wooooo000@oooooeOo2NX:0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00?ooooo2Ol9jPX2ooooo`03o`WZ2_oooooo2NX:00Co2NX:00?oooooo`WZ2_l9jPX00_l9jPXN
ooooo`Ko2NX:00Coooooo`WZ2_l0003ooooo0_l9jPXhooooo`004?ooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`Go2NX:00?oooooo`WZ2_l000001?moOgl6o`WZ2P03ogmoOol0003ooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`0Io`WZ2PGooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
1?l9jP[ooooooooooooooolAo`WZ2QOooooo1?l9jPX00ooooooo2NX:o`WZ2P07o`WZ2P03o`000?oo
oooo2NX:03Oooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`04o`WZ2_ooooooooooooooo`;o2NX:1Oooool00ol9jP[o0000ogmo
O`02ogmoO`;o2NX:0_moOgl01Ol0003oOgmoo`WZ2_moOgoo000000?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo6?l9jPX4ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oooolBo`WZ2P[ooooo1Ol9jPX2ooooo`_o2NX:
00Go0000o`WZ2_ooooooooooo`WZ2P0fooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool01ol9jP[ooooooooooooooooo0000o`WZ
2_l000001?ooool00ol9jP[o0000ogmoO`02ogmoO`09o`000?l9jP[o0000ogmoOol0003oOgmoo`WZ
2_moOgoo000000?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00ooooolIo`WZ2P;ooooo0_l9jPX4ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool03Ol9jPX00ooooooo2NX:o`WZ2P03o`WZ2PCooooo
2_l9jPX2o`0000Co2NX:0_l000000ooooooo2NX:ooooo`0dooooo`004?ooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_l0003o000000?o000000?o2NX:o`000?moOgl00omoOgl00ol9jP[o0000o`00
0002o`000003o`WZ2_moOgoo000000?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo03?o2NX:0_l000002_l9jP[o0000o`000?l0003o2NX:o`000?oo
oooo2NX:ooooool9jPXbooooo`004?ooool00ol9jP[o0000o`000002o`000003o`WZ2_l0003o0000
00?o000000?o2NX:o`000?l000000_l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o0000
00?o000000?o2NX:o`000?l000000_l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o0000
00;o000000?o2NX:o`000?l000000ol000000ol9jP[o0000o`000002o`000003o`WZ2_l0003o0000
00?o000000?o2NX:o`000?l000000ol000000ol9jP[o0000o`000002o`000003o`WZ2_l0003o0000
00?o000000?o2NX:o`000?l000000_l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o0000
00?o000000?o2NX:o`000?l000000_l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o0000
00;o000000?o2NX:o`000?l000000ol000000ol9jP[o0000o`000002o`000003o`WZ2_l0003o0000
00?o000000?o2NX:o`000?l000000ol000000ol9jP[o0000o`000002o`000003o`WZ2_l0003o0000
00?o000000?o2NX:o`000?l000000_l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o0000
00;o000000?o2NX:o`000?l000000ol000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o0000
00;o000000?o2NX:o`000?l000000ol000000ol9jP[o0000o`000002o`000003o`WZ2_l0003o0000
00?o000000?o2NX:o`000?l000000_l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o0000
00?o00002_l9jPXbooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_l0003o000000;o
000000?oooooo`WZ2_l000001?moOgl00ol9jP[o0000o`000002o`000003o`WZ2_moOgoo000000?o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo7Ol9jPX3ooooo`_o2NX:1?ooool4o`WZ2PCooooo2_l9jPX00ol0003o2NX:o`WZ2P02o`0000;o
2NX:00Go0000o`WZ2_ooooooooooo`WZ2P0booooo`004?ooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool01_l9jP[ooooooooooooooooo0000
o`WZ2PGooooo00?o2NX:o`000?moOgl00_moOgl02Ol0003o2NX:o`WZ2_moOgoo0000ogmoOol9jP[o
Ogmoo`000003ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo7Ol9jPX4ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo2NX:00ko
2NX:3?ooool5o`WZ2P;ooooo1_l9jPX2o`0000Ko2NX:00?o0000o`WZ2_l9jPX00_ooool00ol9jP[o
ooooooooo`0_ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool01?l9jP[oooooooooooooool3o`WZ2PCooooo00?o2NX:o`000?mo
Ogl00omoOgl6o`WZ2P03ogmoOol0003ooooo00;ooooo00?o2NX:ooooooooool00oooool01?l9jP[o
oooooooooooooolNo`WZ2PGooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02oooo
o`;o2NX:1?ooool01?l9jP[oooooooooooooool<o`WZ2P04ooooool9jP[o2NX:o`WZ2QWooooo1?l9
jPX4ooooo`03o`WZ2_oooooo2NX:00Go2NX:00Ko0000o`WZ2_l9jP[o2NX:o`000?l9jPXaooooo`00
4?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`02ooooo`Oo2NX:00?o0000ogmoOomoOgl00_moOglEo`WZ2P03oooo
ool9jP[ooooo00Cooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool9o`WZ2P;ooooo2ol9jPXPooooo`Go2NX:
00?oooooo`WZ2_l9jPX01?l9jPX01_l0003o2NX:ooooool9jP[o0000o`WZ2S7ooooo000@ooooodWo
2NX:00?oOgmoo`000?l000000_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?o
oooo00Co2NX:oooooooooooooooo2?l9jPX5ooooo`co2NX::?ooool6o`WZ2P03ooooool9jP[o0000
00Go2NX:<Oooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool5o`WZ2P04ooooool9jP[oooooo`00
00;oOgmo0_l9jPX2ogmoO`05o`000?moOgoo2NX:ogmoOol000000oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooo2NX:00Oo2NX:00?oooooo`WZ2_l9jPX01?ooool00ol9jP[oooooooooo`08
o`WZ2Roooooo00Co2NX:ooooool9jP[ooooo2_l9jPX00ol0003oooooooooo`0^ooooo`004?ooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
1?l9jP[oooooooooooooool2o`WZ2PGooooo00?o2NX:ooooool000000omoOgl02?l9jP[oOgmoogmo
Ool0003oOgmoo`WZ2_moOgoo00000oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00_ooool8o`WZ2PCooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`09o`WZ2S;ooooo00Ko2NX:oooooooooooo2NX:ooooool9jPX2ooooo`03o`WZ2_l0
003o2NX:00Go2NX:0_l0000^ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooool000000omoOgl00ol9jP[oOgmoogmoO`02o`000003o`WZ2_l0003o
000000?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00oooool:o`WZ2P03ooooool9jP[ooooo00Cooooo00?o2NX:
ooooooooool00_ooool2o`WZ2P?ooooo2Ol9jPXfooooo`03o`WZ2_oooooo2NX:00;ooooo00Go2NX:
oooooooooooo2NX:o`000006o`WZ2P03o`000?l9jP[o000002gooooo000@ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooo`000003ogmoO`08o`WZ2_moOgoo
Ogmoo`000?moOgoo2NX:ogmoOol00004ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00oooool01?l9jP[oooooooooooooool8o`WZ2PGooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo1ol9jPXmooooo`03o`WZ2_oooooo2NX:
00;ooooo00Ko2NX:oooooooooooo2NX:o`000?l9jPX2ooooo`05o`WZ2_oooooo2NX:ooooool9jPX0
;_ooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooo000000?oOgmo00Co2NX:ogmoOomoOgoo00000_moOgl00ol9jP[o0000ooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooool9jPX01ol9jPX2ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`;o2NX:1?ooool8o`WZ2T7ooooo
00?o2NX:ooooool9jPX00_l9jPX2ooooo`04o`WZ2_oooooo0000o`WZ2P;ooooo0ol9jPX00ooooooo
2NX:ooooo`0]ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooool000000omoOgl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_l0003ooooo00?o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;o
oooo2?l9jPX4ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo2Ol9jPY5ooooo`03o`WZ2_oooooo2NX:00go
2NX:0_ooool00ol9jP[oooooooooo`0[ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooool000000_moOgl3o`WZ2P06ogmoOol0003oOgmoogmoOol9
jP[o00001?ooool00ol9jP[oooooooooo`03ooooo`[o2NX:00?oooooo`WZ2_ooool01?ooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Go2NX:Boooool00ol9jP[oooooo`WZ2P02oooo
o`07o`WZ2_ooooooooooo`WZ2_oooooo0000o`WZ2P02ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo
2NX:;Oooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool3o`WZ2P?ooooo00Co2NX:oooooooooooo
00000_moOgl7o`WZ2P;o00000_ooool8o`WZ2PGooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooo2NX:00Ko2NX:Coooool00ol9jP[oooooo`WZ2P02ooooo`07
o`WZ2_ooooooooooo`WZ2_oooooo0000o`WZ2P02ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:
;Oooool0013ooooo8_l9jPX5ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`Oo2NX:00?oooooo`000?l000000_moOgl;o`WZ2P03ooooool9
jP[ooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Go2NX:EOooool00ol9jP[oooooo`WZ2P02ooooo`07o`WZ2_ooooooooooo`WZ2_oooooo
0000o`WZ2P02ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:;Oooool0013ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo9ol9jPX00ol0
003o2NX:o`000005ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`02ooooo`Co2NX:F_ooool00ol9jP[oooooo`WZ2P02ooooo`07o`WZ2_oooooooooo
o`WZ2_oooooo0000o`WZ2P02ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:;Oooool0013ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool7o`WZ2P;ooooo00Co0000ogmoOol9jP[o2NX:0_moOgl01Ol0003o
OgmoogmoOol9jP[o000000Gooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`07o`WZ
2Ukooooo00?o2NX:ooooool9jPX00ol9jPX2ooooo`04o`WZ2_oooooo0000o`WZ2P;ooooo1Ol9jPX0
0ooooooo2NX:ooooo`0[ooooo`004?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`;o2NX:1?ooool01?l9
jP[oooooooooool00003ogmoO`03o`WZ2_moOgoo000000;oOgmo00?o2NX:o`000?ooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`02ooooo`Ko2NX:H_ooool01?l9jP[oooooooooool9jPX2ooooo`Wo2NX:00Oo
ooooo`WZ2_ooooooooooo`WZ2_oooooo2NX:02cooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool01Ol9jP[ooooooooooooooooo000000;oOgmo00?o2NX:ogmoOol0
00000_moOgl00ol9jP[o0000ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`03ooooo`Ko2NX:I_ooool01_l9jP[oooooooooool9jP[ooooo
o`WZ2P?ooooo00Go2NX:ooooool0003oooooo`WZ2P02ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo
2NX:;?ooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`05o`WZ
2_ooooooooooooooool000000_moOgl00ol9jP[oOgmoo`000003ogmoO`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool01?l9jP[oooooooooooooool8o`WZ2V_ooooo00Ko2NX:oooo
oooooooo2NX:ooooool9jPX3ooooo`05o`WZ2_oooooo0000ooooool9jPX00_ooool01_l9jP[ooooo
ooooool9jP[oooooo`WZ2Rcooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool01Ol9jP[ooooooooooooooooo000000;oOgmo00?o2NX:ogmoOol000000omoOgl00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo2?l9jPY_ooooo`03o`WZ2_oooooo2NX:
00;ooooo00Wo2NX:ooooooooooooooooo`WZ2_oooooo0000ooooool9jPX00_ooool01_l9jP[ooooo
ooooool9jP[oooooo`WZ2Rcooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool01Ol9jP[ooooooooooooooooo000000;oOgmo00?o2NX:ogmoOol000000ol000000ol9
jP[oooooooooo`07ooooo`Ko2NX:Loooool00ol9jP[oooooooooo`02o`WZ2P03ooooool9jP[ooooo
00;ooooo00Go2NX:ooooool0003oooooo`WZ2P02ooooo`04o`WZ2_oooooo2NX:o`WZ2P;ooooo00?o
2NX:ooooooooool0:Oooool0013ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00Go0000ogmoOol9jP[oOgmoo`000003ogmoO`03o`000?oo
oooo2NX:00So2NX:N?ooool01Ol9jP[oooooooooool9jP[ooooo00ko2NX:00Goooooo`WZ2_oooooo
ooooo`WZ2P0[ooooo`00Boooool3o`WZ2PCooooo1Ol9jPX00omoOgoo2NX:o`WZ2P07o`WZ2Wcooooo
00?o2NX:ooooool9jPX00oooool02Ol9jP[ooooooooooooooooo2NX:ooooool0003oooooo`WZ2P02
ooooo`07o`WZ2_ooooooooooooooool9jP[oooooo`WZ2P0[ooooo`004?oooolTo`WZ2QSooooo4?l9
jPZ1ooooo`03o`WZ2_oooooo2NX:00?ooooo00Wo2NX:ooooooooooooooooo`WZ2_oooooo0000oooo
ool9jPX00_ooool01ol9jP[ooooooooooooooooo2NX:ooooool9jPX0:oooool003?ooooo7ol9jPX0
0ol0003o2NX:o`WZ2P04o`WZ2P03ogmoOol0003ooooo087ooooo00?o2NX:ooooool9jPX00oooool0
2Ol9jP[ooooooooooooooooo2NX:ooooool0003oooooo`WZ2P03ooooo`06o`WZ2_ooooooooooo`WZ
2_oooooo2NX::oooool004cooooo1Ol9jPX2ooooo`?o2NX:1Ol00021ooooo`04o`WZ2_oooooooooo
o`WZ2P;ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[oooooo`000?oooooo2NX:00?ooooo00Co
2NX:oooooooooooo2NX:0_ooool00ol9jP[oooooooooo`0Xooooo`00Boooool2o`WZ2PGooooo00Go
2NX:ooooool0003oOgmoo`000003ogmoO`03o`000?oooooooooo07oooooo00?o2NX:ooooool9jPX0
1Ol9jPX3ooooo`05o`WZ2_oooooo0000ooooool9jPX00_ooool6o`WZ2P03ooooool9jP[ooooo02Wo
oooo001Dooooo`03o`000?moOgoo000000?oOgmo00?o0000ooooooooool0Ooooool00ol9jP[ooooo
o`WZ2P03ooooo`03o`WZ2_oooooo2NX:00Wo2NX:00?oooooo`WZ2_ooool00_ooool00ol9jP[ooooo
o`WZ2P0Zooooo`00EOooool6o`00087ooooo00?o2NX:ooooool9jPX00oooool00ol9jP[ooooooooo
o`02ooooo`05o`WZ2_oooooo0000ooooool9jPX00oooool01ol9jP[ooooooooooooooooo2NX:oooo
ool9jPX0:_ooool005Gooooo0_l00003ogmoO`03o`000?oooooooooo07oooooo00?o2NX:ooooool9
jPX00oooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_oooooo0000ooooool9jPX00oooool01ol9
jP[ooooooooooooooooo2NX:ooooool9jPX0:_ooool005Kooooo1Ol00020ooooo`04o`WZ2_oooooo
ooooo`WZ2P?ooooo00Go2NX:ooooooooooooooooo`WZ2P02ooooo`03o`000?oooooo2NX:00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooo`WZ2P0Yooooo`00foooool00ol9jP[ooooooooo
o`03o`WZ2P03ooooool9jP[ooooo00;ooooo00Ko2NX:oooooooooooo0000ooooool9jPX3ooooo`03
o`WZ2_oooooo2NX:00?o2NX:00?oooooo`WZ2_ooool0:?ooool00=_ooooo00Go2NX:oooooooooooo
2NX:ooooo`07o`WZ2P;ooooo00?o0000ooooool9jPX01_l9jPX2ooooo`03o`WZ2_oooooo2NX:02Wo
oooo003Kooooo`03o`WZ2_oooooo2NX:00?ooooo00?o2NX:ooooooooool00_ooool6o`WZ2PCooooo
00Oo2NX:ooooooooooooooooo`WZ2_oooooo2NX:02Wooooo003Kooooo`03o`WZ2_oooooo2NX:00?o
oooo00?o2NX:ooooooooool00_ooool01_l9jP[oooooooooool0003oooooo`WZ2PCooooo00Go2NX:
ooooooooooooooooo`WZ2P02ooooo`03o`WZ2_oooooooooo02Kooooo003Jooooo`04o`WZ2_oooooo
ooooo`WZ2P?ooooo00?o2NX:ooooooooool00_ooool01_l9jP[oooooooooool0003oooooo`WZ2PCo
oooo00Go2NX:ooooooooooooooooo`WZ2P02ooooo`03o`WZ2_oooooooooo02Kooooo003Jooooo`04
o`WZ2_ooooooooooo`WZ2P?ooooo00?o2NX:ooooooooool00_ooool01_l9jP[oooooooooool0003o
ooooo`WZ2PCooooo00Go2NX:ooooooooooooooooo`WZ2P02ooooo`03o`WZ2_oooooooooo02Kooooo
003Jooooo`04o`WZ2_oooooo2NX:ooooo`Co2NX:1?ooool01_l9jP[oooooooooool0003oooooo`WZ
2PCooooo1?l9jPX01?oooooo2NX:ooooool9jPXXooooo`00f_ooool00ol9jP[oooooo`WZ2P04oooo
oa3o2NX:1?ooool00ol9jP[oooooo`WZ2P0Xooooo`00fOooool01?l9jP[oooooooooool9jPX4oooo
o`03o`WZ2_oooooooooo00;ooooo00Ko2NX:oooooooooooo0000ooooool9jPX4ooooo`03o`WZ2_oo
oooooooo00;ooooo00Co2NX:oooooooooooo2NX:9oooool00=Wooooo00Co2NX:oooooooooooo2NX:
1?ooool00ol9jP[oooooooooo`02ooooo`06o`WZ2_ooooooooooo`000?oooooo2NX:1Oooool01Ol9
jP[ooooooooooooooooo2NX:00;ooooo00?o2NX:ooooooooool09Oooool00=Wooooo00?o2NX:oooo
ool9jPX01?ooool00ol9jP[oooooooooo`03ooooo`06o`WZ2_ooooooooooo`000?oooooo2NX:1Ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo2NX:02Oooooo003Iooooo`03o`WZ2_oooooo
2NX:00Go2NX:1Oooool01_l9jP[oooooooooool0003oooooo`WZ2PGooooo1_l9jPX00ooooooo2NX:
ooooo`0Vooooo`00fOooool00ol9jP[oooooo`WZ2P04ooooo`Go2NX:00Soooooo`WZ2_oooooooooo
o`000?oooooo2NX:ooooo`Ko2NX:0oooool00ol9jP[oooooo`WZ2P0Wooooo`00f?ooool01?l9jP[o
ooooooooool9jPX4ooooo`03o`WZ2_oooooooooo00;ooooo2Ol9jPX3ooooo`03o`WZ2_oooooooooo
00;ooooo00Co2NX:oooooooooooo2NX:9_ooool00=Sooooo00Co2NX:oooooooooooo2NX:1?ooool0
0ol9jP[oooooooooo`03ooooo`06o`WZ2_ooooooooooo`000?oooooo2NX:1Oooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooo2NX:02Kooooo003Hooooo`04o`WZ2_ooooooooooo`WZ2PCooooo
00?o2NX:ooooooooool00oooool01?l9jP[oooooooooool00002ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooo`WZ2P0Vooooo`00f?ooool00ol9jP[ooooo
ooooo`02o`WZ2P?ooooo00?o2NX:ooooooooool00oooool01?l9jP[oooooooooool00002ooooo`03
o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooooooooooo0ol9jPX00ooooooo2NX:ooooo`0Uoooo
o`00f?ooool00ol9jP[oooooo`WZ2P02ooooo`Co2NX:1Oooool01?l9jP[oooooooooool00002oooo
o`03o`WZ2_oooooooooo00;ooooo1?l9jPX2ooooo`03o`WZ2_oooooo2NX:02Kooooo003Gooooo`04
o`WZ2_ooooooooooo`WZ2PCooooo00?o2NX:ooooool9jPX03ol9jPX00ooooooo2NX:ooooo`03oooo
o`04o`WZ2_ooooooooooo`WZ2RGooooo003Gooooo`04o`WZ2_ooooooooooo`WZ2PCooooo00?o2NX:
ooooooooool01?ooool01?l9jP[oooooooooool00002ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool01?l9jP[oooooooooool9jPXUooooo`00eoooool01?l9jP[ooooooooo
ool9jPX4ooooo`03o`WZ2_oooooooooo00?ooooo00Go2NX:ooooooooooooooooo`000002ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooooooool9jPXUoooo
o`00eOooool01Ol9jP[oooooo`WZ2_oooooo2NX:00?ooooo00?o2NX:ooooool9jPX00oooool03?l9
jP[oooooo`WZ2_oooooo0000ooooool0003oooooo`000?l9jP[oooooo`WZ2P?ooooo00?o2NX:oooo
ool9jPX00oooool01Ol9jP[oooooo`WZ2_oooooo2NX:02?ooooo003Eooooo`03o`WZ2_oooooo2NX:
00Ko2NX:00Woooooo`WZ2_oooooo2NX:ooooool9jP[oooooo`WZ2_ooool01Ol000002?l9jP[ooooo
o`WZ2_oooooo2NX:ooooool9jP[ooooo1ol9jPX00ooooooo2NX:ooooo`0Rooooo`00eOooool5o`WZ
2P?ooooo2_l9jPX5o`0000Wo2NX:0oooool5o`WZ2R?ooooo003Eooooo`Go2NX:0oooool4o`WZ2P;o
oooo3?l9jPX2ooooo`Co2NX:0oooool5o`WZ2R?ooooo003Eooooo`Co2NX:1?ooool4o`WZ2P?ooooo
0ol9jPX01?oooooo0000o`000?l00003o`WZ2P?ooooo1?l9jPX4ooooo`Co2NX:8oooool00=Gooooo
1?l9jPX5ooooo`;o2NX:1?ooool3o`WZ2P04ooooool0003o0000o`0000?o2NX:1?ooool2o`WZ2PGo
oooo1?l9jPXSooooo`00eOooool2o`WZ2P03ooooool9jP[ooooo00Cooooo0_l9jPX4ooooo`?o2NX:
00Coooooo`000?l0003o00000ol9jPX4ooooo`;o2NX:1Oooool01?l9jP[oooooo`WZ2_l9jPX@oooo
o`?o00004?ooool00=Gooooo0_l9jPX00ooooooo2NX:ooooo`04ooooo`;o2NX:1Oooool01Ol9jP[o
oooooooooooooooo000000;ooooo00?o2NX:ooooooooool00oooool2o`WZ2PGooooo00Co2NX:oooo
ool9jP[o2NX:4?ooool01?l0003oooooooooool0000?ooooo`00b_ooool>o`000003o`WZ2_l0003o
000001ko000000?o2NX:o`000?l000003Ol00007ooooo`03o`000?oooooooooo00gooooo003Eoooo
o`;o00001_ooool2o`0000Kooooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo0_l0000@oooo
o`;o00004?ooool00?oooooo3_ooool00ol0003oooooooooo`0@ooooo`00ooooool>ooooo`04o`00
0?ooooooooooo`0000oooooo003oooooo`oooooo0ol0000?ooooo`00oooooolQooooo`00oooooolQ
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {111.75, 0}} -> {-13.0976, -35.3444, 0.807039, \
0.807039}},
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.4"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.3 Reflected ThickLens Example", "Subsection",
  CellTags->{"AOG0.", "4.3", "AOG4.", "AOG4.3", "AOG4.3.1"}],

Cell[CellGroupData[{

Cell["Set-up", "Subsubsection",
  CellTags->{"AOG0.", "4.3.1", "AOG4.", "AOG4.3", "AOG4.3.1"}],

Cell["\<\
thinopticalsystemreflected2 = {
GaussianBeam[{20.,15.},{.01,.05},SymbolicWaveLength->\[Lambda],NumberOfRays->\
6],
Move[ThinLens[{{f1,100},{f2,150}},50],{d1,50}],
Move[Mirror[{b,20}],175,-45],
Move[Screen[50],{175,50},90]};\
\>", "Input",
  CellLabel->"In[35]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[thinopticalsystemreflected2];", "Input",
  CellLabel->"In[36]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .62999 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0178944 1.01789 -0.170572 1.01789 [
[ 0 0 0 0 ]
[ 1 .62999 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .62999 L
0 .62999 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.14167 .47112 m
.32021 .41522 L
s
.09897 .37837 m
.27783 .31461 L
s
.12323 .45473 m
.30234 .39779 L
s
.09752 .3987 m
.27671 .33703 L
s
0 g
.31704 .3488 m
.32494 .37503 L
s
.30635 .324 m
.31704 .3488 L
s
.32494 .37503 m
.32955 .40108 L
s
.039 .916 .04 r
.10445 .43811 m
.28418 .38008 L
s
0 g
.29352 .3022 m
.30635 .324 L
s
.039 .916 .04 r
.09585 .41931 m
.27557 .3597 L
s
0 g
.32955 .40108 m
.33056 .42531 L
s
.27933 .28479 m
.29352 .3022 L
s
.33056 .42531 m
.32787 .44617 L
s
.33056 .42531 m
.31234 .40754 L
s
.33056 .42531 m
.33056 .42531 L
s
.039 .916 .04 r
.09396 .44018 m
.27442 .3826 L
s
.08533 .42125 m
.26573 .36209 L
s
0 g
.27933 .28479 m
.27933 .28479 L
s
.27933 .28479 m
.2779 .31318 L
s
.26467 .27297 m
.27933 .28479 L
s
0 0 0 r
2 Mabswid
.32021 .41522 Mdot
.039 .916 .04 r
.5 Mabswid
.09183 .46132 m
.27325 .40575 L
s
0 g
.32787 .44617 m
.32157 .46225 L
s
.31234 .40754 m
.29382 .38948 L
s
.039 .916 .04 r
.06585 .40415 m
.24699 .34381 L
s
.08947 .48273 m
.27208 .42916 L
s
0 g
.2779 .31318 m
.27646 .34195 L
s
.25049 .26763 m
.26467 .27297 L
s
0 0 0 r
2 Mabswid
.27783 .31461 Mdot
.30234 .39779 Mdot
0 g
.5 Mabswid
.32157 .46225 m
.31201 .47238 L
s
.29382 .38948 m
.27499 .37112 L
s
0 0 0 r
2 Mabswid
.27671 .33703 Mdot
.039 .916 .04 r
.5 Mabswid
.04601 .3868 m
.22794 .32523 L
s
0 g
.80491 .27123 m
.78545 .29128 L
s
.82812 .25515 m
.80491 .27123 L
s
.27646 .34195 m
.27499 .37112 L
s
.78545 .29128 m
.771 .31404 L
s
.85364 .24408 m
.82812 .25515 L
s
.23776 .26927 m
.25049 .26763 L
s
.771 .31404 m
.76249 .33806 L
s
0 0 0 r
2 Mabswid
.28418 .38008 Mdot
0 g
.5 Mabswid
.87983 .23877 m
.85364 .24408 L
s
.85364 .24408 m
.85364 .24408 L
s
.85364 .24408 m
.85612 .27269 L
s
.31201 .47238 m
.29976 .47575 L
s
0 0 0 r
2 Mabswid
.27557 .3597 Mdot
0 g
.5 Mabswid
.76249 .33806 m
.76055 .36183 L
s
.27499 .37112 m
.27351 .40069 L
s
.27499 .37112 m
.25586 .35246 L
s
.90502 .23962 m
.87983 .23877 L
s
0 0 0 r
2 Mabswid
.27442 .3826 Mdot
0 g
.5 Mabswid
.22738 .27796 m
.23776 .26927 L
s
.85612 .27269 m
.85864 .30169 L
s
0 0 0 r
2 Mabswid
.26573 .36209 Mdot
0 g
.5 Mabswid
.76055 .36183 m
.7654 .38377 L
s
.76055 .36183 m
.7938 .35167 L
s
.76055 .36183 m
.76055 .36183 L
s
.29976 .47575 m
.2856 .47194 L
s
.92753 .24669 m
.90502 .23962 L
s
.27351 .40069 m
.272 .43066 L
s
0 0 0 r
2 Mabswid
.27325 .40575 Mdot
0 g
.5 Mabswid
.25586 .35246 m
.23641 .33349 L
s
.7938 .35167 m
.82735 .34143 L
s
.7654 .38377 m
.77682 .40239 L
s
0 0 0 r
2 Mabswid
.80457 .34838 Mdot
0 g
.5 Mabswid
.85864 .30169 m
.86119 .33109 L
s
.22014 .29325 m
.22738 .27796 L
s
0 0 0 r
2 Mabswid
.24699 .34381 Mdot
0 g
.5 Mabswid
.94579 .25961 m
.92753 .24669 L
s
0 0 0 r
2 Mabswid
.82661 .34165 Mdot
0 g
.5 Mabswid
.82735 .34143 m
.86119 .33109 L
s
0 0 0 r
2 Mabswid
.27208 .42916 Mdot
0 g
.5 Mabswid
.2856 .47194 m
.27048 .46106 L
s
.272 .43066 m
.27048 .46106 L
s
0 0 0 r
2 Mabswid
.84954 .33465 Mdot
.86067 .32509 Mdot
0 g
.5 Mabswid
.77682 .40239 m
.79418 .41637 L
s
.23641 .33349 m
.21663 .3142 L
s
0 0 0 r
2 Mabswid
.86088 .32752 Mdot
.86109 .32991 Mdot
0 g
.5 Mabswid
.86378 .36091 m
.86119 .33109 L
s
.86119 .33109 m
.89535 .32066 L
s
0 0 0 r
2 Mabswid
.8613 .33228 Mdot
.86151 .33467 Mdot
0 g
.5 Mabswid
.21663 .3142 m
.22014 .29325 L
s
.95848 .2776 m
.94579 .25961 L
s
0 0 0 r
2 Mabswid
.86172 .33711 Mdot
.87288 .32752 Mdot
.22794 .32523 Mdot
0 g
.5 Mabswid
.27048 .46106 m
.27048 .46106 L
s
.27048 .46106 m
.25547 .44374 L
s
.89535 .32066 m
.92982 .31014 L
s
0 0 0 r
2 Mabswid
.8961 .32043 Mdot
0 g
.5 Mabswid
.79418 .41637 m
.81637 .42465 L
s
.86641 .39114 m
.86378 .36091 L
s
.21663 .3142 m
.21663 .3142 L
s
.21718 .33937 m
.21663 .3142 L
s
0 0 0 r
2 Mabswid
.91868 .31354 Mdot
0 g
.5 Mabswid
.9646 .29951 m
.95848 .2776 L
s
.25547 .44374 m
.2417 .42115 L
s
.92982 .31014 m
.9646 .29951 L
s
.81637 .42465 m
.84192 .42654 L
s
.2218 .36695 m
.21718 .33937 L
s
.2417 .42115 m
.23018 .39491 L
s
.96361 .32386 m
.9646 .29951 L
s
.9646 .29951 m
.9646 .29951 L
s
.86641 .39114 m
.86907 .42181 L
s
.23018 .39491 m
.2218 .36695 L
s
.84192 .42654 m
.86907 .42181 L
s
.95548 .34892 m
.96361 .32386 L
s
.86907 .42181 m
.86907 .42181 L
s
.86907 .42181 m
.89587 .41071 L
s
.94071 .37289 m
.95548 .34892 L
s
.89587 .41071 m
.92035 .394 L
s
.92035 .394 m
.94071 .37289 L
s
.77598 .18818 m .77891 .17736 L .78956 .18293 L .766 .489 .516 r
F
.76845 .18593 m .77891 .17736 L .77598 .18818 L F
.76845 .18593 m .76765 .174 L .77891 .17736 L F
.78311 .1919 m .78956 .18293 L .7989 .19033 L F
.77598 .18818 m .78956 .18293 L .78311 .1919 L F
0 g
.77891 .17736 m
.78956 .18293 L
s
.76103 .18532 m .76765 .174 L .76845 .18593 L .766 .489 .516 r
F
.76103 .18532 m .75654 .17306 L .76765 .174 L F
0 g
.76765 .174 m
.77891 .17736 L
s
.76765 .174 m
.76765 .174 L
s
.78935 .19686 m .7989 .19033 L .80632 .19908 L .766 .489 .516 r
F
.78311 .1919 m .7989 .19033 L .78935 .19686 L F
0 g
.78956 .18293 m
.7989 .19033 L
s
.7542 .18638 m .75654 .17306 L .76103 .18532 L .766 .489 .516 r
F
.7542 .18638 m .74631 .17463 L .75654 .17306 L F
0 g
.75654 .17306 m
.76765 .174 L
s
.7943 .20271 m .80632 .19908 L .8113 .2086 L .766 .489 .516 r
F
.78935 .19686 m .80632 .19908 L .7943 .20271 L F
0 g
.7989 .19033 m
.80632 .19908 L
s
.77304 .19907 m .77598 .18818 L .78311 .1919 L .766 .489 .516 r
F
.039 .916 .04 r
.77473 .19786 m
.86067 .32509 L
s
.76926 .19794 m .77598 .18818 L .77304 .19907 L .766 .489 .516 r
F
.76926 .19794 m .76845 .18593 L .77598 .18818 L F
.77661 .20093 m .78311 .1919 L .78935 .19686 L F
.77304 .19907 m .78311 .1919 L .77661 .20093 L F
.74844 .18905 m .74631 .17463 L .7542 .18638 L F
.74844 .18905 m .73766 .1786 L .74631 .17463 L F
0 g
.74631 .17463 m
.75654 .17306 L
s
.76554 .19764 m .76845 .18593 L .76926 .19794 L .766 .489 .516 r
F
.76554 .19764 m .76103 .18532 L .76845 .18593 L F
0 g
.76765 .174 m
.76845 .18593 L
s
.039 .916 .04 r
.27783 .31461 m
.76287 .19035 L
s
.77974 .20342 m .78935 .19686 L .7943 .20271 L .766 .489 .516 r
F
.77661 .20093 m .78935 .19686 L .77974 .20342 L F
.79761 .20907 m .8113 .2086 L .8135 .21825 L F
.7943 .20271 m .8113 .2086 L .79761 .20907 L F
0 g
.80632 .19908 m
.8113 .2086 L
s
0 0 0 r
2 Mabswid
.76865 .18886 Mdot
.76213 .19818 m .76103 .18532 L .76554 .19764 L .766 .489 .516 r
F
.76213 .19818 m .7542 .18638 L .76103 .18532 L F
.78222 .20636 m .7943 .20271 L .79761 .20907 L F
.77974 .20342 m .7943 .20271 L .78222 .20636 L F
.75925 .19952 m .7542 .18638 L .76213 .19818 L F
.75925 .19952 m .74844 .18905 L .7542 .18638 L F
.039 .916 .04 r
.5 Mabswid
.27671 .33703 m
.76755 .1978 L
s
.74413 .19315 m .73766 .1786 L .74844 .18905 L .766 .489 .516 r
F
.74413 .19315 m .73118 .18473 L .73766 .1786 L F
0 g
.73766 .1786 m
.74631 .17463 L
s
.79761 .20907 m .8135 .21825 L .79906 .21551 L .766 .489 .516 r
F
.78387 .20954 m .79761 .20907 L .79906 .21551 L F
.78222 .20636 m .79761 .20907 L .78387 .20954 L F
.79906 .21551 m .8135 .21825 L .81275 .22739 L F
.039 .916 .04 r
.76976 .19809 m
.86088 .32752 L
s
.81294 .2251 m
.91868 .31354 L
s
.22794 .32523 m
.80018 .21649 L
s
0 g
.8113 .2086 m
.8135 .21825 L
s
.8135 .21825 m
.8135 .21825 L
s
.77008 .21002 m .77304 .19907 L .77661 .20093 L .766 .489 .516 r
F
.77008 .21002 m .76926 .19794 L .77304 .19907 L F
.77008 .21002 m .77661 .20093 L .77974 .20342 L F
0 0 0 r
2 Mabswid
.76922 .19733 Mdot
.77008 .21002 m .76554 .19764 L .76926 .19794 L .766 .489 .516 r
F
0 g
.5 Mabswid
.76845 .18593 m
.76926 .19794 L
s
.77008 .21002 m .77974 .20342 L .78222 .20636 L .766 .489 .516 r
F
.77008 .21002 m .76213 .19818 L .76554 .19764 L F
.7571 .20158 m .74844 .18905 L .75925 .19952 L F
.7571 .20158 m .74413 .19315 L .74844 .18905 L F
0 0 0 r
2 Mabswid
.80218 .21611 Mdot
.77008 .21002 m .78222 .20636 L .78387 .20954 L .766 .489 .516 r
F
.039 .916 .04 r
.5 Mabswid
.77284 .20992 m
.86109 .32991 L
s
.78387 .20954 m .79906 .21551 L .78458 .21277 L .766 .489 .516 r
F
.79906 .21551 m .81275 .22739 L .79854 .2216 L F
.78458 .21277 m .79906 .21551 L .79854 .2216 L F
0 g
.79906 .21551 m
.8135 .21825 L
s
.039 .916 .04 r
.79287 .21801 m
.8961 .32043 L
s
.24699 .34381 m
.78641 .21393 L
s
.77008 .21002 m .75925 .19952 L .76213 .19818 L .766 .489 .516 r
F
.039 .916 .04 r
.27557 .3597 m
.7667 .20675 L
s
.77008 .21002 m .78387 .20954 L .78458 .21277 L .766 .489 .516 r
F
.74158 .19842 m .73118 .18473 L .74413 .19315 L F
.74158 .19842 m .72732 .19262 L .73118 .18473 L F
0 g
.73118 .18473 m
.73766 .1786 L
s
0 0 0 r
2 Mabswid
.78829 .21347 Mdot
.77008 .21002 m .7571 .20158 L .75925 .19952 L .766 .489 .516 r
F
.78458 .21277 m .79854 .2216 L .78431 .21581 L F
.77008 .21002 m .78458 .21277 L .78431 .21581 L F
0 g
.5 Mabswid
.78458 .21277 m
.79906 .21551 L
s
.039 .916 .04 r
.77731 .21296 m
.87288 .32752 L
s
.26573 .36209 m
.774 .21162 L
s
.79854 .2216 m .81275 .22739 L .80909 .23538 L .766 .489 .516 r
F
0 g
.81275 .22739 m
.8135 .21825 L
s
0 0 0 r
2 Mabswid
.76979 .20578 Mdot
.75583 .20422 m .74413 .19315 L .7571 .20158 L .766 .489 .516 r
F
.75583 .20422 m .74158 .19842 L .74413 .19315 L F
.79854 .2216 m .80909 .23538 L .79607 .22692 L F
.78431 .21581 m .79854 .2216 L .79607 .22692 L F
.77008 .21002 m .75583 .20422 L .7571 .20158 L F
0 0 0 r
.77576 .2111 Mdot
.78431 .21581 m .79607 .22692 L .78307 .21846 L .766 .489 .516 r
F
.77008 .21002 m .78431 .21581 L .78307 .21846 L F
.77008 .21002 m .75554 .20726 L .75583 .20422 L F
.77008 .21002 m .75624 .21049 L .75554 .20726 L F
.039 .916 .04 r
.5 Mabswid
.30234 .39779 m
.75555 .20734 L
s
.28418 .38008 m
.76117 .21033 L
s
.7656 .21017 m
.84954 .33465 L
s
.75735 .21046 m
.82661 .34165 L
s
.77008 .21002 m .75788 .2137 L .75624 .21049 L .766 .489 .516 r
F
.77008 .21002 m .76036 .21666 L .75788 .2137 L F
.77008 .21002 m .7635 .21916 L .76036 .21666 L F
.039 .916 .04 r
.27442 .3826 m
.76124 .21736 L
s
.77008 .21002 m .7671 .22104 L .7635 .21916 L .766 .489 .516 r
F
.77008 .21002 m .7709 .22217 L .7671 .22104 L F
.77008 .21002 m .77464 .22246 L .7709 .22217 L F
.039 .916 .04 r
.77278 .2174 m
.8613 .33228 L
s
.77008 .21002 m .77806 .22191 L .77464 .22246 L .766 .489 .516 r
F
.77008 .21002 m .78094 .22054 L .77806 .22191 L F
.77008 .21002 m .78307 .21846 L .78094 .22054 L F
0 g
.77008 .21002 m
.78458 .21277 L
s
.76926 .19794 m
.77008 .21002 L
s
.75554 .20726 m .74158 .19842 L .75583 .20422 L .766 .489 .516 r
F
0 0 0 r
2 Mabswid
.76483 .20902 Mdot
.78307 .21846 m .79182 .2311 L .78094 .22054 L .766 .489 .516 r
F
.78307 .21846 m .79607 .22692 L .79182 .2311 L F
.74097 .2045 m .72732 .19262 L .74158 .19842 L F
.75554 .20726 m .74097 .2045 L .74158 .19842 L F
.79607 .22692 m .80274 .24167 L .79182 .2311 L F
.79607 .22692 m .80909 .23538 L .80274 .24167 L F
0 g
.5 Mabswid
.80909 .23538 m
.81275 .22739 L
s
0 0 0 r
2 Mabswid
.77036 .21426 Mdot
.74097 .2045 m .72636 .20173 L .72732 .19262 L .766 .489 .516 r
F
0 g
.5 Mabswid
.72732 .19262 m
.73118 .18473 L
s
0 0 0 r
2 Mabswid
.75567 .20729 Mdot
.75624 .21049 m .74097 .2045 L .75554 .20726 L .766 .489 .516 r
F
.039 .916 .04 r
.5 Mabswid
.74909 .20769 m
.80457 .34838 L
s
0 g
.75554 .20726 m
.77008 .21002 L
s
.039 .916 .04 r
.32021 .41522 m
.74668 .20674 L
s
.78094 .22054 m .78608 .23385 L .77806 .22191 L .766 .489 .516 r
F
.78094 .22054 m .79182 .2311 L .78608 .23385 L F
0 0 0 r
2 Mabswid
.74839 .20591 Mdot
.75624 .21049 m .74234 .21097 L .74097 .2045 L .766 .489 .516 r
F
.75788 .2137 m .74234 .21097 L .75624 .21049 L F
.77806 .22191 m .77922 .23497 L .77464 .22246 L F
.039 .916 .04 r
.5 Mabswid
.77902 .23278 m
.86151 .33467 L
s
.77806 .22191 m .78608 .23385 L .77922 .23497 L .766 .489 .516 r
F
.74234 .21097 m .72636 .20173 L .74097 .2045 L F
0 g
.74097 .2045 m
.75554 .20726 L
s
.75788 .2137 m .74562 .2174 L .74234 .21097 L .766 .489 .516 r
F
.76036 .21666 m .74562 .2174 L .75788 .2137 L F
.79182 .2311 m .79412 .24583 L .78608 .23385 L F
.79182 .2311 m .80274 .24167 L .79412 .24583 L F
0 g
.80274 .24167 m
.80909 .23538 L
s
.77464 .22246 m .77172 .23439 L .7709 .22217 L .766 .489 .516 r
F
.039 .916 .04 r
.77372 .22622 m
.77791 .23141 L
s
.77464 .22246 m .77922 .23497 L .77172 .23439 L .766 .489 .516 r
F
.039 .916 .04 r
.77424 .23458 m
.86172 .33711 L
s
.76036 .21666 m .75058 .22333 L .74562 .2174 L .766 .489 .516 r
F
.7635 .21916 m .75058 .22333 L .76036 .21666 L F
.7709 .22217 m .7641 .23213 L .7671 .22104 L F
.039 .916 .04 r
.27325 .40575 m
.76615 .22455 L
s
.7709 .22217 m .77172 .23439 L .7641 .23213 L .766 .489 .516 r
F
0 g
.77008 .21002 m
.7709 .22217 L
s
.039 .916 .04 r
.27208 .42916 m
.76728 .23307 L
s
0 0 0 r
2 Mabswid
.77094 .22279 Mdot
.7635 .21916 m .75689 .22836 L .75058 .22333 L .766 .489 .516 r
F
.7671 .22104 m .75689 .22836 L .7635 .21916 L F
.7671 .22104 m .7641 .23213 L .75689 .22836 L F
.74234 .21097 m .7284 .21145 L .72636 .20173 L F
0 g
.5 Mabswid
.72636 .20173 m
.72732 .19262 L
s
.72636 .20173 m
.74097 .2045 L
s
.72636 .20173 m
.72636 .20173 L
s
.74562 .2174 m .7284 .21145 L .74234 .21097 L .766 .489 .516 r
F
.78608 .23385 m .78382 .24754 L .77922 .23497 L F
.78608 .23385 m .79412 .24583 L .78382 .24754 L F
0 g
.79412 .24583 m
.80274 .24167 L
s
.74562 .2174 m .7333 .22111 L .7284 .21145 L .766 .489 .516 r
F
0 g
.72636 .20173 m
.7284 .21145 L
s
.75058 .22333 m .7333 .22111 L .74562 .2174 L .766 .489 .516 r
F
.77922 .23497 m .77255 .24668 L .77172 .23439 L F
.77922 .23497 m .78382 .24754 L .77255 .24668 L F
0 0 0 r
2 Mabswid
.77152 .23139 Mdot
.75058 .22333 m .74075 .23004 L .7333 .22111 L .766 .489 .516 r
F
0 g
.5 Mabswid
.7284 .21145 m
.7333 .22111 L
s
.75689 .22836 m .74075 .23004 L .75058 .22333 L .766 .489 .516 r
F
.77172 .23439 m .76108 .24329 L .7641 .23213 L F
.77172 .23439 m .77255 .24668 L .76108 .24329 L F
0 g
.7709 .22217 m
.77172 .23439 L
s
.77172 .23439 m
.77255 .24668 L
s
.78382 .24754 m
.79412 .24583 L
s
.75689 .22836 m .75023 .23761 L .74075 .23004 L .766 .489 .516 r
F
.7641 .23213 m .75023 .23761 L .75689 .22836 L F
.7641 .23213 m .76108 .24329 L .75023 .23761 L F
0 g
.7333 .22111 m
.74075 .23004 L
s
.77255 .24668 m
.78382 .24754 L
s
.74075 .23004 m
.75023 .23761 L
s
.76108 .24329 m
.77255 .24668 L
s
.77255 .24668 m
.77255 .24668 L
s
.75023 .23761 m
.76108 .24329 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[36]:=",
  ImageSize->{939.188, 591.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>[0002Cb000`400?l00000o`00003ooooooooo
oooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00
oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^
ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooo
oooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooo
oooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo
003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooooooooooo
ojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooo
ooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oo
ooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_oo
ool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooo
oooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooo
oooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00
oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^
ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooo
oooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooo
oooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo
003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooooooooooo
ojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooo
ooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oo
ooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_oo
ool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooo
oooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooo
oooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00
oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^
ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooo
oooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooo
oooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo
003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooooooooooo
ojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooo
ooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oo
ooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_oo
ool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooo
oooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooo
oooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00
oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^
ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooo
oooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooo
oooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo
003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooooooooooo
ojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooo
ooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oo
ooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_oo
ool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooo
oooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooo
oooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00
oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^
ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooo
oooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooo
oooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo
003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooooooooooo
ojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooo
ooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oo
ooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_oo
ool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooo
oooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooo
oooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00
oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^
ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooo
oooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooo
oooooooooooooon^ooooo`00ooooooooooooolGooooo2Ol0003Oooooo`00oooooooooooool3ooooo
1Ol00009olAmQ0Oo0000f?ooool00?oooooooooooonmooooo`?o00004_o4OH@00ol0003oa7f4olAm
Q003o`000=Gooooo003ooooooooooooo^_ooool3o`0001Goa7f400?o0000olAmQ?o4OH@00oo4OH@3
o`000=;ooooo003ooooooooooooo]oooool3o`0001Soa7f400?o0000olAmQ?o4OH@01_o4OH@3o`00
0<oooooo003ooooooooooooo]Oooool2o`0001_oa7f400?o0000olAmQ?o4OH@02Oo4OH@2o`000<go
oooo003ooooooooooooo]?ooool00ol0003oa7f4olAmQ00KolAmQ003o`000?o4OHCoa7f400_oa7f4
0_l0003;ooooo`00oooooooooooook?ooooo00?o0000olAmQ?o4OH@07?o4OH@00ol0003oa7f4olAm
Q00=olAmQ0;o0000bOooool00?oooooooooooonbooooo`03o`000?o4OHCoa7f401goa7f400?o0000
olAmQ?o4OH@03oo4OH@2o`000<Oooooo003ooooooooooooo/Oooool00ol0003oa7f4olAmQ00NolAm
Q003o`000?o4OHCoa7f4017oa7f40_l00035ooooo`00oooooooooooook3ooooo00?o0000olAmQ?o4
OH@07oo4OH@00ol0003oa7f4olAmQ00ColAmQ003o`000?oooooooooo0<;ooooo003ooooooooooooo
[oooool00ol0003oa7f4olAmQ00PolAmQ003o`000?o4OHCoa7f401Coa7f400?o0000ooooooooool0
`Oooool00?oooooooooooon_ooooo`03o`000?o4OHCoa7f4023oa7f400?o0000olAmQ?o4OH@05Oo4
OH@2o`000<7ooooo003ooooooooooooo[_ooool00ol0003oa7f4olAmQ00QolAmQ003o`000?o4OHCo
a7f401Ooa7f400?o0000ooooooooool0__ooool00?oooooooooooon^ooooo`03o`000?o4OHCoa7f4
027oa7f40_l0000IolAmQ003o`000?oooooooooo0;gooooo003ooooooooooooo[Oooool00ol0003o
a7f4olAmQ00RolAmQ0;o00006_o4OH@00ol0003oooooooooo`2looooo`00ooooooooooooojgooooo
00?o0000olAmQ?o4OH@07Oo4OH@00ol9jP[oa7f4olAmQ002olAmQ003o`000?o4OHCoa7f401[oa7f4
00?o0000ooooooooool0^oooool00?oooooooooooon]ooooo`03o`000?o4OHCoa7f402;oa7f400?o
0000olAmQ?o4OH@06_o4OH@00ol0003oooooooooo`2kooooo`00ooooooooooooojcooooo00?o0000
olAmQ?o4OH@09?o4OH@00ol0003oa7f4olAmQ00JolAmQ003o`000?oooooooooo0;[ooooo003ooooo
oooooooo[?ooool00ol0003oa7f4olAmQ00TolAmQ003o`000?o4OHCoa7f401_oa7f400?o0000oooo
ooooool0^Oooool00?oooooooooooon/ooooo`03o`000?o4OHCoa7f402Coa7f400?o0000olAmQ?o4
OH@07?o4OH@00ol0003oooooooooo`2hooooo`00ooooooooooooojcooooo00?o0000olAmQ?o4OH@0
9?o4OH@00ol0003oa7f4olAmQ00MolAmQ003o`000?oooooooooo0;Oooooo003ooooooooooooo[?oo
ool00ol0003oa7f4olAmQ00TolAmQ0;o00007oo4OH@00ol0003oooooooooo`2fooooo`00oooooooo
oooooj_ooooo00?o0000olAmQ?o4OH@08Oo4OH@3o`WZ2P03olAmQ?l0003o000000?oa7f400?o2NX:
olAmQ?o4OH@06_o4OH@00ol0003oooooooooo`2eooooo`00oooooooooooooj_ooooo00?o0000olAm
Q?o4OH@07_o4OH@2o`WZ2PGoa7f400?o0000olAmQ?o4OH@08?o4OH@00ol0003oooooooooo`2doooo
o`00ooooooooooooojSooooo0ol9jPX00ol0003oa7f4olAmQ00LolAmQ003o`WZ2_o4OHCoa7f400Ko
a7f400?o0000olAmQ?o4OH@08?o4OH@00ol0003oooooooooo`2dooooo`00ooooooooooooojCooooo
1?l9jPX3ooooo`03o`000?o4OHCoa7f402Goa7f400?o0000olAmQ?o4OH@08Oo4OH@00ol0003ooooo
ooooo`2cooooo`00oooooooooooooj3ooooo1?l9jPX7ooooo`?o00009Oo4OH@00ol0003oa7f4olAm
Q00QolAmQ003o`000?oooooooooo0;?ooooo003oooooooooooooW?ooool4o`WZ2P_ooooo00?o0000
olAmQ?o4OH@01Ol0000PolAmQ003o`000?o4OHCoa7f402;oa7f400?o0000ooooooooool0/_ooool0
0?oooooooooooonHooooo`Co2NX:3oooool00ol0003oa7f4olAmQ005olAmQ0Go00006oo4OH@00ol0
003oa7f4olAmQ00RolAmQ003o`000?oooooooooo0;;ooooo003oooooooooooooUOooool3o`WZ2QCo
oooo00?o0000olAmQ?o4OH@02Oo4OH@5o`0000;oa7f40_l0000BolAmQ0;o00008oo4OH@00ol0003o
ooooooooo`2booooo`00oooooooooooooi7ooooo1?l9jPXGooooo`03o`000?o4OHCoa7f400koa7f4
1ol0000?olAmQ0;o00009?o4OH@00ol0003oooooooooo`2aooooo`00ooooooooooooohgooooo1?l9
jPXKooooo`03o`000?o4OHCoa7f400ooa7f400?o2NX:olAmQ?o4OH@00oo4OH@5o`0000Soa7f400Co
2NX:olAmQ?o4OHCo00009?o4OH@00ol0003oooooooooo`2aooooo`00ooooooooooooohWooooo1?l9
jPXOooooo`03o`000?o4OHCoa7f401Ooa7f40_l000000oo4OHCo0000o`000005o`0000Coa7f400?o
0000olAmQ?o4OH@08oo4OH@00ol0003oooooooooo`2`ooooo`00ooooooooooooohGooooo1?l9jPXP
ooooo`?o2NX:00?o0000olAmQ?o4OH@07oo4OH@5o`000003olAmQ?l0003oa7f402Coa7f400?o0000
ooooooooool0/?ooool00?oooooooooooon1ooooo`Co2NX:8?ooool4o`WZ2PCooooo00?o0000olAm
Q?o4OH@06?o4OH@01?l9jP[oa7f4o`WZ2_l9jPX4olAmQ003o`WZ2_o4OHCoa7f400Go000000?oa7f4
o`000?l000008?o4OH@00ol0003oooooooooo`2_ooooo`00oooooooooooooggooooo1?l9jPXQoooo
o`?o2NX:2?ooool00ol0003oa7f4olAmQ00TolAmQ004o`000?o4OHCo2NX:o`WZ2POo00007?o4OH@0
0ol0003oooooooooo`2_ooooo`00ooooooooooooogWooooo1?l9jPXQooooo`Co2NX:2oooool00ol0
003oa7f4olAmQ00TolAmQ003o`000?o4OHCoa7f400Coa7f400Co2NX:olAmQ?o4OHCoa7f41ol0000E
olAmQ003o`000?oooooooooo0:oooooo003oooooooooooooMOooool4o`WZ2R;ooooo0ol9jPX@oooo
o`03o`000?o4OHCoa7f402?oa7f40_l0000=olAmQ003o`WZ2_l0003o000000?o00004oo4OH@00ol0
003oooooooooo`2^ooooo`00ooooooooooooog;ooooo0ol9jPXRooooo`Co2NX:4oooool00ol0003o
a7f4olAmQ00SolAmQ0;o00004oo4OH@5o`0000koa7f400?o0000ooooooooool0[_ooool00?oooooo
oooooom^ooooo`Co2NX:8_ooool3o`WZ2QKooooo0_l9jPX00ol0003oa7f4olAmQ00RolAmQ003o`00
0?o4OHCoa7f401Ooa7f41_l00008olAmQ003o`000?oooooooooo0:kooooo003oooooooooooooJ_oo
ool4o`WZ2R;ooooo1?l9jPXGooooo`;o2NX:0_ooool00ol0003oa7f4olAmQ00SolAmQ003o`000?o4
OHCoa7f401Woa7f40_l000000oo4OHCo0000o`000005o`0000;oa7f400?o0000ooooooooool0[Ooo
ool00?oooooooooooomVooooo`Co2NX:8oooool3o`WZ2QSooooo0ol9jPX2ooooo`;o2NX:00?o0000
olAmQ?o4OH@08oo4OH@00ol0003oa7f4olAmQ00AolAmQ0;o2NX:4?o4OH@3o`000:oooooo003ooooo
ooooooooH_ooool4o`WZ2R?ooooo1?l9jPXIooooo`;o2NX:0oooool4o`WZ2P03ooooool0003oa7f4
02?oa7f400?o0000o`WZ2_o4OH@04oo4OH@00ol9jP[oa7f4olAmQ00?olAmQ003o`000?oooooooooo
0:gooooo003oooooooooooooG_ooool4o`WZ2RCooooo0ol9jPXKooooo`;o2NX:0_ooool4o`WZ2PCo
oooo00?o0000olAmQ?o4OH@08_o4OH@00ol0003oa7f4olAmQ00DolAmQ003o`WZ2_o4OHCoa7f400ko
a7f400?o0000ooooooooool0[Oooool00?oooooooooooomJooooo`Co2NX:9?ooool4o`WZ2Qcooooo
0_l9jPX00ooooooo2NX:o`WZ2P02o`WZ2PCooooo0ol9jPX00ooooooo0000olAmQ00RolAmQ003o`00
0?o4OHCoa7f402Goa7f400?o0000ooooooooool0[Oooool00?oooooooooooomFooooo`Co2NX:9?oo
ool4o`WZ2Qkooooo1_l9jPX5ooooo`;o2NX:1?ooool00ol0003oa7f4olAmQ00PolAmQ0;o00009oo4
OH@00ol0003oooooooooo`2]ooooo`00oooooooooooooe;ooooo1?l9jPXUooooo`?o2NX:8?ooool6
o`WZ2PCooooo0ol9jPX5ooooo`;o2NX:00?o0000olAmQ?o4OH@07oo4OH@2o`0002Koa7f400?o0000
ooooooooool0[_ooool00?oooooooooooom?ooooo`?o2NX:9Oooool4o`WZ2R7ooooo1Ol9jPX4oooo
o`?o2NX:1Oooool3o`WZ2P?ooooo00?o0000olAmQ?o4OH@07oo4OH@00ol0003oa7f4olAmQ00TolAm
Q003o`000?oooooooooo0:kooooo003oooooooooooooBoooool4o`WZ2RGooooo0ol9jPXRooooo`Ko
2NX:0oooool3o`WZ2PCooooo1?l9jPX6ooooo`03o`WZ2_l0003oa7f401ooa7f400?o0000olAmQ?o4
OH@09?o4OH@00ol0003o2NX:ooooo`2^ooooo`00ooooooooooooodOooooo1?l9jPXUooooo`Co2NX:
8Oooool7o`WZ2P?ooooo0ol9jPX4ooooo`?o2NX:1_ooool6o`WZ2P03o`000?o4OHCoa7f401goa7f4
00?o0000olAmQ?o4OH@09?o4OH@00ol0003oooooo`WZ2P2^ooooo`00oooooooooooood?ooooo1?l9
jPXVooooo`?o2NX:8_ooool3o`WZ2P03ooooool9jP[o2NX:00;o2NX:0oooool2o`WZ2PCooooo0ol9
jPX5ooooo`Co2NX:00Coooooo`WZ2_l9jP[o2NX:0_ooool00ol0003oa7f4olAmQ00MolAmQ003o`00
0?o4OHCoa7f402Coa7f400Co0000oooooooooooo2NX:[Oooool00?ooooooooooooloooooo`Co2NX:
9_ooool4o`WZ2R;ooooo0ol9jPX2ooooo`Co2NX:0_ooool3o`WZ2P;ooooo1?l9jPX4ooooo`Co2NX:
0_ooool3o`WZ2PCooooo0_l9jPX00ol0003oa7f4olAmQ00LolAmQ003o`000?o4OHCoa7f402Coa7f4
00Go0000ooooooooooooooooo`WZ2P2/ooooo`00oooooooooooooc_ooooo1?l9jPXWooooo`?o2NX:
8oooool3o`WZ2P?ooooo0ol9jPX2ooooo`?o2NX:0_ooool3o`WZ2PCooooo1?l9jPX3ooooo`?o2NX:
00?oooooo`WZ2_l9jPX01?l9jPX3ooooo`03o`000?o4OHCoa7f401_oa7f400?o0000olAmQ?o4OH@0
8oo4OH@00ol0003oooooooooo`03ooooo`03o`WZ2_oooooooooo0:Wooooo003ooooooooooooo=ooo
ool4o`WZ2ROooooo1?l9jPXRooooo`Co2NX:1?ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2P;ooooo
0ol9jPX3ooooo`Co2NX:1?ooool7o`WZ2P[ooooo0_l0000KolAmQ0;o00009?o4OH@00ol0003ooooo
ooooo`04ooooo`;o2NX:ZOooool00?oooooooooooolcooooo`Co2NX::?ooool3o`WZ2R?ooooo0ol9
jPX6ooooo`Ko2NX:00?oooooo`WZ2_l9jPX00_l9jPX00ooooooo2NX:o`WZ2P03o`WZ2PGooooo1Ol9
jPXAooooo`03o`000?o4OHCoa7f401Soa7f40_l00004olAmQ003o`WZ2_o4OHCoa7f401coa7f400?o
0000ooooooooool01oooool00ol9jP[oooooooooo`2Vooooo`00oooooooooooooboooooo1?l9jPXX
ooooo`Co2NX:8oooool3o`WZ2POooooo0_l9jPX01?oooooo2NX:o`WZ2_ooool3o`WZ2P03ooooool9
jP[o2NX:00;o2NX:1Oooool5o`WZ2QGooooo0_l9jPX00ol0003oa7f4olAmQ00BolAmQ0;o2NX:0oo4
OH@00ol0003oa7f4olAmQ00RolAmQ003o`000?oooooooooo00Sooooo00?o2NX:ooooooooool0YOoo
ool00?ooooooooooool/ooooo`?o2NX::Oooool3o`WZ2RCooooo0ol9jPX7ooooo`go2NX:0oooool8
o`WZ2QGooooo0ol9jPX3ooooo`;o00005oo4OH@00ol0003oa7f4olAmQ00QolAmQ003o`000?oooooo
oooo00[ooooo00?o2NX:ooooooooool0Y?ooool00?oooooooooooolXooooo`Co2NX::?ooool4o`WZ
2RCooooo0ol9jPX8ooooo`_o2NX:0_ooool5o`WZ2P;ooooo0ol9jPXEooooo`?o2NX:2?ooool00ol0
003oa7f4olAmQ00DolAmQ004o`000?o4OHCoa7f4o`WZ2R3oa7f400?o0000o`WZ2_ooool02oooool0
0ol9jP[oooooooooo`2Sooooo`00ooooooooooooobCooooo1?l9jPXYooooo`?o2NX:9?ooool4o`WZ
2PWooooo2Ol9jPX00ooooooo2NX:o`WZ2P03o`WZ2PCooooo0ol9jPXFooooo`;o2NX:3?ooool00ol0
003oa7f4olAmQ00ColAmQ003o`000?o4OHCoa7f401ooa7f40_l00002ooooo`03o`WZ2_oooooooooo
00[ooooo0_l9jPZSooooo`00ooooooooooooob3ooooo1?l9jPXYooooo`Co2NX:9?ooool3o`WZ2P[o
oooo3Ol9jPX6ooooo`?o2NX:5_ooool3o`WZ2Poooooo00?o0000olAmQ?o4OH@04_o4OH@00ol0003o
a7f4olAmQ00NolAmQ003o`000?oooooooooo00?ooooo00?o2NX:ooooooooool02oooool00ol9jP[o
ooooooooo`2Pooooo`00oooooooooooooacooooo1?l9jPXZooooo`?o2NX:9Oooool3o`WZ2P_ooooo
2_l9jPX9ooooo`;o2NX:5_ooool3o`WZ2Q?ooooo0_l0000BolAmQ003o`000?o4OHCoa7f401goa7f4
00?o0000ooooooooool01Oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo09oooooo
003ooooooooooooo6?ooool4o`WZ2R[ooooo1?l9jPXUooooo`?o2NX:2oooool7o`WZ2Pcooooo0ol9
jPXFooooo`;o2NX:5_ooool2o`WZ2P;o00004?o4OH@00ol0003oa7f4olAmQ00LolAmQ003o`000?oo
oooooooo00Oooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0Zoooooaco0000F?oo
ool00?oooooooooooolDooooo`Co2NX::oooool3o`WZ2RGooooo1?l9jPX:ooooo`Ko2NX:3_ooool3
o`WZ2QKooooo0ol9jPXEooooo`?o2NX:1?ooool2o`0000koa7f400?o0000olAmQ?o4OH@06oo4OH@0
0ol0003oooooooooo`09ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool09?ooool5
o`0001cooooo0ol0001Eooooo`00oooooooooooooa3ooooo1?l9jPX[ooooo`Co2NX:9Oooool3o`WZ
2P[ooooo2?l9jPX=ooooo`?o2NX:5_ooool3o`WZ2QKooooo0_l9jPX9ooooo`;o00003Oo4OH@00ol0
003oa7f4olAmQ00HolAmQ0;o000000?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`0;oooo
o`03o`WZ2_oooooooooo01kooooo1Ol0000Tooooo`?o0000D_ooool00?ooooooooooool<ooooo`Co
2NX:;?ooool3o`WZ2RKooooo0ol9jPX7ooooo`co2NX:3?ooool3o`WZ2QKooooo0ol9jPXFooooo`?o
2NX:3Oooool2o`0000_oa7f400?o0000olAmQ?o4OH@05_o4OH@2o`000004ooooool9jP[oooooo`WZ
2Pcooooo00?o2NX:ooooooooool02oooool2o`WZ2QWooooo1Ol0000/ooooo`?o0000Coooool00?oo
ooooooooool9ooooo`?o2NX:;?ooool4o`WZ2RKooooo0ol9jPX5ooooo`co2NX:00?oooooo`WZ2_l9
jPX02oooool3o`WZ2QOooooo0_l9jPXGooooo`;o2NX:4_ooool3o`0000Soa7f400?o0000olAmQ?o4
OH@05?o4OH@2o`0000;ooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:oooooooo
ool03?ooool00ol9jP[oooooooooo`0>ooooo`03o`000?oooooooooo00Go0000=?ooool3o`0004co
oooo003ooooooooooooo1Oooool4o`WZ2Rcooooo0ol9jPXWooooo`?o2NX:0oooool?o`WZ2P03oooo
ool9jP[o2NX:00[ooooo0ol9jPXGooooo`?o2NX:5_ooool3o`WZ2QKooooo00?o2NX:o`000?l00000
0_l00004olAmQ003o`000?o4OHCoa7f401;oa7f40_l000000ol9jP[oooooooooo`02ooooo`;o2NX:
00?oooooo`WZ2_ooool03?ooool00ol9jP[oooooooooo`0<ooooo`03o`WZ2_oooooooooo00cooooo
1?l0000looooo`?o0000BOooool00?ooooooooooool1ooooo`Co2NX:;?ooool4o`WZ2RKooooo5ol9
jPX00ooooooo2NX:o`WZ2P09ooooo`?o2NX:5oooool3o`WZ2QKooooo0ol9jPXJooooo`04o`WZ2_oo
ooooooooooooo`?o000000?oa7f4o`000?o4OH@04?o4OH@3o`0000?ooooo00?o2NX:ooooooooool0
0_ooool2o`WZ2P03ooooool9jP[ooooo00cooooo00?o2NX:ooooooooool03?ooool00ol9jP[ooooo
ooooo`08ooooo`?o000000?oooooo`000?ooool0@?ooool3o`0004Kooooo003ooooooocooooo1?l9
jPX]ooooo`?o2NX:9oooool7o`WZ2P03ooooool9jP[o2NX:00;o2NX:0_ooool3o`WZ2P03ooooool9
jP[o2NX:00?o2NX:0_ooool2o`WZ2PSooooo0ol9jPXHooooo`;o2NX:5oooool2o`WZ2Qgooooo00?o
2NX:ooooooooool01?ooool8o`0000Koa7f41Ol00003ooooo`05o`WZ2_ooooooooooooooool9jPX0
0oooool01Ol9jP[oooooo`WZ2_oooooo2NX:00gooooo00?o2NX:ooooooooool03?ooool00ol9jP[o
ooooooooo`05ooooo`;o00001?ooool00ol0003oooooooooo`12ooooo`;o0000A?ooool00?oooooo
n?ooool4o`WZ2Rgooooo1?l9jPXWooooo`Go2NX:0_ooool4o`WZ2P?ooooo0ol9jPX01Ooooooo2NX:
o`WZ2_l9jP[ooooo00;o2NX:0_ooool2o`WZ2POooooo0ol9jPXHooooo`?o2NX:5_ooool3o`WZ2Qoo
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`06o`0000Cooooo00Go2NX:oooooooo
ooooooooo`WZ2P04ooooo`06o`WZ2_ooooooooooooooool9jP[ooooo0_l9jPX>ooooo`03o`WZ2_oo
oooooooo00cooooo0_l9jPX3ooooo`;o00001_ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo047ooooo003oooooooCooooo1?l9jPX^ooooo`?o2NX:9_ooool5o`WZ2P?ooooo1?l9jPX3
ooooo`Co2NX:00Goooooo`WZ2_l9jP[o2NX:ooooo`03o`WZ2P;ooooo0_l9jPX6ooooo`?o2NX:6?oo
ool3o`WZ2QOooooo0_l9jPXSooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool01Ooo
ool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool00ol9jP[ooooo
ooooo`02ooooo`04o`WZ2_oooooo2NX:o`WZ2Pkooooo00?o2NX:ooooooooool03Oooool00ol9jP[o
0000o`000008ooooo`03o`000?oooooooooo04Gooooo0_l00011ooooo`00ooooooo`ooooo`Co2NX:
;_ooool4o`WZ2R?ooooo2?l9jPX2ooooo`Co2NX:1?ooool3o`WZ2P?ooooo0_l9jPX2ooooo`;o2NX:
0oooool2o`WZ2PGooooo0ol9jPXHooooo`?o2NX:5oooool3o`WZ2RGooooo00?o2NX:ooooooooool0
2Oooool00ol9jP[oooooooooo`06ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool01Ol9jP[o
oooooooooooooooo2NX:00?ooooo00Go2NX:ooooool9jP[oooooo`WZ2P0>ooooo`03o`WZ2_oooooo
oooo00[ooooo0_l000000ooooooo2NX:ooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0?_ooool00?ooooook?ooool4o`WZ2Roooooo0ol9jPXRooooo`Go2NX:00Coooooo`WZ
2_l9jP[o2NX:0_ooool4o`WZ2PCooooo1?l9jPX3ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:0ooo
ool2o`WZ2PCooooo0ol9jPXIooooo`;o2NX:6?ooool2o`WZ2RWooooo00?o2NX:ooooooooool02Ooo
ool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_oo
ool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Co2NX:ooooool9jP[o2NX:3oooool00ol9jP[o
ooooooooo`06ooooo`?o00001?ooool00ol9jP[oooooooooo`06ooooo`03o`000?oooooooooo04So
oooo0_l0000nooooo`00oooooooXooooo`Co2NX:;oooool4o`WZ2R3ooooo1Ol9jPX3ooooo`?o2NX:
00?oooooo`WZ2_l9jPX00_l9jPX5ooooo`?o2NX:1?ooool3o`WZ2P;ooooo0_l9jPX4ooooo`;o2NX:
0oooool3o`WZ2QWooooo0ol9jPXGooooo`?o2NX::oooool00ol9jP[oooooooooo`09ooooo`03o`WZ
2_oooooooooo00Kooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Co
oooo00Ko2NX:ooooooooooooooooo`WZ2_ooool2o`WZ2Poooooo00?o2NX:ooooooooool00oooool2
o`0000Sooooo00?o2NX:ooooooooool01_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo03_ooooo003oooooonGooooo0ol9jPX`ooooo`?o2NX:7oooool5o`WZ2PGooooo1ol9jPX6oooo
o`?o2NX:1?ooool3o`WZ2P?ooooo0_l9jPX4ooooo`;o2NX:0_ooool3o`WZ2QWooooo0ol9jPXHoooo
o`;o2NX:;_ooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Kooooo00Co2NX:oooo
oooooooooooo0_l9jPX3ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool00ol9jP[ooooooooo
o`02o`WZ2Poooooo00?o2NX:ooooooooool00_l0000;ooooo`;o2NX:1_ooool00ol0003ooooooooo
o`1:ooooo`;o0000>oooool00?oooooohOooool4o`WZ2Roooooo1?l9jPXLooooo`Ko2NX:1oooool5
o`WZ2POooooo1?l9jPX4ooooo`?o2NX:0oooool3o`WZ2PCooooo0_l9jPX01?oooooo2NX:o`WZ2_l9
jPXJooooo`;o2NX:6?ooool3o`WZ2S7ooooo00?o2NX:ooooooooool02Oooool00ol9jP[ooooooooo
o`07ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool01Ol9jP[ooooooooooooooooo2NX:00?o
oooo00Co2NX:oooooooooooo2NX:3oooool00ol0003o2NX:o`00000?ooooo`03o`WZ2_oooooooooo
00?ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0hooooo`00oooooooMooooo`Co
2NX:<?ooool3o`WZ2Q_ooooo1Ol9jPX9ooooo`Go2NX:2?ooool3o`WZ2PKooooo0_l9jPX4ooooo`;o
2NX:1Oooool5o`WZ2Q[ooooo0ol9jPXHooooo`;o2NX:=?ooool00ol9jP[oooooooooo`0:ooooo`03
o`WZ2_oooooooooo00Oooooo00Co2NX:oooooooooooooooo0_l9jPX3ooooo`05o`WZ2_oooooooooo
ooooool9jPX00oooool01?l9jP[oooooooooool9jPX<ooooo`;o00000_ooool00ol9jP[ooooooooo
o`0>ooooo`03o`WZ2_oooooooooo00;ooooo00?o0000ooooooooool0COooool2o`0003Sooooo003o
ooooomWooooo1?l9jPX`ooooo`Co2NX:6Oooool5o`WZ2P_ooooo1?l9jPX9ooooo`?o2NX:1_ooool3
o`WZ2PCooooo0_l9jPX5ooooo`Co2NX:6_ooool3o`WZ2QSooooo0ol9jPXgooooo`03o`WZ2_oooooo
oooo00Wooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`02o`WZ2PCooooo00Co2NX:
oooooooooooo2NX:1?ooool01?l9jP[oooooo`WZ2_l9jPX:ooooo`03o`000?oooooooooo00?ooooo
00?o2NX:ooooooooool03_ooool01Ol9jP[ooooooooooooooooo0000057ooooo00?o0000oooooooo
ool0=Oooool00?ooooooeOooool4o`WZ2S7ooooo0ol9jPXHooooo`Go2NX:3?ooool4o`WZ2PWooooo
1?l9jPX6ooooo`?o2NX:1?ooool3o`WZ2PGooooo0ol9jPXJooooo`?o2NX:6Oooool2o`WZ2S[ooooo
00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00;o2NX:
0oooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Co2NX:oooooooooooo2NX:2?ooool2o`00
00Oooooo00?o2NX:ooooooooool03_ooool01?l9jP[oooooooooool0001Booooo`;o0000=Oooool0
0?oooooodOooool4o`WZ2S7ooooo1?l9jPXEooooo`Ko2NX:3Oooool5o`WZ2PWooooo0ol9jPX7oooo
o`?o2NX:1Oooool2o`WZ2PGooooo0ol9jPXKooooo`;o2NX:6Oooool3o`WZ2Scooooo00?o2NX:oooo
ooooool02oooool00ol9jP[oooooooooo`07ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool0
1Ol9jP[ooooooooooooooooo2NX:00?ooooo00Co2NX:oooooooooooo2NX:1_ooool00ol0003ooooo
ooooo`08ooooo`03o`WZ2_oooooooooo00kooooo0_l9jPX00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo03;ooooo003oooooolgooooo1?l9jPXbooooo`?o2NX:5?ooool5o`WZ2Poooooo1_l9
jPX8ooooo`Co2NX:1oooool3o`WZ2PGooooo0ol9jPX5ooooo`?o2NX:6_ooool3o`WZ2QWooooo0_l9
jPY0ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02?ooool01_l9jP[ooooooooo
ool9jP[oooooo`WZ2P?ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`04o`WZ2_oooooooooo
o`WZ2P?ooooo0_l0000<ooooo`03o`WZ2_oooooooooo00oooooo00?o2NX:ooooooooool0Doooool0
0ol0003oooooooooo`0aooooo`00ooooooo9ooooo`Co2NX:<_ooool4o`WZ2Q;ooooo1Ol9jPX?oooo
o`Oo2NX:2Oooool3o`WZ2PSooooo0ol9jPX6ooooo`;o2NX:1Oooool3o`WZ2Q[ooooo0ol9jPXIoooo
o`?o2NX:@_ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo00Sooooo00Ko2NX:oooo
oooooooo2NX:ooooool9jPX3ooooo`04o`WZ2_ooooooooooo`WZ2P?ooooo00?o2NX:ooooooooool0
0_l9jPX00ooooooo0000ooooo`0>ooooo`03o`WZ2_oooooooooo00kooooo00?o0000o`WZ2_ooool0
Doooool00ol0003oooooooooo`0aooooo`00ooooooo5ooooo`Co2NX:<oooool3o`WZ2Q7ooooo1Ol9
jPX@ooooo`Co2NX:00Coooooo`WZ2_l9jP[o2NX:2Oooool3o`WZ2PWooooo0_l9jPX7ooooo`;o2NX:
1?ooool4o`WZ2Q[ooooo0_l9jPXJooooo`;o2NX:A_ooool00ol9jP[oooooooooo`0:ooooo`03o`WZ
2_oooooooooo00Wooooo00Ko2NX:oooooooooooo2NX:ooooool9jPX2ooooo`05o`WZ2_oooooooooo
ooooool9jPX00oooool01Ol9jP[oooooooooool9jP[o0000017ooooo00?o2NX:ooooooooool03Ooo
ool00ol0003oooooo`WZ2P1Dooooo`03o`000?oooooooooo033ooooo003ooooool;ooooo0ol9jPXc
ooooo`Co2NX:3_ooool6o`WZ2Q7ooooo1?l9jPX2ooooo`?o2NX:2?ooool4o`WZ2PWooooo0ol9jPX6
ooooo`?o2NX:0oooool5o`WZ2QWooooo0ol9jPXIooooo`?o2NX:B?ooool00ol9jP[oooooooooo`0;
ooooo`03o`WZ2_oooooooooo00Wooooo00Go2NX:ooooool9jP[oooooo`WZ2P03ooooo`05o`WZ2_oo
ooooooooooooool9jPX00oooool01?l9jP[o0000ooooool9jPXBooooo`03o`WZ2_oooooooooo00co
oooo00Co0000oooooooooooo2NX:E?ooool00ol0003oooooooooo`0_ooooo`00oooooonnooooo`Co
2NX:<oooool3o`WZ2Pgooooo1Ol9jPXCooooo`Co2NX:0oooool3o`WZ2PSooooo0ol9jPX:ooooo`?o
2NX:1oooool2o`WZ2P?ooooo0ol9jPX00ooooooo2NX:o`WZ2P0Hooooo`?o2NX:6_ooool2o`WZ2T_o
oooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0:ooooo`05o`WZ2_oooooo2NX:oooo
ool9jPX00oooool01Ol9jP[ooooooooooooooooo2NX:00;ooooo00Go0000o`WZ2_ooooooooooo`WZ
2P0Booooo`03o`WZ2_oooooooooo00_ooooo00Co0000oooooooooooooooo0_l9jPYBooooo`03o`00
0?oooooooooo02oooooo003ooooook[ooooo1?l9jPXcooooo`Co2NX:2oooool5o`WZ2QCooooo1?l9
jPX3ooooo`Co2NX:2?ooool3o`WZ2P[ooooo0ol9jPX8ooooo`;o2NX:0_ooool3o`WZ2P;ooooo0_l9
jPXGooooo`?o2NX:6_ooool3o`WZ2Tkooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooooooo
o`09ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:0oooool01?l9jP[oooooooooool9jPX2o`00
0004ooooool9jP[oooooooooo`;o2NX:4_ooool00ol9jP[oooooooooo`0:ooooo`03o`000?oooooo
oooo00?ooooo00?o2NX:ooooooooool0D?ooool00ol0003oooooooooo`0^ooooo`00oooooonfoooo
o`Co2NX:=?ooool3o`WZ2P[ooooo1Ol9jPXEooooo`Co2NX:1?ooool3o`WZ2PSooooo1?l9jPX:oooo
o`?o2NX:2?ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2P?ooooo0_l9jPXGooooo`;o2NX:6oooool2
o`WZ2U7ooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooo
2NX:00;ooooo00So2NX:ooooooooooooooooo`WZ2_oooooo0000o`WZ2P?ooooo00?o2NX:oooooooo
ool00_l9jPXBooooo`03o`WZ2_oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol9jP[o
ooooooooo`1@ooooo`03o`000?oooooooooo02gooooo003ooooook;ooooo1?l9jPXdooooo`Co2NX:
1oooool6o`WZ2QKooooo1?l9jPX5ooooo`?o2NX:2?ooool3o`WZ2Pcooooo0_l9jPX9ooooo`;o2NX:
00Coooooo`WZ2_l9jP[o2NX:1?ooool2o`WZ2QKooooo0ol9jPXJooooo`?o2NX:E?ooool00ol9jP[o
ooooooooo`0;ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooool9jPX00_ooool01Ol9jP[o
ooooooooool9jP[o000000;ooooo00Go2NX:ooooooooooooooooo`WZ2P02ooooo`;o2NX:4_ooool0
0ol9jP[oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o2NX:ooooooooool0Coooool0
0ol0003oooooooooo`0]ooooo`00iOooool8o`000<3ooooo1?l9jPXdooooo`Co2NX:1_ooool5o`WZ
2QOooooo1Ol9jPX6ooooo`?o2NX:1oooool4o`WZ2Pcooooo0ol9jPX8ooooo`Ko2NX:1Oooool2o`WZ
2QGooooo0ol9jPXKooooo`;o2NX:Eoooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo
00_ooooo00Wo2NX:ooooool9jP[oooooo`WZ2_oooooo0000ooooool9jPX00oooool01?l9jP[ooooo
ooooool9jPX2ooooo`;o2NX:4oooool00ol9jP[oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o2NX:ooooooooool0Coooool00ol0003oooooooooo`0/ooooo`00g_ooool7o`0000Sooooo
0ol0002iooooo`Co2NX:=Oooool3o`WZ2PGooooo1Ol9jPXHooooo`Co2NX:1oooool4o`WZ2POooooo
0ol9jPX=ooooo`?o2NX:2Oooool5o`WZ2PKooooo0_l9jPXDooooo`?o2NX:6oooool3o`WZ2UWooooo
00?o2NX:ooooooooool03?ooool00ol9jP[oooooooooo`0;ooooo`;o2NX:00?oooooo`000?l9jPX0
0oooool01?l9jP[oooooooooool9jPX3ooooo`03o`WZ2_oooooooooo00;o2NX:4oooool00ol9jP[o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l9jPY@ooooo`03o`000?oooooooooo02_o
oooo003Mooooo`03o`000?oooooooooo013ooooo0ol0002booooo`Co2NX:=Oooool4o`WZ2P?ooooo
1Ol9jPXIooooo`Co2NX:2?ooool3o`WZ2PSooooo0ol9jPX=ooooo`?o2NX:2_ooool4o`WZ2POooooo
0_l9jPXDooooo`;o2NX:6oooool3o`WZ2Ugooooo00?o2NX:ooooooooool02oooool00ol9jP[ooooo
ooooo`0<ooooo`;o2NX:0_ooool01Ol9jP[ooooooooooooooooo2NX:00;ooooo00Go2NX:oooooooo
ooooooooo`WZ2P02ooooo`;o2NX:4oooool00ol9jP[oooooooooo`06ooooo`03o`000?oooooooooo
00Sooooo00?o2NX:ooooooooool0COooool00ol0003oooooooooo`0[ooooo`00g?ooool00ol0003o
ooooooooo`0Dooooo`;o0000[?ooool4o`WZ2SKooooo0ol9jPX00ooooooo2NX:o`WZ2P04o`WZ2Q[o
oooo1?l9jPX9ooooo`?o2NX:1oooool4o`WZ2Pgooooo0ol9jPX:ooooo`Co2NX:2?ooool2o`WZ2Q?o
oooo0ol9jPXKooooo`;o2NX:H?ooool00ol9jP[oooooooooo`0<ooooo`03o`WZ2_oooooooooo00_o
oooo00?o0000o`WZ2_l9jPX00_ooool01?l9jP[oooooooooool9jPX3ooooo`04o`WZ2_oooooooooo
o`WZ2P;ooooo00?o2NX:ooooool9jPX04oooool00ol9jP[oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00?o2NX:ooooooooool0COooool00ol0003oooooooooo`0Zooooo`00foooool00ol0
003oooooooooo`0Gooooo`?o0000Y_ooool3o`WZ2SKooooo2?l9jPXLooooo`Co2NX:2_ooool3o`WZ
2POooooo0ol9jPX?ooooo`;o2NX:2oooool3o`WZ2PWooooo0_l9jPXBooooo`?o2NX:6oooool3o`WZ
2V?ooooo00?o2NX:ooooooooool02oooool00ol9jP[oooooooooo`0;ooooo`03o`000?l9jP[o2NX:
00?ooooo00Co2NX:oooooooooooo2NX:0oooool01?l9jP[oooooooooool9jPX2ooooo`03o`WZ2_oo
oooo2NX:01?ooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oo
oooooooo04cooooo00?o0000ooooooooool0:_ooool00=Wooooo0_l0000Mooooo`;o0000X?ooool4
o`WZ2SKooooo1_l9jPXMooooo`Co2NX:2oooool3o`WZ2POooooo0ol9jPX?ooooo`?o2NX:2_ooool3
o`WZ2P[ooooo0_l9jPXBooooo`;o2NX:7?ooool2o`WZ2VKooooo00?o2NX:ooooooooool03?ooool0
0ol9jP[oooooooooo`09ooooo`03o`000?oooooooooo00;o2NX:0_ooool01Ol9jP[ooooooooooooo
oooo2NX:00;ooooo00Go2NX:ooooooooooooooooo`WZ2P02ooooo`03o`WZ2_oooooo2NX:01?ooooo
00?o2NX:ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`WZ2_oooooooooo04cooooo
00?o0000ooooooooool0:Oooool00=Sooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`2Iooooo`Co2NX:=_ooool5o`WZ2Qkooooo1?l9jPX;ooooo`Co2NX:1_ooool4o`WZ2Poooooo0ol9
jPX:ooooo`Co2NX:2_ooool2o`WZ2Q7ooooo0ol9jPXKooooo`?o2NX:J?ooool00ol9jP[ooooooooo
o`0<ooooo`03o`WZ2_oooooooooo00Sooooo00?o0000ooooooooool00_ooool2o`WZ2P;ooooo00Go
2NX:ooooooooooooooooo`WZ2P02ooooo`09o`WZ2_ooooooooooooooool9jP[oooooo`WZ2_oooooo
2NX:01Cooooo00?o2NX:ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`WZ2_oooooo
oooo04cooooo00?o0000ooooooooool0:?ooool00=Oooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`2Dooooo`Co2NX:=?ooool6o`WZ2Qkooooo1Ol9jPX<ooooo`?o2NX:1oooool3o`WZ
2Q3ooooo0ol9jPX:ooooo`Co2NX:2oooool2o`WZ2Q3ooooo0ol9jPXLooooo`;o2NX:K?ooool00ol9
jP[oooooooooo`0<ooooo`03o`WZ2_oooooooooo00Kooooo00?o0000ooooooooool01?ooool01Ol9
jP[ooooooooooooooooo2NX:00?ooooo00Co2NX:oooooooooooo2NX:0_ooool01_l9jP[ooooooooo
ool9jP[oooooo`WZ2QCooooo00Go2NX:ooooooooooooooooo`00000?ooooo`;o2NX:C?ooool00ol0
003oooooooooo`0Xooooo`00e_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08oo
oooo1?l9jPXcooooo`So2NX:7Oooool4o`WZ2Pkooooo0ol9jPX6ooooo`Co2NX:4?ooool3o`WZ2P[o
oooo1Ol9jPX;ooooo`;o2NX:3oooool3o`WZ2Qcooooo0ol9jPY^ooooo`03o`WZ2_oooooooooo00go
oooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`06ooooo`05o`WZ2_oooooooooooooo
ool9jPX00_ooool01Ol9jP[ooooooooooooooooo2NX:00;ooooo00Ko2NX:oooooooooooo2NX:oooo
ool9jPXDooooo`04o`WZ2_ooooooooooo`00017ooooo00?o2NX:ooooooooool0B_ooool00ol0003o
ooooooooo`0Wooooo`00eOooool00ol0003oooooooooo`0Uooooo`;o0000Roooool4o`WZ2S;ooooo
1Ol9jPX01?oooooo2NX:o`WZ2_l9jPXMooooo`Co2NX:3oooool3o`WZ2PKooooo0ol9jPXAooooo`?o
2NX:2_ooool5o`WZ2Pcooooo0_l9jPX?ooooo`;o2NX:7Oooool2o`WZ2W;ooooo00?o2NX:oooooooo
ool03?ooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Go2NX:oooooooo
ooooooooo`WZ2P02ooooo`04o`WZ2_ooooooooooo`WZ2P?ooooo00?o2NX:ooooool9jPX00_ooool0
0ol9jP[oooooooooo`0Booooo`03o`WZ2_oooooo000001;ooooo00?o2NX:ooooooooool0B_ooool0
0ol0003oooooooooo`0Vooooo`00eOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
08Cooooo1?l9jPXaooooo`Go2NX:0_ooool4o`WZ2Qcooooo1?l9jPX?ooooo`Co2NX:1_ooool3o`WZ
2Q;ooooo0_l9jPX:ooooo`?o2NX:00?oooooo`WZ2_l9jPX03?ooool2o`WZ2Pkooooo0ol9jPXLoooo
o`?o2NX:M?ooool00ol9jP[oooooooooo`0=ooooo`05o`WZ2_ooooooooooooooool000002oooool2
o`WZ2P?ooooo00Co2NX:oooooooooooo2NX:0_ooool01?l9jP[oooooooooool9jPX2ooooo`04o`WZ
2_ooooooooooo`WZ2QCooooo00?o2NX:ooooool000004_ooool00ol9jP[oooooooooo`19ooooo`03
o`000?oooooooooo02Kooooo003Dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
Ooooool4o`WZ2Roooooo1_l9jPX4ooooo`?o2NX:7?ooool4o`WZ2Q3ooooo0ol9jPX6ooooo`Co2NX:
4_ooool3o`WZ2P[ooooo0_l9jPX01?oooooo2NX:o`WZ2_l9jPX;ooooo`?o2NX:3Oooool3o`WZ2Qgo
oooo0_l9jPYgooooo`03o`WZ2_oooooooooo00gooooo00Co2NX:oooooooooooo00003Oooool01Ol9
jP[ooooooooooooooooo2NX:00?ooooo00Co2NX:oooooooooooo2NX:0_ooool01?l9jP[ooooooooo
ool9jPX2ooooo`03o`WZ2_oooooooooo01;ooooo00?o2NX:o`000?ooool04_ooool00ol9jP[ooooo
ooooo`18ooooo`03o`000?oooooooooo02Kooooo003Dooooo`03o`000?oooooooooo02[ooooo0_l0
001kooooo`Co2NX:;_ooool5o`WZ2PKooooo1?l9jPXKooooo`Co2NX:4Oooool3o`WZ2PKooooo0ol9
jPXCooooo`?o2NX:2_ooool3o`WZ2P03ooooool9jP[o2NX:00cooooo0_l9jPX>ooooo`;o2NX:7Ooo
ool3o`WZ2W[ooooo00?o2NX:ooooooooool03Oooool00ol9jP[o0000ooooo`0>ooooo`05o`WZ2_oo
ooooooooooooool9jPX00_ooool01Ol9jP[ooooooooooooooooo2NX:00;ooooo00?o2NX:ooooool9
jPX00_ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo01;ooooo0_l9jPY9ooooo`03
o`000?oooooooooo02Gooooo003Cooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
MOooool3o`WZ2Rgooooo1Ol9jPX8ooooo`?o2NX:6_ooool5o`WZ2Q;ooooo0ol9jPX6ooooo`?o2NX:
4oooool3o`WZ2P[ooooo0ol9jPX2ooooo`;o2NX:3?ooool2o`WZ2Pgooooo0ol9jPXMooooo`;o2NX:
OOooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00kooooo0_l9jPX3ooooo`04o`WZ
2_ooooooooooo`WZ2P;ooooo00Co2NX:oooooooooooo2NX:0_ooool01?l9jP[oooooooooool9jPXD
ooooo`03o`000?l9jP[ooooo01Cooooo00?o2NX:ooooooooool0A_ooool00ol0003oooooooooo`0U
ooooo`00doooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo073ooooo1?l9jPX[oooo
o`Go2NX:2Oooool4o`WZ2QWooooo1?l9jPXCooooo`Co2NX:1Oooool4o`WZ2Q?ooooo0ol9jPX:oooo
o`?o2NX:0_ooool3o`WZ2Pcooooo0_l9jPX<ooooo`?o2NX:7Oooool3o`WZ2X3ooooo00?o2NX:oooo
ooooool02oooool00ol0003oooooo`WZ2P0@ooooo`;o2NX:0oooool01?l9jP[oooooooooool9jPX2
ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo00Co2NX:oooooooooooo2NX:4oooool00ol0003ooooo
o`WZ2P0Eooooo`03o`WZ2_oooooooooo04Gooooo00?o0000ooooooooool09Oooool00=;ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`1[ooooo`Co2NX::Oooool6o`WZ2P_ooooo0ol9
jPXIooooo`Co2NX:5?ooool3o`WZ2PKooooo0ol9jPXEooooo`;o2NX:2_ooool3o`WZ2P?ooooo0_l9
jPX=ooooo`;o2NX:2oooool3o`WZ2Qkooooo0_l9jPZ3ooooo`03o`WZ2_oooooooooo00[ooooo00Co
0000oooooooooooo2NX:4Oooool2o`WZ2P?ooooo00Co2NX:oooooooooooo2NX:0_ooool01_l9jP[o
ooooooooool9jP[oooooo`WZ2P?ooooo00?o2NX:ooooooooool04?ooool01?l0003oooooooooool9
jPXEooooo`03o`WZ2_oooooooooo04Gooooo00?o0000ooooooooool09?ooool00=;ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`1Vooooo`Co2NX::?ooool5o`WZ2Pgooooo1?l9jPXH
ooooo`Co2NX:5Oooool3o`WZ2PGooooo1?l9jPXEooooo`?o2NX:2Oooool3o`WZ2P?ooooo0ol9jPX=
ooooo`;o2NX:2oooool2o`WZ2Qkooooo0ol9jPZ5ooooo`03o`WZ2_oooooooooo00Wooooo00?o0000
ooooooooool00_ooool00ol9jP[oooooooooo`0>ooooo`03o`WZ2_oooooo2NX:00;ooooo00Co2NX:
oooooooooooo2NX:0oooool01_l9jP[oooooooooool9jP[oooooo`WZ2P?ooooo00?o2NX:oooooooo
ool03oooool01Ol0003ooooooooooooooooo2NX:01Gooooo00?o2NX:ooooooooool0A?ooool00ol0
003oooooooooo`0Tooooo`00dOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo06;o
oooo1?l9jPXWooooo`Go2NX:3oooool3o`WZ2QSooooo1?l9jPXFooooo`?o2NX:1Oooool3o`WZ2QKo
oooo0ol9jPX9ooooo`?o2NX:1?ooool2o`WZ2Pkooooo0_l9jPX:ooooo`?o2NX:7_ooool2o`WZ2XWo
oooo00?o2NX:ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`WZ2_oooooooooo00oo
oooo00?o2NX:ooooool9jPX00_ooool01?l9jP[oooooooooool9jPX2ooooo`04o`WZ2_oooooooooo
o`WZ2P;ooooo00Co2NX:oooooooooooo2NX:4Oooool00ol0003oooooooooo`02ooooo`03o`WZ2_oo
oooooooo01?ooooo0_l9jPY4ooooo`03o`000?oooooooooo02Cooooo003Aooooo`03o`000?oooooo
oooo03;ooooo0_l0001Oooooo`Co2NX:9_ooool5o`WZ2Q3ooooo1?l9jPXGooooo`Co2NX:5oooool3
o`WZ2PGooooo0ol9jPXFooooo`?o2NX:2Oooool3o`WZ2PGooooo0_l9jPX>ooooo`;o2NX:2Oooool3
o`WZ2Qkooooo0ol9jPZ;ooooo`03o`WZ2_oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol9jP[oooooooooo`0?ooooo`;o2NX:0oooool01?l9jP[oooooooooool9jPX2ooooo`06o`WZ2_oo
ooooooooo`WZ2_oooooo2NX:0oooool00ol9jP[oooooooooo`0>ooooo`03o`000?oooooooooo00?o
oooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`11ooooo`03o`000?oooooooooo02Co
oooo003Aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooool00000F_ooool4o`WZ2RCooooo
1_l9jPXBooooo`?o2NX:5oooool4o`WZ2QOooooo1?l9jPX4ooooo`Co2NX:5_ooool3o`WZ2PWooooo
0ol9jPX5ooooo`?o2NX:3_ooool2o`WZ2PWooooo0_l9jPXOooooo`;o2NX:Soooool00ol9jP[ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o2NX:ooooooooool03oooool00ol9jP[ooooo
o`WZ2P03ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo00Ko2NX:oooooooooooo2NX:ooooool9jPX3
ooooo`03o`WZ2_oooooooooo00kooooo00?o0000ooooooooool00oooool00ol9jP[oooooooooo`0D
ooooo`03o`WZ2_oooooooooo047ooooo00?o0000ooooooooool08oooool00=3ooooo00?o0000oooo
ooooool0<oooool01?l0003oooooooooool0001Eooooo`Co2NX:8oooool5o`WZ2QCooooo1?l9jPXE
ooooo`Go2NX:6?ooool3o`WZ2PGooooo0ol9jPXHooooo`;o2NX:2Oooool3o`WZ2PKooooo0_l9jPX?
ooooo`;o2NX:2?ooool3o`WZ2Qkooooo0ol9jPZAooooo`03o`WZ2_oooooooooo00?ooooo00?o0000
ooooooooool02?ooool00ol9jP[oooooooooo`0?ooooo`03o`WZ2_oooooo2NX:00?ooooo00Ko2NX:
oooooooooooo2NX:ooooool9jPX2ooooo`04o`WZ2_ooooooooooo`WZ2P?ooooo00?o2NX:oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:oooooooo
ool0@?ooool00ol0003oooooooooo`0Sooooo`00d?ooool00ol0003oooooooooo`0cooooo`05o`00
0?ooooooooooooooool00000D?ooool4o`WZ2R;ooooo1Ol9jPXFooooo`?o2NX:5Oooool4o`WZ2Q[o
oooo0ol9jPX4ooooo`Co2NX:6?ooool3o`WZ2PSooooo0ol9jPX7ooooo`;o2NX:3oooool2o`WZ2POo
oooo0ol9jPXOooooo`;o2NX:U?ooool00ol9jP[oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00?o2NX:ooooooooool04?ooool00ol9jP[oooooo`WZ2P02ooooo`04o`WZ2_ooooooooooo`WZ
2P;ooooo00Ko2NX:oooooooooooo2NX:ooooool9jPX4ooooo`03o`WZ2_oooooooooo00cooooo00?o
0000ooooooooool01Oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oooooooooo03oooooo00?o
0000ooooooooool08oooool00<oooooo00?o0000ooooooooool0=?ooool01Ol0003ooooooooooooo
oooo000004gooooo0ol9jPXQooooo`Go2NX:5oooool4o`WZ2QCooooo1?l9jPXKooooo`?o2NX:1?oo
ool3o`WZ2QWooooo0ol9jPX8ooooo`?o2NX:1oooool3o`WZ2Poooooo0_l9jPX6ooooo`?o2NX:7ooo
ool3o`WZ2YOooooo00Co2NX:oooooooooooo00003Oooool00ol9jP[oooooooooo`0?ooooo`04o`WZ
2_ooooooooooo`WZ2P;ooooo00Co2NX:oooooooooooo2NX:0_ooool01_l9jP[oooooooooool9jP[o
ooooo`WZ2PCooooo00?o2NX:ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`WZ2_oo
oooooooo01Cooooo0_l9jPY0ooooo`03o`000?oooooooooo02;ooooo003?ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`16ooooo`Co2NX:7_ooool6
o`WZ2QWooooo0ol9jPXDooooo`Co2NX:6oooool4o`WZ2PCooooo0ol9jPXIooooo`?o2NX:2?ooool3
o`WZ2PSooooo0_l9jPX@ooooo`;o2NX:1_ooool2o`WZ2R3ooooo0_l9jPZJooooo`04o`WZ2_oooooo
ooooo`0000gooooo00?o2NX:ooooooooool04?ooool01?l9jP[oooooooooool9jPX2ooooo`04o`WZ
2_ooooooooooo`WZ2P;ooooo00?o2NX:ooooool9jPX00_ooool01Ol9jP[ooooooooooooooooo2NX:
00gooooo00?o0000ooooooooool01oooool00ol9jP[oooooooooo`0Eooooo`03o`WZ2_oooooooooo
03gooooo00?o0000ooooooooool08_ooool00<kooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo047ooooo1?l9jPXMooooo`Go2NX:6oooool4o`WZ2Q?o
oooo1?l9jPXLooooo`?o2NX:1?ooool4o`WZ2QWooooo0ol9jPX8ooooo`?o2NX:2?ooool3o`WZ2Q3o
oooo0_l9jPX5ooooo`?o2NX:7oooool3o`WZ2Ygooooo00?o2NX:o`000?ooool03_ooool00ol9jP[o
ooooooooo`0@ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo00Ko2NX:oooooooooooo2NX:ooooool9
jPX2ooooo`03o`WZ2_oooooo2NX:00Cooooo00?o2NX:ooooooooool02_ooool00ol0003ooooooooo
o`08ooooo`03o`WZ2_oooooooooo01Gooooo00?o2NX:ooooooooool0??ooool00ol0003ooooooooo
o`0Rooooo`00c_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0??ooool4o`WZ2Qcooooo1Ol9jPXMooooo`?o2NX:4oooool4o`WZ2Qgooooo0ol9jPX4
ooooo`?o2NX:6_ooool3o`WZ2PSooooo0ol9jPX9ooooo`;o2NX:4Oooool2o`WZ2PCooooo0ol9jPXO
ooooo`?o2NX:X?ooool00ol9jP[oooooooooo`0>ooooo`03o`WZ2_oooooooooo013ooooo00Co2NX:
oooooooooooo2NX:0oooool00ol9jP[oooooo`WZ2P02ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo
2NX:1?ooool00ol9jP[oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o2NX:oooooooo
ool05Oooool00ol9jP[oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo003>ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`Co2NX:
6oooool5o`WZ2Qkooooo1?l9jPXBooooo`Co2NX:7_ooool3o`WZ2PCooooo0ol9jPXKooooo`;o2NX:
2?ooool3o`WZ2P[ooooo0_l9jPXAooooo`;o2NX:1?ooool2o`WZ2R3ooooo0_l9jPZSooooo`03o`WZ
2_oooooooooo00oooooo00?o2NX:ooooooooool04?ooool01?l9jP[oooooooooool9jPX3ooooo`03
o`WZ2_oooooo2NX:00;ooooo00Ko2NX:oooooooooooo2NX:ooooool9jPX4ooooo`03o`WZ2_oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0Eooooo`03o`WZ2_oooooo
oooo03_ooooo00?o0000ooooooooool08Oooool00<kooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03;ooooo1?l9jPXIooooo`Ko2NX:8?ooool3o`WZ
2Q7ooooo1Ol9jPXOooooo`?o2NX:0oooool4o`WZ2Q_ooooo0ol9jPX7ooooo`?o2NX:2_ooool3o`WZ
2Q7ooooo0_l9jPX3ooooo`?o2NX:7oooool3o`WZ2ZCooooo00?o0000ooooool9jPX04Oooool00ol9
jP[oooooooooo`0@ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo00Co2NX:oooooooooooo2NX:0_oo
ool01Ol9jP[oooooo`WZ2_oooooo2NX:00Gooooo00?o2NX:ooooooooool01oooool00ol0003ooooo
ooooo`0;ooooo`03o`WZ2_oooooooooo01Gooooo0_l9jPXkooooo`03o`000?oooooooooo027ooooo
003=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0^ooooo`Co2NX:6?ooool5o`WZ2R;ooooo1?l9jPX@ooooo`Co2NX:8?ooool4o`WZ2P?ooooo0ol9
jPXLooooo`?o2NX:1oooool3o`WZ2P_ooooo0_l9jPXBooooo`;o2NX:0_ooool3o`WZ2R3ooooo0_l9
jPZWooooo`03o`000?oooooo2NX:017ooooo00?o2NX:ooooooooool04?ooool01Ol9jP[ooooooooo
oooooooo2NX:00;ooooo00Ko2NX:oooooooooooo2NX:ooooool9jPX2ooooo`03o`WZ2_oooooo2NX:
00Gooooo00?o2NX:ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`WZ2_oooooooooo
01Kooooo00?o2NX:ooooooooool0>?ooool00ol0003oooooooooo`0Qooooo`00cOooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:Oooool4o`WZ2QOo
oooo1Ol9jPXTooooo`?o2NX:4?ooool4o`WZ2R7ooooo0ol9jPX3ooooo`Co2NX:7?ooool3o`WZ2POo
oooo0ol9jPX<ooooo`;o2NX:4_ooool2o`WZ2P04ooooool9jP[o2NX:o`WZ2R3ooooo0ol9jPZXoooo
o`05o`000?ooooooooooooooool9jPX04Oooool00ol9jP[oooooooooo`0@ooooo`05o`WZ2_oooooo
ooooooooool9jPX00_ooool01_l9jP[oooooooooool9jP[oooooo`WZ2P;ooooo00?o2NX:ooooool9
jPX01?ooool00ol9jP[oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o2NX:oooooooo
ool05_ooool00ol9jP[oooooooooo`0hooooo`03o`000?oooooooooo023ooooo003=ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`Co2NX:
5Oooool6o`WZ2RGooooo1?l9jPX?ooooo`Co2NX:8_ooool3o`WZ2P?ooooo0ol9jPXMooooo`?o2NX:
1oooool3o`WZ2Pcooooo0ol9jPXBooooo`;o2NX:00?oooooo`WZ2_l9jPX08Oooool2o`WZ2Z[ooooo
00?o0000ooooooooool00_ooool00ol9jP[oooooooooo`0?ooooo`03o`WZ2_oooooooooo017ooooo
00Go2NX:ooooooooooooooooo`WZ2P02ooooo`03o`WZ2_oooooo2NX:00;ooooo00Go2NX:ooooool9
jP[oooooo`WZ2P05ooooo`03o`WZ2_oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol9
jP[oooooooooo`0Fooooo`03o`WZ2_oooooooooo03Gooooo0ol0000Rooooo`00cOooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool3o`WZ2QCo
oooo1Ol9jPXXooooo`?o2NX:3oooool4o`WZ2R?ooooo0ol9jPX3ooooo`?o2NX:7_ooool2o`WZ2PSo
oooo0_l9jPX=ooooo`;o2NX:4_ooool6o`WZ2R3ooooo0ol9jPZ/ooooo`03o`000?oooooooooo00;o
oooo00?o2NX:ooooooooool04?ooool00ol9jP[oooooooooo`0@ooooo`03o`WZ2_oooooooooo00;o
oooo00Ko2NX:oooooooooooo2NX:ooooool9jPX2ooooo`05o`WZ2_oooooo2NX:ooooool9jPX01Ooo
ool00ol9jP[oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o2NX:ooooooooool05_oo
ool00ol9jP[oooooooooo`0aooooo`?o00000_ooool00ol0003oooooooooo`0Pooooo`00cOooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool4
o`WZ2Q;ooooo1Ol9jPXYooooo`Co2NX:3_ooool4o`WZ2R?ooooo1?l9jPX2ooooo`Co2NX:7_ooool3
o`WZ2POooooo0ol9jPX<ooooo`?o2NX:4_ooool5o`WZ2R7ooooo0_l9jPZ^ooooo`03o`000?oooooo
oooo00Cooooo00?o2NX:ooooooooool03oooool00ol9jP[oooooooooo`0Aooooo`05o`WZ2_oooooo
ooooooooool9jPX00_ooool01_l9jP[oooooooooool9jP[oooooo`WZ2P;ooooo00?o2NX:ooooool9
jPX01Oooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o2NX:oooooooo
ool05_ooool00ol9jP[oooooooooo`0]ooooo`?o00001Oooool00ol0003oooooooooo`0Pooooo`00
cOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
5oooool4o`WZ2Q7ooooo1Ol9jPX[ooooo`?o2NX:3_ooool4o`WZ2RCooooo0ol9jPX3ooooo`?o2NX:
7oooool3o`WZ2POooooo0ol9jPX=ooooo`;o2NX:4oooool4o`WZ2R7ooooo0ol9jPZ_ooooo`03o`00
0?oooooooooo00Gooooo00?o2NX:ooooooooool04?ooool00ol9jP[oooooooooo`0Aooooo`05o`WZ
2_ooooooooooooooool9jPX00_ooool02_l9jP[oooooooooool9jP[oooooo`WZ2_oooooo2NX:oooo
ool9jPX6ooooo`03o`WZ2_oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol9jP[ooooo
ooooo`0Fooooo`;o2NX::_ooool3o`0000Sooooo00?o0000ooooooooool08?ooool00<cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo1?l9
jPX?ooooo`Ko2NX:;?ooool4o`WZ2Pcooooo1Ol9jPXUooooo`?o2NX:0oooool3o`WZ2Qoooooo0ol9
jPX7ooooo`?o2NX:3_ooool2o`WZ2Q?ooooo1?l9jPXQooooo`;o2NX:/_ooool00ol0003ooooooooo
o`06ooooo`03o`WZ2_oooooooooo00oooooo00?o2NX:ooooooooool04Oooool00ol9jP[ooooooooo
o`02ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:0_ooool01Ol9jP[oooooo`WZ2_oooooo2NX:
00Gooooo00?o2NX:ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`WZ2_oooooooooo
01Oooooo00?o2NX:ooooooooool09?ooool3o`0000_ooooo00?o0000ooooooooool08?ooool00<co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00ko
oooo1?l9jPX>ooooo`Go2NX:;oooool3o`WZ2Pcooooo1?l9jPXWooooo`?o2NX:0_ooool4o`WZ2Qoo
oooo0ol9jPX7ooooo`?o2NX:3_ooool3o`WZ2Q?ooooo0ol9jPXQooooo`?o2NX:/oooool00ol0003o
ooooooooo`07ooooo`03o`WZ2_oooooooooo013ooooo00?o2NX:ooooooooool04Oooool00ol9jP[o
ooooooooo`02ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:0_ooool01Ol9jP[oooooo`WZ2_oo
oooo2NX:00Gooooo00?o2NX:ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`WZ2_oo
oooooooo01Oooooo00?o2NX:ooooooooool07oooool4o`0000kooooo00?o0000ooooooooool08?oo
ool00<cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Wooooo1?l9jPX=ooooo`Go2NX:<?ooool4o`WZ2P_ooooo1?l9jPXXooooo`?o2NX:0_ooool3
o`WZ2R7ooooo0_l9jPX7ooooo`?o2NX:3oooool2o`WZ2Q?ooooo0ol9jPXRooooo`;o2NX:]_ooool0
0ol0003oooooooooo`07ooooo`03o`WZ2_oooooooooo013ooooo00?o2NX:ooooooooool04_ooool0
0ol9jP[oooooooooo`02ooooo`08o`WZ2_ooooooooooo`WZ2_oooooo2NX:ooooool9jPX2ooooo`03
o`WZ2_oooooo2NX:00Gooooo00Go2NX:ooooooooooooooooo`00000Eooooo`03o`WZ2_oooooooooo
01Oooooo00?o2NX:ooooooooool06oooool3o`0001;ooooo00?o0000ooooooooool08?ooool00<co
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Co
oooo1?l9jPX<ooooo`Go2NX:<_ooool3o`WZ2P_ooooo1?l9jPXXooooo`Co2NX:00?oooooo`WZ2_l9
jPX00_l9jPXQooooo`?o2NX:1_ooool3o`WZ2Q3ooooo0_l9jPXCooooo`?o2NX:8Oooool3o`WZ2[Oo
oooo00?o0000ooooooooool02Oooool00ol9jP[oooooooooo`0@ooooo`03o`WZ2_oooooooooo017o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooo`WZ2P02ooooo`07o`WZ2_oooooo2NX:oooo
ool9jP[oooooo`WZ2P06ooooo`04o`WZ2_ooooooooooo`0001Kooooo00?o2NX:ooooooooool05ooo
ool00ol9jP[oooooooooo`0Gooooo`?o00005Oooool00ol0003oooooooooo`0Pooooo`00c?ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?l9jPX:
ooooo`Ko2NX:<oooool4o`WZ2P[ooooo1?l9jPXYooooo`?o2NX:0_ooool3o`WZ2R;ooooo0ol9jPX6
ooooo`?o2NX:4?ooool3o`WZ2Q;ooooo1?l9jPXQooooo`;o2NX:^Oooool00ol0003oooooooooo`0:
ooooo`03o`WZ2_oooooooooo013ooooo00?o2NX:ooooooooool04_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooo2NX:00;ooooo00Oo2NX:ooooool9jP[oooooo`WZ2_oooooo2NX:00Kooooo
00?o2NX:ooooool000005oooool00ol9jP[oooooooooo`0Gooooo`;o2NX:5?ooool3o`0001Sooooo
00?o0000ooooooooool08?ooool00<cooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0>ooooo`Co2NX:2Oooool5o`WZ2SKooooo0ol9jPX:ooooo`Co2NX::_ooool3o`WZ2P;ooooo0ol9
jPXRooooo`?o2NX:1_ooool3o`WZ2Q7ooooo0_l9jPXBooooo`Go2NX:8?ooool3o`WZ2[_ooooo00?o
0000ooooooooool02oooool00ol9jP[oooooooooo`0@ooooo`03o`WZ2_oooooooooo01;ooooo00?o
2NX:ooooooooool00_ooool01_l9jP[oooooooooool9jP[oooooo`WZ2P;ooooo00Go2NX:ooooool9
jP[oooooo`WZ2P06ooooo`03o`WZ2_l0003ooooo01Oooooo00?o2NX:ooooooooool06?ooool00ol9
jP[oooooooooo`0>ooooo`?o00006oooool00ol0003oooooooooo`0Pooooo`00c?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00_ooooo0ol9jPX2ooooo`03o`000?oooooooooo00?o
oooo1Ol9jPXgooooo`Co2NX:2?ooool5o`WZ2R_ooooo0ol9jPX00ooooooo2NX:o`WZ2P02o`WZ2R;o
oooo0ol9jPX6ooooo`?o2NX:4_ooool2o`WZ2Q;ooooo0_l9jPX00ooooooo2NX:o`WZ2P0Pooooo`;o
2NX:_Oooool00ol0003oooooooooo`0<ooooo`03o`WZ2_oooooooooo013ooooo00?o2NX:oooooooo
ool04_ooool00ol9jP[oooooooooo`03ooooo`0<o`WZ2_ooooooooooo`WZ2_oooooo2NX:ooooool9
jP[oooooo`WZ2_oooooo2NX:1_ooool00ol9jP[oooooo`00000Hooooo`03o`WZ2_oooooooooo01So
oooo00?o2NX:ooooooooool02Oooool4o`0001kooooo00?o0000ooooooooool08?ooool00<_ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`Co2NX:1_ooool5o`WZ2SWooooo
0ol9jPX8ooooo`Co2NX:;?ooool4o`WZ2P04ooooool9jP[o2NX:o`WZ2RCooooo0_l9jPX6ooooo`?o
2NX:4_ooool3o`WZ2Q7ooooo0ol9jPX00ooooooo2NX:o`WZ2P0Oooooo`?o2NX:_oooool00ol0003o
ooooooooo`0<ooooo`03o`WZ2_oooooooooo017ooooo00?o2NX:ooooooooool04_ooool00ol9jP[o
ooooooooo`03ooooo`0<o`WZ2_ooooooooooo`WZ2_oooooo2NX:ooooool9jP[oooooo`WZ2_oooooo
2NX:1_ooool00ol9jP[o0000ooooo`0Hooooo`03o`WZ2_oooooooooo01Sooooo00?o2NX:oooooooo
ool01?ooool4o`0002;ooooo00?o0000ooooooooool08?ooool00<_ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`03ooooo`Co2NX:1?ooool6o`WZ2P03o`000?oooooooooo03Oooooo
1?l9jPX7ooooo`Co2NX:;Oooool3o`WZ2P;ooooo0ol9jPXTooooo`?o2NX:1Oooool3o`WZ2Q?ooooo
0_l9jPXAooooo`?o2NX:0_ooool2o`WZ2Qoooooo0_l9jP[1ooooo`03o`000?oooooooooo00kooooo
00?o2NX:ooooooooool04?ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo00?ooooo
00co2NX:oooooooooooo2NX:ooooool9jP[oooooo`WZ2_oooooo2NX:ooooool9jPX6ooooo`03o`WZ
2_oooooooooo01Sooooo00?o2NX:ooooooooool06?ooool00ol9jP[o0000o`000003o`0002Gooooo
00?o0000ooooooooool08Oooool00<_ooooo00?o0000ooooooooool0=_ooool2o`0000Co2NX:0ooo
ool5o`WZ2POooooo00?o0000ooooooooool0<_ooool4o`WZ2POooooo1?l9jPX^ooooo`?o2NX:00?o
ooooo`WZ2_l9jPX00_l9jPXTooooo`?o2NX:1Oooool3o`WZ2Q?ooooo0ol9jPX@ooooo`?o2NX:0ooo
ool2o`WZ2Qkooooo0ol9jP[2ooooo`03o`000?oooooooooo00oooooo00?o2NX:ooooooooool04Ooo
ool00ol9jP[oooooooooo`0Booooo`03o`WZ2_oooooooooo00Cooooo00Go2NX:ooooool9jP[ooooo
o`WZ2P02ooooo`04o`WZ2_oooooo2NX:o`WZ2PKooooo00?o0000o`WZ2_ooool06Oooool00ol9jP[o
ooooooooo`0Fooooo`;o000000?o2NX:o`000?ooool09oooool00ol0003oooooooooo`0Qooooo`00
boooool2o`0003Kooooo0ol9jPX2ooooo`Go2NX:3Oooool00ol0003oooooooooo`0^ooooo`?o2NX:
1oooool4o`WZ2Roooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXUooooo`?o2NX:1Oooool3o`WZ2QCo
oooo0_l9jPXAooooo`;o2NX:1?ooool2o`WZ2Qkooooo0_l9jP[5ooooo`03o`000?oooooooooo00oo
oooo00?o2NX:ooooooooool04_ooool00ol9jP[oooooooooo`0Booooo`03o`WZ2_oooooooooo00Co
oooo00_o2NX:ooooool9jP[oooooo`WZ2_oooooo2NX:ooooool9jP[oooooo`WZ2P05ooooo`03o`00
0?oooooo2NX:01[ooooo00?o2NX:ooooooooool04Oooool4o`0002cooooo00?o0000ooooooooool0
8Oooool00<_ooooo00?o0000ooooool00000<_ooool8o`WZ2Q;ooooo00?o0000ooooooooool0:_oo
ool4o`WZ2PKooooo1?l9jPX`ooooo`Oo2NX:9Oooool3o`WZ2PGooooo0ol9jPXEooooo`;o2NX:4?oo
ool3o`WZ2PCooooo0_l9jPXMooooo`?o2NX:a_ooool00ol0003oooooooooo`0Aooooo`03o`WZ2_oo
oooooooo017ooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`03ooooo`0<o`WZ2_oo
ooooooooo`WZ2_oooooo2NX:ooooool9jP[oooooo`WZ2_oooooo2NX:1?ooool01?l0003ooooooooo
ool9jPXJooooo`03o`WZ2_oooooooooo00gooooo0ol0000`ooooo`03o`000?oooooooooo027ooooo
003;ooooo`04o`000?ooooooooooo`0002kooooo1_l9jPX00ooooooo0000ooooo`0Eooooo`03o`00
0?oooooooooo02Kooooo0ol9jPX6ooooo`Co2NX:<?ooool7o`WZ2RKooooo0ol9jPX5ooooo`?o2NX:
5Oooool3o`WZ2Poooooo0ol9jPX5ooooo`;o2NX:7Oooool2o`WZ2/Wooooo00?o0000ooooooooool0
4Oooool00ol9jP[oooooooooo`0Booooo`03o`WZ2_oooooooooo01;ooooo00?o2NX:ooooooooool0
1?ooool02Ol9jP[oooooooooool9jP[oooooo`WZ2_oooooo2NX:ooooo`02o`WZ2PCooooo00Co0000
oooooooooooo2NX:6oooool00ol9jP[oooooooooo`08ooooo`Co0000<oooool00ol0003ooooooooo
o`0Qooooo`00boooool01Ol0003ooooooooooooooooo000002Sooooo1Ol9jPX7ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool08_ooool4o`WZ2PCooooo1Ol9jPXaooooo`?o2NX:00Co
ooooo`WZ2_l9jP[o2NX:9oooool2o`WZ2PGooooo0ol9jPXFooooo`;o2NX:3oooool3o`WZ2PKooooo
0_l9jPXLooooo`?o2NX:boooool00ol0003oooooooooo`0Booooo`03o`WZ2_oooooooooo017ooooo
00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`04ooooo`05o`WZ2_ooooooooooo`WZ2_oo
ool00_l9jPX01?oooooo2NX:ooooool9jPX3ooooo`05o`000?ooooooooooooooool9jPX06oooool0
0ol9jP[oooooooooo`03ooooo`Co0000=oooool00ol0003oooooooooo`0Qooooo`00boooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo1ol9jPX:ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool07_ooool3o`WZ2PCooooo1?l9jPXcooooo`Oo2NX:9oooool3o`WZ
2PCooooo0ol9jPXGooooo`;o2NX:3oooool2o`WZ2POooooo0_l9jPXKooooo`?o2NX:cOooool00ol0
003oooooooooo`0Cooooo`03o`WZ2_oooooooooo01;ooooo00?o2NX:ooooooooool04oooool00ol9
jP[oooooooooo`04ooooo`0;o`WZ2_oooooo2NX:ooooool9jP[oooooo`WZ2_oooooo2NX:ooooool9
jPX00_ooool00ol0003oooooooooo`02ooooo`03o`WZ2_oooooooooo01Wooooo00?o2NX:ooooool0
00000_l0000kooooo`03o`000?oooooooooo027ooooo003;ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool06_ooool5o`WZ2P;ooooo0_l9jPX=ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool06_ooool4o`WZ2P?ooooo1?l9jPXdooooo`Ko2NX::?ooool3o`WZ2PCooooo
0ol9jPXGooooo`?o2NX:3_ooool3o`WZ2POooooo0_l9jPXKooooo`;o2NX:d?ooool00ol0003ooooo
ooooo`0Cooooo`03o`WZ2_oooooooooo01;ooooo00?o2NX:ooooooooool04oooool00ol9jP[ooooo
ooooo`05ooooo`08o`WZ2_oooooo2NX:ooooool9jP[oooooo`WZ2_ooool2o`WZ2P;ooooo00?o0000
ooooooooool00oooool00ol9jP[oooooooooo`0Fooooo`?o000000?o2NX:ooooooooool0??ooool0
0ol0003oooooooooo`0Qooooo`00boooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01?ooooo1_l9jPX4ooooo`?o2NX:3oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Kooooo0ol9jPX3ooooo`Co2NX:=?ooool7o`WZ2RSooooo0ol9jPX5ooooo`;o2NX:6?ooool2o`WZ
2Pkooooo0ol9jPX7ooooo`?o2NX:6_ooool3o`WZ2];ooooo00?o0000ooooooooool05?ooool00ol9
jP[oooooooooo`0Booooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool01Oooool01_l9
jP[oooooo`WZ2_oooooo2NX:ooooo`;o2NX:00Coooooo`WZ2_oooooo00001_ooool00ol9jP[ooooo
ooooo`0Booooo`?o00000_ooool2o`0003kooooo00?o0000ooooooooool08Oooool00<_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`Go2NX:1oooool3o`WZ2Q;ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Aooooo`Co2NX:0_ooool4o`WZ2SGooooo1ol9
jPXXooooo`?o2NX:1Oooool3o`WZ2QOooooo0ol9jPX>ooooo`;o2NX:2?ooool2o`WZ2Q_ooooo0_l9
jP[Dooooo`03o`000?oooooooooo01Gooooo00?o2NX:ooooooooool04_ooool00ol9jP[ooooooooo
o`0Dooooo`03o`WZ2_oooooooooo00Gooooo00Co2NX:ooooool9jP[ooooo0_l9jPX01Ooooooo2NX:
ooooool9jP[o000000Kooooo00?o2NX:ooooooooool03oooool3o`0004Gooooo00?o0000oooooooo
ool08Oooool00<_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`Go2NX:
2Oooool3o`WZ2QGooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0>ooooo`?o2NX:
0_ooool4o`WZ2SKooooo1_l9jPXZooooo`;o2NX:1Oooool3o`WZ2QSooooo0_l9jPX>ooooo`?o2NX:
2?ooool2o`WZ2Q[ooooo0ol9jP[Fooooo`03o`000?oooooooooo01Kooooo00?o2NX:ooooooooool0
4_ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool0
0_l9jPX00ooooooo2NX:ooooo`02o`WZ2P03o`000?oooooooooo00Gooooo00?o2NX:ooooooooool0
2oooool3o`0004Sooooo00?o0000ooooooooool08Oooool00<_ooooo00?o0000ooooooooool01ooo
ool2o`0000;ooooo1Ol9jPX<ooooo`;o2NX:6?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Wooooo1?l9jPX00ooooooo2NX:o`WZ2P02o`WZ2SOooooo1_l9jPXZooooo`?o2NX:1?oo
ool3o`WZ2QWooooo0_l9jPX=ooooo`?o2NX:2Oooool2o`WZ2Q[ooooo0_l9jP[Iooooo`03o`000?oo
oooooooo01Kooooo00?o2NX:ooooooooool04_ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oo
oooooooo00Gooooo00So2NX:ooooool9jP[oooooo`WZ2_oooooo2NX:ooooo`;o2NX:00?o0000oooo
ooooool01Oooool00ol9jP[oooooooooo`07ooooo`?o0000Boooool00ol0003oooooooooo`0Qoooo
o`00boooool00ol0003oooooooooo`07ooooo`04o`000?l9jP[o2NX:o`WZ2Pkooooo0ol9jPXJoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool8o`WZ2SSooooo1Ol9jPX[oooo
o`?o2NX:1?ooool3o`WZ2QWooooo0ol9jPX<ooooo`?o2NX:2_ooool2o`WZ2QWooooo0ol9jP[Joooo
o`03o`000?oooooooooo01Oooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0Doooo
o`03o`WZ2_oooooooooo00Gooooo00Ko2NX:ooooool9jP[oooooo`WZ2_ooool2o`WZ2P03o`000?l9
jP[ooooo00Oooooo00?o2NX:ooooooooool00_ooool4o`0004kooooo00?o0000ooooooooool08Ooo
ool00<_ooooo00?o0000ooooooooool01?ooool3o`WZ2P;ooooo00?o0000ooooooooool02_ooool3
o`WZ2Qgooooo00?o0000ooooooooool06Oooool01?l0003oooooooooooooool7o`WZ2SWooooo1_l9
jPX[ooooo`?o2NX:1?ooool3o`WZ2Q[ooooo0_l9jPX=ooooo`;o2NX:2oooool2o`WZ2QWooooo0_l9
jP[Mooooo`03o`000?oooooooooo01Sooooo00?o2NX:ooooooooool04_ooool00ol9jP[ooooooooo
o`0Dooooo`03o`WZ2_oooooooooo00Kooooo00Co2NX:ooooool9jP[ooooo0_l9jPX00ooooooo2NX:
o`000009ooooo`04o`WZ2_l0003o0000o`00057ooooo00?o0000ooooooooool08_ooool00<_ooooo
00Co0000oooooooooooooooo0ol9jPX6ooooo`03o`000?oooooooooo00Kooooo0ol9jPXOooooo`03
o`000?oooooooooo01[ooooo00?o0000o`WZ2_l9jPX01?l9jPXjooooo`Ko2NX::oooool3o`WZ2PCo
oooo0ol9jPXKooooo`;o2NX:3?ooool3o`WZ2P_ooooo0_l9jPXHooooo`?o2NX:goooool00ol0003o
ooooooooo`0Hooooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool05?ooool00ol9jP[o
ooooooooo`06ooooo`04o`WZ2_oooooo2NX:ooooo`;o2NX:00?o0000o`WZ2_ooool01_ooool3o`00
0003o`WZ2_l0003ooooo057ooooo00?o0000ooooooooool08_ooool00<_ooooo00Co0000o`WZ2_l9
jP[o2NX:2_ooool00ol0003oooooooooo`02ooooo`?o2NX:8_ooool00ol0003oooooooooo`0Goooo
o`Ko2NX:>oooool5o`WZ2Rgooooo0_l9jPX4ooooo`?o2NX:6oooool3o`WZ2P_ooooo0ol9jPX<oooo
o`;o2NX:6?ooool2o`WZ2^7ooooo00?o0000ooooooooool06_ooool00ol9jP[oooooooooo`0Boooo
o`03o`WZ2_oooooooooo01Gooooo00?o2NX:ooooooooool01_ooool01ol9jP[oooooo`WZ2_l9jP[o
ooooo`WZ2_l000001?ooool3o`0005Oooooo00?o0000ooooooooool08_ooool00<Wooooo0_l9jPX0
0ol0003oooooooooo`0<ooooo`04o`000?oooooo2NX:o`WZ2RGooooo00?o0000ooooooooool05?oo
ool5o`WZ2P;ooooo00?o0000ooooooooool0=oooool5o`WZ2Rgooooo0ol9jPX3ooooo`?o2NX:7?oo
ool2o`WZ2Pcooooo0_l9jPX=ooooo`;o2NX:5oooool3o`WZ2^?ooooo00?o0000ooooooooool06_oo
ool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool01ooo
ool01_l9jP[oooooo`WZ2_l9jP[oooooo`WZ2PCo0000FOooool00ol0003oooooooooo`0Sooooo`00
a_ooool3o`WZ2P;ooooo00?o0000ooooooooool02oooool2o`WZ2P03o`000?oooooooooo02Gooooo
00?o0000ooooooooool04?ooool5o`WZ2PKooooo00?o0000ooooooooool0<oooool6o`WZ2Rgooooo
0ol9jPX3ooooo`?o2NX:7?ooool3o`WZ2P_ooooo0ol9jPX=ooooo`;o2NX:5oooool2o`WZ2^Kooooo
00?o0000ooooooooool06_ooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo01Gooooo
00?o2NX:ooooooooool01_ooool01Ol9jP[oooooo`WZ2_l0003o2NX:00;o0000G?ooool00ol0003o
ooooooooo`0Sooooo`00`oooool3o`WZ2PGooooo00?o0000ooooooooool02?ooool3o`WZ2P?ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`Co2NX:2oooool00ol0003ooooo
ooooo`0_ooooo`Go2NX:;_ooool3o`WZ2P?ooooo0ol9jPXMooooo`;o2NX:2oooool3o`WZ2Pkooooo
0_l9jPXFooooo`?o2NX:ioooool00ol0003oooooooooo`0Looooo`03o`WZ2_oooooooooo01?ooooo
00?o2NX:ooooooooool05Oooool00ol9jP[oooooooooo`05ooooo`07o`000?l9jP[o0000o`WZ2_oo
oooo2NX:o`00001Looooo`03o`000?oooooooooo02?ooooo0030ooooo`?o2NX:2?ooool00ol0003o
ooooooooo`05ooooo`?o2NX:1oooool2o`0002Cooooo00?o0000ooooooooool02?ooool5o`WZ2Poo
oooo00?o0000ooooooooool0;?ooool5o`WZ2Rkooooo0ol9jPX3ooooo`?o2NX:7_ooool2o`WZ2P[o
oooo0ol9jPX?ooooo`;o2NX:5_ooool2o`WZ2^[ooooo00?o0000ooooooooool07?ooool00ol9jP[o
ooooooooo`0Dooooo`03o`WZ2_oooooooooo01Cooooo00?o2NX:ooooooooool00_ooool3o`0000;o
oooo00?o2NX:ooooool9jPX00_l0001Looooo`03o`000?oooooooooo02?ooooo002mooooo`?o2NX:
2oooool00ol0003oooooooooo`03ooooo`;o2NX:3?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Cooooo1Ol9jPXDooooo`03o`000?oooooooooo02Sooooo1?l9jPX_ooooo`?o2NX:
0oooool3o`WZ2Qkooooo0ol9jPX:ooooo`;o2NX:4?ooool2o`WZ2QGooooo0ol9jP[/ooooo`03o`00
0?oooooooooo01gooooo00?o2NX:ooooooooool04oooool00ol9jP[oooooooooo`0Eooooo`04o`WZ
2_l0003o0000o`0000Kooooo00Co2NX:ooooool9jP[o0000Foooool00ol0003oooooooooo`0Toooo
o`00^_ooool3o`WZ2Pkooooo00?o0000ooooooooool00ol9jPX?ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool01_l9jPXGooooo`03o`000?oooooooooo02Gooooo1?l9jPX`ooooo`;o
2NX:0oooool3o`WZ2Qoooooo0_l9jPX:ooooo`?o2NX:4?ooool2o`WZ2QGooooo0_l9jP[^ooooo`03
o`000?oooooooooo01kooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0Booooo`?o
000000?o2NX:o`000?ooool01oooool00ol9jP[o0000o`WZ2P1Kooooo`03o`000?oooooooooo02Co
oooo002gooooo`?o2NX:4Oooool00ol0003o2NX:o`WZ2P0Cooooo`03o`000?oooooooooo01kooooo
1_l9jPXLooooo`03o`000?oooooooooo023ooooo1Ol9jPX`ooooo`?o2NX:0_ooool3o`WZ2R3ooooo
0_l9jPX9ooooo`?o2NX:4Oooool2o`WZ2QCooooo0ol9jP[`ooooo`03o`000?oooooooooo01kooooo
00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0?ooooo`?o00003_ooool00ol9jP[o0000
ooooo`1Jooooo`03o`000?oooooooooo02Cooooo002dooooo`?o2NX:4Oooool3o`WZ2P03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool06Oooool7o`WZ2Qoooooo00?o0000ooooooooool07Ooo
ool4o`WZ2S7ooooo0ol9jPX2ooooo`?o2NX:8?ooool3o`WZ2PWooooo0_l9jPXBooooo`;o2NX:5?oo
ool2o`WZ2_?ooooo00?o0000ooooooooool07oooool00ol9jP[oooooooooo`0Dooooo`03o`WZ2_oo
oooooooo00_ooooo0ol0000Aooooo`03o`000?l9jP[ooooo05Wooooo00?o0000ooooooooool09Ooo
ool00;7ooooo0ol9jPXAooooo`?o2NX:0oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01Cooooo1?l9jPX01_oooooo2NX:o`WZ2_l9jP[oooooo`00023ooooo00?o0000ooooooooool0
6_ooool4o`WZ2S7ooooo0ol9jPX2ooooo`?o2NX:8Oooool2o`WZ2PWooooo0ol9jPXBooooo`;o2NX:
4oooool3o`WZ2_Cooooo00?o0000ooooooooool08?ooool00ol9jP[oooooooooo`0Dooooo`03o`WZ
2_oooooooooo00Sooooo0ol0000Eooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
9Oooool00:kooooo0ol9jPXBooooo`;o2NX:1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00oooooo1?l9jPX2ooooo`?o2NX:1?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01Kooooo1?l9jPXaooooo`?o2NX:0_ooool3o`WZ2R7ooooo0ol9jPX8ooooo`?o2NX:4ooo
ool2o`WZ2Q?ooooo0_l9jP[gooooo`03o`000?oooooooooo027ooooo00?o2NX:ooooooooool05?oo
ool00ol9jP[oooooooooo`04ooooo`?o00006?ooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooooooo02Gooooo002[ooooo`?o2NX:4_ooool3o`WZ2PSooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`09ooooo`Go2NX:0oooool3o`WZ2POooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Booooo`Co2NX:<oooool2o`WZ2P;ooooo0ol9jPXRooooo`;o2NX:2?ooool3
o`WZ2QCooooo0_l9jPXBooooo`?o2NX:nOooool00ol0003oooooooooo`0Qooooo`03o`WZ2_oooooo
oooo01Cooooo00Co2NX:oooooooooooooooo0ol0000Kooooo`03o`000?oooooooooo05Oooooo00?o
0000ooooooooool09_ooool00:Sooooo0ol9jPXBooooo`?o2NX:2oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Cooooo1?l9jPX5ooooo`?o2NX:2_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00kooooo1?l9jPXcooooo`?o2NX:0_ooool2o`WZ2R?ooooo0_l9jPX8
ooooo`;o2NX:5Oooool2o`WZ2Q;ooooo0_l9jP[looooo`03o`000?oooooooooo027ooooo00?o2NX:
ooooooooool05?ooool01?l0003o2NX:o`000?l0000Nooooo`03o`000?oooooooooo05Oooooo00?o
0000ooooooooool09_ooool00:Gooooo0ol9jPXBooooo`?o2NX:3_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooo2NX:00?o2NX:1_ooool3o`WZ2Pgooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0;ooooo`?o2NX:=?ooool3o`WZ2P;ooooo0ol9jPXRooooo`?o2NX:1oooool3
o`WZ2QCooooo0ol9jPXAooooo`?o2NX:o_ooool00ol0003oooooooooo`0Rooooo`03o`WZ2_oooooo
oooo013ooooo1Ol0000Pooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool09_ooool0
0:;ooooo0ol9jPXBooooo`?o2NX:4_ooool00ol0003oooooooooo`0Gooooo`?o2NX:1oooool3o`WZ
2Q3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`?o2NX:=?ooool3o`WZ
2P;ooooo0ol9jPXSooooo`;o2NX:1oooool3o`WZ2QGooooo0_l9jPXAooooo`?o2NX:ooooool2oooo
o`03o`000?oooooooooo02;ooooo00?o2NX:ooooooooool03Oooool3o`0002Gooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`0Vooooo`00Woooool3o`WZ2Q?ooooo0_l9jPXEooooo`03
o`000?oooooooooo01Cooooo0ol9jPX01?oooooo0000o`000?l00003ooooo`?o2NX:4oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo1?l9jPXdooooo`?o2NX:0_ooool3o`WZ
2RCooooo0_l9jPX7ooooo`;o2NX:5_ooool2o`WZ2Q7ooooo0_l9jP[oooooo`Cooooo00?o0000oooo
ooooool09?ooool00ol9jP[oooooooooo`09ooooo`?o0000:?ooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo02Oooooo002Looooo`?o2NX:4oooool3o`WZ2QOooooo00?o0000oooooooo
ool04Oooool3o`WZ2POooooo00?o0000o`WZ2_l9jPX05_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Co2NX:=Oooool2o`WZ2P;ooooo0ol9jPXTooooo`?o2NX:1_ooool3o`WZ2QKo
oooo0_l9jPX@ooooo`?o2NX:ooooool6ooooo`03o`000?oooooooooo02Cooooo00?o2NX:oooooooo
ool01_ooool3o`0002_ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Wooooo`00
VOooool3o`WZ2Q?ooooo0ol9jPXJooooo`03o`000?oooooooooo00kooooo0ol9jPX7ooooo`?o2NX:
00?oooooo`000?ooool05_ooool00ol0003oooooooooo`0Qooooo`?o2NX:=_ooool3o`WZ2P04oooo
ool9jP[o2NX:o`WZ2RGooooo0_l9jPX6ooooo`?o2NX:5oooool2o`WZ2Q3ooooo0_l9jP[oooooo`Wo
oooo00?o0000ooooooooool09?ooool00ol9jP[oooooooooo`02ooooo`Co0000;oooool00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo02Oooooo002Fooooo`?o2NX:4oooool3o`WZ2Qgooooo
00?o0000ooooooooool02oooool3o`WZ2PSooooo0_l9jPX5ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool07Oooool4o`WZ2P03ooooool0003ooooo03?ooooo0ol9jPX01?oooooo2NX:
o`WZ2_l9jPXUooooo`?o2NX:1Oooool3o`WZ2QSooooo0_l9jPX?ooooo`?o2NX:ooooool;ooooo`03
o`000?oooooooooo02Gooooo00Co2NX:o`000?l0003o0000<oooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo02Sooooo002Cooooo`?o2NX:5?ooool2o`WZ2R7ooooo00?o0000oooooooo
ool01oooool3o`WZ2PSooooo0ol9jPX8ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool06_ooool4o`WZ2PGooooo00?o0000ooooooooool0;_ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ
2RKooooo0_l9jPX6ooooo`;o2NX:6Oooool2o`WZ2Poooooo0_l9jP[oooooo`kooooo00?o0000oooo
ooooool08oooool4o`0003Gooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Xoooo
o`00T?ooool3o`WZ2QCooooo0ol9jPXSooooo`03o`000?oooooooooo00Cooooo0ol9jPX8ooooo`?o
2NX:3?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo1Ol9jPX8ooooo`03
o`000?oooooooooo02_ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXWooooo`;o2NX:1Oooool3o`WZ
2QWooooo0_l9jPX>ooooo`?o2NX:ooooool@ooooo`03o`000?oooooooooo023ooooo0ol0000ioooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0:?ooool008gooooo0ol9jPXDooooo`?o
2NX:9_ooool01?l0003oooooooooooooool3o`WZ2PSooooo0ol9jPX@ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04oooool4o`WZ2Pcooooo00?o0000ooooooooool0:?ooool3o`WZ
2P04ooooool9jP[o2NX:o`WZ2ROooooo0ol9jPX4ooooo`?o2NX:6_ooool2o`WZ2Pkooooo0_l9jP[o
oooooa?ooooo00?o0000ooooooooool07Oooool3o`0003cooooo00?o0000ooooooooool0Doooool0
0ol0003oooooooooo`0Yooooo`00R_ooool3o`WZ2QCooooo0ol9jPXYooooo`04o`000?l9jP[o2NX:
o`WZ2PSooooo0ol9jPXDooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool4
o`WZ2Q3ooooo00?o0000ooooooooool09Oooool2o`WZ2P04ooooool9jP[o2NX:o`WZ2RSooooo0_l9
jPX5ooooo`;o2NX:6oooool2o`WZ2Pgooooo0ol9jP[ooooooaGooooo00?o0000ooooooooool06Ooo
ool4o`0003oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Zooooo`00Qoooool3
o`WZ2QCooooo0ol9jPXZooooo`;o2NX:00?o0000ooooooooool01_ooool3o`WZ2QSooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0<ooooo`Go2NX:4oooool00ol0003oooooooooo`0R
ooooo`Ko2NX::Oooool2o`WZ2PCooooo0ol9jPXKooooo`;o2NX:3Oooool2o`WZ2_oooooo6?ooool0
0ol0003oooooooooo`0Fooooo`?o0000@oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo02[ooooo0024ooooo`?o2NX:5Oooool2o`WZ2R[ooooo0ol9jPX3ooooo`03o`000?oooooooooo
00;ooooo0ol9jPXLooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool5o`WZ
2QKooooo00?o0000ooooooooool07oooool6o`WZ2RWooooo0ol9jPX3ooooo`?o2NX:7?ooool2o`WZ
2Pcooooo0ol9jP[ooooooa[ooooo00?o0000ooooooooool04_ooool4o`0004Kooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0[ooooo`00POooool3o`WZ2QGooooo0ol9jPXYooooo`?o
2NX:1_ooool00ol0003oooooo`WZ2P02o`WZ2R3ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`06ooooo`Go2NX:6_ooool00ol0003oooooooooo`0Kooooo`Ko2NX::_ooool2o`WZ2P?o
oooo0ol9jPXMooooo`;o2NX:3?ooool2o`WZ2_oooooo7Oooool00ol0003oooooooooo`0?ooooo`?o
0000B_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02cooooo001nooooo`?o2NX:
5Oooool3o`WZ2RWooooo0ol9jPX8ooooo`03o`WZ2_l0003o2NX:02Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`02ooooo`Go2NX:7_ooool00ol0003oooooooooo`0Hooooo`Ko2NX:
:_ooool3o`WZ2P?ooooo0_l9jPXNooooo`;o2NX:2oooool3o`WZ2_oooooo7_ooool00ol0003ooooo
ooooo`0<ooooo`Co0000C_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02cooooo
001kooooo`?o2NX:5Oooool3o`WZ2RWooooo0ol9jPX9ooooo`;o2NX:00?oooooo`000?ooool09Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Go2NX:8Oooool00ol0003ooooooooo
o`0Fooooo`Go2NX::oooool2o`WZ2P?ooooo0ol9jPXNooooo`;o2NX:2oooool2o`WZ2_oooooo8Ooo
ool00ol0003oooooooooo`09ooooo`?o0000D_ooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo02gooooo001hooooo`?o2NX:5Oooool3o`WZ2RWooooo0ol9jPX9ooooo`?o2NX:0oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo1_l9jPXTooooo`03o`000?oooooo
oooo01?ooooo1Ol9jPX/ooooo`;o2NX:0_ooool3o`WZ2Qoooooo0_l9jPX:ooooo`?o2NX:oooooolS
ooooo`03o`000?oooooooooo00Kooooo0ol0001Eooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0;Oooool007Gooooo0ol9jPXFooooo`;o2NX::Oooool3o`WZ2PWooooo0ol9jPX7oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool6o`WZ2RSooooo00?o0000oooo
ooooool03oooool5o`WZ2Rcooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXPooooo`;o2NX:2_ooool2
o`WZ2_oooooo9_ooool00ol0003oooooooooo`02ooooo`Co0000F?ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo02kooooo001booooo`?o2NX:5_ooool3o`WZ2RSooooo0ol9jPX9oooo
o`?o2NX:2_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Ko2NX:00?oooooo`00
0?l00000:?ooool00ol0003oooooooooo`0<ooooo`Go2NX:;Oooool2o`WZ2P;ooooo0_l9jPXQoooo
o`;o2NX:2Oooool3o`WZ2_oooooo:?ooool00ol0003oooooo`000002o`0005cooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0_ooooo`00Koooool3o`WZ2QKooooo0ol9jPXXooooo`?o
2NX:2Oooool3o`WZ2Pgooooo00?o0000ooooooooool09Oooool00ol9jP[o0000o`WZ2P04o`WZ2PCo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`Go2NX:;_ooool2o`WZ2P04
ooooool9jP[o2NX:o`WZ2R7ooooo0_l9jPX9ooooo`;o2NX:ooooool[ooooo`;o0000Goooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo02oooooo001/ooooo`?o2NX:5_ooool3o`WZ2RSo
oooo0ol9jPX9ooooo`?o2NX:4?ooool00ol0003oooooooooo`0Rooooo`?o2NX:00Coooooo`000?l0
003o00001oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo1?l9jPX^oooo
o`Ko2NX:8Oooool3o`WZ2PSooooo0ol9jP[oooooobgooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo033ooooo001Yooooo`?o2NX:5oooool2o`WZ2RSo
oooo0ol9jPX9ooooo`?o2NX:4oooool00ol0003oooooooooo`0Oooooo`?o2NX:00Coooooo`WZ2_l9
jP[o2NX:0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool00oooool5o`WZ2Rkooooo0_l9jPX00ooooooo2NX:o`WZ2P0Rooooo`;o2NX:2Oooool2o`WZ
2_oooooo<?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool0<Oooool006Kooooo0ol9jPXGooooo`?o2NX:9oooool3o`WZ2PWooooo0ol9jPXGooooo`03
o`000?oooooooooo01_ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX7ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05o`WZ2Rkooooo1_l9jPXRoooo
o`;o2NX:2?ooool3o`WZ2_oooooo<_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool0<Oooool006?ooooo0ol9jPXGooooo`?o2NX:9oooool3o`WZ2PWo
oooo0ol9jPXJooooo`03o`000?oooooooooo01Sooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX;oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool5o`WZ2Roooooo1Ol9jPXSoooo
o`;o2NX:2?ooool2o`WZ2_oooooo=_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0<_ooool0063ooooo0ol9jPXGooooo`?o2NX:9oooool3o`WZ2PWo
oooo0ol9jPXMooooo`03o`000?oooooooooo01Gooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX?oooo
o`05o`000?ooooooooooooooool000009oooool5o`WZ2S3ooooo1?l9jPXTooooo`;o2NX:1oooool3
o`WZ2_oooooo>?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool0<oooool005gooooo0ol9jPXGooooo`?o2NX:9oooool3o`WZ2P[ooooo0_l9jPXPoooo
o`03o`000?oooooooooo01;ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXCooooo`04o`000?oooooo
ooooo`0002Gooooo1?l9jPX2ooooo`03o`000?oooooooooo02_ooooo1?l9jPXUooooo`;o2NX:1_oo
ool3o`WZ2_oooooo>oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool0<oooool005[ooooo0ol9jPXHooooo`;o2NX:9oooool3o`WZ2P[ooooo0ol9jPXR
ooooo`03o`000?oooooooooo00oooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXGooooo`03o`000?oo
oooo000002;ooooo1?l9jPX5ooooo`03o`000?oooooooooo02Wooooo1?l9jPXUooooo`;o2NX:1_oo
ool2o`WZ2_oooooo?_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0=?ooool005Oooooo0ol9jPXHooooo`?o2NX:9_ooool3o`WZ2P[ooooo0ol9jPXV
ooooo`03o`000?oooooooooo00_ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXKooooo`;o00007ooo
ool4o`WZ2PWooooo00?o0000ooooooooool09_ooool3o`WZ2RKooooo0_l9jPX5ooooo`?o2NX:oooo
oom0ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0dooooo`00E?ooool3o`WZ2QSooooo0ol9jPXVooooo`?o2NX:2_ooool3o`WZ2RWooooo00?o0000
ooooooooool02?ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2Qoooooo00?o0000ooooooooool06_oo
ool4o`WZ2Pcooooo00?o0000ooooooooool08oooool3o`WZ2ROooooo0_l9jPX5ooooo`;o2NX:oooo
oom4ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`0eooooo`00DOooool3o`WZ2QSooooo0ol9jPXVooooo`?o2NX:2_ooool3o`WZ2Rcooooo00?o0000
ooooooooool01Oooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2R;ooooo0_l0000Hooooo`Co2NX:3ooo
ool00ol0003oooooooooo`0Qooooo`?o2NX:9oooool2o`WZ2PCooooo0ol9jP[oooooodKooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo03Kooooo001>
ooooo`?o2NX:6Oooool2o`WZ2RKooooo0ol9jPX:ooooo`?o2NX:<?ooool01?l0003ooooooooooooo
ool3o`WZ2P04ooooool9jP[o2NX:o`WZ2RGooooo00?o0000ooooool000005?ooool4o`WZ2Q?ooooo
00?o0000ooooooooool07Oooool3o`WZ2RSooooo0_l9jPX4ooooo`;o2NX:oooooom9ooooo`03o`00
0?oooooooooo05gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0fooooo`00Booo
ool3o`WZ2QWooooo0ol9jPXVooooo`;o2NX:2_ooool3o`WZ2S?ooooo00Go0000o`WZ2_l9jP[o2NX:
ooooo`03o`WZ2RSooooo00Co0000oooooooooooo00004Oooool3o`WZ2QKooooo00?o0000oooooooo
ool06_ooool3o`WZ2RWooooo0_l9jPX3ooooo`?o2NX:oooooom;ooooo`03o`000?oooooooooo05go
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0gooooo`00B?ooool3o`WZ2QWooooo
0ol9jPXVooooo`?o2NX:2Oooool3o`WZ2SCooooo0_l9jPX00ol0003oooooo`WZ2P02o`WZ2R_ooooo
00Go0000ooooooooooooooooo`00000=ooooo`?o2NX:6Oooool00ol0003oooooooooo`0Hooooo`?o
2NX::Oooool2o`WZ2P?ooooo0_l9jP[oooooodkooooo00?o0000ooooooooool0GOooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo03Sooooo0015ooooo`?o2NX:6Oooool3o`WZ2RKooooo
0ol9jPX9ooooo`?o2NX:=?ooool3o`WZ2P04ooooool9jP[o2NX:o`0002kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`?o2NX:7?ooool00ol0003oooooooooo`0Eooooo`Co
2NX::Oooool2o`WZ2P;ooooo0ol9jP[ooooooe7ooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo03Wooooo0012ooooo`?o2NX:6Oooool3o`WZ2RKooooo
0ol9jPX9ooooo`?o2NX:=?ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2P;ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0ol9jPXPooooo`03
o`000?oooooooooo017ooooo1?l9jPXZooooo`;o2NX:0_ooool2o`WZ2_ooooooE?ooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0>_ooool003oooooo
0ol9jPXKooooo`03o`WZ2_oooooooooo02Cooooo0ol9jPX:ooooo`;o2NX:=?ooool3o`WZ2P04oooo
ool9jP[o2NX:o`WZ2PGooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo2NX:00;o2NX:8oooool00ol0003oooooooooo`0?ooooo`Co2NX::_ooool2o`WZ2P04
ooooool9jP[o2NX:o`WZ2_ooooooE_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0>oooool003cooooo0ol9jPY2ooooo`?o2NX:2_ooool3o`WZ2S?o
oooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX9ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool01?ooool3o`WZ2P03o`000?oooooooooo02?ooooo00?o0000ooooooooool03?ooool5o`WZ
2R[ooooo0_l9jPX00ooooooo2NX:o`WZ2P3ooooooeWooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03cooooo000iooooo`?o2NX:@_ooool3o`WZ2P[o
oooo0ol9jPXcooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:3?ooool00ol0003oooooooooo`0Zoooo
o`04o`000?ooooooooooooooo`?o2NX:0_ooool2o`0002Gooooo00?o0000ooooooooool02Oooool5
o`WZ2R_ooooo1Ol9jP[ooooooe_ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo03gooooo000fooooo`?o2NX:@_ooool3o`WZ2P[ooooo0ol9jPXcoooo
o`?o2NX:00Coooooo`WZ2_l9jP[o2NX:3oooool00ol0003oooooooooo`0Zooooo`04o`000?l9jP[o
2NX:o`WZ2POooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`Ko2NX::ooo
ool4o`WZ2_ooooooGoooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool0?_ooool003?ooooo0ol9jPY2ooooo`?o2NX:2_ooool3o`WZ2S?ooooo0ol9jPX0
1?oooooo2NX:o`WZ2_l9jPXBooooo`03o`000?oooooooooo02Sooooo0ol9jPX00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool2o`WZ2P03ooooool9
jP[o2NX:02cooooo1?l9jP[oooooof7ooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo03oooooo000`ooooo`?o2NX:@_ooool3o`WZ2P[ooooo0ol9jPXc
ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:5_ooool00ol0003oooooooooo`0Tooooo`?o2NX:0_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00ol9
jPX00ooooooo2NX:o`WZ2P0[ooooo`Co2NX:oooooomTooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`10ooooo`00;Oooool3o`WZ2T;ooooo0ol9jPX:
ooooo`?o2NX:<oooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2QWooooo00?o0000ooooooooool08Ooo
ool3o`WZ2PGooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`?o2NX:00Co
ooooo`WZ2_l9jP[o2NX::oooool4o`WZ2_ooooooI_ooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0@Oooool002_ooooo0_l9jPY2ooooo`?o2NX:2_oo
ool3o`WZ2S?ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXLooooo`03o`000?oooooooooo01kooooo
0ol9jPX8ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07Oooool2o`WZ2P04o`00
0?oooooo2NX:o`WZ2Rcooooo0ol9jP[oooooof[ooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04;ooooo001/ooooo`?o2NX:2_ooool3o`WZ2S?ooooo
0ol9jPX01?oooooo2NX:o`WZ2_l9jPXPooooo`03o`000?oooooooooo01[ooooo0ol9jPX;ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool3o`WZ2P;ooooo0_l9jPX/ooooo`?o
2NX:oooooom]ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`13ooooo`00JOooool3o`WZ2P_ooooo0_l9jPXcooooo`?o2NX:00Coooooo`WZ2_l9jP[o
2NX:8oooool00ol0003oooooooooo`0Gooooo`?o2NX:3_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Gooooo0ol9jPX2ooooo`?o2NX:00?oooooo`000?ooool0:Oooool2o`WZ2_oo
ooooL?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0A?ooool006Kooooo0ol9jPX;ooooo`?o2NX:<_ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2RKo
oooo00?o0000ooooooooool05?ooool3o`WZ2Q7ooooo00?o0000ooooooooool03oooool2o`0001;o
oooo0ol9jPX3ooooo`;o2NX:1?ooool00ol0003oooooooooo`0Uooooo`?o2NX:oooooomcooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`15ooooo`00
Hoooool3o`WZ2P_ooooo0ol9jPXbooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX::_ooool00ol0003o
ooooooooo`0@ooooo`?o2NX:5?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00go
oooo0_l9jPX3ooooo`?o2NX:1_ooool00ol0003oooooooooo`0Sooooo`?o2NX:oooooomfooooo`03
o`000?oooooooooo05Sooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`16ooooo`00
H?ooool3o`WZ2P_ooooo0ol9jPXbooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:;Oooool00ol0003o
ooooooooo`0<ooooo`Co2NX:5oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wo
oooo0ol9jPX3ooooo`;o2NX:2Oooool00ol0003oooooooooo`0Pooooo`Co2NX:oooooomhooooo`03
o`000?oooooooooo05Sooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`17ooooo`00
GOooool3o`WZ2P_ooooo0ol9jPXbooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:<?ooool00ol0003o
ooooooooo`09ooooo`Co2NX:6_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Go
oooo0ol9jPX4ooooo`;o2NX:2oooool00ol0003oooooooooo`0Mooooo`Go2NX:oooooomkooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`18ooooo`00
F_ooool3o`WZ2P_ooooo0ol9jPXbooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:=?ooool00ol0003o
ooooooooo`05ooooo`Co2NX:7Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;o
oooo0_l9jPX4ooooo`?o2NX:3_ooool00ol0003oooooooooo`0Jooooo`;o2NX:00?oooooo`WZ2_l9
jPX0oooooomnooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0;oooool2o`0004_o
oooo001Gooooo`?o2NX:2oooool3o`WZ2S;ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXgooooo`03
o`000?oooooooooo00;ooooo1?l9jPXOooooo`03o`000?oooooooooo01Kooooo00Co0000o`WZ2_l9
jP[o2NX:1?ooool2o`WZ2Q7ooooo00?o0000ooooooooool05oooool3o`WZ2P03ooooool9jP[o2NX:
0?ooooooP?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0Boooool005Cooooo0ol9jPX;ooooo`?o2NX:<_ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ
2S[ooooo00?o0000ooooool9jPX00ol9jPXRooooo`03o`000?oooooooooo01Cooooo0ol9jPX00ol0
003oooooooooo`02ooooo`;o2NX:4oooool00ol0003oooooooooo`0Eooooo`;o2NX:0_ooool2o`WZ
2_ooooooPoooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02cooooo0_l0001>oooo
o`00DOooool3o`WZ2P_ooooo0ol9jPXbooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:??ooool2o`WZ
2P03o`000?l9jP[ooooo02Cooooo00?o0000ooooooooool04Oooool3o`WZ2PCooooo00Co0000o`WZ
2_l9jP[o2NX:5Oooool00ol0003oooooooooo`0Booooo`?o2NX:0_ooool2o`WZ2_ooooooQOooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0C_ooool0
04kooooo0ol9jPX;ooooo`?o2NX:<_ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2Scooooo1?l9jPX0
0ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00oooooo0_l9jPX5ooooo`?o2NX:00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`;o2NX:0oooool2o`WZ2_ooooooR?ooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Coooool0
04_ooooo0ol9jPX=ooooo`03o`WZ2_oooooooooo033ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXk
ooooo`Go2NX:1?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00cooooo0ol9jPX4
ooooo`?o2NX:1?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo0ol9jPX3
ooooo`;o2NX:oooooon;ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool09oooool2
o`0005;ooooo0018ooooo`?o2NX:@?ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2S_ooooo1?l9jPX9
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool3o`WZ2PCooooo0ol9jPX8
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool2o`WZ2PCooooo0_l9jP[o
ooooohgooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo05;ooooo0015ooooo`?o2NX:@?ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2S_ooooo1?l9jPX<
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool2o`WZ2PCooooo0ol9jPX<
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool3o`WZ2PCooooo0_l9jP[o
oooooi3ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Tooooo`;o0000EOooool0
04;ooooo0ol9jPY0ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:>oooool4o`WZ2Q3ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`04ooooo`?o2NX:0oooool3o`WZ2Q3ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`05ooooo`;o2NX:1Oooool2o`WZ2_ooooooToooool2
o`0005?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Eooooo`00?oooool3o`WZ
2T3ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXkooooo`Co2NX:4oooool00ol0003oooooooooo`0R
ooooo`04o`000?ooooooooooooooo`?o2NX:0oooool3o`WZ2QCooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`02ooooo`?o2NX:1Oooool2o`WZ2_ooooooUoooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo027ooooo0_l0001Hooooo`00?_ooool00ol9jP[oooooooooo`0n
ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:>oooool4o`WZ2QKooooo00?o0000ooooooooool08_oo
ool01?l0003o2NX:o`WZ2_l9jPX2ooooo`Co2NX:6?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00;o2NX:1Oooool3o`WZ2_ooooooV_ooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0F?ooool007cooooo0ol9jPX01?oooooo2NX:o`WZ
2_l9jPXkooooo`Co2NX:6_ooool00ol0003oooooooooo`0Oooooo`03o`WZ2_l0003o2NX:00;ooooo
0ol9jPXMooooo`03o`000?oooooooooo00oooooo0ol9jPX5ooooo`;o2NX:oooooonNooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool07_ooool2o`0005_ooooo001iooooo`?o2NX:00Co
ooooo`WZ2_l9jP[o2NX:>oooool4o`WZ2Qgooooo00?o0000ooooooooool07?ooool3o`WZ2P03oooo
ool0003o000000;o2NX:8Oooool00ol0003oooooooooo`0<ooooo`;o2NX:00?o0000ooooooooool0
0oooool2o`WZ2_ooooooXOooool2o`0004kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`1Kooooo`00M_ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2S[ooooo1Ol9jPXQooooo`03o`00
0?oooooooooo01Sooooo0ol9jPX2ooooo`?o2NX:00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`08ooooo`?o2NX:0_ooool01?l0003oooooooooooooool2o`WZ2_ooooooYOooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0G?ooool007?ooooo
0ol9jPX01?oooooo2NX:o`WZ2_l9jPXjooooo`Go2NX:9?ooool00ol0003oooooooooo`0Eooooo`?o
2NX:0_ooool3o`WZ2P?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`05ooooo`;o
2NX:1Oooool01?l0003oooooo`WZ2_l9jP[oooooojSooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`0Iooooo`;o0000Goooool0073ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXjoooo
o`Go2NX:9oooool00ol0003oooooooooo`0Aooooo`Co2NX:0_ooool3o`WZ2PKooooo00?o0000oooo
ooooool09?ooool01?l0003oooooooooooooool3o`WZ2POooooo0_l9jP[ooooooj_ooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05oooooo001]oooo
o`?o2NX:00Coooooo`WZ2_l9jP[o2NX:>_ooool5o`WZ2R_ooooo00?o0000ooooooooool03Oooool3
o`WZ2P;ooooo1?l9jPX9ooooo`03o`000?oooooooooo02Gooooo00?o0000o`WZ2_l9jPX02?ooool2
o`WZ2P03o`000?oooooooooo0?ooooooZoooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo01Kooooo0_l0001Rooooo`00J_ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2S[ooooo1Ol9jPX^
ooooo`03o`000?oooooooooo00[ooooo0ol9jPX2ooooo`?o2NX:3Oooool00ol0003oooooooooo`0S
ooooo`?o2NX:00?o0000ooooooooool01Oooool2o`WZ2P;ooooo00?o0000ooooooooool0oooooon/
ooooo`;o0000BOooool00ol0003oooooooooo`0Cooooo`?o0000I?ooool006Oooooo0ol9jPX01?oo
oooo2NX:o`WZ2_l9jPXjooooo`Go2NX:<_ooool00ol0003oooooooooo`05ooooo`Co2NX:0_ooool3
o`WZ2Q3ooooo00?o0000ooooooooool08Oooool2o`WZ2PCooooo00?o0000ooooooooool00_ooool2
o`WZ2PCooooo00?o0000ooooooooool0oooooon^ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool04Oooool2o`0006Oooooo001Tooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:>_ooool5
o`WZ2SGooooo00?o0000ooooooooool00_ooool3o`WZ2P?ooooo0ol9jPXCooooo`03o`000?oooooo
oooo01kooooo0ol9jPX7ooooo`04o`000?oooooo2NX:o`WZ2POooooo00?o0000ooooooooool0oooo
oon^ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03_ooool3o`0006Wooooo001Q
ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:>_ooool5o`WZ2SSooooo00?o0000ooooool9jPX00_l9
jPX3ooooo`?o2NX:5_ooool00ol0003oooooooooo`0Looooo`;o2NX:2Oooool3o`WZ2P03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooon_ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool03?ooool2o`0006cooooo001Nooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:>Ooo
ool6o`WZ2S[ooooo0_l9jPX01?l0003oooooooooooooool3o`WZ2QWooooo00?o0000ooooooooool0
6Oooool3o`WZ2PSooooo0ol9jPX2ooooo`;o00002?ooool00ol0003oooooooooo`3ooooook3ooooo
0_l00014ooooo`03o`000?oooooooooo00Wooooo0ol0001^ooooo`00Foooool3o`WZ2P04ooooool9
jP[o2NX:o`WZ2SWooooo1_l9jPXiooooo`Co2NX:0_ooool01?l0003o2NX:o`WZ2_l9jPXKooooo`03
o`000?oooooooooo01Oooooo0ol9jPX8ooooo`?o2NX:1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo/_ooool3o`0004;ooooo00?o0000ooooooooool01_ooool2o`00077o
oooo001Hooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:>Oooool6o`WZ2SWooooo0ol9jPX3ooooo`?o
2NX:00?oooooo`000?ooool07?ooool00ol0003oooooooooo`0Eooooo`;o2NX:2?ooool3o`WZ2P_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooookGooooo0ol0000oooooo`03
o`000?oooooooooo00?ooooo0ol0001cooooo`00EOooool3o`WZ2P;ooooo0_l9jPXiooooo`Ko2NX:
>Oooool3o`WZ2P?ooooo0ol9jPX4ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
4_ooool3o`WZ2POooooo0ol9jPX?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
oooooonhooooo`;o0000?Oooool01?l0003oooooooooooooool2o`0007Kooooo001Booooo`?o2NX:
?Oooool5o`WZ2S[ooooo0ol9jPX3ooooo`?o2NX:1oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo013ooooo0_l9jPX7ooooo`?o2NX:4oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo^_ooool3o`0003[ooooo1?l0001hooooo`00D?ooool2o`WZ2Sgooooo1Ol9
jPXiooooo`Co2NX:0oooool3o`WZ2P_ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0=ooooo`?o2NX:1_ooool3o`WZ2QOooooo00Go0000ooooooooooooooooo`00003ooooookoooooo
0_l0000eooooo`Co0000Noooool008cooooo1Ol9jPXiooooo`?o2NX:1?ooool3o`WZ2Pkooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`;o2NX:1Oooool4o`WZ2Q_ooooo00Co
0000oooooooooooo0000ooooooo1ooooo`?o0000;Oooool5o`0007oooooo0029ooooo`Go2NX:>Ooo
ool3o`WZ2P?ooooo1?l9jPXBooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?oo
ool3o`WZ2PCooooo0ol9jPXPooooo`03o`000?oooooo00000?ooooooa?ooool3o`0002Gooooo1Ol0
0024ooooo`00QOooool6o`WZ2SWooooo0ol9jPX3ooooo`?o2NX:5oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Kooooo0_l9jPX4ooooo`?o2NX:9?ooool2o`000?ooooooaoooool7
o`0001Wooooo1Ol00029ooooo`00P_ooool6o`WZ2SSooooo1?l9jPX3ooooo`?o2NX:6_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0ol9jPX3ooooo`?o2NX::?ooool00ol0
003oooooooooo`3oooooolcooooo3?l00008ooooo`Go0000S_ooool007oooooo1_l9jPXhooooo`?o
2NX:1?ooool3o`WZ2Qkooooo00?o0000ooooooooool05oooool01?l0003oooooooooooooool2o`WZ
2P?ooooo0ol9jPX[ooooo`03o`000?oooooooooo0?oooooof?ooool8o`0009?ooooo001looooo`Ko
2NX:>?ooool3o`WZ2PCooooo0ol9jPXQooooo`03o`000?oooooooooo01Oooooo00Co0000o`WZ2_l9
jP[o2NX:0_ooool3o`WZ2Rkooooo00?o0000ooooooooool0ooooooooooooogCooooo001iooooo`Ko
2NX:=oooool4o`WZ2P?ooooo1?l9jPXUooooo`03o`000?oooooooooo01Cooooo00Co2NX:o`000?l9
jP[ooooo1?l9jPXaooooo`03o`000?oooooooooo0?oooooooooooomdooooo`00M_ooool6o`WZ2SOo
oooo0ol9jPX4ooooo`?o2NX::_ooool00ol0003oooooooooo`0@ooooo`?o2NX:00Coooooo`000?l0
003o2NX:=?ooool00ol0003oooooooooo`3oooooooooooooMOooool007?ooooo1_l9jPXgooooo`?o
2NX:1?ooool3o`WZ2Rgooooo00?o0000ooooooooool03?ooool4o`WZ2P06ooooool9jP[o2NX:o`WZ
2_oooooo0000=Oooool00ol0003oooooooooo`3oooooooooooooMOooool006oooooo1ol9jPXgoooo
o`?o2NX:1?ooool3o`WZ2S7ooooo00?o0000ooooooooool02?ooool3o`WZ2P;ooooo0ol9jPX4oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0ooooooooooooogGooooo001/ooooo`?o
2NX:00Coooooo`WZ2_l9jP[o2NX:=_ooool4o`WZ2PCooooo0ol9jPXeooooo`03o`000?oooooooooo
00Cooooo0ol9jPX2ooooo`?o2NX:1oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
0?oooooooooooomeooooo`00JOooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2SKooooo0ol9jPX5oooo
o`?o2NX:>?ooool00ol0003oooooooooo`04o`WZ2P;ooooo0ol9jPX:ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0ooooooooooooogGooooo001Vooooo`?o2NX:00Coooooo`WZ2_l9
jP[o2NX:=_ooool3o`WZ2PCooooo1?l9jPXkooooo`03o`WZ2_l0003o2NX:00?ooooo0ol9jPX=oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0ooooooooooooogGooooo001Sooooo`?o
2NX:00Coooooo`WZ2_l9jP[o2NX:=_ooool3o`WZ2PCooooo0ol9jPXkooooo`Co2NX:00?oooooo`00
0?l9jPX00ol9jPX@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0oooooooooooo
ogKooooo001Pooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:=Oooool4o`WZ2PCooooo0ol9jPXkoooo
o`?o2NX:0oooool3o`WZ2P03o`000?oooooooooo017ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`3oooooooooooooM_ooool005gooooo0ol9jPX2ooooo`;o2NX:=Oooool3o`WZ2PGo
oooo0ol9jPXkooooo`?o2NX:0oooool3o`WZ2PCooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo0?oooooooooooomfooooo`00F_ooool3o`WZ2SWooooo
0ol9jPX5ooooo`?o2NX:>_ooool4o`WZ2P?ooooo0ol9jPX7ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`3oooooooooooooM_ooool005Sooooo0_l9
jPXhooooo`Co2NX:1Oooool3o`WZ2S[ooooo0ol9jPX4ooooo`?o2NX:2oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0ooooooooooooogKooooo002?
ooooo`?o2NX:1Oooool4o`WZ2SWooooo1?l9jPX4ooooo`?o2NX:3_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0ooooooooooooogKooooo002<oooo
o`?o2NX:1Oooool3o`WZ2S[ooooo0ol9jPX4ooooo`Co2NX:4_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0ooooooooooooogKooooo0029ooooo`?o
2NX:1Oooool3o`WZ2SWooooo1?l9jPX4ooooo`?o2NX:5oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0ooooooooooooogOooooo0025ooooo`Co2NX:
1Oooool3o`WZ2SWooooo0ol9jPX5ooooo`?o2NX:6_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool0ooooooooooooogOooooo0022ooooo`?o2NX:1_oo
ool3o`WZ2SWooooo0ol9jPX5ooooo`?o2NX:7_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0ooooooooooooogOooooo001oooooo`?o2NX:1_ooool3
o`WZ2SSooooo1?l9jPX5ooooo`?o2NX:8_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0ooooooooooooogOooooo001looooo`?o2NX:1Oooool4o`WZ
2SSooooo0ol9jPX6ooooo`?o2NX:9_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0ooooooooooooogSooooo001hooooo`Co2NX:1Oooool3o`WZ2SSo
oooo1?l9jPX6ooooo`?o2NX::_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0ooooooooooooogSooooo001eooooo`?o2NX:1_ooool3o`WZ2SSooooo
0ol9jPX6ooooo`Co2NX:;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0ooooooooooooogSooooo001booooo`?o2NX:1_ooool3o`WZ2SOooooo1?l9
jPX6ooooo`?o2NX:<oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0ooooooooooooogWooooo001_ooooo`?o2NX:1_ooool3o`WZ2SOooooo0ol9jPX7
ooooo`?o2NX:=oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0ooooooooooooogWooooo001[ooooo`Co2NX:1_ooool3o`WZ2SOooooo0ol9jPX7oooo
o`?o2NX:>_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0ooooooooooooog[ooooo001Xooooo`?o2NX:2?ooool2o`WZ2SKooooo1?l9jPX7ooooo`?o
2NX:?_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0ooooooooooooog[ooooo001Uooooo`?o2NX:@?ooool3o`WZ2PSooooo0ol9jPY2ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3ooooooooooooo
N_ooool0067ooooo1?l9jPXoooooo`Co2NX:2?ooool3o`WZ2TKooooo00Go0000oooooooooooooooo
o`00000aooooo`03o`000?oooooooooo0?oooooooooooomkooooo`00G_ooool3o`WZ2T3ooooo0ol9
jPX8ooooo`Co2NX:B_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo0?oooooo
oooooomkooooo`00Foooool3o`WZ2T3ooooo0ol9jPX8ooooo`?o2NX:Coooool00ol0003oooooo`00
000`ooooo`03o`000?oooooooooo0?oooooooooooomlooooo`00F?ooool3o`WZ2Soooooo1?l9jPX8
ooooo`?o2NX:Doooool2o`00033ooooo00?o0000ooooooooool0ooooooooooooogcooooo001Foooo
o`;o2NX:?oooool3o`WZ2PWooooo0ol9jPYGooooo`;o0000;oooool00ol0003oooooooooo`3ooooo
ooooooooO?ooool009?ooooo1?l9jPX9ooooo`?o2NX:G?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo0?oooooooooooommooooo`00T?ooool3o`WZ2P[ooooo0ol9jPYPooooo`;o0000
:oooool00ol0003oooooooooo`3oooooooooooooOOooool008cooooo1?l9jPX9ooooo`Co2NX:IOoo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooooooooomnooooo`00ROooool3
o`WZ2P[ooooo0ol9jPYZooooo`;o00009_ooool00ol0003oooooooooo`3oooooooooooooOoooool0
08Kooooo0ol9jPX:ooooo`?o2NX:Koooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
0?oooooooooooon0ooooo`00P_ooool4o`WZ2P[ooooo0ol9jPYcooooo`;o00008Oooool00ol0003o
ooooooooo`3oooooooooooooPOooool007oooooo0ol9jPX;ooooo`?o2NX:N?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo0?oooooooooooon2ooooo`00Noooool4o`WZ2P_ooooo0ol9
jPYlooooo`;o00007?ooool00ol0003oooooooooo`3oooooooooooooPoooool007Sooooo0ol9jPX<
ooooo`?o2NX:POooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?oooooooooooon4
ooooo`00M?ooool4o`WZ2Pgooooo0_l9jPZ5ooooo`?o00005_ooool00ol0003oooooooooo`3ooooo
ooooooooQOooool0077ooooo0ol9jPZKooooo`?o00004?ooool3o`000?oooooooooooon8ooooo`00
K_ooool3o`WZ2Z7ooooo0ol00009ooooo`Co0000oooooooooooooh_ooooo001Zooooo`Co2NX:Yooo
ool3o`0000?ooooo0ol0003oooooooooooooSoooool006Oooooo0ol9jPZ^ooooo`?o0000oooooooo
oooooi;ooooo001Sooooo`Co2NX:ooooooooooooooooooooAoooool0063ooooo0ol9jP[ooooooooo
oooooooooom;ooooo`00GOooool3o`WZ2_ooooooooooooooooooodkooooo001Iooooo`Co2NX:oooo
ooooooooooooooooDOooool005Kooooo0ol9jP[ooooooooooooooooooomEooooo`00E?ooool2o`WZ
2_oooooooooooooooooooeSooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo
[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooo
oooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooo
oooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^oooo
o`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooo
oon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooo
oooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003o
oooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojko
oooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooooooo
ooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooo
ooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool0
0?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo
[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooo
oooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooo
oooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^oooo
o`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooo
oon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooo
oooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003o
oooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojko
oooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooooooo
ooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooo
ooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool0
0?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo
[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooo
oooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooo
oooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^oooo
o`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooo
oon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooo
oooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003o
oooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojko
oooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooooooo
ooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooo
ooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool0
0?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo
[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooo
oooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooo
oooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^oooo
o`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooo
oon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooo
oooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003o
oooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojko
oooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooooooooooo
ooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?oooooo
ooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo[_ooool0
0?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooooooooooo
[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooooooooooo
oooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^ooooo`00oooo
oooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooooon^oooo
o`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooooooooooo
oon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo003ooooooooo
oooooooooon^ooooo`00oooooooooooooooooooo[_ooool00?ooooooooooooooooooojkooooo0000
\
\>"],
  ImageRangeCache->{{{0, 938.188}, {590.688, 0}} -> {0.0172746, 0.167571, \
0.0010478, 0.0010478}},
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[thinopticalsystemreflected2,MatrixForm->True,DecomposeABCD->\
True,NumericalResults->True,SymbolicRefractiveModels->{Air->1}]\
\>", "Input",
  CellLabel->"In[37]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-1\), \(-250\)},
                    {"0", \(-1\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(-125\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(1\/100\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "125"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(1\/150\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Row, TableAlignments -> 
          Center]]]], "Output",
  CellLabel->"Out[37]//TableForm=",
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[thinopticalsystemreflected2,MatrixForm->True,DecomposeABCD->\
True,NumericalResults->False,SymbolicRefractiveModels->{Air->1}]\
\>", "Input",
  CellLabel->"In[38]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-1\), \(\(-350\) + 2\ d1\)},
                    {"0", \(-1\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(\(-175\) + d1\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(1\/f1\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(175 - d1\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(1\/f2\)\), "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Row, TableAlignments -> 
          Center]]]], "Output",
  CellLabel->"Out[38]//TableForm=",
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianTrace", "Subsubsection",
  CellTags->{"AOG0.", "4.3.2", "AOG4.", "AOG4.3", "AOG4.3.2"}],

Cell[CellGroupData[{

Cell["GaussianTrace[thinopticalsystemreflected2]", "Input",
  CellLabel->"In[39]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.2"}],

Cell[BoxData[
    \({{BeamSpotSize \[Rule] {20.`, 15.`}, 
        BeamDivergence \[Rule] {0.01`, 0.05`}, 
        ComplexBeamParameter \[Rule] {\(\(3999.994267820059`\)\(\
\[InvisibleSpace]\)\) + 
              6.771809703999253`\ \[ImaginaryI], \(\(599.9999388567878`\)\(\
\[InvisibleSpace]\)\) + 0.27087238815997`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.033859048519996264`, 0.006771809703999252`}, 
        WaistDistance \[Rule] {\(-3999.9942678200596`\), \
\(-599.9999388567878`\)}, 
        BeamScaleLength \[Rule] {6.771809703999252`, 0.27087238815997006`}, 
        BeamCurvature \[Rule] {\(-4000.005732188155`\), \(-600.0000611432181`\
\)}, ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {0, 0, 0}, OpticalLength \[Rule] 0, 
        Intensity \[Rule] 100, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {20.24999964616168`, 
            16.2499998824169`}, 
        BeamDivergence \[Rule] {\(-0.39500000725592294`\), \
\(-0.16666667074288075`\)}, 
        ComplexBeamParameter \[Rule] {\(-102.53164180272508`\) + 
              0.004340207950784013`\ \[ImaginaryI], \(-194.99999229595568`\) \
+ 0.024378513741932804`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.0008571910860259498`, 0.0020315428615137543`}, 
        WaistDistance \[Rule] {102.53164180272506`, 194.99999229595568`}, 
        BeamScaleLength \[Rule] {0.004340207950784013`, 
            0.024378513741932808`}, 
        BeamCurvature \[Rule] {102.53164198644791`, 194.9999953437093`}, 
        ABCDMatrix \[Rule] {{{1, 50.`}, {\(-0.01`\), 0.5`}}, {{1, 
                50.`}, {\(-0.006666666666666667`\), 0.6666666666666666`}}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {50.`, 0, 0}, 
        OpticalLength \[Rule] 50.01347257285401`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {4.437500908267855`, 
            5.833333187754255`}, 
        BeamDivergence \[Rule] {0.39500000725592394`, \(-0.16666667074288072`\
\)}, ComplexBeamParameter \[Rule] \
{\(\(22.46835819727492`\)\(\[InvisibleSpace]\)\) + 
              0.00434020795078399`\ \[ImaginaryI], \(-69.99999229595566`\) + 
              0.024378513741932808`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.0008571910860259477`, 0.0020315428615137548`}, 
        WaistDistance \[Rule] {\(-22.46835819727492`\), 69.99999229595566`}, 
        BeamScaleLength \[Rule] {0.004340207950783991`, 
            0.024378513741932818`}, 
        BeamCurvature \[Rule] {\(-22.468359035671963`\), 70.00000078612706`}, 
        ABCDMatrix \[Rule] {{{0.24999999999999994`, \
\(-112.49999999999997`\)}, {0.010000000000000002`, \(-0.5`\)}}, \
{{0.16666666666666663`, 133.33333333333331`}, {\(-0.006666666666666667`\), 
                0.6666666666666667`}}}, 
        ABCDRotationMatrix \[Rule] {{0, 1, 0}, {\(-1.`\), 0, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {175.`, 0, 0}, 
        OpticalLength \[Rule] 175.04715400498904`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {14.312501032543311`, 
            1.6666673035750026`}, 
        BeamDivergence \[Rule] {0.39500000725592443`, \(-0.16666667074288072`\
\)}, ComplexBeamParameter \[Rule] \
{\(\(72.46835819727492`\)\(\[InvisibleSpace]\)\) + 
              0.00434020795078398`\ \[ImaginaryI], \(-19.999992295955657`\) + 
              0.024378513741932808`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.0008571910860259467`, 0.0020315428615137548`}, 
        WaistDistance \[Rule] {\(-72.46835819727492`\), 19.999992295955654`}, 
        BeamScaleLength \[Rule] {0.0043402079507839815`, 
            0.024378513741932818`}, 
        BeamCurvature \[Rule] {\(-72.46835845721465`\), 20.000022011563715`}, 
        ABCDMatrix \[Rule] {{{0.75`, \(-137.49999999999997`\)}, \
{0.010000000000000002`, \(-0.5`\)}}, {{\(-0.1666666666666668`\), 
                166.66666666666666`}, {\(-0.006666666666666667`\), 
                0.6666666666666667`}}}, 
        ABCDRotationMatrix \[Rule] {{0, 1, 0}, {\(-1.`\), 0, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {175.`, 50.`, 0}, 
        OpticalLength \[Rule] 225.06062657784307`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 0.532`}}\)], "Output",
  CellLabel->"Out[39]=",
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.2"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianPlot", "Subsubsection",
  CellTags->{"AOG0.", "4.3.3", "AOG4.", "AOG4.3", "AOG4.3.3"}],

Cell[CellGroupData[{

Cell["GaussianPlot[thinopticalsystemreflected2]", "Input",
  CellLabel->"In[40]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0042328 0 0.0264244 [
[.23545 -0.0125 -6 -9 ]
[.23545 -0.0125 6 0 ]
[.44709 -0.0125 -9 -9 ]
[.44709 -0.0125 9 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.87037 -0.0125 -9 -9 ]
[.87037 -0.0125 9 0 ]
[.01131 .13212 -6 -4.5 ]
[.01131 .13212 0 4.5 ]
[.01131 .26424 -12 -4.5 ]
[.01131 .26424 0 4.5 ]
[.01131 .39637 -12 -4.5 ]
[.01131 .39637 0 4.5 ]
[.01131 .52849 -12 -4.5 ]
[.01131 .52849 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23545 0 m
.23545 .00625 L
s
[(50)] .23545 -0.0125 0 1 Mshowa
.44709 0 m
.44709 .00625 L
s
[(100)] .44709 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(150)] .65873 -0.0125 0 1 Mshowa
.87037 0 m
.87037 .00625 L
s
[(200)] .87037 -0.0125 0 1 Mshowa
.125 Mabswid
.06614 0 m
.06614 .00375 L
s
.10847 0 m
.10847 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.19312 0 m
.19312 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.32011 0 m
.32011 .00375 L
s
.36243 0 m
.36243 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.48942 0 m
.48942 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.57407 0 m
.57407 .00375 L
s
.6164 0 m
.6164 .00375 L
s
.70106 0 m
.70106 .00375 L
s
.74339 0 m
.74339 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.82804 0 m
.82804 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.95503 0 m
.95503 .00375 L
s
.99735 0 m
.99735 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .13212 m
.03006 .13212 L
s
[(5)] .01131 .13212 1 0 Mshowa
.02381 .26424 m
.03006 .26424 L
s
[(10)] .01131 .26424 1 0 Mshowa
.02381 .39637 m
.03006 .39637 L
s
[(15)] .01131 .39637 1 0 Mshowa
.02381 .52849 m
.03006 .52849 L
s
[(20)] .01131 .52849 1 0 Mshowa
.125 Mabswid
.02381 .02642 m
.02756 .02642 L
s
.02381 .05285 m
.02756 .05285 L
s
.02381 .07927 m
.02756 .07927 L
s
.02381 .1057 m
.02756 .1057 L
s
.02381 .15855 m
.02756 .15855 L
s
.02381 .18497 m
.02756 .18497 L
s
.02381 .2114 m
.02756 .2114 L
s
.02381 .23782 m
.02756 .23782 L
s
.02381 .29067 m
.02756 .29067 L
s
.02381 .31709 m
.02756 .31709 L
s
.02381 .34352 m
.02756 .34352 L
s
.02381 .36994 m
.02756 .36994 L
s
.02381 .42279 m
.02756 .42279 L
s
.02381 .44922 m
.02756 .44922 L
s
.02381 .47564 m
.02756 .47564 L
s
.02381 .50206 m
.02756 .50206 L
s
.02381 .55491 m
.02756 .55491 L
s
.02381 .58134 m
.02756 .58134 L
s
.02381 .60776 m
.02756 .60776 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .52849 m
.09004 .53056 L
.16227 .53281 L
.19739 .53391 L
.21452 .53444 L
.22263 .53469 L
.23011 .53493 L
.23206 .53499 L
.23388 .53505 L
.23578 .53468 L
.23788 .5321 L
.24631 .5217 L
.26163 .50281 L
.29535 .46124 L
.36182 .37929 L
.43249 .29216 L
.50056 .20823 L
.56603 .1275 L
.60258 .08245 L
.63571 .0416 L
.6523 .02114 L
.66103 .01038 L
.66333 .00754 L
.6658 .0045 L
.66699 .00302 L
.66813 .00163 L
.67025 .00099 L
.67226 .00347 L
.67412 .00576 L
.67833 .01095 L
.6872 .02189 L
.70279 .04111 L
.7701 .1241 L
.83482 .20389 L
.90374 .28887 L
.97006 .37064 L
.97619 .3782 L
s
0 0 0 r
gsave
.23545 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76455 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 0 m
.23545 .56185 L
s
.76455 0 m
.76455 .56185 L
s
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00C_ooool3o`0000Cooooo0_l0000Xooooo`?o00001?ooool2o`0000Cooooo0_l0000Toooo
o`?o00000oooool3o`0000Cooooo0_l0000Sooooo`Go00000oooool2o`0000Cooooo0_l0000/oooo
o`00COooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
9?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000[ooooo`00DOooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0002_ooooo001Aooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0Yooooo`00COooool4o`0000?ooooo00Co
0000oooooooooooo0000:?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009?ooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000
oooooooooooo00008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000[ooooo`00COooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0002Oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00008oooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002_ooooo001=ooooo`Go00000oooool2o`0002Wooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l0000Uooooo`04o`000?ooooooooooooooo`Go00000oooool2
o`0002Cooooo0ol00004ooooo`;o00001?ooool2o`0002cooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo000Joooooj;o00000_l9jPY@o`0001;ooooo000Poooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`05o`000?l9jP[o2NX:ooooool9jPX01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`008?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo06Gooooo00Go2NX:ooooooooooooooooo`WZ2P0D
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Uooooo`05o`WZ2_ooooooooooooooool9jPX05?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0I?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
017ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo06?ooooo00?o2NX:ooooooooool01Oooool00ol9jP[o
ooooooooo`0@ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo
0_l0000aooooo`03o`000?oooooooooo06?ooooo00?o2NX:ooooooooool01Oooool00ol9jP[ooooo
ooooo`0@ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`1Rooooo`03o`WZ2_oooooooooo00Oooooo00?o
2NX:ooooooooool03oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000P
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0HOooool00ol9jP[oooooooooo`09
ooooo`03o`WZ2_oooooooooo00kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0F
ooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo063ooooo00?o2NX:oooo
ooooool02oooool00ol9jP[oooooooooo`0=ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Oooooo`03
o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool03?ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
Goooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00cooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Fooooo`008?ooool2o`00037ooooo00?o0000ooooooooool0G_oo
ool00ol9jP[oooooooooo`0?ooooo`03o`WZ2_oooooooooo00_ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo05gooooo00?o2NX:ooooooooool04Oooool00ol9jP[oooooooooo`0:ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`1Looooo`03o`WZ2_oooooooooo01?ooooo00?o2NX:ooooooooool02Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0Foooool00ol9jP[oooooooooo`0Eooooo`03o`WZ2_oooooooooo00So
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo05_ooooo00?o2NX:ooooooooool05Oooool00ol9jP[ooooo
ooooo`08ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`1Jooooo`03o`WZ2_oooooooooo01Oooooo00?o
2NX:ooooooooool01oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000P
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0FOooool00ol9jP[oooooooooo`0I
ooooo`03o`WZ2_oooooooooo00Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0F
ooooo`008?ooool2o`00037ooooo00?o0000ooooooooool0F?ooool00ol9jP[oooooooooo`0Koooo
o`03o`WZ2_oooooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Foooo
o`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05Oooooo00?o2NX:oooooooo
ool07Oooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Gooooo`03o`WZ
2_oooooooooo01gooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0E_oo
ool00ol9jP[oooooooooo`0Oooooo`03o`WZ2_oooooooooo00?ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo05Gooooo00?o2NX:ooooooooool08Oooool00ol9jP[oooooooooo`02ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`1Dooooo`03o`WZ2_oooooooooo02?ooooo00Go2NX:ooooooooooooooooo`00000b
ooooo`03o`000?oooooooooo01Kooooo000Pooooo`;o0000<Oooool00ol0003oooooooooo`1Coooo
o`03o`WZ2_oooooooooo02Gooooo00Co2NX:oooooooooooo0000<_ooool00ol0003oooooooooo`0F
ooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05;ooooo00?o2NX:oooo
ooooool09_ooool01?l9jP[oooooooooool0000booooo`03o`000?oooooooooo01Kooooo000Poooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0D_ooool00ol9jP[oooooooooo`0Woooo
o`03o`WZ2_oooooo000003;ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`1Aooooo`03o`WZ2_oooooooooo02Wooooo00?o2NX:o`000?oo
ool0<Oooool00ol0003oooooooooo`0Fooooo`006?ooool3o`0000Gooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`1@ooooo`03o`WZ2_oooooooooo02_ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Fooooo`005oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1?ooooo`03o`WZ2_oooooooooo02cooooo
00?o0000o`WZ2_ooool0<?ooool00ol0003oooooooooo`0Fooooo`006oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0C_ooool00ol9jP[ooooooooo
o`0]ooooo`03o`000?l9jP[ooooo033ooooo00?o0000ooooooooool05_ooool001_ooooo00?o0000
ooooooooool00_ooool3o`00033ooooo00?o0000ooooooooool0C_ooool00ol9jP[oooooooooo`0]
ooooo`03o`000?oooooo2NX:033ooooo00?o0000ooooooooool05_ooool001Oooooo1?l00005oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0COooool00ol9jP[oooooooooo`0^oooo
o`04o`000?ooooooooooo`WZ2Roooooo00?o0000ooooooooool05_ooool001Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04cooooo00?o2NX:oooo
ooooool0;oooool01Ol0003ooooooooooooooooo2NX:02kooooo00?o0000ooooooooool05_ooool0
01Oooooo1Ol00004ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Boooool00ol9
jP[oooooooooo`0`ooooo`03o`000?oooooooooo00;ooooo00?o2NX:ooooooooool0:oooool00ol0
003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04[o
oooo00?o2NX:ooooooooool0<Oooool00ol0003oooooooooo`03ooooo`03o`WZ2_oooooooooo02[o
oooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`19ooooo`03o`WZ2_oooooooooo03;ooooo00?o0000ooooooooool00oooool00ol9jP[ooooo
ooooo`0Zooooo`03o`000?oooooooooo01Kooooo000Pooooo`;o0000<Oooool00ol0003ooooooooo
o`19ooooo`03o`WZ2_oooooooooo03;ooooo00?o0000ooooooooool01?ooool00ol9jP[ooooooooo
o`0Yooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0B?ooool00ol9jP[oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o2NX:
ooooooooool0:?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo04Oooooo00?o2NX:ooooooooool0=?ooool00ol0003oooooooooo`06oooo
o`03o`WZ2_oooooooooo02Oooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`16ooooo`03o`WZ2_oooooooooo03Gooooo00?o0000oooooooo
ool01oooool00ol9jP[oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0AOooool00ol9jP[oooooooooo`0fooooo`03o`00
0?oooooooooo00Sooooo00?o2NX:ooooooooool09Oooool00ol0003oooooooooo`0Fooooo`008?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Cooooo00?o2NX:ooooooooool0=ooo
ool00ol0003oooooooooo`09ooooo`03o`WZ2_oooooooooo02Cooooo00?o0000ooooooooool05_oo
ool0023ooooo0_l0000aooooo`03o`000?oooooooooo04?ooooo00?o2NX:ooooooooool0>?ooool0
0ol0003oooooooooo`09ooooo`03o`WZ2_oooooooooo02Cooooo00?o0000ooooooooool05_ooool0
023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`13ooooo`03o`WZ2_oooooooooo
03Sooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0Sooooo`03o`000?oooooooooo
01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0@_ooool00ol9jP[o
ooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o2NX:ooooooooool08_ooool00ol0003o
ooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo047ooooo
00?o2NX:ooooooooool0>_ooool00ol0003oooooooooo`0<ooooo`03o`WZ2_oooooooooo027ooooo
00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`10ooooo`03o`WZ2_oooooooooo03_ooooo00?o0000ooooooooool03Oooool00ol9jP[ooooooooo
o`0Pooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0?oooool00ol9jP[oooooooooo`0looooo`03o`000?oooooooooo00kooooo00?o2NX:
ooooooooool07oooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo03kooooo00?o2NX:ooooooooool0?Oooool00ol0003oooooooooo`0>oooo
o`03o`WZ2_oooooooooo01oooooo00?o0000ooooooooool05_ooool0023ooooo0_l0000aooooo`03
o`000?oooooooooo03kooooo00?o2NX:ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`03
o`WZ2_oooooooooo01kooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0mooooo`03o`WZ2_oooooooooo03kooooo00?o0000ooooooooool0
4?ooool00ol9jP[oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0??ooool00ol9jP[oooooooooo`0oooooo`03o`000?oo
oooooooo017ooooo00?o2NX:ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`008?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03_ooooo00?o2NX:ooooooooool0@?ooool0
0ol0003oooooooooo`0Booooo`03o`WZ2_oooooooooo01_ooooo00?o0000ooooooooool05_ooool0
023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0jooooo`03o`WZ2_oooooooooo
047ooooo00?o0000ooooooooool04_ooool00ol9jP[oooooooooo`0Kooooo`03o`000?oooooooooo
01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0>Oooool00ol9jP[o
ooooooooo`12ooooo`03o`000?oooooooooo01?ooooo00?o2NX:ooooooooool06_ooool00ol0003o
ooooooooo`0Fooooo`008?ooool2o`00037ooooo00?o0000ooooooooool0>?ooool00ol9jP[ooooo
ooooo`13ooooo`03o`000?oooooooooo01Cooooo00?o2NX:ooooooooool06Oooool00ol0003ooooo
ooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03Sooooo00?o
2NX:ooooooooool0@oooool00ol0003oooooooooo`0Eooooo`03o`WZ2_oooooooooo01Sooooo00?o
0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0g
ooooo`03o`WZ2_oooooooooo04Cooooo00?o0000ooooooooool05_ooool00ol9jP[oooooooooo`0G
ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0=_ooool00ol9jP[oooooooooo`15ooooo`03o`000?oooooooooo01Oooooo00?o2NX:oooo
ooooool05_ooool00ol0003oooooooooo`0Fooooo`004_ooool3o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0=Oooool00ol9jP[oooooooooo`16ooooo`03
o`000?oooooooooo01Oooooo00?o2NX:ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`00
4oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0dooooo`03o`WZ2_oooooooooo04Oooooo00?o0000oooooooo
ool06?ooool00ol9jP[oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo000Cooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo03?ooooo00?o2NX:ooooooooool0B?ooool00ol0003oooooooooo`0Iooooo`03
o`WZ2_oooooooooo01Cooooo00?o0000ooooooooool05_ooool001?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00004ooooo`?o0000<?ooool00ol0003oooooooooo`0cooooo`03
o`WZ2_oooooooooo04Sooooo00?o0000ooooooooool06_ooool00ol9jP[oooooooooo`0Cooooo`03
o`000?oooooooooo01Kooooo000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03;ooooo00?o2NX:oooooooo
ool0BOooool00ol0003oooooooooo`0Kooooo`03o`WZ2_oooooooooo01;ooooo00?o0000oooooooo
ool05_ooool001;ooooo0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0aooooo`03o`WZ2_oooooooooo04[ooooo00?o0000oooooooo
ool06oooool00ol9jP[oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo000Cooooo`03o`00
0?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
<?ooool00ol9jP[oooooooooo`1;ooooo`03o`000?oooooooooo01cooooo00?o2NX:ooooooooool0
4Oooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo02oooooo00?o2NX:ooooooooool0C?ooool00ol0003oooooooooo`0Mooooo`03o`WZ2_oo
oooooooo013ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0^ooooo`03o`WZ2_oooooooooo04gooooo00?o0000ooooooooool07_ooool0
0ol9jP[oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo000Pooooo`;o0000<Oooool00ol0
003oooooooooo`0]ooooo`03o`WZ2_oooooooooo04kooooo00?o0000ooooooooool07oooool00ol9
jP[oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0;Oooool00ol9jP[oooooooooo`1>ooooo`03o`000?oooooooooo01oo
oooo00?o2NX:ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02cooooo00?o2NX:ooooooooool0Coooool00ol0003ooooo
ooooo`0Pooooo`03o`WZ2_oooooooooo00gooooo00?o0000ooooooooool05_ooool0023ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0[ooooo`03o`WZ2_oooooooooo053ooooo00?o
0000ooooooooool08Oooool00ol9jP[oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo000P
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0:_ooool00ol9jP[oooooooooo`1A
ooooo`03o`000?oooooooooo02;ooooo00?o2NX:ooooooooool02oooool00ol0003oooooooooo`0F
ooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02[ooooo00?o2NX:oooo
ooooool0DOooool00ol0003oooooooooo`0Sooooo`03o`WZ2_oooooooooo00[ooooo00?o0000oooo
ooooool05_ooool0023ooooo0_l0000aooooo`03o`000?oooooooooo02Wooooo00?o2NX:oooooooo
ool0D_ooool00ol0003oooooooooo`0Tooooo`03o`WZ2_oooooooooo00Wooooo00?o0000oooooooo
ool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Xooooo`03o`WZ
2_oooooooooo05?ooooo00?o0000ooooooooool09?ooool00ol9jP[oooooooooo`09ooooo`03o`00
0?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool09ooo
ool00ol9jP[oooooooooo`1Dooooo`03o`000?oooooooooo02Gooooo00?o2NX:ooooooooool02?oo
ool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo02Kooooo00?o2NX:ooooooooool0EOooool00ol0003oooooooooo`0Vooooo`03o`WZ2_oooooo
oooo00Oooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0Vooooo`03o`WZ2_oooooooooo05Gooooo00?o0000ooooooooool09oooool00ol9
jP[oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool09Oooool00ol9jP[oooooooooo`1Fooooo`03o`000?oooooooooo02So
oooo00?o2NX:ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02Cooooo00?o2NX:ooooooooool0Eoooool00ol0003ooooo
ooooo`0Yooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool05_ooool0023ooooo0_l0
000aooooo`03o`000?oooooooooo02?ooooo00?o2NX:ooooooooool0F?ooool00ol0003ooooooooo
o`0Zooooo`03o`WZ2_oooooooooo00?ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Sooooo`03o`WZ2_oooooooooo05Sooooo00?o0000
ooooooooool0:_ooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo000Poooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool08_ooool00ol9jP[oooooooooo`1Ioooo
o`03o`000?oooooooooo02_ooooo00?o2NX:ooooooooool00_ooool00ol0003oooooooooo`0Foooo
o`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo027ooooo00?o2NX:oooooooo
ool0F_ooool00ol0003oooooooooo`0/ooooo`05o`WZ2_ooooooooooooooool000006?ooool0023o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Pooooo`03o`WZ2_oooooooooo05_o
oooo00?o0000ooooooooool0;Oooool01?l9jP[oooooooooool0000Hooooo`008?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo01oooooo00?o2NX:ooooooooool0G?ooool00ol0003o
ooooooooo`0^ooooo`03o`WZ2_oooooo000001Sooooo000Pooooo`;o0000<Oooool00ol0003ooooo
ooooo`0Oooooo`03o`WZ2_oooooooooo05cooooo00?o0000ooooooooool0;oooool00ol9jP[o0000
ooooo`0Gooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01kooooo00?o
2NX:ooooooooool0GOooool00ol0003oooooooooo`0_ooooo`03o`WZ2_l0003ooooo01Oooooo000P
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool07Oooool00ol9jP[oooooooooo`1N
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Looooo`03o`WZ2_oooooooooo05oooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Fooooo`004_ooool3o`0000?ooooo0ol00005ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool07?ooool00ol9jP[oooooooooo`1Oooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool001?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Kooooo`03o`WZ2_oooooooooo063ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Fooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Jooooo`03o`WZ2_oooooooooo067ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`004oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo0ol0000`ooooo`03o`000?oooooooooo01Wooooo00?o
2NX:ooooooooool0H_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000C
ooooo`04o`000?ooooooooooooooo`Co00001Oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo01Sooooo00?o2NX:ooooooooool0Hoooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo01Kooooo000Booooo`;o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool05oooool00ol9jP[oooooooooo`1Tooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool05_ooool001?ooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05oooool00ol9jP[oooooooooo`1T
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Fooooo`03o`WZ2_oooooooooo06Gooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01Gooooo00?o2NX:ooooooooool0I_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01Kooooo000Pooooo`;o0000<Oooool00ol0003oooooooooo`0Dooooo`03o`WZ
2_oooooooooo06Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o2NX:ooooooooool0J?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool04_ooool00ol9jP[oooooooooo`1Yooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0Aooooo`03o`WZ2_oooooooooo06[ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo017o
oooo00?o2NX:ooooooooool0J_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Ko
oooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool00ol9jP[ooooo
ooooo`1[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0?ooooo`03o`WZ2_oooooooooo06cooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool2o`00037ooooo00?o0000
ooooooooool03_ooool00ol9jP[oooooooooo`1]ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0=oooo
o`03o`WZ2_oooooooooo06kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Foooo
o`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00cooooo00?o2NX:oooooooo
ool0Koooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool03?ooool00ol9jP[oooooooooo`1_ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0;ooooo`03o`WZ2_oooooooooo073ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00[ooooo00?o2NX:ooooooooool0LOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo01Kooooo000Pooooo`;o0000<Oooool00ol0003oooooooooo`09ooooo`03o`WZ2_oooooooooo
07;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00Wooooo00?o2NX:ooooooooool0L_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02?ooool00ol9jP[oooooooooo`1cooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`07ooooo`03o`WZ2_oooooooooo07Cooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Fooooo`008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o2NX:
ooooooooool0M?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Poooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool01_ooool00ol9jP[oooooooooo`1eoooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo0_l0000aooooo`03
o`000?oooooooooo00Gooooo00?o2NX:ooooooooool0M_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
1?ooool00ol9jP[oooooooooo`1gooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
5_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`03ooooo`03o`WZ2_oo
oooooooo07Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`008?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00;ooooo00?o2NX:ooooooooool0NOooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Aooooo`Go00000oooool2o`00
00Gooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo2NX:07cooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`004_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<?ooool01?l0003ooooooooo
ool9jPYmooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool001?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo033ooooo
00Co0000oooooooooooo2NX:OOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Ko
oooo000Dooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02oooooa[o
2NX:6Oooool00ol0003oooooo`WZ2P1nooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool05_ooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool05ooooolIo`WZ2P03o`000?l9jP[ooooo07kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Fooooo`004Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`004_ooool3o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Ko
oooo000Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Pooooo`;o0000<Oooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool05_ooool0023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool0023ooooo00?o0000oooooooo
ool0oOooool0023ooooo00?o0000ooooooooool0;Oooool5o`0007cooooo0_l000001?oooooo0000
o`000?l0000^ooooo`?o00006?ooool0023ooooo00?o0000ooooooooool0;_ooool01?l0003ooooo
ooooool0001looooo`05o`000?ooooooooooooooool00000;oooool01?l0003oooooooooool0000G
ooooo`008?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo07gooooo00Go0000oooo
ooooooooooooo`00000booooo`03o`000?oooooooooo01Gooooo000Pooooo`;o0000;oooool00ol0
003oooooooooo`1mooooo`05o`000?ooooooooooooooool00000<?ooool2o`0001Sooooo000Poooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0OOooool01Ol0003oooooo`000?oooooo
000002oooooo00?o0000ooooooooool06?ooool0023ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1mooooo`;o000000?oooooo`000?l00000;oooool01?l0003oooooooooool0000G
ooooo`008?ooool00ol0003oooooooooo`0]ooooo`?o0000O_ooool01?l0003oooooooooooooool2
o`0002oooooo0ol0000Gooooo`008?ooool00ol0003oooooooooo`3mooooo`008?ooool00ol0003o
ooooooooo`3mooooo`008?ooool2o`000?kooooo000Pooooo`03o`000?oooooooooo0?gooooo000P
ooooo`03o`000?oooooooooo0?gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo002>ooooo`?o0000Soooool008oooooo00?o0000ooooooooool0S_ooool006[o
oooo1?l00003ooooo`?o00000oooool4o`000006ooooool0003oooooo`000?oooooo00002?ooool3
o`0000?ooooo0ol00003ooooo`?o00001?ooool2o`0000Wooooo0ol00002ooooo`Go000000?ooooo
o`000?l000000ol00002ooooo`?o0000I?ooool006_ooooo00Ko0000oooooooooooo0000ooooool0
0005ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000008ooooo`04
o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool0001Wooooo`00Joooool01Ol0
003oooooooooool0003ooooo00Go00000_ooool3o`0000;ooooo00Go0000ooooool0003oooooo`00
000;ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooool0000>ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooooooool5
o`0006?ooooo001[ooooo`?o00000_ooool01ol0003ooooooooooooooooo0000ooooool000000_oo
ool02?l0003oooooooooool0003oooooo`000?oooooo00002Oooool2o`0000?ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000cooooo0_l00004ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
067ooooo001[ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`;o00000oooool2o`00
0003ooooool0003ooooo00Sooooo00?o0000ooooooooool00_ooool4o`0000?ooooo0ol00002oooo
o`Co00002Oooool00ol0003oooooooooo`02ooooo`?o00000oooool5o`0000;ooooo0ol0001Toooo
o`00Joooool01?l0003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000kooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool0001eooooo`00J_ooool4o`0001cooooo0ol0000>
ooooo`03o`000?oooooooooo00[ooooo0ol00003ooooo`03o`000?oooooooooo06oooooo003ooooo
ob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-31.8099, -1.87767, \
0.974221, 0.156056}},
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0042328 0 0.0329289 [
[.23545 -0.0125 -6 -9 ]
[.23545 -0.0125 6 0 ]
[.44709 -0.0125 -9 -9 ]
[.44709 -0.0125 9 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.87037 -0.0125 -9 -9 ]
[.87037 -0.0125 9 0 ]
[.01131 .08232 -18 -4.5 ]
[.01131 .08232 0 4.5 ]
[.01131 .16464 -6 -4.5 ]
[.01131 .16464 0 4.5 ]
[.01131 .24697 -18 -4.5 ]
[.01131 .24697 0 4.5 ]
[.01131 .32929 -12 -4.5 ]
[.01131 .32929 0 4.5 ]
[.01131 .41161 -24 -4.5 ]
[.01131 .41161 0 4.5 ]
[.01131 .49393 -12 -4.5 ]
[.01131 .49393 0 4.5 ]
[.01131 .57626 -24 -4.5 ]
[.01131 .57626 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23545 0 m
.23545 .00625 L
s
[(50)] .23545 -0.0125 0 1 Mshowa
.44709 0 m
.44709 .00625 L
s
[(100)] .44709 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(150)] .65873 -0.0125 0 1 Mshowa
.87037 0 m
.87037 .00625 L
s
[(200)] .87037 -0.0125 0 1 Mshowa
.125 Mabswid
.06614 0 m
.06614 .00375 L
s
.10847 0 m
.10847 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.19312 0 m
.19312 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.32011 0 m
.32011 .00375 L
s
.36243 0 m
.36243 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.48942 0 m
.48942 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.57407 0 m
.57407 .00375 L
s
.6164 0 m
.6164 .00375 L
s
.70106 0 m
.70106 .00375 L
s
.74339 0 m
.74339 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.82804 0 m
.82804 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.95503 0 m
.95503 .00375 L
s
.99735 0 m
.99735 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .08232 m
.03006 .08232 L
s
[(2.5)] .01131 .08232 1 0 Mshowa
.02381 .16464 m
.03006 .16464 L
s
[(5)] .01131 .16464 1 0 Mshowa
.02381 .24697 m
.03006 .24697 L
s
[(7.5)] .01131 .24697 1 0 Mshowa
.02381 .32929 m
.03006 .32929 L
s
[(10)] .01131 .32929 1 0 Mshowa
.02381 .41161 m
.03006 .41161 L
s
[(12.5)] .01131 .41161 1 0 Mshowa
.02381 .49393 m
.03006 .49393 L
s
[(15)] .01131 .49393 1 0 Mshowa
.02381 .57626 m
.03006 .57626 L
s
[(17.5)] .01131 .57626 1 0 Mshowa
.125 Mabswid
.02381 .01646 m
.02756 .01646 L
s
.02381 .03293 m
.02756 .03293 L
s
.02381 .04939 m
.02756 .04939 L
s
.02381 .06586 m
.02756 .06586 L
s
.02381 .09879 m
.02756 .09879 L
s
.02381 .11525 m
.02756 .11525 L
s
.02381 .13172 m
.02756 .13172 L
s
.02381 .14818 m
.02756 .14818 L
s
.02381 .18111 m
.02756 .18111 L
s
.02381 .19757 m
.02756 .19757 L
s
.02381 .21404 m
.02756 .21404 L
s
.02381 .2305 m
.02756 .2305 L
s
.02381 .26343 m
.02756 .26343 L
s
.02381 .2799 m
.02756 .2799 L
s
.02381 .29636 m
.02756 .29636 L
s
.02381 .31282 m
.02756 .31282 L
s
.02381 .34575 m
.02756 .34575 L
s
.02381 .36222 m
.02756 .36222 L
s
.02381 .37868 m
.02756 .37868 L
s
.02381 .39515 m
.02756 .39515 L
s
.02381 .42808 m
.02756 .42808 L
s
.02381 .44454 m
.02756 .44454 L
s
.02381 .461 m
.02756 .461 L
s
.02381 .47747 m
.02756 .47747 L
s
.02381 .5104 m
.02756 .5104 L
s
.02381 .52686 m
.02756 .52686 L
s
.02381 .54333 m
.02756 .54333 L
s
.02381 .55979 m
.02756 .55979 L
s
.02381 .59272 m
.02756 .59272 L
s
.02381 .60918 m
.02756 .60918 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .49393 m
.09004 .50681 L
.16227 .52086 L
.19739 .52769 L
.21452 .53102 L
.22263 .5326 L
.23011 .53406 L
.23206 .53443 L
.23388 .53479 L
.23578 .53488 L
.23788 .53352 L
.24631 .52805 L
.26163 .51812 L
.29535 .49626 L
.36182 .45317 L
.43249 .40736 L
.50056 .36323 L
.56603 .32078 L
.63571 .27561 L
.70279 .23212 L
.77407 .18591 L
.84276 .14138 L
.90885 .09854 L
.97619 .05488 L
s
0 0 0 r
gsave
.23545 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76455 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23545 0 m
.23545 .56185 L
s
.76455 0 m
.76455 .56185 L
s
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00E?ooool3o`0000Cooooo0_l0000Xooooo`?o00001?ooool2o`0000Cooooo0_l0000Toooo
o`?o00000oooool3o`0000Cooooo0_l0000Sooooo`Go00000oooool2o`0000Cooooo0_l0000Voooo
o`00Doooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
9?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000Uooooo`00Eoooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0002Gooooo001Gooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0Sooooo`00Doooool4o`0000?ooooo00Co
0000oooooooooooo0000:?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009?ooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000
oooooooooooo00008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000Uooooo`00Doooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0002Oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00008oooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002Gooooo001Cooooo`Go00000oooool2o`0002Wooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l0000Uooooo`04o`000?ooooooooooooooo`Go00000oooool2
o`0002Cooooo0ol00004ooooo`;o00001?ooool2o`0002Kooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo000PooooooCo00003?ooool002Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo07kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`00
9_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0@ooooo`009_ooool2o`00037ooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo013ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013o
oooo000Vooooo`;o0000<Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool04?ooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool04?ooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo0_l0000aooooo`03
o`000?oooooooooo07kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`00
9_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
;oooool00ol9jP[o0000ooooo`0Aooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo07kooooo00?o0000ooooooooool0;_ooool00ol9jP[oooooo`00000Booooo`009_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0;?ooool2
o`WZ2P;ooooo00?o0000ooooooooool04?ooool002Kooooo0_l0000aooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool0:_ooool2o`WZ2PCooooo00?o0000ooooooooool04?ooool0017o
oooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Yooooo`03o`WZ2_oooooooooo00Co
oooo00?o0000ooooooooool04?ooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo02Oooooo0_l9jPX7ooooo`03o`000?oooooooooo013ooooo000Cooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo07kooooo00?o0000ooooooooool09_ooool00ol9jP[oooooooooo`07ooooo`03
o`000?oooooooooo013ooooo000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool3o`00033ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Tooooo`;o2NX:
2_ooool00ol0003oooooooooo`0@ooooo`004Oooool01Ol0003ooooooooooooooooo000000Oooooo
1?l00005ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`0Rooooo`;o2NX:3?ooool00ol0003oooooooooo`0@ooooo`004Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool08Oooool00ol9jP[oooooooooo`0<ooooo`03o`00
0?oooooooooo013ooooo000Booooo`?o00002?ooool5o`0000Cooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo01oooooo0_l9jPX?ooooo`03o`000?oo
oooooooo013ooooo000Vooooo`;o0000<Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo01kooooo00?o2NX:ooooooooool03oooool00ol0003oooooooooo`0@ooooo`009_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool07?ooool2o`WZ
2Q;ooooo00?o0000ooooooooool04?ooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo01_ooooo00?o2NX:ooooooooool04_ooool00ol0003o
ooooooooo`0@ooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool06Oooool2o`WZ2QGooooo00?o0000ooooooooool04?ooool002Kooooo0_l0
000aooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool06?ooool00ol9jP[ooooooooo
o`0Eooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`0Gooooo`03o`WZ2_oooooooooo01Kooooo00?o0000
ooooooooool04?ooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo01Gooooo0_l9jPXIooooo`03o`000?oooooooooo013ooooo000Vooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Dooooo`03
o`WZ2_oooooooooo01Wooooo00?o0000ooooooooool04?ooool002Kooooo0_l0000aooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool04_ooool2o`WZ2Qcooooo00?o0000ooooooooool0
4?ooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo017ooooo00?o2NX:ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`009_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool03oooool2
o`WZ2Qoooooo00?o0000ooooooooool04?ooool002Kooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00kooooo00?o2NX:ooooooooool07oooool00ol0
003oooooooooo`0@ooooo`009_ooool2o`00037ooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`0<ooooo`;o2NX:8_ooool00ol0003oooooooooo`0@ooooo`007_ooool3o`0000Gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00_ooooo
00?o2NX:ooooooooool08_ooool00ol0003oooooooooo`0@ooooo`007Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Wooooo0_l9jPXUooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Oooooo0_l9jPXWooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo0ol0000`ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01_ooool0
0ol9jP[oooooooooo`0Wooooo`03o`000?oooooooooo013ooooo000Mooooo`Co00001Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01?ooool2o`WZ
2R[ooooo00?o0000ooooooooool04?ooool001gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool00oooool00ol9jP[o
ooooooooo`0Zooooo`03o`000?oooooooooo013ooooo000Mooooo`Go00001?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo07kooooo00Co0000oooooooooooooooo0_l9jPX]ooooo`03
o`000?oooooooooo013ooooo000Vooooo`;o0000<Oooool00ol0003oooooooooo`1nooooo`04o`00
0?ooooooooooo`WZ2Roooooo00?o0000ooooooooool04?ooool002Kooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`1nooooo`03o`000?l9jP[o2NX:033ooooo00?o0000ooooooooool0
4?ooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`1looooo`;o2NX:00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@
ooooo`009_ooool2o`00037ooooo00?o0000ooooooooool0Noooool01?l9jP[oooooooooool0000b
ooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0NOooool2o`WZ2P?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@oooo
o`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07Oooooo0_l9jPX5ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo0_l0000aooooo`03o`00
0?oooooooooo07Kooooo00?o2NX:ooooooooool01Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0M?oo
ool2o`WZ2PSooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`009_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07?ooooo00?o2NX:ooooooooool02?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0LOooool2o`WZ2P_ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0@ooooo`009_ooool2o`00037ooooo00?o0000ooooooooool0L?ooool00ol9jP[o
ooooooooo`0;ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1^ooooo`;o2NX:3_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo013ooooo000Cooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`1]ooooo`03o`WZ2_oooooooooo00kooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0@ooooo`004oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo06_ooooo0_l9jPXAooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04?ooool001Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`02ooooo`?o0000<?ooool00ol0003oooooooooo`1Yooooo`;o2NX:4oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Dooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
06Sooooo00?o2NX:ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
013ooooo000Eooooo`03o`000?oooooooooo00Gooooo1?l00005ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0I_ooool2o`WZ2QKooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0@ooooo`004Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo06Gooooo00?o2NX:oooooooo
ool05_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Aooooo`Go0000
1oooool5o`0000Cooooo0_l0000aooooo`03o`000?oooooooooo06?ooooo0_l9jPXIooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`1Qooooo`;o2NX:6oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo013ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0H?ooool0
0ol9jP[oooooooooo`0Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool0
02Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Nooooo`;o2NX:7_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Vooooo`;o0000<Oooool00ol0003o
ooooooooo`1Mooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0@ooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05_ooooo
0_l9jPXQooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`1Jooooo`03o`WZ2_oooooooooo027ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`009_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo05Sooooo0_l9jPXTooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool04?ooool002Kooooo0_l0000aooooo`03o`000?oooooooooo05Kooooo0_l9jPXVoooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`1Eooooo`03o`WZ2_oooooooooo02Kooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0@ooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo05?ooooo0_l9jPXYooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4?ooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Booooo`03o`WZ2_oo
oooooooo02Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`009_ooool2
o`00037ooooo00?o0000ooooooooool0D?ooool2o`WZ2Rcooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0@ooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
04oooooo00?o2NX:ooooooooool0;?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
013ooooo000Hooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`1=ooooo`;o2NX:;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013o
oooo000Iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo04cooooo00?o2NX:ooooooooool0;oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Iooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001?ooool3o`00033ooooo00?o0000ooooooooool0B_ooool2o`WZ2S;o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`006Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`19ooooo`03o`WZ2_oooooooooo03;ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0@ooooo`006Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`17ooooo`;o2NX:=Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Hooooo`;o00001?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0A_ooool00ol9jP[o
ooooooooo`0eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool001Wooooo
00?o0000ooooooooool00oooool2o`0000Gooooo0_l0000aooooo`03o`000?oooooooooo04Gooooo
00?o2NX:ooooooooool0=_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo
000Vooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0@oooool2o`WZ2SWooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`009_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo04;ooooo00?o2NX:ooooooooool0>Oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0@?ooool2o`WZ2Scooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@oooo
o`009_ooool2o`00037ooooo00?o0000ooooooooool0?oooool00ol9jP[oooooooooo`0looooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0mooooo`;o2NX:?oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0>ooo
ool2o`WZ2T7ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`009_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03[ooooo00?o2NX:ooooooooool0@Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Vooooo`;o0000<Oooool00ol0
003oooooooooo`0hooooo`;o2NX:A?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
013ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0=_ooool2o`WZ2TKo
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`009_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo03Gooooo00?o2NX:ooooooooool0A_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0<oooool2o`WZ2TWooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0@ooooo`009_ooool2o`00037ooooo00?o0000ooooooooool0<Oooool2o`WZ2T_ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`009_ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo033ooooo00?o2NX:ooooooooool0Boooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo013ooooo000<ooooo`?o00000_ooool5o`0000?ooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0^ooooo`;o
2NX:C_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000=ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0/ooooo`;o2NX:D?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000=ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`?o0000<?ooool00ol0003o
ooooooooo`0[ooooo`03o`WZ2_oooooooooo053ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0@ooooo`003Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Wooooo
0_l9jPYCooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool000gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo1?l00005ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0:?ooool00ol9jP[oooooooooo`1Cooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool04?ooool000cooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool09_ooool2o`WZ2UKooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0@ooooo`003Oooool00ol0003oooooooooo`02ooooo`?o00002?ooool5o`0000Cooooo0_l0
000aooooo`03o`000?oooooooooo02Cooooo0_l9jPYHooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool04?ooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0S
ooooo`03o`WZ2_oooooooooo05Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@
ooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo027ooooo0_l9jPYKoooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Pooooo`03o`WZ2_oooooooooo05_ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0@ooooo`009_ooool2o`00037ooooo00?o0000ooooooooool0
7_ooool2o`WZ2Ukooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`009_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo00?o2NX:ooooooooool0G_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool06oooool2o`WZ2V7ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0@ooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
01[ooooo00?o2NX:ooooooooool0HOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
013ooooo000Vooooo`;o0000<Oooool00ol0003oooooooooo`0Hooooo`;o2NX:I?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool05oooool00ol9jP[oooooooooo`1Tooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool04?ooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Eooooo`;o2NX:Ioooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000V
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05?ooool00ol9jP[oooooooooo`1W
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo0_l0000aoooo
o`03o`000?oooooooooo01?ooooo00?o2NX:ooooooooool0J?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool04Oooool2o`WZ2V_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`00
6?ooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4?ooool00ol9jP[oooooooooo`1[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4?ooool001Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0>ooooo`;o2NX:K_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo013ooooo000Iooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool4o`WZ2Roooooo00?o0000ooooooooool03Oooool00ol9jP[ooooooooo
o`1^ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool001Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Go2NX::_oo
ool00ol0003oooooooooo`0;ooooo`;o2NX:LOooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo013ooooo000Iooooo`04o`000?ooooooooooooooo`Co00001Oooool00ol0003ooooooooo
o`06ooooo`Go2NX:9Oooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo077ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`006?ooool2o`0000?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`Go2NX:8?ooool00ol0003oooooooooo`08
ooooo`;o2NX:M?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Ioooo
o`04o`000?ooooooooooooooo`Go00001?ooool2o`00017ooooo1Ol9jPXKooooo`03o`000?oooooo
oooo00Kooooo0_l9jPYfooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool0
02Kooooo00?o0000ooooooooool05Oooool4o`WZ2QOooooo00?o0000ooooooooool01Oooool00ol9
jP[oooooooooo`1fooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool002Ko
oooo00?o0000ooooooooool06Oooool5o`WZ2Q;ooooo00?o0000ooooooooool00oooool2o`WZ2WWo
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`009_ooool00ol0003ooooo
ooooo`0Nooooo`Co2NX:3_ooool00ol0003oooooooooo`02ooooo`03o`WZ2_oooooooooo07Wooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`009_ooool2o`0002?ooooo1?l9
jPX:ooooo`05o`000?ooooooooooooooool9jPX0O?ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo02Kooooo1ol9jPX3ooooo`04o`000?oo
oooo2NX:o`WZ2Wgooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`009_oo
ool00ol0003oooooooooo`0]ooooo`?o2NX:00?o0000o`WZ2_ooool0O_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013ooooo000Voooo
o`;o0000<Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool04?ooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1nooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4?ooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04?ooool002Kooooo0_l0000aooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`009_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0@ooooo`003?ooool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3gooooo`003Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo02gooooo1Ol0001looooo`;o000000Coooooo`000?l0003o0000;_ooool3o`00
01;ooooo000=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`?o0000;_ooool01?l0003oooooooooool0001looooo`05o`000?oooooooooo
ooooool00000;oooool01?l0003oooooooooool0000Aooooo`003Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo07gooooo00Go0000ooooooooooooooooo`00000booooo`03o`000?oo
oooooooo00oooooo000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool4
o`0000Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1mooooo`05o`000?oooooo
ooooooooool00000<?ooool2o`0001;ooooo000<ooooo`;o00000oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo07gooooo00Go0000ooooool0003oooooo`00000_ooooo`03o`000?oooooooooo01;ooooo
000=ooooo`04o`000?ooooooooooooooo`Go00001oooool5o`0000Cooooo0_l0000_ooooo`03o`00
0?oooooooooo07gooooo0_l000000ooooooo0000o`00000_ooooo`04o`000?ooooooooooo`00017o
oooo000Vooooo`03o`000?oooooooooo02gooooo0ol0001nooooo`04o`000?ooooooooooooooo`;o
0000;oooool3o`00017ooooo000Vooooo`03o`000?oooooooooo0?Oooooo000Vooooo`03o`000?oo
oooooooo0?Oooooo000Vooooo`;o0000n?ooool002Kooooo00?o0000ooooooooool0moooool002Ko
oooo00?o0000ooooooooool0moooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool009Cooooo0ol00029ooooo`00UOooool00ol0003oooooooooo`28ooooo`00L?oo
ool4o`0000?ooooo0ol00003ooooo`Co000000Koooooo`000?oooooo0000ooooool00008ooooo`?o
00000oooool3o`0000?ooooo0ol00004ooooo`;o00002Oooool3o`0000;ooooo1Ol000000ooooooo
0000o`000003o`0000;ooooo0ol0001Nooooo`00LOooool01_l0003oooooooooool0003oooooo`00
00Gooooo00Co0000oooooooooooo00000_ooool01Ol0003oooooo`000?oooooo000000Sooooo00Co
0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`00067ooooo001aooooo`05o`00
0?ooooooooooo`000?ooool01Ol00002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo0000
00_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`04o`000?oooooo
ooooo`0000kooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooooooo`Go
0000GOooool0077ooooo0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`000002oooo
o`08o`000?ooooooooooo`000?oooooo0000ooooool00009ooooo`;o00000oooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00003?ooool2o`0000Cooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
Foooool0077ooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo0_l00003ooooo`;o0000
00?oooooo`000?ooool02?ooool00ol0003oooooooooo`02ooooo`Co00000oooool3o`0000;ooooo
1?l00009ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Go00000_ooool3o`0005kooooo
001aooooo`04o`000?ooooooooooo`0001[ooooo00Co0000oooooooooooo00003_ooool00ol0003o
ooooooooo`09ooooo`04o`000?ooooooooooo`0006oooooo001`ooooo`Co00007?ooool3o`0000ko
oooo00?o0000ooooooooool02_ooool3o`0000?ooooo00?o0000ooooooooool0JOooool00?oooooo
8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-37.6552, -1.50677, \
0.974221, 0.12523}},
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"BeamSpotSizeGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              
              TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
                
                False,
                Editable->False], ",", 
              
              TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
                
                False,
                Editable->False]}], "}"}]}], 
        ",", \(BeamSpotSizeFunction \[Rule] {Which[#1 < 50.`, 
                0.033859048519996264`\ \@\(1 + 0.02180672813135181`\ \
\((\(\(3999.9942678200596`\)\(\[InvisibleSpace]\)\) + #1)\)\^2\), #1 \
\[GreaterEqual] 50.` && #1 < 175.`, 
                0.0008571910860259498`\ \@\(1 + 53085.86809194806`\ \
\((\(-152.53164180272506`\) + #1)\)\^2\), #1 \[GreaterEqual] 175.` && #1 < 
                    225.`, 0.0008571910860259477`\ \@\(1 + 53085.8680919486`\ \
\((\(-152.5316418027251`\) + #1)\)\^2\), #1 \[GreaterEqual] 225.`, 
                0.0008571910860259467`\ \@\(1 + 53085.868091948825`\ \
\((\(-152.53164180272506`\) + #1)\)\^2\)] &, 
            Which[#1 < 50.`, 
                0.006771809703999252`\ \@\(1 + 13.629205082094883`\ \
\((\(\(599.9999388567878`\)\(\[InvisibleSpace]\)\) + #1)\)\^2\), #1 \
\[GreaterEqual] 50.` && #1 < 175.`, 
                0.0020315428615137543`\ \@\(1 + 1682.618075978803`\ \
\((\(-244.99999229595568`\) + #1)\)\^2\), #1 \[GreaterEqual] 175.` && #1 < 
                    225.`, 0.0020315428615137548`\ \@\(1 + \
1682.6180759788015`\ \((\(-244.99999229595568`\) + #1)\)\^2\), #1 \
\[GreaterEqual] 225.`, 
                0.0020315428615137548`\ \@\(1 + 1682.6180759788015`\ \
\((\(-244.99999229595565`\) + #1)\)\^2\)] &}\), 
        ",", \(BeamCurvatureFunction \[Rule] {Which[#1 < 
                  50.`, \(-\((\(\(3999.9942678200596`\)\(\[InvisibleSpace]\)\)\
 + #1)\)\)\ \((1 + 
                      45.85740666717844`\/\((\(\(3999.9942678200596`\)\(\
\[InvisibleSpace]\)\) + #1)\)\^2)\), #1 \[GreaterEqual] 50.` && #1 < 
                    175.`, \(-\((1 + 
                        0.00001883740505604876`\/\((\(-152.53164180272506`\) \
+ #1)\)\^2)\)\)\ \((\(-152.53164180272506`\) + #1)\), #1 \[GreaterEqual] 
                    175.` && #1 < 
                    225.`, \(-\((1 + 
                        0.00001883740505604857`\/\((\(-152.5316418027251`\) + \
#1)\)\^2)\)\)\ \((\(-152.5316418027251`\) + #1)\), #1 \[GreaterEqual] 
                  225.`, \(-\((1 + 
                        0.00001883740505604849`\/\((\(-152.53164180272506`\) \
+ #1)\)\^2)\)\)\ \((\(-152.53164180272506`\) + #1)\)] &, 
            Which[#1 < 
                  50.`, \(-\((\(\(599.9999388567878`\)\(\[InvisibleSpace]\)\) \
+ #1)\)\)\ \((1 + 
                      0.07337185066748549`\/\((\(\(599.9999388567878`\)\(\
\[InvisibleSpace]\)\) + #1)\)\^2)\), #1 \[GreaterEqual] 50.` && #1 < 
                    175.`, \(-\((1 + 
                        0.0005943119322656068`\/\((\(-244.99999229595568`\) + \
#1)\)\^2)\)\)\ \((\(-244.99999229595568`\) + #1)\), #1 \[GreaterEqual] 
                    175.` && #1 < 
                    225.`, \(-\((1 + 
                        0.0005943119322656073`\/\((\(-244.99999229595568`\) + \
#1)\)\^2)\)\)\ \((\(-244.99999229595568`\) + #1)\), #1 \[GreaterEqual] 
                  225.`, \(-\((1 + 
                        0.0005943119322656073`\/\((\(-244.99999229595565`\) + \
#1)\)\^2)\)\)\ \((\(-244.99999229595565`\) + #1)\)] &}\), 
        ",", \(ComplexBeamParameterFunction \[Rule] {Which[#1 < 
                  50.`, \((\(\(3999.9942678200596`\)\(\[InvisibleSpace]\)\) + 
                      6.771809703999252`\ \[ImaginaryI])\) - #1, #1 \
\[GreaterEqual] 50.` && #1 < 
                    175.`, \((\(-52.53164180272506`\) + 
                      0.004340207950784013`\ \[ImaginaryI])\) - #1, #1 \
\[GreaterEqual] 175.` && #1 < 
                    225.`, \((\(\(197.4683581972749`\)\(\[InvisibleSpace]\)\) \
+ 0.004340207950783991`\ \[ImaginaryI])\) - #1, #1 \[GreaterEqual] 
                  225.`, \((\(\(297.46835819727494`\)\(\[InvisibleSpace]\)\) \
+ 0.0043402079507839815`\ \[ImaginaryI])\) - #1] &, 
            Which[#1 < 
                  50.`, \((\(\(599.9999388567878`\)\(\[InvisibleSpace]\)\) + 
                      0.27087238815997006`\ \[ImaginaryI])\) - #1, #1 \
\[GreaterEqual] 50.` && #1 < 
                    175.`, \((\(-144.99999229595568`\) + 
                      0.024378513741932808`\ \[ImaginaryI])\) - #1, #1 \
\[GreaterEqual] 175.` && #1 < 
                    225.`, \((\(\(105.00000770404434`\)\(\[InvisibleSpace]\)\)\
 + 0.024378513741932818`\ \[ImaginaryI])\) - #1, #1 \[GreaterEqual] 
                  225.`, \((\(\(205.00000770404435`\)\(\[InvisibleSpace]\)\) \
+ 0.024378513741932818`\ \[ImaginaryI])\) - #1] &}\), 
        ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(PlotDomain \[Rule] {0, 225.`}\)}], "}"}]], "Output",
  CellLabel->"Out[40]=",
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowGaussian", "Subsubsection",
  CellTags->{"AOG0.", "4.3.4", "AOG4.", "AOG4.3", "AOG4.3.4"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[thinopticalsystemreflected2,ShowGaussian->True,CreateStereoView->\
Crossed];\
\>", "Input",
  CellLabel->"In[41]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57143 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0136054 0.47619 [
[ 0 0 0 0 ]
[ 1 .57143 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .57143 L
0 .57143 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0136054 0.568027 0.557823 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.039 .916 .04 r
1 Mabswid
[ ] 0 setdash
.17149 .62614 m
.18374 .62223 L
s
.16384 .61994 m
.1666 .6223 L
s
.18374 .62223 m
.19605 .61831 L
s
.16107 .61756 m
.16384 .61994 L
s
.1583 .61519 m
.16107 .61756 L
s
.19605 .61831 m
.20841 .61437 L
s
.18226 .61402 m
.18502 .61641 L
s
.15551 .61281 m
.1583 .61519 L
s
.1795 .61163 m
.18226 .61402 L
s
.15272 .61042 m
.15551 .61281 L
s
.20841 .61437 m
.22082 .61041 L
s
.13029 .53678 m
.14253 .53232 L
s
.17674 .60924 m
.1795 .61163 L
s
.14992 .60803 m
.15272 .61042 L
s
.12877 .542 m
.12854 .5449 L
s
.2008 .60807 m
.20355 .61047 L
s
.17396 .60684 m
.17674 .60924 L
s
.12854 .5449 m
.12829 .54782 L
s
.22082 .61041 m
.23329 .60644 L
s
.14711 .60564 m
.14992 .60803 L
s
.14253 .53232 m
.15483 .52783 L
s
.12829 .54782 m
.12804 .55074 L
s
.19805 .60567 m
.2008 .60807 L
s
.17117 .60444 m
.17396 .60684 L
s
.14429 .60324 m
.14711 .60564 L
s
.12804 .55074 m
.12778 .55366 L
s
.19529 .60326 m
.19805 .60567 L
s
.23329 .60644 m
.2458 .60245 L
s
.16838 .60203 m
.17117 .60444 L
s
.12778 .55366 m
.12751 .5566 L
s
.15483 .52783 m
.16717 .52333 L
s
.14715 .53535 m
.14693 .53829 L
s
.14146 .60084 m
.14429 .60324 L
s
.12751 .5566 m
.12723 .55954 L
s
.21946 .60209 m
.2222 .60451 L
s
.14693 .53829 m
.1467 .54123 L
s
.19252 .60084 m
.19529 .60326 L
s
.16558 .59962 m
.16838 .60203 L
s
.13863 .59843 m
.14146 .60084 L
s
.12723 .55954 m
.12694 .56248 L
s
.1467 .54123 m
.14645 .54418 L
s
.21672 .59966 m
.21946 .60209 L
s
.18975 .59842 m
.19252 .60084 L
s
.2458 .60245 m
.25837 .59844 L
s
.12694 .56248 m
.12665 .56544 L
s
.16717 .52333 m
.17956 .51881 L
s
.16277 .5972 m
.16558 .59962 L
s
.14645 .54418 m
.1462 .54714 L
s
.13579 .59601 m
.13863 .59843 L
s
.12665 .56544 m
.12634 .5684 L
s
.21396 .59723 m
.21672 .59966 L
s
.1462 .54714 m
.14594 .55011 L
s
.18696 .59599 m
.18975 .59842 L
s
.16565 .52867 m
.16544 .53163 L
s
.15995 .59478 m
.16277 .5972 L
s
.13293 .5936 m
.13579 .59601 L
s
.12634 .5684 m
.12603 .57137 L
s
.14594 .55011 m
.14567 .55308 L
s
.23823 .59606 m
.24096 .5985 L
s
.16544 .53163 m
.16521 .53461 L
s
.2112 .5948 m
.21396 .59723 L
s
.25837 .59844 m
.27099 .59442 L
s
.17956 .51881 m
.19201 .51428 L
s
.18417 .59356 m
.18696 .59599 L
s
.12603 .57137 m
.1257 .57434 L
s
.15712 .59236 m
.15995 .59478 L
s
.14567 .55308 m
.1454 .55606 L
s
.13007 .59118 m
.13293 .5936 L
s
.16521 .53461 m
.16498 .53759 L
s
.2355 .59362 m
.23823 .59606 L
s
.1257 .57434 m
.12537 .57733 L
s
.20843 .59236 m
.2112 .5948 L
s
.1454 .55606 m
.14511 .55905 L
s
.18136 .59113 m
.18417 .59356 L
s
.16498 .53759 m
.16474 .54058 L
s
.15429 .58993 m
.15712 .59236 L
s
.12721 .58875 m
.13007 .59118 L
s
.12537 .57733 m
.12503 .58032 L
s
0 g
.5 Mabswid
.33764 .50867 m
.34518 .53395 L
s
.32716 .48477 m
.33764 .50867 L
s
.039 .916 .04 r
1 Mabswid
.14511 .55905 m
.14481 .56204 L
s
.23275 .59117 m
.2355 .59362 L
s
.16474 .54058 m
.16449 .54358 L
s
.19201 .51428 m
.2045 .50972 L
s
.27099 .59442 m
.28366 .59038 L
s
.18426 .52194 m
.18406 .52494 L
s
.20566 .58992 m
.20843 .59236 L
s
0 g
.5 Mabswid
.34518 .53395 m
.34931 .55906 L
s
.039 .916 .04 r
1 Mabswid
.12503 .58032 m
.12469 .58331 L
s
.17855 .58869 m
.18136 .59113 L
s
.15144 .58749 m
.15429 .58993 L
s
.14481 .56204 m
.14451 .56504 L
s
.12433 .58632 m
.12721 .58875 L
s
.16449 .54358 m
.16423 .54659 L
s
.25713 .59 m
.25984 .59245 L
s
.18406 .52494 m
.18385 .52795 L
s
.12469 .58331 m
.12433 .58632 L
s
.23 .58872 m
.23275 .59117 L
s
.20287 .58747 m
.20566 .58992 L
s
.14451 .56504 m
.1442 .56805 L
s
0 g
.5 Mabswid
.31437 .46377 m
.32716 .48477 L
s
.039 .916 .04 r
1 Mabswid
.17573 .58625 m
.17855 .58869 L
s
.16423 .54659 m
.16397 .5496 L
s
.14859 .58505 m
.15144 .58749 L
s
.18385 .52795 m
.18363 .53096 L
s
.12433 .58632 m
.12396 .58933 L
s
0 0 0 r
.12433 .58632 m
.2933 .53015 L
s
.039 .916 .04 r
.12144 .58388 m
.12433 .58632 L
s
.2544 .58754 m
.25713 .59 L
s
.1442 .56805 m
.14388 .57107 L
s
.2045 .50972 m
.21705 .50514 L
s
.22724 .58626 m
.23 .58872 L
s
.28366 .59038 m
.29639 .58632 L
s
.16397 .5496 m
.16369 .55262 L
s
.20008 .58502 m
.20287 .58747 L
s
.18363 .53096 m
.1834 .53398 L
s
.12396 .58933 m
.12359 .59235 L
s
.1729 .5838 m
.17573 .58625 L
s
0 g
.5 Mabswid
.34931 .55906 m
.34973 .58241 L
s
.039 .916 .04 r
1 Mabswid
.14573 .58261 m
.14859 .58505 L
s
.14388 .57107 m
.14355 .57409 L
s
.11855 .58144 m
.12144 .58388 L
s
.16369 .55262 m
.16341 .55564 L
s
.25166 .58507 m
.2544 .58754 L
s
.1834 .53398 m
.18316 .53701 L
s
.12359 .59235 m
.1232 .59537 L
s
.20299 .51517 m
.2028 .5182 L
s
.22447 .5838 m
.22724 .58626 L
s
.14355 .57409 m
.14321 .57712 L
s
.19727 .58256 m
.20008 .58502 L
s
.17007 .58135 m
.1729 .5838 L
s
.16341 .55564 m
.16311 .55868 L
s
.14286 .58016 m
.14573 .58261 L
s
.1232 .59537 m
.12281 .5984 L
s
.18316 .53701 m
.18291 .54005 L
s
.11564 .579 m
.11855 .58144 L
s
.2028 .5182 m
.2026 .52124 L
s
.27614 .5839 m
.27885 .58637 L
s
.14321 .57712 m
.14286 .58016 L
s
.21705 .50514 m
.22965 .50055 L
s
.24892 .5826 m
.25166 .58507 L
s
.29639 .58632 m
.30917 .58224 L
s
.22169 .58134 m
.22447 .5838 L
s
.16311 .55868 m
.16281 .56172 L
s
.12281 .5984 m
.12241 .60144 L
s
.19446 .5801 m
.19727 .58256 L
s
.18291 .54005 m
.18265 .54309 L
s
.2026 .52124 m
.20239 .52429 L
s
.16722 .57889 m
.17007 .58135 L
s
.14286 .58016 m
.1425 .5832 L
s
.13998 .5777 m
.14286 .58016 L
s
0 g
.5 Mabswid
.30006 .44701 m
.31437 .46377 L
s
.039 .916 .04 r
1 Mabswid
.11273 .57655 m
.11564 .579 L
s
.27342 .58142 m
.27614 .5839 L
s
.16281 .56172 m
.1625 .56477 L
s
.12241 .60144 m
.122 .60449 L
s
.24617 .58013 m
.24892 .5826 L
s
.18265 .54309 m
.18239 .54615 L
s
.20239 .52429 m
.20217 .52734 L
s
.21891 .57887 m
.22169 .58134 L
s
.1425 .5832 m
.14213 .58625 L
s
.19164 .57763 m
.19446 .5801 L
s
.16437 .57643 m
.16722 .57889 L
s
.1625 .56477 m
.16218 .56782 L
s
.122 .60449 m
.12158 .60754 L
s
.13709 .57525 m
.13998 .5777 L
s
.18239 .54615 m
.18211 .5492 L
s
.10981 .57409 m
.11273 .57655 L
s
.22965 .50055 m
.2423 .49594 L
s
.20217 .52734 m
.20194 .5304 L
s
.27069 .57893 m
.27342 .58142 L
s
.22183 .50836 m
.22165 .51142 L
s
.14213 .58625 m
.14176 .58931 L
s
.30917 .58224 m
.32201 .57815 L
s
.24341 .57765 m
.24617 .58013 L
s
.16218 .56782 m
.16185 .57089 L
s
.21611 .57639 m
.21891 .57887 L
s
.12158 .60754 m
.12115 .6106 L
s
.18881 .57516 m
.19164 .57763 L
s
.18211 .5492 m
.18183 .55227 L
s
0 g
.5 Mabswid
.34973 .58241 m
.34637 .60251 L
s
.34973 .58241 m
.33121 .56526 L
s
.34973 .58241 m
.34973 .58241 L
s
.039 .916 .04 r
1 Mabswid
.16151 .57396 m
.16437 .57643 L
s
.20194 .5304 m
.20171 .53347 L
s
.22165 .51142 m
.22146 .51449 L
s
.14176 .58931 m
.14137 .59238 L
s
.13419 .57278 m
.13709 .57525 L
s
.29527 .57775 m
.29797 .58025 L
s
.10688 .57163 m
.10981 .57409 L
s
.16185 .57089 m
.16151 .57396 L
s
.12115 .6106 m
.12071 .61367 L
s
.26796 .57645 m
.27069 .57893 L
s
.24064 .57517 m
.24341 .57765 L
s
.18183 .55227 m
.18154 .55535 L
s
.20171 .53347 m
.20146 .53655 L
s
.21331 .57391 m
.21611 .57639 L
s
.14137 .59238 m
.14098 .59545 L
s
.22146 .51449 m
.22126 .51757 L
s
.18597 .57269 m
.18881 .57516 L
s
.12071 .61367 m
.12026 .61675 L
s
.16151 .57396 m
.16116 .57704 L
s
.15863 .57149 m
.16151 .57396 L
s
.13129 .57031 m
.13419 .57278 L
s
.2423 .49594 m
.255 .49131 L
s
.29256 .57526 m
.29527 .57775 L
s
.18154 .55535 m
.18124 .55843 L
s
.10394 .56917 m
.10688 .57163 L
s
.14098 .59545 m
.14058 .59853 L
s
.20146 .53655 m
.20121 .53963 L
s
.26522 .57395 m
.26796 .57645 L
s
.32201 .57815 m
.3349 .57404 L
s
.22126 .51757 m
.22106 .52066 L
s
.23786 .57268 m
.24064 .57517 L
s
.12026 .61675 m
.11981 .61983 L
s
.16116 .57704 m
.1608 .58012 L
s
.2105 .57143 m
.21331 .57391 L
s
.18313 .5702 m
.18597 .57269 L
s
.18124 .55843 m
.18092 .56152 L
s
.14058 .59853 m
.14016 .60162 L
s
.15575 .56901 m
.15863 .57149 L
s
.20121 .53963 m
.20094 .54273 L
s
.12838 .56784 m
.13129 .57031 L
s
.22106 .52066 m
.22084 .52375 L
s
.24079 .50151 m
.24062 .5046 L
s
.28985 .57276 m
.29256 .57526 L
s
.101 .5667 m
.10394 .56917 L
s
.11981 .61983 m
.11934 .62292 L
s
.1608 .58012 m
.16043 .58322 L
s
.26246 .57146 m
.26522 .57395 L
s
.18092 .56152 m
.1806 .56461 L
s
.23507 .57018 m
.23786 .57268 L
s
.14016 .60162 m
.13974 .60472 L
s
.20094 .54273 m
.20067 .54583 L
s
.20768 .56894 m
.2105 .57143 L
s
.22084 .52375 m
.22062 .52685 L
s
.24062 .5046 m
.24045 .5077 L
s
.18027 .56772 m
.18313 .5702 L
s
.11934 .62292 m
.11887 .62601 L
s
0 g
.5 Mabswid
.28512 .43563 m
.30006 .44701 L
s
.30006 .44701 m
.30006 .44701 L
s
.29784 .47435 m
.30006 .44701 L
s
.039 .916 .04 r
1 Mabswid
.16043 .58322 m
.16006 .58632 L
s
.15287 .56653 m
.15575 .56901 L
s
.255 .49131 m
.26775 .48665 L
s
.31453 .57157 m
.31722 .57408 L
s
.12545 .56536 m
.12838 .56784 L
s
.1806 .56461 m
.18027 .56772 L
s
.28712 .57025 m
.28985 .57276 L
s
.09804 .56423 m
.101 .5667 L
s
.13974 .60472 m
.13931 .60782 L
s
.3349 .57404 m
.34672 .56887 L
s
.20067 .54583 m
.20039 .54893 L
s
.2597 .56895 m
.26246 .57146 L
s
.11887 .62601 m
.11839 .62912 L
s
.22062 .52685 m
.22038 .52996 L
s
.24045 .5077 m
.24026 .51081 L
s
.23228 .56769 m
.23507 .57018 L
s
.16006 .58632 m
.15967 .58942 L
s
.20485 .56644 m
.20768 .56894 L
s
.18027 .56772 m
.17994 .57083 L
s
.17741 .56523 m
.18027 .56772 L
s
.13931 .60782 m
.13887 .61093 L
s
.14997 .56404 m
.15287 .56653 L
s
.31183 .56906 m
.31453 .57157 L
s
.20039 .54893 m
.20009 .55205 L
s
.12252 .56288 m
.12545 .56536 L
s
.11839 .62912 m
.11789 .63223 L
s
.22038 .52996 m
.22014 .53308 L
s
.09507 .56175 m
.09804 .56423 L
s
.28439 .56774 m
.28712 .57025 L
s
.24026 .51081 m
.24007 .51393 L
s
.15967 .58942 m
.15928 .59254 L
s
.25694 .56645 m
.2597 .56895 L
s
.17994 .57083 m
.17959 .57395 L
s
.13887 .61093 m
.13843 .61404 L
s
.22948 .56518 m
.23228 .56769 L
s
.20201 .56394 m
.20485 .56644 L
s
.20009 .55205 m
.19979 .55517 L
s
.26775 .48665 m
.28056 .48198 L
s
.22014 .53308 m
.21989 .5362 L
s
.17454 .56273 m
.17741 .56523 L
s
.15928 .59254 m
.15887 .59566 L
s
.25986 .49461 m
.25971 .49774 L
s
.24007 .51393 m
.23986 .51706 L
s
.14706 .56155 m
.14997 .56404 L
s
.30912 .56654 m
.31183 .56906 L
s
.11958 .56039 m
.12252 .56288 L
s
.13843 .61404 m
.13797 .61717 L
s
.17959 .57395 m
.17923 .57708 L
s
.0921 .55927 m
.09507 .56175 L
s
.28164 .56522 m
.28439 .56774 L
s
0 g
.5 Mabswid
.34637 .60251 m
.3394 .61799 L
s
.039 .916 .04 r
1 Mabswid
.19979 .55517 m
.19948 .5583 L
s
.25416 .56393 m
.25694 .56645 L
s
.15887 .59566 m
.15846 .59879 L
s
.21989 .5362 m
.21963 .53934 L
s
.22666 .56267 m
.22948 .56518 L
s
.34672 .56887 m
.35804 .56314 L
s
.23986 .51706 m
.23965 .52019 L
s
.25971 .49774 m
.25955 .50087 L
s
.19916 .56144 m
.20201 .56394 L
s
.13797 .61717 m
.1375 .6203 L
s
.17923 .57708 m
.17886 .58021 L
s
.17166 .56023 m
.17454 .56273 L
s
.11822 .63705 m
.13066 .63332 L
s
.14415 .55905 m
.14706 .56155 L
s
.19948 .5583 m
.19916 .56144 L
s
.3064 .56402 m
.30912 .56654 L
s
.11663 .5579 m
.11958 .56039 L
s
.15846 .59879 m
.15804 .60193 L
s
.08912 .55678 m
.0921 .55927 L
s
.21963 .53934 m
.21936 .54248 L
s
.27889 .5627 m
.28164 .56522 L
s
.23965 .52019 m
.23943 .52333 L
s
.25955 .50087 m
.25938 .50401 L
s
.25137 .56142 m
.25416 .56393 L
s
.1375 .6203 m
.13703 .62344 L
s
.17886 .58021 m
.17849 .58335 L
s
.22384 .56016 m
.22666 .56267 L
s
.28056 .48198 m
.29342 .47729 L
s
.19916 .56144 m
.19883 .56458 L
s
.19631 .55893 m
.19916 .56144 L
s
.15804 .60193 m
.15761 .60507 L
s
.16877 .55773 m
.17166 .56023 L
s
0 g
.5 Mabswid
.33121 .56526 m
.3124 .54784 L
s
.039 .916 .04 r
1 Mabswid
.21936 .54248 m
.21907 .54563 L
s
.14122 .55655 m
.14415 .55905 L
s
.23943 .52333 m
.2392 .52648 L
s
.25938 .50401 m
.2592 .50716 L
s
.13703 .62344 m
.13654 .62658 L
s
.30368 .56149 m
.3064 .56402 L
s
.11368 .55541 m
.11663 .5579 L
s
.17849 .58335 m
.1781 .5865 L
s
.08613 .55429 m
.08912 .55678 L
s
.27613 .56018 m
.27889 .5627 L
s
.19883 .56458 m
.1985 .56774 L
s
.24858 .5589 m
.25137 .56142 L
s
.15761 .60507 m
.15717 .60822 L
s
.343 .56211 m
.34704 .56418 L
s
.21907 .54563 m
.21878 .54878 L
s
.22101 .55764 m
.22384 .56016 L
s
.2392 .52648 m
.23896 .52964 L
s
.27906 .48767 m
.27892 .49083 L
s
.2592 .50716 m
.259 .51032 L
s
.19344 .55642 m
.19631 .55893 L
s
.1781 .5865 m
.17771 .58966 L
s
.16587 .55522 m
.16877 .55773 L
s
.13066 .63332 m
.14315 .62959 L
s
.13829 .55405 m
.14122 .55655 L
s
.1985 .56774 m
.19815 .5709 L
s
.30095 .55895 m
.30368 .56149 L
s
.11071 .5529 m
.11368 .55541 L
s
.15717 .60822 m
.15672 .61138 L
s
.35804 .56314 m
.36943 .55738 L
s
.08313 .55179 m
.08613 .55429 L
s
.21878 .54878 m
.21848 .55195 L
s
.27336 .55765 m
.27613 .56018 L
s
.33904 .56 m
.343 .56211 L
s
.23896 .52964 m
.23871 .53281 L
s
.27892 .49083 m
.27877 .49399 L
s
.259 .51032 m
.2588 .51349 L
s
.24577 .55637 m
.24858 .5589 L
s
.17771 .58966 m
.1773 .59282 L
s
.29342 .47729 m
.30627 .47348 L
s
.21818 .55512 m
.22101 .55764 L
s
.19815 .5709 m
.19779 .57407 L
s
.19057 .5539 m
.19344 .55642 L
s
.15672 .61138 m
.15626 .61455 L
s
.16296 .5527 m
.16587 .55522 L
s
0 g
.5 Mabswid
.29558 .50206 m
.29784 .47435 L
s
.27052 .4305 m
.28512 .43563 L
s
.039 .916 .04 r
1 Mabswid
.21848 .55195 m
.21818 .55512 L
s
.13535 .55154 m
.13829 .55405 L
s
.23871 .53281 m
.23845 .53598 L
s
.10773 .5504 m
.11071 .5529 L
s
.1773 .59282 m
.17689 .596 L
s
.2982 .55641 m
.30095 .55895 L
s
.27877 .49399 m
.27861 .49717 L
s
.2588 .51349 m
.25859 .51666 L
s
.33518 .55786 m
.33904 .56 L
s
.08012 .54929 m
.08313 .55179 L
s
.27059 .55511 m
.27336 .55765 L
s
.15626 .61455 m
.15579 .61772 L
s
.19779 .57407 m
.19742 .57724 L
s
.24296 .55384 m
.24577 .55637 L
s
.21818 .55512 m
.21786 .5583 L
s
.21533 .55259 m
.21818 .55512 L
s
.18769 .55137 m
.19057 .5539 L
s
.23845 .53598 m
.23818 .53916 L
s
.17689 .596 m
.17647 .59918 L
s
.25859 .51666 m
.25838 .51985 L
s
.27861 .49717 m
.27844 .50035 L
s
.16005 .55018 m
.16296 .5527 L
s
.14315 .62959 m
.1557 .62583 L
s
.1324 .54902 m
.13535 .55154 L
s
.33139 .55568 m
.33518 .55786 L
s
.15579 .61772 m
.15531 .6209 L
s
.19742 .57724 m
.19705 .58043 L
s
.10475 .54789 m
.10773 .5504 L
s
.29545 .55387 m
.2982 .55641 L
s
.21786 .5583 m
.21753 .56149 L
s
.2678 .55257 m
.27059 .55511 L
s
.17647 .59918 m
.17603 .60236 L
s
.23818 .53916 m
.2379 .54235 L
s
.24014 .5513 m
.24296 .55384 L
s
.25838 .51985 m
.25815 .52304 L
s
.27844 .50035 m
.27827 .50354 L
s
.30627 .47348 m
.31914 .4701 L
s
.21247 .55006 m
.21533 .55259 L
s
.36943 .55738 m
.38088 .55159 L
s
.19705 .58043 m
.19666 .58362 L
s
.1848 .54884 m
.18769 .55137 L
s
.3277 .55347 m
.33139 .55568 L
s
.15712 .54766 m
.16005 .55018 L
s
.21753 .56149 m
.21719 .56468 L
s
.12944 .5465 m
.1324 .54902 L
s
.17603 .60236 m
.17559 .60556 L
s
.10176 .54537 m
.10475 .54789 L
s
.2379 .54235 m
.23761 .54555 L
s
.2927 .55132 m
.29545 .55387 L
s
.35993 .55399 m
.36375 .55596 L
s
.30296 .47932 m
.30225 .4827 L
s
.25815 .52304 m
.25791 .52624 L
s
.27827 .50354 m
.27808 .50674 L
s
.26501 .55002 m
.2678 .55257 L
s
.19666 .58362 m
.19627 .58682 L
s
.23731 .54876 m
.24014 .5513 L
s
.20961 .54752 m
.21247 .55006 L
s
.21719 .56468 m
.21684 .56788 L
s
0 g
.5 Mabswid
.3394 .61799 m
.32918 .62773 L
s
.039 .916 .04 r
1 Mabswid
.17559 .60556 m
.17514 .60876 L
s
.32409 .55123 m
.3277 .55347 L
s
.1819 .54631 m
.1848 .54884 L
s
.23761 .54555 m
.23731 .54876 L
s
.30225 .4827 m
.30156 .48608 L
s
.15419 .54513 m
.15712 .54766 L
s
.07539 .545 m
.08781 .54069 L
s
.1557 .62583 m
.16831 .62206 L
s
.25791 .52624 m
.25766 .52944 L
s
.3562 .55198 m
.35993 .55399 L
s
.27808 .50674 m
.27788 .50995 L
s
.12647 .54397 m
.12944 .5465 L
s
.19627 .58682 m
.19586 .59003 L
s
.09875 .54285 m
.10176 .54537 L
s
.28993 .54876 m
.2927 .55132 L
s
.21684 .56788 m
.21649 .5711 L
s
.2622 .54747 m
.26501 .55002 L
s
.17514 .60876 m
.17468 .61197 L
s
.30156 .48608 m
.30091 .48944 L
s
.23731 .54876 m
.237 .55197 L
s
.23447 .54621 m
.23731 .54876 L
s
.25766 .52944 m
.2574 .53266 L
s
.32056 .54895 m
.32409 .55123 L
s
.20673 .54498 m
.20961 .54752 L
s
.27788 .50995 m
.27768 .51317 L
s
.19586 .59003 m
.19545 .59324 L
s
.35254 .54994 m
.3562 .55198 L
s
.31914 .4701 m
.33207 .4667 L
s
.17899 .54377 m
.1819 .54631 L
s
.15124 .54259 m
.15419 .54513 L
s
.21649 .5711 m
.21612 .57431 L
s
.17468 .61197 m
.17421 .61519 L
s
.12349 .54144 m
.12647 .54397 L
s
.30091 .48944 m
.30029 .49281 L
s
.237 .55197 m
.23669 .55519 L
s
.28715 .5462 m
.28993 .54876 L
s
.38088 .55159 m
.3924 .54577 L
s
.2574 .53266 m
.25713 .53588 L
s
.25939 .54492 m
.2622 .54747 L
s
.19545 .59324 m
.19503 .59646 L
s
.27768 .51317 m
.27746 .51639 L
s
.23163 .54366 m
.23447 .54621 L
s
.31712 .54663 m
.32056 .54895 L
s
.34897 .54787 m
.35254 .54994 L
s
.21612 .57431 m
.21575 .57754 L
s
.20385 .54243 m
.20673 .54498 L
s
.30029 .49281 m
.29969 .49616 L
s
.17607 .54123 m
.17899 .54377 L
s
.08781 .54069 m
.10029 .53636 L
s
.23669 .55519 m
.23636 .55842 L
s
0 g
.5 Mabswid
.3124 .54784 m
.2933 .53015 L
s
.039 .916 .04 r
1 Mabswid
.14829 .54005 m
.15124 .54259 L
s
.16831 .62206 m
.18097 .61827 L
s
.25713 .53588 m
.25686 .53911 L
s
.12051 .53891 m
.12349 .54144 L
s
.19503 .59646 m
.19459 .59969 L
s
.27746 .51639 m
.27723 .51962 L
s
.28437 .54364 m
.28715 .5462 L
s
.21575 .57754 m
.21536 .58078 L
s
.34548 .54577 m
.34897 .54787 L
s
.25657 .54235 m
.25939 .54492 L
s
.3222 .47414 m
.32152 .47743 L
s
.29969 .49616 m
.29913 .49952 L
s
.31377 .54428 m
.31712 .54663 L
s
.22877 .5411 m
.23163 .54366 L
s
.23636 .55842 m
.23602 .56166 L
s
.20096 .53988 m
.20385 .54243 L
s
.19459 .59969 m
.19415 .60293 L
s
.25686 .53911 m
.25657 .54235 L
s
.27723 .51962 m
.277 .52286 L
s
.17315 .53868 m
.17607 .54123 L
s
.377 .5458 m
.3806 .54767 L
s
0 g
.5 Mabswid
.2933 .53015 m
.29558 .50206 L
s
.039 .916 .04 r
1 Mabswid
.33207 .4667 m
.34506 .46328 L
s
.14533 .53751 m
.14829 .54005 L
s
.21536 .58078 m
.21496 .58402 L
s
.32152 .47743 m
.32086 .48071 L
s
.11751 .53637 m
.12051 .53891 L
s
.29913 .49952 m
.2986 .50286 L
s
.34207 .54363 m
.34548 .54577 L
s
.23602 .56166 m
.23568 .56491 L
s
.28157 .54107 m
.28437 .54364 L
s
.19415 .60293 m
.1937 .60618 L
s
.3105 .5419 m
.31377 .54428 L
s
.25657 .54235 m
.25627 .5456 L
s
.25374 .53979 m
.25657 .54235 L
s
.277 .52286 m
.27675 .52611 L
s
.2259 .53854 m
.22877 .5411 L
s
.37348 .5439 m
.377 .5458 L
s
.32086 .48071 m
.32024 .48399 L
s
.21496 .58402 m
.21456 .58727 L
s
.19806 .53732 m
.20096 .53988 L
s
.2986 .50286 m
.2981 .5062 L
s
0 g
.5 Mabswid
.25724 .43209 m
.27052 .4305 L
s
.039 .916 .04 r
1 Mabswid
.3924 .54577 m
.40398 .53991 L
s
.10029 .53636 m
.11282 .53201 L
s
.17021 .53612 m
.17315 .53868 L
s
.23568 .56491 m
.23532 .56816 L
s
.18097 .61827 m
.19369 .61447 L
s
.14236 .53496 m
.14533 .53751 L
s
.1937 .60618 m
.19324 .60943 L
s
.33875 .54146 m
.34207 .54363 L
s
.25627 .5456 m
.25597 .54886 L
s
.27675 .52611 m
.2765 .52937 L
s
.27877 .53849 m
.28157 .54107 L
s
.32024 .48399 m
.31965 .48727 L
s
.30732 .53947 m
.3105 .5419 L
s
.37004 .54196 m
.37348 .5439 L
s
.21456 .58727 m
.21415 .59053 L
s
.2981 .5062 m
.29763 .50953 L
s
.2509 .53722 m
.25374 .53979 L
s
.22303 .53597 m
.2259 .53854 L
s
.23532 .56816 m
.23495 .57142 L
s
.19515 .53475 m
.19806 .53732 L
s
.25597 .54886 m
.25565 .55212 L
s
.16727 .53357 m
.17021 .53612 L
s
.3355 .53926 m
.33875 .54146 L
s
.31965 .48727 m
.31908 .49053 L
s
.2765 .52937 m
.27623 .53264 L
s
.13938 .5324 m
.14236 .53496 L
s
.21415 .59053 m
.21372 .59379 L
s
.36668 .54 m
.37004 .54196 L
s
.34506 .46328 m
.35812 .45985 L
s
.29763 .50953 m
.29719 .51286 L
s
.30423 .53702 m
.30732 .53947 L
s
.23495 .57142 m
.23458 .57469 L
s
.27596 .53591 m
.27877 .53849 L
s
.24806 .53464 m
.2509 .53722 L
s
.25565 .55212 m
.25533 .55539 L
s
.31908 .49053 m
.31855 .49379 L
s
.22015 .5334 m
.22303 .53597 L
s
.34157 .46892 m
.34092 .47212 L
s
.27623 .53264 m
.27596 .53591 L
s
.21372 .59379 m
.21329 .59706 L
s
.33234 .53702 m
.3355 .53926 L
s
.19223 .53219 m
.19515 .53475 L
s
.29719 .51286 m
.29679 .51619 L
s
.11282 .53201 m
.1254 .52765 L
s
.3634 .53801 m
.36668 .54 L
s
.16432 .531 m
.16727 .53357 L
s
.19369 .61447 m
.20647 .61064 L
s
.23458 .57469 m
.23419 .57797 L
s
.1364 .52984 m
.13938 .5324 L
s
.25533 .55539 m
.25499 .55868 L
s
.31855 .49379 m
.31805 .49705 L
s
.34092 .47212 m
.3403 .47531 L
s
.30122 .53452 m
.30423 .53702 L
s
.27314 .53332 m
.27596 .53591 L
s
.27596 .53591 m
.27567 .53919 L
s
.21329 .59706 m
.21284 .60035 L
s
.40398 .53991 m
.41563 .53401 L
s
.29679 .51619 m
.29641 .5195 L
s
.2452 .53206 m
.24806 .53464 L
s
.39421 .53755 m
.39758 .53932 L
s
.32926 .53475 m
.33234 .53702 L
s
.36019 .53598 m
.3634 .53801 L
s
.21726 .53082 m
.22015 .5334 L
s
.23419 .57797 m
.2338 .58125 L
s
.18931 .52961 m
.19223 .53219 L
s
0 g
.5 Mabswid
.32918 .62773 m
.31634 .63095 L
s
.039 .916 .04 r
1 Mabswid
.3403 .47531 m
.33971 .4785 L
s
.31805 .49705 m
.31757 .5003 L
s
.25499 .55868 m
.25464 .56196 L
s
.16135 .52843 m
.16432 .531 L
s
.21284 .60035 m
.21239 .60364 L
s
.27567 .53919 m
.27538 .54248 L
s
.29641 .5195 m
.29607 .52281 L
s
.39091 .53575 m
.39421 .53755 L
s
.2983 .53199 m
.30122 .53452 L
s
.35812 .45985 m
.37124 .4564 L
s
.2338 .58125 m
.23339 .58455 L
s
.27031 .53073 m
.27314 .53332 L
s
.35707 .53392 m
.36019 .53598 L
s
.33971 .4785 m
.33914 .48168 L
s
.31757 .5003 m
.31713 .50354 L
s
.32627 .53245 m
.32926 .53475 L
s
.24233 .52947 m
.2452 .53206 L
s
.25464 .56196 m
.25429 .56526 L
s
.21436 .52824 m
.21726 .53082 L
s
.27538 .54248 m
.27507 .54578 L
s
.1254 .52765 m
.13804 .52326 L
s
.18637 .52703 m
.18931 .52961 L
s
.29607 .52281 m
.29575 .52612 L
s
.15838 .52586 m
.16135 .52843 L
s
.38769 .53392 m
.39091 .53575 L
s
.20647 .61064 m
.2193 .6068 L
s
.23339 .58455 m
.23298 .58785 L
s
.33914 .48168 m
.33861 .48486 L
s
.31713 .50354 m
.31672 .50678 L
s
.35402 .53183 m
.35707 .53392 L
s
.29547 .52942 m
.2983 .53199 L
s
.25429 .56526 m
.25392 .56857 L
s
.26747 .52814 m
.27031 .53073 L
s
.32335 .53011 m
.32627 .53245 L
s
.27507 .54578 m
.27476 .54909 L
s
.23946 .52688 m
.24233 .52947 L
s
.29575 .52612 m
.29547 .52942 L
s
.38453 .53207 m
.38769 .53392 L
s
.33861 .48486 m
.3381 .48803 L
s
.23298 .58785 m
.23255 .59116 L
s
.21145 .52565 m
.21436 .52824 L
s
.18343 .52445 m
.18637 .52703 L
s
.31672 .50678 m
.31634 .51002 L
s
.36109 .46366 m
.36047 .46677 L
s
.1554 .52328 m
.15838 .52586 L
s
0 g
.5 Mabswid
.2933 .53015 m
.29098 .55862 L
s
.2933 .53015 m
.27388 .51217 L
s
.039 .916 .04 r
1 Mabswid
.25392 .56857 m
.25355 .57188 L
s
.41563 .53401 m
.42735 .52809 L
s
.35105 .52971 m
.35402 .53183 L
s
.27476 .54909 m
.27443 .5524 L
s
.29547 .52942 m
.29522 .53272 L
s
.29272 .52682 m
.29547 .52942 L
s
0 g
.5 Mabswid
.80628 .43358 m
.78728 .45304 L
s
.82874 .41797 m
.80628 .43358 L
s
.039 .916 .04 r
1 Mabswid
.3381 .48803 m
.33762 .4912 L
s
.32052 .52774 m
.32335 .53011 L
s
.38146 .53018 m
.38453 .53207 L
s
.23255 .59116 m
.23212 .59448 L
s
.26462 .52554 m
.26747 .52814 L
s
.36047 .46677 m
.35987 .46987 L
s
.37124 .4564 m
.38443 .45294 L
s
.31634 .51002 m
.31598 .51324 L
s
0 g
.5 Mabswid
.78728 .45304 m
.77294 .47512 L
s
.039 .916 .04 r
1 Mabswid
.23658 .52428 m
.23946 .52688 L
s
.25355 .57188 m
.25316 .5752 L
s
.20853 .52306 m
.21145 .52565 L
s
.13804 .52326 m
.15074 .51886 L
s
.18047 .52186 m
.18343 .52445 L
s
.27443 .5524 m
.2741 .55573 L
s
.34816 .52756 m
.35105 .52971 L
s
.33762 .4912 m
.33718 .49436 L
s
.29522 .53272 m
.295 .53601 L
s
.2193 .6068 m
.2322 .60295 L
s
.35987 .46987 m
.35931 .47297 L
s
.23212 .59448 m
.23167 .5978 L
s
.37845 .52827 m
.38146 .53018 L
s
.31598 .51324 m
.31566 .51646 L
s
.41156 .52923 m
.41471 .53089 L
s
.31778 .52533 m
.32052 .52774 L
s
.29007 .52418 m
.29272 .52682 L
s
.25316 .5752 m
.25277 .57853 L
s
.26177 .52293 m
.26462 .52554 L
s
.2741 .55573 m
.27375 .55906 L
s
.33718 .49436 m
.33676 .49751 L
s
.23369 .52168 m
.23658 .52428 L
s
.35931 .47297 m
.35877 .47606 L
s
0 g
.5 Mabswid
.85325 .4072 m
.82874 .41797 L
s
.039 .916 .04 r
1 Mabswid
.295 .53601 m
.29481 .53929 L
s
.34534 .52538 m
.34816 .52756 L
s
.2056 .52046 m
.20853 .52306 L
s
.37553 .52632 m
.37845 .52827 L
s
.31566 .51646 m
.31537 .51968 L
s
.17751 .51927 m
.18047 .52186 L
s
.40848 .52754 m
.41156 .52923 L
s
.25277 .57853 m
.25236 .58187 L
s
0 g
.5 Mabswid
.24623 .44046 m
.25724 .43209 L
s
.77294 .47512 m
.76419 .49841 L
s
.039 .916 .04 r
1 Mabswid
.33676 .49751 m
.33637 .50066 L
s
.35877 .47606 m
.35827 .47915 L
s
.31511 .52289 m
.31778 .52533 L
s
.27375 .55906 m
.2734 .5624 L
s
.2875 .5215 m
.29007 .52418 L
s
.29481 .53929 m
.29465 .54257 L
s
.2589 .52032 m
.26177 .52293 L
s
.31537 .51968 m
.31511 .52289 L
s
.40547 .52582 m
.40848 .52754 L
s
.42735 .52809 m
.43913 .52213 L
s
.34261 .52316 m
.34534 .52538 L
s
.37267 .52435 m
.37553 .52632 L
s
.23078 .51907 m
.23369 .52168 L
s
.38443 .45294 m
.39768 .44945 L
s
.25236 .58187 m
.25195 .58521 L
s
.15074 .51886 m
.16349 .51443 L
s
.20266 .51786 m
.2056 .52046 L
s
.35827 .47915 m
.35779 .48223 L
s
.33637 .50066 m
.33602 .5038 L
s
.17454 .51667 m
.17751 .51927 L
s
.2734 .5624 m
.27303 .56575 L
s
.2322 .60295 m
.24515 .59907 L
s
.38075 .45837 m
.38015 .46138 L
s
.29465 .54257 m
.29453 .54585 L
s
.40253 .52407 m
.40547 .52582 L
s
.31511 .52289 m
.31488 .5261 L
s
.31253 .52042 m
.31511 .52289 L
s
.36989 .52235 m
.37267 .52435 L
s
.25195 .58521 m
.25152 .58857 L
s
.28501 .51878 m
.2875 .5215 L
s
.35779 .48223 m
.35734 .48531 L
s
.33996 .52091 m
.34261 .52316 L
s
.33602 .5038 m
.33569 .50694 L
s
.25603 .5177 m
.2589 .52032 L
s
.27303 .56575 m
.27266 .5691 L
s
.38015 .46138 m
.37959 .4644 L
s
.22787 .51646 m
.23078 .51907 L
s
.19972 .51525 m
.20266 .51786 L
s
.39966 .5223 m
.40253 .52407 L
s
.29453 .54585 m
.29444 .54912 L
s
.31488 .5261 m
.31468 .5293 L
s
.35734 .48531 m
.35692 .48838 L
s
.25152 .58857 m
.25109 .59193 L
s
.36719 .52032 m
.36989 .52235 L
s
.33569 .50694 m
.33539 .51007 L
s
.31003 .5179 m
.31253 .52042 L
s
.37959 .4644 m
.37905 .4674 L
s
.27266 .5691 m
.27227 .57247 L
s
.33738 .51863 m
.33996 .52091 L
s
0 g
.5 Mabswid
.87826 .40201 m
.85325 .4072 L
s
.85325 .4072 m
.85325 .4072 L
s
.85325 .4072 m
.85477 .43496 L
s
.039 .916 .04 r
1 Mabswid
.28262 .51602 m
.28501 .51878 L
s
.39686 .5205 m
.39966 .5223 L
s
.25314 .51508 m
.25603 .5177 L
s
.31468 .5293 m
.31452 .53249 L
s
.29444 .54912 m
.29438 .55238 L
s
.35692 .48838 m
.35653 .49144 L
s
.16349 .51443 m
.1763 .50999 L
s
.22495 .51384 m
.22787 .51646 L
s
.37905 .4674 m
.37855 .4704 L
s
.33539 .51007 m
.33512 .5132 L
s
.19676 .51263 m
.19972 .51525 L
s
.39768 .44945 m
.411 .44595 L
s
.42905 .52084 m
.43198 .5224 L
s
.36456 .51825 m
.36719 .52032 L
s
.27227 .57247 m
.27188 .57584 L
s
.24515 .59907 m
.25816 .59518 L
s
0 g
.5 Mabswid
.31634 .63095 m
.30169 .62725 L
s
.039 .916 .04 r
1 Mabswid
.43913 .52213 m
.45099 .51613 L
s
.30762 .51536 m
.31003 .5179 L
s
.33488 .51632 m
.33738 .51863 L
s
.39413 .51867 m
.39686 .5205 L
s
.35653 .49144 m
.35616 .4945 L
s
.31452 .53249 m
.31438 .53568 L
s
0 g
.5 Mabswid
.76419 .49841 m
.76167 .52145 L
s
.039 .916 .04 r
1 Mabswid
.29438 .55238 m
.29435 .55564 L
s
.37855 .4704 m
.37807 .4734 L
s
.33512 .5132 m
.33488 .51632 L
s
.42619 .51925 m
.42905 .52084 L
s
.28031 .51323 m
.28262 .51602 L
s
.25025 .51245 m
.25314 .51508 L
s
.27188 .57584 m
.27147 .57923 L
s
.22203 .51122 m
.22495 .51384 L
s
.362 .51616 m
.36456 .51825 L
s
.1938 .51002 m
.19676 .51263 L
s
.35616 .4945 m
.35583 .49755 L
s
.37807 .4734 m
.37761 .47639 L
s
.39147 .51681 m
.39413 .51867 L
s
.31438 .53568 m
.31427 .53887 L
s
0 g
.5 Mabswid
.29098 .55862 m
.28863 .58748 L
s
.039 .916 .04 r
1 Mabswid
.29435 .55564 m
.29435 .5589 L
s
.42339 .51764 m
.42619 .51925 L
s
.33488 .51632 m
.33467 .51944 L
s
.33247 .51397 m
.33488 .51632 L
s
.30529 .51278 m
.30762 .51536 L
s
.40054 .45303 m
.39998 .45596 L
s
.27147 .57923 m
.27106 .58262 L
s
.35583 .49755 m
.35552 .5006 L
s
.37761 .47639 m
.37719 .47937 L
s
.35952 .51404 m
.362 .51616 L
s
.24735 .50982 m
.25025 .51245 L
s
.1763 .50999 m
.18916 .50553 L
s
.38888 .51493 m
.39147 .51681 L
s
.27809 .51039 m
.28031 .51323 L
s
.31427 .53887 m
.3142 .54205 L
s
.21909 .50859 m
.22203 .51122 L
s
.42066 .51601 m
.42339 .51764 L
s
.33467 .51944 m
.3345 .52255 L
s
.29435 .5589 m
.29438 .56215 L
s
.39998 .45596 m
.39945 .45888 L
s
.411 .44595 m
.42438 .44244 L
s
0 g
.5 Mabswid
.27388 .51217 m
.25416 .4939 L
s
.039 .916 .04 r
1 Mabswid
.33013 .51159 m
.33247 .51397 L
s
.25816 .59518 m
.27123 .59127 L
s
.27106 .58262 m
.27063 .58601 L
s
.37719 .47937 m
.3768 .48235 L
s
.35552 .5006 m
.35525 .50364 L
s
.30304 .51016 m
.30529 .51278 L
s
.418 .51435 m
.42066 .51601 L
s
.35712 .51189 m
.35952 .51404 L
s
.38636 .51302 m
.38888 .51493 L
s
.39945 .45888 m
.39894 .46179 L
s
.3142 .54205 m
.31415 .54522 L
s
.3345 .52255 m
.33435 .52565 L
s
.29438 .56215 m
.29445 .56539 L
s
.24444 .50718 m
.24735 .50982 L
s
.45099 .51613 m
.46291 .5101 L
s
.3768 .48235 m
.37643 .48532 L
s
.21614 .50596 m
.21909 .50859 L
s
.35525 .50364 m
.355 .50667 L
s
.27596 .50752 m
.27809 .51039 L
s
.39894 .46179 m
.39846 .4647 L
s
.32787 .50918 m
.33013 .51159 L
s
.4154 .51266 m
.418 .51435 L
s
.31415 .54522 m
.31414 .54839 L
s
.38391 .51108 m
.38636 .51302 L
s
.33435 .52565 m
.33423 .52875 L
s
.35479 .5097 m
.35712 .51189 L
s
.30088 .5075 m
.30304 .51016 L
s
.37643 .48532 m
.37609 .48829 L
s
.29445 .56539 m
.29455 .56863 L
s
0 g
.5 Mabswid
.90214 .40281 m
.87826 .40201 L
s
.039 .916 .04 r
1 Mabswid
.355 .50667 m
.35479 .5097 L
s
.39846 .4647 m
.39801 .46761 L
s
.18916 .50553 m
.20209 .50104 L
s
.44669 .51238 m
.44939 .51383 L
s
.41287 .51095 m
.4154 .51266 L
s
.24152 .50454 m
.24444 .50718 L
s
.21319 .50332 m
.21614 .50596 L
s
.33423 .52875 m
.33414 .53184 L
s
.31414 .54839 m
.31416 .55156 L
s
.38153 .50911 m
.38391 .51108 L
s
.37609 .48829 m
.37578 .49125 L
s
.32569 .50674 m
.32787 .50918 L
s
.27392 .50461 m
.27596 .50752 L
s
.35479 .5097 m
.3546 .51273 L
s
.35253 .50749 m
.35479 .5097 L
s
.39801 .46761 m
.39758 .47051 L
s
.27123 .59127 m
.28436 .58734 L
s
.29455 .56863 m
.29468 .57187 L
s
.44405 .51091 m
.44669 .51238 L
s
.42438 .44244 m
.43782 .4389 L
s
0 g
.5 Mabswid
.23831 .45518 m
.24623 .44046 L
s
.039 .916 .04 r
1 Mabswid
.2988 .50481 m
.30088 .5075 L
s
.4104 .50922 m
.41287 .51095 L
s
.42049 .44766 m
.41995 .45049 L
s
.37578 .49125 m
.3755 .49421 L
s
.33414 .53184 m
.33409 .53493 L
s
0 g
.5 Mabswid
.76167 .52145 m
.76561 .54272 L
s
.76167 .52145 m
.79342 .51162 L
s
.76167 .52145 m
.76167 .52145 L
s
.039 .916 .04 r
1 Mabswid
.31416 .55156 m
.31421 .55472 L
s
.39758 .47051 m
.39718 .4734 L
s
.37922 .50712 m
.38153 .50911 L
s
.23859 .50189 m
.24152 .50454 L
s
.3546 .51273 m
.35444 .51575 L
s
.44146 .50941 m
.44405 .51091 L
s
.29468 .57187 m
.29484 .5751 L
s
.32359 .50426 m
.32569 .50674 L
s
.35035 .50524 m
.35253 .50749 L
s
.408 .50746 m
.4104 .50922 L
s
.41995 .45049 m
.41945 .45332 L
s
.27197 .50166 m
.27392 .50461 L
s
.3755 .49421 m
.37524 .49716 L
s
.39718 .4734 m
.39681 .47629 L
s
.33409 .53493 m
.33406 .53802 L
s
.46291 .5101 m
.47491 .50403 L
s
.43894 .50789 m
.44146 .50941 L
s
.31421 .55472 m
.31429 .55787 L
s
.29681 .50208 m
.2988 .50481 L
s
.35444 .51575 m
.35431 .51876 L
s
.37699 .50509 m
.37922 .50712 L
s
0 g
.5 Mabswid
.85477 .43496 m
.85631 .46312 L
s
.039 .916 .04 r
1 Mabswid
.41945 .45332 m
.41897 .45615 L
s
.20209 .50104 m
.21507 .49654 L
s
.29484 .5751 m
.29504 .57832 L
s
.40566 .50567 m
.408 .50746 L
s
.23565 .49923 m
.23859 .50189 L
s
.37524 .49716 m
.37502 .5001 L
s
.39681 .47629 m
.39647 .47917 L
s
.34825 .50297 m
.35035 .50524 L
s
.32157 .50174 m
.32359 .50426 L
s
.43648 .50634 m
.43894 .50789 L
s
.33406 .53802 m
.33406 .5411 L
s
.35431 .51876 m
.35421 .52177 L
s
.31429 .55787 m
.31441 .56102 L
s
.28436 .58734 m
.29762 .58245 L
s
.41897 .45615 m
.41851 .45896 L
s
.37482 .50304 m
.37699 .50509 L
s
.27011 .49867 m
.27197 .50166 L
s
.4034 .50385 m
.40566 .50567 L
s
.39647 .47917 m
.39615 .48204 L
s
.37502 .5001 m
.37482 .50304 L
s
.43782 .4389 m
.45134 .43535 L
s
.2949 .49932 m
.29681 .50208 L
s
.43409 .50477 m
.43648 .50634 L
s
.33406 .5411 m
.3341 .54417 L
s
.41851 .45896 m
.41809 .46178 L
s
.34622 .50066 m
.34825 .50297 L
s
.35421 .52177 m
.35414 .52477 L
s
.23271 .49657 m
.23565 .49923 L
s
.31441 .56102 m
.31455 .56416 L
s
.31964 .4992 m
.32157 .50174 L
s
.39615 .48204 m
.39586 .48491 L
s
.37482 .50304 m
.37465 .50598 L
s
.37272 .50096 m
.37482 .50304 L
s
.40119 .50201 m
.4034 .50385 L
s
0 g
.5 Mabswid
.30169 .62725 m
.28625 .61674 L
s
.039 .916 .04 r
1 Mabswid
.43175 .50318 m
.43409 .50477 L
s
0 g
.5 Mabswid
.28863 .58748 m
.28625 .61674 L
s
.039 .916 .04 r
1 Mabswid
.41809 .46178 m
.41769 .46458 L
s
.46447 .50385 m
.46695 .5052 L
s
.3341 .54417 m
.33416 .54724 L
s
.35414 .52477 m
.3541 .52777 L
s
.26833 .49564 m
.27011 .49867 L
s
.29308 .49652 m
.2949 .49932 L
s
.31455 .56416 m
.31473 .5673 L
s
.39586 .48491 m
.3956 .48778 L
s
.21507 .49654 m
.22811 .49202 L
s
.34426 .49832 m
.34622 .50066 L
s
.37465 .50598 m
.37451 .50891 L
s
.42948 .50157 m
.43175 .50318 L
s
.39906 .50015 m
.40119 .50201 L
s
.44058 .44224 m
.44007 .44499 L
s
.41769 .46458 m
.41731 .46738 L
s
.3707 .49885 m
.37272 .50096 L
s
.46205 .50249 m
.46447 .50385 L
s
.31778 .49661 m
.31964 .4992 L
s
.47491 .50403 m
.48697 .49793 L
s
.29762 .58245 m
.31098 .57706 L
s
.3541 .52777 m
.35409 .53077 L
s
.33416 .54724 m
.33426 .5503 L
s
.3956 .48778 m
.39537 .49064 L
s
.44007 .44499 m
.43959 .44772 L
s
.37451 .50891 m
.3744 .51183 L
s
.31473 .5673 m
.31493 .57044 L
s
.42726 .49993 m
.42948 .50157 L
s
.41731 .46738 m
.41697 .47018 L
s
.45968 .5011 m
.46205 .50249 L
s
0 g
.5 Mabswid
.92331 .40966 m
.90214 .40281 L
s
.039 .916 .04 r
1 Mabswid
.39699 .49826 m
.39906 .50015 L
s
.34239 .49595 m
.34426 .49832 L
s
.29134 .49368 m
.29308 .49652 L
s
.45134 .43535 m
.46492 .43178 L
s
.26665 .49257 m
.26833 .49564 L
s
.36875 .49671 m
.3707 .49885 L
s
.35409 .53077 m
.35411 .53375 L
s
.39537 .49064 m
.39517 .49349 L
s
.33426 .5503 m
.33438 .55336 L
s
.43959 .44772 m
.43914 .45046 L
s
.316 .494 m
.31778 .49661 L
s
.45737 .4997 m
.45968 .5011 L
s
.41697 .47018 m
.41665 .47297 L
s
.3744 .51183 m
.37432 .51475 L
s
.42511 .49826 m
.42726 .49993 L
s
0 g
.5 Mabswid
.79342 .51162 m
.82549 .50169 L
s
.25416 .4939 m
.23412 .47533 L
s
.039 .916 .04 r
1 Mabswid
.39499 .49634 m
.39699 .49826 L
s
.43914 .45046 m
.43871 .45318 L
s
.39517 .49349 m
.39499 .49634 L
s
.35411 .53375 m
.35416 .53674 L
s
.45511 .49827 m
.45737 .4997 L
s
.34058 .49355 m
.34239 .49595 L
s
.41665 .47297 m
.41635 .47575 L
s
.36687 .49455 m
.36875 .49671 L
s
.33438 .55336 m
.33454 .55641 L
s
.22811 .49202 m
.2412 .48747 L
s
.37432 .51475 m
.37427 .51766 L
s
.42302 .49658 m
.42511 .49826 L
s
.31098 .57706 m
.32439 .57166 L
s
.28969 .4908 m
.29134 .49368 L
s
0 g
.5 Mabswid
.76561 .54272 m
.77588 .56079 L
s
.039 .916 .04 r
1 Mabswid
.26506 .48946 m
.26665 .49257 L
s
.43871 .45318 m
.43831 .4559 L
s
.3143 .49135 m
.316 .494 L
s
.45292 .49682 m
.45511 .49827 L
s
.39499 .49634 m
.39484 .49918 L
s
.39305 .49439 m
.39499 .49634 L
s
.41635 .47575 m
.41609 .47853 L
s
.35416 .53674 m
.35423 .53971 L
s
.79831 .49966 m
.80245 .50882 L
s
.37427 .51766 m
.37424 .52057 L
s
.33454 .55641 m
.33473 .55946 L
s
.421 .49487 m
.42302 .49658 L
s
.36506 .49235 m
.36687 .49455 L
s
.43831 .4559 m
.43794 .45861 L
s
.33886 .49111 m
.34058 .49355 L
s
.48697 .49793 m
.49911 .49179 L
s
.45078 .49535 m
.45292 .49682 L
s
.39484 .49918 m
.39472 .50202 L
s
.41609 .47853 m
.41585 .4813 L
s
.39118 .49242 m
.39305 .49439 L
s
.46492 .43178 m
.47857 .42819 L
s
.35423 .53971 m
.35434 .54269 L
s
0 g
.5 Mabswid
.23412 .47533 m
.23831 .45518 L
s
.039 .916 .04 r
1 Mabswid
.28812 .48789 m
.28969 .4908 L
s
.37424 .52057 m
.37425 .52347 L
s
.41903 .49313 m
.421 .49487 L
s
.43794 .45861 m
.43759 .46132 L
s
.31269 .48866 m
.3143 .49135 L
s
.33473 .55946 m
.33495 .56251 L
s
.46081 .43679 m
.46034 .43944 L
s
.4824 .49525 m
.48466 .49649 L
s
.26356 .48631 m
.26506 .48946 L
s
.4487 .49386 m
.45078 .49535 L
s
.41585 .4813 m
.41563 .48407 L
s
.36332 .49013 m
.36506 .49235 L
s
.39472 .50202 m
.39462 .50485 L
s
.33721 .48865 m
.33886 .49111 L
s
.32439 .57166 m
.33785 .56623 L
s
.43759 .46132 m
.43726 .46403 L
s
.38938 .49042 m
.39118 .49242 L
s
.35434 .54269 m
.35448 .54565 L
s
.46034 .43944 m
.45989 .44209 L
s
.4802 .494 m
.4824 .49525 L
s
.37425 .52347 m
.37428 .52637 L
s
.2412 .48747 m
.25557 .48404 L
s
.41713 .49137 m
.41903 .49313 L
s
0 g
.5 Mabswid
.85631 .46312 m
.85788 .49166 L
s
.039 .916 .04 r
1 Mabswid
.44667 .49234 m
.4487 .49386 L
s
.41563 .48407 m
.41545 .48683 L
s
.39462 .50485 m
.39456 .50768 L
s
.28664 .48494 m
.28812 .48789 L
s
.31116 .48594 m
.31269 .48866 L
s
.43726 .46403 m
.43697 .46672 L
s
.47804 .49273 m
.4802 .494 L
s
.45989 .44209 m
.45946 .44472 L
s
.36165 .48787 m
.36332 .49013 L
s
.35448 .54565 m
.35465 .54862 L
s
.37428 .52637 m
.37434 .52926 L
s
.4447 .49081 m
.44667 .49234 L
s
.41529 .48959 m
.41713 .49137 L
s
.38765 .4884 m
.38938 .49042 L
s
.33564 .48615 m
.33721 .48865 L
s
.41545 .48683 m
.41529 .48959 L
s
.39456 .50768 m
.39452 .5105 L
s
.47594 .49144 m
.47804 .49273 L
s
.45946 .44472 m
.45906 .44736 L
s
.43697 .46672 m
.43669 .46942 L
s
.44279 .48925 m
.4447 .49081 L
s
.37434 .52926 m
.37443 .53214 L
s
.35465 .54862 m
.35485 .55157 L
s
.41351 .48778 m
.41529 .48959 L
s
.41529 .48959 m
.41516 .49234 L
s
.36006 .48558 m
.36165 .48787 L
s
.47389 .49013 m
.47594 .49144 L
s
.47857 .42819 m
.49229 .42459 L
s
.45906 .44736 m
.45868 .44998 L
s
.38598 .48634 m
.38765 .4884 L
s
.3097 .48318 m
.31116 .48594 L
s
.39452 .5105 m
.39451 .51331 L
s
.43669 .46942 m
.43645 .4721 L
s
.25557 .48404 m
.2706 .48115 L
s
.49911 .49179 m
.51132 .48562 L
s
.28525 .48194 m
.28664 .48494 L
s
.33785 .56623 m
.35137 .56079 L
s
0 g
.5 Mabswid
.28625 .61674 m
.2711 .60004 L
s
.28625 .61674 m
.28625 .61674 L
s
.039 .916 .04 r
1 Mabswid
.33414 .48362 m
.33564 .48615 L
s
0 g
.5 Mabswid
.82549 .50169 m
.85788 .49166 L
s
.039 .916 .04 r
1 Mabswid
.44094 .48767 m
.44279 .48925 L
s
.4719 .4888 m
.47389 .49013 L
s
.41516 .49234 m
.41506 .49509 L
s
.45868 .44998 m
.45833 .45261 L
s
.37443 .53214 m
.37455 .53503 L
s
.35485 .55157 m
.35508 .55453 L
s
.4118 .48595 m
.41351 .48778 L
s
.43645 .4721 m
.43623 .47478 L
s
.39451 .51331 m
.39453 .51612 L
s
.79413 .49043 m
.79831 .49966 L
s
.35854 .48327 m
.36006 .48558 L
s
.38438 .48426 m
.38598 .48634 L
s
.46995 .48746 m
.4719 .4888 L
s
0 g
.5 Mabswid
.94029 .42219 m
.92331 .40966 L
s
.039 .916 .04 r
1 Mabswid
.43915 .48606 m
.44094 .48767 L
s
.45833 .45261 m
.458 .45522 L
s
.41506 .49509 m
.41498 .49783 L
s
.30833 .48039 m
.3097 .48318 L
s
.43623 .47478 m
.43604 .47746 L
s
.37455 .53503 m
.3747 .5379 L
s
.33273 .48105 m
.33414 .48362 L
s
.4812 .4313 m
.48075 .43386 L
s
.41014 .48409 m
.4118 .48595 L
s
.39453 .51612 m
.39458 .51893 L
s
.2706 .48115 m
.28567 .47826 L
s
.46806 .48609 m
.46995 .48746 L
s
.458 .45522 m
.4577 .45783 L
s
.43741 .48444 m
.43915 .48606 L
s
.38285 .48216 m
.38438 .48426 L
s
.41498 .49783 m
.41493 .50056 L
s
.35709 .48092 m
.35854 .48327 L
s
.48075 .43386 m
.48032 .43641 L
s
.43604 .47746 m
.43587 .48013 L
s
.50048 .48658 m
.50252 .4877 L
s
.3747 .5379 m
.37488 .54077 L
s
.35137 .56079 m
.36493 .55532 L
s
.46622 .4847 m
.46806 .48609 L
s
.39458 .51893 m
.39465 .52173 L
s
.40855 .48221 m
.41014 .48409 L
s
.4577 .45783 m
.45743 .46044 L
s
.49229 .42459 m
.50607 .42096 L
s
.49849 .48545 m
.50048 .48658 L
s
.30704 .47756 m
.30833 .48039 L
s
.48032 .43641 m
.47992 .43895 L
s
.43573 .48279 m
.43741 .48444 L
s
.33139 .47845 m
.33273 .48105 L
s
.43587 .48013 m
.43573 .48279 L
s
.41493 .50056 m
.41491 .50329 L
s
.38138 .48002 m
.38285 .48216 L
s
.46444 .48329 m
.46622 .4847 L
s
0 g
.5 Mabswid
.77588 .56079 m
.79189 .57436 L
s
.039 .916 .04 r
1 Mabswid
.37488 .54077 m
.37509 .54364 L
s
.45743 .46044 m
.45718 .46304 L
s
.49655 .48429 m
.49849 .48545 L
s
.35571 .47855 m
.35709 .48092 L
s
.39465 .52173 m
.39476 .52453 L
s
.47992 .43895 m
.47955 .44149 L
s
.51132 .48562 m
.5236 .47941 L
s
.40703 .4803 m
.40855 .48221 L
s
.28567 .47826 m
.30078 .47537 L
s
.43573 .48279 m
.43562 .48545 L
s
.43411 .48112 m
.43573 .48279 L
s
.41491 .50329 m
.41491 .50601 L
s
.46271 .48186 m
.46444 .48329 L
s
.49466 .48312 m
.49655 .48429 L
s
.45718 .46304 m
.45695 .46563 L
s
.47955 .44149 m
.4792 .44403 L
s
.37509 .54364 m
.37533 .5465 L
s
.33012 .47582 m
.33139 .47845 L
s
.39476 .52453 m
.39489 .52732 L
s
0 g
.5 Mabswid
.23403 .49955 m
.23412 .47533 L
s
.23412 .47533 m
.23412 .47533 L
s
.039 .916 .04 r
1 Mabswid
.37998 .47786 m
.38138 .48002 L
s
.43562 .48545 m
.43553 .48811 L
s
.85066 .47643 m
.85756 .48592 L
s
.49282 .48193 m
.49466 .48312 L
s
.40556 .47837 m
.40703 .4803 L
s
.43255 .47943 m
.43411 .48112 L
s
.41491 .50601 m
.41495 .50873 L
s
.35441 .47614 m
.35571 .47855 L
s
.46103 .48042 m
.46271 .48186 L
s
.36493 .55532 m
.37856 .54983 L
s
.45695 .46563 m
.45675 .46822 L
s
.4792 .44403 m
.47887 .44655 L
s
.39489 .52732 m
.39505 .5301 L
s
.49102 .48073 m
.49282 .48193 L
s
.43553 .48811 m
.43547 .49075 L
s
.30078 .47537 m
.31594 .47246 L
s
.37865 .47567 m
.37998 .47786 L
s
.4594 .47895 m
.46103 .48042 L
s
.41495 .50873 m
.41501 .51145 L
s
.43104 .47772 m
.43255 .47943 L
s
.47887 .44655 m
.47856 .44908 L
s
.45675 .46822 m
.45658 .4708 L
s
.40416 .47641 m
.40556 .47837 L
s
.32894 .47316 m
.33012 .47582 L
s
.78992 .48112 m
.79413 .49043 L
s
.50607 .42096 m
.51993 .41732 L
s
.48927 .4795 m
.49102 .48073 L
s
.35318 .4737 m
.35441 .47614 L
s
.50174 .42577 m
.50131 .42823 L
s
.39505 .5301 m
.39524 .53288 L
s
.43547 .49075 m
.43543 .4934 L
s
.47856 .44908 m
.47829 .45159 L
s
.45783 .47746 m
.4594 .47895 L
s
0 0 0 r
.85788 .49166 m
.85788 .49166 L
s
0 g
.5 Mabswid
.85788 .49166 m
.85946 .52061 L
s
.85788 .49166 m
.89059 .48154 L
s
.039 .916 .04 r
1 Mabswid
.45658 .4708 m
.45643 .47338 L
s
.41501 .51145 m
.41509 .51416 L
s
.42959 .47598 m
.43104 .47772 L
s
.48757 .47826 m
.48927 .4795 L
s
.37739 .47345 m
.37865 .47567 L
s
.50131 .42823 m
.50091 .43069 L
s
.80115 .48865 m
.7976 .48903 L
s
.40282 .47443 m
.40416 .47641 L
s
0 g
.5 Mabswid
.2711 .60004 m
.25737 .57828 L
s
.039 .916 .04 r
1 Mabswid
.80466 .48822 m
.80115 .48865 L
s
.47829 .45159 m
.47803 .45411 L
s
.43543 .4934 m
.43543 .49604 L
s
.39524 .53288 m
.39546 .53566 L
s
.45631 .47595 m
.45783 .47746 L
s
.45643 .47338 m
.45631 .47595 L
s
.48592 .477 m
.48757 .47826 L
s
.5236 .47941 m
.53595 .47316 L
s
.80815 .48775 m
.80466 .48822 L
s
.41509 .51416 m
.41521 .51686 L
s
.37856 .54983 m
.39223 .54431 L
s
.35202 .47124 m
.35318 .4737 L
s
.50091 .43069 m
.50054 .43314 L
s
.31594 .47246 m
.33115 .46954 L
s
.4282 .47422 m
.42959 .47598 L
s
.51871 .47784 m
.52053 .47884 L
s
.8116 .48725 m
.80815 .48775 L
s
.47803 .45411 m
.4778 .45661 L
s
.40155 .47242 m
.40282 .47443 L
s
.43543 .49604 m
.43545 .49867 L
s
.48432 .47572 m
.48592 .477 L
s
.3762 .4712 m
.37739 .47345 L
s
.45631 .47595 m
.45621 .47852 L
s
.45484 .47442 m
.45631 .47595 L
s
.81502 .4867 m
.8116 .48725 L
s
.51694 .47682 m
.51871 .47784 L
s
.50054 .43314 m
.50019 .43558 L
s
.39546 .53566 m
.39571 .53843 L
s
.85139 .49011 m
.85819 .49742 L
s
.41521 .51686 m
.41535 .51956 L
s
.81842 .48611 m
.81502 .4867 L
s
.42687 .47244 m
.4282 .47422 L
s
.4778 .45661 m
.4776 .45911 L
s
.51522 .47579 m
.51694 .47682 L
s
.48276 .47443 m
.48432 .47572 L
s
.43545 .49867 m
.43549 .5013 L
s
.50019 .43558 m
.49986 .43802 L
s
.35093 .46874 m
.35202 .47124 L
s
.45621 .47852 m
.45614 .48108 L
s
.82178 .48549 m
.81842 .48611 L
s
.45343 .47287 m
.45484 .47442 L
s
.84371 .46687 m
.85066 .47643 L
s
.40033 .47039 m
.40155 .47242 L
s
.51993 .41732 m
.53385 .41366 L
s
.51354 .47473 m
.51522 .47579 L
s
.41535 .51956 m
.41552 .52225 L
s
.82511 .48482 m
.82178 .48549 L
s
.37507 .46893 m
.3762 .4712 L
s
.4776 .45911 m
.47742 .46161 L
s
.48126 .47311 m
.48276 .47443 L
s
.33115 .46954 m
.3464 .46662 L
s
.49986 .43802 m
.49955 .44046 L
s
.4256 .47063 m
.42687 .47244 L
s
0 g
.5 Mabswid
.95182 .43967 m
.94029 .42219 L
s
.039 .916 .04 r
1 Mabswid
.45614 .48108 m
.45609 .48364 L
s
.43549 .5013 m
.43556 .50392 L
s
.82841 .48411 m
.82511 .48482 L
s
.45207 .47131 m
.45343 .47287 L
s
.5119 .47367 m
.51354 .47473 L
s
.39223 .54431 m
.40596 .53878 L
s
.47742 .46161 m
.47726 .4641 L
s
.4798 .47178 m
.48126 .47311 L
s
.41552 .52225 m
.41572 .52494 L
s
.83168 .48337 m
.82841 .48411 L
s
0 g
.5 Mabswid
.23811 .5261 m
.23403 .49955 L
s
.039 .916 .04 r
1 Mabswid
.39918 .46833 m
.40033 .47039 L
s
.49955 .44046 m
.49927 .44289 L
s
.5103 .47259 m
.5119 .47367 L
s
.45609 .48364 m
.45607 .48619 L
s
.42438 .4688 m
.4256 .47063 L
s
.43556 .50392 m
.43566 .50654 L
s
.37401 .46663 m
.37507 .46893 L
s
.45076 .46972 m
.45207 .47131 L
s
.83492 .48258 m
.83168 .48337 L
s
.47726 .4641 m
.47713 .46659 L
s
.47839 .47043 m
.4798 .47178 L
s
.52243 .42019 m
.52203 .42256 L
s
.49927 .44289 m
.49901 .44531 L
s
.50875 .47149 m
.5103 .47259 L
s
.53595 .47316 m
.54838 .46687 L
s
.41572 .52494 m
.41595 .52762 L
s
.83813 .48175 m
.83492 .48258 L
s
.78567 .47173 m
.78992 .48112 L
s
.84748 .4727 m
.84747 .4731 L
s
.45607 .48619 m
.45608 .48873 L
s
.84747 .4731 m
.84747 .47351 L
s
.3981 .46624 m
.39918 .46833 L
s
.3464 .46662 m
.3617 .46368 L
s
.43566 .50654 m
.43579 .50915 L
s
.52203 .42256 m
.52165 .42492 L
s
.44951 .4681 m
.45076 .46972 L
s
.84747 .47351 m
.84746 .47392 L
s
.42323 .46695 m
.42438 .4688 L
s
.50724 .47037 m
.50875 .47149 L
s
.47713 .46659 m
.47702 .46907 L
s
.47702 .46907 m
.47839 .47043 L
s
.49901 .44531 m
.49878 .44773 L
s
.84746 .47392 m
.84746 .47433 L
s
.84131 .48089 m
.83813 .48175 L
s
0 g
.5 Mabswid
.79189 .57436 m
.81266 .58242 L
s
.039 .916 .04 r
1 Mabswid
.84746 .47433 m
.84746 .47474 L
s
.37303 .46429 m
.37401 .46663 L
s
0 g
.5 Mabswid
.25737 .57828 m
.24609 .55301 L
s
.039 .916 .04 r
1 Mabswid
.84746 .47474 m
.84746 .47516 L
s
.41595 .52762 m
.4162 .5303 L
s
.45608 .48873 m
.45611 .49128 L
s
.84746 .47516 m
.84747 .47558 L
s
.52165 .42492 m
.5213 .42728 L
s
.50577 .46924 m
.50724 .47037 L
s
.84446 .47998 m
.84131 .48089 L
s
.84747 .47558 m
.84747 .476 L
s
.49878 .44773 m
.49857 .45014 L
s
.43579 .50915 m
.43594 .51175 L
s
.53385 .41366 m
.54785 .40998 L
s
.47702 .46907 m
.47694 .47154 L
s
.47571 .46768 m
.47702 .46907 L
s
.44831 .46647 m
.44951 .4681 L
s
.84747 .476 m
.84748 .47642 L
s
.40596 .53878 m
.41975 .53322 L
s
.39708 .46413 m
.3981 .46624 L
s
.84748 .47642 m
.84749 .47685 L
s
.42213 .46508 m
.42323 .46695 L
s
.84749 .47685 m
.84751 .47728 L
s
.50435 .4681 m
.50577 .46924 L
s
0 g
.5 Mabswid
.89059 .48154 m
.92363 .47131 L
s
.039 .916 .04 r
1 Mabswid
.5213 .42728 m
.52098 .42963 L
s
.84758 .47903 m
.84446 .47998 L
s
.84751 .47728 m
.84752 .47771 L
s
.45611 .49128 m
.45617 .49381 L
s
.5371 .46902 m
.53869 .46991 L
s
.84752 .47771 m
.84754 .47815 L
s
.49857 .45014 m
.49839 .45255 L
s
.47444 .46627 m
.47571 .46768 L
s
.47694 .47154 m
.47689 .47401 L
s
.84754 .47815 m
.84756 .47859 L
s
.84453 .48273 m
.85139 .49011 L
s
.43594 .51175 m
.43612 .51436 L
s
.84756 .47859 m
.84758 .47903 L
s
.44716 .46482 m
.44831 .46647 L
s
.83672 .45725 m
.84371 .46687 L
s
.3617 .46368 m
.37705 .46074 L
s
.50297 .46694 m
.50435 .4681 L
s
.84758 .47903 m
.84761 .47947 L
s
.85067 .47804 m
.84758 .47903 L
s
.52098 .42963 m
.52067 .43198 L
s
.53555 .46812 m
.5371 .46902 L
s
0 g
.5 Mabswid
.24609 .55301 m
.23811 .5261 L
s
.039 .916 .04 r
1 Mabswid
.84761 .47947 m
.84763 .47992 L
s
.42109 .46318 m
.42213 .46508 L
s
.84763 .47992 m
.84766 .48037 L
s
.39612 .46199 m
.39708 .46413 L
s
.49839 .45255 m
.49822 .45496 L
s
.45617 .49381 m
.45625 .49634 L
s
.84766 .48037 m
.84769 .48082 L
s
.47323 .46485 m
.47444 .46627 L
s
.47689 .47401 m
.47686 .47647 L
s
.53404 .46721 m
.53555 .46812 L
s
.84769 .48082 m
.84772 .48128 L
s
.50163 .46576 m
.50297 .46694 L
s
.85373 .47701 m
.85067 .47804 L
s
.84772 .48128 m
.84776 .48174 L
s
.43612 .51436 m
.43633 .51695 L
s
.52067 .43198 m
.52039 .43432 L
s
.84776 .48174 m
.8478 .4822 L
s
.44607 .46315 m
.44716 .46482 L
s
.8478 .4822 m
.84784 .48266 L
s
.79444 .47518 m
.79117 .47553 L
s
.53256 .46628 m
.53404 .46721 L
s
.49822 .45496 m
.49808 .45735 L
s
.84784 .48266 m
.84788 .48313 L
s
.84788 .48313 m
.84792 .4836 L
s
.45625 .49634 m
.45636 .49887 L
s
.79768 .47478 m
.79444 .47518 L
s
.50034 .46457 m
.50163 .46576 L
s
.85677 .47594 m
.85373 .47701 L
s
.47206 .46341 m
.47323 .46485 L
s
.42011 .46126 m
.42109 .46318 L
s
.47686 .47647 m
.47685 .47893 L
s
.84792 .4836 m
.84797 .48407 L
s
.52039 .43432 m
.52013 .43666 L
s
.84797 .48407 m
.84802 .48455 L
s
.54838 .46687 m
.56088 .46055 L
s
.39522 .45983 m
.39612 .46199 L
s
.80089 .47435 m
.79768 .47478 L
s
.53113 .46534 m
.53256 .46628 L
s
.84802 .48455 m
.84807 .48503 L
s
.43633 .51695 m
.43656 .51954 L
s
.41975 .53322 m
.43359 .52764 L
s
.84807 .48503 m
.84812 .48551 L
s
.44503 .46145 m
.44607 .46315 L
s
.49808 .45735 m
.49797 .45974 L
s
.84812 .48551 m
.84818 .48599 L
s
.80407 .47388 m
.80089 .47435 L
s
.37705 .46074 m
.39245 .45779 L
s
0 g
.5 Mabswid
.85946 .52061 m
.86107 .54996 L
s
.039 .916 .04 r
1 Mabswid
.49909 .46336 m
.50034 .46457 L
s
.85977 .47483 m
.85677 .47594 L
s
.52013 .43666 m
.51989 .43899 L
s
.52973 .46438 m
.53113 .46534 L
s
.45636 .49887 m
.4565 .50139 L
s
.47094 .46195 m
.47206 .46341 L
s
.47685 .47893 m
.47687 .48139 L
s
.80722 .47337 m
.80407 .47388 L
s
.54785 .40998 m
.56191 .40628 L
s
.54327 .41458 m
.5429 .41685 L
s
.41919 .45931 m
.42011 .46126 L
s
.81034 .47282 m
.80722 .47337 L
s
.43656 .51954 m
.43682 .52213 L
s
.49797 .45974 m
.49788 .46213 L
s
.52837 .46341 m
.52973 .46438 L
s
.49788 .46213 m
.49909 .46336 L
s
.86274 .47367 m
.85977 .47483 L
s
.44404 .45974 m
.44503 .46145 L
s
.51989 .43899 m
.51968 .44131 L
s
.5429 .41685 m
.54255 .41912 L
s
.81343 .47224 m
.81034 .47282 L
s
.47687 .48139 m
.47691 .48383 L
s
.46987 .46047 m
.47094 .46195 L
s
.4565 .50139 m
.45666 .5039 L
s
.78139 .46226 m
.78567 .47173 L
s
.52705 .46243 m
.52837 .46341 L
s
.8165 .47163 m
.81343 .47224 L
s
.49788 .46213 m
.49781 .46451 L
s
.49672 .46089 m
.49788 .46213 L
s
.86569 .47248 m
.86274 .47367 L
s
.51968 .44131 m
.51949 .44363 L
s
.54255 .41912 m
.54222 .42138 L
s
.41833 .45734 m
.41919 .45931 L
s
.52577 .46143 m
.52705 .46243 L
s
.44311 .458 m
.44404 .45974 L
s
.81954 .47097 m
.8165 .47163 L
s
.47691 .48383 m
.47698 .48628 L
s
.46885 .45897 m
.46987 .46047 L
s
.45666 .5039 m
.45685 .50641 L
s
.39245 .45779 m
.40789 .45482 L
s
.4956 .45963 m
.49672 .46089 L
s
.90461 .46658 m
.91426 .47421 L
s
.49781 .46451 m
.49777 .46689 L
s
.54222 .42138 m
.54192 .42364 L
s
.86861 .47124 m
.86569 .47248 L
s
.82254 .47028 m
.81954 .47097 L
s
.51949 .44363 m
.51932 .44594 L
s
.52452 .46042 m
.52577 .46143 L
s
.43359 .52764 m
.44749 .52204 L
s
.82968 .44756 m
.83672 .45725 L
s
.83707 .45853 m
.83706 .45902 L
s
.47698 .48628 m
.47707 .48871 L
s
.82553 .46955 m
.82254 .47028 L
s
.46787 .45746 m
.46885 .45897 L
s
.83706 .45902 m
.83705 .45951 L
s
.41752 .45535 m
.41833 .45734 L
s
0 g
.5 Mabswid
.95701 .46097 m
.95182 .43967 L
s
.039 .916 .04 r
1 Mabswid
.44223 .45624 m
.44311 .458 L
s
.45685 .50641 m
.45706 .50891 L
s
.49452 .45836 m
.4956 .45963 L
s
.54192 .42364 m
.54163 .42589 L
s
.52332 .45939 m
.52452 .46042 L
s
.83705 .45951 m
.83704 .46001 L
s
.49777 .46689 m
.49775 .46926 L
s
.51932 .44594 m
.51917 .44825 L
s
.87149 .46996 m
.86861 .47124 L
s
.83762 .4753 m
.84453 .48273 L
s
.83704 .46001 m
.83704 .46051 L
s
.82848 .46878 m
.82553 .46955 L
s
.55564 .46013 m
.55701 .4609 L
s
.83704 .46051 m
.83704 .46102 L
s
.52215 .45835 m
.52332 .45939 L
s
.47707 .48871 m
.47719 .49115 L
s
.83704 .46102 m
.83704 .46152 L
s
.56088 .46055 m
.57345 .45419 L
s
.54163 .42589 m
.54137 .42814 L
s
.49349 .45707 m
.49452 .45836 L
s
.46695 .45592 m
.46787 .45746 L
s
.56191 .40628 m
.57605 .40257 L
s
.55431 .45935 m
.55564 .46013 L
s
.51917 .44825 m
.51905 .45056 L
s
.83704 .46152 m
.83704 .46204 L
s
.8314 .46798 m
.82848 .46878 L
s
.45706 .50891 m
.4573 .51141 L
s
.49775 .46926 m
.49776 .47163 L
s
.87435 .46864 m
.87149 .46996 L
s
.44141 .45446 m
.44223 .45624 L
s
.83704 .46204 m
.83705 .46255 L
s
0 g
.5 Mabswid
.92363 .47131 m
.95701 .46097 L
s
.039 .916 .04 r
1 Mabswid
.40789 .45482 m
.42338 .45185 L
s
.83705 .46255 m
.83706 .46307 L
s
.52102 .4573 m
.52215 .45835 L
s
.55301 .45856 m
.55431 .45935 L
s
.54137 .42814 m
.54113 .43038 L
s
.8343 .46714 m
.8314 .46798 L
s
.83706 .46307 m
.83707 .46359 L
s
.4925 .45576 m
.49349 .45707 L
s
.47719 .49115 m
.47734 .49357 L
s
.51905 .45056 m
.51895 .45286 L
s
.83707 .46359 m
.83708 .46412 L
s
.46607 .45437 m
.46695 .45592 L
s
.49776 .47163 m
.49779 .47399 L
s
.55174 .45775 m
.55301 .45856 L
s
.83708 .46412 m
.8371 .46465 L
s
.4573 .51141 m
.45757 .51391 L
s
.87718 .46728 m
.87435 .46864 L
s
.51993 .45623 m
.52102 .4573 L
s
.83717 .46626 m
.8343 .46714 L
s
.8371 .46465 m
.83712 .46518 L
s
.44064 .45266 m
.44141 .45446 L
s
.54113 .43038 m
.54092 .43261 L
s
0 g
.5 Mabswid
.81266 .58242 m
.83682 .58429 L
s
.039 .916 .04 r
1 Mabswid
.55051 .45694 m
.55174 .45775 L
s
.83712 .46518 m
.83714 .46572 L
s
.44749 .52204 m
.46144 .51642 L
s
.49156 .45443 m
.4925 .45576 L
s
.51895 .45286 m
.51888 .45515 L
s
.83714 .46572 m
.83717 .46626 L
s
.47734 .49357 m
.47751 .496 L
s
.56427 .40892 m
.56392 .4111 L
s
.51888 .45515 m
.51993 .45623 L
s
.49779 .47399 m
.49785 .47634 L
s
.83717 .46626 m
.8372 .4668 L
s
.84001 .46534 m
.83717 .46626 L
s
.46525 .4528 m
.46607 .45437 L
s
.54931 .45611 m
.55051 .45694 L
s
.87999 .46588 m
.87718 .46728 L
s
.8372 .4668 m
.83723 .46735 L
s
.54092 .43261 m
.54072 .43484 L
s
.83723 .46735 m
.83726 .4679 L
s
.49066 .45309 m
.49156 .45443 L
s
.56392 .4111 m
.5636 .41327 L
s
.83726 .4679 m
.8373 .46845 L
s
.43993 .45084 m
.44064 .45266 L
s
.51888 .45515 m
.51883 .45744 L
s
.51787 .45405 m
.51888 .45515 L
s
.54815 .45527 m
.54931 .45611 L
s
.84283 .46439 m
.84001 .46534 L
s
.8373 .46845 m
.83734 .46901 L
s
.42338 .45185 m
.43891 .44887 L
s
.47751 .496 m
.4777 .49841 L
s
.49785 .47634 m
.49793 .47869 L
s
.83734 .46901 m
.83738 .46957 L
s
.54072 .43484 m
.54055 .43707 L
s
.46447 .45121 m
.46525 .4528 L
s
.83738 .46957 m
.83743 .47013 L
s
.88276 .46443 m
.87999 .46588 L
s
.54701 .45442 m
.54815 .45527 L
s
.8949 .4589 m
.90461 .46658 L
s
.5636 .41327 m
.56329 .41544 L
s
.51689 .45294 m
.51787 .45405 L
s
.83743 .47013 m
.83747 .4707 L
s
.84561 .46339 m
.84283 .46439 L
s
.4898 .45174 m
.49066 .45309 L
s
.51883 .45744 m
.5188 .45972 L
s
.77708 .45272 m
.78139 .46226 L
s
.83747 .4707 m
.83753 .47127 L
s
.83753 .47127 m
.83758 .47185 L
s
.54591 .45356 m
.54701 .45442 L
s
.54055 .43707 m
.5404 .43929 L
s
.49793 .47869 m
.49803 .48104 L
s
.78765 .46154 m
.78467 .46187 L
s
.4777 .49841 m
.47792 .50083 L
s
.57605 .40257 m
.59026 .39883 L
s
.82258 .43781 m
.82968 .44756 L
s
.83758 .47185 m
.83763 .47243 L
s
.56329 .41544 m
.56301 .4176 L
s
.51596 .45182 m
.51689 .45294 L
s
.83763 .47243 m
.83769 .47301 L
s
.79061 .46118 m
.78765 .46154 L
s
.84837 .46236 m
.84561 .46339 L
s
.46374 .44959 m
.46447 .45121 L
s
.88551 .46294 m
.88276 .46443 L
s
.83769 .47301 m
.83775 .47359 L
s
.54485 .45268 m
.54591 .45356 L
s
.48899 .45036 m
.4898 .45174 L
s
.5188 .45972 m
.51879 .462 L
s
.79354 .46078 m
.79061 .46118 L
s
.83775 .47359 m
.83782 .47418 L
s
.57345 .45419 m
.5861 .44779 L
s
.5404 .43929 m
.54027 .44151 L
s
.83782 .47418 m
.83789 .47477 L
s
.46144 .51642 m
.47545 .51077 L
s
.56301 .4176 m
.56275 .41976 L
s
.79644 .46035 m
.79354 .46078 L
s
.49803 .48104 m
.49816 .48338 L
s
.51506 .45068 m
.51596 .45182 L
s
.47792 .50083 m
.47817 .50323 L
s
.54382 .45179 m
.54485 .45268 L
s
.85111 .46129 m
.84837 .46236 L
s
.79932 .45988 m
.79644 .46035 L
s
.43891 .44887 m
.4545 .44588 L
s
.46306 .44796 m
.46374 .44959 L
s
.48822 .44897 m
.48899 .45036 L
s
.51879 .462 m
.51881 .46427 L
s
.88822 .46141 m
.88551 .46294 L
s
.83066 .46781 m
.83762 .4753 L
s
.54027 .44151 m
.54017 .44372 L
s
.54282 .45089 m
.54382 .45179 L
s
.56275 .41976 m
.56251 .42191 L
s
.80217 .45938 m
.79932 .45988 L
s
.5142 .44953 m
.51506 .45068 L
s
.85381 .46019 m
.85111 .46129 L
s
.49816 .48338 m
.49831 .48571 L
s
.47817 .50323 m
.47844 .50564 L
s
.80499 .45885 m
.80217 .45938 L
s
.54185 .44998 m
.54282 .45089 L
s
.51881 .46427 m
.51885 .46654 L
s
.57434 .45116 m
.57548 .45181 L
s
.4875 .44757 m
.48822 .44897 L
s
.56251 .42191 m
.56229 .42405 L
s
.54017 .44372 m
.54008 .44592 L
s
.46243 .44631 m
.46306 .44796 L
s
.80779 .45828 m
.80499 .45885 L
s
.51338 .44836 m
.5142 .44953 L
s
.89091 .45984 m
.88822 .46141 L
s
.85649 .45904 m
.85381 .46019 L
s
.57322 .45051 m
.57434 .45116 L
s
0 g
.5 Mabswid
.86107 .54996 m
.8627 .57974 L
s
.039 .916 .04 r
1 Mabswid
.82655 .44421 m
.82654 .44479 L
s
.54092 .44906 m
.54185 .44998 L
s
.49831 .48571 m
.49849 .48804 L
s
.81056 .45767 m
.80779 .45828 L
s
.82654 .44479 m
.82652 .44537 L
s
.56229 .42405 m
.56209 .4262 L
s
.57214 .44984 m
.57322 .45051 L
s
.51885 .46654 m
.51892 .4688 L
s
.54008 .44592 m
.54002 .44812 L
s
.48682 .44614 m
.4875 .44757 L
s
.5126 .44718 m
.51338 .44836 L
s
.82652 .44537 m
.82651 .44596 L
s
.8133 .45704 m
.81056 .45767 L
s
.54002 .44812 m
.54092 .44906 L
s
.85914 .45786 m
.85649 .45904 L
s
.57108 .44916 m
.57214 .44984 L
s
.82651 .44596 m
.82651 .44655 L
s
.4545 .44588 m
.47013 .44289 L
s
.58542 .40322 m
.5851 .4053 L
s
.49849 .48804 m
.49869 .49037 L
s
.56209 .4262 m
.56192 .42833 L
s
.82651 .44655 m
.8265 .44715 L
s
.81602 .45637 m
.8133 .45704 L
s
.59026 .39883 m
.60454 .39508 L
s
.47545 .51077 m
.48951 .5051 L
s
.57005 .44847 m
.57108 .44916 L
s
.54002 .44812 m
.53998 .45032 L
s
.53916 .44717 m
.54002 .44812 L
s
.51892 .4688 m
.51901 .47106 L
s
.51186 .44598 m
.5126 .44718 L
s
.8265 .44715 m
.8265 .44775 L
s
.48618 .4447 m
.48682 .44614 L
s
.86177 .45664 m
.85914 .45786 L
s
0 g
.5 Mabswid
.95535 .48464 m
.95701 .46097 L
s
.95701 .46097 m
.95701 .46097 L
s
.039 .916 .04 r
1 Mabswid
.88512 .45118 m
.8949 .4589 L
s
.81872 .45566 m
.81602 .45637 L
s
.8265 .44775 m
.8265 .44835 L
s
.56905 .44777 m
.57005 .44847 L
s
.5851 .4053 m
.5848 .40738 L
s
.56192 .42833 m
.56176 .43046 L
s
.53833 .44621 m
.53916 .44717 L
s
.8265 .44835 m
.82651 .44896 L
s
.49869 .49037 m
.49891 .49269 L
s
.53998 .45032 m
.53997 .45251 L
s
.51116 .44477 m
.51186 .44598 L
s
.56808 .44707 m
.56905 .44777 L
s
.82651 .44896 m
.82652 .44957 L
s
.82139 .45492 m
.81872 .45566 L
s
.51901 .47106 m
.51912 .47331 L
s
.5848 .40738 m
.58452 .40945 L
s
.48559 .44324 m
.48618 .4447 L
s
.82652 .44957 m
.82653 .45019 L
s
.86437 .45537 m
.86177 .45664 L
s
.5861 .44779 m
.59883 .44135 L
s
.53753 .44524 m
.53833 .44621 L
s
.81544 .42798 m
.82258 .43781 L
s
.56713 .44635 m
.56808 .44707 L
s
.56176 .43046 m
.56163 .43259 L
s
.82653 .45019 m
.82655 .45081 L
s
.82403 .45415 m
.82139 .45492 L
s
.51049 .44355 m
.51116 .44477 L
s
.53997 .45251 m
.53997 .45469 L
s
.82655 .45081 m
.82657 .45144 L
s
.49891 .49269 m
.49916 .495 L
s
.56621 .44562 m
.56713 .44635 L
s
.58452 .40945 m
.58426 .41152 L
s
.51912 .47331 m
.51925 .47556 L
s
.53676 .44426 m
.53753 .44524 L
s
.82657 .45144 m
.82659 .45207 L
s
.77272 .44309 m
.77708 .45272 L
s
.47013 .44289 m
.48581 .43988 L
s
.82664 .45334 m
.82403 .45415 L
s
.86694 .45408 m
.86437 .45537 L
s
.56163 .43259 m
.56151 .43471 L
s
.48505 .44177 m
.48559 .44324 L
s
.82659 .45207 m
.82661 .4527 L
s
.56533 .44488 m
.56621 .44562 L
s
.82661 .4527 m
.82664 .45334 L
s
.50987 .44231 m
.51049 .44355 L
s
0 g
.5 Mabswid
.83682 .58429 m
.8627 .57974 L
s
.039 .916 .04 r
1 Mabswid
.58426 .41152 m
.58402 .41358 L
s
.53997 .45469 m
.54 .45687 L
s
.53603 .44326 m
.53676 .44426 L
s
.82664 .45334 m
.82668 .45398 L
s
.82923 .4525 m
.82664 .45334 L
s
.49916 .495 m
.49944 .49731 L
s
.56447 .44414 m
.56533 .44488 L
s
.51925 .47556 m
.51941 .4778 L
s
.56151 .43471 m
.56142 .43683 L
s
.82668 .45398 m
.82671 .45463 L
s
.48951 .5051 m
.50363 .49941 L
s
.86948 .45274 m
.86694 .45408 L
s
.82671 .45463 m
.82675 .45528 L
s
.58402 .41358 m
.5838 .41563 L
s
.53534 .44225 m
.53603 .44326 L
s
.56363 .44338 m
.56447 .44414 L
s
.50928 .44105 m
.50987 .44231 L
s
.8318 .45162 m
.82923 .4525 L
s
.54 .45687 m
.54005 .45905 L
s
.82675 .45528 m
.82679 .45594 L
s
.82679 .45594 m
.82684 .4566 L
s
.82364 .46026 m
.83066 .46781 L
s
.56142 .43683 m
.56136 .43894 L
s
.51941 .4778 m
.5196 .48004 L
s
.56283 .44261 m
.56363 .44338 L
s
.60454 .39508 m
.61889 .39131 L
s
.82684 .4566 m
.82689 .45726 L
s
.53467 .44123 m
.53534 .44225 L
s
.5838 .41563 m
.5836 .41769 L
s
.83434 .45071 m
.8318 .45162 L
s
.872 .45136 m
.86948 .45274 L
s
.82689 .45726 m
.82694 .45793 L
s
.50874 .43978 m
.50928 .44105 L
s
.54005 .45905 m
.54013 .46122 L
s
.56206 .44183 m
.56283 .44261 L
s
.82694 .45793 m
.82699 .4586 L
s
.48581 .43988 m
.50154 .43686 L
s
.56136 .43894 m
.56131 .44105 L
s
.82699 .4586 m
.82705 .45928 L
s
.53404 .4402 m
.53467 .44123 L
s
.5196 .48004 m
.5198 .48227 L
s
.83686 .44976 m
.83434 .45071 L
s
.5836 .41769 m
.58342 .41973 L
s
.82705 .45928 m
.82711 .45996 L
s
.56131 .44105 m
.56206 .44183 L
s
.5932 .44212 m
.59411 .44265 L
s
.82711 .45996 m
.82718 .46064 L
s
.50823 .4385 m
.50874 .43978 L
s
.87449 .44994 m
.872 .45136 L
s
.54013 .46122 m
.54023 .46338 L
s
.82718 .46064 m
.82725 .46133 L
s
.78078 .44775 m
.77808 .44805 L
s
.5923 .44159 m
.5932 .44212 L
s
.53345 .43915 m
.53404 .4402 L
s
.56059 .44025 m
.56131 .44105 L
s
.56131 .44105 m
.56128 .44315 L
s
.83934 .44878 m
.83686 .44976 L
s
.58342 .41973 m
.58326 .42177 L
s
.82725 .46133 m
.82732 .46202 L
s
.87528 .4434 m
.88512 .45118 L
s
.78345 .44741 m
.78078 .44775 L
s
.60674 .39748 m
.60644 .39946 L
s
.5198 .48227 m
.52003 .4845 L
s
.59143 .44104 m
.5923 .44159 L
s
.82732 .46202 m
.82739 .46272 L
s
.7861 .44705 m
.78345 .44741 L
s
.5599 .43944 m
.56059 .44025 L
s
.82739 .46272 m
.82747 .46342 L
s
.50776 .4372 m
.50823 .4385 L
s
.59883 .44135 m
.61164 .43487 L
s
.59058 .4405 m
.59143 .44104 L
s
.53289 .43809 m
.53345 .43915 L
s
.54023 .46338 m
.54035 .46554 L
s
.87696 .44849 m
.87449 .44994 L
s
.84181 .44776 m
.83934 .44878 L
s
.56128 .44315 m
.56128 .44524 L
s
.78872 .44666 m
.7861 .44705 L
s
.58326 .42177 m
.58312 .42381 L
s
.50363 .49941 m
.51781 .49369 L
s
.60644 .39946 m
.60616 .40144 L
s
.58975 .43994 m
.59058 .4405 L
s
.55924 .43862 m
.5599 .43944 L
s
.79132 .44623 m
.78872 .44666 L
s
.52003 .4845 m
.52029 .48672 L
s
.80825 .41809 m
.81544 .42798 L
s
.58895 .43937 m
.58975 .43994 L
s
.53236 .43702 m
.53289 .43809 L
s
.7939 .44578 m
.79132 .44623 L
s
.81593 .42974 m
.8159 .4304 L
s
.84425 .44671 m
.84181 .44776 L
s
.50154 .43686 m
.51732 .43383 L
s
.58312 .42381 m
.583 .42584 L
s
.54035 .46554 m
.54049 .46769 L
s
.60616 .40144 m
.6059 .40342 L
s
.5586 .43779 m
.55924 .43862 L
s
.56128 .44524 m
.5613 .44733 L
s
.58816 .4388 m
.58895 .43937 L
s
.8159 .4304 m
.81589 .43108 L
s
.79645 .44529 m
.7939 .44578 L
s
.53186 .43594 m
.53236 .43702 L
s
.58741 .43822 m
.58816 .4388 L
s
.81589 .43108 m
.81587 .43176 L
s
.558 .43695 m
.5586 .43779 L
s
.52029 .48672 m
.52057 .48894 L
s
.79898 .44477 m
.79645 .44529 L
s
.6059 .40342 m
.60566 .40539 L
s
.84666 .44563 m
.84425 .44671 L
s
.583 .42584 m
.58291 .42787 L
s
.5613 .44733 m
.56134 .44942 L
s
.54049 .46769 m
.54065 .46984 L
s
.81587 .43176 m
.81586 .43244 L
s
.61889 .39131 m
.63332 .38752 L
s
.58667 .43763 m
.58741 .43822 L
s
.80148 .44422 m
.79898 .44477 L
s
.55742 .4361 m
.558 .43695 L
s
0 g
.5 Mabswid
.94689 .509 m
.95535 .48464 L
s
.039 .916 .04 r
1 Mabswid
.81586 .43244 m
.81586 .43313 L
s
.5314 .43484 m
.53186 .43594 L
s
.58596 .43703 m
.58667 .43763 L
s
.60566 .40539 m
.60544 .40735 L
s
.58291 .42787 m
.58283 .42989 L
s
.80396 .44364 m
.80148 .44422 L
s
.84905 .4445 m
.84666 .44563 L
s
.81586 .43313 m
.81585 .43382 L
s
.76833 .43339 m
.77272 .44309 L
s
.56134 .44942 m
.5614 .4515 L
s
.58527 .43642 m
.58596 .43703 L
s
.55687 .43525 m
.55742 .4361 L
s
.54065 .46984 m
.54084 .47199 L
s
.81585 .43382 m
.81585 .43452 L
s
.80641 .44303 m
.80396 .44364 L
s
.53098 .43373 m
.5314 .43484 L
s
.60544 .40735 m
.60524 .40932 L
s
.5846 .43581 m
.58527 .43642 L
s
.81585 .43452 m
.81586 .43522 L
s
.58283 .42989 m
.58278 .43191 L
s
.55635 .43438 m
.55687 .43525 L
s
.85142 .44335 m
.84905 .4445 L
s
.51732 .43383 m
.53315 .4308 L
s
.51781 .49369 m
.53205 .48796 L
s
.80884 .44239 m
.80641 .44303 L
s
.81586 .43522 m
.81587 .43593 L
s
.5614 .4515 m
.56148 .45358 L
s
.58396 .43519 m
.5846 .43581 L
s
.54084 .47199 m
.54105 .47413 L
s
.60524 .40932 m
.60506 .41127 L
s
.81587 .43593 m
.81588 .43664 L
s
.53059 .43261 m
.53098 .43373 L
s
0 g
.5 Mabswid
.8627 .57974 m
.88845 .56899 L
s
.8627 .57974 m
.8627 .57974 L
s
.039 .916 .04 r
1 Mabswid
.55586 .4335 m
.55635 .43438 L
s
.81125 .44172 m
.80884 .44239 L
s
.58334 .43456 m
.58396 .43519 L
s
.81656 .45265 m
.82364 .46026 L
s
.58278 .43191 m
.58274 .43392 L
s
.81588 .43664 m
.8159 .43736 L
s
.85376 .44215 m
.85142 .44335 L
s
.58274 .43392 m
.58334 .43456 L
s
.56148 .45358 m
.56158 .45565 L
s
.8159 .43736 m
.81592 .43808 L
s
.60506 .41127 m
.6049 .41322 L
s
.81364 .44102 m
.81125 .44172 L
s
.5554 .43261 m
.55586 .4335 L
s
.54105 .47413 m
.54129 .47626 L
s
.81592 .43808 m
.81594 .43881 L
s
.86537 .43557 m
.87528 .4434 L
s
.61164 .43487 m
.62452 .42836 L
s
.58274 .43392 m
.58273 .43593 L
s
.58217 .43327 m
.58274 .43392 L
s
.81594 .43881 m
.81597 .43954 L
s
.816 .44028 m
.81364 .44102 L
s
.85607 .44093 m
.85376 .44215 L
s
.55497 .43171 m
.5554 .43261 L
s
.6049 .41322 m
.60476 .41517 L
s
.56158 .45565 m
.56171 .45771 L
s
.58162 .43262 m
.58217 .43327 L
s
.81597 .43954 m
.816 .44028 L
s
.816 .44028 m
.81603 .44102 L
s
.81834 .43951 m
.816 .44028 L
s
.54129 .47626 m
.54154 .47839 L
s
.58273 .43593 m
.58273 .43793 L
s
.62822 .39169 m
.62794 .39358 L
s
.58109 .43196 m
.58162 .43262 L
s
.55456 .43079 m
.55497 .43171 L
s
.61221 .433 m
.61291 .4334 L
s
.81603 .44102 m
.81607 .44177 L
s
.53315 .4308 m
.54903 .42775 L
s
.60476 .41517 m
.60464 .41711 L
s
.63332 .38752 m
.64782 .3837 L
s
.85836 .43966 m
.85607 .44093 L
s
.61154 .43259 m
.61221 .433 L
s
.56171 .45771 m
.56186 .45978 L
s
.58058 .43129 m
.58109 .43196 L
s
.81607 .44177 m
.81612 .44252 L
s
.82065 .43872 m
.81834 .43951 L
s
.80101 .40813 m
.80825 .41809 L
s
.62794 .39358 m
.62769 .39546 L
s
.55419 .42987 m
.55456 .43079 L
s
.61088 .43218 m
.61154 .43259 L
s
.58273 .43793 m
.58276 .43993 L
s
.81612 .44252 m
.81616 .44328 L
s
.54154 .47839 m
.54182 .48052 L
s
.5801 .43061 m
.58058 .43129 L
s
.60464 .41711 m
.60453 .41905 L
s
.53205 .48796 m
.54634 .48219 L
s
.61023 .43176 m
.61088 .43218 L
s
.81616 .44328 m
.81621 .44404 L
s
.82294 .43789 m
.82065 .43872 L
s
.62769 .39546 m
.62745 .39734 L
s
.60961 .43133 m
.61023 .43176 L
s
.86063 .43836 m
.85836 .43966 L
s
.81621 .44404 m
.81627 .44481 L
s
.56186 .45978 m
.56203 .46183 L
s
.55384 .42894 m
.55419 .42987 L
s
.57964 .42992 m
.5801 .43061 L
s
.58276 .43993 m
.58281 .44192 L
s
.609 .4309 m
.60961 .43133 L
s
.81627 .44481 m
.81633 .44558 L
s
.60453 .41905 m
.60445 .42098 L
s
.82521 .43703 m
.82294 .43789 L
s
.60841 .43046 m
.609 .4309 L
s
.81633 .44558 m
.81639 .44636 L
s
.57921 .42923 m
.57964 .42992 L
s
.62745 .39734 m
.62723 .39922 L
s
.55352 .428 m
.55384 .42894 L
s
.81639 .44636 m
.81645 .44714 L
s
.60784 .43002 m
.60841 .43046 L
s
.56203 .46183 m
.56222 .46388 L
s
.86287 .43703 m
.86063 .43836 L
s
0 g
.5 Mabswid
.93215 .53229 m
.94689 .509 L
s
.039 .916 .04 r
1 Mabswid
.58281 .44192 m
.58288 .44391 L
s
.57879 .42852 m
.57921 .42923 L
s
.82746 .43613 m
.82521 .43703 L
s
.81645 .44714 m
.81652 .44793 L
s
.60445 .42098 m
.60439 .42291 L
s
.60728 .42957 m
.60784 .43002 L
s
.62723 .39922 m
.62703 .40109 L
s
.81652 .44793 m
.8166 .44872 L
s
.54903 .42775 m
.56495 .4247 L
s
.60675 .42912 m
.60728 .42957 L
s
.5784 .42781 m
.57879 .42852 L
s
.8166 .44872 m
.81667 .44952 L
s
.60623 .42865 m
.60675 .42912 L
s
.82968 .43521 m
.82746 .43613 L
s
.56222 .46388 m
.56243 .46593 L
s
.60439 .42291 m
.60435 .42483 L
s
.58288 .44391 m
.58297 .44589 L
s
.81667 .44952 m
.81676 .45032 L
s
.62703 .40109 m
.62684 .40295 L
s
.77383 .43378 m
.77142 .43405 L
s
.57804 .42709 m
.5784 .42781 L
s
.60572 .42819 m
.60623 .42865 L
s
0 g
.5 Mabswid
.88845 .56899 m
.91218 .55279 L
s
.039 .916 .04 r
1 Mabswid
.81676 .45032 m
.81684 .45112 L
s
.77621 .43348 m
.77383 .43378 L
s
.80519 .41511 m
.80516 .41587 L
s
.81684 .45112 m
.81693 .45194 L
s
.76391 .4236 m
.76833 .43339 L
s
.60524 .42771 m
.60572 .42819 L
s
.83188 .43425 m
.82968 .43521 L
s
.77857 .43316 m
.77621 .43348 L
s
.5777 .42636 m
.57804 .42709 L
s
.60435 .42483 m
.60432 .42675 L
s
.62684 .40295 m
.62668 .40481 L
s
.80516 .41587 m
.80514 .41663 L
s
.62452 .42836 m
.63748 .4218 L
s
.58297 .44589 m
.58308 .44787 L
s
.60477 .42723 m
.60524 .42771 L
s
.56243 .46593 m
.56267 .46797 L
s
.78091 .4328 m
.77857 .43316 L
s
.54634 .48219 m
.56069 .47641 L
s
.80514 .41663 m
.80512 .4174 L
s
.8554 .42769 m
.86537 .43557 L
s
.60432 .42675 m
.60477 .42723 L
s
.57738 .42563 m
.5777 .42636 L
s
.78323 .43242 m
.78091 .4328 L
s
.64782 .3837 m
.6624 .37987 L
s
.83405 .43327 m
.83188 .43425 L
s
.62668 .40481 m
.62654 .40667 L
s
.60432 .42675 m
.60432 .42866 L
s
.60389 .42625 m
.60432 .42675 L
s
.80512 .4174 m
.8051 .41818 L
s
.78553 .43201 m
.78323 .43242 L
s
.80942 .44498 m
.81656 .45265 L
s
.58308 .44787 m
.58321 .44984 L
s
.57708 .42488 m
.57738 .42563 L
s
.56267 .46797 m
.56293 .47001 L
s
.60348 .42575 m
.60389 .42625 L
s
.78781 .43157 m
.78553 .43201 L
s
.8051 .41818 m
.80509 .41896 L
s
.56495 .4247 m
.58093 .42164 L
s
.8362 .43225 m
.83405 .43327 L
s
.62654 .40667 m
.62641 .40852 L
s
.60308 .42525 m
.60348 .42575 L
s
.57681 .42413 m
.57708 .42488 L
s
.79006 .43111 m
.78781 .43157 L
s
.60432 .42866 m
.60434 .43057 L
s
.80509 .41896 m
.80509 .41974 L
s
0 g
.5 Mabswid
.91218 .55279 m
.93215 .53229 L
s
.039 .916 .04 r
1 Mabswid
.58321 .44984 m
.58337 .45181 L
s
.6027 .42474 m
.60308 .42525 L
s
.79229 .43062 m
.79006 .43111 L
s
.80509 .41974 m
.80509 .42054 L
s
.56293 .47001 m
.56321 .47204 L
s
.57656 .42337 m
.57681 .42413 L
s
.62641 .40852 m
.6263 .41036 L
s
.83833 .4312 m
.8362 .43225 L
s
.60234 .42422 m
.6027 .42474 L
s
.64986 .38586 m
.64961 .38765 L
s
.80509 .42054 m
.80509 .42133 L
s
.7945 .43009 m
.79229 .43062 L
s
.60434 .43057 m
.60437 .43247 L
s
.79372 .3981 m
.80101 .40813 L
s
.602 .4237 m
.60234 .42422 L
s
.58337 .45181 m
.58354 .45377 L
s
.80509 .42133 m
.8051 .42214 L
s
.79669 .42955 m
.7945 .43009 L
s
.6263 .41036 m
.62622 .4122 L
s
.64961 .38765 m
.64937 .38944 L
s
.60167 .42317 m
.602 .4237 L
s
.84044 .43011 m
.83833 .4312 L
s
.8051 .42214 m
.80511 .42294 L
s
.60437 .43247 m
.60443 .43437 L
s
.79886 .42897 m
.79669 .42955 L
s
.60136 .42263 m
.60167 .42317 L
s
.6314 .4238 m
.63187 .42407 L
s
.80511 .42294 m
.80513 .42376 L
s
.64937 .38944 m
.64915 .39122 L
s
.63094 .42352 m
.6314 .4238 L
s
.58354 .45377 m
.58374 .45573 L
s
.62622 .4122 m
.62615 .41404 L
s
.80101 .42837 m
.79886 .42897 L
s
.60107 .42209 m
.60136 .42263 L
s
.56069 .47641 m
.5751 .4706 L
s
.63049 .42324 m
.63094 .42352 L
s
.80513 .42376 m
.80515 .42458 L
s
.84253 .429 m
.84044 .43011 L
s
.63005 .42295 m
.63049 .42324 L
s
.58093 .42164 m
.59696 .41856 L
s
.60443 .43437 m
.60451 .43626 L
s
.6008 .42154 m
.60107 .42209 L
s
.62963 .42266 m
.63005 .42295 L
s
.64915 .39122 m
.64895 .393 L
s
.80515 .42458 m
.80517 .4254 L
s
.80313 .42773 m
.80101 .42837 L
s
.62615 .41404 m
.6261 .41587 L
s
.62922 .42236 m
.62963 .42266 L
s
.58374 .45573 m
.58395 .45768 L
s
.60055 .42099 m
.6008 .42154 L
s
.80517 .4254 m
.8052 .42624 L
s
.62882 .42206 m
.62922 .42236 L
s
.84459 .42785 m
.84253 .429 L
s
.80523 .42707 m
.80313 .42773 L
s
.62843 .42176 m
.62882 .42206 L
s
.60451 .43626 m
.6046 .43815 L
s
.6624 .37987 m
.67705 .37602 L
s
.64895 .393 m
.64877 .39477 L
s
.8052 .42624 m
.80523 .42707 L
s
.60031 .42043 m
.60055 .42099 L
s
.62805 .42145 m
.62843 .42176 L
s
.6261 .41587 m
.62607 .4177 L
s
.63748 .4218 m
.65053 .4152 L
s
.62769 .42114 m
.62805 .42145 L
s
.80523 .42707 m
.80527 .42792 L
s
.80732 .42639 m
.80523 .42707 L
s
.60009 .41986 m
.60031 .42043 L
s
.58395 .45768 m
.58419 .45963 L
s
.62734 .42083 m
.62769 .42114 L
s
.64877 .39477 m
.6486 .39654 L
s
.80527 .42792 m
.80531 .42876 L
s
.84663 .42667 m
.84459 .42785 L
s
.6046 .43815 m
.60472 .44003 L
s
.627 .42051 m
.62734 .42083 L
s
.59989 .41929 m
.60009 .41986 L
s
.80938 .42567 m
.80732 .42639 L
s
.62607 .4177 m
.62605 .41952 L
s
.62667 .42018 m
.627 .42051 L
s
.80531 .42876 m
.80536 .42962 L
s
.84536 .41976 m
.8554 .42769 L
s
.62636 .41985 m
.62667 .42018 L
s
.5997 .41871 m
.59989 .41929 L
s
.6486 .39654 m
.64846 .3983 L
s
.80536 .42962 m
.80541 .43048 L
s
.58419 .45963 m
.58445 .46157 L
s
.62605 .41952 m
.62636 .41985 L
s
.81142 .42492 m
.80938 .42567 L
s
.60472 .44003 m
.60486 .44191 L
s
.84864 .42545 m
.84663 .42667 L
s
.62605 .41952 m
.62606 .42134 L
s
.62576 .41918 m
.62605 .41952 L
s
.59696 .41856 m
.61303 .41548 L
s
.80541 .43048 m
.80547 .43134 L
s
.75944 .41373 m
.76391 .4236 L
s
.62548 .41884 m
.62576 .41918 L
s
.64846 .3983 m
.64833 .40006 L
s
.80547 .43134 m
.80553 .43222 L
s
.81344 .42415 m
.81142 .42492 L
s
.62522 .4185 m
.62548 .41884 L
s
.5751 .4706 m
.58957 .46477 L
s
.58445 .46157 m
.58473 .46351 L
s
.80553 .43222 m
.80559 .43309 L
s
.60486 .44191 m
.60501 .44379 L
s
.62496 .41815 m
.62522 .4185 L
s
.62606 .42134 m
.62609 .42315 L
s
.64833 .40006 m
.64822 .40182 L
s
.62472 .4178 m
.62496 .41815 L
s
.81544 .42335 m
.81344 .42415 L
s
.80559 .43309 m
.80566 .43398 L
s
.80223 .43725 m
.80942 .44498 L
s
.62449 .41744 m
.62472 .4178 L
s
.80566 .43398 m
.80573 .43486 L
s
.62427 .41708 m
.62449 .41744 L
s
.62609 .42315 m
.62613 .42496 L
s
.60501 .44379 m
.60519 .44565 L
s
.64822 .40182 m
.64813 .40357 L
s
.81741 .42252 m
.81544 .42335 L
s
.80573 .43486 m
.80581 .43576 L
s
.78638 .388 m
.79372 .3981 L
s
.62406 .41671 m
.62427 .41708 L
s
.79433 .40034 m
.7943 .40118 L
s
.80581 .43576 m
.80589 .43666 L
s
.62387 .41634 m
.62406 .41671 L
s
.67166 .37998 m
.67143 .38168 L
s
.80589 .43666 m
.80598 .43756 L
s
.62369 .41597 m
.62387 .41634 L
s
.81937 .42166 m
.81741 .42252 L
s
.62613 .42496 m
.62619 .42676 L
s
.7943 .40118 m
.79427 .40204 L
s
.64813 .40357 m
.64805 .40531 L
s
.60519 .44565 m
.60539 .44752 L
s
.62352 .41559 m
.62369 .41597 L
s
.80598 .43756 m
.80607 .43847 L
s
.67705 .37602 m
.69178 .37215 L
s
.61303 .41548 m
.62916 .41239 L
s
.67143 .38168 m
.67122 .38337 L
s
.79427 .40204 m
.79425 .4029 L
s
.62336 .41521 m
.62352 .41559 L
s
.80607 .43847 m
.80616 .43939 L
s
.82131 .42078 m
.81937 .42166 L
s
.76679 .41965 m
.76468 .41989 L
s
.64805 .40531 m
.648 .40705 L
s
.62619 .42676 m
.62628 .42856 L
s
.62321 .41482 m
.62336 .41521 L
s
.80616 .43939 m
.80626 .44031 L
s
.79425 .4029 m
.79423 .40376 L
s
.76888 .41938 m
.76679 .41965 L
s
.60539 .44752 m
.60561 .44938 L
s
.67122 .38337 m
.67102 .38505 L
s
.62308 .41443 m
.62321 .41482 L
s
.77096 .41909 m
.76888 .41938 L
s
.79423 .40376 m
.79422 .40464 L
s
.82322 .41986 m
.82131 .42078 L
s
.62296 .41404 m
.62308 .41443 L
s
.77301 .41878 m
.77096 .41909 L
s
.648 .40705 m
.64796 .40879 L
s
.65053 .4152 m
.66365 .40857 L
s
.62628 .42856 m
.62638 .43036 L
s
.67102 .38505 m
.67084 .38673 L
s
.77505 .41844 m
.77301 .41878 L
s
.58957 .46477 m
.6041 .45891 L
s
.79422 .40464 m
.79421 .40551 L
s
.60561 .44938 m
.60584 .45124 L
s
.65075 .41452 m
.65099 .41467 L
s
.6505 .41437 m
.65075 .41452 L
s
.77706 .41808 m
.77505 .41844 L
s
.65027 .41422 m
.6505 .41437 L
s
.82512 .41892 m
.82322 .41986 L
s
.64796 .40879 m
.64794 .41052 L
s
.65004 .41407 m
.65027 .41422 L
s
.79421 .40551 m
.7942 .4064 L
s
.67084 .38673 m
.67067 .38841 L
s
.64981 .41391 m
.65004 .41407 L
s
.77906 .41769 m
.77706 .41808 L
s
.62638 .43036 m
.6265 .43215 L
s
.6496 .41376 m
.64981 .41391 L
s
.64939 .4136 m
.6496 .41376 L
s
.64918 .41344 m
.64939 .4136 L
s
.7942 .4064 m
.7942 .40729 L
s
.78104 .41728 m
.77906 .41769 L
s
.83525 .41178 m
.84536 .41976 L
s
.60584 .45124 m
.6061 .45309 L
s
.64898 .41327 m
.64918 .41344 L
s
.82699 .41795 m
.82512 .41892 L
s
.64879 .41311 m
.64898 .41327 L
s
.64794 .41052 m
.64793 .41225 L
s
.67067 .38841 m
.67053 .39008 L
s
.64861 .41294 m
.64879 .41311 L
s
.783 .41685 m
.78104 .41728 L
s
.62916 .41239 m
.64534 .40928 L
s
.7942 .40729 m
.79421 .40819 L
s
.64843 .41277 m
.64861 .41294 L
s
.6265 .43215 m
.62664 .43393 L
s
.64826 .4126 m
.64843 .41277 L
s
.64809 .41242 m
.64826 .4126 L
s
.78494 .41639 m
.783 .41685 L
s
.64793 .41225 m
.64809 .41242 L
s
.79421 .40819 m
.79422 .40909 L
s
.67053 .39008 m
.6704 .39175 L
s
.64793 .41225 m
.64795 .41397 L
s
.64778 .41207 m
.64793 .41225 L
s
.82884 .41695 m
.82699 .41795 L
s
.6061 .45309 m
.60638 .45493 L
s
.64764 .41189 m
.64778 .41207 L
s
.78686 .4159 m
.78494 .41639 L
s
.6475 .4117 m
.64764 .41189 L
s
.79422 .40909 m
.79424 .41001 L
s
.62664 .43393 m
.6268 .43571 L
s
.64736 .41152 m
.6475 .4117 L
s
.64724 .41133 m
.64736 .41152 L
s
.78876 .41539 m
.78686 .4159 L
s
.6704 .39175 m
.67028 .39341 L
s
.64712 .41114 m
.64724 .41133 L
s
.64795 .41397 m
.64798 .41569 L
s
.79424 .41001 m
.79426 .41092 L
s
.647 .41095 m
.64712 .41114 L
s
.83068 .41592 m
.82884 .41695 L
s
.6469 .41076 m
.647 .41095 L
s
.79064 .41486 m
.78876 .41539 L
s
.6468 .41056 m
.6469 .41076 L
s
.69178 .37215 m
.70658 .36826 L
s
.79426 .41092 m
.79428 .41185 L
s
.6268 .43571 m
.62698 .43749 L
s
.6467 .41036 m
.6468 .41056 L
s
.67028 .39341 m
.67019 .39507 L
s
.64661 .41016 m
.6467 .41036 L
s
.7925 .4143 m
.79064 .41486 L
s
.64798 .41569 m
.64804 .4174 L
s
.64653 .40996 m
.64661 .41016 L
s
.75494 .40377 m
.75944 .41373 L
s
.79428 .41185 m
.79431 .41278 L
s
.83249 .41486 m
.83068 .41592 L
s
.6041 .45891 m
.61869 .45303 L
s
.64646 .40975 m
.64653 .40996 L
s
.77898 .37783 m
.78638 .388 L
s
.64639 .40955 m
.64646 .40975 L
s
.67019 .39507 m
.67011 .39672 L
s
.79435 .41372 m
.7925 .4143 L
s
.64633 .40934 m
.64639 .40955 L
s
.79431 .41278 m
.79435 .41372 L
s
.62698 .43749 m
.62718 .43926 L
s
.79498 .42945 m
.80223 .43725 L
s
.64534 .40928 m
.66157 .40617 L
s
.64804 .4174 m
.64811 .41911 L
s
.79435 .41372 m
.79439 .41466 L
s
.79617 .41311 m
.79435 .41372 L
s
.83428 .41377 m
.83249 .41486 L
s
.67011 .39672 m
.67005 .39837 L
s
.69364 .37406 m
.69343 .37566 L
s
.79439 .41466 m
.79443 .41561 L
s
.62718 .43926 m
.6274 .44103 L
s
.79798 .41247 m
.79617 .41311 L
s
.64811 .41911 m
.6482 .42081 L
s
.66365 .40857 m
.67785 .40305 L
s
.79443 .41561 m
.79448 .41657 L
s
.67005 .39837 m
.67 .40001 L
s
.69343 .37566 m
.69323 .37725 L
s
.79977 .41182 m
.79798 .41247 L
s
.79448 .41657 m
.79454 .41753 L
s
.6274 .44103 m
.62763 .44279 L
s
.6482 .42081 m
.6483 .42251 L
s
.69323 .37725 m
.69305 .37884 L
s
.67 .40001 m
.66997 .40165 L
s
.80154 .41113 m
.79977 .41182 L
s
.79454 .41753 m
.7946 .4185 L
s
.7946 .4185 m
.79466 .41947 L
s
.69305 .37884 m
.69289 .38042 L
s
.80329 .41043 m
.80154 .41113 L
s
.6483 .42251 m
.64843 .42421 L
s
.62763 .44279 m
.62789 .44455 L
s
.66997 .40165 m
.66996 .40329 L
s
.79466 .41947 m
.79473 .42046 L
s
.82508 .40374 m
.83525 .41178 L
s
.66157 .40617 m
.67685 .40189 L
s
.78337 .38541 m
.78333 .38634 L
s
.80502 .40969 m
.80329 .41043 L
s
.69289 .38042 m
.69274 .382 L
s
.79473 .42046 m
.79481 .42145 L
s
.61869 .45303 m
.63334 .44713 L
s
.64843 .42421 m
.64857 .4259 L
s
.66996 .40329 m
.66997 .40492 L
s
.62789 .44455 m
.62817 .4463 L
s
.79481 .42145 m
.79489 .42244 L
s
.78333 .38634 m
.78329 .38729 L
s
.70658 .36826 m
.72146 .36435 L
s
.80673 .40894 m
.80502 .40969 L
s
.69274 .382 m
.69261 .38357 L
s
.67026 .40516 m
.67029 .40518 L
s
.67024 .40515 m
.67026 .40516 L
s
.79489 .42244 m
.79497 .42344 L
s
.67021 .40513 m
.67024 .40515 L
s
.67019 .40511 m
.67021 .40513 L
s
.67016 .4051 m
.67019 .40511 L
s
.67014 .40508 m
.67016 .4051 L
s
.67012 .40506 m
.67014 .40508 L
s
.6701 .40505 m
.67012 .40506 L
s
.67008 .40503 m
.6701 .40505 L
s
.67006 .40501 m
.67008 .40503 L
s
.67004 .40499 m
.67006 .40501 L
s
.67002 .40498 m
.67004 .40499 L
s
.67 .40496 m
.67002 .40498 L
s
.66999 .40494 m
.67 .40496 L
s
.66997 .40492 m
.66999 .40494 L
s
.66997 .40492 m
.66999 .40655 L
s
.66995 .4049 m
.66997 .40492 L
s
.66994 .40488 m
.66995 .4049 L
s
.78329 .38729 m
.78326 .38824 L
s
.66992 .40486 m
.66994 .40488 L
s
.66991 .40484 m
.66992 .40486 L
s
.64857 .4259 m
.64873 .42759 L
s
.6699 .40482 m
.66991 .40484 L
s
.66988 .40481 m
.6699 .40482 L
s
.66987 .40478 m
.66988 .40481 L
s
.66986 .40476 m
.66987 .40478 L
s
.66985 .40474 m
.66986 .40476 L
s
.66984 .40472 m
.66985 .40474 L
s
.66983 .4047 m
.66984 .40472 L
s
.66982 .40468 m
.66983 .4047 L
s
.66982 .40466 m
.66982 .40468 L
s
.66981 .40464 m
.66982 .40466 L
s
.79497 .42344 m
.79506 .42445 L
s
.6698 .40462 m
.66981 .40464 L
s
.80843 .40815 m
.80673 .40894 L
s
.69261 .38357 m
.69249 .38514 L
s
.78326 .38824 m
.78324 .38919 L
s
.79506 .42445 m
.79516 .42547 L
s
.66999 .40655 m
.67003 .40817 L
s
.64873 .42759 m
.64891 .42927 L
s
.8101 .40735 m
.80843 .40815 L
s
.79516 .42547 m
.79526 .42649 L
s
.69249 .38514 m
.6924 .38671 L
s
.78324 .38919 m
.78322 .39016 L
s
.79526 .42649 m
.79536 .42751 L
s
.67003 .40817 m
.67009 .40979 L
s
.78322 .39016 m
.78321 .39113 L
s
.81176 .40651 m
.8101 .40735 L
s
.6924 .38671 m
.69231 .38827 L
s
.67785 .40305 m
.69418 .39992 L
s
.79536 .42751 m
.79547 .42855 L
s
.64891 .42927 m
.64911 .43095 L
s
.75967 .40534 m
.75785 .40555 L
s
.76147 .40511 m
.75967 .40534 L
s
.77154 .36759 m
.77898 .37783 L
s
.78321 .39113 m
.7832 .39211 L
s
.76325 .40486 m
.76147 .40511 L
s
.67009 .40979 m
.67017 .4114 L
s
.69231 .38827 m
.69225 .38982 L
s
.8134 .40566 m
.81176 .40651 L
s
.76501 .40459 m
.76325 .40486 L
s
.64911 .43095 m
.64933 .43262 L
s
.67685 .40189 m
.69013 .39517 L
s
.7832 .39211 m
.7832 .3931 L
s
.76676 .4043 m
.76501 .40459 L
s
.63334 .44713 m
.64805 .4412 L
s
.76849 .40398 m
.76676 .4043 L
s
.69225 .38982 m
.6922 .39138 L
s
.67017 .4114 m
.67026 .41301 L
s
.81502 .40477 m
.8134 .40566 L
s
.7504 .39373 m
.75494 .40377 L
s
.7832 .3931 m
.7832 .39409 L
s
.77021 .40365 m
.76849 .40398 L
s
.78767 .42159 m
.79498 .42945 L
s
.64933 .43262 m
.64956 .43429 L
s
.71578 .3681 m
.71559 .36959 L
s
.77191 .40329 m
.77021 .40365 L
s
.6922 .39138 m
.69216 .39293 L
s
.7832 .39409 m
.78321 .39509 L
s
.67026 .41301 m
.67037 .41462 L
s
.81662 .40386 m
.81502 .40477 L
s
.77359 .40292 m
.77191 .40329 L
s
.71559 .36959 m
.71541 .37109 L
s
.78321 .39509 m
.78322 .3961 L
s
.77526 .40252 m
.77359 .40292 L
s
.64956 .43429 m
.64982 .43595 L
s
.72146 .36435 m
.73642 .36042 L
s
.69216 .39293 m
.69214 .39447 L
s
.67037 .41462 m
.6705 .41622 L
s
.81821 .40293 m
.81662 .40386 L
s
.77691 .4021 m
.77526 .40252 L
s
.69418 .39992 m
.71056 .39677 L
s
.69335 .3997 m
.69339 .39987 L
s
.78322 .3961 m
.78324 .39712 L
s
.71541 .37109 m
.71525 .37258 L
s
.6933 .39954 m
.69335 .3997 L
s
.69324 .39938 m
.6933 .39954 L
s
.81484 .39565 m
.82508 .40374 L
s
.77854 .40166 m
.77691 .4021 L
s
.69318 .39921 m
.69324 .39938 L
s
.69214 .39447 m
.69214 .39601 L
s
.69311 .39905 m
.69318 .39921 L
s
.64982 .43595 m
.65009 .43761 L
s
.78324 .39712 m
.78327 .39814 L
s
.69304 .3989 m
.69311 .39905 L
s
.71525 .37258 m
.7151 .37406 L
s
.6705 .41622 m
.67064 .41781 L
s
.81977 .40197 m
.81821 .40293 L
s
.78015 .40119 m
.77854 .40166 L
s
.69296 .39874 m
.69304 .3989 L
s
.69288 .39858 m
.69296 .39874 L
s
.69279 .39843 m
.69288 .39858 L
s
.78327 .39814 m
.7833 .39917 L
s
.69214 .39601 m
.69216 .39754 L
s
.6927 .39828 m
.69279 .39843 L
s
.78175 .40071 m
.78015 .40119 L
s
.6926 .39813 m
.6927 .39828 L
s
.7151 .37406 m
.71497 .37554 L
s
.6925 .39798 m
.6926 .39813 L
s
.69239 .39783 m
.6925 .39798 L
s
.67064 .41781 m
.67081 .41941 L
s
.7833 .39917 m
.78334 .40021 L
s
.78334 .40021 m
.78175 .40071 L
s
.69228 .39769 m
.69239 .39783 L
s
.69216 .39754 m
.69228 .39769 L
s
.69216 .39754 m
.69219 .39908 L
s
.69203 .3974 m
.69216 .39754 L
s
.71497 .37554 m
.71486 .37702 L
s
.6919 .39726 m
.69203 .3974 L
s
.78334 .40021 m
.78338 .40125 L
s
.7849 .39968 m
.78334 .40021 L
s
.69177 .39713 m
.6919 .39726 L
s
.64805 .4412 m
.66282 .43524 L
s
.69163 .39699 m
.69177 .39713 L
s
.69149 .39685 m
.69163 .39699 L
s
.67081 .41941 m
.67099 .42099 L
s
.69134 .39672 m
.69149 .39685 L
s
.69118 .39659 m
.69134 .39672 L
s
.78645 .39913 m
.7849 .39968 L
s
.78338 .40125 m
.78343 .4023 L
s
.69219 .39908 m
.69224 .4006 L
s
.71486 .37702 m
.71476 .37849 L
s
.69102 .39646 m
.69118 .39659 L
s
.69085 .39633 m
.69102 .39646 L
s
.69068 .39621 m
.69085 .39633 L
s
.69051 .39608 m
.69068 .39621 L
s
.71056 .39677 m
.727 .39362 L
s
.69033 .39596 m
.69051 .39608 L
s
.78799 .39856 m
.78645 .39913 L
s
.78343 .4023 m
.78348 .40336 L
s
.69014 .39584 m
.69033 .39596 L
s
.67099 .42099 m
.67118 .42258 L
s
.68995 .39572 m
.69014 .39584 L
s
.71476 .37849 m
.71467 .37996 L
s
.68975 .3956 m
.68995 .39572 L
s
.69224 .4006 m
.6923 .40213 L
s
.78348 .40336 m
.78354 .40443 L
s
.7895 .39797 m
.78799 .39856 L
s
.69013 .39517 m
.7035 .38841 L
s
.71467 .37996 m
.7146 .38142 L
s
.76404 .35727 m
.77154 .36759 L
s
.78354 .40443 m
.7836 .4055 L
s
.67118 .42258 m
.6714 .42416 L
s
.6923 .40213 m
.69238 .40364 L
s
.79101 .39736 m
.7895 .39797 L
s
.77228 .37032 m
.77224 .37134 L
s
.7836 .4055 m
.78367 .40658 L
s
.717 .39475 m
.71709 .39511 L
s
.7146 .38142 m
.71455 .38288 L
s
.79249 .39673 m
.79101 .39736 L
s
.73642 .36042 m
.75146 .35646 L
s
.69238 .40364 m
.69248 .40516 L
s
.71689 .39439 m
.717 .39475 L
s
.77224 .37134 m
.77219 .37237 L
s
.6714 .42416 m
.67163 .42573 L
s
.78367 .40658 m
.78374 .40767 L
s
.71678 .39404 m
.71689 .39439 L
s
.79396 .39607 m
.79249 .39673 L
s
.71455 .38288 m
.71451 .38434 L
s
.7688 .35308 m .77208 .34258 L .78244 .34796 L .757 .483 .518 r
F
.76143 .35091 m .77208 .34258 L .7688 .35308 L F
.76143 .35091 m .76106 .33934 L .77208 .34258 L F
.039 .916 .04 r
.71665 .3937 m
.71678 .39404 L
s
.78374 .40767 m
.78383 .40877 L
s
.77219 .37237 m
.77216 .37342 L
s
.69248 .40516 m
.69259 .40667 L
s
.77573 .35668 m .78244 .34796 L .79143 .35513 L .757 .483 .518 r
F
.7688 .35308 m .78244 .34796 L .77573 .35668 L F
0 g
.5 Mabswid
.77208 .34258 m
.78244 .34796 L
s
.039 .916 .04 r
1 Mabswid
.71651 .39335 m
.71665 .3937 L
s
.67163 .42573 m
.67188 .4273 L
s
.79541 .3954 m
.79396 .39607 L
s
.78383 .40877 m
.78391 .40987 L
s
.71451 .38434 m
.71448 .38579 L
s
.71636 .39301 m
.71651 .39335 L
s
.727 .39362 m
.74348 .39046 L
s
.75411 .35033 m .76106 .33934 L .76143 .35091 L .757 .483 .518 r
F
.75411 .35033 m .75009 .33846 L .76106 .33934 L F
0 g
.5 Mabswid
.76106 .33934 m
.77208 .34258 L
s
.76106 .33934 m
.76106 .33934 L
s
.039 .916 .04 r
1 Mabswid
.77216 .37342 m
.77213 .37446 L
s
.66282 .43524 m
.67765 .42927 L
s
.73809 .36209 m
.73792 .36348 L
s
.7162 .39268 m
.71636 .39301 L
s
.78391 .40987 m
.784 .41098 L
s
.69259 .40667 m
.69272 .40817 L
s
.79685 .3947 m
.79541 .3954 L
s
.7803 .41367 m
.78767 .42159 L
s
.71602 .39234 m
.7162 .39268 L
s
.67188 .4273 m
.67215 .42887 L
s
.74582 .38361 m
.7504 .39373 L
s
.71448 .38579 m
.71447 .38723 L
s
.80452 .3875 m
.81484 .39565 L
s
.77213 .37446 m
.7721 .37552 L
s
.784 .41098 m
.7841 .4121 L
s
.71584 .39202 m
.71602 .39234 L
s
.73792 .36348 m
.73776 .36488 L
s
.79827 .39398 m
.79685 .3947 L
s
.71565 .39169 m
.71584 .39202 L
s
.69272 .40817 m
.69286 .40968 L
s
.78174 .36147 m .79143 .35513 L .79847 .3636 L .757 .483 .518 r
F
.77573 .35668 m .79143 .35513 L .78174 .36147 L F
0 g
.5 Mabswid
.78244 .34796 m
.79143 .35513 L
s
.039 .916 .04 r
1 Mabswid
.7841 .4121 m
.7842 .41322 L
s
.71447 .38723 m
.71448 .38868 L
s
.7721 .37552 m
.77209 .37659 L
s
.71544 .39137 m
.71565 .39169 L
s
.73776 .36488 m
.73762 .36627 L
s
.71522 .39105 m
.71544 .39137 L
s
.79967 .39324 m
.79827 .39398 L
s
.7842 .41322 m
.78431 .41436 L
s
.71499 .39073 m
.71522 .39105 L
s
.69286 .40968 m
.69303 .41117 L
s
.71448 .38868 m
.7145 .39012 L
s
.77209 .37659 m
.77207 .37766 L
s
.73762 .36627 m
.73749 .36765 L
s
.74731 .35137 m .75009 .33846 L .75411 .35033 L .757 .483 .518 r
F
.74731 .35137 m .73992 .33999 L .75009 .33846 L F
0 g
.5 Mabswid
.75009 .33846 m
.76106 .33934 L
s
.039 .916 .04 r
1 Mabswid
.78431 .41436 m
.78442 .4155 L
s
.71475 .39042 m
.71499 .39073 L
s
.80106 .39247 m
.79967 .39324 L
s
.7145 .39012 m
.71475 .39042 L
s
.78442 .4155 m
.78454 .41664 L
s
.77207 .37766 m
.77207 .37874 L
s
.73749 .36765 m
.73737 .36903 L
s
.7145 .39012 m
.71454 .39155 L
s
.71424 .38981 m
.7145 .39012 L
s
.69303 .41117 m
.6932 .41267 L
s
.75245 .39086 m
.75094 .39104 L
s
.71397 .38951 m
.71424 .38981 L
s
.80243 .39169 m
.80106 .39247 L
s
.75396 .39067 m
.75245 .39086 L
s
.74348 .39046 m
.76002 .38729 L
s
.71368 .38922 m
.71397 .38951 L
s
.77207 .37874 m
.77207 .37983 L
s
.74077 .38977 m
.74091 .39032 L
s
.73737 .36903 m
.73727 .37041 L
s
.75544 .39046 m
.75396 .39067 L
s
.71454 .39155 m
.71459 .39298 L
s
.71338 .38892 m
.71368 .38922 L
s
.75692 .39023 m
.75544 .39046 L
s
.6932 .41267 m
.6934 .41416 L
s
.71308 .38863 m
.71338 .38892 L
s
.74061 .38922 m
.74077 .38977 L
s
.80378 .39088 m
.80243 .39169 L
s
.75838 .38998 m
.75692 .39023 L
s
.77207 .37983 m
.77208 .38093 L
s
.75146 .35646 m
.76404 .35727 L
s
.7035 .38841 m
.71695 .38161 L
s
.73727 .37041 m
.73718 .37179 L
s
.71276 .38835 m
.71308 .38863 L
s
.78643 .36714 m .79847 .3636 L .80307 .37282 L .757 .483 .518 r
F
.78174 .36147 m .79847 .3636 L .78643 .36714 L F
0 g
.5 Mabswid
.79143 .35513 m
.79847 .3636 L
s
.039 .916 .04 r
1 Mabswid
.75982 .38972 m
.75838 .38998 L
s
.71459 .39298 m
.71466 .39441 L
s
.71243 .38807 m
.71276 .38835 L
s
.74044 .38868 m
.74061 .38922 L
s
.67765 .42927 m
.69254 .42326 L
s
.76125 .38944 m
.75982 .38972 L
s
.6934 .41416 m
.69361 .41564 L
s
.71209 .38779 m
.71243 .38807 L
s
.77208 .38093 m
.77209 .38204 L
s
.80512 .39005 m
.80378 .39088 L
s
.73718 .37179 m
.73711 .37316 L
s
.76267 .38914 m
.76125 .38944 L
s
.71174 .38751 m
.71209 .38779 L
s
.74025 .38815 m
.74044 .38868 L
s
.71137 .38724 m
.71174 .38751 L
s
.76407 .38882 m
.76267 .38914 L
s
.71466 .39441 m
.71474 .39583 L
s
.77209 .38204 m
.77211 .38315 L
s
.711 .38698 m
.71137 .38724 L
s
.74004 .38762 m
.74025 .38815 L
s
.73711 .37316 m
.73705 .37452 L
s
.76546 .38848 m
.76407 .38882 L
s
.74152 .35397 m .73992 .33999 L .74731 .35137 L .757 .483 .518 r
F
.74152 .35397 m .73122 .34386 L .73992 .33999 L F
0 g
.5 Mabswid
.73992 .33999 m
.75009 .33846 L
s
.039 .916 .04 r
1 Mabswid
.69361 .41564 m
.69384 .41712 L
s
.71061 .38671 m
.711 .38698 L
s
.76551 .36364 m .7688 .35308 L .77573 .35668 L .757 .483 .518 r
F
.76181 .36255 m .7688 .35308 L .76551 .36364 L F
.76181 .36255 m .76143 .35091 L .7688 .35308 L F
.039 .916 .04 r
.76684 .38813 m
.76546 .38848 L
s
.71022 .38645 m
.71061 .38671 L
s
.73981 .3871 m
.74004 .38762 L
s
.76898 .36544 m .77573 .35668 L .78174 .36147 L .757 .483 .518 r
F
.76551 .36364 m .77573 .35668 L .76898 .36544 L F
.039 .916 .04 r
.71474 .39583 m
.71484 .39725 L
s
.77211 .38315 m
.77213 .38427 L
s
.70981 .3862 m
.71022 .38645 L
s
.73705 .37452 m
.73701 .37588 L
s
.7682 .38776 m
.76684 .38813 L
s
.75814 .36227 m .76143 .35091 L .76181 .36255 L .757 .483 .518 r
F
.75814 .36227 m .75411 .35033 L .76143 .35091 L F
0 g
.5 Mabswid
.76106 .33934 m
.76143 .35091 L
s
.039 .916 .04 r
1 Mabswid
.70939 .38594 m
.70981 .3862 L
s
.73957 .38658 m
.73981 .3871 L
s
.69384 .41712 m
.69408 .4186 L
s
.76955 .38737 m
.7682 .38776 L
s
.77213 .38427 m
.77216 .3854 L
s
.71484 .39725 m
.71496 .39867 L
s
.76002 .38729 m
.74582 .38361 L
s
.73931 .38607 m
.73957 .38658 L
s
.73701 .37588 m
.73698 .37724 L
s
.77088 .38697 m
.76955 .38737 L
s
.76898 .36544 m .78174 .36147 L .77199 .36785 L .757 .483 .518 r
F
.77199 .36785 m .78174 .36147 L .78643 .36714 L F
.039 .916 .04 r
.77216 .3854 m
.7722 .38654 L
s
.73903 .38556 m
.73931 .38607 L
s
.69408 .4186 m
.69434 .42007 L
s
.7722 .38654 m
.77088 .38697 L
s
.71496 .39867 m
.71508 .40008 L
s
.73698 .37724 m
.73696 .3786 L
s
.75474 .36279 m .75411 .35033 L .75814 .36227 L .757 .483 .518 r
F
.75474 .36279 m .74731 .35137 L .75411 .35033 L F
.039 .916 .04 r
.73874 .38506 m
.73903 .38556 L
s
.7722 .38654 m
.77224 .38769 L
s
.7735 .3861 m
.7722 .38654 L
s
.78949 .3733 m .80307 .37282 L .80491 .38218 L .757 .483 .518 r
F
.78643 .36714 m .80307 .37282 L .78949 .3733 L F
0 g
.5 Mabswid
.79847 .3636 m
.80307 .37282 L
s
.039 .916 .04 r
1 Mabswid
.73842 .38456 m
.73874 .38506 L
s
.73696 .3786 m
.73696 .37995 L
s
.7748 .38564 m
.7735 .3861 L
s
.71508 .40008 m
.71523 .40148 L
s
.77224 .38769 m
.77229 .38884 L
s
.76466 .38476 m
.76484 .38551 L
s
.7381 .38407 m
.73842 .38456 L
s
.77607 .38516 m
.7748 .38564 L
s
.73696 .37995 m
.73697 .38129 L
s
.69254 .42326 m
.70749 .41724 L
s
.77229 .38884 m
.77235 .39001 L
s
.77434 .37069 m .78643 .36714 L .78949 .3733 L .757 .483 .518 r
F
.77199 .36785 m .78643 .36714 L .77434 .37069 L F
.039 .916 .04 r
.73775 .38359 m
.7381 .38407 L
s
.71523 .40148 m
.71539 .40289 L
s
.77287 .40568 m
.7803 .41367 L
s
.77734 .38467 m
.77607 .38516 L
s
.76445 .38402 m
.76466 .38476 L
s
.73738 .38311 m
.73775 .38359 L
s
.77235 .39001 m
.77241 .39118 L
s
.73697 .38129 m
.737 .38264 L
s
.77859 .38415 m
.77734 .38467 L
s
.73711 .35795 m .73122 .34386 L .74152 .35397 L .757 .483 .518 r
F
.73711 .35795 m .7246 .34982 L .73122 .34386 L F
0 g
.5 Mabswid
.73122 .34386 m
.73992 .33999 L
s
.039 .916 .04 r
1 Mabswid
.76422 .38329 m
.76445 .38402 L
s
.75184 .3641 m .74731 .35137 L .75474 .36279 L .757 .483 .518 r
F
.75184 .3641 m .74152 .35397 L .74731 .35137 L F
.039 .916 .04 r
.71539 .40289 m
.71557 .40429 L
s
.737 .38264 m
.73738 .38311 L
s
.77982 .38362 m
.77859 .38415 L
s
.77241 .39118 m
.77247 .39236 L
s
.737 .38264 m
.73705 .38397 L
s
.7366 .38217 m
.737 .38264 L
s
.76397 .38257 m
.76422 .38329 L
s
.78105 .38307 m
.77982 .38362 L
s
.71695 .38161 m
.73048 .37476 L
s
.71557 .40429 m
.71576 .40568 L
s
.77247 .39236 m
.77255 .39354 L
s
.73619 .38171 m
.7366 .38217 L
s
.75994 .36248 m
.75994 .36241 L
s
.73705 .38397 m
.7371 .38531 L
s
.73575 .38125 m
.73619 .38171 L
s
.7637 .38186 m
.76397 .38257 L
s
.78225 .3825 m
.78105 .38307 L
s
.77255 .39354 m
.77263 .39474 L
s
.75985 .36376 m
.75994 .36248 L
s
.71576 .40568 m
.71597 .40707 L
s
.7353 .3808 m
.73575 .38125 L
s
.78949 .3733 m .80491 .38218 L .79069 .37955 L .757 .483 .518 r
F
.77586 .37378 m .78949 .3733 L .79069 .37955 L F
.77434 .37069 m .78949 .3733 L .77586 .37378 L F
.039 .916 .04 r
.7371 .38531 m
.73717 .38664 L
s
.78345 .38192 m
.78225 .3825 L
s
.7634 .38115 m
.7637 .38186 L
s
.77263 .39474 m
.77271 .39594 L
s
.73484 .38035 m
.7353 .3808 L
s
.76219 .37426 m .76551 .36364 L .76898 .36544 L .757 .483 .518 r
F
.76219 .37426 m .76181 .36255 L .76551 .36364 L F
.76219 .37426 m .76898 .36544 L .77199 .36785 L F
.039 .916 .04 r
.78463 .38131 m
.78345 .38192 L
s
.73435 .37991 m
.73484 .38035 L
s
.71597 .40707 m
.71619 .40846 L
s
.77271 .39594 m
.77281 .39715 L
s
.76219 .37426 m .75814 .36227 L .76181 .36255 L .757 .483 .518 r
F
0 g
.5 Mabswid
.76143 .35091 m
.76181 .36255 L
s
.039 .916 .04 r
1 Mabswid
.76308 .38045 m
.7634 .38115 L
s
.73717 .38664 m
.73726 .38797 L
s
.74964 .3661 m .74152 .35397 L .75184 .3641 L .757 .483 .518 r
F
.74964 .3661 m .73711 .35795 L .74152 .35397 L F
.79069 .37955 m .80491 .38218 L .80384 .39105 L F
.039 .916 .04 r
.80429 .38732 m
.80452 .3875 L
s
0 g
.5 Mabswid
.80307 .37282 m
.80491 .38218 L
s
.80491 .38218 m
.80491 .38218 L
s
.039 .916 .04 r
1 Mabswid
.73385 .37948 m
.73435 .37991 L
s
.76219 .37426 m .77199 .36785 L .77434 .37069 L .757 .483 .518 r
F
.039 .916 .04 r
.7858 .38069 m
.78463 .38131 L
s
.77281 .39715 m
.7729 .39837 L
s
.76273 .37975 m
.76308 .38045 L
s
.73333 .37905 m
.73385 .37948 L
s
.76219 .37426 m .75474 .36279 L .75814 .36227 L .757 .483 .518 r
F
.039 .916 .04 r
.71619 .40846 m
.71643 .40984 L
s
.73726 .38797 m
.73736 .38929 L
s
.70749 .41724 m
.72251 .41118 L
s
.73279 .37862 m
.73333 .37905 L
s
.78695 .38005 m
.7858 .38069 L
s
.7729 .39837 m
.77301 .3996 L
s
.76237 .37907 m
.76273 .37975 L
s
.76219 .37426 m .77434 .37069 L .77586 .37378 L .757 .483 .518 r
F
.039 .916 .04 r
.73223 .3782 m
.73279 .37862 L
s
.73736 .38929 m
.73747 .39061 L
s
.71643 .40984 m
.71668 .41122 L
s
.77301 .3996 m
.77312 .40084 L
s
.73166 .37779 m
.73223 .3782 L
s
.76219 .37426 m .75184 .3641 L .75474 .36279 L .757 .483 .518 r
F
.039 .916 .04 r
.76197 .37839 m
.76237 .37907 L
s
.7344 .36307 m .7246 .34982 L .73711 .35795 L .757 .483 .518 r
F
.7344 .36307 m .7205 .35746 L .7246 .34982 L F
0 g
.5 Mabswid
.7246 .34982 m
.73122 .34386 L
s
.039 .916 .04 r
1 Mabswid
.73107 .37739 m
.73166 .37779 L
s
.77312 .40084 m
.77323 .40208 L
s
.73747 .39061 m
.7376 .39193 L
s
.77586 .37378 m .79069 .37955 L .77646 .37691 L .757 .483 .518 r
F
.79069 .37955 m .80384 .39105 L .78996 .38545 L F
.039 .916 .04 r
.79414 .3793 m
.79561 .38046 L
s
.77646 .37691 m .79069 .37955 L .78996 .38545 L .757 .483 .518 r
F
0 g
.5 Mabswid
.79069 .37955 m
.80491 .38218 L
s
.039 .916 .04 r
1 Mabswid
.78851 .37914 m
.78922 .37871 L
s
.76156 .37772 m
.76197 .37839 L
s
.73046 .37698 m
.73107 .37739 L
s
.77323 .40208 m
.77336 .40333 L
s
.76219 .37426 m .77586 .37378 L .77646 .37691 L .757 .483 .518 r
F
.039 .916 .04 r
.72984 .37659 m
.73046 .37698 L
s
.78922 .37871 m
.79033 .37802 L
s
.7376 .39193 m
.73775 .39324 L
s
.76112 .37705 m
.76156 .37772 L
s
.7292 .3762 m
.72984 .37659 L
s
.77336 .40333 m
.77349 .40459 L
s
.76219 .37426 m .74964 .3661 L .75184 .3641 L .757 .483 .518 r
F
.039 .916 .04 r
.75961 .37258 m
.75961 .37261 L
s
.7483 .36866 m .73711 .35795 L .74964 .3661 L .757 .483 .518 r
F
.7483 .36866 m .7344 .36307 L .73711 .35795 L F
.039 .916 .04 r
.76066 .37639 m
.76112 .37705 L
s
.73775 .39324 m
.7379 .39455 L
s
.75961 .37261 m
.75963 .37386 L
s
.77646 .37691 m .78996 .38545 L .77608 .37986 L .757 .483 .518 r
F
.039 .916 .04 r
.78369 .37104 m
.79414 .3793 L
s
.76219 .37426 m .77646 .37691 L .77608 .37986 L .757 .483 .518 r
F
0 g
.5 Mabswid
.77646 .37691 m
.79069 .37955 L
s
.039 .916 .04 r
1 Mabswid
.76017 .37574 m
.76066 .37639 L
s
.7379 .39455 m
.73808 .39585 L
s
.75966 .3751 m
.76017 .37574 L
s
.76219 .37426 m .7483 .36866 L .74964 .3661 L .757 .483 .518 r
F
.039 .916 .04 r
.75963 .37386 m
.75966 .3751 L
s
.73808 .39585 m
.73826 .39715 L
s
.78996 .38545 m .80384 .39105 L .79993 .3988 L .757 .483 .518 r
F
0 g
.5 Mabswid
.80384 .39105 m
.80491 .38218 L
s
.039 .916 .04 r
1 Mabswid
.72251 .41118 m
.73759 .40511 L
s
.75966 .3751 m
.75971 .37634 L
s
.75913 .37447 m
.75966 .3751 L
s
.78996 .38545 m .79993 .3988 L .78734 .39061 L .757 .483 .518 r
F
.77608 .37986 m .78996 .38545 L .78734 .39061 L F
.77608 .37986 m .78734 .39061 L .77476 .38243 L F
.76219 .37426 m .77608 .37986 L .77476 .38243 L F
.039 .916 .04 r
.73826 .39715 m
.73846 .39845 L
s
.76219 .37426 m .7479 .37161 L .7483 .36866 L .757 .483 .518 r
F
.76219 .37426 m .74848 .37475 L .7479 .37161 L F
.039 .916 .04 r
.75905 .37437 m
.75913 .37447 L
s
.76219 .37426 m .74999 .37785 L .74848 .37475 L .757 .483 .518 r
F
.76219 .37426 m .75234 .38071 L .74999 .37785 L F
0 0 0 r
.2933 .53015 m
.75029 .37822 L
s
.76219 .37426 m .75536 .38313 L .75234 .38071 L .757 .483 .518 r
F
.76219 .37426 m .75885 .38495 L .75536 .38313 L F
.76219 .37426 m .76257 .38604 L .75885 .38495 L F
.76219 .37426 m .76627 .38632 L .76257 .38604 L F
.76219 .37426 m .76968 .38578 L .76627 .38632 L F
.76219 .37426 m .77257 .38445 L .76968 .38578 L F
0 0 0 r
.77106 .38514 m
.85788 .49166 L
s
.76219 .37426 m .77476 .38243 L .77257 .38445 L .757 .483 .518 r
F
0 g
.5 Mabswid
.76219 .37426 m
.77646 .37691 L
s
.76181 .36255 m
.76219 .37426 L
s
.039 .916 .04 r
1 Mabswid
.75799 .37322 m
.75829 .37354 L
s
.7479 .37161 m .7344 .36307 L .7483 .36866 L .757 .483 .518 r
F
.039 .916 .04 r
.73846 .39845 m
.73868 .39974 L
s
.73358 .36896 m .7205 .35746 L .7344 .36307 L .757 .483 .518 r
F
.7479 .37161 m .73358 .36896 L .7344 .36307 L F
.039 .916 .04 r
.75739 .37261 m
.75799 .37322 L
s
.73358 .36896 m .71924 .3663 L .7205 .35746 L .757 .483 .518 r
F
0 g
.5 Mabswid
.7205 .35746 m
.7246 .34982 L
s
.039 .916 .04 r
1 Mabswid
.73868 .39974 m
.73891 .40103 L
s
.75676 .372 m
.75739 .37261 L
s
.77476 .38243 m .78298 .39467 L .77257 .38445 L .757 .483 .518 r
F
.77476 .38243 m .78734 .39061 L .78298 .39467 L F
.039 .916 .04 r
.75611 .37141 m
.75676 .372 L
s
.74848 .37475 m .73358 .36896 L .7479 .37161 L .757 .483 .518 r
F
0 g
.5 Mabswid
.7479 .37161 m
.76219 .37426 L
s
.039 .916 .04 r
1 Mabswid
.73048 .37476 m
.73832 .3708 L
s
.73891 .40103 m
.73916 .40231 L
s
.75544 .37082 m
.75611 .37141 L
s
.78734 .39061 m .79342 .40492 L .78298 .39467 L .757 .483 .518 r
F
.78734 .39061 m .79993 .3988 L .79342 .40492 L F
0 g
.5 Mabswid
.79993 .3988 m
.80384 .39105 L
s
.039 .916 .04 r
1 Mabswid
.75474 .37023 m
.75544 .37082 L
s
.77257 .38445 m .77719 .39734 L .76968 .38578 L .757 .483 .518 r
F
.77257 .38445 m .78298 .39467 L .77719 .39734 L F
.039 .916 .04 r
.75402 .36966 m
.75474 .37023 L
s
.73759 .40511 m
.75273 .399 L
s
.74848 .37475 m .73471 .37523 L .73358 .36896 L .757 .483 .518 r
F
.039 .916 .04 r
.73971 .37009 m
.7441 .36787 L
s
.74999 .37785 m .73471 .37523 L .74848 .37475 L .757 .483 .518 r
F
.039 .916 .04 r
.7441 .36787 m
.78369 .37104 L
s
.75327 .36909 m
.75402 .36966 L
s
.73471 .37523 m .71924 .3663 L .73358 .36896 L .757 .483 .518 r
F
0 g
.5 Mabswid
.73358 .36896 m
.7479 .37161 L
s
.76968 .38578 m .77036 .39844 L .76627 .38632 L .757 .483 .518 r
F
.76968 .38578 m .77719 .39734 L .77036 .39844 L F
.039 .916 .04 r
1 Mabswid
.7525 .36853 m
.75327 .36909 L
s
.76047 .38543 m
.76057 .38615 L
s
.74999 .37785 m .73773 .38145 L .73471 .37523 L .757 .483 .518 r
F
.75234 .38071 m .73773 .38145 L .74999 .37785 L F
.039 .916 .04 r
.75171 .36798 m
.7525 .36853 L
s
.76057 .38615 m
.76073 .38736 L
s
.75089 .36743 m
.75171 .36798 L
s
.76627 .38632 m .76296 .39789 L .76257 .38604 L .757 .483 .518 r
F
.76627 .38632 m .77036 .39844 L .76296 .39789 L F
.039 .916 .04 r
.76582 .3981 m
.77287 .40568 L
s
.75234 .38071 m .74243 .3872 L .73773 .38145 L .757 .483 .518 r
F
.75536 .38313 m .74243 .3872 L .75234 .38071 L F
.039 .916 .04 r
.75005 .3669 m
.75089 .36743 L
s
.73471 .37523 m .72091 .37572 L .71924 .3663 L .757 .483 .518 r
F
0 g
.5 Mabswid
.71924 .3663 m
.73358 .36896 L
s
.71924 .3663 m
.7205 .35746 L
s
.71924 .3663 m
.71924 .3663 L
s
.78298 .39467 m .78474 .40896 L .77719 .39734 L .757 .483 .518 r
F
.78298 .39467 m .79342 .40492 L .78474 .40896 L F
0 g
.79342 .40492 m
.79993 .3988 L
s
.76257 .38604 m .7555 .39571 L .75885 .38495 L .757 .483 .518 r
F
.76257 .38604 m .76296 .39789 L .7555 .39571 L F
0 g
.76219 .37426 m
.76257 .38604 L
s
.039 .916 .04 r
1 Mabswid
.74919 .36637 m
.75005 .3669 L
s
.75536 .38313 m .74849 .39206 L .74243 .3872 L .757 .483 .518 r
F
.75885 .38495 m .74849 .39206 L .75536 .38313 L F
.75885 .38495 m .7555 .39571 L .74849 .39206 L F
.73773 .38145 m .72091 .37572 L .73471 .37523 L F
.039 .916 .04 r
.75273 .399 m
.76295 .39788 L
s
.77719 .39734 m .77448 .41063 L .77036 .39844 L .757 .483 .518 r
F
.77719 .39734 m .78474 .40896 L .77448 .41063 L F
0 g
.5 Mabswid
.78474 .40896 m
.79342 .40492 L
s
.73773 .38145 m .72542 .38507 L .72091 .37572 L .757 .483 .518 r
F
0 g
.71924 .3663 m
.72091 .37572 L
s
.74243 .3872 m .72542 .38507 L .73773 .38145 L .757 .483 .518 r
F
.77036 .39844 m .76335 .4098 L .76296 .39789 L F
.77036 .39844 m .77448 .41063 L .76335 .4098 L F
.74243 .3872 m .73247 .39372 L .72542 .38507 L F
0 g
.72091 .37572 m
.72542 .38507 L
s
.74849 .39206 m .73247 .39372 L .74243 .3872 L .757 .483 .518 r
F
.76296 .39789 m .75212 .40653 L .7555 .39571 L F
.76296 .39789 m .76335 .4098 L .75212 .40653 L F
0 g
.76257 .38604 m
.76296 .39789 L
s
.76296 .39789 m
.76335 .4098 L
s
.74849 .39206 m .74158 .40104 L .73247 .39372 L .757 .483 .518 r
F
.7555 .39571 m .74158 .40104 L .74849 .39206 L F
.7555 .39571 m .75212 .40653 L .74158 .40104 L F
0 g
.77448 .41063 m
.78474 .40896 L
s
.72542 .38507 m
.73247 .39372 L
s
.76335 .4098 m
.77448 .41063 L
s
.73247 .39372 m
.74158 .40104 L
s
.75212 .40653 m
.76335 .4098 L
s
.76335 .4098 m
.76335 .4098 L
s
.74158 .40104 m
.75212 .40653 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.431973 0.0136054 0.97619 0.557823 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.039 .916 .04 r
1 Mabswid
[ ] 0 setdash
.15351 .62788 m
.16651 .62387 L
s
.16651 .62387 m
.17956 .61985 L
s
.14643 .62162 m
.14897 .62401 L
s
.14389 .61923 m
.14643 .62162 L
s
.17956 .61985 m
.19265 .61581 L
s
.14133 .61683 m
.14389 .61923 L
s
.16599 .61556 m
.16851 .61797 L
s
.19265 .61581 m
.20579 .61176 L
s
.13877 .61443 m
.14133 .61683 L
s
.16346 .61315 m
.16599 .61556 L
s
.1362 .61202 m
.13877 .61443 L
s
.16092 .61074 m
.16346 .61315 L
s
.20579 .61176 m
.21897 .6077 L
s
.18565 .60947 m
.18816 .61189 L
s
.11308 .53744 m
.1261 .5329 L
s
.13362 .60961 m
.1362 .61202 L
s
.15837 .60832 m
.16092 .61074 L
s
.18313 .60704 m
.18565 .60947 L
s
.21897 .6077 m
.2322 .60362 L
s
.11179 .54274 m
.11174 .54568 L
s
.13104 .60719 m
.13362 .60961 L
s
.15581 .6059 m
.15837 .60832 L
s
.1261 .5329 m
.13915 .52834 L
s
.1806 .60461 m
.18313 .60704 L
s
.11174 .54568 m
.11167 .54864 L
s
.2054 .60335 m
.2079 .60579 L
s
.12844 .60477 m
.13104 .60719 L
s
.11167 .54864 m
.1116 .5516 L
s
.2322 .60362 m
.24548 .59953 L
s
.15324 .60347 m
.15581 .6059 L
s
.17806 .60218 m
.1806 .60461 L
s
.2029 .60091 m
.2054 .60335 L
s
.1116 .5516 m
.11152 .55456 L
s
.13915 .52834 m
.15225 .52377 L
s
.13133 .53597 m
.13129 .53895 L
s
.12583 .60235 m
.12844 .60477 L
s
0 g
.5 Mabswid
.32605 .5088 m
.33377 .53427 L
s
.31587 .48472 m
.32605 .5088 L
s
.039 .916 .04 r
1 Mabswid
.15067 .60103 m
.15324 .60347 L
s
.11152 .55456 m
.11143 .55754 L
s
0 g
.5 Mabswid
.33377 .53427 m
.33857 .55956 L
s
.039 .916 .04 r
1 Mabswid
.17552 .59974 m
.17806 .60218 L
s
.13129 .53895 m
.13124 .54193 L
s
.20038 .59846 m
.2029 .60091 L
s
.24548 .59953 m
.2588 .59543 L
s
.22526 .59719 m
.22775 .59965 L
s
.11143 .55754 m
.11133 .56052 L
s
.12322 .59991 m
.12583 .60235 L
s
.15225 .52377 m
.16539 .51918 L
s
.13124 .54193 m
.13118 .54492 L
s
.14808 .5986 m
.15067 .60103 L
s
.17296 .59729 m
.17552 .59974 L
s
.11133 .56052 m
.11122 .56351 L
s
.19786 .596 m
.20038 .59846 L
s
0 g
.5 Mabswid
.30386 .46354 m
.31587 .48472 L
s
.039 .916 .04 r
1 Mabswid
.22277 .59473 m
.22526 .59719 L
s
.13118 .54492 m
.13111 .54792 L
s
.1206 .59748 m
.12322 .59991 L
s
.15097 .52917 m
.15094 .53218 L
s
.2588 .59543 m
.27217 .59131 L
s
.11122 .56351 m
.1111 .56651 L
s
.14549 .59615 m
.14808 .5986 L
s
0 g
.5 Mabswid
.33857 .55956 m
.34011 .58308 L
s
.039 .916 .04 r
1 Mabswid
.1704 .59484 m
.17296 .59729 L
s
.13111 .54792 m
.13104 .55092 L
s
.16539 .51918 m
.17858 .51458 L
s
.19533 .59355 m
.19786 .596 L
s
.15094 .53218 m
.15091 .53519 L
s
.1111 .56651 m
.11098 .56951 L
s
.22027 .59227 m
.22277 .59473 L
s
.24523 .59101 m
.2477 .59348 L
s
.11797 .59504 m
.1206 .59748 L
s
.13104 .55092 m
.13095 .55394 L
s
.14289 .5937 m
.14549 .59615 L
s
.15091 .53519 m
.15086 .53821 L
s
.11098 .56951 m
.11084 .57252 L
s
.16783 .59239 m
.1704 .59484 L
s
.27217 .59131 m
.28558 .58718 L
s
.19279 .59108 m
.19533 .59355 L
s
.13095 .55394 m
.13085 .55696 L
s
.21776 .5898 m
.22027 .59227 L
s
.15086 .53821 m
.15081 .54124 L
s
.11084 .57252 m
.1107 .57554 L
s
.17858 .51458 m
.19181 .50996 L
s
.24275 .58853 m
.24523 .59101 L
s
.11533 .59259 m
.11797 .59504 L
s
.17071 .52234 m
.17069 .52537 L
s
.14028 .59125 m
.14289 .5937 L
s
.13085 .55696 m
.13075 .55999 L
s
.16525 .58992 m
.16783 .59239 L
s
.1107 .57554 m
.11054 .57856 L
s
.15081 .54124 m
.15074 .54428 L
s
.19024 .58862 m
.19279 .59108 L
s
.21524 .58732 m
.21776 .5898 L
s
.17069 .52537 m
.17067 .52842 L
s
.13075 .55999 m
.13064 .56302 L
s
.28558 .58718 m
.29904 .58303 L
s
.24026 .58605 m
.24275 .58853 L
s
.11268 .59014 m
.11533 .59259 L
s
0 g
.5 Mabswid
.29076 .44662 m
.30386 .46354 L
s
.039 .916 .04 r
1 Mabswid
.2653 .58479 m
.26775 .58728 L
s
.11054 .57856 m
.11038 .58159 L
s
.15074 .54428 m
.15067 .54732 L
s
.13767 .58879 m
.14028 .59125 L
s
.19181 .50996 m
.20509 .50532 L
s
.16267 .58746 m
.16525 .58992 L
s
.17067 .52842 m
.17064 .53147 L
s
.13064 .56302 m
.13051 .56606 L
s
.18768 .58614 m
.19024 .58862 L
s
.11038 .58159 m
.11021 .58463 L
s
.21272 .58484 m
.21524 .58732 L
s
.15067 .54732 m
.15059 .55037 L
s
0 g
.5 Mabswid
.34011 .58308 m
.33826 .60334 L
s
.34011 .58308 m
.32342 .56585 L
s
.34011 .58308 m
.34011 .58308 L
s
.039 .916 .04 r
1 Mabswid
.11003 .58768 m
.11268 .59014 L
s
.23777 .58356 m
.24026 .58605 L
s
.17064 .53147 m
.1706 .53453 L
s
.13051 .56606 m
.13038 .56911 L
s
.26283 .58229 m
.2653 .58479 L
s
.13504 .58633 m
.13767 .58879 L
s
.19054 .51547 m
.19055 .51854 L
s
.11021 .58463 m
.11003 .58768 L
s
.16007 .58499 m
.16267 .58746 L
s
.29904 .58303 m
.31254 .57887 L
s
.15059 .55037 m
.1505 .55343 L
s
.18512 .58366 m
.18768 .58614 L
s
.1706 .53453 m
.17055 .5376 L
s
.13038 .56911 m
.13024 .57217 L
s
.20509 .50532 m
.21841 .50067 L
s
.21018 .58236 m
.21272 .58484 L
s
.19055 .51854 m
.19054 .52161 L
s
.11003 .58768 m
.10984 .59073 L
s
0 0 0 r
.11003 .58768 m
.28918 .5305 L
s
.039 .916 .04 r
.10736 .58522 m
.11003 .58768 L
s
.23526 .58107 m
.23777 .58356 L
s
.1505 .55343 m
.1504 .5565 L
s
.26036 .57979 m
.26283 .58229 L
s
.13241 .58386 m
.13504 .58633 L
s
.28547 .57854 m
.28791 .58104 L
s
.17055 .5376 m
.17049 .54067 L
s
.13024 .57217 m
.13009 .57523 L
s
.15747 .58251 m
.16007 .58499 L
s
.10984 .59073 m
.10964 .5938 L
s
.19054 .52161 m
.19052 .52469 L
s
.18254 .58118 m
.18512 .58366 L
s
.1504 .5565 m
.15029 .55957 L
s
.20764 .57987 m
.21018 .58236 L
s
.31254 .57887 m
.3261 .57469 L
s
.13009 .57523 m
.12993 .5783 L
s
.10469 .58275 m
.10736 .58522 L
s
.17049 .54067 m
.17043 .54375 L
s
.23275 .57857 m
.23526 .58107 L
s
.25788 .57729 m
.26036 .57979 L
s
.10964 .5938 m
.10943 .59686 L
s
.12976 .58138 m
.13241 .58386 L
s
.21841 .50067 m
.23177 .496 L
s
.19052 .52469 m
.1905 .52778 L
s
.15029 .55957 m
.15017 .56265 L
s
.28302 .57603 m
.28547 .57854 L
s
.15485 .58003 m
.15747 .58251 L
s
.21048 .50857 m
.2105 .51166 L
s
.12993 .5783 m
.12976 .58138 L
s
.17996 .57869 m
.18254 .58118 L
s
.17043 .54375 m
.17035 .54684 L
s
.10943 .59686 m
.10921 .59994 L
s
.20509 .57737 m
.20764 .57987 L
s
.1905 .52778 m
.19046 .53088 L
s
.15017 .56265 m
.15004 .56574 L
s
.10201 .58028 m
.10469 .58275 L
s
.23023 .57607 m
.23275 .57857 L
s
.2105 .51166 m
.21051 .51477 L
s
.25539 .57478 m
.25788 .57729 L
s
.12976 .58138 m
.12958 .58447 L
s
.12711 .5789 m
.12976 .58138 L
s
.17035 .54684 m
.17026 .54994 L
s
.3261 .57469 m
.33869 .56945 L
s
.28056 .57351 m
.28302 .57603 L
s
.10921 .59994 m
.10899 .60302 L
s
.15223 .57754 m
.15485 .58003 L
s
.19046 .53088 m
.19042 .53399 L
s
.30575 .57225 m
.30818 .57478 L
s
.15004 .56574 m
.1499 .56884 L
s
.17737 .5762 m
.17996 .57869 L
s
.23177 .496 m
.24518 .49132 L
s
.21051 .51477 m
.21051 .51788 L
s
.12958 .58447 m
.1294 .58756 L
s
.20253 .57487 m
.20509 .57737 L
s
0 g
.5 Mabswid
.29076 .44662 m
.29076 .44662 L
s
.29076 .44662 m
.29024 .47421 L
s
.27738 .43513 m
.29076 .44662 L
s
.039 .916 .04 r
1 Mabswid
.17026 .54994 m
.17017 .55305 L
s
.09932 .5778 m
.10201 .58028 L
s
.10899 .60302 m
.10875 .60611 L
s
.2277 .57356 m
.23023 .57607 L
s
.19042 .53399 m
.19037 .5371 L
s
.1499 .56884 m
.14976 .57194 L
s
.12445 .57642 m
.12711 .5789 L
s
.25289 .57226 m
.25539 .57478 L
s
.21051 .51788 m
.2105 .521 L
s
.27809 .57099 m
.28056 .57351 L
s
.1496 .57505 m
.15223 .57754 L
s
.1294 .58756 m
.1292 .59066 L
s
.17017 .55305 m
.17006 .55616 L
s
.30331 .56972 m
.30575 .57225 L
s
.23052 .50163 m
.23056 .50476 L
s
.10875 .60611 m
.1085 .60921 L
s
.17477 .5737 m
.17737 .5762 L
s
.19037 .5371 m
.1903 .54022 L
s
.14976 .57194 m
.1496 .57505 L
s
.19996 .57236 m
.20253 .57487 L
s
0 g
.5 Mabswid
.33826 .60334 m
.33309 .61896 L
s
.039 .916 .04 r
1 Mabswid
.09662 .57532 m
.09932 .5778 L
s
.22516 .57104 m
.2277 .57356 L
s
.1292 .59066 m
.12899 .59377 L
s
.2105 .521 m
.21048 .52413 L
s
.24518 .49132 m
.25864 .48662 L
s
.17006 .55616 m
.16995 .55928 L
s
.1085 .60921 m
.10825 .61232 L
s
.12178 .57393 m
.12445 .57642 L
s
.25038 .56974 m
.25289 .57226 L
s
.23056 .50476 m
.23058 .50789 L
s
.33869 .56945 m
.35083 .56365 L
s
.27562 .56846 m
.27809 .57099 L
s
.1496 .57505 m
.14944 .57817 L
s
.14696 .57255 m
.1496 .57505 L
s
.1903 .54022 m
.19023 .54335 L
s
.30087 .56719 m
.30331 .56972 L
s
.17216 .57119 m
.17477 .5737 L
s
.12899 .59377 m
.12878 .59689 L
s
.21048 .52413 m
.21045 .52727 L
s
.16995 .55928 m
.16982 .56241 L
s
.10825 .61232 m
.10798 .61543 L
s
.19738 .56985 m
.19996 .57236 L
s
.23058 .50789 m
.23059 .51103 L
s
.09391 .57283 m
.09662 .57532 L
s
.14944 .57817 m
.14926 .58129 L
s
.22262 .56853 m
.22516 .57104 L
s
.19023 .54335 m
.19015 .54649 L
s
.1191 .57143 m
.12178 .57393 L
s
.24787 .56722 m
.25038 .56974 L
s
.12878 .59689 m
.12855 .60001 L
s
.21045 .52727 m
.21041 .53041 L
s
.16982 .56241 m
.16969 .56554 L
s
.10798 .61543 m
.10771 .61855 L
s
.27314 .56592 m
.27562 .56846 L
s
.14431 .57005 m
.14696 .57255 L
s
.25864 .48662 m
.27214 .48191 L
s
.23059 .51103 m
.2306 .51419 L
s
.29842 .56465 m
.30087 .56719 L
s
.16955 .56868 m
.17216 .57119 L
s
.14926 .58129 m
.14908 .58443 L
s
.19015 .54649 m
.19006 .54963 L
s
.25066 .49466 m
.25071 .49781 L
s
0 g
.5 Mabswid
.32342 .56585 m
.30644 .54832 L
s
.039 .916 .04 r
1 Mabswid
.19479 .56733 m
.19738 .56985 L
s
.12855 .60001 m
.12832 .60314 L
s
.21041 .53041 m
.21036 .53356 L
s
.09119 .57034 m
.09391 .57283 L
s
.10771 .61855 m
.10743 .62167 L
s
.16969 .56554 m
.16955 .56868 L
s
.22006 .566 m
.22262 .56853 L
s
.33573 .56264 m
.33957 .56472 L
s
.2306 .51419 m
.2306 .51735 L
s
.11641 .56893 m
.1191 .57143 L
s
.24534 .56469 m
.24787 .56722 L
s
.14908 .58443 m
.14888 .58757 L
s
.19006 .54963 m
.18996 .55278 L
s
.35083 .56365 m
.36303 .55783 L
s
.25071 .49781 m
.25075 .50098 L
s
.14166 .56754 m
.14431 .57005 L
s
.27064 .56339 m
.27314 .56592 L
s
.12832 .60314 m
.12808 .60628 L
s
.10743 .62167 m
.10714 .62481 L
s
.29596 .5621 m
.29842 .56465 L
s
.21036 .53356 m
.2103 .53672 L
s
.16955 .56868 m
.16939 .57184 L
s
.16692 .56617 m
.16955 .56868 L
s
.2306 .51735 m
.23058 .52051 L
s
.1922 .56481 m
.19479 .56733 L
s
.27214 .48191 m
.28569 .47717 L
s
.14888 .58757 m
.14868 .59072 L
s
.33198 .56053 m
.33573 .56264 L
s
.08846 .56784 m
.09119 .57034 L
s
.18996 .55278 m
.18985 .55594 L
s
.25075 .50098 m
.25079 .50415 L
s
.2175 .56347 m
.22006 .566 L
s
.12808 .60628 m
.12782 .60942 L
s
.10714 .62481 m
.10684 .62795 L
s
.11372 .56643 m
.11641 .56893 L
s
.24281 .56215 m
.24534 .56469 L
s
.2103 .53672 m
.21024 .53989 L
s
.16939 .57184 m
.16923 .57499 L
s
.13899 .56503 m
.14166 .56754 L
s
.26814 .56084 m
.27064 .56339 L
s
.23058 .52051 m
.23056 .52369 L
s
.14868 .59072 m
.14847 .59387 L
s
.18985 .55594 m
.18973 .55911 L
s
.29349 .55955 m
.29596 .5621 L
s
.16429 .56365 m
.16692 .56617 L
s
.12782 .60942 m
.12756 .61258 L
s
.25079 .50415 m
.25081 .50733 L
s
.10684 .62795 m
.10652 .6311 L
s
.32832 .55838 m
.33198 .56053 L
s
.27091 .48765 m
.27097 .49083 L
s
.1896 .56229 m
.1922 .56481 L
s
.16923 .57499 m
.16906 .57816 L
s
.21024 .53989 m
.21016 .54307 L
s
0 g
.5 Mabswid
.80043 .43385 m
.78183 .45318 L
s
.82285 .41836 m
.80043 .43385 L
s
.039 .916 .04 r
1 Mabswid
.08573 .56534 m
.08846 .56784 L
s
.21493 .56094 m
.2175 .56347 L
s
.14847 .59387 m
.14824 .59704 L
s
.23056 .52369 m
.23053 .52687 L
s
.11101 .56392 m
.11372 .56643 L
s
.18973 .55911 m
.1896 .56229 L
s
.24027 .55961 m
.24281 .56215 L
s
.12756 .61258 m
.12729 .61574 L
s
.28569 .47717 m
.29927 .47333 L
s
.25081 .50733 m
.25082 .51052 L
s
.10652 .6311 m
.1062 .63425 L
s
.13632 .56251 m
.13899 .56503 L
s
.36303 .55783 m
.3753 .55197 L
s
.26563 .55829 m
.26814 .56084 L
s
0 g
.5 Mabswid
.29024 .47421 m
.28971 .50216 L
s
.039 .916 .04 r
1 Mabswid
.16906 .57816 m
.16888 .58133 L
s
.27097 .49083 m
.27103 .49403 L
s
0 g
.5 Mabswid
.78183 .45318 m
.76822 .47513 L
s
.039 .916 .04 r
1 Mabswid
.21016 .54307 m
.21007 .54625 L
s
0 g
.5 Mabswid
.84765 .40772 m
.82285 .41836 L
s
.039 .916 .04 r
1 Mabswid
.29101 .55699 m
.29349 .55955 L
s
.16164 .56112 m
.16429 .56365 L
s
.32475 .55619 m
.32832 .55838 L
s
.14824 .59704 m
.14801 .60021 L
s
.23053 .52687 m
.23048 .53006 L
s
0 g
.5 Mabswid
.26459 .42992 m
.27738 .43513 L
s
.039 .916 .04 r
1 Mabswid
.1896 .56229 m
.18946 .56547 L
s
.18698 .55975 m
.1896 .56229 L
s
.12729 .61574 m
.12701 .6189 L
s
.08298 .56283 m
.08573 .56534 L
s
.25082 .51052 m
.25082 .51372 L
s
.35384 .55443 m
.35746 .55641 L
s
.21234 .5584 m
.21493 .56094 L
s
.16888 .58133 m
.16869 .58452 L
s
.21007 .54625 m
.20998 .54944 L
s
.27103 .49403 m
.27108 .49723 L
s
.1083 .5614 m
.11101 .56392 L
s
.23772 .55706 m
.24027 .55961 L
s
.14801 .60021 m
.14777 .60339 L
s
.13364 .55999 m
.13632 .56251 L
s
.23048 .53006 m
.23043 .53326 L
s
.26312 .55574 m
.26563 .55829 L
s
.12701 .6189 m
.12672 .62208 L
s
.18946 .56547 m
.18931 .56866 L
s
.32127 .55397 m
.32475 .55619 L
s
.28852 .55443 m
.29101 .55699 L
s
.15899 .55859 m
.16164 .56112 L
s
.25082 .51372 m
.25081 .51693 L
s
.16869 .58452 m
.16849 .5877 L
s
.20998 .54944 m
.20987 .55264 L
s
.27108 .49723 m
.27112 .50045 L
s
.3503 .55241 m
.35384 .55443 L
s
.18436 .55721 m
.18698 .55975 L
s
.29927 .47333 m
.31289 .46993 L
s
.14777 .60339 m
.14752 .60657 L
s
.08023 .56032 m
.08298 .56283 L
s
.12672 .62208 m
.12642 .62526 L
s
.20975 .55585 m
.21234 .5584 L
s
.1069 .63914 m
.12018 .63531 L
s
.23043 .53326 m
.23037 .53647 L
s
0 g
.5 Mabswid
.33309 .61896 m
.32485 .62881 L
s
.039 .916 .04 r
1 Mabswid
.18931 .56866 m
.18915 .57186 L
s
.10558 .55888 m
.1083 .5614 L
s
.23516 .55451 m
.23772 .55706 L
s
.25081 .51693 m
.25079 .52014 L
s
.16849 .5877 m
.16828 .5909 L
s
.13094 .55746 m
.13364 .55999 L
s
.31788 .55172 m
.32127 .55397 L
s
.20987 .55264 m
.20975 .55585 L
s
0 g
.5 Mabswid
.76822 .47513 m
.76052 .49832 L
s
.039 .916 .04 r
1 Mabswid
.26059 .55318 m
.26312 .55574 L
s
.27112 .50045 m
.27115 .50367 L
s
.3753 .55197 m
.38762 .54609 L
s
.14752 .60657 m
.14726 .60977 L
s
.29611 .47922 m
.29557 .48263 L
s
0 g
.5 Mabswid
.87328 .40263 m
.84765 .40772 L
s
.84765 .40772 m
.84765 .40772 L
s
.84765 .40772 m
.85092 .43529 L
s
.039 .916 .04 r
1 Mabswid
.15633 .55606 m
.15899 .55859 L
s
.28603 .55186 m
.28852 .55443 L
s
.12642 .62526 m
.12611 .62845 L
s
.34685 .55037 m
.3503 .55241 L
s
.23037 .53647 m
.2303 .53969 L
s
.18915 .57186 m
.18898 .57506 L
s
.18173 .55467 m
.18436 .55721 L
s
.07747 .5578 m
.08023 .56032 L
s
.25079 .52014 m
.25077 .52337 L
s
.16828 .5909 m
.16806 .59411 L
s
.20975 .55585 m
.20963 .55907 L
s
.20716 .5533 m
.20975 .55585 L
s
.29557 .48263 m
.29506 .48604 L
s
.14726 .60977 m
.14699 .61297 L
s
.27115 .50367 m
.27116 .5069 L
s
.10285 .55635 m
.10558 .55888 L
s
.2326 .55195 m
.23516 .55451 L
s
.31458 .54942 m
.31788 .55172 L
s
.18898 .57506 m
.1888 .57828 L
s
.2303 .53969 m
.23021 .54291 L
s
.12824 .55493 m
.13094 .55746 L
s
.25805 .55061 m
.26059 .55318 L
s
.34348 .54829 m
.34685 .55037 L
s
.31289 .46993 m
.32657 .46651 L
s
.16806 .59411 m
.16783 .59732 L
s
.25077 .52337 m
.25073 .5266 L
s
.12018 .63531 m
.13351 .63147 L
s
.15366 .55352 m
.15633 .55606 L
s
.28353 .54929 m
.28603 .55186 L
s
.20963 .55907 m
.20949 .56229 L
s
.29506 .48604 m
.29459 .48943 L
s
.14699 .61297 m
.14671 .61618 L
s
.27116 .5069 m
.27117 .51014 L
s
.1791 .55212 m
.18173 .55467 L
s
.0747 .55527 m
.07747 .5578 L
s
.1888 .57828 m
.18862 .5815 L
s
.23021 .54291 m
.23012 .54614 L
s
.37207 .54615 m
.37548 .54803 L
s
.20455 .55074 m
.20716 .5533 L
s
.10011 .55382 m
.10285 .55635 L
s
.16783 .59732 m
.16759 .60054 L
s
.31137 .5471 m
.31458 .54942 L
s
.25073 .5266 m
.25068 .52984 L
s
.23002 .54938 m
.2326 .55195 L
s
.3402 .54617 m
.34348 .54829 L
s
.20949 .56229 m
.20935 .56552 L
s
.14671 .61618 m
.14642 .6194 L
s
.29459 .48943 m
.29415 .49283 L
s
.12553 .55239 m
.12824 .55493 L
s
.25551 .54804 m
.25805 .55061 L
s
.27117 .51014 m
.27117 .51338 L
s
.18862 .5815 m
.18842 .58473 L
s
.38762 .54609 m
.40001 .54018 L
s
.15098 .55097 m
.15366 .55352 L
s
.23012 .54614 m
.23002 .54938 L
s
.28102 .54671 m
.28353 .54929 L
s
0 g
.5 Mabswid
.30644 .54832 m
.28918 .5305 L
s
.039 .916 .04 r
1 Mabswid
.36875 .54424 m
.37207 .54615 L
s
.16759 .60054 m
.16734 .60377 L
s
.17645 .54957 m
.1791 .55212 L
s
.25068 .52984 m
.25063 .53309 L
s
.07192 .55274 m
.0747 .55527 L
s
.14642 .6194 m
.14612 .62262 L
s
.29415 .49283 m
.29374 .49621 L
s
.20935 .56552 m
.20919 .56876 L
s
.31646 .474 m
.31595 .47732 L
s
.20193 .54818 m
.20455 .55074 L
s
.27117 .51338 m
.27116 .51664 L
s
.13351 .63147 m
.14689 .62761 L
s
.33701 .54403 m
.3402 .54617 L
s
.30826 .54473 m
.31137 .5471 L
s
.09736 .55128 m
.10011 .55382 L
s
.18842 .58473 m
.18821 .58797 L
s
.32657 .46651 m
.34031 .46307 L
s
.23002 .54938 m
.22991 .55263 L
s
.22744 .54681 m
.23002 .54938 L
s
.12281 .54984 m
.12553 .55239 L
s
.16734 .60377 m
.16708 .607 L
s
.25296 .54546 m
.25551 .54804 L
s
0 g
.5 Mabswid
.76052 .49832 m
.75929 .52125 L
s
.039 .916 .04 r
1 Mabswid
.3655 .5423 m
.36875 .54424 L
s
.25063 .53309 m
.25056 .53634 L
s
.29374 .49621 m
.29337 .49959 L
s
.20919 .56876 m
.20903 .57201 L
s
.31595 .47732 m
.31548 .48063 L
s
.14829 .54842 m
.15098 .55097 L
s
.27849 .54413 m
.28102 .54671 L
s
0 g
.5 Mabswid
.89807 .40348 m
.87328 .40263 L
s
.039 .916 .04 r
1 Mabswid
.27116 .51664 m
.27114 .5199 L
s
.18821 .58797 m
.18799 .59122 L
s
.17379 .54701 m
.17645 .54957 L
s
.22991 .55263 m
.22979 .55589 L
s
.06913 .55021 m
.07192 .55274 L
s
.3339 .54185 m
.33701 .54403 L
s
.16708 .607 m
.16681 .61025 L
s
.19931 .54561 m
.20193 .54818 L
s
0 g
.5 Mabswid
.28971 .50216 m
.28918 .5305 L
s
.039 .916 .04 r
1 Mabswid
.30523 .54233 m
.30826 .54473 L
s
.0946 .54874 m
.09736 .55128 L
s
.31548 .48063 m
.31503 .48394 L
s
.29337 .49959 m
.29303 .50297 L
s
.25056 .53634 m
.25048 .53961 L
s
.20903 .57201 m
.20885 .57526 L
s
.22484 .54424 m
.22744 .54681 L
s
.36234 .54033 m
.3655 .5423 L
s
.12009 .54729 m
.12281 .54984 L
s
.27114 .5199 m
.27111 .52317 L
s
.18799 .59122 m
.18777 .59447 L
s
.2504 .54288 m
.25296 .54546 L
s
.22979 .55589 m
.22966 .55915 L
s
.16681 .61025 m
.16654 .6135 L
s
.1456 .54586 m
.14829 .54842 L
s
.27597 .54154 m
.27849 .54413 L
s
.14689 .62761 m
.16032 .62374 L
s
.40001 .54018 m
.41246 .53423 L
s
.31503 .48394 m
.31462 .48724 L
s
.29303 .50297 m
.29272 .50634 L
s
.20885 .57526 m
.20867 .57853 L
s
.25048 .53961 m
.2504 .54288 L
s
.17113 .54444 m
.17379 .54701 L
s
.33088 .53963 m
.3339 .54185 L
s
.34031 .46307 m
.3541 .45963 L
s
.39044 .53782 m
.39363 .53959 L
s
.3023 .53989 m
.30523 .54233 L
s
.18777 .59447 m
.18753 .59773 L
s
.19667 .54304 m
.19931 .54561 L
s
.27111 .52317 m
.27107 .52645 L
s
.35926 .53833 m
.36234 .54033 L
s
.09183 .54619 m
.0946 .54874 L
s
.22966 .55915 m
.22952 .56242 L
s
.16654 .6135 m
.16625 .61675 L
s
.22224 .54166 m
.22484 .54424 L
s
.31462 .48724 m
.31424 .49053 L
s
.11735 .54474 m
.12009 .54729 L
s
.29272 .50634 m
.29244 .5097 L
s
.20867 .57853 m
.20848 .5818 L
s
.2504 .54288 m
.2503 .54616 L
s
.24783 .54029 m
.2504 .54288 L
s
.33695 .46875 m
.33646 .47197 L
s
0 g
.5 Mabswid
.25327 .43151 m
.26459 .42992 L
s
.039 .916 .04 r
1 Mabswid
.14289 .5433 m
.1456 .54586 L
s
.18753 .59773 m
.18728 .601 L
s
.27343 .53894 m
.27597 .54154 L
s
.38732 .53601 m
.39044 .53782 L
s
.32795 .53738 m
.33088 .53963 L
s
.27107 .52645 m
.27101 .52974 L
s
.22952 .56242 m
.22937 .56571 L
s
.16845 .54187 m
.17113 .54444 L
s
.35626 .53629 m
.35926 .53833 L
s
.31424 .49053 m
.31389 .49382 L
s
.29945 .53742 m
.3023 .53989 L
s
.29244 .5097 m
.2922 .51306 L
s
.33646 .47197 m
.33601 .47519 L
s
.19403 .54046 m
.19667 .54304 L
s
.20848 .5818 m
.20827 .58508 L
s
.2503 .54616 m
.25019 .54945 L
s
.08905 .54364 m
.09183 .54619 L
s
0 g
.5 Mabswid
.85423 .46324 m
.85092 .43529 L
s
.039 .916 .04 r
1 Mabswid
.16032 .62374 m
.1738 .61985 L
s
.21963 .53907 m
.22224 .54166 L
s
.18728 .601 m
.18703 .60428 L
s
.1146 .54218 m
.11735 .54474 L
s
.27101 .52974 m
.27095 .53304 L
s
.38428 .53418 m
.38732 .53601 L
s
.22937 .56571 m
.2292 .56899 L
s
.24525 .5377 m
.24783 .54029 L
s
.31389 .49382 m
.31357 .4971 L
s
.06479 .54586 m
.07808 .54147 L
s
.3541 .45963 m
.36795 .45616 L
s
.3251 .5351 m
.32795 .53738 L
s
.14018 .54073 m
.14289 .5433 L
s
.33601 .47519 m
.33559 .47841 L
s
.27088 .53634 m
.27343 .53894 L
s
.2922 .51306 m
.29199 .51641 L
s
.35334 .53422 m
.35626 .53629 L
s
.20827 .58508 m
.20806 .58837 L
s
.25019 .54945 m
.25008 .55275 L
s
.41246 .53423 m
.42498 .52826 L
s
.16577 .53929 m
.16845 .54187 L
s
0 g
.5 Mabswid
.32485 .62881 m
.31403 .6321 L
s
.039 .916 .04 r
1 Mabswid
.18703 .60428 m
.18676 .60756 L
s
.2967 .5349 m
.29945 .53742 L
s
.27095 .53304 m
.27088 .53634 L
s
.19138 .53788 m
.19403 .54046 L
s
.2292 .56899 m
.22903 .57229 L
s
.38132 .53232 m
.38428 .53418 L
s
.31357 .4971 m
.31328 .50038 L
s
.33559 .47841 m
.33521 .48161 L
s
.21701 .53648 m
.21963 .53907 L
s
.29199 .51641 m
.29181 .51976 L
s
.20806 .58837 m
.20783 .59166 L
s
.11185 .53961 m
.1146 .54218 L
s
.25008 .55275 m
.24995 .55605 L
s
.24266 .5351 m
.24525 .5377 L
s
.35051 .53212 m
.35334 .53422 L
s
0 g
.5 Mabswid
.75929 .52125 m
.76471 .54242 L
s
.75929 .52125 m
.7918 .51144 L
s
.75929 .52125 m
.75929 .52125 L
s
.039 .916 .04 r
1 Mabswid
.32234 .53278 m
.3251 .5351 L
s
.18676 .60756 m
.18649 .61086 L
s
.13745 .53815 m
.14018 .54073 L
s
.26833 .53373 m
.27088 .53634 L
s
.27088 .53634 m
.2708 .53965 L
s
.22903 .57229 m
.22885 .5756 L
s
0 g
.5 Mabswid
.92039 .41032 m
.89807 .40348 L
s
.039 .916 .04 r
1 Mabswid
.1738 .61985 m
.18733 .61595 L
s
.31328 .50038 m
.31303 .50365 L
s
.33521 .48161 m
.33485 .48481 L
s
.16308 .53671 m
.16577 .53929 L
s
.37844 .53042 m
.38132 .53232 L
s
.29404 .53235 m
.2967 .5349 L
s
.20783 .59166 m
.2076 .59497 L
s
.29181 .51976 m
.29166 .5231 L
s
.40893 .52943 m
.41191 .5311 L
s
.35755 .46347 m
.3571 .4666 L
s
.24995 .55605 m
.24981 .55937 L
s
.18872 .53529 m
.19138 .53788 L
s
.07808 .54147 m
.09141 .53706 L
s
.21438 .53388 m
.21701 .53648 L
s
.36795 .45616 m
.38186 .45269 L
s
.34776 .52999 m
.35051 .53212 L
s
.22885 .5756 m
.22866 .57891 L
s
.2708 .53965 m
.27071 .54298 L
s
.33485 .48481 m
.33452 .48801 L
s
.10909 .53704 m
.11185 .53961 L
s
.31303 .50365 m
.31281 .50691 L
s
.31967 .53043 m
.32234 .53278 L
s
.24006 .53249 m
.24266 .5351 L
s
.3571 .4666 m
.35667 .46972 L
s
.2076 .59497 m
.20736 .59828 L
s
.29166 .5231 m
.29155 .52644 L
s
.13472 .53557 m
.13745 .53815 L
s
.37564 .5285 m
.37844 .53042 L
s
.40603 .52773 m
.40893 .52943 L
s
.24981 .55937 m
.24967 .56269 L
s
.26576 .53112 m
.26833 .53373 L
s
.16038 .53413 m
.16308 .53671 L
s
.42498 .52826 m
.43756 .52226 L
s
.29148 .52977 m
.29404 .53235 L
s
.33452 .48801 m
.33423 .4912 L
s
.22866 .57891 m
.22846 .58223 L
s
.27071 .54298 m
.27061 .54631 L
s
.31281 .50691 m
.31262 .51017 L
s
.18605 .5327 m
.18872 .53529 L
s
.35667 .46972 m
.35628 .47284 L
s
.34509 .52783 m
.34776 .52999 L
s
.20736 .59828 m
.2071 .6016 L
s
.29155 .52644 m
.29148 .52977 L
s
.21175 .53128 m
.21438 .53388 L
s
.18733 .61595 m
.20091 .61203 L
s
.4032 .526 m
.40603 .52773 L
s
.31709 .52804 m
.31967 .53043 L
s
.24967 .56269 m
.24951 .56602 L
s
.37291 .52655 m
.37564 .5285 L
s
.23746 .52988 m
.24006 .53249 L
s
.33423 .4912 m
.33396 .49438 L
s
.09141 .53706 m
.1048 .53263 L
s
.22846 .58223 m
.22825 .58556 L
s
.13198 .53299 m
.13472 .53557 L
s
.31262 .51017 m
.31246 .51343 L
s
.35628 .47284 m
.35591 .47595 L
s
.27061 .54631 m
.27049 .54965 L
s
0 g
.5 Mabswid
.28918 .5305 m
.28864 .55923 L
s
.28918 .5305 m
.27163 .51237 L
s
.039 .916 .04 r
1 Mabswid
.26319 .52851 m
.26576 .53112 L
s
.2071 .6016 m
.20684 .60493 L
s
.15767 .53153 m
.16038 .53413 L
s
.29148 .52977 m
.29143 .53309 L
s
.289 .52714 m
.29148 .52977 L
s
.24951 .56602 m
.24934 .56936 L
s
.40044 .52425 m
.4032 .526 L
s
.38186 .45269 m
.39582 .4492 L
s
.34251 .52563 m
.34509 .52783 L
s
.18337 .53009 m
.18605 .5327 L
s
.33396 .49438 m
.33373 .49756 L
s
.37027 .52456 m
.37291 .52655 L
s
.35591 .47595 m
.35558 .47906 L
s
.22825 .58556 m
.22803 .5889 L
s
.31246 .51343 m
.31234 .51668 L
s
.31459 .52562 m
.31709 .52804 L
s
.27049 .54965 m
.27037 .55299 L
s
.2091 .52867 m
.21175 .53128 L
s
.37828 .45815 m
.37785 .46119 L
s
.23484 .52727 m
.23746 .52988 L
s
.29143 .53309 m
.29142 .53641 L
s
.24934 .56936 m
.24916 .57271 L
s
.12923 .5304 m
.13198 .53299 L
s
.39776 .52247 m
.40044 .52425 L
s
.33373 .49756 m
.33353 .50073 L
s
.26061 .52588 m
.26319 .52851 L
s
.35558 .47906 m
.35528 .48216 L
s
0 g
.5 Mabswid
.7918 .51144 m
.82456 .50155 L
s
.039 .916 .04 r
1 Mabswid
.20091 .61203 m
.21454 .6081 L
s
.34001 .5234 m
.34251 .52563 L
s
.15495 .52893 m
.15767 .53153 L
s
.22803 .5889 m
.2278 .59224 L
s
.31234 .51668 m
.31224 .51992 L
s
.3677 .52255 m
.37027 .52456 L
s
.28662 .52448 m
.289 .52714 L
s
.27037 .55299 m
.27024 .55635 L
s
.42756 .52097 m
.43032 .52254 L
s
.43756 .52226 m
.4502 .51622 L
s
.37785 .46119 m
.37745 .46422 L
s
.1048 .53263 m
.11823 .52818 L
s
.18069 .52749 m
.18337 .53009 L
s
.31218 .52316 m
.31459 .52562 L
s
.29142 .53641 m
.29145 .53973 L
s
.24916 .57271 m
.24898 .57606 L
s
.20644 .52606 m
.2091 .52867 L
s
.33353 .50073 m
.33336 .5039 L
s
.35528 .48216 m
.35501 .48526 L
s
.39515 .52066 m
.39776 .52247 L
s
.2278 .59224 m
.22756 .5956 L
s
.31224 .51992 m
.31218 .52316 L
s
.23222 .52465 m
.23484 .52727 L
s
.37745 .46422 m
.37709 .46724 L
s
.42487 .51938 m
.42756 .52097 L
s
.27024 .55635 m
.2701 .55971 L
s
.39582 .4492 m
.40985 .44569 L
s
.36521 .52051 m
.3677 .52255 L
s
.33759 .52114 m
.34001 .5234 L
s
.79802 .49955 m
.80102 .50865 L
s
.25802 .52325 m
.26061 .52588 L
s
0 g
.5 Mabswid
.85423 .46324 m
.85759 .49158 L
s
.039 .916 .04 r
1 Mabswid
.15222 .52633 m
.15495 .52893 L
s
.24898 .57606 m
.24878 .57942 L
s
.29145 .53973 m
.2915 .54304 L
s
.35501 .48526 m
.35477 .48835 L
s
.33336 .5039 m
.33323 .50706 L
s
.28433 .52178 m
.28662 .52448 L
s
.37709 .46724 m
.37675 .47026 L
s
.39261 .51882 m
.39515 .52066 L
s
.17799 .52488 m
.18069 .52749 L
s
.22756 .5956 m
.2273 .59896 L
s
.31218 .52316 m
.31216 .52639 L
s
.30987 .52066 m
.31218 .52316 L
s
0 g
.5 Mabswid
.76471 .54242 m
.77651 .56038 L
s
.039 .916 .04 r
1 Mabswid
.42224 .51777 m
.42487 .51938 L
s
.2701 .55971 m
.26994 .56309 L
s
.20378 .52344 m
.20644 .52606 L
s
.21454 .6081 m
.22822 .60416 L
s
0 g
.5 Mabswid
.93869 .42277 m
.92039 .41032 L
s
.039 .916 .04 r
1 Mabswid
.35477 .48835 m
.35456 .49144 L
s
0 g
.5 Mabswid
.24424 .43995 m
.25327 .43151 L
s
.039 .916 .04 r
1 Mabswid
.36279 .51843 m
.36521 .52051 L
s
.24878 .57942 m
.24857 .5828 L
s
.33323 .50706 m
.33312 .51022 L
s
.22959 .52202 m
.23222 .52465 L
s
.2915 .54304 m
.29159 .54634 L
s
.11823 .52818 m
.13171 .52372 L
s
.33525 .51884 m
.33759 .52114 L
s
.37675 .47026 m
.37644 .47328 L
s
.25542 .52062 m
.25802 .52325 L
s
.31216 .52639 m
.31216 .52962 L
s
.39015 .51696 m
.39261 .51882 L
s
.41969 .51613 m
.42224 .51777 L
s
.14948 .52372 m
.15222 .52633 L
s
.26994 .56309 m
.26978 .56647 L
s
.39914 .4528 m
.39874 .45574 L
s
.28214 .51904 m
.28433 .52178 L
s
.35456 .49144 m
.35438 .49452 L
s
.4502 .51622 m
.46291 .51016 L
s
.30763 .51813 m
.30987 .52066 L
s
.17528 .52226 m
.17799 .52488 L
s
.33312 .51022 m
.33305 .51337 L
s
.24857 .5828 m
.24835 .58618 L
s
.37644 .47328 m
.37616 .47629 L
s
.29159 .54634 m
.29172 .54964 L
s
.36046 .51633 m
.36279 .51843 L
s
.20111 .52082 m
.20378 .52344 L
s
.40985 .44569 m
.42393 .44217 L
s
.31216 .52962 m
.3122 .53284 L
s
.333 .51651 m
.33525 .51884 L
s
.4172 .51446 m
.41969 .51613 L
s
.39874 .45574 m
.39836 .45868 L
s
.38776 .51507 m
.39015 .51696 L
s
.26978 .56647 m
.26961 .56986 L
s
.22695 .51939 m
.22959 .52202 L
s
.35438 .49452 m
.35423 .49759 L
s
.37616 .47629 m
.37591 .47929 L
s
.33305 .51337 m
.333 .51651 L
s
.25281 .51798 m
.25542 .52062 L
s
.24835 .58618 m
.24813 .58957 L
s
0 g
.5 Mabswid
.31403 .6321 m
.30131 .62843 L
s
.039 .916 .04 r
1 Mabswid
.29172 .54964 m
.29188 .55293 L
s
.22822 .60416 m
.24196 .6002 L
s
.44632 .51246 m
.44887 .51392 L
s
.39836 .45868 m
.39802 .46161 L
s
.28004 .51626 m
.28214 .51904 L
s
.30549 .51557 m
.30763 .51813 L
s
.3122 .53284 m
.31227 .53606 L
s
.13171 .52372 m
.14524 .51925 L
s
0 g
.5 Mabswid
.82456 .50155 m
.85759 .49158 L
s
.039 .916 .04 r
1 Mabswid
.17257 .51964 m
.17528 .52226 L
s
.35821 .5142 m
.36046 .51633 L
s
.41478 .51277 m
.4172 .51446 L
s
.26961 .56986 m
.26942 .57325 L
s
.35423 .49759 m
.35411 .50066 L
s
.38544 .51315 m
.38776 .51507 L
s
.37591 .47929 m
.37569 .48229 L
s
.19842 .51818 m
.20111 .52082 L
s
.333 .51651 m
.33299 .51965 L
s
.33084 .51415 m
.333 .51651 L
s
.24813 .58957 m
.24789 .59296 L
s
.44384 .51098 m
.44632 .51246 L
s
.39802 .46161 m
.3977 .46454 L
s
.2243 .51675 m
.22695 .51939 L
s
.29188 .55293 m
.29207 .55622 L
s
.31227 .53606 m
.31238 .53927 L
s
.25019 .51533 m
.25281 .51798 L
s
.41243 .51105 m
.41478 .51277 L
s
.35411 .50066 m
.35402 .50372 L
s
.26942 .57325 m
.26923 .57666 L
s
.37569 .48229 m
.3755 .48528 L
s
.35603 .51203 m
.35821 .5142 L
s
.33299 .51965 m
.33302 .52279 L
s
.3832 .5112 m
.38544 .51315 L
s
.30344 .51296 m
.30549 .51557 L
s
.3977 .46454 m
.39742 .46746 L
s
.42393 .44217 m
.43806 .43864 L
s
.27803 .51344 m
.28004 .51626 L
s
.44142 .50948 m
.44384 .51098 L
s
.16984 .51701 m
.17257 .51964 L
s
.79498 .49037 m
.79802 .49955 L
s
.46291 .51016 m
.47568 .50406 L
s
.32876 .51176 m
.33084 .51415 L
s
.29207 .55622 m
.29229 .5595 L
s
0 g
.5 Mabswid
.28864 .55923 m
.2881 .58835 L
s
.039 .916 .04 r
1 Mabswid
.19573 .51555 m
.19842 .51818 L
s
.31238 .53927 m
.31252 .54247 L
s
.3755 .48528 m
.37534 .48827 L
s
.35402 .50372 m
.35396 .50678 L
s
.41015 .50931 m
.41243 .51105 L
s
.26923 .57666 m
.26903 .58008 L
s
.42012 .44742 m
.41975 .45027 L
s
.24196 .6002 m
.25575 .59622 L
s
.22164 .51411 m
.2243 .51675 L
s
.14524 .51925 m
.15882 .51476 L
s
.39742 .46746 m
.39716 .47038 L
s
.33302 .52279 m
.33307 .52592 L
s
.43906 .50795 m
.44142 .50948 L
s
.38104 .50922 m
.3832 .5112 L
s
.35394 .50983 m
.35603 .51203 L
s
.24756 .51268 m
.25019 .51533 L
s
.37534 .48827 m
.37521 .49125 L
s
.41975 .45027 m
.4194 .45311 L
s
.29229 .5595 m
.29256 .56278 L
s
.35396 .50678 m
.35394 .50983 L
s
.31252 .54247 m
.31269 .54567 L
s
.30148 .51033 m
.30344 .51296 L
s
.26903 .58008 m
.26881 .5835 L
s
.39716 .47038 m
.39693 .47328 L
s
.40794 .50754 m
.41015 .50931 L
s
.27612 .51058 m
.27803 .51344 L
s
.32676 .50933 m
.32876 .51176 L
s
.33307 .52592 m
.33316 .52904 L
s
.85105 .47646 m
.85691 .48588 L
s
.43677 .5064 m
.43906 .50795 L
s
.19303 .51291 m
.19573 .51555 L
s
.4194 .45311 m
.41908 .45595 L
s
.37894 .50721 m
.38104 .50922 L
s
.37521 .49125 m
.37511 .49422 L
s
.21897 .51146 m
.22164 .51411 L
s
.35394 .50983 m
.35394 .51288 L
s
.35192 .5076 m
.35394 .50983 L
s
0 g
.5 Mabswid
.27163 .51237 m
.25377 .49394 L
s
.039 .916 .04 r
1 Mabswid
.39693 .47328 m
.39673 .47619 L
s
.29256 .56278 m
.29285 .56606 L
s
.31269 .54567 m
.31289 .54887 L
s
.26881 .5835 m
.26859 .58693 L
s
.43806 .43864 m
.45226 .43509 L
s
.24493 .51002 m
.24756 .51268 L
s
.4058 .50574 m
.40794 .50754 L
s
.33316 .52904 m
.33327 .53216 L
s
.43455 .50482 m
.43677 .5064 L
s
.46522 .50388 m
.46755 .50523 L
s
.41908 .45595 m
.41878 .45878 L
s
.2996 .50765 m
.30148 .51033 L
s
.25575 .59622 m
.26959 .59223 L
s
.15882 .51476 m
.17245 .51025 L
s
.37511 .49422 m
.37504 .49719 L
s
.32484 .50686 m
.32676 .50933 L
s
.39673 .47619 m
.39656 .47909 L
s
.35394 .51288 m
.35398 .51592 L
s
.2743 .50769 m
.27612 .51058 L
s
0 g
.5 Mabswid
.77651 .56038 m
.79403 .57384 L
s
.039 .916 .04 r
1 Mabswid
.37693 .50518 m
.37894 .50721 L
s
.47568 .50406 m
.48852 .49793 L
s
.31289 .54887 m
.31313 .55206 L
s
.29285 .56606 m
.29318 .56932 L
s
.19032 .51026 m
.19303 .51291 L
s
0 g
.5 Mabswid
.85759 .49158 m
.86099 .52031 L
s
0 0 0 r
1 Mabswid
.85759 .49158 m
.85759 .49158 L
s
0 g
.5 Mabswid
.85759 .49158 m
.89089 .48153 L
s
.039 .916 .04 r
1 Mabswid
.34999 .50534 m
.35192 .5076 L
s
.46294 .50252 m
.46522 .50388 L
s
.41878 .45878 m
.41852 .46161 L
s
.43238 .50323 m
.43455 .50482 L
s
.40373 .50392 m
.4058 .50574 L
s
.33327 .53216 m
.33342 .53527 L
s
0 g
.5 Mabswid
.95166 .4401 m
.93869 .42277 L
s
.039 .916 .04 r
1 Mabswid
.21629 .5088 m
.21897 .51146 L
s
.37504 .49719 m
.375 .50016 L
s
.39656 .47909 m
.39642 .48198 L
s
.35398 .51592 m
.35405 .51896 L
s
.24228 .50736 m
.24493 .51002 L
s
.44123 .442 m
.44088 .44476 L
s
.41852 .46161 m
.41828 .46443 L
s
.46073 .50113 m
.46294 .50252 L
s
.31313 .55206 m
.3134 .55524 L
s
.32301 .50436 m
.32484 .50686 L
s
.37499 .50311 m
.37693 .50518 L
s
.29782 .50494 m
.2996 .50765 L
s
.29318 .56932 m
.29354 .57259 L
s
.43029 .5016 m
.43238 .50323 L
s
.33342 .53527 m
.33361 .53838 L
s
.40173 .50207 m
.40373 .50392 L
s
.375 .50016 m
.37499 .50311 L
s
.39642 .48198 m
.39631 .48487 L
s
.34813 .50305 m
.34999 .50534 L
s
.27258 .50475 m
.2743 .50769 L
s
.35405 .51896 m
.35415 .52199 L
s
.44088 .44476 m
.44056 .44751 L
s
.45226 .43509 m
.46652 .43153 L
s
.41828 .46443 m
.41807 .46724 L
s
.85264 .49004 m
.85827 .4973 L
s
.45857 .49971 m
.46073 .50113 L
s
.79193 .4811 m
.79498 .49037 L
s
.17245 .51025 m
.18613 .50572 L
s
.26959 .59223 m
.28348 .58823 L
s
.21361 .50614 m
.21629 .5088 L
s
.3134 .55524 m
.31371 .55842 L
s
.42826 .49996 m
.43029 .5016 L
s
.29354 .57259 m
.29394 .57584 L
s
.33361 .53838 m
.33382 .54148 L
s
.23963 .50469 m
.24228 .50736 L
s
.37499 .50311 m
.37501 .50607 L
s
.37312 .50102 m
.37499 .50311 L
s
.39631 .48487 m
.39622 .48775 L
s
.3998 .50019 m
.40173 .50207 L
s
.44056 .44751 m
.44026 .45025 L
s
.32127 .50183 m
.32301 .50436 L
s
.35415 .52199 m
.35428 .52501 L
s
.41807 .46724 m
.41789 .47005 L
s
.80211 .48859 m
.79857 .48898 L
s
.29612 .50219 m
.29782 .50494 L
s
.45648 .49828 m
.45857 .49971 L
s
.80563 .48817 m
.80211 .48859 L
s
.34635 .50073 m
.34813 .50305 L
s
.84514 .46697 m
.85105 .47646 L
s
.80912 .4877 m
.80563 .48817 L
s
0 g
.5 Mabswid
.23818 .45482 m
.24424 .43995 L
s
.039 .916 .04 r
1 Mabswid
.42629 .49829 m
.42826 .49996 L
s
.31371 .55842 m
.31404 .5616 L
s
.39622 .48775 m
.39617 .49062 L
s
.81258 .4872 m
.80912 .4877 L
s
.48852 .49793 m
.50143 .49177 L
s
.37501 .50607 m
.37506 .50902 L
s
.27095 .50177 m
.27258 .50475 L
s
.44026 .45025 m
.43999 .45299 L
s
.33382 .54148 m
.33407 .54458 L
s
.29394 .57584 m
.29437 .5791 L
s
.81602 .48666 m
.81258 .4872 L
s
.41789 .47005 m
.41774 .47286 L
s
.39794 .49829 m
.3998 .50019 L
s
.21091 .50347 m
.21361 .50614 L
s
.37133 .4989 m
.37312 .50102 L
s
.35428 .52501 m
.35444 .52803 L
s
.45444 .49683 m
.45648 .49828 L
s
.81942 .48607 m
.81602 .48666 L
s
.23697 .50201 m
.23963 .50469 L
s
.82281 .48545 m
.81942 .48607 L
s
.43999 .45299 m
.43975 .45572 L
s
.31961 .49926 m
.32127 .50183 L
s
.39617 .49062 m
.39614 .49349 L
s
.48425 .49525 m
.48637 .49648 L
s
.37506 .50902 m
.37514 .51196 L
s
.42439 .49659 m
.42629 .49829 L
s
.34466 .49837 m
.34635 .50073 L
s
.31404 .5616 m
.31441 .56477 L
s
.82617 .48479 m
.82281 .48545 L
s
.41774 .47286 m
.41762 .47566 L
s
.33407 .54458 m
.33435 .54767 L
s
.18613 .50572 m
.19986 .50118 L
s
.29452 .4994 m
.29612 .50219 L
s
.28348 .58823 m
.29744 .58325 L
s
.46652 .43153 m
.48083 .42795 L
s
.45247 .49535 m
.45444 .49683 L
s
.35444 .52803 m
.35463 .53104 L
s
.8295 .48409 m
.82617 .48479 L
s
.39615 .49636 m
.39794 .49829 L
s
.43975 .45572 m
.43953 .45845 L
s
.36961 .49675 m
.37133 .4989 L
s
.48219 .49399 m
.48425 .49525 L
s
.46248 .43655 m
.46215 .43921 L
s
.8328 .48335 m
.8295 .48409 L
s
.39614 .49349 m
.39615 .49636 L
s
.26941 .49875 m
.27095 .50177 L
s
.37514 .51196 m
.37525 .51489 L
s
0 g
.5 Mabswid
.30131 .62843 m
.28754 .61789 L
s
.039 .916 .04 r
1 Mabswid
.41762 .47566 m
.41752 .47845 L
s
.42255 .49487 m
.42439 .49659 L
s
.84839 .47276 m
.84842 .47316 L
s
0 g
.5 Mabswid
.89089 .48153 m
.92446 .4714 L
s
.039 .916 .04 r
1 Mabswid
.83608 .48257 m
.8328 .48335 L
s
.33435 .54767 m
.33466 .55076 L
s
.31441 .56477 m
.31482 .56793 L
s
.45055 .49385 m
.45247 .49535 L
s
.84842 .47316 m
.84844 .47356 L
s
.2343 .49933 m
.23697 .50201 L
s
.35463 .53104 m
.35486 .53405 L
s
.84844 .47356 m
.84847 .47396 L
s
.31804 .49666 m
.31961 .49926 L
s
.43953 .45845 m
.43934 .46117 L
s
.48018 .49272 m
.48219 .49399 L
s
.34304 .49599 m
.34466 .49837 L
s
0 g
.5 Mabswid
.2881 .58835 m
.28754 .61789 L
s
.039 .916 .04 r
1 Mabswid
.46215 .43921 m
.46185 .44187 L
s
.83934 .48174 m
.83608 .48257 L
s
.84847 .47396 m
.8485 .47437 L
s
.39615 .49636 m
.39618 .49922 L
s
.39443 .4944 m
.39615 .49636 L
s
.8485 .47437 m
.84853 .47478 L
s
.293 .49657 m
.29452 .4994 L
s
.41752 .47845 m
.41746 .48124 L
s
.37525 .51489 m
.37539 .51783 L
s
.84853 .47478 m
.84856 .47519 L
s
.84257 .48088 m
.83934 .48174 L
s
.36797 .49457 m
.36961 .49675 L
s
.84856 .47519 m
.8486 .47561 L
s
.42078 .49313 m
.42255 .49487 L
s
.44869 .49233 m
.45055 .49385 L
s
.8486 .47561 m
.84864 .47603 L
s
.33466 .55076 m
.33501 .55384 L
s
.47822 .49142 m
.48018 .49272 L
s
.46185 .44187 m
.46157 .44452 L
s
.43934 .46117 m
.43918 .46388 L
s
.31482 .56793 m
.31526 .57109 L
s
.84864 .47603 m
.84868 .47645 L
s
.84577 .47998 m
.84257 .48088 L
s
.29744 .58325 m
.31146 .57779 L
s
.50143 .49177 m
.5144 .48558 L
s
.35486 .53405 m
.35512 .53706 L
s
.84868 .47645 m
.84872 .47688 L
s
.19986 .50118 m
.21364 .49662 L
s
.39618 .49922 m
.39625 .50207 L
s
.84872 .47688 m
.84876 .4773 L
s
.26798 .49569 m
.26941 .49875 L
s
.41746 .48124 m
.41742 .48402 L
s
.84876 .4773 m
.84881 .47773 L
s
.37539 .51783 m
.37557 .52075 L
s
.84895 .47904 m
.84577 .47998 L
s
.39278 .49242 m
.39443 .4944 L
s
.34151 .49357 m
.34304 .49599 L
s
.84881 .47773 m
.84885 .47817 L
s
.31655 .49402 m
.31804 .49666 L
s
.23161 .49665 m
.2343 .49933 L
s
.84697 .48272 m
.85264 .49004 L
s
.48083 .42795 m
.49521 .42436 L
s
.46157 .44452 m
.46132 .44716 L
s
.47632 .49011 m
.47822 .49142 L
s
.4469 .49079 m
.44869 .49233 L
s
.43918 .46388 m
.43905 .46659 L
s
.84885 .47817 m
.8489 .4786 L
s
.41907 .49136 m
.42078 .49313 L
s
.78884 .47177 m
.79193 .4811 L
s
.8489 .4786 m
.84895 .47904 L
s
.3664 .49235 m
.36797 .49457 L
s
.33501 .55384 m
.33539 .55691 L
s
.84895 .47904 m
.849 .47948 L
s
.85211 .47806 m
.84895 .47904 L
s
.83918 .45741 m
.84514 .46697 L
s
.35512 .53706 m
.3554 .54006 L
s
.29158 .49371 m
.293 .49657 L
s
.849 .47948 m
.84906 .47993 L
s
.39625 .50207 m
.39634 .50492 L
s
.41742 .48402 m
.41741 .4868 L
s
.84906 .47993 m
.84911 .48037 L
s
0 g
.5 Mabswid
.79403 .57384 m
.81613 .5818 L
s
.039 .916 .04 r
1 Mabswid
.84911 .48037 m
.84917 .48082 L
s
.46132 .44716 m
.4611 .4498 L
s
.37557 .52075 m
.37577 .52367 L
s
.47447 .48878 m
.47632 .49011 L
s
.85524 .47704 m
.85211 .47806 L
s
.43905 .46659 m
.43894 .4693 L
s
.84917 .48082 m
.84923 .48128 L
s
.44516 .48922 m
.4469 .49079 L
s
.84923 .48128 m
.84929 .48173 L
s
.3912 .49041 m
.39278 .49242 L
s
0 g
.5 Mabswid
.9583 .46119 m
.95166 .4401 L
s
.039 .916 .04 r
1 Mabswid
.84929 .48173 m
.84936 .48219 L
s
.41743 .48957 m
.41907 .49136 L
s
.84936 .48219 m
.84942 .48265 L
s
.33539 .55691 m
.3358 .55999 L
s
.34005 .49111 m
.34151 .49357 L
s
.41741 .4868 m
.41743 .48957 L
s
.85834 .47597 m
.85524 .47704 L
s
.39634 .50492 m
.39646 .50777 L
s
.84942 .48265 m
.84949 .48311 L
s
.3554 .54006 m
.35573 .54305 L
s
.31146 .57779 m
.32552 .5723 L
s
.26663 .49259 m
.26798 .49569 L
s
.4611 .4498 m
.4609 .45243 L
s
.31515 .49135 m
.31655 .49402 L
s
.84949 .48311 m
.84956 .48358 L
s
.36491 .49011 m
.3664 .49235 L
s
.47268 .48742 m
.47447 .48878 L
s
.84956 .48358 m
.84963 .48405 L
s
.43894 .4693 m
.43886 .472 L
s
.50343 .48655 m
.50534 .48767 L
s
.37577 .52367 m
.376 .52659 L
s
.48385 .43107 m
.48355 .43364 L
s
.84963 .48405 m
.8497 .48452 L
s
0 g
.5 Mabswid
.86444 .54945 m
.86099 .52031 L
s
.039 .916 .04 r
1 Mabswid
.8497 .48452 m
.84978 .485 L
s
.90638 .46671 m
.91494 .47427 L
s
.44349 .48764 m
.44516 .48922 L
s
.21364 .49662 m
.22748 .49204 L
s
.86142 .47487 m
.85834 .47597 L
s
.84978 .485 m
.84985 .48547 L
s
.84985 .48547 m
.84993 .48595 L
s
.29025 .49081 m
.29158 .49371 L
s
.38969 .48837 m
.3912 .49041 L
s
.41743 .48957 m
.41748 .49233 L
s
.41585 .48775 m
.41743 .48957 L
s
.4609 .45243 m
.46073 .45506 L
s
.39646 .50777 m
.39662 .5106 L
s
.3358 .55999 m
.33624 .56305 L
s
.50157 .48541 m
.50343 .48655 L
s
.35573 .54305 m
.35608 .54604 L
s
.47094 .48605 m
.47268 .48742 L
s
.48355 .43364 m
.48327 .4362 L
s
.43886 .472 m
.43881 .47469 L
s
.86448 .47373 m
.86142 .47487 L
s
.49521 .42436 m
.50965 .42075 L
s
.376 .52659 m
.37627 .5295 L
s
0 g
.5 Mabswid
.25377 .49394 m
.23561 .47518 L
s
.039 .916 .04 r
1 Mabswid
.5144 .48558 m
.52744 .47935 L
s
.33868 .48863 m
.34005 .49111 L
s
.44187 .48603 m
.44349 .48764 L
s
.3635 .48784 m
.36491 .49011 L
s
.46073 .45506 m
.46059 .45768 L
s
.49976 .48425 m
.50157 .48541 L
s
.31384 .48864 m
.31515 .49135 L
s
.41748 .49233 m
.41755 .49509 L
s
.86751 .47254 m
.86448 .47373 L
s
.48327 .4362 m
.48301 .43875 L
s
.39662 .5106 m
.3968 .51344 L
s
.26539 .48945 m
.26663 .49259 L
s
.46926 .48466 m
.47094 .48605 L
s
.43881 .47469 m
.43879 .47738 L
s
.41434 .48591 m
.41585 .48775 L
s
0 g
.5 Mabswid
.92446 .4714 m
.9583 .46119 L
s
.039 .916 .04 r
1 Mabswid
.79708 .4752 m
.79382 .47555 L
s
.35608 .54604 m
.35646 .54902 L
s
.38825 .48631 m
.38969 .48837 L
s
.32552 .5723 m
.33962 .5668 L
s
.80032 .4748 m
.79708 .4752 L
s
.37627 .5295 m
.37657 .5324 L
s
.80353 .47437 m
.80032 .4748 L
s
.87052 .47132 m
.86751 .47254 L
s
.498 .48307 m
.49976 .48425 L
s
.46059 .45768 m
.46048 .46029 L
s
.44032 .48439 m
.44187 .48603 L
s
.28901 .48787 m
.29025 .49081 L
s
.80672 .47391 m
.80353 .47437 L
s
.48301 .43875 m
.48278 .4413 L
s
.41755 .49509 m
.41766 .49785 L
s
.80989 .4734 m
.80672 .47391 L
s
.46764 .48324 m
.46926 .48466 L
s
.43879 .47738 m
.43879 .48006 L
s
.3968 .51344 m
.39701 .51626 L
s
.36216 .48554 m
.3635 .48784 L
s
.33739 .48611 m
.33868 .48863 L
s
.22748 .49204 m
.24136 .48745 L
s
.81303 .47287 m
.80989 .4734 L
s
.4129 .48404 m
.41434 .48591 L
s
.87351 .47005 m
.87052 .47132 L
s
.35646 .54902 m
.35688 .552 L
s
.49629 .48188 m
.498 .48307 L
s
.81615 .47229 m
.81303 .47287 L
s
.46048 .46029 m
.46039 .4629 L
s
.48278 .4413 m
.48258 .44384 L
s
.37657 .5324 m
.37689 .5353 L
s
.38689 .48421 m
.38825 .48631 L
s
.31261 .4859 m
.31384 .48864 L
s
.43883 .48274 m
.44032 .48439 L
s
.41766 .49785 m
.41779 .5006 L
s
.81924 .47168 m
.81615 .47229 L
s
.43879 .48006 m
.43883 .48274 L
s
.46607 .48181 m
.46764 .48324 L
s
.83319 .44778 m
.83918 .45741 L
s
.39701 .51626 m
.39726 .51909 L
s
.83954 .45867 m
.83957 .45916 L
s
.87647 .46874 m
.87351 .47005 L
s
.26424 .48627 m
.26539 .48945 L
s
.8223 .47103 m
.81924 .47168 L
s
.49464 .48067 m
.49629 .48188 L
s
.83957 .45916 m
.8396 .45965 L
s
.84124 .47534 m
.84697 .48272 L
s
.48258 .44384 m
.48241 .44638 L
s
.46039 .4629 m
.46032 .46551 L
s
.50965 .42075 m
.52414 .41712 L
s
.82535 .47034 m
.8223 .47103 L
s
.8396 .45965 m
.83964 .46015 L
s
.35688 .552 m
.35733 .55497 L
s
.33962 .5668 m
.35377 .56128 L
s
.41152 .48215 m
.4129 .48404 L
s
.3609 .48321 m
.36216 .48554 L
s
.28786 .48489 m
.28901 .48787 L
s
.37689 .5353 m
.37725 .5382 L
s
.78573 .46235 m
.78884 .47177 L
s
.83964 .46015 m
.83967 .46065 L
s
.33618 .48356 m
.33739 .48611 L
s
0 g
.5 Mabswid
.23561 .47518 m
.23818 .45482 L
s
.039 .916 .04 r
1 Mabswid
.41779 .5006 m
.41796 .50334 L
s
.50536 .42556 m
.50507 .42803 L
s
.43883 .48274 m
.43889 .48541 L
s
.43739 .48106 m
.43883 .48274 L
s
.8794 .46739 m
.87647 .46874 L
s
.82837 .46962 m
.82535 .47034 L
s
.46455 .48035 m
.46607 .48181 L
s
.83967 .46065 m
.83971 .46115 L
s
.38559 .48209 m
.38689 .48421 L
s
.49303 .47944 m
.49464 .48067 L
s
.39726 .51909 m
.39753 .5219 L
s
.83971 .46115 m
.83975 .46165 L
s
.48241 .44638 m
.48225 .44891 L
s
.52744 .47935 m
.54055 .47309 L
s
.46032 .46551 m
.46029 .46811 L
s
.83136 .46886 m
.82837 .46962 L
s
.83975 .46165 m
.83979 .46216 L
s
.31147 .48312 m
.31261 .4859 L
s
.89776 .45909 m
.90638 .46671 L
s
.50507 .42803 m
.50482 .43049 L
s
.83979 .46216 m
.83984 .46267 L
s
.52274 .47778 m
.52444 .47879 L
s
.88232 .466 m
.8794 .46739 L
s
.83434 .46806 m
.83136 .46886 L
s
.83984 .46267 m
.83988 .46319 L
s
.37725 .5382 m
.37764 .54109 L
s
.41796 .50334 m
.41815 .50608 L
s
.43889 .48541 m
.43897 .48808 L
s
.41021 .48023 m
.41152 .48215 L
s
.46309 .47888 m
.46455 .48035 L
s
.49147 .4782 m
.49303 .47944 L
s
.24136 .48745 m
.2564 .48398 L
s
.43602 .47936 m
.43739 .48106 L
s
.83988 .46319 m
.83993 .46371 L
s
.48225 .44891 m
.48213 .45143 L
s
.46029 .46811 m
.46028 .4707 L
s
.39753 .5219 m
.39783 .52471 L
s
.35971 .48085 m
.3609 .48321 L
s
.83729 .46722 m
.83434 .46806 L
s
.83993 .46371 m
.83998 .46423 L
s
.52109 .47676 m
.52274 .47778 L
s
.50482 .43049 m
.50458 .43295 L
s
.38437 .47994 m
.38559 .48209 L
s
.83998 .46423 m
.84004 .46475 L
s
.33505 .48097 m
.33618 .48356 L
s
.88521 .46457 m
.88232 .466 L
s
.84004 .46475 m
.84009 .46528 L
s
.28681 .48187 m
.28786 .48489 L
s
.84021 .46635 m
.83729 .46722 L
s
.48996 .47693 m
.49147 .4782 L
s
.43897 .48808 m
.43909 .49074 L
s
0 g
.5 Mabswid
.28754 .61789 m
.28754 .61789 L
s
.28754 .61789 m
.27371 .60108 L
s
.039 .916 .04 r
1 Mabswid
.84009 .46528 m
.84015 .46582 L
s
.41815 .50608 m
.41837 .50882 L
s
.35377 .56128 m
.36796 .55575 L
s
.46169 .47739 m
.46309 .47888 L
s
.48213 .45143 m
.48203 .45396 L
s
.37764 .54109 m
.37806 .54397 L
s
.84015 .46582 m
.84021 .46635 L
s
.51948 .47572 m
.52109 .47676 L
s
.46028 .4707 m
.4603 .47329 L
s
.40896 .47829 m
.41021 .48023 L
s
.43471 .47764 m
.43602 .47936 L
s
.50458 .43295 m
.50438 .4354 L
s
.84021 .46635 m
.84028 .46689 L
s
.84311 .46544 m
.84021 .46635 L
s
.39783 .52471 m
.39816 .52752 L
s
.31041 .4803 m
.31147 .48312 L
s
.84028 .46689 m
.84034 .46744 L
s
.88808 .46309 m
.88521 .46457 L
s
.52414 .41712 m
.5387 .41349 L
s
.84034 .46744 m
.84041 .46798 L
s
.4885 .47565 m
.48996 .47693 L
s
0 g
.5 Mabswid
.81613 .5818 m
.84136 .58359 L
s
.039 .916 .04 r
1 Mabswid
.84599 .4645 m
.84311 .46544 L
s
.43909 .49074 m
.43923 .49339 L
s
.48203 .45396 m
.48195 .45647 L
s
.35861 .47845 m
.35971 .48085 L
s
.84041 .46798 m
.84048 .46853 L
s
.51792 .47467 m
.51948 .47572 L
s
.38321 .47777 m
.38437 .47994 L
s
.41837 .50882 m
.41862 .51154 L
s
.2564 .48398 m
.27202 .48107 L
s
.46034 .47587 m
.46169 .47739 L
s
.84048 .46853 m
.84055 .46909 L
s
.50438 .4354 m
.50419 .43785 L
s
.4603 .47329 m
.46034 .47587 L
s
.37806 .54397 m
.37851 .54685 L
s
0 g
.5 Mabswid
.95803 .48462 m
.9583 .46119 L
s
.9583 .46119 m
.9583 .46119 L
s
.039 .916 .04 r
1 Mabswid
.84055 .46909 m
.84062 .46964 L
s
.334 .47836 m
.33505 .48097 L
s
.84885 .46351 m
.84599 .4645 L
s
.43346 .47589 m
.43471 .47764 L
s
.84062 .46964 m
.8407 .4702 L
s
.89092 .46157 m
.88808 .46309 L
s
.39816 .52752 m
.39853 .53032 L
s
.40778 .47632 m
.40896 .47829 L
s
.4871 .47435 m
.4885 .47565 L
s
.8407 .4702 m
.84078 .47077 L
s
.51641 .4736 m
.51792 .47467 L
s
.48195 .45647 m
.48191 .45898 L
s
.84078 .47077 m
.84086 .47133 L
s
.43923 .49339 m
.43941 .49604 L
s
.50419 .43785 m
.50403 .44029 L
s
.84086 .47133 m
.84095 .47191 L
s
.85169 .46249 m
.84885 .46351 L
s
.41862 .51154 m
.4189 .51427 L
s
.45905 .47434 m
.46034 .47587 L
s
.46034 .47587 m
.46041 .47845 L
s
.84095 .47191 m
.84103 .47248 L
s
.54055 .47309 m
.55373 .4668 L
s
.30944 .47745 m
.31041 .4803 L
s
.36796 .55575 m
.3822 .55019 L
s
.84103 .47248 m
.84112 .47306 L
s
.51493 .47251 m
.51641 .4736 L
s
.89374 .46002 m
.89092 .46157 L
s
.38213 .47556 m
.38321 .47777 L
s
.82715 .43808 m
.83319 .44778 L
s
.84112 .47306 m
.84121 .47364 L
s
.48574 .47303 m
.4871 .47435 L
s
.35758 .47603 m
.35861 .47845 L
s
.527 .42001 m
.52674 .42238 L
s
.39853 .53032 m
.39892 .53312 L
s
.27202 .48107 m
.28767 .47815 L
s
.43227 .47412 m
.43346 .47589 L
s
.48191 .45898 m
.48188 .46149 L
s
.8545 .46143 m
.85169 .46249 L
s
.84121 .47364 m
.8413 .47422 L
s
.50403 .44029 m
.5039 .44272 L
s
.8413 .47422 m
.8414 .47481 L
s
.43941 .49604 m
.43961 .49869 L
s
.40667 .47432 m
.40778 .47632 L
s
.46041 .47845 m
.46051 .48102 L
s
.4189 .51427 m
.41921 .51698 L
s
.33304 .4757 m
.334 .47836 L
s
.45781 .47278 m
.45905 .47434 L
s
.51351 .47141 m
.51493 .47251 L
s
.52674 .42238 m
.5265 .42475 L
s
.85729 .46034 m
.8545 .46143 L
s
.48444 .47169 m
.48574 .47303 L
s
.48188 .46149 m
.48189 .46398 L
s
.5039 .44272 m
.50379 .44516 L
s
.83548 .4679 m
.84124 .47534 L
s
.39892 .53312 m
.39935 .53591 L
s
.5387 .41349 m
.55332 .40983 L
s
0 g
.5 Mabswid
.86794 .57899 m
.86444 .54945 L
s
.039 .916 .04 r
1 Mabswid
.43114 .47233 m
.43227 .47412 L
s
.43961 .49869 m
.43983 .50133 L
s
.51213 .47029 m
.51351 .47141 L
s
.88907 .45142 m
.89776 .45909 L
s
.38112 .47333 m
.38213 .47556 L
s
.46051 .48102 m
.46064 .48359 L
s
.86005 .4592 m
.85729 .46034 L
s
.5265 .42475 m
.52629 .42711 L
s
.35662 .47358 m
.35758 .47603 L
s
.78259 .45285 m
.78573 .46235 L
s
.41921 .51698 m
.41954 .5197 L
s
.45663 .4712 m
.45781 .47278 L
s
.28767 .47815 m
.30336 .47523 L
s
.40562 .4723 m
.40667 .47432 L
s
.5422 .46895 m
.54368 .46984 L
s
.48318 .47034 m
.48444 .47169 L
s
.79199 .46164 m
.78901 .46196 L
s
.50379 .44516 m
.50371 .44758 L
s
.48189 .46398 m
.48192 .46648 L
s
.79495 .46127 m
.79199 .46164 L
s
.8628 .45803 m
.86005 .4592 L
s
.79788 .46088 m
.79495 .46127 L
s
.3822 .55019 m
.39648 .54462 L
s
.51079 .46916 m
.51213 .47029 L
s
.39935 .53591 m
.3998 .53869 L
s
.52629 .42711 m
.5261 .42947 L
s
.8008 .46045 m
.79788 .46088 L
s
.43983 .50133 m
.44009 .50396 L
s
.33216 .47302 m
.33304 .4757 L
s
.46064 .48359 m
.46079 .48615 L
s
.54075 .46805 m
.5422 .46895 L
s
.43007 .47052 m
.43114 .47233 L
s
.80369 .45999 m
.8008 .46045 L
s
.41954 .5197 m
.41991 .5224 L
s
.50371 .44758 m
.50365 .45 L
s
.45551 .46961 m
.45663 .4712 L
s
.48197 .46897 m
.48318 .47034 L
s
.8306 .44444 m
.83063 .44501 L
s
.48192 .46648 m
.48197 .46897 L
s
.80656 .4595 m
.80369 .45999 L
s
.86552 .45682 m
.8628 .45803 L
s
.38019 .47107 m
.38112 .47333 L
s
.5095 .46801 m
.51079 .46916 L
s
.83063 .44501 m
.83067 .44559 L
s
.53935 .46713 m
.54075 .46805 L
s
.8094 .45897 m
.80656 .4595 L
s
.5261 .42947 m
.52593 .43182 L
s
.40464 .47026 m
.40562 .4723 L
s
.35575 .47109 m
.35662 .47358 L
s
.83067 .44559 m
.83071 .44618 L
s
.30336 .47523 m
.31908 .47231 L
s
.46079 .48615 m
.46097 .48871 L
s
.44009 .50396 m
.44038 .50659 L
s
.81222 .4584 m
.8094 .45897 L
s
.50365 .45 m
.50361 .45242 L
s
.83071 .44618 m
.83075 .44677 L
s
.55373 .4668 m
.56698 .46048 L
s
.86822 .45557 m
.86552 .45682 L
s
.48197 .46897 m
.48206 .47145 L
s
.48082 .46757 m
.48197 .46897 L
s
.53798 .4662 m
.53935 .46713 L
s
.81503 .45781 m
.81222 .4584 L
s
.50826 .46685 m
.5095 .46801 L
s
.42907 .46868 m
.43007 .47052 L
s
.41991 .5224 m
.42031 .52511 L
s
.83075 .44677 m
.83079 .44736 L
s
.45444 .46799 m
.45551 .46961 L
s
.52593 .43182 m
.52579 .43416 L
s
.8178 .45718 m
.81503 .45781 L
s
.83079 .44736 m
.83083 .44796 L
s
.46097 .48871 m
.46118 .49126 L
s
.53666 .46526 m
.53798 .4662 L
s
.83083 .44796 m
.83088 .44856 L
s
.44038 .50659 m
.44069 .50922 L
s
.87089 .45428 m
.86822 .45557 L
s
.82056 .45651 m
.8178 .45718 L
s
.50361 .45242 m
.5036 .45483 L
s
.55332 .40983 m
.568 .40616 L
s
.37932 .46878 m
.38019 .47107 L
s
.40373 .46819 m
.40464 .47026 L
s
.39648 .54462 m
.41081 .53903 L
s
.50706 .46566 m
.50826 .46685 L
s
.83088 .44856 m
.83093 .44916 L
s
.48206 .47145 m
.48217 .47393 L
s
.47972 .46616 m
.48082 .46757 L
s
.54877 .41442 m
.54853 .4167 L
s
.52579 .43416 m
.52567 .4365 L
s
.8233 .45581 m
.82056 .45651 L
s
0 g
.5 Mabswid
.23561 .47518 m
.23561 .47518 L
s
.23677 .49966 m
.23561 .47518 L
s
.039 .916 .04 r
1 Mabswid
.83093 .44916 m
.83099 .44977 L
s
.42031 .52511 m
.42073 .5278 L
s
.45342 .46635 m
.45444 .46799 L
s
.31908 .47231 m
.33483 .46937 L
s
.35495 .46857 m
.35575 .47109 L
s
.53537 .4643 m
.53666 .46526 L
s
.42813 .46682 m
.42907 .46868 L
s
.83099 .44977 m
.83105 .45039 L
s
.82601 .45508 m
.8233 .45581 L
s
.87355 .45296 m
.87089 .45428 L
s
.5036 .45483 m
.50362 .45723 L
s
.46118 .49126 m
.46141 .4938 L
s
.83105 .45039 m
.8311 .451 L
s
.5059 .46447 m
.50706 .46566 L
s
.54853 .4167 m
.54831 .41897 L
s
.82106 .4283 m
.82715 .43808 L
s
.44069 .50922 m
.44103 .51184 L
s
.52567 .4365 m
.52558 .43884 L
s
.48217 .47393 m
.4823 .4764 L
s
.8311 .451 m
.83117 .45162 L
s
.47866 .46474 m
.47972 .46616 L
s
.8287 .45432 m
.82601 .45508 L
s
.53412 .46333 m
.53537 .4643 L
s
.83117 .45162 m
.83123 .45225 L
s
.40288 .46609 m
.40373 .46819 L
s
0 g
.5 Mabswid
.84136 .58359 m
.86794 .57899 L
s
.039 .916 .04 r
1 Mabswid
.42073 .5278 m
.42119 .5305 L
s
.37853 .46646 m
.37932 .46878 L
s
.87618 .45159 m
.87355 .45296 L
s
.45247 .46469 m
.45342 .46635 L
s
.83137 .45352 m
.8287 .45432 L
s
.83123 .45225 m
.8313 .45288 L
s
.50362 .45723 m
.50366 .45963 L
s
.54831 .41897 m
.54812 .42124 L
s
.50479 .46325 m
.5059 .46447 L
s
0 g
.5 Mabswid
.95076 .50874 m
.95803 .48462 L
s
.039 .916 .04 r
1 Mabswid
.46141 .4938 m
.46167 .49634 L
s
.52558 .43884 m
.52551 .44117 L
s
.42724 .46493 m
.42813 .46682 L
s
.8313 .45288 m
.83137 .45352 L
s
.53292 .46234 m
.53412 .46333 L
s
0 g
.5 Mabswid
.27371 .60108 m
.26082 .57915 L
s
.039 .916 .04 r
1 Mabswid
.4823 .4764 m
.48246 .47887 L
s
.44103 .51184 m
.4414 .51445 L
s
.83137 .45352 m
.83144 .45415 L
s
.83402 .45268 m
.83137 .45352 L
s
.33483 .46937 m
.35062 .46643 L
s
.47766 .46329 m
.47866 .46474 L
s
.88033 .4437 m
.88907 .45142 L
s
.83144 .45415 m
.83152 .4548 L
s
.87879 .45019 m
.87618 .45159 L
s
.54812 .42124 m
.54795 .4235 L
s
.41081 .53903 m
.42518 .53343 L
s
.50366 .45963 m
.50373 .46202 L
s
.83152 .4548 m
.8316 .45544 L
s
.50373 .46202 m
.50479 .46325 L
s
.53175 .46134 m
.53292 .46234 L
s
.83665 .45181 m
.83402 .45268 L
s
.52551 .44117 m
.52547 .44349 L
s
.45157 .46301 m
.45247 .46469 L
s
.8316 .45544 m
.83168 .45609 L
s
.46167 .49634 m
.46196 .49888 L
s
.40211 .46396 m
.40288 .46609 L
s
.82966 .46039 m
.83548 .4679 L
s
.48246 .47887 m
.48265 .48133 L
s
.56179 .46006 m
.56307 .46083 L
s
.83168 .45609 m
.83177 .45675 L
s
.4414 .51445 m
.4418 .51706 L
s
.56698 .46048 m
.58029 .45413 L
s
.42643 .46302 m
.42724 .46493 L
s
.37781 .46411 m
.37853 .46646 L
s
.47671 .46182 m
.47766 .46329 L
s
.83925 .45091 m
.83665 .45181 L
s
.568 .40616 m
.58275 .40248 L
s
.54795 .4235 m
.5478 .42575 L
s
.83177 .45675 m
.83185 .45741 L
s
.53063 .46032 m
.53175 .46134 L
s
.88138 .44875 m
.87879 .45019 L
s
.50373 .46202 m
.50382 .46441 L
s
.50271 .46078 m
.50373 .46202 L
s
.52547 .44349 m
.52545 .44581 L
s
.83185 .45741 m
.83194 .45807 L
s
.56055 .45928 m
.56179 .46006 L
s
.77943 .44327 m
.78259 .45285 L
s
.83194 .45807 m
.83204 .45874 L
s
.84184 .44997 m
.83925 .45091 L
s
.35062 .46643 m
.36644 .46349 L
s
.46196 .49888 m
.46228 .50141 L
s
.48265 .48133 m
.48286 .48379 L
s
.45073 .46131 m
.45157 .46301 L
s
.83204 .45874 m
.83213 .45941 L
s
.5478 .42575 m
.54768 .428 L
s
.52954 .4593 m
.53063 .46032 L
s
.55935 .45848 m
.56055 .45928 L
s
.83213 .45941 m
.83223 .46009 L
s
.4418 .51706 m
.44223 .51966 L
s
.47581 .46034 m
.47671 .46182 L
s
.8444 .449 m
.84184 .44997 L
s
.50174 .45951 m
.50271 .46078 L
s
.52545 .44581 m
.52545 .44813 L
s
.4014 .46181 m
.40211 .46396 L
s
.50382 .46441 m
.50394 .46679 L
s
.83223 .46009 m
.83233 .46077 L
s
.42567 .46109 m
.42643 .46302 L
s
.83233 .46077 m
.83243 .46145 L
s
.55818 .45768 m
.55935 .45848 L
s
.5285 .45825 m
.52954 .4593 L
s
.54768 .428 m
.54758 .43025 L
s
.83243 .46145 m
.83254 .46214 L
s
.46228 .50141 m
.46262 .50393 L
s
.48286 .48379 m
.4831 .48624 L
s
.84694 .44799 m
.8444 .449 L
s
.42518 .53343 m
.4396 .5278 L
s
.57068 .4088 m
.57046 .41098 L
s
.83254 .46214 m
.83265 .46283 L
s
.44994 .45958 m
.45073 .46131 L
s
.52545 .44813 m
.52548 .45044 L
s
.83265 .46283 m
.83276 .46353 L
s
.50081 .45823 m
.50174 .45951 L
s
.47496 .45883 m
.47581 .46034 L
s
.55704 .45686 m
.55818 .45768 L
s
.44223 .51966 m
.44268 .52226 L
s
.50394 .46679 m
.50408 .46917 L
s
.36644 .46349 m
.3823 .46054 L
s
.52749 .4572 m
.5285 .45825 L
s
.84946 .44695 m
.84694 .44799 L
s
.54758 .43025 m
.5475 .43249 L
s
.57046 .41098 m
.57026 .41316 L
s
.42497 .45913 m
.42567 .46109 L
s
.55594 .45603 m
.55704 .45686 L
s
.40075 .45964 m
.4014 .46181 L
s
.4831 .48624 m
.48337 .48868 L
s
.46262 .50393 m
.463 .50645 L
s
.52548 .45044 m
.52553 .45274 L
s
.49993 .45694 m
.50081 .45823 L
s
.50408 .46917 m
.50425 .47155 L
s
.85197 .44587 m
.84946 .44695 L
s
.52653 .45613 m
.52749 .4572 L
s
.47417 .45731 m
.47496 .45883 L
s
.44921 .45784 m
.44994 .45958 L
s
.5475 .43249 m
.54744 .43472 L
s
.55488 .45519 m
.55594 .45603 L
s
.57026 .41316 m
.57009 .41533 L
s
.58275 .40248 m
.59755 .39878 L
s
.81494 .41846 m
.82106 .4283 L
s
.82156 .43005 m
.82159 .43071 L
s
.78683 .44791 m
.78414 .4482 L
s
.48337 .48868 m
.48366 .49113 L
s
.52553 .45274 m
.5256 .45504 L
s
.85445 .44476 m
.85197 .44587 L
s
.78951 .44758 m
.78683 .44791 L
s
.463 .50645 m
.4634 .50897 L
s
.82159 .43071 m
.82163 .43138 L
s
.5256 .45504 m
.52653 .45613 L
s
.55385 .45433 m
.55488 .45519 L
s
.4991 .45563 m
.49993 .45694 L
s
.79216 .44722 m
.78951 .44758 L
s
.50425 .47155 m
.50444 .47391 L
s
.3823 .46054 m
.39819 .45758 L
s
.42434 .45715 m
.42497 .45913 L
s
.54744 .43472 m
.54741 .43695 L
s
.57009 .41533 m
.56994 .41749 L
s
.58029 .45413 m
.59368 .44774 L
s
.7948 .44683 m
.79216 .44722 L
s
.82163 .43138 m
.82167 .43205 L
s
.47342 .45577 m
.47417 .45731 L
s
0 g
.5 Mabswid
.24163 .52647 m
.23677 .49966 L
s
.039 .916 .04 r
1 Mabswid
.4396 .5278 m
.45407 .52216 L
s
.79741 .44641 m
.7948 .44683 L
s
0 g
.5 Mabswid
.86794 .57899 m
.89397 .56827 L
s
.86794 .57899 m
.86794 .57899 L
s
.039 .916 .04 r
1 Mabswid
.44854 .45607 m
.44921 .45784 L
s
.85691 .44362 m
.85445 .44476 L
s
.82167 .43205 m
.82172 .43273 L
s
.55285 .45347 m
.55385 .45433 L
s
.8 .44596 m
.79741 .44641 L
s
0 g
.5 Mabswid
.93695 .53181 m
.95076 .50874 L
s
.039 .916 .04 r
1 Mabswid
.5256 .45504 m
.52571 .45733 L
s
.52472 .45394 m
.5256 .45504 L
s
.87152 .43592 m
.88033 .4437 L
s
.48366 .49113 m
.48398 .49356 L
s
.56994 .41749 m
.5698 .41965 L
s
.49831 .4543 m
.4991 .45563 L
s
.82172 .43273 m
.82177 .43342 L
s
.80258 .44548 m
.8 .44596 L
s
.54741 .43695 m
.5474 .43917 L
s
.4634 .50897 m
.46382 .51148 L
s
.50444 .47391 m
.50466 .47628 L
s
.55189 .45259 m
.55285 .45347 L
s
.80513 .44497 m
.80258 .44548 L
s
.82177 .43342 m
.82182 .43411 L
s
.85934 .44244 m
.85691 .44362 L
s
0 g
.5 Mabswid
.26082 .57915 m
.24985 .55365 L
s
.039 .916 .04 r
1 Mabswid
.47273 .45421 m
.47342 .45577 L
s
.42377 .45515 m
.42434 .45715 L
s
.52388 .45283 m
.52472 .45394 L
s
.80766 .44443 m
.80513 .44497 L
s
.82182 .43411 m
.82187 .4348 L
s
.52571 .45733 m
.52583 .45962 L
s
.5698 .41965 m
.5697 .4218 L
s
.44792 .45428 m
.44854 .45607 L
s
.58154 .4511 m
.5826 .45175 L
s
.5474 .43917 m
.54742 .44139 L
s
.48398 .49356 m
.48433 .49599 L
s
.39819 .45758 m
.41412 .45461 L
s
.81017 .44385 m
.80766 .44443 L
s
.55096 .4517 m
.55189 .45259 L
s
.49756 .45295 m
.49831 .4543 L
s
.82187 .4348 m
.82193 .4355 L
s
.50466 .47628 m
.50491 .47863 L
s
.46382 .51148 m
.46428 .51398 L
s
.86176 .44122 m
.85934 .44244 L
s
.82193 .4355 m
.82199 .4362 L
s
.81266 .44325 m
.81017 .44385 L
s
.5805 .45044 m
.58154 .4511 L
s
.52307 .4517 m
.52388 .45283 L
s
.82379 .45282 m
.82966 .46039 L
s
.5697 .4218 m
.56961 .42395 L
s
.82199 .4362 m
.82206 .43691 L
s
.47208 .45263 m
.47273 .45421 L
s
.55007 .4508 m
.55096 .4517 L
s
.52583 .45962 m
.52598 .46191 L
s
.81513 .44262 m
.81266 .44325 L
s
.54742 .44139 m
.54746 .44361 L
s
.5795 .44977 m
.5805 .45044 L
s
.59755 .39878 m
.61242 .39506 L
s
.82206 .43691 m
.82212 .43762 L
s
.48433 .49599 m
.4847 .49842 L
s
.49687 .45159 m
.49756 .45295 L
s
.59273 .40315 m
.59253 .40523 L
s
.86416 .43997 m
.86176 .44122 L
s
.45407 .52216 m
.46858 .5165 L
s
.50491 .47863 m
.50518 .48099 L
s
.81758 .44195 m
.81513 .44262 L
s
.44736 .45247 m
.44792 .45428 L
s
.82212 .43762 m
.82219 .43834 L
s
.52231 .45056 m
.52307 .4517 L
s
.54921 .44988 m
.55007 .4508 L
s
.56961 .42395 m
.56955 .4261 L
s
.57852 .44909 m
.5795 .44977 L
s
.77624 .43361 m
.77943 .44327 L
s
.82001 .44125 m
.81758 .44195 L
s
.82219 .43834 m
.82227 .43907 L
s
.52598 .46191 m
.52615 .46418 L
s
.54746 .44361 m
.54752 .44582 L
s
.41412 .45461 m
.43008 .45164 L
s
.59253 .40523 m
.59235 .40731 L
s
.47149 .45103 m
.47208 .45263 L
s
.82227 .43907 m
.82235 .43979 L
s
.86654 .43868 m
.86416 .43997 L
s
.57757 .4484 m
.57852 .44909 L
s
.49621 .45021 m
.49687 .45159 L
s
.82243 .44053 m
.82001 .44125 L
s
.54839 .44896 m
.54921 .44988 L
s
.4847 .49842 m
.4851 .50084 L
s
.50518 .48099 m
.50547 .48333 L
s
.52159 .4494 m
.52231 .45056 L
s
.82235 .43979 m
.82243 .44053 L
s
.56955 .4261 m
.5695 .42823 L
s
.57666 .4477 m
.57757 .4484 L
s
.82243 .44053 m
.82251 .44127 L
s
.82482 .43977 m
.82243 .44053 L
s
.59235 .40731 m
.59219 .40938 L
s
0 g
.5 Mabswid
.24985 .55365 m
.24163 .52647 L
s
.039 .916 .04 r
1 Mabswid
.44686 .45064 m
.44736 .45247 L
s
.54752 .44582 m
.5476 .44802 L
s
.59368 .44774 m
.60714 .44131 L
s
.52615 .46418 m
.52635 .46646 L
s
0 g
.5 Mabswid
.89397 .56827 m
.91755 .55215 L
s
.039 .916 .04 r
1 Mabswid
.5476 .44802 m
.54839 .44896 L
s
.82251 .44127 m
.8226 .44201 L
s
0 g
.5 Mabswid
.91755 .55215 m
.93695 .53181 L
s
.039 .916 .04 r
1 Mabswid
.8689 .43736 m
.86654 .43868 L
s
.57577 .44699 m
.57666 .4477 L
s
.82719 .43898 m
.82482 .43977 L
s
.47095 .44941 m
.47149 .45103 L
s
.49561 .44882 m
.49621 .45021 L
s
.52091 .44823 m
.52159 .4494 L
s
.5695 .42823 m
.56948 .43037 L
s
.8226 .44201 m
.82269 .44276 L
s
.50547 .48333 m
.50579 .48567 L
s
.4851 .50084 m
.48553 .50325 L
s
.59219 .40938 m
.59206 .41145 L
s
.82269 .44276 m
.82278 .44351 L
s
.5476 .44802 m
.54771 .45022 L
s
.54685 .44707 m
.5476 .44802 L
s
.82954 .43816 m
.82719 .43898 L
s
.52635 .46646 m
.52658 .46873 L
s
.57491 .44628 m
.57577 .44699 L
s
.43008 .45164 m
.44608 .44866 L
s
.80876 .40855 m
.81494 .41846 L
s
.82278 .44351 m
.82288 .44427 L
s
.46858 .5165 m
.48314 .51082 L
s
.56948 .43037 m
.56949 .4325 L
s
.52026 .44705 m
.52091 .44823 L
s
.82288 .44427 m
.82298 .44503 L
s
.59206 .41145 m
.59194 .41351 L
s
.83188 .43731 m
.82954 .43816 L
s
.49505 .4474 m
.49561 .44882 L
s
.57408 .44555 m
.57491 .44628 L
s
.50579 .48567 m
.50614 .48801 L
s
.54613 .44611 m
.54685 .44707 L
s
.47047 .44778 m
.47095 .44941 L
s
.82298 .44503 m
.82308 .4458 L
s
.48553 .50325 m
.48598 .50566 L
s
.54771 .45022 m
.54784 .45241 L
s
.61242 .39506 m
.62735 .39133 L
s
.52658 .46873 m
.52682 .47099 L
s
.82308 .4458 m
.82318 .44657 L
s
.57328 .44481 m
.57408 .44555 L
s
.83419 .43642 m
.83188 .43731 L
s
.56949 .4325 m
.56951 .43462 L
s
.86265 .42808 m
.87152 .43592 L
s
.82318 .44657 m
.82329 .44735 L
s
.51966 .44585 m
.52026 .44705 L
s
.59194 .41351 m
.59185 .41557 L
s
.54545 .44513 m
.54613 .44611 L
s
.82329 .44735 m
.82341 .44813 L
s
.49454 .44598 m
.49505 .4474 L
s
.50614 .48801 m
.50651 .49034 L
s
.57251 .44406 m
.57328 .44481 L
s
.83648 .43551 m
.83419 .43642 L
s
.54784 .45241 m
.548 .4546 L
s
.82341 .44813 m
.82352 .44891 L
s
.44608 .44866 m
.46211 .44568 L
s
.47003 .44612 m
.47047 .44778 L
s
.52682 .47099 m
.5271 .47325 L
s
.56951 .43462 m
.56956 .43674 L
s
.59185 .41557 m
.59177 .41762 L
s
.82352 .44891 m
.82364 .44971 L
s
.5448 .44415 m
.54545 .44513 L
s
.5191 .44463 m
.51966 .44585 L
s
.57177 .4433 m
.57251 .44406 L
s
.82364 .44971 m
.82376 .4505 L
s
.83876 .43456 m
.83648 .43551 L
s
.82376 .4505 m
.82389 .4513 L
s
.60143 .44208 m
.60228 .4426 L
s
.548 .4546 m
.54818 .45678 L
s
.49407 .44453 m
.49454 .44598 L
s
.50651 .49034 m
.50691 .49267 L
s
.61491 .39746 m
.61473 .39944 L
s
.57106 .44253 m
.57177 .4433 L
s
.54419 .44315 m
.5448 .44415 L
s
.82389 .4513 m
.82402 .45211 L
s
.59177 .41762 m
.59172 .41967 L
s
.56956 .43674 m
.56963 .43885 L
s
.48314 .51082 m
.49774 .50512 L
s
.5271 .47325 m
.52739 .4755 L
s
.84102 .43358 m
.83876 .43456 L
s
.60059 .44154 m
.60143 .44208 L
s
.51859 .4434 m
.5191 .44463 L
s
.81242 .4155 m
.81246 .41625 L
s
.57038 .44175 m
.57106 .44253 L
s
.61473 .39944 m
.61457 .40142 L
s
.59979 .441 m
.60059 .44154 L
s
.60714 .44131 m
.62067 .43485 L
s
.54818 .45678 m
.54838 .45896 L
s
.54361 .44213 m
.54419 .44315 L
s
.59172 .41967 m
.59169 .42171 L
s
.84325 .43258 m
.84102 .43358 L
s
.46211 .44568 m
.47817 .44269 L
s
.81246 .41625 m
.8125 .41701 L
s
.56963 .43885 m
.56972 .44096 L
s
.49365 .44307 m
.49407 .44453 L
s
.50691 .49267 m
.50734 .49499 L
s
.59901 .44045 m
.59979 .441 L
s
.52739 .4755 m
.52772 .47775 L
s
.81788 .44519 m
.82379 .45282 L
s
.56972 .44096 m
.57038 .44175 L
s
.51811 .44216 m
.51859 .4434 L
s
.8125 .41701 m
.81254 .41777 L
s
.61457 .40142 m
.61443 .4034 L
s
.59825 .43989 m
.59901 .44045 L
s
.84547 .43153 m
.84325 .43258 L
s
.54307 .44111 m
.54361 .44213 L
s
.59169 .42171 m
.59169 .42375 L
s
.81254 .41777 m
.81259 .41854 L
s
.54838 .45896 m
.54861 .46114 L
s
.62735 .39133 m
.64235 .38758 L
s
.78162 .43401 m
.77921 .43427 L
s
.56972 .44096 m
.56984 .44306 L
s
.5691 .44016 m
.56972 .44096 L
s
.59751 .43932 m
.59825 .43989 L
s
.784 .43371 m
.78162 .43401 L
s
.50734 .49499 m
.50779 .49731 L
s
.49328 .44159 m
.49365 .44307 L
s
.81259 .41854 m
.81264 .41932 L
s
.78637 .43339 m
.784 .43371 L
s
.61443 .4034 m
.61431 .40537 L
s
.52772 .47775 m
.52806 .47999 L
s
.51767 .4409 m
.51811 .44216 L
s
.84767 .43046 m
.84547 .43153 L
s
.78872 .43304 m
.78637 .43339 L
s
.54256 .44007 m
.54307 .44111 L
s
.5968 .43875 m
.59751 .43932 L
s
.77302 .42386 m
.77624 .43361 L
s
.56851 .43935 m
.5691 .44016 L
s
.81264 .41932 m
.8127 .4201 L
s
.59169 .42375 m
.5917 .42578 L
s
.79106 .43267 m
.78872 .43304 L
s
.54861 .46114 m
.54886 .4633 L
s
.56984 .44306 m
.56998 .44516 L
s
.47817 .44269 m
.49427 .43969 L
s
.79337 .43226 m
.79106 .43267 L
s
.49774 .50512 m
.5124 .49941 L
s
.59611 .43816 m
.5968 .43875 L
s
.8127 .4201 m
.81276 .42089 L
s
.61431 .40537 m
.61421 .40733 L
s
.79567 .43183 m
.79337 .43226 L
s
.84985 .42936 m
.84767 .43046 L
s
.56794 .43853 m
.56851 .43935 L
s
.51727 .43963 m
.51767 .4409 L
s
.54209 .43902 m
.54256 .44007 L
s
.52806 .47999 m
.52843 .48223 L
s
.81276 .42089 m
.81282 .42168 L
s
.79794 .43137 m
.79567 .43183 L
s
.5917 .42578 m
.59173 .42781 L
s
.59545 .43757 m
.59611 .43816 L
s
.80254 .39856 m
.80876 .40855 L
s
.8002 .43089 m
.79794 .43137 L
s
.56998 .44516 m
.57014 .44725 L
s
.54886 .4633 m
.54913 .46547 L
s
.81282 .42168 m
.81289 .42248 L
s
.61421 .40733 m
.61413 .40929 L
s
.56741 .4377 m
.56794 .43853 L
s
.59481 .43697 m
.59545 .43757 L
s
.85201 .42822 m
.84985 .42936 L
s
.80244 .43037 m
.8002 .43089 L
s
.54166 .43796 m
.54209 .43902 L
s
.81289 .42248 m
.81296 .42328 L
s
.51692 .43834 m
.51727 .43963 L
s
.59173 .42781 m
.59179 .42983 L
s
.52843 .48223 m
.52883 .48446 L
s
.80467 .42983 m
.80244 .43037 L
s
.59419 .43637 m
.59481 .43697 L
s
.5669 .43686 m
.56741 .4377 L
s
.81296 .42328 m
.81304 .42409 L
s
.61413 .40929 m
.61407 .41125 L
s
.85371 .42019 m
.86265 .42808 L
s
.57014 .44725 m
.57032 .44934 L
s
.80687 .42926 m
.80467 .42983 L
s
.54913 .46547 m
.54943 .46763 L
s
.49427 .43969 m
.51041 .43669 L
s
.85415 .42705 m
.85201 .42822 L
s
.5936 .43575 m
.59419 .43637 L
s
.81304 .42409 m
.81312 .42491 L
s
.54126 .43689 m
.54166 .43796 L
s
.80906 .42866 m
.80687 .42926 L
s
.59179 .42983 m
.59187 .43185 L
s
.56643 .43601 m
.5669 .43686 L
s
.5166 .43704 m
.51692 .43834 L
s
.81312 .42491 m
.8132 .42573 L
s
.61407 .41125 m
.61403 .4132 L
s
.59303 .43513 m
.5936 .43575 L
s
.62067 .43485 m
.63427 .42836 L
s
.52883 .48446 m
.52925 .48669 L
s
.63724 .39173 m
.63708 .39362 L
s
.81122 .42804 m
.80906 .42866 L
s
.64235 .38758 m
.65741 .38381 L
s
.57032 .44934 m
.57053 .45143 L
s
.85628 .42585 m
.85415 .42705 L
s
.8132 .42573 m
.81328 .42655 L
s
.54943 .46763 m
.54975 .46978 L
s
.5124 .49941 m
.52709 .49367 L
s
.54089 .4358 m
.54126 .43689 L
s
.56598 .43515 m
.56643 .43601 L
s
.59249 .4345 m
.59303 .43513 L
s
.81337 .42739 m
.81122 .42804 L
s
.59187 .43185 m
.59197 .43386 L
s
.81328 .42655 m
.81337 .42739 L
s
.61403 .4132 m
.61402 .41515 L
s
.63708 .39362 m
.63693 .3955 L
s
.59197 .43386 m
.59249 .4345 L
s
.81337 .42739 m
.81347 .42822 L
s
.81551 .4267 m
.81337 .42739 L
s
.52925 .48669 m
.5297 .48891 L
s
.62146 .43298 m
.62211 .43339 L
s
.56557 .43428 m
.56598 .43515 L
s
.57053 .45143 m
.57076 .4535 L
s
.54056 .4347 m
.54089 .4358 L
s
.51041 .43669 m
.52658 .43368 L
s
.54975 .46978 m
.5501 .47193 L
s
.81347 .42822 m
.81356 .42907 L
s
.62084 .43258 m
.62146 .43298 L
s
.59197 .43386 m
.59209 .43587 L
s
.59147 .43321 m
.59197 .43386 L
s
.81762 .426 m
.81551 .4267 L
s
.63693 .3955 m
.63681 .39738 L
s
.61402 .41515 m
.61402 .41709 L
s
.81356 .42907 m
.81367 .42992 L
s
.62023 .43216 m
.62084 .43258 L
s
.56518 .43339 m
.56557 .43428 L
s
.81972 .42526 m
.81762 .426 L
s
.591 .43256 m
.59147 .43321 L
s
.81367 .42992 m
.81377 .43077 L
s
.57076 .4535 m
.57101 .45558 L
s
.61964 .43174 m
.62023 .43216 L
s
.54027 .43359 m
.54056 .4347 L
s
.63681 .39738 m
.6367 .39925 L
s
.59209 .43587 m
.59223 .43787 L
s
.61402 .41709 m
.61404 .41902 L
s
.5501 .47193 m
.55047 .47407 L
s
.81377 .43077 m
.81388 .43163 L
s
.61906 .43131 m
.61964 .43174 L
s
.56482 .4325 m
.56518 .43339 L
s
.8218 .4245 m
.81972 .42526 L
s
.59055 .43189 m
.591 .43256 L
s
.81388 .43163 m
.81399 .4325 L
s
.61851 .43088 m
.61906 .43131 L
s
.54001 .43247 m
.54027 .43359 L
s
.6367 .39925 m
.63662 .40112 L
s
.57101 .45558 m
.57128 .45765 L
s
.59013 .43122 m
.59055 .43189 L
s
.82386 .4237 m
.8218 .4245 L
s
.81399 .4325 m
.81411 .43337 L
s
.61797 .43044 m
.61851 .43088 L
s
.61404 .41902 m
.61409 .42095 L
s
.5645 .4316 m
.56482 .4325 L
s
.52709 .49367 m
.54184 .48792 L
s
.59223 .43787 m
.5924 .43987 L
s
.52658 .43368 m
.54279 .43066 L
s
.81191 .4375 m
.81788 .44519 L
s
.55047 .47407 m
.55086 .47621 L
s
.81411 .43337 m
.81422 .43425 L
s
.61745 .43 m
.61797 .43044 L
s
.58973 .43054 m
.59013 .43122 L
s
.8259 .42288 m
.82386 .4237 L
s
.63662 .40112 m
.63655 .40298 L
s
.81422 .43425 m
.81435 .43513 L
s
.61695 .42955 m
.61745 .43 L
s
.5642 .43069 m
.5645 .4316 L
s
.65741 .38381 m
.67254 .38003 L
s
.61409 .42095 m
.61415 .42288 L
s
.57128 .45765 m
.57158 .45971 L
s
.58935 .42985 m
.58973 .43054 L
s
.81435 .43513 m
.81447 .43602 L
s
.5924 .43987 m
.59259 .44186 L
s
.82793 .42203 m
.8259 .42288 L
s
.61647 .42909 m
.61695 .42955 L
s
.55086 .47621 m
.55128 .47834 L
s
.81447 .43602 m
.8146 .43691 L
s
.63655 .40298 m
.6365 .40484 L
s
.61601 .42863 m
.61647 .42909 L
s
.56393 .42977 m
.5642 .43069 L
s
.589 .42916 m
.58935 .42985 L
s
.63427 .42836 m
.64794 .42184 L
s
.76977 .41403 m
.77302 .42386 L
s
.79628 .3885 m
.80254 .39856 L
s
.8146 .43691 m
.81474 .43781 L
s
.82994 .42116 m
.82793 .42203 L
s
.61415 .42288 m
.61423 .4248 L
s
.80318 .40078 m
.80322 .40162 L
s
.61557 .42816 m
.61601 .42863 L
s
.57158 .45971 m
.5719 .46177 L
s
.59259 .44186 m
.59279 .44385 L
s
.81474 .43781 m
.81488 .43872 L
s
.54279 .43066 m
.55903 .42764 L
s
.58867 .42845 m
.589 .42916 L
s
.6365 .40484 m
.63648 .4067 L
s
.61514 .42769 m
.61557 .42816 L
s
.56369 .42883 m
.56393 .42977 L
s
.80322 .40162 m
.80326 .40247 L
s
.81488 .43872 m
.81502 .43963 L
s
.83193 .42025 m
.82994 .42116 L
s
.55128 .47834 m
.55172 .48047 L
s
.84471 .41224 m
.85371 .42019 L
s
.61423 .4248 m
.61434 .42672 L
s
.81502 .43963 m
.81516 .44055 L
s
.65971 .38597 m
.65956 .38776 L
s
.61473 .42721 m
.61514 .42769 L
s
.58837 .42774 m
.58867 .42845 L
s
.80326 .40247 m
.80331 .40333 L
s
.59279 .44385 m
.59302 .44583 L
s
.5719 .46177 m
.57224 .46382 L
s
.63648 .4067 m
.63647 .40854 L
s
.54184 .48792 m
.55663 .48215 L
s
.61434 .42672 m
.61473 .42721 L
s
.56349 .42789 m
.56369 .42883 L
s
.83391 .41932 m
.83193 .42025 L
s
.80331 .40333 m
.80336 .40419 L
s
.58809 .42702 m
.58837 .42774 L
s
.65956 .38776 m
.65943 .38954 L
s
.61434 .42672 m
.61447 .42863 L
s
.61397 .42623 m
.61434 .42672 L
s
.83587 .41836 m
.83391 .41932 L
s
.80336 .40419 m
.80342 .40506 L
s
.63647 .40854 m
.63648 .41039 L
s
.59302 .44583 m
.59328 .44781 L
s
.61361 .42573 m
.61397 .42623 L
s
.58783 .42629 m
.58809 .42702 L
s
.57224 .46382 m
.57261 .46587 L
s
.65943 .38954 m
.65932 .39132 L
s
.55903 .42764 m
.5753 .42461 L
s
.80342 .40506 m
.80348 .40593 L
s
.61328 .42522 m
.61361 .42573 L
s
.61447 .42863 m
.61461 .43054 L
s
.5876 .42555 m
.58783 .42629 L
s
.83781 .41736 m
.83587 .41836 L
s
.63648 .41039 m
.63651 .41223 L
s
.77633 .41993 m
.77422 .42017 L
s
.61296 .42471 m
.61328 .42522 L
s
.80348 .40593 m
.80354 .40681 L
s
.77843 .41967 m
.77633 .41993 L
s
.59328 .44781 m
.59355 .44979 L
s
.65932 .39132 m
.65923 .3931 L
s
.67254 .38003 m
.68773 .37624 L
s
.64165 .42382 m
.64209 .4241 L
s
.78051 .41939 m
.77843 .41967 L
s
.57261 .46587 m
.573 .46792 L
s
.78258 .41908 m
.78051 .41939 L
s
.58739 .42481 m
.5876 .42555 L
s
.64122 .42354 m
.64165 .42382 L
s
.61266 .42419 m
.61296 .42471 L
s
.80354 .40681 m
.80361 .4077 L
s
.61461 .43054 m
.61478 .43244 L
s
.83973 .41635 m
.83781 .41736 L
s
.78462 .41875 m
.78258 .41908 L
s
.64081 .42326 m
.64122 .42354 L
s
.63651 .41223 m
.63656 .41406 L
s
.78666 .41839 m
.78462 .41875 L
s
.61238 .42367 m
.61266 .42419 L
s
.65923 .3931 m
.65916 .39487 L
s
.64041 .42297 m
.64081 .42326 L
s
.80361 .4077 m
.80369 .40859 L
s
.58721 .42405 m
.58739 .42481 L
s
.59355 .44979 m
.59385 .45175 L
s
.78867 .41801 m
.78666 .41839 L
s
.64002 .42268 m
.64041 .42297 L
s
.573 .46792 m
.57341 .46996 L
s
.61212 .42314 m
.61238 .42367 L
s
.79067 .41761 m
.78867 .41801 L
s
.84164 .4153 m
.83973 .41635 L
s
.55663 .48215 m
.57148 .47636 L
s
.63965 .42239 m
.64002 .42268 L
s
.61478 .43244 m
.61497 .43434 L
s
.80369 .40859 m
.80376 .40949 L
s
.5753 .42461 m
.59162 .42157 L
s
.63656 .41406 m
.63664 .41589 L
s
.79265 .41718 m
.79067 .41761 L
s
.65916 .39487 m
.65911 .39663 L
s
.63929 .42209 m
.63965 .42239 L
s
.58705 .42329 m
.58721 .42405 L
s
.61188 .4226 m
.61212 .42314 L
s
.64794 .42184 m
.66169 .41528 L
s
.63894 .42178 m
.63929 .42209 L
s
.79462 .41672 m
.79265 .41718 L
s
.80376 .40949 m
.80385 .4104 L
s
.59385 .45175 m
.59416 .45372 L
s
.6386 .42147 m
.63894 .42178 L
s
.84353 .41422 m
.84164 .4153 L
s
.61165 .42206 m
.61188 .4226 L
s
.79657 .41624 m
.79462 .41672 L
s
.57341 .46996 m
.57385 .47199 L
s
.61497 .43434 m
.61518 .43623 L
s
.80385 .4104 m
.80393 .41131 L
s
.65911 .39663 m
.65907 .39839 L
s
.63664 .41589 m
.63673 .41772 L
s
.63827 .42116 m
.6386 .42147 L
s
.79851 .41574 m
.79657 .41624 L
s
.61145 .42151 m
.61165 .42206 L
s
.63796 .42084 m
.63827 .42116 L
s
.80393 .41131 m
.80402 .41223 L
s
.80043 .41521 m
.79851 .41574 L
s
.63766 .42052 m
.63796 .42084 L
s
.59416 .45372 m
.5945 .45568 L
s
.61126 .42096 m
.61145 .42151 L
s
.65907 .39839 m
.65905 .40015 L
s
.63673 .41772 m
.63684 .41954 L
s
.63737 .4202 m
.63766 .42052 L
s
.61518 .43623 m
.61541 .43812 L
s
.80402 .41223 m
.80412 .41315 L
s
.80233 .41466 m
.80043 .41521 L
s
.8059 .42973 m
.81191 .4375 L
s
.6371 .41987 m
.63737 .4202 L
s
.61109 .4204 m
.61126 .42096 L
s
.59162 .42157 m
.60797 .41852 L
s
.80412 .41315 m
.80422 .41409 L
s
.80422 .41409 m
.80233 .41466 L
s
.63684 .41954 m
.6371 .41987 L
s
.68232 .38017 m
.68219 .38186 L
s
.78997 .37836 m
.79628 .3885 L
s
.65905 .40015 m
.65906 .4019 L
s
.5945 .45568 m
.59487 .45763 L
s
.61094 .41983 m
.61109 .4204 L
s
.63684 .41954 m
.63697 .42136 L
s
.63659 .4192 m
.63684 .41954 L
s
.80422 .41409 m
.80432 .41502 L
s
.80609 .41349 m
.80422 .41409 L
s
.61541 .43812 m
.61566 .44 L
s
.68773 .37624 m
.70298 .37242 L
s
.63635 .41886 m
.63659 .4192 L
s
.57148 .47636 m
.58637 .47055 L
s
.6108 .41926 m
.61094 .41983 L
s
.80432 .41502 m
.80442 .41597 L
s
.68219 .38186 m
.68207 .38355 L
s
.80794 .41286 m
.80609 .41349 L
s
.83565 .40424 m
.84471 .41224 L
s
.63613 .41852 m
.63635 .41886 L
s
.65906 .4019 m
.65908 .40365 L
s
.63697 .42136 m
.63712 .42317 L
s
.63591 .41817 m
.63613 .41852 L
s
.61069 .41868 m
.6108 .41926 L
s
.59487 .45763 m
.59525 .45958 L
s
.80442 .41597 m
.80454 .41692 L
s
.80978 .41221 m
.80794 .41286 L
s
.61566 .44 m
.61593 .44188 L
s
.7665 .40411 m
.76977 .41403 L
s
.63571 .41781 m
.63591 .41817 L
s
.68207 .38355 m
.68198 .38523 L
s
.80454 .41692 m
.80465 .41788 L
s
.65908 .40365 m
.65912 .40539 L
s
.63553 .41746 m
.63571 .41781 L
s
.8116 .41153 m
.80978 .41221 L
s
.60797 .41852 m
.62435 .41547 L
s
.63712 .42317 m
.63729 .42497 L
s
.63535 .41709 m
.63553 .41746 L
s
.80465 .41788 m
.80477 .41884 L
s
.68198 .38523 m
.6819 .38691 L
s
.59525 .45958 m
.59566 .46153 L
s
.61593 .44188 m
.61623 .44376 L
s
.81341 .41084 m
.8116 .41153 L
s
.63519 .41673 m
.63535 .41709 L
s
.65912 .40539 m
.65917 .40713 L
s
.80477 .41884 m
.80489 .41981 L
s
.63504 .41636 m
.63519 .41673 L
s
.8152 .41011 m
.81341 .41084 L
s
.63729 .42497 m
.63748 .42678 L
s
.80489 .41981 m
.80502 .42079 L
s
.6819 .38691 m
.68184 .38858 L
s
.6349 .41598 m
.63504 .41636 L
s
.66169 .41528 m
.67551 .40868 L
s
.61623 .44376 m
.61654 .44563 L
s
.59566 .46153 m
.59608 .46347 L
s
.65917 .40713 m
.65925 .40886 L
s
.63478 .41561 m
.6349 .41598 L
s
.80502 .42079 m
.80515 .42177 L
s
.81698 .40936 m
.8152 .41011 L
s
.66199 .41459 m
.66222 .41474 L
s
.63467 .41522 m
.63478 .41561 L
s
.68184 .38858 m
.6818 .39025 L
s
.58637 .47055 m
.6013 .46473 L
s
.66176 .41445 m
.66199 .41459 L
s
.80515 .42177 m
.80529 .42276 L
s
.63748 .42678 m
.63769 .42857 L
s
.79383 .38591 m
.79387 .38684 L
s
.66155 .41429 m
.66176 .41445 L
s
.63457 .41484 m
.63467 .41522 L
s
.81874 .40859 m
.81698 .40936 L
s
.66134 .41414 m
.66155 .41429 L
s
.62435 .41547 m
.64077 .41242 L
s
.65925 .40886 m
.65935 .41059 L
s
.66113 .41399 m
.66134 .41414 L
s
.80529 .42276 m
.80543 .42376 L
s
.61654 .44563 m
.61688 .44749 L
s
.63448 .41445 m
.63457 .41484 L
s
.66094 .41383 m
.66113 .41399 L
s
.6818 .39025 m
.68177 .39191 L
s
.66074 .41367 m
.66094 .41383 L
s
.79387 .38684 m
.79392 .38777 L
s
.80543 .42376 m
.80558 .42476 L
s
.66056 .41351 m
.66074 .41367 L
s
.70298 .37242 m
.71831 .36859 L
s
.82049 .40779 m
.81874 .40859 L
s
.63441 .41405 m
.63448 .41445 L
s
.63769 .42857 m
.63792 .43037 L
s
.66038 .41334 m
.66056 .41351 L
s
.66021 .41318 m
.66038 .41334 L
s
.65935 .41059 m
.65946 .41232 L
s
.80558 .42476 m
.80572 .42577 L
s
.66005 .41301 m
.66021 .41318 L
s
.79392 .38777 m
.79397 .38872 L
s
.65989 .41284 m
.66005 .41301 L
s
.61688 .44749 m
.61723 .44935 L
s
.68177 .39191 m
.68177 .39357 L
s
.82222 .40696 m
.82049 .40779 L
s
.65974 .41267 m
.65989 .41284 L
s
.80572 .42577 m
.80588 .42679 L
s
.6596 .41249 m
.65974 .41267 L
s
.63792 .43037 m
.63817 .43215 L
s
.79397 .38872 m
.79402 .38967 L
s
.65946 .41232 m
.6596 .41249 L
s
.80588 .42679 m
.80603 .42781 L
s
.65946 .41232 m
.6596 .41404 L
s
.65933 .41214 m
.65946 .41232 L
s
.82393 .40612 m
.82222 .40696 L
s
.65921 .41196 m
.65933 .41214 L
s
.68177 .39357 m
.68178 .39522 L
s
.65909 .41178 m
.65921 .41196 L
s
.80603 .42781 m
.8062 .42884 L
s
.61723 .44935 m
.61761 .45121 L
s
.79402 .38967 m
.79409 .39063 L
s
.64077 .41242 m
.65723 .40935 L
s
.65898 .41159 m
.65909 .41178 L
s
.70507 .37434 m
.70495 .37593 L
s
.65888 .4114 m
.65898 .41159 L
s
.63817 .43215 m
.63844 .43394 L
s
.65878 .41121 m
.65888 .4114 L
s
.82563 .40524 m
.82393 .40612 L
s
.6596 .41404 m
.65975 .41575 L
s
.68178 .39522 m
.68181 .39687 L
s
.79409 .39063 m
.79415 .3916 L
s
.65869 .41102 m
.65878 .41121 L
s
.65861 .41083 m
.65869 .41102 L
s
.6013 .46473 m
.61629 .45888 L
s
.70495 .37593 m
.70486 .37752 L
s
.65853 .41063 m
.65861 .41083 L
s
.61761 .45121 m
.61801 .45306 L
s
.65846 .41043 m
.65853 .41063 L
s
.82732 .40434 m
.82563 .40524 L
s
.79415 .3916 m
.79422 .39257 L
s
.78361 .36815 m
.78997 .37836 L
s
.65839 .41023 m
.65846 .41043 L
s
.63844 .43394 m
.63873 .43572 L
s
.65975 .41575 m
.65992 .41746 L
s
.68181 .39687 m
.68185 .39852 L
s
.65834 .41003 m
.65839 .41023 L
s
.70486 .37752 m
.70477 .3791 L
s
.65829 .40983 m
.65834 .41003 L
s
.79422 .39257 m
.79429 .39355 L
s
.79983 .42191 m
.8059 .42973 L
s
.82652 .39617 m
.83565 .40424 L
s
.65824 .40962 m
.65829 .40983 L
s
.82899 .40342 m
.82732 .40434 L
s
.65821 .40941 m
.65824 .40962 L
s
.61801 .45306 m
.61843 .4549 L
s
.68185 .39852 m
.68192 .40016 L
s
.77098 .40568 m
.76916 .40589 L
s
.65992 .41746 m
.66011 .41917 L
s
.70477 .3791 m
.70471 .38068 L
s
.63873 .43572 m
.63904 .43749 L
s
.65723 .40935 m
.67372 .40628 L
s
.79429 .39355 m
.79437 .39454 L
s
.77278 .40546 m
.77098 .40568 L
s
.67551 .40868 m
.69025 .4032 L
s
.77457 .40521 m
.77278 .40546 L
s
.77635 .40495 m
.77457 .40521 L
s
.83064 .40247 m
.82899 .40342 L
s
.71831 .36859 m
.73369 .36475 L
s
.77811 .40466 m
.77635 .40495 L
s
.79437 .39454 m
.79446 .39554 L
s
.68192 .40016 m
.682 .4018 L
s
.70471 .38068 m
.70466 .38225 L
s
.77986 .40435 m
.77811 .40466 L
s
.66011 .41917 m
.66032 .42087 L
s
.63904 .43749 m
.63937 .43926 L
s
.78159 .40402 m
.77986 .40435 L
s
.79446 .39554 m
.79455 .39654 L
s
.78331 .40367 m
.78159 .40402 L
s
.70466 .38225 m
.70463 .38382 L
s
.78501 .4033 m
.78331 .40367 L
s
.682 .4018 m
.6821 .40343 L
s
.76319 .39411 m
.7665 .40411 L
s
.79455 .39654 m
.79464 .39755 L
s
.66032 .42087 m
.66055 .42257 L
s
.7867 .40291 m
.78501 .4033 L
s
.61629 .45888 m
.63132 .45301 L
s
.63937 .43926 m
.63972 .44103 L
s
.78838 .40249 m
.7867 .40291 L
s
.70463 .38382 m
.70461 .38538 L
s
.79464 .39755 m
.79474 .39857 L
s
.67372 .40628 m
.6894 .40205 L
s
.6821 .40343 m
.68222 .40506 L
s
.79004 .40206 m
.78838 .40249 L
s
.66055 .42257 m
.66079 .42426 L
s
.79169 .4016 m
.79004 .40206 L
s
.79474 .39857 m
.79484 .3996 L
s
.68248 .4053 m
.6825 .40531 L
s
.70461 .38538 m
.70462 .38694 L
s
.68245 .40528 m
.68248 .4053 L
s
.63972 .44103 m
.64008 .44279 L
s
.68243 .40526 m
.68245 .40528 L
s
.68241 .40525 m
.68243 .40526 L
s
.68239 .40523 m
.68241 .40525 L
s
.68237 .40521 m
.68239 .40523 L
s
.68235 .4052 m
.68237 .40521 L
s
.68233 .40518 m
.68235 .4052 L
s
.68231 .40516 m
.68233 .40518 L
s
.68229 .40515 m
.68231 .40516 L
s
.68228 .40513 m
.68229 .40515 L
s
.68226 .40511 m
.68228 .40513 L
s
.68224 .40509 m
.68226 .40511 L
s
.79333 .40113 m
.79169 .4016 L
s
.68223 .40507 m
.68224 .40509 L
s
.68222 .40506 m
.68223 .40507 L
s
.68222 .40506 m
.68235 .40668 L
s
.6822 .40504 m
.68222 .40506 L
s
.68219 .40502 m
.6822 .40504 L
s
.68218 .405 m
.68219 .40502 L
s
.68217 .40498 m
.68218 .405 L
s
.68215 .40496 m
.68217 .40498 L
s
.68215 .40494 m
.68215 .40496 L
s
.68214 .40492 m
.68215 .40494 L
s
.68213 .4049 m
.68214 .40492 L
s
.68212 .40488 m
.68213 .4049 L
s
.68211 .40486 m
.68212 .40488 L
s
.68211 .40484 m
.68211 .40486 L
s
.6821 .40482 m
.68211 .40484 L
s
.79484 .3996 m
.79495 .40063 L
s
.68209 .40479 m
.6821 .40482 L
s
.68209 .40477 m
.68209 .40479 L
s
.68209 .40475 m
.68209 .40477 L
s
.79495 .40063 m
.79333 .40113 L
s
.66079 .42426 m
.66106 .42595 L
s
.70462 .38694 m
.70464 .3885 L
s
.79495 .40063 m
.79506 .40167 L
s
.79655 .40011 m
.79495 .40063 L
s
.64008 .44279 m
.64048 .44455 L
s
.68235 .40668 m
.6825 .4083 L
s
.79815 .39957 m
.79655 .40011 L
s
.72797 .36847 m
.72787 .36996 L
s
.79506 .40167 m
.79517 .40271 L
s
.70464 .3885 m
.70467 .39005 L
s
.66106 .42595 m
.66134 .42764 L
s
.69025 .4032 m
.70682 .40012 L
s
.79973 .39901 m
.79815 .39957 L
s
.6825 .4083 m
.68267 .40991 L
s
.64048 .44455 m
.64089 .4463 L
s
.79517 .40271 m
.7953 .40377 L
s
.73369 .36475 m
.74915 .36088 L
s
.72787 .36996 m
.72778 .37144 L
s
.70467 .39005 m
.70472 .3916 L
s
.80129 .39842 m
.79973 .39901 L
s
.63132 .45301 m
.64641 .44713 L
s
.66134 .42764 m
.66165 .42932 L
s
.7953 .40377 m
.79542 .40483 L
s
.6894 .40205 m
.70337 .39538 L
s
.68267 .40991 m
.68286 .41152 L
s
.80284 .39782 m
.80129 .39842 L
s
.72778 .37144 m
.72771 .37293 L
s
.70472 .3916 m
.70479 .39315 L
s
.79542 .40483 m
.79555 .4059 L
s
.80438 .39719 m
.80284 .39782 L
s
.66165 .42932 m
.66197 .43099 L
s
.72771 .37293 m
.72766 .37441 L
s
.79555 .4059 m
.79569 .40697 L
s
.68286 .41152 m
.68307 .41313 L
s
.80591 .39654 m
.80438 .39719 L
s
.70479 .39315 m
.70488 .39469 L
s
.78438 .37086 m
.78442 .37188 L
s
.70682 .40012 m
.72342 .39703 L
s
.70602 .39991 m
.70605 .40008 L
s
.79569 .40697 m
.79583 .40806 L
s
.81732 .38805 m
.82652 .39617 L
s
.70599 .39974 m
.70602 .39991 L
s
.72766 .37441 m
.72762 .37588 L
s
.70595 .39958 m
.70599 .39974 L
s
.80742 .39588 m
.80591 .39654 L
s
.66197 .43099 m
.66231 .43266 L
s
.68307 .41313 m
.6833 .41473 L
s
.70591 .39942 m
.70595 .39958 L
s
.79583 .40806 m
.79597 .40915 L
s
.70488 .39469 m
.70498 .39622 L
s
.78442 .37188 m
.78447 .37291 L
s
.70587 .39926 m
.70591 .39942 L
s
.70581 .3991 m
.70587 .39926 L
s
.78878 .35731 m .79455 .34866 L .80361 .35582 L .775 .495 .512 r
F
.78194 .3537 m .79455 .34866 L .78878 .35731 L F
.78194 .3537 m .78432 .34327 L .79455 .34866 L F
.039 .916 .04 r
.80891 .39519 m
.80742 .39588 L
s
.70575 .39894 m
.70581 .3991 L
s
.72762 .37588 m
.7276 .37735 L
s
.79597 .40915 m
.79612 .41024 L
s
.70569 .39879 m
.70575 .39894 L
s
.77476 .35152 m .78432 .34327 L .78194 .3537 L .775 .495 .512 r
F
.77476 .35152 m .77359 .34 L .78432 .34327 L F
0 g
.5 Mabswid
.78432 .34327 m
.79455 .34866 L
s
.039 .916 .04 r
1 Mabswid
.70562 .39864 m
.70569 .39879 L
s
.78447 .37291 m
.78452 .37395 L
s
.66231 .43266 m
.66267 .43433 L
s
.6833 .41473 m
.68354 .41633 L
s
.70555 .39848 m
.70562 .39864 L
s
.70498 .39622 m
.7051 .39775 L
s
.79371 .41401 m
.79983 .42191 L
s
.8104 .39447 m
.80891 .39519 L
s
.70547 .39833 m
.70555 .39848 L
s
.79612 .41024 m
.79627 .41135 L
s
.7276 .37735 m
.72759 .37882 L
s
.70538 .39819 m
.70547 .39833 L
s
.64641 .44713 m
.66154 .44123 L
s
.70529 .39804 m
.70538 .39819 L
s
.7052 .3979 m
.70529 .39804 L
s
.78452 .37395 m
.78458 .37499 L
s
.79627 .41135 m
.79643 .41246 L
s
.7051 .39775 m
.7052 .3979 L
s
.79484 .3621 m .80361 .35582 L .8109 .36427 L .775 .495 .512 r
F
.78878 .35731 m .80361 .35582 L .79484 .3621 L F
0 g
.5 Mabswid
.79455 .34866 m
.80361 .35582 L
s
.039 .916 .04 r
1 Mabswid
.81187 .39374 m
.8104 .39447 L
s
.7051 .39775 m
.70523 .39928 L
s
.70499 .39761 m
.7051 .39775 L
s
.68354 .41633 m
.6838 .41792 L
s
.66267 .43433 m
.66305 .43599 L
s
.72342 .39703 m
.74007 .39393 L
s
.70488 .39747 m
.70499 .39761 L
s
.72759 .37882 m
.7276 .38028 L
s
.70476 .39733 m
.70488 .39747 L
s
.79643 .41246 m
.7966 .41358 L
s
.70464 .3972 m
.70476 .39733 L
s
.74915 .36088 m
.76467 .357 L
s
.76774 .35091 m .77359 .34 L .77476 .35152 L .775 .495 .512 r
F
.76774 .35091 m .76308 .33907 L .77359 .34 L F
0 g
.5 Mabswid
.77359 .34 m
.78432 .34327 L
s
.77359 .34 m
.77359 .34 L
s
.039 .916 .04 r
1 Mabswid
.78458 .37499 m
.78465 .37604 L
s
.70451 .39706 m
.70464 .3972 L
s
.81332 .39299 m
.81187 .39374 L
s
.70438 .39693 m
.70451 .39706 L
s
.70424 .3968 m
.70438 .39693 L
s
.7966 .41358 m
.79677 .41471 L
s
.70523 .39928 m
.70539 .4008 L
s
.7276 .38028 m
.72763 .38174 L
s
.7041 .39667 m
.70424 .3968 L
s
.6838 .41792 m
.68408 .41951 L
s
.70395 .39654 m
.7041 .39667 L
s
.66305 .43599 m
.66345 .43765 L
s
.7038 .39641 m
.70395 .39654 L
s
.78465 .37604 m
.78471 .3771 L
s
.81477 .39221 m
.81332 .39299 L
s
.79677 .41471 m
.79694 .41584 L
s
.70364 .39629 m
.7038 .39641 L
s
.70347 .39617 m
.70364 .39629 L
s
.73004 .39503 m
.73009 .39538 L
s
.7033 .39605 m
.70347 .39617 L
s
.70539 .4008 m
.70556 .40232 L
s
.72763 .38174 m
.72767 .38319 L
s
.70312 .39593 m
.7033 .39605 L
s
.75986 .38401 m
.76319 .39411 L
s
.79694 .41584 m
.79712 .41698 L
s
.70294 .39581 m
.70312 .39593 L
s
.72998 .39467 m
.73004 .39503 L
s
.78471 .3771 m
.78479 .37817 L
s
.68408 .41951 m
.68437 .4211 L
s
.8162 .39141 m
.81477 .39221 L
s
.75101 .36255 m
.75093 .36395 L
s
.7299 .39433 m
.72998 .39467 L
s
.70337 .39538 m
.71742 .38868 L
s
.7997 .36775 m .8109 .36427 L .81592 .37346 L .775 .495 .512 r
F
.79484 .3621 m .8109 .36427 L .7997 .36775 L F
0 g
.5 Mabswid
.80361 .35582 m
.8109 .36427 L
s
.039 .916 .04 r
1 Mabswid
.72767 .38319 m
.72773 .38464 L
s
.72982 .39398 m
.7299 .39433 L
s
.70556 .40232 m
.70574 .40384 L
s
.74007 .39393 m
.75674 .39083 L
s
.78479 .37817 m
.78487 .37925 L
s
.81761 .39059 m
.8162 .39141 L
s
.75093 .36395 m
.75085 .36533 L
s
.68437 .4211 m
.68469 .42268 L
s
.72972 .39364 m
.72982 .39398 L
s
.66154 .44123 m
.67672 .43531 L
s
.72961 .3933 m
.72972 .39364 L
s
.72773 .38464 m
.7278 .38609 L
s
.78487 .37925 m
.78495 .38033 L
s
.70574 .40384 m
.70595 .40535 L
s
.76134 .35192 m .76308 .33907 L .76774 .35091 L .775 .495 .512 r
F
.76134 .35192 m .75349 .34056 L .76308 .33907 L F
0 g
.5 Mabswid
.76308 .33907 m
.77359 .34 L
s
.039 .916 .04 r
1 Mabswid
.75085 .36533 m
.7508 .36672 L
s
.72949 .39296 m
.72961 .3933 L
s
.68469 .42268 m
.68502 .42425 L
s
.72936 .39263 m
.72949 .39296 L
s
.78495 .38033 m
.78504 .38142 L
s
.7278 .38609 m
.72789 .38753 L
s
.7508 .36672 m
.75075 .3681 L
s
.72921 .3923 m
.72936 .39263 L
s
.70595 .40535 m
.70617 .40685 L
s
.76556 .39125 m
.76404 .39142 L
s
.76707 .39106 m
.76556 .39125 L
s
.72906 .39198 m
.72921 .3923 L
s
.76856 .39086 m
.76707 .39106 L
s
.78504 .38142 m
.78514 .38252 L
s
.77005 .39063 m
.76856 .39086 L
s
.68502 .42425 m
.68537 .42583 L
s
.72789 .38753 m
.72799 .38897 L
s
.72889 .39166 m
.72906 .39198 L
s
.77152 .39039 m
.77005 .39063 L
s
.75075 .3681 m
.75073 .36947 L
s
.77297 .39013 m
.77152 .39039 L
s
.75674 .39083 m
.77346 .38771 L
s
.72871 .39134 m
.72889 .39166 L
s
.70617 .40685 m
.70641 .40835 L
s
.77442 .38986 m
.77297 .39013 L
s
.78514 .38252 m
.78523 .38363 L
s
.75414 .39013 m
.75421 .39068 L
s
.76467 .357 m
.7772 .35786 L
s
.72853 .39102 m
.72871 .39134 L
s
.77586 .38956 m
.77442 .38986 L
s
.75073 .36947 m
.75071 .37084 L
s
.72799 .38897 m
.72811 .39041 L
s
.78297 .36601 m .78878 .35731 L .79484 .3621 L .775 .495 .512 r
F
.77954 .3642 m .78878 .35731 L .78297 .36601 L F
.039 .916 .04 r
.78194 .36546 m
.78361 .36815 L
s
.77954 .3642 m .78194 .3537 L .78878 .35731 L .775 .495 .512 r
F
.039 .916 .04 r
.7772 .35786 m
.77997 .3623 L
s
.77728 .38925 m
.77586 .38956 L
s
.68537 .42583 m
.68574 .42739 L
s
.72832 .39071 m
.72853 .39102 L
s
.75405 .38959 m
.75414 .39013 L
s
.77594 .36311 m .78194 .3537 L .77954 .3642 L .775 .495 .512 r
F
.77594 .36311 m .77476 .35152 L .78194 .3537 L F
.039 .916 .04 r
.78523 .38363 m
.78534 .38475 L
s
.77869 .38892 m
.77728 .38925 L
s
.70641 .40835 m
.70666 .40985 L
s
.72811 .39041 m
.72832 .39071 L
s
.80304 .37389 m .81592 .37346 L .81832 .38277 L .775 .495 .512 r
F
.7997 .36775 m .81592 .37346 L .80304 .37389 L F
0 g
.5 Mabswid
.8109 .36427 m
.81592 .37346 L
s
.039 .916 .04 r
1 Mabswid
.78009 .38857 m
.77869 .38892 L
s
.75071 .37084 m
.75071 .37221 L
s
.75394 .38905 m
.75405 .38959 L
s
.72811 .39041 m
.72825 .39184 L
s
.72789 .3901 m
.72811 .39041 L
s
.78601 .36841 m .79484 .3621 L .7997 .36775 L .775 .495 .512 r
F
.78297 .36601 m .79484 .3621 L .78601 .36841 L F
.039 .916 .04 r
.78147 .38821 m
.78009 .38857 L
s
.78534 .38475 m
.78545 .38587 L
s
.72765 .3898 m
.72789 .3901 L
s
.68574 .42739 m
.68613 .42896 L
s
.67672 .43531 m
.69196 .42936 L
s
.78285 .38783 m
.78147 .38821 L
s
.75382 .38852 m
.75394 .38905 L
s
.70666 .40985 m
.70693 .41135 L
s
.77242 .36281 m .77476 .35152 L .77594 .36311 L .775 .495 .512 r
F
.77242 .36281 m .76774 .35091 L .77476 .35152 L F
0 g
.5 Mabswid
.77359 .34 m
.77476 .35152 L
s
.039 .916 .04 r
1 Mabswid
.72741 .38951 m
.72765 .3898 L
s
.75071 .37221 m
.75073 .37358 L
s
.72825 .39184 m
.7284 .39326 L
s
.78421 .38743 m
.78285 .38783 L
s
.78545 .38587 m
.78557 .38701 L
s
.72715 .38921 m
.72741 .38951 L
s
.75367 .38799 m
.75382 .38852 L
s
.78557 .38701 m
.78421 .38743 L
s
.756 .35449 m .75349 .34056 L .76134 .35192 L .775 .495 .512 r
F
.756 .35449 m .74547 .34438 L .75349 .34056 L F
0 g
.5 Mabswid
.75349 .34056 m
.76308 .33907 L
s
.039 .916 .04 r
1 Mabswid
.72688 .38893 m
.72715 .38921 L
s
.77346 .38771 m
.75986 .38401 L
s
.75073 .37358 m
.75076 .37494 L
s
.70693 .41135 m
.70722 .41284 L
s
.7266 .38864 m
.72688 .38893 L
s
.78557 .38701 m
.78569 .38815 L
s
.78691 .38657 m
.78557 .38701 L
s
.75351 .38747 m
.75367 .38799 L
s
.7284 .39326 m
.72857 .39469 L
s
.7263 .38836 m
.7266 .38864 L
s
.78845 .37125 m .7997 .36775 L .80304 .37389 L .775 .495 .512 r
F
.78601 .36841 m .7997 .36775 L .78845 .37125 L F
.039 .916 .04 r
.78823 .38612 m
.78691 .38657 L
s
.71742 .38868 m
.73154 .38194 L
s
.75076 .37494 m
.75081 .37629 L
s
.726 .38808 m
.7263 .38836 L
s
.75333 .38695 m
.75351 .38747 L
s
.78569 .38815 m
.78581 .3893 L
s
.78955 .38565 m
.78823 .38612 L
s
.72568 .38781 m
.726 .38808 L
s
.70722 .41284 m
.70753 .41432 L
s
.72857 .39469 m
.72875 .3961 L
s
.78754 .40605 m
.79371 .41401 L
s
.76922 .36332 m .76774 .35091 L .77242 .36281 L .775 .495 .512 r
F
.76922 .36332 m .76134 .35192 L .76774 .35091 L F
.039 .916 .04 r
.75313 .38644 m
.75333 .38695 L
s
.72535 .38753 m
.72568 .38781 L
s
.79086 .38516 m
.78955 .38565 L
s
.77833 .38521 m
.77842 .38596 L
s
.75081 .37629 m
.75087 .37765 L
s
.78581 .3893 m
.78594 .39045 L
s
.72501 .38727 m
.72535 .38753 L
s
.75292 .38594 m
.75313 .38644 L
s
.72466 .387 m
.72501 .38727 L
s
.79215 .38465 m
.79086 .38516 L
s
.72875 .3961 m
.72895 .39752 L
s
.70753 .41432 m
.70785 .4158 L
s
.78594 .39045 m
.78608 .39162 L
s
.7243 .38674 m
.72466 .387 L
s
.77821 .38448 m
.77833 .38521 L
s
.75087 .37765 m
.75094 .379 L
s
.75269 .38544 m
.75292 .38594 L
s
.79343 .38412 m
.79215 .38465 L
s
.72393 .38649 m
.7243 .38674 L
s
.72354 .38623 m
.72393 .38649 L
s
.78608 .39162 m
.78622 .39279 L
s
.72895 .39752 m
.72917 .39893 L
s
.75244 .38494 m
.75269 .38544 L
s
.7947 .38358 m
.79343 .38412 L
s
.69196 .42936 m
.70724 .4234 L
s
.70785 .4158 m
.70819 .41728 L
s
.77808 .38375 m
.77821 .38448 L
s
.75094 .379 m
.75103 .38034 L
s
.80304 .37389 m .81832 .38277 L .80463 .38011 L .775 .495 .512 r
F
.79011 .37433 m .80304 .37389 L .80463 .38011 L F
.78845 .37125 m .80304 .37389 L .79011 .37433 L F
.039 .916 .04 r
.75217 .38445 m
.75244 .38494 L
s
.79596 .38302 m
.7947 .38358 L
s
.78622 .39279 m
.78637 .39397 L
s
.80463 .38011 m .81832 .38277 L .81794 .39158 L .775 .495 .512 r
F
0 g
.5 Mabswid
.81592 .37346 m
.81832 .38277 L
s
.81832 .38277 m
.81832 .38277 L
s
.039 .916 .04 r
1 Mabswid
.72917 .39893 m
.7294 .40034 L
s
.77791 .38303 m
.77808 .38375 L
s
.75103 .38034 m
.75114 .38168 L
s
.75188 .38397 m
.75217 .38445 L
s
.79721 .38244 m
.79596 .38302 L
s
.70819 .41728 m
.70855 .41875 L
s
.78637 .39397 m
.78652 .39516 L
s
.76655 .36461 m .76134 .35192 L .76922 .36332 L .775 .495 .512 r
F
.76655 .36461 m .756 .35449 L .76134 .35192 L F
.039 .916 .04 r
.75158 .38349 m
.75188 .38397 L
s
.77397 .36303 m
.77397 .36294 L
s
.79844 .38184 m
.79721 .38244 L
s
.77773 .38232 m
.77791 .38303 L
s
.75114 .38168 m
.75126 .38302 L
s
.7294 .40034 m
.72965 .40174 L
s
.78652 .39516 m
.78667 .39636 L
s
.75126 .38302 m
.75158 .38349 L
s
.70855 .41875 m
.70892 .42022 L
s
.79967 .38123 m
.79844 .38184 L
s
.75208 .35844 m .74547 .34438 L .756 .35449 L .775 .495 .512 r
F
.75208 .35844 m .73956 .35029 L .74547 .34438 L F
0 g
.5 Mabswid
.74547 .34438 m
.75349 .34056 L
s
.039 .916 .04 r
1 Mabswid
.77397 .3643 m
.77397 .36303 L
s
.77752 .38162 m
.77773 .38232 L
s
.78667 .39636 m
.78684 .39757 L
s
.75126 .38302 m
.75139 .38435 L
s
.75092 .38255 m
.75126 .38302 L
s
.77713 .37476 m .78297 .36601 L .78601 .36841 L .775 .495 .512 r
F
.77713 .37476 m .77954 .3642 L .78297 .36601 L F
.77713 .37476 m .77594 .36311 L .77954 .3642 L F
.039 .916 .04 r
.72965 .40174 m
.72991 .40314 L
s
.80088 .38059 m
.79967 .38123 L
s
.77713 .37476 m .78601 .36841 L .78845 .37125 L .775 .495 .512 r
F
.039 .916 .04 r
.75056 .38209 m
.75092 .38255 L
s
.78684 .39757 m
.787 .39878 L
s
.77728 .38092 m
.77752 .38162 L
s
.77713 .37476 m .77242 .36281 L .77594 .36311 L .775 .495 .512 r
F
0 g
.5 Mabswid
.77476 .35152 m
.77594 .36311 L
s
.039 .916 .04 r
1 Mabswid
.75139 .38435 m
.75154 .38568 L
s
.75019 .38163 m
.75056 .38209 L
s
.72991 .40314 m
.73019 .40453 L
s
.787 .39878 m
.78718 .4 L
s
.79011 .37433 m .80463 .38011 L .7909 .37744 L .775 .495 .512 r
F
.80463 .38011 m .81794 .39158 L .80435 .38598 L F
.039 .916 .04 r
.80806 .37987 m
.80937 .38103 L
s
.7909 .37744 m .80463 .38011 L .80435 .38598 L .775 .495 .512 r
F
0 g
.5 Mabswid
.80463 .38011 m
.81832 .38277 L
s
.039 .916 .04 r
1 Mabswid
.77702 .38023 m
.77728 .38092 L
s
.77713 .37476 m .78845 .37125 L .79011 .37433 L .775 .495 .512 r
F
.039 .916 .04 r
.70724 .4234 m
.72257 .41742 L
s
.74979 .38118 m
.75019 .38163 L
s
.80252 .3797 m
.80327 .37927 L
s
.75154 .38568 m
.75171 .38701 L
s
.78718 .4 m
.78735 .40123 L
s
.77713 .37476 m .76922 .36332 L .77242 .36281 L .775 .495 .512 r
F
.039 .916 .04 r
.73154 .38194 m
.74573 .37516 L
s
.73019 .40453 m
.73048 .40592 L
s
.74938 .38074 m
.74979 .38118 L
s
.77674 .37954 m
.77702 .38023 L
s
.80327 .37927 m
.80445 .37859 L
s
.78735 .40123 m
.78754 .40247 L
s
.7646 .3666 m .756 .35449 L .76655 .36461 L .775 .495 .512 r
F
.7646 .3666 m .75208 .35844 L .756 .35449 L F
.039 .916 .04 r
.75171 .38701 m
.75189 .38833 L
s
.74896 .3803 m
.74938 .38074 L
s
.77643 .37886 m
.77674 .37954 L
s
.77713 .37476 m .79011 .37433 L .7909 .37744 L .775 .495 .512 r
F
.039 .916 .04 r
.73048 .40592 m
.7308 .40731 L
s
.74851 .37986 m
.74896 .3803 L
s
.78754 .40247 m
.78773 .40372 L
s
.77713 .37476 m .76655 .36461 L .76922 .36332 L .775 .495 .512 r
F
.039 .916 .04 r
.75189 .38833 m
.75208 .38965 L
s
.74805 .37943 m
.74851 .37986 L
s
.7761 .3782 m
.77643 .37886 L
s
.78773 .40372 m
.78792 .40497 L
s
.7308 .40731 m
.73112 .40869 L
s
.80435 .38598 m .81794 .39158 L .81477 .39928 L .775 .495 .512 r
F
0 g
.5 Mabswid
.81794 .39158 m
.81832 .38277 L
s
.039 .916 .04 r
1 Mabswid
.74756 .37901 m
.74805 .37943 L
s
.75208 .38965 m
.75229 .39096 L
s
.77575 .37753 m
.7761 .3782 L
s
.74706 .37859 m
.74756 .37901 L
s
.7909 .37744 m .80435 .38598 L .79075 .38037 L .775 .495 .512 r
F
.039 .916 .04 r
.79873 .37163 m
.80806 .37987 L
s
.77713 .37476 m .7909 .37744 L .79075 .38037 L .775 .495 .512 r
F
0 g
.5 Mabswid
.7909 .37744 m
.80463 .38011 L
s
.039 .916 .04 r
1 Mabswid
.73112 .40869 m
.73147 .41007 L
s
.74655 .37818 m
.74706 .37859 L
s
.77537 .37688 m
.77575 .37753 L
s
.75229 .39096 m
.75251 .39227 L
s
.77713 .37476 m .7646 .3666 L .76655 .36461 L .775 .495 .512 r
F
.039 .916 .04 r
.7743 .37292 m
.77431 .37311 L
s
.80435 .38598 m .81477 .39928 L .80221 .3911 L .775 .495 .512 r
F
.79075 .38037 m .80435 .38598 L .80221 .3911 L F
.039 .916 .04 r
.74601 .37777 m
.74655 .37818 L
s
.72257 .41742 m
.73796 .41142 L
s
.77431 .37311 m
.77442 .37435 L
s
.74985 .36352 m .73956 .35029 L .75208 .35844 L .775 .495 .512 r
F
.74985 .36352 m .73619 .35789 L .73956 .35029 L F
0 g
.5 Mabswid
.73956 .35029 m
.74547 .34438 L
s
.039 .916 .04 r
1 Mabswid
.77496 .37623 m
.77537 .37688 L
s
.73147 .41007 m
.73183 .41144 L
s
.74546 .37737 m
.74601 .37777 L
s
.75251 .39227 m
.75275 .39358 L
s
.74489 .37698 m
.74546 .37737 L
s
.77442 .37435 m
.77454 .37559 L
s
.77454 .37559 m
.77496 .37623 L
s
.7635 .36914 m .75208 .35844 L .7646 .3666 L .775 .495 .512 r
F
.7635 .36914 m .74985 .36352 L .75208 .35844 L F
.79075 .38037 m .80221 .3911 L .78967 .38293 L F
.77713 .37476 m .79075 .38037 L .78967 .38293 L F
.039 .916 .04 r
.7443 .37658 m
.74489 .37698 L
s
.75275 .39358 m
.75301 .39488 L
s
.77454 .37559 m
.77467 .37683 L
s
.77408 .37496 m
.77454 .37559 L
s
.77713 .37476 m .7635 .36914 L .7646 .3666 L .775 .495 .512 r
F
.039 .916 .04 r
.75301 .39488 m
.75328 .39618 L
s
.77713 .37476 m .76333 .37208 L .7635 .36914 L .775 .495 .512 r
F
.77713 .37476 m .7641 .3752 L .76333 .37208 L F
.039 .916 .04 r
.77402 .37487 m
.77408 .37496 L
s
.77713 .37476 m .76576 .37829 L .7641 .3752 L .775 .495 .512 r
F
.77713 .37476 m .7682 .38115 L .76576 .37829 L F
0 0 0 r
.28918 .5305 m
.76582 .37837 L
s
.77713 .37476 m .77125 .38357 L .7682 .38115 L .775 .495 .512 r
F
.77713 .37476 m .77471 .38539 L .77125 .38357 L F
.77713 .37476 m .77833 .38648 L .77471 .38539 L F
.77713 .37476 m .78186 .38678 L .77833 .38648 L F
.77713 .37476 m .78507 .38625 L .78186 .38678 L F
0 0 0 r
.78504 .38625 m
.85759 .49158 L
s
.77713 .37476 m .78773 .38493 L .78507 .38625 L .775 .495 .512 r
F
.77713 .37476 m .78967 .38293 L .78773 .38493 L F
0 g
.5 Mabswid
.77594 .36311 m
.77713 .37476 L
s
.77713 .37476 m
.7909 .37744 L
s
.039 .916 .04 r
1 Mabswid
.75328 .39618 m
.75356 .39748 L
s
.77311 .37371 m
.77337 .37403 L
s
.78967 .38293 m .79836 .39513 L .78773 .38493 L .775 .495 .512 r
F
.78967 .38293 m .80221 .3911 L .79836 .39513 L F
.039 .916 .04 r
.77258 .3731 m
.77311 .37371 L
s
.76333 .37208 m .74985 .36352 L .7635 .36914 L .775 .495 .512 r
F
.039 .916 .04 r
.75356 .39748 m
.75386 .39877 L
s
.80221 .3911 m .80901 .40534 L .79836 .39513 L .775 .495 .512 r
F
.80221 .3911 m .81477 .39928 L .80901 .40534 L F
0 g
.5 Mabswid
.81477 .39928 m
.81794 .39158 L
s
.039 .916 .04 r
1 Mabswid
.73796 .41142 m
.75339 .4054 L
s
.77204 .3725 m
.77258 .3731 L
s
.75386 .39877 m
.75417 .40006 L
s
.77146 .3719 m
.77204 .3725 L
s
.74949 .36939 m .73619 .35789 L .74985 .36352 L .775 .495 .512 r
F
.76333 .37208 m .74949 .36939 L .74985 .36352 L F
.78773 .38493 m .79304 .39777 L .78507 .38625 L F
.78773 .38493 m .79836 .39513 L .79304 .39777 L F
.039 .916 .04 r
.75417 .40006 m
.7545 .40134 L
s
.77087 .37131 m
.77146 .3719 L
s
.7641 .3752 m .74949 .36939 L .76333 .37208 L .775 .495 .512 r
F
.039 .916 .04 r
.74573 .37516 m
.75403 .3712 L
s
0 g
.5 Mabswid
.76333 .37208 m
.77713 .37476 L
s
.039 .916 .04 r
1 Mabswid
.77025 .37073 m
.77087 .37131 L
s
.74949 .36939 m .73561 .36669 L .73619 .35789 L .775 .495 .512 r
F
0 g
.5 Mabswid
.73619 .35789 m
.73956 .35029 L
s
.039 .916 .04 r
1 Mabswid
.7545 .40134 m
.75485 .40262 L
s
.7696 .37015 m
.77025 .37073 L
s
.78507 .38625 m .78661 .39885 L .78186 .38678 L .775 .495 .512 r
F
.78507 .38625 m .79304 .39777 L .78661 .39885 L F
.7641 .3752 m .75101 .37564 L .74949 .36939 L F
.039 .916 .04 r
.76001 .36834 m
.79873 .37163 L
s
.75541 .37054 m
.76001 .36834 L
s
.76576 .37829 m .75101 .37564 L .7641 .3752 L .775 .495 .512 r
F
.039 .916 .04 r
.76893 .36959 m
.7696 .37015 L
s
.77607 .3858 m
.77623 .38659 L
s
.79836 .39513 m .80104 .40934 L .79304 .39777 L .775 .495 .512 r
F
.79836 .39513 m .80901 .40534 L .80104 .40934 L F
0 g
.5 Mabswid
.80901 .40534 m
.81477 .39928 L
s
.039 .916 .04 r
1 Mabswid
.76824 .36903 m
.76893 .36959 L
s
.75339 .4054 m
.76887 .39936 L
s
.78186 .38678 m .77953 .39828 L .77833 .38648 L .775 .495 .512 r
F
.78186 .38678 m .78661 .39885 L .77953 .39828 L F
.039 .916 .04 r
.78165 .39845 m
.78754 .40605 L
s
.77623 .38659 m
.77648 .38779 L
s
.76752 .36847 m
.76824 .36903 L
s
.76576 .37829 m .75432 .38185 L .75101 .37564 L .775 .495 .512 r
F
.7682 .38115 m .75432 .38185 L .76576 .37829 L F
.75101 .37564 m .73561 .36669 L .74949 .36939 L F
0 g
.5 Mabswid
.74949 .36939 m
.76333 .37208 L
s
.039 .916 .04 r
1 Mabswid
.76677 .36793 m
.76752 .36847 L
s
.77833 .38648 m .77227 .39609 L .77471 .38539 L .775 .495 .512 r
F
.77833 .38648 m .77953 .39828 L .77227 .39609 L F
0 g
.5 Mabswid
.77713 .37476 m
.77833 .38648 L
s
.7682 .38115 m .75921 .38758 L .75432 .38185 L .775 .495 .512 r
F
.77125 .38357 m .75921 .38758 L .7682 .38115 L F
.039 .916 .04 r
1 Mabswid
.76601 .36739 m
.76677 .36793 L
s
.77471 .38539 m .76533 .39244 L .77125 .38357 L .775 .495 .512 r
F
.77471 .38539 m .77227 .39609 L .76533 .39244 L F
.77125 .38357 m .76533 .39244 L .75921 .38758 L F
.039 .916 .04 r
.76522 .36686 m
.76601 .36739 L
s
.76887 .39936 m
.77936 .39823 L
s
.79304 .39777 m .79139 .41098 L .78661 .39885 L .775 .495 .512 r
F
.79304 .39777 m .80104 .40934 L .79139 .41098 L F
0 g
.5 Mabswid
.80104 .40934 m
.80901 .40534 L
s
.75101 .37564 m .73787 .37608 L .73561 .36669 L .775 .495 .512 r
F
0 g
.73561 .36669 m
.74949 .36939 L
s
.73561 .36669 m
.73619 .35789 L
s
.73561 .36669 m
.73561 .36669 L
s
.75432 .38185 m .73787 .37608 L .75101 .37564 L .775 .495 .512 r
F
.78661 .39885 m .78074 .41014 L .77953 .39828 L F
.78661 .39885 m .79139 .41098 L .78074 .41014 L F
.75432 .38185 m .74283 .38542 L .73787 .37608 L F
0 g
.73561 .36669 m
.73787 .37608 L
s
.75921 .38758 m .74283 .38542 L .75432 .38185 L .775 .495 .512 r
F
0 g
.79139 .41098 m
.80104 .40934 L
s
.77953 .39828 m .76981 .40686 L .77227 .39609 L .775 .495 .512 r
F
.77953 .39828 m .78074 .41014 L .76981 .40686 L F
0 g
.77833 .38648 m
.77953 .39828 L
s
.77953 .39828 m
.78074 .41014 L
s
.75921 .38758 m .75017 .39405 L .74283 .38542 L .775 .495 .512 r
F
.76533 .39244 m .75017 .39405 L .75921 .38758 L F
0 g
.73787 .37608 m
.74283 .38542 L
s
.77227 .39609 m .75938 .40137 L .76533 .39244 L .775 .495 .512 r
F
.77227 .39609 m .76981 .40686 L .75938 .40137 L F
.76533 .39244 m .75938 .40137 L .75017 .39405 L F
0 g
.78074 .41014 m
.79139 .41098 L
s
.74283 .38542 m
.75017 .39405 L
s
.76981 .40686 m
.78074 .41014 L
s
.78074 .41014 m
.78074 .41014 L
s
.75017 .39405 m
.75938 .40137 L
s
.75938 .40137 m
.76981 .40686 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[41]:=",
  ImageSize->{972.875, 555.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000?<0002:b000`400?l00000o`00003ooooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocooo
ool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooo
oooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocooo
ool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooo
oooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocooo
ool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooo
oooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocooo
ool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooo
oooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocooo
ool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooo
oooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocooo
ool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooo
oooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooonNooooo`oo0000oooooon:ooooo`Ko000000?oooooo`000?oo
ool0S_ooool00?ooooooW?ooool2o`0000co`G^400?o0000ol5kQ?o1Nh@00ol0003ooooooh?ooooo
1?l00006olInP`Go0000S?ooool00?ooooooVoooool00ol0003o`G^4ol5kQ00<ol5kQ003o`000?o1
NhCo`G^400?o`G^40_l0003oooooogkooooo0ol0000;olInP`04o`000?o6OX?oaWj3olInP`Co0000
R?ooool00?ooooooV_ooool00ol0003o`G^4ol5kQ00=ol5kQ003o`000?o1NhCo`G^400Go`G^40_l0
003oooooog_ooooo00?o0000olInPoo6OX<03?o6OX<00ol0003oaWj3olInP`05olInP`;o0000Q_oo
ool00?ooooooVOooool00ol0003o`G^4ol5kQ00>ol5kQ003o`000?o1NhCo`G^400Oo`G^400?o0000
ooooooooool0oooooomgooooo`03o`000?o6OX?oaWj300goaWj300?o0000olInPoo6OX<01oo6OX<0
0ol0003oooooooooo`23ooooo`00oooooonHooooo`03o`000?o1NhCo`G^400oo`G^400?o0000ol5k
Q?o1Nh@02?o1Nh@2o`000?ooooooM_ooool00ol0003oaWj3olInP`0?olInP`03o`000?o6OX?oaWj3
00OoaWj30_l00023ooooo`00oooooonGooooo`03o`000?o1NhCo`G^4013o`G^400?o0000ol5kQ?o1
Nh@02_o1Nh@2o`000?ooooooLoooool00ol0003oaWj3olInP`0@olInP`03o`000?o6OX?oaWj300Wo
aWj300?o0000ooooooooool0P?ooool00?ooooooUoooool00ol0003o`G^4ol5kQ00@ol5kQ003o`00
0?o1NhCo`G^400co`G^400?o0000ooooooooool0oooooom`ooooo`03o`000?o6OX?oaWj3013oaWj3
00?o0000olInPoo6OX<02_o6OX<00ol0003oooooooooo`1oooooo`00oooooonFooooo`03o`000?o1
NhCo`G^4017o`G^400?o0000ol5kQ?o1Nh@03Oo1Nh@00ol0003oooooooooo`3oooooofkooooo00?o
0000olInPoo6OX<04Oo6OX<00ol0003oaWj3olInP`0;olInP`03o`000?oooooooooo07kooooo003o
oooooiKooooo00?o0000ol5kQ?o1Nh@04Oo1Nh@00ol0003o`G^4ol5kQ00=ol5kQ003o`000?oooooo
oooo0?ooooooK_ooool00ol0003oaWj3olInP`0AolInP`03o`000?o6OX?oaWj300coaWj300?o0000
ooooooooool0OOooool00?ooooooUOooool00ol0003o`G^4ol5kQ00Col5kQ003o`000?o1NhCo`G^4
00go`G^400?o0000ooooooooool0oooooom/ooooo`03o`000?o6OX?oaWj301;oaWj300?o0000olIn
Poo6OX<03Oo6OX<00ol0003oooooooooo`1looooo`00oooooonEooooo`03o`000?o1NhCo`G^401?o
`G^400?o0000ol5kQ?o1Nh@03_o1Nh@00ol0003oooooooooo`3oooooof_ooooo00?o0000olInPoo6
OX<04_o6OX<00ol0003oaWj3olInP`0>olInP`03o`000?oooooooooo07_ooooo003ooooooiGooooo
00?o0000ol5kQ?o1Nh@04_o1Nh@00ol9jP[o0000ol5kQ00@ol5kQ003o`000?oooooooooo0?oooooo
J_ooool00ol0003oaWj3olInP`0BolInP`04o`000?o6OX?oaWj3o`WZ2PkoaWj300?o0000oooooooo
ool0N_ooool00?ooooooToooool00ol9jP[o0000ol5kQ00Eol5kQ003o`000?o1NhCo`G^4013o`G^4
00?o0000ooooooooool0oooooomYooooo`03o`000?o6OX?oaWj3017oaWj300?o2NX:o`000?o6OX<0
4Oo6OX<00ol0003oooooooooo`1iooooo`00oooooon?ooooo`Co2NX:00Coooooo`000?l0003o0000
3Oo1Nh@00ol9jP[o`G^4ol5kQ004ol5kQ003o`000?o1NhCo`G^4013o`G^400?o0000ooooooooool0
oooooomVooooo`?o2NX:00?o0000olInPoo6OX<04_o6OX<01Ol0003oaWj3olInPoo6OX?o2NX:00ko
aWj300?o0000ooooooooool0NOooool00?ooooooRoooool4o`WZ2P?ooooo00?o2NX:ooooool00000
0_o1Nh@4o`0000Go`G^41ol9jPX4ol5kQ003o`000?o1NhCo`G^4017o`G^400?o0000ooooooooool0
oooooomQooooo`Co2NX:0oooool5o`0000SoaWj31_l9jPX2olInP`03o`000?o6OX?oaWj3017oaWj3
00?o0000ooooooooool0N?ooool00?ooooooR?ooool3o`WZ2POooooo00?o2NX:ooooool000001_o1
Nh@6o`0000Go`G^43?l9jPX=ol5kQ003o`000?oooooooooo0?ooooooGOooool4o`WZ2P?ooooo00Go
2NX:ooooooooooooooooo`000004olInP`Oo000000?o2NX:olInPoo6OX<00_o6OX<=o`WZ2PcoaWj3
00?o0000ooooooooool0Moooool00?ooooooQOooool3o`WZ2P[ooooo00Co2NX:oooooooooooo0000
2?o1Nh@00ol9jP[o`G^4ol5kQ005o`000003ol5kQ?l9jP[o2NX:00;o`G^400?o0000ol5kQ?o1Nh@0
1?o1Nh@6o`WZ2POo`G^400?o0000ooooooooool0oooooomIooooo`Co2NX:1oooool01Ol9jP[ooooo
oooooooooooo000000SoaWj30ol9jPX6o`0000;o2NX:0_o6OX<00ol0003oaWj3olInP`05olInP`Go
2NX:1oo6OX<00ol0003oooooooooo`1gooooo`00oooooon2ooooo`?o2NX:3Oooool01?l9jP[ooooo
ooooool0000@ol5kQ0Co000000?o`G^4o`000?o1Nh@02oo1Nh@00ol9jP[o`G^4ol5kQ005ol5kQ003
o`000?oooooooooo0?ooooooE?ooool4o`WZ2P_ooooo00?o2NX:ooooooooool00_ooool00ol0003o
aWj3olInP`0>olInP`?o000000?o2NX:o`000?o6OX<02_o6OX<00ol9jP[oaWj3olInP`06olInP`03
o`000?oooooooooo07Kooooo003oooooogoooooo0ol9jPX4ooooo`;o2NX:2_ooool01?l9jP[ooooo
ooooool0000Col5kQ003o`WZ2_l0003o000000Co00002Oo1Nh@2o`WZ2PGo`G^400?o0000oooooooo
ool0oooooom@ooooo`Co2NX:0oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00;o
oooo00?o0000olInPoo6OX<04?o6OX<00ol9jP[o0000o`000004o`0000SoaWj300?o2NX:olInPoo6
OX<01Oo6OX<00ol0003oooooooooo`1fooooo`00oooooomlooooo`?o2NX:1oooool00ol9jP[ooooo
ooooo`09ooooo`04o`WZ2_ooooooooooo`0001Go`G^400?o0000ol5kQ?o1Nh@00_o1Nh@7o`0000Co
`G^400?o2NX:ol5kQ?o1Nh@00_o1Nh@00ol0003oooooooooo`3oooooodcooooo1?l9jPX7ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool00_ooool00ol0003oaWj3olInP`0BolInP`03
o`000?o6OX?oaWj300;oaWj31Ol00004olInP`03o`WZ2_o6OX?oaWj300CoaWj300?o0000oooooooo
ool0M_ooool00?ooooooN?ooool4o`WZ2P[ooooo00?o2NX:ooooooooool02Oooool01Ol9jP[ooooo
o`WZ2_l9jP[o000000go`G^400?o0000ol5kQ?o1Nh@01?o1Nh@00ol0003o`G^4ol5kQ009ol5kQ0Go
000000?o2NX:ol5kQ?o1Nh@00_o1Nh@00ol0003oooooooooo`3oooooodOooooo1?l9jPX;ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool00_ooool00ol0003oaWj3olInP`0<olInP`03
o`000?o6OX?oaWj300?oaWj300?o0000olInPoo6OX<01oo6OX<4o`0000;o2NX:1_o6OX<00ol0003o
ooooooooo`1eooooo`00oooooomdooooo`Co2NX:0oooool00ol9jP[oooooooooo`08ooooo`03o`WZ
2_oooooooooo00Wooooo0_l9jPX2ooooo`03o`000?o1NhCo`G^401;o`G^400?o0000ol5kQ?o1Nh@0
3_o1Nh@01_l9jP[o0000o`000?l0003o`G^4o`000?ooooooAOooool4o`WZ2P?ooooo00?o2NX:oooo
ooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00;o2NX:00?oooooo`00
0?o6OX<04_o6OX<00ol0003oaWj3olInP`0;olInP`;o000000Co2NX:o`000?l0003o00000_o6OX<0
0ol0003oooooooooo`1eooooo`00oooooom`ooooo`Co2NX:1oooool00ol9jP[oooooooooo`08oooo
o`03o`WZ2_oooooooooo00Oooooo0ol9jPX3ooooo`03o`000?o1NhCo`G^401;o`G^400?o0000ol5k
Q?o1Nh@04_o1Nh@3o`000?oooooo@?ooool4o`WZ2POooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`?o2NX:1?ooool00ol0003oaWj3olInP`0AolInP`03o`000?o6OX?oaWj3
013oaWj30ol0001gooooo`00oooooom/ooooo`Co2NX:2oooool00ol9jP[oooooooooo`08ooooo`03
o`WZ2_oooooooooo00Kooooo00Co2NX:oooooooooooo2NX:1?ooool00ol0003o`G^4ol5kQ00Aol5k
Q005o`000?o1NhCo`G^4ol5kQ?l000004Oo1Nh@00ol0003oooooooooo`3ooooooc_ooooo1?l9jPX;
ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool01oooool3o`WZ2PKooooo00?o0000
olInPoo6OX<04Oo6OX<00ol0003oaWj3olInP`0BolInP`03o`000?oooooooooo07Gooooo003ooooo
ofWooooo0ol9jPX3ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02?ooool00ol9
jP[oooooooooo`04ooooo`Co2NX:00?oooooo`WZ2_ooool00_ooool2o`0001?o`G^400Go0000ol5k
Q?o1NhCo`G^4o`00000Aol5kQ003o`000?oooooooooo0?oooooo=oooool4o`WZ2P?ooooo00?o2NX:
ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Gooooo1Ol9jPX5
ooooo`?o00004_o6OX<00ol0003oaWj3olInP`0BolInP`03o`000?oooooooooo07Gooooo003ooooo
ofGooooo1?l9jPX6ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`02ooooo`;o2NX:0oooool3o`WZ2P?o00000_ooool00ol0003o`G^4ol5kQ00@ol5k
Q003o`000?o1NhCo`G^401?o`G^400?o0000o`WZ2_ooool0oooooolcooooo`Co2NX:1oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool00oooool2o`WZ
2P?ooooo0_l9jPX2ooooo`?o00000oooool00ol0003oaWj3olInP`0?olInP`03o`000?o6OX?oaWj3
01;oaWj300?o0000ooooooooool0MOooool00?ooooooHOooool4o`WZ2P[ooooo00?o2NX:oooooooo
ool02?ooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00;o2NX:1Oooool3o`0000Ko
oooo00?o0000ol5kQ?o1Nh@03oo1Nh@00ol0003o`G^4ol5kQ00Col5kQ003o`000?oooooo2NX:0?oo
oooo;oooool4o`WZ2P_ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`04
o`WZ2_ooooooooooooooo`;o2NX:1_ooool3o`0000Oooooo00?o0000olInPoo6OX<03_o6OX<00ol0
003oaWj3olInP`0BolInP`03o`000?l9jP[ooooo07Gooooo003ooooooegooooo1?l9jPX3ooooo`03
o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`09ooooo`03
o`WZ2_oooooo2NX:00Cooooo0ol00002ooooo`03o`WZ2_oooooooooo00Gooooo00?o0000ol5kQ?o1
Nh@03_o1Nh@00ol0003o`G^4ol5kQ00Col5kQ003o`000?oooooooooo00;o2NX:oooooolYooooo`Co
2NX:0oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool02Oooool01?l9jP[oooooo`WZ2_l9jPX4ooooo`Co00000_l9jPX7ooooo`;o2NX:00?o0000olIn
Poo6OX<03Oo6OX<00ol0003oaWj3olInP`0BolInP`03o`000?oooooo2NX:07Gooooo003ooooooeWo
oooo1?l9jPX7ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool02?ooool00ol9jP[o
ooooooooo`09ooooo`;o2NX:0_ooool3o`0000Gooooo0_l9jPX2ooooo`Co2NX:00?oooooo`000?l0
00003_o1Nh@00ol0003o`G^4ol5kQ00Bol5kQ003o`000?oooooooooo00?ooooo00?o2NX:oooooooo
ool0oooooolRooooo`Co2NX:1oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wo
oooo00?o2NX:ooooooooool02Oooool2o`WZ2P?ooooo0ol00004ooooo`;o2NX:0oooool4o`WZ2P?o
oooo0_l0000=olInP`03o`000?o6OX?oaWj301;oaWj300Co0000oooooooooooo2NX:M?ooool00?oo
ooooEOooool4o`WZ2P_ooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`08ooooo`03
o`WZ2_oooooooooo00Oooooo0ol9jPX3o`0000Sooooo1?l9jPX7ooooo`03o`000?o1NhCo`G^400_o
`G^400?o0000ol5kQ?o1Nh@04_o1Nh@00ol0003oooooooooo`04ooooo`;o2NX:oooooolNooooo`Co
2NX:2oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooooooo
ool01oooool3o`WZ2P04ooooool0003o0000o`0000Oooooo1Ol9jPX8ooooo`03o`WZ2_l0003oaWj3
00_oaWj300?o0000olInPoo6OX<04Oo6OX<00ol0003oooooooooo`02ooooo`;o2NX:L_ooool00?oo
ooooD_ooool3o`WZ2PCooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`08ooooo`03
o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01?ooool3o`WZ2P?o00001Oooool7o`WZ2P_o
oooo00?o0000ol5kQ?o1Nh@02Oo1Nh@01?l9jP[o0000ol5kQ?l9jPXBol5kQ003o`000?oooooooooo
00Kooooo00?o2NX:ooooooooool0oooooolGooooo`Co2NX:0oooool00ol9jP[oooooooooo`09oooo
o`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`04oooo
o`?o2NX:00Coooooo`000?l0003o00001?ooool6o`WZ2P03ooooool9jP[ooooo00_ooooo00?o2NX:
o`000?o6OX<02_o6OX<00ol0003o2NX:olInP`0AolInP`03o`000?oooooooooo00Cooooo00?o2NX:
ooooooooool0Koooool00?ooooooC_ooool4o`WZ2PKooooo00?o2NX:ooooooooool02?ooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool00_ooool2o`WZ
2P?o000000?oooooo`WZ2_l9jPX01Ol9jPX6ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:o`00
0?o1Nh@02_o1Nh@00ol0003o`G^4ol5kQ00@ol5kQ0;o00002_ooool00ol9jP[oooooooooo`3ooooo
oa;ooooo1?l9jPX7ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPX01?oooooo0000o`000?l00007
o`WZ2POooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooo`00000:olInP`03o`000?o6OX?o
aWj3013oaWj300?o0000ooooooooool01_ooool00ol9jP[oooooooooo`1^ooooo`00oooooom:oooo
o`Co2NX:2_ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooo
ooooool02?ooool01?l9jP[oooooo`WZ2_l9jPX3o`0000Co2NX:00?oooooo`WZ2_ooool02_ooool0
0ol9jP[oooooooooo`09ooooo`;o2NX:0_l00009ol5kQ003o`000?o1NhCo`G^400oo`G^400?o0000
ooooooooool02Oooool00ol9jP[oooooo`WZ2P0Jooooo`[o0000j_ooool4o`WZ2P_ooooo00?o2NX:
ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:
ooooooooool00_l9jPX3o`0000?o2NX:00?oooooo`WZ2_ooool02oooool00ol9jP[oooooooooo`0:
ooooo`03o`WZ2_oooooooooo00;o00002?o6OX<00ol0003oaWj3olInP`0?olInP`03o`000?oooooo
oooo00Sooooo00?o2NX:ooooooooool0KOooool00?ooooooA_ooool4o`WZ2P?ooooo00?o2NX:oooo
ooooool02?ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooo
ooooool01_ooool3o`WZ2P?o00000_l9jPX6ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooo
ooooool02_ooool3o`WZ2P;o00001oo1Nh@00ol0003o`G^4ol5kQ00>ol5kQ003o`000?l9jP[ooooo
00Wooooo00Co2NX:oooooooooooooooo0_l9jPXCooooo`Go00002_ooool8o`000=gooooo1Ol9jPX4
ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`09
ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:o`000?l000000_l000000ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02_ooool4o`WZ2P03ooooool0003o
000000KoaWj300?o0000olInPoo6OX<03_o6OX<00ol0003oooooooooo`06ooooo`;o2NX:0_ooool0
0ol9jP[oooooooooo`0>oooooa?o0000Boooool00?oooooo@oooool3o`WZ2POooooo00?o2NX:oooo
ooooool02?ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:oooo
ooooool00oooool4o`WZ2P?o00000_l9jPX9ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooo
ooooool02?ooool2o`WZ2PGooooo00?o0000ol5kQ?o1Nh@01?o1Nh@00ol0003o`G^4ol5kQ00<ol5k
Q0;o00000_l9jPX8ooooo`;o2NX:1_ooool00ol9jP[oooooooooo`0<ooooo`Co00005oooool4o`00
0=?ooooo1_l9jPX9ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Kooooo00Co2NX:o`000?l0003o00000_l9jPX9
ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02Oooool2o`WZ2PGooooo00?o2NX:
o`000?o6OX<01Oo6OX<00ol0003oaWj3olInP`0;olInP`;o00001oooool3o`WZ2PCooooo00?o2NX:
ooooooooool01_ooool7o`0001?ooooo0ol00018ooooo`00oooooolnooooo`Go2NX:2_ooool00ol9
jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool02?ooool6o`WZ
2P04ooooool0003o0000o`0000?o2NX:2oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooo
oooo00Gooooo0ol9jPX8ooooo`Co00000_o1Nh@00ol0003o`G^4ol5kQ00:ol5kQ0;o00000_ooool0
0ol9jP[oooooo`WZ2P05ooooo`;o2NX:2Oooool00ol9jP[oooooooooo`08ooooo`?o00007oooool3
o`000<cooooo1?l9jPX>ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool0
0ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Co2NX:0ol00003o`WZ2Pcooooo00?o2NX:
ooooooooool02_ooool00ol9jP[oooooooooo`05ooooo`?o2NX:2?ooool01?l9jP[o0000o`000?l0
0003olInP`03o`000?o6OX?oaWj300WoaWj30_l000000ol9jP[oooooooooo`04ooooo`;o2NX:2?oo
ool00ol9jP[oooooooooo`05o`0001gooooo0ol00015ooooo`00oooooolhooooo`Ko2NX:1?ooool0
0ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool02?ooool0
0ol9jP[oooooooooo`05ooooo`Co2NX:0oooool3o`000003ooooool9jP[o2NX:00;ooooo00?o2NX:
ooooooooool02Oooool00ol9jP[oooooooooo`09ooooo`;o2NX:0oooool3o`WZ2Pkooooo00?o2NX:
o`000?l000001?l00005ol5kQ0Co000000Goooooo`000?ooooooooooo`WZ2P02ooooo`03o`WZ2_oo
oooo2NX:00;o2NX:3?ooool00ol9jP[oooooooooo`05ooooo`;o000000?oooooo`000?ooool08_oo
ool3o`000<Gooooo1?l9jPX7ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool02Ooo
ool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Kooooo1_l9jPX01?oooooo0000o`00
0?l00002o`WZ2P?ooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`0:ooooo`03o`WZ
2_oooooooooo00;ooooo0ol9jPX;ooooo`04o`WZ2_ooooooooooooooo`Co00002?o6OX<3o`000004
o`WZ2_ooooooooooo`WZ2P?ooooo0_l9jPX;ooooo`04o`WZ2_l0003oooooo`0002?ooooo0ol00012
ooooo`00ooooooldooooo`Co2NX:2_ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo
00Sooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`05o`WZ2P?ooooo00Go2NX:o`00
0?l0003o0000ooooo`03o`WZ2PCooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:
ooooo`04o`WZ2_oooooo2NX:o`WZ2Q7ooooo00?o2NX:ooooooooool01?ooool5o`0000;ooooo00Oo
2NX:ooooooooooooooooo`000?oooooo2NX:00;ooooo0ol9jPX?ooooo`;o2NX:0oooool2o`0000?o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2nooooo`Co2NX:2oooool00ol9jP[o
ooooooooo`08ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Oooool01?l9jP[o
ooooooooooooool5o`WZ2P;ooooo0_l9jPX3o`0000?o2NX:1Oooool00ol9jP[oooooooooo`0:oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooool9jPX00_l9jPX>ooooo`03o`WZ2_oooooooooo
00Cooooo2Ol00002ooooo`04o`000?l9jP[oooooooooo`Co2NX:2oooool2o`000004ooooool9jP[o
ooooo`0002Kooooo0_l00010ooooo`00ooooool`ooooo`Co2NX:3_ooool00ol9jP[oooooooooo`08
ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01Oooool6o`WZ2PKooooo0ol00000
1?l9jP[oooooo`WZ2_l9jPX7ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02Ooo
ool3o`WZ2QCooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooo`WZ2P04ooooo`06o`000?l9
jP[o2NX:o`WZ2_oooooo2NX:4?ooool00ol9jP[oooooo`WZ2P02o`0000Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`2iooooo`Co2NX:3oooool00ol9jP[oooooooooo`08ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool01oooool6o`WZ2PKooooo0ol00003o`WZ2PSo
oooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`09ooooo`?o2NX:4_ooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooo2NX:00;ooooo00?o0000o`WZ2_l9jPX00ol9jPX:ooooo`?o
00001?ooool2o`WZ2RSooooo00?o0000ooooooooool0?Oooool00?oooooo;Oooool3o`WZ2POooooo
00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Sooooo
00?o2NX:ooooool9jPX01Ol9jPX01?oooooo2NX:o`WZ2_l9jPX5ooooo`?o00000_ooool3o`WZ2PWo
oooo00?o2NX:ooooooooool02Oooool2o`WZ2POooooo0ol9jPXGooooo`03o`WZ2_oooooooooo00So
oooo00Go2NX:ooooool9jP[o2NX:ooooo`03o`WZ2P03o`000?oooooooooo00;ooooo0_l9jPX=oooo
o`05o`WZ2_l0003o0000ooooool9jPX01_ooool00ol0003oooooooooo`0Vooooo`;o0000]Oooool4
o`WZ2POooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooo
oooo00Wooooo00?o2NX:ooooooooool01ol9jPX00ooooooo2NX:o`WZ2P06ooooo`?o00000_ooool2
o`WZ2P_ooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`06ooooo`?o2NX:5Oooool0
0ol9jP[oooooooooo`0:ooooo`;o2NX:00Coooooo`WZ2_l9jP[o00001?ooool00ol9jP[ooooooooo
o`05ooooo`;o00001Oooool2o`WZ2P03ooooool0003o2NX:02Sooooo0_l0000mooooo`00oooooolY
ooooo`Co2NX:2_ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:
ooooooooool01Oooool5o`WZ2PSooooo0_l9jPX2ooooo`?o00001?ooool2o`WZ2P_ooooo00?o2NX:
ooooooooool02_ooool00ol9jP[oooooooooo`03ooooo`;o2NX:6oooool00ol9jP[oooooooooo`08
ooooo`Co2NX:0oooool00ol0003oooooooooo`02ooooo`;o2NX:2oooool2o`WZ2P03o`000?oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo0:kooooo1?l9jPX;ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool02?ooool0
0ol9jP[oooooooooo`08ooooo`Co2NX:2?ooool2o`WZ2P;ooooo1?l00003ooooo`?o2NX:3?ooool0
0ol9jP[oooooooooo`09ooooo`;o2NX:1Oooool2o`WZ2QSooooo00?o2NX:ooooooooool02Oooool4
o`WZ2P?ooooo00Go0000ooooooooooooooooo`WZ2P05ooooo`;o00001Oooool2o`WZ2PCooooo00?o
0000o`WZ2_ooool0:?ooool00ol0003oooooooooo`0jooooo`00oooooolUooooo`Co2NX:3_ooool0
0ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool00_ooool5
o`WZ2P03ooooool9jP[ooooo00Wooooo00Co2NX:o`000?l0003o00001_ooool00ol9jP[oooooo`WZ
2P0;ooooo`03o`WZ2_oooooooooo00[ooooo00Co2NX:oooooooooooooooo0_l9jPXMooooo`04o`WZ
2_ooooooooooooooo`Oo2NX:00?oooooo`WZ2_ooool01?ooool00ol9jP[o0000ooooo`02ooooo`03
o`WZ2_oooooo2NX:00Sooooo0_l9jPX00ol0003oooooooooo`05ooooo`03o`WZ2_oooooooooo00;o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Zooooo`?o2NX:3oooool00ol9jP[o
ooooooooo`09ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01?ooool4o`WZ2P03
ooooool9jP[ooooo00Wooooo00Co2NX:o`000?l0003o00001_ooool01?l9jP[oooooooooool9jPX<
ooooo`03o`WZ2_oooooooooo00[ooooo00Co2NX:oooooooooooooooo0_l9jPXKooooo`03o`WZ2_oo
oooooooo00;ooooo1_l9jPX2ooooo`03o`WZ2_oooooooooo00;ooooo00Co0000oooooooooooooooo
0_l9jPX2ooooo`;o00001Oooool2o`WZ2PKooooo00?o0000ooooool9jPX0:Oooool2o`0003[ooooo
003oooooob7ooooo1?l9jPX7ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01ooo
ool00ol9jP[oooooooooo`08ooooo`Go2NX:1?ooool00ol9jP[oooooo`WZ2P08ooooo`?o00000_l9
jPX5ooooo`;o2NX:0oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo00Co
2NX:ooooool9jP[o2NX:8?ooool3o`WZ2PWooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
o`000002ooooo`03o`WZ2_oooooo2NX:00Kooooo0_l9jPX00ol0003oooooooooo`08ooooo`;o2NX:
0_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0:Gooooo1?l9jPX7ooooo`03o`WZ
2_oooooooooo00Sooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`08ooooo`03o`WZ
2_oooooo2NX:00Co2NX:0oooool00ol9jP[oooooo`WZ2P08ooooo`?o00000_l9jPX5ooooo`;o2NX:
0oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00[ooooo00Co2NX:ooooool9jP[o
2NX:7Oooool00ol9jP[oooooo`WZ2P02o`WZ2PWooooo00Ko2NX:ooooooooooooooooo`WZ2_l00002
ooooo`;o2NX:00?oooooo`000?ooool01?ooool2o`WZ2PSooooo00Co0000oooooooooooo2NX::_oo
ool00ol0003oooooooooo`0gooooo`00oooooolNooooo`?o2NX:2oooool00ol9jP[oooooooooo`08
ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool00oooool6o`WZ2PSooooo0ol9jPX5
ooooo`?o00000oooool3o`WZ2P;ooooo0_l9jPX5ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:
ooooooooool02Oooool2o`WZ2R;ooooo00?o2NX:ooooooooool02_ooool01Ol9jP[ooooooooooooo
oooo2NX:00;ooooo00?o0000ooooool9jPX00_ooool01?l9jP[oooooooooooooool2o`WZ2P;o0000
3Oooool01?l9jP[oooooooooool0000/ooooo`03o`000?oooooooooo0:3ooooo1?l9jPX;ooooo`03
o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`05ooooo`Ko
2NX:2Oooool2o`WZ2PGooooo0ol00003ooooo`?o2NX:0_ooool2o`WZ2PGooooo00?o2NX:oooooooo
ool02_ooool00ol9jP[oooooooooo`0:ooooo`;o2NX:7oooool00ol9jP[oooooooooo`0<ooooo`0:
o`WZ2_ooooooooooo`WZ2_oooooo0000ooooool9jP[o0000o`WZ2PCooooo0_l9jPX:ooooo`05o`00
0?ooooooooooooooool9jPX0:_ooool00ol0003oooooooooo`0fooooo`00oooooolJooooo`Co2NX:
3_ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00Sooooo1_l9jPX2ooooo`04o`WZ
2_ooooooooooo`WZ2PWooooo0_l9jPX2ooooo`?o00001_ooool00ol9jP[oooooo`WZ2P02o`WZ2POo
oooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`07ooooo`;o2NX:9Oooool00ol9jP[o
ooooooooo`0:ooooo`04o`WZ2_ooooooooooo`WZ2P?ooooo00?o0000o`WZ2_ooool00_ooool3o`WZ
2P03ooooool0003ooooo00oooooo00?o2NX:ooooool00000;?ooool00ol0003oooooooooo`2Loooo
o`Co2NX:3oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Sooooo2?l9jPX2oooo
o`03o`WZ2_oooooo2NX:00[ooooo0_l9jPX2ooooo`?o00001_ooool00ol9jP[oooooo`WZ2P02o`WZ
2PSooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`08ooooo`;o2NX:8_ooool00ol9
jP[oooooooooo`0;ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo00Ko0000o`WZ2_ooooooooooo`WZ
2_ooool2o`WZ2Pcooooo00?o0000ooooooooool00_ooool00ol9jP[oooooooooo`0Wooooo`03o`00
0?oooooooooo03Kooooo003ooooooaOooooo0ol9jPX7ooooo`03o`WZ2_oooooooooo00Sooooo00?o
2NX:ooooooooool01oooool00ol9jP[oooooooooo`03ooooo`Ko2NX:1oooool01?l9jP[ooooooooo
ool9jPX:ooooo`?o00002Oooool2o`WZ2P[ooooo00?o2NX:ooooooooool02Oooool00ol9jP[ooooo
ooooo`04ooooo`?o2NX:9oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooo2NX:00?ooooo
00?o0000ooooool9jPX00_l9jPX01?oooooo2NX:o`000?l0000>ooooo`;o2NX:0_ooool00ol9jP[o
0000ooooo`0/ooooo`03o`000?oooooooooo09Oooooo1?l9jPX7ooooo`03o`WZ2_oooooooooo00Wo
oooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`05ooooo`Co2NX:2Oooool00ol9jP[o
ooooo`WZ2P0:ooooo`04o`WZ2_l0003o0000o`0000Wooooo0_l9jPX;ooooo`03o`WZ2_oooooooooo
00[ooooo00?o2NX:ooooooooool01?ooool3o`WZ2RCooooo00?o2NX:ooooooooool03?ooool01?l9
jP[oooooo`WZ2_ooool2o`0000Go2NX:3_ooool01ol0003ooooooooooooooooo2NX:ooooool9jPX0
:Oooool00ol0003oooooooooo`0eooooo`00oooooolCooooo`Co2NX:2_ooool00ol9jP[ooooooooo
o`07ooooo`03o`WZ2_oooooooooo00Sooooo1_l9jPX00ooooooo2NX:ooooo`02ooooo`03o`WZ2_oo
oooooooo00Gooooo0_l9jPX00ooooooo2NX:ooooo`06ooooo`?o00000_l9jPX8ooooo`?o2NX:2ooo
ool00ol9jP[oooooooooo`09ooooo`04o`WZ2_ooooooooooooooo`?o2NX::oooool00ol9jP[ooooo
ooooo`0;ooooo`;o2NX:0_ooool2o`WZ2P03o`000?l9jP[ooooo00;ooooo00?o0000o`WZ2_ooool0
3Oooool00ol9jP[oooooooooo`03ooooo`;o2NX:;Oooool00ol0003oooooooooo`2Booooo`Co2NX:
2oooool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooool9jPX0
1_l9jPX2ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooool9jPX02?ooool3o`0000;o2NX:
2?ooool3o`WZ2Pcooooo00?o2NX:ooooooooool02_ooool01?l9jP[oooooooooooooool3o`WZ2RSo
oooo00?o2NX:ooooooooool03?ooool2o`WZ2P04o`000?l9jP[o2NX:o`0000?ooooo00?o2NX:oooo
ooooool03?ooool01?l0003oooooo`WZ2_l9jPX3ooooo`;o2NX::?ooool00ol0003oooooooooo`0d
ooooo`00Xoooool5o`0006Oooooo0ol9jPX>ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:oooo
ooooool00_ooool7o`WZ2PKooooo00Go2NX:ooooooooooooooooo`WZ2P08ooooo`?o2NX:1?ooool3
o`0000?ooooo00Co2NX:ooooool9jP[o2NX:1?ooool2o`WZ2P;ooooo00?o2NX:ooooooooool02Ooo
ool00ol9jP[oooooooooo`0;ooooo`;o2NX:;_ooool00ol9jP[oooooooooo`0;ooooo`Co2NX:0ooo
ool01_l0003oooooo`000?l0003oooooo`WZ2Pcooooo0_l9jPX6ooooo`03o`000?oooooo2NX:02co
oooo00?o0000ooooooooool07oooool5o`0006_ooooo0ol9jPX?ooooo`03o`WZ2_oooooooooo00So
oooo00?o2NX:ooooooooool01?ooool7o`WZ2PKooooo0_l9jPX00ooooooo2NX:ooooo`09ooooo`;o
2NX:1?ooool4o`0000?ooooo0ol9jPX5ooooo`;o2NX:0oooool00ol9jP[oooooooooo`09ooooo`03
o`WZ2_oooooooooo00[ooooo00Co2NX:ooooool9jP[o2NX::oooool00ol9jP[oooooooooo`0;oooo
o`Co2NX:0_ooool01?l9jP[o0000ooooooooool2o`WZ2Pcooooo0ol9jPX7ooooo`03o`WZ2_oooooo
oooo02Kooooo00?o0000ooooooooool0<oooool009kooooo1Ol00005ooooo`?o0000H?ooool4o`WZ
2PKooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`07ooooo`Ko2NX:1Oooool00ol9
jP[oooooooooo`04ooooo`05o`WZ2_ooooooooooooooool9jPX02Oooool2o`WZ2P04ooooool0003o
0000o`0000Kooooo00?o2NX:ooooooooool00_l9jPX2ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool02Oooool00ol9jP[oooooooooo`08ooooo`?o2NX:<?ooool00ol9jP[ooooooooo
o`06ooooo`Go2NX:0_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_l0003ooooo00;ooooo0_l9
jPX9ooooo`;o2NX:2?ooool01?l0003oooooooooool9jPX/ooooo`03o`000?oooooooooo01[ooooo
1?l00005ooooo`?o0000I?ooool4o`WZ2POooooo00?o2NX:ooooooooool02?ooool00ol9jP[ooooo
ooooo`08ooooo`03o`WZ2_oooooooooo00Co2NX:00?oooooo`WZ2_ooool00_ooool00ol9jP[ooooo
ooooo`06ooooo`03o`WZ2_oooooo2NX:00[ooooo0_l9jPX01?oooooo0000o`000?l00007ooooo`04
o`WZ2_oooooo2NX:o`WZ2P;ooooo0_l9jPX5ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:oooo
ooooool02Oooool3o`WZ2Rgooooo00?o2NX:ooooooooool01Oooool6o`WZ2P03o`000?oooooo2NX:
00Cooooo00Go0000ooooooooooooooooo`WZ2P0:ooooo`;o2NX:0_ooool00ol0003oooooooooo`06
ooooo`03o`WZ2_oooooooooo02Kooooo00?o0000ooooooooool0<_ooool009gooooo00?o0000oooo
ooooool02oooool3o`0005[ooooo0ol9jPX:ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:oooo
ooooool00oooool5o`WZ2PGooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`05oooo
o`04o`WZ2_ooooooooooo`WZ2PWooooo0ol00009ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPX5
ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool01Oooool3o`WZ2SCooooo00?o2NX:
ooooool9jPX01Ol9jPX8ooooo`07o`WZ2_ooooooooooooooool9jP[oooooo`000002ooooo`03o`WZ
2_oooooo2NX:00Gooooo0ol9jPX:ooooo`05o`000?ooooooooooooooool9jPX0;?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo0_l0001Nooooo`Co2NX:2oooool00ol9jP[o
ooooooooo`08ooooo`03o`WZ2_oooooooooo00Oooooo1?l9jPX5ooooo`05o`WZ2_oooooooooooooo
ool9jPX02?ooool00ol9jP[oooooo`WZ2P0:ooooo`?o00002_ooool01?l9jP[oooooooooooooool2
o`WZ2POooooo00?o2NX:ooooooooool02_ooool00ol9jP[oooooooooo`05ooooo`?o2NX:<Oooool7
o`WZ2PGooooo00Go0000ooooooooooooooooo`WZ2P03ooooo`04o`WZ2_l0003oooooooooo`;o2NX:
1_ooool3o`WZ2PCooooo00?o0000ooooooooool01oooool00ol9jP[oooooooooo`0Uooooo`03o`00
0?oooooooooo03;ooooo002Looooo`03o`000?oooooooooo00oooooo0_l0001Dooooo`Co2NX:3Ooo
ool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00Co2NX:1?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01Oooool2o`WZ2P03ooooool9
jP[ooooo00Gooooo0ol000000ooooooo2NX:o`WZ2P09ooooo`03o`WZ2_oooooooooo00;o2NX:1ooo
ool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00?ooooo0_l9jPXgooooo`03o`WZ2_oo
oooooooo00kooooo00Ko2NX:ooooool0003o2NX:ooooool00002ooooo`04o`WZ2_ooooooooooo`WZ
2P;ooooo0_l9jPX=ooooo`03o`000?oooooooooo00;ooooo0_l9jPXZooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool03Oooool2o`0005Sooooo1?l9jPX?ooooo`03o`WZ2_oooooooooo
00Sooooo00?o2NX:ooooooooool00_ooool5o`WZ2P03ooooool9jP[ooooo00Kooooo00Go2NX:oooo
ooooooooooooo`WZ2P08ooooo`?o2NX:1oooool3o`000003ooooool9jP[o2NX:00[ooooo00Co2NX:
ooooool9jP[o2NX:2Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00?ooooo0_l9
jPXdooooo`03o`WZ2_oooooooooo00Wooooo00?o0000ooooooooool00_ooool02_l9jP[ooooooooo
ool9jP[oooooo`000?oooooo2NX:ooooool9jPX3ooooo`;o2NX:1oooool00ol0003oooooooooo`08
ooooo`;o2NX:9_ooool00ol0003oooooooooo`0aooooo`00Voooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo04gooooo1?l9jPX7ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:oooo
ooooool01?ooool6o`WZ2P03ooooool9jP[ooooo00Gooooo00?o2NX:ooooooooool00oooool2o`WZ
2P?ooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooo`WZ2P03ooooo`?o00001?ooool00ol9
jP[oooooo`WZ2P08ooooo`?o2NX:2Oooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooo2NX:
00;o2NX:>_ooool00ol9jP[oooooooooo`0>ooooo`03o`WZ2_oooooo2NX:00;ooooo00?o0000oooo
ool9jPX00oooool2o`WZ2Poooooo00?o0000ooooooooool00_l9jPX2ooooo`03o`WZ2_oooooooooo
02Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05;ooooo0ol9jPX8ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01oooool6o`WZ
2P03ooooool9jP[o2NX:00?ooooo00?o2NX:ooooooooool01Oooool2o`WZ2P;ooooo00?o2NX:oooo
ooooool01oooool2o`WZ2PCooooo0ol00004ooooo`03o`WZ2_oooooo2NX:00Sooooo0ol9jPX;oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool00ol9jPXfooooo`03o`WZ2_oooooooooo
00Sooooo00?o0000ooooooooool01?ooool01ol9jP[oooooo`WZ2_oooooo0000ooooool9jPX00_oo
ool3o`WZ2PWooooo00?o0000ooooooooool01_ooool2o`WZ2P;ooooo00?o2NX:ooooooooool09?oo
ool00ol0003oooooooooo`0`ooooo`00V_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo04Sooooo1?l9jPX:ooooo`03o`WZ2_oooooooooo00Sooooo1ol9jPX3ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`05o`WZ2_oooooo
ooooooooool9jPX02Oooool2o`WZ2P?o00001oooool00ol9jP[oooooooooo`02o`WZ2PCooooo0_l9
jPX00ooooooo2NX:ooooo`09ooooo`03o`WZ2_oooooooooo00Wooooo0ol9jPXmooooo`03o`WZ2_oo
oooooooo00gooooo00Co0000ooooool9jP[o2NX:0oooool00ol0003o2NX:o`WZ2P03o`WZ2Q3ooooo
00?o0000o`WZ2_l9jPX01Oooool2o`WZ2RWooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo04_ooooo1_l9jPX;ooooo`03o`WZ2_oooooooooo00Sooooo
00Co2NX:oooooooooooooooo1_l9jPX00ooooooo2NX:ooooo`05ooooo`05o`WZ2_oooooooooooooo
ool9jPX02?ooool01?l9jP[oooooooooool9jPX:ooooo`03o`WZ2_oooooo000000;o00001oooool0
0ol9jP[oooooooooo`02o`WZ2PCooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:
ooooooooool02_ooool3o`WZ2S[ooooo00?o2NX:ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`;o2NX:0_ooool00ol0003o2NX:o`WZ2P02o`WZ2P_ooooo00?o0000ooooooooool01?ooool2
o`WZ2PGooooo00?o2NX:ooooooooool09?ooool00ol0003oooooooooo`0_ooooo`00VOooool00ol0
003oooooooooo`0Fooooo`;o0000AOooool3o`WZ2Pkooooo00?o2NX:ooooooooool01?ooool5o`WZ
2P03ooooool9jP[ooooo00Kooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Gooooo00Co2NX:oooooooooooo2NX:2?ooool3o`0000[ooooo00Co2NX:
oooooooooooooooo0_l9jPX00ooooooo2NX:o`WZ2P03ooooo`03o`WZ2_oooooooooo00Wooooo00?o
2NX:ooooooooool01_ooool2o`WZ2T3ooooo00?o2NX:ooooooooool03?ooool01_l0003ooooooooo
oooooooo2NX:ooooo`?o2NX:00?o0000ooooooooool00_ooool00ol9jP[oooooooooo`0<ooooo`;o
2NX:2Oooool00ol9jP[oooooooooo`0Vooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`14ooooo`Ko2NX:1_ooool00ol9jP[oooooooooo`07ooooo`03
o`WZ2_oooooooooo00Sooooo1Ol9jPX00ooooooo2NX:ooooo`04ooooo`03o`WZ2_oooooooooo00Co
oooo00Go2NX:ooooooooooooooooo`WZ2P08ooooo`;o2NX:00?oooooo`WZ2_ooool01oooool4o`00
00_ooooo00?o2NX:ooooooooool00_l9jPX00ooooooo2NX:o`WZ2P04ooooo`03o`WZ2_oooooooooo
00Wooooo00?o2NX:ooooooooool02?ooool2o`WZ2Sgooooo00?o2NX:ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`Co2NX:00Go0000ooooooooooooooooo`WZ2P0:ooooo`03o`000?oooooo
oooo00?ooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0Sooooo`03o`000?oooooo
oooo02oooooo002Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0?Oooool5o`WZ
2POooooo00?o2NX:ooooooooool01oooool7o`WZ2P?ooooo00Go2NX:ooooooooooooooooo`WZ2P06
ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:
ooooool9jPX01_ooool3o`0000;ooooo0_l9jPX9ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPX5
ooooo`03o`WZ2_oooooooooo00Wooooo00?o2NX:ooooooooool00oooool3o`WZ2T?ooooo00?o2NX:
ooooooooool02_ooool01?l0003oooooooooooooool3o`WZ2P?ooooo00?o2NX:o`000?ooool00ooo
ool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooo000000[ooooo0_l9jPXVooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`10ooooo`?o2NX:3?oo
ool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00;ooooo1ol9jPX5ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool01Ol9jP[ooooooooooooooooo2NX:00Wooooo
00?o2NX:ooooool9jPX01Oooool3o`0000?ooooo0_l9jPX:ooooo`03o`WZ2_oooooooooo00?o2NX:
1_ooool00ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00Cooooo0ol9jPXoooooo`03o`WZ
2_oooooooooo00Cooooo00?o0000ooooooooool01_ooool5o`WZ2P;ooooo00?o2NX:o`000?ooool0
0_ooool00ol9jP[oooooooooo`07ooooo`03o`000?oooooooooo00?o2NX:2_ooool00ol9jP[ooooo
ooooo`0Sooooo`03o`000?oooooooooo02kooooo002Hooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0=_ooool6o`WZ2Pcooooo00?o2NX:ooooooooool00_ooool6o`WZ2PWooooo00Go
2NX:ooooooooooooooooo`WZ2P06ooooo`03o`WZ2_oooooooooo00?ooooo00Go2NX:oooooooooooo
ooooo`WZ2P09ooooo`;o2NX:0oooool3o`0000Gooooo0ol9jPX8ooooo`03o`WZ2_oooooooooo00;o
2NX:1oooool00ol9jP[oooooooooo`09ooooo`04o`WZ2_ooooooooooooooo`;o2NX:A_ooool00ol9
jP[oooooooooo`08ooooo`Ko2NX:0oooool01Ol9jP[oooooooooool9jP[o000000Cooooo00?o2NX:
ooooooooool01oooool3o`WZ2P;ooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`0T
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0k
ooooo`Co2NX:3_ooool00ol9jP[oooooooooo`07ooooo`Ko2NX:1_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Oooool01?l9jP[oooooooooool9
jPX9ooooo`?o2NX:0_ooool3o`0000Kooooo0ol9jPX9ooooo`?o2NX:2Oooool00ol9jP[ooooooooo
o`0:ooooo`04o`WZ2_ooooooooooooooo`?o2NX:@_ooool00ol9jP[oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo1?l9jPX5ooooo`04o`WZ2_oooooo2NX:o`0000;ooooo0_l9jPX9ooooo`?o
2NX:3_ooool00ol9jP[oooooooooo`0Rooooo`03o`000?oooooooooo02kooooo002Hooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0<_ooool3o`WZ2POooooo00?o2NX:ooooooooool0
1oooool00ol9jP[oooooo`WZ2P03o`WZ2PGooooo0_l9jPX8ooooo`04o`WZ2_ooooooooooooooo`;o
2NX:1Oooool00ol9jP[oooooooooo`03ooooo`;o2NX:0_ooool00ol9jP[oooooooooo`07ooooo`;o
2NX:0ol00008ooooo`03o`WZ2_oooooooooo00;o2NX:1_ooool3o`WZ2PWooooo00?o2NX:oooooooo
ool02Oooool01?l9jP[oooooo`WZ2_l9jPY9ooooo`03o`WZ2_oooooooooo00Oo2NX:00?o0000oooo
ooooool01oooool01Ol9jP[oooooo`WZ2_oooooo000000?ooooo0_l9jPX6ooooo`;o2NX:1Oooool0
0ol0003oooooooooo`0;ooooo`03o`WZ2_oooooooooo02?ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Oooooo0ol9jPX7ooooo`03o`WZ2_oooooo
oooo00Sooooo00?o2NX:ooooooooool00_ooool5o`WZ2P03ooooool9jP[ooooo00?ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool01Oooool01?l9jP[oooooooooool9jPX:ooooo`04o`WZ2_l0003o0000o`0000Wooooo
00Co2NX:ooooool9jP[o2NX:1oooool2o`WZ2P_ooooo00?o2NX:ooooooooool02_ooool01?l9jP[o
ooooo`WZ2_l9jPY6ooooo`04o`WZ2_ooooooooooooooo`Oo2NX:2Oooool02Ol9jP[oooooo`WZ2_oo
oooo0000ooooool9jP[oooooo`WZ2P07ooooo`03o`WZ2_oooooo0000013ooooo00?o2NX:oooooooo
ool08Oooool00ol0003oooooooooo`0^ooooo`00Uoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo02kooooo1?l9jPX:ooooo`03o`WZ2_oooooooooo00Gooooo1?l9jPX9ooooo`03o`WZ
2_oooooo2NX:00Oooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo0_l9jPX00ooooooo2NX:ooooo`07ooooo`?o000000?o2NX:ooooooooool0
2?ooool01?l9jP[oooooooooooooool2o`WZ2PCooooo0_l9jPX;ooooo`03o`WZ2_oooooooooo00So
oooo0ol9jPY<ooooo`;o2NX:1_ooool00ol0003oooooooooo`09ooooo`?o2NX:00Coooooo`000?oo
oooooooo0_l9jPX4ooooo`;o2NX:1oooool00ol0003oooooooooo`08ooooo`05o`WZ2_oooooooooo
ooooool9jPX09?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0<oooool4o`WZ2P[ooooo00?o2NX:ooooooooool02?ooool5o`WZ2PKooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooo2NX:00Sooooo0ol00000
0ol9jP[oooooooooo`09ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool2o`WZ2P03ooooool9
jP[ooooo00_ooooo00?o2NX:ooooooooool02?ooool3o`WZ2TSooooo00Co2NX:ooooool9jP[o2NX:
4Oooool01Ol9jP[oooooo`WZ2_oooooo000000?o2NX:1?ooool3o`WZ2P;ooooo00?o0000oooooooo
ool03?ooool01?l9jP[oooooooooool9jPXSooooo`03o`000?oooooooooo02gooooo002Fooooo`03
o`000?oooooooooo01gooooo0_l0000/ooooo`?o2NX:3_ooool01?l9jP[oooooooooooooool4o`WZ
2P;ooooo00?o2NX:ooooooooool01oooool01?l9jP[oooooooooool9jPX7ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooo
2NX:00Gooooo0ol00002ooooo`?o2NX:2Oooool00ol9jP[oooooooooo`02ooooo`?o2NX:00Cooooo
o`WZ2_oooooo2NX:2oooool00ol9jP[oooooooooo`05ooooo`?o2NX:Coooool00ol9jP[ooooooooo
o`04ooooo`03o`000?oooooooooo00_ooooo0_l9jPX2ooooo`04o`000?oooooo2NX:ooooo`Co2NX:
2_ooool00ol0003oooooooooo`04ooooo`?o2NX:1Oooool2o`WZ2R?ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Hooooo`;o0000<?ooool4o`WZ2Pkooooo00?o2NX:ooooooooool0
1Oooool4o`WZ2P?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool01Oooool01Ol9jP[ooooooooooooooooo2NX:00So
oooo00?o2NX:ooooool9jPX01Oooool3o`0000?ooooo0_l9jPX:ooooo`03o`WZ2_oooooooooo00;o
oooo0_l9jPX00ooooooo2NX:ooooo`02ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:oooooooo
ool01Oooool3o`WZ2T_ooooo00?o2NX:ooooool000004oooool2o`WZ2P07ooooool0003oooooo`WZ
2_oooooo2NX:ooooo`02o`WZ2PGooooo00?o0000ooooooooool02Oooool3o`WZ2PCooooo0_l9jPXQ
ooooo`03o`000?oooooooooo02gooooo002Fooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ool000009oooool4o`WZ2POooooo00?o2NX:ooooooooool01Oooool6o`WZ2PKooooo0_l9jPX8oooo
o`05o`WZ2_ooooooooooooooool9jPX01_ooool00ol9jP[oooooooooo`03ooooo`05o`WZ2_oooooo
ooooooooool9jPX02Oooool2o`WZ2P;ooooo0ol00005ooooo`04o`WZ2_oooooo2NX:o`WZ2PSooooo
00?o2NX:ooooooooool01?ooool2o`WZ2P;ooooo00?o2NX:ooooooooool02Oooool00ol9jP[ooooo
ooooo`03ooooo`;o2NX:Doooool00ol9jP[oooooooooo`02ooooo`03o`000?oooooooooo00gooooo
00Go2NX:ooooooooooooooooo`000002o`WZ2P03ooooool9jP[ooooo00_ooooo00?o0000oooooooo
ool00oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo023ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000002_ooooo1?l9jPX7ooooo`03
o`WZ2_oooooooooo00Sooooo00?o2NX:ooooool9jPX01Ol9jPX3ooooo`05o`WZ2_oooooooooooooo
ool9jPX01_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool01Oooool01Ol9jP[ooooooooooooooooo2NX:00Wooooo0_l9jPX2ooooo`?o00001_ooool0
1?l9jP[oooooo`WZ2_l9jPX8ooooo`03o`WZ2_oooooooooo00?ooooo0_l9jPX4ooooo`03o`WZ2_oo
oooooooo00[ooooo00?o2NX:ooooooooool00oooool2o`WZ2Toooooo00?o2NX:ooooooooool04ooo
ool01?l9jP[oooooooooool00004o`WZ2POooooo00?o0000ooooooooool02?ooool00ol9jP[ooooo
ooooo`07ooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool0;Oooool009Gooooo00?o
0000ooooooooool07_ooool01?l0003oooooooooool0000Sooooo`?o2NX:2oooool00ol9jP[ooooo
o`WZ2P05o`WZ2P03ooooool9jP[o2NX:00Wooooo0_l9jPX8ooooo`05o`WZ2_ooooooooooooooool9
jPX01_ooool00ol9jP[oooooooooo`04ooooo`04o`WZ2_ooooooooooo`WZ2P[ooooo0ol00008oooo
o`03o`WZ2_oooooooooo00?o2NX:1_ooool00ol9jP[oooooooooo`02ooooo`;o2NX:1?ooool00ol9
jP[oooooooooo`09ooooo`03o`WZ2_oooooooooo00?o2NX:EOooool00ol9jP[oooooooooo`02oooo
o`03o`000?oooooooooo00gooooo00Ko2NX:ooooool9jP[o2NX:o`000?l9jPX3ooooo`03o`WZ2_oo
oooooooo00Wooooo00?o0000ooooooooool00ol9jPX<ooooo`03o`WZ2_oooooooooo01oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0002Oooooo
0ol9jPX;ooooo`03o`WZ2_oooooooooo00?ooooo2?l9jPX8ooooo`05o`WZ2_ooooooooooooooool9
jPX01_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool01_ooool01?l9jP[oooooooooool9jPX9ooooo`Co00002Oooool00ol9jP[oooooooooo`02o`WZ
2POooooo00Co2NX:oooooooooooooooo0_l9jPX6ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:
ooooooooool00ol9jPYAooooo`03o`WZ2_oooooooooo01?ooooo0ol9jPX01Ooooooo0000oooooooo
oooo2NX:00Oooooo00?o0000ooooooooool01_ooool2o`WZ2P_ooooo00?o2NX:ooooooooool07_oo
ool00ol0003oooooooooo`0/ooooo`00UOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07?ooool4o`WZ2P_ooooo1Ol9jPX7ooooo`03o`WZ2_oooooo
oooo00Sooooo00?o2NX:ooooool9jPX01oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool01Oooool2o`WZ2P03ooooool9jP[ooooo00Kooooo0ol00002
o`WZ2PWooooo00?o2NX:ooooooooool00_ooool2o`WZ2PGooooo00?o2NX:ooooool9jPX00_l9jPX6
ooooo`03o`WZ2_oooooooooo00Wooooo0ol9jPYIooooo`04o`WZ2_ooooooooooo`0000gooooo1Ol9
jPX3ooooo`03o`000?oooooooooo00;ooooo00?o2NX:ooooooooool02?ooool00ol0003oooooo`WZ
2P0@ooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Iooooo`05o`000?ooooooooooooooool000008_ooool4o`WZ2Pkooooo00?o2NX:ooooool9jPX0
0ol9jPX5ooooo`04o`WZ2_ooooooooooo`WZ2POooooo00Go2NX:ooooooooooooooooo`WZ2P06oooo
o`03o`WZ2_oooooooooo00Cooooo00Go2NX:ooooooooooooooooo`WZ2P08ooooo`;o2NX:00?ooooo
o`WZ2_ooool01Oooool3o`000003ooooool9jP[o2NX:00[ooooo00Co2NX:oooooooooooooooo0_l9
jPX6ooooo`Co2NX:2Oooool00ol9jP[oooooooooo`09ooooo`?o2NX:Doooool00ol0003oooooo`WZ
2P0@ooooo`Co2NX:00Goooooo`WZ2_ooooooooooo`000002ooooo`03o`WZ2_oooooooooo00Gooooo
00?o0000ooooooooool00oooool3o`WZ2Pkooooo00?o2NX:ooooooooool07Oooool00ol0003ooooo
ooooo`0/ooooo`00UOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06Oooool3o`WZ2POooooo00?o2NX:ooooool9jPX01Ol9jPX2ooooo`03o`WZ2_oo
oooooooo00Oooooo00?o2NX:ooooooooool01oooool01?l9jP[oooooooooool9jPX7ooooo`03o`WZ
2_oooooooooo00;ooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooool9jPX0
1?ooool3o`0000?ooooo00?o2NX:ooooool9jPX02?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00;ooooo0_l9jPX:ooooo`03o`WZ2_oooooooooo00Kooooo0_l9jPYLooooo`03o`WZ
2_oooooo000000[ooooo1?l9jPX5ooooo`05o`WZ2_ooooooooooo`WZ2_l000000oooool00ol9jP[o
ooooooooo`07ooooo`?o2NX:4_ooool2o`WZ2Qoooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Iooooo`05o`000?ooooooooooooooool000007oooool3o`WZ2POooooo00?o2NX:oooo
ooooool01?ooool6o`WZ2PWooooo00Co2NX:oooooooooooo2NX:1oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool01Ol9jP[ooooooooooooo
oooo2NX:00Wooooo00?o2NX:ooooool9jPX00oooool3o`0000Cooooo00?o2NX:ooooool9jPX02Ooo
ool00ol9jP[oooooooooo`02ooooo`;o2NX:1?ooool2o`WZ2Pcooooo00?o2NX:ooooooooool01ooo
ool2o`WZ2UGooooo00Co0000oooooooooooo2NX:3?ooool4o`WZ2PKooooo00Co2NX:ooooool9jP[o
00000_ooool00ol9jP[oooooooooo`05ooooo`03o`000?oooooo2NX:00;o2NX:4_ooool00ol9jP[o
ooooooooo`0Looooo`03o`000?oooooooooo02cooooo002Eooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`Co2NX:1_ooool6o`WZ2PKooooo
00?o2NX:ooooool9jPX02Oooool2o`WZ2PSooooo00Go2NX:ooooooooooooooooo`WZ2P06ooooo`03
o`WZ2_oooooooooo00?ooooo00Go2NX:ooooooooooooooooo`WZ2P09ooooo`;o2NX:00Coooooo`00
0?l0003o00001_ooool01?l9jP[oooooooooool9jPX7ooooo`03o`WZ2_oooooooooo00Gooooo1Ol9
jPX;ooooo`03o`WZ2_oooooooooo00?ooooo0ol9jPYNooooo`03o`WZ2_oooooo000000Cooooo1_l9
jPX:ooooo`05o`WZ2_oooooo2NX:ooooool000000_ooool2o`WZ2POooooo00?o2NX:ooooool00000
4?ooool2o`WZ2P?ooooo00?o2NX:ooooooooool06oooool2o`0000oooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo1?l9jPX:ooooo`Oo2NX:
1?ooool2o`WZ2PWooooo00Co2NX:oooooooooooo2NX:1oooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Oooool01?l9jP[oooooooooool9jPX:oooo
o`;o2NX:0ol00007ooooo`04o`WZ2_oooooo2NX:o`WZ2PSooooo00?o2NX:ooooooooool01?ooool4
o`WZ2P03ooooool9jP[ooooo00_ooooo00?o2NX:ooooooooool01?ooool3o`WZ2UOooooo00Co0000
oooooooooooo2NX:1_ooool6o`WZ2P_ooooo0_l9jPX01?oooooo0000ooooool9jPX7ooooo`03o`00
0?l9jP[ooooo017ooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo01cooooo00?o0000ooooooooool0
:oooool009Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo013ooooo0ol9jPX6ooooo`Co2NX:1?ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oo
oooo2NX:00Wooooo0_l9jPX8ooooo`05o`WZ2_ooooooooooooooool9jPX01_ooool00ol9jP[ooooo
ooooo`04ooooo`04o`WZ2_ooooooooooo`WZ2PWooooo0ol00009ooooo`04o`WZ2_oooooooooooooo
o`;o2NX:1Oooool00ol9jP[oooooooooo`06ooooo`04o`WZ2_ooooooooooo`WZ2P_ooooo00Co2NX:
oooooooooooooooo0_l9jPYRooooo`03o`WZ2_oooooo2NX:00?o2NX:4Oooool2o`WZ2P;ooooo00Go
0000ooooool9jP[oooooo`WZ2P03ooooo`?o2NX:0_ooool00ol0003oooooooooo`0<ooooo`;o2NX:
1_ooool00ol9jP[oooooooooo`0Gooooo`?o000000?oooooo`000?ooool03_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool4o`WZ2P[ooooo
1Ol9jPX:ooooo`03o`WZ2_oooooo2NX:00Sooooo00Co2NX:oooooooooooo2NX:1oooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01Oooool01?l9jP[o
ooooooooool9jPX9ooooo`?o00002_ooool00ol9jP[oooooooooo`02o`WZ2POooooo00?o2NX:oooo
ooooool01?ooool2o`WZ2PCooooo00?o2NX:ooooooooool02Oooool01?l9jP[oooooooooooooool3
o`WZ2UWooooo00?o0000ooooooooool00_ooool6o`WZ2Q7ooooo0_l9jPX2ooooo`03o`000?l9jP[o
2NX:00Cooooo0ol9jPXBooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool06Oooool3
o`0002gooooo002Dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`Go2NX:0oooool6o`WZ2PCooooo00Go2NX:ooooooooooooooooo`WZ2P08
ooooo`;o2NX:2Oooool00ol9jP[oooooo`WZ2P07ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`;o2NX:00?oooooo`WZ2_ooool01Oooool3
o`000003ooooool9jP[o2NX:00Wooooo00?o2NX:ooooooooool00_ooool2o`WZ2PCooooo00?o2NX:
ooooooooool01?ooool2o`WZ2P?ooooo00?o2NX:ooooooooool02Oooool01?l9jP[oooooo`WZ2_l9
jPYSooooo`03o`000?l9jP[ooooo01Kooooo00Oo2NX:oooooooooooo0000ooooool9jP[ooooo00Co
2NX:1Oooool00ol0003oooooooooo`0:ooooo`;o2NX:2Oooool00ol9jP[oooooooooo`0Cooooo`?o
00001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0=ooooo`Go2NX:1oooool7o`WZ2PCooooo00?o2NX:oooooooo
ool02?ooool00ol9jP[oooooo`WZ2P07ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`;o2NX:0oooool00ol9jP[oooooooooo`06ooooo`03
o`WZ2_oooooo2NX:00Kooooo0ol00002ooooo`;o2NX:2Oooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Wooooo00Co2NX:ooooool9jP[o2NX:Foooool00ol0003oooooooooo`03oooo
o`03o`WZ2_oooooooooo01Gooooo00Ko2NX:oooooooooooo0000o`WZ2_ooool4o`WZ2P;ooooo00?o
0000ooooooooool03Oooool3o`WZ2POooooo00?o2NX:ooooooooool05Oooool3o`0000;ooooo00?o
0000ooooooooool0:oooool009Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo1Ol9jPX2ooooo`Ko2NX:0oooool00ol9jP[oooooooooo`05
ooooo`04o`WZ2_ooooooooooo`WZ2PSooooo0_l9jPX9ooooo`03o`WZ2_oooooo2NX:00Oooooo00?o
2NX:ooooooooool00oooool01Ol9jP[ooooooooooooooooo2NX:00Wooooo0_l9jPX3ooooo`?o0000
1?ooool00ol9jP[oooooo`WZ2P08ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
2Oooool2o`WZ2VGooooo00?o0000ooooool9jPX05oooool01?l9jP[oooooooooool00004o`WZ2POo
oooo00?o0000ooooooooool02Oooool00ol9jP[oooooooooo`0:ooooo`;o2NX:4?ooool3o`0000Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01oooool6o`WZ2POooooo1_l9jPX:ooooo`03o`WZ2_oooooooooo00So
oooo00?o2NX:ooooool9jPX01oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool01Oooool01Ol9jP[ooooooooooooooooo2NX:00Wooooo0_l9jPX3oooo
o`?o00001Oooool2o`WZ2P[ooooo00?o2NX:ooooooooool00_ooool2o`WZ2PGooooo00?o2NX:oooo
ooooool00_l9jPX7ooooo`03o`WZ2_oooooooooo00Sooooo0ol9jPYMooooo`03o`000?oooooooooo
00?ooooo00?o2NX:ooooooooool05_ooool01?l9jP[oooooooooool00002o`WZ2PGooooo00?o0000
ooooooooool02oooool2o`WZ2P_ooooo0_l9jPXAooooo`Co00001Oooool00ol0003oooooooooo`0[
ooooo`00U?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00Co0000oooo
oooooooooooo0ol9jPX3ooooo`Co2NX:2Oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooo
2NX:00Wooooo0_l9jPX9ooooo`04o`WZ2_ooooooooooo`WZ2PKooooo00?o2NX:ooooooooool01?oo
ool01?l9jP[oooooooooool9jPX9ooooo`;o2NX:0ol00007ooooo`03o`WZ2_oooooooooo00;o2NX:
1_ooool00ol9jP[oooooooooo`05ooooo`;o2NX:0_ooool00ol9jP[oooooooooo`02o`WZ2PKooooo
00?o2NX:ooooooooool01oooool2o`WZ2VKooooo00Co0000oooooooooooo2NX:6?ooool3o`WZ2P05
o`000?ooooooooooooooool9jPX01_ooool00ol0003oooooooooo`06ooooo`?o2NX:3oooool00ol9
jP[oooooooooo`0:ooooo`?o00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o2NX:2?ooool5o`WZ
2PCooooo0_l9jPX:ooooo`03o`WZ2_oooooooooo00Oooooo00Go2NX:ooooooooooooooooo`WZ2P06
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`06
ooooo`04o`WZ2_ooooooooooo`WZ2PWooooo00?o2NX:o`000?l000000_l00008ooooo`04o`WZ2_oo
oooo2NX:o`WZ2PSooooo00?o2NX:ooooooooool00oooool2o`WZ2PCooooo0ol9jPX9ooooo`03o`WZ
2_oooooooooo00Gooooo0ol9jPYOooooo`03o`000?oooooooooo00Gooooo00?o2NX:ooooooooool0
5Oooool4o`WZ2P03o`000?oooooo2NX:00Cooooo00?o0000ooooooooool02_ooool00ol9jP[ooooo
ooooo`0=ooooo`03o`WZ2_oooooooooo00[ooooo1?l00009ooooo`03o`000?oooooooooo02_ooooo
002Dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool4o`WZ2P;ooooo1?l9
jPX3ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`05ooooo`03o`WZ2_oooooo2NX:00Wooooo00?o2NX:ooooool9jPX01oooool01Ol9jP[ooooooooo
oooooooo2NX:00Kooooo00?o2NX:ooooooooool01?ooool01?l9jP[oooooooooool9jPX8ooooo`?o
000000?o2NX:ooooooooool01oooool01?l9jP[oooooooooooooool2o`WZ2PGooooo00?o2NX:oooo
ooooool01oooool5o`WZ2PSooooo00?o2NX:ooooooooool01Oooool2o`WZ2VOooooo00Go0000oooo
ooooooooooooo`WZ2P0Cooooo`Go2NX:00Goooooo`WZ2_ooooooooooo`000002ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool2o`WZ2Q?ooooo00?o2NX:ooooooooool01_oo
ool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool9jPX00ol9jPX5ooooo`Ko2NX:2Oooool2o`WZ2PWooooo00?o
2NX:ooooool9jPX02?ooool01Ol9jP[ooooooooooooooooo2NX:00Kooooo00?o2NX:ooooooooool0
0oooool2o`WZ2P?ooooo00?o2NX:ooooooooool01_ooool01?l9jP[oooooooooool9jPX7ooooo`?o
00000_l9jPX:ooooo`03o`WZ2_oooooooooo00;o2NX:1oooool00ol9jP[oooooooooo`05ooooo`Go
2NX:2oooool00ol9jP[oooooooooo`03ooooo`;o2NX:HOooool00ol0003oooooooooo`06ooooo`03
o`WZ2_oooooooooo013ooooo1Ol9jPX01ooooooo2NX:oooooooooooo0000ooooool9jPX01?ooool0
0ol0003oooooooooo`06ooooo`Co2NX:4Oooool00ol9jP[oooooooooo`06ooooo`?o00003Oooool0
0ol0003oooooooooo`0[ooooo`00Toooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Cooooo0ol9jPX00ooooooo0000o`WZ2P03o`WZ2POooooo00?o2NX:ooooooooool00oooool01Ol9
jP[ooooooooooooooooo2NX:00Sooooo0_l9jPX9ooooo`03o`WZ2_oooooo2NX:00Oooooo00?o2NX:
ooooooooool00_ooool2o`WZ2PCooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooo`WZ2P05
ooooo`?o00000_ooool00ol9jP[oooooo`WZ2P08ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`07ooooo`?o2NX:2oooool00ol9jP[oooooooooo`02
ooooo`;o2NX:JOooool00ol0003oooooooooo`02ooooo`03o`WZ2_oooooooooo00_ooooo1Ol9jPX7
ooooo`04o`WZ2_oooooo2NX:o`0000;ooooo00?o2NX:ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`;o2NX:5_ooool01?l9jP[oooooooooooooool4o`00013ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo0ol9jPX3ooooo`Ko2NX:
1Oooool00ol9jP[oooooooooo`07ooooo`;o2NX:2Oooool00ol9jP[oooooo`WZ2P08ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`05o`WZ
2_ooooooooooooooool9jPX02Oooool00ol9jP[oooooo`WZ2P04ooooo`?o00000oooool2o`WZ2P[o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Go
oooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool00_l9jPYSooooo`03
o`000?oooooooooo00Kooooo00?o2NX:ooooooooool02oooool5o`WZ2POooooo00Ko2NX:ooooool9
jP[o0000ooooool9jPX3ooooo`03o`000?oooooooooo00Gooooo00?o2NX:ooooooooool05?ooool0
1?l9jP[oooooooooooooool4o`00013ooooo00?o0000ooooooooool0:oooool009?ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`09o`WZ2P03o`000?l9jP[ooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`04o`WZ2_ooooooooooo`WZ2PSooooo0_l9
jPX9ooooo`03o`WZ2_oooooo2NX:00Oooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00Kooooo0_l9jPX2ooooo`?o00001Oooool00ol9jP[oooooo`WZ
2P08ooooo`03o`WZ2_oooooooooo00Cooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00Gooooo0_l9
jPX2ooooo`03o`WZ2_oooooooooo00_ooooo0ol9jPYZooooo`03o`000?oooooooooo00?ooooo00?o
2NX:ooooooooool01_ooool5o`WZ2Pgooooo0_l9jPX01Ooooooo0000oooooooooooo2NX:00Cooooo
00?o0000ooooool9jPX00_l9jPXIooooo`03o`WZ2_l0003o000001?ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Co2NX:0_ooool4o`WZ2P03oooo
ool9jP[ooooo00Kooooo00?o2NX:ooooool9jPX02_ooool00ol9jP[oooooooooo`07ooooo`04o`WZ
2_ooooooooooo`WZ2POooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Gooooo00Co2NX:oooooooooooo2NX:2Oooool3o`WZ2P04ooooool0003o0000
o`0000Kooooo00?o2NX:ooooool9jPX02Oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00oooool2o`WZ2PCooooo00?o2NX:ooooooooool02oooool2
o`WZ2VCooooo00?o0000ooooooooool01oooool00ol9jP[oooooooooo`06ooooo`Go2NX:3Oooool2
o`WZ2P04ooooool0003oooooo`WZ2P?ooooo00Co0000oooooooooooooooo0ol9jPXHooooo`03o`WZ
2_l0003o000001Cooooo00?o0000ooooooooool0:oooool009?ooooo00?o0000ooooooooool07_oo
ool6o`WZ2POooooo00Go2NX:ooooooooooooooooo`WZ2P05ooooo`03o`WZ2_oooooooooo00Cooooo
00Co2NX:oooooooooooo2NX:2Oooool00ol9jP[oooooooooo`07ooooo`04o`WZ2_ooooooooooo`WZ
2PKooooo00?o2NX:ooooooooool01?ooool01Ol9jP[ooooooooooooooooo2NX:00Sooooo00Co2NX:
o`000?l0003o00002?ooool00ol9jP[oooooooooo`02o`WZ2PKooooo00?o2NX:ooooooooool01Ooo
ool2o`WZ2P03ooooool9jP[ooooo00Cooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo00Sooooo0ol9
jPY/ooooo`03o`000?oooooooooo00Gooooo00?o2NX:ooooool9jPX01Ol9jPXCooooo`03o`WZ2_oo
oooo000000;ooooo0_l9jPX2ooooo`?o2NX:6?ooool4o`0001Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Iooooo`04o`WZ2_l0003o2NX:o`WZ2P;ooooo1?l9jPX00ooooooo0000
ooooo`02ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooool9jPX02Oooool2o`WZ2PWooooo
00Co2NX:oooooooooooo2NX:1oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool01Oooool01?l9jP[oooooooooool9jPX:ooooo`?o00002Oooool00ol9
jP[oooooooooo`02o`WZ2POooooo00?o2NX:ooooooooool01?ooool2o`WZ2P?ooooo00?o2NX:oooo
ooooool00ol9jPX7ooooo`03o`WZ2_oooooooooo00Sooooo0_l9jPYUooooo`03o`000?oooooooooo
00Wooooo00?o2NX:ooooool9jPX01Ol9jPXCooooo`05o`WZ2_oooooo0000ooooool9jPX00oooool4
o`WZ2QOooooo1?l0000Gooooo`03o`000?oooooooooo02_ooooo002Cooooo`;o00006oooool4o`WZ
2P03o`000?oooooooooo00;ooooo00?o2NX:ooooooooool01Oooool01Ol9jP[ooooooooooooooooo
2NX:00Gooooo00?o2NX:ooooooooool01?ooool01?l9jP[oooooooooool9jPX9ooooo`;o2NX:2?oo
ool01Ol9jP[ooooooooooooooooo2NX:00Gooooo00?o2NX:ooooooooool01Oooool00ol9jP[ooooo
o`WZ2P07ooooo`?o00000_l9jPX9ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`07ooooo`;o2NX:0oooool2o`WZ2PKooooo00?o2NX:ooooooooool0
1_ooool2o`WZ2Voooooo00?o0000ooooooooool01Oooool00ol9jP[oooooooooo`0Hooooo`05o`WZ
2_ooooooooooo`000?ooool01?l9jPX00ooooooo0000ooooo`0Eooooo`?o00006_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo0ol9jPX00ooooooo2NX:o`WZ2P03o`WZ2PGo
oooo00Co2NX:o`000?oooooo2NX:2?ooool00ol9jP[oooooo`WZ2P09ooooo`;o2NX:2Oooool01Ol9
jP[ooooooooooooooooo2NX:00Kooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooool9jPX01oooool3o`000003ooooool9jP[o
oooo00Wooooo00Go2NX:ooooooooooooooooo`WZ2P07ooooo`03o`WZ2_oooooooooo00Kooooo0_l9
jPX01?oooooo2NX:o`WZ2_l9jPX:ooooo`03o`WZ2_oooooooooo00Kooooo0_l9jPYWooooo`03o`00
0?oooooooooo00Wooooo00?o2NX:ooooooooool06?ooool01?l9jP[oooooooooool00004o`WZ2P03
o`000?oooooooooo01Cooooo1?l0000Kooooo`03o`000?oooooooooo02_ooooo002Cooooo`03o`00
0?oooooo000001Cooooo1ol9jPX3ooooo`06o`000?ooooooooooo`WZ2_oooooo2NX:1oooool00ol9
jP[o0000ooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01Oooool2o`WZ
2PWooooo00?o2NX:ooooool9jPX02?ooool01Ol9jP[ooooooooooooooooo2NX:00Gooooo00?o2NX:
ooooooooool01_ooool2o`WZ2PCooooo0ol00003ooooo`03o`WZ2_oooooo2NX:00Sooooo00?o2NX:
ooooooooool00oooool2o`WZ2P?ooooo00?o2NX:ooooooooool02?ooool4o`WZ2PSooooo00?o2NX:
ooooooooool00oooool3o`WZ2W3ooooo00?o0000ooooooooool01_ooool00ol9jP[oooooooooo`0I
ooooo`07o`WZ2_oooooo2NX:o`000?l9jP[oooooo`WZ2P02ooooo`03o`000?oooooooooo017ooooo
0ol0000Mooooo`03o`000?oooooooooo00gooooo0_l0000Dooooo`Oo2NX:00Co0000oooooooooooo
2NX:1_ooool01?l9jP[o0000ooooool9jPX9ooooo`;o2NX:2Oooool00ol9jP[oooooo`WZ2P08oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`05o`WZ2_ooooooooooooooool9jPX02Oooool2o`WZ2P?ooooo1?l00004ooooo`;o2NX:2Oooool0
0ol9jP[oooooooooo`02ooooo`;o2NX:1Oooool00ol9jP[oooooooooo`08ooooo`;o2NX:3?ooool0
0ol9jP[oooooooooo`03ooooo`?o2NX:J?ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo01Wooooo0ol9jPX01Ol0003o2NX:oooooooooooo000001?ooooo0ol0000Oooooo`03o`000?oo
oooooooo02_ooooo002Cooooo`04o`000?ooooooooooo`0000gooooo1_l9jPX2ooooo`;o2NX:1_oo
ool01?l0003oooooooooool9jPX2ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:o`000?ooool0
0oooool01?l9jP[oooooooooool9jPX9ooooo`03o`WZ2_oooooooooo00Oooooo00Co2NX:oooooooo
oooo2NX:1oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool01_ooool2o`WZ2P04ooooool0003o0000o`0000Kooooo00?o2NX:ooooooooool00_l9jPX6
ooooo`03o`WZ2_oooooooooo00Cooooo00Go2NX:ooooooooooooooooo`WZ2P09ooooo`?o2NX:2_oo
ool01?l9jP[oooooooooooooool2o`WZ2W?ooooo00?o0000ooooooooool01oooool00ol9jP[ooooo
ooooo`0Fooooo`Co2NX:0_ooool01_l0003oooooooooool9jP[oooooo`00013ooooo0ol0000Poooo
o`03o`000?oooooooooo00gooooo00?o0000ooooool000003_ooool6o`WZ2PCooooo00?o2NX:oooo
ool000000_ooool00ol9jP[oooooooooo`04ooooo`04o`WZ2_oooooo0000o`WZ2PWooooo0_l9jPX9
ooooo`03o`WZ2_oooooo2NX:00Sooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00Go2NX:ooooooooooooooooo`WZ2P0:ooooo`04o`WZ2_l0
003o0000o`0000Sooooo00Co2NX:ooooool9jP[o2NX:1oooool00ol9jP[oooooooooo`04ooooo`;o
2NX:0oooool00ol9jP[oooooooooo`05ooooo`?o2NX:00?oooooo`WZ2_ooool02oooool01?l9jP[o
ooooooooooooool2o`WZ2V_ooooo00?o0000ooooooooool02oooool00ol9jP[oooooooooo`0Eoooo
o`Go2NX:00Koooooo`000?oooooo2NX:ooooool0000@ooooo`?o00008_ooool00ol0003ooooooooo
o`0[ooooo`00Toooool01Ol0003ooooooooooooooooo000000Sooooo1?l9jPX5ooooo`?o2NX:0_oo
ool00ol9jP[oooooooooo`03ooooo`04o`000?ooooooooooo`WZ2P?ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooo`000004ooooo`03o`WZ2_oooooo2NX:00Wooooo00?o2NX:ooooooooool0
1oooool01?l9jP[oooooooooool9jPX6ooooo`03o`WZ2_oooooooooo00Cooooo00Go2NX:oooooooo
ooooooooo`WZ2P08ooooo`?o00002Oooool01Ol9jP[ooooooooooooooooo2NX:00Kooooo00?o2NX:
ooooooooool01Oooool2o`WZ2P03ooooool9jP[ooooo00Kooooo0_l9jPX2ooooo`03o`WZ2_oooooo
oooo00[ooooo0_l9jPYeooooo`03o`000?oooooooooo00Oooooo00?o2NX:ooooooooool04oooool3
o`WZ2PCooooo00Co2NX:ooooool9jP[o00000_ooool00ol9jP[o0000ooooo`0<ooooo`?o00008ooo
ool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000Wooooo1ol9jPX7ooooo`03o`WZ
2_oooooo000000;ooooo00?o2NX:ooooooooool01Oooool00ol9jP[o0000o`WZ2P0:ooooo`03o`WZ
2_oooooooooo00Oooooo00Co2NX:oooooooooooo2NX:1oooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Oooool01?l9jP[oooooooooool9jPX8oooo
o`?o00002oooool01Ol9jP[ooooooooooooooooo2NX:00Oooooo00?o2NX:ooooooooool01Oooool0
1Ol9jP[ooooooooooooooooo2NX:00Cooooo0_l9jPX5ooooo`03o`WZ2_oooooooooo00_ooooo0_l9
jPY]ooooo`03o`000?oooooooooo00_ooooo00?o2NX:ooooooooool04_ooool3o`WZ2PGooooo0_l9
jPX01?l0003oooooo`WZ2_l0000=ooooo`?o00009Oooool00ol0003oooooooooo`0[ooooo`00Tooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo2NX:00Go2NX:1_ooool3o`WZ2PGooooo00?o
2NX:ooooooooool00oooool01?l0003oooooooooool9jPX3ooooo`03o`WZ2_oooooooooo00;ooooo
00Go2NX:ooooooooooooooooo`000003ooooo`03o`WZ2_oooooo2NX:00Wooooo0_l9jPX8ooooo`05
o`WZ2_ooooooooooooooool9jPX01Oooool00ol9jP[oooooooooo`05ooooo`04o`WZ2_oooooooooo
o`WZ2PGooooo0ol000000ooooooo2NX:o`WZ2P09ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`07ooooo`;o2NX:1Oooool2o`WZ2PCooooo00?o2NX:
ooooooooool01oooool3o`WZ2WKooooo00?o0000ooooooooool02Oooool00ol9jP[oooooooooo`0=
ooooo`Go2NX:2?ooool2o`WZ2P05o`000?ooooooooooo`WZ2_l000002_ooool3o`0002Kooooo00?o
0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000;ooooo1_l9jPX01?oooooo2NX:
o`WZ2_l9jPX;ooooo`05o`WZ2_l0003oooooooooool9jPX01oooool00ol9jP[oooooo`WZ2P09oooo
o`;o2NX:2Oooool01Ol9jP[ooooooooooooooooo2NX:00Kooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooool9jPX01Oooool3
o`0000;ooooo0_l9jPX:ooooo`05o`WZ2_ooooooooooooooool9jPX01oooool00ol9jP[ooooooooo
o`06ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo0_l9jPX7ooooo`03o`WZ2_oooooooooo00Sooooo
0ol9jPY^ooooo`03o`000?oooooooooo00gooooo00?o2NX:ooooooooool02oooool6o`WZ2PSooooo
0ol9jPX00ol0003o2NX:o`00000:ooooo`?o0000:?ooool00ol0003oooooooooo`0[ooooo`00Tooo
ool00ol0003oooooo`WZ2P04o`WZ2PSooooo1?l9jPX8ooooo`03o`WZ2_oooooooooo00?ooooo00?o
0000ooooool9jPX01?ooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool00000
0oooool00ol9jP[oooooo`WZ2P09ooooo`;o2NX:2?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooo`WZ2P02ooooo`?o0000
1?ooool00ol9jP[oooooo`WZ2P08ooooo`03o`WZ2_oooooooooo00?ooooo0_l9jPX3ooooo`03o`WZ
2_oooooooooo00Sooooo0ol9jPX2ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool3o`WZ2WWooooo00?o0000ooooooooool02_ooool00ol9jP[oooooooooo`06ooooo`Ko2NX:
3_ooool00ol9jP[oooooo`000002ooooo`03o`WZ2_oooooooooo00Gooooo0ol0000Yooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooool9jPX01?l9jPX3ooooo`Co2NX:00?oooooo`WZ2_ooool0
2oooool01?l9jP[o0000ooooool9jPX9ooooo`;o2NX:2Oooool00ol9jP[oooooo`WZ2P08ooooo`05
o`WZ2_ooooooooooooooool9jPX01_ooool00ol9jP[oooooooooo`04ooooo`05o`WZ2_oooooooooo
ooooool9jPX02?ooool00ol9jP[oooooo`WZ2P02ooooo`?o00001Oooool00ol9jP[oooooo`WZ2P09
ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPX5ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:
ooooool9jPX00_l9jPX9ooooo`03o`WZ2_oooooooooo00Gooooo0ol9jPYaooooo`03o`000?oooooo
oooo00gooooo00?o2NX:ooooooooool01_ooool5o`WZ2Poooooo0_l9jPX01?oooooo0000o`WZ2_l0
0006ooooo`?o0000:oooool00ol0003oooooooooo`0[ooooo`00Toooool00ol0003o2NX:ooooo`04
ooooo`03o`000?oooooooooo00?ooooo1?l9jPX6ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00_ooool00ol0003oooooo`WZ2P05ooooo`05o`WZ2_ooooooooooooooool9jPX01?oo
ool01?l0003oooooooooooooool2o`WZ2PWooooo00?o2NX:ooooool9jPX01oooool00ol9jP[ooooo
ooooo`03ooooo`05o`WZ2_ooooooooooooooool9jPX02Oooool01?l9jP[o0000o`000?l00007oooo
o`03o`WZ2_oooooooooo00;o2NX:1_ooool00ol9jP[oooooooooo`05ooooo`04o`WZ2_oooooooooo
o`WZ2P[ooooo00?o2NX:ooooooooool00_l9jPX7ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPYl
ooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool01_l9jPXEooooo`05o`WZ2_oooooo
0000ooooool000001?ooool3o`0002_ooooo00?o0000ooooooooool03Oooool2o`WZ2P03o`000?oo
oooooooo00;ooooo00Co0000o`WZ2_l9jP[o2NX:1_ooool01?l9jP[oooooooooool9jPX8ooooo`04
o`WZ2_ooooooooooo`WZ2PWooooo0_l9jPX00ol0003oooooooooo`06ooooo`03o`WZ2_oooooo2NX:
00Sooooo00Go2NX:ooooooooooooooooo`WZ2P06ooooo`03o`WZ2_oooooooooo00Cooooo00Go2NX:
ooooooooooooooooo`WZ2P09ooooo`04o`WZ2_l0003o0000o`0000Sooooo00?o2NX:ooooooooool0
0_l9jPX7ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`08ooooo`;o2NX:2oooool00ol9jP[oooooooooo`03ooooo`;o2NX:M?ooool00ol0003ooooo
ooooo`0=ooooo`03o`WZ2_oooooo2NX:00Ko2NX:5Oooool01Ol9jP[oooooo`000?oooooo000000?o
oooo0ol0000^ooooo`03o`000?oooooooooo02_ooooo002Aooooo`;o2NX:00?o0000ooooooooool0
1Oooool00ol0003oooooo`WZ2P02o`WZ2P?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`04o`WZ2_ooooooooooo`0000;ooooo00?o2NX:ooooooooool01?ooool01?l9jP[o
ooooooooool9jPX4ooooo`04o`000?ooooooooooooooo`;o2NX:2Oooool01?l9jP[oooooooooool9
jPX6ooooo`03o`WZ2_oooooooooo00Cooooo00Co2NX:oooooooooooo2NX:1oooool3o`000003o`WZ
2_oooooooooo00Oooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Kooooo0ol9jPX;ooooo`;o2NX:2oooool3o`WZ2Wgooooo00?o0000ooooooooool0
3?ooool00ol9jP[oooooooooo`0Kooooo`05o`WZ2_oooooo0000o`000?ooool00ol0000^ooooo`03
o`000?oooooooooo00_ooooo0_l9jPX2ooooo`03o`000?oooooooooo00?o2NX:00?o0000oooooooo
ool01_ooool01?l9jP[oooooooooool9jPX8ooooo`04o`000?l9jP[oooooo`WZ2PWooooo0_l9jPX0
0ol0003oooooooooo`06ooooo`04o`WZ2_ooooooooooo`WZ2POooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00Co2NX:oooooooooooo2NX:
1oooool3o`0000;o2NX:2Oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool01Oooool01Ol9jP[ooooooooooooooooo2NX:00Wooooo0ol9jPX>ooooo`?o
2NX:MOooool00ol0003oooooooooo`0?ooooo`03o`WZ2_oooooooooo01_ooooo00?o2NX:ooooool0
00001?l0000`ooooo`03o`000?oooooooooo02cooooo002>ooooo`?o2NX:0_ooool00ol0003ooooo
ooooo`04ooooo`;o2NX:00?o0000ooooooooool01Oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00?ooooo00Co2NX:oooooooooooo00000_ooool00ol9jP[oooooooooo`04ooooo`04
o`WZ2_ooooooooooo`WZ2PCooooo00Co0000oooooooooooooooo0_l9jPX8ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooo
2NX:00Cooooo0ol00002ooooo`03o`WZ2_oooooo2NX:00Sooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Sooooo0_l9jPX9ooooo`;o2NX:2_ooool2
o`WZ2X3ooooo00?o0000ooooooooool03?ooool00ol9jP[oooooooooo`0Looooo`04o`WZ2_l0003o
0000o`00037ooooo00?o0000ooooooooool02?ooool3o`WZ2PCooooo00?o0000o`WZ2_l9jPX01?oo
ool00ol0003oooooooooo`05ooooo`04o`WZ2_ooooooooooo`WZ2PSooooo00Co0000o`WZ2_oooooo
2NX:2Oooool2o`WZ2P03ooooool0003ooooo00Kooooo00Co2NX:oooooooooooo2NX:1oooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01_ooool00ol9
jP[oooooo`WZ2P03ooooo`Co00000oooool00ol9jP[oooooo`WZ2P08ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`06ooooo`;o2NX:00?oooooo`WZ
2_ooool01_ooool2o`WZ2P;ooooo00?o2NX:ooooooooool02Oooool3o`WZ2WSooooo00?o0000oooo
ooooool03oooool00ol9jP[oooooooooo`0Kooooo`04o`WZ2_l0003o0000o`0003?ooooo00?o0000
ooooooooool0;?ooool008_ooooo0ol9jPX5ooooo`03o`000?oooooooooo00;ooooo0_l9jPX3oooo
o`;o000000?oooooo`WZ2_ooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooool000000_ooool00ol9jP[oooooooooo`05ooooo`;o2NX:1_ooool01_l0
003oooooooooool9jP[oooooo`WZ2POooooo00?o2NX:ooooooooool00oooool01Ol9jP[ooooooooo
oooooooo2NX:00Wooooo0_l9jPX01?oooooo0000o`000?l00005ooooo`03o`WZ2_oooooooooo00;o
2NX:1_ooool00ol9jP[oooooooooo`04ooooo`05o`WZ2_ooooooooooooooool9jPX02_ooool00ol9
jP[oooooo`WZ2P05ooooo`?o2NX:00?oooooo`WZ2_ooool01oooool2o`WZ2X;ooooo00?o0000oooo
ooooool03Oooool00ol9jP[oooooooooo`0Hooooo`?o000000?oooooo`WZ2_l00000<Oooool00ol0
003oooooooooo`05ooooo`Co2NX:1Oooool2o`WZ2P03o`000?oooooooooo00Cooooo00?o2NX:o`00
0?ooool01Oooool01?l9jP[oooooooooool9jPX8ooooo`04o`000?l9jP[oooooo`WZ2PWooooo00Co
2NX:ooooool9jP[o00001oooool01Ol9jP[ooooooooooooooooo2NX:00Kooooo00?o2NX:oooooooo
ool01?ooool01Ol9jP[ooooooooooooooooo2NX:00Wooooo0_l9jPX3o`0000Oooooo00Co2NX:oooo
oooooooo2NX:2?ooool00ol9jP[oooooooooo`02ooooo`;o2NX:1?ooool00ol9jP[oooooooooo`08
ooooo`;o2NX:1Oooool2o`WZ2PGooooo00?o2NX:ooooooooool01_ooool2o`WZ2W_ooooo00?o0000
ooooooooool03oooool00ol9jP[oooooooooo`0Iooooo`?o000000?o2NX:ooooool00000<oooool0
0ol0003oooooooooo`0/ooooo`00R?ooool3o`WZ2POooooo00?o2NX:o`000?ooool00ol9jPX7oooo
o`03o`000?l9jP[ooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`05oooo
o`04o`WZ2_l0003oooooo`WZ2PWooooo00?o2NX:ooooooooool01?ooool01?l0003oooooooooool9
jPX2ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool01?l9jP[ooooooooo
ool9jPX9ooooo`?o00002?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01Oooool2o`WZ2P03ooooool9jP[ooooo00Wooooo00?o2NX:ooooooooool0
0_l9jPX00ooooooo2NX:o`WZ2P04ooooo`03o`WZ2_oooooooooo00?ooooo0ol9jPZ3ooooo`03o`00
0?oooooooooo00kooooo00?o2NX:ooooooooool05?ooool4o`0000Gooooo00?o2NX:ooooooooool0
;oooool00ol0003oooooooooo`02ooooo`?o2NX:1_ooool3o`WZ2P;ooooo00?o0000ooooooooool0
1?ooool00ol9jP[oooooo`000006ooooo`03o`WZ2_oooooo2NX:00Sooooo00Co0000ooooool9jP[o
2NX:2Oooool01Ol9jP[oooooo`WZ2_oooooo000000Kooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00Co2NX:oooooooooooo2NX:2?ooool3
o`0000[ooooo00Go2NX:ooooooooooooooooo`WZ2P07ooooo`03o`WZ2_oooooooooo00Cooooo0_l9
jPX2ooooo`03o`WZ2_oooooooooo00Wooooo0_l9jPX2ooooo`;o2NX:1oooool00ol9jP[ooooooooo
o`03ooooo`?o2NX:O?ooool00ol0003oooooooooo`0Aooooo`03o`WZ2_oooooooooo01Cooooo1?l0
0004ooooo`03o`WZ2_l0003ooooo037ooooo00?o0000ooooooooool0;Oooool008Gooooo0ol9jPX:
ooooo`03o`WZ2_l0003o2NX:00_ooooo00?o0000ooooooooool00oooool01Ol9jP[ooooooooooooo
oooo2NX:00Oooooo00Co2NX:o`000?oooooo2NX:2Oooool00ol9jP[oooooooooo`05ooooo`03o`00
0?oooooo2NX:00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`05ooooo`03o`WZ
2_oooooo2NX:00Kooooo0ol000000ooooooo2NX:o`WZ2P08ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`07ooooo`;o2NX:2_ooool01?l9jP[ooooo
ooooooooool2o`WZ2PKooooo00?o2NX:ooooooooool00ol9jPZ6ooooo`03o`000?oooooooooo00ko
oooo00?o2NX:ooooooooool04Oooool3o`0000Wooooo00?o0000o`WZ2_ooool0;_ooool00ol0003o
ooooooooo`03o`WZ2PKooooo0ol9jPX2ooooo`04o`WZ2_ooooooooooo`0000Kooooo00Co2NX:oooo
oooooooo00001_ooool2o`WZ2PSooooo00Co0000ooooool9jP[o2NX:2Oooool01Ol9jP[oooooo`WZ
2_oooooo000000Kooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00Kooooo00?o2NX:ooooool9jPX01Oooool3o`0000;ooooo0_l9jPX9ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`06ooooo`04o`WZ
2_ooooooooooo`WZ2P_ooooo0ol9jPX9ooooo`03o`WZ2_oooooooooo00?o2NX:Ooooool00ol0003o
ooooooooo`0Aooooo`03o`WZ2_oooooooooo013ooooo1?l00009ooooo`03o`WZ2_oooooooooo033o
oooo00?o0000ooooooooool0;Oooool008?ooooo0_l9jPX:ooooo`?o2NX:00?oooooo`000?l9jPX0
2oooool00ol9jP[o0000ooooo`03ooooo`05o`WZ2_ooooooooooooooool9jPX02?ooool00ol9jP[o
ooooo`WZ2P09ooooo`;o2NX:1_ooool00ol0003oooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooo`WZ2P03ooooo`?o00001?ooool00ol9jP[o
ooooo`WZ2P07ooooo`03o`WZ2_oooooooooo00Cooooo00Go2NX:ooooooooooooooooo`WZ2P0:oooo
o`;o2NX:2_ooool3o`WZ2PWooooo0_l9jPZ9ooooo`03o`000?oooooooooo00oooooo00?o2NX:oooo
ooooool03Oooool3o`0000cooooo00?o0000ooooooooool0;_ooool00ol0003o2NX:o`WZ2P06oooo
o`?o2NX:1_ooool2o`WZ2P03o`000?oooooooooo00Cooooo00Go2NX:ooooooooooooooooo`000005
ooooo`;o2NX:2?ooool01?l0003oooooo`WZ2_l9jPX9ooooo`05o`WZ2_ooooooooooo`WZ2_l00000
1_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
1_ooool00ol9jP[oooooo`WZ2P02ooooo`?o00001Oooool00ol9jP[oooooo`WZ2P08ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`07ooooo`03o`WZ
2_oooooo2NX:00Wooooo0ol9jPX<ooooo`;o2NX:P_ooool00ol0003oooooooooo`0Aooooo`03o`WZ
2_oooooooooo00gooooo0ol0000=ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
;Oooool0083ooooo0ol9jPX:ooooo`;o2NX:1?ooool01?l0003oooooo`WZ2_l9jPX9ooooo`04o`WZ
2_oooooo0000o`0000?ooooo00Co2NX:oooooooooooo2NX:2?ooool00ol0003o2NX:o`WZ2P09oooo
o`03o`WZ2_oooooo2NX:00Gooooo00?o0000ooooool9jPX01?ooool00ol9jP[oooooooooo`02oooo
o`03o`WZ2_oooooooooo00Kooooo0_l9jPX3o`0000Oooooo00Co2NX:oooooooooooo2NX:1_ooool0
0ol9jP[oooooooooo`05ooooo`04o`WZ2_ooooooooooo`WZ2P[ooooo00Co2NX:ooooool9jP[o2NX:
1oooool2o`WZ2PSooooo0ol9jPZ;ooooo`03o`000?oooooooooo00oooooo00?o2NX:ooooooooool0
2Oooool4o`0000oooooo00?o0000ooooooooool0;?ooool3o`WZ2PGooooo0ol9jPX7ooooo`05o`WZ
2_ooooooooooooooool000001_ooool00ol9jP[oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o2NX:ooooooooool01_ooool01Ol0003oooooo`WZ2_oooooo2NX:00Sooooo00Ko2NX:oooo
ooooooooooooo`WZ2_l00005ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`07ooooo`04o`WZ2_l0003o0000o`0000Sooooo00Co2NX:oooooooooooo
2NX:1oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool02?ooool2o`WZ2POooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00Oooooo0ol9jPZ4ooooo`03
o`000?oooooooooo017ooooo00?o2NX:ooooooooool02Oooool4o`00013ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0^ooooo`00OOooool3o`WZ2PSooooo00?o2NX:ooooooooool0
0_l9jPX6ooooo`03o`000?oooooooooo00;o2NX:2?ooool01Ol9jP[ooooooooooooooooo000000?o
oooo00?o2NX:ooooool9jPX02?ooool00ol0003o2NX:o`WZ2P09ooooo`04o`WZ2_ooooooooooo`WZ
2PGooooo00?o0000o`WZ2_ooool01?ooool01Ol9jP[ooooooooooooooooo2NX:00Oooooo0ol0000:
ooooo`05o`WZ2_ooooooooooooooool9jPX01Oooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oo
oooo2NX:00[ooooo00Co2NX:oooooooooooooooo0_l9jPX3ooooo`;o2NX:00?oooooo`WZ2_ooool0
1Oooool2o`WZ2Xkooooo00?o0000ooooooooool04?ooool00ol9jP[oooooooooo`05ooooo`?o0000
4oooool00ol0003oooooooooo`0Yooooo`?o2NX:00?oooooo`000?ooool00oooool3o`WZ2PWooooo
00Go2NX:ooooooooooooooooo`000006ooooo`03o`WZ2_oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol9jP[oooooooooo`06ooooo`05o`000?oooooo2NX:ooooool9jPX02?ooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool01?l9
jP[oooooooooool9jPX8ooooo`?o000000?o2NX:ooooooooool02?ooool01Ol9jP[ooooooooooooo
oooo2NX:00Kooooo00?o2NX:ooooooooool01Oooool01Ol9jP[ooooooooooooooooo2NX:00_ooooo
0_l9jPX4ooooo`;o2NX:1?ooool00ol9jP[oooooooooo`04ooooo`?o2NX:Qoooool00ol0003ooooo
ooooo`0Booooo`03o`WZ2_oooooooooo00Gooooo0ol0000Dooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0;_ooool007Wooooo1?l9jPX;ooooo`?o2NX:2?ooool00ol0003ooooooooo
o`02o`WZ2PSooooo00?o2NX:ooooooooool00_ooool01_l0003oooooooooool9jP[oooooo`WZ2PSo
oooo00?o0000ooooool9jPX02Oooool01?l9jP[oooooooooool9jPX5ooooo`03o`000?l9jP[ooooo
00Gooooo00Co2NX:oooooooooooo2NX:1?ooool3o`0000;ooooo0_l9jPX9ooooo`03o`WZ2_oooooo
oooo00;ooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo00Oooooo0ol9jPX9ooooo`03o`WZ2_oooooo
oooo00?ooooo0ol9jPX3ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPZ@ooooo`03o`000?oooooo
oooo013ooooo00Co2NX:oooooooooooooooo1?l0000Fooooo`03o`000?oooooooooo02Gooooo1?l9
jPX4ooooo`03o`000?oooooo2NX:00;o2NX:0oooool00ol9jP[oooooooooo`06ooooo`06o`WZ2_oo
ooooooooooooool0003o2NX:1Oooool00ol9jP[oooooooooo`04ooooo`05o`000?oooooooooooooo
ool9jPX02?ooool00ol0003oooooo`WZ2P02ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[o0000ooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:oooo
ool9jPX01?ooool4o`0000?ooooo0_l9jPX9ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`06ooooo`;o2NX:00?oooooo`WZ2_ooool02_ooool00ol9
jP[oooooo`WZ2P03o`WZ2PKooooo00?o2NX:ooooooooool00_ooool2o`WZ2X[ooooo00?o0000oooo
ooooool04_ooool01?l9jP[oooooooooooooool4o`0001Oooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0^ooooo`00M_ooool3o`WZ2Pcooooo0ol9jPX2ooooo`03o`WZ2_oooooo2NX:
00Oooooo00Co0000ooooool9jP[ooooo0_l9jPX6ooooo`03o`WZ2_oooooooooo00?ooooo00?o0000
ooooooooool00_l9jPX8ooooo`04o`000?oooooo2NX:o`WZ2POooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Kooooo00Co2NX:ooooool9jP[ooooo
0ol00005ooooo`04o`WZ2_oooooo2NX:o`WZ2PKooooo00?o2NX:ooooooooool01Oooool01?l9jP[o
ooooooooool9jPX:ooooo`03o`WZ2_oooooo2NX:00Sooooo00?o2NX:ooooooooool00_ooool2o`WZ
2POooooo0ol9jPZBooooo`03o`000?oooooooooo013ooooo00Co2NX:o`000?l0003o00006oooool0
0ol0003oooooooooo`0Qooooo`?o2NX:1oooool3o`WZ2POooooo00?o2NX:ooooooooool01Oooool0
0ol9jP[oooooooooo`02ooooo`03o`000?l9jP[o2NX:00?ooooo00?o2NX:ooooooooool01Oooool0
0ol0003oooooooooo`02o`WZ2POooooo00?o0000ooooool9jPX00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00Go2NX:ooooooooooooooooo`WZ2P09ooooo`;o2NX:00Co
ooooo`000?l0003o00001oooool00ol9jP[oooooo`WZ2P08ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`08ooooo`;o2NX:2oooool3o`WZ2P_ooooo
0ol9jPZ<ooooo`03o`000?oooooooooo01;ooooo00Co2NX:o`000?l0003o00007?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo02oooooo001cooooo`?o2NX:1oooool00ol9jP[ooooo
ooooo`02ooooo`?o2NX:1_ooool2o`WZ2POooooo00?o0000ooooool9jPX00oooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00Co0000ooooool9jP[o2NX:2?ooool01Ol0003o
2NX:oooooooooooo2NX:00Kooooo00?o2NX:ooooooooool00oooool01_l9jP[ooooooooooooooooo
2NX:o`0000Sooooo0ol00008ooooo`05o`WZ2_ooooooooooooooool9jPX01Oooool00ol9jP[ooooo
ooooo`06ooooo`03o`WZ2_oooooo2NX:00[ooooo00?o2NX:ooooooooool00_l9jPX7ooooo`04o`WZ
2_oooooo2NX:o`WZ2PKooooo0ol9jPZEooooo`03o`000?oooooooooo00kooooo0ol000000ol9jP[o
ooooooooo`0Kooooo`03o`000?oooooooooo01kooooo0ol9jPX7ooooo`?o2NX:00?o0000oooooooo
ool01Oooool01?l9jP[oooooooooool9jPX6ooooo`03o`WZ2_oooooooooo00;ooooo00Co0000oooo
oooooooo2NX:0_ooool00ol9jP[oooooooooo`06ooooo`04o`000?oooooo2NX:o`WZ2POooooo00?o
0000ooooool9jPX00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00Co
2NX:oooooooooooo2NX:2Oooool3o`0000[ooooo00Co2NX:oooooooooooo2NX:1oooool00ol9jP[o
ooooooooo`04ooooo`05o`WZ2_ooooooooooooooool9jPX02oooool2o`WZ2PWooooo0_l9jPX;oooo
o`;o2NX:Soooool00ol0003oooooooooo`0@ooooo`?o000000?o2NX:ooooooooool07?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo001`ooooo`?o2NX:2oooool4o`WZ2P[o
oooo0_l9jPX6ooooo`03o`000?oooooo2NX:00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`05ooooo`03o`000?oooooo2NX:00Sooooo00Go0000o`WZ2_ooooooooooo`WZ2P06oooo
o`03o`WZ2_oooooooooo00Cooooo0_l9jPX00ooooooo2NX:o`000005ooooo`?o000000?o2NX:oooo
ool9jPX02?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool01oooool2o`WZ2P[ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`04oooo
o`;o2NX:1_ooool2o`WZ2YOooooo00?o0000ooooooooool02oooool4o`00027ooooo00?o0000oooo
ooooool06oooool3o`WZ2POooooo1?l9jPX2ooooo`03o`000?oooooooooo00Gooooo00Go2NX:oooo
ooooooooooooo`WZ2P05ooooo`03o`WZ2_oooooooooo00;ooooo00Co0000oooooooooooo2NX:0_oo
ool00ol9jP[oooooooooo`07ooooo`04o`000?l9jP[oooooo`WZ2PKooooo00?o0000ooooool9jPX0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00Co0000o`WZ2_oooooo
2NX:1_ooool3o`000004ooooool9jP[oooooo`WZ2PWooooo00Go2NX:ooooooooooooooooo`WZ2P06
ooooo`03o`WZ2_oooooooooo00Gooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:
ooooool9jPX01_ooool2o`WZ2P;ooooo00?o2NX:ooooooooool01_ooool2o`WZ2Y7ooooo00?o0000
ooooooooool03?ooool4o`0002;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0_
ooooo`00K_ooool2o`WZ2Pgooooo1?l9jPX;ooooo`03o`WZ2_oooooo2NX:00Gooooo00?o0000oooo
ool9jPX01?ooool2o`WZ2P?ooooo00?o2NX:ooooooooool01_ooool00ol0003o2NX:o`WZ2P07oooo
o`03o`000?l9jP[ooooo00;ooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo00Kooooo0_l9jPX00ol0
003oooooooooo`03o`0000?ooooo00Co2NX:oooooooooooo2NX:1oooool00ol9jP[oooooooooo`03
ooooo`05o`WZ2_ooooooooooooooool9jPX02_ooool2o`WZ2PWooooo00?o2NX:ooooooooool00ooo
ool2o`WZ2P?ooooo0_l9jPX4ooooo`?o2NX:VOooool00ol0003oooooooooo`08ooooo`?o00009Ooo
ool00ol0003oooooooooo`0Hooooo`?o2NX:2?ooool2o`WZ2PCooooo0_l9jPX8ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`04o`000?oo
ooooooooooooo`?o2NX:2_ooool01?l0003oooooooooool9jPX5ooooo`03o`000?oooooo2NX:00Go
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`04ooooo`04o`000?l9jP[oooooo`WZ
2P?ooooo0ol00004ooooo`03o`WZ2_oooooo2NX:00Wooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooool9jPX02_ooool00ol9
jP[oooooooooo`03o`WZ2P;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`?o2NX:Toooool00ol0003oooooooooo`09ooooo`?o00009_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo033ooooo001/ooooo`;o2NX:3Oooool2o`WZ2PCooooo0_l9jPX9ooooo`03
o`WZ2_oooooo2NX:00Gooooo00?o0000ooooool9jPX01_ooool01?l9jP[oooooooooool9jPX9oooo
o`03o`000?l9jP[ooooo00Kooooo00?o0000o`WZ2_ooool01?ooool01Ol9jP[ooooooooooooooooo
2NX:00Sooooo0_l9jPX3o`0000Kooooo00Co2NX:oooooooooooo2NX:1oooool00ol9jP[ooooooooo
o`04ooooo`;o2NX:00?oooooo`WZ2_ooool02Oooool00ol9jP[oooooo`WZ2P08ooooo`03o`WZ2_oo
oooooooo00Kooooo0_l9jPX4ooooo`;o2NX:W?ooool00ol0003oooooooooo`05ooooo`?o0000:?oo
ool00ol0003oooooooooo`0Eooooo`?o2NX:2?ooool3o`WZ2PGooooo00Co2NX:ooooool0003o2NX:
1oooool00ol9jP[oooooooooo`03ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool00ol0003o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Sooooo00Co2NX:o`000?oooooo2NX:1Oooool00ol0
003oooooo`WZ2P06ooooo`05o`WZ2_ooooooooooooooool9jPX01oooool00ol0003o2NX:o`WZ2P03
o`0000Oooooo00Co2NX:oooooooooooo2NX:2?ooool00ol9jP[oooooooooo`03ooooo`;o2NX:0ooo
ool00ol9jP[oooooooooo`08ooooo`;o2NX:2oooool00ol9jP[oooooooooo`02ooooo`;o2NX:2?oo
ool3o`WZ2YKooooo00?o0000ooooooooool01Oooool4o`0002Wooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0`ooooo`00JOooool3o`WZ2POooooo0_l9jPX3ooooo`?o2NX:1oooool0
0ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00;o2NX:0oooool00ol0003oooooo`WZ2P07
ooooo`03o`WZ2_oooooo2NX:00Wooooo00Co2NX:o`000?l9jP[o2NX:1?ooool00ol0003oooooo`WZ
2P05ooooo`05o`WZ2_ooooooooooooooool9jPX01oooool3o`000003ooooool0003ooooo00Kooooo
00Co2NX:oooooooooooooooo0_l9jPX5ooooo`03o`WZ2_oooooooooo00Kooooo0_l9jPX:ooooo`03
o`WZ2_oooooooooo00?o2NX:1_ooool00ol9jP[oooooooooo`03ooooo`;o2NX:1?ooool2o`WZ2Yko
oooo00?o0000ooooooooool00_ooool3o`0002_ooooo00?o0000ooooooooool04_ooool3o`WZ2PSo
oooo0ol9jPX8ooooo`04o`WZ2_l0003oooooo`WZ2POooooo00?o2NX:ooooooooool01?ooool01?l9
jP[oooooooooool9jPX4ooooo`03o`000?oooooooooo00?ooooo00?o2NX:ooooooooool02?ooool0
1Ol9jP[oooooo`000?oooooo2NX:00Cooooo00?o0000ooooool9jPX01_ooool01?l9jP[ooooooooo
ool9jPX7ooooo`Co000000?o2NX:ooooooooool01oooool01Ol9jP[ooooooooooooooooo2NX:00Oo
oooo00?o2NX:ooooooooool01Oooool01?l9jP[oooooooooool9jPX;ooooo`?o2NX:2Oooool00ol9
jP[oooooooooo`02o`WZ2PSooooo0_l9jPZIooooo`03o`000?oooooooooo00;ooooo0ol0000]oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<Oooool006Gooooo1?l9jPX;ooooo`Co
2NX:2_ooool2o`WZ2PSooooo00?o2NX:ooooooooool00_ooool01_l9jP[oooooooooool0003ooooo
o`WZ2PSooooo0_l9jPX8ooooo`06o`WZ2_ooooooooooo`000?oooooo2NX:0oooool00ol0003ooooo
o`WZ2P06ooooo`04o`WZ2_ooooooooooo`WZ2PCooooo0ol00002ooooo`?o2NX:1oooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01oooool2o`WZ2PWo
oooo00?o2NX:ooooooooool00oooool2o`WZ2PCooooo00Co2NX:oooooooooooooooo0_l9jPX3oooo
o`?o2NX:X?ooool00ol0003oooooo`000002o`0002kooooo00?o0000ooooooooool03oooool3o`WZ
2PSooooo0ol9jPX2ooooo`03o`WZ2_oooooooooo00Kooooo00Co2NX:oooooooooooooooo0_l9jPX5
ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooool9jPX01?ooool00ol0003oooooooooo`03
ooooo`;o2NX:2Oooool01_l9jP[oooooooooool0003oooooo`WZ2P?ooooo00?o0000ooooool9jPX0
1oooool00ol9jP[oooooo`WZ2P04ooooo`?o000000Koooooo`000?oooooo2NX:ooooool9jPX8oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`06oooo
o`03o`WZ2_oooooo2NX:00_ooooo00Co2NX:oooooooooooo2NX:2?ooool3o`WZ2POooooo0ol9jPZK
ooooo`03o`000?oooooo000000;o0000<?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo03;ooooo001Rooooo`?o2NX:3?ooool3o`WZ2P03ooooool9jP[ooooo00_ooooo00?o2NX:oooo
ool9jPX01oooool00ol9jP[oooooooooo`02ooooo`06o`WZ2_ooooooooooooooool0003o2NX:2Ooo
ool00ol9jP[oooooooooo`06ooooo`07o`WZ2_ooooooooooooooool0003oooooo`WZ2P02ooooo`03
o`000?oooooo2NX:00Oooooo0ol9jPX01?oooooo0000o`000?l00005ooooo`04o`WZ2_oooooooooo
o`WZ2PKooooo00?o2NX:ooooooooool01?ooool01Ol9jP[ooooooooooooooooo2NX:00[ooooo0_l9
jPX8ooooo`03o`WZ2_oooooooooo00Gooooo00Ko2NX:ooooooooooooooooo`WZ2_ooool2o`WZ2P;o
oooo0ol9jPZSooooo`;o0000<Oooool00ol0003oooooooooo`0<ooooo`?o2NX:2?ooool3o`WZ2PGo
oooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool01_ooool2o`WZ2PGooooo00?o0000ooooooooool00_ooool01?l9jP[o
ooooo`WZ2_l9jPX7ooooo`07o`WZ2_ooooooooooooooool0003oooooo`WZ2P02ooooo`03o`000?oo
oooo2NX:00Sooooo0_l9jPX01?oooooo0000o`000?l00005ooooo`05o`000?l9jP[oooooooooool9
jPX01oooool00ol9jP[oooooooooo`03ooooo`;o2NX:1?ooool00ol9jP[oooooooooo`07ooooo`;o
2NX:2oooool01?l9jP[oooooooooooooool2o`WZ2PGooooo0_l9jPX6ooooo`?o2NX:W_ooool2o`00
03?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0booooo`00Goooool3o`WZ2POo
oooo00?o2NX:ooooooooool00_ooool3o`WZ2PGooooo0ol9jPX9ooooo`04o`WZ2_ooooooooooo`WZ
2PKooooo00?o2NX:ooooooooool00oooool2o`WZ2P03ooooool0003o2NX:00Sooooo00?o2NX:oooo
ool9jPX01oooool00ol9jP[oooooooooo`02ooooo`06o`000?l9jP[oooooooooool0003o2NX:2Ooo
ool3o`0000Sooooo00Go2NX:oooooooooooo0000o`WZ2P05ooooo`03o`WZ2_oooooooooo00Gooooo
0_l9jPX00ooooooo2NX:ooooo`09ooooo`04o`WZ2_oooooo2NX:o`WZ2POooooo00?o2NX:oooooooo
ool01Oooool00ol9jP[oooooooooo`02o`WZ2P;ooooo0_l9jPZVooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02_ooool2o`WZ2PWooooo0_l9jPX7ooooo`03o`WZ2_oooooo2NX:00Ko
oooo00?o0000o`WZ2_ooool01Oooool01Ol9jP[ooooooooooooooooo2NX:00Wooooo00?o2NX:oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX01_ooool0
0ol9jP[oooooooooo`02ooooo`07o`000?oooooo2NX:ooooool0003oooooo`WZ2P08ooooo`?o0000
2?ooool00ol0003o2NX:ooooo`02ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool0
1?ooool01Ol9jP[ooooooooooooooooo2NX:00[ooooo0_l9jPX:ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_l9jPX00ooooooo2NX:ooooo`03ooooo`;o2NX:XOooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<oooool005cooooo
0ol9jPX;ooooo`04o`WZ2_oooooo2NX:o`WZ2P[ooooo00?o2NX:ooooooooool01oooool01Ol9jP[o
oooooooooooooooo2NX:00Gooooo00?o2NX:ooooooooool01Oooool00ol9jP[o0000o`WZ2P08oooo
o`04o`WZ2_ooooooooooo`WZ2PKooooo00?o2NX:ooooooooool00oooool01Ol0003o2NX:o`WZ2_l0
003o2NX:00Kooooo0ol000000ooooooo2NX:o`WZ2P08ooooo`06o`WZ2_ooooooooooo`000?oooooo
2NX:1?ooool00ol9jP[oooooooooo`07ooooo`;o2NX:2_ooool01Ol9jP[ooooooooooooooooo2NX:
00Kooooo00?o2NX:ooooooooool01_ooool2o`WZ2P04ooooool9jP[o2NX:o`WZ2ZSooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`?o2NX:2?ooool3o`WZ2PWooooo00Co2NX:
oooooooooooo2NX:1Oooool00ol0003o2NX:ooooo`05ooooo`05o`WZ2_ooooooooooooooool9jPX0
2Oooool2o`WZ2PCooooo00?o0000ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Ko
oooo00?o2NX:ooooooooool00oooool01_l0003oooooo`WZ2_l0003oooooo`WZ2PGooooo0ol00000
0ooooooo2NX:o`WZ2P08ooooo`03o`000?l9jP[ooooo00;ooooo00?o2NX:ooooooooool01Oooool0
0ol9jP[oooooooooo`05ooooo`04o`WZ2_ooooooooooo`WZ2P_ooooo0_l9jPX:ooooo`03o`WZ2_oo
oooooooo00;ooooo0ol9jPX5ooooo`?o2NX:Xoooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0<oooool005[ooooo0_l9jPX>ooooo`;o2NX:3?ooool2
o`WZ2PSooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00Kooooo00?o0000o`WZ2_ooool01oooool01Ol9jP[ooooooooooooooooo2NX:00Gooooo00?o
2NX:ooooooooool01?ooool01?l0003oooooo`WZ2_l9jPX3ooooo`?o00000oooool00ol9jP[ooooo
o`WZ2P08ooooo`07o`WZ2_ooooooooooooooool0003oooooo`WZ2P03ooooo`03o`WZ2_oooooooooo
00Sooooo0_l9jPX9ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo
00Cooooo0_l9jPX00ooooooo2NX:o`WZ2P2[ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool01?ooool3o`WZ2PSooooo0ol9jPX2ooooo`03o`WZ2_oooooooooo00Oooooo00Go2NX:oooo
ooooooooooooo`WZ2P03ooooo`03o`000?oooooo2NX:00Oooooo0_l9jPX00ooooooo2NX:ooooo`08
ooooo`03o`WZ2_oooooo2NX:00?ooooo00?o0000ooooooooool00_ooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool01?l0003oooooo`WZ2_l9
jPX3ooooo`?o00001?ooool00ol9jP[oooooo`WZ2P08ooooo`03o`WZ2_oooooooooo00;ooooo0_l9
jPX5ooooo`03o`WZ2_oooooooooo00Kooooo0ol9jPX;ooooo`04o`WZ2_oooooo2NX:o`WZ2PSooooo
00?o2NX:ooooooooool00_l9jPX6ooooo`;o2NX:Yoooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0=?ooool005Sooooo0_l9jPX=ooooo`?o2NX:0_oo
ool2o`WZ2P03ooooool9jP[ooooo00Oooooo00?o2NX:ooooool9jPX01oooool00ol9jP[ooooooooo
o`03ooooo`;o2NX:0_ooool00ol9jP[oooooooooo`06ooooo`03o`000?l9jP[ooooo00Oooooo00?o
2NX:ooooooooool00_ooool2o`WZ2P?ooooo00?o2NX:ooooooooool01Oooool00ol0003o2NX:o`WZ
2P03o`0000Kooooo00?o2NX:ooooooooool00_l9jPX6ooooo`05o`WZ2_ooooooooooooooool00000
0_ooool2o`WZ2P03ooooool9jP[ooooo00Wooooo00Co2NX:ooooool9jP[o2NX:1oooool00ol9jP[o
ooooooooo`04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool2o`WZ2P03ooooool9jP[o2NX:
0:kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`04o`WZ2POooooo1?l9jPX4oooo
o`03o`WZ2_oooooo2NX:00Sooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooo`000002oooo
o`03o`WZ2_oooooooooo00Oooooo0_l9jPX9ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo00?o0000
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool01Oooool00ol0003o2NX:o`WZ2P03o`0000Oooooo00Co2NX:oooooooooooo2NX:1ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool02?oo
ool00ol9jP[oooooooooo`09ooooo`05o`WZ2_ooooooooooooooool9jPX01oooool3o`WZ2PKooooo
0_l9jPZYooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0eooooo`00EOooool3o`WZ2POooooo0_l9jPX3ooooo`?o2NX:1oooool2o`WZ2PSooooo00?o
2NX:ooooooooool00_l9jPX5ooooo`03o`WZ2_oooooooooo00Gooooo0_l9jPX9ooooo`04o`000?oo
oooo2NX:o`WZ2PKooooo00?o2NX:ooooooooool01?ooool01?l9jP[oooooooooool9jPX7ooooo`?o
000000?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00Go2NX:ooooooooooooooooo`000004ooooo`;o2NX:2_ooool01Ol9jP[ooooooooooooooooo
2NX:00Kooooo00?o2NX:ooooooooool01Oooool4o`WZ2P;ooooo1Ol9jPZ`ooooo`03o`000?oooooo
oooo02oooooo0ol9jPX8ooooo`?o2NX:2?ooool01?l9jP[oooooooooool9jPX7ooooo`03o`WZ2_oo
oooooooo00?ooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00Oooooo0_l9jPX9ooooo`07o`WZ2_oo
ooooooooooooool9jP[oooooo`000004ooooo`03o`WZ2_oooooooooo00Cooooo00Go2NX:oooooooo
ooooooooo`WZ2P06ooooo`Co000000?o2NX:ooooooooool01oooool01?l9jP[oooooooooooooool2
o`WZ2PGooooo00?o2NX:ooooooooool01Oooool2o`WZ2P;ooooo00?o2NX:ooooooooool02?ooool3
o`WZ2PWooooo00?o2NX:ooooooooool00_ooool3o`WZ2P;ooooo0ol9jPX5ooooo`?o2NX:Zoooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=Oooool0
057ooooo1?l9jPX<ooooo`?o2NX:2_ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`05ooooo`;o2NX:2Oooool01Ol9
jP[o0000oooooooooooo2NX:00Gooooo00?o2NX:ooooooooool01?ooool01?l9jP[oooooooooool9
jPX4ooooo`?o000000Goooooo`000?l9jP[o0000o`WZ2P07ooooo`03o`WZ2_oooooooooo00?ooooo
0_l9jPX3ooooo`03o`WZ2_oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`WZ2PWooooo
00?o2NX:ooooooooool00_ooool2o`WZ2PCooooo00?o2NX:ooooooooool02Oooool4o`WZ2[?ooooo
00?o0000ooooooooool0;?ooool3o`WZ2P03o`000?oooooooooo00Gooooo0ol9jPX00ooooooo2NX:
ooooo`08ooooo`05o`WZ2_ooooooooooooooool9jPX01_ooool00ol9jP[oooooooooo`03ooooo`05
o`000?oooooo2NX:ooooool9jPX02_ooool2o`WZ2PSooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooo`000003ooooo`03o`WZ2_oooooooooo00Gooooo00Co2NX:oooooooooooo2NX:0oooool3
o`0000;ooooo00Co0000o`WZ2_oooooo2NX:2?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooo`WZ2P0:ooooo`04o`WZ2_oo
ooooooooo`WZ2PSooooo00?o2NX:ooooooooool01Oooool2o`WZ2PGooooo0ol9jPZ_ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0fooooo`00C_oo
ool3o`WZ2Pgooooo1?l9jPX<ooooo`?o2NX:1oooool00ol9jP[oooooooooo`03ooooo`05o`WZ2_oo
ooooooooooooool9jPX02?ooool2o`WZ2PSooooo00?o2NX:o`000?ooool00_ooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00Gooooo0ol9jPX01?oooooo0000o`000?l00004ooooo`05
o`000?l9jP[oooooo`000?l9jPX01_ooool00ol9jP[oooooooooo`05ooooo`04o`WZ2_oooooooooo
o`WZ2PCooooo00?o0000ooooooooool00_ooool00ol9jP[oooooo`WZ2P08ooooo`03o`WZ2_oooooo
oooo00Cooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00Oooooo1?l9jPZeooooo`03o`000?oooooo
oooo02Wooooo0ol9jPX3ooooo`03o`000?oooooooooo00;ooooo0ol9jPX5ooooo`03o`WZ2_oooooo
oooo00Kooooo00?o2NX:ooooooooool00_ooool2o`WZ2PCooooo00?o2NX:ooooooooool00_ooool0
1_l0003oooooooooool9jP[oooooo`WZ2P[ooooo00?o2NX:ooooool9jPX01oooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_l0003ooooo00;ooooo00?o2NX:ooooooooool01_ooool3o`WZ2P?o0000
1Oooool01?l0003o2NX:ooooool9jPX8ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`07ooooo`;o2NX:2_ooool01?l9jP[oooooooooooooool2o`WZ
2PKooooo00?o2NX:ooooooooool00oooool2o`WZ2PGooooo0_l9jPZbooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0gooooo`00Boooool3o`WZ2POo
oooo00?o2NX:ooooooooool01?ooool2o`WZ2PCooooo0_l9jPX00ooooooo2NX:ooooo`07ooooo`04
o`WZ2_ooooooooooo`WZ2PKooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooo`WZ2P09oooo
o`03o`WZ2_oooooo2NX:00Oooooo00?o2NX:o`000?ooool00oooool01Ol9jP[ooooooooooooooooo
2NX:00Sooooo00?o0000o`WZ2_l000001oooool01_l0003o2NX:oooooooooooo0000o`WZ2PGooooo
00?o2NX:ooooooooool01_ooool00ol9jP[oooooo`WZ2P04ooooo`03o`000?oooooooooo00;ooooo
00?o2NX:ooooooooool00_l9jPX6ooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooool9jPX0
1_ooool5o`WZ2[Oooooo00?o0000ooooooooool09oooool2o`WZ2POooooo00Co0000ooooool9jP[o
2NX:1oooool00ol9jP[oooooo`WZ2P07ooooo`03o`WZ2_oooooooooo00Cooooo00Go2NX:oooooooo
ooooooooo`WZ2P03ooooo`03o`000?oooooooooo00;ooooo0_l9jPX:ooooo`04o`WZ2_oooooooooo
o`WZ2PKooooo00?o2NX:ooooooooool01?ooool01Ol0003ooooooooooooooooo2NX:00Sooooo0_l0
00000ol9jP[oooooooooo`06ooooo`04o`000?l9jP[o0000ooooo`;o2NX:1_ooool00ol9jP[ooooo
ooooo`04ooooo`;o2NX:0oooool00ol9jP[oooooooooo`08ooooo`;o2NX:2_ooool00ol9jP[ooooo
ooooo`02ooooo`;o2NX:1?ooool01?l9jP[oooooooooooooool2o`WZ2PCooooo0ol9jPZdooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0hooooo`00
B?ooool3o`WZ2P_ooooo00?o2NX:ooooooooool02oooool2o`WZ2PSooooo00Co2NX:oooooooooooo
2NX:1_ooool00ol9jP[oooooooooo`05ooooo`;o2NX:2Oooool01?l9jP[oooooooooool9jPX6oooo
o`03o`WZ2_oooooo000000Cooooo00Co2NX:oooooooooooo2NX:1Oooool3o`000003ooooool9jP[o
2NX:00Oooooo00?o0000o`WZ2_ooool00_ooool00ol0003o2NX:ooooo`03ooooo`03o`WZ2_oooooo
oooo00Oooooo0_l9jPX4ooooo`03o`000?oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool2
o`WZ2PCooooo00?o2NX:ooooooooool01oooool2o`WZ2PCooooo1?l9jPZjooooo`03o`000?oooooo
oooo02Cooooo0ol9jPX8ooooo`03o`WZ2_l0003o2NX:00Wooooo00Co2NX:oooooooooooo2NX:1_oo
ool00ol9jP[oooooooooo`04ooooo`05o`WZ2_ooooooooooooooool9jPX00_ooool00ol0003ooooo
ooooo`04ooooo`;o2NX:2Oooool01?l9jP[oooooooooool9jPX6ooooo`03o`WZ2_oooooooooo00Go
oooo00Co0000oooooooooooo2NX:1Oooool3o`0000;ooooo00?o2NX:ooooooooool01_ooool01?l0
003o2NX:ooooool00002ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01_ooool0
1?l9jP[oooooooooool9jPX:ooooo`04o`WZ2_oooooo2NX:o`WZ2PSooooo00?o2NX:ooooooooool0
1?ooool01_l9jP[ooooooooooooooooo2NX:ooooo`;o2NX:0oooool3o`WZ2[Oooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Wooooo0016ooooo`;o
2NX:3oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo00Kooooo00Co2NX:oooooooo
oooooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo00Kooooo0_l9jPX8ooooo`05o`WZ2_oooooooooo
ooooool9jPX01Oooool00ol9jP[oooooo`000005ooooo`?o2NX:0_ooool3o`0000Cooooo00?o2NX:
ooooool9jPX01_ooool00ol0003o2NX:ooooo`03ooooo`03o`000?l9jP[o2NX:00;ooooo00?o2NX:
ooooooooool02?ooool2o`WZ2PCooooo00Go0000ooooooooooooooooo`WZ2P06ooooo`;o2NX:0_oo
ool00ol9jP[oooooooooo`09ooooo`03o`WZ2_oooooo2NX:00?o2NX:_Oooool00ol0003ooooooooo
o`0Pooooo`?o2NX:3?ooool2o`WZ2PWooooo00Co2NX:oooooooooooo2NX:1_ooool00ol9jP[ooooo
ooooo`05ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo00001oooool00ol9jP[oooooo`WZ2P07oooo
o`03o`WZ2_oooooooooo00;ooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo00Gooooo00Co0000o`WZ
2_oooooo2NX:0_ooool3o`0000Cooooo00?o2NX:ooooool9jPX01oooool01Ol0003o2NX:oooooooo
oooo000000;ooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo00Oooooo0ol9jPX:ooooo`04o`WZ2_oo
ooooooooooooo`;o2NX:1_ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00;o2NX:
0oooool2o`WZ2[_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo03[ooooo0014ooooo`;o2NX:4_ooool2o`WZ2P03ooooool9jP[ooooo00Sooooo0_l9
jPX7ooooo`03o`WZ2_oooooooooo00?ooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00Kooooo00?o
2NX:ooooool9jPX01oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooool000001oooool00ol9jP[o0000o`000007ooooo`04o`WZ2_ooooooooooo`WZ2PGooooo
00?o0000o`WZ2_ooool01?ooool00ol0003oooooo`WZ2P02o`WZ2P[ooooo00Co2NX:ooooool9jP[o
2NX:0_ooool01Ol0003ooooooooooooooooo2NX:00Sooooo00?o2NX:ooooool9jPX02_ooool4o`WZ
2/3ooooo00?o0000ooooooooool07?ooool4o`WZ2Poooooo00?o0000ooooool9jPX02?ooool01?l9
jP[oooooooooooooool2o`WZ2PCooooo00?o2NX:ooooooooool01_ooool2o`WZ2P03ooooool0003o
oooo00Oooooo00?o2NX:ooooool9jPX01oooool00ol9jP[oooooooooo`04ooooo`05o`WZ2_oooooo
ooooooooool9jPX01oooool01?l0003oooooo`WZ2_l9jPX2o`0000Oooooo00?o2NX:ooooooooool0
0_l9jPX5ooooo`03o`000?l9jP[ooooo00;ooooo00Go0000ooooooooooooooooo`WZ2P02ooooo`03
o`WZ2_oooooooooo00Wooooo00?o2NX:o`000?ooool02?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01Oooool3o`WZ2P;ooooo0ol9jPZmooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0kooooo`00
@Oooool3o`WZ2POooooo0_l9jPX=ooooo`;o2NX:2?ooool01?l9jP[oooooooooool9jPX6ooooo`03
o`WZ2_oooooooooo00Gooooo00?o2NX:ooooool9jPX02?ooool00ol9jP[oooooo`WZ2P07ooooo`03
o`WZ2_oooooooooo00?ooooo0_l9jPX2ooooo`03o`WZ2_oooooo000000Cooooo0ol000000ol9jP[o
ooooooooo`07ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool00ol0003o2NX:ooooo`05oooo
o`04o`000?ooooooooooo`WZ2P[ooooo00Co2NX:oooooooooooooooo0_l9jPX01Ol0003ooooooooo
oooooooo2NX:00Wooooo0_l9jPX7ooooo`Co2NX:`oooool00ol0003oooooooooo`0Iooooo`?o2NX:
1oooool2o`WZ2P[ooooo00?o2NX:ooooool9jPX02?ooool00ol9jP[oooooooooo`03ooooo`05o`WZ
2_ooooooooooooooool9jPX02Oooool00ol9jP[o0000ooooo`08ooooo`03o`WZ2_oooooooooo00;o
2NX:1Oooool00ol9jP[oooooooooo`05ooooo`04o`WZ2_ooooooooooo`WZ2PKooooo1?l000000ol9
jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol0
003o2NX:ooooo`03ooooo`04o`000?ooooooooooo`WZ2P?ooooo00?o2NX:ooooooooool02?ooool3
o`WZ2PSooooo00?o2NX:ooooooooool01?ooool2o`WZ2P?ooooo00?o2NX:ooooooooool00oooool2
o`WZ2P?ooooo0_l9jP[0ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0looooo`00?oooool2o`WZ2Pcooooo00?o2NX:ooooooooool02_ooool2o`WZ
2PSooooo00Co2NX:oooooooooooooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo00Gooooo0_l9jPX9
ooooo`03o`WZ2_oooooooooo00;o2NX:1Oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooo
2NX:00;ooooo1?l00002ooooo`04o`WZ2_oooooo2NX:o`WZ2PKooooo00?o2NX:ooooooooool01?oo
ool01Ol9jP[oooooo`000?oooooo2NX:00Oooooo00Co0000ooooool9jP[o2NX:2Oooool00ol9jP[o
ooooooooo`03ooooo`05o`WZ2_ooooooooooooooool9jPX02_ooool3o`WZ2P;ooooo1Ol9jP[5oooo
o`03o`000?oooooooooo01Oooooo0_l9jPX<ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:oooo
ooooool00_l9jPX6ooooo`03o`WZ2_oooooooooo00Cooooo00Co2NX:oooooooooooo2NX:2Oooool2
o`WZ2PWooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00Kooooo00?o2NX:ooooool9jPX00oooool3o`0000;ooooo00Co0000ooooool9jP[o2NX:2?oo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o0000o`WZ2_ooool01?oo
ool00ol0003oooooooooo`02o`WZ2P03ooooool9jP[ooooo00Wooooo00Co2NX:o`000?oooooo2NX:
2?ooool00ol9jP[oooooooooo`05ooooo`;o2NX:00?oooooo`WZ2_ooool00_ooool2o`WZ2P?ooooo
0_l9jP[3ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0mooooo`00C_ooool00ol9jP[oooooooooo`0:ooooo`;o2NX:1oooool00ol9jP[ooooooooo
o`03ooooo`05o`WZ2_ooooooooooooooool9jPX02?ooool2o`WZ2PSooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooool9jPX0
0ol00005ooooo`05o`WZ2_ooooooooooooooool9jPX01Oooool00ol9jP[oooooooooo`04ooooo`05
o`WZ2_oooooo0000ooooool9jPX02?ooool01?l0003o2NX:ooooool9jPX8ooooo`03o`WZ2_oooooo
oooo00Cooooo0_l9jPX00ooooooo2NX:ooooo`09ooooo`03o`WZ2_oooooooooo00;o2NX:00?ooooo
o`WZ2_l9jPX0b?ooool00ol0003oooooooooo`0Tooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:
ooooool9jPX02?ooool00ol0003o2NX:ooooo`02o`WZ2POooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Oooooo0_l9jPX3o`0000Gooooo00Go0000
ooooool9jP[oooooo`WZ2P07ooooo`03o`WZ2_oooooooooo00?ooooo00Ko2NX:oooooooooooooooo
o`000?l9jPX6ooooo`04o`000?ooooooooooooooo`;o2NX:2_ooool01Ol9jP[o0000oooooooooooo
2NX:00Oooooo00?o2NX:ooooooooool01oooool2o`WZ2P;ooooo00?o2NX:ooooooooool00ol9jP[6
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0n
ooooo`00@Oooool2o`WZ2Pcooooo00?o2NX:ooooooooool02Oooool01?l9jP[oooooo`WZ2_l9jPX5
ooooo`03o`WZ2_oooooooooo00Cooooo00Co2NX:oooooooooooo2NX:2?ooool00ol9jP[oooooo`WZ
2P07ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`05ooooo`03o`000?l9jP[o2NX:00;ooooo00?o0000ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01Oooool01?l9jP[o0000oooo
ool9jPX9ooooo`03o`WZ2_oooooooooo00;o2NX:1_ooool00ol9jP[oooooooooo`04ooooo`04o`00
0?oooooo2NX:o`WZ2P_ooooo0_l9jPX00ooooooo2NX:o`WZ2P3:ooooo`03o`000?oooooooooo02Go
oooo0_l9jPX7ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`06ooooo`;o2NX:1oooool00ol0003oooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool01Ol9jP[ooooooooooooooooo2NX:00Sooooo0_l000000ol9
jP[oooooooooo`06ooooo`03o`000?oooooo2NX:00;ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`04ooooo`;o2NX:00Coooooo`000?oooooo2NX:1_ooool01?l0003ooooooooooooo
ool2o`WZ2PWooooo00?o2NX:o`000?ooool00_ooool2o`WZ2PGooooo00?o2NX:ooooooooool02Ooo
ool5o`WZ2/Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo03oooooo0013ooooo`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooooooool02?ooool0
1Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooo`WZ
2P08ooooo`04o`WZ2_ooooooooooo`WZ2PKooooo00?o2NX:ooooooooool00oooool2o`WZ2P;ooooo
00?o2NX:ooooooooool00_ooool3o`000004ooooool9jP[oooooo`WZ2P;ooooo00?o0000oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`05o`WZ2_ooooooooooooooool9jPX02?ooool00ol0
003o2NX:o`WZ2P09ooooo`03o`WZ2_l0003ooooo00;ooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo
00Cooooo00?o0000ooooooooool00_l9jPX7ooooo`?o2NX:00?oooooo`WZ2_l9jPX0cOooool00ol0
003oooooooooo`0Gooooo`03o`WZ2_oooooooooo00cooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`04ooooo`05o`WZ2_ooooooooooooooool9jPX02Oooool2o`WZ2PGooooo00Co0000
oooooooooooo2NX:0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo0_l9
jPX00ooooooo2NX:ooooo`04ooooo`?o00000_ooool00ol9jP[oooooooooo`07ooooo`03o`000?l9
jP[ooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`06ooooo`04o`WZ2_l0
003oooooo`WZ2POooooo00Ko0000oooooooooooo2NX:ooooool9jPX8ooooo`03o`WZ2_l0003ooooo
00Cooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo00Sooooo0ol9jP[=ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`10ooooo`00@oooool00ol9jP[o
ooooooooo`0;ooooo`;o2NX:2?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:oooo
ooooool01_ooool2o`WZ2PSooooo00Go2NX:ooooooooooooooooo`WZ2P05ooooo`03o`WZ2_oooooo
oooo00Gooooo0_l9jPX2ooooo`?o00001?ooool00ol9jP[oooooo`WZ2P02ooooo`03o`000?oooooo
oooo00;ooooo00?o2NX:ooooooooool01?ooool01?l9jP[oooooooooool9jPX8ooooo`03o`000?l9
jP[o2NX:00Wooooo00?o2NX:ooooool000001?ooool2o`WZ2P;ooooo00?o2NX:ooooooooool01?oo
ool01?l0003oooooooooooooool2o`WZ2PCooooo0_l9jPX2ooooo`;o2NX:d?ooool00ol0003ooooo
ooooo`0Gooooo`;o2NX:3?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Gooooo
00Co2NX:oooooooooooo2NX:2Oooool00ol9jP[oooooo`WZ2P02ooooo`;o00000oooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01_ooool2o`WZ2P;o
oooo0ol00005ooooo`?o2NX:1oooool00ol0003o2NX:ooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool01_ooool01?l9jP[o0000ooooool9jPX8ooooo`03o`000?oooooo2NX:
00;ooooo00?o2NX:ooooooooool01Oooool00ol9jP[o0000ooooo`06ooooo`04o`WZ2_oooooooooo
o`WZ2PSooooo0ol9jP[?ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06?ooool2
o`0004?ooooo0014ooooo`;o2NX:3Oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo
00;ooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooool9jPX01oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01_ooool00ol9
jP[o0000o`000007ooooo`03o`WZ2_oooooooooo00;o2NX:00?o0000ooooooooool00_ooool00ol9
jP[oooooooooo`05ooooo`03o`WZ2_oooooo2NX:00Sooooo00Co0000ooooool9jP[o2NX:2?ooool0
1?l9jP[oooooooooool00005ooooo`03o`WZ2_oooooo2NX:00Kooooo00Ko0000oooooooooooooooo
o`WZ2_ooool4o`WZ2P;ooooo0_l9jP[Booooo`03o`000?oooooooooo01Wooooo00?o2NX:oooooooo
ool02_ooool2o`WZ2PCooooo00?o2NX:ooooooooool01_ooool3o`WZ2PWooooo00Go2NX:ooooool9
jP[oooooo`000005ooooo`03o`WZ2_oooooooooo00?ooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo
00Kooooo0_l9jPX2o`0000Sooooo00Co2NX:oooooooooooo2NX:1_ooool00ol0003o2NX:ooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01oooool00ol0003oooooo`WZ2P09
ooooo`03o`000?l9jP[ooooo00;ooooo0_l9jPX5ooooo`03o`WZ2_oooooo000000Oooooo0ol9jPX5
ooooo`?o2NX:doooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0@oooool004Kooooo0_l9jPX<ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool01Oooool00ol9jP[oooooo`WZ2P08ooooo`03o`WZ2_oooooo2NX:00Oooooo00?o2NX:oooo
ooooool00oooool2o`WZ2P;ooooo00?o2NX:ooooooooool00oooool3o`0000;o2NX:2?ooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_l0003ooooo00;ooooo00?o2NX:ooooooooool01Oooool00ol9
jP[oooooo`WZ2P08ooooo`05o`000?oooooo2NX:ooooool9jPX01oooool01Ol9jP[ooooooooooooo
oooo000000Gooooo0_l9jPX7ooooo`04o`000?ooooooooooooooo`Co2NX:00?oooooo`WZ2_l9jPX0
eOooool00ol0003oooooooooo`0Hooooo`03o`WZ2_oooooooooo00cooooo00Go2NX:oooooooooooo
ooooo`WZ2P0:ooooo`03o`WZ2_oooooooooo00Oooooo00Co2NX:oooooooooooo2NX:1_ooool00ol9
jP[oooooooooo`05ooooo`04o`WZ2_ooooooooooo`WZ2PKooooo0ol00002o`WZ2PWooooo00Go2NX:
ooooooooooooooooo`WZ2P05ooooo`03o`WZ2_l0003ooooo00Cooooo0_l9jPX2ooooo`03o`WZ2_oo
oooooooo00Oooooo00?o0000o`WZ2_l9jPX02_ooool00ol9jP[oooooooooo`03ooooo`;o2NX:1?oo
ool00ol9jP[o0000ooooo`08ooooo`04o`WZ2_ooooooooooooooo`?o2NX:e_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo01Gooooo0_l00016ooooo`00B?ooool00ol9jP[ooooooooo
o`0:ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01_ooool2o`WZ2PSooooo00?o
2NX:ooooooooool00_l9jPX5ooooo`03o`WZ2_oooooooooo00Gooooo0_l9jPX3ooooo`?o00000ooo
ool00ol9jP[oooooo`WZ2P07ooooo`03o`WZ2_oooooooooo00?ooooo00Go0000oooooooooooooooo
o`WZ2P08ooooo`;o2NX:2?ooool00ol0003oooooo`WZ2P02ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o2NX:1_ooool01?l0003ooooo
o`WZ2_l9jPX3ooooo`;o2NX:eoooool00ol0003oooooooooo`0Iooooo`;o2NX:3Oooool01?l9jP[o
ooooooooool9jPX:ooooo`03o`WZ2_oooooooooo00Oooooo00Co2NX:o`000?l0003ooooo0_l9jPX4
ooooo`03o`WZ2_oooooooooo00Gooooo00Co2NX:oooooooooooo2NX:0_ooool4o`0000?ooooo00?o
2NX:ooooool9jPX02?ooool01Ol9jP[ooooooooooooooooo2NX:00Gooooo00?o2NX:o`000?ooool0
1_ooool00ol9jP[oooooo`WZ2P09ooooo`03o`000?l9jP[o2NX:00[ooooo00?o2NX:o`000?ooool0
1Oooool2o`WZ2P;ooooo00?o2NX:o`000?ooool02?ooool4o`WZ2]Wooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Kooooo0018ooooo`03o`WZ2_oo
oooooooo00_ooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool01_oo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01Ooo
ool2o`WZ2P?o00001_ooool00ol9jP[oooooooooo`02o`WZ2PGooooo00?o2NX:ooooooooool01?oo
ool01?l0003oooooooooool9jPX9ooooo`;o2NX:1oooool00ol0003oooooo`WZ2P02ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`WZ
2_oooooo2NX:o`WZ2PCooooo0_l9jPX3ooooo`;o2NX:f_ooool2o`0001_ooooo00?o2NX:oooooooo
ool02oooool00ol9jP[oooooo`WZ2P09ooooo`03o`WZ2_oooooo2NX:00Sooooo00?o2NX:oooooooo
ool00oooool01Ol9jP[ooooooooooooooooo2NX:00Sooooo0ol9jPX2o`0000Oooooo00Co2NX:oooo
oooooooo2NX:1oooool00ol9jP[oooooooooo`02ooooo`;o2NX:0oooool00ol9jP[oooooo`000007
ooooo`;o2NX:2Oooool01?l0003oooooo`WZ2_l9jPX9ooooo`03o`WZ2_oooooo000000Oooooo0ol9
jPX00ol0003oooooooooo`04ooooo`Go2NX:g?ooool2o`0002gooooo00?o0000ooooooooool04Ooo
ool2o`0004Wooooo0019ooooo`;o2NX:3Oooool00ol9jP[oooooo`WZ2P09ooooo`;o2NX:1oooool0
0ol9jP[oooooooooo`03ooooo`05o`WZ2_ooooooooooooooool9jPX01_ooool2o`0000;o2NX:2?oo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01?oo
ool01?l0003o2NX:ooooool9jPX8ooooo`04o`WZ2_ooooooooooo`WZ2PKooooo00?o0000ooooool9
jPX00oooool2o`WZ2PCooooo00?o2NX:ooooooooool01?ooool01Ol0003ooooooooooooooooo2NX:
00?ooooo1?l9jPX00ol0003oooooooooo`02o`WZ2]kooooo00?o0000ooooooooool06Oooool00ol9
jP[oooooooooo`0;ooooo`;o2NX:2Oooool00ol9jP[oooooooooo`02o`WZ2PGooooo00?o0000o`WZ
2_ooool01?ooool01Ol9jP[ooooooooooooooooo2NX:00Oooooo0ol000000ol9jP[oooooooooo`07
ooooo`04o`WZ2_ooooooooooo`WZ2POooooo00?o2NX:ooooooooool01?ooool01_l9jP[ooooooooo
ool9jP[oooooo`0000Oooooo0_l9jPX9ooooo`05o`000?oooooo2NX:ooooool9jPX02?ooool01?l9
jP[oooooooooool00008ooooo`;o2NX:0oooool3o`WZ2P03ooooool9jP[o2NX:0>3ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Wooooo001;oooo
o`03o`WZ2_oooooooooo00[ooooo00?o2NX:ooooool9jPX02?ooool00ol9jP[oooooooooo`02o`WZ
2PGooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooo`WZ2P04ooooo`?o00000_ooool00ol9
jP[oooooo`WZ2P07ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`05ooooo`03o`000?l9jP[o2NX:00Sooooo00Go2NX:ooooooooooooooooo`WZ2P05
ooooo`03o`000?oooooo2NX:00Gooooo00Go2NX:ooooooooooooooooo`WZ2P07ooooo`03o`000?oo
oooooooo00?ooooo0_l9jPX01?oooooo2NX:ooooool00002o`WZ2^7ooooo00?o0000ooooooooool0
6Oooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`02o`000003ooooool9jP[ooooo00Gooooo0_l9jPX00ooooooo2NX:
ooooo`03ooooo`?o00000oooool2o`WZ2PSooooo00Co2NX:oooooooooooooooo0_l9jPX5ooooo`03
o`WZ2_oooooooooo00Gooooo00Go2NX:ooooool9jP[oooooo`000008ooooo`;o2NX:2?ooool00ol0
003oooooo`WZ2P02ooooo`03o`WZ2_oooooooooo00Kooooo00Co2NX:oooooooooooo00002?ooool0
1?l0003o2NX:o`WZ2_l9jPX2ooooo`;o2NX:hoooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00kooooo0_l0001<ooooo`00C?ooool00ol9jP[oooooooooo`0:ooooo`;o2NX:2?ooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool01Oooool2
o`WZ2P04ooooool0003o0000o`0000Gooooo00?o2NX:ooooooooool00_l9jPX5ooooo`03o`WZ2_oo
oooooooo00?ooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00Gooooo00Co0000o`WZ2_oooooo2NX:
1oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o0000ooooool9jPX0
1_ooool01?l9jP[oooooooooool9jPX8ooooo`;o000000?oooooo`WZ2_l9jPX01?ooool2o`WZ2^Co
oooo00?o0000ooooooooool06Oooool00ol9jP[oooooooooo`0:ooooo`?o2NX:1oooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooo000000?ooooo00?o2NX:ooooooooool01_ooool2o`WZ2P04
ooooool0003o0000o`0000Kooooo0_l9jPX8ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooo2NX:00;ooooo00?o0000oooo
ooooool01Oooool00ol9jP[oooooo`WZ2P07ooooo`03o`000?oooooo2NX:00;ooooo00?o2NX:oooo
ooooool01_ooool01Ol9jP[ooooooooooooooooo000000Oooooo0_l9jPX01?oooooo2NX:o`WZ2_l9
jP[Vooooo`;o0000:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04cooooo001=
ooooo`03o`WZ2_oooooooooo00[ooooo0_l9jPX7ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`05ooooo`03o`000?l9jP[o2NX:00Sooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Gooooo0_l9jPX8
ooooo`04o`000?l9jP[oooooo`WZ2POooooo00?o2NX:ooooooooool00oooool2o`WZ2P;ooooo00?o
0000ooooool9jPX01oooool00ol9jP[oooooo`WZ2P08ooooo`?o2NX:1?ooool2o`WZ2P03ooooool0
003ooooo0>Cooooo00?o0000ooooooooool06Oooool2o`WZ2P[ooooo00Co2NX:o`000?oooooo2NX:
1_ooool00ol9jP[oooooooooo`03ooooo`;o2NX:0oooool00ol9jP[oooooooooo`06ooooo`03o`00
0?l9jP[o000000Sooooo00?o2NX:ooooooooool00_l9jPX6ooooo`03o`WZ2_oooooooooo00Cooooo
00Go2NX:ooooooooooooooooo`WZ2P08ooooo`;o2NX:0_ooool00ol0003oooooooooo`05ooooo`04
o`WZ2_ooooooooooo`WZ2PKooooo00?o0000ooooool9jPX00oooool2o`WZ2PKooooo00?o2NX:oooo
ooooool00_ooool01?l0003oooooooooooooool3o`WZ2P03o`000?l9jP[o2NX:0>_ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0;ooooo`;o0000Coooool004kooooo00?o2NX:oooo
ooooool02Oooool00ol9jP[oooooo`WZ2P06ooooo`03o`WZ2_oooooooooo00?ooooo0_l9jPX2oooo
o`03o`WZ2_oooooooooo00;ooooo0ol000001?oooooo2NX:ooooool9jPX7ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`06ooooo`;o2NX:2?ooool0
0ol0003oooooooooo`02o`WZ2PGooooo00?o2NX:ooooooooool01Oooool01Ol9jP[oooooo`000?oo
oooo2NX:00Sooooo0_l9jPX5ooooo`?o2NX:0oooool01?l0003oooooo`WZ2_l9jPX3ooooo`03o`00
0?oooooooooo0>Cooooo00?o0000ooooooooool06_ooool00ol9jP[oooooooooo`07ooooo`04o`WZ
2_l0003oooooo`WZ2PKooooo00Co2NX:oooooooooooooooo0_l00002ooooo`04o`WZ2_oooooooooo
o`WZ2PGooooo0ol000000ooooooo2NX:ooooo`08ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`05o`WZ2_ooooooooooooooool9jPX02Ooo
ool2o`WZ2P;ooooo00?o0000ooooooooool01?ooool01?l9jP[oooooooooool9jPX6ooooo`03o`00
0?oooooo2NX:00Gooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`?o2NX:
0_ooool2o`WZ2^kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`08ooooo`?o0000
DOooool004oooooo0_l9jPX9ooooo`04o`WZ2_ooooooooooo`WZ2PGooooo00?o2NX:ooooooooool0
1Oooool01?l9jP[oooooo`WZ2_ooool3o`0000Cooooo00Co2NX:oooooooooooo2NX:1_ooool00ol9
jP[oooooooooo`03ooooo`;o2NX:00?oooooo`WZ2_ooool02?ooool00ol9jP[oooooo`WZ2P07oooo
o`03o`000?oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`05oooo
o`05o`WZ2_oooooo0000ooooool9jPX02Oooool2o`WZ2P;ooooo0_l9jPX6ooooo`;o2NX:1Oooool0
0ol0003oooooooooo`3Uooooo`03o`000?oooooooooo01Wooooo00?o2NX:ooooooooool01oooool0
1?l9jP[o0000ooooooooool2o`WZ2PCooooo00Co2NX:o`000?l0003o00001Oooool01?l9jP[ooooo
o`WZ2_ooool4o`0000Cooooo0ol9jPX7ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`05ooooo`?o2NX:2_ooool01Ol9jP[oooooo`WZ2_oooooo0000
00Kooooo00Co2NX:oooooooooooooooo0_l9jPX4ooooo`04o`000?ooooooooooo`WZ2PGooooo00?o
2NX:ooooooooool00_ooool01?l9jP[oooooooooooooool2o`WZ2P03ooooool0003ooooo00;o2NX:
00?oooooo`000?ooool0k_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo
0_l0001Dooooo`00DOooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`06ooooo`;o2NX:00?o0000ooooooooool01Ooo
ool01Ol9jP[ooooooooooooooooo2NX:00Gooooo00?o2NX:ooooooooool01Oooool2o`WZ2PWooooo
00?o2NX:ooooool9jPX01oooool00ol9jP[o0000ooooo`03ooooo`;o2NX:0_ooool00ol9jP[ooooo
ooooo`06ooooo`04o`000?l9jP[oooooo`WZ2P[ooooo0ol9jPX5ooooo`?o2NX:0_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0>Kooooo0_l0000Jooooo`03o`WZ2_oooooooooo00Ko
oooo00?o2NX:o`000?ooool00oooool01Ol9jP[oooooo`000?l0003o2NX:00Sooooo00Co2NX:o`00
0?l9jP[o00002?ooool01?l9jP[oooooooooool9jPX6ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00Sooooo00?o
2NX:ooooool9jPX00_ooool00ol0003oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00Go
2NX:ooooooooooooooooo`000002ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0oooool3o`WZ2P?ooooo0_l9jPX4ooooo`03o`000?oooooooooo0>gooooo0ol0000Tooooo`03o`00
0?oooooooooo00?ooooo0_l0001Fooooo`00D_ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00?ooooo0ol000000ol9jP[oooooo`WZ
2P07ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`06ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool00_l9jPX5ooooo`03o`WZ2_l0
003ooooo00Gooooo00?o2NX:ooooool9jPX02?ooool01?l0003oooooo`WZ2_l9jPX8ooooo`;o2NX:
1Oooool3o`WZ2PKooooo00Go0000ooooooooooooooooo`00003Zooooo`;o00006Oooool2o`WZ2PKo
oooo00?o2NX:o`000?ooool00_ooool2o`000004o`WZ2_ooooooooooo`WZ2PKooooo0ol00002o`WZ
2PWooooo00Go2NX:ooooooooooooooooo`WZ2P05ooooo`03o`WZ2_oooooooooo00Cooooo0_l9jPX2
ooooo`03o`WZ2_oooooooooo00Oooooo0_l9jPX9ooooo`03o`WZ2_oooooooooo00;o2NX:00?o0000
ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`04o`WZ2_ooooooooooo`0000;ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`02o`WZ2P?ooooo0ol9jPX2ooooo`05o`000?oo
ooooooooooooool00000l_ooool3o`00027ooooo00?o0000ooooooooool00ol0001Hooooo`00Dooo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooool9jPX00_oo
ool3o`0000?ooooo00?o2NX:ooooool9jPX01oooool00ol9jP[oooooooooo`03ooooo`;o2NX:00?o
ooooo`WZ2_ooool02?ooool2o`WZ2PSooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooo000000Gooooo00?o2NX:ooooool9jPX02?ooool01?l0003ooooooooo
ool9jPX6ooooo`;o2NX:1?ooool3o`WZ2P[ooooo00Co0000oooooooooooo0000k?ooool3o`0001So
oooo00?o2NX:ooooooooool00oooool00ol9jP[o0000o`000002o`0000?ooooo00?o2NX:ooooool9
jPX00oooool3o`0000?ooooo00?o2NX:ooooool9jPX02?ooool01Ol9jP[ooooooooooooooooo2NX:
00Gooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooo`WZ2P09ooooo`;o2NX:2Oooool00ol9
jP[oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool01?l9
jP[oooooooooool00002ooooo`03o`WZ2_oooooooooo00Gooooo0_l9jPX2ooooo`?o2NX:1_ooool0
1?l0003oooooooooool0003eooooo`?o00007_ooool3o`0005_ooooo001Dooooo`;o2NX:0oooool0
0ol9jP[oooooooooo`06ooooo`04o`WZ2_l0003o0000o`0000Kooooo00?o2NX:ooooooooool00_l9
jPX4ooooo`03o`WZ2_oooooooooo00Kooooo0_l9jPX9ooooo`03o`WZ2_oooooo2NX:00Oooooo00?o
2NX:ooooooooool00oooool01ol9jP[ooooooooooooooooo2NX:ooooool000001_ooool00ol9jP[o
ooooooooo`07ooooo`05o`000?ooooooooooooooool9jPX00_ooool3o`WZ2P?ooooo0ol9jPX>oooo
o`03o`000?oooooo00000>oooooo0_l0000Gooooo`07o`WZ2_ooooooooooooooool0003o2NX:o`00
0007ooooo`;o2NX:0ol00006ooooo`04o`WZ2_ooooooooooo`WZ2POooooo00?o2NX:ooooooooool0
0_ooool2o`WZ2P?ooooo00?o2NX:ooooooooool01oooool2o`WZ2PWooooo00Co2NX:ooooool9jP[o
2NX:1oooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o2NX:oooooooo
ool01Oooool2o`WZ2P04o`000?ooooooooooo`WZ2PCooooo1ol9jPX:ooooo`03o`000?oooooo0000
0?Sooooo0ol0000Hooooo`Co0000GOooool005Kooooo00Co2NX:oooooooooooo2NX:1_ooool2o`00
00;o2NX:2?ooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX02?ooool2
o`WZ2PWooooo00?o2NX:ooooooooool00_l9jPX5ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:
ooooool9jPX00oooool00ol0003oooooooooo`03ooooo`?o2NX:1oooool00ol0003oooooooooo`02
ooooo`;o2NX:1?ooool2o`WZ2Q;ooooo0_l0003aooooo`;o00005?ooool2o`000005o`WZ2_l0003o
0000ooooool9jPX01oooool2o`000003o`WZ2_oooooooooo00Oooooo00Go2NX:oooooooooooooooo
o`WZ2P06ooooo`03o`WZ2_oooooooooo00Cooooo00Co2NX:oooooooooooo2NX:2Oooool2o`WZ2PWo
oooo00Go2NX:ooooooooooooooooo`WZ2P06ooooo`03o`WZ2_oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol9jP[oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo1Ol9jPX?oooo
o`;o0000noooool8o`0000Wooooo1ol0001Qooooo`00Eoooool00ol9jP[oooooo`WZ2P03ooooo`?o
00000_ooool01?l9jP[oooooo`WZ2_l9jPX6ooooo`03o`WZ2_oooooooooo00?ooooo00Co2NX:oooo
oooooooo2NX:2Oooool2o`WZ2PSooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00Gooooo0_l9jPX3ooooo`03o`000?oooooooooo00?ooooo00Co2NX:
oooooooooooo2NX:1_ooool00ol0003oooooo`WZ2P02o`WZ2PCooooo0_l9jPXEooooo`03o`000?oo
oooooooo0?7ooooo2?l00007ooooo`Go00000oooool01?l9jP[oooooooooool9jPX4ooooo`?o0000
0_ooool2o`WZ2PSooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Gooooo00?o2NX:ooooool9jPX02_ooool2o`WZ2PSooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00Co0000o`WZ2_oooooo
2NX:2_ooool00ol0003oooooooooo`04o`WZ2QCooooo00?o0000ooooooooool0ooooool2ooooo`Wo
0000J?ooool005Sooooo0_l9jPX3o`0000Gooooo00Go2NX:ooooooooooooooooo`WZ2P05ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooool9jPX02Oooool00ol9jP[oooooo`WZ2P07ooooo`03
o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P09ooooo`03o`WZ2_oooooooooo
00;ooooo00?o0000ooooooooool00_ooool01?l9jP[oooooooooool9jPX5ooooo`?o2NX:1?ooool3
o`WZ2QOooooo00?o0000ooooooooool0nOooool7o`0000Wooooo0ol9jPX01?oooooo0000o`000?l0
0005ooooo`03o`WZ2_oooooo2NX:00Oooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00Kooooo0_l9jPX9ooooo`04o`WZ2_ooooooooooo`WZ2POooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Gooooo
00?o0000o`WZ2_l9jPX02_ooool01?l0003o2NX:o`WZ2_l9jPXGooooo`03o`000?oooooooooo0?oo
ooooLoooool005Wooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool01Oooool2o`WZ2PWooooo00Co2NX:oooooooooooo
2NX:1Oooool00ol9jP[oooooooooo`04ooooo`;o2NX:00?oooooo`WZ2_ooool02?ooool2o`WZ2PCo
oooo00Go0000ooooooooooooooooo`WZ2P03ooooo`Go2NX:00?oooooo`000?ooool01?l9jPXJoooo
o`03o`000?oooooooooo0?oooooo3?ooool00ol9jP[o0000ooooo`07ooooo`04o`WZ2_oooooooooo
o`WZ2PKooooo00?o2NX:ooooooooool01?ooool01?l9jP[oooooooooool9jPX:ooooo`03o`WZ2_oo
oooooooo00Oooooo00Go2NX:ooooooooooooooooo`WZ2P06ooooo`03o`WZ2_oooooooooo00?ooooo
0_l9jPX3ooooo`03o`WZ2_oooooooooo00Gooooo00?o0000ooooool9jPX01_ooool5o`WZ2Q[ooooo
00?o0000ooooooooool0oooooomcooooo`00F?ooool01?l9jP[oooooo`WZ2_l9jPX6ooooo`03o`WZ
2_oooooooooo00?ooooo00Co2NX:oooooooooooo2NX:2Oooool2o`WZ2PSooooo00Go2NX:oooooooo
ooooooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00Kooooo0_l9jPX9ooooo`03o`WZ2_oooooo2NX:
00?ooooo00?o0000ooooooooool00oooool3o`WZ2PCooooo00?o2NX:o`000?l9jPX07Oooool00ol0
003oooooooooo`3oooooo`gooooo00?o2NX:ooooooooool01oooool01?l9jP[oooooooooooooool2
o`WZ2PCooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooo`WZ2P0:ooooo`;o2NX:2?ooool0
1Ol9jP[ooooooooooooooooo2NX:00Kooooo00?o2NX:ooooooooool01Oooool01?l9jP[ooooooooo
ool9jPX8ooooo`03o`000?oooooooooo00;ooooo1Ol9jPX2ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0oooooomcooooo`00F?ooool01Ol9jP[ooooooooooooooooo2NX:00Gooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooo`WZ2P09ooooo`03o`WZ2_oooooo2NX:00Kooooo
00?o2NX:ooooooooool00oooool01Ol9jP[ooooooooooooooooo2NX:00Wooooo00?o2NX:oooooooo
ool01oooool01?l9jP[oooooooooool9jPX3ooooo`03o`000?l9jP[o2NX:00;o2NX:0oooool4o`WZ
2P03ooooool0003ooooo01gooooo00?o0000ooooooooool0ooooool<ooooo`03o`WZ2_oooooo2NX:
00Sooooo00?o2NX:ooooooooool00oooool01Ol9jP[ooooooooooooooooo2NX:00Sooooo0_l9jPX:
ooooo`03o`WZ2_oooooo2NX:00Oooooo00?o2NX:ooooooooool00_ooool2o`WZ2PCooooo00?o2NX:
ooooooooool01_ooool00ol9jP[oooooo`WZ2P09ooooo`03o`000?l9jP[o2NX:00?o2NX:1Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?ooooooLoooool005Sooooo00Go2NX:oooo
ooooooooooooo`WZ2P05ooooo`03o`WZ2_oooooooooo00Gooooo0_l9jPX9ooooo`03o`WZ2_oooooo
2NX:00Kooooo00?o2NX:ooooooooool01?ooool2o`WZ2P03ooooool9jP[ooooo00Sooooo00?o2NX:
ooooooooool01oooool01?l9jP[oooooooooooooool3o`WZ2P03o`000?oooooooooo00;ooooo0ol9
jPX5ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0ooooool<ooooo`03o`WZ2_oo
oooooooo00;o2NX:1_ooool00ol9jP[oooooooooo`03ooooo`05o`WZ2_ooooooooooooooool9jPX0
2Oooool00ol9jP[oooooooooo`08ooooo`04o`WZ2_ooooooooooo`WZ2PKooooo00?o2NX:oooooooo
ool01?ooool01Ol9jP[ooooooooooooooooo2NX:00Wooooo00?o2NX:ooooooooool01Oooool3o`WZ
2P03o`000?l9jP[o2NX:00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3ooooo
og?ooooo001Hooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo00Ko
oooo0_l9jPX8ooooo`03o`WZ2_oooooooooo00;o2NX:1?ooool00ol9jP[oooooooooo`06ooooo`;o
2NX:2Oooool3o`WZ2PWooooo0ol9jPX3ooooo`04o`000?l9jP[o2NX:o`WZ2PSooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`3oooooo`cooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00Co2NX:oooooooooooo2NX:2Oooool3
o`WZ2PSooooo00Go2NX:ooooooooooooooooo`WZ2P05ooooo`03o`WZ2_oooooooooo00Gooooo00Co
2NX:oooooooooooo2NX:3_ooool5o`WZ2P;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo0?ooooooM?ooool005Sooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooo`WZ2P09ooooo`03o`WZ2_oooooo2NX:00Kooooo00?o2NX:ooooooooool00ooo
ool01Ol9jP[ooooooooooooooooo2NX:00Wooooo00?o2NX:ooooooooool01oooool01?l9jP[ooooo
ooooool9jPX5ooooo`?o2NX:1?ooool3o`WZ2P03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`3oooooo`cooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooooooo00Kooooo0ol9jPX9ooooo`04o`WZ2_ooooooooooo`WZ
2POooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00Kooooo00?o2NX:ooooool9jPX02oooool5o`WZ2PGooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo0?ooooooM?ooool005Sooooo00?o2NX:oooooooo
ool01Oooool2o`WZ2PWooooo00?o2NX:ooooool9jPX01_ooool00ol9jP[oooooooooo`04ooooo`;o
2NX:00?oooooo`WZ2_ooool02?ooool2o`WZ2POooooo00?o2NX:ooooooooool00_ooool5o`WZ2P?o
oooo1?l9jPX3ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`3oooooo`gooooo00?o2NX:ooooooooool00oooool2o`WZ2P;ooooo00?o2NX:oooooooo
ool02?ooool00ol9jP[oooooooooo`07ooooo`04o`WZ2_ooooooooooo`WZ2PKooooo00?o2NX:oooo
ooooool01?ooool2o`WZ2P;ooooo00?o2NX:ooooooooool01oooool2o`WZ2PSooooo1?l9jPX:oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3ooooo
ogCooooo001Hooooo`03o`WZ2_oooooooooo00Kooooo0_l9jPX8ooooo`03o`WZ2_oooooooooo00;o
2NX:1?ooool00ol9jP[oooooooooo`06ooooo`;o2NX:2?ooool01?l9jP[oooooooooool9jPX9oooo
o`?o2NX:1?ooool3o`WZ2PSooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo0?oooooo3Oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooo2NX:
00[ooooo0_l9jPX8ooooo`05o`WZ2_ooooooooooooooool9jPX01Oooool00ol9jP[oooooooooo`06
ooooo`03o`WZ2_oooooo2NX:00[ooooo00?o2NX:ooooooooool00_ooool5o`WZ2Pkooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0?ooooooM?ooool0
05Sooooo00?o2NX:ooooooooool01_ooool2o`WZ2POooooo00?o2NX:ooooooooool00oooool01Ol9
jP[ooooooooooooooooo2NX:00Sooooo0_l9jPX8ooooo`05o`WZ2_ooooooooooooooool9jPX01Ooo
ool3o`WZ2P?ooooo1?l9jPX;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`3oooooo`gooooo00?o2NX:ooooooooool01_ooool2o`WZ2P[ooooo0_l9
jPX8ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo00Kooooo00?o
2NX:ooooool9jPX03?ooool5o`WZ2Q7ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo0?ooooooM?ooool005Oooooo00?o2NX:ooooooooool01oooool0
1?l9jP[oooooo`WZ2_l9jPX5ooooo`03o`WZ2_oooooooooo00Cooooo00Co2NX:oooooooooooo2NX:
2Oooool2o`WZ2POooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooo`WZ2P02o`WZ2P?ooooo
0ol9jPX@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`3oooooo`gooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`07ooooo`03o`WZ
2_oooooooooo00;o2NX:1_ooool00ol9jP[oooooooooo`04ooooo`04o`WZ2_ooooooooooo`WZ2PWo
oooo0_l9jPX8ooooo`Ko2NX:5Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0oooooomdooooo`00Eoooool00ol9jP[oooooooooo`07ooooo`05o`WZ
2_ooooooooooooooool9jPX01?ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooo2NX:00So
oooo00Co2NX:oooooooooooo2NX:2oooool2o`WZ2P?ooooo0ol9jPXDooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3oooooo`kooooo00?o2NX:oooo
ooooool01oooool2o`WZ2PSooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00Co2NX:oooooooooooo2NX:2_ooool00ol9jP[oooooooooo`03
ooooo`Go2NX:6_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0oooooomdooooo`00Eoooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo
00;ooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00Kooooo0_l9jPX8ooooo`04o`WZ2_oooooooooo
ooooo`;o2NX:1_ooool3o`WZ2P;ooooo0ol9jPXHooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`3oooooo`kooooo00?o2NX:ooooooooool01oooool0
0ol9jP[oooooo`WZ2P07ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooo2NX:00cooooo1_l9jPXNooooo`05o`000?oooooo
ooooooooool000006Oooool00ol0003oooooooooo`3oooooogGooooo001Gooooo`03o`WZ2_oooooo
oooo00Oooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooo`WZ2P09ooooo`;o2NX:1oooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?o2NX:0_ooool3o`WZ2Qcooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0?oooooo3oooool0
0ol9jP[oooooooooo`07ooooo`04o`WZ2_ooooooooooo`WZ2PKooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Kooooo0_l9jPX9ooooo`Go2NX:8ooo
ool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo0?ooooooMOooool005Oooooo00?o
2NX:ooooooooool01_ooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooo2NX:00Sooooo00Co
2NX:oooooooooooo2NX:2oooool4o`WZ2P;ooooo0ol9jPXPooooo`04o`000?ooooooooooo`0001go
oooo00?o0000ooooooooool0ooooool?ooooo`03o`WZ2_oooooooooo00Oooooo00Go2NX:oooooooo
ooooooooo`WZ2P05ooooo`03o`WZ2_oooooooooo00Cooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo
00Oooooo0_l9jPX4ooooo`Ko2NX:9_ooool01?l0003oooooooooool0000Iooooo`03o`000?oooooo
oooo0?ooooooMOooool005Oooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`06oooo
o`;o2NX:2?ooool01Ol9jP[ooooooooooooooooo2NX:00Oooooo0ol9jPX4ooooo`;o2NX:9?ooool0
0ol0003oooooo`00000Looooo`03o`000?oooooooooo0?oooooo4?ooool00ol9jP[oooooooooo`07
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`06
ooooo`;o2NX:3?ooool6o`WZ2R_ooooo00?o0000ooooool000006?ooool00ol0003oooooooooo`3o
ooooogKooooo001Gooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool01oooool2o`WZ
2POooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooooooooooool3o`WZ2PGooooo0_l9jPXW
ooooo`;o00007?ooool00ol0003oooooooooo`3oooooo`oooooo00?o2NX:ooooooooool02?ooool0
0ol9jP[oooooooooo`03ooooo`05o`WZ2_ooooooooooooooool9jPX02Oooool00ol9jP[ooooooooo
o`06ooooo`Oo2NX:;oooool2o`0001Sooooo00?o0000ooooooooool0oooooomfooooo`00Eoooool0
0ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool00_l9jPX;
ooooo`?o2NX:1Oooool3o`WZ2R[ooooo0_l0000Jooooo`03o`000?oooooooooo0?oooooo4?ooool0
0ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Cooooo00Co2NX:oooooooooooo2NX:2Ooo
ool2o`WZ2PCooooo1_l9jPXdooooo`;o00005oooool00ol0003oooooooooo`3oooooogKooooo001F
ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00Cooooo1?l9jPX4ooooo`Co2NX:;oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooo
oooo00Gooooo0ol9jPX;ooooo`Oo2NX:>Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo0?ooooooMoooool005Kooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`06oooo
o`03o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooooooooooo0ol9jPX5ooooo`?o2NX:=?ooool2
o`0001Kooooo00?o0000ooooooooool0oooooolAooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:
ooooooooool01oooool00ol9jP[oooooooooo`06ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:?Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?ooooooMoooool005Kooooo00?o2NX:
ooooooooool01_ooool00ol9jP[oooooooooo`0<ooooo`Co2NX:1Oooool3o`WZ2SWooooo0_l0000C
ooooo`03o`000?oooooooooo0?oooooo4_ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooo
oooo00Sooooo00?o2NX:ooooooooool00oooool3o`WZ2P;ooooo0_l9jPY1ooooo`;o00004Oooool0
0ol0003oooooooooo`3oooooogSooooo001Fooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:oooo
ooooool02Oooool3o`WZ2PKooooo0ol9jPXnooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0oooooolCooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool02Oooool00ol9
jP[oooooo`WZ2P02o`WZ2P?ooooo0_l9jPY5ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0oooooomiooooo`00E_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooooooo00Ko
oooo0ol9jPX7ooooo`;o2NX:@_ooool3o`0000gooooo00?o0000ooooooooool0oooooolDooooo`03
o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool02Oooool2o`WZ2P?ooooo0ol9jPY8ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0oooooomjooooo`00E_ooool00ol9jP[ooooo
ooooo`0<ooooo`?o2NX:DOooool4o`0000Gooooo1?l0003ooooooaOooooo00?o2NX:ooooooooool0
1oooool00ol9jP[oooooooooo`06ooooo`?o2NX:0oooool2o`WZ2Tcooooo0ol00008ooooo`;o0000
oooooommooooo`00E_ooool00ol9jP[oooooooooo`08ooooo`Co2NX:F?ooool5o`000?oooooo6ooo
ool00ol9jP[oooooooooo`0=ooooo`?o2NX:Eoooool3o`0000;ooooo0ol0003oooooogoooooo001E
ooooo`03o`WZ2_oooooooooo00Kooooo0ol9jP[oooooogcooooo00?o2NX:ooooooooool02Oooool4
o`WZ2Ugooooo0_l0003ooooooh;ooooo001Iooooo`Go2NX:oooooomoooooo`03o`WZ2_oooooooooo
00Kooooo0ol9jP[oooooonGooooo001Eooooo`Co2NX:oooooon9ooooo`Co2NX:oooooooXooooo`00
oooooooOooooo`?o2NX:ooooooo/ooooo`00oooooooMooooo`;o2NX:ooooooo_ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocooo
ool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooo
oooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocooo
ool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooo
oooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocooo
ool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooo
oooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocooo
ool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooo
oooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocooo
ool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooo
oooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocooo
ool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooo
oooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooo
oooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?ooooo`00
oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003oooooooooooooooooooo?
ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooooooooooo
ooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo003ooooo
ooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooooloooooo
003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooooooooooo
oloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oooooooooo
oooooooooloooooo003oooooooooooooooooooo?ooooo`00oooooooooooooooooooocoooool00?oo
oooooooooooooooooloooooo0000\
\>"],
  ImageRangeCache->{{{0, 971.875}, {554.938, 0}} -> {-0.0508071, -0.0285774, \
0.00216243, 0.00216243}, {{23.4375, 552}, {541.688, 13.1875}} -> {-0.0444118, \
-0.0250762, 0.00189217, 0.00189217}, {{419.875, 948.375}, {541.688, 13.1875}} -> \
{-0.794478, -0.0250762, 0.00189217, 0.00189217}},
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.4"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.4 Off-Axis Beam Example", "Subsection",
  CellTags->{"AOG0.", "4.4", "AOG4.", "AOG4.4", "AOG4.4.1"}],

Cell[CellGroupData[{

Cell["Set-up", "Subsubsection",
  CellTags->{"AOG0.", "4.4.1", "AOG4.", "AOG4.4", "AOG4.4.1"}],

Cell["\<\
opticalsystemoffaxis = {
Move[GaussianBeam[{5.,5.},{.01,.01},SymbolicWaveLength->\[Lambda]],{0,10}],
Move[PlanoConvexLens[{f,100},{a,50},{t,10},DesignWaveLength->.532],{d1,50}],
Move[Mirror[20],175,-45],
Move[Screen[50],{175,50},90]};\
\>", "Input",
  CellLabel->"In[61]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[opticalsystemoffaxis];", "Input",
  CellLabel->"In[62]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .63021 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0178596 1.01786 -0.170432 1.01786 [
[ 0 0 0 0 ]
[ 1 .63021 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .63021 L
0 .63021 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.11655 .46829 m
.30087 .41044 L
s
0 g
.34776 .36779 m
.33982 .34145 L
s
.33982 .34145 m
.35288 .33719 L
s
.33982 .34145 m
.32913 .31654 L
s
.35244 .39392 m
.34776 .36779 L
s
.34776 .36779 m
.36083 .36357 L
s
.32913 .31654 m
.34219 .31223 L
s
.32913 .31654 m
.31634 .29462 L
s
.35288 .33719 m
.36083 .36357 L
s
.34219 .31223 m
.35288 .33719 L
s
.36083 .36357 m
.36556 .38974 L
s
.35244 .39392 m
.36556 .38974 L
s
.32942 .29025 m
.34219 .31223 L
s
.31634 .29462 m
.32942 .29025 L
s
.32197 .40461 m .36673 .41407 L .35356 .41822 L .656 .751 .92 r
F
0 g
.351 .43911 m
.35356 .41822 L
s
.35244 .39392 m
.35324 .41121 L
s
.32197 .40461 m .3487 .3961 L .36673 .41407 L .656 .751 .92 r
F
0 g
.36424 .43498 m
.36673 .41407 L
s
.36556 .38974 m
.36673 .41407 L
s
.35356 .41822 m
.36673 .41407 L
s
.30222 .2771 m .31416 .30115 L .2875 .31004 L .539 .318 .527 r
F
.30222 .2771 m .31535 .27267 L .31416 .30115 L F
0 g
.31452 .29237 m
.31634 .29462 L
s
.30222 .2771 m
.31535 .27267 L
s
.31535 .27267 m
.32942 .29025 L
s
.28766 .26518 m
.30222 .2771 L
s
.30085 .2607 m
.31535 .27267 L
s
.34485 .45521 m
.351 .43911 L
s
.351 .43911 m
.36424 .43498 L
s
.29585 .38894 m .3487 .3961 L .32197 .40461 L .656 .751 .92 r
F
0 g
.32197 .40461 m
.35356 .41822 L
s
.039 .916 .04 r
.1195 .43364 m
.30248 .37353 L
s
.12972 .46119 m
.31721 .4021 L
s
0 0 0 r
2 Mabswid
.31721 .4021 Mdot
.039 .916 .04 r
.5 Mabswid
.30248 .37353 m
.3334 .36277 L
s
0 g
.36424 .43498 m
.35818 .45107 L
s
.2875 .31004 m .31295 .33001 L .27848 .34137 L .539 .318 .527 r
F
.2875 .31004 m .31416 .30115 L .31295 .33001 L F
0 g
.2875 .31004 m
.30222 .2771 L
s
.31416 .30115 m
.31535 .27267 L
s
.29585 .38894 m .33036 .37783 L .3487 .3961 L .656 .751 .92 r
F
.039 .916 .04 r
.31721 .4021 m
.34393 .39134 L
s
.11808 .45088 m
.30068 .39223 L
s
0 g
.3487 .3961 m
.36673 .41407 L
s
.28766 .26518 m
.30085 .2607 L
s
.28766 .26518 m
.27361 .25975 L
s
0 0 0 r
2 Mabswid
.34393 .39134 Mdot
0 g
.5 Mabswid
.28688 .25522 m
.30085 .2607 L
s
0 0 0 r
2 Mabswid
.3334 .36277 Mdot
.27454 .37137 m .33036 .37783 L .29585 .38894 L .656 .751 .92 r
F
.039 .916 .04 r
.5 Mabswid
.30068 .39223 m
.33272 .38018 L
s
0 g
.29585 .38894 m
.32197 .40461 L
s
.039 .916 .04 r
.10624 .4405 m
.28611 .38161 L
s
0 g
.33544 .46532 m
.34485 .45521 L
s
.34485 .45521 m
.35818 .45107 L
s
.8048 .27142 m
.78533 .29148 L
s
.82803 .25533 m
.8048 .27142 L
s
.78533 .29148 m
.77086 .31425 L
s
.27848 .34137 m .31173 .35927 L .27454 .37137 L .539 .318 .527 r
F
.27848 .34137 m .31295 .33001 L .31173 .35927 L F
0 g
.27848 .34137 m
.2875 .31004 L
s
.31295 .33001 m
.31416 .30115 L
s
.85356 .24425 m
.82803 .25533 L
s
.35818 .45107 m
.34886 .46117 L
s
.77086 .31425 m
.76235 .33829 L
s
0 0 0 r
2 Mabswid
.33272 .38018 Mdot
.33272 .38018 Mdot
0 g
.5 Mabswid
.87977 .23893 m
.85356 .24425 L
s
.85356 .24425 m
.85356 .24425 L
s
.85356 .24425 m
.85604 .27287 L
s
.27454 .37137 m .31173 .35927 L .33036 .37783 L .656 .751 .92 r
F
0 g
.33036 .37783 m
.3487 .3961 L
s
.27361 .25975 m
.28688 .25522 L
s
.27361 .25975 m
.26101 .26134 L
s
.76235 .33829 m
.76041 .36207 L
s
.27437 .25677 m
.28688 .25522 L
s
.27454 .37137 m .31049 .38893 L .27555 .40015 L .539 .318 .527 r
F
.039 .916 .04 r
.30087 .41044 m
.33211 .3978 L
s
.27454 .37137 m .31173 .35927 L .31049 .38893 L .539 .318 .527 r
F
.25789 .35187 m .31173 .35927 L .27454 .37137 L .656 .751 .92 r
F
0 g
.27676 .35447 m
.27848 .34137 L
s
.039 .916 .04 r
.31116 .37281 m
.32163 .36913 L
s
0 0 0 r
2 Mabswid
.33211 .3978 Mdot
0 g
.5 Mabswid
.32333 .46864 m
.33544 .46532 L
s
.33544 .46532 m
.34886 .46117 L
s
0 0 0 r
2 Mabswid
.32163 .36913 Mdot
0 g
.5 Mabswid
.90498 .23979 m
.87977 .23893 L
s
.34886 .46117 m
.33685 .46446 L
s
.85604 .27287 m
.85856 .3019 L
s
.76041 .36207 m
.76526 .38403 L
s
.76041 .36207 m
.79368 .35191 L
s
.76041 .36207 m
.76041 .36207 L
s
.25789 .35187 m .29278 .34039 L .31173 .35927 L .656 .751 .92 r
F
0 g
.31173 .35927 m
.31295 .33001 L
s
.31173 .35927 m
.33036 .37783 L
s
.26101 .26134 m
.25078 .26999 L
s
.27437 .25677 m
.26101 .26134 L
s
.92749 .24686 m
.90498 .23979 L
s
.27555 .40015 m .30923 .41901 L .28185 .42769 L .539 .318 .527 r
F
.27555 .40015 m .31049 .38893 L .30923 .41901 L F
0 g
.27454 .37137 m
.27555 .40015 L
s
.31049 .38893 m
.31173 .35927 L
s
.26423 .2654 m
.27437 .25677 L
s
.79368 .35191 m
.82725 .34166 L
s
.2462 .33029 m .29278 .34039 L .25789 .35187 L .656 .751 .92 r
F
0 g
.25789 .35187 m
.27454 .37137 L
s
.3093 .46476 m
.32333 .46864 L
s
.32333 .46864 m
.33685 .46446 L
s
.76526 .38403 m
.77669 .40266 L
s
.85856 .3019 m
.86112 .33132 L
s
.33685 .46446 m
.3229 .46054 L
s
0 0 0 r
2 Mabswid
.82996 .32975 Mdot
.81679 .34486 Mdot
0 g
.5 Mabswid
.94577 .25979 m
.92749 .24686 L
s
.82725 .34166 m
.86112 .33132 L
s
0 0 0 r
2 Mabswid
.8311 .34048 Mdot
.8311 .34048 Mdot
.2462 .33029 m .27352 .3212 L .29278 .34039 L .656 .751 .92 r
F
0 g
.5 Mabswid
.29278 .34039 m
.31173 .35927 L
s
.25078 .26999 m
.26423 .2654 L
s
.25078 .26999 m
.24369 .28529 L
s
.28185 .42769 m .30795 .44951 L .29429 .45378 L .539 .318 .527 r
F
.28185 .42769 m .30923 .41901 L .30795 .44951 L F
0 g
.27555 .40015 m
.28185 .42769 L
s
.28185 .42769 m
.29429 .45378 L
s
.30923 .41901 m
.31049 .38893 L
s
0 0 0 r
2 Mabswid
.8437 .33664 Mdot
.83169 .35145 Mdot
0 g
.5 Mabswid
.77669 .40266 m
.79405 .41665 L
s
.25723 .2807 m
.26423 .2654 L
s
.29429 .45378 m
.3093 .46476 L
s
.3093 .46476 m
.3229 .46054 L
s
.86371 .36116 m
.86112 .33132 L
s
.86112 .33132 m
.8953 .32088 L
s
.24031 .30627 m .27352 .3212 L .2462 .33029 L .656 .751 .92 r
F
0 g
.2462 .33029 m
.25789 .35187 L
s
.95846 .27779 m
.94577 .25979 L
s
.30795 .44951 m
.3229 .46054 L
s
.30795 .44951 m
.30923 .41901 L
s
.24031 .30627 m .25393 .30169 L .27352 .3212 L .656 .751 .92 r
F
0 g
.25393 .30169 m
.27352 .3212 L
s
.27352 .3212 m
.29278 .34039 L
s
.24031 .30627 m
.2462 .33029 L
s
.8953 .32088 m
.92979 .31035 L
s
.24031 .30627 m
.24369 .28529 L
s
.25723 .2807 m
.24369 .28529 L
s
.79405 .41665 m
.81626 .42494 L
s
.25393 .30169 m
.25723 .2807 L
s
.29429 .45378 m
.30795 .44951 L
s
.27936 .43635 m
.29429 .45378 L
s
.86371 .36116 m
.86634 .39141 L
s
.96459 .29972 m
.95846 .27779 L
s
.29308 .43202 m
.30795 .44951 L
s
.92979 .31035 m
.96459 .29972 L
s
.24031 .30627 m
.25393 .30169 L
s
.24031 .30627 m
.24098 .33151 L
s
.81626 .42494 m
.84183 .42683 L
s
.26562 .41363 m
.27936 .43635 L
s
.27936 .43635 m
.29308 .43202 L
s
.25393 .30169 m
.25466 .32696 L
s
.96361 .32408 m
.96459 .29972 L
s
.96459 .29972 m
.96459 .29972 L
s
.86634 .39141 m
.869 .4221 L
s
.29308 .43202 m
.27937 .40924 L
s
.24098 .33151 m
.25466 .32696 L
s
.24098 .33151 m
.24568 .35919 L
s
.2541 .38727 m
.26562 .41363 L
s
.26562 .41363 m
.27937 .40924 L
s
.84183 .42683 m
.869 .4221 L
s
.2594 .35468 m
.25466 .32696 L
s
.24568 .35919 m
.2594 .35468 L
s
.24568 .35919 m
.2541 .38727 L
s
.2541 .38727 m
.26785 .38281 L
s
.27937 .40924 m
.26785 .38281 L
s
.95547 .34916 m
.96361 .32408 L
s
.26785 .38281 m
.2594 .35468 L
s
.869 .4221 m
.89581 .41099 L
s
.869 .4221 m
.869 .4221 L
s
.94069 .37315 m
.95547 .34916 L
s
.89581 .41099 m
.92031 .39428 L
s
.92031 .39428 m
.94069 .37315 L
s
.77584 .18831 m .77877 .17749 L .78943 .18306 L .766 .489 .516 r
F
.76831 .18606 m .77877 .17749 L .77584 .18831 L F
.76831 .18606 m .76751 .17412 L .77877 .17749 L F
.78297 .19204 m .78943 .18306 L .79878 .19047 L F
.77584 .18831 m .78943 .18306 L .78297 .19204 L F
0 g
.77877 .17749 m
.78943 .18306 L
s
.76088 .18545 m .76751 .17412 L .76831 .18606 L .766 .489 .516 r
F
.76088 .18545 m .75639 .17318 L .76751 .17412 L F
0 g
.76751 .17412 m
.77877 .17749 L
s
.76751 .17412 m
.76751 .17412 L
s
.78922 .197 m .79878 .19047 L .8062 .19922 L .766 .489 .516 r
F
.78297 .19204 m .79878 .19047 L .78922 .197 L F
0 g
.78943 .18306 m
.79878 .19047 L
s
.75405 .18651 m .75639 .17318 L .76088 .18545 L .766 .489 .516 r
F
.75405 .18651 m .74615 .17475 L .75639 .17318 L F
0 g
.75639 .17318 m
.76751 .17412 L
s
.79417 .20285 m .8062 .19922 L .81118 .20875 L .766 .489 .516 r
F
.78922 .197 m .8062 .19922 L .79417 .20285 L F
0 g
.79878 .19047 m
.8062 .19922 L
s
.7729 .1992 m .77584 .18831 L .78297 .19204 L .766 .489 .516 r
F
.76912 .19808 m .77584 .18831 L .7729 .1992 L F
.76912 .19808 m .76831 .18606 L .77584 .18831 L F
.77647 .20107 m .78297 .19204 L .78922 .197 L F
.7729 .1992 m .78297 .19204 L .77647 .20107 L F
.74828 .18918 m .74615 .17475 L .75405 .18651 L F
.74828 .18918 m .7375 .17873 L .74615 .17475 L F
0 g
.74615 .17475 m
.75639 .17318 L
s
.7654 .19777 m .76831 .18606 L .76912 .19808 L .766 .489 .516 r
F
.7654 .19777 m .76088 .18545 L .76831 .18606 L F
0 g
.76751 .17412 m
.76831 .18606 L
s
.77647 .20107 m .78922 .197 L .77961 .20356 L .766 .489 .516 r
F
.77961 .20356 m .78922 .197 L .79417 .20285 L F
.79749 .20922 m .81118 .20875 L .81339 .2184 L F
.79417 .20285 m .81118 .20875 L .79749 .20922 L F
0 g
.8062 .19922 m
.81118 .20875 L
s
.76198 .19831 m .76088 .18545 L .7654 .19777 L .766 .489 .516 r
F
.76198 .19831 m .75405 .18651 L .76088 .18545 L F
.78208 .2065 m .79417 .20285 L .79749 .20922 L F
.77961 .20356 m .79417 .20285 L .78208 .2065 L F
.7591 .19966 m .75405 .18651 L .76198 .19831 L F
.7591 .19966 m .74828 .18918 L .75405 .18651 L F
.74397 .19329 m .7375 .17873 L .74828 .18918 L F
.74397 .19329 m .73101 .18486 L .7375 .17873 L F
0 g
.7375 .17873 m
.74615 .17475 L
s
.79749 .20922 m .81339 .2184 L .79893 .21566 L .766 .489 .516 r
F
.78374 .20969 m .79749 .20922 L .79893 .21566 L F
.78208 .2065 m .79749 .20922 L .78374 .20969 L F
.79893 .21566 m .81339 .2184 L .81264 .22754 L F
0 g
.81118 .20875 m
.81339 .2184 L
s
.81339 .2184 m
.81339 .2184 L
s
.76993 .21016 m .7729 .1992 L .77647 .20107 L .766 .489 .516 r
F
.76993 .21016 m .76912 .19808 L .7729 .1992 L F
.76993 .21016 m .77647 .20107 L .77961 .20356 L F
.76993 .21016 m .7654 .19777 L .76912 .19808 L F
0 g
.76831 .18606 m
.76912 .19808 L
s
.76993 .21016 m .77961 .20356 L .78208 .2065 L .766 .489 .516 r
F
.76993 .21016 m .76198 .19831 L .7654 .19777 L F
.75695 .20172 m .74828 .18918 L .7591 .19966 L F
.75695 .20172 m .74397 .19329 L .74828 .18918 L F
.76993 .21016 m .78208 .2065 L .78374 .20969 L F
.78374 .20969 m .79893 .21566 L .78445 .21292 L F
.79893 .21566 m .81264 .22754 L .79841 .22175 L F
.78445 .21292 m .79893 .21566 L .79841 .22175 L F
0 g
.79893 .21566 m
.81339 .2184 L
s
.76993 .21016 m .7591 .19966 L .76198 .19831 L .766 .489 .516 r
F
.76993 .21016 m .78374 .20969 L .78445 .21292 L F
.74142 .19856 m .73101 .18486 L .74397 .19329 L F
.74142 .19856 m .72714 .19275 L .73101 .18486 L F
0 g
.73101 .18486 m
.7375 .17873 L
s
.76993 .21016 m .75695 .20172 L .7591 .19966 L .766 .489 .516 r
F
.78445 .21292 m .79841 .22175 L .78418 .21596 L F
.76993 .21016 m .78445 .21292 L .78418 .21596 L F
0 g
.78445 .21292 m
.79893 .21566 L
s
.79841 .22175 m .81264 .22754 L .80897 .23554 L .766 .489 .516 r
F
0 g
.81264 .22754 m
.81339 .2184 L
s
.75568 .20436 m .74397 .19329 L .75695 .20172 L .766 .489 .516 r
F
.75568 .20436 m .74142 .19856 L .74397 .19329 L F
.79841 .22175 m .80897 .23554 L .79595 .22707 L F
.78418 .21596 m .79841 .22175 L .79595 .22707 L F
.76993 .21016 m .75568 .20436 L .75695 .20172 L F
.78418 .21596 m .79595 .22707 L .78294 .21862 L F
.76993 .21016 m .78418 .21596 L .78294 .21862 L F
.76993 .21016 m .75539 .20741 L .75568 .20436 L F
.039 .916 .04 r
.75795 .20789 m
.82996 .32975 L
s
.76993 .21016 m .75608 .21064 L .75539 .20741 L .766 .489 .516 r
F
.039 .916 .04 r
.33272 .38018 m
.75558 .20833 L
s
.32163 .36913 m
.75593 .20994 L
s
.76167 .21045 m
.8437 .33664 L
s
.75865 .21055 m
.8311 .34048 L
s
.76993 .21016 m .75773 .21385 L .75608 .21064 L .766 .489 .516 r
F
.76993 .21016 m .76021 .21681 L .75773 .21385 L F
.039 .916 .04 r
.76062 .21653 m
.83169 .35145 L
s
.76993 .21016 m .76336 .21931 L .76021 .21681 L .766 .489 .516 r
F
.76993 .21016 m .76695 .22119 L .76336 .21931 L F
.76993 .21016 m .77075 .22232 L .76695 .22119 L F
.76993 .21016 m .7745 .22262 L .77075 .22232 L F
.76993 .21016 m .77792 .22206 L .7745 .22262 L F
.76993 .21016 m .7808 .2207 L .77792 .22206 L F
.76993 .21016 m .78294 .21862 L .7808 .2207 L F
0 g
.76993 .21016 m
.78445 .21292 L
s
.76912 .19808 m
.76993 .21016 L
s
.75539 .20741 m .74142 .19856 L .75568 .20436 L .766 .489 .516 r
F
.039 .916 .04 r
.33211 .3978 m
.75445 .20681 L
s
.78294 .21862 m .7917 .23126 L .7808 .2207 L .766 .489 .516 r
F
.78294 .21862 m .79595 .22707 L .7917 .23126 L F
0 0 0 r
2 Mabswid
.75671 .20579 Mdot
.7408 .20464 m .72714 .19275 L .74142 .19856 L .766 .489 .516 r
F
.75539 .20741 m .7408 .20464 L .74142 .19856 L F
0 0 0 r
.7603 .20834 Mdot
.79595 .22707 m .80262 .24184 L .7917 .23126 L .766 .489 .516 r
F
.79595 .22707 m .80897 .23554 L .80262 .24184 L F
0 g
.5 Mabswid
.80897 .23554 m
.81264 .22754 L
s
0 0 0 r
2 Mabswid
.75707 .20773 Mdot
.75707 .20773 Mdot
.7408 .20464 m .72619 .20187 L .72714 .19275 L .766 .489 .516 r
F
0 g
.5 Mabswid
.72714 .19275 m
.73101 .18486 L
s
.75608 .21064 m .7408 .20464 L .75539 .20741 L .766 .489 .516 r
F
.039 .916 .04 r
.75406 .20985 m
.81679 .34486 L
s
0 g
.75539 .20741 m
.76993 .21016 L
s
.039 .916 .04 r
.34393 .39134 m
.74983 .20819 L
s
.3334 .36277 m
.75508 .21025 L
s
.7808 .2207 m .78594 .23401 L .77792 .22206 L .766 .489 .516 r
F
.7808 .2207 m .7917 .23126 L .78594 .23401 L F
0 0 0 r
2 Mabswid
.75269 .2069 Mdot
.75695 .20957 Mdot
.75608 .21064 m .74218 .21112 L .7408 .20464 L .766 .489 .516 r
F
.75773 .21385 m .74218 .21112 L .75608 .21064 L F
.77792 .22206 m .77908 .23513 L .7745 .22262 L F
.77792 .22206 m .78594 .23401 L .77908 .23513 L F
.74218 .21112 m .72619 .20187 L .7408 .20464 L F
0 g
.5 Mabswid
.7408 .20464 m
.75539 .20741 L
s
.75773 .21385 m .74546 .21755 L .74218 .21112 L .766 .489 .516 r
F
.76021 .21681 m .74546 .21755 L .75773 .21385 L F
.7917 .23126 m .794 .246 L .78594 .23401 L F
.7917 .23126 m .80262 .24184 L .794 .246 L F
0 g
.80262 .24184 m
.80897 .23554 L
s
.7745 .22262 m .77158 .23455 L .77075 .22232 L .766 .489 .516 r
F
.7745 .22262 m .77908 .23513 L .77158 .23455 L F
.76021 .21681 m .75042 .22349 L .74546 .21755 L F
.76336 .21931 m .75042 .22349 L .76021 .21681 L F
.77075 .22232 m .76395 .23229 L .76695 .22119 L F
.77075 .22232 m .77158 .23455 L .76395 .23229 L F
0 g
.76993 .21016 m
.77075 .22232 L
s
.76336 .21931 m .75673 .22852 L .75042 .22349 L .766 .489 .516 r
F
.76695 .22119 m .75673 .22852 L .76336 .21931 L F
.76695 .22119 m .76395 .23229 L .75673 .22852 L F
.74218 .21112 m .72822 .2116 L .72619 .20187 L F
0 g
.72619 .20187 m
.72714 .19275 L
s
.72619 .20187 m
.7408 .20464 L
s
.72619 .20187 m
.72619 .20187 L
s
.74546 .21755 m .72822 .2116 L .74218 .21112 L .766 .489 .516 r
F
.78594 .23401 m .78369 .24771 L .77908 .23513 L F
.78594 .23401 m .794 .246 L .78369 .24771 L F
0 g
.794 .246 m
.80262 .24184 L
s
.74546 .21755 m .73313 .22127 L .72822 .2116 L .766 .489 .516 r
F
0 g
.72619 .20187 m
.72822 .2116 L
s
.75042 .22349 m .73313 .22127 L .74546 .21755 L .766 .489 .516 r
F
.77908 .23513 m .77241 .24685 L .77158 .23455 L F
.77908 .23513 m .78369 .24771 L .77241 .24685 L F
.75042 .22349 m .74058 .23021 L .73313 .22127 L F
0 g
.72822 .2116 m
.73313 .22127 L
s
.75673 .22852 m .74058 .23021 L .75042 .22349 L .766 .489 .516 r
F
.77158 .23455 m .76093 .24346 L .76395 .23229 L F
.77158 .23455 m .77241 .24685 L .76093 .24346 L F
0 g
.77075 .22232 m
.77158 .23455 L
s
.77158 .23455 m
.77241 .24685 L
s
.78369 .24771 m
.794 .246 L
s
.75673 .22852 m .75007 .23778 L .74058 .23021 L .766 .489 .516 r
F
.76395 .23229 m .75007 .23778 L .75673 .22852 L F
.76395 .23229 m .76093 .24346 L .75007 .23778 L F
0 g
.73313 .22127 m
.74058 .23021 L
s
.77241 .24685 m
.78369 .24771 L
s
.74058 .23021 m
.75007 .23778 L
s
.76093 .24346 m
.77241 .24685 L
s
.77241 .24685 m
.77241 .24685 L
s
.75007 .23778 m
.76093 .24346 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[62]:=",
  ImageSize->{885, 557.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=e0002;B000`400?l00000o`00003ooooooooo
ooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00
ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomh
ooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooo
oooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooo
oooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo
003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooooooooooo
ogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooo
ooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oo
ooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?oo
ool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooooooooooo
ooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooo
ooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00
ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomh
ooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooo
oooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooo
oooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo
003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooooooooooo
ogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooo
ooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oo
ooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?oo
ool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooooooooooo
ooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooo
ooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00
ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomh
ooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooo
oooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooo
oooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo
003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooooooooooo
ogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooo
ooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oo
ooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?oo
ool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooooooooooo
ooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooo
ooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00
ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomh
ooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooo
oooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooo
oooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo
003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooooooooooo
ogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooo
ooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oo
ooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?oo
ool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooooooooooo
ooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooo
ooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00
ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomh
ooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooo
oooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooo
oooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo
003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooooooooooo
ogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooo
ooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oo
ooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?oo
ool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooooooooooo
ooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooo
ooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00
oooooooooooooi[ooooo2_l00004ooooo`03o`000?oooooooooo0<cooooo003oooooooooooooU?oo
ool6o`0000[oa7f41ol0003<ooooo`00oooooooooooooi;ooooo0_l0000DolAmQ003o`000?o4OHCo
a7f400?o0000bOooool00?oooooooooooon@ooooo`;o00005_o4OH@00ol0003oa7f4olAmQ003olAm
Q0?o0000a_ooool00?oooooooooooon>ooooo`;o00006?o4OH@00ol0003oa7f4olAmQ006olAmQ0?o
0000`oooool00?oooooooooooon=ooooo`03o`000?o4OHCoa7f401Soa7f400?o0000olAmQ?o4OH@0
2Oo4OH@2o`000<7ooooo003oooooooooooooS?ooool00ol0003oa7f4olAmQ00IolAmQ003o`000?o4
OHCoa7f400_oa7f40_l0002oooooo`00oooooooooooooh_ooooo00?o0000olAmQ?o4OH@06oo4OH@0
0ol0003oa7f4olAmQ00<olAmQ003o`000?oooooooooo0;cooooo003oooooooooooooR_ooool00ol0
003oa7f4olAmQ00LolAmQ003o`000?o4OHCoa7f400goa7f40_l0002looooo`00ooooooooooooohWo
oooo00?o0000olAmQ?o4OH@07Oo4OH@00ol0003oa7f4olAmQ00?olAmQ0;o0000^_ooool00?oooooo
oooooon8ooooo`03o`000?o4OHCoa7f401koa7f400?o0000olAmQ?o4OH@04Oo4OH@00ol0003ooooo
ooooo`2gooooo`00ooooooooooooohSooooo00?o0000olAmQ?o4OH@07_o4OH@00ol0003oa7f4olAm
Q00BolAmQ003o`000?oooooooooo0;Kooooo003oooooooooooooQoooool00ol0003oa7f4olAmQ00O
olAmQ003o`000?o4OHCoa7f401?oa7f40_l0002fooooo`00ooooooooooooohOooooo00?o0000olAm
Q?o4OH@07oo4OH@00ol0003oa7f4olAmQ00EolAmQ003o`000?oooooooooo0;?ooooo003ooooooooo
ooooQ_ooool00ol0003oa7f4olAmQ00PolAmQ003o`000?o4OHCoa7f401Koa7f400?o0000oooooooo
ool0/_ooool00?oooooooooooon5ooooo`03o`000?o4OHCoa7f4027oa7f400?o0000olAmQ?o4OH@0
5oo4OH@00ol0003oooooooooo`2aooooo`00ooooooooooooohGooooo00?o0000olAmQ?o4OH@08Oo4
OH@00ol0003oa7f4olAmQ00GolAmQ003o`000?oooooooooo0;7ooooo003oooooooooooooQ?ooool0
0ol0003oa7f4olAmQ00RolAmQ003o`000?o4OHCoa7f401Soa7f400?o0000ooooooooool0/?ooool0
0?oooooooooooon4ooooo`03o`000?o4OHCoa7f402;oa7f400?o0000olAmQ?o4OH@06Oo4OH@00ol0
003oooooooooo`2_ooooo`00ooooooooooooohCooooo00?o0000olAmQ?o4OH@08_o4OH@00ol0003o
a7f4olAmQ00JolAmQ003o`000?oooooooooo0:kooooo003oooooooooooooQ?ooool00ol0003oa7f4
olAmQ00RolAmQ003o`000?o4OHCoa7f401_oa7f400?o0000ooooooooool0[Oooool00?oooooooooo
oon4ooooo`03o`000?o4OHCoa7f402;oa7f400?o0000olAmQ?o4OH@07?o4OH@00ol0003ooooooooo
o`2/ooooo`00oooooooooooooh?ooooo00?o0000olAmQ?o4OH@08oo4OH@00ol0003oa7f4olAmQ00M
olAmQ003o`000?oooooooooo0:_ooooo003oooooooooooooPoooool00ol0003oa7f4olAmQ00SolAm
Q003o`000?o4OHCoa7f401koa7f400?o0000ooooooooool0Z_ooool00?oooooooooooon3ooooo`03
o`000?o4OHCoa7f402?oa7f400?o0000olAmQ?o4OH@07_o4OH@00ol0003oooooooooo`2Zooooo`00
oooooooooooooh?ooooo0ol0000SolAmQ003o`000?o4OHCoa7f401ooa7f400?o0000ooooooooool0
ZOooool00?oooooooooooon3ooooo`03o`000?o4OHCoa7f400Go00007_o4OH@00ol0003oa7f4olAm
Q00OolAmQ003o`000?oooooooooo0:Wooooo003oooooooooooooPoooool00ol0003oa7f4olAmQ005
olAmQ0Co00006_o4OH@00ol0003oa7f4olAmQ00PolAmQ003o`000?oooooooooo0:Sooooo003ooooo
ooooooooQ?ooool00ol0003oa7f4olAmQ008olAmQ0Go00002_o4OH@2o`0000[oa7f400?o0000olAm
Q?o4OH@07oo4OH@00ol0003oooooooooo`2Xooooo`00ooooooooooooohCooooo00?o0000olAmQ?o4
OH@03Oo4OH@8o`000004o`WZ2_o4OHCo0000o`0000[oa7f400?o0000olAmQ?o4OH@08?o4OH@00ol0
003oooooooooo`2Wooooo`00ooooooooooooohCooooo00?o0000olAmQ?o4OH@04oo4OH@9o`0000Oo
a7f400?o0000olAmQ?o4OH@08?o4OH@00ol0003oooooooooo`2Wooooo`00ooooooooooooohCooooo
00?o0000olAmQ?o4OH@04Oo4OH@00ol9jP[oa7f4olAmQ002olAmQ004o`WZ2_l0003o0000olAmQ0Oo
00000_o4OH@00ol0003oa7f4olAmQ00QolAmQ003o`000?oooooooooo0:Kooooo003ooooooooooooo
Q?ooool00ol0003oa7f4olAmQ00EolAmQ004o`WZ2_o4OHCo0000o`0000Soa7f41Ol0000QolAmQ003
o`000?oooooooooo0:Kooooo003oooooooooooooQOooool00ol0003oa7f4olAmQ00HolAmQ004o`WZ
2_o4OHCoa7f4o`WZ2PKoa7f400?o0000olAmQ?o4OH@01Ol0000LolAmQ003o`000?oooooooooo0:Ko
oooo003oooooooooooooQOooool00ol0003oa7f4olAmQ00RolAmQ003o`000?o4OHCoa7f400Goa7f4
1?l0000IolAmQ003o`000?oooooooooo0:Gooooo003oooooooooooooQOooool00ol0003oa7f4olAm
Q00RolAmQ003o`000?o4OHCoa7f400Woa7f41Ol0000DolAmQ003o`000?oooooooooo0:Gooooo003o
ooooooooooooQ_ooool00ol0003oa7f4olAmQ00QolAmQ003o`000?o4OHCoa7f400koa7f41ol0000=
olAmQ003o`000?oooooooooo0:Gooooo003oooooooooooooQ_ooool00ol0003oa7f4olAmQ00QolAm
Q003o`000?o4OHCoa7f401Goa7f41Ol00008olAmQ003o`000?oooooooooo0:Gooooo003ooooooooo
ooooQoooool00ol0003oa7f4olAmQ00QolAmQ003o`000?o4OHCoa7f401Woa7f41?l00004olAmQ003
o`000?oooooooooo0:Gooooo003oooooooooooooQOooool2o`WZ2P03o`000?o4OHCoa7f4027oa7f4
00?o0000olAmQ?o4OH@07Oo4OH@4o`000003olAmQ?l0003o00000:Gooooo003oooooooooooooPooo
ool2o`WZ2P04ooooool9jP[o2NX:o`0002;oa7f400?o0000olAmQ?o4OH@08Oo4OH@2o`000:Kooooo
003oooooooooooooP?ooool8o`WZ2P03o`000?o4OHCoa7f4023oa7f400?o0000olAmQ?o4OH@08_o4
OH@00ol0003oooooooooo`2Tooooo`00ooooooooooooogkooooo1ol9jPX4ooooo`03o`000?o4OHCo
a7f401ooa7f400?o0000olAmQ?o4OH@08_o4OH@00ol0003oooooooooo`2Tooooo`00oooooooooooo
ogcooooo1ol9jPX6ooooo`03o`000?o4OHCoa7f401ooa7f400?o0000olAmQ?o4OH@08_o4OH@00ol0
003oooooooooo`2Tooooo`00ooooooooooooog[ooooo1_l9jPX:ooooo`03o`000?o4OHCoa7f401ko
a7f400?o0000olAmQ?o4OH@08_o4OH@00ol0003oooooooooo`2Tooooo`00ooooooooooooogSooooo
1Ol9jPX>ooooo`03o`000?o4OHCoa7f401goa7f400?o0000olAmQ?o4OH@08_o4OH@00ol0003ooooo
ooooo`2Tooooo`00ooooooooooooogGooooo1Ol9jPXBooooo`03o`000?o4OHCoa7f401coa7f400?o
0000olAmQ?o4OH@08_o4OH@00ol0003oooooooooo`2Tooooo`00ooooooooooooog?ooooo1?l9jPXF
ooooo`03o`000?o4OHCoa7f401_oa7f400?o0000olAmQ?o4OH@08_o4OH@00ol0003oooooooooo`2T
ooooo`00ooooooooooooog7ooooo1?l9jPXIooooo`03o`000?o4OHCoa7f401[oa7f400?o0000olAm
Q?o4OH@08_o4OH@00ol0003oooooooooo`2Tooooo`00ooooooooooooofkooooo1?l9jPXMooooo`03
o`000?o4OHCoa7f401Woa7f400?o0000olAmQ?o4OH@08_o4OH@00ol0003oooooooooo`2Tooooo`00
ooooooooooooofcooooo1?l9jPXPooooo`;o00006Oo4OH@00ol0003oa7f4olAmQ00QolAmQ003o`00
0?oooooooooo0:Gooooo003oooooooooooooJOooool4o`WZ2RGooooo00?o0000olAmQ?o4OH@05_o4
OH@00ol0003oa7f4olAmQ00QolAmQ003o`000?oooooooooo0:Gooooo003oooooooooooooI_ooool5
o`WZ2RSooooo00?o0000olAmQ?o4OH@05Oo4OH@00ol0003oa7f4olAmQ00PolAmQ003o`000?oooooo
oooo0:Kooooo003oooooooooooooHoooool5o`WZ2Rcooooo00?o0000olAmQ?o4OH@05?o4OH@00ol0
003oa7f4olAmQ00OolAmQ003o`000?oooooooooo0:Oooooo003oooooooooooooHOooool5o`WZ2Roo
oooo00?o0000olAmQ?o4OH@04oo4OH@00ol0003oa7f4olAmQ00OolAmQ003o`000?oooooooooo0:Oo
oooo003oooooooooooooG_ooool6o`WZ2S;ooooo00?o0000olAmQ?o4OH@04_o4OH@00ol0003oa7f4
olAmQ00NolAmQ003o`000?oooooooooo0:Sooooo003oooooooooooooFoooool7o`WZ2SGooooo00?o
0000olAmQ?o4OH@04Oo4OH@00ol0003oa7f4olAmQ00MolAmQ003o`000?oooooooooo0:Wooooo003o
ooooooooooooFOooool6o`WZ2SWooooo0_l0000AolAmQ003o`000?o4OHCoa7f401coa7f400?o0000
ooooooooool0Z_ooool00?oooooooooooomFooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:?Oooool2
o`0000ooa7f400?o0000olAmQ?o4OH@06oo4OH@00ol0003oooooooooo`0mooooo`ko0000H?ooool0
0?oooooooooooomCooooo`?o2NX:00?oooooo`WZ2_l9jPX00_l9jPY1ooooo`;o00003Oo4OH@00ol0
003oa7f4olAmQ00JolAmQ003o`000?oooooooooo03Wooooo1Ol0000>ooooo`go0000Doooool00?oo
oooooooooom@ooooo`?o2NX:0_ooool4o`WZ2TGooooo0_l0000<olAmQ003o`000?o4OHCoa7f401Oo
a7f40_l0000gooooo`Go00008?ooool3o`00053ooooo003oooooooooooooC_ooool2o`WZ2P;ooooo
1?l9jPY:ooooo`;o00002_o4OH@00ol0003oa7f4olAmQ00EolAmQ0;o0000=Oooool4o`0002Sooooo
0ol0001=ooooo`00oooooooooooood_ooooo0ol9jPX2ooooo`Co2NX:C_ooool3o`0000Ooa7f400?o
0000olAmQ?o4OH@04oo4OH@2o`00033ooooo00?o0000ooooool000001?l0000_ooooo`Co0000BOoo
ool00?oooooooooooom8ooooo`?o2NX:0_ooool5o`WZ2U?ooooo0ol00004olAmQ003o`000?o4OHCo
a7f4017oa7f40_l0000aooooo`?o0000>?ooool3o`0004Kooooo003oooooooooooooAOooool3o`WZ
2P?ooooo0_l9jPX00ooooooo2NX:o`WZ2P1Hooooo`?o000000?oa7f4o`000?o4OH@03oo4OH@3o`00
033ooooo0ol000000ooooooo0000ooooo`0kooooo`?o0000@oooool00?oooooooooooom3ooooo`;o
2NX:0oooool6o`WZ2Ugooooo1ol00006olAmQ0Go0000<Oooool2o`0000Cooooo00?o0000oooooooo
ool0?Oooool3o`00043ooooo003ooooooooooooo@?ooool3o`WZ2P?ooooo0_l9jPX00ooooooo2NX:
o`WZ2P1Pooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooool000001Ol000000ol9jP[ooooo
ooooo`0`ooooo`?o00001_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03gooooo
003ooooooooooooo?Oooool3o`WZ2P?ooooo0ol9jPX00ooooooo2NX:o`WZ2P1Sooooo`03o`WZ2_oo
oooooooo00;ooooo00Go2NX:ooooool9jP[oooooo`WZ2P03ooooo`03o`WZ2_oooooooooo02cooooo
0ol00009ooooo`03o`000?oooooooooo047ooooo0_l0000mooooo`00oooooooooooooc[ooooo0ol9
jPX4ooooo`;o2NX:0_ooool2o`WZ2VGooooo00?o2NX:ooooooooool00_ooool01Ol9jP[oooooo`WZ
2_oooooo2NX:00?ooooo00?o2NX:ooooooooool0:_ooool2o`0000cooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`0jooooo`00ooooooooooooocOooooo1?l9jPX4ooooo`;o2NX:00Co
ooooo`WZ2_l9jP[o2NX:J?ooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_oooooo2NX:ooooool9
jPX00oooool00ol9jP[oooooooooo`0Vooooo`?o00003_ooool00ol0003oooooooooo`14ooooo`;o
0000>_ooool00?ooooooooooooleooooo`?o2NX:1?ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2V[o
oooo00?o2NX:ooooooooool00_ooool01Ol9jP[oooooo`WZ2_oooooo2NX:00Cooooo00?o2NX:oooo
ooooool08oooool2o`0001;ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0goooo
o`00oooooooooooooc;ooooo0ol9jPX5ooooo`;o2NX:0_ooool2o`WZ2Vkooooo00?o2NX:oooooooo
ool00_ooool01Ol9jP[oooooo`WZ2_oooooo2NX:00?ooooo00?o2NX:ooooooooool08?ooool3o`00
01Cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0fooooo`00n_ooool5o`000?oo
oooo;oooool3o`WZ2PGooooo0ol9jPX2ooooo`;o2NX:L?ooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooo2NX:00;ooooo00Go2NX:ooooooooooooooooo`WZ2P0Oooooo`;o00005oooool00ol0
003oooooooooo`17ooooo`;o0000=_ooool00?Gooooo1ol00003ooooo`?o0000oooooolYooooo`Co
2NX:1Oooool2o`WZ2P;ooooo0ol9jPYcooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooool9
jP[oooooo`WZ2P04ooooo`03o`WZ2_oooooooooo01_ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo03?ooooo003aooooo`Co000000Coooooo`000?l0
003o00002Oooool3o`000?oooooo8oooool4o`WZ2PGooooo0ol9jPX2ooooo`?o2NX:MOooool00ol9
jP[oooooooooo`02ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:0oooool00ol9jP[ooooooooo
o`0Jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B_ooool2o`0003?ooooo003^
ooooo`?o00000_ooool3o`0000oooooo0_l0003ooooooaoooooo0ol9jPX6ooooo`;o2NX:0oooool3
o`WZ2WSooooo00?o2NX:ooooooooool00_ooool01Ol9jP[oooooo`WZ2_oooooo2NX:00Cooooo00?o
2NX:ooooooooool05oooool2o`0001_ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0`ooooo`00joooool3o`000003ooooool0003o000000?o00004oooool3o`000?oooooo6Oooool4
o`WZ2PGooooo0ol9jPX3ooooo`;o2NX:Noooool00ol9jP[oooooooooo`03ooooo`05o`WZ2_oooooo
2NX:ooooool9jPX01?ooool00ol9jP[oooooooooo`0Eooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`0_ooooo`00j?ooool7o`0000Gooooo0ol0000B
ooooo`?o0000oooooolDooooo`Co2NX:1_ooool2o`WZ2PCooooo0_l9jPYnooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooool9jPX00_ooool01Ol9jP[ooooooooooooooooo2NX:01Kooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02oooooo003U
ooooo`Co00000oooool00ol0003oooooooooo`08ooooo`;o00003Oooool3o`0000?ooooo00?o0000
ooooooooool0ooooool>ooooo`Co2NX:1_ooool3o`WZ2P?ooooo0ol9jPZ0ooooo`03o`WZ2_oooooo
oooo00?ooooo00Go2NX:ooooool9jP[oooooo`WZ2P04ooooo`03o`WZ2_oooooooooo017ooooo0_l0
000Oooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0;_ooool00>Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`;o00002?ooool3o`0000Oooooo00?o0000
ooooooooool0ooooool;ooooo`?o2NX:1oooool2o`WZ2PCooooo0ol9jPZ2ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooool9jPX00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo02gooooo003Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool3o`00
00;ooooo0ol0000;ooooo`03o`000?oooooooooo0?oooooo1oooool4o`WZ2POooooo0_l9jPX4oooo
o`?o2NX:QOooool00ol9jP[oooooooooo`03ooooo`05o`WZ2_oooooo2NX:ooooool9jPX01?ooool0
0ol9jP[oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`0]ooooo`00hOooool2o`0000Gooooo0_l0000Dooooo`;o00003oooool00ol0
003oooooooooo`3oooooo`?ooooo1?l9jPX7ooooo`?o2NX:1?ooool2o`WZ2XSooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooo`WZ2P02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool02oooool2o`0002?ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0/oooo
o`00h?ooool00ol0003oooooooooo`02ooooo`?o000000?oooooo`000?ooool05Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo0?kooooo1?l9jPX8ooooo`;o2NX:1?ooool3o`WZ2X_o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooo`WZ2P02ooooo`05o`WZ2_oooooooooooooo
ool9jPX03?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool0:oooool00=oooooo00?o0000ooooooooool00ol00003ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3jooooo`Co2NX:2?ooool3o`WZ2PCo
oooo0ol9jPZ=ooooo`03o`WZ2_oooooooooo00?ooooo00Ko2NX:oooooooooooo2NX:ooooool9jPX4
ooooo`03o`WZ2_oooooooooo00Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo02_ooooo003Nooooo`Co00001_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0moooool4o`WZ2PSooooo0_l9jPX5oooo
o`?o2NX:T?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo2NX:00;ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`05ooooo`;o0000:?ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo02[ooooo003Mooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0loooool4o`WZ2PSooooo0ol9jPX5ooooo`?o
2NX:T_ooool00ol9jP[oooooooooo`03ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:1?ooool0
0ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`0Yooooo`00gOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01[ooooo0_l0000>ooooo`03o`000?oooooooooo0>oooooo1?l9jPX9ooooo`;o2NX:1_ooool2o`WZ
2YKooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooo`WZ2P02ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool0:?ooool00=cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0joooool5o`WZ2PSo
oooo0ol9jPX5ooooo`?o2NX:V?ooool00ol9jP[oooooooooo`03ooooo`06o`WZ2_ooooooooooo`WZ
2_oooooo2NX:1Oooool01?l9jP[oooooooooool0000/ooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool0:?ooool00=cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00_ooooo0_l0003Zooooo`Co2NX:2Oooool2o`WZ2PKooooo0ol9jPZK
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooool9jPX00_ooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooo000002gooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0W
ooooo`00foooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool01oooool3o`000003ohUAQ_l0003ooooo0>Kooooo1?l9jPX9ooooo`?o2NX:1_ooool3o`WZ
2Ygooooo00?o2NX:ooooooooool00oooool01?l9jP[oooooooooool9jPX2ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool0;?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo02Kooooo003Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`03ooooo`?o00001?n9DHH2o`000>?ooooo1?l9jPX:ooooo`;o2NX:1oooool2o`WZ
2Z7ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooo`WZ2P02ooooo`07o`WZ2_oooooooooo
ooooool0003oooooo`WZ2P0]ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool09_oo
ool00=_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
000000;o00001on9DHH00ol0003oooooo`00003Oooooo`Go2NX:2_ooool2o`WZ2PKooooo0ol9jPZS
ooooo`03o`WZ2_oooooooooo00?ooooo00Co2NX:oooooooooooo2NX:0_ooool00ol9jP[oooooo`00
0002ooooo`03o`WZ2_oooooooooo02_ooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`0Uooooo`00f_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000
ohUAQ_n9DHH02?n9DHH01?l0003oooooooooool0003Kooooo`Go2NX:2_ooool3o`WZ2PKooooo0ol9
jPZVooooo`03o`WZ2_oooooooooo00?ooooo00Oo2NX:oooooooooooo2NX:ooooool9jP[o000000Co
oooo00?o2NX:ooooooooool0:_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo02Co
oooo003Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003oRE66
ohUAQP08ohUAQP05o`000?ooooooooooooooool00000f?ooool4o`WZ2P_ooooo0_l9jPX7ooooo`?o
2NX:Z?ooool00ol9jP[oooooooooo`03ooooo`07o`WZ2_ooooooooooo`WZ2_oooooo0000o`WZ2P05
ooooo`03o`WZ2_oooooooooo02Wooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0T
ooooo`00fOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo00?o0000ohUA
Q_n9DHH02On9DHH00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=;ooooo1Ol9jPX:oooo
o`?o2NX:1oooool3o`WZ2Z[ooooo00?o2NX:ooooooooool01?ooool01?l9jP[oooooooooool9jPX2
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0:Oooool00ol0003oooooooooo`1G
ooooo`03o`000?oooooooooo02Cooooo003Iooooo`03o`000?oooooooooo00Kooooo0_l0000Voooo
o`03o`000?n9DHKoRE6600WoRE6600?o0000ooooooooool00oooool00ol0003oooooooooo`3>oooo
o`Go2NX:2oooool2o`WZ2PSooooo0_l9jPZ^ooooo`03o`WZ2_oooooooooo00?ooooo00Co2NX:oooo
ool0003o2NX:0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo02Wooooo00?o0000
ooooooooool0Eoooool00ol0003oooooooooo`0Sooooo`00f?ooool00ol0003oooooooooo`04oooo
o`?o000000?oooooo`000?ooool09?ooool00ol0003oRE66ohUAQP0:ohUAQP03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0b_ooool5o`WZ2P_ooooo0ol9jPX7ooooo`?o2NX:/?ooool00ol9
jP[oooooooooo`04ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`0Xooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool08oooool0
0=Sooooo00Co0000oooooooooooooooo0ol00004ooooo`03o`000?oooooooooo02?ooooo00?o0000
ohUAQ_n9DHH02_n9DHH00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<Oooooo1Ol9jPX<
ooooo`;o2NX:2?ooool3o`WZ2[?ooooo00?o2NX:ooooooooool00_ooool01Ol0003o2NX:oooooooo
oooo2NX:00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Xooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool08oooool00=Sooooo1?l00007ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ohUAQ_n9DHH02_n9DHH00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0<Cooooo1Ol9jPX;ooooo`?o2NX:2?ooool3o`WZ2[Gooooo00Go2NX:ooooooooooooooooo`00
0002ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`0Wooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool08_ooool00=Oooooo0_l0
0009ooooo`03o`000?oooooooooo02?ooooo00?o0000ohUAQ_n9DHH02on9DHH00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0<3ooooo1Ol9jPX<ooooo`;o2NX:2Oooool3o`WZ2[Sooooo00?o
2NX:ooooool000001?ooool00ol9jP[oooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool09oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo02;ooooo003G
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08oooool00ol0003oRE66ohUAQP0;
ohUAQP03o`000?oooooooooo00Oooooo00?o0000ooooooooool0_?ooool5o`WZ2Pcooooo0ol9jPX8
ooooo`?o2NX:^oooool00ol9jP[o0000ooooo`04ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Vooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool08_ooool00=Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0R
ooooo`03o`000?n9DHKoRE6600_oRE6600?o0000ooooooooool02Oooool00ol0003oooooooooo`2h
ooooo`Go2NX:3Oooool2o`WZ2PWooooo0ol9jPZmooooo`03o`000?l9jP[ooooo00Gooooo00Co2NX:
oooooooooooo2NX:0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo02Gooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0Qooooo`00eoooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02;ooooo00?o0000ohUAQ_n9DHH02on9DHH00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo0;Gooooo1Ol9jPX=ooooo`;o2NX:2Oooool3o`WZ2[kooooo00?o0000
ooooool9jPX01_ooool01?l9jP[oooooooooool9jPX2ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool09Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo027ooooo003F
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool00ol0003oRE66ohUAQP0<
ohUAQP03o`000?oooooooooo00[ooooo0_l0002cooooo`Go2NX:3Oooool3o`WZ2PWooooo0ol9jPZo
ooooo`05o`000?ooooooooooooooool9jPX01_ooool01?l9jP[oooooooooool9jPX2ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool09?ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo027ooooo003Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Ooo
ool00ol0003oRE66ohUAQP0<ohUAQP03o`000?oooooooooo00Oooooo0ol000000ooooooo0000oooo
o`2_ooooo`Go2NX:3_ooool2o`WZ2P[ooooo0ol9jP[0ooooo`03o`000?oooooooooo00;ooooo00?o
2NX:ooooooooool01?ooool01?l9jP[oooooooooool9jPX3ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool08oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo027ooooo
003Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003oRE66ohUA
QP0=ohUAQP;o00001Oooool3o`0000Gooooo00?o0000ooooooooool0Z_ooool6o`WZ2Pgooooo0ol9
jPX9ooooo`?o2NX:`oooool00ol0003oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00Co
2NX:oooooooooooo2NX:0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo02?ooooo
00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Pooooo`00e_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo027ooooo00?o0000ohUAQ_n9DHH03On9DHH2o`0000;ooooo0ol0
0008ooooo`03o`000?oooooooooo0:Oooooo1_l9jPX>ooooo`;o2NX:2_ooool3o`WZ2/Cooooo00?o
0000ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`04o`WZ2_ooooooooooo`WZ2P?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Rooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooooooool08?ooool00=Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?n9DHKoRE6600koRE6600Co0000ooooool0003o00003?ooool00ol0003ooooo
ooooo`2Tooooo`Go2NX:3_ooool3o`WZ2P[ooooo0ol9jP[5ooooo`03o`000?oooooooooo00Gooooo
00?o2NX:ooooooooool01Oooool01?l9jP[oooooooooool9jPX2ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool08Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo023o
oooo003Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003oRE66
ohUAQP0>ohUAQP03o`000?oooooo000000gooooo00?o0000ooooooooool0XOooool5o`WZ2Poooooo
0_l9jPX;ooooo`?o2NX:aoooool00ol0003oooooooooo`06ooooo`03o`WZ2_oooooooooo00Cooooo
00Co2NX:oooooooooooo2NX:0oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo02;o
oooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Oooooo`00eOooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo023ooooo00?o0000ohUAQ_n9DHH03_n9DHH01?l0003ooooo
ooooool0000=ooooo`03o`000?oooooooooo09gooooo1_l9jPX>ooooo`?o2NX:2_ooool4o`WZ2/So
oooo00?o0000ooooooooool01oooool00ol9jP[oooooooooo`05ooooo`04o`WZ2_ooooooooooo`WZ
2P?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0Qooooo`03o`000?oooooooooo
05[ooooo00?o0000ooooooooool07oooool00=Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?n9DHKoRE6600ooRE6600Go0000ooooooooooooooooo`00000=oooo
o`03o`000?oooooooooo09Wooooo1_l9jPX?ooooo`;o2NX:2oooool3o`WZ2/[ooooo00?o0000oooo
ooooool02Oooool00ol9jP[oooooooooo`04ooooo`05o`WZ2_ooooooooooooooool9jPX00_ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo023ooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`0Oooooo`00eOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
023ooooo00?o0000ohUAQ_n9DHH03on9DHH01Ol0003ooooooooooooooooo000000gooooo00?o0000
ooooooooool0U_ooool6o`WZ2Poooooo0ol9jPX;ooooo`?o2NX:c?ooool00ol0003oooooooooo`09
ooooo`03o`WZ2_oooooooooo00Gooooo00Co2NX:oooooooooooo2NX:0oooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo023ooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`0Nooooo`00eOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000
ohUAQ_n9DHH04?n9DHH00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0Toooool2o`WZ2P03ooooool9jP[o2NX:013ooooo0_l9jPX<ooooo`?o2NX:cOooool0
0ol0003oooooooooo`0;ooooo`03o`WZ2_oooooooooo00Cooooo00Go2NX:ooooooooooooooooo`WZ
2P02ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool07oooool00ol0003ooooooooo
o`1Iooooo`?o00008?ooool00=Gooooo00?o0000ooooooooool01oooool2o`00027ooooo00?o0000
ohUAQ_n9DHH04?n9DHH00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0T?ooool6o`WZ2Q3ooooo0_l9jPX<ooooo`?o2NX:c_ooool00ol0003oooooooooo`0<
ooooo`03o`WZ2_oooooooooo00Gooooo00Co2NX:oooooooooooo2NX:0oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo01kooooo00?o0000ooooooooool0E_ooool3o`0000;ooooo00?o
0000ooooooooool07_ooool00=Gooooo00?o0000ooooooooool01?ooool3o`000003ojO0jol0003o
oooo01oooooo00?o0000ohUAQ_n9DHH04On9DHH00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0S?ooool6o`WZ2Q3ooooo0ol9jPX;ooooo`?o2NX:dOooool0
0ol0003oooooooooo`0=ooooo`03o`WZ2_oooooooooo00Cooooo00Go2NX:ooooooooooooooooo`WZ
2P02ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool07_ooool00ol0003ooooooooo
o`1Booooo`Co00001Oooool00ol0003oooooooooo`0Nooooo`00e?ooool00ol0003oooooooooo`02
ooooo`?o00001?nW`>/2o`0001oooooo00?o0000ohUAQ_n9DHH04On9DHH00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0ROooool3o`WZ2P03ooooool9jP[o
2NX:017ooooo0_l9jPX<ooooo`?o2NX:d_ooool00ol0003oooooooooo`0>ooooo`03o`WZ2_oooooo
oooo00Gooooo00Co2NX:oooooooooooo2NX:0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo01gooooo00?o0000ooooooooool0Coooool3o`0000Wooooo00?o0000ooooooooool07_oo
ool00=Cooooo00?o0000ooooool000000_l00007ojO0j`03o`000?nW`>_o000001gooooo00?o0000
ohUAQ_n9DHH04_n9DHH00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0Q_ooool2o`WZ2P04ooooool9jP[o2NX:o`WZ2Q3ooooo0ol9jPX<ooooo`?o2NX:e?oo
ool00ol0003oooooooooo`0?ooooo`03o`WZ2_oooooooooo00Cooooo00Go2NX:oooooooooooooooo
o`WZ2P03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool07?ooool00ol0003ooooo
ooooo`1;ooooo`Co00003?ooool00ol0003oooooooooo`0Nooooo`00e?ooool2o`0000[oYl3[00Co
0000ojO0jonW`>_o00007?ooool00ol0003oRE66ohUAQP0BohUAQP03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`23ooooo`Ko2NX:4Oooool2o`WZ2Pgooooo
0ol9jP[Eooooo`03o`000?oooooooooo013ooooo00?o2NX:ooooooooool01Oooool01?l9jP[ooooo
ooooool9jPX3ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool07?ooool00ol0003o
ooooooooo`18ooooo`?o00004?ooool00ol0003oooooooooo`0Nooooo`00e?ooool00ol0003oYl3[
ojO0j`09ojO0j`05o`000?nW`>_oYl3[ojO0jol000006oooool00ol0003oRE66ohUAQP0BohUAQP03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1oooooo`Ko
2NX:4Oooool3o`WZ2Pcooooo1?l9jP[Fooooo`03o`000?oooooooooo01;ooooo00?o2NX:oooooooo
ool01?ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0ol0000Cooooo`03o`000?oooooooooo
01kooooo003Dooooo`03o`000?nW`>_oYl3[00WoYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003o
ooooooooo`0Gooooo`03o`000?n9DHKoRE6601?oRE6600?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo07_ooooo0ol9jPX00ooooooo2NX:o`WZ2P0Booooo`;o
2NX:3Oooool3o`WZ2]Wooooo00?o0000ooooooooool04_ooool00ol9jP[oooooooooo`05ooooo`05
o`WZ2_ooooooooooooooool9jPX00_ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
01_ooooo00?o0000ooooooooool0@Oooool4o`0001Kooooo00?o0000ooooooooool07_ooool00=Co
oooo0_l0000:ojO0j`03o`000?nW`>_oYl3[00?oYl3[00?o0000ooooooooool05_ooool00ol0003o
RE66ohUAQP0CohUAQP03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1hooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:4Oooool3o`WZ2Pgooooo0ol9jP[Joooo
o`03o`000?oooooooooo01?ooooo00?o2NX:ooooooooool01Oooool01Ol9jP[ooooooooooooooooo
2NX:00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Kooooo`03o`000?oooooo
oooo03gooooo0ol0000Jooooo`03o`000?oooooooooo01kooooo003Dooooo`;o00002_nW`>/00ol0
003oYl3[ojO0j`04ojO0j`03o`000?oooooooooo01Cooooo00?o0000ohUAQ_n9DHH05?n9DHH00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0MOooool2o`WZ
2P04ooooool9jP[o2NX:o`WZ2Q;ooooo0_l9jPX>ooooo`?o2NX:foooool00ol0003oooooooooo`0E
ooooo`03o`WZ2_oooooooooo00Gooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool06_ooool00ol0003oooooooooo`0iooooo`Co00007Ooo
ool00ol0003oooooooooo`0Nooooo`00e?ooool2o`0000[oYl3[00?o0000ojO0jonW`>/01OnW`>/0
0ol0003oooooooooo`0Cooooo`03o`000?n9DHKoRE6601CoRE6600?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07;ooooo0ol9jPX00ooooooo2NX:o`WZ2P0B
ooooo`?o2NX:3_ooool3o`WZ2]gooooo00?o0000ooooooooool05Oooool00ol9jP[oooooooooo`06
ooooo`04o`WZ2_ooooooooooo`WZ2P?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`0Jooooo`03o`000?oooooooooo03Kooooo0ol0000Qooooo`03o`000?oooooooooo01kooooo003D
ooooo`;o00002_nW`>/00ol0003oYl3[ojO0j`06ojO0j`03o`000?oooooooooo01;ooooo00?o0000
ohUAQ_n9DHH05?n9DHH00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0ol0001`
ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:4_ooool2o`WZ2Pkooooo1?l9jP[Nooooo`03o`000?oo
oooooooo01Oooooo00?o2NX:ooooooooool01Oooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Iooooo`03o`000?oooooooooo03?ooooo
0ol0000Sooooo`03o`000?oooooooooo01oooooo003Dooooo`;o00002_nW`>/00ol0003oYl3[ojO0
j`07ojO0j`03o`000?oooooooooo013ooooo00?o0000ohUAQ_n9DHH05On9DHH00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Cooooo1?l00002ooooo`03o`000?oooooooooo06_ooooo0ol9
jPX01?oooooo2NX:o`WZ2_l9jPXCooooo`;o2NX:3_ooool3o`WZ2^3ooooo00?o0000ooooooooool0
6?ooool00ol9jP[oooooooooo`06ooooo`04o`WZ2_ooooooooooo`WZ2P?ooooo00?o2NX:oooooooo
ool01Oooool00ol9jP[oooooooooo`0Hooooo`03o`000?oooooooooo02oooooo1?l0000Vooooo`03
o`000?oooooooooo01oooooo003Dooooo`03o`000?oooooo000000[oYl3[00?o0000ojO0jonW`>/0
1onW`>/00ol0003oooooooooo`0?ooooo`03o`000?n9DHKoRE6601GoRE6600?o0000ooooooooool0
2_ooool00ol0003oooooooooo`03o`0000Oooooo00?o0000ooooooooool0J?ooool2o`WZ2P04oooo
ool9jP[o2NX:o`WZ2Q?ooooo0ol9jPX>ooooo`?o2NX:h_ooool00ol0003oooooooooo`0Iooooo`03
o`WZ2_oooooooooo00Gooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool06?ooool00ol0003oooooooooo`0/ooooo`?o0000:_ooool00ol0
003oooooooooo`0Oooooo`00e?ooool00ol0003oooooo`00000:ojO0j`03o`000?nW`>_oYl3[00So
Yl3[00?o0000ooooooooool03_ooool00ol0003oRE66ohUAQP0DohUAQP03o`000?oooooooooo00co
oooo0_l0000:ooooo`03o`000?oooooooooo06Gooooo0ol9jPX00ooooooo2NX:o`WZ2P0Dooooo`;o
2NX:3oooool3o`WZ2^?ooooo00?o0000ooooooooool06_ooool00ol9jP[oooooooooo`06ooooo`04
o`WZ2_ooooooooooo`WZ2PCooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Goooo
o`03o`000?oooooooooo02Wooooo0ol0000]ooooo`03o`000?oooooooooo01oooooo003Dooooo`03
o`000?oooooo000000[oYl3[00?o0000ojO0jonW`>/02OnW`>/00ol0003oooooooooo`0<ooooo`03
o`000?n9DHKoRE6601GoRE6600?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo067ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXCooooo`?o2NX:3_ooool4o`WZ
2^Gooooo00?o0000ooooooooool06oooool00ol9jP[oooooooooo`05ooooo`05o`WZ2_oooooooooo
ooooool9jPX00oooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo01Kooooo00?o0000
ooooooooool09Oooool4o`00033ooooo00?o0000ooooooooool07oooool00=Cooooo00?o0000oooo
ool000002_nW`>/00ol0003oYl3[ojO0j`0:ojO0j`03o`000?oooooooooo00_ooooo00?o0000ohUA
Q_n9DHH05On9DHH00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0G_ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2QCooooo0_l9jPX?ooooo`Co2NX:ioooool0
0ol0003oooooooooo`0Kooooo`03o`WZ2_oooooooooo00Kooooo00Go2NX:ooooooooooooooooo`WZ
2P03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool05_ooool00ol0003ooooooooo
o`0Rooooo`?o0000=?ooool00ol0003oooooooooo`0Oooooo`00eOooool00ol0003oooooo`000009
ojO0j`03o`000?nW`>_oYl3[00_oYl3[00?o0000ooooooooool02_ooool00ol0003oRE66ohUAQP0E
ohUAQP03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1J
ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:5?ooool3o`WZ2Poooooo0ol9jP[Yooooo`03o`000?oo
oooooooo01gooooo00?o2NX:ooooooooool01Oooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo
00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0Eooooo`03o`000?oooooooooo01oooooo
0ol0000gooooo`03o`000?oooooooooo01oooooo003Eooooo`03o`000?oooooo000000WoYl3[00?o
0000ojO0jonW`>/03?nW`>/00ol0003oooooooooo`08ooooo`03o`000?n9DHKoRE6601KoRE6600?o
0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Sooooo0_l9
jPX2ooooo`;o2NX:5Oooool2o`WZ2Q3ooooo0ol9jP[[ooooo`03o`000?oooooooooo01gooooo00?o
2NX:ooooooooool01_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00?o2NX:ooooooooool0
1Oooool00ol9jP[oooooooooo`0Dooooo`03o`000?oooooooooo01_ooooo1?l0000jooooo`03o`00
0?oooooooooo01oooooo003Eooooo`03o`000?oooooo000000WoYl3[00?o0000ojO0jonW`>/03OnW
`>/2o`0000Sooooo00?o0000ohUAQ_n9DHH05_n9DHH00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0EOooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2QCooooo
0ol9jPX@ooooo`?o2NX:kOooool00ol0003oooooooooo`0Nooooo`03o`WZ2_oooooooooo00Gooooo
00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool05?ooool00ol0003oooooooooo`0Hooooo`?o0000?_ooool00ol0003oooooooooo`0Oooooo`00
eOooool00ol0003oooooo`000009ojO0j`03o`000?nW`>_oYl3[00ooYl3[00?o0000ooooooooool0
1Oooool00ol0003oRE66ohUAQP0FohUAQP03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1Aooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:5Oooool2o`WZ2Q3o
oooo1?l9jP[^ooooo`03o`000?oooooooooo01oooooo00?o2NX:ooooooooool01_ooool01Ol9jP[o
oooooooooooooooo2NX:00?ooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0Coooo
o`03o`000?oooooooooo01Cooooo1?l00011ooooo`03o`000?oooooooooo01oooooo003Eooooo`04
o`000?ooooooooooo`0000SoYl3[00?o0000ojO0jonW`>/04?nW`>/00ol0003oooooooooo`04oooo
o`03o`000?n9DHKoRE6601KoRE6600?o0000ooooooooool03oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04kooooo0ol9jPX2ooooo`;o2NX:5Oooool3o`WZ2Q3ooooo1?l9jP[`oooo
o`03o`000?oooooooooo01oooooo00?o2NX:ooooooooool01_ooool01Ol9jP[ooooooooooooooooo
2NX:00Cooooo00?o2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0Cooooo`03o`000?oooooo
oooo013ooooo0ol00015ooooo`03o`000?oooooooooo01oooooo003Eooooo`04o`000?oooooooooo
o`0000SoYl3[00?o0000ojO0jonW`>/04OnW`>/00ol0003oooooooooo`02ooooo`03o`000?n9DHKo
RE6601OoRE6600?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo04[ooooo0ol9jPX2ooooo`?o2NX:5Oooool2o`WZ2Q7ooooo0ol9jP[cooooo`03o`000?oooooo
oooo023ooooo00?o2NX:ooooooooool01_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00?o
2NX:ooooooooool01Oooool00ol9jP[oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo1?l0
0018ooooo`03o`000?oooooooooo01oooooo003Eooooo`04o`000?ooooooooooo`0000SoYl3[00?o
0000ojO0jonW`>/04_nW`>/01Ol0003ooooooooooooooooo000001WoRE6600?o0000ooooooooool0
3oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Sooooo0_l9jPX2ooooo`?o2NX:
5_ooool2o`WZ2Q7ooooo0ol9jP[dooooo`03o`000?oooooooooo027ooooo00?o2NX:ooooooooool0
1_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:ooooooooool01Oooool00ol9jP[o
ooooooooo`0Booooo`03o`000?oooooooooo00Wooooo0ol0001<ooooo`03o`000?oooooooooo01oo
oooo003Eooooo`04o`000?ooooooooooo`0000OoYl3[0_l0000EojO0j`04o`000?ooooooooooo`00
01WoRE6600?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
04Cooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPXFooooo`?o2NX:4?ooool4o`WZ2_Kooooo00?o0000
ooooooooool08_ooool00ol9jP[oooooooooo`06ooooo`05o`WZ2_ooooooooooooooool9jPX01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo01;ooooo00?o0000ooooooooool01_oo
ool3o`0004kooooo00?o0000ooooooooool08?ooool00=Gooooo00Co0000oooooooooooo00001?nW
`>/3o`000003ojO0jol0003oYl3[01GoYl3[0_l0000JohUAQP03o`000?oooooooooo013ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`11ooooo`?o2NX:0_ooool2o`WZ2QOooooo0_l9
jPXAooooo`Co2NX:moooool00ol0003oooooooooo`0Sooooo`03o`WZ2_oooooooooo00Kooooo00?o
2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Oooooo00?o2NX:ooooooooool0
4Oooool00ol0003oooooooooo`02ooooo`Co0000DOooool00ol0003oooooooooo`0Pooooo`00eOoo
ool01?l0003oooooooooooooool4o`0000CoYl3[00?o0000ojO0jonW`>/05OnW`>/00ol0003oRE66
ohUAQP0HohUAQP03o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0mooooo`?o2NX:0_ooool3o`WZ2QKooooo0ol9jPXAooooo`Co2NX:nOooool00ol0003ooooo
ooooo`0Tooooo`03o`WZ2_oooooooooo00Kooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03
o`000?l9jP[ooooo00Kooooo00?o2NX:ooooooooool04?ooool00ol0003oooooo`000002o`0005Go
oooo00?o0000ooooooooool08?ooool00=Gooooo00?o0000ooooool000000_l00007ojO0j`03o`00
0?nW`>_oYl3[01KoYl3[00?o0000ohUAQ_n9DHH05on9DHH00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0>oooool2o`WZ2P;ooooo0ol9jPXGooooo`;o2NX:
4_ooool3o`WZ2_cooooo00?o0000ooooooooool09?ooool00ol9jP[oooooooooo`06ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00_l00007ooooo`03o`WZ2_oooooooooo00oooooo
0ol0001Gooooo`03o`000?oooooooooo027ooooo003Eooooo`;o00000_ooool00ol0003oYl3[ojO0
j`06ojO0j`03o`000?nW`>_oYl3[01KoYl3[00?o0000ohUAQ_n9DHH05_n9DHH00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=oooool3o`WZ2P;ooooo0_l9
jPXGooooo`?o2NX:4_ooool3o`WZ2_gooooo00?o0000ooooooooool09_ooool00ol9jP[ooooooooo
o`06ooooo`05o`WZ2_ooooooooooooooool9jPX03?ooool00ol9jP[oooooooooo`0;ooooo`?o0000
00?oooooo`000?ooool0Eoooool00ol0003oooooooooo`0Qooooo`00eOooool00ol0003ooooooooo
o`02ooooo`03o`000?nW`>_oYl3[00GoYl3[00?o0000ojO0jonW`>/05onW`>/00ol0003oRE66ohUA
QP0EohUAQP03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0dooooo`?o2NX:0_ooool3o`WZ2QOooooo0_l9jPXBooooo`Co2NX:ooooool00ol0003ooooooooo
o`0Vooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`0:ooooo`03o`WZ2_oooooooooo00Oooooo0ol00004ooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool08Oooool00=Gooooo00?o0000ooooooooool00_ooool00ol0003oYl3[ojO0j`05
ojO0j`03o`000?nW`>_oYl3[01SoYl3[00?o0000ohUAQ_n9DHH05?n9DHH00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Oooool3o`WZ2P;ooooo0ol9jPXG
ooooo`?o2NX:4_ooool4o`WZ2_oooooo0_ooool00ol0003oooooooooo`0Wooooo`03o`WZ2_oooooo
oooo00Kooooo00Go2NX:ooooooooooooooooo`WZ2P0<ooooo`03o`WZ2_oooooooooo00Cooooo0ol0
0007ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool08_ooool00=Gooooo00?o0000
ooooooooool00oooool00ol0003oYl3[ojO0j`04ojO0j`03o`000?nW`>_oYl3[01WoYl3[00?o0000
ohUAQ_n9DHH04on9DHH00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0;Oooool3o`WZ2P;ooooo0ol9jPXHooooo`;o2NX:4oooool3o`WZ2_oooooo1?ooool0
0ol0003oooooooooo`0Xooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`0:ooooo`03o`WZ2_oooooooooo00?o00002_ooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo02;ooooo003Fooooo`03o`000?oooooooooo00?ooooo00?o0000ojO0
jonW`>/00onW`>/00ol0003oYl3[ojO0j`0JojO0j`03o`000?n9DHKoRE6601;oRE6600?o0000oooo
ooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo0_l9jPX3oooo
o`;o2NX:6?ooool3o`WZ2Q?ooooo0ol9jP[oooooo`Kooooo00?o0000ooooooooool0:Oooool00ol9
jP[oooooooooo`06ooooo`05o`WZ2_ooooooooooooooool9jPX03?ooool00ol0003o2NX:o`00000>
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool08_ooool00=Kooooo00?o0000oooo
ooooool00oooool00ol0003oYl3[ojO0j`03ojO0j`03o`000?nW`>_oYl3[01_oYl3[00?o0000ohUA
Q_n9DHH04On9DHH00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0ol0000Yoooo
o`?o2NX:0_ooool3o`WZ2QSooooo0_l9jPXCooooo`Co2NX:ooooool8ooooo`03o`000?oooooooooo
02Wooooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00Kooooo0ol000000ooooooo0000o`00000>ooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool08oooool00=Kooooo00?o0000ooooooooool01?ooool00ol0003oYl3[ojO0j`03ojO0j`03
o`000?nW`>_oYl3[01_oYl3[00?o0000ohUAQ_n9DHH04?n9DHH00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Cooooo1?l00002ooooo`03o`000?oooooooooo02Cooooo0ol9jPX2ooooo`?o
2NX:6Oooool2o`WZ2Q?ooooo1?l9jP[oooooo`Wooooo00?o0000ooooooooool0:_ooool00ol9jP[o
ooooooooo`07ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool3o`0001Co
oooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Sooooo`00e_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?nW`>_oYl3[00?oYl3[00?o0000ojO0jonW`>/07?nW`>/00ol0003oRE66
ohUAQP0?ohUAQP03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?l00006ooooo`03o`00
0?oooooooooo027ooooo0ol9jPX2ooooo`?o2NX:6Oooool3o`WZ2Q?ooooo1?l9jP[oooooo`_ooooo
00?o0000ooooooooool0:oooool00ol9jP[oooooooooo`07ooooo`05o`WZ2_ooooooooooooooool9
jPX01?l0000Gooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool08oooool00=Kooooo
00?o0000ooooooooool01Oooool00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW`>_oYl3[01goYl3[
00?o0000ohUAQ_n9DHH03_n9DHH00ol0003oooooooooo`0Eooooo`;o00002oooool00ol0003ooooo
ooooo`0Mooooo`?o2NX:0oooool2o`WZ2Q[ooooo0_l9jPXDooooo`?o2NX:ooooool>ooooo`03o`00
0?oooooooooo02_ooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`02o`000003o`WZ
2_oooooooooo01Sooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Tooooo`00e_oo
ool00ol0003oooooooooo`06ooooo`05o`000?nW`>_oYl3[ojO0jol000008?nW`>/00ol0003oRE66
ohUAQP0=ohUAQP03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Kooooo`;o2NX:0oooool3o`WZ2QWooooo0ol9jPXDooooo`?o2NX:ooooool@ooooo`03o`00
0?oooooooooo02cooooo00?o2NX:ooooooooool01_ooool00ol0003o2NX:o`00000Mooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool09?ooool00=Oooooo00?o0000ooooooooool01Ooo
ool01Ol0003oYl3[ojO0jonW`>_o0000027oYl3[00?o0000ohUAQ_n9DHH03?n9DHH00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool3o`WZ2P;ooooo
0ol9jPXJooooo`;o2NX:5?ooool4o`WZ2_oooooo4_ooool00ol0003oooooooooo`0/ooooo`03o`WZ
2_oooooooooo00?ooooo0ol000000ooooooo2NX:ooooo`0Mooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool09?ooool00=Oooooo00?o0000ooooooooool01_ooool01?l0003oYl3[ojO0
jol0000RojO0j`03o`000?n9DHKoRE6600_oRE6600?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Cooooo0ol9jPX3ooooo`;o2NX:6_ooool3o`WZ2QCooooo
1?l9jP[ooooooaCooooo00?o0000ooooooooool0;Oooool00ol9jP[o0000o`000002o`0000Gooooo
00?o2NX:ooooooooool06oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02Gooooo
003Gooooo`03o`000?oooooooooo00Kooooo00Go0000ojO0jonW`>_oYl3[o`00000RojO0j`03o`00
0?n9DHKoRE6600WoRE6600?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo017ooooo0ol9jPX3ooooo`?o2NX:6_ooool2o`WZ2QGooooo1?l9jP[ooooooaKooooo
00?o0000ooooooooool0:oooool4o`0000Sooooo00?o2NX:ooooooooool06oooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo02Gooooo003Gooooo`03o`000?oooooooooo00Oooooo00Co
0000ojO0jonW`>_o00008onW`>/00ol0003oRE66ohUAQP08ohUAQP03o`000?oooooooooo01Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`;o2NX:0oooool3o`WZ2Q[ooooo
0ol9jPXEooooo`?o2NX:oooooolIooooo`03o`000?oooooooooo02Sooooo0ol0000=ooooo`03o`WZ
2_oooooooooo01_ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`00eooo
ool00ol0003oooooooooo`07ooooo`04o`000?nW`>_oYl3[o`0002CoYl3[00?o0000ohUAQ_n9DHH0
1on9DHH00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool3o`WZ2P;ooooo0ol9jPXKooooo`;o2NX:5Oooool4o`WZ2_oooooo6oooool00ol0003ooooo
ooooo`0Uooooo`?o00004?ooool00ol9jP[oooooooooo`0Kooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool09_ooool00=Oooooo00?o0000ooooooooool02?ooool00ol0003oYl3[o`00
000UojO0j`03o`000?n9DHKoRE6600KoRE6600?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Sooooo0ol9jPX3ooooo`;o2NX:6oooool3o`WZ2QGooooo1?l9
jP[ooooooagooooo00?o0000ooooooooool08Oooool4o`0001Cooooo00?o2NX:ooooooooool06_oo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Kooooo003Hooooo`03o`000?oooooo
oooo00Sooooo0_l0000VojO0j`03o`000?n9DHKoRE6600GoRE6600?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo0ol9jPX3ooooo`?o2NX:6oooool2
o`WZ2QKooooo1?l9jP[ooooooaoooooo00?o0000ooooooooool07_ooool3o`0001Sooooo00?o2NX:
ooooooooool06_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Kooooo003Hoooo
o`03o`000?oooooooooo00Sooooo0_l0000WojO0j`03o`000?n9DHKoRE6600CoRE6600?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooooooo`?o2NX:0oooool3
o`WZ2Qcooooo0_l9jPXFooooo`Co2NX:oooooolPooooo`03o`000?oooooooooo01cooooo0ol0000L
ooooo`03o`WZ2_l0003ooooo01Wooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0W
ooooo`00f?ooool00ol0003oooooooooo`09ooooo`;o00009onW`>/00ol0003oRE66ohUAQP03ohUA
QP03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool01?l0003oooooo`WZ2_l9jPX3
ooooo`?o2NX:7?ooool3o`WZ2QGooooo1?l9jP[oooooob?ooooo00?o0000ooooooooool06?ooool4
o`0001oooooo0_l0000Jooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0:?ooool0
0=Sooooo00?o0000ooooooooool02Oooool2o`0002SoYl3[00?o0000ohUAQ_n9DHH00_n9DHH00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo0ol9jPX3ooooo`;o2NX:7Oooool2o`WZ
2QKooooo1?l9jP[oooooobGooooo00?o0000ooooooooool05Oooool3o`0003oooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`0Xooooo`00f?ooool00ol0003oooooooooo`09ooooo`;o
0000:OnW`>/01Ol0003oRE66ohUAQ_n9DHKo000001_ooooo00?o0000ooooooooool01_ooool3o`WZ
2P03ooooool0003ooooo00?o2NX:7?ooool3o`WZ2QKooooo1?l9jP[oooooobOooooo00?o0000oooo
ooooool04_ooool3o`0004;ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Yoooo
o`00f?ooool00ol0003oooooooooo`06ooooo`?o000000?oooooo`000?l00000:OnW`>/01?l0003o
RE66ohUAQ_l0000Looooo`03o`000?oooooooooo00;ooooo0ol9jPX3ooooo`?o2NX:7Oooool2o`WZ
2QOooooo1?l9jP[oooooobWooooo00?o0000ooooooooool03oooool3o`0004Gooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0Yooooo`00fOooool00ol0003oooooooooo`02ooooo`?o
00001?ooool00ol0003oooooo`00000YojO0j`03o`000?n9DHKo000001cooooo00?o0000oooooooo
ool00_l9jPX4ooooo`;o2NX:0_ooool00ol0003oooooooooo`0Hooooo`?o2NX:5oooool4o`WZ2_oo
oooo:oooool00ol0003oooooooooo`0;ooooo`Co0000BOooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo02[ooooo003Iooooo`03o`000?oooooo000000;o00002?ooool00ol0003ooooo
o`00000YojO0j`;o00007?ooool3o`WZ2P?ooooo0ol9jPX4ooooo`03o`000?oooooooooo01Kooooo
0_l9jPXGooooo`Co2NX:ooooool^ooooo`03o`000?oooooooooo00Sooooo0ol0001=ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool0:oooool00=Wooooo0_l0000;ooooo`04o`000?oo
ooooooooo`0002WoYl3[00?o0000ooooooooool05oooool3o`WZ2P03ooooool0003ooooo00?o2NX:
2?ooool00ol0003oooooooooo`0Booooo`?o2NX:5oooool4o`WZ2_oooooo<?ooool00ol0003ooooo
ooooo`05ooooo`?o0000D?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02_ooooo
003Iooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo0000:?nW`>/00on9DHKo0000
o`00000Eooooo`?o2NX:0oooool3o`WZ2P_ooooo00?o0000ooooooooool04?ooool2o`WZ2QSooooo
1?l9jP[ooooooc;ooooo00?o0000ooooooooool00_ooool3o`0005?ooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0/ooooo`00fOooool00ol0003oooooooooo`0;ooooo`04o`000?oo
ooooooooo`0002CoYl3[1?n9DHH00ol0003oYl3[o`00000Aooooo`?o2NX:1?ooool2o`WZ2P03oooo
ool0003ooooo00_ooooo00?o0000ooooooooool03Oooool3o`WZ2QSooooo1?l9jP[oooooocCooooo
00?o0000ooooool000000_l0001Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
;Oooool00=[ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000023oYl3[
1on9DHH01?l0003oYl3[ojO0jol0000>ooooo`;o2NX:00Co0000oooooooooooooooo0ol9jPX3oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool2o`WZ2QSooooo1Ol9jP[ooooo
ocKooooo0_l0001Iooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0;Oooool00=[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?nW`>_oYl3[01[o
Yl3[2_n9DHH01Ol0003oYl3[ojO0jonW`>_o000000[ooooo0ol9jPX00ooooooo0000o`000003o`WZ
2POooooo00?o0000ooooooooool02Oooool2o`0000[ooooo0_l9jPXHooooo`Co2NX:oooooolioooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0^oooo
o`00f_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ojO0jonW
`>/05_nW`>/=ohUAQP03o`000?nW`>_oYl3[00;oYl3[00?o0000ooooooooool01?ooool3o`WZ2PCo
oooo0_l9jPX:ooooo`03o`000?oooooooooo00Kooooo0ol000000ooooooo0000ooooo`06ooooo`?o
2NX:6?ooool4o`WZ2_oooooo>oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool0;_ooool00=_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?nW`>_oYl3[01?oYl3[4?n9DHH00ol0003oYl3[ojO0j`03ojO0j`04o`00
0?ooooooooooooooo`;o2NX:1?ooool3o`WZ2Pcooooo00?o0000ooooooooool00oooool3o`0000Co
oooo00?o0000ooooooooool00oooool2o`WZ2QWooooo1?l9jP[oooooockooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02oooooo003Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oYl3[ojO0j`0?ojO0ja?oRE66
00?o0000ojO0jonW`>/01?nW`>/00ol0003o2NX:o`WZ2P03ooooo`?o2NX:4?ooool00ol0003ooooo
o`000002o`0000Oooooo00?o0000ooooooooool00ol9jPXIooooo`Co2NX:oooooom0ooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0`ooooo`00fooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ojO0jonW`>/02onW
`>/FohUAQP03o`000?nW`>_oYl3[00GoYl3[0_l00003o`WZ2Q?ooooo0_l0000;ooooo`;o2NX:6Ooo
ool4o`WZ2_oooooo@oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0<?ooool00=_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04
ooooo`03o`000?nW`>_oYl3[00OoYl3[6On9DHH00ol0003oYl3[ojO0j`05ojO0j`03o`000?l9jP[o
oooo01Gooooo00?o0000ooooooooool01oooool3o`WZ2P03o`000?oooooooooo01Kooooo1?l9jP[o
ooooodGooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo037ooooo003Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0
003oYl3[ojO0j`03ojO0jacoRE6600?o0000ojO0jonW`>/00_nW`>/3o`WZ2P;oYl3[00?o0000oooo
ooooool04oooool00ol0003oooooooooo`05ooooo`;o2NX:0oooool00ol0003oooooooooo`0Doooo
o`Co2NX:oooooom7ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`0aooooo`00g?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ojO0jon9DHH07_n9DHH00ol0003oYl3[o`WZ2P02o`WZ2PKoYl3[00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`02ooooo`?o2NX:1Oooool00ol0003oooooooooo`0Booooo`Co
2NX:oooooom:ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0booooo`00g?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo
00?o0000ohUAQ_n9DHH07_n9DHH00ol0003o2NX:ojO0j`09ojO0j`03o`000?oooooooooo01;ooooo
00Co0000ooooool9jP[o2NX:2?ooool00ol0003oooooooooo`0?ooooo`Go2NX:oooooom<ooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0cooooo`00
gOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ohUAQ_n9DHH0
7_n9DHH00ol0003oYl3[ojO0j`0:ojO0j`03o`000?oooooooooo013ooooo0ol9jPX:ooooo`03o`00
0?oooooooooo00gooooo1?l9jP[oooooodoooooo00?o0000ooooooooool0Eoooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo03?ooooo003Mooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01Oooool00ol0003oRE66ohUAQP0MohUAQP03o`000?nW`>_oYl3[00coYl3[00?o
0000ooooooooool03Oooool2o`WZ2P03ooooool0003ooooo00_ooooo00?o0000ooooooooool02_oo
ool4o`WZ2_ooooooDOooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0=?ooool00=gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`03o`000?n9DHKoRE6601goRE6600?o0000ojO0jonW`>/03OnW`>/00ol0003oooooooooo`0:
ooooo`;o2NX:0oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo1?l9jP[o
oooooe?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03Gooooo003Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0
003oRE66ohUAQP0MohUAQP03o`000?nW`>_oYl3[00koYl3[00?o0000ooooooooool01_ooool3o`WZ
2PGooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`Co2NX:oooooomFoooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0foooo
o`00g_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ohUAQ_n9
DHH07On9DHH00ol0003oYl3[ojO0j`0?ojO0j`03o`000?oooooooooo00?ooooo0_l9jPX8ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool5o`WZ2_ooooooF?ooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0=oooool00=kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?n9DHKoRE6601goRE66
00?o0000ojO0jonW`>/04?nW`>/2o`0000?o2NX:2oooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooooooo`Co2NX:oooooomKooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0hooooo`00g_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ohUAQ_n9DHH07On9DHH00ol0003oYl3[ojO0j`0@ojO0j`03o`00
0?l9jP[ooooo00gooooo00?o0000ooooooooool02_ooool00ol0003o2NX:o`WZ2P02o`WZ2_oooooo
GOooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
>Oooool00=kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?n9
DHKoRE6601goRE6600?o0000ojO0jonW`>/03OnW`>/3o`WZ2P;oYl3[00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`09ooooo`Co2NX:oooooomOooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0jooooo`00goooool00ol0003oooooooooo`09
ooooo`;o00001?ooool00ol9jP[o0000ohUAQP0NohUAQP03o`000?nW`>_oYl3[00[oYl3[0ol9jPX6
ojO0j`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool5o`WZ2_ooooooH_ooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>oooool0
0=oooooo00?o0000ooooooooool01_ooool3o`000003ooooool0003ooooo00?o2NX:00?oooooo`00
0?n9DHH07_n9DHH00ol0003oYl3[ojO0j`07ojO0j`?o2NX:2_nW`>/00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Cooooo1Ol9jPX00ooooooo0000ooooo`3oooooof7ooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03cooooo003Oooooo`03
o`000?oooooooooo00?ooooo0ol00003ooooo`;o2NX:00?o0000ooooooooool00_ooool00ol0003o
RE66ohUAQP0MohUAQP03o`000?nW`>_oYl3[00CoYl3[0ol9jPX>ojO0j`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooooooo1?l9jPX4ooooo`03o`000?oooooooooo0?ooooooH?ooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0?Oooool00>3o
oooo00?o0000ooooool000000_l00003ooooo`?o2NX:0_ooool00ol0003oooooo`WZ2P02o`WZ2P03
ooooool0003oRE6601goRE6600Co0000ojO0jonW`>_oYl3[0ol9jPXBojO0j`03o`000?oooooooooo
00Sooooo00?o0000ooooool9jPX00ol9jPX6ooooo`03o`000?oooooooooo0?ooooooHOooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0?_ooool00>3o
oooo0_l00003ooooo`?o2NX:1?ooool2o`WZ2P03o`000?oooooooooo00;ooooo00?o0000ohUAQ_n9
DHH07?n9DHH01?l0003o2NX:o`WZ2_l9jPXFojO0j`03o`000?oooooooooo00Oooooo1?l9jPX9oooo
o`03o`000?oooooooooo0?ooooooHOooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0?oooool00>3ooooo00?o0000ooooool9jPX00_l9jPX4ooooo`?o
2NX:0_ooool00ol0003oooooooooo`02ooooo`03o`000?n9DHKoRE6601coRE6600?o0000ojO0jonW
`>/06?nW`>/00ol0003oooooooooo`03ooooo`Go2NX:2oooool00ol0003oooooooooo`3oooooof7o
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo043o
oooo003Oooooo`;o2NX:00?o0000ooooooooool00_ooool3o`WZ2PKooooo00Go0000oooooooooooo
ooooo`00000NohUAQP03o`000?nW`>_oYl3[01WoYl3[00?o0000ooooooooool01Ol9jPX00ol0003o
ooooooooo`09ooooo`;o0000oooooomTooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`11ooooo`00g?ooool3o`WZ2P;ooooo00?o0000ooooool9jPX0
0_l9jPX9ooooo`05o`000?ooooooooooooooool000007_n9DHH00ol0003oYl3[ojO0j`0JojO0j`04
o`000?l9jP[o2NX:o`WZ2P?ooooo00?o0000ooooooooool01_ooool3o`000003ooooool0003ooooo
0?ooooooHoooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0@_ooool00=Wooooo0ol9jPX4ooooo`;o2NX:00?o0000ooooooooool02oooool01?l0003o
ooooooooool0000NohUAQP03o`000?nW`>_oYl3[01OoYl3[1Ol9jPX6ooooo`03o`000?oooooooooo
00;ooooo0ol00004ooooo`03o`000?oooooooooo0?ooooooHoooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0@oooool00=Kooooo0ol9jPX4ooooo`?o
2NX:0_ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0001koRE6600?o0000ojO0
jonW`>/05OnW`>/2o`WZ2P03ojO0jol9jP[o2NX:00;oYl3[00?o0000ooooooooool00oooool00ol0
003oooooo`000002o`0000Oooooo00?o0000ooooooooool0oooooomTooooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`14ooooo`00d_ooool4o`WZ2PCo
oooo0ol9jPX5ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool000007_n9DHH00ol0003o
Yl3[ojO0j`0CojO0j`;o2NX:00?oYl3[o`WZ2_l9jPX01OnW`>/00ol0003oooooooooo`02ooooo`;o
00002_ooool00ol0003oooooooooo`3oooooofCooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`0/ooooo`;o0000Aoooool00<oooooo0ol9jPX5ooooo`?o2NX:2Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooo000001koRE6600?o0000ojO0jonW`>/04?nW`>/6o`WZ2PSoYl3[
00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo0?ooooooIOooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Aoooool00<cooooo
0ol9jPX5ooooo`?o2NX:3?ooool00ol0003oooooooooo`0<ooooo`;o00007_n9DHH00ol0003oYl3[
ojO0j`0>ojO0j`;o2NX:00?oYl3[o`WZ2_l9jPX03?nW`>/01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo0?ooooooI_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Wo
oooo0_l0001:ooooo`00bOooool3o`WZ2PGooooo0ol9jPX@ooooo`03o`000?oooooooooo00_ooooo
0_l0000NohUAQP;o00003?nW`>/3o`WZ2P04ojO0jol9jP[o2NX:o`0000koYl3[00?o0000ooooool0
00002oooool00ol0003oooooooooo`3oooooofKooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo04[ooooo0036ooooo`?o2NX:1Oooool3o`WZ2Q?ooooo
00?o0000ooooooooool02oooool2o`0001koRE6600Co0000ooooool0003o00002?nW`>/2o`WZ2P05
ojO0jol9jP[o2NX:o`WZ2_nW`>/00_l0000?ojO0j`;o00002oooool00ol0003oooooooooo`3ooooo
ofOooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Vooooo`;o0000COooool00<?o
oooo0ol9jPX5ooooo`?o2NX:5oooool00ol0003oooooooooo`0:ooooo`03o`WZ2_l0003oRE6601go
RE6600Go0000ooooooooooooooooo`000005ojO0j`;o2NX:00?oYl3[o`WZ2_l9jPX05_nW`>/00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo0?ooooooIoooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0COooool00<3ooooo0ol9jPX4ooooo`Co
2NX:6_ooool00ol0003oooooooooo`07ooooo`?o2NX:00?oooooo`000?n9DHH07On9DHH00ol0003o
ooooooooo`02ooooo`;o00001_l9jPXIojO0j`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0oooooomXooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool08_ooool2o`00053o
oooo002mooooo`?o2NX:1?ooool3o`WZ2Qkooooo00?o0000ooooooooool01?ooool3o`WZ2PCooooo
0_l0000MohUAQP04o`000?ooooooooooooooo`?o2NX:00?o0000o`WZ2_l9jPX07OnW`>/00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?ooooooJOooool2o`0004kooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`1@ooooo`00^_ooool3o`WZ2PCooooo0ol9jPXRooooo`03o`00
0?oooooo2NX:00?o2NX:2?ooool00ol0003oRE66ohUAQP0KohUAQP05o`000?l9jP[o2NX:o`WZ2_oo
ool00ol9jPX00ooooooo0000ojO0j`0MojO0j`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooomZooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1Aooooo`00]oooool3o`WZ2PCooooo0ol9jPXTooooo`03o`WZ2_l0003o2NX:00cooooo
0_l0000KohUAQP04o`000?l9jP[oooooooooo`;o2NX:1Oooool2o`0001goYl3[00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3oooooof_ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0Nooooo`;o0000E?ooool00;Cooooo0ol9jPX4ooooo`?o2NX:9?ooool3o`WZ2P;ooooo
00?o0000ooooooooool02_ooool2o`0001_oRE6600Co0000ooooool9jP[o2NX:2Oooool3o`0001_o
Yl3[00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooofcooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Cooooo002aooooo`?o2NX:
1?ooool3o`WZ2RCooooo0ol9jPX5ooooo`03o`000?oooooooooo00[ooooo00?o0000ohUAQ_l00000
6_n9DHH00ol0003o2NX:ooooo`0=ooooo`;o00006_nW`>/00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooKOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01_ooooo
0_l0001Gooooo`00[_ooool3o`WZ2PCooooo0ol9jPXTooooo`?o2NX:2Oooool00ol0003ooooooooo
o`0:ooooo`;o00006_n9DHH00ol0003oooooooooo`0?ooooo`;o00006OnW`>/00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?ooooooK_ooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0Eoooool00:_ooooo0ol9jPX4ooooo`?o2NX:9?ooool3
o`WZ2Pcooooo00?o0000ooooooooool02_ooool3o`0001WoRE6600?o0000ooooooooool04Oooool3
o`0001OoYl3[00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooofoooooo0_l00017
ooooo`03o`000?oooooooooo01Sooooo0_l0001Jooooo`00Z?ooool3o`WZ2PCooooo0ol9jPXToooo
o`?o2NX:3oooool00ol0003oooooooooo`07ooooo`Co000000?oRE66o`000?n9DHH06?n9DHH00ol0
003oooooooooo`0Dooooo`;o00005_nW`>/01Ol0003ooooooooooooooooo00000?ooooooLoooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0F_ooool0
0:Gooooo0ol9jPX4ooooo`?o2NX:9?ooool3o`WZ2Q?ooooo00?o0000ooooooooool00oooool3o`00
00?ooooo00Co0000ohUAQ_n9DHKo00006?n9DHH00ol0003oooooooooo`0Fooooo`;o00005OnW`>/0
1?l0003oooooooooool0003oooooogCooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0Eooooo`;o0000GOooool00:;ooooo0ol9jPX4ooooo`?o2NX:9?ooool3o`WZ2QKooooo00?o0000
ooooooooool00ol00007ooooo`04o`000?n9DHKoRE66o`0001OoRE6600?o0000ooooooooool06?oo
ool3o`0001?oYl3[00?o0000ooooool00000oooooomeooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool04_ooool3o`0005oooooo002Nooooo`Co2NX:1?ooool3o`WZ2RCooooo0ol9jPXJ
ooooo`;o00002_ooool01?l0003oRE66ohUAQ_l0000GohUAQP03o`000?oooooooooo01_ooooo0_l0
000BojO0j`;o0000oooooomfooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool04?oo
ool2o`0006;ooooo002Kooooo`?o2NX:1Oooool3o`WZ2RCooooo0ol9jPXMooooo`03o`000?oooooo
oooo00Kooooo0ol9jPX01Ol0003oRE66ohUAQ_n9DHKo000001KoRE6600?o0000ooooooooool07Ooo
ool2o`0000ooYl3[0ol0003oooooogOooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0>ooooo`;o0000I?ooool009Sooooo0ol9jPX5ooooo`?o2NX:8oooool4o`WZ2R7ooooo00?o0000
ooooooooool00_ooool3o`WZ2P?ooooo00Go0000ohUAQ_n9DHKoRE66o`00000FohUAQP03o`000?oo
oooooooo01oooooo0ol00008ojO0j`Co00000_ooool00ol0003oooooooooo`3oooooogKooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0:ooooo`?o0000I_ooool009Gooooo0ol9jPX5
ooooo`?o2NX:8oooool3o`WZ2RKooooo00Co0000o`WZ2_l9jP[o2NX:1Oooool00ol9jP[o0000ohUA
QP03ohUAQP03o`000?n9DHKoRE6601?oRE6600?o0000ooooooooool08_ooool2o`0000;oYl3[1?l0
0006ooooo`03o`000?oooooooooo0?ooooooMoooool2o`00043ooooo00?o0000ooooooooool02?oo
ool2o`0006Wooooo002Booooo`?o2NX:1Oooool3o`WZ2R?ooooo0ol9jPXWooooo`;o2NX:00?o0000
ooooooooool00oooool3o`WZ2P;ooooo00?o0000ohUAQ_n9DHH00_n9DHH00ol0003oRE66ohUAQP0B
ohUAQP03o`000?oooooooooo02Cooooo0_l0000:ooooo`03o`000?oooooooooo0?ooooooNOooool3
o`0003gooooo00?o0000ooooooooool01Oooool3o`0006_ooooo002?ooooo`?o2NX:1Oooool3o`WZ
2R?ooooo0ol9jPXWooooo`?o2NX:0oooool00ol0003oooooo`WZ2P02o`WZ2PGooooo00?o0000ohUA
Q_n9DHH00_n9DHH00ol0003oRE66ohUAQP0BohUAQP03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`3oooooogcooooo0ol0000jooooo`03o`000?oooooooooo
00?ooooo0_l0001^ooooo`00S?ooool3o`WZ2PGooooo0ol9jPXSooooo`?o2NX:9_ooool4o`WZ2PGo
oooo0_l9jPX00ol0003oooooooooo`06ooooo`03o`000?n9DHKoRE6600?oRE6600?o0000ohUAQ_n9
DHH04On9DHH00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0oooooon0ooooo`?o0000=oooool01?l0003oooooooooooooool2o`00073ooooo0029ooooo`?o
2NX:1?ooool4o`WZ2R?ooooo0ol9jPXVooooo`?o2NX:1Oooool4o`WZ2P;ooooo00?o0000oooooooo
ool01_ooool00ol0003oRE66ohUAQP03ohUAQP03o`000?n9DHKoRE66017oRE6600?o0000oooooooo
ool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?ooooooPoooool3o`0003Co
oooo1?l0001booooo`00Q_ooool3o`WZ2PCooooo0ol9jPXTooooo`?o2NX:9_ooool3o`WZ2PGooooo
0ol9jPX7ooooo`03o`000?oooooooooo00Kooooo00?o0000ohUAQ_n9DHH00on9DHH00ol0003oRE66
ohUAQP0@ohUAQP03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`3oooooohKooooo0ol0000^ooooo`Co0000MOooool008?ooooo0ol9jPX4ooooo`?o2NX:9?oo
ool3o`WZ2RKooooo0ol9jPX5ooooo`?o2NX:2oooool00ol0003oooooooooo`05ooooo`03o`000?n9
DHKoRE6600CoRE6600?o0000ohUAQ_n9DHH03on9DHH00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0oooooon9ooooo`?o00009Oooool6o`0007Wooooo0020
ooooo`?o2NX:1?ooool3o`WZ2RCooooo0ol9jPXVooooo`?o2NX:1Oooool3o`WZ2Pkooooo00?o0000
ooooooooool01Oooool00ol0003oRE66ohUAQP04ohUAQP03o`000?n9DHKoRE6600ooRE6600?o0000
ooooooooool08oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?ooooooS?ooool7
o`0001Sooooo1_l0001oooooo`00OOooool3o`WZ2PCooooo0ol9jPXTooooo`?o2NX:9Oooool4o`WZ
2PGooooo0ol9jPXBooooo`03o`000?oooooooooo00Cooooo00?o0000ohUAQ_n9DHH01On9DHH00ol0
003oRE66ohUAQP0>ohUAQP03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`3ooooooi?ooooo2ol00007ooooo`Ko0000QOooool007[ooooo0ol9jPX4ooooo`?o
2NX:8oooool4o`WZ2RGooooo0ol9jPX5ooooo`Co2NX:5Oooool00ol0003oooooooooo`05ooooo`03
o`000?n9DHKoRE6600CoRE6600?o0000ohUAQ_n9DHH03_n9DHH00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooooonNooooo`Oo0000Roooool007Oooooo
0ol9jPX4ooooo`?o2NX:8oooool3o`WZ2RKooooo0ol9jPX5ooooo`?o2NX:6_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?n9DHKoRE6600GoRE6600?o0000ohUAQ_n9DHH03On9DHH00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooooooooooooc7ooooo
001dooooo`?o2NX:1?ooool3o`WZ2R?ooooo0ol9jPXVooooo`?o2NX:1Oooool3o`WZ2Qkooooo00?o
0000ooooooooool00oooool00ol0003oRE66ohUAQP06ohUAQP03o`000?n9DHKoRE6600coRE6600?o
0000ooooooooool08oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooooooo
oolaooooo`00LOooool3o`WZ2PCooooo0ol9jPXSooooo`?o2NX:9_ooool3o`WZ2PGooooo0ol9jPXQ
ooooo`03o`000?oooooooooo00Cooooo00?o0000ohUAQ_n9DHH01On9DHH00ol0003oRE66ohUAQP0<
ohUAQP03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3o
oooooooooooo<_ooool006kooooo0ol9jPX4ooooo`?o2NX:8oooool3o`WZ2RGooooo1?l9jPX5oooo
o`?o2NX:9Oooool00ol0003oooooooooo`03ooooo`03o`000?n9DHKoRE6600GoRE660_l0000=ohUA
QP03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3ooooo
oooooooo<_ooool006_ooooo0ol9jPX4ooooo`?o2NX:8oooool3o`WZ2RGooooo0ol9jPX5ooooo`Co
2NX::Oooool00ol0003oooooooooo`03ooooo`04o`000?n9DHKoRE66ohUAQP?o000000?oRE66o`00
0?n9DHH03?n9DHH00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0oooooooooooooc;ooooo001Yooooo`;o2NX:1?ooool3o`WZ2R?ooooo0ol9jPXUooooo`?o
2NX:1Oooool3o`WZ2Rgooooo00?o0000ooooooooool00oooool4o`0000GoRE6600?o0000ohUAQ_n9
DHH02_n9DHH00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0oooooooooooooc;ooooo001/ooooo`?o2NX:8oooool3o`WZ2RGooooo0ol9jPX5ooooo`?o2NX:
<Oooool00ol0003oooooooooo`04o`0000SoRE6600?o0000ohUAQ_n9DHH02?n9DHH00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Sooooo0_l0003ooooooooooooo=?ooool006Wooooo0ol9
jPXSooooo`?o2NX:9Oooool3o`WZ2PGooooo0ol9jPXeooooo`;o00000oooool00ol0003oRE66ohUA
QP07ohUAQP03o`000?n9DHKoRE6600OoRE6600?o0000ooooooooool08oooool00ol0003ooooooooo
o`05ooooo`?o000000?oooooo`000?ooool0oooooooooooooc?ooooo001Vooooo`?o2NX:8oooool3
o`WZ2RCooooo1?l9jPX5ooooo`?o2NX:>?ooool00ol0003oooooooooo`03ooooo`03o`000?n9DHKo
RE6600OoRE6600?o0000ohUAQ_n9DHH01_n9DHH00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00;ooooo0ol00003ooooo`03o`000?oooooooooo0?oooooooooooolcooooo`00Hoooool3o`WZ
2R?ooooo0ol9jPXTooooo`?o2NX:1Oooool4o`WZ2Scooooo00?o0000ooooooooool00_ooool00ol0
003oRE66ohUAQP07ohUAQP03o`000?n9DHKoRE6600KoRE6600?o0000ooooooooool08oooool00ol0
003oooooo`000002o`0000Kooooo00?o0000ooooooooool0oooooooooooooc?ooooo001Pooooo`?o
2NX:8_ooool4o`WZ2RCooooo0ol9jPX5ooooo`?o2NX:@Oooool00ol0003oooooooooo`02ooooo`03
o`000?n9DHKoRE6600OoRE6600?o0000ohUAQ_n9DHH01On9DHH00ol0003oooooooooo`0Sooooo`;o
00002?ooool00ol0003oooooooooo`3ooooooooooooo=?ooool005kooooo0_l9jPXRooooo`?o2NX:
9Oooool3o`WZ2PGooooo0ol9jPY5ooooo`05o`000?ooooooooooooooool000002_n9DHH00ol0003o
RE66ohUAQP04ohUAQP03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3ooooooooooooo=?ooool007oooooo0ol9jPXUooooo`?o2NX:1Oooool3o`WZ2TWooooo
00Go0000ooooooooooooooooo`00000:ohUAQP03o`000?n9DHKoRE6600?oRE6600?o0000oooooooo
ool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?ooooooooooooldooooo`00
O?ooool3o`WZ2RCooooo1?l9jPX5ooooo`?o2NX:C?ooool01Ol0003ooooooooooooooooo000000_o
RE6600?o0000ohUAQ_n9DHH00_n9DHH00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0ooooooooooooocGooooo001iooooo`?o2NX:9?ooool3o`WZ2PKooooo
0ol9jPY@ooooo`04o`000?ooooooooooo`0000coRE6600Go0000ohUAQ_n9DHKoRE66o`00000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooooooooooocGooooo001fooooo`?o
2NX:9?ooool3o`WZ2PGooooo1?l9jPYDooooo`04o`000?ooooooooooo`0000_oRE6600Go0000ohUA
Q_n9DHKoRE66o`00000Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooooo
ooooocKooooo001cooooo`?o2NX:9?ooool3o`WZ2PGooooo0ol9jPYIooooo`03o`000?oooooo0000
00coRE6600Co0000ohUAQ_n9DHKo00008oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooooooooolfooooo`00L?ooool3o`WZ2RCooooo0ol9jPX5ooooo`?o2NX:GOooool00ol0
003oooooo`00000<ohUAQP03o`000?n9DHKo000002;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3ooooooooooooo=oooool006gooooo0ol9jPXTooooo`?o2NX:1Oooool3o`WZ2V7o
oooo0_l0000=ohUAQP;o00008_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooooooooolgooooo`00J_ooool3o`WZ2R?ooooo1?l9jPX5ooooo`?o2NX:I?ooool00ol0003ooooo
o`00000<ohUAQP?o00008?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo
oooooolgooooo`00J?ooool2o`WZ2R?ooooo0ol9jPX5ooooo`Co2NX:J?ooool2o`0000WoRE660ol0
0003ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool2o`000?oooooooooo
ooljooooo`00R_ooool3o`WZ2PGooooo0ol9jPY]ooooo`;o00001On9DHH3o`0000Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`04ooooo`?o000000?oooooo`000?ooool0oooooooo
ooooocWooooo0027ooooo`?o2NX:1Oooool3o`WZ2W7ooooo00?o0000ohUAQ_n9DHH00ol0000;oooo
o`;o00006oooool01?l0003oooooooooooooool3o`0000?ooooo00?o0000ooooooooool0oooooooo
ooooocWooooo0024ooooo`?o2NX:1Oooool3o`WZ2WGooooo0_l0000@ooooo`03o`000?oooooooooo
01Sooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooooooooljooooo`00P?ooool4o`WZ2PGo
oooo0ol9jPYjooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool2o`0000Oo
oooo00?o0000ooooooooool0oooooooooooooc_ooooo001mooooo`?o2NX:1Oooool4o`WZ2Wkooooo
0_l0000?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooooooooooo??ooool007[ooooo0ol9jPX5ooooo`?o2NX:Q?ooool00ol0003ooooooooo
o`0=ooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooooooo
oolmooooo`00Moooool3o`WZ2PGooooo0ol9jPZ8ooooo`;o00003oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ooooooooooooockooooo001doooo
o`?o2NX:1Oooool3o`WZ2Xgooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ooooooooooooocoooooo001booooo`;o
2NX:1Oooool3o`WZ2Y7ooooo00?o0000ooooooooool02oooool5o`0000cooooo00?o0000oooooooo
ool00oooool3o`000?oooooooooooom2ooooo`00MOooool4o`WZ2YGooooo0_l00007ooooo`Co0000
1Oooool4o`0000Oooooo00?o0000ooooooooool01Ol0003oooooooooooooA?ooool007;ooooo0ol9
jPZKooooo`03o`000?oooooooooo00Co00003Oooool4o`0000;ooooo1_l0003oooooooooooooAooo
ool006oooooo0ol9jPZOooooo`?o00005?ooool5o`000?oooooooooooom:ooooo`00K?ooool3o`WZ
2ZGooooo0ol0000>ooooo`Go0000ooooooooooooodgooooo001Yooooo`?o2NX:Zoooool3o`0000So
oooo1?l0003oooooooooooooDOooool006Oooooo0_l9jPZaooooo`?o00000_ooool3o`000?oooooo
oooooomEooooo`00oooooolNooooo`;o0000oooooooooooooeSooooo003ooooooooooooooooooomh
ooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooo
oooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooo
oooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo
003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooooooooooo
ogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooo
ooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oo
ooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?oo
ool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooooooooooo
ooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooo
ooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00
ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomh
ooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooo
oooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooo
oooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo
003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooooooooooo
ogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooo
ooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oo
ooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?oo
ool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooooooooooo
ooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooo
ooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00
ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomh
ooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooo
oooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooo
oooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo
003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooooooooooo
ogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooo
ooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oo
ooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?oo
ool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooooooooooo
ooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooo
ooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00
ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomh
ooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooo
oooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooo
oooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo
003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooooooooooo
ogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooo
ooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oo
ooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?oo
ool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooooooooooo
ooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00oooooooo
ooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00
ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomh
ooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooooooooooo
oooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo003ooooo
oooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?ooooooooooooooooooogSooooo
003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooooooooooo
ogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oooooooooo
ooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?ooool00?oo
ooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00ooooooooooooooooooooN?oo
ool00?ooooooooooooooooooogSooooo003ooooooooooooooooooomhooooo`00\
\>"],
  ImageRangeCache->{{{0, 884}, {556.688, 0}} -> {0.0171723, 0.167438, \
0.00111222, 0.00111222}},
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[opticalsystemoffaxis,MatrixForm->True,DecomposeABCD->True,\
NumericalResults->True]\
\>", "Input",
  CellLabel->"In[63]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.0000000000000002`", "0"},
                    {"0", "0.9999999999999998`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "52.353087613316774`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-1.0000000000000004`\), \(-226.99553854398664`\)},
                    {"0", \(-0.9999999999999999`\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(-113.49776927199329`\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.9970832771443876`", "0.026314949382609143`"},
                    {"0", "1.5235067658010406`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "9.022094551072769`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.0108443547670745`", \(-0.5587483884255562`\)},
                    {\(-0.0068417336488217975`\), "0.6550200310527979`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "51.52435533758304`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "0.9999999999999999`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "52.35308761331675`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "113.49776927199329`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "9.048486478393022`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {\(-0.006659641505554293`\), "0.6583004929987584`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "50.97160121100505`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Row, TableAlignments -> 
          Center]]]], "Output",
  CellLabel->"Out[63]//TableForm=",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[opticalsystemoffaxis,NumericalResults->True,MatrixForm->True]
\
\>", "Input",
  CellLabel->"In[64]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.7825651491241232`", \(-130.53849169383759`\)},
                    {"0.010423427503788649`", \(-0.4608670665034028`\)}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-0.7380759044047607`\), "134.18656933215746`"},
                    {\(-0.010116415795494256`\), "0.4843500883873546`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      TableForm[ {
        MatrixForm[ {{0.78256514912412323, -130.53849169383759}, {
          0.010423427503788649, -0.46086706650340281}}], 
        MatrixForm[ {{-0.73807590440476067, 
          134.18656933215746}, {-0.010116415795494256, 0.4843500883873546}}]},
         TableAlignments -> Center]]], "Output",
  CellLabel->"Out[64]//TableForm=",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianTrace", "Subsubsection",
  CellTags->{"AOG0.", "4.4.2", "AOG4.", "AOG4.4", "AOG4.4.2"}],

Cell[CellGroupData[{

Cell["GaussianTrace[opticalsystemoffaxis]", "Input",
  CellLabel->"In[65]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.2"}],

Cell[BoxData[
    \({{BeamSpotSize \[Rule] {5.`, 5.`}, 
        BeamDivergence \[Rule] {0.01`, 0.01`}, 
        ComplexBeamParameter \[Rule] {\(\(999.9770710337976`\)\(\
\[InvisibleSpace]\)\) + 
              6.771809703999252`\ \[ImaginaryI], \(\(999.9770710337974`\)\(\
\[InvisibleSpace]\)\) + 6.771809703999248`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.033859048519996264`, 0.033859048519996264`}, 
        WaistDistance \[Rule] {\(-999.9770710337976`\), \(-999.9770710337974`\
\)}, BeamScaleLength \[Rule] {6.771809703999252`, 6.771809703999252`}, 
        BeamCurvature \[Rule] {\(-1000.0229294919518`\), \
\(-1000.0229294919516`\)}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {0, 10.`, 0}, OpticalLength \[Rule] 0, 
        Intensity \[Rule] 100, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {5.311837930005924`, 
            5.2548524458346595`}, 
        BeamDivergence \[Rule] {\(-0.06539236790382222`\), \
\(-0.06340801282060518`\)}, 
        ComplexBeamParameter \[Rule] {\(-162.46045239383645`\) + 
              0.10424969624429693`\ \[ImaginaryI], \(-165.7472308725592`\) + 
              0.11087678897264427`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.003408567245334388`, 0.0035152384283424825`}, 
        WaistDistance \[Rule] {162.46045239383645`, 165.74723087255921`}, 
        BeamScaleLength \[Rule] {0.10424969624429689`, 0.1108767889726443`}, 
        BeamCurvature \[Rule] {162.46051929011185`, 165.74730504370686`}, 
        ABCDMatrix \[Rule] {{{1.0108443547670745`, 
                51.524355337583046`}, {\(-0.006841733648821799`\), 
                0.30250411540580485`}}, {{1, 
                50.97160121100506`}, {\(-0.006659641505554295`\), 
                0.3188479019693875`}}}, 
        ABCDRotationMatrix \[Rule] {{0.9977799945387509`, \
\(-0.06659641505554416`\), 0}, {0.06659641505554416`, 0.9977799945387509`, 
              0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {50.97160121100503`, 10.`, 0}, 
        OpticalLength \[Rule] 50.98533558322108`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {5.001356772152455`, 
            4.967979240413846`}, 
        BeamDivergence \[Rule] {\(-0.09962571493322392`\), \
\(-0.09632077371196018`\)}, 
        ComplexBeamParameter \[Rule] {\(-100.40290542963662`\) + 
              0.06822787473340654`\ \[ImaginaryI], \(-103.15486068696603`\) + 
              0.07299024484281097`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.003398625399345034`, 0.0035152384283424812`}, 
        WaistDistance \[Rule] {100.40290542963662`, 103.15486068696603`}, 
        BeamScaleLength \[Rule] {0.06822787473340652`, 0.07299024484281096`}, 
        BeamCurvature \[Rule] {100.40295179326395`, 103.1549123333529`}, 
        ABCDMatrix \[Rule] {{{0.946169234061132`, 
                54.10329380402903`}, {\(-0.01042342750378865`\), 
                0.46086706650340253`}}, {{0.9397403238860469`, 
                53.85669214063904`}, {\(-0.010116415795494254`\), 
                0.48435008838735444`}}}, 
        ABCDRotationMatrix \[Rule] {{0.9948697468238072`, \
\(-0.10116415795494907`\), 0}, {0.10116415795494905`, 0.9948697468238071`, 
              0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {60.`, 9.39740323886047`, 0}, 
        OpticalLength \[Rule] 64.73426134359734`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {0.652301439954674`, 
            0.4981308820929204`}, 
        BeamDivergence \[Rule] {0.0996257149332239`, 0.09632077371196011`}, 
        ComplexBeamParameter \[Rule] {\(\(13.094863842356608`\)\(\
\[InvisibleSpace]\)\) + 
              0.06822787473340654`\ \[ImaginaryI], \
\(\(10.342908585027278`\)\(\[InvisibleSpace]\)\) + 
              0.07299024484281098`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.0033986253993450346`, 0.003515238428342483`}, 
        WaistDistance \[Rule] {\(-13.094863842356608`\), \
\(-10.342908585027278`\)}, 
        BeamScaleLength \[Rule] {0.06822787473340654`, 0.07299024484281104`}, 
        BeamCurvature \[Rule] {\(-13.095219328518715`\), \
\(-10.343423679577173`\)}, 
        ABCDMatrix \[Rule] {{{0.23686653578722078`, \
\(-106.41067778309261`\)}, {0.010423427503788649`, \
\(-0.4608670665034024`\)}}, {{\(-0.20845030193050862`\), 
                108.82934671929655`}, {\(-0.010116415795494254`\), 
                0.48435008838735444`}}}, 
        ABCDRotationMatrix \[Rule] {{\(-0.10116415795494266`\), 
              0.994869746823808`, 
              0}, {\(-0.9948697468238078`\), \(-0.10116415795494264`\), 
              0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {172.91549698069494`, \
\(-2.0845030193050706`\), 0}, OpticalLength \[Rule] 178.26261275489634`, 
        Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {3.2601512488342803`, 
            3.019465477440738`}, 
        BeamDivergence \[Rule] {0.09962571493322386`, 0.0963207737119602`}, 
        ComplexBeamParameter \[Rule] {\(\(65.44795145567339`\)\(\
\[InvisibleSpace]\)\) + 
              0.06822787473340657`\ \[ImaginaryI], \(\(62.69599619834405`\)\(\
\[InvisibleSpace]\)\) + 0.07299024484281094`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.0033986253993450364`, 0.0035152384283424804`}, 
        WaistDistance \[Rule] {\(-65.44795145567339`\), \
\(-62.695996198344055`\)}, 
        BeamScaleLength \[Rule] {0.06822787473340661`, 0.07299024484281093`}, 
        BeamCurvature \[Rule] {\(-65.44802258154955`\), \(-62.69608117308192`\
\)}, ABCDMatrix \[Rule] {{{0.7825651491241237`, \(-130.53849169383753`\)}, \
{0.010423427503788649`, \(-0.4608670665034024`\)}}, \
{{\(-0.7380759044047609`\), 
                134.18656933215746`}, {\(-0.010116415795494254`\), 
                0.48435008838735444`}}}, 
        ABCDRotationMatrix \[Rule] {{\(-0.10116415795494266`\), 
              0.994869746823808`, 
              0}, {\(-0.9948697468238078`\), \(-0.10116415795494264`\), 
              0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {167.61924095595242`, 50.`, 0}, 
        OpticalLength \[Rule] 230.62980698395316`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 0.532`}}\)], "Output",
  CellLabel->"Out[65]=",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.2"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianPlot", "Subsubsection",
  CellTags->{"AOG0.", "4.4.3", "AOG4.", "AOG4.4", "AOG4.4.3"}],

Cell[CellGroupData[{

Cell["GaussianPlot[opticalsystemoffaxis];", "Input",
  CellLabel->"In[66]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00421648 0 0.100736 [
[.23463 -0.0125 -6 -9 ]
[.23463 -0.0125 6 0 ]
[.44546 -0.0125 -9 -9 ]
[.44546 -0.0125 9 0 ]
[.65628 -0.0125 -9 -9 ]
[.65628 -0.0125 9 0 ]
[.86711 -0.0125 -9 -9 ]
[.86711 -0.0125 9 0 ]
[.01131 .10074 -6 -4.5 ]
[.01131 .10074 0 4.5 ]
[.01131 .20147 -6 -4.5 ]
[.01131 .20147 0 4.5 ]
[.01131 .30221 -6 -4.5 ]
[.01131 .30221 0 4.5 ]
[.01131 .40294 -6 -4.5 ]
[.01131 .40294 0 4.5 ]
[.01131 .50368 -6 -4.5 ]
[.01131 .50368 0 4.5 ]
[.01131 .60442 -6 -4.5 ]
[.01131 .60442 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23463 0 m
.23463 .00625 L
s
[(50)] .23463 -0.0125 0 1 Mshowa
.44546 0 m
.44546 .00625 L
s
[(100)] .44546 -0.0125 0 1 Mshowa
.65628 0 m
.65628 .00625 L
s
[(150)] .65628 -0.0125 0 1 Mshowa
.86711 0 m
.86711 .00625 L
s
[(200)] .86711 -0.0125 0 1 Mshowa
.125 Mabswid
.06597 0 m
.06597 .00375 L
s
.10814 0 m
.10814 .00375 L
s
.1503 0 m
.1503 .00375 L
s
.19247 0 m
.19247 .00375 L
s
.2768 0 m
.2768 .00375 L
s
.31896 0 m
.31896 .00375 L
s
.36113 0 m
.36113 .00375 L
s
.40329 0 m
.40329 .00375 L
s
.48762 0 m
.48762 .00375 L
s
.52979 0 m
.52979 .00375 L
s
.57195 0 m
.57195 .00375 L
s
.61412 0 m
.61412 .00375 L
s
.69845 0 m
.69845 .00375 L
s
.74061 0 m
.74061 .00375 L
s
.78278 0 m
.78278 .00375 L
s
.82494 0 m
.82494 .00375 L
s
.90927 0 m
.90927 .00375 L
s
.95144 0 m
.95144 .00375 L
s
.9936 0 m
.9936 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .10074 m
.03006 .10074 L
s
[(1)] .01131 .10074 1 0 Mshowa
.02381 .20147 m
.03006 .20147 L
s
[(2)] .01131 .20147 1 0 Mshowa
.02381 .30221 m
.03006 .30221 L
s
[(3)] .01131 .30221 1 0 Mshowa
.02381 .40294 m
.03006 .40294 L
s
[(4)] .01131 .40294 1 0 Mshowa
.02381 .50368 m
.03006 .50368 L
s
[(5)] .01131 .50368 1 0 Mshowa
.02381 .60442 m
.03006 .60442 L
s
[(6)] .01131 .60442 1 0 Mshowa
.125 Mabswid
.02381 .02015 m
.02756 .02015 L
s
.02381 .04029 m
.02756 .04029 L
s
.02381 .06044 m
.02756 .06044 L
s
.02381 .08059 m
.02756 .08059 L
s
.02381 .12088 m
.02756 .12088 L
s
.02381 .14103 m
.02756 .14103 L
s
.02381 .16118 m
.02756 .16118 L
s
.02381 .18133 m
.02756 .18133 L
s
.02381 .22162 m
.02756 .22162 L
s
.02381 .24177 m
.02756 .24177 L
s
.02381 .26191 m
.02756 .26191 L
s
.02381 .28206 m
.02756 .28206 L
s
.02381 .32236 m
.02756 .32236 L
s
.02381 .3425 m
.02756 .3425 L
s
.02381 .36265 m
.02756 .36265 L
s
.02381 .3828 m
.02756 .3828 L
s
.02381 .42309 m
.02756 .42309 L
s
.02381 .44324 m
.02756 .44324 L
s
.02381 .46339 m
.02756 .46339 L
s
.02381 .48353 m
.02756 .48353 L
s
.02381 .52383 m
.02756 .52383 L
s
.02381 .54398 m
.02756 .54398 L
s
.02381 .56412 m
.02756 .56412 L
s
.02381 .58427 m
.02756 .58427 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .50368 m
.09004 .51159 L
.16227 .52022 L
.19739 .52442 L
.21452 .52646 L
.23011 .52832 L
.23388 .52877 L
.23595 .52902 L
.23788 .52925 L
.23997 .53413 L
.24107 .53326 L
.24227 .53233 L
.24631 .52917 L
.26163 .51721 L
.29535 .48184 L
.36602 .39774 L
.43409 .31673 L
.49957 .23881 L
.56924 .15589 L
.63632 .07606 L
.67057 .03531 L
.67995 .02414 L
.68986 .01235 L
.69394 .00749 L
.69619 .00482 L
.69832 .0023 L
.69952 .00091 L
.70083 .00079 L
.70202 .00216 L
.70312 .00346 L
.70761 .00879 L
.77629 .09052 L
.84361 .17063 L
.90832 .24765 L
.97619 .32842 L
s
0 0 0 r
gsave
.23873 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27688 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75544 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23873 0 m
.23873 .56185 L
s
.27688 0 m
.27688 .56185 L
s
.75544 0 m
.75544 .56185 L
s
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[66]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00Boooool3o`0000Cooooo0_l0000Wooooo`?o00001?ooool2o`0000Cooooo0_l0000Uoooo
o`?o00000oooool3o`0000Cooooo0_l0000Sooooo`Go00000oooool2o`0000Cooooo0_l0000_oooo
o`00B_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00009oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
9Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000^ooooo`00C_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0002kooooo001>ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0/ooooo`00B_ooool4o`0000?ooooo00Co
0000oooooooooooo00009oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009Oooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000
oooooooooooo00008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000^ooooo`00B_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0002Kooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00009?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002kooooo001:ooooo`Go00000oooool2o`0002Sooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l0000Vooooo`04o`000?ooooooooooooooo`Go00000oooool2
o`0002Cooooo0ol00004ooooo`;o00001?ooool2o`0002oooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo000Goooooj[o00000_l9jPY8o`0001Gooooo000Moooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`0000Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01_ooool00ol9jP[o0000o`WZ2P08ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
000Gooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0H_ooool01?l9jP[oooooooooool9jPX;ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo063ooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo00Wooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Oooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooo
ooooool02?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Nooooo`03
o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool01oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Nooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool0
1_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Mooooo`03o`WZ2_oo
oooooooo00Wooooo00?o2NX:ooooooooool01Oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Looooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool01?ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05cooooo00?o2NX:ooooooooool03?ooool00ol9
jP[oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001go
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05_o
oooo00?o2NX:ooooooooool03Oooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05[ooooo00?o2NX:ooooooooool03oooool00ol9jP[ooooo
ooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Wooooo00?o
2NX:ooooooooool04Oooool01Ol9jP[ooooooooooooooooo000003Cooooo00?o0000ooooooooool0
6Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05Sooooo00?o2NX:ooooooooool04oooool01?l9jP[oooooooooool0000dooooo`03o`00
0?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05Sooooo00?o2NX:ooooooooool05?ooool00ol9jP[oooooo`00000dooooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Gooooo`03o`WZ2_oooooooooo01Kooooo00?o2NX:o`000?ooool0<oooool0
0ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0E_ooool00ol9jP[oooooooooo`0Gooooo`03o`WZ2_l0003ooooo
03?ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05Gooooo00?o2NX:ooooooooool06Oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Dooooo`03o`WZ2_oooooooooo01[ooooo
00?o0000o`WZ2_ooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Dooooo`03o`WZ2_oooooooooo01[ooooo00?o
0000ooooool9jPX0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Doooool00ol9jP[oooooooooo`0K
ooooo`04o`000?ooooooooooo`WZ2S7ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05;ooooo00?o2NX:
ooooooooool07?ooool01Ol0003ooooooooooooooooo2NX:033ooooo00?o0000ooooooooool06Ooo
ool001Gooooo0ol00005ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Aooooo`03o`WZ2_oooooooooo01gooooo00?o0000ooooooooool00_ooool0
0ol9jP[oooooooooo`0]ooooo`03o`000?oooooooooo01Wooooo000Fooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
053ooooo00?o2NX:ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`WZ2_oooooooooo
02gooooo00?o0000ooooooooool06Oooool001Kooooo00?o0000ooooooooool01?ooool3o`00037o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1?ooooo`03o`WZ2_oooooooooo01oo
oooo00?o0000ooooooooool00oooool00ol9jP[oooooooooo`0/ooooo`03o`000?oooooooooo01Wo
oooo000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04kooooo00?o2NX:ooooooooool08?ooool00ol0003ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo02_ooooo00?o0000ooooooooool06Oooool001Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0COooool00ol9jP[oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o
2NX:ooooooooool0:_ooool00ol0003oooooooooo`0Iooooo`005Oooool2o`0000Kooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04cooooo00?o2NX:
ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03o`WZ2_oooooooooo02Wooooo00?o0000
ooooooooool06Oooool001Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Boooool00ol9jP[oooooooooo`0Soooo
o`03o`000?oooooooooo00Oooooo00?o2NX:ooooooooool0:?ooool00ol0003oooooooooo`0Ioooo
o`007Oooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1;ooooo`03
o`WZ2_oooooooooo02?ooooo00?o0000ooooooooool01oooool00ol9jP[oooooooooo`0Xooooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1:ooooo`03o`WZ2_oooooooooo02Cooooo00?o0000ooooooooool0
2?ooool00ol9jP[oooooooooo`0Wooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`19ooooo`03o`WZ2_oo
oooooooo02Gooooo00?o0000ooooooooool02Oooool00ol9jP[oooooooooo`0Vooooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`18ooooo`03o`WZ2_oooooooooo02Kooooo00?o0000ooooooooool02_ooool0
0ol9jP[oooooooooo`0Uooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`17ooooo`03o`WZ2_oooooooooo
02Oooooo00?o0000ooooooooool02oooool00ol9jP[oooooooooo`0Tooooo`03o`000?oooooooooo
01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Ko
oooo00?o2NX:ooooooooool0:?ooool00ol0003oooooooooo`0<ooooo`03o`WZ2_oooooooooo02?o
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04Gooooo00?o2NX:ooooooooool0:Oooool00ol0003ooooo
ooooo`0=ooooo`03o`WZ2_oooooooooo02;ooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Cooooo00?o
2NX:ooooooooool0:_ooool00ol0003oooooooooo`0=ooooo`03o`WZ2_oooooooooo02;ooooo00?o
0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04?ooooo00?o2NX:ooooooooool0:oooool00ol0003oooooooooo`0>
ooooo`03o`WZ2_oooooooooo027ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o2NX:oooo
ooooool0:oooool00ol0003oooooooooo`0?ooooo`03o`WZ2_oooooooooo023ooooo00?o0000oooo
ooooool06Oooool001gooooo0_l0000booooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0@_ooool00ol9jP[oooooooooo`0/ooooo`03o`000?oooooooooo013ooooo00?o2NX:oooooooo
ool07oooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0@Oooool00ol9jP[oooooooooo`0]ooooo`03o`00
0?oooooooooo017ooooo00?o2NX:ooooooooool07_ooool00ol0003oooooooooo`0Iooooo`007Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@?oo
ool00ol9jP[oooooooooo`0^ooooo`03o`000?oooooooooo01;ooooo00?o2NX:ooooooooool07Ooo
ool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0@?ooool00ol9jP[oooooooooo`0^ooooo`03o`000?oooooo
oooo01;ooooo00?o2NX:ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?oooool00ol9
jP[oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o2NX:ooooooooool07?ooool00ol0
003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0nooooo`03o`WZ2_oooooooooo033ooooo00?o0000ooooooooool05?ooool00ol9jP[o
ooooooooo`0Kooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`03o`WZ2_oooooooooo037ooooo
00?o0000ooooooooool05Oooool00ol9jP[oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo
000Dooooo`Go00001?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0?Oooool00ol9jP[oooooooooo`0aooooo`03o`000?oooooooooo01Kooooo00?o
2NX:ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`005Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0looooo`03o`WZ2_oooooooooo03;ooooo00?o0000ooooooooool05oooool00ol9jP[ooooooooo
o`0Hooooo`03o`000?oooooooooo01Wooooo000Fooooo`03o`000?oooooooooo00Cooooo0ol0000a
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol9jP[oooooooooo`0c
ooooo`03o`000?oooooooooo01Oooooo00?o2NX:ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`005oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0jooooo`03o`WZ2_oooooooooo03Cooooo00?o0000oooo
ooooool06?ooool00ol9jP[oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo000Dooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0>Oooool00ol9jP[oooooooooo`0eooooo`03o`000?oooooooooo
01Wooooo00?o2NX:ooooooooool05_ooool00ol0003oooooooooo`0Iooooo`005?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03Wooooo00?o2NX:ooooooooool0=Oooool00ol0003oooooooooo`0Joooo
o`03o`WZ2_oooooooooo01Gooooo00?o0000ooooooooool06Oooool001Gooooo0ol00005ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0hooooo`03
o`WZ2_oooooooooo03Kooooo00?o0000ooooooooool06oooool00ol9jP[oooooooooo`0Dooooo`03
o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Oooooo00?o2NX:ooooooooool0=oooool00ol0003oooooooooo`0Looooo`03o`WZ
2_oooooooooo01?ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o2NX:ooooooooool0>?oo
ool00ol0003oooooooooo`0Mooooo`03o`WZ2_oooooooooo01;ooooo00?o0000ooooooooool06Ooo
ool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03Kooooo00?o2NX:ooooooooool0>?ooool00ol0003oooooooooo`0Mooooo`03o`WZ2_oooooo
oooo01;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Gooooo00?o2NX:ooooooooool0>Oooool00ol0
003oooooooooo`0Nooooo`03o`WZ2_oooooooooo017ooooo00?o0000ooooooooool06Oooool001go
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Co
oooo00?o2NX:ooooooooool0>_ooool00ol0003oooooooooo`0Oooooo`03o`WZ2_oooooooooo013o
oooo00?o0000ooooooooool06Oooool001gooooo0_l0000booooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<oooool00ol9jP[oooooooooo`0kooooo`03o`000?oooooooooo023ooooo
00?o2NX:ooooooooool03oooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<oooool00ol9jP[ooooooooo
o`0kooooo`03o`000?oooooooooo027ooooo00?o2NX:ooooooooool03_ooool00ol0003ooooooooo
o`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0<_ooool00ol9jP[oooooooooo`0looooo`03o`000?oooooooooo02;ooooo00?o2NX:
ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool00ol9jP[oooooooooo`0moooo
o`03o`000?oooooooooo02;ooooo00?o2NX:ooooooooool03Oooool00ol0003oooooooooo`0Ioooo
o`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0<?ooool00ol9jP[oooooooooo`0nooooo`03o`000?oooooooooo02?ooooo00?o2NX:oooooooo
ool03?ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0_ooooo`03o`WZ2_oooooooooo03oooooo00?o0000ooooooooool0
9?ooool00ol9jP[oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`03o`WZ2_oo
oooooooo043ooooo00?o0000ooooooooool09Oooool00ol9jP[oooooooooo`0:ooooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0]ooooo`03o`WZ2_oooooooooo047ooooo00?o0000ooooooooool09_ooool0
0ol9jP[oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03o`WZ2_oooooooooo
04;ooooo00?o0000ooooooooool09oooool00ol9jP[oooooooooo`08ooooo`03o`000?oooooooooo
01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0[ooooo`03o`WZ2_oooooooooo04?ooooo00?o0000ooooooooool09oooool00ol9jP[o
ooooooooo`08ooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02_ooooo00?o2NX:ooooooooool0@oooool00ol0003ooooo
ooooo`0Xooooo`03o`WZ2_oooooooooo00Oooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02[ooooo00?o
2NX:ooooooooool0A?ooool00ol0003oooooooooo`0Yooooo`03o`WZ2_oooooooooo00Kooooo00?o
0000ooooooooool06Oooool001Gooooo0ol00005ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Yooooo`03o`WZ2_oooooooooo04Gooooo00?o0000
ooooooooool0:_ooool00ol9jP[oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo000Doooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0:?ooool00ol9jP[oooooooooo`16ooooo`03o`000?oooooo
oooo02_ooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`006?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Wooooo`03o`WZ2_oooooooooo04Oooooo00?o0000ooooooooool0;?ooool00ol9
jP[oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo000Fooooo`;o00001Oooool3o`00037o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Vooooo`03o`WZ2_oooooooooo04So
oooo00?o0000ooooooooool0;Oooool00ol9jP[oooooooooo`02ooooo`03o`000?oooooooooo01Wo
oooo000Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o2NX:ooooooooool0BOooool00ol0003ooooo
ooooo`0]ooooo`03o`WZ2_oooooooooo00;ooooo00?o0000ooooooooool06Oooool001Cooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Tooooo`03o`WZ2_oooooooooo04[ooooo00?o0000ooooooooool0
;_ooool01Ol9jP[ooooooooooooooooo000001_ooooo000Eooooo`?o00001Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool00ol9jP[ooooo
ooooo`1;ooooo`03o`000?oooooooooo02oooooo00Co2NX:oooooooooooo00006oooool001gooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo
00?o2NX:ooooooooool0Boooool00ol0003oooooooooo`0`ooooo`03o`WZ2_oooooo000001_ooooo
000Mooooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o
2NX:ooooooooool0C?ooool00ol0003oooooooooo`0aooooo`03o`WZ2_l0003ooooo01[ooooo000M
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Q
ooooo`03o`WZ2_oooooooooo04gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0I
ooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08?ooool00ol9jP[oooooooooo`1>ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01oooooo00?o2NX:ooooooooool0Coooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Nooooo`03o`WZ2_oooooooooo053ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Mooooo`03o`WZ2_oooooooooo057ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool07Oooool00ol9jP[oooooooooo`1Aooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o2NX:ooooooooool0D_ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`WZ2_oooooooooo05?o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol9jP[ooooo
ooooo`1Dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo0_l0
000booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol9jP[ooooooooo
o`1Eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o2NX:
ooooooooool0E_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Moooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hoooo
o`03o`WZ2_oooooooooo05Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Ioooo
o`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05oooool00ol9jP[oooooooooo`1Gooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool06Oooool001gooooo0_l0000booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
5_ooool00ol9jP[oooooooooo`1Hooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
6Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Gooooo00?o2NX:ooooooooool0FOooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Dooooo`03o`WZ2_oooooooooo05[ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Iooooo`005_ooool3o`0000Cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o2NX:ooooooooool0Foooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Gooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;o
oooo00?o2NX:ooooooooool0G?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wo
oooo000Dooooo`Go00001?ooool3o`00037ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Booooo`03o`WZ2_oooooooooo05cooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Iooooo`005?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`WZ2_oooooooooo05gooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`005Oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0@ooooo`03o`WZ2_oooooooooo05kooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Iooooo`005_ooool2o`0000Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00oooooo00?o2NX:ooooooooool0Goooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01Wooooo000Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o2NX:oooo
ooooool0H?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`;o
0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o2NX:oooooooo
ool0HOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`WZ
2_oooooooooo06;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?oo
ool00ol9jP[oooooooooo`1Rooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Ooo
ool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00_ooooo00?o2NX:ooooooooool0Hoooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0:ooooo`03o`WZ2_oooooooooo06Cooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`03o`WZ2_oooooooooo06Gooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol9jP[oooooooooo`1Vooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o2NX:ooooooooool0Ioooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`WZ2_oooooooooo06Oooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol9jP[oooooooooo`1Xoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo0_l0000booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol9jP[oooooooooo`1Yooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o2NX:ooooooooool0
J_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`WZ2_oo
oooooooo06_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
0ol9jP[oooooooooo`1/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool0
01gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooo
ooooool9jPX0Koooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Moooo
o`;o0000<_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool9jPX0Koooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool9jPY`ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06Oooool001Gooooo0ol00005ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01oooool00ol0003oooooo`WZ2P1aooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool06Oooool001Cooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003o2NX:ooooo`1aoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Hooooo`03o`00
0?oooooooooo00;ooooo1Ol9jPX_ooooo`03o`000?oooooooooo00Kooooo00?o2NX:o`000?ooool0
L_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Dooooo`Co00001Ooo
ool00ol0003oooooooooo`02ooooo`So2NX:9oooool00ol0003oooooooooo`05ooooo`03o`WZ2_oo
oooo000007?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`005?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo2Ol9jPXNooooo`03o`000?oooooo
oooo00Cooooo00Co2NX:oooooooooooo0000Loooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Wooooo000Dooooo`Go00001?ooool00ol0003oooooooooo`0Cooooo`Wo2NX:5Oooool0
0ol0003oooooooooo`02ooooo`;o2NX:0oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool07?ooool8o`WZ
2Pgooooo00Go0000ooooooooooooooooo`WZ2P05ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0002Gooooo2_l9jPX3oooo
o`04o`000?ooooooooooo`WZ2PKooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02kooooo0ol9jPX00ol0
003oooooo`WZ2P07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oo
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wo
oooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Ioooo
o`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo0_l0000booooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo0?oooooo0Oooool001gooooo00?o0000oooo
ooooool0;_ooool5o`0000Gooooo1Ol0001_ooooo`;o000000Coooooo`000?l0003o0000<?ooool3
o`0001_ooooo000Mooooo`03o`000?oooooooooo02oooooo00Co0000oooooooooooo00001_ooool0
1?l0003oooooooooool0001_ooooo`05o`000?ooooooooooooooool00000<Oooool01?l0003ooooo
ooooool0000Jooooo`007Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0L?ooool01Ol0003ooooooooooooooooo000003Cooooo00?o0000oooooooo
ool06?ooool001gooooo0_l0000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
L?ooool01Ol0003ooooooooooooooooo000003;ooooo0_l0000Kooooo`007Oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?ooool01Ol0003ooooo
o`000?oooooo0000037ooooo00?o0000ooooooooool06oooool001gooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo073ooooo0_l000000ooooooo0000
o`00000aooooo`04o`000?ooooooooooo`0001[ooooo000Eooooo`?o00001Oooool00ol0003ooooo
ooooo`0^ooooo`?o00001oooool3o`00077ooooo00Co0000oooooooooooooooo0_l0000aooooo`?o
00006_ooool001Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0?oo
oooo0Oooool001Cooooo00Go0000ooooooooooooooooo`000004ooooo`?o0000ooooool1ooooo`00
5?ooool4o`0000Gooooo00?o0000ooooooooool0ooooool1ooooo`005?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo0Oooool001Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3oooooo`7ooooo000Fooooo`;o0000ooooool9ooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00Roooool3o`0009;ooooo002<ooooo`03o`000?oooooooooo
097ooooo001Wooooo`Co00000oooool3o`0000?ooooo1?l000001_oooooo0000ooooool0003ooooo
o`0000Sooooo0ol00003ooooo`?o00000oooool3o`0000Cooooo0_l00009ooooo`?o00000_ooool5
o`000003ooooool0003o000000?o00000_ooool3o`0006Oooooo001Xooooo`06o`000?oooooooooo
o`000?oooooo00001Oooool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000ooooool0
00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo0000J_ooool0
06Sooooo00Go0000oooooooooooo0000ooooo`05o`0000;ooooo0ol00002ooooo`05o`000?oooooo
0000ooooool000002oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo
00Co0000oooooooooooo00003_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooo
oooooooooooo1Ol0001Vooooo`00J?ooool3o`0000;ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000;ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000Wooooo0_l00003oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool0000<ooooo`;o0000
1?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`1Tooooo`00J?ooool01?l0003oooooooooool00002ooooo`?o00000oooool2o`00
00?ooooo0_l000000ooooooo0000ooooo`08ooooo`03o`000?oooooooooo00;ooooo1?l00003oooo
o`?o00000_ooool4o`0000Wooooo00?o0000ooooooooool00_ooool3o`0000?ooooo1Ol00002oooo
o`?o0000Ioooool006Sooooo00Co0000oooooooooooo00006_ooool01?l0003oooooooooool0000>
ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000N?ooool006Oooooo1?l0000L
ooooo`?o00003_ooool00ol0003oooooooooo`0:ooooo`?o00000oooool00ol0003oooooooooo`1b
ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-28.999, -0.492538, \
0.977991, 0.0409355}},
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00421648 0 0.101829 [
[.23463 -0.0125 -6 -9 ]
[.23463 -0.0125 6 0 ]
[.44546 -0.0125 -9 -9 ]
[.44546 -0.0125 9 0 ]
[.65628 -0.0125 -9 -9 ]
[.65628 -0.0125 9 0 ]
[.86711 -0.0125 -9 -9 ]
[.86711 -0.0125 9 0 ]
[.01131 .10183 -6 -4.5 ]
[.01131 .10183 0 4.5 ]
[.01131 .20366 -6 -4.5 ]
[.01131 .20366 0 4.5 ]
[.01131 .30549 -6 -4.5 ]
[.01131 .30549 0 4.5 ]
[.01131 .40731 -6 -4.5 ]
[.01131 .40731 0 4.5 ]
[.01131 .50914 -6 -4.5 ]
[.01131 .50914 0 4.5 ]
[.01131 .61097 -6 -4.5 ]
[.01131 .61097 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23463 0 m
.23463 .00625 L
s
[(50)] .23463 -0.0125 0 1 Mshowa
.44546 0 m
.44546 .00625 L
s
[(100)] .44546 -0.0125 0 1 Mshowa
.65628 0 m
.65628 .00625 L
s
[(150)] .65628 -0.0125 0 1 Mshowa
.86711 0 m
.86711 .00625 L
s
[(200)] .86711 -0.0125 0 1 Mshowa
.125 Mabswid
.06597 0 m
.06597 .00375 L
s
.10814 0 m
.10814 .00375 L
s
.1503 0 m
.1503 .00375 L
s
.19247 0 m
.19247 .00375 L
s
.2768 0 m
.2768 .00375 L
s
.31896 0 m
.31896 .00375 L
s
.36113 0 m
.36113 .00375 L
s
.40329 0 m
.40329 .00375 L
s
.48762 0 m
.48762 .00375 L
s
.52979 0 m
.52979 .00375 L
s
.57195 0 m
.57195 .00375 L
s
.61412 0 m
.61412 .00375 L
s
.69845 0 m
.69845 .00375 L
s
.74061 0 m
.74061 .00375 L
s
.78278 0 m
.78278 .00375 L
s
.82494 0 m
.82494 .00375 L
s
.90927 0 m
.90927 .00375 L
s
.95144 0 m
.95144 .00375 L
s
.9936 0 m
.9936 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .10183 m
.03006 .10183 L
s
[(1)] .01131 .10183 1 0 Mshowa
.02381 .20366 m
.03006 .20366 L
s
[(2)] .01131 .20366 1 0 Mshowa
.02381 .30549 m
.03006 .30549 L
s
[(3)] .01131 .30549 1 0 Mshowa
.02381 .40731 m
.03006 .40731 L
s
[(4)] .01131 .40731 1 0 Mshowa
.02381 .50914 m
.03006 .50914 L
s
[(5)] .01131 .50914 1 0 Mshowa
.02381 .61097 m
.03006 .61097 L
s
[(6)] .01131 .61097 1 0 Mshowa
.125 Mabswid
.02381 .02037 m
.02756 .02037 L
s
.02381 .04073 m
.02756 .04073 L
s
.02381 .0611 m
.02756 .0611 L
s
.02381 .08146 m
.02756 .08146 L
s
.02381 .12219 m
.02756 .12219 L
s
.02381 .14256 m
.02756 .14256 L
s
.02381 .16293 m
.02756 .16293 L
s
.02381 .18329 m
.02756 .18329 L
s
.02381 .22402 m
.02756 .22402 L
s
.02381 .24439 m
.02756 .24439 L
s
.02381 .26475 m
.02756 .26475 L
s
.02381 .28512 m
.02756 .28512 L
s
.02381 .32585 m
.02756 .32585 L
s
.02381 .34622 m
.02756 .34622 L
s
.02381 .36658 m
.02756 .36658 L
s
.02381 .38695 m
.02756 .38695 L
s
.02381 .42768 m
.02756 .42768 L
s
.02381 .44805 m
.02756 .44805 L
s
.02381 .46841 m
.02756 .46841 L
s
.02381 .48878 m
.02756 .48878 L
s
.02381 .52951 m
.02756 .52951 L
s
.02381 .54987 m
.02756 .54987 L
s
.02381 .57024 m
.02756 .57024 L
s
.02381 .59061 m
.02756 .59061 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .50914 m
.09004 .51714 L
.16227 .52586 L
.19739 .5301 L
.21452 .53217 L
.23011 .53405 L
.23388 .53451 L
.23595 .53476 L
.23788 .53499 L
.23997 .53415 L
.24107 .5333 L
.24227 .53239 L
.24631 .52929 L
.26163 .51756 L
.29535 .4844 L
.36602 .40221 L
.43409 .32304 L
.49957 .24689 L
.56924 .16584 L
.63632 .08783 L
.67057 .048 L
.68858 .02705 L
.69842 .01561 L
.70322 .01002 L
.70761 .00493 L
.70963 .00259 L
.71183 .00036 L
.71391 .00244 L
.71584 .00467 L
.72466 .01492 L
.74338 .03669 L
.77629 .07497 L
.84361 .15326 L
.90832 .22853 L
.97619 .30747 L
s
0 0 0 r
gsave
.23873 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27688 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75544 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23873 0 m
.23873 .56185 L
s
.27688 0 m
.27688 .56185 L
s
.75544 0 m
.75544 .56185 L
s
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[66]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00Boooool3o`0000Cooooo0_l0000Wooooo`?o00001?ooool2o`0000Cooooo0_l0000Uoooo
o`?o00000oooool3o`0000Cooooo0_l0000Sooooo`Go00000oooool2o`0000Cooooo0_l0000_oooo
o`00B_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00009oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
9Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000^ooooo`00C_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0002kooooo001>ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0/ooooo`00B_ooool4o`0000?ooooo00Co
0000oooooooooooo00009oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009Oooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000
oooooooooooo00008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000^ooooo`00B_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0002Kooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00009?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002kooooo001:ooooo`Go00000oooool2o`0002Sooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l0000Vooooo`04o`000?ooooooooooooooo`Go00000oooool2
o`0002Cooooo0ol00004ooooo`;o00001?ooool2o`0002oooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo000Gooooojco00000ol9jPY5o`0001Gooooo000Moooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`0000Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool01Ol0003oooooo`WZ2_oooooo2NX:00Gooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000001Oooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Tooooo`05o`WZ2_ooooooooooooooool9jPX02?ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Sooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000M
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1R
ooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo067ooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`03oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo063ooooo00?o2NX:oooooooo
ool02Oooool00ol9jP[oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo063ooooo00?o2NX:ooooooooool02_ooool01Ol9jP[ooooooooooooooooo000003Co
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05oooooo00?o2NX:ooooooooool03?ooool01?l9jP[ooooo
ooooool0000dooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05kooooo00?o2NX:ooooooooool03Oooool01?l9jP[ooooo
ooooool0000dooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Mooooo`03o`WZ2_oooooooooo00oooooo
00?o2NX:ooooool00000=?ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0G?ooool00ol9jP[ooooooooo
o`0Aooooo`03o`WZ2_l0003ooooo03?ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05cooooo00?o2NX:
ooooooooool04_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Moooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Koooo
o`03o`WZ2_oooooooooo01?ooooo00?o0000o`WZ2_ooool0<_ooool00ol0003oooooooooo`0Ioooo
o`007Oooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Jooooo`03
o`WZ2_oooooooooo01Cooooo00?o0000o`WZ2_ooool0<_ooool00ol0003oooooooooo`0Iooooo`00
7Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
FOooool00ol9jP[oooooooooo`0Eooooo`03o`000?oooooo2NX:03;ooooo00?o0000ooooooooool0
6Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05Sooooo00?o2NX:ooooooooool05_ooool01?l0003oooooooooool9jPXaooooo`03o`00
0?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Hooooo`03o`WZ2_oooooooooo01Kooooo00Go0000oooooooooooooooo
o`WZ2P0`ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Gooooo`03o`WZ2_oooooooooo01Oooooo00?o
0000ooooooooool00_ooool00ol9jP[oooooooooo`0]ooooo`03o`000?oooooooooo01Wooooo000M
ooooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o2NX:
ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`WZ2_oooooooooo02gooooo00?o0000
ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05Gooooo00?o2NX:ooooooooool06Oooool00ol0003oooooooooo`03oooo
o`03o`WZ2_oooooooooo02cooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Cooooo00?o2NX:oooooooo
ool06_ooool00ol0003oooooooooo`04ooooo`03o`WZ2_oooooooooo02_ooooo00?o0000oooooooo
ool06Oooool001Gooooo0ol00005ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Dooooo`03o`WZ2_oooooooooo01[ooooo00?o0000ooooooooool0
1Oooool00ol9jP[oooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo000Fooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05?ooooo00?o2NX:ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`WZ2_oo
oooooooo02Wooooo00?o0000ooooooooool06Oooool001Kooooo00?o0000ooooooooool01?ooool3
o`00037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Booooo`03o`WZ2_oooooo
oooo01cooooo00?o0000ooooooooool01oooool00ol9jP[oooooooooo`0Xooooo`03o`000?oooooo
oooo01Wooooo000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo057ooooo00?o2NX:ooooooooool07Oooool00ol0
003oooooooooo`07ooooo`03o`WZ2_oooooooooo02Sooooo00?o0000ooooooooool06Oooool001Ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0D?ooool00ol9jP[oooooooooo`0Nooooo`03o`000?oooooooooo00So
oooo00?o2NX:ooooooooool09oooool00ol0003oooooooooo`0Iooooo`005Oooool2o`0000Kooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04oooooo
00?o2NX:ooooooooool07oooool00ol0003oooooooooo`09ooooo`03o`WZ2_oooooooooo02Kooooo
00?o0000ooooooooool06Oooool001Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C_ooool00ol9jP[ooooooooo
o`0Pooooo`03o`000?oooooooooo00[ooooo00?o2NX:ooooooooool09Oooool00ol0003ooooooooo
o`0Iooooo`007Oooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1=
ooooo`03o`WZ2_oooooooooo027ooooo00?o0000ooooooooool02oooool00ol9jP[oooooooooo`0T
ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1<ooooo`03o`WZ2_oooooooooo02;ooooo00?o0000oooo
ooooool03?ooool00ol9jP[oooooooooo`0Sooooo`03o`000?oooooooooo01Wooooo000Mooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1;ooooo`03
o`WZ2_oooooooooo02?ooooo00?o0000ooooooooool03Oooool00ol9jP[oooooooooo`0Rooooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1;ooooo`03o`WZ2_oooooooooo02?ooooo00?o0000ooooooooool0
3Oooool00ol9jP[oooooooooo`0Rooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1:ooooo`03o`WZ2_oo
oooooooo02Cooooo00?o0000ooooooooool03_ooool00ol9jP[oooooooooo`0Qooooo`03o`000?oo
oooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo04Wooooo00?o2NX:ooooooooool09Oooool00ol0003oooooooooo`0?ooooo`03o`WZ2_oooooo
oooo023ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo00?o2NX:ooooooooool09_ooool00ol0
003oooooooooo`0@ooooo`03o`WZ2_oooooooooo01oooooo00?o0000ooooooooool06Oooool001go
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Oo
oooo00?o2NX:ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`WZ2_oooooooooo01ko
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04Kooooo00?o2NX:ooooooooool0:?ooool00ol0003ooooo
ooooo`0Booooo`03o`WZ2_oooooooooo01gooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Gooooo00?o
2NX:ooooooooool0:Oooool00ol0003oooooooooo`0Booooo`03o`WZ2_oooooooooo01gooooo00?o
0000ooooooooool06Oooool001gooooo0_l0000booooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0A?ooool00ol9jP[oooooooooo`0Zooooo`03o`000?oooooooooo01?ooooo00?o2NX:
ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool00ol9jP[oooooooooo`0[oooo
o`03o`000?oooooooooo01Cooooo00?o2NX:ooooooooool06oooool00ol0003oooooooooo`0Ioooo
o`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0@oooool00ol9jP[oooooooooo`0[ooooo`03o`000?oooooooooo01Gooooo00?o2NX:oooooooo
ool06_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0@_ooool00ol9jP[oooooooooo`0/ooooo`03o`00
0?oooooooooo01Kooooo00?o2NX:ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`007Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@Ooo
ool00ol9jP[oooooooooo`0]ooooo`03o`000?oooooooooo01Oooooo00?o2NX:ooooooooool06?oo
ool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`10ooooo`03o`WZ2_oooooooooo02kooooo00?o0000ooooooooool06?ooool0
0ol9jP[oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0oooooo`03o`WZ2_oooooooooo
02oooooo00?o0000ooooooooool06Oooool00ol9jP[oooooooooo`0Fooooo`03o`000?oooooooooo
01Wooooo000Dooooo`Go00001?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0?_ooool00ol9jP[oooooooooo`0`ooooo`03o`000?oooooooooo01[o
oooo00?o2NX:ooooooooool05Oooool00ol0003oooooooooo`0Iooooo`005Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0nooooo`03o`WZ2_oooooooooo033ooooo00?o0000ooooooooool06_ooool00ol9jP[o
ooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo000Fooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03gooooo
00?o2NX:ooooooooool0<Oooool00ol0003oooooooooo`0Kooooo`03o`WZ2_oooooooooo01Cooooo
00?o0000ooooooooool06Oooool001Oooooo00?o0000ooooooooool00oooool3o`00037ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0looooo`03o`WZ2_oooooooooo03;ooooo00?o
0000ooooooooool07?ooool00ol9jP[oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo000D
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0>oooool00ol9jP[oooooooooo`0cooooo`03o`000?oo
oooooooo01gooooo00?o2NX:ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`005?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03[ooooo00?o2NX:ooooooooool0=?ooool00ol0003ooooooooo
o`0Nooooo`03o`WZ2_oooooooooo017ooooo00?o0000ooooooooool06Oooool001Gooooo0ol00005
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0i
ooooo`03o`WZ2_oooooooooo03Gooooo00?o0000ooooooooool07oooool00ol9jP[oooooooooo`0@
ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0hooooo`03o`WZ2_oooooooooo03Kooooo00?o0000oooo
ooooool08?ooool00ol9jP[oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o
0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo00?o2NX:oooooooo
ool0=_ooool00ol0003oooooooooo`0Qooooo`03o`WZ2_oooooooooo00kooooo00?o0000oooooooo
ool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Oooooo00?o2NX:ooooooooool0=oooool00ol0003oooooooooo`0Rooooo`03o`WZ
2_oooooooooo00gooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o2NX:ooooooooool0>?oo
ool00ol0003oooooooooo`0Rooooo`03o`WZ2_oooooooooo00gooooo00?o0000ooooooooool06Ooo
ool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03Gooooo00?o2NX:ooooooooool0>Oooool00ol0003oooooooooo`0Sooooo`03o`WZ2_oooooo
oooo00cooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo00?o2NX:ooooooooool0>_ooool00ol0
003oooooooooo`0Tooooo`03o`WZ2_oooooooooo00_ooooo00?o0000ooooooooool06Oooool001go
oooo0_l0000booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<oooool00ol9jP[o
ooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00?o2NX:ooooooooool02_ooool00ol0003o
ooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<oooool00ol9jP[oooooooooo`0kooooo`03o`000?oooooooooo02Kooooo
00?o2NX:ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<_ooool00ol9jP[ooooooooo
o`0looooo`03o`000?oooooooooo02Oooooo00?o2NX:ooooooooool02?ooool00ol0003ooooooooo
o`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0<Oooool00ol9jP[oooooooooo`0mooooo`03o`000?oooooooooo02Oooooo00?o2NX:
ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol9jP[oooooooooo`0noooo
o`03o`000?oooooooooo02Sooooo00?o2NX:ooooooooool01oooool00ol0003oooooooooo`0Ioooo
o`007Oooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0_ooooo`03
o`WZ2_oooooooooo03oooooo00?o0000ooooooooool0:Oooool00ol9jP[oooooooooo`06ooooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0^ooooo`03o`WZ2_oooooooooo043ooooo00?o0000ooooooooool0
:_ooool00ol9jP[oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`03o`WZ2_oo
oooooooo043ooooo00?o0000ooooooooool0:oooool00ol9jP[oooooooooo`04ooooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0]ooooo`03o`WZ2_oooooooooo047ooooo00?o0000ooooooooool0;?ooool0
0ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03o`WZ2_oooooooooo
04;ooooo00?o0000ooooooooool0;Oooool00ol9jP[oooooooooo`02ooooo`03o`000?oooooooooo
01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_o
oooo00?o2NX:ooooooooool0@oooool00ol0003oooooooooo`0]ooooo`03o`WZ2_oooooooooo00;o
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02[ooooo00?o2NX:ooooooooool0A?ooool00ol0003ooooo
ooooo`0^ooooo`05o`WZ2_ooooooooooooooool000006oooool001Gooooo0ol00005ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Yooooo`03o`WZ
2_oooooooooo04Gooooo00?o0000ooooooooool0;oooool01?l9jP[oooooooooool0000Kooooo`00
5?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Sooooo00?o2NX:ooooooooool0A_ooool00ol0003o
ooooooooo`0`ooooo`03o`WZ2_oooooo000001_ooooo000Hooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo
00?o2NX:ooooooooool0A_ooool00ol0003oooooooooo`0aooooo`03o`WZ2_l0003ooooo01[ooooo
000Fooooo`;o00001Oooool3o`00037ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Wooooo`03o`WZ2_oooooooooo04Oooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Iooooo`006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Vooooo`03o`WZ2_oooooooooo04Sooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`005?ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Gooooo00?o2NX:ooooooooool0BOooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01Wooooo000Eooooo`?o00001Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool09?ooool00ol9jP[oooooooooo`1:ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02?ooooo00?o2NX:ooooooooool0Boooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02?ooooo00?o2NX:ooooooooool0Boooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`WZ2_oooooooooo04cooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol9jP[oooooooooo`1=
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o2NX:oooo
ooooool0C_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03
o`WZ2_oooooooooo04oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`00
7Oooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`WZ
2_oooooooooo053ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Ooo
ool00ol9jP[oooooooooo`1Aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Ooo
ool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01cooooo00?o2NX:ooooooooool0D_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Kooooo`03o`WZ2_oooooooooo05?ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Jooooo`03o`WZ2_oooooooooo05Cooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06_ooool00ol9jP[oooooooooo`1Dooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Wooooo00?o2NX:ooooooooool0EOooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03o`WZ2_oooooooooo05Kooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol9jP[oooooooooo`1Goooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo0_l0000booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool00ol9jP[oooooooooo`1Hooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o2NX:ooooooooool0
FOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`WZ2_oo
oooooooo05[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`005_ooool3
o`0000Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01?ooooo00?o2NX:ooooooooool0Foooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01Wooooo000Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o2NX:ooooooooool0G?ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Dooooo`Go00001?ooool3o`00037o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`WZ2_oooooooooo05co
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`005?ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Aooooo`03o`WZ2_oooooooooo05gooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Iooooo`005Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`WZ2_oooooooooo05kooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`005_ooool2o`0000Gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o
2NX:ooooooooool0Goooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000G
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00kooooo00?o2NX:ooooooooool0H?ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00gooooo00?o2NX:ooooooooool0HOooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0<ooooo`03o`WZ2_oooooooooo06;ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol9jP[oooooooooo`1Rooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o2NX:ooooooooool0Hooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooo
oooo06Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`00
03;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`WZ2_oooooooooo
06Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol9jP[o
ooooooooo`1Vooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o2NX:ooooooooool0Ioooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo
000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`WZ2_oooooooooo06Oooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol9jP[oooooooooo`1Xooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool06Oooool001gooooo0_l0000booooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01Oooool00ol9jP[oooooooooo`1Yooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo00?o2NX:ooooooooool0J_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`03ooooo`03o`WZ2_oooooooooo06_ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_ooool00ol9jP[oooooooooo`1/ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool9jPX0Koooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07
ooooo`04o`000?ooooooooooo`WZ2W3ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooool9jPX0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Moooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003o2NX:ooooo`1aoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Gooooo0ol00005ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01_ooool00ol9jP[o
0000ooooo`1booooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Sooooo
00?o0000ooooooooool00_ooool5o`WZ2Roooooo00?o0000ooooooooool01Oooool00ol9jP[ooooo
o`00001cooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`So2NX:9oooool00ol0003ooooooooo
o`04ooooo`04o`WZ2_ooooooooooo`0007?ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Iooooo`005?ooool4o`0000Gooooo00?o0000ooooooooool02_ooool9o`WZ2Qkooooo00?o
0000ooooooooool00_ooool2o`WZ2P?ooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01Wooooo000Dooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04oooool9o`WZ2QGooooo00Go0000ooooooooooooooooo`WZ2P05ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`005?ooool5
o`0000Cooooo00?o0000ooooooooool07?ooool8o`WZ2Pgooooo00Co0000oooooooooooo2NX:1_oo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Ooo
ool001gooooo0_l0000Uooooo`Ko2NX:1oooool00ol0003oooooo`WZ2P07ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0
003oooooooooo`0Zooooo`Oo2NX:00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Ooo
ool001gooooo0_l0000booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo
000Mooooo`03o`000?oooooooooo0?oooooo0Oooool001gooooo0_l0000_ooooo`Go00001Oooool5
o`0006oooooo0_l000001?oooooo0000o`000?l0000`ooooo`?o00006oooool001gooooo00?o0000
ooooooooool0;oooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0006oooooo
00Go0000ooooooooooooooooo`00000aooooo`04o`000?ooooooooooo`0001[ooooo000Mooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1`ooooo`05
o`000?ooooooooooooooool00000=?ooool00ol0003oooooooooo`0Hooooo`007Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?ooool01Ol0003o
oooooooooooooooo000003;ooooo0_l0000Kooooo`007Oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?ooool01Ol0003oooooo`000?oooooo0000
037ooooo00?o0000ooooooooool06oooool001gooooo0_l0000`ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0L?ooool2o`000003ooooool0003o0000037ooooo00Co0000oooooooo
oooo00006_ooool001gooooo00?o0000ooooooooool0;_ooool3o`0000Oooooo0ol0001aooooo`04
o`000?ooooooooooooooo`;o0000<Oooool3o`0001[ooooo000Eooooo`?o00001Oooool00ol0003o
ooooooooo`3oooooo`7ooooo000Dooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`3oooooo`7ooooo000Dooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`3oooooo`7ooooo000Dooooo`Co00001Oooool3o`000?oooooo0Oooool001Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`7ooooo000Eooooo`03o`000?oooooo
oooo0?oooooo2Oooool001Kooooo0_l0003oooooo`Wooooo003oooooob7ooooo003oooooob7ooooo
002;ooooo`?o0000T_ooool008cooooo00?o0000ooooooooool0TOooool006Oooooo1?l00003oooo
o`?o00000oooool4o`000006ooooool0003oooooo`000?oooooo00002?ooool3o`0000?ooooo0ol0
0003ooooo`?o00001?ooool2o`0000Wooooo0ol00002ooooo`Go000000?oooooo`000?l000000ol0
0002ooooo`?o0000Ioooool006Sooooo00Ko0000oooooooooooo0000ooooool00005ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000008ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00;ooooo00Ko0000oooooooooooo0000ooooool0001Zooooo`00J?ooool01Ol0003oooooooooool0
003ooooo00Go00000_ooool3o`0000;ooooo00Go0000ooooool0003oooooo`00000;ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0000>oooo
o`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooooooool5o`0006Kooooo001X
ooooo`?o00000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool02?l0003ooooo
ooooool0003oooooo`000?oooooo00002Oooool2o`0000?ooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`04o`000?ooooooooooo`0000cooooo0_l00004ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo06Cooooo001Xoooo
o`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`;o00000oooool2o`000003ooooool0003o
oooo00Sooooo00?o0000ooooooooool00_ooool4o`0000?ooooo0ol00002ooooo`Co00002Oooool0
0ol0003oooooooooo`02ooooo`?o00000oooool5o`0000;ooooo0ol0001Wooooo`00J?ooool01?l0
003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooool0001hooooo`00Ioooool4o`0001cooooo0ol0000>ooooo`03o`000?oo
oooooooo00[ooooo0ol00003ooooo`03o`000?oooooooooo07;ooooo003oooooob7ooooo003ooooo
ob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-28.999, -0.487252, \
0.977991, 0.0404961}},
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}]
}, Open  ]]
}, Open  ]],

Cell[" ", "Input",
  CellLabel->"In[67]:=",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],

Cell[CellGroupData[{

Cell["\<\
GaussianPlot[opticalsystemoffaxis,RenderedParameters->ComplexBeamParameter];
\
\>", "Input",
  CellLabel->"In[68]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00421648 0.118378 0.000484953 [
[.23463 .10588 -6 -9 ]
[.23463 .10588 6 0 ]
[.44546 .10588 -9 -9 ]
[.44546 .10588 9 0 ]
[.65628 .10588 -9 -9 ]
[.65628 .10588 9 0 ]
[.86711 .10588 -9 -9 ]
[.86711 .10588 9 0 ]
[.01131 .02139 -24 -4.5 ]
[.01131 .02139 0 4.5 ]
[.01131 .21537 -18 -4.5 ]
[.01131 .21537 0 4.5 ]
[.01131 .31236 -18 -4.5 ]
[.01131 .31236 0 4.5 ]
[.01131 .40935 -18 -4.5 ]
[.01131 .40935 0 4.5 ]
[.01131 .50634 -18 -4.5 ]
[.01131 .50634 0 4.5 ]
[.01131 .60333 -24 -4.5 ]
[.01131 .60333 0 4.5 ]
[.5 .63053 -83.0625 0 ]
[.5 .63053 83.0625 12 ]
[.23873 .65716 -5 -6 ]
[.23873 .65716 5 6 ]
[.27688 .65716 -5 -6 ]
[.27688 .65716 5 6 ]
[.75544 .65716 -5 -6 ]
[.75544 .65716 5 6 ]
[.97619 .65716 -5 -6 ]
[.97619 .65716 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23463 .11838 m
.23463 .12463 L
s
[(50)] .23463 .10588 0 1 Mshowa
.44546 .11838 m
.44546 .12463 L
s
[(100)] .44546 .10588 0 1 Mshowa
.65628 .11838 m
.65628 .12463 L
s
[(150)] .65628 .10588 0 1 Mshowa
.86711 .11838 m
.86711 .12463 L
s
[(200)] .86711 .10588 0 1 Mshowa
.125 Mabswid
.06597 .11838 m
.06597 .12213 L
s
.10814 .11838 m
.10814 .12213 L
s
.1503 .11838 m
.1503 .12213 L
s
.19247 .11838 m
.19247 .12213 L
s
.2768 .11838 m
.2768 .12213 L
s
.31896 .11838 m
.31896 .12213 L
s
.36113 .11838 m
.36113 .12213 L
s
.40329 .11838 m
.40329 .12213 L
s
.48762 .11838 m
.48762 .12213 L
s
.52979 .11838 m
.52979 .12213 L
s
.57195 .11838 m
.57195 .12213 L
s
.61412 .11838 m
.61412 .12213 L
s
.69845 .11838 m
.69845 .12213 L
s
.74061 .11838 m
.74061 .12213 L
s
.78278 .11838 m
.78278 .12213 L
s
.82494 .11838 m
.82494 .12213 L
s
.90927 .11838 m
.90927 .12213 L
s
.95144 .11838 m
.95144 .12213 L
s
.9936 .11838 m
.9936 .12213 L
s
.25 Mabswid
0 .11838 m
1 .11838 L
s
.02381 .02139 m
.03006 .02139 L
s
[(-200)] .01131 .02139 1 0 Mshowa
.02381 .21537 m
.03006 .21537 L
s
[(200)] .01131 .21537 1 0 Mshowa
.02381 .31236 m
.03006 .31236 L
s
[(400)] .01131 .31236 1 0 Mshowa
.02381 .40935 m
.03006 .40935 L
s
[(600)] .01131 .40935 1 0 Mshowa
.02381 .50634 m
.03006 .50634 L
s
[(800)] .01131 .50634 1 0 Mshowa
.02381 .60333 m
.03006 .60333 L
s
[(1000)] .01131 .60333 1 0 Mshowa
.125 Mabswid
.02381 .04563 m
.02756 .04563 L
s
.02381 .06988 m
.02756 .06988 L
s
.02381 .09413 m
.02756 .09413 L
s
.02381 .14263 m
.02756 .14263 L
s
.02381 .16687 m
.02756 .16687 L
s
.02381 .19112 m
.02756 .19112 L
s
.02381 .23962 m
.02756 .23962 L
s
.02381 .26386 m
.02756 .26386 L
s
.02381 .28811 m
.02756 .28811 L
s
.02381 .33661 m
.02756 .33661 L
s
.02381 .36085 m
.02756 .36085 L
s
.02381 .3851 m
.02756 .3851 L
s
.02381 .4336 m
.02756 .4336 L
s
.02381 .45784 m
.02756 .45784 L
s
.02381 .48209 m
.02756 .48209 L
s
.02381 .53059 m
.02756 .53059 L
s
.02381 .55483 m
.02756 .55483 L
s
.02381 .57908 m
.02756 .57908 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -144.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Real) show
93.000 13.000 moveto
(Complex) show
141.000 13.000 moveto
(Beam) show
171.125 13.000 moveto
(Parameter) show
225.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .60332 m
.09004 .5957 L
.16227 .58739 L
.19739 .58335 L
.21452 .58138 L
.23011 .57959 L
.23388 .57916 L
.23595 .57892 L
.23788 .5787 L
.23997 .03945 L
.24107 .03932 L
.24227 .03919 L
.24631 .03872 L
.26163 .03696 L
.26595 .03646 L
.27066 .03592 L
.27281 .03567 L
.27399 .03554 L
.27511 .03541 L
.27727 .06964 L
.27924 .06942 L
.29535 .06756 L
.36144 .05996 L
.43173 .05188 L
.49942 .04409 L
.56452 .03661 L
.63381 .02864 L
.70051 .02096 L
.71795 .01896 L
.73693 .01678 L
.74561 .01578 L
.75037 .01523 L
.7527 .01496 L
.75484 .01472 L
.75669 .12458 L
.75863 .12436 L
.76272 .12389 L
.77142 .12289 L
.83675 .11538 L
.90628 .10738 L
.97322 .09968 L
.97619 .09934 L
s
0 0 0 r
gsave
.23873 .65716 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27688 .65716 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75544 .65716 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .65716 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23873 .03565 m
0 0 rlineto s
.23873 .03565 m
.23873 .61803 L
s
.27688 .03565 m
0 0 rlineto s
.27688 .03565 m
.27688 .61803 L
s
.75544 .03565 m
0 0 rlineto s
.75544 .03565 m
.75544 .61803 L
s
.97619 .03565 m
0 0 rlineto s
.97619 .03565 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o7_ooool0
0ol0003oooooooooo`3oooooo`007_ooool00ol0003oooooooooo`3oooooo`007_ooool00ol0003o
ooooooooo`3oooooo`002?ooool5o`0000?ooooo0_l00004ooooo`;o00001_ooool00ol0003ooooo
ooooo`2jooooo`;o2NX:@oooool000Wooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0[oooool=o`WZ
2T?ooooo0002ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001Oooool2o`000:[ooooo1_l9jPX<ooooo`03o`WZ2_oooooo
oooo047ooooo000;ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0X?ooool9o`WZ2Q;ooooo00?o
2NX:ooooooooool0@Oooool000Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`2Gooooo`Wo
2NX:6oooool00ol9jP[oooooooooo`11ooooo`002?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo08kooooo2Ol9jPXTooooo`03o`WZ2_oooooooooo047ooooo0009ooooo`?o00001?ooool2o`00
00Cooooo0_l00006ooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooooooo1Ol9jPX2
o`0004Gooooo2Ol9jPX]ooooo`03o`000?oooooooooo03Kooooo0_l00009ooooo`007_ooool00ol0
003oooooooooo`0eooooo`04o`000?l9jP[o2NX:o`WZ2PGooooo00?o0000ooooooooool0>oooool9
o`WZ2SKooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`00
03Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0cooooo`So2NX:?oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`Wo2NX:Aoooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`Wo2NX:D?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool01_ooool00ol0003o2NX:ooooo`0Hooooo`Wo2NX:FOooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool01_ooool00ol0003o2NX:ooooo`0?ooooo`Wo2NX:H_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool01_ooool00ol0003o2NX:ooooo`06ooooo`Wo2NX:Joooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool01_ooool00ol0003o2NX:ooooo`06o`WZ2WCooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`08ooooo`007_ooool2o`0003Kooooo00?o0000ooooooooool01_ooool00ol0003o2NX:
o`WZ2P1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool0;oooool3o`0000?ooooo0ol00006ooooo`03o`000?oooooooooo027ooooo0ol0
0004ooooo`;o00001?ooool2o`0002Sooooo0ol00003ooooo`?o00001?ooool2o`0001?ooooo00?o
0000ooooooooool04Oooool5o`0000?ooooo0_l00004ooooo`;o00005Oooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`0^ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Sooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo03;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005?ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Xooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`0^ooooo`Co00000oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002Sooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`0001;o
oooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00Sooooo000N
ooooo`;o0000;oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool08Oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Wooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
01;ooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo02kooooo1Ol00002ooooo`?o00001_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o0000:Oooool01?l0003ooooooooo
ooooool5o`0000?ooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo0ol00004ooooo`;o0000
1?ooool2o`00017ooooo1?l9jPX00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003ooooooooo
o`0Yooooo`Wo2NX:1?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Q
ooooo`So2NX:3Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Koooo
o`Ko2NX:5Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Eooooo`Ko
2NX:6oooool00ol0003oooooooooo`08ooooo`005ooooooFo`0000Oo2NX::Ol00003ooooo`007_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000o`WZ2_l9jPX01ol9jPX00ooooooo0000ooooo`09ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool001kooooo00?o0000ooooooooool0=?ooool2o`0000Sooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Oooooo00?o
0000o`WZ2_l9jPX01Ol9jPXEooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0003Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000=_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool02?ooool001kooooo0_l0000fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00Sooooo0008ooooo`Go00000oooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool02?ooool000Wooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`08ooooo`002_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Sooooo000;ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00?ooooo0_l0000fooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00Sooooo0008ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`08ooooo`002?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool02?ooool000Wooooo0ol00004ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool0
01kooooo0_l0000fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0003Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo0_l0
000fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08oooo
o`002_ooool3o`0000?ooooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Sooooo000;ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`08ooooo`002?ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool0
00Sooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Gooooo0_l0000eooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0
N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool000[ooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0doooo
o`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o
00001_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000oooooooo
ool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?oo
ool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`08ooooo`007_ooool2o`0003Gooooo00?o2NX:o`000?ooool01oooool0
0ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo
07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo
00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000oooo
o`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Noooo
o`;o0000=Oooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03
o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool0
1oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9jP[o
0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`08ooooo`007_ooool2o`0003Gooooo00?o2NX:o`000?ooool01oooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0d
ooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`00
0?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool02?ooool000Wooooo0ol00004ooooo`;o00001?ooool2o`0000Kooooo00?o0000oooooooo
ool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`08ooooo`002?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool02?ooool000Sooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool2o`0003Gooooo
00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool02?ooool000Sooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oo
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00So
oooo0008ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooo
oooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`002_ooool2o`00
00Cooooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo
00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo
0_l0000eooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o
2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07
ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0
003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`;o0000=Oooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooo
oooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Co
oooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000
ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo0_l0000eoooo
o`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?oo
ool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`00
0?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0009ooooo`?o00001?ooool2
o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool0
0ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool0
00Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo
0008ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Gooooo0_l0000eooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0009ooooo`?o
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`002?ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool02?ooool000Sooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0009ooooo`?o00001?ooool2o`0000Co
oooo0_l00006ooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000=Oooool00ol9jP[o0000ooooo`07
ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0
003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool0
0ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool0
01kooooo0_l0000eooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Co
oooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000
ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`00037ooooo1Ol9jPX00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Vooooo`[o2NX:1Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`0Nooooo`So2NX:3oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`0Gooooo`Oo2NX:5oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08
ooooo`000oooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo00?o0000oooo
ooooool04Oooool6o`WZ2Qkooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool000Cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`06ooooo`_o2NX:9?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`08ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`Wo2NX:;oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`08ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool02?ooool000Cooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0003ooooo`;o00001?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0004ooooo`03
o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`08ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00N?ooool3o`000:Gooooo001iooooo`03o`000?oo
oooooooo0:Cooooo0018ooooo`?o00000_ooool00ol0003oooooo`000002o`000003ooooool0003o
000000Co000000?oooooo`000?l000001Ol00007ooooo`;o00000oooool3o`0000;ooooo00Go0000
ooooool0003oooooo`000002ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`;o000000?o
ooooo`000?l000001oooool4o`0000?ooooo0ol00003ooooo`Co000000Koooooo`000?oooooo0000
ooooool00008ooooo`?o00001?ooool4o`000004ooooool0003o0000o`0000Cooooo1?l000001_oo
oooo0000ooooool0003oooooo`0000;ooooo0ol00002ooooo`Ko000000Coooooo`000?l0003o0000
0_ooool3o`0002_ooooo0ol0000:ooooo`00BOooool01_l0003oooooooooool0003oooooo`0000Go
oooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo00?o0000ooooooooool01?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooool000002Oooool01_l0003oooooooooool0003oooooo`0000Gooooo00Co0000oooooooooooo
00000_ooool01Ol0003oooooo`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01ol0003oooooo`000?oooooo0000ooooool000001Oooool2o`0000;ooooo00?o0000ooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`0000Wooooo0019ooooo`03
o`000?oooooo000000;ooooo1Ol000000ooooooo0000o`000002o`0000Cooooo0_l00008ooooo`03
o`000?oooooooooo00?ooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003ooooo
o`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo1Ol00003oooo
o`03o`000?oooooooooo00Sooooo00Go0000oooooooooooo0000ooooo`05o`0000;ooooo0ol00002
ooooo`05o`000?oooooo0000ooooool000002Oooool00ol0003oooooooooo`03ooooo`?o00000ooo
ool00ol0003oooooooooo`03ooooo`?o00000_ooool01_l0003oooooo`000?oooooo0000ooooo`Go
000000?oooooo`000?l000000_ooool00ol0003oooooo`000004o`0000;ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`07ooooo`00BOooool3o`0000;ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool2o`0000Sooooo00?o0000oooo
ooooool00oooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo000000;o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000
oooooooooooo0000ooooool00009ooooo`?o00000_ooool01ol0003ooooooooooooooooo0000oooo
ool000000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00002Oooool3o`0000;ooooo
00Co0000oooooooooooo00000oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01ol0
003oooooo`000?oooooo0000ooooool000000oooool01?l0003oooooo`000?l00002ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooooooool00_l0000/ooooo`;o00002_ooool004Wooooo00Co
0000oooooooooooo00000_ooool3o`0000;ooooo0ol00005ooooo`;o00002?ooool00ol0003ooooo
ooooo`04ooooo`?o00000_ooool2o`000004ooooool0003oooooooooo`Co00001?ooool00ol0003o
ooooooooo`02ooooo`?o00000_ooool2o`000003ooooool0003o000000Sooooo00Co0000oooooooo
oooo00000_ooool3o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?ooool02Oooool01?l0
003oooooooooool00002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00003
ooooo`;o000000?oooooo`000?ooool00_ooool3o`0000;ooooo1Ol00002ooooo`?o00000_ooool2
o`000003ooooool0003o000002Wooooo00?o0000ooooooooool02_ooool004Wooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`05ooooo`;o00002Oooool01?l0003oooooooooool0
000Eooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00006oooool01?l0003ooooo
ooooool0000Oooooo`;o000000?oooooo`000?l00000=Oooool01?l0003oooooooooool00009oooo
o`00B?ooool4o`0000Oooooo0ol00004ooooo`Go00002Oooool3o`0001?ooooo0ol0000Eooooo`Co
00006oooool4o`00023ooooo0_l00002ooooo`;o0000=Oooool3o`0000Wooooo003oooooob7ooooo
003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-27.5044, -244.109, \
0.911776, 7.92754}},
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00421648 0.00872439 0.0878044 [
[.23463 -0.00378 -6 -9 ]
[.23463 -0.00378 6 0 ]
[.44546 -0.00378 -9 -9 ]
[.44546 -0.00378 9 0 ]
[.65628 -0.00378 -9 -9 ]
[.65628 -0.00378 9 0 ]
[.86711 -0.00378 -9 -9 ]
[.86711 -0.00378 9 0 ]
[.01131 .09653 -6 -4.5 ]
[.01131 .09653 0 4.5 ]
[.01131 .18433 -6 -4.5 ]
[.01131 .18433 0 4.5 ]
[.01131 .27214 -6 -4.5 ]
[.01131 .27214 0 4.5 ]
[.01131 .35994 -6 -4.5 ]
[.01131 .35994 0 4.5 ]
[.01131 .44775 -6 -4.5 ]
[.01131 .44775 0 4.5 ]
[.01131 .53555 -6 -4.5 ]
[.01131 .53555 0 4.5 ]
[.5 .63053 -98.0625 0 ]
[.5 .63053 98.0625 12 ]
[.23873 .66426 -5 -6 ]
[.23873 .66426 5 6 ]
[.27688 .66426 -5 -6 ]
[.27688 .66426 5 6 ]
[.75544 .66426 -5 -6 ]
[.75544 .66426 5 6 ]
[.97619 .66426 -5 -6 ]
[.97619 .66426 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23463 .00872 m
.23463 .01497 L
s
[(50)] .23463 -0.00378 0 1 Mshowa
.44546 .00872 m
.44546 .01497 L
s
[(100)] .44546 -0.00378 0 1 Mshowa
.65628 .00872 m
.65628 .01497 L
s
[(150)] .65628 -0.00378 0 1 Mshowa
.86711 .00872 m
.86711 .01497 L
s
[(200)] .86711 -0.00378 0 1 Mshowa
.125 Mabswid
.06597 .00872 m
.06597 .01247 L
s
.10814 .00872 m
.10814 .01247 L
s
.1503 .00872 m
.1503 .01247 L
s
.19247 .00872 m
.19247 .01247 L
s
.2768 .00872 m
.2768 .01247 L
s
.31896 .00872 m
.31896 .01247 L
s
.36113 .00872 m
.36113 .01247 L
s
.40329 .00872 m
.40329 .01247 L
s
.48762 .00872 m
.48762 .01247 L
s
.52979 .00872 m
.52979 .01247 L
s
.57195 .00872 m
.57195 .01247 L
s
.61412 .00872 m
.61412 .01247 L
s
.69845 .00872 m
.69845 .01247 L
s
.74061 .00872 m
.74061 .01247 L
s
.78278 .00872 m
.78278 .01247 L
s
.82494 .00872 m
.82494 .01247 L
s
.90927 .00872 m
.90927 .01247 L
s
.95144 .00872 m
.95144 .01247 L
s
.9936 .00872 m
.9936 .01247 L
s
.25 Mabswid
0 .00872 m
1 .00872 L
s
.02381 .09653 m
.03006 .09653 L
s
[(1)] .01131 .09653 1 0 Mshowa
.02381 .18433 m
.03006 .18433 L
s
[(2)] .01131 .18433 1 0 Mshowa
.02381 .27214 m
.03006 .27214 L
s
[(3)] .01131 .27214 1 0 Mshowa
.02381 .35994 m
.03006 .35994 L
s
[(4)] .01131 .35994 1 0 Mshowa
.02381 .44775 m
.03006 .44775 L
s
[(5)] .01131 .44775 1 0 Mshowa
.02381 .53555 m
.03006 .53555 L
s
[(6)] .01131 .53555 1 0 Mshowa
.125 Mabswid
.02381 .02629 m
.02756 .02629 L
s
.02381 .04385 m
.02756 .04385 L
s
.02381 .06141 m
.02756 .06141 L
s
.02381 .07897 m
.02756 .07897 L
s
.02381 .11409 m
.02756 .11409 L
s
.02381 .13165 m
.02756 .13165 L
s
.02381 .14921 m
.02756 .14921 L
s
.02381 .16677 m
.02756 .16677 L
s
.02381 .20189 m
.02756 .20189 L
s
.02381 .21945 m
.02756 .21945 L
s
.02381 .23702 m
.02756 .23702 L
s
.02381 .25458 m
.02756 .25458 L
s
.02381 .2897 m
.02756 .2897 L
s
.02381 .30726 m
.02756 .30726 L
s
.02381 .32482 m
.02756 .32482 L
s
.02381 .34238 m
.02756 .34238 L
s
.02381 .3775 m
.02756 .3775 L
s
.02381 .39506 m
.02756 .39506 L
s
.02381 .41262 m
.02756 .41262 L
s
.02381 .43019 m
.02756 .43019 L
s
.02381 .46531 m
.02756 .46531 L
s
.02381 .48287 m
.02756 .48287 L
s
.02381 .50043 m
.02756 .50043 L
s
.02381 .51799 m
.02756 .51799 L
s
.02381 .55311 m
.02756 .55311 L
s
.02381 .57067 m
.02756 .57067 L
s
.02381 .58823 m
.02756 .58823 L
s
.02381 .60579 m
.02756 .60579 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -159.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Imaginary) show
123.000 13.000 moveto
(Complex) show
171.000 13.000 moveto
(Beam) show
201.125 13.000 moveto
(Parameter) show
255.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .60332 m
.09004 .60332 L
.16227 .60332 L
.19739 .60332 L
.21452 .60332 L
.23011 .60332 L
.23388 .60332 L
.23595 .60332 L
.23788 .60332 L
.23997 .01788 L
.24107 .01788 L
.24227 .01788 L
.24631 .01788 L
.26163 .01788 L
.26595 .01788 L
.27066 .01788 L
.27281 .01788 L
.27399 .01788 L
.27511 .01788 L
.27727 .01472 L
.27924 .01472 L
.29535 .01472 L
.36144 .01472 L
.43173 .01472 L
.49942 .01472 L
.56452 .01472 L
.63381 .01472 L
.70051 .01472 L
.71795 .01472 L
.73693 .01472 L
.74561 .01472 L
.75037 .01472 L
.7527 .01472 L
.75484 .01472 L
.75669 .01472 L
.75863 .01472 L
.76272 .01472 L
.77142 .01472 L
.83675 .01472 L
.90628 .01472 L
.97322 .01472 L
.97619 .01472 L
s
0 0 0 r
gsave
.23873 .66426 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27688 .66426 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75544 .66426 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .66426 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23873 .00872 m
0 0 rlineto s
.23873 .00872 m
.23873 .61803 L
s
.27688 .00872 m
0 0 rlineto s
.27688 .00872 m
.27688 .61803 L
s
.75544 .00872 m
0 0 rlineto s
.75544 .00872 m
.75544 .61803 L
s
.97619 .00872 m
0 0 rlineto s
.97619 .00872 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00Boooool3o`0000Cooooo0_l0000Wooooo`?o00001?ooool2o`0000Cooooo0_l0000Uoooo
o`?o00000oooool3o`0000Cooooo0_l0000Sooooo`Go00000oooool2o`0000Cooooo0_l0000_oooo
o`00B_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00009oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
9Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000^ooooo`00C_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0002kooooo001>ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0/ooooo`00B_ooool4o`0000?ooooo00Co
0000oooooooooooo00009oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009Oooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000
oooooooooooo00008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000^ooooo`00B_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0002Kooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00009?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002kooooo001:ooooo`Go00000oooool2o`0002Sooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l0000Vooooo`04o`000?ooooooooooooooo`Go00000oooool2
o`0002Cooooo0ol00004ooooo`;o00001?ooool2o`0002oooooo003oooooob7ooooo000Mooooo`03
o`000?oooooooooo0?oooooo0Oooool001gooooo00?o0000ooooooooool0ooooool1ooooo`007Ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000GooooooCo00005Oooool0
01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o00002Oooool00ol0
003o2NX:o`WZ2P1ao`WZ2P03o`000?l9jP[o2NX:03;o2NX:00Go0000ooooooooooooooooo`00000G
ooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[o2NX:00Oo2NX:00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03
o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo0_l0000booooo`03o`00
0?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01ooo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Ooo
ool001gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0
003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003o
2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo
000Mooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000
ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000o`WZ
2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`00
7Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool0
0ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000o`WZ2_ooool01oooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Go
oooo0ol00005ooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo
000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:oooo
o`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Iooooo`005_ooool00ol0003oooooooooo`04ooooo`?o0000<Oooool00ol0003o2NX:ooooo`07
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0I
ooooo`005_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ
2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool06Oooool001Gooooo0_l00006ooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_oo
ool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool06Oooool001Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`03o`00
0?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003o2NX:ooooo`07ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool0
0ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo
037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o
2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000o`WZ2_ooool01oooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0a
ooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ
2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`00
7Oooool2o`0003;ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Ooo
ool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[o
oooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001go
oooo0_l0000booooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo
00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool06Oooool001Cooooo1Ol00004ooooo`03o`000?oooooooooo037ooooo00?o
0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool06Oooool001Gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01Wooooo000Fooooo`03o`000?oooooooooo00Cooooo0ol0000a
ooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01Wooooo000Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Iooooo`005?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`005?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Ioooo
o`005Oooool3o`0000Gooooo0_l0000booooo`03o`000?l9jP[ooooo00Oooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`00
0?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Ooo
ool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[o
oooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001go
oooo0_l0000booooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo
00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:oooo
o`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Moooo
o`;o0000<_ooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03
o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool0
1oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
6Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2
o`0003;ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0
003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Iooooo`005Oooool3o`0000Gooooo00?o0000ooooooooool0<Oooool00ol0003o
2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Iooooo`005?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Iooooo`006?ooool00ol0003oooooooooo`02ooooo`?o0000
<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Iooooo`005_ooool2o`0000Gooooo00?o0000ooooooooool0<Ooo
ool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Iooooo`006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06Oooool001Cooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Gooooo0ol00005oooo
o`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo0_l0000booooo`03
o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool0
1oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
6Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool0
0ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0
003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oo
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wo
oooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Ioooo
o`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo0_l0000booooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool0
01Kooooo0ol00004ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wo
oooo000Dooooo`Go00001?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo
000Dooooo`04o`000?ooooooooooo`0000Gooooo0ol0000aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo
000Eooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Iooooo`005_ooool2o`0000Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0I
ooooo`005oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool06Oooool001gooooo0_l0000booooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Iooooo`007Oooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
6Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2
o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Iooooo`005Oooool3o`0000Gooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Iooooo`005?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Iooooo`006?ooool00ol0003oooooooooo`02ooooo`?o0000
<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Iooooo`006?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool06Oooool001Cooooo1?l00005ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06Oooool001Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Dooooo`Go00001?ooool2o`0003;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000M
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06Oooool001gooooo0_l0000booooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0I
ooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Eooooo`?o
00001Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Dooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wo
oooo000Dooooo`05o`000?ooooooooooooooool000001?ooool3o`00037ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool06Oooool001Cooooo1?l00005ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
6Oooool001Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Wooooo000Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Iooooo`005_ooool2o`0000Gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool06Oooool001gooooo0_l0000booooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Iooooo`007Oooooldo`WZ2P03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wo
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0014ooooo`?o
00006_ooool3o`0001_ooooo0ol0002Nooooo`00Aoooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0WOooool0037ooooo1Ol000001_oooooo0000oooo
ool0003oooooo`0000;ooooo1?l00002ooooo`Co000000?oooooo`000?l000000ol000001Ooooooo
0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00005
ooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`?o00000_ooool01Ol0003oooooo`000?oo
oooo000000;ooooo0ol00002ooooo`Go00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`00
0007ooooo`Co00000oooool3o`0000?ooooo1?l000001_oooooo0000ooooool0003oooooo`0000Oo
oooo0ol00004ooooo`Co000000Coooooo`000?l0003o00001?ooool4o`000006ooooool0003ooooo
o`000?oooooo00000_ooool3o`0000Cooooo0_l00003ooooo`?o00000_ooool3o`0003;ooooo000c
ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001?ooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooo000000Wooooo00Ko0000oooooooooooo0000ooooool00005ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000008ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000Kooooo00Ko0000oooooooo
oooo0000ooooool00006ooooo`03o`000?oooooooooo037ooooo000cooooo`09o`000?oooooooooo
ooooool0003oooooo`000?oooooo000000;ooooo0ol00002ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`06o`0000;ooooo1ol00005ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool00oooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooooooool5o`00
00?ooooo00?o0000ooooooooool02?ooool01Ol0003oooooooooool0003ooooo00Go00000_ooool3
o`0000;ooooo00Go0000ooooool0003oooooo`000008ooooo`03o`000?oooooooooo00?ooooo0ol0
0003ooooo`04o`000?ooooooooooooooo`Ko000000Ooooooo`000?oooooo0000ooooool0003ooooo
00Go00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool00ol0003oooooooooo`0Coooo
o`?o00006oooool003?ooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003ooooo
o`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`;o000000Goooooo`000?l0003oooooo`000002ooooo`;o00000_ooool2o`0000Cooooo00?o0000
ooooool000002?ooool00ol0003oooooooooo`03ooooo`0;o`000?ooooooooooooooool0003ooooo
o`000?oooooo0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01_l0003oooooooooool0003oooooo`0000Wooooo0ol00002ooooo`07
o`000?ooooooooooooooool0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oooooo0000
ooooool00008ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`;o00000_ooool2o`00
00;ooooo00[o0000oooooooooooo0000ooooool0003oooooo`000?oooooo00000oooool01?l0003o
ooooooooool00004ooooo`05o`000?ooooooooooooooool000000_ooool2o`0001Cooooo00Co0000
oooooooooooo00006_ooool003?ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000oooo
o`02ooooo`;o00001?ooool8o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?ooool00_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Oooooo00?o0000ooooooooool0
1?ooool3o`0000;ooooo0_l000001?oooooo0000ooooooooool4o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`04o`000?ooooooooooo`00
00;ooooo0ol00003ooooo`;o00000oooool2o`000003ooooool0003ooooo00Sooooo00Co0000oooo
oooooooo00000_ooool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00000_oo
ool2o`000003ooooool0003ooooo00;ooooo0ol00002ooooo`Co00000oooool3o`0000;ooooo0_l0
00000ooooooo0000o`00000Eooooo`03o`000?oooooooooo01Sooooo000cooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`04o`000?oooooo
ooooo`0001Gooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0000Jooooo`04o`00
0?ooooooooooo`0000cooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo
023ooooo0_l0000Kooooo`00<Oooool5o`0001Gooooo00Go0000ooooooooooooooooo`000009oooo
o`03o`000?oooooooooo01?ooooo0ol0000Cooooo`?o00005Oooool4o`0001[ooooo1?l0000=oooo
o`05o`000?oooooo0000ooooool000003oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01_ooooo001?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?ooool2o`00
0003ooooool0003o0000037ooooo00Co0000oooooooooooo00006_ooool004kooooo0ol00007oooo
o`?o0000LOooool01?l0003oooooooooooooool2o`00037ooooo0ol0000Jooooo`00oooooolQoooo
o`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.0565, -0.565299, \
0.978384, 0.0469833}},
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00421648 0.119475 0.000483855 [
[.23463 .10697 -6 -9 ]
[.23463 .10697 6 0 ]
[.44546 .10697 -9 -9 ]
[.44546 .10697 9 0 ]
[.65628 .10697 -9 -9 ]
[.65628 .10697 9 0 ]
[.86711 .10697 -9 -9 ]
[.86711 .10697 9 0 ]
[.01131 .0227 -24 -4.5 ]
[.01131 .0227 0 4.5 ]
[.01131 .21625 -18 -4.5 ]
[.01131 .21625 0 4.5 ]
[.01131 .31302 -18 -4.5 ]
[.01131 .31302 0 4.5 ]
[.01131 .40979 -18 -4.5 ]
[.01131 .40979 0 4.5 ]
[.01131 .50656 -18 -4.5 ]
[.01131 .50656 0 4.5 ]
[.01131 .60333 -24 -4.5 ]
[.01131 .60333 0 4.5 ]
[.5 .63053 -83.0625 0 ]
[.5 .63053 83.0625 12 ]
[.23873 .65712 -5 -6 ]
[.23873 .65712 5 6 ]
[.27688 .65712 -5 -6 ]
[.27688 .65712 5 6 ]
[.75544 .65712 -5 -6 ]
[.75544 .65712 5 6 ]
[.97619 .65712 -5 -6 ]
[.97619 .65712 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23463 .11947 m
.23463 .12572 L
s
[(50)] .23463 .10697 0 1 Mshowa
.44546 .11947 m
.44546 .12572 L
s
[(100)] .44546 .10697 0 1 Mshowa
.65628 .11947 m
.65628 .12572 L
s
[(150)] .65628 .10697 0 1 Mshowa
.86711 .11947 m
.86711 .12572 L
s
[(200)] .86711 .10697 0 1 Mshowa
.125 Mabswid
.06597 .11947 m
.06597 .12322 L
s
.10814 .11947 m
.10814 .12322 L
s
.1503 .11947 m
.1503 .12322 L
s
.19247 .11947 m
.19247 .12322 L
s
.2768 .11947 m
.2768 .12322 L
s
.31896 .11947 m
.31896 .12322 L
s
.36113 .11947 m
.36113 .12322 L
s
.40329 .11947 m
.40329 .12322 L
s
.48762 .11947 m
.48762 .12322 L
s
.52979 .11947 m
.52979 .12322 L
s
.57195 .11947 m
.57195 .12322 L
s
.61412 .11947 m
.61412 .12322 L
s
.69845 .11947 m
.69845 .12322 L
s
.74061 .11947 m
.74061 .12322 L
s
.78278 .11947 m
.78278 .12322 L
s
.82494 .11947 m
.82494 .12322 L
s
.90927 .11947 m
.90927 .12322 L
s
.95144 .11947 m
.95144 .12322 L
s
.9936 .11947 m
.9936 .12322 L
s
.25 Mabswid
0 .11947 m
1 .11947 L
s
.02381 .0227 m
.03006 .0227 L
s
[(-200)] .01131 .0227 1 0 Mshowa
.02381 .21625 m
.03006 .21625 L
s
[(200)] .01131 .21625 1 0 Mshowa
.02381 .31302 m
.03006 .31302 L
s
[(400)] .01131 .31302 1 0 Mshowa
.02381 .40979 m
.03006 .40979 L
s
[(600)] .01131 .40979 1 0 Mshowa
.02381 .50656 m
.03006 .50656 L
s
[(800)] .01131 .50656 1 0 Mshowa
.02381 .60333 m
.03006 .60333 L
s
[(1000)] .01131 .60333 1 0 Mshowa
.125 Mabswid
.02381 .0469 m
.02756 .0469 L
s
.02381 .07109 m
.02756 .07109 L
s
.02381 .09528 m
.02756 .09528 L
s
.02381 .14367 m
.02756 .14367 L
s
.02381 .16786 m
.02756 .16786 L
s
.02381 .19205 m
.02756 .19205 L
s
.02381 .24044 m
.02756 .24044 L
s
.02381 .26463 m
.02756 .26463 L
s
.02381 .28882 m
.02756 .28882 L
s
.02381 .33721 m
.02756 .33721 L
s
.02381 .3614 m
.02756 .3614 L
s
.02381 .3856 m
.02756 .3856 L
s
.02381 .43398 m
.02756 .43398 L
s
.02381 .45817 m
.02756 .45817 L
s
.02381 .48237 m
.02756 .48237 L
s
.02381 .53075 m
.02756 .53075 L
s
.02381 .55494 m
.02756 .55494 L
s
.02381 .57914 m
.02756 .57914 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -144.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Real) show
93.000 13.000 moveto
(Complex) show
141.000 13.000 moveto
(Beam) show
171.125 13.000 moveto
(Parameter) show
225.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .60332 m
.09004 .59572 L
.16227 .58743 L
.19739 .5834 L
.21452 .58143 L
.23011 .57965 L
.23388 .57921 L
.23595 .57898 L
.23788 .57875 L
.23997 .03913 L
.24107 .03901 L
.24227 .03887 L
.24631 .03841 L
.26163 .03665 L
.26595 .03615 L
.27066 .03561 L
.27281 .03537 L
.27399 .03523 L
.27511 .0351 L
.27727 .06952 L
.27924 .06929 L
.29535 .06744 L
.36144 .05986 L
.43173 .05179 L
.49942 .04403 L
.56452 .03656 L
.63381 .0286 L
.70051 .02095 L
.71795 .01895 L
.73693 .01677 L
.74561 .01577 L
.75037 .01523 L
.7527 .01496 L
.75484 .01472 L
.75669 .12434 L
.75863 .12411 L
.76272 .12364 L
.77142 .12265 L
.83675 .11515 L
.90628 .10717 L
.97322 .09949 L
.97619 .09915 L
s
0 0 0 r
gsave
.23873 .65712 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27688 .65712 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75544 .65712 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .65712 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23873 .03527 m
0 0 rlineto s
.23873 .03527 m
.23873 .61803 L
s
.27688 .03527 m
0 0 rlineto s
.27688 .03527 m
.27688 .61803 L
s
.75544 .03527 m
0 0 rlineto s
.75544 .03527 m
.75544 .61803 L
s
.97619 .03527 m
0 0 rlineto s
.97619 .03527 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o7_ooool0
0ol0003oooooooooo`3oooooo`007_ooool00ol0003oooooooooo`3oooooo`007_ooool00ol0003o
ooooooooo`3oooooo`002?ooool5o`0000?ooooo0_l00004ooooo`;o00001_ooool00ol0003ooooo
ooooo`2jooooo`;o2NX:@oooool000Wooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0[oooool=o`WZ
2T?ooooo0002ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001Oooool2o`000:[ooooo1_l9jPX<ooooo`03o`WZ2_oooooo
oooo047ooooo000;ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0X?ooool9o`WZ2Q;ooooo00?o
2NX:ooooooooool0@Oooool000Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`2Gooooo`Wo
2NX:6oooool00ol9jP[oooooooooo`11ooooo`002?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1<ooooo`Wo2NX:9?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Oooooo0009ooooo`?o00001?ooool2o`00
00Cooooo0_l00006ooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooooooo1Ol9jPX0
0ol0003oooooooooo`14ooooo`Wo2NX:;Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00Co0000o`WZ2_l9jP[o2NX:1Oooool0
0ol0003oooooooooo`0kooooo`Wo2NX:=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0cooooo`So2NX:?oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00Sooooo000Nooooo`;o0000=_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02[o
oooo2Ol9jPY7ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo
2Ol9jPY@ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?l9jP[ooooo01Sooooo2Ol9
jPYIooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?l9jP[ooooo00oooooo2Ol9jPYR
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?l9jP[ooooo00Kooooo2Ol9jPY[oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?l9jP[ooooo00Ko2NX:M?ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000=_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?l9jP[o2NX:07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`0_ooooo`?o00000oooool3o`0000Kooooo00?o
0000ooooooooool08Oooool3o`0000Cooooo0_l00004ooooo`;o0000:?ooool3o`0000?ooooo0ol0
0004ooooo`;o00004oooool00ol0003oooooooooo`0Aooooo`Go00000oooool2o`0000Cooooo0_l0
000Eooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02kooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo0000:?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool0<_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000:?ooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool0000Dooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo02kooooo1?l00003ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000:?ooool01?l0003oooooooooooooool4o`0000?ooooo
00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`0Aooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Cooooo00?o
0000ooooooooool02?ooool001kooooo0_l0000_ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`0Qooooo`;o00001?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0002Oooooo0_l00003ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`0Aooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Cooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0;_ooool5o`0000;ooooo0ol0
0006ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0
000Yooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0001?ooooo00?o0000ooooooooool0
4_ooool3o`0000Cooooo0_l00004ooooo`;o00004Oooool4o`WZ2P03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo02Wooooo2Ol9jPX4ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo027ooooo2?l9jPX=ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo01_ooooo1_l9jPXEooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo01Gooooo1_l9jPXKooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo00[ooooo2ol9jPXQooooo`03o`000?oooooooooo00Sooooo000GooooolSo00002_l9
jPXdo`0000?ooooo000Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2
o`0000Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`05o`000?oooooo
ooooooooool000000_l9jPX4ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo000Nooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo0_l0
000fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`08ooooo`007_ooool2o`0003Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo0_l0000fooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`002?ooool5
o`0000?ooooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
2?ooool000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`00
2oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`;o0000=_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`002?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool000Sooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0009ooooo`?o0000
1?ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000=_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool02?ooool001kooooo0_l0000fooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[o
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000=_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool000[ooooo0ol00003ooooo`;o
00001?ooool2o`0000Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`00
2oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool000So
oooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0008ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`;o0000
=Oooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0dooooo`03
o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Sooooo000:ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07oooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08oooo
o`002oooool00ol0003oooooooooo`02ooooo`;o00001?ooool2o`0000Kooooo00?o0000oooooooo
ool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ
2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01ooo
ool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?oo
ool001kooooo0_l0000eooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9jP[o
0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0doooo
o`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Sooooo000Nooooo`;o0000=Oooool00ol9jP[o0000ooooo`07ooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0
N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?ooool0
0ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo
00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo
0_l0000eooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o
2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07
ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0009ooooo`?o
00001?ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?oo
ool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool02?ooool000Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003o
oooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Sooooo0008ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Gooooo0_l0000eooooo`03o`WZ2_l0003ooooo00Oooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo
0008ooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[o
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`002?ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool02?ooool000[ooooo0_l00004ooooo`;o00001?ooool2o`00
00Kooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo
07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000=Oooool00ol9jP[o0000
ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03
o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool0
1oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool2
o`0003Gooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9
jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oo
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0d
ooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000=Oooool00ol9jP[o0000ooooo`07oooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000oooooooo
ool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?oo
ool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`08ooooo`002Oooool3o`0000Cooooo0_l00004ooooo`;o00001_ooool0
0ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0008ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`002?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005oooo
o`;o0000=Oooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`08ooooo`002Oooool3o`0000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03Cooooo00?o2NX:
o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool02?ooool000Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0dooooo`03o`WZ
2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00Sooooo0008ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0=?ooool00ol9
jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`08ooooo`002Oooool3o`0000Cooooo0_l00004ooooo`;o00001_ooool00ol0003o
ooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo
00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000oooo
o`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`08ooooo`007_ooool2o`0003Gooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03
o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool0
1oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000=Oooool00ol9
jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`WZ2_l0003ooooo00Oo
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`000?ooool01oooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool0=?ooool00ol9jP[o0000ooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0d
ooooo`03o`WZ2_l0003ooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o2NX:o`00
0?ooool01oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool02?ooool001kooooo0_l0000aooooo`Go2NX:00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool09_ooool:o`WZ2PGooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool07_ooool8o`WZ2Poooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool05oooool7o`WZ2QOooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool000?ooooo0ol00004oooo
o`;o00001?ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo017ooooo1_l9jPXNoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Sooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool02_ooool7o`WZ2RCooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool000Cooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooooooool9o`WZ2R_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool02?ooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool4o`WZ2SCooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool02?ooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0003ooooo`;o00001?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0004ooooo`03o`000?oooooooooo
00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`08ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00N?ooool3o`000:Gooooo001iooooo`03o`000?oooooooooo0:Cooooo
0018ooooo`?o00000_ooool00ol0003oooooo`000002o`000003ooooool0003o000000Co000000?o
ooooo`000?l000001Ol00007ooooo`;o00000oooool3o`0000;ooooo00Go0000ooooool0003ooooo
o`000002ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l00000
1oooool4o`0000?ooooo0ol00003ooooo`Co000000Koooooo`000?oooooo0000ooooool00008oooo
o`?o00001?ooool4o`000004ooooool0003o0000o`0000Cooooo1?l000001_oooooo0000ooooool0
003oooooo`0000;ooooo0ol00002ooooo`Ko000000Coooooo`000?l0003o00000_ooool3o`0002_o
oooo0ol0000:ooooo`00BOooool01_l0003oooooooooool0003oooooo`0000Gooooo00Co0000oooo
oooooooo00001?ooool2o`0000;ooooo00?o0000ooooooooool01?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool000002Ooo
ool01_l0003oooooooooool0003oooooo`0000Gooooo00Co0000oooooooooooo00000_ooool01Ol0
003oooooo`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000001Oooool2o`0000;ooooo00?o0000ooooool000001_ooool00ol0
003oooooooooo`0Zooooo`04o`000?ooooooooooo`0000Wooooo0019ooooo`03o`000?oooooo0000
00;ooooo1Ol000000ooooooo0000o`000002o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo
00?ooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo1Ol00003ooooo`03o`000?oooooo
oooo00Sooooo00Go0000oooooooooooo0000ooooo`05o`0000;ooooo0ol00002ooooo`05o`000?oo
oooo0000ooooool000002Oooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003ooooo
ooooo`03ooooo`?o00000_ooool01_l0003oooooo`000?oooooo0000ooooo`Go000000?oooooo`00
0?l000000_ooool00ol0003oooooo`000004o`0000;ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`07ooooo`00BOooool3o`0000;ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000;ooooo00?o0000ooooooooool00_ooool2o`0000Sooooo00?o0000ooooooooool00oooool0
2ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000oooooooooooo0000
ooooool00009ooooo`?o00000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool0
2?l0003oooooooooool0003oooooo`000?oooooo00002Oooool3o`0000;ooooo00Co0000oooooooo
oooo00000oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01ol0003oooooo`000?oo
oooo0000ooooool000000oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool00_l0000/ooooo`;o00002_ooool004Wooooo00Co0000oooooooooooo
00000_ooool3o`0000;ooooo0ol00005ooooo`;o00002?ooool00ol0003oooooooooo`04ooooo`?o
00000_ooool2o`000004ooooool0003oooooooooo`Co00001?ooool00ol0003oooooooooo`02oooo
o`?o00000_ooool2o`000003ooooool0003o000000Sooooo00Co0000oooooooooooo00000_ooool3
o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?ooool02Oooool01?l0003oooooooooool0
0002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o000000?o
ooooo`000?ooool00_ooool3o`0000;ooooo1Ol00002ooooo`?o00000_ooool2o`000003ooooool0
003o000002Wooooo00?o0000ooooooooool02_ooool004Wooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`05ooooo`;o00002Oooool01?l0003oooooooooool0000Eooooo`03o`00
0?oooooooooo01Cooooo00Co0000oooooooooooo00006oooool01?l0003oooooooooool0000Ooooo
o`;o000000?oooooo`000?l00000=Oooool01?l0003oooooooooool00009ooooo`00B?ooool4o`00
00Oooooo0ol00004ooooo`Go00002Oooool3o`0001?ooooo0ol0000Eooooo`Co00006oooool4o`00
023ooooo0_l00002ooooo`;o0000=Oooool3o`0000Wooooo003oooooob7ooooo003oooooob7ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-27.4958, -246.93, 0.91172, \
7.94505}},
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00421648 0.00830168 0.0878668 [
[.23463 -0.0042 -6 -9 ]
[.23463 -0.0042 6 0 ]
[.44546 -0.0042 -9 -9 ]
[.44546 -0.0042 9 0 ]
[.65628 -0.0042 -9 -9 ]
[.65628 -0.0042 9 0 ]
[.86711 -0.0042 -9 -9 ]
[.86711 -0.0042 9 0 ]
[.01131 .09617 -6 -4.5 ]
[.01131 .09617 0 4.5 ]
[.01131 .18404 -6 -4.5 ]
[.01131 .18404 0 4.5 ]
[.01131 .2719 -6 -4.5 ]
[.01131 .2719 0 4.5 ]
[.01131 .35977 -6 -4.5 ]
[.01131 .35977 0 4.5 ]
[.01131 .44764 -6 -4.5 ]
[.01131 .44764 0 4.5 ]
[.01131 .5355 -6 -4.5 ]
[.01131 .5355 0 4.5 ]
[.5 .63053 -98.0625 0 ]
[.5 .63053 98.0625 12 ]
[.23873 .66431 -5 -6 ]
[.23873 .66431 5 6 ]
[.27688 .66431 -5 -6 ]
[.27688 .66431 5 6 ]
[.75544 .66431 -5 -6 ]
[.75544 .66431 5 6 ]
[.97619 .66431 -5 -6 ]
[.97619 .66431 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23463 .0083 m
.23463 .01455 L
s
[(50)] .23463 -0.0042 0 1 Mshowa
.44546 .0083 m
.44546 .01455 L
s
[(100)] .44546 -0.0042 0 1 Mshowa
.65628 .0083 m
.65628 .01455 L
s
[(150)] .65628 -0.0042 0 1 Mshowa
.86711 .0083 m
.86711 .01455 L
s
[(200)] .86711 -0.0042 0 1 Mshowa
.125 Mabswid
.06597 .0083 m
.06597 .01205 L
s
.10814 .0083 m
.10814 .01205 L
s
.1503 .0083 m
.1503 .01205 L
s
.19247 .0083 m
.19247 .01205 L
s
.2768 .0083 m
.2768 .01205 L
s
.31896 .0083 m
.31896 .01205 L
s
.36113 .0083 m
.36113 .01205 L
s
.40329 .0083 m
.40329 .01205 L
s
.48762 .0083 m
.48762 .01205 L
s
.52979 .0083 m
.52979 .01205 L
s
.57195 .0083 m
.57195 .01205 L
s
.61412 .0083 m
.61412 .01205 L
s
.69845 .0083 m
.69845 .01205 L
s
.74061 .0083 m
.74061 .01205 L
s
.78278 .0083 m
.78278 .01205 L
s
.82494 .0083 m
.82494 .01205 L
s
.90927 .0083 m
.90927 .01205 L
s
.95144 .0083 m
.95144 .01205 L
s
.9936 .0083 m
.9936 .01205 L
s
.25 Mabswid
0 .0083 m
1 .0083 L
s
.02381 .09617 m
.03006 .09617 L
s
[(1)] .01131 .09617 1 0 Mshowa
.02381 .18404 m
.03006 .18404 L
s
[(2)] .01131 .18404 1 0 Mshowa
.02381 .2719 m
.03006 .2719 L
s
[(3)] .01131 .2719 1 0 Mshowa
.02381 .35977 m
.03006 .35977 L
s
[(4)] .01131 .35977 1 0 Mshowa
.02381 .44764 m
.03006 .44764 L
s
[(5)] .01131 .44764 1 0 Mshowa
.02381 .5355 m
.03006 .5355 L
s
[(6)] .01131 .5355 1 0 Mshowa
.125 Mabswid
.02381 .02588 m
.02756 .02588 L
s
.02381 .04345 m
.02756 .04345 L
s
.02381 .06102 m
.02756 .06102 L
s
.02381 .0786 m
.02756 .0786 L
s
.02381 .11374 m
.02756 .11374 L
s
.02381 .13132 m
.02756 .13132 L
s
.02381 .14889 m
.02756 .14889 L
s
.02381 .16646 m
.02756 .16646 L
s
.02381 .20161 m
.02756 .20161 L
s
.02381 .21918 m
.02756 .21918 L
s
.02381 .23676 m
.02756 .23676 L
s
.02381 .25433 m
.02756 .25433 L
s
.02381 .28948 m
.02756 .28948 L
s
.02381 .30705 m
.02756 .30705 L
s
.02381 .32462 m
.02756 .32462 L
s
.02381 .3422 m
.02756 .3422 L
s
.02381 .37734 m
.02756 .37734 L
s
.02381 .39492 m
.02756 .39492 L
s
.02381 .41249 m
.02756 .41249 L
s
.02381 .43006 m
.02756 .43006 L
s
.02381 .46521 m
.02756 .46521 L
s
.02381 .48278 m
.02756 .48278 L
s
.02381 .50036 m
.02756 .50036 L
s
.02381 .51793 m
.02756 .51793 L
s
.02381 .55308 m
.02756 .55308 L
s
.02381 .57065 m
.02756 .57065 L
s
.02381 .58822 m
.02756 .58822 L
s
.02381 .6058 m
.02756 .6058 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -159.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Imaginary) show
123.000 13.000 moveto
(Complex) show
171.000 13.000 moveto
(Beam) show
201.125 13.000 moveto
(Parameter) show
255.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .60332 m
.09004 .60332 L
.16227 .60332 L
.19739 .60332 L
.21452 .60332 L
.23011 .60332 L
.23388 .60332 L
.23595 .60332 L
.23788 .60332 L
.23997 .01804 L
.24107 .01804 L
.24227 .01804 L
.24631 .01804 L
.26163 .01804 L
.26595 .01804 L
.27066 .01804 L
.27281 .01804 L
.27399 .01804 L
.27511 .01804 L
.27727 .01472 L
.27924 .01472 L
.29535 .01472 L
.36144 .01472 L
.43173 .01472 L
.49942 .01472 L
.56452 .01472 L
.63381 .01472 L
.70051 .01472 L
.71795 .01472 L
.73693 .01472 L
.74561 .01472 L
.75037 .01472 L
.7527 .01472 L
.75484 .01472 L
.75669 .01472 L
.75863 .01472 L
.76272 .01472 L
.77142 .01472 L
.83675 .01472 L
.90628 .01472 L
.97322 .01472 L
.97619 .01472 L
s
0 0 0 r
gsave
.23873 .66431 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27688 .66431 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75544 .66431 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .66431 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23873 .0083 m
0 0 rlineto s
.23873 .0083 m
.23873 .61803 L
s
.27688 .0083 m
0 0 rlineto s
.27688 .0083 m
.27688 .61803 L
s
.75544 .0083 m
0 0 rlineto s
.75544 .0083 m
.75544 .61803 L
s
.97619 .0083 m
0 0 rlineto s
.97619 .0083 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00Boooool3o`0000Cooooo0_l0000Wooooo`?o00001?ooool2o`0000Cooooo0_l0000Toooo
o`?o00000oooool3o`0000Cooooo0_l0000Tooooo`Go00000oooool2o`0000Cooooo0_l0000_oooo
o`00B_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00009oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
9?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000^ooooo`00C_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0002kooooo001>ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0/ooooo`00B_ooool4o`0000?ooooo00Co
0000oooooooooooo00009oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00009?ooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000
oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000^ooooo`00B_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0002Kooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00008oooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool0000Sooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002kooooo001:ooooo`Go00000oooool2o`0002Sooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l0000Uooooo`04o`000?ooooooooooooooo`Go00000oooool2
o`0002Gooooo0ol00004ooooo`;o00001?ooool2o`0002oooooo003oooooob7ooooo003oooooob7o
oooo000Mooooo`03o`000?oooooooooo0?oooooo0Oooool001gooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Iooooo`006?oooooco`0001Gooooo000Mooooo`03o`000?oooooooooo
033ooooo0_l00009ooooo`03o`000?l9jP[o2NX:077o2NX:00?o0000o`WZ2_l9jPX0<_l9jPX00ol0
003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[o2NX:00Oo
2NX:00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wo
oooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo0_l0
000booooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000
o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Ioooo
o`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000
<_ooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9
jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool0
01gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;o
oooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:
ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000M
ooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooo
ooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000o`WZ2_oo
ool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool06Oooool001Gooooo0ol00005ooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool0
1oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
6Oooool001Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`03o`000?l9
jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Wooooo000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool0
0ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Iooooo`005_ooool00ol0003oooooooooo`04ooooo`?o0000<Oooool00ol0
003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Iooooo`005_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo037o
oooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool06Oooool001Gooooo0_l00006ooooo`03o`000?oooooooooo037ooooo
00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool06Oooool001Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003o2NX:ooooo`07
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0I
ooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03
o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0
<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000o`WZ2_ooool01ooo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Ooo
ool001gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0
003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037o
oooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:
ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000o`WZ2_ooool01oooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000
ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aoooo
o`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_oo
ool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool06Oooool001gooooo0_l0000booooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool06Oooool001Cooooo1Ol00004ooooo`03o`000?oooooo
oooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06Oooool001Gooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Fooooo`03o`000?oooooooooo
00Cooooo0ol0000aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Gooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`005?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`00
5?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0<Oooool00ol0003o
2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Iooooo`005Oooool3o`0000Gooooo0_l0000booooo`03o`000?l9jP[ooooo00Oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo
000Mooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000
ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aoooo
o`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_oo
ool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool06Oooool001gooooo0_l0000booooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool0
0ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo
00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
01Wooooo000Mooooo`;o0000<_ooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o
0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0I
ooooo`007Oooool2o`0003;ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooooooo
ool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Iooooo`005Oooool3o`0000Gooooo00?o0000ooooooooool0
<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Iooooo`005?ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`006?ooool00ol0003ooooooooo
o`02ooooo`?o0000<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`005_ooool2o`0000Gooooo00?o0000
ooooooooool0<Oooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`006?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Go
oooo0ol00005ooooo`03o`000?oooooooooo037ooooo00?o0000o`WZ2_ooool01oooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo
0_l0000booooo`03o`000?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o
0000o`WZ2_ooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o2NX:ooooo`07
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0I
ooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?l9jP[ooooo00Oooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`;o
0000<_ooool00ol0003o2NX:ooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`00
0?l9jP[ooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Ooo
ool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`00
03;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo
000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo0_l0000b
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool06Oooool001Kooooo0ol00004ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool06Oooool001Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01Wooooo000Dooooo`Go00001?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Wooooo000Dooooo`04o`000?ooooooooooo`0000Gooooo0ol0000aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Wooooo000Eooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Iooooo`005_ooool2o`0000Gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Iooooo`005oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool06Oooool001gooooo0_l0000booooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo
000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`00
7Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001go
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0I
ooooo`007Oooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Iooooo`005Oooool3o`0000Gooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Iooooo`005?ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`006?ooool00ol0003ooooooooo
o`02ooooo`?o0000<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`006?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Cooooo1?l00005oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Dooooo`Go0000
1?ooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001go
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Moooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo0_l0000booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
6Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wo
oooo000Eooooo`?o00001Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo
000Dooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01Wooooo000Dooooo`05o`000?ooooooooooooooool000001?ooool3o`00037ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool06Oooool001Cooooo1?l00005ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool06Oooool001Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01Wooooo000Eooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Iooooo`005_ooool2o`0000Gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0003;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
6Oooool001gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool06Oooool001gooooo0_l0000booooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wo
oooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Ioooo
o`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Iooooo`007Oooooldo`WZ2P03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Moooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01Wooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo0014ooooo`?o00006_ooool3o`0001_ooooo0ol0002Nooooo`00Aoooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0WOooool0037ooooo1Ol00000
1_oooooo0000ooooool0003oooooo`0000;ooooo1?l00002ooooo`Co000000?oooooo`000?l00000
0ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l000001?oooooo
0000o`000?l00005ooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`?o00000_ooool01Ol0
003oooooo`000?oooooo000000;ooooo0ol00002ooooo`Go00000_ooool3o`0000;ooooo0_l00000
0ooooooo0000o`000007ooooo`Co00000oooool3o`0000?ooooo1?l000001_oooooo0000ooooool0
003oooooo`0000Oooooo0ol00004ooooo`Co000000Coooooo`000?l0003o00001?ooool4o`000006
ooooool0003oooooo`000?oooooo00000_ooool3o`0000Cooooo0_l00003ooooo`?o00000_ooool3
o`0003;ooooo000cooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool0
00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001?ooool0
1_l0003oooooooooool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`07o`000?oooooo
0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooo000000Wooooo00Ko0000oooooooooooo0000ooooool0
0005ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000Kooooo
00Ko0000oooooooooooo0000ooooool00006ooooo`03o`000?oooooooooo037ooooo000cooooo`09
o`000?ooooooooooooooool0003oooooo`000?oooooo000000;ooooo0ol00002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`06o`0000;ooooo1ol00005ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool00oooool02ol0003ooooooooooooooooo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooooooool5o`0000?ooooo00?o0000ooooooooool02?ooool01Ol0003oooooooooool0003ooooo
00Go00000_ooool3o`0000;ooooo00Go0000ooooool0003oooooo`000008ooooo`03o`000?oooooo
oooo00?ooooo0ol00003ooooo`04o`000?ooooooooooooooo`Ko000000Ooooooo`000?oooooo0000
ooooool0003ooooo00Go00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool00ol0003o
ooooooooo`0Cooooo`?o00006oooool003?ooooo00_o0000ooooooooooooooooo`000?oooooo0000
ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`;o000000Goooooo`000?l0003oooooo`000002ooooo`;o00000_ooool2o`00
00Cooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`03ooooo`0;o`000?oooooooooo
ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01_l0003oooooooooool0003oooooo`0000Wooooo
0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`08o`000?oooooooooo
o`000?oooooo0000ooooool00008ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`;o
00000_ooool2o`0000;ooooo00[o0000oooooooooooo0000ooooool0003oooooo`000?oooooo0000
0oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000000_ooool2o`00
01Cooooo00Co0000oooooooooooo00006_ooool003?ooooo00Co0000oooooooooooooooo0_l00000
0ooooooo0000ooooo`02ooooo`;o00001?ooool8o`0000?ooooo1?l00003ooooo`;o000000?ooooo
o`000?ooool00_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Oooooo00?o
0000ooooooooool01?ooool3o`0000;ooooo0_l000001?oooooo0000ooooooooool4o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`04o`00
0?ooooooooooo`0000;ooooo0ol00003ooooo`;o00000oooool2o`000003ooooool0003ooooo00So
oooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003o
oooo00?o00000_ooool2o`000003ooooool0003ooooo00;ooooo0ol00002ooooo`Co00000oooool3
o`0000;ooooo0_l000000ooooooo0000o`00000Eooooo`03o`000?oooooooooo01Sooooo000coooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Boooo
o`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0
000Jooooo`04o`000?ooooooooooo`0000cooooo00Go0000ooooooooooooooooo`00000?ooooo`03
o`000?oooooooooo023ooooo0_l0000Kooooo`00<Oooool5o`0001Gooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo01?ooooo0ol0000Cooooo`?o00005Oooool4o`0001[o
oooo1?l0000=ooooo`05o`000?oooooo0000ooooool000003oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01_ooooo001?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0L?ooool2o`000003ooooool0003o0000037ooooo00Co0000oooooooooooo00006_ooool004ko
oooo0ol00007ooooo`?o0000LOooool01?l0003oooooooooooooool2o`00037ooooo0ol0000Joooo
o`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.1574, -0.565164, \
0.979072, 0.0469829}},
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}]
}, Open  ]]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowGaussian", "Subsubsection",
  CellTags->{"AOG0.", "4.4.4", "AOG4.", "AOG4.4", "AOG4.4.4"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[opticalsystemoffaxis, PlotType->TopView, ShowGaussian->True];\
\>", "Input",
  CellLabel->"In[69]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3933 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238977 0.00463403 0.150702 0.00463403 [
[.27877 .00936 -5.03125 -6 ]
[.27877 .00936 5.03125 6 ]
[.78406 .09991 -6.4375 -6 ]
[.78406 .09991 6.4375 6 ]
[.97619 .3824 -4.75 -6 ]
[.97619 .3824 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .3933 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.28531 .03485 m
.30194 .03485 L
.30194 .07347 L
.26833 .07347 L
.28531 .03485 L
F
.26833 .07347 m
.30194 .07347 L
.30194 .11209 L
.25872 .11209 L
.26833 .07347 L
F
.25872 .11209 m
.30194 .11209 L
.30194 .1507 L
.2556 .1507 L
.25872 .11209 L
F
.2556 .1507 m
.30194 .1507 L
.30194 .18932 L
.25872 .18932 L
.2556 .1507 L
F
.25872 .18932 m
.30194 .18932 L
.30194 .22794 L
.26833 .22794 L
.25872 .18932 L
F
.26833 .22794 m
.30194 .22794 L
.30194 .26655 L
.28531 .26655 L
.26833 .22794 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.28531 .03485 m
.26833 .07347 L
.25872 .11209 L
.2556 .1507 L
.25872 .18932 L
.26833 .22794 L
.28531 .26655 L
.30194 .26655 L
.30194 .22794 L
.30194 .18932 L
.30194 .1507 L
.30194 .11209 L
.30194 .07347 L
.30194 .03485 L
.28531 .03485 L
s
.5 g
.28531 .1507 m
.30194 .1507 L
.30194 .1507 L
.26833 .1507 L
.28531 .1507 L
F
.26833 .1507 m
.30194 .1507 L
.30194 .1507 L
.25872 .1507 L
.26833 .1507 L
F
.25872 .1507 m
.30194 .1507 L
.30194 .1507 L
.2556 .1507 L
.25872 .1507 L
F
.2556 .1507 m
.30194 .1507 L
.30194 .1507 L
.25872 .1507 L
.2556 .1507 L
F
.25872 .1507 m
.30194 .1507 L
.30194 .1507 L
.26833 .1507 L
.25872 .1507 L
F
.26833 .1507 m
.30194 .1507 L
.30194 .1507 L
.28531 .1507 L
.26833 .1507 L
F
0 g
.28531 .1507 m
.26833 .1507 L
.25872 .1507 L
.2556 .1507 L
.25872 .1507 L
.26833 .1507 L
.28531 .1507 L
.30194 .1507 L
.30194 .1507 L
.30194 .1507 L
.30194 .1507 L
.30194 .1507 L
.30194 .1507 L
.30194 .1507 L
.28531 .1507 L
s
.28531 .26655 m
.30194 .26655 L
.30194 .26261 L
.28531 .26261 L
.28531 .26655 L
s
.28531 .26261 m
.30194 .26261 L
.30194 .25103 L
.28531 .25103 L
.28531 .26261 L
s
.28531 .25103 m
.30194 .25103 L
.30194 .23262 L
.28531 .23262 L
.28531 .25103 L
s
.28531 .23262 m
.30194 .23262 L
.30194 .20863 L
.28531 .20863 L
.28531 .23262 L
s
.28531 .20863 m
.30194 .20863 L
.30194 .18069 L
.28531 .18069 L
.28531 .20863 L
s
.28531 .18069 m
.30194 .18069 L
.30194 .1507 L
.28531 .1507 L
.28531 .18069 L
s
.28531 .1507 m
.30194 .1507 L
.30194 .12072 L
.28531 .12072 L
.28531 .1507 L
s
.28531 .12072 m
.30194 .12072 L
.30194 .09278 L
.28531 .09278 L
.28531 .12072 L
s
.28531 .09278 m
.30194 .09278 L
.30194 .06878 L
.28531 .06878 L
.28531 .09278 L
s
.28531 .06878 m
.30194 .06878 L
.30194 .05037 L
.28531 .05037 L
.28531 .06878 L
s
.28531 .05037 m
.30194 .05037 L
.30194 .0388 L
.28531 .0388 L
.28531 .05037 L
s
.28531 .0388 m
.30194 .0388 L
.30194 .03485 L
.28531 .03485 L
.28531 .0388 L
s
.28531 .03485 m
.30194 .03485 L
.30194 .0388 L
.28531 .0388 L
.28531 .03485 L
s
.28531 .0388 m
.30194 .0388 L
.30194 .05037 L
.28531 .05037 L
.28531 .0388 L
s
.28531 .05037 m
.30194 .05037 L
.30194 .06878 L
.28531 .06878 L
.28531 .05037 L
s
.28531 .06878 m
.30194 .06878 L
.30194 .09278 L
.28531 .09278 L
.28531 .06878 L
s
.28531 .09278 m
.30194 .09278 L
.30194 .12072 L
.28531 .12072 L
.28531 .09278 L
s
.28531 .12072 m
.30194 .12072 L
.30194 .1507 L
.28531 .1507 L
.28531 .12072 L
s
.28531 .1507 m
.30194 .1507 L
.30194 .18069 L
.28531 .18069 L
.28531 .1507 L
s
.28531 .18069 m
.30194 .18069 L
.30194 .20863 L
.28531 .20863 L
.28531 .18069 L
s
.28531 .20863 m
.30194 .20863 L
.30194 .23262 L
.28531 .23262 L
.28531 .20863 L
s
.28531 .23262 m
.30194 .23262 L
.30194 .25103 L
.28531 .25103 L
.28531 .23262 L
s
.28531 .25103 m
.30194 .25103 L
.30194 .26261 L
.28531 .26261 L
.28531 .25103 L
s
.28531 .26261 m
.30194 .26261 L
.30194 .26655 L
.28531 .26655 L
.28531 .26261 L
s
.5 g
.80209 .11793 m
.80209 .11793 L
.81301 .12886 L
.81301 .12886 L
.80209 .11793 L
F
.81301 .12886 m
.81301 .12886 L
.82393 .13978 L
.82393 .13978 L
.81301 .12886 L
F
.82393 .13978 m
.82393 .13978 L
.83485 .1507 L
.83485 .1507 L
.82393 .13978 L
F
.83485 .1507 m
.83485 .1507 L
.84578 .16162 L
.84578 .16162 L
.83485 .1507 L
F
.84578 .16162 m
.84578 .16162 L
.8567 .17255 L
.8567 .17255 L
.84578 .16162 L
F
.8567 .17255 m
.8567 .17255 L
.86762 .18347 L
.86762 .18347 L
.8567 .17255 L
F
0 g
.80209 .11793 m
.81301 .12886 L
.82393 .13978 L
.83485 .1507 L
.84578 .16162 L
.8567 .17255 L
.86762 .18347 L
.86762 .18347 L
.8567 .17255 L
.84578 .16162 L
.83485 .1507 L
.82393 .13978 L
.81301 .12886 L
.80209 .11793 L
.80209 .11793 L
s
.5 g
.83485 .1507 m
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
F
.83485 .1507 m
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
F
.83485 .1507 m
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
F
.83485 .1507 m
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
F
.83485 .1507 m
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
F
.83485 .1507 m
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
F
0 g
.83485 .1507 m
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
s
.5 g
.83485 .1507 m
.84578 .16162 L
.8454 .16125 L
.83485 .1507 L
.83485 .1507 L
F
.84578 .16162 m
.8567 .17255 L
.85595 .1718 L
.8454 .16125 L
.84578 .16162 L
F
.8567 .17255 m
.86762 .18347 L
.8665 .18235 L
.85595 .1718 L
.8567 .17255 L
F
.83485 .1507 m
.8454 .16125 L
.84431 .16016 L
.83485 .1507 L
.83485 .1507 L
F
.8454 .16125 m
.85595 .1718 L
.85377 .16962 L
.84431 .16016 L
.8454 .16125 L
F
.85595 .1718 m
.8665 .18235 L
.86323 .17908 L
.85377 .16962 L
.85595 .1718 L
F
.83485 .1507 m
.84431 .16016 L
.84258 .15843 L
.83485 .1507 L
.83485 .1507 L
F
.84431 .16016 m
.85377 .16962 L
.8503 .16615 L
.84258 .15843 L
.84431 .16016 L
F
.85377 .16962 m
.86323 .17908 L
.85802 .17387 L
.8503 .16615 L
.85377 .16962 L
F
.83485 .1507 m
.84258 .15843 L
.84031 .15616 L
.83485 .1507 L
.83485 .1507 L
F
.84258 .15843 m
.8503 .16615 L
.84578 .16162 L
.84031 .15616 L
.84258 .15843 L
F
.8503 .16615 m
.85802 .17387 L
.85124 .16709 L
.84578 .16162 L
.8503 .16615 L
F
.83485 .1507 m
.84031 .15616 L
.83768 .15353 L
.83485 .1507 L
.83485 .1507 L
F
.84031 .15616 m
.84578 .16162 L
.84051 .15636 L
.83768 .15353 L
.84031 .15616 L
F
.84578 .16162 m
.85124 .16709 L
.84333 .15918 L
.84051 .15636 L
.84578 .16162 L
F
.83485 .1507 m
.83768 .15353 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
F
.83768 .15353 m
.84051 .15636 L
.83485 .1507 L
.83485 .1507 L
.83768 .15353 L
F
.84051 .15636 m
.84333 .15918 L
.83485 .1507 L
.83485 .1507 L
.84051 .15636 L
F
.83485 .1507 m
.83485 .1507 L
.83203 .14788 L
.83485 .1507 L
.83485 .1507 L
F
.83485 .1507 m
.83485 .1507 L
.8292 .14505 L
.83203 .14788 L
.83485 .1507 L
F
.83485 .1507 m
.83485 .1507 L
.82637 .14222 L
.8292 .14505 L
.83485 .1507 L
F
.83485 .1507 m
.83203 .14788 L
.82939 .14524 L
.83485 .1507 L
.83485 .1507 L
F
.83203 .14788 m
.8292 .14505 L
.82393 .13978 L
.82939 .14524 L
.83203 .14788 L
F
.8292 .14505 m
.82637 .14222 L
.81847 .13432 L
.82393 .13978 L
.8292 .14505 L
F
.83485 .1507 m
.82939 .14524 L
.82713 .14298 L
.83485 .1507 L
.83485 .1507 L
F
.82939 .14524 m
.82393 .13978 L
.81941 .13526 L
.82713 .14298 L
.82939 .14524 L
F
.82393 .13978 m
.81847 .13432 L
.81168 .12753 L
.81941 .13526 L
.82393 .13978 L
F
.83485 .1507 m
.82713 .14298 L
.82539 .14124 L
.83485 .1507 L
.83485 .1507 L
F
.82713 .14298 m
.81941 .13526 L
.81593 .13178 L
.82539 .14124 L
.82713 .14298 L
F
.81941 .13526 m
.81168 .12753 L
.80648 .12232 L
.81593 .13178 L
.81941 .13526 L
F
.83485 .1507 m
.82539 .14124 L
.8243 .14015 L
.83485 .1507 L
.83485 .1507 L
F
.82539 .14124 m
.81593 .13178 L
.81375 .1296 L
.8243 .14015 L
.82539 .14124 L
F
.81593 .13178 m
.80648 .12232 L
.8032 .11905 L
.81375 .1296 L
.81593 .13178 L
F
.83485 .1507 m
.8243 .14015 L
.82393 .13978 L
.83485 .1507 L
.83485 .1507 L
F
.8243 .14015 m
.81375 .1296 L
.81301 .12886 L
.82393 .13978 L
.8243 .14015 L
F
.81375 .1296 m
.8032 .11905 L
.80209 .11793 L
.81301 .12886 L
.81375 .1296 L
F
.83485 .1507 m
.82393 .13978 L
.8243 .14015 L
.83485 .1507 L
.83485 .1507 L
F
.82393 .13978 m
.81301 .12886 L
.81375 .1296 L
.8243 .14015 L
.82393 .13978 L
F
.81301 .12886 m
.80209 .11793 L
.8032 .11905 L
.81375 .1296 L
.81301 .12886 L
F
.83485 .1507 m
.8243 .14015 L
.82539 .14124 L
.83485 .1507 L
.83485 .1507 L
F
.8243 .14015 m
.81375 .1296 L
.81593 .13178 L
.82539 .14124 L
.8243 .14015 L
F
.81375 .1296 m
.8032 .11905 L
.80648 .12232 L
.81593 .13178 L
.81375 .1296 L
F
.83485 .1507 m
.82539 .14124 L
.82713 .14298 L
.83485 .1507 L
.83485 .1507 L
F
.82539 .14124 m
.81593 .13178 L
.81941 .13526 L
.82713 .14298 L
.82539 .14124 L
F
.81593 .13178 m
.80648 .12232 L
.81168 .12753 L
.81941 .13526 L
.81593 .13178 L
F
.83485 .1507 m
.82713 .14298 L
.82939 .14524 L
.83485 .1507 L
.83485 .1507 L
F
.82713 .14298 m
.81941 .13526 L
.82393 .13978 L
.82939 .14524 L
.82713 .14298 L
F
.81941 .13526 m
.81168 .12753 L
.81847 .13432 L
.82393 .13978 L
.81941 .13526 L
F
.83485 .1507 m
.82939 .14524 L
.83203 .14788 L
.83485 .1507 L
.83485 .1507 L
F
.82939 .14524 m
.82393 .13978 L
.8292 .14505 L
.83203 .14788 L
.82939 .14524 L
F
.82393 .13978 m
.81847 .13432 L
.82637 .14222 L
.8292 .14505 L
.82393 .13978 L
F
.83485 .1507 m
.83203 .14788 L
.83485 .1507 L
.83485 .1507 L
.83485 .1507 L
F
.83203 .14788 m
.8292 .14505 L
.83485 .1507 L
.83485 .1507 L
.83203 .14788 L
F
.8292 .14505 m
.82637 .14222 L
.83485 .1507 L
.83485 .1507 L
.8292 .14505 L
F
.83485 .1507 m
.83485 .1507 L
.83768 .15353 L
.83485 .1507 L
.83485 .1507 L
F
.83485 .1507 m
.83485 .1507 L
.84051 .15636 L
.83768 .15353 L
.83485 .1507 L
F
.83485 .1507 m
.83485 .1507 L
.84333 .15918 L
.84051 .15636 L
.83485 .1507 L
F
.83485 .1507 m
.83768 .15353 L
.84031 .15616 L
.83485 .1507 L
.83485 .1507 L
F
.83768 .15353 m
.84051 .15636 L
.84578 .16162 L
.84031 .15616 L
.83768 .15353 L
F
.84051 .15636 m
.84333 .15918 L
.85124 .16709 L
.84578 .16162 L
.84051 .15636 L
F
.83485 .1507 m
.84031 .15616 L
.84258 .15843 L
.83485 .1507 L
.83485 .1507 L
F
.84031 .15616 m
.84578 .16162 L
.8503 .16615 L
.84258 .15843 L
.84031 .15616 L
F
.84578 .16162 m
.85124 .16709 L
.85802 .17387 L
.8503 .16615 L
.84578 .16162 L
F
.83485 .1507 m
.84258 .15843 L
.84431 .16016 L
.83485 .1507 L
.83485 .1507 L
F
.84258 .15843 m
.8503 .16615 L
.85377 .16962 L
.84431 .16016 L
.84258 .15843 L
F
.8503 .16615 m
.85802 .17387 L
.86323 .17908 L
.85377 .16962 L
.8503 .16615 L
F
.83485 .1507 m
.84431 .16016 L
.8454 .16125 L
.83485 .1507 L
.83485 .1507 L
F
.84431 .16016 m
.85377 .16962 L
.85595 .1718 L
.8454 .16125 L
.84431 .16016 L
F
.85377 .16962 m
.86323 .17908 L
.8665 .18235 L
.85595 .1718 L
.85377 .16962 L
F
.83485 .1507 m
.8454 .16125 L
.84578 .16162 L
.83485 .1507 L
.83485 .1507 L
F
.8454 .16125 m
.85595 .1718 L
.8567 .17255 L
.84578 .16162 L
.8454 .16125 L
F
.85595 .1718 m
.8665 .18235 L
.86762 .18347 L
.8567 .17255 L
.85595 .1718 L
F
0 g
.86762 .18347 m
.8665 .18235 L
.86323 .17908 L
.85802 .17387 L
.85124 .16709 L
.84333 .15918 L
.83485 .1507 L
.82637 .14222 L
.81847 .13432 L
.81168 .12753 L
.80648 .12232 L
.8032 .11905 L
.80209 .11793 L
.8032 .11905 L
.80648 .12232 L
.81168 .12753 L
.81847 .13432 L
.82637 .14222 L
.83485 .1507 L
.84333 .15918 L
.85124 .16709 L
.85802 .17387 L
.86323 .17908 L
.8665 .18235 L
.86762 .18347 L
s
.9507 .3824 m
.91209 .3824 L
.87347 .3824 L
.83485 .3824 L
.79624 .3824 L
.75762 .3824 L
.719 .3824 L
.719 .3824 L
.75762 .3824 L
.79624 .3824 L
.83485 .3824 L
.87347 .3824 L
.91209 .3824 L
.9507 .3824 L
.9507 .3824 L
s
.83485 .3824 m
.83485 .3824 L
.83485 .3824 L
.83485 .3824 L
.83485 .3824 L
.83485 .3824 L
.83485 .3824 L
.83485 .3824 L
.83485 .3824 L
.83485 .3824 L
.83485 .3824 L
.83485 .3824 L
.83485 .3824 L
.83485 .3824 L
.83485 .3824 L
s
.719 .3824 m
.72295 .3824 L
.73452 .3824 L
.75293 .3824 L
.77693 .3824 L
.80487 .3824 L
.83485 .3824 L
.86484 .3824 L
.89278 .3824 L
.91677 .3824 L
.93518 .3824 L
.94676 .3824 L
.9507 .3824 L
.94676 .3824 L
.93518 .3824 L
.91677 .3824 L
.89278 .3824 L
.86484 .3824 L
.83485 .3824 L
.80487 .3824 L
.77693 .3824 L
.75293 .3824 L
.73452 .3824 L
.72295 .3824 L
.719 .3824 L
s
0 0 0 r
gsave
.27877 .00936 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78406 .09991 -67.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
71.875 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .3824 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
1 Mabswid
.0239 .22021 m
.03785 .22028 L
.05181 .22035 L
.06577 .22042 L
.07972 .22049 L
.09368 .22056 L
.10763 .22063 L
.12159 .2207 L
.13554 .22077 L
.1495 .22084 L
.16346 .22091 L
.17741 .22098 L
.19137 .22105 L
.20532 .22112 L
.21928 .22119 L
.23324 .22126 L
.24719 .22133 L
.26278 .2215 L
.27668 .22011 L
.29057 .21873 L
.30526 .21716 L
.31907 .21506 L
.33289 .21295 L
.3467 .21085 L
.36051 .20875 L
.37433 .20664 L
.38814 .20454 L
.40196 .20244 L
.41577 .20033 L
.42958 .19823 L
.4434 .19612 L
.45721 .19402 L
.47102 .19192 L
.48484 .18981 L
.49865 .18771 L
.51247 .18561 L
.52628 .1835 L
.54009 .1814 L
.55391 .1793 L
.56772 .17719 L
.58154 .17509 L
.59535 .17299 L
.60916 .17088 L
.62298 .16878 L
.63679 .16668 L
.65061 .16457 L
.66442 .16247 L
.67823 .16037 L
.69205 .15826 L
.70586 .15616 L
Mistroke
.71968 .15406 L
.73349 .15195 L
.7473 .14985 L
.76112 .14775 L
.77504 .14665 L
.78899 .14593 L
.80294 .14521 L
.8169 .14449 L
.82138 .14604 L
.81928 .15985 L
.81717 .17367 L
.81507 .18748 L
.81296 .20129 L
.81086 .21511 L
.80876 .22892 L
.80665 .24274 L
.80455 .25655 L
.80245 .27036 L
.80034 .28418 L
.79824 .29799 L
.79614 .31181 L
.79403 .32562 L
.79193 .33943 L
.78983 .35325 L
.78772 .36706 L
.78562 .38088 L
Mfstroke
.0239 .17387 m
.03785 .1738 L
.05181 .17373 L
.06577 .17366 L
.07972 .17359 L
.09368 .17352 L
.10763 .17345 L
.12159 .17338 L
.13554 .17331 L
.1495 .17324 L
.16346 .17317 L
.17741 .1731 L
.19137 .17303 L
.20532 .17297 L
.21928 .1729 L
.23324 .17283 L
.24719 .17276 L
.25951 .17245 L
.27346 .17197 L
.28742 .1715 L
.30058 .17114 L
.31453 .17042 L
.32849 .1697 L
.34244 .16898 L
.3564 .16826 L
.37035 .16754 L
.38431 .16682 L
.39826 .1661 L
.41221 .16538 L
.42617 .16466 L
.44012 .16394 L
.45408 .16322 L
.46803 .1625 L
.48199 .16178 L
.49594 .16106 L
.5099 .16034 L
.52385 .15962 L
.53781 .1589 L
.55176 .15818 L
.56572 .15746 L
.57967 .15674 L
.59363 .15602 L
.60758 .1553 L
.62153 .15458 L
.63549 .15386 L
.64944 .15314 L
.6634 .15242 L
.67735 .1517 L
.69131 .15098 L
.70526 .15026 L
Mistroke
.71922 .14953 L
.73317 .14881 L
.74713 .14809 L
.76108 .14737 L
.77493 .14564 L
.78875 .14354 L
.80256 .14143 L
.81637 .13933 L
.82792 .1467 L
.8272 .16066 L
.82648 .17461 L
.82576 .18857 L
.82504 .20252 L
.82432 .21648 L
.8236 .23043 L
.82288 .24439 L
.82216 .25834 L
.82144 .27229 L
.82072 .28625 L
.82 .3002 L
.81928 .31416 L
.81856 .32811 L
.81784 .34207 L
.81712 .35602 L
.8164 .36998 L
.81568 .38393 L
Mfstroke
.0239 .19704 m
.03785 .19704 L
.05181 .19704 L
.06577 .19704 L
.07972 .19704 L
.09368 .19704 L
.10763 .19704 L
.12159 .19704 L
.13554 .19704 L
.1495 .19704 L
.16346 .19704 L
.17741 .19704 L
.19137 .19704 L
.20532 .19704 L
.21928 .19704 L
.23324 .19704 L
.24719 .19704 L
.26115 .19697 L
.27507 .19604 L
.289 .19511 L
.30292 .19415 L
.3168 .19274 L
.33069 .19133 L
.34457 .18991 L
.35845 .1885 L
.37234 .18709 L
.38622 .18568 L
.40011 .18427 L
.41399 .18286 L
.42788 .18144 L
.44176 .18003 L
.45564 .17862 L
.46953 .17721 L
.48341 .1758 L
.4973 .17438 L
.51118 .17297 L
.52507 .17156 L
.53895 .17015 L
.55283 .16874 L
.56672 .16733 L
.5806 .16591 L
.59449 .1645 L
.60837 .16309 L
.62226 .16168 L
.63614 .16027 L
.65003 .15885 L
.66391 .15744 L
.67779 .15603 L
.69168 .15462 L
.70556 .15321 L
Mistroke
.71945 .1518 L
.73333 .15038 L
.74722 .14897 L
.7611 .14756 L
.77498 .14615 L
.78887 .14474 L
.80275 .14332 L
.81664 .14191 L
.82465 .14637 L
.82324 .16025 L
.82183 .17414 L
.82042 .18802 L
.819 .20191 L
.81759 .21579 L
.81618 .22968 L
.81477 .24356 L
.81336 .25744 L
.81194 .27133 L
.81053 .28521 L
.80912 .2991 L
.80771 .31298 L
.8063 .32687 L
.80489 .34075 L
.80347 .35463 L
.80206 .36852 L
.80065 .3824 L
Mfstroke
.0239 .19704 m
.03785 .19704 L
.05181 .19704 L
.06577 .19704 L
.07972 .19704 L
.09368 .19704 L
.10763 .19704 L
.12159 .19704 L
.13554 .19704 L
.1495 .19704 L
.16346 .19704 L
.17741 .19704 L
.19137 .19704 L
.20532 .19704 L
.21928 .19704 L
.23324 .19704 L
.24719 .19704 L
.26115 .19697 L
.27507 .19604 L
.289 .19511 L
.30292 .19415 L
.3168 .19274 L
.33069 .19133 L
.34457 .18991 L
.35845 .1885 L
.37234 .18709 L
.38622 .18568 L
.40011 .18427 L
.41399 .18286 L
.42788 .18144 L
.44176 .18003 L
.45564 .17862 L
.46953 .17721 L
.48341 .1758 L
.4973 .17438 L
.51118 .17297 L
.52507 .17156 L
.53895 .17015 L
.55283 .16874 L
.56672 .16733 L
.5806 .16591 L
.59449 .1645 L
.60837 .16309 L
.62226 .16168 L
.63614 .16027 L
.65003 .15885 L
.66391 .15744 L
.67779 .15603 L
.69168 .15462 L
.70556 .15321 L
Mistroke
.71945 .1518 L
.73333 .15038 L
.74722 .14897 L
.7611 .14756 L
.77498 .14615 L
.78887 .14474 L
.80275 .14332 L
.81664 .14191 L
.82465 .14637 L
.82324 .16025 L
.82183 .17414 L
.82042 .18802 L
.819 .20191 L
.81759 .21579 L
.81618 .22968 L
.81477 .24356 L
.81336 .25744 L
.81194 .27133 L
.81053 .28521 L
.80912 .2991 L
.80771 .31298 L
.8063 .32687 L
.80489 .34075 L
.80347 .35463 L
.80206 .36852 L
.80065 .3824 L
Mfstroke
0 0 0 r
.0239 .19704 m
.2601 .19704 L
s
% Start of user PostScript
0 10. 50.9716 10. MAarrowhead1
% End of user PostScript
.2601 .19704 m
.30194 .19425 L
s
% Start of user PostScript
50.9716 10. 60. 9.3974 MAarrowhead1
% End of user PostScript
.30194 .19425 m
.82519 .14104 L
s
% Start of user PostScript
60. 9.3974 172.915 -2.0845 MAarrowhead1
% End of user PostScript
.82519 .14104 m
.80065 .3824 L
s
% Start of user PostScript
172.915 -2.0845 167.619 50. MAarrowhead1
% End of user PostScript
.80065 .3824 m
.80065 .3824 L
s
% Start of user PostScript
167.619 50. MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .17619 m
.02382 .17758 L
.02383 .17897 L
.02384 .18036 L
.02385 .18175 L
.02386 .18314 L
.02387 .18453 L
.02387 .18592 L
.02388 .18731 L
.02388 .1887 L
.02389 .19009 L
.02389 .19148 L
.02389 .19287 L
.0239 .19426 L
.0239 .19565 L
.0239 .19704 L
.0239 .19843 L
.0239 .19982 L
.02389 .20121 L
.02389 .2026 L
.02389 .20399 L
.02388 .20538 L
.02388 .20677 L
.02387 .20816 L
.02387 .20955 L
.02386 .21094 L
.02385 .21233 L
.02384 .21372 L
.02383 .21512 L
.02382 .21651 L
.02381 .2179 L
s
.04474 .17609 m
.04475 .17749 L
.04477 .17889 L
.04477 .18028 L
.04478 .18168 L
.04479 .18308 L
.0448 .18447 L
.04481 .18587 L
.04481 .18727 L
.04482 .18866 L
.04482 .19006 L
.04483 .19146 L
.04483 .19285 L
.04483 .19425 L
.04483 .19565 L
.04483 .19704 L
.04483 .19844 L
.04483 .19984 L
.04483 .20123 L
.04483 .20263 L
.04482 .20402 L
.04482 .20542 L
.04481 .20682 L
.04481 .20821 L
.0448 .20961 L
.04479 .21101 L
.04478 .2124 L
.04477 .2138 L
.04477 .2152 L
.04475 .21659 L
.04474 .21799 L
s
.06568 .176 m
.06569 .1774 L
.0657 .17881 L
.06571 .18021 L
.06572 .18161 L
.06573 .18301 L
.06573 .18442 L
.06574 .18582 L
.06575 .18722 L
.06575 .18863 L
.06576 .19003 L
.06576 .19143 L
.06576 .19283 L
.06576 .19424 L
.06577 .19564 L
.06577 .19704 L
.06577 .19845 L
.06576 .19985 L
.06576 .20125 L
.06576 .20265 L
.06576 .20406 L
.06575 .20546 L
.06575 .20686 L
.06574 .20826 L
.06573 .20967 L
.06573 .21107 L
.06572 .21247 L
.06571 .21388 L
.0657 .21528 L
.06569 .21668 L
.06568 .21808 L
s
.08661 .17591 m
.08662 .17732 L
.08663 .17872 L
.08664 .18013 L
.08665 .18154 L
.08666 .18295 L
.08667 .18436 L
.08667 .18577 L
.08668 .18718 L
.08668 .18859 L
.08669 .19 L
.08669 .19141 L
.0867 .19282 L
.0867 .19422 L
.0867 .19563 L
.0867 .19704 L
.0867 .19845 L
.0867 .19986 L
.0867 .20127 L
.08669 .20268 L
.08669 .20409 L
.08668 .2055 L
.08668 .20691 L
.08667 .20831 L
.08667 .20972 L
.08666 .21113 L
.08665 .21254 L
.08664 .21395 L
.08663 .21536 L
.08662 .21677 L
.08661 .21818 L
s
.10754 .17581 m
.10755 .17723 L
.10757 .17864 L
.10758 .18006 L
.10758 .18147 L
.10759 .18289 L
.1076 .1843 L
.10761 .18572 L
.10761 .18714 L
.10762 .18855 L
.10762 .18997 L
.10763 .19138 L
.10763 .1928 L
.10763 .19421 L
.10763 .19563 L
.10763 .19704 L
.10763 .19846 L
.10763 .19987 L
.10763 .20129 L
.10763 .2027 L
.10762 .20412 L
.10762 .20553 L
.10761 .20695 L
.10761 .20836 L
.1076 .20978 L
.10759 .2112 L
.10758 .21261 L
.10758 .21403 L
.10757 .21544 L
.10755 .21686 L
.10754 .21827 L
s
.12848 .17572 m
.12849 .17714 L
.1285 .17856 L
.12851 .17998 L
.12852 .1814 L
.12853 .18283 L
.12853 .18425 L
.12854 .18567 L
.12855 .18709 L
.12855 .18851 L
.12856 .18993 L
.12856 .19136 L
.12856 .19278 L
.12857 .1942 L
.12857 .19562 L
.12857 .19704 L
.12857 .19846 L
.12857 .19989 L
.12856 .20131 L
.12856 .20273 L
.12856 .20415 L
.12855 .20557 L
.12855 .20699 L
.12854 .20842 L
.12853 .20984 L
.12853 .21126 L
.12852 .21268 L
.12851 .2141 L
.1285 .21552 L
.12849 .21694 L
.12848 .21837 L
s
.14941 .17562 m
.14942 .17705 L
.14943 .17848 L
.14944 .17991 L
.14945 .18134 L
.14946 .18276 L
.14947 .18419 L
.14948 .18562 L
.14948 .18705 L
.14949 .18847 L
.14949 .1899 L
.14949 .19133 L
.1495 .19276 L
.1495 .19419 L
.1495 .19561 L
.1495 .19704 L
.1495 .19847 L
.1495 .1999 L
.1495 .20133 L
.14949 .20275 L
.14949 .20418 L
.14949 .20561 L
.14948 .20704 L
.14948 .20847 L
.14947 .20989 L
.14946 .21132 L
.14945 .21275 L
.14944 .21418 L
.14943 .2156 L
.14942 .21703 L
.14941 .21846 L
s
.17034 .17553 m
.17036 .17696 L
.17037 .1784 L
.17038 .17983 L
.17039 .18127 L
.17039 .1827 L
.1704 .18413 L
.17041 .18557 L
.17041 .187 L
.17042 .18844 L
.17042 .18987 L
.17043 .19131 L
.17043 .19274 L
.17043 .19417 L
.17043 .19561 L
.17043 .19704 L
.17043 .19848 L
.17043 .19991 L
.17043 .20134 L
.17043 .20278 L
.17042 .20421 L
.17042 .20565 L
.17041 .20708 L
.17041 .20852 L
.1704 .20995 L
.17039 .21138 L
.17039 .21282 L
.17038 .21425 L
.17037 .21569 L
.17036 .21712 L
.17034 .21855 L
s
.19128 .17544 m
.19129 .17688 L
.1913 .17832 L
.19131 .17976 L
.19132 .1812 L
.19133 .18264 L
.19134 .18408 L
.19134 .18552 L
.19135 .18696 L
.19135 .1884 L
.19136 .18984 L
.19136 .19128 L
.19136 .19272 L
.19137 .19416 L
.19137 .1956 L
.19137 .19704 L
.19137 .19848 L
.19137 .19992 L
.19136 .20136 L
.19136 .2028 L
.19136 .20424 L
.19135 .20569 L
.19135 .20713 L
.19134 .20857 L
.19134 .21001 L
.19133 .21145 L
.19132 .21289 L
.19131 .21433 L
.1913 .21577 L
.19129 .21721 L
.19128 .21865 L
s
.21221 .17534 m
.21222 .17679 L
.21223 .17823 L
.21224 .17968 L
.21225 .18113 L
.21226 .18258 L
.21227 .18402 L
.21228 .18547 L
.21228 .18692 L
.21229 .18836 L
.21229 .18981 L
.2123 .19126 L
.2123 .1927 L
.2123 .19415 L
.2123 .1956 L
.2123 .19704 L
.2123 .19849 L
.2123 .19994 L
.2123 .20138 L
.2123 .20283 L
.21229 .20428 L
.21229 .20572 L
.21228 .20717 L
.21228 .20862 L
.21227 .21006 L
.21226 .21151 L
.21225 .21296 L
.21224 .2144 L
.21223 .21585 L
.21222 .2173 L
.21221 .21874 L
s
.23314 .17525 m
.23316 .1767 L
.23317 .17815 L
.23318 .17961 L
.23319 .18106 L
.2332 .18251 L
.2332 .18397 L
.23321 .18542 L
.23322 .18687 L
.23322 .18832 L
.23323 .18978 L
.23323 .19123 L
.23323 .19268 L
.23323 .19414 L
.23324 .19559 L
.23324 .19704 L
.23324 .1985 L
.23323 .19995 L
.23323 .2014 L
.23323 .20285 L
.23323 .20431 L
.23322 .20576 L
.23322 .20721 L
.23321 .20867 L
.2332 .21012 L
.2332 .21157 L
.23319 .21303 L
.23318 .21448 L
.23317 .21593 L
.23316 .21738 L
.23314 .21884 L
s
.25408 .17515 m
.25409 .17661 L
.2541 .17807 L
.25411 .17953 L
.25412 .18099 L
.25413 .18245 L
.25414 .18391 L
.25414 .18537 L
.25415 .18683 L
.25416 .18829 L
.25416 .18975 L
.25416 .19121 L
.25417 .19266 L
.25417 .19412 L
.25417 .19558 L
.25417 .19704 L
.25417 .1985 L
.25417 .19996 L
.25417 .20142 L
.25416 .20288 L
.25416 .20434 L
.25416 .2058 L
.25415 .20726 L
.25414 .20872 L
.25414 .21018 L
.25413 .21164 L
.25412 .21309 L
.25411 .21455 L
.2541 .21601 L
.25409 .21747 L
.25408 .21893 L
s
.27402 .17435 m
.27406 .1758 L
.27411 .17725 L
.27417 .1787 L
.27422 .18014 L
.27428 .18159 L
.27434 .18304 L
.27441 .18448 L
.27448 .18593 L
.27456 .18737 L
.27463 .18882 L
.27471 .19026 L
.2748 .19171 L
.27488 .19315 L
.27498 .1946 L
.27507 .19604 L
.27517 .19749 L
.27527 .19893 L
.27538 .20037 L
.27548 .20182 L
.2756 .20326 L
.27571 .2047 L
.27583 .20615 L
.27595 .20759 L
.27608 .20903 L
.27621 .21047 L
.27634 .21192 L
.27648 .21336 L
.27662 .2148 L
.27676 .21624 L
.27691 .21768 L
s
.29494 .17357 m
.29498 .17498 L
.29503 .17639 L
.29508 .17779 L
.29513 .1792 L
.29519 .1806 L
.29525 .18201 L
.29532 .18342 L
.29539 .18482 L
.29546 .18623 L
.29553 .18763 L
.29561 .18903 L
.29569 .19044 L
.29578 .19184 L
.29587 .19325 L
.29596 .19465 L
.29605 .19605 L
.29615 .19746 L
.29625 .19886 L
.29636 .20026 L
.29647 .20166 L
.29658 .20306 L
.2967 .20447 L
.29682 .20587 L
.29694 .20727 L
.29706 .20867 L
.29719 .21007 L
.29733 .21147 L
.29746 .21287 L
.2976 .21427 L
.29775 .21567 L
s
.31561 .17257 m
.31563 .17392 L
.31567 .17527 L
.31571 .17662 L
.31576 .17796 L
.31582 .17931 L
.31588 .18066 L
.31595 .182 L
.31603 .18335 L
.31612 .18469 L
.31622 .18603 L
.31632 .18738 L
.31643 .18872 L
.31654 .19006 L
.31667 .1914 L
.3168 .19274 L
.31694 .19408 L
.31709 .19542 L
.31724 .19675 L
.31741 .19809 L
.31758 .19942 L
.31775 .20076 L
.31794 .20209 L
.31813 .20343 L
.31833 .20476 L
.31854 .20609 L
.31875 .20742 L
.31898 .20875 L
.31921 .21008 L
.31945 .21141 L
.31969 .21274 L
s
.33649 .17139 m
.33651 .17267 L
.33655 .17396 L
.33659 .17525 L
.33663 .17653 L
.33669 .17782 L
.33675 .1791 L
.33682 .18038 L
.3369 .18167 L
.33698 .18295 L
.33707 .18423 L
.33717 .18551 L
.33727 .18679 L
.33738 .18807 L
.3375 .18934 L
.33763 .19062 L
.33776 .1919 L
.3379 .19317 L
.33805 .19445 L
.3382 .19572 L
.33837 .197 L
.33854 .19827 L
.33871 .19954 L
.3389 .20081 L
.33909 .20208 L
.33929 .20335 L
.33949 .20462 L
.3397 .20589 L
.33992 .20716 L
.34015 .20842 L
.34038 .20969 L
s
.35737 .17021 m
.35739 .17143 L
.35743 .17266 L
.35746 .17388 L
.35751 .1751 L
.35756 .17632 L
.35762 .17754 L
.35769 .17876 L
.35776 .17998 L
.35784 .1812 L
.35792 .18242 L
.35802 .18364 L
.35811 .18486 L
.35822 .18607 L
.35833 .18729 L
.35845 .1885 L
.35858 .18972 L
.35872 .19093 L
.35886 .19214 L
.359 .19336 L
.35916 .19457 L
.35932 .19578 L
.35949 .19699 L
.35966 .1982 L
.35984 .19941 L
.36003 .20061 L
.36023 .20182 L
.36043 .20303 L
.36064 .20423 L
.36085 .20544 L
.36107 .20664 L
s
.37825 .16903 m
.37828 .17019 L
.3783 .17135 L
.37834 .17251 L
.37838 .17367 L
.37843 .17483 L
.37849 .17599 L
.37855 .17715 L
.37862 .1783 L
.37869 .17946 L
.37878 .18062 L
.37886 .18177 L
.37896 .18293 L
.37906 .18408 L
.37917 .18523 L
.37928 .18639 L
.3794 .18754 L
.37953 .18869 L
.37966 .18984 L
.3798 .19099 L
.37995 .19214 L
.3801 .19329 L
.38026 .19444 L
.38043 .19558 L
.3806 .19673 L
.38078 .19788 L
.38096 .19902 L
.38115 .20017 L
.38135 .20131 L
.38156 .20245 L
.38177 .2036 L
s
.39913 .16785 m
.39916 .16895 L
.39918 .17004 L
.39922 .17114 L
.39926 .17224 L
.39931 .17334 L
.39936 .17443 L
.39942 .17553 L
.39948 .17662 L
.39955 .17772 L
.39963 .17881 L
.39971 .1799 L
.3998 .18099 L
.3999 .18209 L
.4 .18318 L
.40011 .18427 L
.40022 .18536 L
.40034 .18645 L
.40047 .18753 L
.4006 .18862 L
.40074 .18971 L
.40088 .1908 L
.40103 .19188 L
.40119 .19297 L
.40135 .19405 L
.40152 .19514 L
.4017 .19622 L
.40188 .1973 L
.40207 .19839 L
.40226 .19947 L
.40246 .20055 L
s
.42002 .16667 m
.42004 .1677 L
.42006 .16874 L
.4201 .16977 L
.42013 .17081 L
.42018 .17184 L
.42023 .17288 L
.42028 .17391 L
.42034 .17494 L
.42041 .17597 L
.42048 .177 L
.42056 .17803 L
.42065 .17906 L
.42074 .18009 L
.42083 .18112 L
.42093 .18215 L
.42104 .18318 L
.42115 .1842 L
.42127 .18523 L
.4214 .18626 L
.42153 .18728 L
.42167 .18831 L
.42181 .18933 L
.42195 .19035 L
.42211 .19138 L
.42227 .1924 L
.42243 .19342 L
.4226 .19444 L
.42278 .19546 L
.42296 .19648 L
.42315 .1975 L
s
.4409 .16549 m
.44092 .16646 L
.44094 .16743 L
.44097 .16841 L
.44101 .16938 L
.44105 .17035 L
.4411 .17132 L
.44115 .17229 L
.44121 .17326 L
.44127 .17423 L
.44134 .1752 L
.44141 .17617 L
.44149 .17713 L
.44158 .1781 L
.44167 .17907 L
.44176 .18003 L
.44186 .181 L
.44197 .18196 L
.44208 .18293 L
.4422 .18389 L
.44232 .18485 L
.44245 .18582 L
.44258 .18678 L
.44272 .18774 L
.44286 .1887 L
.44301 .18966 L
.44317 .19062 L
.44333 .19158 L
.4435 .19254 L
.44367 .1935 L
.44384 .19445 L
s
.46178 .16431 m
.4618 .16522 L
.46182 .16613 L
.46185 .16704 L
.46188 .16795 L
.46192 .16886 L
.46197 .16976 L
.46201 .17067 L
.46207 .17158 L
.46213 .17249 L
.46219 .17339 L
.46226 .1743 L
.46233 .1752 L
.46241 .17611 L
.4625 .17701 L
.46259 .17791 L
.46268 .17882 L
.46278 .17972 L
.46289 .18062 L
.46299 .18152 L
.46311 .18242 L
.46323 .18332 L
.46335 .18422 L
.46348 .18512 L
.46362 .18602 L
.46376 .18692 L
.4639 .18782 L
.46405 .18872 L
.46421 .18961 L
.46437 .19051 L
.46454 .19141 L
s
.48266 .16313 m
.48268 .16397 L
.4827 .16482 L
.48273 .16567 L
.48276 .16652 L
.48279 .16736 L
.48284 .16821 L
.48288 .16905 L
.48293 .1699 L
.48299 .17074 L
.48304 .17159 L
.48311 .17243 L
.48318 .17327 L
.48325 .17411 L
.48333 .17496 L
.48341 .1758 L
.4835 .17664 L
.48359 .17748 L
.48369 .17832 L
.48379 .17916 L
.4839 .18 L
.48401 .18083 L
.48413 .18167 L
.48425 .18251 L
.48437 .18335 L
.4845 .18418 L
.48464 .18502 L
.48478 .18585 L
.48492 .18669 L
.48507 .18752 L
.48523 .18836 L
s
.50354 .16195 m
.50356 .16273 L
.50358 .16352 L
.5036 .1643 L
.50363 .16508 L
.50367 .16587 L
.5037 .16665 L
.50375 .16743 L
.50379 .16822 L
.50384 .169 L
.5039 .16978 L
.50396 .17056 L
.50402 .17134 L
.50409 .17212 L
.50416 .1729 L
.50424 .17368 L
.50432 .17446 L
.50441 .17524 L
.5045 .17601 L
.50459 .17679 L
.50469 .17757 L
.50479 .17834 L
.5049 .17912 L
.50501 .1799 L
.50513 .18067 L
.50525 .18144 L
.50538 .18222 L
.50551 .18299 L
.50564 .18377 L
.50578 .18454 L
.50592 .18531 L
s
.52443 .16077 m
.52444 .16149 L
.52446 .16221 L
.52448 .16293 L
.52451 .16365 L
.52454 .16437 L
.52457 .1651 L
.52461 .16582 L
.52465 .16653 L
.5247 .16725 L
.52475 .16797 L
.52481 .16869 L
.52487 .16941 L
.52493 .17013 L
.525 .17084 L
.52507 .17156 L
.52514 .17228 L
.52522 .17299 L
.5253 .17371 L
.52539 .17442 L
.52548 .17514 L
.52558 .17585 L
.52567 .17657 L
.52578 .17728 L
.52589 .17799 L
.526 .17871 L
.52611 .17942 L
.52623 .18013 L
.52635 .18084 L
.52648 .18155 L
.52661 .18226 L
s
.54531 .15959 m
.54532 .16025 L
.54534 .16091 L
.54536 .16156 L
.54538 .16222 L
.54541 .16288 L
.54544 .16354 L
.54548 .1642 L
.54552 .16485 L
.54556 .16551 L
.54561 .16617 L
.54566 .16682 L
.54571 .16748 L
.54577 .16813 L
.54583 .16879 L
.54589 .16944 L
.54596 .1701 L
.54603 .17075 L
.54611 .1714 L
.54619 .17206 L
.54627 .17271 L
.54636 .17336 L
.54645 .17401 L
.54654 .17467 L
.54664 .17532 L
.54674 .17597 L
.54685 .17662 L
.54696 .17727 L
.54707 .17792 L
.54718 .17857 L
.5473 .17922 L
s
.56619 .15841 m
.5662 .159 L
.56622 .1596 L
.56624 .1602 L
.56626 .16079 L
.56628 .16139 L
.56631 .16198 L
.56634 .16258 L
.56638 .16317 L
.56642 .16377 L
.56646 .16436 L
.56651 .16495 L
.56655 .16555 L
.56661 .16614 L
.56666 .16673 L
.56672 .16733 L
.56678 .16792 L
.56685 .16851 L
.56691 .1691 L
.56699 .16969 L
.56706 .17028 L
.56714 .17087 L
.56722 .17146 L
.56731 .17205 L
.5674 .17264 L
.56749 .17323 L
.56758 .17382 L
.56768 .17441 L
.56778 .17499 L
.56789 .17558 L
.568 .17617 L
s
.58707 .15723 m
.58708 .15776 L
.5871 .15829 L
.58711 .15883 L
.58713 .15936 L
.58716 .15989 L
.58718 .16043 L
.58721 .16096 L
.58724 .16149 L
.58728 .16202 L
.58731 .16255 L
.58735 .16309 L
.5874 .16362 L
.58744 .16415 L
.58749 .16468 L
.58755 .16521 L
.5876 .16574 L
.58766 .16627 L
.58772 .1668 L
.58778 .16732 L
.58785 .16785 L
.58792 .16838 L
.588 .16891 L
.58807 .16944 L
.58815 .16996 L
.58823 .17049 L
.58832 .17102 L
.58841 .17154 L
.5885 .17207 L
.58859 .1726 L
.58869 .17312 L
s
.60795 .15605 m
.60796 .15652 L
.60798 .15699 L
.60799 .15746 L
.60801 .15793 L
.60803 .1584 L
.60805 .15887 L
.60808 .15934 L
.6081 .15981 L
.60813 .16028 L
.60817 .16075 L
.6082 .16122 L
.60824 .16169 L
.60828 .16215 L
.60833 .16262 L
.60837 .16309 L
.60842 .16356 L
.60847 .16402 L
.60853 .16449 L
.60858 .16496 L
.60864 .16542 L
.6087 .16589 L
.60877 .16636 L
.60884 .16682 L
.60891 .16729 L
.60898 .16775 L
.60905 .16822 L
.60913 .16868 L
.60921 .16915 L
.6093 .16961 L
.60938 .17007 L
s
.62884 .15487 m
.62884 .15527 L
.62886 .15568 L
.62887 .15609 L
.62888 .1565 L
.6289 .15691 L
.62892 .15731 L
.62894 .15772 L
.62897 .15813 L
.62899 .15854 L
.62902 .15894 L
.62905 .15935 L
.62909 .15976 L
.62912 .16016 L
.62916 .16057 L
.6292 .16097 L
.62924 .16138 L
.62929 .16178 L
.62933 .16219 L
.62938 .16259 L
.62943 .163 L
.62949 .1634 L
.62954 .1638 L
.6296 .16421 L
.62966 .16461 L
.62972 .16501 L
.62979 .16542 L
.62986 .16582 L
.62993 .16622 L
.63 .16662 L
.63007 .16703 L
s
.64972 .15369 m
.64973 .15403 L
.64973 .15438 L
.64975 .15472 L
.64976 .15507 L
.64977 .15541 L
.64979 .15576 L
.64981 .1561 L
.64983 .15645 L
.64985 .15679 L
.64987 .15714 L
.6499 .15748 L
.64993 .15782 L
.64996 .15817 L
.64999 .15851 L
.65003 .15885 L
.65006 .1592 L
.6501 .15954 L
.65014 .15988 L
.65018 .16023 L
.65022 .16057 L
.65027 .16091 L
.65032 .16125 L
.65037 .16159 L
.65042 .16193 L
.65047 .16228 L
.65053 .16262 L
.65058 .16296 L
.65064 .1633 L
.6507 .16364 L
.65077 .16398 L
s
.6706 .15251 m
.67061 .15279 L
.67061 .15307 L
.67062 .15335 L
.67063 .15364 L
.67064 .15392 L
.67066 .1542 L
.67067 .15448 L
.67069 .15477 L
.67071 .15505 L
.67073 .15533 L
.67075 .15561 L
.67077 .15589 L
.6708 .15617 L
.67082 .15646 L
.67085 .15674 L
.67088 .15702 L
.67091 .1573 L
.67094 .15758 L
.67098 .15786 L
.67101 .15814 L
.67105 .15842 L
.67109 .1587 L
.67113 .15898 L
.67117 .15926 L
.67122 .15954 L
.67126 .15982 L
.67131 .1601 L
.67136 .16037 L
.67141 .16065 L
.67146 .16093 L
s
.69148 .15133 m
.69149 .15155 L
.69149 .15177 L
.6915 .15199 L
.69151 .15221 L
.69152 .15243 L
.69153 .15265 L
.69154 .15287 L
.69155 .15309 L
.69157 .15331 L
.69158 .15352 L
.6916 .15374 L
.69162 .15396 L
.69164 .15418 L
.69166 .1544 L
.69168 .15462 L
.6917 .15484 L
.69172 .15506 L
.69175 .15527 L
.69178 .15549 L
.6918 .15571 L
.69183 .15593 L
.69186 .15615 L
.6919 .15636 L
.69193 .15658 L
.69196 .1568 L
.692 .15702 L
.69203 .15723 L
.69207 .15745 L
.69211 .15767 L
.69215 .15788 L
s
.71236 .15015 m
.71237 .1503 L
.71237 .15046 L
.71238 .15062 L
.71238 .15078 L
.71239 .15093 L
.7124 .15109 L
.71241 .15125 L
.71241 .1514 L
.71242 .15156 L
.71244 .15172 L
.71245 .15188 L
.71246 .15203 L
.71247 .15219 L
.71249 .15234 L
.7125 .1525 L
.71252 .15266 L
.71254 .15281 L
.71256 .15297 L
.71258 .15313 L
.71259 .15328 L
.71262 .15344 L
.71264 .15359 L
.71266 .15375 L
.71268 .1539 L
.71271 .15406 L
.71273 .15422 L
.71276 .15437 L
.71279 .15453 L
.71281 .15468 L
.71284 .15484 L
s
.73325 .14897 m
.73325 .14906 L
.73325 .14916 L
.73325 .14925 L
.73326 .14934 L
.73326 .14944 L
.73327 .14953 L
.73327 .14963 L
.73328 .14972 L
.73328 .14982 L
.73329 .14991 L
.7333 .15001 L
.7333 .1501 L
.73331 .1502 L
.73332 .15029 L
.73333 .15038 L
.73334 .15048 L
.73335 .15057 L
.73336 .15067 L
.73337 .15076 L
.73339 .15085 L
.7334 .15095 L
.73341 .15104 L
.73342 .15113 L
.73344 .15123 L
.73345 .15132 L
.73347 .15142 L
.73348 .15151 L
.7335 .1516 L
.73352 .1517 L
.73353 .15179 L
s
.75413 .14779 m
.75413 .14782 L
.75413 .14785 L
.75413 .14788 L
.75413 .14791 L
.75413 .14795 L
.75414 .14798 L
.75414 .14801 L
.75414 .14804 L
.75414 .14807 L
.75414 .14811 L
.75415 .14814 L
.75415 .14817 L
.75415 .1482 L
.75415 .14823 L
.75416 .14827 L
.75416 .1483 L
.75416 .14833 L
.75417 .14836 L
.75417 .14839 L
.75418 .14842 L
.75418 .14846 L
.75418 .14849 L
.75419 .14852 L
.75419 .14855 L
.7542 .14858 L
.7542 .14862 L
.75421 .14865 L
.75421 .14868 L
.75422 .14871 L
.75423 .14874 L
s
.77492 .14569 m
.77492 .14572 L
.77493 .14575 L
.77493 .14578 L
.77494 .14581 L
.77494 .14584 L
.77495 .14588 L
.77495 .14591 L
.77496 .14594 L
.77496 .14597 L
.77497 .146 L
.77497 .14603 L
.77497 .14606 L
.77498 .14609 L
.77498 .14612 L
.77498 .14615 L
.77499 .14618 L
.77499 .14621 L
.77499 .14624 L
.77499 .14627 L
.775 .1463 L
.775 .14633 L
.775 .14636 L
.775 .14639 L
.775 .14642 L
.77501 .14645 L
.77501 .14648 L
.77501 .14651 L
.77501 .14654 L
.77501 .14658 L
.77501 .14661 L
s
.79561 .14265 m
.79563 .14274 L
.79564 .14283 L
.79566 .14292 L
.79568 .14301 L
.79569 .14311 L
.7957 .1432 L
.79572 .14329 L
.79573 .14338 L
.79574 .14348 L
.79576 .14357 L
.79577 .14366 L
.79578 .14375 L
.79579 .14385 L
.7958 .14394 L
.79581 .14403 L
.79582 .14412 L
.79583 .14422 L
.79584 .14431 L
.79584 .1444 L
.79585 .14449 L
.79586 .14459 L
.79586 .14468 L
.79587 .14477 L
.79587 .14487 L
.79588 .14496 L
.79588 .14505 L
.79589 .14515 L
.79589 .14524 L
.79589 .14533 L
.79589 .14543 L
s
.8163 .1396 m
.81633 .13975 L
.81636 .13991 L
.81639 .14006 L
.81641 .14021 L
.81644 .14037 L
.81646 .14052 L
.81648 .14068 L
.81651 .14083 L
.81653 .14098 L
.81655 .14114 L
.81657 .14129 L
.81659 .14145 L
.8166 .1416 L
.81662 .14176 L
.81664 .14191 L
.81665 .14207 L
.81667 .14222 L
.81668 .14238 L
.81669 .14253 L
.8167 .14269 L
.81672 .14284 L
.81673 .143 L
.81673 .14315 L
.81674 .14331 L
.81675 .14347 L
.81676 .14362 L
.81676 .14378 L
.81677 .14393 L
.81677 .14409 L
.81677 .14425 L
s
.82722 .15351 m
.827 .1535 L
.82678 .1535 L
.82656 .15349 L
.82634 .15348 L
.82612 .15347 L
.8259 .15346 L
.82569 .15345 L
.82547 .15344 L
.82525 .15342 L
.82503 .15341 L
.82481 .15339 L
.8246 .15337 L
.82438 .15335 L
.82416 .15333 L
.82395 .15331 L
.82373 .15329 L
.82351 .15327 L
.82329 .15324 L
.82308 .15321 L
.82286 .15319 L
.82264 .15316 L
.82243 .15313 L
.82221 .1531 L
.822 .15306 L
.82178 .15303 L
.82156 .153 L
.82135 .15296 L
.82113 .15292 L
.82092 .15288 L
.8207 .15284 L
s
.82604 .17439 m
.82575 .17438 L
.82547 .17438 L
.82519 .17437 L
.82491 .17436 L
.82463 .17434 L
.82435 .17433 L
.82407 .17432 L
.82379 .1743 L
.82351 .17428 L
.82323 .17426 L
.82295 .17424 L
.82267 .17422 L
.82239 .17419 L
.82211 .17417 L
.82183 .17414 L
.82155 .17411 L
.82127 .17408 L
.82099 .17405 L
.82071 .17401 L
.82043 .17398 L
.82015 .17394 L
.81988 .1739 L
.8196 .17386 L
.81932 .17382 L
.81904 .17378 L
.81876 .17373 L
.81849 .17369 L
.81821 .17364 L
.81793 .17359 L
.81766 .17354 L
s
.82486 .19527 m
.82451 .19526 L
.82417 .19525 L
.82382 .19524 L
.82348 .19523 L
.82314 .19522 L
.82279 .1952 L
.82245 .19518 L
.82211 .19516 L
.82176 .19514 L
.82142 .19512 L
.82108 .19509 L
.82074 .19506 L
.82039 .19503 L
.82005 .195 L
.81971 .19497 L
.81937 .19493 L
.81903 .19489 L
.81869 .19485 L
.81834 .19481 L
.818 .19477 L
.81766 .19472 L
.81732 .19468 L
.81698 .19463 L
.81664 .19458 L
.8163 .19452 L
.81596 .19447 L
.81562 .19441 L
.81529 .19435 L
.81495 .19429 L
.81461 .19423 L
s
.82368 .21615 m
.82327 .21614 L
.82286 .21613 L
.82245 .21612 L
.82205 .21611 L
.82164 .21609 L
.82124 .21607 L
.82083 .21605 L
.82042 .21602 L
.82002 .216 L
.81961 .21597 L
.81921 .21594 L
.8188 .2159 L
.8184 .21587 L
.818 .21583 L
.81759 .21579 L
.81719 .21575 L
.81678 .21571 L
.81638 .21566 L
.81598 .21561 L
.81558 .21556 L
.81517 .2155 L
.81477 .21545 L
.81437 .21539 L
.81397 .21533 L
.81357 .21527 L
.81316 .2152 L
.81276 .21514 L
.81236 .21507 L
.81196 .21499 L
.81156 .21492 L
s
.8225 .23703 m
.82203 .23703 L
.82156 .23701 L
.82109 .237 L
.82062 .23698 L
.82015 .23696 L
.81968 .23694 L
.81921 .23691 L
.81874 .23689 L
.81828 .23686 L
.81781 .23682 L
.81734 .23679 L
.81687 .23675 L
.81641 .23671 L
.81594 .23666 L
.81547 .23662 L
.81501 .23657 L
.81454 .23652 L
.81408 .23646 L
.81361 .23641 L
.81315 .23635 L
.81268 .23629 L
.81222 .23622 L
.81175 .23616 L
.81129 .23609 L
.81083 .23601 L
.81036 .23594 L
.8099 .23586 L
.80944 .23578 L
.80898 .2357 L
.80851 .23561 L
s
.82132 .25792 m
.82078 .25791 L
.82025 .25789 L
.81972 .25788 L
.81919 .25786 L
.81865 .25783 L
.81812 .25781 L
.81759 .25778 L
.81706 .25775 L
.81653 .25771 L
.816 .25768 L
.81547 .25764 L
.81494 .25759 L
.81441 .25755 L
.81388 .2575 L
.81336 .25744 L
.81283 .25739 L
.8123 .25733 L
.81177 .25727 L
.81125 .25721 L
.81072 .25714 L
.81019 .25707 L
.80967 .257 L
.80914 .25692 L
.80861 .25684 L
.80809 .25676 L
.80756 .25667 L
.80704 .25659 L
.80651 .2565 L
.80599 .2564 L
.80547 .25631 L
s
.82014 .2788 m
.81954 .27879 L
.81894 .27877 L
.81835 .27875 L
.81776 .27873 L
.81716 .27871 L
.81657 .27868 L
.81597 .27865 L
.81538 .27861 L
.81479 .27857 L
.8142 .27853 L
.8136 .27848 L
.81301 .27844 L
.81242 .27838 L
.81183 .27833 L
.81124 .27827 L
.81065 .27821 L
.81006 .27814 L
.80947 .27808 L
.80888 .278 L
.80829 .27793 L
.8077 .27785 L
.80711 .27777 L
.80652 .27768 L
.80594 .2776 L
.80535 .2775 L
.80476 .27741 L
.80418 .27731 L
.80359 .27721 L
.803 .27711 L
.80242 .277 L
s
.81896 .29968 m
.8183 .29967 L
.81764 .29965 L
.81698 .29963 L
.81632 .29961 L
.81567 .29958 L
.81501 .29955 L
.81436 .29951 L
.8137 .29947 L
.81304 .29943 L
.81239 .29938 L
.81174 .29933 L
.81108 .29928 L
.81043 .29922 L
.80977 .29916 L
.80912 .2991 L
.80847 .29903 L
.80782 .29896 L
.80716 .29888 L
.80651 .2988 L
.80586 .29872 L
.80521 .29863 L
.80456 .29854 L
.80391 .29845 L
.80326 .29835 L
.80261 .29825 L
.80196 .29815 L
.80131 .29804 L
.80067 .29792 L
.80002 .29781 L
.79937 .29769 L
s
.81778 .32056 m
.81705 .32055 L
.81633 .32053 L
.81561 .32051 L
.81489 .32048 L
.81417 .32045 L
.81346 .32042 L
.81274 .32038 L
.81202 .32033 L
.8113 .32029 L
.81058 .32024 L
.80987 .32018 L
.80915 .32012 L
.80843 .32006 L
.80772 .31999 L
.807 .31992 L
.80629 .31985 L
.80557 .31977 L
.80486 .31969 L
.80415 .3196 L
.80343 .31951 L
.80272 .31942 L
.80201 .31932 L
.8013 .31921 L
.80058 .31911 L
.79987 .319 L
.79916 .31888 L
.79845 .31876 L
.79774 .31864 L
.79703 .31851 L
.79632 .31838 L
s
.8166 .34145 m
.81581 .34143 L
.81503 .34141 L
.81425 .34138 L
.81346 .34136 L
.81268 .34132 L
.8119 .34129 L
.81112 .34124 L
.81034 .3412 L
.80956 .34115 L
.80878 .34109 L
.808 .34103 L
.80722 .34097 L
.80644 .3409 L
.80566 .34083 L
.80489 .34075 L
.80411 .34067 L
.80333 .34058 L
.80256 .34049 L
.80178 .3404 L
.801 .3403 L
.80023 .3402 L
.79946 .34009 L
.79868 .33998 L
.79791 .33986 L
.79713 .33974 L
.79636 .33962 L
.79559 .33949 L
.79482 .33935 L
.79405 .33922 L
.79328 .33907 L
s
.81542 .36233 m
.81457 .36231 L
.81372 .36229 L
.81288 .36226 L
.81203 .36223 L
.81119 .36219 L
.81034 .36215 L
.8095 .36211 L
.80866 .36206 L
.80781 .362 L
.80697 .36194 L
.80613 .36188 L
.80529 .36181 L
.80445 .36174 L
.80361 .36166 L
.80277 .36158 L
.80193 .36149 L
.80109 .3614 L
.80025 .3613 L
.79941 .3612 L
.79858 .36109 L
.79774 .36098 L
.7969 .36086 L
.79607 .36074 L
.79523 .36062 L
.7944 .36049 L
.79356 .36035 L
.79273 .36021 L
.79189 .36007 L
.79106 .35992 L
.79023 .35977 L
s
0 0 0 r
.0239 .19704 m
.2601 .19704 L
s
% Start of user PostScript
0 10. 50.9716 10. MAarrowhead1
% End of user PostScript
.2601 .19704 m
.30194 .19425 L
s
% Start of user PostScript
50.9716 10. 60. 9.3974 MAarrowhead1
% End of user PostScript
.30194 .19425 m
.82519 .14104 L
s
% Start of user PostScript
60. 9.3974 172.915 -2.0845 MAarrowhead1
% End of user PostScript
.82519 .14104 m
.80065 .3824 L
s
% Start of user PostScript
172.915 -2.0845 167.619 50. MAarrowhead1
% End of user PostScript
.80065 .3824 m
.80065 .3824 L
s
% Start of user PostScript
167.619 50. MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .19704 m
.02382 .19704 L
.02383 .19704 L
.02384 .19704 L
.02385 .19704 L
.02386 .19704 L
.02387 .19704 L
.02387 .19704 L
.02388 .19704 L
.02388 .19704 L
.02389 .19704 L
.02389 .19704 L
.02389 .19704 L
.0239 .19704 L
.0239 .19704 L
.0239 .19704 L
.0239 .19704 L
.0239 .19704 L
.02389 .19704 L
.02389 .19704 L
.02389 .19704 L
.02388 .19704 L
.02388 .19704 L
.02387 .19704 L
.02387 .19704 L
.02386 .19704 L
.02385 .19704 L
.02384 .19704 L
.02383 .19704 L
.02382 .19704 L
.02381 .19704 L
s
.04474 .19704 m
.04475 .19704 L
.04477 .19704 L
.04477 .19704 L
.04478 .19704 L
.04479 .19704 L
.0448 .19704 L
.04481 .19704 L
.04481 .19704 L
.04482 .19704 L
.04482 .19704 L
.04483 .19704 L
.04483 .19704 L
.04483 .19704 L
.04483 .19704 L
.04483 .19704 L
.04483 .19704 L
.04483 .19704 L
.04483 .19704 L
.04483 .19704 L
.04482 .19704 L
.04482 .19704 L
.04481 .19704 L
.04481 .19704 L
.0448 .19704 L
.04479 .19704 L
.04478 .19704 L
.04477 .19704 L
.04477 .19704 L
.04475 .19704 L
.04474 .19704 L
s
.06568 .19704 m
.06569 .19704 L
.0657 .19704 L
.06571 .19704 L
.06572 .19704 L
.06573 .19704 L
.06573 .19704 L
.06574 .19704 L
.06575 .19704 L
.06575 .19704 L
.06576 .19704 L
.06576 .19704 L
.06576 .19704 L
.06576 .19704 L
.06577 .19704 L
.06577 .19704 L
.06577 .19704 L
.06576 .19704 L
.06576 .19704 L
.06576 .19704 L
.06576 .19704 L
.06575 .19704 L
.06575 .19704 L
.06574 .19704 L
.06573 .19704 L
.06573 .19704 L
.06572 .19704 L
.06571 .19704 L
.0657 .19704 L
.06569 .19704 L
.06568 .19704 L
s
.08661 .19704 m
.08662 .19704 L
.08663 .19704 L
.08664 .19704 L
.08665 .19704 L
.08666 .19704 L
.08667 .19704 L
.08667 .19704 L
.08668 .19704 L
.08668 .19704 L
.08669 .19704 L
.08669 .19704 L
.0867 .19704 L
.0867 .19704 L
.0867 .19704 L
.0867 .19704 L
.0867 .19704 L
.0867 .19704 L
.0867 .19704 L
.08669 .19704 L
.08669 .19704 L
.08668 .19704 L
.08668 .19704 L
.08667 .19704 L
.08667 .19704 L
.08666 .19704 L
.08665 .19704 L
.08664 .19704 L
.08663 .19704 L
.08662 .19704 L
.08661 .19704 L
s
.10754 .19704 m
.10755 .19704 L
.10757 .19704 L
.10758 .19704 L
.10758 .19704 L
.10759 .19704 L
.1076 .19704 L
.10761 .19704 L
.10761 .19704 L
.10762 .19704 L
.10762 .19704 L
.10763 .19704 L
.10763 .19704 L
.10763 .19704 L
.10763 .19704 L
.10763 .19704 L
.10763 .19704 L
.10763 .19704 L
.10763 .19704 L
.10763 .19704 L
.10762 .19704 L
.10762 .19704 L
.10761 .19704 L
.10761 .19704 L
.1076 .19704 L
.10759 .19704 L
.10758 .19704 L
.10758 .19704 L
.10757 .19704 L
.10755 .19704 L
.10754 .19704 L
s
.12848 .19704 m
.12849 .19704 L
.1285 .19704 L
.12851 .19704 L
.12852 .19704 L
.12853 .19704 L
.12853 .19704 L
.12854 .19704 L
.12855 .19704 L
.12855 .19704 L
.12856 .19704 L
.12856 .19704 L
.12856 .19704 L
.12857 .19704 L
.12857 .19704 L
.12857 .19704 L
.12857 .19704 L
.12857 .19704 L
.12856 .19704 L
.12856 .19704 L
.12856 .19704 L
.12855 .19704 L
.12855 .19704 L
.12854 .19704 L
.12853 .19704 L
.12853 .19704 L
.12852 .19704 L
.12851 .19704 L
.1285 .19704 L
.12849 .19704 L
.12848 .19704 L
s
.14941 .19704 m
.14942 .19704 L
.14943 .19704 L
.14944 .19704 L
.14945 .19704 L
.14946 .19704 L
.14947 .19704 L
.14948 .19704 L
.14948 .19704 L
.14949 .19704 L
.14949 .19704 L
.14949 .19704 L
.1495 .19704 L
.1495 .19704 L
.1495 .19704 L
.1495 .19704 L
.1495 .19704 L
.1495 .19704 L
.1495 .19704 L
.14949 .19704 L
.14949 .19704 L
.14949 .19704 L
.14948 .19704 L
.14948 .19704 L
.14947 .19704 L
.14946 .19704 L
.14945 .19704 L
.14944 .19704 L
.14943 .19704 L
.14942 .19704 L
.14941 .19704 L
s
.17034 .19704 m
.17036 .19704 L
.17037 .19704 L
.17038 .19704 L
.17039 .19704 L
.17039 .19704 L
.1704 .19704 L
.17041 .19704 L
.17041 .19704 L
.17042 .19704 L
.17042 .19704 L
.17043 .19704 L
.17043 .19704 L
.17043 .19704 L
.17043 .19704 L
.17043 .19704 L
.17043 .19704 L
.17043 .19704 L
.17043 .19704 L
.17043 .19704 L
.17042 .19704 L
.17042 .19704 L
.17041 .19704 L
.17041 .19704 L
.1704 .19704 L
.17039 .19704 L
.17039 .19704 L
.17038 .19704 L
.17037 .19704 L
.17036 .19704 L
.17034 .19704 L
s
.19128 .19704 m
.19129 .19704 L
.1913 .19704 L
.19131 .19704 L
.19132 .19704 L
.19133 .19704 L
.19134 .19704 L
.19134 .19704 L
.19135 .19704 L
.19135 .19704 L
.19136 .19704 L
.19136 .19704 L
.19136 .19704 L
.19137 .19704 L
.19137 .19704 L
.19137 .19704 L
.19137 .19704 L
.19137 .19704 L
.19136 .19704 L
.19136 .19704 L
.19136 .19704 L
.19135 .19704 L
.19135 .19704 L
.19134 .19704 L
.19134 .19704 L
.19133 .19704 L
.19132 .19704 L
.19131 .19704 L
.1913 .19704 L
.19129 .19704 L
.19128 .19704 L
s
.21221 .19704 m
.21222 .19704 L
.21223 .19704 L
.21224 .19704 L
.21225 .19704 L
.21226 .19704 L
.21227 .19704 L
.21228 .19704 L
.21228 .19704 L
.21229 .19704 L
.21229 .19704 L
.2123 .19704 L
.2123 .19704 L
.2123 .19704 L
.2123 .19704 L
.2123 .19704 L
.2123 .19704 L
.2123 .19704 L
.2123 .19704 L
.2123 .19704 L
.21229 .19704 L
.21229 .19704 L
.21228 .19704 L
.21228 .19704 L
.21227 .19704 L
.21226 .19704 L
.21225 .19704 L
.21224 .19704 L
.21223 .19704 L
.21222 .19704 L
.21221 .19704 L
s
.23314 .19704 m
.23316 .19704 L
.23317 .19704 L
.23318 .19704 L
.23319 .19704 L
.2332 .19704 L
.2332 .19704 L
.23321 .19704 L
.23322 .19704 L
.23322 .19704 L
.23323 .19704 L
.23323 .19704 L
.23323 .19704 L
.23323 .19704 L
.23324 .19704 L
.23324 .19704 L
.23324 .19704 L
.23323 .19704 L
.23323 .19704 L
.23323 .19704 L
.23323 .19704 L
.23322 .19704 L
.23322 .19704 L
.23321 .19704 L
.2332 .19704 L
.2332 .19704 L
.23319 .19704 L
.23318 .19704 L
.23317 .19704 L
.23316 .19704 L
.23314 .19704 L
s
.25408 .19704 m
.25409 .19704 L
.2541 .19704 L
.25411 .19704 L
.25412 .19704 L
.25413 .19704 L
.25414 .19704 L
.25414 .19704 L
.25415 .19704 L
.25416 .19704 L
.25416 .19704 L
.25416 .19704 L
.25417 .19704 L
.25417 .19704 L
.25417 .19704 L
.25417 .19704 L
.25417 .19704 L
.25417 .19704 L
.25417 .19704 L
.25416 .19704 L
.25416 .19704 L
.25416 .19704 L
.25415 .19704 L
.25414 .19704 L
.25414 .19704 L
.25413 .19704 L
.25412 .19704 L
.25411 .19704 L
.2541 .19704 L
.25409 .19704 L
.25408 .19704 L
s
.27545 .19602 m
.2754 .19602 L
.27535 .19602 L
.27531 .19603 L
.27527 .19603 L
.27524 .19603 L
.27521 .19603 L
.27518 .19604 L
.27515 .19604 L
.27513 .19604 L
.27511 .19604 L
.2751 .19604 L
.27509 .19604 L
.27508 .19604 L
.27507 .19604 L
.27507 .19604 L
.27507 .19604 L
.27508 .19604 L
.27509 .19604 L
.2751 .19604 L
.27511 .19604 L
.27513 .19604 L
.27515 .19604 L
.27518 .19604 L
.27521 .19603 L
.27524 .19603 L
.27527 .19603 L
.27531 .19603 L
.27535 .19602 L
.2754 .19602 L
.27545 .19602 L
s
.29633 .19462 m
.29628 .19463 L
.29623 .19463 L
.29619 .19463 L
.29616 .19464 L
.29612 .19464 L
.29609 .19464 L
.29606 .19464 L
.29604 .19464 L
.29602 .19465 L
.296 .19465 L
.29598 .19465 L
.29597 .19465 L
.29596 .19465 L
.29596 .19465 L
.29596 .19465 L
.29596 .19465 L
.29596 .19465 L
.29597 .19465 L
.29598 .19465 L
.296 .19465 L
.29602 .19465 L
.29604 .19464 L
.29606 .19464 L
.29609 .19464 L
.29612 .19464 L
.29616 .19464 L
.29619 .19463 L
.29623 .19463 L
.29628 .19463 L
.29633 .19462 L
s
.31762 .19266 m
.31751 .19267 L
.31741 .19268 L
.31732 .19269 L
.31724 .19269 L
.31716 .1927 L
.31709 .19271 L
.31703 .19272 L
.31698 .19272 L
.31693 .19273 L
.31689 .19273 L
.31686 .19273 L
.31683 .19274 L
.31682 .19274 L
.31681 .19274 L
.3168 .19274 L
.31681 .19274 L
.31682 .19274 L
.31683 .19274 L
.31686 .19273 L
.31689 .19273 L
.31693 .19273 L
.31698 .19272 L
.31703 .19272 L
.31709 .19271 L
.31716 .1927 L
.31724 .19269 L
.31732 .19269 L
.31741 .19268 L
.31751 .19267 L
.31762 .19266 L
s
.3384 .19054 m
.3383 .19055 L
.33821 .19056 L
.33813 .19057 L
.33805 .19058 L
.33797 .19059 L
.33791 .19059 L
.33785 .1906 L
.3378 .1906 L
.33775 .19061 L
.33771 .19061 L
.33768 .19062 L
.33766 .19062 L
.33764 .19062 L
.33763 .19062 L
.33763 .19062 L
.33763 .19062 L
.33764 .19062 L
.33766 .19062 L
.33768 .19062 L
.33771 .19061 L
.33775 .19061 L
.3378 .1906 L
.33785 .1906 L
.33791 .19059 L
.33797 .19059 L
.33805 .19058 L
.33813 .19057 L
.33821 .19056 L
.3383 .19055 L
.3384 .19054 L
s
.35919 .18843 m
.3591 .18844 L
.35901 .18845 L
.35893 .18845 L
.35885 .18846 L
.35878 .18847 L
.35872 .18848 L
.35867 .18848 L
.35862 .18849 L
.35857 .18849 L
.35854 .18849 L
.35851 .1885 L
.35848 .1885 L
.35847 .1885 L
.35846 .1885 L
.35845 .1885 L
.35846 .1885 L
.35847 .1885 L
.35848 .1885 L
.35851 .1885 L
.35854 .18849 L
.35857 .18849 L
.35862 .18849 L
.35867 .18848 L
.35872 .18848 L
.35878 .18847 L
.35885 .18846 L
.35893 .18845 L
.35901 .18845 L
.3591 .18844 L
.35919 .18843 L
s
.37998 .18631 m
.37989 .18632 L
.37981 .18633 L
.37973 .18634 L
.37966 .18635 L
.37959 .18635 L
.37953 .18636 L
.37948 .18636 L
.37943 .18637 L
.37939 .18637 L
.37936 .18638 L
.37933 .18638 L
.37931 .18638 L
.37929 .18638 L
.37928 .18638 L
.37928 .18639 L
.37928 .18638 L
.37929 .18638 L
.37931 .18638 L
.37933 .18638 L
.37936 .18638 L
.37939 .18637 L
.37943 .18637 L
.37948 .18636 L
.37953 .18636 L
.37959 .18635 L
.37966 .18635 L
.37973 .18634 L
.37981 .18633 L
.37989 .18632 L
.37998 .18631 L
s
.40077 .1842 m
.40069 .18421 L
.40061 .18422 L
.40053 .18422 L
.40047 .18423 L
.4004 .18424 L
.40035 .18424 L
.4003 .18425 L
.40025 .18425 L
.40021 .18426 L
.40018 .18426 L
.40016 .18426 L
.40013 .18426 L
.40012 .18427 L
.40011 .18427 L
.40011 .18427 L
.40011 .18427 L
.40012 .18427 L
.40013 .18426 L
.40016 .18426 L
.40018 .18426 L
.40021 .18426 L
.40025 .18425 L
.4003 .18425 L
.40035 .18424 L
.4004 .18424 L
.40047 .18423 L
.40053 .18422 L
.40061 .18422 L
.40069 .18421 L
.40077 .1842 L
s
.42156 .18209 m
.42148 .18209 L
.42141 .1821 L
.42134 .18211 L
.42127 .18212 L
.42121 .18212 L
.42116 .18213 L
.42111 .18213 L
.42107 .18214 L
.42103 .18214 L
.421 .18214 L
.42098 .18215 L
.42096 .18215 L
.42095 .18215 L
.42094 .18215 L
.42093 .18215 L
.42094 .18215 L
.42095 .18215 L
.42096 .18215 L
.42098 .18215 L
.421 .18214 L
.42103 .18214 L
.42107 .18214 L
.42111 .18213 L
.42116 .18213 L
.42121 .18212 L
.42127 .18212 L
.42134 .18211 L
.42141 .1821 L
.42148 .18209 L
.42156 .18209 L
s
.44235 .17997 m
.44228 .17998 L
.44221 .17999 L
.44214 .17999 L
.44208 .18 L
.44202 .18001 L
.44197 .18001 L
.44193 .18001 L
.44189 .18002 L
.44186 .18002 L
.44183 .18003 L
.4418 .18003 L
.44178 .18003 L
.44177 .18003 L
.44176 .18003 L
.44176 .18003 L
.44176 .18003 L
.44177 .18003 L
.44178 .18003 L
.4418 .18003 L
.44183 .18003 L
.44186 .18002 L
.44189 .18002 L
.44193 .18001 L
.44197 .18001 L
.44202 .18001 L
.44208 .18 L
.44214 .17999 L
.44221 .17999 L
.44228 .17998 L
.44235 .17997 L
s
.46314 .17786 m
.46307 .17787 L
.463 .17787 L
.46294 .17788 L
.46289 .17788 L
.46283 .17789 L
.46279 .17789 L
.46275 .1779 L
.46271 .1779 L
.46268 .17791 L
.46265 .17791 L
.46263 .17791 L
.46261 .17791 L
.4626 .17791 L
.46259 .17791 L
.46259 .17791 L
.46259 .17791 L
.4626 .17791 L
.46261 .17791 L
.46263 .17791 L
.46265 .17791 L
.46268 .17791 L
.46271 .1779 L
.46275 .1779 L
.46279 .17789 L
.46283 .17789 L
.46289 .17788 L
.46294 .17788 L
.463 .17787 L
.46307 .17787 L
.46314 .17786 L
s
.48393 .17574 m
.48387 .17575 L
.4838 .17576 L
.48375 .17576 L
.48369 .17577 L
.48364 .17577 L
.4836 .17578 L
.48356 .17578 L
.48353 .17579 L
.4835 .17579 L
.48347 .17579 L
.48345 .17579 L
.48343 .17579 L
.48342 .1758 L
.48342 .1758 L
.48341 .1758 L
.48342 .1758 L
.48342 .1758 L
.48343 .17579 L
.48345 .17579 L
.48347 .17579 L
.4835 .17579 L
.48353 .17579 L
.48356 .17578 L
.4836 .17578 L
.48364 .17577 L
.48369 .17577 L
.48375 .17576 L
.4838 .17576 L
.48387 .17575 L
.48393 .17574 L
s
.50472 .17363 m
.50466 .17364 L
.5046 .17364 L
.50455 .17365 L
.5045 .17365 L
.50445 .17366 L
.50441 .17366 L
.50438 .17366 L
.50434 .17367 L
.50432 .17367 L
.50429 .17367 L
.50427 .17368 L
.50426 .17368 L
.50425 .17368 L
.50424 .17368 L
.50424 .17368 L
.50424 .17368 L
.50425 .17368 L
.50426 .17368 L
.50427 .17368 L
.50429 .17367 L
.50432 .17367 L
.50434 .17367 L
.50438 .17366 L
.50441 .17366 L
.50445 .17366 L
.5045 .17365 L
.50455 .17365 L
.5046 .17364 L
.50466 .17364 L
.50472 .17363 L
s
.52551 .17152 m
.52545 .17152 L
.5254 .17153 L
.52535 .17153 L
.52531 .17154 L
.52526 .17154 L
.52523 .17154 L
.52519 .17155 L
.52516 .17155 L
.52514 .17155 L
.52512 .17156 L
.5251 .17156 L
.52508 .17156 L
.52507 .17156 L
.52507 .17156 L
.52507 .17156 L
.52507 .17156 L
.52507 .17156 L
.52508 .17156 L
.5251 .17156 L
.52512 .17156 L
.52514 .17155 L
.52516 .17155 L
.52519 .17155 L
.52523 .17154 L
.52526 .17154 L
.52531 .17154 L
.52535 .17153 L
.5254 .17153 L
.52545 .17152 L
.52551 .17152 L
s
.5463 .1694 m
.54625 .16941 L
.5462 .16941 L
.54615 .16942 L
.54611 .16942 L
.54607 .16942 L
.54604 .16943 L
.54601 .16943 L
.54598 .16943 L
.54596 .16944 L
.54594 .16944 L
.54592 .16944 L
.54591 .16944 L
.5459 .16944 L
.54589 .16944 L
.54589 .16944 L
.54589 .16944 L
.5459 .16944 L
.54591 .16944 L
.54592 .16944 L
.54594 .16944 L
.54596 .16944 L
.54598 .16943 L
.54601 .16943 L
.54604 .16943 L
.54607 .16942 L
.54611 .16942 L
.54615 .16942 L
.5462 .16941 L
.54625 .16941 L
.5463 .1694 L
s
.56709 .16729 m
.56704 .16729 L
.567 .1673 L
.56696 .1673 L
.56692 .16731 L
.56688 .16731 L
.56685 .16731 L
.56683 .16731 L
.5668 .16732 L
.56678 .16732 L
.56676 .16732 L
.56675 .16732 L
.56673 .16732 L
.56673 .16732 L
.56672 .16733 L
.56672 .16733 L
.56672 .16733 L
.56673 .16732 L
.56673 .16732 L
.56675 .16732 L
.56676 .16732 L
.56678 .16732 L
.5668 .16732 L
.56683 .16731 L
.56685 .16731 L
.56688 .16731 L
.56692 .16731 L
.56696 .1673 L
.567 .1673 L
.56704 .16729 L
.56709 .16729 L
s
.58788 .16517 m
.58784 .16518 L
.5878 .16518 L
.58776 .16519 L
.58773 .16519 L
.58769 .16519 L
.58767 .1652 L
.58764 .1652 L
.58762 .1652 L
.5876 .1652 L
.58758 .1652 L
.58757 .16521 L
.58756 .16521 L
.58755 .16521 L
.58755 .16521 L
.58755 .16521 L
.58755 .16521 L
.58755 .16521 L
.58756 .16521 L
.58757 .16521 L
.58758 .1652 L
.5876 .1652 L
.58762 .1652 L
.58764 .1652 L
.58767 .1652 L
.58769 .16519 L
.58773 .16519 L
.58776 .16519 L
.5878 .16518 L
.58784 .16518 L
.58788 .16517 L
s
.60867 .16306 m
.60863 .16306 L
.6086 .16307 L
.60856 .16307 L
.60853 .16307 L
.6085 .16308 L
.60848 .16308 L
.60846 .16308 L
.60844 .16308 L
.60842 .16309 L
.60841 .16309 L
.60839 .16309 L
.60838 .16309 L
.60838 .16309 L
.60837 .16309 L
.60837 .16309 L
.60837 .16309 L
.60838 .16309 L
.60838 .16309 L
.60839 .16309 L
.60841 .16309 L
.60842 .16309 L
.60844 .16308 L
.60846 .16308 L
.60848 .16308 L
.6085 .16308 L
.60853 .16307 L
.60856 .16307 L
.6086 .16307 L
.60863 .16306 L
.60867 .16306 L
s
.62946 .16095 m
.62943 .16095 L
.6294 .16095 L
.62937 .16096 L
.62934 .16096 L
.62931 .16096 L
.62929 .16096 L
.62927 .16096 L
.62926 .16097 L
.62924 .16097 L
.62923 .16097 L
.62922 .16097 L
.62921 .16097 L
.6292 .16097 L
.6292 .16097 L
.6292 .16097 L
.6292 .16097 L
.6292 .16097 L
.62921 .16097 L
.62922 .16097 L
.62923 .16097 L
.62924 .16097 L
.62926 .16097 L
.62927 .16096 L
.62929 .16096 L
.62931 .16096 L
.62934 .16096 L
.62937 .16096 L
.6294 .16095 L
.62943 .16095 L
.62946 .16095 L
s
.65025 .15883 m
.65022 .15883 L
.65019 .15884 L
.65017 .15884 L
.65015 .15884 L
.65013 .15884 L
.65011 .15885 L
.65009 .15885 L
.65007 .15885 L
.65006 .15885 L
.65005 .15885 L
.65004 .15885 L
.65003 .15885 L
.65003 .15885 L
.65003 .15885 L
.65003 .15885 L
.65003 .15885 L
.65003 .15885 L
.65003 .15885 L
.65004 .15885 L
.65005 .15885 L
.65006 .15885 L
.65007 .15885 L
.65009 .15885 L
.65011 .15885 L
.65013 .15884 L
.65015 .15884 L
.65017 .15884 L
.65019 .15884 L
.65022 .15883 L
.65025 .15883 L
s
.67104 .15672 m
.67102 .15672 L
.67099 .15672 L
.67097 .15672 L
.67095 .15673 L
.67094 .15673 L
.67092 .15673 L
.67091 .15673 L
.67089 .15673 L
.67088 .15673 L
.67087 .15673 L
.67086 .15674 L
.67086 .15674 L
.67085 .15674 L
.67085 .15674 L
.67085 .15674 L
.67085 .15674 L
.67085 .15674 L
.67086 .15674 L
.67086 .15674 L
.67087 .15673 L
.67088 .15673 L
.67089 .15673 L
.67091 .15673 L
.67092 .15673 L
.67094 .15673 L
.67095 .15673 L
.67097 .15672 L
.67099 .15672 L
.67102 .15672 L
.67104 .15672 L
s
.69183 .1546 m
.69181 .15461 L
.69179 .15461 L
.69177 .15461 L
.69176 .15461 L
.69175 .15461 L
.69173 .15461 L
.69172 .15461 L
.69171 .15462 L
.6917 .15462 L
.69169 .15462 L
.69169 .15462 L
.69168 .15462 L
.69168 .15462 L
.69168 .15462 L
.69168 .15462 L
.69168 .15462 L
.69168 .15462 L
.69168 .15462 L
.69169 .15462 L
.69169 .15462 L
.6917 .15462 L
.69171 .15462 L
.69172 .15461 L
.69173 .15461 L
.69175 .15461 L
.69176 .15461 L
.69177 .15461 L
.69179 .15461 L
.69181 .15461 L
.69183 .1546 L
s
.71262 .15249 m
.7126 .15249 L
.71259 .15249 L
.71258 .15249 L
.71257 .15249 L
.71256 .1525 L
.71255 .1525 L
.71254 .1525 L
.71253 .1525 L
.71252 .1525 L
.71252 .1525 L
.71251 .1525 L
.71251 .1525 L
.71251 .1525 L
.7125 .1525 L
.7125 .1525 L
.7125 .1525 L
.71251 .1525 L
.71251 .1525 L
.71251 .1525 L
.71252 .1525 L
.71252 .1525 L
.71253 .1525 L
.71254 .1525 L
.71255 .1525 L
.71256 .1525 L
.71257 .15249 L
.71258 .15249 L
.71259 .15249 L
.7126 .15249 L
.71262 .15249 L
s
.73341 .15038 m
.7334 .15038 L
.73339 .15038 L
.73338 .15038 L
.73337 .15038 L
.73337 .15038 L
.73336 .15038 L
.73335 .15038 L
.73335 .15038 L
.73334 .15038 L
.73334 .15038 L
.73334 .15038 L
.73333 .15038 L
.73333 .15038 L
.73333 .15038 L
.73333 .15038 L
.73333 .15038 L
.73333 .15038 L
.73333 .15038 L
.73334 .15038 L
.73334 .15038 L
.73334 .15038 L
.73335 .15038 L
.73335 .15038 L
.73336 .15038 L
.73337 .15038 L
.73337 .15038 L
.73338 .15038 L
.73339 .15038 L
.7334 .15038 L
.73341 .15038 L
s
.7542 .14826 m
.75419 .14826 L
.75419 .14826 L
.75418 .14826 L
.75418 .14826 L
.75418 .14826 L
.75417 .14826 L
.75417 .14826 L
.75417 .14826 L
.75416 .14827 L
.75416 .14827 L
.75416 .14827 L
.75416 .14827 L
.75416 .14827 L
.75416 .14827 L
.75416 .14827 L
.75416 .14827 L
.75416 .14827 L
.75416 .14827 L
.75416 .14827 L
.75416 .14827 L
.75416 .14827 L
.75417 .14826 L
.75417 .14826 L
.75417 .14826 L
.75418 .14826 L
.75418 .14826 L
.75418 .14826 L
.75419 .14826 L
.75419 .14826 L
.7542 .14826 L
s
.77499 .14615 m
.77499 .14615 L
.77499 .14615 L
.77499 .14615 L
.77499 .14615 L
.77499 .14615 L
.77499 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77498 .14615 L
.77499 .14615 L
.77499 .14615 L
.77499 .14615 L
.77499 .14615 L
.77499 .14615 L
.77499 .14615 L
.77499 .14615 L
s
.79578 .14403 m
.79578 .14403 L
.79579 .14403 L
.79579 .14403 L
.79579 .14403 L
.7958 .14403 L
.7958 .14403 L
.7958 .14403 L
.7958 .14403 L
.79581 .14403 L
.79581 .14403 L
.79581 .14403 L
.79581 .14403 L
.79581 .14403 L
.79581 .14403 L
.79581 .14403 L
.79581 .14403 L
.79581 .14403 L
.79581 .14403 L
.79581 .14403 L
.79581 .14403 L
.79581 .14403 L
.7958 .14403 L
.7958 .14403 L
.7958 .14403 L
.7958 .14403 L
.79579 .14403 L
.79579 .14403 L
.79579 .14403 L
.79578 .14403 L
.79578 .14403 L
s
.81657 .14192 m
.81658 .14192 L
.81658 .14192 L
.81659 .14192 L
.8166 .14192 L
.81661 .14192 L
.81661 .14191 L
.81662 .14191 L
.81662 .14191 L
.81663 .14191 L
.81663 .14191 L
.81663 .14191 L
.81663 .14191 L
.81664 .14191 L
.81664 .14191 L
.81664 .14191 L
.81664 .14191 L
.81664 .14191 L
.81663 .14191 L
.81663 .14191 L
.81663 .14191 L
.81663 .14191 L
.81662 .14191 L
.81662 .14191 L
.81661 .14191 L
.81661 .14192 L
.8166 .14192 L
.81659 .14192 L
.81658 .14192 L
.81658 .14192 L
.81657 .14192 L
s
.82396 .15321 m
.82395 .15322 L
.82395 .15323 L
.82395 .15324 L
.82395 .15326 L
.82395 .15327 L
.82395 .15327 L
.82395 .15328 L
.82395 .15329 L
.82395 .1533 L
.82395 .1533 L
.82395 .1533 L
.82395 .15331 L
.82395 .15331 L
.82395 .15331 L
.82395 .15331 L
.82395 .15331 L
.82395 .15331 L
.82395 .15331 L
.82395 .1533 L
.82395 .1533 L
.82395 .1533 L
.82395 .15329 L
.82395 .15328 L
.82395 .15327 L
.82395 .15327 L
.82395 .15326 L
.82395 .15324 L
.82395 .15323 L
.82395 .15322 L
.82396 .15321 L
s
.82184 .174 m
.82184 .17401 L
.82184 .17403 L
.82184 .17405 L
.82184 .17406 L
.82183 .17408 L
.82183 .17409 L
.82183 .1741 L
.82183 .17411 L
.82183 .17412 L
.82183 .17412 L
.82183 .17413 L
.82183 .17413 L
.82183 .17414 L
.82183 .17414 L
.82183 .17414 L
.82183 .17414 L
.82183 .17414 L
.82183 .17413 L
.82183 .17413 L
.82183 .17412 L
.82183 .17412 L
.82183 .17411 L
.82183 .1741 L
.82183 .17409 L
.82183 .17408 L
.82184 .17406 L
.82184 .17405 L
.82184 .17403 L
.82184 .17401 L
.82184 .174 L
s
.81973 .19479 m
.81973 .19481 L
.81972 .19483 L
.81972 .19485 L
.81972 .19487 L
.81972 .19489 L
.81972 .1949 L
.81971 .19491 L
.81971 .19493 L
.81971 .19494 L
.81971 .19495 L
.81971 .19495 L
.81971 .19496 L
.81971 .19496 L
.81971 .19496 L
.81971 .19497 L
.81971 .19496 L
.81971 .19496 L
.81971 .19496 L
.81971 .19495 L
.81971 .19495 L
.81971 .19494 L
.81971 .19493 L
.81971 .19491 L
.81972 .1949 L
.81972 .19489 L
.81972 .19487 L
.81972 .19485 L
.81972 .19483 L
.81973 .19481 L
.81973 .19479 L
s
.81761 .21558 m
.81761 .2156 L
.81761 .21563 L
.81761 .21565 L
.8176 .21568 L
.8176 .2157 L
.8176 .21571 L
.8176 .21573 L
.8176 .21574 L
.8176 .21576 L
.81759 .21577 L
.81759 .21578 L
.81759 .21578 L
.81759 .21579 L
.81759 .21579 L
.81759 .21579 L
.81759 .21579 L
.81759 .21579 L
.81759 .21578 L
.81759 .21578 L
.81759 .21577 L
.8176 .21576 L
.8176 .21574 L
.8176 .21573 L
.8176 .21571 L
.8176 .2157 L
.8176 .21568 L
.81761 .21565 L
.81761 .21563 L
.81761 .2156 L
.81761 .21558 L
s
.8155 .23637 m
.8155 .2364 L
.81549 .23643 L
.81549 .23646 L
.81549 .23648 L
.81549 .23651 L
.81548 .23653 L
.81548 .23655 L
.81548 .23656 L
.81548 .23658 L
.81548 .23659 L
.81548 .2366 L
.81548 .23661 L
.81547 .23661 L
.81547 .23662 L
.81547 .23662 L
.81547 .23662 L
.81547 .23661 L
.81548 .23661 L
.81548 .2366 L
.81548 .23659 L
.81548 .23658 L
.81548 .23656 L
.81548 .23655 L
.81548 .23653 L
.81549 .23651 L
.81549 .23648 L
.81549 .23646 L
.81549 .23643 L
.8155 .2364 L
.8155 .23637 L
s
.81339 .25716 m
.81338 .25719 L
.81338 .25723 L
.81338 .25726 L
.81337 .25729 L
.81337 .25732 L
.81337 .25734 L
.81336 .25736 L
.81336 .25738 L
.81336 .2574 L
.81336 .25741 L
.81336 .25742 L
.81336 .25743 L
.81336 .25744 L
.81336 .25744 L
.81336 .25744 L
.81336 .25744 L
.81336 .25744 L
.81336 .25743 L
.81336 .25742 L
.81336 .25741 L
.81336 .2574 L
.81336 .25738 L
.81336 .25736 L
.81337 .25734 L
.81337 .25732 L
.81337 .25729 L
.81338 .25726 L
.81338 .25723 L
.81338 .25719 L
.81339 .25716 L
s
.81127 .27794 m
.81127 .27799 L
.81126 .27803 L
.81126 .27806 L
.81126 .2781 L
.81125 .27813 L
.81125 .27815 L
.81125 .27818 L
.81125 .2782 L
.81124 .27822 L
.81124 .27823 L
.81124 .27825 L
.81124 .27826 L
.81124 .27827 L
.81124 .27827 L
.81124 .27827 L
.81124 .27827 L
.81124 .27827 L
.81124 .27826 L
.81124 .27825 L
.81124 .27823 L
.81124 .27822 L
.81125 .2782 L
.81125 .27818 L
.81125 .27815 L
.81125 .27813 L
.81126 .2781 L
.81126 .27806 L
.81126 .27803 L
.81127 .27799 L
.81127 .27794 L
s
.80916 .29873 m
.80915 .29878 L
.80915 .29882 L
.80914 .29887 L
.80914 .2989 L
.80914 .29894 L
.80913 .29897 L
.80913 .29899 L
.80913 .29902 L
.80913 .29904 L
.80913 .29906 L
.80912 .29907 L
.80912 .29908 L
.80912 .29909 L
.80912 .2991 L
.80912 .2991 L
.80912 .2991 L
.80912 .29909 L
.80912 .29908 L
.80912 .29907 L
.80913 .29906 L
.80913 .29904 L
.80913 .29902 L
.80913 .29899 L
.80913 .29897 L
.80914 .29894 L
.80914 .2989 L
.80914 .29887 L
.80915 .29882 L
.80915 .29878 L
.80916 .29873 L
s
.80704 .31952 m
.80704 .31958 L
.80703 .31962 L
.80703 .31967 L
.80703 .31971 L
.80702 .31975 L
.80702 .31978 L
.80701 .31981 L
.80701 .31984 L
.80701 .31986 L
.80701 .31988 L
.80701 .3199 L
.807 .31991 L
.807 .31992 L
.807 .31992 L
.807 .31992 L
.807 .31992 L
.807 .31992 L
.807 .31991 L
.80701 .3199 L
.80701 .31988 L
.80701 .31986 L
.80701 .31984 L
.80701 .31981 L
.80702 .31978 L
.80702 .31975 L
.80703 .31971 L
.80703 .31967 L
.80703 .31962 L
.80704 .31958 L
.80704 .31952 L
s
.80493 .34031 m
.80492 .34037 L
.80492 .34042 L
.80491 .34047 L
.80491 .34052 L
.80491 .34056 L
.8049 .34059 L
.8049 .34063 L
.8049 .34066 L
.80489 .34068 L
.80489 .3407 L
.80489 .34072 L
.80489 .34073 L
.80489 .34074 L
.80489 .34075 L
.80489 .34075 L
.80489 .34075 L
.80489 .34074 L
.80489 .34073 L
.80489 .34072 L
.80489 .3407 L
.80489 .34068 L
.8049 .34066 L
.8049 .34063 L
.8049 .34059 L
.80491 .34056 L
.80491 .34052 L
.80491 .34047 L
.80492 .34042 L
.80492 .34037 L
.80493 .34031 L
s
.80282 .3611 m
.80281 .36116 L
.8028 .36122 L
.8028 .36127 L
.80279 .36132 L
.80279 .36137 L
.80279 .36141 L
.80278 .36144 L
.80278 .36147 L
.80278 .3615 L
.80277 .36152 L
.80277 .36154 L
.80277 .36156 L
.80277 .36157 L
.80277 .36157 L
.80277 .36158 L
.80277 .36157 L
.80277 .36157 L
.80277 .36156 L
.80277 .36154 L
.80277 .36152 L
.80278 .3615 L
.80278 .36147 L
.80278 .36144 L
.80279 .36141 L
.80279 .36137 L
.80279 .36132 L
.8028 .36127 L
.8028 .36122 L
.80281 .36116 L
.80282 .3611 L
s
0 0 m
1 0 L
1 .3933 L
0 .3933 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[69]:=",
  ImageSize->{288, 113.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000LB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00DOooool6o`000<Wooooo001B
ooooo`05o`000?ooooooooooooooool00000bOooool005;ooooo00?o0000ooooooooool0boooool0
05;ooooo00?o0000ooooooooool0boooool005;ooooo00?o0000ooooooooool0boooool005;ooooo
00?o0000ooooooooool0boooool0057ooooo0ol0003<ooooo`00oooooolQooooo`00oooooolQoooo
o`00EOooool6o`000<Gooooo001Eooooo`Ko0000aOooool005Cooooo0_l00004ogmoO`03o`000?oo
oooooooo0<?ooooo001Dooooo`;o00001?moOgl00ol0003oooooooooo`33ooooo`00E?ooool7o`00
0<Gooooo001Cooooo`03o`000?moOgoo000000CoOgmo00?o0000ooooooooool0`oooool005?ooooo
00?o0000ogmoOol000001?moOgl00ol0003oooooooooo`33ooooo`00D_ooool01?l0003oOgmoogmo
Ool00004ogmoO`03o`000?oooooooooo0<?ooooo001Booooo`04o`000?moOgooOgmoo`0000CoOgmo
00?o0000ooooooooool0`oooool005;ooooo00?o0000ogmoOomoOgl01_l00035ooooo`00DOooool0
1Ol0003oOgmoogmoOomoOgoo000000CoOgmo00?o0000ooooooooool0`oooool0057ooooo00Go0000
ogmoOomoOgooOgmoo`000004ogmoO`03o`000?oooooooooo0<?ooooo001Aooooo`05o`000?moOgoo
OgmoogmoOol000001?moOgl00ol0003oooooooooo`33ooooo`00D?ooool00ol0003oOgmoogmoO`02
ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0`oooool0053ooooo00?o0000ogmo
OomoOgl00_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo0<?ooooo001@ooooo`03
o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`33ooooo`00
Coooool00ol0003oOgmoogmoO`03ogmoO`Ko0000O?ooool3o`000003ooooool0003ooooo00?o0000
@?ooool004oooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oo
oooooooo07_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0oooooo`00Cooo
ool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0Nooo
ool01ol0003oooooo`000?oooooo0000ooooool00000@Oooool004oooooo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo07_ooooo00Oo0000ooooool0003o
ooooo`000?oooooo0000047ooooo001>ooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomo
Ogl00_moOgl00ol0003oooooooooo`1kooooo`;o00000oooool2o`00047ooooo001>ooooo`03o`00
0?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1kooooo`;o0000
0oooool2o`00047ooooo001>ooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00_mo
Ogl00ol0003oooooooooo`1jooooo`;o00001Oooool3o`0003oooooo001>ooooo`03o`000?moOgoo
Ogmo00CoOgmo1_l00025ooooo`;o0000?_ooool004kooooo00?o0000ogmoOomoOgl01?moOgl00ol0
003oOgmoogmoO`02ogmoO`03o`000?oooooooooo08Cooooo0_l0000mooooo`00C_ooool00ol0003o
OgmoogmoO`04ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0QOooool00omoOgoo
0000ooooo`0kooooo`00C_ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00;oOgmo
00?o0000ooooooooool0Q_ooool00omoOgoo0000ooooo`0jooooo`00COooool00ol0003oOgmoogmo
O`05ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0Qoooool00omoOgoo0000oooo
o`0iooooo`00COooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000
ooooooooool0POooool5o`0000?o2NX:00?o0000ooooooooool0=oooool004gooooo00?o0000ogmo
OomoOgl01OmoOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo07kooooo1Ol9jPX4o`00
0004o`WZ2_l0003o0000o`0003Sooooo001=ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmo
OomoOgl00_moOgl00ol0003oooooooooo`1fooooo`Co2NX:0_l000000ol9jP[o0000o`000008o`00
00;o2NX:00?o0000o`WZ2_l00000=oooool004gooooo3_l0001Vooooo`co2NX:00?o0000o`WZ2_l0
00000ol000001?l9jP[o0000o`000?l00008ooooo`;o00001?ooool01Ol9jP[o0000o`WZ2_oooooo
000003Kooooo001=ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0
003oooooooooo`1=oooooa[o2NX:1?l000000ol9jP[o0000o`000002o`0000?o2NX:5Oooool3o`WZ
2P03ooooool0003o000003Gooooo001=ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomo
Ogl00_moOgl00ol0003oooooooooo`0joooooa?o2NX:0_ooool00ol9jP[oooooooooo`03ooooo`04
o`WZ2_ooooooooooooooo`?o2NX:1?l000000ol9jP[o0000o`000003o`0000Go2NX:7Oooool00ol9
jP[o0000o`WZ2P02ooooo`;o0000=?ooool004gooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003o
OgmoogmoO`02ogmoO`03o`000?oooooooooo02Sooooo4_l9jPX4ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo2NX:00?o
000000?o2NX:o`000?l000001?l00008o`WZ2RCooooo00?o2NX:o`000?l9jPX00oooool2o`0003?o
oooo001=ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003ooooo
ooooo`0EoooooaCo2NX:1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`04o`WZ2_oooooo2NX:o`WZ2P;o
000000?o2NX:o`000?l000000_l000000ol9jP[o0000o`000003ooooo`04o`WZ2_oooooooooooooo
o`?o2NX:;?ooool00ol0003o2NX:o`WZ2P04ooooo`;o0000<_ooool004gooooo00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo00;ooooo4ol9jPX2ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooo2NX:00?o2NX:1Ol000001?l9jP[o0000o`000?l00002ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooool9jPX01ol9jPX^ooooo`04o`WZ2_l0003o2NX:o`WZ2PGooooo0_l0000a
ooooo`003ooooom@o`WZ2PCooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_l0003o000000?o000000?o2NX:o`000?l000000_l000000ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00?ooooo1ol9jPXfooooo`;o2NX:00?oooooo`WZ2_ooool01_ooool00ol0
003oooooooooo`0^ooooo`003oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:o`000?moOgl00_moOgl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_moOgoo0000
00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00oooool2o`WZ2PCo000000?o2NX:o`000?l000000ol00005oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool02?l9jPXmooooo`Co2NX:1oooool00omo
Ogoo0000ooooo`0^ooooo`003oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:o`000?moOgl00_moOgl00ol9jP[oOgmoogmoO`03o`000003o`WZ2_l0003o000000;o
oooo0_l9jPX4ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo0ol9jPX2o`0000;o2NX:1?l000000ol9jP[o
0000ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooo`WZ2P06o`WZ2TGooooo00Co2NX:o`000?oooooo2NX:2?ooool00omoOgoo0000ooooo`0]oooo
o`003oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:o`000?mo
Ogl00_moOgl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_moOgoo000000?ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo0_l9jPX2oooo
o`03o`WZ2_l0003o2NX:00Go000000?o2NX:o`000?l000000_ooool2o`WZ2PCooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`02ooooo`;o2NX:0_ooool4o`WZ2Tcooooo00Co2NX:o`00
0?oooooo2NX:2Oooool2o`0002gooooo000?ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[o0000ogmoO`02ogmoO`Co00000_moOgl00ol9jP[oOgmoo`000003oooo
o`03o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooooooooooo0ol9jPX5o`000006o`WZ2_l0003o
0000o`000?oooooo2NX:1Oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooo`WZ2P06o`WZ2U3ooooo00Co2NX:o`000?oooooo
2NX:>?ooool000oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool3o`0000?ooooo00?o2NX:o`000?moOgl0
0_moOgl00ol9jP[o0000o`000004o`000003ogmoOol0003ooooo00;ooooo00?o2NX:o`000?l00000
0_l00002o`WZ2PCo000000?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`So2NX:
Eoooool01?l9jP[o0000ooooool9jPXhooooo`003oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_l0003o000000Go00000_moOgl3o`WZ2PCo000000?o2NX:o`000?l000000ol00002o`WZ2P?ooooo
0_l9jPX4ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool2o`WZ2PCooooo
00Co2NX:oooooooooooooooo2?l9jPYNooooo`Co2NX:>?ooool000oooooo00?o2NX:o`000?l00000
0ol000000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l00000
0ol000000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l00000
0_l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l00000
0_l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000So000000?o2NX:ogmoOol00000
0oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo1?l9jPYUooooo`04o`WZ
2_oooooo0000o`WZ2SWooooo000?ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:o`000?l00000
0ol000000ol9jP[oooooo`000002ogmoO`;o000000OoOgmoo`000?moOgooOgmoo`WZ2_moOgoo0000
00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00?ooooo00Co2NX:oooooooooooooooo1ol9jPYYooooo`04o`WZ2_oooooo0000o`WZ2SWooooo000?
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo0_l00004ooooo`03o`WZ2_oooooo000000?oOgmo00?o2NX:
ogmoOol000000_moOgl00ol9jP[oOgmoo`000003ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooo`WZ2P06o`WZ2W3ooooo00Co2NX:o`000?l9jP[o2NX:>Ooo
ool000oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
000000?oOgmo00?o2NX:ogmoOol000000_l000000ol9jP[o0000o`000003ooooo`03o`WZ2_oooooo
oooo00?ooooo2?l9jPYgooooo`04o`WZ2_l0003o2NX:o`WZ2SWooooo000?ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool01?l9jP[oooooooooool00002ogmoO`03o`WZ2_mo
Ogoo000000?oOgmo00?o2NX:o`000?ooool00_ooool6o`WZ2Woooooo00Co2NX:o`000?oooooo2NX:
>Oooool000oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`04o`WZ2_oo
ooooooooo`0000;oOgmo00?o2NX:ogmoOol000000omoOgl7o`WZ2X?ooooo1?l9jPXiooooo`003ooo
oom:o`WZ2P03ogmoOol0003ooooo08Oooooo00Co2NX:o`000?oooooo2NX:>Oooool0057ooooo00Go
0000ogmoOomoOgooOgmoo`000004ogmoO`03o`000?oooooooooo08Gooooo00Go2NX:ooooool0003o
ooooo`WZ2P0iooooo`00DOooool01Ol0003oOgmoogmoOomoOgoo000000CoOgmo00?o0000oooooooo
ool0QOooool01Ol9jP[oooooo`000?oooooo2NX:03Wooooo001Aooooo`04o`000?moOgooOgmoogmo
O`Ko0000Qoooool01Ol9jP[oooooo`000?oooooo2NX:03Wooooo001Booooo`04o`000?moOgooOgmo
o`0000CoOgmo00?o0000ooooooooool0QOooool5o`WZ2SWooooo001Booooo`04o`000?moOgooOgmo
o`0000CoOgmo00?o0000ooooooooool0Q?ooool01_l9jP[oooooooooool0003oooooo`WZ2SWooooo
001Booooo`04o`000?moOgooOgmoo`0000CoOgmo00?o0000ooooooooool0Q?ooool01_l9jP[ooooo
ooooool0003oooooo`WZ2SWooooo001Cooooo`03o`000?moOgoo000000CoOgmo00?o0000oooooooo
ool0Q?ooool01_l9jP[oooooo`000?l9jP[oooooo`WZ2SWooooo001Cooooo`03o`000?moOgoo0000
00Go0000Q_ooool01_l9jP[oooooo`000?l9jP[oooooo`WZ2SWooooo001Dooooo`;o00001?moOgl0
0ol0003oooooooooo`24ooooo`03o`WZ2_oooooo000000;ooooo00?o2NX:ooooooooool0=oooool0
05Cooooo0_l00004ogmoO`03o`000?oooooooooo08Cooooo1_l9jPXiooooo`00E?ooool7o`0008Ko
oooo00?o2NX:ooooool000000_ooool00ol9jP[oooooooooo`0gooooo`00EOooool6o`0008Gooooo
00Co2NX:oooooooooooo00000_ooool00ol9jP[oooooooooo`0gooooo`00h?ooool01_l9jP[ooooo
ooooool0003oooooo`WZ2S[ooooo003Pooooo`06o`WZ2_ooooooooooo`000?oooooo2NX:>_ooool0
0>3ooooo1?l9jPX00ooooooo2NX:ooooo`0iooooo`00h?ooool00ol9jP[oooooo`WZ2P03o`WZ2S[o
oooo003Pooooo`03o`WZ2_oooooo000000;ooooo00?o2NX:ooooooooool0>?ooool00>3ooooo00?o
2NX:ooooool000000_ooool00ol9jP[oooooooooo`0hooooo`00h?ooool00ol9jP[oooooo`000002
ooooo`03o`WZ2_oooooooooo03Sooooo003Oooooo`04o`WZ2_ooooooooooo`0000;ooooo00?o2NX:
ooooooooool0>?ooool00=oooooo1ol9jPXjooooo`00goooool01?l9jP[oooooooooool00002oooo
o`03o`WZ2_oooooooooo03Sooooo003Oooooo`04o`WZ2_ooooooooooo`0000;ooooo00?o2NX:oooo
ooooool0>?ooool00=oooooo00Co2NX:oooooooooooo00000_ooool00ol9jP[oooooooooo`0hoooo
o`00goooool01?l9jP[oooooooooool00002ooooo`03o`WZ2_oooooooooo03Sooooo003Oooooo`;o
2NX:00Goooooo`000?ooooooooooo`WZ2P0jooooo`00g_ooool00ol9jP[oooooo`WZ2P05o`WZ2S[o
oooo003Nooooo`04o`WZ2_ooooooooooo`0000?ooooo00?o2NX:ooooooooool0>?ooool00=kooooo
00Co2NX:oooooooooooo00000oooool00ol9jP[oooooooooo`0hooooo`00g_ooool01?l9jP[ooooo
ooooool00003ooooo`03o`WZ2_oooooooooo03Sooooo003Mooooo`05o`WZ2_ooooooooooooooool0
00000oooool00ol9jP[oooooooooo`0hooooo`00gOooool8o`WZ2S_ooooo003Mooooo`05o`WZ2_oo
ooooooooooooool000000_ooool00ol9jP[oooooooooo`0iooooo`00gOooool01Ol9jP[ooooooooo
oooooooo000000;ooooo00?o2NX:ooooooooool0>Oooool00=gooooo00Go2NX:ooooool0003ooooo
o`000002ooooo`03o`WZ2_oooooooooo03Wooooo003Mooooo`04o`WZ2_oooooo0000ooooo`?o0000
00?o2NX:ooooooooool0>Oooool00=gooooo00?o2NX:ooooool000001?l000000ol9jP[ooooooooo
o`0iooooo`00g?ooool01Ol9jP[oooooo`WZ2_l0003o2NX:00;o00000_l9jPXkooooo`00g?ooool0
0ol9jP[oooooooooo`04o`000003ooooool9jP[ooooo03[ooooo003Looooo`04o`WZ2_oooooooooo
ooooo`;o00000_ooool00ol9jP[oooooooooo`0iooooo`00g?ooool01?l9jP[oooooooooooooool2
o`0000;ooooo00?o2NX:ooooooooool09_ooool3o`00013ooooo003Looooo`04o`WZ2_oooooooooo
ooooo`;o00000_ooool00ol9jP[oooooooooo`0Vooooo`04o`000?ooooooooooo`0000oooooo003:
oooooa;o000000?o2NX:o`000?l000001Ol000000ol9jP[o0000o`00000Ro`0000Oooooo00?o0000
ooooooooool03Oooool00>Cooooo00?o2NX:ooooooooool09oooool2o`00013ooooo003oooooo`ko
oooo00?o0000ooooooooool04?ooool00?oooooo3_ooool01?l0003oooooooooool0000?ooooo`00
ooooool?ooooo`?o00003oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {112.25, 0}} -> {-12.4903, -35.3193, 0.803002, \
0.803002}},
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[opticalsystemoffaxis, PlotType->SideView, ShowGaussian->True];\
\>", "Input",
  CellLabel->"In[70]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .26827 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238979 0.00464533 0.145747 0.00464533 [
[.27939 .00639 -5.03125 -6 ]
[.27939 .00639 5.03125 6 ]
[.78756 .07607 -6.4375 -6 ]
[.78756 .07607 6.4375 6 ]
[.97619 .00639 -4.75 -6 ]
[.97619 .00639 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .26827 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.28595 .14575 m
.30262 .14575 L
.30262 .14575 L
.26892 .14575 L
.28595 .14575 L
F
.26892 .14575 m
.30262 .14575 L
.30262 .14575 L
.25929 .14575 L
.26892 .14575 L
F
.25929 .14575 m
.30262 .14575 L
.30262 .14575 L
.25616 .14575 L
.25929 .14575 L
F
.25616 .14575 m
.30262 .14575 L
.30262 .14575 L
.25929 .14575 L
.25616 .14575 L
F
.25929 .14575 m
.30262 .14575 L
.30262 .14575 L
.26892 .14575 L
.25929 .14575 L
F
.26892 .14575 m
.30262 .14575 L
.30262 .14575 L
.28595 .14575 L
.26892 .14575 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.28595 .14575 m
.26892 .14575 L
.25929 .14575 L
.25616 .14575 L
.25929 .14575 L
.26892 .14575 L
.28595 .14575 L
.30262 .14575 L
.30262 .14575 L
.30262 .14575 L
.30262 .14575 L
.30262 .14575 L
.30262 .14575 L
.30262 .14575 L
.28595 .14575 L
s
.5 g
.28595 .02961 m
.30262 .02961 L
.30262 .06833 L
.26892 .06833 L
.28595 .02961 L
F
.26892 .06833 m
.30262 .06833 L
.30262 .10704 L
.25929 .10704 L
.26892 .06833 L
F
.25929 .10704 m
.30262 .10704 L
.30262 .14575 L
.25616 .14575 L
.25929 .10704 L
F
.25616 .14575 m
.30262 .14575 L
.30262 .18446 L
.25929 .18446 L
.25616 .14575 L
F
.25929 .18446 m
.30262 .18446 L
.30262 .22317 L
.26892 .22317 L
.25929 .18446 L
F
.26892 .22317 m
.30262 .22317 L
.30262 .26188 L
.28595 .26188 L
.26892 .22317 L
F
0 g
.28595 .02961 m
.26892 .06833 L
.25929 .10704 L
.25616 .14575 L
.25929 .18446 L
.26892 .22317 L
.28595 .26188 L
.30262 .26188 L
.30262 .22317 L
.30262 .18446 L
.30262 .14575 L
.30262 .10704 L
.30262 .06833 L
.30262 .02961 L
.28595 .02961 L
s
.28595 .14575 m
.30262 .14575 L
.30262 .1758 L
.28595 .1758 L
.28595 .14575 L
s
.28595 .1758 m
.30262 .1758 L
.30262 .20381 L
.28595 .20381 L
.28595 .1758 L
s
.28595 .20381 m
.30262 .20381 L
.30262 .22787 L
.28595 .22787 L
.28595 .20381 L
s
.28595 .22787 m
.30262 .22787 L
.30262 .24632 L
.28595 .24632 L
.28595 .22787 L
s
.28595 .24632 m
.30262 .24632 L
.30262 .25792 L
.28595 .25792 L
.28595 .24632 L
s
.28595 .25792 m
.30262 .25792 L
.30262 .26188 L
.28595 .26188 L
.28595 .25792 L
s
.28595 .26188 m
.30262 .26188 L
.30262 .25792 L
.28595 .25792 L
.28595 .26188 L
s
.28595 .25792 m
.30262 .25792 L
.30262 .24632 L
.28595 .24632 L
.28595 .25792 L
s
.28595 .24632 m
.30262 .24632 L
.30262 .22787 L
.28595 .22787 L
.28595 .24632 L
s
.28595 .22787 m
.30262 .22787 L
.30262 .20381 L
.28595 .20381 L
.28595 .22787 L
s
.28595 .20381 m
.30262 .20381 L
.30262 .1758 L
.28595 .1758 L
.28595 .20381 L
s
.28595 .1758 m
.30262 .1758 L
.30262 .14575 L
.28595 .14575 L
.28595 .1758 L
s
.28595 .14575 m
.30262 .14575 L
.30262 .11569 L
.28595 .11569 L
.28595 .14575 L
s
.28595 .11569 m
.30262 .11569 L
.30262 .08768 L
.28595 .08768 L
.28595 .11569 L
s
.28595 .08768 m
.30262 .08768 L
.30262 .06363 L
.28595 .06363 L
.28595 .08768 L
s
.28595 .06363 m
.30262 .06363 L
.30262 .04517 L
.28595 .04517 L
.28595 .06363 L
s
.28595 .04517 m
.30262 .04517 L
.30262 .03357 L
.28595 .03357 L
.28595 .04517 L
s
.28595 .03357 m
.30262 .03357 L
.30262 .02961 L
.28595 .02961 L
.28595 .03357 L
s
.28595 .02961 m
.30262 .02961 L
.30262 .03357 L
.28595 .03357 L
.28595 .02961 L
s
.28595 .03357 m
.30262 .03357 L
.30262 .04517 L
.28595 .04517 L
.28595 .03357 L
s
.28595 .04517 m
.30262 .04517 L
.30262 .06363 L
.28595 .06363 L
.28595 .04517 L
s
.28595 .06363 m
.30262 .06363 L
.30262 .08768 L
.28595 .08768 L
.28595 .06363 L
s
.28595 .08768 m
.30262 .08768 L
.30262 .11569 L
.28595 .11569 L
.28595 .08768 L
s
.28595 .11569 m
.30262 .11569 L
.30262 .14575 L
.28595 .14575 L
.28595 .11569 L
s
.5 g
.80398 .14575 m
.80398 .14575 L
.81493 .14575 L
.81493 .14575 L
.80398 .14575 L
F
.81493 .14575 m
.81493 .14575 L
.82588 .14575 L
.82588 .14575 L
.81493 .14575 L
F
.82588 .14575 m
.82588 .14575 L
.83683 .14575 L
.83683 .14575 L
.82588 .14575 L
F
.83683 .14575 m
.83683 .14575 L
.84778 .14575 L
.84778 .14575 L
.83683 .14575 L
F
.84778 .14575 m
.84778 .14575 L
.85873 .14575 L
.85873 .14575 L
.84778 .14575 L
F
.85873 .14575 m
.85873 .14575 L
.86968 .14575 L
.86968 .14575 L
.85873 .14575 L
F
0 g
.80398 .14575 m
.81493 .14575 L
.82588 .14575 L
.83683 .14575 L
.84778 .14575 L
.85873 .14575 L
.86968 .14575 L
.86968 .14575 L
.85873 .14575 L
.84778 .14575 L
.83683 .14575 L
.82588 .14575 L
.81493 .14575 L
.80398 .14575 L
.80398 .14575 L
s
.5 g
.83683 .09929 m
.83683 .09929 L
.83683 .11478 L
.83683 .11478 L
.83683 .09929 L
F
.83683 .11478 m
.83683 .11478 L
.83683 .13026 L
.83683 .13026 L
.83683 .11478 L
F
.83683 .13026 m
.83683 .13026 L
.83683 .14575 L
.83683 .14575 L
.83683 .13026 L
F
.83683 .14575 m
.83683 .14575 L
.83683 .16123 L
.83683 .16123 L
.83683 .14575 L
F
.83683 .16123 m
.83683 .16123 L
.83683 .17672 L
.83683 .17672 L
.83683 .16123 L
F
.83683 .17672 m
.83683 .17672 L
.83683 .1922 L
.83683 .1922 L
.83683 .17672 L
F
0 g
.83683 .09929 m
.83683 .11478 L
.83683 .13026 L
.83683 .14575 L
.83683 .16123 L
.83683 .17672 L
.83683 .1922 L
.83683 .1922 L
.83683 .17672 L
.83683 .16123 L
.83683 .14575 L
.83683 .13026 L
.83683 .11478 L
.83683 .09929 L
.83683 .09929 L
s
.5 g
.83683 .14575 m
.84778 .14575 L
.84741 .14975 L
.83683 .14575 L
.83683 .14575 L
F
.84778 .14575 m
.85873 .14575 L
.85798 .15376 L
.84741 .14975 L
.84778 .14575 L
F
.85873 .14575 m
.86968 .14575 L
.86856 .15777 L
.85798 .15376 L
.85873 .14575 L
F
.83683 .14575 m
.84741 .14975 L
.84631 .15349 L
.83683 .14575 L
.83683 .14575 L
F
.84741 .14975 m
.85798 .15376 L
.8558 .16123 L
.84631 .15349 L
.84741 .14975 L
F
.85798 .15376 m
.86856 .15777 L
.86528 .16897 L
.8558 .16123 L
.85798 .15376 L
F
.83683 .14575 m
.84631 .15349 L
.84457 .1567 L
.83683 .14575 L
.83683 .14575 L
F
.84631 .15349 m
.8558 .16123 L
.85232 .16765 L
.84457 .1567 L
.84631 .15349 L
F
.8558 .16123 m
.86528 .16897 L
.86006 .17859 L
.85232 .16765 L
.8558 .16123 L
F
.83683 .14575 m
.84457 .1567 L
.84231 .15916 L
.83683 .14575 L
.83683 .14575 L
F
.84457 .1567 m
.85232 .16765 L
.84778 .17257 L
.84231 .15916 L
.84457 .1567 L
F
.85232 .16765 m
.86006 .17859 L
.85325 .18598 L
.84778 .17257 L
.85232 .16765 L
F
.83683 .14575 m
.84231 .15916 L
.83966 .1607 L
.83683 .14575 L
.83683 .14575 L
F
.84231 .15916 m
.84778 .17257 L
.8425 .17566 L
.83966 .1607 L
.84231 .15916 L
F
.84778 .17257 m
.85325 .18598 L
.84533 .19062 L
.8425 .17566 L
.84778 .17257 L
F
.83683 .14575 m
.83966 .1607 L
.83683 .16123 L
.83683 .14575 L
.83683 .14575 L
F
.83966 .1607 m
.8425 .17566 L
.83683 .17672 L
.83683 .16123 L
.83966 .1607 L
F
.8425 .17566 m
.84533 .19062 L
.83683 .1922 L
.83683 .17672 L
.8425 .17566 L
F
.83683 .14575 m
.83683 .16123 L
.834 .1607 L
.83683 .14575 L
.83683 .14575 L
F
.83683 .16123 m
.83683 .17672 L
.83116 .17566 L
.834 .1607 L
.83683 .16123 L
F
.83683 .17672 m
.83683 .1922 L
.82833 .19062 L
.83116 .17566 L
.83683 .17672 L
F
.83683 .14575 m
.834 .1607 L
.83136 .15916 L
.83683 .14575 L
.83683 .14575 L
F
.834 .1607 m
.83116 .17566 L
.82588 .17257 L
.83136 .15916 L
.834 .1607 L
F
.83116 .17566 m
.82833 .19062 L
.82041 .18598 L
.82588 .17257 L
.83116 .17566 L
F
.83683 .14575 m
.83136 .15916 L
.82909 .1567 L
.83683 .14575 L
.83683 .14575 L
F
.83136 .15916 m
.82588 .17257 L
.82135 .16765 L
.82909 .1567 L
.83136 .15916 L
F
.82588 .17257 m
.82041 .18598 L
.8136 .17859 L
.82135 .16765 L
.82588 .17257 L
F
.83683 .14575 m
.82909 .1567 L
.82735 .15349 L
.83683 .14575 L
.83683 .14575 L
F
.82909 .1567 m
.82135 .16765 L
.81787 .16123 L
.82735 .15349 L
.82909 .1567 L
F
.82135 .16765 m
.8136 .17859 L
.80838 .16897 L
.81787 .16123 L
.82135 .16765 L
F
.83683 .14575 m
.82735 .15349 L
.82625 .14975 L
.83683 .14575 L
.83683 .14575 L
F
.82735 .15349 m
.81787 .16123 L
.81568 .15376 L
.82625 .14975 L
.82735 .15349 L
F
.81787 .16123 m
.80838 .16897 L
.8051 .15777 L
.81568 .15376 L
.81787 .16123 L
F
.83683 .14575 m
.82625 .14975 L
.82588 .14575 L
.83683 .14575 L
.83683 .14575 L
F
.82625 .14975 m
.81568 .15376 L
.81493 .14575 L
.82588 .14575 L
.82625 .14975 L
F
.81568 .15376 m
.8051 .15777 L
.80398 .14575 L
.81493 .14575 L
.81568 .15376 L
F
.83683 .14575 m
.82588 .14575 L
.82625 .14174 L
.83683 .14575 L
.83683 .14575 L
F
.82588 .14575 m
.81493 .14575 L
.81568 .13773 L
.82625 .14174 L
.82588 .14575 L
F
.81493 .14575 m
.80398 .14575 L
.8051 .13372 L
.81568 .13773 L
.81493 .14575 L
F
.83683 .14575 m
.82625 .14174 L
.82735 .138 L
.83683 .14575 L
.83683 .14575 L
F
.82625 .14174 m
.81568 .13773 L
.81787 .13026 L
.82735 .138 L
.82625 .14174 L
F
.81568 .13773 m
.8051 .13372 L
.80838 .12252 L
.81787 .13026 L
.81568 .13773 L
F
.83683 .14575 m
.82735 .138 L
.82909 .1348 L
.83683 .14575 L
.83683 .14575 L
F
.82735 .138 m
.81787 .13026 L
.82135 .12385 L
.82909 .1348 L
.82735 .138 L
F
.81787 .13026 m
.80838 .12252 L
.8136 .1129 L
.82135 .12385 L
.81787 .13026 L
F
.83683 .14575 m
.82909 .1348 L
.83136 .13234 L
.83683 .14575 L
.83683 .14575 L
F
.82909 .1348 m
.82135 .12385 L
.82588 .11893 L
.83136 .13234 L
.82909 .1348 L
F
.82135 .12385 m
.8136 .1129 L
.82041 .10552 L
.82588 .11893 L
.82135 .12385 L
F
.83683 .14575 m
.83136 .13234 L
.834 .13079 L
.83683 .14575 L
.83683 .14575 L
F
.83136 .13234 m
.82588 .11893 L
.83116 .11583 L
.834 .13079 L
.83136 .13234 L
F
.82588 .11893 m
.82041 .10552 L
.82833 .10088 L
.83116 .11583 L
.82588 .11893 L
F
.83683 .14575 m
.834 .13079 L
.83683 .13026 L
.83683 .14575 L
.83683 .14575 L
F
.834 .13079 m
.83116 .11583 L
.83683 .11478 L
.83683 .13026 L
.834 .13079 L
F
.83116 .11583 m
.82833 .10088 L
.83683 .09929 L
.83683 .11478 L
.83116 .11583 L
F
.83683 .14575 m
.83683 .13026 L
.83966 .13079 L
.83683 .14575 L
.83683 .14575 L
F
.83683 .13026 m
.83683 .11478 L
.8425 .11583 L
.83966 .13079 L
.83683 .13026 L
F
.83683 .11478 m
.83683 .09929 L
.84533 .10088 L
.8425 .11583 L
.83683 .11478 L
F
.83683 .14575 m
.83966 .13079 L
.84231 .13234 L
.83683 .14575 L
.83683 .14575 L
F
.83966 .13079 m
.8425 .11583 L
.84778 .11893 L
.84231 .13234 L
.83966 .13079 L
F
.8425 .11583 m
.84533 .10088 L
.85325 .10552 L
.84778 .11893 L
.8425 .11583 L
F
.83683 .14575 m
.84231 .13234 L
.84457 .1348 L
.83683 .14575 L
.83683 .14575 L
F
.84231 .13234 m
.84778 .11893 L
.85232 .12385 L
.84457 .1348 L
.84231 .13234 L
F
.84778 .11893 m
.85325 .10552 L
.86006 .1129 L
.85232 .12385 L
.84778 .11893 L
F
.83683 .14575 m
.84457 .1348 L
.84631 .138 L
.83683 .14575 L
.83683 .14575 L
F
.84457 .1348 m
.85232 .12385 L
.8558 .13026 L
.84631 .138 L
.84457 .1348 L
F
.85232 .12385 m
.86006 .1129 L
.86528 .12252 L
.8558 .13026 L
.85232 .12385 L
F
.83683 .14575 m
.84631 .138 L
.84741 .14174 L
.83683 .14575 L
.83683 .14575 L
F
.84631 .138 m
.8558 .13026 L
.85798 .13773 L
.84741 .14174 L
.84631 .138 L
F
.8558 .13026 m
.86528 .12252 L
.86856 .13372 L
.85798 .13773 L
.8558 .13026 L
F
.83683 .14575 m
.84741 .14174 L
.84778 .14575 L
.83683 .14575 L
.83683 .14575 L
F
.84741 .14174 m
.85798 .13773 L
.85873 .14575 L
.84778 .14575 L
.84741 .14174 L
F
.85798 .13773 m
.86856 .13372 L
.86968 .14575 L
.85873 .14575 L
.85798 .13773 L
F
0 g
.86968 .14575 m
.86856 .15777 L
.86528 .16897 L
.86006 .17859 L
.85325 .18598 L
.84533 .19062 L
.83683 .1922 L
.82833 .19062 L
.82041 .18598 L
.8136 .17859 L
.80838 .16897 L
.8051 .15777 L
.80398 .14575 L
.8051 .13372 L
.80838 .12252 L
.8136 .1129 L
.82041 .10552 L
.82833 .10088 L
.83683 .09929 L
.84533 .10088 L
.85325 .10552 L
.86006 .1129 L
.86528 .12252 L
.86856 .13372 L
.86968 .14575 L
s
.95296 .14575 m
.91425 .14575 L
.87554 .14575 L
.83683 .14575 L
.79812 .14575 L
.75941 .14575 L
.7207 .14575 L
.7207 .14575 L
.75941 .14575 L
.79812 .14575 L
.83683 .14575 L
.87554 .14575 L
.91425 .14575 L
.95296 .14575 L
.95296 .14575 L
s
.83683 .02961 m
.83683 .06833 L
.83683 .10704 L
.83683 .14575 L
.83683 .18446 L
.83683 .22317 L
.83683 .26188 L
.83683 .26188 L
.83683 .22317 L
.83683 .18446 L
.83683 .14575 L
.83683 .10704 L
.83683 .06833 L
.83683 .02961 L
.83683 .02961 L
s
.7207 .14575 m
.72465 .1758 L
.73626 .20381 L
.75471 .22787 L
.77876 .24632 L
.80677 .25792 L
.83683 .26188 L
.86689 .25792 L
.8949 .24632 L
.91895 .22787 L
.9374 .20381 L
.94901 .1758 L
.95296 .14575 L
.94901 .11569 L
.9374 .08768 L
.91895 .06363 L
.8949 .04517 L
.86689 .03357 L
.83683 .02961 L
.80677 .03357 L
.77876 .04517 L
.75471 .06363 L
.73626 .08768 L
.72465 .11569 L
.7207 .14575 L
s
0 0 0 r
gsave
.27939 .00639 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78756 .07607 -67.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
71.875 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .00639 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
1 Mabswid
.0239 .14575 m
.03789 .14575 L
.05188 .14575 L
.06587 .14575 L
.07986 .14575 L
.09385 .14575 L
.10784 .14575 L
.12183 .14575 L
.13582 .14575 L
.14981 .14575 L
.1638 .14575 L
.17779 .14575 L
.19178 .14575 L
.20577 .14575 L
.21976 .14575 L
.23375 .14575 L
.24774 .14575 L
.26337 .14575 L
.27729 .14575 L
.29122 .14575 L
.30594 .14575 L
.31979 .14575 L
.33364 .14575 L
.34749 .14575 L
.36133 .14575 L
.37518 .14575 L
.38903 .14575 L
.40288 .14575 L
.41672 .14575 L
.43057 .14575 L
.44442 .14575 L
.45827 .14575 L
.47212 .14575 L
.48596 .14575 L
.49981 .14575 L
.51366 .14575 L
.52751 .14575 L
.54135 .14575 L
.5552 .14575 L
.56905 .14575 L
.5829 .14575 L
.59674 .14575 L
.61059 .14575 L
.62444 .14575 L
.63829 .14575 L
.65214 .14575 L
.66598 .14575 L
.67983 .14575 L
.69368 .14575 L
.70753 .14575 L
Mistroke
.72137 .14575 L
.73522 .14575 L
.74907 .14575 L
.76292 .14575 L
.77687 .14575 L
.79086 .14575 L
.80484 .14575 L
.81883 .14575 L
.82332 .14575 L
.82122 .14575 L
.81911 .14575 L
.817 .14575 L
.81489 .14575 L
.81278 .14575 L
.81067 .14575 L
.80856 .14575 L
.80645 .14575 L
.80435 .14575 L
.80224 .14575 L
.80013 .14575 L
.79802 .14575 L
.79591 .14575 L
.7938 .14575 L
.79169 .14575 L
.78959 .14575 L
.78748 .14575 L
Mfstroke
.0239 .14575 m
.03789 .14575 L
.05188 .14575 L
.06587 .14575 L
.07986 .14575 L
.09385 .14575 L
.10784 .14575 L
.12183 .14575 L
.13582 .14575 L
.14981 .14575 L
.1638 .14575 L
.17779 .14575 L
.19178 .14575 L
.20577 .14575 L
.21976 .14575 L
.23375 .14575 L
.24774 .14575 L
.26008 .14575 L
.27407 .14575 L
.28806 .14575 L
.30125 .14575 L
.31524 .14575 L
.32923 .14575 L
.34322 .14575 L
.35721 .14575 L
.3712 .14575 L
.38518 .14575 L
.39917 .14575 L
.41316 .14575 L
.42715 .14575 L
.44114 .14575 L
.45513 .14575 L
.46912 .14575 L
.48311 .14575 L
.49709 .14575 L
.51108 .14575 L
.52507 .14575 L
.53906 .14575 L
.55305 .14575 L
.56704 .14575 L
.58103 .14575 L
.59501 .14575 L
.609 .14575 L
.62299 .14575 L
.63698 .14575 L
.65097 .14575 L
.66496 .14575 L
.67895 .14575 L
.69294 .14575 L
.70692 .14575 L
Mistroke
.72091 .14575 L
.7349 .14575 L
.74889 .14575 L
.76288 .14575 L
.77676 .14575 L
.79061 .14575 L
.80446 .14575 L
.81831 .14575 L
.82988 .14575 L
.82916 .14575 L
.82844 .14575 L
.82772 .14575 L
.827 .14575 L
.82628 .14575 L
.82555 .14575 L
.82483 .14575 L
.82411 .14575 L
.82339 .14575 L
.82267 .14575 L
.82194 .14575 L
.82122 .14575 L
.8205 .14575 L
.81978 .14575 L
.81906 .14575 L
.81833 .14575 L
.81761 .14575 L
Mfstroke
.0239 .16897 m
.03789 .16904 L
.05188 .16911 L
.06587 .16918 L
.07986 .16925 L
.09385 .16932 L
.10784 .16939 L
.12183 .16946 L
.13582 .16953 L
.14981 .1696 L
.1638 .16967 L
.17779 .16974 L
.19178 .16981 L
.20577 .16988 L
.21976 .16995 L
.23375 .17002 L
.24774 .17009 L
.26172 .17012 L
.27568 .16968 L
.28964 .16924 L
.3036 .16878 L
.31752 .1681 L
.33143 .16743 L
.34535 .16676 L
.35927 .16608 L
.37319 .16541 L
.38711 .16474 L
.40103 .16406 L
.41494 .16339 L
.42886 .16271 L
.44278 .16204 L
.4567 .16137 L
.47062 .16069 L
.48453 .16002 L
.49845 .15935 L
.51237 .15867 L
.52629 .158 L
.54021 .15732 L
.55413 .15665 L
.56804 .15598 L
.58196 .1553 L
.59588 .15463 L
.6098 .15395 L
.62372 .15328 L
.63763 .15261 L
.65155 .15193 L
.66547 .15126 L
.67939 .15059 L
.69331 .14991 L
.70722 .14924 L
Mistroke
.72114 .14856 L
.73506 .14789 L
.74898 .14722 L
.7629 .14654 L
.77682 .14587 L
.79073 .1463 L
.80465 .14697 L
.81857 .14765 L
.8266 .14832 L
.82519 .14899 L
.82377 .14967 L
.82236 .15034 L
.82094 .15101 L
.81953 .15169 L
.81811 .15236 L
.8167 .15304 L
.81528 .15371 L
.81387 .15438 L
.81245 .15506 L
.81104 .15573 L
.80962 .1564 L
.80821 .15708 L
.80679 .15775 L
.80538 .15843 L
.80396 .1591 L
.80254 .15977 L
Mfstroke
.0239 .12252 m
.03789 .12245 L
.05188 .12238 L
.06587 .12231 L
.07986 .12224 L
.09385 .12217 L
.10784 .1221 L
.12183 .12203 L
.13582 .12196 L
.14981 .12189 L
.1638 .12182 L
.17779 .12175 L
.19178 .12168 L
.20577 .12161 L
.21976 .12154 L
.23375 .12147 L
.24774 .1214 L
.26172 .12137 L
.27568 .12181 L
.28964 .12226 L
.3036 .12272 L
.31752 .12339 L
.33143 .12406 L
.34535 .12474 L
.35927 .12541 L
.37319 .12609 L
.38711 .12676 L
.40103 .12743 L
.41494 .12811 L
.42886 .12878 L
.44278 .12945 L
.4567 .13013 L
.47062 .1308 L
.48453 .13148 L
.49845 .13215 L
.51237 .13282 L
.52629 .1335 L
.54021 .13417 L
.55413 .13484 L
.56804 .13552 L
.58196 .13619 L
.59588 .13687 L
.6098 .13754 L
.62372 .13821 L
.63763 .13889 L
.65155 .13956 L
.66547 .14023 L
.67939 .14091 L
.69331 .14158 L
.70722 .14226 L
Mistroke
.72114 .14293 L
.73506 .1436 L
.74898 .14428 L
.7629 .14495 L
.77682 .14562 L
.79073 .1452 L
.80465 .14452 L
.81857 .14385 L
.8266 .14317 L
.82519 .1425 L
.82377 .14183 L
.82236 .14115 L
.82094 .14048 L
.81953 .13981 L
.81811 .13913 L
.8167 .13846 L
.81528 .13778 L
.81387 .13711 L
.81245 .13644 L
.81104 .13576 L
.80962 .13509 L
.80821 .13442 L
.80679 .13374 L
.80538 .13307 L
.80396 .13239 L
.80254 .13172 L
Mfstroke
0 0 0 r
.0239 .14575 m
.26068 .14575 L
s
% Start of user PostScript
0 0 50.9716 0 MAarrowhead1
% End of user PostScript
.26068 .14575 m
.30262 .14575 L
s
% Start of user PostScript
50.9716 0 60. 0 MAarrowhead1
% End of user PostScript
.30262 .14575 m
.82715 .14575 L
s
% Start of user PostScript
60. 0 172.915 0 MAarrowhead1
% End of user PostScript
.82715 .14575 m
.80254 .14575 L
s
% Start of user PostScript
172.915 0 167.619 0 MAarrowhead1
% End of user PostScript
.80254 .14575 m
.80254 .14575 L
s
% Start of user PostScript
167.619 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .14575 m
.02382 .14575 L
.02383 .14575 L
.02384 .14575 L
.02385 .14575 L
.02386 .14575 L
.02387 .14575 L
.02387 .14575 L
.02388 .14575 L
.02388 .14575 L
.02389 .14575 L
.02389 .14575 L
.02389 .14575 L
.0239 .14575 L
.0239 .14575 L
.0239 .14575 L
.0239 .14575 L
.0239 .14575 L
.02389 .14575 L
.02389 .14575 L
.02389 .14575 L
.02388 .14575 L
.02388 .14575 L
.02387 .14575 L
.02387 .14575 L
.02386 .14575 L
.02385 .14575 L
.02384 .14575 L
.02383 .14575 L
.02382 .14575 L
.02381 .14575 L
s
.04479 .14575 m
.04481 .14575 L
.04482 .14575 L
.04483 .14575 L
.04484 .14575 L
.04484 .14575 L
.04485 .14575 L
.04486 .14575 L
.04486 .14575 L
.04487 .14575 L
.04487 .14575 L
.04488 .14575 L
.04488 .14575 L
.04488 .14575 L
.04488 .14575 L
.04488 .14575 L
.04488 .14575 L
.04488 .14575 L
.04488 .14575 L
.04488 .14575 L
.04487 .14575 L
.04487 .14575 L
.04486 .14575 L
.04486 .14575 L
.04485 .14575 L
.04484 .14575 L
.04484 .14575 L
.04483 .14575 L
.04482 .14575 L
.04481 .14575 L
.04479 .14575 L
s
.06578 .14575 m
.06579 .14575 L
.0658 .14575 L
.06581 .14575 L
.06582 .14575 L
.06583 .14575 L
.06584 .14575 L
.06584 .14575 L
.06585 .14575 L
.06585 .14575 L
.06586 .14575 L
.06586 .14575 L
.06586 .14575 L
.06587 .14575 L
.06587 .14575 L
.06587 .14575 L
.06587 .14575 L
.06587 .14575 L
.06586 .14575 L
.06586 .14575 L
.06586 .14575 L
.06585 .14575 L
.06585 .14575 L
.06584 .14575 L
.06584 .14575 L
.06583 .14575 L
.06582 .14575 L
.06581 .14575 L
.0658 .14575 L
.06579 .14575 L
.06578 .14575 L
s
.08676 .14575 m
.08677 .14575 L
.08679 .14575 L
.0868 .14575 L
.0868 .14575 L
.08681 .14575 L
.08682 .14575 L
.08683 .14575 L
.08683 .14575 L
.08684 .14575 L
.08684 .14575 L
.08685 .14575 L
.08685 .14575 L
.08685 .14575 L
.08685 .14575 L
.08685 .14575 L
.08685 .14575 L
.08685 .14575 L
.08685 .14575 L
.08685 .14575 L
.08684 .14575 L
.08684 .14575 L
.08683 .14575 L
.08683 .14575 L
.08682 .14575 L
.08681 .14575 L
.0868 .14575 L
.0868 .14575 L
.08679 .14575 L
.08677 .14575 L
.08676 .14575 L
s
.10775 .14575 m
.10776 .14575 L
.10777 .14575 L
.10778 .14575 L
.10779 .14575 L
.1078 .14575 L
.10781 .14575 L
.10781 .14575 L
.10782 .14575 L
.10782 .14575 L
.10783 .14575 L
.10783 .14575 L
.10783 .14575 L
.10784 .14575 L
.10784 .14575 L
.10784 .14575 L
.10784 .14575 L
.10784 .14575 L
.10783 .14575 L
.10783 .14575 L
.10783 .14575 L
.10782 .14575 L
.10782 .14575 L
.10781 .14575 L
.10781 .14575 L
.1078 .14575 L
.10779 .14575 L
.10778 .14575 L
.10777 .14575 L
.10776 .14575 L
.10775 .14575 L
s
.12873 .14575 m
.12874 .14575 L
.12875 .14575 L
.12876 .14575 L
.12877 .14575 L
.12878 .14575 L
.12879 .14575 L
.1288 .14575 L
.1288 .14575 L
.12881 .14575 L
.12881 .14575 L
.12882 .14575 L
.12882 .14575 L
.12882 .14575 L
.12882 .14575 L
.12882 .14575 L
.12882 .14575 L
.12882 .14575 L
.12882 .14575 L
.12882 .14575 L
.12881 .14575 L
.12881 .14575 L
.1288 .14575 L
.1288 .14575 L
.12879 .14575 L
.12878 .14575 L
.12877 .14575 L
.12876 .14575 L
.12875 .14575 L
.12874 .14575 L
.12873 .14575 L
s
.14972 .14575 m
.14973 .14575 L
.14974 .14575 L
.14975 .14575 L
.14976 .14575 L
.14977 .14575 L
.14977 .14575 L
.14978 .14575 L
.14979 .14575 L
.14979 .14575 L
.1498 .14575 L
.1498 .14575 L
.1498 .14575 L
.14981 .14575 L
.14981 .14575 L
.14981 .14575 L
.14981 .14575 L
.14981 .14575 L
.1498 .14575 L
.1498 .14575 L
.1498 .14575 L
.14979 .14575 L
.14979 .14575 L
.14978 .14575 L
.14977 .14575 L
.14977 .14575 L
.14976 .14575 L
.14975 .14575 L
.14974 .14575 L
.14973 .14575 L
.14972 .14575 L
s
.1707 .14575 m
.17071 .14575 L
.17072 .14575 L
.17073 .14575 L
.17074 .14575 L
.17075 .14575 L
.17076 .14575 L
.17077 .14575 L
.17077 .14575 L
.17078 .14575 L
.17078 .14575 L
.17079 .14575 L
.17079 .14575 L
.17079 .14575 L
.17079 .14575 L
.17079 .14575 L
.17079 .14575 L
.17079 .14575 L
.17079 .14575 L
.17079 .14575 L
.17078 .14575 L
.17078 .14575 L
.17077 .14575 L
.17077 .14575 L
.17076 .14575 L
.17075 .14575 L
.17074 .14575 L
.17073 .14575 L
.17072 .14575 L
.17071 .14575 L
.1707 .14575 L
s
.19169 .14575 m
.1917 .14575 L
.19171 .14575 L
.19172 .14575 L
.19173 .14575 L
.19174 .14575 L
.19174 .14575 L
.19175 .14575 L
.19176 .14575 L
.19176 .14575 L
.19177 .14575 L
.19177 .14575 L
.19177 .14575 L
.19178 .14575 L
.19178 .14575 L
.19178 .14575 L
.19178 .14575 L
.19178 .14575 L
.19177 .14575 L
.19177 .14575 L
.19177 .14575 L
.19176 .14575 L
.19176 .14575 L
.19175 .14575 L
.19174 .14575 L
.19174 .14575 L
.19173 .14575 L
.19172 .14575 L
.19171 .14575 L
.1917 .14575 L
.19169 .14575 L
s
.21267 .14575 m
.21268 .14575 L
.21269 .14575 L
.2127 .14575 L
.21271 .14575 L
.21272 .14575 L
.21273 .14575 L
.21274 .14575 L
.21274 .14575 L
.21275 .14575 L
.21275 .14575 L
.21276 .14575 L
.21276 .14575 L
.21276 .14575 L
.21276 .14575 L
.21276 .14575 L
.21276 .14575 L
.21276 .14575 L
.21276 .14575 L
.21276 .14575 L
.21275 .14575 L
.21275 .14575 L
.21274 .14575 L
.21274 .14575 L
.21273 .14575 L
.21272 .14575 L
.21271 .14575 L
.2127 .14575 L
.21269 .14575 L
.21268 .14575 L
.21267 .14575 L
s
.23365 .14575 m
.23367 .14575 L
.23368 .14575 L
.23369 .14575 L
.2337 .14575 L
.23371 .14575 L
.23371 .14575 L
.23372 .14575 L
.23373 .14575 L
.23373 .14575 L
.23374 .14575 L
.23374 .14575 L
.23374 .14575 L
.23375 .14575 L
.23375 .14575 L
.23375 .14575 L
.23375 .14575 L
.23375 .14575 L
.23374 .14575 L
.23374 .14575 L
.23374 .14575 L
.23373 .14575 L
.23373 .14575 L
.23372 .14575 L
.23371 .14575 L
.23371 .14575 L
.2337 .14575 L
.23369 .14575 L
.23368 .14575 L
.23367 .14575 L
.23365 .14575 L
s
.25464 .14575 m
.25465 .14575 L
.25466 .14575 L
.25467 .14575 L
.25468 .14575 L
.25469 .14575 L
.2547 .14575 L
.25471 .14575 L
.25471 .14575 L
.25472 .14575 L
.25472 .14575 L
.25473 .14575 L
.25473 .14575 L
.25473 .14575 L
.25473 .14575 L
.25473 .14575 L
.25473 .14575 L
.25473 .14575 L
.25473 .14575 L
.25473 .14575 L
.25472 .14575 L
.25472 .14575 L
.25471 .14575 L
.25471 .14575 L
.2547 .14575 L
.25469 .14575 L
.25468 .14575 L
.25467 .14575 L
.25466 .14575 L
.25465 .14575 L
.25464 .14575 L
s
.27463 .14575 m
.27467 .14575 L
.27472 .14575 L
.27478 .14575 L
.27483 .14575 L
.27489 .14575 L
.27496 .14575 L
.27502 .14575 L
.27509 .14575 L
.27517 .14575 L
.27524 .14575 L
.27532 .14575 L
.27541 .14575 L
.2755 .14575 L
.27559 .14575 L
.27568 .14575 L
.27578 .14575 L
.27588 .14575 L
.27599 .14575 L
.2761 .14575 L
.27621 .14575 L
.27633 .14575 L
.27645 .14575 L
.27657 .14575 L
.2767 .14575 L
.27683 .14575 L
.27696 .14575 L
.2771 .14575 L
.27724 .14575 L
.27738 .14575 L
.27753 .14575 L
s
.2956 .14575 m
.29564 .14575 L
.29569 .14575 L
.29574 .14575 L
.2958 .14575 L
.29585 .14575 L
.29591 .14575 L
.29598 .14575 L
.29605 .14575 L
.29612 .14575 L
.29619 .14575 L
.29627 .14575 L
.29636 .14575 L
.29644 .14575 L
.29653 .14575 L
.29662 .14575 L
.29672 .14575 L
.29682 .14575 L
.29692 .14575 L
.29702 .14575 L
.29713 .14575 L
.29725 .14575 L
.29736 .14575 L
.29748 .14575 L
.2976 .14575 L
.29773 .14575 L
.29786 .14575 L
.29799 .14575 L
.29813 .14575 L
.29827 .14575 L
.29841 .14575 L
s
.31632 .14575 m
.31634 .14575 L
.31638 .14575 L
.31642 .14575 L
.31647 .14575 L
.31653 .14575 L
.31659 .14575 L
.31667 .14575 L
.31675 .14575 L
.31683 .14575 L
.31693 .14575 L
.31703 .14575 L
.31714 .14575 L
.31726 .14575 L
.31738 .14575 L
.31752 .14575 L
.31766 .14575 L
.3178 .14575 L
.31796 .14575 L
.31812 .14575 L
.31829 .14575 L
.31847 .14575 L
.31866 .14575 L
.31885 .14575 L
.31905 .14575 L
.31926 .14575 L
.31947 .14575 L
.3197 .14575 L
.31993 .14575 L
.32017 .14575 L
.32041 .14575 L
s
.33725 .14575 m
.33728 .14575 L
.33731 .14575 L
.33735 .14575 L
.3374 .14575 L
.33745 .14575 L
.33751 .14575 L
.33758 .14575 L
.33766 .14575 L
.33774 .14575 L
.33783 .14575 L
.33793 .14575 L
.33804 .14575 L
.33815 .14575 L
.33827 .14575 L
.33839 .14575 L
.33853 .14575 L
.33867 .14575 L
.33882 .14575 L
.33897 .14575 L
.33913 .14575 L
.3393 .14575 L
.33948 .14575 L
.33966 .14575 L
.33986 .14575 L
.34005 .14575 L
.34026 .14575 L
.34047 .14575 L
.34069 .14575 L
.34092 .14575 L
.34115 .14575 L
s
.35818 .14575 m
.35821 .14575 L
.35824 .14575 L
.35828 .14575 L
.35832 .14575 L
.35837 .14575 L
.35843 .14575 L
.3585 .14575 L
.35857 .14575 L
.35865 .14575 L
.35874 .14575 L
.35883 .14575 L
.35893 .14575 L
.35904 .14575 L
.35915 .14575 L
.35927 .14575 L
.3594 .14575 L
.35953 .14575 L
.35967 .14575 L
.35982 .14575 L
.35998 .14575 L
.36014 .14575 L
.36031 .14575 L
.36048 .14575 L
.36066 .14575 L
.36085 .14575 L
.36105 .14575 L
.36125 .14575 L
.36146 .14575 L
.36167 .14575 L
.3619 .14575 L
s
.37912 .14575 m
.37914 .14575 L
.37917 .14575 L
.37921 .14575 L
.37925 .14575 L
.3793 .14575 L
.37935 .14575 L
.37942 .14575 L
.37948 .14575 L
.37956 .14575 L
.37964 .14575 L
.37973 .14575 L
.37982 .14575 L
.37993 .14575 L
.38003 .14575 L
.38015 .14575 L
.38027 .14575 L
.3804 .14575 L
.38053 .14575 L
.38067 .14575 L
.38082 .14575 L
.38097 .14575 L
.38113 .14575 L
.3813 .14575 L
.38147 .14575 L
.38165 .14575 L
.38183 .14575 L
.38202 .14575 L
.38222 .14575 L
.38243 .14575 L
.38264 .14575 L
s
.40005 .14575 m
.40007 .14575 L
.4001 .14575 L
.40013 .14575 L
.40017 .14575 L
.40022 .14575 L
.40027 .14575 L
.40033 .14575 L
.4004 .14575 L
.40047 .14575 L
.40055 .14575 L
.40063 .14575 L
.40072 .14575 L
.40082 .14575 L
.40092 .14575 L
.40103 .14575 L
.40114 .14575 L
.40126 .14575 L
.40139 .14575 L
.40152 .14575 L
.40166 .14575 L
.4018 .14575 L
.40195 .14575 L
.40211 .14575 L
.40227 .14575 L
.40244 .14575 L
.40262 .14575 L
.4028 .14575 L
.40299 .14575 L
.40318 .14575 L
.40338 .14575 L
s
.42098 .14575 m
.421 .14575 L
.42103 .14575 L
.42106 .14575 L
.4211 .14575 L
.42114 .14575 L
.42119 .14575 L
.42125 .14575 L
.42131 .14575 L
.42138 .14575 L
.42145 .14575 L
.42153 .14575 L
.42161 .14575 L
.4217 .14575 L
.4218 .14575 L
.4219 .14575 L
.42201 .14575 L
.42212 .14575 L
.42224 .14575 L
.42237 .14575 L
.4225 .14575 L
.42264 .14575 L
.42278 .14575 L
.42293 .14575 L
.42308 .14575 L
.42324 .14575 L
.42341 .14575 L
.42358 .14575 L
.42375 .14575 L
.42394 .14575 L
.42413 .14575 L
s
.44192 .14575 m
.44193 .14575 L
.44196 .14575 L
.44199 .14575 L
.44203 .14575 L
.44207 .14575 L
.44211 .14575 L
.44217 .14575 L
.44222 .14575 L
.44229 .14575 L
.44236 .14575 L
.44243 .14575 L
.44251 .14575 L
.44259 .14575 L
.44268 .14575 L
.44278 .14575 L
.44288 .14575 L
.44299 .14575 L
.4431 .14575 L
.44322 .14575 L
.44334 .14575 L
.44347 .14575 L
.4436 .14575 L
.44374 .14575 L
.44389 .14575 L
.44404 .14575 L
.44419 .14575 L
.44435 .14575 L
.44452 .14575 L
.44469 .14575 L
.44487 .14575 L
s
.46285 .14575 m
.46287 .14575 L
.46289 .14575 L
.46292 .14575 L
.46295 .14575 L
.46299 .14575 L
.46303 .14575 L
.46308 .14575 L
.46314 .14575 L
.4632 .14575 L
.46326 .14575 L
.46333 .14575 L
.4634 .14575 L
.46348 .14575 L
.46357 .14575 L
.46366 .14575 L
.46375 .14575 L
.46385 .14575 L
.46396 .14575 L
.46407 .14575 L
.46418 .14575 L
.4643 .14575 L
.46443 .14575 L
.46456 .14575 L
.46469 .14575 L
.46483 .14575 L
.46498 .14575 L
.46513 .14575 L
.46528 .14575 L
.46544 .14575 L
.46561 .14575 L
s
.48378 .14575 m
.4838 .14575 L
.48382 .14575 L
.48385 .14575 L
.48388 .14575 L
.48391 .14575 L
.48395 .14575 L
.484 .14575 L
.48405 .14575 L
.48411 .14575 L
.48416 .14575 L
.48423 .14575 L
.4843 .14575 L
.48437 .14575 L
.48445 .14575 L
.48453 .14575 L
.48462 .14575 L
.48472 .14575 L
.48481 .14575 L
.48492 .14575 L
.48502 .14575 L
.48513 .14575 L
.48525 .14575 L
.48537 .14575 L
.4855 .14575 L
.48563 .14575 L
.48576 .14575 L
.4859 .14575 L
.48605 .14575 L
.4862 .14575 L
.48635 .14575 L
s
.50471 .14575 m
.50473 .14575 L
.50475 .14575 L
.50477 .14575 L
.5048 .14575 L
.50484 .14575 L
.50487 .14575 L
.50492 .14575 L
.50496 .14575 L
.50501 .14575 L
.50507 .14575 L
.50513 .14575 L
.50519 .14575 L
.50526 .14575 L
.50533 .14575 L
.50541 .14575 L
.50549 .14575 L
.50558 .14575 L
.50567 .14575 L
.50576 .14575 L
.50586 .14575 L
.50597 .14575 L
.50607 .14575 L
.50619 .14575 L
.5063 .14575 L
.50642 .14575 L
.50655 .14575 L
.50668 .14575 L
.50681 .14575 L
.50695 .14575 L
.5071 .14575 L
s
.52565 .14575 m
.52566 .14575 L
.52568 .14575 L
.5257 .14575 L
.52573 .14575 L
.52576 .14575 L
.52579 .14575 L
.52583 .14575 L
.52588 .14575 L
.52592 .14575 L
.52597 .14575 L
.52603 .14575 L
.52609 .14575 L
.52615 .14575 L
.52622 .14575 L
.52629 .14575 L
.52636 .14575 L
.52644 .14575 L
.52653 .14575 L
.52661 .14575 L
.5267 .14575 L
.5268 .14575 L
.5269 .14575 L
.527 .14575 L
.52711 .14575 L
.52722 .14575 L
.52734 .14575 L
.52746 .14575 L
.52758 .14575 L
.52771 .14575 L
.52784 .14575 L
s
.54658 .14575 m
.54659 .14575 L
.54661 .14575 L
.54663 .14575 L
.54666 .14575 L
.54668 .14575 L
.54671 .14575 L
.54675 .14575 L
.54679 .14575 L
.54683 .14575 L
.54688 .14575 L
.54693 .14575 L
.54698 .14575 L
.54704 .14575 L
.5471 .14575 L
.54717 .14575 L
.54723 .14575 L
.54731 .14575 L
.54738 .14575 L
.54746 .14575 L
.54755 .14575 L
.54763 .14575 L
.54772 .14575 L
.54782 .14575 L
.54792 .14575 L
.54802 .14575 L
.54812 .14575 L
.54823 .14575 L
.54834 .14575 L
.54846 .14575 L
.54858 .14575 L
s
.56751 .14575 m
.56753 .14575 L
.56754 .14575 L
.56756 .14575 L
.56758 .14575 L
.56761 .14575 L
.56764 .14575 L
.56767 .14575 L
.5677 .14575 L
.56774 .14575 L
.56778 .14575 L
.56783 .14575 L
.56788 .14575 L
.56793 .14575 L
.56798 .14575 L
.56804 .14575 L
.56811 .14575 L
.56817 .14575 L
.56824 .14575 L
.56831 .14575 L
.56839 .14575 L
.56847 .14575 L
.56855 .14575 L
.56863 .14575 L
.56872 .14575 L
.56881 .14575 L
.56891 .14575 L
.56901 .14575 L
.56911 .14575 L
.56921 .14575 L
.56932 .14575 L
s
.58845 .14575 m
.58846 .14575 L
.58847 .14575 L
.58849 .14575 L
.58851 .14575 L
.58853 .14575 L
.58856 .14575 L
.58858 .14575 L
.58862 .14575 L
.58865 .14575 L
.58869 .14575 L
.58873 .14575 L
.58877 .14575 L
.58882 .14575 L
.58887 .14575 L
.58892 .14575 L
.58898 .14575 L
.58903 .14575 L
.5891 .14575 L
.58916 .14575 L
.58923 .14575 L
.5893 .14575 L
.58937 .14575 L
.58945 .14575 L
.58953 .14575 L
.58961 .14575 L
.5897 .14575 L
.58978 .14575 L
.58987 .14575 L
.58997 .14575 L
.59007 .14575 L
s
.60938 .14575 m
.60939 .14575 L
.6094 .14575 L
.60942 .14575 L
.60943 .14575 L
.60945 .14575 L
.60948 .14575 L
.6095 .14575 L
.60953 .14575 L
.60956 .14575 L
.60959 .14575 L
.60963 .14575 L
.60967 .14575 L
.60971 .14575 L
.60975 .14575 L
.6098 .14575 L
.60985 .14575 L
.6099 .14575 L
.60995 .14575 L
.61001 .14575 L
.61007 .14575 L
.61013 .14575 L
.6102 .14575 L
.61026 .14575 L
.61033 .14575 L
.61041 .14575 L
.61048 .14575 L
.61056 .14575 L
.61064 .14575 L
.61072 .14575 L
.61081 .14575 L
s
.63031 .14575 m
.63032 .14575 L
.63033 .14575 L
.63034 .14575 L
.63036 .14575 L
.63038 .14575 L
.6304 .14575 L
.63042 .14575 L
.63044 .14575 L
.63047 .14575 L
.6305 .14575 L
.63053 .14575 L
.63056 .14575 L
.6306 .14575 L
.63063 .14575 L
.63067 .14575 L
.63072 .14575 L
.63076 .14575 L
.63081 .14575 L
.63086 .14575 L
.63091 .14575 L
.63096 .14575 L
.63102 .14575 L
.63108 .14575 L
.63114 .14575 L
.6312 .14575 L
.63127 .14575 L
.63134 .14575 L
.6314 .14575 L
.63148 .14575 L
.63155 .14575 L
s
.65124 .14575 m
.65125 .14575 L
.65126 .14575 L
.65127 .14575 L
.65128 .14575 L
.6513 .14575 L
.65132 .14575 L
.65133 .14575 L
.65135 .14575 L
.65138 .14575 L
.6514 .14575 L
.65143 .14575 L
.65146 .14575 L
.65149 .14575 L
.65152 .14575 L
.65155 .14575 L
.65159 .14575 L
.65163 .14575 L
.65167 .14575 L
.65171 .14575 L
.65175 .14575 L
.6518 .14575 L
.65184 .14575 L
.65189 .14575 L
.65195 .14575 L
.652 .14575 L
.65205 .14575 L
.65211 .14575 L
.65217 .14575 L
.65223 .14575 L
.65229 .14575 L
s
.67218 .14575 m
.67218 .14575 L
.67219 .14575 L
.6722 .14575 L
.67221 .14575 L
.67222 .14575 L
.67224 .14575 L
.67225 .14575 L
.67227 .14575 L
.67229 .14575 L
.67231 .14575 L
.67233 .14575 L
.67235 .14575 L
.67238 .14575 L
.6724 .14575 L
.67243 .14575 L
.67246 .14575 L
.67249 .14575 L
.67252 .14575 L
.67256 .14575 L
.67259 .14575 L
.67263 .14575 L
.67267 .14575 L
.67271 .14575 L
.67275 .14575 L
.67279 .14575 L
.67284 .14575 L
.67289 .14575 L
.67294 .14575 L
.67299 .14575 L
.67304 .14575 L
s
.69311 .14575 m
.69312 .14575 L
.69312 .14575 L
.69313 .14575 L
.69314 .14575 L
.69315 .14575 L
.69316 .14575 L
.69317 .14575 L
.69318 .14575 L
.6932 .14575 L
.69321 .14575 L
.69323 .14575 L
.69325 .14575 L
.69326 .14575 L
.69329 .14575 L
.69331 .14575 L
.69333 .14575 L
.69335 .14575 L
.69338 .14575 L
.69341 .14575 L
.69343 .14575 L
.69346 .14575 L
.69349 .14575 L
.69352 .14575 L
.69356 .14575 L
.69359 .14575 L
.69363 .14575 L
.69366 .14575 L
.6937 .14575 L
.69374 .14575 L
.69378 .14575 L
s
.71404 .14575 m
.71405 .14575 L
.71405 .14575 L
.71406 .14575 L
.71406 .14575 L
.71407 .14575 L
.71408 .14575 L
.71408 .14575 L
.71409 .14575 L
.7141 .14575 L
.71412 .14575 L
.71413 .14575 L
.71414 .14575 L
.71415 .14575 L
.71417 .14575 L
.71418 .14575 L
.7142 .14575 L
.71422 .14575 L
.71424 .14575 L
.71425 .14575 L
.71427 .14575 L
.7143 .14575 L
.71432 .14575 L
.71434 .14575 L
.71436 .14575 L
.71439 .14575 L
.71441 .14575 L
.71444 .14575 L
.71447 .14575 L
.71449 .14575 L
.71452 .14575 L
s
.73498 .14575 m
.73498 .14575 L
.73498 .14575 L
.73498 .14575 L
.73499 .14575 L
.73499 .14575 L
.735 .14575 L
.735 .14575 L
.73501 .14575 L
.73501 .14575 L
.73502 .14575 L
.73503 .14575 L
.73503 .14575 L
.73504 .14575 L
.73505 .14575 L
.73506 .14575 L
.73507 .14575 L
.73508 .14575 L
.73509 .14575 L
.7351 .14575 L
.73512 .14575 L
.73513 .14575 L
.73514 .14575 L
.73515 .14575 L
.73517 .14575 L
.73518 .14575 L
.7352 .14575 L
.73521 .14575 L
.73523 .14575 L
.73525 .14575 L
.73526 .14575 L
s
.75591 .14575 m
.75591 .14575 L
.75591 .14575 L
.75591 .14575 L
.75591 .14575 L
.75591 .14575 L
.75592 .14575 L
.75592 .14575 L
.75592 .14575 L
.75592 .14575 L
.75592 .14575 L
.75593 .14575 L
.75593 .14575 L
.75593 .14575 L
.75594 .14575 L
.75594 .14575 L
.75594 .14575 L
.75595 .14575 L
.75595 .14575 L
.75595 .14575 L
.75596 .14575 L
.75596 .14575 L
.75597 .14575 L
.75597 .14575 L
.75597 .14575 L
.75598 .14575 L
.75599 .14575 L
.75599 .14575 L
.756 .14575 L
.756 .14575 L
.75601 .14575 L
s
.77675 .14575 m
.77676 .14575 L
.77676 .14575 L
.77677 .14575 L
.77677 .14575 L
.77678 .14575 L
.77678 .14575 L
.77679 .14575 L
.77679 .14575 L
.77679 .14575 L
.7768 .14575 L
.7768 .14575 L
.77681 .14575 L
.77681 .14575 L
.77681 .14575 L
.77682 .14575 L
.77682 .14575 L
.77682 .14575 L
.77682 .14575 L
.77683 .14575 L
.77683 .14575 L
.77683 .14575 L
.77683 .14575 L
.77683 .14575 L
.77684 .14575 L
.77684 .14575 L
.77684 .14575 L
.77684 .14575 L
.77684 .14575 L
.77684 .14575 L
.77684 .14575 L
s
.79749 .14575 m
.79751 .14575 L
.79753 .14575 L
.79754 .14575 L
.79756 .14575 L
.79757 .14575 L
.79759 .14575 L
.7976 .14575 L
.79761 .14575 L
.79763 .14575 L
.79764 .14575 L
.79765 .14575 L
.79766 .14575 L
.79767 .14575 L
.79768 .14575 L
.79769 .14575 L
.7977 .14575 L
.79771 .14575 L
.79772 .14575 L
.79773 .14575 L
.79773 .14575 L
.79774 .14575 L
.79775 .14575 L
.79775 .14575 L
.79776 .14575 L
.79776 .14575 L
.79777 .14575 L
.79777 .14575 L
.79777 .14575 L
.79777 .14575 L
.79778 .14575 L
s
.81824 .14575 m
.81826 .14575 L
.81829 .14575 L
.81832 .14575 L
.81834 .14575 L
.81837 .14575 L
.81839 .14575 L
.81842 .14575 L
.81844 .14575 L
.81846 .14575 L
.81848 .14575 L
.8185 .14575 L
.81852 .14575 L
.81854 .14575 L
.81855 .14575 L
.81857 .14575 L
.81859 .14575 L
.8186 .14575 L
.81861 .14575 L
.81863 .14575 L
.81864 .14575 L
.81865 .14575 L
.81866 .14575 L
.81867 .14575 L
.81868 .14575 L
.81868 .14575 L
.81869 .14575 L
.8187 .14575 L
.8187 .14575 L
.81871 .14575 L
.81871 .14575 L
s
.82918 .14575 m
.82896 .14575 L
.82874 .14575 L
.82852 .14575 L
.8283 .14575 L
.82808 .14575 L
.82786 .14575 L
.82764 .14575 L
.82742 .14575 L
.8272 .14575 L
.82699 .14575 L
.82677 .14575 L
.82655 .14575 L
.82633 .14575 L
.82611 .14575 L
.8259 .14575 L
.82568 .14575 L
.82546 .14575 L
.82524 .14575 L
.82503 .14575 L
.82481 .14575 L
.82459 .14575 L
.82438 .14575 L
.82416 .14575 L
.82394 .14575 L
.82373 .14575 L
.82351 .14575 L
.82329 .14575 L
.82308 .14575 L
.82286 .14575 L
.82265 .14575 L
s
.82799 .14575 m
.82771 .14575 L
.82743 .14575 L
.82715 .14575 L
.82686 .14575 L
.82658 .14575 L
.8263 .14575 L
.82602 .14575 L
.82574 .14575 L
.82546 .14575 L
.82518 .14575 L
.8249 .14575 L
.82461 .14575 L
.82433 .14575 L
.82405 .14575 L
.82377 .14575 L
.82349 .14575 L
.82321 .14575 L
.82293 .14575 L
.82265 .14575 L
.82238 .14575 L
.8221 .14575 L
.82182 .14575 L
.82154 .14575 L
.82126 .14575 L
.82098 .14575 L
.8207 .14575 L
.82042 .14575 L
.82015 .14575 L
.81987 .14575 L
.81959 .14575 L
s
.82681 .14575 m
.82646 .14575 L
.82612 .14575 L
.82577 .14575 L
.82543 .14575 L
.82508 .14575 L
.82474 .14575 L
.8244 .14575 L
.82405 .14575 L
.82371 .14575 L
.82337 .14575 L
.82302 .14575 L
.82268 .14575 L
.82234 .14575 L
.82199 .14575 L
.82165 .14575 L
.82131 .14575 L
.82097 .14575 L
.82062 .14575 L
.82028 .14575 L
.81994 .14575 L
.8196 .14575 L
.81926 .14575 L
.81892 .14575 L
.81858 .14575 L
.81824 .14575 L
.8179 .14575 L
.81756 .14575 L
.81722 .14575 L
.81688 .14575 L
.81654 .14575 L
s
.82563 .14575 m
.82522 .14575 L
.82481 .14575 L
.8244 .14575 L
.82399 .14575 L
.82359 .14575 L
.82318 .14575 L
.82277 .14575 L
.82237 .14575 L
.82196 .14575 L
.82155 .14575 L
.82115 .14575 L
.82074 .14575 L
.82034 .14575 L
.81993 .14575 L
.81953 .14575 L
.81912 .14575 L
.81872 .14575 L
.81831 .14575 L
.81791 .14575 L
.81751 .14575 L
.8171 .14575 L
.8167 .14575 L
.8163 .14575 L
.81589 .14575 L
.81549 .14575 L
.81509 .14575 L
.81469 .14575 L
.81428 .14575 L
.81388 .14575 L
.81348 .14575 L
s
.82444 .14575 m
.82397 .14575 L
.8235 .14575 L
.82303 .14575 L
.82256 .14575 L
.82209 .14575 L
.82162 .14575 L
.82115 .14575 L
.82068 .14575 L
.82021 .14575 L
.81974 .14575 L
.81928 .14575 L
.81881 .14575 L
.81834 .14575 L
.81787 .14575 L
.8174 .14575 L
.81694 .14575 L
.81647 .14575 L
.816 .14575 L
.81554 .14575 L
.81507 .14575 L
.81461 .14575 L
.81414 .14575 L
.81368 .14575 L
.81321 .14575 L
.81275 .14575 L
.81228 .14575 L
.81182 .14575 L
.81135 .14575 L
.81089 .14575 L
.81043 .14575 L
s
.82326 .14575 m
.82273 .14575 L
.82219 .14575 L
.82166 .14575 L
.82113 .14575 L
.82059 .14575 L
.82006 .14575 L
.81953 .14575 L
.819 .14575 L
.81847 .14575 L
.81793 .14575 L
.8174 .14575 L
.81687 .14575 L
.81634 .14575 L
.81581 .14575 L
.81528 .14575 L
.81475 .14575 L
.81422 .14575 L
.81369 .14575 L
.81317 .14575 L
.81264 .14575 L
.81211 .14575 L
.81158 .14575 L
.81105 .14575 L
.81053 .14575 L
.81 .14575 L
.80947 .14575 L
.80895 .14575 L
.80842 .14575 L
.8079 .14575 L
.80737 .14575 L
s
.82208 .14575 m
.82148 .14575 L
.82088 .14575 L
.82029 .14575 L
.81969 .14575 L
.8191 .14575 L
.8185 .14575 L
.81791 .14575 L
.81731 .14575 L
.81672 .14575 L
.81612 .14575 L
.81553 .14575 L
.81494 .14575 L
.81434 .14575 L
.81375 .14575 L
.81316 .14575 L
.81257 .14575 L
.81198 .14575 L
.81138 .14575 L
.81079 .14575 L
.8102 .14575 L
.80961 .14575 L
.80902 .14575 L
.80843 .14575 L
.80784 .14575 L
.80726 .14575 L
.80667 .14575 L
.80608 .14575 L
.80549 .14575 L
.8049 .14575 L
.80432 .14575 L
s
.82089 .14575 m
.82023 .14575 L
.81958 .14575 L
.81892 .14575 L
.81826 .14575 L
.8176 .14575 L
.81694 .14575 L
.81628 .14575 L
.81563 .14575 L
.81497 .14575 L
.81431 .14575 L
.81366 .14575 L
.813 .14575 L
.81235 .14575 L
.81169 .14575 L
.81104 .14575 L
.81038 .14575 L
.80973 .14575 L
.80907 .14575 L
.80842 .14575 L
.80777 .14575 L
.80712 .14575 L
.80646 .14575 L
.80581 .14575 L
.80516 .14575 L
.80451 .14575 L
.80386 .14575 L
.80321 .14575 L
.80256 .14575 L
.80191 .14575 L
.80126 .14575 L
s
.81971 .14575 m
.81899 .14575 L
.81827 .14575 L
.81754 .14575 L
.81682 .14575 L
.8161 .14575 L
.81538 .14575 L
.81466 .14575 L
.81394 .14575 L
.81322 .14575 L
.8125 .14575 L
.81178 .14575 L
.81107 .14575 L
.81035 .14575 L
.80963 .14575 L
.80891 .14575 L
.8082 .14575 L
.80748 .14575 L
.80676 .14575 L
.80605 .14575 L
.80533 .14575 L
.80462 .14575 L
.80391 .14575 L
.80319 .14575 L
.80248 .14575 L
.80177 .14575 L
.80105 .14575 L
.80034 .14575 L
.79963 .14575 L
.79892 .14575 L
.79821 .14575 L
s
.81853 .14575 m
.81774 .14575 L
.81696 .14575 L
.81617 .14575 L
.81539 .14575 L
.8146 .14575 L
.81382 .14575 L
.81304 .14575 L
.81226 .14575 L
.81147 .14575 L
.81069 .14575 L
.80991 .14575 L
.80913 .14575 L
.80835 .14575 L
.80757 .14575 L
.80679 .14575 L
.80601 .14575 L
.80523 .14575 L
.80445 .14575 L
.80368 .14575 L
.8029 .14575 L
.80212 .14575 L
.80135 .14575 L
.80057 .14575 L
.7998 .14575 L
.79902 .14575 L
.79825 .14575 L
.79747 .14575 L
.7967 .14575 L
.79593 .14575 L
.79515 .14575 L
s
.81735 .14575 m
.8165 .14575 L
.81565 .14575 L
.8148 .14575 L
.81395 .14575 L
.81311 .14575 L
.81226 .14575 L
.81142 .14575 L
.81057 .14575 L
.80973 .14575 L
.80888 .14575 L
.80804 .14575 L
.80719 .14575 L
.80635 .14575 L
.80551 .14575 L
.80467 .14575 L
.80383 .14575 L
.80299 .14575 L
.80214 .14575 L
.8013 .14575 L
.80047 .14575 L
.79963 .14575 L
.79879 .14575 L
.79795 .14575 L
.79711 .14575 L
.79628 .14575 L
.79544 .14575 L
.7946 .14575 L
.79377 .14575 L
.79293 .14575 L
.7921 .14575 L
s
0 0 0 r
.0239 .14575 m
.26068 .14575 L
s
% Start of user PostScript
0 0 50.9716 0 MAarrowhead1
% End of user PostScript
.26068 .14575 m
.30262 .14575 L
s
% Start of user PostScript
50.9716 0 60. 0 MAarrowhead1
% End of user PostScript
.30262 .14575 m
.82715 .14575 L
s
% Start of user PostScript
60. 0 172.915 0 MAarrowhead1
% End of user PostScript
.82715 .14575 m
.80254 .14575 L
s
% Start of user PostScript
172.915 0 167.619 0 MAarrowhead1
% End of user PostScript
.80254 .14575 m
.80254 .14575 L
s
% Start of user PostScript
167.619 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .12484 m
.02382 .12624 L
.02383 .12763 L
.02384 .12902 L
.02385 .13042 L
.02386 .13181 L
.02387 .1332 L
.02387 .1346 L
.02388 .13599 L
.02388 .13739 L
.02389 .13878 L
.02389 .14017 L
.02389 .14157 L
.0239 .14296 L
.0239 .14435 L
.0239 .14575 L
.0239 .14714 L
.0239 .14853 L
.02389 .14993 L
.02389 .15132 L
.02389 .15272 L
.02388 .15411 L
.02388 .1555 L
.02387 .1569 L
.02387 .15829 L
.02386 .15968 L
.02385 .16108 L
.02384 .16247 L
.02383 .16386 L
.02382 .16526 L
.02381 .16665 L
s
.04479 .12475 m
.04481 .12615 L
.04482 .12755 L
.04483 .12895 L
.04484 .13035 L
.04484 .13175 L
.04485 .13315 L
.04486 .13455 L
.04486 .13595 L
.04487 .13735 L
.04487 .13875 L
.04488 .14015 L
.04488 .14155 L
.04488 .14295 L
.04488 .14435 L
.04488 .14575 L
.04488 .14715 L
.04488 .14855 L
.04488 .14995 L
.04488 .15135 L
.04487 .15275 L
.04487 .15415 L
.04486 .15555 L
.04486 .15695 L
.04485 .15835 L
.04484 .15975 L
.04484 .16115 L
.04483 .16255 L
.04482 .16395 L
.04481 .16535 L
.04479 .16675 L
s
.06578 .12465 m
.06579 .12606 L
.0658 .12747 L
.06581 .12887 L
.06582 .13028 L
.06583 .13169 L
.06584 .13309 L
.06584 .1345 L
.06585 .1359 L
.06585 .13731 L
.06586 .13872 L
.06586 .14012 L
.06586 .14153 L
.06587 .14293 L
.06587 .14434 L
.06587 .14575 L
.06587 .14715 L
.06587 .14856 L
.06586 .14997 L
.06586 .15137 L
.06586 .15278 L
.06585 .15418 L
.06585 .15559 L
.06584 .157 L
.06584 .1584 L
.06583 .15981 L
.06582 .16122 L
.06581 .16262 L
.0658 .16403 L
.06579 .16543 L
.06578 .16684 L
s
.08676 .12456 m
.08677 .12597 L
.08679 .12738 L
.0868 .1288 L
.0868 .13021 L
.08681 .13162 L
.08682 .13303 L
.08683 .13445 L
.08683 .13586 L
.08684 .13727 L
.08684 .13868 L
.08685 .1401 L
.08685 .14151 L
.08685 .14292 L
.08685 .14433 L
.08685 .14575 L
.08685 .14716 L
.08685 .14857 L
.08685 .14998 L
.08685 .1514 L
.08684 .15281 L
.08684 .15422 L
.08683 .15563 L
.08683 .15705 L
.08682 .15846 L
.08681 .15987 L
.0868 .16128 L
.0868 .1627 L
.08679 .16411 L
.08677 .16552 L
.08676 .16693 L
s
.10775 .12447 m
.10776 .12588 L
.10777 .1273 L
.10778 .12872 L
.10779 .13014 L
.1078 .13156 L
.10781 .13298 L
.10781 .1344 L
.10782 .13582 L
.10782 .13723 L
.10783 .13865 L
.10783 .14007 L
.10783 .14149 L
.10784 .14291 L
.10784 .14433 L
.10784 .14575 L
.10784 .14717 L
.10784 .14858 L
.10783 .15 L
.10783 .15142 L
.10783 .15284 L
.10782 .15426 L
.10782 .15568 L
.10781 .1571 L
.10781 .15852 L
.1078 .15994 L
.10779 .16135 L
.10778 .16277 L
.10777 .16419 L
.10776 .16561 L
.10775 .16703 L
s
.12873 .12437 m
.12874 .1258 L
.12875 .12722 L
.12876 .12865 L
.12877 .13007 L
.12878 .1315 L
.12879 .13292 L
.1288 .13435 L
.1288 .13577 L
.12881 .1372 L
.12881 .13862 L
.12882 .14005 L
.12882 .14147 L
.12882 .1429 L
.12882 .14432 L
.12882 .14575 L
.12882 .14717 L
.12882 .1486 L
.12882 .15002 L
.12882 .15145 L
.12881 .15287 L
.12881 .1543 L
.1288 .15572 L
.1288 .15715 L
.12879 .15857 L
.12878 .16 L
.12877 .16142 L
.12876 .16285 L
.12875 .16427 L
.12874 .1657 L
.12873 .16712 L
s
.14972 .12428 m
.14973 .12571 L
.14974 .12714 L
.14975 .12857 L
.14976 .13 L
.14977 .13143 L
.14977 .13286 L
.14978 .1343 L
.14979 .13573 L
.14979 .13716 L
.1498 .13859 L
.1498 .14002 L
.1498 .14145 L
.14981 .14288 L
.14981 .14432 L
.14981 .14575 L
.14981 .14718 L
.14981 .14861 L
.1498 .15004 L
.1498 .15147 L
.1498 .1529 L
.14979 .15434 L
.14979 .15577 L
.14978 .1572 L
.14977 .15863 L
.14977 .16006 L
.14976 .16149 L
.14975 .16292 L
.14974 .16436 L
.14973 .16579 L
.14972 .16722 L
s
.1707 .12418 m
.17071 .12562 L
.17072 .12706 L
.17073 .1285 L
.17074 .12993 L
.17075 .13137 L
.17076 .13281 L
.17077 .13425 L
.17077 .13568 L
.17078 .13712 L
.17078 .13856 L
.17079 .14 L
.17079 .14143 L
.17079 .14287 L
.17079 .14431 L
.17079 .14575 L
.17079 .14718 L
.17079 .14862 L
.17079 .15006 L
.17079 .1515 L
.17078 .15294 L
.17078 .15437 L
.17077 .15581 L
.17077 .15725 L
.17076 .15869 L
.17075 .16012 L
.17074 .16156 L
.17073 .163 L
.17072 .16444 L
.17071 .16587 L
.1707 .16731 L
s
.19169 .12409 m
.1917 .12553 L
.19171 .12698 L
.19172 .12842 L
.19173 .12986 L
.19174 .13131 L
.19174 .13275 L
.19175 .1342 L
.19176 .13564 L
.19176 .13708 L
.19177 .13853 L
.19177 .13997 L
.19177 .14142 L
.19178 .14286 L
.19178 .1443 L
.19178 .14575 L
.19178 .14719 L
.19178 .14864 L
.19177 .15008 L
.19177 .15152 L
.19177 .15297 L
.19176 .15441 L
.19176 .15585 L
.19175 .1573 L
.19174 .15874 L
.19174 .16019 L
.19173 .16163 L
.19172 .16307 L
.19171 .16452 L
.1917 .16596 L
.19169 .16741 L
s
.21267 .12399 m
.21268 .12544 L
.21269 .12689 L
.2127 .12834 L
.21271 .12979 L
.21272 .13124 L
.21273 .13269 L
.21274 .13415 L
.21274 .1356 L
.21275 .13705 L
.21275 .1385 L
.21276 .13995 L
.21276 .1414 L
.21276 .14285 L
.21276 .1443 L
.21276 .14575 L
.21276 .1472 L
.21276 .14865 L
.21276 .1501 L
.21276 .15155 L
.21275 .153 L
.21275 .15445 L
.21274 .1559 L
.21274 .15735 L
.21273 .1588 L
.21272 .16025 L
.21271 .1617 L
.2127 .16315 L
.21269 .1646 L
.21268 .16605 L
.21267 .1675 L
s
.23365 .1239 m
.23367 .12536 L
.23368 .12681 L
.23369 .12827 L
.2337 .12973 L
.23371 .13118 L
.23371 .13264 L
.23372 .13409 L
.23373 .13555 L
.23373 .13701 L
.23374 .13846 L
.23374 .13992 L
.23374 .14138 L
.23375 .14283 L
.23375 .14429 L
.23375 .14575 L
.23375 .1472 L
.23375 .14866 L
.23374 .15012 L
.23374 .15157 L
.23374 .15303 L
.23373 .15449 L
.23373 .15594 L
.23372 .1574 L
.23371 .15886 L
.23371 .16031 L
.2337 .16177 L
.23369 .16323 L
.23368 .16468 L
.23367 .16614 L
.23365 .1676 L
s
.25464 .1238 m
.25465 .12527 L
.25466 .12673 L
.25467 .12819 L
.25468 .12966 L
.25469 .13112 L
.2547 .13258 L
.25471 .13404 L
.25471 .13551 L
.25472 .13697 L
.25472 .13843 L
.25473 .1399 L
.25473 .14136 L
.25473 .14282 L
.25473 .14428 L
.25473 .14575 L
.25473 .14721 L
.25473 .14867 L
.25473 .15014 L
.25473 .1516 L
.25472 .15306 L
.25472 .15452 L
.25471 .15599 L
.25471 .15745 L
.2547 .15891 L
.25469 .16038 L
.25468 .16184 L
.25467 .1633 L
.25466 .16476 L
.25465 .16623 L
.25464 .16769 L
s
.27606 .12421 m
.27601 .12564 L
.27597 .12708 L
.27593 .12851 L
.27589 .12995 L
.27585 .13139 L
.27582 .13282 L
.27579 .13426 L
.27577 .1357 L
.27574 .13713 L
.27573 .13857 L
.27571 .14 L
.2757 .14144 L
.27569 .14288 L
.27569 .14431 L
.27568 .14575 L
.27569 .14718 L
.27569 .14862 L
.2757 .15006 L
.27571 .15149 L
.27573 .15293 L
.27574 .15436 L
.27577 .1558 L
.27579 .15724 L
.27582 .15867 L
.27585 .16011 L
.27589 .16154 L
.27593 .16298 L
.27597 .16442 L
.27601 .16585 L
.27606 .16729 L
s
.29699 .12481 m
.29694 .1262 L
.2969 .1276 L
.29686 .12899 L
.29682 .13039 L
.29679 .13179 L
.29675 .13318 L
.29673 .13458 L
.2967 .13597 L
.29668 .13737 L
.29666 .13877 L
.29665 .14016 L
.29664 .14156 L
.29663 .14296 L
.29662 .14435 L
.29662 .14575 L
.29662 .14714 L
.29663 .14854 L
.29664 .14994 L
.29665 .15133 L
.29666 .15273 L
.29668 .15412 L
.2967 .15552 L
.29673 .15692 L
.29675 .15831 L
.29679 .15971 L
.29682 .1611 L
.29686 .1625 L
.2969 .1639 L
.29694 .16529 L
.29699 .16669 L
s
.31833 .12563 m
.31823 .12697 L
.31813 .12831 L
.31804 .12965 L
.31795 .13099 L
.31788 .13233 L
.31781 .13367 L
.31775 .13502 L
.31769 .13636 L
.31765 .1377 L
.31761 .13904 L
.31757 .14038 L
.31755 .14172 L
.31753 .14306 L
.31752 .14441 L
.31752 .14575 L
.31752 .14709 L
.31753 .14843 L
.31755 .14977 L
.31757 .15111 L
.31761 .15245 L
.31765 .1538 L
.31769 .15514 L
.31775 .15648 L
.31781 .15782 L
.31788 .15916 L
.31795 .1605 L
.31804 .16184 L
.31813 .16319 L
.31823 .16453 L
.31833 .16587 L
s
.33917 .12654 m
.33907 .12782 L
.33898 .1291 L
.33889 .13038 L
.33881 .13166 L
.33874 .13294 L
.33867 .13422 L
.33862 .1355 L
.33856 .13678 L
.33852 .13806 L
.33848 .13934 L
.33845 .14062 L
.33842 .1419 L
.33841 .14319 L
.3384 .14447 L
.33839 .14575 L
.3384 .14703 L
.33841 .14831 L
.33842 .14959 L
.33845 .15087 L
.33848 .15215 L
.33852 .15343 L
.33856 .15471 L
.33862 .15599 L
.33867 .15727 L
.33874 .15855 L
.33881 .15984 L
.33889 .16112 L
.33898 .1624 L
.33907 .16368 L
.33917 .16496 L
s
.36001 .12745 m
.35992 .12867 L
.35983 .12989 L
.35975 .13111 L
.35967 .13233 L
.3596 .13355 L
.35954 .13477 L
.35948 .13599 L
.35943 .13721 L
.35939 .13843 L
.35935 .13965 L
.35932 .14087 L
.3593 .14209 L
.35928 .14331 L
.35927 .14453 L
.35927 .14575 L
.35927 .14697 L
.35928 .14819 L
.3593 .14941 L
.35932 .15063 L
.35935 .15185 L
.35939 .15307 L
.35943 .15429 L
.35948 .15551 L
.35954 .15673 L
.3596 .15795 L
.35967 .15917 L
.35975 .16039 L
.35983 .16161 L
.35992 .16283 L
.36001 .16405 L
s
.38085 .12835 m
.38076 .12951 L
.38068 .13067 L
.3806 .13183 L
.38053 .13299 L
.38046 .13415 L
.3804 .13531 L
.38035 .13647 L
.3803 .13763 L
.38026 .13879 L
.38023 .13995 L
.3802 .14111 L
.38018 .14227 L
.38016 .14343 L
.38015 .14459 L
.38015 .14575 L
.38015 .14691 L
.38016 .14807 L
.38018 .14923 L
.3802 .15039 L
.38023 .15154 L
.38026 .1527 L
.3803 .15386 L
.38035 .15502 L
.3804 .15618 L
.38046 .15734 L
.38053 .1585 L
.3806 .15966 L
.38068 .16082 L
.38076 .16198 L
.38085 .16314 L
s
.40169 .12926 m
.40161 .13036 L
.40153 .13146 L
.40145 .13256 L
.40138 .13366 L
.40132 .13476 L
.40127 .13586 L
.40122 .13696 L
.40117 .13806 L
.40113 .13915 L
.4011 .14025 L
.40107 .14135 L
.40105 .14245 L
.40104 .14355 L
.40103 .14465 L
.40103 .14575 L
.40103 .14685 L
.40104 .14794 L
.40105 .14904 L
.40107 .15014 L
.4011 .15124 L
.40113 .15234 L
.40117 .15344 L
.40122 .15454 L
.40127 .15564 L
.40132 .15674 L
.40138 .15783 L
.40145 .15893 L
.40153 .16003 L
.40161 .16113 L
.40169 .16223 L
s
.42253 .13017 m
.42245 .13121 L
.42238 .13225 L
.42231 .13329 L
.42224 .13433 L
.42218 .13537 L
.42213 .1364 L
.42208 .13744 L
.42204 .13848 L
.422 .13952 L
.42197 .14056 L
.42195 .14159 L
.42193 .14263 L
.42191 .14367 L
.42191 .14471 L
.4219 .14575 L
.42191 .14679 L
.42191 .14782 L
.42193 .14886 L
.42195 .1499 L
.42197 .15094 L
.422 .15198 L
.42204 .15301 L
.42208 .15405 L
.42213 .15509 L
.42218 .15613 L
.42224 .15717 L
.42231 .15821 L
.42238 .15924 L
.42245 .16028 L
.42253 .16132 L
s
.44337 .13108 m
.4433 .13206 L
.44323 .13304 L
.44316 .13402 L
.4431 .13499 L
.44304 .13597 L
.44299 .13695 L
.44295 .13793 L
.44291 .1389 L
.44287 .13988 L
.44285 .14086 L
.44282 .14184 L
.4428 .14281 L
.44279 .14379 L
.44278 .14477 L
.44278 .14575 L
.44278 .14672 L
.44279 .1477 L
.4428 .14868 L
.44282 .14966 L
.44285 .15064 L
.44287 .15161 L
.44291 .15259 L
.44295 .15357 L
.44299 .15455 L
.44304 .15552 L
.4431 .1565 L
.44316 .15748 L
.44323 .15846 L
.4433 .15943 L
.44337 .16041 L
s
.46421 .13199 m
.46414 .13291 L
.46408 .13383 L
.46401 .13474 L
.46396 .13566 L
.4639 .13658 L
.46386 .13749 L
.46382 .13841 L
.46378 .13933 L
.46375 .14025 L
.46372 .14116 L
.4637 .14208 L
.46368 .143 L
.46367 .14391 L
.46366 .14483 L
.46366 .14575 L
.46366 .14666 L
.46367 .14758 L
.46368 .1485 L
.4637 .14941 L
.46372 .15033 L
.46375 .15125 L
.46378 .15217 L
.46382 .15308 L
.46386 .154 L
.4639 .15492 L
.46396 .15583 L
.46401 .15675 L
.46408 .15767 L
.46414 .15858 L
.46421 .1595 L
s
.48505 .1329 m
.48499 .13376 L
.48493 .13462 L
.48487 .13547 L
.48481 .13633 L
.48477 .13718 L
.48472 .13804 L
.48468 .1389 L
.48465 .13975 L
.48462 .14061 L
.48459 .14147 L
.48457 .14232 L
.48456 .14318 L
.48454 .14403 L
.48454 .14489 L
.48453 .14575 L
.48454 .1466 L
.48454 .14746 L
.48456 .14832 L
.48457 .14917 L
.48459 .15003 L
.48462 .15088 L
.48465 .15174 L
.48468 .1526 L
.48472 .15345 L
.48477 .15431 L
.48481 .15517 L
.48487 .15602 L
.48493 .15688 L
.48499 .15774 L
.48505 .15859 L
s
.5059 .13381 m
.50583 .13461 L
.50577 .1354 L
.50572 .1362 L
.50567 .137 L
.50563 .13779 L
.50559 .13859 L
.50555 .13938 L
.50552 .14018 L
.50549 .14097 L
.50547 .14177 L
.50545 .14256 L
.50543 .14336 L
.50542 .14416 L
.50541 .14495 L
.50541 .14575 L
.50541 .14654 L
.50542 .14734 L
.50543 .14813 L
.50545 .14893 L
.50547 .14973 L
.50549 .15052 L
.50552 .15132 L
.50555 .15211 L
.50559 .15291 L
.50563 .1537 L
.50567 .1545 L
.50572 .1553 L
.50577 .15609 L
.50583 .15689 L
.5059 .15768 L
s
.52674 .13472 m
.52668 .13546 L
.52662 .13619 L
.52657 .13693 L
.52653 .13766 L
.52649 .1384 L
.52645 .13913 L
.52642 .13987 L
.52639 .1406 L
.52636 .14134 L
.52634 .14207 L
.52632 .14281 L
.52631 .14354 L
.5263 .14428 L
.52629 .14501 L
.52629 .14575 L
.52629 .14648 L
.5263 .14722 L
.52631 .14795 L
.52632 .14869 L
.52634 .14942 L
.52636 .15016 L
.52639 .15089 L
.52642 .15163 L
.52645 .15236 L
.52649 .1531 L
.52653 .15383 L
.52657 .15457 L
.52662 .1553 L
.52668 .15604 L
.52674 .15677 L
s
.54758 .13563 m
.54752 .13631 L
.54747 .13698 L
.54743 .13765 L
.54739 .13833 L
.54735 .139 L
.54731 .13968 L
.54728 .14035 L
.54726 .14103 L
.54723 .1417 L
.54721 .14238 L
.5472 .14305 L
.54718 .14372 L
.54717 .1444 L
.54717 .14507 L
.54717 .14575 L
.54717 .14642 L
.54717 .1471 L
.54718 .14777 L
.5472 .14844 L
.54721 .14912 L
.54723 .14979 L
.54726 .15047 L
.54728 .15114 L
.54731 .15182 L
.54735 .15249 L
.54739 .15317 L
.54743 .15384 L
.54747 .15451 L
.54752 .15519 L
.54758 .15586 L
s
.56842 .13654 m
.56837 .13715 L
.56832 .13777 L
.56828 .13838 L
.56824 .139 L
.56821 .13961 L
.56818 .14022 L
.56815 .14084 L
.56812 .14145 L
.5681 .14206 L
.56808 .14268 L
.56807 .14329 L
.56806 .14391 L
.56805 .14452 L
.56804 .14513 L
.56804 .14575 L
.56804 .14636 L
.56805 .14697 L
.56806 .14759 L
.56807 .1482 L
.56808 .14882 L
.5681 .14943 L
.56812 .15004 L
.56815 .15066 L
.56818 .15127 L
.56821 .15188 L
.56824 .1525 L
.56828 .15311 L
.56832 .15373 L
.56837 .15434 L
.56842 .15495 L
s
.58926 .13745 m
.58921 .138 L
.58917 .13856 L
.58914 .13911 L
.5891 .13966 L
.58907 .14022 L
.58904 .14077 L
.58902 .14132 L
.58899 .14188 L
.58897 .14243 L
.58896 .14298 L
.58894 .14353 L
.58893 .14409 L
.58893 .14464 L
.58892 .14519 L
.58892 .14575 L
.58892 .1463 L
.58893 .14685 L
.58893 .14741 L
.58894 .14796 L
.58896 .14851 L
.58897 .14907 L
.58899 .14962 L
.58902 .15017 L
.58904 .15073 L
.58907 .15128 L
.5891 .15183 L
.58914 .15238 L
.58917 .15294 L
.58921 .15349 L
.58926 .15404 L
s
.6101 .13836 m
.61006 .13885 L
.61002 .13935 L
.60999 .13984 L
.60996 .14033 L
.60993 .14082 L
.60991 .14132 L
.60988 .14181 L
.60986 .1423 L
.60985 .14279 L
.60983 .14328 L
.60982 .14378 L
.60981 .14427 L
.6098 .14476 L
.6098 .14525 L
.6098 .14575 L
.6098 .14624 L
.6098 .14673 L
.60981 .14722 L
.60982 .14772 L
.60983 .14821 L
.60985 .1487 L
.60986 .14919 L
.60988 .14969 L
.60991 .15018 L
.60993 .15067 L
.60996 .15116 L
.60999 .15166 L
.61002 .15215 L
.61006 .15264 L
.6101 .15313 L
s
.63094 .13927 m
.6309 .1397 L
.63087 .14013 L
.63084 .14057 L
.63082 .141 L
.63079 .14143 L
.63077 .14186 L
.63075 .14229 L
.63073 .14272 L
.63072 .14316 L
.6307 .14359 L
.63069 .14402 L
.63069 .14445 L
.63068 .14488 L
.63068 .14532 L
.63067 .14575 L
.63068 .14618 L
.63068 .14661 L
.63069 .14704 L
.63069 .14747 L
.6307 .14791 L
.63072 .14834 L
.63073 .14877 L
.63075 .1492 L
.63077 .14963 L
.63079 .15007 L
.63082 .1505 L
.63084 .15093 L
.63087 .15136 L
.6309 .15179 L
.63094 .15222 L
s
.65178 .14018 m
.65175 .14055 L
.65172 .14092 L
.6517 .14129 L
.65167 .14166 L
.65165 .14204 L
.65163 .14241 L
.65162 .14278 L
.6516 .14315 L
.65159 .14352 L
.65158 .14389 L
.65157 .14426 L
.65156 .14463 L
.65156 .145 L
.65155 .14538 L
.65155 .14575 L
.65155 .14612 L
.65156 .14649 L
.65156 .14686 L
.65157 .14723 L
.65158 .1476 L
.65159 .14797 L
.6516 .14835 L
.65162 .14872 L
.65163 .14909 L
.65165 .14946 L
.65167 .14983 L
.6517 .1502 L
.65172 .15057 L
.65175 .15094 L
.65178 .15132 L
s
.67262 .14109 m
.67259 .1414 L
.67257 .14171 L
.67255 .14202 L
.67253 .14233 L
.67251 .14264 L
.6725 .14295 L
.67248 .14326 L
.67247 .14357 L
.67246 .14388 L
.67245 .14419 L
.67244 .14451 L
.67244 .14482 L
.67243 .14513 L
.67243 .14544 L
.67243 .14575 L
.67243 .14606 L
.67243 .14637 L
.67244 .14668 L
.67244 .14699 L
.67245 .1473 L
.67246 .14761 L
.67247 .14792 L
.67248 .14823 L
.6725 .14854 L
.67251 .14885 L
.67253 .14916 L
.67255 .14947 L
.67257 .14978 L
.67259 .15009 L
.67262 .15041 L
s
.69346 .142 m
.69344 .14225 L
.69342 .1425 L
.6934 .14275 L
.69339 .143 L
.69337 .14325 L
.69336 .1435 L
.69335 .14375 L
.69334 .144 L
.69333 .14425 L
.69332 .1445 L
.69332 .14475 L
.69331 .145 L
.69331 .14525 L
.69331 .1455 L
.69331 .14575 L
.69331 .146 L
.69331 .14625 L
.69331 .1465 L
.69332 .14675 L
.69332 .147 L
.69333 .14725 L
.69334 .1475 L
.69335 .14775 L
.69336 .148 L
.69337 .14825 L
.69339 .1485 L
.6934 .14875 L
.69342 .149 L
.69344 .14925 L
.69346 .1495 L
s
.7143 .14291 m
.71428 .1431 L
.71427 .14329 L
.71426 .14348 L
.71425 .14367 L
.71424 .14385 L
.71423 .14404 L
.71422 .14423 L
.71421 .14442 L
.7142 .14461 L
.7142 .1448 L
.71419 .14499 L
.71419 .14518 L
.71419 .14537 L
.71418 .14556 L
.71418 .14575 L
.71418 .14594 L
.71419 .14613 L
.71419 .14632 L
.71419 .1465 L
.7142 .14669 L
.7142 .14688 L
.71421 .14707 L
.71422 .14726 L
.71423 .14745 L
.71424 .14764 L
.71425 .14783 L
.71426 .14802 L
.71427 .14821 L
.71428 .1484 L
.7143 .14859 L
s
.73514 .14382 m
.73513 .14395 L
.73512 .14407 L
.73511 .1442 L
.7351 .14433 L
.7351 .14446 L
.73509 .14459 L
.73508 .14472 L
.73508 .14485 L
.73507 .14498 L
.73507 .1451 L
.73507 .14523 L
.73506 .14536 L
.73506 .14549 L
.73506 .14562 L
.73506 .14575 L
.73506 .14588 L
.73506 .146 L
.73506 .14613 L
.73507 .14626 L
.73507 .14639 L
.73507 .14652 L
.73508 .14665 L
.73508 .14678 L
.73509 .1469 L
.7351 .14703 L
.7351 .14716 L
.73511 .14729 L
.73512 .14742 L
.73513 .14755 L
.73514 .14768 L
s
.75598 .14473 m
.75597 .1448 L
.75597 .14486 L
.75596 .14493 L
.75596 .145 L
.75596 .14507 L
.75595 .14514 L
.75595 .1452 L
.75595 .14527 L
.75595 .14534 L
.75594 .14541 L
.75594 .14548 L
.75594 .14554 L
.75594 .14561 L
.75594 .14568 L
.75594 .14575 L
.75594 .14582 L
.75594 .14588 L
.75594 .14595 L
.75594 .14602 L
.75594 .14609 L
.75595 .14616 L
.75595 .14622 L
.75595 .14629 L
.75595 .14636 L
.75596 .14643 L
.75596 .1465 L
.75596 .14656 L
.75597 .14663 L
.75597 .1467 L
.75598 .14677 L
s
.77682 .14564 m
.77682 .14564 L
.77682 .14565 L
.77682 .14566 L
.77682 .14567 L
.77682 .14567 L
.77682 .14568 L
.77682 .14569 L
.77682 .1457 L
.77682 .1457 L
.77682 .14571 L
.77682 .14572 L
.77682 .14572 L
.77682 .14573 L
.77682 .14574 L
.77682 .14575 L
.77682 .14575 L
.77682 .14576 L
.77682 .14577 L
.77682 .14578 L
.77682 .14578 L
.77682 .14579 L
.77682 .1458 L
.77682 .14581 L
.77682 .14581 L
.77682 .14582 L
.77682 .14583 L
.77682 .14584 L
.77682 .14584 L
.77682 .14585 L
.77682 .14586 L
s
.79766 .14495 m
.79766 .145 L
.79767 .14505 L
.79767 .14511 L
.79768 .14516 L
.79768 .14521 L
.79768 .14527 L
.79768 .14532 L
.79769 .14537 L
.79769 .14543 L
.79769 .14548 L
.79769 .14553 L
.79769 .14559 L
.79769 .14564 L
.79769 .14569 L
.79769 .14575 L
.79769 .1458 L
.79769 .14585 L
.79769 .14591 L
.79769 .14596 L
.79769 .14601 L
.79769 .14607 L
.79769 .14612 L
.79768 .14617 L
.79768 .14623 L
.79768 .14628 L
.79768 .14633 L
.79767 .14639 L
.79767 .14644 L
.79766 .14649 L
.79766 .14655 L
s
.8185 .14404 m
.81851 .14415 L
.81852 .14427 L
.81853 .14438 L
.81853 .14449 L
.81854 .14461 L
.81855 .14472 L
.81855 .14484 L
.81856 .14495 L
.81856 .14506 L
.81856 .14518 L
.81857 .14529 L
.81857 .14541 L
.81857 .14552 L
.81857 .14563 L
.81857 .14575 L
.81857 .14586 L
.81857 .14598 L
.81857 .14609 L
.81857 .1462 L
.81856 .14632 L
.81856 .14643 L
.81856 .14654 L
.81855 .14666 L
.81855 .14677 L
.81854 .14689 L
.81853 .147 L
.81853 .14711 L
.81852 .14723 L
.81851 .14734 L
.8185 .14746 L
s
.82591 .14313 m
.82591 .1433 L
.8259 .14348 L
.8259 .14365 L
.8259 .14383 L
.8259 .144 L
.8259 .14418 L
.8259 .14435 L
.8259 .14453 L
.8259 .1447 L
.8259 .14487 L
.8259 .14505 L
.8259 .14522 L
.8259 .1454 L
.8259 .14557 L
.8259 .14575 L
.8259 .14592 L
.8259 .1461 L
.8259 .14627 L
.8259 .14645 L
.8259 .14662 L
.8259 .14679 L
.8259 .14697 L
.8259 .14714 L
.8259 .14732 L
.8259 .14749 L
.8259 .14767 L
.8259 .14784 L
.8259 .14802 L
.82591 .14819 L
.82591 .14837 L
s
.82379 .14222 m
.82379 .14245 L
.82378 .14269 L
.82378 .14292 L
.82378 .14316 L
.82378 .1434 L
.82378 .14363 L
.82378 .14387 L
.82378 .1441 L
.82378 .14434 L
.82378 .14457 L
.82377 .14481 L
.82377 .14504 L
.82377 .14528 L
.82377 .14551 L
.82377 .14575 L
.82377 .14598 L
.82377 .14622 L
.82377 .14645 L
.82377 .14669 L
.82378 .14692 L
.82378 .14716 L
.82378 .14739 L
.82378 .14763 L
.82378 .14786 L
.82378 .1481 L
.82378 .14833 L
.82378 .14857 L
.82378 .1488 L
.82379 .14904 L
.82379 .14928 L
s
.82167 .14131 m
.82167 .14161 L
.82166 .1419 L
.82166 .1422 L
.82166 .14249 L
.82166 .14279 L
.82166 .14308 L
.82166 .14338 L
.82165 .14368 L
.82165 .14397 L
.82165 .14427 L
.82165 .14456 L
.82165 .14486 L
.82165 .14516 L
.82165 .14545 L
.82165 .14575 L
.82165 .14604 L
.82165 .14634 L
.82165 .14663 L
.82165 .14693 L
.82165 .14723 L
.82165 .14752 L
.82165 .14782 L
.82166 .14811 L
.82166 .14841 L
.82166 .14871 L
.82166 .149 L
.82166 .1493 L
.82166 .14959 L
.82167 .14989 L
.82167 .15018 L
s
.81955 .1404 m
.81955 .14076 L
.81954 .14111 L
.81954 .14147 L
.81954 .14183 L
.81954 .14218 L
.81954 .14254 L
.81953 .1429 L
.81953 .14325 L
.81953 .14361 L
.81953 .14396 L
.81953 .14432 L
.81953 .14468 L
.81953 .14503 L
.81953 .14539 L
.81953 .14575 L
.81953 .1461 L
.81953 .14646 L
.81953 .14682 L
.81953 .14717 L
.81953 .14753 L
.81953 .14789 L
.81953 .14824 L
.81953 .1486 L
.81954 .14896 L
.81954 .14931 L
.81954 .14967 L
.81954 .15002 L
.81954 .15038 L
.81955 .15074 L
.81955 .15109 L
s
.81743 .13949 m
.81743 .13991 L
.81742 .14032 L
.81742 .14074 L
.81742 .14116 L
.81742 .14158 L
.81741 .14199 L
.81741 .14241 L
.81741 .14283 L
.81741 .14324 L
.81741 .14366 L
.81741 .14408 L
.81741 .1445 L
.81741 .14491 L
.81741 .14533 L
.8174 .14575 L
.81741 .14616 L
.81741 .14658 L
.81741 .147 L
.81741 .14742 L
.81741 .14783 L
.81741 .14825 L
.81741 .14867 L
.81741 .14908 L
.81741 .1495 L
.81742 .14992 L
.81742 .15034 L
.81742 .15075 L
.81742 .15117 L
.81743 .15159 L
.81743 .152 L
s
.81531 .13858 m
.81531 .13906 L
.8153 .13954 L
.8153 .14001 L
.8153 .14049 L
.8153 .14097 L
.81529 .14145 L
.81529 .14193 L
.81529 .1424 L
.81529 .14288 L
.81529 .14336 L
.81528 .14384 L
.81528 .14431 L
.81528 .14479 L
.81528 .14527 L
.81528 .14575 L
.81528 .14622 L
.81528 .1467 L
.81528 .14718 L
.81528 .14766 L
.81529 .14814 L
.81529 .14861 L
.81529 .14909 L
.81529 .14957 L
.81529 .15005 L
.8153 .15052 L
.8153 .151 L
.8153 .15148 L
.8153 .15196 L
.81531 .15244 L
.81531 .15291 L
s
.81319 .13767 m
.81319 .13821 L
.81318 .13875 L
.81318 .13929 L
.81318 .13982 L
.81317 .14036 L
.81317 .1409 L
.81317 .14144 L
.81317 .14198 L
.81316 .14252 L
.81316 .14306 L
.81316 .14359 L
.81316 .14413 L
.81316 .14467 L
.81316 .14521 L
.81316 .14575 L
.81316 .14629 L
.81316 .14682 L
.81316 .14736 L
.81316 .1479 L
.81316 .14844 L
.81316 .14898 L
.81317 .14952 L
.81317 .15005 L
.81317 .15059 L
.81317 .15113 L
.81318 .15167 L
.81318 .15221 L
.81318 .15275 L
.81319 .15328 L
.81319 .15382 L
s
.81107 .13676 m
.81107 .13736 L
.81106 .13796 L
.81106 .13856 L
.81106 .13916 L
.81105 .13976 L
.81105 .14036 L
.81105 .14095 L
.81104 .14155 L
.81104 .14215 L
.81104 .14275 L
.81104 .14335 L
.81104 .14395 L
.81104 .14455 L
.81104 .14515 L
.81104 .14575 L
.81104 .14635 L
.81104 .14695 L
.81104 .14754 L
.81104 .14814 L
.81104 .14874 L
.81104 .14934 L
.81104 .14994 L
.81105 .15054 L
.81105 .15114 L
.81105 .15174 L
.81106 .15234 L
.81106 .15294 L
.81106 .15353 L
.81107 .15413 L
.81107 .15473 L
s
.80895 .13585 m
.80895 .13651 L
.80894 .13717 L
.80894 .13783 L
.80894 .13849 L
.80893 .13915 L
.80893 .13981 L
.80892 .14047 L
.80892 .14113 L
.80892 .14179 L
.80892 .14245 L
.80892 .14311 L
.80891 .14377 L
.80891 .14443 L
.80891 .14509 L
.80891 .14575 L
.80891 .14641 L
.80891 .14707 L
.80891 .14773 L
.80892 .14839 L
.80892 .14905 L
.80892 .14971 L
.80892 .15036 L
.80892 .15102 L
.80893 .15168 L
.80893 .15234 L
.80894 .153 L
.80894 .15366 L
.80894 .15432 L
.80895 .15498 L
.80895 .15564 L
s
.80683 .13494 m
.80683 .13566 L
.80682 .13638 L
.80682 .1371 L
.80681 .13782 L
.80681 .13854 L
.80681 .13926 L
.8068 .13998 L
.8068 .14071 L
.8068 .14143 L
.8068 .14215 L
.80679 .14287 L
.80679 .14359 L
.80679 .14431 L
.80679 .14503 L
.80679 .14575 L
.80679 .14647 L
.80679 .14719 L
.80679 .14791 L
.80679 .14863 L
.8068 .14935 L
.8068 .15007 L
.8068 .15079 L
.8068 .15151 L
.80681 .15223 L
.80681 .15295 L
.80681 .15367 L
.80682 .15439 L
.80682 .15511 L
.80683 .15583 L
.80683 .15655 L
s
.80472 .13403 m
.80471 .13481 L
.8047 .13559 L
.8047 .13638 L
.80469 .13716 L
.80469 .13794 L
.80468 .13872 L
.80468 .1395 L
.80468 .14028 L
.80468 .14106 L
.80467 .14184 L
.80467 .14262 L
.80467 .1434 L
.80467 .14419 L
.80467 .14497 L
.80467 .14575 L
.80467 .14653 L
.80467 .14731 L
.80467 .14809 L
.80467 .14887 L
.80467 .14965 L
.80468 .15043 L
.80468 .15121 L
.80468 .15199 L
.80468 .15278 L
.80469 .15356 L
.80469 .15434 L
.8047 .15512 L
.8047 .1559 L
.80471 .15668 L
.80472 .15746 L
s
0 0 m
1 0 L
1 .26827 L
0 .26827 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 77.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000CB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00DOooool6o`000;Kooooo0ol0
000@ooooo`00D_ooool01Ol0003ooooooooooooooooo00000;Kooooo00Co0000oooooooooooo0000
3oooool005;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0=ooooo`00D_ooool0
0ol0003oooooooooo`2iooooo`;o00004?ooool005;ooooo00?o0000ooooooooool0^?ooool00ol0
003oooooooooo`0@ooooo`00D_ooool00ol0003oooooooooo`2hooooo`04o`000?ooooooooooo`00
00oooooo001Aooooo`?o0000^_ooool3o`0000oooooo003oooooob7ooooo001Fooooo`Go0000S?oo
ool5o`0003Cooooo001Fooooo`05o`000?moOgooOgmoogmoOol00000R?ooool4o`0000;ooooo00?o
0000ooooooooool01?l0000`ooooo`00EOooool6o`0008Gooooo0ol00006ooooo`03o`000?oooooo
oooo00Cooooo0ol0000]ooooo`00EOooool2o`0000?oOgmo00?o0000ooooooooool0P?ooool3o`00
00Wooooo00?o0000ooooooooool01oooool3o`0002[ooooo001Dooooo`03o`000?moOgoo000000?o
Ogmo00?o0000ooooooooool0O_ooool2o`0000cooooo00?o0000ooooooooool02_ooool3o`0002Oo
oooo001Dooooo`03o`000?moOgoo000000Co0000O_ooool2o`0000kooooo00?o0000ooooooooool0
3Oooool2o`0002Gooooo001Cooooo`04o`000?moOgooOgmoo`0000?oOgmo00?o0000ooooooooool0
Noooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
8_ooool005?ooooo00Co0000ogmoOomoOgoo00000omoOgl00ol0003oooooooooo`1iooooo`;o0000
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo001Cooooo`04o`000?mo
OgooOgmoo`0000?oOgmo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool08?ooool005;ooooo00Go0000ogmoOomoOgooOgmo
o`000003ogmoO`03o`000?oooooooooo07Oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01oooooo001Booooo`04o`000?moOgooOgmoogmoO`Go0000
N?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
7_ooool0057ooooo00?o0000ogmoOomoOgl00_moOgl01Ol0003oOgmoogmoOomoOgoo000007Sooooo
00?o0000ooooooooool00_ooool3o`000003ooooool0003ooooo00?o00002?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01kooooo001Aooooo`03o`000?moOgooOgmo00;oOgmo00Go
0000ogmoOomoOgooOgmoo`00001gooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool07Oooool0057ooooo00?o0000ogmoOomoOgl00_moOgl01Ol0003oOgmoogmoOomoOgoo000007Ko
oooo00?o0000ooooooooool01Oooool01ol0003oooooo`000?oooooo0000ooooool000002Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01cooooo001@ooooo`03o`000?moOgooOgmo
00?oOgmo00Go0000ogmoOomoOgooOgmoo`00001eooooo`03o`000?oooooooooo00Kooooo00Oo0000
ooooool0003oooooo`000?oooooo000000Wooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Kooooo`00D?ooool00ol0003oOgmoogmoO`03ogmoO`05o`000?moOgooOgmoogmoOol00000
M?ooool00ol0003oooooooooo`07ooooo`;o00000oooool2o`0000Wooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Jooooo`00D?ooool00ol0003oOgmoogmoO`03ogmoO`Go0000Looo
ool00ol0003oooooooooo`08ooooo`;o00000oooool2o`0000Wooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Iooooo`00Coooool00ol0003oOgmoogmoO`04ogmoO`05o`000?moOgoo
OgmoogmoOol00000Loooool00ol0003oooooooooo`07ooooo`;o00001Oooool2o`0000Sooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`00Coooool00ol0003oOgmoogmoO`04
ogmoO`05o`000?moOgooOgmoogmoOol00000L_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06?ooool004oooooo00?o0000ogmoOomoOgl01?moOgl0
1Ol0003oOgmoogmoOomoOgoo000007;ooooo00?o0000ooooooooool06?ooool4o`0001Wooooo00?o
0000ooooooooool06?ooool004kooooo00?o0000ogmoOomoOgl01OmoOgl01Ol0003oOgmoogmoOomo
Ogoo000007;ooooo00?o0000ooooooooool05_ooool2o`000004ogmoOol0003oOgmoogmoO`;o0000
5oooool00ol0003oooooooooo`0Hooooo`00C_ooool00ol0003oOgmoogmoO`05ogmoO`05o`000?mo
OgooOgmoogmoOol00000LOooool00ol0003oooooooooo`0Fooooo`05o`000?moOgooOgmoogmoOol0
00001?moOgl00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Oooooo001>ooooo`03o`00
0?moOgooOgmo00GoOgmo00Go0000ogmoOomoOgooOgmoo`00001aooooo`03o`000?oooooooooo01Go
oooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool05oooool004kooooo00?o0000ogmoOomoOgl01OmoOgl01Ol0003oOgmo
ogmoOomoOgoo0000077ooooo00?o0000ooooooooool05?ooool00ol0003oOgmoogmoO`03ogmoO`03
o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Gooooo`00
C_ooool00ol0003oOgmoogmoO`05ogmoO`Go0000L?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01Kooooo000?ooooodko2NX:K_ooool00ol0003oooooooooo`0Dooooo`03o`000?mo
OgooOgmo00CoOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Kooooo000?ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[o0000ogmoO`03ogmoO`04o`WZ2_moOgooOgmoo`0000;oOgmo00Co2NX:o`000?oooooooooo
4ol9jPYKooooo`03o`000?oooooooooo01Cooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmo
ogmoO`05ogmoO`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool000oooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_l0003oOgmo00?oOgmo00Co
2NX:ogmoOomoOgoo00000_moOgl00ol9jP[o0000ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooooaOo2NX:AOooool00ol0003ooooo
ooooo`0Cooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01Gooooo000?ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[o0000ogmoO`03ogmoO`08o`WZ2_moOgooOgmoo`000?moOgoo
2NX:ogmoOol00003ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo5?l9jPXbooooo`03o`000?oooooooooo
01;ooooo0_l9jPX7ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Eooooo`003oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:o`000?moOgl00omoOgl02?l9jP[oOgmoogmoOol0003oOgmoo`WZ2_moOgoo00000ooo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo01Ko2NX:6oooool00ol0003ooooooooo
o`0Dooooo`Co2NX:1?moOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool05Oooool000oooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol0003o2NX:o`000003
ooooo`03o`WZ2_l0003oOgmo00;oOgmo00Wo0000o`WZ2_l0003oOgmoo`000?moOgoo2NX:ogmoOol0
00000oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool2o`WZ2PCooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool2o`WZ2P03ooooool9jP[o2NX:017o
2NX:2?ooool00ol0003oooooooooo`0Booooo`;o00001Ol9jPX4o`0000SoOgmo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Eooooo`003oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_l0003o000000;o000000?o2NX:o`000?moOgl00omoOgl00ol9jP[o0000o`000002o`000003o`WZ
2_moOgoo000000?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00;ooooo5ol9jPX2ooooo`Go2NX:00?o0000o`WZ2_l9jPX01?l9jPX00ol0003oOgmo
o`000008ogmoO`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool000oooooo00?o
2NX:o`000?l000000ol000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000;o000000?o
2NX:o`000?l000000ol000000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o
2NX:o`000?l000000ol000000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o
2NX:o`000?l000000ol000000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o
2NX:o`000?l000000_l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000?o000000?o
2NX:o`000?l000000_l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000;o000000?o
2NX:o`000?l000000ol000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000;o000000?o
2NX:o`000?l000000ol000000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o
2NX:o`000?l000000ol000000ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000?o000000?o
2NX:o`000?l000000_l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000?o000000?o
2NX:o`000?l000000_l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000;o000000?o
2NX:o`000?l000000ol000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000;o000000?o
2NX:o`000?l000000ol000000ol9jP[o0000o`WZ2P05o`WZ2R?o00005_ooool000oooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00oooool00ol9jP[o0000o`000002o`000003o`WZ2_l0003oOgmo00?oOgmo00?o2NX:
o`000?l000000_l000000ol9jP[oOgmoo`000003ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool2o`WZ2PCooooo5ol9jPX00ooooooo0000ooooo`0Dooooo`03o`000?l9jP[o
2NX:00Co2NX:00?o0000ogmoOol000002?moOgl00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Cooooo000?ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o0000o`WZ2_ooool00oooool00ol9
jP[o0000ogmoO`02ogmoO`09o`000?l9jP[oOgmoogmoOol0003oOgmoo`WZ2_moOgoo000000?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool00_ooool2o`WZ2PCooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00Co2NX:oooooooooooooooo4_l9jPXHooooo`03
o`000?oooooooooo01;ooooo0_l00004o`WZ2P;oOgmo0ol00008ogmoO`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool05?ooool000oooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_l0003oOgmo00?oOgmo00So2NX:ogmoOomoOgoo0000ogmoOol9jP[oOgmo
o`0000?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool00_ooool01?l9jP[ooooooooooooooolGo`WZ2R[ooooo00?o
0000ooooooooool04oooool3o`WZ2PKoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01Gooooo000?ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[o0000ogmoO`03ogmoO`05o`WZ2_moOgooOgmoo`000?moOgl00_l9
jPX01Ol0003ooooooooooooooooo2NX:00Gooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo5?l9jPY1ooooo`03o`000?oooooooooo01Cooooo
00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool05Oooool000oooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_l0003oOgmo00?oOgmo00Co2NX:ogmoOomoOgoo00000_moOgl00ol9jP[o0000
ooooo`02ooooo`03o`WZ2_oooooo2NX:01Go2NX:EOooool00ol0003oooooooooo`0Dooooo`03o`00
0?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01Gooooo000?oooooe7o2NX:Joooool00ol0003oooooooooo`0Dooooo`03o`000?mo
OgooOgmo00CoOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01Gooooo001>ooooo`03o`000?moOgooOgmo00GoOgmo00Go0000ogmoOomoOgooOgmoo`00
001`ooooo`03o`000?oooooooooo01Cooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmo
O`05ogmoO`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool004kooooo00?o0000
ogmoOomoOgl01OmoOgl5o`00073ooooo00?o0000ooooooooool05Oooool00ol0003oOgmoogmoO`03
ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0F
ooooo`00C_ooool00ol0003oOgmoogmoO`05ogmoO`05o`000?moOgooOgmoogmoOol00000L?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00omoOgl0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo001>ooooo`03o`000?moOgooOgmo
00GoOgmo00Go0000ogmoOomoOgooOgmoo`00001aooooo`03o`000?oooooooooo01Kooooo00Go0000
ogmoOomoOgooOgmoo`000004ogmoO`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05ooo
ool004kooooo00?o0000ogmoOomoOgl01OmoOgl01Ol0003oOgmoogmoOomoOgoo0000077ooooo00?o
0000ooooooooool05oooool01?l0003oOgmoogmoOol00003ogmoO`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05oooool004kooooo00?o0000ogmoOomoOgl01OmoOgl01Ol0003oOgmoogmo
OomoOgoo000007;ooooo00?o0000ooooooooool05oooool6o`0001Sooooo00?o0000ooooooooool0
6?ooool004oooooo00?o0000ogmoOomoOgl01?moOgl01Ol0003oOgmoogmoOomoOgoo000007;ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo
001?ooooo`03o`000?moOgooOgmo00CoOgmo00Go0000ogmoOomoOgooOgmoo`00001booooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`00Cooo
ool00ol0003oOgmoogmoO`04ogmoO`Go0000Loooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool06Oooool0053ooooo00?o0000ogmoOomoOgl00omoOgl0
1Ol0003oOgmoogmoOomoOgoo000007?ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Wooooo001@ooooo`03o`000?moOgooOgmo00?oOgmo00Go0000
ogmoOomoOgooOgmoo`00001dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Jooooo`00D?ooool00ol0003oOgmoogmoO`03ogmoO`05o`000?moOgoo
OgmoogmoOol00000MOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool06oooool0057ooooo00?o0000ogmoOomoOgl00_moOgl01Ol0003oOgmoogmoOomo
Ogoo000007Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01cooooo001Aooooo`03o`000?moOgooOgmo00;oOgmo00Go0000ogmoOomoOgooOgmoo`00
001fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Looooo`00DOooool00ol0003oOgmoogmoO`02ogmoO`05o`000?moOgooOgmoogmoOol00000Mooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07Ooo
ool005;ooooo00Co0000ogmoOomoOgooOgmo1Ol0001hooooo`;o00005?ooool00ol0003ooooooooo
o`0Booooo`;o00008?ooool005;ooooo00Go0000ogmoOomoOgooOgmoo`000003ogmoO`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo023ooooo001Cooooo`04o`000?moOgooOgmoo`0000?oOgmo00?o0000ooooooooool0NOoo
ool2o`00017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`00Doooool0
1?l0003oOgmoogmoOol00003ogmoO`03o`000?oooooooooo07_ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo001Dooooo`03o`000?moOgoo
000000?oOgmo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool08oooool005Cooooo00?o0000ogmoOol000001?l0001ooooo
o`;o00003Oooool00ol0003oooooooooo`0<ooooo`;o00009_ooool005Cooooo00?o0000ogmoOol0
00000omoOgl00ol0003oooooooooo`1oooooo`?o00002_ooool00ol0003oooooooooo`09ooooo`?o
0000:?ooool005Gooooo0_l00003ogmoO`03o`000?oooooooooo08;ooooo0_l00008ooooo`03o`00
0?oooooooooo00Kooooo0ol0000[ooooo`00EOooool6o`0008Kooooo1Ol00003ooooo`04o`000?oo
ooooooooooooo`Go0000;_ooool005Kooooo1Ol0002;ooooo`Oo0000<oooool00?oooooo8Oooool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {76.25, 0}} -> {-12.6679, -34.8146, 0.802498, \
0.802498}},
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[opticalsystemoffaxis, ShowGaussian->True];", "Input",
  CellLabel->"In[71]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .63055 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0176843 1.01768 -0.170107 1.01768 [
[ 0 0 0 0 ]
[ 1 .63055 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .63055 L
0 .63055 L
closepath
clip
newpath
.039 .916 .04 r
1 Mabswid
[ ] 0 setdash
.12975 .46098 m
.14027 .45766 L
s
.12783 .45935 m
.12852 .45997 L
s
.12714 .45874 m
.12783 .45935 L
s
.11954 .43344 m
.13002 .43 L
s
.12645 .45812 m
.12714 .45874 L
s
.11933 .43518 m
.11925 .43621 L
s
.12576 .4575 m
.12645 .45812 L
s
.11925 .43621 m
.11917 .43724 L
s
.14027 .45766 m
.15082 .45433 L
s
.12506 .45688 m
.12576 .4575 L
s
.11917 .43724 m
.11909 .43827 L
s
.11909 .43827 m
.11901 .4393 L
s
.12437 .45626 m
.12506 .45688 L
s
.11901 .4393 m
.11893 .44033 L
s
.12367 .45564 m
.12437 .45626 L
s
.13002 .43 m
.14054 .42654 L
s
.11893 .44033 m
.11884 .44136 L
s
.12298 .45502 m
.12367 .45564 L
s
.11884 .44136 m
.11876 .4424 L
s
.12228 .45441 m
.12298 .45502 L
s
.14362 .45436 m
.14431 .45499 L
s
.11876 .4424 m
.11868 .44343 L
s
.12158 .45379 m
.12228 .45441 L
s
.14293 .45374 m
.14362 .45436 L
s
.15082 .45433 m
.1614 .451 L
s
.11868 .44343 m
.11859 .44447 L
s
.11859 .44447 m
.11851 .4455 L
s
.12088 .45317 m
.12158 .45379 L
s
.14224 .45312 m
.14293 .45374 L
s
.13507 .43002 m
.13499 .43106 L
s
.11851 .4455 m
.11842 .44654 L
s
.12018 .45255 m
.12088 .45317 L
s
.14154 .45249 m
.14224 .45312 L
s
.13499 .43106 m
.13491 .43209 L
s
.11842 .44654 m
.11834 .44757 L
s
.14054 .42654 m
.15108 .42308 L
s
.11948 .45193 m
.12018 .45255 L
s
.14085 .45187 m
.14154 .45249 L
s
.13491 .43209 m
.13484 .43313 L
s
.11834 .44757 m
.11825 .44861 L
s
.11878 .45131 m
.11948 .45193 L
s
.13484 .43313 m
.13476 .43416 L
s
.14016 .45124 m
.14085 .45187 L
s
.11825 .44861 m
.11816 .44965 L
s
.13476 .43416 m
.13468 .4352 L
s
.11807 .45069 m
.11878 .45131 L
s
.13946 .45062 m
.14016 .45124 L
s
.11816 .44965 m
.11807 .45069 L
s
.1614 .451 m
.17202 .44765 L
s
.13468 .4352 m
.1346 .43624 L
s
.11807 .45069 m
.11798 .45173 L
s
.11737 .45007 m
.11807 .45069 L
s
.13876 .44999 m
.13946 .45062 L
s
.1346 .43624 m
.13452 .43728 L
s
.11798 .45173 m
.11789 .45277 L
s
.11666 .44945 m
.11737 .45007 L
s
.13807 .44937 m
.13876 .44999 L
s
.15948 .44935 m
.16017 .44998 L
s
.13452 .43728 m
.13444 .43832 L
s
.11789 .45277 m
.1178 .45381 L
s
.11596 .44882 m
.11666 .44945 L
s
.13737 .44874 m
.13807 .44937 L
s
.15879 .44872 m
.15948 .44935 L
s
.13444 .43832 m
.13436 .43936 L
s
.15108 .42308 m
.16166 .4196 L
s
.1178 .45381 m
.11771 .45485 L
s
.11525 .4482 m
.11596 .44882 L
s
.13436 .43936 m
.13428 .4404 L
s
.13667 .44812 m
.13737 .44874 L
s
.1581 .44809 m
.15879 .44872 L
s
.11771 .45485 m
.11762 .45589 L
s
.15088 .42484 m
.1508 .42588 L
s
.13428 .4404 m
.13419 .44144 L
s
.11454 .44758 m
.11525 .4482 L
s
.13597 .44749 m
.13667 .44812 L
s
.11762 .45589 m
.11753 .45693 L
s
.15741 .44746 m
.1581 .44809 L
s
.1508 .42588 m
.15073 .42692 L
s
.13419 .44144 m
.13411 .44248 L
s
.17202 .44765 m
.18267 .4443 L
s
.11753 .45693 m
.11744 .45797 L
s
.11383 .44696 m
.11454 .44758 L
s
.13526 .44687 m
.13597 .44749 L
s
.15671 .44683 m
.15741 .44746 L
s
.15073 .42692 m
.15066 .42796 L
s
.13411 .44248 m
.13403 .44353 L
s
.11744 .45797 m
.11734 .45902 L
s
.11312 .44634 m
.11383 .44696 L
s
.13456 .44624 m
.13526 .44687 L
s
.15066 .42796 m
.15058 .42901 L
s
.15602 .4462 m
.15671 .44683 L
s
.13403 .44353 m
.13394 .44457 L
s
.11734 .45902 m
.11725 .46006 L
s
.11241 .44572 m
.11312 .44634 L
s
.15058 .42901 m
.15051 .43005 L
s
.13386 .44562 m
.13456 .44624 L
s
.15532 .44557 m
.15602 .4462 L
s
.13394 .44457 m
.13386 .44562 L
s
.11725 .46006 m
.11716 .46111 L
s
.16166 .4196 m
.17227 .41612 L
s
.15051 .43005 m
.15043 .43109 L
s
.1117 .4451 m
.11241 .44572 L
s
.13386 .44562 m
.13377 .44666 L
s
.13315 .44499 m
.13386 .44562 L
s
.15462 .44494 m
.15532 .44557 L
s
.11716 .46111 m
.11706 .46215 L
s
.15043 .43109 m
.15035 .43214 L
s
.11098 .44448 m
.1117 .4451 L
s
.13377 .44666 m
.13369 .44771 L
s
.11706 .46215 m
.11696 .4632 L
s
.13245 .44436 m
.13315 .44499 L
s
.17542 .44431 m
.17611 .44495 L
s
.15393 .44431 m
.15462 .44494 L
s
.15035 .43214 m
.15028 .43318 L
s
.13369 .44771 m
.1336 .44875 L
s
.11696 .4632 m
.11687 .46425 L
s
.11027 .44385 m
.11098 .44448 L
s
.13174 .44374 m
.13245 .44436 L
s
.17473 .44367 m
.17542 .44431 L
s
.15323 .44368 m
.15393 .44431 L
s
.18267 .4443 m
.19335 .44093 L
s
.15028 .43318 m
.1502 .43423 L
s
.1336 .44875 m
.13351 .4498 L
s
.11687 .46425 m
.11677 .4653 L
s
.10955 .44323 m
.11027 .44385 L
s
.13103 .44311 m
.13174 .44374 L
s
.1502 .43423 m
.15012 .43528 L
s
.15253 .44305 m
.15323 .44368 L
s
.17403 .44304 m
.17473 .44367 L
s
.13351 .4498 m
.13342 .45085 L
s
.11677 .4653 m
.11667 .46635 L
s
.16676 .41963 m
.16669 .42068 L
s
.10884 .44261 m
.10955 .44323 L
s
.15012 .43528 m
.15004 .43632 L
s
.13032 .44248 m
.13103 .44311 L
s
.15183 .44241 m
.15253 .44305 L
s
.17334 .4424 m
.17403 .44304 L
s
.13342 .45085 m
.13333 .4519 L
s
.16669 .42068 m
.16662 .42173 L
s
.15004 .43632 m
.14996 .43737 L
s
.10812 .44199 m
.10884 .44261 L
s
.17227 .41612 m
.18291 .41262 L
s
.13333 .4519 m
.13324 .45295 L
s
.12961 .44186 m
.13032 .44248 L
s
.15112 .44178 m
.15183 .44241 L
s
.17265 .44177 m
.17334 .4424 L
s
.16662 .42173 m
.16655 .42277 L
s
.14996 .43737 m
.14988 .43842 L
s
.11659 .46807 m
.12714 .46476 L
s
.1074 .44136 m
.10812 .44199 L
s
.13324 .45295 m
.13315 .454 L
s
.1289 .44123 m
.12961 .44186 L
s
.15042 .44115 m
.15112 .44178 L
s
.16655 .42277 m
.16648 .42382 L
s
.17195 .44113 m
.17265 .44177 L
s
.14988 .43842 m
.1498 .43947 L
s
.13315 .454 m
.13306 .45505 L
s
.16648 .42382 m
.16641 .42487 L
s
.12819 .4406 m
.1289 .44123 L
s
.14972 .44052 m
.15042 .44115 L
s
.17126 .4405 m
.17195 .44113 L
s
.1498 .43947 m
.14972 .44052 L
s
.19335 .44093 m
.20406 .43755 L
s
.13306 .45505 m
.13297 .4561 L
s
.16641 .42487 m
.16633 .42592 L
s
.12748 .43997 m
.12819 .4406 L
s
.14972 .44052 m
.14963 .44157 L
s
.14901 .43989 m
.14972 .44052 L
s
.17056 .43986 m
.17126 .4405 L
s
.13297 .4561 m
.13288 .45715 L
s
.10628 .4403 m
.1168 .43686 L
s
.16633 .42592 m
.16626 .42697 L
s
.14963 .44157 m
.14955 .44262 L
s
.12677 .43935 m
.12748 .43997 L
s
.19143 .43925 m
.19212 .43989 L
s
.14831 .43926 m
.14901 .43989 L
s
.13288 .45715 m
.13279 .4582 L
s
.16986 .43922 m
.17056 .43986 L
s
.16626 .42697 m
.16619 .42802 L
s
.14955 .44262 m
.14947 .44368 L
s
.13279 .4582 m
.13269 .45925 L
s
.12605 .43872 m
.12677 .43935 L
s
.1476 .43862 m
.14831 .43926 L
s
.19073 .43861 m
.19143 .43925 L
s
.16916 .43859 m
.16986 .43922 L
s
.18291 .41262 m
.19359 .40911 L
s
.16619 .42802 m
.16611 .42907 L
s
.14947 .44368 m
.14938 .44473 L
s
.13269 .45925 m
.1326 .46031 L
s
.12534 .43809 m
.12605 .43872 L
s
.14689 .43799 m
.1476 .43862 L
s
.19004 .43797 m
.19073 .43861 L
s
.12714 .46476 m
.13773 .46143 L
s
.16611 .42907 m
.16604 .43013 L
s
.16846 .43795 m
.16916 .43859 L
s
.14938 .44473 m
.1493 .44578 L
s
.1326 .46031 m
.13251 .46136 L
s
.18272 .4144 m
.18265 .41545 L
s
.12462 .43746 m
.12534 .43809 L
s
.16604 .43013 m
.16596 .43118 L
s
.14618 .43736 m
.14689 .43799 L
s
.18935 .43733 m
.19004 .43797 L
s
.16776 .43731 m
.16846 .43795 L
s
.1493 .44578 m
.14921 .44684 L
s
.18265 .41545 m
.18259 .41651 L
s
.20406 .43755 m
.21481 .43417 L
s
.16596 .43118 m
.16588 .43223 L
s
.1239 .43683 m
.12462 .43746 L
s
.14921 .44684 m
.14913 .44789 L
s
.14547 .43673 m
.14618 .43736 L
s
.18866 .43668 m
.18935 .43733 L
s
.16706 .43668 m
.16776 .43731 L
s
.18259 .41651 m
.18252 .41756 L
s
.16588 .43223 m
.16581 .43329 L
s
.1168 .43686 m
.12734 .4334 L
s
.12318 .43621 m
.1239 .43683 L
s
.14913 .44789 m
.14904 .44895 L
s
.14476 .43609 m
.14547 .43673 L
s
.18252 .41756 m
.18245 .41861 L
s
.18796 .43604 m
.18866 .43668 L
s
.16636 .43604 m
.16706 .43668 L
s
.16581 .43329 m
.16573 .43435 L
s
.14904 .44895 m
.14895 .45 L
s
.18245 .41861 m
.18238 .41967 L
s
.14405 .43546 m
.14476 .43609 L
s
.18726 .4354 m
.18796 .43604 L
s
.16565 .4354 m
.16636 .43604 L
s
.16573 .43435 m
.16565 .4354 L
s
.14895 .45 m
.14886 .45106 L
s
.19359 .40911 m
.2043 .4056 L
s
.18238 .41967 m
.18231 .42072 L
s
.14334 .43483 m
.14405 .43546 L
s
.16565 .4354 m
.16557 .43646 L
s
.16495 .43476 m
.16565 .4354 L
s
.18657 .43476 m
.18726 .4354 L
s
.14886 .45106 m
.14877 .45212 L
s
.13773 .46143 m
.14834 .4581 L
s
.18231 .42072 m
.18224 .42178 L
s
.16557 .43646 m
.16549 .43752 L
s
.14262 .43419 m
.14334 .43483 L
s
.20751 .43416 m
.2082 .43481 L
s
.16424 .43413 m
.16495 .43476 L
s
.18587 .43412 m
.18657 .43476 L
s
.14877 .45212 m
.14869 .45318 L
s
.18224 .42178 m
.18217 .42284 L
s
.16549 .43752 m
.16541 .43857 L
s
.14869 .45318 m
.1486 .45424 L
s
.14191 .43356 m
.14262 .43419 L
s
.21481 .43417 m
.22559 .43077 L
s
.20682 .43352 m
.20751 .43416 L
s
.16353 .43349 m
.16424 .43413 L
s
.18517 .43347 m
.18587 .43412 L
s
.18217 .42284 m
.1821 .4239 L
s
.16541 .43857 m
.16533 .43963 L
s
0 g
.5 Mabswid
.34761 .36764 m
.33968 .34132 L
s
.33968 .34132 m
.35273 .33706 L
s
.33968 .34132 m
.329 .31643 L
s
.039 .916 .04 r
1 Mabswid
.1486 .45424 m
.1485 .4553 L
s
.14119 .43293 m
.14191 .43356 L
s
.20613 .43287 m
.20682 .43352 L
s
.16282 .43285 m
.16353 .43349 L
s
.1821 .4239 m
.18203 .42495 L
s
.18447 .43283 m
.18517 .43347 L
s
.12734 .4334 m
.13792 .42994 L
s
.16533 .43963 m
.16525 .44069 L
s
.19875 .40915 m
.19869 .4102 L
s
.1485 .4553 m
.14841 .45636 L
s
0 g
.5 Mabswid
.3523 .39376 m
.34761 .36764 L
s
.34761 .36764 m
.36068 .36343 L
s
.039 .916 .04 r
1 Mabswid
.18203 .42495 m
.18196 .42601 L
s
.14047 .43229 m
.14119 .43293 L
s
.20543 .43222 m
.20613 .43287 L
s
.16211 .43221 m
.16282 .43285 L
s
.18377 .43219 m
.18447 .43283 L
s
.16525 .44069 m
.16517 .44175 L
s
.19869 .4102 m
.19862 .41126 L
s
.18196 .42601 m
.18188 .42707 L
s
.2043 .4056 m
.21504 .40207 L
s
.13976 .43166 m
.14047 .43229 L
s
.20474 .43158 m
.20543 .43222 L
s
.16517 .44175 m
.16508 .44281 L
s
.1614 .43157 m
.16211 .43221 L
s
.18307 .43154 m
.18377 .43219 L
s
.19862 .41126 m
.19856 .41232 L
s
.18188 .42707 m
.18181 .42813 L
s
.14834 .4581 m
.15899 .45476 L
s
.16508 .44281 m
.165 .44388 L
s
.13904 .43102 m
.13976 .43166 L
s
.19856 .41232 m
.1985 .41338 L
s
.20404 .43093 m
.20474 .43158 L
s
.16069 .43093 m
.1614 .43157 L
s
.18236 .4309 m
.18307 .43154 L
s
.18181 .42813 m
.18173 .4292 L
s
.165 .44388 m
.16492 .44494 L
s
.1985 .41338 m
.19843 .41444 L
s
.15998 .4303 m
.16069 .43093 L
s
.20335 .43028 m
.20404 .43093 L
s
.18166 .43026 m
.18236 .4309 L
s
.18173 .4292 m
.18166 .43026 L
s
.22559 .43077 m
.23641 .42736 L
s
.16492 .44494 m
.16483 .446 L
s
.19843 .41444 m
.19836 .4155 L
s
.15927 .42966 m
.15998 .4303 L
s
.20265 .42963 m
.20335 .43028 L
s
.18166 .43026 m
.18158 .43132 L
s
.18095 .42962 m
.18166 .43026 L
s
.16483 .446 m
.16474 .44707 L
s
.19836 .4155 m
.1983 .41657 L
s
.13792 .42994 m
.14853 .42646 L
s
0 g
.5 Mabswid
.329 .31643 m
.34205 .31211 L
s
.329 .31643 m
.31621 .29452 L
s
.039 .916 .04 r
1 Mabswid
.18158 .43132 m
.18151 .43239 L
s
.22367 .42906 m
.22436 .42971 L
s
.15855 .42902 m
.15927 .42966 L
s
.20195 .42898 m
.20265 .42963 L
s
0 g
.5 Mabswid
.35273 .33706 m
.36068 .36343 L
s
.34205 .31211 m
.35273 .33706 L
s
.039 .916 .04 r
1 Mabswid
.18025 .42897 m
.18095 .42962 L
s
.16474 .44707 m
.16466 .44813 L
s
.1983 .41657 m
.19823 .41763 L
s
.18151 .43239 m
.18143 .43345 L
s
.22298 .4284 m
.22367 .42906 L
s
.16466 .44813 m
.16457 .4492 L
s
.15784 .42838 m
.15855 .42902 L
s
.20125 .42834 m
.20195 .42898 L
s
.17954 .42833 m
.18025 .42897 L
s
.21504 .40207 m
.22582 .39853 L
s
0 g
.5 Mabswid
.36068 .36343 m
.3654 .38958 L
s
.039 .916 .04 r
1 Mabswid
.19823 .41763 m
.19816 .41869 L
s
.18143 .43345 m
.18135 .43451 L
s
.16457 .4492 m
.16448 .45026 L
s
.22228 .42775 m
.22298 .4284 L
s
.15712 .42774 m
.15784 .42838 L
s
.19816 .41869 m
.19809 .41976 L
s
.20055 .42769 m
.20125 .42834 L
s
.17883 .42768 m
.17954 .42833 L
s
.15899 .45476 m
.16968 .4514 L
s
.18135 .43451 m
.18127 .43558 L
s
.21486 .40387 m
.2148 .40493 L
s
.16448 .45026 m
.1644 .45133 L
s
.19809 .41976 m
.19803 .42082 L
s
.22159 .4271 m
.22228 .42775 L
s
.1564 .4271 m
.15712 .42774 L
s
.19985 .42704 m
.20055 .42769 L
s
.17812 .42704 m
.17883 .42768 L
s
0 g
.5 Mabswid
.3523 .39376 m
.3654 .38958 L
s
.039 .916 .04 r
1 Mabswid
.18127 .43558 m
.18119 .43665 L
s
.2148 .40493 m
.21474 .40599 L
s
.23641 .42736 m
.24725 .42394 L
s
.19803 .42082 m
.19796 .42189 L
s
.15569 .42646 m
.1564 .4271 L
s
.2209 .42644 m
.22159 .4271 L
s
.18119 .43665 m
.18111 .43771 L
s
.17741 .42639 m
.17812 .42704 L
s
.19915 .42639 m
.19985 .42704 L
s
.21474 .40599 m
.21468 .40706 L
s
.19796 .42189 m
.19789 .42296 L
s
.18111 .43771 m
.18103 .43878 L
s
.14853 .42646 m
.15918 .42298 L
s
.15497 .42582 m
.15569 .42646 L
s
.21468 .40706 m
.21462 .40813 L
s
.2202 .42579 m
.2209 .42644 L
s
.1767 .42575 m
.17741 .42639 L
s
.19845 .42574 m
.19915 .42639 L
s
.19789 .42296 m
.19781 .42402 L
s
.18103 .43878 m
.18095 .43985 L
s
.21462 .40813 m
.21455 .40919 L
s
.21951 .42514 m
.2202 .42579 L
s
.17599 .42511 m
.1767 .42575 L
s
.19774 .42509 m
.19845 .42574 L
s
0 g
.5 Mabswid
.32928 .29015 m
.34205 .31211 L
s
.039 .916 .04 r
1 Mabswid
.19781 .42402 m
.19774 .42509 L
s
.22582 .39853 m
.23662 .39497 L
s
.18095 .43985 m
.18087 .44092 L
s
.21455 .40919 m
.21449 .41026 L
s
.21881 .42448 m
.21951 .42514 L
s
.17527 .42446 m
.17599 .42511 L
s
.19774 .42509 m
.19767 .42616 L
s
.19704 .42444 m
.19774 .42509 L
s
.18087 .44092 m
.18079 .44199 L
s
.21449 .41026 m
.21443 .41133 L
s
.16968 .4514 m
.1804 .44804 L
s
.2399 .42392 m
.24059 .42458 L
s
.19767 .42616 m
.1976 .42723 L
s
.21811 .42383 m
.21881 .42448 L
s
.17456 .42382 m
.17527 .42446 L
s
.19633 .42379 m
.19704 .42444 L
s
.18079 .44199 m
.18071 .44306 L
s
.21443 .41133 m
.21437 .4124 L
s
.1976 .42723 m
.19752 .4283 L
s
.24725 .42394 m
.25813 .42051 L
s
.23921 .42326 m
.2399 .42392 L
s
.21741 .42317 m
.21811 .42383 L
s
.18071 .44306 m
.18062 .44413 L
s
.17384 .42317 m
.17456 .42382 L
s
.19562 .42314 m
.19633 .42379 L
s
.21437 .4124 m
.2143 .41347 L
s
.19752 .4283 m
.19745 .42937 L
s
.18062 .44413 m
.18054 .4452 L
s
.23852 .42261 m
.23921 .42326 L
s
.2143 .41347 m
.21424 .41454 L
s
.21671 .42252 m
.21741 .42317 L
s
.17313 .42252 m
.17384 .42317 L
s
.19492 .42249 m
.19562 .42314 L
s
.15918 .42298 m
.16986 .41948 L
s
.23104 .39856 m
.23098 .39963 L
s
.19745 .42937 m
.19737 .43044 L
s
.18054 .4452 m
.18045 .44628 L
s
.21424 .41454 m
.21417 .41561 L
s
.23783 .42195 m
.23852 .42261 L
s
.17241 .42188 m
.17313 .42252 L
s
.21601 .42187 m
.21671 .42252 L
s
.19421 .42184 m
.19492 .42249 L
s
.23098 .39963 m
.23093 .4007 L
s
.19737 .43044 m
.1973 .43152 L
s
.23662 .39497 m
.24747 .39141 L
s
.21417 .41561 m
.2141 .41668 L
s
.23713 .42129 m
.23783 .42195 L
s
.17169 .42123 m
.17241 .42188 L
s
.21531 .42121 m
.21601 .42187 L
s
.1973 .43152 m
.19722 .43259 L
s
.1935 .42119 m
.19421 .42184 L
s
.23093 .4007 m
.23087 .40177 L
s
.2141 .41668 m
.21404 .41775 L
s
0 g
.5 Mabswid
.31621 .29452 m
.32928 .29015 L
s
.039 .916 .04 r
1 Mabswid
.19722 .43259 m
.19715 .43366 L
s
.23087 .40177 m
.23081 .40284 L
s
.23644 .42063 m
.23713 .42129 L
s
.1804 .44804 m
.19115 .44466 L
s
.17097 .42059 m
.17169 .42123 L
s
.21461 .42056 m
.21531 .42121 L
s
.19278 .42054 m
.1935 .42119 L
s
.21404 .41775 m
.21397 .41883 L
s
.19715 .43366 m
.19707 .43474 L
s
.23081 .40284 m
.23075 .40392 L
s
.23574 .41997 m
.23644 .42063 L
s
.2139 .4199 m
.21461 .42056 L
s
.19207 .41989 m
.19278 .42054 L
s
.25813 .42051 m
.26905 .41707 L
s
.21397 .41883 m
.2139 .4199 L
s
.19707 .43474 m
.19699 .43581 L
s
.23075 .40392 m
.2307 .40499 L
s
.23504 .41931 m
.23574 .41997 L
s
.2139 .4199 m
.21383 .42098 L
s
.2132 .41924 m
.2139 .4199 L
s
.19136 .41924 m
.19207 .41989 L
s
.19699 .43581 m
.19691 .43689 L
s
.2307 .40499 m
.23064 .40606 L
s
.16986 .41948 m
.18057 .41597 L
s
.25621 .41877 m
.2569 .41943 L
s
.21383 .42098 m
.21376 .42205 L
s
.23435 .41865 m
.23504 .41931 L
s
.21249 .41859 m
.2132 .41924 L
s
.19064 .41859 m
.19136 .41924 L
s
.19691 .43689 m
.19683 .43797 L
s
.23064 .40606 m
.23058 .40714 L
s
.21376 .42205 m
.21369 .42313 L
s
.25552 .4181 m
.25621 .41877 L
s
.24747 .39141 m
.25834 .38784 L
s
.23365 .41799 m
.23435 .41865 L
s
.19683 .43797 m
.19675 .43904 L
s
.21178 .41793 m
.21249 .41859 L
s
.18993 .41794 m
.19064 .41859 L
s
.23058 .40714 m
.23052 .40822 L
s
.21369 .42313 m
.21362 .4242 L
s
.25483 .41744 m
.25552 .4181 L
s
.19675 .43904 m
.19667 .44012 L
s
.32184 .40443 m .36657 .41389 L .35341 .41804 L .656 .751 .92 r
F
0 g
.5 Mabswid
.35084 .43892 m
.35341 .41804 L
s
.3523 .39376 m
.35309 .41104 L
s
.039 .916 .04 r
1 Mabswid
.23052 .40822 m
.23045 .40929 L
s
.23295 .41733 m
.23365 .41799 L
s
.18921 .41729 m
.18993 .41794 L
s
.21107 .41728 m
.21178 .41793 L
s
.19115 .44466 m
.20193 .44128 L
s
.24729 .39323 m
.24724 .39431 L
s
.21362 .4242 m
.21355 .42528 L
s
.19667 .44012 m
.19659 .4412 L
s
.23045 .40929 m
.23039 .41037 L
s
.25414 .41677 m
.25483 .41744 L
s
.23225 .41667 m
.23295 .41733 L
s
.18849 .41663 m
.18921 .41729 L
s
.21036 .41662 m
.21107 .41728 L
s
.24724 .39431 m
.24719 .39538 L
s
.21355 .42528 m
.21348 .42636 L
s
.26905 .41707 m
.28 .41362 L
s
.23039 .41037 m
.23033 .41145 L
s
.25344 .41611 m
.25414 .41677 L
s
.23154 .41601 m
.23225 .41667 L
s
.24719 .39538 m
.24714 .39646 L
s
.18777 .41598 m
.18849 .41663 L
s
.21348 .42636 m
.21341 .42744 L
s
.20965 .41597 m
.21036 .41662 L
s
.23033 .41145 m
.23027 .41253 L
s
.24714 .39646 m
.24708 .39754 L
s
.25275 .41544 m
.25344 .41611 L
s
.21341 .42744 m
.21333 .42852 L
s
.23084 .41535 m
.23154 .41601 L
s
.18705 .41533 m
.18777 .41598 L
s
.18057 .41597 m
.19132 .41246 L
s
.20894 .41531 m
.20965 .41597 L
s
.23027 .41253 m
.2302 .4136 L
s
.24708 .39754 m
.24703 .39862 L
s
.21333 .42852 m
.21326 .4296 L
s
.25205 .41478 m
.25275 .41544 L
s
.23014 .41468 m
.23084 .41535 L
s
.20823 .41465 m
.20894 .41531 L
s
.2302 .4136 m
.23014 .41468 L
s
.25834 .38784 m
.26926 .38425 L
s
.24703 .39862 m
.24697 .3997 L
s
.21326 .4296 m
.21318 .43068 L
s
.25136 .41411 m
.25205 .41478 L
s
.23014 .41468 m
.23007 .41577 L
s
.22943 .41402 m
.23014 .41468 L
s
.20752 .414 m
.20823 .41465 L
s
.24697 .3997 m
.24692 .40078 L
s
.21318 .43068 m
.21311 .43176 L
s
.20193 .44128 m
.21275 .43788 L
s
.2726 .41359 m
.27329 .41426 L
s
.23007 .41577 m
.23001 .41685 L
s
.25066 .41344 m
.25136 .41411 L
s
.22873 .41336 m
.22943 .41402 L
s
.2068 .41334 m
.20752 .414 L
s
.32184 .40443 m .34854 .39593 L .36657 .41389 L .656 .751 .92 r
F
0 g
.5 Mabswid
.36408 .43479 m
.36657 .41389 L
s
.3654 .38958 m
.36657 .41389 L
s
.35341 .41804 m
.36657 .41389 L
s
.039 .916 .04 r
1 Mabswid
.24692 .40078 m
.24686 .40186 L
s
.21311 .43176 m
.21303 .43285 L
s
.28 .41362 m
.29098 .41016 L
s
.27191 .41292 m
.2726 .41359 L
s
.23001 .41685 m
.22994 .41793 L
s
.24996 .41278 m
.25066 .41344 L
s
.22802 .4127 m
.22873 .41336 L
s
.21303 .43285 m
.21296 .43393 L
s
.20609 .41268 m
.2068 .41334 L
s
.24686 .40186 m
.24681 .40294 L
s
.22994 .41793 m
.22987 .41901 L
s
.27122 .41224 m
.27191 .41292 L
s
.21296 .43393 m
.21288 .43501 L
s
.24681 .40294 m
.24675 .40402 L
s
.24926 .41211 m
.24996 .41278 L
s
.22731 .41204 m
.22802 .4127 L
s
.20537 .41202 m
.20609 .41268 L
s
.26363 .38788 m
.26358 .38896 L
s
.22987 .41901 m
.2298 .4201 L
s
.19132 .41246 m
.2021 .40893 L
s
.21288 .43501 m
.2128 .4361 L
s
.27052 .41157 m
.27122 .41224 L
s
.24675 .40402 m
.24669 .4051 L
s
.24856 .41144 m
.24926 .41211 L
s
.2266 .41138 m
.22731 .41204 L
s
.26358 .38896 m
.26353 .39004 L
s
.20465 .41137 m
.20537 .41202 L
s
.2298 .4201 m
.22974 .42118 L
s
.26926 .38425 m
.2802 .38066 L
s
.24669 .4051 m
.24663 .40619 L
s
.26983 .4109 m
.27052 .41157 L
s
.26353 .39004 m
.26348 .39112 L
s
.24786 .41078 m
.24856 .41144 L
s
.22974 .42118 m
.22967 .42227 L
s
.22589 .41071 m
.2266 .41138 L
s
.20393 .41071 m
.20465 .41137 L
s
.24663 .40619 m
.24657 .40727 L
s
.26348 .39112 m
.26343 .39221 L
s
.26914 .41023 m
.26983 .4109 L
s
.22967 .42227 m
.2296 .42335 L
s
.24715 .41011 m
.24786 .41078 L
s
.21275 .43788 m
.22361 .43447 L
s
.22518 .41005 m
.22589 .41071 L
s
.20321 .41005 m
.20393 .41071 L
s
.24657 .40727 m
.24651 .40836 L
s
.26343 .39221 m
.26338 .39329 L
s
.2296 .42335 m
.22953 .42444 L
s
.26844 .40956 m
.26914 .41023 L
s
.29098 .41016 m
.302 .40668 L
s
.24645 .40944 m
.24715 .41011 L
s
.22447 .40939 m
.22518 .41005 L
s
.24651 .40836 m
.24645 .40944 L
s
.26338 .39329 m
.26333 .39438 L
s
.22953 .42444 m
.22945 .42553 L
s
.26774 .40889 m
.26844 .40956 L
s
.24645 .40944 m
.24639 .41053 L
s
.24574 .40878 m
.24645 .40944 L
s
.22375 .40873 m
.22447 .40939 L
s
.26333 .39438 m
.26328 .39546 L
s
.22945 .42553 m
.22938 .42661 L
s
.3021 .27701 m .31403 .30103 L .28738 .30992 L .539 .317 .527 r
F
.3021 .27701 m .31522 .27258 L .31403 .30103 L F
0 g
.5 Mabswid
.31439 .29227 m
.31621 .29452 L
s
.3021 .27701 m
.31522 .27258 L
s
.31522 .27258 m
.32928 .29015 L
s
.28755 .26509 m
.3021 .27701 L
s
.039 .916 .04 r
1 Mabswid
.28906 .40838 m
.28975 .40906 L
s
.2021 .40893 m
.21291 .40538 L
s
.24639 .41053 m
.24633 .41162 L
s
.26705 .40822 m
.26774 .40889 L
s
.24504 .40811 m
.24574 .40878 L
s
.22304 .40806 m
.22375 .40873 L
s
.26328 .39546 m
.26323 .39655 L
s
.22938 .42661 m
.22931 .4277 L
s
.28837 .4077 m
.28906 .40838 L
s
.24633 .41162 m
.24626 .41271 L
s
.2802 .38066 m
.29118 .37705 L
s
.26635 .40754 m
.26705 .40822 L
s
.24433 .40744 m
.24504 .40811 L
s
.26323 .39655 m
.26317 .39764 L
s
.22931 .4277 m
.22924 .42879 L
s
.22232 .4074 m
.22304 .40806 L
s
.24626 .41271 m
.2462 .4138 L
s
.28768 .40703 m
.28837 .4077 L
s
.26317 .39764 m
.26312 .39873 L
s
.26565 .40687 m
.26635 .40754 L
s
.22924 .42879 m
.22916 .42988 L
s
.24362 .40677 m
.24433 .40744 L
s
.2216 .40674 m
.22232 .4074 L
s
.28004 .3825 m
.27999 .38359 L
s
.22361 .43447 m
.2345 .43106 L
s
.2462 .4138 m
.24613 .41489 L
s
.28699 .40635 m
.28768 .40703 L
s
.26312 .39873 m
.26306 .39981 L
s
.22916 .42988 m
.22909 .43097 L
s
.26495 .4062 m
.26565 .40687 L
s
.27999 .38359 m
.27995 .38467 L
s
.24291 .4061 m
.24362 .40677 L
s
.22089 .40607 m
.2216 .40674 L
s
.24613 .41489 m
.24607 .41598 L
s
.26306 .39981 m
.26301 .4009 L
s
.28629 .40567 m
.28699 .40635 L
s
.27995 .38467 m
.2799 .38576 L
s
.26425 .40552 m
.26495 .4062 L
s
.24607 .41598 m
.246 .41707 L
s
.2422 .40544 m
.24291 .4061 L
s
.22017 .40541 m
.22089 .40607 L
s
.26301 .4009 m
.26295 .402 L
s
.2799 .38576 m
.27986 .38685 L
s
.2856 .405 m
.28629 .40567 L
s
.246 .41707 m
.24594 .41816 L
s
.26354 .40485 m
.26425 .40552 L
s
.24149 .40477 m
.2422 .40544 L
s
.21945 .40474 m
.22017 .40541 L
s
.21291 .40538 m
.22376 .40183 L
s
.26295 .402 m
.2629 .40309 L
s
.27986 .38685 m
.27981 .38794 L
s
.28491 .40432 m
.2856 .405 L
s
.24594 .41816 m
.24587 .41925 L
s
0 g
.5 Mabswid
.30073 .26061 m
.31522 .27258 L
s
.039 .916 .04 r
1 Mabswid
.26284 .40418 m
.26354 .40485 L
s
.29118 .37705 m
.30216 .37343 L
s
.24078 .4041 m
.24149 .40477 L
s
.2629 .40309 m
.26284 .40418 L
s
0 g
.5 Mabswid
.34469 .455 m
.35084 .43892 L
s
.35084 .43892 m
.36408 .43479 L
s
.039 .916 .04 r
1 Mabswid
.27981 .38794 m
.27976 .38903 L
s
.24587 .41925 m
.2458 .42035 L
s
.29573 .38878 m .34854 .39593 L .32184 .40443 L .656 .751 .92 r
F
.039 .916 .04 r
.302 .40668 m
.31439 .40283 L
s
0 g
.5 Mabswid
.32184 .40443 m
.35341 .41804 L
s
.039 .916 .04 r
1 Mabswid
.28421 .40364 m
.28491 .40432 L
s
.26284 .40418 m
.26278 .40527 L
s
.26213 .40351 m
.26284 .40418 L
s
.24007 .40343 m
.24078 .4041 L
s
.27976 .38903 m
.27972 .39013 L
s
.2458 .42035 m
.24574 .42144 L
s
.3056 .40315 m
.30629 .40383 L
s
.2345 .43106 m
.24542 .42763 L
s
.28351 .40296 m
.28421 .40364 L
s
.26278 .40527 m
.26272 .40636 L
s
.26143 .40283 m
.26213 .40351 L
s
.23935 .40276 m
.24007 .40343 L
s
.27972 .39013 m
.27967 .39122 L
s
.24574 .42144 m
.24567 .42253 L
s
.30491 .40247 m
.3056 .40315 L
s
.26272 .40636 m
.26266 .40746 L
s
.28281 .40228 m
.28351 .40296 L
s
.27967 .39122 m
.27962 .39231 L
s
.31439 .40283 m
.32475 .39867 L
s
.26072 .40216 m
.26143 .40283 L
s
.24567 .42253 m
.2456 .42363 L
s
.23864 .40209 m
.23935 .40276 L
s
.26266 .40746 m
.2626 .40855 L
s
.30422 .40179 m
.30491 .40247 L
s
.27962 .39231 m
.27957 .39341 L
s
.28212 .4016 m
.28281 .40228 L
s
.2456 .42363 m
.24553 .42473 L
s
.26001 .40148 m
.26072 .40216 L
s
.29653 .37709 m
.29649 .37819 L
s
.23792 .40142 m
.23864 .40209 L
s
.2626 .40855 m
.26254 .40965 L
s
.22376 .40183 m
.23465 .39827 L
s
.30353 .4011 m
.30422 .40179 L
s
.27957 .39341 m
.27952 .3945 L
s
.24553 .42473 m
.24546 .42582 L
s
.28141 .40093 m
.28212 .4016 L
s
.29649 .37819 m
.29645 .37928 L
s
.2593 .40081 m
.26001 .40148 L
s
.2372 .40075 m
.23792 .40142 L
s
.26254 .40965 m
.26248 .41075 L
s
.30216 .37343 m
.31272 .36975 L
s
.27952 .3945 m
.27947 .3956 L
s
.30284 .40042 m
.30353 .4011 L
s
.29645 .37928 m
.2964 .38037 L
s
.28071 .40025 m
.28141 .40093 L
s
.26248 .41075 m
.26242 .41184 L
s
.25859 .40013 m
.2593 .40081 L
s
.23648 .40008 m
.2372 .40075 L
s
.27947 .3956 m
.27941 .39669 L
s
0 g
.5 Mabswid
.36408 .43479 m
.35802 .45087 L
s
.039 .916 .04 r
1 Mabswid
.2964 .38037 m
.29636 .38147 L
s
.30214 .39974 m
.30284 .40042 L
s
.26242 .41184 m
.26236 .41294 L
s
.28001 .39957 m
.28071 .40025 L
s
.24542 .42763 m
.25638 .42419 L
s
.25788 .39946 m
.25859 .40013 L
s
.23576 .39941 m
.23648 .40008 L
s
.27941 .39669 m
.27936 .39779 L
s
.29636 .38147 m
.29632 .38257 L
s
.30145 .39905 m
.30214 .39974 L
s
.26236 .41294 m
.26229 .41404 L
s
.27931 .39889 m
.28001 .39957 L
s
.25717 .39878 m
.25788 .39946 L
s
.27936 .39779 m
.27931 .39889 L
s
.29632 .38257 m
.29628 .38366 L
s
.26229 .41404 m
.26223 .41514 L
s
.30075 .39837 m
.30145 .39905 L
s
.27931 .39889 m
.27925 .39999 L
s
.2786 .39821 m
.27931 .39889 L
s
.25646 .39811 m
.25717 .39878 L
s
.29628 .38366 m
.29623 .38476 L
s
.26223 .41514 m
.26217 .41624 L
s
.28738 .30992 m .31282 .32988 L .27837 .34123 L .539 .317 .527 r
F
.28738 .30992 m .31403 .30103 L .31282 .32988 L F
0 g
.5 Mabswid
.28738 .30992 m
.3021 .27701 L
s
.31403 .30103 m
.31522 .27258 L
s
.039 .916 .04 r
1 Mabswid
.30006 .39768 m
.30075 .39837 L
s
.27925 .39999 m
.2792 .40109 L
s
.23465 .39827 m
.24557 .39469 L
s
.2779 .39753 m
.2786 .39821 L
s
.29623 .38476 m
.29619 .38586 L
s
.25574 .39743 m
.25646 .39811 L
s
.26217 .41624 m
.2621 .41734 L
s
.2792 .40109 m
.27914 .40219 L
s
.29936 .397 m
.30006 .39768 L
s
.29619 .38586 m
.29614 .38696 L
s
.27719 .39685 m
.2779 .39753 L
s
.32297 .39684 m
.32378 .39748 L
s
.2621 .41734 m
.26203 .41844 L
s
.25503 .39676 m
.25574 .39743 L
s
.27914 .40219 m
.27909 .40329 L
s
.31272 .36975 m
.32332 .36606 L
s
.29614 .38696 m
.29609 .38806 L
s
.29866 .39631 m
.29936 .397 L
s
.26203 .41844 m
.26197 .41955 L
s
.27648 .39617 m
.27719 .39685 L
s
.32217 .3962 m
.32297 .39684 L
s
.25431 .39608 m
.25503 .39676 L
s
.27909 .40329 m
.27903 .40439 L
s
.25638 .42419 m
.26738 .42074 L
s
.29606 .38882 m
.29609 .38806 L
s
.26197 .41955 m
.2619 .42065 L
s
.27577 .39549 m
.27648 .39617 L
s
.31293 .37144 m
.31285 .37253 L
s
.25359 .39541 m
.25431 .39608 L
s
.27903 .40439 m
.27897 .40549 L
s
.29573 .38878 m .33022 .37767 L .34854 .39593 L .656 .751 .92 r
F
.039 .916 .04 r
.32137 .39556 m
.32217 .3962 L
s
.29796 .39563 m
.29866 .39631 L
s
.29605 .38916 m
.29606 .38897 L
s
.32475 .39867 m
.33514 .3945 L
s
0 0 0 r
.11807 .45069 m
.30056 .39206 L
s
0 g
.5 Mabswid
.34854 .39593 m
.36657 .41389 L
s
.039 .916 .04 r
1 Mabswid
.296 .39026 m
.29605 .38916 L
s
.29726 .39494 m
.29796 .39563 L
s
.32058 .39492 m
.32137 .39556 L
s
.31285 .37253 m
.31277 .37362 L
s
.27897 .40549 m
.27891 .4066 L
s
.27506 .39481 m
.27577 .39549 L
s
.25287 .39473 m
.25359 .39541 L
s
.29595 .39137 m
.296 .39026 L
s
.31277 .37362 m
.3127 .37471 L
s
.29656 .39426 m
.29726 .39494 L
s
.27891 .4066 m
.27886 .4077 L
s
.31979 .39427 m
.32058 .39492 L
s
.27435 .39413 m
.27506 .39481 L
s
.25215 .39406 m
.25287 .39473 L
s
.2959 .39247 m
.29595 .39137 L
s
.24557 .39469 m
.25652 .3911 L
s
.33514 .3945 m
.34611 .39002 L
s
.3127 .37471 m
.31262 .3758 L
s
.27886 .4077 m
.2788 .4088 L
s
.31899 .39363 m
.31979 .39427 L
s
.29585 .39357 m
.29656 .39426 L
s
.29585 .39357 m
.2959 .39247 L
s
.27364 .39345 m
.27435 .39413 L
s
.31262 .3758 m
.31255 .37689 L
s
.2788 .4088 m
.27874 .40991 L
s
.31821 .39298 m
.31899 .39363 L
s
0 g
.5 Mabswid
.28755 .26509 m
.30073 .26061 L
s
.28755 .26509 m
.2735 .25966 L
s
.039 .916 .04 r
1 Mabswid
.2958 .39468 m
.29585 .39357 L
s
.29515 .39289 m
.29585 .39357 L
s
.27293 .39276 m
.27364 .39345 L
s
.31248 .37798 m
.31255 .37689 L
s
.27874 .40991 m
.27867 .41102 L
s
.29575 .39578 m
.2958 .39468 L
s
.26738 .42074 m
.27841 .41727 L
s
.31742 .39234 m
.31821 .39298 L
s
.32332 .36606 m
.33395 .36235 L
s
.29444 .3922 m
.29515 .39289 L
s
.31241 .37907 m
.31248 .37798 L
s
.27221 .39208 m
.27293 .39276 L
s
.27867 .41102 m
.27861 .41212 L
s
.2957 .39689 m
.29575 .39578 L
s
.31663 .39169 m
.31742 .39234 L
s
.31235 .38016 m
.31241 .37907 L
s
.29374 .39151 m
.29444 .3922 L
s
.27861 .41212 m
.27855 .41323 L
s
.2715 .3914 m
.27221 .39208 L
s
.2957 .39689 m
.29565 .398 L
s
.31585 .39104 m
.31663 .39169 L
s
.31229 .38125 m
.31235 .38016 L
s
.27855 .41323 m
.27849 .41434 L
s
.29303 .39083 m
.29374 .39151 L
s
.27078 .39072 m
.2715 .3914 L
s
.29565 .398 m
.2956 .3991 L
s
.33863 .39061 m
.33941 .39123 L
s
.31223 .38234 m
.31229 .38125 L
s
.25652 .3911 m
.26751 .3875 L
s
.31507 .39039 m
.31585 .39104 L
s
.27849 .41434 m
.27842 .41545 L
s
.29232 .39014 m
.29303 .39083 L
s
.27006 .39004 m
.27078 .39072 L
s
.2956 .3991 m
.29554 .40021 L
s
.33786 .38999 m
.33863 .39061 L
s
.31217 .38342 m
.31223 .38234 L
s
.31429 .38973 m
.31507 .39039 L
s
.29554 .40021 m
.29549 .40132 L
s
.29161 .38945 m
.29232 .39014 L
s
.26934 .38935 m
.27006 .39004 L
s
.34611 .39002 m
.35618 .38549 L
s
.31217 .38348 m
.31217 .38342 L
s
.33708 .38936 m
.33786 .38999 L
s
.32886 .36585 m
.32878 .36691 L
s
.31352 .38908 m
.31429 .38973 L
s
.29549 .40132 m
.29543 .40243 L
s
.27841 .41727 m
.28947 .4138 L
s
.33631 .38873 m
.33708 .38936 L
s
0 g
.5 Mabswid
.28676 .25513 m
.30073 .26061 L
s
.039 .916 .04 r
1 Mabswid
.26862 .38867 m
.26934 .38935 L
s
.32878 .36691 m
.32871 .36798 L
s
.29543 .40243 m
.29538 .40354 L
s
.32871 .36798 m
.32864 .36904 L
s
.33395 .36235 m
.34436 .35858 L
s
.27443 .37121 m .33022 .37767 L .29573 .38878 L .656 .751 .92 r
F
.039 .916 .04 r
.31274 .38842 m
.31352 .38908 L
s
.2909 .38877 m
.29161 .38945 L
s
0 0 0 r
.30056 .39206 m
.33258 .38002 L
s
0 g
.5 Mabswid
.29573 .38878 m
.32184 .40443 L
s
.039 .916 .04 r
1 Mabswid
.29019 .38808 m
.2909 .38877 L
s
.33554 .38811 m
.33631 .38873 L
s
.29538 .40354 m
.29532 .40466 L
s
.31197 .38777 m
.31274 .38842 L
s
0 g
.5 Mabswid
.33529 .46511 m
.34469 .455 L
s
.34469 .455 m
.35802 .45087 L
s
.039 .916 .04 r
1 Mabswid
.32864 .36904 m
.32857 .3701 L
s
.33478 .38748 m
.33554 .38811 L
s
.28948 .38739 m
.29019 .38808 L
s
.29532 .40466 m
.29526 .40577 L
s
.31193 .38885 m
.31197 .38777 L
s
.3112 .38711 m
.31197 .38777 L
s
.32857 .3701 m
.3285 .37116 L
s
.26751 .3875 m
.27854 .38389 L
s
.33401 .38684 m
.33478 .38748 L
s
.28876 .3867 m
.28948 .38739 L
s
.29526 .40577 m
.29521 .40688 L
s
.31189 .38994 m
.31193 .38885 L
s
.32844 .37222 m
.3285 .37116 L
s
.31044 .38645 m
.3112 .38711 L
s
0 g
.5 Mabswid
.80437 .27132 m
.78491 .29137 L
s
.82759 .25524 m
.80437 .27132 L
s
.039 .916 .04 r
1 Mabswid
.33325 .38621 m
.33401 .38684 L
s
.29521 .40688 m
.29515 .408 L
s
.28805 .38602 m
.28876 .3867 L
s
.32838 .37328 m
.32844 .37222 L
s
.31185 .39102 m
.31189 .38994 L
s
.30967 .38579 m
.31044 .38645 L
s
.33249 .38558 m
.33325 .38621 L
s
.29515 .408 m
.29509 .40911 L
s
.32832 .37434 m
.32838 .37328 L
s
.31181 .39211 m
.31185 .39102 L
s
.28733 .38533 m
.28805 .38602 L
s
.28947 .4138 m
.30054 .41025 L
s
.30891 .38513 m
.30967 .38579 L
s
0 g
.5 Mabswid
.78491 .29137 m
.77046 .31413 L
s
.27837 .34123 m .31159 .35912 L .27443 .37121 L .539 .317 .527 r
F
.27837 .34123 m .31282 .32988 L .31159 .35912 L F
0 g
.27837 .34123 m
.28738 .30992 L
s
.31282 .32988 m
.31403 .30103 L
s
.039 .916 .04 r
1 Mabswid
.33173 .38494 m
.33249 .38558 L
s
.32826 .3754 m
.32832 .37434 L
s
.29509 .40911 m
.29503 .41023 L
s
.31178 .39319 m
.31181 .39211 L
s
.35618 .38549 m
.36629 .38094 L
s
.28661 .38464 m
.28733 .38533 L
s
.30815 .38446 m
.30891 .38513 L
s
.32821 .37646 m
.32826 .3754 L
s
.33098 .38431 m
.33173 .38494 L
s
.31175 .39427 m
.31178 .39319 L
s
.28589 .38395 m
.28661 .38464 L
s
.32816 .37743 m
.32821 .37646 L
s
.30739 .3838 m
.30815 .38446 L
s
.31172 .39536 m
.31175 .39427 L
s
.33022 .38367 m
.33098 .38431 L
s
.34436 .35858 m
.35482 .3548 L
s
0 g
.5 Mabswid
.8531 .24417 m
.82759 .25524 L
s
.039 .916 .04 r
1 Mabswid
.35476 .38367 m
.35558 .38423 L
s
0 g
.5 Mabswid
.35802 .45087 m
.34871 .46096 L
s
.039 .916 .04 r
1 Mabswid
.28517 .38326 m
.28589 .38395 L
s
.27854 .38389 m
.28818 .38058 L
s
.30664 .38313 m
.30739 .3838 L
s
.31169 .39644 m
.31172 .39536 L
s
.32947 .38303 m
.33022 .38367 L
s
.35394 .3831 m
.35476 .38367 L
s
.31169 .39644 m
.31167 .39752 L
s
.34492 .36002 m
.34481 .36106 L
s
.30588 .38246 m
.30664 .38313 L
s
.35313 .38253 m
.35394 .3831 L
s
.32872 .38239 m
.32947 .38303 L
s
.34481 .36106 m
.3447 .3621 L
s
.31167 .39752 m
.31165 .3986 L
s
.35232 .38195 m
.35313 .38253 L
s
.30513 .38179 m
.30588 .38246 L
s
.32798 .38175 m
.32872 .38239 L
s
.30054 .41025 m
.31122 .40594 L
s
.3447 .3621 m
.34459 .36314 L
s
.31165 .3986 m
.31163 .39968 L
s
.35152 .38137 m
.35232 .38195 L
s
.30438 .38112 m
.30513 .38179 L
s
.32794 .38281 m
.32798 .38175 L
s
.32723 .38111 m
.32798 .38175 L
s
.34459 .36314 m
.3445 .36417 L
s
.31163 .39968 m
.31162 .40076 L
s
.35072 .38079 m
.35152 .38137 L
s
.3279 .38386 m
.32794 .38281 L
s
.3445 .36417 m
.34441 .36521 L
s
.30364 .38045 m
.30438 .38112 L
s
.32649 .38046 m
.32723 .38111 L
s
0 g
.5 Mabswid
.77046 .31413 m
.76195 .33815 L
s
.039 .916 .04 r
1 Mabswid
.36629 .38094 m
.37644 .37638 L
s
.31162 .40076 m
.3116 .40184 L
s
.34993 .38021 m
.35072 .38079 L
s
.34441 .36521 m
.34432 .36624 L
s
.32787 .38492 m
.3279 .38386 L
s
.32575 .37982 m
.32649 .38046 L
s
.30289 .37978 m
.30364 .38045 L
s
.3116 .40184 m
.31159 .40292 L
s
.34914 .37963 m
.34993 .38021 L
s
.34432 .36624 m
.34424 .36727 L
s
.32784 .38597 m
.32787 .38492 L
s
.32501 .37917 m
.32575 .37982 L
s
.35482 .3548 m
.36532 .35101 L
s
.30215 .3791 m
.30289 .37978 L
s
.31159 .40292 m
.31158 .404 L
s
.34424 .36727 m
.34416 .3683 L
s
.34836 .37904 m
.34914 .37963 L
s
.32781 .38703 m
.32784 .38597 L
s
.32428 .37852 m
.32501 .37917 L
s
.34416 .3683 m
.34409 .36933 L
s
.30141 .37843 m
.30215 .3791 L
s
.34759 .37845 m
.34836 .37904 L
s
.32778 .38808 m
.32781 .38703 L
s
.34409 .36933 m
.34403 .37036 L
s
.32354 .37787 m
.32428 .37852 L
s
.34682 .37786 m
.34759 .37845 L
s
.30067 .37775 m
.30141 .37843 L
s
.32776 .38914 m
.32778 .38808 L
s
.31122 .40594 m
.32193 .4016 L
s
0 g
.5 Mabswid
.8793 .23885 m
.8531 .24417 L
s
.8531 .24417 m
.8531 .24417 L
s
.8531 .24417 m
.85558 .27277 L
s
.039 .916 .04 r
1 Mabswid
.34403 .37036 m
.34397 .37138 L
s
.32774 .39019 m
.32776 .38914 L
s
.34605 .37726 m
.34682 .37786 L
s
.27443 .37121 m .31159 .35912 L .33022 .37767 L .656 .751 .92 r
F
.039 .916 .04 r
.32281 .37722 m
.32354 .37787 L
s
.28818 .38058 m
.29907 .37676 L
s
0 g
.5 Mabswid
.33022 .37767 m
.34854 .39593 L
s
.039 .916 .04 r
1 Mabswid
.34397 .37138 m
.34391 .37241 L
s
.37001 .37691 m
.3708 .37746 L
s
.32774 .39019 m
.32772 .39124 L
s
.34529 .37667 m
.34605 .37726 L
s
.32208 .37657 m
.32281 .37722 L
s
.34391 .37241 m
.34387 .37343 L
s
.36923 .37637 m
.37001 .37691 L
s
.29907 .37676 m
.31001 .37292 L
s
.32772 .39124 m
.3277 .3923 L
s
.34454 .37607 m
.34529 .37667 L
s
.32135 .37591 m
.32208 .37657 L
s
.34387 .37343 m
.34382 .37445 L
s
.3606 .35427 m
.3605 .35527 L
s
.37644 .37638 m
.38663 .37179 L
s
.36846 .37582 m
.36923 .37637 L
s
.3277 .3923 m
.32769 .39335 L
s
.34379 .37546 m
.34454 .37607 L
s
.34382 .37445 m
.34379 .37546 L
s
.3605 .35527 m
.3604 .35627 L
s
.32063 .37526 m
.32135 .37591 L
s
.36769 .37527 m
.36846 .37582 L
s
0 g
.5 Mabswid
.2735 .25966 m
.28676 .25513 L
s
.2735 .25966 m
.26091 .26124 L
s
.039 .916 .04 r
1 Mabswid
.32769 .39335 m
.32768 .3944 L
s
.3604 .35627 m
.3603 .35726 L
s
.34379 .37546 m
.34375 .37648 L
s
.34304 .37486 m
.34379 .37546 L
s
.36532 .35101 m
.37586 .34719 L
s
.36693 .37472 m
.36769 .37527 L
s
.31991 .3746 m
.32063 .37526 L
s
.32768 .3944 m
.32767 .39545 L
s
.3603 .35726 m
.36021 .35825 L
s
.34375 .37648 m
.34373 .37749 L
s
.3423 .37425 m
.34304 .37486 L
s
.36617 .37416 m
.36693 .37472 L
s
.31919 .37394 m
.31991 .3746 L
s
.36021 .35825 m
.36013 .35924 L
s
.32767 .39545 m
.32766 .3965 L
s
.32193 .4016 m
.33267 .39723 L
s
.34373 .37749 m
.34371 .37851 L
s
.34157 .37364 m
.3423 .37425 L
s
.36542 .3736 m
.36617 .37416 L
s
.36013 .35924 m
.36005 .36023 L
s
.31847 .37328 m
.31919 .37394 L
s
.32766 .3965 m
.32766 .39755 L
s
.34371 .37851 m
.34369 .37952 L
s
.34084 .37302 m
.34157 .37364 L
s
.36467 .37304 m
.36542 .3736 L
s
.36005 .36023 m
.35998 .36122 L
s
.34369 .37952 m
.34368 .38052 L
s
.31775 .37262 m
.31847 .37328 L
s
.35998 .36122 m
.35991 .3622 L
s
.36392 .37248 m
.36467 .37304 L
s
.34012 .37241 m
.34084 .37302 L
s
0 g
.5 Mabswid
.76195 .33815 m
.76001 .36192 L
s
.039 .916 .04 r
1 Mabswid
.34368 .38052 m
.34368 .38153 L
s
.31704 .37196 m
.31775 .37262 L
s
.35991 .3622 m
.35984 .36318 L
s
.36319 .37191 m
.36392 .37248 L
s
.3394 .37179 m
.34012 .37241 L
s
.34368 .38153 m
.34368 .38254 L
s
.35984 .36318 m
.35979 .36416 L
s
.36245 .37134 m
.36319 .37191 L
s
.38663 .37179 m
.39686 .36719 L
s
.33869 .37117 m
.3394 .37179 L
s
.34368 .38254 m
.34368 .38354 L
s
.35979 .36416 m
.35973 .36514 L
s
0 g
.5 Mabswid
.27426 .25667 m
.28676 .25513 L
s
.039 .916 .04 r
1 Mabswid
.36172 .37077 m
.36245 .37134 L
s
.27443 .37121 m .31035 .38876 L .27544 .39998 L .539 .317 .527 r
F
.27443 .37121 m .31159 .35912 L .31035 .38876 L F
.25778 .35172 m .31159 .35912 L .27443 .37121 L .656 .751 .92 r
F
.039 .916 .04 r
.31103 .37256 m
.32039 .36933 L
s
0 g
.5 Mabswid
.27665 .35432 m
.27837 .34123 L
s
.039 .916 .04 r
1 Mabswid
.33798 .37054 m
.33869 .37117 L
s
.34368 .38354 m
.34369 .38454 L
s
.35973 .36514 m
.35968 .36612 L
s
.361 .3702 m
.36172 .37077 L
s
.37586 .34719 m
.38645 .34337 L
s
.38536 .37012 m
.3861 .37064 L
s
.33267 .39723 m
.3432 .39247 L
s
.34369 .38454 m
.34371 .38554 L
s
.35968 .36612 m
.35964 .3671 L
s
.33728 .36992 m
.33798 .37054 L
s
.36028 .36962 m
.361 .3702 L
s
.38462 .3696 m
.38536 .37012 L
s
.35964 .3671 m
.3596 .36807 L
s
0 g
.5 Mabswid
.32319 .46842 m
.33529 .46511 L
s
.33529 .46511 m
.34871 .46096 L
s
.039 .916 .04 r
1 Mabswid
.34371 .38554 m
.34373 .38654 L
s
.33658 .36929 m
.33728 .36992 L
s
.37639 .3485 m
.37629 .34945 L
s
.35957 .36905 m
.36028 .36962 L
s
.38388 .36907 m
.38462 .3696 L
s
.3596 .36807 m
.35957 .36905 L
s
.34373 .38654 m
.34376 .38754 L
s
.32039 .36933 m
.33128 .36535 L
s
.33589 .36866 m
.33658 .36929 L
s
.37629 .34945 m
.3762 .3504 L
s
.38315 .36855 m
.38388 .36907 L
s
.35957 .36905 m
.35954 .37002 L
s
.35886 .36847 m
.35957 .36905 L
s
.34376 .38754 m
.34379 .38853 L
s
0 g
.5 Mabswid
.90449 .23971 m
.8793 .23885 L
s
.039 .916 .04 r
1 Mabswid
.3762 .3504 m
.37611 .35135 L
s
.3352 .36802 m
.33589 .36866 L
s
.38243 .36802 m
.38315 .36855 L
s
.35954 .37002 m
.35952 .37099 L
s
.35816 .36788 m
.35886 .36847 L
s
.34379 .38853 m
.34383 .38953 L
s
.37611 .35135 m
.37603 .35229 L
s
.33452 .36738 m
.3352 .36802 L
s
.35952 .37099 m
.35951 .37195 L
s
.38171 .36749 m
.38243 .36802 L
s
.35746 .3673 m
.35816 .36788 L
s
.37603 .35229 m
.37595 .35324 L
s
.34383 .38953 m
.34388 .39052 L
s
.35951 .37195 m
.35949 .37292 L
s
.38099 .36695 m
.38171 .36749 L
s
.33385 .36674 m
.33452 .36738 L
s
.37595 .35324 m
.37588 .35418 L
s
.35677 .36671 m
.35746 .3673 L
s
.39686 .36719 m
.40713 .36257 L
s
.35949 .37292 m
.35949 .37389 L
s
.38028 .36641 m
.38099 .36695 L
s
.37588 .35418 m
.37581 .35512 L
s
.33318 .3661 m
.33385 .36674 L
s
.35608 .36612 m
.35677 .36671 L
s
.3432 .39247 m
.35377 .3877 L
s
.35949 .37389 m
.35949 .37485 L
s
.37581 .35512 m
.37575 .35606 L
s
.37958 .36588 m
.38028 .36641 L
s
.38645 .34337 m
.39707 .33952 L
s
.3554 .36552 m
.35608 .36612 L
s
.37575 .35606 m
.37569 .357 L
s
.35949 .37485 m
.35949 .37581 L
s
.37888 .36533 m
.37958 .36588 L
s
0 g
.5 Mabswid
.34871 .46096 m
.3367 .46424 L
s
.039 .916 .04 r
1 Mabswid
.35473 .36493 m
.3554 .36552 L
s
.37569 .357 m
.37564 .35794 L
s
.35949 .37581 m
.3595 .37677 L
s
.33128 .36535 m
.34221 .36135 L
s
.37818 .36479 m
.37888 .36533 L
s
.37564 .35794 m
.37559 .35887 L
s
.35405 .36433 m
.35473 .36493 L
s
.3595 .37677 m
.35952 .37773 L
s
.37749 .36424 m
.37818 .36479 L
s
.37559 .35887 m
.37554 .3598 L
s
.35952 .37773 m
.35954 .37868 L
s
.35339 .36373 m
.35405 .36433 L
s
.3768 .3637 m
.37749 .36424 L
s
.37554 .3598 m
.37551 .36073 L
s
.35954 .37868 m
.35956 .37964 L
s
.40079 .36329 m
.4015 .36378 L
s
.35272 .36313 m
.35339 .36373 L
s
.37612 .36315 m
.3768 .3637 L
s
.37551 .36073 m
.37547 .36166 L
s
.40009 .36279 m
.40079 .36329 L
s
.35956 .37964 m
.35959 .38059 L
s
.37545 .36259 m
.37612 .36315 L
s
.35207 .36252 m
.35272 .36313 L
s
.37547 .36166 m
.37545 .36259 L
s
.39226 .34269 m
.39217 .34359 L
s
.3994 .36229 m
.40009 .36279 L
s
.35959 .38059 m
.35963 .38154 L
s
0 g
.5 Mabswid
.85558 .27277 m
.8581 .30177 L
s
.039 .916 .04 r
1 Mabswid
.37545 .36259 m
.37542 .36352 L
s
.37478 .36204 m
.37545 .36259 L
s
.40713 .36257 m
.41745 .35793 L
s
.35142 .36191 m
.35207 .36252 L
s
.35377 .3877 m
.36438 .38291 L
s
.39217 .34359 m
.39209 .3445 L
s
.39871 .36178 m
.3994 .36229 L
s
.35963 .38154 m
.35967 .38249 L
s
.37542 .36352 m
.37541 .36444 L
s
.37411 .36148 m
.37478 .36204 L
s
.39209 .3445 m
.39201 .3454 L
s
0 g
.5 Mabswid
.76001 .36192 m
.76485 .38386 L
s
.76001 .36192 m
.79326 .35176 L
s
.76001 .36192 m
.76001 .36192 L
s
.039 .916 .04 r
1 Mabswid
.35077 .3613 m
.35142 .36191 L
s
.39802 .36128 m
.39871 .36178 L
s
.35967 .38249 m
.35972 .38344 L
s
.37541 .36444 m
.37539 .36537 L
s
.39707 .33952 m
.40774 .33566 L
s
.39201 .3454 m
.39193 .3463 L
s
.37345 .36092 m
.37411 .36148 L
s
.34221 .36135 m
.35317 .35734 L
s
.35013 .36069 m
.35077 .3613 L
s
.39734 .36077 m
.39802 .36128 L
s
.39193 .3463 m
.39186 .3472 L
s
.37539 .36537 m
.37539 .36629 L
s
.37279 .36036 m
.37345 .36092 L
s
.39666 .36026 m
.39734 .36077 L
s
.34949 .36007 m
.35013 .36069 L
s
.39186 .3472 m
.39179 .3481 L
s
.37539 .36629 m
.37539 .36721 L
s
.37214 .35979 m
.37279 .36036 L
s
.39599 .35975 m
.39666 .36026 L
s
.39179 .3481 m
.39173 .34899 L
s
.37539 .36721 m
.37539 .36813 L
s
.37149 .35922 m
.37214 .35979 L
s
.39173 .34899 m
.39168 .34989 L
s
.39532 .35924 m
.39599 .35975 L
s
.37539 .36813 m
.3754 .36904 L
s
.39168 .34989 m
.39162 .35078 L
s
.39466 .35872 m
.39532 .35924 L
s
.37085 .35865 m
.37149 .35922 L
s
.25778 .35172 m .29265 .34025 L .31159 .35912 L .656 .751 .92 r
F
0 g
.5 Mabswid
.31159 .35912 m
.31282 .32988 L
s
.31159 .35912 m
.33022 .37767 L
s
.039 .916 .04 r
1 Mabswid
.3754 .36904 m
.37541 .36996 L
s
.39162 .35078 m
.39158 .35167 L
s
.394 .3582 m
.39466 .35872 L
s
.37022 .35808 m
.37085 .35865 L
s
.37541 .36996 m
.37543 .37087 L
s
.36438 .38291 m
.37503 .3781 L
s
.39158 .35167 m
.39153 .35256 L
s
.39335 .35768 m
.394 .3582 L
s
.37543 .37087 m
.37545 .37178 L
s
.36958 .35751 m
.37022 .35808 L
s
.39153 .35256 m
.3915 .35345 L
s
.41745 .35793 m
.42781 .35327 L
s
.3927 .35716 m
.39335 .35768 L
s
.37545 .37178 m
.37548 .37269 L
s
.36896 .35693 m
.36958 .35751 L
s
.3915 .35345 m
.39146 .35433 L
s
.35317 .35734 m
.36418 .35332 L
s
.39205 .35663 m
.3927 .35716 L
s
.37548 .37269 m
.37551 .3736 L
s
.39146 .35433 m
.39144 .35522 L
s
.40774 .33566 m
.41846 .33179 L
s
.36833 .35635 m
.36896 .35693 L
s
.41632 .35641 m
.41699 .35688 L
s
0 g
.5 Mabswid
.26091 .26124 m
.25068 .26989 L
s
.27426 .25667 m
.26091 .26124 L
s
.92699 .24677 m
.90449 .23971 L
s
.039 .916 .04 r
1 Mabswid
.39141 .3561 m
.39205 .35663 L
s
.39144 .35522 m
.39141 .3561 L
s
.37551 .3736 m
.37555 .37451 L
s
.41566 .35594 m
.41632 .35641 L
s
.36772 .35577 m
.36833 .35635 L
s
.39141 .3561 m
.3914 .35698 L
s
.39078 .35557 m
.39141 .3561 L
s
.40823 .33684 m
.40815 .3377 L
s
.37555 .37451 m
.37559 .37541 L
s
.41501 .35546 m
.41566 .35594 L
s
.3671 .35518 m
.36772 .35577 L
s
.3914 .35698 m
.39138 .35786 L
s
.40815 .3377 m
.40807 .33856 L
s
.39015 .35504 m
.39078 .35557 L
s
.37559 .37541 m
.37564 .37632 L
s
.41435 .35498 m
.41501 .35546 L
s
.40807 .33856 m
.408 .33942 L
s
.3665 .3546 m
.3671 .35518 L
s
.39138 .35786 m
.39137 .35874 L
s
.38952 .35451 m
.39015 .35504 L
s
.41371 .3545 m
.41435 .35498 L
s
.27544 .39998 m .30909 .41882 L .28173 .42749 L .539 .317 .527 r
F
.27544 .39998 m .31035 .38876 L .30909 .41882 L F
0 g
.5 Mabswid
.27443 .37121 m
.27544 .39998 L
s
.31035 .38876 m
.31159 .35912 L
s
.039 .916 .04 r
1 Mabswid
.408 .33942 m
.40793 .34027 L
s
.39137 .35874 m
.39137 .35962 L
s
.36589 .35401 m
.3665 .3546 L
s
.3889 .35397 m
.38952 .35451 L
s
.41306 .35402 m
.41371 .3545 L
s
.37503 .3781 m
.38571 .37328 L
s
.40793 .34027 m
.40786 .34112 L
s
.39137 .35962 m
.39137 .36049 L
s
.41242 .35353 m
.41306 .35402 L
s
.38829 .35343 m
.3889 .35397 L
s
.40786 .34112 m
.4078 .34198 L
s
.39137 .36049 m
.39138 .36137 L
s
.41179 .35304 m
.41242 .35353 L
s
.4078 .34198 m
.40775 .34283 L
s
.38768 .35289 m
.38829 .35343 L
s
.36418 .35332 m
.37522 .34928 L
s
.42781 .35327 m
.43821 .34859 L
s
.39138 .36137 m
.39139 .36224 L
s
.40775 .34283 m
.4077 .34368 L
s
.41116 .35256 m
.41179 .35304 L
s
.38707 .35234 m
.38768 .35289 L
s
.39139 .36224 m
.3914 .36311 L
s
.4077 .34368 m
.40765 .34452 L
s
.41053 .35206 m
.41116 .35256 L
s
0 g
.5 Mabswid
.26412 .2653 m
.27426 .25667 L
s
.039 .916 .04 r
1 Mabswid
.41846 .33179 m
.42922 .3279 L
s
.38647 .3518 m
.38707 .35234 L
s
.3914 .36311 m
.39142 .36398 L
s
.40765 .34452 m
.40761 .34537 L
s
.40991 .35157 m
.41053 .35206 L
s
.39142 .36398 m
.39145 .36485 L
s
.38587 .35125 m
.38647 .3518 L
s
.40761 .34537 m
.40757 .34621 L
s
0 g
.5 Mabswid
.79326 .35176 m
.8268 .34152 L
s
.2461 .33015 m .29265 .34025 L .25778 .35172 L .656 .751 .92 r
F
0 g
.25778 .35172 m
.27443 .37121 L
s
.039 .916 .04 r
1 Mabswid
.4093 .35107 m
.40991 .35157 L
s
.40757 .34621 m
.40754 .34706 L
s
.39145 .36485 m
.39148 .36571 L
s
.38528 .3507 m
.38587 .35125 L
s
.40868 .35058 m
.4093 .35107 L
s
0 g
.5 Mabswid
.30916 .46454 m
.32319 .46842 L
s
.32319 .46842 m
.3367 .46424 L
s
.039 .916 .04 r
1 Mabswid
.40754 .34706 m
.40751 .3479 L
s
.39148 .36571 m
.39151 .36658 L
s
.38469 .35015 m
.38528 .3507 L
s
.40808 .35008 m
.40868 .35058 L
s
.40751 .3479 m
.40749 .34874 L
s
.39151 .36658 m
.39155 .36744 L
s
.38571 .37328 m
.39644 .36844 L
s
.38411 .34959 m
.38469 .35015 L
s
.40747 .34957 m
.40808 .35008 L
s
.40749 .34874 m
.40747 .34957 L
s
.43195 .34949 m
.43257 .34994 L
s
.39155 .36744 m
.3916 .3683 L
s
.38353 .34903 m
.38411 .34959 L
s
.40747 .34957 m
.40746 .35041 L
s
.40687 .34907 m
.40747 .34957 L
s
.43133 .34904 m
.43195 .34949 L
s
.3916 .3683 m
.39165 .36916 L
s
.37522 .34928 m
.3863 .34522 L
s
.4243 .33096 m
.42422 .33177 L
s
.40746 .35041 m
.40745 .35125 L
s
.40628 .34856 m
.40687 .34907 L
s
.43071 .34859 m
.43133 .34904 L
s
.38295 .34847 m
.38353 .34903 L
s
.42422 .33177 m
.42415 .33259 L
s
0 g
.5 Mabswid
.76485 .38386 m
.77628 .40248 L
s
.039 .916 .04 r
1 Mabswid
.40745 .35125 m
.40744 .35208 L
s
.43821 .34859 m
.44866 .3439 L
s
.43009 .34814 m
.43071 .34859 L
s
.40569 .34806 m
.40628 .34856 L
s
.38238 .34791 m
.38295 .34847 L
s
.42415 .33259 m
.42409 .3334 L
s
.40744 .35208 m
.40744 .35291 L
s
.42948 .34768 m
.43009 .34814 L
s
.4051 .34754 m
.40569 .34806 L
s
.42409 .3334 m
.42402 .33421 L
s
.40744 .35291 m
.40745 .35374 L
s
.42922 .3279 m
.44002 .32399 L
s
.42888 .34722 m
.42948 .34768 L
s
.42402 .33421 m
.42397 .33501 L
s
.40452 .34703 m
.4051 .34754 L
s
.40745 .35374 m
.40746 .35457 L
s
.42828 .34676 m
.42888 .34722 L
s
.42397 .33501 m
.42391 .33582 L
s
0 g
.5 Mabswid
.8581 .30177 m
.86065 .33118 L
s
.039 .916 .04 r
1 Mabswid
.40395 .34652 m
.40452 .34703 L
s
.40746 .35457 m
.40747 .3554 L
s
.42768 .3463 m
.42828 .34676 L
s
.42391 .33582 m
.42386 .33662 L
s
0 g
.5 Mabswid
.3367 .46424 m
.32275 .46032 L
s
.039 .916 .04 r
1 Mabswid
.40338 .346 m
.40395 .34652 L
s
.40747 .3554 m
.40749 .35622 L
s
.42386 .33662 m
.42382 .33743 L
s
.42709 .34584 m
.42768 .3463 L
s
.39644 .36844 m
.4072 .36358 L
s
.82582 .32292 m
.82981 .32966 L
s
.40281 .34548 m
.40338 .346 L
s
.40749 .35622 m
.40751 .35705 L
s
.42382 .33743 m
.42378 .33823 L
s
.4265 .34537 m
.42709 .34584 L
s
.42378 .33823 m
.42374 .33903 L
s
.40225 .34496 m
.40281 .34548 L
s
.40751 .35705 m
.40754 .35787 L
s
.42592 .3449 m
.4265 .34537 L
s
.3863 .34522 m
.39742 .34116 L
s
.42374 .33903 m
.42371 .33983 L
s
.40754 .35787 m
.40757 .35869 L
s
.40169 .34443 m
.40225 .34496 L
s
.42534 .34443 m
.42592 .3449 L
s
.42371 .33983 m
.42368 .34063 L
s
.40757 .35869 m
.40761 .35951 L
s
.40113 .34391 m
.40169 .34443 L
s
.42476 .34396 m
.42534 .34443 L
s
.42368 .34063 m
.42366 .34142 L
s
.40761 .35951 m
.40765 .36033 L
s
.42419 .34349 m
.42476 .34396 L
s
.40058 .34338 m
.40113 .34391 L
s
.44866 .3439 m
.45914 .33918 L
s
.42366 .34142 m
.42364 .34222 L
s
.40765 .36033 m
.40769 .36115 L
s
.81352 .33622 m
.81697 .34359 L
s
.42362 .34301 m
.42419 .34349 L
s
.42364 .34222 m
.42362 .34301 L
s
.40004 .34285 m
.40058 .34338 L
s
.40769 .36115 m
.40774 .36196 L
s
.44002 .32399 m
.45086 .32007 L
s
.42362 .34301 m
.42361 .3438 L
s
.42306 .34253 m
.42362 .34301 L
s
0 g
.5 Mabswid
.94525 .25969 m
.92699 .24677 L
s
.039 .916 .04 r
1 Mabswid
.44767 .34253 m
.44826 .34296 L
s
.3995 .34232 m
.40004 .34285 L
s
.42361 .3438 m
.42361 .34459 L
s
.44709 .34211 m
.44767 .34253 L
s
.4225 .34205 m
.42306 .34253 L
s
.39896 .34178 m
.3995 .34232 L
s
.44046 .32504 m
.4404 .32581 L
s
.42361 .34459 m
.42361 .34538 L
s
.4072 .36358 m
.418 .3587 L
s
.44651 .34168 m
.44709 .34211 L
s
.42195 .34157 m
.4225 .34205 L
s
.4404 .32581 m
.44033 .32658 L
s
.42361 .34538 m
.42361 .34617 L
s
.44593 .34125 m
.44651 .34168 L
s
.4214 .34108 m
.42195 .34157 L
s
0 g
.5 Mabswid
.8268 .34152 m
.86065 .33118 L
s
.039 .916 .04 r
1 Mabswid
.44033 .32658 m
.44027 .32734 L
s
.42361 .34617 m
.42362 .34695 L
s
.44536 .34082 m
.44593 .34125 L
s
.39742 .34116 m
.40858 .33707 L
s
.44027 .32734 m
.44022 .3281 L
s
.42085 .3406 m
.4214 .34108 L
s
.42362 .34695 m
.42363 .34774 L
s
.44479 .34039 m
.44536 .34082 L
s
.44022 .3281 m
.44016 .32887 L
s
.42031 .34011 m
.42085 .3406 L
s
.42363 .34774 m
.42364 .34852 L
s
.44423 .33995 m
.44479 .34039 L
s
0 0 0 r
.83066 .34034 m
.83066 .34034 L
s
.039 .916 .04 r
.44016 .32887 m
.44012 .32963 L
s
.2461 .33015 m .2734 .32107 L .29265 .34025 L .656 .751 .92 r
F
0 g
.5 Mabswid
.29265 .34025 m
.31159 .35912 L
s
.039 .916 .04 r
1 Mabswid
.41977 .33962 m
.42031 .34011 L
s
.42364 .34852 m
.42366 .3493 L
s
.44367 .33952 m
.44423 .33995 L
s
.44012 .32963 m
.44007 .33039 L
s
.41924 .33913 m
.41977 .33962 L
s
.44007 .33039 m
.44003 .33114 L
s
.42366 .3493 m
.42369 .35008 L
s
.44311 .33908 m
.44367 .33952 L
s
.45914 .33918 m
.46967 .33444 L
s
.44003 .33114 m
.44 .3319 L
s
.41871 .33863 m
.41924 .33913 L
s
.42369 .35008 m
.42372 .35086 L
s
.44256 .33864 m
.44311 .33908 L
s
.44 .3319 m
.43996 .33265 L
s
.42372 .35086 m
.42375 .35163 L
s
.44202 .33819 m
.44256 .33864 L
s
.41819 .33814 m
.41871 .33863 L
s
.8218 .31613 m
.82582 .32292 L
s
.45086 .32007 m
.46175 .31613 L
s
.43996 .33265 m
.43994 .33341 L
s
.42375 .35163 m
.42379 .35241 L
s
.44147 .33775 m
.44202 .33819 L
s
.41767 .33764 m
.41819 .33814 L
s
0 g
.5 Mabswid
.25068 .26989 m
.26412 .2653 L
s
.25068 .26989 m
.24359 .28517 L
s
.039 .916 .04 r
1 Mabswid
.43994 .33341 m
.43991 .33416 L
s
.418 .3587 m
.42884 .3538 L
s
.42379 .35241 m
.42383 .35318 L
s
.44093 .3373 m
.44147 .33775 L
s
.41715 .33714 m
.41767 .33764 L
s
.43991 .33416 m
.43989 .33491 L
s
.42383 .35318 m
.42388 .35396 L
s
.4404 .33686 m
.44093 .3373 L
s
.43989 .33491 m
.43988 .33566 L
s
.41664 .33663 m
.41715 .33714 L
s
.83975 .32997 m
.84438 .33708 L
s
.40858 .33707 m
.41978 .33298 L
s
.42388 .35396 m
.42393 .35473 L
s
.43987 .33641 m
.4404 .33686 L
s
.43988 .33566 m
.43987 .33641 L
s
.41613 .33613 m
.41664 .33663 L
s
.28173 .42749 m .30781 .44929 L .29416 .45356 L .539 .317 .527 r
F
.28173 .42749 m .30909 .41882 L .30781 .44929 L F
0 g
.5 Mabswid
.27544 .39998 m
.28173 .42749 L
s
.28173 .42749 m
.29416 .45356 L
s
.30909 .41882 m
.31035 .38876 L
s
.039 .916 .04 r
1 Mabswid
.43987 .33641 m
.43986 .33715 L
s
.43934 .33595 m
.43987 .33641 L
s
.81006 .32881 m
.81352 .33622 L
s
.41563 .33562 m
.41613 .33613 L
s
.43986 .33715 m
.43986 .3379 L
s
.43882 .3355 m
.43934 .33595 L
s
.46349 .33553 m
.46403 .33593 L
s
.43986 .3379 m
.43986 .33864 L
s
.46294 .33513 m
.46349 .33553 L
s
.4383 .33504 m
.43882 .3355 L
s
.45673 .31909 m
.45667 .31981 L
s
.43986 .33864 m
.43986 .33938 L
s
.4624 .33473 m
.46294 .33513 L
s
.43778 .33459 m
.4383 .33504 L
s
.45667 .31981 m
.45661 .32053 L
s
.43986 .33938 m
.43987 .34012 L
s
.46186 .33432 m
.4624 .33473 L
s
.43727 .33413 m
.43778 .33459 L
s
.82743 .34334 m
.83151 .35108 L
s
.45661 .32053 m
.45655 .32125 L
s
.46967 .33444 m
.48025 .32969 L
s
.43987 .34012 m
.43989 .34086 L
s
.46133 .33392 m
.46186 .33432 L
s
0 g
.5 Mabswid
.77628 .40248 m
.79363 .41646 L
s
.039 .916 .04 r
1 Mabswid
.45655 .32125 m
.4565 .32197 L
s
.43677 .33367 m
.43727 .33413 L
s
.82375 .32027 m
.82382 .3209 L
s
.43989 .34086 m
.43991 .3416 L
s
.4608 .33351 m
.46133 .33392 L
s
.42884 .3538 m
.43972 .34889 L
s
.4565 .32197 m
.45646 .32268 L
s
.82382 .3209 m
.82388 .32153 L
s
.46175 .31613 m
.47269 .31218 L
s
.43626 .3332 m
.43677 .33367 L
s
0 g
.5 Mabswid
.25712 .28058 m
.26412 .2653 L
s
.039 .916 .04 r
1 Mabswid
.43991 .3416 m
.43993 .34234 L
s
.46027 .3331 m
.4608 .33351 L
s
.45646 .32268 m
.45641 .3234 L
s
.82388 .32153 m
.82394 .32215 L
s
.43576 .33274 m
.43626 .3332 L
s
.82394 .32215 m
.824 .32277 L
s
.43993 .34234 m
.43995 .34307 L
s
.45641 .3234 m
.45638 .32411 L
s
.45975 .33269 m
.46027 .3331 L
s
.41978 .33298 m
.43102 .32887 L
s
.824 .32277 m
.82406 .32339 L
s
.45638 .32411 m
.45634 .32482 L
s
.43527 .33227 m
.43576 .33274 L
s
.43995 .34307 m
.43998 .3438 L
s
.45923 .33228 m
.45975 .33269 L
s
.82406 .32339 m
.82412 .32401 L
s
0 g
.5 Mabswid
.29416 .45356 m
.30916 .46454 L
s
.30916 .46454 m
.32275 .46032 L
s
.039 .916 .04 r
1 Mabswid
.45634 .32482 m
.45631 .32553 L
s
.43998 .3438 m
.44002 .34454 L
s
.45872 .33186 m
.45923 .33228 L
s
.82412 .32401 m
.82418 .32462 L
s
.43478 .3318 m
.43527 .33227 L
s
.45631 .32553 m
.45628 .32624 L
s
.82418 .32462 m
.82423 .32523 L
s
.8137 .33179 m
.81292 .33194 L
s
.44002 .34454 m
.44006 .34527 L
s
.45821 .33145 m
.45872 .33186 L
s
.43429 .33133 m
.43478 .3318 L
s
.81449 .33164 m
.8137 .33179 L
s
.82423 .32523 m
.82429 .32584 L
s
.81527 .33149 m
.81449 .33164 L
s
.45628 .32624 m
.45626 .32695 L
s
.81606 .33133 m
.81527 .33149 L
s
.44006 .34527 m
.4401 .346 L
s
.4577 .33103 m
.45821 .33145 L
s
.82429 .32584 m
.82434 .32645 L
s
.81684 .33118 m
.81606 .33133 L
s
.43381 .33086 m
.43429 .33133 L
s
.45626 .32695 m
.45624 .32765 L
s
0 g
.5 Mabswid
.86324 .36099 m
.86065 .33118 L
s
.86065 .33118 m
.89481 .32075 L
s
.039 .916 .04 r
1 Mabswid
.81762 .33102 m
.81684 .33118 L
s
.81776 .3093 m
.8218 .31613 L
s
.82434 .32645 m
.82439 .32706 L
s
.4401 .346 m
.44015 .34672 L
s
.4572 .33061 m
.4577 .33103 L
s
.8184 .33085 m
.81762 .33102 L
s
.45624 .32765 m
.45623 .32836 L
s
.43333 .33038 m
.43381 .33086 L
s
.81918 .33069 m
.8184 .33085 L
s
.82439 .32706 m
.82445 .32766 L
s
.81996 .33052 m
.81918 .33069 L
s
.4567 .33019 m
.4572 .33061 L
s
.44015 .34672 m
.4402 .34745 L
s
.82073 .33035 m
.81996 .33052 L
s
.45623 .32836 m
.45621 .32906 L
s
.82445 .32766 m
.8245 .32827 L
s
.43286 .32991 m
.43333 .33038 L
s
.82151 .33018 m
.82073 .33035 L
s
.45621 .32976 m
.4567 .33019 L
s
.82228 .33001 m
.82151 .33018 L
s
.24021 .30614 m .2734 .32107 L .2461 .33015 L .656 .751 .92 r
F
0 g
.5 Mabswid
.2461 .33015 m
.25778 .35172 L
s
.039 .916 .04 r
1 Mabswid
.45621 .32906 m
.45621 .32976 L
s
.8245 .32827 m
.82454 .32887 L
s
.82305 .32983 m
.82228 .33001 L
s
.83509 .32282 m
.83975 .32997 L
s
.43239 .32943 m
.43286 .32991 L
s
.82382 .32965 m
.82305 .32983 L
s
.82454 .32887 m
.82459 .32947 L
s
.45621 .32976 m
.4562 .33047 L
s
.45571 .32934 m
.45621 .32976 L
s
.43972 .34889 m
.45064 .34396 L
s
.48025 .32969 m
.49087 .32491 L
s
.82459 .32947 m
.82382 .32965 L
s
.82459 .32947 m
.82464 .33006 L
s
.82536 .32928 m
.82459 .32947 L
s
.4562 .33047 m
.4562 .33117 L
s
.45523 .32891 m
.45571 .32934 L
s
.82613 .32909 m
.82536 .32928 L
s
.82464 .33006 m
.82468 .33066 L
s
.82689 .3289 m
.82613 .32909 L
s
.4562 .33117 m
.45621 .33186 L
s
.47269 .31218 m
.48367 .30821 L
s
.45474 .32848 m
.45523 .32891 L
s
.82766 .32871 m
.82689 .3289 L
s
.43102 .32887 m
.4423 .32474 L
s
.4794 .32849 m
.47991 .32886 L
s
.82468 .33066 m
.82473 .33125 L
s
.80657 .32135 m
.81006 .32881 L
s
.82842 .32852 m
.82766 .32871 L
s
.45621 .33186 m
.45621 .33256 L
s
.82918 .32832 m
.82842 .32852 L
s
.82473 .33125 m
.82477 .33184 L
s
.47889 .32811 m
.4794 .32849 L
s
.45426 .32805 m
.45474 .32848 L
s
.82994 .32812 m
.82918 .32832 L
s
.47309 .3131 m
.47304 .31377 L
s
.45621 .33256 m
.45623 .33326 L
s
0 g
.5 Mabswid
.95794 .27768 m
.94525 .25969 L
s
.039 .916 .04 r
1 Mabswid
.82477 .33184 m
.82481 .33243 L
s
.8307 .32792 m
.82994 .32812 L
s
.47839 .32773 m
.47889 .32811 L
s
.45379 .32762 m
.45426 .32805 L
s
0 g
.5 Mabswid
.30781 .44929 m
.32275 .46032 L
s
.039 .916 .04 r
1 Mabswid
.83146 .32771 m
.8307 .32792 L
s
.47304 .31377 m
.47298 .31445 L
s
.45623 .33326 m
.45624 .33395 L
s
.82481 .33243 m
.82485 .33301 L
s
.47789 .32736 m
.47839 .32773 L
s
.83222 .3275 m
.83146 .32771 L
s
.45331 .32719 m
.45379 .32762 L
s
.82332 .33555 m
.82743 .34334 L
s
.47298 .31445 m
.47294 .31512 L
s
.83297 .32729 m
.83222 .3275 L
s
0 g
.5 Mabswid
.30781 .44929 m
.30909 .41882 L
s
.039 .916 .04 r
1 Mabswid
.82485 .33301 m
.82489 .3336 L
s
.45624 .33395 m
.45626 .33464 L
s
.4774 .32698 m
.47789 .32736 L
s
.83373 .32708 m
.83297 .32729 L
s
.47294 .31512 m
.47289 .31579 L
s
.45285 .32675 m
.45331 .32719 L
s
.82489 .3336 m
.82493 .33418 L
s
.83448 .32687 m
.83373 .32708 L
s
.45626 .33464 m
.45628 .33533 L
s
.4769 .32659 m
.4774 .32698 L
s
.47289 .31579 m
.47285 .31646 L
s
.83523 .32665 m
.83448 .32687 L
s
.82493 .33418 m
.82496 .33476 L
s
.45238 .32631 m
.45285 .32675 L
s
.45628 .33533 m
.45631 .33602 L
s
.83598 .32643 m
.83523 .32665 L
s
.47642 .32621 m
.4769 .32659 L
s
.47285 .31646 m
.47281 .31713 L
s
.82496 .33476 m
.825 .33534 L
s
.45192 .32587 m
.45238 .32631 L
s
.45631 .33602 m
.45634 .33671 L
s
.47281 .31713 m
.47278 .3178 L
s
.47593 .32583 m
.47642 .32621 L
s
.825 .33534 m
.82503 .33591 L
s
.45634 .33671 m
.45638 .3374 L
s
.47278 .3178 m
.47275 .31846 L
s
.45146 .32543 m
.45192 .32587 L
s
.47545 .32544 m
.47593 .32583 L
s
.82503 .33591 m
.82507 .33649 L
s
.47275 .31846 m
.47272 .31913 L
s
.45064 .34396 m
.46159 .33901 L
s
.45638 .3374 m
.45642 .33809 L
s
.47497 .32505 m
.47545 .32544 L
s
.45101 .32499 m
.45146 .32543 L
s
.82507 .33649 m
.8251 .33706 L
s
.47272 .31913 m
.4727 .31979 L
s
.45642 .33809 m
.45646 .33877 L
s
.8251 .33706 m
.82513 .33763 L
s
.4745 .32466 m
.47497 .32505 L
s
.45056 .32454 m
.45101 .32499 L
s
.49087 .32491 m
.50153 .32012 L
s
.4727 .31979 m
.47268 .32045 L
s
.4423 .32474 m
.45362 .3206 L
s
.82513 .33763 m
.82516 .3382 L
s
.45646 .33877 m
.45651 .33945 L
s
.47403 .32427 m
.4745 .32466 L
s
.45012 .3241 m
.45056 .32454 L
s
.47268 .32045 m
.47266 .32111 L
s
.45651 .33945 m
.45656 .34014 L
s
.48367 .30821 m
.49469 .30422 L
s
.47356 .32388 m
.47403 .32427 L
s
.47266 .32111 m
.47265 .32177 L
s
.44967 .32365 m
.45012 .3241 L
s
.4731 .32348 m
.47356 .32388 L
s
.47265 .32177 m
.47264 .32243 L
s
.44924 .3232 m
.44967 .32365 L
s
.81369 .30243 m
.81776 .3093 L
s
.47264 .32308 m
.4731 .32348 L
s
.47264 .32243 m
.47264 .32308 L
s
.47264 .32308 m
.47264 .32374 L
s
.47218 .32269 m
.47264 .32308 L
s
.8304 .31562 m
.83509 .32282 L
s
.8177 .30999 m
.81776 .31057 L
s
.47264 .32374 m
.47264 .32439 L
s
.47173 .32229 m
.47218 .32269 L
s
.81776 .31057 m
.81782 .31115 L
s
.47264 .32439 m
.47265 .32505 L
s
.47128 .32189 m
.47173 .32229 L
s
.81782 .31115 m
.81788 .31172 L
s
.47265 .32505 m
.47266 .3257 L
s
.81788 .31172 m
.81793 .3123 L
s
.47084 .32148 m
.47128 .32189 L
s
.49541 .3214 m
.49588 .32175 L
s
.81793 .3123 m
.81799 .31287 L
s
.47266 .3257 m
.47267 .32635 L
s
.47039 .32108 m
.47084 .32148 L
s
.49494 .32105 m
.49541 .3214 L
s
.81799 .31287 m
.81804 .31344 L
s
.80306 .31383 m
.80657 .32135 L
s
.46159 .33901 m
.47259 .33405 L
s
.47267 .32635 m
.47269 .327 L
s
.48956 .30707 m
.48951 .3077 L
s
.81804 .31344 m
.81809 .31401 L
s
.46996 .32067 m
.47039 .32108 L
s
.24021 .30614 m .25382 .30156 L .2734 .32107 L .656 .751 .92 r
F
0 g
.5 Mabswid
.25382 .30156 m
.2734 .32107 L
s
.2734 .32107 m
.29265 .34025 L
s
.24021 .30614 m
.2461 .33015 L
s
.039 .916 .04 r
1 Mabswid
.49448 .3207 m
.49494 .32105 L
s
.47269 .327 m
.47271 .32765 L
s
.48951 .3077 m
.48946 .30833 L
s
.81809 .31401 m
.81814 .31457 L
s
.80835 .32066 m
.80761 .3208 L
s
0 g
.5 Mabswid
.89481 .32075 m
.92928 .31022 L
s
.24021 .30614 m
.24359 .28517 L
s
.25712 .28058 m
.24359 .28517 L
s
.039 .916 .04 r
1 Mabswid
.49402 .32034 m
.49448 .3207 L
s
.46952 .32026 m
.46996 .32067 L
s
.80908 .32052 m
.80835 .32066 L
s
.45362 .3206 m
.46499 .31644 L
s
.48946 .30833 m
.48942 .30895 L
s
.47271 .32765 m
.47273 .32829 L
s
.81918 .32771 m
.82332 .33555 L
s
.81814 .31457 m
.81819 .31514 L
s
.80981 .32038 m
.80908 .32052 L
s
.81053 .32023 m
.80981 .32038 L
s
.49356 .31999 m
.49402 .32034 L
s
.46909 .31985 m
.46952 .32026 L
s
.81819 .31514 m
.81824 .3157 L
s
.48942 .30895 m
.48938 .30958 L
s
.81126 .32009 m
.81053 .32023 L
s
.47273 .32829 m
.47276 .32894 L
s
.50153 .32012 m
.51224 .3153 L
s
.81199 .31994 m
.81126 .32009 L
s
.49311 .31963 m
.49356 .31999 L
s
.81824 .3157 m
.81829 .31626 L
s
.81271 .31979 m
.81199 .31994 L
s
.48938 .30958 m
.48934 .3102 L
s
.46866 .31944 m
.46909 .31985 L
s
.47276 .32894 m
.47279 .32958 L
s
.81344 .31963 m
.81271 .31979 L
s
.81829 .31626 m
.81834 .31682 L
s
.49266 .31928 m
.49311 .31963 L
s
.81416 .31948 m
.81344 .31963 L
s
.48934 .3102 m
.48931 .31082 L
s
.49469 .30422 m
.50576 .30022 L
s
.81488 .31932 m
.81416 .31948 L
s
.47279 .32958 m
.47283 .33022 L
s
.46824 .31903 m
.46866 .31944 L
s
.81834 .31682 m
.81838 .31738 L
s
.8156 .31916 m
.81488 .31932 L
s
.48931 .31082 m
.48928 .31144 L
s
.49221 .31892 m
.49266 .31928 L
s
0 g
.5 Mabswid
.79363 .41646 m
.81582 .42474 L
s
.039 .916 .04 r
1 Mabswid
.81632 .31899 m
.8156 .31916 L
s
.81838 .31738 m
.81843 .31793 L
s
.47283 .33022 m
.47287 .33086 L
s
.46782 .31861 m
.46824 .31903 L
s
.81704 .31883 m
.81632 .31899 L
s
.48928 .31144 m
.48925 .31206 L
s
.49176 .31856 m
.49221 .31892 L
s
.81775 .31866 m
.81704 .31883 L
s
.81843 .31793 m
.81847 .31849 L
s
.47287 .33086 m
.47291 .3315 L
s
.48925 .31206 m
.48923 .31268 L
s
.81847 .31849 m
.81775 .31866 L
s
.4674 .3182 m
.46782 .31861 L
s
.49132 .3182 m
.49176 .31856 L
s
.81847 .31849 m
.81851 .31904 L
s
.81918 .31831 m
.81847 .31849 L
s
.48923 .31268 m
.48921 .3133 L
s
.47291 .3315 m
.47296 .33214 L
s
.8199 .31814 m
.81918 .31831 L
s
.49089 .31783 m
.49132 .3182 L
s
.46699 .31778 m
.4674 .3182 L
s
.81851 .31904 m
.81855 .31959 L
s
.82061 .31796 m
.8199 .31814 L
s
.48921 .3133 m
.4892 .31391 L
s
.82132 .31778 m
.82061 .31796 L
s
.47296 .33214 m
.47301 .33278 L
s
.81855 .31959 m
.81859 .32014 L
s
.49045 .31747 m
.49089 .31783 L
s
.82203 .3176 m
.82132 .31778 L
s
.46658 .31736 m
.46699 .31778 L
s
.4892 .31391 m
.48918 .31453 L
s
.82274 .31741 m
.82203 .3176 L
s
.81859 .32014 m
.81863 .32068 L
s
.49002 .3171 m
.49045 .31747 L
s
.82344 .31723 m
.82274 .31741 L
s
.46618 .31694 m
.46658 .31736 L
s
.48918 .31453 m
.48918 .31514 L
s
.81863 .32068 m
.81867 .32122 L
s
.82415 .31704 m
.82344 .31723 L
s
.47259 .33405 m
.48363 .32906 L
s
.48959 .31674 m
.49002 .3171 L
s
.82485 .31685 m
.82415 .31704 L
s
.48918 .31514 m
.48917 .31575 L
s
.81867 .32122 m
.8187 .32177 L
s
.82556 .31665 m
.82485 .31685 L
s
.48917 .31637 m
.48959 .31674 L
s
.48917 .31575 m
.48917 .31637 L
s
.82626 .31646 m
.82556 .31665 L
s
.8187 .32177 m
.81874 .32231 L
s
.82696 .31626 m
.82626 .31646 L
s
.46499 .31644 m
.47639 .31227 L
s
.48917 .31637 m
.48917 .31698 L
s
.48875 .31599 m
.48917 .31637 L
s
.81874 .32231 m
.81877 .32284 L
s
.82766 .31606 m
.82696 .31626 L
s
0 g
.5 Mabswid
.25382 .30156 m
.25712 .28058 L
s
.039 .916 .04 r
1 Mabswid
.82836 .31585 m
.82766 .31606 L
s
.48917 .31698 m
.48917 .31758 L
s
.81877 .32284 m
.81881 .32338 L
s
.48833 .31562 m
.48875 .31599 L
s
0 g
.5 Mabswid
.29416 .45356 m
.30781 .44929 L
s
.27924 .43614 m
.29416 .45356 L
s
.039 .916 .04 r
1 Mabswid
.8096 .29551 m
.81369 .30243 L
s
.82906 .31565 m
.82836 .31585 L
s
.48917 .31758 m
.48918 .31819 L
s
.81881 .32338 m
.81884 .32391 L
s
.48792 .31525 m
.48833 .31562 L
s
.82568 .30838 m
.8304 .31562 L
s
.81884 .32391 m
.81887 .32445 L
s
.48918 .31819 m
.48919 .3188 L
s
.51224 .3153 m
.52299 .31047 L
s
.4875 .31487 m
.48792 .31525 L
s
0 g
.5 Mabswid
.86586 .39123 m
.86324 .36099 L
s
.039 .916 .04 r
1 Mabswid
.81887 .32445 m
.8189 .32498 L
s
.48919 .3188 m
.48921 .3194 L
s
.4871 .3145 m
.4875 .31487 L
s
.50576 .30022 m
.51688 .2962 L
s
.8189 .32498 m
.81893 .32551 L
s
.48921 .3194 m
.48923 .32001 L
s
.51152 .31427 m
.51196 .31459 L
s
.48669 .31412 m
.4871 .3145 L
s
.81893 .32551 m
.81895 .32603 L
s
.48923 .32001 m
.48925 .32061 L
s
.51109 .31394 m
.51152 .31427 L
s
.48629 .31374 m
.48669 .31412 L
s
.50612 .30101 m
.50608 .30159 L
s
.81895 .32603 m
.81898 .32656 L
s
.48925 .32061 m
.48928 .32121 L
s
.51067 .31362 m
.51109 .31394 L
s
.79953 .30627 m
.80306 .31383 L
s
.50608 .30159 m
.50604 .30217 L
s
.4859 .31336 m
.48629 .31374 L
s
.48928 .32121 m
.4893 .32181 L
s
.51024 .31329 m
.51067 .31362 L
s
.50604 .30217 m
.506 .30275 L
s
.81502 .31983 m
.81918 .32771 L
s
.4855 .31297 m
.4859 .31336 L
s
0 g
.5 Mabswid
.96406 .29959 m
.95794 .27768 L
s
.039 .916 .04 r
1 Mabswid
.4893 .32181 m
.48934 .32241 L
s
.50982 .31296 m
.51024 .31329 L
s
.506 .30275 m
.50596 .30333 L
s
.48511 .31259 m
.4855 .31297 L
s
.48934 .32241 m
.48937 .32301 L
s
.50941 .31263 m
.50982 .31296 L
s
.50596 .30333 m
.50593 .3039 L
s
.48363 .32906 m
.49471 .32406 L
s
.50899 .3123 m
.50941 .31263 L
s
.50593 .3039 m
.5059 .30448 L
s
.48937 .32301 m
.48941 .3236 L
s
.48472 .3122 m
.48511 .31259 L
s
.5059 .30448 m
.50588 .30505 L
s
.50858 .31197 m
.50899 .3123 L
s
.47639 .31227 m
.48783 .30809 L
s
.48941 .3236 m
.48945 .3242 L
s
.48434 .31181 m
.48472 .3122 L
s
.50588 .30505 m
.50586 .30563 L
s
.50817 .31164 m
.50858 .31197 L
s
.48945 .3242 m
.4895 .32479 L
s
.48396 .31142 m
.48434 .31181 L
s
.50586 .30563 m
.50584 .3062 L
s
.50777 .3113 m
.50817 .31164 L
s
.4895 .32479 m
.48955 .32538 L
s
.50584 .3062 m
.50582 .30677 L
s
.48358 .31103 m
.48396 .31142 L
s
0 g
.5 Mabswid
.29294 .43181 m
.30781 .44929 L
s
.039 .916 .04 r
1 Mabswid
.81159 .2996 m
.81165 .30013 L
s
.50737 .31097 m
.50777 .3113 L
s
.50582 .30677 m
.50581 .30734 L
s
.81165 .30013 m
.8117 .30066 L
s
.48321 .31064 m
.48358 .31103 L
s
.50697 .31063 m
.50737 .31097 L
s
.8117 .30066 m
.81175 .30119 L
s
.50581 .30734 m
.5058 .30791 L
s
.50658 .31029 m
.50697 .31063 L
s
.81175 .30119 m
.8118 .30172 L
s
.5058 .30791 m
.5058 .30848 L
s
.52299 .31047 m
.53378 .30561 L
s
.8118 .30172 m
.81185 .30225 L
s
.50618 .30995 m
.50658 .31029 L
s
.5058 .30848 m
.50579 .30904 L
s
0 g
.5 Mabswid
.92928 .31022 m
.96406 .29959 L
s
.039 .916 .04 r
1 Mabswid
.81185 .30225 m
.8119 .30277 L
s
.51688 .2962 m
.52804 .29216 L
s
.50579 .30961 m
.50618 .30995 L
s
.50579 .30904 m
.50579 .30961 L
s
.8119 .30277 m
.81195 .30329 L
s
.50579 .30961 m
.5058 .31017 L
s
.50541 .30926 m
.50579 .30961 L
s
.81195 .30329 m
.81199 .30381 L
s
.80293 .30942 m
.80226 .30955 L
s
.80361 .30929 m
.80293 .30942 L
s
.81199 .30381 m
.81204 .30433 L
s
.5058 .31017 m
.5058 .31073 L
s
.80428 .30916 m
.80361 .30929 L
s
.50503 .30892 m
.50541 .30926 L
s
.80496 .30903 m
.80428 .30916 L
s
.81204 .30433 m
.81208 .30485 L
s
.80563 .30889 m
.80496 .30903 L
s
.5058 .31073 m
.50581 .3113 L
s
.50465 .30857 m
.50503 .30892 L
s
.8063 .30875 m
.80563 .30889 L
s
.81208 .30485 m
.81213 .30536 L
s
.80697 .30861 m
.8063 .30875 L
s
.49471 .32406 m
.50583 .31904 L
s
.50581 .3113 m
.50583 .31186 L
s
.80764 .30847 m
.80697 .30861 L
s
.50427 .30823 m
.50465 .30857 L
s
.81213 .30536 m
.81217 .30587 L
s
.80831 .30832 m
.80764 .30847 L
s
.82093 .30109 m
.82568 .30838 L
s
.50583 .31186 m
.50584 .31242 L
s
.80897 .30817 m
.80831 .30832 L
s
.81217 .30587 m
.81221 .30639 L
s
.5039 .30788 m
.50427 .30823 L
s
.80547 .28854 m
.8096 .29551 L
s
.80964 .30802 m
.80897 .30817 L
s
.48783 .30809 m
.49932 .30388 L
s
.50584 .31242 m
.50586 .31297 L
s
.8103 .30787 m
.80964 .30802 L
s
.81221 .30639 m
.81225 .3069 L
s
.50353 .30753 m
.5039 .30788 L
s
.81097 .30772 m
.8103 .30787 L
s
.50586 .31297 m
.50589 .31353 L
s
.81163 .30756 m
.81097 .30772 L
s
.81225 .3069 m
.81229 .3074 L
s
.81229 .3074 m
.81163 .30756 L
s
.50316 .30718 m
.50353 .30753 L
s
.50589 .31353 m
.50591 .31409 L
s
.81229 .3074 m
.81233 .30791 L
s
.81295 .30724 m
.81229 .3074 L
s
.52773 .30709 m
.52813 .30738 L
s
.81361 .30708 m
.81295 .30724 L
s
.50279 .30682 m
.50316 .30718 L
s
.81233 .30791 m
.81236 .30841 L
s
.50591 .31409 m
.50594 .31464 L
s
.52734 .30679 m
.52773 .30709 L
s
.81426 .30692 m
.81361 .30708 L
s
.52279 .29491 m
.52275 .29544 L
s
.81492 .30675 m
.81426 .30692 L
s
.81236 .30841 m
.8124 .30892 L
s
.50243 .30647 m
.50279 .30682 L
s
.52695 .30649 m
.52734 .30679 L
s
.50594 .31464 m
.50597 .3152 L
s
.81558 .30658 m
.81492 .30675 L
s
.52275 .29544 m
.52271 .29598 L
s
.81623 .30641 m
.81558 .30658 L
s
.8124 .30892 m
.81243 .30942 L
s
.52657 .30619 m
.52695 .30649 L
s
.50208 .30611 m
.50243 .30647 L
s
.50597 .3152 m
.50601 .31575 L
s
.52271 .29598 m
.52268 .29651 L
s
.81688 .30623 m
.81623 .30641 L
s
.81083 .3119 m
.81502 .31983 L
s
.81243 .30942 m
.81247 .30992 L
s
.79597 .29866 m
.79953 .30627 L
s
.81753 .30606 m
.81688 .30623 L
s
.52619 .30589 m
.52657 .30619 L
s
.52268 .29651 m
.52265 .29704 L
s
0 g
.5 Mabswid
.24021 .30614 m
.25382 .30156 L
s
.24021 .30614 m
.24087 .33136 L
s
.039 .916 .04 r
1 Mabswid
.50601 .31575 m
.50605 .3163 L
s
.50172 .30575 m
.50208 .30611 L
s
.81819 .30588 m
.81753 .30606 L
s
.81247 .30992 m
.8125 .31041 L
s
.52581 .30559 m
.52619 .30589 L
s
.81884 .3057 m
.81819 .30588 L
s
.52265 .29704 m
.52262 .29757 L
s
.50605 .3163 m
.50609 .31685 L
s
.50137 .3054 m
.50172 .30575 L
s
.8125 .31041 m
.81253 .31091 L
s
.81948 .30552 m
.81884 .3057 L
s
.53378 .30561 m
.54463 .30073 L
s
.52262 .29757 m
.5226 .2981 L
s
.52543 .30529 m
.52581 .30559 L
s
.82013 .30533 m
.81948 .30552 L
s
.50609 .31685 m
.50613 .3174 L
s
.81253 .31091 m
.81256 .3114 L
s
.50102 .30503 m
.50137 .3054 L
s
.82078 .30515 m
.82013 .30533 L
s
.5226 .2981 m
.52258 .29863 L
s
.52506 .30498 m
.52543 .30529 L
s
.82142 .30496 m
.82078 .30515 L
s
.52804 .29216 m
.53925 .28811 L
s
.50613 .3174 m
.50618 .31795 L
s
.81256 .3114 m
.81259 .31189 L
s
.52258 .29863 m
.52256 .29915 L
s
.50067 .30467 m
.50102 .30503 L
s
.52468 .30467 m
.52506 .30498 L
s
.82207 .30477 m
.82142 .30496 L
s
0 g
.5 Mabswid
.81582 .42474 m
.84138 .42663 L
s
.039 .916 .04 r
1 Mabswid
.81259 .31189 m
.81262 .31238 L
s
.52256 .29915 m
.52255 .29968 L
s
.52432 .30437 m
.52468 .30467 L
s
.50033 .30431 m
.50067 .30467 L
s
.81262 .31238 m
.81265 .31287 L
s
.52255 .29968 m
.52253 .3002 L
s
.50583 .31904 m
.51699 .314 L
s
.52395 .30406 m
.52432 .30437 L
s
.81265 .31287 m
.81267 .31336 L
s
.52253 .3002 m
.52253 .30073 L
s
.52359 .30375 m
.52395 .30406 L
s
.52253 .30073 m
.52252 .30125 L
s
.81267 .31336 m
.8127 .31384 L
s
.49932 .30388 m
.51085 .29967 L
s
.52323 .30344 m
.52359 .30375 L
s
.52252 .30125 m
.52252 .30177 L
s
.8127 .31384 m
.81272 .31433 L
s
.52287 .30312 m
.52323 .30344 L
s
.52252 .30177 m
.52251 .30229 L
s
.81272 .31433 m
.81275 .31481 L
s
.52252 .30281 m
.52287 .30312 L
s
.52251 .30229 m
.52252 .30281 L
s
.52252 .30281 m
.52252 .30333 L
s
.52217 .30249 m
.52252 .30281 L
s
.52252 .30333 m
.52253 .30384 L
s
.52182 .30218 m
.52217 .30249 L
s
0 g
.5 Mabswid
.2655 .41344 m
.27924 .43614 L
s
.27924 .43614 m
.29294 .43181 L
s
.039 .916 .04 r
1 Mabswid
.52253 .30384 m
.52254 .30436 L
s
.52147 .30186 m
.52182 .30218 L
s
.52254 .30436 m
.52256 .30488 L
s
.52113 .30154 m
.52147 .30186 L
s
.52256 .30488 m
.52257 .30539 L
s
0 g
.5 Mabswid
.25382 .30156 m
.25454 .32681 L
s
.039 .916 .04 r
1 Mabswid
.52079 .30122 m
.52113 .30154 L
s
.52257 .30539 m
.52259 .3059 L
s
.52045 .3009 m
.52079 .30122 L
s
.81615 .29376 m
.82093 .30109 L
s
.52259 .3059 m
.52262 .30641 L
s
.52012 .30058 m
.52045 .3009 L
s
.52262 .30641 m
.52264 .30693 L
s
.54463 .30073 m
.55551 .29584 L
s
.51979 .30025 m
.52012 .30058 L
s
.52264 .30693 m
.52267 .30743 L
s
.80132 .28152 m
.80547 .28854 L
s
.53925 .28811 m
.5505 .28404 L
s
.51946 .29993 m
.51979 .30025 L
s
.52267 .30743 m
.5227 .30794 L
s
.51699 .314 m
.52819 .30894 L
s
.54405 .29987 m
.5444 .30014 L
s
.51913 .2996 m
.51946 .29993 L
s
.5227 .30794 m
.52274 .30845 L
s
.54369 .2996 m
.54405 .29987 L
s
.80542 .28911 m
.80547 .28959 L
s
.53956 .28877 m
.53953 .28926 L
s
.51085 .29967 m
.52242 .29544 L
s
.80547 .28959 m
.80552 .29008 L
s
.51881 .29927 m
.51913 .2996 L
s
.54334 .29932 m
.54369 .2996 L
s
.52274 .30845 m
.52277 .30896 L
s
0 g
.5 Mabswid
.96307 .32394 m
.96406 .29959 L
s
.96406 .29959 m
.96406 .29959 L
s
.039 .916 .04 r
1 Mabswid
.53953 .28926 m
.53949 .28974 L
s
.80552 .29008 m
.80556 .29056 L
s
.54299 .29905 m
.54334 .29932 L
s
.52277 .30896 m
.52281 .30946 L
s
.51849 .29894 m
.51881 .29927 L
s
.53949 .28974 m
.53947 .29023 L
s
.80662 .30392 m
.81083 .3119 L
s
.80556 .29056 m
.80561 .29104 L
s
.54265 .29878 m
.54299 .29905 L
s
.53947 .29023 m
.53944 .29071 L
s
.52281 .30946 m
.52286 .30997 L
s
.51818 .29861 m
.51849 .29894 L
s
.80561 .29104 m
.80565 .29152 L
s
.54231 .2985 m
.54265 .29878 L
s
.53944 .29071 m
.53942 .2912 L
s
0 g
.5 Mabswid
.86586 .39123 m
.86852 .4219 L
s
.039 .916 .04 r
1 Mabswid
.52286 .30997 m
.5229 .31047 L
s
.80565 .29152 m
.8057 .29199 L
s
.79239 .291 m
.79597 .29866 L
s
.51786 .29828 m
.51818 .29861 L
s
.53942 .2912 m
.5394 .29168 L
s
.54197 .29823 m
.54231 .2985 L
s
.8057 .29199 m
.80574 .29247 L
s
.51755 .29795 m
.51786 .29828 L
s
.5394 .29168 m
.53938 .29216 L
s
.54163 .29795 m
.54197 .29823 L
s
.80574 .29247 m
.80578 .29294 L
s
.79747 .29808 m
.79685 .29819 L
s
.79809 .29796 m
.79747 .29808 L
s
.53938 .29216 m
.53937 .29264 L
s
.79871 .29783 m
.79809 .29796 L
s
.80578 .29294 m
.80582 .29342 L
s
.54129 .29767 m
.54163 .29795 L
s
.79933 .29771 m
.79871 .29783 L
s
0 g
.5 Mabswid
.29294 .43181 m
.27924 .40905 L
s
.039 .916 .04 r
1 Mabswid
.53937 .29264 m
.53935 .29312 L
s
.80582 .29342 m
.80586 .29389 L
s
.79994 .29758 m
.79933 .29771 L
s
.54096 .29739 m
.54129 .29767 L
s
.80056 .29745 m
.79994 .29758 L
s
.53935 .29312 m
.53935 .2936 L
s
.80586 .29389 m
.8059 .29435 L
s
.80117 .29732 m
.80056 .29745 L
s
.54063 .29711 m
.54096 .29739 L
s
.80178 .29719 m
.80117 .29732 L
s
.53935 .2936 m
.53934 .29407 L
s
.8059 .29435 m
.80594 .29482 L
s
.8024 .29706 m
.80178 .29719 L
s
.5403 .29683 m
.54063 .29711 L
s
.80301 .29692 m
.8024 .29706 L
s
.53934 .29407 m
.53933 .29455 L
s
.80594 .29482 m
.80598 .29529 L
s
.80362 .29678 m
.80301 .29692 L
s
.53998 .29654 m
.5403 .29683 L
s
.80423 .29664 m
.80362 .29678 L
s
.53933 .29455 m
.53933 .29502 L
s
.80598 .29529 m
.80601 .29575 L
s
.80483 .2965 m
.80423 .29664 L
s
.53966 .29626 m
.53998 .29654 L
s
.80544 .29636 m
.80483 .2965 L
s
.53933 .29502 m
.53933 .2955 L
s
.80601 .29575 m
.80605 .29621 L
s
.80605 .29621 m
.80544 .29636 L
s
.53934 .29597 m
.53966 .29626 L
s
.53933 .2955 m
.53934 .29597 L
s
.80605 .29621 m
.80608 .29667 L
s
.80665 .29606 m
.80605 .29621 L
s
.80726 .29591 m
.80665 .29606 L
s
.53934 .29597 m
.53935 .29644 L
s
.53902 .29568 m
.53934 .29597 L
s
.80608 .29667 m
.80611 .29713 L
s
.80786 .29576 m
.80726 .29591 L
s
.52819 .30894 m
.53943 .30386 L
s
.55551 .29584 m
.56645 .29092 L
s
.80846 .29561 m
.80786 .29576 L
s
.53935 .29644 m
.53935 .29692 L
s
.80611 .29713 m
.80615 .29759 L
s
.53871 .2954 m
.53902 .29568 L
s
.80906 .29545 m
.80846 .29561 L
s
.5505 .28404 m
.56181 .27995 L
s
.80966 .2953 m
.80906 .29545 L
s
.53935 .29692 m
.53937 .29739 L
s
.80615 .29759 m
.80618 .29805 L
s
.52242 .29544 m
.53403 .29119 L
s
0 g
.5 Mabswid
.24087 .33136 m
.25454 .32681 L
s
.24087 .33136 m
.24557 .35903 L
s
.039 .916 .04 r
1 Mabswid
.5384 .29511 m
.53871 .2954 L
s
.81026 .29514 m
.80966 .2953 L
s
.53937 .29739 m
.53938 .29785 L
s
.80618 .29805 m
.80621 .2985 L
s
.81086 .29497 m
.81026 .29514 L
s
.53809 .29482 m
.5384 .29511 L
s
.81145 .29481 m
.81086 .29497 L
s
.53938 .29785 m
.5394 .29832 L
s
.80621 .2985 m
.80624 .29895 L
s
.53778 .29453 m
.53809 .29482 L
s
.81205 .29464 m
.81145 .29481 L
s
.5394 .29832 m
.53942 .29879 L
s
.80624 .29895 m
.80626 .2994 L
s
.81264 .29448 m
.81205 .29464 L
s
.53748 .29423 m
.53778 .29453 L
s
.81324 .29431 m
.81264 .29448 L
s
.80626 .2994 m
.80629 .29985 L
s
.53942 .29879 m
.53944 .29926 L
s
.81383 .29413 m
.81324 .29431 L
s
.53718 .29394 m
.53748 .29423 L
s
.81442 .29396 m
.81383 .29413 L
s
.80629 .29985 m
.80632 .3003 L
s
.53944 .29926 m
.53947 .29972 L
s
.81501 .29378 m
.81442 .29396 L
s
.53688 .29364 m
.53718 .29394 L
s
.80632 .3003 m
.80634 .30074 L
s
.53947 .29972 m
.5395 .30019 L
s
.81134 .28638 m
.81615 .29376 L
s
.53658 .29335 m
.53688 .29364 L
s
.5395 .30019 m
.53953 .30065 L
s
.80634 .30074 m
.80637 .30119 L
s
.53629 .29305 m
.53658 .29335 L
s
.53953 .30065 m
.53956 .30111 L
s
.80637 .30119 m
.80639 .30163 L
s
.536 .29275 m
.53629 .29305 L
s
0 g
.5 Mabswid
.25399 .38708 m
.2655 .41344 L
s
.2655 .41344 m
.27924 .40905 L
s
.039 .916 .04 r
1 Mabswid
.53956 .30111 m
.5396 .30157 L
s
.80639 .30163 m
.80641 .30207 L
s
.56046 .2926 m
.56078 .29284 L
s
.5396 .30157 m
.53964 .30203 L
s
.53571 .29245 m
.536 .29275 L
s
.80641 .30207 m
.80643 .30251 L
s
.79715 .27446 m
.80132 .28152 L
s
.56014 .29236 m
.56046 .2926 L
s
.55643 .28259 m
.5564 .28303 L
s
.53964 .30203 m
.53968 .30249 L
s
.80643 .30251 m
.80645 .30295 L
s
.53543 .29215 m
.53571 .29245 L
s
.55983 .29211 m
.56014 .29236 L
s
.5564 .28303 m
.55638 .28347 L
s
0 g
.5 Mabswid
.84138 .42663 m
.86852 .4219 L
s
.039 .916 .04 r
1 Mabswid
.53968 .30249 m
.53972 .30295 L
s
.53514 .29185 m
.53543 .29215 L
s
.55952 .29187 m
.55983 .29211 L
s
.55638 .28347 m
.55636 .28391 L
s
.80238 .29588 m
.80662 .30392 L
s
.55921 .29162 m
.55952 .29187 L
s
.55636 .28391 m
.55633 .28435 L
s
.53486 .29154 m
.53514 .29185 L
s
.55633 .28435 m
.55631 .28478 L
s
.55891 .29137 m
.55921 .29162 L
s
.53943 .30386 m
.55071 .29877 L
s
.55631 .28478 m
.5563 .28522 L
s
.5586 .29112 m
.55891 .29137 L
s
.53403 .29119 m
.54568 .28693 L
s
.5563 .28522 m
.55628 .28565 L
s
.5583 .29087 m
.5586 .29112 L
s
.78878 .28329 m
.79239 .291 L
s
.55628 .28565 m
.55627 .28609 L
s
.56645 .29092 m
.57743 .28598 L
s
.558 .29062 m
.5583 .29087 L
s
0 g
.5 Mabswid
.25929 .35452 m
.25454 .32681 L
s
.039 .916 .04 r
1 Mabswid
.55627 .28609 m
.55626 .28652 L
s
.55771 .29037 m
.558 .29062 L
s
.56181 .27995 m
.57316 .27585 L
s
.55626 .28652 m
.55626 .28695 L
s
.55741 .29012 m
.55771 .29037 L
s
.55626 .28695 m
.55625 .28738 L
s
.55712 .28986 m
.55741 .29012 L
s
.55625 .28738 m
.55625 .28781 L
s
.55683 .28961 m
.55712 .28986 L
s
.55625 .28781 m
.55625 .28824 L
s
.55654 .28935 m
.55683 .28961 L
s
.55625 .28824 m
.55625 .28867 L
s
0 g
.5 Mabswid
.24557 .35903 m
.25929 .35452 L
s
.24557 .35903 m
.25399 .38708 L
s
.039 .916 .04 r
1 Mabswid
.55626 .28909 m
.55654 .28935 L
s
.55625 .28867 m
.55626 .28909 L
s
.55626 .28909 m
.55627 .28952 L
s
.55598 .28884 m
.55626 .28909 L
s
.55627 .28952 m
.55628 .28994 L
s
.5557 .28858 m
.55598 .28884 L
s
.55628 .28994 m
.55629 .29037 L
s
0 g
.5 Mabswid
.25399 .38708 m
.26773 .38263 L
s
.039 .916 .04 r
1 Mabswid
.55542 .28832 m
.5557 .28858 L
s
0 g
.5 Mabswid
.27924 .40905 m
.26773 .38263 L
s
.039 .916 .04 r
1 Mabswid
.55629 .29037 m
.55631 .29079 L
s
.55514 .28805 m
.55542 .28832 L
s
.79919 .27851 m
.79923 .27895 L
s
.55631 .29079 m
.55632 .29122 L
s
.55487 .28779 m
.55514 .28805 L
s
.79923 .27895 m
.79928 .27939 L
s
.55632 .29122 m
.55634 .29164 L
s
0 g
.5 Mabswid
.95494 .349 m
.96307 .32394 L
s
.039 .916 .04 r
1 Mabswid
.5546 .28753 m
.55487 .28779 L
s
.79928 .27939 m
.79932 .27982 L
s
.55634 .29164 m
.55636 .29206 L
s
.79932 .27982 m
.79936 .28025 L
s
.55433 .28726 m
.5546 .28753 L
s
.55636 .29206 m
.55639 .29248 L
s
.79936 .28025 m
.7994 .28068 L
s
.55071 .29877 m
.56204 .29366 L
s
.55407 .287 m
.55433 .28726 L
s
.55639 .29248 m
.55642 .2929 L
s
.7994 .28068 m
.79944 .28111 L
s
.5538 .28673 m
.55407 .287 L
s
.79944 .28111 m
.79947 .28154 L
s
.54568 .28693 m
.55738 .28265 L
s
.55642 .2929 m
.55645 .29331 L
s
.55354 .28646 m
.5538 .28673 L
s
.79195 .28662 m
.79139 .28672 L
s
.79947 .28154 m
.79951 .28197 L
s
.55645 .29331 m
.55648 .29373 L
s
.79252 .28651 m
.79195 .28662 L
s
.79308 .28639 m
.79252 .28651 L
s
.79951 .28197 m
.79955 .28239 L
s
.55328 .2862 m
.55354 .28646 L
s
.55648 .29373 m
.55651 .29415 L
s
.79364 .28628 m
.79308 .28639 L
s
.8065 .27896 m
.81134 .28638 L
s
.7942 .28617 m
.79364 .28628 L
s
.79955 .28239 m
.79958 .28282 L
s
.55303 .28593 m
.55328 .2862 L
s
.55651 .29415 m
.55655 .29456 L
s
.79476 .28605 m
.7942 .28617 L
s
.79958 .28282 m
.79962 .28324 L
s
.79532 .28593 m
.79476 .28605 L
s
.57743 .28598 m
.58845 .28102 L
s
.79587 .28581 m
.79532 .28593 L
s
.55655 .29456 m
.55659 .29498 L
s
.55277 .28565 m
.55303 .28593 L
s
.79962 .28324 m
.79965 .28366 L
s
.79643 .28569 m
.79587 .28581 L
s
.57316 .27585 m
.58455 .27173 L
s
.79698 .28556 m
.79643 .28569 L
s
.55659 .29498 m
.55663 .29539 L
s
.55252 .28538 m
.55277 .28565 L
s
.79965 .28366 m
.79968 .28408 L
s
.79754 .28544 m
.79698 .28556 L
s
.57698 .28529 m
.57726 .2855 L
s
.79809 .28531 m
.79754 .28544 L
s
.55227 .28511 m
.55252 .28538 L
s
.79968 .28408 m
.79971 .2845 L
s
.79864 .28518 m
.79809 .28531 L
s
.5767 .28507 m
.57698 .28529 L
s
.57341 .27638 m
.57339 .27677 L
s
.7992 .28505 m
.79864 .28518 L
s
.79971 .2845 m
.79975 .28491 L
s
.57642 .28485 m
.5767 .28507 L
s
.57339 .27677 m
.57337 .27716 L
s
.79975 .28491 m
.7992 .28505 L
s
.79975 .28491 m
.79978 .28533 L
s
.8003 .28478 m
.79975 .28491 L
s
.57615 .28464 m
.57642 .28485 L
s
.57337 .27716 m
.57335 .27755 L
s
.79294 .26736 m
.79715 .27446 L
s
.80084 .28464 m
.8003 .28478 L
s
0 g
.5 Mabswid
.26773 .38263 m
.25929 .35452 L
s
.039 .916 .04 r
1 Mabswid
.79812 .2878 m
.80238 .29588 L
s
.79978 .28533 m
.7998 .28574 L
s
.57335 .27755 m
.57333 .27794 L
s
.80139 .2845 m
.80084 .28464 L
s
.57588 .28442 m
.57615 .28464 L
s
.80194 .28436 m
.80139 .2845 L
s
.57333 .27794 m
.57331 .27833 L
s
.7998 .28574 m
.79983 .28615 L
s
.57561 .2842 m
.57588 .28442 L
s
.80248 .28422 m
.80194 .28436 L
s
.57331 .27833 m
.5733 .27872 L
s
.80303 .28408 m
.80248 .28422 L
s
.79983 .28615 m
.79986 .28656 L
s
.57534 .28398 m
.57561 .2842 L
s
.80357 .28393 m
.80303 .28408 L
s
.5733 .27872 m
.57329 .27911 L
s
.57508 .28375 m
.57534 .28398 L
s
.79986 .28656 m
.79989 .28697 L
s
.80411 .28378 m
.80357 .28393 L
s
.57329 .27911 m
.57328 .27949 L
s
.80466 .28363 m
.80411 .28378 L
s
.57481 .28353 m
.57508 .28375 L
s
.79989 .28697 m
.79991 .28738 L
s
.57328 .27949 m
.57327 .27988 L
s
.8052 .28348 m
.80466 .28363 L
s
.57455 .28331 m
.57481 .28353 L
s
.79991 .28738 m
.79994 .28779 L
s
.80574 .28333 m
.8052 .28348 L
s
.57327 .27988 m
.57327 .28026 L
s
.80628 .28317 m
.80574 .28333 L
s
.57429 .28308 m
.57455 .28331 L
s
.78516 .27552 m
.78878 .28329 L
s
.79994 .28779 m
.79996 .28819 L
s
.57327 .28026 m
.57327 .28065 L
s
.80681 .28301 m
.80628 .28317 L
s
.57404 .28286 m
.57429 .28308 L
s
.57327 .28065 m
.57327 .28103 L
s
.80735 .28286 m
.80681 .28301 L
s
.79996 .28819 m
.79998 .28859 L
s
.56204 .29366 m
.5734 .28852 L
s
.57378 .28263 m
.57404 .28286 L
s
.80789 .28269 m
.80735 .28286 L
s
.57327 .28103 m
.57327 .28141 L
s
.79998 .28859 m
.80001 .28899 L
s
.55738 .28265 m
.56912 .27835 L
s
.57353 .2824 m
.57378 .28263 L
s
.57327 .28141 m
.57327 .28179 L
s
.80001 .28899 m
.80003 .28939 L
s
.57328 .28217 m
.57353 .2824 L
s
.57327 .28179 m
.57328 .28217 L
s
.80003 .28939 m
.80005 .28979 L
s
0 g
.5 Mabswid
.86852 .4219 m
.89532 .4108 L
s
.86852 .4219 m
.86852 .4219 L
s
.039 .916 .04 r
1 Mabswid
.57328 .28217 m
.57329 .28255 L
s
.57303 .28195 m
.57328 .28217 L
s
.80005 .28979 m
.80007 .29019 L
s
.57329 .28255 m
.5733 .28293 L
s
.57279 .28172 m
.57303 .28195 L
s
.80007 .29019 m
.80009 .29058 L
s
.5733 .28293 m
.57331 .28331 L
s
.57254 .28148 m
.57279 .28172 L
s
.57331 .28331 m
.57333 .28369 L
s
.80009 .29058 m
.8001 .29098 L
s
.5723 .28125 m
.57254 .28148 L
s
.57333 .28369 m
.57334 .28407 L
s
.57206 .28102 m
.5723 .28125 L
s
.57334 .28407 m
.57336 .28444 L
s
.58845 .28102 m
.59953 .27604 L
s
.57182 .28079 m
.57206 .28102 L
s
.57336 .28444 m
.57339 .28482 L
s
.58455 .27173 m
.596 .26759 L
s
.57159 .28055 m
.57182 .28079 L
s
.57339 .28482 m
.57341 .28519 L
s
.57135 .28031 m
.57159 .28055 L
s
.57341 .28519 m
.57344 .28556 L
s
.57112 .28008 m
.57135 .28031 L
s
.57344 .28556 m
.57346 .28594 L
s
.57089 .27984 m
.57112 .28008 L
s
.57346 .28594 m
.57349 .28631 L
s
.57067 .2796 m
.57089 .27984 L
s
.57349 .28631 m
.57353 .28668 L
s
.57044 .27936 m
.57067 .2796 L
s
.57353 .28668 m
.57356 .28705 L
s
.57022 .27912 m
.57044 .27936 L
s
.57356 .28705 m
.5736 .28742 L
s
.57 .27888 m
.57022 .27912 L
s
.5736 .28742 m
.57364 .28779 L
s
0 g
.5 Mabswid
.94017 .37297 m
.95494 .349 L
s
.039 .916 .04 r
1 Mabswid
.80162 .27148 m
.8065 .27896 L
s
.56978 .27864 m
.57 .27888 L
s
.5734 .28852 m
.58481 .28337 L
s
.56912 .27835 m
.5809 .27405 L
s
.5936 .27793 m
.59384 .27812 L
s
.59336 .27774 m
.5936 .27793 L
s
.5905 .27012 m
.59048 .27047 L
s
.59048 .27047 m
.59046 .27081 L
s
.59312 .27755 m
.59336 .27774 L
s
.59046 .27081 m
.59045 .27116 L
s
.59288 .27736 m
.59312 .27755 L
s
.59045 .27116 m
.59043 .2715 L
s
.79383 .27967 m
.79812 .2878 L
s
.59265 .27717 m
.59288 .27736 L
s
.59043 .2715 m
.59042 .27184 L
s
.59241 .27698 m
.59265 .27717 L
s
.59042 .27184 m
.59041 .27218 L
s
.59218 .27679 m
.59241 .27698 L
s
.78871 .2602 m
.79294 .26736 L
s
.59041 .27218 m
.5904 .27252 L
s
.59195 .27659 m
.59218 .27679 L
s
.5904 .27252 m
.59039 .27286 L
s
.59173 .2764 m
.59195 .27659 L
s
.59039 .27286 m
.59039 .2732 L
s
.7929 .26781 m
.79293 .2682 L
s
.5915 .2762 m
.59173 .2764 L
s
.59039 .2732 m
.59039 .27354 L
s
.79293 .2682 m
.79297 .26859 L
s
.59128 .27601 m
.5915 .2762 L
s
.59039 .27354 m
.59039 .27387 L
s
.79297 .26859 m
.79301 .26897 L
s
.59953 .27604 m
.61065 .27104 L
s
.59106 .27581 m
.59128 .27601 L
s
.59039 .27387 m
.59039 .27421 L
s
.79301 .26897 m
.79304 .26936 L
s
.596 .26759 m
.60749 .26343 L
s
.59084 .27561 m
.59106 .27581 L
s
.59039 .27421 m
.59039 .27455 L
s
.79304 .26936 m
.79308 .26974 L
s
.59062 .27541 m
.59084 .27561 L
s
.59039 .27455 m
.59039 .27488 L
s
.7815 .26771 m
.78516 .27552 L
s
.79308 .26974 m
.79311 .27012 L
s
0 g
.5 Mabswid
.89532 .4108 m
.9198 .39409 L
s
.039 .916 .04 r
1 Mabswid
.5904 .27522 m
.59062 .27541 L
s
.59039 .27488 m
.5904 .27522 L
s
.79311 .27012 m
.79315 .27051 L
s
.5904 .27522 m
.59041 .27555 L
s
.59019 .27502 m
.5904 .27522 L
s
.78638 .27504 m
.78588 .27514 L
s
.79315 .27051 m
.79318 .27089 L
s
.78689 .27494 m
.78638 .27504 L
s
.59041 .27555 m
.59042 .27588 L
s
.58997 .27481 m
.59019 .27502 L
s
.78739 .27484 m
.78689 .27494 L
s
.79318 .27089 m
.79321 .27126 L
s
.7879 .27474 m
.78739 .27484 L
s
.59042 .27588 m
.59043 .27621 L
s
.58976 .27461 m
.58997 .27481 L
s
.7884 .27464 m
.7879 .27474 L
s
.79321 .27126 m
.79324 .27164 L
s
.59043 .27621 m
.59045 .27654 L
s
.7889 .27453 m
.7884 .27464 L
s
.58956 .27441 m
.58976 .27461 L
s
.7894 .27442 m
.7889 .27453 L
s
.79324 .27164 m
.79327 .27202 L
s
.59045 .27654 m
.59047 .27688 L
s
.7899 .27431 m
.7894 .27442 L
s
.58935 .27421 m
.58956 .27441 L
s
.79327 .27202 m
.7933 .27239 L
s
.7904 .2742 m
.7899 .27431 L
s
.58481 .28337 m
.59626 .2782 L
s
.59047 .27688 m
.59048 .27721 L
s
.58914 .274 m
.58935 .27421 L
s
.7909 .27409 m
.7904 .2742 L
s
.7933 .27239 m
.79333 .27276 L
s
.7914 .27398 m
.7909 .27409 L
s
.59048 .27721 m
.5905 .27753 L
s
.5809 .27405 m
.59273 .26972 L
s
.58894 .2738 m
.58914 .274 L
s
.7919 .27386 m
.7914 .27398 L
s
.79333 .27276 m
.79336 .27313 L
s
.5905 .27753 m
.59053 .27786 L
s
.79239 .27374 m
.7919 .27386 L
s
0 g
.5 Mabswid
.9198 .39409 m
.94017 .37297 L
s
.039 .916 .04 r
1 Mabswid
.58874 .27359 m
.58894 .2738 L
s
.79289 .27363 m
.79239 .27374 L
s
.79336 .27313 m
.79338 .27351 L
s
.59053 .27786 m
.59055 .27819 L
s
.79338 .27351 m
.79289 .27363 L
s
.58854 .27339 m
.58874 .27359 L
s
.79338 .27351 m
.79341 .27387 L
s
.79388 .27338 m
.79338 .27351 L
s
.59055 .27819 m
.59058 .27852 L
s
.58834 .27318 m
.58854 .27339 L
s
.79437 .27326 m
.79388 .27338 L
s
.59058 .27852 m
.5906 .27884 L
s
.79341 .27387 m
.79343 .27424 L
s
.79486 .27313 m
.79437 .27326 L
s
.58815 .27297 m
.58834 .27318 L
s
.79535 .27301 m
.79486 .27313 L
s
.5906 .27884 m
.59063 .27917 L
s
.79343 .27424 m
.79346 .27461 L
s
.79584 .27288 m
.79535 .27301 L
s
.58795 .27276 m
.58815 .27297 L
s
.59063 .27917 m
.59067 .27949 L
s
.79633 .27275 m
.79584 .27288 L
s
.79346 .27461 m
.79348 .27497 L
s
.58776 .27255 m
.58795 .27276 L
s
.79682 .27262 m
.79633 .27275 L
s
.59067 .27949 m
.5907 .27982 L
s
.79348 .27497 m
.79351 .27534 L
s
.79731 .27248 m
.79682 .27262 L
s
.58757 .27234 m
.58776 .27255 L
s
.5907 .27982 m
.59074 .28014 L
s
.79779 .27235 m
.79731 .27248 L
s
.79351 .27534 m
.79353 .2757 L
s
.79828 .27221 m
.79779 .27235 L
s
.58738 .27213 m
.58757 .27234 L
s
.79353 .2757 m
.79355 .27606 L
s
.79877 .27207 m
.79828 .27221 L
s
.79925 .27193 m
.79877 .27207 L
s
.79355 .27606 m
.79357 .27642 L
s
.79973 .27179 m
.79925 .27193 L
s
.79357 .27642 m
.79359 .27678 L
s
.80022 .27165 m
.79973 .27179 L
s
.8007 .2715 m
.80022 .27165 L
s
.79359 .27678 m
.79361 .27713 L
s
.79672 .26396 m
.80162 .27148 L
s
.79361 .27713 m
.79363 .27749 L
s
.79363 .27749 m
.79365 .27784 L
s
.61065 .27104 m
.62181 .26602 L
s
.79365 .27784 m
.79366 .27819 L
s
.60749 .26343 m
.61903 .25926 L
s
.79366 .27819 m
.79368 .27855 L
s
.61032 .27053 m
.61052 .27069 L
s
.60769 .26383 m
.60768 .26413 L
s
.61012 .27037 m
.61032 .27053 L
s
.79368 .27855 m
.79369 .2789 L
s
.60768 .26413 m
.60766 .26442 L
s
.60992 .2702 m
.61012 .27037 L
s
.60766 .26442 m
.60765 .26472 L
s
.60972 .27004 m
.60992 .2702 L
s
.60765 .26472 m
.60764 .26501 L
s
.78951 .27149 m
.79383 .27967 L
s
.60952 .26988 m
.60972 .27004 L
s
.60764 .26501 m
.60763 .26531 L
s
.59626 .2782 m
.60776 .27301 L
s
.60932 .26972 m
.60952 .26988 L
s
.60763 .26531 m
.60762 .2656 L
s
.59273 .26972 m
.6046 .26538 L
s
.60913 .26955 m
.60932 .26972 L
s
.60762 .2656 m
.60761 .26589 L
s
.60893 .26939 m
.60913 .26955 L
s
.60761 .26589 m
.60761 .26619 L
s
.60874 .26922 m
.60893 .26939 L
s
.60761 .26619 m
.60761 .26648 L
s
.60855 .26905 m
.60874 .26922 L
s
.60761 .26648 m
.60761 .26677 L
s
.60836 .26889 m
.60855 .26905 L
s
.78444 .25299 m
.78871 .2602 L
s
.60761 .26677 m
.60761 .26706 L
s
.60818 .26872 m
.60836 .26889 L
s
.60761 .26706 m
.60761 .26735 L
s
.60799 .26855 m
.60818 .26872 L
s
.60761 .26735 m
.60761 .26764 L
s
.60781 .26838 m
.60799 .26855 L
s
.60761 .26764 m
.60762 .26793 L
s
.60763 .26821 m
.60781 .26838 L
s
.60762 .26793 m
.60763 .26821 L
s
.60763 .26821 m
.60763 .2685 L
s
.60744 .26804 m
.60763 .26821 L
s
.60763 .2685 m
.60764 .26879 L
s
.60727 .26787 m
.60744 .26804 L
s
.60764 .26879 m
.60766 .26907 L
s
.60709 .2677 m
.60727 .26787 L
s
.60766 .26907 m
.60767 .26936 L
s
.77783 .25984 m
.7815 .26771 L
s
.60691 .26753 m
.60709 .2677 L
s
.60767 .26936 m
.60769 .26964 L
s
.60674 .26736 m
.60691 .26753 L
s
.60769 .26964 m
.6077 .26993 L
s
.60656 .26718 m
.60674 .26736 L
s
.6077 .26993 m
.60772 .27021 L
s
.60639 .26701 m
.60656 .26718 L
s
.60772 .27021 m
.60774 .27049 L
s
.60622 .26683 m
.60639 .26701 L
s
.60774 .27049 m
.60776 .27077 L
s
.60606 .26666 m
.60622 .26683 L
s
.60776 .27077 m
.60779 .27106 L
s
.60589 .26648 m
.60606 .26666 L
s
.60779 .27106 m
.60781 .27134 L
s
.60572 .2663 m
.60589 .26648 L
s
.60781 .27134 m
.60784 .27162 L
s
.60556 .26613 m
.60572 .2663 L
s
.60784 .27162 m
.60787 .2719 L
s
.6054 .26595 m
.60556 .26613 L
s
.60787 .2719 m
.6079 .27217 L
s
.62181 .26602 m
.63303 .26098 L
s
.60524 .26577 m
.6054 .26595 L
s
.61903 .25926 m
.63062 .25506 L
s
.6079 .27217 m
.60793 .27245 L
s
.60508 .26559 m
.60524 .26577 L
s
.60776 .27301 m
.6193 .2678 L
s
.6046 .26538 m
.61651 .26102 L
s
.78654 .257 m
.78657 .25734 L
s
.78657 .25734 m
.7866 .25768 L
s
.7866 .25768 m
.78663 .25802 L
s
.78663 .25802 m
.78667 .25836 L
s
.79179 .25639 m
.79672 .26396 L
s
.78667 .25836 m
.7867 .25869 L
s
.7867 .25869 m
.78672 .25903 L
s
.78672 .25903 m
.78675 .25936 L
s
.78076 .26335 m
.78031 .26344 L
s
.78675 .25936 m
.78678 .25969 L
s
.7812 .26327 m
.78076 .26335 L
s
.78165 .26318 m
.7812 .26327 L
s
.78678 .25969 m
.78681 .26002 L
s
.62715 .26308 m
.62732 .26321 L
s
.7821 .26308 m
.78165 .26318 L
s
.62499 .2575 m
.62498 .25775 L
s
.78254 .26299 m
.7821 .26308 L
s
.62699 .26294 m
.62715 .26308 L
s
.78681 .26002 m
.78684 .26035 L
s
.62498 .25775 m
.62497 .258 L
s
.78299 .2629 m
.78254 .26299 L
s
.62682 .26281 m
.62699 .26294 L
s
.78343 .2628 m
.78299 .2629 L
s
.62497 .258 m
.62496 .25824 L
s
.78684 .26035 m
.78686 .26068 L
s
.62666 .26268 m
.62682 .26281 L
s
.78388 .2627 m
.78343 .2628 L
s
.62496 .25824 m
.62495 .25849 L
s
.78686 .26068 m
.78689 .26101 L
s
.78432 .26261 m
.78388 .2627 L
s
.6265 .26254 m
.62666 .26268 L
s
.78516 .26326 m
.78951 .27149 L
s
.62495 .25849 m
.62494 .25874 L
s
.78476 .26251 m
.78432 .26261 L
s
.62634 .26241 m
.6265 .26254 L
s
.78689 .26101 m
.78691 .26134 L
s
.7852 .26241 m
.78476 .26251 L
s
.62494 .25874 m
.62494 .25898 L
s
.62618 .26227 m
.62634 .26241 L
s
.78564 .2623 m
.7852 .26241 L
s
.62494 .25898 m
.62493 .25923 L
s
.78691 .26134 m
.78693 .26166 L
s
.78608 .2622 m
.78564 .2623 L
s
.62602 .26214 m
.62618 .26227 L
s
.62493 .25923 m
.62493 .25947 L
s
.78652 .26209 m
.78608 .2622 L
s
.78693 .26166 m
.78696 .26198 L
s
.62586 .262 m
.62602 .26214 L
s
.62493 .25947 m
.62493 .25972 L
s
.78696 .26198 m
.78652 .26209 L
s
.62571 .26186 m
.62586 .262 L
s
.78696 .26198 m
.78698 .26231 L
s
.7874 .26188 m
.78696 .26198 L
s
.62493 .25972 m
.62493 .25996 L
s
.78783 .26177 m
.7874 .26188 L
s
.62555 .26173 m
.62571 .26186 L
s
.62493 .25996 m
.62493 .2602 L
s
.78698 .26231 m
.787 .26263 L
s
.78827 .26165 m
.78783 .26177 L
s
.6254 .26159 m
.62555 .26173 L
s
.62493 .2602 m
.62493 .26045 L
s
.7887 .26154 m
.78827 .26165 L
s
.787 .26263 m
.78702 .26295 L
s
.62525 .26145 m
.6254 .26159 L
s
.62493 .26045 m
.62494 .26069 L
s
.78914 .26143 m
.7887 .26154 L
s
.6251 .26131 m
.62525 .26145 L
s
.62494 .26069 m
.62494 .26093 L
s
.78702 .26295 m
.78704 .26327 L
s
.78957 .26131 m
.78914 .26143 L
s
.62495 .26117 m
.6251 .26131 L
s
.79 .26119 m
.78957 .26131 L
s
.62494 .26093 m
.62495 .26117 L
s
.78704 .26327 m
.78706 .26359 L
s
.79043 .26107 m
.79 .26119 L
s
.62495 .26117 m
.62496 .26141 L
s
.6248 .26103 m
.62495 .26117 L
s
.6193 .2678 m
.63088 .26257 L
s
.79087 .26095 m
.79043 .26107 L
s
.78706 .26359 m
.78708 .2639 L
s
.62496 .26141 m
.62497 .26165 L
s
.62466 .26089 m
.6248 .26103 L
s
.78015 .24574 m
.78444 .25299 L
s
.61651 .26102 m
.62847 .25665 L
s
.63303 .26098 m
.64429 .25591 L
s
.7913 .26083 m
.79087 .26095 L
s
.63062 .25506 m
.64226 .25086 L
s
.62497 .26165 m
.62498 .26189 L
s
.62451 .26075 m
.62466 .26089 L
s
.78708 .2639 m
.7871 .26422 L
s
.79173 .26071 m
.7913 .26083 L
s
.62498 .26189 m
.62499 .26213 L
s
.62437 .26061 m
.62451 .26075 L
s
.79215 .26058 m
.79173 .26071 L
s
.7871 .26422 m
.78712 .26453 L
s
.62499 .26213 m
.62501 .26237 L
s
.62423 .26046 m
.62437 .26061 L
s
.79258 .26046 m
.79215 .26058 L
s
.62501 .26237 m
.62502 .26261 L
s
.78712 .26453 m
.78714 .26485 L
s
.62409 .26032 m
.62423 .26046 L
s
.79301 .26033 m
.79258 .26046 L
s
.62502 .26261 m
.62504 .26284 L
s
.79344 .2602 m
.79301 .26033 L
s
.62395 .26018 m
.62409 .26032 L
s
.78714 .26485 m
.78715 .26516 L
s
.62504 .26284 m
.62506 .26308 L
s
.62381 .26003 m
.62395 .26018 L
s
.78715 .26516 m
.78717 .26547 L
s
.62506 .26308 m
.62508 .26332 L
s
.62367 .25989 m
.62381 .26003 L
s
.62508 .26332 m
.6251 .26355 L
s
.78717 .26547 m
.78718 .26578 L
s
.62354 .25974 m
.62367 .25989 L
s
.77413 .25193 m
.77783 .25984 L
s
.6251 .26355 m
.62512 .26379 L
s
.6234 .2596 m
.62354 .25974 L
s
.78718 .26578 m
.7872 .26609 L
s
.62512 .26379 m
.62514 .26402 L
s
.62327 .25945 m
.6234 .2596 L
s
.7872 .26609 m
.78721 .26639 L
s
.62514 .26402 m
.62517 .26425 L
s
.62314 .25931 m
.62327 .25945 L
s
.62517 .26425 m
.6252 .26449 L
s
.62301 .25916 m
.62314 .25931 L
s
.78721 .26639 m
.78722 .2667 L
s
.6252 .26449 m
.62522 .26472 L
s
.62288 .25901 m
.62301 .25916 L
s
.63088 .26257 m
.6425 .25732 L
s
.62847 .25665 m
.64047 .25226 L
s
.78682 .24877 m
.79179 .25639 L
s
.64226 .25086 m
.65395 .24663 L
s
.64429 .25591 m
.6556 .25082 L
s
.6424 .25113 m
.64239 .25133 L
s
.64409 .25558 m
.64422 .25568 L
s
.64239 .25133 m
.64239 .25153 L
s
.64396 .25547 m
.64409 .25558 L
s
.64239 .25153 m
.64238 .25173 L
s
.64383 .25537 m
.64396 .25547 L
s
.64238 .25173 m
.64237 .25193 L
s
.64371 .25526 m
.64383 .25537 L
s
.64237 .25193 m
.64237 .25212 L
s
.64358 .25516 m
.64371 .25526 L
s
.78079 .25497 m
.78516 .26326 L
s
.64237 .25212 m
.64236 .25232 L
s
.64346 .25505 m
.64358 .25516 L
s
.64236 .25232 m
.64236 .25252 L
s
.64333 .25495 m
.64346 .25505 L
s
.64236 .25252 m
.64236 .25272 L
s
.64321 .25484 m
.64333 .25495 L
s
.64236 .25272 m
.64236 .25291 L
s
.64309 .25474 m
.64321 .25484 L
s
.64236 .25291 m
.64236 .25311 L
s
.64297 .25463 m
.64309 .25474 L
s
.64236 .25311 m
.64236 .25331 L
s
.64285 .25452 m
.64297 .25463 L
s
.64236 .25331 m
.64237 .2535 L
s
.64273 .25441 m
.64285 .25452 L
s
.64237 .2535 m
.64237 .2537 L
s
.64261 .2543 m
.64273 .25441 L
s
.64237 .2537 m
.64238 .25389 L
s
.6425 .25419 m
.64261 .2543 L
s
.64238 .25389 m
.64238 .25409 L
s
.64238 .25409 m
.6425 .25419 L
s
.64238 .25409 m
.64239 .25428 L
s
.64227 .25398 m
.64238 .25409 L
s
.64215 .25387 m
.64227 .25398 L
s
.64239 .25428 m
.6424 .25447 L
s
.64204 .25375 m
.64215 .25387 L
s
.6424 .25447 m
.64241 .25467 L
s
.64193 .25364 m
.64204 .25375 L
s
.64241 .25467 m
.64242 .25486 L
s
.64182 .25353 m
.64193 .25364 L
s
.64242 .25486 m
.64243 .25505 L
s
.64171 .25342 m
.64182 .25353 L
s
.64243 .25505 m
.64244 .25524 L
s
.6416 .25331 m
.64171 .25342 L
s
.64244 .25524 m
.64246 .25543 L
s
.6415 .2532 m
.6416 .25331 L
s
.64246 .25543 m
.64247 .25562 L
s
.64139 .25308 m
.6415 .2532 L
s
.64247 .25562 m
.64249 .25581 L
s
.64129 .25297 m
.64139 .25308 L
s
.64249 .25581 m
.64251 .256 L
s
.77583 .23844 m
.78015 .24574 L
s
.64118 .25285 m
.64129 .25297 L
s
.64251 .256 m
.64253 .25619 L
s
.64108 .25274 m
.64118 .25285 L
s
.64253 .25619 m
.64255 .25638 L
s
.64098 .25262 m
.64108 .25274 L
s
.64255 .25638 m
.64257 .25657 L
s
.64088 .25251 m
.64098 .25262 L
s
.64257 .25657 m
.64259 .25676 L
s
.78012 .24608 m
.78014 .24637 L
s
.64078 .25239 m
.64088 .25251 L
s
.64259 .25676 m
.64261 .25695 L
s
.78014 .24637 m
.78017 .24666 L
s
.78017 .24666 m
.7802 .24695 L
s
.64047 .25226 m
.65251 .24785 L
s
.6425 .25732 m
.65417 .25205 L
s
.7802 .24695 m
.78022 .24724 L
s
.78022 .24724 m
.78025 .24753 L
s
.7704 .24395 m
.77413 .25193 L
s
.78025 .24753 m
.78027 .24782 L
s
.78027 .24782 m
.7803 .2481 L
s
.77507 .25155 m
.77468 .25162 L
s
.7803 .2481 m
.78032 .24839 L
s
.77546 .25147 m
.77507 .25155 L
s
.77585 .25139 m
.77546 .25147 L
s
.78032 .24839 m
.78034 .24867 L
s
.77624 .25131 m
.77585 .25139 L
s
.77663 .25123 m
.77624 .25131 L
s
.78034 .24867 m
.78037 .24895 L
s
.77702 .25115 m
.77663 .25123 L
s
.7774 .25107 m
.77702 .25115 L
s
.78037 .24895 m
.78039 .24923 L
s
.77779 .25098 m
.7774 .25107 L
s
.77817 .25089 m
.77779 .25098 L
s
.78039 .24923 m
.78041 .24952 L
s
.77856 .25081 m
.77817 .25089 L
s
.65395 .24663 m
.66569 .24238 L
s
.6556 .25082 m
.66696 .24571 L
s
.78041 .24952 m
.78043 .24979 L
s
.77894 .25072 m
.77856 .25081 L
s
.77932 .25063 m
.77894 .25072 L
s
.78043 .24979 m
.78045 .25007 L
s
.77971 .25054 m
.77932 .25063 L
s
.78009 .25044 m
.77971 .25054 L
s
.78045 .25007 m
.78047 .25035 L
s
.78047 .25035 m
.78009 .25044 L
s
.78047 .25035 m
.78049 .25063 L
s
.78085 .25026 m
.78047 .25035 L
s
.78123 .25016 m
.78085 .25026 L
s
.78049 .25063 m
.78051 .2509 L
s
.78161 .25006 m
.78123 .25016 L
s
.78199 .24996 m
.78161 .25006 L
s
.78051 .2509 m
.78052 .25118 L
s
.78237 .24986 m
.78199 .24996 L
s
.78052 .25118 m
.78054 .25145 L
s
.78274 .24976 m
.78237 .24986 L
s
.78312 .24966 m
.78274 .24976 L
s
.78054 .25145 m
.78056 .25172 L
s
.78349 .24955 m
.78312 .24966 L
s
.78387 .24945 m
.78349 .24955 L
s
.78056 .25172 m
.78057 .25199 L
s
.78424 .24934 m
.78387 .24945 L
s
.78057 .25199 m
.78059 .25226 L
s
.78462 .24923 m
.78424 .24934 L
s
.78499 .24912 m
.78462 .24923 L
s
.78059 .25226 m
.7806 .25253 L
s
.78536 .24901 m
.78499 .24912 L
s
.7806 .25253 m
.78062 .2528 L
s
.78573 .2489 m
.78536 .24901 L
s
.78611 .24879 m
.78573 .2489 L
s
.78062 .2528 m
.78063 .25307 L
s
.78182 .24111 m
.78682 .24877 L
s
.78063 .25307 m
.78064 .25333 L
s
.78064 .25333 m
.78066 .2536 L
s
.78066 .2536 m
.78067 .25386 L
s
.78067 .25386 m
.78068 .25413 L
s
.65992 .24471 m
.65992 .24487 L
s
.66113 .24803 m
.66122 .24811 L
s
.65992 .24487 m
.65991 .24502 L
s
.78068 .25413 m
.78069 .25439 L
s
.66104 .24796 m
.66113 .24803 L
s
.65991 .24502 m
.65991 .24517 L
s
.66095 .24788 m
.66104 .24796 L
s
.65991 .24517 m
.6599 .24532 L
s
.66086 .24781 m
.66095 .24788 L
s
.6599 .24532 m
.6599 .24547 L
s
.65251 .24785 m
.6646 .24343 L
s
.66077 .24773 m
.66086 .24781 L
s
.65417 .25205 m
.66588 .24676 L
s
.6599 .24547 m
.6599 .24562 L
s
.66068 .24765 m
.66077 .24773 L
s
.77639 .24663 m
.78079 .25497 L
s
.6599 .24562 m
.6599 .24577 L
s
.66059 .24758 m
.66068 .24765 L
s
.6599 .24577 m
.6599 .24592 L
s
.66051 .2475 m
.66059 .24758 L
s
.6599 .24592 m
.6599 .24607 L
s
.66042 .24743 m
.66051 .2475 L
s
.6599 .24607 m
.6599 .24622 L
s
.66033 .24735 m
.66042 .24743 L
s
.6599 .24622 m
.6599 .24637 L
s
.66025 .24727 m
.66033 .24735 L
s
.6599 .24637 m
.6599 .24651 L
s
.66016 .24719 m
.66025 .24727 L
s
.6599 .24651 m
.65991 .24666 L
s
.66008 .24711 m
.66016 .24719 L
s
.65991 .24666 m
.65991 .24681 L
s
.66 .24704 m
.66008 .24711 L
s
.65991 .24681 m
.65992 .24696 L
s
.65992 .24696 m
.66 .24704 L
s
.65992 .24696 m
.65992 .2471 L
s
.65983 .24688 m
.65992 .24696 L
s
.65975 .2468 m
.65983 .24688 L
s
.65992 .2471 m
.65993 .24725 L
s
.65967 .24672 m
.65975 .2468 L
s
.65993 .24725 m
.65994 .2474 L
s
.6596 .24664 m
.65967 .24672 L
s
.65994 .2474 m
.65995 .24754 L
s
.65952 .24656 m
.6596 .24664 L
s
.65995 .24754 m
.65996 .24769 L
s
.65944 .24648 m
.65952 .24656 L
s
.65996 .24769 m
.65997 .24783 L
s
.65936 .2464 m
.65944 .24648 L
s
.65997 .24783 m
.65998 .24798 L
s
.65929 .24632 m
.65936 .2464 L
s
.65998 .24798 m
.65999 .24812 L
s
.65921 .24624 m
.65929 .24632 L
s
.65999 .24812 m
.66 .24827 L
s
.65914 .24615 m
.65921 .24624 L
s
.66 .24827 m
.66002 .24841 L
s
.65906 .24607 m
.65914 .24615 L
s
.66002 .24841 m
.66003 .24856 L
s
.65899 .24599 m
.65906 .24607 L
s
.66003 .24856 m
.66005 .2487 L
s
.65892 .24591 m
.65899 .24599 L
s
.66005 .2487 m
.66007 .24884 L
s
.65884 .24582 m
.65892 .24591 L
s
.66007 .24884 m
.66008 .24898 L
s
.66569 .24238 m
.67748 .23812 L
s
.65877 .24574 m
.65884 .24582 L
s
.66008 .24898 m
.6601 .24913 L
s
.66696 .24571 m
.67837 .24058 L
s
.77148 .23108 m
.77583 .23844 L
s
.76665 .23593 m
.7704 .24395 L
s
.6646 .24343 m
.67674 .23899 L
s
.66588 .24676 m
.67763 .24146 L
s
.77679 .23339 m
.78182 .24111 L
s
.67748 .23812 m
.68932 .23384 L
s
.67756 .23826 m
.67755 .23836 L
s
.67837 .24058 m
.68983 .23543 L
s
.67755 .23836 m
.67755 .23847 L
s
.67755 .23847 m
.67754 .23857 L
s
.67829 .24044 m
.67834 .24048 L
s
.77363 .23505 m
.77365 .23529 L
s
.67754 .23857 m
.67754 .23867 L
s
.67823 .24039 m
.67829 .24044 L
s
.67754 .23867 m
.67754 .23877 L
s
.67818 .24035 m
.67823 .24039 L
s
.77365 .23529 m
.77367 .23553 L
s
.67754 .23877 m
.67754 .23888 L
s
.67812 .2403 m
.67818 .24035 L
s
.67807 .24026 m
.67812 .2403 L
s
.67754 .23888 m
.67754 .23898 L
s
.67802 .24021 m
.67807 .24026 L
s
.77367 .23553 m
.77369 .23578 L
s
.67754 .23898 m
.67754 .23908 L
s
.67796 .24016 m
.67802 .24021 L
s
.77196 .23824 m
.77639 .24663 L
s
.67754 .23908 m
.67754 .23918 L
s
.67791 .24012 m
.67796 .24016 L
s
.67754 .23918 m
.67754 .23928 L
s
.77369 .23578 m
.77372 .23602 L
s
.67786 .24007 m
.67791 .24012 L
s
.67754 .23928 m
.67754 .23938 L
s
.67781 .24002 m
.67786 .24007 L
s
.67776 .23998 m
.67781 .24002 L
s
.67754 .23938 m
.67755 .23949 L
s
.77372 .23602 m
.77374 .23626 L
s
.67771 .23993 m
.67776 .23998 L
s
.67755 .23949 m
.67755 .23959 L
s
.67766 .23988 m
.67771 .23993 L
s
.67755 .23959 m
.67755 .23969 L
s
.67761 .23983 m
.67766 .23988 L
s
.77374 .23626 m
.77376 .23649 L
s
.67755 .23969 m
.67756 .23979 L
s
.67756 .23979 m
.67761 .23983 L
s
.67756 .23979 m
.67756 .23989 L
s
.67751 .23974 m
.67756 .23979 L
s
.77376 .23649 m
.77378 .23673 L
s
.67746 .23969 m
.67751 .23974 L
s
.67756 .23989 m
.67757 .23999 L
s
.67741 .23964 m
.67746 .23969 L
s
.76933 .23963 m
.769 .23969 L
s
.67757 .23999 m
.67757 .24009 L
s
.67736 .23959 m
.67741 .23964 L
s
.77378 .23673 m
.7738 .23697 L
s
.76966 .23956 m
.76933 .23963 L
s
.67757 .24009 m
.67758 .24019 L
s
.67732 .23955 m
.67736 .23959 L
s
.76999 .23949 m
.76966 .23956 L
s
.67758 .24019 m
.67759 .24028 L
s
.67727 .2395 m
.67732 .23955 L
s
.7738 .23697 m
.77382 .2372 L
s
.67722 .23945 m
.67727 .2395 L
s
.67759 .24028 m
.67759 .24038 L
s
.77032 .23942 m
.76999 .23949 L
s
.67718 .2394 m
.67722 .23945 L
s
.67759 .24038 m
.6776 .24048 L
s
.77065 .23936 m
.77032 .23942 L
s
.67713 .23935 m
.67718 .2394 L
s
.6776 .24048 m
.67761 .24058 L
s
.77382 .2372 m
.77383 .23744 L
s
.77098 .23928 m
.77065 .23936 L
s
.67709 .2393 m
.67713 .23935 L
s
.67761 .24058 m
.67762 .24068 L
s
.67704 .23925 m
.67709 .2393 L
s
.77131 .23921 m
.77098 .23928 L
s
.67762 .24068 m
.67763 .24078 L
s
.77383 .23744 m
.77385 .23767 L
s
.677 .2392 m
.67704 .23925 L
s
.77164 .23914 m
.77131 .23921 L
s
.67763 .24078 m
.67764 .24087 L
s
.67696 .23915 m
.677 .2392 L
s
.67691 .2391 m
.67696 .23915 L
s
.67764 .24087 m
.67765 .24097 L
s
.77197 .23907 m
.77164 .23914 L
s
.77385 .23767 m
.77387 .23791 L
s
.67687 .23905 m
.67691 .2391 L
s
.67765 .24097 m
.67766 .24107 L
s
.77229 .23899 m
.77197 .23907 L
s
.67766 .24107 m
.67768 .24117 L
s
.77387 .23791 m
.77389 .23814 L
s
.77262 .23892 m
.77229 .23899 L
s
.67674 .23899 m
.68892 .23454 L
s
.67768 .24117 m
.67769 .24126 L
s
.77294 .23884 m
.77262 .23892 L
s
.77389 .23814 m
.7739 .23837 L
s
.77327 .23876 m
.77294 .23884 L
s
.67763 .24146 m
.68943 .23613 L
s
.77359 .23868 m
.77327 .23876 L
s
.7739 .23837 m
.77392 .2386 L
s
.77392 .2386 m
.77359 .23868 L
s
.77392 .2386 m
.77393 .23883 L
s
.77424 .23852 m
.77392 .2386 L
s
.77456 .23844 m
.77424 .23852 L
s
.77393 .23883 m
.77395 .23906 L
s
.77489 .23835 m
.77456 .23844 L
s
.77521 .23827 m
.77489 .23835 L
s
.77395 .23906 m
.77396 .23929 L
s
.77553 .23818 m
.77521 .23827 L
s
.77396 .23929 m
.77398 .23952 L
s
.77585 .2381 m
.77553 .23818 L
s
.77617 .23801 m
.77585 .2381 L
s
.77398 .23952 m
.77399 .23974 L
s
.77649 .23792 m
.77617 .23801 L
s
.77399 .23974 m
.774 .23997 L
s
.77681 .23783 m
.77649 .23792 L
s
.77712 .23774 m
.77681 .23783 L
s
.774 .23997 m
.77402 .24019 L
s
.77744 .23765 m
.77712 .23774 L
s
.77402 .24019 m
.77403 .24042 L
s
.77776 .23755 m
.77744 .23765 L
s
.77807 .23746 m
.77776 .23755 L
s
.77403 .24042 m
.77404 .24064 L
s
.77839 .23736 m
.77807 .23746 L
s
.77404 .24064 m
.77405 .24086 L
s
.7787 .23727 m
.77839 .23736 L
s
.77405 .24086 m
.77406 .24108 L
s
.77406 .24108 m
.77407 .2413 L
s
.77407 .2413 m
.77408 .24152 L
s
.77408 .24152 m
.77409 .24174 L
s
.7671 .22368 m
.77148 .23108 L
s
.77409 .24174 m
.7741 .24196 L
s
.76288 .22785 m
.76665 .23593 L
s
.68932 .23384 m
.70121 .22954 L
s
.68983 .23543 m
.70134 .23025 L
s
.68892 .23454 m
.70115 .23006 L
s
.68943 .23613 m
.70127 .23078 L
s
.77173 .22562 m
.77679 .23339 L
s
.6953 .23176 m
.6953 .23182 L
s
.6953 .23182 m
.6953 .23187 L
s
.6953 .23187 m
.69529 .23193 L
s
.69529 .23193 m
.69529 .23198 L
s
.69529 .23198 m
.69529 .23204 L
s
.69529 .23204 m
.69529 .23209 L
s
.69529 .23209 m
.69529 .23215 L
s
.69529 .23215 m
.69529 .2322 L
s
.69555 .23279 m
.69557 .23281 L
s
.69553 .23278 m
.69555 .23279 L
s
.69529 .2322 m
.69529 .23225 L
s
.69551 .23276 m
.69553 .23278 L
s
.69549 .23275 m
.69551 .23276 L
s
.69529 .23225 m
.69529 .23231 L
s
.69548 .23273 m
.69549 .23275 L
s
.69546 .23272 m
.69548 .23273 L
s
.69529 .23231 m
.6953 .23236 L
s
.69544 .2327 m
.69546 .23272 L
s
.69542 .23269 m
.69544 .2327 L
s
.6953 .23236 m
.6953 .23241 L
s
.6954 .23267 m
.69542 .23269 L
s
.69539 .23265 m
.6954 .23267 L
s
.6953 .23241 m
.6953 .23247 L
s
.69537 .23264 m
.69539 .23265 L
s
.69535 .23262 m
.69537 .23264 L
s
.6953 .23247 m
.6953 .23252 L
s
.69534 .23261 m
.69535 .23262 L
s
.69532 .23259 m
.69534 .23261 L
s
.6953 .23252 m
.6953 .23257 L
s
.7675 .2298 m
.77196 .23824 L
s
.6953 .23257 m
.69532 .23259 L
s
.6953 .23257 m
.69531 .23263 L
s
.69529 .23256 m
.6953 .23257 L
s
.69527 .23254 m
.69529 .23256 L
s
.69531 .23263 m
.69531 .23268 L
s
.69525 .23252 m
.69527 .23254 L
s
.77541 .18824 m .77834 .17742 L .789 .18299 L .766 .489 .516 r
F
.76789 .18599 m .77834 .17742 L .77541 .18824 L F
.76789 .18599 m .76708 .17405 L .77834 .17742 L F
.039 .916 .04 r
.69524 .23251 m
.69525 .23252 L
s
.69531 .23268 m
.69531 .23273 L
s
.69522 .23249 m
.69524 .23251 L
s
.69521 .23247 m
.69522 .23249 L
s
.69531 .23273 m
.69532 .23278 L
s
.69519 .23246 m
.69521 .23247 L
s
.69518 .23244 m
.69519 .23246 L
s
.69532 .23278 m
.69532 .23284 L
s
.69516 .23242 m
.69518 .23244 L
s
.69515 .23241 m
.69516 .23242 L
s
.69532 .23284 m
.69532 .23289 L
s
.69513 .23239 m
.69515 .23241 L
s
.78254 .19196 m .789 .18299 L .79834 .19039 L .766 .489 .516 r
F
.77541 .18824 m .789 .18299 L .78254 .19196 L F
0 g
.5 Mabswid
.77834 .17742 m
.789 .18299 L
s
.039 .916 .04 r
1 Mabswid
.69512 .23237 m
.69513 .23239 L
s
.69532 .23289 m
.69533 .23294 L
s
.6951 .23236 m
.69512 .23237 L
s
.69509 .23234 m
.6951 .23236 L
s
.69533 .23294 m
.69533 .23299 L
s
.69507 .23232 m
.69509 .23234 L
s
.69533 .23299 m
.69534 .23304 L
s
.69534 .23304 m
.69534 .2331 L
s
.69534 .2331 m
.69535 .23315 L
s
.69535 .23315 m
.69536 .2332 L
s
.69536 .2332 m
.69536 .23325 L
s
.69536 .23325 m
.69537 .2333 L
s
.69537 .2333 m
.69538 .23335 L
s
.76046 .18537 m .76708 .17405 L .76789 .18599 L .766 .489 .516 r
F
.76046 .18537 m .75597 .17312 L .76708 .17405 L F
0 g
.5 Mabswid
.76708 .17405 m
.77834 .17742 L
s
.76708 .17405 m
.76708 .17405 L
s
.78878 .19692 m .79834 .19039 L .80575 .19914 L .766 .489 .516 r
F
.78254 .19196 m .79834 .19039 L .78878 .19692 L F
0 g
.789 .18299 m
.79834 .19039 L
s
.039 .916 .04 r
1 Mabswid
.70121 .22954 m
.71315 .22522 L
s
.70134 .23025 m
.71342 .22558 L
s
.70115 .23006 m
.7129 .22506 L
s
.70127 .23078 m
.71316 .22541 L
s
.76269 .21623 m
.7671 .22368 L
s
.75363 .18643 m .75597 .17312 L .76046 .18537 L .766 .489 .516 r
F
.75363 .18643 m .74574 .17468 L .75597 .17312 L F
0 g
.5 Mabswid
.75597 .17312 m
.76708 .17405 L
s
.039 .916 .04 r
1 Mabswid
.76707 .2239 m
.76709 .2241 L
s
.76709 .2241 m
.76711 .22429 L
s
.76711 .22429 m
.76713 .22448 L
s
.76713 .22448 m
.76714 .22468 L
s
.76714 .22468 m
.76716 .22487 L
s
.75907 .21971 m
.76288 .22785 L
s
.76716 .22487 m
.76717 .22506 L
s
.79373 .20277 m .80575 .19914 L .81073 .20866 L .766 .489 .516 r
F
.78878 .19692 m .80575 .19914 L .79373 .20277 L F
0 g
.5 Mabswid
.79834 .19039 m
.80575 .19914 L
s
.039 .916 .04 r
1 Mabswid
.76717 .22506 m
.76719 .22525 L
s
.76353 .22758 m
.76326 .22764 L
s
.76381 .22753 m
.76353 .22758 L
s
.76719 .22525 m
.76721 .22544 L
s
.76408 .22747 m
.76381 .22753 L
s
.76435 .22742 m
.76408 .22747 L
s
.76721 .22544 m
.76722 .22562 L
s
.76462 .22736 m
.76435 .22742 L
s
.76722 .22562 m
.76723 .22581 L
s
.76489 .2273 m
.76462 .22736 L
s
.76516 .22724 m
.76489 .2273 L
s
.76723 .22581 m
.76725 .226 L
s
.76543 .22718 m
.76516 .22724 L
s
.7657 .22712 m
.76543 .22718 L
s
.76725 .226 m
.76726 .22618 L
s
.76597 .22706 m
.7657 .22712 L
s
.76623 .227 m
.76597 .22706 L
s
.76726 .22618 m
.76728 .22637 L
s
.7665 .22693 m
.76623 .227 L
s
.76728 .22637 m
.76729 .22655 L
s
.76677 .22687 m
.7665 .22693 L
s
.76703 .2268 m
.76677 .22687 L
s
.76729 .22655 m
.7673 .22674 L
s
.7673 .22674 m
.76703 .2268 L
s
.7673 .22674 m
.76731 .22692 L
s
.76757 .22667 m
.7673 .22674 L
s
.76783 .2266 m
.76757 .22667 L
s
.76731 .22692 m
.76732 .2271 L
s
.7681 .22653 m
.76783 .2266 L
s
.76836 .22646 m
.7681 .22653 L
s
.76732 .2271 m
.76734 .22728 L
s
.76862 .22639 m
.76836 .22646 L
s
.76734 .22728 m
.76735 .22746 L
s
.76889 .22632 m
.76862 .22639 L
s
.76915 .22625 m
.76889 .22632 L
s
.76735 .22746 m
.76736 .22765 L
s
.76941 .22617 m
.76915 .22625 L
s
.76736 .22765 m
.76737 .22782 L
s
.76967 .2261 m
.76941 .22617 L
s
.76993 .22602 m
.76967 .2261 L
s
.76737 .22782 m
.76738 .228 L
s
.77019 .22595 m
.76993 .22602 L
s
.76738 .228 m
.76739 .22818 L
s
.77045 .22587 m
.77019 .22595 L
s
.77071 .22579 m
.77045 .22587 L
s
.76739 .22818 m
.76739 .22836 L
s
.77097 .22571 m
.77071 .22579 L
s
.76739 .22836 m
.7674 .22854 L
s
.77123 .22563 m
.77097 .22571 L
s
.7674 .22854 m
.76741 .22871 L
s
.76663 .21781 m
.77173 .22562 L
s
.71342 .22558 m
.72574 .22107 L
s
.71336 .22554 m
.71338 .22556 L
s
.71335 .22552 m
.71336 .22554 L
s
.76741 .22871 m
.76742 .22889 L
s
.71333 .22551 m
.71335 .22552 L
s
.71332 .22549 m
.71333 .22551 L
s
.71331 .22547 m
.71332 .22549 L
s
.71329 .22546 m
.71331 .22547 L
s
.71328 .22544 m
.71329 .22546 L
s
.71326 .22543 m
.71328 .22544 L
s
.71325 .22541 m
.71326 .22543 L
s
.76742 .22889 m
.76743 .22906 L
s
.71323 .22539 m
.71325 .22541 L
s
.71322 .22538 m
.71323 .22539 L
s
.7132 .22536 m
.71322 .22538 L
s
.71315 .22522 m
.7251 .22002 L
s
.71316 .22523 m
.71316 .22523 L
s
.71319 .22535 m
.7132 .22536 L
s
.71316 .22523 m
.71316 .22524 L
s
.71316 .22524 m
.71316 .22525 L
s
.71316 .22525 m
.71316 .22525 L
s
.71316 .22525 m
.71316 .22526 L
s
.71316 .22526 m
.71316 .22526 L
s
.71317 .22533 m
.71319 .22535 L
s
.71316 .22526 m
.71316 .22527 L
s
.71316 .22527 m
.71316 .22527 L
s
.71316 .22527 m
.71316 .22528 L
s
.71316 .22528 m
.71316 .22529 L
s
.71316 .22529 m
.71316 .22529 L
s
.71316 .22532 m
.71317 .22533 L
s
.71316 .22529 m
.71316 .2253 L
s
.71316 .2253 m
.71316 .2253 L
s
.71316 .2253 m
.71316 .22531 L
s
.71316 .22531 m
.71316 .22532 L
s
.71316 .22532 m
.71316 .22532 L
s
.71314 .2253 m
.71316 .22532 L
s
.71316 .22532 m
.71316 .22533 L
s
.71316 .22533 m
.71316 .22533 L
s
.71316 .22533 m
.71316 .22534 L
s
.71316 .22534 m
.71316 .22534 L
s
.71313 .22528 m
.71314 .2253 L
s
.71316 .22534 m
.71316 .22535 L
s
.71316 .22535 m
.71316 .22536 L
s
.76743 .22906 m
.76743 .22924 L
s
.71316 .22536 m
.71316 .22536 L
s
.71316 .22536 m
.71316 .22537 L
s
.71316 .22537 m
.71316 .22537 L
s
.71311 .22527 m
.71313 .22528 L
s
.71316 .22537 m
.71316 .22538 L
s
.71316 .22538 m
.71316 .22538 L
s
.71316 .22538 m
.71316 .22539 L
s
.71316 .22539 m
.71316 .2254 L
s
.71309 .22525 m
.71311 .22527 L
s
.71316 .2254 m
.71317 .2254 L
s
.71316 .22541 m
.72514 .22088 L
s
.71308 .22524 m
.71309 .22525 L
s
.71306 .22522 m
.71308 .22524 L
s
.71304 .22521 m
.71306 .22522 L
s
.71303 .22519 m
.71304 .22521 L
s
.71301 .22518 m
.71303 .22519 L
s
.76743 .22924 m
.76744 .22941 L
s
.71299 .22516 m
.71301 .22518 L
s
.71298 .22515 m
.71299 .22516 L
s
.71296 .22513 m
.71298 .22515 L
s
.71294 .22512 m
.71296 .22513 L
s
.71292 .2251 m
.71294 .22512 L
s
.71291 .22509 m
.71292 .2251 L
s
.77247 .19912 m .77541 .18824 L .78254 .19196 L .766 .489 .516 r
F
.76869 .198 m .77541 .18824 L .77247 .19912 L F
.76869 .198 m .76789 .18599 L .77541 .18824 L F
.039 .916 .04 r
.7129 .22506 m
.7245 .21984 L
s
.77604 .20099 m .78254 .19196 L .78878 .19692 L .766 .489 .516 r
F
.77247 .19912 m .78254 .19196 L .77604 .20099 L F
.039 .916 .04 r
.76302 .2213 m
.7675 .2298 L
s
.74787 .1891 m .74574 .17468 L .75363 .18643 L .766 .489 .516 r
F
.74787 .1891 m .73709 .17866 L .74574 .17468 L F
0 g
.5 Mabswid
.74574 .17468 m
.75597 .17312 L
s
.76497 .19769 m .76789 .18599 L .76869 .198 L .766 .489 .516 r
F
.76497 .19769 m .76046 .18537 L .76789 .18599 L F
0 g
.76708 .17405 m
.76789 .18599 L
s
.77917 .20348 m .78878 .19692 L .79373 .20277 L .766 .489 .516 r
F
.77604 .20099 m .78878 .19692 L .77917 .20348 L F
.79704 .20913 m .81073 .20866 L .81293 .21831 L F
.79373 .20277 m .81073 .20866 L .79704 .20913 L F
0 g
.80575 .19914 m
.81073 .20866 L
s
.76155 .19823 m .76046 .18537 L .76497 .19769 L .766 .489 .516 r
F
.76155 .19823 m .75363 .18643 L .76046 .18537 L F
.78165 .20641 m .79373 .20277 L .79704 .20913 L F
.77917 .20348 m .79373 .20277 L .78165 .20641 L F
.039 .916 .04 r
1 Mabswid
.72574 .22107 m
.7381 .21655 L
s
.7251 .22002 m
.73707 .21461 L
s
.72514 .22088 m
.73719 .21653 L
s
.7245 .21984 m
.73616 .21459 L
s
.75525 .21152 m
.75907 .21971 L
s
.75867 .19958 m .75363 .18643 L .76155 .19823 L .766 .489 .516 r
F
.75867 .19958 m .74787 .1891 L .75363 .18643 L F
.74356 .19321 m .73709 .17866 L .74787 .1891 L F
.74356 .19321 m .7306 .18479 L .73709 .17866 L F
0 g
.5 Mabswid
.73709 .17866 m
.74574 .17468 L
s
.79704 .20913 m .81293 .21831 L .79849 .21557 L .766 .489 .516 r
F
.7833 .2096 m .79704 .20913 L .79849 .21557 L F
.78165 .20641 m .79704 .20913 L .7833 .2096 L F
.039 .916 .04 r
1 Mabswid
.73174 .2187 m
.73178 .21875 L
s
.7317 .21865 m
.73174 .2187 L
s
.73166 .2186 m
.7317 .21865 L
s
.73162 .21855 m
.73166 .2186 L
s
.73157 .2185 m
.73162 .21855 L
s
.73153 .21845 m
.73157 .2185 L
s
.73149 .2184 m
.73153 .21845 L
s
.73144 .21835 m
.73149 .2184 L
s
.73106 .2174 m
.73106 .21744 L
s
.73106 .21744 m
.73107 .21748 L
s
.7314 .2183 m
.73144 .21835 L
s
.73107 .21748 m
.73107 .21752 L
s
.73107 .21752 m
.73108 .21756 L
s
.79849 .21557 m .81293 .21831 L .81219 .22744 L .766 .489 .516 r
F
0 g
.5 Mabswid
.81073 .20866 m
.81293 .21831 L
s
.81293 .21831 m
.81293 .21831 L
s
.039 .916 .04 r
1 Mabswid
.73135 .21826 m
.7314 .2183 L
s
.73108 .21756 m
.73108 .2176 L
s
.73108 .2176 m
.73109 .21764 L
s
.73131 .21821 m
.73135 .21826 L
s
.73109 .21764 m
.73109 .21768 L
s
.73109 .21768 m
.7311 .21772 L
s
.73126 .21816 m
.73131 .21821 L
s
.7311 .21772 m
.7311 .21777 L
s
.7311 .21777 m
.7311 .21781 L
s
.73121 .21811 m
.73126 .21816 L
s
.7311 .21781 m
.73111 .21785 L
s
.73111 .21785 m
.73111 .21789 L
s
.73117 .21806 m
.73121 .21811 L
s
.73111 .21789 m
.73111 .21793 L
s
.73111 .21793 m
.73112 .21797 L
s
.73112 .21801 m
.73117 .21806 L
s
.73112 .21797 m
.73112 .21801 L
s
.73112 .21801 m
.73112 .21806 L
s
.73107 .21797 m
.73112 .21801 L
s
.73112 .21806 m
.73112 .2181 L
s
.73102 .21792 m
.73107 .21797 L
s
.73112 .2181 m
.73113 .21814 L
s
.73113 .21814 m
.73113 .21818 L
s
.73098 .21787 m
.73102 .21792 L
s
.73113 .21818 m
.73113 .21822 L
s
.73113 .21822 m
.73113 .21827 L
s
.73093 .21782 m
.73098 .21787 L
s
.73113 .21827 m
.73113 .21831 L
s
.73113 .21831 m
.73113 .21835 L
s
.73088 .21778 m
.73093 .21782 L
s
.73113 .21835 m
.73113 .21839 L
s
.73113 .21839 m
.73113 .21844 L
s
.73083 .21773 m
.73088 .21778 L
s
.73113 .21844 m
.73113 .21848 L
s
.73113 .21848 m
.73113 .21852 L
s
.73113 .21852 m
.73113 .21856 L
s
.73078 .21768 m
.73083 .21773 L
s
.73113 .21856 m
.73113 .21861 L
s
.73113 .21861 m
.73113 .21865 L
s
.73072 .21764 m
.73078 .21768 L
s
.73067 .21759 m
.73072 .21764 L
s
.76951 .21007 m .77247 .19912 L .77604 .20099 L .766 .489 .516 r
F
.76951 .21007 m .76869 .198 L .77247 .19912 L F
.039 .916 .04 r
.73062 .21754 m
.73067 .21759 L
s
.76951 .21007 m .77604 .20099 L .77917 .20348 L .766 .489 .516 r
F
.039 .916 .04 r
.73057 .2175 m
.73062 .21754 L
s
.73052 .21745 m
.73057 .2175 L
s
.73046 .21741 m
.73052 .21745 L
s
.73041 .21736 m
.73046 .21741 L
s
.73036 .21732 m
.73041 .21736 L
s
.76951 .21007 m .76497 .19769 L .76869 .198 L .766 .489 .516 r
F
0 g
.5 Mabswid
.76789 .18599 m
.76869 .198 L
s
.76951 .21007 m .77917 .20348 L .78165 .20641 L .766 .489 .516 r
F
.039 .916 .04 r
1 Mabswid
.7381 .21655 m
.75051 .21201 L
s
.76951 .21007 m .76155 .19823 L .76497 .19769 L .766 .489 .516 r
F
.75653 .20164 m .74787 .1891 L .75867 .19958 L F
.75653 .20164 m .74356 .19321 L .74787 .1891 L F
.039 .916 .04 r
.73707 .21461 m
.7491 .20918 L
s
.76951 .21007 m .78165 .20641 L .7833 .2096 L .766 .489 .516 r
F
.039 .916 .04 r
.76045 .21265 m
.76046 .21279 L
s
.76046 .21279 m
.76048 .21293 L
s
.76048 .21293 m
.76049 .21308 L
s
.76049 .21308 m
.7605 .21322 L
s
.7605 .21322 m
.76051 .21336 L
s
.7833 .2096 m .79849 .21557 L .78402 .21283 L .766 .489 .516 r
F
.79849 .21557 m .81219 .22744 L .79797 .22166 L F
.78402 .21283 m .79849 .21557 L .79797 .22166 L F
0 g
.5 Mabswid
.79849 .21557 m
.81293 .21831 L
s
.039 .916 .04 r
1 Mabswid
.76051 .21336 m
.76053 .2135 L
s
.75768 .21542 m
.75746 .21546 L
s
.76053 .2135 m
.76054 .21364 L
s
.75789 .21537 m
.75768 .21542 L
s
.7581 .21533 m
.75789 .21537 L
s
.76054 .21364 m
.76055 .21378 L
s
.75831 .21529 m
.7581 .21533 L
s
.76055 .21378 m
.76056 .21392 L
s
.75852 .21524 m
.75831 .21529 L
s
.75874 .2152 m
.75852 .21524 L
s
.76056 .21392 m
.76057 .21406 L
s
.75895 .21515 m
.75874 .2152 L
s
.75916 .2151 m
.75895 .21515 L
s
.76057 .21406 m
.76058 .2142 L
s
.75937 .21505 m
.75916 .2151 L
s
.76058 .2142 m
.76059 .21434 L
s
.75958 .21501 m
.75937 .21505 L
s
.73719 .21653 m
.74928 .21215 L
s
.75979 .21496 m
.75958 .21501 L
s
.76059 .21434 m
.7606 .21448 L
s
.75999 .21491 m
.75979 .21496 L
s
.7606 .21448 m
.76061 .21462 L
s
.7602 .21486 m
.75999 .21491 L
s
.76041 .2148 m
.7602 .21486 L
s
.76061 .21462 m
.76062 .21475 L
s
.76951 .21007 m .75867 .19958 L .76155 .19823 L .766 .489 .516 r
F
.039 .916 .04 r
.76062 .21475 m
.76041 .2148 L
s
.76062 .21475 m
.76063 .21489 L
s
.76082 .2147 m
.76062 .21475 L
s
.76103 .21465 m
.76082 .2147 L
s
.76063 .21489 m
.76063 .21502 L
s
.76124 .21459 m
.76103 .21465 L
s
.76063 .21502 m
.76064 .21516 L
s
.76144 .21454 m
.76124 .21459 L
s
.73616 .21459 m
.74787 .20933 L
s
.76951 .21007 m .7833 .2096 L .78402 .21283 L .766 .489 .516 r
F
.039 .916 .04 r
.76165 .21448 m
.76144 .21454 L
s
.76064 .21516 m
.76065 .21529 L
s
.76185 .21443 m
.76165 .21448 L
s
.76065 .21529 m
.76066 .21543 L
s
.76206 .21437 m
.76185 .21443 L
s
.76226 .21431 m
.76206 .21437 L
s
.76066 .21543 m
.76067 .21556 L
s
.76247 .21425 m
.76226 .21431 L
s
.76067 .21556 m
.76067 .2157 L
s
.76267 .21419 m
.76247 .21425 L
s
.76288 .21413 m
.76267 .21419 L
s
.76067 .2157 m
.76068 .21583 L
s
.76308 .21407 m
.76288 .21413 L
s
.76068 .21583 m
.76069 .21596 L
s
.76328 .21401 m
.76308 .21407 L
s
.76069 .21596 m
.76069 .21609 L
s
.76348 .21395 m
.76328 .21401 L
s
.76368 .21389 m
.76348 .21395 L
s
.76069 .21609 m
.7607 .21622 L
s
.7607 .21622 m
.7607 .21635 L
s
.7607 .21635 m
.76071 .21648 L
s
.76071 .21648 m
.76071 .21661 L
s
.76071 .21661 m
.76072 .21674 L
s
.74101 .19848 m .7306 .18479 L .74356 .19321 L .766 .489 .516 r
F
.74101 .19848 m .72674 .19267 L .7306 .18479 L F
0 g
.5 Mabswid
.7306 .18479 m
.73709 .17866 L
s
.76951 .21007 m .75653 .20164 L .75867 .19958 L .766 .489 .516 r
F
.039 .916 .04 r
1 Mabswid
.75825 .20872 m
.76269 .21623 L
s
.78402 .21283 m .79797 .22166 L .78374 .21587 L .766 .489 .516 r
F
.76951 .21007 m .78402 .21283 L .78374 .21587 L F
0 g
.5 Mabswid
.78402 .21283 m
.79849 .21557 L
s
.79797 .22166 m .81219 .22744 L .80852 .23544 L .766 .489 .516 r
F
0 g
.81219 .22744 m
.81293 .21831 L
s
.75526 .20428 m .74356 .19321 L .75653 .20164 L .766 .489 .516 r
F
.75526 .20428 m .74101 .19848 L .74356 .19321 L F
.039 .916 .04 r
1 Mabswid
.75051 .21201 m
.75525 .21152 L
s
.75023 .21182 m
.75029 .21191 L
s
.7491 .20918 m
.75825 .20872 L
s
.75016 .21174 m
.75023 .21182 L
s
.75009 .21166 m
.75016 .21174 L
s
.79797 .22166 m .80852 .23544 L .7955 .22697 L .766 .489 .516 r
F
.78374 .21587 m .79797 .22166 L .7955 .22697 L F
.039 .916 .04 r
.75002 .21157 m
.75009 .21166 L
s
.74995 .21149 m
.75002 .21157 L
s
.74987 .2114 m
.74995 .21149 L
s
.74905 .20936 m
.74906 .20944 L
s
.74906 .20944 m
.74907 .20953 L
s
.7498 .21132 m
.74987 .2114 L
s
.74907 .20953 m
.74909 .20961 L
s
.74973 .21124 m
.7498 .21132 L
s
.74909 .20961 m
.7491 .2097 L
s
.7491 .2097 m
.74911 .20979 L
s
.74965 .21116 m
.74973 .21124 L
s
.76951 .21007 m .75526 .20428 L .75653 .20164 L .766 .489 .516 r
F
.039 .916 .04 r
.74911 .20979 m
.74912 .20987 L
s
.74958 .21107 m
.74965 .21116 L
s
.74912 .20987 m
.74913 .20996 L
s
.74913 .20996 m
.74914 .21005 L
s
.7495 .21099 m
.74958 .21107 L
s
.74914 .21005 m
.74915 .21014 L
s
.74943 .21091 m
.7495 .21099 L
s
.74915 .21014 m
.74916 .21022 L
s
.74916 .21022 m
.74917 .21031 L
s
.74935 .21083 m
.74943 .21091 L
s
.78374 .21587 m .7955 .22697 L .7825 .21852 L .766 .489 .516 r
F
.76951 .21007 m .78374 .21587 L .7825 .21852 L F
.039 .916 .04 r
.74917 .21031 m
.74917 .2104 L
s
.74927 .21075 m
.74935 .21083 L
s
.74917 .2104 m
.74918 .21049 L
s
.74918 .21049 m
.74919 .21058 L
s
.74919 .21067 m
.74927 .21075 L
s
.74919 .21058 m
.74919 .21067 L
s
.74919 .21067 m
.7492 .21076 L
s
.74911 .21059 m
.74919 .21067 L
s
.7492 .21076 m
.7492 .21085 L
s
.74903 .21051 m
.74911 .21059 L
s
.7492 .21085 m
.74921 .21094 L
s
.74921 .21094 m
.74921 .21103 L
s
.74895 .21043 m
.74903 .21051 L
s
.74921 .21103 m
.74921 .21112 L
s
.74887 .21035 m
.74895 .21043 L
s
.74921 .21112 m
.74922 .21121 L
s
.74922 .21121 m
.74922 .2113 L
s
.74879 .21027 m
.74887 .21035 L
s
.74922 .2113 m
.74922 .21139 L
s
.7487 .21019 m
.74879 .21027 L
s
.74922 .21139 m
.74922 .21148 L
s
.74922 .21148 m
.74922 .21157 L
s
.74862 .21011 m
.7487 .21019 L
s
.74922 .21157 m
.74922 .21166 L
s
.74853 .21003 m
.74862 .21011 L
s
.74922 .21166 m
.74922 .21175 L
s
.76951 .21007 m .75497 .20732 L .75526 .20428 L .766 .489 .516 r
F
.76951 .21007 m .75566 .21055 L .75497 .20732 L F
0 0 0 r
.33258 .38002 m
.75516 .20824 L
s
.039 .916 .04 r
.76177 .21034 m
.76663 .21781 L
s
0 0 0 r
.75822 .21046 m
.83066 .34034 L
s
.76951 .21007 m .75731 .21376 L .75566 .21055 L .766 .489 .516 r
F
.76951 .21007 m .75978 .21671 L .75731 .21376 L F
.039 .916 .04 r
.76038 .2163 m
.76302 .2213 L
s
.76951 .21007 m .76293 .21922 L .75978 .21671 L .766 .489 .516 r
F
.76951 .21007 m .76653 .2211 L .76293 .21922 L F
.76951 .21007 m .77032 .22222 L .76653 .2211 L F
.76951 .21007 m .77407 .22252 L .77032 .22222 L F
.76951 .21007 m .77749 .22197 L .77407 .22252 L F
.76951 .21007 m .78037 .2206 L .77749 .22197 L F
.76951 .21007 m .7825 .21852 L .78037 .2206 L F
0 g
.5 Mabswid
.76869 .198 m
.76951 .21007 L
s
.76951 .21007 m
.78402 .21283 L
s
.039 .916 .04 r
1 Mabswid
.74922 .21175 m
.74922 .21184 L
s
.74845 .20996 m
.74853 .21003 L
s
.74922 .21184 m
.74922 .21194 L
s
.74922 .21194 m
.74922 .21203 L
s
.74836 .20988 m
.74845 .20996 L
s
.74787 .20933 m
.75547 .20967 L
s
.74827 .2098 m
.74836 .20988 L
s
.74819 .20972 m
.74827 .2098 L
s
.74928 .21215 m
.75673 .21263 L
s
.7481 .20965 m
.74819 .20972 L
s
.74801 .20957 m
.7481 .20965 L
s
.74792 .20949 m
.74801 .20957 L
s
.75497 .20732 m .74101 .19848 L .75526 .20428 L .766 .489 .516 r
F
.7825 .21852 m .79126 .23115 L .78037 .2206 L F
.7825 .21852 m .7955 .22697 L .79126 .23115 L F
.74039 .20455 m .72674 .19267 L .74101 .19848 L F
.75497 .20732 m .74039 .20455 L .74101 .19848 L F
.7955 .22697 m .80217 .24173 L .79126 .23115 L F
.7955 .22697 m .80852 .23544 L .80217 .24173 L F
0 g
.5 Mabswid
.80852 .23544 m
.81219 .22744 L
s
.74039 .20455 m .72578 .20178 L .72674 .19267 L .766 .489 .516 r
F
0 g
.72674 .19267 m
.7306 .18479 L
s
.75566 .21055 m .74039 .20455 L .75497 .20732 L .766 .489 .516 r
F
0 g
.75497 .20732 m
.76951 .21007 L
s
.78037 .2206 m .78551 .2339 L .77749 .22197 L .766 .489 .516 r
F
.78037 .2206 m .79126 .23115 L .78551 .2339 L F
.75566 .21055 m .74177 .21103 L .74039 .20455 L F
.75731 .21376 m .74177 .21103 L .75566 .21055 L F
.77749 .22197 m .77865 .23503 L .77407 .22252 L F
.77749 .22197 m .78551 .2339 L .77865 .23503 L F
.74177 .21103 m .72578 .20178 L .74039 .20455 L F
0 g
.74039 .20455 m
.75497 .20732 L
s
.75731 .21376 m .74504 .21745 L .74177 .21103 L .766 .489 .516 r
F
.75978 .21671 m .74504 .21745 L .75731 .21376 L F
.79126 .23115 m .79355 .24589 L .78551 .2339 L F
.79126 .23115 m .80217 .24173 L .79355 .24589 L F
0 g
.80217 .24173 m
.80852 .23544 L
s
.77407 .22252 m .77115 .23444 L .77032 .22222 L .766 .489 .516 r
F
.77407 .22252 m .77865 .23503 L .77115 .23444 L F
.75978 .21671 m .75001 .22339 L .74504 .21745 L F
.76293 .21922 m .75001 .22339 L .75978 .21671 L F
.77032 .22222 m .76353 .23219 L .76653 .2211 L F
.77032 .22222 m .77115 .23444 L .76353 .23219 L F
0 g
.76951 .21007 m
.77032 .22222 L
s
.76293 .21922 m .75631 .22841 L .75001 .22339 L .766 .489 .516 r
F
.76653 .2211 m .75631 .22841 L .76293 .21922 L F
.76653 .2211 m .76353 .23219 L .75631 .22841 L F
.74177 .21103 m .72782 .21151 L .72578 .20178 L F
0 g
.72578 .20178 m
.74039 .20455 L
s
.72578 .20178 m
.72674 .19267 L
s
.72578 .20178 m
.72578 .20178 L
s
.74504 .21745 m .72782 .21151 L .74177 .21103 L .766 .489 .516 r
F
.78551 .2339 m .78325 .2476 L .77865 .23503 L F
.78551 .2339 m .79355 .24589 L .78325 .2476 L F
0 g
.79355 .24589 m
.80217 .24173 L
s
.74504 .21745 m .73272 .22117 L .72782 .21151 L .766 .489 .516 r
F
0 g
.72578 .20178 m
.72782 .21151 L
s
.75001 .22339 m .73272 .22117 L .74504 .21745 L .766 .489 .516 r
F
.77865 .23503 m .77197 .24674 L .77115 .23444 L F
.77865 .23503 m .78325 .2476 L .77197 .24674 L F
.75001 .22339 m .74017 .2301 L .73272 .22117 L F
0 g
.72782 .21151 m
.73272 .22117 L
s
.75631 .22841 m .74017 .2301 L .75001 .22339 L .766 .489 .516 r
F
.77115 .23444 m .76051 .24335 L .76353 .23219 L F
.77115 .23444 m .77197 .24674 L .76051 .24335 L F
0 g
.77032 .22222 m
.77115 .23444 L
s
.77115 .23444 m
.77197 .24674 L
s
.78325 .2476 m
.79355 .24589 L
s
.75631 .22841 m .74965 .23767 L .74017 .2301 L .766 .489 .516 r
F
.76353 .23219 m .74965 .23767 L .75631 .22841 L F
.76353 .23219 m .76051 .24335 L .74965 .23767 L F
0 g
.73272 .22117 m
.74017 .2301 L
s
.77197 .24674 m
.78325 .2476 L
s
.74017 .2301 m
.74965 .23767 L
s
.76051 .24335 m
.77197 .24674 L
s
.77197 .24674 m
.77197 .24674 L
s
.74965 .23767 m
.76051 .24335 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[71]:=",
  ImageSize->{288, 181.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000]B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00e?ooool:
o`0004;ooooo003Cooooo`03o`000?o4OHCoa7f400Goa7f400?o0000olAmQ?o4OH@01?l0000noooo
o`00d_ooool00ol0003oa7f4olAmQ007olAmQ003o`000?o4OHCoa7f400?oa7f400?o0000oooooooo
ool0>oooool00=7ooooo00?o0000olAmQ?o4OH@02?o4OH@00ol0003oa7f4olAmQ004olAmQ003o`00
0?oooooooooo03[ooooo003Aooooo`03o`000?o4OHCoa7f400Soa7f400?o0000olAmQ?o4OH@01Oo4
OH@00ol0003oooooooooo`0iooooo`00d?ooool00ol0003oa7f4olAmQ009olAmQ003o`000?o4OHCo
a7f400Koa7f400?o0000ooooooooool0>?ooool00=3ooooo00?o0000olAmQ?o4OH@02Oo4OH@00ol0
003oa7f4olAmQ007olAmQ003o`000?oooooooooo03Oooooo003@ooooo`03o`000?o4OHCoa7f400Wo
a7f400?o0000olAmQ?o4OH@02?o4OH@00ol0003oooooooooo`0fooooo`00d?ooool3o`0000Woa7f4
00?o0000olAmQ?o4OH@02?o4OH@00ol0003oooooooooo`0fooooo`00d?ooool00ol0003oa7f4olAm
Q008o`000003olAmQ?l0003oa7f400[oa7f400?o0000ooooooooool0=Oooool00=3ooooo00?o0000
olAmQ?o4OH@01Oo4OH@00ol9jP[o0000o`WZ2P04o`0000Woa7f400?o0000ooooooooool0=Oooool0
0=3ooooo00?o0000olAmQ?o4OH@01_o4OH@01?l9jP[oa7f4olAmQ?l00002olAmQ0Co00001Oo4OH@0
0ol0003oooooooooo`0eooooo`00d?ooool00ol9jP[o0000olAmQ009olAmQ003o`000?o4OHCoa7f4
00Coa7f41ol0000fooooo`00c_ooool00ol9jP[o0000o`000002o`0000Woa7f400?o0000olAmQ?o4
OH@02_o4OH@00ol0003oooooooooo`0dooooo`00boooool2o`WZ2P;o00000oooool00ol0003oa7f4
olAmQ007olAmQ003o`000?o4OHCoa7f400Woa7f400?o0000ooooooooool0=Oooool00<[ooooo0ol0
0006ooooo`03o`000?o4OHCoa7f400Koa7f400?o0000olAmQ?o4OH@02Oo4OH@00ol0003ooooooooo
o`0eooooo`00aoooool01?l9jP[o0000o`000?l9jPX9ooooo`03o`000?o4OHCoa7f400Koa7f400?o
0000olAmQ?o4OH@02?o4OH@00ol0003oooooooooo`0eooooo`00a?ooool01?l9jP[o0000o`000?l0
000=ooooo`03o`000?o4OHCoa7f400Goa7f400?o0000olAmQ?o4OH@01oo4OH@00ol0003ooooooooo
o`0fooooo`00`?ooool3o`WZ2P;o000000?o2NX:ooooooooool03_ooool2o`0000Goa7f400?o0000
olAmQ?o4OH@01oo4OH@00ol0003oooooooooo`0@ooooo`Oo00007oooool00;gooooo1?l9jPX2o`00
0003o`WZ2_oooooooooo01;ooooo0_l00003olAmQ003o`000?o4OHCoa7f400Goa7f40_l0000?oooo
o`Co00001oooool5o`0001[ooooo002looooo`;o2NX:0ol0000Iooooo`Co00001?o4OH@3o`0000ko
oooo0ol0000@ooooo`?o00005oooool00;Wooooo0ol9jPX2o`0000;o2NX:7Oooool5o`0000kooooo
0ol000000ooooooo0000ooooo`0Cooooo`;o00005Oooool00;Kooooo0ol9jPX3o`000003o`WZ2_oo
oooooooo01oooooo0_l9jPX00ol0003oooooo`WZ2P0;ooooo`;o00001?ooool00ol0003ooooooooo
o`0Dooooo`;o00004oooool004gooooo1ol0001Oooooo`?o2NX:00Coooooo`000?l0003o2NX:9?oo
ool2o`WZ2P04o`000?l9jP[oooooo`WZ2PSooooo0_l00006ooooo`03o`000?oooooooooo01Kooooo
0_l0000Aooooo`00C?ooool4o`0000Cooooo0_l0001Jooooo`Co2NX:0ol00002o`WZ2RKooooo0_l9
jPX00ol0003o2NX:o`WZ2P07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0>ooooo`00B_ooool3o`0000?ooooo0_l00002ooooo`Co0000EOooool4
o`WZ2P03ooooool0003o000000;o2NX::Oooool2o`WZ2P04o`000?l9jP[o2NX:o`WZ2PCooooo0_l0
000:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool004Wooooo0ol00006
ooooo`;o00001?ooool00ol0003oooooooooo`1@ooooo`Co2NX:0ol00002o`WZ2Rcooooo0_l9jPX0
0ol0003o2NX:o`WZ2P03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0=ooooo`00B?ooool2o`000003ooooool0003ooooo00Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1<ooooo`Co2NX:00?oooooo`000?l000000ol9jPX^oooo
o`03o`WZ2_oooooo000000;o2NX:0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03?ooool004Sooooo00?o0000ooooool000002_ooool00ol0003o
ooooooooo`03o`0004[ooooo1Ol9jPX3o`0000?o2NX:<?ooool01?l9jP[oooooo`WZ2_l00002o`WZ
2P03o`000?oooooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<oooo
o`00Aoooool01?l0003oooooooooool0000;ooooo`;o00000_n9DHH00ol0003oooooooooo`16oooo
o`?o2NX:0_ooool2o`0000Co2NX:<oooool3o`WZ2P;o000000?o2NX:ooooooooool03?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo0017ooooo`?o00003?ooool01?l0003o
RE66ohUAQ_n9DHH2o`0004?ooooo1_l9jPX3o`0000Co2NX:=Oooool01ol9jP[oooooo`WZ2_l0003o
2NX:ooooool9jPX03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo0017
ooooo`03o`000?oooooo000000_ooooo00?o0000ohUAQ_n9DHH00_n9DHH00ol0003oooooo`00000o
ooooo`Go2NX:0_ooool2o`0000Co2NX:>Oooool2o`WZ2P04ooooool0003o2NX:o`WZ2Pgooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`00A_ooool01?l0003oooooooooool0
000;ooooo`03o`000?n9DHKoRE6600;oRE6600Co0000oooooooooooo0000>oooool7o`WZ2P?o0000
00?oooooo`WZ2_l9jPX0??ooool3o`WZ2P04o`000?ooooooooooo`WZ2Pcooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0:ooooo`00A_ooool01?l0003oooooooooool0000;ooooo`03
o`000?n9DHKoRE6600;oRE6600?o0000ooooool000000_l0000iooooo`?o2NX:0oooool2o`0000Go
2NX:??ooool00ol0003oooooo`WZ2P02o`WZ2P04o`000?l9jP[oooooo`WZ2Pcooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0:ooooo`00A_ooool01?l0003oooooooooool0000:oooo
o`03o`000?n9DHKoRE6600?oRE660_l00002ooooo`03o`000?oooooooooo03Gooooo0_l9jPX00ooo
oooo2NX:o`WZ2P03o`000003ooooool9jP[o2NX:00;o2NX:?_ooool01_l0003oooooo`WZ2_oooooo
2NX:o`0000Co2NX:2oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo0016
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ohUAQ_n9DHH00on9DHH00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo037ooooo1?l9jPX2ooooo`;o000000?o2NX:ooooool9jPX00_l9
jPY0ooooo`04o`000?ooooooooooooooo`?o2NX:00Co0000o`WZ2_oooooo2NX:2oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo0015ooooo`03o`000?oooooooooo00;o0000
2Oooool00ol0003oRE66ohUAQP04ohUAQP;o00001?ooool00ol0003oooooooooo`0/ooooo`Oo2NX:
00Coooooo`000?l0003ooooo1?l9jPY1ooooo`03o`000?oooooooooo00;ooooo00Go2NX:ooooool9
jP[o0000o`WZ2P02ooooo`03o`WZ2_oooooooooo00Sooooo00?o0000ooooooooool06Oooool3o`00
00_ooooo0015ooooo`?o000000?oYl3[o`000?ooool02?ooool00ol0003oRE66ohUAQP04ohUAQP;o
00001?ooool00ol0003oooooooooo`0Yooooo`Ko2NX:0_ooool3o`000004ooooool9jP[o2NX:o`WZ
2T?ooooo00?o0000ooooooooool01?ooool01?l9jP[oooooo`WZ2_l00003o`WZ2P[ooooo00?o0000
ooooooooool05_ooool3o`0000;ooooo00?o0000ooooooooool02Oooool004Gooooo00Co0000ojO0
jonW`>_oYl3[0_l00008ooooo`03o`000?n9DHKoRE6600CoRE6600?o0000ooooool000001?ooool0
0ol0003oooooooooo`0Uooooo`Go2NX:0_ooool2o`WZ2P;o000000?oooooo`WZ2_l9jPX00_l9jPY5
ooooo`03o`000?oooooooooo00Cooooo1?l9jPX01?l0003o2NX:ooooool9jPX9ooooo`03o`000?oo
oooooooo01?ooooo0ol00005ooooo`03o`000?oooooooooo00Wooooo0015ooooo`07o`000?nW`>_o
Yl3[ojO0jol0003oYl3[o`000006ooooo`03o`000?n9DHKoRE6600GoRE6600Co0000oooooooooooo
00000oooool2o`0002?ooooo1ol9jPX2ooooo`?o000000?o2NX:ooooooooool00_l9jPY6ooooo`03
o`000?oooooooooo00Gooooo0_l9jPX01?oooooo2NX:o`000?l9jPX2ooooo`03o`WZ2_oooooooooo
00Kooooo00?o0000ooooooooool03oooool4o`0000Sooooo00?o0000ooooooooool02Oooool004Go
oooo00Go0000ojO0jonW`>_oYl3[o`000002ojO0j`03o`000?oooooooooo00?ooooo00?o0000ohUA
Q_n9DHH01On9DHH01Ol0003oooooooooool0003ooooo00;o000000?oooooo`000?ooool07oooool5
o`WZ2P?ooooo0_l9jPX2o`0000;ooooo1?l9jPY7ooooo`03o`000?oooooooooo00Oooooo00Oo2NX:
ooooool9jP[o2NX:o`000?l9jP[ooooo00;o2NX:1oooool00ol0003oooooooooo`0<ooooo`?o0000
3?ooool00ol0003oooooooooo`09ooooo`00AOooool01Ol0003oYl3[ojO0jonW`>_o000000?oYl3[
00?o0000ooooooooool00_ooool00ol0003oRE66ohUAQP04ohUAQP03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`Ko2NX:0_ooool3o`000003o`WZ
2_oooooooooo00?o2NX:BOooool00ol0003oooooooooo`07ooooo`05o`WZ2_ooooooooooo`WZ2_l0
00000_l9jPX00ooooooo2NX:ooooo`06ooooo`03o`000?oooooooooo00Wooooo0ol0000?ooooo`03
o`000?oooooooooo00Wooooo0015ooooo`;o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`;o0000
00?oooooo`000?n9DHH01_n9DHH00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06_ooool4o`WZ2P;ooooo0_l9jPX2o`0000;ooooo1?l9jPY<ooooo`03o`00
0?oooooooooo00Sooooo1?l9jPX01Ol0003o2NX:oooooooooooo2NX:00Kooooo00?o0000oooooooo
ool01Oooool4o`0001;ooooo00?o0000ooooooooool02Oooool004Gooooo0_l00002ojO0j`03o`00
0?nW`>_oYl3[00CoYl3[0_l00007ohUAQP03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Fooooo`?o2NX:00Goooooo`WZ2_l9jP[o2NX:ooooo`03o`000003
o`WZ2_oooooooooo00?o2NX:COooool00ol0003oooooooooo`09ooooo`06o`WZ2_oooooo2NX:o`WZ
2_l0003o2NX:0_ooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol0000F
ooooo`03o`000?oooooooooo00Wooooo0015ooooo`Go00001onW`>/00ol0003oRE66ohUAQP05ohUA
QP03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Coooo
o`?o2NX:00?oooooo`WZ2_ooool00_ooool00ol9jP[o0000o`000002ooooo`Go2NX:Coooool00ol0
003oooooooooo`0:ooooo`05o`WZ2_oooooo2NX:o`WZ2_l000001?l9jPX5ooooo`03o`000?oooooo
000000;o00006Oooool00ol0003oooooooooo`09ooooo`00AOooool2o`0000;oYl3[00?o0000ojO0
jonW`>/01_nW`>/00ol0003oRE66ohUAQP04ohUAQP03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00000Booooo`?o2NX:0_ooool3o`WZ2P04ooooool0003o0000o`0000;o2NX:0_oo
ool2o`WZ2U;ooooo00?o0000ooooooooool02_ooool5o`WZ2P05o`000?ooooooooooooooool9jPX0
0oooool3o`0001_ooooo00?o0000ooooooooool02_ooool004Gooooo00Go0000ooooool0003oYl3[
o`000009ojO0j`03o`000?n9DHKoRE6600?oRE6600?o0000ooooooooool01?ooool01?l0003ooooo
ooooooooool2o`0000kooooo1?l9jPX00ooooooo2NX:ooooo`02ooooo`03o`WZ2_l0003o000000;o
oooo00?o2NX:ooooool9jPX00ol9jPYBooooo`03o`000?oooooooooo00cooooo00Go2NX:oooooooo
oooo2NX:o`000004ooooo`05o`WZ2_l0003o0000ooooool000007?ooool00ol0003oooooooooo`0:
ooooo`00AOooool01Ol0003oooooo`000?nW`>_o000000[oYl3[00?o0000ohUAQ_n9DHH00_n9DHH0
0ol0003oooooooooo`04ooooo`06o`000?oooooo0000o`000?oooooo00002_ooool4o`WZ2P03oooo
ool9jP[ooooo00?o2NX:00Coooooo`000?l0003o00000_l9jPX2ooooo`Co2NX:E?ooool00ol0003o
ooooooooo`0<ooooo`05o`WZ2_ooooooooooo`WZ2_ooool01?l00004ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool02oooool004Gooooo00Ko0000oooooooooooo0000ojO0jol00009
ojO0j`03o`000?n9DHKoRE6600;oRE6600?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000Oooooo1ol9jPX01Ooooooo2NX:oooooooooooo2NX:00;o00000oooool5o`WZ2UOooooo
00?o0000ooooooooool03Oooool01Ol9jP[o0000o`000?l9jP[o000000Oooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0;ooooo`00AOooool01?l0003oooooooooooooool2o`0000[o
Yl3[00Go0000ohUAQ_n9DHKoRE66o`000007ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooooooo1ol9jPX2ooooo`?o2NX:0ol00003o`WZ2P;ooooo0_l9jPYJooooo`03o`000?oooooo
oooo00_ooooo0ol00002ooooo`03o`WZ2_oooooooooo00Kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0;ooooo`00A_ooool00ol0003oooooooooo`02o`0000_oYl3[00Co0000ohUA
Q_n9DHKo00001oooool00ol0003oooooooooo`02ooooo`03o`000?l9jP[o2NX:00Ko2NX:00?ooooo
o`WZ2_ooool00_ooool2o`0000?ooooo00?o2NX:ooooool9jPX00ol9jPYKooooo`03o`000?oooooo
oooo00Sooooo0ol00006ooooo`03o`WZ2_oooooooooo00Kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0<ooooo`00A_ooool00ol0003oooooooooo`02o`0000coYl3[00?o0000ohUA
Q_l000002?ooool01?l0003oooooooooooooool4o`WZ2P04ooooool9jP[o2NX:ooooo`?o2NX:00?o
ooooo`000?l000000ol9jPX2ooooo`Co2NX:G?ooool00ol0003oooooooooo`05ooooo`Co00004_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo0016ooooo`?o000000?ooooo
o`000?nW`>/03?nW`>/2o`0000Sooooo00?o0000ooooool9jPX00ol9jPX01?oooooo2NX:o`WZ2_l9
jPX3ooooo`?o00000oooool5o`WZ2Uoooooo00?o0000ooooooooool00_ooool3o`0001Kooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`00A_ooool01?l0003ooooooooooooo
ool2o`0000goYl3[00?o0000ooooooooool01Oooool4o`WZ2P;ooooo00?o2NX:ooooooooool00_l9
jPX01?oooooo0000o`000?ooool3o`WZ2P;ooooo1?l9jPYPooooo`Go00006Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00gooooo0016ooooo`03o`000?oooooooooo00;ooooo0_l0
000:ojO0j`;oRE660_l00003ooooo`?o2NX:00?oooooo`WZ2_l9jPX00_l9jPX01?l0003o2NX:oooo
ooooool3o`0000?ooooo00?o2NX:ooooool9jPX00ol9jPYSooooo`;o00007?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00kooooo0017ooooo`07o`000?ooooooooooooooool0003o
ooooo`000005ojO0j`KoRE6600?o0000ojO0jol000001Ol9jPX01Ooooooo2NX:o`000?l0003ooooo
00;o2NX:0_l000000ooooooo2NX:o`WZ2P02o`WZ2P04ooooool9jP[o2NX:o`WZ2VKooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo0017oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oYl3[ohUAQP08ohUAQP04o`000?nW`>_o
2NX:o`0000;o2NX:00Koooooo`WZ2_l9jP[o2NX:o`000?ooool3o`000004o`WZ2_ooooooooooo`WZ
2P;ooooo0ol9jPYYooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0?ooooo`00Aoooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ohUA
Q_n9DHH02?n9DHH01_l0003o2NX:o`WZ2_l9jP[o0000o`WZ2P;ooooo0_l9jPX2o`0000;ooooo0ol9
jPX00ooooooo2NX:ooooo`02o`WZ2V_ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo013ooooo0018ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ohUAQ_n9DHH02?n9DHH01Ol0003oYl3[ojO0jol9jP[oYl3[00Go00000_l9jPX2ooooo`03o`WZ
2_l0003o2NX:00?o2NX:KOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04Oooool004Sooooo00Oo0000ooooooooooooooooo`000?oooooo000000[o
RE6600Co0000ojO0jonW`>_oYl3[0_l9jPX2o`000003ooooool9jP[ooooo00;o2NX:00?oooooo`WZ
2_l9jPX00_l9jPY`ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Booooo`00B?ooool00ol0003oooooooooo`02o`000003o`WZ2_l0003oRE6600Wo
RE6600?o0000ojO0jol000000_l00002o`WZ2P05ojO0jol0003o2NX:ooooool000001?l9jPYboooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Coooo
o`00BOooool2o`000005o`WZ2_l0003o2NX:ooooool000002On9DHH2o`0000?oYl3[0ol9jPX00onW
`>_o2NX:ooooo`03o`WZ2P;o0000L_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool05?ooool004Kooooo0ol9jPX01ol0003o2NX:o`WZ2_oooooo0000
o`WZ2_l000002On9DHH00ol0003o2NX:o`WZ2P02ojO0j`03o`WZ2_nW`>_oYl3[00?o2NX:00Gooooo
o`000?l0003oooooo`00001cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Eooooo`00@_ooool8o`WZ2P06o`000?l9jP[oooooo`000?l9jP[o0000
2On9DHH01Ol0003oYl3[o`WZ2_l9jP[oYl3[00Co2NX:0_nW`>/2o`0000;ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo0_l0000Hooooo`00
?oooool6o`WZ2P;ooooo00Go2NX:ooooool9jP[o0000o`WZ2P02ooooo`;o00002On9DHH2o`000003
ojO0jol9jP[o2NX:00;o2NX:1OnW`>/01?l0003oooooooooool0001dooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`00??ooool7o`WZ2P03
ooooool9jP[o2NX:00;o2NX:0_ooool01_l9jP[o0000o`000?l0003oooooo`0000WoRE6600?o0000
o`WZ2_l9jPX00_l9jPX8ojO0j`04o`000?ooooooooooo`0007Cooooo0_l0000Hooooo`03o`000?oo
oooooooo00Sooooo0_l0000Kooooo`00>Oooool7o`WZ2P;ooooo00?o2NX:ooooooooool00_l9jPX0
0ooooooo0000o`000002o`000004o`WZ2_ooooooooooo`0000SoRE6600Co0000o`WZ2_l9jP[ooooo
0_l00009ojO0j`03o`000?oooooo000007Kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01_ooooo000fooooo`Ko2NX:00?oooooo`WZ2_ooool00_l9
jPX01?oooooo2NX:ooooooooool3o`0000?ooooo00?o0000o`WZ2_l9jPX00ol00007ohUAQP03o`00
0?oooooooooo00?ooooo0_l00008ojO0j`;o0000Moooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07?ooool003?ooooo2Ol9jPX00ooooooo2NX:oooo
o`02ooooo`05o`WZ2_l0003o0000o`000?ooool00ol9jPX2ooooo`04o`WZ2_l0003o0000o`WZ2P;o
00001on9DHH00ol0003oooooooooo`05ooooo`?o00000_nW`>/00ol0003oYl3[ojO0j`02o`0007So
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`;o00007oooool0033ooooo
1ol9jPX2ooooo`03o`WZ2_oooooo2NX:00;o2NX:00Coooooo`000?l0003o00000_l9jPX2ooooo`07
o`WZ2_oooooo2NX:o`WZ2_oooooo2NX:o`000003o`WZ2P;o00001_n9DHH00ol0003oooooooooo`08
ooooo`;o000000GoYl3[o`000?l0003oooooo`00001iooooo`;o00005?ooool00ol0003ooooooooo
o`03o`00027ooooo000]ooooo`Go2NX:0_ooool01_l9jP[oooooo`WZ2_l9jP[oooooo`WZ2P;ooooo
0ol00003ooooo`?o2NX:00Coooooo`WZ2_oooooooooo1?l9jPX00ol0003oooooooooo`02o`0000Ko
RE6600?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000007_ooooo0_l0000Boooo
o`?o00009?ooool002[ooooo2Ol9jPX01?oooooo2NX:ooooooooool2o`WZ2P?o000000?oooooo`WZ
2_l9jPX00oooool00ol9jP[oooooo`WZ2P06o`WZ2P;ooooo00Ko0000oooooooooooo0000ohUAQ_l0
0005ohUAQP03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00001mooooo`;o0000
3?ooool5o`0002Kooooo000Wooooo`Oo2NX:00Coooooo`WZ2_oooooooooo0ol9jPX01Ooooooo0000
o`000?l0003o2NX:00?ooooo00Co2NX:ooooool9jP[ooooo1ol9jPX6ooooo`03o`000?oooooo0000
00;oRE6600?o0000ohUAQ_n9DHH00_n9DHH00ol0003oooooooooo`0:ooooo`04o`000?oooooooooo
o`00083ooooo3?l0000[ooooo`009?ooool5o`WZ2P;ooooo00?o2NX:ooooool9jPX00_l9jPX3oooo
o`?o00000_ooool3o`WZ2P;ooooo00?o2NX:ooooool9jPX01Ol9jPX:ooooo`;o00000_n9DHH00ol0
003oRE66ohUAQP02ohUAQP03o`000?oooooooooo00[ooooo00Co0000oooooooooooo0000]oooool0
02;ooooo1Ol9jPX01Ooooooo2NX:o`WZ2_oooooo2NX:00;ooooo0_l9jPX3o`000003ooooool9jP[o
2NX:00;ooooo00?o2NX:ooooool9jPX01ol9jPX=ooooo`03o`000?oooooo000000?o00000on9DHH0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o0000]oooool0023ooooo1Ol9jPX01?oo
oooo2NX:ooooooooool3o`WZ2P05ooooool0003o0000o`000?l9jPX00oooool3o`WZ2P03ooooool9
jP[o2NX:00Go2NX:4Oooool2o`0000;oRE6600Go0000ohUAQ_n9DHKoRE66o`00000;ooooo`?o0000
00?oooooo`000?ooool0]_ooool001kooooo0_l9jPX2ooooo`03o`WZ2_oooooo2NX:00;o2NX:0ooo
ool3o`0000;ooooo0ol9jPX2ooooo`03o`WZ2_oooooo2NX:00Go2NX:5?ooool00ol0003oooooo`00
0002ohUAQP04o`000?n9DHKoRE66o`0000_ooooo00Co0000oooooooooooo0000^?ooool001oooooo
0_l9jPX01?oooooo2NX:ooooooooool2o`WZ2P?o000000?oooooo`WZ2_l9jPX00_ooool00ol9jP[o
ooooo`WZ2P07o`WZ2QSooooo0_l00003ohUAQP03o`000?n9DHKo000000_ooooo00Co0000oooooooo
oooo0000^?ooool0023ooooo0ol9jPX01Ooooooo0000o`000?l0003o2NX:00?ooooo0ol9jPX00ooo
oooo2NX:o`WZ2P04o`WZ2Qgooooo0_l00003ohUAQP;o00002oooool01?l0003oooooooooool0002h
ooooo`008Oooool00ol9jP[o0000o`000002ooooo`?o2NX:00Coooooo`WZ2_oooooooooo1Ol9jPXQ
ooooo`03o`000?n9DHKoRE6600Co00002Oooool01?l0003oooooo`000?l0002iooooo`008_ooool2
o`WZ2P;ooooo00?o2NX:ooooool9jPX01_l9jPXUooooo`;o00001?ooool00ol0003oooooooooo`06
ooooo`;o000000?oooooo`000?ooool0^?ooool0027ooooo00Go2NX:ooooool9jP[o2NX:ooooo`06
o`WZ2R[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`000;[ooooo000Qooooo`04o`WZ2_ooooooooooooooo`Co2NX:;_ooool00ol0003ooooooooo
o`05o`0000;ooooo1?l0002kooooo`008Oooool00ol9jP[oooooo`WZ2P02o`WZ2S;ooooo0ol00003
ooooo`Co0000__ooool0027ooooo0_l9jPXhooooo`?o0000`_ooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {180.562, 0}} -> {0.0162692, 0.167149, \
0.00343151, 0.00343151}},
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.5 CylindricalLens Example", "Subsection",
  CellTags->{"AOG0.", "4.5", "AOG4.", "AOG4.5", "AOG4.5.1"}],

Cell[CellGroupData[{

Cell["Set-up", "Subsubsection",
  CellTags->{"AOG0.", "4.5.1", "AOG4.", "AOG4.5", "AOG4.5.1"}],

Cell["\<\
cylindricalsystem = {
GaussianBeam[{5,10},{.01,.005},SymbolicWaveLength->\[Lambda]],
Move[PlanoConvexCylindricalLens[{f,100},{{a,50},{b,40}},{t,10},\
DesignWaveLength->.532],{d1,50}],
Move[Screen[{{h,30},{v,50}}],{d2+t,100}, TwistAngle->30]};\
\>", "Input",
  CellLabel->"In[72]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[cylindricalsystem];", "Input",
  CellLabel->"In[73]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .86293 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.00352509 1.00353 -0.0447179 1.00353 [
[ 0 0 0 0 ]
[ 1 .86293 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .86293 L
0 .86293 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.57668 .3946 m
.62958 .42003 L
s
.62958 .42003 m
.65376 .4123 L
s
.62958 .42003 m
.63095 .4603 L
s
.65376 .4123 m
.62593 .37856 L
s
.65538 .45265 m
.65376 .4123 L
s
.63095 .4603 m
.65538 .45265 L
s
.63095 .4603 m
.63234 .50143 L
s
.53329 .36498 m
.57668 .3946 L
s
.57668 .3946 m
.62593 .37856 L
s
.65704 .49385 m
.65538 .45265 L
s
.62593 .37856 m
.5972 .34373 L
s
.63234 .50143 m
.65704 .49385 L
s
.5972 .34373 m
.53329 .36498 L
s
.57921 .5187 m .65874 .53592 L .63377 .54343 L .656 .751 .92 r
F
0 g
.63377 .54343 m
.63523 .58633 L
s
.63234 .50143 m
.63333 .53042 L
s
.57921 .5187 m .63008 .50309 L .65874 .53592 L .656 .751 .92 r
F
0 g
.65874 .53592 m
.66047 .57891 L
s
.65704 .49385 m
.65874 .53592 L
s
.63377 .54343 m
.65874 .53592 L
s
.49828 .33127 m .56831 .34896 L .49828 .37228 L .544 .324 .532 r
F
0 g
.52993 .36174 m
.53329 .36498 L
s
.49828 .33127 m .56755 .30777 L .56831 .34896 L .544 .324 .532 r
F
0 g
.56755 .30777 m
.5972 .34373 L
s
.4715 .29329 m
.49828 .33127 L
s
.49828 .33127 m
.56755 .30777 L
s
.63523 .58633 m
.66047 .57891 L
s
.63523 .58633 m
.63672 .63017 L
s
.53444 .48987 m .63008 .50309 L .57921 .5187 L .656 .751 .92 r
F
0 g
.57921 .5187 m
.63377 .54343 L
s
.66224 .62283 m
.66047 .57891 L
s
.53691 .27062 m
.56755 .30777 L
s
.53444 .48987 m .60048 .46917 L .63008 .50309 L .656 .751 .92 r
F
0 g
.63008 .50309 m
.65874 .53592 L
s
.49828 .37228 m .56908 .39106 L .49828 .41419 L .544 .324 .532 r
F
.039 .916 .04 r
.16747 .50226 m
.49828 .39234 L
s
.49828 .37228 m .56831 .34896 L .56908 .39106 L .544 .324 .532 r
F
0 g
.49828 .33127 m
.49828 .37228 L
s
.56755 .30777 m
.56831 .34896 L
s
.63672 .63017 m
.66224 .62283 L
s
.63672 .63017 m
.63824 .67497 L
s
.94116 .36039 m
.89453 .54393 L
s
.85284 .1502 m
.94116 .36039 L
s
.66404 .66772 m
.66224 .62283 L
s
.45366 .25048 m
.4715 .29329 L
s
.4715 .29329 m
.53691 .27062 L
s
.49828 .45703 m .60048 .46917 L .53444 .48987 L .656 .751 .92 r
F
0 g
.53444 .48987 m
.57921 .5187 L
s
.039 .916 .04 r
.18343 .58327 m
.52009 .47819 L
s
.49828 .41419 m .56988 .43411 L .49828 .45703 L .544 .324 .532 r
F
.49828 .41419 m .56908 .39106 L .56988 .43411 L F
0 g
.49828 .37228 m
.49828 .41419 L
s
.56831 .34896 m
.56908 .39106 L
s
.039 .916 .04 r
.49828 .39234 m
.56868 .369 L
s
0 g
.63824 .67497 m
.66404 .66772 L
s
.63824 .67497 m
.58192 .65109 L
s
.89759 .2567 m
.89759 .2567 L
s
.89759 .2567 m
.88961 .28242 L
s
.039 .916 .04 r
.56868 .369 m
.86601 .2702 L
s
0 0 0 r
2 Mabswid
.56868 .369 Mdot
.49828 .45703 m .56988 .43411 L .60048 .46917 L .656 .751 .92 r
F
0 g
.5 Mabswid
.60048 .46917 m
.63008 .50309 L
s
.53691 .27062 m
.50524 .23222 L
s
.63451 .636 m
.66404 .66772 L
s
.49828 .45703 m .57069 .47813 L .49828 .50083 L .544 .324 .532 r
F
0 g
.53414 .48959 m
.53444 .48987 L
s
.49828 .45703 m .56988 .43411 L .57069 .47813 L .544 .324 .532 r
F
.039 .916 .04 r
.57038 .4611 m
.58816 .45506 L
s
.4706 .41998 m .56988 .43411 L .49828 .45703 L .656 .751 .92 r
F
.039 .916 .04 r
.16233 .56459 m
.49828 .45703 L
s
0 g
.49828 .41419 m
.49828 .42392 L
s
.039 .916 .04 r
.14067 .5456 m
.47982 .4342 L
s
0 0 0 r
2 Mabswid
.49828 .45703 Mdot
.49828 .45703 Mdot
.039 .916 .04 r
.5 Mabswid
.58816 .45506 m
.88249 .3513 L
s
0 0 0 r
2 Mabswid
.58816 .45506 Mdot
0 g
.5 Mabswid
.58192 .65109 m
.63451 .636 L
s
.58192 .65109 m
.53566 .62321 L
s
.44657 .20189 m
.45366 .25048 L
s
.45366 .25048 m
.50524 .23222 L
s
.7924 .31 m
.85284 .1502 L
s
0 0 0 r
2 Mabswid
.47982 .4342 Mdot
0 g
.5 Mabswid
.60397 .60319 m
.63451 .636 L
s
.50524 .23222 m
.47249 .19251 L
s
.4706 .41998 m .53823 .39785 L .56988 .43411 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.56988 .43411 Mdot
.56988 .43411 Mdot
.039 .916 .04 r
.5 Mabswid
.56988 .43411 m
.87263 .33718 L
s
.49828 .45703 m
.56988 .43411 L
s
0 g
.56988 .43411 m
.60048 .46917 L
s
.56908 .39106 m
.56988 .43411 L
s
.49828 .50083 m .57152 .52316 L .49828 .54562 L .544 .324 .532 r
F
.039 .916 .04 r
.15686 .62896 m
.49828 .52394 L
s
.49828 .50083 m .57069 .47813 L .57152 .52316 L .544 .324 .532 r
F
0 g
.49828 .45703 m
.49828 .50083 L
s
.56988 .43411 m
.57069 .47813 L
s
.88961 .28242 m
.8813 .30923 L
s
0 0 0 r
2 Mabswid
.49828 .52394 Mdot
0 g
.5 Mabswid
.53566 .62321 m
.60397 .60319 L
s
.45212 .37818 m .53823 .39785 L .4706 .41998 L .656 .751 .92 r
F
0 g
.4706 .41998 m
.49828 .45703 L
s
.039 .916 .04 r
.47982 .4342 m
.55123 .41274 L
s
.55123 .41274 m
.86265 .32288 L
s
0 0 0 r
2 Mabswid
.55123 .41274 Mdot
.49828 .54562 m .57237 .56924 L .49828 .59144 L .544 .324 .532 r
F
0 g
.5 Mabswid
.49828 .59144 m
.53566 .62321 L
s
.49828 .54562 m .57152 .52316 L .57237 .56924 L .544 .324 .532 r
F
0 g
.49828 .50083 m
.49828 .54562 L
s
.49828 .54562 m
.49828 .59144 L
s
.57069 .47813 m
.57152 .52316 L
s
.039 .916 .04 r
.49828 .52394 m
.57112 .50148 L
s
0 g
.47249 .19251 m
.44657 .20189 L
s
.44597 .24383 m
.44657 .20189 L
s
.57237 .56924 m
.60397 .60319 L
s
.47249 .19251 m
.4722 .2345 L
s
.45212 .37818 m .50549 .36033 L .53823 .39785 L .656 .751 .92 r
F
0 g
.53823 .39785 m
.56988 .43411 L
s
.039 .916 .04 r
.57112 .50148 m
.8795 .40661 L
s
0 0 0 r
2 Mabswid
.57112 .50148 Mdot
0 g
.5 Mabswid
.57152 .52316 m
.57237 .56924 L
s
.49828 .59144 m
.57237 .56924 L
s
.46963 .55555 m
.49828 .59144 L
s
.8813 .30923 m
.87263 .33718 L
s
.44536 .28674 m
.44597 .24383 L
s
.44597 .24383 m
.4722 .2345 L
s
.44474 .33066 m .50549 .36033 L .45212 .37818 L .656 .751 .92 r
F
0 g
.45212 .37818 m
.4706 .41998 L
s
0 0 0 r
2 Mabswid
.86601 .2702 Mdot
0 g
.5 Mabswid
.4722 .2345 m
.47189 .27748 L
s
.91933 .44633 m
.90391 .41029 L
s
.91933 .44633 m
.91933 .44633 L
s
.53965 .53409 m
.57237 .56924 L
s
.44474 .33066 m .47158 .32148 L .50549 .36033 L .656 .751 .92 r
F
0 g
.47158 .32148 m
.50549 .36033 L
s
.50549 .36033 m
.53823 .39785 L
s
.44474 .33066 m
.45212 .37818 L
s
.90391 .41029 m
.88835 .37391 L
s
.44474 .33066 m
.44536 .28674 L
s
.44536 .28674 m
.47189 .27748 L
s
0 0 0 r
2 Mabswid
.88249 .3513 Mdot
0 g
.5 Mabswid
.88835 .37391 m
.87263 .33718 L
s
.47158 .32148 m
.47189 .27748 L
s
.46963 .55555 m
.53965 .53409 L
s
.46963 .55555 m
.45047 .51501 L
s
0 0 0 r
2 Mabswid
.87263 .33718 Mdot
.87263 .33718 Mdot
0 g
.5 Mabswid
.86359 .36636 m
.87263 .33718 L
s
.87263 .33718 m
.85677 .3001 L
s
.44411 .37563 m
.44474 .33066 L
s
.44474 .33066 m
.47158 .32148 L
s
.85677 .3001 m
.84076 .26267 L
s
0 0 0 r
2 Mabswid
.86265 .32288 Mdot
0 g
.5 Mabswid
.47126 .36652 m
.47158 .32148 L
s
.50575 .49767 m
.53965 .53409 L
s
.84076 .26267 m
.82459 .22488 L
s
.82459 .22488 m
.82459 .22488 L
s
.44345 .42168 m
.44411 .37563 L
s
.44411 .37563 m
.47126 .36652 L
s
.45047 .51501 m
.50575 .49767 L
s
.45047 .51501 m
.44279 .46885 L
s
0 0 0 r
2 Mabswid
.8795 .40661 Mdot
0 g
.5 Mabswid
.47126 .36652 m
.47094 .41265 L
s
.86359 .36636 m
.85413 .39685 L
s
.4706 .45992 m
.50575 .49767 L
s
.44279 .46885 m
.44345 .42168 L
s
.44345 .42168 m
.47094 .41265 L
s
.47094 .41265 m
.4706 .45992 L
s
.4706 .45992 m
.44279 .46885 L
s
.85413 .39685 m
.84424 .42874 L
s
.89453 .54393 m
.7924 .31 L
s
.84424 .42874 m
.84424 .42874 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[73]:=",
  ImageSize->{288, 248.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000n2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00m?ooool00ol0003oooooooooo`0Yooooo`00m?oo
ool00ol0003oooooooooo`0Yooooo`00loooool00ol0003oooooo`00000Zooooo`00loooool00ol0
003oooooo`00000Zooooo`00loooool01?l0003oooooooooool0000Yooooo`00l_ooool01Ol0003o
oooooooooooooooo000002Wooooo003booooo`05o`000?ooooooooooooooool00000:Oooool00?;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`00lOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Kooooo003aooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool09Oooool00?3ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0U
ooooo`00l?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Cooooo0026ooooo`;o
0000J?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Cooooo0023ooooo`?o0000
00?oooooo`000?ooool0I_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo
0021ooooo`;o00001?ooool2o`0006Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Sooooo`00P?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000006Gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`00P?ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0006?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0R
ooooo`00P?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000H_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo0020ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool08Oooool0083ooooo0_l00005ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo027o
oooo0020ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Qooooo`00P?ooool2o`0000Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool08?ooool0083ooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0F_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo0020oooo
o`;o00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Wooooo0_l0000@oooo
o`03o`000?oooooooooo01oooooo0020ooooo`;o00001?ooool2o`0000Sooooo0_l0001Iooooo`03
o`000?oooooo0000013ooooo00?o0000ooooooooool07oooool0083ooooo0_l000001_oooooo0000
o`000?l0003oooooo`0000Gooooo0ol000000ooooooo0000ooooo`1Hooooo`04o`000?oooooooooo
o`00013ooooo00?o0000ooooooooool07_ooool0083ooooo0ol00004ooooo`03o`000?oooooooooo
00?o00001Oooool00ol0003oooooooooo`1Fooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool07_ooool0083ooooo00?o0000ooooool000001?ooool3o`0000Wooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool07_ooool0083ooooo00Co0000ooooool0003ooooo1?l0000<ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01gooooo0020ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Mooooo`00P?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool07?ooool0083ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01cooooo0020ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool2o`0001gooooo0020ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool2o`0001gooooo001oooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool2o`0000Oooooo00Co0000oooooooooooo00007?ooool007oo
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000@ooooo`?o0000C?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooo2NX:00;o2NX:0_l00007ooooo`04o`000?oooooooooo
o`0001cooooo001oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000003Oooool3o`00
00;ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`07ooooo`03o`WZ2_l0003o2NX:
00cooooo00Co0000oooooooooooo00007?ooool007oooooo00?o0000ooooooooool00oooool3o`00
00[ooooo0ol00006ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01?ooool3o`WZ
2P;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Wooooo001oooooo`03o`000?oooooo000000?o000000?oooooo`000?l000001oooool3o`0000[o
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`02ooooo`?o2NX:1Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool007oooooo
0_l00005ooooo`;o00001?ooool3o`0000kooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
o`WZ2P02o`WZ2PSooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Sooooo001oooooo`03o`000?oooooooooo00Cooooo0_l000001?oooooo0000o`00
0?l0000Booooo`03o`000?oooooooooo04Cooooo00?o0000o`WZ2_l9jPX03?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool007oooooo00?o
0000ooooooooool01Oooool2o`0001Gooooo00?o0000ooooooooool0@Oooool3o`WZ2P03o`000?oo
oooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Oooooo001oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0mooooo`?o2NX:0oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`00Ooooool00ol0
003oooooooooo`05ooooo`;o00005oooool00ol0003oooooooooo`0iooooo`?o2NX:1Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Gooooo`00Ooooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000001Oo
oooo00?o0000ooooooooool0=Oooool3o`WZ2PSooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool007oooooo
00?o0000ooooooooool01Oooool01?l0003oooooooooool0000Fooooo`;o0000<oooool3o`WZ2P_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05_ooool007oooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool0000Cooooo`?o000000?oRe:8o`000?ooool0;oooool3o`WZ2Pgooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool05Oooool007oooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000oo
oooo0ol00004oh]BR0;o0000;?ooool3o`WZ2Q3ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool007oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo
0ol00007oh]BR003o`000?oooooo000002Sooooo0ol9jPXDooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo
001oooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`000?oooooooooo00Oooooo0_l0
000:oh]BR004o`000?ooooooooooo`0002Gooooo0_l9jPXGooooo`03o`000?oooooooooo013ooooo
0_l00002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool007oooooo00Co
0000oooooooooooooooo0ol000000onW`>_o0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo
0ol0000<oh]BR005o`000?ooooooooooooooool000008Oooool3o`WZ2Q[ooooo00?o0000oooooooo
ool03Oooool2o`WZ2P;o00000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Co
oooo001oooooo`Co00001?nW`>/2o`0000Gooooo00?o0000ooooool000000_l0000?oh]BR003o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06oooool3o`WZ2Qgooooo00?o0000ooooooooool0
2_ooool3o`WZ2P?ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0Cooooo`00
Ooooool00ol0003oYl3[ojO0j`05ojO0j`03o`000?nW`>_o000000Gooooo00?o0000oh]BR?n;DXP0
4On;DXP01Ol0003ooooooooooooooooo000001[ooooo0ol9jPXPooooo`03o`000?oooooooooo00Ko
oooo1?l9jPX7ooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool04oooool007oooooo
00?o0000ojO0jonW`>/01OnW`>/01?l0003oYl3[ojO0jol00004ooooo`03o`000?n;DXSoRe:8017o
Re:800?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`?o2NX:9?ooool00ol0003o
ooooooooo`02ooooo`?o2NX:2oooool2o`00013ooooo00?o0000ooooooooool04_ooool007oooooo
00?o0000ojO0jonW`>/01OnW`>/01Ol0003oYl3[ojO0jonW`>_o000000?ooooo00?o0000oh]BR?n;
DXP04On;DXP00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo0ol9jPXWooooo`03
o`000?l9jP[o2NX:00;o2NX:3Oooool00ol9jP[o0000o`00000@ooooo`03o`000?oooooooooo01;o
oooo001oooooo`03o`000?nW`>_oYl3[00GoYl3[00?o0000ojO0jonW`>/00_nW`>/01?l0003ooooo
ooooool0000Coh]BR003o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool3o`WZ2ROo
oooo1?l9jPX00ol0003oooooooooo`0;ooooo`?o2NX:0_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo017ooooo001oooooo`;o00001_nW`>/00ol0003oYl3[ojO0j`03ojO0j`03o`00
0?oooooo000001?oRe:800?o0000ooooooooool01?ooool2o`0000[ooooo0ol9jPXWooooo`?o2NX:
1?ooool00ol0003oooooooooo`08ooooo`?o2NX:1?ooool00ol0003oooooo`00000@ooooo`03o`00
0?oooooooooo017ooooo001oooooo`;o00001_nW`>/00ol0003oYl3[ojO0j`04ojO0j`;o00004on;
DXP01?l0003oooooooooooooool3o`000003ooooool0003ooooo00Kooooo0ol9jPXVooooo`Co2NX:
2?ooool00ol0003oooooooooo`04ooooo`?o2NX:1oooool00ol0003oooooo`000002o`0000kooooo
00?o0000ooooooooool04Oooool007oooooo0_l00006ojO0j`03o`000?nW`>_oYl3[00GoYl3[00?o
0000oh]BR?n;DXP04On;DXP4o`0000Gooooo00Co0000oooooooooooooooo0ol9jPXVooooo`?o2NX:
3?ooool01?l0003oooooooooooooool3o`WZ2P[ooooo00?o0000ooooool000000_l0000?ooooo`03
o`000?oooooooooo013ooooo001oooooo`;o00001_nW`>/00ol0003oYl3[ojO0j`06ojO0j`03o`00
0?n;DXSoRe:8013oRe:800?o0000ooooooooool01oooool3o`WZ2RGooooo1?l9jPX?ooooo`04o`00
0?l9jP[o2NX:o`WZ2Pcooooo00Go0000o`WZ2_l9jP[o2NX:o`00000@ooooo`03o`000?oooooooooo
013ooooo001oooooo`;o00001_nW`>/00ol0003oYl3[ojO0j`07ojO0j`03o`000?n;DXSoRe:800oo
Re:800?o0000ooooooooool01?ooool3o`WZ2P03ooooool0003ooooo02;ooooo0ol9jPXAooooo`?o
2NX:00?o0000ooooooooool02_ooool2o`WZ2P05o`000?ooooooooooooooool000004Oooool00ol0
003oooooooooo`0?ooooo`00Ooooool2o`0000KoYl3[00?o0000ojO0jonW`>/01onW`>/00ol0003o
Re:8oh]BR004oh]BR003o`000?n;DXSoRe:800SoRe:800Co0000oooooooooooooooo0ol9jPX5oooo
o`03o`000?oooooooooo01cooooo1?l9jPXAooooo`?o2NX:0oooool00ol0003oooooooooo`07oooo
o`?o2NX:0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03oooool007oooooo0_l00005ojO0j`;o00002_nW`>/00ol0003oRe:8oh]BR00=oh]BR0;o
00000ol9jPX8ooooo`03o`000?oooooooooo01Sooooo1?l9jPXBooooo`?o2NX:1oooool00ol0003o
ooooooooo`03ooooo`?o2NX:1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool007oooooo00Co0000ooooool0003oYl3[0ol000000onW`>_o
0000ojO0j`0:ojO0j`03o`000?n;DXSoRe:800coRe:80_l0000<ooooo`03o`000?oooooooooo01Co
oooo0ol9jPXBooooo`Co2NX:2_ooool00ol0003oooooooooo`03o`WZ2POooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo001oooooo`Co0000
1?nW`>/00ol0003oYl3[ojO0j`0:ojO0j`03o`000?n;DXSoRe:800SoRe:80ol9jPX00on;DXSo0000
ooooo`0<ooooo`03o`000?oooooooooo00oooooo1?l9jPXBooooo`?o2NX:3oooool00ol0003o2NX:
ooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0@ooooo`00Ooooool00ol0003oooooo`000005ojO0j`03o`000?nW`>_oYl3[00_oYl3[00?o
0000oh]BR?n;DXP01?n;DXP3o`WZ2PCoRe:800?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`?o2NX:4oooool3o`WZ2Poooooo0ol9jPX00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`00Ooooool0
0ol0003oooooo`000005ojO0j`03o`000?nW`>_oYl3[00coYl3[00?o0000oh]BR?n;DXP00ol9jPX7
oh]BR003o`000?oooooooooo00_ooooo0ol00008ooooo`Co2NX:4oooool3o`WZ2Poooooo0ol9jPX3
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo013ooooo001oooooo`04o`000?ooooooooooo`0000CoYl3[00?o0000
ojO0jonW`>/03?nW`>/00ol0003o2NX:o`WZ2P0:oh]BR003o`000?oooooooooo00Sooooo0ol00002
ooooo`03o`000?oooooooooo00?ooooo0ol9jPXDooooo`?o2NX:3oooool3o`WZ2POooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04Oooool007oooooo00Co0000oooooooooooo00001?nW`>/00ol0003oYl3[ojO0j`0=
ojO0j`03o`000?n;DXSoRe:800WoRe:800?o0000ooooooooool01?ooool4o`0000Kooooo00?o0000
o`WZ2_l9jPX00_l9jPXDooooo`?o2NX:3oooool3o`WZ2P[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool0
07oooooo00Go0000ooooooooooooooooo`000003ojO0j`03o`000?nW`>_oYl3[00koYl3[00?o0000
oh]BR?n;DXP02?n;DXP2o`0000;ooooo0ol00008ooooo`?o2NX:00?o0000ooooooooool04_ooool3
o`WZ2Poooooo0ol9jPX>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo001oooooo`05o`000?oooooooooo
ooooool000000onW`>/00ol0003oYl3[ojO0j`0?ojO0j`03o`000?n;DXSoRe:800OoRe:800Co0000
ooooool0003o00001oooool4o`WZ2PCooooo00?o0000ooooooooool03_ooool3o`WZ2Q3ooooo0_l9
jPXAooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo001oooooo`03o`000?oooooooooo00;ooooo00Co0000
ojO0jonW`>_o00004_nW`>/00ol0003oRe:8oh]BR006oh]BR004o`000?ooooooooooooooo`;o0000
00?oooooo`WZ2_l9jPX00_l9jPX9ooooo`03o`000?oooooooooo00[ooooo0ol9jPX@ooooo`?o2NX:
5?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Booooo`00Ooooool00ol0003oooooooooo`02ooooo`04o`000?nW
`>_oYl3[o`0001;oYl3[00?o0000oh]BR?n;DXP01_n;DXP01?l0003oooooooooooooool3o`WZ2P03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool3o`WZ2Q3ooooo0ol9jPXGooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01;ooooo001oooooo`03o`000?oooooooooo00;ooooo00Co2NX:o`000?nW`>_o
00004onW`>/00ol0003oRe:8oh]BR005oh]BR0Co2NX:1?ooool3o`0000_ooooo00Co0000oooooooo
oooooooo1?l9jPX@ooooo`?o2NX:6_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo0_l00005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool007oo
oooo00?o0000ooooool9jPX00_l9jPX01?oooooo0000ojO0jol0000DojO0j`04o`000?n;DXSoRe:8
oh]BR0?o2NX:00?o0000ooooooooool02?ooool2o`0000[ooooo0ol9jPXAooooo`?o2NX:7_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o2NX:o`000?l000001Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo001nooooo`03o`WZ2_l0003o2NX:
00Gooooo0_l0000EojO0j`;o000000Go2NX:oh]BR?n;DXSoRe:8o`00000<ooooo`;o00001Oooool3
o`WZ2P;o00003oooool3o`WZ2R7ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
o`WZ2PWooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`00Noooool3o`WZ
2P03ooooool0003ooooo00;ooooo1Ol0000BojO0j`?o2NX:0_l00004oh]BR003o`000?oooooooooo
00cooooo0_l00003o`WZ2P;o00000_ooool00ol0003oooooooooo`0;ooooo`;o2NX:9Oooool01?l0
003oooooooooool00003o`WZ2Pcooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0C
ooooo`00N?ooool3o`WZ2PCooooo1?l00004ooooo`03o`000?nW`>_oYl3[00goYl3[0ol9jPX5ojO0
j`05o`000?n;DXSoRe:8oh]BR?l000003Oooool3o`WZ2P;o00001Oooool00ol0003oooooooooo`08
ooooo`?o2NX:9oooool01?l0003o2NX:o`WZ2_l0000@ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04oooool007Gooooo0ol9jPX7ooooo`03o`000?oooooooooo00Gooooo00?o0000
ojO0jonW`>/02_nW`>/3o`WZ2PSoYl3[00Go0000oh]BR?n;DXSoRe:8o`00000:ooooo`?o2NX:0ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo0ol9jPXWooooo`?o2NX:00Co
ooooo`000?oooooo00004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo
001booooo`?o2NX:2_ooool00ol0003oooooooooo`05ooooo`;o00001_nW`>/00ol0003oYl3[o`WZ
2P02o`WZ2PcoYl3[00Co0000oh]BR?n;DXSo00001oooool3o`WZ2PKooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`?o2NX:9oooool3o`WZ2PCooooo0_l0000Aooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool05?ooool006oooooo0ol9jPX=ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool000001?nW`>/3o`WZ2Q3oYl3[00?o0000oh]BR?l000001?oo
ool3o`WZ2PWooooo00?o0000ooooooooool01?ooool00ol0003oooooo`WZ2P02o`WZ2ROooooo0ol9
jPX8ooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000Fooooo`00K?oo
ool3o`WZ2Q3ooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00003o`WZ2QCoYl3[
0ol00003o`WZ2Pcooooo00?o0000ooooooooool00oooool3o`WZ2RKooooo1?l9jPX;ooooo`03o`00
0?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000Fooooo`00JOooool3o`WZ2Q?ooooo
00?o0000ooooooooool01Oooool01?l0003o2NX:o`WZ2_l9jPXFojO0j`;o2NX:00?o0000o`WZ2_oo
ool03_ooool01?l0003oooooooooooooool2o`WZ2P;ooooo00?o0000ooooooooool08Oooool3o`WZ
2Poooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00000Gooooo`00I_ooool3o`WZ2QKo
oooo00?o0000ooooooooool00_ooool3o`WZ2P05o`000?ooooooooooooooool000004_nW`>/3o`WZ
2P;oRe:800?o0000ooooooooool03_ooool01?l0003o2NX:o`WZ2_l9jPX4ooooo`03o`000?oooooo
oooo01kooooo0ol9jPXCooooo`03o`000?oooooooooo013ooooo00?o0000ooooool000005oooool0
06?ooooo0ol9jPXIooooo`03o`000?oooooo2NX:00;o2NX:0oooool00ol0003oooooooooo`02oooo
o`03o`000?nW`>_oYl3[00coYl3[0ol9jPX5oh]BR0;o00003Oooool3o`WZ2P03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06_ooool4o`WZ2QKooooo00?o0000ooooooooool04?ooool00ol0
003oooooo`00000Gooooo`00Goooool4o`WZ2Q_ooooo00?o2NX:o`000?l9jPX01_ooool00ol0003o
ooooooooo`02ooooo`03o`000?nW`>_oYl3[00SoYl3[1?l9jPX8oh]BR003o`000?nW`>_o000000Wo
oooo0ol9jPX3ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool3o`WZ2Q_o
oooo00?o0000ooooooooool04?ooool2o`0001Oooooo001Looooo`?o2NX:7?ooool3o`WZ2P03oooo
ool0003ooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oYl3[ojO0j`04ojO0j`?o2NX:
3?n;DXP01?l0003oYl3[ojO0jol00005ooooo`?o2NX:1_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01Cooooo0ol9jPXNooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool05_ooool005Wooooo0ol9jPXLooooo`?o2NX:1?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ojO0jonW`>/00ol9jPX?oh]BR004o`000?nW`>_oYl3[ojO0j`?o
00000_l9jPX9ooooo`03o`000?oooooooooo00;ooooo0ol0000Booooo`Co2NX:8_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo001Fooooo`?o2NX:7?ooool3o`WZ2POooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04o`WZ2_l0003o0000o`WZ2Q;o
Re:800?o0000ojO0jonW`>/00_l9jPX2o`0000_ooooo00?o0000ooooool000000_l00002ooooo`03
o`000?oooooooooo00gooooo0ol9jPXVooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool05_ooool005?ooooo0ol9jPXLooooo`?o2NX:2_ooool00ol0003oooooooooo`03ooooo`?o0000
0_ooool3o`WZ2P03ooooool0003o000001?oRe:800?o0000o`WZ2_l9jPX00onW`>/00ol0003ooooo
ooooo`09ooooo`;o00001Oooool00ol0003oooooooooo`0:ooooo`?o2NX::Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01Oooooo001@ooooo`?o2NX:6oooool4o`WZ2Pgooooo00?o
0000ooooool000000ol00002ooooo`03o`000?l9jP[o2NX:00Gooooo00?o0000oh]BR?n;DXP04On;
DXP00ol0003oYl3[ojO0j`04ojO0j`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`?o2NX:;Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Oooooo001=ooooo`?o2NX:6oooool3o`WZ2Q7ooooo0_l00003ooooo`?o2NX:00?ooooo
o`000?ooool01Oooool00ol0003oRe:8oh]BR00Aoh]BR003o`000?nW`>_oYl3[00GoYl3[00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo1?l9jPX`
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool004[ooooo0ol9jPXKoooo
o`?o2NX:5?ooool00ol0003oooooo`WZ2P02o`WZ2PGooooo00?o0000ooooooooool00oooool00ol0
003oRe:8oh]BR00Aoh]BR003o`000?nW`>_oYl3[00KoYl3[00?o0000ooooooooool01_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?o2NX:=Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01Oooooo0017ooooo`?o2NX:6oooool3o`WZ2QKooooo00?o2NX:o`000?l9
jPX02Oooool00ol0003oooooooooo`02ooooo`03o`000?n;DXSoRe:8017oRe:800?o0000ojO0jonW
`>/01_nW`>/00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo0ol9jPXhooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool004Cooooo0ol9jPXKooooo`?o2NX:
5_ooool3o`WZ2P03ooooool0003ooooo00[ooooo00Go0000ooooooooooooooooo`00000Coh]BR003
o`000?nW`>_oYl3[00OoYl3[00?o0000ooooooooool01Oooool00ol0003oooooooooo`04o`WZ2P03
o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`00
@Oooool3o`WZ2Q_ooooo0ol9jPXFooooo`?o2NX:1Oooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`0001?oRe:800?o0000ojO0jonW`>/02?nW`>/00ol0003oooooooooo`04ooooo`?o
2NX:1?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06?ooool003kooooo0ol9jPXKooooo`?o2NX:5Oooool4o`WZ2PSooooo00?o0000ooooooooool0
2_ooool00ol0003o2NX:o`00000Coh]BR003o`000?nW`>_oYl3[00WoYl3[00?o0000ooooooooool0
0ol9jPX00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Hooooo`00>oooool3o`WZ2Q[ooooo1?l9jPXEooooo`?o2NX:3?oo
ool00ol0003oooooooooo`07ooooo`?o2NX:00?oooooo`000?l000002On;DXP00ol0003oRe:8oh]B
R007oh]BR003o`000?nW`>_oYl3[00WoYl3[0ol9jPX3ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo000h
ooooo`?o2NX:6_ooool3o`WZ2QKooooo0ol9jPX?ooooo`03o`000?oooooooooo00?ooooo1?l9jPX5
ooooo`03o`000?n;DXSoRe:8017oRe:800?o0000ojO0jonW`>/01OnW`>/4o`WZ2P;oYl3[00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Iooooo`00=Oooool3o`WZ2Q[ooooo0ol9jPXFooooo`?o2NX:4_ooool0
0ol0003oooooooooo`03o`WZ2PWooooo0_l0000Boh]BR003o`000?nW`>_oYl3[00;oYl3[0ol9jPX7
ojO0j`04o`000?ooooooooooo`0000Cooooo0ol0000mooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool06Oooool003;ooooo0ol9jPXJooooo`?o2NX:5_ooool3o`WZ2QGooooo00?o0000
o`WZ2_l9jPX03?ooool3o`00017oRe:80_l00003o`WZ2P_oYl3[00Co0000ooooool0003ooooo0ol0
0002ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Iooooo`00<?ooool2o`WZ2Q[ooooo0ol9jPXFooooo`?o2NX:5Oooool3o`WZ2P03o`000?oooooo
oooo00Wooooo1?l000000on;DXSo0000oh]BR00>oh]BR0;o2NX:0_l0000?ojO0j`?o00001Oooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool0
04Wooooo0ol9jPXFooooo`?o2NX:5Oooool3o`WZ2PCooooo00?o0000ooooooooool01Oooool3o`00
00?ooooo00Co0000oh]BR?n;DXSo00002on;DXP3o`WZ2P?oRe:800?o0000ojO0jonW`>/03OnW`>/2
o`0000Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01[ooooo0016ooooo`?o2NX:5Oooool4o`WZ2QCooooo1?l9jPX7ooooo`03o`000?oooooooooo
00;ooooo0ol00006ooooo`05o`000?n;DXSoRe:8oh]BR?l000001on;DXP3o`WZ2PKoRe:800?o0000
ojO0jonW`>/03_nW`>/00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`00@oooool3o`WZ2QGooooo0ol9jPXEoooo
o`?o2NX:2oooool00ol0003oooooo`000002o`0000Wooooo00?o0000oh]BR?n;DXP00_n;DXP00ol0
003oRe:8oh]BR004o`WZ2PWoRe:800?o0000ojO0jonW`>/03onW`>/00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Joooo
o`00?oooool4o`WZ2QGooooo0ol9jPXEooooo`?o2NX:3_ooool2o`0000cooooo00?o0000oh]BR?n;
DXP00_n;DXP00ol9jP[o0000o`WZ2P0=oh]BR0;o00004OnW`>/00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`00
??ooool3o`WZ2QKooooo0ol9jPXEooooo`?o2NX:4Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?n;DXSo2NX:00;o2NX:0_n;DXP00ol0003oRe:8oh]BR00;oh]BR004o`000?oooooo0000o`00013o
Yl3[00?o0000ooooooooool00_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06oooool003Wooooo0ol9jPXFooooo`?o2NX:5?ooool4o`WZ2QGooooo
00?o0000ooooooooool02?ooool01?l9jP[o0000o`WZ2_l9jPX6oh]BR003o`000?n;DXSoRe:800[o
Re:800Co0000oooooooooooooooo0_l0000?ojO0j`05o`000?ooooooooooooooool00000?oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo000fooooo`?o2NX:5_ooool3o`WZ
2QCooooo0ol9jPXIooooo`03o`000?oooooooooo00Gooooo0ol9jPX00ooooooo0000o`000008oh]B
R003o`000?n;DXSoRe:800WoRe:800?o0000ooooooooool00oooool2o`0000koYl3[00Co0000oooo
oooooooo0000@?ooool01?l0003oooooooooool0000Nooooo`00<oooool3o`WZ2QKooooo0ol9jPXD
ooooo`?o2NX:7Oooool01?l0003oooooooooooooool3o`WZ2PGooooo00?o0000oh]BR?n;DXP01on;
DXP00ol0003oRe:8oh]BR008oh]BR003o`000?oooooooooo00Gooooo0ol0000<ojO0j`03o`000?oo
oooo0000043ooooo00Co0000oooooooooooo00007_ooool0033ooooo0ol9jPXFooooo`?o2NX:5?oo
ool3o`WZ2R3ooooo00Co0000o`WZ2_l9jP[o2NX:2?ooool00ol0003oRe:8oh]BR006oh]BR0?o0000
2On;DXP00ol0003oooooooooo`08ooooo`;o00002onW`>/2o`00043ooooo00Co0000oooooooooooo
00007_ooool002gooooo0ol9jPXEooooo`Co2NX:4oooool4o`WZ2R3ooooo1?l9jPX00ol0003ooooo
ooooo`08ooooo`03o`000?n;DXSoRe:800?oRe:80ol00003oh]BR003o`000?n;DXSoRe:800KoRe:8
00?o0000ooooooooool02_ooool2o`0000SoYl3[0ol00011ooooo`03o`000?oooooo000001kooooo
000Zooooo`?o2NX:5Oooool3o`WZ2QCooooo0ol9jPXQooooo`?o2NX:1?ooool00ol0003ooooooooo
o`08ooooo`03o`000?n;DXSoRe:800?o00001on;DXP00ol0003oRe:8oh]BR005oh]BR003o`000?oo
oooooooo00cooooo0_l00002ojO0j`Co00000_ooool00ol0003oooooooooo`0oooooo`;o00007ooo
ool002Sooooo0_l9jPXEooooo`?o2NX:5?ooool3o`WZ2R7ooooo0ol9jPX7ooooo`03o`000?oooooo
oooo00Oooooo1?l0000;oh]BR003o`000?n;DXSoRe:800CoRe:800?o0000ooooooooool03_ooool2
o`0000Kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`00??ooool3o`WZ
2QCooooo0ol9jPXPooooo`Co2NX:2oooool00ol0003oooooooooo`03ooooo`?o000000?oooooo`00
0?n;DXP03On;DXP00ol0003oRe:8oh]BR003oh]BR003o`000?oooooooooo00kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Pooooo`00>Oooool3o`WZ2Q?ooooo1?l9jPXPooooo`?o
2NX:3oooool00ol0003oooooooooo`03o`0000Cooooo00?o0000oh]BR?n;DXP03On;DXP00ol0003o
Re:8oh]BR002oh]BR003o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Pooooo`00=_ooool3o`WZ2Q?ooooo0ol9jPXQooooo`?o2NX:4oooool2o`0000Oooooo
00?o0000oh]BR?n;DXP03_n;DXP01Ol0003oRe:8oh]BR?n;DXSo0000013ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Pooooo`00<oooool3o`WZ2Q?ooooo0ol9jPXQooooo`?o2NX:
5_ooool00ol0003oooooooooo`06ooooo`03o`000?n;DXSoRe:800ooRe:800Co0000oh]BR?n;DXSo
00004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo063ooooo000`ooooo`?o2NX:
4oooool3o`WZ2R3ooooo1?l9jPXJooooo`03o`000?oooooooooo00Gooooo00?o0000oh]BR?n;DXP0
4?n;DXP00ol0003oRe:8o`00000@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
H?ooool002kooooo0_l9jPXCooooo`?o2NX:8?ooool3o`WZ2Qoooooo00?o0000ooooooooool01?oo
ool00ol0003oRe:8oh]BR00Aoh]BR0;o00004?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo063ooooo000oooooo`Co2NX:8?ooool3o`WZ2R?ooooo00?o0000ooooooooool00oooool0
0ol0003oRe:8oh]BR00Aoh]BR0;o00004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo063ooooo000looooo`?o2NX:8Oooool3o`WZ2ROooooo00?o0000ooooooooool00_ooool00ol0
003oRe:8oh]BR00>oh]BR0?o000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo063ooooo000iooooo`?o2NX:8?ooool4o`WZ2R_ooooo00Go0000oooooooo
ooooooooo`00000=oh]BR0?o00001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0H?ooool003Kooooo0ol9jPXPooooo`?o2NX:;oooool01Ol0003o
oooooooooooooooo000000[oRe:80ol00009ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00_ooool3o`0006;ooooo000dooooo`;o2NX:8?ooool3o`WZ2S?ooooo00Co0000oooooooo
oooo00001on;DXP3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooo`000002o`00
00;ooooo00?o0000ooooooooool0H?ooool005?ooooo0ol9jPXgooooo`03o`000?oooooo000000Co
Re:80ol0000Aooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`03o`000?oooooooooo063o
oooo001?ooooo`Co2NX:>oooool2o`000004oh]BR?l0003o0000o`0001Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo001<ooooo`?o2NX:
@?ooool2o`0001Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo063ooooo0019ooooo`?o2NX:AOooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00AOooool4
o`WZ2TWooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0H?ooool004;ooooo0ol9jPY>ooooo`03o`000?oooooooooo
01Gooooo0ol00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool003oo
oooo0ol9jPYBooooo`03o`000?oooooooooo017ooooo0ol00003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00??ooool3o`WZ2UKooooo
00?o0000ooooooooool03Oooool3o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo05oooooo000hooooo`Co2NX:F_ooool00ol0003ooooooooo
o`08ooooo`Co00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Goooool003Gooooo0ol9jPYOooooo`03o`000?oooooooooo00Cooooo0ol0000@
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1O
ooooo`00<_ooool3o`WZ2V?ooooo00?o0000ooooooooool00ol0000Dooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`1Oooooo`00;oooool3o`WZ2VOooooo0_l0000Hoooo
o`04o`000?ooooooooooo`0000Gooooo0ol0001Qooooo`00;Oooool2o`WZ2Vcooooo00?o0000oooo
ooooool05_ooool01?l0003oooooo`000?ooool4o`0000;ooooo00?o0000ooooooooool0Goooool0
09cooooo0_l0000Gooooo`?o00001_ooool00ol0003oooooooooo`1Oooooo`00W_ooool2o`0001Co
oooo0ol00007ooooo`03o`000?oooooooooo05oooooo002Pooooo`03o`000?oooooooooo00kooooo
0ol00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:7ooooo0_l0
000;ooooo`?o00001Oooool2o`0000Kooooo00?o0000ooooooooool0Goooool00:?ooooo0_l00006
ooooo`?o00002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo05oooooo002Uoooo
o`03o`000?oooooooooo00?o00002oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo05oooooo002Vooooo`;o00003_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool0Goooool00:Sooooo0ol0000<ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool0Goooool00:_ooooo0_l0000:ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`1Oooooo`00[Oooool3o`0000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`00001Qooooo`00/?ooool2o`0000Gooooo00?o0000ooooooooool00oooool2o`00067o
oooo002booooo`;o00000oooool00ol0003oooooooooo`02ooooo`?o0000HOooool00;Cooooo1?l0
00001?oooooo0000o`000?l0001Tooooo`00]oooool2o`0006Oooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {247.5, 0}} -> {0.00318378, 0.0445563, \
0.00347436, 0.00347436}},
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[cylindricalsystem,{f>0},MatrixForm->True,DecomposeABCD->True]
\
\>", "Input",
  CellLabel->"In[74]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.0000000000000004`", "0"},
                    {"0", "1.0000000000000004`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      "1", \(\(-1.0000000000000004`\)\ d1 + 
                        1.0000000000000004`\ d2\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(1.0000000000000002`\ t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {\(-\(0.6577817908690828`\/f\)\), "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.0000000000000004`", "0"},
                    {"0", "1.0000000000000004`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      "1", \(\(-1.0000000000000004`\)\ d1 + 
                        1.0000000000000004`\ d2\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", \(1.`\ t\)},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0"},
                    {"0", "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "d1"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Row, TableAlignments -> 
          Center]]]], "Output",
  CellLabel->"Out[74]//TableForm=",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[cylindricalsystem,NumericalResults->True,MatrixForm->False]\
\>", "Input",
  CellLabel->"In[75]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],

Cell[BoxData[
    \({ABCDCenterPoint \[Rule] {{100, 0, 0}, {100, 0, 0}}, 
      ABCDMatrix \[Rule] {{{0.5345369974230242`, 
              73.30985480113881`}, {\(-0.009992120587251697`\), 
              0.5003939706374156`}}, {{1.0000000000000004`, 
              96.58300492998764`}, {0, 1.0000000000000004`}}}, 
      ABCDRotationMatrix \[Rule] {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {{1, 0, 
              0}, {0, 1, 0}, {0, 0, 1}}}, 
      SymbolicIntensity \[Rule] {100, 100}, 
      SymbolicOpticalLength \[Rule] {105.21897495681029`, 
          105.21897495681029`}, 
      SymbolicWaveLength \[Rule] {0.532`, 0.532`}}\)], "Output",
  CellLabel->"Out[75]=",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianTrace", "Subsubsection",
  CellTags->{"AOG0.", "4.5.2", "AOG4.", "AOG4.5", "AOG4.5.2"}],

Cell[CellGroupData[{

Cell["GaussianTrace[cylindricalsystem]", "Input",
  CellLabel->"In[76]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.2"}],

Cell[BoxData[
    \({{BeamSpotSize \[Rule] {5, 10}, BeamDivergence \[Rule] {0.01`, 0.005`}, 
        ComplexBeamParameter \[Rule] {\(\(999.9770710337976`\)\(\
\[InvisibleSpace]\)\) + 
              6.771809703999252`\ \[ImaginaryI], \(\(3999.9082841351897`\)\(\
\[InvisibleSpace]\)\) + 27.087238815996994`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.033859048519996264`, 0.06771809703999253`}, 
        WaistDistance \[Rule] {\(-999.9770710337976`\), \
\(-3999.9082841351897`\)}, 
        BeamScaleLength \[Rule] {6.771809703999252`, 27.087238815997008`}, 
        BeamCurvature \[Rule] {\(-1000.0229294919518`\), \
\(-4000.0917179678063`\)}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {0, 0, 0}, OpticalLength \[Rule] 0, 
        Intensity \[Rule] 100, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {5.2499945407194915`, 
            10.124997169263038`}, 
        BeamDivergence \[Rule] {\(-0.062484162623305285`\), 
            0.0032915024649937926`}, 
        ComplexBeamParameter \[Rule] {\(-168.04236812656717`\) + 
              0.1141797315717831`\ \[ImaginaryI], \(\(6152.066308938385`\)\(\
\[InvisibleSpace]\)\) + 41.14722547541536`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.0035672124579083212`, 0.0677180970399925`}, 
        WaistDistance \[Rule] {168.0423681265672`, \(-6152.066308938385`\)}, 
        BeamScaleLength \[Rule] {0.11417973157178311`, 41.14722547541535`}, 
        BeamCurvature \[Rule] {168.04244570825833`, \(-6152.341516336892`\)}, 
        ABCDMatrix \[Rule] {{{1, 
                50.000000000000014`}, {\(-0.00657781790869083`\), 
                0.32940959756421656`}}, {{1, 50.000000000000014`}, {0, 
                0.6583004929987581`}}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {49.999999999999986`, 0, 0}, 
        OpticalLength \[Rule] 50.01347257285403`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {4.937573804285335`, 
            10.141454314091357`}, 
        BeamDivergence \[Rule] {\(-0.09491738694994904`\), 
            0.005000000000000002`}, 
        ComplexBeamParameter \[Rule] {\(-104.03936885241038`\) + 
              
              0.0751645735841706`\ \[ImaginaryI], \(\(4056.491289065177`\)\(\
\[InvisibleSpace]\)\) + 27.087238815996994`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.0035672124579083178`, 0.06771809703999251`}, 
        WaistDistance \[Rule] {104.03936885241036`, \(-4056.491289065177`\)}, 
        BeamScaleLength \[Rule] {0.07516457358417054`, 27.087238815996997`}, 
        BeamCurvature \[Rule] {104.03942315601854`, \
\(-4056.6721642241237`\)}, 
        ABCDMatrix \[Rule] {{{0.9342218209130916`, 
                53.294095975642186`}, {\(-0.009992120587251692`\), 
                0.5003939706374152`}}, {{1, 56.5830049299876`}, {0, 1}}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {60.`, 0, 0}, 
        OpticalLength \[Rule] 65.20819689852712`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {3.0392268701589114`, 
            10.241452106480546`}, 
        BeamDivergence \[Rule] {\(-0.09491738694994907`\), 
            0.005000000000000002`}, 
        ComplexBeamParameter \[Rule] {\(-64.03936885241036`\) + 
              0.0751645735841705`\ \[ImaginaryI], \(\(4096.491289065178`\)\(\
\[InvisibleSpace]\)\) + 27.087238815996994`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.003567212457908317`, 0.06771809703999251`}, 
        WaistDistance \[Rule] {64.03936885241036`, \(-4096.491289065178`\)}, 
        BeamScaleLength \[Rule] {0.07516457358417052`, 27.087238815996997`}, 
        BeamCurvature \[Rule] {64.03945707490885`, \(-4096.670398076988`\)}, 
        ABCDMatrix \[Rule] {{{0.5345369974230242`, 
                73.30985480113881`}, {\(-0.009992120587251697`\), 
                0.5003939706374154`}}, {{1.0000000000000004`, 
                96.58300492998765`}, {0, 1.0000000000000004`}}}, 
        ABCDRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {100.`, 0, 0}, 
        OpticalLength \[Rule] 105.21897495681033`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 0.532`}}\)], "Output",
  CellLabel->"Out[76]=",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.2"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianPlot", "Subsubsection",
  CellTags->{"AOG0.", "4.5.3", "AOG4.", "AOG4.5", "AOG4.5.3"}],

Cell[CellGroupData[{

Cell["GaussianPlot[cylindricalsystem];", "Input",
  CellLabel->"In[77]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0 0.101923 [
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .10192 -6 -4.5 ]
[.01131 .10192 0 4.5 ]
[.01131 .20385 -6 -4.5 ]
[.01131 .20385 0 4.5 ]
[.01131 .30577 -6 -4.5 ]
[.01131 .30577 0 4.5 ]
[.01131 .40769 -6 -4.5 ]
[.01131 .40769 0 4.5 ]
[.01131 .50961 -6 -4.5 ]
[.01131 .50961 0 4.5 ]
[.01131 .61154 -6 -4.5 ]
[.01131 .61154 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .10192 m
.03006 .10192 L
s
[(1)] .01131 .10192 1 0 Mshowa
.02381 .20385 m
.03006 .20385 L
s
[(2)] .01131 .20385 1 0 Mshowa
.02381 .30577 m
.03006 .30577 L
s
[(3)] .01131 .30577 1 0 Mshowa
.02381 .40769 m
.03006 .40769 L
s
[(4)] .01131 .40769 1 0 Mshowa
.02381 .50961 m
.03006 .50961 L
s
[(5)] .01131 .50961 1 0 Mshowa
.02381 .61154 m
.03006 .61154 L
s
[(6)] .01131 .61154 1 0 Mshowa
.125 Mabswid
.02381 .02038 m
.02756 .02038 L
s
.02381 .04077 m
.02756 .04077 L
s
.02381 .06115 m
.02756 .06115 L
s
.02381 .08154 m
.02756 .08154 L
s
.02381 .12231 m
.02756 .12231 L
s
.02381 .14269 m
.02756 .14269 L
s
.02381 .16308 m
.02756 .16308 L
s
.02381 .18346 m
.02756 .18346 L
s
.02381 .22423 m
.02756 .22423 L
s
.02381 .24461 m
.02756 .24461 L
s
.02381 .265 m
.02756 .265 L
s
.02381 .28538 m
.02756 .28538 L
s
.02381 .32615 m
.02756 .32615 L
s
.02381 .34654 m
.02756 .34654 L
s
.02381 .36692 m
.02756 .36692 L
s
.02381 .38731 m
.02756 .38731 L
s
.02381 .42808 m
.02756 .42808 L
s
.02381 .44846 m
.02756 .44846 L
s
.02381 .46885 m
.02756 .46885 L
s
.02381 .48923 m
.02756 .48923 L
s
.02381 .53 m
.02756 .53 L
s
.02381 .55038 m
.02756 .55038 L
s
.02381 .57077 m
.02756 .57077 L
s
.02381 .59115 m
.02756 .59115 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .50961 m
.09004 .51316 L
.16227 .51702 L
.23011 .52065 L
.29535 .52414 L
.36479 .52786 L
.43164 .53144 L
.46571 .53326 L
.47504 .53376 L
.48494 .53429 L
.49338 .53474 L
.4957 .53486 L
.49697 .53493 L
.49819 .535 L
.49931 .53506 L
.50054 .53491 L
.50269 .5342 L
.57114 .51131 L
.64082 .4801 L
.7079 .44603 L
.77918 .40983 L
.84787 .37494 L
.91395 .34138 L
.97619 .30977 L
s
0 0 0 r
gsave
.5 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .56185 L
s
.59524 0 m
.59524 .56185 L
s
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00A?ooool5o`0000?ooooo0_l0000Vooooo`?o00000oooool2o`0002Gooooo0ol00004oooo
o`;o00009Oooool3o`0000Cooooo0_l0000Rooooo`?o00001?ooool2o`0000Cooooo0_l0000Goooo
o`00AOooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Kooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo027ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0002?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0001Kooooo0016ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00008oooool5o`0000;ooooo00Co0000oooooooooooo00008oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00008_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005_ooool004Oooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool0000Sooooo`Co00000oooool01?l0003oooooooooool0000Tooooo`?o0000
0oooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000Fooooo`00A?ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00009?ooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0002?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Sooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Rooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Fooooo`00A?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00009Oooool2o`0000?o
oooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0002?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00027ooooo
0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005_ooool004Go
oooo0ol00004ooooo`;o00009oooool00ol0003oooooooooo`02ooooo`;o00009_ooool2o`0000Co
oooo0_l0000Uooooo`?o00001?ooool2o`0002?ooooo00?o0000ooooooooool00oooool2o`0000Co
oooo0_l0000Gooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`005_oooooco`0001Oooooo000Looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Koooo
o`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?oo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0K
ooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`00
7?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Kooooo`005?ooool3o`0000Gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06ooo
ool001Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`005Oooool00ol0
003oooooooooo`04ooooo`;o0000LOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool06oooool001Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Kooooo`005Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo
000Dooooo`;o00001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`005Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03
o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo
000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Loooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_o
oooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Cooooo`Go00001?ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Kooooo`005?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000E
ooooo`03o`000?oooooooooo00Cooooo0_l0001aooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`005_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo01_ooooo000Cooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0Kooooo`004oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool06oooool001Cooooo0ol00005ooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_o
oooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000L
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03
o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo
000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo01_ooooo000Dooooo`?o00001Oooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0K
ooooo`004oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool0
01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`005Oooool2o`0000Go
oooo0_l0001aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Kooooo`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Hooooo`03o`WZ2_l0003ooooo01cooooo
000Cooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1`ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0E_ooool2o`WZ2P03ooooool0003ooooo01cooooo
000Dooooo`?o00001Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0E?ooool2o`WZ2P?ooooo00?o0000ooooooooool06oooool001cooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo057ooooo0ol9jPX5
ooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1?ooooo`;o2NX:2?ooool00ol0003oooooooooo`0Koooo
o`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0COooool2o`WZ2P[ooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04_ooooo0_l9jPX<ooooo`03o`00
0?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`19ooooo`;o2NX:3_ooool00ol0003oooooooooo`0Kooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Aoooool2
o`WZ2Q3ooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo04Kooooo00?o2NX:ooooooooool04?ooool00ol0
003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0A?ooool2o`WZ2Q?ooooo00?o0000ooooooooool06oooool001cooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04;ooooo
0_l9jPXEooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`10ooooo`;o2NX:5oooool00ol0003ooooooooo
o`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0?_ooool2o`WZ2QWooooo00?o0000ooooooooool06oooool001cooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03gooooo00?o2NX:oooo
ooooool06Oooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0>oooool2o`WZ2Qcooooo00?o0000oooooooo
ool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo03Wooooo0_l9jPXNooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0gooooo`;o2NX:8?oo
ool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0=Oooool2o`WZ2R;ooooo00?o0000ooooooooool06oooool0
01cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
03?ooooo0_l9jPXTooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0aooooo`;o2NX:9_ooool00ol0003o
ooooooooo`0Kooooo`005Oooool3o`0000Cooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02oooooo0_l9jPXXooooo`03o`000?oooooooooo01_ooooo
000Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02gooooo0_l9jPXZooooo`03o`000?oooooooooo01_ooooo000C
ooooo`Go00001?ooool2o`00077ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0[
ooooo`;o2NX:;?ooool00ol0003oooooooooo`0Kooooo`004oooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Y
ooooo`;o2NX:;_ooool00ol0003oooooooooo`0Kooooo`005?ooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Woooo
o`;o2NX:<?ooool00ol0003oooooooooo`0Kooooo`005Oooool2o`0000Gooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Gooooo0_l9jPXbooooo`03
o`000?oooooooooo01_ooooo000Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02?ooooo0_l9jPXdooooo`03o`00
0?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Qooooo`;o2NX:=_ooool00ol0003oooooooooo`0Kooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07oooool2
o`WZ2SSooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01gooooo0_l9jPXjooooo`03o`000?oooooooooo
01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Kooooo`;o2NX:??ooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06Oooool2o`WZ2Skooooo
00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01Oooooo0_l9jPY0ooooo`03o`000?oooooooooo01_ooooo000L
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0E
ooooo`;o2NX:@_ooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool2o`WZ2TCooooo00?o0000oooo
ooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo017ooooo0_l9jPY6ooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`;o2NX:
B?ooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool03Oooool2o`WZ2T[ooooo00?o0000ooooooooool06ooo
ool001cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00_ooooo0_l9jPY<ooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09ooooo`;o2NX:C_ooool00ol0
003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01oooool2o`WZ2U3ooooo00?o0000ooooooooool06oooool001cooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo
0_l9jPYBooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`;o2NX:E?ooool00ol0003ooooooooo
o`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00Co0000
oooooooooooooooo0_l9jPYFooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool05?ooool01?l0003o2NX:o`WZ2_l9jPYHooooo`03o`000?oo
oooooooo01_ooooo000Dooooo`?o00001Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo01?ooooo00?o2NX:o`000?ooool0F_ooool00ol0003oooooooooo`0Kooooo`004oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0A
ooooo`;o2NX:00?oooooo`000?ooool0F_ooool00ol0003oooooooooo`0Kooooo`005oooool00ol0
003oooooooooo`02ooooo`Wo2NX:J_ooool00ol0003oooooooooo`0?ooooo`;o2NX:0oooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Gooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_oooolAo`WZ2UWooooo00?o0000ooooooooool03?ooool3o`WZ2PGo
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`004oooool4o`0000Gooooo
00?o0000ooooooooool05ooooolAo`WZ2TSooooo00?o0000ooooooooool02Oooool3o`WZ2PSooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Sooooo4?l9jPXhooooo`03o`000?oooooooooo00Kooooo0ol9
jPX;ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001?ooooo1Ol00004
ooooo`03o`000?oooooooooo03Sooooo4?l9jPXXooooo`03o`000?oooooooooo00?ooooo0ol9jPX>
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000oooo
ooooool0B?oooolMo`WZ2P_ooooo00?o0000ooooooooool00ol9jPXAooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0IOooool;o`WZ2P03
o`000?l9jP[o2NX:01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`00
7?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Kooooo`007?ooool00ol0003oooooooooo`3oooooo`;ooooo000Looooo`03o`000?oooooooooo
06gooooo1Ol0000Booooo`Go0000F?ooool3o`0001gooooo000Looooo`03o`000?oooooooooo06ko
oooo00Co0000oooooooooooo00004oooool01?l0003oooooooooool0001Hooooo`04o`000?oooooo
ooooo`0001cooooo000Looooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Looooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Jooooo`;o00007Oooool001co
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool07Oooool001cooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo05Wooooo00Co0000oooooooooooo00007?ooool001cooooo
00?o0000ooooooooool0KOooool3o`0001Cooooo0ol0001Kooooo`?o00007?ooool001Cooooo0ol0
0005ooooo`03o`000?oooooooooo0?oooooo0_ooool001?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo0?oooooo0_ooool001?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo0?oooooo0_ooool001?ooooo1?l00005ooooo`;o0000ooooool3
ooooo`004oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo0_ooool001Co
oooo00?o0000ooooooooool0ooooool:ooooo`005Oooool2o`000?oooooo2_ooool00?oooooo8Ooo
ool00?oooooo8Oooool008Wooooo0ol0002Dooooo`00R_ooool00ol0003oooooooooo`2Cooooo`00
IOooool4o`0000?ooooo0ol00003ooooo`Co000000Koooooo`000?oooooo0000ooooool00008oooo
o`?o00000oooool3o`0000?ooooo0ol00004ooooo`;o00002Oooool3o`0000;ooooo1Ol000000ooo
oooo0000o`000003o`0000;ooooo0ol0001Yooooo`00I_ooool01_l0003oooooooooool0003ooooo
o`0000Gooooo00Co0000oooooooooooo00000_ooool01Ol0003oooooo`000?oooooo000000Sooooo
00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0006cooooo001Vooooo`05
o`000?ooooooooooo`000?ooool01Ol00002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo
000000_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000kooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooooooooooo
o`Go0000J?ooool006Kooooo0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`000002
ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00009ooooo`;o00000oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00003?ooool2o`0000Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool0I_ooool006Kooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo0_l00003ooooo`;o
000000?oooooo`000?ooool02?ooool00ol0003oooooooooo`02ooooo`Co00000oooool3o`0000;o
oooo1?l00009ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Go00000_ooool3o`0006Wo
oooo001Vooooo`04o`000?ooooooooooo`0001[ooooo00Co0000oooooooooooo00003_ooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0007[ooooo001Uooooo`Co00007?ooool3o`00
00kooooo00?o0000ooooooooool02_ooool3o`0000?ooooo00?o0000ooooooooool0M?ooool00?oo
oooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.1403, -0.486802, \
0.432986, 0.0404588}},
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0 0.0528488 [
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .1057 -6 -4.5 ]
[.01131 .1057 0 4.5 ]
[.01131 .2114 -6 -4.5 ]
[.01131 .2114 0 4.5 ]
[.01131 .31709 -6 -4.5 ]
[.01131 .31709 0 4.5 ]
[.01131 .42279 -6 -4.5 ]
[.01131 .42279 0 4.5 ]
[.01131 .52849 -12 -4.5 ]
[.01131 .52849 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .1057 m
.03006 .1057 L
s
[(2)] .01131 .1057 1 0 Mshowa
.02381 .2114 m
.03006 .2114 L
s
[(4)] .01131 .2114 1 0 Mshowa
.02381 .31709 m
.03006 .31709 L
s
[(6)] .01131 .31709 1 0 Mshowa
.02381 .42279 m
.03006 .42279 L
s
[(8)] .01131 .42279 1 0 Mshowa
.02381 .52849 m
.03006 .52849 L
s
[(10)] .01131 .52849 1 0 Mshowa
.125 Mabswid
.02381 .02642 m
.02756 .02642 L
s
.02381 .05285 m
.02756 .05285 L
s
.02381 .07927 m
.02756 .07927 L
s
.02381 .13212 m
.02756 .13212 L
s
.02381 .15855 m
.02756 .15855 L
s
.02381 .18497 m
.02756 .18497 L
s
.02381 .23782 m
.02756 .23782 L
s
.02381 .26424 m
.02756 .26424 L
s
.02381 .29067 m
.02756 .29067 L
s
.02381 .34352 m
.02756 .34352 L
s
.02381 .36994 m
.02756 .36994 L
s
.02381 .39637 m
.02756 .39637 L
s
.02381 .44922 m
.02756 .44922 L
s
.02381 .47564 m
.02756 .47564 L
s
.02381 .50206 m
.02756 .50206 L
s
.02381 .55491 m
.02756 .55491 L
s
.02381 .58134 m
.02756 .58134 L
s
.02381 .60776 m
.02756 .60776 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .52849 m
.09004 .52941 L
.16227 .53041 L
.23011 .53135 L
.29535 .53226 L
.36479 .53322 L
.43164 .53415 L
.46571 .53462 L
.48366 .53487 L
.49348 .535 L
.50269 .53512 L
.51962 .53527 L
.53828 .53544 L
.57114 .53574 L
.63761 .53655 L
.70828 .53753 L
.77635 .53848 L
.84182 .53938 L
.9115 .54035 L
.97619 .54125 L
s
0 0 0 r
gsave
.5 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .56185 L
s
.59524 0 m
.59524 .56185 L
s
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00Aoooool5o`0000?ooooo0_l0000Vooooo`?o00000oooool2o`0002Gooooo0ol00004oooo
o`;o00009Oooool3o`0000Cooooo0_l0000Rooooo`?o00001?ooool2o`0000Cooooo0_l0000Doooo
o`00B?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Kooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo027ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0002?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0001?ooooo0019ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00008oooool5o`0000;ooooo00Co0000oooooooooooo00008oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00008_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004oooool004[ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool0000Sooooo`Co00000oooool01?l0003oooooooooool0000Tooooo`?o0000
0oooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000Cooooo`00Aoooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00009?ooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0002?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Sooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Rooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Cooooo`00Aooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00009Oooool2o`0000?o
oooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0002?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00027ooooo
0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004oooool004So
oooo0ol00004ooooo`;o00009oooool00ol0003oooooooooo`02ooooo`;o00009_ooool2o`0000Co
oooo0_l0000Uooooo`?o00001?ooool2o`0002?ooooo00?o0000ooooooooool00oooool2o`0000Co
oooo0_l0000Dooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`006Ooooooco`0001Cooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hoooo
o`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0H
ooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`00
7oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`005_ooool5
o`0000Cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool06?ooool001Oooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Hooooo`006?ooool00ol0003oooooooooo`04ooooo`;o0000LOooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`005_ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001Kooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo01Sooooo000Gooooo`?o00001Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0H
ooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`00
7oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hoooo
o`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0Hooooo`006?ooool3o`0000Cooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`005_ooool5o`0000Cooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool06?ooool001Kooooo00Co0000oooooooooooo00001Oooool2o`00077ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01Sooooo000G
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001Sooooo0_l00005oooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo01Sooooo000Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool06?ooool001oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001oooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?oo
ool001oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool06?ooool001oooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001oo
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool06?ooool001oooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001oooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool06?ooool001oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001oooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool06?ooool001oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001oooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
6?ooool001oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool06?ooool001oooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool0
01oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool06?ooool001oooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001oooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool06?ooool001oooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001oooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool06?ooool001oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001Oooooo0ol00005ooooo`03
o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo01Sooooo000Fooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Hooooo`005_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l0001aooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`00
5_ooool4o`0000Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`0Hooooo`005oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo01Sooooo000Hooooo`;o00001Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hoooo
o`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0H
ooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`00
7oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Hooooo`005oooool3o`0000Gooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001Ko
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01Sooooo000Fooooo`05
o`000?ooooooooooooooool000001?ooool2o`00077ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo01Sooooo000Gooooo`?o00001Oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Hooooo`005_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool06?ooool001Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01So
oooo000Gooooo`?o00001Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hoooo
o`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0H
ooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`00
7oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`004Oooool3o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo01Sooooo000Booooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`004_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004oooooc_o2NX:>?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06?ooool001;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03So
oooo>?l9jPX00ol0003o2NX:o`WZ2P0;o`WZ2PWooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Hooooo`004Oooool2o`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo00_ooooo2Ol9jPX00ol0003o2NX:o`WZ2P13o`WZ2QKo
oooo00?o0000ooooooooool06?ooool001;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04?ooooo
5_l9jPX00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Hooooo`007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003ooooooooo
o`3nooooo`007oooool00ol0003oooooooooo`1]ooooo`Go00004_ooool5o`0005Sooooo0ol0000J
ooooo`007oooool00ol0003oooooooooo`1^ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000
oooooooooooo0000F?ooool01?l0003oooooooooool0000Iooooo`007oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`0Gooooo`007oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0F_ooool2o`0001[ooooo000Oooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01[ooooo000Oooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`04
o`000?ooooooooooo`0001Wooooo000Oooooo`03o`000?oooooooooo06gooooo0ol0000Dooooo`?o
0000Foooool3o`0001Wooooo000Oooooo`03o`000?oooooooooo0?kooooo000Oooooo`03o`000?oo
oooooooo0?kooooo000Oooooo`03o`000?oooooooooo0?kooooo000Oooooo`03o`000?oooooooooo
0?kooooo000Oooooo`03o`000?oooooooooo0?kooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo002<ooooo`?o0000TOooool008gooooo00?o0000ooooooooool0
T?ooool006Sooooo1?l00003ooooo`?o00000oooool4o`000006ooooool0003oooooo`000?oooooo
00002?ooool3o`0000?ooooo0ol00003ooooo`?o00001?ooool2o`0000Wooooo0ol00002ooooo`Go
000000?oooooo`000?l000000ol00002ooooo`?o0000I_ooool006Wooooo00Ko0000oooooooooooo
0000ooooool00005ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`00
0008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool0001Yooooo`00
JOooool01Ol0003oooooooooool0003ooooo00Go00000_ooool3o`0000;ooooo00Go0000ooooool0
003oooooo`00000;ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool0
1?l0003oooooooooool0000>ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooo
ooooooooool5o`0006Gooooo001Yooooo`?o00000_ooool01ol0003ooooooooooooooooo0000oooo
ool000000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00002Oooool2o`0000?ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000cooooo0_l00004
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo06?ooooo001Yooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`;o0000
0oooool2o`000003ooooool0003ooooo00Sooooo00?o0000ooooooooool00_ooool4o`0000?ooooo
0ol00002ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`?o00000oooool5o`0000;ooooo
0ol0001Vooooo`00JOooool01?l0003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000ko
oooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0001gooooo`00J?ooool4o`0001co
oooo0ol0000>ooooo`03o`000?oooooooooo00[ooooo0ol00003ooooo`03o`000?oooooooooo077o
oooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.4393, -0.938836, \
0.432986, 0.0780279}},
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
GaussianPlot[cylindricalsystem,RenderedParameters->ComplexBeamParameter];\
\>", "Input",
  CellLabel->"In[78]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.103622 0.000499708 [
[.21429 .09112 -6 -9 ]
[.21429 .09112 6 0 ]
[.40476 .09112 -6 -9 ]
[.40476 .09112 6 0 ]
[.59524 .09112 -6 -9 ]
[.59524 .09112 6 0 ]
[.78571 .09112 -6 -9 ]
[.78571 .09112 6 0 ]
[.97619 .09112 -9 -9 ]
[.97619 .09112 9 0 ]
[.01131 .00368 -24 -4.5 ]
[.01131 .00368 0 4.5 ]
[.01131 .20356 -18 -4.5 ]
[.01131 .20356 0 4.5 ]
[.01131 .30351 -18 -4.5 ]
[.01131 .30351 0 4.5 ]
[.01131 .40345 -18 -4.5 ]
[.01131 .40345 0 4.5 ]
[.01131 .50339 -18 -4.5 ]
[.01131 .50339 0 4.5 ]
[.01131 .60333 -24 -4.5 ]
[.01131 .60333 0 4.5 ]
[.5 .63053 -83.0625 0 ]
[.5 .63053 83.0625 12 ]
[.5 .65895 -5 -6 ]
[.5 .65895 5 6 ]
[.59524 .65895 -5 -6 ]
[.59524 .65895 5 6 ]
[.97619 .65895 -5 -6 ]
[.97619 .65895 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .10362 m
.21429 .10987 L
s
[(20)] .21429 .09112 0 1 Mshowa
.40476 .10362 m
.40476 .10987 L
s
[(40)] .40476 .09112 0 1 Mshowa
.59524 .10362 m
.59524 .10987 L
s
[(60)] .59524 .09112 0 1 Mshowa
.78571 .10362 m
.78571 .10987 L
s
[(80)] .78571 .09112 0 1 Mshowa
.97619 .10362 m
.97619 .10987 L
s
[(100)] .97619 .09112 0 1 Mshowa
.125 Mabswid
.07143 .10362 m
.07143 .10737 L
s
.11905 .10362 m
.11905 .10737 L
s
.16667 .10362 m
.16667 .10737 L
s
.2619 .10362 m
.2619 .10737 L
s
.30952 .10362 m
.30952 .10737 L
s
.35714 .10362 m
.35714 .10737 L
s
.45238 .10362 m
.45238 .10737 L
s
.5 .10362 m
.5 .10737 L
s
.54762 .10362 m
.54762 .10737 L
s
.64286 .10362 m
.64286 .10737 L
s
.69048 .10362 m
.69048 .10737 L
s
.7381 .10362 m
.7381 .10737 L
s
.83333 .10362 m
.83333 .10737 L
s
.88095 .10362 m
.88095 .10737 L
s
.92857 .10362 m
.92857 .10737 L
s
.25 Mabswid
0 .10362 m
1 .10362 L
s
.02381 .00368 m
.03006 .00368 L
s
[(-200)] .01131 .00368 1 0 Mshowa
.02381 .20356 m
.03006 .20356 L
s
[(200)] .01131 .20356 1 0 Mshowa
.02381 .30351 m
.03006 .30351 L
s
[(400)] .01131 .30351 1 0 Mshowa
.02381 .40345 m
.03006 .40345 L
s
[(600)] .01131 .40345 1 0 Mshowa
.02381 .50339 m
.03006 .50339 L
s
[(800)] .01131 .50339 1 0 Mshowa
.02381 .60333 m
.03006 .60333 L
s
[(1000)] .01131 .60333 1 0 Mshowa
.125 Mabswid
.02381 .02867 m
.02756 .02867 L
s
.02381 .05365 m
.02756 .05365 L
s
.02381 .07864 m
.02756 .07864 L
s
.02381 .12861 m
.02756 .12861 L
s
.02381 .15359 m
.02756 .15359 L
s
.02381 .17858 m
.02756 .17858 L
s
.02381 .22855 m
.02756 .22855 L
s
.02381 .25353 m
.02756 .25353 L
s
.02381 .27852 m
.02756 .27852 L
s
.02381 .32849 m
.02756 .32849 L
s
.02381 .35348 m
.02756 .35348 L
s
.02381 .37846 m
.02756 .37846 L
s
.02381 .42843 m
.02756 .42843 L
s
.02381 .45342 m
.02756 .45342 L
s
.02381 .4784 m
.02756 .4784 L
s
.02381 .52837 m
.02756 .52837 L
s
.02381 .55336 m
.02756 .55336 L
s
.02381 .57834 m
.02756 .57834 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -144.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Real) show
93.000 13.000 moveto
(Complex) show
141.000 13.000 moveto
(Beam) show
171.125 13.000 moveto
(Parameter) show
225.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .60332 m
.09004 .59984 L
.16227 .59605 L
.23011 .59249 L
.29535 .58907 L
.36479 .58543 L
.43164 .58192 L
.44915 .581 L
.46816 .58 L
.47688 .57955 L
.48611 .57906 L
.494 .57865 L
.49616 .57853 L
.49735 .57847 L
.49849 .57841 L
.50068 .01961 L
.50269 .01951 L
.53703 .01771 L
.56816 .01607 L
.5765 .01564 L
.58553 .01516 L
.58967 .01494 L
.59193 .01483 L
.59405 .01472 L
.59585 .0516 L
.59778 .0515 L
.60189 .05128 L
.63784 .0494 L
.70874 .04568 L
.77705 .04209 L
.84276 .03865 L
.91267 .03498 L
.97619 .03164 L
s
0 0 0 r
gsave
.5 .65895 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .65895 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .65895 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .01545 m
0 0 rlineto s
.5 .01545 m
.5 .61803 L
s
.59524 .01545 m
0 0 rlineto s
.59524 .01545 m
.59524 .61803 L
s
.97619 .01545 m
0 0 rlineto s
.97619 .01545 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`002_ooool5o`0000?ooooo0_l00004ooooo`;o0000ooooool7ooooo`00
2oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`3nooooo`001?ooool5o`0000?ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo0ol0
003nooooo`003Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?kooooo000:ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0o_ooool000[ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1fooooo`03o`000?oooooooooo00[ooooo2ol9jPX2o`0005oooooo00?o0000ooooooooool03?oo
ool000_ooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0M_ooool0
0ol0003o2NX:o`WZ2P0:o`WZ2P_ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<
ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool2o`0007Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Fooooo`So2NX:
00?o0000ooooooooool03?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo04Gooooo4Ol9jPX8ooooo`03o`000?oooooooooo00cooooo000O
ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0d
oooooa7o2NX:6Oooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08ooooolAo`WZ2R[ooooo00?o0000oooo
ooooool03?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo017ooooo4_l9jPXkooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003o2NX:o`WZ2P0Ao`WZ2Tgooooo
00?o0000ooooooooool03?ooool001oooooo0_l0001gooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`0X
ooooo`Go00000oooool2o`0002Sooooo0ol00003ooooo`;o00005?ooool00ol0003oooooooooo`0@
ooooo`?o00000_ooool01?l0003oooooo`000?l0000Xooooo`?o00001?ooool2o`0002Cooooo0ol0
0004ooooo`;o00001?ooool2o`0000Sooooo000Oooooo`03o`000?oooooooooo02Wooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000Xooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00Ko0000oooooooo
ooooooooo`000?ooool2o`0000;ooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`02ooooo`04o`00
0?oooooo0000o`0000;ooooo00Co0000oooooooooooo00001oooool001oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Gooooo1Ol00002oooo
o`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool03oooool01_l0003ooooooooooooo
oooo0000ooooo`;o00000_ooool00ol0003oooooooooo`0Tooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool0000Tooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
ool0003o00000_ooool01?l0003oooooooooool00007ooooo`007oooool00ol0003oooooooooo`0[
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Sooooo`04o`000?oo
ooooooooo`0000?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`0?ooooo`Co
00000_ooool2o`0000;ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo00Co0000oooooooo
oooo00009?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000
oooooooooooo00001oooool001oooooo00?o0000ooooooooool0:?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00009_ooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0001?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`;o
00000_ooool00ol0003oooooooooo`0Tooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Tooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003o00000_oo
ool01?l0003oooooooooool00007ooooo`007oooool2o`0002Wooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0002Oooooo0_l00003ooooo`04o`000?ooooooooooo`00
01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0
003oooooooooo`0Tooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
000Sooooo`;o00001?ooool01?l0003oooooo`000?l00002ooooo`04o`000?ooooooooooo`0000Oo
oooo000Oooooo`03o`000?oooooooooo02Wooooo0ol00004ooooo`;o0000:Oooool00ol0003ooooo
ooooo`02ooooo`;o00005?ooool00ol0003oooooooooo`0Aooooo`;o00000_ooool01?l0003ooooo
o`000?l0000Xooooo`?o00001?ooool2o`0002Gooooo00?o0000ooooooooool00oooool2o`0000Co
oooo0_l00008ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003ooooooooo
o`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<oooo
o`006Oooooooo`0000Sooooo000Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<ooooo`007oooool0
0ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003o
ooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool2o`0007Oooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000O
ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`03
o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo00cooooo000Oooooo`;o0000Moooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool03?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oo
oooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool03?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o
0000ooooooooool03?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oooooo0_l0001goooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<oooo
o`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007ooo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0<ooooo`002_ooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool0
0ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0<ooooo`002oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`003?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`0<ooooo`003Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`?o0000M_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool000[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`002_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo00cooooo000;ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooo
oooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo00cooooo000Oooooo`;o0000Moooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool03?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oooooo
00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo
00?o0000ooooooooool03?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oooooo00?o0000
ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000
ooooooooool03?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oooooo00?o0000oooooooo
ool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool03?ooool001oooooo0_l0001gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool0
0ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003o
ooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool2o`0007Oooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000O
ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`03
o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo00cooooo000<ooooo`?o00000oooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo00cooooo000=ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool000[ooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool3o`00
07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
00cooooo000:ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000;ooooo`03o`000?oooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo00cooooo000<ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0
0_ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo00cooooo000Oooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`;o0000Moooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oo
oooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool03?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o
0000ooooooooool03?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oooooo00?o0000oooo
ooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool03?ooool001oooooo0_l0001gooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007ooo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0
003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool2o`0007Oooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo
000Oooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo07Kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Ooooo
o`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo00cooooo000;ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo00cooooo000:ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool0
00[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`002_ooool4o`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`?o0000M_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool000[ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool03?ooool000_ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool0
00cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0M_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oo
oooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool03?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oooooo0_l0
001gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<oooo
o`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007ooo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0<ooooo`007oooool2o`0007Oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo
07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
00cooooo000Oooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo
000Oooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo07Kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Ooooo
o`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo00cooooo000Oooooo`;o0000Moooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
3?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo05kooooo00?o0000ooooooooool03?ooool000_ooooo0ol00004ooooo`;o00001?ooool2
o`0000Gooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool03?ooool000[ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`0<ooooo`002_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000;ooooo`?o
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo0ol0001f
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<
ooooo`002_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000:ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool03?ooool000_ooooo0ol00004ooooo`;o00001?ooool2o`0000Go
oooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool03?ooool001oooooo00?o0000ooooooooool0M_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o
0000ooooooooool03?ooool001oooooo0_l0001gooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<oooo
o`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007ooo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`1fooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`007oooool00ol0
003oooooooooo`1fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`0<ooooo`007oooool2o`0007Oooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo
000Oooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo07Kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Ooooo
o`03o`000?oooooooooo07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo07Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Oooooo`;o0000
KOooool:o`WZ2P03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`0<ooooo`007oooool00ol0003oooooooooo`1Mooooo`oo2NX:2_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?ooool001oooooo00?o0000
ooooooooool0BooooolBo`WZ2QWooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo00cooooo000Oooooo`03o`000?oooooooooo03[ooooo4Ol9jPX[oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<oooo
o`001Oooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0:OoooolAo`WZ2Scooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo00cooooo0006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01_oooolSo`WZ2Tgooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo00cooooo0006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
2Ol9jPY`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`0<ooooo`001_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
07Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
00cooooo0006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0M_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03?oo
ool000Gooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo0006ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
3?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool007Oooooo
0ol0002Vooooo`00N?ooool00ol0003oooooooooo`2Uooooo`00Aoooool3o`0000;ooooo00?o0000
ooooool000000_l00003ooooo`Co000000?oooooo`000?l000000ol00009ooooo`;o00000oooool3
o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o00000_ooool5o`0000;ooooo0ol0
0002ooooo`;o000000?oooooo`000?l000001oooool4o`0000?ooooo0ol00003ooooo`Co000000Ko
ooooo`000?oooooo0000ooooool00007ooooo`?o00001?ooool4o`000004ooooool0003o0000o`00
00Cooooo1?l000001_oooooo0000ooooool0003oooooo`0000;ooooo0ol00004ooooo`;o00000ooo
ool3o`0000;ooooo0ol0000jooooo`00B?ooool01_l0003oooooooooool0003oooooo`0000Gooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`08ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`000008oooo
o`Go000000?oooooo`000?ooool01?ooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
0000ooooool0003ooooo1Ol00002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000Kooooo00Ko0000oooooooooooo0000ooooool00006ooooo`03
o`000?oooooooooo02Sooooo0ol0000>ooooo`00B?ooool00ol0003oooooo`000002ooooo`Go0000
0_ooool3o`0000Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`0;o`00
0?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooooooo`Go00000oooool00ol0003oooooooooo`08ooooo`05
o`000?ooooooooooo`000?ooool01Ol00002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo
000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`?o00000ooo
ool00ol0003oooooooooo`03ooooo`?o00000_ooool01_l0003oooooo`000?oooooo0000ooooo`Go
00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool00ol0003oooooooooo`0Xooooo`04
o`000?ooooooooooo`0000gooooo0018ooooo`?o00000_ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00oooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Ko
0000oooooooooooo0000ooooool00009ooooo`?o00000_ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00000_ooool00ol0003o
ooooooooo`03ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`;o00000oooool01?l0
003oooooooooool00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`;o0000;?ooool00ol0
003oooooooooo`0;ooooo`00B?ooool01?l0003oooooooooool00002ooooo`?o00000oooool2o`00
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`?o00000_ooool2o`00
0004ooooool0003oooooooooo`Co00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool2
o`000003ooooool0003o000000Sooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo0_l0
0003ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo
0_l000000ooooooo0000ooooo`02ooooo`?o00000_ooool4o`0000?ooooo0ol00002ooooo`;o0000
00?oooooo`000?l00000:?ooool2o`0000kooooo0018ooooo`04o`000?ooooooooooo`0000oooooo
00?o0000ooooooooool02?ooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo01Co
oooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`00023ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`00Aoooool4o`00
00kooooo0ol0000;ooooo`?o00004oooool3o`0001Gooooo1?l0000Eooooo`03o`000?oooooooooo
00;ooooo1?l0000Qooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo00003Oooool0
09Gooooo0ol0000Eooooo`?o0000H?ooool3o`0000gooooo003oooooob7ooooo003oooooob7ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.0785, -235.462, \
0.413393, 7.87875}},
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.00810848 0.0878953 [
[.21429 -0.00439 -6 -9 ]
[.21429 -0.00439 6 0 ]
[.40476 -0.00439 -6 -9 ]
[.40476 -0.00439 6 0 ]
[.59524 -0.00439 -6 -9 ]
[.59524 -0.00439 6 0 ]
[.78571 -0.00439 -6 -9 ]
[.78571 -0.00439 6 0 ]
[.97619 -0.00439 -9 -9 ]
[.97619 -0.00439 9 0 ]
[.01131 .096 -6 -4.5 ]
[.01131 .096 0 4.5 ]
[.01131 .1839 -6 -4.5 ]
[.01131 .1839 0 4.5 ]
[.01131 .27179 -6 -4.5 ]
[.01131 .27179 0 4.5 ]
[.01131 .35969 -6 -4.5 ]
[.01131 .35969 0 4.5 ]
[.01131 .44759 -6 -4.5 ]
[.01131 .44759 0 4.5 ]
[.01131 .53548 -6 -4.5 ]
[.01131 .53548 0 4.5 ]
[.5 .63053 -98.0625 0 ]
[.5 .63053 98.0625 12 ]
[.5 .66433 -5 -6 ]
[.5 .66433 5 6 ]
[.59524 .66433 -5 -6 ]
[.59524 .66433 5 6 ]
[.97619 .66433 -5 -6 ]
[.97619 .66433 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .00811 m
.21429 .01436 L
s
[(20)] .21429 -0.00439 0 1 Mshowa
.40476 .00811 m
.40476 .01436 L
s
[(40)] .40476 -0.00439 0 1 Mshowa
.59524 .00811 m
.59524 .01436 L
s
[(60)] .59524 -0.00439 0 1 Mshowa
.78571 .00811 m
.78571 .01436 L
s
[(80)] .78571 -0.00439 0 1 Mshowa
.97619 .00811 m
.97619 .01436 L
s
[(100)] .97619 -0.00439 0 1 Mshowa
.125 Mabswid
.07143 .00811 m
.07143 .01186 L
s
.11905 .00811 m
.11905 .01186 L
s
.16667 .00811 m
.16667 .01186 L
s
.2619 .00811 m
.2619 .01186 L
s
.30952 .00811 m
.30952 .01186 L
s
.35714 .00811 m
.35714 .01186 L
s
.45238 .00811 m
.45238 .01186 L
s
.5 .00811 m
.5 .01186 L
s
.54762 .00811 m
.54762 .01186 L
s
.64286 .00811 m
.64286 .01186 L
s
.69048 .00811 m
.69048 .01186 L
s
.7381 .00811 m
.7381 .01186 L
s
.83333 .00811 m
.83333 .01186 L
s
.88095 .00811 m
.88095 .01186 L
s
.92857 .00811 m
.92857 .01186 L
s
.25 Mabswid
0 .00811 m
1 .00811 L
s
.02381 .096 m
.03006 .096 L
s
[(1)] .01131 .096 1 0 Mshowa
.02381 .1839 m
.03006 .1839 L
s
[(2)] .01131 .1839 1 0 Mshowa
.02381 .27179 m
.03006 .27179 L
s
[(3)] .01131 .27179 1 0 Mshowa
.02381 .35969 m
.03006 .35969 L
s
[(4)] .01131 .35969 1 0 Mshowa
.02381 .44759 m
.03006 .44759 L
s
[(5)] .01131 .44759 1 0 Mshowa
.02381 .53548 m
.03006 .53548 L
s
[(6)] .01131 .53548 1 0 Mshowa
.125 Mabswid
.02381 .02569 m
.02756 .02569 L
s
.02381 .04327 m
.02756 .04327 L
s
.02381 .06085 m
.02756 .06085 L
s
.02381 .07842 m
.02756 .07842 L
s
.02381 .11358 m
.02756 .11358 L
s
.02381 .13116 m
.02756 .13116 L
s
.02381 .14874 m
.02756 .14874 L
s
.02381 .16632 m
.02756 .16632 L
s
.02381 .20148 m
.02756 .20148 L
s
.02381 .21906 m
.02756 .21906 L
s
.02381 .23664 m
.02756 .23664 L
s
.02381 .25422 m
.02756 .25422 L
s
.02381 .28937 m
.02756 .28937 L
s
.02381 .30695 m
.02756 .30695 L
s
.02381 .32453 m
.02756 .32453 L
s
.02381 .34211 m
.02756 .34211 L
s
.02381 .37727 m
.02756 .37727 L
s
.02381 .39485 m
.02756 .39485 L
s
.02381 .41243 m
.02756 .41243 L
s
.02381 .43001 m
.02756 .43001 L
s
.02381 .46516 m
.02756 .46516 L
s
.02381 .48274 m
.02756 .48274 L
s
.02381 .50032 m
.02756 .50032 L
s
.02381 .5179 m
.02756 .5179 L
s
.02381 .55306 m
.02756 .55306 L
s
.02381 .57064 m
.02756 .57064 L
s
.02381 .58822 m
.02756 .58822 L
s
.02381 .6058 m
.02756 .6058 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -159.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Imaginary) show
123.000 13.000 moveto
(Complex) show
171.000 13.000 moveto
(Beam) show
201.125 13.000 moveto
(Parameter) show
255.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .60332 m
.09004 .60332 L
.16227 .60332 L
.23011 .60332 L
.29535 .60332 L
.36479 .60332 L
.43164 .60332 L
.44915 .60332 L
.46816 .60332 L
.47688 .60332 L
.48611 .60332 L
.494 .60332 L
.49616 .60332 L
.49735 .60332 L
.49849 .60332 L
.50068 .01814 L
.50269 .01814 L
.53703 .01814 L
.56816 .01814 L
.5765 .01814 L
.58553 .01814 L
.58967 .01814 L
.59193 .01814 L
.59405 .01814 L
.59585 .01472 L
.59778 .01472 L
.60189 .01472 L
.63784 .01472 L
.70874 .01472 L
.77705 .01472 L
.84276 .01472 L
.91267 .01472 L
.97619 .01472 L
s
0 0 0 r
gsave
.5 .66433 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .66433 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .66433 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .00811 m
0 0 rlineto s
.5 .00811 m
.5 .61803 L
s
.59524 .00811 m
0 0 rlineto s
.59524 .00811 m
.59524 .61803 L
s
.97619 .00811 m
0 0 rlineto s
.97619 .00811 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00A?ooool5o`0000?ooooo0_l0000Vooooo`?o00000oooool2o`0002Gooooo0ol00004oooo
o`;o00009Oooool3o`0000Cooooo0_l0000Rooooo`?o00001?ooool2o`0000Cooooo0_l0000Goooo
o`00AOooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Kooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo027ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0002?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0001Kooooo0016ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00008oooool5o`0000;ooooo00Co0000oooooooooooo00008oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00008_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005_ooool004Oooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool0000Sooooo`Co00000oooool01?l0003oooooooooool0000Tooooo`?o0000
0oooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000Fooooo`00A?ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00009?ooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0002?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Sooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Rooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Fooooo`00A?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00009Oooool2o`0000?o
oooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0002?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00027ooooo
0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005_ooool004Go
oooo0ol00004ooooo`;o00009oooool00ol0003oooooooooo`02ooooo`;o00009_ooool2o`0000Co
oooo0_l0000Uooooo`?o00001?ooool2o`0002?ooooo00?o0000ooooooooool00oooool2o`0000Co
oooo0_l0000Gooooo`00oooooolQooooo`00oooooolQooooo`007?ooool00ol0003oooooooooo`3o
ooooo`;ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo01[ooooo000Foooooo?o00005oooool001cooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool05?ooool00ol0003o2NX:o`WZ2P1Io`WZ2P03o`000?oooooooooo01_ooooo
000Looooo`03o`000?oooooooooo073ooooo00?o0000o`WZ2_l9jPX05?l9jPX00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Loooo
o`;o0000LOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
6oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo0_l0001aooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0Kooooo`007?ooool2o`00077ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Loooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo01_ooooo000Looooo`;o0000LOooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool06oooool001Cooooo0ol00005ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo01_ooooo000Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`005Oooool00ol0003ooooo
ooooo`04ooooo`;o0000LOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool06oooool001Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Kooooo`005?ooool2o`0000Kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool2o`00077ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo01_ooooo000Looooo`;o0000LOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool06oooool001cooooo0_l0001aooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`00
7?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool2
o`00077ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Cooooo`Go00001?ooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Kooooo`005?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_o
oooo000Eooooo`03o`000?oooooooooo00Cooooo0_l0001aooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`005_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo01_ooooo000Cooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`0Kooooo`004oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool06oooool001Cooooo0ol00005ooooo`;o0000LOooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
6oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo0_l0001aooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0Kooooo`007?ooool2o`00077ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Loooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`;o0000
LOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
6oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool06oooool001Cooooo0ol00005ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo01_ooooo000Cooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0K
ooooo`005oooool00ol0003oooooooooo`02ooooo`;o0000LOooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001Gooooo0_l00005ooooo`03
o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo01_ooooo000Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
6oooool001?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo
000Dooooo`?o00001Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool2o`00077ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Loooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo01_ooooo000Looooo`;o0000LOooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool0
01cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo
0_l0001aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0K
ooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool2o`00077ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo01_ooooo000Eooooo`?o00001?ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`005_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Cooooo`Go00001?ooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0Kooooo`004oooool01?l0003oooooooooool00005ooooo`;o0000LOooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001Co
oooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`005Oooool2o`0000Gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool06oooool001Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Kooooo`007?ooool2o`00077ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03
o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`;o0000LOoo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06ooo
ool001cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001co
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool06oooool001cooooo0_l0001aooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Koooo
o`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool2o`00077ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo01_ooooo000Dooooo`?o00001Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`004oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001Oooooo00?o0000oooo
ooooool00_ooool2o`00077ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo01_ooooo000Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool06oooool001?ooooo1?l00005ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool06oooool001?ooooo1Ol00004ooooo`;o0000LOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool0
01cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo0_l0001a
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0K
ooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`00
7?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Kooooo`007?ooool2o`00077ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_o
oooo000Looooo`;o0000LOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001Cooooo0ol00005
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo01_ooooo000Cooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Kooooo`004oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0001a
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0K
ooooo`004oooool4o`0000Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`0Kooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo01_ooooo000Eooooo`;o00001Oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool2
o`00077ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo01_ooooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_o
oooo000Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo01_ooooo000Looooo`;o0000LOooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool06oooool001cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool06oooool001cooooo0_l0001aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?oooomco`WZ2P03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`00
7?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Kooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00@_ooool3o`0001[ooooo0ol0000Kooooo`?o0000X?ooool004Gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09oooooo000_ooooo`Go
000000Koooooo`000?oooooo0000ooooool00002ooooo`Co00000_ooool4o`000003ooooool0003o
000000?o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o000000Co
ooooo`000?l0003o00001Oooool00ol0003oooooooooo`09ooooo`;o00000oooool3o`0000;ooooo
00Go0000ooooool0003oooooo`000002ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`;o
000000?oooooo`000?l000001oooool4o`0000?ooooo0ol00003ooooo`Co000000Koooooo`000?oo
oooo0000ooooool00007ooooo`?o00001?ooool4o`000004ooooool0003o0000o`0000Cooooo1?l0
00001_oooooo0000ooooool0003oooooo`0000;ooooo0ol00004ooooo`;o00000oooool3o`0000;o
oooo0ol0000dooooo`00<Oooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Co
oooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`08ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooo`000009ooooo`06o`000?ooooooooooo`000?oo
oooo00001Oooool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000ooooool000002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000006
ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`0cooooo`00<Ooo
ool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`000002ooooo`?o00000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Sooooo00?o
0000ooooooooool00oooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooooooool9o`0000[ooooo
00Go0000oooooooooooo0000ooooo`0:o`0000;ooooo00Go0000ooooool0003oooooo`000008oooo
o`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo0ol00002oooo
o`06o`000?oooooo0000ooooool0003ooooo1Ol00002ooooo`03o`000?oooooooooo00;ooooo1Ol0
0002ooooo`03o`000?oooooooooo01?ooooo0ol0000Mooooo`00<Oooool02ol0003ooooooooooooo
oooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000Cooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04
o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo
00?ooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?oooooo
ooooo`000?oooooo00002Oooool3o`0000;ooooo00?o0000ooooooooool00_l000001Ooooooo0000
oooooooooooo000000;ooooo00Go0000ooooool0003oooooo`000008ooooo`?o00000_ooool01?l0
003oooooooooool00003ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`07o`000?oo
oooo0000ooooool0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooo
ooooooooooooo`000002ooooo`;o00005?ooool01?l0003oooooooooool0000Looooo`00<Oooool0
1?l0003oooooooooooooool2o`000003ooooool0003ooooo00;ooooo0_l00004ooooo`So00000ooo
ool4o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000007ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`;o000000Coooooo`000?oooooo
oooo1?l00004ooooo`03o`000?oooooooooo00;ooooo1?l000001?oooooo0000o`000?ooool2o`00
00Sooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo0_l00003ooooo`;o000000?ooooo
o`000?ooool02?ooool01?l0003oooooooooool00002ooooo`;o00000oooool2o`000003ooooool0
003o000000;ooooo0_l00003ooooo`;o000000?oooooo`000?ooool00_ooool3o`0000;ooooo1?l0
0003ooooo`?o00000_ooool2o`000003ooooool0003o000001Gooooo00?o0000ooooooooool06_oo
ool0037ooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0000Eooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo01?ooooo00Co0000oooooooooooo00008?ooool00ol0003oooooooooo`0Pooooo`;o
00007Oooool002oooooo1Ol0000Eooooo`03o`000?oooooooooo027ooooo0ol0000Cooooo`?o0000
1oooool00ol0003oooooooooo`0;ooooo`Co00001Oooool00ol0003oooooooooo`0Booooo`Co0000
8Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01gooooo002=ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0FOooool01?l0003oooooooooool0000Looooo`00S?oo
ool3o`0001Cooooo0ol0001Kooooo`?o00007?ooool00?oooooo8Oooool00?oooooo8Oooool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.2276, -0.565077, \
0.433601, 0.0469824}},
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -1.04119 0.000267313 [
[.21429 .01556 -6 -9 ]
[.21429 .01556 6 0 ]
[.40476 .01556 -6 -9 ]
[.40476 .01556 6 0 ]
[.59524 .01556 -6 -9 ]
[.59524 .01556 6 0 ]
[.78571 .01556 -6 -9 ]
[.78571 .01556 6 0 ]
[.97619 .01556 -9 -9 ]
[.97619 .01556 9 0 ]
[.01131 .16172 -24 -4.5 ]
[.01131 .16172 0 4.5 ]
[.01131 .29538 -24 -4.5 ]
[.01131 .29538 0 4.5 ]
[.01131 .42903 -24 -4.5 ]
[.01131 .42903 0 4.5 ]
[.01131 .56269 -24 -4.5 ]
[.01131 .56269 0 4.5 ]
[.5 .63053 -83.0625 0 ]
[.5 .63053 83.0625 12 ]
[.5 .7719 -5 -6 ]
[.5 .7719 5 6 ]
[.59524 .7719 -5 -6 ]
[.59524 .7719 5 6 ]
[.97619 .7719 -5 -6 ]
[.97619 .7719 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .02806 m
.21429 .03431 L
s
[(20)] .21429 .01556 0 1 Mshowa
.40476 .02806 m
.40476 .03431 L
s
[(40)] .40476 .01556 0 1 Mshowa
.59524 .02806 m
.59524 .03431 L
s
[(60)] .59524 .01556 0 1 Mshowa
.78571 .02806 m
.78571 .03431 L
s
[(80)] .78571 .01556 0 1 Mshowa
.97619 .02806 m
.97619 .03431 L
s
[(100)] .97619 .01556 0 1 Mshowa
.125 Mabswid
.07143 .02806 m
.07143 .03181 L
s
.11905 .02806 m
.11905 .03181 L
s
.16667 .02806 m
.16667 .03181 L
s
.2619 .02806 m
.2619 .03181 L
s
.30952 .02806 m
.30952 .03181 L
s
.35714 .02806 m
.35714 .03181 L
s
.45238 .02806 m
.45238 .03181 L
s
.5 .02806 m
.5 .03181 L
s
.54762 .02806 m
.54762 .03181 L
s
.64286 .02806 m
.64286 .03181 L
s
.69048 .02806 m
.69048 .03181 L
s
.7381 .02806 m
.7381 .03181 L
s
.83333 .02806 m
.83333 .03181 L
s
.88095 .02806 m
.88095 .03181 L
s
.92857 .02806 m
.92857 .03181 L
s
.25 Mabswid
0 .02806 m
1 .02806 L
s
.02381 .16172 m
.03006 .16172 L
s
[(4500)] .01131 .16172 1 0 Mshowa
.02381 .29538 m
.03006 .29538 L
s
[(5000)] .01131 .29538 1 0 Mshowa
.02381 .42903 m
.03006 .42903 L
s
[(5500)] .01131 .42903 1 0 Mshowa
.02381 .56269 m
.03006 .56269 L
s
[(6000)] .01131 .56269 1 0 Mshowa
.125 Mabswid
.02381 .05479 m
.02756 .05479 L
s
.02381 .08153 m
.02756 .08153 L
s
.02381 .10826 m
.02756 .10826 L
s
.02381 .13499 m
.02756 .13499 L
s
.02381 .18845 m
.02756 .18845 L
s
.02381 .21518 m
.02756 .21518 L
s
.02381 .24191 m
.02756 .24191 L
s
.02381 .26864 m
.02756 .26864 L
s
.02381 .32211 m
.02756 .32211 L
s
.02381 .34884 m
.02756 .34884 L
s
.02381 .37557 m
.02756 .37557 L
s
.02381 .4023 m
.02756 .4023 L
s
.02381 .45576 m
.02756 .45576 L
s
.02381 .48249 m
.02756 .48249 L
s
.02381 .50923 m
.02756 .50923 L
s
.02381 .53596 m
.02756 .53596 L
s
.02381 .00133 m
.02756 .00133 L
s
.02381 .58942 m
.02756 .58942 L
s
.02381 .61615 m
.02756 .61615 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -144.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Real) show
93.000 13.000 moveto
(Complex) show
141.000 13.000 moveto
(Beam) show
171.125 13.000 moveto
(Parameter) show
225.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .02804 m
.09004 .02618 L
.16227 .02415 L
.23011 .02225 L
.29535 .02042 L
.36479 .01847 L
.43164 .01659 L
.44915 .0161 L
.46816 .01557 L
.47688 .01532 L
.48611 .01506 L
.494 .01484 L
.49616 .01478 L
.49735 .01475 L
.49849 .01472 L
.50068 .60332 L
.50269 .60326 L
.53703 .6023 L
.56816 .60142 L
.5765 .60119 L
.58553 .60094 L
.58967 .60082 L
.59193 .60076 L
.59405 .6007 L
.59585 .04315 L
.59778 .04309 L
.60189 .04298 L
.63784 .04197 L
.70874 .03998 L
.77705 .03806 L
.84276 .03622 L
.91267 .03425 L
.97619 .03247 L
s
0 0 0 r
gsave
.5 .7719 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .7719 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .7719 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00EOooool5o`0000?ooooo0_l0000Pooooo`?o00000oooool2o`00023ooooo0ol00004oooo
o`;o00008?ooool3o`0000Cooooo0_l0000Mooooo`?o00001?ooool2o`0000Cooooo0_l0000Koooo
o`00E_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01cooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0001kooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0001[ooooo001Gooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00007Oooool5o`0000;ooooo00Co0000oooooooooooo00007_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00007_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00007Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006_ooool005Sooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool0000Nooooo`Co00000oooool01?l0003oooooooooool0000Oooooo`?o0000
0oooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000Jooooo`00<_ooool00ol0003oooooooooo`0Poooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Nooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooooooo01cooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool00_ooool01?l0
003oooooo`000?l00002ooooo`04o`000?ooooooooooo`0001[ooooo000booooo`;o00008Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00007oooool2o`0000?ooooo
00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo0_l00002ooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0001cooooo0_l00004ooooo`04o`000?oooooo0000o`0000;ooooo00Co
0000oooooooooooo00006_ooool003;ooooo00?o0000ooooooooool08Oooool3o`0000Cooooo0_l0
000Qooooo`03o`000?oooooooooo00;ooooo0_l0000Aooooo`03o`000?oooooooooo00gooooo0_l0
0002ooooo`04o`000?oooooo0000o`00023ooooo0ol00004ooooo`;o00007_ooool00ol0003ooooo
ooooo`03ooooo`;o00001?ooool2o`0001_ooooo000booooo`03o`000?oooooooooo05oooooo1?l9
jPX00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07ooo
ool003;ooooo00?o0000ooooooooool0?ooooolPo`WZ2PCooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`000?oooooooooo
01?ooooo;?l9jPXTooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`0Oooooo`00;Oooool5o`0001Ko2NX:_?l0000Looooo`00<_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oo2NX:00?o0000ooooooooool07oooool003;ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Mooooob_o2NX:1oooool00ol0003ooooooooo
o`0Oooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000
o`WZ2_l9jPX07Ol9jPXbooooo`03o`000?oooooooooo01oooooo000booooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`;o0000I?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool07oooool003;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool07oooool003;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0
7oooool003;ooooo0_l0001Tooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`0Oooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`0Oooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`0Oooooo`00<_ooool2o`0006Cooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000boooo
o`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`;o0000I?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool0
03;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool07oooool003;ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool001Wooooo
0ol00002ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo
000Jooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool001Oo
oooo1Ol00005ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000Gooooo`04o`000?oooooooooo
o`0000Kooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0001Tooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0Oooooo`006?ooool00ol0003oooooo`000002ooooo`Co00000ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool07oooool001Wooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000Jooooo`03
o`000?oooooooooo00Go00000oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oo
oooo000booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000b
ooooo`;o0000I?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool07oooool003;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool07oooool003;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07ooo
ool003;ooooo0_l0001Tooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`0Oooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`0Oooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0Oooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool2o`0006Cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
01oooooo000booooo`;o0000I?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool07oooool003;ooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool07oooool001Sooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo01oooooo000Gooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Coooool00ol0003oooooooooo`0Oooooo`006oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02
ooooo`;o0000I?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool07oooool001_ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`0Oooooo`005oooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool001Oo
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`005oooool5
o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool0
03;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool07oooool003;ooooo0_l0001Tooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`0Oooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool00ol0003oooooooooo`1S
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0O
ooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00
<_ooool2o`0006Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oo
oooo000booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`;o0000I?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool07oooool003;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool07oooool003;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo0_l0001Tooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`0Oooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`0Oooooo`006?ooool3o`0000?ooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool07oooool001Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo04oooooo00?o0000ooooooooool07oooool001_ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool2o`0006Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo01oooooo000Kooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0
7oooool001Oooooo1?l00002ooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool001Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`0Oooooo`005oooool5o`000003ooooool0003o000000?o
00000oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo01oooooo000booooo`;o0000I?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool0
03;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool07oooool003;ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool07oooool003;ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo0_l0001T
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0O
ooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00
<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0Oooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool2
o`0006Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oo
oooo000booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000b
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo01oooooo000booooo`;o0000I?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool07oooool003;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool07oooool001Sooooo0ol00004ooooo`;o00001?oo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000Gooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`005oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool001Oooooo1?l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`;o0000I?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool07oooool001Oooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`0Oooooo`006?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo01oooooo000Iooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o0000
1Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0Oooooo`00<_ooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Oooooo`00<_ooool2
o`0006Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oo
oooo000booooo`03o`000?oooooooooo06?ooooo00?o0000o`WZ2_l9jPX04Ol9jPX00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo01oooooo000booooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01oooooo000b
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo01oooooo000booooo`;o0000I?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool003;ooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool07oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool007Oooooo0ol0002Voooo
o`00N?ooool00ol0003oooooooooo`2Uooooo`00Aoooool3o`0000;ooooo00?o0000ooooool00000
0_l00003ooooo`Co000000?oooooo`000?l000000ol00009ooooo`;o00000oooool3o`0000;ooooo
00Go0000ooooool0003oooooo`000002ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`;o
000000?oooooo`000?l000001oooool4o`0000?ooooo0ol00003ooooo`Co000000Koooooo`000?oo
oooo0000ooooool00007ooooo`?o00001?ooool4o`000004ooooool0003o0000o`0000Cooooo1?l0
00001_oooooo0000ooooool0003oooooo`0000;ooooo0ol00004ooooo`;o00000oooool3o`0000;o
oooo0ol0000jooooo`00B?ooool01_l0003oooooooooool0003oooooo`0000Gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`08ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`000009ooooo`06o`000?oo
ooooooooo`000?oooooo00001Oooool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000
ooooool000002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`07o`000?oooooo0000ooooool0
003oooooo`000006ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003ooooooooo
o`0iooooo`00B?ooool00ol0003oooooo`000002ooooo`Go00000_ooool3o`0000Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`0;o`000?ooooooooooooooool0003ooooo
o`000?oooooo0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooo
ooooooooo`Go00000oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooo`000?ooool0
1Ol00002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000Sooooo00?o0000oooooooo
ool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool3o`0000;ooooo00Ko0000ooooool0
003oooooo`000?ooool5o`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00?o0000
ooooooooool0>Oooool004Sooooo0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01_l0003ooooo
ooooool0003oooooo`0000Wooooo0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00008ooooo`?o00000_ooool01?l0
003oooooooooool00003ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`07o`000?oo
oooo0000ooooool0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooo
ooooooooooooo`000002ooooo`;o0000>_ooool004Sooooo00Co0000oooooooooooo00000_ooool3
o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool3
o`0000;ooooo0_l000001?oooooo0000ooooooooool4o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`04o`000?ooooooooooo`0000;ooooo
0ol00003ooooo`;o00000oooool2o`000003ooooool0003ooooo00Sooooo00Co0000oooooooooooo
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`000003
ooooool0003ooooo00;ooooo0ol00002ooooo`Co00000oooool3o`0000;ooooo0_l000000ooooooo
0000o`00000hooooo`00B?ooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo00So
oooo00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`0Dooooo`04o`000?oooooooooo
o`0001[ooooo00Co0000oooooooooooo00008?ooool00ol0003oooooooooo`15ooooo`00Aoooool4
o`0000kooooo0ol0000;ooooo`?o00004oooool3o`0001Gooooo1?l0000Jooooo`Co00008Oooool0
0ol0003oooooooooo`15ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00UOooool5o`0000oooooo
1Ol0001>ooooo`?o00008Oooool009Kooooo00Co0000oooooooooooo00004?ooool01?l0003ooooo
ooooool0001>ooooo`04o`000?ooooooooooo`00023ooooo002Fooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Nooooo`00U_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo053ooooo0_l0000Qooooo`00U_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool08Oooool009Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`04o`000?ooooooooooo`00023ooooo002E
ooooo`?o00004Oooool3o`00057ooooo0ol0000Pooooo`00oooooolQooooo`00oooooolQooooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.7088, 3795.96, 0.490414, \
17.4725}},
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -1.11926 0.0418638 [
[.21429 .04043 -6 -9 ]
[.21429 .04043 6 0 ]
[.40476 .04043 -6 -9 ]
[.40476 .04043 6 0 ]
[.59524 .04043 -6 -9 ]
[.59524 .04043 6 0 ]
[.78571 .04043 -6 -9 ]
[.78571 .04043 6 0 ]
[.97619 .04043 -9 -9 ]
[.97619 .04043 9 0 ]
[.01131 .13665 -12 -4.5 ]
[.01131 .13665 0 4.5 ]
[.01131 .22038 -12 -4.5 ]
[.01131 .22038 0 4.5 ]
[.01131 .30411 -12 -4.5 ]
[.01131 .30411 0 4.5 ]
[.01131 .38784 -12 -4.5 ]
[.01131 .38784 0 4.5 ]
[.01131 .47156 -12 -4.5 ]
[.01131 .47156 0 4.5 ]
[.01131 .55529 -12 -4.5 ]
[.01131 .55529 0 4.5 ]
[.5 .63053 -98.0625 0 ]
[.5 .63053 98.0625 12 ]
[.5 .77988 -5 -6 ]
[.5 .77988 5 6 ]
[.59524 .77988 -5 -6 ]
[.59524 .77988 5 6 ]
[.97619 .77988 -5 -6 ]
[.97619 .77988 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .05293 m
.21429 .05918 L
s
[(20)] .21429 .04043 0 1 Mshowa
.40476 .05293 m
.40476 .05918 L
s
[(40)] .40476 .04043 0 1 Mshowa
.59524 .05293 m
.59524 .05918 L
s
[(60)] .59524 .04043 0 1 Mshowa
.78571 .05293 m
.78571 .05918 L
s
[(80)] .78571 .04043 0 1 Mshowa
.97619 .05293 m
.97619 .05918 L
s
[(100)] .97619 .04043 0 1 Mshowa
.125 Mabswid
.07143 .05293 m
.07143 .05668 L
s
.11905 .05293 m
.11905 .05668 L
s
.16667 .05293 m
.16667 .05668 L
s
.2619 .05293 m
.2619 .05668 L
s
.30952 .05293 m
.30952 .05668 L
s
.35714 .05293 m
.35714 .05668 L
s
.45238 .05293 m
.45238 .05668 L
s
.5 .05293 m
.5 .05668 L
s
.54762 .05293 m
.54762 .05668 L
s
.64286 .05293 m
.64286 .05668 L
s
.69048 .05293 m
.69048 .05668 L
s
.7381 .05293 m
.7381 .05668 L
s
.83333 .05293 m
.83333 .05668 L
s
.88095 .05293 m
.88095 .05668 L
s
.92857 .05293 m
.92857 .05668 L
s
.25 Mabswid
0 .05293 m
1 .05293 L
s
.02381 .13665 m
.03006 .13665 L
s
[(30)] .01131 .13665 1 0 Mshowa
.02381 .22038 m
.03006 .22038 L
s
[(32)] .01131 .22038 1 0 Mshowa
.02381 .30411 m
.03006 .30411 L
s
[(34)] .01131 .30411 1 0 Mshowa
.02381 .38784 m
.03006 .38784 L
s
[(36)] .01131 .38784 1 0 Mshowa
.02381 .47156 m
.03006 .47156 L
s
[(38)] .01131 .47156 1 0 Mshowa
.02381 .55529 m
.03006 .55529 L
s
[(40)] .01131 .55529 1 0 Mshowa
.125 Mabswid
.02381 .07386 m
.02756 .07386 L
s
.02381 .09479 m
.02756 .09479 L
s
.02381 .11572 m
.02756 .11572 L
s
.02381 .15759 m
.02756 .15759 L
s
.02381 .17852 m
.02756 .17852 L
s
.02381 .19945 m
.02756 .19945 L
s
.02381 .24131 m
.02756 .24131 L
s
.02381 .26225 m
.02756 .26225 L
s
.02381 .28318 m
.02756 .28318 L
s
.02381 .32504 m
.02756 .32504 L
s
.02381 .34597 m
.02756 .34597 L
s
.02381 .3669 m
.02756 .3669 L
s
.02381 .40877 m
.02756 .40877 L
s
.02381 .4297 m
.02756 .4297 L
s
.02381 .45063 m
.02756 .45063 L
s
.02381 .4925 m
.02756 .4925 L
s
.02381 .51343 m
.02756 .51343 L
s
.02381 .53436 m
.02756 .53436 L
s
.02381 .03199 m
.02756 .03199 L
s
.02381 .01106 m
.02756 .01106 L
s
.02381 .57622 m
.02756 .57622 L
s
.02381 .59716 m
.02756 .59716 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -159.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Imaginary) show
123.000 13.000 moveto
(Complex) show
171.000 13.000 moveto
(Beam) show
201.125 13.000 moveto
(Parameter) show
255.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .01472 m
.09004 .01472 L
.16227 .01472 L
.23011 .01472 L
.29535 .01472 L
.36479 .01472 L
.43164 .01472 L
.44915 .01472 L
.46816 .01472 L
.47688 .01472 L
.48611 .01472 L
.494 .01472 L
.49616 .01472 L
.49735 .01472 L
.49849 .01472 L
.50068 .60332 L
.50269 .60332 L
.53703 .60332 L
.56816 .60332 L
.5765 .60332 L
.58553 .60332 L
.58967 .60332 L
.59193 .60332 L
.59405 .60332 L
.59585 .01472 L
.59778 .01472 L
.60189 .01472 L
.63784 .01472 L
.70874 .01472 L
.77705 .01472 L
.84276 .01472 L
.91267 .01472 L
.97619 .01472 L
s
0 0 0 r
gsave
.5 .77988 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .77988 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .77988 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o:_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`0Pooooo`Go00000oooool2o`00
02;ooooo0ol00003ooooo`;o00004Oooool00ol0003oooooooooo`0=ooooo`?o00000_ooool01?l0
003oooooo`000?l0000Pooooo`?o00001?ooool2o`0001kooooo0ol00004ooooo`;o00001?ooool2
o`0001oooooo000Zooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0000Rooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00cooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
00;ooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00007_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0000;ooooo
00Co0000oooooooooooo00007_ooool002[oooooJ?l9jPX00ol0003oooooooooo`0<ooooo`07o`00
0?ooooooooooooooool0003oooooo`00001Bo`WZ2P;o00000_ooool01?l0003oooooooooool0000N
ooooo`00:_ooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
4?ooool00ol0003oooooooooo`0<ooooo`Co00000_ooool2o`0000;ooooo00?o0000ooooooooool0
7Oooool3o`0000?ooooo00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`02ooooo`04
o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooo00007_ooool002[ooooo00?o0000oooo
ooooool08?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008?oo
ool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`0Looooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo
00;ooooo00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0000Nooooo`00:_ooool0
0ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool0000Qooooo`;o00000oooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool07?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00007Oooool2o`0000Cooooo00Co0000
ooooool0003o00000_ooool01?l0003oooooooooool0000Nooooo`00:_ooool00ol0003ooooooooo
o`0Qooooo`?o00001?ooool2o`0002?ooooo00?o0000ooooooooool00_ooool2o`00017ooooo00?o
0000ooooooooool03_ooool2o`0000;ooooo00Co0000ooooool0003o00008?ooool3o`0000Cooooo
0_l0000Oooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00007oooool002[ooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool08oooool002Cooooog?l0000Pooooo`00:_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08ooo
ool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool002[o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool002[ooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
8oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo053ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool0
02[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool001cooooo
0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`006oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`00
7oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool08oooool001gooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001Vooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`00
7oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool08oooool001_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool08oooool001cooooo0ol00004ooooo`;o00001Oooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Soooo
o`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`00:_oo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`0Sooooo`007?ooool3o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02?ooooo000K
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo02?ooooo000Oooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`0Sooooo`007Oooool2o`0000Gooooo00?o0000ooooooooool00oooool2o`0006Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02?ooooo000O
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0S
ooooo`006oooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo02?ooooo000Looooo`?o00000oooool3o`0000Gooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08ooo
ool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool002[o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool002[ooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool001cooooo0ol00004ooooo`?o0000
1?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0Sooooo`006oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`007oooool00ol0003oooooo`00
0004o`0000Cooooo0_l0001Vooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Sooooo`007Oooool2o`0000;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Sooooo`007oooool01_l0003oooooooooool0003oooooo`0000Gooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Aooooo`03o`WZ2_l0003ooooo057ooooo
00?o0000ooooooooool08oooool001_ooooo00Go0000ooooooooooooooooo`000003ooooo`;o0000
1Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0
DOooool00ol0003oooooooooo`0Sooooo`007?ooool3o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOoo
ool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0
003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017o
oooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003ooooo
ooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o
2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0S
ooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`00
0?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00
:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0
DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool0
0ol0003oooooooooo`0Sooooo`007?ooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool04Oooool00ol9jP[o0000ooooo`1Aooooo`03o`000?oooooooooo
02?ooooo000Kooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Aooooo`03o`WZ2_l0003o
oooo057ooooo00?o0000ooooooooool08oooool001oooooo00?o0000ooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool04Oooool00ol9
jP[o0000ooooo`1Aooooo`03o`000?oooooooooo02?ooooo000Mooooo`;o00000_ooool4o`0000Go
oooo0_l0001Vooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003o
ooooooooo`0Sooooo`007oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool04Oooool00ol9jP[o0000ooooo`1Aooooo`03o`000?oooooooooo02?ooooo
000Kooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool04Oooool00ol9jP[o0000ooooo`1Aooooo`03o`00
0?oooooooooo02?ooooo000Looooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`0Aooooo`03o`WZ2_l0003ooooo057ooooo00?o0000ooooooooool08ooo
ool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Aooooo`03o`WZ2_l0003o
oooo057ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`0Aooooo`03o`WZ2_l0003ooooo057ooooo00?o0000ooooooooool08oooool002[o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Aooooo`03o`WZ2_l0003ooooo057o
oooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`0Aooooo`03o`WZ2_l0003ooooo057ooooo00?o0000ooooooooool08oooool002[ooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`0Aooooo`03o`WZ2_l0003ooooo057ooooo00?o
0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0A
ooooo`03o`WZ2_l0003ooooo057ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0Aooooo`03o`WZ2_l0003ooooo057ooooo00?o0000oooo
ooooool08oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Aooooo`03
o`WZ2_l0003ooooo057ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`0Aooooo`03o`WZ2_l0003ooooo057ooooo00?o0000ooooooooool0
8oooool002[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Aooooo`03o`WZ2_l0
003ooooo057ooooo00?o0000ooooooooool08oooool002[ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`0Aooooo`03o`WZ2_l0003ooooo057ooooo00?o0000ooooooooool08oooool0
01cooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`006oooool01ol0003o
oooooooooooooooo0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool04Oooool00ol9jP[o0000ooooo`1Aooooo`03o`000?oooooo
oooo02?ooooo000Oooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0
003oooooooooo`0Sooooo`007Oooool2o`0000?ooooo0ol00005ooooo`;o0000I_ooool00ol0003o
ooooooooo`0Aooooo`03o`WZ2_l0003ooooo057ooooo00?o0000ooooooooool08oooool001oooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool04Oooool00ol9jP[o0000ooooo`1Aooooo`03o`000?oooooooooo02?ooooo
000Kooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Aooooo`03o`WZ2_l0003ooooo057o
oooo00?o0000ooooooooool08oooool001cooooo0ol00003ooooo`?o00001Oooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003ooooo
ooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o
2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0S
ooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`00
0?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00
:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0
DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool0
0ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003o
ooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo
00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003ooooooooo
o`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:
o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`007Oooool3o`0000?ooooo0_l00005oooo
o`03o`000?oooooooooo06Gooooo00?o0000ooooooooool04Oooool00ol9jP[o0000ooooo`1Aoooo
o`03o`000?oooooooooo02?ooooo000Nooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool04Oooool00ol9
jP[o0000ooooo`1Aooooo`03o`000?oooooooooo02?ooooo000Kooooo`Go00000_ooool01?l0003o
ooooooooool00004ooooo`;o0000I_ooool00ol0003oooooooooo`0Aooooo`03o`WZ2_l0003ooooo
057ooooo00?o0000ooooooooool08oooool001_ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool04Oooool0
0ol9jP[o0000ooooo`1Aooooo`03o`000?oooooooooo02?ooooo000Looooo`03o`000?oooooo0000
00?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`007Oooool2o`00
00?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0
003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003o
ooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo
00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003ooooooooo
o`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:
o`000?ooool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo017ooooo00?o2NX:o`000?ooool0DOooool00ol0003oooooooooo`0Soooo
o`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o2NX:o`000?oo
ool0DOooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`00
0?l9jP[o2NX:01;o2NX:00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`00:_oo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Sooooo`00:_ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0Sooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00AOooool3o`0001[ooooo0ol0000Kooooo`?o0000WOooool004Sooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09cooooo000booooo`Go0000
00Koooooo`000?oooooo0000ooooool00002ooooo`Co00000_ooool4o`000003ooooool0003o0000
00?o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003o00001Oooool00ol0003oooooooooo`09ooooo`;o00000oooool3o`0000;ooooo00Go
0000ooooool0003oooooo`000002ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`;o0000
00?oooooo`000?l000001oooool4o`0000?ooooo0ol00003ooooo`Co000000Koooooo`000?oooooo
0000ooooool00007ooooo`?o00001?ooool4o`000004ooooool0003o0000o`0000Cooooo1?l00000
1_oooooo0000ooooool0003oooooo`0000;ooooo0ol00004ooooo`;o00000oooool3o`0000;ooooo
0ol0000aooooo`00=?ooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Cooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`08ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooo`000009ooooo`06o`000?ooooooooooo`000?oooooo
00001Oooool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000ooooool000002?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000006oooo
o`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`0`ooooo`00=?ooool0
2Ol0003ooooooooooooooooo0000ooooool0003oooooo`000002ooooo`?o00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool00oooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooooooool5o`0000?ooooo00?o
0000ooooooooool02?ooool01Ol0003oooooooooool0003ooooo00Go00000_ooool3o`0000;ooooo
00Go0000ooooool0003oooooo`000008ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03
o`000?oooooooooo00?ooooo0ol00002ooooo`06o`000?oooooo0000ooooool0003ooooo1Ol00002
ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`03o`000?oooooooooo033ooooo000doooo
o`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000001?ooool01_l0003oooooooooool0
003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool00oooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Ko0000oooooooooooo0000ooooool00009ooooo`?o00000_ooool01ol0003ooooooooo
oooooooo0000ooooool000000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00002?oo
ool3o`0000;ooooo00Co0000oooooooooooo00000oooool2o`0000?ooooo00Co0000oooooooooooo
00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000oooool01?l0003oooooooooool0
0004ooooo`05o`000?ooooooooooooooool000000_ooool2o`00037ooooo000dooooo`04o`000?oo
ooooooooooooo`;o000000?oooooo`000?ooool00_ooool2o`0000Cooooo2?l00003ooooo`Co0000
0oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Oo
oooo00?o0000ooooooooool01?ooool3o`0000;ooooo0_l000001?oooooo0000ooooooooool4o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000;ooooo0_l000000ooooooo0000o`000008oooo
o`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`;o00000oooool2o`000003ooooool0003o
oooo00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000oooool2o`000003ooooool0003ooooo00;ooooo0ol00002ooooo`Co00000ooo
ool3o`0000;ooooo0_l000000ooooooo0000o`00000_ooooo`00=?ooool00ol0003oooooooooo`0h
ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0000Jooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool0??ooool003;ooooo
1Ol0000Eooooo`03o`000?oooooooooo027ooooo0ol0000Cooooo`?o00005Oooool4o`0001[ooooo
1?l0000Qooooo`03o`000?oooooooooo03cooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo002?ooooo`Go00004?ooool5o`0004oooooo0ol0000Uooooo`00T?oo
ool01?l0003oooooooooool0000Aooooo`04o`000?ooooooooooo`0004oooooo00Co0000oooooooo
oooo00009?ooool0093ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo02;ooooo002@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
DOooool2o`0002Gooooo002@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Uooooo`00T?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo053ooooo00Co0000oooooooooooo00009?ooool008oooooo0ol0000Booooo`?o0000D_ooool3
o`0002Cooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-20.1784, 26.7197, 0.479463, \
0.109075}},
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}]
}, Open  ]]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowGaussian", "Subsubsection",
  CellTags->{"AOG0.", "4.5.4", "AOG4.", "AOG4.5", "AOG4.5.4"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[cylindricalsystem, PlotType->TopView, ShowGaussian->True];\
\>", "Input",
  CellLabel->"In[79]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .535 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0239907 0.009522 0.279541 0.009522 [
[.5477 .01274 -5.03125 -6 ]
[.5477 .01274 5.03125 6 ]
[.97619 .26435 -4.75 -6 ]
[.97619 .26435 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .535 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.56114 .04149 m
.59531 .04149 L
.59531 .12084 L
.52624 .12084 L
.56114 .04149 L
F
.52624 .12084 m
.59531 .12084 L
.59531 .20019 L
.5065 .20019 L
.52624 .12084 L
F
.5065 .20019 m
.59531 .20019 L
.59531 .27954 L
.50009 .27954 L
.5065 .20019 L
F
.50009 .27954 m
.59531 .27954 L
.59531 .35889 L
.5065 .35889 L
.50009 .27954 L
F
.5065 .35889 m
.59531 .35889 L
.59531 .43824 L
.52624 .43824 L
.5065 .35889 L
F
.52624 .43824 m
.59531 .43824 L
.59531 .51759 L
.56114 .51759 L
.52624 .43824 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.56114 .04149 m
.52624 .12084 L
.5065 .20019 L
.50009 .27954 L
.5065 .35889 L
.52624 .43824 L
.56114 .51759 L
.59531 .51759 L
.59531 .43824 L
.59531 .35889 L
.59531 .27954 L
.59531 .20019 L
.59531 .12084 L
.59531 .04149 L
.56114 .04149 L
s
.5 g
.50009 .27954 m
.59531 .27954 L
.59531 .27954 L
.50009 .27954 L
.50009 .27954 L
F
.50009 .27954 m
.59531 .27954 L
.59531 .27954 L
.50009 .27954 L
.50009 .27954 L
F
.50009 .27954 m
.59531 .27954 L
.59531 .27954 L
.50009 .27954 L
.50009 .27954 L
F
.50009 .27954 m
.59531 .27954 L
.59531 .27954 L
.50009 .27954 L
.50009 .27954 L
F
.50009 .27954 m
.59531 .27954 L
.59531 .27954 L
.50009 .27954 L
.50009 .27954 L
F
.50009 .27954 m
.59531 .27954 L
.59531 .27954 L
.50009 .27954 L
.50009 .27954 L
F
0 g
.50009 .27954 m
.50009 .27954 L
.50009 .27954 L
.50009 .27954 L
.50009 .27954 L
.50009 .27954 L
.50009 .27954 L
.59531 .27954 L
.59531 .27954 L
.59531 .27954 L
.59531 .27954 L
.59531 .27954 L
.59531 .27954 L
.59531 .27954 L
.50009 .27954 L
s
.56114 .04149 m
.59531 .04149 L
.59531 .12084 L
.52624 .12084 L
.56114 .04149 L
s
.52624 .12084 m
.59531 .12084 L
.59531 .20019 L
.5065 .20019 L
.52624 .12084 L
s
.5065 .20019 m
.59531 .20019 L
.59531 .27954 L
.50009 .27954 L
.5065 .20019 L
s
.50009 .27954 m
.59531 .27954 L
.59531 .35889 L
.5065 .35889 L
.50009 .27954 L
s
.5065 .35889 m
.59531 .35889 L
.59531 .43824 L
.52624 .43824 L
.5065 .35889 L
s
.52624 .43824 m
.59531 .43824 L
.59531 .51759 L
.56114 .51759 L
.52624 .43824 L
s
.56114 .51759 m
.59531 .51759 L
.59531 .51759 L
.56114 .51759 L
.56114 .51759 L
s
.56114 .51759 m
.59531 .51759 L
.59531 .51759 L
.56114 .51759 L
.56114 .51759 L
s
.56114 .51759 m
.59531 .51759 L
.59531 .51759 L
.56114 .51759 L
.56114 .51759 L
s
.56114 .51759 m
.59531 .51759 L
.59531 .51759 L
.56114 .51759 L
.56114 .51759 L
s
.56114 .51759 m
.59531 .51759 L
.59531 .51759 L
.56114 .51759 L
.56114 .51759 L
s
.56114 .51759 m
.59531 .51759 L
.59531 .51759 L
.56114 .51759 L
.56114 .51759 L
s
.56114 .51759 m
.59531 .51759 L
.59531 .43824 L
.52624 .43824 L
.56114 .51759 L
s
.52624 .43824 m
.59531 .43824 L
.59531 .35889 L
.5065 .35889 L
.52624 .43824 L
s
.5065 .35889 m
.59531 .35889 L
.59531 .27954 L
.50009 .27954 L
.5065 .35889 L
s
.50009 .27954 m
.59531 .27954 L
.59531 .20019 L
.5065 .20019 L
.50009 .27954 L
s
.5065 .20019 m
.59531 .20019 L
.59531 .12084 L
.52624 .12084 L
.5065 .20019 L
s
.52624 .12084 m
.59531 .12084 L
.59531 .04149 L
.56114 .04149 L
.52624 .12084 L
s
.56114 .04149 m
.59531 .04149 L
.59531 .04149 L
.56114 .04149 L
.56114 .04149 L
s
.56114 .04149 m
.59531 .04149 L
.59531 .04149 L
.56114 .04149 L
.56114 .04149 L
s
.56114 .04149 m
.59531 .04149 L
.59531 .04149 L
.56114 .04149 L
.56114 .04149 L
s
.56114 .04149 m
.59531 .04149 L
.59531 .04149 L
.56114 .04149 L
.56114 .04149 L
s
.56114 .04149 m
.59531 .04149 L
.59531 .04149 L
.56114 .04149 L
.56114 .04149 L
s
.56114 .04149 m
.59531 .04149 L
.59531 .04149 L
.56114 .04149 L
.56114 .04149 L
s
.97619 .15585 m
.97619 .19708 L
.97619 .23831 L
.97619 .27954 L
.97619 .32077 L
.97619 .362 L
.97619 .40324 L
.97619 .40324 L
.97619 .362 L
.97619 .32077 L
.97619 .27954 L
.97619 .23831 L
.97619 .19708 L
.97619 .15585 L
.97619 .15585 L
s
.97619 .39857 m
.97619 .35889 L
.97619 .31922 L
.97619 .27954 L
.97619 .23987 L
.97619 .20019 L
.97619 .16052 L
.97619 .16052 L
.97619 .20019 L
.97619 .23987 L
.97619 .27954 L
.97619 .31922 L
.97619 .35889 L
.97619 .39857 L
.97619 .39857 L
s
.97619 .27487 m
.97619 .52226 L
.97619 .28421 L
.97619 .03682 L
.97619 .27487 L
s
0 0 0 r
gsave
.5477 .01274 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .26435 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
1 Mabswid
.02399 .32715 m
.03986 .32723 L
.05573 .32731 L
.0716 .32739 L
.08747 .32747 L
.10334 .32755 L
.11921 .32763 L
.13508 .32771 L
.15095 .32779 L
.16682 .32786 L
.18269 .32794 L
.19856 .32802 L
.21443 .3281 L
.2303 .32818 L
.24617 .32826 L
.26204 .32834 L
.27791 .32842 L
.29378 .3285 L
.30965 .32858 L
.32552 .32866 L
.34139 .32874 L
.35726 .32882 L
.37313 .3289 L
.389 .32898 L
.40487 .32906 L
.42074 .32913 L
.43661 .32921 L
.45248 .32929 L
.46835 .32937 L
.48422 .32945 L
.50009 .32953 L
.51596 .32904 L
.53183 .32854 L
.5477 .32804 L
.56357 .32755 L
.57944 .32705 L
.59531 .32656 L
.61118 .3258 L
.62705 .32505 L
.64292 .3243 L
.65879 .32354 L
.67466 .32279 L
.69053 .32204 L
.7064 .32128 L
.72227 .32053 L
.73814 .31978 L
.75401 .31902 L
.76988 .31827 L
.78575 .31752 L
.80162 .31677 L
Mistroke
.81749 .31601 L
.83336 .31526 L
.84923 .31451 L
.8651 .31375 L
.88097 .313 L
.89684 .31225 L
.91271 .31149 L
.92858 .31074 L
.94445 .30999 L
.96032 .30923 L
.97619 .30848 L
Mfstroke
.02399 .23193 m
.03986 .23185 L
.05573 .23177 L
.0716 .23169 L
.08747 .23161 L
.10334 .23153 L
.11921 .23145 L
.13508 .23138 L
.15095 .2313 L
.16682 .23122 L
.18269 .23114 L
.19856 .23106 L
.21443 .23098 L
.2303 .2309 L
.24617 .23082 L
.26204 .23074 L
.27791 .23066 L
.29378 .23058 L
.30965 .2305 L
.32552 .23042 L
.34139 .23034 L
.35726 .23026 L
.37313 .23019 L
.389 .23011 L
.40487 .23003 L
.42074 .22995 L
.43661 .22987 L
.45248 .22979 L
.46835 .22971 L
.48422 .22963 L
.50009 .22955 L
.51596 .23005 L
.53183 .23054 L
.5477 .23104 L
.56357 .23153 L
.57944 .23203 L
.59531 .23253 L
.61118 .23328 L
.62705 .23403 L
.64292 .23478 L
.65879 .23554 L
.67466 .23629 L
.69053 .23704 L
.7064 .2378 L
.72227 .23855 L
.73814 .2393 L
.75401 .24006 L
.76988 .24081 L
.78575 .24156 L
.80162 .24232 L
Mistroke
.81749 .24307 L
.83336 .24382 L
.84923 .24458 L
.8651 .24533 L
.88097 .24608 L
.89684 .24684 L
.91271 .24759 L
.92858 .24834 L
.94445 .24909 L
.96032 .24985 L
.97619 .2506 L
Mfstroke
.02399 .27954 m
.03986 .27954 L
.05573 .27954 L
.0716 .27954 L
.08747 .27954 L
.10334 .27954 L
.11921 .27954 L
.13508 .27954 L
.15095 .27954 L
.16682 .27954 L
.18269 .27954 L
.19856 .27954 L
.21443 .27954 L
.2303 .27954 L
.24617 .27954 L
.26204 .27954 L
.27791 .27954 L
.29378 .27954 L
.30965 .27954 L
.32552 .27954 L
.34139 .27954 L
.35726 .27954 L
.37313 .27954 L
.389 .27954 L
.40487 .27954 L
.42074 .27954 L
.43661 .27954 L
.45248 .27954 L
.46835 .27954 L
.48422 .27954 L
.50009 .27954 L
.51596 .27954 L
.53183 .27954 L
.5477 .27954 L
.56357 .27954 L
.57944 .27954 L
.59531 .27954 L
.61118 .27954 L
.62705 .27954 L
.64292 .27954 L
.65879 .27954 L
.67466 .27954 L
.69053 .27954 L
.7064 .27954 L
.72227 .27954 L
.73814 .27954 L
.75401 .27954 L
.76988 .27954 L
.78575 .27954 L
.80162 .27954 L
Mistroke
.81749 .27954 L
.83336 .27954 L
.84923 .27954 L
.8651 .27954 L
.88097 .27954 L
.89684 .27954 L
.91271 .27954 L
.92858 .27954 L
.94445 .27954 L
.96032 .27954 L
.97619 .27954 L
Mfstroke
.02399 .27954 m
.03986 .27954 L
.05573 .27954 L
.0716 .27954 L
.08747 .27954 L
.10334 .27954 L
.11921 .27954 L
.13508 .27954 L
.15095 .27954 L
.16682 .27954 L
.18269 .27954 L
.19856 .27954 L
.21443 .27954 L
.2303 .27954 L
.24617 .27954 L
.26204 .27954 L
.27791 .27954 L
.29378 .27954 L
.30965 .27954 L
.32552 .27954 L
.34139 .27954 L
.35726 .27954 L
.37313 .27954 L
.389 .27954 L
.40487 .27954 L
.42074 .27954 L
.43661 .27954 L
.45248 .27954 L
.46835 .27954 L
.48422 .27954 L
.50009 .27954 L
.51596 .27954 L
.53183 .27954 L
.5477 .27954 L
.56357 .27954 L
.57944 .27954 L
.59531 .27954 L
.61118 .27954 L
.62705 .27954 L
.64292 .27954 L
.65879 .27954 L
.67466 .27954 L
.69053 .27954 L
.7064 .27954 L
.72227 .27954 L
.73814 .27954 L
.75401 .27954 L
.76988 .27954 L
.78575 .27954 L
.80162 .27954 L
Mistroke
.81749 .27954 L
.83336 .27954 L
.84923 .27954 L
.8651 .27954 L
.88097 .27954 L
.89684 .27954 L
.91271 .27954 L
.92858 .27954 L
.94445 .27954 L
.96032 .27954 L
.97619 .27954 L
Mfstroke
0 0 0 r
.02399 .27954 m
.50009 .27954 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
.50009 .27954 m
.59531 .27954 L
s
% Start of user PostScript
50. 0 60. 0 MAarrowhead1
% End of user PostScript
.59531 .27954 m
.97619 .27954 L
s
% Start of user PostScript
60. 0 100. 0 MAarrowhead1
% End of user PostScript
.97619 .27954 m
.97619 .27954 L
s
% Start of user PostScript
100. 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .23669 m
.02383 .23955 L
.02385 .2424 L
.02387 .24526 L
.02389 .24812 L
.02391 .25097 L
.02393 .25383 L
.02394 .25669 L
.02395 .25954 L
.02396 .2624 L
.02397 .26526 L
.02398 .26811 L
.02398 .27097 L
.02399 .27383 L
.02399 .27668 L
.02399 .27954 L
.02399 .2824 L
.02399 .28525 L
.02398 .28811 L
.02398 .29097 L
.02397 .29382 L
.02396 .29668 L
.02395 .29954 L
.02394 .30239 L
.02393 .30525 L
.02391 .30811 L
.02389 .31096 L
.02387 .31382 L
.02385 .31668 L
.02383 .31953 L
.02381 .32239 L
s
.04761 .23658 m
.04764 .23945 L
.04766 .24231 L
.04768 .24518 L
.0477 .24804 L
.04771 .2509 L
.04773 .25377 L
.04774 .25663 L
.04776 .25949 L
.04777 .26236 L
.04778 .26522 L
.04778 .26809 L
.04779 .27095 L
.04779 .27381 L
.04779 .27668 L
.0478 .27954 L
.04779 .2824 L
.04779 .28527 L
.04779 .28813 L
.04778 .291 L
.04778 .29386 L
.04777 .29672 L
.04776 .29959 L
.04774 .30245 L
.04773 .30531 L
.04771 .30818 L
.0477 .31104 L
.04768 .31391 L
.04766 .31677 L
.04764 .31963 L
.04761 .3225 L
s
.07142 .23648 m
.07144 .23935 L
.07146 .24222 L
.07148 .24509 L
.0715 .24796 L
.07152 .25083 L
.07154 .2537 L
.07155 .25657 L
.07156 .25944 L
.07157 .26232 L
.07158 .26519 L
.07159 .26806 L
.07159 .27093 L
.0716 .2738 L
.0716 .27667 L
.0716 .27954 L
.0716 .28241 L
.0716 .28528 L
.07159 .28815 L
.07159 .29102 L
.07158 .2939 L
.07157 .29677 L
.07156 .29964 L
.07155 .30251 L
.07154 .30538 L
.07152 .30825 L
.0715 .31112 L
.07148 .31399 L
.07146 .31686 L
.07144 .31973 L
.07142 .3226 L
s
.09522 .23637 m
.09525 .23925 L
.09527 .24213 L
.09529 .245 L
.09531 .24788 L
.09532 .25076 L
.09534 .25364 L
.09535 .25652 L
.09537 .25939 L
.09538 .26227 L
.09539 .26515 L
.09539 .26803 L
.0954 .27091 L
.0954 .27378 L
.0954 .27666 L
.09541 .27954 L
.0954 .28242 L
.0954 .2853 L
.0954 .28817 L
.09539 .29105 L
.09539 .29393 L
.09538 .29681 L
.09537 .29969 L
.09535 .30256 L
.09534 .30544 L
.09532 .30832 L
.09531 .3112 L
.09529 .31408 L
.09527 .31696 L
.09525 .31983 L
.09522 .32271 L
s
.11903 .23626 m
.11905 .23915 L
.11907 .24203 L
.11909 .24492 L
.11911 .2478 L
.11913 .25069 L
.11914 .25357 L
.11916 .25646 L
.11917 .25934 L
.11918 .26223 L
.11919 .26511 L
.1192 .268 L
.1192 .27089 L
.11921 .27377 L
.11921 .27666 L
.11921 .27954 L
.11921 .28243 L
.11921 .28531 L
.1192 .2882 L
.1192 .29108 L
.11919 .29397 L
.11918 .29685 L
.11917 .29974 L
.11916 .30262 L
.11914 .30551 L
.11913 .30839 L
.11911 .31128 L
.11909 .31416 L
.11907 .31705 L
.11905 .31993 L
.11903 .32282 L
s
.14283 .23616 m
.14286 .23905 L
.14288 .24194 L
.1429 .24483 L
.14292 .24773 L
.14293 .25062 L
.14295 .25351 L
.14296 .2564 L
.14298 .25929 L
.14299 .26219 L
.143 .26508 L
.143 .26797 L
.14301 .27086 L
.14301 .27376 L
.14301 .27665 L
.14302 .27954 L
.14301 .28243 L
.14301 .28533 L
.14301 .28822 L
.143 .29111 L
.143 .294 L
.14299 .29689 L
.14298 .29979 L
.14296 .30268 L
.14295 .30557 L
.14293 .30846 L
.14292 .31136 L
.1429 .31425 L
.14288 .31714 L
.14286 .32003 L
.14283 .32293 L
s
.16664 .23605 m
.16666 .23895 L
.16668 .24185 L
.1667 .24475 L
.16672 .24765 L
.16674 .25055 L
.16675 .25345 L
.16677 .25635 L
.16678 .25924 L
.16679 .26214 L
.1668 .26504 L
.16681 .26794 L
.16681 .27084 L
.16682 .27374 L
.16682 .27664 L
.16682 .27954 L
.16682 .28244 L
.16682 .28534 L
.16681 .28824 L
.16681 .29114 L
.1668 .29404 L
.16679 .29694 L
.16678 .29984 L
.16677 .30274 L
.16675 .30564 L
.16674 .30854 L
.16672 .31143 L
.1667 .31433 L
.16668 .31723 L
.16666 .32013 L
.16664 .32303 L
s
.19044 .23594 m
.19047 .23885 L
.19049 .24176 L
.19051 .24466 L
.19053 .24757 L
.19054 .25047 L
.19056 .25338 L
.19057 .25629 L
.19059 .25919 L
.1906 .2621 L
.19061 .26501 L
.19061 .26791 L
.19062 .27082 L
.19062 .27373 L
.19062 .27663 L
.19063 .27954 L
.19062 .28245 L
.19062 .28535 L
.19062 .28826 L
.19061 .29117 L
.19061 .29407 L
.1906 .29698 L
.19059 .29989 L
.19057 .30279 L
.19056 .3057 L
.19054 .30861 L
.19053 .31151 L
.19051 .31442 L
.19049 .31733 L
.19047 .32023 L
.19044 .32314 L
s
.21425 .23583 m
.21427 .23875 L
.21429 .24166 L
.21431 .24458 L
.21433 .24749 L
.21435 .2504 L
.21436 .25332 L
.21438 .25623 L
.21439 .25914 L
.2144 .26206 L
.21441 .26497 L
.21442 .26789 L
.21442 .2708 L
.21443 .27371 L
.21443 .27663 L
.21443 .27954 L
.21443 .28245 L
.21443 .28537 L
.21442 .28828 L
.21442 .2912 L
.21441 .29411 L
.2144 .29702 L
.21439 .29994 L
.21438 .30285 L
.21436 .30576 L
.21435 .30868 L
.21433 .31159 L
.21431 .31451 L
.21429 .31742 L
.21427 .32033 L
.21425 .32325 L
s
.23805 .23573 m
.23807 .23865 L
.2381 .24157 L
.23812 .24449 L
.23814 .24741 L
.23815 .25033 L
.23817 .25325 L
.23818 .25617 L
.2382 .25909 L
.23821 .26202 L
.23822 .26494 L
.23822 .26786 L
.23823 .27078 L
.23823 .2737 L
.23823 .27662 L
.23824 .27954 L
.23823 .28246 L
.23823 .28538 L
.23823 .2883 L
.23822 .29122 L
.23822 .29415 L
.23821 .29707 L
.2382 .29999 L
.23818 .30291 L
.23817 .30583 L
.23815 .30875 L
.23814 .31167 L
.23812 .31459 L
.2381 .31751 L
.23807 .32043 L
.23805 .32335 L
s
.26185 .23562 m
.26188 .23855 L
.2619 .24148 L
.26192 .2444 L
.26194 .24733 L
.26196 .25026 L
.26197 .25319 L
.26199 .25612 L
.262 .25904 L
.26201 .26197 L
.26202 .2649 L
.26203 .26783 L
.26203 .27076 L
.26204 .27368 L
.26204 .27661 L
.26204 .27954 L
.26204 .28247 L
.26204 .2854 L
.26203 .28832 L
.26203 .29125 L
.26202 .29418 L
.26201 .29711 L
.262 .30004 L
.26199 .30296 L
.26197 .30589 L
.26196 .30882 L
.26194 .31175 L
.26192 .31468 L
.2619 .3176 L
.26188 .32053 L
.26185 .32346 L
s
.28566 .23551 m
.28568 .23845 L
.28571 .24138 L
.28573 .24432 L
.28575 .24725 L
.28576 .25019 L
.28578 .25312 L
.28579 .25606 L
.28581 .25899 L
.28582 .26193 L
.28582 .26486 L
.28583 .2678 L
.28584 .27074 L
.28584 .27367 L
.28584 .27661 L
.28585 .27954 L
.28584 .28248 L
.28584 .28541 L
.28584 .28835 L
.28583 .29128 L
.28582 .29422 L
.28582 .29715 L
.28581 .30009 L
.28579 .30302 L
.28578 .30596 L
.28576 .30889 L
.28575 .31183 L
.28573 .31476 L
.28571 .3177 L
.28568 .32063 L
.28566 .32357 L
s
.30946 .23541 m
.30949 .23835 L
.30951 .24129 L
.30953 .24423 L
.30955 .24718 L
.30957 .25012 L
.30958 .25306 L
.3096 .256 L
.30961 .25894 L
.30962 .26189 L
.30963 .26483 L
.30964 .26777 L
.30964 .27071 L
.30965 .27366 L
.30965 .2766 L
.30965 .27954 L
.30965 .28248 L
.30965 .28543 L
.30964 .28837 L
.30964 .29131 L
.30963 .29425 L
.30962 .29719 L
.30961 .30014 L
.3096 .30308 L
.30958 .30602 L
.30957 .30896 L
.30955 .31191 L
.30953 .31485 L
.30951 .31779 L
.30949 .32073 L
.30946 .32368 L
s
.33327 .2353 m
.33329 .23825 L
.33332 .2412 L
.33334 .24415 L
.33336 .2471 L
.33337 .25005 L
.33339 .253 L
.3334 .25595 L
.33341 .25889 L
.33343 .26184 L
.33343 .26479 L
.33344 .26774 L
.33345 .27069 L
.33345 .27364 L
.33345 .27659 L
.33346 .27954 L
.33345 .28249 L
.33345 .28544 L
.33345 .28839 L
.33344 .29134 L
.33343 .29429 L
.33343 .29724 L
.33341 .30019 L
.3334 .30314 L
.33339 .30609 L
.33337 .30904 L
.33336 .31198 L
.33334 .31493 L
.33332 .31788 L
.33329 .32083 L
.33327 .32378 L
s
.35707 .23519 m
.3571 .23815 L
.35712 .24111 L
.35714 .24406 L
.35716 .24702 L
.35718 .24997 L
.35719 .25293 L
.35721 .25589 L
.35722 .25884 L
.35723 .2618 L
.35724 .26476 L
.35725 .26771 L
.35725 .27067 L
.35726 .27363 L
.35726 .27658 L
.35726 .27954 L
.35726 .2825 L
.35726 .28545 L
.35725 .28841 L
.35725 .29137 L
.35724 .29432 L
.35723 .29728 L
.35722 .30024 L
.35721 .30319 L
.35719 .30615 L
.35718 .30911 L
.35716 .31206 L
.35714 .31502 L
.35712 .31798 L
.3571 .32093 L
.35707 .32389 L
s
.38088 .23508 m
.3809 .23805 L
.38092 .24101 L
.38095 .24398 L
.38096 .24694 L
.38098 .2499 L
.381 .25287 L
.38101 .25583 L
.38102 .25879 L
.38104 .26176 L
.38104 .26472 L
.38105 .26769 L
.38106 .27065 L
.38106 .27361 L
.38106 .27658 L
.38107 .27954 L
.38106 .2825 L
.38106 .28547 L
.38106 .28843 L
.38105 .2914 L
.38104 .29436 L
.38104 .29732 L
.38102 .30029 L
.38101 .30325 L
.381 .30621 L
.38098 .30918 L
.38096 .31214 L
.38095 .31511 L
.38092 .31807 L
.3809 .32103 L
.38088 .324 L
s
.40468 .23498 m
.40471 .23795 L
.40473 .24092 L
.40475 .24389 L
.40477 .24686 L
.40479 .24983 L
.4048 .2528 L
.40482 .25577 L
.40483 .25874 L
.40484 .26172 L
.40485 .26469 L
.40486 .26766 L
.40486 .27063 L
.40487 .2736 L
.40487 .27657 L
.40487 .27954 L
.40487 .28251 L
.40487 .28548 L
.40486 .28845 L
.40486 .29142 L
.40485 .2944 L
.40484 .29737 L
.40483 .30034 L
.40482 .30331 L
.4048 .30628 L
.40479 .30925 L
.40477 .31222 L
.40475 .31519 L
.40473 .31816 L
.40471 .32113 L
.40468 .3241 L
s
.42849 .23487 m
.42851 .23785 L
.42853 .24083 L
.42855 .2438 L
.42857 .24678 L
.42859 .24976 L
.42861 .25274 L
.42862 .25572 L
.42863 .25869 L
.42865 .26167 L
.42865 .26465 L
.42866 .26763 L
.42867 .27061 L
.42867 .27358 L
.42867 .27656 L
.42868 .27954 L
.42867 .28252 L
.42867 .2855 L
.42867 .28847 L
.42866 .29145 L
.42865 .29443 L
.42865 .29741 L
.42863 .30039 L
.42862 .30336 L
.42861 .30634 L
.42859 .30932 L
.42857 .3123 L
.42855 .31528 L
.42853 .31825 L
.42851 .32123 L
.42849 .32421 L
s
.45229 .23476 m
.45232 .23775 L
.45234 .24073 L
.45236 .24372 L
.45238 .2467 L
.4524 .24969 L
.45241 .25267 L
.45243 .25566 L
.45244 .25864 L
.45245 .26163 L
.45246 .26462 L
.45247 .2676 L
.45247 .27059 L
.45248 .27357 L
.45248 .27656 L
.45248 .27954 L
.45248 .28253 L
.45248 .28551 L
.45247 .2885 L
.45247 .29148 L
.45246 .29447 L
.45245 .29745 L
.45244 .30044 L
.45243 .30342 L
.45241 .30641 L
.4524 .30939 L
.45238 .31238 L
.45236 .31536 L
.45234 .31835 L
.45232 .32133 L
.45229 .32432 L
s
.4761 .23466 m
.47612 .23765 L
.47614 .24064 L
.47616 .24363 L
.47618 .24663 L
.4762 .24962 L
.47622 .25261 L
.47623 .2556 L
.47624 .25859 L
.47626 .26159 L
.47626 .26458 L
.47627 .26757 L
.47628 .27056 L
.47628 .27356 L
.47628 .27655 L
.47629 .27954 L
.47628 .28253 L
.47628 .28553 L
.47628 .28852 L
.47627 .29151 L
.47626 .2945 L
.47626 .29749 L
.47624 .30049 L
.47623 .30348 L
.47622 .30647 L
.4762 .30946 L
.47618 .31246 L
.47616 .31545 L
.47614 .31844 L
.47612 .32143 L
.4761 .32443 L
s
.50087 .23455 m
.50077 .23755 L
.50068 .24055 L
.50059 .24355 L
.50051 .24655 L
.50044 .24955 L
.50037 .25255 L
.50031 .25555 L
.50026 .25854 L
.50022 .26154 L
.50018 .26454 L
.50015 .26754 L
.50012 .27054 L
.5001 .27354 L
.50009 .27654 L
.50009 .27954 L
.50009 .28254 L
.5001 .28554 L
.50012 .28854 L
.50015 .29154 L
.50018 .29454 L
.50022 .29754 L
.50026 .30054 L
.50031 .30354 L
.50037 .30654 L
.50044 .30954 L
.50051 .31253 L
.50059 .31553 L
.50068 .31853 L
.50077 .32153 L
.50087 .32453 L
s
.52467 .23522 m
.52457 .23817 L
.52447 .24113 L
.52439 .24408 L
.52431 .24704 L
.52424 .24999 L
.52417 .25295 L
.52411 .2559 L
.52406 .25886 L
.52402 .26181 L
.52398 .26477 L
.52395 .26772 L
.52393 .27068 L
.52391 .27363 L
.5239 .27659 L
.5239 .27954 L
.5239 .2825 L
.52391 .28545 L
.52393 .28841 L
.52395 .29136 L
.52398 .29431 L
.52402 .29727 L
.52406 .30022 L
.52411 .30318 L
.52417 .30613 L
.52424 .30909 L
.52431 .31204 L
.52439 .315 L
.52447 .31795 L
.52457 .32091 L
.52467 .32386 L
s
.54846 .23589 m
.54836 .2388 L
.54827 .24171 L
.54819 .24462 L
.54811 .24753 L
.54804 .25044 L
.54797 .25335 L
.54792 .25626 L
.54787 .25917 L
.54782 .26208 L
.54778 .26499 L
.54775 .2679 L
.54773 .27081 L
.54771 .27372 L
.5477 .27663 L
.5477 .27954 L
.5477 .28245 L
.54771 .28536 L
.54773 .28827 L
.54775 .29118 L
.54778 .29409 L
.54782 .297 L
.54787 .29991 L
.54792 .30282 L
.54797 .30573 L
.54804 .30864 L
.54811 .31155 L
.54819 .31446 L
.54827 .31737 L
.54836 .32028 L
.54846 .32319 L
s
.57225 .23656 m
.57216 .23942 L
.57207 .24229 L
.57198 .24515 L
.57191 .24802 L
.57184 .25089 L
.57177 .25375 L
.57172 .25662 L
.57167 .25948 L
.57163 .26235 L
.57159 .26521 L
.57156 .26808 L
.57154 .27094 L
.57152 .27381 L
.57151 .27668 L
.57151 .27954 L
.57151 .28241 L
.57152 .28527 L
.57154 .28814 L
.57156 .291 L
.57159 .29387 L
.57163 .29673 L
.57167 .2996 L
.57172 .30247 L
.57177 .30533 L
.57184 .3082 L
.57191 .31106 L
.57198 .31393 L
.57207 .31679 L
.57216 .31966 L
.57225 .32252 L
s
.59701 .23723 m
.59679 .24005 L
.59659 .24287 L
.5964 .24569 L
.59622 .24851 L
.59607 .25133 L
.59592 .25415 L
.59579 .25697 L
.59568 .25979 L
.59558 .26262 L
.5955 .26544 L
.59543 .26826 L
.59538 .27108 L
.59534 .2739 L
.59532 .27672 L
.59531 .27954 L
.59532 .28236 L
.59534 .28518 L
.59538 .288 L
.59543 .29082 L
.5955 .29365 L
.59558 .29647 L
.59568 .29929 L
.59579 .30211 L
.59592 .30493 L
.59607 .30775 L
.59622 .31057 L
.5964 .31339 L
.59659 .31621 L
.59679 .31903 L
.59701 .32185 L
s
.62077 .23824 m
.62056 .241 L
.62036 .24375 L
.62018 .2465 L
.62001 .24926 L
.61985 .25201 L
.61971 .25476 L
.61959 .25752 L
.61948 .26027 L
.61938 .26302 L
.6193 .26578 L
.61923 .26853 L
.61918 .27128 L
.61915 .27403 L
.61912 .27679 L
.61912 .27954 L
.61912 .28229 L
.61915 .28505 L
.61918 .2878 L
.61923 .29055 L
.6193 .29331 L
.61938 .29606 L
.61948 .29881 L
.61959 .30157 L
.61971 .30432 L
.61985 .30707 L
.62001 .30983 L
.62018 .31258 L
.62036 .31533 L
.62056 .31808 L
.62077 .32084 L
s
.64454 .23926 m
.64433 .24195 L
.64413 .24463 L
.64396 .24732 L
.64379 .25 L
.64364 .25269 L
.6435 .25537 L
.64338 .25806 L
.64327 .26074 L
.64318 .26343 L
.6431 .26611 L
.64304 .2688 L
.64299 .27148 L
.64295 .27417 L
.64293 .27686 L
.64292 .27954 L
.64293 .28223 L
.64295 .28491 L
.64299 .2876 L
.64304 .29028 L
.6431 .29297 L
.64318 .29565 L
.64327 .29834 L
.64338 .30102 L
.6435 .30371 L
.64364 .30639 L
.64379 .30908 L
.64396 .31177 L
.64413 .31445 L
.64433 .31714 L
.64454 .31982 L
s
.6683 .24028 m
.6681 .24289 L
.66791 .24551 L
.66773 .24813 L
.66757 .25075 L
.66743 .25336 L
.66729 .25598 L
.66717 .2586 L
.66707 .26122 L
.66698 .26384 L
.6669 .26645 L
.66684 .26907 L
.66679 .27169 L
.66675 .27431 L
.66673 .27692 L
.66673 .27954 L
.66673 .28216 L
.66675 .28478 L
.66679 .28739 L
.66684 .29001 L
.6669 .29263 L
.66698 .29525 L
.66707 .29786 L
.66717 .30048 L
.66729 .3031 L
.66743 .30572 L
.66757 .30833 L
.66773 .31095 L
.66791 .31357 L
.6681 .31619 L
.6683 .3188 L
s
.69207 .24129 m
.69187 .24384 L
.69168 .24639 L
.69151 .24894 L
.69136 .25149 L
.69121 .25404 L
.69108 .25659 L
.69097 .25914 L
.69086 .26169 L
.69078 .26424 L
.6907 .26679 L
.69064 .26934 L
.69059 .27189 L
.69056 .27444 L
.69054 .27699 L
.69053 .27954 L
.69054 .28209 L
.69056 .28464 L
.69059 .28719 L
.69064 .28974 L
.6907 .29229 L
.69078 .29484 L
.69086 .29739 L
.69097 .29994 L
.69108 .30249 L
.69121 .30504 L
.69136 .30759 L
.69151 .31014 L
.69168 .31269 L
.69187 .31524 L
.69207 .31779 L
s
.71583 .24231 m
.71564 .24479 L
.71546 .24727 L
.71529 .24976 L
.71514 .25224 L
.715 .25472 L
.71487 .2572 L
.71476 .25968 L
.71466 .26217 L
.71457 .26465 L
.7145 .26713 L
.71444 .26961 L
.7144 .27209 L
.71436 .27458 L
.71434 .27706 L
.71434 .27954 L
.71434 .28202 L
.71436 .2845 L
.7144 .28699 L
.71444 .28947 L
.7145 .29195 L
.71457 .29443 L
.71466 .29691 L
.71476 .2994 L
.71487 .30188 L
.715 .30436 L
.71514 .30684 L
.71529 .30932 L
.71546 .31181 L
.71564 .31429 L
.71583 .31677 L
s
.73959 .24333 m
.73941 .24574 L
.73923 .24816 L
.73907 .25057 L
.73892 .25298 L
.73879 .2554 L
.73866 .25781 L
.73855 .26023 L
.73846 .26264 L
.73837 .26506 L
.7383 .26747 L
.73824 .26988 L
.7382 .2723 L
.73817 .27471 L
.73815 .27713 L
.73814 .27954 L
.73815 .28195 L
.73817 .28437 L
.7382 .28678 L
.73824 .2892 L
.7383 .29161 L
.73837 .29403 L
.73846 .29644 L
.73855 .29885 L
.73866 .30127 L
.73879 .30368 L
.73892 .3061 L
.73907 .30851 L
.73923 .31093 L
.73941 .31334 L
.73959 .31575 L
s
.76336 .24434 m
.76318 .24669 L
.76301 .24904 L
.76285 .25138 L
.76271 .25373 L
.76257 .25608 L
.76245 .25842 L
.76235 .26077 L
.76225 .26312 L
.76217 .26546 L
.7621 .26781 L
.76205 .27016 L
.762 .2725 L
.76197 .27485 L
.76195 .27719 L
.76195 .27954 L
.76195 .28189 L
.76197 .28423 L
.762 .28658 L
.76205 .28893 L
.7621 .29127 L
.76217 .29362 L
.76225 .29597 L
.76235 .29831 L
.76245 .30066 L
.76257 .30301 L
.76271 .30535 L
.76285 .3077 L
.76301 .31004 L
.76318 .31239 L
.76336 .31474 L
s
.78712 .24536 m
.78695 .24764 L
.78678 .24992 L
.78663 .2522 L
.78649 .25448 L
.78636 .25675 L
.78624 .25903 L
.78614 .26131 L
.78605 .26359 L
.78597 .26587 L
.7859 .26815 L
.78585 .27043 L
.78581 .2727 L
.78577 .27498 L
.78576 .27726 L
.78575 .27954 L
.78576 .28182 L
.78577 .2841 L
.78581 .28638 L
.78585 .28866 L
.7859 .29093 L
.78597 .29321 L
.78605 .29549 L
.78614 .29777 L
.78624 .30005 L
.78636 .30233 L
.78649 .30461 L
.78663 .30688 L
.78678 .30916 L
.78695 .31144 L
.78712 .31372 L
s
.81089 .24638 m
.81071 .24859 L
.81056 .2508 L
.81041 .25301 L
.81027 .25522 L
.81015 .25743 L
.81003 .25964 L
.80993 .26185 L
.80985 .26406 L
.80977 .26628 L
.8097 .26849 L
.80965 .2707 L
.80961 .27291 L
.80958 .27512 L
.80956 .27733 L
.80956 .27954 L
.80956 .28175 L
.80958 .28396 L
.80961 .28617 L
.80965 .28838 L
.8097 .2906 L
.80977 .29281 L
.80985 .29502 L
.80993 .29723 L
.81003 .29944 L
.81015 .30165 L
.81027 .30386 L
.81041 .30607 L
.81056 .30828 L
.81071 .31049 L
.81089 .3127 L
s
.83465 .24739 m
.83448 .24954 L
.83433 .25168 L
.83419 .25382 L
.83405 .25597 L
.83393 .25811 L
.83382 .26025 L
.83373 .2624 L
.83364 .26454 L
.83357 .26668 L
.8335 .26883 L
.83345 .27097 L
.83341 .27311 L
.83338 .27525 L
.83337 .2774 L
.83336 .27954 L
.83337 .28168 L
.83338 .28383 L
.83341 .28597 L
.83345 .28811 L
.8335 .29026 L
.83357 .2924 L
.83364 .29454 L
.83373 .29669 L
.83382 .29883 L
.83393 .30097 L
.83405 .30311 L
.83419 .30526 L
.83433 .3074 L
.83448 .30954 L
.83465 .31169 L
s
.85841 .24841 m
.85825 .25049 L
.8581 .25256 L
.85797 .25464 L
.85784 .25671 L
.85772 .25879 L
.85762 .26086 L
.85752 .26294 L
.85744 .26501 L
.85737 .26709 L
.8573 .26916 L
.85725 .27124 L
.85722 .27331 L
.85719 .27539 L
.85717 .27747 L
.85717 .27954 L
.85717 .28162 L
.85719 .28369 L
.85722 .28577 L
.85725 .28784 L
.8573 .28992 L
.85737 .29199 L
.85744 .29407 L
.85752 .29614 L
.85762 .29822 L
.85772 .30029 L
.85784 .30237 L
.85797 .30444 L
.8581 .30652 L
.85825 .30859 L
.85841 .31067 L
s
.88218 .24943 m
.88202 .25144 L
.88188 .25344 L
.88174 .25545 L
.88162 .25746 L
.88151 .25947 L
.88141 .26147 L
.88131 .26348 L
.88123 .26549 L
.88116 .2675 L
.8811 .2695 L
.88106 .27151 L
.88102 .27352 L
.88099 .27553 L
.88098 .27753 L
.88097 .27954 L
.88098 .28155 L
.88099 .28356 L
.88102 .28556 L
.88106 .28757 L
.8811 .28958 L
.88116 .29159 L
.88123 .29359 L
.88131 .2956 L
.88141 .29761 L
.88151 .29962 L
.88162 .30162 L
.88174 .30363 L
.88188 .30564 L
.88202 .30765 L
.88218 .30965 L
s
.90594 .25044 m
.90579 .25238 L
.90565 .25432 L
.90552 .25626 L
.9054 .2582 L
.90529 .26014 L
.9052 .26208 L
.90511 .26402 L
.90503 .26596 L
.90496 .2679 L
.90491 .26984 L
.90486 .27178 L
.90482 .27372 L
.9048 .27566 L
.90478 .2776 L
.90478 .27954 L
.90478 .28148 L
.9048 .28342 L
.90482 .28536 L
.90486 .2873 L
.90491 .28924 L
.90496 .29118 L
.90503 .29312 L
.90511 .29506 L
.9052 .297 L
.90529 .29894 L
.9054 .30088 L
.90552 .30282 L
.90565 .30476 L
.90579 .3067 L
.90594 .30864 L
s
.92971 .25146 m
.92956 .25333 L
.92943 .25521 L
.9293 .25708 L
.92919 .25895 L
.92908 .26082 L
.92899 .26269 L
.9289 .26457 L
.92883 .26644 L
.92876 .26831 L
.92871 .27018 L
.92866 .27205 L
.92863 .27392 L
.9286 .2758 L
.92859 .27767 L
.92858 .27954 L
.92859 .28141 L
.9286 .28328 L
.92863 .28516 L
.92866 .28703 L
.92871 .2889 L
.92876 .29077 L
.92883 .29264 L
.9289 .29452 L
.92899 .29639 L
.92908 .29826 L
.92919 .30013 L
.9293 .302 L
.92943 .30388 L
.92956 .30575 L
.92971 .30762 L
s
.95347 .25248 m
.95333 .25428 L
.9532 .25609 L
.95308 .25789 L
.95297 .2597 L
.95287 .2615 L
.95278 .2633 L
.95269 .26511 L
.95262 .26691 L
.95256 .26872 L
.95251 .27052 L
.95246 .27232 L
.95243 .27413 L
.9524 .27593 L
.95239 .27774 L
.95239 .27954 L
.95239 .28134 L
.9524 .28315 L
.95243 .28495 L
.95246 .28676 L
.95251 .28856 L
.95256 .29037 L
.95262 .29217 L
.95269 .29397 L
.95278 .29578 L
.95287 .29758 L
.95297 .29939 L
.95308 .30119 L
.9532 .30299 L
.95333 .3048 L
.95347 .3066 L
s
0 0 0 r
.02399 .27954 m
.50009 .27954 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
.50009 .27954 m
.59531 .27954 L
s
% Start of user PostScript
50. 0 60. 0 MAarrowhead1
% End of user PostScript
.59531 .27954 m
.97619 .27954 L
s
% Start of user PostScript
60. 0 100. 0 MAarrowhead1
% End of user PostScript
.97619 .27954 m
.97619 .27954 L
s
% Start of user PostScript
100. 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .27954 m
.02383 .27954 L
.02385 .27954 L
.02387 .27954 L
.02389 .27954 L
.02391 .27954 L
.02393 .27954 L
.02394 .27954 L
.02395 .27954 L
.02396 .27954 L
.02397 .27954 L
.02398 .27954 L
.02398 .27954 L
.02399 .27954 L
.02399 .27954 L
.02399 .27954 L
.02399 .27954 L
.02399 .27954 L
.02398 .27954 L
.02398 .27954 L
.02397 .27954 L
.02396 .27954 L
.02395 .27954 L
.02394 .27954 L
.02393 .27954 L
.02391 .27954 L
.02389 .27954 L
.02387 .27954 L
.02385 .27954 L
.02383 .27954 L
.02381 .27954 L
s
.04761 .27954 m
.04764 .27954 L
.04766 .27954 L
.04768 .27954 L
.0477 .27954 L
.04772 .27954 L
.04773 .27954 L
.04774 .27954 L
.04776 .27954 L
.04777 .27954 L
.04778 .27954 L
.04778 .27954 L
.04779 .27954 L
.04779 .27954 L
.04779 .27954 L
.0478 .27954 L
.04779 .27954 L
.04779 .27954 L
.04779 .27954 L
.04778 .27954 L
.04778 .27954 L
.04777 .27954 L
.04776 .27954 L
.04774 .27954 L
.04773 .27954 L
.04772 .27954 L
.0477 .27954 L
.04768 .27954 L
.04766 .27954 L
.04764 .27954 L
.04761 .27954 L
s
.07142 .27954 m
.07144 .27954 L
.07146 .27954 L
.07148 .27954 L
.0715 .27954 L
.07152 .27954 L
.07154 .27954 L
.07155 .27954 L
.07156 .27954 L
.07157 .27954 L
.07158 .27954 L
.07159 .27954 L
.07159 .27954 L
.0716 .27954 L
.0716 .27954 L
.0716 .27954 L
.0716 .27954 L
.0716 .27954 L
.07159 .27954 L
.07159 .27954 L
.07158 .27954 L
.07157 .27954 L
.07156 .27954 L
.07155 .27954 L
.07154 .27954 L
.07152 .27954 L
.0715 .27954 L
.07148 .27954 L
.07146 .27954 L
.07144 .27954 L
.07142 .27954 L
s
.09522 .27954 m
.09525 .27954 L
.09527 .27954 L
.09529 .27954 L
.09531 .27954 L
.09533 .27954 L
.09534 .27954 L
.09535 .27954 L
.09537 .27954 L
.09538 .27954 L
.09539 .27954 L
.09539 .27954 L
.0954 .27954 L
.0954 .27954 L
.0954 .27954 L
.09541 .27954 L
.0954 .27954 L
.0954 .27954 L
.0954 .27954 L
.09539 .27954 L
.09539 .27954 L
.09538 .27954 L
.09537 .27954 L
.09535 .27954 L
.09534 .27954 L
.09533 .27954 L
.09531 .27954 L
.09529 .27954 L
.09527 .27954 L
.09525 .27954 L
.09522 .27954 L
s
.11903 .27954 m
.11905 .27954 L
.11907 .27954 L
.11909 .27954 L
.11911 .27954 L
.11913 .27954 L
.11915 .27954 L
.11916 .27954 L
.11917 .27954 L
.11918 .27954 L
.11919 .27954 L
.1192 .27954 L
.1192 .27954 L
.11921 .27954 L
.11921 .27954 L
.11921 .27954 L
.11921 .27954 L
.11921 .27954 L
.1192 .27954 L
.1192 .27954 L
.11919 .27954 L
.11918 .27954 L
.11917 .27954 L
.11916 .27954 L
.11915 .27954 L
.11913 .27954 L
.11911 .27954 L
.11909 .27954 L
.11907 .27954 L
.11905 .27954 L
.11903 .27954 L
s
.14283 .27954 m
.14286 .27954 L
.14288 .27954 L
.1429 .27954 L
.14292 .27954 L
.14293 .27954 L
.14295 .27954 L
.14296 .27954 L
.14298 .27954 L
.14299 .27954 L
.143 .27954 L
.143 .27954 L
.14301 .27954 L
.14301 .27954 L
.14301 .27954 L
.14302 .27954 L
.14301 .27954 L
.14301 .27954 L
.14301 .27954 L
.143 .27954 L
.143 .27954 L
.14299 .27954 L
.14298 .27954 L
.14296 .27954 L
.14295 .27954 L
.14293 .27954 L
.14292 .27954 L
.1429 .27954 L
.14288 .27954 L
.14286 .27954 L
.14283 .27954 L
s
.16664 .27954 m
.16666 .27954 L
.16668 .27954 L
.1667 .27954 L
.16672 .27954 L
.16674 .27954 L
.16676 .27954 L
.16677 .27954 L
.16678 .27954 L
.16679 .27954 L
.1668 .27954 L
.16681 .27954 L
.16681 .27954 L
.16682 .27954 L
.16682 .27954 L
.16682 .27954 L
.16682 .27954 L
.16682 .27954 L
.16681 .27954 L
.16681 .27954 L
.1668 .27954 L
.16679 .27954 L
.16678 .27954 L
.16677 .27954 L
.16676 .27954 L
.16674 .27954 L
.16672 .27954 L
.1667 .27954 L
.16668 .27954 L
.16666 .27954 L
.16664 .27954 L
s
.19044 .27954 m
.19047 .27954 L
.19049 .27954 L
.19051 .27954 L
.19053 .27954 L
.19054 .27954 L
.19056 .27954 L
.19057 .27954 L
.19059 .27954 L
.1906 .27954 L
.19061 .27954 L
.19061 .27954 L
.19062 .27954 L
.19062 .27954 L
.19062 .27954 L
.19063 .27954 L
.19062 .27954 L
.19062 .27954 L
.19062 .27954 L
.19061 .27954 L
.19061 .27954 L
.1906 .27954 L
.19059 .27954 L
.19057 .27954 L
.19056 .27954 L
.19054 .27954 L
.19053 .27954 L
.19051 .27954 L
.19049 .27954 L
.19047 .27954 L
.19044 .27954 L
s
.21425 .27954 m
.21427 .27954 L
.21429 .27954 L
.21431 .27954 L
.21433 .27954 L
.21435 .27954 L
.21437 .27954 L
.21438 .27954 L
.21439 .27954 L
.2144 .27954 L
.21441 .27954 L
.21442 .27954 L
.21442 .27954 L
.21443 .27954 L
.21443 .27954 L
.21443 .27954 L
.21443 .27954 L
.21443 .27954 L
.21442 .27954 L
.21442 .27954 L
.21441 .27954 L
.2144 .27954 L
.21439 .27954 L
.21438 .27954 L
.21437 .27954 L
.21435 .27954 L
.21433 .27954 L
.21431 .27954 L
.21429 .27954 L
.21427 .27954 L
.21425 .27954 L
s
.23805 .27954 m
.23808 .27954 L
.2381 .27954 L
.23812 .27954 L
.23814 .27954 L
.23815 .27954 L
.23817 .27954 L
.23818 .27954 L
.2382 .27954 L
.23821 .27954 L
.23822 .27954 L
.23822 .27954 L
.23823 .27954 L
.23823 .27954 L
.23823 .27954 L
.23824 .27954 L
.23823 .27954 L
.23823 .27954 L
.23823 .27954 L
.23822 .27954 L
.23822 .27954 L
.23821 .27954 L
.2382 .27954 L
.23818 .27954 L
.23817 .27954 L
.23815 .27954 L
.23814 .27954 L
.23812 .27954 L
.2381 .27954 L
.23808 .27954 L
.23805 .27954 L
s
.26186 .27954 m
.26188 .27954 L
.2619 .27954 L
.26192 .27954 L
.26194 .27954 L
.26196 .27954 L
.26198 .27954 L
.26199 .27954 L
.262 .27954 L
.26201 .27954 L
.26202 .27954 L
.26203 .27954 L
.26203 .27954 L
.26204 .27954 L
.26204 .27954 L
.26204 .27954 L
.26204 .27954 L
.26204 .27954 L
.26203 .27954 L
.26203 .27954 L
.26202 .27954 L
.26201 .27954 L
.262 .27954 L
.26199 .27954 L
.26198 .27954 L
.26196 .27954 L
.26194 .27954 L
.26192 .27954 L
.2619 .27954 L
.26188 .27954 L
.26186 .27954 L
s
.28566 .27954 m
.28569 .27954 L
.28571 .27954 L
.28573 .27954 L
.28575 .27954 L
.28576 .27954 L
.28578 .27954 L
.28579 .27954 L
.28581 .27954 L
.28582 .27954 L
.28583 .27954 L
.28583 .27954 L
.28584 .27954 L
.28584 .27954 L
.28584 .27954 L
.28585 .27954 L
.28584 .27954 L
.28584 .27954 L
.28584 .27954 L
.28583 .27954 L
.28583 .27954 L
.28582 .27954 L
.28581 .27954 L
.28579 .27954 L
.28578 .27954 L
.28576 .27954 L
.28575 .27954 L
.28573 .27954 L
.28571 .27954 L
.28569 .27954 L
.28566 .27954 L
s
.30947 .27954 m
.30949 .27954 L
.30951 .27954 L
.30953 .27954 L
.30955 .27954 L
.30957 .27954 L
.30958 .27954 L
.3096 .27954 L
.30961 .27954 L
.30962 .27954 L
.30963 .27954 L
.30964 .27954 L
.30964 .27954 L
.30965 .27954 L
.30965 .27954 L
.30965 .27954 L
.30965 .27954 L
.30965 .27954 L
.30964 .27954 L
.30964 .27954 L
.30963 .27954 L
.30962 .27954 L
.30961 .27954 L
.3096 .27954 L
.30958 .27954 L
.30957 .27954 L
.30955 .27954 L
.30953 .27954 L
.30951 .27954 L
.30949 .27954 L
.30947 .27954 L
s
.33327 .27954 m
.3333 .27954 L
.33332 .27954 L
.33334 .27954 L
.33336 .27954 L
.33337 .27954 L
.33339 .27954 L
.3334 .27954 L
.33342 .27954 L
.33343 .27954 L
.33344 .27954 L
.33344 .27954 L
.33345 .27954 L
.33345 .27954 L
.33345 .27954 L
.33346 .27954 L
.33345 .27954 L
.33345 .27954 L
.33345 .27954 L
.33344 .27954 L
.33344 .27954 L
.33343 .27954 L
.33342 .27954 L
.3334 .27954 L
.33339 .27954 L
.33337 .27954 L
.33336 .27954 L
.33334 .27954 L
.33332 .27954 L
.3333 .27954 L
.33327 .27954 L
s
.35708 .27954 m
.3571 .27954 L
.35712 .27954 L
.35714 .27954 L
.35716 .27954 L
.35718 .27954 L
.35719 .27954 L
.35721 .27954 L
.35722 .27954 L
.35723 .27954 L
.35724 .27954 L
.35725 .27954 L
.35725 .27954 L
.35726 .27954 L
.35726 .27954 L
.35726 .27954 L
.35726 .27954 L
.35726 .27954 L
.35725 .27954 L
.35725 .27954 L
.35724 .27954 L
.35723 .27954 L
.35722 .27954 L
.35721 .27954 L
.35719 .27954 L
.35718 .27954 L
.35716 .27954 L
.35714 .27954 L
.35712 .27954 L
.3571 .27954 L
.35708 .27954 L
s
.38088 .27954 m
.38091 .27954 L
.38093 .27954 L
.38095 .27954 L
.38097 .27954 L
.38098 .27954 L
.381 .27954 L
.38101 .27954 L
.38103 .27954 L
.38104 .27954 L
.38105 .27954 L
.38105 .27954 L
.38106 .27954 L
.38106 .27954 L
.38106 .27954 L
.38107 .27954 L
.38106 .27954 L
.38106 .27954 L
.38106 .27954 L
.38105 .27954 L
.38105 .27954 L
.38104 .27954 L
.38103 .27954 L
.38101 .27954 L
.381 .27954 L
.38098 .27954 L
.38097 .27954 L
.38095 .27954 L
.38093 .27954 L
.38091 .27954 L
.38088 .27954 L
s
.40469 .27954 m
.40471 .27954 L
.40473 .27954 L
.40475 .27954 L
.40477 .27954 L
.40479 .27954 L
.4048 .27954 L
.40482 .27954 L
.40483 .27954 L
.40484 .27954 L
.40485 .27954 L
.40486 .27954 L
.40486 .27954 L
.40487 .27954 L
.40487 .27954 L
.40487 .27954 L
.40487 .27954 L
.40487 .27954 L
.40486 .27954 L
.40486 .27954 L
.40485 .27954 L
.40484 .27954 L
.40483 .27954 L
.40482 .27954 L
.4048 .27954 L
.40479 .27954 L
.40477 .27954 L
.40475 .27954 L
.40473 .27954 L
.40471 .27954 L
.40469 .27954 L
s
.42849 .27954 m
.42852 .27954 L
.42854 .27954 L
.42856 .27954 L
.42858 .27954 L
.42859 .27954 L
.42861 .27954 L
.42862 .27954 L
.42864 .27954 L
.42865 .27954 L
.42866 .27954 L
.42866 .27954 L
.42867 .27954 L
.42867 .27954 L
.42867 .27954 L
.42868 .27954 L
.42867 .27954 L
.42867 .27954 L
.42867 .27954 L
.42866 .27954 L
.42866 .27954 L
.42865 .27954 L
.42864 .27954 L
.42862 .27954 L
.42861 .27954 L
.42859 .27954 L
.42858 .27954 L
.42856 .27954 L
.42854 .27954 L
.42852 .27954 L
.42849 .27954 L
s
.4523 .27954 m
.45232 .27954 L
.45234 .27954 L
.45236 .27954 L
.45238 .27954 L
.4524 .27954 L
.45241 .27954 L
.45243 .27954 L
.45244 .27954 L
.45245 .27954 L
.45246 .27954 L
.45247 .27954 L
.45247 .27954 L
.45248 .27954 L
.45248 .27954 L
.45248 .27954 L
.45248 .27954 L
.45248 .27954 L
.45247 .27954 L
.45247 .27954 L
.45246 .27954 L
.45245 .27954 L
.45244 .27954 L
.45243 .27954 L
.45241 .27954 L
.4524 .27954 L
.45238 .27954 L
.45236 .27954 L
.45234 .27954 L
.45232 .27954 L
.4523 .27954 L
s
.4761 .27954 m
.47613 .27954 L
.47615 .27954 L
.47617 .27954 L
.47619 .27954 L
.4762 .27954 L
.47622 .27954 L
.47623 .27954 L
.47625 .27954 L
.47626 .27954 L
.47627 .27954 L
.47627 .27954 L
.47628 .27954 L
.47628 .27954 L
.47628 .27954 L
.47629 .27954 L
.47628 .27954 L
.47628 .27954 L
.47628 .27954 L
.47627 .27954 L
.47627 .27954 L
.47626 .27954 L
.47625 .27954 L
.47623 .27954 L
.47622 .27954 L
.4762 .27954 L
.47619 .27954 L
.47617 .27954 L
.47615 .27954 L
.47613 .27954 L
.4761 .27954 L
s
.50001 .27954 m
.50002 .27954 L
.50003 .27954 L
.50004 .27954 L
.50005 .27954 L
.50006 .27954 L
.50006 .27954 L
.50007 .27954 L
.50007 .27954 L
.50008 .27954 L
.50008 .27954 L
.50008 .27954 L
.50009 .27954 L
.50009 .27954 L
.50009 .27954 L
.50009 .27954 L
.50009 .27954 L
.50009 .27954 L
.50009 .27954 L
.50008 .27954 L
.50008 .27954 L
.50008 .27954 L
.50007 .27954 L
.50007 .27954 L
.50006 .27954 L
.50006 .27954 L
.50005 .27954 L
.50004 .27954 L
.50003 .27954 L
.50002 .27954 L
.50001 .27954 L
s
.52382 .27954 m
.52383 .27954 L
.52384 .27954 L
.52384 .27954 L
.52385 .27954 L
.52386 .27954 L
.52387 .27954 L
.52387 .27954 L
.52388 .27954 L
.52388 .27954 L
.52389 .27954 L
.52389 .27954 L
.52389 .27954 L
.52389 .27954 L
.5239 .27954 L
.5239 .27954 L
.5239 .27954 L
.52389 .27954 L
.52389 .27954 L
.52389 .27954 L
.52389 .27954 L
.52388 .27954 L
.52388 .27954 L
.52387 .27954 L
.52387 .27954 L
.52386 .27954 L
.52385 .27954 L
.52384 .27954 L
.52384 .27954 L
.52383 .27954 L
.52382 .27954 L
s
.54762 .27954 m
.54763 .27954 L
.54764 .27954 L
.54765 .27954 L
.54766 .27954 L
.54767 .27954 L
.54767 .27954 L
.54768 .27954 L
.54768 .27954 L
.54769 .27954 L
.54769 .27954 L
.54769 .27954 L
.5477 .27954 L
.5477 .27954 L
.5477 .27954 L
.5477 .27954 L
.5477 .27954 L
.5477 .27954 L
.5477 .27954 L
.54769 .27954 L
.54769 .27954 L
.54769 .27954 L
.54768 .27954 L
.54768 .27954 L
.54767 .27954 L
.54767 .27954 L
.54766 .27954 L
.54765 .27954 L
.54764 .27954 L
.54763 .27954 L
.54762 .27954 L
s
.57143 .27954 m
.57144 .27954 L
.57145 .27954 L
.57145 .27954 L
.57146 .27954 L
.57147 .27954 L
.57148 .27954 L
.57148 .27954 L
.57149 .27954 L
.57149 .27954 L
.5715 .27954 L
.5715 .27954 L
.5715 .27954 L
.5715 .27954 L
.57151 .27954 L
.57151 .27954 L
.57151 .27954 L
.5715 .27954 L
.5715 .27954 L
.5715 .27954 L
.5715 .27954 L
.57149 .27954 L
.57149 .27954 L
.57148 .27954 L
.57148 .27954 L
.57147 .27954 L
.57146 .27954 L
.57145 .27954 L
.57145 .27954 L
.57144 .27954 L
.57143 .27954 L
s
.59513 .27954 m
.59515 .27954 L
.59517 .27954 L
.59519 .27954 L
.59521 .27954 L
.59523 .27954 L
.59524 .27954 L
.59526 .27954 L
.59527 .27954 L
.59528 .27954 L
.59529 .27954 L
.5953 .27954 L
.5953 .27954 L
.59531 .27954 L
.59531 .27954 L
.59531 .27954 L
.59531 .27954 L
.59531 .27954 L
.5953 .27954 L
.5953 .27954 L
.59529 .27954 L
.59528 .27954 L
.59527 .27954 L
.59526 .27954 L
.59524 .27954 L
.59523 .27954 L
.59521 .27954 L
.59519 .27954 L
.59517 .27954 L
.59515 .27954 L
.59513 .27954 L
s
.61893 .27954 m
.61896 .27954 L
.61898 .27954 L
.619 .27954 L
.61902 .27954 L
.61903 .27954 L
.61905 .27954 L
.61906 .27954 L
.61908 .27954 L
.61909 .27954 L
.6191 .27954 L
.6191 .27954 L
.61911 .27954 L
.61911 .27954 L
.61911 .27954 L
.61912 .27954 L
.61911 .27954 L
.61911 .27954 L
.61911 .27954 L
.6191 .27954 L
.6191 .27954 L
.61909 .27954 L
.61908 .27954 L
.61906 .27954 L
.61905 .27954 L
.61903 .27954 L
.61902 .27954 L
.619 .27954 L
.61898 .27954 L
.61896 .27954 L
.61893 .27954 L
s
.64274 .27954 m
.64276 .27954 L
.64278 .27954 L
.6428 .27954 L
.64282 .27954 L
.64284 .27954 L
.64285 .27954 L
.64287 .27954 L
.64288 .27954 L
.64289 .27954 L
.6429 .27954 L
.64291 .27954 L
.64291 .27954 L
.64292 .27954 L
.64292 .27954 L
.64292 .27954 L
.64292 .27954 L
.64292 .27954 L
.64291 .27954 L
.64291 .27954 L
.6429 .27954 L
.64289 .27954 L
.64288 .27954 L
.64287 .27954 L
.64285 .27954 L
.64284 .27954 L
.64282 .27954 L
.6428 .27954 L
.64278 .27954 L
.64276 .27954 L
.64274 .27954 L
s
.66654 .27954 m
.66657 .27954 L
.66659 .27954 L
.66661 .27954 L
.66663 .27954 L
.66664 .27954 L
.66666 .27954 L
.66667 .27954 L
.66669 .27954 L
.6667 .27954 L
.66671 .27954 L
.66671 .27954 L
.66672 .27954 L
.66672 .27954 L
.66672 .27954 L
.66673 .27954 L
.66672 .27954 L
.66672 .27954 L
.66672 .27954 L
.66671 .27954 L
.66671 .27954 L
.6667 .27954 L
.66669 .27954 L
.66667 .27954 L
.66666 .27954 L
.66664 .27954 L
.66663 .27954 L
.66661 .27954 L
.66659 .27954 L
.66657 .27954 L
.66654 .27954 L
s
.69035 .27954 m
.69037 .27954 L
.69039 .27954 L
.69041 .27954 L
.69043 .27954 L
.69045 .27954 L
.69046 .27954 L
.69048 .27954 L
.69049 .27954 L
.6905 .27954 L
.69051 .27954 L
.69052 .27954 L
.69052 .27954 L
.69053 .27954 L
.69053 .27954 L
.69053 .27954 L
.69053 .27954 L
.69053 .27954 L
.69052 .27954 L
.69052 .27954 L
.69051 .27954 L
.6905 .27954 L
.69049 .27954 L
.69048 .27954 L
.69046 .27954 L
.69045 .27954 L
.69043 .27954 L
.69041 .27954 L
.69039 .27954 L
.69037 .27954 L
.69035 .27954 L
s
.71415 .27954 m
.71418 .27954 L
.7142 .27954 L
.71422 .27954 L
.71424 .27954 L
.71425 .27954 L
.71427 .27954 L
.71428 .27954 L
.7143 .27954 L
.71431 .27954 L
.71432 .27954 L
.71432 .27954 L
.71433 .27954 L
.71433 .27954 L
.71433 .27954 L
.71434 .27954 L
.71433 .27954 L
.71433 .27954 L
.71433 .27954 L
.71432 .27954 L
.71432 .27954 L
.71431 .27954 L
.7143 .27954 L
.71428 .27954 L
.71427 .27954 L
.71425 .27954 L
.71424 .27954 L
.71422 .27954 L
.7142 .27954 L
.71418 .27954 L
.71415 .27954 L
s
.73796 .27954 m
.73798 .27954 L
.738 .27954 L
.73802 .27954 L
.73804 .27954 L
.73806 .27954 L
.73807 .27954 L
.73809 .27954 L
.7381 .27954 L
.73811 .27954 L
.73812 .27954 L
.73813 .27954 L
.73813 .27954 L
.73814 .27954 L
.73814 .27954 L
.73814 .27954 L
.73814 .27954 L
.73814 .27954 L
.73813 .27954 L
.73813 .27954 L
.73812 .27954 L
.73811 .27954 L
.7381 .27954 L
.73809 .27954 L
.73807 .27954 L
.73806 .27954 L
.73804 .27954 L
.73802 .27954 L
.738 .27954 L
.73798 .27954 L
.73796 .27954 L
s
.76176 .27954 m
.76178 .27954 L
.76181 .27954 L
.76183 .27954 L
.76185 .27954 L
.76186 .27954 L
.76188 .27954 L
.76189 .27954 L
.76191 .27954 L
.76192 .27954 L
.76193 .27954 L
.76193 .27954 L
.76194 .27954 L
.76194 .27954 L
.76194 .27954 L
.76195 .27954 L
.76194 .27954 L
.76194 .27954 L
.76194 .27954 L
.76193 .27954 L
.76193 .27954 L
.76192 .27954 L
.76191 .27954 L
.76189 .27954 L
.76188 .27954 L
.76186 .27954 L
.76185 .27954 L
.76183 .27954 L
.76181 .27954 L
.76178 .27954 L
.76176 .27954 L
s
.78557 .27954 m
.78559 .27954 L
.78561 .27954 L
.78563 .27954 L
.78565 .27954 L
.78567 .27954 L
.78568 .27954 L
.7857 .27954 L
.78571 .27954 L
.78572 .27954 L
.78573 .27954 L
.78574 .27954 L
.78574 .27954 L
.78575 .27954 L
.78575 .27954 L
.78575 .27954 L
.78575 .27954 L
.78575 .27954 L
.78574 .27954 L
.78574 .27954 L
.78573 .27954 L
.78572 .27954 L
.78571 .27954 L
.7857 .27954 L
.78568 .27954 L
.78567 .27954 L
.78565 .27954 L
.78563 .27954 L
.78561 .27954 L
.78559 .27954 L
.78557 .27954 L
s
.80937 .27954 m
.80939 .27954 L
.80942 .27954 L
.80944 .27954 L
.80946 .27954 L
.80947 .27954 L
.80949 .27954 L
.8095 .27954 L
.80952 .27954 L
.80953 .27954 L
.80953 .27954 L
.80954 .27954 L
.80955 .27954 L
.80955 .27954 L
.80955 .27954 L
.80956 .27954 L
.80955 .27954 L
.80955 .27954 L
.80955 .27954 L
.80954 .27954 L
.80953 .27954 L
.80953 .27954 L
.80952 .27954 L
.8095 .27954 L
.80949 .27954 L
.80947 .27954 L
.80946 .27954 L
.80944 .27954 L
.80942 .27954 L
.80939 .27954 L
.80937 .27954 L
s
.83318 .27954 m
.8332 .27954 L
.83322 .27954 L
.83324 .27954 L
.83326 .27954 L
.83328 .27954 L
.83329 .27954 L
.83331 .27954 L
.83332 .27954 L
.83333 .27954 L
.83334 .27954 L
.83335 .27954 L
.83335 .27954 L
.83336 .27954 L
.83336 .27954 L
.83336 .27954 L
.83336 .27954 L
.83336 .27954 L
.83335 .27954 L
.83335 .27954 L
.83334 .27954 L
.83333 .27954 L
.83332 .27954 L
.83331 .27954 L
.83329 .27954 L
.83328 .27954 L
.83326 .27954 L
.83324 .27954 L
.83322 .27954 L
.8332 .27954 L
.83318 .27954 L
s
.85698 .27954 m
.857 .27954 L
.85703 .27954 L
.85705 .27954 L
.85707 .27954 L
.85708 .27954 L
.8571 .27954 L
.85711 .27954 L
.85713 .27954 L
.85714 .27954 L
.85714 .27954 L
.85715 .27954 L
.85716 .27954 L
.85716 .27954 L
.85716 .27954 L
.85717 .27954 L
.85716 .27954 L
.85716 .27954 L
.85716 .27954 L
.85715 .27954 L
.85714 .27954 L
.85714 .27954 L
.85713 .27954 L
.85711 .27954 L
.8571 .27954 L
.85708 .27954 L
.85707 .27954 L
.85705 .27954 L
.85703 .27954 L
.857 .27954 L
.85698 .27954 L
s
.88079 .27954 m
.88081 .27954 L
.88083 .27954 L
.88085 .27954 L
.88087 .27954 L
.88089 .27954 L
.8809 .27954 L
.88092 .27954 L
.88093 .27954 L
.88094 .27954 L
.88095 .27954 L
.88096 .27954 L
.88096 .27954 L
.88097 .27954 L
.88097 .27954 L
.88097 .27954 L
.88097 .27954 L
.88097 .27954 L
.88096 .27954 L
.88096 .27954 L
.88095 .27954 L
.88094 .27954 L
.88093 .27954 L
.88092 .27954 L
.8809 .27954 L
.88089 .27954 L
.88087 .27954 L
.88085 .27954 L
.88083 .27954 L
.88081 .27954 L
.88079 .27954 L
s
.90459 .27954 m
.90461 .27954 L
.90464 .27954 L
.90466 .27954 L
.90468 .27954 L
.90469 .27954 L
.90471 .27954 L
.90472 .27954 L
.90474 .27954 L
.90475 .27954 L
.90475 .27954 L
.90476 .27954 L
.90477 .27954 L
.90477 .27954 L
.90477 .27954 L
.90478 .27954 L
.90477 .27954 L
.90477 .27954 L
.90477 .27954 L
.90476 .27954 L
.90475 .27954 L
.90475 .27954 L
.90474 .27954 L
.90472 .27954 L
.90471 .27954 L
.90469 .27954 L
.90468 .27954 L
.90466 .27954 L
.90464 .27954 L
.90461 .27954 L
.90459 .27954 L
s
.9284 .27954 m
.92842 .27954 L
.92844 .27954 L
.92846 .27954 L
.92848 .27954 L
.9285 .27954 L
.92851 .27954 L
.92853 .27954 L
.92854 .27954 L
.92855 .27954 L
.92856 .27954 L
.92857 .27954 L
.92857 .27954 L
.92858 .27954 L
.92858 .27954 L
.92858 .27954 L
.92858 .27954 L
.92858 .27954 L
.92857 .27954 L
.92857 .27954 L
.92856 .27954 L
.92855 .27954 L
.92854 .27954 L
.92853 .27954 L
.92851 .27954 L
.9285 .27954 L
.92848 .27954 L
.92846 .27954 L
.92844 .27954 L
.92842 .27954 L
.9284 .27954 L
s
.9522 .27954 m
.95222 .27954 L
.95225 .27954 L
.95227 .27954 L
.95229 .27954 L
.9523 .27954 L
.95232 .27954 L
.95233 .27954 L
.95235 .27954 L
.95236 .27954 L
.95236 .27954 L
.95237 .27954 L
.95238 .27954 L
.95238 .27954 L
.95238 .27954 L
.95239 .27954 L
.95238 .27954 L
.95238 .27954 L
.95238 .27954 L
.95237 .27954 L
.95236 .27954 L
.95236 .27954 L
.95235 .27954 L
.95233 .27954 L
.95232 .27954 L
.9523 .27954 L
.95229 .27954 L
.95227 .27954 L
.95225 .27954 L
.95222 .27954 L
.9522 .27954 L
s
0 0 m
1 0 L
1 .535 L
0 .535 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[79]:=",
  ImageSize->{288, 154.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000VR000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00VOooool6o`00087ooooo002J
ooooo`05o`000?ooooooooooooooool00000POooool009[ooooo00?o0000ooooooooool0Poooool0
09[ooooo00?o0000ooooooooool0Poooool009[ooooo00?o0000ooooooooool0Poooool009[ooooo
00?o0000ooooooooool0Poooool009Wooooo0ol00024ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolFooooo`03o`000?oooooooooo00Sooooo002Pooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00X?ooool;o`0006[ooooo00?o
0000ooooooooool02?ooool00:3ooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo00Sooooo002Oooooo`03o`000?moOgooOgmo00SoOgmo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`08ooooo`00Woooool00ol0003oOgmoogmoO`08ogmoO`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool009kooooo00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Nooooo`03o`000?mo
OgooOgmo00WoOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00WOooool0
0ol0003oOgmoogmoO`0:ogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool0
09gooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
00Sooooo002Mooooo`03o`000?moOgooOgmo00[oOgmo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`08ooooo`00W?ooool00ol0003oOgmoogmoO`0;ogmoO`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool02?ooool009cooooo00?o0000ogmoOomoOgl02omoOgl00ol0003ooooooooo
o`1Xooooo`03o`000?oooooooooo00Sooooo002Kooooo`03o`000?moOgooOgmo00coOgmo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00Voooool00ol0003oOgmoogmoO`0<ogmo
O`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool009[ooooo00?o0000ogmoOomo
Ogl03OmoOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Jooooo`03o`00
0?moOgooOgmo00goOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00VOoo
ool00ol0003oOgmoogmoO`0>ogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?oo
ool009Wooooo00?o0000ogmoOomoOgl03_moOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo00Sooooo002Hooooo`03o`000?moOgooOgmo00ooOgmo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`08ooooo`00V?ooool00ol0003oOgmoogmoO`0?ogmoO`03o`000?oooooooooo06So
oooo00?o0000ooooooooool02?ooool009Sooooo00?o0000ogmoOomoOgl03omoOgl00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Gooooo`03o`000?moOgooOgmo013oOgmo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00Uoooool00ol0003oOgmoogmoO`0@
ogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool009Kooooo5Ol0001Zoooo
o`03o`000?oooooooooo00Sooooo002Fooooo`03o`000?moOgooOgmo017oOgmo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`08ooooo`00U_ooool00ol0003oOgmoogmoO`0AogmoO`03o`00
0?oooooooooo06Sooooo00?o0000ooooooooool02?ooool009Gooooo00?o0000ogmoOomoOgl04_mo
Ogl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Eooooo`03o`000?moOgoo
Ogmo01;oOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00UOooool00ol0
003oOgmoogmoO`0BogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool009Go
oooo00?o0000ogmoOomoOgl04_moOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00So
oooo002Eooooo`03o`000?moOgooOgmo01;oOgmo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`08ooooo`00U?ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?oooooooooo06Sooooo00?o
0000ooooooooool02?ooool009Cooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo00Sooooo002Dooooo`03o`000?moOgooOgmo01?oOgmo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`08ooooo`00U?ooool00ol0003oOgmoogmoO`0CogmoO`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool009?ooooo00?o0000ogmoOomoOgl0
5?moOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Cooooo`03o`000?mo
OgooOgmo01CoOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00Toooool0
0ol0003oOgmoogmoO`0DogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool0
09?ooooo00?o0000ogmoOomoOgl05?moOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
00Sooooo002Booooo`03o`000?moOgooOgmo01GoOgmo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`08ooooo`00T_ooool00ol0003oOgmoogmoO`0EogmoO`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool02?ooool009;ooooo00?o0000ogmoOomoOgl05OmoOgl00ol0003ooooooooo
o`1Xooooo`03o`000?oooooooooo00Sooooo002Booooo`03o`000?moOgooOgmo01GoOgmo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00T_ooool00ol0003oOgmoogmoO`0Eogmo
O`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool0097ooooo00?o0000ogmoOomo
Ogl05_moOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Aoooooa[o0000
J_ooool00ol0003oooooooooo`08ooooo`00TOooool00ol0003oOgmoogmoO`0FogmoO`03o`000?oo
oooooooo06Sooooo00?o0000ooooooooool02?ooool0097ooooo00?o0000ogmoOomoOgl05_moOgl0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Aooooo`03o`000?moOgooOgmo
01KoOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00TOooool00ol0003o
OgmoogmoO`0FogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool0097ooooo
00?o0000ogmoOomoOgl05_moOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo
002Aooooo`03o`000?moOgooOgmo01KoOgmo00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`08ooooo`00T?ooool00ol0003oOgmoogmoO`0GogmoO`03o`000?oooooooooo06Sooooo00?o0000
ooooooooool02?ooool008gooooo1Ol9jPXHogmoO`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool02?ooool000WoooooQ?l9jPX3ooooo`03o`000?moOgoo2NX:01[o2NX:J?ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:o`000?moOgl01?moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00?oOgmo
00?o2NX:ogmoOomoOgl01?moOgl00ol0003oooooooooo`0Go`WZ2U7ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_l0
003oOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`03ogmoO`03o`WZ2_mo
OgooOgmo00CoOgmo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Wooooo5_l9jPXkooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o0000ogmoO`04ogmoO`03o`WZ2_moOgoo
Ogmo00CoOgmo00?o2NX:ogmoOomoOgl00omoOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Gooooo4_l9jPXYooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o0000ogmoO`04ogmoO`03o`WZ2_moOgooOgmo
00CoOgmo00?o2NX:ogmoOomoOgl00omoOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00;ooooo5_l9jPXCooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool01?ooool00ol9jP[o0000ogmoO`04ogmoO`03o`WZ2_moOgooOgmo00Co
Ogmo00?o2NX:ogmoOomoOgl00omoOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?o
oooo5Ol9jPX:ooooo`002Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:o`000?moOgl01?moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00?oOgmo
00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o0000ogmo
O`04ogmoO`03o`WZ2_moOgooOgmo00?oOgmo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmo
O`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`04ooooo`04o`WZ2_ooooooooooooooo`?o00002_ooool000Wooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_l0003oOgmo00CoOgmo00?o2NX:ogmoOomoOgl00omo
Ogl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00Ko2NX:oooooooooooooooo
o`000?ooool2o`0000Wooooo0009ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00?oOgmo00?o2NX:ogmoOomoOgl0
1?moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo0_l00009ooooo`002Ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ogmoOomoOgl01?mo
Ogl00ol9jP[oOgmoogmoO`03ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?mo
Ogl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`03ooooo`;o00002_ooool000Wooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl00omoOgl0
0ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol0003oooooo`00000:ooooo`002Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`02ooooo`?o00001Oooool00ol9
jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00?oOgmo00?o2NX:ogmoOomoOgl00omoOgl3o`00
00GoOgmo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00;ooooo0ol00003ooooo`04o`000?oooooo0000o`0000Wooooo0009ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo1_l000000ooooooo2NX:ogmoO`05ogmoO`03o`WZ2_moOgooOgmo00?oOgmo00?o2NX:ogmo
OomoOgl01?moOgl6o`000003ogmoOol9jP[ooooo00Gooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9
jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9
jP[oooooooooo`03ooooo`Wo00002Oooool000Wooooo00?o2NX:o`000?l000001?l000000ol9jP[o
0000o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000001?l000000ol9jP[o
0000o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000001?l000000ol9jP[o
0000o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000001?l000000ol9jP[o
0000o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000001?l000000ol9jP[o
0000o`000004o`000003o`WZ2_l0003o000000?o00000_l9jPX5o`000003o`WZ2_l0003o000000Co
000000?o2NX:o`000?l000001?l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000Co
000000?o2NX:o`000?l000001?l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000Co
000000?o2NX:o`000?l000001?l000000ol9jP[o0000o`000003o`0000;o2NX:1Ol000000ol9jP[o
0000o`000004o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol000000ol9jP[o
0000o`000004o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol000000ol9jP[o
0000o`000004o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000001?l000000ol9jP[o
0000o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000001?l000000ol9jP[o
0000o`000003o`000003o`WZ2_l0003o000000Go00002_ooool000Wooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool5o`0000;ooooo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`03ogmoO`03o`WZ
2_moOgooOgmo00CoOgmo1Ol00002ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`Go00000_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`02ooooo`;o00001_ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_mo
OgooOgmo00?oOgmo00?o2NX:ogmoOomoOgl00omoOgl2o`0000KoOgmo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00;ooooo0_l00006ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00?oOgmo00?o2NX:ogmoOomoOgl01?moOgl0
0ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_moOgooOgmo
00CoOgmo00?o2NX:ogmoOomoOgl00omoOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo
00CoOgmo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool2o`WZ2PGo
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00?o
Ogmo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Co
oooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_l0003oOgmo00CoOgmo00?o2NX:ogmoOomoOgl00omoOgl00ol9jP[oOgmo
ogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:o`000?moOgl01?moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00?oOgmo00?o
2NX:ogmoOomoOgl01?moOgl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o0000ogmoO`04
ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl00omoOgl00ol9jP[oOgmoogmoO`04
ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool@o`WZ2P[ooooo0009oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o0000ogmoO`04ogmo
O`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl00omoOgl00ol9jP[oOgmoogmoO`04ogmo
O`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooool9jPX05_l9jPX?ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
0000ogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl00omoOgl00ol9jP[o
OgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo5_l9jPXVooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o0000
ogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl00omoOgl00ol9jP[oOgmo
ogmoO`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Kooooo4_l9jPXlooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooooooo
o`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[o0000ogmo
O`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl00omoOgl00ol9jP[oOgmoogmo
O`04ogmoO`03o`000?oooooooooo00Cooooo5_l9jPY>ooooo`03o`000?oooooooooo00Sooooo0009
ooooof[o2NX:7Oooool00ol0003oOgmoogmoO`03ogmoOa_o2NX:I?ooool00ol0003oooooooooo`08
ooooo`00LooooolSo`WZ2QCoOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08oooo
o`00T?ooool00ol0003oOgmoogmoO`0GogmoO`03o`000?oooooooooo06Sooooo00?o0000oooooooo
ool02?ooool0093ooooo00?o0000ogmoOomoOgl05omoOgl00ol0003oooooooooo`1Xooooo`03o`00
0?oooooooooo00Sooooo002Aooooo`03o`000?moOgooOgmo01KoOgmo00?o0000ooooooooool0J?oo
ool00ol0003oooooooooo`08ooooo`00TOooool00ol0003oOgmoogmoO`0FogmoO`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool02?ooool0097ooooo00?o0000ogmoOomoOgl05_moOgl00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Aooooo`03o`000?moOgooOgmo01Ko
Ogmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00TOooool00ol0003oOgmo
ogmoO`0FogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool0097ooooo6_l0
001Zooooo`03o`000?oooooooooo00Sooooo002Aooooo`03o`000?moOgooOgmo01KoOgmo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00TOooool00ol0003oOgmoogmoO`0Fogmo
O`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool009;ooooo00?o0000ogmoOomo
Ogl05OmoOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Booooo`03o`00
0?moOgooOgmo01GoOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00T_oo
ool00ol0003oOgmoogmoO`0EogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?oo
ool009;ooooo00?o0000ogmoOomoOgl05OmoOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo00Sooooo002Booooo`03o`000?moOgooOgmo01GoOgmo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`08ooooo`00Toooool00ol0003oOgmoogmoO`0DogmoO`03o`000?oooooooooo06So
oooo00?o0000ooooooooool02?ooool009?ooooo00?o0000ogmoOomoOgl05?moOgl00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Cooooo`03o`000?moOgooOgmo01CoOgmo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00Toooool00ol0003oOgmoogmoO`0D
ogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool009Cooooo00?o0000ogmo
OomoOgl04omoOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Dooooo`03
o`000?moOgooOgmo01?oOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00
U?ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
2?ooool009Cooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`1Xooooo`03o`000?oo
oooooooo00Sooooo002Eooooo`03o`000?moOgooOgmo01;oOgmo00?o0000ooooooooool0J?ooool0
0ol0003oooooooooo`08ooooo`00UOooool00ol0003oOgmoogmoO`0BogmoO`03o`000?oooooooooo
06Sooooo00?o0000ooooooooool02?ooool009Gooooo00?o0000ogmoOomoOgl04_moOgl00ol0003o
ooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Eooooo`03o`000?moOgooOgmo01;oOgmo
00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00UOooool00ol0003oOgmoogmo
O`0BogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool009Kooooo00?o0000
ogmoOomoOgl04OmoOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Foooo
oaGo0000J_ooool00ol0003oooooooooo`08ooooo`00U_ooool00ol0003oOgmoogmoO`0AogmoO`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool009Oooooo00?o0000ogmoOomoOgl0
4?moOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Gooooo`03o`000?mo
OgooOgmo013oOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00V?ooool0
0ol0003oOgmoogmoO`0?ogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool0
09Sooooo00?o0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
00Sooooo002Hooooo`03o`000?moOgooOgmo00ooOgmo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`08ooooo`00VOooool00ol0003oOgmoogmoO`0>ogmoO`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool02?ooool009Wooooo00?o0000ogmoOomoOgl03_moOgl00ol0003ooooooooo
o`1Xooooo`03o`000?oooooooooo00Sooooo002Jooooo`03o`000?moOgooOgmo00goOgmo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00V_ooool00ol0003oOgmoogmoO`0=ogmo
O`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool009_ooooo00?o0000ogmoOomo
Ogl03?moOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Kooooo`03o`00
0?moOgooOgmo00coOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00Vooo
ool00ol0003oOgmoogmoO`0<ogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?oo
ool009cooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo00Sooooo002Looooo`03o`000?moOgooOgmo00_oOgmo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`08ooooo`00WOooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?oooooooooo06So
oooo00?o0000ooooooooool02?ooool009gooooo00?o0000ogmoOomoOgl02_moOgl00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Nooooo`03o`000?moOgooOgmo00WoOgmo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00W_ooool00ol0003oOgmoogmoO`09
ogmoO`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool009kooooo00?o0000ogmo
OomoOgl02OmoOgl00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo002Oooooo`03
o`000?moOgooOgmo00SoOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00
Woooool2o`0000WoOgmo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`00X?oo
ool;o`0006[ooooo00?o0000ooooooooool02?ooool00?oooooo5_ooool00ol0003oooooooooo`08
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {153.062, 0}} -> {-3.52913, -30.2575, \
0.372959, 0.372959}},
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[cylindricalsystem, PlotType->SideView, ShowGaussian->True];\
\>", "Input",
  CellLabel->"In[80]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .62614 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0239907 0.009522 0.333662 0.009522 [
[.5477 .11307 -5.03125 -6 ]
[.5477 .11307 5.03125 6 ]
[.97619 .01491 -4.75 -6 ]
[.97619 .01491 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .62614 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.56114 .33366 m
.59531 .33366 L
.59531 .33366 L
.52624 .33366 L
.56114 .33366 L
F
.52624 .33366 m
.59531 .33366 L
.59531 .33366 L
.5065 .33366 L
.52624 .33366 L
F
.5065 .33366 m
.59531 .33366 L
.59531 .33366 L
.50009 .33366 L
.5065 .33366 L
F
.50009 .33366 m
.59531 .33366 L
.59531 .33366 L
.5065 .33366 L
.50009 .33366 L
F
.5065 .33366 m
.59531 .33366 L
.59531 .33366 L
.52624 .33366 L
.5065 .33366 L
F
.52624 .33366 m
.59531 .33366 L
.59531 .33366 L
.56114 .33366 L
.52624 .33366 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.56114 .33366 m
.52624 .33366 L
.5065 .33366 L
.50009 .33366 L
.5065 .33366 L
.52624 .33366 L
.56114 .33366 L
.59531 .33366 L
.59531 .33366 L
.59531 .33366 L
.59531 .33366 L
.59531 .33366 L
.59531 .33366 L
.59531 .33366 L
.56114 .33366 L
s
.5 g
.50009 .14322 m
.59531 .14322 L
.59531 .2067 L
.50009 .2067 L
.50009 .14322 L
F
.50009 .2067 m
.59531 .2067 L
.59531 .27018 L
.50009 .27018 L
.50009 .2067 L
F
.50009 .27018 m
.59531 .27018 L
.59531 .33366 L
.50009 .33366 L
.50009 .27018 L
F
.50009 .33366 m
.59531 .33366 L
.59531 .39714 L
.50009 .39714 L
.50009 .33366 L
F
.50009 .39714 m
.59531 .39714 L
.59531 .46062 L
.50009 .46062 L
.50009 .39714 L
F
.50009 .46062 m
.59531 .46062 L
.59531 .5241 L
.50009 .5241 L
.50009 .46062 L
F
0 g
.50009 .14322 m
.50009 .2067 L
.50009 .27018 L
.50009 .33366 L
.50009 .39714 L
.50009 .46062 L
.50009 .5241 L
.59531 .5241 L
.59531 .46062 L
.59531 .39714 L
.59531 .33366 L
.59531 .27018 L
.59531 .2067 L
.59531 .14322 L
.50009 .14322 L
s
.56114 .5241 m
.59531 .5241 L
.59531 .5241 L
.52624 .5241 L
.56114 .5241 L
s
.52624 .5241 m
.59531 .5241 L
.59531 .5241 L
.5065 .5241 L
.52624 .5241 L
s
.5065 .5241 m
.59531 .5241 L
.59531 .5241 L
.50009 .5241 L
.5065 .5241 L
s
.50009 .5241 m
.59531 .5241 L
.59531 .5241 L
.5065 .5241 L
.50009 .5241 L
s
.5065 .5241 m
.59531 .5241 L
.59531 .5241 L
.52624 .5241 L
.5065 .5241 L
s
.52624 .5241 m
.59531 .5241 L
.59531 .5241 L
.56114 .5241 L
.52624 .5241 L
s
.56114 .5241 m
.59531 .5241 L
.59531 .46062 L
.56114 .46062 L
.56114 .5241 L
s
.56114 .46062 m
.59531 .46062 L
.59531 .39714 L
.56114 .39714 L
.56114 .46062 L
s
.56114 .39714 m
.59531 .39714 L
.59531 .33366 L
.56114 .33366 L
.56114 .39714 L
s
.56114 .33366 m
.59531 .33366 L
.59531 .27018 L
.56114 .27018 L
.56114 .33366 L
s
.56114 .27018 m
.59531 .27018 L
.59531 .2067 L
.56114 .2067 L
.56114 .27018 L
s
.56114 .2067 m
.59531 .2067 L
.59531 .14322 L
.56114 .14322 L
.56114 .2067 L
s
.56114 .14322 m
.59531 .14322 L
.59531 .14322 L
.52624 .14322 L
.56114 .14322 L
s
.52624 .14322 m
.59531 .14322 L
.59531 .14322 L
.5065 .14322 L
.52624 .14322 L
s
.5065 .14322 m
.59531 .14322 L
.59531 .14322 L
.50009 .14322 L
.5065 .14322 L
s
.50009 .14322 m
.59531 .14322 L
.59531 .14322 L
.5065 .14322 L
.50009 .14322 L
s
.5065 .14322 m
.59531 .14322 L
.59531 .14322 L
.52624 .14322 L
.5065 .14322 L
s
.52624 .14322 m
.59531 .14322 L
.59531 .14322 L
.56114 .14322 L
.52624 .14322 L
s
.56114 .14322 m
.59531 .14322 L
.59531 .2067 L
.56114 .2067 L
.56114 .14322 L
s
.56114 .2067 m
.59531 .2067 L
.59531 .27018 L
.56114 .27018 L
.56114 .2067 L
s
.56114 .27018 m
.59531 .27018 L
.59531 .33366 L
.56114 .33366 L
.56114 .27018 L
s
.56114 .33366 m
.59531 .33366 L
.59531 .39714 L
.56114 .39714 L
.56114 .33366 L
s
.56114 .39714 m
.59531 .39714 L
.59531 .46062 L
.56114 .46062 L
.56114 .39714 L
s
.56114 .46062 m
.59531 .46062 L
.59531 .5241 L
.56114 .5241 L
.56114 .46062 L
s
.97619 .26225 m
.97619 .28605 L
.97619 .30986 L
.97619 .33366 L
.97619 .35747 L
.97619 .38127 L
.97619 .40508 L
.97619 .40508 L
.97619 .38127 L
.97619 .35747 L
.97619 .33366 L
.97619 .30986 L
.97619 .28605 L
.97619 .26225 L
.97619 .26225 L
s
.97619 .1275 m
.97619 .19622 L
.97619 .26494 L
.97619 .33366 L
.97619 .40238 L
.97619 .4711 L
.97619 .53982 L
.97619 .53982 L
.97619 .4711 L
.97619 .40238 L
.97619 .33366 L
.97619 .26494 L
.97619 .19622 L
.97619 .1275 L
.97619 .1275 L
s
.97619 .05609 m
.97619 .19892 L
.97619 .61123 L
.97619 .4684 L
.97619 .05609 L
s
0 0 0 r
gsave
.5477 .11307 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .01491 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
1 Mabswid
.02399 .33366 m
.03986 .33366 L
.05573 .33366 L
.0716 .33366 L
.08747 .33366 L
.10334 .33366 L
.11921 .33366 L
.13508 .33366 L
.15095 .33366 L
.16682 .33366 L
.18269 .33366 L
.19856 .33366 L
.21443 .33366 L
.2303 .33366 L
.24617 .33366 L
.26204 .33366 L
.27791 .33366 L
.29378 .33366 L
.30965 .33366 L
.32552 .33366 L
.34139 .33366 L
.35726 .33366 L
.37313 .33366 L
.389 .33366 L
.40487 .33366 L
.42074 .33366 L
.43661 .33366 L
.45248 .33366 L
.46835 .33366 L
.48422 .33366 L
.50009 .33366 L
.51596 .33366 L
.53183 .33366 L
.5477 .33366 L
.56357 .33366 L
.57944 .33366 L
.59531 .33366 L
.61118 .33366 L
.62705 .33366 L
.64292 .33366 L
.65879 .33366 L
.67466 .33366 L
.69053 .33366 L
.7064 .33366 L
.72227 .33366 L
.73814 .33366 L
.75401 .33366 L
.76988 .33366 L
.78575 .33366 L
.80162 .33366 L
Mistroke
.81749 .33366 L
.83336 .33366 L
.84923 .33366 L
.8651 .33366 L
.88097 .33366 L
.89684 .33366 L
.91271 .33366 L
.92858 .33366 L
.94445 .33366 L
.96032 .33366 L
.97619 .33366 L
Mfstroke
.02399 .33366 m
.03986 .33366 L
.05573 .33366 L
.0716 .33366 L
.08747 .33366 L
.10334 .33366 L
.11921 .33366 L
.13508 .33366 L
.15095 .33366 L
.16682 .33366 L
.18269 .33366 L
.19856 .33366 L
.21443 .33366 L
.2303 .33366 L
.24617 .33366 L
.26204 .33366 L
.27791 .33366 L
.29378 .33366 L
.30965 .33366 L
.32552 .33366 L
.34139 .33366 L
.35726 .33366 L
.37313 .33366 L
.389 .33366 L
.40487 .33366 L
.42074 .33366 L
.43661 .33366 L
.45248 .33366 L
.46835 .33366 L
.48422 .33366 L
.50009 .33366 L
.51596 .33366 L
.53183 .33366 L
.5477 .33366 L
.56357 .33366 L
.57944 .33366 L
.59531 .33366 L
.61118 .33366 L
.62705 .33366 L
.64292 .33366 L
.65879 .33366 L
.67466 .33366 L
.69053 .33366 L
.7064 .33366 L
.72227 .33366 L
.73814 .33366 L
.75401 .33366 L
.76988 .33366 L
.78575 .33366 L
.80162 .33366 L
Mistroke
.81749 .33366 L
.83336 .33366 L
.84923 .33366 L
.8651 .33366 L
.88097 .33366 L
.89684 .33366 L
.91271 .33366 L
.92858 .33366 L
.94445 .33366 L
.96032 .33366 L
.97619 .33366 L
Mfstroke
.02399 .42888 m
.03986 .42892 L
.05573 .42896 L
.0716 .429 L
.08747 .42904 L
.10334 .42908 L
.11921 .42912 L
.13508 .42916 L
.15095 .4292 L
.16682 .42924 L
.18269 .42928 L
.19856 .42932 L
.21443 .42936 L
.2303 .4294 L
.24617 .42944 L
.26204 .42948 L
.27791 .42952 L
.29378 .42956 L
.30965 .4296 L
.32552 .42964 L
.34139 .42968 L
.35726 .42971 L
.37313 .42975 L
.389 .42979 L
.40487 .42983 L
.42074 .42987 L
.43661 .42991 L
.45248 .42995 L
.46835 .42999 L
.48422 .43003 L
.50009 .43007 L
.51596 .4301 L
.53183 .43012 L
.5477 .43015 L
.56357 .43018 L
.57944 .4302 L
.59531 .43023 L
.61118 .43027 L
.62705 .43031 L
.64292 .43035 L
.65879 .43039 L
.67466 .43043 L
.69053 .43047 L
.7064 .43051 L
.72227 .43055 L
.73814 .43059 L
.75401 .43063 L
.76988 .43067 L
.78575 .4307 L
.80162 .43074 L
Mistroke
.81749 .43078 L
.83336 .43082 L
.84923 .43086 L
.8651 .4309 L
.88097 .43094 L
.89684 .43098 L
.91271 .43102 L
.92858 .43106 L
.94445 .4311 L
.96032 .43114 L
.97619 .43118 L
Mfstroke
.02399 .23844 m
.03986 .2384 L
.05573 .23836 L
.0716 .23832 L
.08747 .23828 L
.10334 .23824 L
.11921 .2382 L
.13508 .23816 L
.15095 .23812 L
.16682 .23808 L
.18269 .23805 L
.19856 .23801 L
.21443 .23797 L
.2303 .23793 L
.24617 .23789 L
.26204 .23785 L
.27791 .23781 L
.29378 .23777 L
.30965 .23773 L
.32552 .23769 L
.34139 .23765 L
.35726 .23761 L
.37313 .23757 L
.389 .23753 L
.40487 .23749 L
.42074 .23745 L
.43661 .23741 L
.45248 .23737 L
.46835 .23733 L
.48422 .23729 L
.50009 .23725 L
.51596 .23723 L
.53183 .2372 L
.5477 .23717 L
.56357 .23715 L
.57944 .23712 L
.59531 .23709 L
.61118 .23706 L
.62705 .23702 L
.64292 .23698 L
.65879 .23694 L
.67466 .2369 L
.69053 .23686 L
.7064 .23682 L
.72227 .23678 L
.73814 .23674 L
.75401 .2367 L
.76988 .23666 L
.78575 .23662 L
.80162 .23658 L
Mistroke
.81749 .23654 L
.83336 .2365 L
.84923 .23646 L
.8651 .23642 L
.88097 .23638 L
.89684 .23634 L
.91271 .2363 L
.92858 .23626 L
.94445 .23622 L
.96032 .23618 L
.97619 .23614 L
Mfstroke
0 0 0 r
.02399 .33366 m
.50009 .33366 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
.50009 .33366 m
.59531 .33366 L
s
% Start of user PostScript
50. 0 60. 0 MAarrowhead1
% End of user PostScript
.59531 .33366 m
.97619 .33366 L
s
% Start of user PostScript
60. 0 100. 0 MAarrowhead1
% End of user PostScript
.97619 .33366 m
.97619 .33366 L
s
% Start of user PostScript
100. 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .33366 m
.02383 .33366 L
.02385 .33366 L
.02387 .33366 L
.02389 .33366 L
.02391 .33366 L
.02393 .33366 L
.02394 .33366 L
.02395 .33366 L
.02396 .33366 L
.02397 .33366 L
.02398 .33366 L
.02398 .33366 L
.02399 .33366 L
.02399 .33366 L
.02399 .33366 L
.02399 .33366 L
.02399 .33366 L
.02398 .33366 L
.02398 .33366 L
.02397 .33366 L
.02396 .33366 L
.02395 .33366 L
.02394 .33366 L
.02393 .33366 L
.02391 .33366 L
.02389 .33366 L
.02387 .33366 L
.02385 .33366 L
.02383 .33366 L
.02381 .33366 L
s
.04761 .33366 m
.04764 .33366 L
.04766 .33366 L
.04768 .33366 L
.0477 .33366 L
.04771 .33366 L
.04773 .33366 L
.04774 .33366 L
.04776 .33366 L
.04777 .33366 L
.04778 .33366 L
.04778 .33366 L
.04779 .33366 L
.04779 .33366 L
.04779 .33366 L
.0478 .33366 L
.04779 .33366 L
.04779 .33366 L
.04779 .33366 L
.04778 .33366 L
.04778 .33366 L
.04777 .33366 L
.04776 .33366 L
.04774 .33366 L
.04773 .33366 L
.04771 .33366 L
.0477 .33366 L
.04768 .33366 L
.04766 .33366 L
.04764 .33366 L
.04761 .33366 L
s
.07142 .33366 m
.07144 .33366 L
.07146 .33366 L
.07148 .33366 L
.0715 .33366 L
.07152 .33366 L
.07154 .33366 L
.07155 .33366 L
.07156 .33366 L
.07157 .33366 L
.07158 .33366 L
.07159 .33366 L
.07159 .33366 L
.0716 .33366 L
.0716 .33366 L
.0716 .33366 L
.0716 .33366 L
.0716 .33366 L
.07159 .33366 L
.07159 .33366 L
.07158 .33366 L
.07157 .33366 L
.07156 .33366 L
.07155 .33366 L
.07154 .33366 L
.07152 .33366 L
.0715 .33366 L
.07148 .33366 L
.07146 .33366 L
.07144 .33366 L
.07142 .33366 L
s
.09522 .33366 m
.09525 .33366 L
.09527 .33366 L
.09529 .33366 L
.09531 .33366 L
.09532 .33366 L
.09534 .33366 L
.09535 .33366 L
.09537 .33366 L
.09538 .33366 L
.09539 .33366 L
.09539 .33366 L
.0954 .33366 L
.0954 .33366 L
.0954 .33366 L
.09541 .33366 L
.0954 .33366 L
.0954 .33366 L
.0954 .33366 L
.09539 .33366 L
.09539 .33366 L
.09538 .33366 L
.09537 .33366 L
.09535 .33366 L
.09534 .33366 L
.09532 .33366 L
.09531 .33366 L
.09529 .33366 L
.09527 .33366 L
.09525 .33366 L
.09522 .33366 L
s
.11903 .33366 m
.11905 .33366 L
.11907 .33366 L
.11909 .33366 L
.11911 .33366 L
.11913 .33366 L
.11914 .33366 L
.11916 .33366 L
.11917 .33366 L
.11918 .33366 L
.11919 .33366 L
.1192 .33366 L
.1192 .33366 L
.11921 .33366 L
.11921 .33366 L
.11921 .33366 L
.11921 .33366 L
.11921 .33366 L
.1192 .33366 L
.1192 .33366 L
.11919 .33366 L
.11918 .33366 L
.11917 .33366 L
.11916 .33366 L
.11914 .33366 L
.11913 .33366 L
.11911 .33366 L
.11909 .33366 L
.11907 .33366 L
.11905 .33366 L
.11903 .33366 L
s
.14283 .33366 m
.14286 .33366 L
.14288 .33366 L
.1429 .33366 L
.14292 .33366 L
.14293 .33366 L
.14295 .33366 L
.14296 .33366 L
.14298 .33366 L
.14299 .33366 L
.143 .33366 L
.143 .33366 L
.14301 .33366 L
.14301 .33366 L
.14301 .33366 L
.14302 .33366 L
.14301 .33366 L
.14301 .33366 L
.14301 .33366 L
.143 .33366 L
.143 .33366 L
.14299 .33366 L
.14298 .33366 L
.14296 .33366 L
.14295 .33366 L
.14293 .33366 L
.14292 .33366 L
.1429 .33366 L
.14288 .33366 L
.14286 .33366 L
.14283 .33366 L
s
.16664 .33366 m
.16666 .33366 L
.16668 .33366 L
.1667 .33366 L
.16672 .33366 L
.16674 .33366 L
.16675 .33366 L
.16677 .33366 L
.16678 .33366 L
.16679 .33366 L
.1668 .33366 L
.16681 .33366 L
.16681 .33366 L
.16682 .33366 L
.16682 .33366 L
.16682 .33366 L
.16682 .33366 L
.16682 .33366 L
.16681 .33366 L
.16681 .33366 L
.1668 .33366 L
.16679 .33366 L
.16678 .33366 L
.16677 .33366 L
.16675 .33366 L
.16674 .33366 L
.16672 .33366 L
.1667 .33366 L
.16668 .33366 L
.16666 .33366 L
.16664 .33366 L
s
.19044 .33366 m
.19047 .33366 L
.19049 .33366 L
.19051 .33366 L
.19053 .33366 L
.19054 .33366 L
.19056 .33366 L
.19057 .33366 L
.19059 .33366 L
.1906 .33366 L
.19061 .33366 L
.19061 .33366 L
.19062 .33366 L
.19062 .33366 L
.19062 .33366 L
.19063 .33366 L
.19062 .33366 L
.19062 .33366 L
.19062 .33366 L
.19061 .33366 L
.19061 .33366 L
.1906 .33366 L
.19059 .33366 L
.19057 .33366 L
.19056 .33366 L
.19054 .33366 L
.19053 .33366 L
.19051 .33366 L
.19049 .33366 L
.19047 .33366 L
.19044 .33366 L
s
.21425 .33366 m
.21427 .33366 L
.21429 .33366 L
.21431 .33366 L
.21433 .33366 L
.21435 .33366 L
.21436 .33366 L
.21438 .33366 L
.21439 .33366 L
.2144 .33366 L
.21441 .33366 L
.21442 .33366 L
.21442 .33366 L
.21443 .33366 L
.21443 .33366 L
.21443 .33366 L
.21443 .33366 L
.21443 .33366 L
.21442 .33366 L
.21442 .33366 L
.21441 .33366 L
.2144 .33366 L
.21439 .33366 L
.21438 .33366 L
.21436 .33366 L
.21435 .33366 L
.21433 .33366 L
.21431 .33366 L
.21429 .33366 L
.21427 .33366 L
.21425 .33366 L
s
.23805 .33366 m
.23807 .33366 L
.2381 .33366 L
.23812 .33366 L
.23814 .33366 L
.23815 .33366 L
.23817 .33366 L
.23818 .33366 L
.2382 .33366 L
.23821 .33366 L
.23822 .33366 L
.23822 .33366 L
.23823 .33366 L
.23823 .33366 L
.23823 .33366 L
.23824 .33366 L
.23823 .33366 L
.23823 .33366 L
.23823 .33366 L
.23822 .33366 L
.23822 .33366 L
.23821 .33366 L
.2382 .33366 L
.23818 .33366 L
.23817 .33366 L
.23815 .33366 L
.23814 .33366 L
.23812 .33366 L
.2381 .33366 L
.23807 .33366 L
.23805 .33366 L
s
.26185 .33366 m
.26188 .33366 L
.2619 .33366 L
.26192 .33366 L
.26194 .33366 L
.26196 .33366 L
.26197 .33366 L
.26199 .33366 L
.262 .33366 L
.26201 .33366 L
.26202 .33366 L
.26203 .33366 L
.26203 .33366 L
.26204 .33366 L
.26204 .33366 L
.26204 .33366 L
.26204 .33366 L
.26204 .33366 L
.26203 .33366 L
.26203 .33366 L
.26202 .33366 L
.26201 .33366 L
.262 .33366 L
.26199 .33366 L
.26197 .33366 L
.26196 .33366 L
.26194 .33366 L
.26192 .33366 L
.2619 .33366 L
.26188 .33366 L
.26185 .33366 L
s
.28566 .33366 m
.28568 .33366 L
.28571 .33366 L
.28573 .33366 L
.28575 .33366 L
.28576 .33366 L
.28578 .33366 L
.28579 .33366 L
.28581 .33366 L
.28582 .33366 L
.28582 .33366 L
.28583 .33366 L
.28584 .33366 L
.28584 .33366 L
.28584 .33366 L
.28585 .33366 L
.28584 .33366 L
.28584 .33366 L
.28584 .33366 L
.28583 .33366 L
.28582 .33366 L
.28582 .33366 L
.28581 .33366 L
.28579 .33366 L
.28578 .33366 L
.28576 .33366 L
.28575 .33366 L
.28573 .33366 L
.28571 .33366 L
.28568 .33366 L
.28566 .33366 L
s
.30946 .33366 m
.30949 .33366 L
.30951 .33366 L
.30953 .33366 L
.30955 .33366 L
.30957 .33366 L
.30958 .33366 L
.3096 .33366 L
.30961 .33366 L
.30962 .33366 L
.30963 .33366 L
.30964 .33366 L
.30964 .33366 L
.30965 .33366 L
.30965 .33366 L
.30965 .33366 L
.30965 .33366 L
.30965 .33366 L
.30964 .33366 L
.30964 .33366 L
.30963 .33366 L
.30962 .33366 L
.30961 .33366 L
.3096 .33366 L
.30958 .33366 L
.30957 .33366 L
.30955 .33366 L
.30953 .33366 L
.30951 .33366 L
.30949 .33366 L
.30946 .33366 L
s
.33327 .33366 m
.33329 .33366 L
.33332 .33366 L
.33334 .33366 L
.33336 .33366 L
.33337 .33366 L
.33339 .33366 L
.3334 .33366 L
.33341 .33366 L
.33343 .33366 L
.33343 .33366 L
.33344 .33366 L
.33345 .33366 L
.33345 .33366 L
.33345 .33366 L
.33346 .33366 L
.33345 .33366 L
.33345 .33366 L
.33345 .33366 L
.33344 .33366 L
.33343 .33366 L
.33343 .33366 L
.33341 .33366 L
.3334 .33366 L
.33339 .33366 L
.33337 .33366 L
.33336 .33366 L
.33334 .33366 L
.33332 .33366 L
.33329 .33366 L
.33327 .33366 L
s
.35707 .33366 m
.3571 .33366 L
.35712 .33366 L
.35714 .33366 L
.35716 .33366 L
.35718 .33366 L
.35719 .33366 L
.35721 .33366 L
.35722 .33366 L
.35723 .33366 L
.35724 .33366 L
.35725 .33366 L
.35725 .33366 L
.35726 .33366 L
.35726 .33366 L
.35726 .33366 L
.35726 .33366 L
.35726 .33366 L
.35725 .33366 L
.35725 .33366 L
.35724 .33366 L
.35723 .33366 L
.35722 .33366 L
.35721 .33366 L
.35719 .33366 L
.35718 .33366 L
.35716 .33366 L
.35714 .33366 L
.35712 .33366 L
.3571 .33366 L
.35707 .33366 L
s
.38088 .33366 m
.3809 .33366 L
.38092 .33366 L
.38095 .33366 L
.38096 .33366 L
.38098 .33366 L
.381 .33366 L
.38101 .33366 L
.38102 .33366 L
.38104 .33366 L
.38104 .33366 L
.38105 .33366 L
.38106 .33366 L
.38106 .33366 L
.38106 .33366 L
.38107 .33366 L
.38106 .33366 L
.38106 .33366 L
.38106 .33366 L
.38105 .33366 L
.38104 .33366 L
.38104 .33366 L
.38102 .33366 L
.38101 .33366 L
.381 .33366 L
.38098 .33366 L
.38096 .33366 L
.38095 .33366 L
.38092 .33366 L
.3809 .33366 L
.38088 .33366 L
s
.40468 .33366 m
.40471 .33366 L
.40473 .33366 L
.40475 .33366 L
.40477 .33366 L
.40479 .33366 L
.4048 .33366 L
.40482 .33366 L
.40483 .33366 L
.40484 .33366 L
.40485 .33366 L
.40486 .33366 L
.40486 .33366 L
.40487 .33366 L
.40487 .33366 L
.40487 .33366 L
.40487 .33366 L
.40487 .33366 L
.40486 .33366 L
.40486 .33366 L
.40485 .33366 L
.40484 .33366 L
.40483 .33366 L
.40482 .33366 L
.4048 .33366 L
.40479 .33366 L
.40477 .33366 L
.40475 .33366 L
.40473 .33366 L
.40471 .33366 L
.40468 .33366 L
s
.42849 .33366 m
.42851 .33366 L
.42853 .33366 L
.42855 .33366 L
.42857 .33366 L
.42859 .33366 L
.42861 .33366 L
.42862 .33366 L
.42863 .33366 L
.42865 .33366 L
.42865 .33366 L
.42866 .33366 L
.42867 .33366 L
.42867 .33366 L
.42867 .33366 L
.42868 .33366 L
.42867 .33366 L
.42867 .33366 L
.42867 .33366 L
.42866 .33366 L
.42865 .33366 L
.42865 .33366 L
.42863 .33366 L
.42862 .33366 L
.42861 .33366 L
.42859 .33366 L
.42857 .33366 L
.42855 .33366 L
.42853 .33366 L
.42851 .33366 L
.42849 .33366 L
s
.45229 .33366 m
.45232 .33366 L
.45234 .33366 L
.45236 .33366 L
.45238 .33366 L
.4524 .33366 L
.45241 .33366 L
.45243 .33366 L
.45244 .33366 L
.45245 .33366 L
.45246 .33366 L
.45247 .33366 L
.45247 .33366 L
.45248 .33366 L
.45248 .33366 L
.45248 .33366 L
.45248 .33366 L
.45248 .33366 L
.45247 .33366 L
.45247 .33366 L
.45246 .33366 L
.45245 .33366 L
.45244 .33366 L
.45243 .33366 L
.45241 .33366 L
.4524 .33366 L
.45238 .33366 L
.45236 .33366 L
.45234 .33366 L
.45232 .33366 L
.45229 .33366 L
s
.4761 .33366 m
.47612 .33366 L
.47614 .33366 L
.47616 .33366 L
.47618 .33366 L
.4762 .33366 L
.47622 .33366 L
.47623 .33366 L
.47624 .33366 L
.47626 .33366 L
.47626 .33366 L
.47627 .33366 L
.47628 .33366 L
.47628 .33366 L
.47628 .33366 L
.47629 .33366 L
.47628 .33366 L
.47628 .33366 L
.47628 .33366 L
.47627 .33366 L
.47626 .33366 L
.47626 .33366 L
.47624 .33366 L
.47623 .33366 L
.47622 .33366 L
.4762 .33366 L
.47618 .33366 L
.47616 .33366 L
.47614 .33366 L
.47612 .33366 L
.4761 .33366 L
s
.50087 .33366 m
.50077 .33366 L
.50068 .33366 L
.50059 .33366 L
.50051 .33366 L
.50044 .33366 L
.50037 .33366 L
.50031 .33366 L
.50026 .33366 L
.50022 .33366 L
.50018 .33366 L
.50015 .33366 L
.50012 .33366 L
.5001 .33366 L
.50009 .33366 L
.50009 .33366 L
.50009 .33366 L
.5001 .33366 L
.50012 .33366 L
.50015 .33366 L
.50018 .33366 L
.50022 .33366 L
.50026 .33366 L
.50031 .33366 L
.50037 .33366 L
.50044 .33366 L
.50051 .33366 L
.50059 .33366 L
.50068 .33366 L
.50077 .33366 L
.50087 .33366 L
s
.52467 .33366 m
.52457 .33366 L
.52447 .33366 L
.52439 .33366 L
.52431 .33366 L
.52424 .33366 L
.52417 .33366 L
.52411 .33366 L
.52406 .33366 L
.52402 .33366 L
.52398 .33366 L
.52395 .33366 L
.52393 .33366 L
.52391 .33366 L
.5239 .33366 L
.5239 .33366 L
.5239 .33366 L
.52391 .33366 L
.52393 .33366 L
.52395 .33366 L
.52398 .33366 L
.52402 .33366 L
.52406 .33366 L
.52411 .33366 L
.52417 .33366 L
.52424 .33366 L
.52431 .33366 L
.52439 .33366 L
.52447 .33366 L
.52457 .33366 L
.52467 .33366 L
s
.54846 .33366 m
.54836 .33366 L
.54827 .33366 L
.54819 .33366 L
.54811 .33366 L
.54804 .33366 L
.54797 .33366 L
.54792 .33366 L
.54787 .33366 L
.54782 .33366 L
.54778 .33366 L
.54775 .33366 L
.54773 .33366 L
.54771 .33366 L
.5477 .33366 L
.5477 .33366 L
.5477 .33366 L
.54771 .33366 L
.54773 .33366 L
.54775 .33366 L
.54778 .33366 L
.54782 .33366 L
.54787 .33366 L
.54792 .33366 L
.54797 .33366 L
.54804 .33366 L
.54811 .33366 L
.54819 .33366 L
.54827 .33366 L
.54836 .33366 L
.54846 .33366 L
s
.57225 .33366 m
.57216 .33366 L
.57207 .33366 L
.57198 .33366 L
.57191 .33366 L
.57184 .33366 L
.57177 .33366 L
.57172 .33366 L
.57167 .33366 L
.57163 .33366 L
.57159 .33366 L
.57156 .33366 L
.57154 .33366 L
.57152 .33366 L
.57151 .33366 L
.57151 .33366 L
.57151 .33366 L
.57152 .33366 L
.57154 .33366 L
.57156 .33366 L
.57159 .33366 L
.57163 .33366 L
.57167 .33366 L
.57172 .33366 L
.57177 .33366 L
.57184 .33366 L
.57191 .33366 L
.57198 .33366 L
.57207 .33366 L
.57216 .33366 L
.57225 .33366 L
s
.59701 .33366 m
.59679 .33366 L
.59659 .33366 L
.5964 .33366 L
.59622 .33366 L
.59607 .33366 L
.59592 .33366 L
.59579 .33366 L
.59568 .33366 L
.59558 .33366 L
.5955 .33366 L
.59543 .33366 L
.59538 .33366 L
.59534 .33366 L
.59532 .33366 L
.59531 .33366 L
.59532 .33366 L
.59534 .33366 L
.59538 .33366 L
.59543 .33366 L
.5955 .33366 L
.59558 .33366 L
.59568 .33366 L
.59579 .33366 L
.59592 .33366 L
.59607 .33366 L
.59622 .33366 L
.5964 .33366 L
.59659 .33366 L
.59679 .33366 L
.59701 .33366 L
s
.62077 .33366 m
.62056 .33366 L
.62036 .33366 L
.62018 .33366 L
.62001 .33366 L
.61985 .33366 L
.61971 .33366 L
.61959 .33366 L
.61948 .33366 L
.61938 .33366 L
.6193 .33366 L
.61923 .33366 L
.61918 .33366 L
.61915 .33366 L
.61912 .33366 L
.61912 .33366 L
.61912 .33366 L
.61915 .33366 L
.61918 .33366 L
.61923 .33366 L
.6193 .33366 L
.61938 .33366 L
.61948 .33366 L
.61959 .33366 L
.61971 .33366 L
.61985 .33366 L
.62001 .33366 L
.62018 .33366 L
.62036 .33366 L
.62056 .33366 L
.62077 .33366 L
s
.64454 .33366 m
.64433 .33366 L
.64413 .33366 L
.64396 .33366 L
.64379 .33366 L
.64364 .33366 L
.6435 .33366 L
.64338 .33366 L
.64327 .33366 L
.64318 .33366 L
.6431 .33366 L
.64304 .33366 L
.64299 .33366 L
.64295 .33366 L
.64293 .33366 L
.64292 .33366 L
.64293 .33366 L
.64295 .33366 L
.64299 .33366 L
.64304 .33366 L
.6431 .33366 L
.64318 .33366 L
.64327 .33366 L
.64338 .33366 L
.6435 .33366 L
.64364 .33366 L
.64379 .33366 L
.64396 .33366 L
.64413 .33366 L
.64433 .33366 L
.64454 .33366 L
s
.6683 .33366 m
.6681 .33366 L
.66791 .33366 L
.66773 .33366 L
.66757 .33366 L
.66743 .33366 L
.66729 .33366 L
.66717 .33366 L
.66707 .33366 L
.66698 .33366 L
.6669 .33366 L
.66684 .33366 L
.66679 .33366 L
.66675 .33366 L
.66673 .33366 L
.66673 .33366 L
.66673 .33366 L
.66675 .33366 L
.66679 .33366 L
.66684 .33366 L
.6669 .33366 L
.66698 .33366 L
.66707 .33366 L
.66717 .33366 L
.66729 .33366 L
.66743 .33366 L
.66757 .33366 L
.66773 .33366 L
.66791 .33366 L
.6681 .33366 L
.6683 .33366 L
s
.69207 .33366 m
.69187 .33366 L
.69168 .33366 L
.69151 .33366 L
.69136 .33366 L
.69121 .33366 L
.69108 .33366 L
.69097 .33366 L
.69086 .33366 L
.69078 .33366 L
.6907 .33366 L
.69064 .33366 L
.69059 .33366 L
.69056 .33366 L
.69054 .33366 L
.69053 .33366 L
.69054 .33366 L
.69056 .33366 L
.69059 .33366 L
.69064 .33366 L
.6907 .33366 L
.69078 .33366 L
.69086 .33366 L
.69097 .33366 L
.69108 .33366 L
.69121 .33366 L
.69136 .33366 L
.69151 .33366 L
.69168 .33366 L
.69187 .33366 L
.69207 .33366 L
s
.71583 .33366 m
.71564 .33366 L
.71546 .33366 L
.71529 .33366 L
.71514 .33366 L
.715 .33366 L
.71487 .33366 L
.71476 .33366 L
.71466 .33366 L
.71457 .33366 L
.7145 .33366 L
.71444 .33366 L
.7144 .33366 L
.71436 .33366 L
.71434 .33366 L
.71434 .33366 L
.71434 .33366 L
.71436 .33366 L
.7144 .33366 L
.71444 .33366 L
.7145 .33366 L
.71457 .33366 L
.71466 .33366 L
.71476 .33366 L
.71487 .33366 L
.715 .33366 L
.71514 .33366 L
.71529 .33366 L
.71546 .33366 L
.71564 .33366 L
.71583 .33366 L
s
.73959 .33366 m
.73941 .33366 L
.73923 .33366 L
.73907 .33366 L
.73892 .33366 L
.73879 .33366 L
.73866 .33366 L
.73855 .33366 L
.73846 .33366 L
.73837 .33366 L
.7383 .33366 L
.73824 .33366 L
.7382 .33366 L
.73817 .33366 L
.73815 .33366 L
.73814 .33366 L
.73815 .33366 L
.73817 .33366 L
.7382 .33366 L
.73824 .33366 L
.7383 .33366 L
.73837 .33366 L
.73846 .33366 L
.73855 .33366 L
.73866 .33366 L
.73879 .33366 L
.73892 .33366 L
.73907 .33366 L
.73923 .33366 L
.73941 .33366 L
.73959 .33366 L
s
.76336 .33366 m
.76318 .33366 L
.76301 .33366 L
.76285 .33366 L
.76271 .33366 L
.76257 .33366 L
.76245 .33366 L
.76235 .33366 L
.76225 .33366 L
.76217 .33366 L
.7621 .33366 L
.76205 .33366 L
.762 .33366 L
.76197 .33366 L
.76195 .33366 L
.76195 .33366 L
.76195 .33366 L
.76197 .33366 L
.762 .33366 L
.76205 .33366 L
.7621 .33366 L
.76217 .33366 L
.76225 .33366 L
.76235 .33366 L
.76245 .33366 L
.76257 .33366 L
.76271 .33366 L
.76285 .33366 L
.76301 .33366 L
.76318 .33366 L
.76336 .33366 L
s
.78712 .33366 m
.78695 .33366 L
.78678 .33366 L
.78663 .33366 L
.78649 .33366 L
.78636 .33366 L
.78624 .33366 L
.78614 .33366 L
.78605 .33366 L
.78597 .33366 L
.7859 .33366 L
.78585 .33366 L
.78581 .33366 L
.78577 .33366 L
.78576 .33366 L
.78575 .33366 L
.78576 .33366 L
.78577 .33366 L
.78581 .33366 L
.78585 .33366 L
.7859 .33366 L
.78597 .33366 L
.78605 .33366 L
.78614 .33366 L
.78624 .33366 L
.78636 .33366 L
.78649 .33366 L
.78663 .33366 L
.78678 .33366 L
.78695 .33366 L
.78712 .33366 L
s
.81089 .33366 m
.81071 .33366 L
.81056 .33366 L
.81041 .33366 L
.81027 .33366 L
.81015 .33366 L
.81003 .33366 L
.80993 .33366 L
.80985 .33366 L
.80977 .33366 L
.8097 .33366 L
.80965 .33366 L
.80961 .33366 L
.80958 .33366 L
.80956 .33366 L
.80956 .33366 L
.80956 .33366 L
.80958 .33366 L
.80961 .33366 L
.80965 .33366 L
.8097 .33366 L
.80977 .33366 L
.80985 .33366 L
.80993 .33366 L
.81003 .33366 L
.81015 .33366 L
.81027 .33366 L
.81041 .33366 L
.81056 .33366 L
.81071 .33366 L
.81089 .33366 L
s
.83465 .33366 m
.83448 .33366 L
.83433 .33366 L
.83419 .33366 L
.83405 .33366 L
.83393 .33366 L
.83382 .33366 L
.83373 .33366 L
.83364 .33366 L
.83357 .33366 L
.8335 .33366 L
.83345 .33366 L
.83341 .33366 L
.83338 .33366 L
.83337 .33366 L
.83336 .33366 L
.83337 .33366 L
.83338 .33366 L
.83341 .33366 L
.83345 .33366 L
.8335 .33366 L
.83357 .33366 L
.83364 .33366 L
.83373 .33366 L
.83382 .33366 L
.83393 .33366 L
.83405 .33366 L
.83419 .33366 L
.83433 .33366 L
.83448 .33366 L
.83465 .33366 L
s
.85841 .33366 m
.85825 .33366 L
.8581 .33366 L
.85797 .33366 L
.85784 .33366 L
.85772 .33366 L
.85762 .33366 L
.85752 .33366 L
.85744 .33366 L
.85737 .33366 L
.8573 .33366 L
.85725 .33366 L
.85722 .33366 L
.85719 .33366 L
.85717 .33366 L
.85717 .33366 L
.85717 .33366 L
.85719 .33366 L
.85722 .33366 L
.85725 .33366 L
.8573 .33366 L
.85737 .33366 L
.85744 .33366 L
.85752 .33366 L
.85762 .33366 L
.85772 .33366 L
.85784 .33366 L
.85797 .33366 L
.8581 .33366 L
.85825 .33366 L
.85841 .33366 L
s
.88218 .33366 m
.88202 .33366 L
.88188 .33366 L
.88174 .33366 L
.88162 .33366 L
.88151 .33366 L
.88141 .33366 L
.88131 .33366 L
.88123 .33366 L
.88116 .33366 L
.8811 .33366 L
.88106 .33366 L
.88102 .33366 L
.88099 .33366 L
.88098 .33366 L
.88097 .33366 L
.88098 .33366 L
.88099 .33366 L
.88102 .33366 L
.88106 .33366 L
.8811 .33366 L
.88116 .33366 L
.88123 .33366 L
.88131 .33366 L
.88141 .33366 L
.88151 .33366 L
.88162 .33366 L
.88174 .33366 L
.88188 .33366 L
.88202 .33366 L
.88218 .33366 L
s
.90594 .33366 m
.90579 .33366 L
.90565 .33366 L
.90552 .33366 L
.9054 .33366 L
.90529 .33366 L
.9052 .33366 L
.90511 .33366 L
.90503 .33366 L
.90496 .33366 L
.90491 .33366 L
.90486 .33366 L
.90482 .33366 L
.9048 .33366 L
.90478 .33366 L
.90478 .33366 L
.90478 .33366 L
.9048 .33366 L
.90482 .33366 L
.90486 .33366 L
.90491 .33366 L
.90496 .33366 L
.90503 .33366 L
.90511 .33366 L
.9052 .33366 L
.90529 .33366 L
.9054 .33366 L
.90552 .33366 L
.90565 .33366 L
.90579 .33366 L
.90594 .33366 L
s
.92971 .33366 m
.92956 .33366 L
.92943 .33366 L
.9293 .33366 L
.92919 .33366 L
.92908 .33366 L
.92899 .33366 L
.9289 .33366 L
.92883 .33366 L
.92876 .33366 L
.92871 .33366 L
.92866 .33366 L
.92863 .33366 L
.9286 .33366 L
.92859 .33366 L
.92858 .33366 L
.92859 .33366 L
.9286 .33366 L
.92863 .33366 L
.92866 .33366 L
.92871 .33366 L
.92876 .33366 L
.92883 .33366 L
.9289 .33366 L
.92899 .33366 L
.92908 .33366 L
.92919 .33366 L
.9293 .33366 L
.92943 .33366 L
.92956 .33366 L
.92971 .33366 L
s
.95347 .33366 m
.95333 .33366 L
.9532 .33366 L
.95308 .33366 L
.95297 .33366 L
.95287 .33366 L
.95278 .33366 L
.95269 .33366 L
.95262 .33366 L
.95256 .33366 L
.95251 .33366 L
.95246 .33366 L
.95243 .33366 L
.9524 .33366 L
.95239 .33366 L
.95239 .33366 L
.95239 .33366 L
.9524 .33366 L
.95243 .33366 L
.95246 .33366 L
.95251 .33366 L
.95256 .33366 L
.95262 .33366 L
.95269 .33366 L
.95278 .33366 L
.95287 .33366 L
.95297 .33366 L
.95308 .33366 L
.9532 .33366 L
.95333 .33366 L
.95347 .33366 L
s
0 0 0 r
.02399 .33366 m
.50009 .33366 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
.50009 .33366 m
.59531 .33366 L
s
% Start of user PostScript
50. 0 60. 0 MAarrowhead1
% End of user PostScript
.59531 .33366 m
.97619 .33366 L
s
% Start of user PostScript
60. 0 100. 0 MAarrowhead1
% End of user PostScript
.97619 .33366 m
.97619 .33366 L
s
% Start of user PostScript
100. 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .24796 m
.02383 .25368 L
.02385 .25939 L
.02387 .2651 L
.02389 .27082 L
.02391 .27653 L
.02393 .28224 L
.02394 .28796 L
.02395 .29367 L
.02396 .29938 L
.02397 .3051 L
.02398 .31081 L
.02398 .31652 L
.02399 .32224 L
.02399 .32795 L
.02399 .33366 L
.02399 .33938 L
.02399 .34509 L
.02398 .3508 L
.02398 .35651 L
.02397 .36223 L
.02396 .36794 L
.02395 .37365 L
.02394 .37937 L
.02393 .38508 L
.02391 .39079 L
.02389 .39651 L
.02387 .40222 L
.02385 .40793 L
.02383 .41365 L
.02381 .41936 L
s
.04761 .24791 m
.04764 .25363 L
.04766 .25934 L
.04768 .26506 L
.0477 .27078 L
.04772 .27649 L
.04773 .28221 L
.04774 .28793 L
.04776 .29364 L
.04777 .29936 L
.04778 .30508 L
.04778 .31079 L
.04779 .31651 L
.04779 .32223 L
.04779 .32795 L
.0478 .33366 L
.04779 .33938 L
.04779 .3451 L
.04779 .35081 L
.04778 .35653 L
.04778 .36225 L
.04777 .36796 L
.04776 .37368 L
.04774 .3794 L
.04773 .38511 L
.04772 .39083 L
.0477 .39655 L
.04768 .40226 L
.04766 .40798 L
.04764 .4137 L
.04761 .41941 L
s
.07142 .24786 m
.07144 .25358 L
.07146 .2593 L
.07148 .26502 L
.0715 .27074 L
.07152 .27646 L
.07154 .28218 L
.07155 .2879 L
.07156 .29362 L
.07157 .29934 L
.07158 .30506 L
.07159 .31078 L
.07159 .3165 L
.0716 .32222 L
.0716 .32794 L
.0716 .33366 L
.0716 .33938 L
.0716 .3451 L
.07159 .35082 L
.07159 .35654 L
.07158 .36226 L
.07157 .36798 L
.07156 .3737 L
.07155 .37942 L
.07154 .38514 L
.07152 .39087 L
.0715 .39659 L
.07148 .40231 L
.07146 .40803 L
.07144 .41375 L
.07142 .41947 L
s
.09522 .2478 m
.09525 .25353 L
.09527 .25925 L
.09529 .26497 L
.09531 .2707 L
.09533 .27642 L
.09534 .28215 L
.09535 .28787 L
.09537 .29359 L
.09538 .29932 L
.09539 .30504 L
.09539 .31077 L
.0954 .31649 L
.0954 .32221 L
.0954 .32794 L
.09541 .33366 L
.0954 .33939 L
.0954 .34511 L
.0954 .35083 L
.09539 .35656 L
.09539 .36228 L
.09538 .36801 L
.09537 .37373 L
.09535 .37945 L
.09534 .38518 L
.09533 .3909 L
.09531 .39662 L
.09529 .40235 L
.09527 .40807 L
.09525 .4138 L
.09522 .41952 L
s
.11903 .24775 m
.11905 .25348 L
.11907 .2592 L
.11909 .26493 L
.11911 .27066 L
.11913 .27639 L
.11915 .28211 L
.11916 .28784 L
.11917 .29357 L
.11918 .2993 L
.11919 .30502 L
.1192 .31075 L
.1192 .31648 L
.11921 .32221 L
.11921 .32793 L
.11921 .33366 L
.11921 .33939 L
.11921 .34512 L
.1192 .35084 L
.1192 .35657 L
.11919 .3623 L
.11918 .36803 L
.11917 .37375 L
.11916 .37948 L
.11915 .38521 L
.11913 .39094 L
.11911 .39666 L
.11909 .40239 L
.11907 .40812 L
.11905 .41385 L
.11903 .41957 L
s
.14283 .2477 m
.14286 .25343 L
.14288 .25916 L
.1429 .26489 L
.14292 .27062 L
.14293 .27635 L
.14295 .28208 L
.14296 .28781 L
.14298 .29354 L
.14299 .29928 L
.143 .30501 L
.143 .31074 L
.14301 .31647 L
.14301 .3222 L
.14301 .32793 L
.14302 .33366 L
.14301 .33939 L
.14301 .34512 L
.14301 .35085 L
.143 .35659 L
.143 .36232 L
.14299 .36805 L
.14298 .37378 L
.14296 .37951 L
.14295 .38524 L
.14293 .39097 L
.14292 .3967 L
.1429 .40243 L
.14288 .40817 L
.14286 .4139 L
.14283 .41963 L
s
.16664 .24764 m
.16666 .25338 L
.16668 .25911 L
.1667 .26485 L
.16672 .27058 L
.16674 .27632 L
.16676 .28205 L
.16677 .28778 L
.16678 .29352 L
.16679 .29925 L
.1668 .30499 L
.16681 .31072 L
.16681 .31646 L
.16682 .32219 L
.16682 .32793 L
.16682 .33366 L
.16682 .3394 L
.16682 .34513 L
.16681 .35087 L
.16681 .3566 L
.1668 .36233 L
.16679 .36807 L
.16678 .3738 L
.16677 .37954 L
.16676 .38527 L
.16674 .39101 L
.16672 .39674 L
.1667 .40248 L
.16668 .40821 L
.16666 .41395 L
.16664 .41968 L
s
.19044 .24759 m
.19047 .25333 L
.19049 .25907 L
.19051 .2648 L
.19053 .27054 L
.19054 .27628 L
.19056 .28202 L
.19057 .28776 L
.19059 .29349 L
.1906 .29923 L
.19061 .30497 L
.19061 .31071 L
.19062 .31645 L
.19062 .32219 L
.19062 .32792 L
.19063 .33366 L
.19062 .3394 L
.19062 .34514 L
.19062 .35088 L
.19061 .35661 L
.19061 .36235 L
.1906 .36809 L
.19059 .37383 L
.19057 .37957 L
.19056 .38531 L
.19054 .39104 L
.19053 .39678 L
.19051 .40252 L
.19049 .40826 L
.19047 .414 L
.19044 .41973 L
s
.21425 .24754 m
.21427 .25328 L
.21429 .25902 L
.21431 .26476 L
.21433 .2705 L
.21435 .27624 L
.21437 .28199 L
.21438 .28773 L
.21439 .29347 L
.2144 .29921 L
.21441 .30495 L
.21442 .31069 L
.21442 .31644 L
.21443 .32218 L
.21443 .32792 L
.21443 .33366 L
.21443 .3394 L
.21443 .34515 L
.21442 .35089 L
.21442 .35663 L
.21441 .36237 L
.2144 .36811 L
.21439 .37385 L
.21438 .3796 L
.21437 .38534 L
.21435 .39108 L
.21433 .39682 L
.21431 .40256 L
.21429 .4083 L
.21427 .41405 L
.21425 .41979 L
s
.23805 .24748 m
.23808 .25323 L
.2381 .25897 L
.23812 .26472 L
.23814 .27046 L
.23815 .27621 L
.23817 .28195 L
.23818 .2877 L
.2382 .29344 L
.23821 .29919 L
.23822 .30494 L
.23822 .31068 L
.23823 .31643 L
.23823 .32217 L
.23823 .32792 L
.23824 .33366 L
.23823 .33941 L
.23823 .34515 L
.23823 .3509 L
.23822 .35664 L
.23822 .36239 L
.23821 .36813 L
.2382 .37388 L
.23818 .37962 L
.23817 .38537 L
.23815 .39112 L
.23814 .39686 L
.23812 .40261 L
.2381 .40835 L
.23808 .4141 L
.23805 .41984 L
s
.26186 .24743 m
.26188 .25318 L
.2619 .25893 L
.26192 .26467 L
.26194 .27042 L
.26196 .27617 L
.26198 .28192 L
.26199 .28767 L
.262 .29342 L
.26201 .29917 L
.26202 .30492 L
.26203 .31067 L
.26203 .31642 L
.26204 .32216 L
.26204 .32791 L
.26204 .33366 L
.26204 .33941 L
.26204 .34516 L
.26203 .35091 L
.26203 .35666 L
.26202 .36241 L
.26201 .36816 L
.262 .3739 L
.26199 .37965 L
.26198 .3854 L
.26196 .39115 L
.26194 .3969 L
.26192 .40265 L
.2619 .4084 L
.26188 .41415 L
.26186 .4199 L
s
.28566 .24737 m
.28569 .25313 L
.28571 .25888 L
.28573 .26463 L
.28575 .27038 L
.28576 .27614 L
.28578 .28189 L
.28579 .28764 L
.28581 .29339 L
.28582 .29915 L
.28583 .3049 L
.28583 .31065 L
.28584 .3164 L
.28584 .32216 L
.28584 .32791 L
.28585 .33366 L
.28584 .33941 L
.28584 .34517 L
.28584 .35092 L
.28583 .35667 L
.28583 .36242 L
.28582 .36818 L
.28581 .37393 L
.28579 .37968 L
.28578 .38543 L
.28576 .39119 L
.28575 .39694 L
.28573 .40269 L
.28571 .40844 L
.28569 .4142 L
.28566 .41995 L
s
.30947 .24732 m
.30949 .25308 L
.30951 .25883 L
.30953 .26459 L
.30955 .27035 L
.30957 .2761 L
.30958 .28186 L
.3096 .28761 L
.30961 .29337 L
.30962 .29913 L
.30963 .30488 L
.30964 .31064 L
.30964 .31639 L
.30965 .32215 L
.30965 .32791 L
.30965 .33366 L
.30965 .33942 L
.30965 .34517 L
.30964 .35093 L
.30964 .35669 L
.30963 .36244 L
.30962 .3682 L
.30961 .37395 L
.3096 .37971 L
.30958 .38547 L
.30957 .39122 L
.30955 .39698 L
.30953 .40273 L
.30951 .40849 L
.30949 .41425 L
.30947 .42 L
s
.33327 .24727 m
.3333 .25303 L
.33332 .25879 L
.33334 .26455 L
.33336 .27031 L
.33337 .27607 L
.33339 .28183 L
.3334 .28758 L
.33342 .29334 L
.33343 .2991 L
.33344 .30486 L
.33344 .31062 L
.33345 .31638 L
.33345 .32214 L
.33345 .3279 L
.33346 .33366 L
.33345 .33942 L
.33345 .34518 L
.33345 .35094 L
.33344 .3567 L
.33344 .36246 L
.33343 .36822 L
.33342 .37398 L
.3334 .37974 L
.33339 .3855 L
.33337 .39126 L
.33336 .39702 L
.33334 .40278 L
.33332 .40854 L
.3333 .4143 L
.33327 .42006 L
s
.35708 .24721 m
.3571 .25298 L
.35712 .25874 L
.35714 .2645 L
.35716 .27027 L
.35718 .27603 L
.35719 .28179 L
.35721 .28756 L
.35722 .29332 L
.35723 .29908 L
.35724 .30485 L
.35725 .31061 L
.35725 .31637 L
.35726 .32214 L
.35726 .3279 L
.35726 .33366 L
.35726 .33943 L
.35726 .34519 L
.35725 .35095 L
.35725 .35671 L
.35724 .36248 L
.35723 .36824 L
.35722 .374 L
.35721 .37977 L
.35719 .38553 L
.35718 .39129 L
.35716 .39706 L
.35714 .40282 L
.35712 .40858 L
.3571 .41435 L
.35708 .42011 L
s
.38088 .24716 m
.38091 .25293 L
.38093 .25869 L
.38095 .26446 L
.38097 .27023 L
.38098 .27599 L
.381 .28176 L
.38101 .28753 L
.38103 .29329 L
.38104 .29906 L
.38105 .30483 L
.38105 .31059 L
.38106 .31636 L
.38106 .32213 L
.38106 .3279 L
.38107 .33366 L
.38106 .33943 L
.38106 .3452 L
.38106 .35096 L
.38105 .35673 L
.38105 .3625 L
.38104 .36826 L
.38103 .37403 L
.38101 .3798 L
.381 .38556 L
.38098 .39133 L
.38097 .3971 L
.38095 .40286 L
.38093 .40863 L
.38091 .4144 L
.38088 .42016 L
s
.40469 .24711 m
.40471 .25288 L
.40473 .25865 L
.40475 .26442 L
.40477 .27019 L
.40479 .27596 L
.4048 .28173 L
.40482 .2875 L
.40483 .29327 L
.40484 .29904 L
.40485 .30481 L
.40486 .31058 L
.40486 .31635 L
.40487 .32212 L
.40487 .32789 L
.40487 .33366 L
.40487 .33943 L
.40487 .3452 L
.40486 .35097 L
.40486 .35674 L
.40485 .36251 L
.40484 .36828 L
.40483 .37405 L
.40482 .37982 L
.4048 .38559 L
.40479 .39137 L
.40477 .39714 L
.40475 .40291 L
.40473 .40868 L
.40471 .41445 L
.40469 .42022 L
s
.42849 .24705 m
.42852 .25283 L
.42854 .2586 L
.42856 .26438 L
.42858 .27015 L
.42859 .27592 L
.42861 .2817 L
.42862 .28747 L
.42864 .29324 L
.42865 .29902 L
.42866 .30479 L
.42866 .31057 L
.42867 .31634 L
.42867 .32211 L
.42867 .32789 L
.42868 .33366 L
.42867 .33944 L
.42867 .34521 L
.42867 .35098 L
.42866 .35676 L
.42866 .36253 L
.42865 .36831 L
.42864 .37408 L
.42862 .37985 L
.42861 .38563 L
.42859 .3914 L
.42858 .39717 L
.42856 .40295 L
.42854 .40872 L
.42852 .4145 L
.42849 .42027 L
s
.4523 .247 m
.45232 .25278 L
.45234 .25855 L
.45236 .26433 L
.45238 .27011 L
.4524 .27589 L
.45241 .28166 L
.45243 .28744 L
.45244 .29322 L
.45245 .299 L
.45246 .30477 L
.45247 .31055 L
.45247 .31633 L
.45248 .32211 L
.45248 .32788 L
.45248 .33366 L
.45248 .33944 L
.45248 .34522 L
.45247 .35099 L
.45247 .35677 L
.45246 .36255 L
.45245 .36833 L
.45244 .3741 L
.45243 .37988 L
.45241 .38566 L
.4524 .39144 L
.45238 .39721 L
.45236 .40299 L
.45234 .40877 L
.45232 .41455 L
.4523 .42032 L
s
.4761 .24695 m
.47613 .25273 L
.47615 .25851 L
.47617 .26429 L
.47619 .27007 L
.4762 .27585 L
.47622 .28163 L
.47623 .28741 L
.47625 .29319 L
.47626 .29898 L
.47627 .30476 L
.47627 .31054 L
.47628 .31632 L
.47628 .3221 L
.47628 .32788 L
.47629 .33366 L
.47628 .33944 L
.47628 .34522 L
.47628 .351 L
.47627 .35679 L
.47627 .36257 L
.47626 .36835 L
.47625 .37413 L
.47623 .37991 L
.47622 .38569 L
.4762 .39147 L
.47619 .39725 L
.47617 .40303 L
.47615 .40882 L
.47613 .4146 L
.4761 .42038 L
s
.50001 .24689 m
.50002 .25268 L
.50003 .25846 L
.50004 .26425 L
.50005 .27003 L
.50006 .27582 L
.50006 .2816 L
.50007 .28738 L
.50007 .29317 L
.50008 .29895 L
.50008 .30474 L
.50008 .31052 L
.50009 .31631 L
.50009 .32209 L
.50009 .32788 L
.50009 .33366 L
.50009 .33945 L
.50009 .34523 L
.50009 .35102 L
.50008 .3568 L
.50008 .36258 L
.50008 .36837 L
.50007 .37415 L
.50007 .37994 L
.50006 .38572 L
.50006 .39151 L
.50005 .39729 L
.50004 .40308 L
.50003 .40886 L
.50002 .41465 L
.50001 .42043 L
s
.52382 .24686 m
.52383 .25264 L
.52384 .25843 L
.52384 .26422 L
.52385 .27001 L
.52386 .27579 L
.52387 .28158 L
.52387 .28737 L
.52388 .29315 L
.52388 .29894 L
.52389 .30473 L
.52389 .31051 L
.52389 .3163 L
.52389 .32209 L
.5239 .32787 L
.5239 .33366 L
.5239 .33945 L
.52389 .34524 L
.52389 .35102 L
.52389 .35681 L
.52389 .3626 L
.52388 .36838 L
.52388 .37417 L
.52387 .37996 L
.52387 .38574 L
.52386 .39153 L
.52385 .39732 L
.52384 .40311 L
.52384 .40889 L
.52383 .41468 L
.52382 .42047 L
s
.54762 .24682 m
.54763 .25261 L
.54764 .2584 L
.54765 .26419 L
.54766 .26998 L
.54767 .27577 L
.54767 .28156 L
.54768 .28735 L
.54768 .29314 L
.54769 .29893 L
.54769 .30472 L
.54769 .3105 L
.5477 .31629 L
.5477 .32208 L
.5477 .32787 L
.5477 .33366 L
.5477 .33945 L
.5477 .34524 L
.5477 .35103 L
.54769 .35682 L
.54769 .36261 L
.54769 .3684 L
.54768 .37419 L
.54768 .37998 L
.54767 .38577 L
.54767 .39155 L
.54766 .39734 L
.54765 .40313 L
.54764 .40892 L
.54763 .41471 L
.54762 .4205 L
s
.57143 .24679 m
.57144 .25258 L
.57145 .25837 L
.57145 .26416 L
.57146 .26995 L
.57147 .27575 L
.57148 .28154 L
.57148 .28733 L
.57149 .29312 L
.57149 .29891 L
.5715 .3047 L
.5715 .3105 L
.5715 .31629 L
.5715 .32208 L
.57151 .32787 L
.57151 .33366 L
.57151 .33945 L
.5715 .34525 L
.5715 .35104 L
.5715 .35683 L
.5715 .36262 L
.57149 .36841 L
.57149 .3742 L
.57148 .38 L
.57148 .38579 L
.57147 .39158 L
.57146 .39737 L
.57145 .40316 L
.57145 .40895 L
.57144 .41475 L
.57143 .42054 L
s
.59513 .24675 m
.59515 .25255 L
.59517 .25834 L
.59519 .26413 L
.59521 .26993 L
.59523 .27572 L
.59524 .28152 L
.59526 .28731 L
.59527 .2931 L
.59528 .2989 L
.59529 .30469 L
.5953 .31049 L
.5953 .31628 L
.59531 .32207 L
.59531 .32787 L
.59531 .33366 L
.59531 .33946 L
.59531 .34525 L
.5953 .35104 L
.5953 .35684 L
.59529 .36263 L
.59528 .36843 L
.59527 .37422 L
.59526 .38001 L
.59524 .38581 L
.59523 .3916 L
.59521 .3974 L
.59519 .40319 L
.59517 .40898 L
.59515 .41478 L
.59513 .42057 L
s
.61893 .2467 m
.61896 .2525 L
.61898 .25829 L
.619 .26409 L
.61902 .26989 L
.61903 .27569 L
.61905 .28148 L
.61906 .28728 L
.61908 .29308 L
.61909 .29888 L
.6191 .30467 L
.6191 .31047 L
.61911 .31627 L
.61911 .32207 L
.61911 .32786 L
.61912 .33366 L
.61911 .33946 L
.61911 .34526 L
.61911 .35105 L
.6191 .35685 L
.6191 .36265 L
.61909 .36845 L
.61908 .37424 L
.61906 .38004 L
.61905 .38584 L
.61903 .39164 L
.61902 .39744 L
.619 .40323 L
.61898 .40903 L
.61896 .41483 L
.61893 .42063 L
s
.64274 .24664 m
.64276 .25245 L
.64278 .25825 L
.6428 .26405 L
.64282 .26985 L
.64284 .27565 L
.64285 .28145 L
.64287 .28725 L
.64288 .29305 L
.64289 .29885 L
.6429 .30466 L
.64291 .31046 L
.64291 .31626 L
.64292 .32206 L
.64292 .32786 L
.64292 .33366 L
.64292 .33946 L
.64292 .34526 L
.64291 .35107 L
.64291 .35687 L
.6429 .36267 L
.64289 .36847 L
.64288 .37427 L
.64287 .38007 L
.64285 .38587 L
.64284 .39167 L
.64282 .39747 L
.6428 .40328 L
.64278 .40908 L
.64276 .41488 L
.64274 .42068 L
s
.66654 .24659 m
.66657 .2524 L
.66659 .2582 L
.66661 .26401 L
.66663 .26981 L
.66664 .27561 L
.66666 .28142 L
.66667 .28722 L
.66669 .29303 L
.6667 .29883 L
.66671 .30464 L
.66671 .31044 L
.66672 .31625 L
.66672 .32205 L
.66672 .32786 L
.66673 .33366 L
.66672 .33947 L
.66672 .34527 L
.66672 .35108 L
.66671 .35688 L
.66671 .36269 L
.6667 .36849 L
.66669 .37429 L
.66667 .3801 L
.66666 .3859 L
.66664 .39171 L
.66663 .39751 L
.66661 .40332 L
.66659 .40912 L
.66657 .41493 L
.66654 .42073 L
s
.69035 .24654 m
.69037 .25235 L
.69039 .25815 L
.69041 .26396 L
.69043 .26977 L
.69045 .27558 L
.69046 .28139 L
.69048 .2872 L
.69049 .293 L
.6905 .29881 L
.69051 .30462 L
.69052 .31043 L
.69052 .31624 L
.69053 .32205 L
.69053 .32785 L
.69053 .33366 L
.69053 .33947 L
.69053 .34528 L
.69052 .35109 L
.69052 .3569 L
.69051 .3627 L
.6905 .36851 L
.69049 .37432 L
.69048 .38013 L
.69046 .38594 L
.69045 .39174 L
.69043 .39755 L
.69041 .40336 L
.69039 .40917 L
.69037 .41498 L
.69035 .42079 L
s
.71415 .24648 m
.71418 .2523 L
.7142 .25811 L
.71422 .26392 L
.71424 .26973 L
.71425 .27554 L
.71427 .28136 L
.71428 .28717 L
.7143 .29298 L
.71431 .29879 L
.71432 .3046 L
.71432 .31041 L
.71433 .31623 L
.71433 .32204 L
.71433 .32785 L
.71434 .33366 L
.71433 .33947 L
.71433 .34529 L
.71433 .3511 L
.71432 .35691 L
.71432 .36272 L
.71431 .36853 L
.7143 .37434 L
.71428 .38016 L
.71427 .38597 L
.71425 .39178 L
.71424 .39759 L
.71422 .4034 L
.7142 .40922 L
.71418 .41503 L
.71415 .42084 L
s
.73796 .24643 m
.73798 .25225 L
.738 .25806 L
.73802 .26388 L
.73804 .26969 L
.73806 .27551 L
.73807 .28132 L
.73809 .28714 L
.7381 .29295 L
.73811 .29877 L
.73812 .30458 L
.73813 .3104 L
.73813 .31622 L
.73814 .32203 L
.73814 .32785 L
.73814 .33366 L
.73814 .33948 L
.73814 .34529 L
.73813 .35111 L
.73813 .35692 L
.73812 .36274 L
.73811 .36855 L
.7381 .37437 L
.73809 .38019 L
.73807 .386 L
.73806 .39182 L
.73804 .39763 L
.73802 .40345 L
.738 .40926 L
.73798 .41508 L
.73796 .42089 L
s
.76176 .24638 m
.76178 .2522 L
.76181 .25801 L
.76183 .26383 L
.76185 .26965 L
.76186 .27547 L
.76188 .28129 L
.76189 .28711 L
.76191 .29293 L
.76192 .29875 L
.76193 .30457 L
.76193 .31039 L
.76194 .3162 L
.76194 .32202 L
.76194 .32784 L
.76195 .33366 L
.76194 .33948 L
.76194 .3453 L
.76194 .35112 L
.76193 .35694 L
.76193 .36276 L
.76192 .36858 L
.76191 .37439 L
.76189 .38021 L
.76188 .38603 L
.76186 .39185 L
.76185 .39767 L
.76183 .40349 L
.76181 .40931 L
.76178 .41513 L
.76176 .42095 L
s
.78557 .24632 m
.78559 .25215 L
.78561 .25797 L
.78563 .26379 L
.78565 .26961 L
.78567 .27544 L
.78568 .28126 L
.7857 .28708 L
.78571 .2929 L
.78572 .29873 L
.78573 .30455 L
.78574 .31037 L
.78574 .31619 L
.78575 .32202 L
.78575 .32784 L
.78575 .33366 L
.78575 .33948 L
.78575 .34531 L
.78574 .35113 L
.78574 .35695 L
.78573 .36277 L
.78572 .3686 L
.78571 .37442 L
.7857 .38024 L
.78568 .38607 L
.78567 .39189 L
.78565 .39771 L
.78563 .40353 L
.78561 .40936 L
.78559 .41518 L
.78557 .421 L
s
.80937 .24627 m
.80939 .2521 L
.80942 .25792 L
.80944 .26375 L
.80946 .26957 L
.80947 .2754 L
.80949 .28123 L
.8095 .28705 L
.80952 .29288 L
.80953 .2987 L
.80953 .30453 L
.80954 .31036 L
.80955 .31618 L
.80955 .32201 L
.80955 .32784 L
.80956 .33366 L
.80955 .33949 L
.80955 .34531 L
.80955 .35114 L
.80954 .35697 L
.80953 .36279 L
.80953 .36862 L
.80952 .37444 L
.8095 .38027 L
.80949 .3861 L
.80947 .39192 L
.80946 .39775 L
.80944 .40358 L
.80942 .4094 L
.80939 .41523 L
.80937 .42105 L
s
.83318 .24622 m
.8332 .25205 L
.83322 .25788 L
.83324 .26371 L
.83326 .26953 L
.83328 .27536 L
.83329 .28119 L
.83331 .28702 L
.83332 .29285 L
.83333 .29868 L
.83334 .30451 L
.83335 .31034 L
.83335 .31617 L
.83336 .322 L
.83336 .32783 L
.83336 .33366 L
.83336 .33949 L
.83336 .34532 L
.83335 .35115 L
.83335 .35698 L
.83334 .36281 L
.83333 .36864 L
.83332 .37447 L
.83331 .3803 L
.83329 .38613 L
.83328 .39196 L
.83326 .39779 L
.83324 .40362 L
.83322 .40945 L
.8332 .41528 L
.83318 .42111 L
s
.85698 .24616 m
.857 .252 L
.85703 .25783 L
.85705 .26366 L
.85707 .2695 L
.85708 .27533 L
.8571 .28116 L
.85711 .287 L
.85713 .29283 L
.85714 .29866 L
.85714 .3045 L
.85715 .31033 L
.85716 .31616 L
.85716 .322 L
.85716 .32783 L
.85717 .33366 L
.85716 .3395 L
.85716 .34533 L
.85716 .35116 L
.85715 .35699 L
.85714 .36283 L
.85714 .36866 L
.85713 .37449 L
.85711 .38033 L
.8571 .38616 L
.85708 .39199 L
.85707 .39783 L
.85705 .40366 L
.85703 .40949 L
.857 .41533 L
.85698 .42116 L
s
.88079 .24611 m
.88081 .25195 L
.88083 .25778 L
.88085 .26362 L
.88087 .26946 L
.88089 .27529 L
.8809 .28113 L
.88092 .28697 L
.88093 .2928 L
.88094 .29864 L
.88095 .30448 L
.88096 .31031 L
.88096 .31615 L
.88097 .32199 L
.88097 .32782 L
.88097 .33366 L
.88097 .3395 L
.88097 .34534 L
.88096 .35117 L
.88096 .35701 L
.88095 .36285 L
.88094 .36868 L
.88093 .37452 L
.88092 .38036 L
.8809 .38619 L
.88089 .39203 L
.88087 .39787 L
.88085 .4037 L
.88083 .40954 L
.88081 .41538 L
.88079 .42121 L
s
.90459 .24606 m
.90461 .2519 L
.90464 .25774 L
.90466 .26358 L
.90468 .26942 L
.90469 .27526 L
.90471 .2811 L
.90472 .28694 L
.90474 .29278 L
.90475 .29862 L
.90475 .30446 L
.90476 .3103 L
.90477 .31614 L
.90477 .32198 L
.90477 .32782 L
.90478 .33366 L
.90477 .3395 L
.90477 .34534 L
.90477 .35118 L
.90476 .35702 L
.90475 .36286 L
.90475 .3687 L
.90474 .37454 L
.90472 .38039 L
.90471 .38623 L
.90469 .39207 L
.90468 .39791 L
.90466 .40375 L
.90464 .40959 L
.90461 .41543 L
.90459 .42127 L
s
.9284 .246 m
.92842 .25185 L
.92844 .25769 L
.92846 .26353 L
.92848 .26938 L
.9285 .27522 L
.92851 .28107 L
.92853 .28691 L
.92854 .29275 L
.92855 .2986 L
.92856 .30444 L
.92857 .31029 L
.92857 .31613 L
.92858 .32197 L
.92858 .32782 L
.92858 .33366 L
.92858 .33951 L
.92858 .34535 L
.92857 .35119 L
.92857 .35704 L
.92856 .36288 L
.92855 .36873 L
.92854 .37457 L
.92853 .38041 L
.92851 .38626 L
.9285 .3921 L
.92848 .39795 L
.92846 .40379 L
.92844 .40963 L
.92842 .41548 L
.9284 .42132 L
s
.9522 .24595 m
.95222 .2518 L
.95225 .25764 L
.95227 .26349 L
.95229 .26934 L
.9523 .27519 L
.95232 .28103 L
.95233 .28688 L
.95235 .29273 L
.95236 .29858 L
.95236 .30442 L
.95237 .31027 L
.95238 .31612 L
.95238 .32197 L
.95238 .32781 L
.95239 .33366 L
.95238 .33951 L
.95238 .34536 L
.95238 .3512 L
.95237 .35705 L
.95236 .3629 L
.95236 .36875 L
.95235 .37459 L
.95233 .38044 L
.95232 .38629 L
.9523 .39214 L
.95229 .39799 L
.95227 .40383 L
.95225 .40968 L
.95222 .41553 L
.9522 .42138 L
s
0 0 m
1 0 L
1 .62614 L
0 .62614 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[80]:=",
  ImageSize->{288, 180.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000]2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolEooooo`?o00002Ooo
ool00?oooooo5Oooool01?l0003oooooooooool00008ooooo`00oooooolHooooo`03o`000?oooooo
oooo00Kooooo003ooooooaKooooo0_l00009ooooo`00oooooolEooooo`03o`000?oooooooooo00Wo
oooo003ooooooaGooooo00Co0000oooooooooooo00002?ooool00?oooooo5_ooool3o`0000Sooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003ooooooaOooooo00?o0000ooooooooool01oooool00?oo
oooo5oooool00ol0003oooooooooo`07ooooo`00oooooolGooooo`03o`000?oooooooooo00Oooooo
003ooooooaOooooo00?o0000ooooooooool01oooool00?oooooo5oooool00ol0003oooooooooo`07
ooooo`00oooooolGooooo`03o`000?oooooooooo00Oooooo003ooooooaOooooo00?o0000oooooooo
ool01oooool00?oooooo5oooool00ol0003oooooooooo`07ooooo`00oooooolGooooo`03o`000?oo
oooooooo00Oooooo003ooooooaOooooo00?o0000ooooooooool01oooool00?oooooo5oooool00ol0
003oooooooooo`07ooooo`00oooooolGooooo`03o`000?oooooooooo00Oooooo003ooooooaOooooo
00?o0000ooooooooool01oooool00?oooooo5oooool00ol0003oooooooooo`07ooooo`00VOooool6
o`0007Oooooo00?o0000ooooooooool01oooool009[ooooo00Go0000ooooooooooooooooo`00001g
ooooo`03o`000?oooooooooo00Oooooo002Jooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool01oooool009[ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`07ooooo`00
V_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Oooooo002Jooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool01oooool009Wooooo0ol0001jooooo`03o`000?oooooo
oooo00Oooooo003ooooooaOooooo00?o0000ooooooooool01oooool00?oooooo5oooool00ol0003o
ooooooooo`07ooooo`00oooooolGooooo`03o`000?oooooooooo00Oooooo002Zooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool01oooool008oooooo7?l0001[ooooo`03o`000?oooooo
oooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0
003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00ko
Ogmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oo
oooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003ooooo
ooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o
0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?
ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Y
ooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmo
OomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03
o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl0
1omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?mo
OgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo
00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo
00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo
002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003ooooooooo
o`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000
ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?oooo
o`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomo
Ogl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`00
0?moOgooOgmo00koOgmo2ol0001[ooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?mo
OgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo
00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo
00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo
002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003ooooooooo
o`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000
ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo000Qoooo
ooKo2NX:2Oooool000Sooooo6Ol9jPY^ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomo
Ogl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`00
0?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo00Oooooo0008ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo0000
0_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool0
1oooool000Sooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_mo
OgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ
2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ogmoOomoOgl01?mo
Ogl00ol9jP[oOgmoogmoO`04ogmoO`04o`WZ2_moOgooOgmoo`0000;oOgmo00?o2NX:ogmoOomoOgl0
1?moOgl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_mo
OgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo00000_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?mo
Ogl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`04ogmoO`04o`WZ2_mo
OgooOgmoo`0000;oOgmo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`00
0?oooooooooo00Oooooo0008ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo0000
0_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool0
1oooool000Sooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_mo
OgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`03o`000003o`WZ2_l0
003o000000Co000000?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`07ooooo`002?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ogmoOomoOgl01?moOgl0
0ol9jP[oOgmoogmoO`04ogmoO`04o`WZ2_moOgooOgmoo`0000;oOgmo00?o2NX:ogmoOomoOgl01?mo
Ogl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgoo
Ogmo00CoOgmo00Co2NX:ogmoOomoOgoo00000_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl0
1?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`002?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`04ogmoO`04o`WZ2_moOgoo
Ogmoo`0000;oOgmo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo0008ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo00000_mo
Ogl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool01ooo
ool000Sooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_moOgoo
Ogmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_mo
OgooOgmo00CoOgmo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`07ooooo`002?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ogmoOomoOgl01?moOgl0
0ol9jP[oOgmoogmoO`04ogmoO`04o`WZ2_moOgooOgmoo`0000;oOgmo00?o2NX:ogmoOomoOgl01?mo
Ogl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgoo
Ogmo00CoOgmo00Co2NX:ogmoOomoOgoo00000_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl0
1?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`002?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`04ogmoO`04o`WZ2_moOgoo
Ogmoo`0000;oOgmo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo0008ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo00000_mo
Ogl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool01ooo
ool000Sooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_moOgoo
Ogmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_mo
OgooOgmo00CoOgmo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`07ooooo`002?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ogmoOomoOgl01?moOgl0
0ol9jP[oOgmoogmoO`04ogmoO`04o`WZ2_moOgooOgmoo`0000;oOgmo00?o2NX:ogmoOomoOgl01?mo
Ogl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgoo
Ogmo00CoOgmo00Co2NX:ogmoOomoOgoo00000_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`04ooooo`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl0
1?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`002?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooo
oooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`02ooooo`03o`000?l9jP[o
000000Gooooo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`04ogmoO`08o`WZ2_moOgoo
Ogmoo`000?moOgoo0000o`WZ2_l00005ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`02ooooo`03o`000?l9jP[o000000Gooooo00?o0000oooooooo
ool01oooool000Sooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o0000o`000003o`000003oooo
ool9jP[oOgmo00GoOgmo00?o2NX:ogmoOomoOgl01?moOgl01?l9jP[oOgmoogmoOol00002ogmoO`03
o`WZ2_l0003o000000?o000000?oOgmoo`WZ2_ooool01Oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:o`000?l000000ol000000ooooooo0000ooooo`08ooooo`00
2?ooool00ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l00000
0ol000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l00000
1?l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l00000
1?l000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l00000
1?l000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l00000
0ol000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l00000
1?l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l00000
1?l000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l00000
1?l000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l00000
0ol000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l00000
1?l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l00000
1?l000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l00000
1?l000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l00000
0ol000000ol9jP[o0000o`000005o`0000Wooooo0008ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:o`000?l000000_l00002ooooo`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?mo
Ogl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_l0003o000000;o00000_moOgl00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[ooooo
ooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[o0000
o`000002o`0000;ooooo00?o0000ooooooooool01oooool000Sooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00_oo
ool00ol0003o2NX:ooooo`05ooooo`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?mo
Ogl01ol9jP[oOgmoogmoOol0003oOgmoo`000?l9jPX01_moOgl00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00_ooool00ol0003o2NX:ooooo`05ooooo`03
o`000?oooooooooo00Oooooo0008ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo
00000_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000oooooooo
ool01oooool000Sooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl01?l9jP[oOgmoogmoOol00002ogmoO`03
o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`07ooooo`00
2?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ogmoOomoOgl0
1?moOgl00ol9jP[oOgmoogmoO`04ogmoO`04o`WZ2_moOgooOgmoo`0000;oOgmo00?o2NX:ogmoOomo
Ogl01?moOgl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ
2_moOgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo00000_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl0
1?moOgl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`04ogmoO`04o`WZ
2_moOgooOgmoo`0000;oOgmo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`000?oooooooooo00Oooooo0008ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo
00000_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000oooooooo
ool01oooool000Sooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl01?l9jP[oOgmoogmoOol00002ogmoO`03
o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`07ooooo`00
2?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ogmoOomoOgl0
1?moOgl00ol9jP[oOgmoogmoO`04ogmoO`04o`WZ2_moOgooOgmoo`0000;oOgmo00?o2NX:ogmoOomo
Ogl01?moOgl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ
2_moOgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo00000_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl0
1?moOgl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`04ogmoO`04o`WZ
2_moOgooOgmoo`0000;oOgmo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`000?oooooooooo00Oooooo0008ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo
00000_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000oooooooo
ool01oooool000Sooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl01?l9jP[oOgmoogmoOol00002ogmoO`03
o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`07ooooo`00
2?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ogmoOomoOgl0
1?moOgl00ol9jP[oOgmoogmoO`04ogmoO`04o`WZ2_moOgooOgmoo`0000;oOgmo00?o2NX:ogmoOomo
Ogl01?moOgl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ
2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl00ol000000ol9jP[o0000o`000004o`000003o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?mo
Ogl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oOgmoogmoO`04ogmoO`04o`WZ2_mo
OgooOgmoo`0000;oOgmo00?o2NX:ogmoOomoOgl01?moOgl00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`00
0?oooooooooo00Oooooo0008ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_moOgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo0000
0_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool0
1oooool000Sooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_mo
OgooOgmo00CoOgmo00?o2NX:ogmoOomoOgl01?moOgl01?l9jP[oOgmoogmoOol00002ogmoO`03o`WZ
2_moOgooOgmo00CoOgmo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ogmoOomoOgl01?mo
Ogl00ol9jP[oOgmoogmoO`04ogmoO`04o`WZ2_moOgooOgmoo`0000;oOgmo00?o2NX:ogmoOomoOgl0
1?moOgl00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ2_mo
OgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo00000_moOgl00ol9jP[oOgmoogmoO`04ogmoO`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ
2_oooooooooo00Cooooo00?o0000ooooooooool01oooool008oooooo00?o0000ogmoOomoOgl03_mo
Ogl00ol0003oOgmoogmoO`07ogmoO`03o`000?oooooooooo06Wooooo00?o0000ooooooooool01ooo
ool008oooooo00?o0000ogmoOomoOgl03_moOgl00ol0003oOgmoogmoO`07ogmoO`03o`000?oooooo
oooo06Wooooo00?o0000ooooooooool01oooool000Soooooool9jPX@o`WZ2PWooooo002?ooooo`03
o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl0
1omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?mo
OgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo
00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo
00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo
002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003ooooooooo
o`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo2ol0001[
ooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmo
OomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03
o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl0
1omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?mo
OgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo
00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo
00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo
002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003ooooooooo
o`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000
ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?oooo
o`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomo
Ogl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`00
0?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omo
Ogl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgoo
Ogmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo00Oooooo002?ooooo`03o`000?moOgooOgmo00koOgmo00?o0000ogmoOomoOgl01omoOgl00ol0
003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo002?ooooo`03o`000?moOgooOgmo00ko
Ogmo00?o0000ogmoOomoOgl01omoOgl00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oo
oooo002?oooooaco0000Joooool00ol0003oooooooooo`07ooooo`00oooooolGooooo`03o`000?oo
oooooooo00Oooooo003ooooooaOooooo00?o0000ooooooooool01oooool00?oooooo5oooool00ol0
003oooooooooo`07ooooo`00oooooolGooooo`03o`000?oooooooooo00Oooooo003ooooooaOooooo
00?o0000ooooooooool01oooool00?oooooo5oooool00ol0003oooooooooo`07ooooo`00oooooolG
ooooo`03o`000?oooooooooo00Oooooo003ooooooaOooooo00?o0000ooooooooool01oooool00?oo
oooo5oooool00ol0003oooooooooo`07ooooo`00oooooolGooooo`03o`000?oooooooooo00Oooooo
003ooooooaOooooo00?o0000ooooooooool01oooool00?oooooo5oooool00ol0003oooooooooo`07
ooooo`00oooooolGooooo`03o`000?oooooooooo00Oooooo003ooooooaOooooo00?o0000oooooooo
ool01oooool00?oooooo5oooool00ol0003oooooooooo`07ooooo`00oooooolGooooo`03o`000?oo
oooooooo00Oooooo003ooooooaOooooo00?o0000ooooooooool01oooool00?oooooo5oooool00ol0
003oooooooooo`07ooooo`00oooooolGooooo`03o`000?oooooooooo00Oooooo003ooooooaOooooo
00?o0000ooooooooool01oooool00?oooooo5oooool00ol0003oooooooooo`07ooooo`00oooooolG
ooooo`03o`000?oooooooooo00Oooooo003ooooooaOooooo00?o0000ooooooooool01oooool00?oo
oooo5oooool00ol0003oooooooooo`07ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {179.312, 0}} -> {-3.15947, -35.6979, \
0.370383, 0.370383}},
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[cylindricalsystem, ShowGaussian->True];", "Input",
  CellLabel->"In[81]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .86291 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.00352875 1.00353 -0.0447334 1.00353 [
[ 0 0 0 0 ]
[ 1 .86291 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .86291 L
0 .86291 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5767 .39458 m
.6296 .42001 L
s
.6296 .42001 m
.65377 .41228 L
s
.6296 .42001 m
.63096 .46028 L
s
.65377 .41228 m
.62594 .37854 L
s
.6554 .45263 m
.65377 .41228 L
s
.039 .916 .04 r
1 Mabswid
.16758 .50221 m
.17807 .49873 L
s
.16694 .5084 m
.16665 .51209 L
s
.17807 .49873 m
.18859 .49523 L
s
.16665 .51209 m
.16636 .51579 L
s
.18859 .49523 m
.19915 .49172 L
s
.16636 .51579 m
.16606 .5195 L
s
.18271 .50318 m
.18243 .50688 L
s
.16606 .5195 m
.16576 .52322 L
s
.18243 .50688 m
.18215 .51059 L
s
.19915 .49172 m
.20974 .4882 L
s
0 g
.5 Mabswid
.63096 .46028 m
.6554 .45263 L
s
.63096 .46028 m
.63236 .50141 L
s
.039 .916 .04 r
1 Mabswid
.16576 .52322 m
.16546 .52694 L
s
.18215 .51059 m
.18187 .5143 L
s
.16546 .52694 m
.16516 .53067 L
s
.18354 .58322 m
.19415 .57991 L
s
.19856 .49793 m
.19829 .50164 L
s
0 g
.5 Mabswid
.53331 .36496 m
.5767 .39458 L
s
.5767 .39458 m
.62594 .37854 L
s
.039 .916 .04 r
1 Mabswid
.20974 .4882 m
.22037 .48467 L
s
.18187 .5143 m
.18158 .51802 L
s
.18007 .58029 m
.18132 .58141 L
s
.16516 .53067 m
.16485 .5344 L
s
.19829 .50164 m
.19802 .50535 L
s
.17882 .57918 m
.18007 .58029 L
s
.18158 .51802 m
.18129 .52175 L
s
.19415 .57991 m
.2048 .57659 L
s
.16485 .5344 m
.16455 .53815 L
s
.17757 .57806 m
.17882 .57918 L
s
.22037 .48467 m
.23104 .48113 L
s
.19802 .50535 m
.19775 .50907 L
s
.18129 .52175 m
.18101 .52549 L
s
0 g
.5 Mabswid
.65706 .49382 m
.6554 .45263 L
s
.039 .916 .04 r
1 Mabswid
.17632 .57694 m
.17757 .57806 L
s
.16455 .53815 m
.16424 .5419 L
s
.21448 .49266 m
.21423 .49637 L
s
.19775 .50907 m
.19748 .5128 L
s
.17506 .57582 m
.17632 .57694 L
s
.2048 .57659 m
.21548 .57325 L
s
.19601 .5753 m
.19725 .57642 L
s
.18101 .52549 m
.18072 .52923 L
s
.1738 .5747 m
.17506 .57582 L
s
.16424 .5419 m
.16393 .54566 L
s
.21423 .49637 m
.21398 .50009 L
s
.23104 .48113 m
.24174 .47757 L
s
.19476 .57417 m
.19601 .5753 L
s
.19748 .5128 m
.19721 .51654 L
s
.17254 .57357 m
.1738 .5747 L
s
.18072 .52923 m
.18042 .53298 L
s
.19352 .57305 m
.19476 .57417 L
s
.16393 .54566 m
.16362 .54942 L
s
.21398 .50009 m
.21372 .50382 L
s
.17128 .57245 m
.17254 .57357 L
s
.21548 .57325 m
.2262 .56991 L
s
.19721 .51654 m
.19694 .52028 L
s
.19226 .57192 m
.19352 .57305 L
s
.18042 .53298 m
.18013 .53674 L
s
.23049 .48736 m
.23025 .49108 L
s
.17001 .57133 m
.17128 .57245 L
s
.24174 .47757 m
.25247 .474 L
s
.16362 .54942 m
.16331 .5532 L
s
.19101 .57079 m
.19226 .57192 L
s
.21372 .50382 m
.21347 .50756 L
s
.21203 .57028 m
.21327 .57141 L
s
.16874 .5702 m
.17001 .57133 L
s
.19694 .52028 m
.19666 .52403 L
s
.18976 .56966 m
.19101 .57079 L
s
.18013 .53674 m
.17984 .54051 L
s
.23025 .49108 m
.23002 .49481 L
s
.21079 .56914 m
.21203 .57028 L
s
.16747 .56908 m
.16874 .5702 L
s
.16331 .5532 m
.16299 .55698 L
s
.21347 .50756 m
.21321 .5113 L
s
.2262 .56991 m
.23696 .56655 L
s
.1885 .56853 m
.18976 .56966 L
s
.19666 .52403 m
.19638 .52779 L
s
.20954 .56801 m
.21079 .56914 L
s
.1662 .56795 m
.16747 .56908 L
s
.17984 .54051 m
.17954 .54428 L
s
.25247 .474 m
.26325 .47042 L
s
.23002 .49481 m
.22977 .49854 L
s
.18724 .5674 m
.1885 .56853 L
s
.16299 .55698 m
.16268 .56077 L
s
.21321 .5113 m
.21295 .51505 L
s
.20829 .56687 m
.20954 .56801 L
s
.16492 .56682 m
.1662 .56795 L
s
0 g
.5 Mabswid
.62594 .37854 m
.59722 .34371 L
s
.039 .916 .04 r
1 Mabswid
.19638 .52779 m
.1961 .53156 L
s
.24658 .48203 m
.24636 .48576 L
s
.18597 .56626 m
.18724 .5674 L
s
.17954 .54428 m
.17924 .54806 L
s
.20704 .56573 m
.20829 .56687 L
s
.22977 .49854 m
.22953 .50228 L
s
.16364 .56569 m
.16492 .56682 L
s
.23696 .56655 m
.24775 .56318 L
s
.16268 .56077 m
.16236 .56456 L
s
.22813 .56523 m
.22937 .56638 L
s
.18471 .56513 m
.18597 .56626 L
s
.21295 .51505 m
.21269 .51881 L
s
.20579 .5646 m
.20704 .56573 L
s
.16236 .56456 m
.16364 .56569 L
s
.1961 .53156 m
.19582 .53533 L
s
.24636 .48576 m
.24613 .48949 L
s
.26325 .47042 m
.27406 .46683 L
s
.22689 .56409 m
.22813 .56523 L
s
.18344 .564 m
.18471 .56513 L
s
.17924 .54806 m
.17894 .55185 L
s
.22953 .50228 m
.22929 .50603 L
s
.20453 .56346 m
.20579 .5646 L
s
.16236 .56456 m
.16204 .56837 L
s
.16108 .56343 m
.16236 .56456 L
s
0 g
.5 Mabswid
.63236 .50141 m
.65706 .49382 L
s
.039 .916 .04 r
1 Mabswid
.21269 .51881 m
.21242 .52257 L
s
.22565 .56295 m
.22689 .56409 L
s
.18217 .56286 m
.18344 .564 L
s
.19582 .53533 m
.19554 .53911 L
s
.24613 .48949 m
.24591 .49324 L
s
.20328 .56232 m
.20453 .56346 L
s
.15979 .5623 m
.16108 .56343 L
s
.17894 .55185 m
.17864 .55564 L
s
.24775 .56318 m
.25858 .5598 L
s
.22929 .50603 m
.22904 .50979 L
s
.2244 .5618 m
.22565 .56295 L
s
.18089 .56172 m
.18217 .56286 L
s
.16204 .56837 m
.16172 .57218 L
s
.21242 .52257 m
.21216 .52634 L
s
.26275 .47668 m
.26254 .48041 L
s
.20201 .56117 m
.20328 .56232 L
s
.1585 .56117 m
.15979 .5623 L
s
.27406 .46683 m
.28491 .46323 L
s
.19554 .53911 m
.19526 .5429 L
s
.22316 .56065 m
.2244 .5618 L
s
.24591 .49324 m
.24568 .49698 L
s
.17962 .56059 m
.18089 .56172 L
s
.17864 .55564 m
.17834 .55945 L
s
.24431 .56016 m
.24555 .56131 L
s
.20075 .56003 m
.20201 .56117 L
s
.15721 .56003 m
.1585 .56117 L
s
.22904 .50979 m
.2288 .51356 L
s
.16172 .57218 m
.1614 .576 L
s
.22191 .55951 m
.22316 .56065 L
s
.17834 .55945 m
.17962 .56059 L
s
.21216 .52634 m
.21189 .53012 L
s
.26254 .48041 m
.26233 .48415 L
s
.24308 .55901 m
.24431 .56016 L
s
.15592 .5589 m
.15721 .56003 L
s
.19949 .55889 m
.20075 .56003 L
s
.19526 .5429 m
.19497 .54669 L
s
.24568 .49698 m
.24545 .50074 L
s
.25858 .5598 m
.26945 .55641 L
s
.22065 .55836 m
.22191 .55951 L
s
.17834 .55945 m
.17803 .56326 L
s
.17706 .55831 m
.17834 .55945 L
s
.2288 .51356 m
.22855 .51733 L
s
.24184 .55786 m
.24308 .55901 L
s
.15462 .55776 m
.15592 .5589 L
s
.1614 .576 m
.16108 .57982 L
s
.19822 .55774 m
.19949 .55889 L
s
.21189 .53012 m
.21163 .53391 L
s
.28491 .46323 m
.29579 .45961 L
s
.26233 .48415 m
.26212 .4879 L
s
.2194 .55721 m
.22065 .55836 L
s
.17577 .55717 m
.17706 .55831 L
s
.19497 .54669 m
.19469 .5505 L
s
.24545 .50074 m
.24522 .5045 L
s
.2406 .5567 m
.24184 .55786 L
s
.15332 .55663 m
.15462 .55776 L
s
.19695 .5566 m
.19822 .55774 L
s
.17803 .56326 m
.17773 .56708 L
s
.22855 .51733 m
.2283 .52111 L
s
.27901 .4713 m
.27881 .47504 L
s
.21814 .55606 m
.2194 .55721 L
s
.17449 .55603 m
.17577 .55717 L
s
.16108 .57982 m
.16075 .58366 L
s
.21163 .53391 m
.21136 .53771 L
s
.23935 .55555 m
.2406 .5567 L
s
.26212 .4879 m
.26191 .49166 L
s
.15202 .55549 m
.15332 .55663 L
s
.19567 .55545 m
.19695 .5566 L
s
.26945 .55641 m
.28035 .553 L
s
.26058 .55506 m
.26181 .55622 L
s
.19469 .5505 m
.1944 .55431 L
s
.21688 .55491 m
.21814 .55606 L
s
.24522 .5045 m
.24499 .50828 L
s
.1732 .55488 m
.17449 .55603 L
s
.17773 .56708 m
.17742 .5709 L
s
.2381 .55439 m
.23935 .55555 L
s
.15071 .55435 m
.15202 .55549 L
s
.1944 .55431 m
.19567 .55545 L
s
.2283 .52111 m
.22805 .52489 L
s
.27881 .47504 m
.27862 .47879 L
s
0 g
.5 Mabswid
.59722 .34371 m
.53331 .36496 L
s
.039 .916 .04 r
1 Mabswid
.29579 .45961 m
.30672 .45598 L
s
.16075 .58366 m
.16042 .5875 L
s
.25935 .5539 m
.26058 .55506 L
s
.21562 .55376 m
.21688 .55491 L
s
.17191 .55374 m
.1732 .55488 L
s
.21136 .53771 m
.21109 .54151 L
s
.26191 .49166 m
.2617 .49542 L
s
.23685 .55323 m
.2381 .55439 L
s
.14941 .55321 m
.15071 .55435 L
s
.19312 .55316 m
.1944 .55431 L
s
.1944 .55431 m
.19411 .55812 L
s
.24499 .50828 m
.24475 .51206 L
s
.25811 .55274 m
.25935 .5539 L
s
.21435 .5526 m
.21562 .55376 L
s
.17742 .5709 m
.17711 .57474 L
s
.17061 .5526 m
.17191 .55374 L
s
.22805 .52489 m
.22779 .52869 L
s
.27862 .47879 m
.27842 .48254 L
s
.2356 .55208 m
.23685 .55323 L
s
.1481 .55207 m
.14941 .55321 L
s
.16042 .5875 m
.16009 .59135 L
s
.19184 .55201 m
.19312 .55316 L
s
.28035 .553 m
.2913 .54959 L
s
.21109 .54151 m
.21081 .54532 L
s
.2617 .49542 m
.26148 .49919 L
s
.25687 .55158 m
.25811 .55274 L
s
.21308 .55145 m
.21435 .5526 L
s
.16932 .55145 m
.17061 .5526 L
s
.19411 .55812 m
.19381 .56195 L
s
.24475 .51206 m
.24452 .51584 L
s
.29535 .46589 m
.29517 .46964 L
s
.23435 .55092 m
.2356 .55208 L
s
.14679 .55093 m
.1481 .55207 L
s
.19055 .55086 m
.19184 .55201 L
s
.17711 .57474 m
.1768 .57858 L
s
.30672 .45598 m
.31768 .45234 L
s
.22779 .52869 m
.22754 .53249 L
s
.25563 .55041 m
.25687 .55158 L
s
.27842 .48254 m
.27823 .4863 L
s
.16802 .55031 m
.16932 .55145 L
s
.21181 .55029 m
.21308 .55145 L
s
.16009 .59135 m
.15976 .59521 L
s
.27693 .54994 m
.27816 .55111 L
s
.21081 .54532 m
.21054 .54914 L
s
.14547 .54979 m
.14679 .55093 L
s
.23309 .54976 m
.23435 .55092 L
s
.26148 .49919 m
.26126 .50297 L
s
.18927 .54971 m
.19055 .55086 L
s
.19381 .56195 m
.19352 .56578 L
s
.25439 .54925 m
.25563 .55041 L
s
.16671 .54916 m
.16802 .55031 L
s
.24452 .51584 m
.24428 .51964 L
s
.21054 .54914 m
.21181 .55029 L
s
.29517 .46964 m
.29499 .47339 L
s
.2757 .54877 m
.27693 .54994 L
s
.1768 .57858 m
.17648 .58243 L
s
.14415 .54865 m
.14547 .54979 L
s
.23183 .5486 m
.23309 .54976 L
s
.22754 .53249 m
.22728 .5363 L
s
.18798 .54856 m
.18927 .54971 L
s
.2913 .54959 m
.30227 .54616 L
s
.27823 .4863 m
.27803 .49007 L
s
.15976 .59521 m
.15943 .59907 L
s
.25314 .54808 m
.25439 .54925 L
s
.16541 .54801 m
.16671 .54916 L
s
.21054 .54914 m
.21026 .55296 L
s
.20926 .54798 m
.21054 .54914 L
s
.26126 .50297 m
.26104 .50676 L
s
.27447 .5476 m
.2757 .54877 L
s
.14284 .5475 m
.14415 .54865 L
s
.23057 .54744 m
.23183 .5486 L
s
.19352 .56578 m
.19323 .56963 L
s
.18669 .5474 m
.18798 .54856 L
s
.31768 .45234 m
.32867 .44868 L
s
.24428 .51964 m
.24404 .52344 L
s
.29499 .47339 m
.29481 .47715 L
s
.25189 .54692 m
.25314 .54808 L
s
.17648 .58243 m
.17617 .58629 L
s
.1641 .54686 m
.16541 .54801 L
s
.20798 .54682 m
.20926 .54798 L
s
.22728 .5363 m
.22702 .54012 L
s
.27803 .49007 m
.27783 .49385 L
s
.27323 .54643 m
.27447 .5476 L
s
.15943 .59907 m
.1591 .60294 L
s
.2293 .54627 m
.23057 .54744 L
s
.18539 .54625 m
.18669 .5474 L
s
.21026 .55296 m
.20999 .5568 L
s
.26104 .50676 m
.26082 .51055 L
s
.31177 .46045 m
.31161 .4642 L
s
.25064 .54575 m
.25189 .54692 L
s
.16279 .54571 m
.1641 .54686 L
s
.2067 .54566 m
.20798 .54682 L
s
.19323 .56963 m
.19293 .57347 L
s
.24404 .52344 m
.2438 .52725 L
s
.27199 .54526 m
.27323 .54643 L
s
.29481 .47715 m
.29462 .48092 L
s
.22803 .54511 m
.2293 .54627 L
s
.1841 .54509 m
.18539 .54625 L
s
.30227 .54616 m
.31329 .54272 L
s
.17617 .58629 m
.17585 .59015 L
s
.29336 .54479 m
.29459 .54597 L
s
.22702 .54012 m
.22676 .54394 L
s
.24938 .54458 m
.25064 .54575 L
s
.27783 .49385 m
.27762 .49764 L
s
.16148 .54456 m
.16279 .54571 L
s
.20542 .5445 m
.2067 .54566 L
s
.1591 .60294 m
.15876 .60682 L
s
.14078 .54554 m
.15145 .54204 L
s
.20999 .5568 m
.20971 .56064 L
s
.27075 .54408 m
.27199 .54526 L
s
.26082 .51055 m
.2606 .51435 L
s
.22676 .54394 m
.22803 .54511 L
s
.1828 .54394 m
.1841 .54509 L
s
.31161 .4642 m
.31144 .46797 L
s
.32867 .44868 m
.33971 .44502 L
s
.29214 .54361 m
.29336 .54479 L
s
.19293 .57347 m
.19263 .57733 L
s
.24813 .54341 m
.24938 .54458 L
s
.16017 .54341 m
.16148 .54456 L
s
.2438 .52725 m
.24356 .53106 L
s
.20413 .54334 m
.20542 .5445 L
s
.29462 .48092 m
.29444 .4847 L
s
.17585 .59015 m
.17554 .59402 L
s
.26951 .54291 m
.27075 .54408 L
s
.22676 .54394 m
.2265 .54778 L
s
.22549 .54278 m
.22676 .54394 L
s
.1815 .54278 m
.1828 .54394 L
s
.27762 .49764 m
.27742 .50143 L
s
.15876 .60682 m
.15842 .61071 L
s
.29091 .54243 m
.29214 .54361 L
s
.24687 .54224 m
.24813 .54341 L
s
.15885 .54226 m
.16017 .54341 L
s
.57923 .51868 m .65875 .5359 L .63379 .54341 L .656 .751 .92 r
F
0 g
.5 Mabswid
.63379 .54341 m
.63524 .58631 L
s
.63236 .50141 m
.63334 .5304 L
s
.039 .916 .04 r
1 Mabswid
.20971 .56064 m
.20943 .56449 L
s
.20285 .54218 m
.20413 .54334 L
s
.2606 .51435 m
.26038 .51816 L
s
.31144 .46797 m
.31128 .47173 L
s
.26826 .54173 m
.26951 .54291 L
s
.19263 .57733 m
.19233 .5812 L
s
.18019 .54162 m
.1815 .54278 L
s
.22422 .54161 m
.22549 .54278 L
s
.31329 .54272 m
.32434 .53927 L
s
.24356 .53106 m
.24332 .53489 L
s
.29444 .4847 m
.29425 .48848 L
s
.28967 .54125 m
.29091 .54243 L
s
.17554 .59402 m
.17522 .5979 L
s
.24561 .54107 m
.24687 .54224 L
s
.20155 .54102 m
.20285 .54218 L
s
.15145 .54204 m
.16216 .53852 L
s
.2265 .54778 m
.22624 .55162 L
s
.27742 .50143 m
.27721 .50523 L
s
.32828 .45499 m
.32813 .45875 L
s
.26701 .54055 m
.26826 .54173 L
s
.15842 .61071 m
.15808 .61461 L
s
.17888 .54046 m
.18019 .54162 L
s
.22294 .54044 m
.22422 .54161 L
s
.33971 .44502 m
.35078 .44134 L
s
.20943 .56449 m
.20914 .56834 L
s
.28844 .54007 m
.28967 .54125 L
s
.26038 .51816 m
.26015 .52198 L
s
.31128 .47173 m
.31111 .47551 L
s
.24434 .5399 m
.24561 .54107 L
s
.20026 .53986 m
.20155 .54102 L
s
.19233 .5812 m
.19203 .58507 L
s
.30988 .53961 m
.3111 .5408 L
s
.24332 .53489 m
.24307 .53872 L
s
.26576 .53938 m
.26701 .54055 L
s
.29425 .48848 m
.29407 .49227 L
s
.17757 .5393 m
.17888 .54046 L
s
.22166 .53927 m
.22294 .54044 L
s
.17522 .5979 m
.17489 .60179 L
s
.22624 .55162 m
.22598 .55547 L
s
.2872 .53889 m
.28844 .54007 L
s
.27721 .50523 m
.27701 .50904 L
s
.24307 .53872 m
.24434 .5399 L
s
.19896 .53869 m
.20026 .53986 L
s
.32813 .45875 m
.32798 .46251 L
s
.15808 .61461 m
.15774 .61851 L
s
.30866 .53843 m
.30988 .53961 L
s
.20914 .56834 m
.20886 .57221 L
s
.26451 .5382 m
.26576 .53938 L
s
.26015 .52198 m
.25993 .5258 L
s
.17626 .53814 m
.17757 .5393 L
s
.32434 .53927 m
.33543 .53581 L
s
.22037 .5381 m
.22166 .53927 L
s
.31111 .47551 m
.31094 .47929 L
s
.19203 .58507 m
.19172 .58895 L
s
.28596 .5377 m
.2872 .53889 L
s
.24307 .53872 m
.24283 .54256 L
s
.2418 .53755 m
.24307 .53872 L
s
.19767 .53752 m
.19896 .53869 L
s
.29407 .49227 m
.29388 .49608 L
s
.16216 .53852 m
.1729 .53499 L
s
.30743 .53724 m
.30866 .53843 L
s
.17489 .60179 m
.17457 .60569 L
s
.26325 .53702 m
.26451 .5382 L
s
.22598 .55547 m
.22571 .55932 L
s
.17495 .53698 m
.17626 .53814 L
s
.21909 .53693 m
.22037 .5381 L
s
.35078 .44134 m
.3619 .43765 L
s
.27701 .50904 m
.2768 .51285 L
s
.15774 .61851 m
.1574 .62242 L
s
.32798 .46251 m
.32783 .46629 L
s
.28472 .53652 m
.28596 .5377 L
s
.20886 .57221 m
.20857 .57608 L
s
.24053 .53637 m
.2418 .53755 L
s
.19636 .53636 m
.19767 .53752 L
s
.25993 .5258 m
.2597 .52963 L
s
.3062 .53605 m
.30743 .53724 L
s
.31094 .47929 m
.31077 .48309 L
s
.19172 .58895 m
.19142 .59284 L
s
.26199 .53584 m
.26325 .53702 L
s
.2178 .53576 m
.21909 .53693 L
s
.24283 .54256 m
.24258 .54641 L
s
.29388 .49608 m
.29369 .49988 L
s
.34487 .44949 m
.34474 .45326 L
s
.28348 .53533 m
.28472 .53652 L
s
.17457 .60569 m
.17425 .60959 L
s
.23926 .53519 m
.24053 .53637 L
s
.19506 .53519 m
.19636 .53636 L
s
.22571 .55932 m
.22544 .56319 L
s
.30497 .53486 m
.3062 .53605 L
s
.2768 .51285 m
.27659 .51668 L
s
.32783 .46629 m
.32768 .47007 L
s
.57923 .51868 m .6301 .50307 L .65875 .5359 L .656 .751 .92 r
F
0 g
.5 Mabswid
.65875 .5359 m
.66048 .57888 L
s
.65706 .49382 m
.65875 .5359 L
s
.63379 .54341 m
.65875 .5359 L
s
.039 .916 .04 r
1 Mabswid
.26073 .53466 m
.26199 .53584 L
s
.33543 .53581 m
.34656 .53234 L
s
.21651 .53459 m
.2178 .53576 L
s
.20857 .57608 m
.20829 .57996 L
s
.32648 .53441 m
.3277 .53561 L
s
.2597 .52963 m
.25947 .53347 L
s
.28223 .53415 m
.28348 .53533 L
s
.31077 .48309 m
.3106 .48689 L
s
.23798 .53402 m
.23926 .53519 L
s
.19375 .53402 m
.19506 .53519 L
s
.19142 .59284 m
.19111 .59673 L
s
.1729 .53499 m
.18369 .53145 L
s
.30374 .53367 m
.30497 .53486 L
s
.24258 .54641 m
.24233 .55027 L
s
.29369 .49988 m
.2935 .5037 L
s
.25947 .53347 m
.26073 .53466 L
s
.21522 .53342 m
.21651 .53459 L
s
.34474 .45326 m
.3446 .45703 L
s
.17425 .60959 m
.17392 .6135 L
s
.3619 .43765 m
.37305 .43394 L
s
.32527 .53321 m
.32648 .53441 L
s
.22544 .56319 m
.22517 .56706 L
s
.28098 .53296 m
.28223 .53415 L
s
.27659 .51668 m
.27638 .52051 L
s
.19244 .53285 m
.19375 .53402 L
s
.2367 .53284 m
.23798 .53402 L
s
.32768 .47007 m
.32752 .47386 L
s
.20829 .57996 m
.208 .58385 L
s
.3025 .53247 m
.30374 .53367 L
s
.25947 .53347 m
.25924 .53732 L
s
.2582 .53229 m
.25947 .53347 L
s
.21392 .53224 m
.21522 .53342 L
s
.3106 .48689 m
.31042 .49069 L
s
.32404 .53202 m
.32527 .53321 L
s
.19111 .59673 m
.1908 .60063 L
s
.27972 .53177 m
.28098 .53296 L
s
.24233 .55027 m
.24208 .55413 L
s
.19113 .53168 m
.19244 .53285 L
s
.23542 .53166 m
.2367 .53284 L
s
.2935 .5037 m
.2933 .50752 L
s
.15698 .62891 m
.16778 .62559 L
s
.3446 .45703 m
.34447 .46082 L
s
.17392 .6135 m
.17359 .61742 L
s
.30126 .53128 m
.3025 .53247 L
s
.34656 .53234 m
.35773 .52885 L
s
.22517 .56706 m
.2249 .57094 L
s
.25693 .5311 m
.2582 .53229 L
s
.21262 .53106 m
.21392 .53224 L
s
.27638 .52051 m
.27616 .52435 L
s
.32282 .53082 m
.32404 .53202 L
s
.32752 .47386 m
.32737 .47766 L
s
.27847 .53058 m
.27972 .53177 L
s
.208 .58385 m
.20771 .58774 L
s
.23413 .53048 m
.23542 .53166 L
s
.25924 .53732 m
.25901 .54118 L
s
.18369 .53145 m
.19451 .5279 L
s
.31042 .49069 m
.31025 .49451 L
s
.36155 .44397 m
.36143 .44774 L
s
.30002 .53008 m
.30126 .53128 L
s
.1908 .60063 m
.19049 .60455 L
s
.25566 .52992 m
.25693 .5311 L
s
.21132 .52989 m
.21262 .53106 L
s
.37305 .43394 m
.38424 .43022 L
s
.24208 .55413 m
.24183 .558 L
s
.32159 .52962 m
.32282 .53082 L
s
.2933 .50752 m
.29311 .51135 L
s
.34447 .46082 m
.34433 .46461 L
s
.27721 .52939 m
.27847 .53058 L
s
.23284 .5293 m
.23413 .53048 L
s
.34317 .52918 m
.34439 .53038 L
s
.2249 .57094 m
.22463 .57482 L
s
.27616 .52435 m
.27595 .5282 L
s
.29878 .52889 m
.30002 .53008 L
s
.32737 .47766 m
.32721 .48147 L
s
.25439 .52873 m
.25566 .52992 L
s
.21002 .52871 m
.21132 .52989 L
s
.20771 .58774 m
.20741 .59165 L
s
.32036 .52842 m
.32159 .52962 L
s
.25901 .54118 m
.25877 .54504 L
s
.31025 .49451 m
.31007 .49833 L
s
.27595 .5282 m
.27721 .52939 L
s
.36143 .44774 m
.36131 .45152 L
s
.23155 .52811 m
.23284 .5293 L
s
.19049 .60455 m
.19018 .60847 L
s
.34196 .52797 m
.34317 .52918 L
s
.16778 .62559 m
.17862 .62225 L
s
.24183 .558 m
.24157 .56188 L
s
.29753 .52769 m
.29878 .52889 L
s
.35773 .52885 m
.36894 .52536 L
s
.29311 .51135 m
.29291 .51519 L
s
.25311 .52754 m
.25439 .52873 L
s
.20871 .52753 m
.21002 .52871 L
s
.34433 .46461 m
.3442 .4684 L
s
.31913 .52721 m
.32036 .52842 L
s
.22463 .57482 m
.22436 .57872 L
s
.27595 .5282 m
.27573 .53205 L
s
.27469 .527 m
.27595 .5282 L
s
.23026 .52693 m
.23155 .52811 L
s
.32721 .48147 m
.32706 .48528 L
s
.34074 .52677 m
.34196 .52797 L
s
.19451 .5279 m
.20537 .52433 L
s
.20741 .59165 m
.20712 .59556 L
s
.29628 .52649 m
.29753 .52769 L
s
.25877 .54504 m
.25854 .54891 L
s
.25183 .52635 m
.25311 .52754 L
s
.2074 .52635 m
.20871 .52753 L
s
.38424 .43022 m
.39546 .42649 L
s
.31007 .49833 m
.3099 .50216 L
s
.36131 .45152 m
.3612 .45531 L
s
.19018 .60847 m
.18987 .61239 L
s
.31789 .52601 m
.31913 .52721 L
s
.24157 .56188 m
.24132 .56577 L
s
.27342 .52581 m
.27469 .527 L
s
.22896 .52574 m
.23026 .52693 L
s
.29291 .51519 m
.29272 .51904 L
s
.33952 .52556 m
.34074 .52677 L
s
.3442 .4684 m
.34406 .47221 L
s
.29503 .52529 m
.29628 .52649 L
s
.22436 .57872 m
.22408 .58262 L
s
.25055 .52516 m
.25183 .52635 L
s
.27573 .53205 m
.27552 .53591 L
s
.32706 .48528 m
.3269 .4891 L
s
.37831 .43842 m
.37821 .4422 L
s
.31665 .52481 m
.31789 .52601 L
s
.20712 .59556 m
.20683 .59948 L
s
.27215 .52461 m
.27342 .52581 L
s
.22766 .52456 m
.22896 .52574 L
s
.25854 .54891 m
.2583 .55279 L
s
.17862 .62225 m
.18949 .61891 L
s
.33829 .52435 m
.33952 .52556 L
s
.3099 .50216 m
.30972 .506 L
s
.3612 .45531 m
.36108 .45911 L
s
.36894 .52536 m
.38019 .52185 L
s
.29377 .52409 m
.29503 .52529 L
s
.24926 .52397 m
.25055 .52516 L
s
.35995 .52392 m
.36116 .52514 L
s
.24132 .56577 m
.24106 .56966 L
s
.29272 .51904 m
.29252 .52289 L
s
.31541 .5236 m
.31665 .52481 L
s
.34406 .47221 m
.34392 .47602 L
s
.27088 .52342 m
.27215 .52461 L
s
.22636 .52337 m
.22766 .52456 L
s
.4983 .33126 m .56833 .34894 L .4983 .37227 L .544 .324 .532 r
F
0 g
.5 Mabswid
.52995 .36172 m
.53331 .36496 L
s
.4983 .33126 m .56757 .30775 L .56833 .34894 L .544 .324 .532 r
F
0 g
.56757 .30775 m
.59722 .34371 L
s
.47153 .29327 m
.4983 .33126 L
s
.4983 .33126 m
.56757 .30775 L
s
.039 .916 .04 r
1 Mabswid
.22408 .58262 m
.2238 .58653 L
s
.33707 .52314 m
.33829 .52435 L
s
.20537 .52433 m
.21626 .52075 L
s
.27552 .53591 m
.2753 .53979 L
s
.3269 .4891 m
.32674 .49293 L
s
.29252 .52289 m
.29377 .52409 L
s
.37821 .4422 m
.37811 .44599 L
s
.39546 .42649 m
.40673 .42275 L
s
.24798 .52278 m
.24926 .52397 L
s
.20683 .59948 m
.20653 .6034 L
s
.35874 .52271 m
.35995 .52392 L
s
.2583 .55279 m
.25806 .55668 L
s
.31417 .5224 m
.31541 .5236 L
s
.30972 .506 m
.30954 .50985 L
s
.26961 .52222 m
.27088 .52342 L
s
.36108 .45911 m
.36095 .46292 L
s
.22506 .52218 m
.22636 .52337 L
s
.33584 .52193 m
.33707 .52314 L
s
.24106 .56966 m
.2408 .57357 L
s
.29252 .52289 m
.29232 .52676 L
s
.29126 .52169 m
.29252 .52289 L
s
.24669 .52159 m
.24798 .52278 L
s
.34392 .47602 m
.34377 .47984 L
s
.35752 .52149 m
.35874 .52271 L
s
.2238 .58653 m
.22352 .59045 L
s
.31292 .52119 m
.31417 .5224 L
s
.2753 .53979 m
.27508 .54366 L
s
.26833 .52102 m
.26961 .52222 L
s
.22375 .52099 m
.22506 .52218 L
s
.32674 .49293 m
.32657 .49677 L
s
.37811 .44599 m
.37801 .44978 L
s
.18949 .61891 m
.20041 .61555 L
s
.20653 .6034 m
.20623 .60734 L
s
.33461 .52072 m
.33584 .52193 L
s
.38019 .52185 m
.39147 .51832 L
s
0 g
.5 Mabswid
.63524 .58631 m
.66048 .57888 L
s
.63524 .58631 m
.63673 .63014 L
s
.039 .916 .04 r
1 Mabswid
.25806 .55668 m
.25782 .56057 L
s
.28999 .52049 m
.29126 .52169 L
s
.24539 .52039 m
.24669 .52159 L
s
.30954 .50985 m
.30935 .5137 L
s
.35631 .52027 m
.35752 .52149 L
s
.36095 .46292 m
.36083 .46673 L
s
.31168 .51998 m
.31292 .52119 L
s
.2408 .57357 m
.24054 .57748 L
s
.26705 .51982 m
.26833 .52102 L
s
.29232 .52676 m
.29211 .53063 L
s
.34377 .47984 m
.34363 .48367 L
s
.21626 .52075 m
.2272 .51716 L
s
.39517 .43284 m
.39508 .43663 L
s
.33337 .5195 m
.33461 .52072 L
s
.22352 .59045 m
.22324 .59438 L
s
.28873 .51928 m
.28999 .52049 L
s
.40673 .42275 m
.41804 .41899 L
s
.2441 .5192 m
.24539 .52039 L
s
.27508 .54366 m
.27485 .54755 L
s
.35509 .51906 m
.35631 .52027 L
s
.32657 .49677 m
.32641 .50062 L
s
.37801 .44978 m
.37791 .45359 L
s
.31042 .51877 m
.31168 .51998 L
s
.37681 .51864 m
.37802 .51986 L
s
.26577 .51862 m
.26705 .51982 L
s
.25782 .56057 m
.25758 .56447 L
s
.30935 .5137 m
.30917 .51756 L
s
.33214 .51829 m
.33337 .5195 L
s
.36083 .46673 m
.36071 .47055 L
s
.28746 .51808 m
.28873 .51928 L
s
.2428 .518 m
.2441 .5192 L
s
.24054 .57748 m
.24028 .5814 L
s
.35386 .51784 m
.35509 .51906 L
s
.29211 .53063 m
.29191 .5345 L
s
.34363 .48367 m
.34349 .48751 L
s
.30917 .51756 m
.31042 .51877 L
s
.39508 .43663 m
.395 .44042 L
s
.53446 .48984 m .6301 .50307 L .57923 .51868 L .656 .751 .92 r
F
0 g
.5 Mabswid
.57923 .51868 m
.63379 .54341 L
s
.039 .916 .04 r
1 Mabswid
.37561 .51741 m
.37681 .51864 L
s
.26448 .51742 m
.26577 .51862 L
s
.22324 .59438 m
.22296 .59832 L
s
.20041 .61555 m
.21136 .61218 L
s
.27485 .54755 m
.27463 .55144 L
s
.39147 .51832 m
.40279 .51479 L
s
.3309 .51707 m
.33214 .51829 L
s
.32641 .50062 m
.32625 .50447 L
s
.37791 .45359 m
.3778 .4574 L
s
.28619 .51687 m
.28746 .51808 L
s
.2415 .51681 m
.2428 .518 L
s
.35264 .51662 m
.35386 .51784 L
s
.25758 .56447 m
.25733 .56838 L
s
.30917 .51756 m
.30899 .52143 L
s
.30791 .51635 m
.30917 .51756 L
s
.36071 .47055 m
.36058 .47438 L
s
.2632 .51622 m
.26448 .51742 L
s
.3744 .51619 m
.37561 .51741 L
s
.24028 .5814 m
.24001 .58532 L
s
.2272 .51716 m
.23817 .51356 L
s
.32965 .51586 m
.3309 .51707 L
s
.29191 .5345 m
.29171 .53839 L
s
.41804 .41899 m
.42938 .41522 L
s
.28492 .51566 m
.28619 .51687 L
s
.34349 .48751 m
.34334 .49135 L
s
.24019 .51561 m
.2415 .51681 L
s
.395 .44042 m
.39491 .44422 L
s
.22296 .59832 m
.22268 .60226 L
s
.35141 .51539 m
.35264 .51662 L
s
.27463 .55144 m
.27441 .55535 L
s
.30665 .51514 m
.30791 .51635 L
s
.26191 .51502 m
.2632 .51622 L
s
.37318 .51496 m
.3744 .51619 L
s
.32625 .50447 m
.32608 .50833 L
s
.3778 .4574 m
.37769 .46122 L
s
.32841 .51464 m
.32965 .51586 L
s
.25733 .56838 m
.25709 .5723 L
s
.28364 .51446 m
.28492 .51566 L
s
.30899 .52143 m
.3088 .52531 L
s
.36058 .47438 m
.36045 .47821 L
s
.41211 .42723 m
.41204 .43102 L
s
.35018 .51417 m
.35141 .51539 L
s
.24001 .58532 m
.23975 .58926 L
s
.30539 .51392 m
.30665 .51514 L
s
.26062 .51381 m
.26191 .51502 L
s
.29171 .53839 m
.2915 .54228 L
s
.37197 .51373 m
.37318 .51496 L
s
.21136 .61218 m
.22236 .6088 L
s
.34334 .49135 m
.34319 .49521 L
s
.40279 .51479 m
.41416 .51124 L
s
.39491 .44422 m
.39482 .44803 L
s
.32716 .51342 m
.32841 .51464 L
s
.39377 .51332 m
.39497 .51456 L
s
.28236 .51325 m
.28364 .51446 L
s
.27441 .55535 m
.27418 .55926 L
s
.32608 .50833 m
.32591 .5122 L
s
.34895 .51295 m
.35018 .51417 L
s
0 g
.5 Mabswid
.66225 .6228 m
.66048 .57888 L
s
.039 .916 .04 r
1 Mabswid
.37769 .46122 m
.37758 .46505 L
s
.30413 .51271 m
.30539 .51392 L
s
.25932 .51261 m
.26062 .51381 L
s
.25709 .5723 m
.25684 .57623 L
s
.37075 .5125 m
.37197 .51373 L
s
.3088 .52531 m
.30861 .52919 L
s
.23817 .51356 m
.24919 .50994 L
s
.36045 .47821 m
.36032 .48206 L
s
.32591 .5122 m
.32716 .51342 L
s
.41204 .43102 m
.41197 .43483 L
s
.42938 .41522 m
.44077 .41144 L
s
.39256 .51209 m
.39377 .51332 L
s
.28108 .51204 m
.28236 .51325 L
s
.23975 .58926 m
.23948 .5932 L
s
.2915 .54228 m
.29129 .54619 L
s
.34771 .51172 m
.34895 .51295 L
s
.34319 .49521 m
.34304 .49907 L
s
.39482 .44803 m
.39473 .45185 L
s
.30286 .51149 m
.30413 .51271 L
s
.25802 .5114 m
.25932 .51261 L
s
.36953 .51127 m
.37075 .5125 L
s
.27418 .55926 m
.27395 .56318 L
s
.32591 .5122 m
.32574 .51608 L
s
.32466 .51098 m
.32591 .5122 L
s
.37758 .46505 m
.37748 .46888 L
s
.39135 .51086 m
.39256 .51209 L
s
.2798 .51082 m
.28108 .51204 L
s
.25684 .57623 m
.25659 .58016 L
s
.34647 .5105 m
.34771 .51172 L
s
.30861 .52919 m
.30842 .53309 L
s
.30159 .51028 m
.30286 .51149 L
s
.36032 .48206 m
.36019 .48591 L
s
.25672 .51019 m
.25802 .5114 L
s
.41197 .43483 m
.4119 .43863 L
s
.22236 .6088 m
.23339 .60541 L
s
.3683 .51004 m
.36953 .51127 L
s
.41416 .51124 m
.42556 .50768 L
s
.23948 .5932 m
.23921 .59715 L
s
.29129 .54619 m
.29108 .5501 L
s
.3234 .50976 m
.32466 .51098 L
s
.39015 .50962 m
.39135 .51086 L
s
.27851 .50961 m
.2798 .51082 L
s
.34304 .49907 m
.34289 .50294 L
s
.39473 .45185 m
.39464 .45568 L
s
.34523 .50927 m
.34647 .5105 L
s
.27395 .56318 m
.27372 .5671 L
s
.30032 .50906 m
.30159 .51028 L
s
.32574 .51608 m
.32557 .51996 L
s
.37748 .46888 m
.37736 .47272 L
s
.42914 .42159 m
.42909 .42539 L
s
.36708 .50881 m
.3683 .51004 L
s
.24919 .50994 m
.26024 .50631 L
s
.25659 .58016 m
.25634 .58411 L
s
.44077 .41144 m
.4522 .40764 L
s
.32215 .50854 m
.3234 .50976 L
s
.38893 .50838 m
.39015 .50962 L
s
.27722 .5084 m
.27851 .50961 L
s
.30842 .53309 m
.30823 .53699 L
s
.36019 .48591 m
.36006 .48977 L
s
.4119 .43863 m
.41183 .44245 L
s
.34399 .50804 m
.34523 .50927 L
s
.41081 .50798 m
.412 .50923 L
s
.29904 .50784 m
.30032 .50906 L
s
.29108 .5501 m
.29087 .55401 L
s
.34289 .50294 m
.34274 .50681 L
s
.36585 .50758 m
.36708 .50881 L
s
.39464 .45568 m
.39455 .45951 L
s
.32088 .50731 m
.32215 .50854 L
s
.27372 .5671 m
.27349 .57104 L
s
.27593 .50718 m
.27722 .5084 L
s
.38772 .50715 m
.38893 .50838 L
s
.32557 .51996 m
.3254 .52386 L
s
.37736 .47272 m
.37725 .47658 L
s
.34274 .50681 m
.34399 .50804 L
s
.42909 .42539 m
.42904 .4292 L
s
.40961 .50674 m
.41081 .50798 L
s
.29777 .50662 m
.29904 .50784 L
s
.25634 .58411 m
.25609 .58806 L
s
.23339 .60541 m
.24446 .602 L
s
.42556 .50768 m
.437 .50411 L
s
.30823 .53699 m
.30804 .5409 L
s
.36461 .50634 m
.36585 .50758 L
s
.36006 .48977 m
.35993 .49364 L
s
.41183 .44245 m
.41176 .44628 L
s
.31962 .50609 m
.32088 .50731 L
s
.27464 .50597 m
.27593 .50718 L
s
.3865 .50591 m
.38772 .50715 L
s
.29087 .55401 m
.29066 .55794 L
s
.34274 .50681 m
.34259 .5107 L
s
.34149 .50558 m
.34274 .50681 L
s
.4084 .5055 m
.40961 .50674 L
s
.39455 .45951 m
.39446 .46336 L
s
.29649 .5054 m
.29777 .50662 L
s
.27349 .57104 m
.27325 .57498 L
s
.36338 .50511 m
.36461 .50634 L
s
.26024 .50631 m
.27133 .50267 L
s
.4522 .40764 m
.46366 .40383 L
s
.3254 .52386 m
.32523 .52776 L
s
.31835 .50486 m
.31962 .50609 L
s
.37725 .47658 m
.37714 .48043 L
s
.42904 .4292 m
.42898 .43302 L
s
.27334 .50475 m
.27464 .50597 L
s
.38528 .50467 m
.3865 .50591 L
s
.25609 .58806 m
.25583 .59202 L
s
.30804 .5409 m
.30784 .54482 L
s
.34024 .50435 m
.34149 .50558 L
s
.4072 .50425 m
.4084 .5055 L
s
.35993 .49364 m
.3598 .49751 L
s
.2952 .50418 m
.29649 .5054 L
s
.41176 .44628 m
.41168 .45011 L
s
.36214 .50387 m
.36338 .50511 L
s
.29066 .55794 m
.29044 .56187 L
s
.31709 .50363 m
.31835 .50486 L
s
.34259 .5107 m
.34243 .51459 L
s
.39446 .46336 m
.39436 .46721 L
s
.44626 .41592 m
.44623 .41973 L
s
.38406 .50342 m
.38528 .50467 L
s
.27325 .57498 m
.27302 .57893 L
s
.33899 .50312 m
.34024 .50435 L
s
.40599 .50301 m
.4072 .50425 L
s
.32523 .52776 m
.32505 .53167 L
s
.29392 .50295 m
.2952 .50418 L
s
.437 .50411 m
.44849 .50053 L
s
.24446 .602 m
.25557 .59858 L
s
.37714 .48043 m
.37702 .4843 L
s
.42898 .43302 m
.42893 .43684 L
s
.3609 .50264 m
.36214 .50387 L
s
.42794 .50262 m
.42913 .50387 L
s
.31581 .5024 m
.31709 .50363 L
s
.30784 .54482 m
.30765 .54874 L
s
.38283 .50218 m
.38406 .50342 L
s
.3598 .49751 m
.35966 .5014 L
s
.41168 .45011 m
.41161 .45395 L
s
.33773 .50189 m
.33899 .50312 L
s
0 g
.5 Mabswid
.53693 .27061 m
.56757 .30775 L
s
.53446 .48984 m .60049 .46915 L .6301 .50307 L .656 .751 .92 r
F
0 g
.6301 .50307 m
.65875 .5359 L
s
.039 .916 .04 r
1 Mabswid
.40478 .50176 m
.40599 .50301 L
s
.29044 .56187 m
.29023 .56582 L
s
.29263 .50173 m
.29392 .50295 L
s
.34243 .51459 m
.34228 .51849 L
s
.39436 .46721 m
.39427 .47107 L
s
.27133 .50267 m
.28246 .49901 L
s
.44623 .41973 m
.44619 .42355 L
s
.35966 .5014 m
.3609 .50264 L
s
.42674 .50136 m
.42794 .50262 L
s
.46366 .40383 m
.47517 .40001 L
s
.4983 .37227 m .5691 .39104 L .4983 .41417 L .544 .324 .532 r
F
.4983 .37227 m .56833 .34894 L .5691 .39104 L F
0 g
.5 Mabswid
.4983 .33126 m
.4983 .37227 L
s
.56757 .30775 m
.56833 .34894 L
s
.039 .916 .04 r
1 Mabswid
.31454 .50117 m
.31581 .5024 L
s
.27302 .57893 m
.27278 .58289 L
s
.38161 .50094 m
.38283 .50218 L
s
.32505 .53167 m
.32487 .53558 L
s
.37702 .4843 m
.37691 .48818 L
s
.42893 .43684 m
.42887 .44067 L
s
.33647 .50065 m
.33773 .50189 L
s
.40357 .50051 m
.40478 .50176 L
s
.29134 .5005 m
.29263 .50173 L
s
.30765 .54874 m
.30745 .55268 L
s
.35966 .5014 m
.35952 .50529 L
s
.35842 .50016 m
.35966 .5014 L
s
.42554 .50011 m
.42674 .50136 L
s
.41161 .45395 m
.41153 .4578 L
s
.31326 .49994 m
.31454 .50117 L
s
.29023 .56582 m
.29001 .56977 L
s
.38038 .49969 m
.38161 .50094 L
s
.34228 .51849 m
.34212 .5224 L
s
.39427 .47107 m
.39417 .47493 L
s
.33521 .49941 m
.33647 .50065 L
s
.44619 .42355 m
.44615 .42737 L
s
.44849 .50053 m
.46001 .49693 L
s
.40235 .49926 m
.40357 .50051 L
s
.29004 .49928 m
.29134 .5005 L
s
.25557 .59858 m
.26671 .59515 L
s
.27278 .58289 m
.27255 .58685 L
s
.32487 .53558 m
.3247 .53951 L
s
.35717 .49892 m
.35842 .50016 L
s
.42434 .49885 m
.42554 .50011 L
s
.37691 .48818 m
.37679 .49206 L
s
.31198 .49871 m
.31326 .49994 L
s
.42887 .44067 m
.42882 .44451 L
s
0 g
.5 Mabswid
.63673 .63014 m
.66225 .6228 L
s
.63673 .63014 m
.63825 .67494 L
s
.039 .916 .04 r
1 Mabswid
.37914 .49845 m
.38038 .49969 L
s
.30745 .55268 m
.30725 .55662 L
s
.33394 .49818 m
.33521 .49941 L
s
.35952 .50529 m
.35938 .50919 L
s
.41153 .4578 m
.41145 .46166 L
s
.46347 .41022 m
.46345 .41404 L
s
.40113 .49801 m
.40235 .49926 L
s
.28246 .49901 m
.29363 .49534 L
s
.47517 .40001 m
.48671 .39617 L
s
.29001 .56977 m
.28979 .57372 L
s
.35592 .49767 m
.35717 .49892 L
s
.42314 .4976 m
.42434 .49885 L
s
0 g
.5 Mabswid
.94117 .36038 m
.89453 .5439 L
s
.85284 .1502 m
.94117 .36038 L
s
.039 .916 .04 r
1 Mabswid
.34212 .5224 m
.34196 .52632 L
s
.3107 .49748 m
.31198 .49871 L
s
.39417 .47493 m
.39407 .47881 L
s
.44615 .42737 m
.44612 .4312 L
s
.44515 .49722 m
.44634 .49848 L
s
.37791 .4972 m
.37914 .49845 L
s
.33267 .49694 m
.33394 .49818 L
s
.3247 .53951 m
.32452 .54344 L
s
.39991 .49676 m
.40113 .49801 L
s
.37679 .49206 m
.37667 .49595 L
s
.42882 .44451 m
.42876 .44836 L
s
.35466 .49643 m
.35592 .49767 L
s
.42193 .49634 m
.42314 .4976 L
s
.30725 .55662 m
.30705 .56057 L
s
.30942 .49625 m
.3107 .49748 L
s
.35938 .50919 m
.35924 .5131 L
s
.41145 .46166 m
.41138 .46553 L
s
.46345 .41404 m
.46344 .41786 L
s
.44396 .49596 m
.44515 .49722 L
s
.37667 .49595 m
.37791 .4972 L
s
.28979 .57372 m
.28957 .57769 L
s
.3314 .4957 m
.33267 .49694 L
s
.46001 .49693 m
.47157 .49332 L
s
.26671 .59515 m
.2779 .59171 L
s
.39869 .4955 m
.39991 .49676 L
s
.34196 .52632 m
.3418 .53024 L
s
.39407 .47881 m
.39397 .48269 L
s
.44612 .4312 m
.44608 .43504 L
s
.35341 .49519 m
.35466 .49643 L
s
.42072 .49508 m
.42193 .49634 L
s
.30813 .49501 m
.30942 .49625 L
s
.32452 .54344 m
.32434 .54738 L
s
.44277 .49469 m
.44396 .49596 L
s
.37667 .49595 m
.37655 .49985 L
s
.37543 .4947 m
.37667 .49595 L
s
.42876 .44836 m
.4287 .45222 L
s
.33013 .49446 m
.3314 .4957 L
s
.30705 .56057 m
.30685 .56453 L
s
.39746 .49425 m
.39869 .4955 L
s
.48671 .39617 m
.4983 .39232 L
s
.29363 .49534 m
.30484 .49166 L
s
.35924 .5131 m
.3591 .51701 L
s
.41138 .46553 m
.41129 .4694 L
s
.35215 .49394 m
.35341 .49519 L
s
.46344 .41786 m
.46342 .42169 L
s
.41951 .49382 m
.42072 .49508 L
s
.30684 .49377 m
.30813 .49501 L
s
.28957 .57769 m
.28935 .58167 L
s
.37418 .49345 m
.37543 .4947 L
s
.3418 .53024 m
.34164 .53417 L
s
.44157 .49343 m
.44277 .49469 L
s
.39397 .48269 m
.39387 .48658 L
s
.44608 .43504 m
.44604 .43889 L
s
.32885 .49322 m
.33013 .49446 L
s
.39623 .49299 m
.39746 .49425 L
s
.32434 .54738 m
.32415 .55133 L
s
.35089 .49269 m
.35215 .49394 L
s
.37655 .49985 m
.37643 .50376 L
s
.4287 .45222 m
.42864 .45608 L
s
.48077 .4045 m
.48077 .40832 L
s
.4183 .49256 m
.41951 .49382 L
s
.30685 .56453 m
.30665 .56849 L
s
.37294 .4922 m
.37418 .49345 L
s
.44038 .49216 m
.44157 .49343 L
s
.47157 .49332 m
.48318 .4897 L
s
.3591 .51701 m
.35896 .52094 L
s
.32757 .49198 m
.32885 .49322 L
s
.41129 .4694 m
.41121 .47328 L
s
.46342 .42169 m
.4634 .42553 L
s
.2779 .59171 m
.28913 .58826 L
s
.46247 .49179 m
.46365 .49307 L
s
.395 .49173 m
.39623 .49299 L
s
.34962 .49145 m
.35089 .49269 L
s
.34164 .53417 m
.34147 .53811 L
s
.41708 .4913 m
.4183 .49256 L
s
.39387 .48658 m
.39377 .49048 L
s
.44604 .43889 m
.446 .44274 L
s
.37169 .49095 m
.37294 .4922 L
s
.43917 .4909 m
.44038 .49216 L
s
.32415 .55133 m
.32397 .55529 L
s
.32629 .49073 m
.32757 .49198 L
s
0 g
.5 Mabswid
.66406 .66769 m
.66225 .6228 L
s
.039 .916 .04 r
1 Mabswid
.37643 .50376 m
.3763 .50767 L
s
.46128 .49052 m
.46247 .49179 L
s
.42864 .45608 m
.42857 .45996 L
s
.48077 .40832 m
.48077 .41215 L
s
.4983 .39232 m
.50993 .38846 L
s
.39377 .49048 m
.395 .49173 L
s
.30484 .49166 m
.31609 .48796 L
s
.30665 .56849 m
.30644 .57247 L
s
.34836 .4902 m
.34962 .49145 L
s
.41586 .49004 m
.41708 .4913 L
s
.35896 .52094 m
.35882 .52487 L
s
.41121 .47328 m
.41113 .47717 L
s
.4634 .42553 m
.46337 .42938 L
s
.37044 .48969 m
.37169 .49095 L
s
.43797 .48963 m
.43917 .4909 L
s
.32501 .48949 m
.32629 .49073 L
s
.34147 .53811 m
.34131 .54206 L
s
.46009 .48925 m
.46128 .49052 L
s
.39377 .49048 m
.39366 .49438 L
s
.39253 .48922 m
.39377 .49048 L
s
.446 .44274 m
.44595 .44661 L
s
.34709 .48895 m
.34836 .4902 L
s
.41464 .48877 m
.41586 .49004 L
s
.32397 .55529 m
.32378 .55926 L
s
0 g
.5 Mabswid
.45369 .25047 m
.47153 .29327 L
s
.47153 .29327 m
.53693 .27061 L
s
.4983 .45701 m .60049 .46915 L .53446 .48984 L .656 .751 .92 r
F
0 g
.53446 .48984 m
.57923 .51868 L
s
.039 .916 .04 r
1 Mabswid
.3763 .50767 m
.37618 .5116 L
s
.42857 .45996 m
.42851 .46384 L
s
.48077 .41215 m
.48077 .41598 L
s
.48318 .4897 m
.49482 .48607 L
s
.36918 .48844 m
.37044 .48969 L
s
.43676 .48836 m
.43797 .48963 L
s
.32372 .48824 m
.32501 .48949 L
s
.28913 .58826 m
.3004 .58479 L
s
.30644 .57247 m
.30624 .57645 L
s
.4589 .48797 m
.46009 .48925 L
s
.39129 .48796 m
.39253 .48922 L
s
.35882 .52487 m
.35867 .52881 L
s
.41113 .47717 m
.41104 .48107 L
s
.46337 .42938 m
.46335 .43323 L
s
.34581 .4877 m
.34709 .48895 L
s
.41342 .48751 m
.41464 .48877 L
s
.34131 .54206 m
.34114 .54602 L
s
.36792 .48718 m
.36918 .48844 L
s
.39366 .49438 m
.39356 .4983 L
s
.43555 .48709 m
.43676 .48836 L
s
.44595 .44661 m
.44591 .45048 L
s
.49824 .39871 m
.49825 .40254 L
s
.50993 .38846 m
.5216 .3846 L
s
.32378 .55926 m
.3236 .56323 L
s
.45771 .4867 m
.4589 .48797 L
s
.31609 .48796 m
.32739 .48425 L
s
.39005 .4867 m
.39129 .48796 L
s
.37618 .5116 m
.37605 .51553 L
s
.34454 .48644 m
.34581 .4877 L
s
.42851 .46384 m
.42844 .46773 L
s
.48077 .41598 m
.48077 .41983 L
s
.47987 .48634 m
.48105 .48762 L
s
.41219 .48624 m
.41342 .48751 L
s
.36666 .48592 m
.36792 .48718 L
s
.35867 .52881 m
.35852 .53276 L
s
.43434 .48582 m
.43555 .48709 L
s
.41104 .48107 m
.41096 .48497 L
s
.46335 .43323 m
.46333 .43709 L
s
.45651 .48542 m
.45771 .4867 L
s
.3888 .48543 m
.39005 .4867 L
s
.34114 .54602 m
.34098 .54999 L
s
.34326 .48519 m
.34454 .48644 L
s
.39356 .4983 m
.39345 .50222 L
s
.47869 .48506 m
.47987 .48634 L
s
.44591 .45048 m
.44586 .45436 L
s
.49825 .40254 m
.49826 .40638 L
s
.41096 .48497 m
.41219 .48624 L
s
.49482 .48607 m
.50651 .48242 L
s
.3236 .56323 m
.32341 .56721 L
s
.3654 .48467 m
.36666 .48592 L
s
.43313 .48454 m
.43434 .48582 L
s
.3004 .58479 m
.31171 .58131 L
s
.37605 .51553 m
.37592 .51947 L
s
.42844 .46773 m
.42838 .47162 L
s
.48077 .41983 m
.48076 .42368 L
s
.38755 .48417 m
.3888 .48543 L
s
.45531 .48414 m
.45651 .48542 L
s
.34198 .48394 m
.34326 .48519 L
s
.35852 .53276 m
.35837 .53671 L
s
.4775 .48378 m
.47869 .48506 L
s
.41096 .48497 m
.41087 .48889 L
s
.40973 .4837 m
.41096 .48497 L
s
.46333 .43709 m
.4633 .44096 L
s
.36413 .48341 m
.3654 .48467 L
s
.43191 .48327 m
.43313 .48454 L
s
.34098 .54999 m
.34081 .55396 L
s
.5216 .3846 m
.53331 .38071 L
s
.39345 .50222 m
.39334 .50615 L
s
.32739 .48425 m
.33872 .48053 L
s
.44586 .45436 m
.44582 .45824 L
s
.49826 .40638 m
.49826 .41023 L
s
.3863 .4829 m
.38755 .48417 L
s
.45411 .48287 m
.45531 .48414 L
s
.3407 .48268 m
.34198 .48394 L
s
.32341 .56721 m
.32322 .5712 L
s
.47632 .48249 m
.4775 .48378 L
s
.40849 .48243 m
.40973 .4837 L
s
.37592 .51947 m
.37579 .52342 L
s
.42838 .47162 m
.42831 .47553 L
s
.48076 .42368 m
.48076 .42754 L
s
.36287 .48214 m
.36413 .48341 L
s
.43069 .48199 m
.43191 .48327 L
s
.35837 .53671 m
.35822 .54068 L
s
.41087 .48889 m
.41078 .49281 L
s
.38505 .48164 m
.3863 .4829 L
s
.4529 .48159 m
.45411 .48287 L
s
.4633 .44096 m
.46327 .44484 L
s
.51573 .39293 m
.51576 .39677 L
s
.47513 .48121 m
.47632 .48249 L
s
.34081 .55396 m
.34063 .55794 L
s
.40725 .48116 m
.40849 .48243 L
s
.50651 .48242 m
.51823 .47876 L
s
.39334 .50615 m
.39323 .51009 L
s
.44582 .45824 m
.44577 .46214 L
s
.49736 .48086 m
.49854 .48215 L
s
.49826 .41023 m
.49827 .41408 L
s
.36159 .48088 m
.36287 .48214 L
s
.31171 .58131 m
.32306 .57782 L
s
.42947 .48072 m
.43069 .48199 L
s
.38379 .48037 m
.38505 .48164 L
s
.37579 .52342 m
.37566 .52737 L
s
.45169 .4803 m
.4529 .48159 L
s
.42831 .47553 m
.42824 .47944 L
s
.48076 .42754 m
.48075 .43141 L
s
.47393 .47992 m
.47513 .48121 L
s
.40601 .47989 m
.40725 .48116 L
s
.35822 .54068 m
.35807 .54465 L
s
.36032 .47962 m
.36159 .48088 L
s
.49619 .47957 m
.49736 .48086 L
s
.41078 .49281 m
.41069 .49674 L
s
.46327 .44484 m
.46324 .44873 L
s
.53331 .38071 m
.54506 .37682 L
s
.42824 .47944 m
.42947 .48072 L
s
.33872 .48053 m
.35009 .4768 L
s
.34063 .55794 m
.34046 .56193 L
s
.38254 .4791 m
.38379 .48037 L
s
.45048 .47902 m
.45169 .4803 L
s
.39323 .51009 m
.39312 .51404 L
s
.44577 .46214 m
.44572 .46604 L
s
.49827 .41408 m
.49828 .41795 L
s
.4983 .41417 m .5699 .43409 L .4983 .45701 L .544 .324 .532 r
F
.4983 .41417 m .5691 .39104 L .5699 .43409 L F
0 g
.5 Mabswid
.4983 .37227 m
.4983 .41417 L
s
.56833 .34894 m
.5691 .39104 L
s
.039 .916 .04 r
1 Mabswid
.51576 .39677 m
.51578 .40062 L
s
.47274 .47863 m
.47393 .47992 L
s
.40477 .47862 m
.40601 .47989 L
s
.35904 .47836 m
.36032 .47962 L
s
.37566 .52737 m
.37553 .53134 L
s
.49501 .47827 m
.49619 .47957 L
s
.42824 .47944 m
.42817 .48336 L
s
.42701 .47816 m
.42824 .47944 L
s
.48075 .43141 m
.48074 .43529 L
s
.38127 .47783 m
.38254 .4791 L
s
.44927 .47774 m
.45048 .47902 L
s
.35807 .54465 m
.35792 .54863 L
s
.41069 .49674 m
.4106 .50068 L
s
.51823 .47876 m
.52978 .47484 L
s
.46324 .44873 m
.46321 .45262 L
s
.51578 .40062 m
.5158 .40447 L
s
.47154 .47734 m
.47274 .47863 L
s
.40352 .47734 m
.40477 .47862 L
s
.32306 .57782 m
.33445 .57432 L
s
.35776 .47709 m
.35904 .47836 L
s
.34046 .56193 m
.34029 .56593 L
s
.49382 .47698 m
.49501 .47827 L
s
.42578 .47688 m
.42701 .47816 L
s
.39312 .51404 m
.39301 .51799 L
s
.44572 .46604 m
.44567 .46996 L
s
.49828 .41795 m
.49828 .42182 L
s
.38001 .47656 m
.38127 .47783 L
s
.44805 .47645 m
.44927 .47774 L
s
.37553 .53134 m
.3754 .53531 L
s
.42817 .48336 m
.4281 .48729 L
s
.47034 .47605 m
.47154 .47734 L
s
.40227 .47607 m
.40352 .47734 L
s
.48074 .43529 m
.48073 .43918 L
s
.53331 .38713 m
.53335 .39097 L
s
0 g
.5 Mabswid
.63825 .67494 m
.66406 .66769 L
s
.63825 .67494 m
.58193 .65106 L
s
.039 .916 .04 r
1 Mabswid
.54506 .37682 m
.55686 .37291 L
s
.49264 .47568 m
.49382 .47698 L
s
.35792 .54863 m
.35777 .55262 L
s
.42455 .4756 m
.42578 .47688 L
s
.35009 .4768 m
.3615 .47305 L
s
.4106 .50068 m
.41051 .50463 L
s
.46321 .45262 m
.46318 .45653 L
s
.5158 .40447 m
.51583 .40833 L
s
.37874 .47529 m
.38001 .47656 L
s
.44684 .47517 m
.44805 .47645 L
s
.51558 .47515 m
.51684 .47642 L
s
.39301 .51799 m
.3929 .52196 L
s
.40102 .47479 m
.40227 .47607 L
s
.46914 .47476 m
.47034 .47605 L
s
.44567 .46996 m
.44562 .47388 L
s
.49828 .42182 m
.49829 .42569 L
s
.49145 .47439 m
.49264 .47568 L
s
.42331 .47432 m
.42455 .4756 L
s
.3754 .53531 m
.37526 .53929 L
s
.4281 .48729 m
.42802 .49123 L
s
.37747 .47402 m
.37874 .47529 L
s
.48073 .43918 m
.48072 .44307 L
s
.53335 .39097 m
.5334 .39482 L
s
.44562 .47388 m
.44684 .47517 L
s
.51432 .47387 m
.51558 .47515 L
s
.52978 .47484 m
.54136 .4709 L
s
.35777 .55262 m
.35761 .55662 L
s
.39976 .47351 m
.40102 .47479 L
s
.46793 .47347 m
.46914 .47476 L
s
.33445 .57432 m
.34588 .5708 L
s
.41051 .50463 m
.41041 .50858 L
s
.46318 .45653 m
.46315 .46044 L
s
.51583 .40833 m
.51585 .4122 L
s
.49026 .47309 m
.49145 .47439 L
s
.42207 .47303 m
.42331 .47432 L
s
.3762 .47274 m
.37747 .47402 L
s
.3929 .52196 m
.39278 .52593 L
s
.44562 .47388 m
.44556 .47781 L
s
.44439 .47259 m
.44562 .47388 L
s
.51306 .4726 m
.51432 .47387 L
s
.49829 .42569 m
.49829 .42958 L
s
.39851 .47223 m
.39976 .47351 L
s
.46672 .47217 m
.46793 .47347 L
s
.37526 .53929 m
.37513 .54328 L
s
.55686 .37291 m
.5687 .36898 L
s
.42802 .49123 m
.42795 .49518 L
s
.48072 .44307 m
.48071 .44697 L
s
.5334 .39482 m
.53344 .39868 L
s
.48907 .47179 m
.49026 .47309 L
s
.3615 .47305 m
.37296 .46929 L
s
.42083 .47175 m
.42207 .47303 L
s
.35761 .55662 m
.35745 .56063 L
s
.37492 .47147 m
.3762 .47274 L
s
.51181 .47131 m
.51306 .4726 L
s
.44316 .4713 m
.44439 .47259 L
s
.41041 .50858 m
.41032 .51254 L
s
.46315 .46044 m
.46312 .46436 L
s
.51585 .4122 m
.51587 .41607 L
s
.39725 .47095 m
.39851 .47223 L
s
.46551 .47088 m
.46672 .47217 L
s
.39278 .52593 m
.39266 .52991 L
s
.44556 .47781 m
.44551 .48174 L
s
.48788 .47049 m
.48907 .47179 L
s
.41958 .47046 m
.42083 .47175 L
s
.55099 .38129 m
.55105 .38513 L
s
.49829 .42958 m
.49829 .43347 L
s
0 g
.5 Mabswid
.89759 .25669 m
.89759 .25669 L
s
.89759 .25669 m
.88962 .28241 L
s
.039 .916 .04 r
1 Mabswid
.51057 .47003 m
.51181 .47131 L
s
.44193 .47001 m
.44316 .4713 L
s
.37513 .54328 m
.37499 .54728 L
s
.42795 .49518 m
.42787 .49913 L
s
.48071 .44697 m
.48069 .45088 L
s
.53344 .39868 m
.53348 .40255 L
s
.39598 .46967 m
.39725 .47095 L
s
.34588 .5708 m
.35735 .56727 L
s
.4643 .46958 m
.46551 .47088 L
s
.53297 .46929 m
.5342 .47055 L
s
.48668 .46919 m
.48788 .47049 L
s
.41032 .51254 m
.41022 .51652 L
s
.41834 .46918 m
.41958 .47046 L
s
.46312 .46436 m
.46308 .46829 L
s
.51587 .41607 m
.5159 .41996 L
s
.4407 .46872 m
.44193 .47001 L
s
.39266 .52991 m
.39255 .5339 L
s
.44551 .48174 m
.44545 .48569 L
s
.39472 .46839 m
.39598 .46967 L
s
.49829 .43347 m
.4983 .43738 L
s
.55105 .38513 m
.55111 .38899 L
s
.5687 .36898 m
.58057 .36504 L
s
.46308 .46829 m
.4643 .46958 L
s
.37296 .46929 m
.38446 .46551 L
s
.37499 .54728 m
.37485 .55128 L
s
.48548 .46789 m
.48668 .46919 L
s
.41708 .46789 m
.41834 .46918 L
s
0 g
.5 Mabswid
.53693 .27061 m
.50526 .23221 L
s
.4983 .45701 m .5699 .43409 L .60049 .46915 L .656 .751 .92 r
F
.039 .916 .04 r
1 Mabswid
.53174 .46803 m
.53297 .46929 L
s
.50933 .46874 m
.51057 .47003 L
s
.54136 .4709 m
.55299 .46695 L
s
0 g
.5 Mabswid
.60049 .46915 m
.6301 .50307 L
s
.63453 .63597 m
.66406 .66769 L
s
.039 .916 .04 r
1 Mabswid
.42787 .49913 m
.4278 .50309 L
s
.48069 .45088 m
.48068 .4548 L
s
.53348 .40255 m
.53352 .40642 L
s
.50809 .46745 m
.50933 .46874 L
s
.43947 .46742 m
.4407 .46872 L
s
.41022 .51652 m
.41012 .5205 L
s
.39345 .4671 m
.39472 .46839 L
s
.46308 .46829 m
.46305 .47222 L
s
.46186 .46699 m
.46308 .46829 L
s
.5159 .41996 m
.51592 .42385 L
s
.53051 .46677 m
.53174 .46803 L
s
.41583 .4666 m
.41708 .46789 L
s
.48427 .46658 m
.48548 .46789 L
s
.39255 .5339 m
.39243 .5379 L
s
.44545 .48569 m
.44539 .48964 L
s
.4983 .43738 m
.4983 .44129 L
s
.55111 .38899 m
.55117 .39286 L
s
.50685 .46616 m
.50809 .46745 L
s
.43823 .46613 m
.43947 .46742 L
s
.35735 .56727 m
.36886 .56373 L
s
.37485 .55128 m
.37471 .5553 L
s
.39218 .46582 m
.39345 .4671 L
s
.46064 .46569 m
.46186 .46699 L
s
.4278 .50309 m
.42772 .50706 L
s
.55299 .46695 m
.56467 .46298 L
s
.48068 .4548 m
.48066 .45873 L
s
.53352 .40642 m
.53356 .4103 L
s
.52928 .4655 m
.53051 .46677 L
s
.41458 .46531 m
.41583 .4666 L
s
.48307 .46528 m
.48427 .46658 L
s
.41012 .5205 m
.41002 .52448 L
s
.46305 .47222 m
.46301 .47617 L
s
.56868 .37544 m
.56877 .37929 L
s
.50562 .46486 m
.50685 .46616 L
s
.51592 .42385 m
.51594 .42775 L
s
.43699 .46483 m
.43823 .46613 L
s
.58057 .36504 m
.5925 .36107 L
s
.45942 .46439 m
.46064 .46569 L
s
.39243 .5379 m
.3923 .5419 L
s
.44539 .48964 m
.44534 .4936 L
s
.38446 .46551 m
.39599 .46172 L
s
.52806 .46422 m
.52928 .4655 L
s
.4983 .44129 m
.4983 .44521 L
s
.55117 .39286 m
.55123 .39673 L
s
.41332 .46402 m
.41458 .46531 L
s
.48186 .46397 m
.48307 .46528 L
s
.42772 .50706 m
.42764 .51104 L
s
.50439 .46356 m
.50562 .46486 L
s
.43575 .46353 m
.43699 .46483 L
s
.48066 .45873 m
.48065 .46266 L
s
.53356 .4103 m
.5336 .41419 L
s
.55046 .46341 m
.55167 .46465 L
s
.45819 .46308 m
.45942 .46439 L
s
.52685 .46295 m
.52806 .46422 L
s
.41002 .52448 m
.40992 .52848 L
s
.46301 .47617 m
.46297 .48012 L
s
.56877 .37929 m
.56885 .38315 L
s
.51594 .42775 m
.51596 .43166 L
s
.41205 .46272 m
.41332 .46402 L
s
.48065 .46266 m
.48186 .46397 L
s
.3923 .5419 m
.39218 .54592 L
s
.50317 .46226 m
.50439 .46356 L
s
.4345 .46224 m
.43575 .46353 L
s
.44534 .4936 m
.44528 .49757 L
s
.54925 .46216 m
.55046 .46341 L
s
.36886 .56373 m
.38042 .56018 L
s
.4983 .44521 m
.4983 .44913 L
s
.55123 .39673 m
.55128 .40061 L
s
.45696 .46178 m
.45819 .46308 L
s
.56467 .46298 m
.57639 .459 L
s
.52563 .46167 m
.52685 .46295 L
s
.42764 .51104 m
.42756 .51503 L
s
.41079 .46143 m
.41205 .46272 L
s
.48065 .46266 m
.48063 .46661 L
s
.47943 .46135 m
.48065 .46266 L
s
.5336 .41419 m
.53364 .41809 L
s
.50194 .46095 m
.50317 .46226 L
s
.43325 .46094 m
.4345 .46224 L
s
.5925 .36107 m
.60446 .3571 L
s
.54805 .4609 m
.54925 .46216 L
s
.40992 .52848 m
.40982 .53249 L
s
.46297 .48012 m
.46293 .48408 L
s
.56885 .38315 m
.56894 .38702 L
s
.51596 .43166 m
.51598 .43558 L
s
.45573 .46047 m
.45696 .46178 L
s
.39599 .46172 m
.40758 .45792 L
s
.52442 .46039 m
.52563 .46167 L
s
.39218 .54592 m
.39206 .54994 L
s
.40952 .46013 m
.41079 .46143 L
s
.47821 .46004 m
.47943 .46135 L
s
.44528 .49757 m
.44521 .50155 L
s
.4983 .44913 m
.4983 .45307 L
s
.55128 .40061 m
.55134 .4045 L
s
.50073 .45964 m
.50194 .46095 L
s
.432 .45963 m
.43325 .46094 L
s
.54685 .45964 m
.54805 .4609 L
s
.42756 .51503 m
.42748 .51903 L
s
.58654 .36953 m
.58665 .37338 L
s
.48063 .46661 m
.48061 .47056 L
s
.53364 .41809 m
.53368 .422 L
s
.45449 .45917 m
.45573 .46047 L
s
.52322 .4591 m
.52442 .46039 L
s
.47699 .45873 m
.47821 .46004 L
s
.40982 .53249 m
.40971 .5365 L
s
.46293 .48408 m
.46289 .48805 L
s
.56894 .38702 m
.56903 .3909 L
s
.51598 .43558 m
.516 .4395 L
s
.54566 .45838 m
.54685 .45964 L
s
.49951 .45833 m
.50073 .45964 L
s
.43074 .45833 m
.432 .45963 L
s
.38042 .56018 m
.39201 .55661 L
s
.44521 .50155 m
.44515 .50554 L
s
.45325 .45786 m
.45449 .45917 L
s
.55134 .4045 m
.5514 .4084 L
s
.52201 .45782 m
.52322 .4591 L
s
.57639 .459 m
.58815 .455 L
s
.47577 .45742 m
.47699 .45873 L
s
.56805 .45748 m
.56923 .45872 L
s
.42748 .51903 m
.42739 .52303 L
s
.48061 .47056 m
.48059 .47452 L
s
.58665 .37338 m
.58675 .37725 L
s
.60446 .3571 m
.61647 .35311 L
s
.54447 .45712 m
.54566 .45838 L
s
.42949 .45703 m
.43074 .45833 L
s
.40971 .5365 m
.40961 .54052 L
s
.40758 .45792 m
.4192 .4541 L
s
.45201 .45655 m
.45325 .45786 L
s
.46289 .48805 m
.46285 .49203 L
s
.56903 .3909 m
.56911 .39478 L
s
.44515 .50554 m
.44509 .50954 L
s
.42823 .45573 m
.42949 .45703 L
s
.4983 .45701 m .57071 .47811 L .4983 .50081 L .544 .324 .532 r
F
0 g
.5 Mabswid
.53415 .48957 m
.53446 .48984 L
s
.4983 .45701 m .5699 .43409 L .57071 .47811 L .544 .324 .532 r
F
.47062 .41996 m .5699 .43409 L .4983 .45701 L .656 .751 .92 r
F
.039 .916 .04 r
1 Mabswid
.4971 .45569 m
.4983 .45701 L
s
.4983 .46096 m
.4983 .45701 L
s
0 0 0 r
.16236 .56456 m
.4983 .45701 L
s
0 g
.5 Mabswid
.4983 .41417 m
.4983 .4239 L
s
.039 .916 .04 r
1 Mabswid
.47454 .45611 m
.47577 .45742 L
s
.53368 .422 m
.53372 .42591 L
s
.5514 .4084 m
.55146 .4123 L
s
.45076 .45524 m
.45201 .45655 L
s
.42739 .52303 m
.42731 .52704 L
s
.48059 .47452 m
.48056 .47849 L
s
.58675 .37725 m
.58686 .38113 L
s
.53372 .42591 m
.53375 .42894 L
s
.47332 .45479 m
.47454 .45611 L
s
.39201 .55661 m
.40365 .55303 L
s
.40961 .54052 m
.4095 .54455 L
s
.42696 .45442 m
.42823 .45573 L
s
.49589 .45437 m
.4971 .45569 L
s
.46285 .49203 m
.4628 .49601 L
s
.56911 .39478 m
.56919 .39867 L
s
.44952 .45393 m
.45076 .45524 L
s
.58815 .455 m
.59986 .45088 L
s
.44509 .50954 m
.44502 .51354 L
s
.6045 .36358 m
.60463 .36744 L
s
.4983 .46096 m
.4983 .46492 L
s
.55146 .4123 m
.55152 .41621 L
s
.47209 .45347 m
.47332 .45479 L
s
.61647 .35311 m
.62852 .34911 L
s
.49469 .45304 m
.49589 .45437 L
s
.42731 .52704 m
.42722 .53107 L
s
.48056 .47849 m
.48054 .48246 L
s
.58686 .38113 m
.58696 .38501 L
s
.4192 .4541 m
.43086 .45027 L
s
.44827 .45262 m
.44952 .45393 L
s
.4628 .49601 m
.46276 .50001 L
s
.47085 .45216 m
.47209 .45347 L
s
.56919 .39867 m
.56928 .40258 L
s
.4935 .45171 m
.49469 .45304 L
s
.44502 .51354 m
.44496 .51755 L
s
.60463 .36744 m
.60475 .37132 L
s
.4983 .46492 m
.4983 .46889 L
s
.55152 .41621 m
.55157 .42014 L
s
.44701 .45131 m
.44827 .45262 L
s
.58637 .45133 m
.58762 .45252 L
s
.42722 .53107 m
.42713 .5351 L
s
.46961 .45084 m
.47085 .45216 L
s
.48054 .48246 m
.48052 .48645 L
s
.58696 .38501 m
.58707 .3889 L
s
.40365 .55303 m
.41533 .54944 L
s
.49231 .45038 m
.4935 .45171 L
s
.46276 .50001 m
.46271 .50401 L
s
.58513 .45013 m
.58637 .45133 L
s
.51606 .45133 m
.51607 .45528 L
s
.51488 .45002 m
.51606 .45133 L
s
.56928 .40258 m
.56936 .40649 L
s
.44576 .44999 m
.44701 .45131 L
s
.59986 .45088 m
.61162 .44673 L
s
.62852 .34911 m
.64061 .34509 L
s
.46837 .44952 m
.46961 .45084 L
s
0 g
.5 Mabswid
.44659 .20188 m
.45369 .25047 L
s
.45369 .25047 m
.50526 .23221 L
s
.58193 .65106 m
.63453 .63597 L
s
.58193 .65106 m
.53568 .62318 L
s
.039 .916 .04 r
1 Mabswid
.44496 .51755 m
.44489 .52157 L
s
.60475 .37132 m
.60488 .3752 L
s
.4983 .46889 m
.4983 .47286 L
s
.55157 .42014 m
.55163 .42407 L
s
.49112 .44904 m
.49231 .45038 L
s
.43086 .45027 m
.44257 .44642 L
s
.5839 .44893 m
.58513 .45013 L
s
.42713 .5351 m
.42704 .53913 L
s
.5137 .44871 m
.51488 .45002 L
s
.4445 .44867 m
.44576 .44999 L
s
.48052 .48645 m
.48049 .49044 L
s
.58707 .3889 m
.58717 .3928 L
s
.46713 .4482 m
.46837 .44952 L
s
.46271 .50401 m
.46267 .50802 L
s
.62256 .3576 m
.6227 .36147 L
s
.51607 .45528 m
.51609 .45925 L
s
.56936 .40649 m
.56944 .4104 L
s
.48993 .4477 m
.49112 .44904 L
s
.58268 .44772 m
.5839 .44893 L
s
.51252 .44739 m
.5137 .44871 L
s
.44489 .52157 m
.44482 .5256 L
s
.4983 .47286 m
.4983 .47685 L
s
.60488 .3752 m
.605 .37909 L
s
.55163 .42407 m
.55169 .428 L
s
.41533 .54944 m
.42706 .54583 L
s
.46589 .44687 m
.46713 .4482 L
s
.48049 .49044 m
.48046 .49445 L
s
.58717 .3928 m
.58727 .39671 L
s
.58146 .4465 m
.58268 .44772 L
s
.48875 .44635 m
.48993 .4477 L
s
.51136 .44608 m
.51252 .44739 L
s
.46267 .50802 m
.46262 .51204 L
s
.6227 .36147 m
.62285 .36535 L
s
.64061 .34509 m
.65275 .34105 L
s
.51609 .45925 m
.51611 .46322 L
s
.56944 .4104 m
.56952 .41433 L
s
.46464 .44555 m
.46589 .44687 L
s
.61162 .44673 m
.62342 .44258 L
s
.58026 .44529 m
.58146 .4465 L
s
.44482 .5256 m
.44475 .52964 L
s
.44257 .44642 m
.45432 .44256 L
s
.60402 .4452 m
.60524 .44637 L
s
.4983 .47685 m
.49829 .48084 L
s
.48758 .44501 m
.48875 .44635 L
s
.605 .37909 m
.60512 .38299 L
s
.55169 .428 m
.55174 .4315 L
s
.51019 .44475 m
.51136 .44608 L
s
.48046 .49445 m
.48044 .49846 L
s
.53391 .44561 m
.53394 .44958 L
s
.53275 .44432 m
.53391 .44561 L
s
.58727 .39671 m
.58737 .40063 L
s
.46339 .44422 m
.46464 .44555 L
s
.57907 .44406 m
.58026 .44529 L
s
.60282 .44403 m
.60402 .4452 L
s
.46262 .51204 m
.46257 .51607 L
s
.4864 .44366 m
.48758 .44501 L
s
.62285 .36535 m
.62299 .36924 L
s
.51611 .46322 m
.51612 .4672 L
s
.56952 .41433 m
.5696 .41826 L
s
.50903 .44343 m
.51019 .44475 L
s
.42706 .54583 m
.43882 .54221 L
s
.44475 .52964 m
.44468 .53369 L
s
.5316 .44302 m
.53275 .44432 L
s
.46213 .4429 m
.46339 .44422 L
s
.49829 .48084 m
.49829 .48484 L
s
.60512 .38299 m
.60524 .3869 L
s
.57789 .44283 m
.57907 .44406 L
s
.60162 .44284 m
.60282 .44403 L
s
.48523 .4423 m
.4864 .44366 L
s
.48044 .49846 m
.48041 .50248 L
s
.64071 .35159 m
.64088 .35547 L
s
.53394 .44958 m
.53398 .45355 L
s
.58737 .40063 m
.58747 .40455 L
s
.50787 .4421 m
.50903 .44343 L
s
.65275 .34105 m
.66493 .33701 L
s
0 g
.5 Mabswid
.79241 .30999 m
.85284 .1502 L
s
.039 .916 .04 r
1 Mabswid
.53045 .44172 m
.5316 .44302 L
s
.46257 .51607 m
.46252 .52011 L
s
.60043 .44166 m
.60162 .44284 L
s
.57672 .4416 m
.57789 .44283 L
s
.62299 .36924 m
.62313 .37314 L
s
.51612 .4672 m
.51614 .47119 L
s
.5696 .41826 m
.56967 .42221 L
s
.62342 .44258 m
.63527 .4384 L
s
.45432 .44256 m
.46611 .43869 L
s
.48407 .44095 m
.48523 .4423 L
s
.50671 .44077 m
.50787 .4421 L
s
.49829 .48484 m
.49829 .48885 L
s
.60524 .3869 m
.60536 .39081 L
s
.52931 .44041 m
.53045 .44172 L
s
.59926 .44047 m
.60043 .44166 L
s
.57555 .44036 m
.57672 .4416 L
s
.48041 .50248 m
.48037 .5065 L
s
.64088 .35547 m
.64104 .35936 L
s
.53398 .45355 m
.53401 .45753 L
s
.58747 .40455 m
.58757 .40848 L
s
.48291 .43958 m
.48407 .44095 L
s
.50556 .43944 m
.50671 .44077 L
s
.46252 .52011 m
.46246 .52415 L
s
.62313 .37314 m
.62327 .37704 L
s
.51614 .47119 m
.51616 .47519 L
s
.56967 .42221 m
.56975 .42616 L
s
.43882 .54221 m
.45063 .53858 L
s
.59809 .43927 m
.59926 .44047 L
s
.52817 .4391 m
.52931 .44041 L
s
.5744 .43912 m
.57555 .44036 L
s
.62177 .43904 m
.62295 .44019 L
s
.49829 .48885 m
.49828 .49286 L
s
.60536 .39081 m
.60548 .39473 L
s
.55185 .43987 m
.55191 .44384 L
s
.55072 .43858 m
.55185 .43987 L
s
.48175 .43822 m
.48291 .43958 L
s
.66493 .33701 m
.67716 .33294 L
s
.50441 .4381 m
.50556 .43944 L
s
.59693 .43807 m
.59809 .43927 L
s
.48037 .5065 m
.48034 .51054 L
s
.64104 .35936 m
.6412 .36325 L
s
.53401 .45753 m
.53405 .46152 L
s
.58757 .40848 m
.58766 .41243 L
s
.57326 .43787 m
.5744 .43912 L
s
.52703 .43779 m
.52817 .4391 L
s
.62061 .43788 m
.62177 .43904 L
s
.46611 .43869 m
.47795 .4348 L
s
.46246 .52415 m
.46241 .52821 L
s
.5496 .4373 m
.55072 .43858 L
s
.51616 .47519 m
.51617 .4792 L
s
.62327 .37704 m
.62341 .38096 L
s
.56975 .42616 m
.56982 .43012 L
s
.63527 .4384 m
.64716 .43421 L
s
.48059 .43685 m
.48175 .43822 L
s
.50327 .43676 m
.50441 .4381 L
s
.59579 .43686 m
.59693 .43807 L
s
.61944 .43672 m
.62061 .43788 L
s
.57213 .43661 m
.57326 .43787 L
s
.65897 .34555 m
.65915 .34943 L
s
.5259 .43648 m
.52703 .43779 L
s
.49828 .49286 m
.49828 .49689 L
s
.60548 .39473 m
.6056 .39867 L
s
.55191 .44384 m
.55196 .44781 L
s
.54847 .43601 m
.5496 .4373 L
s
.48034 .51054 m
.48031 .51459 L
s
.6412 .36325 m
.64136 .36716 L
s
.53405 .46152 m
.53408 .46551 L
s
.58766 .41243 m
.58776 .41638 L
s
.59465 .43565 m
.59579 .43686 L
s
.50213 .43542 m
.50327 .43676 L
s
.61829 .43556 m
.61944 .43672 L
s
.45063 .53858 m
.46249 .53493 L
s
.57101 .43535 m
.57213 .43661 L
s
.52477 .43516 m
.5259 .43648 L
s
.51617 .4792 m
.51618 .48322 L
s
.62341 .38096 m
.62355 .38488 L
s
.54736 .43472 m
.54847 .43601 L
s
.59352 .43443 m
.59465 .43565 L
s
.65915 .34943 m
.65933 .35333 L
s
.67716 .33294 m
.68943 .32887 L
s
.49828 .49689 m
.49827 .50092 L
s
.61715 .43439 m
.61829 .43556 L
s
.55196 .44781 m
.55201 .4518 L
s
.6056 .39867 m
.60572 .40261 L
s
.48031 .51459 m
.48027 .51864 L
s
.64136 .36716 m
.64152 .37107 L
s
.53408 .46551 m
.53411 .46952 L
s
.58776 .41638 m
.58785 .42034 L
s
.59241 .43321 m
.59352 .43443 L
s
.61602 .43322 m
.61715 .43439 L
s
.64716 .43421 m
.65911 .43 L
s
.62355 .38488 m
.62369 .38881 L
s
0 g
.5 Mabswid
.50526 .23221 m
.47252 .1925 L
s
.60399 .60316 m
.63453 .63597 L
s
.47062 .41996 m .53825 .39783 L .5699 .43409 L .656 .751 .92 r
F
.039 .916 .04 r
1 Mabswid
.5688 .43282 m
.5699 .43409 L
s
0 0 0 r
.5699 .43409 m
.87264 .33716 L
s
.039 .916 .04 r
.5699 .43409 m
.56997 .43807 L
s
.54624 .43342 m
.54736 .43472 L
s
.47795 .4348 m
.49007 .43116 L
s
.52364 .43384 m
.52477 .43516 L
s
.5699 .43409 m
.57101 .43535 L
s
.50099 .43407 m
.50213 .43542 L
s
.56982 .43012 m
.5699 .43409 L
s
0 g
.5 Mabswid
.5699 .43409 m
.60049 .46915 L
s
0 0 0 r
1 Mabswid
.4983 .45701 m
.5699 .43409 L
s
0 g
.5 Mabswid
.5691 .39104 m
.5699 .43409 L
s
.039 .916 .04 r
1 Mabswid
.49986 .43272 m
.50099 .43407 L
s
.63963 .43284 m
.64078 .43397 L
s
.52252 .43252 m
.52364 .43384 L
s
.4983 .50081 m .57154 .52314 L .4983 .5456 L .544 .324 .532 r
F
.4983 .50081 m .57071 .47811 L .57154 .52314 L F
0 g
.5 Mabswid
.4983 .45701 m
.4983 .50081 L
s
.5699 .43409 m
.57071 .47811 L
s
.039 .916 .04 r
1 Mabswid
.51618 .48322 m
.5162 .48724 L
s
.49827 .50092 m
.49827 .50496 L
s
.65933 .35333 m
.65952 .35723 L
s
.54513 .43213 m
.54624 .43342 L
s
.55201 .4518 m
.55207 .4558 L
s
.60572 .40261 m
.60583 .40656 L
s
.6149 .43204 m
.61602 .43322 L
s
.5913 .43199 m
.59241 .43321 L
s
.6385 .43171 m
.63963 .43284 L
s
.56771 .43154 m
.5688 .43282 L
s
.46249 .53493 m
.47438 .53127 L
s
.48027 .51864 m
.48024 .5227 L
s
.49873 .43136 m
.49986 .43272 L
s
.64152 .37107 m
.64168 .37499 L
s
.53411 .46952 m
.53415 .47353 L
s
.58785 .42034 m
.58795 .4243 L
s
.5214 .43119 m
.52252 .43252 L
s
.54402 .43082 m
.54513 .43213 L
s
.61379 .43086 m
.6149 .43204 L
s
.67732 .33947 m
.67753 .34336 L
s
.5902 .43076 m
.5913 .43199 L
s
.5162 .48724 m
.51621 .49127 L
s
.62369 .38881 m
.62383 .39275 L
s
.56997 .43807 m
.57004 .44205 L
s
.68943 .32887 m
.70174 .32477 L
s
.63737 .43057 m
.6385 .43171 L
s
.56662 .43026 m
.56771 .43154 L
s
.49827 .50496 m
.49826 .50901 L
s
.65952 .35723 m
.6597 .36114 L
s
.55207 .4558 m
.55212 .4598 L
s
.52029 .42986 m
.5214 .43119 L
s
.60583 .40656 m
.60595 .41051 L
s
.49007 .43116 m
.50223 .4275 L
s
.61269 .42967 m
.61379 .43086 L
s
.54292 .42952 m
.54402 .43082 L
s
.58912 .42952 m
.5902 .43076 L
s
.63626 .42943 m
.63737 .43057 L
s
.53415 .47353 m
.53418 .47755 L
s
.64168 .37499 m
.64184 .37892 L
s
.58795 .4243 m
.58804 .42828 L
s
.56555 .42898 m
.56662 .43026 L
s
.65911 .43 m
.6711 .42578 L
s
.51918 .42852 m
.52029 .42986 L
s
.67753 .34336 m
.67773 .34726 L
s
.51621 .49127 m
.51622 .49531 L
s
.62383 .39275 m
.62396 .3967 L
s
.57004 .44205 m
.57011 .44605 L
s
.6116 .42848 m
.61269 .42967 L
s
.58804 .42828 m
.58912 .42952 L
s
.54182 .42821 m
.54292 .42952 L
s
.63515 .42828 m
.63626 .42943 L
s
.49826 .50901 m
.49825 .51307 L
s
.6597 .36114 m
.65988 .36506 L
s
.55212 .4598 m
.55217 .46381 L
s
.60595 .41051 m
.60606 .41448 L
s
.56449 .42769 m
.56555 .42898 L
s
.47438 .53127 m
.48632 .5276 L
s
.51807 .42719 m
.51918 .42852 L
s
0 g
.5 Mabswid
.88962 .28241 m
.88131 .30921 L
s
.039 .916 .04 r
1 Mabswid
.61051 .42728 m
.6116 .42848 L
s
.53418 .47755 m
.53421 .48159 L
s
.64184 .37892 m
.642 .38286 L
s
.63406 .42713 m
.63515 .42828 L
s
.58804 .42828 m
.58813 .43226 L
s
.58697 .42703 m
.58804 .42828 L
s
.54072 .4269 m
.54182 .42821 L
s
.70174 .32477 m
.7141 .32067 L
s
.6576 .4266 m
.6587 .42771 L
s
.56344 .42639 m
.56449 .42769 L
s
.67773 .34726 m
.67793 .35117 L
s
.51622 .49531 m
.51624 .49936 L
s
.57011 .44605 m
.57018 .45005 L
s
.62396 .3967 m
.6241 .40065 L
s
.50223 .4275 m
.51442 .42383 L
s
.60944 .42608 m
.61051 .42728 L
s
.51697 .42585 m
.51807 .42719 L
s
.63297 .42598 m
.63406 .42713 L
s
.58592 .42578 m
.58697 .42703 L
s
.49825 .51307 m
.49824 .51714 L
s
.53963 .42559 m
.54072 .4269 L
s
.65988 .36506 m
.66005 .36899 L
s
.55217 .46381 m
.55222 .46783 L
s
.60606 .41448 m
.60617 .41846 L
s
.6565 .42549 m
.6576 .4266 L
s
.5624 .42509 m
.56344 .42639 L
s
.69578 .33336 m
.696 .33726 L
s
.53421 .48159 m
.53425 .48562 L
s
.642 .38286 m
.64216 .3868 L
s
.58813 .43226 m
.58822 .43626 L
s
.60838 .42487 m
.60944 .42608 L
s
.63189 .42482 m
.63297 .42598 L
s
.58487 .42453 m
.58592 .42578 L
s
.6711 .42578 m
.68314 .42153 L
s
.53854 .42427 m
.53963 .42559 L
s
.65541 .42438 m
.6565 .42549 L
s
.67793 .35117 m
.67813 .35509 L
s
.51624 .49936 m
.51625 .50342 L
s
.57018 .45005 m
.57025 .45406 L
s
.6241 .40065 m
.62423 .40462 L
s
.56137 .42378 m
.5624 .42509 L
s
.48632 .5276 m
.4983 .52392 L
s
.60733 .42366 m
.60838 .42487 L
s
.63083 .42365 m
.63189 .42482 L
s
.66005 .36899 m
.66023 .37292 L
s
.55222 .46783 m
.55228 .47186 L
s
.60617 .41846 m
.60628 .42244 L
s
.58383 .42326 m
.58487 .42453 L
s
.65433 .42326 m
.65541 .42438 L
s
.53745 .42295 m
.53854 .42427 L
s
.696 .33726 m
.69622 .34117 L
s
.7141 .32067 m
.72651 .31655 L
s
.53425 .48562 m
.53428 .48967 L
s
.64216 .3868 m
.64231 .39076 L
s
.58822 .43626 m
.58831 .44026 L
s
.51442 .42383 m
.52667 .42015 L
s
.56036 .42247 m
.56137 .42378 L
s
.60628 .42244 m
.60733 .42366 L
s
.62977 .42248 m
.63083 .42365 L
s
.58281 .422 m
.58383 .42326 L
s
.51625 .50342 m
.51626 .50748 L
s
.65326 .42214 m
.65433 .42326 L
s
.67813 .35509 m
.67833 .35902 L
s
.57025 .45406 m
.57032 .45808 L
s
.62423 .40462 m
.62437 .40859 L
s
.53637 .42163 m
.53745 .42295 L
s
.62872 .42131 m
.62977 .42248 L
s
.66023 .37292 m
.66041 .37687 L
s
.55228 .47186 m
.55233 .4759 L
s
.55935 .42115 m
.56036 .42247 L
s
.60628 .42244 m
.6064 .42643 L
s
.60525 .42122 m
.60628 .42244 L
s
.6522 .42101 m
.65326 .42214 L
s
.58179 .42073 m
.58281 .422 L
s
.69622 .34117 m
.69644 .34508 L
s
.53428 .48967 m
.53431 .49373 L
s
.64231 .39076 m
.64247 .39472 L
s
.58831 .44026 m
.5884 .44427 L
s
.53529 .4203 m
.53637 .42163 L
s
.68314 .42153 m
.69522 .41728 L
s
.67566 .42033 m
.67674 .42141 L
s
.62768 .42013 m
.62872 .42131 L
s
.60423 .41999 m
.60525 .42122 L
s
.55835 .41983 m
.55935 .42115 L
s
.4983 .52392 m
.51033 .52021 L
s
.51626 .50748 m
.51627 .51156 L
s
.67833 .35902 m
.67853 .36295 L
s
.65114 .41988 m
.6522 .42101 L
s
.57032 .45808 m
.57038 .46211 L
s
.62437 .40859 m
.6245 .41258 L
s
.58078 .41945 m
.58179 .42073 L
s
.71433 .32722 m
.71457 .33112 L
s
.6746 .41924 m
.67566 .42033 L
s
.55233 .4759 m
.55238 .47995 L
s
.66041 .37687 m
.66058 .38082 L
s
.6064 .42643 m
.6065 .43043 L
s
.72651 .31655 m
.73896 .31241 L
s
.62666 .41895 m
.62768 .42013 L
s
.60322 .41876 m
.60423 .41999 L
s
.45215 .37816 m .53825 .39783 L .47062 .41996 L .656 .751 .92 r
F
.039 .916 .04 r
.52667 .42015 m
.53895 .41646 L
s
0 g
.5 Mabswid
.47062 .41996 m
.4983 .45701 L
s
.53568 .62318 m
.60399 .60316 L
s
.039 .916 .04 r
1 Mabswid
.6501 .41874 m
.65114 .41988 L
s
.55736 .4185 m
.55835 .41983 L
s
.69644 .34508 m
.69666 .34901 L
s
.53431 .49373 m
.53434 .49779 L
s
.64247 .39472 m
.64262 .39869 L
s
.5884 .44427 m
.58849 .44829 L
s
.57979 .41817 m
.58078 .41945 L
s
.67355 .41815 m
.6746 .41924 L
s
.62564 .41776 m
.62666 .41895 L
s
.67853 .36295 m
.67872 .36689 L
s
.57038 .46211 m
.57045 .46615 L
s
.6245 .41258 m
.62463 .41657 L
s
.60221 .41752 m
.60322 .41876 L
s
.64907 .4176 m
.6501 .41874 L
s
.55638 .41717 m
.55736 .4185 L
s
.71457 .33112 m
.71482 .33504 L
s
.5788 .41688 m
.57979 .41817 L
s
.6725 .41706 m
.67355 .41815 L
s
.55238 .47995 m
.55243 .484 L
s
.66058 .38082 m
.66076 .38478 L
s
.6065 .43043 m
.60661 .43444 L
s
.62463 .41657 m
.62564 .41776 L
s
.64805 .41646 m
.64907 .4176 L
s
.60122 .41628 m
.60221 .41752 L
s
.69666 .34901 m
.69688 .35294 L
s
.53434 .49779 m
.53437 .50187 L
s
.58849 .44829 m
.58857 .45232 L
s
.64262 .39869 m
.64277 .40267 L
s
.69522 .41728 m
.70736 .413 L
s
.55541 .41583 m
.55638 .41717 L
s
.51033 .52021 m
.5224 .51648 L
s
.67147 .41596 m
.6725 .41706 L
s
.57783 .41559 m
.5788 .41688 L
s
.67872 .36689 m
.67892 .37085 L
s
.57045 .46615 m
.57051 .47019 L
s
.62463 .41657 m
.62476 .42057 L
s
.62363 .41537 m
.62463 .41657 L
s
.53895 .41646 m
.55128 .41275 L
s
.64703 .41531 m
.64805 .41646 L
s
.60024 .41503 m
.60122 .41628 L
s
.73896 .31241 m
.75146 .30826 L
s
.71482 .33504 m
.71506 .33896 L
s
.67044 .41486 m
.67147 .41596 L
s
.55243 .484 m
.55248 .48806 L
s
.66076 .38478 m
.66093 .38875 L
s
.60661 .43444 m
.60672 .43846 L
s
.55446 .41449 m
.55541 .41583 L
s
.57686 .41429 m
.57783 .41559 L
s
.62264 .41417 m
.62363 .41537 L
s
.64603 .41415 m
.64703 .41531 L
s
.53437 .50187 m
.5344 .50595 L
s
.69688 .35294 m
.6971 .35688 L
s
.58857 .45232 m
.58866 .45635 L
s
.64277 .40267 m
.64292 .40666 L
s
.69384 .41402 m
.69488 .41508 L
s
.59926 .41378 m
.60024 .41503 L
s
.66942 .41375 m
.67044 .41486 L
s
.73299 .32104 m
.73325 .32495 L
s
.57051 .47019 m
.57058 .47425 L
s
.67892 .37085 m
.67912 .37481 L
s
.62476 .42057 m
.62489 .42457 L
s
.5759 .41299 m
.57686 .41429 L
s
.62166 .41296 m
.62264 .41417 L
s
.64503 .41299 m
.64603 .41415 L
s
.69281 .41296 m
.69384 .41402 L
s
.5983 .41252 m
.59926 .41378 L
s
.66841 .41263 m
.66942 .41375 L
s
.71506 .33896 m
.7153 .34289 L
s
.55248 .48806 m
.55253 .49214 L
s
.66093 .38875 m
.66111 .39273 L
s
.60672 .43846 m
.60683 .44249 L
s
.5224 .51648 m
.53452 .51275 L
s
.70736 .413 m
.71954 .40871 L
s
.64405 .41183 m
.64503 .41299 L
s
.57496 .41168 m
.5759 .41299 L
s
.62069 .41175 m
.62166 .41296 L
s
.69179 .41189 m
.69281 .41296 L
s
.6971 .35688 m
.69732 .36083 L
s
.58866 .45635 m
.58874 .4604 L
s
.64292 .40666 m
.64307 .41066 L
s
.55128 .41275 m
.56375 .40915 L
s
.66742 .41152 m
.66841 .41263 L
s
.59734 .41126 m
.5983 .41252 L
s
.75146 .30826 m
.764 .30409 L
s
.73325 .32495 m
.73351 .32887 L
s
.57058 .47425 m
.57064 .47831 L
s
.67912 .37481 m
.67931 .37877 L
s
.62489 .42457 m
.62502 .42859 L
s
.69078 .41082 m
.69179 .41189 L
s
.64307 .41066 m
.64405 .41183 L
s
.61973 .41053 m
.62069 .41175 L
s
.57402 .41037 m
.57496 .41168 L
s
.66643 .4104 m
.66742 .41152 L
s
.7153 .34289 m
.71554 .34683 L
s
.55253 .49214 m
.55258 .49622 L
s
.66111 .39273 m
.66128 .39672 L
s
.60683 .44249 m
.60693 .44652 L
s
.5964 .40999 m
.59734 .41126 L
s
.68978 .40974 m
.69078 .41082 L
s
.69732 .36083 m
.69753 .36479 L
s
.58874 .4604 m
.58883 .46445 L
s
.64307 .41066 m
.64322 .41467 L
s
.64211 .40949 m
.64307 .41066 L
s
.61878 .40931 m
.61973 .41053 L
s
.66545 .40927 m
.66643 .4104 L
s
.5731 .40905 m
.57402 .41037 L
s
.73351 .32887 m
.73377 .3328 L
s
.59547 .40872 m
.5964 .40999 L
s
.57064 .47831 m
.5707 .48238 L
s
.67931 .37877 m
.6795 .38275 L
s
.62502 .42859 m
.62514 .43262 L
s
.68879 .40866 m
.68978 .40974 L
s
.64115 .40831 m
.64211 .40949 L
s
.4983 .5456 m .57239 .56922 L .49831 .59141 L .544 .324 .532 r
F
0 g
.5 Mabswid
.49831 .59141 m
.53568 .62318 L
s
.4983 .5456 m .57154 .52314 L .57239 .56922 L .544 .324 .532 r
F
0 g
.4983 .50081 m
.4983 .5456 L
s
.4983 .5456 m
.49831 .59141 L
s
.57071 .47811 m
.57154 .52314 L
s
.039 .916 .04 r
1 Mabswid
.61784 .40808 m
.61878 .40931 L
s
.71554 .34683 m
.71577 .35078 L
s
.66448 .40814 m
.66545 .40927 L
s
.53452 .51275 m
.54668 .509 L
s
.55258 .49622 m
.55262 .5003 L
s
.60693 .44652 m
.60704 .45056 L
s
.66128 .39672 m
.66145 .40072 L
s
.56375 .40915 m
.57626 .40554 L
s
.59454 .40744 m
.59547 .40872 L
s
.71954 .40871 m
.73178 .4044 L
s
.71212 .40767 m
.71312 .40871 L
s
.68781 .40758 m
.68879 .40866 L
s
.75175 .31483 m
.75203 .31875 L
s
.69753 .36479 m
.69775 .36876 L
s
.58883 .46445 m
.58891 .46851 L
s
.64322 .41467 m
.64337 .41868 L
s
.764 .30409 m
.77659 .29991 L
s
.6402 .40713 m
.64115 .40831 L
s
.66352 .40701 m
.66448 .40814 L
s
.61691 .40685 m
.61784 .40808 L
s
.73377 .3328 m
.73404 .33674 L
s
.5707 .48238 m
.57076 .48647 L
s
.6795 .38275 m
.6797 .38674 L
s
.62514 .43262 m
.62527 .43665 L
s
.71113 .40663 m
.71212 .40767 L
s
.68683 .40649 m
.68781 .40758 L
s
.59363 .40616 m
.59454 .40744 L
s
.63927 .40594 m
.6402 .40713 L
s
.71577 .35078 m
.71601 .35474 L
s
.66256 .40587 m
.66352 .40701 L
s
.60704 .45056 m
.60714 .45462 L
s
.66145 .40072 m
.66162 .40472 L
s
.61599 .40561 m
.61691 .40685 L
s
.71014 .40559 m
.71113 .40663 L
s
.68587 .4054 m
.68683 .40649 L
s
0 g
.5 Mabswid
.47252 .1925 m
.44659 .20188 L
s
.446 .24382 m
.44659 .20188 L
s
.039 .916 .04 r
1 Mabswid
.75203 .31875 m
.75231 .32268 L
s
.69775 .36876 m
.69796 .37273 L
s
.58891 .46851 m
.58899 .47259 L
s
.64337 .41868 m
.64352 .42271 L
s
.59273 .40487 m
.59363 .40616 L
s
.63834 .40475 m
.63927 .40594 L
s
.66162 .40472 m
.66256 .40587 L
s
.61507 .40437 m
.61599 .40561 L
s
.73404 .33674 m
.73429 .34069 L
s
.70917 .40454 m
.71014 .40559 L
s
.57076 .48647 m
.57082 .49056 L
s
.57626 .40554 m
.58882 .40191 L
s
.6797 .38674 m
.67989 .39073 L
s
.62527 .43665 m
.62539 .44069 L
s
.68491 .4043 m
.68587 .4054 L
s
.54668 .509 m
.55889 .50523 L
s
.59183 .40358 m
.59273 .40487 L
s
.71601 .35474 m
.71625 .3587 L
s
.63742 .40355 m
.63834 .40475 L
s
.60714 .45462 m
.60724 .45868 L
s
.66162 .40472 m
.66179 .40874 L
s
.66069 .40357 m
.66162 .40472 L
s
.7082 .40349 m
.70917 .40454 L
s
.77659 .29991 m
.78922 .29571 L
s
.73178 .4044 m
.74406 .40007 L
s
.61417 .40312 m
.61507 .40437 L
s
.68397 .4032 m
.68491 .4043 L
s
.75231 .32268 m
.7526 .32661 L
s
.58899 .47259 m
.58907 .47667 L
s
.69796 .37273 m
.69818 .37672 L
s
.64352 .42271 m
.64367 .42674 L
s
.65976 .40242 m
.66069 .40357 L
s
.63651 .40235 m
.63742 .40355 L
s
.70724 .40244 m
.7082 .40349 L
s
.73429 .34069 m
.73455 .34464 L
s
.57082 .49056 m
.57087 .49465 L
s
.67989 .39073 m
.68008 .39474 L
s
.62539 .44069 m
.62552 .44474 L
s
.68303 .40209 m
.68397 .4032 L
s
.61328 .40187 m
.61417 .40312 L
s
.77061 .30858 m
.77092 .31251 L
s
.71625 .3587 m
.71649 .36268 L
s
.60724 .45868 m
.60735 .46275 L
s
.66179 .40874 m
.66196 .41276 L
s
.70629 .40138 m
.70724 .40244 L
s
.65885 .40126 m
.65976 .40242 L
s
.63561 .40114 m
.63651 .40235 L
s
.73051 .40129 m
.73148 .4023 L
s
.6821 .40098 m
.68303 .40209 L
s
.58882 .40191 m
.60142 .39828 L
s
.7526 .32661 m
.75288 .33056 L
s
.6124 .40061 m
.61328 .40187 L
s
.58907 .47667 m
.58915 .48076 L
s
.69818 .37672 m
.69839 .38071 L
s
.64367 .42674 m
.64381 .43078 L
s
.70535 .40031 m
.70629 .40138 L
s
.55889 .50523 m
.57114 .50145 L
s
.72955 .40027 m
.73051 .40129 L
s
.65795 .4001 m
.65885 .40126 L
s
.63472 .39993 m
.63561 .40114 L
s
.73455 .34464 m
.73481 .34861 L
s
.68008 .39474 m
.68027 .39875 L
s
.62552 .44474 m
.62564 .44881 L
s
.68118 .39987 m
.6821 .40098 L
s
.61153 .39935 m
.6124 .40061 L
s
.78922 .29571 m
.8019 .29149 L
s
.77092 .31251 m
.77122 .31644 L
s
.70442 .39924 m
.70535 .40031 L
s
.71649 .36268 m
.71672 .36666 L
s
.60735 .46275 m
.60745 .46683 L
s
.7286 .39925 m
.72955 .40027 L
s
.66196 .41276 m
.66213 .41679 L
s
.65705 .39893 m
.65795 .4001 L
s
.74406 .40007 m
.75639 .39572 L
s
.63384 .39871 m
.63472 .39993 L
s
.68027 .39875 m
.68118 .39987 L
s
.75288 .33056 m
.75316 .33451 L
s
.58915 .48076 m
.58923 .48485 L
s
.69839 .38071 m
.6986 .38472 L
s
.64381 .43078 m
.64396 .43483 L
s
.61066 .39809 m
.61153 .39935 L
s
.72766 .39823 m
.7286 .39925 L
s
.7035 .39817 m
.70442 .39924 L
s
.65616 .39776 m
.65705 .39893 L
s
.73481 .34861 m
.73507 .35258 L
s
.62564 .44881 m
.62576 .45288 L
s
.68027 .39875 m
.68046 .40277 L
s
.67937 .39763 m
.68027 .39875 L
s
.63297 .39749 m
.63384 .39871 L
s
.60142 .39828 m
.61406 .39463 L
s
.72673 .3972 m
.72766 .39823 L
s
.77122 .31644 m
.77152 .32039 L
s
.70259 .3971 m
.7035 .39817 L
s
.71672 .36666 m
.71696 .37065 L
s
.60745 .46683 m
.60755 .47092 L
s
.66213 .41679 m
.66229 .42083 L
s
0 g
.5 Mabswid
.47252 .1925 m
.47222 .23449 L
s
.45215 .37816 m .50551 .36031 L .53825 .39783 L .656 .751 .92 r
F
0 g
.53825 .39783 m
.5699 .43409 L
s
.57239 .56922 m
.60399 .60316 L
s
.039 .916 .04 r
1 Mabswid
.65529 .39659 m
.65616 .39776 L
s
.67848 .3965 m
.67937 .39763 L
s
.63211 .39627 m
.63297 .39749 L
s
.75316 .33451 m
.75344 .33847 L
s
.58923 .48485 m
.5893 .48896 L
s
.57114 .50145 m
.58344 .49767 L
s
.6986 .38472 m
.69882 .38873 L
s
.64396 .43483 m
.6441 .43889 L
s
.72581 .39617 m
.72673 .3972 L
s
.70168 .39601 m
.70259 .3971 L
s
.78958 .3023 m
.78991 .30624 L
s
.65442 .39541 m
.65529 .39659 L
s
.73507 .35258 m
.73533 .35656 L
s
.62576 .45288 m
.62588 .45695 L
s
.6776 .39537 m
.67848 .3965 L
s
.68046 .40277 m
.68065 .4068 L
s
.8019 .29149 m
.81463 .28727 L
s
.63126 .39504 m
.63211 .39627 L
s
.72489 .39514 m
.72581 .39617 L
s
.70079 .39493 m
.70168 .39601 L
s
.77152 .32039 m
.77182 .32434 L
s
.74902 .39486 m
.74995 .39585 L
s
.60755 .47092 m
.60764 .47502 L
s
.71696 .37065 m
.71719 .37465 L
s
.66229 .42083 m
.66246 .42488 L
s
.75639 .39572 m
.76877 .39136 L
s
.65356 .39422 m
.65442 .39541 L
s
.67673 .39423 m
.6776 .39537 L
s
.72398 .3941 m
.72489 .39514 L
s
.75344 .33847 m
.75372 .34244 L
s
.63042 .3938 m
.63126 .39504 L
s
.69882 .38873 m
.69903 .39275 L
s
.6441 .43889 m
.64424 .44296 L
s
.6999 .39384 m
.70079 .39493 L
s
.74809 .39387 m
.74902 .39486 L
s
.61406 .39463 m
.62675 .39096 L
s
.78991 .30624 m
.79023 .31018 L
s
.73533 .35656 m
.73558 .36055 L
s
.62588 .45695 m
.626 .46104 L
s
.68065 .4068 m
.68084 .41084 L
s
.67586 .39309 m
.67673 .39423 L
s
.65271 .39303 m
.65356 .39422 L
s
.72309 .39305 m
.72398 .3941 L
s
.74717 .39288 m
.74809 .39387 L
s
.69903 .39275 m
.6999 .39384 L
s
.62959 .39256 m
.63042 .3938 L
s
.77182 .32434 m
.77213 .3283 L
s
.60764 .47502 m
.60774 .47912 L
s
.71719 .37465 m
.71742 .37866 L
s
.66246 .42488 m
.66262 .42894 L
s
.58344 .49767 m
.59578 .49387 L
s
.67501 .39195 m
.67586 .39309 L
s
.7222 .39201 m
.72309 .39305 L
s
.65188 .39184 m
.65271 .39303 L
s
.74627 .39188 m
.74717 .39288 L
s
.75372 .34244 m
.75399 .34642 L
s
.69903 .39275 m
.69924 .39678 L
s
.69816 .39165 m
.69903 .39275 L
s
.64424 .44296 m
.64439 .44704 L
s
.81463 .28727 m
.8274 .28302 L
s
.79023 .31018 m
.79055 .31413 L
s
.73558 .36055 m
.73584 .36455 L
s
.626 .46104 m
.62612 .46514 L
s
.72132 .39096 m
.7222 .39201 L
s
.68084 .41084 m
.68102 .41489 L
s
.67416 .39079 m
.67501 .39195 L
s
.74537 .39088 m
.74627 .39188 L
s
.65105 .39064 m
.65188 .39184 L
s
.6973 .39055 m
.69816 .39165 L
s
.77213 .3283 m
.77243 .33227 L
s
.76877 .39136 m
.7812 .38698 L
s
.60774 .47912 m
.60784 .48324 L
s
.71742 .37866 m
.71765 .38268 L
s
.66262 .42894 m
.66279 .43301 L
s
.62675 .39096 m
.63947 .38729 L
s
.72045 .3899 m
.72132 .39096 L
s
.74448 .38987 m
.74537 .39088 L
s
.67333 .38964 m
.67416 .39079 L
s
.80865 .29599 m
.809 .29993 L
s
.65023 .38943 m
.65105 .39064 L
s
.75399 .34642 m
.75427 .35041 L
s
.69645 .38944 m
.6973 .39055 L
s
.64439 .44704 m
.64453 .45112 L
s
.69924 .39678 m
.69945 .40081 L
s
.79055 .31413 m
.79088 .31809 L
s
.71958 .38884 m
.72045 .3899 L
s
.7436 .38886 m
.74448 .38987 L
s
.73584 .36455 m
.73609 .36856 L
s
.62612 .46514 m
.62624 .46924 L
s
.68102 .41489 m
.68121 .41895 L
s
.6725 .38848 m
.67333 .38964 L
s
.69561 .38833 m
.69645 .38944 L
s
.64942 .38822 m
.65023 .38943 L
s
.76763 .3884 m
.76853 .38936 L
s
.59578 .49387 m
.60817 .49006 L
s
.77243 .33227 m
.77273 .33625 L
s
.71765 .38268 m
.71789 .38671 L
s
.66279 .43301 m
.66295 .43708 L
s
.74272 .38785 m
.7436 .38886 L
s
.71873 .38778 m
.71958 .38884 L
s
.8274 .28302 m
.84023 .27876 L
s
.67168 .38732 m
.6725 .38848 L
s
.809 .29993 m
.80935 .30388 L
s
.76674 .38744 m
.76763 .3884 L
s
.69478 .38721 m
.69561 .38833 L
s
.75427 .35041 m
.75455 .35441 L
s
.64862 .38701 m
.64942 .38822 L
s
.64453 .45112 m
.64467 .45522 L
s
.69945 .40081 m
.69965 .40486 L
s
.74186 .38683 m
.74272 .38785 L
s
.71789 .38671 m
.71873 .38778 L
s
.79088 .31809 m
.7912 .32205 L
s
.73609 .36856 m
.73635 .37258 L
s
.62624 .46924 m
.62636 .47336 L
s
.68121 .41895 m
.6814 .42301 L
s
.76585 .38647 m
.76674 .38744 L
s
.67088 .38615 m
.67168 .38732 L
s
.63947 .38729 m
.65224 .3836 L
s
.69395 .3861 m
.69478 .38721 L
s
.7812 .38698 m
.79369 .38258 L
s
.741 .38581 m
.74186 .38683 L
s
.77273 .33625 m
.77303 .34023 L
s
.71789 .38671 m
.71812 .39075 L
s
.71705 .38564 m
.71789 .38671 L
s
.66295 .43708 m
.66311 .44117 L
s
.76498 .38549 m
.76585 .38647 L
s
.80935 .30388 m
.80969 .30783 L
s
.67008 .38498 m
.67088 .38615 L
s
.69314 .38497 m
.69395 .3861 L
s
.75455 .35441 m
.75482 .35842 L
s
.64467 .45522 m
.64481 .45932 L
s
.69965 .40486 m
.69986 .40892 L
s
.74015 .38478 m
.741 .38581 L
s
.71622 .38456 m
.71705 .38564 L
s
.76411 .38451 m
.76498 .38549 L
s
0 g
.5 Mabswid
.57154 .52314 m
.57239 .56922 L
s
.039 .916 .04 r
1 Mabswid
.7912 .32205 m
.79152 .32603 L
s
.62636 .47336 m
.62647 .47748 L
s
.73635 .37258 m
.7366 .3766 L
s
.60817 .49006 m
.62061 .48624 L
s
.6814 .42301 m
.68158 .42709 L
s
.66929 .3838 m
.67008 .38498 L
s
.69234 .38384 m
.69314 .38497 L
s
0 g
.5 Mabswid
.49831 .59141 m
.57239 .56922 L
s
.46965 .55552 m
.49831 .59141 L
s
.039 .916 .04 r
1 Mabswid
.73931 .38375 m
.74015 .38478 L
s
.82783 .28964 m
.8282 .29358 L
s
.7154 .38348 m
.71622 .38456 L
s
.77303 .34023 m
.77332 .34423 L
s
.76326 .38353 m
.76411 .38451 L
s
.84023 .27876 m
.8531 .27448 L
s
.71812 .39075 m
.71835 .39479 L
s
.66311 .44117 m
.66327 .44526 L
s
.80969 .30783 m
.81004 .3118 L
s
.69154 .38271 m
.69234 .38384 L
s
.66851 .38262 m
.66929 .3838 L
s
0 g
.5 Mabswid
.87264 .33716 m
.88131 .30921 L
s
.039 .916 .04 r
1 Mabswid
.73848 .38272 m
.73931 .38375 L
s
.75482 .35842 m
.7551 .36243 L
s
.64481 .45932 m
.64494 .46344 L
s
.69986 .40892 m
.70007 .41298 L
s
.65224 .3836 m
.66506 .3799 L
s
.76241 .38255 m
.76326 .38353 L
s
.7146 .3824 m
.7154 .38348 L
s
.79152 .32603 m
.79184 .33001 L
s
.7366 .3766 m
.73685 .38064 L
s
.68158 .42709 m
.68176 .43117 L
s
.78635 .3819 m
.78722 .38284 L
s
.73766 .38168 m
.73848 .38272 L
s
.69075 .38157 m
.69154 .38271 L
s
.66774 .38143 m
.66851 .38262 L
s
.79369 .38258 m
.80622 .37817 L
s
.76157 .38156 m
.76241 .38255 L
s
.8282 .29358 m
.82857 .29754 L
s
.71379 .38131 m
.7146 .3824 L
s
.77332 .34423 m
.77362 .34823 L
s
.71835 .39479 m
.71857 .39885 L
s
.66327 .44526 m
.66343 .44937 L
s
.78549 .38096 m
.78635 .3819 L
s
0 g
.5 Mabswid
.44539 .28673 m
.446 .24382 L
s
.446 .24382 m
.47222 .23449 L
s
.039 .916 .04 r
1 Mabswid
.73685 .38064 m
.73766 .38168 L
s
.81004 .3118 m
.81038 .31577 L
s
.68998 .38043 m
.69075 .38157 L
s
.76074 .38057 m
.76157 .38156 L
s
.7551 .36243 m
.75537 .36646 L
s
.64494 .46344 m
.64508 .46756 L
s
.70007 .41298 m
.70027 .41705 L
s
.713 .38021 m
.71379 .38131 L
s
.62061 .48624 m
.63309 .4824 L
s
.78465 .38001 m
.78549 .38096 L
s
.79184 .33001 m
.79216 .33401 L
s
.73685 .38064 m
.7371 .38468 L
s
.73605 .37959 m
.73685 .38064 L
s
.68176 .43117 m
.68195 .43527 L
s
.75991 .37957 m
.76074 .38057 L
s
.8531 .27448 m
.86602 .27019 L
s
.68921 .37929 m
.68998 .38043 L
s
.71222 .37912 m
.713 .38021 L
s
.82857 .29754 m
.82894 .3015 L
s
.78381 .37907 m
.78465 .38001 L
s
.77362 .34823 m
.77392 .35225 L
s
.66506 .3799 m
.67792 .37619 L
s
.66343 .44937 m
.66359 .45348 L
s
.71857 .39885 m
.7188 .40291 L
s
.73525 .37854 m
.73605 .37959 L
s
.7591 .37857 m
.75991 .37957 L
s
.68845 .37814 m
.68921 .37929 L
s
.81038 .31577 m
.81072 .31975 L
s
.75537 .36646 m
.75565 .37049 L
s
.64508 .46756 m
.64522 .47169 L
s
.71145 .37802 m
.71222 .37912 L
s
.70027 .41705 m
.70048 .42114 L
s
.78297 .37811 m
.78381 .37907 L
s
.84712 .28325 m
.84751 .2872 L
s
.75829 .37757 m
.7591 .37857 L
s
.73446 .37749 m
.73525 .37854 L
s
.79216 .33401 m
.79248 .33801 L
s
.7371 .38468 m
.73735 .38873 L
s
.68195 .43527 m
.68213 .43937 L
s
.80622 .37817 m
.8188 .37373 L
s
.44477 .33065 m .50551 .36031 L .45215 .37816 L .656 .751 .92 r
F
0 g
.5 Mabswid
.45215 .37816 m
.47062 .41996 L
s
.039 .916 .04 r
1 Mabswid
.6877 .37698 m
.68845 .37814 L
s
.78215 .37716 m
.78297 .37811 L
s
.71068 .37691 m
.71145 .37802 L
s
.82894 .3015 m
.8293 .30547 L
s
.77392 .35225 m
.77422 .35627 L
s
.66359 .45348 m
.66375 .4576 L
s
.75749 .37656 m
.75829 .37757 L
s
.7188 .40291 m
.71903 .40698 L
s
.73369 .37643 m
.73446 .37749 L
s
.78133 .3762 m
.78215 .37716 L
s
.63309 .4824 m
.64562 .47854 L
s
.68696 .37582 m
.6877 .37698 L
s
.81072 .31975 m
.81107 .32375 L
s
.70993 .3758 m
.71068 .37691 L
s
.75565 .37049 m
.75592 .37453 L
s
.70048 .42114 m
.70068 .42523 L
s
.7567 .37555 m
.75749 .37656 L
s
.73292 .37537 m
.73369 .37643 L
s
.84751 .2872 m
.8479 .29117 L
s
.80519 .37536 m
.80602 .37627 L
s
.78052 .37524 m
.78133 .3762 L
s
.67792 .37619 m
.69082 .37247 L
s
.79248 .33801 m
.7928 .34202 L
s
.73735 .38873 m
.7376 .3928 L
s
.68213 .43937 m
.68231 .44348 L
s
.70918 .37469 m
.70993 .3758 L
s
.75592 .37453 m
.7567 .37555 L
s
.8293 .30547 m
.82967 .30946 L
s
.73216 .3743 m
.73292 .37537 L
s
.80437 .37444 m
.80519 .37536 L
s
.77422 .35627 m
.77451 .3603 L
s
.66375 .4576 m
.66391 .46173 L
s
.71903 .40698 m
.71926 .41106 L
s
.77972 .37427 m
.78052 .37524 L
s
.70844 .37357 m
.70918 .37469 L
s
.81107 .32375 m
.81141 .32775 L
s
.75592 .37453 m
.75619 .37858 L
s
.75515 .37351 m
.75592 .37453 L
s
.70068 .42523 m
.70088 .42933 L
s
.80355 .37353 m
.80437 .37444 L
s
.7314 .37323 m
.73216 .3743 L
s
.77893 .3733 m
.77972 .37427 L
s
.8479 .29117 m
.84829 .29514 L
s
.7928 .34202 m
.79312 .34604 L
s
.7376 .3928 m
.73785 .39687 L
s
.68231 .44348 m
.68249 .4476 L
s
.8188 .37373 m
.83144 .36928 L
s
.70771 .37244 m
.70844 .37357 L
s
.80274 .3726 m
.80355 .37353 L
s
.75438 .37249 m
.75515 .37351 L
s
.77815 .37233 m
.77893 .3733 L
s
.73066 .37216 m
.7314 .37323 L
s
.82967 .30946 m
.83003 .31345 L
s
.77451 .3603 m
.77481 .36434 L
s
.66391 .46173 m
.66407 .46587 L
s
.64562 .47854 m
.6582 .47467 L
s
0 g
.5 Mabswid
.47222 .23449 m
.47192 .27747 L
s
.039 .916 .04 r
1 Mabswid
.71926 .41106 m
.71948 .41515 L
s
.80194 .37168 m
.80274 .3726 L
s
.75363 .37146 m
.75438 .37249 L
s
.69082 .37247 m
.70376 .36873 L
s
.70699 .37132 m
.70771 .37244 L
s
.81141 .32775 m
.81175 .33176 L
s
.77738 .37135 m
.77815 .37233 L
s
.75619 .37858 m
.75647 .38264 L
s
.70088 .42933 m
.70109 .43344 L
s
.72993 .37108 m
.73066 .37216 L
s
.84829 .29514 m
.84868 .29912 L
s
.80115 .37075 m
.80194 .37168 L
s
.79312 .34604 m
.79344 .35007 L
s
.75288 .37043 m
.75363 .37146 L
s
.68249 .4476 m
.68267 .45173 L
s
.73785 .39687 m
.7381 .40095 L
s
.77661 .37037 m
.77738 .37135 L
s
.70628 .37019 m
.70699 .37132 L
s
.7292 .36999 m
.72993 .37108 L
s
.83003 .31345 m
.8304 .31744 L
s
.80037 .36981 m
.80115 .37075 L
s
.77481 .36434 m
.7751 .36839 L
s
.71948 .41515 m
.71971 .41925 L
s
.75214 .36939 m
.75288 .37043 L
s
.77585 .36938 m
.77661 .37037 L
s
.81175 .33176 m
.81209 .33578 L
s
.72848 .36891 m
.7292 .36999 L
s
.75647 .38264 m
.75674 .38671 L
s
.70109 .43344 m
.70129 .43756 L
s
.79959 .36888 m
.80037 .36981 L
s
.82414 .36878 m
.82494 .36967 L
s
.75141 .36836 m
.75214 .36939 L
s
.84868 .29912 m
.84906 .3031 L
s
.7751 .36839 m
.77585 .36938 L
s
.83144 .36928 m
.84413 .36481 L
s
.79344 .35007 m
.79376 .35411 L
s
.68267 .45173 m
.68284 .45587 L
s
.7381 .40095 m
.73835 .40504 L
s
.72778 .36782 m
.72848 .36891 L
s
.79882 .36794 m
.79959 .36888 L
s
.6582 .47467 m
.67082 .47079 L
s
.82335 .36789 m
.82414 .36878 L
s
.70376 .36873 m
.71675 .36498 L
s
.8304 .31744 m
.83076 .32145 L
s
.7751 .36839 m
.77539 .37245 L
s
.77436 .3674 m
.7751 .36839 L
s
.75069 .36731 m
.75141 .36836 L
s
.71971 .41925 m
.71993 .42336 L
s
0 g
.5 Mabswid
.91933 .44631 m
.90391 .41027 L
s
.91933 .44631 m
.91933 .44631 L
s
.039 .916 .04 r
1 Mabswid
.79806 .36699 m
.79882 .36794 L
s
.82257 .367 m
.82335 .36789 L
s
.72708 .36672 m
.72778 .36782 L
s
.81209 .33578 m
.81243 .3398 L
s
.75674 .38671 m
.75701 .39079 L
s
.70129 .43756 m
.70149 .44169 L
s
.77363 .3664 m
.77436 .3674 L
s
.74998 .36626 m
.75069 .36731 L
s
.84906 .3031 m
.84945 .3071 L
s
.82179 .3661 m
.82257 .367 L
s
.79731 .36604 m
.79806 .36699 L
s
.79376 .35411 m
.79407 .35816 L
s
.68284 .45587 m
.68302 .46001 L
s
.73835 .40504 m
.73859 .40913 L
s
.72639 .36562 m
.72708 .36672 L
s
.7729 .3654 m
.77363 .3664 L
s
.74927 .36521 m
.74998 .36626 L
s
.83076 .32145 m
.83112 .32547 L
s
.82102 .3652 m
.82179 .3661 L
s
.77539 .37245 m
.77569 .37652 L
s
.79657 .36509 m
.79731 .36604 L
s
.71993 .42336 m
.72015 .42748 L
s
.7257 .36452 m
.72639 .36562 L
s
.77218 .3644 m
.7729 .3654 L
s
.81243 .3398 m
.81277 .34384 L
s
.75701 .39079 m
.75728 .39488 L
s
.70149 .44169 m
.70169 .44582 L
s
.74858 .36416 m
.74927 .36521 L
s
.82026 .3643 m
.82102 .3652 L
s
.79583 .36414 m
.79657 .36509 L
s
.71675 .36498 m
.72979 .36121 L
s
.84413 .36481 m
.85686 .36032 L
s
.67082 .47079 m
.6835 .46689 L
s
.84945 .3071 m
.84984 .31111 L
s
.79407 .35816 m
.79439 .36222 L
s
.73859 .40913 m
.73884 .41324 L
s
.77148 .36339 m
.77218 .3644 L
s
.81951 .36339 m
.82026 .3643 L
s
.74789 .3631 m
.74858 .36416 L
s
.79511 .36318 m
.79583 .36414 L
s
.83112 .32547 m
.83149 .3295 L
s
.77569 .37652 m
.77598 .38059 L
s
.72015 .42748 m
.72038 .4316 L
s
.81877 .36248 m
.81951 .36339 L
s
.77078 .36238 m
.77148 .36339 L
s
.79439 .36222 m
.79511 .36318 L
s
.74721 .36204 m
.74789 .3631 L
s
.81277 .34384 m
.81311 .34789 L
s
.8432 .36216 m
.84397 .36302 L
s
.75728 .39488 m
.75754 .39897 L
s
.70169 .44582 m
.70189 .44997 L
s
.81803 .36156 m
.81877 .36248 L
s
.77008 .36136 m
.77078 .36238 L
s
.84984 .31111 m
.85022 .31512 L
s
.79439 .36222 m
.7947 .36628 L
s
.79368 .36125 m
.79439 .36222 L
s
.84245 .3613 m
.8432 .36216 L
s
.73884 .41324 m
.73908 .41736 L
s
.74654 .36097 m
.74721 .36204 L
s
.81731 .36065 m
.81803 .36156 L
s
.83149 .3295 m
.83185 .33353 L
s
.77598 .38059 m
.77627 .38468 L
s
.72038 .4316 m
.7206 .43574 L
s
.7694 .36034 m
.77008 .36136 L
s
.8417 .36043 m
.84245 .3613 L
s
.79297 .36028 m
.79368 .36125 L
s
.72979 .36121 m
.74287 .35744 L
s
.74588 .3599 m
.74654 .36097 L
s
.81311 .34789 m
.81345 .35194 L
s
.81659 .35973 m
.81731 .36065 L
s
.70189 .44997 m
.70208 .45413 L
s
.75754 .39897 m
.75781 .40308 L
s
.6835 .46689 m
.69622 .46298 L
s
.84095 .35956 m
.8417 .36043 L
s
.76872 .35932 m
.7694 .36034 L
s
.85686 .36032 m
.86966 .35582 L
s
.44477 .33065 m .4716 .32146 L .50551 .36031 L .656 .751 .92 r
F
0 g
.5 Mabswid
.4716 .32146 m
.50551 .36031 L
s
.50551 .36031 m
.53825 .39783 L
s
.44477 .33065 m
.45215 .37816 L
s
.53967 .53407 m
.57239 .56922 L
s
.039 .916 .04 r
1 Mabswid
.79228 .35931 m
.79297 .36028 L
s
.85022 .31512 m
.85061 .31915 L
s
.74523 .35882 m
.74588 .3599 L
s
.7947 .36628 m
.79502 .37036 L
s
.73908 .41736 m
.73933 .42148 L
s
.81587 .3588 m
.81659 .35973 L
s
.84022 .35869 m
.84095 .35956 L
s
.76806 .35829 m
.76872 .35932 L
s
.79159 .35833 m
.79228 .35931 L
s
.83185 .33353 m
.83221 .33757 L
s
.77627 .38468 m
.77656 .38878 L
s
.7206 .43574 m
.72082 .43989 L
s
.81517 .35787 m
.81587 .3588 L
s
.83949 .35781 m
.84022 .35869 L
s
.81345 .35194 m
.81378 .35601 L
s
.79091 .35735 m
.79159 .35833 L
s
.7674 .35726 m
.76806 .35829 L
s
.75781 .40308 m
.75808 .40719 L
s
0 g
.5 Mabswid
.90391 .41027 m
.88835 .37389 L
s
.039 .916 .04 r
1 Mabswid
.81447 .35694 m
.81517 .35787 L
s
.83877 .35693 m
.83949 .35781 L
s
.85061 .31915 m
.85099 .32318 L
s
.79502 .37036 m
.79533 .37444 L
s
.73933 .42148 m
.73957 .42562 L
s
.74287 .35744 m
.756 .35365 L
s
.79024 .35637 m
.79091 .35735 L
s
.76675 .35623 m
.7674 .35726 L
s
.81378 .35601 m
.81447 .35694 L
s
.83806 .35604 m
.83877 .35693 L
s
.83221 .33757 m
.83257 .34163 L
s
.77656 .38878 m
.77685 .39288 L
s
.72082 .43989 m
.72104 .44404 L
s
0 g
.5 Mabswid
.44477 .33065 m
.44539 .28673 L
s
.44539 .28673 m
.47192 .27747 L
s
.039 .916 .04 r
1 Mabswid
.69622 .46298 m
.70898 .45905 L
s
.78958 .35538 m
.79024 .35637 L
s
.86239 .3555 m
.86312 .35634 L
s
.76611 .35519 m
.76675 .35623 L
s
.83736 .35516 m
.83806 .35604 L
s
.81378 .35601 m
.81412 .36008 L
s
.8131 .35507 m
.81378 .35601 L
s
.75808 .40719 m
.75835 .41132 L
s
.86966 .35582 m
.8825 .35129 L
s
.86166 .35466 m
.86239 .3555 L
s
.78893 .35439 m
.78958 .35538 L
s
.85099 .32318 m
.85138 .32722 L
s
.79533 .37444 m
.79564 .37854 L
s
.76548 .35414 m
.76611 .35519 L
s
.83666 .35427 m
.83736 .35516 L
s
.73957 .42562 m
.73981 .42976 L
s
.81243 .35413 m
.8131 .35507 L
s
.86094 .35382 m
.86166 .35466 L
s
.83257 .34163 m
.83293 .34569 L
s
.78828 .35339 m
.78893 .35439 L
s
.77685 .39288 m
.77714 .39699 L
s
.72104 .44404 m
.72126 .4482 L
s
.83597 .35337 m
.83666 .35427 L
s
.76485 .3531 m
.76548 .35414 L
s
.81177 .35318 m
.81243 .35413 L
s
.86023 .35298 m
.86094 .35382 L
s
.81412 .36008 m
.81446 .36416 L
s
.756 .35365 m
.76917 .34985 L
s
.75835 .41132 m
.75861 .41545 L
s
.78764 .35239 m
.78828 .35339 L
s
.83529 .35247 m
.83597 .35337 L
s
.81111 .35223 m
.81177 .35318 L
s
.85953 .35213 m
.86023 .35298 L
s
.85138 .32722 m
.85176 .33127 L
s
.79564 .37854 m
.79596 .38264 L
s
.73981 .42976 m
.74006 .43391 L
s
.83462 .35157 m
.83529 .35247 L
s
.78701 .35139 m
.78764 .35239 L
s
.70898 .45905 m
.7218 .45511 L
s
.81046 .35128 m
.81111 .35223 L
s
.85883 .35128 m
.85953 .35213 L
s
.83293 .34569 m
.83329 .34976 L
s
.77714 .39699 m
.77743 .40112 L
s
.83395 .35067 m
.83462 .35157 L
s
.78639 .35038 m
.78701 .35139 L
s
.81446 .36416 m
.81479 .36825 L
s
.85815 .35043 m
.85883 .35128 L
s
.80982 .35032 m
.81046 .35128 L
s
.75861 .41545 m
.75888 .41959 L
s
.83329 .34976 m
.83395 .35067 L
s
.85176 .33127 m
.85214 .33533 L
s
.79596 .38264 m
.79627 .38675 L
s
.74006 .43391 m
.7403 .43808 L
s
.85747 .34957 m
.85815 .35043 L
s
.78578 .34937 m
.78639 .35038 L
s
.80919 .34936 m
.80982 .35032 L
s
.76917 .34985 m
.78238 .34603 L
s
.83329 .34976 m
.83365 .35384 L
s
.83264 .34885 m
.83329 .34976 L
s
.77743 .40112 m
.77772 .40525 L
s
.85679 .34871 m
.85747 .34957 L
s
.78517 .34836 m
.78578 .34937 L
s
.80856 .3484 m
.80919 .34936 L
s
.81479 .36825 m
.81513 .37235 L
s
.75888 .41959 m
.75914 .42375 L
s
.832 .34794 m
.83264 .34885 L
s
.85613 .34785 m
.85679 .34871 L
s
.80794 .34743 m
.80856 .3484 L
s
.78458 .34734 m
.78517 .34836 L
s
.85214 .33533 m
.85253 .3394 L
s
.79627 .38675 m
.79658 .39087 L
s
.7403 .43808 m
.74054 .44225 L
s
.7218 .45511 m
.73467 .45115 L
s
.83136 .34702 m
.832 .34794 L
s
.85547 .34698 m
.85613 .34785 L
s
0 g
.5 Mabswid
.88835 .37389 m
.87264 .33716 L
s
.4716 .32146 m
.47192 .27747 L
s
.039 .916 .04 r
1 Mabswid
.80733 .34646 m
.80794 .34743 L
s
.83365 .35384 m
.83401 .35793 L
s
.77772 .40525 m
.77801 .40939 L
s
.83073 .3461 m
.83136 .34702 L
s
.85482 .34611 m
.85547 .34698 L
s
.81513 .37235 m
.81546 .37647 L
s
.75914 .42375 m
.7594 .42791 L
s
.80673 .34549 m
.80733 .34646 L
s
.85417 .34524 m
.85482 .34611 L
s
.83011 .34517 m
.83073 .3461 L
s
.78238 .34603 m
.79564 .3422 L
s
.85253 .3394 m
.85291 .34348 L
s
.79658 .39087 m
.79689 .395 L
s
.80614 .34451 m
.80673 .34549 L
s
.85354 .34436 m
.85417 .34524 L
s
0 g
.5 Mabswid
.46965 .55552 m
.53967 .53407 L
s
.46965 .55552 m
.4505 .51498 L
s
.039 .916 .04 r
1 Mabswid
.8295 .34425 m
.83011 .34517 L
s
.83401 .35793 m
.83437 .36203 L
s
.77801 .40939 m
.77829 .41354 L
s
.80555 .34353 m
.80614 .34451 L
s
.85291 .34348 m
.85354 .34436 L
s
.8289 .34331 m
.8295 .34425 L
s
.81546 .37647 m
.8158 .38058 L
s
.7594 .42791 m
.75967 .43208 L
s
.73467 .45115 m
.74758 .44718 L
s
.80498 .34254 m
.80555 .34353 L
s
.85291 .34348 m
.85329 .34757 L
s
.85229 .3426 m
.85291 .34348 L
s
.79689 .395 m
.7972 .39914 L
s
.8283 .34238 m
.8289 .34331 L
s
.83437 .36203 m
.83472 .36614 L
s
.85167 .34171 m
.85229 .3426 L
s
.77829 .41354 m
.77858 .4177 L
s
.80441 .34155 m
.80498 .34254 L
s
.82771 .34144 m
.8283 .34238 L
s
.79564 .3422 m
.80895 .33836 L
s
.8158 .38058 m
.81613 .38471 L
s
.75967 .43208 m
.75993 .43626 L
s
.85107 .34082 m
.85167 .34171 L
s
.82713 .3405 m
.82771 .34144 L
s
.85329 .34757 m
.85367 .35167 L
s
.7972 .39914 m
.79751 .40329 L
s
.85047 .33993 m
.85107 .34082 L
s
.82656 .33955 m
.82713 .3405 L
s
.83472 .36614 m
.83508 .37026 L
s
.77858 .4177 m
.77886 .42187 L
s
.84988 .33903 m
.85047 .33993 L
s
.74758 .44718 m
.76055 .44319 L
s
.82599 .3386 m
.82656 .33955 L
s
.81613 .38471 m
.81646 .38885 L
s
.8493 .33813 m
.84988 .33903 L
s
.85367 .35167 m
.85405 .35577 L
s
.79751 .40329 m
.79782 .40745 L
s
.82544 .33765 m
.82599 .3386 L
s
.80895 .33836 m
.82231 .3345 L
s
.84872 .33723 m
.8493 .33813 L
s
.83508 .37026 m
.83544 .37438 L
s
.77886 .42187 m
.77915 .42605 L
s
.82489 .3367 m
.82544 .33765 L
s
.84815 .33633 m
.84872 .33723 L
s
0 0 0 r
.87264 .33716 m
.87264 .33716 L
s
0 g
.5 Mabswid
.86359 .36634 m
.87264 .33716 L
s
.87264 .33716 m
.85678 .30009 L
s
.039 .916 .04 r
1 Mabswid
.81646 .38885 m
.8168 .393 L
s
.82434 .33574 m
.82489 .3367 L
s
.84759 .33542 m
.84815 .33633 L
s
.85405 .35577 m
.85443 .35989 L
s
.79782 .40745 m
.79813 .41161 L
s
.83544 .37438 m
.83579 .37852 L
s
.77915 .42605 m
.77943 .43023 L
s
.84704 .3345 m
.84759 .33542 L
s
.76055 .44319 m
.77356 .43918 L
s
.8168 .393 m
.81713 .39716 L
s
.84649 .33359 m
.84704 .3345 L
s
.82231 .3345 m
.83571 .33063 L
s
.85443 .35989 m
.85481 .36401 L
s
.79813 .41161 m
.79843 .41579 L
s
.84595 .33267 m
.84649 .33359 L
s
.83579 .37852 m
.83615 .38267 L
s
.84542 .33175 m
.84595 .33267 L
s
.81713 .39716 m
.81746 .40132 L
s
.8449 .33082 m
.84542 .33175 L
s
.85481 .36401 m
.85519 .36815 L
s
.79843 .41579 m
.79874 .41998 L
s
.77356 .43918 m
.78663 .43516 L
s
.84438 .32989 m
.8449 .33082 L
s
.83615 .38267 m
.8365 .38682 L
s
0 g
.5 Mabswid
.44413 .37561 m
.44477 .33065 L
s
.44477 .33065 m
.4716 .32146 L
s
.039 .916 .04 r
1 Mabswid
.83571 .33063 m
.84916 .32675 L
s
.81746 .40132 m
.81779 .4055 L
s
.85519 .36815 m
.85557 .37229 L
s
.79874 .41998 m
.79905 .42417 L
s
.8365 .38682 m
.83686 .39099 L
s
.81779 .4055 m
.81812 .40968 L
s
.78663 .43516 m
.79974 .43113 L
s
.84916 .32675 m
.86265 .32286 L
s
.85557 .37229 m
.85595 .37645 L
s
0 g
.5 Mabswid
.85678 .30009 m
.84077 .26266 L
s
.039 .916 .04 r
1 Mabswid
.83686 .39099 m
.83721 .39516 L
s
.81812 .40968 m
.81845 .41388 L
s
.85595 .37645 m
.85632 .38061 L
s
.83721 .39516 m
.83756 .39934 L
s
.81845 .41388 m
.81877 .41808 L
s
.79974 .43113 m
.81291 .42708 L
s
.85632 .38061 m
.8567 .38478 L
s
0 g
.5 Mabswid
.47129 .3665 m
.4716 .32146 L
s
.50577 .49765 m
.53967 .53407 L
s
.039 .916 .04 r
1 Mabswid
.83756 .39934 m
.83791 .40354 L
s
.8567 .38478 m
.85708 .38896 L
s
.83791 .40354 m
.83827 .40774 L
s
.81291 .42708 m
.82612 .42301 L
s
.85708 .38896 m
.85745 .39315 L
s
.83827 .40774 m
.83862 .41195 L
s
0 g
.5 Mabswid
.84077 .26266 m
.8246 .22487 L
s
.039 .916 .04 r
1 Mabswid
.85745 .39315 m
.85783 .39736 L
s
.82612 .42301 m
.83939 .41893 L
s
.85783 .39736 m
.8582 .40157 L
s
.8582 .40157 m
.85858 .40579 L
s
.83939 .41893 m
.85271 .41484 L
s
.85271 .41484 m
.86608 .41072 L
s
0 g
.5 Mabswid
.8246 .22487 m
.8246 .22487 L
s
.44348 .42166 m
.44413 .37561 L
s
.44413 .37561 m
.47129 .3665 L
s
.039 .916 .04 r
1 Mabswid
.86608 .41072 m
.8795 .40659 L
s
0 g
.5 Mabswid
.4505 .51498 m
.50577 .49765 L
s
.4505 .51498 m
.44281 .46882 L
s
.47129 .3665 m
.47096 .41263 L
s
.85414 .39683 m
.86359 .36634 L
s
.47063 .45989 m
.50577 .49765 L
s
.44281 .46882 m
.44348 .42166 L
s
.44348 .42166 m
.47096 .41263 L
s
.47096 .41263 m
.47063 .45989 L
s
.47063 .45989 m
.44281 .46882 L
s
.85414 .39683 m
.84425 .42872 L
s
.89453 .5439 m
.79241 .30999 L
s
.84425 .42872 m
.84425 .42872 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  ImageSize->{288, 248.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000n2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00m?ooool00ol0003oooooooooo`0Yooooo`00m?oo
ool00ol0003oooooooooo`0Yooooo`00loooool00ol0003oooooo`00000Zooooo`00loooool00ol0
003oooooo`00000Zooooo`00loooool01?l0003oooooooooool0000Yooooo`00l_ooool01Ol0003o
oooooooooooooooo000002Wooooo003booooo`05o`000?ooooooooooooooool00000:Oooool00?;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`00lOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Kooooo003aooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool09Oooool00?3ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0U
ooooo`00l?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Cooooo0026ooooo`;o
0000J?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Cooooo0023ooooo`?o0000
00?oooooo`000?ooool0I_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo
0021ooooo`;o00001?ooool2o`0006Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Sooooo`00P?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000006Gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`00P?ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0006?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0R
ooooo`00P?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000H_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo0020ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool08Oooool0083ooooo0_l00005ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo027o
oooo0020ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Qooooo`00P?ooool2o`0000Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool08?ooool0083ooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0F_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo0020oooo
o`;o00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Wooooo0_l0000@oooo
o`03o`000?oooooooooo01oooooo0020ooooo`;o00001?ooool2o`0000Sooooo0_l0001Iooooo`03
o`000?oooooo0000013ooooo00?o0000ooooooooool07oooool0083ooooo0_l000001_oooooo0000
o`000?l0003oooooo`0000Gooooo0ol000000ooooooo0000ooooo`1Hooooo`04o`000?oooooooooo
o`00013ooooo00?o0000ooooooooool07_ooool0083ooooo0ol00004ooooo`03o`000?oooooooooo
00?o00001Oooool00ol0003oooooooooo`1Fooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool07_ooool0083ooooo00?o0000ooooool000001?ooool3o`0000Wooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool07_ooool0083ooooo00Co0000ooooool0003ooooo1?l0000<ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01gooooo0020ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Mooooo`00P?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool07?ooool0083ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01cooooo0020ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool2o`0001gooooo0020ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool2o`0001gooooo001oooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool2o`WZ2POooooo00Co0000oooooooooooo00007?ooool007oo
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000@ooooo`?o0000C?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00;o2NX:2Oooool01?l0003oooooooooool0000L
ooooo`00Ooooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000gooooo0ol00002oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02?ooool00ol0003o2NX:o`WZ2P0;oooo
o`04o`000?ooooooooooo`0001cooooo001oooooo`03o`000?oooooooooo00?ooooo0ol0000:oooo
o`?o00001_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo1?l9jPX00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool007oo
oooo00?o0000ooooool000000ol000000ooooooo0000o`000007ooooo`?o00002_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo00;ooooo1?l9jPX4ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`00Ooooool2o`0000Gooooo
0_l00004ooooo`?o00003_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo2NX:00;o2NX:
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6?ooool007oooooo00?o0000ooooooooool01?ooool2o`000004ooooool0003o0000o`0001;ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooo`WZ2P05ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo
001oooooo`03o`000?oooooooooo00Gooooo0_l0000Eooooo`03o`000?oooooooooo04?ooooo0ol9
jPX6ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:o`000?ooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Oooooo001oooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0nooooo`Co2NX:00Goooooo`000?ooooooooooo`WZ
2P04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:o`000?ooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Oooooo001oooooo`03o`000?oooooooooo00Gooooo0_l0000G
ooooo`03o`000?oooooooooo03[ooooo0ol9jPX4ooooo`05o`000?ooooooooooooooool9jPX01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooo000000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Gooooo`00Ooooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000001Oooooo00?o0000ooooooooool0=Oooool4o`WZ2PGooooo00?o2NX:ooooool000000oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooool000001oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo001oooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00005_ooool2o`0003?ooooo0ol9jPX9ooooo`03o`WZ2_oooooo
000000?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`04o`WZ2_oooooo
ooooo`0000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`00Ooooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0001?ooooo0ol000000on;DXSo0000oooo
o`0aooooo`03o`WZ2_oooooooooo00Gooooo00?o2NX:ooooooooool00_ooool00ol9jP[o0000oooo
o`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool01?l9jP[ooooooooo
ool00005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool007oooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000oooooo0ol00004oh]BR0;o0000
;_ooool3o`WZ2P;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_l0003ooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`05o`WZ
2_ooooooooooooooool000001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Go
oooo001oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`?o00001on;DXP00ol0003oooooo`00000Yooooo`Co2NX:1Oooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooool000000oooool00ol9jP[ooooo
ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool007oooooo00?o0000ooooooooool0
1?ooool2o`0000Cooooo00?o0000ooooooooool01oooool2o`0000[oRe:800Co0000oooooooooooo
00009Oooool3o`WZ2PCooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:o`000?ooool00_ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00?ooooo00Go2NX:ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool05?ooool007oooooo00Co0000oooooooooooooooo0ol000000onW
`>_o0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo0ol0000<oh]BR005o`000?oooooooooo
ooooool000008?ooool4o`WZ2POooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooool000000_ooool00ol9jP[oooooooooo`03
ooooo`03o`WZ2_oooooooooo00?ooooo1?l9jPX01?l0003oooooooooool0000=ooooo`03o`000?oo
oooooooo01Cooooo001oooooo`Co00001?nW`>/2o`0000Gooooo00?o0000ooooool000000_l0000?
oh]BR003o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool3o`WZ2PGooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooo`000002ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool01?l9jPX3ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool04ooo
ool007oooooo00?o0000ojO0jonW`>/01OnW`>/00ol0003oYl3[o`000005ooooo`03o`000?n;DXSo
Re:8017oRe:800Go0000ooooooooooooooooo`00000Iooooo`?o2NX:2Oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`03ooooo`03o`WZ2_oooooo000000;ooooo00?o2NX:ooooooooool00_ooool4o`WZ2P04ooooool9
jP[oooooo`WZ2PCooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0Cooooo`00Oooo
ool00ol0003oYl3[ojO0j`05ojO0j`04o`000?nW`>_oYl3[o`0000Cooooo00?o0000oh]BR?n;DXP0
4On;DXP00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo0_l9jPX6ooooo`03o`WZ
2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool01?l9jP[oooooooooool00002ooooo`Co
2NX:00?oooooo`WZ2_ooool00_ooool3o`WZ2PCooooo0_l0000@ooooo`03o`000?oooooooooo01;o
oooo001oooooo`03o`000?nW`>_oYl3[00GoYl3[00Go0000ojO0jonW`>_oYl3[o`000003ooooo`03
o`000?n;DXSoRe:8017oRe:800?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`;o
2NX:0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool01?l9jP[oooooooooool00003o`WZ2P;ooooo0ol9jPX4ooooo`;o2NX:0oooool3o`00
013ooooo00?o0000ooooooooool04_ooool007oooooo00?o0000ojO0jonW`>/01OnW`>/00ol0003o
Yl3[ojO0j`02ojO0j`04o`000?ooooooooooo`0001?oRe:800?o0000ooooooooool01?ooool00ol0
003oooooooooo`0<ooooo`Co2NX:1Oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00_ooool5o`WZ2P03o`000?oooooo2NX:00?ooooo0_l9jPX5oooo
o`04o`WZ2_l0003o0000o`0000;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0A
ooooo`00Ooooool2o`0000KoYl3[00?o0000ojO0jonW`>/00onW`>/00ol0003oooooo`00000Coh]B
R003o`000?oooooooooo00Cooooo0_l0000:ooooo`?o2NX:1?ooool00ol9jP[oooooooooo`02oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool5o`WZ2P03ooooool9jP[ooooo
00;ooooo00?o0000ooooool9jPX01?ooool01?l9jP[oooooooooooooool2o`0000;o2NX:0oooool0
0ol0003oooooo`00000@ooooo`03o`000?oooooooooo017ooooo001oooooo`;o00001_nW`>/00ol0
003oYl3[ojO0j`04ojO0j`;o00004on;DXP01?l0003oooooooooooooool3o`000003ooooool0003o
oooo00Gooooo1?l9jPX7ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooo`WZ2P03o`WZ2P?ooooo00?o2NX:ooooool9jPX00oooool00ol9jP[o0000o`WZ2P04
ooooo`;o2NX:0_l00002ooooo`?o2NX:0_ooool00ol0003oooooo`00000@ooooo`03o`000?oooooo
oooo017ooooo001oooooo`;o00001_nW`>/00ol0003oYl3[ojO0j`05ojO0j`03o`000?n;DXSoRe:8
017oRe:81?l00005ooooo`03o`000?oooooooooo00?o2NX:1Oooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool3o`WZ2P05ooooool9jP[ooooo
ooooool9jPX00_ooool3o`WZ2PCooooo00Co0000o`WZ2_oooooooooo0ol000000ol9jP[ooooooooo
o`02ooooo`08o`WZ2_oooooo2NX:o`WZ2_oooooo0000ooooool00002o`WZ2Poooooo00?o0000oooo
ooooool04?ooool007oooooo0_l00006ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000oh]BR?n;
DXP04?n;DXP00ol0003oooooooooo`06ooooo`?o2NX:2?ooool00ol9jP[oooooooooo`03ooooo`03
o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00;ooooo00Oo2NX:ooooooooooooooooo`WZ2_oooooo2NX:00;ooooo0_l9jPX0
0ooooooo2NX:ooooo`02ooooo`;o2NX:1?ooool01?l0003o2NX:o`000?l00003ooooo`;o2NX:1?oo
ool01?l9jP[oooooo`WZ2_l00002o`WZ2P03ooooool0003ooooo00oooooo00?o0000ooooooooool0
4?ooool007oooooo0_l00006ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000oh]BR?n;DXP03on;
DXP00ol0003oooooooooo`05ooooo`04o`WZ2_ooooooooooo`0000?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo1?l9jPX00ooooooo2NX:
ooooo`02ooooo`03o`WZ2_oooooo2NX:00Cooooo00?o2NX:ooooooooool01?l000000ol9jP[ooooo
ooooo`02ooooo`?o2NX:0_ooool3o`WZ2P03ooooool0003ooooo00;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0?ooooo`00Ooooool2o`0000KoYl3[00?o0000ojO0jonW`>/01onW
`>/00ol0003oRe:8oh]BR004oh]BR003o`000?n;DXSoRe:800SoRe:800?o0000ooooooooool00_oo
ool3o`WZ2P;ooooo00?o2NX:ooooool000000_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooool9jPX01?l9jPX2ooooo`03o`WZ2_oooooo2NX:00?ooooo0ol9
jPX4ooooo`;o2NX:00Go0000ooooooooooooooooo`000002o`WZ2P?ooooo00?o2NX:ooooool9jPX0
0_l9jPX01Ooooooo2NX:oooooooooooo000000Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`00Ooooool2o`0000GoYl3[0_l0000:ojO0j`03o`000?n;DXSoRe:800koRe:8
00?o0000ooooool9jPX00_l9jPX5ooooo`03o`WZ2_oooooo000000;ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04o`WZ2P05ooooool9jP[oooooooooool9jPX00_ooool3o`WZ2PCo
oooo0_l9jPX01_oooooo0000o`000?l0003oooooo`WZ2PCooooo00Co2NX:o`000?l9jP[o2NX:0_oo
ool4o`WZ2P;ooooo00?o2NX:ooooool000001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00oooooo001oooooo`04o`000?oooooo0000ojO0j`?o000000?oYl3[o`000?nW`>/02_nW
`>/00ol0003oRe:8oh]BR00;oh]BR0Co2NX:0oooool00ol9jP[oooooooooo`02ooooo`06o`WZ2_oo
ooooooooo`000?oooooo2NX:1Oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00oooool3o`WZ2P;ooooo00Oo2NX:ooooooooooooooooo`WZ2_oooooo
2NX:00?ooooo0_l9jPX3ooooo`;o000000?o2NX:o`000?ooool00oooool2o`WZ2P?ooooo00?o2NX:
o`000?ooool01?l9jPX5ooooo`03o`WZ2_oooooo000000Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0@ooooo`00Ooooool4o`0000CoYl3[00?o0000ojO0jonW`>/02_nW`>/00ol0
003oRe:8oh]BR007oh]BR0?o2NX:0_n;DXP00ol0003oooooooooo`02ooooo`03o`WZ2_oooooooooo
00;ooooo00Ko2NX:ooooooooooooooooo`000?l9jPX5ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooo`WZ2P04o`WZ2P05ooooool9jP[o2NX:ooooool9jPX0
0oooool3o`WZ2PCooooo00Co2NX:o`000?l0003o00000_ooool2o`WZ2PCooooo00?o2NX:ooooool9
jPX00_ooool2o`WZ2P05o`000?ooooooooooooooool9jPX01Oooool00ol9jP[oooooo`000006oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool007oooooo00?o0000ooooool0
00001OnW`>/00ol0003oYl3[ojO0j`0;ojO0j`03o`000?n;DXSoRe:800?oRe:80ol9jPX5oh]BR003
o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`04o`WZ2P05
ooooool9jP[oooooooooool9jPX00_ooool3o`WZ2PCooooo0_l9jPX2ooooo`;o00000_l9jPX4oooo
o`?o2NX:0oooool00ol9jP[oooooo`WZ2P03o`WZ2P03ooooool0003ooooo00;ooooo00?o2NX:oooo
ooooool00oooool00ol9jP[o0000ooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool04?ooool007oooooo00?o0000ooooool000001OnW`>/00ol0003oYl3[ojO0j`0<ojO0j`03
o`000?l9jP[o2NX:00;o2NX:0on;DXP00ol9jP[oRe:8oh]BR002oh]BR003o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00_ooool01ol9jP[ooooooooooooooooo0000o`WZ2_l000001?ooool0
0ol9jP[oooooooooo`02ooooo`?o2NX:0_ooool00ol9jP[oooooooooo`02o`WZ2P03ooooool9jP[o
oooo00;ooooo0_l9jPX4ooooo`;o2NX:0_l00002ooooo`?o2NX:0oooool01?l9jP[oooooo`WZ2_l9
jPX2ooooo`;o2NX:1?ooool00ol9jP[o0000ooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:o`000?ooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo001o
ooooo`04o`000?ooooooooooo`0000CoYl3[00?o0000ojO0jonW`>/03?nW`>/00ol0003oRe:8oh]B
R005oh]BR003o`WZ2_n;DXSoRe:800;oRe:800?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`02ooooo`07o`WZ2_l0003o0000o`000?oooooo2NX:o`000004ooooo`Ko2NX:00Goooooo`WZ2_l9
jP[oooooo`WZ2P03ooooo`03o`WZ2_oooooo2NX:00Cooooo00?o2NX:ooooooooool00ol00002o`WZ
2PCooooo0ol9jPX2ooooo`03o`WZ2_oooooooooo00Co2NX:1Oooool00ol9jP[oooooo`000002oooo
o`03o`WZ2_oooooooooo00?ooooo00?o2NX:o`000?ooool01oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo017ooooo001oooooo`04o`000?ooooooooooo`0000CoYl3[00?o0000ojO0
jonW`>/03OnW`>/00ol0003oRe:8o`WZ2P04oh]BR003o`WZ2_n;DXSoRe:800;oRe:800?o2NX:oooo
ooooool00_ooool00ol9jP[oooooo`000002o`000003o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ool000001?l9jPX01Ooooooo2NX:oooooooooooo2NX:00;ooooo00Co2NX:oooooooooooo2NX:0ooo
ool2o`WZ2PCooooo0_l9jPX01?l0003oooooooooooooool3o`WZ2P?ooooo00Go2NX:ooooool9jP[o
2NX:ooooo`04o`WZ2P;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooo`000003ooooo`03
o`WZ2_oooooooooo00;ooooo00?o2NX:o`000?ooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo017ooooo001oooooo`05o`000?ooooooooooooooool000000onW`>/00ol0003o
Yl3[ojO0j`0>ojO0j`03o`000?l9jP[oRe:800?oRe:800?o2NX:oh]BR?n;DXP00_n;DXP2o`0000;o
oooo00?o0000o`WZ2_l000000oooool00ol9jP[oooooooooo`02ooooo`?o2NX:00Go0000oooooooo
oooo2NX:ooooo`02o`WZ2P03ooooool9jP[ooooo00;ooooo00?o2NX:ooooool9jPX00oooool2o`WZ
2P05ooooool0003o0000o`000?ooool00_l9jPX3ooooo`04o`WZ2_oooooo2NX:o`WZ2P;ooooo00?o
2NX:ooooool9jPX00ol9jPX5ooooo`03o`WZ2_oooooooooo00?ooooo00Co2NX:oooooooooooo0000
0_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_l0003ooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Aooooo`00Ooooool01Ol0003ooooooooooooooooo000000?oYl3[
00?o0000ojO0jonW`>/03onW`>/00ol0003oRe:8oh]BR002oh]BR003o`WZ2_n;DXSoRe:800;oRe:8
00Ko0000ooooool0003o0000ooooool9jPX4ooooo`Go2NX:00Ooooooo`WZ2_l9jP[o2NX:o`000?oo
oooo2NX:00;ooooo00?o2NX:ooooool9jPX00oooool3o`WZ2P?ooooo00?o0000o`WZ2_l9jPX01?oo
ool3o`WZ2P;ooooo00Go2NX:oooooooooooo2NX:ooooo`03o`WZ2P?ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`03ooooo`04o`WZ2_ooooooooooo`0000;ooooo00?o2NX:oooooooo
ool00_ooool00ol0003o2NX:ooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04_ooool007oooooo00?o0000ooooooooool00_ooool01?l0003oYl3[ojO0jol0000BojO0j`05
o`000?n;DXSoRe:8oh]BR?l9jPX01?n;DXP01ol0003ooooooooooooooooo0000o`WZ2_ooool01?l9
jPX00ooooooo2NX:ooooo`02ooooo`06o`WZ2_oooooo2NX:ooooool0003o2NX:0oooool2o`WZ2PCo
oooo0_l9jPX3o`000003ooooool9jP[o2NX:00Cooooo00?o2NX:ooooool9jPX00_ooool00ol9jP[o
ooooooooo`02o`WZ2P03ooooool9jP[ooooo00?ooooo00?o2NX:ooooooooool00oooool00ol9jP[o
ooooooooo`03ooooo`07o`WZ2_ooooooooooooooool0003oooooo`WZ2P04ooooo`03o`000?l9jP[o
oooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`00Ooooool00ol0
003oooooooooo`02ooooo`04o`000?nW`>_oYl3[o`0001;oYl3[00Go0000oh]BR?n;DXSoRe:8o`WZ
2P04oh]BR004o`000?ooooooooooooooo`?o2NX:00Ko0000oooooooooooo2NX:ooooool9jPX3oooo
o`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:0oooool2o`WZ2P?ooooo0_l000000ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooo2NX:00?ooooo00Go2NX:oooooooooooo2NX:ooooo`03o`WZ2P?ooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo
00Oo2NX:ooooooooooooooooo`000?oooooo2NX:00Cooooo00?o0000o`WZ2_ooool02Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo001oooooo`04o`000?oooooooooooooo
o`;o2NX:00?o0000ojO0jol000004onW`>/01?l0003oRe:8oh]BR?l9jPX4oh]BR0Co2NX:00Cooooo
o`WZ2_l9jP[o2NX:0_l000001?l9jP[oooooooooool9jPX2ooooo`03o`WZ2_oooooooooo00?o2NX:
00Co0000oooooooooooooooo0_l9jPX2o`0000;ooooo0_l9jPX3ooooo`04o`WZ2_ooooooooooo`WZ
2P;ooooo00?o2NX:ooooool9jPX00ol9jPX5ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03ooooo`07o`WZ2_ooooooooooooooool0003oooooo`WZ
2P03ooooo`03o`000?oooooo2NX:00_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Booooo`00Ooooool01?l0003o2NX:o`WZ2_l9jPX2ooooo`03o`000?nW`>_o000001CoYl3[00Co
0000oh]BR?l9jP[oRe:80ol9jPX00ol0003o2NX:ooooo`02ooooo`03o`WZ2_oooooo2NX:00;ooooo
00Oo2NX:o`000?l0003oooooo`WZ2_oooooo2NX:00?ooooo0_l9jPX01?oooooo0000o`000?l00002
o`WZ2PCooooo00?o2NX:ooooool9jPX00_ooool01?l9jP[oooooooooooooool4o`WZ2P?ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`000?l9jP[ooooo00;ooooo00?o
0000ooooooooool00oooool3o`WZ2PGooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Cooooo`00OOooool2o`WZ2P03o`000?oooooooooo00?ooooo00?o2NX:o`000?l000005?nW`>/0
1?l9jP[o0000o`WZ2_l9jPX3oh]BR003o`000?l9jP[o2NX:00;ooooo00Ko2NX:oooooooooooo2NX:
ooooool9jPX2ooooo`04o`000?l9jP[o2NX:o`WZ2P?ooooo00?o0000o`WZ2_l9jPX00_l000001?oo
oooo2NX:ooooool9jPX3ooooo`05o`WZ2_oooooo2NX:o`WZ2_ooool01?l9jPX2ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oo
oooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`000?l9
jP[ooooo00;ooooo00?o0000ooooool9jPX00ol9jPX9ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04oooool007Wooooo1?l9jPX2ooooo`04o`000?l9jP[oooooooooo`Go00004OnW
`>/3o`WZ2P;oYl3[00?o0000o`WZ2_n;DXP00_n;DXP00ol0003oooooo`WZ2P02ooooo`03o`WZ2_oo
oooooooo00?o2NX:1?ooool2o`WZ2PCo00000_l9jPX01?oooooo0000ooooool9jPX2ooooo`04o`WZ
2_ooooooooooo`WZ2P?ooooo0_l9jPX5ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`04o`000?oooooo2NX:o`0000;o2NX:3Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo001fooooo`?o2NX:1_ooool4o`0000;o
oooo00?o2NX:ooooool000004?nW`>/00ol9jP[oYl3[ojO0j`04ojO0j`05o`000?l9jP[oRe:8oh]B
R?l000000_ooool00ol9jP[oooooo`WZ2P03ooooo`;o2NX:0oooool2o`0000;o2NX:00Oo0000oooo
oooooooo2NX:ooooool9jP[o000000;ooooo00Ko2NX:ooooool9jP[o2NX:ooooool9jPX2ooooo`?o
2NX:1Oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00_ooool01Ol9jP[o0000o`WZ2_oooooo0000013ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`00Loooool3o`WZ2PGooooo00Ko2NX:ooooooooooooooooo`000?l9jPX4
ooooo`03o`WZ2_oooooo000000goYl3[0ol9jPX00onW`>_o2NX:o`WZ2P04ojO0j`05o`000?l9jP[o
Re:8oh]BR?l000000_ooool3o`WZ2PCooooo00Co2NX:o`000?l0003o00000_ooool2o`WZ2P?ooooo
00Co2NX:oooooooooooo2NX:0_ooool00ol9jP[oooooooooo`05o`WZ2P?ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo1?l9jPX2ooooo`03
o`000?oooooo0000013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`00
L?ooool3o`WZ2PSooooo00Ko2NX:ooooooooooooooooo`000?l9jPX4ooooo`04o`WZ2_oooooo0000
o`0000KoYl3[00?o0000ojO0jonW`>/00ol9jPX5ojO0j`;o2NX:1?nW`>/01?l0003o2NX:oh]BR?l0
0003ooooo`;o2NX:0_ooool3o`000003o`WZ2_oooooooooo00;ooooo00?o2NX:o`000?l9jPX00_oo
ool01_l9jP[oooooooooool0003o2NX:ooooo`Co2NX:00?oooooo`WZ2_ooool01?ooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00ol9jPX6ooooo`;o
00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo001]ooooo`?o2NX:
1_ooool00ol9jP[oooooooooo`02ooooo`06o`WZ2_ooooooooooooooool0003o2NX:0oooool01_l9
jP[oooooooooool0003oooooo`0000CoYl3[1?l9jPX2ojO0j`;o2NX:1OnW`>/00ol9jP[oYl3[ojO0
j`03ojO0j`03o`000?l9jP[o000000Cooooo0_l9jPX01?l0003oooooooooooooool2o`WZ2P?ooooo
00Ko2NX:o`000?l9jP[o2NX:ooooool9jPX2ooooo`04o`000?l9jP[o2NX:o`WZ2PCooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo0_l9jPX:
ooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000Fooooo`00J_ooool3
o`WZ2PCooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`06o`WZ2_oooooo
ooooooooool0003o2NX:0oooool01ol9jP[oooooooooool0003oooooo`WZ2_l000000ol9jPX00onW
`>_o2NX:ojO0j`04ojO0j`;o2NX:1OnW`>/00ol9jP[oYl3[ojO0j`03ojO0j`03o`000?l9jP[ooooo
00?o00000ol9jPX3ooooo`03o`WZ2_oooooo2NX:00;ooooo00Co2NX:o`000?oooooooooo0_l9jPX0
0ooooooo2NX:o`WZ2P02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`07ooooo`?o2NX:3?ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooo
ooooooooool000005_ooool006Sooooo0_l9jPX7ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00_ooool01_l9jP[ooooooooooooooooo0000o`WZ2P?ooooo00Co2NX:oooooooooooo
00000_l9jPX00ol0003oYl3[ojO0j`03ojO0j`03o`WZ2_nW`>_oYl3[00?oYl3[00?o2NX:ojO0jonW
`>/01?nW`>/01?l9jP[oYl3[ojO0jonW`>/4o`0000?ooooo00?o2NX:ooooool9jPX00oooool01ol9
jP[oooooooooool9jP[oooooo`WZ2_l000000oooool2o`WZ2P;ooooo00?o0000ooooool9jPX01?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00ooo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo1?l9jPX?ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooool000005oooool006Kooooo0_l9jPX4ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`06o`WZ2_oooooo
ooooooooool0003o2NX:0oooool3o`WZ2P05o`000?oooooo2NX:o`WZ2_l000001?nW`>/2o`WZ2PGo
Yl3[00?o2NX:ojO0jonW`>/01?nW`>/3o`0000;oRe:80ol9jPX2ooooo`04o`WZ2_ooooooooooo`WZ
2P;ooooo00Co2NX:oooooooooooooooo1ol9jPX3ooooo`03o`000?oooooo2NX:00Cooooo00?o2NX:
ooooooooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:
ooooooooool01Oooool3o`WZ2QCooooo00?o0000ooooooooool04?ooool00ol0003oooooo`00000G
ooooo`00Hoooool3o`WZ2P03ooooool9jP[ooooo00?ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`000006
o`WZ2P07ooooool0003oooooo`WZ2_oooooo2NX:o`000004ojO0j`;o2NX:1OnW`>/00ol9jP[oYl3[
ojO0j`03o`000003o`WZ2_n;DXSoRe:800;oRe:800Ko2NX:o`000?l9jP[o2NX:ooooool9jPX3oooo
o`03o`WZ2_oooooo2NX:00;ooooo0ol9jPX01Ooooooo0000oooooooooooo2NX:00?ooooo00?o0000
ooooool9jPX01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00oooool01?l9jP[oooooooooooooool4o`WZ2QOooooo00?o0000ooooooooool04?oo
ool00ol0003oooooo`00000Gooooo`00H?ooool3o`WZ2PCooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool0
1_l9jP[oooooo`WZ2_l9jP[o0000o`WZ2P?ooooo0_l9jPX01ooooooo0000ooooool9jP[oooooo`WZ
2_l000001OnW`>/2o`WZ2P?oYl3[1?l00003oh]BR003o`WZ2_n;DXSoRe:800;oRe:800?o2NX:ojO0
jol000000ol9jPX4ooooo`Co2NX:0_ooool00ol9jP[oooooo`000002ooooo`07o`WZ2_oooooooooo
ooooool0003oooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool00_oo
ool00ol9jP[oooooooooo`03ooooo`Co2NX:7?ooool00ol0003oooooooooo`0@ooooo`;o00005ooo
ool005gooooo0ol9jPX3ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooooooooooo0ol9jPX2ooooo`03o`00
0?l9jP[ooooo00;ooooo00Ko2NX:ooooool9jP[o0000ooooool9jPX2ooooo`03o`WZ2_l0003oYl3[
00CoYl3[00Co2NX:o`000?l0003o00000_n;DXP00ol9jP[oRe:8oh]BR002oh]BR003o`WZ2_n;DXSo
Re:800;oRe:800Co2NX:ojO0jonW`>_o00000_l9jPX2ooooo`Co2NX:1?ooool00ol9jP[oooooo`00
0002ooooo`07o`WZ2_ooooooooooooooool0003oooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00?o
oooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`03o`WZ2R3ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Fooooo`00F_ooool3o`WZ2P03ooooool9jP[ooooo00;ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00_ooool6o`WZ2P?ooooo00?o0000o`WZ2_l9jPX00_ooool01_l9jP[ooooo
ooooool0003oooooo`WZ2P?ooooo00Co2NX:o`000?nW`>_oYl3[0ol000000ol9jP[oRe:8oh]BR002
oh]BR003o`WZ2_n;DXSoRe:800;oRe:800?o2NX:oh]BR?n;DXP00_n;DXP01Ol9jP[oYl3[ojO0jonW
`>_o000000?o2NX:0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo000000;ooooo00?o
2NX:ooooool000000_l000000ooooooo2NX:ooooo`03ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`0Rooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool05_ooool005Kooooo1?l9jPX4ooooo`05o`WZ2_ooooooooooooooool9jPX01?oo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooool9jPX00ol9
jPX3ooooo`;o2NX:0oooool01_l0003oooooo`WZ2_l9jP[oooooo`WZ2P;ooooo00?o0000o`WZ2_l9
jPX00oooool01?l0003o2NX:o`000?l00003oh]BR003o`WZ2_n;DXSoRe:800;oRe:800?o2NX:oh]B
R?n;DXP00_n;DXP00ol9jP[oRe:8oh]BR002oh]BR004o`WZ2_nW`>_oYl3[ojO0j`;o2NX:1Oooool0
0ol9jP[oooooooooo`02ooooo`07o`WZ2_oooooo0000ooooool0003o2NX:o`000002ooooo`03o`00
0?oooooo2NX:00Cooooo00?o2NX:ooooooooool01oooool3o`WZ2RGooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Fooooo`00Doooool3o`WZ2P?ooooo00?o2NX:ooooooooool00_oo
ool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:ooooooooool00_ooool01?l9jP[ooooo
ooooooooool3o`WZ2P;ooooo0_l9jPX4ooooo`;o2NX:0_ooool00ol0003oooooooooo`03o`WZ2P?o
00000_l9jPX3o`0000;ooooo00?o0000oh]BR?n;DXP00_n;DXP00ol9jP[oRe:8oh]BR002oh]BR003
o`WZ2_n;DXSoRe:800;oRe:800?o2NX:oh]BR?n;DXP00_n;DXP4o`WZ2P03ojO0jol9jP[o000000Co
oooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooo`000?l00002ooooo`06o`WZ2_oooooooooo
o`000?oooooo2NX:1?ooool00ol9jP[oooooooooo`03ooooo`Co2NX::?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01Oooooo001@ooooo`?o2NX:1_ooool00ol9jP[oooooooooo`02
ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool00ol9jP[oooooooooo`02ooooo`06o`WZ2_oo
ooooooooo`WZ2_oooooo2NX:1?ooool2o`WZ2P;ooooo00Oo2NX:ooooool9jP[o2NX:ooooool0003o
oooo00Co00000_ooool3o`000003o`WZ2_oooooooooo00;ooooo00?o0000oh]BR?n;DXP00_n;DXP0
0ol9jP[oRe:8oh]BR002oh]BR003o`WZ2_n;DXSoRe:800;oRe:800?o2NX:oh]BR?n;DXP00_n;DXP0
0ol9jP[oYl3[ojO0j`02ojO0j`03o`WZ2_nW`>_o000000?ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooo`000003ooooo`06o`WZ2_ooooooooooo`000?oooooo2NX:1oooool3o`WZ2Rgooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`00COooool3o`WZ2PCooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX0
1?ooool00ol9jP[oooooooooo`02ooooo`?o2NX:00?oooooo`WZ2_l9jPX01?ooool2o`WZ2P;ooooo
00?o2NX:ooooooooool00_l9jPX2o`0000?ooooo0ol000000ooooooo0000o`WZ2P02o`WZ2P?ooooo
00?o0000oh]BR?n;DXP00_n;DXP00ol9jP[oRe:8oh]BR002oh]BR003o`WZ2_n;DXSoRe:800;oRe:8
00?o2NX:oh]BR?n;DXP00_n;DXP00ol9jP[oYl3[ojO0j`03ojO0j`03o`WZ2_nW`>_o000000;ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooo`000003ooooo`06o`WZ2_ooooooooooo`000?oo
oooo2NX:0oooool4o`WZ2S3ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Goooo
o`00B_ooool3o`WZ2P?ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ2_oooooooooo
00;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ2_oooooo2NX:00?o2NX:1?ooool2
o`WZ2P?ooooo00Go2NX:ooooool9jP[oooooo`WZ2P03ooooo`03o`WZ2_l0003ooooo00?o00000_l9
jPX3ooooo`04o`000?oooooo2NX:o`WZ2P;ooooo00?o0000oh]BR?n;DXP00_n;DXP00ol9jP[oRe:8
oh]BR002oh]BR003o`WZ2_n;DXSoRe:800;oRe:800?o2NX:oh]BR?n;DXP00_n;DXP00ol9jP[oYl3[
ojO0j`03ojO0j`06o`WZ2_nW`>_oYl3[o`000?oooooo2NX:1?ooool00ol9jP[oooooo`000003oooo
o`05o`WZ2_ooooooooooo`000?ooool01?l9jPXeooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool05oooool004Oooooo0ol9jPX6ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool0
0ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool3o`WZ2P;ooooo0_l9
jPX4ooooo`?o2NX:0_ooool00ol9jP[oooooooooo`02o`WZ2P?ooooo0ol00003ooooo`03o`WZ2_oo
oooo2NX:00;ooooo00?o2NX:o`000?ooool00_l9jPX00ooooooo0000oh]BR003oh]BR003o`WZ2_n;
DXSoRe:800;oRe:800?o2NX:oh]BR?n;DXP00_n;DXP00ol9jP[oRe:8oh]BR002oh]BR003o`WZ2_nW
`>_oYl3[00?oYl3[00Ko2NX:ojO0jonW`>_o0000ooooool9jPX4ooooo`03o`WZ2_oooooo000000Go
oooo0ol9jPXiooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool004Cooooo
0ol9jPX4ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05
o`WZ2_ooooooooooooooool9jPX01?ooool6o`WZ2PCooooo0_l9jPX3ooooo`06o`WZ2_oooooo2NX:
o`WZ2_oooooo2NX:0oooool01_l9jP[o0000o`000?l0003oooooo`0000;o2NX:0_ooool02Ol9jP[o
ooooo`WZ2_l9jP[oooooo`WZ2_oooooo0000ooooo`02o`WZ2P03o`000?n;DXSoRe:800;oRe:800?o
2NX:oh]BR?n;DXP00_n;DXP00ol9jP[oRe:8oh]BR002oh]BR003o`WZ2_n;DXSoRe:800;oRe:800?o
0000ojO0jonW`>/00onW`>/01_l9jP[oYl3[ojO0jonW`>_o0000o`WZ2PCooooo00Co2NX:ooooool0
003ooooo1?l9jPX00ooooooo0000ooooo`0jooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool06?ooool0047ooooo0ol9jPX2ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooooooo
ooooooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00;ooooo00Ko2NX:ooooooooooooooooo`WZ2_oo
ool4o`WZ2PCooooo0_l9jPX3ooooo`03o`WZ2_oooooo2NX:00;ooooo00?o2NX:ooooooooool00_l9
jPX2ooooo`?o000000Ko2NX:ooooooooooooooooo`WZ2_l00002o`WZ2P03ooooool9jP[ooooo00;o
oooo0_l9jPX2ooooo`04o`000?oooooo2NX:o`0000CoRe:800?o2NX:oh]BR?n;DXP00_n;DXP00ol9
jP[oRe:8oh]BR002oh]BR003o`WZ2_n;DXSoRe:800;oRe:800?o2NX:ojO0jonW`>/00onW`>/00ol9
jP[oYl3[ojO0j`02ojO0j`03o`WZ2_oooooooooo00?ooooo0ol9jPX5ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`00?_ooool3o`WZ2PGo
oooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`03o`WZ2P?ooooo00?o2NX:ooooooooool00_ooool3o`WZ
2P;ooooo00Ko2NX:ooooool9jP[o2NX:ooooool9jPX2ooooo`Co00000_ooool3o`WZ2P;ooooo00?o
2NX:o`000?ooool00ol9jPX4ooooo`07o`WZ2_ooooooooooo`WZ2_l0003o2NX:o`000004oh]BR003
o`WZ2_n;DXSoRe:800;oRe:800?o2NX:oh]BR?n;DXP00_n;DXP00ol9jP[oRe:8oh]BR002oh]BR003
o`WZ2_nW`>_oYl3[00?oYl3[00?o2NX:ojO0jonW`>/00_nW`>/00ol9jP[o0000ooooo`03o`WZ2P03
ooooool0003ooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Sooooo000kooooo`?o2NX:1?ooool01Ol9jP[ooooooooooooooooo2NX:00Co
oooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00;ooooo1Ol9jPX4oooo
o`;o2NX:0oooool01_l9jP[oooooo`WZ2_l9jP[oooooo`WZ2P;ooooo0_l9jPX3o`000004ooooool9
jP[o2NX:o`WZ2P;ooooo00Oo2NX:oooooooooooo2NX:ooooool9jP[o000000;ooooo0_l9jPX4oooo
o`?o2NX:0_ooool2o`0000CoRe:800?o2NX:oh]BR?n;DXP00_n;DXP00ol9jP[oRe:8oh]BR002oh]B
R003o`WZ2_n;DXSoRe:800;oRe:800?o2NX:ojO0jonW`>/00onW`>/00ol9jP[oYl3[ojO0j`03ojO0
j`;o2NX:1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Iooooo`00>?ooool3o`WZ2P;ooooo00?o2NX:oooooooo
ool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04
ooooo`03o`WZ2_oooooo2NX:00?o2NX:0oooool2o`WZ2P?ooooo00?o2NX:ooooool9jPX00_ooool0
0ol9jP[oooooooooo`03o`WZ2P05ooooool0003o0000o`000?l9jPX00oooool01_l9jP[oooooo`WZ
2_l9jP[oooooo`WZ2P?ooooo0_l9jPX01?l0003oooooooooooooool6o`WZ2PGooooo00?o0000oh]B
R?n;DXP00_n;DXP00ol9jP[oRe:8oh]BR002oh]BR003o`WZ2_n;DXSoRe:800;oRe:800?o2NX:oh]B
R?n;DXP00_n;DXP00ol9jP[oYl3[ojO0j`06ojO0j`?o2NX:0_nW`>/01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Wooooo000eooooo`?o2NX:1Oooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_oooooooooo
ooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo0ol9jPX2ooooo`;o2NX:0ooo
ool3o`WZ2P;ooooo00Ko2NX:oooooooooooo2NX:ooooool9jPX3ooooo`?o00000oooool2o`WZ2P;o
oooo00?o2NX:ooooooooool00ol9jPX3ooooo`;o2NX:00Co0000oooooooooooooooo0_l9jPX3oooo
o`03o`WZ2_oooooooooo00?ooooo0_l00003oh]BR003o`WZ2_n;DXSoRe:800;oRe:800?o2NX:oh]B
R?n;DXP00_n;DXP00ol9jP[oRe:8oh]BR002oh]BR003o`WZ2_nW`>_oYl3[00?oYl3[0ol9jPX6ojO0
j`04o`000?ooooooooooo`0000Cooooo0ol0000mooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06Oooool003;ooooo0ol9jPX4ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool0
0ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooooooooooo1_l9
jPX4ooooo`06o`WZ2_ooooooooooooooool9jP[ooooo0_l9jPX00ooooooo2NX:ooooo`02ooooo`;o
2NX:0ol000000ooooooo2NX:o`WZ2P02ooooo`06o`WZ2_ooooooooooo`WZ2_oooooo2NX:0oooool2
o`WZ2PCooooo00?o2NX:o`000?ooool00ol9jPX4ooooo`03o`WZ2_oooooooooo00?ooooo0ol00002
oh]BR003o`WZ2_n;DXSoRe:800;oRe:800?o2NX:oh]BR?n;DXP00_n;DXP00ol9jP[oRe:8oh]BR002
oh]BR003o`000?nW`>_o2NX:00?o2NX:2_nW`>/01?l0003oooooo`000?ooool3o`0000;ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo000`
ooooo`;o2NX:0_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooooooooooooooo
o`WZ2P04ooooo`03o`WZ2_oooooooooo00;ooooo1Ol9jPX3ooooo`;o2NX:0oooool01_l9jP[ooooo
o`WZ2_l9jP[oooooo`WZ2P;ooooo0ol9jPX2ooooo`?o00001?ooool3o`WZ2P04ooooool9jP[ooooo
ooooo`?o2NX:1?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_l0003o2NX:00;ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`04o`000005oh]BR?l0003oRe:8oh]BR?l9jPX01?n;
DXP00ol9jP[oRe:8oh]BR006oh]BR0?o2NX:3onW`>/3o`0000Gooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo000dooooo`05o`WZ2_oooooo
ooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:ooooooooool0
0ol9jPX2ooooo`;o2NX:1?ooool2o`WZ2P;ooooo00Ko2NX:oooooooooooo2NX:ooooool9jPX3oooo
o`04o`WZ2_l0003o0000o`0000;ooooo0_l9jPX3ooooo`03o`WZ2_oooooo2NX:00;o2NX:0oooool2
o`WZ2PCooooo1_l9jPX01Ooooooo0000oooooooooooo2NX:00Cooooo0ol00003ooooo`06o`000?n;
DXSoRe:8o`000?n;DXSo2NX:1?n;DXP00ol9jP[oRe:8oh]BR002oh]BR0Co2NX:0_n;DXP00ol0003o
Yl3[ojO0j`0=ojO0j`;o00001_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool06_ooool002oooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooo
oooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`Go2NX:1?ooool00ol9
jP[oooooooooo`02ooooo`?o2NX:00?oooooo`WZ2_ooool00_ooool2o`WZ2PCo00000_l9jPX3oooo
o`03o`WZ2_oooooo2NX:00;ooooo00?o2NX:ooooooooool00_l9jPX4ooooo`;o2NX:00?oooooo`WZ
2_l9jPX00_l9jPX3ooooo`03o`WZ2_oooooo000000;ooooo00?o2NX:ooooool000000_l000000ol9
jP[oooooooooo`03ooooo`06o`000?n;DXSoRe:8oh]BR?l0003o2NX:1_n;DXP3o`WZ2PKoRe:800?o
0000ojO0jonW`>/03_nW`>/00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`00;oooool00ol9jP[oooooooooo`02
ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01_l9jP[ooooooooooooooooo2NX:ooooo`Co
2NX:0oooool00ol9jP[oooooooooo`02ooooo`?o2NX:0_ooool00ol9jP[oooooo`WZ2P02o`WZ2P;o
oooo0ol00004ooooo`?o2NX:0_ooool00ol9jP[oooooooooo`02o`WZ2PCooooo0_l9jPX3ooooo`?o
2NX:0_ooool00ol9jP[oooooooooo`02ooooo`04o`WZ2_oooooo0000ooooo`?o00000oooool00ol9
jP[oooooooooo`03ooooo`03o`000?n;DXSoRe:800;oRe:800?o0000oh]BR?n;DXP01?l9jPX9oh]B
R003o`000?nW`>_oYl3[00ooYl3[00?o0000ooooooooool00oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool002oooooo00?o2NX:oooooooo
ool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:ooooooooool00ol9jPX01?oo
oooo2NX:o`WZ2_l9jPX3ooooo`;o2NX:0oooool01_l9jP[oooooo`WZ2_l9jP[oooooo`WZ2P?ooooo
0ol00002ooooo`?o2NX:0_ooool01_l9jP[oooooo`WZ2_l9jP[oooooo`WZ2P?ooooo00?o2NX:oooo
ooooool00_ooool6o`WZ2PCooooo00?o2NX:ooooooooool00_ooool01_l9jP[oooooo`000?l0003o
ooooo`WZ2PCooooo00?o2NX:ooooooooool00_ooool00ol9jP[o0000oh]BR003oh]BR003o`WZ2_l0
003o2NX:00goRe:80_l0000AojO0j`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo000_ooooo`03o`WZ2_oooooo
oooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`Ko2NX:0oooool2o`WZ2P?ooooo00Ko
2NX:ooooool9jP[o2NX:ooooool9jPX2ooooo`?o2NX:0ol00002o`WZ2P?ooooo00Ko2NX:ooooool9
jP[o2NX:ooooool9jPX2ooooo`?o2NX:0oooool2o`WZ2P;ooooo0ol9jPX3ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooo`000002ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00oooool00ol0003oRe:8o`WZ2P02o`WZ2P;oRe:800?o0000
oh]BR?n;DXP02on;DXP01?l0003oooooo`000?l0000@ojO0j`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo000_
ooooo`03o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooooooooooo1?l9jPX01?oooooo2NX:oooo
ooooool2o`WZ2PCooooo0_l9jPX2ooooo`03o`WZ2_oooooooooo00?o2NX:0_ooool3o`0000?ooooo
00?o2NX:ooooool9jPX00_ooool00ol9jP[oooooooooo`03o`WZ2P?ooooo0_l9jPX3ooooo`Co2NX:
00?oooooo`WZ2_ooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo
00Ko2NX:oooooooooooo0000ooooool9jPX4ooooo`04o`WZ2_ooooooooooooooo`;o2NX:00?o0000
o`WZ2_n;DXP01On;DXP00ol0003oRe:8oh]BR00:oh]BR004o`000?ooooooooooooooo`;o00003onW
`>/01Ol0003ooooooooooooooooo000003oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Kooooo`00;oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo2NX:00;o2NX:0_oo
ool2o`WZ2PCooooo0_l9jPX3ooooo`?o2NX:00?oooooo`WZ2_ooool00_ooool01Ol9jP[o0000o`00
0?l0003ooooo00?o2NX:0_ooool01_l9jP[oooooo`WZ2_l9jP[oooooo`WZ2P?ooooo0_l9jPX4oooo
o`Go2NX:1?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00_ooool01_l9jP[oooooooooool0003oooooo`WZ2PGooooo0ol9jPX2ooooo`03o`000?n;
DXSoRe:800KoRe:800?o0000oh]BR?n;DXP02On;DXP00ol0003oooooooooo`03ooooo`;o00003_nW
`>/01?l0003oooooooooool00010ooooo`04o`000?ooooooooooo`0001kooooo000_ooooo`04o`WZ
2_ooooooooooooooo`Co2NX:00?oooooo`WZ2_ooool00_ooool2o`WZ2P?ooooo0ol9jPX00ooooooo
2NX:ooooo`02ooooo`;o2NX:00Goooooo`000?l0003o0000o`WZ2P03ooooo`06o`WZ2_oooooo2NX:
o`WZ2_oooooo2NX:0_ooool3o`WZ2PCooooo00?o2NX:ooooooooool00ol9jPX3ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00;ooooo00Go2NX:ooooooooooooooooo`000002ooooo`Co2NX:1Oooool00ol0003oRe:8
oh]BR007oh]BR003o`000?n;DXSoRe:800SoRe:800?o0000ooooooooool01Oooool3o`0000coYl3[
00?o0000ooooool00000@?ooool01?l0003oooooooooool0000Nooooo`00;oooool5o`WZ2P?ooooo
0_l9jPX3ooooo`?o2NX:0_ooool00ol9jP[oooooo`WZ2P02o`WZ2P?ooooo0ol00003ooooo`?o2NX:
00Coooooo`WZ2_oooooooooo0ol9jPX4ooooo`03o`WZ2_oooooooooo00;ooooo0ol9jPX00ooooooo
2NX:ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`000002o`WZ
2PWooooo00?o0000oh]BR?n;DXP01_n;DXP3o`0000WoRe:800?o0000ooooooooool02?ooool2o`00
00_oYl3[0_l00010ooooo`04o`000?ooooooooooo`0001kooooo000]ooooo`?o2NX:0_ooool2o`WZ
2PCooooo00Ko2NX:ooooooooooooooooo`WZ2_ooool2o`WZ2P05ooooool9jP[oooooooooool9jPX0
1?l000000ooooooo2NX:o`WZ2P03ooooo`03o`WZ2_oooooo2NX:00;o2NX:0oooool2o`WZ2PCooooo
1_l9jPX3ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00oooool3o`WZ2P03oooo
ool0003ooooo00Wooooo00?o0000oh]BR?n;DXP00on;DXP3o`0000?oRe:800?o0000oh]BR?n;DXP0
1_n;DXP00ol0003oooooooooo`0:ooooo`;o00002?nW`>/3o`00047ooooo00?o0000ooooool00000
7_ooool002[ooooo0ol9jPX2ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool2o`WZ2P;ooooo
00?o2NX:ooooooooool00ol9jPX3o`0000;o2NX:0oooool01_l9jP[oooooo`WZ2_l9jP[oooooo`WZ
2P;ooooo0_l9jPX4ooooo`;o2NX:00?oooooo`WZ2_l9jPX00_l9jPX2ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooooooooooool2o`WZ2PCooooo00?o0000
ooooooooool02?ooool00ol0003oRe:8oh]BR003o`0000OoRe:800?o0000oh]BR?n;DXP01On;DXP0
0ol0003oooooooooo`0<ooooo`;o00000_nW`>/4o`0000;ooooo00?o0000ooooooooool0?oooool2
o`0001oooooo000Xooooo`;o2NX:0oooool3o`WZ2P?ooooo0_l9jPX3ooooo`03o`WZ2_oooooo2NX:
00;o2NX:0_ooool3o`0000?ooooo0ol9jPX2ooooo`03o`WZ2_oooooooooo00;o2NX:1?ooool2o`WZ
2P?ooooo0ol9jPX2ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`04
ooooo`;o2NX:1_ooool00ol0003oooooooooo`07ooooo`Co00002on;DXP00ol0003oRe:8oh]BR004
oh]BR003o`000?oooooooooo00kooooo0_l00006ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool07Oooool002Wooooo00?o2NX:ooooooooool00_ooool2o`WZ2P?ooooo00Ko2NX:oooo
ool9jP[o2NX:ooooool9jPX2ooooo`04o`WZ2_l0003o0000o`0000;ooooo0_l9jPX2ooooo`06o`WZ
2_oooooo2NX:o`WZ2_oooooo2NX:0oooool2o`WZ2P?ooooo1_l9jPX4ooooo`05o`WZ2_oooooooooo
ooooool9jPX01?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool01_ooool3o`WZ2PWooooo00?o0000ooooooooool00oooool3o`000003ooooool0003o
Re:800goRe:800?o0000oh]BR?n;DXP00on;DXP00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0H?ooool002Wooooo0_l9jPX4ooooo`?o2NX:00Coooooo`WZ
2_oooooooooo0_l9jPX01?oooooo0000o`000?l00002o`WZ2P;ooooo00Ko2NX:ooooool9jP[o2NX:
ooooool9jPX3ooooo`;o2NX:0oooool2o`WZ2P;ooooo0ol9jPX3ooooo`03o`WZ2_oooooooooo00;o
oooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`02ooooo`Co2NX:3?ooool00ol0003oooooooooo`03o`00
00Cooooo00?o0000oh]BR?n;DXP03On;DXP00ol0003oRe:8oh]BR002oh]BR003o`000?oooooooooo
00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`00:_ooool2o`WZ2P;o
oooo00?o2NX:ooooooooool00ol9jPX2ooooo`?o00000oooool3o`WZ2P03ooooool9jP[ooooo00;o
oooo0_l9jPX4ooooo`04o`WZ2_ooooooooooooooo`Co2NX:00?oooooo`WZ2_ooool00oooool00ol9
jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool00ol9jP[oooooooooo`02
ooooo`03o`WZ2_oooooooooo00Cooooo0ol9jPXAooooo`;o00001oooool00ol0003oRe:8oh]BR00>
oh]BR005o`000?n;DXSoRe:8oh]BR?l000004?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo063ooooo000/ooooo`03o`WZ2_oooooo2NX:00?ooooo00Go2NX:o`000?l0003o0000oooo
o`03o`WZ2P;ooooo00?o2NX:ooooooooool00_l9jPX4ooooo`03o`WZ2_oooooooooo00;ooooo1Ol9
jPX4ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool01_ooool3o`WZ2QCooooo00?o0000ooooooooool0
1_ooool00ol0003oRe:8oh]BR00?oh]BR004o`000?n;DXSoRe:8o`00013ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Pooooo`00;Oooool2o`WZ2P04ooooool0003o0000o`0000;o
2NX:0_ooool01_l9jP[oooooo`WZ2_l9jP[oooooo`WZ2P?ooooo00?o2NX:ooooooooool00_ooool2
o`WZ2P;ooooo0ol9jPX2ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool0
1Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`02ooooo`Co2NX:6?ooool00ol0003oooooooooo`05ooooo`03o`000?n;DXSoRe:8013oRe:800?o
0000oh]BR?l000004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo063ooooo000^
ooooo`;o00000oooool3o`WZ2P04ooooool9jP[oooooooooo`?o2NX:0oooool:o`WZ2PCooooo00?o
2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX0
1?ooool00ol9jP[oooooooooo`04ooooo`?o2NX:7Oooool00ol0003oooooooooo`04ooooo`03o`00
0?n;DXSoRe:8017oRe:80_l0000@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
H?ooool002kooooo0ol9jPX2ooooo`03o`WZ2_oooooo2NX:00;o2NX:0oooool2o`WZ2P;ooooo0ol9
jPX3ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P08ooooo`?o2NX:8Oooool00ol0003o
ooooooooo`03ooooo`03o`000?n;DXSoRe:8017oRe:80_l0000Aooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0H?ooool002kooooo00?o2NX:ooooool9jPX00_l9jPX3ooooo`;o2NX:
0oooool4o`WZ2P03ooooool9jP[ooooo00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03
o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ2_oooooooooo
00?ooooo0ol9jPXUooooo`03o`000?oooooooooo00;ooooo00?o0000oh]BR?n;DXP03_n;DXP3o`00
0003ooooool0003ooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Poooo
o`00;_ooool00ol9jP[oooooooooo`02o`WZ2PCooooo1Ol9jPX4ooooo`03o`WZ2_oooooooooo00;o
oooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooo
ooooooooooooo`WZ2P06ooooo`Co2NX::Oooool01Ol0003ooooooooooooooooo000000goRe:80ol0
0005ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Pooooo`00;_ooool01?l9jP[oooooooooooooool2o`WZ2P;ooooo0ol9jPX2ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`05ooooo`?o2NX:;Oooool01Ol0003ooooo
oooooooooooo000000[oRe:80ol00009ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00_ooool3o`0006;ooooo000^ooooo`06o`WZ2_ooooooooooooooool9jP[ooooo0_l9jPX00ooo
oooo2NX:ooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool01Ol9
jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02
ooooo`?o2NX:<Oooool01?l0003oooooooooool00007oh]BR0?o00003Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooooooo`1Pooooo`00;_ooool0
1Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ
2_ooooooooooooooool9jPX01?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Co
oooo0ol9jPXeooooo`03o`000?oooooo000000CoRe:80ol0000Aooooo`03o`000?oooooooooo00_o
oooo0_l00005ooooo`03o`000?oooooooooo063ooooo000^ooooo`05o`WZ2_ooooooooooooooool9
jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04
ooooo`03o`WZ2_oooooooooo00Gooooo1?l9jPXiooooo`;o000000CoRe:8o`000?l0003o00005Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H?oo
ool002kooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:ooooooooool0
0_ooool3o`WZ2Skooooo0_l0000Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Pooooo`00;Oooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_oo
ooooooooooooool9jPX01?ooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9
jPX01_ooool3o`WZ2T?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0H?ooool002gooooo00?o2NX:ooooooooool0
0_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`05ooooo`?o2NX:Aoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00;Oooool00ol9jP[ooooo
ooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:
00Gooooo0ol9jPY;ooooo`03o`000?oooooooooo01Gooooo0ol00008ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Goooool002gooooo00?o2NX:ooooooooool00_ooool01Ol9jP[o
oooooooooooooooo2NX:00Cooooo00?o2NX:ooooooooool00oooool4o`WZ2Toooooo00?o0000oooo
ooooool04Oooool3o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo05oooooo000]ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooooooo
ooooooooo`WZ2P07ooooo`?o2NX:E?ooool00ol0003oooooooooo`0=ooooo`?o00001oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool002go
oooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00;ooooo0ol9jPYHoooo
o`03o`000?oooooooooo00Sooooo1?l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Oooooo`00;Oooool01Ol9jP[ooooooooooooooooo2NX:
00Kooooo0ol9jPYLooooo`03o`000?oooooooooo00Cooooo0ol0000@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00;Oooool00ol9jP[o
ooooooooo`02ooooo`Ko2NX:H?ooool00ol0003oooooooooo`03o`0001Cooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo05oooooo000]ooooo`03o`WZ2_oooooo2NX:00;o
2NX:Ioooool2o`0001Sooooo00Co0000oooooooooooo00001Oooool3o`00067ooooo000]ooooo`;o
2NX:K?ooool2o`0001Oooooo00Co0000ooooool0003ooooo1?l00002ooooo`03o`000?oooooooooo
05oooooo002Mooooo`03o`000?oooooooooo01Gooooo0ol00006ooooo`03o`000?oooooooooo05oo
oooo002Nooooo`;o00005Oooool2o`0000Oooooo00?o0000ooooooooool0Goooool00:3ooooo0_l0
000@ooooo`?o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`1Oooooo`00X_ooool2
o`0000_ooooo0ol00004ooooo`;o00001_ooool00ol0003oooooooooo`1Oooooo`00Y?ooool00ol0
003oooooooooo`05ooooo`?o00001oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
05oooooo002Uooooo`;o00000_ooool3o`0000[ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1Oooooo`00Yoooool2o`0000gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo05oooooo002Yooooo`;o00003?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo05oooooo002[ooooo`?o00002Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool0Goooool00:kooooo0_l00007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool00000HOooool00;3ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo
0_l0001Qooooo`00/_ooool3o`0000;ooooo00?o0000ooooooooool00_ooool3o`00067ooooo002e
ooooo`?o000000Coooooo`000?l0003o0000I?ooool00;Oooooo0_l0001Wooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {247.5, 0}} -> {0.00319898, 0.0445717, \
0.00347428, 0.00347428}},
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.6 Prism-Lens Example", "Subsection",
  CellTags->{"AOG0.", "4.6", "AOG4.", "AOG4.6"}],

Cell[CellGroupData[{

Cell["Set-up", "Subsubsection",
  CellTags->{"AOG0.", "4.6.1", "AOG4.", "AOG4.6", "AOG4.6.1"}],

Cell["\<\
prism = Prism[{60,50,60},50];
prismgaussiansystem = {
Move[GaussianBeam[{5,5},{.01,.01}],0,20],
Move[prism,{30,-20}],
Move[BiConvexLens[45,30,10],60],
Move[Screen[50],120]};\
\>", "Input",
  CellLabel->"In[82]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[prismgaussiansystem];", "Input",
  CellLabel->"In[84]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74418 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0142289 1.01423 -0.111241 1.01423 [
[ 0 0 0 0 ]
[ 1 .74418 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .74418 L
0 .74418 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4001 .3968 m
.39394 .67174 L
s
.40098 .19055 m
.4001 .3968 L
s
.40017 .39677 m
.39402 .67172 L
s
.11088 .29336 m
.40017 .39677 L
s
.40015 .39686 m
.40103 .19062 L
s
.11085 .29346 m
.40015 .39686 L
s
.039 .916 .04 r
.15404 .52521 m
.33894 .51026 L
s
.14841 .47943 m
.29342 .46641 L
s
.33894 .51026 m
.39724 .49248 L
s
0 0 0 r
2 Mabswid
.33894 .51026 Mdot
.039 .916 .04 r
.5 Mabswid
.29342 .46641 m
.39799 .43312 L
s
0 0 0 r
2 Mabswid
.29342 .46641 Mdot
.039 .916 .04 r
.5 Mabswid
.14625 .50685 m
.29209 .49453 L
s
0 g
.08427 .57484 m
.11088 .29342 L
s
.11088 .29342 m
.40106 .19058 L
s
.08426 .57479 m
.11088 .29336 L
s
.40103 .19062 m
.11085 .29346 L
s
.039 .916 .04 r
.29209 .49453 m
.39733 .46177 L
s
0 0 0 r
2 Mabswid
.29209 .49453 Mdot
.29209 .49453 Mdot
.039 .916 .04 r
.5 Mabswid
.14391 .53464 m
.29074 .52302 L
s
0 0 0 r
2 Mabswid
.39724 .49248 Mdot
.039 .916 .04 r
.5 Mabswid
.13817 .48818 m
.2451 .47874 L
s
.29074 .52302 m
.39668 .49082 L
s
0 0 0 r
2 Mabswid
.29074 .52302 Mdot
.039 .916 .04 r
.5 Mabswid
.2451 .47874 m
.39743 .43035 L
s
0 0 0 r
2 Mabswid
.2451 .47874 Mdot
.39799 .43312 Mdot
.39733 .46177 Mdot
.39733 .46177 Mdot
0 g
.5 Mabswid
.394 .67167 m
.39433 .47774 L
s
.08424 .57474 m
.394 .67167 L
s
.39394 .67174 m
.39427 .47782 L
s
.39402 .67172 m
.08426 .57479 L
s
.55573 .39405 m
.54796 .36852 L
s
.54796 .36852 m
.57735 .35907 L
s
.54796 .36852 m
.53795 .3443 L
s
.56076 .41933 m
.55573 .39405 L
s
.55573 .39405 m
.58515 .38471 L
s
.53795 .3443 m
.56735 .33473 L
s
.53795 .3443 m
.52631 .32292 L
s
.56076 .41933 m
.59028 .41007 L
s
.57735 .35907 m
.58515 .38471 L
s
.56735 .33473 m
.57735 .35907 L
s
.58515 .38471 m
.59028 .41007 L
s
.039 .916 .04 r
.39668 .49082 m
.50166 .42527 L
s
0 0 0 r
2 Mabswid
.39668 .49082 Mdot
0 g
.5 Mabswid
.52631 .32292 m
.55577 .31323 L
s
.55577 .31323 m
.56735 .33473 L
s
.53791 .42794 m .59239 .43356 L .56273 .44276 L .656 .751 .92 r
F
0 g
.56147 .46285 m
.56273 .44276 L
s
.56076 .41933 m
.56169 .43039 L
s
.51374 .30576 m .55263 .32043 L .50501 .33606 L .544 .324 .532 r
F
.51374 .30576 m .54332 .29594 L .55263 .32043 L F
0 g
.54332 .29594 m
.55577 .31323 L
s
.51374 .30576 m
.54332 .29594 L
s
.50105 .29398 m
.51374 .30576 L
s
.53791 .42794 m .58563 .41298 L .59239 .43356 L .656 .751 .92 r
F
0 g
.5913 .45368 m
.59239 .43356 L
s
.59028 .41007 m
.59239 .43356 L
s
.56273 .44276 m
.59239 .43356 L
s
0 0 0 r
2 Mabswid
.39743 .43035 Mdot
0 g
.5 Mabswid
.557 .47823 m
.56147 .46285 L
s
.56147 .46285 m
.5913 .45368 L
s
.51646 .41174 m .58563 .41298 L .53791 .42794 L .656 .751 .92 r
F
0 g
.53791 .42794 m
.56273 .44276 L
s
.039 .916 .04 r
.39724 .49248 m
.52086 .41539 L
s
0 g
.53077 .28404 m
.54332 .29594 L
s
.50501 .33606 m .55833 .34655 L .49988 .3655 L .544 .324 .532 r
F
.50501 .33606 m .55263 .32043 L .55833 .34655 L F
0 g
.50501 .33606 m
.51374 .30576 L
s
.54332 .29594 m
.55263 .32043 L
s
.5913 .45368 m
.58704 .46906 L
s
.50105 .29398 m
.53077 .28404 L
s
.50105 .29398 m
.48905 .28847 L
s
.54956 .4878 m
.557 .47823 L
s
.557 .47823 m
.58704 .46906 L
s
.51646 .41174 m .57497 .3932 L .58563 .41298 L .656 .751 .92 r
F
0 g
.58563 .41298 m
.59239 .43356 L
s
.4982 .39417 m .57497 .3932 L .51646 .41174 L .656 .751 .92 r
F
0 g
.51646 .41174 m
.53791 .42794 L
s
.039 .916 .04 r
.39799 .43312 m
.50153 .36545 L
s
.39733 .46177 m
.50003 .39615 L
s
.50153 .36545 m
.50471 .36393 L
s
0 g
.51897 .27843 m
.53077 .28404 L
s
.49988 .3655 m .56054 .37421 L .4982 .39417 L .544 .324 .532 r
F
.49988 .3655 m .55833 .34655 L .56054 .37421 L F
0 g
.49988 .3655 m
.50501 .33606 L
s
.039 .916 .04 r
.51221 .36035 m
.55287 .34092 L
s
0 g
.40106 .19058 m
.39436 .47784 L
s
.39427 .47782 m
.40098 .19055 L
s
.55263 .32043 m
.55833 .34655 L
s
.58704 .46906 m
.57981 .47859 L
s
.48905 .28847 m
.51897 .27843 L
s
.48905 .28847 m
.47858 .28974 L
s
.53957 .49075 m
.54956 .4878 L
s
.54956 .4878 m
.57981 .47859 L
s
.4982 .39417 m .55924 .40339 L .49997 .42213 L .544 .324 .532 r
F
.4982 .39417 m .56054 .37421 L .57497 .3932 L .656 .751 .92 r
F
.4982 .39417 m .56054 .37421 L .55924 .40339 L .544 .324 .532 r
F
0 g
.57497 .3932 m
.58563 .41298 L
s
.48312 .3752 m .56054 .37421 L .4982 .39417 L .656 .751 .92 r
F
0 g
.49932 .37499 m
.49988 .3655 L
s
.039 .916 .04 r
.55966 .39412 m
.57127 .38775 L
s
0 g
.92782 .23994 m
.94136 .2837 L
s
.91179 .19793 m
.92782 .23994 L
s
.94136 .2837 m
.95162 .32671 L
s
.5087 .27962 m
.51897 .27843 L
s
.039 .916 .04 r
.57127 .38775 m
.82888 .18151 L
s
0 0 0 r
2 Mabswid
.57127 .38775 Mdot
0 g
.5 Mabswid
.89417 .16013 m
.91179 .19793 L
s
.57981 .47859 m
.57003 .48148 L
s
.039 .916 .04 r
.55287 .34092 m
.8374 .20072 L
s
0 0 0 r
2 Mabswid
.55287 .34092 Mdot
0 g
.5 Mabswid
.95162 .32671 m
.95797 .36644 L
s
.47858 .28974 m
.47038 .29788 L
s
.5087 .27962 m
.47858 .28974 L
s
.49997 .42213 m .5543 .4341 L .50534 .44937 L .544 .324 .532 r
F
.49997 .42213 m .55924 .40339 L .5543 .4341 L F
0 g
.4982 .39417 m
.49997 .42213 L
s
.039 .916 .04 r
.51248 .41936 m
.55369 .39685 L
s
0 g
.52765 .48673 m
.53957 .49075 L
s
.53957 .49075 m
.57003 .48148 L
s
.48312 .3752 m .54233 .35604 L .56054 .37421 L .656 .751 .92 r
F
0 g
.55833 .34655 m
.56054 .37421 L
s
.56054 .37421 m
.57497 .3932 L
s
.47134 .35474 m .54233 .35604 L .48312 .3752 L .656 .751 .92 r
F
0 g
.48312 .3752 m
.4982 .39417 L
s
.039 .916 .04 r
.51335 .38932 m
.55488 .36804 L
s
.39743 .43035 m
.48267 .37453 L
s
0 0 0 r
2 Mabswid
.48267 .37453 Mdot
0 g
.5 Mabswid
.55924 .40339 m
.56054 .37421 L
s
.50071 .28771 m
.5087 .27962 L
s
.87597 .12887 m
.89417 .16013 L
s
.039 .916 .04 r
.55488 .36804 m
.83704 .1932 L
s
0 0 0 r
2 Mabswid
.55488 .36804 Mdot
.55488 .36804 Mdot
0 g
.5 Mabswid
.57003 .48148 m
.55831 .47737 L
s
.95797 .36644 m
.95993 .40045 L
s
.95797 .36644 m
.93589 .33481 L
s
.95797 .36644 m
.95797 .36644 L
s
.47038 .29788 m
.50071 .28771 L
s
.47038 .29788 m
.46509 .31248 L
s
.50534 .44937 m .54544 .46637 L .51462 .47585 L .544 .324 .532 r
F
.50534 .44937 m .5543 .4341 L .54544 .46637 L F
0 g
.49997 .42213 m
.50534 .44937 L
s
.50534 .44937 m
.51462 .47585 L
s
.5543 .4341 m
.55924 .40339 L
s
.51462 .47585 m
.52765 .48673 L
s
.52765 .48673 m
.55831 .47737 L
s
.47134 .35474 m .5202 .33876 L .54233 .35604 L .656 .751 .92 r
F
0 g
.54233 .35604 m
.56054 .37421 L
s
.46316 .33264 m .5202 .33876 L .47134 .35474 L .656 .751 .92 r
F
0 g
.47134 .35474 m
.48312 .3752 L
s
.039 .916 .04 r
.48267 .37453 m
.53487 .34975 L
s
0 g
.49563 .3023 m
.50071 .28771 L
s
.039 .916 .04 r
.55369 .39685 m
.836 .18474 L
s
0 0 0 r
2 Mabswid
.55369 .39685 Mdot
0 g
.5 Mabswid
.39433 .47774 m
.08424 .57474 L
s
.39436 .47784 m
.08427 .57484 L
s
.8583 .10624 m
.87597 .12887 L
s
.87597 .12887 m
.87597 .12887 L
s
.87597 .12887 m
.88048 .17441 L
s
.039 .916 .04 r
.53487 .34975 m
.84203 .20035 L
s
0 0 0 r
2 Mabswid
.53487 .34975 Mdot
0 g
.5 Mabswid
.54544 .46637 m
.55831 .47737 L
s
.49563 .3023 m
.46509 .31248 L
s
.54544 .46637 m
.5543 .4341 L
s
.95993 .40045 m
.95725 .42645 L
s
.51462 .47585 m
.54544 .46637 L
s
.50138 .45876 m
.51462 .47585 L
s
.46316 .33264 m .49388 .32248 L .5202 .33876 L .656 .751 .92 r
F
0 g
.49388 .32248 m
.5202 .33876 L
s
.46316 .33264 m
.46509 .31248 L
s
.5202 .33876 m
.54233 .35604 L
s
.46316 .33264 m
.47134 .35474 L
s
.49388 .32248 m
.49563 .3023 L
s
.93589 .33481 m
.91318 .30227 L
s
.46316 .33264 m
.49388 .32248 L
s
.46316 .33264 m
.46479 .35697 L
s
.53233 .44914 m
.54544 .46637 L
s
.48891 .4366 m
.50138 .45876 L
s
.50138 .45876 m
.53233 .44914 L
s
.88048 .17441 m
.88509 .22104 L
s
.84229 .09398 m
.8583 .10624 L
s
.49388 .32248 m
.49566 .34687 L
s
.46479 .35697 m
.49566 .34687 L
s
.46479 .35697 m
.4699 .38374 L
s
.47815 .41096 m
.48891 .4366 L
s
.48891 .4366 m
.51993 .42685 L
s
.53233 .44914 m
.51993 .42685 L
s
.4699 .38374 m
.50088 .37373 L
s
.4699 .38374 m
.47815 .41096 L
s
.47815 .41096 m
.50917 .40107 L
s
.95725 .42645 m
.94992 .44247 L
s
.50088 .37373 m
.49566 .34687 L
s
.51993 .42685 m
.50917 .40107 L
s
.50917 .40107 m
.50088 .37373 L
s
.91318 .30227 m
.88981 .2688 L
s
.88509 .22104 m
.88981 .2688 L
s
.82908 .09335 m
.84229 .09398 L
s
.94992 .44247 m
.93825 .44701 L
s
.89465 .31771 m
.88981 .2688 L
s
.88981 .2688 m
.86576 .23434 L
s
.81969 .10489 m
.82908 .09335 L
s
.93825 .44701 m
.92284 .43924 L
s
.89465 .31771 m
.8996 .36784 L
s
.86576 .23434 m
.84099 .19886 L
s
.81498 .1283 m
.81969 .10489 L
s
.92284 .43924 m
.90468 .41921 L
s
.8996 .36784 m
.90468 .41921 L
s
0 0 0 r
2 Mabswid
.84203 .20035 Mdot
0 g
.5 Mabswid
.84099 .19886 m
.81548 .1623 L
s
0 0 0 r
2 Mabswid
.836 .18474 Mdot
.83704 .1932 Mdot
.83704 .1932 Mdot
0 g
.5 Mabswid
.81548 .1623 m
.81498 .1283 L
s
0 0 0 r
2 Mabswid
.8374 .20072 Mdot
.82888 .18151 Mdot
0 g
.5 Mabswid
.90468 .41921 m
.88503 .38797 L
s
.90468 .41921 m
.90468 .41921 L
s
.82132 .20463 m
.81548 .1623 L
s
.81548 .1623 m
.81548 .1623 L
s
.88503 .38797 m
.86538 .34759 L
s
.83219 .25213 m
.82132 .20463 L
s
.86538 .34759 m
.84727 .30109 L
s
.84727 .30109 m
.83219 .25213 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[84]:=",
  ImageSize->{288, 214.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eR000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00kOooool6o`0002gooooo003]ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0:_ooool00>cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Yooooo`00joooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo003[oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09oooool00>_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Wooooo`00j_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Kooooo003Zooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Ooo
ool00>[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`00jOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo003Yooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool08_ooool00>Wooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Rooooo`00jOooool00ol0003oooooooooo`0?ooooo`;o00008oooool00>Wooooo00?o0000
ooooooooool03oooool2o`0002?ooooo003Yooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ool000008_ooool00>Wooooo00?o0000ooooooooool03oooool01?l0003oooooooooool0000Qoooo
o`00jOooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`00027ooooo003Yooooo`03
o`000?oooooooooo013ooooo00Co0000oooooooooooo00008?ooool00>Wooooo00?o0000oooooooo
ool04?ooool01?l0003oooooooooool0000Pooooo`00jOooool2o`00017ooooo00Go0000oooooooo
ooooooooo`00000Oooooo`00jOooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000007oooool00>Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01cooooo003Yooooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01cooooo003Yooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Kooooo`00j_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06oooool00>[ooooo00?o0000ooooool9jPX00_l0000=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00>[ooooo00?o0000o`WZ2_oo
ool01?l0000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00>[ooooo
00Co0000oooooooooooo2NX:0ol0000;ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool06_ooool007;ooooo0_l0001eooooo`04o`WZ2_l0003oooooo`WZ2P;ooooo0_l0000;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool006oooooo0ol000000ooooooo0000
ooooo`1booooo`;o2NX:00?oooooo`000?l9jPX00oooool2o`0000_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Iooooo`00K?ooool3o`0000Cooooo00?o0000ooooooooool0L?oo
ool01_l9jP[oooooooooool9jP[oooooo`0000;ooooo00?o2NX:o`000?l000000_l00009ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool006Wooooo0ol00007ooooo`03o`00
0?oooooooooo06oooooo00Co2NX:oooooooooooo2NX:0_ooool01?l0003o2NX:o`WZ2_ooool4o`00
00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`00I_ooool3o`0000[o
oooo00?o0000ooooooooool0K_ooool01?l9jP[oooooo`WZ2_l9jPX2ooooo`03o`WZ2_l0003ooooo
00?o2NX:0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05oooool006?ooooo0ol0000=ooooo`03o`000?oooooooooo06cooooo0_l9jPX00ooooooo
2NX:ooooo`02ooooo`03o`WZ2_oooooo000000;o2NX:1Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool0063ooooo0ol0000@ooooo`03o`00
0?oooooooooo06_ooooo00Co2NX:oooooooooooo2NX:0_ooool4o`WZ2P03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oo
oooo001Mooooo`?o00004oooool00ol0003oooooooooo`1Zooooo`05o`WZ2_oooooo2NX:o`WZ2_oo
ool01Ol9jPX2ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Kooooo001Jooooo`?o00005_ooool00ol0003ooooo
ooooo`1Yooooo`03o`WZ2_oooooo2NX:00;ooooo1?l9jPX4ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo
001Gooooo`?o00006Oooool00ol0003oooooooooo`1Wooooo`;o2NX:00?oooooo`WZ2_ooool00ol9
jPX7ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01Gooooo001Eooooo`;o00007?ooool00ol0003oooooooooo`1V
ooooo`05o`WZ2_oooooo2NX:o`WZ2_ooool00_l9jPX9ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo001B
ooooo`?o00007_ooool00ol0003oooooooooo`1Uooooo`04o`WZ2_oooooo2NX:ooooo`;o2NX:3?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Dooooo`00Coooool3o`00027ooooo00?o0000ooooooooool0I?ooool0
0ol9jP[oooooo`WZ2P02o`WZ2Pkooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool004cooooo0ol0000Toooo
o`03o`000?oooooooooo06;ooooo1Ol9jPX@ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo0019ooooo`?o
00009oooool00ol0003oooooooooo`1Qooooo`Go2NX:4Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`00
A_ooool3o`0002[ooooo00?o0000ooooooooool0H?ooool4o`WZ2Q?ooooo00?o0000ooooooooool0
2_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool04oooool004?ooooo
0ol0000]ooooo`03o`000?oooooooooo05kooooo1Ol9jPXEooooo`03o`000?oooooooooo00Wooooo
00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo01?ooooo0010ooooo`?o0000
<?ooool00ol0003oooooooooo`1Looooo`Go2NX:5oooool00ol0003oooooooooo`0:ooooo`04o`00
0?ooooooooooo`0000cooooo00?o0000ooooooooool04_ooool003gooooo0ol0000cooooo`03o`00
0?oooooooooo05[ooooo0ol9jPX00ooooooo2NX:ooooo`0Hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooool000003?ooool00ol0003oooooooooo`0Booooo`00>oooool2o`0003Kooooo00?o
0000ooooooooool0F?ooool6o`WZ2Q_ooooo00?o0000ooooooooool02oooool2o`0000cooooo00?o
0000ooooooooool04_ooool003Sooooo0ol0000hooooo`03o`000?oooooooooo05Kooooo0_l9jPX2
ooooo`;o2NX:7Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000cooooo00?o0000
ooooooooool04Oooool003Gooooo0ol0000jooooo`;o0000E_ooool2o`WZ2P;ooooo0ol9jPXNoooo
o`03o`000?oooooooooo00cooooo0_l0000<ooooo`03o`000?oooooooooo017ooooo000booooo`?o
0000?Oooool2o`0005Cooooo0_l9jPX3ooooo`?o2NX:8?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool002oooooo0ol00010ooooo`;o0000
D_ooool2o`WZ2PCooooo0_l9jPXRooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0@ooooo`00;?ooool3o`0004?ooooo0_l0001@ooooo`;o2NX:1?oo
ool3o`WZ2R?ooooo00?o0000ooooooooool03?ooool2o`0000cooooo00?o0000ooooooooool04?oo
ool002Wooooo0ol00016ooooo`;o00007?ooool6o`0002cooooo0_l9jPX4ooooo`Co2NX:9Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool04?ooool0
02Kooooo0ol00019ooooo`;o00006Oooool6o`0000?ooooo0_l0000Xooooo`;o2NX:1Oooool3o`WZ
2ROooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo
00oooooo000Sooooo`?o0000C?ooool2o`0001Kooooo1ol00005ooooo`?o00009Oooool2o`WZ2PGo
oooo1?l9jPXXooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00002oooool00ol0
003oooooooooo`0?ooooo`008?ooool3o`0004oooooo0_l0000Eooooo`Oo000000?oooooo`000?l0
00000ol00003ooooo`03o`000?oooooooooo023ooooo0_l9jPX5ooooo`Go2NX::_ooool00ol0003o
ooooooooo`0:ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool03oooool001oo
oooo0_l0001Aooooo`;o00005Oooool00ol0003oooooo`000002o`000003ooooool0003o000000Wo
oooo00?o0000ooooooooool07?ooool3o`WZ2PKooooo00Co2NX:ooooool9jP[o2NX:;?ooool00ol0
003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0?
ooooo`007oooool00ol0003oooooo`000002o`0004kooooo00?o0000ooooooooool04oooool3o`00
00Cooooo0_l00009ooooo`;o00006oooool3o`WZ2PKooooo0_l9jPX00ooooooo2NX:o`WZ2P0]oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo
oooo00oooooo000Oooooo`03o`000?oooooooooo00;ooooo0ol0001;ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00005ooooo`?o000000?oRe:8
o`000?ooool06?ooool3o`WZ2POooooo00?o2NX:ooooooooool00_l9jPX_ooooo`03o`000?oooooo
oooo00[ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00kooooo000O
ooooo`03o`000?oooooooooo00Gooooo0ol00018ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00oooool2o`0000?ooooo00?o0000ooooool000000_l00005oh]BR003o`000?oooooo
oooo01Cooooo0ol9jPX7ooooo`;o2NX:00Coooooo`WZ2_l9jP[o2NX:<?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0>ooooo`007oooool00ol0003oooooooooo`08ooooo`;o0000A_ooool00ol0003oooooooooo`0A
ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool00oooool00ol0003oRe:8oh]B
R006oh]BR0;o00004oooool3o`WZ2POooooo0_l9jPX2ooooo`;o2NX:<oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0>ooooo`007oooool00ol0003oooooooooo`0:ooooo`?o0000@oooool00ol0003oooooooooo`0A
ooooo`Co00001?ooool00ol0003oooooooooo`02ooooo`03o`000?n;DXSoRe:800OoRe:80_l0000@
ooooo`;o2NX:2Oooool01?l9jP[oooooooooooooool2o`WZ2SCooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_oo
ool001oooooo00?o0000ooooooooool03Oooool3o`00043ooooo00?o0000ooooooooool04?ooool2
o`0000Oooooo00Go0000ooooooooooooooooo`00000:oh]BR0?o00003Oooool2o`WZ2PWooooo0_l9
jPX3ooooo`;o2NX:=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0A
ooooo`?o0000?Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oRe:8oh]BR008oh]BR003o`000?oooooo000000_ooooo0_l9jPX9
ooooo`;o2NX:0oooool2o`WZ2SSooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool001kooooo00?o0000oooo
ooooool05?ooool3o`0003[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000oh]BR?n;DXP02On;DXP00ol0003oooooo`000008oooo
o`;o2NX:2_ooool00ol9jP[oooooooooo`02ooooo`;o2NX:>Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=oooo
o`007_ooool00ol0003oooooooooo`0Gooooo`;o0000>?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Cooooo0ol00002ooooo`03o`000?n;DXSoRe:800[oRe:800?o0000ooooool0
00001_ooool2o`WZ2P[ooooo0_l9jPX4ooooo`;o2NX:>_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`00
7_ooool00ol0003oooooooooo`0Iooooo`?o0000=Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00;ooooo0ol000000onW`>_o0000ojO0j`03o`0000coRe:800Co0000oooooooooooo
00000oooool2o`WZ2P_ooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`0kooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00gooooo000Nooooo`03o`000?oooooooooo01cooooo0ol0000booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooool000000_l00004ojO0j`04o`000?nW`>_oYl3[ojO0j`;o
00003?n;DXP00ol0003oooooo`000003o`WZ2P_ooooo0_l9jPX4ooooo`;o2NX:?_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0=ooooo`007_ooool00ol0003oooooooooo`0Oooooo`?o0000;oooool00ol0003ooooo
ooooo`0?ooooo`;o00001onW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00002_n;DXP01?l0003o2NX:
o`WZ2_l9jPX;ooooo`;o2NX:1Oooool2o`WZ2Soooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool000003oooool001kooooo00?o0000oooooooo
ool08_ooool2o`0002gooooo00?o0000ooooooooool03oooool00ol0003oYl3[ojO0j`07ojO0j`03
o`000?nW`>_oYl3[00CoYl3[0_l00007oh]BR0?o2NX:00?oooooo`000?ooool02Oooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooooooo043ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool000003oooool001kooooo00?o0000oooooooo
ool09?ooool3o`0002[ooooo00?o0000ooooooooool03oooool2o`0000SoYl3[00?o0000ojO0jonW
`>/01_nW`>/00ol0003oRe:8oh]BR002oh]BR0;o2NX:0_l00003ooooo`03o`000?oooooooooo00Go
oooo0_l9jPX6ooooo`03o`WZ2_oooooooooo047ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000003_ooool001kooooo00?o0000oooooooo
ool09oooool3o`0002Oooooo00?o0000ooooooooool03oooool2o`0000SoYl3[00?o0000ojO0jonW
`>/01onW`>/00ol0003oRe:8o`WZ2P02o`WZ2P?oRe:800Co0000oooooooooooo00001_ooool00ol9
jP[oooooooooo`04ooooo`;o2NX:A?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00[ooooo00Co0000oooooooooooo00003_ooool001kooooo00?o0000ooooooooool0:_ooool3o`00
02Cooooo00?o0000ooooooooool04?ooool2o`0000KoYl3[0_l00009ojO0j`;o000000?o2NX:oh]B
R?n;DXP00on;DXP01Ol0003ooooooooooooooooo000000?ooooo0_l9jPX6ooooo`03o`WZ2_oooooo
oooo04Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`04o`000?oooooo
ooooo`0000kooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000Rooooo`03o`000?oooooo
oooo013ooooo0_l00003ojO0j`?o000000?oYl3[o`000?nW`>/01_nW`>/2o`WZ2P?o00001On;DXP0
1_l0003ooooooooooooooooo0000ooooo`;o2NX:1oooool00ol9jP[oooooooooo`16ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`007Ooo
ool00ol0003oooooooooo`0`ooooo`?o00007oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooo000000;o00001?nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o2NX:1OnW`>/00ol0003oRe:8oh]B
R002oh]BR006o`000?ooooooooooooooool0003o2NX:1oooool2o`WZ2T[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool001gooooo00?o0000ooooooooool0
<oooool3o`0001cooooo00?o0000ooooooooool04?ooool3o`0000KoYl3[00Co0000ojO0jonW`>_o
Yl3[0_l9jPX8ojO0j`05o`000?n;DXSoRe:8oh]BR?l000000_ooool2o`WZ2P03o`000?oooooooooo
00Cooooo0_l9jPY;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooo`00000=ooooo`007Oooool00ol0003oooooooooo`0fooooo`?o00006Oooool00ol0003o
ooooooooo`0@ooooo`04o`000?ooooooooooo`0000KoYl3[00?o0000ojO0jol9jPX02onW`>/01?l0
003oRe:8oh]BR?l00002o`WZ2P03o`000?oooooo000000Gooooo00?o2NX:ooooooooool0C?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`007Oooool00ol0
003oooooooooo`0iooooo`;o00005oooool00ol0003oooooooooo`0@ooooo`04o`000?oooooooooo
o`0000KoYl3[00?o0000o`WZ2_nW`>/03?nW`>/2o`000003o`WZ2_oooooooooo00;ooooo00Co0000
oooooooooooooooo0_l9jPY?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Ooo
ool2o`0000cooooo000Mooooo`03o`000?oooooooooo03_ooooo0ol0000Dooooo`03o`000?oooooo
oooo013ooooo00Go0000ooooooooooooooooo`000003ojO0j`;o2NX:00?o0000ojO0jonW`>/03?nW
`>/3o`0000Gooooo00Co0000ooooool9jP[o2NX:DOooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02oooool001gooooo00?o0000ooooooooool0?_oo
ool3o`00017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02o`0000;o2NX:00?o
Yl3[o`000?l000003?nW`>/2o`WZ2P;oYl3[00?o0000ooooooooool00oooool00ol0003o2NX:o`WZ
2P1Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`007Oooool00ol0003oooooooooo`11ooooo`?o00003_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00;o2NX:0ol000000onW`>_o0000ojO0j`09ojO0j`;o2NX:0onW`>/0
0on;DXSo0000ooooo`03ooooo`;o2NX:E?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02oooool001gooooo00?o0000ooooooooool0A?ooool3o`00
00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooo`000002o`0000GoYl3[00?o0000ojO0
jonW`>/01OnW`>/2o`WZ2P;oYl3[1?n;DXP2o`0000;ooooo0_l9jPX00ooooooo0000ooooo`1Coooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`007Oooool00ol0003oooooooooo`17ooooo`;o00002Oooool00ol0003oooooooooo`0Aooooo`;o
00000oooool00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l9jPX00onW`>_o
Re:8oh]BR005oh]BR003o`000?nW`>_o000000;o2NX:00?oooooo`000?l00000E?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool001gooooo
00?o0000ooooooooool0BOooool3o`0000Kooooo00?o0000ooooooooool04?ooool00ol9jP[o0000
ooooo`04ooooo`05o`000?nW`>_oYl3[ojO0jol000000onW`>/2o`WZ2P[oRe:800?o0000o`WZ2_l9
jPX00ol000000ooooooo0000ooooo`1Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0:ooooo`007Oooool00ol0003oooooooooo`1<ooooo`?o0000
0oooool00ol0003oooooooooo`0>ooooo`;o2NX:0_ooool00ol0003oooooooooo`03ooooo`07o`00
0?nW`>_oYl3[ojO0jol0003oYl3[o`WZ2P0<oh]BR0;o2NX:00?oYl3[o`000?l000000_ooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0:ooooo`007Oooool00ol0003oooooooooo`1?ooooo`Co00003oooool2o`WZ2P?o
oooo00?o0000ooooooooool01?ooool01?l0003oYl3[oh]BR?l0000<oh]BR0?o00000onW`>/01Ol0
003ooooooooooooooooo000005Gooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oo
oooooooo00[ooooo000Looooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02oooool2
o`WZ2PGooooo00?o0000ooooooooool01?ooool01?l0003oRe:8oh]BR?l0000;oh]BR004o`WZ2_l0
003o0000o`0000?oYl3[00Go0000ooooooooooooooooo`00001Fooooo`05o`000?oooooooooooooo
ool000003oooool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00[ooooo00?o2NX:ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04
o`WZ2_l0003oRe:8oh]BR0;o00002?n;DXP2o`WZ2P?oRe:800?o0000ojO0jonW`>/00_nW`>/01?l0
003oooooooooool0001Fooooo`05o`000?ooooooooooooooool000003oooool00ol0003ooooooooo
o`0:ooooo`007?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Sooooo0_l9jPX9
ooooo`03o`000?oooooooooo00;o2NX:00Koooooo`000?l0003o0000oh]BR?l00006oh]BR0;o2NX:
1On;DXP00ol0003oYl3[ojO0j`03ojO0j`03o`000?oooooo000005Oooooo00Co0000oooooooooooo
00003oooool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o0000
2Oooool00ol9jP[oooooooooo`09ooooo`03o`000?oooooo2NX:00Co00001?n;DXP00ol0003oRe:8
oh]BR002oh]BR003o`WZ2_n;DXSoRe:800GoRe:800?o0000ojO0jonW`>/00onW`>/01?l0003ooooo
ooooool0001Gooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool02_ooool001cooooo
00?o0000ooooooooool0D_ooool2o`0000Oooooo0_l9jPX<ooooo`03o`WZ2_l0003o000000Cooooo
00Go0000oh]BR?n;DXSoRe:8o`000002oh]BR0;o2NX:2?n;DXP00ol0003oYl3[ojO0j`04ojO0j`?o
0000Eoooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00[ooooo000Looooo`03o`00
0?oooooooooo05;ooooo0_l00006ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooool00000
1Oooool01Ol0003oRe:8oh]BR?n;DXSo000000;o2NX:2_n;DXP00ol0003oYl3[ojO0j`05ojO0j`;o
0000F?ooool2o`0000kooooo00?o0000ooooooooool02oooool001cooooo00?o0000ooooooooool0
D_ooool2o`0000Cooooo0_l9jPX<ooooo`;o2NX:0oooool00ol0003oooooooooo`02ooooo`06o`00
0?n;DXSoRe:8oh]BR?l9jP[o00002on;DXP00ol0003oYl3[ojO0j`05ojO0j`;o0000FOooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooooooo05;o
oooo0_l00003ooooo`03o`WZ2_oooooooooo00_ooooo00?o2NX:ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?n;DXSoRe:800;oRe:800?o0000oh]BR?n;DXP02?n;DXP00ol0003o
Yl3[ojO0j`06ojO0j`;o0000FOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo000Looooo`03o`000?oooooooooo05;ooooo0_l000000ooooooo2NX:o`WZ2P0<ooooo`;o2NX:
1oooool01Ol0003oooooooooool9jP[o000000CoRe:800?o0000oh]BR?n;DXP02?n;DXP00ol0003o
Yl3[ojO0j`07ojO0j`03o`000?oooooooooo05Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o000000?o2NX:ooooooooool0
2_ooool2o`WZ2PWooooo00Go0000ooooool9jP[o2NX:o`000003oh]BR0?o00002On;DXP00ol0003o
Yl3[ojO0j`07ojO0j`03o`000?oooooooooo05Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`1Aooooo`03o`WZ2_l0003o2NX:00cooooo
00?o2NX:ooooooooool02Oooool00ol0003o2NX:o`WZ2P05o`0000;oRe:800?o0000oh]BR?n;DXP0
1on;DXP00ol0003oYl3[o`000006ojO0j`;o0000G?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00cooooo000Kooooo`03o`000?oooooooooo04oooooo1?l9jPX2o`0000[ooooo0_l9
jPX:ooooo`?o2NX:0_l00002ooooo`03o`000?n;DXSoRe:800?oRe:800?o0000oh]BR?n;DXP01_n;
DXP00ol0003oYl3[ojO0j`03ojO0j`?o000000?oooooo`000?ooool0G?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00cooooo000Kooooo`03o`000?oooooooooo04cooooo1?l9jPX3
ooooo`;o00002Oooool00ol9jP[oooooooooo`09ooooo`?o2NX:00?oooooo`000?ooool00_ooool0
0ol0003oRe:8oh]BR003oh]BR003o`000?n;DXSoRe:800KoRe:80_l000001?nW`>_o0000o`000?l0
0004ooooo`03o`000?oooooooooo05cooooo0_l00007ooooo`03o`000?oooooooooo00cooooo000K
ooooo`03o`000?oooooooooo04Sooooo1Ol9jPX6ooooo`;o00001oooool2o`WZ2P[ooooo0ol9jPX4
ooooo`04o`000?ooooooooooo`0000KoRe:800?o0000oh]BR?n;DXP01?n;DXP01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo05kooooo0ol00002ooooo`;o00003oooool001_ooooo00?o
0000ooooooooool0AOooool5o`WZ2PWooooo0_l00006ooooo`03o`WZ2_oooooooooo00Wooooo0_l9
jPX6ooooo`05o`000?ooooooooooooooool000001On;DXP00ol0003oRe:8oh]BR004oh]BR004o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0HOooool2o`00017ooooo000Kooooo`03o`00
0?oooooooooo047ooooo1_l9jPX<ooooo`;o00001?ooool2o`WZ2P[ooooo0ol9jPX8ooooo`04o`00
0?ooooooooooo`0000GoRe:80_l00005oh]BR004o`000?ooooooooooo`0000Oooooo00?o0000oooo
ooooool0M?ooool001_ooooo00?o0000ooooooooool0?_ooool6o`WZ2Poooooo0_l00003ooooo`03
o`WZ2_oooooooooo00Wooooo0_l9jPX:ooooo`04o`000?ooooooooooo`0000;oRe:80ol000000on;
DXSo0000oh]BR003oh]BR005o`000?ooooooooooooooool000001_ooool2o`0007Kooooo000Koooo
o`03o`000?oooooooooo03_ooooo1_l9jPXBooooo`;o000000?oooooo`WZ2_l9jPX02_ooool3o`WZ
2P_ooooo00?o0000ooooooooool00ol00005oh]BR005o`000?n;DXSoRe:8oh]BR?l000000oooool0
1?l0003oooooooooooooool3o`000003ooooool0003ooooo07Gooooo000Kooooo`03o`000?oooooo
oooo03Oooooo1ol9jPXEooooo`;o000000?o2NX:ooooooooool02?ooool3o`WZ2Pkooooo0_l00000
0ooooooo0000oh]BR006oh]BR004o`000?n;DXSoRe:8o`0000?ooooo1?l00004ooooo`03o`000?oo
oooooooo07Cooooo000Kooooo`03o`000?oooooooooo03Cooooo0ol9jPX01?oooooo2NX:o`WZ2_l9
jPXGooooo`03o`WZ2_l0003o2NX:00[ooooo0ol9jPX?ooooo`04o`000?ooooooooooo`0000SoRe:8
0_l00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0MOooool001_ooooo00?o
0000ooooooooool0<?ooool5o`WZ2P;o000000?o2NX:ooooooooool05Oooool3o`WZ2P03ooooool0
003o000000Sooooo0ol9jPXBooooo`03o`000?oooooo000000SoRe:80ol00003ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0MOooool001_ooooo00?o0000ooooooooool09_ooool;
o`WZ2Q[ooooo1?l9jPX4ooooo`;o00001oooool2o`WZ2QGooooo0_l00005oh]BR0?o00000oooool0
0ol0003oooooo`000005ooooo`?o0000Moooool001_ooooo00?o0000ooooooooool07?ooool:o`WZ
2PCooooo0ol9jPXKooooo`?o2NX:2?ooool2o`0000Gooooo0ol9jPXGooooo`;o000000CoRe:8o`00
0?l0003o00001oooool7o`000003ooooool0003ooooo07Oooooo000Jooooo`03o`000?oooooooooo
01;ooooo2ol9jPX7ooooo`Co2NX:0_l000000ol9jP[oooooooooo`0Hooooo`Co2NX:2Oooool4o`00
00Cooooo0_l9jPXJooooo`;o00002_ooool4o`0000;ooooo0_l0001iooooo`006_ooool00ol0003o
ooooooooo`0=ooooo`Go2NX:1oooool;o`WZ2PCooooo0_l0000Hooooo`?o2NX:2_ooool3o`0000;o
oooo0_l00002ooooo`?o2NX:7Oooool00ol0003oooooooooo`04ooooo`Co00000_ooool3o`0007_o
oooo000Jooooo`03o`000?oooooooooo00oooooo2_l9jPXVooooo`?o2NX:2_ooool3o`0000Gooooo
0_l00003o`WZ2R3ooooo00?o0000ooooooooool00ol00002ooooo`Co0000O_ooool001[ooooo00?o
0000ooooooooool02_ooool5o`WZ2Rcooooo1?l9jPX:ooooo`?o00002?ooool2o`000003o`WZ2_oo
oooooooo027ooooo0ol00002ooooo`?o0000POooool001[ooooo00?o0000ooooooooool0=_ooool2
o`0000?o2NX:2oooool3o`0000Wooooo0_l9jPX00ol0003o2NX:ooooo`0Vooooo`;o0000Q?ooool0
01[ooooo00?o0000ooooooooool0;oooool7o`WZ2P;o00002oooool3o`0000Wooooo1?l9jPX00ooo
oooo0000o`00002]ooooo`006_ooool00ol0003oooooooooo`0Qooooo`ko2NX:4?ooool4o`0000Wo
oooo1?l9jPX4ooooo`;o0000[Oooool001[ooooo00?o0000ooooooooool05?ooool=o`WZ2Q_ooooo
0ol00009ooooo`Co2NX:2?ooool2o`000:gooooo000Jooooo`03o`000?oooooooooo00gooooo1ol9
jPXUooooo`?o00002Oooool4o`WZ2P_ooooo0_l0002]ooooo`006_ooool00ol0003oooooooooo`0f
ooooo`?o00001_ooool7o`WZ2Pkooooo0_l0002]ooooo`006_ooool00ol0003oooooooooo`0coooo
o`?o00003?l9jPX00ooooooo0000o`00000?ooooo`;o0000[Oooool001[ooooo00?o0000oooooooo
ool0:Oooool6o`WZ2PCo000000?o2NX:ooooooooool01Oooool3o`WZ2QKooooo0_l0002]ooooo`00
6Oooool00ol0003oooooooooo`0Pooooo`[o2NX:0oooool3o`0000Wooooo0ol9jPXIooooo`;o0000
[Oooool001Wooooo00?o0000ooooooooool05Oooool;o`WZ2P[ooooo0ol00003ooooo`Oo2NX:0_l0
000Looooo`;o0000[Oooool001Wooooo00?o0000ooooooooool04?ooool5o`WZ2Pgooooo1Ol9jPX3
o`0000Ko2NX:1oooool2o`0001cooooo0_l0002]ooooo`006Oooool00ol0003oooooooooo`0Doooo
o`ko2NX:0_ooool3o`0002kooooo0_l0002]ooooo`006Oooool00ol0003oooooooooo`0=ooooo`Oo
2NX:3Oooool3o`00037ooooo0_l0002]ooooo`006Oooool00ol0003oooooooooo`0Mooooo`Co0000
=?ooool00ol0003oooooooooo`2/ooooo`006Oooool00ol0003oooooooooo`0Jooooo`?o0000>?oo
ool00ol0003oooooooooo`2/ooooo`006Oooool00ol0003oooooooooo`0Gooooo`?o0000>oooool0
0ol0003oooooooooo`2/ooooo`006Oooool00ol0003oooooooooo`0Dooooo`?o0000?_ooool00ol0
003oooooooooo`2/ooooo`006Oooool00ol0003oooooooooo`0Aooooo`?o0000@Oooool00ol0003o
ooooooooo`2/ooooo`006Oooool00ol0003oooooooooo`0=ooooo`Co0000A?ooool00ol0003ooooo
ooooo`2/ooooo`006?ooool00ol0003oooooooooo`0;ooooo`?o0000B?ooool00ol0003ooooooooo
o`2/ooooo`006?ooool00ol0003oooooooooo`08ooooo`?o0000Boooool00ol0003oooooooooo`2/
ooooo`006?ooool00ol0003oooooooooo`05ooooo`?o0000C_ooool00ol0003oooooooooo`2/oooo
o`006?ooool00ol0003oooooooooo`02ooooo`?o0000DOooool00ol0003oooooooooo`2/ooooo`00
6?ooool00ol0003oooooo`000002o`0005Cooooo00?o0000ooooooooool0[?ooool001Sooooo0ol0
001Fooooo`03o`000?oooooooooo0:cooooo000Kooooo`?o0000Doooool00ol0003oooooooooo`2/
ooooo`007_ooool3o`00053ooooo00?o0000ooooooooool0[?ooool0027ooooo0ol0001=ooooo`03
o`000?oooooooooo0:cooooo000Tooooo`?o0000B_ooool00ol0003oooooooooo`2/ooooo`009ooo
ool3o`0004Oooooo00?o0000ooooooooool0[?ooool002[ooooo1?l00013ooooo`03o`000?oooooo
oooo0:cooooo000^ooooo`?o0000@?ooool00ol0003oooooooooo`2/ooooo`00<Oooool3o`0003go
oooo00?o0000ooooooooool0[?ooool003Cooooo0ol0000jooooo`03o`000?oooooooooo0:cooooo
000gooooo`?o0000=oooool00ol0003oooooooooo`2/ooooo`00>_ooool4o`0003?ooooo00?o0000
ooooooooool0[?ooool003kooooo0ol0000`ooooo`03o`000?oooooooooo0:cooooo0011ooooo`?o
0000;Oooool00ol0003oooooooooo`2/ooooo`00A?ooool3o`0002[ooooo00?o0000ooooooooool0
[?ooool004Oooooo0ol0000Wooooo`03o`000?oooooooooo0:cooooo001:ooooo`?o00009?ooool0
0ol0003oooooooooo`2/ooooo`00COooool4o`00023ooooo00?o0000ooooooooool0[?ooool0057o
oooo0ol0000Mooooo`03o`000?oooooooooo0:cooooo001Dooooo`?o00006_ooool00ol0003ooooo
ooooo`2/ooooo`00Eoooool3o`0001Oooooo00?o0000ooooooooool0[?ooool005[ooooo0ol0000D
ooooo`03o`000?oooooooooo0:cooooo001Mooooo`Co00004?ooool00ol0003oooooooooo`2/oooo
o`00HOooool3o`0000gooooo00?o0000ooooooooool0[?ooool006Cooooo0ol0000:ooooo`03o`00
0?oooooooooo0:cooooo001Wooooo`?o00001oooool00ol0003oooooooooo`2/ooooo`00J_ooool3
o`0000Cooooo00?o0000ooooooooool0[?ooool006gooooo0ol000000ooooooo0000ooooo`2]oooo
o`00L?ooool2o`000:kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {213.312, 0}} -> {0.0134069, 0.109677, \
0.00343977, 0.00343977}},
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindABCDMatrix[prismgaussiansystem,MatrixForm->True,DecomposeABCD->True,\
NumbericalResults->True]\
\>", "Input",
  CellLabel->"In[85]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.9999999999999998`", "0"},
                    {"0", "1.`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "52.61948213752446`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.9777393004843139`", "0.2221957880002261`"},
                    {\(-0.012533900141421072`\), "1.5508000325105435`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "9.981527662401357`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.0300244934497826`", \(-0.6863912985787266`\)},
                    {\(-0.008457046225124394`\), "0.6447471299591376`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "22.861045090627375`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.7576572398462605`", "3.3142224059044914`"},
                    {"0", "2.004947671462612`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "13.675764045115217`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.3434233144031036`", \(-10.285495048270743`\)},
                    {"0", "0.4900171717588866`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "29.94990327359613`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]},
          {
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.9999999999999998`", "0"},
                    {"0", "0.9999999999999998`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "52.61948213752449`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {\(-0.011855700261249711`\), "1.5190631187965495`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "10.208782297548153`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {\(-0.007864972136386744`\), "0.6583004929987583`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "22.194661618250088`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "1.51906311879655`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "18.050067135754265`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.`", "0"},
                    {"0", "0.6583004929987581`"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]], 
            TagBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "22.293720045273425`"},
                    {"0", "1"}
                    }], "\[NoBreak]", ")"}],
              Function[ BoxForm`e$, 
                MatrixForm[ BoxForm`e$]]]}
          },
        RowSpacings->3,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Center}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDirections -> Row, TableAlignments -> 
          Center]]]], "Output",
  CellLabel->"Out[85]//TableForm=",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.1"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianTrace", "Subsubsection",
  CellTags->{"AOG0.", "4.6.2", "AOG4.", "AOG4.6", "AOG4.6.2"}],

Cell[CellGroupData[{

Cell["GaussianTrace[prismgaussiansystem]", "Input",
  CellLabel->"In[86]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.2"}],

Cell[BoxData[
    \({{BeamSpotSize \[Rule] {5, 5}, BeamDivergence \[Rule] {0.01`, 0.01`}, 
        ComplexBeamParameter \[Rule] {\(\(999.9770710337976`\)\(\
\[InvisibleSpace]\)\) + 
              6.771809703999252`\ \[ImaginaryI], \(\(999.9770710337974`\)\(\
\[InvisibleSpace]\)\) + 6.771809703999248`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.033859048519996264`, 0.033859048519996264`}, 
        WaistDistance \[Rule] {\(-999.9770710337976`\), \(-999.9770710337974`\
\)}, BeamScaleLength \[Rule] {6.771809703999252`, 6.771809703999252`}, 
        BeamCurvature \[Rule] {\(-1000.0229294919518`\), \
\(-1000.0229294919516`\)}, 
        ABCDRotationMatrix \[Rule] {{0.9396926207859084`, 
              0.3420201433256687`, 0}, {\(-0.3420201433256687`\), 
              0.9396926207859084`, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {0, 0, 0}, OpticalLength \[Rule] 0, 
        Intensity \[Rule] 100, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {6.866862729659511`, 
            5.1114661001030255`}, 
        BeamDivergence \[Rule] {0.004900171717588867`, 
            0.006583004929987583`}, 
        ComplexBeamParameter \[Rule] {\(\(2802.6414042581396`\)\(\
\[InvisibleSpace]\)\) + 
              18.56548619388008`\ \[ImaginaryI], \(\(1552.8938561511898`\)\(\
\[InvisibleSpace]\)\) + 10.28680636885384`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.045487035185268865`, 0.03385904851999626`}, 
        WaistDistance \[Rule] {\(-2802.6414042581396`\), \
\(-1552.8938561511898`\)}, 
        BeamScaleLength \[Rule] {18.56548619388008`, 10.286806368853842`}, 
        BeamCurvature \[Rule] {\(-2802.764387268771`\), \
\(-1552.9619988544732`\)}, 
        ABCDMatrix \[Rule] {{{1.3434233144031034`, 29.949903273596128`}, {0, 
                0.4900171717588866`}}, {{1, 22.293720045273425`}, {0, 
                0.6583004929987581`}}}, 
        ABCDRotationMatrix \[Rule] {{0.9999877100409463`, 
              0.004957798610695369`, 0}, {\(-0.004957798610695324`\), 
              0.9999877100409463`, 0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {20.949244216410325`, 7.624901325146749`, 0}, 
        OpticalLength \[Rule] 22.299727120623363`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {5.236234327822737`, 
            5.170876652064364`}, 
        BeamDivergence \[Rule] {0.009824587874946748`, 
            0.010000000000000004`}, 
        ComplexBeamParameter \[Rule] {\(\(1065.9217420448458`\)\(\
\[InvisibleSpace]\)\) + 
              7.015781621770541`\ \[ImaginaryI], \(\(1034.1531591731984`\)\(\
\[InvisibleSpace]\)\) + 6.771809703999248`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.03446358152726054`, 0.03385904851999626`}, 
        WaistDistance \[Rule] {\(-1065.9217420448456`\), \
\(-1034.1531591731984`\)}, 
        BeamScaleLength \[Rule] {7.0157816217705395`, 6.771809703999249`}, 
        BeamCurvature \[Rule] {\(-1065.9679191606908`\), \
\(-1034.1975021278763`\)}, 
        ABCDMatrix \[Rule] {{{1.01785440033577`, 29.39312026696456`}, {0, 
                0.9824587874946744`}}, {{1, 34.17608813940114`}, {0, 1}}}, 
        ABCDRotationMatrix \[Rule] {{0.9463624802424491`, \
\(-0.32310688013312283`\), 0}, {0.32310688013312294`, 0.9463624802424491`, 
              0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {38.999089517578575`, 7.714389922915342`, 0}, 
        OpticalLength \[Rule] 49.72630653939109`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {5.505747401500449`, 
            5.281847631031942`}, 
        BeamDivergence \[Rule] {\(-0.08413133331208746`\), \
\(-0.07650031086507708`\)}, 
        ComplexBeamParameter \[Rule] {\(-130.88457171221813`\) + 
              0.0629815554867743`\ \[ImaginaryI], \(-138.08693762613424`\) + 
              0.07617325706807748`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.0026493611185857686`, 0.002913638922656678`}, 
        WaistDistance \[Rule] {130.88457171221813`, 138.08693762613427`}, 
        BeamScaleLength \[Rule] {0.06298155548677428`, 0.07617325706807747`}, 
        BeamCurvature \[Rule] {130.8846020188943`, 138.08697964578647`}, 
        ABCDMatrix \[Rule] {{{1.0484149631114839`, 
                52.73566845448756`}, {\(-0.008608041714085883`\), 
                0.19491295556852584`}}, {{1, 
                56.37074975765123`}, {\(-0.007864972136386745`\), 
                0.21494611684760156`}}}, 
        ABCDRotationMatrix \[Rule] {{0.97617755747506`, \
\(-0.21697321558668461`\), 0}, {0.21697321558668473`, 0.97617755747506`, 
              0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {60.00328453476761`, 0.5431420518321985`, 0}, 
        OpticalLength \[Rule] 71.92694854155361`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {4.963306050346265`, 
            4.891360185529179`}, 
        BeamDivergence \[Rule] {\(-0.2579623849334914`\), \
\(-0.2321897909722131`\)}, 
        ComplexBeamParameter \[Rule] {\(-38.480849663965515`\) + 
              0.010176348665373477`\ \[ImaginaryI], \(-42.13242923107269`\) + 
              0.01256083481374923`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.0013125575858172465`, 0.0014582488049204665`}, 
        WaistDistance \[Rule] {38.480849663965515`, 42.1324292310727`}, 
        BeamScaleLength \[Rule] {0.010176348665373473`, 
            0.012560834813749238`}, 
        BeamCurvature \[Rule] {38.480852355124185`, 42.132432975802686`}, 
        ABCDMatrix \[Rule] {{{0.9391551061616564`, 
                53.50726464303101`}, {\(-0.025413149495533287`\), \
\(-0.3830976513995334`\)}}, {{0.9197082116833456`, 
                58.56508787025174`}, {\(-0.022851173988275353`\), \
\(-0.36781340893173053`\)}}}, 
        ABCDRotationMatrix \[Rule] {{0.9508100282412034`, \
\(-0.3097745796477851`\), 0}, {0.3097745796477852`, 0.9508100282412033`, 
              0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {69.9688687027828`, \(-1.671890270491252`\), 
            0}, OpticalLength \[Rule] 87.43891181275916`, 
        Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 
          0.532`}, {BeamSpotSize \[Rule] {1.823618148648437`, 
            1.2174941844379465`}, 
        BeamDivergence \[Rule] {0.25796238493349144`, 0.2321897909722125`}, 
        ComplexBeamParameter \[Rule] {\(\(14.138632473558918`\)\(\
\[InvisibleSpace]\)\) + 
              0.010176348665373475`\ \[ImaginaryI], \
\(\(10.48705290645179`\)\(\[InvisibleSpace]\)\) + 
              0.012560834813749302`\ \[ImaginaryI]}, 
        BeamWaist \[Rule] {0.0013125575858172463`, 0.00145824880492047`}, 
        WaistDistance \[Rule] {\(-14.138632473558916`\), \
\(-10.48705290645179`\)}, 
        BeamScaleLength \[Rule] {0.01017634866537347`, 
            0.012560834813749302`}, 
        BeamCurvature \[Rule] {\(-14.13863979803477`\), \
\(-10.487067951152396`\)}, 
        ABCDMatrix \[Rule] {{{\(-0.39807165977679526`\), 
                33.348864618285695`}, {\(-0.025413149495533287`\), \
\(-0.3830976513995334`\)}}, {{\(-0.2827087298141734`\), 
                39.210936769026546`}, {\(-0.022851173988275353`\), \
\(-0.36781340893173053`\)}}}, 
        ABCDRotationMatrix \[Rule] {{0.9508100282412034`, \
\(-0.3097745796477851`\), 0}, {0.3097745796477852`, 0.9508100282412033`, 
              0}, {0, 0, 1}}, 
        ABCDCenterPoint \[Rule] {120.`, \(-17.972068230926894`\), 0}, 
        OpticalLength \[Rule] 140.07257234641642`, Intensity \[Rule] 100.`, 
        WaveLength \[Rule] 0.532`}}\)], "Output",
  CellLabel->"Out[86]=",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.2"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianPlot", "Subsubsection",
  CellTags->{"AOG0.", "4.6.3", "AOG4.", "AOG4.6", "AOG4.6.3"}],

Cell[CellGroupData[{

Cell["GaussianPlot[prismgaussiansystem];", "Input",
  CellLabel->"In[87]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00759676 0 0.0779241 [
[.17574 -0.0125 -6 -9 ]
[.17574 -0.0125 6 0 ]
[.32768 -0.0125 -6 -9 ]
[.32768 -0.0125 6 0 ]
[.47962 -0.0125 -6 -9 ]
[.47962 -0.0125 6 0 ]
[.63155 -0.0125 -6 -9 ]
[.63155 -0.0125 6 0 ]
[.78349 -0.0125 -9 -9 ]
[.78349 -0.0125 9 0 ]
[.93542 -0.0125 -9 -9 ]
[.93542 -0.0125 9 0 ]
[.01131 .07792 -6 -4.5 ]
[.01131 .07792 0 4.5 ]
[.01131 .15585 -6 -4.5 ]
[.01131 .15585 0 4.5 ]
[.01131 .23377 -6 -4.5 ]
[.01131 .23377 0 4.5 ]
[.01131 .3117 -6 -4.5 ]
[.01131 .3117 0 4.5 ]
[.01131 .38962 -6 -4.5 ]
[.01131 .38962 0 4.5 ]
[.01131 .46754 -6 -4.5 ]
[.01131 .46754 0 4.5 ]
[.01131 .54547 -6 -4.5 ]
[.01131 .54547 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17574 0 m
.17574 .00625 L
s
[(20)] .17574 -0.0125 0 1 Mshowa
.32768 0 m
.32768 .00625 L
s
[(40)] .32768 -0.0125 0 1 Mshowa
.47962 0 m
.47962 .00625 L
s
[(60)] .47962 -0.0125 0 1 Mshowa
.63155 0 m
.63155 .00625 L
s
[(80)] .63155 -0.0125 0 1 Mshowa
.78349 0 m
.78349 .00625 L
s
[(100)] .78349 -0.0125 0 1 Mshowa
.93542 0 m
.93542 .00625 L
s
[(120)] .93542 -0.0125 0 1 Mshowa
.125 Mabswid
.06179 0 m
.06179 .00375 L
s
.09978 0 m
.09978 .00375 L
s
.13776 0 m
.13776 .00375 L
s
.21373 0 m
.21373 .00375 L
s
.25171 0 m
.25171 .00375 L
s
.2897 0 m
.2897 .00375 L
s
.36566 0 m
.36566 .00375 L
s
.40365 0 m
.40365 .00375 L
s
.44163 0 m
.44163 .00375 L
s
.5176 0 m
.5176 .00375 L
s
.55558 0 m
.55558 .00375 L
s
.59357 0 m
.59357 .00375 L
s
.66953 0 m
.66953 .00375 L
s
.70752 0 m
.70752 .00375 L
s
.7455 0 m
.7455 .00375 L
s
.82147 0 m
.82147 .00375 L
s
.85945 0 m
.85945 .00375 L
s
.89744 0 m
.89744 .00375 L
s
.9734 0 m
.9734 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07792 m
.03006 .07792 L
s
[(1)] .01131 .07792 1 0 Mshowa
.02381 .15585 m
.03006 .15585 L
s
[(2)] .01131 .15585 1 0 Mshowa
.02381 .23377 m
.03006 .23377 L
s
[(3)] .01131 .23377 1 0 Mshowa
.02381 .3117 m
.03006 .3117 L
s
[(4)] .01131 .3117 1 0 Mshowa
.02381 .38962 m
.03006 .38962 L
s
[(5)] .01131 .38962 1 0 Mshowa
.02381 .46754 m
.03006 .46754 L
s
[(6)] .01131 .46754 1 0 Mshowa
.02381 .54547 m
.03006 .54547 L
s
[(7)] .01131 .54547 1 0 Mshowa
.125 Mabswid
.02381 .01558 m
.02756 .01558 L
s
.02381 .03117 m
.02756 .03117 L
s
.02381 .04675 m
.02756 .04675 L
s
.02381 .06234 m
.02756 .06234 L
s
.02381 .09351 m
.02756 .09351 L
s
.02381 .10909 m
.02756 .10909 L
s
.02381 .12468 m
.02756 .12468 L
s
.02381 .14026 m
.02756 .14026 L
s
.02381 .17143 m
.02756 .17143 L
s
.02381 .18702 m
.02756 .18702 L
s
.02381 .2026 m
.02756 .2026 L
s
.02381 .21819 m
.02756 .21819 L
s
.02381 .24936 m
.02756 .24936 L
s
.02381 .26494 m
.02756 .26494 L
s
.02381 .28053 m
.02756 .28053 L
s
.02381 .29611 m
.02756 .29611 L
s
.02381 .32728 m
.02756 .32728 L
s
.02381 .34287 m
.02756 .34287 L
s
.02381 .35845 m
.02756 .35845 L
s
.02381 .37404 m
.02756 .37404 L
s
.02381 .40521 m
.02756 .40521 L
s
.02381 .42079 m
.02756 .42079 L
s
.02381 .43638 m
.02756 .43638 L
s
.02381 .45196 m
.02756 .45196 L
s
.02381 .48313 m
.02756 .48313 L
s
.02381 .49871 m
.02756 .49871 L
s
.02381 .5143 m
.02756 .5143 L
s
.02381 .52988 m
.02756 .52988 L
s
.02381 .56105 m
.02756 .56105 L
s
.02381 .57664 m
.02756 .57664 L
s
.02381 .59222 m
.02756 .59222 L
s
.02381 .60781 m
.02756 .60781 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .38962 m
.09004 .39302 L
.12451 .39479 L
.14276 .39572 L
.16227 .39672 L
.17173 .39721 L
.18066 .39767 L
.18456 .39786 L
.18868 .39808 L
.19084 .39819 L
.19206 .39825 L
.19321 .5351 L
.19523 .53515 L
.19739 .5352 L
.23011 .53602 L
.2639 .53687 L
.28175 .53732 L
.30078 .5378 L
.31031 .53804 L
.31929 .53826 L
.32322 .53836 L
.32736 .53847 L
.32952 .53852 L
.33075 .40805 L
.3319 .40811 L
.33608 .40832 L
.36885 .40997 L
.43555 .41333 L
.45299 .41421 L
.47196 .41517 L
.48065 .41561 L
.48988 .41607 L
.49367 .41626 L
.49566 .41636 L
.49776 .41647 L
.49888 .41652 L
.5001 .42851 L
.50225 .42759 L
.50646 .42577 L
.54289 .41005 L
.56011 .40262 L
.56767 .39936 L
.57197 .3975 L
.57407 .39659 L
.57599 .39577 L
.57798 .38475 L
.57986 .38225 L
.58402 .37676 L
.59251 .36551 L
.61042 .34182 L
Mistroke
.64293 .29882 L
.70849 .21207 L
.77826 .11977 L
.81054 .07705 L
.84542 .0309 L
.85475 .01856 L
.85984 .01183 L
.86459 .00555 L
.86667 .00279 L
.86865 .00021 L
.86974 .00127 L
.87092 .00283 L
.87299 .00557 L
.8822 .01775 L
.9168 .06353 L
.97619 .1421 L
Mfstroke
0 0 0 r
gsave
.19317 .5787 -78.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33029 .5787 -78.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4989 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57645 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19317 0 m
.19317 .56185 L
s
.33029 0 m
.33029 .56185 L
s
.4989 0 m
.4989 .56185 L
s
.57645 0 m
.57645 .56185 L
s
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[87]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00??ooool5o`0000?ooooo0_l0000Mooooo`?o00000oooool2o`0001cooooo0ol00004oooo
o`;o00007?ooool3o`0000Cooooo0_l0000Hooooo`?o00001?ooool2o`0000Cooooo0_l0000Foooo
o`?o00000_ooool5o`0000?ooooo0_l0000Oooooo`00?Oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0001gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
01kooooo000nooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool5o`00
00;ooooo00Co0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00006?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00007_ooool003oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo01Sooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0000Joooo
o`Co00000oooool01?l0003oooooooooool0000Kooooo`?o00000oooool01?l0003oooooooooool0
000Hooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Fooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo01cooooo000looooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Kooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00006_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0001[ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07?ooool003cooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001cooooo0_l00003oooo
o`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
000Jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Gooooo`;o
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Gooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Nooooo`00?Ooo
ool3o`0000Cooooo0_l0000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`;o00001?oo
ool2o`0001cooooo0ol00004ooooo`;o00006Oooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0001Oooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0000Oooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`005ooooooCo`0000;o2NX:7ol0
000Eooooo`007Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000009ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`04
o`000?l9jP[oooooo`WZ2PGooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`;o00006oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`12ooooo`04
o`WZ2_ooooooooooo`WZ2QSooooo00?o0000ooooooooool06Oooool001gooooo0_l0000Wooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo04;ooooo00Go2NX:ooooooooooooooooo`WZ2P0Gooooo`03o`000?oooooooooo
01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@Oooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo01Cooooo00?o0000ooooooooool06Oooool001gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`10ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool05?ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03oooooo00?o2NX:ooooooooool01_ooool00ol9jP[ooooooooo
o`0Cooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o00009oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0n
ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool04_ooool00ol0003oooooooooo`0I
ooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03kooooo00?o2NX:oooo
ooooool02Oooool00ol9jP[oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo000Mooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0?Oooool00ol9jP[oooooooooo`0;ooooo`03
o`WZ2_oooooooooo013ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0looooo`03o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool0
3oooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0002Oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>ooo
ool00ol9jP[oooooooooo`0>ooooo`03o`WZ2_oooooooooo00oooooo00?o0000ooooooooool06Ooo
ool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0kooooo`03o`WZ2_oooooo
oooo00oooooo00?o2NX:ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo03[ooooo00?o2NX:ooooooooool04Oooool00ol9
jP[oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0>Oooool00ol9jP[oooooooooo`0Cooooo`03o`WZ2_oooooooooo00co
oooo00?o0000ooooooooool06Oooool001gooooo0_l0000Wooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Wooooo
00?o2NX:ooooooooool05?ooool00ol9jP[oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo
000Eooooo`?o00001Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Sooooo00?o
2NX:ooooooooool05Oooool00ol9jP[oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo000F
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0g
ooooo`03o`WZ2_oooooooooo01Oooooo00?o2NX:ooooooooool02_ooool00ol0003oooooooooo`0I
ooooo`005_ooool00ol0003oooooooooo`04ooooo`?o00009_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0foooo
o`03o`WZ2_oooooooooo01Wooooo00?o2NX:ooooooooool02Oooool00ol0003oooooooooo`0Ioooo
o`005_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0=_ooool00ol9jP[oooooooooo`0Jooooo`03o`WZ2_oooooooooo00Sooooo00?o0000oooooooo
ool06Oooool001Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03Gooooo00?o2NX:ooooooooool06oooool00ol9jP[oooooooooo`08ooooo`03o`00
0?oooooooooo01Wooooo000Eooooo`;o00001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo03Cooooo00?o2NX:ooooooooool07Oooool00ol9jP[oooooooooo`07ooooo`03o`000?oo
oooooooo01Wooooo000Fooooo`03o`000?oooooooooo00Cooooo0_l0000Wooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03?ooooo00?o2NX:ooooooooool07oooool00ol9jP[oooooooooo`06ooooo`03o`000?oooooo
oooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool00ol9
jP[oooooooooo`0Pooooo`03o`WZ2_oooooooooo00Gooooo00?o0000ooooooooool06Oooool001go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`WZ2_oooooooooo027o
oooo00?o2NX:ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo037ooooo00?o2NX:ooooooooool08oooool00ol9jP[ooooo
ooooo`04ooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o00009oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0aooooo`03o`WZ2_oooooooooo02Cooooo00?o2NX:ooooooooool00oooool00ol0003ooooooooo
o`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo033ooooo00?o2NX:
ooooooooool09Oooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo000Moooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;oooool00ol9jP[oooooooooo`0Woooo
o`03o`WZ2_oooooooooo00;ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0^ooooo`03o`WZ2_oooooooooo02Wooooo00Go2NX:oooooooo
ooooooooo`00000Kooooo`007Oooool2o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;_ooool00ol9jP[o
ooooooooo`0Zooooo`04o`WZ2_ooooooooooo`0001_ooooo000Mooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0;Oooool00ol9jP[oooooooooo`0[ooooo`04o`WZ2_ooooooooooo`00
01_ooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;?ooool00ol9jP[o
ooooooooo`0]ooooo`03o`WZ2_oooooo000001_ooooo000Mooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0:oooool00ol9jP[oooooooooo`0_ooooo`03o`WZ2_l0003ooooo01[ooooo
000Mooooo`;o00009oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0[ooooo`03o`WZ2_oooooooooo033ooooo00?o
0000ooooooooool06Oooool001Cooooo1Ol00004ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0:_ooool00ol9jP[oooooooooo`0aooooo`03o`000?oooooooooo01Wooooo000Eoooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Y
ooooo`03o`WZ2_oooooooooo03;ooooo00?o0000ooooooooool06Oooool001Kooooo00?o0000oooo
ooooool01?ooool3o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:?ooool00ol9jP[oooooooooo`0coooo
o`03o`000?oooooooooo01Wooooo000Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Wooooo`03o`WZ2_oooooooooo03Cooooo00?o0000oooooooo
ool06Oooool001Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool09oooool00ol9jP[oooooooooo`0dooooo`03o`000?oooooooooo01Wo
oooo000Dooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02Kooooo00?o2NX:ooooooooool0=Oooool00ol0003oooooooooo`0Iooooo`00
5Oooool3o`0000Gooooo0_l0000Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Gooooo00?o2NX:ooooooooool0
=_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02Cooooo00?o2NX:ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`007Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo00?o2NX:ooooooooool0=oooool0
0ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02?ooooo00?o2NX:ooooooooool0>?ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0002Oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool08_ooool00ol9jP[oooooooooo`0iooooo`03o`000?oooooooooo01Wo
oooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08Oooool00ol9jP[ooooo
ooooo`0jooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool08?ooool00ol9jP[oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo000M
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08?ooool00ol9jP[oooooooooo`0k
ooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o00009oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Ooooo
o`03o`WZ2_oooooooooo03cooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Nooooo`03o`WZ2_oooooooooo03gooooo00?o0000oooooooo
ool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`WZ
2_oooooooooo03kooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Mooooo`03o`WZ2_oooooooooo03kooooo00?o0000ooooooooool06Ooo
ool001gooooo0_l0000Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01cooooo00?o2NX:ooooooooool0?oooool0
0ol0003oooooooooo`0Iooooo`005Oooool3o`0000Gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Kooooo`03o`WZ2_oooooooooo043ooooo00?o0000ooooooooool06Oooool001Co
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool06_ooool00ol9jP[oooooooooo`11ooooo`03o`000?oooooooooo01Wooooo000Hooooo`03
o`000?oooooooooo00;ooooo0ol0000Vooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o2NX:oooooooo
ool0@Oooool00ol0003oooooooooo`0Iooooo`005_ooool2o`0000Gooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Iooooo`03o`WZ2_oooooooooo04;ooooo00?o0000ooooooooool0
6Oooool001Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01Sooooo00?o2NX:ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`005?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Gooooo`03o`WZ2_oooooooooo04Cooooo00?o0000ooooooooool06Oooool001Gooooo0ol00005
ooooo`;o00009oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`03o`WZ2_oooooooooo04Cooooo00?o0000
ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Foooo
o`03o`WZ2_oooooooooo04Gooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Eooooo`03o`WZ2_oooooooooo04Kooooo00?o0000oooooooo
ool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`WZ
2_oooooooooo04Oooooo00?o0000ooooooooool06Oooool001gooooo0_l0000Wooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01?ooooo00?o2NX:ooooooooool0B?ooool00ol0003oooooooooo`0Iooooo`007Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o2NX:ooooooooool0B?ooool0
0ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01;ooooo00?o2NX:ooooooooool0BOooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o2NX:ooooooooool0B_ooool00ol0003o
ooooooooo`0Iooooo`007Oooool2o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol9jP[ooooo
ooooo`1;ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol9jP[oooooooooo`1;ooooo`03o`000?oooooooooo01Wooooo000M
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol9jP[oooooooooo`1<
ooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o00009oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>oooo
o`03o`WZ2_oooooooooo04gooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0=ooooo`03o`WZ2_oooooooooo04kooooo00?o0000oooooooo
ool06Oooool001Kooooo0ol00004ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3Oooool00ol9jP[oooooooooo`1>ooooo`03o`000?oooooooooo01Wooooo000Gooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`WZ2_oo
oooooooo04oooooo00?o0000ooooooooool06Oooool001Cooooo1Ol00004ooooo`?o00009_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0;ooooo`03o`WZ2_oooooooooo053ooooo00?o0000ooooooooool06Oooool0
01Cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00[ooooo00?o2NX:ooooooooool0DOooool00ol0003oooooooooo`0Iooooo`005Oooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol9
jP[oooooooooo`1Booooo`03o`000?oooooooooo01Wooooo000Fooooo`;o00001Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o2NX:ooooooooool0D_ooool00ol0003o
ooooooooo`0Iooooo`005oooool00ol0003oooooooooo`03ooooo`;o00009oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`08ooooo`03o`WZ2_oooooooooo05?ooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`WZ2_oooooooooo05Cooooo00?o
0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06
ooooo`03o`WZ2_oooooooooo05Gooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`05ooooo`03o`WZ2_oooooooooo05Kooooo00?o0000oooo
ooooool06Oooool001gooooo0_l0000Wooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o2NX:oooooooo
ool0E_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Cooooo00?o2NX:ooooooooool0Eoooool00ol0003oooooooooo`0Iooooo`007Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o2NX:ooooooooool0F?oo
ool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00?ooooo00?o2NX:ooooooooool0F?ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`00
02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00_ooool00ol9jP[oooooooooo`1Iooooo`03o`000?oooooooooo
01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`WZ2P1Loooo
o`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00Go0000oooooooo
ooooooooo`WZ2P1Looooo`03o`000?oooooooooo01Wooooo000Mooooo`;o00009oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool01?l0003o
ooooooooool9jPYMooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013o
oooo00?o0000ooooool9jPX0G_ooool00ol0003oooooooooo`0Iooooo`005Oooool3o`0000Gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool04?ooool00ol0003o2NX:ooooo`1Nooooo`03o`000?oooooooooo01Wooooo
000Dooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?l9jP[ooooo05kooooo00?o0000ooooooooool06Oooool001Sooooo00?o0000ooooooooool00_oo
ool9o`WZ2R3ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo013ooooo00?o0000o`WZ2_ooool0G_ooool00ol0003oooooooooo`0Iooooo`006?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo4ol9jPX=ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool06Oooool001Cooooo1?l00005ooooo`03o`000?oooooooooo
01Wooooo3Ol9jPX00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool03Oooool3o`WZ2P03o`000?oooooooooo05kooooo00?o0000ooooooooool06Oooool001Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;ooooo`;o2NX:0oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo000Dooooo`Go00001?ooool2o`0002Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo
0_l9jPX5ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?l9jP[o2NX:013o2NX:5_oo
ool00ol0003oooooooooo`07ooooo`;o2NX:1oooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool0
0ol0003o2NX:ooooo`0@oooooaGo2NX:00?oooooo`000?ooool01_ooool2o`WZ2PWooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01kooooo00?o0000o`WZ2_ooool09Oooool00ol9jP[o0000ooooo`03oooo
o`?o2NX:2oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o
00009oooool00ol0003oooooooooo`0Nooooo`03o`000?l9jP[ooooo02Kooooo00?o0000oooooooo
ool00_l9jPX>ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06Oooool001gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?l9jP[ooooo02Kooooo
00?o0000o`WZ2_l9jPX04?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo
000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003o2NX:oooo
o`0Vooooo`03o`000?l9jP[ooooo013ooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`0Iooooo`007Oooool2o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003o2NX:ooooo`0V
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0I
ooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000o`WZ
2_ooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03
o`000?l9jP[ooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7_ooool00ol0003o2NX:ooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0002Oooooo00?o0000ooooooooool07_oo
ool00ol0003o2NX:ooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0Iooooo`005Oooool3o`0000Gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?l9jP[ooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo000Dooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000
o`WZ2_ooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05kooooo00?o0000
ooooooooool06Oooool001Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07_ooool00ol0003o2NX:ooooo`0Vooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Iooooo`005?ooool4o`00
00Gooooo0ol0000Vooooo`03o`000?oooooooooo01kooooo00?o0000o`WZ2_ooool09_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06Oooool001Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01ko
oooo00?o0000o`WZ2_ooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool06Oooool001Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06Oooool001Kooooo0_l0
0005ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`0Iooooo`007Oooool2o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0I
ooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0002Oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o00009oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06Oooool001gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo000Moooo
o`;o00009oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo000Fooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003o2NX:o`WZ2P03o`WZ2Q_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool06Oooool001Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00?ooooo6ol9jPX00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Iooooo`005ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0Iooooo`005oooool00ol0003oooooooooo`03ooooo`?o00009_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo000Hooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
01Wooooo000Dooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool06Oooool001Cooooo1Ol00004ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Iooooo`00
7Oooool2o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Iooooo`007Ooo
ool00ol0003oooooooooo`3oooooo`7ooooo000Mooooo`03o`000?oooooooooo01Oooooo0ol00003
ooooo`?o00000oooool5o`000003ooooool0003o000000;o00000_ooool01Ol0003oooooo`000?oo
oooo000000Cooooo0ol00003ooooo`?o00000oooool5o`000003ooooool0003o000000;o00000_oo
ool01Ol0003oooooo`000?oooooo000001Sooooo1Ol0000>ooooo`Go0000GOooool3o`0001_ooooo
000Mooooo`;o00006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool01ol0003oooooo`000?oooooo0000ooooool000001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool01ol0003o
ooooo`000?oooooo0000ooooool000006Oooool01?l0003oooooooooool0000?ooooo`04o`000?oo
ooooooooo`0005gooooo00Co0000oooooooooooo00006_ooool001gooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool3o`0000;ooooo00Go0000ooooool0003oooooo`000005ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool01Ol0003o
ooooo`000?oooooo000001Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo01Sooooo000Mooooo`03o`000?oooooooooo01Sooooo0ol00003ooooo`;o
00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooool0003oooooo`000005
ooooo`?o00000oooool2o`0000Gooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oo
oooo0000ooooool000006Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo
0_l0000Kooooo`007Oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooo`000?ooool0
0_l000001?oooooo0000o`000?ooool3o`0000Cooooo1?l000001Ooooooo0000o`000?oooooo0000
00Kooooo00Go0000oooooooooooo0000ooooo`02o`000004ooooool0003o0000ooooo`?o00001?oo
ool4o`000005ooooool0003o0000ooooool000006_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool06oooool001gooooo0_l0000Iooooo`04o`000?oo
ooooooooo`0001gooooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo05kooooo00Co0000oooooooooooo00006_ooool001gooooo00?o0000oooooooo
ool05oooool4o`0000[ooooo00?o0000ooooooooool04?ooool4o`0000[ooooo00?o0000oooooooo
ool09?ooool3o`00013ooooo0ol0001Pooooo`?o00006_ooool001gooooo00?o0000ooooooooool0
ooooool1ooooo`007Oooool00ol0003oooooooooo`3oooooo`7ooooo000Mooooo`;o0000ooooool2
ooooo`007Oooool00ol0003oooooooooo`3oooooo`7ooooo000Mooooo`03o`000?oooooooooo0?oo
oooo0Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool008_o
oooo0ol0002Booooo`00S?ooool00ol0003oooooooooo`2Aooooo`00Ioooool4o`0000?ooooo0ol0
0003ooooo`Co000000Koooooo`000?oooooo0000ooooool00008ooooo`?o00000oooool3o`0000?o
oooo0ol00004ooooo`;o00002Oooool3o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000;o
oooo0ol0001Wooooo`00J?ooool01_l0003oooooooooool0003oooooo`0000Gooooo00Co0000oooo
oooooooo00000_ooool01Ol0003oooooo`000?oooooo000000Sooooo00Co0000oooooooooooo0000
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_oo
ool01_l0003oooooooooool0003oooooo`0006[ooooo001Xooooo`05o`000?ooooooooooo`000?oo
ool01Ol00002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000_ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000kooooo00Go
0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooooooo`Go0000I_ooool006Sooooo
0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`08o`000?oooooooooo
o`000?oooooo0000ooooool00009ooooo`;o00000oooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00003?ooool2o`0000Cooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0I?ooool006Sooooo00Co
0000oooooooooooo00000_ooool3o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?ooool0
2?ooool00ol0003oooooooooo`02ooooo`Co00000oooool3o`0000;ooooo1?l00009ooooo`03o`00
0?oooooooooo00;ooooo0ol00003ooooo`Go00000_ooool3o`0006Oooooo001Xooooo`04o`000?oo
ooooooooo`0001[ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`09ooooo`04
o`000?ooooooooooo`0007Sooooo001Wooooo`Co00007?ooool3o`0000kooooo00?o0000oooooooo
ool02_ooool3o`0000?ooooo00?o0000ooooooooool0L_ooool00?oooooo8Oooool00?oooooo8Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-16.0955, -0.636726, \
0.542821, 0.0529192}},
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00759676 0 0.104685 [
[.17574 -0.0125 -6 -9 ]
[.17574 -0.0125 6 0 ]
[.32768 -0.0125 -6 -9 ]
[.32768 -0.0125 6 0 ]
[.47962 -0.0125 -6 -9 ]
[.47962 -0.0125 6 0 ]
[.63155 -0.0125 -6 -9 ]
[.63155 -0.0125 6 0 ]
[.78349 -0.0125 -9 -9 ]
[.78349 -0.0125 9 0 ]
[.93542 -0.0125 -9 -9 ]
[.93542 -0.0125 9 0 ]
[.01131 .10469 -6 -4.5 ]
[.01131 .10469 0 4.5 ]
[.01131 .20937 -6 -4.5 ]
[.01131 .20937 0 4.5 ]
[.01131 .31406 -6 -4.5 ]
[.01131 .31406 0 4.5 ]
[.01131 .41874 -6 -4.5 ]
[.01131 .41874 0 4.5 ]
[.01131 .52343 -6 -4.5 ]
[.01131 .52343 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17574 0 m
.17574 .00625 L
s
[(20)] .17574 -0.0125 0 1 Mshowa
.32768 0 m
.32768 .00625 L
s
[(40)] .32768 -0.0125 0 1 Mshowa
.47962 0 m
.47962 .00625 L
s
[(60)] .47962 -0.0125 0 1 Mshowa
.63155 0 m
.63155 .00625 L
s
[(80)] .63155 -0.0125 0 1 Mshowa
.78349 0 m
.78349 .00625 L
s
[(100)] .78349 -0.0125 0 1 Mshowa
.93542 0 m
.93542 .00625 L
s
[(120)] .93542 -0.0125 0 1 Mshowa
.125 Mabswid
.06179 0 m
.06179 .00375 L
s
.09978 0 m
.09978 .00375 L
s
.13776 0 m
.13776 .00375 L
s
.21373 0 m
.21373 .00375 L
s
.25171 0 m
.25171 .00375 L
s
.2897 0 m
.2897 .00375 L
s
.36566 0 m
.36566 .00375 L
s
.40365 0 m
.40365 .00375 L
s
.44163 0 m
.44163 .00375 L
s
.5176 0 m
.5176 .00375 L
s
.55558 0 m
.55558 .00375 L
s
.59357 0 m
.59357 .00375 L
s
.66953 0 m
.66953 .00375 L
s
.70752 0 m
.70752 .00375 L
s
.7455 0 m
.7455 .00375 L
s
.82147 0 m
.82147 .00375 L
s
.85945 0 m
.85945 .00375 L
s
.89744 0 m
.89744 .00375 L
s
.9734 0 m
.9734 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .10469 m
.03006 .10469 L
s
[(1)] .01131 .10469 1 0 Mshowa
.02381 .20937 m
.03006 .20937 L
s
[(2)] .01131 .20937 1 0 Mshowa
.02381 .31406 m
.03006 .31406 L
s
[(3)] .01131 .31406 1 0 Mshowa
.02381 .41874 m
.03006 .41874 L
s
[(4)] .01131 .41874 1 0 Mshowa
.02381 .52343 m
.03006 .52343 L
s
[(5)] .01131 .52343 1 0 Mshowa
.125 Mabswid
.02381 .02094 m
.02756 .02094 L
s
.02381 .04187 m
.02756 .04187 L
s
.02381 .06281 m
.02756 .06281 L
s
.02381 .08375 m
.02756 .08375 L
s
.02381 .12562 m
.02756 .12562 L
s
.02381 .14656 m
.02756 .14656 L
s
.02381 .1675 m
.02756 .1675 L
s
.02381 .18843 m
.02756 .18843 L
s
.02381 .23031 m
.02756 .23031 L
s
.02381 .25124 m
.02756 .25124 L
s
.02381 .27218 m
.02756 .27218 L
s
.02381 .29312 m
.02756 .29312 L
s
.02381 .33499 m
.02756 .33499 L
s
.02381 .35593 m
.02756 .35593 L
s
.02381 .37687 m
.02756 .37687 L
s
.02381 .3978 m
.02756 .3978 L
s
.02381 .43968 m
.02756 .43968 L
s
.02381 .46061 m
.02756 .46061 L
s
.02381 .48155 m
.02756 .48155 L
s
.02381 .50249 m
.02756 .50249 L
s
.02381 .54436 m
.02756 .54436 L
s
.02381 .5653 m
.02756 .5653 L
s
.02381 .58624 m
.02756 .58624 L
s
.02381 .60717 m
.02756 .60717 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .52343 m
.09004 .52799 L
.16227 .53297 L
.23011 .53677 L
.29535 .53973 L
.36479 .54369 L
.43164 .5483 L
.44915 .5495 L
.46816 .55081 L
.47688 .55141 L
.48611 .55205 L
.494 .55259 L
.49616 .55274 L
.49735 .55282 L
.49849 .5529 L
.50068 .55199 L
.50269 .55093 L
.53703 .53283 L
.55198 .52495 L
.56816 .51642 L
.57256 .5141 L
.57372 .51349 L
.57496 .51284 L
.57721 .51085 L
.57928 .50753 L
.58117 .5045 L
.58553 .49754 L
.60189 .47136 L
.63784 .41385 L
.70615 .30457 L
.77185 .19945 L
.80508 .14628 L
.84177 .0876 L
.85847 .06087 L
.87648 .03206 L
.88477 .01881 L
.88929 .01158 L
.89149 .00806 L
.89349 .00486 L
.89534 .0019 L
.89709 .00092 L
.89893 .00386 L
.90093 .00706 L
.90908 .02009 L
.97619 .12745 L
s
0 0 0 r
gsave
.19317 .5787 -78.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33029 .5787 -78.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4989 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57645 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19317 0 m
.19317 .56185 L
s
.33029 0 m
.33029 .56185 L
s
.4989 0 m
.4989 .56185 L
s
.57645 0 m
.57645 .56185 L
s
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[87]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00??ooool5o`0000?ooooo0_l0000Mooooo`?o00000oooool2o`0001cooooo0ol00004oooo
o`;o00007?ooool3o`0000Cooooo0_l0000Hooooo`?o00001?ooool2o`0000Cooooo0_l0000Foooo
o`?o00000_ooool5o`0000?ooooo0_l0000Oooooo`00?Oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0001gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
01kooooo000nooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool5o`00
00;ooooo00Co0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00006?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00007_ooool003oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo01Sooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0000Joooo
o`Co00000oooool01?l0003oooooooooool0000Kooooo`?o00000oooool01?l0003oooooooooool0
000Hooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Fooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo01cooooo000looooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Kooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00006_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0001[ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07?ooool003cooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001cooooo0_l00003oooo
o`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
000Jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Gooooo`;o
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Gooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Nooooo`00?Ooo
ool3o`0000Cooooo0_l0000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`;o00001?oo
ool2o`0001cooooo0ol00004ooooo`;o00006Oooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0001Oooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0000Oooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`005ooooooJo`000003o`WZ2_l0
003o000001Oo00005Oooool001gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`?o2NX:1oooool00ol0003oooooooooo`06ooooo`;o
00006oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`19ooooo`;o2NX:
00?oooooo`WZ2_ooool04?ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo04Wooooo00Go2NX:ooooooooooooooooo`WZ2P0@ooooo`03o`00
0?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0B?oo
ool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00gooooo00?o0000ooooooooool06Ooo
ool001gooooo0_l0000Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Sooooo00?o2NX:ooooooooool00oooool0
0ol9jP[oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0Aoooool00ol9jP[oooooooooo`05ooooo`03o`WZ2_oooooooooo
00cooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`16ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool02oooool00ol0003o
ooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Kooooo
00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo
000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0AOooool00ol9jP[ooooooooo
o`09ooooo`03o`WZ2_oooooooooo00[ooooo00?o0000ooooooooool06Oooool001gooooo0_l0000W
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo04Gooooo00?o2NX:ooooooooool02Oooool00ol9jP[oooooooooo`0:
ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0A?ooool00ol9jP[oooooooooo`0;ooooo`03o`WZ2_oooooooooo00Wooooo00?o0000oooo
ooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`13ooooo`03
o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`00
7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04?ooooo00?o2NX:ooooooooool0
3Oooool00ol9jP[oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0@_ooool00ol9jP[oooooooooo`0?ooooo`03o`WZ2_oo
oooooooo00Oooooo00?o0000ooooooooool06Oooool001gooooo0_l0000Wooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo04;ooooo00?o2NX:ooooooooool03oooool00ol9jP[oooooooooo`07ooooo`03o`000?oooooo
oooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@Oooool00ol9
jP[oooooooooo`0Aooooo`03o`WZ2_oooooooooo00Kooooo00?o0000ooooooooool06Oooool001go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`11ooooo`03o`WZ2_oooooooooo01;o
oooo00?o2NX:ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo043ooooo00?o2NX:ooooooooool04oooool00ol9jP[ooooo
ooooo`05ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0?oooool00ol9jP[oooooooooo`0Eooooo`03o`WZ2_oooooooooo00Cooooo00?o
0000ooooooooool06Oooool001gooooo0_l0000Wooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03oooooo00?o2NX:
ooooooooool05_ooool00ol9jP[oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo000Moooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?_ooool00ol9jP[oooooooooo`0Goooo
o`03o`WZ2_oooooooooo00?ooooo00?o0000ooooooooool06Oooool001Gooooo0ol00005ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0?_ooool00ol9jP[oooooooooo`0Hooooo`03
o`WZ2_oooooooooo00;ooooo00?o0000ooooooooool06Oooool001Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03gooooo00?o2NX:ooooooooool0
6Oooool00ol9jP[oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo000Fooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0looooo`03o`WZ2_oo
oooooooo01_ooooo00Go2NX:ooooooooooooooooo`00000Kooooo`005_ooool00ol0003ooooooooo
o`04ooooo`?o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0looooo`03o`WZ2_oooooooooo01cooooo00Co
2NX:oooooooooooo00006oooool001Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03_ooooo00?o2NX:ooooooooool07Oooool01?l9jP[ooooooooo
ool0000Kooooo`005Oooool2o`0000Kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0jooooo`03o`WZ2_oooooooooo01oooooo00?o2NX:ooooool000006oooool001Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03[ooooo00?o2NX:
ooooooooool07oooool00ol9jP[oooooo`00000Kooooo`007Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo03Wooooo00?o2NX:ooooooooool08Oooool00ol9jP[o0000ooooo`0Joooo
o`007Oooool2o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0>Oooool00ol9jP[oooooooooo`0Rooooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
>?ooool00ol9jP[oooooooooo`0Sooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0=oooool00ol9jP[oooooooooo`0Tooooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=oooool0
0ol9jP[oooooooooo`0Tooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0=_ooool00ol9jP[oooooooooo`0Uooooo`03o`000?oooooooooo
01Wooooo000Mooooo`;o00009oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0eooooo`03o`WZ2_oooooooooo02Ko
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0eooooo`03o`WZ2_oooooooooo02Kooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`03o`WZ2_oooooooooo02Oooooo00?o
0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0c
ooooo`03o`WZ2_oooooooooo02Sooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0cooooo`03o`WZ2_oooooooooo02Sooooo00?o0000oooo
ooooool06Oooool001gooooo0_l0000Wooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o2NX:oooooooo
ool0:Oooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03;ooooo00?o2NX:ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`007Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo037ooooo00?o2NX:ooooooooool0:_oo
ool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo033ooooo00?o2NX:ooooooooool0:oooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo033ooooo00?o2NX:ooooooooool0:oooool00ol0
003oooooooooo`0Iooooo`007Oooool2o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;oooool00ol9jP[o
ooooooooo`0/ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0;oooool00ol9jP[oooooooooo`0/ooooo`03o`000?oooooooooo01Wooooo
000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;_ooool00ol9jP[ooooooooo
o`0]ooooo`03o`000?oooooooooo01Wooooo000Dooooo`Go00001?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02gooooo00?o2NX:ooooooooool0;_ooool00ol0003oooooooooo`0I
ooooo`005Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0;Oooool00ol9jP[oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo000Foooo
o`03o`000?oooooooooo00Cooooo0ol0000Vooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02cooooo00?o2NX:oooo
ooooool0;oooool00ol0003oooooooooo`0Iooooo`005oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0:oooool00ol9jP[oooooooooo`0`ooooo`03
o`000?oooooooooo01Wooooo000Dooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02_ooooo00?o2NX:ooooooooool0<?ooool00ol0003o
ooooooooo`0Iooooo`005?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Zooooo`03o`WZ2_oooooooooo037ooooo00?o0000oooooooo
ool06Oooool001Gooooo0ol00005ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
:Oooool00ol9jP[oooooooooo`0booooo`03o`000?oooooooooo01Wooooo000Mooooo`;o00009ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Yooooo`03o`WZ2_oooooooooo03;ooooo00?o0000ooooooooool06Ooo
ool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`WZ2_oooooo
oooo03?ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Xooooo`03o`WZ2_oooooooooo03?ooooo00?o0000ooooooooool06Oooool001go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Wooooo`03o`WZ2_oooooooooo03Co
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Vooooo`03o`WZ2_oooooooooo03Gooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`03o`WZ2_oooooooooo03Gooooo00?o
0000ooooooooool06Oooool001gooooo0_l0000Wooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Gooooo00?o2NX:
ooooooooool0=_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02Cooooo00?o2NX:ooooooooool0=oooool00ol0003oooooooooo`0Ioooo
o`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo00?o2NX:oooooooo
ool0=oooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo02?ooooo00?o2NX:ooooooooool0>?ooool00ol0003oooooooooo`0Iooooo`007Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02;ooooo00?o2NX:ooooooooool0>Ooo
ool00ol0003oooooooooo`0Iooooo`007Oooool2o`0002Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08_ooool0
0ol9jP[oooooooooo`0iooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool08Oooool00ol9jP[oooooooooo`0jooooo`03o`000?oooooooooo
01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08Oooool00ol9jP[o
ooooooooo`0jooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool08?ooool00ol9jP[oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo
000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07oooool00ol9jP[ooooooooo
o`0looooo`03o`000?oooooooooo01Wooooo000Mooooo`;o00009oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0O
ooooo`03o`WZ2_oooooooooo03cooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Nooooo`03o`WZ2_oooooooooo03gooooo00?o0000oooo
ooooool06Oooool001Gooooo0ol00005ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool07Oooool00ol9jP[oooooooooo`0nooooo`03o`000?oooooooooo01Wooooo000Dooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01go
oooo00?o2NX:ooooooooool0?_ooool00ol0003oooooooooo`0Iooooo`006?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool00ol9jP[ooooo
ooooo`0oooooo`03o`000?oooooooooo01Wooooo000Fooooo`;o00001Oooool3o`0002Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool06oooool00ol9jP[oooooooooo`10ooooo`03o`000?oooooooooo01Wooooo000H
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0K
ooooo`03o`WZ2_oooooooooo043ooooo00?o0000ooooooooool06Oooool001Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06_ooool0
0ol9jP[oooooooooo`11ooooo`03o`000?oooooooooo01Wooooo000Eooooo`?o00001Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o2NX:ooooooooool0@Oooool00ol0
003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wo
oooo00?o2NX:ooooooooool0@_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0002Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool06?ooool00ol9jP[oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo
000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06?ooool00ol9jP[ooooooooo
o`13ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool05oooool00ol9jP[oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo000Moooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool00ol9jP[oooooooooo`15oooo
o`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool05_ooool00ol9jP[oooooooooo`15ooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o0000
9oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Eooooo`03o`WZ2_oooooooooo04Kooooo00?o0000ooooooooool0
6Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`WZ2_oo
oooooooo04Oooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Dooooo`03o`WZ2_oooooooooo04Oooooo00?o0000ooooooooool06Oooool0
01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`03o`WZ2_oooooooooo
04Sooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Cooooo`03o`WZ2_oooooooooo04Sooooo00?o0000ooooooooool06Oooool001gooooo
0_l0000Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o2NX:ooooooooool0BOooool00ol0003ooooo
ooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o
2NX:ooooooooool0B_ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo017ooooo00?o2NX:ooooooooool0B_ooool00ol0003oooooooooo`0I
ooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o2NX:oooo
ooooool0Boooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00oooooo00?o2NX:ooooooooool0C?ooool00ol0003oooooooooo`0Iooooo`00
7Oooool2o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol9jP[oooooooooo`1<ooooo`03o`00
0?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_oo
ool00ol9jP[oooooooooo`1=ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03_ooool00ol9jP[oooooooooo`1=ooooo`03o`000?oooooo
oooo01Wooooo000Fooooo`?o00001?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00gooooo00?o2NX:ooooooooool0C_ooool00ol0003oooooooooo`0Iooooo`005oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol9jP[o
ooooooooo`1?ooooo`03o`000?oooooooooo01Wooooo000Dooooo`Go00001?ooool3o`0002Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03?ooool00ol9jP[oooooooooo`1?ooooo`03o`000?oooooooooo01Wooooo
000Dooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0;ooooo`03o`WZ2_oooooooooo053ooooo00?o0000ooooooooool06Oooool001Gooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo00?o
2NX:ooooooooool0DOooool00ol0003oooooooooo`0Iooooo`005_ooool2o`0000Gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`WZ2_oooooooooo057ooooo00?o0000
ooooooooool06Oooool001Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Wooooo00?o2NX:ooooooooool0D_ooool00ol0003oooooooooo`0Ioooo
o`007Oooool2o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol9jP[oooooooooo`1Cooooo`03
o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2?ooool00ol9jP[oooooooooo`1Cooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01oooool00ol9jP[oooooooooo`1Dooooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool0
0ol9jP[oooooooooo`1Dooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool00ol9jP[oooooooooo`1Eooooo`03o`000?oooooooooo
01Wooooo000Mooooo`;o00009oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`WZ2_oooooooooo05Ko
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`05ooooo`03o`WZ2_oooooooooo05Kooooo00?o0000ooooooooool06Oooool001gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`WZ2_oooooooooo05Oooooo00?o
0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03
ooooo`03o`WZ2_oooooooooo05Sooooo00?o0000ooooooooool06Oooool001gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`03ooooo`03o`WZ2_oooooooooo05Sooooo00?o0000oooo
ooooool06Oooool001gooooo0_l0000Wooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o2NX:oooooooo
ool0FOooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`05o`00
0?ooooooooooooooool9jPX0G?ooool00ol0003oooooooooo`0Iooooo`007Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0@ooooo`05o`000?ooooooooooooooool9jPX0G?ooool00ol0003oooooooooo`0Iooooo`00
7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0@ooooo`04o`000?ooooooooooo`WZ2Ugooooo00?o0000oooooooo
ool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooo`WZ2P1Nooooo`03o`00
0?oooooooooo01Wooooo000Mooooo`;o00009oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooo`WZ2P1Nooooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000o`WZ2_ooool0G_ooool0
0ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?l9jP[ooooo
05kooooo00?o0000ooooooooool06Oooool001Gooooo0ol00005ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oo
oooo00?o2NX:o`000?ooool0Goooool00ol0003oooooooooo`0Iooooo`005?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool2o`WZ2P03ooooool0003ooooo05oo
oooo00?o0000ooooooooool06Oooool001Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0;ooooo`;o2NX:0oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo
000Hooooo`03o`000?oooooooooo00;ooooo2Ol9jPXPooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o2NX:1Oooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo01Wooooo000Dooooo`Co00001Oooool00ol0003oooooooooo`06
oooooa7o2NX:3oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool02?ooool00ol9jP[oooooooooo`05ooooo`03o`000?oooooooooo05kooooo00?o0000
ooooooooool06Oooool001Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Goooo
o`oo2NX:00?o0000o`WZ2_ooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Kooooo0_l9jPX8ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06Oooool001Co
oooo1Ol00004ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooool9jPX07_l9jPX00ol0003o
2NX:ooooo`0Vooooo`03o`000?oooooooooo00Cooooo0_l9jPX:ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooo2NX:00_o2NX:6oooool01?l0003oooooooooooooool3o`WZ2Pco
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Iooooo`007Oooool2o`0002Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`So2NX:4oooool01?l0003ooooo
o`WZ2_l9jPX?ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06Oooool001gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo
4_l9jPX00ooooooo0000o`WZ2P0Aooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
6Oooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Gooooo00?o2NX:o`000?ooool04Oooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo01Wooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0Iooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool06Oooool001gooooo0_l0003oooooo`;ooooo000Mooooo`03o`00
0?oooooooooo01Oooooo0ol00003ooooo`?o00000oooool5o`000003ooooool0003o000000;o0000
0_ooool01Ol0003oooooo`000?oooooo000000Cooooo0ol00003ooooo`?o00000oooool5o`000003
ooooool0003o000000;o00000_ooool01Ol0003oooooo`000?oooooo000001Sooooo1Ol0000>oooo
o`Go0000GOooool3o`0001_ooooo000Mooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooool0
003oooooo`000?oooooo000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooool0003oooooo`000?oooooo000001Wooooo
00Co0000oooooooooooo00003oooool01?l0003oooooooooool0001Mooooo`04o`000?oooooooooo
o`0001[ooooo000Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`05o`000?oooooo0000
ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool3o`0000;ooooo00Go0000ooooool0003oooooo`00000Iooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Hooooo`007Oooool0
0ol0003oooooooooo`0Hooooo`?o00000oooool2o`0000Gooooo00Go0000ooooooooooooooooo`00
0005ooooo`05o`000?oooooo0000ooooool000001Oooool3o`0000?ooooo0_l00005ooooo`05o`00
0?ooooooooooooooool000001Oooool01Ol0003oooooo`000?oooooo000001Wooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Oooooo`;o00006oooool001gooooo0_l0000Iooooo`05
o`000?ooooooooooo`000?ooool00_l000001?oooooo0000o`000?ooool3o`0000Cooooo1?l00000
1Ooooooo0000o`000?oooooo000000Kooooo00Go0000oooooooooooo0000ooooo`02o`000004oooo
ool0003o0000ooooo`?o00001?ooool4o`000005ooooool0003o0000ooooool000006_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06oooool001go
oooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Mooooo`04o`000?oooooooooo
o`00037ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Nooooo`04o`000?oooooo
ooooo`0001[ooooo000Mooooo`03o`000?oooooooooo01Oooooo1?l0000:ooooo`03o`000?oooooo
oooo013ooooo1?l0000:ooooo`03o`000?oooooooooo02Cooooo0ol0000@ooooo`?o0000H?ooool3
o`0001[ooooo000Mooooo`03o`000?oooooooooo0?oooooo0Oooool001gooooo00?o0000oooooooo
ool0ooooool1ooooo`007Oooool2o`000?oooooo0_ooool001gooooo00?o0000ooooooooool0oooo
ool1ooooo`007Oooool00ol0003oooooooooo`3oooooo`7ooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo002;ooooo`?o0000T_ooool008cooooo00?o0000oooo
ooooool0TOooool006Oooooo1?l00003ooooo`?o00000oooool4o`000006ooooool0003oooooo`00
0?oooooo00002?ooool3o`0000?ooooo0ol00003ooooo`?o00001?ooool2o`0000Wooooo0ol00002
ooooo`Go000000?oooooo`000?l000000ol00002ooooo`?o0000Ioooool006Sooooo00Ko0000oooo
oooooooo0000ooooool00005ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003o
ooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool0001Z
ooooo`00J?ooool01Ol0003oooooooooool0003ooooo00Go00000_ooool3o`0000;ooooo00Go0000
ooooool0003oooooo`00000;ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool00000
0oooool01?l0003oooooooooool0000>ooooo`05o`000?ooooooooooooooool000001Oooool01?l0
003oooooooooooooool5o`0006Kooooo001Xooooo`?o00000_ooool01ol0003ooooooooooooooooo
0000ooooool000000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00002Oooool2o`00
00?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000cooooo
0_l00004ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo06Cooooo001Xooooo`04o`000?ooooooooooo`0000;ooooo0ol00003oooo
o`;o00000oooool2o`000003ooooool0003ooooo00Sooooo00?o0000ooooooooool00_ooool4o`00
00?ooooo0ol00002ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`?o00000oooool5o`00
00;ooooo0ol0001Wooooo`00J?ooool01?l0003oooooooooool0000Jooooo`04o`000?oooooooooo
o`0000kooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0001hooooo`00Ioooool4
o`0001cooooo0ol0000>ooooo`03o`000?oooooooooo00[ooooo0ol00003ooooo`03o`000?oooooo
oooo07;ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-16.0955, -0.473958, \
0.542821, 0.0393913}},
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
GaussianPlot[prismgaussiansystem,RenderedParameters->ComplexBeamParameter];\
\>", "Input",
  CellLabel->"In[88]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00759676 0.0429154 0.000199956 [
[.17574 .03042 -6 -9 ]
[.17574 .03042 6 0 ]
[.32768 .03042 -6 -9 ]
[.32768 .03042 6 0 ]
[.47962 .03042 -6 -9 ]
[.47962 .03042 6 0 ]
[.63155 .03042 -6 -9 ]
[.63155 .03042 6 0 ]
[.78349 .03042 -9 -9 ]
[.78349 .03042 9 0 ]
[.93542 .03042 -9 -9 ]
[.93542 .03042 9 0 ]
[.01131 .14289 -18 -4.5 ]
[.01131 .14289 0 4.5 ]
[.01131 .24287 -24 -4.5 ]
[.01131 .24287 0 4.5 ]
[.01131 .34285 -24 -4.5 ]
[.01131 .34285 0 4.5 ]
[.01131 .44283 -24 -4.5 ]
[.01131 .44283 0 4.5 ]
[.01131 .54281 -24 -4.5 ]
[.01131 .54281 0 4.5 ]
[.5 .63053 -83.0625 0 ]
[.5 .63053 83.0625 12 ]
[.19317 .66214 -17.0625 -6 ]
[.19317 .66214 17.0625 6 ]
[.33029 .66214 -17.0625 -6 ]
[.33029 .66214 17.0625 6 ]
[.4989 .66214 -5 -6 ]
[.4989 .66214 5 6 ]
[.57645 .66214 -5 -6 ]
[.57645 .66214 5 6 ]
[.97619 .66214 -5 -6 ]
[.97619 .66214 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17574 .04292 m
.17574 .04917 L
s
[(20)] .17574 .03042 0 1 Mshowa
.32768 .04292 m
.32768 .04917 L
s
[(40)] .32768 .03042 0 1 Mshowa
.47962 .04292 m
.47962 .04917 L
s
[(60)] .47962 .03042 0 1 Mshowa
.63155 .04292 m
.63155 .04917 L
s
[(80)] .63155 .03042 0 1 Mshowa
.78349 .04292 m
.78349 .04917 L
s
[(100)] .78349 .03042 0 1 Mshowa
.93542 .04292 m
.93542 .04917 L
s
[(120)] .93542 .03042 0 1 Mshowa
.125 Mabswid
.06179 .04292 m
.06179 .04667 L
s
.09978 .04292 m
.09978 .04667 L
s
.13776 .04292 m
.13776 .04667 L
s
.21373 .04292 m
.21373 .04667 L
s
.25171 .04292 m
.25171 .04667 L
s
.2897 .04292 m
.2897 .04667 L
s
.36566 .04292 m
.36566 .04667 L
s
.40365 .04292 m
.40365 .04667 L
s
.44163 .04292 m
.44163 .04667 L
s
.5176 .04292 m
.5176 .04667 L
s
.55558 .04292 m
.55558 .04667 L
s
.59357 .04292 m
.59357 .04667 L
s
.66953 .04292 m
.66953 .04667 L
s
.70752 .04292 m
.70752 .04667 L
s
.7455 .04292 m
.7455 .04667 L
s
.82147 .04292 m
.82147 .04667 L
s
.85945 .04292 m
.85945 .04667 L
s
.89744 .04292 m
.89744 .04667 L
s
.9734 .04292 m
.9734 .04667 L
s
.25 Mabswid
0 .04292 m
1 .04292 L
s
.02381 .14289 m
.03006 .14289 L
s
[(500)] .01131 .14289 1 0 Mshowa
.02381 .24287 m
.03006 .24287 L
s
[(1000)] .01131 .24287 1 0 Mshowa
.02381 .34285 m
.03006 .34285 L
s
[(1500)] .01131 .34285 1 0 Mshowa
.02381 .44283 m
.03006 .44283 L
s
[(2000)] .01131 .44283 1 0 Mshowa
.02381 .54281 m
.03006 .54281 L
s
[(2500)] .01131 .54281 1 0 Mshowa
.125 Mabswid
.02381 .06291 m
.02756 .06291 L
s
.02381 .08291 m
.02756 .08291 L
s
.02381 .1029 m
.02756 .1029 L
s
.02381 .1229 m
.02756 .1229 L
s
.02381 .16289 m
.02756 .16289 L
s
.02381 .18288 m
.02756 .18288 L
s
.02381 .20288 m
.02756 .20288 L
s
.02381 .22288 m
.02756 .22288 L
s
.02381 .26287 m
.02756 .26287 L
s
.02381 .28286 m
.02756 .28286 L
s
.02381 .30286 m
.02756 .30286 L
s
.02381 .32285 m
.02756 .32285 L
s
.02381 .36284 m
.02756 .36284 L
s
.02381 .38284 m
.02756 .38284 L
s
.02381 .40284 m
.02756 .40284 L
s
.02381 .42283 m
.02756 .42283 L
s
.02381 .46282 m
.02756 .46282 L
s
.02381 .48282 m
.02756 .48282 L
s
.02381 .50281 m
.02756 .50281 L
s
.02381 .52281 m
.02756 .52281 L
s
.02381 .02292 m
.02756 .02292 L
s
.02381 .00292 m
.02756 .00292 L
s
.02381 .5628 m
.02756 .5628 L
s
.02381 .5828 m
.02756 .5828 L
s
.02381 .60279 m
.02756 .60279 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -144.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Real) show
93.000 13.000 moveto
(Complex) show
141.000 13.000 moveto
(Beam) show
171.125 13.000 moveto
(Parameter) show
225.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .24287 m
.09004 .24112 L
.12451 .24022 L
.14276 .23974 L
.16227 .23922 L
.17173 .23897 L
.18066 .23874 L
.18456 .23864 L
.18868 .23853 L
.19084 .23847 L
.19206 .23844 L
.19321 .60332 L
.19523 .60327 L
.19739 .60321 L
.23011 .60235 L
.2639 .60146 L
.28175 .60099 L
.30078 .60049 L
.31031 .60024 L
.31929 .6 L
.32322 .5999 L
.32736 .59979 L
.32952 .59973 L
.33075 .25604 L
.3319 .25601 L
.33608 .2559 L
.36885 .25504 L
.43555 .25328 L
.45299 .25282 L
.47196 .25232 L
.48065 .2521 L
.48988 .25185 L
.49367 .25175 L
.49566 .2517 L
.49776 .25164 L
.49888 .25162 L
.5001 .01671 L
.50225 .01666 L
.50646 .01655 L
.54289 .01559 L
.56011 .01513 L
.56767 .01493 L
.57197 .01482 L
.57407 .01477 L
.57599 .01472 L
.57798 .03518 L
.57986 .03513 L
.58402 .03502 L
.59251 .0348 L
.61042 .03433 L
Mistroke
.64293 .03347 L
.70849 .03175 L
.77826 .02991 L
.84542 .02814 L
.9168 .02626 L
.97619 .0247 L
Mfstroke
0 0 0 r
gsave
.19317 .66214 -78.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33029 .66214 -78.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4989 .66214 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57645 .66214 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .66214 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19317 .01544 m
0 0 rlineto s
.19317 .01544 m
.19317 .61803 L
s
.33029 .01544 m
0 0 rlineto s
.33029 .01544 m
.33029 .61803 L
s
.4989 .01544 m
0 0 rlineto s
.4989 .01544 m
.4989 .61803 L
s
.57645 .01544 m
0 0 rlineto s
.57645 .01544 m
.57645 .61803 L
s
.97619 .01544 m
0 0 rlineto s
.97619 .01544 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[88]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`007oooool00ol0003oooooooooo`0Nooooo`Go00000oooool2o`0001oooooo0ol00003oooo
o`;o00007_ooool3o`0000Cooooo0_l0000Nooooo`?o00001?ooool2o`0001_ooooo0ol00004oooo
o`;o00001?ooool2o`0001Sooooo0ol00002ooooo`Go00000oooool2o`00013ooooo000Oooooo`;o
00008?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001oooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01[ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0001cooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000oooooo000Oooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Looooo`Go00000_ooool01?l0
003oooooooooool0000Looooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool0000Looooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Koooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000?ooooo`007oooool00ol0003oooooooooo`0Qooooo`05o`000?ooooooooooooooool00000
0_ooool2o`0001_ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0000Loooo
o`Co00000oooool01_l0003oooooooooool0003oooooo`0001;ooooo00?o0000ooooooooool01_oo
ool3o`0000?ooooo00Co0000oooooooooooo00006oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000_ooooo000O
ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00;o00007?ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0001cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02o`0001?o2NX:00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00006oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
oooooooooooooooo000000_ooooo000Oooooo`03o`000?oooooooooo01kooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00;o00007Oooool2o`0000?ooooo00Co0000oooo
oooooooo00007Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o000000?o2NX:
ooooooooool04?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0000Jooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0001Oooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Wooooo000Oooooo`;o00008?ooool3
o`0000Cooooo0_l000000ooooooo0000ooooo`0Mooooo`04o`000?ooooooooooooooo`?o00007ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`WZ2P0Booooo`03o`000?oooooooooo00Kooooo0ol0
0004ooooo`;o00007?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0001;ooooo6Ol9
jPX00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0:?ooool00ol0003o2NX:ooooo`0Aooooo`03o`000?l9jP[o
oooo02Sooooo8ol9jPXIooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[ooooo
017ooooo00?o0000o`WZ2_ooool02_oooolNo`WZ2Scooooo00?o0000ooooooooool02Oooool001oo
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02So
oooo00?o0000o`WZ2_ooool04Oooool00ol0003o2NX:o`WZ2P0:o`WZ2U[ooooo00?o0000oooooooo
ool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo00Wooooo000Ioooooh7o000000?o2NX:o`000?l00000O_l00005ooooo`007oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2
o`0000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003o2NX:ooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo0_l0000;ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0:?ooool00ol0003o2NX:ooooo`0Aooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool2o`0002[ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003o2NX:ooooo`0A
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ
2_ooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03
o`000?l9jP[ooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`00
7oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
:?ooool00ol0003o2NX:ooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
2Oooool001oooooo0_l0000Zooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?oo
ool00ol0003o2NX:ooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Ooo
ool001oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0:?ooool00ol0003o2NX:ooooo`0Aooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`;o0000:_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003o2NX:ooooo`0Aoooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ2_oo
ool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?l9jP[ooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007ooo
ool2o`0002[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?l9
jP[ooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool0
0ol0003o2NX:ooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool0
01oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
00Wooooo000;ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[ooooo017o
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`002_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09
ooooo`003_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool3o`0002Wooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`09ooooo`003_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool02Oooool000[ooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000:ooooo`Go00000oooool2o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool02Oooool001oooooo0_l0000Zooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`;o0000:_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oo
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wo
oooo000Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`09ooooo`007oooool2o`0002[ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo0_l0000Zooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`001Oooool3o`0000Co
oooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool04ooooolFo`WZ2P03o`000?oooooooooo023ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oooolFo`WZ2QKooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`Wo2NX:00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo0005
ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023o
oooo00?o0000o`WZ2_l9jPX07ol9jPX9ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`03ooooo`;o0000
1?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`09ooooo`007oooool2o`0002[ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo0_l0
000Zooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Ooooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09oooo
o`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo00Wooooo000Oooooo`;o0000:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo0_l0000Z
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo0005ooooo`?o
00000oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool000Kooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`001_ooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`?o0000:Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo00Wooooo0006ooooo`04o`000?ooooooooooooooo`Co00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo0005ooooo`;o00000oooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool0
00Kooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Ooooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09oooo
o`007oooool2o`0002[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`00
7oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
2Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool02Oooool001oooooo0_l0000Zooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`;o
0000:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Ooo
ool001oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`09ooooo`007oooool2o`0002[ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo00Wooooo0004ooooo`Go00000oooool2o`0000Cooooo0_l00004
ooooo`;o00001Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool02Oooool000Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool000Kooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool3o`0002Wooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`09ooooo`001oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo
0004ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool000Cooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`09ooooo`001Oooool3o`0000Cooooo0_l00004ooooo`;o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo00Wooooo000Oooooo`;o0000:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo0_l0000Z
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`00
7oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
2Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00Wooooo000Oooooo`;o0000:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool2o`0002[ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool000Cooooo1Ol00002ooooo`?o
00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`09ooooo`001Oooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00Wooooo0006ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo0007ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo0ol0000Yooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool02Oooool000Cooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000?ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`001?ooool01ol0003ooooooooooooo
oooo0000ooooool000001_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
00Wooooo0005ooooo`?o00000_ooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo
000Oooooo`;o0000:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000O
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09
ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`09ooooo`007oooool2o`0002[ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`09ooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`007oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo0_l0
000Zooooo`03o`000?l9jP[o2NX:023o2NX:00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool001oooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo000Ooooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09oooo
o`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool02Oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo00Wooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo001hooooo`?o0000YOooool007Wooooo00?o0000ooooooooool0Y?ooool004Sooooo0ol00002
ooooo`03o`000?oooooo000000;o00000oooool4o`000003ooooool0003o000000?o00002Oooool2
o`0000?ooooo0ol00002ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000;ooooo1Ol0
0002ooooo`?o00000_ooool2o`000003ooooool0003o000000Oooooo1?l00003ooooo`?o00000ooo
ool4o`000006ooooool0003oooooo`000?oooooo00002?ooool3o`0000Cooooo1?l000001?oooooo
0000o`000?l00004ooooo`Co000000Koooooo`000?oooooo0000ooooool00002ooooo`?o00001?oo
ool2o`0000?ooooo0ol00002ooooo`?o0000>?ooool004Wooooo00Ko0000oooooooooooo0000oooo
ool00005ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ool000002Oooool01_l0003oooooooooool0003oooooo`0000Gooooo00Co0000oooooooooooo0000
0_ooool01Ol0003oooooo`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1ol0003oooooo`000?oooooo0000ooooool000001_ooool01_l0003oooooooooool0003oooooo`00
00Kooooo00?o0000ooooooooool0=oooool003cooooo0ol00003ooooo`?o00000oooool5o`000003
ooooool0003o000000?o000000?oooooo`000?l000000ol00003ooooo`03o`000?oooooooooo00?o
00000oooool3o`0000?ooooo2_l000001_oooooo0000o`000?oooooo0000ooooo`;o00000oooool0
1?l0003oooooooooooooool5o`0000?ooooo00?o0000ooooooooool01oooool5o`000003ooooool0
003o000000?o00000_ooool3o`0000;ooooo00?o0000ooooool000001?l00007ooooo`03o`000?oo
oooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`06o`000?oo
oooo0000ooooool0003ooooo1Ol00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`03
o`000?oooooooooo02Wooooo0ol0000;ooooo`00?Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo0ol00002ooooo`08o`000?ooooooooooooooool0003oooooo`000?ooool3
o`0000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo0_l0
0002ooooo`04o`000?oooooo0000ooooo`Co000000?oooooo`000?ooool00_l00003ooooo`05o`00
0?ooooooooooooooool000000oooool01_l0003oooooooooool0003oooooo`0000Wooooo1?l00000
0ooooooo0000ooooo`02ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooo0000oooo
o`03o`000003ooooool0003ooooo00Kooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo
0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000?ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000;ooooo
0_l0000Zooooo`04o`000?ooooooooooo`0000[ooooo000mooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool2o`000004ooooool0003oooooooooo`?o00000_ooool3o`000003
ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
00Cooooo0ol00002ooooo`Co000000?oooooo`000?l000000ol00004ooooo`03o`000?oooooooooo
00;ooooo0ol00002ooooo`;o000000?oooooo`000?l000002?ooool01?l0003oooooooooool00002
ooooo`?o00000oooool2o`0000?ooooo0_l000000ooooooo0000ooooo`09ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0
00000ooooooo0000ooooo`02ooooo`?o00000_ooool4o`0000?ooooo0ol00002ooooo`;o000000?o
ooooo`000?l00000:oooool00ol0003oooooooooo`08ooooo`00?Oooool3o`0000?ooooo0_l00004
ooooo`;o000000Coooooo`000?oooooo00001Oooool01Ol0003oooooo`000?oooooo000000?ooooo
00Co0000oooooooooooooooo0ol00003ooooo`;o00000_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooool0003oooooo`000004ooooo`03o`000?oooooo
oooo01Cooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`08ooooo`04o`000?oo
ooooooooo`00023ooooo00?o0000ooooooooool0=_ooool2o`0000_ooooo000mooooo`05o`000?oo
ooooooooo`000?ooool00_l000001?oooooo0000o`000?ooool4o`0000?ooooo1?l000001Ooooooo
0000o`000?oooooo000000;ooooo0ol00003ooooo`05o`000?ooooooooooo`000?ooool00_l00000
0ooooooo0000o`000004o`0000Cooooo1?l000001Ooooooo0000o`000?oooooo000000?ooooo0ol0
000Eooooo`Co00004Oooool00ol0003oooooooooo`07ooooo`Co00008Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00_ooooo000mooooo`04o`000?ooooooooooo`0001oooooo00Co
0000oooooooooooo0000<oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo
00Co0000oooooooooooo00002_ooool003cooooo1?l0000:ooooo`03o`000?oooooooooo01;ooooo
1?l0000:ooooo`03o`000?oooooooooo02Kooooo0ol0000Aooooo`?o0000I_ooool3o`0000[ooooo
003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-16.4238, -238.092, \
0.513515, 19.5095}},
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00759676 0.0143923 0.0317216 [
[.17574 .00189 -6 -9 ]
[.17574 .00189 6 0 ]
[.32768 .00189 -6 -9 ]
[.32768 .00189 6 0 ]
[.47962 .00189 -6 -9 ]
[.47962 .00189 6 0 ]
[.63155 .00189 -6 -9 ]
[.63155 .00189 6 0 ]
[.78349 .00189 -9 -9 ]
[.78349 .00189 9 0 ]
[.93542 .00189 -9 -9 ]
[.93542 .00189 9 0 ]
[.01131 .0937 -18 -4.5 ]
[.01131 .0937 0 4.5 ]
[.01131 .173 -6 -4.5 ]
[.01131 .173 0 4.5 ]
[.01131 .2523 -18 -4.5 ]
[.01131 .2523 0 4.5 ]
[.01131 .33161 -12 -4.5 ]
[.01131 .33161 0 4.5 ]
[.01131 .41091 -24 -4.5 ]
[.01131 .41091 0 4.5 ]
[.01131 .49022 -12 -4.5 ]
[.01131 .49022 0 4.5 ]
[.01131 .56952 -24 -4.5 ]
[.01131 .56952 0 4.5 ]
[.5 .63053 -98.0625 0 ]
[.5 .63053 98.0625 12 ]
[.19317 .66368 -17.0625 -6 ]
[.19317 .66368 17.0625 6 ]
[.33029 .66368 -17.0625 -6 ]
[.33029 .66368 17.0625 6 ]
[.4989 .66368 -5 -6 ]
[.4989 .66368 5 6 ]
[.57645 .66368 -5 -6 ]
[.57645 .66368 5 6 ]
[.97619 .66368 -5 -6 ]
[.97619 .66368 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17574 .01439 m
.17574 .02064 L
s
[(20)] .17574 .00189 0 1 Mshowa
.32768 .01439 m
.32768 .02064 L
s
[(40)] .32768 .00189 0 1 Mshowa
.47962 .01439 m
.47962 .02064 L
s
[(60)] .47962 .00189 0 1 Mshowa
.63155 .01439 m
.63155 .02064 L
s
[(80)] .63155 .00189 0 1 Mshowa
.78349 .01439 m
.78349 .02064 L
s
[(100)] .78349 .00189 0 1 Mshowa
.93542 .01439 m
.93542 .02064 L
s
[(120)] .93542 .00189 0 1 Mshowa
.125 Mabswid
.06179 .01439 m
.06179 .01814 L
s
.09978 .01439 m
.09978 .01814 L
s
.13776 .01439 m
.13776 .01814 L
s
.21373 .01439 m
.21373 .01814 L
s
.25171 .01439 m
.25171 .01814 L
s
.2897 .01439 m
.2897 .01814 L
s
.36566 .01439 m
.36566 .01814 L
s
.40365 .01439 m
.40365 .01814 L
s
.44163 .01439 m
.44163 .01814 L
s
.5176 .01439 m
.5176 .01814 L
s
.55558 .01439 m
.55558 .01814 L
s
.59357 .01439 m
.59357 .01814 L
s
.66953 .01439 m
.66953 .01814 L
s
.70752 .01439 m
.70752 .01814 L
s
.7455 .01439 m
.7455 .01814 L
s
.82147 .01439 m
.82147 .01814 L
s
.85945 .01439 m
.85945 .01814 L
s
.89744 .01439 m
.89744 .01814 L
s
.9734 .01439 m
.9734 .01814 L
s
.25 Mabswid
0 .01439 m
1 .01439 L
s
.02381 .0937 m
.03006 .0937 L
s
[(2.5)] .01131 .0937 1 0 Mshowa
.02381 .173 m
.03006 .173 L
s
[(5)] .01131 .173 1 0 Mshowa
.02381 .2523 m
.03006 .2523 L
s
[(7.5)] .01131 .2523 1 0 Mshowa
.02381 .33161 m
.03006 .33161 L
s
[(10)] .01131 .33161 1 0 Mshowa
.02381 .41091 m
.03006 .41091 L
s
[(12.5)] .01131 .41091 1 0 Mshowa
.02381 .49022 m
.03006 .49022 L
s
[(15)] .01131 .49022 1 0 Mshowa
.02381 .56952 m
.03006 .56952 L
s
[(17.5)] .01131 .56952 1 0 Mshowa
.125 Mabswid
.02381 .03025 m
.02756 .03025 L
s
.02381 .04611 m
.02756 .04611 L
s
.02381 .06197 m
.02756 .06197 L
s
.02381 .07784 m
.02756 .07784 L
s
.02381 .10956 m
.02756 .10956 L
s
.02381 .12542 m
.02756 .12542 L
s
.02381 .14128 m
.02756 .14128 L
s
.02381 .15714 m
.02756 .15714 L
s
.02381 .18886 m
.02756 .18886 L
s
.02381 .20472 m
.02756 .20472 L
s
.02381 .22058 m
.02756 .22058 L
s
.02381 .23644 m
.02756 .23644 L
s
.02381 .26816 m
.02756 .26816 L
s
.02381 .28403 m
.02756 .28403 L
s
.02381 .29989 m
.02756 .29989 L
s
.02381 .31575 m
.02756 .31575 L
s
.02381 .34747 m
.02756 .34747 L
s
.02381 .36333 m
.02756 .36333 L
s
.02381 .37919 m
.02756 .37919 L
s
.02381 .39505 m
.02756 .39505 L
s
.02381 .42677 m
.02756 .42677 L
s
.02381 .44263 m
.02756 .44263 L
s
.02381 .45849 m
.02756 .45849 L
s
.02381 .47436 m
.02756 .47436 L
s
.02381 .50608 m
.02756 .50608 L
s
.02381 .52194 m
.02756 .52194 L
s
.02381 .5378 m
.02756 .5378 L
s
.02381 .55366 m
.02756 .55366 L
s
.02381 .58538 m
.02756 .58538 L
s
.02381 .60124 m
.02756 .60124 L
s
.02381 .6171 m
.02756 .6171 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -159.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Imaginary) show
123.000 13.000 moveto
(Complex) show
171.000 13.000 moveto
(Beam) show
201.125 13.000 moveto
(Parameter) show
255.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .2292 m
.09004 .2292 L
.12451 .2292 L
.14276 .2292 L
.16227 .2292 L
.17173 .2292 L
.18066 .2292 L
.18456 .2292 L
.18868 .2292 L
.19084 .2292 L
.19206 .2292 L
.19321 .60332 L
.19523 .60332 L
.19739 .60332 L
.23011 .60332 L
.2639 .60332 L
.28175 .60332 L
.30078 .60332 L
.31031 .60332 L
.31929 .60332 L
.32322 .60332 L
.32736 .60332 L
.32952 .60332 L
.33075 .23694 L
.3319 .23694 L
.33608 .23694 L
.36885 .23694 L
.43555 .23694 L
.45299 .23694 L
.47196 .23694 L
.48065 .23694 L
.48988 .23694 L
.49367 .23694 L
.49566 .23694 L
.49776 .23694 L
.49888 .23694 L
.5001 .01639 L
.50225 .01639 L
.50646 .01639 L
.54289 .01639 L
.56011 .01639 L
.56767 .01639 L
.57197 .01639 L
.57407 .01639 L
.57599 .01639 L
.57798 .01472 L
.57986 .01472 L
.58402 .01472 L
.59251 .01472 L
.61042 .01472 L
Mistroke
.64293 .01472 L
.70849 .01472 L
.77826 .01472 L
.84542 .01472 L
.9168 .01472 L
.97619 .01472 L
Mfstroke
0 0 0 r
gsave
.19317 .66368 -78.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33029 .66368 -78.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4989 .66368 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57645 .66368 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .66368 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19317 .01439 m
0 0 rlineto s
.19317 .01439 m
.19317 .61803 L
s
.33029 .01439 m
0 0 rlineto s
.33029 .01439 m
.33029 .61803 L
s
.4989 .01439 m
0 0 rlineto s
.4989 .01439 m
.4989 .61803 L
s
.57645 .01439 m
0 0 rlineto s
.57645 .01439 m
.57645 .61803 L
s
.97619 .01439 m
0 0 rlineto s
.97619 .01439 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[88]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00A?ooool5o`0000?ooooo0_l0000Mooooo`?o00000oooool2o`0001gooooo0ol00004oooo
o`;o00007?ooool3o`0000Cooooo0_l0000Iooooo`?o00001?ooool2o`0000Cooooo0_l0000Foooo
o`?o00000_ooool5o`0000?ooooo0_l0000Eooooo`00AOooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0001gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo01Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
01Cooooo0016ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool5o`00
00;ooooo00Co0000oooooooooooo00006oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00006Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00005?ooool004Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo01Sooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0000Koooo
o`Co00000oooool01?l0003oooooooooool0000Kooooo`?o00000oooool01?l0003oooooooooool0
000Iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Fooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo01;ooooo0014ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Kooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00006ooo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0001[ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool04_ooool004Cooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001cooooo0_l00003oooo
o`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
000Jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Hooooo`;o
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Gooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Dooooo`00AOoo
ool3o`0000Cooooo0_l0000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Nooooo`;o00001?oo
ool2o`0001cooooo0ol00004ooooo`;o00006_ooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0001Oooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0000Eooooo`009Oooool0
0ol0003oooooooooo`3hooooo`009Oooool00ol0003oooooooooo`3hooooo`009Oooool00ol0003o
ooooooooo`3hooooo`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05kooooo
00?o0000ooooooooool03oooool001ooooooNol0000Bo`WZ2P03o`000?l9jP[o2NX:05oo2NX:1ol0
000;ooooo`009Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool2o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00Ko0000ooooooooooooooooo`000?l9jPX3ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo0_l0000Aooooo`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`;o0000:?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?l9jP[ooooo013o
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`009Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:
ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo0_l0
000Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:oooo
o`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000
o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Voooo
o`03o`000?l9jP[ooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?oooo
o`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool03oooool002Gooooo0_l0000Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0
3oooool002Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo00oooooo000Uooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?l9jP[ooooo013ooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`0?ooooo`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool03oooool002Gooooo0_l0000Xooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool03oooool002Gooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo00oooooo000@ooooo`Go00000oooool00ol0003ooooooooo
o`02ooooo`?o00001Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool03oooool0017ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo00oooooo000Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_oo
ool3o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?l9
jP[ooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`004oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000@ooooo`05o`000?oooooooooo
ooooool000001oooool4o`0000Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo00oooooo000@ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?l9jP[ooooo013ooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`0?ooooo`004Oooool3o`0000Sooooo1Ol00004ooooo`;o0000:?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?l9jP[ooooo013o
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`009Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:
ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000U
ooooo`;o0000:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000
o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?oooo
o`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool03oooool002Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo00oooooo000Uooooo`;o0000:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo00oooooo000Uooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`0?ooooo`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool03oooool002Gooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`;o0000:?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo00oooooo000Mooooo`?o00001Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool001cooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`0?ooooo`008?ooool00ol0003oooooooooo`02ooooo`?o00009oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Pooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
00oooooo000Looooo`Co00001Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool03oooool001cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool001cooooo1Ol0
0004ooooo`;o0000:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000U
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?
ooooo`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool03oooool002Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03
o`000?oooooooooo00oooooo000Uooooo`;o0000:?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo00oooooo000Uooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`0?ooooo`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool03oooool002Gooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`;o0000:?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`009OoooolZo`WZ2P03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo00?o0000ooooooooool09_ooool0
0ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`;o00009oooool00ol9
jP[o0000ooooo`0Oooooo`03o`000?l9jP[o2NX:02Ko2NX:00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool09_ooool00ol9jP[o
0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Booooo`03o`000?oooooooooo00Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Kooooo00?o2NX:o`000?oo
ool07oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0Goooool00ol0003oooooooooo`0?ooooo`004oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool09_ooool00ol9jP[o0000ooooo`0Oooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo00oooooo000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_oo
ool3o`0002Kooooo00?o2NX:o`000?ooool07oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`005?ooool0
0ol0003oooooooooo`05ooooo`Co00001Oooool00ol0003oooooooooo`0Vooooo`03o`WZ2_l0003o
oooo01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool03oooool0013ooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool00ol9jP[o0000ooooo`0O
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo00oooooo000@ooooo`Go00001oooool5o`0000Cooooo00?o0000oooo
ooooool09_ooool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`;o
00009oooool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`03o`00
0?oooooooooo02Kooooo00?o2NX:o`000?ooool07oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`009Ooo
ool00ol0003oooooooooo`0Vooooo`03o`WZ2_l0003ooooo01oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03ooo
ool002Gooooo00?o0000ooooooooool09_ooool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo00oooooo000Uooooo`;o00009oooool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
00oooooo000Uooooo`03o`000?oooooooooo02Kooooo00?o2NX:o`000?ooool07oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`0?ooooo`009Oooool00ol0003oooooooooo`0Vooooo`03o`WZ2_l0003ooooo01oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool03oooool002Gooooo0_l0000Wooooo`03o`WZ2_l0003ooooo01oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool03oooool002Gooooo00?o0000ooooooooool09_ooool00ol9jP[o0000ooooo`0O
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo00oooooo000Uooooo`03o`000?oooooooooo02Kooooo00?o2NX:o`00
0?ooool07oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0?ooooo`009Oooool00ol0003oooooooooo`0Vooooo`03
o`WZ2_l0003ooooo01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo0_l0000Wooooo`03o`WZ
2_l0003ooooo01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo00?o0000ooooooooool09_oo
ool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Gooooo`?o00001?ooool2
o`0000Gooooo00?o0000ooooooooool09_ooool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo00oooooo000Hooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0Vooooo`03o`WZ2_l0003ooooo01oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool0
01Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`?o00009_ooool0
0ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Hooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Vooooo`03o`WZ2_l0003o
oooo01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool03oooool001Sooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo02Kooooo00?o2NX:o`000?ooool07oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`0?ooooo`005oooool2o`0000Cooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0Vooooo`03o`WZ2_l0003ooooo01oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool0
01Sooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l0000Wooooo`03o`WZ2_l0003ooooo
01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool03oooool002Gooooo00?o0000ooooooooool09_ooool00ol9jP[o
0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`03o`000?oooooooooo02Kooooo
00?o2NX:o`000?ooool07oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`009Oooool00ol0003ooooooooo
o`0Vooooo`03o`WZ2_l0003ooooo01oooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo0_l0000W
ooooo`03o`WZ2_l0003ooooo01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo00?o0000oooo
ooooool09_ooool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`03
o`000?oooooooooo02Kooooo00?o2NX:o`000?ooool07oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`00
9Oooool00ol0003oooooooooo`0Vooooo`03o`WZ2_l0003ooooo01oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0
3oooool002Gooooo0_l0000Wooooo`03o`WZ2_l0003ooooo01oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03ooo
ool002Gooooo00?o0000ooooooooool09_ooool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo00oooooo000Uooooo`03o`000?oooooooooo02Kooooo00?o2NX:o`000?ooool07oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0?ooooo`009Oooool00ol0003oooooooooo`0Vooooo`03o`WZ2_l0003ooooo01oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool03oooool002Gooooo0_l0000Wooooo`03o`WZ2_l0003ooooo01oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool03oooool000_ooooo0ol00002ooooo`Go00000oooool00ol0003ooooooooo
o`02ooooo`?o00001Oooool00ol0003oooooooooo`0Vooooo`03o`WZ2_l0003ooooo01oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool03oooool000cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Vooooo`03o`WZ
2_l0003ooooo01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool03oooool000cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_oo
ool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000<ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`?o00009_ooool0
0ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000<ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`05ooooo`Co00001Oooool00ol0003oooooooooo`0V
ooooo`03o`WZ2_l0003ooooo01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool000_ooooo0_l00003oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`003?ooool00ol0
003oooooooooo`02ooooo`?o00002?ooool5o`0000Cooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`;o0000:?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`009Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo0_l0000X
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`00
9Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0
3oooool002Gooooo0_l0000Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03ooo
ool002Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo00oooooo000Uooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0?ooooo`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool03oooool002Gooooo0_l0000Xooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool03oooool002Gooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo00oooooo000Gooooo`?o00000oooool3o`0000Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Hoooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`006?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool03oooool001Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`0?ooooo`006?ooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Gooooo`;o0000
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0?ooooo`006?ooool01?l0003oooooooooooooool5o`0000Cooooo
0_l0000Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000U
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?
ooooo`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool03oooool002Gooooo0_l0000Xooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool03oooool002Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo00oooooo000Uooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`0?ooooo`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool03oooool002Gooooo0_l0000Xooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool03oooool002Gooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`009Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo0_l0000X
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool000_ooooo0ol00004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
00oooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`?o00009oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oo
oooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`0?ooooo`003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo1?l0
0005ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0?ooooo`002oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo00oooooo000<ooooo`04o`000?ooooooooooooooo`Go00001oooool5o`0000Cooooo0_l0
000Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool03oooool002Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo000Uoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?oooo
o`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool03oooool002Gooooo0_l0000Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0
3oooool002Gooooo00?o0000ooooooooool09oooool00ol0003o2NX:o`WZ2P0No`WZ2P03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo00oooooo000Uooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`0?ooooo`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool03oooool002Gooooo0_l0000Xooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool03oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool004gooooo0ol0000Jooooo`?o00006oooool3o`0009Gooooo001@ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Dooooo`00>_oo
ool5o`000006ooooool0003oooooo`000?oooooo00000_ooool4o`0000;ooooo1?l000000ooooooo
0000o`000003o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000002o`00
0004ooooool0003o0000o`0000Gooooo00?o0000ooooooooool02Oooool2o`0000?ooooo0ol00002
ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000;ooooo1Ol00002ooooo`?o00000_oo
ool2o`000003ooooool0003o000000Oooooo1?l00003ooooo`?o00000oooool4o`000006ooooool0
003oooooo`000?oooooo00001oooool3o`0000Cooooo1?l000001?oooooo0000o`000?l00004oooo
o`Co000000Koooooo`000?oooooo0000ooooool00002ooooo`?o00001?ooool2o`0000?ooooo0ol0
0002ooooo`?o0000:Oooool003cooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0
003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool02?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooool000002Oooool01_l0003oooooooooool0
003oooooo`0000Gooooo00Co0000oooooooooooo00000_ooool01Ol0003oooooo`000?oooooo0000
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01ol0003oooooo`000?oooooo0000ooooool0
00001_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00?o0000ooooooooool0:?ooool0
03cooooo00?o0000ooooooooool01?l000000ooooooo0000o`000004o`000003ooooool0003o0000
00So00000_ooool01?l0003oooooo`000?ooool2o`0000;ooooo1Ol000000ooooooo0000ooooo`03
o`000003ooooool0003ooooo00Go000000?oooooo`000?l000000_l00002ooooo`03o`000?oooooo
000000;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooooooo`Oo000000?oooooo`000?ooool02Oooool00ol0
003oooooo`000007o`0000;ooooo0ol00002ooooo`05o`000?oooooo0000ooooool000002?ooool0
0ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`?o00000_ooool0
1_l0003oooooo`000?oooooo0000ooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`Go0000
0_ooool00ol0003oooooooooo`0Dooooo`?o00004Oooool003cooooo00_o0000oooooooooooooooo
o`000?oooooo0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool0
1?l0003oooooooooooooool2o`000005ooooool0003oooooo`000?ooool00_l000001?oooooo0000
ooooooooool2o`0000;ooooo0_l000002Ooooooo0000oooooooooooo0000ooooool0003oooooo`00
0006ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`;o000000Goooooo`000?l0003oooooo`000009ooooo`Co000000?oooooo`000?l000000_oo
ool00ol0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00008oooo
o`?o00000_ooool01?l0003oooooooooool00003ooooo`;o00000oooool01?l0003oooooooooool0
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00Cooooo00Go0000ooooooooooooooooo`000002ooooo`;o00005Oooool01?l0003oooooooooool0
000@ooooo`00??ooool01?l0003oooooooooooooool2o`000004ooooool0003oooooooooo`?o0000
1?ooool8o`0000;ooooo1Ol00003ooooo`;o000000?oooooo`000?ooool00_l000001?oooooo0000
o`000?ooool2o`000004ooooool0003o0000o`0000Cooooo0ol00002ooooo`04o`000?oooooo0000
ooooo`?o00000_ooool2o`000004ooooool0003oooooooooo`Co00001?ooool00ol0003ooooooooo
o`02ooooo`?o00000_ooool2o`000003ooooool0003o000000Sooooo00Co0000oooooooooooo0000
0_ooool3o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?ooool02?ooool01?l0003ooooo
ooooool00002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o
000000?oooooo`000?ooool00_ooool3o`0000;ooooo1?l00003ooooo`?o00000_ooool2o`000003
ooooool0003o000001Kooooo00?o0000ooooooooool03_ooool003cooooo00Co0000oooooooooooo
oooo0ol00003ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ool0003oooooo`000006ooooo`?o00000oooool2o`0000Gooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool04Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00006_ooool01?l0003ooooo
ooooool0000Pooooo`03o`000?oooooooooo027ooooo0_l0000Aooooo`00>_ooool5o`000006oooo
ool0003oooooooooool0003ooooo0_l000001?oooooo0000o`000?ooool3o`0000Cooooo1?l00000
1Ooooooo0000o`000?oooooo000000Oooooo00Go0000oooooooooooo0000ooooo`02o`000004oooo
ool0003o0000ooooo`?o00001?ooool7o`000003ooooool0003ooooo013ooooo0ol00006ooooo`03
o`000?oooooooooo00cooooo1Ol0000Iooooo`Co00008Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo017ooooo0010ooooo`04o`000?ooooooooooo`0001kooooo00Co0000oooooooo
oooo0000<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00Co0000oooo
oooooooo00004?ooool003oooooo1?l0000:ooooo`03o`000?oooooooooo017ooooo1?l0000:oooo
o`03o`000?oooooooooo02Cooooo0ol0000@ooooo`?o0000HOooool3o`00013ooooo003oooooob7o
oooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-20.2248, -1.55371, \
0.537958, 0.128831}},
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00759676 0.0660057 0.000346009 [
[.17574 .05351 -6 -9 ]
[.17574 .05351 6 0 ]
[.32768 .05351 -6 -9 ]
[.32768 .05351 6 0 ]
[.47962 .05351 -6 -9 ]
[.47962 .05351 6 0 ]
[.63155 .05351 -6 -9 ]
[.63155 .05351 6 0 ]
[.78349 .05351 -9 -9 ]
[.78349 .05351 9 0 ]
[.93542 .05351 -9 -9 ]
[.93542 .05351 9 0 ]
[.01131 .15251 -18 -4.5 ]
[.01131 .15251 0 4.5 ]
[.01131 .23901 -18 -4.5 ]
[.01131 .23901 0 4.5 ]
[.01131 .32551 -18 -4.5 ]
[.01131 .32551 0 4.5 ]
[.01131 .41201 -24 -4.5 ]
[.01131 .41201 0 4.5 ]
[.01131 .49852 -24 -4.5 ]
[.01131 .49852 0 4.5 ]
[.01131 .58502 -24 -4.5 ]
[.01131 .58502 0 4.5 ]
[.5 .63053 -83.0625 0 ]
[.5 .63053 83.0625 12 ]
[.19317 .6609 -17.0625 -6 ]
[.19317 .6609 17.0625 6 ]
[.33029 .6609 -17.0625 -6 ]
[.33029 .6609 17.0625 6 ]
[.4989 .6609 -5 -6 ]
[.4989 .6609 5 6 ]
[.57645 .6609 -5 -6 ]
[.57645 .6609 5 6 ]
[.97619 .6609 -5 -6 ]
[.97619 .6609 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17574 .06601 m
.17574 .07226 L
s
[(20)] .17574 .05351 0 1 Mshowa
.32768 .06601 m
.32768 .07226 L
s
[(40)] .32768 .05351 0 1 Mshowa
.47962 .06601 m
.47962 .07226 L
s
[(60)] .47962 .05351 0 1 Mshowa
.63155 .06601 m
.63155 .07226 L
s
[(80)] .63155 .05351 0 1 Mshowa
.78349 .06601 m
.78349 .07226 L
s
[(100)] .78349 .05351 0 1 Mshowa
.93542 .06601 m
.93542 .07226 L
s
[(120)] .93542 .05351 0 1 Mshowa
.125 Mabswid
.06179 .06601 m
.06179 .06976 L
s
.09978 .06601 m
.09978 .06976 L
s
.13776 .06601 m
.13776 .06976 L
s
.21373 .06601 m
.21373 .06976 L
s
.25171 .06601 m
.25171 .06976 L
s
.2897 .06601 m
.2897 .06976 L
s
.36566 .06601 m
.36566 .06976 L
s
.40365 .06601 m
.40365 .06976 L
s
.44163 .06601 m
.44163 .06976 L
s
.5176 .06601 m
.5176 .06976 L
s
.55558 .06601 m
.55558 .06976 L
s
.59357 .06601 m
.59357 .06976 L
s
.66953 .06601 m
.66953 .06976 L
s
.70752 .06601 m
.70752 .06976 L
s
.7455 .06601 m
.7455 .06976 L
s
.82147 .06601 m
.82147 .06976 L
s
.85945 .06601 m
.85945 .06976 L
s
.89744 .06601 m
.89744 .06976 L
s
.9734 .06601 m
.9734 .06976 L
s
.25 Mabswid
0 .06601 m
1 .06601 L
s
.02381 .15251 m
.03006 .15251 L
s
[(250)] .01131 .15251 1 0 Mshowa
.02381 .23901 m
.03006 .23901 L
s
[(500)] .01131 .23901 1 0 Mshowa
.02381 .32551 m
.03006 .32551 L
s
[(750)] .01131 .32551 1 0 Mshowa
.02381 .41201 m
.03006 .41201 L
s
[(1000)] .01131 .41201 1 0 Mshowa
.02381 .49852 m
.03006 .49852 L
s
[(1250)] .01131 .49852 1 0 Mshowa
.02381 .58502 m
.03006 .58502 L
s
[(1500)] .01131 .58502 1 0 Mshowa
.125 Mabswid
.02381 .08331 m
.02756 .08331 L
s
.02381 .10061 m
.02756 .10061 L
s
.02381 .11791 m
.02756 .11791 L
s
.02381 .13521 m
.02756 .13521 L
s
.02381 .16981 m
.02756 .16981 L
s
.02381 .18711 m
.02756 .18711 L
s
.02381 .20441 m
.02756 .20441 L
s
.02381 .22171 m
.02756 .22171 L
s
.02381 .25631 m
.02756 .25631 L
s
.02381 .27361 m
.02756 .27361 L
s
.02381 .29091 m
.02756 .29091 L
s
.02381 .30821 m
.02756 .30821 L
s
.02381 .34281 m
.02756 .34281 L
s
.02381 .36011 m
.02756 .36011 L
s
.02381 .37741 m
.02756 .37741 L
s
.02381 .39471 m
.02756 .39471 L
s
.02381 .42932 m
.02756 .42932 L
s
.02381 .44662 m
.02756 .44662 L
s
.02381 .46392 m
.02756 .46392 L
s
.02381 .48122 m
.02756 .48122 L
s
.02381 .51582 m
.02756 .51582 L
s
.02381 .53312 m
.02756 .53312 L
s
.02381 .55042 m
.02756 .55042 L
s
.02381 .56772 m
.02756 .56772 L
s
.02381 .04871 m
.02756 .04871 L
s
.02381 .0314 m
.02756 .0314 L
s
.02381 .0141 m
.02756 .0141 L
s
.02381 .60232 m
.02756 .60232 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -144.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Real) show
93.000 13.000 moveto
(Complex) show
141.000 13.000 moveto
(Beam) show
171.125 13.000 moveto
(Parameter) show
225.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .41201 m
.09004 .40899 L
.12451 .40742 L
.14276 .40659 L
.16227 .4057 L
.17173 .40527 L
.18066 .40486 L
.18456 .40469 L
.18868 .4045 L
.19084 .4044 L
.19206 .40434 L
.19321 .60332 L
.19523 .60323 L
.19739 .60313 L
.23011 .60164 L
.2639 .6001 L
.28175 .59929 L
.30078 .59842 L
.31031 .59799 L
.31929 .59758 L
.32322 .5974 L
.32736 .59721 L
.32952 .59711 L
.33075 .42381 L
.3319 .42376 L
.33608 .42357 L
.36885 .42208 L
.43555 .41904 L
.45299 .41824 L
.47196 .41738 L
.48065 .41698 L
.48988 .41656 L
.49367 .41639 L
.49566 .4163 L
.49776 .4162 L
.49888 .41615 L
.5001 .01817 L
.50225 .01807 L
.50646 .01788 L
.54289 .01622 L
.56011 .01544 L
.56767 .01509 L
.57197 .0149 L
.57407 .0148 L
.57599 .01472 L
.57798 .05136 L
.57986 .05127 L
.58402 .05108 L
.59251 .0507 L
.61042 .04988 L
Mistroke
.64293 .0484 L
.70849 .04541 L
.77826 .04224 L
.84542 .03918 L
.9168 .03593 L
.97619 .03322 L
Mfstroke
0 0 0 r
gsave
.19317 .6609 -78.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33029 .6609 -78.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4989 .6609 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57645 .6609 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .6609 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19317 .01584 m
0 0 rlineto s
.19317 .01584 m
.19317 .61803 L
s
.33029 .01584 m
0 0 rlineto s
.33029 .01584 m
.33029 .61803 L
s
.4989 .01584 m
0 0 rlineto s
.4989 .01584 m
.4989 .61803 L
s
.57645 .01584 m
0 0 rlineto s
.57645 .01584 m
.57645 .61803 L
s
.97619 .01584 m
0 0 rlineto s
.97619 .01584 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[88]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o7_ooool0
0ol0003oooooooooo`3oooooo`007_ooool00ol0003oooooooooo`3oooooo`007_ooool00ol0003o
ooooooooo`3oooooo`007_ooool2o`0002[ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00gooooo1?l9jPX00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[o2NX:00ko2NX:0oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo01oooooo1Ol00003
ooooo`?o00007_ooool3o`0000;ooooo0ol0000Nooooo`?o00001?ooool2o`000003ooooool0003o
2NX:01;ooooo00?o0000ooooooooool01oooool3o`0000Cooooo0_l0000Kooooo`?o00001?ooool2
o`0000Cooooo0_l0000Hooooo`?o00000_ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0000Oooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`0Jooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`000003
o`WZ2_oooooooooo013ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00006oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00007?ooool5o`0000;ooooo00Co0000oooooooooooo00007?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_l000000ol9jP[oooooooooo`0@ooooo`03o`000?oo
oooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001_o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool02?ooool001kooooo0_l0000Sooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooo00007?ooool4o`0000?ooooo00?o0000ooooooooool00_l000000ol9jP[o
ooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`04o`000?ooooooooooo`00
01_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0001Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08o`WZ2P03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooool0000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_l000000ol9jP[o
ooooooooo`0@ooooo`03o`000?l9jP[ooooo00Kooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`00017ooooo4Ol9jPX01Ooooooo0000oooooooooooo000000?o
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool07oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00007_ooool2o`0000?ooooo00Co0000oooo
oooooooo00007Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o000000?o2NX:
ooooooooool04?ooool00ol0003o2NX:ooooo`06ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0000Hooooob?o2NX:1_ooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool08?ooool3o`0000Cooooo0ol0000Oooooo`04o`000?oooooooooooooo
o`?o00007oooool2o`0000Cooooo0_l000000ooooooo0000o`WZ2P0Booooo`03o`000?l9jP[ooooo
00Oooooo0ol00004ooooo`;o00001ooooolBo`WZ2P?ooooo00?o0000ooooooooool00oooool2o`00
00Cooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`;o00001?ooool00ol0
003oooooooooo`08ooooo`007_ooool2o`0002[ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo00?o0000o`WZ2_ooool01?oooolCo`WZ2Tko
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003o2NX:
o`WZ2P04o`WZ2V7ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ2_ooool04Ooo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[o
oooo017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0
003o2NX:ooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001So
ooooP_l000000ol9jP[o0000o`00001oo`0000Cooooo000Nooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03
o`000?l9jP[ooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?l9jP[ooooo017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?oo
ool00ol0003o2NX:ooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?oo
ool001kooooo0_l0000Zooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool0
0ol0003o2NX:ooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0:?ooool00ol0003o2NX:ooooo`0Aooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000:_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003o2NX:ooooo`0Aooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ2_ooool0
4Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000:_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ2_ooool04Ooo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[o
oooo017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0
003o2NX:ooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02So
oooo00?o0000o`WZ2_ooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0002[ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?l9jP[ooooo017ooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0:?ooool00ol0003o2NX:ooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool02?ooool000Wooooo1Ol00002ooooo`?o00001?ooool2o`0000Gooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ
2_ooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000:ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`?o0000:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo00Sooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`08ooooo`002Oooool01_l0003ooooooooooooooooo0000ooooo`Co0000
0oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`08ooooo`002Oooool01ol0003ooooooooooooooooo0000oooo
ool000001_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`08ooooo`002_ooool3o`0000;ooooo1Ol00003oooo
o`;o00001Oooool2o`0002[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xoooo
o`03o`000?l9jP[ooooo017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0:?ooool00ol0003o2NX:ooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003oooooooooo`1Uooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0:?ooool00ol0003o2NX:ooooo`0Aooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool02?ooool001kooooo0_l0000Zooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0:?ooool00ol0003o2NX:ooooo`0Aooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ2_ooool04Oooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?l9jP[ooooo017ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003o2NX:oooo
o`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001kooooo0_l0000Z
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003o2NX:ooooo`0A
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000o`WZ
2_ooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03
o`000?l9jP[ooooo017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
:?ooool00ol0003o2NX:ooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`;o0000:_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`08ooooo`002_ooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool000Wooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool02?ooool000gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo0ol0000Yooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool02?ooool000gooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`Co00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`002Oooool5o`0000?o
oooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Go
oooo00?o0000ooooooooool02?ooool001kooooo0_l0000Zooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001kooooo0_l0000Zooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
00Sooooo000Nooooo`;o0000:_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000:_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`02ooooo`?o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`00
0?oooooooooo00Sooooo000;ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000<ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`003?ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool3o`0002Wo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`003Oooool00ol0003ooooo
o`000003o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool000Wooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool000Wooooo1Ol000000ooo
oooo0000o`000003o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`08ooooo`007_ooool2o`0002[ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001ko
oooo0_l0000Zooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool02?ooool001kooooo0_l0000Zooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000:_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`001?ooool3o`0000Cooooo
0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool07oooool:o`WZ2P03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool02?ooool000Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`06oooooaWo2NX:2_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo00Sooooo0005ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo2Ol9
jPXSooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool000Gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool08oooool5o`WZ2P03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`08ooooo`001Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0@
oooooa?o2NX:1Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool02?ooool000Cooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool08Oooool00ol0003o2NX:o`WZ2P0@o`WZ2QSooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo0005ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000:_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo
000Nooooo`;o0000:_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`08ooooo`007_ooool2o`0002[ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`007_ooool2o`0002[ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool000Cooooo0ol00002
ooooo`Go00000_ooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`08ooooo`001Oooool00ol0003oooooooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`00
0?oooooooooo00Sooooo0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0ol0000Yooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool02?ooool000Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
2?ooool000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?o0000
0oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`08ooooo`001?ooool2o`0000?ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool000Gooooo00?o0000oooo
ooooool00_ooool3o`0000;ooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo023ooooo00?o2NX:o`000?ooool0:Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001kooooo0_l0000Zooooo`03
o`000?oooooooooo023ooooo00?o2NX:o`000?ooool0:Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Pooooo`03o`WZ2_l0003ooooo02Wooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool08?ooool00ol9jP[o0000ooooo`0Yooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o2NX:o`000?ooool0:Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool0
01kooooo0_l0000Zooooo`03o`000?oooooooooo023ooooo00?o2NX:o`000?ooool0:Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`WZ2_l0003ooooo02Wo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol9jP[o0000
ooooo`0Yooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o
2NX:o`000?ooool0:Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0P
ooooo`03o`WZ2_l0003ooooo02Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000:_ooool00ol0003oooooooooo`0Poooo
o`03o`WZ2_l0003ooooo02Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool08?ooool00ol9jP[o0000ooooo`0Yooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo023ooooo00?o2NX:o`000?ooool0:Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Pooooo`03o`WZ2_l0003ooooo02Wooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000:_ooool0
0ol0003oooooooooo`0Pooooo`03o`WZ2_l0003ooooo02Wooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool08?ooool00ol9jP[o0000ooooo`0Yooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08ooooo`001?ooool3o`0000?o
oooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Pooooo`03o`WZ2_l0003ooooo02Wooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo0005ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo00?o2NX:
o`000?ooool0:Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool02?ooool000Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo023ooooo00?o2NX:o`000?ooool0:Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool000Gooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool3o`0002Wooooo00?o0000ooooooooool08?ooool00ol9jP[o0000
ooooo`0Yooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`08ooooo`001Oooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool08?ooool00ol9jP[o0000ooooo`0Yooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`08ooooo`001?ooool2o`0000?ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`WZ2_l0003ooooo02Wooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo0005oooo
o`04o`000?ooooooooooooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool05oooool:o`WZ2P03o`000?oooooooooo02Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo000Noooo
o`;o0000:_ooool00ol0003oooooooooo`03oooooaCo2NX:2_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?l9jP[o2NX:00?o2NX:7_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`08ooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00N?ooool3o`000:Gooooo001iooooo`03
o`000?oooooooooo0:Cooooo0018ooooo`?o00000_ooool00ol0003oooooo`000002o`0000?ooooo
1?l000000ooooooo0000o`000003o`0000Wooooo0_l00003ooooo`?o00000_ooool01Ol0003ooooo
o`000?oooooo000000;ooooo0ol00002ooooo`Go00000_ooool3o`0000;ooooo0_l000000ooooooo
0000o`000007ooooo`Co00000oooool3o`0000?ooooo1?l000001_oooooo0000ooooool0003ooooo
o`0000Sooooo0ol00004ooooo`Co000000Coooooo`000?l0003o00001?ooool4o`000006ooooool0
003oooooo`000?oooooo00000_ooool3o`0000Cooooo0_l00003ooooo`?o00000_ooool3o`0003So
oooo000kooooo`?o00000oooool3o`0000?ooooo2_l00002ooooo`?o000000?oooooo`000?ooool0
0oooool00ol0003oooooooooo`03o`0000?ooooo0ol00002ooooo`_o000000Koooooo`000?l0003o
ooooo`000?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
000000Sooooo1Ol000000ooooooo0000ooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooool000001?l00007ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Oo0000ooooool0
003oooooo`000?oooooo000000Kooooo00Ko0000oooooooooooo0000ooooool00006ooooo`03o`00
0?oooooooooo02[ooooo0ol0000:ooooo`00??ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000000_ooool6o`000004ooooool0003o0000o`0000Cooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`04
o`000?oooooo0000ooooo`Co000000?oooooo`000?ooool00_l00003ooooo`04o`000?oooooooooo
ooooo`Go00000oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooo`000?ooool01Ol0
0002ooooo`?o00000_ooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Kooooo00?o
0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool3o`0000;ooooo00Ko
0000ooooool0003oooooo`000?ooool5o`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;o
oooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool00009ooooo`00??ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`?o000000?oooooo`000?l0
00000_l000000ooooooo0000ooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooo`000002o`000006ooooool0003o0000
ooooool0003ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool01_l0003ooooo
ooooool0003oooooo`0000Wooooo0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`05o`000?ooooooooooo`000?ooool00ol00009ooooo`?o00000_ooool01?l0003ooooo
ooooool00003ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`07o`000?oooooo0000
ooooool0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`00??ooool3o`0000?ooooo
0_l00005ooooo`03o`000?oooooooooo00;o000000Ooooooo`000?l0003o0000ooooool0003ooooo
00?o00001?ooool01?l0003oooooooooooooool3o`0000?ooooo0_l00005ooooo`?o000000Oooooo
o`000?l0003o0000ooooool0003ooooo00Go00001?ooool00ol0003oooooooooo`02ooooo`?o0000
0_ooool2o`000003ooooool0003o000000Sooooo00Co0000oooooooooooo00000_ooool3o`0000?o
oooo0_l00003ooooo`;o000000?oooooo`000?ooool02Oooool01?l0003oooooooooool00002oooo
o`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o000000?oooooo`00
0?ooool00_ooool3o`0000;ooooo1?l00003ooooo`?o00000_ooool2o`000003ooooool0003o0000
02[ooooo0_l0000:ooooo`00??ooool01Ol0003oooooooooool0003ooooo00;o000000Coooooo`00
0?l0003ooooo0ol00002ooooo`03o`000?oooooo000000?o000000Goooooo`000?l0003oooooo`00
0005ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000008o`0000Cooooo
1?l000001Ooooooo0000o`000?oooooo000000Gooooo00?o0000ooooooooool05?ooool01?l0003o
ooooooooool0000@ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00008?ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00[ooooo000looooo`04o`000?oooooooooo
o`0000Sooooo1?l0000>ooooo`?o00000oooool01?l0003oooooooooool00004ooooo`?o00004ooo
ool3o`0001Gooooo1?l0000Aooooo`03o`000?oooooooooo00Oooooo1?l0000Qooooo`03o`000?oo
oooooooo03Kooooo00Co0000oooooooooooo00002Oooool003_ooooo1?l0000:ooooo`03o`000?oo
oooooooo01?ooooo1?l0000:ooooo`03o`000?oooooooooo02Kooooo0ol0000Aooooo`?o0000Iooo
ool3o`0000Wooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-15.7138, -190.773, \
0.508949, 11.1742}},
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00759676 0.0139955 0.0572892 [
[.17574 .0015 -6 -9 ]
[.17574 .0015 6 0 ]
[.32768 .0015 -6 -9 ]
[.32768 .0015 6 0 ]
[.47962 .0015 -6 -9 ]
[.47962 .0015 6 0 ]
[.63155 .0015 -6 -9 ]
[.63155 .0015 6 0 ]
[.78349 .0015 -9 -9 ]
[.78349 .0015 9 0 ]
[.93542 .0015 -9 -9 ]
[.93542 .0015 9 0 ]
[.01131 .12857 -6 -4.5 ]
[.01131 .12857 0 4.5 ]
[.01131 .24315 -6 -4.5 ]
[.01131 .24315 0 4.5 ]
[.01131 .35773 -6 -4.5 ]
[.01131 .35773 0 4.5 ]
[.01131 .47231 -6 -4.5 ]
[.01131 .47231 0 4.5 ]
[.01131 .58689 -12 -4.5 ]
[.01131 .58689 0 4.5 ]
[.5 .63053 -98.0625 0 ]
[.5 .63053 98.0625 12 ]
[.19317 .66372 -17.0625 -6 ]
[.19317 .66372 17.0625 6 ]
[.33029 .66372 -17.0625 -6 ]
[.33029 .66372 17.0625 6 ]
[.4989 .66372 -5 -6 ]
[.4989 .66372 5 6 ]
[.57645 .66372 -5 -6 ]
[.57645 .66372 5 6 ]
[.97619 .66372 -5 -6 ]
[.97619 .66372 5 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17574 .014 m
.17574 .02025 L
s
[(20)] .17574 .0015 0 1 Mshowa
.32768 .014 m
.32768 .02025 L
s
[(40)] .32768 .0015 0 1 Mshowa
.47962 .014 m
.47962 .02025 L
s
[(60)] .47962 .0015 0 1 Mshowa
.63155 .014 m
.63155 .02025 L
s
[(80)] .63155 .0015 0 1 Mshowa
.78349 .014 m
.78349 .02025 L
s
[(100)] .78349 .0015 0 1 Mshowa
.93542 .014 m
.93542 .02025 L
s
[(120)] .93542 .0015 0 1 Mshowa
.125 Mabswid
.06179 .014 m
.06179 .01775 L
s
.09978 .014 m
.09978 .01775 L
s
.13776 .014 m
.13776 .01775 L
s
.21373 .014 m
.21373 .01775 L
s
.25171 .014 m
.25171 .01775 L
s
.2897 .014 m
.2897 .01775 L
s
.36566 .014 m
.36566 .01775 L
s
.40365 .014 m
.40365 .01775 L
s
.44163 .014 m
.44163 .01775 L
s
.5176 .014 m
.5176 .01775 L
s
.55558 .014 m
.55558 .01775 L
s
.59357 .014 m
.59357 .01775 L
s
.66953 .014 m
.66953 .01775 L
s
.70752 .014 m
.70752 .01775 L
s
.7455 .014 m
.7455 .01775 L
s
.82147 .014 m
.82147 .01775 L
s
.85945 .014 m
.85945 .01775 L
s
.89744 .014 m
.89744 .01775 L
s
.9734 .014 m
.9734 .01775 L
s
.25 Mabswid
0 .014 m
1 .014 L
s
.02381 .12857 m
.03006 .12857 L
s
[(2)] .01131 .12857 1 0 Mshowa
.02381 .24315 m
.03006 .24315 L
s
[(4)] .01131 .24315 1 0 Mshowa
.02381 .35773 m
.03006 .35773 L
s
[(6)] .01131 .35773 1 0 Mshowa
.02381 .47231 m
.03006 .47231 L
s
[(8)] .01131 .47231 1 0 Mshowa
.02381 .58689 m
.03006 .58689 L
s
[(10)] .01131 .58689 1 0 Mshowa
.125 Mabswid
.02381 .04264 m
.02756 .04264 L
s
.02381 .07128 m
.02756 .07128 L
s
.02381 .09993 m
.02756 .09993 L
s
.02381 .15722 m
.02756 .15722 L
s
.02381 .18586 m
.02756 .18586 L
s
.02381 .21451 m
.02756 .21451 L
s
.02381 .2718 m
.02756 .2718 L
s
.02381 .30044 m
.02756 .30044 L
s
.02381 .32909 m
.02756 .32909 L
s
.02381 .38638 m
.02756 .38638 L
s
.02381 .41502 m
.02756 .41502 L
s
.02381 .44366 m
.02756 .44366 L
s
.02381 .50095 m
.02756 .50095 L
s
.02381 .5296 m
.02756 .5296 L
s
.02381 .55824 m
.02756 .55824 L
s
.02381 .61553 m
.02756 .61553 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -159.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Imaginary) show
123.000 13.000 moveto
(Complex) show
171.000 13.000 moveto
(Beam) show
201.125 13.000 moveto
(Parameter) show
255.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
.5 Mabswid
.02381 .40195 m
.09004 .40195 L
.12451 .40195 L
.14276 .40195 L
.16227 .40195 L
.17173 .40195 L
.18066 .40195 L
.18456 .40195 L
.18868 .40195 L
.19084 .40195 L
.19206 .40195 L
.19321 .60332 L
.19523 .60332 L
.19739 .60332 L
.23011 .60332 L
.2639 .60332 L
.28175 .60332 L
.30078 .60332 L
.31031 .60332 L
.31929 .60332 L
.32322 .60332 L
.32736 .60332 L
.32952 .60332 L
.33075 .40195 L
.3319 .40195 L
.33608 .40195 L
.36885 .40195 L
.43555 .40195 L
.45299 .40195 L
.47196 .40195 L
.48065 .40195 L
.48988 .40195 L
.49367 .40195 L
.49566 .40195 L
.49776 .40195 L
.49888 .40195 L
.5001 .01836 L
.50225 .01836 L
.50646 .01836 L
.54289 .01836 L
.56011 .01836 L
.56767 .01836 L
.57197 .01836 L
.57407 .01836 L
.57599 .01836 L
.57798 .01472 L
.57986 .01472 L
.58402 .01472 L
.59251 .01472 L
.61042 .01472 L
Mistroke
.64293 .01472 L
.70849 .01472 L
.77826 .01472 L
.84542 .01472 L
.9168 .01472 L
.97619 .01472 L
Mfstroke
0 0 0 r
gsave
.19317 .66372 -78.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33029 .66372 -78.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4989 .66372 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57645 .66372 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .66372 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19317 .014 m
0 0 rlineto s
.19317 .014 m
.19317 .61803 L
s
.33029 .014 m
0 0 rlineto s
.33029 .014 m
.33029 .61803 L
s
.4989 .014 m
0 0 rlineto s
.4989 .014 m
.4989 .61803 L
s
.57645 .014 m
0 0 rlineto s
.57645 .014 m
.57645 .61803 L
s
.97619 .014 m
0 0 rlineto s
.97619 .014 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[88]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool5o`0000?ooooo0_l0000Mooooo`?o00000oooool2o`0001gooooo0ol00004oooo
o`;o00007?ooool3o`0000Cooooo0_l0000Iooooo`?o00001?ooool2o`0000Cooooo0_l0000Foooo
o`?o00000_ooool5o`0000?ooooo0_l0000Kooooo`00?oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0001gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo01Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
01[ooooo0010ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool5o`00
00;ooooo00Co0000oooooooooooo00006oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00006Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00006_ooool0047ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo01Sooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0000Koooo
o`Co00000oooool01?l0003oooooooooool0000Kooooo`?o00000oooool01?l0003oooooooooool0
000Iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Fooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo01Sooooo000nooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Kooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00006ooo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0001[ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool06?ooool003kooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001cooooo0_l00003oooo
o`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
000Jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Hooooo`;o
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Gooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Jooooo`00?ooo
ool3o`0000Cooooo0_l0000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Nooooo`;o00001?oo
ool2o`0001cooooo0ol00004ooooo`;o00006_ooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0001Oooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0000Kooooo`007oooool0
0ol0003oooooooooo`3nooooo`007oooool00ol0003oooooooooo`3nooooo`007oooool00ol0003o
ooooooooo`3nooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05kooooo
00?o0000ooooooooool05Oooool001WoooooS_l0001Qo`WZ2POo00004Oooool001oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo0_l00008
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000004_l9jPX00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo0_l0000Gooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?l9jP[ooooo013o
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:
ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000O
ooooo`;o0000:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000
o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Ooooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Voooo
o`03o`000?l9jP[ooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eoooo
o`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?l9jP[ooooo013ooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`;o0000:?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?l9jP[ooooo013ooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:oooo
o`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000
o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Ooooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Voooo
o`03o`000?l9jP[ooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eoooo
o`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo01Gooooo000Oooooo`;o0000:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?l9jP[ooooo013ooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Fooooo`Go00001?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:
ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001Oooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool05Oooool001Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:oooo
o`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001Wooooo00?o0000
ooooooooool00oooool3o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0V
ooooo`03o`000?l9jP[ooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0E
ooooo`005_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Fooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool05Oooool001Oooooo0ol00005ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?l9jP[ooooo013ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:ooooo`0@ooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool0
4?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?l9
jP[ooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool2
o`0002Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?l9jP[o
oooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0
003o2NX:ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001oo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Ko
oooo00?o0000o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo000Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?l9jP[ooooo013ooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`0Eooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?ooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?l9jP[ooooo013ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool2o`0002Sooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?l9jP[ooooo013ooooo00?o0000oooooooo
ool0Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o2NX:ooooo`0@ooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000o`WZ2_ooool04?oo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?l9jP[o
oooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0
003o2NX:ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001oo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Ko
oooo00?o0000o`WZ2_ooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo000Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`0Eooooo`007oooool2o`0002Sooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0Eooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0Goooool00ol0003oooooooooo`0Eooooo`006?ooool3o`0000Cooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Iooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo01Gooooo000Fooooo`Go00001?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool05Oooool001Kooooo00Co0000oooooooooooo00001Oooool3
o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`005oooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0Eooooo`006?ooool2o`0000Gooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Iooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo
000Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0Eooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo01Gooooo000Oooooo`;o0000:?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03
o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001oooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo
000Oooooo`;o0000:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000O
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0E
ooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03
o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`;o0000:?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000G
ooooo`?o00001Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool05Oooool001Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`005_ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo000Fooooo`Co00001Oooool3o`0002Oooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0Eooooo`005_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`00
5oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0Eooooo`006?ooool2o`0000Gooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001oo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo000Oooooo`;o0000:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo
000Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0Eooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool05Oooool001oooooo:_l9jPX00ol0003oooooooooo`0Nooooo`03o`000?l9jP[o2NX:
02Ko2NX:00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
01Gooooo000Oooooo`03o`000?oooooooooo02Kooooo00?o2NX:o`000?ooool07oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0Vooooo`03o`WZ2_l0003ooooo01oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool05Oooool001oooooo00?o0000ooooooooool09_ooool00ol9jP[o0000oooo
o`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`;o00009oooool00ol9jP[o0000ooooo`0O
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Kooooo00?o2NX:o`00
0?ooool07oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0Vooooo`03
o`WZ2_l0003ooooo01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o0000ooooooooool0
9_ooool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oo
oooooooo02Kooooo00?o2NX:o`000?ooool07oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool0
0ol0003oooooooooo`0Vooooo`03o`WZ2_l0003ooooo01oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool0
01oooooo00?o0000ooooooooool09_ooool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
01Gooooo000Oooooo`;o00009oooool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo000Oooooo`03o`000?oooooooooo02Kooooo00?o2NX:o`000?ooool07oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`0Eooooo`007oooool00ol0003oooooooooo`0Vooooo`03o`WZ2_l0003ooooo01oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool05Oooool001oooooo00?o0000ooooooooool09_ooool00ol9jP[o0000ooooo`0O
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo000Gooooo`?o00001Oooool00ol0003oooooooooo`0Voooo
o`03o`WZ2_l0003ooooo01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001Kooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo02Kooooo00?o2NX:o`000?ooool07oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0Eooooo`005_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool09_ooool00ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Gooooo`?o
00001Oooool3o`0002Kooooo00?o2NX:o`000?ooool07oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`00
5_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool09_ooool00ol9jP[o
0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Fooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0Vooooo`03o`WZ2_l0003ooooo01oooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool05Oooool001Oooooo0ol00005ooooo`03o`000?oooooooooo02Kooooo00?o2NX:o`000?ooool0
7oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0Vooooo`03o`WZ2_l0
003ooooo01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o0000ooooooooool09_ooool0
0ol9jP[o0000ooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo
02Kooooo00?o2NX:o`000?ooool07oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool2o`0002Oo
oooo00?o2NX:o`000?ooool07oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000O
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0E
ooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03
o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0Eooooo`007oooool2o`0002Sooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool001oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000O
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0E
ooooo`007oooool2o`0002Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eoooo
o`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`0Eooooo`004Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`004_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Booooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool05Oooool001;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00004ooooo`?o00009oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo01Gooooo000Booooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05Oooool0
017ooooo0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Booooo`03o`000?oooooooooo
00?ooooo0_l00005ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?l9jP[o2NX:01ko
2NX:00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool05Oooool001oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`007oooool2o`0002Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00Aoooool3o`0001[ooooo0ol0000Kooooo`?o0000Voooool0
04[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
09[ooooo000dooooo`Go000000Koooooo`000?oooooo0000ooooool00002ooooo`Co00000_ooool4
o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0
003o000000;o000000Coooooo`000?l0003o00001Oooool00ol0003oooooooooo`09ooooo`;o0000
0oooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o00000_ooool5o`0000;o
oooo0ol00002ooooo`;o000000?oooooo`000?l000001oooool4o`0000?ooooo0ol00003ooooo`Co
000000Koooooo`000?oooooo0000ooooool00007ooooo`?o00001?ooool4o`000004ooooool0003o
0000o`0000Cooooo1?l000001_oooooo0000ooooool0003oooooo`0000;ooooo0ol00004ooooo`;o
00000oooool3o`0000;ooooo0ol0000_ooooo`00=_ooool02ol0003ooooooooooooooooo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000Cooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`08ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`000009ooooo`06o`00
0?ooooooooooo`000?oooooo00001Oooool01?l0003oooooooooool00002ooooo`05o`000?oooooo
0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000006ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003ooooo
ooooo`0^ooooo`00=_ooool01?l0003oooooooooooooool3o`000003ooooool0003ooooo00Co0000
0_ooool5o`000003ooooool0003o000000;o00000_ooool3o`000004ooooool0003oooooooooo`Go
000000?oooooo`000?ooool00ol000000ooooooo0000ooooo`05o`000003ooooool0003o000000;o
00000_ooool00ol0003oooooo`000002o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooooooool7o`000003oooo
ool0003ooooo00Wooooo00?o0000ooooool000001ol00002ooooo`?o00000_ooool01Ol0003ooooo
o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000oooooooo
ool00oooool3o`0000;ooooo00Ko0000ooooool0003oooooo`000?ooool5o`0000;ooooo00?o0000
ooooooooool00_ooool5o`0000;ooooo00?o0000ooooooooool05?ooool3o`0001Oooooo000foooo
o`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool00_l000002Ooooooo0000oooooooo
oooo0000ooooool0003oooooo`000003ooooo`04o`000?oooooo0000ooooo`?o000000Coooooo`00
0?oooooo00000_ooool2o`0000;ooooo0_l000002Ooooooo0000oooooooooooo0000ooooool0003o
ooooo`000006ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`;o000000Goooooo`000?l0003oooooo`000009ooooo`Co000000?oooooo`000?l0
00000_ooool00ol0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool0
0008ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`;o00000oooool01?l0003ooooo
ooooool00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`04o`000?oooooo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`;o00005Oooool01?l0003ooooo
ooooool0000Fooooo`00=_ooool01?l0003oooooooooooooool2o`000003ooooool0003ooooo00;o
oooo0_l00004ooooo`Wo00000_ooool5o`0000;ooooo0_l000000ooooooo0000ooooo`02o`000004
ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`0000;ooooo00Co0000
ooooool0003ooooo0ol00002ooooo`;o000000Coooooo`000?oooooooooo1?l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00002ooooo`;o000000?oooooo`000?l000002?ooool01?l0003ooooo
ooooool00002ooooo`?o00000oooool2o`0000?ooooo0_l000000ooooooo0000ooooo`08ooooo`04
o`000?ooooooooooo`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00?ooooo0_l000000ooooooo0000ooooo`02ooooo`?o00000_ooool4o`0000?ooooo0ol00002oooo
o`;o000000?oooooo`000?l000005_ooool00ol0003oooooooooo`0Dooooo`00=_ooool00ol0003o
ooooooooo`02ooooo`?o00000oooool2o`0000Gooooo00Go0000ooooooooooooooooo`000005oooo
o`05o`000?oooooo0000ooooool000001Oooool3o`0000?ooooo0_l00005ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooo`000002o`000003ooooool0003ooooo017ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0001[ooooo
00Co0000oooooooooooo00008?ooool00ol0003oooooooooo`0Qooooo`;o00005oooool003Cooooo
1Ol00002ooooo`05o`000?ooooooooooo`000?ooool00_l000001?oooooo0000o`000?ooool3o`00
00Cooooo1?l000001Ooooooo0000o`000?oooooo000000Kooooo00Go0000oooooooooooo0000oooo
o`02o`000004ooooool0003o0000ooooo`?o00001?ooool7o`000003ooooool0003ooooo013ooooo
0ol00006ooooo`03o`000?oooooooooo00cooooo1Ol0000Iooooo`Co00008Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo01Oooooo000kooooo`04o`000?ooooooooooo`0001gooooo
00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oo
oooo00Co0000oooooooooooo00005_ooool003[ooooo1?l0000:ooooo`03o`000?oooooooooo013o
oooo1?l0000:ooooo`03o`000?oooooooooo02Cooooo0ol0000@ooooo`?o0000HOooool3o`0001Ko
oooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-17.0493, -0.860605, \
0.538308, 0.0713816}},
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}]
}, Open  ]]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowGaussian", "Subsubsection",
  CellTags->{"AOG0.", "4.6.4", "AOG4.", "AOG4.6", "AOG4.6.4"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[prismgaussiansystem, PlotType->TopView, ShowGaussian->True];\
\>", "Input",
  CellLabel->"In[89]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .43672 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0371292 0.00778884 0.231601 0.00778884 [
[.04959 .04934 -13.5938 -6 ]
[.04959 .04934 13.5938 6 ]
[.5434 .08829 -5.03125 -6 ]
[.5434 .08829 5.03125 6 ]
[.97179 .0104 -4.75 -6 ]
[.97179 .0104 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .43672 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.07602 .07574 m
.27084 .41318 L
.27084 .41318 L
.07602 .07574 L
.07602 .07574 L
s
.46556 .07574 m
.27075 .41318 L
.27075 .41318 L
.46556 .07574 L
.46556 .07574 L
s
.07598 .07582 m
.46561 .07582 L
.46561 .07582 L
.07598 .07582 L
.07598 .07582 L
s
.07598 .07577 m
.27079 .4132 L
.46561 .07577 L
.07598 .07577 L
s
.07598 .07577 m
.27079 .4132 L
.46561 .07577 L
.07598 .07577 L
s
.5 g
.52455 .11477 m
.56226 .11477 L
.57357 .15371 L
.51324 .15371 L
.52455 .11477 L
F
.51324 .15371 m
.57357 .15371 L
.58017 .19266 L
.50663 .19266 L
.51324 .15371 L
F
.50663 .19266 m
.58017 .19266 L
.58235 .2316 L
.50446 .2316 L
.50663 .19266 L
F
.50446 .2316 m
.58235 .2316 L
.58017 .27055 L
.50663 .27055 L
.50446 .2316 L
F
.50663 .27055 m
.58017 .27055 L
.57357 .30949 L
.51324 .30949 L
.50663 .27055 L
F
.51324 .30949 m
.57357 .30949 L
.56226 .34843 L
.52455 .34843 L
.51324 .30949 L
F
0 g
.52455 .11477 m
.51324 .15371 L
.50663 .19266 L
.50446 .2316 L
.50663 .27055 L
.51324 .30949 L
.52455 .34843 L
.56226 .34843 L
.57357 .30949 L
.58017 .27055 L
.58235 .2316 L
.58017 .19266 L
.57357 .15371 L
.56226 .11477 L
.52455 .11477 L
s
.5 g
.52455 .2316 m
.56226 .2316 L
.57357 .2316 L
.51324 .2316 L
.52455 .2316 L
F
.51324 .2316 m
.57357 .2316 L
.58017 .2316 L
.50663 .2316 L
.51324 .2316 L
F
.50663 .2316 m
.58017 .2316 L
.58235 .2316 L
.50446 .2316 L
.50663 .2316 L
F
.50446 .2316 m
.58235 .2316 L
.58017 .2316 L
.50663 .2316 L
.50446 .2316 L
F
.50663 .2316 m
.58017 .2316 L
.57357 .2316 L
.51324 .2316 L
.50663 .2316 L
F
.51324 .2316 m
.57357 .2316 L
.56226 .2316 L
.52455 .2316 L
.51324 .2316 L
F
0 g
.52455 .2316 m
.51324 .2316 L
.50663 .2316 L
.50446 .2316 L
.50663 .2316 L
.51324 .2316 L
.52455 .2316 L
.56226 .2316 L
.57357 .2316 L
.58017 .2316 L
.58235 .2316 L
.58017 .2316 L
.57357 .2316 L
.56226 .2316 L
.52455 .2316 L
s
.52455 .34843 m
.56226 .34843 L
.56226 .34445 L
.52455 .34445 L
.52455 .34843 L
s
.52455 .34445 m
.56226 .34445 L
.56226 .33278 L
.52455 .33278 L
.52455 .34445 L
s
.52455 .33278 m
.56226 .33278 L
.56226 .31421 L
.52455 .31421 L
.52455 .33278 L
s
.52455 .31421 m
.56226 .31421 L
.56226 .29002 L
.52455 .29002 L
.52455 .31421 L
s
.52455 .29002 m
.56226 .29002 L
.56226 .26184 L
.52455 .26184 L
.52455 .29002 L
s
.52455 .26184 m
.56226 .26184 L
.56226 .2316 L
.52455 .2316 L
.52455 .26184 L
s
.52455 .2316 m
.56226 .2316 L
.56226 .20136 L
.52455 .20136 L
.52455 .2316 L
s
.52455 .20136 m
.56226 .20136 L
.56226 .17318 L
.52455 .17318 L
.52455 .20136 L
s
.52455 .17318 m
.56226 .17318 L
.56226 .14899 L
.52455 .14899 L
.52455 .17318 L
s
.52455 .14899 m
.56226 .14899 L
.56226 .13042 L
.52455 .13042 L
.52455 .14899 L
s
.52455 .13042 m
.56226 .13042 L
.56226 .11875 L
.52455 .11875 L
.52455 .13042 L
s
.52455 .11875 m
.56226 .11875 L
.56226 .11477 L
.52455 .11477 L
.52455 .11875 L
s
.52455 .11477 m
.56226 .11477 L
.56226 .11875 L
.52455 .11875 L
.52455 .11477 L
s
.52455 .11875 m
.56226 .11875 L
.56226 .13042 L
.52455 .13042 L
.52455 .11875 L
s
.52455 .13042 m
.56226 .13042 L
.56226 .14899 L
.52455 .14899 L
.52455 .13042 L
s
.52455 .14899 m
.56226 .14899 L
.56226 .17318 L
.52455 .17318 L
.52455 .14899 L
s
.52455 .17318 m
.56226 .17318 L
.56226 .20136 L
.52455 .20136 L
.52455 .17318 L
s
.52455 .20136 m
.56226 .20136 L
.56226 .2316 L
.52455 .2316 L
.52455 .20136 L
s
.52455 .2316 m
.56226 .2316 L
.56226 .26184 L
.52455 .26184 L
.52455 .2316 L
s
.52455 .26184 m
.56226 .26184 L
.56226 .29002 L
.52455 .29002 L
.52455 .26184 L
s
.52455 .29002 m
.56226 .29002 L
.56226 .31421 L
.52455 .31421 L
.52455 .29002 L
s
.52455 .31421 m
.56226 .31421 L
.56226 .33278 L
.52455 .33278 L
.52455 .31421 L
s
.52455 .33278 m
.56226 .33278 L
.56226 .34445 L
.52455 .34445 L
.52455 .33278 L
s
.52455 .34445 m
.56226 .34445 L
.56226 .34843 L
.52455 .34843 L
.52455 .34445 L
s
.97179 .03688 m
.97179 .10179 L
.97179 .16669 L
.97179 .2316 L
.97179 .29651 L
.97179 .36142 L
.97179 .42632 L
.97179 .42632 L
.97179 .36142 L
.97179 .29651 L
.97179 .2316 L
.97179 .16669 L
.97179 .10179 L
.97179 .03688 L
.97179 .03688 L
s
.97179 .2316 m
.97179 .2316 L
.97179 .2316 L
.97179 .2316 L
.97179 .2316 L
.97179 .2316 L
.97179 .2316 L
.97179 .2316 L
.97179 .2316 L
.97179 .2316 L
.97179 .2316 L
.97179 .2316 L
.97179 .2316 L
.97179 .2316 L
.97179 .2316 L
s
.97179 .42632 m
.97179 .41969 L
.97179 .40023 L
.97179 .36929 L
.97179 .32896 L
.97179 .282 L
.97179 .2316 L
.97179 .1812 L
.97179 .13424 L
.97179 .09391 L
.97179 .06297 L
.97179 .04352 L
.97179 .03688 L
.97179 .04352 L
.97179 .06297 L
.97179 .09391 L
.97179 .13424 L
.97179 .1812 L
.97179 .2316 L
.97179 .282 L
.97179 .32896 L
.97179 .36929 L
.97179 .40023 L
.97179 .41969 L
.97179 .42632 L
s
0 0 0 r
gsave
.04959 .04934 -74.5938 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
86.188 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5434 .08829 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97179 .0104 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
1 Mabswid
.02381 .2682 m
.03399 .27196 L
.04416 .27572 L
.05434 .27948 L
.06452 .28324 L
.07469 .28701 L
.08487 .29077 L
.09505 .29453 L
.10522 .29829 L
.1154 .30205 L
.12558 .30581 L
.13575 .30958 L
.14593 .31334 L
.15611 .3171 L
.16628 .32086 L
.17646 .32462 L
.18664 .32838 L
.21083 .34455 L
.22168 .34464 L
.23253 .34472 L
.24338 .3448 L
.25423 .34488 L
.26508 .34496 L
.27593 .34504 L
.28678 .34512 L
.29763 .3452 L
.30848 .34528 L
.31933 .34536 L
.33018 .34544 L
.35445 .33015 L
.36473 .3267 L
.37502 .32324 L
.3853 .31979 L
.39559 .31633 L
.40587 .31288 L
.41616 .30942 L
.42644 .30597 L
.43673 .30251 L
.44701 .29906 L
.4573 .2956 L
.46758 .29215 L
.47787 .28869 L
.48815 .28524 L
.49844 .28178 L
.50872 .27833 L
.51488 .2774 L
.52537 .2746 L
.53587 .2718 L
.54636 .269 L
.55685 .2662 L
Mistroke
.56734 .2634 L
.57783 .2606 L
.58833 .25781 L
.60174 .2517 L
.61162 .24701 L
.62151 .24232 L
.63139 .23762 L
.64127 .23293 L
.65115 .22824 L
.66104 .22355 L
.67092 .21886 L
.6808 .21417 L
.69068 .20948 L
.70057 .20478 L
.71045 .20009 L
.72033 .1954 L
.73021 .19071 L
.7401 .18602 L
.74998 .18133 L
.75986 .17664 L
.76974 .17194 L
.77963 .16725 L
.78951 .16256 L
.79939 .15787 L
.80927 .15318 L
.81915 .14849 L
.82904 .1438 L
.83892 .1391 L
.8488 .13441 L
.85868 .12972 L
.8687 .12543 L
.87945 .1234 L
.8902 .12137 L
.90094 .11934 L
.91169 .11731 L
.92244 .11528 L
.93319 .11325 L
.94394 .11122 L
.95469 .10919 L
.96544 .10716 L
.97619 .10512 L
Mfstroke
.05045 .19501 m
.06066 .19867 L
.07088 .20233 L
.08109 .20599 L
.0913 .20964 L
.10152 .2133 L
.11173 .21696 L
.12195 .22062 L
.13216 .22428 L
.14237 .22794 L
.15259 .2316 L
.1628 .23526 L
.17301 .23892 L
.18323 .24258 L
.19344 .24624 L
.20366 .2499 L
.21387 .25356 L
.21137 .23753 L
.22221 .23756 L
.23306 .23759 L
.24391 .23761 L
.25476 .23764 L
.26561 .23767 L
.27646 .2377 L
.28731 .23772 L
.29816 .23775 L
.30901 .23778 L
.31986 .23781 L
.33071 .23783 L
.32809 .25296 L
.33834 .2494 L
.34859 .24585 L
.35884 .24229 L
.36909 .23873 L
.37935 .23518 L
.3896 .23162 L
.39985 .22807 L
.4101 .22451 L
.42035 .22095 L
.4306 .2174 L
.44085 .21384 L
.4511 .21029 L
.46135 .20673 L
.4716 .20317 L
.48185 .19962 L
.49629 .19377 L
.50698 .19186 L
.51767 .18995 L
.52836 .18805 L
.53905 .18614 L
Mistroke
.54974 .18423 L
.56043 .18232 L
.57112 .18041 L
.57846 .18025 L
.58921 .17822 L
.59996 .17619 L
.61071 .17416 L
.62146 .17213 L
.63221 .1701 L
.64296 .16807 L
.65371 .16604 L
.66446 .16401 L
.67521 .16198 L
.68596 .15994 L
.69671 .15791 L
.70746 .15588 L
.71821 .15385 L
.72895 .15182 L
.7397 .14979 L
.75045 .14776 L
.7612 .14573 L
.77195 .1437 L
.7827 .14167 L
.79345 .13964 L
.8042 .13761 L
.81495 .13558 L
.8257 .13355 L
.83645 .13152 L
.8472 .12949 L
.85795 .12746 L
.86857 .12503 L
.87845 .12034 L
.88833 .11565 L
.89821 .11095 L
.9081 .10626 L
.91798 .10157 L
.92786 .09688 L
.93774 .09219 L
.94763 .0875 L
.95751 .08281 L
.96739 .07811 L
Mfstroke
.03713 .2316 m
.04732 .23531 L
.05752 .23902 L
.06772 .24273 L
.07791 .24644 L
.08811 .25016 L
.0983 .25387 L
.1085 .25758 L
.11869 .26129 L
.12889 .265 L
.13908 .26871 L
.14928 .27242 L
.15947 .27613 L
.16967 .27984 L
.17986 .28355 L
.19006 .28726 L
.20025 .29097 L
.2111 .29104 L
.22195 .2911 L
.2328 .29115 L
.24365 .29121 L
.2545 .29126 L
.26535 .29131 L
.2762 .29137 L
.28705 .29142 L
.2979 .29147 L
.30874 .29153 L
.31959 .29158 L
.33044 .29164 L
.34127 .29156 L
.35154 .28805 L
.36181 .28455 L
.37207 .28104 L
.38234 .27753 L
.39261 .27403 L
.40288 .27052 L
.41314 .26702 L
.42341 .26351 L
.43368 .26001 L
.44395 .2565 L
.45422 .25299 L
.46448 .24949 L
.47475 .24598 L
.48502 .24248 L
.49529 .23897 L
.50559 .23559 L
.51618 .23323 L
.52677 .23088 L
.53736 .22852 L
.54795 .22617 L
Mistroke
.55854 .22382 L
.56913 .22146 L
.57972 .21911 L
.5901 .21597 L
.60042 .21261 L
.61073 .20925 L
.62105 .20589 L
.63137 .20253 L
.64168 .19917 L
.652 .19581 L
.66231 .19245 L
.67263 .18909 L
.68295 .18573 L
.69326 .18236 L
.70358 .179 L
.71389 .17564 L
.72421 .17228 L
.73453 .16892 L
.74484 .16556 L
.75516 .1622 L
.76547 .15884 L
.77579 .15548 L
.7861 .15212 L
.79642 .14876 L
.80674 .14539 L
.81705 .14203 L
.82737 .13867 L
.83768 .13531 L
.848 .13195 L
.85832 .12859 L
.86863 .12523 L
.87895 .12187 L
.88926 .11851 L
.89958 .11515 L
.9099 .11179 L
.92021 .10842 L
.93053 .10506 L
.94084 .1017 L
.95116 .09834 L
.96147 .09498 L
.97179 .09162 L
Mfstroke
.03713 .2316 m
.04732 .23531 L
.05752 .23902 L
.06772 .24273 L
.07791 .24644 L
.08811 .25016 L
.0983 .25387 L
.1085 .25758 L
.11869 .26129 L
.12889 .265 L
.13908 .26871 L
.14928 .27242 L
.15947 .27613 L
.16967 .27984 L
.17986 .28355 L
.19006 .28726 L
.20025 .29097 L
.2111 .29104 L
.22195 .2911 L
.2328 .29115 L
.24365 .29121 L
.2545 .29126 L
.26535 .29131 L
.2762 .29137 L
.28705 .29142 L
.2979 .29147 L
.30874 .29153 L
.31959 .29158 L
.33044 .29164 L
.34127 .29156 L
.35154 .28805 L
.36181 .28455 L
.37207 .28104 L
.38234 .27753 L
.39261 .27403 L
.40288 .27052 L
.41314 .26702 L
.42341 .26351 L
.43368 .26001 L
.44395 .2565 L
.45422 .25299 L
.46448 .24949 L
.47475 .24598 L
.48502 .24248 L
.49529 .23897 L
.50559 .23559 L
.51618 .23323 L
.52677 .23088 L
.53736 .22852 L
.54795 .22617 L
Mistroke
.55854 .22382 L
.56913 .22146 L
.57972 .21911 L
.5901 .21597 L
.60042 .21261 L
.61073 .20925 L
.62105 .20589 L
.63137 .20253 L
.64168 .19917 L
.652 .19581 L
.66231 .19245 L
.67263 .18909 L
.68295 .18573 L
.69326 .18236 L
.70358 .179 L
.71389 .17564 L
.72421 .17228 L
.73453 .16892 L
.74484 .16556 L
.75516 .1622 L
.76547 .15884 L
.77579 .15548 L
.7861 .15212 L
.79642 .14876 L
.80674 .14539 L
.81705 .14203 L
.82737 .13867 L
.83768 .13531 L
.848 .13195 L
.85832 .12859 L
.86863 .12523 L
.87895 .12187 L
.88926 .11851 L
.89958 .11515 L
.9099 .11179 L
.92021 .10842 L
.93053 .10506 L
.94084 .1017 L
.95116 .09834 L
.96147 .09498 L
.97179 .09162 L
Mfstroke
0 0 0 r
.03713 .2316 m
.2003 .29099 L
s
% Start of user PostScript
0 0 20.9492 7.6249 MAarrowhead1
% End of user PostScript
.2003 .29099 m
.34089 .29169 L
s
% Start of user PostScript
20.9492 7.6249 38.9991 7.71439 MAarrowhead1
% End of user PostScript
.34089 .29169 m
.50449 .23583 L
s
% Start of user PostScript
38.9991 7.71439 60.0033 0.543142 MAarrowhead1
% End of user PostScript
.50449 .23583 m
.58211 .21858 L
s
% Start of user PostScript
60.0033 0.543142 69.9689 -1.67189 MAarrowhead1
% End of user PostScript
.58211 .21858 m
.97179 .09162 L
s
% Start of user PostScript
69.9689 -1.67189 120. -17.9721 MAarrowhead1
% End of user PostScript
.97179 .09162 m
.97179 .09162 L
s
% Start of user PostScript
120. -17.9721 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.04898 .19861 m
.0482 .20082 L
.04741 .20302 L
.04663 .20522 L
.04585 .20742 L
.04506 .20962 L
.04427 .21182 L
.04348 .21402 L
.04269 .21622 L
.0419 .21842 L
.04111 .22062 L
.04032 .22281 L
.03952 .22501 L
.03873 .22721 L
.03793 .22941 L
.03713 .2316 L
.03633 .2338 L
.03553 .23599 L
.03473 .23819 L
.03392 .24038 L
.03312 .24257 L
.03231 .24477 L
.0315 .24696 L
.0307 .24915 L
.02989 .25134 L
.02908 .25354 L
.02826 .25573 L
.02745 .25792 L
.02664 .26011 L
.02582 .2623 L
.025 .26449 L
s
.0643 .20411 m
.06351 .20632 L
.06273 .20853 L
.06194 .21073 L
.06116 .21294 L
.06037 .21514 L
.05958 .21735 L
.05879 .21955 L
.058 .22175 L
.0572 .22396 L
.05641 .22616 L
.05562 .22836 L
.05482 .23056 L
.05402 .23277 L
.05322 .23497 L
.05242 .23717 L
.05162 .23937 L
.05082 .24157 L
.05001 .24377 L
.04921 .24597 L
.0484 .24816 L
.04759 .25036 L
.04679 .25256 L
.04598 .25476 L
.04516 .25695 L
.04435 .25915 L
.04354 .26134 L
.04272 .26354 L
.04191 .26573 L
.04109 .26793 L
.04027 .27012 L
s
.07961 .20961 m
.07883 .21182 L
.07804 .21403 L
.07726 .21624 L
.07647 .21845 L
.07568 .22066 L
.07489 .22287 L
.0741 .22508 L
.0733 .22729 L
.07251 .2295 L
.07171 .2317 L
.07092 .23391 L
.07012 .23612 L
.06932 .23832 L
.06852 .24053 L
.06772 .24273 L
.06691 .24494 L
.06611 .24714 L
.0653 .24935 L
.06449 .25155 L
.06369 .25375 L
.06288 .25595 L
.06207 .25816 L
.06126 .26036 L
.06044 .26256 L
.05963 .26476 L
.05881 .26696 L
.058 .26916 L
.05718 .27136 L
.05636 .27356 L
.05554 .27576 L
s
.09493 .21511 m
.09414 .21732 L
.09336 .21954 L
.09257 .22175 L
.09178 .22397 L
.09099 .22618 L
.0902 .2284 L
.0894 .23061 L
.08861 .23282 L
.08781 .23503 L
.08701 .23725 L
.08621 .23946 L
.08541 .24167 L
.08461 .24388 L
.08381 .24609 L
.08301 .2483 L
.0822 .25051 L
.0814 .25272 L
.08059 .25493 L
.07978 .25713 L
.07897 .25934 L
.07816 .26155 L
.07735 .26376 L
.07653 .26596 L
.07572 .26817 L
.0749 .27037 L
.07409 .27258 L
.07327 .27478 L
.07245 .27698 L
.07163 .27919 L
.0708 .28139 L
s
.11025 .2206 m
.10946 .22282 L
.10867 .22504 L
.10788 .22726 L
.10709 .22948 L
.1063 .2317 L
.1055 .23392 L
.10471 .23614 L
.10391 .23836 L
.10311 .24057 L
.10231 .24279 L
.10151 .24501 L
.10071 .24722 L
.09991 .24944 L
.09911 .25165 L
.0983 .25387 L
.09749 .25608 L
.09669 .25829 L
.09588 .26051 L
.09507 .26272 L
.09426 .26493 L
.09344 .26714 L
.09263 .26935 L
.09181 .27156 L
.091 .27377 L
.09018 .27598 L
.08936 .27819 L
.08854 .2804 L
.08772 .28261 L
.0869 .28482 L
.08607 .28703 L
s
.12557 .2261 m
.12478 .22833 L
.12399 .23055 L
.12319 .23278 L
.1224 .235 L
.12161 .23722 L
.12081 .23945 L
.12001 .24167 L
.11922 .24389 L
.11842 .24611 L
.11762 .24833 L
.11681 .25055 L
.11601 .25277 L
.11521 .25499 L
.1144 .25721 L
.11359 .25943 L
.11279 .26165 L
.11198 .26387 L
.11117 .26609 L
.11035 .2683 L
.10954 .27052 L
.10873 .27274 L
.10791 .27495 L
.10709 .27717 L
.10628 .27938 L
.10546 .2816 L
.10464 .28381 L
.10381 .28602 L
.10299 .28824 L
.10217 .29045 L
.10134 .29266 L
s
.14088 .2316 m
.14009 .23383 L
.1393 .23606 L
.13851 .23829 L
.13771 .24051 L
.13692 .24274 L
.13612 .24497 L
.13532 .2472 L
.13452 .24942 L
.13372 .25165 L
.13292 .25388 L
.13211 .2561 L
.13131 .25833 L
.1305 .26055 L
.1297 .26277 L
.12889 .265 L
.12808 .26722 L
.12727 .26944 L
.12645 .27167 L
.12564 .27389 L
.12482 .27611 L
.12401 .27833 L
.12319 .28055 L
.12237 .28277 L
.12155 .28499 L
.12073 .28721 L
.11991 .28943 L
.11909 .29164 L
.11826 .29386 L
.11743 .29608 L
.11661 .2983 L
s
.1562 .2371 m
.15541 .23933 L
.15461 .24156 L
.15382 .2438 L
.15302 .24603 L
.15223 .24826 L
.15143 .2505 L
.15063 .25273 L
.14982 .25496 L
.14902 .25719 L
.14822 .25942 L
.14741 .26165 L
.14661 .26388 L
.1458 .26611 L
.14499 .26834 L
.14418 .27056 L
.14337 .27279 L
.14256 .27502 L
.14174 .27725 L
.14093 .27947 L
.14011 .2817 L
.13929 .28392 L
.13847 .28615 L
.13765 .28837 L
.13683 .2906 L
.13601 .29282 L
.13518 .29504 L
.13436 .29727 L
.13353 .29949 L
.1327 .30171 L
.13188 .30393 L
s
.17152 .24259 m
.17072 .24483 L
.16993 .24707 L
.16913 .24931 L
.16833 .25155 L
.16753 .25378 L
.16673 .25602 L
.16593 .25826 L
.16513 .26049 L
.16433 .26273 L
.16352 .26496 L
.16271 .2672 L
.1619 .26943 L
.16109 .27166 L
.16028 .2739 L
.15947 .27613 L
.15866 .27836 L
.15784 .28059 L
.15703 .28283 L
.15621 .28506 L
.15539 .28729 L
.15457 .28952 L
.15375 .29175 L
.15293 .29398 L
.15211 .2962 L
.15128 .29843 L
.15046 .30066 L
.14963 .30289 L
.1488 .30511 L
.14797 .30734 L
.14714 .30957 L
s
.18684 .24809 m
.18604 .25033 L
.18524 .25258 L
.18445 .25482 L
.18365 .25706 L
.18284 .2593 L
.18204 .26154 L
.18124 .26379 L
.18043 .26603 L
.17963 .26827 L
.17882 .27051 L
.17801 .27274 L
.1772 .27498 L
.17639 .27722 L
.17558 .27946 L
.17477 .2817 L
.17395 .28393 L
.17313 .28617 L
.17232 .28841 L
.1715 .29064 L
.17068 .29288 L
.16986 .29511 L
.16903 .29734 L
.16821 .29958 L
.16739 .30181 L
.16656 .30404 L
.16573 .30628 L
.1649 .30851 L
.16407 .31074 L
.16324 .31297 L
.16241 .3152 L
s
.20215 .25359 m
.20136 .25584 L
.20056 .25808 L
.19976 .26033 L
.19896 .26258 L
.19815 .26482 L
.19735 .26707 L
.19654 .26932 L
.19574 .27156 L
.19493 .2738 L
.19412 .27605 L
.19331 .27829 L
.1925 .28054 L
.19169 .28278 L
.19087 .28502 L
.19006 .28726 L
.18924 .2895 L
.18842 .29175 L
.1876 .29399 L
.18678 .29623 L
.18596 .29847 L
.18514 .3007 L
.18432 .30294 L
.18349 .30518 L
.18266 .30742 L
.18184 .30966 L
.18101 .31189 L
.18018 .31413 L
.17934 .31636 L
.17851 .3186 L
.17768 .32084 L
s
.20585 .24287 m
.20584 .24608 L
.20583 .24929 L
.20582 .2525 L
.20581 .25571 L
.20581 .25892 L
.20579 .26213 L
.20578 .26534 L
.20577 .26855 L
.20576 .27176 L
.20575 .27497 L
.20573 .27818 L
.20572 .28139 L
.20571 .2846 L
.20569 .28781 L
.20568 .29102 L
.20566 .29423 L
.20564 .29744 L
.20562 .30065 L
.20561 .30386 L
.20559 .30707 L
.20557 .31028 L
.20555 .31349 L
.20553 .3167 L
.20551 .31991 L
.20549 .32312 L
.20546 .32633 L
.20544 .32954 L
.20542 .33274 L
.2054 .33595 L
.20537 .33916 L
s
.22212 .24291 m
.22212 .24613 L
.22211 .24934 L
.2221 .25255 L
.22209 .25576 L
.22208 .25898 L
.22207 .26219 L
.22206 .2654 L
.22205 .26861 L
.22203 .27182 L
.22202 .27504 L
.22201 .27825 L
.22199 .28146 L
.22198 .28467 L
.22197 .28789 L
.22195 .2911 L
.22193 .29431 L
.22192 .29752 L
.2219 .30073 L
.22188 .30395 L
.22186 .30716 L
.22184 .31037 L
.22182 .31358 L
.2218 .3168 L
.22178 .32001 L
.22176 .32322 L
.22174 .32643 L
.22172 .32964 L
.22169 .33286 L
.22167 .33607 L
.22164 .33928 L
s
.2384 .24296 m
.23839 .24617 L
.23838 .24939 L
.23837 .2526 L
.23836 .25582 L
.23835 .25903 L
.23834 .26225 L
.23833 .26546 L
.23832 .26868 L
.23831 .27189 L
.2383 .27511 L
.23828 .27832 L
.23827 .28153 L
.23825 .28475 L
.23824 .28796 L
.23822 .29118 L
.23821 .29439 L
.23819 .29761 L
.23817 .30082 L
.23816 .30404 L
.23814 .30725 L
.23812 .31047 L
.2381 .31368 L
.23808 .3169 L
.23806 .32011 L
.23803 .32332 L
.23801 .32654 L
.23799 .32975 L
.23797 .33297 L
.23794 .33618 L
.23792 .3394 L
s
.25467 .243 m
.25466 .24622 L
.25466 .24944 L
.25465 .25265 L
.25464 .25587 L
.25463 .25909 L
.25462 .26231 L
.25461 .26552 L
.2546 .26874 L
.25458 .27196 L
.25457 .27517 L
.25456 .27839 L
.25454 .28161 L
.25453 .28483 L
.25451 .28804 L
.2545 .29126 L
.25448 .29448 L
.25446 .29769 L
.25445 .30091 L
.25443 .30413 L
.25441 .30734 L
.25439 .31056 L
.25437 .31378 L
.25435 .317 L
.25433 .32021 L
.25431 .32343 L
.25429 .32665 L
.25426 .32986 L
.25424 .33308 L
.25422 .3363 L
.25419 .33951 L
s
.27095 .24305 m
.27094 .24627 L
.27093 .24949 L
.27092 .25271 L
.27091 .25593 L
.2709 .25915 L
.27089 .26236 L
.27088 .26558 L
.27087 .2688 L
.27086 .27202 L
.27084 .27524 L
.27083 .27846 L
.27082 .28168 L
.2708 .2849 L
.27079 .28812 L
.27077 .29134 L
.27076 .29456 L
.27074 .29778 L
.27072 .301 L
.2707 .30422 L
.27068 .30744 L
.27067 .31066 L
.27065 .31388 L
.27063 .3171 L
.2706 .32031 L
.27058 .32353 L
.27056 .32675 L
.27054 .32997 L
.27051 .33319 L
.27049 .33641 L
.27047 .33963 L
s
.28722 .24309 m
.28721 .24631 L
.2872 .24954 L
.2872 .25276 L
.28719 .25598 L
.28718 .2592 L
.28717 .26242 L
.28716 .26565 L
.28714 .26887 L
.28713 .27209 L
.28712 .27531 L
.28711 .27853 L
.28709 .28176 L
.28708 .28498 L
.28706 .2882 L
.28705 .29142 L
.28703 .29464 L
.28701 .29786 L
.287 .30109 L
.28698 .30431 L
.28696 .30753 L
.28694 .31075 L
.28692 .31397 L
.2869 .31719 L
.28688 .32042 L
.28686 .32364 L
.28683 .32686 L
.28681 .33008 L
.28679 .3333 L
.28677 .33653 L
.28674 .33975 L
s
.30349 .24314 m
.30349 .24636 L
.30348 .24959 L
.30347 .25281 L
.30346 .25603 L
.30345 .25926 L
.30344 .26248 L
.30343 .26571 L
.30342 .26893 L
.30341 .27216 L
.30339 .27538 L
.30338 .2786 L
.30337 .28183 L
.30335 .28505 L
.30334 .28828 L
.30332 .2915 L
.3033 .29473 L
.30329 .29795 L
.30327 .30117 L
.30325 .3044 L
.30323 .30762 L
.30321 .31085 L
.30319 .31407 L
.30317 .31729 L
.30315 .32052 L
.30313 .32374 L
.30311 .32697 L
.30309 .33019 L
.30306 .33342 L
.30304 .33664 L
.30301 .33986 L
s
.31977 .24318 m
.31976 .24641 L
.31975 .24964 L
.31974 .25286 L
.31973 .25609 L
.31973 .25932 L
.31971 .26254 L
.3197 .26577 L
.31969 .269 L
.31968 .27222 L
.31967 .27545 L
.31965 .27868 L
.31964 .2819 L
.31963 .28513 L
.31961 .28836 L
.31959 .29158 L
.31958 .29481 L
.31956 .29804 L
.31954 .30126 L
.31953 .30449 L
.31951 .30771 L
.31949 .31094 L
.31947 .31417 L
.31945 .31739 L
.31943 .32062 L
.31941 .32385 L
.31938 .32707 L
.31936 .3303 L
.31934 .33353 L
.31931 .33675 L
.31929 .33998 L
s
.33604 .24323 m
.33604 .24646 L
.33603 .24969 L
.33602 .25291 L
.33601 .25614 L
.336 .25937 L
.33599 .2626 L
.33598 .26583 L
.33597 .26906 L
.33595 .27229 L
.33594 .27552 L
.33593 .27875 L
.33591 .28198 L
.3359 .2852 L
.33588 .28843 L
.33587 .29166 L
.33585 .29489 L
.33584 .29812 L
.33582 .30135 L
.3358 .30458 L
.33578 .30781 L
.33576 .31104 L
.33574 .31427 L
.33572 .31749 L
.3357 .32072 L
.33568 .32395 L
.33566 .32718 L
.33563 .33041 L
.33561 .33364 L
.33559 .33687 L
.33556 .3401 L
s
.33952 .25332 m
.34033 .25563 L
.34114 .25794 L
.34195 .26025 L
.34275 .26257 L
.34356 .26488 L
.34436 .2672 L
.34516 .26951 L
.34597 .27183 L
.34677 .27414 L
.34756 .27646 L
.34836 .27878 L
.34916 .2811 L
.34995 .28341 L
.35075 .28573 L
.35154 .28805 L
.35233 .29037 L
.35312 .29269 L
.35391 .29501 L
.3547 .29733 L
.35548 .29965 L
.35627 .30197 L
.35705 .30429 L
.35783 .30662 L
.35861 .30894 L
.35939 .31126 L
.36017 .31359 L
.36095 .31591 L
.36172 .31823 L
.3625 .32056 L
.36327 .32288 L
s
.3549 .24799 m
.35571 .25031 L
.35652 .25262 L
.35733 .25494 L
.35814 .25726 L
.35894 .25958 L
.35975 .2619 L
.36055 .26422 L
.36136 .26654 L
.36216 .26886 L
.36296 .27118 L
.36376 .2735 L
.36455 .27582 L
.36535 .27815 L
.36615 .28047 L
.36694 .28279 L
.36773 .28512 L
.36852 .28744 L
.36931 .28976 L
.3701 .29209 L
.37089 .29442 L
.37168 .29674 L
.37246 .29907 L
.37325 .30139 L
.37403 .30372 L
.37481 .30605 L
.37559 .30838 L
.37637 .31071 L
.37714 .31303 L
.37792 .31536 L
.37869 .31769 L
s
.37027 .24266 m
.37109 .24498 L
.3719 .24731 L
.37271 .24963 L
.37352 .25195 L
.37433 .25428 L
.37514 .2566 L
.37594 .25892 L
.37675 .26125 L
.37755 .26357 L
.37835 .2659 L
.37915 .26823 L
.37995 .27055 L
.38075 .27288 L
.38155 .27521 L
.38234 .27753 L
.38314 .27986 L
.38393 .28219 L
.38472 .28452 L
.38551 .28685 L
.3863 .28918 L
.38709 .29151 L
.38787 .29384 L
.38866 .29617 L
.38944 .2985 L
.39023 .30084 L
.39101 .30317 L
.39179 .3055 L
.39257 .30784 L
.39334 .31017 L
.39412 .3125 L
s
.38565 .23734 m
.38647 .23966 L
.38728 .24199 L
.38809 .24432 L
.38891 .24664 L
.38972 .24897 L
.39052 .2513 L
.39133 .25363 L
.39214 .25596 L
.39294 .25829 L
.39375 .26062 L
.39455 .26295 L
.39535 .26528 L
.39615 .26761 L
.39695 .26994 L
.39774 .27228 L
.39854 .27461 L
.39933 .27694 L
.40013 .27928 L
.40092 .28161 L
.40171 .28394 L
.4025 .28628 L
.40329 .28861 L
.40407 .29095 L
.40486 .29329 L
.40564 .29562 L
.40643 .29796 L
.40721 .3003 L
.40799 .30264 L
.40877 .30497 L
.40954 .30731 L
s
.40103 .23201 m
.40185 .23434 L
.40266 .23667 L
.40348 .239 L
.40429 .24134 L
.4051 .24367 L
.40591 .246 L
.40672 .24833 L
.40753 .25067 L
.40833 .253 L
.40914 .25534 L
.40994 .25767 L
.41075 .26001 L
.41155 .26234 L
.41235 .26468 L
.41314 .26702 L
.41394 .26935 L
.41474 .27169 L
.41553 .27403 L
.41633 .27637 L
.41712 .27871 L
.41791 .28105 L
.4187 .28339 L
.41949 .28573 L
.42027 .28807 L
.42106 .29041 L
.42184 .29275 L
.42263 .29509 L
.42341 .29744 L
.42419 .29978 L
.42497 .30212 L
s
.41641 .22668 m
.41723 .22902 L
.41804 .23135 L
.41886 .23369 L
.41967 .23603 L
.42049 .23836 L
.4213 .2407 L
.42211 .24304 L
.42292 .24538 L
.42373 .24772 L
.42453 .25006 L
.42534 .2524 L
.42614 .25474 L
.42694 .25708 L
.42775 .25942 L
.42855 .26176 L
.42935 .2641 L
.43014 .26644 L
.43094 .26879 L
.43173 .27113 L
.43253 .27347 L
.43332 .27582 L
.43411 .27816 L
.4349 .28051 L
.43569 .28285 L
.43648 .2852 L
.43726 .28754 L
.43805 .28989 L
.43883 .29224 L
.43961 .29459 L
.44039 .29693 L
s
.43179 .22136 m
.43261 .2237 L
.43342 .22604 L
.43424 .22838 L
.43506 .23072 L
.43587 .23306 L
.43669 .2354 L
.4375 .23775 L
.43831 .24009 L
.43912 .24243 L
.43993 .24478 L
.44073 .24712 L
.44154 .24946 L
.44234 .25181 L
.44315 .25415 L
.44395 .2565 L
.44475 .25885 L
.44555 .26119 L
.44635 .26354 L
.44714 .26589 L
.44794 .26824 L
.44873 .27059 L
.44952 .27293 L
.45031 .27528 L
.4511 .27763 L
.45189 .27998 L
.45268 .28234 L
.45347 .28469 L
.45425 .28704 L
.45503 .28939 L
.45582 .29174 L
s
.44716 .21603 m
.44799 .21838 L
.44881 .22072 L
.44962 .22307 L
.45044 .22541 L
.45126 .22776 L
.45207 .2301 L
.45289 .23245 L
.4537 .2348 L
.45451 .23715 L
.45532 .23949 L
.45613 .24184 L
.45694 .24419 L
.45774 .24654 L
.45855 .24889 L
.45935 .25124 L
.46015 .25359 L
.46095 .25594 L
.46175 .2583 L
.46255 .26065 L
.46335 .263 L
.46414 .26535 L
.46494 .26771 L
.46573 .27006 L
.46652 .27242 L
.46731 .27477 L
.4681 .27713 L
.46889 .27948 L
.46967 .28184 L
.47046 .2842 L
.47124 .28655 L
s
.46254 .21071 m
.46337 .21305 L
.46419 .2154 L
.46501 .21775 L
.46583 .2201 L
.46664 .22245 L
.46746 .2248 L
.46828 .22716 L
.46909 .22951 L
.4699 .23186 L
.47071 .23421 L
.47152 .23657 L
.47233 .23892 L
.47314 .24127 L
.47395 .24363 L
.47475 .24598 L
.47555 .24834 L
.47636 .2507 L
.47716 .25305 L
.47796 .25541 L
.47876 .25777 L
.47955 .26012 L
.48035 .26248 L
.48114 .26484 L
.48194 .2672 L
.48273 .26956 L
.48352 .27192 L
.48431 .27428 L
.48509 .27664 L
.48588 .279 L
.48667 .28136 L
s
.47792 .20538 m
.47874 .20773 L
.47957 .21009 L
.48039 .21244 L
.48121 .21479 L
.48203 .21715 L
.48285 .21951 L
.48366 .22186 L
.48448 .22422 L
.48529 .22657 L
.48611 .22893 L
.48692 .23129 L
.48773 .23365 L
.48854 .23601 L
.48935 .23837 L
.49015 .24073 L
.49096 .24309 L
.49176 .24545 L
.49256 .24781 L
.49336 .25017 L
.49416 .25253 L
.49496 .25489 L
.49576 .25725 L
.49656 .25962 L
.49735 .26198 L
.49814 .26435 L
.49894 .26671 L
.49973 .26908 L
.50052 .27144 L
.5013 .27381 L
.50209 .27617 L
s
.4981 .19776 m
.49855 .20029 L
.499 .20282 L
.49946 .20535 L
.49993 .20788 L
.5004 .21041 L
.50089 .21294 L
.50138 .21546 L
.50188 .21798 L
.50238 .2205 L
.5029 .22302 L
.50342 .22554 L
.50395 .22805 L
.50449 .23057 L
.50503 .23308 L
.50559 .23559 L
.50615 .23809 L
.50672 .2406 L
.5073 .24311 L
.50788 .24561 L
.50847 .24811 L
.50907 .25061 L
.50968 .25311 L
.5103 .2556 L
.51092 .2581 L
.51156 .26059 L
.5122 .26308 L
.51284 .26557 L
.5135 .26806 L
.51416 .27054 L
.51483 .27302 L
s
.51411 .19483 m
.51455 .19732 L
.51499 .19982 L
.51544 .20231 L
.5159 .20479 L
.51637 .20728 L
.51685 .20977 L
.51733 .21225 L
.51782 .21473 L
.51832 .21721 L
.51883 .21969 L
.51934 .22217 L
.51986 .22464 L
.52039 .22711 L
.52093 .22959 L
.52147 .23206 L
.52203 .23452 L
.52259 .23699 L
.52315 .23945 L
.52373 .24192 L
.52431 .24438 L
.52491 .24684 L
.5255 .2493 L
.52611 .25175 L
.52672 .25421 L
.52735 .25666 L
.52798 .25911 L
.52861 .26156 L
.52926 .26401 L
.52991 .26645 L
.53057 .2689 L
s
.53012 .1919 m
.53055 .19436 L
.53098 .19681 L
.53143 .19926 L
.53188 .20171 L
.53234 .20415 L
.53281 .2066 L
.53328 .20904 L
.53377 .21148 L
.53426 .21392 L
.53476 .21636 L
.53526 .2188 L
.53578 .22123 L
.5363 .22366 L
.53682 .2261 L
.53736 .22852 L
.5379 .23095 L
.53846 .23338 L
.53901 .2358 L
.53958 .23823 L
.54015 .24065 L
.54074 .24307 L
.54133 .24548 L
.54192 .2479 L
.54253 .25031 L
.54314 .25273 L
.54376 .25514 L
.54438 .25755 L
.54502 .25996 L
.54566 .26236 L
.54631 .26477 L
s
.54612 .18898 m
.54655 .19139 L
.54698 .1938 L
.54741 .19621 L
.54786 .19862 L
.54831 .20102 L
.54877 .20343 L
.54924 .20583 L
.54971 .20823 L
.5502 .21063 L
.55069 .21303 L
.55118 .21543 L
.55169 .21782 L
.5522 .22021 L
.55272 .2226 L
.55325 .22499 L
.55378 .22738 L
.55432 .22977 L
.55487 .23215 L
.55543 .23453 L
.556 .23692 L
.55657 .2393 L
.55715 .24167 L
.55773 .24405 L
.55833 .24642 L
.55893 .2488 L
.55954 .25117 L
.56016 .25354 L
.56078 .25591 L
.56141 .25827 L
.56205 .26064 L
s
.56213 .18605 m
.56254 .18842 L
.56297 .19079 L
.5634 .19316 L
.56384 .19553 L
.56428 .1979 L
.56473 .20026 L
.56519 .20262 L
.56566 .20498 L
.56613 .20734 L
.56662 .2097 L
.5671 .21206 L
.5676 .21441 L
.5681 .21676 L
.56862 .21911 L
.56913 .22146 L
.56966 .22381 L
.57019 .22616 L
.57073 .2285 L
.57128 .23084 L
.57184 .23318 L
.5724 .23552 L
.57297 .23786 L
.57354 .2402 L
.57413 .24253 L
.57472 .24487 L
.57532 .2472 L
.57593 .24953 L
.57654 .25186 L
.57716 .25418 L
.57779 .25651 L
s
.57785 .18374 m
.5781 .18607 L
.57838 .1884 L
.57869 .19071 L
.57904 .19301 L
.57942 .1953 L
.57983 .19758 L
.58027 .19986 L
.58074 .20212 L
.58125 .20437 L
.58178 .20661 L
.58235 .20884 L
.58295 .21106 L
.58359 .21327 L
.58425 .21547 L
.58494 .21765 L
.58567 .21983 L
.58643 .222 L
.58722 .22416 L
.58804 .22631 L
.5889 .22844 L
.58978 .23057 L
.5907 .23268 L
.59165 .23479 L
.59263 .23689 L
.59365 .23897 L
.59469 .24105 L
.59577 .24311 L
.59688 .24516 L
.59802 .24721 L
.59919 .24924 L
s
.59371 .18056 m
.59395 .18276 L
.59421 .18496 L
.59451 .18714 L
.59484 .18932 L
.5952 .19149 L
.59558 .19364 L
.596 .19579 L
.59645 .19793 L
.59692 .20005 L
.59743 .20217 L
.59797 .20428 L
.59854 .20638 L
.59913 .20847 L
.59976 .21054 L
.60042 .21261 L
.60111 .21467 L
.60182 .21672 L
.60257 .21876 L
.60335 .22079 L
.60416 .22281 L
.60499 .22482 L
.60586 .22682 L
.60676 .22881 L
.60769 .23079 L
.60864 .23276 L
.60963 .23472 L
.61065 .23667 L
.6117 .23861 L
.61277 .24055 L
.61388 .24247 L
s
.60957 .17738 m
.6098 .17945 L
.61005 .18152 L
.61033 .18358 L
.61064 .18563 L
.61097 .18767 L
.61134 .1897 L
.61173 .19173 L
.61215 .19374 L
.6126 .19574 L
.61308 .19774 L
.61359 .19972 L
.61412 .2017 L
.61468 .20367 L
.61527 .20562 L
.61589 .20757 L
.61654 .20951 L
.61722 .21144 L
.61792 .21336 L
.61865 .21527 L
.61941 .21718 L
.6202 .21907 L
.62102 .22095 L
.62186 .22283 L
.62274 .22469 L
.62364 .22655 L
.62457 .2284 L
.62553 .23024 L
.62651 .23206 L
.62753 .23388 L
.62857 .23569 L
s
.62544 .17419 m
.62565 .17614 L
.62588 .17809 L
.62614 .18002 L
.62643 .18194 L
.62675 .18386 L
.62709 .18576 L
.62746 .18766 L
.62786 .18955 L
.62828 .19143 L
.62873 .1933 L
.6292 .19516 L
.6297 .19702 L
.63023 .19886 L
.63079 .2007 L
.63137 .20253 L
.63197 .20435 L
.63261 .20616 L
.63327 .20796 L
.63396 .20976 L
.63467 .21154 L
.63541 .21332 L
.63618 .21509 L
.63697 .21685 L
.63779 .2186 L
.63864 .22034 L
.63951 .22207 L
.64041 .2238 L
.64133 .22551 L
.64229 .22722 L
.64327 .22892 L
s
.6413 .17101 m
.64149 .17284 L
.64172 .17465 L
.64196 .17645 L
.64223 .17825 L
.64253 .18004 L
.64285 .18182 L
.64319 .18359 L
.64356 .18536 L
.64395 .18712 L
.64437 .18887 L
.64482 .19061 L
.64529 .19234 L
.64578 .19406 L
.6463 .19578 L
.64684 .19749 L
.64741 .19919 L
.648 .20088 L
.64862 .20257 L
.64926 .20424 L
.64993 .20591 L
.65062 .20757 L
.65133 .20922 L
.65208 .21087 L
.65284 .2125 L
.65363 .21413 L
.65445 .21575 L
.65529 .21736 L
.65615 .21896 L
.65704 .22056 L
.65796 .22215 L
s
.65716 .16783 m
.65734 .16953 L
.65755 .17121 L
.65778 .17289 L
.65803 .17456 L
.6583 .17623 L
.6586 .17788 L
.65892 .17953 L
.65926 .18117 L
.65963 .1828 L
.66002 .18443 L
.66043 .18605 L
.66087 .18766 L
.66133 .18926 L
.66181 .19086 L
.66231 .19245 L
.66284 .19403 L
.66339 .1956 L
.66397 .19717 L
.66456 .19873 L
.66518 .20028 L
.66583 .20182 L
.66649 .20336 L
.66718 .20488 L
.66789 .20641 L
.66863 .20792 L
.66939 .20942 L
.67017 .21092 L
.67097 .21241 L
.6718 .2139 L
.67265 .21537 L
s
.67303 .16465 m
.67319 .16622 L
.67338 .16778 L
.67359 .16933 L
.67383 .17087 L
.67408 .17241 L
.67436 .17394 L
.67465 .17546 L
.67497 .17698 L
.67531 .17849 L
.67567 .17999 L
.67605 .18149 L
.67645 .18298 L
.67688 .18446 L
.67732 .18594 L
.67779 .18741 L
.67828 .18887 L
.67878 .19032 L
.67932 .19177 L
.67987 .19321 L
.68044 .19464 L
.68103 .19607 L
.68165 .19749 L
.68229 .1989 L
.68295 .20031 L
.68363 .20171 L
.68433 .2031 L
.68505 .20449 L
.68579 .20586 L
.68656 .20723 L
.68734 .2086 L
s
.68889 .16147 m
.68904 .16291 L
.68922 .16434 L
.68941 .16576 L
.68962 .16718 L
.68986 .16859 L
.69011 .17 L
.69038 .1714 L
.69067 .17279 L
.69098 .17418 L
.69131 .17556 L
.69167 .17693 L
.69203 .1783 L
.69242 .17966 L
.69283 .18102 L
.69326 .18236 L
.69371 .18371 L
.69418 .18504 L
.69466 .18637 L
.69517 .18769 L
.6957 .18901 L
.69624 .19032 L
.69681 .19162 L
.69739 .19292 L
.698 .19421 L
.69862 .1955 L
.69927 .19678 L
.69993 .19805 L
.70061 .19931 L
.70131 .20057 L
.70204 .20183 L
s
.70475 .15829 m
.70489 .1596 L
.70505 .1609 L
.70523 .1622 L
.70542 .16349 L
.70563 .16478 L
.70586 .16606 L
.70611 .16733 L
.70638 .1686 L
.70666 .16987 L
.70696 .17112 L
.70728 .17237 L
.70762 .17362 L
.70797 .17486 L
.70835 .17609 L
.70874 .17732 L
.70914 .17855 L
.70957 .17976 L
.71001 .18097 L
.71047 .18218 L
.71095 .18338 L
.71145 .18457 L
.71197 .18576 L
.7125 .18694 L
.71305 .18812 L
.71362 .18929 L
.71421 .19045 L
.71481 .19161 L
.71543 .19276 L
.71607 .19391 L
.71673 .19505 L
s
.72061 .15511 m
.72074 .15629 L
.72088 .15747 L
.72104 .15864 L
.72122 .1598 L
.72141 .16096 L
.72162 .16212 L
.72184 .16327 L
.72208 .16441 L
.72234 .16555 L
.72261 .16669 L
.7229 .16782 L
.7232 .16894 L
.72352 .17006 L
.72386 .17117 L
.72421 .17228 L
.72458 .17338 L
.72496 .17448 L
.72536 .17558 L
.72578 .17666 L
.72621 .17774 L
.72666 .17882 L
.72712 .17989 L
.72761 .18096 L
.7281 .18202 L
.72862 .18308 L
.72914 .18413 L
.72969 .18517 L
.73025 .18621 L
.73083 .18725 L
.73142 .18828 L
s
.73648 .15193 m
.73659 .15298 L
.73672 .15403 L
.73686 .15507 L
.73702 .15611 L
.73719 .15715 L
.73737 .15818 L
.73757 .1592 L
.73779 .16022 L
.73801 .16124 L
.73826 .16225 L
.73851 .16326 L
.73878 .16426 L
.73907 .16526 L
.73937 .16625 L
.73968 .16724 L
.74001 .16822 L
.74035 .1692 L
.74071 .17018 L
.74108 .17115 L
.74147 .17211 L
.74187 .17307 L
.74228 .17403 L
.74271 .17498 L
.74315 .17592 L
.74361 .17687 L
.74408 .1778 L
.74457 .17874 L
.74507 .17966 L
.74559 .18059 L
.74611 .1815 L
s
.75234 .14874 m
.75244 .14967 L
.75255 .15059 L
.75268 .15151 L
.75281 .15242 L
.75296 .15333 L
.75313 .15424 L
.7533 .15514 L
.75349 .15604 L
.75369 .15693 L
.7539 .15782 L
.75413 .1587 L
.75437 .15958 L
.75462 .16046 L
.75488 .16133 L
.75516 .1622 L
.75545 .16306 L
.75575 .16392 L
.75606 .16478 L
.75639 .16563 L
.75673 .16648 L
.75708 .16732 L
.75744 .16816 L
.75782 .169 L
.75821 .16983 L
.75861 .17066 L
.75902 .17148 L
.75945 .1723 L
.75989 .17311 L
.76034 .17392 L
.76081 .17473 L
s
.7682 .14556 m
.76829 .14636 L
.76839 .14716 L
.76849 .14795 L
.76861 .14873 L
.76874 .14952 L
.76888 .1503 L
.76903 .15107 L
.76919 .15185 L
.76937 .15262 L
.76955 .15338 L
.76974 .15414 L
.76995 .1549 L
.77017 .15566 L
.77039 .15641 L
.77063 .15716 L
.77088 .1579 L
.77114 .15864 L
.77141 .15938 L
.77169 .16012 L
.77198 .16085 L
.77229 .16157 L
.7726 .1623 L
.77292 .16302 L
.77326 .16373 L
.77361 .16445 L
.77396 .16515 L
.77433 .16586 L
.77471 .16656 L
.7751 .16726 L
.7755 .16796 L
s
.78407 .14238 m
.78414 .14305 L
.78422 .14372 L
.78431 .14438 L
.78441 .14504 L
.78452 .1457 L
.78464 .14636 L
.78476 .14701 L
.7849 .14766 L
.78504 .1483 L
.7852 .14895 L
.78536 .14959 L
.78553 .15022 L
.78571 .15086 L
.7859 .15149 L
.7861 .15212 L
.78631 .15274 L
.78653 .15336 L
.78676 .15398 L
.78699 .1546 L
.78724 .15521 L
.78749 .15582 L
.78776 .15643 L
.78803 .15703 L
.78831 .15764 L
.7886 .15823 L
.7889 .15883 L
.78921 .15942 L
.78953 .16001 L
.78986 .1606 L
.79019 .16118 L
s
.79993 .1392 m
.79999 .13974 L
.80005 .14028 L
.80013 .14082 L
.80021 .14135 L
.8003 .14189 L
.80039 .14242 L
.80049 .14294 L
.8006 .14347 L
.80072 .14399 L
.80084 .14451 L
.80098 .14503 L
.80112 .14554 L
.80126 .14606 L
.80142 .14657 L
.80158 .14707 L
.80175 .14758 L
.80192 .14808 L
.80211 .14858 L
.8023 .14908 L
.8025 .14958 L
.8027 .15007 L
.80292 .15056 L
.80314 .15105 L
.80336 .15154 L
.8036 .15202 L
.80384 .15251 L
.80409 .15299 L
.80435 .15346 L
.80461 .15394 L
.80489 .15441 L
s
.81579 .13602 m
.81584 .13643 L
.81589 .13685 L
.81594 .13726 L
.81601 .13766 L
.81607 .13807 L
.81614 .13847 L
.81622 .13888 L
.81631 .13928 L
.8164 .13968 L
.81649 .14007 L
.81659 .14047 L
.8167 .14086 L
.81681 .14126 L
.81693 .14165 L
.81705 .14203 L
.81718 .14242 L
.81732 .1428 L
.81746 .14319 L
.8176 .14357 L
.81775 .14395 L
.81791 .14432 L
.81807 .1447 L
.81824 .14507 L
.81842 .14544 L
.8186 .14581 L
.81878 .14618 L
.81897 .14655 L
.81917 .14691 L
.81937 .14727 L
.81958 .14763 L
s
.83166 .13284 m
.83169 .13312 L
.83172 .13341 L
.83176 .13369 L
.8318 .13397 L
.83185 .13425 L
.8319 .13453 L
.83195 .13481 L
.83201 .13509 L
.83207 .13536 L
.83214 .13564 L
.83221 .13591 L
.83228 .13618 L
.83236 .13645 L
.83244 .13672 L
.83253 .13699 L
.83262 .13726 L
.83271 .13752 L
.8328 .13779 L
.83291 .13805 L
.83301 .13831 L
.83312 .13857 L
.83323 .13883 L
.83335 .13909 L
.83347 .13935 L
.83359 .1396 L
.83372 .13986 L
.83385 .14011 L
.83399 .14036 L
.83413 .14061 L
.83427 .14086 L
s
.84752 .12966 m
.84754 .12981 L
.84756 .12997 L
.84758 .13013 L
.8476 .13028 L
.84763 .13044 L
.84765 .13059 L
.84768 .13075 L
.84772 .1309 L
.84775 .13105 L
.84779 .1312 L
.84782 .13135 L
.84787 .1315 L
.84791 .13165 L
.84795 .1318 L
.848 .13195 L
.84805 .1321 L
.8481 .13224 L
.84815 .13239 L
.84821 .13254 L
.84827 .13268 L
.84833 .13282 L
.84839 .13297 L
.84845 .13311 L
.84852 .13325 L
.84859 .13339 L
.84866 .13353 L
.84873 .13367 L
.84881 .13381 L
.84888 .13395 L
.84896 .13409 L
s
.86338 .12648 m
.86339 .12651 L
.86339 .12653 L
.86339 .12656 L
.8634 .12659 L
.8634 .12662 L
.86341 .12665 L
.86341 .12668 L
.86342 .12671 L
.86343 .12674 L
.86343 .12677 L
.86344 .1268 L
.86345 .12682 L
.86346 .12685 L
.86346 .12688 L
.86347 .12691 L
.86348 .12694 L
.86349 .12696 L
.8635 .12699 L
.86351 .12702 L
.86352 .12705 L
.86354 .12707 L
.86355 .1271 L
.86356 .12713 L
.86357 .12716 L
.86359 .12718 L
.8636 .12721 L
.86361 .12724 L
.86363 .12726 L
.86364 .12729 L
.86366 .12731 L
s
.87835 .12054 m
.8784 .12063 L
.87845 .12071 L
.87849 .1208 L
.87854 .12088 L
.87858 .12097 L
.87862 .12106 L
.87867 .12115 L
.87871 .12124 L
.87874 .12132 L
.87878 .12141 L
.87882 .1215 L
.87885 .12159 L
.87889 .12169 L
.87892 .12178 L
.87895 .12187 L
.87898 .12196 L
.879 .12205 L
.87903 .12215 L
.87906 .12224 L
.87908 .12233 L
.8791 .12243 L
.87912 .12252 L
.87914 .12262 L
.87916 .12271 L
.87918 .12281 L
.8792 .1229 L
.87921 .123 L
.87922 .1231 L
.87924 .1232 L
.87925 .12329 L
s
.89304 .11377 m
.89315 .11396 L
.89327 .11416 L
.89337 .11436 L
.89348 .11456 L
.89358 .11476 L
.89368 .11496 L
.89377 .11517 L
.89386 .11537 L
.89395 .11558 L
.89404 .11578 L
.89412 .11599 L
.8942 .1162 L
.89428 .11641 L
.89435 .11662 L
.89442 .11683 L
.89449 .11704 L
.89455 .11725 L
.89461 .11747 L
.89467 .11768 L
.89473 .1179 L
.89478 .11811 L
.89483 .11833 L
.89487 .11855 L
.89492 .11877 L
.89496 .11899 L
.89499 .11921 L
.89503 .11944 L
.89506 .11966 L
.89508 .11989 L
.89511 .12011 L
s
.90773 .10699 m
.90791 .1073 L
.90808 .10761 L
.90825 .10792 L
.90842 .10824 L
.90857 .10855 L
.90873 .10887 L
.90888 .10918 L
.90902 .1095 L
.90916 .10983 L
.9093 .11015 L
.90942 .11047 L
.90955 .1108 L
.90967 .11113 L
.90978 .11145 L
.9099 .11179 L
.91 .11212 L
.9101 .11245 L
.9102 .11279 L
.91029 .11312 L
.91037 .11346 L
.91046 .1138 L
.91053 .11414 L
.9106 .11449 L
.91067 .11483 L
.91073 .11518 L
.91079 .11552 L
.91084 .11587 L
.91089 .11622 L
.91093 .11658 L
.91097 .11693 L
s
.92243 .10022 m
.92267 .10064 L
.9229 .10106 L
.92313 .10148 L
.92336 .10191 L
.92357 .10234 L
.92378 .10277 L
.92398 .1032 L
.92418 .10364 L
.92437 .10408 L
.92455 .10452 L
.92473 .10496 L
.9249 .1054 L
.92506 .10585 L
.92522 .10629 L
.92537 .10674 L
.92551 .1072 L
.92565 .10765 L
.92578 .10811 L
.9259 .10857 L
.92602 .10903 L
.92613 .10949 L
.92624 .10995 L
.92633 .11042 L
.92643 .11089 L
.92651 .11136 L
.92659 .11183 L
.92666 .11231 L
.92673 .11279 L
.92678 .11327 L
.92684 .11375 L
s
.93712 .09344 m
.93743 .09398 L
.93772 .09451 L
.93801 .09505 L
.93829 .09559 L
.93857 .09613 L
.93883 .09667 L
.93909 .09722 L
.93934 .09777 L
.93958 .09833 L
.93981 .09888 L
.94003 .09944 L
.94025 .1 L
.94045 .10057 L
.94065 .10113 L
.94084 .1017 L
.94102 .10227 L
.9412 .10285 L
.94136 .10343 L
.94152 .10401 L
.94167 .10459 L
.94181 .10518 L
.94194 .10576 L
.94206 .10636 L
.94218 .10695 L
.94229 .10755 L
.94239 .10814 L
.94248 .10875 L
.94256 .10935 L
.94263 .10996 L
.9427 .11057 L
s
.95181 .08667 m
.95218 .08731 L
.95254 .08796 L
.95289 .08861 L
.95323 .08926 L
.95356 .08992 L
.95389 .09058 L
.9542 .09124 L
.9545 .09191 L
.95479 .09258 L
.95507 .09325 L
.95534 .09392 L
.9556 .0946 L
.95585 .09529 L
.95609 .09597 L
.95632 .09666 L
.95654 .09735 L
.95675 .09805 L
.95695 .09875 L
.95714 .09945 L
.95732 .10015 L
.95749 .10086 L
.95765 .10158 L
.9578 .10229 L
.95793 .10301 L
.95806 .10373 L
.95818 .10446 L
.95829 .10518 L
.95839 .10591 L
.95848 .10665 L
.95856 .10739 L
s
0 0 0 r
.03713 .2316 m
.2003 .29099 L
s
% Start of user PostScript
0 0 20.9492 7.6249 MAarrowhead1
% End of user PostScript
.2003 .29099 m
.34089 .29169 L
s
% Start of user PostScript
20.9492 7.6249 38.9991 7.71439 MAarrowhead1
% End of user PostScript
.34089 .29169 m
.50449 .23583 L
s
% Start of user PostScript
38.9991 7.71439 60.0033 0.543142 MAarrowhead1
% End of user PostScript
.50449 .23583 m
.58211 .21858 L
s
% Start of user PostScript
60.0033 0.543142 69.9689 -1.67189 MAarrowhead1
% End of user PostScript
.58211 .21858 m
.97179 .09162 L
s
% Start of user PostScript
69.9689 -1.67189 120. -17.9721 MAarrowhead1
% End of user PostScript
.97179 .09162 m
.97179 .09162 L
s
% Start of user PostScript
120. -17.9721 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.03699 .23155 m
.03701 .23156 L
.03702 .23156 L
.03704 .23157 L
.03705 .23157 L
.03707 .23158 L
.03708 .23158 L
.03709 .23159 L
.0371 .23159 L
.03711 .23159 L
.03711 .2316 L
.03712 .2316 L
.03712 .2316 L
.03713 .2316 L
.03713 .2316 L
.03713 .2316 L
.03713 .2316 L
.03713 .2316 L
.03712 .2316 L
.03712 .2316 L
.03711 .2316 L
.03711 .23159 L
.0371 .23159 L
.03709 .23159 L
.03708 .23158 L
.03707 .23158 L
.03705 .23157 L
.03704 .23157 L
.03702 .23156 L
.03701 .23156 L
.03699 .23155 L
s
.05228 .23712 m
.0523 .23712 L
.05232 .23713 L
.05233 .23713 L
.05235 .23714 L
.05236 .23714 L
.05237 .23715 L
.05238 .23715 L
.05239 .23716 L
.0524 .23716 L
.05241 .23716 L
.05241 .23716 L
.05242 .23717 L
.05242 .23717 L
.05242 .23717 L
.05242 .23717 L
.05242 .23717 L
.05242 .23717 L
.05242 .23717 L
.05241 .23716 L
.05241 .23716 L
.0524 .23716 L
.05239 .23716 L
.05238 .23715 L
.05237 .23715 L
.05236 .23714 L
.05235 .23714 L
.05233 .23713 L
.05232 .23713 L
.0523 .23712 L
.05228 .23712 L
s
.06758 .24268 m
.06759 .24269 L
.06761 .2427 L
.06763 .2427 L
.06764 .24271 L
.06765 .24271 L
.06766 .24272 L
.06768 .24272 L
.06768 .24272 L
.06769 .24273 L
.0677 .24273 L
.06771 .24273 L
.06771 .24273 L
.06771 .24273 L
.06771 .24273 L
.06772 .24273 L
.06771 .24273 L
.06771 .24273 L
.06771 .24273 L
.06771 .24273 L
.0677 .24273 L
.06769 .24273 L
.06768 .24272 L
.06768 .24272 L
.06766 .24272 L
.06765 .24271 L
.06764 .24271 L
.06763 .2427 L
.06761 .2427 L
.06759 .24269 L
.06758 .24268 L
s
.08287 .24825 m
.08289 .24826 L
.0829 .24826 L
.08292 .24827 L
.08293 .24827 L
.08295 .24828 L
.08296 .24828 L
.08297 .24829 L
.08298 .24829 L
.08299 .24829 L
.08299 .24829 L
.083 .2483 L
.083 .2483 L
.08301 .2483 L
.08301 .2483 L
.08301 .2483 L
.08301 .2483 L
.08301 .2483 L
.083 .2483 L
.083 .2483 L
.08299 .24829 L
.08299 .24829 L
.08298 .24829 L
.08297 .24829 L
.08296 .24828 L
.08295 .24828 L
.08293 .24827 L
.08292 .24827 L
.0829 .24826 L
.08289 .24826 L
.08287 .24825 L
s
.09816 .25381 m
.09818 .25382 L
.0982 .25383 L
.09821 .25383 L
.09823 .25384 L
.09824 .25384 L
.09825 .25385 L
.09826 .25385 L
.09827 .25385 L
.09828 .25386 L
.09829 .25386 L
.09829 .25386 L
.0983 .25386 L
.0983 .25386 L
.0983 .25387 L
.0983 .25387 L
.0983 .25387 L
.0983 .25386 L
.0983 .25386 L
.09829 .25386 L
.09829 .25386 L
.09828 .25386 L
.09827 .25385 L
.09826 .25385 L
.09825 .25385 L
.09824 .25384 L
.09823 .25384 L
.09821 .25383 L
.0982 .25383 L
.09818 .25382 L
.09816 .25381 L
s
.11345 .25938 m
.11347 .25939 L
.11349 .25939 L
.1135 .2594 L
.11352 .2594 L
.11353 .25941 L
.11354 .25941 L
.11355 .25942 L
.11356 .25942 L
.11357 .25942 L
.11358 .25943 L
.11358 .25943 L
.11359 .25943 L
.11359 .25943 L
.11359 .25943 L
.11359 .25943 L
.11359 .25943 L
.11359 .25943 L
.11359 .25943 L
.11358 .25943 L
.11358 .25943 L
.11357 .25942 L
.11356 .25942 L
.11355 .25942 L
.11354 .25941 L
.11353 .25941 L
.11352 .2594 L
.1135 .2594 L
.11349 .25939 L
.11347 .25939 L
.11345 .25938 L
s
.12875 .26495 m
.12876 .26495 L
.12878 .26496 L
.1288 .26497 L
.12881 .26497 L
.12882 .26498 L
.12884 .26498 L
.12885 .26498 L
.12886 .26499 L
.12886 .26499 L
.12887 .26499 L
.12888 .26499 L
.12888 .265 L
.12888 .265 L
.12889 .265 L
.12889 .265 L
.12889 .265 L
.12888 .265 L
.12888 .265 L
.12888 .26499 L
.12887 .26499 L
.12886 .26499 L
.12886 .26499 L
.12885 .26498 L
.12884 .26498 L
.12882 .26498 L
.12881 .26497 L
.1288 .26497 L
.12878 .26496 L
.12876 .26495 L
.12875 .26495 L
s
.14404 .27051 m
.14406 .27052 L
.14407 .27053 L
.14409 .27053 L
.1441 .27054 L
.14412 .27054 L
.14413 .27055 L
.14414 .27055 L
.14415 .27055 L
.14416 .27056 L
.14416 .27056 L
.14417 .27056 L
.14417 .27056 L
.14418 .27056 L
.14418 .27056 L
.14418 .27056 L
.14418 .27056 L
.14418 .27056 L
.14417 .27056 L
.14417 .27056 L
.14416 .27056 L
.14416 .27056 L
.14415 .27055 L
.14414 .27055 L
.14413 .27055 L
.14412 .27054 L
.1441 .27054 L
.14409 .27053 L
.14407 .27053 L
.14406 .27052 L
.14404 .27051 L
s
.15933 .27608 m
.15935 .27609 L
.15937 .27609 L
.15938 .2761 L
.1594 .2761 L
.15941 .27611 L
.15942 .27611 L
.15943 .27612 L
.15944 .27612 L
.15945 .27612 L
.15946 .27612 L
.15946 .27613 L
.15947 .27613 L
.15947 .27613 L
.15947 .27613 L
.15947 .27613 L
.15947 .27613 L
.15947 .27613 L
.15947 .27613 L
.15946 .27613 L
.15946 .27612 L
.15945 .27612 L
.15944 .27612 L
.15943 .27612 L
.15942 .27611 L
.15941 .27611 L
.1594 .2761 L
.15938 .2761 L
.15937 .27609 L
.15935 .27609 L
.15933 .27608 L
s
.17462 .28165 m
.17464 .28165 L
.17466 .28166 L
.17467 .28166 L
.17469 .28167 L
.1747 .28167 L
.17471 .28168 L
.17472 .28168 L
.17473 .28169 L
.17474 .28169 L
.17475 .28169 L
.17476 .28169 L
.17476 .28169 L
.17476 .2817 L
.17476 .2817 L
.17477 .2817 L
.17476 .2817 L
.17476 .2817 L
.17476 .28169 L
.17476 .28169 L
.17475 .28169 L
.17474 .28169 L
.17473 .28169 L
.17472 .28168 L
.17471 .28168 L
.1747 .28167 L
.17469 .28167 L
.17467 .28166 L
.17466 .28166 L
.17464 .28165 L
.17462 .28165 L
s
.18992 .28721 m
.18993 .28722 L
.18995 .28722 L
.18997 .28723 L
.18998 .28724 L
.19 .28724 L
.19001 .28724 L
.19002 .28725 L
.19003 .28725 L
.19004 .28725 L
.19004 .28726 L
.19005 .28726 L
.19005 .28726 L
.19006 .28726 L
.19006 .28726 L
.19006 .28726 L
.19006 .28726 L
.19006 .28726 L
.19005 .28726 L
.19005 .28726 L
.19004 .28726 L
.19004 .28725 L
.19003 .28725 L
.19002 .28725 L
.19001 .28724 L
.19 .28724 L
.18998 .28724 L
.18997 .28723 L
.18995 .28722 L
.18993 .28722 L
.18992 .28721 L
s
.20561 .29102 m
.20562 .29102 L
.20563 .29102 L
.20563 .29102 L
.20564 .29102 L
.20565 .29102 L
.20565 .29102 L
.20566 .29102 L
.20566 .29102 L
.20566 .29102 L
.20567 .29102 L
.20567 .29102 L
.20567 .29102 L
.20567 .29102 L
.20567 .29102 L
.20568 .29102 L
.20567 .29102 L
.20567 .29102 L
.20567 .29102 L
.20567 .29102 L
.20567 .29102 L
.20566 .29102 L
.20566 .29102 L
.20566 .29102 L
.20565 .29102 L
.20565 .29102 L
.20564 .29102 L
.20563 .29102 L
.20563 .29102 L
.20562 .29102 L
.20561 .29102 L
s
.22188 .2911 m
.22189 .2911 L
.2219 .2911 L
.22191 .2911 L
.22191 .2911 L
.22192 .2911 L
.22193 .2911 L
.22193 .2911 L
.22194 .2911 L
.22194 .2911 L
.22194 .2911 L
.22194 .2911 L
.22195 .2911 L
.22195 .2911 L
.22195 .2911 L
.22195 .2911 L
.22195 .2911 L
.22195 .2911 L
.22195 .2911 L
.22194 .2911 L
.22194 .2911 L
.22194 .2911 L
.22194 .2911 L
.22193 .2911 L
.22193 .2911 L
.22192 .2911 L
.22191 .2911 L
.22191 .2911 L
.2219 .2911 L
.22189 .2911 L
.22188 .2911 L
s
.23816 .29118 m
.23817 .29118 L
.23817 .29118 L
.23818 .29118 L
.23819 .29118 L
.23819 .29118 L
.2382 .29118 L
.2382 .29118 L
.23821 .29118 L
.23821 .29118 L
.23822 .29118 L
.23822 .29118 L
.23822 .29118 L
.23822 .29118 L
.23822 .29118 L
.23822 .29118 L
.23822 .29118 L
.23822 .29118 L
.23822 .29118 L
.23822 .29118 L
.23822 .29118 L
.23821 .29118 L
.23821 .29118 L
.2382 .29118 L
.2382 .29118 L
.23819 .29118 L
.23819 .29118 L
.23818 .29118 L
.23817 .29118 L
.23817 .29118 L
.23816 .29118 L
s
.25443 .29126 m
.25444 .29126 L
.25445 .29126 L
.25446 .29126 L
.25446 .29126 L
.25447 .29126 L
.25447 .29126 L
.25448 .29126 L
.25448 .29126 L
.25449 .29126 L
.25449 .29126 L
.25449 .29126 L
.2545 .29126 L
.2545 .29126 L
.2545 .29126 L
.2545 .29126 L
.2545 .29126 L
.2545 .29126 L
.2545 .29126 L
.25449 .29126 L
.25449 .29126 L
.25449 .29126 L
.25448 .29126 L
.25448 .29126 L
.25447 .29126 L
.25447 .29126 L
.25446 .29126 L
.25446 .29126 L
.25445 .29126 L
.25444 .29126 L
.25443 .29126 L
s
.27071 .29134 m
.27071 .29134 L
.27072 .29134 L
.27073 .29134 L
.27074 .29134 L
.27074 .29134 L
.27075 .29134 L
.27075 .29134 L
.27076 .29134 L
.27076 .29134 L
.27076 .29134 L
.27077 .29134 L
.27077 .29134 L
.27077 .29134 L
.27077 .29134 L
.27077 .29134 L
.27077 .29134 L
.27077 .29134 L
.27077 .29134 L
.27077 .29134 L
.27076 .29134 L
.27076 .29134 L
.27076 .29134 L
.27075 .29134 L
.27075 .29134 L
.27074 .29134 L
.27074 .29134 L
.27073 .29134 L
.27072 .29134 L
.27071 .29134 L
.27071 .29134 L
s
.28698 .29142 m
.28699 .29142 L
.287 .29142 L
.287 .29142 L
.28701 .29142 L
.28702 .29142 L
.28702 .29142 L
.28703 .29142 L
.28703 .29142 L
.28704 .29142 L
.28704 .29142 L
.28704 .29142 L
.28704 .29142 L
.28704 .29142 L
.28705 .29142 L
.28705 .29142 L
.28705 .29142 L
.28704 .29142 L
.28704 .29142 L
.28704 .29142 L
.28704 .29142 L
.28704 .29142 L
.28703 .29142 L
.28703 .29142 L
.28702 .29142 L
.28702 .29142 L
.28701 .29142 L
.287 .29142 L
.287 .29142 L
.28699 .29142 L
.28698 .29142 L
s
.30325 .2915 m
.30326 .2915 L
.30327 .2915 L
.30328 .2915 L
.30328 .2915 L
.30329 .2915 L
.3033 .2915 L
.3033 .2915 L
.30331 .2915 L
.30331 .2915 L
.30331 .2915 L
.30332 .2915 L
.30332 .2915 L
.30332 .2915 L
.30332 .2915 L
.30332 .2915 L
.30332 .2915 L
.30332 .2915 L
.30332 .2915 L
.30332 .2915 L
.30331 .2915 L
.30331 .2915 L
.30331 .2915 L
.3033 .2915 L
.3033 .2915 L
.30329 .2915 L
.30328 .2915 L
.30328 .2915 L
.30327 .2915 L
.30326 .2915 L
.30325 .2915 L
s
.31953 .29158 m
.31954 .29158 L
.31954 .29158 L
.31955 .29158 L
.31956 .29158 L
.31956 .29158 L
.31957 .29158 L
.31958 .29158 L
.31958 .29158 L
.31958 .29158 L
.31959 .29158 L
.31959 .29158 L
.31959 .29158 L
.31959 .29158 L
.31959 .29158 L
.31959 .29158 L
.31959 .29158 L
.31959 .29158 L
.31959 .29158 L
.31959 .29158 L
.31959 .29158 L
.31958 .29158 L
.31958 .29158 L
.31958 .29158 L
.31957 .29158 L
.31956 .29158 L
.31956 .29158 L
.31955 .29158 L
.31954 .29158 L
.31954 .29158 L
.31953 .29158 L
s
.3358 .29166 m
.33581 .29166 L
.33582 .29166 L
.33583 .29166 L
.33583 .29166 L
.33584 .29166 L
.33584 .29166 L
.33585 .29166 L
.33585 .29166 L
.33586 .29166 L
.33586 .29166 L
.33586 .29166 L
.33587 .29166 L
.33587 .29166 L
.33587 .29166 L
.33587 .29166 L
.33587 .29166 L
.33587 .29166 L
.33587 .29166 L
.33586 .29166 L
.33586 .29166 L
.33586 .29166 L
.33585 .29166 L
.33585 .29166 L
.33584 .29166 L
.33584 .29166 L
.33583 .29166 L
.33583 .29166 L
.33582 .29166 L
.33581 .29166 L
.3358 .29166 L
s
.35139 .2881 m
.35141 .28809 L
.35143 .28809 L
.35145 .28808 L
.35146 .28808 L
.35147 .28807 L
.35149 .28807 L
.3515 .28806 L
.35151 .28806 L
.35152 .28806 L
.35152 .28806 L
.35153 .28805 L
.35153 .28805 L
.35154 .28805 L
.35154 .28805 L
.35154 .28805 L
.35154 .28805 L
.35154 .28805 L
.35153 .28805 L
.35153 .28805 L
.35152 .28806 L
.35152 .28806 L
.35151 .28806 L
.3515 .28806 L
.35149 .28807 L
.35147 .28807 L
.35146 .28808 L
.35145 .28808 L
.35143 .28809 L
.35141 .28809 L
.35139 .2881 L
s
.3668 .28284 m
.36681 .28284 L
.36683 .28283 L
.36685 .28282 L
.36686 .28282 L
.36688 .28281 L
.36689 .28281 L
.3669 .28281 L
.36691 .2828 L
.36692 .2828 L
.36692 .2828 L
.36693 .2828 L
.36693 .28279 L
.36694 .28279 L
.36694 .28279 L
.36694 .28279 L
.36694 .28279 L
.36694 .28279 L
.36693 .28279 L
.36693 .2828 L
.36692 .2828 L
.36692 .2828 L
.36691 .2828 L
.3669 .28281 L
.36689 .28281 L
.36688 .28281 L
.36686 .28282 L
.36685 .28282 L
.36683 .28283 L
.36681 .28284 L
.3668 .28284 L
s
.3822 .27758 m
.38221 .27758 L
.38223 .27757 L
.38225 .27757 L
.38226 .27756 L
.38228 .27756 L
.38229 .27755 L
.3823 .27755 L
.38231 .27754 L
.38232 .27754 L
.38233 .27754 L
.38233 .27754 L
.38234 .27754 L
.38234 .27753 L
.38234 .27753 L
.38234 .27753 L
.38234 .27753 L
.38234 .27753 L
.38234 .27754 L
.38233 .27754 L
.38233 .27754 L
.38232 .27754 L
.38231 .27754 L
.3823 .27755 L
.38229 .27755 L
.38228 .27756 L
.38226 .27756 L
.38225 .27757 L
.38223 .27757 L
.38221 .27758 L
.3822 .27758 L
s
.3976 .27233 m
.39762 .27232 L
.39763 .27231 L
.39765 .27231 L
.39766 .2723 L
.39768 .2723 L
.39769 .27229 L
.3977 .27229 L
.39771 .27229 L
.39772 .27228 L
.39773 .27228 L
.39773 .27228 L
.39774 .27228 L
.39774 .27228 L
.39774 .27228 L
.39774 .27228 L
.39774 .27228 L
.39774 .27228 L
.39774 .27228 L
.39773 .27228 L
.39773 .27228 L
.39772 .27228 L
.39771 .27229 L
.3977 .27229 L
.39769 .27229 L
.39768 .2723 L
.39766 .2723 L
.39765 .27231 L
.39763 .27231 L
.39762 .27232 L
.3976 .27233 L
s
.413 .26707 m
.41302 .26706 L
.41303 .26705 L
.41305 .26705 L
.41307 .26704 L
.41308 .26704 L
.41309 .26704 L
.4131 .26703 L
.41311 .26703 L
.41312 .26703 L
.41313 .26702 L
.41313 .26702 L
.41314 .26702 L
.41314 .26702 L
.41314 .26702 L
.41314 .26702 L
.41314 .26702 L
.41314 .26702 L
.41314 .26702 L
.41313 .26702 L
.41313 .26702 L
.41312 .26703 L
.41311 .26703 L
.4131 .26703 L
.41309 .26704 L
.41308 .26704 L
.41307 .26704 L
.41305 .26705 L
.41303 .26705 L
.41302 .26706 L
.413 .26707 L
s
.4284 .26181 m
.42842 .2618 L
.42844 .2618 L
.42845 .26179 L
.42847 .26179 L
.42848 .26178 L
.42849 .26178 L
.4285 .26177 L
.42851 .26177 L
.42852 .26177 L
.42853 .26176 L
.42854 .26176 L
.42854 .26176 L
.42854 .26176 L
.42855 .26176 L
.42855 .26176 L
.42855 .26176 L
.42854 .26176 L
.42854 .26176 L
.42854 .26176 L
.42853 .26176 L
.42852 .26177 L
.42851 .26177 L
.4285 .26177 L
.42849 .26178 L
.42848 .26178 L
.42847 .26179 L
.42845 .26179 L
.42844 .2618 L
.42842 .2618 L
.4284 .26181 L
s
.4438 .25655 m
.44382 .25654 L
.44384 .25654 L
.44385 .25653 L
.44387 .25653 L
.44388 .25652 L
.44389 .25652 L
.44391 .25651 L
.44392 .25651 L
.44392 .25651 L
.44393 .25651 L
.44394 .2565 L
.44394 .2565 L
.44395 .2565 L
.44395 .2565 L
.44395 .2565 L
.44395 .2565 L
.44395 .2565 L
.44394 .2565 L
.44394 .2565 L
.44393 .25651 L
.44392 .25651 L
.44392 .25651 L
.44391 .25651 L
.44389 .25652 L
.44388 .25652 L
.44387 .25653 L
.44385 .25653 L
.44384 .25654 L
.44382 .25654 L
.4438 .25655 L
s
.4592 .25129 m
.45922 .25129 L
.45924 .25128 L
.45925 .25127 L
.45927 .25127 L
.45928 .25126 L
.4593 .25126 L
.45931 .25126 L
.45932 .25125 L
.45933 .25125 L
.45933 .25125 L
.45934 .25125 L
.45934 .25124 L
.45935 .25124 L
.45935 .25124 L
.45935 .25124 L
.45935 .25124 L
.45935 .25124 L
.45934 .25124 L
.45934 .25125 L
.45933 .25125 L
.45933 .25125 L
.45932 .25125 L
.45931 .25126 L
.4593 .25126 L
.45928 .25126 L
.45927 .25127 L
.45925 .25127 L
.45924 .25128 L
.45922 .25129 L
.4592 .25129 L
s
.4746 .24603 m
.47462 .24603 L
.47464 .24602 L
.47466 .24602 L
.47467 .24601 L
.47469 .24601 L
.4747 .246 L
.47471 .246 L
.47472 .24599 L
.47473 .24599 L
.47473 .24599 L
.47474 .24599 L
.47474 .24599 L
.47475 .24598 L
.47475 .24598 L
.47475 .24598 L
.47475 .24598 L
.47475 .24598 L
.47474 .24599 L
.47474 .24599 L
.47473 .24599 L
.47473 .24599 L
.47472 .24599 L
.47471 .246 L
.4747 .246 L
.47469 .24601 L
.47467 .24601 L
.47466 .24602 L
.47464 .24602 L
.47462 .24603 L
.4746 .24603 L
s
.49 .24078 m
.49002 .24077 L
.49004 .24076 L
.49006 .24076 L
.49007 .24075 L
.49009 .24075 L
.4901 .24074 L
.49011 .24074 L
.49012 .24074 L
.49013 .24073 L
.49014 .24073 L
.49014 .24073 L
.49015 .24073 L
.49015 .24073 L
.49015 .24073 L
.49015 .24073 L
.49015 .24073 L
.49015 .24073 L
.49015 .24073 L
.49014 .24073 L
.49014 .24073 L
.49013 .24073 L
.49012 .24074 L
.49011 .24074 L
.4901 .24074 L
.49009 .24075 L
.49007 .24075 L
.49006 .24076 L
.49004 .24076 L
.49002 .24077 L
.49 .24078 L
s
.50636 .23542 m
.50626 .23544 L
.50616 .23546 L
.50608 .23548 L
.506 .23549 L
.50593 .23551 L
.50586 .23553 L
.50581 .23554 L
.50575 .23555 L
.50571 .23556 L
.50567 .23557 L
.50564 .23557 L
.50562 .23558 L
.5056 .23558 L
.50559 .23559 L
.50559 .23559 L
.50559 .23559 L
.5056 .23558 L
.50562 .23558 L
.50564 .23557 L
.50567 .23557 L
.50571 .23556 L
.50575 .23555 L
.50581 .23554 L
.50586 .23553 L
.50593 .23551 L
.506 .23549 L
.50608 .23548 L
.50616 .23546 L
.50626 .23544 L
.50636 .23542 L
s
.52223 .23189 m
.52213 .23191 L
.52204 .23193 L
.52196 .23195 L
.52188 .23197 L
.52181 .23198 L
.52175 .232 L
.52169 .23201 L
.52164 .23202 L
.5216 .23203 L
.52156 .23204 L
.52153 .23204 L
.5215 .23205 L
.52149 .23205 L
.52148 .23205 L
.52147 .23206 L
.52148 .23205 L
.52149 .23205 L
.5215 .23205 L
.52153 .23204 L
.52156 .23204 L
.5216 .23203 L
.52164 .23202 L
.52169 .23201 L
.52175 .232 L
.52181 .23198 L
.52188 .23197 L
.52196 .23195 L
.52204 .23193 L
.52213 .23191 L
.52223 .23189 L
s
.53811 .22836 m
.53801 .22838 L
.53792 .2284 L
.53784 .22842 L
.53776 .22844 L
.53769 .22845 L
.53763 .22846 L
.53757 .22848 L
.53752 .22849 L
.53748 .2285 L
.53744 .22851 L
.53741 .22851 L
.53739 .22852 L
.53737 .22852 L
.53736 .22852 L
.53736 .22852 L
.53736 .22852 L
.53737 .22852 L
.53739 .22852 L
.53741 .22851 L
.53744 .22851 L
.53748 .2285 L
.53752 .22849 L
.53757 .22848 L
.53763 .22846 L
.53769 .22845 L
.53776 .22844 L
.53784 .22842 L
.53792 .2284 L
.53801 .22838 L
.53811 .22836 L
s
.55398 .22483 m
.55389 .22485 L
.5538 .22487 L
.55372 .22489 L
.55364 .22491 L
.55357 .22492 L
.55351 .22493 L
.55346 .22495 L
.55341 .22496 L
.55336 .22497 L
.55333 .22498 L
.5533 .22498 L
.55328 .22499 L
.55326 .22499 L
.55325 .22499 L
.55325 .22499 L
.55325 .22499 L
.55326 .22499 L
.55328 .22499 L
.5533 .22498 L
.55333 .22498 L
.55336 .22497 L
.55341 .22496 L
.55346 .22495 L
.55351 .22493 L
.55357 .22492 L
.55364 .22491 L
.55372 .22489 L
.5538 .22487 L
.55389 .22485 L
.55398 .22483 L
s
.56986 .2213 m
.56976 .22132 L
.56968 .22134 L
.5696 .22136 L
.56952 .22138 L
.56945 .22139 L
.56939 .2214 L
.56934 .22142 L
.56929 .22143 L
.56925 .22144 L
.56921 .22144 L
.56919 .22145 L
.56916 .22146 L
.56915 .22146 L
.56914 .22146 L
.56913 .22146 L
.56914 .22146 L
.56915 .22146 L
.56916 .22146 L
.56919 .22145 L
.56921 .22144 L
.56925 .22144 L
.56929 .22143 L
.56934 .22142 L
.56939 .2214 L
.56945 .22139 L
.56952 .22138 L
.5696 .22136 L
.56968 .22134 L
.56976 .22132 L
.56986 .2213 L
s
.58812 .21662 m
.58771 .21675 L
.58733 .21688 L
.58697 .21699 L
.58665 .2171 L
.58635 .21719 L
.58609 .21728 L
.58585 .21736 L
.58564 .21743 L
.58545 .21749 L
.5853 .21754 L
.58517 .21758 L
.58507 .21761 L
.585 .21764 L
.58496 .21765 L
.58494 .21765 L
.58496 .21765 L
.585 .21764 L
.58507 .21761 L
.58517 .21758 L
.5853 .21754 L
.58545 .21749 L
.58564 .21743 L
.58585 .21736 L
.58609 .21728 L
.58635 .21719 L
.58665 .2171 L
.58697 .21699 L
.58733 .21688 L
.58771 .21675 L
.58812 .21662 L
s
.60343 .21163 m
.60304 .21176 L
.60268 .21188 L
.60235 .21198 L
.60204 .21208 L
.60176 .21218 L
.6015 .21226 L
.60128 .21233 L
.60107 .2124 L
.6009 .21246 L
.60075 .2125 L
.60063 .21254 L
.60054 .21257 L
.60047 .2126 L
.60043 .21261 L
.60042 .21261 L
.60043 .21261 L
.60047 .2126 L
.60054 .21257 L
.60063 .21254 L
.60075 .2125 L
.6009 .21246 L
.60107 .2124 L
.60128 .21233 L
.6015 .21226 L
.60176 .21218 L
.60204 .21208 L
.60235 .21198 L
.60268 .21188 L
.60304 .21176 L
.60343 .21163 L
s
.61875 .20664 m
.61838 .20676 L
.61804 .20687 L
.61772 .20698 L
.61743 .20707 L
.61716 .20716 L
.61692 .20724 L
.6167 .20731 L
.61651 .20737 L
.61635 .20742 L
.61621 .20747 L
.6161 .20751 L
.61601 .20753 L
.61594 .20755 L
.61591 .20757 L
.61589 .20757 L
.61591 .20757 L
.61594 .20755 L
.61601 .20753 L
.6161 .20751 L
.61621 .20747 L
.61635 .20742 L
.61651 .20737 L
.6167 .20731 L
.61692 .20724 L
.61716 .20716 L
.61743 .20707 L
.61772 .20698 L
.61804 .20687 L
.61838 .20676 L
.61875 .20664 L
s
.63406 .20165 m
.63371 .20177 L
.63339 .20187 L
.63309 .20197 L
.63282 .20206 L
.63256 .20214 L
.63234 .20221 L
.63213 .20228 L
.63195 .20234 L
.6318 .20239 L
.63167 .20243 L
.63156 .20247 L
.63147 .20249 L
.63141 .20251 L
.63138 .20253 L
.63137 .20253 L
.63138 .20253 L
.63141 .20251 L
.63147 .20249 L
.63156 .20247 L
.63167 .20243 L
.6318 .20239 L
.63195 .20234 L
.63213 .20228 L
.63234 .20221 L
.63256 .20214 L
.63282 .20206 L
.63309 .20197 L
.63339 .20187 L
.63371 .20177 L
.63406 .20165 L
s
.64938 .19666 m
.64905 .19677 L
.64875 .19687 L
.64846 .19696 L
.6482 .19704 L
.64797 .19712 L
.64775 .19719 L
.64756 .19725 L
.64739 .19731 L
.64725 .19736 L
.64712 .1974 L
.64702 .19743 L
.64694 .19746 L
.64689 .19747 L
.64685 .19749 L
.64684 .19749 L
.64685 .19749 L
.64689 .19747 L
.64694 .19746 L
.64702 .19743 L
.64712 .1974 L
.64725 .19736 L
.64739 .19731 L
.64756 .19725 L
.64775 .19719 L
.64797 .19712 L
.6482 .19704 L
.64846 .19696 L
.64875 .19687 L
.64905 .19677 L
.64938 .19666 L
s
.66469 .19167 m
.66439 .19177 L
.6641 .19187 L
.66384 .19195 L
.66359 .19203 L
.66337 .1921 L
.66317 .19217 L
.66299 .19223 L
.66283 .19228 L
.66269 .19232 L
.66258 .19236 L
.66248 .19239 L
.66241 .19242 L
.66236 .19243 L
.66232 .19244 L
.66231 .19245 L
.66232 .19244 L
.66236 .19243 L
.66241 .19242 L
.66248 .19239 L
.66258 .19236 L
.66269 .19232 L
.66283 .19228 L
.66299 .19223 L
.66317 .19217 L
.66337 .1921 L
.66359 .19203 L
.66384 .19195 L
.6641 .19187 L
.66439 .19177 L
.66469 .19167 L
s
.68001 .18668 m
.67972 .18678 L
.67945 .18686 L
.67921 .18694 L
.67898 .18702 L
.67877 .18708 L
.67859 .18715 L
.67842 .1872 L
.67827 .18725 L
.67814 .18729 L
.67803 .18733 L
.67795 .18735 L
.67788 .18738 L
.67783 .18739 L
.6778 .1874 L
.67779 .18741 L
.6778 .1874 L
.67783 .18739 L
.67788 .18738 L
.67795 .18735 L
.67803 .18733 L
.67814 .18729 L
.67827 .18725 L
.67842 .1872 L
.67859 .18715 L
.67877 .18708 L
.67898 .18702 L
.67921 .18694 L
.67945 .18686 L
.67972 .18678 L
.68001 .18668 L
s
.69532 .18169 m
.69506 .18178 L
.69481 .18186 L
.69458 .18193 L
.69437 .182 L
.69418 .18207 L
.694 .18212 L
.69385 .18217 L
.69371 .18222 L
.69359 .18226 L
.69349 .18229 L
.69341 .18232 L
.69334 .18234 L
.6933 .18235 L
.69327 .18236 L
.69326 .18236 L
.69327 .18236 L
.6933 .18235 L
.69334 .18234 L
.69341 .18232 L
.69349 .18229 L
.69359 .18226 L
.69371 .18222 L
.69385 .18217 L
.694 .18212 L
.69418 .18207 L
.69437 .182 L
.69458 .18193 L
.69481 .18186 L
.69506 .18178 L
.69532 .18169 L
s
.71064 .1767 m
.71039 .17678 L
.71016 .17686 L
.70995 .17693 L
.70976 .17699 L
.70958 .17705 L
.70942 .1771 L
.70928 .17715 L
.70915 .17719 L
.70904 .17722 L
.70895 .17725 L
.70887 .17728 L
.70881 .1773 L
.70877 .17731 L
.70874 .17732 L
.70874 .17732 L
.70874 .17732 L
.70877 .17731 L
.70881 .1773 L
.70887 .17728 L
.70895 .17725 L
.70904 .17722 L
.70915 .17719 L
.70928 .17715 L
.70942 .1771 L
.70958 .17705 L
.70976 .17699 L
.70995 .17693 L
.71016 .17686 L
.71039 .17678 L
.71064 .1767 L
s
.72595 .17171 m
.72573 .17179 L
.72552 .17186 L
.72532 .17192 L
.72515 .17198 L
.72498 .17203 L
.72484 .17208 L
.72471 .17212 L
.72459 .17216 L
.72449 .17219 L
.7244 .17222 L
.72433 .17224 L
.72428 .17226 L
.72424 .17227 L
.72422 .17228 L
.72421 .17228 L
.72422 .17228 L
.72424 .17227 L
.72428 .17226 L
.72433 .17224 L
.7244 .17222 L
.72449 .17219 L
.72459 .17216 L
.72471 .17212 L
.72484 .17208 L
.72498 .17203 L
.72515 .17198 L
.72532 .17192 L
.72552 .17186 L
.72573 .17179 L
.72595 .17171 L
s
.74127 .16672 m
.74106 .16679 L
.74087 .16685 L
.7407 .16691 L
.74054 .16696 L
.74039 .16701 L
.74025 .16705 L
.74013 .16709 L
.74003 .16713 L
.73994 .16716 L
.73986 .16718 L
.7398 .1672 L
.73975 .16722 L
.73971 .16723 L
.73969 .16724 L
.73968 .16724 L
.73969 .16724 L
.73971 .16723 L
.73975 .16722 L
.7398 .1672 L
.73986 .16718 L
.73994 .16716 L
.74003 .16713 L
.74013 .16709 L
.74025 .16705 L
.74039 .16701 L
.74054 .16696 L
.7407 .16691 L
.74087 .16685 L
.74106 .16679 L
.74127 .16672 L
s
.75658 .16173 m
.7564 .16179 L
.75623 .16185 L
.75607 .1619 L
.75592 .16195 L
.75579 .16199 L
.75567 .16203 L
.75556 .16207 L
.75547 .1621 L
.75538 .16212 L
.75532 .16215 L
.75526 .16217 L
.75521 .16218 L
.75518 .16219 L
.75516 .1622 L
.75516 .1622 L
.75516 .1622 L
.75518 .16219 L
.75521 .16218 L
.75526 .16217 L
.75532 .16215 L
.75538 .16212 L
.75547 .1621 L
.75556 .16207 L
.75567 .16203 L
.75579 .16199 L
.75592 .16195 L
.75607 .1619 L
.75623 .16185 L
.7564 .16179 L
.75658 .16173 L
s
.7719 .15674 m
.77173 .1568 L
.77158 .15685 L
.77144 .15689 L
.77131 .15694 L
.77119 .15697 L
.77109 .15701 L
.77099 .15704 L
.77091 .15707 L
.77083 .15709 L
.77077 .15711 L
.77072 .15713 L
.77068 .15714 L
.77065 .15715 L
.77064 .15716 L
.77063 .15716 L
.77064 .15716 L
.77065 .15715 L
.77068 .15714 L
.77072 .15713 L
.77077 .15711 L
.77083 .15709 L
.77091 .15707 L
.77099 .15704 L
.77109 .15701 L
.77119 .15697 L
.77131 .15694 L
.77144 .15689 L
.77158 .15685 L
.77173 .1568 L
.7719 .15674 L
s
.78721 .15176 m
.78707 .1518 L
.78694 .15185 L
.78681 .15189 L
.7867 .15192 L
.7866 .15196 L
.7865 .15199 L
.78642 .15201 L
.78635 .15204 L
.78628 .15206 L
.78623 .15208 L
.78618 .15209 L
.78615 .1521 L
.78612 .15211 L
.78611 .15211 L
.7861 .15212 L
.78611 .15211 L
.78612 .15211 L
.78615 .1521 L
.78618 .15209 L
.78623 .15208 L
.78628 .15206 L
.78635 .15204 L
.78642 .15201 L
.7865 .15199 L
.7866 .15196 L
.7867 .15192 L
.78681 .15189 L
.78694 .15185 L
.78707 .1518 L
.78721 .15176 L
s
.80253 .14677 m
.80241 .14681 L
.80229 .14684 L
.80219 .14688 L
.80209 .14691 L
.802 .14694 L
.80192 .14696 L
.80185 .14699 L
.80179 .14701 L
.80173 .14703 L
.80168 .14704 L
.80165 .14705 L
.80162 .14706 L
.8016 .14707 L
.80158 .14707 L
.80158 .14707 L
.80158 .14707 L
.8016 .14707 L
.80162 .14706 L
.80165 .14705 L
.80168 .14704 L
.80173 .14703 L
.80179 .14701 L
.80185 .14699 L
.80192 .14696 L
.802 .14694 L
.80209 .14691 L
.80219 .14688 L
.80229 .14684 L
.80241 .14681 L
.80253 .14677 L
s
.81784 .14178 m
.81774 .14181 L
.81765 .14184 L
.81756 .14187 L
.81748 .14189 L
.8174 .14192 L
.81734 .14194 L
.81728 .14196 L
.81722 .14198 L
.81718 .14199 L
.81714 .142 L
.81711 .14202 L
.81708 .14202 L
.81707 .14203 L
.81706 .14203 L
.81705 .14203 L
.81706 .14203 L
.81707 .14203 L
.81708 .14202 L
.81711 .14202 L
.81714 .142 L
.81718 .14199 L
.81722 .14198 L
.81728 .14196 L
.81734 .14194 L
.8174 .14192 L
.81748 .14189 L
.81756 .14187 L
.81765 .14184 L
.81774 .14181 L
.81784 .14178 L
s
.83316 .13679 m
.83308 .13681 L
.833 .13684 L
.83293 .13686 L
.83287 .13688 L
.83281 .1369 L
.83275 .13692 L
.83271 .13693 L
.83266 .13695 L
.83263 .13696 L
.8326 .13697 L
.83257 .13698 L
.83255 .13698 L
.83254 .13699 L
.83253 .13699 L
.83253 .13699 L
.83253 .13699 L
.83254 .13699 L
.83255 .13698 L
.83257 .13698 L
.8326 .13697 L
.83263 .13696 L
.83266 .13695 L
.83271 .13693 L
.83275 .13692 L
.83281 .1369 L
.83287 .13688 L
.83293 .13686 L
.833 .13684 L
.83308 .13681 L
.83316 .13679 L
s
.84847 .1318 m
.84841 .13182 L
.84836 .13183 L
.8483 .13185 L
.84825 .13187 L
.84821 .13188 L
.84817 .1319 L
.84813 .13191 L
.8481 .13192 L
.84808 .13193 L
.84805 .13193 L
.84803 .13194 L
.84802 .13194 L
.84801 .13195 L
.848 .13195 L
.848 .13195 L
.848 .13195 L
.84801 .13195 L
.84802 .13194 L
.84803 .13194 L
.84805 .13193 L
.84808 .13193 L
.8481 .13192 L
.84813 .13191 L
.84817 .1319 L
.84821 .13188 L
.84825 .13187 L
.8483 .13185 L
.84836 .13183 L
.84841 .13182 L
.84847 .1318 L
s
.86379 .12681 m
.86375 .12682 L
.86371 .12683 L
.86367 .12684 L
.86364 .12685 L
.86361 .12686 L
.86359 .12687 L
.86356 .12688 L
.86354 .12689 L
.86352 .12689 L
.86351 .1269 L
.8635 .1269 L
.86349 .12691 L
.86348 .12691 L
.86348 .12691 L
.86347 .12691 L
.86348 .12691 L
.86348 .12691 L
.86349 .12691 L
.8635 .1269 L
.86351 .1269 L
.86352 .12689 L
.86354 .12689 L
.86356 .12688 L
.86359 .12687 L
.86361 .12686 L
.86364 .12685 L
.86367 .12684 L
.86371 .12683 L
.86375 .12682 L
.86379 .12681 L
s
.8791 .12182 m
.87908 .12182 L
.87906 .12183 L
.87905 .12184 L
.87903 .12184 L
.87902 .12185 L
.879 .12185 L
.87899 .12185 L
.87898 .12186 L
.87897 .12186 L
.87896 .12186 L
.87896 .12186 L
.87895 .12187 L
.87895 .12187 L
.87895 .12187 L
.87895 .12187 L
.87895 .12187 L
.87895 .12187 L
.87895 .12187 L
.87896 .12186 L
.87896 .12186 L
.87897 .12186 L
.87898 .12186 L
.87899 .12185 L
.879 .12185 L
.87902 .12185 L
.87903 .12184 L
.87905 .12184 L
.87906 .12183 L
.87908 .12182 L
.8791 .12182 L
s
.89442 .11683 m
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
.89442 .11683 L
s
.90973 .11184 m
.90975 .11183 L
.90977 .11182 L
.90979 .11182 L
.90981 .11181 L
.90982 .11181 L
.90984 .1118 L
.90985 .1118 L
.90986 .1118 L
.90987 .11179 L
.90988 .11179 L
.90988 .11179 L
.90989 .11179 L
.90989 .11179 L
.90989 .11179 L
.9099 .11179 L
.90989 .11179 L
.90989 .11179 L
.90989 .11179 L
.90988 .11179 L
.90988 .11179 L
.90987 .11179 L
.90986 .1118 L
.90985 .1118 L
.90984 .1118 L
.90982 .11181 L
.90981 .11181 L
.90979 .11182 L
.90977 .11182 L
.90975 .11183 L
.90973 .11184 L
s
.92505 .10685 m
.92509 .10683 L
.92513 .10682 L
.92516 .10681 L
.9252 .1068 L
.92523 .10679 L
.92525 .10678 L
.92528 .10677 L
.9253 .10677 L
.92532 .10676 L
.92533 .10676 L
.92535 .10675 L
.92536 .10675 L
.92536 .10675 L
.92537 .10674 L
.92537 .10674 L
.92537 .10674 L
.92536 .10675 L
.92536 .10675 L
.92535 .10675 L
.92533 .10676 L
.92532 .10676 L
.9253 .10677 L
.92528 .10677 L
.92525 .10678 L
.92523 .10679 L
.9252 .1068 L
.92516 .10681 L
.92513 .10682 L
.92509 .10683 L
.92505 .10685 L
s
.94036 .10186 m
.94043 .10184 L
.94048 .10182 L
.94054 .1018 L
.94059 .10179 L
.94063 .10177 L
.94067 .10176 L
.94071 .10175 L
.94074 .10174 L
.94077 .10173 L
.94079 .10172 L
.94081 .10171 L
.94082 .10171 L
.94083 .10171 L
.94084 .1017 L
.94084 .1017 L
.94084 .1017 L
.94083 .10171 L
.94082 .10171 L
.94081 .10171 L
.94079 .10172 L
.94077 .10173 L
.94074 .10174 L
.94071 .10175 L
.94067 .10176 L
.94063 .10177 L
.94059 .10179 L
.94054 .1018 L
.94048 .10182 L
.94043 .10184 L
.94036 .10186 L
s
.95568 .09687 m
.95576 .09684 L
.95584 .09682 L
.95591 .09679 L
.95597 .09677 L
.95603 .09675 L
.95609 .09674 L
.95614 .09672 L
.95618 .09671 L
.95621 .09669 L
.95625 .09668 L
.95627 .09668 L
.95629 .09667 L
.95631 .09666 L
.95631 .09666 L
.95632 .09666 L
.95631 .09666 L
.95631 .09666 L
.95629 .09667 L
.95627 .09668 L
.95625 .09668 L
.95621 .09669 L
.95618 .09671 L
.95614 .09672 L
.95609 .09674 L
.95603 .09675 L
.95597 .09677 L
.95591 .09679 L
.95584 .09682 L
.95576 .09684 L
.95568 .09687 L
s
0 0 m
1 0 L
1 .43672 L
0 .43672 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[89]:=",
  ImageSize->{288, 125.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000OB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolBooooo`?o00003?oo
ool00?oooooo4_ooool01?l0003oooooooooool0000;ooooo`00oooooolEooooo`03o`000?oooooo
oooo00Wooooo003ooooooa?ooooo0_l0000<ooooo`00oooooolBooooo`03o`000?oooooooooo00co
oooo003ooooooa;ooooo00Co0000oooooooooooo00002oooool00?oooooo4oooool3o`0000_ooooo
003oooooob7ooooo003oooooob7ooooo003ooooooa?ooooo0_l0000<ooooo`00oooooolCooooo`03
o`000?oooooooooo00_ooooo0006ooooo`?o00001?ooool8o`0000;ooooo00Co0000ooooool0003o
oooo0_l0003eooooo`03o`000?oooooooooo00_ooooo0007ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00001?ooool01ol0003oooooo`000?oooooo0000ooooool00000m_ooool0
0ol0003oooooooooo`0;ooooo`001oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool2
o`0000;ooooo00Go0000ooooool0003oooooo`00003fooooo`03o`000?oooooooooo00_ooooo0007
ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00004ooooo`05
o`000?oooooo0000ooooool00000m_ooool00ol0003oooooooooo`0;ooooo`001oooool01Ol0003o
ooooooooool0003ooooo00Go00000_ooool8o`000?Oooooo00?o0000ooooooooool02oooool000Oo
oooo00Co0000oooooooooooo0000ooooool8ooooo`03o`000?oooooooooo00_ooooo0006ooooo`Co
00001_ooool00ol0003oooooooooo`3oooooo`03o`000?oooooooooo00_ooooo003ooooooa?ooooo
00?o0000ooooooooool02oooool00?oooooo4oooool00ol0003oooooooooo`0;ooooo`006Ooooom^
o`0008_ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`0@ooooo`Ko0000L_ooool2o`WZ2P03o`000?oooooooooo00_ooooo000Jooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo0000
06oooooo0ol9jPX2ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1_ooooo`?o2NX:1?ooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0K_ooool01?l9jP[oooooooooool9jPX5o`0000gooooo000Looooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1/ooooo`;o2NX:
1ol000000ooooooo0000ooooo`0<ooooo`007?ooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0JOooool3o`WZ2P03ooooool9jP[o2NX:00?o000000Go
2NX:o`000?ooooooooooo`00000=ooooo`007Oooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo01Cooooo0ol0001Wooooo`Co2NX:0_ooool2o`0000;o2NX:00Coooooo`000?l9jP[o2NX:
0_ooool00ol0003oooooooooo`0;ooooo`007Oooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo07cooooo0_l9jPX3ooooo`?o000000Go2NX:ooooool9jP[oooooo`000002ooooo`04o`WZ
2_ooooooooooo`0000;o2NX:2oooool001kooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`1looooo`03o`WZ2_oooooo2NX:00?o00000_l9jPX3ooooo`03o`WZ2_l0003ooooo00Ko2NX:
3Oooool001kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1jooooo`;o2NX:0_l0
0002o`WZ2P?ooooo1ol9jPX5ooooo`03o`000?oooooooooo00_ooooo000Oooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool05?ooool;o`0005Wooooo0_l9jPX01_l0003o2NX:o`000?l9
jP[oooooo`WZ2P;ooooo0ol9jPX;ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool05Oooool;o`0005Oooooo00Co2NX:o`000?l0003o0000
2?l9jPX>ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool05Oooool00ol0003oOgmoogmoO`07ogmoO`03o`000?oooooooooo05?ooooo0ol0
0005o`WZ2QCooooo00?o0000ooooooooool02oooool0027ooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Eooooo`;o00002OmoOgl2o`00053ooooo00Co2NX:o`000?l9jP[o00000_l9
jPXJooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool05Oooool=o`0004[ooooo1?l9jPX3o`0000;o2NX:7Oooool00ol0003oooooooooo`0;
ooooo`008_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01Kooooo0_l00009ogmo
O`;o0000Aoooool3o`WZ2P04ooooool0003o0000o`0000;o2NX:8?ooool00ol0003oooooooooo`0;
ooooo`008_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01Gooooo00?o0000ogmo
Ool000002OmoOgl00ol0003oOgmoo`000010ooooo`Oo2NX:0_l00003o`WZ2R?ooooo00?o0000oooo
ooooool02oooool002?ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Fooooo`03
o`000?moOgoo000000WoOgmo00?o0000ogmoOol00000>_ooool7o`WZ2P;ooooo0ol9jPX00ol0003o
ooooooooo`02o`WZ2RCooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`0Gooooo`03o`000?moOgoo000000WoOgmo00?o0000ogmoOol00000
=?ooool6o`WZ2P03ooooool9jP[ooooo00?ooooo00Co2NX:o`000?l0003o00000_l9jPX00ooooooo
2NX:o`WZ2P0Vooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool05oooool00ol0003oOgmoo`00000:o`000003ogmoOol0003ooooo033ooooo
0ol9jPX3ooooo`05o`WZ2_ooooooooooooooool9jPX00_ooool2o`000004o`WZ2_oooooooooooooo
o`?o2NX::?ooool00ol0003oooooooooo`0;ooooo`009Oooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo01Oooooo00Co0000ogmoOomoOgoo00002OmoOgl01?l0003oOgmoogmoOol0000Z
ooooo`Ko2NX:00?oooooo`WZ2_ooool00oooool01ol9jP[ooooooooooooooooo0000o`WZ2_l00000
0_ooool2o`WZ2P03ooooool9jP[ooooo02[ooooo00?o0000ooooooooool02oooool002Gooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`0Gooooo`04o`000?moOgooOgmoo`0000WoOgmo
00Co0000ogmoOomoOgoo00009?ooool6o`WZ2P?ooooo00Co2NX:oooooooooooooooo0_l9jPX3oooo
o`06o`WZ2_l0003o0000o`000?oooooo2NX:1?ooool2o`WZ2Rcooooo00?o0000ooooooooool02ooo
ool002Kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Hooooo`04o`000?moOgoo
Ogmoo`0000WoOgmo00Co0000ogmoOomoOgoo00007_ooool7o`WZ2PCooooo00Go2NX:oooooooooooo
ooooo`WZ2P04ooooo`04o`WZ2_oooooo0000o`0000;o2NX:0oooool5o`WZ2Rkooooo00?o0000oooo
ooooool02oooool002Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Iooooo`04
o`000?moOgooOgmoo`0000WoOgmo00Co0000ogmoOomoOgoo00006oooool3o`WZ2P;ooooo00Go2NX:
ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool00ol0003o2NX:
o`000003ooooo`04o`WZ2_ooooooooooooooo`;o2NX:<Oooool00ol0003oooooooooo`0;ooooo`00
9oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01Wooooo00Co0000ogmoOomoOgoo
00002OmoOgl01?l0003oOgmoogmoOol0000Eooooo`Oo2NX:1?ooool01Ol9jP[ooooooooooooooooo
2NX:00Cooooo00?o2NX:ooooooooool00_ooool01?l9jP[o0000o`000?ooool2o`WZ2P?ooooo1?l9
jPXcooooo`03o`000?oooooooooo00_ooooo000Xooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool06Oooool01Ol0003oOgmoogmoOomoOgoo000000WoOgmo00Go0000ogmoOomoOgooOgmo
o`00000>ooooo`Ko2NX:0_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Co2NX:oooooooo
oooooooo0_l9jPX3ooooo`03o`WZ2_oooooo000000;o000000?o2NX:ooooooooool00_ooool01?l9
jP[oooooooooooooool2o`WZ2SGooooo00?o0000ooooooooool02oooool002Sooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0Iooooo`04o`000?moOgooOgmoogmoO`_o00000omoOgl0
0ol0003oooooooooo`06ooooo`Ko2NX:0oooool00ol9jP[oooooooooo`02ooooo`04o`WZ2_oooooo
ooooooooo`;o2NX:0oooool00ol9jP[oooooooooo`02ooooo`04o`WZ2_ooooooooooo`0000;o2NX:
0oooool00ol9jP[oooooooooo`02ooooo`Co2NX:=oooool00ol0003oooooooooo`0;ooooo`00:Ooo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01[ooooo00Go0000ogmoOomoOgooOgmo
o`000009ogmoO`05o`000?moOgooOgmoogmoOol000000_ooool6o`WZ2P03ooooool9jP[ooooo00;o
oooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooo
ooooooooooooo`WZ2P04ooooo`;o2NX:00Co0000oooooooooooo2NX:1?ooool00ol9jP[ooooooooo
o`03o`WZ2SWooooo00?o0000ooooooooool02oooool002Wooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Jooooo`05o`000?moOgooOgmoogmoOol000002OmoOgl00ol0003oOgmoo`WZ
2P04o`WZ2P;ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo
00Go2NX:ooooooooooooooooo`WZ2P04ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0ol000000ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo0ol9jPXlooooo`03o`000?oooooooooo
00_ooooo000Zooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool06oooool01Ol0003o
OgmoogmoOomoOgoo000000GoOgmo1_l9jPX2ogmoO`03o`000?l9jP[ooooo00;ooooo00?o2NX:oooo
ooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Co2NX:oooooooooooooooo0_l9
jPX3ooooo`03o`WZ2_oooooooooo00;o00000_l9jPX3ooooo`03o`WZ2_oooooooooo00;ooooo00Go
2NX:ooooooooooooooooo`WZ2P0nooooo`03o`000?oooooooooo00_ooooo000[ooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool06oooool00ol0003oOgmoogmoO`02ogmoO`Oo2NX:0omo
Ogl00ol9jP[oOgmoogmoO`02ogmoO`05o`WZ2_ooooooooooooooool9jPX01?ooool01?l9jP[ooooo
ooooooooool2o`WZ2P?ooooo00?o2NX:ooooooooool00_ooool02Ol9jP[ooooooooooooooooo0000
o`WZ2_l0003o2NX:ooooo`02o`WZ2P?ooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooo`WZ
2_l9jPXoooooo`03o`000?oooooooooo00_ooooo000[ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool06_ooool6o`WZ2P03o`000?l9jP[oOgmo00?oOgmo00Ko2NX:ogmoOomoOgooOgmo
o`000?l9jPX3ogmoO`04o`WZ2_ooooooooooooooo`;o2NX:0oooool00ol9jP[oooooooooo`02oooo
o`05o`WZ2_ooooooooooooooool9jPX00oooool3o`WZ2P;o00000_l9jPX4ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00ol9jPY1ooooo`03o`000?oooooooooo00_ooooo000Boooo
o`?o2NX:5oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Oooooo1?l9jPX01?oo
oooo0000ogmoOol9jPX2ogmoO`03o`000?moOgoo2NX:00?oOgmo00Ko2NX:ogmoOomoOgooOgmoo`00
0?l9jPX3ogmoO`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03
o`WZ2_oooooooooo00;ooooo0_l9jPX3o`000005o`WZ2_ooooooooooooooool9jPX01?ooool00ol9
jP[oooooooooo`02ooooo`?o2NX:A?ooool00ol0003oooooooooo`0;ooooo`004Oooool01?l9jP[o
ooooooooooooool2o`WZ2QGooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Doooo
o`?o2NX:0_ooool01_l9jP[oooooooooool0003oOgmoo`WZ2P;oOgmo00?o0000ogmoOol9jPX00omo
Ogl01_l9jP[oOgmoogmoOomoOgoo0000o`WZ2P?oOgmo00?o2NX:ooooooooool00_ooool01?l9jP[o
ooooooooooooool2o`WZ2P?ooooo00Go2NX:ooooool9jP[o2NX:o`000002o`WZ2P?ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX0A_oo
ool00ol0003oooooooooo`0;ooooo`004Oooool00ol9jP[oooooooooo`03ooooo`?o2NX:4oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo01;ooooo0ol9jPX6ooooo`05o`WZ2_oooooo
0000ogmoOol9jPX00_moOgl2o`000005o`WZ2_l0003o0000o`000?l9jPX01?l000001Ol9jP[oOgmo
ogmoOomoOgoo2NX:00Cooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooooooooooool2o`WZ
2P;o000000?oooooo`WZ2_ooool00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00;ooooo00Co2NX:ooooool9jP[o2NX:Aoooool00ol0003oooooooooo`0;ooooo`004Oooool01?l9
jP[oooooooooooooool2o`WZ2P?ooooo0ol9jPX@ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool03oooool3o`WZ2P?ooooo00?o2NX:ooooooooool00oooool01Ol9jP[oooooo`000?mo
Ogoo2NX:00;oOgmo00?o0000ogmoOol9jPX01?moOgl01Ol9jP[oOgmoogmoOol0003o2NX:00?oOgmo
00?o0000o`WZ2_ooool00_ooool00ol9jP[oooooooooo`02ooooo`;o2NX:0ol000000ol9jP[ooooo
ooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooo
ooooo`03o`WZ2TWooooo00?o0000ooooooooool02oooool0013ooooo0_l9jPX3ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00ol9jPX>ooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03Oooool3o`WZ2PKooooo00?o2NX:ooooooooool00oooool00ol9jP[oooooo`00
0002ogmoO`05o`WZ2_moOgoo0000ogmoOol9jPX01?moOgl01?l9jP[oOgmoogmoOol00002o`WZ2P;o
Ogmo00?o0000o`WZ2_ooool00oooool01?l9jP[oooooo`WZ2_l00002o`WZ2P?ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo0ol9jPY<oooo
o`03o`000?oooooooooo00_ooooo000@ooooo`03o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooo
oooooooo0_l9jPX5ooooo`?o2NX:3?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00cooooo0_l9jPX5ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooo`000002ogmoO`04o`WZ2_moOgoo0000ogmoO`;o2NX:0omoOgl01_l9jP[oOgmoogmoOol0
003oOgmoo`WZ2P;oOgmo00?o0000o`WZ2_ooool00_ooool3o`WZ2P04o`000?ooooooooooo`WZ2PCo
oooo00Co2NX:oooooooooooooooo0_l9jPX3ooooo`;o2NX:0_ooool00ol9jP[oooooooooo`1=oooo
o`03o`000?oooooooooo00_ooooo000@ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo0ol9jPX9ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool02Oooool3o`WZ2P;ooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:o`000?moOgl00_moOgl00ol9
jP[oOgmoo`000002ogmoO`05o`WZ2_moOgooOgmoogmoOol9jPX00_moOgl00ol0003oOgmoo`WZ2P03
ogmoO`?o2NX:0_l000000ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`?o2NX:D?ooool00ol0003oooooooooo`0;
ooooo`003oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo0ol9jPX7ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool01oooool3o`WZ2PKooooo00Go2NX:ooooooooooooooooo`WZ
2P04ooooo`03o`WZ2_oooooooooo00?ooooo00Oo2NX:ogmoOomoOgooOgmoo`WZ2_moOgoo000000;o
Ogmo00Go2NX:ogmoOomoOgooOgmoo`WZ2P04o`000003o`WZ2_l0003o000000?o00001?ooool01?l9
jP[oooooooooooooool2o`WZ2P?ooooo0_l9jPX3ooooo`;o2NX:0_ooool2o`WZ2U;ooooo00?o0000
ooooooooool02oooool000oooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02oooo
o`04o`WZ2_ooooooooooooooo`;o2NX:0oooool00ol9jP[oooooooooo`04ooooo`;o2NX:1Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Cooooo0ol9jPX4ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooooooooooool2o`WZ2PCooooo00Co
2NX:ogmoOomoOgooOgmo0_l9jPX01?l0003oOgmoogmoOol9jPX4ogmoO`05o`WZ2_l0003o0000o`00
0?l9jPX00_l000000omoOgoo0000o`WZ2P04ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooo
ooooool00_ooool00ol9jP[oooooooooo`02ooooo`?o2NX:E?ooool00ol0003oooooooooo`0;oooo
o`003oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:ooooooooool00_ooool00ol9
jP[oooooooooo`02ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool3o`WZ2P?ooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`02ooooo`?o2NX:0oooool01?l9jP[ooooooooooooo
ool2o`WZ2P?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ogmoOomoOgl00_moOgl01?l9jP[o0000ogmoOomoOgl2o`WZ2P?o0000
00Ko2NX:o`000?l0003o0000ogmoOol9jPX2ogmoO`03o`000?oooooo2NX:00?ooooo00?o2NX:oooo
ooooool00_ooool2o`WZ2P?ooooo1Ol9jPYGooooo`03o`000?oooooooooo00_ooooo000>ooooo`03
o`WZ2_l0003o2NX:00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`04
o`WZ2_ooooooooooooooo`;o2NX:0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00?o2NX:00?o0000ooooooooool0>Oooool00ol0003oooooo`WZ2P02o`WZ2P03ooooool9jP[ooooo
00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`04o`WZ2_oooooooooo
ooooo`;o2NX:0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_l0003o000000;o00000_l9jPX2
o`000003o`WZ2_l0003o000000Oo000000Ko2NX:o`000?l0003o0000ooooool9jPX4ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`1Hooooo`;o0000
3?ooool000kooooo00?o2NX:ooooool000000_l000001Ol9jP[ooooooooooooooooo2NX:00Cooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00oooool3o`WZ2SSooooo0ol9jPX5ooooo`05o`WZ2_ooooooooooooooool9
jPX01?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00_ooool01?l9jP[oooooooooooooool2o`WZ2PGo00000omoOgl01ol9jP[oOgmoogmoOomoOgoo
2NX:ogmoOol000000_moOgl01Ol9jP[oOgmoogmoOol0003ooooo00;o2NX:0oooool2o`WZ2PCooooo
00Co2NX:ooooool9jP[o2NX:Foooool00ol0003oooooooooo`0;ooooo`003Oooool2o`WZ2P?ooooo
00Co2NX:o`000?l0003o00000_l9jPX4ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00_ooool01?l9jP[oooooooooooooool2o`WZ2P?ooooo00Go2NX:ooooooooooooooooo`000003
o`WZ2PSooooo8_l9jPX9ooooo`;o2NX:0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o
2NX:o`000?l000002?l00003ogmoO`03o`WZ2_l0003oOgmo00;oOgmo00?o2NX:ogmoOomoOgl00_mo
Ogl01Ol9jP[o0000ogmoOomoOgoo2NX:00;oOgmo00Co0000oooooooooooo2NX:1?ooool00ol9jP[o
ooooooooo`02ooooo`;o2NX:GOooool00ol0003oooooooooo`0;ooooo`003Oooool00ol9jP[ooooo
ooooo`02ooooo`05o`WZ2_ooooooooooooooool000000_l9jPX3ooooo`05o`WZ2_oooooooooooooo
ool9jPX01?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00Ko2NX:oooo
ooooooooooooo`000?l9jPX2ooooo`?o2NX:1Oooool00ol9jP[oooooooooo`0Nooooo`03o`WZ2_oo
oooooooo00Cooooo0ol9jPX00ooooooo2NX:ooooo`02ooooo`;o2NX:0oooool00ol9jP[ooooooooo
o`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[ooooooooo
o`02ooooo`05o`WZ2_oooooo2NX:o`000?l9jPX00_l000000ooooooo0000o`WZ2P03ogmoO`;o2NX:
0omoOgl00ol9jP[oOgmoogmoO`02ogmoO`04o`WZ2_l0003oOgmoogmoO`;o2NX:00GoOgmoo`000?oo
ooooooooo`WZ2P04ooooo`Go2NX:Goooool00ol0003oooooooooo`0;ooooo`003Oooool01?l9jP[o
ooooooooooooool2o`WZ2P?ooooo00?o2NX:ooooool000000_l000000ol9jP[oooooooooo`02oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooooooooooool2
o`WZ2P?ooooo00?o2NX:o`000?ooool01?ooool2o`WZ2P04ooooool9jP[oooooo`WZ2P;ooooo00Go
2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[o
oooooooooooooooo2NX:00Cooooo00?o2NX:ooooooooool00_l9jPX2ooooo`?o2NX:0oooool00ol0
003o2NX:ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooooooooooo0_l9jPX3
ooooo`03o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooooooooooo0_l9jPX4o`000005o`WZ2_oo
ooooooooo`000?l9jPX01?moOgl01?l9jP[oOgmoogmoOomoOgl2o`WZ2P?oOgmo00?o2NX:o`000?mo
Ogl00_moOgl00ol9jP[oOgmoo`000003ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool0H?ooool00ol0003oooooooooo`0;ooooo`003?ooool2o`WZ2P?ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_l0003o000000;ooooo00Go2NX:oooooooooooo
ooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
0000ooooo`02ooooo`04o`WZ2_ooooooooooooooo`Co2NX:0_ooool01Ol9jP[ooooooooooooooooo
2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX0
1?ooool01?l9jP[oooooo`WZ2_ooool3o`WZ2P?ooooo00Co2NX:oooooooooooo00000_l9jPX3oooo
o`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooooooooooool2
o`WZ2P?ooooo0ol9jPX3o`000005ooooool0003o0000ooooool9jPX00_ooool00ol0003o2NX:ogmo
O`03ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00Ko2NX:ogmoOomoOgooOgmoo`WZ2_l00003ogmoO`03
o`WZ2_moOgoo000000?ooooo0_l9jPX00ooooooo2NX:o`WZ2P1Sooooo`03o`000?oooooooooo00_o
oooo000<ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool01?l9jP[ooooo
ooooooooool4o`WZ2P?o00000oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooo`000?ooool2o`WZ2P?ooooo0_l9jPX01Ooo
oooo2NX:oooooooooooo2NX:00?ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooo
oooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ2_oooooo2NX:00?o2NX:
1?ooool00ol9jP[oooooo`000002ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooooooooooo
ooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00;ooooo00Oo2NX:ooooool9jP[o2NX:o`000?l9jP[o
000000;ooooo00?o2NX:o`000?ooool00_ooool01_l9jP[ooooooooooooooooo0000o`WZ2P?oOgmo
00?o2NX:ogmoOomoOgl00_moOgl00ol9jP[oOgmoogmoO`02ogmoO`06o`WZ2_moOgooOgmoogmoOol9
jP[o00001?ooool3o`WZ2VGooooo00?o0000ooooooooool02oooool000cooooo00Co2NX:oooooooo
oooooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool2o`WZ
2P;o000000?oooooo`WZ2_ooool00oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Ko2NX:
oooooooooooo0000ooooool9jPX4ooooo`;o2NX:1?ooool01Ol9jP[ooooooooooooooooo2NX:00Co
oooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool0
1ol9jP[ooooooooooooooooo2NX:ooooool9jPX00oooool00ol9jP[oooooo`000002ooooo`03o`WZ
2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooooooooooool2o`WZ2P;o
oooo0_l9jPX3o`000003ooooool9jP[ooooo00?ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[o
ooooooooool0003o2NX:00?oOgmo0_l9jPX3ogmoO`03o`WZ2_moOgooOgmo00;oOgmo00Co2NX:ogmo
OomoOgooOgmo0_l9jPX3ooooo`03o`WZ2_oooooooooo06Kooooo00?o0000ooooooooool02oooool0
00_ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00;ooooo00Co2NX:oooooooooooooooo0_l9jPX2ooooo`;o2NX:0_l00002ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00_ooool01_l9jP[ooooooooooooooooo0000o`WZ2P?ooooo
0ol9jPX4ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:
00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`07o`WZ2_ooooooooooooooool9jP[ooooo
o`WZ2P03ooooo`;o2NX:0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00_ooool2o`WZ2P?o000000Co2NX:oooooooooooooooo0_l9jPX3ooooo`03
o`WZ2_oooooooooo00;ooooo00Go2NX:oooooooooooo0000o`WZ2P03ogmoO`03o`000?l9jP[oOgmo
00;oOgmo0_l9jPX3ogmoO`04o`WZ2_moOgooOgmoogmoO`Go2NX:JOooool00ol0003oooooooooo`0;
ooooo`002oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00Co2NX:oooo
oooooooooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooool9jPX00ol00004
ooooo`03o`WZ2_oooooooooo00;ooooo00Ko2NX:ooooooooooooooooo`WZ2_l00003ooooo`03o`WZ
2_oooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooooooooooo
ool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Oo2NX:ooooooooooooooooo`WZ
2_oooooo2NX:00?ooooo00?o0000o`WZ2_ooool00oooool00ol9jP[oooooooooo`02ooooo`05o`WZ
2_ooooooooooooooool9jPX00_ooool01?l9jP[o0000o`WZ2_l00003ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00;ooooo00?o0000
o`WZ2_moOgl00_moOgl00ol0003o2NX:o`000003o`000003o`WZ2_l0003o000000;o00000ol9jPX0
0omoOgoo0000ooooo`1[ooooo`03o`000?oooooooooo00_ooooo000;ooooo`05o`WZ2_oooooooooo
ooooool9jPX01?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool00_ooool01?l9jP[oooooooooooooool2o`WZ2P;o000000?oooooo`WZ2_ooool00ooo
ool00ol9jP[oooooooooo`02ooooo`03o`WZ2_l0003ooooo00;ooooo00?o2NX:ooooool9jPX01?oo
ool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05
o`WZ2_ooooooooooooooool9jPX01?ooool01_l9jP[ooooooooooooooooo2NX:ooooo`;o2NX:0_oo
ool00ol0003o2NX:ooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooooooooooo
0_l9jPX2o`0000;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00;o
oooo00?o2NX:ooooooooool00_ooool01Ol9jP[oooooo`000?moOgoo2NX:00;oOgmo00?o0000o`WZ
2_moOgl00omoOgl00ol9jP[oOgmoo`WZ2P02o`WZ2PCoOgmo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`0;ooooo`002_ooool3o`WZ2P;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`02ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool00ol9jP[oooooooooo`02oooo
o`07o`WZ2_ooooooooooo`WZ2_l0003o2NX:o`000003ooooo`03o`WZ2_oooooooooo00;ooooo00Go
2NX:ooooool0003oooooo`WZ2P02ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooooooooooo
ooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo
2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P02ooooo`03o`WZ2_oooooo000000;ooooo00Co
2NX:oooooooooooooooo0_l9jPX3ooooo`;o2NX:0ol000000ol9jP[oooooooooo`02ooooo`03o`WZ
2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00;o
oooo00Go2NX:ooooool0003oOgmoo`WZ2P02ogmoO`03o`000?moOgoo2NX:00;oOgmo0ol9jPX2ogmo
O`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0;oooo
o`003Oooool3o`WZ2P?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooooooooooool3o`WZ
2P?o000000Co2NX:oooooooooooooooo0_l000001?oooooo0000ooooool9jPX2ooooo`03o`WZ2_oo
oooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9
jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P02
ooooo`03o`WZ2_oooooo000000;ooooo00?o2NX:ooooooooool00_ooool01?l9jP[oooooo`WZ2_l0
0002o`WZ2P?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00;ooooo00Co2NX:oooooooooooooooo0_l9jPX3ooooo`06o`WZ2_oooooo0000ogmoOol9
jP[oOgmo1_l9jPX5ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`0;ooooo`004?ooool4o`WZ2PCooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool00ol9jP[oooooooooo`02oooo
o`05o`WZ2_l0003o0000o`000?ooool00ol000000ooooooo0000o`WZ2P02ooooo`03o`WZ2_oooooo
oooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX0
1?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P03oooo
o`05o`WZ2_ooooooooooooooool9jPX00oooool2o`WZ2P;o00000_ooool00ol9jP[oooooooooo`02
ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00;ooooo00?o2NX:ooooooooool00_ooool5o`WZ2P03ogmoOol0003oOgmo00SoOgmo00?o
0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00_ooooo000C
ooooo`?o2NX:00?oooooo`WZ2_l9jPX00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00;o2NX:1Ol00003ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ
2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Co
oooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Co2NX:o`00
0?l0003o00000_l9jPX3ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool0
0ol9jP[oooooooooo`02ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool00ol9jP[ooooooooo
o`02o`WZ2P03ooooool0003oOgmo00?oOgmo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmo
O`02ogmoO`03o`000?oooooooooo06[ooooo00?o0000ooooooooool02oooool001Kooooo0ol9jPX3
ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02
ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool00ol9jP[o0000o`000004o`0000;ooooo00?o
2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooooooooooo
ooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX00_ooool3o`0000?ooooo00Go2NX:oooo
oooooooo0000o`WZ2P02ooooo`;o000000?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02
ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oo
oooooooo00;ooooo00Co2NX:oooooooooooooooo0ol9jPX4ooooo`05o`000?moOgooOgmoogmoOol0
00002OmoOgl01Ol0003oOgmoogmoOomoOgoo000006gooooo00?o0000ooooooooool02oooool001Wo
oooo0_l9jPX00ooooooo2NX:ooooo`02ooooo`;o2NX:0oooool00ol9jP[oooooooooo`02ooooo`03
o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooooooooooo1_l000001Ol9jP[o0000o`000?oooooo
2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX0
1?ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo1_l000001_oooooo0000ooooool0003o2NX:
o`0000;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo
oooo00;ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo1?l9
jPX7ooooo`05o`000?moOgooOgmoogmoOol000002OmoOgl01Ol0003oOgmoogmoOomoOgoo000006go
oooo00?o0000ooooooooool02oooool001_ooooo0ol9jPX2ooooo`03o`WZ2_oooooooooo00;ooooo
00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`02ooooo`04o`WZ2_ooooooooooooooo`;o
2NX:0oooool00ol9jP[o0000o`000002o`000003o`WZ2_l0003o000000;o000000Go2NX:o`000?l0
003o0000o`WZ2P04o`000005o`WZ2_l0003o0000o`000?l9jPX01?l000001Ol9jP[o0000o`000?l0
003o2NX:00Co000000Go2NX:o`000?l0003o0000o`WZ2P03o`000003ooooool9jP[ooooo00?ooooo
00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo2NX:00;o2NX:2_ooool01?l0003o
OgmoogmoOomoOgl;o`0000?oOgmo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0;oooo
o`007_ooool3o`WZ2P?ooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`02ooooo`06o`WZ2_ooooooooooooooool0003o2NX:1?ooool0
1Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ
2_ooooooooooooooool9jPX00oooool5o`000003o`WZ2_l0003ooooo00;ooooo00?o2NX:oooooooo
ool00_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooooooo
ooooooooo`WZ2P04ooooo`04o`WZ2_ooooooooooooooo`?o2NX:3Oooool01Ol0003oOgmoogmoOomo
Ogoo000000WoOgmo00Go0000ogmoOomoOgooOgmoo`00001]ooooo`03o`000?oooooooooo00_ooooo
000Qooooo`Co2NX:1?ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00;ooooo00?o
2NX:ooooooooool00_ooool01_l9jP[ooooooooooooooooo0000o`WZ2PCooooo00Go2NX:oooooooo
ooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooo
oooo2NX:00;ooooo0_l000001_l9jP[ooooooooooooooooo2NX:o`0000Cooooo00Go2NX:oooooooo
ooooooooo`WZ2P04ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool01?l9
jP[oooooooooooooool4o`WZ2Q3ooooo00Go0000ogmoOomoOgooOgmoo`000009ogmoO`05o`000?mo
OgooOgmoogmoOol00000KOooool00ol0003oooooooooo`0;ooooo`009?ooool3o`WZ2P;ooooo00Co
2NX:oooooooooooooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[o
oooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooo
ooooooooool9jPX01Oooool00ol9jP[oooooooooo`02ooooo`04o`WZ2_ooooooooooooooo`;o2NX:
0oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooo2NX:00;o2NX:5?ooool01?l0003oOgmo
ogmoOol00009ogmoO`04o`000?moOgooOgmoo`0006kooooo00?o0000ooooooooool02oooool002Oo
oooo0ol9jPX3ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool00_ooool00ol9jP[o
ooooooooo`03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P04oooo
o`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go
2NX:ooooooooooooooooo`WZ2P05ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooooooool0
0_ooool00ol9jP[oooooooooo`02ooooo`04o`WZ2_ooooooooooooooo`;o2NX:5oooool01?l0003o
OgmoogmoOol00009ogmoO`04o`000?moOgooOgmoo`0006kooooo00?o0000ooooooooool02oooool0
02[ooooo0_l9jPX00ooooooo2NX:ooooo`02ooooo`;o2NX:0oooool00ol9jP[oooooooooo`04oooo
o`03o`WZ2_l0003ooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooo
ooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooooooooooo
0000o`WZ2P06ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool00ol9jP[oooooooooo`03oooo
o`?o2NX:6Oooool01?l0003oOgmoogmoOol00009ogmoO`04o`000?moOgooOgmoo`0006kooooo00?o
0000ooooooooool02oooool002cooooo0ol9jPX2ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:
ooooooooool01?ooool00ol9jP[oooooo`000002ooooo`05o`WZ2_ooooooooooooooool9jPX01?oo
ool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05
o`WZ2_oooooo0000ooooool9jPX01_ooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo
00;ooooo00?o2NX:ooooool9jPX00_l9jPXLooooo`03o`000?moOgooOgmo00_o00000_moOgl00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo00_ooooo000_ooooo`?o2NX:1?ooool00ol9jP[o
ooooooooo`04ooooo`03o`WZ2_oooooo000000;ooooo00Go2NX:ooooooooooooooooo`WZ2P04oooo
o`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go
2NX:ooooool0003oooooo`WZ2P06ooooo`03o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooooooo
oooo0ol9jPXOooooo`04o`000?moOgooOgmoo`0000WoOgmo00Co0000ogmoOomoOgoo0000K_ooool0
0ol0003oooooooooo`0;ooooo`00<_ooool4o`WZ2POooooo00Ko2NX:oooooooooooo0000ooooool9
jPX3ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ
2_ooooooooooooooool9jPX01?ooool01Ol9jP[o0000oooooooooooo2NX:00Oooooo00?o2NX:oooo
ooooool00_ooool3o`WZ2R?ooooo00?o0000ogmoOol000002OmoOgl00ol0003oOgmoo`00001_oooo
o`03o`000?oooooooooo00_ooooo000eooooo`?o2NX:1Oooool01Ol9jP[oooooooooool0003o2NX:
00Cooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:
ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_l0003oooooooooool9jPX01oooool00ol9jP[ooooo
o`WZ2P02o`WZ2RKooooo00?o0000ogmoOol000002OmoOgl00ol0003oOgmoo`00001_ooooo`03o`00
0?oooooooooo00_ooooo000hooooo`;o2NX:0oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo
00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooooooo
ooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01_ooool3o`WZ2RWooooo00?o0000
ogmoOol000002OmoOgl00ol0003oOgmoo`00001_ooooo`03o`000?oooooooooo00_ooooo000joooo
o`04o`WZ2_ooooooooooo`WZ2P?ooooo00?o2NX:o`000?ooool00_ooool00ol9jP[oooooooooo`02
ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo
00?o0000o`WZ2_ooool00_ooool01?l9jP[oooooooooooooool3o`WZ2Rgooooo0_l00009ogmoO`;o
0000L?ooool00ol0003oooooooooo`0;ooooo`00>oooool00ol9jP[oooooo`WZ2P03ooooo`03o`WZ
2_l0003ooooo00;ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Co
oooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`000?l9jP[ooooo00;ooooo00Co2NX:oooo
oooooooo2NX:<?ooool=o`00073ooooo00?o0000ooooooooool02oooool003cooooo0_l9jPX3oooo
o`03o`WZ2_oooooo000000;ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo
2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P02ooooo`03o`000?oooooo2NX:00?ooooo0ol9
jPXaooooo`;o00002OmoOgl2o`00073ooooo00?o0000ooooooooool02oooool003gooooo00?o2NX:
ooooooooool00oooool00ol0003oooooooooo`0Booooo`06o`WZ2_ooooooooooo`000?oooooo2NX:
0oooool00ol9jP[oooooooooo`0aooooo`;o00002OmoOgl2o`00073ooooo00?o0000ooooooooool0
2oooool003kooooo8ol9jPXeooooo`_o0000LOooool00ol0003oooooooooo`0;ooooo`00A?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Wooooo2ol0001aooooo`03o`000?oooooo
oooo00_ooooo0015ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0]_ooool00ol0
003oooooooooo`0;ooooo`00A_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;Oo
oooo00?o0000ooooooooool02oooool004Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2gooooo`03o`000?oooooooooo00_ooooo0017ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0^?ooool00ol0003oooooooooo`0;ooooo`00Aoooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool02oooool004Sooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo00_ooooo0018ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`0;ooooo`00
BOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
2oooool004[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2kooooo`03o`000?oo
oooooooo00_ooooo001:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^oooool0
0ol0003oooooooooo`0;ooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;cooooo00?o0000ooooooooool02oooool004_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2looooo`03o`000?oooooooooo00_ooooo001<ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0_Oooool00ol0003oooooooooo`0;ooooo`00C?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool02oooool004gooooo00Go0000
ooooooooooooooooo`000030ooooo`03o`000?oooooooooo00_ooooo001>ooooo`03o`000?oooooo
00000<7ooooo00?o0000ooooooooool02oooool004kooooo00?o0000ooooool00000`Oooool00ol0
003oooooooooo`0;ooooo`00Coooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo00_o
oooo003ooooooa?ooooo00?o0000ooooooooool02oooool00?oooooo4oooool00ol0003ooooooooo
o`0;ooooo`00oooooolCooooo`;o00003?ooool00?oooooo4oooool00ol0003oooooooooo`0;oooo
o`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {124.75, 0}} -> {-6.71582, -31.1656, 0.460929, \
0.460929}},
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[prismgaussiansystem, PlotType->SideView, ShowGaussian->True];\
\>", "Input",
  CellLabel->"In[90]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .43683 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0371292 0.00778884 0.231608 0.00778884 [
[.04959 .0104 -13.5938 -6 ]
[.04959 .0104 13.5938 6 ]
[.5434 .08829 -5.03125 -6 ]
[.5434 .08829 5.03125 6 ]
[.97179 .0104 -4.75 -6 ]
[.97179 .0104 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .43683 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.07602 .03679 m
.27084 .03679 L
.27084 .42643 L
.07602 .42643 L
.07602 .03679 L
s
.46556 .03679 m
.27075 .03679 L
.27075 .42643 L
.46556 .42643 L
.46556 .03679 L
s
.07598 .03679 m
.46561 .03679 L
.46561 .42643 L
.07598 .42643 L
.07598 .03679 L
s
.07598 .03689 m
.27079 .03689 L
.46561 .03689 L
.07598 .03689 L
s
.07598 .42633 m
.27079 .42633 L
.46561 .42633 L
.07598 .42633 L
s
.5 g
.52455 .23161 m
.56226 .23161 L
.57357 .23161 L
.51324 .23161 L
.52455 .23161 L
F
.51324 .23161 m
.57357 .23161 L
.58017 .23161 L
.50663 .23161 L
.51324 .23161 L
F
.50663 .23161 m
.58017 .23161 L
.58235 .23161 L
.50446 .23161 L
.50663 .23161 L
F
.50446 .23161 m
.58235 .23161 L
.58017 .23161 L
.50663 .23161 L
.50446 .23161 L
F
.50663 .23161 m
.58017 .23161 L
.57357 .23161 L
.51324 .23161 L
.50663 .23161 L
F
.51324 .23161 m
.57357 .23161 L
.56226 .23161 L
.52455 .23161 L
.51324 .23161 L
F
0 g
.52455 .23161 m
.51324 .23161 L
.50663 .23161 L
.50446 .23161 L
.50663 .23161 L
.51324 .23161 L
.52455 .23161 L
.56226 .23161 L
.57357 .23161 L
.58017 .23161 L
.58235 .23161 L
.58017 .23161 L
.57357 .23161 L
.56226 .23161 L
.52455 .23161 L
s
.5 g
.52455 .11478 m
.56226 .11478 L
.57357 .15372 L
.51324 .15372 L
.52455 .11478 L
F
.51324 .15372 m
.57357 .15372 L
.58017 .19266 L
.50663 .19266 L
.51324 .15372 L
F
.50663 .19266 m
.58017 .19266 L
.58235 .23161 L
.50446 .23161 L
.50663 .19266 L
F
.50446 .23161 m
.58235 .23161 L
.58017 .27055 L
.50663 .27055 L
.50446 .23161 L
F
.50663 .27055 m
.58017 .27055 L
.57357 .3095 L
.51324 .3095 L
.50663 .27055 L
F
.51324 .3095 m
.57357 .3095 L
.56226 .34844 L
.52455 .34844 L
.51324 .3095 L
F
0 g
.52455 .11478 m
.51324 .15372 L
.50663 .19266 L
.50446 .23161 L
.50663 .27055 L
.51324 .3095 L
.52455 .34844 L
.56226 .34844 L
.57357 .3095 L
.58017 .27055 L
.58235 .23161 L
.58017 .19266 L
.57357 .15372 L
.56226 .11478 L
.52455 .11478 L
s
.52455 .23161 m
.56226 .23161 L
.56226 .26185 L
.52455 .26185 L
.52455 .23161 L
s
.52455 .26185 m
.56226 .26185 L
.56226 .29002 L
.52455 .29002 L
.52455 .26185 L
s
.52455 .29002 m
.56226 .29002 L
.56226 .31422 L
.52455 .31422 L
.52455 .29002 L
s
.52455 .31422 m
.56226 .31422 L
.56226 .33279 L
.52455 .33279 L
.52455 .31422 L
s
.52455 .33279 m
.56226 .33279 L
.56226 .34446 L
.52455 .34446 L
.52455 .33279 L
s
.52455 .34446 m
.56226 .34446 L
.56226 .34844 L
.52455 .34844 L
.52455 .34446 L
s
.52455 .34844 m
.56226 .34844 L
.56226 .34446 L
.52455 .34446 L
.52455 .34844 L
s
.52455 .34446 m
.56226 .34446 L
.56226 .33279 L
.52455 .33279 L
.52455 .34446 L
s
.52455 .33279 m
.56226 .33279 L
.56226 .31422 L
.52455 .31422 L
.52455 .33279 L
s
.52455 .31422 m
.56226 .31422 L
.56226 .29002 L
.52455 .29002 L
.52455 .31422 L
s
.52455 .29002 m
.56226 .29002 L
.56226 .26185 L
.52455 .26185 L
.52455 .29002 L
s
.52455 .26185 m
.56226 .26185 L
.56226 .23161 L
.52455 .23161 L
.52455 .26185 L
s
.52455 .23161 m
.56226 .23161 L
.56226 .20137 L
.52455 .20137 L
.52455 .23161 L
s
.52455 .20137 m
.56226 .20137 L
.56226 .17319 L
.52455 .17319 L
.52455 .20137 L
s
.52455 .17319 m
.56226 .17319 L
.56226 .14899 L
.52455 .14899 L
.52455 .17319 L
s
.52455 .14899 m
.56226 .14899 L
.56226 .13043 L
.52455 .13043 L
.52455 .14899 L
s
.52455 .13043 m
.56226 .13043 L
.56226 .11876 L
.52455 .11876 L
.52455 .13043 L
s
.52455 .11876 m
.56226 .11876 L
.56226 .11478 L
.52455 .11478 L
.52455 .11876 L
s
.52455 .11478 m
.56226 .11478 L
.56226 .11876 L
.52455 .11876 L
.52455 .11478 L
s
.52455 .11876 m
.56226 .11876 L
.56226 .13043 L
.52455 .13043 L
.52455 .11876 L
s
.52455 .13043 m
.56226 .13043 L
.56226 .14899 L
.52455 .14899 L
.52455 .13043 L
s
.52455 .14899 m
.56226 .14899 L
.56226 .17319 L
.52455 .17319 L
.52455 .14899 L
s
.52455 .17319 m
.56226 .17319 L
.56226 .20137 L
.52455 .20137 L
.52455 .17319 L
s
.52455 .20137 m
.56226 .20137 L
.56226 .23161 L
.52455 .23161 L
.52455 .20137 L
s
.97179 .23161 m
.97179 .23161 L
.97179 .23161 L
.97179 .23161 L
.97179 .23161 L
.97179 .23161 L
.97179 .23161 L
.97179 .23161 L
.97179 .23161 L
.97179 .23161 L
.97179 .23161 L
.97179 .23161 L
.97179 .23161 L
.97179 .23161 L
.97179 .23161 L
s
.97179 .03689 m
.97179 .10179 L
.97179 .1667 L
.97179 .23161 L
.97179 .29651 L
.97179 .36142 L
.97179 .42633 L
.97179 .42633 L
.97179 .36142 L
.97179 .29651 L
.97179 .23161 L
.97179 .1667 L
.97179 .10179 L
.97179 .03689 L
.97179 .03689 L
s
.97179 .23161 m
.97179 .28201 L
.97179 .32897 L
.97179 .3693 L
.97179 .40024 L
.97179 .41969 L
.97179 .42633 L
.97179 .41969 L
.97179 .40024 L
.97179 .3693 L
.97179 .32897 L
.97179 .28201 L
.97179 .23161 L
.97179 .18121 L
.97179 .13425 L
.97179 .09392 L
.97179 .06297 L
.97179 .04352 L
.97179 .03689 L
.97179 .04352 L
.97179 .06297 L
.97179 .09392 L
.97179 .13425 L
.97179 .18121 L
.97179 .23161 L
s
0 0 0 r
gsave
.04959 .0104 -74.5938 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Prism) show
86.188 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5434 .08829 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97179 .0104 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
1 Mabswid
.02381 .23161 m
.03399 .23161 L
.04416 .23161 L
.05434 .23161 L
.06452 .23161 L
.07469 .23161 L
.08487 .23161 L
.09505 .23161 L
.10522 .23161 L
.1154 .23161 L
.12558 .23161 L
.13575 .23161 L
.14593 .23161 L
.15611 .23161 L
.16628 .23161 L
.17646 .23161 L
.18664 .23161 L
.21083 .23161 L
.22168 .23161 L
.23253 .23161 L
.24338 .23161 L
.25423 .23161 L
.26508 .23161 L
.27593 .23161 L
.28678 .23161 L
.29763 .23161 L
.30848 .23161 L
.31933 .23161 L
.33018 .23161 L
.35445 .23161 L
.36473 .23161 L
.37502 .23161 L
.3853 .23161 L
.39559 .23161 L
.40587 .23161 L
.41616 .23161 L
.42644 .23161 L
.43673 .23161 L
.44701 .23161 L
.4573 .23161 L
.46758 .23161 L
.47787 .23161 L
.48815 .23161 L
.49844 .23161 L
.50872 .23161 L
.51488 .23161 L
.52537 .23161 L
.53587 .23161 L
.54636 .23161 L
.55685 .23161 L
Mistroke
.56734 .23161 L
.57783 .23161 L
.58833 .23161 L
.60174 .23161 L
.61162 .23161 L
.62151 .23161 L
.63139 .23161 L
.64127 .23161 L
.65115 .23161 L
.66104 .23161 L
.67092 .23161 L
.6808 .23161 L
.69068 .23161 L
.70057 .23161 L
.71045 .23161 L
.72033 .23161 L
.73021 .23161 L
.7401 .23161 L
.74998 .23161 L
.75986 .23161 L
.76974 .23161 L
.77963 .23161 L
.78951 .23161 L
.79939 .23161 L
.80927 .23161 L
.81915 .23161 L
.82904 .23161 L
.83892 .23161 L
.8488 .23161 L
.85868 .23161 L
.8687 .23161 L
.87945 .23161 L
.8902 .23161 L
.90094 .23161 L
.91169 .23161 L
.92244 .23161 L
.93319 .23161 L
.94394 .23161 L
.95469 .23161 L
.96544 .23161 L
.97619 .23161 L
Mfstroke
.05045 .23161 m
.06066 .23161 L
.07088 .23161 L
.08109 .23161 L
.0913 .23161 L
.10152 .23161 L
.11173 .23161 L
.12195 .23161 L
.13216 .23161 L
.14237 .23161 L
.15259 .23161 L
.1628 .23161 L
.17301 .23161 L
.18323 .23161 L
.19344 .23161 L
.20366 .23161 L
.21387 .23161 L
.21137 .23161 L
.22221 .23161 L
.23306 .23161 L
.24391 .23161 L
.25476 .23161 L
.26561 .23161 L
.27646 .23161 L
.28731 .23161 L
.29816 .23161 L
.30901 .23161 L
.31986 .23161 L
.33071 .23161 L
.32809 .23161 L
.33834 .23161 L
.34859 .23161 L
.35884 .23161 L
.36909 .23161 L
.37935 .23161 L
.3896 .23161 L
.39985 .23161 L
.4101 .23161 L
.42035 .23161 L
.4306 .23161 L
.44085 .23161 L
.4511 .23161 L
.46135 .23161 L
.4716 .23161 L
.48185 .23161 L
.49629 .23161 L
.50698 .23161 L
.51767 .23161 L
.52836 .23161 L
.53905 .23161 L
Mistroke
.54974 .23161 L
.56043 .23161 L
.57112 .23161 L
.57846 .23161 L
.58921 .23161 L
.59996 .23161 L
.61071 .23161 L
.62146 .23161 L
.63221 .23161 L
.64296 .23161 L
.65371 .23161 L
.66446 .23161 L
.67521 .23161 L
.68596 .23161 L
.69671 .23161 L
.70746 .23161 L
.71821 .23161 L
.72895 .23161 L
.7397 .23161 L
.75045 .23161 L
.7612 .23161 L
.77195 .23161 L
.7827 .23161 L
.79345 .23161 L
.8042 .23161 L
.81495 .23161 L
.8257 .23161 L
.83645 .23161 L
.8472 .23161 L
.85795 .23161 L
.86857 .23161 L
.87845 .23161 L
.88833 .23161 L
.89821 .23161 L
.9081 .23161 L
.91798 .23161 L
.92786 .23161 L
.93774 .23161 L
.94763 .23161 L
.95751 .23161 L
.96739 .23161 L
Mfstroke
.03713 .27055 m
.04732 .27061 L
.05752 .27066 L
.06772 .27071 L
.07791 .27077 L
.08811 .27082 L
.0983 .27088 L
.1085 .27093 L
.11869 .27099 L
.12889 .27104 L
.13908 .27109 L
.14928 .27115 L
.15947 .2712 L
.16967 .27126 L
.17986 .27131 L
.19006 .27137 L
.20025 .27142 L
.2111 .27146 L
.22195 .27149 L
.2328 .27153 L
.24365 .27156 L
.2545 .2716 L
.26535 .27163 L
.2762 .27167 L
.28705 .27171 L
.2979 .27174 L
.30874 .27178 L
.31959 .27181 L
.33044 .27185 L
.34127 .27188 L
.35154 .27194 L
.36181 .27199 L
.37207 .27205 L
.38234 .2721 L
.39261 .27216 L
.40288 .27221 L
.41314 .27226 L
.42341 .27232 L
.43368 .27237 L
.44395 .27243 L
.45422 .27248 L
.46448 .27254 L
.47475 .27259 L
.48502 .27264 L
.49529 .2727 L
.50559 .2727 L
.51618 .27229 L
.52677 .27187 L
.53736 .27146 L
.54795 .27104 L
Mistroke
.55854 .27063 L
.56913 .27021 L
.57972 .2698 L
.5901 .26873 L
.60042 .26747 L
.61073 .26621 L
.62105 .26495 L
.63137 .26369 L
.64168 .26243 L
.652 .26117 L
.66231 .25991 L
.67263 .25865 L
.68295 .25739 L
.69326 .25613 L
.70358 .25487 L
.71389 .25361 L
.72421 .25235 L
.73453 .2511 L
.74484 .24984 L
.75516 .24858 L
.76547 .24732 L
.77579 .24606 L
.7861 .2448 L
.79642 .24354 L
.80674 .24228 L
.81705 .24102 L
.82737 .23976 L
.83768 .2385 L
.848 .23724 L
.85832 .23598 L
.86863 .23472 L
.87895 .23346 L
.88926 .2322 L
.89958 .23227 L
.9099 .23353 L
.92021 .23479 L
.93053 .23605 L
.94084 .23731 L
.95116 .23857 L
.96147 .23983 L
.97179 .24109 L
Mfstroke
.03713 .19266 m
.04732 .19261 L
.05752 .19255 L
.06772 .1925 L
.07791 .19245 L
.08811 .19239 L
.0983 .19234 L
.1085 .19228 L
.11869 .19223 L
.12889 .19218 L
.13908 .19212 L
.14928 .19207 L
.15947 .19201 L
.16967 .19196 L
.17986 .1919 L
.19006 .19185 L
.20025 .1918 L
.2111 .19176 L
.22195 .19172 L
.2328 .19169 L
.24365 .19165 L
.2545 .19162 L
.26535 .19158 L
.2762 .19155 L
.28705 .19151 L
.2979 .19147 L
.30874 .19144 L
.31959 .1914 L
.33044 .19137 L
.34127 .19133 L
.35154 .19128 L
.36181 .19122 L
.37207 .19117 L
.38234 .19111 L
.39261 .19106 L
.40288 .19101 L
.41314 .19095 L
.42341 .1909 L
.43368 .19084 L
.44395 .19079 L
.45422 .19073 L
.46448 .19068 L
.47475 .19063 L
.48502 .19057 L
.49529 .19052 L
.50559 .19051 L
.51618 .19093 L
.52677 .19134 L
.53736 .19176 L
.54795 .19217 L
Mistroke
.55854 .19259 L
.56913 .193 L
.57972 .19342 L
.5901 .19449 L
.60042 .19575 L
.61073 .19701 L
.62105 .19826 L
.63137 .19952 L
.64168 .20078 L
.652 .20204 L
.66231 .2033 L
.67263 .20456 L
.68295 .20582 L
.69326 .20708 L
.70358 .20834 L
.71389 .2096 L
.72421 .21086 L
.73453 .21212 L
.74484 .21338 L
.75516 .21464 L
.76547 .2159 L
.77579 .21716 L
.7861 .21842 L
.79642 .21968 L
.80674 .22094 L
.81705 .2222 L
.82737 .22346 L
.83768 .22472 L
.848 .22598 L
.85832 .22724 L
.86863 .22849 L
.87895 .22975 L
.88926 .23101 L
.89958 .23094 L
.9099 .22968 L
.92021 .22842 L
.93053 .22716 L
.94084 .2259 L
.95116 .22464 L
.96147 .22338 L
.97179 .22212 L
Mfstroke
0 0 0 r
.03713 .23161 m
.2003 .23161 L
s
% Start of user PostScript
0 0 20.9492 0 MAarrowhead1
% End of user PostScript
.2003 .23161 m
.34089 .23161 L
s
% Start of user PostScript
20.9492 0 38.9991 0 MAarrowhead1
% End of user PostScript
.34089 .23161 m
.50449 .23161 L
s
% Start of user PostScript
38.9991 0 60.0033 0 MAarrowhead1
% End of user PostScript
.50449 .23161 m
.58211 .23161 L
s
% Start of user PostScript
60.0033 0 69.9689 0 MAarrowhead1
% End of user PostScript
.58211 .23161 m
.97179 .23161 L
s
% Start of user PostScript
69.9689 0 120. 0 MAarrowhead1
% End of user PostScript
.97179 .23161 m
.97179 .23161 L
s
% Start of user PostScript
120. 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.04898 .23161 m
.0482 .23161 L
.04741 .23161 L
.04663 .23161 L
.04585 .23161 L
.04506 .23161 L
.04427 .23161 L
.04348 .23161 L
.04269 .23161 L
.0419 .23161 L
.04111 .23161 L
.04032 .23161 L
.03952 .23161 L
.03873 .23161 L
.03793 .23161 L
.03713 .23161 L
.03633 .23161 L
.03553 .23161 L
.03473 .23161 L
.03392 .23161 L
.03312 .23161 L
.03231 .23161 L
.0315 .23161 L
.0307 .23161 L
.02989 .23161 L
.02908 .23161 L
.02826 .23161 L
.02745 .23161 L
.02664 .23161 L
.02582 .23161 L
.025 .23161 L
s
.0643 .23161 m
.06351 .23161 L
.06273 .23161 L
.06194 .23161 L
.06116 .23161 L
.06037 .23161 L
.05958 .23161 L
.05879 .23161 L
.058 .23161 L
.0572 .23161 L
.05641 .23161 L
.05562 .23161 L
.05482 .23161 L
.05402 .23161 L
.05322 .23161 L
.05242 .23161 L
.05162 .23161 L
.05082 .23161 L
.05001 .23161 L
.04921 .23161 L
.0484 .23161 L
.04759 .23161 L
.04679 .23161 L
.04598 .23161 L
.04516 .23161 L
.04435 .23161 L
.04354 .23161 L
.04272 .23161 L
.04191 .23161 L
.04109 .23161 L
.04027 .23161 L
s
.07961 .23161 m
.07883 .23161 L
.07804 .23161 L
.07726 .23161 L
.07647 .23161 L
.07568 .23161 L
.07489 .23161 L
.0741 .23161 L
.0733 .23161 L
.07251 .23161 L
.07171 .23161 L
.07092 .23161 L
.07012 .23161 L
.06932 .23161 L
.06852 .23161 L
.06772 .23161 L
.06691 .23161 L
.06611 .23161 L
.0653 .23161 L
.06449 .23161 L
.06369 .23161 L
.06288 .23161 L
.06207 .23161 L
.06126 .23161 L
.06044 .23161 L
.05963 .23161 L
.05881 .23161 L
.058 .23161 L
.05718 .23161 L
.05636 .23161 L
.05554 .23161 L
s
.09493 .23161 m
.09414 .23161 L
.09336 .23161 L
.09257 .23161 L
.09178 .23161 L
.09099 .23161 L
.0902 .23161 L
.0894 .23161 L
.08861 .23161 L
.08781 .23161 L
.08701 .23161 L
.08621 .23161 L
.08541 .23161 L
.08461 .23161 L
.08381 .23161 L
.08301 .23161 L
.0822 .23161 L
.0814 .23161 L
.08059 .23161 L
.07978 .23161 L
.07897 .23161 L
.07816 .23161 L
.07735 .23161 L
.07653 .23161 L
.07572 .23161 L
.0749 .23161 L
.07409 .23161 L
.07327 .23161 L
.07245 .23161 L
.07163 .23161 L
.0708 .23161 L
s
.11025 .23161 m
.10946 .23161 L
.10867 .23161 L
.10788 .23161 L
.10709 .23161 L
.1063 .23161 L
.1055 .23161 L
.10471 .23161 L
.10391 .23161 L
.10311 .23161 L
.10231 .23161 L
.10151 .23161 L
.10071 .23161 L
.09991 .23161 L
.09911 .23161 L
.0983 .23161 L
.09749 .23161 L
.09669 .23161 L
.09588 .23161 L
.09507 .23161 L
.09426 .23161 L
.09344 .23161 L
.09263 .23161 L
.09181 .23161 L
.091 .23161 L
.09018 .23161 L
.08936 .23161 L
.08854 .23161 L
.08772 .23161 L
.0869 .23161 L
.08607 .23161 L
s
.12557 .23161 m
.12478 .23161 L
.12399 .23161 L
.12319 .23161 L
.1224 .23161 L
.12161 .23161 L
.12081 .23161 L
.12001 .23161 L
.11922 .23161 L
.11842 .23161 L
.11762 .23161 L
.11681 .23161 L
.11601 .23161 L
.11521 .23161 L
.1144 .23161 L
.11359 .23161 L
.11279 .23161 L
.11198 .23161 L
.11117 .23161 L
.11035 .23161 L
.10954 .23161 L
.10873 .23161 L
.10791 .23161 L
.10709 .23161 L
.10628 .23161 L
.10546 .23161 L
.10464 .23161 L
.10381 .23161 L
.10299 .23161 L
.10217 .23161 L
.10134 .23161 L
s
.14088 .23161 m
.14009 .23161 L
.1393 .23161 L
.13851 .23161 L
.13771 .23161 L
.13692 .23161 L
.13612 .23161 L
.13532 .23161 L
.13452 .23161 L
.13372 .23161 L
.13292 .23161 L
.13211 .23161 L
.13131 .23161 L
.1305 .23161 L
.1297 .23161 L
.12889 .23161 L
.12808 .23161 L
.12727 .23161 L
.12645 .23161 L
.12564 .23161 L
.12482 .23161 L
.12401 .23161 L
.12319 .23161 L
.12237 .23161 L
.12155 .23161 L
.12073 .23161 L
.11991 .23161 L
.11909 .23161 L
.11826 .23161 L
.11743 .23161 L
.11661 .23161 L
s
.1562 .23161 m
.15541 .23161 L
.15461 .23161 L
.15382 .23161 L
.15302 .23161 L
.15223 .23161 L
.15143 .23161 L
.15063 .23161 L
.14982 .23161 L
.14902 .23161 L
.14822 .23161 L
.14741 .23161 L
.14661 .23161 L
.1458 .23161 L
.14499 .23161 L
.14418 .23161 L
.14337 .23161 L
.14256 .23161 L
.14174 .23161 L
.14093 .23161 L
.14011 .23161 L
.13929 .23161 L
.13847 .23161 L
.13765 .23161 L
.13683 .23161 L
.13601 .23161 L
.13518 .23161 L
.13436 .23161 L
.13353 .23161 L
.1327 .23161 L
.13188 .23161 L
s
.17152 .23161 m
.17072 .23161 L
.16993 .23161 L
.16913 .23161 L
.16833 .23161 L
.16753 .23161 L
.16673 .23161 L
.16593 .23161 L
.16513 .23161 L
.16433 .23161 L
.16352 .23161 L
.16271 .23161 L
.1619 .23161 L
.16109 .23161 L
.16028 .23161 L
.15947 .23161 L
.15866 .23161 L
.15784 .23161 L
.15703 .23161 L
.15621 .23161 L
.15539 .23161 L
.15457 .23161 L
.15375 .23161 L
.15293 .23161 L
.15211 .23161 L
.15128 .23161 L
.15046 .23161 L
.14963 .23161 L
.1488 .23161 L
.14797 .23161 L
.14714 .23161 L
s
.18684 .23161 m
.18604 .23161 L
.18524 .23161 L
.18445 .23161 L
.18365 .23161 L
.18284 .23161 L
.18204 .23161 L
.18124 .23161 L
.18043 .23161 L
.17963 .23161 L
.17882 .23161 L
.17801 .23161 L
.1772 .23161 L
.17639 .23161 L
.17558 .23161 L
.17477 .23161 L
.17395 .23161 L
.17313 .23161 L
.17232 .23161 L
.1715 .23161 L
.17068 .23161 L
.16986 .23161 L
.16903 .23161 L
.16821 .23161 L
.16739 .23161 L
.16656 .23161 L
.16573 .23161 L
.1649 .23161 L
.16407 .23161 L
.16324 .23161 L
.16241 .23161 L
s
.20215 .23161 m
.20136 .23161 L
.20056 .23161 L
.19976 .23161 L
.19896 .23161 L
.19815 .23161 L
.19735 .23161 L
.19654 .23161 L
.19574 .23161 L
.19493 .23161 L
.19412 .23161 L
.19331 .23161 L
.1925 .23161 L
.19169 .23161 L
.19087 .23161 L
.19006 .23161 L
.18924 .23161 L
.18842 .23161 L
.1876 .23161 L
.18678 .23161 L
.18596 .23161 L
.18514 .23161 L
.18432 .23161 L
.18349 .23161 L
.18266 .23161 L
.18184 .23161 L
.18101 .23161 L
.18018 .23161 L
.17934 .23161 L
.17851 .23161 L
.17768 .23161 L
s
.20585 .23161 m
.20584 .23161 L
.20583 .23161 L
.20582 .23161 L
.20581 .23161 L
.20581 .23161 L
.20579 .23161 L
.20578 .23161 L
.20577 .23161 L
.20576 .23161 L
.20575 .23161 L
.20573 .23161 L
.20572 .23161 L
.20571 .23161 L
.20569 .23161 L
.20568 .23161 L
.20566 .23161 L
.20564 .23161 L
.20562 .23161 L
.20561 .23161 L
.20559 .23161 L
.20557 .23161 L
.20555 .23161 L
.20553 .23161 L
.20551 .23161 L
.20549 .23161 L
.20546 .23161 L
.20544 .23161 L
.20542 .23161 L
.2054 .23161 L
.20537 .23161 L
s
.22212 .23161 m
.22212 .23161 L
.22211 .23161 L
.2221 .23161 L
.22209 .23161 L
.22208 .23161 L
.22207 .23161 L
.22206 .23161 L
.22205 .23161 L
.22203 .23161 L
.22202 .23161 L
.22201 .23161 L
.22199 .23161 L
.22198 .23161 L
.22197 .23161 L
.22195 .23161 L
.22193 .23161 L
.22192 .23161 L
.2219 .23161 L
.22188 .23161 L
.22186 .23161 L
.22184 .23161 L
.22182 .23161 L
.2218 .23161 L
.22178 .23161 L
.22176 .23161 L
.22174 .23161 L
.22172 .23161 L
.22169 .23161 L
.22167 .23161 L
.22164 .23161 L
s
.2384 .23161 m
.23839 .23161 L
.23838 .23161 L
.23837 .23161 L
.23836 .23161 L
.23835 .23161 L
.23834 .23161 L
.23833 .23161 L
.23832 .23161 L
.23831 .23161 L
.2383 .23161 L
.23828 .23161 L
.23827 .23161 L
.23825 .23161 L
.23824 .23161 L
.23822 .23161 L
.23821 .23161 L
.23819 .23161 L
.23817 .23161 L
.23816 .23161 L
.23814 .23161 L
.23812 .23161 L
.2381 .23161 L
.23808 .23161 L
.23806 .23161 L
.23803 .23161 L
.23801 .23161 L
.23799 .23161 L
.23797 .23161 L
.23794 .23161 L
.23792 .23161 L
s
.25467 .23161 m
.25466 .23161 L
.25466 .23161 L
.25465 .23161 L
.25464 .23161 L
.25463 .23161 L
.25462 .23161 L
.25461 .23161 L
.2546 .23161 L
.25458 .23161 L
.25457 .23161 L
.25456 .23161 L
.25454 .23161 L
.25453 .23161 L
.25451 .23161 L
.2545 .23161 L
.25448 .23161 L
.25446 .23161 L
.25445 .23161 L
.25443 .23161 L
.25441 .23161 L
.25439 .23161 L
.25437 .23161 L
.25435 .23161 L
.25433 .23161 L
.25431 .23161 L
.25429 .23161 L
.25426 .23161 L
.25424 .23161 L
.25422 .23161 L
.25419 .23161 L
s
.27095 .23161 m
.27094 .23161 L
.27093 .23161 L
.27092 .23161 L
.27091 .23161 L
.2709 .23161 L
.27089 .23161 L
.27088 .23161 L
.27087 .23161 L
.27086 .23161 L
.27084 .23161 L
.27083 .23161 L
.27082 .23161 L
.2708 .23161 L
.27079 .23161 L
.27077 .23161 L
.27076 .23161 L
.27074 .23161 L
.27072 .23161 L
.2707 .23161 L
.27068 .23161 L
.27067 .23161 L
.27065 .23161 L
.27063 .23161 L
.2706 .23161 L
.27058 .23161 L
.27056 .23161 L
.27054 .23161 L
.27051 .23161 L
.27049 .23161 L
.27047 .23161 L
s
.28722 .23161 m
.28721 .23161 L
.2872 .23161 L
.2872 .23161 L
.28719 .23161 L
.28718 .23161 L
.28717 .23161 L
.28716 .23161 L
.28714 .23161 L
.28713 .23161 L
.28712 .23161 L
.28711 .23161 L
.28709 .23161 L
.28708 .23161 L
.28706 .23161 L
.28705 .23161 L
.28703 .23161 L
.28701 .23161 L
.287 .23161 L
.28698 .23161 L
.28696 .23161 L
.28694 .23161 L
.28692 .23161 L
.2869 .23161 L
.28688 .23161 L
.28686 .23161 L
.28683 .23161 L
.28681 .23161 L
.28679 .23161 L
.28677 .23161 L
.28674 .23161 L
s
.30349 .23161 m
.30349 .23161 L
.30348 .23161 L
.30347 .23161 L
.30346 .23161 L
.30345 .23161 L
.30344 .23161 L
.30343 .23161 L
.30342 .23161 L
.30341 .23161 L
.30339 .23161 L
.30338 .23161 L
.30337 .23161 L
.30335 .23161 L
.30334 .23161 L
.30332 .23161 L
.3033 .23161 L
.30329 .23161 L
.30327 .23161 L
.30325 .23161 L
.30323 .23161 L
.30321 .23161 L
.30319 .23161 L
.30317 .23161 L
.30315 .23161 L
.30313 .23161 L
.30311 .23161 L
.30309 .23161 L
.30306 .23161 L
.30304 .23161 L
.30301 .23161 L
s
.31977 .23161 m
.31976 .23161 L
.31975 .23161 L
.31974 .23161 L
.31973 .23161 L
.31973 .23161 L
.31971 .23161 L
.3197 .23161 L
.31969 .23161 L
.31968 .23161 L
.31967 .23161 L
.31965 .23161 L
.31964 .23161 L
.31963 .23161 L
.31961 .23161 L
.31959 .23161 L
.31958 .23161 L
.31956 .23161 L
.31954 .23161 L
.31953 .23161 L
.31951 .23161 L
.31949 .23161 L
.31947 .23161 L
.31945 .23161 L
.31943 .23161 L
.31941 .23161 L
.31938 .23161 L
.31936 .23161 L
.31934 .23161 L
.31931 .23161 L
.31929 .23161 L
s
.33604 .23161 m
.33604 .23161 L
.33603 .23161 L
.33602 .23161 L
.33601 .23161 L
.336 .23161 L
.33599 .23161 L
.33598 .23161 L
.33597 .23161 L
.33595 .23161 L
.33594 .23161 L
.33593 .23161 L
.33591 .23161 L
.3359 .23161 L
.33588 .23161 L
.33587 .23161 L
.33585 .23161 L
.33584 .23161 L
.33582 .23161 L
.3358 .23161 L
.33578 .23161 L
.33576 .23161 L
.33574 .23161 L
.33572 .23161 L
.3357 .23161 L
.33568 .23161 L
.33566 .23161 L
.33563 .23161 L
.33561 .23161 L
.33559 .23161 L
.33556 .23161 L
s
.33952 .23161 m
.34033 .23161 L
.34114 .23161 L
.34195 .23161 L
.34275 .23161 L
.34356 .23161 L
.34436 .23161 L
.34516 .23161 L
.34597 .23161 L
.34677 .23161 L
.34756 .23161 L
.34836 .23161 L
.34916 .23161 L
.34995 .23161 L
.35075 .23161 L
.35154 .23161 L
.35233 .23161 L
.35312 .23161 L
.35391 .23161 L
.3547 .23161 L
.35548 .23161 L
.35627 .23161 L
.35705 .23161 L
.35783 .23161 L
.35861 .23161 L
.35939 .23161 L
.36017 .23161 L
.36095 .23161 L
.36172 .23161 L
.3625 .23161 L
.36327 .23161 L
s
.3549 .23161 m
.35571 .23161 L
.35652 .23161 L
.35733 .23161 L
.35814 .23161 L
.35894 .23161 L
.35975 .23161 L
.36055 .23161 L
.36136 .23161 L
.36216 .23161 L
.36296 .23161 L
.36376 .23161 L
.36455 .23161 L
.36535 .23161 L
.36615 .23161 L
.36694 .23161 L
.36773 .23161 L
.36852 .23161 L
.36931 .23161 L
.3701 .23161 L
.37089 .23161 L
.37168 .23161 L
.37246 .23161 L
.37325 .23161 L
.37403 .23161 L
.37481 .23161 L
.37559 .23161 L
.37637 .23161 L
.37714 .23161 L
.37792 .23161 L
.37869 .23161 L
s
.37027 .23161 m
.37109 .23161 L
.3719 .23161 L
.37271 .23161 L
.37352 .23161 L
.37433 .23161 L
.37514 .23161 L
.37594 .23161 L
.37675 .23161 L
.37755 .23161 L
.37835 .23161 L
.37915 .23161 L
.37995 .23161 L
.38075 .23161 L
.38155 .23161 L
.38234 .23161 L
.38314 .23161 L
.38393 .23161 L
.38472 .23161 L
.38551 .23161 L
.3863 .23161 L
.38709 .23161 L
.38787 .23161 L
.38866 .23161 L
.38944 .23161 L
.39023 .23161 L
.39101 .23161 L
.39179 .23161 L
.39257 .23161 L
.39334 .23161 L
.39412 .23161 L
s
.38565 .23161 m
.38647 .23161 L
.38728 .23161 L
.38809 .23161 L
.38891 .23161 L
.38972 .23161 L
.39052 .23161 L
.39133 .23161 L
.39214 .23161 L
.39294 .23161 L
.39375 .23161 L
.39455 .23161 L
.39535 .23161 L
.39615 .23161 L
.39695 .23161 L
.39774 .23161 L
.39854 .23161 L
.39933 .23161 L
.40013 .23161 L
.40092 .23161 L
.40171 .23161 L
.4025 .23161 L
.40329 .23161 L
.40407 .23161 L
.40486 .23161 L
.40564 .23161 L
.40643 .23161 L
.40721 .23161 L
.40799 .23161 L
.40877 .23161 L
.40954 .23161 L
s
.40103 .23161 m
.40185 .23161 L
.40266 .23161 L
.40348 .23161 L
.40429 .23161 L
.4051 .23161 L
.40591 .23161 L
.40672 .23161 L
.40753 .23161 L
.40833 .23161 L
.40914 .23161 L
.40994 .23161 L
.41075 .23161 L
.41155 .23161 L
.41235 .23161 L
.41314 .23161 L
.41394 .23161 L
.41474 .23161 L
.41553 .23161 L
.41633 .23161 L
.41712 .23161 L
.41791 .23161 L
.4187 .23161 L
.41949 .23161 L
.42027 .23161 L
.42106 .23161 L
.42184 .23161 L
.42263 .23161 L
.42341 .23161 L
.42419 .23161 L
.42497 .23161 L
s
.41641 .23161 m
.41723 .23161 L
.41804 .23161 L
.41886 .23161 L
.41967 .23161 L
.42049 .23161 L
.4213 .23161 L
.42211 .23161 L
.42292 .23161 L
.42373 .23161 L
.42453 .23161 L
.42534 .23161 L
.42614 .23161 L
.42694 .23161 L
.42775 .23161 L
.42855 .23161 L
.42935 .23161 L
.43014 .23161 L
.43094 .23161 L
.43173 .23161 L
.43253 .23161 L
.43332 .23161 L
.43411 .23161 L
.4349 .23161 L
.43569 .23161 L
.43648 .23161 L
.43726 .23161 L
.43805 .23161 L
.43883 .23161 L
.43961 .23161 L
.44039 .23161 L
s
.43179 .23161 m
.43261 .23161 L
.43342 .23161 L
.43424 .23161 L
.43506 .23161 L
.43587 .23161 L
.43669 .23161 L
.4375 .23161 L
.43831 .23161 L
.43912 .23161 L
.43993 .23161 L
.44073 .23161 L
.44154 .23161 L
.44234 .23161 L
.44315 .23161 L
.44395 .23161 L
.44475 .23161 L
.44555 .23161 L
.44635 .23161 L
.44714 .23161 L
.44794 .23161 L
.44873 .23161 L
.44952 .23161 L
.45031 .23161 L
.4511 .23161 L
.45189 .23161 L
.45268 .23161 L
.45347 .23161 L
.45425 .23161 L
.45503 .23161 L
.45582 .23161 L
s
.44716 .23161 m
.44799 .23161 L
.44881 .23161 L
.44962 .23161 L
.45044 .23161 L
.45126 .23161 L
.45207 .23161 L
.45289 .23161 L
.4537 .23161 L
.45451 .23161 L
.45532 .23161 L
.45613 .23161 L
.45694 .23161 L
.45774 .23161 L
.45855 .23161 L
.45935 .23161 L
.46015 .23161 L
.46095 .23161 L
.46175 .23161 L
.46255 .23161 L
.46335 .23161 L
.46414 .23161 L
.46494 .23161 L
.46573 .23161 L
.46652 .23161 L
.46731 .23161 L
.4681 .23161 L
.46889 .23161 L
.46967 .23161 L
.47046 .23161 L
.47124 .23161 L
s
.46254 .23161 m
.46337 .23161 L
.46419 .23161 L
.46501 .23161 L
.46583 .23161 L
.46664 .23161 L
.46746 .23161 L
.46828 .23161 L
.46909 .23161 L
.4699 .23161 L
.47071 .23161 L
.47152 .23161 L
.47233 .23161 L
.47314 .23161 L
.47395 .23161 L
.47475 .23161 L
.47555 .23161 L
.47636 .23161 L
.47716 .23161 L
.47796 .23161 L
.47876 .23161 L
.47955 .23161 L
.48035 .23161 L
.48114 .23161 L
.48194 .23161 L
.48273 .23161 L
.48352 .23161 L
.48431 .23161 L
.48509 .23161 L
.48588 .23161 L
.48667 .23161 L
s
.47792 .23161 m
.47874 .23161 L
.47957 .23161 L
.48039 .23161 L
.48121 .23161 L
.48203 .23161 L
.48285 .23161 L
.48366 .23161 L
.48448 .23161 L
.48529 .23161 L
.48611 .23161 L
.48692 .23161 L
.48773 .23161 L
.48854 .23161 L
.48935 .23161 L
.49015 .23161 L
.49096 .23161 L
.49176 .23161 L
.49256 .23161 L
.49336 .23161 L
.49416 .23161 L
.49496 .23161 L
.49576 .23161 L
.49656 .23161 L
.49735 .23161 L
.49814 .23161 L
.49894 .23161 L
.49973 .23161 L
.50052 .23161 L
.5013 .23161 L
.50209 .23161 L
s
.4981 .23161 m
.49855 .23161 L
.499 .23161 L
.49946 .23161 L
.49993 .23161 L
.5004 .23161 L
.50089 .23161 L
.50138 .23161 L
.50188 .23161 L
.50238 .23161 L
.5029 .23161 L
.50342 .23161 L
.50395 .23161 L
.50449 .23161 L
.50503 .23161 L
.50559 .23161 L
.50615 .23161 L
.50672 .23161 L
.5073 .23161 L
.50788 .23161 L
.50847 .23161 L
.50907 .23161 L
.50968 .23161 L
.5103 .23161 L
.51092 .23161 L
.51156 .23161 L
.5122 .23161 L
.51284 .23161 L
.5135 .23161 L
.51416 .23161 L
.51483 .23161 L
s
.51411 .23161 m
.51455 .23161 L
.51499 .23161 L
.51544 .23161 L
.5159 .23161 L
.51637 .23161 L
.51685 .23161 L
.51733 .23161 L
.51782 .23161 L
.51832 .23161 L
.51883 .23161 L
.51934 .23161 L
.51986 .23161 L
.52039 .23161 L
.52093 .23161 L
.52147 .23161 L
.52203 .23161 L
.52259 .23161 L
.52315 .23161 L
.52373 .23161 L
.52431 .23161 L
.52491 .23161 L
.5255 .23161 L
.52611 .23161 L
.52672 .23161 L
.52735 .23161 L
.52798 .23161 L
.52861 .23161 L
.52926 .23161 L
.52991 .23161 L
.53057 .23161 L
s
.53012 .23161 m
.53055 .23161 L
.53098 .23161 L
.53143 .23161 L
.53188 .23161 L
.53234 .23161 L
.53281 .23161 L
.53328 .23161 L
.53377 .23161 L
.53426 .23161 L
.53476 .23161 L
.53526 .23161 L
.53578 .23161 L
.5363 .23161 L
.53682 .23161 L
.53736 .23161 L
.5379 .23161 L
.53846 .23161 L
.53901 .23161 L
.53958 .23161 L
.54015 .23161 L
.54074 .23161 L
.54133 .23161 L
.54192 .23161 L
.54253 .23161 L
.54314 .23161 L
.54376 .23161 L
.54438 .23161 L
.54502 .23161 L
.54566 .23161 L
.54631 .23161 L
s
.54612 .23161 m
.54655 .23161 L
.54698 .23161 L
.54741 .23161 L
.54786 .23161 L
.54831 .23161 L
.54877 .23161 L
.54924 .23161 L
.54971 .23161 L
.5502 .23161 L
.55069 .23161 L
.55118 .23161 L
.55169 .23161 L
.5522 .23161 L
.55272 .23161 L
.55325 .23161 L
.55378 .23161 L
.55432 .23161 L
.55487 .23161 L
.55543 .23161 L
.556 .23161 L
.55657 .23161 L
.55715 .23161 L
.55773 .23161 L
.55833 .23161 L
.55893 .23161 L
.55954 .23161 L
.56016 .23161 L
.56078 .23161 L
.56141 .23161 L
.56205 .23161 L
s
.56213 .23161 m
.56254 .23161 L
.56297 .23161 L
.5634 .23161 L
.56384 .23161 L
.56428 .23161 L
.56473 .23161 L
.56519 .23161 L
.56566 .23161 L
.56613 .23161 L
.56662 .23161 L
.5671 .23161 L
.5676 .23161 L
.5681 .23161 L
.56862 .23161 L
.56913 .23161 L
.56966 .23161 L
.57019 .23161 L
.57073 .23161 L
.57128 .23161 L
.57184 .23161 L
.5724 .23161 L
.57297 .23161 L
.57354 .23161 L
.57413 .23161 L
.57472 .23161 L
.57532 .23161 L
.57593 .23161 L
.57654 .23161 L
.57716 .23161 L
.57779 .23161 L
s
.57785 .23161 m
.5781 .23161 L
.57838 .23161 L
.57869 .23161 L
.57904 .23161 L
.57942 .23161 L
.57983 .23161 L
.58027 .23161 L
.58074 .23161 L
.58125 .23161 L
.58178 .23161 L
.58235 .23161 L
.58295 .23161 L
.58359 .23161 L
.58425 .23161 L
.58494 .23161 L
.58567 .23161 L
.58643 .23161 L
.58722 .23161 L
.58804 .23161 L
.5889 .23161 L
.58978 .23161 L
.5907 .23161 L
.59165 .23161 L
.59263 .23161 L
.59365 .23161 L
.59469 .23161 L
.59577 .23161 L
.59688 .23161 L
.59802 .23161 L
.59919 .23161 L
s
.59371 .23161 m
.59395 .23161 L
.59421 .23161 L
.59451 .23161 L
.59484 .23161 L
.5952 .23161 L
.59558 .23161 L
.596 .23161 L
.59645 .23161 L
.59692 .23161 L
.59743 .23161 L
.59797 .23161 L
.59854 .23161 L
.59913 .23161 L
.59976 .23161 L
.60042 .23161 L
.60111 .23161 L
.60182 .23161 L
.60257 .23161 L
.60335 .23161 L
.60416 .23161 L
.60499 .23161 L
.60586 .23161 L
.60676 .23161 L
.60769 .23161 L
.60864 .23161 L
.60963 .23161 L
.61065 .23161 L
.6117 .23161 L
.61277 .23161 L
.61388 .23161 L
s
.60957 .23161 m
.6098 .23161 L
.61005 .23161 L
.61033 .23161 L
.61064 .23161 L
.61097 .23161 L
.61134 .23161 L
.61173 .23161 L
.61215 .23161 L
.6126 .23161 L
.61308 .23161 L
.61359 .23161 L
.61412 .23161 L
.61468 .23161 L
.61527 .23161 L
.61589 .23161 L
.61654 .23161 L
.61722 .23161 L
.61792 .23161 L
.61865 .23161 L
.61941 .23161 L
.6202 .23161 L
.62102 .23161 L
.62186 .23161 L
.62274 .23161 L
.62364 .23161 L
.62457 .23161 L
.62553 .23161 L
.62651 .23161 L
.62753 .23161 L
.62857 .23161 L
s
.62544 .23161 m
.62565 .23161 L
.62588 .23161 L
.62614 .23161 L
.62643 .23161 L
.62675 .23161 L
.62709 .23161 L
.62746 .23161 L
.62786 .23161 L
.62828 .23161 L
.62873 .23161 L
.6292 .23161 L
.6297 .23161 L
.63023 .23161 L
.63079 .23161 L
.63137 .23161 L
.63197 .23161 L
.63261 .23161 L
.63327 .23161 L
.63396 .23161 L
.63467 .23161 L
.63541 .23161 L
.63618 .23161 L
.63697 .23161 L
.63779 .23161 L
.63864 .23161 L
.63951 .23161 L
.64041 .23161 L
.64133 .23161 L
.64229 .23161 L
.64327 .23161 L
s
.6413 .23161 m
.64149 .23161 L
.64172 .23161 L
.64196 .23161 L
.64223 .23161 L
.64253 .23161 L
.64285 .23161 L
.64319 .23161 L
.64356 .23161 L
.64395 .23161 L
.64437 .23161 L
.64482 .23161 L
.64529 .23161 L
.64578 .23161 L
.6463 .23161 L
.64684 .23161 L
.64741 .23161 L
.648 .23161 L
.64862 .23161 L
.64926 .23161 L
.64993 .23161 L
.65062 .23161 L
.65133 .23161 L
.65208 .23161 L
.65284 .23161 L
.65363 .23161 L
.65445 .23161 L
.65529 .23161 L
.65615 .23161 L
.65704 .23161 L
.65796 .23161 L
s
.65716 .23161 m
.65734 .23161 L
.65755 .23161 L
.65778 .23161 L
.65803 .23161 L
.6583 .23161 L
.6586 .23161 L
.65892 .23161 L
.65926 .23161 L
.65963 .23161 L
.66002 .23161 L
.66043 .23161 L
.66087 .23161 L
.66133 .23161 L
.66181 .23161 L
.66231 .23161 L
.66284 .23161 L
.66339 .23161 L
.66397 .23161 L
.66456 .23161 L
.66518 .23161 L
.66583 .23161 L
.66649 .23161 L
.66718 .23161 L
.66789 .23161 L
.66863 .23161 L
.66939 .23161 L
.67017 .23161 L
.67097 .23161 L
.6718 .23161 L
.67265 .23161 L
s
.67303 .23161 m
.67319 .23161 L
.67338 .23161 L
.67359 .23161 L
.67383 .23161 L
.67408 .23161 L
.67436 .23161 L
.67465 .23161 L
.67497 .23161 L
.67531 .23161 L
.67567 .23161 L
.67605 .23161 L
.67645 .23161 L
.67688 .23161 L
.67732 .23161 L
.67779 .23161 L
.67828 .23161 L
.67878 .23161 L
.67932 .23161 L
.67987 .23161 L
.68044 .23161 L
.68103 .23161 L
.68165 .23161 L
.68229 .23161 L
.68295 .23161 L
.68363 .23161 L
.68433 .23161 L
.68505 .23161 L
.68579 .23161 L
.68656 .23161 L
.68734 .23161 L
s
.68889 .23161 m
.68904 .23161 L
.68922 .23161 L
.68941 .23161 L
.68962 .23161 L
.68986 .23161 L
.69011 .23161 L
.69038 .23161 L
.69067 .23161 L
.69098 .23161 L
.69131 .23161 L
.69167 .23161 L
.69203 .23161 L
.69242 .23161 L
.69283 .23161 L
.69326 .23161 L
.69371 .23161 L
.69418 .23161 L
.69466 .23161 L
.69517 .23161 L
.6957 .23161 L
.69624 .23161 L
.69681 .23161 L
.69739 .23161 L
.698 .23161 L
.69862 .23161 L
.69927 .23161 L
.69993 .23161 L
.70061 .23161 L
.70131 .23161 L
.70204 .23161 L
s
.70475 .23161 m
.70489 .23161 L
.70505 .23161 L
.70523 .23161 L
.70542 .23161 L
.70563 .23161 L
.70586 .23161 L
.70611 .23161 L
.70638 .23161 L
.70666 .23161 L
.70696 .23161 L
.70728 .23161 L
.70762 .23161 L
.70797 .23161 L
.70835 .23161 L
.70874 .23161 L
.70914 .23161 L
.70957 .23161 L
.71001 .23161 L
.71047 .23161 L
.71095 .23161 L
.71145 .23161 L
.71197 .23161 L
.7125 .23161 L
.71305 .23161 L
.71362 .23161 L
.71421 .23161 L
.71481 .23161 L
.71543 .23161 L
.71607 .23161 L
.71673 .23161 L
s
.72061 .23161 m
.72074 .23161 L
.72088 .23161 L
.72104 .23161 L
.72122 .23161 L
.72141 .23161 L
.72162 .23161 L
.72184 .23161 L
.72208 .23161 L
.72234 .23161 L
.72261 .23161 L
.7229 .23161 L
.7232 .23161 L
.72352 .23161 L
.72386 .23161 L
.72421 .23161 L
.72458 .23161 L
.72496 .23161 L
.72536 .23161 L
.72578 .23161 L
.72621 .23161 L
.72666 .23161 L
.72712 .23161 L
.72761 .23161 L
.7281 .23161 L
.72862 .23161 L
.72914 .23161 L
.72969 .23161 L
.73025 .23161 L
.73083 .23161 L
.73142 .23161 L
s
.73648 .23161 m
.73659 .23161 L
.73672 .23161 L
.73686 .23161 L
.73702 .23161 L
.73719 .23161 L
.73737 .23161 L
.73757 .23161 L
.73779 .23161 L
.73801 .23161 L
.73826 .23161 L
.73851 .23161 L
.73878 .23161 L
.73907 .23161 L
.73937 .23161 L
.73968 .23161 L
.74001 .23161 L
.74035 .23161 L
.74071 .23161 L
.74108 .23161 L
.74147 .23161 L
.74187 .23161 L
.74228 .23161 L
.74271 .23161 L
.74315 .23161 L
.74361 .23161 L
.74408 .23161 L
.74457 .23161 L
.74507 .23161 L
.74559 .23161 L
.74611 .23161 L
s
.75234 .23161 m
.75244 .23161 L
.75255 .23161 L
.75268 .23161 L
.75281 .23161 L
.75296 .23161 L
.75313 .23161 L
.7533 .23161 L
.75349 .23161 L
.75369 .23161 L
.7539 .23161 L
.75413 .23161 L
.75437 .23161 L
.75462 .23161 L
.75488 .23161 L
.75516 .23161 L
.75545 .23161 L
.75575 .23161 L
.75606 .23161 L
.75639 .23161 L
.75673 .23161 L
.75708 .23161 L
.75744 .23161 L
.75782 .23161 L
.75821 .23161 L
.75861 .23161 L
.75902 .23161 L
.75945 .23161 L
.75989 .23161 L
.76034 .23161 L
.76081 .23161 L
s
.7682 .23161 m
.76829 .23161 L
.76839 .23161 L
.76849 .23161 L
.76861 .23161 L
.76874 .23161 L
.76888 .23161 L
.76903 .23161 L
.76919 .23161 L
.76937 .23161 L
.76955 .23161 L
.76974 .23161 L
.76995 .23161 L
.77017 .23161 L
.77039 .23161 L
.77063 .23161 L
.77088 .23161 L
.77114 .23161 L
.77141 .23161 L
.77169 .23161 L
.77198 .23161 L
.77229 .23161 L
.7726 .23161 L
.77292 .23161 L
.77326 .23161 L
.77361 .23161 L
.77396 .23161 L
.77433 .23161 L
.77471 .23161 L
.7751 .23161 L
.7755 .23161 L
s
.78407 .23161 m
.78414 .23161 L
.78422 .23161 L
.78431 .23161 L
.78441 .23161 L
.78452 .23161 L
.78464 .23161 L
.78476 .23161 L
.7849 .23161 L
.78504 .23161 L
.7852 .23161 L
.78536 .23161 L
.78553 .23161 L
.78571 .23161 L
.7859 .23161 L
.7861 .23161 L
.78631 .23161 L
.78653 .23161 L
.78676 .23161 L
.78699 .23161 L
.78724 .23161 L
.78749 .23161 L
.78776 .23161 L
.78803 .23161 L
.78831 .23161 L
.7886 .23161 L
.7889 .23161 L
.78921 .23161 L
.78953 .23161 L
.78986 .23161 L
.79019 .23161 L
s
.79993 .23161 m
.79999 .23161 L
.80005 .23161 L
.80013 .23161 L
.80021 .23161 L
.8003 .23161 L
.80039 .23161 L
.80049 .23161 L
.8006 .23161 L
.80072 .23161 L
.80084 .23161 L
.80098 .23161 L
.80112 .23161 L
.80126 .23161 L
.80142 .23161 L
.80158 .23161 L
.80175 .23161 L
.80192 .23161 L
.80211 .23161 L
.8023 .23161 L
.8025 .23161 L
.8027 .23161 L
.80292 .23161 L
.80314 .23161 L
.80336 .23161 L
.8036 .23161 L
.80384 .23161 L
.80409 .23161 L
.80435 .23161 L
.80461 .23161 L
.80489 .23161 L
s
.81579 .23161 m
.81584 .23161 L
.81589 .23161 L
.81594 .23161 L
.81601 .23161 L
.81607 .23161 L
.81614 .23161 L
.81622 .23161 L
.81631 .23161 L
.8164 .23161 L
.81649 .23161 L
.81659 .23161 L
.8167 .23161 L
.81681 .23161 L
.81693 .23161 L
.81705 .23161 L
.81718 .23161 L
.81732 .23161 L
.81746 .23161 L
.8176 .23161 L
.81775 .23161 L
.81791 .23161 L
.81807 .23161 L
.81824 .23161 L
.81842 .23161 L
.8186 .23161 L
.81878 .23161 L
.81897 .23161 L
.81917 .23161 L
.81937 .23161 L
.81958 .23161 L
s
.83166 .23161 m
.83169 .23161 L
.83172 .23161 L
.83176 .23161 L
.8318 .23161 L
.83185 .23161 L
.8319 .23161 L
.83195 .23161 L
.83201 .23161 L
.83207 .23161 L
.83214 .23161 L
.83221 .23161 L
.83228 .23161 L
.83236 .23161 L
.83244 .23161 L
.83253 .23161 L
.83262 .23161 L
.83271 .23161 L
.8328 .23161 L
.83291 .23161 L
.83301 .23161 L
.83312 .23161 L
.83323 .23161 L
.83335 .23161 L
.83347 .23161 L
.83359 .23161 L
.83372 .23161 L
.83385 .23161 L
.83399 .23161 L
.83413 .23161 L
.83427 .23161 L
s
.84752 .23161 m
.84754 .23161 L
.84756 .23161 L
.84758 .23161 L
.8476 .23161 L
.84763 .23161 L
.84765 .23161 L
.84768 .23161 L
.84772 .23161 L
.84775 .23161 L
.84779 .23161 L
.84782 .23161 L
.84787 .23161 L
.84791 .23161 L
.84795 .23161 L
.848 .23161 L
.84805 .23161 L
.8481 .23161 L
.84815 .23161 L
.84821 .23161 L
.84827 .23161 L
.84833 .23161 L
.84839 .23161 L
.84845 .23161 L
.84852 .23161 L
.84859 .23161 L
.84866 .23161 L
.84873 .23161 L
.84881 .23161 L
.84888 .23161 L
.84896 .23161 L
s
.86338 .23161 m
.86339 .23161 L
.86339 .23161 L
.86339 .23161 L
.8634 .23161 L
.8634 .23161 L
.86341 .23161 L
.86341 .23161 L
.86342 .23161 L
.86343 .23161 L
.86343 .23161 L
.86344 .23161 L
.86345 .23161 L
.86346 .23161 L
.86346 .23161 L
.86347 .23161 L
.86348 .23161 L
.86349 .23161 L
.8635 .23161 L
.86351 .23161 L
.86352 .23161 L
.86354 .23161 L
.86355 .23161 L
.86356 .23161 L
.86357 .23161 L
.86359 .23161 L
.8636 .23161 L
.86361 .23161 L
.86363 .23161 L
.86364 .23161 L
.86366 .23161 L
s
.87835 .23161 m
.8784 .23161 L
.87845 .23161 L
.87849 .23161 L
.87854 .23161 L
.87858 .23161 L
.87862 .23161 L
.87867 .23161 L
.87871 .23161 L
.87874 .23161 L
.87878 .23161 L
.87882 .23161 L
.87885 .23161 L
.87889 .23161 L
.87892 .23161 L
.87895 .23161 L
.87898 .23161 L
.879 .23161 L
.87903 .23161 L
.87906 .23161 L
.87908 .23161 L
.8791 .23161 L
.87912 .23161 L
.87914 .23161 L
.87916 .23161 L
.87918 .23161 L
.8792 .23161 L
.87921 .23161 L
.87922 .23161 L
.87924 .23161 L
.87925 .23161 L
s
.89304 .23161 m
.89315 .23161 L
.89327 .23161 L
.89337 .23161 L
.89348 .23161 L
.89358 .23161 L
.89368 .23161 L
.89377 .23161 L
.89386 .23161 L
.89395 .23161 L
.89404 .23161 L
.89412 .23161 L
.8942 .23161 L
.89428 .23161 L
.89435 .23161 L
.89442 .23161 L
.89449 .23161 L
.89455 .23161 L
.89461 .23161 L
.89467 .23161 L
.89473 .23161 L
.89478 .23161 L
.89483 .23161 L
.89487 .23161 L
.89492 .23161 L
.89496 .23161 L
.89499 .23161 L
.89503 .23161 L
.89506 .23161 L
.89508 .23161 L
.89511 .23161 L
s
.90773 .23161 m
.90791 .23161 L
.90808 .23161 L
.90825 .23161 L
.90842 .23161 L
.90857 .23161 L
.90873 .23161 L
.90888 .23161 L
.90902 .23161 L
.90916 .23161 L
.9093 .23161 L
.90942 .23161 L
.90955 .23161 L
.90967 .23161 L
.90978 .23161 L
.9099 .23161 L
.91 .23161 L
.9101 .23161 L
.9102 .23161 L
.91029 .23161 L
.91037 .23161 L
.91046 .23161 L
.91053 .23161 L
.9106 .23161 L
.91067 .23161 L
.91073 .23161 L
.91079 .23161 L
.91084 .23161 L
.91089 .23161 L
.91093 .23161 L
.91097 .23161 L
s
.92243 .23161 m
.92267 .23161 L
.9229 .23161 L
.92313 .23161 L
.92336 .23161 L
.92357 .23161 L
.92378 .23161 L
.92398 .23161 L
.92418 .23161 L
.92437 .23161 L
.92455 .23161 L
.92473 .23161 L
.9249 .23161 L
.92506 .23161 L
.92522 .23161 L
.92537 .23161 L
.92551 .23161 L
.92565 .23161 L
.92578 .23161 L
.9259 .23161 L
.92602 .23161 L
.92613 .23161 L
.92624 .23161 L
.92633 .23161 L
.92643 .23161 L
.92651 .23161 L
.92659 .23161 L
.92666 .23161 L
.92673 .23161 L
.92678 .23161 L
.92684 .23161 L
s
.93712 .23161 m
.93743 .23161 L
.93772 .23161 L
.93801 .23161 L
.93829 .23161 L
.93857 .23161 L
.93883 .23161 L
.93909 .23161 L
.93934 .23161 L
.93958 .23161 L
.93981 .23161 L
.94003 .23161 L
.94025 .23161 L
.94045 .23161 L
.94065 .23161 L
.94084 .23161 L
.94102 .23161 L
.9412 .23161 L
.94136 .23161 L
.94152 .23161 L
.94167 .23161 L
.94181 .23161 L
.94194 .23161 L
.94206 .23161 L
.94218 .23161 L
.94229 .23161 L
.94239 .23161 L
.94248 .23161 L
.94256 .23161 L
.94263 .23161 L
.9427 .23161 L
s
.95181 .23161 m
.95218 .23161 L
.95254 .23161 L
.95289 .23161 L
.95323 .23161 L
.95356 .23161 L
.95389 .23161 L
.9542 .23161 L
.9545 .23161 L
.95479 .23161 L
.95507 .23161 L
.95534 .23161 L
.9556 .23161 L
.95585 .23161 L
.95609 .23161 L
.95632 .23161 L
.95654 .23161 L
.95675 .23161 L
.95695 .23161 L
.95714 .23161 L
.95732 .23161 L
.95749 .23161 L
.95765 .23161 L
.9578 .23161 L
.95793 .23161 L
.95806 .23161 L
.95818 .23161 L
.95829 .23161 L
.95839 .23161 L
.95848 .23161 L
.95856 .23161 L
s
0 0 0 r
.03713 .23161 m
.2003 .23161 L
s
% Start of user PostScript
0 0 20.9492 0 MAarrowhead1
% End of user PostScript
.2003 .23161 m
.34089 .23161 L
s
% Start of user PostScript
20.9492 0 38.9991 0 MAarrowhead1
% End of user PostScript
.34089 .23161 m
.50449 .23161 L
s
% Start of user PostScript
38.9991 0 60.0033 0 MAarrowhead1
% End of user PostScript
.50449 .23161 m
.58211 .23161 L
s
% Start of user PostScript
60.0033 0 69.9689 0 MAarrowhead1
% End of user PostScript
.58211 .23161 m
.97179 .23161 L
s
% Start of user PostScript
69.9689 0 120. 0 MAarrowhead1
% End of user PostScript
.97179 .23161 m
.97179 .23161 L
s
% Start of user PostScript
120. 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.03699 .19656 m
.03701 .19889 L
.03702 .20123 L
.03704 .20357 L
.03705 .2059 L
.03707 .20824 L
.03708 .21058 L
.03709 .21291 L
.0371 .21525 L
.03711 .21759 L
.03711 .21992 L
.03712 .22226 L
.03712 .2246 L
.03713 .22693 L
.03713 .22927 L
.03713 .23161 L
.03713 .23394 L
.03713 .23628 L
.03712 .23862 L
.03712 .24095 L
.03711 .24329 L
.03711 .24563 L
.0371 .24796 L
.03709 .2503 L
.03708 .25264 L
.03707 .25497 L
.03705 .25731 L
.03704 .25965 L
.03702 .26198 L
.03701 .26432 L
.03699 .26666 L
s
.05228 .19648 m
.0523 .19883 L
.05232 .20117 L
.05233 .20351 L
.05235 .20585 L
.05236 .20819 L
.05237 .21053 L
.05238 .21288 L
.05239 .21522 L
.0524 .21756 L
.05241 .2199 L
.05241 .22224 L
.05242 .22458 L
.05242 .22692 L
.05242 .22927 L
.05242 .23161 L
.05242 .23395 L
.05242 .23629 L
.05242 .23863 L
.05241 .24097 L
.05241 .24332 L
.0524 .24566 L
.05239 .248 L
.05238 .25034 L
.05237 .25268 L
.05236 .25502 L
.05235 .25736 L
.05233 .25971 L
.05232 .26205 L
.0523 .26439 L
.05228 .26673 L
s
.06758 .19641 m
.06759 .19876 L
.06761 .2011 L
.06763 .20345 L
.06764 .2058 L
.06765 .20814 L
.06766 .21049 L
.06768 .21284 L
.06768 .21518 L
.06769 .21753 L
.0677 .21988 L
.06771 .22222 L
.06771 .22457 L
.06771 .22691 L
.06771 .22926 L
.06772 .23161 L
.06771 .23395 L
.06771 .2363 L
.06771 .23865 L
.06771 .24099 L
.0677 .24334 L
.06769 .24569 L
.06768 .24803 L
.06768 .25038 L
.06766 .25273 L
.06765 .25507 L
.06764 .25742 L
.06763 .25976 L
.06761 .26211 L
.06759 .26446 L
.06758 .2668 L
s
.08287 .19634 m
.08289 .19869 L
.0829 .20104 L
.08292 .20339 L
.08293 .20574 L
.08295 .20809 L
.08296 .21045 L
.08297 .2128 L
.08298 .21515 L
.08299 .2175 L
.08299 .21985 L
.083 .2222 L
.083 .22455 L
.08301 .22691 L
.08301 .22926 L
.08301 .23161 L
.08301 .23396 L
.08301 .23631 L
.083 .23866 L
.083 .24101 L
.08299 .24336 L
.08299 .24572 L
.08298 .24807 L
.08297 .25042 L
.08296 .25277 L
.08295 .25512 L
.08293 .25747 L
.08292 .25982 L
.0829 .26217 L
.08289 .26453 L
.08287 .26688 L
s
.09816 .19626 m
.09818 .19862 L
.0982 .20098 L
.09821 .20333 L
.09823 .20569 L
.09824 .20805 L
.09825 .2104 L
.09826 .21276 L
.09827 .21511 L
.09828 .21747 L
.09829 .21983 L
.09829 .22218 L
.0983 .22454 L
.0983 .2269 L
.0983 .22925 L
.0983 .23161 L
.0983 .23396 L
.0983 .23632 L
.0983 .23868 L
.09829 .24103 L
.09829 .24339 L
.09828 .24574 L
.09827 .2481 L
.09826 .25046 L
.09825 .25281 L
.09824 .25517 L
.09823 .25753 L
.09821 .25988 L
.0982 .26224 L
.09818 .26459 L
.09816 .26695 L
s
.11345 .19619 m
.11347 .19855 L
.11349 .20091 L
.1135 .20327 L
.11352 .20564 L
.11353 .208 L
.11354 .21036 L
.11355 .21272 L
.11356 .21508 L
.11357 .21744 L
.11358 .2198 L
.11358 .22216 L
.11359 .22452 L
.11359 .22689 L
.11359 .22925 L
.11359 .23161 L
.11359 .23397 L
.11359 .23633 L
.11359 .23869 L
.11358 .24105 L
.11358 .24341 L
.11357 .24577 L
.11356 .24814 L
.11355 .2505 L
.11354 .25286 L
.11353 .25522 L
.11352 .25758 L
.1135 .25994 L
.11349 .2623 L
.11347 .26466 L
.11345 .26702 L
s
.12875 .19612 m
.12876 .19848 L
.12878 .20085 L
.1288 .20322 L
.12881 .20558 L
.12882 .20795 L
.12884 .21031 L
.12885 .21268 L
.12886 .21505 L
.12886 .21741 L
.12887 .21978 L
.12888 .22214 L
.12888 .22451 L
.12888 .22688 L
.12889 .22924 L
.12889 .23161 L
.12889 .23397 L
.12888 .23634 L
.12888 .23871 L
.12888 .24107 L
.12887 .24344 L
.12886 .2458 L
.12886 .24817 L
.12885 .25054 L
.12884 .2529 L
.12882 .25527 L
.12881 .25763 L
.1288 .26 L
.12878 .26236 L
.12876 .26473 L
.12875 .2671 L
s
.14404 .19605 m
.14406 .19842 L
.14407 .20079 L
.14409 .20316 L
.1441 .20553 L
.14412 .2079 L
.14413 .21027 L
.14414 .21264 L
.14415 .21501 L
.14416 .21738 L
.14416 .21975 L
.14417 .22212 L
.14417 .2245 L
.14418 .22687 L
.14418 .22924 L
.14418 .23161 L
.14418 .23398 L
.14418 .23635 L
.14417 .23872 L
.14417 .24109 L
.14416 .24346 L
.14416 .24583 L
.14415 .2482 L
.14414 .25057 L
.14413 .25295 L
.14412 .25532 L
.1441 .25769 L
.14409 .26006 L
.14407 .26243 L
.14406 .2648 L
.14404 .26717 L
s
.15933 .19597 m
.15935 .19835 L
.15937 .20072 L
.15938 .2031 L
.1594 .20547 L
.15941 .20785 L
.15942 .21023 L
.15943 .2126 L
.15944 .21498 L
.15945 .21735 L
.15946 .21973 L
.15946 .2221 L
.15947 .22448 L
.15947 .22686 L
.15947 .22923 L
.15947 .23161 L
.15947 .23398 L
.15947 .23636 L
.15947 .23873 L
.15946 .24111 L
.15946 .24349 L
.15945 .24586 L
.15944 .24824 L
.15943 .25061 L
.15942 .25299 L
.15941 .25536 L
.1594 .25774 L
.15938 .26012 L
.15937 .26249 L
.15935 .26487 L
.15933 .26724 L
s
.17462 .1959 m
.17464 .19828 L
.17466 .20066 L
.17467 .20304 L
.17469 .20542 L
.1747 .2078 L
.17471 .21018 L
.17472 .21256 L
.17473 .21494 L
.17474 .21732 L
.17475 .2197 L
.17476 .22209 L
.17476 .22447 L
.17476 .22685 L
.17476 .22923 L
.17477 .23161 L
.17476 .23399 L
.17476 .23637 L
.17476 .23875 L
.17476 .24113 L
.17475 .24351 L
.17474 .24589 L
.17473 .24827 L
.17472 .25065 L
.17471 .25303 L
.1747 .25541 L
.17469 .25779 L
.17467 .26017 L
.17466 .26256 L
.17464 .26494 L
.17462 .26732 L
s
.18992 .19583 m
.18993 .19821 L
.18995 .2006 L
.18997 .20298 L
.18998 .20537 L
.19 .20775 L
.19001 .21014 L
.19002 .21252 L
.19003 .21491 L
.19004 .21729 L
.19004 .21968 L
.19005 .22207 L
.19005 .22445 L
.19006 .22684 L
.19006 .22922 L
.19006 .23161 L
.19006 .23399 L
.19006 .23638 L
.19005 .23876 L
.19005 .24115 L
.19004 .24354 L
.19004 .24592 L
.19003 .24831 L
.19002 .25069 L
.19001 .25308 L
.19 .25546 L
.18998 .25785 L
.18997 .26023 L
.18995 .26262 L
.18993 .265 L
.18992 .26739 L
s
.20561 .19576 m
.20562 .19815 L
.20563 .20054 L
.20563 .20293 L
.20564 .20532 L
.20565 .20771 L
.20565 .2101 L
.20566 .21249 L
.20566 .21488 L
.20566 .21727 L
.20567 .21966 L
.20567 .22205 L
.20567 .22444 L
.20567 .22683 L
.20567 .22922 L
.20568 .23161 L
.20567 .234 L
.20567 .23639 L
.20567 .23878 L
.20567 .24117 L
.20567 .24356 L
.20566 .24595 L
.20566 .24834 L
.20566 .25073 L
.20565 .25312 L
.20565 .25551 L
.20564 .2579 L
.20563 .26029 L
.20563 .26268 L
.20562 .26506 L
.20561 .26745 L
s
.22188 .19571 m
.22189 .19811 L
.2219 .2005 L
.22191 .20289 L
.22191 .20528 L
.22192 .20768 L
.22193 .21007 L
.22193 .21246 L
.22194 .21486 L
.22194 .21725 L
.22194 .21964 L
.22194 .22204 L
.22195 .22443 L
.22195 .22682 L
.22195 .22921 L
.22195 .23161 L
.22195 .234 L
.22195 .23639 L
.22195 .23879 L
.22194 .24118 L
.22194 .24357 L
.22194 .24597 L
.22194 .24836 L
.22193 .25075 L
.22193 .25314 L
.22192 .25554 L
.22191 .25793 L
.22191 .26032 L
.2219 .26272 L
.22189 .26511 L
.22188 .2675 L
s
.23816 .19566 m
.23817 .19806 L
.23817 .20046 L
.23818 .20285 L
.23819 .20525 L
.23819 .20765 L
.2382 .21004 L
.2382 .21244 L
.23821 .21483 L
.23821 .21723 L
.23822 .21963 L
.23822 .22202 L
.23822 .22442 L
.23822 .22682 L
.23822 .22921 L
.23822 .23161 L
.23822 .234 L
.23822 .2364 L
.23822 .2388 L
.23822 .24119 L
.23822 .24359 L
.23821 .24599 L
.23821 .24838 L
.2382 .25078 L
.2382 .25317 L
.23819 .25557 L
.23819 .25797 L
.23818 .26036 L
.23817 .26276 L
.23817 .26515 L
.23816 .26755 L
s
.25443 .19562 m
.25444 .19802 L
.25445 .20041 L
.25446 .20281 L
.25446 .20521 L
.25447 .20761 L
.25447 .21001 L
.25448 .21241 L
.25448 .21481 L
.25449 .21721 L
.25449 .21961 L
.25449 .22201 L
.2545 .22441 L
.2545 .22681 L
.2545 .22921 L
.2545 .23161 L
.2545 .23401 L
.2545 .23641 L
.2545 .23881 L
.25449 .24121 L
.25449 .2436 L
.25449 .246 L
.25448 .2484 L
.25448 .2508 L
.25447 .2532 L
.25447 .2556 L
.25446 .258 L
.25446 .2604 L
.25445 .2628 L
.25444 .2652 L
.25443 .2676 L
s
.27071 .19557 m
.27071 .19797 L
.27072 .20037 L
.27073 .20278 L
.27074 .20518 L
.27074 .20758 L
.27075 .20998 L
.27075 .21239 L
.27076 .21479 L
.27076 .21719 L
.27076 .21959 L
.27077 .222 L
.27077 .2244 L
.27077 .2268 L
.27077 .22921 L
.27077 .23161 L
.27077 .23401 L
.27077 .23641 L
.27077 .23882 L
.27077 .24122 L
.27076 .24362 L
.27076 .24602 L
.27076 .24843 L
.27075 .25083 L
.27075 .25323 L
.27074 .25563 L
.27074 .25804 L
.27073 .26044 L
.27072 .26284 L
.27071 .26524 L
.27071 .26765 L
s
.28698 .19552 m
.28699 .19793 L
.287 .20033 L
.287 .20274 L
.28701 .20514 L
.28702 .20755 L
.28702 .20995 L
.28703 .21236 L
.28703 .21477 L
.28704 .21717 L
.28704 .21958 L
.28704 .22198 L
.28704 .22439 L
.28704 .2268 L
.28705 .2292 L
.28705 .23161 L
.28705 .23401 L
.28704 .23642 L
.28704 .23883 L
.28704 .24123 L
.28704 .24364 L
.28704 .24604 L
.28703 .24845 L
.28703 .25085 L
.28702 .25326 L
.28702 .25567 L
.28701 .25807 L
.287 .26048 L
.287 .26288 L
.28699 .26529 L
.28698 .2677 L
s
.30325 .19547 m
.30326 .19788 L
.30327 .20029 L
.30328 .2027 L
.30328 .20511 L
.30329 .20752 L
.3033 .20993 L
.3033 .21233 L
.30331 .21474 L
.30331 .21715 L
.30331 .21956 L
.30332 .22197 L
.30332 .22438 L
.30332 .22679 L
.30332 .2292 L
.30332 .23161 L
.30332 .23402 L
.30332 .23643 L
.30332 .23883 L
.30332 .24124 L
.30331 .24365 L
.30331 .24606 L
.30331 .24847 L
.3033 .25088 L
.3033 .25329 L
.30329 .2557 L
.30328 .25811 L
.30328 .26052 L
.30327 .26293 L
.30326 .26533 L
.30325 .26774 L
s
.31953 .19542 m
.31954 .19784 L
.31954 .20025 L
.31955 .20266 L
.31956 .20507 L
.31956 .20748 L
.31957 .2099 L
.31958 .21231 L
.31958 .21472 L
.31958 .21713 L
.31959 .21955 L
.31959 .22196 L
.31959 .22437 L
.31959 .22678 L
.31959 .2292 L
.31959 .23161 L
.31959 .23402 L
.31959 .23643 L
.31959 .23884 L
.31959 .24126 L
.31959 .24367 L
.31958 .24608 L
.31958 .24849 L
.31958 .25091 L
.31957 .25332 L
.31956 .25573 L
.31956 .25814 L
.31955 .26056 L
.31954 .26297 L
.31954 .26538 L
.31953 .26779 L
s
.3358 .19537 m
.33581 .19779 L
.33582 .20021 L
.33583 .20262 L
.33583 .20504 L
.33584 .20745 L
.33584 .20987 L
.33585 .21228 L
.33585 .2147 L
.33586 .21711 L
.33586 .21953 L
.33586 .22195 L
.33587 .22436 L
.33587 .22678 L
.33587 .22919 L
.33587 .23161 L
.33587 .23402 L
.33587 .23644 L
.33587 .23885 L
.33586 .24127 L
.33586 .24369 L
.33586 .2461 L
.33585 .24852 L
.33585 .25093 L
.33584 .25335 L
.33584 .25576 L
.33583 .25818 L
.33583 .26059 L
.33582 .26301 L
.33581 .26542 L
.3358 .26784 L
s
.35139 .19531 m
.35141 .19773 L
.35143 .20015 L
.35145 .20257 L
.35146 .20499 L
.35147 .20741 L
.35149 .20983 L
.3515 .21225 L
.35151 .21467 L
.35152 .21709 L
.35152 .21951 L
.35153 .22193 L
.35153 .22435 L
.35154 .22677 L
.35154 .22919 L
.35154 .23161 L
.35154 .23403 L
.35154 .23645 L
.35153 .23887 L
.35153 .24129 L
.35152 .24371 L
.35152 .24613 L
.35151 .24855 L
.3515 .25097 L
.35149 .25339 L
.35147 .25581 L
.35146 .25823 L
.35145 .26065 L
.35143 .26307 L
.35141 .26549 L
.35139 .26791 L
s
.3668 .19524 m
.36681 .19766 L
.36683 .20009 L
.36685 .20251 L
.36686 .20494 L
.36688 .20736 L
.36689 .20978 L
.3669 .21221 L
.36691 .21463 L
.36692 .21706 L
.36692 .21948 L
.36693 .22191 L
.36693 .22433 L
.36694 .22676 L
.36694 .22918 L
.36694 .23161 L
.36694 .23403 L
.36694 .23646 L
.36693 .23888 L
.36693 .24131 L
.36692 .24373 L
.36692 .24616 L
.36691 .24858 L
.3669 .25101 L
.36689 .25343 L
.36688 .25586 L
.36686 .25828 L
.36685 .2607 L
.36683 .26313 L
.36681 .26555 L
.3668 .26798 L
s
.3822 .19516 m
.38221 .19759 L
.38223 .20002 L
.38225 .20245 L
.38226 .20488 L
.38228 .20731 L
.38229 .20974 L
.3823 .21217 L
.38231 .2146 L
.38232 .21703 L
.38233 .21946 L
.38233 .22189 L
.38234 .22432 L
.38234 .22675 L
.38234 .22918 L
.38234 .23161 L
.38234 .23404 L
.38234 .23647 L
.38234 .2389 L
.38233 .24133 L
.38233 .24376 L
.38232 .24619 L
.38231 .24862 L
.3823 .25104 L
.38229 .25347 L
.38228 .2559 L
.38226 .25833 L
.38225 .26076 L
.38223 .26319 L
.38221 .26562 L
.3822 .26805 L
s
.3976 .19509 m
.39762 .19752 L
.39763 .19996 L
.39765 .20239 L
.39766 .20483 L
.39768 .20726 L
.39769 .2097 L
.3977 .21213 L
.39771 .21457 L
.39772 .217 L
.39773 .21944 L
.39773 .22187 L
.39774 .2243 L
.39774 .22674 L
.39774 .22917 L
.39774 .23161 L
.39774 .23404 L
.39774 .23648 L
.39774 .23891 L
.39773 .24135 L
.39773 .24378 L
.39772 .24621 L
.39771 .24865 L
.3977 .25108 L
.39769 .25352 L
.39768 .25595 L
.39766 .25839 L
.39765 .26082 L
.39763 .26326 L
.39762 .26569 L
.3976 .26813 L
s
.413 .19502 m
.41302 .19746 L
.41303 .1999 L
.41305 .20233 L
.41307 .20477 L
.41308 .20721 L
.41309 .20965 L
.4131 .21209 L
.41311 .21453 L
.41312 .21697 L
.41313 .21941 L
.41313 .22185 L
.41314 .22429 L
.41314 .22673 L
.41314 .22917 L
.41314 .23161 L
.41314 .23405 L
.41314 .23649 L
.41314 .23893 L
.41313 .24137 L
.41313 .2438 L
.41312 .24624 L
.41311 .24868 L
.4131 .25112 L
.41309 .25356 L
.41308 .256 L
.41307 .25844 L
.41305 .26088 L
.41303 .26332 L
.41302 .26576 L
.413 .2682 L
s
.4284 .19494 m
.42842 .19739 L
.42844 .19983 L
.42845 .20228 L
.42847 .20472 L
.42848 .20716 L
.42849 .20961 L
.4285 .21205 L
.42851 .2145 L
.42852 .21694 L
.42853 .21939 L
.42854 .22183 L
.42854 .22427 L
.42854 .22672 L
.42855 .22916 L
.42855 .23161 L
.42855 .23405 L
.42854 .2365 L
.42854 .23894 L
.42854 .24138 L
.42853 .24383 L
.42852 .24627 L
.42851 .24872 L
.4285 .25116 L
.42849 .25361 L
.42848 .25605 L
.42847 .25849 L
.42845 .26094 L
.42844 .26338 L
.42842 .26583 L
.4284 .26827 L
s
.4438 .19487 m
.44382 .19732 L
.44384 .19977 L
.44385 .20222 L
.44387 .20467 L
.44388 .20712 L
.44389 .20957 L
.44391 .21201 L
.44392 .21446 L
.44392 .21691 L
.44393 .21936 L
.44394 .22181 L
.44394 .22426 L
.44395 .22671 L
.44395 .22916 L
.44395 .23161 L
.44395 .23406 L
.44395 .23651 L
.44394 .23896 L
.44394 .2414 L
.44393 .24385 L
.44392 .2463 L
.44392 .24875 L
.44391 .2512 L
.44389 .25365 L
.44388 .2561 L
.44387 .25855 L
.44385 .261 L
.44384 .26345 L
.44382 .2659 L
.4438 .26835 L
s
.4592 .1948 m
.45922 .19725 L
.45924 .1997 L
.45925 .20216 L
.45927 .20461 L
.45928 .20707 L
.4593 .20952 L
.45931 .21198 L
.45932 .21443 L
.45933 .21688 L
.45933 .21934 L
.45934 .22179 L
.45934 .22425 L
.45935 .2267 L
.45935 .22915 L
.45935 .23161 L
.45935 .23406 L
.45935 .23652 L
.45934 .23897 L
.45934 .24142 L
.45933 .24388 L
.45933 .24633 L
.45932 .24879 L
.45931 .25124 L
.4593 .25369 L
.45928 .25615 L
.45927 .2586 L
.45925 .26106 L
.45924 .26351 L
.45922 .26596 L
.4592 .26842 L
s
.4746 .19472 m
.47462 .19718 L
.47464 .19964 L
.47466 .2021 L
.47467 .20456 L
.47469 .20702 L
.4747 .20948 L
.47471 .21194 L
.47472 .2144 L
.47473 .21685 L
.47473 .21931 L
.47474 .22177 L
.47474 .22423 L
.47475 .22669 L
.47475 .22915 L
.47475 .23161 L
.47475 .23407 L
.47475 .23653 L
.47474 .23898 L
.47474 .24144 L
.47473 .2439 L
.47473 .24636 L
.47472 .24882 L
.47471 .25128 L
.4747 .25374 L
.47469 .2562 L
.47467 .25866 L
.47466 .26112 L
.47464 .26357 L
.47462 .26603 L
.4746 .26849 L
s
.49 .19465 m
.49002 .19711 L
.49004 .19958 L
.49006 .20204 L
.49007 .20451 L
.49009 .20697 L
.4901 .20943 L
.49011 .2119 L
.49012 .21436 L
.49013 .21682 L
.49014 .21929 L
.49014 .22175 L
.49015 .22422 L
.49015 .22668 L
.49015 .22914 L
.49015 .23161 L
.49015 .23407 L
.49015 .23654 L
.49015 .239 L
.49014 .24146 L
.49014 .24393 L
.49013 .24639 L
.49012 .24885 L
.49011 .25132 L
.4901 .25378 L
.49009 .25625 L
.49007 .25871 L
.49006 .26117 L
.49004 .26364 L
.49002 .2661 L
.49 .26857 L
s
.50636 .19462 m
.50626 .19709 L
.50616 .19955 L
.50608 .20202 L
.506 .20448 L
.50593 .20695 L
.50586 .20942 L
.50581 .21188 L
.50575 .21435 L
.50571 .21681 L
.50567 .21928 L
.50564 .22174 L
.50562 .22421 L
.5056 .22668 L
.50559 .22914 L
.50559 .23161 L
.50559 .23407 L
.5056 .23654 L
.50562 .23901 L
.50564 .24147 L
.50567 .24394 L
.50571 .2464 L
.50575 .24887 L
.50581 .25133 L
.50586 .2538 L
.50593 .25627 L
.506 .25873 L
.50608 .2612 L
.50616 .26366 L
.50626 .26613 L
.50636 .26859 L
s
.52223 .19518 m
.52213 .19761 L
.52204 .20004 L
.52196 .20247 L
.52188 .20489 L
.52181 .20732 L
.52175 .20975 L
.52169 .21218 L
.52164 .21461 L
.5216 .21704 L
.52156 .21947 L
.52153 .22189 L
.5215 .22432 L
.52149 .22675 L
.52148 .22918 L
.52147 .23161 L
.52148 .23404 L
.52149 .23646 L
.5215 .23889 L
.52153 .24132 L
.52156 .24375 L
.5216 .24618 L
.52164 .24861 L
.52169 .25104 L
.52175 .25346 L
.52181 .25589 L
.52188 .25832 L
.52196 .26075 L
.52204 .26318 L
.52213 .26561 L
.52223 .26803 L
s
.53811 .19574 m
.53801 .19813 L
.53792 .20052 L
.53784 .20291 L
.53776 .20531 L
.53769 .2077 L
.53763 .21009 L
.53757 .21248 L
.53752 .21487 L
.53748 .21726 L
.53744 .21965 L
.53741 .22204 L
.53739 .22443 L
.53737 .22683 L
.53736 .22922 L
.53736 .23161 L
.53736 .234 L
.53737 .23639 L
.53739 .23878 L
.53741 .24117 L
.53744 .24356 L
.53748 .24595 L
.53752 .24835 L
.53757 .25074 L
.53763 .25313 L
.53769 .25552 L
.53776 .25791 L
.53784 .2603 L
.53792 .26269 L
.53801 .26508 L
.53811 .26747 L
s
.55398 .1963 m
.55389 .19866 L
.5538 .20101 L
.55372 .20336 L
.55364 .20572 L
.55357 .20807 L
.55351 .21042 L
.55346 .21278 L
.55341 .21513 L
.55336 .21749 L
.55333 .21984 L
.5533 .22219 L
.55328 .22455 L
.55326 .2269 L
.55325 .22925 L
.55325 .23161 L
.55325 .23396 L
.55326 .23632 L
.55328 .23867 L
.5533 .24102 L
.55333 .24338 L
.55336 .24573 L
.55341 .24808 L
.55346 .25044 L
.55351 .25279 L
.55357 .25514 L
.55364 .2575 L
.55372 .25985 L
.5538 .26221 L
.55389 .26456 L
.55398 .26691 L
s
.56986 .19686 m
.56976 .19918 L
.56968 .20149 L
.5696 .20381 L
.56952 .20613 L
.56945 .20844 L
.56939 .21076 L
.56934 .21308 L
.56929 .21539 L
.56925 .21771 L
.56921 .22003 L
.56919 .22234 L
.56916 .22466 L
.56915 .22697 L
.56914 .22929 L
.56913 .23161 L
.56914 .23392 L
.56915 .23624 L
.56916 .23856 L
.56919 .24087 L
.56921 .24319 L
.56925 .24551 L
.56929 .24782 L
.56934 .25014 L
.56939 .25246 L
.56945 .25477 L
.56952 .25709 L
.5696 .2594 L
.56968 .26172 L
.56976 .26404 L
.56986 .26635 L
s
.58812 .19763 m
.58771 .1999 L
.58733 .20216 L
.58697 .20443 L
.58665 .20669 L
.58635 .20896 L
.58609 .21122 L
.58585 .21349 L
.58564 .21575 L
.58545 .21802 L
.5853 .22028 L
.58517 .22255 L
.58507 .22481 L
.585 .22708 L
.58496 .22934 L
.58494 .23161 L
.58496 .23387 L
.585 .23614 L
.58507 .2384 L
.58517 .24067 L
.5853 .24293 L
.58545 .2452 L
.58564 .24746 L
.58585 .24973 L
.58609 .25199 L
.58635 .25426 L
.58665 .25652 L
.58697 .25879 L
.58733 .26105 L
.58771 .26332 L
.58812 .26558 L
s
.60343 .19933 m
.60304 .20148 L
.60268 .20364 L
.60235 .20579 L
.60204 .20794 L
.60176 .21009 L
.6015 .21224 L
.60128 .21439 L
.60107 .21655 L
.6009 .2187 L
.60075 .22085 L
.60063 .223 L
.60054 .22515 L
.60047 .2273 L
.60043 .22946 L
.60042 .23161 L
.60043 .23376 L
.60047 .23591 L
.60054 .23806 L
.60063 .24021 L
.60075 .24237 L
.6009 .24452 L
.60107 .24667 L
.60128 .24882 L
.6015 .25097 L
.60176 .25312 L
.60204 .25528 L
.60235 .25743 L
.60268 .25958 L
.60304 .26173 L
.60343 .26388 L
s
.61875 .20103 m
.61838 .20307 L
.61804 .20511 L
.61772 .20715 L
.61743 .20919 L
.61716 .21122 L
.61692 .21326 L
.6167 .2153 L
.61651 .21734 L
.61635 .21938 L
.61621 .22142 L
.6161 .22345 L
.61601 .22549 L
.61594 .22753 L
.61591 .22957 L
.61589 .23161 L
.61591 .23365 L
.61594 .23568 L
.61601 .23772 L
.6161 .23976 L
.61621 .2418 L
.61635 .24384 L
.61651 .24588 L
.6167 .24791 L
.61692 .24995 L
.61716 .25199 L
.61743 .25403 L
.61772 .25607 L
.61804 .25811 L
.61838 .26014 L
.61875 .26218 L
s
.63406 .20273 m
.63371 .20466 L
.63339 .20658 L
.63309 .20851 L
.63282 .21043 L
.63256 .21236 L
.63234 .21428 L
.63213 .21621 L
.63195 .21813 L
.6318 .22006 L
.63167 .22198 L
.63156 .22391 L
.63147 .22583 L
.63141 .22776 L
.63138 .22968 L
.63137 .23161 L
.63138 .23353 L
.63141 .23546 L
.63147 .23738 L
.63156 .23931 L
.63167 .24123 L
.6318 .24316 L
.63195 .24508 L
.63213 .24701 L
.63234 .24893 L
.63256 .25086 L
.63282 .25278 L
.63309 .25471 L
.63339 .25663 L
.63371 .25856 L
.63406 .26048 L
s
.64938 .20443 m
.64905 .20624 L
.64875 .20806 L
.64846 .20987 L
.6482 .21168 L
.64797 .21349 L
.64775 .2153 L
.64756 .21711 L
.64739 .21893 L
.64725 .22074 L
.64712 .22255 L
.64702 .22436 L
.64694 .22617 L
.64689 .22798 L
.64685 .2298 L
.64684 .23161 L
.64685 .23342 L
.64689 .23523 L
.64694 .23704 L
.64702 .23885 L
.64712 .24067 L
.64725 .24248 L
.64739 .24429 L
.64756 .2461 L
.64775 .24791 L
.64797 .24972 L
.6482 .25154 L
.64846 .25335 L
.64875 .25516 L
.64905 .25697 L
.64938 .25878 L
s
.66469 .20613 m
.66439 .20783 L
.6641 .20953 L
.66384 .21123 L
.66359 .21293 L
.66337 .21462 L
.66317 .21632 L
.66299 .21802 L
.66283 .21972 L
.66269 .22142 L
.66258 .22312 L
.66248 .22481 L
.66241 .22651 L
.66236 .22821 L
.66232 .22991 L
.66231 .23161 L
.66232 .23331 L
.66236 .235 L
.66241 .2367 L
.66248 .2384 L
.66258 .2401 L
.66269 .2418 L
.66283 .2435 L
.66299 .24519 L
.66317 .24689 L
.66337 .24859 L
.66359 .25029 L
.66384 .25199 L
.6641 .25369 L
.66439 .25538 L
.66469 .25708 L
s
.68001 .20783 m
.67972 .20942 L
.67945 .211 L
.67921 .21259 L
.67898 .21417 L
.67877 .21576 L
.67859 .21734 L
.67842 .21893 L
.67827 .22051 L
.67814 .2221 L
.67803 .22368 L
.67795 .22527 L
.67788 .22685 L
.67783 .22844 L
.6778 .23002 L
.67779 .23161 L
.6778 .23319 L
.67783 .23478 L
.67788 .23636 L
.67795 .23795 L
.67803 .23953 L
.67814 .24112 L
.67827 .2427 L
.67842 .24429 L
.67859 .24587 L
.67877 .24746 L
.67898 .24904 L
.67921 .25063 L
.67945 .25221 L
.67972 .2538 L
.68001 .25538 L
s
.69532 .20953 m
.69506 .21101 L
.69481 .21248 L
.69458 .21395 L
.69437 .21542 L
.69418 .21689 L
.694 .21836 L
.69385 .21984 L
.69371 .22131 L
.69359 .22278 L
.69349 .22425 L
.69341 .22572 L
.69334 .22719 L
.6933 .22866 L
.69327 .23014 L
.69326 .23161 L
.69327 .23308 L
.6933 .23455 L
.69334 .23602 L
.69341 .23749 L
.69349 .23897 L
.69359 .24044 L
.69371 .24191 L
.69385 .24338 L
.694 .24485 L
.69418 .24632 L
.69437 .24779 L
.69458 .24927 L
.69481 .25074 L
.69506 .25221 L
.69532 .25368 L
s
.71064 .21123 m
.71039 .21259 L
.71016 .21395 L
.70995 .21531 L
.70976 .21667 L
.70958 .21803 L
.70942 .21938 L
.70928 .22074 L
.70915 .2221 L
.70904 .22346 L
.70895 .22482 L
.70887 .22617 L
.70881 .22753 L
.70877 .22889 L
.70874 .23025 L
.70874 .23161 L
.70874 .23297 L
.70877 .23432 L
.70881 .23568 L
.70887 .23704 L
.70895 .2384 L
.70904 .23976 L
.70915 .24111 L
.70928 .24247 L
.70942 .24383 L
.70958 .24519 L
.70976 .24655 L
.70995 .24791 L
.71016 .24926 L
.71039 .25062 L
.71064 .25198 L
s
.72595 .21294 m
.72573 .21418 L
.72552 .21542 L
.72532 .21667 L
.72515 .21791 L
.72498 .21916 L
.72484 .2204 L
.72471 .22165 L
.72459 .22289 L
.72449 .22414 L
.7244 .22538 L
.72433 .22663 L
.72428 .22787 L
.72424 .22912 L
.72422 .23036 L
.72421 .23161 L
.72422 .23285 L
.72424 .2341 L
.72428 .23534 L
.72433 .23659 L
.7244 .23783 L
.72449 .23908 L
.72459 .24032 L
.72471 .24157 L
.72484 .24281 L
.72498 .24406 L
.72515 .2453 L
.72532 .24655 L
.72552 .24779 L
.72573 .24904 L
.72595 .25028 L
s
.74127 .21464 m
.74106 .21577 L
.74087 .2169 L
.7407 .21803 L
.74054 .21916 L
.74039 .22029 L
.74025 .22142 L
.74013 .22256 L
.74003 .22369 L
.73994 .22482 L
.73986 .22595 L
.7398 .22708 L
.73975 .22821 L
.73971 .22934 L
.73969 .23048 L
.73968 .23161 L
.73969 .23274 L
.73971 .23387 L
.73975 .235 L
.7398 .23613 L
.73986 .23727 L
.73994 .2384 L
.74003 .23953 L
.74013 .24066 L
.74025 .24179 L
.74039 .24292 L
.74054 .24405 L
.7407 .24519 L
.74087 .24632 L
.74106 .24745 L
.74127 .24858 L
s
.75658 .21634 m
.7564 .21735 L
.75623 .21837 L
.75607 .21939 L
.75592 .22041 L
.75579 .22143 L
.75567 .22244 L
.75556 .22346 L
.75547 .22448 L
.75538 .2255 L
.75532 .22652 L
.75526 .22754 L
.75521 .22855 L
.75518 .22957 L
.75516 .23059 L
.75516 .23161 L
.75516 .23263 L
.75518 .23364 L
.75521 .23466 L
.75526 .23568 L
.75532 .2367 L
.75538 .23772 L
.75547 .23873 L
.75556 .23975 L
.75567 .24077 L
.75579 .24179 L
.75592 .24281 L
.75607 .24382 L
.75623 .24484 L
.7564 .24586 L
.75658 .24688 L
s
.7719 .21804 m
.77173 .21894 L
.77158 .21985 L
.77144 .22075 L
.77131 .22166 L
.77119 .22256 L
.77109 .22347 L
.77099 .22437 L
.77091 .22527 L
.77083 .22618 L
.77077 .22708 L
.77072 .22799 L
.77068 .22889 L
.77065 .2298 L
.77064 .2307 L
.77063 .23161 L
.77064 .23251 L
.77065 .23342 L
.77068 .23432 L
.77072 .23523 L
.77077 .23613 L
.77083 .23704 L
.77091 .23794 L
.77099 .23885 L
.77109 .23975 L
.77119 .24066 L
.77131 .24156 L
.77144 .24246 L
.77158 .24337 L
.77173 .24427 L
.7719 .24518 L
s
.78721 .21974 m
.78707 .22053 L
.78694 .22132 L
.78681 .22211 L
.7867 .2229 L
.7866 .22369 L
.7865 .22449 L
.78642 .22528 L
.78635 .22607 L
.78628 .22686 L
.78623 .22765 L
.78618 .22844 L
.78615 .22923 L
.78612 .23002 L
.78611 .23082 L
.7861 .23161 L
.78611 .2324 L
.78612 .23319 L
.78615 .23398 L
.78618 .23477 L
.78623 .23556 L
.78628 .23636 L
.78635 .23715 L
.78642 .23794 L
.7865 .23873 L
.7866 .23952 L
.7867 .24031 L
.78681 .2411 L
.78694 .2419 L
.78707 .24269 L
.78721 .24348 L
s
.80253 .22144 m
.80241 .22212 L
.80229 .22279 L
.80219 .22347 L
.80209 .22415 L
.802 .22483 L
.80192 .22551 L
.80185 .22618 L
.80179 .22686 L
.80173 .22754 L
.80168 .22822 L
.80165 .2289 L
.80162 .22957 L
.8016 .23025 L
.80158 .23093 L
.80158 .23161 L
.80158 .23229 L
.8016 .23296 L
.80162 .23364 L
.80165 .23432 L
.80168 .235 L
.80173 .23568 L
.80179 .23635 L
.80185 .23703 L
.80192 .23771 L
.802 .23839 L
.80209 .23907 L
.80219 .23974 L
.80229 .24042 L
.80241 .2411 L
.80253 .24178 L
s
.81784 .22314 m
.81774 .2237 L
.81765 .22427 L
.81756 .22483 L
.81748 .2254 L
.8174 .22596 L
.81734 .22653 L
.81728 .22709 L
.81722 .22766 L
.81718 .22822 L
.81714 .22878 L
.81711 .22935 L
.81708 .22991 L
.81707 .23048 L
.81706 .23104 L
.81705 .23161 L
.81706 .23217 L
.81707 .23274 L
.81708 .2333 L
.81711 .23387 L
.81714 .23443 L
.81718 .235 L
.81722 .23556 L
.81728 .23612 L
.81734 .23669 L
.8174 .23725 L
.81748 .23782 L
.81756 .23838 L
.81765 .23895 L
.81774 .23951 L
.81784 .24008 L
s
.83316 .22484 m
.83308 .22529 L
.833 .22574 L
.83293 .22619 L
.83287 .22664 L
.83281 .22709 L
.83275 .22755 L
.83271 .228 L
.83266 .22845 L
.83263 .2289 L
.8326 .22935 L
.83257 .2298 L
.83255 .23025 L
.83254 .23071 L
.83253 .23116 L
.83253 .23161 L
.83253 .23206 L
.83254 .23251 L
.83255 .23296 L
.83257 .23341 L
.8326 .23386 L
.83263 .23432 L
.83266 .23477 L
.83271 .23522 L
.83275 .23567 L
.83281 .23612 L
.83287 .23657 L
.83293 .23702 L
.833 .23747 L
.83308 .23793 L
.83316 .23838 L
s
.84847 .22654 m
.84841 .22688 L
.84836 .22721 L
.8483 .22755 L
.84825 .22789 L
.84821 .22823 L
.84817 .22857 L
.84813 .2289 L
.8481 .22924 L
.84808 .22958 L
.84805 .22992 L
.84803 .23026 L
.84802 .23059 L
.84801 .23093 L
.848 .23127 L
.848 .23161 L
.848 .23195 L
.84801 .23228 L
.84802 .23262 L
.84803 .23296 L
.84805 .2333 L
.84808 .23364 L
.8481 .23397 L
.84813 .23431 L
.84817 .23465 L
.84821 .23499 L
.84825 .23532 L
.8483 .23566 L
.84836 .236 L
.84841 .23634 L
.84847 .23668 L
s
.86379 .22824 m
.86375 .22846 L
.86371 .22869 L
.86367 .22891 L
.86364 .22914 L
.86361 .22936 L
.86359 .22959 L
.86356 .22981 L
.86354 .23004 L
.86352 .23026 L
.86351 .23048 L
.8635 .23071 L
.86349 .23093 L
.86348 .23116 L
.86348 .23138 L
.86347 .23161 L
.86348 .23183 L
.86348 .23206 L
.86349 .23228 L
.8635 .23251 L
.86351 .23273 L
.86352 .23296 L
.86354 .23318 L
.86356 .2334 L
.86359 .23363 L
.86361 .23385 L
.86364 .23408 L
.86367 .2343 L
.86371 .23453 L
.86375 .23475 L
.86379 .23498 L
s
.8791 .22994 m
.87908 .23005 L
.87906 .23016 L
.87905 .23027 L
.87903 .23038 L
.87902 .2305 L
.879 .23061 L
.87899 .23072 L
.87898 .23083 L
.87897 .23094 L
.87896 .23105 L
.87896 .23116 L
.87895 .23127 L
.87895 .23139 L
.87895 .2315 L
.87895 .23161 L
.87895 .23172 L
.87895 .23183 L
.87895 .23194 L
.87896 .23205 L
.87896 .23216 L
.87897 .23227 L
.87898 .23239 L
.87899 .2325 L
.879 .23261 L
.87902 .23272 L
.87903 .23283 L
.87905 .23294 L
.87906 .23305 L
.87908 .23316 L
.8791 .23328 L
s
.89442 .23157 m
.89442 .23158 L
.89442 .23158 L
.89442 .23158 L
.89442 .23158 L
.89442 .23159 L
.89442 .23159 L
.89442 .23159 L
.89442 .23159 L
.89442 .23159 L
.89442 .2316 L
.89442 .2316 L
.89442 .2316 L
.89442 .2316 L
.89442 .23161 L
.89442 .23161 L
.89442 .23161 L
.89442 .23161 L
.89442 .23161 L
.89442 .23162 L
.89442 .23162 L
.89442 .23162 L
.89442 .23162 L
.89442 .23163 L
.89442 .23163 L
.89442 .23163 L
.89442 .23163 L
.89442 .23163 L
.89442 .23164 L
.89442 .23164 L
.89442 .23164 L
s
.90973 .22987 m
.90975 .22999 L
.90977 .23011 L
.90979 .23022 L
.90981 .23034 L
.90982 .23045 L
.90984 .23057 L
.90985 .23068 L
.90986 .2308 L
.90987 .23091 L
.90988 .23103 L
.90988 .23115 L
.90989 .23126 L
.90989 .23138 L
.90989 .23149 L
.9099 .23161 L
.90989 .23172 L
.90989 .23184 L
.90989 .23195 L
.90988 .23207 L
.90988 .23219 L
.90987 .2323 L
.90986 .23242 L
.90985 .23253 L
.90984 .23265 L
.90982 .23276 L
.90981 .23288 L
.90979 .23299 L
.90977 .23311 L
.90975 .23323 L
.90973 .23334 L
s
.92505 .22817 m
.92509 .2284 L
.92513 .22863 L
.92516 .22886 L
.9252 .22909 L
.92523 .22932 L
.92525 .22955 L
.92528 .22978 L
.9253 .23001 L
.92532 .23023 L
.92533 .23046 L
.92535 .23069 L
.92536 .23092 L
.92536 .23115 L
.92537 .23138 L
.92537 .23161 L
.92537 .23184 L
.92536 .23207 L
.92536 .23229 L
.92535 .23252 L
.92533 .23275 L
.92532 .23298 L
.9253 .23321 L
.92528 .23344 L
.92525 .23367 L
.92523 .2339 L
.9252 .23413 L
.92516 .23435 L
.92513 .23458 L
.92509 .23481 L
.92505 .23504 L
s
.94036 .22647 m
.94043 .22682 L
.94048 .22716 L
.94054 .2275 L
.94059 .22784 L
.94063 .22819 L
.94067 .22853 L
.94071 .22887 L
.94074 .22921 L
.94077 .22955 L
.94079 .2299 L
.94081 .23024 L
.94082 .23058 L
.94083 .23092 L
.94084 .23127 L
.94084 .23161 L
.94084 .23195 L
.94083 .23229 L
.94082 .23263 L
.94081 .23298 L
.94079 .23332 L
.94077 .23366 L
.94074 .234 L
.94071 .23435 L
.94067 .23469 L
.94063 .23503 L
.94059 .23537 L
.94054 .23571 L
.94048 .23606 L
.94043 .2364 L
.94036 .23674 L
s
.95568 .22477 m
.95576 .22523 L
.95584 .22568 L
.95591 .22614 L
.95597 .2266 L
.95603 .22705 L
.95609 .22751 L
.95614 .22796 L
.95618 .22842 L
.95621 .22887 L
.95625 .22933 L
.95627 .22979 L
.95629 .23024 L
.95631 .2307 L
.95631 .23115 L
.95632 .23161 L
.95631 .23206 L
.95631 .23252 L
.95629 .23297 L
.95627 .23343 L
.95625 .23389 L
.95621 .23434 L
.95618 .2348 L
.95614 .23525 L
.95609 .23571 L
.95603 .23616 L
.95597 .23662 L
.95591 .23708 L
.95584 .23753 L
.95576 .23799 L
.95568 .23844 L
s
0 0 m
1 0 L
1 .43683 L
0 .43683 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[90]:=",
  ImageSize->{288, 125.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000OB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`001_ooool3o`0000Cooooo2?l0
0002ooooo`04o`000?oooooo0000ooooo`;o0000m?ooool3o`0000cooooo0007ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00001?ooool01ol0003oooooo`000?oooooo0000oooo
ool00000mOooool01?l0003oooooooooool0000;ooooo`001oooool3o`0000?ooooo00Co0000oooo
oooooooo00000_ooool2o`0000;ooooo00Go0000ooooool0003oooooo`00003hooooo`03o`000?oo
oooooooo00Wooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00004ooooo`05o`000?oooooo0000ooooool00000m_ooool2o`0000cooooo0007ooooo`05
o`000?ooooooooooo`000?ooool01Ol00002ooooo`So0000m_ooool00ol0003oooooooooo`0<oooo
o`001oooool01?l0003oooooooooool0003oooooo`Oooooo00Co0000oooooooooooo00002oooool0
00Kooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo0ol0000;ooooo`00oooooolQooooo`00
oooooolQooooo`006Ooooom]o`0008cooooo0_l0000<ooooo`006Oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0;
ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0R_ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0;ooooo`00
6Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
R_ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0;ooooo`006Oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0R_ooool0
0ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0R_ooool00ol0003o
ooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0R_ooool00ol0003ooooooooo
o`0;ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool6o`0007Cooooo00?o0000oooo
ooooool02oooool001Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`00001dooooo`03o`000?oooooooooo
00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool02oooool001Wooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1fooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo07Kooooo00?o0000
ooooooooool02oooool001Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo013ooooo0ol0001gooooo`03o`000?oooooooooo00_ooooo000Iooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`03o`000?oo
oooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0>ooooo`_o0000LOooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03_ooool;o`00
077ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00kooooo00?o0000ogmoOomoOgl01omoOgl00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0=ooooo`;o00002OmoOgl2o`00073ooooo
00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00gooooo3Ol0001`ooooo`03o`000?oooooooooo00_ooooo000I
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0=
ooooo`;o00002OmoOgl2o`00073ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00cooooo00?o0000ogmo
Ool000002OmoOgl00ol0003oOgmoo`00001_ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0<ooooo`03
o`000?moOgoo000000WoOgmo00?o0000ogmoOol00000Koooool00ol0003oooooooooo`0;ooooo`00
6Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
3?ooool00ol0003oOgmoo`000009ogmoO`03o`000?moOgoo000006oooooo00?o0000ooooooooool0
2oooool001Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00cooooo00?o0000ogmoOol000002_l000000omoOgoo0000ooooo`1^ooooo`03o`000?oo
oooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0;ooooo`04o`000?moOgooOgmoo`0000WoOgmo00Co0000ogmoOomoOgoo0000
K_ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool02oooool01?l0003oOgmoogmoOol00009ogmoO`04o`00
0?moOgooOgmoo`0006kooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00_ooooo00Co0000ogmoOomoOgoo
00002OmoOgl01?l0003oOgmoogmoOol0001^ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0;ooooo`04
o`000?moOgooOgmoo`0000WoOgmo00Co0000ogmoOomoOgoo0000K_ooool00ol0003oooooooooo`0;
ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool02oooool01?l0003oOgmoogmoOol00009ogmoO`04o`000?moOgooOgmoo`0006kooooo00?o
0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00[ooooo00Go0000ogmoOomoOgooOgmoo`000009ogmoO`05o`000?mo
OgooOgmoogmoOol00000KOooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_ooool01?l0003oOgmoogmo
OomoOgl;o`0000?oOgmo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0;ooooo`006Ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_oo
ool01Ol0003oOgmoogmoOomoOgoo000000WoOgmo00Go0000ogmoOomoOgooOgmoo`00001]ooooo`03
o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0:ooooo`05o`000?moOgooOgmoogmoOol000002OmoOgl01Ol0003o
OgmoogmoOomoOgoo000006gooooo00?o0000ooooooooool02oooool001Wooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00[ooooo00Go0000ogmoOomo
OgooOgmoo`000009ogmoO`05o`000?moOgooOgmoogmoOol00000KOooool00ol0003oooooooooo`0;
ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool02Oooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00OoOgmo00?o0000ogmo
OomoOgl00_moOgl00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00_ooooo000@oooooi;o
2NX:0omoOgl00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o2NX:
2Oooool00ol0003oooooooooo`07ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooooooooooo
ooooo`WZ2P03ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo
2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX0
1?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04oooo
o`05o`WZ2_ooooooooooooooool9jPX00oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go
2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:o`000?oooooo
ooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Ko2NX:ogmoOomoOgooOgmoo`WZ2_l00003
ogmoO`03o`WZ2_moOgooOgmo00?oOgmo00?o0000ogmoOol9jPX02ol9jPYTooooo`03o`000?oooooo
oooo00_ooooo000>ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[oooooo`000?oo
oooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9
jPX00oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04
ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo
00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9
jP[ooooooooooooooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oo
ooooooooooooool9jPX00oooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_l0003oooooooooool9
jPX00oooool00ol9jP[oooooooooo`02ooooo`06o`WZ2_moOgooOgmoogmoOol9jP[o00000omoOgl0
2Ol9jP[oOgmoogmoOomoOgoo2NX:ogmoOol0003oOgmoo`WZ2P02ogmoO`04o`000?ooooooooooo`WZ
2P?ooooo00?o2NX:ooooool9jPX01ol9jPYLooooo`03o`000?oooooooooo00_ooooo000>ooooo`05
o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[oooooo`000?oooooo2NX:00?ooooo00Go2NX:
ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool01Ol9jP[ooooo
oooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooooooo
ooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooooooooooooooo
o`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:
00?ooooo00Co2NX:oooooooooooooooo0_l9jPX3ooooo`05o`WZ2_ooooooooooooooool9jPX00ooo
ool00ol9jP[oooooooooo`02ooooo`05o`WZ2_l0003oooooooooool9jPX00oooool00ol9jP[ooooo
ooooo`02ooooo`05o`WZ2_moOgooOgmoogmoOol9jPX01?l000001Ol9jP[o0000o`000?l0003o2NX:
00;o000000OoOgmoo`WZ2_moOgooOgmoo`000?oooooo2NX:00Cooooo00Go2NX:oooooooooooooooo
o`WZ2P03ooooo`03o`WZ2_oooooo2NX:00So2NX:Doooool00ol0003oooooooooo`0;ooooo`003_oo
ool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooool0003oooooo`WZ2P03ooooo`05
o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Go2NX:
ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooo
oooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooooooo
ooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooooooooooooooo
o`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`05
o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[o0000oooooooooooo2NX:00?ooooo00?o2NX:
ooooooooool00_ooool01_l9jP[oOgmoogmoOomoOgoo2NX:o`0000?oOgmo00Wo2NX:ogmoOomoOgoo
Ogmoo`WZ2_moOgoo0000ogmoOol9jPX00_moOgl00ol0003oooooo`WZ2P04ooooo`05o`WZ2_oooooo
ooooooooool9jPX00oooool00ol9jP[oooooooooo`02ooooo`06o`WZ2_ooooooooooooooool9jP[o
oooo1_l9jPY=ooooo`03o`000?oooooooooo00_ooooo000>ooooo`05o`WZ2_ooooooooooooooool9
jPX01?ooool01Ol9jP[oooooo`000?oooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04
ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo
00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9
jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oo
ooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00?o2NX:oooooooo
ool00_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04
ooooo`05o`WZ2_l0003oooooooooool9jPX00oooool00ol9jP[oooooooooo`02ooooo`06o`WZ2_mo
OgooOgmoogmoOol9jP[o00000_moOgl00ol9jP[oOgmoogmoO`02ogmoO`05o`WZ2_moOgoo0000ogmo
Ool9jPX00_moOgl00ol0003oooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooo
ooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ
2P03ooooo`So2NX:AOooool00ol0003oooooooooo`0;ooooo`003_ooool01Ol9jP[ooooooooooooo
oooo2NX:00Cooooo00Go2NX:ooooool0003oooooo`WZ2P03ooooo`05o`WZ2_ooooooooooooooool9
jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04
ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo
00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9
jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oo
oooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`05o`WZ2_ooooooooooooooool9
jPX01?ooool01Ol9jP[o0000oooooooooooo2NX:00?ooooo00?o2NX:ooooooooool00_ooool01_l9
jP[oOgmoogmoOomoOgoo2NX:o`0000;oOgmo00?o2NX:ogmoOomoOgl00_moOgl01Ol9jP[oOgmoo`00
0?moOgoo2NX:00;oOgmo00?o0000ooooool9jPX00oooool00ol9jP[oooooooooo`02ooooo`05o`WZ
2_ooooooooooooooool9jPX00oooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_oooooooooooooo
ool9jPX00oooool00ol9jP[oooooooooo`02ooooo`03o`WZ2_oooooooooo00Wo2NX:??ooool00ol0
003oooooooooo`0;ooooo`003_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooo
ool0003oooooo`WZ2P03ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooo
oooooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooooooooooo
ool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ
2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Co
oooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooo
ooooooooooooo`WZ2P03ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[o0000oooo
oooooooo2NX:00?ooooo00Ko2NX:ooooooooooooooooo`000?l9jPX3ogmoO`05o`WZ2_l0003oOgmo
ogmoOol9jPX01?moOgl01Ol9jP[oOgmoo`000?moOgoo2NX:00?oOgmo00?o0000o`WZ2_ooool00_oo
ool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03
o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo
00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`Wo2NX:<oooool00ol0003oooooooooo`0;
ooooo`003_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooool0003oooooo`WZ
2P03ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00?o
oooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool0
1Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ
2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooo
ooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ
2P03ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[o0000oooooooooooo2NX:00?o
oooo00Ko2NX:ooooooooooooooooo`000?l9jPX3ogmoO`05o`WZ2_l0003oOgmoogmoOol9jPX01?mo
Ogl01Ol9jP[oOgmoo`000?moOgoo2NX:00?oOgmo00?o0000o`WZ2_ooool00_ooool01Ol9jP[ooooo
oooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo
00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:
ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Co2NX:oooooooooooooooo
2?l9jPX[ooooo`03o`000?oooooooooo00_ooooo000>ooooo`05o`WZ2_ooooooooooooooool9jPX0
1?ooool01Ol9jP[oooooo`000?oooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04oooo
o`05o`WZ2_ooooooooooooooool9jPX00oooool01Ol9jP[ooooooooooooooooo2NX:00;o00000_oo
ool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05
o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00;ooooo0_l00000
1Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ
2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`05o`WZ2_oooooooooooooo
ool9jPX01?ooool01Ol9jP[o0000oooooooooooo2NX:00;o000000?oooooo`WZ2_ooool00_ooool0
0ol0003o2NX:ogmoO`02ogmoO`05o`WZ2_l0003oOgmoogmoOol9jPX01?moOgl01Ol9jP[o0000o`00
0?moOgoo2NX:00?oOgmo00?o0000o`WZ2_ooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00Co
oooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooo
ooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ
2P03ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool01Ol9jP[ooooooooooooooooo2NX:00?o
oooo2Ol9jPXJooooo`?o00001_l9jPX=ooooo`003_ooool01Ol9jP[ooooooooooooooooo2NX:00Co
oooo00Go2NX:ooooool0003oooooo`WZ2P03ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool0
1Ol9jP[ooooooooooooooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04o`000005o`WZ
2_l0003oooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooo
ooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool00ol0003o2NX:o`00
0002o`000003o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ
2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`05o`WZ2_oooooooooooooo
ool9jPX01?ooool01Ol9jP[o0000oooooooooooo2NX:00?o000000Ko2NX:o`000?l0003oooooo`00
0?l9jPX3ogmoO`05o`WZ2_l0003oOgmoogmoOol9jPX01?moOgl01Ol9jP[o0000o`000?l0003o2NX:
00;o000000?oOgmoo`000?l9jPX00oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:
ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooooooooooooooo
o`WZ2P03ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:
00?ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00?o2NX:
ooooooooool00_ooool01?l9jP[oooooooooooooool9o`WZ2P[ooooo2?l9jPX3o`000005o`WZ2_l0
003o0000ooooool000003Oooool000[ooooo1Ol9jPX3o`000003o`WZ2_l0003o000000;o000000Go
2NX:o`000?l0003o0000o`WZ2P03o`000005o`WZ2_l0003o0000o`000?l9jPX01?l000001Ol9jP[o
0000o`000?l0003o2NX:00?o000000Go2NX:o`000?l0003o0000o`WZ2P04o`000005o`WZ2_l0003o
0000o`000?l9jPX01?l000001Ol9jP[o0000o`000?l0003o2NX:00Co000000Go2NX:o`000?l0003o
0000o`WZ2P04o`000005o`WZ2_l0003o0000o`000?l9jPX01?l000001Ol9jP[o0000o`000?l0003o
2NX:00Co000000Go2NX:o`000?l0003o0000o`WZ2P03o`000003o`WZ2_l0003o000000;o000000Go
2NX:o`000?l0003o0000o`WZ2P03o`000005o`WZ2_l0003o0000o`000?l9jPX01?l000001Ol9jP[o
0000o`000?l0003o2NX:00?o000000?o2NX:o`000?l000000_l000001Ol9jP[o0000o`000?l0003o
2NX:00?o000000?o2NX:o`000?l000000_l000001Ol9jP[o0000o`000?l0003o2NX:00Co000000Go
2NX:o`000?l0003o0000o`WZ2P03o`000003o`WZ2_l0003o000000;o000000Go2NX:o`000?l0003o
0000o`WZ2P03o`000003o`WZ2_l0003o000000;o000000Go2NX:o`000?l0003o0000o`WZ2P03o`00
0005o`WZ2_l0003o0000o`000?l9jPX01?l000001Ol9jP[o0000o`000?l0003o2NX:00?o000000?o
2NX:o`000?l000000_l000001Ol9jP[o0000o`000?l0003o2NX:00?o000000?o2NX:o`000?l00000
0_l000001Ol9jP[o0000o`000?l0003o2NX:00?o000000?o2NX:o`000?l000000_l000001Ol9jP[o
0000o`000?l0003o2NX:00?o000000Go2NX:o`000?l0003o0000o`WZ2P04o`000005o`WZ2_l0003o
0000o`000?l9jPX01?l00002o`WZ2P_ooooo000>ooooo`05o`WZ2_ooooooooooooooool9jPX01?oo
ool01Ol9jP[oooooo`000?oooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05
o`WZ2_ooooooooooooooool9jPX00oooool01Ol9jP[ooooooooooooooooo2NX:00Co000000Go2NX:
ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooo
oooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`000?l9jP[o0000
00;o000000?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00?o2NX:
ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Go2NX:oooooooooooooooo
o`WZ2P04ooooo`05o`WZ2_l0003oooooooooool9jPX00ol000001_l9jP[o0000oooooooooooo0000
o`WZ2P?oOgmo00Go2NX:o`000?moOgooOgmoo`WZ2P04ogmoO`06o`WZ2_l0003o0000o`000?l9jP[o
00000_moOgl00ol0003o2NX:ooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9
jP[ooooooooooooooooo2NX:00?ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooo
oooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9
jPX00oooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool00ol9
jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX00ooooolCo`WZ2P?ooooo00Ko2NX:
o`000?l0003o0000o`WZ2_l00002ooooo`03o`000?oooooooooo00_ooooo000>ooooo`05o`WZ2_oo
ooooooooooooool9jPX01?ooool01Ol9jP[oooooo`000?oooooo2NX:00?ooooo00Go2NX:oooooooo
ooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool01_l9jP[ooooooooooooo
oooo2NX:o`0000?ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooooooooooo
ool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ
2P02ooooo`;o000000Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9
jPX00oooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool01Ol9
jP[ooooooooooooooooo2NX:00Cooooo00Ko2NX:o`000?ooooooooooo`WZ2_l00002ooooo`06o`WZ
2_ooooooooooooooool0003o2NX:0omoOgl01Ol9jP[o0000ogmoOomoOgoo2NX:00CoOgmo00Go2NX:
o`000?l0003oOgmoo`WZ2P03ogmoO`03o`000?l9jP[ooooo00;ooooo00Go2NX:oooooooooooooooo
o`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool00ol9jP[oooooooooo`02ooooo`05
o`WZ2_ooooooooooooooool9jPX00oooool01?l9jP[oooooooooooooool2o`WZ2P?ooooo00Go2NX:
ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooooooooooooooo
o`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo2Ol9jPXBooooo`Co2NX:00?o0000o`WZ2_l9jPX0
0_l9jPX2ooooo`03o`000?oooooooooo00_ooooo000>ooooo`05o`WZ2_ooooooooooooooool9jPX0
1?ooool01Ol9jP[oooooo`000?oooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04oooo
o`05o`WZ2_ooooooooooooooool9jPX00oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go
2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[o
oooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooo
ooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00?o2NX:ooooooooool0
0_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04oooo
o`05o`WZ2_l0003oooooooooool9jPX00oooool01_l9jP[ooooooooooooooooo0000o`WZ2P?oOgmo
00Go2NX:o`000?moOgooOgmoo`WZ2P04ogmoO`05o`WZ2_moOgoo0000ogmoOol9jPX00omoOgl00ol0
003o2NX:ooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooo
oooo2NX:00?ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo
00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Co2NX:oooooooo
oooooooo0_l9jPX3ooooo`04o`WZ2_ooooooooooooooo`Wo2NX:9?ooool3o`WZ2Pgooooo000>oooo
o`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[oooooo`000?oooooo2NX:00?ooooo00Go
2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool01Ol9jP[o
oooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooo
ooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooooooooooo
ooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo
2NX:00?ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Go
2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_l0003oooooooooool9jPX00oooool01_l9jP[o
oooooooooooooooo0000o`WZ2P?oOgmo00Go2NX:o`000?moOgooOgmoo`WZ2P04ogmoO`05o`WZ2_mo
Ogoo0000ogmoOol9jPX00omoOgl00ol0003o2NX:ooooo`02ooooo`05o`WZ2_ooooooooooooooool9
jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00?o2NX:ooooooooool00_ooool01Ol9
jP[ooooooooooooooooo2NX:00?ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooo
oooo2NX:00?ooooo00?o2NX:ooooooooool00_ooool8o`WZ2Roooooo00?o0000ooooooooool02ooo
ool000kooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooo0000ooooool9jPX0
0oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P03oooo
o`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go
2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[o
oooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooo
ooooooooool9jPX00oooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_ooooooooooooooool9jPX0
0oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:o`000?ooooooooooo`WZ2P03oooo
o`06o`WZ2_ooooooooooooooool0003o2NX:0omoOgl01Ol9jP[o0000ogmoOomoOgoo2NX:00CoOgmo
00Go2NX:ogmoOol0003oOgmoo`WZ2P03ogmoO`03o`000?l9jP[ooooo00;ooooo00Co2NX:oooooooo
oooooooo0_l9jPX3ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool00ol9jP[oooooooooo`02
ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool2o`WZ2P?ooooo00Co2NX:oooooooooooooooo
2Ol9jPXgooooo`03o`000?oooooooooo00_ooooo000>ooooo`05o`WZ2_ooooooooooooooool9jPX0
1?ooool01Ol9jP[oooooo`000?oooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04oooo
o`05o`WZ2_ooooooooooooooool9jPX00oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go
2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[o
oooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooo
ooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00?o2NX:ooooooooool0
0_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04oooo
o`05o`WZ2_l0003oooooooooool9jPX00oooool00ol9jP[oooooooooo`02ooooo`06o`WZ2_moOgoo
OgmoogmoOol9jP[o00000_moOgl00ol9jP[oOgmoogmoO`02ogmoO`05o`WZ2_moOgoo0000ogmoOol9
jPX00_moOgl00ol0003oooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:oooooooo
ooooooooo`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03
ooooo`03o`WZ2_oooooooooo00;ooooo2?l9jPY0ooooo`03o`000?oooooooooo00_ooooo000>oooo
o`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[oooooo`000?oooooo2NX:00?ooooo00Go
2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool01Ol9jP[o
oooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooo
ooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooooooooooo
ooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo
2NX:00?ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Go
2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_l0003oooooooooool9jPX00oooool00ol9jP[o
ooooooooo`02ooooo`06o`WZ2_moOgooOgmoogmoOol9jP[o00000_moOgl00ol9jP[oOgmoogmoO`02
ogmoO`05o`WZ2_moOgoo0000ogmoOol9jPX00_moOgl00ol0003oooooo`WZ2P03ooooo`03o`WZ2_oo
oooooooo00;ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`;o2NX:0oooool01Ol9jP[ooooo
oooooooooooo2NX:00;ooooo1_l9jPY8ooooo`03o`000?oooooooooo00_ooooo000>ooooo`05o`WZ
2_ooooooooooooooool9jPX01?ooool01Ol9jP[oooooo`000?oooooo2NX:00?ooooo00Go2NX:oooo
ooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX00oooool01Ol9jP[ooooooooo
oooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooooooooooo
ool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ
2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00?o
oooo00?o2NX:ooooooooool00_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Go2NX:oooo
ooooooooooooo`WZ2P04ooooo`05o`WZ2_l0003oooooooooool9jPX00oooool00ol9jP[ooooooooo
o`02ooooo`06o`WZ2_moOgooOgmoogmoOol9jP[o00000omoOgl02Ol9jP[oOgmoogmoOomoOgoo2NX:
ogmoOol0003oOgmoo`WZ2P02ogmoO`03o`000?oooooo2NX:00Cooooo00Go2NX:oooooooooooooooo
o`WZ2P03ooooo`03o`WZ2_oooooooooo00;ooooo00?o2NX:ooooool9jPX02?l9jPY>ooooo`03o`00
0?oooooooooo00_ooooo000>ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooo
o`000?oooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_oooooooooo
ooooool9jPX00oooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooooooooooooooo
o`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:
00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?oo
ool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05
o`WZ2_ooooooooooooooool9jPX00oooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_l0003ooooo
ooooool9jPX00oooool00ol9jP[oooooooooo`02ooooo`05o`WZ2_moOgooOgmoogmoOol9jPX01?l0
00001Ol9jP[o0000o`000?l0003o2NX:00;o000000OoOgmoo`WZ2_moOgooOgmoo`000?oooooo2NX:
00Cooooo00Go2NX:ooooooooooooooooo`WZ2P02ooooo`So2NX:Eoooool00ol0003oooooooooo`0;
ooooo`003_ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooool0003oooooo`WZ
2P03ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00?o
oooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool0
1Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:ooooooooooooooooo`WZ2P04ooooo`05o`WZ
2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooooooooooo2NX:00Cooooo00Go2NX:oooo
ooooooooooooo`WZ2P03ooooo`05o`WZ2_ooooooooooooooool9jPX01?ooool01Ol9jP[ooooooooo
oooooooo2NX:00?ooooo00?o2NX:ooooooooool00_ooool01Ol9jP[o0000oooooooooooo2NX:00?o
oooo00?o2NX:ooooooooool00_ooool01_l9jP[oOgmoogmoOomoOgoo2NX:o`0000?oOgmo00Wo2NX:
ogmoOomoOgooOgmoo`WZ2_moOgoo0000ogmoOol9jPX00_moOgl01Ol0003oooooooooool9jP[ooooo
00Wo2NX:Goooool00ol0003oooooooooo`0;ooooo`003_oooom3o`WZ2R7ooooo00?o2NX:oooooooo
ool00_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00?o2NX:ooooooooool00_ooool01Ol9
jP[o0000oooooooooooo2NX:00?ooooo00?o2NX:ooooooooool00_ooool00ol9jP[oOgmoogmoO`02
ogmoO`03o`000?moOgoo2NX:017o2NX:J?ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooo2NX:04Ko2NX:2?moOgl00ol0003oOgmoogmoO`02ogmo
O`03o`000?oooooooooo06[ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo00?o0000ogmoOomo
Ogl00_moOgl00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool02Oooool00ol0003oOgmoogmoO`02ogmoO`03o`00
0?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0:ooooo`05o`000?moOgooOgmoogmoOol000002OmoOgl01Ol0003oOgmo
ogmoOomoOgoo000006gooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00[ooooo00Go0000ogmoOomoOgoo
Ogmoo`000009ogmoO`05o`000?moOgooOgmoogmoOol00000KOooool00ol0003oooooooooo`0;oooo
o`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool02_ooool01?l0003oOgmoogmoOomoOgl;o`0000?oOgmo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool02_ooool01Ol0003oOgmoogmoOomoOgoo000000WoOgmo00Go0000ogmo
OomoOgooOgmoo`00001]ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0:ooooo`05o`000?moOgooOgmo
ogmoOol000002OmoOgl01Ol0003oOgmoogmoOomoOgoo000006gooooo00?o0000ooooooooool02ooo
ool001Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00_ooooo00Co0000ogmoOomoOgoo00002OmoOgl01?l0003oOgmoogmoOol0001^ooooo`03o`00
0?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0;ooooo`04o`000?moOgooOgmoo`0000WoOgmo00Co0000ogmoOomoOgoo
0000K_ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool02oooool01?l0003oOgmoogmoOol00009ogmoO`04
o`000?moOgooOgmoo`0006kooooo00?o0000ooooooooool02oooool001Wooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00_ooooo00?o0000ogmoOomo
Ogl02ol00002ogmoO`03o`000?oooooooooo06cooooo00?o0000ooooooooool02oooool001Wooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00_ooooo
00Co0000ogmoOomoOgoo00002OmoOgl01?l0003oOgmoogmoOol0001^ooooo`03o`000?oooooooooo
00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0<ooooo`03o`000?moOgoo000000WoOgmo00?o0000ogmoOol00000Koooool00ol0003o
ooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03?ooool00ol0003oOgmoo`000009ogmoO`03o`000?moOgoo000006oooooo
00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00cooooo00?o0000ogmoOol000002OmoOgl00ol0003oOgmoo`00
001_ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0=ooooo`;o00002OmoOgl2o`00073ooooo00?o0000
ooooooooool02oooool001Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00gooooo3Ol0001`ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0=ooooo`;o
00002OmoOgl2o`00073ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00gooooo0_l00009ogmoO`;o0000
L?ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool03_ooool;o`00077ooooo00?o0000ooooooooool02ooo
ool001Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00kooooo2ol0001aooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`2:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00_ooooo
000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`2:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00_ooooo000Ioooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:oooo
o`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`03o`00
0?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooo
oooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`2:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00_o
oooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`2:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00_ooooo000I
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:
ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`03o`000?oo
oooooooo00_ooooo000Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2:ooooo`;o00003?ooool001Wo
ooooKOl0002<ooooo`03o`000?oooooooooo00_ooooo003oooooob7ooooo003oooooob7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {124.75, 0}} -> {-6.73288, -31.1672, 0.461048, \
0.461048}},
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[prismgaussiansystem, ShowGaussian->True];", "Input",
  CellLabel->"In[91]:=",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74268 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0144285 1.01443 -0.112145 1.01443 [
[ 0 0 0 0 ]
[ 1 .74268 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .74268 L
0 .74268 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.3987 .3965 m
.39249 .67048 L
s
.39947 .19108 m
.3987 .3965 L
s
.39877 .39648 m
.39256 .67046 L
s
.11045 .29347 m
.39877 .39648 L
s
.39875 .39657 m
.39952 .19115 L
s
.11043 .29356 m
.39875 .39657 L
s
.039 .916 .04 r
1 Mabswid
.15354 .52448 m
.16251 .52375 L
s
.16251 .52375 m
.17148 .52303 L
s
.17148 .52303 m
.18046 .5223 L
s
.15219 .52158 m
.15264 .52267 L
s
.18046 .5223 m
.18944 .52157 L
s
.15174 .52049 m
.15219 .52158 L
s
.16565 .52048 m
.1661 .52158 L
s
.18944 .52157 m
.19843 .52085 L
s
.19843 .52085 m
.20743 .52012 L
s
.15128 .51939 m
.15174 .52049 L
s
.17913 .51939 m
.17957 .52049 L
s
.16521 .51939 m
.16565 .52048 L
s
.20743 .52012 m
.21643 .51939 L
s
.14793 .47886 m
.15691 .47805 L
s
.15082 .5183 m
.15128 .51939 L
s
.21643 .51939 m
.22544 .51866 L
s
.19263 .51829 m
.19306 .51939 L
s
.16476 .51829 m
.16521 .51939 L
s
.17869 .51829 m
.17913 .51939 L
s
.15691 .47805 m
.16589 .47725 L
s
.22544 .51866 m
.23445 .51794 L
s
.14759 .48159 m
.14747 .48322 L
s
.15037 .5172 m
.15082 .5183 L
s
.16589 .47725 m
.17488 .47644 L
s
.20614 .51719 m
.20656 .51829 L
s
.16431 .51719 m
.16476 .51829 L
s
.19219 .51719 m
.19263 .51829 L
s
.17825 .51719 m
.17869 .51829 L
s
.23445 .51794 m
.24347 .51721 L
s
.14747 .48322 m
.14735 .48485 L
s
.17488 .47644 m
.18387 .47563 L
s
.16106 .48038 m
.16095 .48202 L
s
.24347 .51721 m
.2525 .51648 L
s
.14991 .51611 m
.15037 .5172 L
s
.21966 .51609 m
.22008 .5172 L
s
.16386 .51609 m
.16431 .51719 L
s
.20571 .51608 m
.20614 .51719 L
s
.17781 .51609 m
.17825 .51719 L
s
.19176 .51608 m
.19219 .51719 L
s
.18387 .47563 m
.19288 .47482 L
s
.14735 .48485 m
.14723 .48648 L
s
.16095 .48202 m
.16084 .48365 L
s
.2525 .51648 m
.26154 .51575 L
s
.17455 .47918 m
.17444 .48082 L
s
.14945 .51501 m
.14991 .51611 L
s
.23319 .51499 m
.23361 .5161 L
s
.1634 .51499 m
.16386 .51609 L
s
.19288 .47482 m
.20188 .47401 L
s
.21923 .51498 m
.21966 .51609 L
s
.17736 .51498 m
.17781 .51609 L
s
.20528 .51497 m
.20571 .51608 L
s
.19132 .51498 m
.19176 .51608 L
s
.14723 .48648 m
.14711 .48812 L
s
.26154 .51575 m
.27058 .51502 L
s
.16084 .48365 m
.16072 .48529 L
s
.17444 .48082 m
.17433 .48246 L
s
.20188 .47401 m
.2109 .47321 L
s
.14711 .48812 m
.14699 .48975 L
s
.18805 .47797 m
.18795 .47962 L
s
.27058 .51502 m
.27962 .51428 L
s
.14898 .51391 m
.14945 .51501 L
s
.24674 .51388 m
.24715 .515 L
s
.16295 .51389 m
.1634 .51499 L
s
.23278 .51387 m
.23319 .51499 L
s
.17691 .51388 m
.17736 .51498 L
s
.21881 .51387 m
.21923 .51498 L
s
.19088 .51387 m
.19132 .51498 L
s
.20484 .51387 m
.20528 .51497 L
s
.16072 .48529 m
.16061 .48693 L
s
.2109 .47321 m
.21992 .4724 L
s
.17433 .48246 m
.17422 .4841 L
s
.14699 .48975 m
.14687 .49139 L
s
.27962 .51428 m
.28868 .51355 L
s
.18795 .47962 m
.18785 .48126 L
s
.32247 .5141 m
.33042 .51168 L
s
.29774 .51282 m
.32247 .5141 L
s
.16061 .48693 m
.16049 .48857 L
s
.20157 .47677 m
.20147 .47841 L
s
.14852 .51281 m
.14898 .51391 L
s
.26031 .51278 m
.26071 .5139 L
s
.16249 .51279 m
.16295 .51389 L
s
.24633 .51277 m
.24674 .51388 L
s
.17646 .51277 m
.17691 .51388 L
s
.21992 .4724 m
.22894 .47158 L
s
.23236 .51276 m
.23278 .51387 L
s
.19044 .51276 m
.19088 .51387 L
s
.21838 .51275 m
.21881 .51387 L
s
.20441 .51276 m
.20484 .51387 L
s
.17422 .4841 m
.17411 .48574 L
s
.28868 .51355 m
.29774 .51282 L
s
.14687 .49139 m
.14674 .49303 L
s
.18785 .48126 m
.18774 .4829 L
s
.16049 .48857 m
.16037 .49021 L
s
.20147 .47841 m
.20137 .48006 L
s
.22894 .47158 m
.23798 .47077 L
s
.31473 .51174 m
.31613 .51309 L
s
.17411 .48574 m
.174 .48738 L
s
.2151 .47556 m
.21501 .47721 L
s
.14806 .51171 m
.14852 .51281 L
s
.27389 .51167 m
.27429 .51279 L
s
.16203 .51169 m
.16249 .51279 L
s
.2599 .51166 m
.26031 .51278 L
s
.17601 .51167 m
.17646 .51277 L
s
.24592 .51165 m
.24633 .51277 L
s
.18999 .51165 m
.19044 .51276 L
s
.23194 .51164 m
.23236 .51276 L
s
.20397 .51165 m
.20441 .51276 L
s
.21796 .51164 m
.21838 .51275 L
s
.14674 .49303 m
.14662 .49467 L
s
.18774 .4829 m
.18764 .48455 L
s
.16037 .49021 m
.16025 .49185 L
s
.23798 .47077 m
.24701 .46996 L
s
.20137 .48006 m
.20127 .48171 L
s
.174 .48738 m
.17389 .48903 L
s
.21501 .47721 m
.21491 .47886 L
s
.14662 .49467 m
.14649 .49631 L
s
.18764 .48455 m
.18753 .4862 L
s
.22865 .47435 m
.22856 .476 L
s
.31333 .51039 m
.31473 .51174 L
s
.14759 .51061 m
.14806 .51171 L
s
.28748 .51057 m
.28787 .51169 L
s
.16157 .51058 m
.16203 .51169 L
s
.33042 .51168 m
.33839 .50925 L
s
.27349 .51055 m
.27389 .51167 L
s
.17556 .51056 m
.17601 .51167 L
s
.24701 .46996 m
.25606 .46915 L
s
.2595 .51054 m
.2599 .51166 L
s
.18955 .51055 m
.18999 .51165 L
s
.24551 .51053 m
.24592 .51165 L
s
.20354 .51053 m
.20397 .51165 L
s
.23152 .51053 m
.23194 .51164 L
s
.21753 .51053 m
.21796 .51164 L
s
.16025 .49185 m
.16013 .4935 L
s
.20127 .48171 m
.20117 .48336 L
s
.17389 .48903 m
.17377 .49068 L
s
.21491 .47886 m
.21482 .48051 L
s
.14649 .49631 m
.14636 .49795 L
s
.18753 .4862 m
.18742 .48785 L
s
.22856 .476 m
.22847 .47766 L
s
.25606 .46915 m
.26511 .46834 L
s
.16013 .4935 m
.16001 .49514 L
s
.20117 .48336 m
.20107 .48501 L
s
.2422 .47314 m
.24212 .4748 L
s
.14712 .5095 m
.14759 .51061 L
s
.16111 .50948 m
.16157 .51058 L
s
.28709 .50944 m
.28748 .51057 L
s
.17511 .50945 m
.17556 .51056 L
s
.27309 .50942 m
.27349 .51055 L
s
.1891 .50944 m
.18955 .51055 L
s
.25909 .50941 m
.2595 .51054 L
s
.2031 .50942 m
.20354 .51053 L
s
.24509 .50941 m
.24551 .51053 L
s
.21709 .50941 m
.21753 .51053 L
s
.23109 .50941 m
.23152 .51053 L
s
.17377 .49068 m
.17366 .49232 L
s
.21482 .48051 m
.21472 .48217 L
s
.31193 .50903 m
.31333 .51039 L
s
.14636 .49795 m
.14623 .4996 L
s
.18742 .48785 m
.18731 .4895 L
s
.26511 .46834 m
.27417 .46752 L
s
.22847 .47766 m
.22838 .47932 L
s
.16001 .49514 m
.15988 .49679 L
s
.20107 .48501 m
.20097 .48666 L
s
.24212 .4748 m
.24204 .47646 L
s
.17366 .49232 m
.17354 .49397 L
s
.21472 .48217 m
.21463 .48382 L
s
.25578 .47193 m
.2557 .47359 L
s
.14665 .5084 m
.14712 .5095 L
s
.16065 .50837 m
.16111 .50948 L
s
.14623 .4996 m
.1461 .50124 L
s
.17465 .50834 m
.17511 .50945 L
s
.32666 .50809 m
.32805 .50944 L
s
.28669 .50831 m
.28709 .50944 L
s
.27417 .46752 m
.28323 .46671 L
s
.18865 .50832 m
.1891 .50944 L
s
.27269 .5083 m
.27309 .50942 L
s
.20266 .50831 m
.2031 .50942 L
s
.25868 .50829 m
.25909 .50941 L
s
.21666 .5083 m
.21709 .50941 L
s
.24467 .50829 m
.24509 .50941 L
s
.23067 .50829 m
.23109 .50941 L
s
.18731 .4895 m
.1872 .49115 L
s
.22838 .47932 m
.22829 .48097 L
s
.33839 .50925 m
.34638 .50681 L
s
.15988 .49679 m
.15976 .49844 L
s
.20097 .48666 m
.20086 .48832 L
s
.31053 .50768 m
.31193 .50903 L
s
.24204 .47646 m
.24195 .47812 L
s
.17354 .49397 m
.17342 .49562 L
s
.21463 .48382 m
.21453 .48548 L
s
.2557 .47359 m
.25562 .47525 L
s
.28323 .46671 m
.2923 .4659 L
s
.1461 .50124 m
.14597 .50289 L
s
.1872 .49115 m
.18709 .4928 L
s
.22829 .48097 m
.2282 .48263 L
s
.26937 .47072 m
.26929 .47238 L
s
.14618 .50729 m
.14665 .5084 L
s
.16019 .50726 m
.16065 .50837 L
s
.17419 .50723 m
.17465 .50834 L
s
.15976 .49844 m
.15964 .50009 L
s
.1882 .50721 m
.18865 .50832 L
s
.2863 .50718 m
.28669 .50831 L
s
.20222 .50719 m
.20266 .50831 L
s
.27228 .50717 m
.27269 .5083 L
s
.21623 .50718 m
.21666 .5083 L
s
.25827 .50717 m
.25868 .50829 L
s
.23024 .50717 m
.23067 .50829 L
s
.24425 .50717 m
.24467 .50829 L
s
.20086 .48832 m
.20076 .48997 L
s
.24195 .47812 m
.24187 .47978 L
s
.32527 .50673 m
.32666 .50809 L
s
.17342 .49562 m
.1733 .49728 L
s
.2923 .4659 m
.30024 .46338 L
s
.21453 .48548 m
.21443 .48714 L
s
.25562 .47525 m
.25554 .47692 L
s
.14597 .50289 m
.14584 .50454 L
s
.18709 .4928 m
.18697 .49446 L
s
.30913 .50632 m
.31053 .50768 L
s
.2282 .48263 m
.2281 .48429 L
s
.26929 .47238 m
.26922 .47405 L
s
.15964 .50009 m
.15951 .50174 L
s
.20076 .48997 m
.20065 .49163 L
s
.24187 .47978 m
.24178 .48144 L
s
.28297 .4695 m
.2829 .47117 L
s
.1457 .50619 m
.14618 .50729 L
s
.15972 .50615 m
.16019 .50726 L
s
.17374 .50612 m
.17419 .50723 L
s
.18775 .5061 m
.1882 .50721 L
s
.1733 .49728 m
.17318 .49893 L
s
.20177 .50608 m
.20222 .50719 L
s
.2859 .50605 m
.2863 .50718 L
s
.21579 .50606 m
.21623 .50718 L
s
.27188 .50604 m
.27228 .50717 L
s
.22981 .50605 m
.23024 .50717 L
s
.25786 .50604 m
.25827 .50717 L
s
.24383 .50604 m
.24425 .50717 L
s
.21443 .48714 m
.21433 .4888 L
s
.25554 .47692 m
.25546 .47858 L
s
.14584 .50454 m
.1457 .50619 L
s
.18697 .49446 m
.18686 .49611 L
s
.34638 .50681 m
.35439 .50437 L
s
.2281 .48429 m
.22801 .48595 L
s
.26922 .47405 m
.26915 .47572 L
s
.32387 .50537 m
.32527 .50673 L
s
.15951 .50174 m
.15938 .50339 L
s
.20065 .49163 m
.20054 .49329 L
s
.24178 .48144 m
.24169 .48311 L
s
.2829 .47117 m
.28283 .47284 L
s
.17318 .49893 m
.17306 .50058 L
s
.30772 .50497 m
.30913 .50632 L
s
.21433 .4888 m
.21423 .49046 L
s
.25546 .47858 m
.25538 .48025 L
s
.1457 .50619 m
.14557 .50784 L
s
0 0 0 r
.1457 .50619 m
.29101 .49391 L
s
.039 .916 .04 r
.14523 .50508 m
.1457 .50619 L
s
.15925 .50504 m
.15972 .50615 L
s
.17328 .50501 m
.17374 .50612 L
s
.1873 .50498 m
.18775 .5061 L
s
.20133 .50496 m
.20177 .50608 L
s
.21535 .50494 m
.21579 .50606 L
s
.18686 .49611 m
.18674 .49777 L
s
.2855 .50492 m
.2859 .50605 L
s
.22938 .50493 m
.22981 .50605 L
s
.27147 .50491 m
.27188 .50604 L
s
.24341 .50492 m
.24383 .50604 L
s
.25744 .50491 m
.25786 .50604 L
s
.22801 .48595 m
.22791 .48762 L
s
.26915 .47572 m
.26907 .47738 L
s
.15938 .50339 m
.15925 .50504 L
s
.33863 .50442 m
.34002 .50578 L
s
.20054 .49329 m
.20043 .49495 L
s
.24169 .48311 m
.2416 .48477 L
s
.28283 .47284 m
.28277 .47451 L
s
.17306 .50058 m
.17294 .50224 L
s
.30024 .46338 m
.30818 .46085 L
s
.21423 .49046 m
.21412 .49212 L
s
.25538 .48025 m
.2553 .48192 L
s
.32247 .50401 m
.32387 .50537 L
s
.14557 .50784 m
.14543 .50949 L
s
.29609 .46744 m
.29602 .46912 L
s
.18674 .49777 m
.18663 .49943 L
s
.22791 .48762 m
.22782 .48928 L
s
.26907 .47738 m
.26899 .47906 L
s
.14475 .50397 m
.14523 .50508 L
s
.15925 .50504 m
.15912 .5067 L
s
.15878 .50393 m
.15925 .50504 L
s
.17281 .5039 m
.17328 .50501 L
s
.18685 .50387 m
.1873 .50498 L
s
.30631 .50361 m
.30772 .50497 L
s
.20088 .50384 m
.20133 .50496 L
s
.21492 .50382 m
.21535 .50494 L
s
.22895 .5038 m
.22938 .50493 L
s
.2851 .50379 m
.2855 .50492 L
s
.20043 .49495 m
.20032 .49661 L
s
.24299 .50379 m
.24341 .50492 L
s
.27106 .50378 m
.27147 .50491 L
s
.25703 .50379 m
.25744 .50491 L
s
.2416 .48477 m
.24151 .48644 L
s
.28277 .47451 m
.28269 .47619 L
s
.17294 .50224 m
.17281 .5039 L
s
.21412 .49212 m
.21402 .49378 L
s
.14543 .50949 m
.14529 .51115 L
s
.2553 .48192 m
.25521 .48359 L
s
.29602 .46912 m
.29595 .47079 L
s
.33724 .50306 m
.33863 .50442 L
s
.18663 .49943 m
.18651 .50109 L
s
.35439 .50437 m
.36241 .50192 L
s
.22782 .48928 m
.22772 .49095 L
s
.26899 .47906 m
.26892 .48073 L
s
.15912 .5067 m
.15899 .50836 L
s
.20032 .49661 m
.20021 .49827 L
s
.32107 .50265 m
.32247 .50401 L
s
.24151 .48644 m
.24142 .48811 L
s
.14427 .50286 m
.14475 .50397 L
s
.28269 .47619 m
.28262 .47786 L
s
.15831 .50282 m
.15878 .50393 L
s
.17281 .5039 m
.17269 .50556 L
s
.17235 .50278 m
.17281 .5039 L
s
.18639 .50275 m
.18685 .50387 L
s
.20043 .50272 m
.20088 .50384 L
s
.21447 .5027 m
.21492 .50382 L
s
.22852 .50268 m
.22895 .5038 L
s
.24256 .50267 m
.24299 .50379 L
s
.2847 .50265 m
.2851 .50379 L
s
.25661 .50266 m
.25703 .50379 L
s
.27065 .50265 m
.27106 .50378 L
s
.21402 .49378 m
.21391 .49545 L
s
.14529 .51115 m
.14516 .5128 L
s
.25521 .48359 m
.25513 .48526 L
s
.29595 .47079 m
.29588 .47247 L
s
.3049 .50225 m
.30631 .50361 L
s
.18651 .50109 m
.18639 .50275 L
s
.22772 .49095 m
.22762 .49262 L
s
.26892 .48073 m
.26884 .4824 L
s
.15899 .50836 m
.15886 .51001 L
s
.20021 .49827 m
.2001 .49994 L
s
.24142 .48811 m
.24133 .48978 L
s
.28262 .47786 m
.28255 .47954 L
s
.30818 .46085 m
.31615 .45831 L
s
.17269 .50556 m
.17256 .50722 L
s
.33585 .5017 m
.33724 .50306 L
s
.21391 .49545 m
.21381 .49711 L
s
.14516 .5128 m
.14502 .51446 L
s
.25513 .48526 m
.25504 .48693 L
s
.14379 .50175 m
.14427 .50286 L
s
.29588 .47247 m
.2958 .47414 L
s
.15784 .50171 m
.15831 .50282 L
s
.17189 .50167 m
.17235 .50278 L
s
.18639 .50275 m
.18627 .50441 L
s
.18593 .50163 m
.18639 .50275 L
s
.19998 .5016 m
.20043 .50272 L
s
.21403 .50158 m
.21447 .5027 L
s
.22808 .50155 m
.22852 .50268 L
s
.24214 .50154 m
.24256 .50267 L
s
.25619 .50153 m
.25661 .50266 L
s
.2843 .50152 m
.2847 .50265 L
s
.27024 .50152 m
.27065 .50265 L
s
.31967 .50129 m
.32107 .50265 L
s
.22762 .49262 m
.22752 .49429 L
s
.15886 .51001 m
.15872 .51167 L
s
.26884 .4824 m
.26876 .48408 L
s
.2001 .49994 m
.19998 .5016 L
s
.24133 .48978 m
.24123 .49145 L
s
.28255 .47954 m
.28248 .48121 L
s
.30349 .50089 m
.3049 .50225 L
s
.17256 .50722 m
.17243 .50888 L
s
.21381 .49711 m
.2137 .49878 L
s
.35065 .50075 m
.35203 .50211 L
s
.14502 .51446 m
.14487 .51612 L
s
.25504 .48693 m
.25495 .4886 L
s
.2958 .47414 m
.29573 .47582 L
s
.18627 .50441 m
.18615 .50608 L
s
.36241 .50192 m
.37045 .49947 L
s
.22752 .49429 m
.22742 .49596 L
s
.14331 .50064 m
.14379 .50175 L
s
.15872 .51167 m
.15859 .51333 L
s
.26876 .48408 m
.26868 .48575 L
s
.15737 .50059 m
.15784 .50171 L
s
.33446 .50033 m
.33585 .5017 L
s
.30801 .46366 m
.30795 .46533 L
s
.17142 .50055 m
.17189 .50167 L
s
.18547 .50051 m
.18593 .50163 L
s
.19998 .5016 m
.19987 .50327 L
s
.19953 .50048 m
.19998 .5016 L
s
.21359 .50045 m
.21403 .50158 L
s
.22765 .50043 m
.22808 .50155 L
s
.24171 .50041 m
.24214 .50154 L
s
.25577 .5004 m
.25619 .50153 L
s
.26983 .50039 m
.27024 .50152 L
s
.28389 .50038 m
.2843 .50152 L
s
.24123 .49145 m
.24114 .49312 L
s
.28248 .48121 m
.2824 .48289 L
s
.17243 .50888 m
.17231 .51054 L
s
.31827 .49992 m
.31967 .50129 L
s
.2137 .49878 m
.21359 .50045 L
s
.14487 .51612 m
.14473 .51778 L
s
.25495 .4886 m
.25487 .49028 L
s
.29573 .47582 m
.29566 .4775 L
s
.18615 .50608 m
.18603 .50774 L
s
.22742 .49596 m
.22731 .49763 L
s
.15859 .51333 m
.15845 .51499 L
s
.26868 .48575 m
.26859 .48743 L
s
.30207 .49952 m
.30349 .50089 L
s
.30795 .46533 m
.30788 .46701 L
s
.19987 .50327 m
.19975 .50494 L
s
.34926 .49938 m
.35065 .50075 L
s
.24114 .49312 m
.24104 .4948 L
s
.14283 .49953 m
.14331 .50064 L
s
.31615 .45831 m
.32413 .45577 L
s
.15689 .49948 m
.15737 .50059 L
s
.2824 .48289 m
.28233 .48457 L
s
.17231 .51054 m
.17218 .51221 L
s
.17095 .49943 m
.17142 .50055 L
s
.18501 .49939 m
.18547 .50051 L
s
.19908 .49936 m
.19953 .50048 L
s
.21359 .50045 m
.21348 .50212 L
s
.21314 .49933 m
.21359 .50045 L
s
.14473 .51778 m
.14459 .51944 L
s
.22721 .4993 m
.22765 .50043 L
s
.24128 .49928 m
.24171 .50041 L
s
.25535 .49926 m
.25577 .5004 L
s
.26942 .49925 m
.26983 .50039 L
s
.28349 .49924 m
.28389 .50038 L
s
.25487 .49028 m
.25477 .49196 L
s
.33306 .49896 m
.33446 .50033 L
s
.29566 .4775 m
.29558 .47918 L
s
.18603 .50774 m
.1859 .50941 L
s
.22731 .49763 m
.22721 .4993 L
s
.15845 .51499 m
.15831 .51666 L
s
0 g
.5 Mabswid
.08395 .57391 m
.11046 .29352 L
s
.11046 .29352 m
.39954 .19111 L
s
.039 .916 .04 r
1 Mabswid
.26859 .48743 m
.26851 .48911 L
s
0 g
.5 Mabswid
.08394 .57387 m
.11045 .29347 L
s
.39952 .19115 m
.11043 .29356 L
s
.039 .916 .04 r
1 Mabswid
.30788 .46701 m
.30781 .46869 L
s
.19975 .50494 m
.19963 .50661 L
s
.31686 .49856 m
.31827 .49992 L
s
.24104 .4948 m
.24095 .49647 L
s
.17218 .51221 m
.17204 .51387 L
s
.28233 .48457 m
.28225 .48625 L
s
.21348 .50212 m
.21337 .50379 L
s
.14459 .51944 m
.14444 .5211 L
s
.14235 .49841 m
.14283 .49953 L
s
.30066 .49816 m
.30207 .49952 L
s
.25477 .49196 m
.25468 .49363 L
s
.15641 .49836 m
.15689 .49948 L
s
.37045 .49947 m
.37852 .49701 L
s
.29558 .47918 m
.29551 .48086 L
s
.1859 .50941 m
.18578 .51108 L
s
.17048 .49831 m
.17095 .49943 L
s
.18455 .49827 m
.18501 .49939 L
s
.34787 .49801 m
.34926 .49938 L
s
.19862 .49823 m
.19908 .49936 L
s
.2127 .4982 m
.21314 .49933 L
s
.22677 .49817 m
.22721 .4993 L
s
.22721 .4993 m
.22711 .50098 L
s
.24085 .49815 m
.24128 .49928 L
s
.15831 .51666 m
.15818 .51832 L
s
.25492 .49813 m
.25535 .49926 L
s
.269 .49811 m
.26942 .49925 L
s
.28308 .49811 m
.28349 .49924 L
s
.26851 .48911 m
.26843 .49079 L
s
.30781 .46869 m
.30774 .47037 L
s
.19963 .50661 m
.19951 .50828 L
s
.24095 .49647 m
.24085 .49815 L
s
.33167 .49759 m
.33306 .49896 L
s
.17204 .51387 m
.17191 .51554 L
s
.28225 .48625 m
.28217 .48794 L
s
.14444 .5211 m
.1443 .52276 L
s
.21337 .50379 m
.21325 .50547 L
s
.25468 .49363 m
.25459 .49531 L
s
.29551 .48086 m
.29543 .48255 L
s
.18578 .51108 m
.18565 .51275 L
s
.31545 .49719 m
.31686 .49856 L
s
.22711 .50098 m
.227 .50265 L
s
.15818 .51832 m
.15804 .51999 L
s
.3627 .49706 m
.36408 .49843 L
s
.14186 .4973 m
.14235 .49841 L
s
.26843 .49079 m
.26834 .49247 L
s
.15593 .49724 m
.15641 .49836 L
s
.17001 .49719 m
.17048 .49831 L
s
.30774 .47037 m
.30767 .47205 L
s
.19951 .50828 m
.19939 .50995 L
s
.18409 .49715 m
.18455 .49827 L
s
.19817 .49711 m
.19862 .49823 L
s
.21225 .49707 m
.2127 .4982 L
s
.32413 .45577 m
.33214 .45322 L
s
.22633 .49704 m
.22677 .49817 L
s
.29924 .49679 m
.30066 .49816 L
s
.24085 .49815 m
.24075 .49983 L
s
.24041 .49702 m
.24085 .49815 L
s
.2545 .49699 m
.25492 .49813 L
s
.26858 .49698 m
.269 .49811 L
s
.17191 .51554 m
.17178 .51721 L
s
.28267 .49697 m
.28308 .49811 L
s
.28217 .48794 m
.28209 .48962 L
s
.34648 .49664 m
.34787 .49801 L
s
.31998 .45986 m
.31991 .46154 L
s
.1443 .52276 m
.14415 .52443 L
s
.21325 .50547 m
.21314 .50714 L
s
.25459 .49531 m
.2545 .49699 L
s
.18565 .51275 m
.18552 .51442 L
s
.29543 .48255 m
.29535 .48423 L
s
.227 .50265 m
.22689 .50433 L
s
.15804 .51999 m
.15789 .52166 L
s
.33027 .49622 m
.33167 .49759 L
s
.26834 .49247 m
.26825 .49415 L
s
.30767 .47205 m
.3076 .47373 L
s
.19939 .50995 m
.19927 .51162 L
s
.24075 .49983 m
.24064 .50151 L
s
.14137 .49618 m
.14186 .4973 L
s
.17178 .51721 m
.17164 .51888 L
s
.15545 .49613 m
.15593 .49724 L
s
.28209 .48962 m
.28201 .49131 L
s
.16954 .49607 m
.17001 .49719 L
s
.31404 .49582 m
.31545 .49719 L
s
.31991 .46154 m
.31985 .46322 L
s
.18362 .49603 m
.18409 .49715 L
s
.14415 .52443 m
.144 .52609 L
s
.21314 .50714 m
.21303 .50882 L
s
.19771 .49598 m
.19817 .49711 L
s
.2118 .49594 m
.21225 .49707 L
s
.36132 .49568 m
.3627 .49706 L
s
.22589 .49591 m
.22633 .49704 L
s
.23998 .49588 m
.24041 .49702 L
s
.37852 .49701 m
.3866 .49454 L
s
.2545 .49699 m
.2544 .49868 L
s
.25407 .49586 m
.2545 .49699 L
s
.26816 .49584 m
.26858 .49698 L
s
.28226 .49583 m
.28267 .49697 L
s
.18552 .51442 m
.18539 .51609 L
s
.29535 .48423 m
.29528 .48592 L
s
.22689 .50433 m
.22678 .50601 L
s
.15789 .52166 m
.15775 .52332 L
s
.29782 .49542 m
.29924 .49679 L
s
.26825 .49415 m
.26816 .49584 L
s
.34509 .49526 m
.34648 .49664 L
s
.19927 .51162 m
.19915 .5133 L
s
.3076 .47373 m
.30753 .47542 L
s
.24064 .50151 m
.24054 .50319 L
s
.17164 .51888 m
.17151 .52055 L
s
.28201 .49131 m
.28193 .49299 L
s
.144 .52609 m
.14385 .52776 L
s
.31985 .46322 m
.31979 .4649 L
s
.21303 .50882 m
.21291 .5105 L
s
.32886 .49485 m
.33027 .49622 L
s
.14088 .49507 m
.14137 .49618 L
s
.2544 .49868 m
.25431 .50036 L
s
.15497 .49501 m
.15545 .49613 L
s
.18539 .51609 m
.18526 .51777 L
s
.16906 .49495 m
.16954 .49607 L
s
.29528 .48592 m
.2952 .48761 L
s
.18316 .4949 m
.18362 .49603 L
s
.19725 .49486 m
.19771 .49598 L
s
.15775 .52332 m
.15761 .525 L
s
.22678 .50601 m
.22667 .50769 L
s
.21135 .49482 m
.2118 .49594 L
s
.22544 .49478 m
.22589 .49591 L
s
.23954 .49475 m
.23998 .49588 L
s
.25364 .49472 m
.25407 .49586 L
s
.26816 .49584 m
.26807 .49753 L
s
.26774 .4947 m
.26816 .49584 L
s
.28184 .49468 m
.28226 .49583 L
s
.31263 .49445 m
.31404 .49582 L
s
.19915 .5133 m
.19903 .51497 L
s
.30753 .47542 m
.30746 .4771 L
s
.33214 .45322 m
.34016 .45067 L
s
.35994 .49431 m
.36132 .49568 L
s
.24054 .50319 m
.24044 .50487 L
s
.17151 .52055 m
.17137 .52222 L
s
.28193 .49299 m
.28184 .49468 L
s
.14385 .52776 m
.1437 .52943 L
s
.31979 .4649 m
.31972 .46658 L
s
.21291 .5105 m
.21279 .51218 L
s
.29639 .49405 m
.29782 .49542 L
s
.25431 .50036 m
.25421 .50205 L
s
.18526 .51777 m
.18513 .51944 L
s
.3437 .49389 m
.34509 .49526 L
s
.2952 .48761 m
.29512 .4893 L
s
.15761 .525 m
.15746 .52667 L
s
.22667 .50769 m
.22656 .50937 L
s
.14039 .49395 m
.14088 .49507 L
s
.15449 .49389 m
.15497 .49501 L
s
.26807 .49753 m
.26798 .49921 L
s
.16859 .49383 m
.16906 .49495 L
s
.19903 .51497 m
.1989 .51665 L
s
.30746 .4771 m
.30739 .47879 L
s
.18269 .49378 m
.18316 .4949 L
s
.19679 .49373 m
.19725 .49486 L
s
.32746 .49348 m
.32886 .49485 L
s
.21089 .49368 m
.21135 .49482 L
s
.24044 .50487 m
.24033 .50655 L
s
.17137 .52222 m
.17123 .5239 L
s
.225 .49365 m
.22544 .49478 L
s
.2391 .49361 m
.23954 .49475 L
s
.3748 .49335 m
.37617 .49473 L
s
.25321 .49358 m
.25364 .49472 L
s
.26732 .49356 m
.26774 .4947 L
s
.28184 .49468 m
.28176 .49637 L
s
.28143 .49354 m
.28184 .49468 L
s
.1437 .52943 m
.14355 .5311 L
s
.21279 .51218 m
.21267 .51386 L
s
.31972 .46658 m
.31966 .46827 L
s
.3866 .49454 m
.3947 .49207 L
s
.25421 .50205 m
.25411 .50373 L
s
.31121 .49308 m
.31263 .49445 L
s
.18513 .51944 m
.185 .52112 L
s
.29512 .4893 m
.29504 .49099 L
s
.33198 .45604 m
.33192 .45773 L
s
.35855 .49293 m
.35994 .49431 L
s
.15746 .52667 m
.15732 .52834 L
s
.22656 .50937 m
.22645 .51105 L
s
.26798 .49921 m
.26789 .5009 L
s
.1989 .51665 m
.19877 .51833 L
s
.30739 .47879 m
.30732 .48048 L
s
.29496 .49268 m
.29639 .49405 L
s
.17123 .5239 m
.17109 .52557 L
s
.24033 .50655 m
.24023 .50824 L
s
.1399 .49283 m
.14039 .49395 L
s
0 0 0 r
.29101 .49391 m
.39586 .46127 L
s
.039 .916 .04 r
.3423 .49251 m
.3437 .49389 L
s
.154 .49276 m
.15449 .49389 L
s
.28176 .49637 m
.28167 .49807 L
s
.16811 .4927 m
.16859 .49383 L
s
.18222 .49265 m
.18269 .49378 L
s
.21267 .51386 m
.21255 .51554 L
s
.31966 .46827 m
.31959 .46996 L
s
.19633 .4926 m
.19679 .49373 L
s
.21044 .49255 m
.21089 .49368 L
s
.22455 .49251 m
.225 .49365 L
s
.25411 .50373 m
.25401 .50542 L
s
.23867 .49248 m
.2391 .49361 L
s
.185 .52112 m
.18487 .5228 L
s
.25278 .49245 m
.25321 .49358 L
s
.2669 .49242 m
.26732 .49356 L
s
.28101 .4924 m
.28143 .49354 L
s
.29504 .49099 m
.29496 .49268 L
s
.32605 .4921 m
.32746 .49348 L
s
.15732 .52834 m
.15717 .53001 L
s
.33192 .45773 m
.33186 .45941 L
s
.22645 .51105 m
.22633 .51274 L
s
.37342 .49198 m
.3748 .49335 L
s
.26789 .5009 m
.2678 .50259 L
s
.19877 .51833 m
.19865 .52001 L
s
.34016 .45067 m
.3482 .44811 L
s
.30732 .48048 m
.30725 .48217 L
s
.17109 .52557 m
.17095 .52725 L
s
.24023 .50824 m
.24012 .50993 L
s
.3098 .4917 m
.31121 .49308 L
s
.28167 .49807 m
.28159 .49976 L
s
.21255 .51554 m
.21243 .51722 L
s
.35717 .49155 m
.35855 .49293 L
s
.31959 .46996 m
.31953 .47164 L
s
.1394 .49171 m
.1399 .49283 L
s
.25401 .50542 m
.25391 .50711 L
s
.18487 .5228 m
.18473 .52448 L
s
.15352 .49164 m
.154 .49276 L
s
.16763 .49158 m
.16811 .4927 L
s
.29496 .49268 m
.29489 .49437 L
s
.29354 .49131 m
.29496 .49268 L
s
.18175 .49152 m
.18222 .49265 L
s
.33186 .45941 m
.3318 .4611 L
s
.19586 .49147 m
.19633 .4926 L
s
.22633 .51274 m
.22622 .51442 L
s
.20998 .49142 m
.21044 .49255 L
s
.34091 .49114 m
.3423 .49251 L
s
.2241 .49138 m
.22455 .49251 L
s
.23822 .49134 m
.23867 .49248 L
s
.2678 .50259 m
.2677 .50429 L
s
.25235 .4913 m
.25278 .49245 L
s
.14345 .53387 m
.15253 .53316 L
s
.19865 .52001 m
.19852 .5217 L
s
.26647 .49128 m
.2669 .49242 L
s
.2806 .49125 m
.28101 .4924 L
s
.30725 .48217 m
.30717 .48386 L
s
.17095 .52725 m
.17081 .52893 L
s
.24012 .50993 m
.24001 .51162 L
s
.28159 .49976 m
.2815 .50145 L
s
.32464 .49073 m
.32605 .4921 L
s
.21243 .51722 m
.21231 .51891 L
s
.3947 .49207 m
.40281 .4896 L
s
.31953 .47164 m
.31946 .47333 L
s
.37204 .49059 m
.37342 .49198 L
s
.18473 .52448 m
.1846 .52616 L
s
.25391 .50711 m
.25381 .5088 L
s
.29489 .49437 m
.29481 .49607 L
s
.22622 .51442 m
.2261 .51611 L
s
.3318 .4611 m
.33174 .46278 L
s
.13891 .49059 m
.1394 .49171 L
s
.30838 .49033 m
.3098 .4917 L
s
.15253 .53316 m
.16162 .53244 L
s
.15303 .49052 m
.15352 .49164 L
s
.2677 .50429 m
.26761 .50598 L
s
.19852 .5217 m
.19839 .52338 L
s
.16715 .49045 m
.16763 .49158 L
s
.35578 .49017 m
.35717 .49155 L
s
.18127 .49039 m
.18175 .49152 L
s
.30717 .48386 m
.3071 .48556 L
s
.1954 .49034 m
.19586 .49147 L
s
.24001 .51162 m
.2399 .51331 L
s
.20952 .49029 m
.20998 .49142 L
s
.22365 .49024 m
.2241 .49138 L
s
.23778 .4902 m
.23822 .49134 L
s
.2921 .48993 m
.29354 .49131 L
s
.25191 .49016 m
.25235 .4913 L
s
.2815 .50145 m
.28141 .50315 L
s
.26604 .49013 m
.26647 .49128 L
s
.21231 .51891 m
.21219 .52059 L
s
.28018 .49011 m
.2806 .49125 L
s
.31946 .47333 m
.31939 .47502 L
s
.33951 .48976 m
.34091 .49114 L
s
.1846 .52616 m
.18446 .52784 L
s
.25381 .5088 m
.2537 .51049 L
s
.38694 .48964 m
.38831 .49102 L
s
.29481 .49607 m
.29473 .49777 L
s
.2261 .51611 m
.22599 .5178 L
s
.33174 .46278 m
.33168 .46447 L
s
.16162 .53244 m
.17072 .53172 L
s
.3482 .44811 m
.35625 .44554 L
s
.26761 .50598 m
.26751 .50767 L
s
.19839 .52338 m
.19826 .52506 L
s
.32323 .48935 m
.32464 .49073 L
s
.3071 .48556 m
.30703 .48725 L
s
.34403 .45222 m
.34397 .4539 L
s
.37066 .48921 m
.37204 .49059 L
s
.13841 .48947 m
.13891 .49059 L
s
.2399 .51331 m
.23979 .515 L
s
.15254 .48939 m
.15303 .49052 L
s
.16667 .48933 m
.16715 .49045 L
s
.28141 .50315 m
.28132 .50485 L
s
.21219 .52059 m
.21206 .52228 L
s
.1808 .48926 m
.18127 .49039 L
s
.31939 .47502 m
.31933 .47672 L
s
.19493 .4892 m
.1954 .49034 L
s
.30695 .48895 m
.30838 .49033 L
s
.20906 .48915 m
.20952 .49029 L
s
.2537 .51049 m
.2536 .51219 L
s
.2232 .4891 m
.22365 .49024 L
s
.23734 .48906 m
.23778 .4902 L
s
.35439 .48879 m
.35578 .49017 L
s
.25148 .48902 m
.25191 .49016 L
s
.26561 .48899 m
.26604 .49013 L
s
.29473 .49777 m
.29464 .49946 L
s
.27976 .48896 m
.28018 .49011 L
s
.22599 .5178 m
.22587 .51949 L
s
.17072 .53172 m
.17983 .53099 L
s
.33168 .46447 m
.33162 .46616 L
s
.29067 .48855 m
.2921 .48993 L
s
.19826 .52506 m
.19813 .52675 L
s
.26751 .50767 m
.26741 .50937 L
s
.30703 .48725 m
.30695 .48895 L
s
.3381 .48838 m
.33951 .48976 L
s
.34397 .4539 m
.34392 .45559 L
s
.23979 .515 m
.23968 .51669 L
s
.38557 .48825 m
.38694 .48964 L
s
.28132 .50485 m
.28123 .50655 L
s
.40281 .4896 m
.41095 .48711 L
s
.21206 .52228 m
.21194 .52397 L
s
.31933 .47672 m
.31926 .47841 L
s
.2536 .51219 m
.25349 .51388 L
s
.15205 .48827 m
.15254 .48939 L
s
.32182 .48797 m
.32323 .48935 L
s
.16618 .4882 m
.16667 .48933 L
s
.29464 .49946 m
.29456 .50116 L
s
.18032 .48813 m
.1808 .48926 L
s
.17983 .53099 m
.18894 .53027 L
s
.22587 .51949 m
.22575 .52118 L
s
.36928 .48783 m
.37066 .48921 L
s
.19446 .48807 m
.19493 .4892 L
s
.33162 .46616 m
.33156 .46786 L
s
.2086 .48802 m
.20906 .48915 L
s
.22275 .48796 m
.2232 .4891 L
s
.26741 .50937 m
.26731 .51107 L
s
.23689 .48792 m
.23734 .48906 L
s
.25104 .48788 m
.25148 .48902 L
s
.26518 .48784 m
.26561 .48899 L
s
.27933 .48781 m
.27976 .48896 L
s
.30695 .48895 m
.30688 .49065 L
s
.30553 .48757 m
.30695 .48895 L
s
.23968 .51669 m
.23957 .51838 L
s
.34392 .45559 m
.34386 .45728 L
s
.35299 .48741 m
.35439 .48879 L
s
.28123 .50655 m
.28113 .50825 L
s
.21194 .52397 m
.21181 .52566 L
s
.31926 .47841 m
.31919 .48011 L
s
.25349 .51388 m
.25339 .51558 L
s
.28924 .48718 m
.29067 .48855 L
s
.18894 .53027 m
.19806 .52955 L
s
.29456 .50116 m
.29448 .50287 L
s
.22575 .52118 m
.22563 .52287 L
s
.3367 .48699 m
.3381 .48838 L
s
.33156 .46786 m
.3315 .46955 L
s
.35625 .44554 m
.36433 .44297 L
s
.38419 .48687 m
.38557 .48825 L
s
.26731 .51107 m
.26721 .51277 L
s
.1657 .48707 m
.16618 .4882 L
s
.17984 .487 m
.18032 .48813 L
s
.30688 .49065 m
.3068 .49234 L
s
.19399 .48694 m
.19446 .48807 L
s
.23957 .51838 m
.23945 .52008 L
s
.34386 .45728 m
.34381 .45897 L
s
.20814 .48688 m
.2086 .48802 L
s
.3204 .48659 m
.32182 .48797 L
s
.22229 .48683 m
.22275 .48796 L
s
.23644 .48678 m
.23689 .48792 L
s
.28113 .50825 m
.28104 .50995 L
s
.2506 .48673 m
.25104 .48788 L
s
.26475 .48669 m
.26518 .48784 L
s
.3679 .48644 m
.36928 .48783 L
s
.27891 .48666 m
.27933 .48781 L
s
.31919 .48011 m
.31912 .4818 L
s
.25339 .51558 m
.25328 .51728 L
s
.19806 .52955 m
.20718 .52883 L
s
.13773 .48758 m
.14683 .48678 L
s
.29448 .50287 m
.2944 .50457 L
s
.3041 .48619 m
.30553 .48757 L
s
.22563 .52287 m
.22551 .52457 L
s
.3315 .46955 m
.33144 .47124 L
s
.3516 .48602 m
.35299 .48741 L
s
.26721 .51277 m
.26711 .51447 L
s
.39912 .48591 m
.40048 .4873 L
s
.3068 .49234 m
.30673 .49405 L
s
.23945 .52008 m
.23934 .52178 L
s
.2878 .4858 m
.28924 .48718 L
s
.34381 .45897 m
.34375 .46067 L
s
.41095 .48711 m
.42265 .47485 L
s
.28104 .50995 m
.28094 .51165 L
s
.17936 .48587 m
.17984 .487 L
s
.33529 .48561 m
.3367 .48699 L
s
.19352 .4858 m
.19399 .48694 L
s
.31912 .4818 m
.31905 .4835 L
s
.35611 .44838 m
.35606 .45007 L
s
.20768 .48574 m
.20814 .48688 L
s
.20718 .52883 m
.21632 .52811 L
s
.38282 .48548 m
.38419 .48687 L
s
.25328 .51728 m
.25317 .51898 L
s
.22183 .48568 m
.22229 .48683 L
s
.23599 .48563 m
.23644 .48678 L
s
.14683 .48678 m
.15593 .48597 L
s
.25016 .48559 m
.2506 .48673 L
s
.2944 .50457 m
.29432 .50627 L
s
.26432 .48555 m
.26475 .48669 L
s
.27848 .48551 m
.27891 .48666 L
s
.33144 .47124 m
.33138 .47294 L
s
.31898 .4852 m
.3204 .48659 L
s
.26711 .51447 m
.26701 .51617 L
s
.36651 .48505 m
.3679 .48644 L
s
.30673 .49405 m
.30665 .49575 L
s
.23934 .52178 m
.23922 .52348 L
s
.34375 .46067 m
.3437 .46236 L
s
.28094 .51165 m
.28085 .51336 L
s
.30267 .4848 m
.3041 .48619 L
s
.21632 .52811 m
.22546 .52738 L
s
.31905 .4835 m
.31898 .4852 L
s
.3502 .48463 m
.3516 .48602 L
s
.35606 .45007 m
.35602 .45176 L
s
.25317 .51898 m
.25306 .52068 L
s
.15593 .48597 m
.16504 .48517 L
s
.39775 .48452 m
.39912 .48591 L
s
.29432 .50627 m
.29423 .50798 L
s
.36433 .44297 m
.37243 .4404 L
s
.19304 .48466 m
.19352 .4858 L
s
.28636 .48441 m
.2878 .4858 L
s
.33138 .47294 m
.33131 .47464 L
s
.20721 .4846 m
.20768 .48574 L
s
.22138 .48454 m
.22183 .48568 L
s
.26701 .51617 m
.2669 .51787 L
s
.23554 .48449 m
.23599 .48563 L
s
.33388 .48422 m
.33529 .48561 L
s
.24971 .48444 m
.25016 .48559 L
s
.26388 .4844 m
.26432 .48555 L
s
.30665 .49575 m
.30657 .49745 L
s
.27806 .48436 m
.27848 .48551 L
s
.38144 .48409 m
.38282 .48548 L
s
.3437 .46236 m
.34364 .46406 L
s
.28085 .51336 m
.28075 .51506 L
s
.22546 .52738 m
.2346 .52666 L
s
.31898 .4852 m
.31891 .4869 L
s
.31756 .48382 m
.31898 .4852 L
s
.16504 .48517 m
.17415 .48436 L
s
.25306 .52068 m
.25295 .52238 L
s
.35602 .45176 m
.35597 .45345 L
s
.36512 .48366 m
.36651 .48505 L
s
.29423 .50798 m
.29415 .50969 L
s
.33131 .47464 m
.33125 .47634 L
s
.2669 .51787 m
.2668 .51958 L
s
.30124 .48342 m
.30267 .4848 L
s
.30657 .49745 m
.3065 .49916 L
s
.3488 .48325 m
.3502 .48463 L
s
.20674 .48346 m
.20721 .4846 L
s
.34364 .46406 m
.34358 .46575 L
s
.22092 .4834 m
.22138 .48454 L
s
.39638 .48313 m
.39775 .48452 L
s
.23509 .48334 m
.23554 .48449 L
s
.28075 .51506 m
.28065 .51677 L
s
.2346 .52666 m
.24375 .52593 L
s
.24927 .48329 m
.24971 .48444 L
s
.28491 .48303 m
.28636 .48441 L
s
.26345 .48325 m
.26388 .4844 L
s
.17415 .48436 m
.18328 .48356 L
s
.27763 .4832 m
.27806 .48436 L
s
.31891 .4869 m
.31884 .48861 L
s
.35597 .45345 m
.35592 .45515 L
s
.33247 .48283 m
.33388 .48422 L
s
.29415 .50969 m
.29407 .5114 L
s
.38006 .4827 m
.38144 .48409 L
s
.33125 .47634 m
.33119 .47804 L
s
.2668 .51958 m
.26669 .52129 L
s
.31614 .48243 m
.31756 .48382 L
s
.3065 .49916 m
.30642 .50086 L
s
.34358 .46575 m
.34353 .46745 L
s
.24375 .52593 m
.25291 .52521 L
s
.36373 .48227 m
.36512 .48366 L
s
.28065 .51677 m
.28055 .51848 L
s
.41134 .48217 m
.4127 .48357 L
s
.18328 .48356 m
.19241 .48275 L
s
.31884 .48861 m
.31877 .49031 L
s
.35592 .45515 m
.35586 .45684 L
s
.29981 .48203 m
.30124 .48342 L
s
.22045 .48225 m
.22092 .4834 L
s
.23464 .4822 m
.23509 .48334 L
s
.37243 .4404 m
.38054 .43781 L
s
.29407 .5114 m
.29398 .51311 L
s
.24882 .48214 m
.24927 .48329 L
s
.26301 .48209 m
.26345 .48325 L
s
.34739 .48185 m
.3488 .48325 L
s
.2772 .48205 m
.27763 .4832 L
s
.33119 .47804 m
.33112 .47974 L
s
.36824 .44452 m
.3682 .44622 L
s
.39501 .48173 m
.39638 .48313 L
s
.28347 .48165 m
.28491 .48303 L
s
.30642 .50086 m
.30634 .50257 L
s
.25291 .52521 m
.26208 .52448 L
s
.34353 .46745 m
.34347 .46915 L
s
.33106 .48145 m
.33247 .48283 L
s
.28055 .51848 m
.28045 .52019 L
s
.19241 .48275 m
.20154 .48195 L
s
.37867 .4813 m
.38006 .4827 L
s
.31877 .49031 m
.3187 .49202 L
s
.35586 .45684 m
.35581 .45854 L
s
.29398 .51311 m
.2939 .51482 L
s
.31472 .48104 m
.31614 .48243 L
s
.33112 .47974 m
.33106 .48145 L
s
.3682 .44622 m
.36815 .44791 L
s
.36233 .48088 m
.36373 .48227 L
s
.23418 .48105 m
.23464 .4822 L
s
.40998 .48077 m
.41134 .48217 L
s
.24838 .48099 m
.24882 .48214 L
s
.30634 .50257 m
.30626 .50428 L
s
.26257 .48094 m
.26301 .48209 L
s
.26208 .52448 m
.27125 .52376 L
s
.27677 .48089 m
.2772 .48205 L
s
.29837 .48065 m
.29981 .48203 L
s
.34347 .46915 m
.34341 .47085 L
s
.20154 .48195 m
.21069 .48114 L
s
.34599 .48046 m
.34739 .48185 L
s
.3187 .49202 m
.31863 .49373 L
s
.39364 .48034 m
.39501 .48173 L
s
.35581 .45854 m
.35576 .46024 L
s
.28202 .48026 m
.28347 .48165 L
s
.2939 .51482 m
.29381 .51653 L
s
.33106 .48145 m
.33099 .48315 L
s
.32964 .48005 m
.33106 .48145 L
s
.36815 .44791 m
.36811 .44961 L
s
.37729 .47991 m
.37867 .4813 L
s
.27125 .52376 m
.28043 .52303 L
s
.30626 .50428 m
.30618 .50599 L
s
.21069 .48114 m
.21984 .48033 L
s
.34341 .47085 m
.34335 .47256 L
s
.31329 .47965 m
.31472 .48104 L
s
.24793 .47984 m
.24838 .48099 L
s
.26213 .47979 m
.26257 .48094 L
s
.31863 .49373 m
.31856 .49544 L
s
.27633 .47974 m
.27677 .48089 L
s
.36094 .47948 m
.36233 .48088 L
s
.35576 .46024 m
.35571 .46194 L
s
.38054 .43781 m
.38867 .43522 L
s
.40862 .47938 m
.40998 .48077 L
s
.29381 .51653 m
.29372 .51825 L
s
.29693 .47926 m
.29837 .48065 L
s
.33099 .48315 m
.33093 .48486 L
s
.36811 .44961 m
.36806 .45131 L
s
.28043 .52303 m
.28962 .5223 L
s
.34458 .47907 m
.34599 .48046 L
s
.30618 .50599 m
.3061 .50771 L
s
.39226 .47894 m
.39364 .48034 L
s
.21984 .48033 m
.229 .47952 L
s
.34335 .47256 m
.34329 .47426 L
s
.28057 .47887 m
.28202 .48026 L
s
.32822 .47866 m
.32964 .48005 L
s
.31856 .49544 m
.31848 .49715 L
s
.35571 .46194 m
.35566 .46364 L
s
.3759 .47851 m
.37729 .47991 L
s
.26169 .47863 m
.26213 .47979 L
s
.2759 .47858 m
.27633 .47974 L
s
.33093 .48486 m
.33086 .48657 L
s
.28962 .5223 m
.29766 .51987 L
s
.36806 .45131 m
.36802 .45301 L
s
.31186 .47826 m
.31329 .47965 L
s
.3061 .50771 m
.30602 .50942 L
s
.229 .47952 m
.23816 .47871 L
s
.35954 .47809 m
.36094 .47948 L
s
.34329 .47426 m
.34323 .47597 L
s
.38042 .44066 m
.38038 .44235 L
s
.40725 .47797 m
.40862 .47938 L
s
.29549 .47787 m
.29693 .47926 L
s
.31848 .49715 m
.31841 .49886 L
s
.35566 .46364 m
.3556 .46535 L
s
.34317 .47767 m
.34458 .47907 L
s
.39088 .47754 m
.39226 .47894 L
s
.27912 .47748 m
.28057 .47887 L
s
.33086 .48657 m
.33079 .48828 L
s
.36802 .45301 m
.36797 .45471 L
s
.23816 .47871 m
.24733 .47791 L
s
.30602 .50942 m
.30594 .51114 L
s
.3268 .47727 m
.32822 .47866 L
s
.27546 .47742 m
.2759 .47858 L
s
.34323 .47597 m
.34317 .47767 L
s
.38038 .44235 m
.38034 .44405 L
s
.37451 .47711 m
.3759 .47851 L
s
.38867 .43522 m
.39675 .43257 L
s
.31841 .49886 m
.31834 .50057 L
s
.31043 .47687 m
.31186 .47826 L
s
.3556 .46535 m
.35555 .46705 L
s
.35814 .47669 m
.35954 .47809 L
s
.33079 .48828 m
.33073 .48999 L
s
.40588 .47657 m
.40725 .47797 L
s
.36797 .45471 m
.36793 .45641 L
s
.24733 .47791 m
.25651 .4771 L
s
.29405 .47647 m
.29549 .47787 L
s
.30594 .51114 m
.30586 .51285 L
s
.34317 .47767 m
.34311 .47938 L
s
.34176 .47628 m
.34317 .47767 L
s
.38034 .44405 m
.3803 .44575 L
s
.3895 .47614 m
.39088 .47754 L
s
.27767 .47609 m
.27912 .47748 L
s
.31834 .50057 m
.31826 .50229 L
s
.35555 .46705 m
.3555 .46876 L
s
.32538 .47587 m
.3268 .47727 L
s
.29766 .51987 m
.3057 .51742 L
s
.33073 .48999 m
.33066 .4917 L
s
.37312 .47571 m
.37451 .47711 L
s
.25651 .4771 m
.26569 .47628 L
s
.36793 .45641 m
.36788 .45812 L
s
.30586 .51285 m
.30578 .51457 L
s
.30899 .47547 m
.31043 .47687 L
s
.34311 .47938 m
.34305 .48109 L
s
.3803 .44575 m
.38026 .44746 L
s
.35674 .47529 m
.35814 .47669 L
s
.31826 .50229 m
.31819 .504 L
s
.40451 .47517 m
.40588 .47657 L
s
.3555 .46876 m
.35544 .47047 L
s
.2926 .47508 m
.29405 .47647 L
s
.26569 .47628 m
.27489 .47547 L
s
.34035 .47488 m
.34176 .47628 L
s
.33066 .4917 m
.33059 .49341 L
s
.36788 .45812 m
.36783 .45982 L
s
.38812 .47473 m
.3895 .47614 L
s
.27621 .4747 m
.27767 .47609 L
s
.34305 .48109 m
.34299 .48281 L
s
.38026 .44746 m
.38021 .44916 L
s
.32395 .47447 m
.32538 .47587 L
s
.39675 .43257 m
.40296 .42852 L
s
.31819 .504 m
.31811 .50572 L
s
.37173 .47431 m
.37312 .47571 L
s
.39263 .43678 m
.3926 .43848 L
s
.35544 .47047 m
.35539 .47218 L
s
.27489 .47547 m
.28409 .47466 L
s
.30756 .47408 m
.30899 .47547 L
s
.33059 .49341 m
.33052 .49513 L
s
.36783 .45982 m
.36778 .46153 L
s
.35533 .47389 m
.35674 .47529 L
s
.40314 .47376 m
.40451 .47517 L
s
.29116 .47368 m
.2926 .47508 L
s
.34299 .48281 m
.34293 .48452 L
s
.38021 .44916 m
.38017 .45087 L
s
.33893 .47348 m
.34035 .47488 L
s
.31811 .50572 m
.31804 .50744 L
s
.42265 .47485 m
.42894 .47093 L
s
.3926 .43848 m
.39256 .44018 L
s
.35539 .47218 m
.35533 .47389 L
s
.38674 .47333 m
.38812 .47473 L
s
.27475 .4733 m
.27621 .4747 L
s
.28409 .47466 m
.27493 .46828 L
s
.3057 .51742 m
.31377 .51497 L
s
.33052 .49513 m
.33045 .49685 L
s
.32253 .47307 m
.32395 .47447 L
s
.36778 .46153 m
.36773 .46324 L
s
.37033 .4729 m
.37173 .47431 L
s
.34293 .48452 m
.34286 .48624 L
s
.38017 .45087 m
.38013 .45257 L
s
.30612 .47268 m
.30756 .47408 L
s
.31804 .50744 m
.31796 .50916 L
s
.35533 .47389 m
.35528 .4756 L
s
.35392 .47249 m
.35533 .47389 L
s
.39256 .44018 m
.39253 .44188 L
s
.40176 .47236 m
.40314 .47376 L
s
.28971 .47229 m
.29116 .47368 L
s
.33045 .49685 m
.33038 .49857 L
s
.36773 .46324 m
.36768 .46495 L
s
.33751 .47208 m
.33893 .47348 L
s
.34286 .48624 m
.3428 .48795 L
s
.38535 .47192 m
.38674 .47333 L
s
.27329 .4719 m
.27475 .4733 L
s
.38013 .45257 m
.38009 .45428 L
s
.31796 .50916 m
.31788 .51089 L
s
.3211 .47167 m
.32253 .47307 L
s
.35528 .4756 m
.35522 .47732 L
s
.39253 .44188 m
.39249 .44359 L
s
.36893 .4715 m
.37033 .4729 L
s
.33038 .49857 m
.33031 .50029 L
s
.36768 .46495 m
.36763 .46666 L
s
.30468 .47128 m
.30612 .47268 L
s
.35251 .47108 m
.35392 .47249 L
s
.3428 .48795 m
.34274 .48967 L
s
.38009 .45428 m
.38005 .45599 L
s
.40038 .47095 m
.40176 .47236 L
s
.28825 .47089 m
.28971 .47229 L
s
.35522 .47732 m
.35516 .47903 L
s
.39249 .44359 m
.39245 .4453 L
s
.31377 .51497 m
.32186 .51251 L
s
.33609 .47067 m
.33751 .47208 L
s
.33031 .50029 m
.33024 .50201 L
s
.38396 .47052 m
.38535 .47192 L
s
.40296 .42852 m
.40918 .42445 L
s
.36763 .46666 m
.36758 .46838 L
s
.31966 .47027 m
.3211 .47167 L
s
.34274 .48967 m
.34267 .49139 L
s
.38005 .45599 m
.38 .4577 L
s
.36753 .47009 m
.36893 .4715 L
s
.35516 .47903 m
.3551 .48075 L
s
.30323 .46987 m
.30468 .47128 L
s
.39245 .4453 m
.39242 .44701 L
s
.3511 .46968 m
.35251 .47108 L
s
.33024 .50201 m
.33017 .50373 L
s
.36758 .46838 m
.36753 .47009 L
s
.399 .46954 m
.40038 .47095 L
s
.42894 .47093 m
.43524 .467 L
s
.2868 .46949 m
.28825 .47089 L
s
.34267 .49139 m
.34261 .49311 L
s
.33467 .46927 m
.33609 .47067 L
s
.38 .4577 m
.37996 .45941 L
s
.38257 .46911 m
.38396 .47052 L
s
.40281 .43142 m
.40278 .43312 L
s
.3551 .48075 m
.35505 .48247 L
s
.39242 .44701 m
.39238 .44872 L
s
.31823 .46887 m
.31966 .47027 L
s
.33017 .50373 m
.3301 .50546 L
s
.36753 .47009 m
.36748 .47181 L
s
.36613 .46868 m
.36753 .47009 L
s
.30179 .46847 m
.30323 .46987 L
s
.34261 .49311 m
.34254 .49483 L
s
.37996 .45941 m
.37991 .46113 L
s
.34969 .46827 m
.3511 .46968 L
s
.42463 .46879 m
.4262 .46962 L
s
.40278 .43312 m
.40275 .43482 L
s
.32186 .51251 m
.32996 .51005 L
s
.39762 .46812 m
.399 .46954 L
s
.35505 .48247 m
.35499 .48419 L
s
.39238 .44872 m
.39234 .45043 L
s
.28534 .46808 m
.2868 .46949 L
s
.3301 .50546 m
.33002 .50719 L
s
.33324 .46786 m
.33467 .46927 L
s
.36748 .47181 m
.36743 .47353 L
s
.38117 .46769 m
.38257 .46911 L
s
.34254 .49483 m
.34248 .49656 L
s
.37991 .46113 m
.37987 .46284 L
s
.31679 .46746 m
.31823 .46887 L
s
.42305 .46795 m
.42463 .46879 L
s
.36473 .46727 m
.36613 .46868 L
s
.40275 .43482 m
.40273 .43653 L
s
.35499 .48419 m
.35493 .48591 L
s
.39234 .45043 m
.39231 .45214 L
s
.30034 .46707 m
.30179 .46847 L
s
.36743 .47353 m
.36738 .47525 L
s
.27493 .46828 m
.28297 .46572 L
s
.34827 .46686 m
.34969 .46827 L
s
.39623 .46671 m
.39762 .46812 L
s
.34248 .49656 m
.34241 .49828 L
s
.37987 .46284 m
.37982 .46456 L
s
.42147 .46712 m
.42305 .46795 L
s
.40918 .42445 m
.41543 .42037 L
s
.33182 .46645 m
.33324 .46786 L
s
.40273 .43653 m
.4027 .43823 L
s
.35493 .48591 m
.35487 .48764 L
s
.39231 .45214 m
.39227 .45386 L
s
.37978 .46628 m
.38117 .46769 L
s
.36738 .47525 m
.36733 .47697 L
s
.31535 .46605 m
.31679 .46746 L
s
.36332 .46586 m
.36473 .46727 L
s
.34241 .49828 m
.34235 .50001 L
s
.37982 .46456 m
.37978 .46628 L
s
.41988 .46629 m
.42147 .46712 L
s
.29889 .46566 m
.30034 .46707 L
s
.43524 .467 m
.44158 .46305 L
s
.32996 .51005 m
.33809 .50758 L
s
.35487 .48764 m
.35481 .48936 L
s
.4027 .43823 m
.40267 .43994 L
s
.39227 .45386 m
.39223 .45557 L
s
.34685 .46545 m
.34827 .46686 L
s
.39485 .46529 m
.39623 .46671 L
s
.36733 .47697 m
.36727 .47869 L
s
.33039 .46504 m
.33182 .46645 L
s
.34235 .50001 m
.34228 .50174 L
s
.4183 .46546 m
.41988 .46629 L
s
.37978 .46628 m
.37973 .468 L
s
.37838 .46487 m
.37978 .46628 L
s
.31391 .46464 m
.31535 .46605 L
s
.35481 .48936 m
.35475 .49109 L
s
.40267 .43994 m
.40264 .44165 L
s
.39223 .45557 m
.39219 .45729 L
s
.36191 .46445 m
.36332 .46586 L
s
.28297 .46572 m
.29103 .46316 L
s
.36727 .47869 m
.36722 .48042 L
s
.29744 .46425 m
.29889 .46566 L
s
.34228 .50174 m
.34221 .50347 L
s
.41671 .46463 m
.4183 .46546 L
s
.34543 .46403 m
.34685 .46545 L
s
.37973 .468 m
.37968 .46972 L
s
.39346 .46388 m
.39485 .46529 L
s
.35475 .49109 m
.35469 .49282 L
s
.40264 .44165 m
.40261 .44337 L
s
.39219 .45729 m
.39215 .45901 L
s
.32895 .46363 m
.33039 .46504 L
s
.37698 .46345 m
.37838 .46487 L
s
.36722 .48042 m
.36716 .48214 L
s
.31247 .46323 m
.31391 .46464 L
s
.41512 .4638 m
.41671 .46463 L
s
.41216 .42532 m
.41214 .42703 L
s
.37968 .46972 m
.37964 .47145 L
s
.3605 .46303 m
.36191 .46445 L
s
.33809 .50758 m
.34623 .5051 L
s
.35469 .49282 m
.35463 .49455 L
s
.40261 .44337 m
.40258 .44508 L
s
.39215 .45901 m
.39211 .46073 L
s
.34401 .46262 m
.34543 .46403 L
s
.41543 .42037 m
.4217 .41627 L
s
.36716 .48214 m
.36711 .48387 L
s
.39207 .46246 m
.39346 .46388 L
s
.41353 .46296 m
.41512 .4638 L
s
.43409 .46286 m
.43567 .4637 L
s
.37964 .47145 m
.37959 .47317 L
s
.41214 .42703 m
.41211 .42874 L
s
.32752 .46221 m
.32895 .46363 L
s
.37558 .46203 m
.37698 .46345 L
s
.35463 .49455 m
.35457 .49628 L
s
.40258 .44508 m
.40255 .4468 L
s
.39211 .46073 m
.39207 .46246 L
s
.31102 .46182 m
.31247 .46323 L
s
.29103 .46316 m
.29912 .46059 L
s
.36711 .48387 m
.36706 .4856 L
s
.44158 .46305 m
.44793 .45908 L
s
.35908 .46161 m
.3605 .46303 L
s
.41194 .46213 m
.41353 .46296 L
s
.43251 .46202 m
.43409 .46286 L
s
.37959 .47317 m
.37954 .4749 L
s
.41211 .42874 m
.41209 .43045 L
s
.34258 .4612 m
.34401 .46262 L
s
.35457 .49628 m
.3545 .49801 L
s
.40255 .4468 m
.40252 .44852 L
s
.39207 .46246 m
.39202 .46418 L
s
.39067 .46103 m
.39207 .46246 L
s
.32608 .4608 m
.32752 .46221 L
s
.36706 .4856 m
.367 .48733 L
s
.41034 .4613 m
.41194 .46213 L
s
.37417 .46061 m
.37558 .46203 L
s
.43092 .46119 m
.43251 .46202 L
s
.37954 .4749 m
.37949 .47663 L
s
.34623 .5051 m
.3544 .50262 L
s
.41209 .43045 m
.41207 .43216 L
s
.30957 .4604 m
.31102 .46182 L
s
.3545 .49801 m
.35444 .49974 L
s
.35767 .46019 m
.35908 .46161 L
s
.40252 .44852 m
.40248 .45024 L
s
.39202 .46418 m
.39198 .46591 L
s
.367 .48733 m
.36694 .48906 L
s
.40875 .46047 m
.41034 .4613 L
s
.34116 .45978 m
.34258 .4612 L
s
.42933 .46035 m
.43092 .46119 L
s
.38928 .45961 m
.39067 .46103 L
s
.37949 .47663 m
.37944 .47836 L
s
.41207 .43216 m
.41204 .43387 L
s
.32464 .45938 m
.32608 .4608 L
s
.40248 .45024 m
.40245 .45196 L
s
.39198 .46591 m
.39194 .46763 L
s
.37276 .45919 m
.37417 .46061 L
s
.29912 .46059 m
.30722 .45802 L
s
.40715 .45963 m
.40875 .46047 L
s
.36694 .48906 m
.36689 .49079 L
s
.42775 .45951 m
.42933 .46035 L
s
.35625 .45877 m
.35767 .46019 L
s
.37944 .47836 m
.37939 .48009 L
s
.41204 .43387 m
.41201 .43559 L
s
0 g
.5 Mabswid
.39254 .6704 m
.39275 .4772 L
s
.08393 .57381 m
.39254 .6704 L
s
.039 .916 .04 r
1 Mabswid
.4217 .41627 m
.42799 .41216 L
s
0 g
.5 Mabswid
.39249 .67048 m
.39269 .47728 L
s
.39256 .67046 m
.08394 .57387 L
s
.039 .916 .04 r
1 Mabswid
.39194 .46763 m
.3919 .46936 L
s
.40245 .45196 m
.40241 .45368 L
s
.33972 .45836 m
.34116 .45978 L
s
.40555 .4588 m
.40715 .45963 L
s
.38788 .45819 m
.38928 .45961 L
s
.36689 .49079 m
.36683 .49253 L
s
.42615 .45867 m
.42775 .45951 L
s
.3232 .45796 m
.32464 .45938 L
s
.3544 .50262 m
.36258 .50013 L
s
.37939 .48009 m
.37934 .48182 L
s
.37135 .45776 m
.37276 .45919 L
s
.41201 .43559 m
.41199 .43731 L
s
.44793 .45908 m
.45431 .4551 L
s
.3919 .46936 m
.39185 .47109 L
s
.40241 .45368 m
.40238 .45541 L
s
.40395 .45797 m
.40555 .4588 L
s
.35482 .45735 m
.35625 .45877 L
s
.36683 .49253 m
.36677 .49427 L
s
.42456 .45783 m
.42615 .45867 L
s
.42156 .41919 m
.42154 .4209 L
s
.33829 .45694 m
.33972 .45836 L
s
.37934 .48182 m
.37929 .48356 L
s
.41199 .43731 m
.41196 .43903 L
s
.38648 .45676 m
.38788 .45819 L
s
.39185 .47109 m
.39181 .47282 L
s
.40238 .45541 m
.40234 .45713 L
s
.30722 .45802 m
.31534 .45544 L
s
.40234 .45713 m
.40395 .45797 L
s
.32176 .45654 m
.3232 .45796 L
s
.42297 .457 m
.42456 .45783 L
s
.36677 .49427 m
.36671 .496 L
s
.36994 .45634 m
.37135 .45776 L
s
.4436 .4569 m
.44519 .45775 L
s
0 g
.5 Mabswid
.55367 .39381 m
.54594 .36836 L
s
.54594 .36836 m
.57521 .35895 L
s
.54594 .36836 m
.53596 .34424 L
s
.039 .916 .04 r
1 Mabswid
.42154 .4209 m
.42152 .42262 L
s
.37929 .48356 m
.37924 .48529 L
s
.41196 .43903 m
.41193 .44075 L
s
.3534 .45592 m
.35482 .45735 L
s
.39181 .47282 m
.39177 .47456 L
s
.40234 .45713 m
.4023 .45886 L
s
.40073 .4563 m
.40234 .45713 L
s
0 g
.5 Mabswid
.55868 .41899 m
.55367 .39381 L
s
.55367 .39381 m
.58298 .3845 L
s
.039 .916 .04 r
1 Mabswid
.42137 .45616 m
.42297 .457 L
s
.33686 .45552 m
.33829 .45694 L
s
.44201 .45606 m
.4436 .4569 L
s
.42152 .42262 m
.4215 .42433 L
s
.38507 .45533 m
.38648 .45676 L
s
.36258 .50013 m
.37078 .49764 L
s
.37924 .48529 m
.37919 .48703 L
s
.41193 .44075 m
.4119 .44247 L
s
.36853 .45491 m
.36994 .45634 L
s
.39912 .45547 m
.40073 .4563 L
s
.39177 .47456 m
.39172 .47629 L
s
.4023 .45886 m
.40226 .4606 L
s
.41977 .45532 m
.42137 .45616 L
s
.44043 .45522 m
.44201 .45606 L
s
.42799 .41216 m
.43431 .40803 L
s
.35198 .4545 m
.3534 .45592 L
s
.4215 .42433 m
.42148 .42605 L
s
.37919 .48703 m
.37914 .48877 L
s
.4119 .44247 m
.41187 .4442 L
s
.33542 .45409 m
.33686 .45552 L
s
.39751 .45463 m
.39912 .45547 L
s
.31534 .45544 m
.32348 .45286 L
s
.39172 .47629 m
.39168 .47803 L
s
.40226 .4606 m
.40222 .46233 L
s
.38367 .4539 m
.38507 .45533 L
s
.41817 .45448 m
.41977 .45532 L
s
.43884 .45437 m
.44043 .45522 L
s
.45431 .4551 m
.46071 .45111 L
s
.42148 .42605 m
.42146 .42777 L
s
.36711 .45348 m
.36853 .45491 L
s
.37914 .48877 m
.37909 .49051 L
s
.41187 .4442 m
.41184 .44593 L
s
.3959 .4538 m
.39751 .45463 L
s
.35055 .45307 m
.35198 .4545 L
s
.39168 .47803 m
.39163 .47977 L
s
.41657 .45364 m
.41817 .45448 L
s
.40222 .46233 m
.40218 .46407 L
s
.43724 .45353 m
.43884 .45437 L
s
.37078 .49764 m
.379 .49514 L
s
.33398 .45267 m
.33542 .45409 L
s
.42146 .42777 m
.42144 .42949 L
s
.37909 .49051 m
.37903 .49225 L
s
.38226 .45247 m
.38367 .4539 L
s
0 g
.5 Mabswid
.53596 .34424 m
.56524 .33471 L
s
.53596 .34424 m
.52435 .32294 L
s
.039 .916 .04 r
1 Mabswid
.41184 .44593 m
.41181 .44766 L
s
.39428 .45297 m
.3959 .4538 L
s
.41496 .4528 m
.41657 .45364 L
s
.39163 .47977 m
.39158 .48151 L
s
.40218 .46407 m
.40214 .4658 L
s
.43565 .45268 m
.43724 .45353 L
s
.36569 .45205 m
.36711 .45348 L
s
.42144 .42949 m
.42142 .43122 L
s
.34912 .45164 m
.35055 .45307 L
s
.39267 .45213 m
.39428 .45297 L
s
.41181 .44766 m
.41178 .44939 L
s
.32348 .45286 m
.33164 .45026 L
s
.41336 .45196 m
.41496 .4528 L
s
.39158 .48151 m
.39154 .48325 L
s
.40214 .4658 m
.4021 .46754 L
s
.43405 .45184 m
.43565 .45268 L
s
.43101 .41302 m
.431 .41474 L
s
.38085 .45104 m
.38226 .45247 L
s
.42142 .43122 m
.42139 .43294 L
s
.39105 .4513 m
.39267 .45213 L
s
.43431 .40803 m
.44065 .40388 L
s
.36427 .45062 m
.36569 .45205 L
s
.41178 .44939 m
.41175 .45112 L
s
.41175 .45112 m
.41336 .45196 L
s
.43245 .45099 m
.43405 .45184 L
s
.39154 .48325 m
.39149 .48499 L
s
.4021 .46754 m
.40206 .46928 L
s
0 g
.5 Mabswid
.55868 .41899 m
.58809 .40977 L
s
.039 .916 .04 r
1 Mabswid
.45317 .45091 m
.45475 .45176 L
s
.431 .41474 m
.43098 .41646 L
s
.34768 .45021 m
.34912 .45164 L
s
.379 .49514 m
.38725 .49263 L
s
.42139 .43294 m
.42137 .43467 L
s
.38943 .45046 m
.39105 .4513 L
s
.41175 .45112 m
.41171 .45286 L
s
.41014 .45028 m
.41175 .45112 L
s
.46071 .45111 m
.46714 .4471 L
s
.37944 .4496 m
.38085 .45104 L
s
.43085 .45015 m
.43245 .45099 L
s
.39149 .48499 m
.39144 .48674 L
s
.45158 .45006 m
.45317 .45091 L
s
.40206 .46928 m
.40202 .47103 L
s
.43098 .41646 m
.43097 .41818 L
s
.36285 .44919 m
.36427 .45062 L
s
.42137 .43467 m
.42134 .4364 L
s
.3878 .44963 m
.38943 .45046 L
s
.40852 .44944 m
.41014 .45028 L
s
.33164 .45026 m
.33982 .44767 L
s
.41171 .45286 m
.41168 .4546 L
s
.34625 .44878 m
.34768 .45021 L
s
.42925 .4493 m
.43085 .45015 L
s
.44998 .44921 m
.45158 .45006 L
s
.39144 .48674 m
.39139 .48848 L
s
.40202 .47103 m
.40197 .47277 L
s
.43097 .41818 m
.43095 .41991 L
s
.38618 .4488 m
.3878 .44963 L
s
.37803 .44817 m
.37944 .4496 L
s
.42134 .4364 m
.42132 .43813 L
s
.40691 .4486 m
.40852 .44944 L
s
.41168 .4546 m
.41164 .45633 L
s
.42765 .44846 m
.42925 .4493 L
s
.44839 .44836 m
.44998 .44921 L
s
.36142 .44775 m
.36285 .44919 L
s
.40197 .47277 m
.40193 .47452 L
s
.43095 .41991 m
.43094 .42163 L
s
.38725 .49263 m
.39543 .49007 L
s
.38455 .44796 m
.38618 .4488 L
s
.42132 .43813 m
.42129 .43986 L
s
0 g
.5 Mabswid
.57521 .35895 m
.58298 .3845 L
s
.56524 .33471 m
.57521 .35895 L
s
.039 .916 .04 r
1 Mabswid
.40529 .44776 m
.40691 .4486 L
s
.42604 .44761 m
.42765 .44846 L
s
.41164 .45633 m
.41161 .45808 L
s
.44679 .44751 m
.44839 .44836 L
s
.40193 .47452 m
.40188 .47627 L
s
.37661 .44673 m
.37803 .44817 L
s
.43094 .42163 m
.43092 .42336 L
s
.44065 .40388 m
.44701 .39973 L
s
.38292 .44713 m
.38455 .44796 L
s
0 g
.5 Mabswid
.58298 .3845 m
.58809 .40977 L
s
.039 .916 .04 r
1 Mabswid
.42129 .43986 m
.42126 .4416 L
s
.40367 .44692 m
.40529 .44776 L
s
.35999 .44631 m
.36142 .44775 L
s
.33982 .44767 m
.34801 .44506 L
s
.42443 .44677 m
.42604 .44761 L
s
.41161 .45808 m
.41157 .45982 L
s
.4452 .44666 m
.44679 .44751 L
s
.40188 .47627 m
.40184 .47802 L
s
.3692 .44722 m
.3754 .44316 L
s
.36447 .43983 m
.3692 .44722 L
s
.43092 .42336 m
.4309 .42509 L
s
.38129 .44629 m
.38292 .44713 L
s
.46714 .4471 m
.47359 .44308 L
s
.40205 .44608 m
.40367 .44692 L
s
.42126 .4416 m
.42124 .44334 L
s
.42282 .44592 m
.42443 .44677 L
s
.37519 .44529 m
.37661 .44673 L
s
.4436 .44581 m
.4452 .44666 L
s
.41157 .45982 m
.41153 .46156 L
s
.44052 .40683 m
.44051 .40855 L
s
.40184 .47802 m
.40179 .47977 L
s
.35856 .44487 m
.35999 .44631 L
s
.37966 .44546 m
.38129 .44629 L
s
.39543 .49007 m
.40172 .48615 L
s
.4309 .42509 m
.43088 .42682 L
s
.40043 .44524 m
.40205 .44608 L
s
.42124 .44334 m
.42121 .44508 L
s
.42121 .44508 m
.42282 .44592 L
s
.44199 .44496 m
.4436 .44581 L
s
.46279 .44489 m
.46438 .44575 L
s
.41153 .46156 m
.41149 .46331 L
s
.44051 .40855 m
.4405 .41027 L
s
0 g
.5 Mabswid
.52435 .32294 m
.5537 .31329 L
s
.039 .916 .04 r
1 Mabswid
.40179 .47977 m
.40174 .48153 L
s
.37802 .44462 m
.37966 .44546 L
s
.43088 .42682 m
.43086 .42856 L
s
.37377 .44385 m
.37519 .44529 L
s
.3988 .4444 m
.40043 .44524 L
s
.42121 .44508 m
.42118 .44682 L
s
.41959 .44423 m
.42121 .44508 L
s
.34801 .44506 m
.35623 .44245 L
s
.44039 .44411 m
.44199 .44496 L
s
.46119 .44403 m
.46279 .44489 L
s
.41149 .46331 m
.41145 .46506 L
s
0 g
.5 Mabswid
.5537 .31329 m
.56524 .33471 L
s
.039 .916 .04 r
1 Mabswid
.4405 .41027 m
.44049 .412 L
s
.40174 .48153 m
.40169 .48328 L
s
.43086 .42856 m
.43084 .43029 L
s
.39717 .44356 m
.3988 .4444 L
s
.41797 .44338 m
.41959 .44423 L
s
.42118 .44682 m
.42114 .44856 L
s
.43878 .44326 m
.44039 .44411 L
s
.4596 .44318 m
.46119 .44403 L
s
.44701 .39973 m
.4534 .39555 L
s
.41145 .46506 m
.41141 .46681 L
s
.44049 .412 m
.44048 .41373 L
s
.37234 .4424 m
.37377 .44385 L
s
.39555 .44272 m
.39717 .44356 L
s
.43084 .43029 m
.43081 .43203 L
s
.41635 .44254 m
.41797 .44338 L
s
.42114 .44856 m
.42111 .45031 L
s
.43717 .4424 m
.43878 .44326 L
s
.458 .44232 m
.4596 .44318 L
s
.3754 .44316 m
.38162 .43908 L
s
.47359 .44308 m
.48006 .43904 L
s
.41141 .46681 m
.41137 .46856 L
s
.44048 .41373 m
.44046 .41546 L
s
.39391 .44188 m
.39555 .44272 L
s
.43081 .43203 m
.43079 .43377 L
s
.41473 .44169 m
.41635 .44254 L
s
.35623 .44245 m
.36447 .43983 L
s
.43556 .44155 m
.43717 .4424 L
s
.37092 .44096 m
.37234 .4424 L
s
.42111 .45031 m
.42108 .45205 L
s
.5359 .42758 m .59018 .43317 L .56064 .44234 L .656 .751 .92 r
F
0 g
.5 Mabswid
.55937 .46236 m
.56064 .44234 L
s
.55868 .41899 m
.5596 .43002 L
s
.039 .916 .04 r
1 Mabswid
.4564 .44146 m
.458 .44232 L
s
.40172 .48615 m
.40802 .48221 L
s
.41137 .46856 m
.41133 .47032 L
s
.44046 .41546 m
.44045 .41719 L
s
.39228 .44104 m
.39391 .44188 L
s
.43079 .43377 m
.43077 .43551 L
s
.41311 .44085 m
.41473 .44169 L
s
.43395 .4407 m
.43556 .44155 L
s
.42108 .45205 m
.42105 .4538 L
s
.4548 .4406 m
.4564 .44146 L
s
.41133 .47032 m
.41129 .47208 L
s
.44045 .41719 m
.44043 .41893 L
s
.39064 .4402 m
.39228 .44104 L
s
.41149 .44 m
.41311 .44085 L
s
.43077 .43551 m
.43074 .43725 L
s
.43233 .43985 m
.43395 .4407 L
s
.45319 .43975 m
.4548 .4406 L
s
.42105 .4538 m
.42101 .45555 L
s
.45008 .40059 m
.45007 .40232 L
s
.41129 .47208 m
.41124 .47384 L
s
.44043 .41893 m
.44042 .42067 L
s
.38901 .43936 m
.39064 .4402 L
s
.40986 .43915 m
.41149 .44 L
s
.4534 .39555 m
.45981 .39136 L
s
.43074 .43725 m
.43072 .439 L
s
.43072 .439 m
.43233 .43985 L
s
.45159 .43889 m
.45319 .43975 L
s
.47246 .43883 m
.47405 .43969 L
s
.42101 .45555 m
.42098 .45731 L
s
.45007 .40232 m
.45007 .40405 L
s
.41124 .47384 m
.4112 .4756 L
s
.38737 .43851 m
.38901 .43936 L
s
.44042 .42067 m
.4404 .42241 L
s
.40823 .43831 m
.40986 .43915 L
s
.38162 .43908 m
.38786 .43499 L
s
.48006 .43904 m
.48656 .43499 L
s
.43072 .439 m
.43069 .44074 L
s
.4291 .43814 m
.43072 .439 L
s
.44998 .43803 m
.45159 .43889 L
s
.47086 .43797 m
.47246 .43883 L
s
.42098 .45731 m
.42094 .45906 L
s
.45007 .40405 m
.45006 .40578 L
s
.4112 .4756 m
.41115 .47736 L
s
.4404 .42241 m
.44038 .42415 L
s
.4066 .43746 m
.40823 .43831 L
s
.42748 .43729 m
.4291 .43814 L
s
.40802 .48221 m
.41435 .47825 L
s
.43069 .44074 m
.43066 .44249 L
s
.44837 .43717 m
.44998 .43803 L
s
.46926 .43711 m
.47086 .43797 L
s
.42094 .45906 m
.42091 .46082 L
s
.45006 .40578 m
.45005 .40752 L
s
.44038 .42415 m
.44036 .42589 L
s
.40496 .43661 m
.4066 .43746 L
s
.42586 .43644 m
.42748 .43729 L
s
.43066 .44249 m
.43064 .44424 L
s
.44675 .43632 m
.44837 .43717 L
s
.46766 .43624 m
.46926 .43711 L
s
.42091 .46082 m
.42087 .46258 L
s
.45005 .40752 m
.45004 .40926 L
s
.40333 .43576 m
.40496 .43661 L
s
.44036 .42589 m
.44035 .42764 L
s
.42423 .43559 m
.42586 .43644 L
s
.44514 .43546 m
.44675 .43632 L
s
.43064 .44424 m
.43061 .446 L
s
.46606 .43538 m
.46766 .43624 L
s
.42087 .46258 m
.42083 .46434 L
s
.45004 .40926 m
.45003 .41099 L
s
.45981 .39136 m
.46624 .38716 L
s
.40169 .43492 m
.40333 .43576 L
s
.44035 .42764 m
.44033 .42938 L
s
.4226 .43473 m
.42423 .43559 L
s
.44352 .4346 m
.44514 .43546 L
s
.46445 .43451 m
.46606 .43538 L
s
.43061 .446 m
.43058 .44775 L
s
.42083 .46434 m
.42079 .4661 L
s
.45003 .41099 m
.45002 .41274 L
s
.38786 .43499 m
.39413 .43089 L
s
.48656 .43499 m
.49308 .43092 L
s
.40005 .43407 m
.40169 .43492 L
s
.42097 .43388 m
.4226 .43473 L
s
.44033 .42938 m
.4403 .43113 L
s
.4419 .43374 m
.44352 .4346 L
s
.46284 .43365 m
.46445 .43451 L
s
.45969 .39432 m
.45969 .39606 L
s
.43058 .44775 m
.43055 .44951 L
s
.42079 .4661 m
.42075 .46787 L
s
.45002 .41274 m
.45001 .41448 L
s
.39841 .43322 m
.40005 .43407 L
s
.41435 .47825 m
.42071 .47428 L
s
.41934 .43303 m
.42097 .43388 L
s
.4403 .43113 m
.44028 .43288 L
s
.44028 .43288 m
.4419 .43374 L
s
.46123 .43279 m
.46284 .43365 L
s
.48218 .43274 m
.48378 .43361 L
s
.51182 .30585 m .55054 .32048 L .50311 .33604 L .544 .324 .532 r
F
.51182 .30585 m .54128 .29607 L .55054 .32048 L F
0 g
.5 Mabswid
.54128 .29607 m
.5537 .31329 L
s
.51182 .30585 m
.54128 .29607 L
s
.49917 .29412 m
.51182 .30585 L
s
.039 .916 .04 r
1 Mabswid
.45969 .39606 m
.45969 .39779 L
s
.43055 .44951 m
.43052 .45127 L
s
.42075 .46787 m
.42071 .46963 L
s
.39677 .43237 m
.39841 .43322 L
s
.45001 .41448 m
.45 .41622 L
s
.5359 .42758 m .58342 .41267 L .59018 .43317 L .656 .751 .92 r
F
0 g
.5 Mabswid
.58908 .45322 m
.59018 .43317 L
s
.58809 .40977 m
.59018 .43317 L
s
.56064 .44234 m
.59018 .43317 L
s
.039 .916 .04 r
1 Mabswid
.41771 .43217 m
.41934 .43303 L
s
.44028 .43288 m
.44026 .43464 L
s
.43866 .43202 m
.44028 .43288 L
s
.45962 .43192 m
.46123 .43279 L
s
.48058 .43187 m
.48218 .43274 L
s
.45969 .39779 m
.45968 .39953 L
s
.43052 .45127 m
.43048 .45303 L
s
.42071 .46963 m
.42067 .4714 L
s
.45 .41622 m
.44998 .41797 L
s
.41607 .43132 m
.41771 .43217 L
s
.43704 .43117 m
.43866 .43202 L
s
.44026 .43464 m
.44024 .43639 L
s
.45801 .43106 m
.45962 .43192 L
s
.46624 .38716 m
.4727 .38294 L
s
.47898 .431 m
.48058 .43187 L
s
.43048 .45303 m
.43045 .45479 L
s
.45968 .39953 m
.45968 .40127 L
s
.44998 .41797 m
.44997 .41972 L
s
.41444 .43047 m
.41607 .43132 L
s
.43541 .43031 m
.43704 .43117 L
s
.45639 .43019 m
.45801 .43106 L
s
.44024 .43639 m
.44021 .43815 L
s
.47737 .43013 m
.47898 .431 L
s
.49308 .43092 m
.49963 .42683 L
s
.39413 .43089 m
.40042 .42677 L
s
.43045 .45479 m
.43042 .45656 L
s
.45968 .40127 m
.45967 .40302 L
s
.4128 .42961 m
.41444 .43047 L
s
.44997 .41972 m
.44995 .42147 L
s
.43378 .42945 m
.43541 .43031 L
s
.45477 .42933 m
.45639 .43019 L
s
.44021 .43815 m
.44019 .43991 L
s
.47577 .42926 m
.47737 .43013 L
s
.42071 .47428 m
.42709 .4703 L
s
.43042 .45656 m
.43038 .45832 L
s
.45967 .40302 m
.45967 .40476 L
s
.41115 .42876 m
.4128 .42961 L
s
.44995 .42147 m
.44994 .42322 L
s
.43215 .42859 m
.43378 .42945 L
s
.45315 .42847 m
.45477 .42933 L
s
.47416 .42839 m
.47577 .42926 L
s
0 g
.5 Mabswid
.55491 .47768 m
.55937 .46236 L
s
.55937 .46236 m
.58908 .45322 L
s
.039 .916 .04 r
1 Mabswid
.44019 .43991 m
.44016 .44167 L
s
.43038 .45832 m
.43035 .46009 L
s
.45967 .40476 m
.45966 .40651 L
s
.40951 .42791 m
.41115 .42876 L
s
.43051 .42773 m
.43215 .42859 L
s
.44994 .42322 m
.44992 .42498 L
s
.45153 .4276 m
.45315 .42847 L
s
.47255 .42752 m
.47416 .42839 L
s
.46936 .38802 m
.46936 .38976 L
s
.44016 .44167 m
.44014 .44343 L
s
.43035 .46009 m
.43031 .46186 L
s
.45966 .40651 m
.45965 .40826 L
s
.40786 .42705 m
.40951 .42791 L
s
.4727 .38294 m
.47918 .3787 L
s
.42888 .42687 m
.43051 .42773 L
s
.44992 .42498 m
.4499 .42673 L
s
.4499 .42673 m
.45153 .4276 L
s
.51451 .41144 m .58342 .41267 L .5359 .42758 L .656 .751 .92 r
F
0 g
.5 Mabswid
.5359 .42758 m
.56064 .44234 L
s
.039 .916 .04 r
1 Mabswid
.47093 .42665 m
.47255 .42752 L
s
.49197 .42661 m
.49357 .42749 L
s
.46936 .38976 m
.46936 .3915 L
s
.44014 .44343 m
.44011 .4452 L
s
.43031 .46186 m
.43027 .46364 L
s
.45965 .40826 m
.45965 .41001 L
s
.40622 .4262 m
.40786 .42705 L
s
.42724 .42601 m
.42888 .42687 L
s
.49963 .42683 m
.5062 .42274 L
s
.40042 .42677 m
.40674 .42263 L
s
.4499 .42673 m
.44988 .42849 L
s
.44828 .42587 m
.4499 .42673 L
s
.46932 .42578 m
.47093 .42665 L
s
.49036 .42574 m
.49197 .42661 L
s
.46936 .3915 m
.46936 .39325 L
s
.44011 .4452 m
.44008 .44696 L
s
.43027 .46364 m
.43024 .46541 L
s
.45965 .41001 m
.45964 .41176 L
s
.4256 .42515 m
.42724 .42601 L
s
.44665 .425 m
.44828 .42587 L
s
.44988 .42849 m
.44986 .43025 L
s
.42709 .4703 m
.43349 .4663 L
s
.4677 .42491 m
.46932 .42578 L
s
.48875 .42486 m
.49036 .42574 L
s
.46936 .39325 m
.46936 .39499 L
s
.44008 .44696 m
.44005 .44873 L
s
.45964 .41176 m
.45963 .41351 L
s
.42396 .42429 m
.4256 .42515 L
s
.44502 .42414 m
.44665 .425 L
s
.46608 .42404 m
.4677 .42491 L
s
.44986 .43025 m
.44984 .43202 L
s
.48714 .42399 m
.48875 .42486 L
s
.46936 .39499 m
.46936 .39674 L
s
.44005 .44873 m
.44002 .4505 L
s
0 g
.5 Mabswid
.52877 .28422 m
.54128 .29607 L
s
.039 .916 .04 r
1 Mabswid
.42232 .42343 m
.42396 .42429 L
s
.45963 .41351 m
.45961 .41527 L
s
.44338 .42327 m
.44502 .42414 L
s
.46446 .42317 m
.46608 .42404 L
s
.48553 .42311 m
.48714 .42399 L
s
.44984 .43202 m
.44982 .43378 L
s
.47918 .3787 m
.48569 .37445 L
s
.44002 .4505 m
.43999 .45228 L
s
.46936 .39674 m
.46936 .39849 L
s
.42067 .42257 m
.42232 .42343 L
s
.45961 .41527 m
.4596 .41703 L
s
.44175 .42241 m
.44338 .42327 L
s
.46283 .4223 m
.46446 .42317 L
s
.48392 .42223 m
.48553 .42311 L
s
.44982 .43378 m
.4498 .43555 L
s
.43999 .45228 m
.43996 .45405 L
s
.46936 .39849 m
.46936 .40024 L
s
.5062 .42274 m
.51279 .41862 L
s
.40674 .42263 m
.41307 .41848 L
s
.41902 .42171 m
.42067 .42257 L
s
.4596 .41703 m
.45959 .41879 L
s
.44011 .42154 m
.44175 .42241 L
s
.4612 .42142 m
.46283 .4223 L
s
.4823 .42136 m
.48392 .42223 L
s
.47908 .38168 m
.47909 .38342 L
s
.4498 .43555 m
.44978 .43732 L
s
.43996 .45405 m
.43993 .45583 L
s
.46936 .40024 m
.46935 .402 L
s
.41737 .42085 m
.41902 .42171 L
s
.50311 .33604 m .55621 .3465 L .49799 .36538 L .544 .324 .532 r
F
.50311 .33604 m .55054 .32048 L .55621 .3465 L F
0 g
.5 Mabswid
.50311 .33604 m
.51182 .30585 L
s
.54128 .29607 m
.55054 .32048 L
s
.039 .916 .04 r
1 Mabswid
.43349 .4663 m
.43991 .46229 L
s
.43847 .42067 m
.44011 .42154 L
s
.45959 .41879 m
.45958 .42055 L
s
.45958 .42055 m
.4612 .42142 L
s
.48069 .42048 m
.4823 .42136 L
s
.5018 .42046 m
.50341 .42134 L
s
.47909 .38342 m
.47909 .38517 L
s
.44978 .43732 m
.44976 .43909 L
s
.43993 .45583 m
.43989 .45761 L
s
.46935 .402 m
.46935 .40375 L
s
.41572 .41999 m
.41737 .42085 L
s
.43683 .41981 m
.43847 .42067 L
s
.45958 .42055 m
.45956 .42232 L
s
.45795 .41968 m
.45958 .42055 L
s
.47907 .4196 m
.48069 .42048 L
s
.50019 .41957 m
.5018 .42046 L
s
.47909 .38517 m
.4791 .38692 L
s
.44976 .43909 m
.44973 .44086 L
s
.43989 .45761 m
.43986 .45939 L
s
.46935 .40375 m
.46934 .40551 L
s
0 g
.5 Mabswid
.58908 .45322 m
.58482 .46854 L
s
.039 .916 .04 r
1 Mabswid
.43519 .41894 m
.43683 .41981 L
s
.45631 .41881 m
.45795 .41968 L
s
.45956 .42232 m
.45955 .42408 L
s
.48569 .37445 m
.49222 .37018 L
s
.47745 .41872 m
.47907 .4196 L
s
.49858 .41869 m
.50019 .41957 L
s
.4791 .38692 m
.4791 .38867 L
s
.44973 .44086 m
.44971 .44264 L
s
.46934 .40551 m
.46934 .40727 L
s
.43354 .41808 m
.43519 .41894 L
s
.45468 .41794 m
.45631 .41881 L
s
.47582 .41785 m
.47745 .41872 L
s
.45955 .42408 m
.45953 .42585 L
s
.49697 .41781 m
.49858 .41869 L
s
.51279 .41862 m
.51941 .41449 L
s
.41307 .41848 m
.41944 .41431 L
s
.4791 .38867 m
.4791 .39043 L
s
.44971 .44264 m
.44968 .44441 L
s
0 g
.5 Mabswid
.49917 .29412 m
.52877 .28422 L
s
.49917 .29412 m
.4872 .28864 L
s
.039 .916 .04 r
1 Mabswid
.46934 .40727 m
.46933 .40903 L
s
.43189 .41721 m
.43354 .41808 L
s
.45304 .41706 m
.45468 .41794 L
s
.47419 .41697 m
.47582 .41785 L
s
.49535 .41692 m
.49697 .41781 L
s
.45953 .42585 m
.45951 .42762 L
s
.4791 .39043 m
.47911 .39218 L
s
.43991 .46229 m
.44636 .45826 L
s
.44968 .44441 m
.44965 .44619 L
s
.43024 .41634 m
.43189 .41721 L
s
.46933 .40903 m
.46932 .4108 L
s
.4514 .41619 m
.45304 .41706 L
s
.47257 .41609 m
.47419 .41697 L
s
.49374 .41604 m
.49535 .41692 L
s
.45951 .42762 m
.4595 .4294 L
s
.47911 .39218 m
.47911 .39394 L
s
.44965 .44619 m
.44963 .44797 L
s
.42859 .41547 m
.43024 .41634 L
s
.46932 .4108 m
.46931 .41257 L
s
.44976 .41532 m
.4514 .41619 L
s
.47094 .41521 m
.47257 .41609 L
s
.48886 .3753 m
.48887 .37706 L
s
.49212 .41516 m
.49374 .41604 L
s
.4595 .4294 m
.45948 .43117 L
s
.44963 .44797 m
.4496 .44976 L
s
.47911 .39394 m
.47911 .3957 L
s
.49222 .37018 m
.49885 .36598 L
s
.42694 .41461 m
.42859 .41547 L
s
.44812 .41445 m
.44976 .41532 L
s
.46931 .41257 m
.4693 .41433 L
s
.4693 .41433 m
.47094 .41521 L
s
.4905 .41427 m
.49212 .41516 L
s
.51169 .41426 m
.5133 .41515 L
s
.48887 .37706 m
.48888 .37881 L
s
.45948 .43117 m
.45946 .43295 L
s
.4496 .44976 m
.44957 .45154 L
s
.47911 .3957 m
.47911 .39747 L
s
.42528 .41374 m
.42694 .41461 L
s
.44647 .41357 m
.44812 .41445 L
s
.4693 .41433 m
.46929 .41611 L
s
.46767 .41346 m
.4693 .41433 L
s
.41944 .41431 m
.42582 .41013 L
s
.48887 .41339 m
.4905 .41427 L
s
.51008 .41337 m
.51169 .41426 L
s
.48888 .37881 m
.48889 .38056 L
s
.45946 .43295 m
.45944 .43473 L
s
.44957 .45154 m
.44954 .45333 L
s
.47911 .39747 m
.47911 .39923 L
s
.44482 .4127 m
.44647 .41357 L
s
.46603 .41258 m
.46767 .41346 L
s
.46929 .41611 m
.46928 .41788 L
s
.48725 .4125 m
.48887 .41339 L
s
.50847 .41248 m
.51008 .41337 L
s
.44636 .45826 m
.45284 .45422 L
s
0 g
.5 Mabswid
.54747 .48721 m
.55491 .47768 L
s
.55491 .47768 m
.58482 .46854 L
s
.039 .916 .04 r
1 Mabswid
.48889 .38056 m
.48889 .38232 L
s
.45944 .43473 m
.45942 .43651 L
s
.47911 .39923 m
.4791 .401 L
s
.44317 .41183 m
.44482 .4127 L
s
.51451 .41144 m .57279 .39298 L .58342 .41267 L .656 .751 .92 r
F
.039 .916 .04 r
.51941 .41449 m
.52387 .41254 L
s
0 g
.5 Mabswid
.58342 .41267 m
.59018 .43317 L
s
.039 .916 .04 r
1 Mabswid
.46439 .4117 m
.46603 .41258 L
s
.48562 .41162 m
.48725 .4125 L
s
.50685 .41159 m
.50847 .41248 L
s
.46928 .41788 m
.46927 .41965 L
s
.48889 .38232 m
.4889 .38408 L
s
.45942 .43651 m
.45939 .43829 L
s
.4791 .401 m
.4791 .40276 L
s
.44152 .41095 m
.44317 .41183 L
s
.46275 .41082 m
.46439 .4117 L
s
.48399 .41074 m
.48562 .41162 L
s
.46927 .41965 m
.46926 .42143 L
s
.49631 .39394 m .57279 .39298 L .51451 .41144 L .656 .751 .92 r
F
.039 .916 .04 r
.50523 .4107 m
.50685 .41159 L
s
.52387 .41254 m
.53096 .40863 L
s
0 g
.5 Mabswid
.51451 .41144 m
.5359 .42758 L
s
0 0 0 r
1 Mabswid
.39586 .46127 m
.49813 .39591 L
s
.039 .916 .04 r
.4889 .38408 m
.48891 .38584 L
s
.45939 .43829 m
.45937 .44008 L
s
.43987 .41008 m
.44152 .41095 L
s
.4791 .40276 m
.4791 .40453 L
s
.46111 .40994 m
.46275 .41082 L
s
.48236 .40985 m
.48399 .41074 L
s
.50361 .40981 m
.50523 .4107 L
s
.46926 .42143 m
.46924 .42321 L
s
.52043 .40956 m
.522 .41054 L
s
.48891 .38584 m
.48891 .38761 L
s
.45937 .44008 m
.45935 .44186 L
s
.42582 .41013 m
.43223 .40593 L
s
.43821 .40921 m
.43987 .41008 L
s
.4791 .40453 m
.47909 .40631 L
s
.45946 .40906 m
.46111 .40994 L
s
.48072 .40897 m
.48236 .40985 L
s
.50199 .40892 m
.50361 .40981 L
s
.46924 .42321 m
.46923 .42499 L
s
.51887 .40858 m
.52043 .40956 L
s
.49939 .36864 m
.49932 .37043 L
s
.48891 .38761 m
.48892 .38937 L
s
.45935 .44186 m
.45932 .44365 L
s
.43655 .40833 m
.43821 .40921 L
s
.45284 .45422 m
.45934 .45016 L
s
.45782 .40818 m
.45946 .40906 L
s
.47909 .40631 m
.47909 .40808 L
s
0 g
.5 Mabswid
.51699 .27864 m
.52877 .28422 L
s
.039 .916 .04 r
1 Mabswid
.47909 .40808 m
.48072 .40897 L
s
.50036 .40803 m
.50199 .40892 L
s
.46923 .42499 m
.46921 .42677 L
s
.53096 .40863 m
.53808 .40472 L
s
.5173 .4076 m
.51887 .40858 L
s
.49799 .36538 m .55839 .37406 L .49631 .39394 L .544 .324 .532 r
F
.49799 .36538 m .55621 .3465 L .55839 .37406 L F
0 g
.5 Mabswid
.49799 .36538 m
.50311 .33604 L
s
.039 .916 .04 r
1 Mabswid
.48892 .38937 m
.48892 .39114 L
s
.45932 .44365 m
.4593 .44544 L
s
.43489 .40746 m
.43655 .40833 L
s
.45617 .4073 m
.45782 .40818 L
s
.47909 .40808 m
.47908 .40986 L
s
.47745 .4072 m
.47909 .40808 L
s
.49873 .40714 m
.50036 .40803 L
s
.46921 .42677 m
.4692 .42856 L
s
.51575 .40661 m
.5173 .4076 L
s
.4593 .44544 m
.45927 .44724 L
s
.48892 .39114 m
.48892 .39291 L
s
.51127 .36003 m
.51353 .35895 L
s
.45452 .40642 m
.45617 .4073 L
s
.47581 .40631 m
.47745 .4072 L
s
.49711 .40625 m
.49873 .40714 L
s
.47908 .40986 m
.47907 .41164 L
s
.4692 .42856 m
.46918 .43034 L
s
0 g
.5 Mabswid
.39954 .19111 m
.39277 .47731 L
s
.39269 .47728 m
.39947 .19108 L
s
.55054 .32048 m
.55621 .3465 L
s
.039 .916 .04 r
1 Mabswid
.5142 .40562 m
.51575 .40661 L
s
.48892 .39291 m
.48893 .39468 L
s
.45286 .40554 m
.45452 .40642 L
s
.47416 .40543 m
.47581 .40631 L
s
.49547 .40536 m
.49711 .40625 L
s
.47907 .41164 m
.47907 .41342 L
s
.43223 .40593 m
.43867 .40171 L
s
.46918 .43034 m
.46916 .43213 L
s
.51265 .40463 m
.5142 .40562 L
s
.48893 .39468 m
.48893 .39646 L
s
.45121 .40466 m
.45286 .40554 L
s
.47252 .40454 m
.47416 .40543 L
s
.49384 .40447 m
.49547 .40536 L
s
.47907 .41342 m
.47906 .4152 L
s
.46916 .43213 m
.46914 .43392 L
s
.45934 .45016 m
.46586 .44608 L
s
.53808 .40472 m
.54523 .40079 L
s
.53114 .40373 m
.53269 .4047 L
s
.44955 .40378 m
.45121 .40466 L
s
.48893 .39646 m
.48893 .39823 L
s
.5111 .40363 m
.51265 .40463 L
s
.47087 .40365 m
.47252 .40454 L
s
.4922 .40358 m
.49384 .40447 L
s
.47906 .4152 m
.47905 .41698 L
s
.46914 .43392 m
.46912 .43572 L
s
0 g
.5 Mabswid
.58482 .46854 m
.5776 .47804 L
s
.039 .916 .04 r
1 Mabswid
.44789 .4029 m
.44955 .40378 L
s
.5296 .40277 m
.53114 .40373 L
s
.48893 .39823 m
.48893 .40001 L
s
.46922 .40277 m
.47087 .40365 L
s
.50956 .40263 m
.5111 .40363 L
s
.51353 .35895 m
.5209 .35542 L
s
.49057 .40268 m
.4922 .40358 L
s
.47905 .41698 m
.47904 .41877 L
s
.46912 .43572 m
.4691 .43751 L
s
.44623 .40202 m
.44789 .4029 L
s
.46757 .40188 m
.46922 .40277 L
s
.52807 .40179 m
.5296 .40277 L
s
.48893 .40001 m
.48893 .40179 L
s
.48893 .40179 m
.49057 .40268 L
s
.50803 .40162 m
.50956 .40263 L
s
.47904 .41877 m
.47903 .42056 L
s
.4691 .43751 m
.46908 .43931 L
s
.44456 .40114 m
.44623 .40202 L
s
.46592 .401 m
.46757 .40188 L
s
.48893 .40179 m
.48892 .40358 L
s
.48728 .4009 m
.48893 .40179 L
s
.52654 .40082 m
.52807 .40179 L
s
.43867 .40171 m
.44513 .39748 L
s
.5065 .40061 m
.50803 .40162 L
s
.47903 .42056 m
.47901 .42235 L
s
.46908 .43931 m
.46906 .44111 L
s
.46426 .40011 m
.46592 .401 L
s
0 g
.5 Mabswid
.4872 .28864 m
.51699 .27864 L
s
.4872 .28864 m
.47675 .28992 L
s
.039 .916 .04 r
1 Mabswid
.48564 .40001 m
.48728 .4009 L
s
.48892 .40358 m
.48892 .40536 L
s
.52501 .39984 m
.52654 .40082 L
s
.54523 .40079 m
.5524 .39684 L
s
.46586 .44608 m
.47241 .44199 L
s
.50497 .3996 m
.5065 .40061 L
s
.47901 .42235 m
.479 .42414 L
s
.46261 .39922 m
.46426 .40011 L
s
.48399 .39912 m
.48564 .40001 L
s
.48892 .40536 m
.48892 .40715 L
s
.52349 .39885 m
.52501 .39984 L
s
.5209 .35542 m
.5283 .35188 L
s
.50345 .39859 m
.50497 .3996 L
s
.479 .42414 m
.47899 .42594 L
s
.46095 .39834 m
.46261 .39922 L
s
.48234 .39822 m
.48399 .39912 L
s
.48892 .40715 m
.48891 .40894 L
s
.52197 .39787 m
.52349 .39885 L
s
.54191 .39788 m
.54343 .39883 L
s
.47899 .42594 m
.47897 .42774 L
s
.50193 .39757 m
.50345 .39859 L
s
.45928 .39745 m
.46095 .39834 L
s
.48069 .39733 m
.48234 .39822 L
s
.48891 .40894 m
.48891 .41073 L
s
.5404 .39692 m
.54191 .39788 L
s
.52046 .39688 m
.52197 .39787 L
s
.52138 .35975 m
.52144 .35801 L
s
.47897 .42774 m
.47896 .42954 L
s
.50041 .39654 m
.50193 .39757 L
s
.44513 .39748 m
.45161 .39323 L
s
.45762 .39656 m
.45928 .39745 L
s
.4989 .39373 m
.4989 .39311 L
s
.47904 .39644 m
.48069 .39733 L
s
.48891 .41073 m
.4889 .41252 L
s
.52133 .3615 m
.52138 .35975 L
s
.53889 .39596 m
.5404 .39692 L
s
.51895 .39588 m
.52046 .39688 L
s
.47896 .42954 m
.47894 .43134 L
s
.45595 .39567 m
.45762 .39656 L
s
.4989 .39552 m
.50041 .39654 L
s
.47241 .44199 m
.47899 .43789 L
s
.4989 .39373 m
.4989 .39391 L
s
.47738 .39555 m
.47904 .39644 L
s
.52129 .36325 m
.52133 .3615 L
s
.4889 .41252 m
.48889 .41431 L
s
.53739 .39499 m
.53889 .39596 L
s
.51744 .39489 m
.51895 .39588 L
s
.47894 .43134 m
.47892 .43314 L
s
.5283 .35188 m
.53573 .34832 L
s
.45428 .39479 m
.45595 .39567 L
s
.47573 .39465 m
.47738 .39555 L
s
.4989 .39552 m
.4989 .3973 L
s
.49739 .39449 m
.4989 .39552 L
s
0 g
.5 Mabswid
.5375 .49016 m
.54747 .48721 L
s
.54747 .48721 m
.5776 .47804 L
s
.039 .916 .04 r
1 Mabswid
.52125 .365 m
.52129 .36325 L
s
.48889 .41431 m
.48889 .41611 L
s
.53588 .39402 m
.53739 .39499 L
s
.47892 .43314 m
.4789 .43495 L
s
.47407 .39376 m
.47573 .39465 L
s
.52121 .36674 m
.52125 .365 L
s
.48889 .41611 m
.48888 .41791 L
s
.49631 .39394 m .55709 .40314 L .49806 .42179 L .544 .324 .532 r
F
.49631 .39394 m .55839 .37406 L .57279 .39298 L .656 .751 .92 r
F
.49631 .39394 m .55839 .37406 L .55709 .40314 L .544 .324 .532 r
F
0 g
.5 Mabswid
.57279 .39298 m
.58342 .41267 L
s
.48127 .37505 m .55839 .37406 L .49631 .39394 L .656 .751 .92 r
F
.039 .916 .04 r
1 Mabswid
.49589 .39345 m
.49651 .39388 L
s
.55749 .39404 m
.5596 .39289 L
s
0 g
.5 Mabswid
.49743 .37484 m
.49799 .36538 L
s
.039 .916 .04 r
1 Mabswid
.4724 .39287 m
.47407 .39376 L
s
0 g
.5 Mabswid
.92429 .24029 m
.93778 .28389 L
s
.90831 .19845 m
.92429 .24029 L
s
.039 .916 .04 r
1 Mabswid
.49439 .39241 m
.49589 .39345 L
s
.52118 .36849 m
.52121 .36674 L
s
.45161 .39323 m
.45812 .38897 L
s
.48888 .41791 m
.48887 .41971 L
s
.5596 .39289 m
.56682 .38891 L
s
.47074 .39197 m
.4724 .39287 L
s
.52115 .37023 m
.52118 .36849 L
s
.49289 .39137 m
.49439 .39241 L
s
0 g
.5 Mabswid
.93778 .28389 m
.94799 .32674 L
s
.039 .916 .04 r
1 Mabswid
.48887 .41971 m
.48886 .42151 L
s
.47899 .43789 m
.48559 .43376 L
s
.5325 .35437 m
.53255 .35265 L
s
.46907 .39108 m
.47074 .39197 L
s
.53573 .34832 m
.54318 .34476 L
s
.52113 .37197 m
.52115 .37023 L
s
0 g
.5 Mabswid
.50675 .27984 m
.51699 .27864 L
s
.039 .916 .04 r
1 Mabswid
.4914 .39032 m
.49289 .39137 L
s
.48886 .42151 m
.48884 .42332 L
s
.53246 .3561 m
.5325 .35437 L
s
.46741 .39018 m
.46907 .39108 L
s
.52111 .37371 m
.52113 .37197 L
s
.48884 .42332 m
.48883 .42513 L
s
.48991 .38927 m
.4914 .39032 L
s
.53241 .35782 m
.53246 .3561 L
s
.46574 .38929 m
.46741 .39018 L
s
.50849 .38882 m
.5097 .38965 L
s
.5211 .37454 m
.52111 .37371 L
s
.48883 .42513 m
.48882 .42694 L
s
.53238 .35954 m
.53241 .35782 L
s
.46406 .3884 m
.46574 .38929 L
s
.48843 .38822 m
.48991 .38927 L
s
.45812 .38897 m
.46466 .38469 L
s
.56682 .38891 m
.57407 .38493 L
s
.50701 .3878 m
.50849 .38882 L
s
.48882 .42694 m
.48881 .42875 L
s
.53235 .36126 m
.53238 .35954 L
s
.48695 .38716 m
.48843 .38822 L
s
.48559 .43376 m
.49221 .42963 L
s
.54318 .34476 m
.55066 .34117 L
s
.50553 .38677 m
.50701 .3878 L
s
.53232 .36298 m
.53235 .36126 L
s
.48548 .3861 m
.48695 .38716 L
s
.56362 .38607 m
.56509 .387 L
s
0 g
.5 Mabswid
.89073 .16081 m
.90831 .19845 L
s
.039 .916 .04 r
1 Mabswid
.50406 .38574 m
.50553 .38677 L
s
.5323 .3647 m
.53232 .36298 L
s
.52256 .38514 m
.52295 .38541 L
s
.484 .38504 m
.48548 .3861 L
s
.54368 .34896 m
.54372 .34726 L
s
.56216 .38513 m
.56362 .38607 L
s
.5026 .38471 m
.50406 .38574 L
s
.53228 .36641 m
.5323 .3647 L
s
0 g
.5 Mabswid
.5776 .47804 m
.56784 .48092 L
s
.039 .916 .04 r
1 Mabswid
.54364 .35066 m
.54368 .34896 L
s
.5211 .38414 m
.52256 .38514 L
s
.5607 .38419 m
.56216 .38513 L
s
.48254 .38397 m
.484 .38504 L
s
.57407 .38493 m
.58234 .37861 L
s
.53226 .36813 m
.53228 .36641 L
s
.50114 .38367 m
.5026 .38471 L
s
.46466 .38469 m
.47354 .37823 L
s
.5436 .35236 m
.54364 .35066 L
s
.55925 .38325 m
.5607 .38419 L
s
.5211 .38414 m
.52111 .38587 L
s
.51964 .38313 m
.5211 .38414 L
s
.48107 .3829 m
.48254 .38397 L
s
.53226 .36985 m
.53226 .36813 L
s
.55066 .34117 m
.55767 .33773 L
s
.49968 .38263 m
.50114 .38367 L
s
.49221 .42963 m
.49894 .42548 L
s
.54357 .35405 m
.5436 .35236 L
s
.55802 .38244 m
.55925 .38325 L
s
.52111 .38587 m
.52113 .38761 L
s
.51819 .38212 m
.51964 .38313 L
s
0 g
.5 Mabswid
.94799 .32674 m
.95428 .36632 L
s
.039 .916 .04 r
1 Mabswid
.53225 .37156 m
.53226 .36985 L
s
.47962 .38182 m
.48107 .3829 L
s
.49822 .38158 m
.49968 .38263 L
s
.54354 .35575 m
.54357 .35405 L
s
0 g
.5 Mabswid
.47675 .28992 m
.46857 .29803 L
s
.50675 .27984 m
.47675 .28992 L
s
.039 .916 .04 r
1 Mabswid
.52113 .38761 m
.52115 .38934 L
s
.51674 .3811 m
.51819 .38212 L
s
.53225 .37156 m
.53225 .37327 L
s
.47816 .38074 m
.47962 .38182 L
s
.49944 .42136 m
.49948 .42219 L
s
.54352 .35744 m
.54354 .35575 L
s
.49677 .38053 m
.49822 .38158 L
s
.53515 .38039 m
.53626 .38115 L
s
.52115 .38934 m
.52118 .39107 L
s
.53225 .37327 m
.53225 .3744 L
s
.51529 .38009 m
.51674 .3811 L
s
.5435 .35914 m
.54352 .35744 L
s
.47671 .37965 m
.47816 .38074 L
s
.49533 .37948 m
.49677 .38053 L
s
.53372 .3794 m
.53515 .38039 L
s
.52118 .39107 m
.52121 .3928 L
s
.51385 .37906 m
.51529 .38009 L
s
.54349 .36083 m
.5435 .35914 L
s
.49389 .37842 m
.49533 .37948 L
s
.52121 .3928 m
.52125 .39453 L
s
.53228 .37841 m
.53372 .3794 L
s
.55767 .33773 m
.56458 .33432 L
s
.51241 .37804 m
.51385 .37906 L
s
.54348 .36252 m
.54349 .36083 L
s
.55639 .34082 m
.55614 .34263 L
s
.58234 .37861 m
.58837 .37385 L
s
.52125 .39453 m
.52129 .39626 L
s
.49245 .37736 m
.49389 .37842 L
s
.53228 .37841 m
.5323 .38012 L
s
.53085 .37741 m
.53228 .37841 L
s
.55614 .34263 m
.55591 .34442 L
s
.49806 .42179 m .55215 .43372 L .5034 .44893 L .544 .324 .532 r
F
.49806 .42179 m .55709 .40314 L .55215 .43372 L F
0 g
.5 Mabswid
.49631 .39394 m
.49806 .42179 L
s
.039 .916 .04 r
1 Mabswid
.57748 .37744 m
.57927 .37811 L
s
.54347 .36421 m
.54348 .36252 L
s
.51098 .37701 m
.51241 .37804 L
s
.54919 .37655 m
.54965 .37686 L
s
.52129 .39626 m
.52134 .39799 L
s
.5323 .38012 m
.53232 .38183 L
s
.57572 .37677 m
.57748 .37744 L
s
.55591 .34442 m
.5557 .3462 L
s
.52942 .37641 m
.53085 .37741 L
s
.49101 .3763 m
.49245 .37736 L
s
.54347 .36421 m
.54348 .3659 L
s
.50955 .37597 m
.51098 .37701 L
s
.57398 .37608 m
.57572 .37677 L
s
.55551 .34797 m
.5557 .3462 L
s
0 g
.5 Mabswid
.52562 .48615 m
.5375 .49016 L
s
.5375 .49016 m
.56784 .48092 L
s
.039 .916 .04 r
1 Mabswid
.54776 .37558 m
.54919 .37655 L
s
.53232 .38183 m
.53235 .38353 L
s
.52134 .39799 m
.52139 .39972 L
s
.528 .37541 m
.52942 .37641 L
s
.54348 .3659 m
.54348 .36759 L
s
.48958 .37523 m
.49101 .3763 L
s
.57226 .37538 m
.57398 .37608 L
s
.55534 .34973 m
.55551 .34797 L
s
.51153 .4186 m
.51382 .41735 L
s
.53235 .38353 m
.53238 .38524 L
s
.52139 .39972 m
.52145 .40145 L
s
.57055 .37466 m
.57226 .37538 L
s
.55518 .35147 m
.55534 .34973 L
s
.48127 .37505 m .54023 .35597 L .55839 .37406 L .656 .751 .92 r
F
.039 .916 .04 r
.54635 .37461 m
.54776 .37558 L
s
0 g
.5 Mabswid
.55621 .3465 m
.55839 .37406 L
s
.55839 .37406 m
.57279 .39298 L
s
.46952 .35467 m .54023 .35597 L .48127 .37505 L .656 .751 .92 r
F
0 g
.48127 .37505 m
.49631 .39394 L
s
0 0 0 r
1 Mabswid
.5114 .38911 m
.55274 .36792 L
s
.039 .916 .04 r
.50813 .37493 m
.50955 .37597 L
s
.52658 .3744 m
.528 .37541 L
s
.48816 .37416 m
.48958 .37523 L
s
.47354 .37823 m
.4812 .37458 L
s
.50671 .37389 m
.50813 .37493 L
s
.53238 .38524 m
.53242 .38695 L
s
.56887 .37393 m
.57055 .37466 L
s
.54493 .37363 m
.54635 .37461 L
s
.52145 .40145 m
.52151 .40317 L
s
.56458 .33432 m
.57151 .33089 L
s
.4812 .37458 m
.48889 .37092 L
s
.52516 .37339 m
.52658 .3744 L
s
.55505 .35321 m
.55518 .35147 L
s
0 g
.5 Mabswid
.55709 .40314 m
.55839 .37406 L
s
.039 .916 .04 r
1 Mabswid
.56721 .37318 m
.56887 .37393 L
s
.50529 .37285 m
.50671 .37389 L
s
.58837 .37385 m
.59444 .36906 L
s
.53242 .38695 m
.53246 .38865 L
s
.54352 .37265 m
.54493 .37363 L
s
.52151 .40317 m
.52158 .4049 L
s
.55505 .35321 m
.55493 .35494 L
s
.52375 .37237 m
.52516 .37339 L
s
.56557 .37243 m
.56721 .37318 L
s
.50388 .3718 m
.50529 .37285 L
s
.53246 .38865 m
.53251 .39036 L
s
.55483 .35666 m
.55493 .35494 L
s
0 g
.5 Mabswid
.49878 .2879 m
.50675 .27984 L
s
.039 .916 .04 r
1 Mabswid
.54352 .37265 m
.54354 .37433 L
s
.54212 .37166 m
.54352 .37265 L
s
.52158 .4049 m
.52165 .40662 L
s
.56395 .37166 m
.56557 .37243 L
s
.52234 .37136 m
.52375 .37237 L
s
0 g
.5 Mabswid
.87257 .12968 m
.89073 .16081 L
s
.039 .916 .04 r
1 Mabswid
.51382 .41735 m
.5213 .41326 L
s
.55476 .35836 m
.55483 .35666 L
s
.56664 .33564 m
.56641 .33735 L
s
.53251 .39036 m
.53256 .39206 L
s
.50247 .37075 m
.50388 .3718 L
s
.54354 .37433 m
.54357 .37601 L
s
.52165 .40662 m
.52172 .40834 L
s
.54071 .37067 m
.54212 .37166 L
s
.56235 .37087 m
.56395 .37166 L
s
.52094 .37033 m
.52234 .37136 L
s
.56641 .33735 m
.5662 .33906 L
s
.58664 .37048 m
.58833 .37111 L
s
.5547 .36006 m
.55476 .35836 L
s
.48889 .37092 m
.4966 .36724 L
s
.53256 .39206 m
.53261 .39376 L
s
.56077 .37007 m
.56235 .37087 L
s
.54357 .37601 m
.5436 .3777 L
s
.50107 .36969 m
.50247 .37075 L
s
.52172 .40834 m
.5218 .41006 L
s
.53932 .36968 m
.54071 .37067 L
s
.5662 .33906 m
.566 .34075 L
s
.58497 .36983 m
.58664 .37048 L
s
.51954 .36931 m
.52094 .37033 L
s
.55465 .36175 m
.5547 .36006 L
s
.55921 .36926 m
.56077 .37007 L
s
.53261 .39376 m
.53268 .39546 L
s
.5436 .3777 m
.54364 .37938 L
s
.58332 .36918 m
.58497 .36983 L
s
.57151 .33089 m
.57847 .32745 L
s
.566 .34075 m
.56582 .34244 L
s
.49966 .36863 m
.50107 .36969 L
s
.53792 .36869 m
.53932 .36968 L
s
.55463 .36342 m
.55465 .36175 L
s
.51814 .36828 m
.51954 .36931 L
s
.55766 .36844 m
.55921 .36926 L
s
.58169 .36851 m
.58332 .36918 L
s
.56582 .34244 m
.56566 .34411 L
s
.59444 .36906 m
.60053 .36426 L
s
.53268 .39546 m
.53274 .39716 L
s
.54364 .37938 m
.54368 .38106 L
s
.53653 .36769 m
.53792 .36869 L
s
.55463 .36509 m
.55463 .36342 L
s
.58008 .36783 m
.58169 .36851 L
s
.55614 .3676 m
.55766 .36844 L
s
.5213 .41326 m
.5288 .40916 L
s
.56566 .34411 m
.56552 .34578 L
s
.51675 .36725 m
.51814 .36828 L
s
.54368 .38106 m
.54373 .38274 L
s
.53274 .39716 m
.53281 .39886 L
s
0 0 0 r
.55274 .36792 m
.83356 .19387 L
s
.039 .916 .04 r
.57849 .36713 m
.58008 .36783 L
s
.53514 .36668 m
.53653 .36769 L
s
.55463 .36509 m
.55464 .36674 L
s
.55464 .36674 m
.55614 .3676 L
s
.56552 .34578 m
.56539 .34743 L
s
.51537 .36621 m
.51675 .36725 L
s
.4966 .36724 m
.50433 .36355 L
s
.57692 .36643 m
.57849 .36713 L
s
.54373 .38274 m
.54378 .38442 L
s
.53281 .39886 m
.53288 .40056 L
s
0 g
.5 Mabswid
.56784 .48092 m
.55615 .47682 L
s
.039 .916 .04 r
1 Mabswid
.56539 .34743 m
.56528 .34907 L
s
.55464 .36674 m
.55468 .36839 L
s
.55316 .36588 m
.55464 .36674 L
s
.53376 .36568 m
.53514 .36668 L
s
.57537 .36571 m
.57692 .36643 L
s
0 g
.5 Mabswid
.95428 .36632 m
.95619 .4002 L
s
.95428 .36632 m
.93223 .33482 L
s
.95428 .36632 m
.95428 .36632 L
s
.039 .916 .04 r
1 Mabswid
.51398 .36517 m
.51537 .36621 L
s
.54378 .38442 m
.54383 .3861 L
s
.53288 .40056 m
.53296 .40226 L
s
.56528 .34907 m
.56519 .35071 L
s
.5517 .36499 m
.55316 .36588 L
s
.55468 .36839 m
.55473 .37002 L
s
.57383 .36497 m
.57537 .36571 L
s
.53238 .36467 m
.53376 .36568 L
s
.56519 .35071 m
.56512 .35233 L
s
.54383 .3861 m
.54389 .38777 L
s
.5126 .36413 m
.51398 .36517 L
s
.53296 .40226 m
.53305 .40395 L
s
.57847 .32745 m
.58547 .32399 L
s
.55026 .3641 m
.5517 .36499 L
s
.57232 .36423 m
.57383 .36497 L
s
.55473 .37002 m
.5548 .37164 L
s
.57696 .33042 m
.57674 .33205 L
s
.5288 .40916 m
.53632 .40505 L
s
.53101 .36365 m
.53238 .36467 L
s
.56512 .35233 m
.56507 .35395 L
s
.60053 .36426 m
.60665 .35943 L
s
.54389 .38777 m
.54396 .38945 L
s
.57674 .33205 m
.57654 .33366 L
s
.57082 .36347 m
.57232 .36423 L
s
.51123 .36308 m
.5126 .36413 L
s
.54884 .36319 m
.55026 .3641 L
s
.59586 .36347 m
.59745 .36406 L
s
.5548 .37164 m
.55489 .37326 L
s
0 g
.5 Mabswid
.46857 .29803 m
.49878 .2879 L
s
.46857 .29803 m
.46329 .31258 L
s
.039 .916 .04 r
1 Mabswid
.56507 .35395 m
.56503 .35555 L
s
.52964 .36264 m
.53101 .36365 L
s
.57654 .33366 m
.57636 .33527 L
s
.50433 .36355 m
.51209 .35985 L
s
.56935 .3627 m
.57082 .36347 L
s
.59428 .36286 m
.59586 .36347 L
s
.54396 .38945 m
.54403 .39112 L
s
.54744 .36227 m
.54884 .36319 L
s
.55489 .37326 m
.555 .37486 L
s
.57636 .33527 m
.57619 .33687 L
s
.59273 .36224 m
.59428 .36286 L
s
.56503 .35555 m
.56502 .35714 L
s
.56789 .36191 m
.56935 .3627 L
s
.52827 .36162 m
.52964 .36264 L
s
.54403 .39112 m
.5441 .3928 L
s
.54606 .36133 m
.54744 .36227 L
s
.59119 .3616 m
.59273 .36224 L
s
.57619 .33687 m
.57604 .33846 L
s
.555 .37486 m
.55513 .37645 L
s
.56502 .35714 m
.56502 .35873 L
s
.56645 .36111 m
.56789 .36191 L
s
.52691 .36059 m
.52827 .36162 L
s
.58967 .36096 m
.59119 .3616 L
s
.57604 .33846 m
.57591 .34004 L
s
.5441 .3928 m
.54418 .39447 L
s
.5447 .36038 m
.54606 .36133 L
s
.56502 .35873 m
.56503 .3603 L
s
.56503 .3603 m
.56645 .36111 L
s
.55513 .37645 m
.55528 .37804 L
s
.53632 .40505 m
.54387 .40092 L
s
.58817 .3603 m
.58967 .36096 L
s
.5034 .44893 m .54331 .46587 L .51262 .47532 L .544 .324 .532 r
F
.5034 .44893 m .55215 .43372 L .54331 .46587 L F
0 g
.5 Mabswid
.49806 .42179 m
.5034 .44893 L
s
.5034 .44893 m
.51262 .47532 L
s
.039 .916 .04 r
1 Mabswid
.57591 .34004 m
.57579 .34161 L
s
.52555 .35956 m
.52691 .36059 L
s
.54418 .39447 m
.54426 .39614 L
s
.54336 .35941 m
.5447 .36038 L
s
.56503 .3603 m
.56507 .36187 L
s
.56364 .35948 m
.56503 .3603 L
s
.58669 .35963 m
.58817 .3603 L
s
.58547 .32399 m
.59249 .32052 L
s
.55528 .37804 m
.55545 .37961 L
s
.57579 .34161 m
.5757 .34317 L
s
.51209 .35985 m
.51988 .35614 L
s
.58522 .35895 m
.58669 .35963 L
s
.5242 .35853 m
.52555 .35956 L
s
.54426 .39614 m
.54435 .39781 L
s
.56226 .35864 m
.56364 .35948 L
s
.56507 .36187 m
.56513 .36342 L
s
.60665 .35943 m
.61279 .35458 L
s
.54205 .35844 m
.54336 .35941 L
s
.5757 .34317 m
.57561 .34472 L
s
.55545 .37961 m
.55563 .38117 L
s
0 g
.5 Mabswid
.55215 .43372 m
.55709 .40314 L
s
.039 .916 .04 r
1 Mabswid
.58378 .35825 m
.58522 .35895 L
s
.56089 .35779 m
.56226 .35864 L
s
.57561 .34472 m
.57555 .34626 L
s
.56513 .36342 m
.5652 .36496 L
s
.52285 .3575 m
.5242 .35853 L
s
0 g
.5 Mabswid
.51262 .47532 m
.52562 .48615 L
s
.52562 .48615 m
.55615 .47682 L
s
.039 .916 .04 r
1 Mabswid
.54075 .35744 m
.54205 .35844 L
s
.58235 .35754 m
.58378 .35825 L
s
.55563 .38117 m
.55584 .38272 L
s
.58735 .32517 m
.58714 .32671 L
s
.57555 .34626 m
.5755 .34779 L
s
.55955 .35693 m
.56089 .35779 L
s
.5652 .36496 m
.56529 .3665 L
s
.58094 .35682 m
.58235 .35754 L
s
.53947 .35644 m
.54075 .35744 L
s
.54387 .40092 m
.55144 .39678 L
s
.58714 .32671 m
.58696 .32824 L
s
.55584 .38272 m
.55607 .38426 L
s
.5755 .34779 m
.57547 .34932 L
s
.60513 .35641 m
.60663 .35698 L
s
.55823 .35605 m
.55955 .35693 L
s
.57955 .35609 m
.58094 .35682 L
s
.56529 .3665 m
.5654 .36802 L
s
.58696 .32824 m
.58678 .32976 L
s
.60365 .35584 m
.60513 .35641 L
s
.57547 .34932 m
.57546 .35083 L
s
.57818 .35535 m
.57955 .35609 L
s
.55607 .38426 m
.55631 .38579 L
s
.55693 .35516 m
.55823 .35605 L
s
.46952 .35467 m .51818 .33876 L .54023 .35597 L .656 .751 .92 r
F
.039 .916 .04 r
.51988 .35614 m
.52769 .35242 L
s
.53821 .35541 m
.53947 .35644 L
s
0 g
.5 Mabswid
.54023 .35597 m
.55839 .37406 L
s
.039 .916 .04 r
1 Mabswid
.58678 .32976 m
.58663 .33127 L
s
.5654 .36802 m
.56553 .36954 L
s
.60219 .35525 m
.60365 .35584 L
s
.57546 .35083 m
.57546 .35233 L
s
.59249 .32052 m
.59954 .31703 L
s
.53697 .35438 m
.53821 .35541 L
s
.57682 .35459 m
.57818 .35535 L
s
.58663 .33127 m
.58649 .33278 L
s
.60075 .35465 m
.60219 .35525 L
s
.55564 .35425 m
.55693 .35516 L
s
.55631 .38579 m
.55657 .38731 L
s
.56553 .36954 m
.56567 .37104 L
s
.46136 .33266 m .51818 .33876 L .46952 .35467 L .656 .751 .92 r
F
0 g
.5 Mabswid
.46952 .35467 m
.48127 .37505 L
s
.039 .916 .04 r
1 Mabswid
.59932 .35404 m
.60075 .35465 L
s
.57546 .35233 m
.57549 .35382 L
s
.57549 .35382 m
.57682 .35459 L
s
.58649 .33278 m
.58637 .33427 L
s
.61279 .35458 m
.61896 .34972 L
s
.53575 .35333 m
.53697 .35438 L
s
.55438 .35334 m
.55564 .35425 L
s
0 g
.5 Mabswid
.4937 .30244 m
.49878 .2879 L
s
.039 .916 .04 r
1 Mabswid
.59791 .35342 m
.59932 .35404 L
s
.56567 .37104 m
.56584 .37254 L
s
.55657 .38731 m
.55685 .38882 L
s
.58637 .33427 m
.58626 .33576 L
s
.57549 .35382 m
.57552 .35531 L
s
.57417 .35304 m
.57549 .35382 L
s
.55144 .39678 m
.55853 .39182 L
s
.59652 .35279 m
.59791 .35342 L
s
.55313 .35241 m
.55438 .35334 L
s
.53455 .35226 m
.53575 .35333 L
s
.58626 .33576 m
.58617 .33723 L
s
.57287 .35225 m
.57417 .35304 L
s
0 g
.5 Mabswid
.39275 .4772 m
.08393 .57381 L
s
.39277 .47731 m
.08395 .57391 L
s
.039 .916 .04 r
1 Mabswid
.56584 .37254 m
.56602 .37402 L
s
.57552 .35531 m
.57558 .35678 L
s
.55685 .38882 m
.55716 .39032 L
s
.59514 .35214 m
.59652 .35279 L
s
.58617 .33723 m
.5861 .3387 L
s
.52769 .35242 m
.53356 .35041 L
s
.55191 .35146 m
.55313 .35241 L
s
.57159 .35144 m
.57287 .35225 L
s
.57558 .35678 m
.57565 .35825 L
s
.59378 .35149 m
.59514 .35214 L
s
.56602 .37402 m
.56622 .37549 L
s
.5861 .3387 m
.58604 .34016 L
s
.59244 .35082 m
.59378 .35149 L
s
.5507 .35051 m
.55191 .35146 L
s
.57032 .35063 m
.57159 .35144 L
s
.57565 .35825 m
.57574 .3597 L
s
.58604 .34016 m
.586 .34161 L
s
.56622 .37549 m
.56644 .37696 L
s
.59112 .35014 m
.59244 .35082 L
s
.5978 .31988 m
.59761 .32133 L
s
0 g
.5 Mabswid
.85493 .10716 m
.87257 .12968 L
s
.87257 .12968 m
.87257 .12968 L
s
.87257 .12968 m
.87702 .17507 L
s
.039 .916 .04 r
1 Mabswid
.56908 .3498 m
.57032 .35063 L
s
.59954 .31703 m
.60662 .31353 L
s
.54951 .34954 m
.5507 .35051 L
s
.57574 .3597 m
.57585 .36115 L
s
.53356 .35041 m
.54141 .34659 L
s
.586 .34161 m
.58597 .34305 L
s
.58981 .34945 m
.59112 .35014 L
s
.59761 .32133 m
.59743 .32278 L
s
.56644 .37696 m
.56667 .37841 L
s
.61446 .34931 m
.61586 .34984 L
s
.56785 .34895 m
.56908 .3498 L
s
.61896 .34972 m
.62516 .34483 L
s
.55853 .39182 m
.5655 .38662 L
s
.58597 .34305 m
.58597 .34448 L
s
.57585 .36115 m
.57598 .36258 L
s
.54834 .34855 m
.54951 .34954 L
s
.59743 .32278 m
.59727 .32421 L
s
.58852 .34875 m
.58981 .34945 L
s
.61308 .34877 m
.61446 .34931 L
s
.56667 .37841 m
.56693 .37986 L
s
.56664 .3481 m
.56785 .34895 L
s
.59727 .32421 m
.59713 .32564 L
s
.58597 .34448 m
.58597 .3459 L
s
.61171 .34822 m
.61308 .34877 L
s
.58725 .34804 m
.58852 .34875 L
s
.57598 .36258 m
.57612 .36401 L
s
0 g
.5 Mabswid
.54331 .46587 m
.55615 .47682 L
s
.039 .916 .04 r
1 Mabswid
.54719 .34755 m
.54834 .34855 L
s
.59713 .32564 m
.597 .32706 L
s
.61036 .34766 m
.61171 .34822 L
s
.56545 .34723 m
.56664 .3481 L
s
.58597 .3459 m
.586 .34731 L
s
.56693 .37986 m
.5672 .38129 L
s
.586 .34731 m
.58725 .34804 L
s
.57612 .36401 m
.57628 .36543 L
s
.60902 .34709 m
.61036 .34766 L
s
.597 .32706 m
.59689 .32847 L
s
.54606 .34654 m
.54719 .34755 L
s
.586 .34731 m
.58604 .34871 L
s
.58476 .34657 m
.586 .34731 L
s
.56428 .34635 m
.56545 .34723 L
s
.60771 .3465 m
.60902 .34709 L
s
.5672 .38129 m
.56749 .38272 L
s
.59689 .32847 m
.59679 .32987 L
s
0 g
.5 Mabswid
.4937 .30244 m
.46329 .31258 L
s
.039 .916 .04 r
1 Mabswid
.57628 .36543 m
.57646 .36683 L
s
.54141 .34659 m
.54929 .34276 L
s
.58354 .34582 m
.58476 .34657 L
s
.58604 .34871 m
.58609 .35011 L
s
.6064 .34591 m
.60771 .3465 L
s
.59679 .32987 m
.59671 .33126 L
s
.56312 .34545 m
.56428 .34635 L
s
.57646 .36683 m
.57665 .36823 L
s
.60512 .3453 m
.6064 .34591 L
s
.5655 .38662 m
.57249 .3814 L
s
.58234 .34506 m
.58354 .34582 L
s
.58609 .35011 m
.58617 .35149 L
s
.60662 .31353 m
.61374 .31001 L
s
.59671 .33126 m
.59664 .33264 L
s
.56199 .34455 m
.56312 .34545 L
s
.60385 .34468 m
.60512 .3453 L
s
0 g
.5 Mabswid
.54331 .46587 m
.55215 .43372 L
s
.039 .916 .04 r
1 Mabswid
.58115 .34429 m
.58234 .34506 L
s
.57665 .36823 m
.57686 .36962 L
s
.59664 .33264 m
.59659 .33402 L
s
.58617 .35149 m
.58626 .35287 L
s
.62516 .34483 m
.63138 .33992 L
s
.60259 .34406 m
.60385 .34468 L
s
.56087 .34363 m
.56199 .34455 L
s
.59659 .33402 m
.59656 .33538 L
s
.57998 .34351 m
.58115 .34429 L
s
.58626 .35287 m
.58636 .35423 L
s
.57686 .36962 m
.57709 .371 L
s
.60136 .34342 m
.60259 .34406 L
s
.59656 .33538 m
.59654 .33674 L
s
.55977 .3427 m
.56087 .34363 L
s
.60831 .31456 m
.60814 .31593 L
s
.57883 .34271 m
.57998 .34351 L
s
.60013 .34277 m
.60136 .34342 L
s
.58636 .35423 m
.58648 .35559 L
s
.57709 .371 m
.57734 .37237 L
s
.60814 .31593 m
.60798 .31729 L
s
.59654 .33674 m
.59653 .33809 L
s
0 g
.5 Mabswid
.95619 .4002 m
.95347 .42611 L
s
.039 .916 .04 r
1 Mabswid
.59893 .34211 m
.60013 .34277 L
s
.54929 .34276 m
.55719 .33891 L
s
.5777 .3419 m
.57883 .34271 L
s
.55869 .34175 m
.55977 .3427 L
s
.62385 .34217 m
.62516 .34267 L
s
.60798 .31729 m
.60783 .31863 L
s
.58648 .35559 m
.58662 .35694 L
s
0 g
.5 Mabswid
.51262 .47532 m
.54331 .46587 L
s
.49942 .45829 m
.51262 .47532 L
s
.039 .916 .04 r
1 Mabswid
.59653 .33809 m
.59654 .33943 L
s
.57734 .37237 m
.5776 .37373 L
s
.62257 .34166 m
.62385 .34217 L
s
.59774 .34144 m
.59893 .34211 L
s
.57249 .3814 m
.5795 .37616 L
s
.57658 .34108 m
.5777 .3419 L
s
.60783 .31863 m
.6077 .31997 L
s
.55763 .34079 m
.55869 .34175 L
s
.62129 .34115 m
.62257 .34166 L
s
.58662 .35694 m
.58678 .35828 L
s
.59654 .33943 m
.59657 .34076 L
s
.59657 .34076 m
.59774 .34144 L
s
.6077 .31997 m
.60758 .32131 L
s
.5776 .37373 m
.57788 .37508 L
s
.62003 .34062 m
.62129 .34115 L
s
.57548 .34025 m
.57658 .34108 L
s
.61374 .31001 m
.62088 .30648 L
s
.59657 .34076 m
.59661 .34208 L
s
.59541 .34007 m
.59657 .34076 L
s
.58678 .35828 m
.58695 .35961 L
s
.60758 .32131 m
.60748 .32263 L
s
.61879 .34009 m
.62003 .34062 L
s
.5744 .33941 m
.57548 .34025 L
s
.61756 .33954 m
.61879 .34009 L
s
.59427 .33936 m
.59541 .34007 L
s
.60748 .32263 m
.60739 .32394 L
s
.59661 .34208 m
.59667 .34339 L
s
.63138 .33992 m
.63763 .33499 L
s
.58695 .35961 m
.58714 .36093 L
s
.61635 .33898 m
.61756 .33954 L
s
.60739 .32394 m
.60731 .32525 L
s
.57334 .33856 m
.5744 .33941 L
s
.59315 .33865 m
.59427 .33936 L
s
.59667 .34339 m
.59674 .3447 L
s
.61515 .33842 m
.61635 .33898 L
s
.58714 .36093 m
.58734 .36224 L
s
.55719 .33891 m
.56512 .33506 L
s
.60731 .32525 m
.60725 .32655 L
s
.46136 .33266 m .49195 .32255 L .51818 .33876 L .656 .751 .92 r
F
0 g
.5 Mabswid
.49195 .32255 m
.51818 .33876 L
s
.46136 .33266 m
.46329 .31258 L
s
.51818 .33876 m
.54023 .35597 L
s
.46136 .33266 m
.46952 .35467 L
s
.039 .916 .04 r
1 Mabswid
.59204 .33792 m
.59315 .33865 L
s
.57229 .33769 m
.57334 .33856 L
s
.59674 .3447 m
.59683 .34599 L
s
.61397 .33784 m
.61515 .33842 L
s
.60725 .32655 m
.60721 .32784 L
s
.5795 .37616 m
.58653 .3709 L
s
.58734 .36224 m
.58756 .36354 L
s
.59095 .33718 m
.59204 .33792 L
s
.6128 .33725 m
.61397 .33784 L
s
.59683 .34599 m
.59693 .34728 L
s
.57126 .33681 m
.57229 .33769 L
s
.60721 .32784 m
.60718 .32912 L
s
.61165 .33666 m
.6128 .33725 L
s
.58988 .33644 m
.59095 .33718 L
s
.58756 .36354 m
.5878 .36483 L
s
0 g
.5 Mabswid
.49195 .32255 m
.4937 .30244 L
s
.039 .916 .04 r
1 Mabswid
.59693 .34728 m
.59705 .34856 L
s
.60718 .32912 m
.60716 .3304 L
s
.57025 .33592 m
.57126 .33681 L
s
.61052 .33605 m
.61165 .33666 L
s
.58882 .33568 m
.58988 .33644 L
s
.61889 .30921 m
.61873 .31049 L
s
.5878 .36483 m
.58806 .36612 L
s
.60716 .3304 m
.60716 .33166 L
s
.59705 .34856 m
.59718 .34983 L
s
.6094 .33543 m
.61052 .33605 L
s
.62088 .30648 m
.62805 .30293 L
s
.56925 .33502 m
.57025 .33592 L
s
.61873 .31049 m
.61858 .31176 L
s
.58778 .33491 m
.58882 .33568 L
s
.60716 .33166 m
.60717 .33292 L
s
.6333 .33498 m
.63451 .33544 L
s
.60829 .33481 m
.6094 .33543 L
s
.59718 .34983 m
.59733 .35109 L
s
.58806 .36612 m
.58833 .36739 L
s
.61858 .31176 m
.61845 .31302 L
s
.56512 .33506 m
.57308 .33119 L
s
.63763 .33499 m
.64391 .33003 L
s
.63211 .33451 m
.6333 .33498 L
s
.58675 .33413 m
.58778 .33491 L
s
.60717 .33292 m
.6072 .33417 L
s
0 g
.5 Mabswid
.93223 .33482 m
.90955 .30243 L
s
.039 .916 .04 r
1 Mabswid
.6072 .33417 m
.60829 .33481 L
s
.61845 .31302 m
.61833 .31427 L
s
.59733 .35109 m
.5975 .35234 L
s
.63093 .33403 m
.63211 .33451 L
s
.58653 .3709 m
.59359 .36562 L
s
.61833 .31427 m
.61822 .31552 L
s
.6072 .33417 m
.60724 .33541 L
s
.60613 .33352 m
.6072 .33417 L
s
.58574 .33334 m
.58675 .33413 L
s
.62977 .33354 m
.63093 .33403 L
s
.5975 .35234 m
.59768 .35358 L
s
.61822 .31552 m
.61813 .31675 L
s
.62862 .33304 m
.62977 .33354 L
s
.60507 .33286 m
.60613 .33352 L
s
.60724 .33541 m
.6073 .33664 L
s
.58475 .33253 m
.58574 .33334 L
s
.61813 .31675 m
.61805 .31798 L
s
.62748 .33253 m
.62862 .33304 L
s
.60402 .33219 m
.60507 .33286 L
s
.59768 .35358 m
.59788 .35482 L
s
.6073 .33664 m
.60737 .33786 L
s
0 g
.5 Mabswid
.46136 .33266 m
.49195 .32255 L
s
.46136 .33266 m
.46297 .3569 L
s
.039 .916 .04 r
1 Mabswid
.62636 .33202 m
.62748 .33253 L
s
.58377 .33172 m
.58475 .33253 L
s
.61805 .31798 m
.61798 .31921 L
s
.60299 .33152 m
.60402 .33219 L
s
0 g
.5 Mabswid
.53024 .44872 m
.54331 .46587 L
s
.039 .916 .04 r
1 Mabswid
.60737 .33786 m
.60746 .33908 L
s
.62525 .33149 m
.62636 .33202 L
s
.59788 .35482 m
.59809 .35605 L
s
.61798 .31921 m
.61793 .32042 L
s
.58281 .33089 m
.58377 .33172 L
s
.60198 .33083 m
.60299 .33152 L
s
.62416 .33095 m
.62525 .33149 L
s
.61793 .32042 m
.61789 .32163 L
s
.60746 .33908 m
.60756 .34029 L
s
.57308 .33119 m
.58106 .3273 L
s
.59809 .35605 m
.59832 .35726 L
s
.62805 .30293 m
.63526 .29937 L
s
.62308 .33041 m
.62416 .33095 L
s
.58187 .33006 m
.58281 .33089 L
s
.60098 .33013 m
.60198 .33083 L
s
.61789 .32163 m
.61786 .32282 L
s
.60756 .34029 m
.60767 .34149 L
s
.62201 .32985 m
.62308 .33041 L
s
.59359 .36562 m
.60068 .36033 L
s
.59832 .35726 m
.59856 .35847 L
s
.6 .32942 m
.60098 .33013 L
s
.61786 .32282 m
.61785 .32402 L
s
.58094 .32921 m
.58187 .33006 L
s
.64391 .33003 m
.65021 .32506 L
s
.62096 .32929 m
.62201 .32985 L
s
.60767 .34149 m
.6078 .34268 L
s
.61785 .32402 m
.61785 .3252 L
s
.59903 .3287 m
.6 .32942 L
s
.59856 .35847 m
.59882 .35967 L
s
.61993 .32872 m
.62096 .32929 L
s
.62954 .30382 m
.6294 .30501 L
s
.6078 .34268 m
.60795 .34386 L
s
0 g
.5 Mabswid
.487 .43622 m
.49942 .45829 L
s
.49942 .45829 m
.53024 .44872 L
s
.039 .916 .04 r
1 Mabswid
.61785 .3252 m
.61787 .32637 L
s
.6189 .32813 m
.61993 .32872 L
s
.59808 .32797 m
.59903 .3287 L
s
.6294 .30501 m
.62926 .30619 L
s
.60795 .34386 m
.60811 .34504 L
s
.61787 .32637 m
.6179 .32754 L
s
.64281 .32775 m
.64392 .32818 L
s
.6179 .32754 m
.6189 .32813 L
s
.62926 .30619 m
.62914 .30737 L
s
.59714 .32723 m
.59808 .32797 L
s
.64172 .32731 m
.64281 .32775 L
s
.62914 .30737 m
.62903 .30853 L
s
.6179 .32754 m
.61794 .3287 L
s
.6169 .32694 m
.6179 .32754 L
s
.60811 .34504 m
.60828 .3462 L
s
.64063 .32687 m
.64172 .32731 L
s
.58106 .3273 m
.58907 .32341 L
s
.59622 .32648 m
.59714 .32723 L
s
.62903 .30853 m
.62893 .30969 L
s
.61592 .32633 m
.6169 .32694 L
s
.61794 .3287 m
.61799 .32985 L
s
.63956 .32642 m
.64063 .32687 L
s
.60828 .3462 m
.60847 .34736 L
s
.62893 .30969 m
.62884 .31084 L
s
.59531 .32572 m
.59622 .32648 L
s
.6385 .32596 m
.63956 .32642 L
s
.60068 .36033 m
.60779 .35502 L
s
.61496 .3257 m
.61592 .32633 L
s
.61799 .32985 m
.61806 .33099 L
s
.63526 .29937 m
.64249 .29579 L
s
.62884 .31084 m
.62877 .31199 L
s
.63746 .32549 m
.6385 .32596 L
s
.60847 .34736 m
.60867 .34851 L
s
.59442 .32495 m
.59531 .32572 L
s
.61401 .32507 m
.61496 .3257 L
s
.61806 .33099 m
.61815 .33213 L
s
.62877 .31199 m
.62871 .31312 L
s
.63643 .32501 m
.63746 .32549 L
s
.60867 .34851 m
.60889 .34965 L
s
.61307 .32443 m
.61401 .32507 L
s
.65021 .32506 m
.65655 .32006 L
s
.63541 .32452 m
.63643 .32501 L
s
.62871 .31312 m
.62867 .31425 L
s
.59354 .32416 m
.59442 .32495 L
s
.61815 .33213 m
.61825 .33326 L
s
.6344 .32403 m
.63541 .32452 L
s
.61215 .32378 m
.61307 .32443 L
s
.62867 .31425 m
.62863 .31537 L
s
.60889 .34965 m
.60913 .35079 L
s
.59268 .32337 m
.59354 .32416 L
s
.61825 .33326 m
.61836 .33438 L
s
0 g
.5 Mabswid
.87702 .17507 m
.88157 .22153 L
s
.039 .916 .04 r
1 Mabswid
.63341 .32352 m
.6344 .32403 L
s
.62863 .31537 m
.62861 .31649 L
s
.61124 .32312 m
.61215 .32378 L
s
.63243 .32301 m
.63341 .32352 L
s
.60913 .35079 m
.60937 .35191 L
s
.61836 .33438 m
.61848 .33549 L
s
.58907 .32341 m
.59711 .3195 L
s
.62861 .31649 m
.6286 .3176 L
s
0 g
.5 Mabswid
.83893 .09498 m
.85493 .10716 L
s
.039 .916 .04 r
1 Mabswid
.61034 .32246 m
.61124 .32312 L
s
.63147 .32249 m
.63243 .32301 L
s
.61848 .33549 m
.61862 .33659 L
s
.6286 .3176 m
.62861 .3187 L
s
0 g
.5 Mabswid
.49195 .32255 m
.49371 .34685 L
s
.039 .916 .04 r
1 Mabswid
.60779 .35502 m
.61492 .34969 L
s
.63052 .32196 m
.63147 .32249 L
s
.60947 .32178 m
.61034 .32246 L
s
0 g
.5 Mabswid
.46297 .3569 m
.49371 .34685 L
s
.46297 .3569 m
.46806 .38357 L
s
.039 .916 .04 r
1 Mabswid
.62861 .3187 m
.62862 .31979 L
s
.61862 .33659 m
.61877 .33769 L
s
.62958 .32142 m
.63052 .32196 L
s
.64026 .2984 m
.64013 .2995 L
s
.6086 .32109 m
.60947 .32178 L
s
.62862 .31979 m
.62865 .32087 L
s
.62865 .32087 m
.62958 .32142 L
s
.64013 .2995 m
.64 .3006 L
s
.61877 .33769 m
.61894 .33878 L
s
.64249 .29579 m
.64976 .2922 L
s
.60775 .32039 m
.6086 .32109 L
s
.64 .3006 m
.63989 .30168 L
s
.62865 .32087 m
.62869 .32195 L
s
.62774 .32032 m
.62865 .32087 L
s
.65238 .32047 m
.6534 .32086 L
s
.61894 .33878 m
.61912 .33986 L
s
.65138 .32007 m
.65238 .32047 L
s
.63989 .30168 m
.63979 .30276 L
s
.60691 .31968 m
.60775 .32039 L
s
.62684 .31975 m
.62774 .32032 L
s
.62869 .32195 m
.62875 .32302 L
s
.65039 .31966 m
.65138 .32007 L
s
.65655 .32006 m
.66291 .31504 L
s
.63979 .30276 m
.6397 .30383 L
s
0 g
.5 Mabswid
.47627 .41068 m
.487 .43622 L
s
.487 .43622 m
.51788 .42651 L
s
.039 .916 .04 r
1 Mabswid
.61912 .33986 m
.61931 .34094 L
s
.62595 .31918 m
.62684 .31975 L
s
.60609 .31897 m
.60691 .31968 L
s
.64942 .31925 m
.65039 .31966 L
s
.62875 .32302 m
.62882 .32408 L
s
.59711 .3195 m
.60518 .31558 L
s
.6397 .30383 m
.63963 .3049 L
s
.64845 .31883 m
.64942 .31925 L
s
.62508 .3186 m
.62595 .31918 L
s
.61931 .34094 m
.61952 .342 L
s
.62882 .32408 m
.6289 .32514 L
s
.60528 .31824 m
.60609 .31897 L
s
.63963 .3049 m
.63956 .30595 L
s
0 g
.5 Mabswid
.53024 .44872 m
.51788 .42651 L
s
.039 .916 .04 r
1 Mabswid
.6475 .3184 m
.64845 .31883 L
s
.62422 .318 m
.62508 .3186 L
s
.61492 .34969 m
.62207 .34434 L
s
.63956 .30595 m
.63951 .307 L
s
.64656 .31796 m
.6475 .3184 L
s
.6289 .32514 m
.62899 .32619 L
s
.61952 .342 m
.61974 .34306 L
s
.60449 .3175 m
.60528 .31824 L
s
.62338 .3174 m
.62422 .318 L
s
.64563 .31751 m
.64656 .31796 L
s
.63951 .307 m
.63947 .30805 L
s
.62899 .32619 m
.6291 .32723 L
s
.64471 .31706 m
.64563 .31751 L
s
.61974 .34306 m
.61998 .34411 L
s
.63947 .30805 m
.63944 .30908 L
s
.62254 .3168 m
.62338 .3174 L
s
.6291 .32723 m
.62922 .32826 L
s
.64381 .3166 m
.64471 .31706 L
s
.63944 .30908 m
.63942 .31012 L
s
.62172 .31618 m
.62254 .3168 L
s
.64292 .31613 m
.64381 .3166 L
s
.62922 .32826 m
.62935 .32929 L
s
.63942 .31012 m
.63942 .31114 L
s
0 g
.5 Mabswid
.46806 .38357 m
.4989 .37361 L
s
.46806 .38357 m
.47627 .41068 L
s
.039 .916 .04 r
1 Mabswid
.62091 .31555 m
.62172 .31618 L
s
.64204 .31565 m
.64292 .31613 L
s
.64976 .2922 m
.65706 .28859 L
s
.63942 .31114 m
.63942 .31215 L
s
.62935 .32929 m
.6295 .33031 L
s
.64117 .31516 m
.64204 .31565 L
s
.60518 .31558 m
.61327 .31164 L
s
.62012 .31492 m
.62091 .31555 L
s
0 g
.5 Mabswid
.47627 .41068 m
.50716 .40084 L
s
.039 .916 .04 r
1 Mabswid
.63942 .31215 m
.63944 .31316 L
s
.64031 .31467 m
.64117 .31516 L
s
.66291 .31504 m
.66929 .31001 L
s
.6295 .33031 m
.62965 .33132 L
s
.61934 .31427 m
.62012 .31492 L
s
.63944 .31316 m
.63947 .31417 L
s
.63947 .31417 m
.64031 .31467 L
s
.62207 .34434 m
.62926 .33897 L
s
.65105 .29295 m
.65092 .29396 L
s
.62965 .33132 m
.62983 .33232 L
s
.61857 .31362 m
.61934 .31427 L
s
.63947 .31417 m
.63951 .31516 L
s
.63864 .31366 m
.63947 .31417 L
s
.65092 .29396 m
.65081 .29496 L
s
0 g
.5 Mabswid
.95347 .42611 m
.94611 .44207 L
s
.039 .916 .04 r
1 Mabswid
.63782 .31314 m
.63864 .31366 L
s
.62983 .33232 m
.63001 .33332 L
s
.65081 .29496 m
.65071 .29596 L
s
.61782 .31296 m
.61857 .31362 L
s
.63951 .31516 m
.63957 .31615 L
s
.66201 .31314 m
.66293 .3135 L
s
.65071 .29596 m
.65062 .29695 L
s
.66111 .31278 m
.66201 .31314 L
s
.63701 .31261 m
.63782 .31314 L
s
.63957 .31615 m
.63963 .31713 L
s
.61708 .31229 m
.61782 .31296 L
s
.63001 .33332 m
.63021 .33431 L
s
.66022 .31241 m
.66111 .31278 L
s
.65062 .29695 m
.65054 .29793 L
s
.63622 .31208 m
.63701 .31261 L
s
.63963 .31713 m
.63971 .31811 L
s
.65933 .31204 m
.66022 .31241 L
s
.65054 .29793 m
.65048 .29891 L
s
.61635 .31161 m
.61708 .31229 L
s
.63021 .33431 m
.63042 .33529 L
s
.63544 .31154 m
.63622 .31208 L
s
.65846 .31165 m
.65933 .31204 L
s
0 g
.5 Mabswid
.4989 .37361 m
.49371 .34685 L
s
.039 .916 .04 r
1 Mabswid
.65048 .29891 m
.65042 .29988 L
s
.63971 .31811 m
.6398 .31908 L
s
.6576 .31126 m
.65846 .31165 L
s
.61327 .31164 m
.62139 .30769 L
s
.63467 .31099 m
.63544 .31154 L
s
.63042 .33529 m
.63064 .33627 L
s
.65042 .29988 m
.65037 .30085 L
s
.65675 .31086 m
.6576 .31126 L
s
.6398 .31908 m
.6399 .32004 L
s
.65706 .28859 m
.66439 .28496 L
s
.63391 .31043 m
.63467 .31099 L
s
.65037 .30085 m
.65034 .30181 L
s
.65591 .31046 m
.65675 .31086 L
s
.62926 .33897 m
.63646 .33359 L
s
.6399 .32004 m
.64002 .32099 L
s
.65509 .31005 m
.65591 .31046 L
s
.65034 .30181 m
.65031 .30276 L
s
.63316 .30987 m
.63391 .31043 L
s
.65427 .30963 m
.65509 .31005 L
s
.64002 .32099 m
.64014 .32194 L
s
.66929 .31001 m
.67571 .30494 L
s
.65031 .30276 m
.6503 .3037 L
s
.63243 .30929 m
.63316 .30987 L
s
.65346 .3092 m
.65427 .30963 L
s
0 g
.5 Mabswid
.51788 .42651 m
.50716 .40084 L
s
.039 .916 .04 r
1 Mabswid
.6503 .3037 m
.6503 .30464 L
s
.64014 .32194 m
.64028 .32288 L
s
.6317 .30871 m
.63243 .30929 L
s
.65267 .30877 m
.65346 .3092 L
s
.6503 .30464 m
.6503 .30558 L
s
.65189 .30833 m
.65267 .30877 L
s
.64028 .32288 m
.64043 .32382 L
s
.63099 .30812 m
.6317 .30871 L
s
.6503 .30558 m
.65032 .3065 L
s
.65112 .30788 m
.65189 .30833 L
s
.6303 .30752 m
.63099 .30812 L
s
.64043 .32382 m
.64059 .32474 L
s
.65032 .3065 m
.65035 .30742 L
s
.65035 .30742 m
.65112 .30788 L
s
.62139 .30769 m
.62954 .30373 L
s
.62961 .30692 m
.6303 .30752 L
s
.64059 .32474 m
.64076 .32567 L
s
.65035 .30742 m
.6504 .30834 L
s
.6496 .30696 m
.65035 .30742 L
s
.6619 .28746 m
.66179 .28838 L
s
.64886 .30649 m
.6496 .30696 L
s
.62894 .3063 m
.62961 .30692 L
s
.6504 .30834 m
.65045 .30924 L
s
.64076 .32567 m
.64095 .32658 L
s
.66179 .28838 m
.66169 .28929 L
s
.63646 .33359 m
.64369 .32819 L
s
.64814 .30601 m
.64886 .30649 L
s
.65045 .30924 m
.65051 .31014 L
s
.66169 .28929 m
.6616 .2902 L
s
.62828 .30568 m
.62894 .3063 L
s
.64095 .32658 m
.64114 .32749 L
s
.67171 .30577 m
.67252 .30609 L
s
.66439 .28496 m
.67176 .28132 L
s
.64742 .30553 m
.64814 .30601 L
s
0 g
.5 Mabswid
.50716 .40084 m
.4989 .37361 L
s
.039 .916 .04 r
1 Mabswid
.6616 .2902 m
.66152 .2911 L
s
.65051 .31014 m
.65058 .31104 L
s
.6709 .30545 m
.67171 .30577 L
s
.64671 .30504 m
.64742 .30553 L
s
.66152 .2911 m
.66145 .292 L
s
.64114 .32749 m
.64135 .32839 L
s
.6701 .30511 m
.6709 .30545 L
s
.65058 .31104 m
.65067 .31193 L
s
.66931 .30478 m
.6701 .30511 L
s
.66145 .292 m
.66139 .29289 L
s
.64602 .30454 m
.64671 .30504 L
s
.67571 .30494 m
.68215 .29986 L
s
.66853 .30443 m
.66931 .30478 L
s
.65067 .31193 m
.65076 .31281 L
s
.66139 .29289 m
.66134 .29377 L
s
.64534 .30403 m
.64602 .30454 L
s
.66777 .30408 m
.66853 .30443 L
s
.66134 .29377 m
.6613 .29465 L
s
.65076 .31281 m
.65087 .31369 L
s
.66701 .30372 m
.66777 .30408 L
s
.64466 .30352 m
.64534 .30403 L
s
.6613 .29465 m
.66127 .29553 L
s
.62954 .30373 m
.63772 .29975 L
s
.66626 .30336 m
.66701 .30372 L
s
.65087 .31369 m
.65099 .31455 L
s
.644 .303 m
.64466 .30352 L
s
.66127 .29553 m
.66125 .29639 L
s
.66552 .30299 m
.66626 .30336 L
s
.65099 .31455 m
.65112 .31542 L
s
.64335 .30247 m
.644 .303 L
s
.66479 .30261 m
.66552 .30299 L
s
.66125 .29639 m
.66124 .29725 L
s
.64369 .32819 m
.65095 .32276 L
s
.66407 .30223 m
.66479 .30261 L
s
.66124 .29725 m
.66124 .29811 L
s
.64271 .30194 m
.64335 .30247 L
s
0 g
.5 Mabswid
.90955 .30243 m
.88622 .26911 L
s
.039 .916 .04 r
1 Mabswid
.65112 .31542 m
.65126 .31627 L
s
.66337 .30184 m
.66407 .30223 L
s
.66124 .29811 m
.66125 .29896 L
s
.64208 .30139 m
.64271 .30194 L
s
.66267 .30145 m
.66337 .30184 L
s
.65126 .31627 m
.65141 .31712 L
s
.66125 .29896 m
.66127 .2998 L
s
.66198 .30105 m
.66267 .30145 L
s
.64146 .30084 m
.64208 .30139 L
s
.65141 .31712 m
.65157 .31797 L
s
.66127 .2998 m
.6613 .30064 L
s
.6613 .30064 m
.66198 .30105 L
s
.67176 .28132 m
.67915 .27766 L
s
.64086 .30029 m
.64146 .30084 L
s
.65157 .31797 m
.65174 .31881 L
s
.6613 .30064 m
.66134 .30147 L
s
.66063 .30022 m
.6613 .30064 L
s
.64026 .29972 m
.64086 .30029 L
s
.65997 .2998 m
.66063 .30022 L
s
.66134 .30147 m
.66139 .30229 L
s
.65174 .31881 m
.65193 .31964 L
s
.68215 .29986 m
.68862 .29475 L
s
.65932 .29937 m
.65997 .2998 L
s
.63772 .29975 m
.64592 .29576 L
s
.66139 .30229 m
.66145 .30311 L
s
.67283 .28193 m
.67273 .28276 L
s
.65193 .31964 m
.65212 .32046 L
s
.65868 .29894 m
.65932 .29937 L
s
.67273 .28276 m
.67264 .28359 L
s
.66145 .30311 m
.66152 .30393 L
s
.67264 .28359 m
.67256 .28441 L
s
.65806 .2985 m
.65868 .29894 L
s
.65095 .32276 m
.65823 .31732 L
s
.66152 .30393 m
.6616 .30474 L
s
.68146 .29835 m
.68218 .29863 L
s
.67256 .28441 m
.67249 .28522 L
s
.65744 .29805 m
.65806 .2985 L
s
.68075 .29806 m
.68146 .29835 L
s
.67249 .28522 m
.67243 .28603 L
s
.6616 .30474 m
.66169 .30554 L
s
.68005 .29777 m
.68075 .29806 L
s
.65683 .2976 m
.65744 .29805 L
s
.67243 .28603 m
.67238 .28683 L
s
.67936 .29747 m
.68005 .29777 L
s
.66169 .30554 m
.66179 .30634 L
s
.65623 .29714 m
.65683 .2976 L
s
.67238 .28683 m
.67233 .28763 L
s
.67867 .29717 m
.67936 .29747 L
s
.678 .29686 m
.67867 .29717 L
s
.65564 .29667 m
.65623 .29714 L
s
.66179 .30634 m
.6619 .30713 L
s
.67233 .28763 m
.6723 .28842 L
s
0 g
.5 Mabswid
.88622 .26911 m
.88157 .22153 L
s
.039 .916 .04 r
1 Mabswid
.67733 .29654 m
.678 .29686 L
s
.6723 .28842 m
.67227 .28921 L
s
.65506 .2962 m
.65564 .29667 L
s
.6619 .30713 m
.66202 .30791 L
s
.67667 .29622 m
.67733 .29654 L
s
.67227 .28921 m
.67226 .28999 L
s
.67602 .29589 m
.67667 .29622 L
s
.65449 .29572 m
.65506 .2962 L
s
.66202 .30791 m
.66215 .30869 L
s
.67915 .27766 m
.68658 .27399 L
s
.67226 .28999 m
.67225 .29076 L
s
.67538 .29556 m
.67602 .29589 L
s
.64592 .29576 m
.65416 .29175 L
s
.65393 .29523 m
.65449 .29572 L
s
.67475 .29522 m
.67538 .29556 L
s
.66215 .30869 m
.66229 .30946 L
s
.67225 .29076 m
.67225 .29153 L
s
.65338 .29474 m
.65393 .29523 L
s
.67413 .29488 m
.67475 .29522 L
s
.67225 .29153 m
.67226 .2923 L
s
.66229 .30946 m
.66244 .31023 L
s
.67351 .29453 m
.67413 .29488 L
s
.68862 .29475 m
.69512 .28962 L
s
.65284 .29424 m
.65338 .29474 L
s
.67226 .2923 m
.67228 .29306 L
s
.65823 .31732 m
.66554 .31186 L
s
.67291 .29417 m
.67351 .29453 L
s
.66244 .31023 m
.6626 .31099 L
s
.67228 .29306 m
.67231 .29381 L
s
.65231 .29373 m
.65284 .29424 L
s
.67231 .29381 m
.67291 .29417 L
s
.6626 .31099 m
.66277 .31175 L
s
.67231 .29381 m
.67235 .29456 L
s
.67172 .29345 m
.67231 .29381 L
s
.67114 .29307 m
.67172 .29345 L
s
.67235 .29456 m
.6724 .29531 L
s
.66277 .31175 m
.66295 .3125 L
s
.67057 .2927 m
.67114 .29307 L
s
.6724 .29531 m
.67245 .29604 L
s
.67001 .29231 m
.67057 .2927 L
s
.67245 .29604 m
.67252 .29678 L
s
.66946 .29192 m
.67001 .29231 L
s
.68382 .27637 m
.68374 .27711 L
s
.67252 .29678 m
.67259 .29751 L
s
.66892 .29153 m
.66946 .29192 L
s
.68374 .27711 m
.68366 .27785 L
s
.65416 .29175 m
.66242 .28774 L
s
.67259 .29751 m
.67267 .29823 L
s
.68366 .27785 m
.68359 .27858 L
s
.66838 .29113 m
.66892 .29153 L
s
0 g
.5 Mabswid
.82572 .09438 m
.83893 .09498 L
s
.039 .916 .04 r
1 Mabswid
.68359 .27858 m
.68353 .2793 L
s
.66786 .29072 m
.66838 .29113 L
s
.69128 .29088 m
.6919 .29113 L
s
.67267 .29823 m
.67277 .29895 L
s
.68353 .2793 m
.68348 .28002 L
s
.69067 .29063 m
.69128 .29088 L
s
.68658 .27399 m
.69404 .2703 L
s
.66734 .29031 m
.66786 .29072 L
s
.67277 .29895 m
.67287 .29966 L
s
.69006 .29038 m
.69067 .29063 L
s
.66554 .31186 m
.67287 .30638 L
s
.68348 .28002 m
.68343 .28073 L
s
.68946 .29012 m
.69006 .29038 L
s
.66683 .28989 m
.66734 .29031 L
s
.68343 .28073 m
.68339 .28144 L
s
.67287 .29966 m
.67298 .30036 L
s
.68887 .28986 m
.68946 .29012 L
s
.66633 .28947 m
.66683 .28989 L
s
.68339 .28144 m
.68336 .28215 L
s
.68829 .28959 m
.68887 .28986 L
s
.67298 .30036 m
.6731 .30107 L
s
.69512 .28962 m
.70165 .28447 L
s
.68771 .28931 m
.68829 .28959 L
s
.68336 .28215 m
.68334 .28285 L
s
.66584 .28904 m
.66633 .28947 L
s
.68715 .28904 m
.68771 .28931 L
s
.6731 .30107 m
.67323 .30176 L
s
.68334 .28285 m
.68333 .28354 L
s
.66536 .2886 m
.66584 .28904 L
s
.68659 .28875 m
.68715 .28904 L
s
.68333 .28354 m
.68333 .28423 L
s
.68603 .28846 m
.68659 .28875 L
s
.67323 .30176 m
.67337 .30245 L
s
.66489 .28816 m
.66536 .2886 L
s
.68549 .28817 m
.68603 .28846 L
s
.68333 .28423 m
.68333 .28492 L
s
.67337 .30245 m
.67351 .30314 L
s
.68495 .28787 m
.68549 .28817 L
s
.66442 .28771 m
.66489 .28816 L
s
.68333 .28492 m
.68334 .2856 L
s
.68442 .28757 m
.68495 .28787 L
s
.66242 .28774 m
.67071 .2837 L
s
.68334 .2856 m
.68336 .28628 L
s
.67351 .30314 m
.67367 .30382 L
s
.6839 .28726 m
.68442 .28757 L
s
.68336 .28628 m
.68339 .28695 L
s
.68339 .28695 m
.6839 .28726 L
s
.67367 .30382 m
.67383 .30449 L
s
.68339 .28695 m
.68342 .28762 L
s
.68288 .28663 m
.68339 .28695 L
s
.68238 .28631 m
.68288 .28663 L
s
.67287 .30638 m
.68023 .30088 L
s
.68342 .28762 m
.68347 .28828 L
s
.68189 .28598 m
.68238 .28631 L
s
.68347 .28828 m
.68352 .28893 L
s
.68141 .28565 m
.68189 .28598 L
s
.68352 .28893 m
.68358 .28959 L
s
.69404 .2703 m
.70153 .2666 L
s
.68093 .28531 m
.68141 .28565 L
s
.68358 .28959 m
.68365 .29023 L
s
.68046 .28497 m
.68093 .28531 L
s
.68 .28462 m
.68046 .28497 L
s
.68365 .29023 m
.68372 .29088 L
s
.69489 .27078 m
.69481 .27142 L
s
.67955 .28427 m
.68 .28462 L
s
.68372 .29088 m
.68381 .29151 L
s
.70165 .28447 m
.70821 .2793 L
s
.69481 .27142 m
.69475 .27207 L
s
.67911 .28391 m
.67955 .28427 L
s
.68381 .29151 m
.6839 .29215 L
s
.69475 .27207 m
.69469 .27271 L
s
.67867 .28355 m
.67911 .28391 L
s
.69469 .27271 m
.69464 .27334 L
s
.67071 .2837 m
.67903 .27966 L
s
.6839 .29215 m
.684 .29278 L
s
.70116 .28337 m
.70168 .28357 L
s
.67824 .28318 m
.67867 .28355 L
s
.69464 .27334 m
.69459 .27397 L
s
.70064 .28316 m
.70116 .28337 L
s
.684 .29278 m
.68411 .2934 L
s
.69459 .27397 m
.69455 .2746 L
s
.67782 .28281 m
.67824 .28318 L
s
.70013 .28294 m
.70064 .28316 L
s
.69963 .28272 m
.70013 .28294 L
s
.69455 .2746 m
.69452 .27522 L
s
.68411 .2934 m
.68423 .29402 L
s
.6774 .28243 m
.67782 .28281 L
s
.69914 .2825 m
.69963 .28272 L
s
.69452 .27522 m
.6945 .27584 L
s
.68023 .30088 m
.68761 .29537 L
s
.69865 .28227 m
.69914 .2825 L
s
.677 .28205 m
.6774 .28243 L
s
.68423 .29402 m
.68435 .29463 L
s
.6945 .27584 m
.69448 .27645 L
s
.69816 .28204 m
.69865 .28227 L
s
.6766 .28166 m
.677 .28205 L
s
.69769 .28181 m
.69816 .28204 L
s
.69448 .27645 m
.69447 .27706 L
s
.68435 .29463 m
.68448 .29524 L
s
.69721 .28157 m
.69769 .28181 L
s
.69447 .27706 m
.69447 .27767 L
s
.69675 .28132 m
.69721 .28157 L
s
.68448 .29524 m
.68462 .29585 L
s
.69447 .27767 m
.69447 .27827 L
s
.69629 .28108 m
.69675 .28132 L
s
.69584 .28082 m
.69629 .28108 L
s
.69447 .27827 m
.69448 .27886 L
s
.68462 .29585 m
.68477 .29645 L
s
0 g
.5 Mabswid
.94611 .44207 m
.93442 .4466 L
s
.039 .916 .04 r
1 Mabswid
.6954 .28057 m
.69584 .28082 L
s
.69448 .27886 m
.6945 .27946 L
s
.69496 .28031 m
.6954 .28057 L
s
.70153 .2666 m
.70906 .26288 L
s
.6945 .27946 m
.69453 .28004 L
s
.69453 .28004 m
.69496 .28031 L
s
.69453 .28004 m
.69456 .28063 L
s
.6941 .27977 m
.69453 .28004 L
s
.69368 .2795 m
.6941 .27977 L
s
.69456 .28063 m
.6946 .28121 L
s
.67903 .27966 m
.68738 .2756 L
s
.69327 .27923 m
.69368 .2795 L
s
.6946 .28121 m
.69465 .28178 L
s
.70821 .2793 m
.7148 .2741 L
s
.69287 .27894 m
.69327 .27923 L
s
.69465 .28178 m
.6947 .28235 L
s
.69247 .27866 m
.69287 .27894 L
s
.69208 .27837 m
.69247 .27866 L
s
.6947 .28235 m
.69476 .28292 L
s
.68761 .29537 m
.69502 .28983 L
s
.69169 .27808 m
.69208 .27837 L
s
.69476 .28292 m
.69483 .28348 L
s
.69131 .27778 m
.69169 .27808 L
s
.69483 .28348 m
.69491 .28404 L
s
.69094 .27748 m
.69131 .27778 L
s
.69491 .28404 m
.69499 .28459 L
s
.69057 .27717 m
.69094 .27748 L
s
.69499 .28459 m
.69508 .28514 L
s
.69021 .27686 m
.69057 .27717 L
s
.70603 .26514 m
.70596 .2657 L
s
.68986 .27655 m
.69021 .27686 L
s
.70596 .2657 m
.70591 .26625 L
s
.69508 .28514 m
.69518 .28569 L
s
.70591 .26625 m
.70586 .2668 L
s
.68951 .27623 m
.68986 .27655 L
s
.69518 .28569 m
.69528 .28623 L
s
.70586 .2668 m
.70581 .26735 L
s
.68917 .27591 m
.68951 .27623 L
s
.70581 .26735 m
.70578 .26789 L
s
.69528 .28623 m
.69539 .28677 L
s
.7111 .2758 m
.71153 .27597 L
s
.68883 .27558 m
.68917 .27591 L
s
.70578 .26789 m
.70574 .26842 L
s
.71069 .27563 m
.7111 .2758 L
s
.69539 .28677 m
.69551 .2873 L
s
.71027 .27546 m
.71069 .27563 L
s
.68738 .2756 m
.69575 .27152 L
s
.70574 .26842 m
.70572 .26896 L
s
.70987 .27528 m
.71027 .27546 L
s
.70906 .26288 m
.71662 .25914 L
s
.70572 .26896 m
.7057 .26949 L
s
.70946 .2751 m
.70987 .27528 L
s
.69551 .2873 m
.69564 .28783 L
s
.70907 .27491 m
.70946 .2751 L
s
.7057 .26949 m
.70569 .27002 L
s
.70868 .27472 m
.70907 .27491 L
s
.69564 .28783 m
.69577 .28836 L
s
.70569 .27002 m
.70568 .27054 L
s
.70829 .27453 m
.70868 .27472 L
s
.70791 .27434 m
.70829 .27453 L
s
.70568 .27054 m
.70568 .27106 L
s
.69502 .28983 m
.70245 .28428 L
s
.70753 .27414 m
.70791 .27434 L
s
.70568 .27106 m
.70568 .27157 L
s
.70716 .27394 m
.70753 .27414 L
s
.7148 .2741 m
.72141 .26888 L
s
.70568 .27157 m
.70569 .27208 L
s
.7068 .27373 m
.70716 .27394 L
s
.70644 .27352 m
.7068 .27373 L
s
.70569 .27208 m
.70571 .27259 L
s
.70608 .27331 m
.70644 .27352 L
s
.70571 .27259 m
.70574 .2731 L
s
.70574 .2731 m
.70608 .27331 L
s
.70574 .2731 m
.70577 .2736 L
s
.70539 .27288 m
.70574 .2731 L
s
.70505 .27266 m
.70539 .27288 L
s
.70577 .2736 m
.7058 .27409 L
s
.70472 .27243 m
.70505 .27266 L
s
.7058 .27409 m
.70584 .27459 L
s
.70439 .2722 m
.70472 .27243 L
s
.70407 .27197 m
.70439 .2722 L
s
.70584 .27459 m
.70589 .27508 L
s
.70375 .27174 m
.70407 .27197 L
s
.70589 .27508 m
.70595 .27556 L
s
.70344 .2715 m
.70375 .27174 L
s
.70595 .27556 m
.70601 .27605 L
s
.69575 .27152 m
.70416 .26743 L
s
.70313 .27126 m
.70344 .2715 L
s
.70601 .27605 m
.70607 .27652 L
s
.70283 .27101 m
.70313 .27126 L
s
.70254 .27076 m
.70283 .27101 L
s
.70607 .27652 m
.70615 .277 L
s
.70224 .27051 m
.70254 .27076 L
s
.70615 .277 m
.70622 .27747 L
s
.70196 .27025 m
.70224 .27051 L
s
.70622 .27747 m
.70631 .27794 L
s
.70245 .28428 m
.70991 .2787 L
s
.70168 .27 m
.70196 .27025 L
s
.71662 .25914 m
.72421 .25538 L
s
.7014 .26973 m
.70168 .27 L
s
.70631 .27794 m
.7064 .2784 L
s
.70113 .26947 m
.7014 .26973 L
s
.7064 .2784 m
.7065 .27886 L
s
.71724 .25947 m
.71719 .25994 L
s
.7065 .27886 m
.7066 .27932 L
s
.71719 .25994 m
.71714 .2604 L
s
0 g
.5 Mabswid
.89099 .31784 m
.88622 .26911 L
s
.88622 .26911 m
.86221 .23481 L
s
.039 .916 .04 r
1 Mabswid
.71714 .2604 m
.7171 .26086 L
s
.7066 .27932 m
.70671 .27977 L
s
.72141 .26888 m
.72806 .26364 L
s
.7171 .26086 m
.71706 .26131 L
s
.71706 .26131 m
.71703 .26176 L
s
.70671 .27977 m
.70683 .28022 L
s
.71703 .26176 m
.71701 .26221 L
s
.72111 .26819 m
.72144 .26832 L
s
.71701 .26221 m
.71699 .26266 L
s
.72079 .26806 m
.72111 .26819 L
s
.72048 .26792 m
.72079 .26806 L
s
.71699 .26266 m
.71697 .2631 L
s
.72017 .26779 m
.72048 .26792 L
s
.71986 .26765 m
.72017 .26779 L
s
.71697 .2631 m
.71696 .26354 L
s
.71956 .2675 m
.71986 .26765 L
s
.71696 .26354 m
.71696 .26398 L
s
.71926 .26736 m
.71956 .2675 L
s
.70416 .26743 m
.71259 .26333 L
s
.71896 .26721 m
.71926 .26736 L
s
.71696 .26398 m
.71696 .26441 L
s
.71867 .26706 m
.71896 .26721 L
s
.71696 .26441 m
.71696 .26484 L
s
.71838 .26691 m
.71867 .26706 L
s
.7181 .26675 m
.71838 .26691 L
s
.71696 .26484 m
.71697 .26526 L
s
.71782 .2666 m
.7181 .26675 L
s
.71755 .26644 m
.71782 .2666 L
s
.71697 .26526 m
.71699 .26569 L
s
.71728 .26627 m
.71755 .26644 L
s
.71699 .26569 m
.71701 .26611 L
s
.71701 .26611 m
.71728 .26627 L
s
.70991 .2787 m
.7174 .27311 L
s
.71701 .26611 m
.71704 .26653 L
s
.71675 .26594 m
.71701 .26611 L
s
.71649 .26577 m
.71675 .26594 L
s
.71704 .26653 m
.71707 .26694 L
s
.71623 .2656 m
.71649 .26577 L
s
.71707 .26694 m
.7171 .26735 L
s
.71598 .26542 m
.71623 .2656 L
s
.71574 .26524 m
.71598 .26542 L
s
.7171 .26735 m
.71714 .26776 L
s
.7155 .26506 m
.71574 .26524 L
s
.71714 .26776 m
.71719 .26817 L
s
.71526 .26488 m
.7155 .26506 L
s
.72421 .25538 m
.73184 .25161 L
s
.71502 .26469 m
.71526 .26488 L
s
.71719 .26817 m
.71724 .26857 L
s
.71479 .26451 m
.71502 .26469 L
s
.71724 .26857 m
.7173 .26897 L
s
.71457 .26432 m
.71479 .26451 L
s
.71435 .26412 m
.71457 .26432 L
s
.7173 .26897 m
.71736 .26936 L
s
.71413 .26393 m
.71435 .26412 L
s
.71736 .26936 m
.71743 .26976 L
s
.71391 .26373 m
.71413 .26393 L
s
.71743 .26976 m
.7175 .27015 L
s
.71371 .26353 m
.71391 .26373 L
s
.72806 .26364 m
.73474 .25837 L
s
.7135 .26332 m
.71371 .26353 L
s
.7175 .27015 m
.71758 .27053 L
s
.71259 .26333 m
.72106 .25921 L
s
.71758 .27053 m
.71766 .27092 L
s
.71766 .27092 m
.71775 .2713 L
s
.71775 .2713 m
.71784 .27167 L
s
.71784 .27167 m
.71794 .27205 L
s
.7174 .27311 m
.72491 .26749 L
s
.72852 .25377 m
.72848 .25414 L
s
.72848 .25414 m
.72844 .25451 L
s
.72844 .25451 m
.72841 .25488 L
s
.72841 .25488 m
.72838 .25524 L
s
.72838 .25524 m
.72836 .2556 L
s
.72836 .2556 m
.72834 .25596 L
s
.72834 .25596 m
.72833 .25632 L
s
.73119 .26052 m
.73141 .26061 L
s
.72833 .25632 m
.72831 .25667 L
s
.73097 .26043 m
.73119 .26052 L
s
.73075 .26034 m
.73097 .26043 L
s
.72831 .25667 m
.72831 .25702 L
s
.73053 .26024 m
.73075 .26034 L
s
.73032 .26015 m
.73053 .26024 L
s
.72831 .25702 m
.7283 .25737 L
s
.73011 .26005 m
.73032 .26015 L
s
.7299 .25995 m
.73011 .26005 L
s
.7283 .25737 m
.72831 .25772 L
s
.7297 .25985 m
.7299 .25995 L
s
.72831 .25772 m
.72831 .25806 L
s
.7295 .25974 m
.7297 .25985 L
s
.73184 .25161 m
.7395 .24782 L
s
.7293 .25964 m
.7295 .25974 L
s
.72831 .25806 m
.72832 .2584 L
s
.72911 .25953 m
.7293 .25964 L
s
.72891 .25942 m
.72911 .25953 L
s
.72832 .2584 m
.72833 .25874 L
s
.72872 .25931 m
.72891 .25942 L
s
.72854 .25919 m
.72872 .25931 L
s
.72833 .25874 m
.72835 .25908 L
s
.72106 .25921 m
.72955 .25508 L
s
.72835 .25908 m
.72854 .25919 L
s
.72835 .25908 m
.72837 .25941 L
s
.72817 .25896 m
.72835 .25908 L
s
.72799 .25885 m
.72817 .25896 L
s
.72837 .25941 m
.7284 .25975 L
s
.72782 .25872 m
.72799 .25885 L
s
.72764 .2586 m
.72782 .25872 L
s
.7284 .25975 m
.72843 .26007 L
s
.72747 .25848 m
.72764 .2586 L
s
.72731 .25835 m
.72747 .25848 L
s
.72843 .26007 m
.72846 .2604 L
s
.73474 .25837 m
.74144 .25308 L
s
.72714 .25823 m
.72731 .25835 L
s
.72846 .2604 m
.7285 .26073 L
s
.72698 .2581 m
.72714 .25823 L
s
.72682 .25797 m
.72698 .2581 L
s
.7285 .26073 m
.72854 .26105 L
s
.72667 .25783 m
.72682 .25797 L
s
.72491 .26749 m
.73245 .26186 L
s
.72854 .26105 m
.72859 .26137 L
s
.72651 .2577 m
.72667 .25783 L
s
.72636 .25756 m
.72651 .2577 L
s
.72859 .26137 m
.72864 .26168 L
s
.72622 .25743 m
.72636 .25756 L
s
.72607 .25729 m
.72622 .25743 L
s
.72864 .26168 m
.7287 .262 L
s
.72593 .25714 m
.72607 .25729 L
s
.7287 .262 m
.72876 .26231 L
s
0 g
.5 Mabswid
.81632 .1059 m
.82572 .09438 L
s
.039 .916 .04 r
1 Mabswid
.72876 .26231 m
.72882 .26262 L
s
.72882 .26262 m
.72889 .26292 L
s
.72889 .26292 m
.72896 .26323 L
s
.72896 .26323 m
.72903 .26353 L
s
.72903 .26353 m
.72911 .26383 L
s
.72955 .25508 m
.73808 .25094 L
s
.7395 .24782 m
.7472 .24402 L
s
.73988 .24802 m
.73985 .2483 L
s
.73985 .2483 m
.73982 .24858 L
s
.73982 .24858 m
.7398 .24885 L
s
.73245 .26186 m
.74002 .2562 L
s
.7398 .24885 m
.73978 .24913 L
s
.73978 .24913 m
.73976 .2494 L
s
.73976 .2494 m
.73975 .24967 L
s
.73975 .24967 m
.73974 .24994 L
s
.73974 .24994 m
.73973 .2502 L
s
.74144 .25308 m
.74818 .24776 L
s
.73973 .2502 m
.73972 .25047 L
s
.73972 .25047 m
.73972 .25073 L
s
.74133 .25281 m
.74145 .25286 L
s
.74121 .25276 m
.74133 .25281 L
s
.74109 .25271 m
.74121 .25276 L
s
.73972 .25073 m
.73972 .25099 L
s
.74097 .25266 m
.74109 .25271 L
s
.74085 .2526 m
.74097 .25266 L
s
.74073 .25255 m
.74085 .2526 L
s
.73972 .25099 m
.73973 .25125 L
s
.74062 .25249 m
.74073 .25255 L
s
.74051 .25243 m
.74062 .25249 L
s
.73973 .25125 m
.73974 .2515 L
s
.74039 .25238 m
.74051 .25243 L
s
.74029 .25232 m
.74039 .25238 L
s
.74018 .25226 m
.74029 .25232 L
s
.73974 .2515 m
.73975 .25176 L
s
.74007 .2522 m
.74018 .25226 L
s
.73997 .25214 m
.74007 .2522 L
s
.73975 .25176 m
.73976 .25201 L
s
.73986 .25207 m
.73997 .25214 L
s
.73976 .25201 m
.73986 .25207 L
s
.73976 .25201 m
.73978 .25226 L
s
.73966 .25194 m
.73976 .25201 L
s
.73956 .25188 m
.73966 .25194 L
s
.73947 .25181 m
.73956 .25188 L
s
.73978 .25226 m
.7398 .25251 L
s
.73937 .25174 m
.73947 .25181 L
s
.73928 .25167 m
.73937 .25174 L
s
.7398 .25251 m
.73982 .25275 L
s
.73918 .25161 m
.73928 .25167 L
s
.73909 .25153 m
.73918 .25161 L
s
.73982 .25275 m
.73985 .253 L
s
.739 .25146 m
.73909 .25153 L
s
.73892 .25139 m
.739 .25146 L
s
.73985 .253 m
.73988 .25324 L
s
.73883 .25132 m
.73892 .25139 L
s
.73875 .25124 m
.73883 .25132 L
s
.73866 .25117 m
.73875 .25124 L
s
.73988 .25324 m
.73991 .25348 L
s
.73858 .25109 m
.73866 .25117 L
s
.7385 .25101 m
.73858 .25109 L
s
.73991 .25348 m
.73995 .25372 L
s
.73843 .25093 m
.7385 .25101 L
s
.73808 .25094 m
.74663 .24678 L
s
.73995 .25372 m
.73998 .25396 L
s
.73998 .25396 m
.74003 .25419 L
s
.74003 .25419 m
.74007 .25443 L
s
.74007 .25443 m
.74012 .25466 L
s
.74012 .25466 m
.74017 .25489 L
s
.74017 .25489 m
.74023 .25512 L
s
.74023 .25512 m
.74028 .25534 L
s
.74028 .25534 m
.74034 .25557 L
s
.74002 .2562 m
.74761 .25053 L
s
.7472 .24402 m
.75493 .2402 L
s
.74818 .24776 m
.75522 .2426 L
s
.74663 .24678 m
.75494 .24243 L
s
0 g
.5 Mabswid
.93442 .4466 m
.91903 .43887 L
s
.039 .916 .04 r
1 Mabswid
.75131 .24224 m
.75129 .24243 L
s
.75129 .24243 m
.75127 .24261 L
s
.75127 .24261 m
.75126 .2428 L
s
.75126 .2428 m
.75125 .24298 L
s
.75125 .24298 m
.75123 .24316 L
s
.75123 .24316 m
.75123 .24334 L
s
.75123 .24334 m
.75122 .24352 L
s
.75122 .24352 m
.75121 .24369 L
s
.75121 .24369 m
.75121 .24387 L
s
.75121 .24387 m
.75121 .24404 L
s
.75121 .24404 m
.75121 .24422 L
s
.74761 .25053 m
.75523 .24483 L
s
.75121 .24422 m
.75122 .24439 L
s
.75122 .24439 m
.75122 .24456 L
s
.75122 .24456 m
.75123 .24473 L
s
.75154 .24505 m
.75156 .24506 L
s
.75151 .24504 m
.75154 .24505 L
s
.75149 .24503 m
.75151 .24504 L
s
.75147 .24502 m
.75149 .24503 L
s
.75144 .24501 m
.75147 .24502 L
s
.75142 .245 m
.75144 .24501 L
s
.7514 .24499 m
.75142 .245 L
s
.75123 .24473 m
.75124 .24489 L
s
.75138 .24498 m
.7514 .24499 L
s
.75136 .24496 m
.75138 .24498 L
s
.75134 .24495 m
.75136 .24496 L
s
.75132 .24494 m
.75134 .24495 L
s
.7513 .24493 m
.75132 .24494 L
s
.75128 .24492 m
.7513 .24493 L
s
.75126 .24491 m
.75128 .24492 L
s
.75124 .24489 m
.75126 .24491 L
s
.75124 .24489 m
.75125 .24506 L
s
.75122 .24488 m
.75124 .24489 L
s
.7512 .24487 m
.75122 .24488 L
s
.75118 .24486 m
.7512 .24487 L
s
.75116 .24484 m
.75118 .24486 L
s
.75115 .24483 m
.75116 .24484 L
s
.75113 .24482 m
.75115 .24483 L
s
.75111 .2448 m
.75113 .24482 L
s
.7511 .24479 m
.75111 .2448 L
s
.75125 .24506 m
.75126 .24523 L
s
.75108 .24478 m
.7511 .24479 L
s
.75106 .24476 m
.75108 .24478 L
s
.75105 .24475 m
.75106 .24476 L
s
.75103 .24473 m
.75105 .24475 L
s
.75102 .24472 m
.75103 .24473 L
s
.751 .2447 m
.75102 .24472 L
s
.75099 .24469 m
.751 .2447 L
s
.75126 .24523 m
.75128 .24539 L
s
.75128 .24539 m
.7513 .24555 L
s
.7513 .24555 m
.75132 .24572 L
s
.75132 .24572 m
.75134 .24588 L
s
.75134 .24588 m
.75137 .24603 L
s
.75137 .24603 m
.75139 .24619 L
s
.75139 .24619 m
.75142 .24635 L
s
.75142 .24635 m
.75145 .2465 L
s
.75493 .2402 m
.76269 .23636 L
s
.75145 .2465 m
.75148 .24666 L
s
.75148 .24666 m
.75152 .24681 L
s
.75152 .24681 m
.75156 .24696 L
s
.75156 .24696 m
.75159 .24711 L
s
.75159 .24711 m
.75164 .24726 L
s
.75522 .2426 m
.76383 .23841 L
s
.75494 .24243 m
.76174 .23706 L
s
.75523 .24483 m
.76288 .23912 L
s
0 g
.5 Mabswid
.89588 .36776 m
.89099 .31784 L
s
.039 .916 .04 r
1 Mabswid
.76269 .23636 m
.77049 .2325 L
s
.76357 .23836 m
.76361 .23841 L
s
.76383 .23841 m
.77248 .23421 L
s
.76282 .23642 m
.76281 .23651 L
s
.76281 .23651 m
.7628 .23661 L
s
.76352 .23832 m
.76357 .23836 L
s
.7628 .23661 m
.76279 .2367 L
s
.76347 .23827 m
.76352 .23832 L
s
.76279 .2367 m
.76279 .23679 L
s
.76342 .23822 m
.76347 .23827 L
s
.76279 .23679 m
.76278 .23688 L
s
.76336 .23817 m
.76342 .23822 L
s
.76278 .23688 m
.76278 .23697 L
s
.76331 .23813 m
.76336 .23817 L
s
.76278 .23697 m
.76277 .23705 L
s
.76326 .23808 m
.76331 .23813 L
s
.76277 .23705 m
.76277 .23714 L
s
.7632 .23804 m
.76326 .23808 L
s
.76277 .23714 m
.76277 .23723 L
s
.76314 .23799 m
.7632 .23804 L
s
.76277 .23723 m
.76277 .23732 L
s
.76309 .23795 m
.76314 .23799 L
s
.76277 .23732 m
.76277 .2374 L
s
.76303 .2379 m
.76309 .23795 L
s
.76277 .2374 m
.76277 .23749 L
s
.76297 .23786 m
.76303 .2379 L
s
.76277 .23749 m
.76278 .23757 L
s
.76291 .23782 m
.76297 .23786 L
s
.76278 .23757 m
.76278 .23765 L
s
.76285 .23778 m
.76291 .23782 L
s
.76278 .23765 m
.76279 .23774 L
s
.76279 .23774 m
.76285 .23778 L
s
.76279 .23774 m
.76279 .23782 L
s
.76272 .2377 m
.76279 .23774 L
s
.76266 .23766 m
.76272 .2377 L
s
.76279 .23782 m
.7628 .2379 L
s
.76259 .23762 m
.76266 .23766 L
s
.7628 .2379 m
.76281 .23798 L
s
.76253 .23758 m
.76259 .23762 L
s
.76281 .23798 m
.76282 .23806 L
s
.76246 .23754 m
.76253 .23758 L
s
.76239 .23751 m
.76246 .23754 L
s
.76282 .23806 m
.76283 .23814 L
s
.76232 .23747 m
.76239 .23751 L
s
.76283 .23814 m
.76284 .23822 L
s
.76225 .23743 m
.76232 .23747 L
s
.76218 .2374 m
.76225 .23743 L
s
.76284 .23822 m
.76285 .2383 L
s
.76211 .23736 m
.76218 .2374 L
s
.76285 .2383 m
.76286 .23838 L
s
.76204 .23733 m
.76211 .23736 L
s
.76196 .2373 m
.76204 .23733 L
s
.76286 .23838 m
.76288 .23846 L
s
.76189 .23726 m
.76196 .2373 L
s
.76288 .23846 m
.76289 .23854 L
s
.76181 .23723 m
.76189 .23726 L
s
.76173 .2372 m
.76181 .23723 L
s
.76289 .23854 m
.76291 .23861 L
s
.76291 .23861 m
.76293 .23869 L
s
.76293 .23869 m
.76295 .23876 L
s
.76174 .23706 m
.76857 .23168 L
s
.76295 .23876 m
.76297 .23884 L
s
.76297 .23884 m
.76299 .23891 L
s
.76288 .23912 m
.77055 .23339 L
s
0 g
.5 Mabswid
.86221 .23481 m
.83749 .1995 L
s
.039 .916 .04 r
1 Mabswid
.77248 .23421 m
.78115 .22999 L
s
.77049 .2325 m
.77825 .22763 L
s
.77055 .23339 m
.77833 .22863 L
s
.7762 .23199 m
.77631 .2321 L
s
.77608 .23188 m
.7762 .23199 L
s
.77597 .23177 m
.77608 .23188 L
s
.77585 .23166 m
.77597 .23177 L
s
.76857 .23168 m
.77543 .22627 L
s
.77573 .23155 m
.77585 .23166 L
s
.77561 .23144 m
.77573 .23155 L
s
.77548 .23133 m
.77561 .23144 L
s
.77536 .23123 m
.77548 .23133 L
s
.77523 .23113 m
.77536 .23123 L
s
.7751 .23102 m
.77523 .23113 L
s
.77496 .23092 m
.7751 .23102 L
s
.77483 .23083 m
.77496 .23092 L
s
.77469 .23073 m
.77483 .23083 L
s
.77455 .23063 m
.77469 .23073 L
s
.7744 .23054 m
.77455 .23063 L
s
.7744 .23051 m
.7744 .23052 L
s
.7744 .23052 m
.7744 .23052 L
s
.7744 .23052 m
.7744 .23052 L
s
.7744 .23052 m
.7744 .23052 L
s
.7744 .23052 m
.7744 .23052 L
s
.7744 .23052 m
.7744 .23052 L
s
.7744 .23052 m
.7744 .23052 L
s
.7744 .23052 m
.7744 .23053 L
s
.7744 .23053 m
.7744 .23053 L
s
.7744 .23053 m
.7744 .23053 L
s
.7744 .23053 m
.7744 .23053 L
s
.7744 .23053 m
.7744 .23053 L
s
.7744 .23053 m
.7744 .23053 L
s
.7744 .23053 m
.7744 .23054 L
s
.7744 .23054 m
.7744 .23054 L
s
.7744 .23054 m
.7744 .23054 L
s
.77426 .23044 m
.7744 .23054 L
s
.7744 .23054 m
.7744 .23054 L
s
.7744 .23054 m
.7744 .23054 L
s
.7744 .23054 m
.7744 .23054 L
s
.7744 .23054 m
.7744 .23055 L
s
.7744 .23055 m
.7744 .23055 L
s
.7744 .23055 m
.7744 .23055 L
s
.7744 .23055 m
.7744 .23055 L
s
.7744 .23055 m
.7744 .23055 L
s
.7744 .23055 m
.7744 .23056 L
s
.7744 .23056 m
.7744 .23056 L
s
.7744 .23056 m
.7744 .23056 L
s
.7744 .23056 m
.7744 .23056 L
s
.7744 .23056 m
.7744 .23056 L
s
.7744 .23056 m
.7744 .23056 L
s
.77411 .23035 m
.77426 .23044 L
s
.77396 .23026 m
.77411 .23035 L
s
.77381 .23017 m
.77396 .23026 L
s
.77365 .23009 m
.77381 .23017 L
s
.77349 .23 m
.77365 .23009 L
s
.77333 .22992 m
.77349 .23 L
s
.78115 .22999 m
.78986 .22575 L
s
.77317 .22983 m
.77333 .22992 L
s
.77301 .22975 m
.77317 .22983 L
s
.77284 .22967 m
.77301 .22975 L
s
.77267 .22959 m
.77284 .22967 L
s
.7725 .22952 m
.77267 .22959 L
s
.77233 .22944 m
.7725 .22952 L
s
.77215 .22937 m
.77233 .22944 L
s
.77197 .22929 m
.77215 .22937 L
s
.77825 .22763 m
.78598 .22186 L
s
.77833 .22863 m
.7862 .22473 L
s
.77543 .22627 m
.78231 .22083 L
s
.7889 .22558 m
.78907 .22576 L
s
.78986 .22575 m
.79859 .2215 L
s
.78872 .2254 m
.7889 .22558 L
s
.78854 .22523 m
.78872 .2254 L
s
.78836 .22505 m
.78854 .22523 L
s
.78817 .22488 m
.78836 .22505 L
s
.78798 .22471 m
.78817 .22488 L
s
.78778 .22455 m
.78798 .22471 L
s
.78758 .22438 m
.78778 .22455 L
s
.78738 .22422 m
.78758 .22438 L
s
.78718 .22406 m
.78738 .22422 L
s
.78598 .22186 m
.79374 .21606 L
s
.78587 .22207 m
.78589 .22215 L
s
.78589 .22215 m
.78591 .22223 L
s
.78697 .2239 m
.78718 .22406 L
s
.78591 .22223 m
.78593 .22231 L
s
.78593 .22231 m
.78595 .22239 L
s
.78595 .22239 m
.78597 .22246 L
s
.78675 .22375 m
.78697 .2239 L
s
.78597 .22246 m
.78599 .22254 L
s
.78599 .22254 m
.786 .22262 L
s
.78654 .22359 m
.78675 .22375 L
s
.786 .22262 m
.78602 .22271 L
s
.78602 .22271 m
.78603 .22279 L
s
.78603 .22279 m
.78604 .22287 L
s
.78631 .22344 m
.78654 .22359 L
s
.78604 .22287 m
.78606 .22295 L
s
.78606 .22295 m
.78607 .22304 L
s
.78607 .22304 m
.78607 .22312 L
s
.78609 .22329 m
.78631 .22344 L
s
.78607 .22312 m
.78608 .22321 L
s
.78608 .22321 m
.78609 .22329 L
s
.78609 .22329 m
.7861 .22338 L
s
.78586 .22315 m
.78609 .22329 L
s
.7861 .22338 m
.7861 .22347 L
s
.7861 .22347 m
.7861 .22356 L
s
.78563 .223 m
.78586 .22315 L
s
.7861 .22356 m
.78611 .22364 L
s
.78611 .22364 m
.78611 .22373 L
s
.78611 .22373 m
.78611 .22382 L
s
.78539 .22286 m
.78563 .223 L
s
.78611 .22382 m
.78611 .22392 L
s
.78611 .22392 m
.78611 .22401 L
s
.78611 .22401 m
.7861 .2241 L
s
.78516 .22272 m
.78539 .22286 L
s
.7861 .2241 m
.7861 .22419 L
s
.7861 .22419 m
.78609 .22429 L
s
.78609 .22429 m
.78609 .22438 L
s
.78491 .22258 m
.78516 .22272 L
s
.78609 .22438 m
.78608 .22447 L
s
.78608 .22447 m
.78607 .22457 L
s
0 g
.5 Mabswid
.81158 .12925 m
.81632 .1059 L
s
.039 .916 .04 r
1 Mabswid
.78607 .22457 m
.78606 .22467 L
s
.78467 .22245 m
.78491 .22258 L
s
.78442 .22232 m
.78467 .22245 L
s
.7862 .22473 m
.7941 .22082 L
s
.78416 .22218 m
.78442 .22232 L
s
.7839 .22206 m
.78416 .22218 L
s
.78364 .22193 m
.7839 .22206 L
s
.78338 .22181 m
.78364 .22193 L
s
.78311 .22168 m
.78338 .22181 L
s
.78284 .22156 m
.78311 .22168 L
s
.78256 .22145 m
.78284 .22156 L
s
.79859 .2215 m
.80736 .21724 L
s
.78228 .22133 m
.78256 .22145 L
s
.78231 .22083 m
.78924 .21537 L
s
.79374 .21606 m
.80152 .21024 L
s
.80167 .21914 m
.8019 .21938 L
s
.80143 .21889 m
.80167 .21914 L
s
.80118 .21865 m
.80143 .21889 L
s
.80093 .21842 m
.80118 .21865 L
s
.80068 .21818 m
.80093 .21842 L
s
.80042 .21795 m
.80068 .21818 L
s
.80015 .21772 m
.80042 .21795 L
s
.79988 .2175 m
.80015 .21772 L
s
.79741 .21359 m
.79745 .21374 L
s
.79745 .21374 m
.79749 .21389 L
s
.79961 .21728 m
.79988 .2175 L
s
.79749 .21389 m
.79753 .21405 L
s
.79753 .21405 m
.79757 .2142 L
s
.79933 .21706 m
.79961 .21728 L
s
.80736 .21724 m
.81616 .21296 L
s
.79757 .2142 m
.79761 .21436 L
s
.79761 .21436 m
.79764 .21452 L
s
.79904 .21684 m
.79933 .21706 L
s
.7941 .22082 m
.80204 .2169 L
s
.79764 .21452 m
.79767 .21468 L
s
.79767 .21468 m
.7977 .21484 L
s
.79875 .21663 m
.79904 .21684 L
s
.7977 .21484 m
.79773 .215 L
s
.79773 .215 m
.79776 .21517 L
s
.79845 .21642 m
.79875 .21663 L
s
.79776 .21517 m
.79778 .21533 L
s
.79778 .21533 m
.7978 .2155 L
s
.79815 .21621 m
.79845 .21642 L
s
.7978 .2155 m
.79782 .21567 L
s
.79782 .21567 m
.79783 .21584 L
s
.79785 .21601 m
.79815 .21621 L
s
.79783 .21584 m
.79785 .21601 L
s
.79785 .21601 m
.79786 .21618 L
s
.79754 .21581 m
.79785 .21601 L
s
.79786 .21618 m
.79787 .21635 L
s
.79722 .21561 m
.79754 .21581 L
s
.79787 .21635 m
.79788 .21653 L
s
.79788 .21653 m
.79788 .2167 L
s
.7969 .21541 m
.79722 .21561 L
s
.79788 .2167 m
.79789 .21688 L
s
.80152 .21024 m
.80934 .2044 L
s
.79789 .21688 m
.79789 .21706 L
s
.79658 .21522 m
.7969 .21541 L
s
.79789 .21706 m
.79789 .21724 L
s
.78924 .21537 m
.79619 .20988 L
s
.79789 .21724 m
.79788 .21742 L
s
.79624 .21503 m
.79658 .21522 L
s
.79788 .21742 m
.79788 .2176 L
s
.79788 .2176 m
.79787 .21779 L
s
.79787 .21779 m
.79786 .21797 L
s
.79591 .21485 m
.79624 .21503 L
s
.79786 .21797 m
.79785 .21816 L
s
.79785 .21816 m
.79784 .21835 L
s
.79557 .21467 m
.79591 .21485 L
s
.79784 .21835 m
.79782 .21854 L
s
.79782 .21854 m
.7978 .21873 L
s
.79522 .21449 m
.79557 .21467 L
s
.79487 .21431 m
.79522 .21449 L
s
.79452 .21414 m
.79487 .21431 L
s
.79415 .21397 m
.79452 .21414 L
s
.79379 .2138 m
.79415 .21397 L
s
.79342 .21364 m
.79379 .2138 L
s
.79304 .21348 m
.79342 .21364 L
s
.79266 .21332 m
.79304 .21348 L
s
.8145 .21266 m
.8148 .21297 L
s
.81616 .21296 m
.82499 .20866 L
s
.8142 .21235 m
.8145 .21266 L
s
0 g
.5 Mabswid
.91903 .43887 m
.90089 .41893 L
s
.039 .916 .04 r
1 Mabswid
.81389 .21204 m
.8142 .21235 L
s
.81357 .21174 m
.81389 .21204 L
s
.81325 .21144 m
.81357 .21174 L
s
.80204 .2169 m
.81002 .21295 L
s
.81292 .21115 m
.81325 .21144 L
s
0 g
.5 Mabswid
.89588 .36776 m
.90089 .41893 L
s
.039 .916 .04 r
1 Mabswid
.80934 .2044 m
.81718 .19855 L
s
.809 .20506 m
.80907 .20529 L
s
.81259 .21086 m
.81292 .21115 L
s
.80907 .20529 m
.80914 .20551 L
s
.80914 .20551 m
.8092 .20574 L
s
.81225 .21057 m
.81259 .21086 L
s
.8092 .20574 m
.80926 .20598 L
s
.8119 .21029 m
.81225 .21057 L
s
.80926 .20598 m
.80931 .20621 L
s
.80931 .20621 m
.80936 .20645 L
s
.81155 .21001 m
.8119 .21029 L
s
.80936 .20645 m
.80941 .20669 L
s
.81119 .20974 m
.81155 .21001 L
s
.80941 .20669 m
.80945 .20693 L
s
.79619 .20988 m
.80317 .20437 L
s
.80945 .20693 m
.8095 .20717 L
s
.81082 .20946 m
.81119 .20974 L
s
.8095 .20717 m
.80953 .20742 L
s
.80953 .20742 m
.80957 .20766 L
s
.81044 .2092 m
.81082 .20946 L
s
.80957 .20766 m
.8096 .20791 L
s
.81006 .20893 m
.81044 .2092 L
s
.8096 .20791 m
.80963 .20817 L
s
.80963 .20817 m
.80966 .20842 L
s
.80968 .20867 m
.81006 .20893 L
s
.80966 .20842 m
.80968 .20867 L
s
.80968 .20867 m
.8097 .20893 L
s
.80929 .20842 m
.80968 .20867 L
s
.82499 .20866 m
.83385 .20435 L
s
.8097 .20893 m
.80971 .20919 L
s
.80889 .20817 m
.80929 .20842 L
s
.80971 .20919 m
.80973 .20945 L
s
.80973 .20945 m
.80973 .20972 L
s
.80848 .20792 m
.80889 .20817 L
s
.80973 .20972 m
.80974 .20998 L
s
.80807 .20768 m
.80848 .20792 L
s
.80974 .20998 m
.80974 .21025 L
s
.80974 .21025 m
.80974 .21052 L
s
.80765 .20744 m
.80807 .20768 L
s
.80974 .21052 m
.80974 .21079 L
s
.80974 .21079 m
.80973 .21107 L
s
.80722 .2072 m
.80765 .20744 L
s
.80973 .21107 m
.80972 .21134 L
s
.80972 .21134 m
.80971 .21162 L
s
.80679 .20697 m
.80722 .2072 L
s
.80971 .21162 m
.80969 .2119 L
s
.80635 .20674 m
.80679 .20697 L
s
.81718 .19855 m
.82504 .19267 L
s
.80969 .2119 m
.80967 .21218 L
s
.80967 .21218 m
.80965 .21247 L
s
.80591 .20651 m
.80635 .20674 L
s
.80965 .21247 m
.80962 .21275 L
s
.82741 .20615 m
.82777 .20653 L
s
.80546 .20629 m
.80591 .20651 L
s
.805 .20608 m
.80546 .20629 L
s
.82704 .20577 m
.82741 .20615 L
s
.80454 .20586 m
.805 .20608 L
s
.81002 .21295 m
.81803 .20899 L
s
.80407 .20566 m
.80454 .20586 L
s
.82667 .2054 m
.82704 .20577 L
s
.80359 .20545 m
.80407 .20566 L
s
.80311 .20525 m
.80359 .20545 L
s
.82629 .20503 m
.82667 .2054 L
s
.8259 .20467 m
.82629 .20503 L
s
.82066 .19648 m
.82075 .19678 L
s
.8255 .20431 m
.8259 .20467 L
s
.82075 .19678 m
.82084 .19709 L
s
.80317 .20437 m
.81019 .19884 L
s
.83385 .20435 m
.84275 .20003 L
s
.8251 .20396 m
.8255 .20431 L
s
.82084 .19709 m
.82092 .19739 L
s
.82092 .19739 m
.821 .1977 L
s
.82469 .20361 m
.8251 .20396 L
s
.821 .1977 m
.82108 .19802 L
s
.82427 .20326 m
.82469 .20361 L
s
.82108 .19802 m
.82115 .19833 L
s
.82115 .19833 m
.82121 .19865 L
s
.82384 .20292 m
.82427 .20326 L
s
.82121 .19865 m
.82127 .19897 L
s
.8234 .20259 m
.82384 .20292 L
s
.82127 .19897 m
.82133 .1993 L
s
.82504 .19267 m
.83294 .18676 L
s
.82133 .1993 m
.82138 .19962 L
s
.82296 .20226 m
.8234 .20259 L
s
.82138 .19962 m
.82143 .19995 L
s
.82251 .20193 m
.82296 .20226 L
s
.82143 .19995 m
.82148 .20028 L
s
.82148 .20028 m
.82151 .20062 L
s
.82205 .20161 m
.82251 .20193 L
s
.82151 .20062 m
.82155 .20096 L
s
.82158 .2013 m
.82205 .20161 L
s
.82155 .20096 m
.82158 .2013 L
s
.82158 .2013 m
.82161 .20164 L
s
.82111 .20099 m
.82158 .2013 L
s
.82161 .20164 m
.82163 .20199 L
s
.82062 .20068 m
.82111 .20099 L
s
.82163 .20199 m
.82165 .20234 L
s
.82165 .20234 m
.82166 .20269 L
s
.82013 .20038 m
.82062 .20068 L
s
.81803 .20899 m
.82609 .20501 L
s
.82166 .20269 m
.82167 .20304 L
s
.81963 .20008 m
.82013 .20038 L
s
.82167 .20304 m
.82167 .2034 L
s
.82167 .2034 m
.82167 .20376 L
s
.81913 .19979 m
.81963 .20008 L
s
.82167 .20376 m
.82167 .20412 L
s
.81861 .1995 m
.81913 .19979 L
s
.82167 .20412 m
.82166 .20449 L
s
.82166 .20449 m
.82165 .20485 L
s
.81809 .19922 m
.81861 .1995 L
s
0 g
.5 Mabswid
.83749 .1995 m
.81203 .16313 L
s
.039 .916 .04 r
1 Mabswid
.82165 .20485 m
.82163 .20522 L
s
.81756 .19894 m
.81809 .19922 L
s
.82163 .20522 m
.82161 .2056 L
s
.82161 .2056 m
.82158 .20598 L
s
.81702 .19867 m
.81756 .19894 L
s
.81019 .19884 m
.81724 .19328 L
s
.82158 .20598 m
.82155 .20635 L
s
.81647 .1984 m
.81702 .19867 L
s
.82155 .20635 m
.82152 .20674 L
s
.81592 .19814 m
.81647 .1984 L
s
.81536 .19788 m
.81592 .19814 L
s
.81479 .19762 m
.81536 .19788 L
s
.81421 .19737 m
.81479 .19762 L
s
.81362 .19713 m
.81421 .19737 L
s
.82609 .20501 m
.83417 .20101 L
s
0 0 0 r
.83356 .19387 m
.83356 .19387 L
s
.039 .916 .04 r
.81724 .19328 m
.82432 .18769 L
s
0 g
.5 Mabswid
.81203 .16313 m
.81158 .12925 L
s
.90089 .41893 m
.88128 .38782 L
s
.90089 .41893 m
.90089 .41893 L
s
.81203 .16313 m
.81203 .16313 L
s
.81783 .20529 m
.81203 .16313 L
s
.88128 .38782 m
.86168 .34763 L
s
.82863 .25259 m
.81783 .20529 L
s
.86168 .34763 m
.84364 .30134 L
s
.84364 .30134 m
.82863 .25259 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[91]:=",
  ImageSize->{288, 213.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000eB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00k?ooool6o`0002kooooo003/ooooo`03o`000?oooooooooo00?ooooo
0_l0000/ooooo`00joooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo003Z
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:?ooool00>[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Xooooo`00j_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02Oooooo003Yooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
9_ooool00>Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Uooooo`00jOooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo003Xooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool09?ooool00>Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Sooooo`00j?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo
003Xooooo`03o`000?oooooooooo00oooooo0_l0000Tooooo`00j?ooool00ol0003oooooooooo`0?
ooooo`;o00009?ooool00>Sooooo00?o0000ooooooooool03oooool00ol0003oooooo`00000Soooo
o`00j?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0002;ooooo003Xooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooo00008_ooool00>Sooooo00?o0000oooooooo
ool04?ooool01?l0003oooooooooool0000Qooooo`00j?ooool00ol0003oooooooooo`0@ooooo`04
o`000?ooooooooooo`00027ooooo003Xooooo`;o00004Oooool01Ol0003ooooooooooooooooo0000
023ooooo003Xooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000Poooo
o`00j?ooool2o`00017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`00
j?ooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7Oooool00>Wooooo00?o0000ooooool000003oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01cooooo003Yooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Looooo`00jOooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06oooool00>Wooooo00Ko0000oooooooooooo2NX:o`000?l9
jPX<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool0077ooooo0_l0001f
ooooo`05o`000?oooooo2NX:ooooool000003Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01_ooooo001^ooooo`?o000000?oooooo`000?ooool0MOooool01Ol0003o2NX:ooooool9
jP[ooooo00;o00002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo001[
ooooo`?o00001?ooool00ol0003oooooooooo`1dooooo`07o`WZ2_l0003o2NX:ooooool0003ooooo
o`00000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool006Sooooo0ol0
0007ooooo`03o`000?oooooooooo07;ooooo0ol9jPX01?l0003o2NX:o`000?ooool2o`WZ2P03o`00
0?l9jP[ooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`00I_oo
ool2o`0000[ooooo00?o0000ooooooooool0LOooool3o`WZ2P;o00001Ol9jPX00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool006?ooooo0ol0000<
ooooo`03o`000?oooooooooo073ooooo1?l9jPX00ooooooo0000o`WZ2P02o`WZ2P?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo001Poooo
o`?o00003oooool00ol0003oooooooooo`1^ooooo`?o2NX:0_l00002o`WZ2P03o`000?l9jP[ooooo
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Sooooo001Mooooo`?o00004_ooool00ol0003oooooooooo`1]ooooo`?o2NX:00?o0000ooooool9
jPX00ol9jPX00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Gooooo`00F_ooool3o`0001Gooooo00?o0000ooooooooool0
K?ooool8o`WZ2P;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05oooool005Sooooo0_l0000Hooooo`03o`000?oo
oooooooo06[ooooo2?l9jPX4ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo001Eooooo`?o00006_ooool0
0ol0003oooooooooo`1Yooooo`03o`WZ2_oooooo2NX:00?o2NX:1oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0F
ooooo`00D_ooool3o`0001gooooo00?o0000ooooooooool0J?ooool3o`WZ2P03ooooool9jP[ooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool05_ooool004oooooo0ol0000Pooooo`03o`000?oooooooooo06Oo
oooo1Ol9jPX;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Gooooo001=ooooo`;o00008oooool00ol0003ooooo
ooooo`1Tooooo`Ko2NX:3Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`00B_ooool3o`0002Gooooo00?o
0000ooooooooool0Hoooool4o`WZ2Q3ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool004Oooooo0ol0000X
ooooo`03o`000?oooooooooo06;ooooo0ol9jPXBooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo0014oooo
o`?o0000:oooool00ol0003oooooooooo`1Pooooo`Co2NX:4oooool00ol0003oooooooooo`0:oooo
o`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0Dooooo`00@_ooool2o`00
02kooooo00?o0000ooooooooool0G_ooool4o`WZ2QKooooo00?o0000ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool04oooool003oooooo0ol0000`oooo
o`03o`000?oooooooooo05_ooooo1_l9jPXGooooo`03o`000?oooooooooo00[ooooo00Co0000oooo
oooooooo00003?ooool00ol0003oooooooooo`0Cooooo`00??ooool3o`0003?ooooo00?o0000oooo
ooooool0FOooool4o`WZ2P03o`000?l9jP[o2NX:01Sooooo00?o0000ooooooooool02oooool00ol0
003oooooo`00000<ooooo`03o`000?oooooooooo01?ooooo000iooooo`?o0000=_ooool00ol0003o
ooooooooo`1Gooooo`So2NX:6Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo000000_o
oooo00?o0000ooooooooool04oooool003Oooooo0_l0000hooooo`;o0000Eoooool4o`WZ2P03o`00
0?oooooo2NX:00;o2NX:6oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000cooooo
00?o0000ooooooooool04_ooool003Cooooo0ol0000jooooo`;o0000EOooool3o`WZ2P03ooooool0
003o2NX:00?o2NX:7Oooool00ol0003oooooooooo`0<ooooo`;o00003?ooool00ol0003ooooooooo
o`0Booooo`00<Oooool3o`0003gooooo0_l0001Cooooo`Go2NX:00Co0000ooooool9jP[o2NX:7ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_oo
ool002kooooo0ol00010ooooo`;o0000D?ooool5o`WZ2P06ooooool9jP[o2NX:o`WZ2_oooooo2NX:
8Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
4_ooool002_ooooo0ol00013ooooo`;o00008?ooool3o`0002_ooooo0_l9jPX00ooooooo2NX:o`WZ
2P02o`WZ2P03o`000?oooooo2NX:00;o2NX:8_ooool00ol0003oooooooooo`0<ooooo`;o00002ooo
ool00ol0003oooooooooo`0Booooo`00:Oooool2o`0004Kooooo0_l0000Mooooo`?o00000oooool0
0ol0003oooooooooo`0Vooooo`Ko2NX:00Goooooo`WZ2_l9jP[o2NX:ooooo`02o`WZ2R?ooooo00?o
0000ooooooooool03?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo017ooooo000V
ooooo`?o0000B?ooool2o`0001[ooooo1?l00005ooooo`?o00009?ooool8o`WZ2P03o`000?oooooo
2NX:00;o2NX:9Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo000000_ooooo00?o0000
ooooooooool04Oooool002?ooooo0ol0001;ooooo`;o00005oooool3o`000003ooooool0003o0000
00?ooooo0ol00003ooooo`03o`000?oooooooooo01oooooo1_l9jPX00ooooooo0000o`WZ2P02o`WZ
2P03ooooool9jP[o2NX:02Oooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo017ooooo000Pooooo`?o0000C_ooool2o`0001Gooooo0_l000000ooo
oooo0000o`000006o`0000Oooooo00?o0000ooooooooool07?ooool5o`WZ2P04ooooool9jP[o2NX:
o`0000;ooooo1?l9jPXXooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00
0009ooooo`03o`000?oooooooooo017ooooo000Oooooo`;o0000D?ooool2o`0001Cooooo1?l00003
ooooo`;o00002_ooool2o`0001_ooooo1Ol9jPX01?oooooo2NX:ooooool00002o`WZ2P;ooooo0_l9
jPXZooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`00
0?oooooooooo013ooooo000Oooooo`03o`000?oooooo000000;o0000COooool2o`0001?ooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo0ol000000on;DXSo0000ooooo`0Hooooo`?o2NX:0_oo
ool4o`WZ2P03o`000?oooooo2NX:00Co2NX:;?ooool00ol0003oooooooooo`0;ooooo`05o`000?oo
ooooooooooooool000002Oooool00ol0003oooooooooo`0@ooooo`007oooool00ol0003ooooooooo
o`02ooooo`?o0000B_ooool2o`0001?ooooo00?o0000ooooooooool00oooool2o`0000?ooooo00?o
0000ooooooooool00ol00004oh]BR0;o00005_ooool6o`WZ2P04ooooool9jP[oooooo`0000;o2NX:
0_ooool3o`WZ2Rgooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool01Ooo
ool3o`0004Oooooo0_l0000Booooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool0
0oooool2o`0000SoRe:80_l0000Cooooo`Co2NX:0_ooool4o`WZ2P04o`000?oooooo2NX:ooooo`?o
2NX:;oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0@ooooo`007oooool00ol0003oooooooooo`08ooooo`?o0000
A?ooool2o`0001;ooooo1?l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000oh]BR?n;DXP0
1on;DXP2o`00017ooooo1?l9jPX01ooooooo2NX:o`WZ2_oooooo2NX:ooooool000000_l9jPX00ooo
oooo2NX:o`WZ2P02o`WZ2S7ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool001oooooo00?o0000oooooooo
ool02oooool3o`00047ooooo0_l0000Aooooo`;o00001oooool00ol0003oooooooooo`02ooooo`03
o`000?n;DXSoRe:800OoRe:80ol0000>ooooo`Go2NX:0_ooool4o`WZ2P04o`000?oooooo2NX:oooo
o`Co2NX:<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0?ooooo`007oooool00ol0003oooooooooo`0>ooooo`?o
0000?_ooool2o`00017ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo0000
00_oRe:80_l0000<ooooo`Co2NX:0_ooool2o`WZ2P04ooooool9jP[o0000o`0000;o2NX:00Cooooo
o`WZ2_oooooooooo0_l9jPXdooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooo
oooo01;ooooo0_l0000looooo`;o00004Oooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000002on;DXP00ol0003oooooo`000009ooooo`?o2NX:00?oooooo`WZ2_l9jPX00_oo
ool4o`WZ2P;ooooo1_l9jPXfooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooo
oooo01Cooooo0ol0000iooooo`;o00004Oooool00ol0003oooooooooo`05ooooo`?o00000_ooool0
0ol0003oRe:8oh]BR009oh]BR003o`000?oooooo000000Oooooo1Ol9jPX2ooooo`;o2NX:00Cooooo
o`WZ2_l0003o00000_l9jPX01?oooooo2NX:ooooooooool2o`WZ2SSooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3_ooool001kooooo00?o0000ooooooooool05oooool3o`0003Kooooo0_l0000Aooooo`03o`000?oo
oooooooo00;ooooo0ol000001_nW`>_o0000ojO0jol0003oooooo`0000_oRe:800Co0000oooooooo
oooo00000oooool5o`WZ2P03ooooool9jP[o2NX:00;ooooo1?l9jPX2ooooo`03o`WZ2_oooooo2NX:
00Co2NX:>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Jooooo`?o
0000<oooool2o`00017ooooo00?o0000ooooool000000_l00004ojO0j`03o`000?nW`>_oYl3[00;o
00003?n;DXP01ol0003oooooooooool0003oooooo`WZ2_ooool01?l9jPX2ooooo`;o2NX:00Cooooo
o`WZ2_l0003o00001?l9jPX2ooooo`;o2NX:>oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`007_ooool0
0ol0003oooooooooo`0Mooooo`?o0000<?ooool2o`00017ooooo0_l00007ojO0j`03o`000?nW`>_o
Yl3[00;oYl3[00?o0000oh]BR?n;DXP02On;DXP00ol0003oooooooooo`05o`WZ2P03ooooool9jP[o
2NX:00;ooooo00Co2NX:ooooool9jP[o2NX:0_ooool00ol9jP[oooooo`WZ2P04o`WZ2Sgooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03_ooool001kooooo00?o0000ooooooooool08?ooool3o`0002gooooo0_l0000A
ooooo`03o`000?nW`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/00onW`>/00ol0003oRe:8oh]BR008
oh]BR003o`000?l9jP[o2NX:00Go2NX:0_ooool2o`WZ2P04ooooool9jP[o0000ooooo`Co2NX:0_oo
ool3o`WZ2Skooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000004?ooool001kooooo00?o0000ooooooooool08oooool3o`0002[ooooo0_l0
000Aooooo`;o00001onW`>/00ol0003oYl3[ojO0j`04ojO0j`;o00001on;DXP4o`WZ2P03ooooool9
jP[ooooo00;o2NX:0_ooool01?l9jP[oooooo`WZ2_l9jPX2ooooo`03o`WZ2_oooooo2NX:00Go2NX:
@?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`007_ooool00ol0003oooooooooo`0Vooooo`?o00009ooo
ool2o`00017ooooo0_l00007ojO0j`03o`000?nW`>_oYl3[00KoYl3[00Co0000oh]BR?n;DXSoRe:8
1?l9jPX00on;DXSo2NX:o`WZ2P02o`WZ2P08o`000?oooooo2NX:o`WZ2_oooooo2NX:o`000?ooool4
o`WZ2P;ooooo0ol9jPY2ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000000oooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000U
ooooo`;o00004Oooool2o`0000KoYl3[0_l00009ojO0j`;o00001Ol9jPX00on;DXSo0000ooooo`02
o`WZ2P04o`000?oooooo2NX:ooooo`;o2NX:0_ooool00ol9jP[oooooo`WZ2P02o`WZ2P03ooooool9
jP[o2NX:04Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`04o`000?oo
ooooooooo`0000oooooo000Nooooo`03o`000?oooooooooo02_ooooo0ol0000Rooooo`;o00004Ooo
ool00ol0003oooooo`000002ojO0j`?o000000?oYl3[o`000?nW`>/02OnW`>/01?l9jP[o0000oh]B
R?n;DXP4o`WZ2P;ooooo1?l9jPX00ol0003oooooo`WZ2P03o`WZ2P;ooooo1?l9jPY5ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000?ooooo`00
7_ooool00ol0003oooooooooo`0^ooooo`?o00007oooool2o`00017ooooo00?o0000ooooool00000
0_l00004ojO0j`03o`000?nW`>_oYl3[00KoYl3[0_l9jPX01?nW`>_o2NX:o`000?l9jPX2oh]BR0;o
2NX:0_ooool01?l9jP[oooooo`WZ2_l9jPX2ooooo`03o`WZ2_oooooo2NX:00;o2NX:00?oooooo`WZ
2_l9jPX0B?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000003oooool001gooooo00?o0000ooooooooool0<_ooool3o`0001cooooo0_l0000Aooooo`?o
00001onW`>/00ol0003oYl3[ojO0j`04ojO0j`03o`WZ2_nW`>_oYl3[00;oYl3[00?o2NX:o`000?n;
DXP00_n;DXP4o`WZ2P;o00001?l9jPX2ooooo`03o`WZ2_oooooo2NX:00;o2NX:B?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00cooooo0_l0000?ooooo`007Oooool00ol0003ooooo
ooooo`0eooooo`?o00006Oooool2o`00017ooooo00Co0000oooooooooooo00001_nW`>/00ol0003o
Yl3[ojO0j`03o`WZ2P;oYl3[0_l9jPX3ojO0j`06o`WZ2_l0003o2NX:oh]BR?l9jP[o00000_l9jPX2
o`000003o`WZ2_oooooo2NX:00Oo2NX:BOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooool000003_ooool001gooooo00?o0000ooooooooool0>?ooool3o`00
01Kooooo0_l0000Aooooo`05o`000?ooooooooooooooool000001OnW`>/01?l0003o2NX:o`WZ2_nW
`>/2o`WZ2P?oYl3[0ol9jPX3ojO0j`03o`000?l9jP[o2NX:00;o00001?l9jPX2ooooo`03o`WZ2_oo
oooo2NX:00;o2NX:C?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0_l0
000>ooooo`007Oooool00ol0003oooooooooo`0kooooo`?o00004oooool2o`0001;ooooo00Co0000
oooooooooooo00001?nW`>/00ol9jP[o0000o`WZ2P03ojO0j`?o2NX:0onW`>/2o`WZ2P;oYl3[0_l0
0002o`WZ2P04ooooool9jP[oooooooooo`Ko2NX:C_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03?ooool001gooooo00?o0000ooooooooool0?_oo
ool2o`00017ooooo0_l0000Booooo`06o`000?ooooooooooooooool0003oYl3[0_l9jPX2ojO0j`03
o`000?l9jP[o2NX:00?oYl3[0_l9jPX3ojO0j`;o2NX:00Co0000ojO0jonW`>_o00000ol9jPX2oooo
o`03o`WZ2_l0003o2NX:00;o2NX:D?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03?ooool001gooooo00?o0000ooooooooool0@?ooool3o`0000ko
oooo0_l0000Booooo`09o`000?ooooooooooooooool9jP[o0000ojO0jol9jP[oYl3[00;o000000?o
Yl3[o`WZ2_l9jPX00onW`>/2o`WZ2P03ojO0jol0003o000000?o2NX:00CoYl3[o`WZ2_l0003ooooo
1Ol9jPX00ooooooo2NX:ooooo`1@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0<ooooo`007Oooool00ol0003oooooooooo`13ooooo`?o00002ooo
ool2o`0001;ooooo00?o0000ooooool9jPX00_l9jPX4o`000004o`WZ2_l0003oYl3[ojO0j`;o2NX:
0onW`>/2o`000003o`WZ2_nW`>_o2NX:00;o2NX:00GoYl3[o`WZ2_l0003oooooo`WZ2P02ooooo`?o
2NX:Doooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03?ooool001gooooo00?o0000ooooooooool0A_ooool3o`0000Sooooo0_l0000Cooooo`03o`00
0?l9jP[o000000?o00000_nW`>/00ol9jP[o0000ojO0j`02ojO0j`;o2NX:0_l000000onW`>_o2NX:
o`WZ2P02ojO0j`04o`WZ2_n;DXSoRe:8o`WZ2P;o00001?l9jPX00ooooooo0000ooooo`1Booooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00
7Oooool00ol0003oooooooooo`19ooooo`?o00001Oooool2o`00017ooooo0_l9jPX2o`000005oooo
ool9jP[o2NX:o`WZ2_l000000_nW`>/01?l9jP[o0000o`WZ2_nW`>/2o`0000;o2NX:00?oYl3[o`WZ
2_n;DXP00_n;DXP01Ol9jP[oRe:8oh]BR?l9jP[o000000Co2NX:00?oooooo`000?l00000Doooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool0
01gooooo00?o0000ooooooooool0C?ooool3o`0000;ooooo0_l0000?ooooo`Co2NX:00Oo0000oooo
oooooooo2NX:ooooool9jP[o000000?oYl3[00?o0000o`WZ2_l000000_nW`>/01?l9jP[oRe:8oh]B
R?l9jPX3oh]BR005o`WZ2_n;DXSoRe:8o`WZ2_l000000_l9jPX3o`000003ooooool0003ooooo05?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_o
oooo000Mooooo`03o`000?oooooooooo04oooooo1?l0000>ooooo`03o`WZ2_oooooo2NX:00;ooooo
00Co0000o`WZ2_l9jP[o2NX:0_ooool01Ol9jP[o0000o`WZ2_nW`>_o000000;oYl3[0_n;DXP01?l9
jP[oRe:8oh]BR?l9jPX3oh]BR003o`WZ2_n;DXSoRe:800;o2NX:0onW`>/01?l0003oooooooooool0
001Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0;ooooo`007Oooool00ol0003oooooooooo`1Aooooo`;o00003Oooool4o`WZ2P;ooooo00Co2NX:
o`000?l9jP[o2NX:0_ooool01Ol9jP[o0000o`000?nW`>_o000000CoRe:800Co2NX:oh]BR?n;DXSo
2NX:0on;DXP01?l9jP[oRe:8o`WZ2_l00004ojO0j`04o`000?ooooooooooo`0005Gooooo00Go0000
ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooo
oooo05;ooooo0_l0000;ooooo`Co2NX:00?oooooo`WZ2_l9jPX00_l9jPX00ol0003oooooo`WZ2P03
o`WZ2P05ooooool0003oRe:8oh]BR?l000000on;DXP01?l9jP[oRe:8oh]BR?l9jPX3oh]BR0;o2NX:
00?oRe:8o`000?nW`>/01?nW`>/01?l0003oooooooooool0001Eooooo`04o`000?ooooooooooo`00
013ooooo00?o0000ooooooooool02oooool001cooooo00?o0000ooooooooool0D_ooool2o`0000[o
oooo1Ol9jPX00ooooooo2NX:ooooo`02o`WZ2P04o`000?oooooo2NX:o`0000?o2NX:1?l00003oh]B
R004o`WZ2_n;DXSoRe:8o`WZ2P;oRe:80_l9jPX2oh]BR003o`000?nW`>_oYl3[00?oYl3[00Co0000
oooooooooooo0000EOooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00_ooooo
000Looooo`03o`000?oooooooooo057ooooo00?o0000ooooool000002?ooool4o`WZ2P;ooooo0ol9
jPX2ooooo`;o2NX:00?o0000o`WZ2_l000001?l00002oh]BR005o`000?n;DXSoRe:8oh]BR?l9jPX0
0_n;DXP3o`WZ2PCoRe:800?o0000ojO0jonW`>/01?nW`>/00ol0003oooooo`00001Fooooo`03o`00
0?oooooo0000013ooooo00?o0000ooooooooool02oooool001cooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooo`000006ooooo`Ko2NX:0_ooool01_l9jP[oooooo`WZ2_l9jP[oooooo`WZ2P?o
000000Go2NX:ooooool9jP[oooooo`000003oh]BR003o`000?n;DXSoRe:800?o2NX:1on;DXP00ol0
003oYl3[ojO0j`04ojO0j`?o0000Eoooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo
00_ooooo000Looooo`03o`000?oooooooooo057ooooo00?o0000ooooool000001Oooool01?l9jP[o
ooooo`WZ2_l9jPX2ooooo`Co2NX:00Woooooo`WZ2_oooooo2NX:o`000?oooooo0000o`WZ2_ooool0
0_l9jPX00ooooooo0000oh]BR002oh]BR004o`000?n;DXSo2NX:o`WZ2PWoRe:800?o0000ojO0jonW
`>/01OnW`>/2o`0005Oooooo00?o0000ooooool000003oooool00ol0003oooooooooo`0;ooooo`00
7?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo000000Cooooo0ol9jPX01Ooooooo2NX:
o`WZ2_oooooo2NX:00;ooooo0ol9jPX2o`0000?o2NX:00?o0000ooooooooool00_l9jPX00ol0003o
Re:8oh]BR002oh]BR003o`000?n;DXSoRe:800WoRe:800?o0000ojO0jonW`>/01OnW`>/2o`0005So
oooo0_l0000>ooooo`03o`000?oooooooooo00cooooo000Looooo`03o`000?oooooooooo057ooooo
00?o0000ooooool000000_ooool5o`WZ2P03ooooool9jP[o2NX:00;o2NX:0_ooool2o`WZ2P04o`00
0?l9jP[oooooo`WZ2P;ooooo00Oo0000o`WZ2_oooooo2NX:ooooool0003o2NX:00;oRe:800?o2NX:
o`000?n;DXP02On;DXP00ol0003oYl3[ojO0j`07ojO0j`03o`000?oooooooooo05Oooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`007?ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooo000000?o2NX:0_ooool4o`WZ2P;ooooo0ol9jPX2o`0000Co2NX:0_ooool01_l0
003o2NX:o`WZ2_l9jP[oooooo`0000CoRe:800?o0000oh]BR?n;DXP02?n;DXP00ol0003oYl3[ojO0
j`07ojO0j`;o0000FOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo000L
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooool9jPX01?l9jPX00ooooooo2NX:ooooo`03
o`WZ2P04ooooool9jP[o0000o`0000?o2NX:0_ooool4o`WZ2P05o`000?oooooo2NX:o`WZ2_l00000
1?n;DXP2o`0000WoRe:800?o0000ojO0jonW`>/01onW`>/2o`0005[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0<ooooo`007?ooool00ol0003oooooooooo`1Aooooo`04o`000?l9
jP[o2NX:o`WZ2P;ooooo0ol9jPX2ooooo`?o2NX:00?o0000ooooooooool00ol9jPX2ooooo`06o`WZ
2_oooooo2NX:o`WZ2_l0003ooooo0_l9jPX00ol0003oRe:8o`000002o`000003oh]BR?l0003oRe:8
00SoRe:800?o0000ojO0jonW`>/02?nW`>/00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03?ooool001cooooo00?o0000ooooooooool0Coooool2o`WZ2P04
o`000?l9jP[o2NX:o`WZ2P;ooooo00Ko2NX:ooooool9jP[o2NX:ooooool9jPX2o`0000;o2NX:00?o
ooooo`WZ2_ooool01?l9jPX2ooooo`04o`WZ2_l0003o2NX:ooooo`?o00001On;DXP00ol0003oRe:8
oh]BR006oh]BR003o`000?nW`>_oYl3[00KoYl3[0ol0001Looooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0C_ooool2o`WZ2P05ooooool9
jP[o0000ooooool000001?l9jPX01Ooooooo2NX:ooooool9jP[o000000;ooooo00Ko2NX:ooooool9
jP[o2NX:ooooool9jPX2ooooo`Co2NX:00?oooooo`000?l000000_ooool00ol0003oRe:8oh]BR004
oh]BR003o`000?n;DXSoRe:800GoRe:80_l00002ojO0j`Go00000_ooool00ol0003oooooooooo`1K
ooooo`;o00001oooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`17oooo
o`Wo2NX:00Koooooo`WZ2_l0003o2NX:o`000?l9jPX2ooooo`?o2NX:0_l00004o`WZ2P;ooooo0ol9
jPX2ooooo`?o2NX:0_ooool01Ol0003ooooooooooooooooo000000KoRe:800?o0000oh]BR?n;DXP0
1?n;DXP00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool0GOooool2o`0000?ooooo
0_l0000@ooooo`006oooool00ol0003oooooooooo`14ooooo`So2NX:00Coooooo`WZ2_l9jP[o2NX:
0_ooool01?l0003o2NX:o`WZ2_l9jPX2ooooo`;o2NX:00Go0000o`WZ2_oooooo2NX:ooooo`03o`WZ
2P03ooooool9jP[ooooo00?o2NX:00?oooooo`WZ2_ooool00oooool01Ol0003ooooooooooooooooo
000000KoRe:800?o0000oh]BR?n;DXP00on;DXP01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooool000004_ooool001_ooooo00?o0000ooooooooool0@_ooool5
o`WZ2P03ooooool9jP[o2NX:00?o2NX:00Soooooo`WZ2_l9jP[o2NX:ooooool0003oooooo`0000?o
2NX:0_l00004o`WZ2P;ooooo1?l9jPX00ooooooo2NX:o`WZ2P02o`WZ2PKooooo00Co0000oooooooo
oooo00001_n;DXP2o`0000CoRe:800Co0000oooooooooooo00002?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo017ooooo000Kooooo`03o`000?oooooooooo03gooooo2_l9jPX00ooo
oooo2NX:ooooo`02o`WZ2P?ooooo00Wo2NX:ooooool9jP[o0000o`WZ2_l0003o2NX:ooooool00000
0ol9jPX2ooooo`Co2NX:0_ooool4o`WZ2PSooooo00Co0000oooooooooooo00000on;DXP3o`000003
oh]BR?l0003oRe:800;oRe:800Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
07Cooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l9jPX00ooooooo2NX:o`WZ2P03o`WZ2P04
ooooool9jP[oooooooooo`;o2NX:0_ooool2o`WZ2P;ooooo0_l9jPX01?oooooo0000o`WZ2_l9jPX2
o`000004ooooool9jP[o2NX:o`WZ2P;ooooo00Co2NX:ooooool9jP[o2NX:0_ooool2o`WZ2P_ooooo
00?o0000ooooooooool00ol00005oh]BR004o`000?n;DXSoRe:8o`0000?ooooo00?o0000oooooooo
ool01?ooool3o`0007Kooooo000Kooooo`03o`000?oooooooooo03Wooooo1ol9jPX00ooooooo2NX:
ooooo`02o`WZ2P;ooooo0_l9jPX2ooooo`?o2NX:00Ooooooo`WZ2_l9jP[o2NX:o`000?oooooo0000
00;o2NX:00?oooooo`WZ2_ooool01?l9jPX2ooooo`?o2NX:3_ooool3o`0000SoRe:800?o0000oh]B
R?l000000oooool00ol0003oooooo`000004o`0000;ooooo00?o0000ooooooooool0M?ooool001_o
oooo00?o0000ooooooooool0=?ooool8o`WZ2P03ooooool9jP[ooooo00?o2NX:0_ooool01?l9jP[o
ooooooooooooool2o`WZ2P03ooooool9jP[ooooo00?o2NX:00?oooooo`000?l000000_l000001_l9
jP[oooooo`WZ2_l9jP[oooooo`WZ2P;ooooo1?l9jPX@ooooo`03o`000?oooooo000000SoRe:80_l0
0004ooooo`;o00001_ooool00ol0003oooooooooo`1eooooo`006oooool00ol0003oooooooooo`0b
ooooo`Oo2NX:00?oooooo`WZ2_ooool00_l9jPX2ooooo`;o2NX:0_ooool3o`WZ2P03ooooool9jP[o
2NX:00;o2NX:0_ooool2o`WZ2P06o`000?oooooo0000o`WZ2_l0003o2NX:0_ooool3o`WZ2P;ooooo
0ol9jPXBooooo`03o`000?oooooo000000OoRe:80ol00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0MOooool001_ooooo00?o0000ooooooooool09oooool;o`WZ2P03ooooool9
jP[o2NX:00;ooooo1?l9jPX00ooooooo2NX:o`WZ2P03ooooo`;o2NX:00Ooooooo`WZ2_oooooo2NX:
ooooool9jP[ooooo00;o2NX:0_l000001?oooooo2NX:o`WZ2_ooool2o`0000;o2NX:0_ooool00ol9
jP[oooooo`WZ2P02o`WZ2P03ooooool9jP[ooooo01?ooooo0_l00004oh]BR0?o00000oooool01?l0
003oooooooooool00005ooooo`;o0000N?ooool001_ooooo00?o0000ooooooooool06oooool=o`WZ
2P?ooooo00Co2NX:oooooooooooooooo0_l9jPX00ooooooo2NX:o`WZ2P04o`WZ2P03ooooool9jP[o
2NX:00;ooooo0_l9jPX2ooooo`Co2NX:0_ooool2o`WZ2P;o00000_l9jPX00ooooooo2NX:o`WZ2P02
o`WZ2P;o00000_l9jPX2ooooo`03o`WZ2_oooooo2NX:00?o2NX:5_ooool00ol0003oRe:8o`000002
o`0000Oooooo0_l00003ooooo`?o000000?oooooo`000?ooool0Moooool001[ooooo00?o0000oooo
ooooool04Oooool<o`WZ2P?ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03o`WZ2_oooooo
oooo00[o2NX:0_ooool01?l9jP[oooooooooooooool2o`WZ2P07ooooool9jP[oooooo`WZ2_oooooo
2NX:ooooo`02o`WZ2P;o000000Coooooo`WZ2_oooooooooo1?l9jPX00ooooooo0000o`000002o`00
0004ooooool9jP[o2NX:ooooo`Co2NX:6Oooool00ol0003oooooooooo`08ooooo`Go00000oooool0
0ol0003oooooooooo`1gooooo`006_ooool00ol0003oooooooooo`0=ooooo`Go2NX:0oooool01Ol9
jP[ooooooooooooooooo2NX:00;ooooo00Co2NX:oooooooooooooooo2ol9jPX01ooooooo2NX:oooo
ool9jP[oooooo`WZ2_ooool00ol9jPX2ooooo`;o2NX:0_ooool2o`WZ2P04ooooool9jP[ooooooooo
o`;o2NX:0_l00002o`WZ2P03ooooool9jP[ooooo00?o2NX:00Coooooo`000?l0003o00000_ooool2
o`WZ2P03ooooool9jP[o2NX:00?o2NX:7?ooool00ol0003oooooooooo`04ooooo`?o000000?ooooo
o`000?ooool01Ol0001jooooo`006_ooool00ol0003oooooooooo`0=ooooo`05o`WZ2_oooooooooo
ooooool9jPX00_ooool=o`WZ2P0Cooooool9jP[oooooo`WZ2_oooooo2NX:ooooool9jP[oooooo`WZ
2_oooooo2NX:ooooool9jP[oooooo`WZ2_oooooo2NX:ooooo`02o`WZ2P07ooooool9jP[oooooo`WZ
2_oooooo2NX:ooooo`02o`WZ2P?o000000?o2NX:ooooooooool01?l9jPX2ooooo`?o000000?ooooo
o`WZ2_l9jPX00_ooool2o`WZ2P03ooooool9jP[o2NX:00;o2NX:7_ooool00ol0003oooooooooo`03
o`0000?ooooo1Ol0001mooooo`006_ooool00ol0003oooooooooo`0:ooooo`[o2NX:00koooooo`WZ
2_l9jP[oooooo`WZ2_oooooo2NX:ooooool9jP[oooooo`WZ2_oooooo2NX:ooooo`?o2NX:00Gooooo
o`WZ2_l9jP[o2NX:ooooo`03o`WZ2P04ooooool9jP[o2NX:o`WZ2P;ooooo1Ol9jPX01?oooooo2NX:
o`WZ2_l9jPX2o`0000;o2NX:0_ooool2o`WZ2P04ooooool9jP[oooooo`WZ2P?o000000Coooooo`WZ
2_l9jP[ooooo0ol9jPX00ooooooo2NX:o`000004o`WZ2R3ooooo0ol00002ooooo`Co0000POooool0
01[ooooo00?o0000ooooooooool02_ooool2o`WZ2P05ooooool9jP[o2NX:o`WZ2_ooool02?l9jPX0
1Ooooooo2NX:o`WZ2_l9jP[ooooo00?o2NX:0_ooool2o`WZ2P;ooooo0_l9jPX2ooooo`;o2NX:0_oo
ool2o`WZ2P;ooooo0_l9jPX00ooooooo2NX:o`WZ2P03o`000003o`WZ2_oooooooooo00Go2NX:00?o
ooooo`WZ2_l000000_l00002o`WZ2P;ooooo0_l9jPX00ooooooo2NX:ooooo`06o`WZ2RGooooo0ol0
0024ooooo`006_ooool00ol0003oooooooooo`0;ooooo`08o`WZ2_oooooo2NX:ooooool9jP[ooooo
o`WZ2_ooool2o`WZ2P;ooooo0_l9jPX2ooooo`;o2NX:0_ooool2o`WZ2P;ooooo0_l9jPX2ooooo`;o
2NX:0_ooool2o`WZ2P;ooooo0_l9jPX2o`000004o`WZ2_l0003o0000o`0000;o2NX:0_ooool2o`WZ
2P03ooooool9jP[ooooo00;o2NX:0ol000000ol9jP[oooooooooo`03o`WZ2P03ooooool9jP[ooooo
00Go2NX:00?o0000o`WZ2_ooool0[Oooool001[ooooo00?o0000ooooooooool02oooool01?l9jP[o
ooooo`WZ2_ooool3o`WZ2P03ooooool9jP[o2NX:00;ooooo0_l9jPX2ooooo`;o2NX:0_ooool2o`WZ
2P;ooooo0_l9jPX01?oooooo0000o`WZ2_l9jPX3o`000005o`WZ2_l0003o0000o`000?l9jPX00_oo
ool2o`WZ2P;ooooo0ol9jPX00ooooooo2NX:ooooo`02o`WZ2P?o000000?o2NX:ooooooooool00_l9
jPX00ooooooo2NX:ooooo`07o`WZ2P;ooooo0_l0002^ooooo`006_ooool00ol0003oooooooooo`0<
ooooo`;o2NX:0_ooool01Ol9jP[ooooooooooooooooo2NX:00?ooooo00Go2NX:oooooooooooooooo
o`WZ2P03o`000006o`WZ2_l0003o0000o`000?l9jP[o00000_ooool01Ol9jP[ooooooooooooooooo
2NX:00;ooooo0_l9jPX2ooooo`;o2NX:0_ooool01?l9jP[oooooo`WZ2_l9jPX4o`0000;ooooo0ol9
jPX00ooooooo2NX:ooooo`02o`WZ2P03ooooool9jP[o2NX:00;o2NX:1Oooool2o`000:kooooo000J
ooooo`03o`000?oooooooooo00cooooo0_l9jPX2ooooo`05o`WZ2_l0003o0000o`000?l9jPX00ol0
00001Ol9jP[o0000o`000?l0003o2NX:00?ooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`03
o`WZ2_oooooooooo00;o2NX:0_ooool2o`WZ2P;ooooo0ol9jPX00ooooooo2NX:o`000002o`000003
o`WZ2_oooooooooo00Co2NX:00?oooooo`WZ2_l9jPX01Ol9jPX9ooooo`;o0000[_ooool001[ooooo
00?o0000ooooooooool03?ooool01?l9jP[o0000o`000?l00002o`WZ2P;ooooo0_l9jPX2ooooo`;o
2NX:0_ooool2o`WZ2P;ooooo0_l9jPX2ooooo`;o2NX:0_ooool2o`WZ2P0;ooooool9jP[oooooo`WZ
2_oooooo2NX:ooooool9jP[oooooo`WZ2_ooool00ol00002ooooo`?o2NX:00?oooooo`WZ2_ooool0
0_l9jPX00ooooooo2NX:o`WZ2P02o`WZ2Pcooooo0_l0002^ooooo`006_ooool00ol0003ooooooooo
o`0<ooooo`;o2NX:0_ooool2o`WZ2P;ooooo0_l9jPX2ooooo`;o2NX:0_ooool2o`WZ2P;ooooo0_l9
jPX2ooooo`;o2NX:00coooooo`WZ2_l9jP[o2NX:ooooool9jP[oooooo`WZ2_oooooo2NX:ooooool9
jPX3o`000003o`WZ2_oooooo2NX:00;ooooo00?o2NX:ooooool9jPX00_l9jPX00ooooooo2NX:o`WZ
2P03o`WZ2Pkooooo0_l0002^ooooo`006_ooool00ol0003oooooooooo`0<ooooo`?o2NX:00Gooooo
o`WZ2_l9jP[o2NX:ooooo`03o`WZ2P05ooooool9jP[o2NX:o`WZ2_ooool00ol9jPX01Ooooooo2NX:
o`WZ2_l9jP[ooooo00Co2NX:00Goooooo`WZ2_l9jP[o2NX:ooooo`02o`WZ2P?o00003_l9jPXCoooo
o`;o0000[_ooool001Wooooo00?o0000ooooooooool03Oooool05?l9jP[oooooo`WZ2_oooooo2NX:
ooooool9jP[oooooo`WZ2_oooooo2NX:ooooool9jP[oooooo`WZ2_oooooo2NX:ooooool9jP[ooooo
3?l9jPX3o`000005o`WZ2_ooooooooooooooool9jPX00oooool00ol9jP[oooooo`WZ2P02o`WZ2QOo
oooo0_l0002^ooooo`006Oooool00ol0003oooooooooo`0=ooooo`08o`WZ2_oooooo2NX:ooooool9
jP[oooooo`WZ2_ooool=o`WZ2P;ooooo00Ko2NX:ooooooooooooooooo`WZ2_ooool3o`0000?ooooo
00Ko2NX:ooooooooooooooooo`WZ2_ooool4o`WZ2Q[ooooo0_l0002^ooooo`006Oooool00ol0003o
ooooooooo`0=ooooo`03o`WZ2_oooooooooo00Ko2NX:0oooool01Ol9jP[ooooooooooooooooo2NX:
00;ooooo00Ko2NX:ooooooooooooooooo`WZ2_ooool4o`0000co2NX:7_ooool2o`000:kooooo000I
ooooo`03o`000?oooooooooo00gooooo00Go2NX:ooooooooooooooooo`WZ2P03ooooo`06o`WZ2_oo
ooooooooooooool9jP[ooooo2?l9jPX3o`0000?o2NX::oooool2o`000:kooooo000Iooooo`03o`00
0?oooooooooo00gooooo3_l9jPX5ooooo`?o0000<Oooool2o`000:kooooo000Iooooo`03o`000?oo
oooooooo00gooooo00?o2NX:ooooooooool03Oooool3o`0003Cooooo0_l0002^ooooo`006Oooool0
0ol0003oooooooooo`0Jooooo`?o0000=oooool2o`000:kooooo000Iooooo`03o`000?oooooooooo
01Oooooo0ol0000jooooo`;o0000[_ooool001Wooooo00?o0000ooooooooool05?ooool3o`0003go
oooo0_l0002^ooooo`006Oooool00ol0003oooooooooo`0@ooooo`Co0000@?ooool2o`000:kooooo
000Iooooo`03o`000?oooooooooo00gooooo0ol00014ooooo`;o0000[_ooool001Sooooo00?o0000
ooooooooool02oooool3o`0004Oooooo0_l0002^ooooo`006?ooool00ol0003oooooooooo`08oooo
o`?o0000B_ooool2o`000:kooooo000Hooooo`03o`000?oooooooooo00Gooooo0ol0001=ooooo`;o
0000[_ooool001Sooooo00?o0000ooooooooool00_ooool3o`00053ooooo0_l0002^ooooo`006?oo
ool00ol0003oooooo`000002o`0005?ooooo0_l0002^ooooo`006?ooool3o`0005Gooooo0_l0002^
ooooo`006oooool3o`0005;ooooo0_l0002^ooooo`007_ooool3o`0004oooooo0_l0002^ooooo`00
8Oooool3o`0004cooooo0_l0002^ooooo`009?ooool3o`0004Wooooo0_l0002^ooooo`009oooool3
o`0004Kooooo0_l0002^ooooo`00:_ooool3o`0004?ooooo0_l0002^ooooo`00;Oooool4o`0003oo
oooo0_l0002^ooooo`00<Oooool3o`0003cooooo0_l0002^ooooo`00=?ooool3o`0003Wooooo00?o
0000ooooooooool0[Oooool003Oooooo0ol0000fooooo`03o`000?oooooooooo0:gooooo000joooo
o`?o0000<oooool00ol0003oooooooooo`2]ooooo`00?Oooool3o`00033ooooo00?o0000oooooooo
ool0[Oooool0043ooooo0ol0000]ooooo`03o`000?oooooooooo0:gooooo0013ooooo`Co0000:Ooo
ool00ol0003oooooooooo`2]ooooo`00Aoooool3o`0002Kooooo00?o0000ooooooooool0[Oooool0
04[ooooo0ol0000Sooooo`03o`000?oooooooooo0:gooooo001=ooooo`?o00008?ooool00ol0003o
ooooooooo`2]ooooo`00D?ooool3o`0001gooooo00?o0000ooooooooool0[Oooool005?ooooo0ol0
000Jooooo`03o`000?oooooooooo0:gooooo001Fooooo`?o00005oooool00ol0003oooooooooo`2]
ooooo`00FOooool4o`0001?ooooo00?o0000ooooooooool0[Oooool005gooooo0ol0000@ooooo`03
o`000?oooooooooo0:gooooo001Pooooo`?o00003Oooool00ol0003oooooooooo`2]ooooo`00Hooo
ool3o`0000[ooooo00?o0000ooooooooool0[Oooool006Kooooo0ol00007ooooo`03o`000?oooooo
oooo0:gooooo001Yooooo`?o00001?ooool00ol0003oooooooooo`2]ooooo`00K?ooool3o`000003
ooooool0003ooooo0:kooooo001_ooooo`;o0000[oooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {212.875, 0}} -> {0.0135885, 0.11055, \
0.00343918, 0.00343918}},
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG4."}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Imaging Calculations", "Section",
  CellTags->{"AOG0.", "5", "AOG5.", "AOG5.1"}],

Cell[CellGroupData[{

Cell["5.1 Overview", "Subsection",
  CellTags->{"AOG0.", "5.1", "AOG5.", "AOG5.1"}],

Cell[TextData[{
  StyleBox["Optica",
    FontSlant->"Italic"],
  " has several built-in functions userful for characterizing imaging \
systems. These functions include: ",
  StyleBox["FindLensParameters", "Input"],
  ", ",
  StyleBox["PupilFunction", "Input"],
  ", ",
  StyleBox["PointSpreadFunction", "Input"],
  ", ",
  StyleBox["GeometricPointSpreadFunction", "Input"],
  ", and ",
  StyleBox["OpticalTransferFunction", "Input"],
  ". In addition to these names, many of these functions can also take an \
abbreviated alias that include: ",
  StyleBox["PF", "Input"],
  ", ",
  StyleBox["PSF", "Input"],
  ", ",
  StyleBox["GPSF", "Input"],
  ", ",
  StyleBox["OTF", "Input"],
  " and ",
  StyleBox["MTF", "Input"],
  ". The following examples shall serve to introduce the basic use of these \
highlighted functions. Next, evaluate the examples to see the resulting \
answers."
}], "Text",
  CellLabel->"In[106]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell["\<\
optics = {PlanoConvexLens[100,50,10],
\tMove[Screen[1],{d+103,103}]};\
\>", "Input",
  CellLabel->"In[122]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell["opticalsystem = {Move[LineOfRays[20],{-50,{y,0}}],optics};", "Input",
  CellLabel->"In[123]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[opticalsystem,PlotType->TopView];", "Input",
  CellLabel->"In[124]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.335045 0.00622471 0.189303 0.00622471 [
[.36617 .00841 -5.03125 -6 ]
[.36617 .00841 5.03125 6 ]
[.97619 .16092 -4.75 -6 ]
[.97619 .16092 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .35333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.37502 .03369 m
.39729 .03369 L
.39729 .08556 L
.35217 .08556 L
.37502 .03369 L
F
.35217 .08556 m
.39729 .08556 L
.39729 .13743 L
.33924 .13743 L
.35217 .08556 L
F
.33924 .13743 m
.39729 .13743 L
.39729 .1893 L
.33505 .1893 L
.33924 .13743 L
F
.33505 .1893 m
.39729 .1893 L
.39729 .24118 L
.33924 .24118 L
.33505 .1893 L
F
.33924 .24118 m
.39729 .24118 L
.39729 .29305 L
.35217 .29305 L
.33924 .24118 L
F
.35217 .29305 m
.39729 .29305 L
.39729 .34492 L
.37502 .34492 L
.35217 .29305 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.37502 .03369 m
.35217 .08556 L
.33924 .13743 L
.33505 .1893 L
.33924 .24118 L
.35217 .29305 L
.37502 .34492 L
.39729 .34492 L
.39729 .29305 L
.39729 .24118 L
.39729 .1893 L
.39729 .13743 L
.39729 .08556 L
.39729 .03369 L
.37502 .03369 L
s
.5 g
.37502 .1893 m
.39729 .1893 L
.39729 .1893 L
.35217 .1893 L
.37502 .1893 L
F
.35217 .1893 m
.39729 .1893 L
.39729 .1893 L
.33924 .1893 L
.35217 .1893 L
F
.33924 .1893 m
.39729 .1893 L
.39729 .1893 L
.33505 .1893 L
.33924 .1893 L
F
.33505 .1893 m
.39729 .1893 L
.39729 .1893 L
.33924 .1893 L
.33505 .1893 L
F
.33924 .1893 m
.39729 .1893 L
.39729 .1893 L
.35217 .1893 L
.33924 .1893 L
F
.35217 .1893 m
.39729 .1893 L
.39729 .1893 L
.37502 .1893 L
.35217 .1893 L
F
0 g
.37502 .1893 m
.35217 .1893 L
.33924 .1893 L
.33505 .1893 L
.33924 .1893 L
.35217 .1893 L
.37502 .1893 L
.39729 .1893 L
.39729 .1893 L
.39729 .1893 L
.39729 .1893 L
.39729 .1893 L
.39729 .1893 L
.39729 .1893 L
.37502 .1893 L
s
.37502 .34492 m
.39729 .34492 L
.39729 .33962 L
.37502 .33962 L
.37502 .34492 L
s
.37502 .33962 m
.39729 .33962 L
.39729 .32407 L
.37502 .32407 L
.37502 .33962 L
s
.37502 .32407 m
.39729 .32407 L
.39729 .29934 L
.37502 .29934 L
.37502 .32407 L
s
.37502 .29934 m
.39729 .29934 L
.39729 .26711 L
.37502 .26711 L
.37502 .29934 L
s
.37502 .26711 m
.39729 .26711 L
.39729 .22958 L
.37502 .22958 L
.37502 .26711 L
s
.37502 .22958 m
.39729 .22958 L
.39729 .1893 L
.37502 .1893 L
.37502 .22958 L
s
.37502 .1893 m
.39729 .1893 L
.39729 .14903 L
.37502 .14903 L
.37502 .1893 L
s
.37502 .14903 m
.39729 .14903 L
.39729 .11149 L
.37502 .11149 L
.37502 .14903 L
s
.37502 .11149 m
.39729 .11149 L
.39729 .07926 L
.37502 .07926 L
.37502 .11149 L
s
.37502 .07926 m
.39729 .07926 L
.39729 .05453 L
.37502 .05453 L
.37502 .07926 L
s
.37502 .05453 m
.39729 .05453 L
.39729 .03899 L
.37502 .03899 L
.37502 .05453 L
s
.37502 .03899 m
.39729 .03899 L
.39729 .03369 L
.37502 .03369 L
.37502 .03899 L
s
.37502 .03369 m
.39729 .03369 L
.39729 .03899 L
.37502 .03899 L
.37502 .03369 L
s
.37502 .03899 m
.39729 .03899 L
.39729 .05453 L
.37502 .05453 L
.37502 .03899 L
s
.37502 .05453 m
.39729 .05453 L
.39729 .07926 L
.37502 .07926 L
.37502 .05453 L
s
.37502 .07926 m
.39729 .07926 L
.39729 .11149 L
.37502 .11149 L
.37502 .07926 L
s
.37502 .11149 m
.39729 .11149 L
.39729 .14903 L
.37502 .14903 L
.37502 .11149 L
s
.37502 .14903 m
.39729 .14903 L
.39729 .1893 L
.37502 .1893 L
.37502 .14903 L
s
.37502 .1893 m
.39729 .1893 L
.39729 .22958 L
.37502 .22958 L
.37502 .1893 L
s
.37502 .22958 m
.39729 .22958 L
.39729 .26711 L
.37502 .26711 L
.37502 .22958 L
s
.37502 .26711 m
.39729 .26711 L
.39729 .29934 L
.37502 .29934 L
.37502 .26711 L
s
.37502 .29934 m
.39729 .29934 L
.39729 .32407 L
.37502 .32407 L
.37502 .29934 L
s
.37502 .32407 m
.39729 .32407 L
.39729 .33962 L
.37502 .33962 L
.37502 .32407 L
s
.37502 .33962 m
.39729 .33962 L
.39729 .34492 L
.37502 .34492 L
.37502 .33962 L
s
.97619 .18619 m
.97619 .18723 L
.97619 .18827 L
.97619 .1893 L
.97619 .19034 L
.97619 .19138 L
.97619 .19242 L
.97619 .19242 L
.97619 .19138 L
.97619 .19034 L
.97619 .1893 L
.97619 .18827 L
.97619 .18723 L
.97619 .18619 L
.97619 .18619 L
s
.97619 .1893 m
.97619 .1893 L
.97619 .1893 L
.97619 .1893 L
.97619 .1893 L
.97619 .1893 L
.97619 .1893 L
.97619 .1893 L
.97619 .1893 L
.97619 .1893 L
.97619 .1893 L
.97619 .1893 L
.97619 .1893 L
.97619 .1893 L
.97619 .1893 L
s
.97619 .19242 m
.97619 .19231 L
.97619 .192 L
.97619 .1915 L
.97619 .19086 L
.97619 .19011 L
.97619 .1893 L
.97619 .1885 L
.97619 .18775 L
.97619 .1871 L
.97619 .18661 L
.97619 .1863 L
.97619 .18619 L
.97619 .1863 L
.97619 .18661 L
.97619 .1871 L
.97619 .18775 L
.97619 .1885 L
.97619 .1893 L
.97619 .19011 L
.97619 .19086 L
.97619 .1915 L
.97619 .192 L
.97619 .19231 L
.97619 .19242 L
s
.039 .916 .04 r
.02381 .12706 m
.3411 .12706 L
s
% Start of user PostScript
-50. -10. 0.973037 -10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.3411 .12706 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .1893 m
.33505 .1893 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.33505 .1893 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25155 m
.3411 .25155 L
s
% Start of user PostScript
-50. 10. 0.973037 10. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.3411 .25155 Mdot
.039 .916 .04 r
.5 Mabswid
.3411 .12706 m
.39729 .13081 L
s
% Start of user PostScript
0.973037 -10. 10. -9.3966 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.39729 .13081 Mdot
.039 .916 .04 r
.5 Mabswid
.33505 .1893 m
.39729 .1893 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.39729 .1893 Mdot
.039 .916 .04 r
.5 Mabswid
.3411 .25155 m
.39729 .24779 L
s
% Start of user PostScript
0.973037 10. 10. 9.3966 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.39729 .24779 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .13081 m
.97619 .18977 L
s
% Start of user PostScript
10. -9.3966 103. 0.0743844 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .18977 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .1893 m
.97619 .1893 L
s
% Start of user PostScript
10. 0 103. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1893 Mdot
.039 .916 .04 r
.5 Mabswid
.39729 .24779 m
.97619 .18884 L
s
% Start of user PostScript
10. 9.3966 103. -0.0743844 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .18884 Mdot
gsave
.36617 .00841 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .16092 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35333 L
0 .35333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[124]:=",
  ImageSize->{288, 101.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000IB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00Ioooool6o`000;?ooooo001X
ooooo`05o`000?ooooooooooooooool00000/oooool006Sooooo00?o0000ooooooooool0]Oooool0
06Sooooo00?o0000ooooooooool0]Oooool006Sooooo00?o0000ooooooooool0]Oooool006Sooooo
00?o0000ooooooooool0]Oooool006Oooooo0ol0002fooooo`00oooooolQooooo`00oooooolQoooo
o`00KOooool7o`000:cooooo001]ooooo`Oo0000[?ooool006cooooo0_l00005ogmoO`03o`000?oo
oooooooo0:[ooooo001/ooooo`;o00001OmoOgl00ol0003oooooooooo`2Zooooo`00Joooool00ol0
003oOgmoo`000005ogmoO`03o`000?oooooooooo0:[ooooo001[ooooo`03o`000?moOgoo000000Ko
0000[?ooool006[ooooo00Co0000ogmoOomoOgoo00001OmoOgl00ol0003oooooooooo`2Zooooo`00
J_ooool01?l0003oOgmoogmoOol00005ogmoO`03o`000?oooooooooo0:[ooooo001Yooooo`05o`00
0?moOgooOgmoogmoOol000001OmoOgl00ol0003oooooooooo`2Zooooo`00JOooool01Ol0003oOgmo
ogmoOomoOgoo000000GoOgmo00?o0000ooooooooool0Z_ooool006Sooooo00?o0000ogmoOomoOgl0
0_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo0:[ooooo001Xooooo`03o`000?mo
OgooOgmo00;oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Zooooo`00Ioooool0
0ol0003oOgmoogmoO`03ogmoO`Oo0000[?ooool006Oooooo00?o0000ogmoOomoOgl00omoOgl00ol0
003oOgmoogmoO`03ogmoO`03o`000?oooooooooo0:[ooooo001Vooooo`03o`000?moOgooOgmo00Co
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Zooooo`00I_ooool00ol0003oOgmo
ogmoO`04ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0Z_ooool006Kooooo00?o
0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo0:[ooooo001U
ooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Z
ooooo`00IOooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000oooo
ooooool0Z_ooool006Gooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo0:[ooooo001Uooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Zooooo`00IOooool00ol0003oOgmoogmoO`05ogmoO`Oo0000[?oo
ool006Cooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo0:[ooooo001Kooooo`?o2NX:1_ooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo
00?oOgmo00?o0000ooooooooool0Z_ooool005cooooo1_l9jPX2ooooo`03o`000?moOgooOgmo00Co
Ogmo0ol9jPX5ogmoO`03o`000?oooooooooo0:[ooooo000<ooooofKo2NX:00?oOgmoo`000?ooool0
Zoooool005cooooo1Ol9jPX2ooooo`;o00001omoOgl6o`WZ2P03o`000?l9jP[o2NX:00Co2NX:Yooo
ool005_ooooo0_l9jPX6ooooo`03o`000?moOgooOgmo00KoOgmo1Ol9jPX00omoOgoo0000o`000005
ooooo`Wo2NX:W_ooool006?ooooo00?o0000ogmoOomoOgl01OmoOgl2o`WZ2P03o`000?moOgooOgmo
00?oOgmo00?o0000ooooooooool03?ooool9o`WZ2YGooooo001Sooooo`03o`000?moOgooOgmo00Oo
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0Eooooo`[o2NX:Roooool006?ooooo
00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo01oooooo
2Ol9jPZ2ooooo`00Hoooool00ol0003oOgmoogmoO`07ogmoO`Oo0000:_ooool9o`WZ2WWooooo001S
ooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`0a
ooooo`[o2NX:Koooool006?ooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmo
O`03o`000?oooooooooo03_ooooo2Ol9jPYFooooo`?o00003Oooool006?ooooo00?o0000ogmoOomo
Ogl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo04Cooooo2_l9jPY<ooooo`04
o`000?ooooooooooo`0000cooooo001Sooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomo
Ogl00omoOgl00ol0003oooooooooo`1>ooooo`Wo2NX:A_ooool00ol0003oooooooooo`0:ooooo`00
H_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0
Eoooool9o`WZ2S_ooooo0_l0000=ooooo`00H_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?mo
OgooOgmo00?oOgmo00?o0000ooooooooool0H?ooool:o`WZ2S3ooooo00?o0000ooooooooool03Ooo
ool006;ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooo
oooo06[ooooo2Ol9jPXWooooo`04o`000?ooooooooooo`0000cooooo001Rooooo`03o`000?moOgoo
Ogmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`1cooooo`Wo2NX:7oooool3
o`0000cooooo001Jooooo`?o2NX:1Oooool00ol0003oOgmoogmoO`06ogmoO`?o2NX:1OmoOgl00ol0
003oooooooooo`1looooo`[o2NX:3_ooool3o`WZ2Q?ooooo001Kooooo`Ko2NX:00?oooooo`000?mo
Ogl02?moOgl6o`WZ2P03ogmoOol0003ooooo08Oooooo2Ol9jPX5ooooo`Oo2NX:00?oooooo`000?oo
ool03?ooool000coooooEOl9jPX00ol0003o2NX:o`WZ2P0>o`WZ2P03o`000?l9jP[o2NX:09co2NX:
0_l0000=ooooo`00Foooool5o`WZ2P03ooooool0003o000000WoOgmo1Ol9jPX00omoOgoo0000o`00
002@ooooo`go2NX:0_l0000=ooooo`00F_ooool2o`WZ2PKooooo00?o0000ogmoOomoOgl01_moOgl2
o`WZ2P03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0QOooool9o`WZ2PKooooo1?l9jPXB
ooooo`00H_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000oooo
ooooool0Noooool:o`WZ2Poooooo00?o2NX:ooooooooool04oooool006;ooooo00?o0000ogmoOomo
Ogl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo07;ooooo2Ol9jPX_ooooo`00
H_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0
JOooool9o`WZ2SSooooo001Rooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omo
Ogl00ol0003oooooooooo`1Oooooo`[o2NX:@Oooool006;ooooo00?o0000ogmoOomoOgl02?moOgl0
0ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo05Kooooo2Ol9jPY;ooooo`00Hoooool00ol0
003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0C?ooool:o`WZ
2UCooooo001Sooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003o
ooooooooo`13ooooo`Wo2NX:G_ooool006?ooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo03[ooooo2Ol9jPYWooooo`00Hoooool00ol0003oOgmoogmo
O`07ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0<?ooool:o`WZ2W3ooooo001S
ooooo`03o`000?moOgooOgmo00OoOgmo1ol0000Yooooo`Wo2NX:N_ooool006?ooooo00?o0000ogmo
OomoOgl01omoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo01kooooo2Ol9jPZ3oooo
o`00Hoooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000oooooooo
ool05?ooool:o`WZ2Xcooooo001Sooooo`03o`000?moOgooOgmo00GoOgmo0ol9jPX5ogmoO`03o`00
0?oooooooooo00_ooooo2Ol9jPZFooooo`00Foooool3o`WZ2PGooooo00?o0000ogmoOomoOgl01_mo
Ogl6o`WZ2P;o00001?ooool9o`WZ2Yoooooo001Looooo`Ko2NX:00?oooooo`000?l000001_moOgl7
o`WZ2P03o`000?l9jP[o2NX:00?o2NX:Z?ooool000coooooGol9jPX00omoOgoo2NX:o`WZ2P03o`WZ
2P;oOgmo00?o0000ooooooooool0Z_ooool005cooooo1Ol9jPX3ooooo`03o`000?moOgooOgmo00Co
Ogmo0_l9jPX00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo0:[ooooo001Kooooo`;o2NX:
1oooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0
Z_ooool006Cooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oo
oooooooo0:[ooooo001Tooooo`03o`000?moOgooOgmo00KoOgmo1ol0002/ooooo`00IOooool00ol0
003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0Z_ooool006Go
oooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo0:[o
oooo001Uooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`2Zooooo`00IOooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo00?o
0000ooooooooool0Z_ooool006Gooooo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo0:[ooooo001Vooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmo
OomoOgl00omoOgl00ol0003oooooooooo`2Zooooo`00I_ooool00ol0003oOgmoogmoO`04ogmoO`03
o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0Z_ooool006Kooooo00?o0000ogmoOomoOgl0
1?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo0:[ooooo001Wooooo`03o`000?mo
OgooOgmo00?oOgmo1ol0002/ooooo`00Ioooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgoo
Ogmo00?oOgmo00?o0000ooooooooool0Z_ooool006Sooooo00?o0000ogmoOomoOgl00_moOgl00ol0
003oOgmoogmoO`03ogmoO`03o`000?oooooooooo0:[ooooo001Xooooo`03o`000?moOgooOgmo00;o
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Zooooo`00JOooool01Ol0003oOgmo
ogmoOomoOgoo000000GoOgmo00?o0000ooooooooool0Z_ooool006Wooooo00Go0000ogmoOomoOgoo
Ogmoo`000005ogmoO`03o`000?oooooooooo0:[ooooo001Zooooo`03o`000?moOgooOgmo00Oo0000
[?ooool006[ooooo00Co0000ogmoOomoOgoo00001OmoOgl00ol0003oooooooooo`2Zooooo`00Jooo
ool00ol0003oOgmoo`000005ogmoO`03o`000?oooooooooo0:[ooooo001[ooooo`03o`000?moOgoo
000000GoOgmo00?o0000ooooooooool0Z_ooool006cooooo0_l00005ogmoO`03o`000?oooooooooo
0:[ooooo001/ooooo`So0000[?ooool006gooooo1ol0002/ooooo`00oooooolQooooo`00oooooolQ
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {100.75, 0}} -> {-57.4221, -32.5697, 0.584823, \
0.584823}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindFocus[{Move[LineOfRays[20,NumberOfRays->21],-50],optics}]\
\>", "Input",
  CellLabel->"In[125]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00551 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.49474 8.55371 0.502754 8.55371 [
[.15259 -0.0125 -15 -9 ]
[.15259 -0.0125 15 0 ]
[.32367 -0.0125 -15 -9 ]
[.32367 -0.0125 15 0 ]
[.49474 -0.0125 -3 -9 ]
[.49474 -0.0125 3 0 ]
[.66581 -0.0125 -12 -9 ]
[.66581 -0.0125 12 0 ]
[.83689 -0.0125 -12 -9 ]
[.83689 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .16061 -30 -4.5 ]
[-0.0125 .16061 0 4.5 ]
[-0.0125 .33168 -30 -4.5 ]
[-0.0125 .33168 0 4.5 ]
[-0.0125 .50275 -6 -4.5 ]
[-0.0125 .50275 0 4.5 ]
[-0.0125 .67383 -24 -4.5 ]
[-0.0125 .67383 0 4.5 ]
[-0.0125 .8449 -24 -4.5 ]
[-0.0125 .8449 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1.00551 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1.00551 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15259 0 m
.15259 .00625 L
s
[(-0.04)] .15259 -0.0125 0 1 Mshowa
.32367 0 m
.32367 .00625 L
s
[(-0.02)] .32367 -0.0125 0 1 Mshowa
.49474 0 m
.49474 .00625 L
s
[(0)] .49474 -0.0125 0 1 Mshowa
.66581 0 m
.66581 .00625 L
s
[(0.02)] .66581 -0.0125 0 1 Mshowa
.83689 0 m
.83689 .00625 L
s
[(0.04)] .83689 -0.0125 0 1 Mshowa
.125 Mabswid
.19536 0 m
.19536 .00375 L
s
.23813 0 m
.23813 .00375 L
s
.2809 0 m
.2809 .00375 L
s
.36643 0 m
.36643 .00375 L
s
.4092 0 m
.4092 .00375 L
s
.45197 0 m
.45197 .00375 L
s
.53751 0 m
.53751 .00375 L
s
.58028 0 m
.58028 .00375 L
s
.62305 0 m
.62305 .00375 L
s
.70858 0 m
.70858 .00375 L
s
.75135 0 m
.75135 .00375 L
s
.79412 0 m
.79412 .00375 L
s
.87966 0 m
.87966 .00375 L
s
.92243 0 m
.92243 .00375 L
s
.96519 0 m
.96519 .00375 L
s
.10982 0 m
.10982 .00375 L
s
.06705 0 m
.06705 .00375 L
s
.02429 0 m
.02429 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16061 m
.00625 .16061 L
s
[(-0.04)] -0.0125 .16061 1 0 Mshowa
0 .33168 m
.00625 .33168 L
s
[(-0.02)] -0.0125 .33168 1 0 Mshowa
0 .50275 m
.00625 .50275 L
s
[(0)] -0.0125 .50275 1 0 Mshowa
0 .67383 m
.00625 .67383 L
s
[(0.02)] -0.0125 .67383 1 0 Mshowa
0 .8449 m
.00625 .8449 L
s
[(0.04)] -0.0125 .8449 1 0 Mshowa
.125 Mabswid
0 .20337 m
.00375 .20337 L
s
0 .24614 m
.00375 .24614 L
s
0 .28891 m
.00375 .28891 L
s
0 .37445 m
.00375 .37445 L
s
0 .41722 m
.00375 .41722 L
s
0 .45999 m
.00375 .45999 L
s
0 .54552 m
.00375 .54552 L
s
0 .58829 m
.00375 .58829 L
s
0 .63106 m
.00375 .63106 L
s
0 .7166 m
.00375 .7166 L
s
0 .75937 m
.00375 .75937 L
s
0 .80213 m
.00375 .80213 L
s
0 .11784 m
.00375 .11784 L
s
0 .07507 m
.00375 .07507 L
s
0 .0323 m
.00375 .0323 L
s
0 .88767 m
.00375 .88767 L
s
0 .93044 m
.00375 .93044 L
s
0 .97321 m
.00375 .97321 L
s
.25 Mabswid
0 0 m
0 1.00551 L
s
.15259 .99926 m
.15259 1.00551 L
s
.32367 .99926 m
.32367 1.00551 L
s
.49474 .99926 m
.49474 1.00551 L
s
.66581 .99926 m
.66581 1.00551 L
s
.83689 .99926 m
.83689 1.00551 L
s
.125 Mabswid
.19536 1.00176 m
.19536 1.00551 L
s
.23813 1.00176 m
.23813 1.00551 L
s
.2809 1.00176 m
.2809 1.00551 L
s
.36643 1.00176 m
.36643 1.00551 L
s
.4092 1.00176 m
.4092 1.00551 L
s
.45197 1.00176 m
.45197 1.00551 L
s
.53751 1.00176 m
.53751 1.00551 L
s
.58028 1.00176 m
.58028 1.00551 L
s
.62305 1.00176 m
.62305 1.00551 L
s
.70858 1.00176 m
.70858 1.00551 L
s
.75135 1.00176 m
.75135 1.00551 L
s
.79412 1.00176 m
.79412 1.00551 L
s
.87966 1.00176 m
.87966 1.00551 L
s
.92243 1.00176 m
.92243 1.00551 L
s
.96519 1.00176 m
.96519 1.00551 L
s
.10982 1.00176 m
.10982 1.00551 L
s
.06705 1.00176 m
.06705 1.00551 L
s
.02429 1.00176 m
.02429 1.00551 L
s
.25 Mabswid
0 1.00551 m
1 1.00551 L
s
.99375 .16061 m
1 .16061 L
s
.99375 .33168 m
1 .33168 L
s
.99375 .50275 m
1 .50275 L
s
.99375 .67383 m
1 .67383 L
s
.99375 .8449 m
1 .8449 L
s
.125 Mabswid
.99625 .20337 m
1 .20337 L
s
.99625 .24614 m
1 .24614 L
s
.99625 .28891 m
1 .28891 L
s
.99625 .37445 m
1 .37445 L
s
.99625 .41722 m
1 .41722 L
s
.99625 .45999 m
1 .45999 L
s
.99625 .54552 m
1 .54552 L
s
.99625 .58829 m
1 .58829 L
s
.99625 .63106 m
1 .63106 L
s
.99625 .7166 m
1 .7166 L
s
.99625 .75937 m
1 .75937 L
s
.99625 .80213 m
1 .80213 L
s
.99625 .11784 m
1 .11784 L
s
.99625 .07507 m
1 .07507 L
s
.99625 .0323 m
1 .0323 L
s
.99625 .88767 m
1 .88767 L
s
.99625 .93044 m
1 .93044 L
s
.99625 .97321 m
1 .97321 L
s
.25 Mabswid
1 0 m
1 1.00551 L
s
.039 .916 .04 r
2.5 Mabswid
.81571 .50275 Mdot
.62066 .50275 Mdot
.47841 .50275 Mdot
.38233 .50275 Mdot
.32609 .50275 Mdot
.30356 .50275 Mdot
.30884 .50275 Mdot
.33617 .50275 Mdot
.37995 .50275 Mdot
.43462 .50275 Mdot
.49474 .50275 Mdot
.55485 .50275 Mdot
.60953 .50275 Mdot
.6533 .50275 Mdot
.68064 .50275 Mdot
.68592 .50275 Mdot
.66339 .50275 Mdot
.60714 .50275 Mdot
.51107 .50275 Mdot
.36882 .50275 Mdot
.17377 .50275 Mdot
0 0 0 r
.0002 w
.97619 .50275 m
.93457 .69858 L
.81689 .86054 L
.64352 .96064 L
.44441 .98157 L
.25401 .9197 L
.10524 .78574 L
.02381 .60285 L
.02381 .40265 L
.10524 .21976 L
.25401 .08581 L
.44441 .02394 L
.64352 .04487 L
.81689 .14497 L
.93457 .30693 L
.97619 .50275 L
s
0 0 m
1 0 L
1 1.00551 L
0 1.00551 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[125]:=",
  ImageSize->{288, 289.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00018B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00@?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Co
oooo0ol0000Gooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0001co
oooo0_l0000Qooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0001Ko
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`?o00008?ooool003oooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
01Gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0001_ooooo00Co0000oooooooooooo00007oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07oooool003Sooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`05o`00
00oooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0001oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Gooooo00Co0000oooo
oooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Go00008?ooool003oooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000oooooooo
ool05Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool06_ooool01?l0003oooooooooool0000Oooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo01oooooo000o
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
o`00000Gooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00007oooool01?l0003ooooooooo
ool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Coooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00
000Qooooo`00?oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
0_l0000Gooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00007oooool01?l0003ooooooooo
ool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Coooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool2o`00027ooooo0010
ooooo`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool05_ooool2o`0000[ooooo0_l00003
ooooo`?o00007Oooool2o`00027ooooo0_l0000:ooooo`;o00000oooool3o`0001Oooooo0_l0000:
ooooo`;o00001Oooool00ol0003oooooooooo`0Oooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`008Oooooono`00007ooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo0?[ooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`3jooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool0n_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo06cooooo1ol00027oooo
o`7o00000Oooool0027ooooo00?o0000ooooooooool0JOooool3o`0000Oooooo2_l0001mooooo`7o
00000Oooool0027ooooo0_l0001Wooooo`?o00005?ooool;o`00077ooooo0_l00001ooooo`008Ooo
ool00ol0003oooooooooo`1Sooooo`?o00008_ooool:o`0006Sooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`1Pooooo`?o0000;oooool:o`0005kooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`1Mooooo`?o0000??ooool6o`0005Sooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`1Jooooo`?o0000AOooool2o`0005Kooooo0Ol00001ooooo`008Oooool00ol0003ooooo
ooooo`1Gooooo`?o0000B_ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool0027ooooo00?o
0000ooooooooool0E?ooool3o`0004kooooo0_l0001Cooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool0DOooool3o`0005?ooooo0_l0001Aooooo`7o00000Oooool0027ooooo00?o0000oooo
ooooool0C_ooool3o`0005Sooooo00?o0000ooooooooool0C_ooool1o`00007ooooo000Qooooo`03
o`000?oooooooooo04_ooooo0ol0001Looooo`;o0000C_ooool1o`00007ooooo000Qooooo`03o`00
0?oooooooooo04Sooooo0ol0001Qooooo`;o0000C?ooool1o`00007ooooo000Qooooo`;o0000A_oo
ool3o`0006Kooooo00?o0000ooooooooool0B?ooool2o`00007ooooo000Qooooo`03o`000?oooooo
oooo04;ooooo0ol0001Zooooo`;o0000BOooool1o`00007ooooo000Qooooo`03o`000?oooooooooo
03oooooo0ol0001_ooooo`;o0000Aoooool1o`00007ooooo000Qooooo`03o`000?oooooooooo03co
oooo0ol0001dooooo`03o`000?oooooooooo04Cooooo0Ol00001ooooo`008Oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo07Kooooo0_l00014ooooo`7o00000Oooool0027ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`1iooooo`;o0000@_ooool1o`00007ooooo000Q
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0O?ooool2o`00043ooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool0?Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0POooool2o`0003gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo08Cooooo0_l0000kooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo03Sooooo0Ol00001ooooo`008Oooool2
o`0003Cooooo0_l0002;ooooo`;o0000=oooool2o`00007ooooo000Qooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0SOooool2o`0003Kooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0<oooool1o`00007o
oooo000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0T_ooool2o`0003?ooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09Gooooo0_l0
000aooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2H
ooooo`03o`000?oooooooooo02kooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo09[ooooo0_l0000^ooooo`7o00000Oooool0027ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo02_ooooo0Ol00001ooooo`00
2?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol00004ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0[ooooo`7o0000
0Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool2o`000:;ooooo00?o0000oooooooo
ool0:_ooool1o`00007ooooo0005o`0000;ooooo00Co0000oooooooooooo00002?ooool01Ol0003o
ooooooooool0003ooooo00Go00001?ooool2o`0002Wooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`0Xooooo`;o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0:?ooool1o`00007ooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Y_ooool00ol0003ooooo
ooooo`0Xooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00003ooooo`;o00001Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0:So
oooo00?o0000ooooooooool09oooool1o`00007ooooo0008ooooo`;o00002_ooool2o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0:[ooooo
00?o0000ooooooooool09_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`0Vooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02Gooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`0Pooooo`;o0000/Oooool00ol0003oooooooooo`0Toooo
o`7o00000Oooool0027ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo02?ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo0;?ooooo00?o0000ooooooooool08oooool1o`00007ooooo000Qooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`0Rooooo`7o00000Ooo
ool0027ooooo0_l0000Mooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooooooool08?ooool2
o`00007ooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0^Oooool00ol0
003oooooooooo`0Pooooo`7o00000Oooool0027ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo023ooooo0Ol00001ooooo`008Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool07oooool1o`00007ooooo
000Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0__ooool00ol0003ooooooooo
o`0Nooooo`7o00000Oooool0027ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`30
ooooo`03o`000?oooooooooo01gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool07Oooool1o`00007ooooo000Qooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0`_ooool00ol0003oooooooooo`0Looooo`7o
00000Oooool0027ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`33ooooo`03o`00
0?oooooooooo01_ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0<Cooooo00?o0000ooooooooool06oooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0aOooool00ol0003oooooooooo`0Jooooo`7o00000Oooool0
027ooooo0_l0000Fooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool06?ooool2o`00
007ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0b?ooool00ol0003o
ooooooooo`0Hooooo`7o00000Oooool0027ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`38ooooo`03o`000?oooooooooo01Sooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool05oooool1o`00007ooooo000Q
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0F
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3=oooo
o`03o`000?oooooooooo01Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0<gooooo00?o0000ooooooooool05Oooool1o`00007ooooo000Qooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0c_ooool00ol0003oooooooooo`0Dooooo`7o0000
0Oooool0027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3@ooooo`03o`000?oo
oooooooo01?ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo0=7ooooo00?o0000ooooooooool04_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0d_ooool00ol0003oooooooooo`0Booooo`7o00000Oooool0027o
oooo0_l0000Aooooo`03o`000?oooooooooo0=?ooooo00?o0000ooooooooool04?ooool2o`00007o
oooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0eOooool00ol0003ooooo
ooooo`0@ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`3Eooooo`03o`000?oooooooooo013ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0=Kooooo00?o0000ooooooooool03oooool1o`00007ooooo000Qoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0f?ooool00ol0003oooooooooo`0>oooo
o`7o00000Oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3Iooooo`03
o`000?oooooooooo00gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo0=[ooooo00?o0000ooooooooool03Oooool1o`00007ooooo000Qooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0f_ooool00ol0003oooooooooo`0=ooooo`7o00000Ooo
ool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00001?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0=cooooo00?o0000ooooooooool03?ooool1
o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
g?ooool00ol0003oooooooooo`0<ooooo`7o00000Oooool000Go00000_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo0=gooooo00?o0000ooooooooool03?ooool1o`00007o
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`03ooooo`;o00003?ooool00ol0003oooooooooo`3Mooooo`03o`000?oooooooooo
00_ooooo0_l00001ooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0gOooool00ol0003oooooooooo`0<ooooo`7o00000Oooool000Oooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0=oooooo00?o0000oooooooo
ool02oooool1o`00007ooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00005ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0goooool00ol0003oooooooooo`0;ooooo`7o0000
0Oooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3Pooooo`03o`000?oo
oooooooo00_ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo0>3ooooo00?o0000ooooooooool02oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0hOooool00ol0003oooooooooo`0;ooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Rooooo`03o`000?oooooooooo00[o
oooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0>;ooooo
00?o0000ooooooooool02_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0hoooool00ol0003oooooooooo`0:ooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3Sooooo`03o`000?oooooooooo00[ooooo0Ol00001
ooooo`008Oooool2o`0000Oooooo00?o0000ooooooooool0i?ooool00ol0003oooooooooo`09oooo
o`;o00000Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Uooooo`03
o`000?oooooooooo00Wooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0>Kooooo00?o0000ooooooooool02Oooool1o`00007ooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0i_ooool00ol0003oooooooooo`09ooooo`7o00000Ooo
ool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Vooooo`03o`000?oooooo
oooo00Wooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0>Oooooo00?o0000ooooooooool02Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0j?ooool00ol0003oooooooooo`08ooooo`7o00000Oooool0027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo00Sooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>Wooooo00?o
0000ooooooooool02?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0jOooool00ol0003oooooooooo`08ooooo`7o00000Oooool0027ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo00Sooooo0Ol00001oooo
o`008Oooool2o`0000Cooooo00?o0000ooooooooool0j_ooool00ol0003oooooooooo`06ooooo`;o
00000Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Zooooo`03o`00
0?oooooooooo00Oooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0>[ooooo00?o0000ooooooooool01oooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0j_ooool00ol0003oooooooooo`07ooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Zooooo`03o`000?oooooooooo
00Oooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>_o
oooo00?o0000ooooooooool01_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0joooool00ol0003oooooooooo`06ooooo`7o00000Oooool0027ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3[ooooo`03o`000?oooooooooo00Kooooo0Ol0
0001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>_ooooo00?o0000
ooooooooool01_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0joooool00ol0003oooooooooo`06ooooo`7o00000Oooool0027ooooo0_l00004ooooo`03
o`000?oooooooooo0>cooooo00?o0000ooooooooool01?ooool2o`00007ooooo000Qooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`05ooooo`7o0000
0Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3/ooooo`03o`000?oo
oooooooo00Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0>cooooo00?o0000ooooooooool01Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`05ooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Co
oooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>gooooo
00?o0000ooooooooool01?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0kOooool00ol0003oooooooooo`04ooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Cooooo0Ol00001
ooooo`006_ooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3]oooo
o`03o`000?oooooooooo00Cooooo0Ol00001ooooo`006Oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_ooool00ol0003oooooooooo`03oooo
o`7o00000Oooool001Wooooo00Co0000oooooooooooo00001?ooool2o`0000Cooooo00?o0000oooo
ooooool08_ooool2o`WZ2Qoooooo0ol9jPX3ooooo`Co2NX:1_ooool2o`WZ2P04ooooool9jP[o2NX:
o`WZ2P_ooooo0_l9jPX9ooooo`;o2NX:0_ooool2o`WZ2P?ooooo0_l9jPX9ooooo`;o2NX:2oooool5
o`WZ2POooooo1?l9jPX3ooooo`?o2NX:7oooool2o`WZ2ROooooo00?o0000ooooooooool00_ooool2
o`00007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Rooooo`;o2NX:7oooool3o`WZ2P?ooooo1?l9jPX6ooooo`;o2NX:00Cooooo
o`WZ2_l9jP[o2NX:2oooool2o`WZ2PWooooo0_l9jPX2ooooo`;o2NX:0oooool2o`WZ2PWooooo0_l9
jPX;ooooo`Go2NX:1oooool4o`WZ2P?ooooo0ol9jPXOooooo`;o2NX:9oooool00ol0003ooooooooo
o`03ooooo`7o00000Oooool001Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool00oooool1o`00007ooooo000I
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3]ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`006_ooool2o`0000Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Cooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>gooooo00?o0000oooo
ooooool01?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0kOooool00ol0003oooooooooo`04ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>cooooo00?o0000ooooooooool01Ooo
ool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0k?ooool0
0ol0003oooooooooo`05ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3/ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`008Oooool2o`0000Co
oooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`04ooooo`;o00000Oooool0027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo00Gooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>_ooooo00?o
0000ooooooooool01_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0joooool00ol0003oooooooooo`06ooooo`7o00000Oooool0027ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3[ooooo`03o`000?oooooooooo00Kooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>_ooooo00?o0000oooooooo
ool01_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
joooool00ol0003oooooooooo`06ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3Zooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>[ooooo00?o0000ooooooooool01oooool1
o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0j_ooool00ol0
003oooooooooo`07ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3Zooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`008Oooool2o`0000Cooooo
00?o0000ooooooooool0j_ooool00ol0003oooooooooo`06ooooo`;o00000Oooool0027ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo00Sooooo0Ol0
0001ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>Wooooo00?o0000
ooooooooool02?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0jOooool00ol0003oooooooooo`08ooooo`7o00000Oooool0027ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`00
8Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>Wooooo00?o0000ooooooooool0
2?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0iooo
ool00ol0003oooooooooo`09ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3Wooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0>Kooooo00?o0000ooooooooool02Oooool1o`00
007ooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i_ooool00ol0003o
ooooooooo`09ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3Vooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`008Oooool2o`0000Oooooo00?o
0000ooooooooool0i?ooool00ol0003oooooooooo`09ooooo`;o00000Oooool0027ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3Tooooo`03o`000?oooooooooo00[ooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0>?ooooo00?o0000oooo
ooooool02_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0hoooool00ol0003oooooooooo`0:ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`3Rooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0>7ooooo00?o0000ooooooooool02ooo
ool1o`00007ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0hOooool0
0ol0003oooooooooo`0;ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`3Pooooo`03o`000?oooooooooo00_ooooo0Ol00001ooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0h?ooool00ol0003oooooooooo`0;ooooo`7o00000Oooool000Oooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Oooooo`03o`000?oooooo
oooo00_ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo0=kooooo00?o0000ooooooooool03?ooool1o`00007ooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`;o0000
3?ooool00ol0003oooooooooo`3Mooooo`03o`000?oooooooooo00_ooooo0_l00001ooooo`001ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0gOooool00ol0
003oooooooooo`0<ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo0=gooooo00?o0000ooooooooool03?ooool1o`00007ooooo0008
ooooo`;o00002_ooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0g?ooool00ol0003oooooooooo`0<ooooo`7o00000Oooool0027ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`3Kooooo`03o`000?oooooooooo00gooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0=[ooooo00?o0000oooooooo
ool03Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
f_ooool00ol0003oooooooooo`0=ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`3Iooooo`03o`000?oooooooooo00gooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0=Sooooo00?o0000ooooooooool03_ooool1
o`00007ooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0e_ooool00ol0
003oooooooooo`0?ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`3Eooooo`03o`000?oooooooooo013ooooo0Ol00001ooooo`008Oooool2o`00013ooooo
00?o0000ooooooooool0eOooool00ol0003oooooooooo`0?ooooo`;o00000Oooool0027ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`3Cooooo`03o`000?oooooooooo017ooooo0Ol0
0001ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0=;ooooo00?o0000
ooooooooool04_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0dOooool00ol0003oooooooooo`0Booooo`7o00000Oooool0027ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`3@ooooo`03o`000?oooooooooo01?ooooo0Ol00001ooooo`00
8Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0<kooooo00?o0000ooooooooool0
5?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0cOoo
ool00ol0003oooooooooo`0Eooooo`7o00000Oooool0027ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`3=ooooo`03o`000?oooooooooo01Gooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool05_ooool1o`00
007ooooo000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0b_ooool00ol0003o
ooooooooo`0Gooooo`7o00000Oooool0027ooooo0_l0000Eooooo`03o`000?oooooooooo0<Sooooo
00?o0000ooooooooool05oooool2o`00007ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0b?ooool00ol0003oooooooooo`0Hooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo01Wooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<Gooooo00?o0000oooo
ooooool06_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0a?ooool00ol0003oooooooooo`0Kooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo01_ooooo0Ol00001ooooo`008Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool07?oo
ool1o`00007ooooo000Qooooo`03o`000?oooooooooo01Oooooo0_l00031ooooo`03o`000?oooooo
oooo01gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
0;kooooo00?o0000ooooooooool07Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`0Nooooo`7o00000Oooool0027ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo01oooooo
0Ol00001ooooo`008Oooool2o`0001gooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0Oooooo`;o00000Oooool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2g
ooooo`03o`000?oooooooooo023ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool08Oooool1o`00007ooooo000Qooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0Rooooo`7o
00000Oooool0027ooooo00?o0000ooooooooool08?ooool2o`000;;ooooo00?o0000ooooooooool0
8oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0[ooo
ool00ol0003oooooooooo`0Sooooo`7o00000Oooool0027ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02Cooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool09Oooool1o`00
007ooooo000Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0ZOooool00ol0003o
ooooooooo`0Vooooo`7o00000Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0_l00004ooooo`?o00001?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0:Sooooo
00?o0000ooooooooool09_ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0Wooooo`7o00000Oooool000Oooooo
00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Go00001?ooool2o`00
02Wooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0Wooooo`;o00000Oooool000Oo
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0:?ooooo00?o
0000ooooooooool0:?ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo02[ooooo
0_l0002Rooooo`03o`000?oooooooooo02Wooooo0Ol00001ooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l00005ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0Zooooo`7o00000Oooool000Sooooo
0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0Voooool2o`0002gooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo09Sooooo0_l0000_ooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo02oooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo0_l0000boooo
o`7o00000Oooool0027ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2@ooooo`;o
0000=?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
SOooool2o`0003Kooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0cooooo`;o0000S?oo
ool00ol0003oooooooooo`0fooooo`7o00000Oooool0027ooooo0_l0000fooooo`03o`000?oooooo
oooo08Oooooo0_l0000hooooo`;o00000Oooool0027ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`24ooooo`;o0000>oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0POooool2o`0003gooooo0Ol00001ooooo`008Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0?Oooool1o`00007ooooo
000Qooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0O?ooool2o`00043ooooo0Ol0
0001ooooo`008Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo07Wooooo0_l00012
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1foooo
o`;o0000A?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0Loooool2o`0004Kooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0mooooo`?o0000
LOooool00ol0003oooooooooo`16ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0@?oo
ool3o`0006cooooo0_l00019ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0@oooool3
o`0006Oooooo0_l0001;ooooo`7o00000Oooool0027ooooo0_l00017ooooo`?o0000H_ooool2o`00
04cooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`19ooooo`?o0000G_ooool00ol0003o
ooooooooo`1=ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0C?ooool3o`0005Wooooo
0_l0001@ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0Coooool3o`0005Cooooo0_l0
001Booooo`7o00000Oooool0027ooooo00?o0000ooooooooool0D_ooool3o`0004oooooo0_l0001D
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0EOooool3o`0004_ooooo00?o0000oooo
ooooool0E?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo05Sooooo0ol00016ooooo`;o
0000Eoooool1o`00007ooooo000Qooooo`03o`000?oooooooooo05_ooooo0ol0000nooooo`Go0000
FOooool1o`00007ooooo000Qooooo`03o`000?oooooooooo05kooooo0ol0000booooo`Wo0000G_oo
ool1o`00007ooooo000Qooooo`03o`000?oooooooooo067ooooo0ol0000Wooooo`So0000Ioooool1
o`00007ooooo000Qooooo`03o`000?oooooooooo06Cooooo0ol0000Kooooo`Wo0000Koooool1o`00
007ooooo000Qooooo`;o0000J?ooool3o`00013ooooo2?l0001gooooo`;o00000Oooool0027ooooo
00?o0000ooooooooool0J_ooool3o`0000Cooooo2Ol00020ooooo`7o00000Oooool0027ooooo00?o
0000ooooooooool0KOooool4o`0008Wooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`3j
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Qooooo`03
o`000?oooooooooo0?[ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool09_ooool1o`00007ooooo000Qooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`7o00000Ooo
ool0027oooooo_l00001ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {288.562, 0}} -> {-0.0731255, -0.0692906, \
0.000460811, 0.000460811}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"Screen", "\[Rule]", 
          TagBox[
            StyleBox[
              
              TagBox[\(Move[Screen[0.11257126058009825`], 
                  102.63804780794283`]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(TurboSystem \[Rule] "-traced system-"\), 
        ",", \(FocalPoint \[Rule] {102.63804780794283`, 0, 0}\), 
        ",", \(FocusType \[Rule] RMSFocus\), 
        ",", \(WeightedSpotSize \[Rule] 0.018859993933788476`\), 
        ",", \(SpotSize \[Rule] 0.01885999393378848`\), 
        ",", \(BackFocalLength \[Rule] 92.63804780794283`\), 
        ",", \(FocalPlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(TurboRays \[Rule] "-ray intercepts of 1 surfaces-"\)}], 
      "}"}]], "Output",
  CellLabel->"Out[125]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
lensparameters = FindLensParameters[opticalsystem,FindImagePoint->True]\
\>", "Input",
  CellLabel->"In[126]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] 0.49966958432041564`\), 
        ",", \(BackFocalLength \[Rule] 93.35095557506479`\), 
        ",", \(BackFocalPoint \[Rule] {103.35095557506479`, 0, 0}\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] 0\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {0, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.583004929987583`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {3.416995070012417`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 1\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 1, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 1}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalLength \[Rule] 99.93396050505237`\), 
        ",", \(FrontFocalLength \[Rule] 99.93396050505234`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-99.93396050505234`\), 0, 0}\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {102.50971221923828`, 0, 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(PlanoConvexLens[100, 50, 10]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[Screen[1], {103 + d, 103.`}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.9341264481391712`, 
              6.583004929987581`}, {\(-0.010006608313591684`\), 
              0.9999999999999998`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(Move[LineOfRays[20], {\(-50.`\), {y, 0}}]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(OpticalMedium \[Rule] Air\), 
        ",", "\<\"-Options-\"\>", 
        ",", \(PrinciplePoints \[Rule] {{2.842170943040401`*^-14, 0, 
              0}, {3.416995070012419`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 3.4169950700123906`\), 
        ",", \(SourceID \[Rule] 17849\), 
        ",", \(SystemABCDMatrix \[Rule] {{0.003511874975144755`, 
              99.75859867874478`}, {\(-0.010006608313591682`\), 
              0.49966958432041564`}}\), 
        ",", \(TransverseMagnification \[Rule] 0.003511874975144755`\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", \(WaveLength \[Rule] 0.532`\)}], 
      "}"}]], "Output",
  CellLabel->"Out[126]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["pupilfunction = PupilFunction[lensparameters]", "Input",
  CellLabel->"In[127]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0475462 -20721.4 353.467 [
[.02454 -0.0125 -9 -9 ]
[.02454 -0.0125 9 0 ]
[.26227 -0.0125 -6 -9 ]
[.26227 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.73773 -0.0125 -3 -9 ]
[.73773 -0.0125 3 0 ]
[.97546 -0.0125 -6 -9 ]
[.97546 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04208 -42 -4.5 ]
[-0.0125 .04208 0 4.5 ]
[-0.0125 .13044 -42 -4.5 ]
[-0.0125 .13044 0 4.5 ]
[-0.0125 .21881 -36 -4.5 ]
[-0.0125 .21881 0 4.5 ]
[-0.0125 .30718 -42 -4.5 ]
[-0.0125 .30718 0 4.5 ]
[-0.0125 .39554 -42 -4.5 ]
[-0.0125 .39554 0 4.5 ]
[-0.0125 .48391 -42 -4.5 ]
[-0.0125 .48391 0 4.5 ]
[-0.0125 .57228 -36 -4.5 ]
[-0.0125 .57228 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02454 0 m
.02454 .00625 L
s
[(-10)] .02454 -0.0125 0 1 Mshowa
.26227 0 m
.26227 .00625 L
s
[(-5)] .26227 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.73773 0 m
.73773 .00625 L
s
[(5)] .73773 -0.0125 0 1 Mshowa
.97546 0 m
.97546 .00625 L
s
[(10)] .97546 -0.0125 0 1 Mshowa
.125 Mabswid
.07208 0 m
.07208 .00375 L
s
.11963 0 m
.11963 .00375 L
s
.16718 0 m
.16718 .00375 L
s
.21472 0 m
.21472 .00375 L
s
.30982 0 m
.30982 .00375 L
s
.35736 0 m
.35736 .00375 L
s
.40491 0 m
.40491 .00375 L
s
.45245 0 m
.45245 .00375 L
s
.54755 0 m
.54755 .00375 L
s
.59509 0 m
.59509 .00375 L
s
.64264 0 m
.64264 .00375 L
s
.69018 0 m
.69018 .00375 L
s
.78528 0 m
.78528 .00375 L
s
.83282 0 m
.83282 .00375 L
s
.88037 0 m
.88037 .00375 L
s
.92792 0 m
.92792 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04208 m
.00625 .04208 L
s
[(58.6235)] -0.0125 .04208 1 0 Mshowa
0 .13044 m
.00625 .13044 L
s
[(58.6238)] -0.0125 .13044 1 0 Mshowa
0 .21881 m
.00625 .21881 L
s
[(58.624)] -0.0125 .21881 1 0 Mshowa
0 .30718 m
.00625 .30718 L
s
[(58.6243)] -0.0125 .30718 1 0 Mshowa
0 .39554 m
.00625 .39554 L
s
[(58.6245)] -0.0125 .39554 1 0 Mshowa
0 .48391 m
.00625 .48391 L
s
[(58.6248)] -0.0125 .48391 1 0 Mshowa
0 .57228 m
.00625 .57228 L
s
[(58.625)] -0.0125 .57228 1 0 Mshowa
.125 Mabswid
0 .05975 m
.00375 .05975 L
s
0 .07742 m
.00375 .07742 L
s
0 .0951 m
.00375 .0951 L
s
0 .11277 m
.00375 .11277 L
s
0 .14812 m
.00375 .14812 L
s
0 .16579 m
.00375 .16579 L
s
0 .18346 m
.00375 .18346 L
s
0 .20114 m
.00375 .20114 L
s
0 .23648 m
.00375 .23648 L
s
0 .25416 m
.00375 .25416 L
s
0 .27183 m
.00375 .27183 L
s
0 .2895 m
.00375 .2895 L
s
0 .32485 m
.00375 .32485 L
s
0 .34252 m
.00375 .34252 L
s
0 .3602 m
.00375 .3602 L
s
0 .37787 m
.00375 .37787 L
s
0 .41322 m
.00375 .41322 L
s
0 .43089 m
.00375 .43089 L
s
0 .44856 m
.00375 .44856 L
s
0 .46624 m
.00375 .46624 L
s
0 .50158 m
.00375 .50158 L
s
0 .51926 m
.00375 .51926 L
s
0 .53693 m
.00375 .53693 L
s
0 .5546 m
.00375 .5546 L
s
0 .0244 m
.00375 .0244 L
s
0 .00673 m
.00375 .00673 L
s
0 .58995 m
.00375 .58995 L
s
0 .60762 m
.00375 .60762 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02454 .61178 m
.02454 .61803 L
s
.26227 .61178 m
.26227 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.73773 .61178 m
.73773 .61803 L
s
.97546 .61178 m
.97546 .61803 L
s
.125 Mabswid
.07208 .61428 m
.07208 .61803 L
s
.11963 .61428 m
.11963 .61803 L
s
.16718 .61428 m
.16718 .61803 L
s
.21472 .61428 m
.21472 .61803 L
s
.30982 .61428 m
.30982 .61803 L
s
.35736 .61428 m
.35736 .61803 L
s
.40491 .61428 m
.40491 .61803 L
s
.45245 .61428 m
.45245 .61803 L
s
.54755 .61428 m
.54755 .61803 L
s
.59509 .61428 m
.59509 .61803 L
s
.64264 .61428 m
.64264 .61803 L
s
.69018 .61428 m
.69018 .61803 L
s
.78528 .61428 m
.78528 .61803 L
s
.83282 .61428 m
.83282 .61803 L
s
.88037 .61428 m
.88037 .61803 L
s
.92792 .61428 m
.92792 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04208 m
1 .04208 L
s
.99375 .13044 m
1 .13044 L
s
.99375 .21881 m
1 .21881 L
s
.99375 .30718 m
1 .30718 L
s
.99375 .39554 m
1 .39554 L
s
.99375 .48391 m
1 .48391 L
s
.99375 .57228 m
1 .57228 L
s
.125 Mabswid
.99625 .05975 m
1 .05975 L
s
.99625 .07742 m
1 .07742 L
s
.99625 .0951 m
1 .0951 L
s
.99625 .11277 m
1 .11277 L
s
.99625 .14812 m
1 .14812 L
s
.99625 .16579 m
1 .16579 L
s
.99625 .18346 m
1 .18346 L
s
.99625 .20114 m
1 .20114 L
s
.99625 .23648 m
1 .23648 L
s
.99625 .25416 m
1 .25416 L
s
.99625 .27183 m
1 .27183 L
s
.99625 .2895 m
1 .2895 L
s
.99625 .32485 m
1 .32485 L
s
.99625 .34252 m
1 .34252 L
s
.99625 .3602 m
1 .3602 L
s
.99625 .37787 m
1 .37787 L
s
.99625 .41322 m
1 .41322 L
s
.99625 .43089 m
1 .43089 L
s
.99625 .44856 m
1 .44856 L
s
.99625 .46624 m
1 .46624 L
s
.99625 .50158 m
1 .50158 L
s
.99625 .51926 m
1 .51926 L
s
.99625 .53693 m
1 .53693 L
s
.99625 .5546 m
1 .5546 L
s
.99625 .0244 m
1 .0244 L
s
.99625 .00673 m
1 .00673 L
s
.99625 .58995 m
1 .58995 L
s
.99625 .60762 m
1 .60762 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .55564 Mdot
.05462 .59478 Mdot
.08541 .60332 Mdot
.11618 .58725 Mdot
.14694 .55204 Mdot
.17769 .50271 Mdot
.20842 .44379 Mdot
.23915 .37936 Mdot
.26986 .31306 Mdot
.30056 .24812 Mdot
.33126 .18732 Mdot
.36195 .13305 Mdot
.39263 .08728 Mdot
.42331 .05159 Mdot
.45399 .02714 Mdot
.48466 .01472 Mdot
.51534 .01472 Mdot
.54601 .02714 Mdot
.57669 .05159 Mdot
.60737 .08728 Mdot
.63805 .13305 Mdot
.66874 .18732 Mdot
.69944 .24812 Mdot
.73014 .31306 Mdot
.76085 .37936 Mdot
.79158 .44379 Mdot
.82231 .50271 Mdot
.85306 .55204 Mdot
.88382 .58725 Mdot
.91459 .60332 Mdot
.94538 .59478 Mdot
.97619 .55564 Mdot
.5 Mabswid
.02381 .55564 m
.03837 .57413 L
.04579 .58356 L
.04987 .58874 L
.05187 .59128 L
.05372 .59363 L
.0547 .5948 L
.0552 .59494 L
.05574 .59509 L
.05794 .5957 L
.06178 .59676 L
.06929 .59885 L
.07385 .60011 L
.07819 .60132 L
.08209 .6024 L
.08316 .60269 L
.08429 .60301 L
.08485 .60316 L
.08537 .60331 L
.08634 .60283 L
.10137 .59499 L
.10923 .59088 L
.11352 .58864 L
.1146 .58808 L
.11562 .58754 L
.11654 .58685 L
.11753 .58571 L
.12111 .58161 L
.12494 .57723 L
.13308 .56792 L
.14738 .55135 L
.17895 .5003 L
.20935 .44184 L
.23858 .38055 L
.2697 .3134 L
.29965 .25004 L
.3315 .18689 L
.36218 .1327 L
.39168 .0887 L
.40814 .06924 L
.41591 .06019 L
.42309 .05185 L
.42671 .04888 L
.43055 .04582 L
.43863 .03937 L
.44631 .03326 L
.44966 .03059 L
.45143 .02917 L
.45331 .02767 L
.45433 .02699 L
Mistroke
.45526 .02662 L
.45706 .02589 L
.46062 .02445 L
.46847 .02127 L
.47537 .01848 L
.47913 .01695 L
.48265 .01553 L
.48357 .01516 L
.48444 .01481 L
.48544 .01472 L
.48636 .01472 L
.49043 .01472 L
.49758 .01472 L
.5054 .01472 L
.50969 .01472 L
.51179 .01472 L
.5127 .01472 L
.51371 .01472 L
.5146 .01472 L
.51543 .01475 L
.51631 .01511 L
.51724 .01549 L
.52105 .01703 L
.52915 .02031 L
.53658 .02332 L
.54342 .02609 L
.54438 .02648 L
.54542 .02689 L
.54639 .02744 L
.54729 .02815 L
.54923 .0297 L
.55137 .03141 L
.55998 .03827 L
.56808 .04473 L
.57559 .05071 L
.58274 .05863 L
.59035 .06747 L
.60641 .08617 L
.63561 .12941 L
.66671 .18373 L
.69664 .24257 L
.72846 .30951 L
.75912 .3756 L
.78859 .43753 L
.81997 .49823 L
.85018 .54742 L
.86557 .56637 L
.87368 .57565 L
.87812 .58073 L
.88029 .58322 L
Mistroke
.88228 .58549 L
.88318 .58652 L
.88417 .58743 L
.8851 .58792 L
.88597 .58837 L
.88993 .59044 L
.89836 .59485 L
.9055 .59857 L
.90925 .60053 L
.91129 .6016 L
.91321 .6026 L
.91419 .60311 L
.91474 .60328 L
.91524 .60314 L
.91747 .60252 L
.9214 .60143 L
.92911 .59929 L
.9361 .59735 L
.93992 .59629 L
.94352 .59529 L
.94437 .59506 L
.94527 .59481 L
.94626 .59366 L
.94717 .5925 L
.9512 .58739 L
.9583 .57836 L
.97438 .55794 L
.97619 .55564 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[127]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00<?ooool3o`0000Cooooo0_l0000dooooo`?o0000=?ooool2o`0003Oo
oooo0ol0000cooooo`?o00001?ooool2o`0000Cooooo000aooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000<_ooool01Ol0003ooooooooooooooooo000003;ooooo00Co0000oooo
oooooooo0000=Oooool01Ol0003ooooooooooooooooo000003?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`00:Oooool5o`0000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000/ooooo`Go00001Oooool00ol0003oooooooooo`0`ooooo`04o`00
0?ooooooooooo`0003Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo000aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=_ooool00ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`0003Wooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo000a
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000<_ooool4o`0003?ooooo00Co
0000oooooooooooo0000=Oooool4o`0003Cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`00<?ooool2o`0000Cooooo00Co0000oooooooooooo0000<_ooool00ol0003o
ooooooooo`0dooooo`04o`000?ooooooooooo`0003Gooooo00?o0000ooooooooool0=?ooool2o`00
00Cooooo00Co0000oooooooooooo00000oooool0037ooooo00?o0000ooooooooool00oooool2o`00
03?ooooo1Ol0000cooooo`;o0000=_ooool5o`0003?ooooo00?o0000ooooooooool00oooool2o`00
00Cooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000]oooo
oo;o00000Oooool002gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`;o0000
0Oooool002gooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`1fooooo`7o00000Ooo
ool002gooooo00?o0000ooooooooool0L?ooool=o`00077ooooo0Ol00001ooooo`00;Oooool00ol0
003oooooooooo`1]ooooo`?o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`02o`00
00?ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`;o0000KOooool2o`00007o
oooo000]ooooo`03o`000?oooooooooo06[ooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo
0_l0001/ooooo`7o00000Oooool00004ooooool0003o0000o`0000?ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00002ooooo`Go00000_ooool3o`0000?ooooo0ol00005ooooo`03o`00
0?oooooooooo06Sooooo1?l00009ooooo`03o`000?oooooooooo00Sooooo0ol0001[ooooo`7o0000
0Oooool00007o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0J?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0J?oo
ool1o`00007ooooo0004ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo0_l0001Wooooo`;o00003Oooool00ol0003ooooooooo
o`0<ooooo`;o0000Ioooool2o`00007ooooo0004ooooo`03o`000?oooooooooo00?o00002?ooool4
o`0000Gooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1Uooooo`7o00000Oooool000Co00000_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooool000000ol00005ooooo`03o`000?oooooooooo06;ooooo0ol0000@ooooo`03o`000?oo
oooooooo00oooooo0_l0001Uooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooooooooooooo
o`000?oooooo000000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`1Rooooo`;o
00004Oooool00ol0003oooooooooo`0?ooooo`;o0000IOooool1o`00007ooooo0005o`0000;ooooo
0ol0000:ooooo`;o00000oooool3o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1Rooooo`7o00000Oooool002gooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0HOooool2o`00007ooooo000]
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo067ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Poooo
o`7o00000Oooool002gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0Goooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo05gooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Mooooo`7o00000Ooo
ool002gooooo00?o0000ooooooooool0Foooool2o`0001Sooooo00?o0000ooooooooool05oooool2
o`0005gooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1Kooooo`;o00006?ooool00ol0
003oooooooooo`0Gooooo`;o0000GOooool1o`00007ooooo000]ooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05[o
oooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Jooooo`7o00000Oooool002gooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0F_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`1Hooooo`7o00000Oooool002gooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0Eoooool2o`00007ooooo00001?oooooo0000o`000?l00003ooooo`?o00001?ooool00ol0003o
ooooooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol00003ooooo`?o00001Oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`1Gooooo`7o00000Oooool00007o`000?ooooooooooooooool0003oooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0Eoooool1o`00007ooooo0004ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
EOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
E_ooool1o`00007ooooo0004ooooo`03o`000?oooooooooo00?o00002?ooool4o`0000Gooooo00?o
0000ooooooooool00_ooool2o`0000?ooooo0ol00005ooooo`;o0000E?ooool2o`00023ooooo00?o
0000ooooooooool07_ooool2o`0005Gooooo0_l00001ooooo`001?l00002ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Doooool2o`00023ooooo00?o0000ooooooooool07_ooool2o`0005Kooooo0Ol00001ooooo`0000?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0E?ooool1o`00007ooooo0005o`0000;o
oooo0ol0000:ooooo`;o00000oooool3o`0000?ooooo0ol00003ooooo`?o00001Oooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1Cooooo`7o00000Oooool002gooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0D_ooool2o`00007ooooo
000]ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo05;ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1B
ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0DOooool1o`00007ooooo000]ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo04oooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1@ooooo`7o0000
0Oooool002gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0Coooool1o`00007ooooo000]ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo04oooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1>ooooo`7o00000Oooool002go
oooo00?o0000ooooooooool0C?ooool2o`0002Oooooo00?o0000ooooooooool09_ooool2o`0004go
oooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`1<ooooo`;o00009oooool00ol0003ooooo
ooooo`0Vooooo`;o0000C_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04cooooo0Ol0
0001ooooo`00;Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`1<ooooo`7o00000Oooool002gooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0B_ooool2o`00007ooooo000]ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04_ooooo0Ol00001ooooo`00
1oooool3o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go0000
0oooool3o`0000Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0B_ooool1o`00007ooooo0006ooooo`07o`000?oo
ooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`1:ooooo`7o00000Oooool000[ooooo00?o0000ooooool000000oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooooooo
ool5o`0000Cooooo0_l0001:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`18ooooo`;o00000Oooool000[ooooo00?o0000ooooooooool00ol00008
ooooo`Co00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0BOooool1o`00007ooooo0006ooooo`Co00000_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`18ooooo`7o00000Oooool000Kooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00005ooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04So
oooo0Ol00001ooooo`001_ooool5o`0000;ooooo0ol0000:ooooo`;o00000oooool3o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`16ooooo`;o00000Oooool002gooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0Aoooool1o`00007ooooo000]ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Kooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`15ooooo`;o0000;_ooool00ol0003oooooooooo`0]oooo
o`;o0000Aoooool1o`00007ooooo000]ooooo`03o`000?oooooooooo04Gooooo0_l0000^ooooo`03
o`000?oooooooooo02gooooo0_l00017ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
A?ooool2o`00007ooooo000]ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04Cooooo0Ol00001ooooo`00;Oooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`14ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0@oooool1o`00
007ooooo000]ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo04;ooooo0_l00001ooooo`00;Oooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`12ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0@_ooool1o`00007ooooo000]
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo047ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`10oooo
o`;o00000Oooool002gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0@?ooool1o`00007ooooo00001?oooooo0000
o`000?l00003ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000?o
oooo0ol00002ooooo`?o00001Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`10ooooo`7o00000Oooool00007o`00
0?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03oooooo0Ol00001ooooo`001?oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo03oooooo0Ol00001ooooo`001?ooool00ol0003oooooooooo`03o`0000Sooooo
1?l00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Go
oooo0_l00010ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0mooooo`;o00000Oooool000Co00000_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03gooooo0_l0000foooo
o`03o`000?oooooooooo03Cooooo0_l00010ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0?Oooool2o`0003Kooooo00?o0000ooooooooool0=?ooool3o`0003oooooo0Ol0
0001ooooo`001Ol00002ooooo`?o00002_ooool2o`0000?ooooo0ol00005ooooo`04o`000?oooooo
ooooooooo`?o00001Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0mooooo`7o00000Oooool002gooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0>oooool2o`00007ooooo000]ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03cooooo0Ol00001oooo
o`00;Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0looooo`7o00000Oooool002gooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
>oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03[ooooo0_l00001ooooo`00;Oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0jooooo`7o00000Oooool002gooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>_ooool1o`00
007ooooo000]ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0Ol00001ooooo`00;Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0hooooo`;o00000Oooool002gooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>Oooool1o`00007ooooo000]
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo03Sooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0hoooo
o`7o00000Oooool002gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0=oooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo03Kooooo0_l0000mooooo`03o`000?oooooooooo03cooooo0_l0000gooooo`;o0000
0Oooool00004ooooool0003o0000o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo
0ol00002ooooo`Go00000oooool3o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo03Kooooo
0_l0000mooooo`03o`000?oooooooooo03cooooo0_l0000hooooo`7o00000Oooool00007o`000?oo
ooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03Kooooo0Ol00001ooooo`001?ooool0
0ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03Gooooo0Ol00001ooooo`001?ooool00ol0003oooooooooo`03o`0000Sooooo1?l0
0005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`;o0000=Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0=?ooool2o`00007ooooo0004o`0000;ooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooo000000;ooooo1?l00005ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03Cooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0=?ooool1o`00007ooooo0005o`0000;ooooo0ol0000:ooooo`;o
00000oooool3o`0000Gooooo00?o0000ooooooooool01Ol00004ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03?o
oooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0booooo`;o00000Oooool002gooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0<oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03;ooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0booooo`7o00000Oooool002gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0<Oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo033ooooo0_l00001ooooo`00;Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`0`ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0;_ooool2
o`0004Gooooo00?o0000ooooooooool0@oooool2o`00037ooooo0Ol00001ooooo`00;Oooool00ol0
003oooooooooo`0^ooooo`;o0000AOooool00ol0003oooooooooo`13ooooo`;o0000<Oooool1o`00
007ooooo000]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo02kooooo0_l00001ooooo`00;Oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0^ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0;_ooool1o`00007ooooo000]
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo02gooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0/oooo
o`;o00000Oooool002gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool0;?ooool1o`00007ooooo00001?oooooo0000
o`000?l00003ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000?o
oooo0ol00002ooooo`?o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0[ooooo`7o00000Oooool00007o`00
0?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02_ooooo0Ol00001ooooo`001?oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooooooo`Go000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`02ooooo`;o0000:oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool0:Oooool2o`00007ooooo0004ooooo`03o`000?oooooooooo00?o0000
2?ooool4o`0000Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooooooool3o`00
00Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0:_ooool1o`00007ooooo0004o`0000;ooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo02Wooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
0_l00002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Yooooo`7o
00000Oooool000Go00000_ooool3o`0000[ooooo0_l00003ooooo`?o00001Oooool01?l0003ooooo
ooooooooool3o`0000Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool0:?ooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo02Oooooo0_l0001<ooooo`03o`000?oooooooooo04_ooooo0_l0000Xooooo`;o0000
0Oooool002gooooo00?o0000ooooooooool09oooool2o`0004cooooo00?o0000ooooooooool0Booo
ool2o`0002Wooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Wooooo`7o00000Oooool0
02gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool09_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Co
oooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Uooooo`7o00000Oooool002gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool09?ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Cooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0Rooooo`;o00000Oooool002gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo057ooooo00?o0000oooooooo
ool08_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02;ooooo0Ol00001ooooo`00;Ooo
ool00ol0003oooooooooo`0Oooooo`?o0000Doooool00ol0003oooooooooo`1Booooo`;o00008_oo
ool1o`00007ooooo000]ooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`;o0000E?ooool0
0ol0003oooooooooo`1Booooo`;o00007?ooool2o`0000?ooooo0_l00001ooooo`00;Oooool00ol0
003oooooooooo`02ooooo`;o00007?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool06Oooool2o`0000Cooooo0Ol00001ooooo`001oooool3o`0000?o
oooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00000_ooool3o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?o
oooo0Ol00001ooooo`001_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool01?ooool1o`00007ooooo000:ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`05ooooo`7o00000Oooool000[ooooo00?o
0000ooooooooool00ol00008ooooo`Co00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo0_l00007ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool2o`00007ooooo0006ooooo`Co00000_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00oooool01_l0003ooooooooooooooooo0000ooooo`Co00001Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`1Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool1o`00007o
oooo0006ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo0Ol00001
ooooo`001_ooool5o`0000;ooooo0ol0000:ooooo`;o00000oooool3o`0000;ooooo1Ol00004oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool2o`0005_ooooo00?o0000oooo
ooooool0F_ooool2o`0000oooooo00?o0000ooooooooool02?ooool1o`00007ooooo000]ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool4o`0005_ooooo00?o0000oooooooo
ool0F_ooool4o`0000gooooo00?o0000ooooooooool01oooool2o`00007ooooo000]ooooo`03o`00
0?oooooooooo00Wooooo0ol00008ooooo`;o0000Goooool00ol0003oooooooooo`1Nooooo`;o0000
2?ooool3o`0000_ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`09ooooo`Ko00000ooo
ool2o`00067ooooo00?o0000ooooooooool0H?ooool01?l0003oooooooooooooool6o`0000cooooo
0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0?ooooo`?o0000Hoooool00ol0003ooooooooo
o`1Pooooo`Co00004_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo013ooooo0_l0001S
ooooo`03o`000?oooooooooo067ooooo0_l0000Booooo`;o00000Oooool002gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`00;Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool002goooool_l00001ooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00=_ooool3o`0005Sooooo0ol0000Gooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool02?ooool003Oooooo00?o0000ooooooooool0
F_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0
1oooool0037ooooo0ol00003ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000ooo
ool4o`000003ooooool0003o000000?o00001oooool3o`0000Cooooo1?l00003ooooo`;o00000_oo
ool6o`0000Kooooo1Ol00002ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`Co0000
0oooool2o`0000;ooooo1_l00007ooooo`03o`000?oooooooooo00?ooooo1?l000000ooooooo0000
o`000002o`0000;ooooo1?l00003ooooo`?o00000_ooool5o`0000?ooooo0_l000001?oooooo0000
ooooooooool2o`0000?ooooo0ol00009ooooo`Co000000?oooooo`000?l000000ol000000ooooooo
0000o`000002o`0000Cooooo0_l00003ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`00
0004ooooool0003o0000o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00Kooooo000`oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00006ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003ooooo`05o`000?oooooooooo
ooooool000001?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo
00002oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01_oo
ool0033ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo1Ol00002oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00Co0000oooooooo
oooo00000_ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go00001ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`03o`00
0?oooooooooo00?ooooo0ol00003ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5o`00
00Cooooo00?o0000ooooooooool01_ooool0033ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Sooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00003ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo000`ooooo`06
o`000?ooooooooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol00003
ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l0
0003ooooo`Co00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool3o`0000;ooooo1?l0
0003ooooo`Wo00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol0
0003ooooo`Co00000_ooool3o`0000Cooooo00Co0000oooooooooooooooo0_l000001?oooooo0000
o`000?ooool4o`0000?ooooo0ol00009ooooo`?o00000_ooool3o`0000Cooooo1?l000000ooooooo
0000o`000002o`0000?ooooo0_l00003ooooo`Co00000oooool3o`0000?ooooo0ol00005ooooo`03
o`000?oooooooooo00Kooooo000`ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool0037o
oooo0ol00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool3o`0000Wo
oooo1?l00009ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`?o00005_ooool00ol0003o
ooooooooo`02ooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`;o00004?ooool3o`0000[o
oooo00?o0000ooooooooool04?ooool2o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14.4316, 58.6231, \
0.0869639, 1.16978*^-5}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0475462 -1.45732 0.425431 [
[.02454 -0.0125 -9 -9 ]
[.02454 -0.0125 9 0 ]
[.26227 -0.0125 -6 -9 ]
[.26227 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.73773 -0.0125 -3 -9 ]
[.73773 -0.0125 3 0 ]
[.97546 -0.0125 -6 -9 ]
[.97546 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07423 -18 -4.5 ]
[-0.0125 .07423 0 4.5 ]
[-0.0125 .15931 -18 -4.5 ]
[-0.0125 .15931 0 4.5 ]
[-0.0125 .2444 -6 -4.5 ]
[-0.0125 .2444 0 4.5 ]
[-0.0125 .32948 -18 -4.5 ]
[-0.0125 .32948 0 4.5 ]
[-0.0125 .41457 -18 -4.5 ]
[-0.0125 .41457 0 4.5 ]
[-0.0125 .49966 -18 -4.5 ]
[-0.0125 .49966 0 4.5 ]
[-0.0125 .58474 -18 -4.5 ]
[-0.0125 .58474 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02454 0 m
.02454 .00625 L
s
[(-10)] .02454 -0.0125 0 1 Mshowa
.26227 0 m
.26227 .00625 L
s
[(-5)] .26227 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.73773 0 m
.73773 .00625 L
s
[(5)] .73773 -0.0125 0 1 Mshowa
.97546 0 m
.97546 .00625 L
s
[(10)] .97546 -0.0125 0 1 Mshowa
.125 Mabswid
.07208 0 m
.07208 .00375 L
s
.11963 0 m
.11963 .00375 L
s
.16718 0 m
.16718 .00375 L
s
.21472 0 m
.21472 .00375 L
s
.30982 0 m
.30982 .00375 L
s
.35736 0 m
.35736 .00375 L
s
.40491 0 m
.40491 .00375 L
s
.45245 0 m
.45245 .00375 L
s
.54755 0 m
.54755 .00375 L
s
.59509 0 m
.59509 .00375 L
s
.64264 0 m
.64264 .00375 L
s
.69018 0 m
.69018 .00375 L
s
.78528 0 m
.78528 .00375 L
s
.83282 0 m
.83282 .00375 L
s
.88037 0 m
.88037 .00375 L
s
.92792 0 m
.92792 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07423 m
.00625 .07423 L
s
[(3.6)] -0.0125 .07423 1 0 Mshowa
0 .15931 m
.00625 .15931 L
s
[(3.8)] -0.0125 .15931 1 0 Mshowa
0 .2444 m
.00625 .2444 L
s
[(4)] -0.0125 .2444 1 0 Mshowa
0 .32948 m
.00625 .32948 L
s
[(4.2)] -0.0125 .32948 1 0 Mshowa
0 .41457 m
.00625 .41457 L
s
[(4.4)] -0.0125 .41457 1 0 Mshowa
0 .49966 m
.00625 .49966 L
s
[(4.6)] -0.0125 .49966 1 0 Mshowa
0 .58474 m
.00625 .58474 L
s
[(4.8)] -0.0125 .58474 1 0 Mshowa
.125 Mabswid
0 .0955 m
.00375 .0955 L
s
0 .11677 m
.00375 .11677 L
s
0 .13804 m
.00375 .13804 L
s
0 .18058 m
.00375 .18058 L
s
0 .20186 m
.00375 .20186 L
s
0 .22313 m
.00375 .22313 L
s
0 .26567 m
.00375 .26567 L
s
0 .28694 m
.00375 .28694 L
s
0 .30821 m
.00375 .30821 L
s
0 .35076 m
.00375 .35076 L
s
0 .37203 m
.00375 .37203 L
s
0 .3933 m
.00375 .3933 L
s
0 .43584 m
.00375 .43584 L
s
0 .45711 m
.00375 .45711 L
s
0 .47839 m
.00375 .47839 L
s
0 .52093 m
.00375 .52093 L
s
0 .5422 m
.00375 .5422 L
s
0 .56347 m
.00375 .56347 L
s
0 .05295 m
.00375 .05295 L
s
0 .03168 m
.00375 .03168 L
s
0 .01041 m
.00375 .01041 L
s
0 .60601 m
.00375 .60601 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02454 .61178 m
.02454 .61803 L
s
.26227 .61178 m
.26227 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.73773 .61178 m
.73773 .61803 L
s
.97546 .61178 m
.97546 .61803 L
s
.125 Mabswid
.07208 .61428 m
.07208 .61803 L
s
.11963 .61428 m
.11963 .61803 L
s
.16718 .61428 m
.16718 .61803 L
s
.21472 .61428 m
.21472 .61803 L
s
.30982 .61428 m
.30982 .61803 L
s
.35736 .61428 m
.35736 .61803 L
s
.40491 .61428 m
.40491 .61803 L
s
.45245 .61428 m
.45245 .61803 L
s
.54755 .61428 m
.54755 .61803 L
s
.59509 .61428 m
.59509 .61803 L
s
.64264 .61428 m
.64264 .61803 L
s
.69018 .61428 m
.69018 .61803 L
s
.78528 .61428 m
.78528 .61803 L
s
.83282 .61428 m
.83282 .61803 L
s
.88037 .61428 m
.88037 .61803 L
s
.92792 .61428 m
.92792 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07423 m
1 .07423 L
s
.99375 .15931 m
1 .15931 L
s
.99375 .2444 m
1 .2444 L
s
.99375 .32948 m
1 .32948 L
s
.99375 .41457 m
1 .41457 L
s
.99375 .49966 m
1 .49966 L
s
.99375 .58474 m
1 .58474 L
s
.125 Mabswid
.99625 .0955 m
1 .0955 L
s
.99625 .11677 m
1 .11677 L
s
.99625 .13804 m
1 .13804 L
s
.99625 .18058 m
1 .18058 L
s
.99625 .20186 m
1 .20186 L
s
.99625 .22313 m
1 .22313 L
s
.99625 .26567 m
1 .26567 L
s
.99625 .28694 m
1 .28694 L
s
.99625 .30821 m
1 .30821 L
s
.99625 .35076 m
1 .35076 L
s
.99625 .37203 m
1 .37203 L
s
.99625 .3933 m
1 .3933 L
s
.99625 .43584 m
1 .43584 L
s
.99625 .45711 m
1 .45711 L
s
.99625 .47839 m
1 .47839 L
s
.99625 .52093 m
1 .52093 L
s
.99625 .5422 m
1 .5422 L
s
.99625 .56347 m
1 .56347 L
s
.99625 .05295 m
1 .05295 L
s
.99625 .03168 m
1 .03168 L
s
.99625 .01041 m
1 .01041 L
s
.99625 .60601 m
1 .60601 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .07423 m
1 .07423 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01658 m
.02741 .11587 L
.03076 .19253 L
.03837 .32467 L
.04218 .39086 L
.04309 .40665 L
.04406 .42339 L
.04488 .43243 L
.04579 .43952 L
.04778 .4551 L
.04994 .47202 L
.05372 .50159 L
.05571 .51715 L
.05788 .53413 L
.05887 .5419 L
.05943 .54624 L
.05993 .54762 L
.06183 .5525 L
.06639 .56417 L
.07056 .57485 L
.07246 .57971 L
.0735 .58237 L
.07447 .58485 L
.07497 .58535 L
.07551 .58569 L
.07666 .5864 L
.07869 .58766 L
.08634 .5924 L
.08833 .59363 L
.08885 .59396 L
.08941 .59431 L
.09043 .59458 L
.09137 .59471 L
.09223 .59483 L
.09422 .5951 L
.09831 .59567 L
.10047 .59597 L
.10279 .59629 L
.10384 .59644 L
.10484 .59657 L
.10574 .59661 L
.10672 .59665 L
.11037 .5968 L
.11836 .59714 L
.15004 .59815 L
.18055 .59902 L
.20988 .59977 L
.24111 .60049 L
.27117 .6011 L
.30312 .60167 L
Mistroke
.33391 .60213 L
.36352 .6025 L
.39502 .60282 L
.42536 .60304 L
.43334 .60312 L
.43553 .60314 L
.4361 .60315 L
.43672 .60315 L
.43731 .60316 L
.43784 .60316 L
.43885 .60316 L
.43981 .60316 L
.44197 .60316 L
.4456 .60316 L
.44945 .60316 L
.45042 .60316 L
.45147 .60316 L
.45206 .60316 L
.45261 .60316 L
.45313 .60316 L
.45368 .60317 L
.45759 .6032 L
.4614 .60323 L
.465 .60326 L
.46597 .60326 L
.46699 .60327 L
.46752 .60328 L
.46811 .60328 L
.46865 .60327 L
.46914 .60327 L
.47291 .60326 L
.47643 .60325 L
.47977 .60325 L
.48161 .60324 L
.48212 .60324 L
.48266 .60324 L
.48362 .60324 L
.48713 .60326 L
.49438 .6033 L
.49636 .60331 L
.49736 .60332 L
.49792 .60332 L
.49845 .60332 L
.50219 .6033 L
.50903 .60326 L
.51099 .60325 L
.51196 .60325 L
.51285 .60324 L
.51367 .60324 L
.51452 .60325 L
Mistroke
.51634 .60325 L
.52363 .60327 L
.52573 .60328 L
.52676 .60328 L
.52773 .60329 L
.52859 .60328 L
.52952 .60328 L
.53147 .60326 L
.54564 .60317 L
.55317 .60318 L
.555 .60318 L
.55696 .60318 L
.55754 .60318 L
.55809 .60318 L
.55858 .60318 L
.55911 .60317 L
.56112 .60315 L
.56565 .6031 L
.56984 .60306 L
.57184 .60304 L
.57282 .60303 L
.57372 .60302 L
.57467 .60302 L
.57569 .60302 L
.57785 .60302 L
.58134 .60301 L
.58507 .603 L
.58618 .603 L
.58722 .603 L
.58815 .603 L
.58917 .60299 L
.59013 .60298 L
.59115 .60297 L
.59297 .60294 L
.60889 .60278 L
.63823 .60248 L
.66948 .60209 L
.69955 .60162 L
.73152 .60106 L
.76232 .60043 L
.79195 .59973 L
.82347 .59892 L
.85382 .59803 L
.86933 .59757 L
.87354 .59747 L
.87747 .59735 L
.88158 .59718 L
.88607 .597 L
.88817 .59692 L
.88921 .59688 L
Mistroke
.89016 .59684 L
.89103 .5968 L
.89195 .59671 L
.89389 .59654 L
.89822 .59615 L
.90227 .59578 L
.90401 .59562 L
.90488 .59555 L
.90568 .59547 L
.90659 .59521 L
.90759 .59481 L
.90934 .5941 L
.91714 .59096 L
.91905 .59019 L
.9201 .58977 L
.92107 .58938 L
.92158 .58856 L
.92212 .5876 L
.92328 .58557 L
.92532 .58199 L
.92928 .57504 L
.93302 .56846 L
.93477 .56539 L
.93566 .56384 L
.93663 .56052 L
.93714 .55755 L
.93768 .55434 L
.93867 .54854 L
.94056 .53745 L
.94412 .51655 L
.94743 .49709 L
.94909 .48731 L
.95066 .47809 L
.95153 .47154 L
.95247 .45807 L
.95412 .43454 L
.96144 .32986 L
.96911 .19184 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[127]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008_ooool3o`0000Cooooo0_l0000eooooo`?o0000=Oooool2o`0003Sooooo0ol0000eoooo
o`?o00001?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000<oooool01Ol0003ooooooooooooooooo000003?ooooo00Co0000oooooooooooo0000=_oo
ool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000<ooooo`006oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000]ooooo`Go00001Oooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`00
03[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000cooooo000Sooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=oooool0
0ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000cooooo000Sooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000<oooool4o`0003Cooooo00Co0000oooooooooooo
0000=_ooool4o`0003Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000<oooo
o`008_ooool2o`0000Cooooo00Co0000oooooooooooo0000<oooool00ol0003oooooooooo`0eoooo
o`04o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool0=_ooool2o`0000Cooooo00Co0000
oooooooooooo00003?ooool002?ooooo00?o0000ooooooooool00oooool2o`0003Cooooo1Ol0000d
ooooo`;o0000=oooool5o`0003Gooooo00?o0000ooooooooool00oooool2o`0000gooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000NooooooSo00002_ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0007Wo
oooo00?o0000ooooooooool0N?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000:
ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`003Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00002?ooool4
o`0000Gooooon?l0000:ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo000:ooooo`?o00002_ooool2o`0000Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Gooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`002_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`002Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02?ooool000gooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l00006ooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`04ooooo`;o00002_ooool000_ooooo0_l00009ooooo`?o0000
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000=ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo000:ooooo`?o00002Oooool3o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0000Kooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo0_l00006ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`04ooooo`;o00002_ooool0
01kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`007_ooool2o`0000Kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02?ooool001Oooooo0ol00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo000Eooooo`Go00001?ooool2o`0000Kooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`005Oooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
01Kooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo000Gooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1_ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0000Oooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo0_l00007ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05ooooo`;o00002_ooool0
01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`007_ooool2o`0000Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool000_ooooo0ol00003ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03o`000?oooooooooo00Oooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oo
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00So
oooo0009ooooo`Go00002Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003ooooo
ooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01Oooool2o`0000[ooooo
0009ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo000:ooooo`03o`000?oooooo000000Sooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool000_ooooo0_l00008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03o`000?oooooooooo00Oooooo0ol0
0005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo0_l00007
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o00002?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool01_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool001kooooo0_l00008oooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`06oooo
o`;o00002_ooool001kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000;ooooo`?o00000ooo
ool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo000<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`Go00001oooool5o`00
00Cooooo0_l00009ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`07ooooo`;o00002_ooool000Wooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
00[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool000_ooooo0_l0000:ooooo`;o00001Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`;o00002Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool01oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`007_ooool2o`0000[ooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`;o00002_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool02?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0K?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`00
2oooool3o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`003?ooool00ol0003oooooooooo`06ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`Go00001oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000;ooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`09ooooo`;o0000
2_ooool000Wooooo00Co0000oooooooooooo00002?ooool4o`0000Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`002_ooool00ol0003oooooo`000008ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`002oooool2
o`0000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Sooooo000<ooooo`03o`000?oooooooooo00Sooooo0_l00005ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02?ooool001kooooo0_l0000<ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0:ooooo`;o00002_ooool001kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000
3?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
2oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0JOoo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02?ooool001kooooo0_l0000>ooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`0<ooooo`;o00002_ooool001kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Sooooo000;ooooo`?o00000oooool00ol0003oooooooooo`02oooo
o`?o00001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03
o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool02?ooool000Wooooo1Ol00007ooooo`05o`000?oooooooooooooo
ool000001?ooool2o`00013ooooo0_l0001Wooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool03oooool2o`0000[ooooo0009ooooo`04o`000?ooooooooooo`0000Wooooo0ol00005oooo
o`03o`000?oooooooooo013ooooo0_l0001Vooooo`03o`000?oooooooooo06Gooooo0_l0000Boooo
o`03o`000?oooooooooo00Sooooo000:ooooo`03o`000?oooooo000000Sooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo01;ooooo0_l0001Tooooo`03o`000?oooooooooo
06?ooooo0ol0000Cooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00002?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool04ooooolDo`00057ooooo00?o0000oooo
ooooool0DOoooolBo`0001Kooooo00?o0000ooooooooool02?ooool000cooooo00?o0000oooooooo
ool01oooool3o`0000Gooooo00?o0000ooooooooool09oooool]o`0002Cooooo00?o0000oooooooo
ool09?ooool]o`0002Sooooo00?o0000ooooooooool02?ooool001kooooo0_l0001Eoooood_o0000
E?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo000NooooooSo00002_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00<cooooo0ol0001Aooooo`00cOooool00ol0003oooooooooo`1@ooooo`00HOooool00ol0003o
ooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool3o`0000?o
oooo0ol00004ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00008ooooo`Go
000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003ooooo`?o00000_ooool3o`00
0003ooooool0003o000000Co00000_ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo
04oooooo001Qooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`00
0?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
04oooooo001Qooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`03o`000?oooooo000000;o
oooo1Ol00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000D?ooool0063ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`?o00000oooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000oooo
ool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`00001@ooooo`00H?ooool01Ol0003oooooo`000?oooooo000000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000?ooooo00?o0000ooooooooool00_ooool2o`000003oooo
ool0003o000000;ooooo0ol00002ooooo`Co00000_ooool4o`0000[ooooo00Co0000oooooooooooo
oooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0
003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`00001?ooooo`00H?ooool01Ol0003o
ooooo`000?oooooo000001Cooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1F
ooooo`00H?ooool6o`0001;ooooo1Ol0000Dooooo`03o`000?oooooooooo00Sooooo1Ol00008oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Foooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.1028, 3.31053, \
0.0850929, 0.00950999}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0475462 0.0147151 0.188044 [
[.02454 -0.0125 -9 -9 ]
[.02454 -0.0125 9 0 ]
[.26227 -0.0125 -6 -9 ]
[.26227 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.73773 -0.0125 -3 -9 ]
[.73773 -0.0125 3 0 ]
[.97546 -0.0125 -6 -9 ]
[.97546 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10874 -18 -4.5 ]
[-0.0125 .10874 0 4.5 ]
[-0.0125 .20276 -6 -4.5 ]
[-0.0125 .20276 0 4.5 ]
[-0.0125 .29678 -18 -4.5 ]
[-0.0125 .29678 0 4.5 ]
[-0.0125 .3908 -6 -4.5 ]
[-0.0125 .3908 0 4.5 ]
[-0.0125 .48483 -18 -4.5 ]
[-0.0125 .48483 0 4.5 ]
[-0.0125 .57885 -6 -4.5 ]
[-0.0125 .57885 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02454 0 m
.02454 .00625 L
s
[(-10)] .02454 -0.0125 0 1 Mshowa
.26227 0 m
.26227 .00625 L
s
[(-5)] .26227 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.73773 0 m
.73773 .00625 L
s
[(5)] .73773 -0.0125 0 1 Mshowa
.97546 0 m
.97546 .00625 L
s
[(10)] .97546 -0.0125 0 1 Mshowa
.125 Mabswid
.07208 0 m
.07208 .00375 L
s
.11963 0 m
.11963 .00375 L
s
.16718 0 m
.16718 .00375 L
s
.21472 0 m
.21472 .00375 L
s
.30982 0 m
.30982 .00375 L
s
.35736 0 m
.35736 .00375 L
s
.40491 0 m
.40491 .00375 L
s
.45245 0 m
.45245 .00375 L
s
.54755 0 m
.54755 .00375 L
s
.59509 0 m
.59509 .00375 L
s
.64264 0 m
.64264 .00375 L
s
.69018 0 m
.69018 .00375 L
s
.78528 0 m
.78528 .00375 L
s
.83282 0 m
.83282 .00375 L
s
.88037 0 m
.88037 .00375 L
s
.92792 0 m
.92792 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10874 m
.00625 .10874 L
s
[(0.5)] -0.0125 .10874 1 0 Mshowa
0 .20276 m
.00625 .20276 L
s
[(1)] -0.0125 .20276 1 0 Mshowa
0 .29678 m
.00625 .29678 L
s
[(1.5)] -0.0125 .29678 1 0 Mshowa
0 .3908 m
.00625 .3908 L
s
[(2)] -0.0125 .3908 1 0 Mshowa
0 .48483 m
.00625 .48483 L
s
[(2.5)] -0.0125 .48483 1 0 Mshowa
0 .57885 m
.00625 .57885 L
s
[(3)] -0.0125 .57885 1 0 Mshowa
.125 Mabswid
0 .03352 m
.00375 .03352 L
s
0 .05232 m
.00375 .05232 L
s
0 .07113 m
.00375 .07113 L
s
0 .08993 m
.00375 .08993 L
s
0 .12754 m
.00375 .12754 L
s
0 .14635 m
.00375 .14635 L
s
0 .16515 m
.00375 .16515 L
s
0 .18395 m
.00375 .18395 L
s
0 .22156 m
.00375 .22156 L
s
0 .24037 m
.00375 .24037 L
s
0 .25917 m
.00375 .25917 L
s
0 .27798 m
.00375 .27798 L
s
0 .31559 m
.00375 .31559 L
s
0 .33439 m
.00375 .33439 L
s
0 .35319 m
.00375 .35319 L
s
0 .372 m
.00375 .372 L
s
0 .40961 m
.00375 .40961 L
s
0 .42841 m
.00375 .42841 L
s
0 .44722 m
.00375 .44722 L
s
0 .46602 m
.00375 .46602 L
s
0 .50363 m
.00375 .50363 L
s
0 .52243 m
.00375 .52243 L
s
0 .54124 m
.00375 .54124 L
s
0 .56004 m
.00375 .56004 L
s
0 .59765 m
.00375 .59765 L
s
0 .61646 m
.00375 .61646 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02454 .61178 m
.02454 .61803 L
s
.26227 .61178 m
.26227 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.73773 .61178 m
.73773 .61803 L
s
.97546 .61178 m
.97546 .61803 L
s
.125 Mabswid
.07208 .61428 m
.07208 .61803 L
s
.11963 .61428 m
.11963 .61803 L
s
.16718 .61428 m
.16718 .61803 L
s
.21472 .61428 m
.21472 .61803 L
s
.30982 .61428 m
.30982 .61803 L
s
.35736 .61428 m
.35736 .61803 L
s
.40491 .61428 m
.40491 .61803 L
s
.45245 .61428 m
.45245 .61803 L
s
.54755 .61428 m
.54755 .61803 L
s
.59509 .61428 m
.59509 .61803 L
s
.64264 .61428 m
.64264 .61803 L
s
.69018 .61428 m
.69018 .61803 L
s
.78528 .61428 m
.78528 .61803 L
s
.83282 .61428 m
.83282 .61803 L
s
.88037 .61428 m
.88037 .61803 L
s
.92792 .61428 m
.92792 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10874 m
1 .10874 L
s
.99375 .20276 m
1 .20276 L
s
.99375 .29678 m
1 .29678 L
s
.99375 .3908 m
1 .3908 L
s
.99375 .48483 m
1 .48483 L
s
.99375 .57885 m
1 .57885 L
s
.125 Mabswid
.99625 .03352 m
1 .03352 L
s
.99625 .05232 m
1 .05232 L
s
.99625 .07113 m
1 .07113 L
s
.99625 .08993 m
1 .08993 L
s
.99625 .12754 m
1 .12754 L
s
.99625 .14635 m
1 .14635 L
s
.99625 .16515 m
1 .16515 L
s
.99625 .18395 m
1 .18395 L
s
.99625 .22156 m
1 .22156 L
s
.99625 .24037 m
1 .24037 L
s
.99625 .25917 m
1 .25917 L
s
.99625 .27798 m
1 .27798 L
s
.99625 .31559 m
1 .31559 L
s
.99625 .33439 m
1 .33439 L
s
.99625 .35319 m
1 .35319 L
s
.99625 .372 m
1 .372 L
s
.99625 .40961 m
1 .40961 L
s
.99625 .42841 m
1 .42841 L
s
.99625 .44722 m
1 .44722 L
s
.99625 .46602 m
1 .46602 L
s
.99625 .50363 m
1 .50363 L
s
.99625 .52243 m
1 .52243 L
s
.99625 .54124 m
1 .54124 L
s
.99625 .56004 m
1 .56004 L
s
.99625 .59765 m
1 .59765 L
s
.99625 .61646 m
1 .61646 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .55564 Mdot
.05462 .59478 Mdot
.08541 .60332 Mdot
.11618 .58725 Mdot
.14694 .55204 Mdot
.17769 .50271 Mdot
.20842 .44379 Mdot
.23915 .37936 Mdot
.26986 .31306 Mdot
.30056 .24812 Mdot
.33126 .18732 Mdot
.36195 .13305 Mdot
.39263 .08728 Mdot
.42331 .05159 Mdot
.45399 .02714 Mdot
.48466 .01472 Mdot
.51534 .01472 Mdot
.54601 .02714 Mdot
.57669 .05159 Mdot
.60737 .08728 Mdot
.63805 .13305 Mdot
.66874 .18732 Mdot
.69944 .24812 Mdot
.73014 .31306 Mdot
.76085 .37936 Mdot
.79158 .44379 Mdot
.82231 .50271 Mdot
.85306 .55204 Mdot
.88382 .58725 Mdot
.91459 .60332 Mdot
.94538 .59478 Mdot
.97619 .55564 Mdot
.5 Mabswid
.02381 .55564 m
.03837 .57413 L
.04579 .58356 L
.04987 .58874 L
.05187 .59128 L
.05372 .59363 L
.0547 .5948 L
.0552 .59494 L
.05574 .59509 L
.05794 .5957 L
.06178 .59676 L
.06929 .59885 L
.07385 .60011 L
.07819 .60132 L
.08209 .6024 L
.08316 .60269 L
.08429 .60301 L
.08485 .60316 L
.08537 .60331 L
.08634 .60283 L
.10137 .59499 L
.10923 .59088 L
.11352 .58864 L
.1146 .58808 L
.11562 .58754 L
.11654 .58685 L
.11753 .58571 L
.12111 .58161 L
.12494 .57723 L
.13308 .56792 L
.14738 .55135 L
.17895 .5003 L
.20935 .44184 L
.23858 .38055 L
.2697 .3134 L
.29965 .25004 L
.3315 .18689 L
.36218 .1327 L
.39168 .0887 L
.40814 .06924 L
.41591 .06019 L
.42309 .05185 L
.42671 .04888 L
.43055 .04582 L
.43863 .03937 L
.44631 .03326 L
.44966 .03059 L
.45143 .02917 L
.45331 .02767 L
.45433 .02699 L
Mistroke
.45526 .02662 L
.45706 .02589 L
.46062 .02445 L
.46847 .02127 L
.47537 .01848 L
.47913 .01695 L
.48265 .01553 L
.48357 .01516 L
.48444 .01481 L
.48544 .01472 L
.48636 .01472 L
.49043 .01472 L
.49758 .01472 L
.5054 .01472 L
.50969 .01472 L
.51179 .01472 L
.5127 .01472 L
.51371 .01472 L
.5146 .01472 L
.51543 .01475 L
.51631 .01511 L
.51724 .01549 L
.52105 .01703 L
.52915 .02031 L
.53658 .02332 L
.54342 .02609 L
.54438 .02648 L
.54542 .02689 L
.54639 .02744 L
.54729 .02815 L
.54923 .0297 L
.55137 .03141 L
.55998 .03827 L
.56808 .04473 L
.57559 .05071 L
.58274 .05863 L
.59035 .06747 L
.60641 .08617 L
.63561 .12941 L
.66671 .18373 L
.69664 .24257 L
.72846 .30951 L
.75912 .3756 L
.78859 .43753 L
.81997 .49823 L
.85018 .54742 L
.86557 .56637 L
.87368 .57565 L
.87812 .58073 L
.88029 .58322 L
Mistroke
.88228 .58549 L
.88318 .58652 L
.88417 .58743 L
.8851 .58792 L
.88597 .58837 L
.88993 .59044 L
.89836 .59485 L
.9055 .59857 L
.90925 .60053 L
.91129 .6016 L
.91321 .6026 L
.91419 .60311 L
.91474 .60328 L
.91524 .60314 L
.91747 .60252 L
.9214 .60143 L
.92911 .59929 L
.9361 .59735 L
.93992 .59629 L
.94352 .59529 L
.94437 .59506 L
.94527 .59481 L
.94626 .59366 L
.94717 .5925 L
.9512 .58739 L
.9583 .57836 L
.97438 .55794 L
.97619 .55564 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[127]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008_ooool3o`0000Cooooo0_l0000eooooo`?o0000=Oooool2o`0003Sooooo0ol0000eoooo
o`?o00001?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000<oooool01Ol0003ooooooooooooooooo000003?ooooo00Co0000oooooooooooo0000=_oo
ool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000<ooooo`006oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000]ooooo`Go00001Oooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`00
03[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000cooooo000Sooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=oooool0
0ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000cooooo000Sooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000<oooool4o`0003Cooooo00Co0000oooooooooooo
0000=_ooool4o`0003Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000<oooo
o`008_ooool2o`0000Cooooo00Co0000oooooooooooo0000<oooool00ol0003oooooooooo`0eoooo
o`04o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool0=_ooool2o`0000Cooooo00Co0000
oooooooooooo00003?ooool002?ooooo00?o0000ooooooooool00oooool2o`0003Cooooo1Ol0000d
ooooo`;o0000=oooool5o`0003Gooooo00?o0000ooooooooool00oooool2o`0000gooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000NooooooSo00002_ooool0
01Oooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001Ko
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool2o`00
07Gooooo2_l0001eooooo`;o00002_ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1booooo`Co00000_ooool01?l0003oooooooooooooool4o`0007Cooooo00?o0000
ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1`
ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`?o0000LOooool00ol0003oooooooooo`08
ooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06cooooo1?l00008
ooooo`03o`000?oooooooooo00Sooooo0_l0001_ooooo`03o`000?oooooooooo00Sooooo000Goooo
o`;o00001Oooool00ol0003oooooooooo`1/ooooo`;o00002_ooool00ol0003oooooooooo`08oooo
o`?o0000K_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0006_ooooo0_l0000<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo06Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0J?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0JOoo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool2o`0006Wooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool0IOooool2o`00017ooooo00?o0000ooooooooool04?ooool2o`00
06Oooooo00?o0000ooooooooool02?ooool001kooooo0_l0001Vooooo`;o00004Oooool00ol0003o
ooooooooo`0@ooooo`;o0000I_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00Sooooo000Noooo
o`;o0000Hoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0HOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo05gooooo0ol0000Hooooo`03o`000?oooooooooo01Oooooo0_l0001Pooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o0000G_ooool2o`0001Wooooo00?o0000ooooooooool05oooool2o`00
05oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00So
oooo000;ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool02?ooool000[ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo05_ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`02ooooo`;o0000Foooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0FOooool2o`0000[ooooo000:ooooo`04o`00
0?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool02?ooool000[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool02?ooool000_ooooo0_l00008ooooo`Go0000
1?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000F?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Eooo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0000Pooooo`03o`000?oooooo
oooo01oooooo0_l0001Hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
05Kooooo0_l0000Pooooo`03o`000?oooooooooo01oooooo0_l0001Hooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`007_ooool2o`0005Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05Cooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`08ooooo`007_ooool2o`0005?ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo057ooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00So
oooo000Nooooo`;o0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0C_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0
000Xooooo`03o`000?oooooooooo02Oooooo0_l0001@ooooo`03o`000?oooooooooo00Sooooo000F
ooooo`?o00001Oooool00ol0003oooooooooo`1>ooooo`;o0000:?ooool00ol0003oooooooooo`0W
ooooo`;o0000D?ooool00ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool02?ooool001Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Sooooo000Gooooo`03o`00
0?oooooooooo00Cooooo0_l0001>ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`1<ooooo`;o00002_ooool001Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo000Fooooo`;o00001_ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo000Gooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`08ooooo`007_ooool2o`0004co
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[o
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`;o0000BOooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0B?ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0Aooo
ool2o`0002oooooo00?o0000ooooooooool0;_ooool2o`0004Wooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool0Aoooool2o`0002oooooo00?o0000ooooooooool0;_ooool2
o`0004Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`08ooooo`007_ooool2o`0004Oooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo04Gooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`08
ooooo`007_ooool2o`0004Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo04?ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
2?ooool000[ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool01oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`08ooooo`002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l00013
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11
ooooo`;o00002_ooool000_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000oooooooo
ool01oooool4o`0000Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`08ooooo`00
2_ooool2o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`03o`000?oo
oooooooo03oooooo0_l0000gooooo`03o`000?oooooooooo03Kooooo0_l00011ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`;o0000@?ooool2o`0003Oooooo00?o0000ooooooooool0=_ooool2
o`00043ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0003oooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03cooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`;o0000?Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0>_ooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?ooool001kooooo0_l0
000jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0gooooo`;o00002_ooool001kooooo00?o0000ooooooooool0=oooool3o`0003kooooo00?o0000
ooooooooool0?Oooool2o`0003[ooooo00?o0000ooooooooool02?ooool001Gooooo1Ol00004oooo
o`03o`000?oooooooooo03Oooooo0_l0000oooooo`03o`000?oooooooooo03gooooo0ol0000ioooo
o`03o`000?oooooooooo00Sooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04ooooo`;o
0000>?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0=Oooool2o`0000[ooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`08ooooo`005Oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`005Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`08ooooo`005_oo
ool3o`0000Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`08ooooo`007_ooool2
o`0003Kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo03?ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000=?ooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0<Oooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000
A_ooool00ol0003oooooooooo`15ooooo`;o0000<_ooool00ol0003oooooooooo`08ooooo`007_oo
ool2o`00037ooooo0_l00016ooooo`03o`000?oooooooooo04Gooooo0_l0000aooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0002oooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo02gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`?o00001Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`;o0000;Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0:_ooool2o`0000[ooooo000<ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00So
oooo0009ooooo`05o`000?ooooooooooooooool000001oooool4o`0000Gooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`08ooooo`002Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00So
oooo000:ooooo`?o00002?ooool5o`0000Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0002Wooooo0_l0001>ooooo`03o`000?oooooooooo04cooooo0_l0
000Zooooo`;o00002_ooool001kooooo00?o0000ooooooooool0:?ooool2o`0004kooooo00?o0000
ooooooooool0C?ooool3o`0002[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
2?ooool001kooooo0_l0000Wooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Uooooo`;o00002_ooool001kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool001kooooo
0_l0000Tooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`0Rooooo`;o00002_ooool001kooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo027ooooo0_l0001Eooooo`03o`000?oooooooooo05Cooooo0_l0000Soooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`;o
0000EOooool00ol0003oooooooooo`1Dooooo`;o00007?ooool2o`0000Gooooo00?o0000oooooooo
ool02?ooool001kooooo0_l00003ooooo`;o00007?ooool00ol0003oooooooooo`1Eooooo`03o`00
0?oooooooooo05Kooooo00?o0000ooooooooool06Oooool2o`0000Cooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`005_ooool3o`0000Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
01Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001Oooooo0_l00005ooooo`;o
00002?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`00
6Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3_ooool2o`0005gooooo00?o0000ooooooooool0Foooool3o`00013ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`005Oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`;o0000GOooool00ol0003ooooo
ooooo`1Looooo`;o00003oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
000Fooooo`?o00001Oooool00ol0003oooooooooo`0:ooooo`;o00002oooool2o`0005oooooo00?o
0000ooooooooool0G_ooool2o`0000_ooooo0_l0000<ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`;o00002oooool4o`0000Oooooo0_l0001Qooooo`03o`000?oooooooooo063ooooo0_l00007
ooooo`Co00002oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00kooooo1ol0001Soooo
o`03o`000?oooooooooo06;ooooo0ol000001?oooooo0000o`000?l0000@ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0001Uooooo`03o`000?oooooooooo
06?ooooo0ol0000Cooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo07So
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo000NooooooSo00002_ooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool0033ooooo0ol0002:ooooo`03o`000?oooooooooo02_ooooo
0ol0000Eooooo`03o`000?oooooooooo01[ooooo000aooooo`03o`000?oooooooooo08Sooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo000[
ooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000?ooooo1?l00000
0ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co00000oooool2o`0000;ooooo1_l00006
ooooo`Co00000_ooool5o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol00002
ooooo`?o00000_ooool3o`0000Cooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo0ol0
0003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo1?l0
0003ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00000_ooool3o`0000;ooooo0ol0
00001?oooooo0000o`000?ooool4o`0000?ooooo0_l00002ooooo`[o00001Oooool00ol0003ooooo
ooooo`0Hooooo`00:_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`00:_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`03o`000?oooooooooo
00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5o`0000Sooooo00?o
0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`03o`00
0?oooooo000000;ooooo1Ol00003ooooo`04o`000?ooooooooooooooo`Go00000_ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00002ooooo`?o00001Oooool00ol0003oooooooooo`0Hooooo`00:_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Gooooo00Ko0000oooo
oooooooo0000ooooool00008ooooo`03o`000?oooooooooo01Sooooo000Zooooo`06o`000?oooooo
ooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol00003ooooo`;o0000
1Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co
00000oooool3o`0000Wooooo00Go0000oooooooooooo0000ooooo`03o`0000Cooooo1?l00002oooo
o`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`00
00?ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`Ko000000?oooooo`00
0?l000000oooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`03o`000?oooooooooo
00;ooooo0ol00002ooooo`Co00000oooool9o`0000?ooooo0ol00003ooooo`Co00001?ooool00ol0
003oooooooooo`0Hooooo`00:_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06Oooool002_ooooo0ol00009ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03Oooool3o`0000Wooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo0_l0000:
ooooo`Co00001?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool2o`0002kooooo00?o0000
ooooooooool06?ooool3o`0001Kooooo00?o0000ooooooooool00_ooool2o`0000_ooooo00?o0000
ooooooooool06_ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.1028, -0.338383, \
0.0850929, 0.0215154}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] 0.49966958432041564`\), 
        ",", \(BackFocalLength \[Rule] 93.35095557506479`\), 
        ",", \(BackFocalPoint \[Rule] {103.35095557506479`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] 0\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {0, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.583004929987583`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {3.416995070012417`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 1\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 1, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FindPupils \[Rule] True\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 99.93396050505237`\), 
        ",", \(FrontFocalLength \[Rule] 99.93396050505234`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-99.93396050505234`\), 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {102.50971221923828`, 0, 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(PlanoConvexLens[100, 50, 10]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[Screen[1], {103 + d, 103.`}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.9341264481391712`, 
              6.583004929987581`}, {\(-0.010006608313591684`\), 
              0.9999999999999998`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(Move[LineOfRays[20], {\(-50.`\), {y, 0}}]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 58.62342258649551`\), ",", 
        RowBox[{"OpticalLengthFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-10.015327705855315`\), 
                  10.015327705855315`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-10.015327705855315`\), 
                  10.015327705855315`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {58.62342258649551`, 
            58.62508781772297`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(ParaxialReductionRatio \[Rule] 0.002`\), 
        ",", \(Plot2D \[Rule] True\), ",", \(PlotPoints \[Rule] 32\), 
        ",", \(PrinciplePoints \[Rule] {{2.842170943040401`*^-14, 0, 
              0}, {3.416995070012419`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 3.4169950700123906`\), 
        ",", \(RayBoundary \[Rule] {\(-10.015327705855315`\), 
            10.015327705855315`}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] True\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 17849\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{0.003511874975144755`, 
              99.75859867874478`}, {\(-0.010006608313591682`\), 
              0.49966958432041564`}}\), 
        ",", \(TransverseMagnification \[Rule] 0.003511874975144755`\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-12.445282539239507`\), 
                  12.354576541926033`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[127]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?PSF", "Input",
  CellLabel->"In[128]:=",
  CellTags->{"AOG5.", "AOG5.1", "AOG0."}],

Cell[BoxData[
    \("PSF[system, options] is an alias to PointSpreadFunction[system, \
options]."\)], "Print",
  CellTags->{"Info3314357094-6023310", "AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[PointSpreadFunction]", "Input",
  CellLabel->"In[129]:=",
  CellTags->{"AOG5.", "AOG5.1", "AOG0."}],

Cell[BoxData[
    \({SpatialScale \[Rule] 1, NumberOfPoints \[Rule] 128, 
      NumberOfRays \[Rule] Automatic, SignalPlotCutoff \[Rule] 0.01`, 
      PaddingFactor \[Rule] Automatic, FocalFraction \[Rule] Automatic, 
      FindImagePoint \[Rule] False, FindPupils \[Rule] True, 
      FieldStopPosition \[Rule] Automatic, ShowPerfectCase \[Rule] False, 
      NormalizePlot \[Rule] False, 
      GeometricPointSpreadFunction \[Rule] False, 
      InterpolationOrder \[Rule] 1, IntensityTransform \[Rule] True, 
      PlotPoints \[Rule] 64, FilterTrace \[Rule] True, 
      ColorFunction \[Rule] \((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ \
0.65`, 1, #1\ 0.9` + 0.1`] &)\), 
      RenderedParameters \[Rule] {PointSpreadFunction, 
          OpticalPathDifference}, Plot2D \[Rule] True}\)], "Output",
  CellLabel->"Out[129]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
psf = PointSpreadFunction[pupilfunction,NumberOfPoints->512,\
RenderedParameters->PointSpreadFunction,PaddingFactor->8]\
\>", "Input",
  CellLabel->"In[130]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 9.05718 0.0142308 0.000198795 [
[.13771 .00173 -15 -9 ]
[.13771 .00173 15 0 ]
[.31886 .00173 -15 -9 ]
[.31886 .00173 15 0 ]
[.5 .00173 -3 -9 ]
[.5 .00173 3 0 ]
[.68114 .00173 -12 -9 ]
[.68114 .00173 12 0 ]
[.86229 .00173 -12 -9 ]
[.86229 .00173 12 0 ]
[.01131 .11363 -18 -4.5 ]
[.01131 .11363 0 4.5 ]
[.01131 .21303 -24 -4.5 ]
[.01131 .21303 0 4.5 ]
[.01131 .31242 -24 -4.5 ]
[.01131 .31242 0 4.5 ]
[.01131 .41182 -24 -4.5 ]
[.01131 .41182 0 4.5 ]
[.01131 .51122 -24 -4.5 ]
[.01131 .51122 0 4.5 ]
[.01131 .61061 -24 -4.5 ]
[.01131 .61061 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13771 .01423 m
.13771 .02048 L
s
[(-0.04)] .13771 .00173 0 1 Mshowa
.31886 .01423 m
.31886 .02048 L
s
[(-0.02)] .31886 .00173 0 1 Mshowa
.5 .01423 m
.5 .02048 L
s
[(0)] .5 .00173 0 1 Mshowa
.68114 .01423 m
.68114 .02048 L
s
[(0.02)] .68114 .00173 0 1 Mshowa
.86229 .01423 m
.86229 .02048 L
s
[(0.04)] .86229 .00173 0 1 Mshowa
.125 Mabswid
.183 .01423 m
.183 .01798 L
s
.22828 .01423 m
.22828 .01798 L
s
.27357 .01423 m
.27357 .01798 L
s
.36414 .01423 m
.36414 .01798 L
s
.40943 .01423 m
.40943 .01798 L
s
.45471 .01423 m
.45471 .01798 L
s
.54529 .01423 m
.54529 .01798 L
s
.59057 .01423 m
.59057 .01798 L
s
.63586 .01423 m
.63586 .01798 L
s
.72643 .01423 m
.72643 .01798 L
s
.77172 .01423 m
.77172 .01798 L
s
.817 .01423 m
.817 .01798 L
s
.09243 .01423 m
.09243 .01798 L
s
.04714 .01423 m
.04714 .01798 L
s
.00186 .01423 m
.00186 .01798 L
s
.90757 .01423 m
.90757 .01798 L
s
.95286 .01423 m
.95286 .01798 L
s
.99814 .01423 m
.99814 .01798 L
s
.25 Mabswid
0 .01423 m
1 .01423 L
s
.02381 .11363 m
.03006 .11363 L
s
[(500)] .01131 .11363 1 0 Mshowa
.02381 .21303 m
.03006 .21303 L
s
[(1000)] .01131 .21303 1 0 Mshowa
.02381 .31242 m
.03006 .31242 L
s
[(1500)] .01131 .31242 1 0 Mshowa
.02381 .41182 m
.03006 .41182 L
s
[(2000)] .01131 .41182 1 0 Mshowa
.02381 .51122 m
.03006 .51122 L
s
[(2500)] .01131 .51122 1 0 Mshowa
.02381 .61061 m
.03006 .61061 L
s
[(3000)] .01131 .61061 1 0 Mshowa
.125 Mabswid
.02381 .03411 m
.02756 .03411 L
s
.02381 .05399 m
.02756 .05399 L
s
.02381 .07387 m
.02756 .07387 L
s
.02381 .09375 m
.02756 .09375 L
s
.02381 .13351 m
.02756 .13351 L
s
.02381 .15339 m
.02756 .15339 L
s
.02381 .17327 m
.02756 .17327 L
s
.02381 .19315 m
.02756 .19315 L
s
.02381 .2329 m
.02756 .2329 L
s
.02381 .25278 m
.02756 .25278 L
s
.02381 .27266 m
.02756 .27266 L
s
.02381 .29254 m
.02756 .29254 L
s
.02381 .3323 m
.02756 .3323 L
s
.02381 .35218 m
.02756 .35218 L
s
.02381 .37206 m
.02756 .37206 L
s
.02381 .39194 m
.02756 .39194 L
s
.02381 .4317 m
.02756 .4317 L
s
.02381 .45158 m
.02756 .45158 L
s
.02381 .47146 m
.02756 .47146 L
s
.02381 .49134 m
.02756 .49134 L
s
.02381 .5311 m
.02756 .5311 L
s
.02381 .55098 m
.02756 .55098 L
s
.02381 .57086 m
.02756 .57086 L
s
.02381 .59074 m
.02756 .59074 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .02091 m
.02739 .02311 L
.03097 .02417 L
.03455 .02363 L
.03813 .02156 L
.04171 .0187 L
.04529 .01624 L
.04887 .01552 L
.05245 .0175 L
.05603 .02239 L
.05961 .02948 L
.06319 .03729 L
.06677 .04394 L
.07035 .04777 L
.07393 .04781 L
.07752 .04424 L
.0811 .03835 L
.08468 .03234 L
.08826 .02876 L
.09184 .02982 L
.09542 .03682 L
.099 .04972 L
.10258 .06697 L
.10616 .08585 L
.10974 .10295 L
.11332 .11508 L
.1169 .12013 L
.12048 .11782 L
.12406 .11014 L
.12764 .10119 L
.13122 .09643 L
.1348 .10134 L
.13838 .11988 L
.14196 .15308 L
.14554 .19821 L
.14912 .24903 L
.1527 .29704 L
.15628 .3337 L
.15986 .3529 L
.16344 .35309 L
.16702 .33824 L
.17061 .3172 L
.17419 .30153 L
.17777 .30221 L
.18135 .32622 L
.18493 .37407 L
.18851 .43901 L
.19209 .50846 L
.19567 .56719 L
.19925 .60154 L
Mistroke
.20283 .60332 L
.20641 .57229 L
.20999 .51635 L
.21357 .44944 L
.21715 .38763 L
.22073 .34459 L
.22431 .32786 L
.22789 .33685 L
.23147 .36332 L
.23505 .39393 L
.23863 .41429 L
.24221 .41308 L
.24579 .38512 L
.24937 .33252 L
.25295 .2637 L
.25653 .19056 L
.26011 .12497 L
.26369 .07546 L
.26728 .04526 L
.27086 .03216 L
.27444 .03012 L
.27802 .03201 L
.2816 .03249 L
.28518 .03001 L
.28876 .02725 L
.29234 .02988 L
.29592 .04394 L
.2995 .07297 L
.30308 .11582 L
.30666 .16614 L
.31024 .21377 L
.31382 .24785 L
.3174 .2606 L
.32098 .25043 L
.32456 .22324 L
.32814 .19122 L
.33172 .16932 L
.3353 .17033 L
.33888 .20031 L
.34246 .25588 L
.34604 .32443 L
.34962 .38751 L
.3532 .42633 L
.35678 .42764 L
.36037 .38804 L
.36395 .31517 L
.36753 .22522 L
.37111 .13773 L
.37469 .06931 L
.37827 .0287 L
Mistroke
.38185 .01472 L
.38543 .01807 L
.38901 .02612 L
.39259 .02888 L
.39617 .0237 L
.39975 .01687 L
.40333 .02127 L
.40691 .05081 L
.41049 .11388 L
.41407 .20823 L
.41765 .3196 L
.42123 .42492 L
.42481 .49906 L
.42839 .52299 L
.43197 .4903 L
.43555 .40962 L
.43913 .30198 L
.44271 .19394 L
.44629 .109 L
.44987 .06027 L
.45346 .04726 L
.45704 .05773 L
.46062 .07393 L
.4642 .08057 L
.46778 .07159 L
.47136 .05273 L
.47494 .03919 L
.47852 .04901 L
.4821 .09482 L
.48568 .17741 L
.48926 .28352 L
.49284 .3891 L
.49642 .46685 L
.5 .49545 L
.50358 .46684 L
.50716 .38907 L
.51074 .28349 L
.51432 .17738 L
.5179 .0948 L
.52148 .049 L
.52506 .03919 L
.52864 .05273 L
.53222 .07159 L
.5358 .08057 L
.53938 .07393 L
.54296 .05773 L
.54654 .04727 L
.55013 .06029 L
.55371 .10902 L
.55729 .19397 L
Mistroke
.56087 .30199 L
.56445 .40962 L
.56803 .49029 L
.57161 .52296 L
.57519 .49902 L
.57877 .42488 L
.58235 .31957 L
.58593 .2082 L
.58951 .11387 L
.59309 .05081 L
.59667 .02127 L
.60025 .01687 L
.60383 .0237 L
.60741 .02888 L
.61099 .02612 L
.61457 .01806 L
.61815 .01472 L
.62173 .02871 L
.62531 .06932 L
.62889 .13773 L
.63247 .22521 L
.63605 .31515 L
.63963 .38801 L
.64322 .42759 L
.6468 .42629 L
.65038 .38748 L
.65396 .32441 L
.65754 .25587 L
.66112 .20031 L
.6647 .17033 L
.66828 .16932 L
.67186 .19121 L
.67544 .22321 L
.67902 .2504 L
.6826 .26057 L
.68618 .24783 L
.68976 .21376 L
.69334 .16614 L
.69692 .11583 L
.7005 .07297 L
.70408 .04394 L
.70766 .02988 L
.71124 .02725 L
.71482 .03 L
.7184 .03248 L
.72198 .03201 L
.72556 .03012 L
.72914 .03216 L
.73272 .04526 L
.73631 .07545 L
Mistroke
.73989 .12496 L
.74347 .19054 L
.74705 .26367 L
.75063 .33249 L
.75421 .3851 L
.75779 .41308 L
.76137 .41431 L
.76495 .39396 L
.76853 .36336 L
.77211 .3369 L
.77569 .3279 L
.77927 .34462 L
.78285 .38765 L
.78643 .44945 L
.79001 .51635 L
.79359 .57228 L
.79717 .60332 L
.80075 .60154 L
.80433 .5672 L
.80791 .50848 L
.81149 .43904 L
.81507 .37409 L
.81865 .32624 L
.82223 .30221 L
.82581 .30152 L
.82939 .31718 L
.83298 .33821 L
.83656 .35305 L
.84014 .35286 L
.84372 .33367 L
.8473 .29702 L
.85088 .24902 L
.85446 .19821 L
.85804 .15308 L
.86162 .11989 L
.8652 .10134 L
.86878 .09642 L
.87236 .10118 L
.87594 .11012 L
.87952 .1178 L
.8831 .12012 L
.88668 .11508 L
.89026 .10296 L
.89384 .08586 L
.89742 .06699 L
.901 .04973 L
.90458 .03684 L
.90816 .02983 L
.91174 .02876 L
.91532 .03235 L
Mistroke
.9189 .03835 L
.92248 .04424 L
.92607 .04782 L
.92965 .04777 L
.93323 .04395 L
.93681 .03729 L
.94039 .02948 L
.94397 .02239 L
.94755 .0175 L
.95113 .01552 L
.95471 .01624 L
.95829 .01869 L
.96187 .02156 L
.96545 .02363 L
.96903 .02417 L
.97261 .0231 L
.97619 .02091 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[130]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00=oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol0000Ioooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0001oooooo0_l0000Roooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0001Wooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00004ooooo`?o00008?ooool003Kooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001ko
oooo00Co0000oooooooooooo00008?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00006?ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07oooool002oooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`05o`00017ooooo1Ol00002
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`0Nooooo`04o`000?ooooooooooo`00023ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00002?oo
ool01Ol0003oooooooooool0003ooooo00Go00008?ooool003Kooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool05oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Ooo
ool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo01oooooo000fooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00000Iooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo01cooooo00Co0000oooooooooooo00008?ooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Fooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00000Qooooo`00=_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000Iooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo01cooooo00Co0000oooooooooooo00008?ooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Fooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000oooool2o`00027ooooo000gooooo`;o00002_oo
ool2o`0000Gooooo00?o0000ooooooooool06?ooool2o`0000[ooooo0_l00003ooooo`?o00008?oo
ool2o`0002;ooooo0_l0000:ooooo`;o00000oooool3o`0001[ooooo0_l0000:ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`3looooo`008Oooool00ol0
003oooooooooo`3looooo`008Oooool00ol0003oooooooooo`3looooo`008Oooool00ol0003ooooo
ooooo`3looooo`006oooooono`0000Oooooo000Looooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool3o`0000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00Co0000
oooooooooooo00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01oooool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`06ooooo`008Oooool5o`0000?ooooo00?o0000ooooooooool0Coooool01ol0003oooooo`00
0?oooooo0000ooooool00000<?ooool00ol0003oooooo`000002ooooo`;o0000DOooool01?l0003o
ooooooooooooool4o`0000kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;o000000?oooooo`00
0?ooool05Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`;o
0000;Oooool4o`000003ooooool0003ooooo01Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooo`000003o`0002gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Dooooo`00
8Oooool2o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00000/ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo01Cooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000/ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0Eooooo`008Oooool00ol0003oooooooooo`08ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Yoooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Fooooo`008Oooool00ol0
003oooooooooo`09ooooo`;o00001Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Wooooo00Oo0000ooooooooooooooooo`000?oooooo000000[ooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00ooo
ool2o`0001Wooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`07o`000?ooooooooooooooool0003oooooo`00000:ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo01kooooo000Qooooo`;o00004Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000:ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01kooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000002_ooool0
0ol0003oooooo`000002ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000
ooooooooool02?ooool02?l0003oooooooooool0003oooooo`000?oooooo00002_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`05o`000?oooooo0000ooooool0
00000_ooool00ol0003oooooooooo`08ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool0
000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07oooool0027ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00_l00002ooooo`03o`000?oooooooooo00Sooooo00So0000oooooooooooo0000oooo
ool0003oooooo`0000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`00
8Oooool2o`0001;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;o00000oooool00ol0003oooooooooo`06ooooo`09o`000?ooooooooooooooool0
003oooooo`000?oooooo000000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0O
ooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Pooooo`008Oooool2o`0001?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Qooooo`003Oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0C
ooooo`07o`000?ooooooooooooooool0003oooooo`00000Oooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool08Oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Coooo
o`07o`000?ooooooooooooooool0003oooooo`00000Oooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool08Oooool0013ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool01_l0003ooooo
ooooool0003oooooo`0001oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01gooooo00Ko0000oooooooooooo0000ooooool0000Tooooo`004?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool3o`0001Cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`07
o`000?ooooooooooooooool0003oooooo`00000Tooooo`003?ooool4o`0000?ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Gooooo0_l0
0003ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Sooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0:?ooool000cooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Sooooo000Q
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0X
ooooo`008Oooool2o`0001_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Xoooo
o`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0:Oooool0027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo02Wooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0:Oooool0027ooooo0_l0000Looooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02Wooooo000Qooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`008Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:Oooool0027ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00oooool2o`0000Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`;o00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:Oooool0027ooooo0_l0000Looooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Kooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`;o
00002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo0_l00005ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`00
8Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0:_ooool0027ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Zooooo`008Oooool2o`0001gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0:_ooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`002?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Zooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`002?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`?o00007?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00_ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo
0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo02[ooooo0007ooooo`;o00001?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool000Sooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo02_ooooo000Qooooo`;o00007_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0[ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool03Oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00003_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo
000Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0=ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000kooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool2o`0000Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0:oooool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00gooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000003_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo000Qooooo`;o
00007_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00gooooo0_l00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
:oooool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`008Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool0
027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02_ooooo000Qooooo`;o00007_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_o
oooo000Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0/ooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0;?ooool0027ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0/ooooo`008Oooool2o`0001oooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000003Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool01Ol0
003ooooooooooooooooo000001Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/
ooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool05Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00
000Gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool05_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo
o`00000Hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0/ooooo`001oooool3o`0000?ooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`;o00004Oooool00ol0003ooooooooo
o`0Fooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001So
oooo00?o0000ooooooooool03oooool2o`0000Cooooo00?o0000ooooooooool0;?ooool000Sooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool00_ooool2o`00017ooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo00oooooo
0_l00004ooooo`03o`000?oooooooooo02cooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo0ol0000Nooooo`07o`000?ooooooooooooooool0003oooooo`00000Aooooo`03o`000?oooooo
oooo01Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
6?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0
;?ooool000Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`06
o`000?ooooooooooo`000?oooooo00004Oooool00ol0003oooooooooo`0Fooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool0
3oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo02gooooo0008ooooo`04o`000?oo
ooooooooooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Go
0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0]ooooo`001oooool2o`0000?ooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool07oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool05_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo
o`00000Hooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0]ooooo`002?ooool01?l0003oooooooooooooool5o`0000?ooooo0_l00004ooooo`;o
00001Oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0]ooooo`008Oooool2o`00023ooooo00?o0000ooooool000000oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool01ol0003ooooooooooooooooo0000ooooool00000;oooool0
027ooooo00?o0000ooooooooool07oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo
00Sooooo0_l00004ooooo`03o`000?oooooooooo01Kooooo00Go0000ooooooooooooooooo`00000=
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;
ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`02ooooo`;o00002_oo
ool01ol0003ooooooooooooooooo0000ooooool00000;oooool0027ooooo00?o0000ooooooooool0
7oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000
1?ooool00ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000003Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00003Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000H
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002Oooool01ol0003ooooooooooooo
oooo0000ooooool00000;oooool0027ooooo00?o0000ooooooooool08?ooool2o`0000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo01Kooooo00Go
0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02oooool01Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`000009ooooo`07o`000?ooooooooooooooool0003oooooo`00000_ooooo`008Oooool0
0ol0003oooooooooo`0Pooooo`;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool0
00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Wooooo00?o0000oooooooo
ool00_ooool2o`0002oooooo000Qooooo`;o00008Oooool2o`0000?ooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Kooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool01?l0
003oooooooooool0000=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool0
1Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`0002oooooo000Qooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo01Kooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00_ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0dooooo`008Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000000kooooo00Go0000oooooooooooooooo
o`00000>ooooo`04o`000?ooooooooooo`0000kooooo00Go0000ooooooooooooooooo`00000>oooo
o`04o`000?ooooooooooo`0001Wooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03Cooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool01_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooool000003_ooool01Ol0003ooooooooooooooooo000000kooooo00Co0000oooooooooooo
00003_ooool01Ol0003ooooooooooooooooo000000kooooo00Co0000oooooooooooo00006Oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=?oo
ool0027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000000kooooo00Go
0000ooooooooooooooooo`00000>ooooo`04o`000?ooooooooooo`0000kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`04o`000?ooooooooooo`0001Wooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Cooooo000Qooooo`;o00009oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooo000000kooooo00Go0000ooooooooooooooooo`00000>ooooo`04o`00
0?ooooooooooo`0000kooooo00Go0000ooooooooooooooooo`00000>ooooo`04o`000?oooooooooo
o`0001Wooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Cooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool06?ooool00ol0003oooooo`00
000?ooooo`04o`000?ooooooooooo`0000kooooo00Co0000oooooooooooo00003_ooool01?l0003o
ooooooooool0000?ooooo`04o`000?ooooooooooo`0001Wooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Cooooo000Qooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool06?ooool00ol0003oooooo`00000?ooooo`04o`000?ooooooooooo`0000kooooo
00Co0000oooooooooooo00003_ooool01?l0003oooooooooool0000?ooooo`04o`000?oooooooooo
o`0001Wooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Cooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000001[ooooo00?o0000ooooool000003oooool0
1?l0003oooooooooool0000>ooooo`04o`000?ooooooooooo`0000kooooo00Co0000oooooooooooo
00003oooool01?l0003oooooooooool0000Iooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000Joooo
o`03o`000?oooooo000000oooooo00Co0000oooooooooooo00003_ooool01?l0003oooooooooool0
000>ooooo`04o`000?ooooooooooo`0000oooooo00Co0000oooooooooooo00006Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool0027o
oooo0_l0000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`00000Jooooo`03o`000?oooooo000000oooooo00Co0000oooooooooooo00003_ooool01?l0
003oooooooooool0000>ooooo`04o`000?ooooooooooo`0000oooooo00Co0000oooooooooooo0000
6Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0=?ooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000006_ooool00ol0003oooooo`00000?ooooo`04o`00
0?ooooooooooo`0000kooooo00Co0000oooooooooooo00003_ooool01?l0003oooooooooool0000?
ooooo`04o`000?ooooooooooo`0001Wooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Cooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000001[ooooo00?o
0000ooooool000003oooool01?l0003oooooooooool0000>ooooo`04o`000?ooooooooooo`0000ko
oooo00Co0000oooooooooooo00003oooool01?l0003oooooooooool0000Iooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`001_ooool5
o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`03o`000?oooooo
000000oooooo00Co0000oooooooooooo00003_ooool01?l0003oooooooooool0000>ooooo`04o`00
0?ooooooooooo`0000oooooo00Co0000oooooooooooo00006_ooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool000Oooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo000000oooooo
00Co0000oooooooooooo00003_ooool01?l0003oooooooooool0000>ooooo`04o`000?oooooooooo
o`0000oooooo00Co0000oooooooooooo00006_ooool2o`0000Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0dooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`?o
00009oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool06Oooool2o`00013ooooo00Co0000oooooooooooo00003_ooool01?l0003oooooooooool0000>
ooooo`04o`000?ooooooooooo`00013ooooo0_l0000Kooooo`;o00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03Gooooo0009ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Iooooo`;o00004?ooool01?l0003oooooooooool0000>oooo
o`04o`000?ooooooooooo`0000kooooo00Co0000oooooooooooo00004?ooool2o`0001_ooooo0_l0
0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=Oooool000Kooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Oooooo`;o00004?ooool01?l0003oooooooooool0000>
ooooo`04o`000?ooooooooooo`0000kooooo00Co0000oooooooooooo00004?ooool2o`00027ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0eooooo`001_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo023ooooo0_l0000@ooooo`04o`000?ooooooooooo`0000kooooo00Co
0000oooooooooooo00003_ooool01?l0003oooooooooool0000@ooooo`;o00008_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo03Gooooo0007ooooo`?o00001?ooool2o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool08?ooool2o`00013ooooo00Co0000oooooooooooo00003_ooool01?l0003o
ooooooooool0000>ooooo`04o`000?ooooooooooo`00013ooooo0_l0000Rooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=Oooool0027ooooo0_l0000Xooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0<_ooool01?l0003oooooooooool0000?ooooo`;o00003oooool0
1?l0003oooooooooool0000dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Ooo
ool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03;ooooo00Co0000oooooooooooo00003oooool2o`0000oooooo00Co0000oooooooooooo0000
=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo000Qooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0booooo`04o`000?oo
ooooooooo`0000oooooo0_l0000?ooooo`04o`000?ooooooooooo`0003Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0<_ooool01?l0003oooooooooool0000?ooooo`;o
00003oooool01?l0003oooooooooool0000dooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0=Oooool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03;ooooo00Co0000oooooooooooo00003oooool2o`0000oooooo00Co0000oooo
oooooooo0000=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo000Qoooo
o`;o0000:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo00Co0000oooo
oooooooo00003oooool2o`0000oooooo00Co0000oooooooooooo0000=?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03Gooooo000Qooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0booooo`03o`000?oooooo0000013ooooo0_l0000@
ooooo`03o`000?oooooo000003Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0e
ooooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooo`00000@ooooo`;o00004?ooool00ol0003oooooo`00000doooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool0027ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooool0
00004?ooool2o`00013ooooo00?o0000ooooool00000=?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03Gooooo000Qooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0cooooo`;o00004?ooool2o`00013ooooo00?o0000ooooool00000
=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo000Qooooo`;o0000:?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo0_l0000@ooooo`;o00004?oo
ool00ol0003oooooo`00000dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Ooo
ool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03?ooooo0_l0000@ooooo`;o00004?ooool00ol0003oooooo`00000dooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03?ooooo0_l0000@ooooo`;o00004?ooool00ol0
003oooooo`00000dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool0027o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03?o
oooo0_l0000Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooool00000=?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo02Sooooo
00Go0000ooooooooooooooooo`00000fooooo`;o00004Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooo000003Gooooo00Go0000ooooooooooooooooo`00000hooooo`008Oooool2o`0002Wo
oooo00Go0000ooooooooooooooooo`00000fooooo`;o00004Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooo000003Gooooo00Go0000ooooooooooooooooo`00000hooooo`008Oooool00ol0
003oooooooooo`0Xooooo`05o`000?ooooooooooooooool00000=_ooool2o`00017ooooo00?o0000
ooooooooool03_ooool00ol0003oooooo`00000eooooo`05o`000?ooooooooooooooool00000>?oo
ool0027ooooo00?o0000ooooooooool0:?ooool01Ol0003ooooooooooooooooo000003Kooooo0_l0
000Rooooo`03o`000?oooooo000003Gooooo00Go0000ooooooooooooooooo`00000hooooo`001_oo
ool5o`0000;ooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0:?oo
ool01Ol0003ooooooooooooooooo000003Kooooo0_l0000Rooooo`03o`000?oooooo000003Gooooo
00Go0000ooooooooooooooooo`00000hooooo`001oooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0:?ooool01Ol0003ooooooooooooooooo000003Kooooo
0_l0000Rooooo`03o`000?oooooo000003Gooooo00Go0000ooooooooooooooooo`00000hooooo`00
2?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`?o0000:?ooool01Ol0003ooooooooooooooooo
000003Kooooo00?o0000ooooooooool08_ooool2o`0003Gooooo00Go0000ooooooooooooooooo`00
000hooooo`002Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo
00Go0000ooooooooooooooooo`00000fooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0=?ooool01Ol0003ooooooooooooooooo000003Sooooo0006ooooo`06o`000?oooooooooooooo
ool0003ooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Xooooo`05o`000?ooooooooooooooool00000=_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03Cooooo00Go0000ooooooooooooooooo`00000hoooo
o`001_ooool01ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:?ooool01Ol0003ooooo
oooooooooooo000003Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0dooooo`05
o`000?ooooooooooooooool00000>?ooool000Oooooo0ol00002ooooo`Go00000oooool2o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00Go0000ooooooooooooooooo`00002Boooo
o`05o`000?ooooooooooooooool00000>?ooool0027ooooo0_l0000Yooooo`05o`000?oooooooooo
ooooool00000T_ooool01Ol0003ooooooooooooooooo000003Sooooo000Qooooo`03o`000?oooooo
oooo02Sooooo00Go0000ooooooooooooooooo`00002Booooo`05o`000?ooooooooooooooool00000
>?ooool0027ooooo00?o0000ooooooooool0:?ooool01Ol0003ooooooooooooooooo000009;ooooo
00Go0000ooooooooooooooooo`00000hooooo`008Oooool00ol0003oooooooooo`0Yooooo`04o`00
0?ooooooooooo`0009;ooooo00Co0000oooooooooooo0000>Oooool0027ooooo00?o0000oooooooo
ool0:Oooool01?l0003oooooooooool0002Booooo`04o`000?ooooooooooo`0003Wooooo000Qoooo
o`;o0000:_ooool00ol0003oooooo`00002Dooooo`03o`000?oooooo000003Wooooo000Qooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooool00000U?ooool00ol0003oooooo`00000iooooo`00
8Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo000009Cooooo00?o0000ooooool00000
>Oooool0027ooooo00?o0000ooooooooool0:Oooool00ol0003oooooo`00002Dooooo`03o`000?oo
oooo000003Wooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooool00000U?ooool0
0ol0003oooooo`00000iooooo`008Oooool2o`0002[ooooo00?o0000ooooool00000U?ooool00ol0
003oooooo`00000iooooo`008Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo000009Co
oooo00?o0000ooooool00000>Oooool0027ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
o`00002Dooooo`03o`000?oooooo000003Wooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooool00000U?ooool00ol0003oooooo`00000iooooo`008Oooool00ol0003oooooooooo`0Z
ooooo`;o0000U?ooool00ol0003oooooo`00000iooooo`008Oooool2o`0002_ooooo0_l0002Doooo
o`03o`000?oooooo000003Wooooo000Qooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0U?ooool2o`0003Wooooo000Qooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
U?ooool2o`0003Wooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo09Cooooo0_l0000iooooo`001_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`2Dooooo`03o`000?oooooooooo03Sooooo000:ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo0ol0003looooo`002?ooool2o`0000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0o?ooool000[ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3l
ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo1?ooool000Oooooo
0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l0003oooooo`Gooooo003oooooob7ooooo001W
ooooo`?o0000DOooool3o`0006;ooooo001Xooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool0HOooool003gooooo0ol00004ooooo`?o00000_ooool5o`000005ooooool0003o0000o`00
0?ooool00_l00002ooooo`;o00002Oooool3o`0000?ooooo0ol00002ooooo`?o00001?ooool3o`00
00?ooooo1?l00002ooooo`Co00001oooool5o`000005ooooool0003o0000o`000?ooool00_l00002
ooooo`;o00000oooool3o`0000;ooooo0ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003
ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`?o00001Oooool2o`000003ooooool0003o
000000;o000000Coooooo`000?l0003ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol0
0002ooooo`?o000000?oooooo`000?l00000:Oooool003kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool0
1?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo0000:_ooool003kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`Go00000_ooool3o`0000;ooooo00Co0000oooooooooooo00002_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool5
o`0000;ooooo00Co0000oooooooooooo00000_ooool3o`0000Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo02Sooooo000nooooo`?o00000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00[ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`07
o`000?ooooooooooooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooo
oooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000009ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool01?l0003oooooooooool00006ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02Sooooo000n
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00002ooooo`?o00000oooool4o`0000;ooooo1?l0
0009ooooo`03o`000?oooooooooo00;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0000?ooooo0_l00004ooooo`?o00002_ooool01?l0003oooooooooooooool4o`0000;ooooo
1?l00003ooooo`?o00000_ooool4o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co
00000_ooool2o`000003ooooool0003o000000Sooooo00?o0000ooooooooool00_ooool2o`000004
ooooool0003o0000ooooo`Co00000oooool3o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`00
00;ooooo1?l0000[ooooo`00?_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo
00Wooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooo`0001Cooooo00?o0000ooooooooool0?Oooool003gooooo1?l0000:ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool3o`0001_ooooo0_l00008ooooo`Go00002?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool5
o`0001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0fooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0673004, -242.012, \
0.000436815, 19.9015}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] 0.49966958432041564`\), 
        ",", \(BackFocalLength \[Rule] 93.35095557506479`\), 
        ",", \(BackFocalPoint \[Rule] {103.35095557506479`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] 0.10515207566943371`\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] 0\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {0, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.583004929987583`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {3.416995070012417`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 1\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 1, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FindPupils \[Rule] True\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 99.93396050505237`\), 
        ",", \(FrequencyCutoff \[Rule] 378.0374640861614`\), 
        ",", \(FrontFocalLength \[Rule] 99.93396050505234`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-99.93396050505234`\), 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {102.50971221923828`, 0, 0}\), 
        ",", \(ImageSampleSize \[Rule] 0.00039530855514824706`\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(PlanoConvexLens[100, 50, 10]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[Screen[1], {103 + d, 103.`}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.9341264481391712`, 
              6.583004929987581`}, {\(-0.010006608313591684`\), 
              0.9999999999999998`}}\), ",", \(NumberOfPoints \[Rule] 512\), 
        ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(Move[LineOfRays[20], {\(-50.`\), {y, 0}}]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 58.62342258649551`\), ",", 
        RowBox[{"OpticalLengthFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-10.015327705855315`\), 
                  10.015327705855315`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-10.015327705855315`\), 
                  10.015327705855315`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {58.62342258649551`, 
            58.62508781772297`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PaddingFactor \[Rule] 8\), 
        ",", \(ParaxialReductionRatio \[Rule] 0.002`\), ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.100803681562803`\), 
                  0.10119899011795125`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] True\), 
        ",", \(PlotPoints \[Rule] 32\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.100803681562803`\), 
                  0.10119899011795125`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{2.842170943040401`*^-14, 0, 
              0}, {3.416995070012419`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 3.4169950700123906`\), 
        ",", \(RayBoundary \[Rule] {\(-10.015327705855315`\), 
            10.015327705855315`}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] PointSpreadFunction\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] True\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 17849\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.10978289056499839`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{0.003511874975144755`, 
              99.75859867874478`}, {\(-0.010006608313591682`\), 
              0.49966958432041564`}}\), 
        ",", \(TransverseMagnification \[Rule] 0.003511874975144755`\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-12.445282539239507`\), 
                  12.354576541926033`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[130]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?MTF", "Input",
  CellLabel->"In[131]:=",
  CellTags->{"AOG5.", "AOG5.1", "AOG0."}],

Cell[BoxData[
    \("MTF[system, options] is an alias to ModulationTransferFunction[system, \
options]."\)], "Print",
  CellTags->{"Info3314357094-2851735", "AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModulationTransferFunction[psf]", "Input",
  CellLabel->"In[132]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0025182 0.0280925 0.561849 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.14972 -0.0125 -6 -9 ]
[.14972 -0.0125 6 0 ]
[.27563 -0.0125 -9 -9 ]
[.27563 -0.0125 9 0 ]
[.40154 -0.0125 -9 -9 ]
[.40154 -0.0125 9 0 ]
[.52745 -0.0125 -9 -9 ]
[.52745 -0.0125 9 0 ]
[.65336 -0.0125 -9 -9 ]
[.65336 -0.0125 9 0 ]
[.77927 -0.0125 -9 -9 ]
[.77927 -0.0125 9 0 ]
[.90518 -0.0125 -9 -9 ]
[.90518 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .14046 -18 -4.5 ]
[-0.0125 .14046 0 4.5 ]
[-0.0125 .25283 -18 -4.5 ]
[-0.0125 .25283 0 4.5 ]
[-0.0125 .3652 -18 -4.5 ]
[-0.0125 .3652 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -84 0 ]
[.5 .63053 84 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.14972 0 m
.14972 .00625 L
s
[(50)] .14972 -0.0125 0 1 Mshowa
.27563 0 m
.27563 .00625 L
s
[(100)] .27563 -0.0125 0 1 Mshowa
.40154 0 m
.40154 .00625 L
s
[(150)] .40154 -0.0125 0 1 Mshowa
.52745 0 m
.52745 .00625 L
s
[(200)] .52745 -0.0125 0 1 Mshowa
.65336 0 m
.65336 .00625 L
s
[(250)] .65336 -0.0125 0 1 Mshowa
.77927 0 m
.77927 .00625 L
s
[(300)] .77927 -0.0125 0 1 Mshowa
.90518 0 m
.90518 .00625 L
s
[(350)] .90518 -0.0125 0 1 Mshowa
.125 Mabswid
.04899 0 m
.04899 .00375 L
s
.07417 0 m
.07417 .00375 L
s
.09936 0 m
.09936 .00375 L
s
.12454 0 m
.12454 .00375 L
s
.1749 0 m
.1749 .00375 L
s
.20008 0 m
.20008 .00375 L
s
.22527 0 m
.22527 .00375 L
s
.25045 0 m
.25045 .00375 L
s
.30081 0 m
.30081 .00375 L
s
.32599 0 m
.32599 .00375 L
s
.35118 0 m
.35118 .00375 L
s
.37636 0 m
.37636 .00375 L
s
.42672 0 m
.42672 .00375 L
s
.4519 0 m
.4519 .00375 L
s
.47709 0 m
.47709 .00375 L
s
.50227 0 m
.50227 .00375 L
s
.55263 0 m
.55263 .00375 L
s
.57781 0 m
.57781 .00375 L
s
.603 0 m
.603 .00375 L
s
.62818 0 m
.62818 .00375 L
s
.67854 0 m
.67854 .00375 L
s
.70372 0 m
.70372 .00375 L
s
.72891 0 m
.72891 .00375 L
s
.75409 0 m
.75409 .00375 L
s
.80445 0 m
.80445 .00375 L
s
.82963 0 m
.82963 .00375 L
s
.85482 0 m
.85482 .00375 L
s
.88 0 m
.88 .00375 L
s
.93036 0 m
.93036 .00375 L
s
.95554 0 m
.95554 .00375 L
s
.98073 0 m
.98073 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .14046 m
.00625 .14046 L
s
[(0.2)] -0.0125 .14046 1 0 Mshowa
0 .25283 m
.00625 .25283 L
s
[(0.4)] -0.0125 .25283 1 0 Mshowa
0 .3652 m
.00625 .3652 L
s
[(0.6)] -0.0125 .3652 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(0.8)] -0.0125 .47757 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(1)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.14972 .61178 m
.14972 .61803 L
s
.27563 .61178 m
.27563 .61803 L
s
.40154 .61178 m
.40154 .61803 L
s
.52745 .61178 m
.52745 .61803 L
s
.65336 .61178 m
.65336 .61803 L
s
.77927 .61178 m
.77927 .61803 L
s
.90518 .61178 m
.90518 .61803 L
s
.125 Mabswid
.04899 .61428 m
.04899 .61803 L
s
.07417 .61428 m
.07417 .61803 L
s
.09936 .61428 m
.09936 .61803 L
s
.12454 .61428 m
.12454 .61803 L
s
.1749 .61428 m
.1749 .61803 L
s
.20008 .61428 m
.20008 .61803 L
s
.22527 .61428 m
.22527 .61803 L
s
.25045 .61428 m
.25045 .61803 L
s
.30081 .61428 m
.30081 .61803 L
s
.32599 .61428 m
.32599 .61803 L
s
.35118 .61428 m
.35118 .61803 L
s
.37636 .61428 m
.37636 .61803 L
s
.42672 .61428 m
.42672 .61803 L
s
.4519 .61428 m
.4519 .61803 L
s
.47709 .61428 m
.47709 .61803 L
s
.50227 .61428 m
.50227 .61803 L
s
.55263 .61428 m
.55263 .61803 L
s
.57781 .61428 m
.57781 .61803 L
s
.603 .61428 m
.603 .61803 L
s
.62818 .61428 m
.62818 .61803 L
s
.67854 .61428 m
.67854 .61803 L
s
.70372 .61428 m
.70372 .61803 L
s
.72891 .61428 m
.72891 .61803 L
s
.75409 .61428 m
.75409 .61803 L
s
.80445 .61428 m
.80445 .61803 L
s
.82963 .61428 m
.82963 .61803 L
s
.85482 .61428 m
.85482 .61803 L
s
.88 .61428 m
.88 .61803 L
s
.93036 .61428 m
.93036 .61803 L
s
.95554 .61428 m
.95554 .61803 L
s
.98073 .61428 m
.98073 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .14046 m
1 .14046 L
s
.99375 .25283 m
1 .25283 L
s
.99375 .3652 m
1 .3652 L
s
.99375 .47757 m
1 .47757 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(Modulation Transfer Function)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .58994 m
.02509 .58778 L
.02637 .58134 L
.02765 .57069 L
.02894 .55599 L
.03022 .53742 L
.0315 .51525 L
.03278 .48974 L
.03406 .46124 L
.03535 .4301 L
.03663 .39669 L
.03791 .36143 L
.03919 .32473 L
.04047 .287 L
.04175 .24866 L
.04304 .21014 L
.04432 .17183 L
.0456 .13413 L
.04688 .09742 L
.04816 .06206 L
.04945 .02843 L
.05073 .05948 L
.05201 .08889 L
.05329 .11576 L
.05457 .13988 L
.05585 .16105 L
.05714 .17913 L
.05842 .19401 L
.0597 .2056 L
.06098 .21388 L
.06226 .21886 L
.06355 .22058 L
.06483 .21915 L
.06611 .21468 L
.06739 .20736 L
.06867 .19737 L
.06995 .18496 L
.07124 .17039 L
.07252 .15393 L
.0738 .13589 L
.07508 .11657 L
.07636 .0963 L
.07765 .07538 L
.07893 .05414 L
.08021 .03289 L
.08149 .04426 L
.08277 .06467 L
.08405 .08424 L
.08534 .10274 L
.08662 .11993 L
Mistroke
.0879 .13562 L
.08918 .14964 L
.09046 .16182 L
.09175 .17205 L
.09303 .18024 L
.09431 .1863 L
.09559 .19021 L
.09687 .19195 L
.09815 .19153 L
.09944 .18899 L
.10072 .18441 L
.102 .17789 L
.10328 .16953 L
.10456 .15948 L
.10585 .14791 L
.10713 .13499 L
.10841 .12091 L
.10969 .10588 L
.11097 .09011 L
.11225 .07381 L
.11354 .05721 L
.11482 .04052 L
.1161 .03224 L
.11738 .04849 L
.11866 .06423 L
.11994 .07928 L
.12123 .09349 L
.12251 .10669 L
.12379 .11877 L
.12507 .12959 L
.12635 .13908 L
.12764 .14715 L
.12892 .15374 L
.1302 .15881 L
.13148 .16232 L
.13276 .16428 L
.13404 .16468 L
.13533 .16356 L
.13661 .16094 L
.13789 .15689 L
.13917 .15148 L
.14045 .14478 L
.14174 .1369 L
.14302 .12794 L
.1443 .11801 L
.14558 .10725 L
.14686 .09578 L
.14814 .08374 L
.14943 .07128 L
.15071 .05852 L
Mistroke
.15199 .04562 L
.15327 .03272 L
.15455 .03625 L
.15584 .04878 L
.15712 .06093 L
.1584 .0726 L
.15968 .08367 L
.16096 .09406 L
.16224 .10367 L
.16353 .11243 L
.16481 .12028 L
.16609 .12716 L
.16737 .13302 L
.16865 .13784 L
.16994 .14158 L
.17122 .14424 L
.1725 .14581 L
.17378 .1463 L
.17506 .14573 L
.17634 .14412 L
.17763 .14151 L
.17891 .13794 L
.18019 .13347 L
.18147 .12817 L
.18275 .12209 L
.18404 .11531 L
.18532 .10791 L
.1866 .09998 L
.18788 .09158 L
.18916 .08282 L
.19044 .07377 L
.19173 .06451 L
.19301 .05514 L
.19429 .04572 L
.19557 .03634 L
.19685 .02912 L
.19813 .03822 L
.19942 .04708 L
.2007 .05565 L
.20198 .06387 L
.20326 .07169 L
.20454 .07906 L
.20583 .08596 L
.20711 .09234 L
.20839 .09817 L
.20967 .10344 L
.21095 .10813 L
.21223 .11223 L
.21352 .11573 L
.2148 .11863 L
Mistroke
.21608 .12093 L
.21736 .12266 L
.21864 .12382 L
.21993 .12444 L
.22121 .12453 L
.22249 .12413 L
.22377 .12326 L
.22505 .12196 L
.22633 .12026 L
.22762 .11819 L
.2289 .11579 L
.23018 .11308 L
.23146 .1101 L
.23274 .10687 L
.23403 .10344 L
.23531 .09982 L
.23659 .09604 L
.23787 .09212 L
.23915 .0881 L
.24043 .08399 L
.24172 .07981 L
.243 .0756 L
.24428 .07136 L
.24556 .06711 L
.24684 .06288 L
.24813 .05868 L
.24941 .05451 L
.25069 .05041 L
.25197 .04636 L
.25325 .04239 L
.25453 .03849 L
.25582 .03468 L
.2571 .03094 L
.25838 .0289 L
.25966 .03247 L
.26094 .03597 L
.26223 .03939 L
.26351 .04275 L
.26479 .04604 L
.26607 .04926 L
.26735 .05242 L
.26863 .05552 L
.26992 .05856 L
.2712 .06153 L
.27248 .06444 L
.27376 .06728 L
.27504 .07005 L
.27633 .07274 L
.27761 .07536 L
.27889 .07789 L
Mistroke
.28017 .08035 L
.28145 .08272 L
.28273 .08501 L
.28402 .08723 L
.2853 .08936 L
.28658 .09141 L
.28786 .0934 L
.28914 .09531 L
.29042 .09715 L
.29171 .09892 L
.29299 .10063 L
.29427 .10226 L
.29555 .10383 L
.29683 .10534 L
.29812 .10677 L
.2994 .10813 L
.30068 .10941 L
.30196 .11062 L
.30324 .11174 L
.30452 .11279 L
.30581 .11375 L
.30709 .11464 L
.30837 .11544 L
.30965 .11617 L
.31093 .11683 L
.31222 .11741 L
.3135 .11793 L
.31478 .11838 L
.31606 .11878 L
.31734 .11913 L
.31862 .11943 L
.31991 .11969 L
.32119 .1199 L
.32247 .12007 L
.32375 .1202 L
.32503 .1203 L
.32632 .12036 L
.3276 .12039 L
.32888 .12039 L
.33016 .12035 L
.33144 .12028 L
.33272 .12018 L
.33401 .12005 L
.33529 .1199 L
.33657 .11972 L
.33785 .11952 L
.33913 .1193 L
.34042 .11907 L
.3417 .11883 L
.34298 .11857 L
Mistroke
.34426 .1183 L
.34554 .11802 L
.34682 .11773 L
.34811 .11744 L
.34939 .11713 L
.35067 .1168 L
.35195 .11647 L
.35323 .11611 L
.35452 .11574 L
.3558 .11535 L
.35708 .11493 L
.35836 .11449 L
.35964 .11403 L
.36092 .11353 L
.36221 .113 L
.36349 .11245 L
.36477 .11186 L
.36605 .11123 L
.36733 .11056 L
.36862 .10985 L
.3699 .1091 L
.37118 .1083 L
.37246 .10744 L
.37374 .10653 L
.37502 .10556 L
.37631 .10452 L
.37759 .10341 L
.37887 .10223 L
.38015 .10097 L
.38143 .09963 L
.38271 .0982 L
.384 .09668 L
.38528 .09508 L
.38656 .09338 L
.38784 .09159 L
.38912 .0897 L
.39041 .08771 L
.39169 .08563 L
.39297 .08344 L
.39425 .08116 L
.39553 .07878 L
.39681 .07629 L
.3981 .07371 L
.39938 .07102 L
.40066 .06824 L
.40194 .06536 L
.40322 .06238 L
.40451 .05931 L
.40579 .05616 L
.40707 .05292 L
Mistroke
.40835 .04961 L
.40963 .04623 L
.41091 .0428 L
.4122 .03931 L
.41348 .0358 L
.41476 .03225 L
.41604 .0287 L
.41732 .03104 L
.41861 .03458 L
.41989 .03809 L
.42117 .04155 L
.42245 .04496 L
.42373 .04829 L
.42501 .05153 L
.4263 .05467 L
.42758 .05768 L
.42886 .06056 L
.43014 .06329 L
.43142 .06584 L
.43271 .06821 L
.43399 .07037 L
.43527 .07232 L
.43655 .07402 L
.43783 .07548 L
.43911 .07667 L
.4404 .07758 L
.44168 .0782 L
.44296 .07851 L
.44424 .07851 L
.44552 .0782 L
.44681 .07756 L
.44809 .07661 L
.44937 .07533 L
.45065 .07373 L
.45193 .07183 L
.45321 .06962 L
.4545 .06713 L
.45578 .06436 L
.45706 .06135 L
.45834 .05809 L
.45962 .05463 L
.4609 .05098 L
.46219 .04717 L
.46347 .04323 L
.46475 .03919 L
.46603 .03508 L
.46731 .03094 L
.4686 .02938 L
.46988 .03348 L
.47116 .0375 L
Mistroke
.47244 .04141 L
.47372 .04517 L
.475 .04873 L
.47629 .05208 L
.47757 .05516 L
.47885 .05795 L
.48013 .06041 L
.48141 .06251 L
.4827 .06423 L
.48398 .06555 L
.48526 .06644 L
.48654 .0669 L
.48782 .06692 L
.4891 .06649 L
.49039 .06561 L
.49167 .0643 L
.49295 .06257 L
.49423 .06043 L
.49551 .05791 L
.4968 .05503 L
.49808 .05185 L
.49936 .04838 L
.50064 .04467 L
.50192 .04078 L
.5032 .03674 L
.50449 .03261 L
.50577 .02845 L
.50705 .03189 L
.50833 .03597 L
.50961 .03992 L
.5109 .04369 L
.51218 .04724 L
.51346 .0505 L
.51474 .05344 L
.51602 .05601 L
.5173 .05818 L
.51859 .05991 L
.51987 .06118 L
.52115 .06196 L
.52243 .06225 L
.52371 .06204 L
.525 .06133 L
.52628 .06013 L
.52756 .05845 L
.52884 .05632 L
.53012 .05377 L
.5314 .05084 L
.53269 .04756 L
.53397 .04399 L
.53525 .04019 L
Mistroke
.53653 .0362 L
.53781 .03209 L
.5391 .02826 L
.54038 .03242 L
.54166 .03652 L
.54294 .04049 L
.54422 .04427 L
.5455 .0478 L
.54679 .05103 L
.54807 .0539 L
.54935 .05638 L
.55063 .05842 L
.55191 .06 L
.55319 .06109 L
.55448 .06166 L
.55576 .06171 L
.55704 .06124 L
.55832 .06026 L
.5596 .05877 L
.56089 .05681 L
.56217 .05439 L
.56345 .05156 L
.56473 .04835 L
.56601 .04482 L
.56729 .04101 L
.56858 .03699 L
.56986 .03281 L
.57114 .02853 L
.57242 .03197 L
.5737 .03625 L
.57499 .04045 L
.57627 .0445 L
.57755 .04834 L
.57883 .05193 L
.58011 .05521 L
.58139 .05814 L
.58268 .06067 L
.58396 .06279 L
.58524 .06446 L
.58652 .06565 L
.5878 .06636 L
.58909 .06657 L
.59037 .06628 L
.59165 .06549 L
.59293 .06422 L
.59421 .06247 L
.59549 .06028 L
.59678 .05765 L
.59806 .05463 L
.59934 .05125 L
Mistroke
.60062 .04754 L
.6019 .04355 L
.60319 .03932 L
.60447 .03489 L
.60575 .03031 L
.60703 .03056 L
.60831 .0353 L
.60959 .04006 L
.61088 .0448 L
.61216 .04947 L
.61344 .05404 L
.61472 .05848 L
.616 .06276 L
.61729 .06684 L
.61857 .07071 L
.61985 .07435 L
.62113 .07774 L
.62241 .08087 L
.62369 .08372 L
.62498 .08629 L
.62626 .08858 L
.62754 .09058 L
.62882 .09229 L
.6301 .09371 L
.63138 .09484 L
.63267 .0957 L
.63395 .09628 L
.63523 .0966 L
.63651 .09666 L
.63779 .09649 L
.63908 .09609 L
.64036 .09548 L
.64164 .09468 L
.64292 .09371 L
.6442 .09259 L
.64548 .09134 L
.64677 .08997 L
.64805 .08851 L
.64933 .08697 L
.65061 .08538 L
.65189 .08373 L
.65318 .08206 L
.65446 .08036 L
.65574 .07865 L
.65702 .07694 L
.6583 .07523 L
.65958 .07353 L
.66087 .07184 L
.66215 .07017 L
.66343 .06852 L
Mistroke
.66471 .0669 L
.66599 .06531 L
.66728 .06376 L
.66856 .06225 L
.66984 .06079 L
.67112 .05939 L
.6724 .05805 L
.67368 .05678 L
.67497 .05557 L
.67625 .05443 L
.67753 .05337 L
.67881 .05237 L
.68009 .05144 L
.68138 .05058 L
.68266 .04977 L
.68394 .04901 L
.68522 .04829 L
.6865 .04761 L
.68778 .04697 L
.68907 .04634 L
.69035 .04575 L
.69163 .04517 L
.69291 .04461 L
.69419 .04407 L
.69548 .04355 L
.69676 .04306 L
.69804 .04259 L
.69932 .04215 L
.7006 .04173 L
.70188 .04135 L
.70317 .04098 L
.70445 .04064 L
.70573 .04032 L
.70701 .03999 L
.70829 .03967 L
.70958 .03932 L
.71086 .03895 L
.71214 .03855 L
.71342 .0381 L
.7147 .03759 L
.71598 .03704 L
.71727 .03642 L
.71855 .03576 L
.71983 .03505 L
.72111 .0343 L
.72239 .03354 L
.72367 .03276 L
.72496 .032 L
.72624 .03126 L
.72752 .03057 L
Mistroke
.7288 .02994 L
.73008 .02938 L
.73137 .0289 L
.73265 .0285 L
.73393 .02819 L
.73521 .02822 L
.73649 .02838 L
.73777 .02846 L
.73906 .02849 L
.74034 .02847 L
.74162 .02843 L
.7429 .02838 L
.74418 .02832 L
.74547 .02828 L
.74675 .02826 L
.74803 .02825 L
.74931 .02826 L
.75059 .02826 L
.75187 .02828 L
.75316 .0283 L
.75444 .02833 L
.75572 .02836 L
.757 .02839 L
.75828 .02841 L
.75957 .02842 L
.76085 .02841 L
.76213 .02839 L
.76341 .02835 L
.76469 .02829 L
.76597 .02823 L
.76726 .02816 L
.76854 .0281 L
.76982 .02816 L
.7711 .02821 L
.77238 .02826 L
.77367 .02829 L
.77495 .02831 L
.77623 .02831 L
.77751 .02831 L
.77879 .0283 L
.78007 .02828 L
.78136 .02827 L
.78264 .02826 L
.78392 .02825 L
.7852 .02824 L
.78648 .02824 L
.78777 .02824 L
.78905 .02825 L
.79033 .02825 L
.79161 .02826 L
Mistroke
.79289 .02827 L
.79417 .02827 L
.79546 .02827 L
.79674 .02826 L
.79802 .02825 L
.7993 .02822 L
.80058 .02818 L
.80187 .02814 L
.80315 .0281 L
.80443 .02814 L
.80571 .02818 L
.80699 .02822 L
.80827 .02826 L
.80956 .02829 L
.81084 .0283 L
.81212 .02831 L
.8134 .02831 L
.81468 .02831 L
.81596 .02829 L
.81725 .02828 L
.81853 .02826 L
.81981 .02824 L
.82109 .02823 L
.82237 .02822 L
.82366 .02821 L
.82494 .02821 L
.82622 .02821 L
.8275 .02821 L
.82878 .02821 L
.83006 .02821 L
.83135 .02821 L
.83263 .0282 L
.83391 .02819 L
.83519 .02817 L
.83647 .02815 L
.83776 .02812 L
.83904 .0281 L
.84032 .02814 L
.8416 .02818 L
.84288 .02822 L
.84416 .02825 L
.84545 .02828 L
.84673 .0283 L
.84801 .02831 L
.84929 .02832 L
.85057 .02832 L
.85186 .02831 L
.85314 .0283 L
.85442 .02829 L
.8557 .02828 L
Mistroke
.85698 .02826 L
.85826 .02825 L
.85955 .02825 L
.86083 .02824 L
.86211 .02824 L
.86339 .02825 L
.86467 .02825 L
.86596 .02826 L
.86724 .02826 L
.86852 .02826 L
.8698 .02826 L
.87108 .02826 L
.87236 .02824 L
.87365 .02822 L
.87493 .0282 L
.87621 .02817 L
.87749 .02814 L
.87877 .02812 L
.88006 .02813 L
.88134 .02815 L
.88262 .02818 L
.8839 .0282 L
.88518 .02821 L
.88646 .02822 L
.88775 .02822 L
.88903 .02822 L
.89031 .02822 L
.89159 .02821 L
.89287 .02821 L
.89415 .0282 L
.89544 .0282 L
.89672 .02821 L
.898 .02822 L
.89928 .02823 L
.90056 .02825 L
.90185 .02826 L
.90313 .02828 L
.90441 .0283 L
.90569 .02832 L
.90697 .02833 L
.90825 .02834 L
.90954 .02834 L
.91082 .02834 L
.9121 .02833 L
.91338 .02831 L
.91466 .0283 L
.91595 .02828 L
.91723 .02826 L
.91851 .02824 L
.91979 .02823 L
Mistroke
.92107 .02822 L
.92235 .02822 L
.92364 .02822 L
.92492 .02822 L
.9262 .02823 L
.92748 .02824 L
.92876 .02825 L
.93005 .02826 L
.93133 .02826 L
.93261 .02826 L
.93389 .02826 L
.93517 .02826 L
.93645 .02824 L
.93774 .02823 L
.93902 .02821 L
.9403 .02819 L
.94158 .02817 L
.94286 .02816 L
.94415 .02815 L
.94543 .02814 L
.94671 .02813 L
.94799 .02813 L
.94927 .02814 L
.95055 .02814 L
.95184 .02815 L
.95312 .02816 L
.9544 .02817 L
.95568 .02818 L
.95696 .02818 L
.95825 .02819 L
.95953 .02818 L
.96081 .02818 L
.96209 .02817 L
.96337 .02815 L
.96465 .02814 L
.96594 .02813 L
.96722 .02813 L
.9685 .02814 L
.96978 .02814 L
.97106 .02814 L
.97235 .02815 L
.97363 .02814 L
.97491 .02814 L
.97619 .02813 L
Mfstroke
1 0 0 r
.02381 .58994 m
.02509 .58984 L
.02637 .58954 L
.02765 .58906 L
.02894 .58841 L
.03022 .58761 L
.0315 .58669 L
.03278 .58568 L
.03406 .58461 L
.03535 .58349 L
.03663 .58237 L
.03791 .58124 L
.03919 .58013 L
.04047 .57905 L
.04175 .57799 L
.04304 .57696 L
.04432 .57595 L
.0456 .57495 L
.04688 .57396 L
.04816 .57296 L
.04945 .57194 L
.05073 .57091 L
.05201 .56984 L
.05329 .56876 L
.05457 .56765 L
.05585 .56651 L
.05714 .56537 L
.05842 .56421 L
.0597 .56306 L
.06098 .5619 L
.06226 .56076 L
.06355 .55963 L
.06483 .55852 L
.06611 .55742 L
.06739 .55633 L
.06867 .55526 L
.06995 .55418 L
.07124 .55311 L
.07252 .55203 L
.0738 .55094 L
.07508 .54984 L
.07636 .54873 L
.07765 .54761 L
.07893 .54648 L
.08021 .54534 L
.08149 .54421 L
.08277 .54307 L
.08405 .54194 L
.08534 .54081 L
.08662 .5397 L
Mistroke
.0879 .53859 L
.08918 .5375 L
.09046 .53641 L
.09175 .53533 L
.09303 .53425 L
.09431 .53317 L
.09559 .53209 L
.09687 .531 L
.09815 .5299 L
.09944 .5288 L
.10072 .52768 L
.102 .52656 L
.10328 .52543 L
.10456 .5243 L
.10585 .52317 L
.10713 .52204 L
.10841 .52092 L
.10969 .5198 L
.11097 .5187 L
.11225 .51759 L
.11354 .5165 L
.11482 .51541 L
.1161 .51432 L
.11738 .51323 L
.11866 .51213 L
.11994 .51103 L
.12123 .50992 L
.12251 .50881 L
.12379 .50769 L
.12507 .50657 L
.12635 .50544 L
.12764 .5043 L
.12892 .50317 L
.1302 .50205 L
.13148 .50092 L
.13276 .4998 L
.13404 .49869 L
.13533 .49758 L
.13661 .49648 L
.13789 .49538 L
.13917 .49428 L
.14045 .49318 L
.14174 .49208 L
.14302 .49097 L
.1443 .48986 L
.14558 .48874 L
.14686 .48762 L
.14814 .4865 L
.14943 .48537 L
.15071 .48424 L
Mistroke
.15199 .4831 L
.15327 .48198 L
.15455 .48085 L
.15584 .47973 L
.15712 .47862 L
.1584 .4775 L
.15968 .4764 L
.16096 .47529 L
.16224 .47419 L
.16353 .47308 L
.16481 .47198 L
.16609 .47087 L
.16737 .46975 L
.16865 .46863 L
.16994 .46751 L
.17122 .46638 L
.1725 .46525 L
.17378 .46412 L
.17506 .46299 L
.17634 .46186 L
.17763 .46074 L
.17891 .45961 L
.18019 .4585 L
.18147 .45738 L
.18275 .45627 L
.18404 .45516 L
.18532 .45405 L
.1866 .45294 L
.18788 .45183 L
.18916 .45072 L
.19044 .4496 L
.19173 .44848 L
.19301 .44736 L
.19429 .44623 L
.19557 .4451 L
.19685 .44396 L
.19813 .44283 L
.19942 .4417 L
.2007 .44058 L
.20198 .43945 L
.20326 .43833 L
.20454 .43722 L
.20583 .4361 L
.20711 .43499 L
.20839 .43388 L
.20967 .43277 L
.21095 .43165 L
.21223 .43054 L
.21352 .42942 L
.2148 .42829 L
Mistroke
.21608 .42717 L
.21736 .42604 L
.21864 .42491 L
.21993 .42377 L
.22121 .42264 L
.22249 .42151 L
.22377 .42039 L
.22505 .41926 L
.22633 .41814 L
.22762 .41702 L
.2289 .41591 L
.23018 .41479 L
.23146 .41368 L
.23274 .41256 L
.23403 .41145 L
.23531 .41033 L
.23659 .40921 L
.23787 .40808 L
.23915 .40695 L
.24043 .40583 L
.24172 .40469 L
.243 .40356 L
.24428 .40243 L
.24556 .4013 L
.24684 .40017 L
.24813 .39905 L
.24941 .39793 L
.25069 .39681 L
.25197 .39569 L
.25325 .39457 L
.25453 .39346 L
.25582 .39234 L
.2571 .39122 L
.25838 .3901 L
.25966 .38898 L
.26094 .38786 L
.26223 .38673 L
.26351 .3856 L
.26479 .38447 L
.26607 .38334 L
.26735 .38221 L
.26863 .38108 L
.26992 .37995 L
.2712 .37882 L
.27248 .3777 L
.27376 .37658 L
.27504 .37546 L
.27633 .37434 L
.27761 .37323 L
.27889 .37211 L
Mistroke
.28017 .37099 L
.28145 .36987 L
.28273 .36875 L
.28402 .36762 L
.2853 .36649 L
.28658 .36536 L
.28786 .36423 L
.28914 .3631 L
.29042 .36197 L
.29171 .36085 L
.29299 .35972 L
.29427 .35859 L
.29555 .35747 L
.29683 .35635 L
.29812 .35523 L
.2994 .35411 L
.30068 .353 L
.30196 .35188 L
.30324 .35076 L
.30452 .34964 L
.30581 .34852 L
.30709 .34739 L
.30837 .34626 L
.30965 .34513 L
.31093 .34401 L
.31222 .34288 L
.3135 .34175 L
.31478 .34062 L
.31606 .33949 L
.31734 .33837 L
.31862 .33725 L
.31991 .33613 L
.32119 .33501 L
.32247 .33389 L
.32375 .33277 L
.32503 .33166 L
.32632 .33054 L
.3276 .32942 L
.32888 .32829 L
.33016 .32717 L
.33144 .32604 L
.33272 .32492 L
.33401 .32379 L
.33529 .32266 L
.33657 .32153 L
.33785 .32041 L
.33913 .31928 L
.34042 .31816 L
.3417 .31704 L
.34298 .31592 L
Mistroke
.34426 .3148 L
.34554 .31368 L
.34682 .31257 L
.34811 .31145 L
.34939 .31033 L
.35067 .30921 L
.35195 .30809 L
.35323 .30697 L
.35452 .30584 L
.3558 .30472 L
.35708 .30359 L
.35836 .30247 L
.35964 .30134 L
.36092 .30022 L
.36221 .29909 L
.36349 .29797 L
.36477 .29685 L
.36605 .29574 L
.36733 .29462 L
.36862 .2935 L
.3699 .29239 L
.37118 .29127 L
.37246 .29015 L
.37374 .28904 L
.37502 .28792 L
.37631 .28679 L
.37759 .28567 L
.37887 .28455 L
.38015 .28342 L
.38143 .2823 L
.38271 .28118 L
.384 .28006 L
.38528 .27894 L
.38656 .27782 L
.38784 .2767 L
.38912 .27559 L
.39041 .27447 L
.39169 .27336 L
.39297 .27224 L
.39425 .27113 L
.39553 .27001 L
.39681 .26889 L
.3981 .26778 L
.39938 .26666 L
.40066 .26554 L
.40194 .26442 L
.40322 .2633 L
.40451 .26217 L
.40579 .26105 L
.40707 .25994 L
Mistroke
.40835 .25882 L
.40963 .2577 L
.41091 .25659 L
.4122 .25547 L
.41348 .25436 L
.41476 .25325 L
.41604 .25214 L
.41732 .25103 L
.41861 .24991 L
.41989 .2488 L
.42117 .24768 L
.42245 .24657 L
.42373 .24545 L
.42501 .24433 L
.4263 .24321 L
.42758 .24209 L
.42886 .24098 L
.43014 .23986 L
.43142 .23875 L
.43271 .23764 L
.43399 .23652 L
.43527 .23541 L
.43655 .2343 L
.43783 .2332 L
.43911 .23209 L
.4404 .23098 L
.44168 .22986 L
.44296 .22875 L
.44424 .22764 L
.44552 .22653 L
.44681 .22541 L
.44809 .2243 L
.44937 .22318 L
.45065 .22207 L
.45193 .22096 L
.45321 .21985 L
.4545 .21874 L
.45578 .21763 L
.45706 .21652 L
.45834 .21541 L
.45962 .21431 L
.4609 .2132 L
.46219 .21209 L
.46347 .21099 L
.46475 .20988 L
.46603 .20877 L
.46731 .20766 L
.4686 .20655 L
.46988 .20544 L
.47116 .20433 L
Mistroke
.47244 .20322 L
.47372 .20211 L
.475 .201 L
.47629 .19989 L
.47757 .19879 L
.47885 .19768 L
.48013 .19658 L
.48141 .19548 L
.4827 .19437 L
.48398 .19327 L
.48526 .19217 L
.48654 .19106 L
.48782 .18996 L
.4891 .18885 L
.49039 .18775 L
.49167 .18664 L
.49295 .18553 L
.49423 .18443 L
.49551 .18332 L
.4968 .18222 L
.49808 .18112 L
.49936 .18001 L
.50064 .17891 L
.50192 .17781 L
.5032 .17671 L
.50449 .17561 L
.50577 .17452 L
.50705 .17342 L
.50833 .17232 L
.50961 .17122 L
.5109 .17012 L
.51218 .16902 L
.51346 .16792 L
.51474 .16681 L
.51602 .16571 L
.5173 .16461 L
.51859 .16351 L
.51987 .16241 L
.52115 .16132 L
.52243 .16022 L
.52371 .15912 L
.525 .15803 L
.52628 .15694 L
.52756 .15584 L
.52884 .15475 L
.53012 .15366 L
.5314 .15256 L
.53269 .15147 L
.53397 .15037 L
.53525 .14927 L
Mistroke
.53653 .14817 L
.53781 .14707 L
.5391 .14597 L
.54038 .14487 L
.54166 .14377 L
.54294 .14267 L
.54422 .14157 L
.5455 .14048 L
.54679 .13938 L
.54807 .13829 L
.54935 .13719 L
.55063 .13609 L
.55191 .135 L
.55319 .1339 L
.55448 .1328 L
.55576 .1317 L
.55704 .1306 L
.55832 .1295 L
.5596 .1284 L
.56089 .1273 L
.56217 .12621 L
.56345 .12511 L
.56473 .12402 L
.56601 .12292 L
.56729 .12183 L
.56858 .12074 L
.56986 .11965 L
.57114 .11856 L
.57242 .11747 L
.5737 .11639 L
.57499 .1153 L
.57627 .11421 L
.57755 .11311 L
.57883 .11202 L
.58011 .11093 L
.58139 .10984 L
.58268 .10875 L
.58396 .10765 L
.58524 .10657 L
.58652 .10548 L
.5878 .1044 L
.58909 .10331 L
.59037 .10223 L
.59165 .10115 L
.59293 .10007 L
.59421 .099 L
.59549 .09792 L
.59678 .09683 L
.59806 .09575 L
.59934 .09467 L
Mistroke
.60062 .09358 L
.6019 .09249 L
.60319 .0914 L
.60447 .09032 L
.60575 .08923 L
.60703 .08815 L
.60831 .08707 L
.60959 .08599 L
.61088 .08491 L
.61216 .08384 L
.61344 .08277 L
.61472 .0817 L
.616 .08063 L
.61729 .07956 L
.61857 .07849 L
.61985 .07741 L
.62113 .07634 L
.62241 .07526 L
.62369 .07418 L
.62498 .07309 L
.62626 .07201 L
.62754 .07092 L
.62882 .06984 L
.6301 .06876 L
.63138 .06769 L
.63267 .06662 L
.63395 .06556 L
.63523 .0645 L
.63651 .06345 L
.63779 .0624 L
.63908 .06134 L
.64036 .06029 L
.64164 .05923 L
.64292 .05817 L
.6442 .0571 L
.64548 .05602 L
.64677 .05495 L
.64805 .05387 L
.64933 .05279 L
.65061 .05172 L
.65189 .05066 L
.65318 .0496 L
.65446 .04856 L
.65574 .04753 L
.65702 .04651 L
.6583 .0455 L
.65958 .04451 L
.66087 .04352 L
.66215 .04253 L
.66343 .04155 L
Mistroke
.66471 .04056 L
.66599 .03957 L
.66728 .03857 L
.66856 .03756 L
.66984 .03656 L
.67112 .03555 L
.6724 .03457 L
.67368 .0336 L
.67497 .03267 L
.67625 .03179 L
.67753 .03097 L
.67881 .03023 L
.68009 .02957 L
.68138 .02901 L
.68266 .02858 L
.68394 .02839 L
.68522 .02852 L
.6865 .02868 L
.68778 .02879 L
.68907 .02884 L
.69035 .02884 L
.69163 .0288 L
.69291 .02875 L
.69419 .02868 L
.69548 .02862 L
.69676 .02856 L
.69804 .02852 L
.69932 .0285 L
.7006 .0285 L
.70188 .0285 L
.70317 .02852 L
.70445 .02855 L
.70573 .02859 L
.70701 .02862 L
.70829 .02865 L
.70958 .02867 L
.71086 .02868 L
.71214 .02868 L
.71342 .02867 L
.7147 .02865 L
.71598 .02863 L
.71727 .0286 L
.71855 .02858 L
.71983 .02855 L
.72111 .02854 L
.72239 .02853 L
.72367 .02853 L
.72496 .02854 L
.72624 .02855 L
.72752 .02857 L
Mistroke
.7288 .02859 L
.73008 .02861 L
.73137 .02862 L
.73265 .02863 L
.73393 .02864 L
.73521 .02864 L
.73649 .02863 L
.73777 .02861 L
.73906 .0286 L
.74034 .02858 L
.74162 .02856 L
.7429 .02854 L
.74418 .02853 L
.74547 .02853 L
.74675 .02853 L
.74803 .02853 L
.74931 .02854 L
.75059 .02856 L
.75187 .02857 L
.75316 .02858 L
.75444 .02859 L
.75572 .0286 L
.757 .0286 L
.75828 .0286 L
.75957 .02859 L
.76085 .02857 L
.76213 .02856 L
.76341 .02854 L
.76469 .02853 L
.76597 .02851 L
.76726 .0285 L
.76854 .0285 L
.76982 .0285 L
.7711 .0285 L
.77238 .02851 L
.77367 .02852 L
.77495 .02853 L
.77623 .02854 L
.77751 .02855 L
.77879 .02855 L
.78007 .02855 L
.78136 .02855 L
.78264 .02854 L
.78392 .02852 L
.7852 .02851 L
.78648 .0285 L
.78777 .02848 L
.78905 .02847 L
.79033 .02846 L
.79161 .02846 L
Mistroke
.79289 .02846 L
.79417 .02846 L
.79546 .02847 L
.79674 .02847 L
.79802 .02848 L
.7993 .02849 L
.80058 .0285 L
.80187 .0285 L
.80315 .0285 L
.80443 .02849 L
.80571 .02848 L
.80699 .02847 L
.80827 .02846 L
.80956 .02844 L
.81084 .02843 L
.81212 .02842 L
.8134 .02841 L
.81468 .02841 L
.81596 .02841 L
.81725 .02841 L
.81853 .02841 L
.81981 .02842 L
.82109 .02843 L
.82237 .02843 L
.82366 .02844 L
.82494 .02844 L
.82622 .02843 L
.8275 .02843 L
.82878 .02842 L
.83006 .02841 L
.83135 .02839 L
.83263 .02838 L
.83391 .02837 L
.83519 .02836 L
.83647 .02835 L
.83776 .02835 L
.83904 .02835 L
.84032 .02835 L
.8416 .02835 L
.84288 .02836 L
.84416 .02836 L
.84545 .02837 L
.84673 .02837 L
.84801 .02837 L
.84929 .02837 L
.85057 .02836 L
.85186 .02835 L
.85314 .02834 L
.85442 .02833 L
.8557 .02832 L
Mistroke
.85698 .02831 L
.85826 .0283 L
.85955 .02829 L
.86083 .02829 L
.86211 .02829 L
.86339 .02829 L
.86467 .02829 L
.86596 .0283 L
.86724 .0283 L
.86852 .02831 L
.8698 .02831 L
.87108 .02831 L
.87236 .0283 L
.87365 .0283 L
.87493 .02829 L
.87621 .02828 L
.87749 .02827 L
.87877 .02826 L
.88006 .02825 L
.88134 .02824 L
.88262 .02824 L
.8839 .02824 L
.88518 .02824 L
.88646 .02824 L
.88775 .02824 L
.88903 .02825 L
.89031 .02825 L
.89159 .02825 L
.89287 .02825 L
.89415 .02825 L
.89544 .02825 L
.89672 .02824 L
.898 .02824 L
.89928 .02823 L
.90056 .02822 L
.90185 .02822 L
.90313 .02822 L
.90441 .02822 L
.90569 .02822 L
.90697 .02822 L
.90825 .02822 L
.90954 .02822 L
.91082 .02822 L
.9121 .02822 L
.91338 .02822 L
.91466 .02822 L
.91595 .02822 L
.91723 .02822 L
.91851 .02822 L
.91979 .02822 L
Mistroke
.92107 .02822 L
.92235 .02822 L
.92364 .02822 L
.92492 .02823 L
.9262 .02824 L
.92748 .02824 L
.92876 .02825 L
.93005 .02825 L
.93133 .02825 L
.93261 .02825 L
.93389 .02825 L
.93517 .02825 L
.93645 .02824 L
.93774 .02824 L
.93902 .02824 L
.9403 .02824 L
.94158 .02824 L
.94286 .02824 L
.94415 .02825 L
.94543 .02826 L
.94671 .02827 L
.94799 .02828 L
.94927 .02829 L
.95055 .0283 L
.95184 .0283 L
.95312 .02831 L
.9544 .02831 L
.95568 .02831 L
.95696 .0283 L
.95825 .0283 L
.95953 .02829 L
.96081 .02829 L
.96209 .02829 L
.96337 .02829 L
.96465 .02829 L
.96594 .0283 L
.96722 .02831 L
.9685 .02832 L
.96978 .02833 L
.97106 .02834 L
.97235 .02835 L
.97363 .02836 L
.97491 .02837 L
.97619 .02837 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[132]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008oooool2o`0001Wooooo0ol00004ooooo`;o00004oooool3o`0000Cooooo0_l00004oooo
o`;o00004?ooool3o`0000?ooooo0ol00004ooooo`;o00003oooool5o`0000?ooooo0_l00004oooo
o`;o00003oooool5o`0000;ooooo0ol00004ooooo`;o00004Oooool3o`0000Cooooo0_l00004oooo
o`;o00004?ooool3o`0000?ooooo0ol00004ooooo`;o00006oooool002;ooooo00Co0000oooooooo
oooo00005oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00004ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00004?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool0000?ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00gooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00003_ooool01ol0
003ooooooooooooooooo0000ooooool000000oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo01Sooooo000Rooooo`04o`000?ooooooooooo`0001_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Hooooo`008_oo
ool01?l0003oooooooooool0000Kooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00004?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0?ooooo`;o00000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`00013ooooo0_l00006ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool06?ooool002;ooooo00Co0000oooooooooooo00005oooool4o`0000?ooooo
00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?ooooo00Co
0000oooooooooooo00003_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0003ooooo
1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool000000ol00003
ooooo`04o`000?ooooooooooo`0001[ooooo000Rooooo`04o`000?ooooooooooo`0001Oooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0000Booooo`;o00001?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000oooooo0_l00003ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00003_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`07o`000?oooooooooooooo
ool0003oooooo`000006ooooo`04o`000?ooooooooooo`0000oooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00003_ooool01ol0
003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool0000Jooooo`008ooo
ool2o`0001Sooooo1Ol00003ooooo`;o00005?ooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`00017ooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00004?ooool3o`0000Cooooo
0_l00004ooooo`;o00004?ooool3o`0000;ooooo1Ol00003ooooo`;o00004Oooool3o`0000Cooooo
0_l00004ooooo`;o00004?ooool3o`0000;ooooo1Ol00003ooooo`;o00006oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool001kooooon?l0000:ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo0?Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0m?ooool00ol0
003oooooooooo`08ooooo`005oooool2o`0000Gooooo00?o0000ooooooooool0m?ooool00ol0003o
ooooooooo`08ooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?Co
oooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000Fooooo`04o`000?ooooooooooo`0000Co
oooo0_l0000:ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02oooool2o`0002Ko
oooo00?o0000ooooooooool02Oooool2o`0000Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_oooom;ool000Co
oooo0_l0000:ooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`;o00009Oooool2o`0000_o
oooo0_l00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`;o00003oooool2ool000[ooooo0_l00013ooooo`03o`000?oooooooooo00So
oooo000Fooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`;o00003Oooool3o`0002Cooooo00?o0000ooooool000002_ooool2o`0000Oo
oooo00?o0000ooooool000001_ooool2o`0000Gooooo00?o0000ooooool000001_ooool2o`0000ko
oooo00?oo`00ooooooooool01oooool3o`0004Gooooo00?o0000ooooooooool02?ooool001Oooooo
0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`;o00001oooool2o`0000Wooooo0_l0000<ooooo`04o`000?ooooooooooo`0002?o
oooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooool000001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000_ooooo0_oo0007ooooo`Co0000Aoooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o00001oooool2o`00
00Wooooo0_l0000<ooooo`04o`000?ooooooooooo`0002?ooooo00Co0000oooooooooooo00002Ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooo000000Gooooo00Co0000ooooool0003o
00001?ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000[ooooo0_oo0006oooo
o`;o0000Boooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Cooooo0_l00007ooooo`;o00001oooool2o`0000Wooooo0_l0000<ooooo`05
o`000?ooooooooooooooool000008_ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000
oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00009
ooooo`;oo`001Oooool2o`0004gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`04ooooo`;o00001oooool2o`0000Oooooo0_l00009oooo
o`03o`000?oooooo000000_ooooo00Go0000ooooooooooooooooo`00000Rooooo`05o`000?oooooo
ooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000006ooooo`;oo`001_ooool2o`0004kooooo00?o
0000ooooooooool02?ooool001kooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`;o00001oooool00ol0003oooooo`000008ooooo`03o`000?oooooo000000[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Ooo
ool01?l0003oooooo`000?l00004ooooo`04o`000?oooooo0000o`0000Cooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`03ooooo`;oo`001_ooool00ol0003oooooooooo`1=oooo
o`;o00002_ooool001kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`;o
00001oooool2o`0000Oooooo00?o0000ooooool000001oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00005
ooooo`?o00001_ooool2o`0000Gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`02ooooo`;oo`001_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l00007
ooooo`03o`000?oooooo000000Oooooo00Co0000oooooooooooo00002_ooool00ol0003ooooooooo
o`03ooooo`;o00007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0
0005ooooo`?o00005oooool2o`0000Gooooo00Co0000oooooooooooooooo0_oo0006ooooo`;o0000
DOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Cooooo0_l00007ooooo`;o00001oooool00ol0003oooooo`000007ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`04o`00
0?ooooooo`00ool000Kooooo0_l0001Booooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool01Oooool2o`0001cooooo00?o0000ooooooooool01_ooool2o`0000;ooooo00?o0000oooooooo
ool09oooool00ol0003oo`00ooooo`07ooooo`03o`000?oooooooooo057ooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool02Oooool2o`0000Gooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Oooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01oooool4o`0002Sooooo0_oo0008ooooo`03o`000?oooooooooo05;ooooo00?o0000oooooooo
ool02?ooool001kooooo0_l00009ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Oooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0<oooool2ool00003ooooool0003ooooo00Gooooo0_l0001Cooooo`;o00002_ooool001kooooo
00?o0000ooooooooool02?ooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Gooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo0_l0000doooo
o`;oo`000_ooool00ol0003oooooooooo`03ooooo`;o0000EOooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool0
00001Oooool01?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool2
o`0001Sooooo00?o0000ooooooooool0<_ooool2ool000Cooooo00Co0000oooooooooooooooo0_l0
001Fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooool000001Oooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
<_ooool2ool000Kooooo1?l0001Gooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooool000001Oooool00ol0003oooooo`000005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?o
oooo0_l0000booooo`;oo`002Oooool2o`0005Sooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool02?ooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Gooooo
00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo0_l0000Coooo
o`;o0000<_ooool2ool006Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo0_l0000Aooooo`;o0000<_oo
ool2ool006Gooooo00?o0000ooooooooool02?ooool001kooooo0_l00009ooooo`03o`000?oooooo
000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03_ooool2o`0000kooooo0_l0000cooooo`;oo`00IOooool2o`0000[o
oooo000Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000001?ooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_l0000Aooooo`;o00002_ooool3
o`0003Cooooo0_oo001Wooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooool000001?ooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00005?ooool;o`0003Cooooo0_oo001Yooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000001?ooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Oooooo1?l0001Booooo`;oo`00J_ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Cooooo00Co0000oooo
oooooooo00001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000005cooooo0_oo001[ooooo`03o`000?oooooooooo00Sooooo
000;ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo
000005_ooooo0_oo001/ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0005_ooooo0_oo001]oooo
o`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool01?ooool2o`0000Wooooo00?o0000ooooool000001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooool00000F_ooool2ool006gooooo0_l0000:ooooo`002_ooool01?l0003oooooooooool0
000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00
0004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`0005Sooooo0_oo001`ooooo`03o`000?oooooooooo00So
oooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooool000001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool0Eoooool00ooo003oooooooooo`1_ooooo`03o`000?oooooooooo00Sooooo000:
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001Pooooo`;oo`00L_ooool0
0ol0003oooooooooo`08ooooo`002oooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00oooool00ol0003oooooo`00001Oooooo`;oo`00Loooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
G_ooool2ool007Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02?oo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`03ooooo`;o0000G_ooool2ool007Gooooo00?o0000ooooooooool02?ooool001kooooo
0_l00009ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo06;ooooo0_oo001fooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool02?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ool00000I?ooool00ooo003oooooooooo`1fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooo000006;ooooo0_oo001iooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo0000067ooooo0_oo001jooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo0000063ooooo0_oo001kooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03oooo
o`;o0000H?ooool2ool007cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool02?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0GOooool00ooo003oooooooooo`1looooo`03o`000?oooooooooo00Sooooo000Nooooo`;o
00002Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo06?ooooo00?oo`00oooo
ooooool0O?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`1Qooooo`;oo`00P?ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`08ooooo`07o`000?ooooooooooooooool0003oooooo`00001R
ooooo`;oo`00POooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`08oooo
o`07o`000?ooooooooooooooool0003oooooo`00001Qooooo`;oo`00P_ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`08ooooo`07o`000?ooooooooooooooool0003ooooo
o`00001Pooooo`;oo`00Poooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`08ooooo`04o`000?ooooooooooooooo`;o0000H?ooool2ool008Cooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool02?ooool01?l0003oooooooooooooool2o`0005oooooo
00?oo`00ooooooooool0Q?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Wooooo00?o
0000ooooooooool0H?ooool2ool008Kooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05oooooo0_oo0028ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Goooool2ool008Wooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Nooooo`;o
o`00R_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05gooooo0_oo002;ooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05cooooo00?oo`00ooooooooool0Roooool00ol0003oooooooooo`08ooooo`002_ooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Jooooo`;oo`00S_ooool00ol0003oooooooooo`08ooooo`002_ooool0
1?l0003oooooooooool00007ooooo`Go00001?ooool2o`0000Sooooo00?o0000ooooooooool0FOoo
ool2ool008kooooo0_l0000:ooooo`002_ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Hooooo`;oo`00
T?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Gooooo`;oo`00
TOooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`;o0000
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo0_oo002Booooo`03o`00
0?oooooooooo00Sooooo000;ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0EOooool2ool009?ooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Cooooo`;oo`00UOooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05;ooooo0_oo002Fooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00002?ooool00ol0003o
ooooooooo`1Aooooo`;oo`00U_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0D?ooool2ool009Sooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1?ooooo`;oo`00VOooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04kooooo0_oo002J
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0COooool00ooo003oooooooooo`2Jooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0Boooool2ool009gooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1;ooooo`03ool0
0?oooooooooo09cooooo00?o0000ooooooooool02?ooool001kooooo0_l00008ooooo`03o`000?oo
oooooooo04Wooooo0_oo002Nooooo`;o00002_ooool001kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`18ooooo`;oo`00X?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04Oooooo0_oo002Qooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0A_ooool2ool00:;o
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`15ooooo`03ool00?oooooooooo0:;ooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`14ooooo`;oo`00Y?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo0_oo002V
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00002?ooool00ol0003oooooooooo`11oooo
o`;oo`00Y_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0@?ooool2ool00:Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`10ooooo`;oo`00ZOooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03oooooo0_oo002Zooooo`03o`000?oo
oooooooo00Sooooo000;ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03kooooo0_oo002[ooooo`03o`000?oooooo
oooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool00ooo003ooooooooo
o`2[ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
>oooool2ool00:kooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo0000
1oooool4o`0000Gooooo0_l00007ooooo`03o`000?oooooooooo03[ooooo0_oo002^ooooo`;o0000
2_ooool000[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0>Oooool2ool00;3ooooo00?o0000ooooooooool0
2?ooool000[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0>?ooool2ool00;7ooooo00?o0000ooooooooool0
2?ooool000_ooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03Oooooo0_oo002booooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0=_ooool2ool00;?ooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0eooooo`03ool00?oooooooooo
0;?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0cooooo`;oo`00]_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Oooooo
00?o0000ooooooooool0<_ooool2ool00;Kooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo037ooooo0_oo002hooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool2ool00;Wooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_oooo
o`;oo`00^_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02kooooo0_oo002kooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0;?ooool2ool00;gooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0/ooooo`03ool00?oo
oooooooo0;cooooo00?o0000ooooooooool02?ooool001kooooo0_l00007ooooo`03o`000?oooooo
oooo02[ooooo0_oo002nooooo`;o00002_ooool001kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Yooooo`;oo`00`?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02Sooooo0_oo0031ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool2ool00<;ooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo0<;ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Uooooo`;oo`00a?ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Cooooo00?oo`00oooo
ooooool0a?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Kooooo00?o0000oooooooo
ool08oooool2ool00<Kooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02;ooooo0_oo0038ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool08Oooool2ool00<Wooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`;oo`00b_ooool0
0ol0003oooooooooo`08ooooo`002oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`;oo`00boooool00ol0
003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00?oo`00
ooooooooool0boooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01cooooo0_oo003>ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?oooooo
ooooo`0000Sooooo0ol00005ooooo`;o00001_ooool00ol0003oooooooooo`0Kooooo`;oo`00c_oo
ool2o`0000[ooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool2ool00=3ooooo
00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`;o
o`00dOooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Wooooo0ol00005ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool06?ooool2ool00=;ooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`;oo`00dooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Gooooo0_oo003Eooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05?ooool2ool00=Kooooo00?o0000ooooooooool02?ooool001ko
oooo0_l00006ooooo`03o`000?oooooooooo01?ooooo0_oo003Fooooo`;o00002_ooool001kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`;oo`00f?ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo0_oo
003Iooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool04?ooool2ool00=[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo0=[ooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`;o
o`00gOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo0_oo003Nooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001Ooo
ool00ol0003oooooooooo`0<ooooo`;oo`00g_ooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02oooool2ool00>3ooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`;oo`00hOooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wo
oooo00?oo`00ooooooooool0hOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0h_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo0_oo
003Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool2ool00>Kooooo00?o0000ooooooooool02?ooool001kooooo0_l00005oooo
o`03o`000?oooooooooo00Cooooo0_oo003Vooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`;oo`00j?ooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0
j?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
oooooooooooooooo0000joooool00ol0003oooooooooo`08ooooo`005_ooool3o`0000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ool00>cooooo00?o0000ooooooooool02?oo
ool001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
o`00ool00>gooooo00?o0000ooooooooool02?ooool001Oooooo00?o0000ooooooooool01?ooool2
o`0000Cooooo0ooo003]ooooo`;o00002_ooool001Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000Gooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`08ooooo`005_ooool2o`0000Kooooo
00?o0000ooooooooool0m?ooool00ol0003oooooooooo`08ooooo`005oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool0m?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Sooooo000NooooooSo00002_ooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool004Gooooo0_l000001Ooooooo0000
o`000?l0003ooooo00?o00000oooool4o`0000?ooooo0_l000000ooooooo0000o`000004o`0000;o
oooo1?l00003ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l0
00001oooool3o`0000;ooooo0ol00004ooooo`Co000000Goooooo`000?l0003o0000ooooo`06o`00
00;ooooo1Ol00002ooooo`?o00000_ooool3o`0000Wooooo0ol00005ooooo`;o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?ooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3
o`0000;ooooo0ol000000ooooooo0000o`00000cooooo`00AOooool01ol0003ooooooooooooooooo
0000ooooool000000oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0003Cooooo
0015ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool3
o`0000?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool3o`0000Co
oooo00Co0000oooooooooooooooo1Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
1_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo03;ooooo0015ooooo`07o`000?oooooooooooooo
ool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`06o`000?ooooooooooo`000?oooooo00001oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_l0000:ooooo`?o00000oooool01?l0
003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003ooooo
ooooool00006ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo03;ooooo0015ooooo`05o`000?oooooo0000ooooool000000_ooool3
o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02
ooooo`;o00000oooool4o`0000;ooooo0ol00004ooooo`?o00000_ooool4o`0000Sooooo00Ko0000
ooooool0003oooooo`000?ooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co0000
0oooool4o`0000;ooooo1?l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000Sooooo
00?o0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool3o`0000;o
oooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l0000eooooo`00AOooool2o`000003oooo
ool0003o000000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooool0003oooooo`00000Kooooo`03o`000?oooooooooo01Co
oooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`17ooooo`00AOooool01?l0003o
ooooooooooooool2o`0000Sooooo0_l00008ooooo`?o00002_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01?ooooo1Ol0000Looooo`;o00004oooool5o`0001Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`10ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-58.2948, -0.137062, \
1.60664, 0.00720095}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] 0.49966958432041564`\), 
        ",", \(BackFocalLength \[Rule] 93.35095557506479`\), 
        ",", \(BackFocalPoint \[Rule] {103.35095557506479`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] 0.10515207566943371`\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] 0\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {0, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.583004929987583`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {3.416995070012417`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 1\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 1, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FindPupils \[Rule] True\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 99.93396050505237`\), 
        ",", \(FrequencyCutoff \[Rule] 378.0374640861614`\), 
        ",", \(FrontFocalLength \[Rule] 99.93396050505234`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-99.93396050505234`\), 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {102.50971221923828`, 0, 0}\), 
        ",", \(ImageSampleSize \[Rule] 0.00039530855514824706`\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(PlanoConvexLens[100, 50, 10]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[Screen[1], {103 + d, 103.`}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.9341264481391712`, 
              6.583004929987581`}, {\(-0.010006608313591684`\), 
              0.9999999999999998`}}\), ",", 
        RowBox[{"ModulationTransferFunction", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 378.198846498888`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(NumberOfPoints \[Rule] 154\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(Move[LineOfRays[20], {\(-50.`\), {y, 0}}]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 58.62342258649551`\), ",", 
        RowBox[{"OpticalLengthFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-10.015327705855315`\), 
                  10.015327705855315`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-10.015327705855315`\), 
                  10.015327705855315`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {58.62342258649551`, 
            58.62508781772297`}\), ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"ModulationTransferFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PaddingFactor \[Rule] 8\), 
        ",", \(ParaxialReductionRatio \[Rule] 0.002`\), ",", 
        RowBox[{"PerfectModulationTransferFunction", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 378.198846498888`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPhaseTransferFunction", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 378.198846498888`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.100803681562803`\), 
                  0.10119899011795125`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PhaseTransferFunction", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 378.198846498888`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] True\), 
        ",", \(PlotPoints \[Rule] 32\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.100803681562803`\), 
                  0.10119899011795125`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{2.842170943040401`*^-14, 0, 
              0}, {3.416995070012419`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 3.4169950700123906`\), 
        ",", \(RayBoundary \[Rule] {\(-10.015327705855315`\), 
            10.015327705855315`}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] PointSpreadFunction\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] True\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 17849\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.10978289056499839`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{0.003511874975144755`, 
              99.75859867874478`}, {\(-0.010006608313591682`\), 
              0.49966958432041564`}}\), 
        ",", \(TransverseMagnification \[Rule] 0.003511874975144755`\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-12.445282539239507`\), 
                  12.354576541926033`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[132]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
MTF[opticalsystem,NumberOfRays->256,FindImagePoint->True,\
GeometricPointSpreadFunction->True]\
\>", "Input",
  CellLabel->"In[133]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 15.3449 -0.0144948 0.000159314 [
[.03965 -0.02699 -15 -9 ]
[.03965 -0.02699 15 0 ]
[.1931 -0.02699 -15 -9 ]
[.1931 -0.02699 15 0 ]
[.34655 -0.02699 -15 -9 ]
[.34655 -0.02699 15 0 ]
[.65345 -0.02699 -12 -9 ]
[.65345 -0.02699 12 0 ]
[.8069 -0.02699 -12 -9 ]
[.8069 -0.02699 12 0 ]
[.96035 -0.02699 -12 -9 ]
[.96035 -0.02699 12 0 ]
[.4875 .06516 -18 -4.5 ]
[.4875 .06516 0 4.5 ]
[.4875 .14482 -24 -4.5 ]
[.4875 .14482 0 4.5 ]
[.4875 .22448 -24 -4.5 ]
[.4875 .22448 0 4.5 ]
[.4875 .30413 -24 -4.5 ]
[.4875 .30413 0 4.5 ]
[.4875 .38379 -24 -4.5 ]
[.4875 .38379 0 4.5 ]
[.4875 .46345 -24 -4.5 ]
[.4875 .46345 0 4.5 ]
[.4875 .5431 -24 -4.5 ]
[.4875 .5431 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 -0.01449 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03965 -0.01449 m
.03965 -0.00824 L
s
[(-0.03)] .03965 -0.02699 0 1 Mshowa
.1931 -0.01449 m
.1931 -0.00824 L
s
[(-0.02)] .1931 -0.02699 0 1 Mshowa
.34655 -0.01449 m
.34655 -0.00824 L
s
[(-0.01)] .34655 -0.02699 0 1 Mshowa
.65345 -0.01449 m
.65345 -0.00824 L
s
[(0.01)] .65345 -0.02699 0 1 Mshowa
.8069 -0.01449 m
.8069 -0.00824 L
s
[(0.02)] .8069 -0.02699 0 1 Mshowa
.96035 -0.01449 m
.96035 -0.00824 L
s
[(0.03)] .96035 -0.02699 0 1 Mshowa
.125 Mabswid
.07034 -0.01449 m
.07034 -0.01074 L
s
.10103 -0.01449 m
.10103 -0.01074 L
s
.13172 -0.01449 m
.13172 -0.01074 L
s
.16241 -0.01449 m
.16241 -0.01074 L
s
.22379 -0.01449 m
.22379 -0.01074 L
s
.25448 -0.01449 m
.25448 -0.01074 L
s
.28517 -0.01449 m
.28517 -0.01074 L
s
.31586 -0.01449 m
.31586 -0.01074 L
s
.37724 -0.01449 m
.37724 -0.01074 L
s
.40793 -0.01449 m
.40793 -0.01074 L
s
.43862 -0.01449 m
.43862 -0.01074 L
s
.46931 -0.01449 m
.46931 -0.01074 L
s
.53069 -0.01449 m
.53069 -0.01074 L
s
.56138 -0.01449 m
.56138 -0.01074 L
s
.59207 -0.01449 m
.59207 -0.01074 L
s
.62276 -0.01449 m
.62276 -0.01074 L
s
.68414 -0.01449 m
.68414 -0.01074 L
s
.71483 -0.01449 m
.71483 -0.01074 L
s
.74552 -0.01449 m
.74552 -0.01074 L
s
.77621 -0.01449 m
.77621 -0.01074 L
s
.83759 -0.01449 m
.83759 -0.01074 L
s
.86828 -0.01449 m
.86828 -0.01074 L
s
.89897 -0.01449 m
.89897 -0.01074 L
s
.92966 -0.01449 m
.92966 -0.01074 L
s
.00896 -0.01449 m
.00896 -0.01074 L
s
.99104 -0.01449 m
.99104 -0.01074 L
s
.25 Mabswid
0 -0.01449 m
1 -0.01449 L
s
.5 .06516 m
.50625 .06516 L
s
[(500)] .4875 .06516 1 0 Mshowa
.5 .14482 m
.50625 .14482 L
s
[(1000)] .4875 .14482 1 0 Mshowa
.5 .22448 m
.50625 .22448 L
s
[(1500)] .4875 .22448 1 0 Mshowa
.5 .30413 m
.50625 .30413 L
s
[(2000)] .4875 .30413 1 0 Mshowa
.5 .38379 m
.50625 .38379 L
s
[(2500)] .4875 .38379 1 0 Mshowa
.5 .46345 m
.50625 .46345 L
s
[(3000)] .4875 .46345 1 0 Mshowa
.5 .5431 m
.50625 .5431 L
s
[(3500)] .4875 .5431 1 0 Mshowa
.125 Mabswid
.5 .08109 m
.50375 .08109 L
s
.5 .09702 m
.50375 .09702 L
s
.5 .11296 m
.50375 .11296 L
s
.5 .12889 m
.50375 .12889 L
s
.5 .16075 m
.50375 .16075 L
s
.5 .17668 m
.50375 .17668 L
s
.5 .19261 m
.50375 .19261 L
s
.5 .20854 m
.50375 .20854 L
s
.5 .24041 m
.50375 .24041 L
s
.5 .25634 m
.50375 .25634 L
s
.5 .27227 m
.50375 .27227 L
s
.5 .2882 m
.50375 .2882 L
s
.5 .32006 m
.50375 .32006 L
s
.5 .336 m
.50375 .336 L
s
.5 .35193 m
.50375 .35193 L
s
.5 .36786 m
.50375 .36786 L
s
.5 .39972 m
.50375 .39972 L
s
.5 .41565 m
.50375 .41565 L
s
.5 .43158 m
.50375 .43158 L
s
.5 .44752 m
.50375 .44752 L
s
.5 .47938 m
.50375 .47938 L
s
.5 .49531 m
.50375 .49531 L
s
.5 .51124 m
.50375 .51124 L
s
.5 .52717 m
.50375 .52717 L
s
.5 .04923 m
.50375 .04923 L
s
.5 .0333 m
.50375 .0333 L
s
.5 .01737 m
.50375 .01737 L
s
.5 .00144 m
.50375 .00144 L
s
.5 .55903 m
.50375 .55903 L
s
.5 .57497 m
.50375 .57497 L
s
.5 .5909 m
.50375 .5909 L
s
.5 .60683 m
.50375 .60683 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Geometric Point Spread Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02558 .023 L
.02723 .03235 L
.03097 .06033 L
.03462 .09803 L
.03853 .15074 L
.04678 .29863 L
.05458 .4522 L
.05825 .51366 L
.06215 .56328 L
.06418 .58154 L
.06534 .58944 L
.06642 .59521 L
.06693 .59738 L
.06742 .59912 L
.06785 .60043 L
.06832 .60156 L
.06859 .60208 L
.06883 .60246 L
.0693 .60301 L
.06956 .6032 L
.06985 .60331 L
.07012 .60332 L
.07037 .60325 L
.07085 .60292 L
.0713 .60236 L
.07171 .60166 L
.07216 .6007 L
.07315 .59779 L
.07408 .59424 L
.07576 .58586 L
.07754 .57466 L
.08541 .50918 L
.09291 .44536 L
.09979 .39958 L
.10338 .38139 L
.10716 .36592 L
.11511 .34238 L
.12263 .32602 L
.12962 .31249 L
.1445 .28747 L
.16031 .26698 L
.17554 .2514 L
.19019 .23949 L
.20578 .22899 L
.22079 .22053 L
.23523 .2137 L
.25059 .20731 L
.26538 .20217 L
.28111 .19724 L
Mistroke
.29625 .19328 L
.31082 .18982 L
.32633 .18666 L
.34125 .18401 L
.35711 .18151 L
.3724 .17949 L
.3871 .17778 L
.40274 .17624 L
.41781 .17503 L
.43229 .17405 L
.44771 .17323 L
.46255 .17266 L
.47066 .17242 L
.47833 .17226 L
.48202 .1722 L
.48593 .17214 L
.48927 .1721 L
.49103 .17209 L
.49203 .17208 L
.49251 .17207 L
.49295 .17207 L
.49342 .17207 L
.49386 .17207 L
.49433 .17206 L
.49457 .17206 L
.49483 .17206 L
.49533 .17206 L
.4956 .17206 L
.49586 .17206 L
.49681 .17206 L
.49726 .17206 L
.4977 .17206 L
.49809 .17206 L
.49851 .17206 L
.49897 .17206 L
.49946 .17206 L
.49988 .17206 L
.50034 .17206 L
.50084 .17206 L
.50109 .17206 L
.50137 .17206 L
.50185 .17206 L
.50231 .17206 L
.50259 .17206 L
.50285 .17206 L
.50334 .17206 L
.50444 .17206 L
.50628 .17207 L
.50654 .17207 L
.50679 .17207 L
Mistroke
.50704 .17207 L
.50733 .17207 L
.50779 .17207 L
.50829 .17208 L
.51193 .17211 L
.5158 .17216 L
.52005 .17223 L
.524 .1723 L
.53194 .17249 L
.53913 .17271 L
.55441 .17333 L
.5691 .17413 L
.58473 .17521 L
.59978 .17648 L
.61425 .17792 L
.62966 .17975 L
.64449 .18175 L
.66025 .18426 L
.67544 .18701 L
.69005 .19001 L
.70559 .19375 L
.72056 .19772 L
.73495 .20228 L
.75027 .20764 L
.76502 .2138 L
.78069 .22134 L
.7958 .22992 L
.81032 .23988 L
.82578 .25257 L
.84066 .26813 L
.85648 .28891 L
.87172 .31502 L
.8787 .32871 L
.88638 .34611 L
.89396 .37015 L
.8981 .38846 L
.90198 .40995 L
.90971 .46646 L
.91677 .52872 L
.92029 .55851 L
.92403 .58461 L
.92514 .5906 L
.92618 .5953 L
.92712 .59868 L
.9276 .60008 L
.92813 .60134 L
.92863 .60226 L
.92909 .60286 L
.92958 .60323 L
.92986 .60332 L
Mistroke
.93011 .60332 L
.93056 .60312 L
.93104 .60264 L
.9315 .60191 L
.93193 .60099 L
.93285 .59818 L
.9337 .59463 L
.93468 .58933 L
.93561 .58309 L
.93726 .56916 L
.93906 .54986 L
.94313 .49191 L
.94691 .42427 L
.95459 .27169 L
.95835 .20173 L
.96182 .14558 L
.96511 .10125 L
.96872 .06308 L
.97235 .03499 L
.97434 .02344 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[133]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000Aoooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`00013ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o0000=?ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol0000Aooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000_ooool5o`00013ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`?o00005_ooool001Wooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00003oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0<_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00003ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`0Cooooo`004_ooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00Kooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0<_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool03oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool03oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool04oooool001Wooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00003ooooo`;o00004?ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0<_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000Fooooo`006Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
3Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01?ooooo000Iooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l0000dooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000_ooool2o`00017ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Cooooo`006_ooool2o`0000[o
oooo0_l00003ooooo`?o00004Oooool2o`0000[ooooo0_l00003ooooo`?o00004Oooool2o`0000[o
oooo0_l00004ooooo`03o`000?oooooooooo03?ooooo0_l0000:ooooo`;o00001?ooool00ol0003o
ooooooooo`0@ooooo`;o00002_ooool2o`0000?ooooo0ol0000Aooooo`;o00002_ooool2o`0000?o
oooo0ol0000Fooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`006?ooooobo`0001Kooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Mooooo`00oooooolQooooo`00TOooool00ol0003oooooooooo`2<
ooooo`00TOooool00ol0003oooooooooo`2<ooooo`00TOooool00ol0003oooooooooo`2<ooooo`00
TOooool00ol0003oooooooooo`2<ooooo`007Oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool06Oooool001gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool06_ooool001kooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01[ooooo
000Nooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`0Jooooo`007_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool06_ooool001kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo01[ooooo000Oooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`0Jooooo`007oooool00ol0003oooooooooo`1Jooooo`?o0000
1?ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
6oooool001oooooo00?o0000ooooooooool0FOooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool06oooool001oooooo00?o0000ooooooooool0GOooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01_ooooo000Oooooo`03o`000?oooooooooo
05gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00?ooooo0_l0001_ooooo`03o`000?oooooooooo01_ooooo000Oooooo`03o`000?oooooo
oooo05Wooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01_ooooo000Oooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Kooooo`00
7oooool00ol0003oooooooooo`1Iooooo`Go00000oooool2o`0000Cooooo0_l00006ooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool06oooool0023ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01_ooooo000Pooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Looooo`008?ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool07?ooool0023o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo01co
oooo000Pooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Looooo`008?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool07?ooool0023ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo01cooooo000Pooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0Looooo`008?ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool07?ooool0023ooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo01cooooo000Pooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Looooo`008Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool07Oooool0
027ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
01gooooo000Qooooo`03o`000?oooooooooo05;ooooo0ol00004ooooo`;o00001?ooool2o`0000Co
oooo0_l00006ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool07Oooool0027ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo06cooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00005ooooo`;o0000KOooool00ol0003oooooooooo`0Mooooo`008Ooo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool0K?ooool00ol0003oooooooooo`0Mooooo`008Oooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0K?ooool00ol0003ooooooooo
o`0Mooooo`008Oooool00ol0003oooooooooo`1Booooo`;o00001?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool00ol0003ooooo
ooooo`1/ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool0K?ooool00ol0003oooooooooo`0Mooooo`008Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000oooo
ooooool0Eoooool]o`0005Sooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000oooooooo
ool0C?ooool;o`0001Kooooo00?o0000ooooooooool05?ooool7o`00053ooooo00?o0000oooooooo
ool07_ooool0027ooooo00?o0000ooooooooool0B?ooool4o`00027ooooo00?o0000ooooooooool0
6oooool7o`0004Wooooo00?o0000ooooooooool07_ooool0027ooooo00?o0000ooooooooool0@Ooo
ool7o`0002Gooooo00?o0000ooooooooool08_ooool8o`00047ooooo00?o0000ooooooooool07_oo
ool0027ooooo00?o0000ooooooooool0?Oooool4o`0002cooooo00?o0000ooooooooool0:_ooool3
o`0003kooooo00?o0000ooooooooool07_ooool002;ooooo00?o0000ooooooooool0>Oooool3o`00
033ooooo00?o0000ooooooooool0;Oooool4o`0003[ooooo00?o0000ooooooooool07_ooool002;o
oooo00?o0000ooooooooool0=Oooool4o`0003?ooooo00?o0000ooooooooool0<Oooool4o`0003Ko
oooo00?o0000ooooooooool07_ooool002;ooooo00?o0000ooooooooool0<Oooool4o`0003Oooooo
00?o0000ooooooooool0=Oooool3o`0003?ooooo00?o0000ooooooooool07_ooool002;ooooo00?o
0000ooooooooool0;_ooool3o`0003_ooooo00?o0000ooooooooool0>?ooool3o`00033ooooo00?o
0000ooooooooool07_ooool002;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo03_ooooo0_l0000^ooooo`03o`000?oooooooooo01kooooo000Roooo
o`03o`000?oooooooooo02[ooooo0ol0000Tooooo`?o00000oooool3o`0000Cooooo0_l00004oooo
o`;o00001_ooool00ol0003oooooooooo`0mooooo`;o0000;?ooool00ol0003oooooooooo`0Noooo
o`008_ooool00ol0003oooooooooo`0Wooooo`?o0000:?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo01kooooo000Rooooo`03o`000?oooooooooo02Gooooo0_l0000[ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00?ooooo0_l00011ooooo`;o0000:Oooool00ol0003oooooooooo`0Nooooo`008_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`12ooooo`;o00009oooool00ol0003oooooooooo`0Nooooo`00
8_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02cooooo00Co0000oooooooooooo
oooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`14ooooo`;o00009Oooool00ol0003oooooooooo`0Nooooo`008_ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo02cooooo0_l00003ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo04Kooooo0_l0000Sooooo`03o`000?oooooooooo01kooooo000Rooooo`03o`000?oooooo
oooo023ooooo0_l0000`ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Cooooo0_l0
0006ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Oooooo`008_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo000Roooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07oooool002;ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Oooooo`008_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01oooooo000Rooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07ooo
ool002?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Oooooo`008oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo000Sooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool07oooool002?ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Oooooo`008oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05;ooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01oooooo000S
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07oooool002?ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Oooooo`008oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo03Oooooo1Ol00003ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Oooooo`00
8oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Wooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool07oooool002?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01oooooo000Sooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0??ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo0_l0001F
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07oooool002?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool07oooool002?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0kooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1Fooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool07oooool002?ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0looooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07oooool0
02?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`008oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01oooooo000Sooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool07oooool002?ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Oooooo`009?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01oooooo000Toooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool002Cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Oooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Fooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?oo
ool002Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool08?ooool002Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`10ooooo`Go00000_ooool3o`0000Cooooo0_l00004ooooo`;o00001_ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool002Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`12ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool08?ooool002Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`;o0000G_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0@Oooool01_l0003ooooooooooooooooo0000ooooo`Co00000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0@_ooool01ol0003ooooooooooooooooo0000ooooool000001_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool0GOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0@oooool3o`0000;ooooo1Ol00003ooooo`;o0000
1?ooool2o`0000Kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?oo
ool002Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08?ooool002Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Pooooo`009Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo000U
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool002Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Pooooo`009Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo023ooooo000Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8?ooool002Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`009Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo000Uooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool08?ooool002Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`15ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool002Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`14ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool08?ooool002Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`18
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo0_l0001Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool08Oooool002Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`17ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08Oooool002Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`19ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo000Uooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0AOooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo027ooooo000Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A_ooool3o`00
00Cooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo000Vooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool08Oooool002Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Qooooo`009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo000V
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool002Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Qooooo`009_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo027ooooo000Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
8Oooool002Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Qooooo`009_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo000Vooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool08Oooool002Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Rooooo`009_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo
000Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0B?ooool3o`0000?ooooo0ol0
0004ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02;ooooo000Vooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Aoooool01ol0003ooooooooooooooooo0000ooooool000000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool002Oo
oooo00Go0000ooooooooooooooooo`00001=ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo0_l0
001Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool002Oooooo00Go0000
ooooooooooooooooo`00001;ooooo`;o00001_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool002Oooooo00Go0000oooooooooooo
ooooo`00001=ooooo`03o`000?oooooo000000?o00000oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02;ooooo000Wooooo`05o`000?ooooooooooooooool00000BOooool0
1ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02;ooooo000Wooooo`05o`000?ooooooooooooooool00000B_ooool3o`00
00;ooooo1Ol00003ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo000Wooooo`04o`000?ooooooooooo`00
06Kooooo00?o0000ooooooooool0H_ooool01Ol0003ooooooooooooooooo000002Gooooo000Woooo
o`04o`000?ooooooooooo`0006Kooooo00?o0000ooooooooool0H_ooool01Ol0003ooooooooooooo
oooo000002Gooooo000Wooooo`04o`000?ooooooooooo`0006Kooooo00?o0000ooooooooool0H_oo
ool01Ol0003ooooooooooooooooo000002Gooooo000Wooooo`04o`000?ooooooooooo`0006Kooooo
00?o0000ooooooooool0Hoooool01?l0003oooooooooool0000Uooooo`009oooool01?l0003ooooo
ooooool0001Vooooo`03o`000?oooooooooo06?ooooo00Co0000oooooooooooo00009Oooool002Oo
oooo00Co0000oooooooooooo0000I_ooool00ol0003oooooooooo`1Sooooo`04o`000?oooooooooo
o`0002Gooooo000Wooooo`04o`000?ooooooooooo`0006Kooooo00?o0000ooooooooool0Hoooool0
1?l0003oooooooooool0000Uooooo`009oooool01?l0003oooooooooool0001Vooooo`03o`000?oo
oooooooo06?ooooo00Co0000oooooooooooo00009Oooool002Sooooo00?o0000ooooool00000I_oo
ool00ol0003oooooooooo`1Tooooo`;o00009_ooool002Sooooo0_l0001Wooooo`03o`000?oooooo
oooo06Cooooo0_l0000Vooooo`00:?ooool2o`0006Oooooo00?o0000ooooooooool0I?ooool2o`00
02Kooooo002Aooooo`03o`000?oooooooooo08cooooo002Aooooo`03o`000?oooooooooo08cooooo
002Aooooo`03o`000?oooooooooo08cooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo002Jooooo`?o0000Poooool009_ooooo00?o0000ooooooooool0P_ooool003Gooooo0ol00003
ooooo`?o00000oooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o00001?oo
ool2o`0000;ooooo0ol00003ooooo`Go00000_ooool3o`0000Sooooo0ol00004ooooo`?o00000_oo
ool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00002Oooool3o`0000?ooooo
0ol00002ooooo`?o00001?ooool3o`0000?ooooo1?l00002ooooo`Co00001oooool3o`0000Gooooo
0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000;o
oooo1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o000003;ooooo000dooooo`07o`00
0?ooooooooooooooool0003oooooo`000005ooooo`0=o`000?ooooooooooooooool0003oooooo`00
0?oooooo0000ooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000c
ooooo`00=?ooool01_l0003ooooooooooooooooo0000ooooo`Go000000?oooooo`000?ooool00_oo
ool02?l0003oooooo`000?oooooo0000ooooool0003ooooo1Ol00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`Go00000_ooool3o`0000;ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Ko
0000oooooooooooo0000ooooool00006ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0<Oooool0
03Cooooo00?o0000ooooool000001?l00003ooooo`03o`000?oooooo000000?ooooo00Wo0000oooo
ool0003oooooo`000?oooooo0000ooooool000000oooool01?l0003oooooooooool00005ooooo`;o
00001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool3o`00
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0:ooooo`;o00000oooool01?l0003ooooooooo
ool00002ooooo`;o00000oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`00
00Kooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool0<Oooool003Cooooo00?o0000ooooooooool01?ooool3o`0000?ooooo0ol00002
ooooo`;o000000?oooooo`000?ooool00_ooool3o`0000;ooooo1?l00002ooooo`;o000000Cooooo
o`000?l0003ooooo0ol00004ooooo`?o00002Oooool01?l0003oooooooooool00002ooooo`?o0000
0_ooool3o`0000?ooooo1?l00002ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`Co0000
0_ooool2o`000003ooooool0003o000000;ooooo0ol00003ooooo`;o00001?ooool3o`0000Wooooo
00?o0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool3o`0000;o
oooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l0000dooooo`00=?ooool01Ol0003ooooo
oooooooooooo000001[ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0000Doooo
o`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`07
ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0A_ooool003Gooooo0ol0000K
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool4o`0000[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`?o00006oooool2o`0000Sooooo1Ol0000D
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0390923, -312.161, \
0.000269602, 25.9677}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00043174 0.0280925 0.561849 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.23968 -0.0125 -9 -9 ]
[.23968 -0.0125 9 0 ]
[.45555 -0.0125 -12 -9 ]
[.45555 -0.0125 12 0 ]
[.67142 -0.0125 -12 -9 ]
[.67142 -0.0125 12 0 ]
[.88729 -0.0125 -12 -9 ]
[.88729 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .14046 -18 -4.5 ]
[-0.0125 .14046 0 4.5 ]
[-0.0125 .25283 -18 -4.5 ]
[-0.0125 .25283 0 4.5 ]
[-0.0125 .3652 -18 -4.5 ]
[-0.0125 .3652 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -84 0 ]
[.5 .63053 84 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.23968 0 m
.23968 .00625 L
s
[(500)] .23968 -0.0125 0 1 Mshowa
.45555 0 m
.45555 .00625 L
s
[(1000)] .45555 -0.0125 0 1 Mshowa
.67142 0 m
.67142 .00625 L
s
[(1500)] .67142 -0.0125 0 1 Mshowa
.88729 0 m
.88729 .00625 L
s
[(2000)] .88729 -0.0125 0 1 Mshowa
.125 Mabswid
.06698 0 m
.06698 .00375 L
s
.11016 0 m
.11016 .00375 L
s
.15333 0 m
.15333 .00375 L
s
.19651 0 m
.19651 .00375 L
s
.28285 0 m
.28285 .00375 L
s
.32603 0 m
.32603 .00375 L
s
.3692 0 m
.3692 .00375 L
s
.41238 0 m
.41238 .00375 L
s
.49872 0 m
.49872 .00375 L
s
.5419 0 m
.5419 .00375 L
s
.58507 0 m
.58507 .00375 L
s
.62825 0 m
.62825 .00375 L
s
.71459 0 m
.71459 .00375 L
s
.75777 0 m
.75777 .00375 L
s
.80094 0 m
.80094 .00375 L
s
.84412 0 m
.84412 .00375 L
s
.93046 0 m
.93046 .00375 L
s
.97364 0 m
.97364 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .14046 m
.00625 .14046 L
s
[(0.2)] -0.0125 .14046 1 0 Mshowa
0 .25283 m
.00625 .25283 L
s
[(0.4)] -0.0125 .25283 1 0 Mshowa
0 .3652 m
.00625 .3652 L
s
[(0.6)] -0.0125 .3652 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(0.8)] -0.0125 .47757 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(1)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.23968 .61178 m
.23968 .61803 L
s
.45555 .61178 m
.45555 .61803 L
s
.67142 .61178 m
.67142 .61803 L
s
.88729 .61178 m
.88729 .61803 L
s
.125 Mabswid
.06698 .61428 m
.06698 .61803 L
s
.11016 .61428 m
.11016 .61803 L
s
.15333 .61428 m
.15333 .61803 L
s
.19651 .61428 m
.19651 .61803 L
s
.28285 .61428 m
.28285 .61803 L
s
.32603 .61428 m
.32603 .61803 L
s
.3692 .61428 m
.3692 .61803 L
s
.41238 .61428 m
.41238 .61803 L
s
.49872 .61428 m
.49872 .61803 L
s
.5419 .61428 m
.5419 .61803 L
s
.58507 .61428 m
.58507 .61803 L
s
.62825 .61428 m
.62825 .61803 L
s
.71459 .61428 m
.71459 .61803 L
s
.75777 .61428 m
.75777 .61803 L
s
.80094 .61428 m
.80094 .61803 L
s
.84412 .61428 m
.84412 .61803 L
s
.93046 .61428 m
.93046 .61803 L
s
.97364 .61428 m
.97364 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .14046 m
1 .14046 L
s
.99375 .25283 m
1 .25283 L
s
.99375 .3652 m
1 .3652 L
s
.99375 .47757 m
1 .47757 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(Modulation Transfer Function)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .58994 m
.0263 .46176 L
.02878 .16702 L
.03127 .15166 L
.03376 .22743 L
.03624 .11625 L
.03873 .10288 L
.04122 .17019 L
.0437 .10063 L
.04619 .07983 L
.04868 .14093 L
.05116 .09216 L
.05365 .06574 L
.05614 .12218 L
.05862 .0864 L
.06111 .05607 L
.0636 .10875 L
.06608 .082 L
.06857 .04897 L
.07106 .09846 L
.07354 .07843 L
.07603 .0435 L
.07852 .09021 L
.081 .07539 L
.08349 .03914 L
.08598 .08335 L
.08846 .07272 L
.09095 .03555 L
.09344 .07748 L
.09592 .07029 L
.09841 .03257 L
.1009 .07234 L
.10338 .06799 L
.10587 .03007 L
.10836 .06775 L
.11084 .06577 L
.11333 .02819 L
.11581 .06361 L
.1183 .06358 L
.12079 .02987 L
.12327 .05987 L
.12576 .06139 L
.12825 .03117 L
.13073 .0565 L
.13322 .05921 L
.13571 .03212 L
.13819 .0535 L
.14068 .05707 L
.14317 .03276 L
.14565 .05085 L
Mistroke
.14814 .05499 L
.15063 .03312 L
.15311 .04856 L
.1556 .053 L
.15809 .03325 L
.16057 .04659 L
.16306 .05113 L
.16555 .03319 L
.16803 .04492 L
.17052 .04942 L
.17301 .033 L
.17549 .04353 L
.17798 .04786 L
.18047 .03273 L
.18295 .04238 L
.18544 .04647 L
.18793 .03241 L
.19041 .04143 L
.1929 .04524 L
.19539 .03207 L
.19787 .04064 L
.20036 .04415 L
.20285 .03173 L
.20533 .03998 L
.20782 .0432 L
.21031 .03141 L
.21279 .03942 L
.21528 .04237 L
.21777 .03112 L
.22025 .03894 L
.22274 .04164 L
.22523 .03085 L
.22771 .03853 L
.2302 .04101 L
.23269 .03062 L
.23517 .03816 L
.23766 .04045 L
.24015 .03043 L
.24263 .03782 L
.24512 .03995 L
.24761 .03028 L
.25009 .03749 L
.25258 .03948 L
.25507 .03016 L
.25755 .03716 L
.26004 .03903 L
.26253 .03002 L
.26501 .03686 L
.2675 .03858 L
.26999 .02985 L
Mistroke
.27247 .03662 L
.27496 .0382 L
.27745 .0297 L
.27993 .03642 L
.28242 .03789 L
.28491 .0296 L
.28739 .03621 L
.28988 .03758 L
.29237 .02951 L
.29485 .03599 L
.29734 .03728 L
.29983 .02941 L
.30231 .03581 L
.3048 .03702 L
.30729 .02934 L
.30977 .03563 L
.31226 .03677 L
.31475 .02926 L
.31723 .03546 L
.31972 .03653 L
.32221 .02919 L
.32469 .03531 L
.32718 .03631 L
.32967 .02913 L
.33215 .03515 L
.33464 .03611 L
.33713 .02908 L
.33961 .03501 L
.3421 .03591 L
.34459 .02902 L
.34707 .03487 L
.34956 .03573 L
.35205 .02898 L
.35453 .03474 L
.35702 .03555 L
.35951 .02893 L
.36199 .03461 L
.36448 .03539 L
.36697 .02889 L
.36945 .0345 L
.37194 .03523 L
.37442 .02885 L
.37691 .03438 L
.3794 .03508 L
.38188 .02882 L
.38437 .03427 L
.38686 .03494 L
.38934 .02878 L
.39183 .03417 L
.39432 .0348 L
Mistroke
.3968 .02875 L
.39929 .03407 L
.40178 .03468 L
.40426 .02872 L
.40675 .03397 L
.40924 .03455 L
.41172 .02869 L
.41421 .03388 L
.4167 .03444 L
.41918 .02867 L
.42167 .03379 L
.42416 .03432 L
.42664 .02864 L
.42913 .03371 L
.43162 .03422 L
.4341 .02862 L
.43659 .03363 L
.43908 .03411 L
.44156 .0286 L
.44405 .03355 L
.44654 .03402 L
.44902 .02858 L
.45151 .03347 L
.454 .03392 L
.45648 .02856 L
.45897 .0334 L
.46146 .03383 L
.46394 .02854 L
.46643 .03333 L
.46892 .03375 L
.4714 .02852 L
.47389 .03326 L
.47638 .03366 L
.47886 .02851 L
.48135 .0332 L
.48384 .03358 L
.48632 .02849 L
.48881 .03314 L
.4913 .03351 L
.49378 .02848 L
.49627 .03308 L
.49876 .03343 L
.50124 .02846 L
.50373 .03302 L
.50622 .03336 L
.5087 .02845 L
.51119 .03296 L
.51368 .03329 L
.51616 .02844 L
.51865 .03291 L
Mistroke
.52114 .03323 L
.52362 .02842 L
.52611 .03286 L
.5286 .03316 L
.53108 .02841 L
.53357 .03281 L
.53606 .0331 L
.53854 .0284 L
.54103 .03276 L
.54352 .03304 L
.546 .02839 L
.54849 .03271 L
.55098 .03299 L
.55346 .02838 L
.55595 .03267 L
.55844 .03293 L
.56092 .02837 L
.56341 .03263 L
.5659 .03288 L
.56838 .02836 L
.57087 .03258 L
.57336 .03283 L
.57584 .02835 L
.57833 .03254 L
.58082 .03278 L
.5833 .02834 L
.58579 .0325 L
.58828 .03273 L
.59076 .02833 L
.59325 .03247 L
.59574 .03269 L
.59822 .02832 L
.60071 .03243 L
.6032 .03264 L
.60568 .02832 L
.60817 .03239 L
.61066 .0326 L
.61314 .02831 L
.61563 .03236 L
.61812 .03256 L
.6206 .0283 L
.62309 .03233 L
.62558 .03252 L
.62806 .02829 L
.63055 .0323 L
.63303 .03248 L
.63552 .02829 L
.63801 .03227 L
.64049 .03245 L
.64298 .02828 L
Mistroke
.64547 .03224 L
.64795 .03241 L
.65044 .02827 L
.65293 .03221 L
.65541 .03237 L
.6579 .02827 L
.66039 .03218 L
.66287 .03234 L
.66536 .02826 L
.66785 .03215 L
.67033 .03231 L
.67282 .02825 L
.67531 .03213 L
.67779 .03228 L
.68028 .02825 L
.68277 .0321 L
.68525 .03225 L
.68774 .02824 L
.69023 .03208 L
.69271 .03222 L
.6952 .02824 L
.69769 .03206 L
.70017 .03219 L
.70266 .02823 L
.70515 .03204 L
.70763 .03216 L
.71012 .02823 L
.71261 .03201 L
.71509 .03214 L
.71758 .02822 L
.72007 .03199 L
.72255 .03211 L
.72504 .02822 L
.72753 .03198 L
.73001 .03209 L
.7325 .02821 L
.73499 .03196 L
.73747 .03207 L
.73996 .02821 L
.74245 .03194 L
.74493 .03204 L
.74742 .0282 L
.74991 .03192 L
.75239 .03202 L
.75488 .0282 L
.75737 .0319 L
.75985 .032 L
.76234 .02819 L
.76483 .03189 L
.76731 .03198 L
Mistroke
.7698 .02819 L
.77229 .03187 L
.77477 .03196 L
.77726 .02819 L
.77975 .03186 L
.78223 .03195 L
.78472 .02818 L
.78721 .03185 L
.78969 .03193 L
.79218 .02818 L
.79467 .03183 L
.79715 .03191 L
.79964 .02817 L
.80213 .03182 L
.80461 .0319 L
.8071 .02817 L
.80959 .03181 L
.81207 .03188 L
.81456 .02817 L
.81705 .0318 L
.81953 .03187 L
.82202 .02816 L
.82451 .03179 L
.82699 .03185 L
.82948 .02816 L
.83197 .03178 L
.83445 .03184 L
.83694 .02816 L
.83943 .03177 L
.84191 .03183 L
.8444 .02815 L
.84689 .03176 L
.84937 .03181 L
.85186 .02815 L
.85435 .03175 L
.85683 .0318 L
.85932 .02814 L
.86181 .03174 L
.86429 .03179 L
.86678 .02814 L
.86927 .03174 L
.87175 .03178 L
.87424 .02814 L
.87673 .03173 L
.87921 .03177 L
.8817 .02813 L
.88419 .03173 L
.88667 .03176 L
.88916 .02813 L
.89164 .03172 L
Mistroke
.89413 .03175 L
.89662 .02813 L
.8991 .03172 L
.90159 .03175 L
.90408 .02812 L
.90656 .03171 L
.90905 .03174 L
.91154 .02812 L
.91402 .03171 L
.91651 .03173 L
.919 .02812 L
.92148 .03171 L
.92397 .03173 L
.92646 .02811 L
.92894 .0317 L
.93143 .03172 L
.93392 .02811 L
.9364 .0317 L
.93889 .03172 L
.94138 .02811 L
.94386 .0317 L
.94635 .03171 L
.94884 .02811 L
.95132 .0317 L
.95381 .03171 L
.9563 .0281 L
.95878 .0317 L
.96127 .03171 L
.96376 .0281 L
.96624 .0317 L
.96873 .0317 L
.97122 .0281 L
.9737 .0317 L
.97619 .0317 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[133]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008oooool2o`0002cooooo0ol00004ooooo`;o00001?ooool2o`0002?ooooo0ol00004oooo
o`;o00001?ooool2o`0000Cooooo0_l0000Qooooo`?o00000oooool3o`0000Cooooo0_l00004oooo
o`;o00007oooool5o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0001gooooo000Rooooo`04
o`000?ooooooooooo`0002[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Q
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Looooo`008_ooool01?l0003oooooooooool0000^ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`00027ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Looooo`008_ooool01?l0003oooooooooool0000^ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`00027ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo01[ooooo000Rooooo`04o`000?ooooooooooo`0002[ooooo1?l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Qooooo`04o`000?ooooooooooooooo`Co00000oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0001kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Loooo
o`008_ooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000Rooooo`;o00001?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008?ooool2o`00
00?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0001kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Looooo`008oooool2o`00
02_ooooo1Ol00003ooooo`;o00001?ooool2o`0002Cooooo00?o0000ooooooooool00oooool2o`00
00Cooooo0_l00004ooooo`;o00008_ooool01?l0003oooooooooooooool5o`0000?ooooo0_l00004
ooooo`;o00008?ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0001gooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000NooooooSo00002_ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0m?ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Sooooo
000Gooooo`;o00001Oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000F
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0m?ooool00ol0003ooooooooo
o`08ooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?Cooooo00?o
0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool2o`0001Sooooo00Oo
0000ooooool0003oooooo`000?oooooo0000017ooooo00Ko0000ooooool0003oooooo`000?ooool2
o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o000000_oooooo`000?oo
oooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`000009ooooool0003oooooo`000?oo
oooo0000ooooool0003ooooo00;o000000_oooooo`000?oooooo0000ooooool0003oooooo`000?oo
oooo0000ooooo`02o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o0000
00Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l000002ooooooo0000ooooool0
003oooooo`000?oooooo0000ooooool0003ooooo00;o000000Woooooo`000?oooooo0000ooooool0
003oooooo`000?ooool00_l000002ooooooo0000ooooool0003oooooo`000?oooooo0000ooooool0
003ooooo00;o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l000002Ooo
oooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`00000;ooooool0003oooooo`000?oo
oooo0000ooooool0003oooooo`000?ooool00_l000002Ooooooo0000ooooool0003oooooo`000?oo
oooo0000ooooo`0:o`000003ooooool0003o000001Co00001?ooool2o`0000[ooooo000Fooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04oooool02_l0003oooooo`000?oooooo
0000ooooool0003oooooo`000?ooool2o`00000;ooooool0003oooooo`000?oooooo0000ooooool0
003oooooo`000?ooool00_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02
o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o000000_oooooo`000?oo
oooo0000ooooool0003oooooo`000?oooooo0000ooooo`07o`000003ooooool0003o000000So0000
00?oooooo`000?l000002?l000000ooooooo0000o`000008o`000003ooooool0003ooooo00[o0000
00?oooooo`000?l000002?l000000ooooooo0000ooooo`0:o`000003ooooool0003o000000So0000
00?oooooo`000?ooool02?l000000ooooooo0000ooooo`0:o`000003ooooool0003o000000So0000
00?oooooo`000?ooool01Ol000000ooooooo0000ooooo`02o`000004ooooool0003oooooo`0001_o
oooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0Booooo`;o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l0
00002ooooooo0000ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o000000?ooooo
o`000?ooool02ol000000ooooooo0000ooooo`0:o`000009ooooool0003oooooo`000?oooooo0000
ooooool0003ooooo00;o0000X_ooool00ol0003oooooooooo`08ooooo`005oooool2o`0000Gooooo
00?o0000ooooooooool04?ooool03Ol0003oooooo`000?l0003oooooo`000?oooooo0000ooooool0
003oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00?o000000?oooooo`000?l0
00001Ol000002Ooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`000;[ooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool04?ooool03Ol0003oooooo`000?l0
003oooooo`000?oooooo0000ooooool0003oooooo`000?ooool01ol000002Ooooooo0000o`000?l0
003oooooo`000?oooooo0000ooooo`02o`000<Gooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool03_ooool01?l0003oooooo`000?ooool2o`000006ooooool0003o0000oooo
ool0003ooooo2_l000001?oooooo0000ooooool0003<ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00kooooo00Co0000ooooool0003ooooo0_l000001_oooooo0000o`00
0?oooooo0000ooooo`Oo000000?oooooo`000?l00000d?ooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0000gooooo00Co0000ooooool0003ooooo1ol000000ooooooo0000ooooo`05o`000003
ooooool0003ooooo0=7ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooo000000So000000Koooooo`000?oooooo0000ooooool0003Gooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00[ooooo00Co0000ooooool0003ooooo2Ol000000ooo
oooo0000ooooo`3Jooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooool000002_l0003Mooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00[ooooo3Ol0003Mooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooool000002_l0003Oooooo`03o`000?oooooooooo00Sooooo000N
ooooo`;o00002Oooool00ol0003oooooo`000008o`000>3ooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`08ooooo`05o`000?oooooo0000o`000?ooool01?l0003Sooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00Sooooo00Go0000ooooool0003o0000ooooo`02
o`000003ooooool0003ooooo0>;ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool02?ooool01Ol0003oooooo`000?l0003ooooo00;o0000iOooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`08ooooo`05o`000?oooooo0000o`000?ooool00_l0003U
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00Co0000oooo
ool0003ooooo0_l000000ooooooo0000ooooo`3Uooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Kooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`3U
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001oooool00ol0003oooooo`000003o`00
0003ooooool0003ooooo0>Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooo000000?o0000j?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`06ooooo`06o`000?oooooo0000o`000?oooooo0000j?ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`06ooooo`06o`000?oooooo0000o`000?oooooo0000j?ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000
o`000>[ooooo00?o0000ooooooooool02?ooool000_ooooo0_l00004ooooo`04o`000?oooooooooo
ooooo`Go00001?ooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`000>[ooooo00?o
0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0003o0000j_ooool00ol0003o
ooooooooo`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Co
oooo0_l00007ooooo`;o000000?oooooo`000?ooool0j?ooool2o`0000[ooooo000:ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`;o
0000k?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`06ooooo`;o0000k?ooool00ol0
003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`05ooooo`?o0000k?ooool00ol0003oooooooooo`08
ooooo`002oooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo0ol0003/oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo0ol0003/ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo1?l0003/ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`;o00001Oooool4o`000>_ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`04ooooo`Co0000k?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`04ooooo`;o0000k_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`04ooooo`;o0000k_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`;o0000k_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`04ooooo`;o0000k_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04
ooooo`;o0000k_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Gooooo0_l0003]oooo
o`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool2o`000>kooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool01?ooool2o`000>kooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool01?ooool2o`000>kooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool01?ooool2o`000>kooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01?ooool2o`000>kooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool01?ooool2o`000>kooooo00?o0000ooooooooool02?ooool001kooooo
0_l00005ooooo`;o0000kOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0
003^ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0kOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0>gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o0000
1?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0>gooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
kOooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`Go0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0k?ooool2o`0000[ooooo000:ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0>gooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0kOooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`;o
00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>gooooo00?o0000oooooooo
ool02?ooool000_ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool02?ooool0
01kooooo0_l00005ooooo`03o`000?oooooooooo0>cooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0kOooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>gooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3]oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0kOooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Gooooo00?o0000ooooooooool0
k?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0kOoo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0>kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3^ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0k_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`;o00001?ooool00ol0003oooooooooo`3]ooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_ooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool0
2?ooool000_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0k_ooool00ol0003oooooooooo`08ooooo`002_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool02?ooool000[ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`00
0?ooooooooooo`0000Oooooo1?l00005ooooo`;o00001?ooool00ol0003oooooooooo`3]ooooo`;o
00002_ooool000[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_ooool00ol0003oooooooooo`08ooooo`00
2_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o0000
2_ooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3^ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0>kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3^ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003o
ooooooooo`3]ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3^ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0k_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_ooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool0
2?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo0>gooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>kooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3^ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0k_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000oooo
ooooool0kOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0k_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0>kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0>kooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3^ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
k_ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`?o0000
1Oooool2o`0000Cooooo00?o0000ooooooooool0kOooool2o`0000[ooooo000:ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0k_ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0>kooooo00?o0000ooooooooool02?ooool000_ooooo0_l00009ooooo`?o
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3^ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0>kooooo00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo
0>gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>ko
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3^ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0k_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_ooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0000Cooooo00?o0000ooooooooool0kOooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0k_ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>kooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3^ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`3]
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3^oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0k_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0>kooooo00?o0000ooooooooool02?ooool001Kooooo0ol00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0k_ooool00ol0003oooooooooo`08ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_ooool0
0ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0
003oooooooooo`3]ooooo`;o00002_ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000Gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0m?ooool00ol0003oooooooooo`08ooooo`005_ooool2o`0000Kooooo00?o
0000ooooooooool0m?ooool00ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool0m?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`00
7_oooooho`0000[ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo0015ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`0000?ooooo
1?l00003ooooo`;o000000?oooooo`000?l000001?l00002ooooo`Co00000oooool2o`0000;ooooo
1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o000000Oooooo0ol00002ooooo`?o0000
1?ooool4o`000005ooooool0003o0000o`000?ooool01_l00002ooooo`Go00000_ooool3o`0000;o
oooo0ol00009ooooo`?o00001Oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0
003ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?oooooo`00
0?l00000<oooool004Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool0000dooooo`00AOooool01ol0003ooooooooooooo
oooo0000ooooool000000oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol00003ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0ol0
0003ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`04o`000?ooooooooooooooo`Go
00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0booooo`00AOooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00Co0000oooooooooooo00000oooool0
1_l0003oooooooooool0003oooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;o00002_ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0boooo
o`00AOooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`?o00000_ooool2o`00
0003ooooool0003o000000?ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo1?l00002oooo
o`?o00001?ooool3o`0000;ooooo1?l00008ooooo`06o`000?oooooo0000ooooool0003ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000oooool4o`0000?ooooo1?l00002ooooo`Co00000_oo
ool3o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oooooooooo00;ooooo0_l0
00001?oooooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co00000_ooool3o`0000Cooooo
0ol00002ooooo`Co0000=Oooool004Gooooo0_l000000ooooooo0000o`00000:ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`05o`000?oo
oooo0000ooooool000006oooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`0001Co
oooo00?o0000ooooooooool0Aoooool004Gooooo00Co0000oooooooooooooooo0_l00008ooooo`;o
00002?ooool3o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`Go
00007?ooool2o`0001?ooooo1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0@?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-340.015, -0.137062, \
9.37102, 0.00720095}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] 0.49966958432041564`\), 
        ",", \(BackFocalLength \[Rule] 93.35095557506479`\), 
        ",", \(BackFocalPoint \[Rule] {103.35095557506479`, 0, 0}\), 
        ",", \(ComponentNumber \[Rule] 2.`\), ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] 0\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {0, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.583004929987583`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {3.416995070012417`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 1\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 1, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 1}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalLength \[Rule] 99.93396050505237`\), 
        ",", \(FrequencyCutoff \[Rule] 2202.997085509424`\), 
        ",", \(FrontFocalLength \[Rule] 99.93396050505234`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-99.93396050505234`\), 0, 0}\), 
        ",", \(Full3D \[Rule] False\), 
        ",", \(GeometricPointSpreadFunction \[Rule] True\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {102.50971221923828`, 0, 0}\), 
        ",", \(ImageSampleSize \[Rule] 0.00015130902148073104`\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(PlanoConvexLens[100, 50, 10]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[Screen[1], {103 + d, 103.`}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.9341264481391712`, 
              6.583004929987581`}, {\(-0.010006608313591684`\), 
              0.9999999999999998`}}\), ",", 
        RowBox[{"ModulationTransferFunction", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 2205.91074430239`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(NumberOfPoints \[Rule] 256\), 
        ",", \(NumberOfRays \[Rule] 256\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(Move[LineOfRays[20], {\(-50.`\), {y, 0}}]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"ModulationTransferFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PerfectModulationTransferFunction \[Rule] 
          PerfectModulationTransferFunction\), 
        ",", \(PerfectPhaseTransferFunction \[Rule] 
          PerfectPhaseTransferFunction\), ",", 
        RowBox[{"PhaseTransferFunction", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 2205.91074430239`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PointSpreadFunction \[Rule] 
          "CompiledFunction[-intensity data-]"\), 
        ",", \(PrinciplePoints \[Rule] {{2.842170943040401`*^-14, 0, 
              0}, {3.416995070012419`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 3.4169950700123906`\), 
        ",", \(RayBoundary \[Rule] {\(-0.028824368592079708`\), 
            0.02882436859207882`}\), 
        ",", \(RayTraceFunction \[Rule] 
          "RayTraceFunction[{y}, -raytrace code: 945016 Bytes- ]"\), 
        ",", \(RotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}\), 
        ",", \(SmoothKernelSize \[Rule] 0.0014721333123236813`\), 
        ",", \(SourceID \[Rule] 17849\), 
        ",", \(SurfaceNormalFunction \[Rule] \(({{1, 0, 0}, {0, 1, 0}, {0, 0, 
                  1}} &)\)\), ",", \(SurfaceNumber \[Rule] 1.`\), 
        ",", \(SymbolicValues \[Rule] {y \[Rule] 0.`}\), 
        ",", \(SystemABCDMatrix \[Rule] {{0.003511874975144755`, 
              99.75859867874478`}, {\(-0.010006608313591682`\), 
              0.49966958432041564`}}\), 
        ",", \(TransverseMagnification \[Rule] 0.003511874975144755`\), 
        ",", \(WaveFrontID \[Rule] 1.`\), 
        ",", \(WaveLength \[Rule] 0.532`\)}], "}"}]], "Output",
  CellLabel->"Out[133]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define Systems", "Subsection",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell["\<\
This section serves to define the various optical systems used in later in \
imaging calculations.\
\>", "Text",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell["\<\
sys3D = 
\t{PointOfRays[{10,10}, NumberOfRays -> 5], 
\tMove[PlanoConvexLens[{f1,100}, 50, 9, CurvatureDirection -> Back],90.5],
\tMove[ApertureStop[50,30],100],
\tMove[PlanoConvexLens[{f2,100}, 50, 9], 100.5],
    Boundary[208, GraphicDesign -> Off]};\
\>", "Input",
  CellLabel->"In[134]:=",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[sys3D];", "Input",
  CellLabel->"In[135]:=",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .593 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0322525 1.03225 -0.201548 1.03225 [
[ 0 0 0 0 ]
[ 1 .593 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .593 L
0 .593 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.09295 .43973 m
.42246 .29386 L
s
.09295 .43973 m
.43966 .31228 L
s
.09295 .43973 m
.44819 .3215 L
s
.09295 .43973 m
.44803 .33558 L
s
.09295 .43973 m
.4219 .33679 L
s
.09295 .43973 m
.43922 .355 L
s
.09295 .43973 m
.44781 .364 L
s
.09295 .43973 m
.41284 .34195 L
s
.09295 .43973 m
.42168 .35128 L
s
.09295 .43973 m
.4391 .3695 L
s
.09295 .43973 m
.44774 .37845 L
s
0 g
.47711 .33616 m
.4689 .30906 L
s
.4689 .30906 m
.47873 .3059 L
s
.4689 .30906 m
.45815 .28341 L
s
.48227 .36302 m
.47711 .33616 L
s
.47711 .33616 m
.48695 .33303 L
s
.47873 .3059 m
.48695 .33303 L
s
.46798 .28021 m
.47873 .3059 L
s
.48695 .33303 m
.49214 .35992 L
s
.45815 .28341 m
.46798 .28021 L
s
.45815 .28341 m
.44552 .26083 L
s
.48227 .36302 m
.49214 .35992 L
s
.45538 .25759 m
.46798 .28021 L
s
.49108 .27783 m .50525 .29737 L .50042 .30026 L .966 .687 .456 r
F
.49108 .27783 m .49452 .27158 L .50525 .29737 L F
.50042 .30026 m .50525 .29737 L .51352 .32459 L F
.50761 .32395 m .51352 .32459 L .51879 .35156 L F
.50042 .30026 m .51352 .32459 L .50761 .32395 L F
0 g
.50525 .29737 m
.51352 .32459 L
s
.44552 .26083 m
.45538 .25759 L
s
.48015 .25808 m .49452 .27158 L .49108 .27783 L .966 .687 .456 r
F
.48015 .25808 m .48196 .24885 L .49452 .27158 L F
0 g
.49452 .27158 m
.50525 .29737 L
s
.46655 .36947 m .49395 .38489 L .48403 .38797 L .656 .751 .92 r
F
0 g
.48225 .4094 m
.48403 .38797 L
s
.48227 .36302 m
.4834 .37895 L
s
.51219 .34741 m .51879 .35156 L .52072 .37658 L .966 .687 .456 r
F
.50761 .32395 m .51879 .35156 L .51219 .34741 L F
0 g
.51352 .32459 m
.51879 .35156 L
s
.46655 .36947 m .49078 .36187 L .49395 .38489 L .656 .751 .92 r
F
0 g
.49223 .40633 m
.49395 .38489 L
s
.49214 .35992 m
.49395 .38489 L
s
.48403 .38797 m
.49395 .38489 L
s
.54027 .3161 m
.53197 .28878 L
s
.53197 .28878 m
.54196 .28557 L
s
.53197 .28878 m
.52124 .26289 L
s
.54562 .34314 m
.54027 .3161 L
s
.54027 .3161 m
.55028 .31292 L
s
.49556 .30318 m .50042 .30026 L .50761 .32395 L .966 .687 .456 r
F
.48761 .28413 m .50042 .30026 L .49556 .30318 L F
.48761 .28413 m .49108 .27783 L .50042 .30026 L F
.50166 .3233 m .50761 .32395 L .51219 .34741 L F
.49556 .30318 m .50761 .32395 L .50166 .3233 L F
0 g
.54196 .28557 m
.55028 .31292 L
s
.53124 .25963 m
.54196 .28557 L
s
.55028 .31292 m
.55566 .33999 L
s
.52124 .26289 m
.53124 .25963 L
s
.52124 .26289 m
.50874 .24004 L
s
.46833 .2423 m .48196 .24885 L .48015 .25808 L .966 .687 .456 r
F
.46833 .2423 m .46837 .23064 L .48196 .24885 L F
0 g
.48196 .24885 m
.49452 .27158 L
s
.47832 .26738 m .49108 .27783 L .48761 .28413 L .966 .687 .456 r
F
.47832 .26738 m .48015 .25808 L .49108 .27783 L F
.43179 .24278 m .45563 .26406 L .43145 .27199 L .544 .324 .532 r
F
.43179 .24278 m .44168 .23949 L .45563 .26406 L F
0 g
.44168 .23949 m
.45538 .25759 L
s
.43179 .24278 m
.44168 .23949 L
s
.41783 .23047 m
.43179 .24278 L
s
.54562 .34314 m
.55566 .33999 L
s
.51219 .34741 m .52072 .37658 L .51384 .36914 L .966 .687 .456 r
F
.50553 .34322 m .51219 .34741 L .51384 .36914 L F
.50166 .3233 m .51219 .34741 L .50553 .34322 L F
0 g
.51876 .23675 m
.53124 .25963 L
s
.51384 .36914 m .52072 .37658 L .51914 .39804 L .966 .687 .456 r
F
0 g
.51879 .35156 m
.52072 .37658 L
s
.42777 .22715 m
.44168 .23949 L
s
.47697 .42586 m
.48225 .4094 L
s
.48225 .4094 m
.49223 .40633 L
s
.49065 .30612 m .49556 .30318 L .50166 .3233 L .966 .687 .456 r
F
.48412 .29047 m .49556 .30318 L .49065 .30612 L F
.48412 .29047 m .48761 .28413 L .49556 .30318 L F
.49566 .32265 m .50166 .3233 L .50553 .34322 L F
.49065 .30612 m .50166 .3233 L .49566 .32265 L F
.46829 .25403 m .48015 .25808 L .47832 .26738 L F
.46829 .25403 m .46833 .2423 L .48015 .25808 L F
0 g
.50874 .24004 m
.51876 .23675 L
s
.49223 .40633 m
.48701 .42279 L
s
.47649 .27674 m .48761 .28413 L .48412 .29047 L .966 .687 .456 r
F
.47649 .27674 m .47832 .26738 L .48761 .28413 L F
.4488 .35068 m .49078 .36187 L .46655 .36947 L .656 .751 .92 r
F
0 g
.46655 .36947 m
.48403 .38797 L
s
.50553 .34322 m .51384 .36914 L .50692 .36166 L .966 .687 .456 r
F
.51384 .36914 m .51914 .39804 L .51244 .38775 L F
.50692 .36166 m .51384 .36914 L .51244 .38775 L F
.49883 .33901 m .50553 .34322 L .50692 .36166 L F
.49566 .32265 m .50553 .34322 L .49883 .33901 L F
.51614 .35391 m .55776 .36508 L .54767 .36821 L .656 .751 .92 r
F
0 g
.54625 .3897 m
.54767 .36821 L
s
.54562 .34314 m
.54718 .36224 L
s
.45636 .23157 m .46837 .23064 L .46833 .2423 L .966 .687 .456 r
F
.45636 .23157 m .45458 .21819 L .46837 .23064 L F
0 g
.46837 .23064 m
.48196 .24885 L
s
.51614 .35391 m .54069 .34622 L .55776 .36508 L .656 .751 .92 r
F
0 g
.55639 .38658 m
.55776 .36508 L
s
.55566 .33999 m
.55776 .36508 L
s
.54767 .36821 m
.55776 .36508 L
s
.039 .916 .04 r
.44819 .3215 m
.47873 .31146 L
s
.46825 .26582 m .47832 .26738 L .47649 .27674 L .966 .687 .456 r
F
.46825 .26582 m .46829 .25403 L .47832 .26738 L F
0 g
.49065 .30612 m
.49566 .32265 L
s
.48412 .29047 m
.49065 .30612 L
s
.43145 .27199 m .46356 .29107 L .43111 .30159 L .544 .324 .532 r
F
.43145 .27199 m .45563 .26406 L .46356 .29107 L F
0 g
.43145 .27199 m
.43179 .24278 L
s
.44168 .23949 m
.45563 .26406 L
s
.41783 .23047 m
.42777 .22715 L
s
.41783 .23047 m
.40454 .22484 L
s
.51244 .38775 m .51914 .39804 L .5141 .4145 L .966 .687 .456 r
F
0 g
.51914 .39804 m
.52072 .37658 L
s
.4488 .35068 m .48129 .34038 L .49078 .36187 L .656 .751 .92 r
F
0 g
.49078 .36187 m
.49395 .38489 L
s
.49883 .33901 m .50692 .36166 L .49995 .35413 L .966 .687 .456 r
F
0 g
.49566 .32265 m
.49883 .33901 L
s
.50692 .36166 m .51244 .38775 L .5057 .37741 L .966 .687 .456 r
F
.49995 .35413 m .50692 .36166 L .5057 .37741 L F
0 g
.47649 .27674 m
.48412 .29047 L
s
.45814 .24499 m .46833 .2423 L .46829 .25403 L .966 .687 .456 r
F
.45814 .24499 m .45636 .23157 L .46833 .2423 L F
0 g
.41454 .22149 m
.42777 .22715 L
s
.49524 .22172 m .50544 .24772 L .48094 .25576 L .544 .324 .532 r
F
.49524 .22172 m .5053 .21838 L .50544 .24772 L F
0 g
.50538 .23548 m
.50874 .24004 L
s
.5053 .21838 m
.51876 .23675 L
s
.49524 .22172 m
.5053 .21838 L
s
.48159 .20917 m
.49524 .22172 L
s
.46848 .43616 m
.47697 .42586 L
s
.47697 .42586 m
.48701 .42279 L
s
.039 .916 .04 r
.47873 .31146 m
.49328 .30679 L
s
.51244 .38775 m .5141 .4145 L .50802 .40197 L .966 .687 .456 r
F
.5057 .37741 m .51244 .38775 L .50802 .40197 L F
0 g
.4917 .20579 m
.5053 .21838 L
s
.45993 .25846 m .46829 .25403 L .46825 .26582 L .966 .687 .456 r
F
0 g
.46825 .26582 m
.47649 .27674 L
s
.45993 .25846 m .45814 .24499 L .46829 .25403 L .966 .687 .456 r
F
0 g
.54138 .40616 m
.54625 .3897 L
s
.54625 .3897 m
.55639 .38658 L
s
.49995 .35413 m .5057 .37741 L .49893 .36702 L .966 .687 .456 r
F
0 g
.49883 .33901 m
.49995 .35413 L
s
.48701 .42279 m
.47858 .43307 L
s
.4905 .33746 m .54069 .34622 L .51614 .35391 L .656 .751 .92 r
F
0 g
.51614 .35391 m
.54767 .36821 L
s
.039 .916 .04 r
.49328 .30679 m
.52235 .2977 L
s
.5057 .37741 m .50802 .40197 L .50192 .3894 L .966 .687 .456 r
F
.49893 .36702 m .5057 .37741 L .50192 .3894 L F
.44504 .22667 m .45458 .21819 L .45636 .23157 L F
.44504 .22667 m .44151 .21244 L .45458 .21819 L F
0 g
.45458 .21819 m
.46837 .23064 L
s
.55639 .38658 m
.55159 .40304 L
s
.43076 .33158 m .48129 .34038 L .4488 .35068 L .656 .751 .92 r
F
.039 .916 .04 r
.45011 .33495 m
.48072 .32572 L
s
0 g
.4488 .35068 m
.46655 .36947 L
s
.039 .916 .04 r
.09295 .43973 m
.4479 .34973 L
s
.09295 .43973 m
.43935 .34067 L
s
.09295 .43973 m
.43949 .32645 L
s
.4479 .34973 m
.48138 .34054 L
s
.48072 .32572 m
.49133 .32234 L
s
.48094 .25576 m .50558 .27745 L .47277 .28809 L .544 .324 .532 r
F
.48094 .25576 m .50544 .24772 L .50558 .27745 L F
0 g
.48094 .25576 m
.49524 .22172 L
s
.5053 .21838 m
.50544 .24772 L
s
.43111 .30159 m .46609 .32027 L .43076 .33158 L .544 .324 .532 r
F
.039 .916 .04 r
.09295 .43973 m
.43109 .30308 L
s
.43111 .30159 m .46356 .29107 L .46609 .32027 L .544 .324 .532 r
F
0 g
.43111 .30159 m
.43145 .27199 L
s
.039 .916 .04 r
.46464 .30348 m
.47184 .30094 L
s
.46588 .31788 m
.47381 .31531 L
s
0 g
.45563 .26406 m
.46356 .29107 L
s
.039 .916 .04 r
.47184 .30094 m
.48243 .29751 L
s
.44856 .24092 m .45636 .23157 L .45814 .24499 L .966 .687 .456 r
F
.44856 .24092 m .44504 .22667 L .45636 .23157 L F
.039 .916 .04 r
.43109 .30308 m
.46353 .29086 L
s
.4905 .33746 m .52335 .32705 L .54069 .34622 L .656 .751 .92 r
F
0 g
.54069 .34622 m
.55776 .36508 L
s
.49893 .36702 m .50192 .3894 L .4958 .3768 L .966 .687 .456 r
F
0 g
.49893 .36702 m
.49995 .35413 L
s
.50802 .40197 m .5141 .4145 L .50586 .42476 L .966 .687 .456 r
F
0 g
.5141 .4145 m
.51914 .39804 L
s
.40454 .22484 m
.41454 .22149 L
s
.40454 .22484 m
.39283 .22642 L
s
.4521 .25519 m .45814 .24499 L .45993 .25846 L .966 .687 .456 r
F
0 g
.45993 .25846 m
.46825 .26582 L
s
.4521 .25519 m .44856 .24092 L .45814 .24499 L .966 .687 .456 r
F
0 g
.48159 .20917 m
.4917 .20579 L
s
.48159 .20917 m
.46868 .20333 L
s
.039 .916 .04 r
.44781 .364 m
.4807 .35587 L
s
.50802 .40197 m .50586 .42476 L .50083 .41078 L .966 .687 .456 r
F
.50192 .3894 m .50802 .40197 L .50083 .41078 L F
.039 .916 .04 r
.52235 .2977 m
.91899 .17548 L
s
0 0 0 r
2 Mabswid
.52235 .2977 Mdot
0 g
.5 Mabswid
.40289 .22304 m
.41454 .22149 L
s
.039 .916 .04 r
.48138 .34054 m
.49069 .3376 L
s
.43076 .33158 m .46609 .32027 L .48129 .34038 L .656 .751 .92 r
F
0 g
.48129 .34038 m
.49078 .36187 L
s
.039 .916 .04 r
.09295 .43973 m
.43092 .31731 L
s
0 g
.47885 .19992 m
.4917 .20579 L
s
.50192 .3894 m .50083 .41078 L .4958 .39679 L .966 .687 .456 r
F
.4958 .3768 m .50192 .3894 L .4958 .39679 L F
.039 .916 .04 r
.47381 .31531 m
.48042 .31319 L
s
0 g
.45726 .43946 m
.46848 .43616 L
s
.46848 .43616 m
.47858 .43307 L
s
.039 .916 .04 r
.42246 .29386 m
.45381 .28126 L
s
.47003 .31901 m .52335 .32705 L .4905 .33746 L .656 .751 .92 r
F
0 g
.4905 .33746 m
.51614 .35391 L
s
.039 .916 .04 r
.46353 .29086 m
.47281 .28783 L
s
0 g
.53332 .41639 m
.54138 .40616 L
s
.54138 .40616 m
.55159 .40304 L
s
.4958 .3768 m .4958 .39679 L .49076 .38278 L .966 .687 .456 r
F
0 g
.4958 .3768 m
.49893 .36702 L
s
.47858 .43307 m
.46743 .43635 L
s
.039 .916 .04 r
.44774 .37845 m
.47866 .37166 L
s
.47277 .28809 m .50573 .30758 L .47003 .31901 L .544 .324 .532 r
F
.039 .916 .04 r
.49157 .32226 m
.52243 .31189 L
s
.47277 .28809 m .50558 .27745 L .50573 .30758 L .544 .324 .532 r
F
0 g
.47277 .28809 m
.48094 .25576 L
s
.039 .916 .04 r
.50565 .2907 m
.51399 .28826 L
s
.50572 .30518 m
.51407 .30254 L
s
.47281 .28783 m
.50559 .27883 L
s
0 g
.50544 .24772 m
.50558 .27745 L
s
0 0 0 r
2 Mabswid
.52243 .31189 Mdot
0 g
.5 Mabswid
.55159 .40304 m
.54361 .41325 L
s
.039 .916 .04 r
.4807 .35587 m
.49137 .35254 L
s
.43513 .22806 m .44151 .21244 L .44504 .22667 L .966 .687 .456 r
F
.43513 .22806 m .43005 .21393 L .44151 .21244 L F
0 g
.44151 .21244 m
.45458 .21819 L
s
.039 .916 .04 r
.51399 .28826 m
.91936 .17567 L
s
0 0 0 r
2 Mabswid
.51399 .28826 Mdot
.43076 .33158 m .46329 .35158 L .4304 .36198 L .544 .324 .532 r
F
.039 .916 .04 r
.5 Mabswid
.09295 .43973 m
.43042 .36045 L
s
.09295 .43973 m
.43059 .34594 L
s
.43076 .33158 m .46609 .32027 L .46329 .35158 L .544 .324 .532 r
F
.039 .916 .04 r
.46357 .34845 m
.47375 .34572 L
s
.41243 .31219 m .46609 .32027 L .43076 .33158 L .656 .751 .92 r
F
.039 .916 .04 r
.46494 .33307 m
.47445 .33025 L
s
.09295 .43973 m
.43076 .33158 L
s
0 g
.43095 .31498 m
.43111 .30159 L
s
.039 .916 .04 r
.43561 .31568 m
.46547 .30527 L
s
.09295 .43973 m
.41311 .3275 L
s
.09295 .43973 m
.42211 .32242 L
s
.09295 .43973 m
.42229 .30813 L
s
.09295 .43973 m
.41356 .29888 L
s
.09295 .43973 m
.41373 .28459 L
s
.4402 .24218 m .44504 .22667 L .44856 .24092 L .966 .687 .456 r
F
.4402 .24218 m .43513 .22806 L .44504 .22667 L F
.039 .916 .04 r
.47445 .33025 m
.47974 .32857 L
s
.44528 .25628 m .44856 .24092 L .4521 .25519 L .966 .687 .456 r
F
0 g
.4521 .25519 m
.45993 .25846 L
s
.44528 .25628 m .4402 .24218 L .44856 .24092 L .966 .687 .456 r
F
.039 .916 .04 r
.46547 .30527 m
.47075 .30357 L
s
.41373 .28459 m
.44271 .27219 L
s
.45381 .28126 m
.46445 .27777 L
s
.47003 .31901 m .50573 .30758 L .52335 .32705 L .656 .751 .92 r
F
.039 .916 .04 r
.90733 .17901 m
.9191 .17494 L
s
.52243 .31189 m
.90733 .17901 L
s
0 g
.52335 .32705 m
.54069 .34622 L
s
.039 .916 .04 r
.49069 .3376 m
.52254 .32616 L
s
.50083 .41078 m .50586 .42476 L .49489 .42799 L .966 .687 .456 r
F
0 g
.50586 .42476 m
.5141 .4145 L
s
.039 .916 .04 r
.52254 .32616 m
.91913 .17461 L
s
0 0 0 r
2 Mabswid
.52254 .32616 Mdot
.50083 .41078 m .49489 .42799 L .49129 .41347 L .966 .687 .456 r
F
.4958 .39679 m .50083 .41078 L .49129 .41347 L F
.039 .916 .04 r
.5 Mabswid
.47866 .37166 m
.49341 .36709 L
s
0 0 0 r
2 Mabswid
.47866 .37166 Mdot
0 g
.5 Mabswid
.39283 .22642 m
.38354 .23527 L
s
.40289 .22304 m
.39283 .22642 L
s
.4958 .39679 m .49129 .41347 L .48771 .39898 L .966 .687 .456 r
F
.49076 .38278 m .4958 .39679 L .48771 .39898 L F
.039 .916 .04 r
.51407 .30254 m
.91939 .17519 L
s
0 0 0 r
2 Mabswid
.51407 .30254 Mdot
.039 .916 .04 r
.5 Mabswid
.46445 .27777 m
.49712 .2694 L
s
.43059 .34594 m
.46535 .33581 L
s
0 g
.46868 .20333 m
.47885 .19992 L
s
.46868 .20333 m
.4574 .20474 L
s
.49076 .38278 m .48771 .39898 L .48412 .38451 L .966 .687 .456 r
F
0 g
.49076 .38278 m
.4958 .3768 L
s
.039 .916 .04 r
.50559 .27883 m
.91955 .17584 L
s
0 0 0 r
2 Mabswid
.50559 .27883 Mdot
.42211 .32242 Mdot
.039 .916 .04 r
.5 Mabswid
.47375 .34572 m
.48039 .34363 L
s
0 g
.39367 .23188 m
.40289 .22304 L
s
.039 .916 .04 r
.49341 .36709 m
.52283 .35509 L
s
0 g
.46763 .20131 m
.47885 .19992 L
s
.41243 .31219 m .44529 .30156 L .46609 .32027 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.46609 .32027 Mdot
0 g
.5 Mabswid
.46609 .32027 m
.48129 .34038 L
s
.039 .916 .04 r
.42229 .30813 m
.45572 .29566 L
s
.09295 .43973 m
.41335 .31316 L
s
.43076 .33158 m
.46609 .32027 L
s
0 g
.46356 .29107 m
.46609 .32027 L
s
.039 .916 .04 r
.45572 .29566 m
.46235 .2935 L
s
.47003 .31901 m .50587 .33811 L .47262 .34863 L .544 .324 .532 r
F
.039 .916 .04 r
.49137 .35254 m
.52268 .34055 L
s
.47003 .31901 m .50573 .30758 L .50587 .33811 L .544 .324 .532 r
F
.039 .916 .04 r
.50579 .31974 m
.51416 .3169 L
s
.50586 .3344 m
.51426 .33136 L
s
.4546 .29854 m .50573 .30758 L .47003 .31901 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.47003 .31901 Mdot
.039 .916 .04 r
.5 Mabswid
.46609 .32027 m
.47003 .31901 L
s
0 g
.47158 .30154 m
.47277 .28809 L
s
.039 .916 .04 r
.47532 .30221 m
.50566 .29318 L
s
0 g
.44403 .43536 m
.45726 .43946 L
s
.45726 .43946 m
.46743 .43635 L
s
.039 .916 .04 r
.44271 .27219 m
.4574 .26734 L
s
0 0 0 r
2 Mabswid
.44271 .27219 Mdot
.039 .916 .04 r
.5 Mabswid
.52268 .34055 m
.90733 .17901 L
s
.90733 .17901 m
.91902 .1741 L
s
0 0 0 r
2 Mabswid
.52268 .34055 Mdot
0 g
.5 Mabswid
.52254 .41956 m
.53332 .41639 L
s
.53332 .41639 m
.54361 .41325 L
s
.039 .916 .04 r
.51416 .3169 m
.9194 .175 L
s
0 0 0 r
2 Mabswid
.51416 .3169 Mdot
.43042 .36045 Mdot
.43995 .26174 m .4402 .24218 L .44528 .25628 L .966 .687 .456 r
F
0 g
.5 Mabswid
.44528 .25628 m
.4521 .25519 L
s
.46743 .43635 m
.45427 .43223 L
s
.4304 .36198 m .45487 .38503 L .43005 .39277 L .544 .324 .532 r
F
.4304 .36198 m .46329 .35158 L .45487 .38503 L F
0 g
.4304 .36198 m
.43076 .33158 L
s
.039 .916 .04 r
.46005 .36445 m
.47168 .36165 L
s
.43042 .36045 m
.46325 .35182 L
s
0 g
.46329 .35158 m
.46609 .32027 L
s
0 0 0 r
2 Mabswid
.50566 .29318 Mdot
.039 .916 .04 r
.5 Mabswid
.47168 .36165 m
.48241 .35831 L
s
0 0 0 r
2 Mabswid
.47168 .36165 Mdot
.039 .916 .04 r
.5 Mabswid
.4219 .33679 m
.45553 .32618 L
s
0 0 0 r
2 Mabswid
.4219 .33679 Mdot
.43366 .24877 m .43513 .22806 L .4402 .24218 L .966 .687 .456 r
F
.43995 .26174 m .43366 .24877 L .4402 .24218 L F
0 g
.5 Mabswid
.54361 .41325 m
.53289 .4164 L
s
.039 .916 .04 r
.4574 .26734 m
.48858 .25995 L
s
.49712 .2694 m
.91977 .17626 L
s
0 0 0 r
2 Mabswid
.49712 .2694 Mdot
.42735 .23576 m .43005 .21393 L .43513 .22806 L .966 .687 .456 r
F
.43366 .24877 m .42735 .23576 L .43513 .22806 L F
0 0 0 r
.41335 .31316 Mdot
.42735 .23576 m .42101 .22272 L .43005 .21393 L .966 .687 .456 r
F
0 g
.5 Mabswid
.43005 .21393 m
.44151 .21244 L
s
.039 .916 .04 r
.46535 .33581 m
.47066 .33412 L
s
0 0 0 r
2 Mabswid
.46535 .33581 Mdot
.39381 .29247 m .44529 .30156 L .41243 .31219 L .656 .751 .92 r
F
.039 .916 .04 r
.5 Mabswid
.42211 .32242 m
.4563 .31065 L
s
0 g
.41243 .31219 m
.43076 .33158 L
s
.039 .916 .04 r
.41863 .29685 m
.44457 .28651 L
s
.48412 .38451 m .47817 .39574 L .47631 .38179 L .966 .687 .456 r
F
.48412 .38451 m .48771 .39898 L .47817 .39574 L F
0 g
.48412 .38451 m
.49076 .38278 L
s
.039 .916 .04 r
.52283 .35509 m
.90206 .18069 L
s
.90206 .18069 m
.91875 .17302 L
s
0 0 0 r
2 Mabswid
.52283 .35509 Mdot
.039 .916 .04 r
.5 Mabswid
.4563 .31065 m
.4616 .30894 L
s
0 0 0 r
2 Mabswid
.4563 .31065 Mdot
.039 .916 .04 r
.5 Mabswid
.47066 .33412 m
.5058 .32208 L
s
0 0 0 r
2 Mabswid
.47066 .33412 Mdot
.48771 .39898 m .48002 .40974 L .47817 .39574 L .966 .687 .456 r
F
.48771 .39898 m .49129 .41347 L .48002 .40974 L F
.039 .916 .04 r
.5 Mabswid
.44457 .28651 m
.45527 .28299 L
s
0 0 0 r
2 Mabswid
.44457 .28651 Mdot
.039 .916 .04 r
.5 Mabswid
.51426 .33136 m
.9127 .17729 L
s
.9127 .17729 m
.91934 .17472 L
s
0 0 0 r
2 Mabswid
.51426 .33136 Mdot
.4616 .30894 Mdot
.49129 .41347 m .48189 .42378 L .48002 .40974 L .966 .687 .456 r
F
.49129 .41347 m .49489 .42799 L .48189 .42378 L F
0 g
.5 Mabswid
.49489 .42799 m
.50586 .42476 L
s
.4546 .29854 m .48782 .2878 L .50573 .30758 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.50573 .30758 Mdot
.039 .916 .04 r
.5 Mabswid
.50573 .30758 m
.91948 .17512 L
s
.91449 .17671 m
.9195 .17529 L
s
.50566 .29318 m
.91449 .17671 L
s
.46235 .2935 m
.49719 .28378 L
s
0 g
.50573 .30758 m
.52335 .32705 L
s
.039 .916 .04 r
.47003 .31901 m
.50573 .30758 L
s
0 g
.50558 .27745 m
.50573 .30758 L
s
.039 .916 .04 r
.42168 .35128 m
.4534 .3422 L
s
0 0 0 r
2 Mabswid
.42168 .35128 Mdot
.039 .916 .04 r
.5 Mabswid
.49719 .28378 m
.91962 .17552 L
s
0 0 0 r
2 Mabswid
.49719 .28378 Mdot
.039 .916 .04 r
.5 Mabswid
.41311 .3275 m
.44431 .31689 L
s
0 0 0 r
2 Mabswid
.41311 .3275 Mdot
0 g
.5 Mabswid
.38354 .23527 m
.39367 .23188 L
s
.38354 .23527 m
.37739 .25094 L
s
0 0 0 r
2 Mabswid
.46325 .35182 Mdot
.039 .916 .04 r
.5 Mabswid
.48858 .25995 m
.92021 .17722 L
s
0 0 0 r
2 Mabswid
.48858 .25995 Mdot
0 g
.5 Mabswid
.4574 .20474 m
.44855 .21349 L
s
.46763 .20131 m
.4574 .20474 L
s
.43652 .27123 m .43366 .24877 L .43995 .26174 L .966 .687 .456 r
F
0 g
.43995 .26174 m
.44528 .25628 L
s
.039 .916 .04 r
.45553 .32618 m
.46221 .32405 L
s
0 0 0 r
2 Mabswid
.45553 .32618 Mdot
0 g
.5 Mabswid
.38759 .24754 m
.39367 .23188 L
s
.47262 .34863 m .50602 .36906 L .48087 .37691 L .544 .324 .532 r
F
.47262 .34863 m .50587 .33811 L .50602 .36906 L F
0 g
.47003 .31901 m
.47262 .34863 L
s
.039 .916 .04 r
.50593 .34922 m
.51437 .34595 L
s
.46325 .35182 m
.47266 .34887 L
s
0 g
.50573 .30758 m
.50587 .33811 L
s
.039 .916 .04 r
.47266 .34887 m
.50587 .3367 L
s
0 0 0 r
2 Mabswid
.47266 .34887 Mdot
.39381 .29247 m .41858 .28438 L .44529 .30156 L .656 .751 .92 r
F
0 g
.5 Mabswid
.44529 .30156 m
.46609 .32027 L
s
.039 .916 .04 r
.41335 .31316 m
.44511 .30142 L
s
0 0 0 r
2 Mabswid
.44511 .30142 Mdot
.039 .916 .04 r
.5 Mabswid
.51437 .34595 m
.91919 .17397 L
s
0 0 0 r
2 Mabswid
.51437 .34595 Mdot
0 g
.5 Mabswid
.45886 .21004 m
.46763 .20131 L
s
.039 .916 .04 r
.46221 .32405 m
.49727 .31269 L
s
0 0 0 r
2 Mabswid
.46221 .32405 Mdot
.47631 .38179 m .46782 .3872 L .46787 .37477 L .966 .687 .456 r
F
.47631 .38179 m .47817 .39574 L .46782 .3872 L F
0 g
.5 Mabswid
.47631 .38179 m
.48412 .38451 L
s
.42941 .26033 m .42735 .23576 L .43366 .24877 L .966 .687 .456 r
F
.43652 .27123 m .42941 .26033 L .43366 .24877 L F
.039 .916 .04 r
.5058 .32208 m
.91946 .17495 L
s
0 0 0 r
2 Mabswid
.5058 .32208 Mdot
0 g
.5 Mabswid
.44403 .43536 m
.45427 .43223 L
s
.43005 .39277 m .43997 .42082 L .42968 .42399 L .544 .324 .532 r
F
0 g
.42968 .42399 m
.44403 .43536 L
s
.43005 .39277 m .45487 .38503 L .43997 .42082 L .544 .324 .532 r
F
0 g
.43005 .39277 m
.4304 .36198 L
s
.42968 .42399 m
.43005 .39277 L
s
.45487 .38503 m
.46329 .35158 L
s
.44452 .2759 m .48782 .2878 L .4546 .29854 L .656 .751 .92 r
F
.039 .916 .04 r
.44511 .30142 m
.4545 .29837 L
s
.46302 .28098 m
.48863 .27432 L
s
0 g
.4546 .29854 m
.47003 .31901 L
s
.039 .916 .04 r
.4616 .30894 m
.49723 .2982 L
s
.4545 .29837 m
.48865 .28871 L
s
0 0 0 r
2 Mabswid
.4545 .29837 Mdot
.039 .916 .04 r
.5 Mabswid
.49723 .2982 m
.91956 .17524 L
s
0 0 0 r
2 Mabswid
.49723 .2982 Mdot
0 g
.5 Mabswid
.50972 .41527 m
.52254 .41956 L
s
.52254 .41956 m
.53289 .4164 L
s
.039 .916 .04 r
.41284 .34195 m
.44215 .33284 L
s
0 0 0 r
2 Mabswid
.41284 .34195 Mdot
.42228 .24938 m .42101 .22272 L .42735 .23576 L .966 .687 .456 r
F
.42941 .26033 m .42228 .24938 L .42735 .23576 L F
.039 .916 .04 r
.5 Mabswid
.48863 .27432 m
.91994 .17614 L
s
0 0 0 r
2 Mabswid
.48863 .27432 Mdot
0 g
.5 Mabswid
.43997 .42082 m
.45427 .43223 L
s
.47817 .39574 m .46778 .3997 L .46782 .3872 L .966 .687 .456 r
F
.47817 .39574 m .48002 .40974 L .46778 .3997 L F
.039 .916 .04 r
.4534 .3422 m
.46419 .33879 L
s
0 0 0 r
2 Mabswid
.4534 .3422 Mdot
0 g
.5 Mabswid
.53289 .4164 m
.52013 .41208 L
s
.039 .916 .04 r
.44431 .31689 m
.45508 .31342 L
s
0 0 0 r
2 Mabswid
.44431 .31689 Mdot
.42228 .24938 m .41511 .23837 L .42101 .22272 L .966 .687 .456 r
F
0 g
.5 Mabswid
.42101 .22272 m
.43005 .21393 L
s
.43523 .28415 m .42941 .26033 L .43652 .27123 L .966 .687 .456 r
F
0 g
.43652 .27123 m
.43995 .26174 L
s
.37488 .27244 m .41858 .28438 L .39381 .29247 L .656 .751 .92 r
F
0 g
.39381 .29247 m
.41243 .31219 L
s
.039 .916 .04 r
.50587 .3367 m
.91941 .17439 L
s
0 0 0 r
2 Mabswid
.50587 .3367 Mdot
.48002 .40974 m .46774 .41227 L .46778 .3997 L .966 .687 .456 r
F
.48002 .40974 m .48189 .42378 L .46774 .41227 L F
0 g
.5 Mabswid
.48189 .42378 m
.49489 .42799 L
s
.039 .916 .04 r
.46419 .33879 m
.4973 .3273 L
s
0 0 0 r
2 Mabswid
.46419 .33879 Mdot
0 g
.5 Mabswid
.43997 .42082 m
.45487 .38503 L
s
.039 .916 .04 r
.49727 .31269 m
.9127 .17729 L
s
.9127 .17729 m
.91957 .17505 L
s
0 0 0 r
2 Mabswid
.49727 .31269 Mdot
.46787 .37477 m .4574 .37389 L .45937 .36388 L .966 .687 .456 r
F
.46787 .37477 m .46782 .3872 L .4574 .37389 L F
0 g
.5 Mabswid
.46787 .37477 m
.47631 .38179 L
s
.039 .916 .04 r
.45508 .31342 m
.48866 .30318 L
s
0 0 0 r
2 Mabswid
.45508 .31342 Mdot
.039 .916 .04 r
.5 Mabswid
.48865 .28871 m
.91983 .17562 L
s
0 0 0 r
2 Mabswid
.48865 .28871 Mdot
.44452 .2759 m .46963 .26769 L .48782 .2878 L .656 .751 .92 r
F
0 g
.5 Mabswid
.48782 .2878 m
.50573 .30758 L
s
.38759 .24754 m
.37739 .25094 L
s
.42781 .27612 m .42228 .24938 L .42941 .26033 L .966 .687 .456 r
F
.43523 .28415 m .42781 .27612 L .42941 .26033 L F
.039 .916 .04 r
.44215 .33284 m
.45704 .32809 L
s
.37488 .27244 m .38514 .26905 L .41858 .28438 L .656 .751 .92 r
F
0 g
.38514 .26905 m
.41858 .28438 L
s
.37488 .27244 m
.37739 .25094 L
s
.41858 .28438 m
.44529 .30156 L
s
.37488 .27244 m
.39381 .29247 L
s
.44855 .21349 m
.45886 .21004 L
s
.44855 .21349 m
.44282 .22914 L
s
.43622 .29961 m .42781 .27612 L .43523 .28415 L .966 .687 .456 r
F
0 g
.43523 .28415 m
.43652 .27123 L
s
.38514 .26905 m
.38759 .24754 L
s
.46782 .3872 m .45542 .38398 L .4574 .37389 L .966 .687 .456 r
F
.46782 .3872 m .46778 .3997 L .45542 .38398 L F
.48087 .37691 m .50617 .40043 L .49571 .40366 L .544 .324 .532 r
F
.48087 .37691 m .50602 .36906 L .50617 .40043 L F
0 g
.47262 .34863 m
.48087 .37691 L
s
.48087 .37691 m
.49571 .40366 L
s
.50587 .33811 m
.50602 .36906 L
s
.42968 .42399 m
.43997 .42082 L
s
.41523 .40601 m
.42968 .42399 L
s
.039 .916 .04 r
.4973 .3273 m
.9196 .17457 L
s
0 0 0 r
2 Mabswid
.4973 .3273 Mdot
.45937 .36388 m .44765 .35671 L .45143 .34985 L .966 .687 .456 r
F
.45937 .36388 m .4574 .37389 L .44765 .35671 L F
0 g
.5 Mabswid
.45937 .36388 m
.46787 .37477 L
s
.42034 .26804 m .41511 .23837 L .42228 .24938 L .966 .687 .456 r
F
.42781 .27612 m .42034 .26804 L .42228 .24938 L F
.039 .916 .04 r
.45704 .32809 m
.48864 .31774 L
s
0 0 0 r
2 Mabswid
.45704 .32809 Mdot
0 g
.5 Mabswid
.4532 .22568 m
.45886 .21004 L
s
.039 .916 .04 r
.48866 .30318 m
.91986 .17529 L
s
0 0 0 r
2 Mabswid
.48866 .30318 Mdot
0 g
.5 Mabswid
.42556 .4028 m
.43997 .42082 L
s
.49571 .40366 m
.50972 .41527 L
s
.50972 .41527 m
.52013 .41208 L
s
.43622 .29961 m .42899 .29506 L .42781 .27612 L .966 .687 .456 r
F
.43942 .31652 m .42899 .29506 L .43622 .29961 L F
0 g
.43523 .28415 m
.43622 .29961 L
s
.46778 .3997 m .45343 .39414 L .45542 .38398 L .966 .687 .456 r
F
.46778 .3997 m .46774 .41227 L .45343 .39414 L F
0 g
.46774 .41227 m
.48189 .42378 L
s
.45143 .34985 m .43928 .33687 L .44461 .33368 L .966 .687 .456 r
F
.45143 .34985 m .44765 .35671 L .43928 .33687 L F
0 g
.45143 .34985 m
.45937 .36388 L
s
.42899 .29506 m .42034 .26804 L .42781 .27612 L .966 .687 .456 r
F
.4407 .2507 m .46963 .26769 L .44452 .2759 L .656 .751 .92 r
F
0 g
.44452 .2759 m
.4546 .29854 L
s
.42034 .26804 m .41282 .25991 L .41511 .23837 L .966 .687 .456 r
F
0 g
.41511 .23837 m
.42101 .22272 L
s
.50617 .40043 m
.52013 .41208 L
s
.50602 .36906 m
.50617 .40043 L
s
.43942 .31652 m .43291 .31581 L .42899 .29506 L .966 .687 .456 r
F
.44461 .33368 m .43291 .31581 L .43942 .31652 L F
0 g
.43622 .29961 m
.43942 .31652 L
s
.44461 .33368 m .43928 .33687 L .43291 .31581 L .966 .687 .456 r
F
0 g
.44461 .33368 m
.45143 .34985 L
s
.43942 .31652 m
.44461 .33368 L
s
.4574 .37389 m .44384 .36363 L .44765 .35671 L .966 .687 .456 r
F
.4574 .37389 m .45542 .38398 L .44384 .36363 L F
.039 .916 .04 r
.48864 .31774 m
.91997 .17476 L
s
0 0 0 r
2 Mabswid
.48864 .31774 Mdot
0 g
.5 Mabswid
.37488 .27244 m
.38514 .26905 L
s
.37488 .27244 m
.37627 .29832 L
s
.38514 .26905 m
.38657 .29496 L
s
.40173 .38264 m
.41523 .40601 L
s
.41523 .40601 m
.42556 .4028 L
s
.42899 .29506 m .42171 .29048 L .42034 .26804 L .966 .687 .456 r
F
.43291 .31581 m .42171 .29048 L .42899 .29506 L F
.42171 .29048 m .41282 .25991 L .42034 .26804 L F
.4407 .2507 m .45113 .24725 L .46963 .26769 L .656 .751 .92 r
F
0 g
.45113 .24725 m
.46963 .26769 L
s
.46963 .26769 m
.48782 .2878 L
s
.4407 .2507 m
.44452 .2759 L
s
.44765 .35671 m .4339 .34009 L .43928 .33687 L .966 .687 .456 r
F
.44765 .35671 m .44384 .36363 L .4339 .34009 L F
0 g
.4407 .2507 m
.44282 .22914 L
s
.4532 .22568 m
.44282 .22914 L
s
.42556 .4028 m
.41208 .37938 L
s
.45542 .38398 m .44 .3706 L .44384 .36363 L .966 .687 .456 r
F
.45542 .38398 m .45343 .39414 L .44 .3706 L F
0 g
.45343 .39414 m
.46774 .41227 L
s
.43291 .31581 m .42634 .3151 L .42171 .29048 L .966 .687 .456 r
F
.43928 .33687 m .42634 .3151 L .43291 .31581 L F
.43928 .33687 m .4339 .34009 L .42634 .3151 L F
0 g
.45113 .24725 m
.4532 .22568 L
s
.37627 .29832 m
.38657 .29496 L
s
.37627 .29832 m
.38149 .32672 L
s
.49571 .40366 m
.50617 .40043 L
s
.4815 .38541 m
.49571 .40366 L
s
.42171 .29048 m .41437 .28587 L .41282 .25991 L .966 .687 .456 r
F
0 g
.41282 .25991 m
.41511 .23837 L
s
.39019 .35554 m
.40173 .38264 L
s
.40173 .38264 m
.41208 .37938 L
s
.42634 .3151 m .41437 .28587 L .42171 .29048 L .966 .687 .456 r
F
0 g
.39182 .32339 m
.38657 .29496 L
s
.49201 .38214 m
.50617 .40043 L
s
.44384 .36363 m .42848 .34334 L .4339 .34009 L .966 .687 .456 r
F
.44384 .36363 m .44 .3706 L .42848 .34334 L F
0 g
.44 .3706 m
.45343 .39414 L
s
.41208 .37938 m
.40054 .35225 L
s
.38149 .32672 m
.39182 .32339 L
s
.38149 .32672 m
.39019 .35554 L
s
.39019 .35554 m
.40054 .35225 L
s
.4339 .34009 m .41972 .31438 L .42634 .3151 L .966 .687 .456 r
F
.42634 .3151 m .41972 .31438 L .41437 .28587 L F
0 g
.41282 .25991 m
.41437 .28587 L
s
.4339 .34009 m .42848 .34334 L .41972 .31438 L .966 .687 .456 r
F
0 g
.40054 .35225 m
.39182 .32339 L
s
.4407 .2507 m
.45113 .24725 L
s
.4407 .2507 m
.44239 .27671 L
s
.41437 .28587 m
.41972 .31438 L
s
.45113 .24725 m
.45287 .27328 L
s
.46814 .36175 m
.4815 .38541 L
s
.4815 .38541 m
.49201 .38214 L
s
.42848 .34334 m
.44 .3706 L
s
.49201 .38214 m
.47867 .35843 L
s
.41972 .31438 m
.42848 .34334 L
s
.44239 .27671 m
.45287 .27328 L
s
.44239 .27671 m
.44782 .3053 L
s
.45662 .33437 m
.46814 .36175 L
s
.46814 .36175 m
.47867 .35843 L
s
.45834 .30191 m
.45287 .27328 L
s
.47867 .35843 m
.46716 .33102 L
s
.44782 .3053 m
.45834 .30191 L
s
.44782 .3053 m
.45662 .33437 L
s
.45662 .33437 m
.46716 .33102 L
s
.46716 .33102 m
.45834 .30191 L
s
0 0 0 r
2 Mabswid
.91997 .17476 Mdot
.91986 .17529 Mdot
.9196 .17457 Mdot
.91983 .17562 Mdot
.91941 .17439 Mdot
.91994 .17614 Mdot
.91957 .17505 Mdot
.91919 .17397 Mdot
.92021 .17722 Mdot
.91956 .17524 Mdot
.91946 .17495 Mdot
.91962 .17552 Mdot
.91948 .17512 Mdot
.91934 .17472 Mdot
.9195 .17529 Mdot
.9194 .175 Mdot
.91875 .17302 Mdot
.91977 .17626 Mdot
.91939 .17519 Mdot
.91902 .1741 Mdot
.91955 .17584 Mdot
.91913 .17461 Mdot
.91936 .17567 Mdot
.9191 .17494 Mdot
.91899 .17548 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[135]:=",
  ImageSize->{280, 166},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000YR000`400?l00000o`00003ooooooolI
ooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolI
ooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolI
ooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolI
ooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolI
ooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolI
ooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolI
ooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolI
ooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolI
ooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolI
ooooo`00oooooolIooooo`00oooooolIooooo`00ooooool2o`0001Oooooo003nooooo`03o`WZ2_l0
003o000001Oooooo003jooooo`Go2NX:0_l0000Gooooo`00m_ooool8o`WZ2Q[ooooo003booooo`So
2NX:7_ooool00>kooooo2_l9jPXPooooo`00jOooool<o`WZ2R?ooooo003Soooooa3o2NX:9Oooool0
08Cooooo0ol0001Goooooa?o2NX:9oooool007oooooo1Ol00003ooooo`;o0000D?oooolFo`WZ2RWo
oooo001oooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o0000B_oooolIo`WZ2R_ooooo
001nooooo`?o00001Oooool2o`0000;ooooo00?o0000ooooooooool0@OoooolLo`WZ2Rkooooo001g
ooooo`So000000?oooooo`000?ooool01_ooool01?l0003oooooooooool0000moooooaoo2NX:<?oo
ool007Kooooo00?o0000ooN_M?og[g@01?og[g@3o`0000Wooooo00Co0000ooooool0003o0000=ooo
ool5o`WZ2P03ooooool9jP[o2NX:01[o2NX:<_ooool007;ooooo1?l00006ooN_M004o`000?og[gCo
mjmdo`0000[ooooo00?o0000oh]BR?l00000<_ooool5o`WZ2P03ooooool9jP[o2NX:01go2NX:=?oo
ool006gooooo1Ol00003ooooo`03o`000?og[gComjmd00Comjmd0ol000000oog[gCo0000ooooo`08
ooooo`04o`000?n;DXSo0000o`0002cooooo1Ol9jPX00ooooooo2NX:o`WZ2P0Po`WZ2SKooooo001]
ooooo`;o00000oooool3o`0000Komjmd0_l000001Oog[gCo0000ooN_M?og[gCo000000Oooooo00Ko
0000oh]BR?n;DXSo0000ooooool0000Uooooo`Ko2NX:0_oooolSo`WZ2SWooooo001/ooooo`;o0000
1_ooool00ol0003omjmdooN_M004ooN_M004o`000?og[gComjmdo`0000?omjmd00?o0000oooooooo
ool01?ooool01?l0003oRe:8oh]BR?l00002ooooo`03o`000?oooooooooo01gooooo1Ol9jPX3oooo
obKo2NX:>oooool006_ooooo00?o0000ooooool000001_ooool00ol0003omjmdooN_M004ooN_M004
o`000?og[gComjmdo`0000?omjmd00?o0000ooooooooool01?ooool00ol0003oRe:8oh]BR002o`00
0003ooooool0003o000001Wooooo1Ol9jPX3ooooobWo2NX:?Oooool006_ooooo00?o0000ooooool0
00001Oooool00ol0003omjmdooN_M005ooN_M003o`000?og[gCo000000Gomjmd00?o0000oooooooo
ool00_ooool00ol0003oRe:8oh]BR002oh]BR0;o000000?oooooo`000?ooool04oooool5o`WZ2P?o
oooo4Ol9jPX00ooooooo2NX:o`WZ2P0Ho`WZ2Soooooo001Zooooo`03o`000?oooooo000000Kooooo
00?o0000ooN_M?og[g@01Oog[g@00ol0003omjmdo`000006ooN_M005o`000?ooooooooooooooool0
00001?n;DXP01Ol0003ooooooooooooooooo000000gooooo1_l9jPX4ooooo`Co2NX:00?oooooo`WZ
2_l9jPX00_l9jPX00ooooooo2NX:o`WZ2P0Ro`WZ2T7ooooo001Zooooo`?o00001_ooool00ol0003o
mjmdooN_M005ooN_M0?o00001oog[g@00ol0003oooooo`000005oh]BR0;o00000_ooool00ol0003o
ooooooooo`06ooooo`Go2NX:1Oooool:o`WZ2P03ooooool9jP[o2NX:00Ko2NX:00?oooooo`WZ2_l9
jPX06_l9jPY4ooooo`00JOooool2o`000003ooooool0003ooooo00Gooooo00?o0000ooN_M?og[g@0
1Oog[g@01?l0003oYl3[o`000?l00007ooN_M0;o00001On;DXP2o`0000?ooooo00?o0000oooooooo
ool01Ol9jPX5ooooo`Go2NX:00?oooooo`WZ2_l9jPX00_l9jPX2ooooo`So2NX:00?oooooo`WZ2_l9
jPX07?l9jPY6ooooo`00JOooool01?l0003oooooooooool00006ooooo`03o`000?og[gComjmd00Go
mjmd00Go0000ojO0jol0003oYl3[o`000006ooN_M0;o00001On;DXP00ol0003oooooo`000005o`WZ
2PKooooo1?l9jPX00ooooooo2NX:o`WZ2P03o`WZ2P;ooooo1?l9jPX01?oooooo2NX:o`WZ2_l9jPX2
oooooaco2NX:00?oooooo`WZ2_l9jPX0B?ooool006Wooooo00Co0000oooooooooooo00001_ooool0
0ol0003omjmdooN_M005ooN_M003o`000?nW`>_o000000;oYl3[00?o0000ooN_M?og[g@00oog[g@3
o`0000;oRe:81Ol9jPX01?l0003oooooooooool00002ooooo`Go2NX:00?oooooo`WZ2_l9jPX00_l9
jPX3ooooo`Co2NX:00?oooooo`WZ2_l9jPX00_l9jPX00ooooooo2NX:o`WZ2P0Lo`WZ2P03ooooool9
jP[o2NX:04[ooooo001Yooooo`03o`000?oooooo000000Oooooo00?o0000ooN_M?og[g@01?og[g@2
o`000003ojO0jol0003oYl3[00;oYl3[00?o0000ooN_M?og[g@00_og[g@00ol9jP[o0000o`000002
o`WZ2P;oRe:800Co0000oooooooooooo00001Ol9jPX2ooooo`Co2NX:0oooool9o`WZ2P03ooooool9
jP[o2NX:027o2NX:C?ooool006Sooooo00Co0000oooooooooooo00001oooool00ol0003omjmdooN_
M004ooN_M0?o000000?oYl3[o`000?nW`>/00_nW`>/01?l0003o2NX:o`WZ2_l9jPX6oh]BR0Go2NX:
0_l00005o`WZ2P?ooooo2Ol9jPX2oooooa_o2NX:00?oooooo`WZ2_l9jPX00_l9jPX00ooooooo2NX:
o`WZ2P1?ooooo`00J?ooool00ol0003oooooo`000002o`0000Kooooo00?o0000ooN_M?og[g@00oog
[g@01_l0003oRe:8o`000?l0003oYl3[o`0000CoYl3[00?o0000ooN_M?l000000on;DXP01_l9jP[o
0000o`000?n;DXSo0000ooooo`Co2NX:0_ooool00ol0003oooooo`WZ2P04o`WZ2P04ooooool9jP[o
2NX:o`WZ2P;ooooo1Ol9jPX00ooooooo2NX:o`WZ2P0Jo`WZ2P03ooooool9jP[o2NX:057ooooo001X
ooooo`;o000000?oYl3[o`000?nW`>/00_l00004ooooo`03o`000?og[gComjmd00?omjmd00Ko0000
o`WZ2_l0003o0000ojO0jol00004ojO0j`04o`000?og[gCo0000o`WZ2P;o000000?oRe:8o`WZ2_l9
jPX00ol9jPX3ooooo`03o`000?l9jP[o2NX:00?o2NX:00?oooooo`WZ2_l9jPX00_l9jPX2ooooo`[o
2NX:00?oooooo`WZ2_l9jPX04?l9jPX00ooooooo2NX:o`WZ2P03o`WZ2P03ooooool9jP[o2NX:05?o
oooo001Xooooo`04o`000?nW`>_oYl3[o`0000?oYl3[0_l00002ooooo`03o`000?og[gComjmd00?o
mjmd00?o0000oh]BR?l000000ol00005ojO0j`03o`000?l9jP[o2NX:00;o000000Ko2NX:oh]BR?n;
DXSoRe:8o`000?ooool5o`WZ2P03ooooool9jP[o2NX:00;o2NX:0_ooool;o`WZ2P03ooooool9jP[o
2NX:017o2NX:00?oooooo`WZ2_l9jPX00_l9jPX01?oooooo2NX:o`WZ2_l9jPYEooooo`00J?ooool2
o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ooooool000001Oog[g@01_l0003oRe:8o`000?l0
003oYl3[o`0000KoYl3[00?o0000oh]BR?n;DXP00on;DXP5o`WZ2P03ooooool9jP[o2NX:00;o2NX:
00?oooooo`000?ooool01Ol9jPX00ooooooo2NX:o`WZ2P0<o`WZ2P03ooooool9jP[o2NX:00So2NX:
00?oooooo`WZ2_l9jPX00ol9jPX00ooooooo2NX:o`WZ2P1Hooooo`00J?ooool01?l0003oooooo`00
0?l00006ojO0j`;o00001Oog[g@01_l0003oRe:8o`000?l0003oYl3[o`0000;oYl3[00?o2NX:ojO0
jonW`>/00_nW`>/01?l0003oRe:8o`WZ2_l9jPX4o`0000?o2NX:0_ooool00ol0003o2NX:o`WZ2P0O
o`WZ2P03ooooool9jP[o2NX:00?o2NX:00?oooooo`WZ2_l9jPX0F_ooool006Sooooo00Co0000oooo
oooooooo00001onW`>/00ol0003omjmdooN_M003ooN_M003o`000?l9jP[o000000?o00002?nW`>/2
o`000003oh]BR?l9jP[o2NX:00;o2NX:0_l000000ooooooo2NX:o`WZ2P03o`WZ2P03o`000?l9jP[o
2NX:00?o2NX:00?oooooo`WZ2_l9jPX03Ol9jPX00ooooooo2NX:o`WZ2P03o`WZ2P03ooooool9jP[o
2NX:00?o2NX:0_ooool2o`WZ2Ucooooo001Yooooo`04o`000?oooooo0000o`0000KoYl3[00?o0000
ooN_M?og[g@00oog[g@00ol0003o2NX:o`000003o`0000OoYl3[00Co2NX:o`000?l0003o2NX:0on;
DXP2o`0000Co2NX:00?oooooo`WZ2_l9jPX00ol9jPX00ooooooo2NX:o`WZ2P0Co`WZ2P;ooooo1Ol9
jPX2ooooo`;o2NX:G_ooool006Wooooo00Co0000ooooool0003ooooo0_l00004ojO0j`03o`000?og
[gComjmd00?omjmd00?o0000oh]BR?n;DXP00_l000000onW`>_o0000ojO0j`02ojO0j`?o2NX:0onW
`>/00ol0003oRe:8oh]BR003o`WZ2P03ooooool9jP[o2NX:00Co2NX:00?oooooo`WZ2_l9jPX05?l9
jPX2ooooo`Co2NX:0_ooool3o`WZ2V3ooooo001Yooooo`?o00000_l9jPX00ooooooo0000ojO0j`03
ojO0j`03o`000?og[gComjmd00;omjmd1?l000000ol9jP[o0000o`000003o`WZ2PGoYl3[0_l9jPX3
o`0000Co2NX:0_l000000ooooooo2NX:o`WZ2P08o`WZ2P03ooooool9jP[o2NX:00?o2NX:00Cooooo
o`WZ2_l9jP[ooooo0_l9jPX2ooooo`Go2NX:0_ooool2o`WZ2V?ooooo001Yooooo`03o`000?l9jP[o
000000?ooooo00?o2NX:o`000?nW`>/00_nW`>/00ol0003omjmdooN_M002ooN_M005o`000?nW`>_o
0000o`000?l9jPX00_l00005ojO0j`;o2NX:0_l000001?nW`>_o2NX:o`WZ2_l9jPX3o`000003oooo
ool9jP[o2NX:00So2NX:00?oooooo`WZ2_l9jPX00ol9jPX00ooooooo2NX:o`WZ2P04o`WZ2P;ooooo
1Ol9jPX2ooooo`;o2NX:IOooool006Sooooo00Go2NX:o`000?oooooo0000ooooo`02o`WZ2P03oooo
ool9jP[o000000;oYl3[00?o0000ooN_M?og[g@00_og[g@00ol0003o2NX:o`000004o`0000;oYl3[
0ol9jPX2ojO0j`;o000000?o2NX:ojO0jonW`>/00ol00009o`WZ2P03o`000?l9jP[o2NX:00Co2NX:
00?oooooo`WZ2_l9jPX00ol9jPX3ooooo`Co2NX:0oooool2o`WZ2VOooooo001Vooooo`;o2NX:00Go
ooooo`000?oooooo2NX:o`000003o`WZ2P;ooooo00?o0000ojO0jol000001?og[g@01Ol0003oYl3[
ojO0jol0003oYl3[00;o00000_l9jPX2ojO0j`?o2NX:1?nW`>/2o`WZ2P03o`000?l9jP[o2NX:00Go
2NX:00?o0000o`WZ2_l9jPX01?l9jPX00ooooooo2NX:o`WZ2P04o`WZ2P;ooooo1Ol9jPX3ooooo`;o
2NX:JOooool006?ooooo0ol9jPX3ooooo`04o`000?l9jP[o2NX:o`0000Cooooo00Go2NX:o`000?l0
003o2NX:o`000004ooN_M003o`000?nW`>_oYl3[00Co00000ol9jPX4ojO0j`;o2NX:0_l00006o`WZ
2P03o`000?l9jP[o2NX:00Co2NX:00?o0000o`WZ2_l9jPX01?l9jPX3ooooo`Go2NX:0_ooool3o`WZ
2V_ooooo001Qooooo`;o2NX:1?ooool3o`WZ2P03o`000?oooooo000000;ooooo0ol9jPX01?l0003o
2NX:ojO0jol00004ooN_M0Oo000000CoRe:8o`000?nW`>_oYl3[0_l9jPX2o`0000Co2NX:0ol00006
o`WZ2P;o00000_l9jPX01?oooooo2NX:o`WZ2_l9jPX2ooooo`Go2NX:0oooool2o`WZ2Vkooooo001O
ooooo`;o2NX:0oooool5o`WZ2P05ooooool0003oooooo`WZ2_l000001?l9jPX01?oooooo2NX:o`00
0?l00004ooN_M0Co00000_nW`>/4o`0000?o2NX:0_l000001Ol9jP[oRe:8oh]BR?n;DXSo000000Ko
2NX:00?oooooo`WZ2_l9jPX01?l9jPX3ooooo`;o2NX:00?oooooo`WZ2_l9jPX00oooool2o`WZ2W3o
oooo001Mooooo`;o2NX:0oooool4o`WZ2PCooooo00Go0000o`WZ2_l0003o0000o`WZ2P02ooooo`;o
2NX:00?oooooo`WZ2_l000001?og[g@01_l0003oYl3[ojO0jonW`>_o0000ojO0j`;o00001Ol9jPX4
oh]BR003o`WZ2_l0003o000000?o2NX:00?oooooo`WZ2_l9jPX01?l9jPX01?oooooo0000oooooooo
ool5o`WZ2P?ooooo0_l9jPYbooooo`00Foooool2o`WZ2P?ooooo1?l9jPX3ooooo`?o2NX:0_l00000
0ol9jP[o0000o`WZ2P03o`WZ2P;o000000?oooooo`WZ2_l000001?og[g@00ol0003oYl3[o`WZ2P04
o`0000;o2NX:1?n;DXP2o`WZ2P;o00000_l9jPX2ojO0j`03o`WZ2_l0003o000000?o2NX:00?ooooo
o`000?ooool01Ol9jPX4ooooo`;o2NX:M?ooool005Wooooo0_l9jPX3ooooo`Co2NX:0oooool5o`WZ
2P04o`000?l9jP[o2NX:o`0000?o2NX:00Koooooo`000?l0003o2NX:ooooool00004ooN_M003o`00
0?l9jP[o2NX:00Ko000000KoRe:8o`WZ2_l9jP[o2NX:oh]BR?l9jPX2o`000004oh]BR?l0003o0000
o`0000?o2NX:1?ooool2o`WZ2P03ooooool9jP[o2NX:00?ooooo0ol9jPYfooooo`00Eoooool2o`WZ
2P;ooooo1Ol9jPX3ooooo`Go2NX:00?oooooo`WZ2_l000000ol9jPX01Ol0003o2NX:o`WZ2_l9jP[o
oooo00?o2NX:00?o0000ooN_M?og[g@00oog[g@01Ol0003oRe:8oh]BR?l0003oRe:800?o000000?o
2NX:oh]BR?l9jPX00_l9jPX4oh]BR006o`000?l9jP[o2NX:o`WZ2_nW`>_o00000_ooool5o`WZ2P03
o`000?oooooooooo00;o2NX:NOooool005Gooooo0_l9jPX2ooooo`Co2NX:0oooool5o`WZ2P03oooo
ool9jP[o2NX:00?o2NX:00Go0000o`WZ2_l9jP[o0000ooooo`05o`WZ2P;o00001Oog[g@00ol0003o
Re:8oh]BR004o`0000?o2NX:1_n;DXP2o`0000CoYl3[1Ol9jPX01?l0003oooooooooool00002o`WZ
2W_ooooo001Cooooo`;o2NX:0_ooool4o`WZ2P?ooooo1?l9jPX00ooooooo2NX:o`WZ2P06o`WZ2P04
o`000?oooooo2NX:o`0000?o2NX:0_l00003o`WZ2P03o`000?og[gComjmd00;omjmd00Go0000o`WZ
2_l0003o0000o`WZ2P03o`0000GoRe:80ol9jPX2o`0000;oYl3[00?o2NX:o`000?l000000_l9jPX3
ooooo`03o`000?l9jP[o2NX:07gooooo001Aooooo`;o2NX:0_ooool4o`WZ2P;ooooo1Ol9jPX00ooo
oooo2NX:o`WZ2P06o`WZ2P03ooooool9jP[o000000;o2NX:00Co0000o`WZ2_oooooo2NX:0_l00003
o`WZ2P03o`000?og[gComjmd00?omjmd1Ol000000ol9jP[o0000oh]BR002oh]BR0;o2NX:1?n;DXP0
1?l0003o2NX:o`000?l00002o`WZ2P;oYl3[00Ko0000ooooool9jP[o2NX:ooooool0001mooooo`00
Coooool2o`WZ2P;ooooo0ol9jPX3ooooo`Co2NX:00?oooooo`WZ2_l9jPX01_l9jPX00ooooooo2NX:
o`WZ2P02o`WZ2P04o`000?l9jP[oooooo`0000Ko2NX:00?oooooo`WZ2_l000001Oog[g@00ol0003o
Re:8oh]BR002o`000003o`WZ2_l0003o000000;o2NX:1_n;DXP01?l0003o2NX:o`000?l00003ojO0
j`?o2NX:00Coooooo`000?oooooo0000OOooool004gooooo0_l9jPX00ooooooo2NX:o`WZ2P02o`WZ
2P;ooooo3Ol9jPX00ooooooo2NX:o`WZ2P04o`WZ2P03ooooool9jP[o000000;o2NX:00Co0000o`WZ
2_oooooooooo0_l9jPX2o`000003ooooool0003omjmd00?omjmd00?o0000oh]BR?n;DXP00_l00000
0ol9jP[o0000o`000008oh]BR0;o00000onW`>/2o`WZ2P?oYl3[0_l000000ooooooo0000ooooo`1l
ooooo`00Boooool2o`WZ2P03ooooool9jP[o2NX:00;o2NX:0_ooool4o`WZ2P03ooooool9jP[o2NX:
00Go2NX:00?oooooo`WZ2_l9jPX02Ol9jPX4o`0000?o2NX:0_ooool2o`000003o`WZ2_l0003omjmd
00?omjmd00?o0000o`WZ2_l9jPX00_l000000onW`>_o0000o`000008oh]BR004o`000?og[gCo0000
o`WZ2P;o00001OnW`>/01?l0003oooooooooool0001looooo`00BOooool2o`WZ2P03ooooool9jP[o
2NX:00;o2NX:00?oooooo`WZ2_l9jPX02_l9jPX00ooooooo2NX:o`WZ2P0<o`WZ2P04o`000?l9jP[o
2NX:o`0000?ooooo1?l9jPX2o`0000Gomjmd00Co0000oh]BR?n;DXSo00000_nW`>/2o`0000OoRe:8
00?o0000o`WZ2_l9jPX00ol00006ojO0j`03o`000?oooooo000007cooooo0016ooooo`?o2NX:00Co
ooooo`WZ2_l9jP[o2NX:0_oooolHo`WZ2P03ooooool9jP[o2NX:00;o2NX:00Goooooo`000?oooooo
2NX:o`000003o`WZ2P;ooooo00Co2NX:o`000?l0003o00001Oog[g@2o`000003o`WZ2_l0003o0000
00;o00001on;DXP01?l0003omjmdooN_M?l00002ooooo`?o00001?nW`>/2o`0007cooooo0014oooo
o`;o2NX:00?oooooo`WZ2_l9jPX00_l9jPX00ooooooo2NX:o`WZ2P0?o`WZ2P03ooooool9jP[o2NX:
00So2NX:0oooool2o`WZ2P05o`000?l9jP[o2NX:o`000?ooool01?l9jPX2ooooo`;o00001_og[g@0
0ol0003o2NX:o`000004o`0000KoRe:800Go0000ooN_M?og[gComjmdo`000004ooooo`;o00000_nW
`>/2o`0007cooooo0012ooooo`;o2NX:00?oooooo`WZ2_l9jPX00_l9jPX00ooooooo2NX:o`WZ2P0I
o`WZ2P;ooooo1Ol9jPX00ooooooo2NX:o`000002o`WZ2P04o`000?ooooooooooooooo`?o2NX:0_l0
0006ooN_M005o`000?oooooo0000o`000?nW`>/00_l00006oh]BR005o`000?og[gComjmdooN_M?l0
00001_ooool2o`000003ooooool0003ooooo07_ooooo0010ooooo`;o2NX:00Goooooo`WZ2_l9jP[o
2NX:ooooo`0Jo`WZ2P;ooooo1Ol9jPX00ooooooo2NX:o`WZ2P02o`WZ2P03ooooool0003ooooo00;o
2NX:00?o0000o`WZ2_l9jPX00ol9jPX00ol0003oRe:8o`000006ooN_M007o`000?oooooo0000o`WZ
2_l0003oRe:8o`000005oh]BR005o`000?og[gComjmdooN_M?l000001_ooool01?l0003ooooooooo
ool0001looooo`00?_ooool2o`WZ2P05ooooool9jP[o2NX:o`WZ2_ooool06?l9jPX2ooooo`Go2NX:
00?oooooo`WZ2_l9jPX00_l9jPX3ooooo`?o2NX:00Co0000o`WZ2_l9jP[o00001Oooool00ol0003o
Re:8o`000007ooN_M007o`000?oooooo0000ojO0jol0003oRe:8o`000004oh]BR005o`000?og[gCo
mjmdooN_M?l000001_ooool01?l0003oooooooooool0001looooo`00??ooool2o`WZ2P05ooooool9
jP[o2NX:o`WZ2_ooool05ol9jPX00ooooooo2NX:o`WZ2P08o`WZ2P;ooooo1ol9jPX01?oooooo0000
ooooooooool2o`0000Cooooo00Co0000oh]BR?n;DXSo00001oog[g@01_l0003oooooo`000?l0003o
Re:8o`0000CoRe:800Go0000ooN_M?og[gComjmdo`000006ooooo`04o`000?ooooooooooo`0007co
oooo000joooooaco2NX:00?oooooo`WZ2_l9jPX01ol9jPX2ooooo`Oo2NX:1oooool2o`000003oooo
ool0003o2NX:00?o2NX:00Go0000oh]BR?n;DXSoRe:8o`000007ooN_M0Ko00000on;DXP01Ol0003o
mjmdooN_M?og[gCo000000Kooooo00Co0000oooooooooooo0000O?ooool003Sooooo1Ol9jPX00ooo
oooo2NX:o`WZ2P0Bo`WZ2P03ooooool9jP[o2NX:00Oo2NX:0_ooool6o`WZ2P[ooooo0_l9jPX01Ol0
003o2NX:o`WZ2_oooooo000000?ooooo00Go0000oh]BR?n;DXSoRe:8o`000009ooN_M0;o000000?o
Re:8o`000?n;DXP00_n;DXP01Ol0003omjmdooN_M?og[gCo000000Kooooo00Co0000ooooool0003o
0000O?ooool003Kooooo8_l9jPX00ooooooo2NX:o`WZ2P05o`WZ2PSooooo1_l9jPX3ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000oh]BR?n;DXP00_n;DXP00ol0003omjmdooN_M006ooN_M005
o`000?og[gCo0000oh]BR?l000000_n;DXP01?l0003omjmdooN_M?l00007ooooo`;o000000?ooooo
o`000?ooool0Noooool003Cooooo9ol9jPX7ooooo`Ko2NX:2Oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000oh]BR?n;DXP00_n;DXP2o`0000Somjmd0_l00002oh]BR003o`000?n;DXSo
000000;omjmd00?o0000ooooooooool01Oooool00ol0003oooooo`00001mooooo`00<_oooolEo`WZ
2P03ooooool9jP[o2NX:00Go2NX:00?oooooo`WZ2_l9jPX01?l9jPX6ooooo`Ko2NX:4?ooool01?l0
003oooooooooool00002ooooo`03o`000?n;DXSoRe:800;oRe:80_l00009ooN_M0;o00000_n;DXP2
o`0000;omjmd00?o0000ooooooooool01Oooool00ol0003oooooo`00001mooooo`00<?oooolQo`WZ
2PKooooo1Ol9jPXFooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oh]BR?n;DXP00_n;DXP0
0ol0003oooooo`000009ooN_M003o`000?n;DXSoRe:800?o000000?omjmdo`000?ooool01Oooool0
1?l0003oooooooooool0001mooooo`00;_oooolNo`WZ2PGooooo1_l9jPXLooooo`Co000000?ooooo
o`000?n;DXP00_n;DXP01Ol0003ooooooooooooooooo000000Womjmd0_l00003ooN_M0;o00001_oo
ool3o`0007kooooo000/oooooaco2NX:0oooool6o`WZ2R;ooooo00Ko0000oooooooooooo0000oooo
ool00003oh]BR003o`000?oooooooooo00;ooooo00?o0000ooN_M?og[g@02?og[g@00ol0003omjmd
ooN_M002o`0000Gooooo0ol0001oooooo`00:_oooolIo`WZ2P;ooooo1_l9jPXYooooo`04o`000?oo
ooooooooo`0000?oRe:800?o0000ooooooooool01?ooool2o`0000Womjmd00?o0000ooN_M?l00000
1?l000001?oooooo0000o`000?l00020ooooo`009ooooolGo`WZ2P03ooooool9jP[o2NX:00Co2NX:
<?ooool01?l0003oooooo`000?l00002oh]BR003o`000?oooooooooo00Kooooo00?o0000ooN_M?og
[g@01oog[g@3o`0000;ooooo0ol00022ooooo`009OoooolDo`WZ2P03ooooool9jP[o2NX:00?o2NX:
=oooool2o`000004oh]BR?l0003oRe:8o`0000Wooooo00?o0000ooN_M?og[g@01oog[g@01?l0003o
ooooo`000?l00025ooooo`008ooooolGo`WZ2Sgooooo1Ol00009ooooo`?o00001_og[g@00ol0003o
ooooooooo`27ooooo`008OoooolCo`WZ2TCooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooo000000;o00000_og[g@2o`0008[ooooo000Oooooo`oo2NX:Boooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool000000oooool2o`0008cooooo000Mooooo`_o2NX:
D_ooool00ol0003oooooooooo`04o`0000;ooooo0ol0002Booooo`006oooool8o`WZ2USooooo0ol0
0003ooooo`?o0000U?ooool001[ooooo0ol9jPYQooooo`?o0000Uoooool00?oooooo6Oooool00?oo
oooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oo
oooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oo
oooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oo
oooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oo
oooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oo
oooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oo
oooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oo
oooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oooooo6Oooool00?oo
oooo6Oooool00001\
\>"],
  ImageRangeCache->{{{0, 279}, {165, 0}} -> {0.0299278, 0.195248, 0.00348169, \
0.00348169}},
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
    "AOG5.5"}]
}, Open  ]],

Cell["\<\
sys = 
\t{WedgeOfRays[10, NumberOfRays -> 5], 
\tMove[PlanoConvexLens[{f1,100}, 50, 9, CurvatureDirection -> Back],90.5],
\tMove[ApertureStop[50,30],100],
\tMove[PlanoConvexLens[{f2,100}, 50, 9], 100.5],
    Boundary[208, GraphicDesign -> Off]};\
\>", "Input",
  CellLabel->"In[136]:=",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[sys,PlotType->TopView];", "Input",
  CellLabel->"In[137]:=",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .26519 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00457875 0.144409 0.00457875 [
[.50458 .00631 -7.53125 -6 ]
[.50458 .00631 7.53125 6 ]
[.45879 .00631 -7.53125 -6 ]
[.45879 .00631 7.53125 6 ]
[.48168 .00631 -5.59375 -6 ]
[.48168 .00631 5.59375 6 ]
[ 0 0 0 0 ]
[ 1 .26519 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.43819 .02994 m
.44999 .02994 L
.4668 .0681 L
.43819 .0681 L
.43819 .02994 L
F
.43819 .0681 m
.4668 .0681 L
.47631 .10625 L
.43819 .10625 L
.43819 .0681 L
F
.43819 .10625 m
.47631 .10625 L
.4794 .14441 L
.43819 .14441 L
.43819 .10625 L
F
.43819 .14441 m
.4794 .14441 L
.47631 .18257 L
.43819 .18257 L
.43819 .14441 L
F
.43819 .18257 m
.47631 .18257 L
.4668 .22072 L
.43819 .22072 L
.43819 .18257 L
F
.43819 .22072 m
.4668 .22072 L
.44999 .25888 L
.43819 .25888 L
.43819 .22072 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.43819 .02994 m
.43819 .0681 L
.43819 .10625 L
.43819 .14441 L
.43819 .18257 L
.43819 .22072 L
.43819 .25888 L
.44999 .25888 L
.4668 .22072 L
.47631 .18257 L
.4794 .14441 L
.47631 .10625 L
.4668 .0681 L
.44999 .02994 L
.43819 .02994 L
s
.5 g
.43819 .14441 m
.44999 .14441 L
.4668 .14441 L
.43819 .14441 L
.43819 .14441 L
F
.43819 .14441 m
.4668 .14441 L
.47631 .14441 L
.43819 .14441 L
.43819 .14441 L
F
.43819 .14441 m
.47631 .14441 L
.4794 .14441 L
.43819 .14441 L
.43819 .14441 L
F
.43819 .14441 m
.4794 .14441 L
.47631 .14441 L
.43819 .14441 L
.43819 .14441 L
F
.43819 .14441 m
.47631 .14441 L
.4668 .14441 L
.43819 .14441 L
.43819 .14441 L
F
.43819 .14441 m
.4668 .14441 L
.44999 .14441 L
.43819 .14441 L
.43819 .14441 L
F
0 g
.43819 .14441 m
.43819 .14441 L
.43819 .14441 L
.43819 .14441 L
.43819 .14441 L
.43819 .14441 L
.43819 .14441 L
.44999 .14441 L
.4668 .14441 L
.47631 .14441 L
.4794 .14441 L
.47631 .14441 L
.4668 .14441 L
.44999 .14441 L
.43819 .14441 L
s
.43819 .25888 m
.44999 .25888 L
.44999 .25498 L
.43819 .25498 L
.43819 .25888 L
s
.43819 .25498 m
.44999 .25498 L
.44999 .24354 L
.43819 .24354 L
.43819 .25498 L
s
.43819 .24354 m
.44999 .24354 L
.44999 .22535 L
.43819 .22535 L
.43819 .24354 L
s
.43819 .22535 m
.44999 .22535 L
.44999 .20164 L
.43819 .20164 L
.43819 .22535 L
s
.43819 .20164 m
.44999 .20164 L
.44999 .17404 L
.43819 .17404 L
.43819 .20164 L
s
.43819 .17404 m
.44999 .17404 L
.44999 .14441 L
.43819 .14441 L
.43819 .17404 L
s
.43819 .14441 m
.44999 .14441 L
.44999 .11478 L
.43819 .11478 L
.43819 .14441 L
s
.43819 .11478 m
.44999 .11478 L
.44999 .08717 L
.43819 .08717 L
.43819 .11478 L
s
.43819 .08717 m
.44999 .08717 L
.44999 .06347 L
.43819 .06347 L
.43819 .08717 L
s
.43819 .06347 m
.44999 .06347 L
.44999 .04528 L
.43819 .04528 L
.43819 .06347 L
s
.43819 .04528 m
.44999 .04528 L
.44999 .03384 L
.43819 .03384 L
.43819 .04528 L
s
.43819 .03384 m
.44999 .03384 L
.44999 .02994 L
.43819 .02994 L
.43819 .03384 L
s
.43819 .02994 m
.44999 .02994 L
.44999 .03384 L
.43819 .03384 L
.43819 .02994 L
s
.43819 .03384 m
.44999 .03384 L
.44999 .04528 L
.43819 .04528 L
.43819 .03384 L
s
.43819 .04528 m
.44999 .04528 L
.44999 .06347 L
.43819 .06347 L
.43819 .04528 L
s
.43819 .06347 m
.44999 .06347 L
.44999 .08717 L
.43819 .08717 L
.43819 .06347 L
s
.43819 .08717 m
.44999 .08717 L
.44999 .11478 L
.43819 .11478 L
.43819 .08717 L
s
.43819 .11478 m
.44999 .11478 L
.44999 .14441 L
.43819 .14441 L
.43819 .11478 L
s
.43819 .14441 m
.44999 .14441 L
.44999 .17404 L
.43819 .17404 L
.43819 .14441 L
s
.43819 .17404 m
.44999 .17404 L
.44999 .20164 L
.43819 .20164 L
.43819 .17404 L
s
.43819 .20164 m
.44999 .20164 L
.44999 .22535 L
.43819 .22535 L
.43819 .20164 L
s
.43819 .22535 m
.44999 .22535 L
.44999 .24354 L
.43819 .24354 L
.43819 .22535 L
s
.43819 .24354 m
.44999 .24354 L
.44999 .25498 L
.43819 .25498 L
.43819 .24354 L
s
.43819 .25498 m
.44999 .25498 L
.44999 .25888 L
.43819 .25888 L
.43819 .25498 L
s
.5 g
.48168 .21309 m
.48168 .22835 L
.48168 .22549 L
.48168 .21075 L
.48168 .21309 L
F
.48168 .21075 m
.48168 .22549 L
.48168 .21711 L
.48168 .20389 L
.48168 .21075 L
F
.48168 .20389 m
.48168 .21711 L
.48168 .20377 L
.48168 .19297 L
.48168 .20389 L
F
.48168 .19297 m
.48168 .20377 L
.48168 .18638 L
.48168 .17875 L
.48168 .19297 L
F
.48168 .17875 m
.48168 .18638 L
.48168 .16614 L
.48168 .16219 L
.48168 .17875 L
F
.48168 .16219 m
.48168 .16614 L
.48168 .14441 L
.48168 .14441 L
.48168 .16219 L
F
.48168 .14441 m
.48168 .14441 L
.48168 .12268 L
.48168 .12663 L
.48168 .14441 L
F
.48168 .12663 m
.48168 .12268 L
.48168 .10244 L
.48168 .11007 L
.48168 .12663 L
F
.48168 .11007 m
.48168 .10244 L
.48168 .08505 L
.48168 .09584 L
.48168 .11007 L
F
.48168 .09584 m
.48168 .08505 L
.48168 .07171 L
.48168 .08493 L
.48168 .09584 L
F
.48168 .08493 m
.48168 .07171 L
.48168 .06333 L
.48168 .07807 L
.48168 .08493 L
F
.48168 .07807 m
.48168 .06333 L
.48168 .06047 L
.48168 .07573 L
.48168 .07807 L
F
.48168 .07573 m
.48168 .06047 L
.48168 .06333 L
.48168 .07807 L
.48168 .07573 L
F
.48168 .07807 m
.48168 .06333 L
.48168 .07171 L
.48168 .08493 L
.48168 .07807 L
F
.48168 .08493 m
.48168 .07171 L
.48168 .08505 L
.48168 .09584 L
.48168 .08493 L
F
.48168 .09584 m
.48168 .08505 L
.48168 .10244 L
.48168 .11007 L
.48168 .09584 L
F
.48168 .11007 m
.48168 .10244 L
.48168 .12268 L
.48168 .12663 L
.48168 .11007 L
F
.48168 .12663 m
.48168 .12268 L
.48168 .14441 L
.48168 .14441 L
.48168 .12663 L
F
.48168 .14441 m
.48168 .14441 L
.48168 .16614 L
.48168 .16219 L
.48168 .14441 L
F
.48168 .16219 m
.48168 .16614 L
.48168 .18638 L
.48168 .17875 L
.48168 .16219 L
F
.48168 .17875 m
.48168 .18638 L
.48168 .20377 L
.48168 .19297 L
.48168 .17875 L
F
.48168 .19297 m
.48168 .20377 L
.48168 .21711 L
.48168 .20389 L
.48168 .19297 L
F
.48168 .20389 m
.48168 .21711 L
.48168 .22549 L
.48168 .21075 L
.48168 .20389 L
F
.48168 .21075 m
.48168 .22549 L
.48168 .22835 L
.48168 .21309 L
.48168 .21075 L
F
.48168 .22835 m
.48168 .24362 L
.48168 .24024 L
.48168 .22549 L
.48168 .22835 L
F
.48168 .22549 m
.48168 .24024 L
.48168 .23032 L
.48168 .21711 L
.48168 .22549 L
F
.48168 .21711 m
.48168 .23032 L
.48168 .21456 L
.48168 .20377 L
.48168 .21711 L
F
.48168 .20377 m
.48168 .21456 L
.48168 .19401 L
.48168 .18638 L
.48168 .20377 L
F
.48168 .18638 m
.48168 .19401 L
.48168 .17009 L
.48168 .16614 L
.48168 .18638 L
F
.48168 .16614 m
.48168 .17009 L
.48168 .14441 L
.48168 .14441 L
.48168 .16614 L
F
.48168 .14441 m
.48168 .14441 L
.48168 .11873 L
.48168 .12268 L
.48168 .14441 L
F
.48168 .12268 m
.48168 .11873 L
.48168 .09481 L
.48168 .10244 L
.48168 .12268 L
F
.48168 .10244 m
.48168 .09481 L
.48168 .07426 L
.48168 .08505 L
.48168 .10244 L
F
.48168 .08505 m
.48168 .07426 L
.48168 .05849 L
.48168 .07171 L
.48168 .08505 L
F
.48168 .07171 m
.48168 .05849 L
.48168 .04858 L
.48168 .06333 L
.48168 .07171 L
F
.48168 .06333 m
.48168 .04858 L
.48168 .0452 L
.48168 .06047 L
.48168 .06333 L
F
.48168 .06047 m
.48168 .0452 L
.48168 .04858 L
.48168 .06333 L
.48168 .06047 L
F
.48168 .06333 m
.48168 .04858 L
.48168 .05849 L
.48168 .07171 L
.48168 .06333 L
F
.48168 .07171 m
.48168 .05849 L
.48168 .07426 L
.48168 .08505 L
.48168 .07171 L
F
.48168 .08505 m
.48168 .07426 L
.48168 .09481 L
.48168 .10244 L
.48168 .08505 L
F
.48168 .10244 m
.48168 .09481 L
.48168 .11873 L
.48168 .12268 L
.48168 .10244 L
F
.48168 .12268 m
.48168 .11873 L
.48168 .14441 L
.48168 .14441 L
.48168 .12268 L
F
.48168 .14441 m
.48168 .14441 L
.48168 .17009 L
.48168 .16614 L
.48168 .14441 L
F
.48168 .16614 m
.48168 .17009 L
.48168 .19401 L
.48168 .18638 L
.48168 .16614 L
F
.48168 .18638 m
.48168 .19401 L
.48168 .21456 L
.48168 .20377 L
.48168 .18638 L
F
.48168 .20377 m
.48168 .21456 L
.48168 .23032 L
.48168 .21711 L
.48168 .20377 L
F
.48168 .21711 m
.48168 .23032 L
.48168 .24024 L
.48168 .22549 L
.48168 .21711 L
F
.48168 .22549 m
.48168 .24024 L
.48168 .24362 L
.48168 .22835 L
.48168 .22549 L
F
.48168 .24362 m
.48168 .25888 L
.48168 .25498 L
.48168 .24024 L
.48168 .24362 L
F
.48168 .24024 m
.48168 .25498 L
.48168 .24354 L
.48168 .23032 L
.48168 .24024 L
F
.48168 .23032 m
.48168 .24354 L
.48168 .22535 L
.48168 .21456 L
.48168 .23032 L
F
.48168 .21456 m
.48168 .22535 L
.48168 .20164 L
.48168 .19401 L
.48168 .21456 L
F
.48168 .19401 m
.48168 .20164 L
.48168 .17404 L
.48168 .17009 L
.48168 .19401 L
F
.48168 .17009 m
.48168 .17404 L
.48168 .14441 L
.48168 .14441 L
.48168 .17009 L
F
.48168 .14441 m
.48168 .14441 L
.48168 .11478 L
.48168 .11873 L
.48168 .14441 L
F
.48168 .11873 m
.48168 .11478 L
.48168 .08717 L
.48168 .09481 L
.48168 .11873 L
F
.48168 .09481 m
.48168 .08717 L
.48168 .06347 L
.48168 .07426 L
.48168 .09481 L
F
.48168 .07426 m
.48168 .06347 L
.48168 .04528 L
.48168 .05849 L
.48168 .07426 L
F
.48168 .05849 m
.48168 .04528 L
.48168 .03384 L
.48168 .04858 L
.48168 .05849 L
F
.48168 .04858 m
.48168 .03384 L
.48168 .02994 L
.48168 .0452 L
.48168 .04858 L
F
.48168 .0452 m
.48168 .02994 L
.48168 .03384 L
.48168 .04858 L
.48168 .0452 L
F
.48168 .04858 m
.48168 .03384 L
.48168 .04528 L
.48168 .05849 L
.48168 .04858 L
F
.48168 .05849 m
.48168 .04528 L
.48168 .06347 L
.48168 .07426 L
.48168 .05849 L
F
.48168 .07426 m
.48168 .06347 L
.48168 .08717 L
.48168 .09481 L
.48168 .07426 L
F
.48168 .09481 m
.48168 .08717 L
.48168 .11478 L
.48168 .11873 L
.48168 .09481 L
F
.48168 .11873 m
.48168 .11478 L
.48168 .14441 L
.48168 .14441 L
.48168 .11873 L
F
.48168 .14441 m
.48168 .14441 L
.48168 .17404 L
.48168 .17009 L
.48168 .14441 L
F
.48168 .17009 m
.48168 .17404 L
.48168 .20164 L
.48168 .19401 L
.48168 .17009 L
F
.48168 .19401 m
.48168 .20164 L
.48168 .22535 L
.48168 .21456 L
.48168 .19401 L
F
.48168 .21456 m
.48168 .22535 L
.48168 .24354 L
.48168 .23032 L
.48168 .21456 L
F
.48168 .23032 m
.48168 .24354 L
.48168 .25498 L
.48168 .24024 L
.48168 .23032 L
F
.48168 .24024 m
.48168 .25498 L
.48168 .25888 L
.48168 .24362 L
.48168 .24024 L
F
0 g
.48168 .21309 m
.48168 .21075 L
.48168 .20389 L
.48168 .19297 L
.48168 .17875 L
.48168 .16219 L
.48168 .14441 L
.48168 .12663 L
.48168 .11007 L
.48168 .09584 L
.48168 .08493 L
.48168 .07807 L
.48168 .07573 L
.48168 .07807 L
.48168 .08493 L
.48168 .09584 L
.48168 .11007 L
.48168 .12663 L
.48168 .14441 L
.48168 .16219 L
.48168 .17875 L
.48168 .19297 L
.48168 .20389 L
.48168 .21075 L
.48168 .21309 L
s
.48168 .25888 m
.48168 .25498 L
.48168 .24354 L
.48168 .22535 L
.48168 .20164 L
.48168 .17404 L
.48168 .14441 L
.48168 .11478 L
.48168 .08717 L
.48168 .06347 L
.48168 .04528 L
.48168 .03384 L
.48168 .02994 L
.48168 .03384 L
.48168 .04528 L
.48168 .06347 L
.48168 .08717 L
.48168 .11478 L
.48168 .14441 L
.48168 .17404 L
.48168 .20164 L
.48168 .22535 L
.48168 .24354 L
.48168 .25498 L
.48168 .25888 L
s
.5 g
.51338 .02994 m
.52518 .02994 L
.52518 .0681 L
.49657 .0681 L
.51338 .02994 L
F
.49657 .0681 m
.52518 .0681 L
.52518 .10625 L
.48706 .10625 L
.49657 .0681 L
F
.48706 .10625 m
.52518 .10625 L
.52518 .14441 L
.48397 .14441 L
.48706 .10625 L
F
.48397 .14441 m
.52518 .14441 L
.52518 .18257 L
.48706 .18257 L
.48397 .14441 L
F
.48706 .18257 m
.52518 .18257 L
.52518 .22072 L
.49657 .22072 L
.48706 .18257 L
F
.49657 .22072 m
.52518 .22072 L
.52518 .25888 L
.51338 .25888 L
.49657 .22072 L
F
0 g
.51338 .02994 m
.49657 .0681 L
.48706 .10625 L
.48397 .14441 L
.48706 .18257 L
.49657 .22072 L
.51338 .25888 L
.52518 .25888 L
.52518 .22072 L
.52518 .18257 L
.52518 .14441 L
.52518 .10625 L
.52518 .0681 L
.52518 .02994 L
.51338 .02994 L
s
.5 g
.51338 .14441 m
.52518 .14441 L
.52518 .14441 L
.49657 .14441 L
.51338 .14441 L
F
.49657 .14441 m
.52518 .14441 L
.52518 .14441 L
.48706 .14441 L
.49657 .14441 L
F
.48706 .14441 m
.52518 .14441 L
.52518 .14441 L
.48397 .14441 L
.48706 .14441 L
F
.48397 .14441 m
.52518 .14441 L
.52518 .14441 L
.48706 .14441 L
.48397 .14441 L
F
.48706 .14441 m
.52518 .14441 L
.52518 .14441 L
.49657 .14441 L
.48706 .14441 L
F
.49657 .14441 m
.52518 .14441 L
.52518 .14441 L
.51338 .14441 L
.49657 .14441 L
F
0 g
.51338 .14441 m
.49657 .14441 L
.48706 .14441 L
.48397 .14441 L
.48706 .14441 L
.49657 .14441 L
.51338 .14441 L
.52518 .14441 L
.52518 .14441 L
.52518 .14441 L
.52518 .14441 L
.52518 .14441 L
.52518 .14441 L
.52518 .14441 L
.51338 .14441 L
s
.51338 .25888 m
.52518 .25888 L
.52518 .25498 L
.51338 .25498 L
.51338 .25888 L
s
.51338 .25498 m
.52518 .25498 L
.52518 .24354 L
.51338 .24354 L
.51338 .25498 L
s
.51338 .24354 m
.52518 .24354 L
.52518 .22535 L
.51338 .22535 L
.51338 .24354 L
s
.51338 .22535 m
.52518 .22535 L
.52518 .20164 L
.51338 .20164 L
.51338 .22535 L
s
.51338 .20164 m
.52518 .20164 L
.52518 .17404 L
.51338 .17404 L
.51338 .20164 L
s
.51338 .17404 m
.52518 .17404 L
.52518 .14441 L
.51338 .14441 L
.51338 .17404 L
s
.51338 .14441 m
.52518 .14441 L
.52518 .11478 L
.51338 .11478 L
.51338 .14441 L
s
.51338 .11478 m
.52518 .11478 L
.52518 .08717 L
.51338 .08717 L
.51338 .11478 L
s
.51338 .08717 m
.52518 .08717 L
.52518 .06347 L
.51338 .06347 L
.51338 .08717 L
s
.51338 .06347 m
.52518 .06347 L
.52518 .04528 L
.51338 .04528 L
.51338 .06347 L
s
.51338 .04528 m
.52518 .04528 L
.52518 .03384 L
.51338 .03384 L
.51338 .04528 L
s
.51338 .03384 m
.52518 .03384 L
.52518 .02994 L
.51338 .02994 L
.51338 .03384 L
s
.51338 .02994 m
.52518 .02994 L
.52518 .03384 L
.51338 .03384 L
.51338 .02994 L
s
.51338 .03384 m
.52518 .03384 L
.52518 .04528 L
.51338 .04528 L
.51338 .03384 L
s
.51338 .04528 m
.52518 .04528 L
.52518 .06347 L
.51338 .06347 L
.51338 .04528 L
s
.51338 .06347 m
.52518 .06347 L
.52518 .08717 L
.51338 .08717 L
.51338 .06347 L
s
.51338 .08717 m
.52518 .08717 L
.52518 .11478 L
.51338 .11478 L
.51338 .08717 L
s
.51338 .11478 m
.52518 .11478 L
.52518 .14441 L
.51338 .14441 L
.51338 .11478 L
s
.51338 .14441 m
.52518 .14441 L
.52518 .17404 L
.51338 .17404 L
.51338 .14441 L
s
.51338 .17404 m
.52518 .17404 L
.52518 .20164 L
.51338 .20164 L
.51338 .17404 L
s
.51338 .20164 m
.52518 .20164 L
.52518 .22535 L
.51338 .22535 L
.51338 .20164 L
s
.51338 .22535 m
.52518 .22535 L
.52518 .24354 L
.51338 .24354 L
.51338 .22535 L
s
.51338 .24354 m
.52518 .24354 L
.52518 .25498 L
.51338 .25498 L
.51338 .24354 L
s
.51338 .25498 m
.52518 .25498 L
.52518 .25888 L
.51338 .25888 L
.51338 .25498 L
s
.039 .916 .04 r
.02381 .14441 m
.43819 .18066 L
s
% Start of user PostScript
0 0 90.5 7.91772 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.43819 .18066 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14441 m
.43819 .1625 L
s
% Start of user PostScript
0 0 90.5 3.95132 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.43819 .1625 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14441 m
.43819 .14441 L
s
% Start of user PostScript
0 0 90.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.43819 .14441 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14441 m
.43819 .12632 L
s
% Start of user PostScript
0 0 90.5 -3.95132 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.43819 .12632 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .14441 m
.43819 .10816 L
s
% Start of user PostScript
0 0 90.5 -7.91772 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.43819 .10816 Mdot
.039 .916 .04 r
.5 Mabswid
.43819 .18066 m
.47626 .18285 L
s
% Start of user PostScript
90.5 7.91772 98.8161 8.39564 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.47626 .18285 Mdot
.039 .916 .04 r
.5 Mabswid
.43819 .1625 m
.47861 .16366 L
s
% Start of user PostScript
90.5 3.95132 99.3293 4.20495 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.47861 .16366 Mdot
.039 .916 .04 r
.5 Mabswid
.43819 .14441 m
.4794 .14441 L
s
% Start of user PostScript
90.5 0 99.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.4794 .14441 Mdot
.039 .916 .04 r
.5 Mabswid
.43819 .12632 m
.47861 .12516 L
s
% Start of user PostScript
90.5 -3.95132 99.3293 -4.20495 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.47861 .12516 Mdot
.039 .916 .04 r
.5 Mabswid
.43819 .10816 m
.47626 .10597 L
s
% Start of user PostScript
90.5 -7.91772 98.8161 -8.39564 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.47626 .10597 Mdot
.039 .916 .04 r
.5 Mabswid
.47626 .18285 m
.48711 .18288 L
s
% Start of user PostScript
98.8161 8.39564 101.185 8.4014 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48711 .18288 Mdot
.039 .916 .04 r
.5 Mabswid
.47861 .16366 m
.48476 .16367 L
s
% Start of user PostScript
99.3293 4.20495 100.671 4.2069 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48476 .16367 Mdot
.039 .916 .04 r
.5 Mabswid
.4794 .14441 m
.48397 .14441 L
s
% Start of user PostScript
99.5 0 100.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48397 .14441 Mdot
.039 .916 .04 r
.5 Mabswid
.47861 .12516 m
.48476 .12515 L
s
% Start of user PostScript
99.3293 -4.20495 100.671 -4.2069 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48476 .12515 Mdot
.039 .916 .04 r
.5 Mabswid
.47626 .10597 m
.48711 .10594 L
s
% Start of user PostScript
98.8161 -8.39564 101.185 -8.4014 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48711 .10594 Mdot
.039 .916 .04 r
.5 Mabswid
.48711 .18288 m
.52518 .18081 L
s
% Start of user PostScript
101.185 8.4014 109.5 7.94971 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.52518 .18081 Mdot
.039 .916 .04 r
.5 Mabswid
.48476 .16367 m
.52518 .16259 L
s
% Start of user PostScript
100.671 4.2069 109.5 3.97004 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.52518 .16259 Mdot
.039 .916 .04 r
.5 Mabswid
.48397 .14441 m
.52518 .14441 L
s
% Start of user PostScript
100.5 0 109.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.52518 .14441 Mdot
.039 .916 .04 r
.5 Mabswid
.48476 .12515 m
.52518 .12623 L
s
% Start of user PostScript
100.671 -4.2069 109.5 -3.97004 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.52518 .12623 Mdot
.039 .916 .04 r
.5 Mabswid
.48711 .10594 m
.52518 .10801 L
s
% Start of user PostScript
101.185 -8.4014 109.5 -7.94971 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.52518 .10801 Mdot
.039 .916 .04 r
.5 Mabswid
.52518 .18081 m
.97619 .14352 L
s
% Start of user PostScript
109.5 7.94971 208. -0.194042 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .14352 Mdot
.039 .916 .04 r
.5 Mabswid
.52518 .16259 m
.97619 .1442 L
s
% Start of user PostScript
109.5 3.97004 208. -0.0459421 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1442 Mdot
.039 .916 .04 r
.5 Mabswid
.52518 .14441 m
.97619 .14441 L
s
% Start of user PostScript
109.5 0 208. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .14441 Mdot
.039 .916 .04 r
.5 Mabswid
.52518 .12623 m
.97619 .14462 L
s
% Start of user PostScript
109.5 -3.97004 208. 0.0459421 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .14462 Mdot
.039 .916 .04 r
.5 Mabswid
.52518 .10801 m
.97619 .1453 L
s
% Start of user PostScript
109.5 -7.94971 208. 0.194042 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .1453 Mdot
gsave
.50458 .00631 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45879 .00631 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.48168 .00631 -66.5938 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.188 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .26519 L
0 .26519 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[137]:=",
  ImageSize->{288, 76.3125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000C2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00O_ooool6o`000003ooooool0
003o000000?o000000?oooooo`000?l000001ol0002<ooooo`00Ooooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooool000000oooool01?l0003oooooooooooooool2o`0000;ooooo
00?o0000ooooooooool0ROooool007oooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00
0004o`0000Gooooo00?o0000ooooooooool0Roooool007oooooo00?o0000ooooooooool01?ooool0
1Ol0003oooooooooool0003ooooo00;o00001Oooool00ol0003oooooooooo`2;ooooo`00Ooooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooo`000?ooool00_l00006ooooo`03o`000?oo
oooooooo08[ooooo001oooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo0000oooo
o`02o`0000Cooooo00?o0000ooooool00000S?ooool007kooooo0ol00004ooooo`;o00000oooool4
o`0000Cooooo00?o0000ooooooooool0Roooool00?oooooo8Oooool00?oooooo8Oooool007kooooo
1Ol00007ooooo`03o`000?oooooooooo00Kooooo1?l00029ooooo`00O_ooool5o`0000Oooooo00?o
0000ooooooooool01_ooool4o`0008Wooooo001nooooo`04o`000?moOgooOgmoogmoO`;o00001_oo
ool00ol0003oooooooooo`05ooooo`;o00000_moOgl00ol0003oooooooooo`27ooooo`00O_ooool0
1?l0003oOgmoogmoOomoOgl2o`0000Kooooo00?o0000ooooooooool01Oooool2o`0000;oOgmo00?o
0000ooooooooool0Qoooool007kooooo1_l00006ooooo`03o`000?oooooooooo00Cooooo00?o0000
ogmoOol000000ol00029ooooo`00O_ooool01ol0003oOgmoogmoOomoOgoo0000ogmoOol000001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?moOgoo000000;oOgmo00?o0000ooooooooool0Qooo
ool007kooooo00Oo0000ogmoOomoOgooOgmoo`000?moOgoo000000Gooooo00?o0000ooooooooool0
0oooool01?l0003oOgmoogmoOol00002ogmoO`03o`000?oooooooooo08Oooooo001nooooo`05o`00
0?moOgooOgmoogmoOol000000_moOgl00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Co0000ogmoOomoOgoo00000_moOgl00ol0003oooooooooo`27ooooo`00O_ooool5o`0000;o
Ogmo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?moOgooOgmoogmo
O`Co0000ROooool007kooooo00Go0000ogmoOomoOgooOgmoo`000002ogmoO`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool01Ol0003oOgmoogmoOomoOgoo000000;oOgmo00?o0000
ooooooooool0Qoooool007kooooo00Go0000ogmoOomoOgooOgmoo`000003ogmoO`05o`000?oooooo
ooooooooool000000oooool00ol0003oOgmoogmoO`02ogmoO`04o`000?moOgooOgmoo`0008Wooooo
001nooooo`05o`000?moOgooOgmoogmoOol000000omoOgl01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ogmoOomoOgl00_moOgl01?l0003oOgmoogmoOol00029ooooo`00O_ooool01Ol0003o
OgmoogmoOomoOgoo000000?oOgmo00Go0000ooooooooooooooooo`000003ooooo`03o`000?moOgoo
Ogmo00;oOgmo00Co0000ogmoOomoOgoo0000ROooool007kooooo00Go0000ogmoOomoOgooOgmoo`00
0004ogmoO`04o`000?ooooooooooo`0000;ooooo00?o0000ogmoOomoOgl00omoOgl01?l0003oOgmo
ogmoOol00029ooooo`00O_ooool01Ol0003oOgmoogmoOomoOgoo000000CoOgmo00Co0000oooooooo
oooo00000_ooool00ol0003oOgmoogmoO`03ogmoO`04o`000?moOgooOgmoo`0008Wooooo001noooo
o`Go00001?moOgl01?l0003oooooooooool00002ooooo`03o`000?moOgooOgmo00?oOgmo1?l00029
ooooo`00O_ooool01Ol0003oOgmoogmoOomoOgoo000000GoOgmo00?o0000ooooool000000_ooool0
0ol0003oOgmoogmoO`03ogmoO`04o`000?moOgooOgmoo`0008Wooooo001nooooo`05o`000?moOgoo
OgmoogmoOol000001OmoOgl00ol0003oooooo`000002ooooo`03o`000?moOgooOgmo00?oOgmo00Co
0000ogmoOomoOgoo0000ROooool007kooooo00?o0000ogmoOomoOgl01_l9jPX01omoOgoo0000oooo
ool0003oooooo`000?moOgl00ol9jPX2ogmoO`04o`000?moOgooOgmoo`0008Wooooo001fooooo`Go
2NX:0oooool01?l0003oOgmoogmoOomoOgl9o`WZ2P;o00000_moOgl6o`WZ2P03ogmoOol0003ooooo
08Sooooo001goooooaCo2NX:00?o0000o`WZ2_l9jPX01ol9jPX00ol0003o2NX:o`WZ2P05o`WZ2X?o
oooo001^ooooo`oo2NX:00?oooooo`000?l000000_moOgl8o`WZ2P03o`000?oooooo000000;oOgmo
1Ol9jPX00omoOgoo0000o`000006ooooo`co2NX:Moooool006?ooooo2ol9jPX:ooooo`;o2NX:1?oo
ool3o`0000;o2NX:00?oOgmoo`WZ2_l9jPX00omoOgl2o`000003ooooool0003oOgmo00;o2NX:0omo
Ogl4o`0001;ooooo3?l9jPY[ooooo`00F?ooool;o`WZ2QCooooo00?o2NX:ooooooooool01?ooool0
0ol0003oOgmoogmoO`05o`WZ2P?oOgmo0_l000000ooooooo0000ogmoO`03o`WZ2P;oOgmo00Co0000
ogmoOomoOgoo00007_ooool<o`WZ2Uoooooo001=ooooo`_o2NX:7_ooool5o`WZ2P?ooooo00Co0000
ogmoOomoOgooOgmo2?l9jPX00ol0003oooooo`000002ogmoO`Ko2NX:00?oOgmoo`000?ooool0:Ooo
ool<o`WZ2U?ooooo0012ooooo`_o2NX:9_oooolGo`WZ2P03o`000?l9jP[o2NX:00So2NX:00?o0000
o`WZ2_l9jPX02ol9jPXZooooo`co2NX:Aoooool003Oooooo2ol9jPXKoooooaKo2NX:1Oooool5o`WZ
2P03ooooool0003o000000;oOgmo1ol9jPX3o`0000?oOgmo1Ol9jPX00omoOgoo0000o`00000<oooo
oaSo2NX:7_ooool<o`WZ2S_ooooo000/ooooo`_o2NX:4?oooolFo`WZ2Q_ooooo0_l9jPX4ooooo`03
o`000?moOgooOgmo00Co2NX:1?moOgl3o`0000;oOgmo0_l9jPX3ogmoO`04o`000?moOgooOgmoo`00
02Cooooo6?l9jPXBooooo`co2NX:;oooool0027ooooo2ol9jPX5oooooaKo2NX:;oooool3o`WZ2PGo
oooo00?o0000ogmoOomoOgl01Ol9jPX3ogmoO`?o00000_moOgl3o`WZ2P;oOgmo00Co0000ogmoOomo
Ogoo0000??oooolHo`WZ2PKooooo3?l9jPX9ooooo`Co2NX:5_ooool001Kooooo6ol9jPY6ooooo`Ko
2NX:00?oooooo`000?moOgl00_moOgl8o`WZ2P;o00000omoOgl6o`WZ2P03ogmoOol0003ooooo05?o
oooo8_l9jPX00ooooooo0000o`00000@ooooo`004?oooomjo`WZ2P03o`000?l9jP[o2NX:00So2NX:
00?o0000o`WZ2_l9jPX0M_l9jPX2o`00013ooooo000Goooooa_o2NX:AOooool5o`WZ2P;ooooo0_l0
0002ogmoO`Oo2NX:0ol00003ogmoO`Go2NX:00?oOgmoo`000?l00000DooooolSo`WZ2P03ooooool0
003o0000013ooooo000Rooooo`_o2NX:1OoooolFo`WZ2Rkooooo0_l9jPX6ooooo`03o`000?moOgoo
Ogmo00Co2NX:1?moOgl3o`0000;oOgmo0_l9jPX3ogmoO`04o`000?moOgooOgmoo`0003_ooooo6?l9
jPX6ooooo`co2NX:2_ooool4o`WZ2QKooooo000]ooooo`_o2NX:4?oooolFo`WZ2QWooooo0ol9jPX4
ooooo`03o`000?moOgooOgmo00Go2NX:0omoOgl3o`0000;oOgmo0ol9jPX2ogmoO`04o`000?moOgoo
Ogmoo`0002?ooooo6?l9jPXBooooo`co2NX:5oooool00ol9jP[oooooooooo`0Fooooo`00>?ooool;
o`WZ2Q_ooooo5_l9jPX3ooooo`Ko2NX:00?oooooo`000?moOgl00_moOgl8o`WZ2P;o00000omoOgl6
o`WZ2P03ogmoOol0003ooooo00[ooooo6?l9jPXNooooo`co2NX:??ooool004?ooooo2ol9jPXVoooo
oaKo2NX:00?o0000o`WZ2_l9jPX02?l9jPX00ol0003o2NX:o`WZ2P0:o`WZ2R[ooooo3?l9jPY8oooo
o`00C_ooool;o`WZ2Qkooooo1Ol9jPX2ooooo`;o00000_moOgl7o`WZ2PCo00000_moOgl5o`WZ2P03
ogmoOol0003o000002Wooooo3?l9jPYDooooo`00FOooool;o`WZ2Q;ooooo0ol9jPX5ooooo`03o`00
0?moOgooOgmo00Co2NX:1?moOgl2o`000003ooooool0003oOgmo00;o2NX:0omoOgl01?l0003oOgmo
ogmoOol0000Mooooo`co2NX:H?ooool006Cooooo2ol9jPX8ooooo`Go2NX:0_ooool3o`0000Ko2NX:
0_moOgl2o`000003ooooool0003oOgmo00?o2NX:0_moOgl4o`00017ooooo3?l9jPY/ooooo`00Kooo
ool?o`WZ2P;o00000_moOgl9o`WZ2P04ooooool0003oOgmoogmoO`Ko2NX:0_l00005ooooo`co2NX:
N?ooool007Oooooo5?l9jPX00ol0003o2NX:o`WZ2P07o`WZ2P03o`000?l9jP[o2NX:00Co2NX:Q?oo
ool007Kooooo1?l9jPX4ooooo`04o`000?moOgooOgmoogmoO`So2NX:0ol00002ogmoO`Go2NX:0_mo
Ogl00ol0003oooooooooo`27ooooo`00O_ooool00ol0003oOgmoogmoO`02o`WZ2P03ogmoOol9jP[o
2NX:00?oOgmo0_l000000ooooooo0000ogmoO`02o`WZ2P?oOgmo00Co0000ogmoOomoOgoo0000ROoo
ool007kooooo00Go0000ogmoOomoOgooOgmoo`000005ogmoO`05o`000?oooooo0000ooooool00000
1_moOgl01?l0003oOgmoogmoOol00029ooooo`00O_ooool01Ol0003oOgmoogmoOomoOgoo000000Go
Ogmo00?o0000ooooool000000_ooool00ol0003oOgmoogmoO`03ogmoO`04o`000?moOgooOgmoo`00
08Wooooo001nooooo`Go00001OmoOgl00ol0003oooooo`000002ooooo`03o`000?moOgooOgmo00?o
Ogmo1?l00029ooooo`00O_ooool01Ol0003oOgmoogmoOomoOgoo000000CoOgmo00Co0000oooooooo
oooo00000_ooool00ol0003oOgmoogmoO`03ogmoO`04o`000?moOgooOgmoo`0008Wooooo001noooo
o`05o`000?moOgooOgmoogmoOol000001?moOgl01?l0003oooooooooool00002ooooo`03o`000?mo
OgooOgmo00?oOgmo00Co0000ogmoOomoOgoo0000ROooool007kooooo00Go0000ogmoOomoOgooOgmo
o`000004ogmoO`04o`000?ooooooooooo`0000;ooooo00?o0000ogmoOomoOgl00omoOgl01?l0003o
OgmoogmoOol00029ooooo`00O_ooool01Ol0003oOgmoogmoOomoOgoo000000CoOgmo00Co0000oooo
oooooooo00000oooool00ol0003oOgmoogmoO`02ogmoO`04o`000?moOgooOgmoo`0008Wooooo001n
ooooo`05o`000?moOgooOgmoogmoOol000000omoOgl01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ogmoOomoOgl00_moOgl01?l0003oOgmoogmoOol00029ooooo`00O_ooool01Ol0003oOgmo
ogmoOomoOgoo000000?oOgmo00Go0000ooooooooooooooooo`000003ooooo`03o`000?moOgooOgmo
00;oOgmo00Co0000ogmoOomoOgoo0000ROooool007kooooo1Ol00003ogmoO`05o`000?oooooooooo
ooooool000000oooool00ol0003oOgmoogmoO`02ogmoO`Co0000ROooool007kooooo00Go0000ogmo
OomoOgooOgmoo`000002ogmoO`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1Ol0003oOgmoogmoOomoOgoo000000;oOgmo00?o0000ooooooooool0Qoooool007kooooo00Go0000
ogmoOomoOgooOgmoo`000002ogmoO`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01Ol0003oOgmoogmoOomoOgoo000000;oOgmo00?o0000ooooooooool0Qoooool007kooooo00Go
0000ogmoOomoOgooOgmoo`000002ogmoO`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01?l0003oOgmoogmoOol00002ogmoO`03o`000?oooooooooo08Oooooo001nooooo`07o`00
0?moOgooOgmoogmoOol0003oOgmoo`000005ooooo`03o`000?oooooooooo00?ooooo00Co0000ogmo
OomoOgoo00000_moOgl00ol0003oooooooooo`27ooooo`00O_ooool5o`000003ogmoOol0003ooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oOgmoo`000003o`0008Wooooo001nooooo`04
o`000?moOgooOgmoogmoO`;o00001_ooool00ol0003oooooooooo`04ooooo`03o`000?moOgoo0000
00;oOgmo00?o0000ooooooooool0Qoooool007kooooo00Co0000ogmoOomoOgooOgmo0_l00006oooo
o`03o`000?oooooooooo00Gooooo0_l00002ogmoO`03o`000?oooooooooo08Oooooo001nooooo`Ko
00001_ooool00ol0003oooooooooo`05ooooo`Go0000ROooool007kooooo1Ol00007ooooo`03o`00
0?oooooooooo00Kooooo1?l00029ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {75.3125, 0}} -> {-13.0566, -35.0555, \
0.815726, 0.815726}},
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
    "AOG5.5"}]
}, Open  ]],

Cell["\<\
offaxis3D = 
\t{MoveDirected[PointOfRays[{10,10}],{-90.5,30},{0,0},SideOfObject->After],
\tBiConvexLens[50, 50, 20],
\tBoundary[108, GraphicDesign -> Off]};\
\>", "Input",
  CellLabel->"In[138]:=",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[offaxis3D];", "Input",
  CellLabel->"In[139]:=",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61742 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0248347 1.02483 -0.182946 1.02483 [
[ 0 0 0 0 ]
[ 1 .61742 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61742 L
0 .61742 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.18194 .51435 m
.43938 .34913 L
s
.18194 .51435 m
.47778 .39007 L
s
0 g
.52789 .33856 m
.51952 .31101 L
s
.51952 .31101 m
.54306 .30344 L
s
.51952 .31101 m
.50867 .28489 L
s
.53326 .36587 m
.52789 .33856 L
s
.52789 .33856 m
.55146 .33109 L
s
.50867 .28489 m
.53222 .27724 L
s
.50867 .28489 m
.496 .26186 L
s
.53326 .36587 m
.55691 .35846 L
s
.54306 .30344 m
.55146 .33109 L
s
.53222 .27724 m
.54306 .30344 L
s
.55146 .33109 m
.55691 .35846 L
s
.5196 .2541 m
.53222 .27724 L
s
.496 .26186 m
.5196 .2541 L
s
.50199 .37727 m .55903 .38385 L .53526 .39121 L .656 .751 .92 r
F
0 g
.53374 .41296 m
.53526 .39121 L
s
.53326 .36587 m
.53446 .38101 L
s
.50199 .37727 m .5578 .35979 L .55903 .38385 L .656 .751 .92 r
F
0 g
.55765 .40562 m
.55903 .38385 L
s
.55691 .35846 m
.55704 .36003 L
s
.53526 .39121 m
.55903 .38385 L
s
.48229 .2434 m .52211 .25995 L .46642 .27822 L .544 .324 .532 r
F
.48229 .2434 m .50598 .23553 L .52211 .25995 L F
0 g
.50598 .23553 m
.5196 .2541 L
s
.48229 .2434 m
.50598 .23553 L
s
.46839 .23075 m
.48229 .2434 L
s
.4753 .36094 m .5578 .35979 L .50199 .37727 L .656 .751 .92 r
F
0 g
.50199 .37727 m
.53526 .39121 L
s
.039 .916 .04 r
.18194 .51435 m
.4754 .36101 L
s
.18194 .51435 m
.47791 .33001 L
s
0 g
.52873 .42966 m
.53374 .41296 L
s
.53374 .41296 m
.55765 .40562 L
s
.49221 .22279 m
.50598 .23553 L
s
.46642 .27822 m .5314 .28713 L .45738 .31111 L .544 .324 .532 r
F
.46642 .27822 m .52211 .25995 L .5314 .28713 L F
0 g
.46642 .27822 m
.48229 .2434 L
s
.50598 .23553 m
.52211 .25995 L
s
.55765 .40562 m
.55279 .42232 L
s
.46839 .23075 m
.49221 .22279 L
s
.46839 .23075 m
.45522 .22488 L
s
.4753 .36094 m .54941 .33749 L .5578 .35979 L .656 .751 .92 r
F
0 g
.5578 .35979 m
.55903 .38385 L
s
.45428 .34245 m .54941 .33749 L .4753 .36094 L .656 .751 .92 r
F
0 g
.4753 .36094 m
.50199 .37727 L
s
.52047 .44009 m
.52873 .42966 L
s
.52873 .42966 m
.55279 .42232 L
s
.47918 .21683 m
.49221 .22279 L
s
.45738 .31111 m .53466 .31674 L .45428 .34245 L .544 .324 .532 r
F
.039 .916 .04 r
.45451 .31201 m
.4569 .31024 L
s
.18194 .51435 m
.45451 .31201 L
s
.45738 .31111 m .5314 .28713 L .53466 .31674 L .544 .324 .532 r
F
.039 .916 .04 r
.53306 .30216 m
.54007 .29862 L
s
0 g
.45738 .31111 m
.46642 .27822 L
s
.039 .916 .04 r
.4569 .31024 m
.522 .27759 L
s
0 g
.52211 .25995 m
.5314 .28713 L
s
.55279 .42232 m
.5447 .43272 L
s
.45522 .22488 m
.47918 .21683 L
s
.45522 .22488 m
.44367 .22633 L
s
.039 .916 .04 r
.54007 .29862 m
.85054 .11625 L
s
0 0 0 r
2 Mabswid
.54007 .29862 Mdot
.45428 .34245 m .53202 .34867 L .45696 .37236 L .544 .324 .532 r
F
.039 .916 .04 r
.5 Mabswid
.45405 .37331 m
.45647 .37206 L
s
.18194 .51435 m
.45405 .37331 L
s
.45428 .34245 m .53466 .31674 L .54941 .33749 L .656 .751 .92 r
F
.45428 .34245 m .53466 .31674 L .53202 .34867 L .544 .324 .532 r
F
0 g
.54941 .33749 m
.5578 .35979 L
s
.43873 .32179 m .53466 .31674 L .45428 .34245 L .656 .751 .92 r
F
0 g
.45642 .32086 m
.45738 .31111 L
s
.039 .916 .04 r
.53341 .3319 m
.54294 .32712 L
s
.18194 .51435 m
.45428 .34245 L
s
.18194 .51435 m
.44009 .28463 L
s
0 0 0 r
2 Mabswid
.45428 .34245 Mdot
0 g
.5 Mabswid
.50944 .44339 m
.52047 .44009 L
s
.52047 .44009 m
.5447 .43272 L
s
.4678 .21822 m
.47918 .21683 L
s
.039 .916 .04 r
.44009 .28463 m
.49681 .25783 L
s
0 g
.5447 .43272 m
.53385 .43597 L
s
.039 .916 .04 r
.54294 .32712 m
.85127 .11204 L
s
0 0 0 r
2 Mabswid
.54294 .32712 Mdot
0 g
.5 Mabswid
.44367 .22633 m
.43457 .2352 L
s
.4678 .21822 m
.44367 .22633 L
s
.45696 .37236 m .5231 .38297 L .46582 .40081 L .544 .324 .532 r
F
.45696 .37236 m .53202 .34867 L .5231 .38297 L F
.039 .916 .04 r
.52772 .36522 m
.54079 .35872 L
s
0 g
.45428 .34245 m
.45696 .37236 L
s
.039 .916 .04 r
.522 .27759 m
.85603 .12255 L
s
0 0 0 r
2 Mabswid
.522 .27759 Mdot
.039 .916 .04 r
.5 Mabswid
.45647 .37206 m
.52249 .339 L
s
0 0 0 r
2 Mabswid
.45647 .37206 Mdot
.43873 .32179 m .51372 .29754 L .53466 .31674 L .656 .751 .92 r
F
0 g
.5 Mabswid
.5314 .28713 m
.53466 .31674 L
s
.53466 .31674 m
.54941 .33749 L
s
.42904 .29875 m .51372 .29754 L .43873 .32179 L .656 .751 .92 r
F
0 g
.43873 .32179 m
.45428 .34245 L
s
.039 .916 .04 r
.45428 .34245 m
.5249 .30687 L
s
.18194 .51435 m
.43707 .31883 L
s
0 g
.49635 .43916 m
.50944 .44339 L
s
.50944 .44339 m
.53385 .43597 L
s
0 0 0 r
2 Mabswid
.43707 .31883 Mdot
0 g
.5 Mabswid
.45888 .22705 m
.4678 .21822 L
s
.53202 .34867 m
.53466 .31674 L
s
.53385 .43597 m
.52092 .43167 L
s
.039 .916 .04 r
.54079 .35872 m
.84949 .10426 L
s
0 0 0 r
2 Mabswid
.54079 .35872 Mdot
.039 .916 .04 r
.5 Mabswid
.5249 .30687 m
.85534 .11787 L
s
0 0 0 r
2 Mabswid
.5249 .30687 Mdot
0 g
.5 Mabswid
.43457 .2352 m
.45888 .22705 L
s
.43457 .2352 m
.42864 .25104 L
s
.039 .916 .04 r
.49681 .25783 m
.86434 .13845 L
s
0 0 0 r
2 Mabswid
.49681 .25783 Mdot
.46582 .40081 m .50677 .41992 L .48206 .42751 L .544 .324 .532 r
F
.46582 .40081 m .5231 .38297 L .50677 .41992 L F
0 g
.5 Mabswid
.45696 .37236 m
.46582 .40081 L
s
.46582 .40081 m
.48206 .42751 L
s
.5231 .38297 m
.53202 .34867 L
s
.48206 .42751 m
.49635 .43916 L
s
.49635 .43916 m
.52092 .43167 L
s
.039 .916 .04 r
.43938 .34913 m
.49694 .3209 L
s
0 0 0 r
2 Mabswid
.43938 .34913 Mdot
.42904 .29875 m .48619 .28006 L .51372 .29754 L .656 .751 .92 r
F
0 g
.5 Mabswid
.51372 .29754 m
.53466 .31674 L
s
.42636 .27288 m .48619 .28006 L .42904 .29875 L .656 .751 .92 r
F
0 g
.42904 .29875 m
.43873 .32179 L
s
.039 .916 .04 r
.43707 .31883 m
.50008 .2881 L
s
0 g
.45311 .24288 m
.45888 .22705 L
s
.50677 .41992 m
.52092 .43167 L
s
.039 .916 .04 r
.52249 .339 m
.85529 .11412 L
s
0 0 0 r
2 Mabswid
.52249 .339 Mdot
0 g
.5 Mabswid
.45311 .24288 m
.42864 .25104 L
s
.039 .916 .04 r
.50008 .2881 m
.86139 .12654 L
s
0 0 0 r
2 Mabswid
.50008 .2881 Mdot
0 g
.5 Mabswid
.50677 .41992 m
.5231 .38297 L
s
.48206 .42751 m
.50677 .41992 L
s
.4676 .40912 m
.48206 .42751 L
s
.42636 .27288 m .45098 .26474 L .48619 .28006 L .656 .751 .92 r
F
0 g
.45098 .26474 m
.48619 .28006 L
s
.45098 .26474 m
.45311 .24288 L
s
.42636 .27288 m
.42864 .25104 L
s
.48619 .28006 m
.51372 .29754 L
s
.42636 .27288 m
.42904 .29875 L
s
.4924 .40143 m
.50677 .41992 L
s
.42636 .27288 m
.45098 .26474 L
s
.42636 .27288 m
.42798 .29921 L
s
.039 .916 .04 r
.49694 .3209 m
.86277 .12087 L
s
0 0 0 r
2 Mabswid
.49694 .3209 Mdot
0 g
.5 Mabswid
.45401 .38524 m
.4676 .40912 L
s
.4676 .40912 m
.4924 .40143 L
s
.45098 .26474 m
.45272 .29112 L
s
.42798 .29921 m
.45272 .29112 L
s
.42798 .29921 m
.43343 .32815 L
s
.4924 .40143 m
.47887 .37743 L
s
.44232 .35756 m
.45401 .38524 L
s
.45401 .38524 m
.47887 .37743 L
s
.43343 .32815 m
.45825 .32014 L
s
.43343 .32815 m
.44232 .35756 L
s
.44232 .35756 m
.46719 .34965 L
s
.45825 .32014 m
.45272 .29112 L
s
.47887 .37743 m
.46719 .34965 L
s
.46719 .34965 m
.45825 .32014 L
s
0 0 0 r
2 Mabswid
.86277 .12087 Mdot
.86139 .12654 Mdot
.86434 .13845 Mdot
.85529 .11412 Mdot
.85534 .11787 Mdot
.85603 .12255 Mdot
.84949 .10426 Mdot
.85127 .11204 Mdot
.85054 .11625 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[139]:=",
  ImageSize->{288, 177.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00loooool2o`0002_ooooo003b
ooooo`03o`WZ2_l0003o000002_ooooo003aooooo`04o`WZ2_oooooo0000o`0002_ooooo003`oooo
o`03o`WZ2_oooooooooo00?o0000:_ooool00>oooooo00Co2NX:oooooooooooo2NX:0ol0000Zoooo
o`00kOooool2o`WZ2P03ooooool9jP[o2NX:00;o2NX:1?l0000Xooooo`00k?ooool00ol9jP[ooooo
ooooo`03o`WZ2P;ooooo1?l0000Xooooo`00joooool00ol9jP[oooooo`WZ2P03o`WZ2P05ooooool9
jP[o2NX:ooooool9jPX00_l0000Xooooo`00j_ooool5o`WZ2P04ooooool9jP[o2NX:ooooo`;o2NX:
:oooool00>Wooooo2_l9jPX]ooooo`00ioooool9o`WZ2PKooooo00?o2NX:o`000?l000009oooool0
0>Kooooo2?l9jPX5ooooo`?o2NX:00?oooooo`000?l000009oooool00>Cooooo2?l9jPX4ooooo`?o
2NX:;Oooool00>?ooooo1ol9jPX3ooooo`?o2NX:<?ooool00>7ooooo1ol9jPX2ooooo`?o2NX:<ooo
ool00=oooooo1ol9jPX01?oooooo2NX:o`WZ2_l9jPXfooooo`00g_ooool9o`WZ2SWooooo003Loooo
o`So2NX:??ooool00=[ooooo1ol9jPXoooooo`00f?ooool7o`WZ2T7ooooo003Eooooo`So2NX:@ooo
ool00=?ooooo1Ol9jPX00ooooooo2NX:o`WZ2P15ooooo`00dOooool9o`WZ2TKooooo003?ooooo`Ko
2NX:00Coooooo`WZ2_l9jP[o2NX:Aoooool00<cooooo1ol9jPX01?oooooo2NX:o`WZ2_l9jPY9oooo
o`00bOooool=o`WZ2T[ooooo0036ooooo`oo2NX:Boooool00<?ooooo1ol9jPX00ooooooo2NX:o`WZ
2P05o`WZ2P03ooooool9jP[ooooo04_ooooo0030ooooo`?o2NX:00?oooooo`WZ2_l9jPX00_l9jPX0
0ooooooo2NX:o`WZ2P03o`WZ2P03ooooool9jP[o2NX:00;o2NX:COooool00;gooooo0ol9jPX2oooo
o`Co2NX:00?oooooo`WZ2_l9jPX00ol9jPX01Ooooooo2NX:o`WZ2_oooooo2NX:04oooooo002joooo
o`?o2NX:0oooool4o`WZ2P;ooooo1Ol9jPX01Ooooooo2NX:o`WZ2_oooooo2NX:053ooooo002goooo
o`?o2NX:0oooool4o`WZ2P?ooooo1Ol9jPX00ooooooo2NX:o`WZ2P02ooooo`03o`WZ2_oooooooooo
04oooooo002dooooo`?o2NX:1?ooool4o`WZ2P?ooooo1Ol9jPX2ooooo`;o2NX:00?oooooo`WZ2_l9
jPX0D_ooool008Gooooo1ol0000Uooooo`?o2NX:1Oooool4o`WZ2PCooooo1?l9jPX2ooooo`;o2NX:
0_ooool00ol9jP[oooooooooo`1Booooo`00P_ooool5o`0000Gooooo0_l0000Pooooo`?o2NX:1_oo
ool4o`WZ2PCooooo1?l9jPX3ooooo`;o2NX:0_ooool00ol9jP[oooooooooo`1Cooooo`00P?ooool5
o`0000Cooooo0ol00002ooooo`03o`000?oooooooooo01[ooooo0ol9jPX7ooooo`?o2NX:1Oooool5
o`WZ2P?ooooo00Go2NX:ooooooooooooooooo`WZ2P1Fooooo`00O_ooool8o`000003ooooool0003o
000000Kooooo00?o0000ooooooooool05_ooool3o`WZ2POooooo1?l9jPX5ooooo`Go2NX:0oooool2
o`WZ2P?ooooo00?o2NX:ooooooooool0EOooool007gooooo1?l00002ooooo`03o`000?oooooooooo
00;o00002?ooool00ol0003oooooooooo`0Booooo`?o2NX:2?ooool4o`WZ2PKooooo1?l9jPX4oooo
o`;o2NX:0_ooool2o`WZ2USooooo001looooo`;o00001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo0ol0000@ooooo`?o2NX:2Oooool4o`WZ2PKooooo1?l9jPX4ooooo`;o
2NX:0oooool00ol9jP[oooooooooo`1Hooooo`00O?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00ol00002oh]BR003o`000?oooooooooo00_ooooo
0ol9jPX:ooooo`?o2NX:1oooool4o`WZ2PGooooo0_l9jPX3ooooo`03o`WZ2_oooooooooo05Wooooo
001looooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`;o00001_n;DXP00ol0003ooooooooo
o`07ooooo`?o2NX:2oooool3o`WZ2PSooooo1?l9jPX4ooooo`;o2NX:1?ooool00ol9jP[ooooooooo
o`1Jooooo`00Noooool00ol0003oooooooooo`03o`000003ooooool0003ooooo00Kooooo00?o0000
oh]BR?n;DXP01On;DXP2o`0000Gooooo0ol9jPX<ooooo`?o2NX:2?ooool4o`WZ2PGooooo0_l9jPX3
ooooo`;o2NX:GOooool007_ooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oh]B
R?n;DXP01on;DXP2o`000004ooooool9jP[o2NX:o`WZ2Pcooooo1?l9jPX8ooooo`Co2NX:1Oooool2
o`WZ2PCooooo00?o2NX:ooooooooool0GOooool007_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?n;DXSoRe:800OoRe:80ol9jPX=ooooo`Co2NX:2?ooool4o`WZ
2PKooooo0_l9jPX4ooooo`03o`WZ2_oooooooooo05kooooo001kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oRe:8oh]BR003oh]BR0;o00000ol9jPX00on;DXSo
0000o`00000;ooooo`?o2NX:2_ooool3o`WZ2PKooooo0_l9jPX5ooooo`03o`WZ2_oooooooooo05oo
oooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oRe:8
oh]BR002oh]BR003o`WZ2_l0003o000000GoRe:80_l00008ooooo`?o2NX:2_ooool3o`WZ2POooooo
0_l9jPX5ooooo`03o`WZ2_oooooooooo063ooooo001kooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool01?l0003oRe:8oh]BR?n;DXP2o`WZ2PSoRe:80_l00006ooooo`?o2NX:
2_ooool4o`WZ2POooooo00?o2NX:ooooooooool00oooool2o`WZ2V?ooooo001jooooo`03o`000?oo
oooooooo00;ooooo1?l00004ooooo`04o`000?l9jP[o2NX:o`WZ2P_oRe:80_l00002ooooo`Co2NX:
2oooool3o`WZ2POooooo0_l9jPX5ooooo`03o`WZ2_oooooooooo06?ooooo001jooooo`03o`000?oo
oooo000000;o00000_nW`>/00ol0003oYl3[o`000002o`0000;o2NX:3_n;DXP2o`0000?o2NX:3?oo
ool3o`WZ2PSooooo00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`1Tooooo`00N_ooool2
o`0000GoYl3[00?o0000ojO0jonW`>/00_nW`>/2o`0000koRe:80ol9jPX<ooooo`?o2NX:2?ooool2
o`WZ2PKooooo00?o2NX:ooooooooool0IOooool007[ooooo00?o0000ojO0jonW`>/01?nW`>/00ol0
003oYl3[ojO0j`04ojO0j`?o00002On;DXP3o`WZ2P;o00002_ooool3o`WZ2PWooooo00?o2NX:oooo
ooooool01?ooool2o`WZ2VSooooo001jooooo`03o`000?nW`>_oYl3[00CoYl3[00?o0000ojO0jonW
`>/01onW`>/2o`0000GoRe:80ol9jPX4o`0000Wooooo0ol9jPX8ooooo`;o2NX:1_ooool00ol9jP[o
ooooooooo`1Xooooo`00N_ooool00ol0003oYl3[ojO0j`04ojO0j`03o`000?nW`>_oYl3[00WoYl3[
00?o0000oh]BR?n;DXP00_l9jPX5oh]BR003o`000?oooooo000000Kooooo0ol9jPX9ooooo`03o`WZ
2_oooooooooo00Gooooo00?o2NX:ooooooooool0JOooool007[ooooo0_l00005ojO0j`03o`000?nW
`>_oYl3[00[oYl3[0ol00007oh]BR0;o00001?ooool3o`WZ2PWooooo0_l9jPX7ooooo`03o`WZ2_oo
oooooooo06[ooooo001jooooo`;o00000onW`>/3o`0000[oYl3[0_l9jPX01?nW`>_o0000o`000?l0
0006oh]BR0;o00000oooool2o`WZ2P[ooooo00?o2NX:ooooooooool01_ooool00ol9jP[ooooooooo
o`1[ooooo`00N_ooool5o`0000;oYl3[00?o0000ojO0jonW`>/01_nW`>/2o`WZ2PKoYl3[00?o0000
oh]BR?n;DXP00on;DXP00ol0003oooooo`000003o`WZ2PWooooo0_l9jPX7ooooo`;o2NX:K_ooool0
07Wooooo00?o2NX:o`000?l000001OnW`>/00ol0003oYl3[ojO0j`04ojO0j`;o2NX:2OnW`>/2o`00
00?oRe:800Co0000o`WZ2_l9jP[o2NX:2_ooool00ol9jP[oooooooooo`06ooooo`03o`WZ2_oooooo
oooo06kooooo001hooooo`04o`WZ2_oooooo0000o`0000KoYl3[00Co0000ojO0jonW`>_oYl3[0_l9
jPX=ojO0j`03o`000?n;DXSoRe:800;o2NX:0_l00008ooooo`;o2NX:2?ooool00ol9jP[ooooooooo
o`1_ooooo`00Moooool00ol9jP[oooooooooo`02o`0000KoYl3[00Co0000ojO0jol9jP[o2NX:4?nW
`>/3o`WZ2P?o00001oooool2o`WZ2PSooooo00?o2NX:ooooooooool0L?ooool007Kooooo00?o2NX:
ooooooooool00_ooool2o`0000GoYl3[00?o0000o`WZ2_nW`>/03onW`>/2o`WZ2P;o000000CoRe:8
o`000?oooooo00001_ooool00ol9jP[oooooooooo`06ooooo`;o2NX:Loooool007Cooooo0_l9jPX5
ooooo`;o00000onW`>/2o`WZ2P03o`000?nW`>_oYl3[00koYl3[0_l9jPX3ojO0j`;o00000_ooool0
1?l0003oooooooooooooool2o`WZ2PSooooo00?o2NX:ooooooooool0Loooool007?ooooo00?o2NX:
ooooooooool01Oooool3o`0000;o2NX:0onW`>/00ol0003oYl3[ojO0j`0;ojO0j`;o2NX:1_nW`>/0
1?l0003oooooooooool00002ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool0M?oo
ool007;ooooo00?o2NX:ooooooooool01_ooool2o`000003o`WZ2_nW`>_oYl3[00;oYl3[0_l0000:
ojO0j`;o000000?o2NX:ojO0jonW`>/01OnW`>/01On;DXSo0000oooooooooooo000000;o2NX:2Ooo
ool00ol9jP[oooooooooo`1eooooo`00LOooool00ol9jP[oooooooooo`07ooooo`04o`000?oooooo
0000ojO0j`?o000000?oYl3[o`000?nW`>/02?nW`>/00ol9jP[o0000o`000005ojO0j`CoRe:80_l0
00000ooooooo2NX:o`000009ooooo`03o`WZ2_oooooooooo07Kooooo001`ooooo`03o`WZ2_oooooo
oooo00Oooooo00?o2NX:ooooool000000_l00005ojO0j`03o`000?nW`>_oYl3[00CoYl3[0_l9jPX5
ojO0j`OoRe:800?o0000o`WZ2_l9jPX00_l00007ooooo`;o2NX:NOooool006oooooo00?o2NX:oooo
ooooool01_ooool2o`WZ2P05ooooool9jP[o0000ooooool000001OnW`>/00ol0003oYl3[ojO0j`02
ojO0j`;o2NX:1?nW`>/:oh]BR0;o2NX:0ol00006ooooo`03o`WZ2_oooooooooo07Wooooo001^oooo
o`03o`WZ2_oooooooooo00Kooooo00Ko2NX:ooooool9jP[o2NX:ooooool00002ooooo`03o`000?nW
`>_oYl3[00;oYl3[00?o0000ojO0jonW`>/00_l9jPX3ojO0j`_oRe:80_l9jPX00ol0003oYl3[ojO0
j`03o`0000Cooooo00?o2NX:ooooooooool0N_ooool006gooooo00?o2NX:ooooooooool01_ooool0
0ol9jP[oooooo`WZ2P03ooooo`05o`000?ooooooooooooooool000001?nW`>/01?l0003o2NX:ojO0
jonW`>/<oh]BR0;o000000?oRe:8o`000?nW`>/00onW`>/2o`0000?ooooo00?o2NX:ooooooooool0
Noooool006_ooooo0_l9jPX8ooooo`03o`WZ2_oooooo2NX:00Gooooo00Co0000oooooooooooooooo
0_l00002o`WZ2P03o`000?n;DXSoRe:800coRe:800Go2NX:o`000?l0003oRe:8o`000004ojO0j`;o
000000?oooooo`WZ2_l9jPX0O_ooool006[ooooo00?o2NX:ooooooooool01_ooool4o`WZ2PKooooo
00Co0000oooooooooooooooo0_l9jPX2oh]BR003o`000?n;DXSoRe:800[oRe:80_l9jPX4oh]BR003
o`000?nW`>_oYl3[00?oYl3[00?o0000o`WZ2_ooool0Ooooool006Wooooo00?o2NX:ooooooooool0
1_ooool00ol9jP[oooooo`WZ2P08ooooo`;o00000ol9jPX01Ol0003oRe:8oh]BR?n;DXSo000000Wo
Re:80_l9jPX6oh]BR003o`000?nW`>_oYl3[00?oYl3[00?o2NX:o`000?ooool0Ooooool006Sooooo
00?o2NX:ooooooooool01_ooool00ol9jP[oooooo`WZ2P09ooooo`;o000000Go2NX:oooooooooooo
0000oh]BR003o`0000OoRe:80_l9jPX8oh]BR003o`000?nW`>_oYl3[00;oYl3[00?o2NX:ojO0jol0
0000P?ooool006Oooooo00?o2NX:ooooooooool01Oooool4o`WZ2PWooooo0_l9jPX00ol0003ooooo
o`000003o`0000;oRe:800?o0000oh]BR?n;DXP00on;DXP2o`WZ2P[oRe:800Go0000ojO0jonW`>_o
Yl3[o`WZ2P02ojO0j`03o`000?oooooooooo07kooooo001Vooooo`03o`WZ2_oooooooooo00Gooooo
00?o2NX:ooooool9jPX02Oooool3o`WZ2P03ooooool0003o000000;ooooo00?o0000oh]BR?n;DXP0
0_n;DXP00ol0003oRe:8oh]BR002o`WZ2PcoRe:800Co0000ojO0jol0003o00000onW`>/00ol0003o
ooooooooo`1nooooo`00IOooool00ol9jP[oooooooooo`05ooooo`?o2NX:2?ooool3o`WZ2P?ooooo
00?o0000ooooooooool00_ooool01Ol0003oRe:8oh]BR?n;DXSo000000;o2NX:3On;DXP00ol0003o
2NX:o`WZ2P02o`0000CoYl3[00?o0000ooooooooool0OOooool006Cooooo00?o2NX:ooooooooool0
1?ooool3o`WZ2PWooooo0ol9jPX5ooooo`05o`000?ooooooooooooooool000000_n;DXP00ol9jP[o
0000oh]BR00>oh]BR003o`000?nW`>_oYl3[00KoYl3[00?o0000ooooooooool0OOooool006?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooo`WZ2P08ooooo`?o2NX:1oooool01Ol0003ooooo
oooooooooooo000000;o2NX:0_n;DXP00ol0003oRe:8oh]BR00<oh]BR003o`000?nW`>_oYl3[00Ko
Yl3[00?o0000ooooooooool0OOooool0067ooooo0_l9jPX6ooooo`?o2NX:2?ooool3o`WZ2PWooooo
00Co0000o`WZ2_l0003o00001?n;DXP00ol0003oRe:8oh]BR00<oh]BR003o`000?nW`>_oYl3[00Ko
Yl3[00?o0000ooooooooool0OOooool0063ooooo00?o2NX:ooooooooool01?ooool3o`WZ2PSooooo
0ol9jPX:ooooo`03o`WZ2_l0003o2NX:00;o00001?n;DXP00ol0003oRe:8oh]BR00<oh]BR003o`00
0?nW`>_oYl3[00KoYl3[00?o0000ooooooooool0OOooool005oooooo00?o2NX:ooooooooool01?oo
ool00ol9jP[oooooo`WZ2P08ooooo`;o2NX:2_ooool4o`WZ2P03o`000?oooooo000000?oRe:80ol0
000<oh]BR003o`000?nW`>_oYl3[00OoYl3[00?o0000ooooooooool0OOooool005kooooo00?o2NX:
ooooooooool01?ooool3o`WZ2POooooo0ol9jPX:ooooo`?o2NX:0_ooool00ol0003oooooooooo`03
o`0000;oRe:800?o0000oh]BR?n;DXP02_n;DXP00ol0003oYl3[ojO0j`07ojO0j`03o`000?oooooo
oooo07gooooo001Mooooo`03o`WZ2_oooooooooo00Cooooo0_l9jPX7ooooo`?o2NX:2_ooool3o`WZ
2PGooooo0ol00005oh]BR003o`000?n;DXSoRe:800WoRe:800?o0000ojO0jonW`>/01OnW`>/3o`00
07oooooo001Looooo`03o`WZ2_oooooooooo00?ooooo0ol9jPX7ooooo`?o2NX:2Oooool3o`WZ2POo
oooo00?o0000ooooool000001On;DXP00ol0003oRe:8oh]BR008oh]BR004o`000?oooooo0000o`00
00;oYl3[0ol00002ooooo`03o`000?oooooooooo07gooooo001Kooooo`03o`WZ2_oooooooooo00?o
oooo0ol9jPX6ooooo`?o2NX:2Oooool3o`WZ2P[ooooo0_l00006oh]BR003o`000?n;DXSoRe:800Oo
Re:800Co0000oooooooooooooooo0_l00005ooooo`03o`000?oooooooooo07gooooo001Jooooo`03
o`WZ2_oooooooooo00?ooooo0_l9jPX7ooooo`;o2NX:2Oooool3o`WZ2Pcooooo00?o0000o`WZ2_l0
00001_n;DXP00ol0003oRe:8oh]BR005oh]BR003o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1mooooo`00F?ooool2o`WZ2PCooooo0ol9jPX6ooooo`?o2NX:
2?ooool3o`WZ2Pcooooo0_l9jPX00ooooooo0000o`000006oh]BR003o`000?n;DXSoRe:800GoRe:8
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07gooooo
001Gooooo`03o`WZ2_oooooooooo00?ooooo0ol9jPX6ooooo`;o2NX:2?ooool3o`WZ2P_ooooo0ol9
jPX4ooooo`03o`000?n;DXSoRe:800?oRe:80ol00005oh]BR003o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1mooooo`00E_ooool00ol9jP[oooooooooo`03
ooooo`;o2NX:1_ooool3o`WZ2POooooo0ol9jPX;ooooo`;o2NX:1oooool2o`000004oh]BR?l0003o
0000o`0000;oRe:800?o0000oh]BR?n;DXP00on;DXP00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo0ol0001oooooo`00EOooool00ol9jP[oooooooooo`02ooooo`?o2NX:1Oooool3
o`WZ2POooooo0ol9jPX;ooooo`;o2NX:2_ooool2o`0000KoRe:800?o0000oh]BR?n;DXP00_n;DXP0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooooooo`1m
ooooo`00E?ooool00ol9jP[oooooooooo`02ooooo`?o2NX:1Oooool2o`WZ2POooooo1?l9jPX9oooo
o`?o2NX:3?ooool2o`0000OoRe:800Co0000oh]BR?n;DXSo00001_ooool2o`0000Cooooo00?o0000
ooooooooool0O_ooool005?ooooo00?o2NX:ooooooooool00_ooool2o`WZ2PGooooo0ol9jPX6oooo
o`Co2NX:2Oooool2o`WZ2Q3ooooo0_l00007oh]BR003o`000?n;DXSo000000Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1nooooo`00D_ooool00ol9jP[oooooooooo`02ooooo`;o
2NX:1Oooool2o`WZ2POooooo0ol9jPX9ooooo`;o2NX:4oooool00ol0003oRe:8oh]BR004oh]BR0Co
00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07kooooo001Aooooo`04o`WZ
2_ooooooooooooooo`?o2NX:1?ooool2o`WZ2POooooo0ol9jPX8ooooo`?o2NX:5_ooool00ol0003o
Re:8oh]BR003o`0000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`00
087ooooo001?ooooo`;o2NX:0oooool2o`WZ2PGooooo0_l9jPX6ooooo`?o2NX:2?ooool2o`WZ2Q[o
oooo0_l00008ooooo`04o`000?ooooooooooooooo`Co00000_ooool00ol0003oooooooooo`1ooooo
o`00C_ooool00ol9jP[oooooooooo`02ooooo`;o2NX:1?ooool2o`WZ2PKooooo0ol9jPX7ooooo`?o
2NX:7_ooool00ol0003oooooooooo`04ooooo`Ko00001?ooool00ol0003oooooooooo`20ooooo`00
COooool01?l9jP[oooooooooooooool3o`WZ2P?ooooo0ol9jPX5ooooo`?o2NX:1oooool2o`WZ2R;o
oooo00?o0000ooooooooool00ol00004ooooo`;o000000Coooooo`000?l0003o0000Poooool004co
oooo00Co2NX:oooooooooooooooo0_l9jPX4ooooo`;o2NX:1Oooool3o`WZ2POooooo0_l9jPXUoooo
o`;o00001_ooool5o`0008Gooooo001;ooooo`04o`WZ2_ooooooooooooooo`;o2NX:0oooool2o`WZ
2PGooooo0ol9jPX6ooooo`?o2NX::Oooool2o`0000;ooooo0ol00029ooooo`00B_ooool00ol9jP[o
ooooooooo`03o`WZ2P?ooooo0_l9jPX4ooooo`?o2NX:1_ooool2o`WZ2Rkooooo0_l0002<ooooo`00
BOooool00ol9jP[oooooooooo`02o`WZ2P?ooooo0_l9jPX4ooooo`?o2NX:1_ooool2o`WZ2[kooooo
0018ooooo`03o`WZ2_oooooooooo00;o2NX:0oooool2o`WZ2P?ooooo0ol9jPX5ooooo`?o2NX:`?oo
ool004Kooooo0_l9jPX2ooooo`;o2NX:0_ooool2o`WZ2P?ooooo0ol9jPX5ooooo`;o2NX:`oooool0
04Gooooo00?o2NX:ooooooooool00_l9jPX2ooooo`;o2NX:1?ooool2o`WZ2PGooooo0_l9jP[5oooo
o`00A?ooool00ol9jP[oooooooooo`02o`WZ2P;ooooo0_l9jPX3ooooo`;o2NX:1?ooool3o`WZ2/Oo
oooo0013ooooo`04o`WZ2_ooooooooooo`WZ2P;ooooo0_l9jPX3ooooo`;o2NX:1?ooool2o`WZ2/[o
oooo0012ooooo`04o`WZ2_oooooo2NX:o`WZ2P;ooooo0_l9jPX2ooooo`;o2NX:1?ooool2o`WZ2/co
oooo0011ooooo`05o`WZ2_oooooo2NX:o`WZ2_ooool00_l9jPX2ooooo`;o2NX:0oooool3o`WZ2/ko
oooo0010ooooo`03o`WZ2_oooooo2NX:00;ooooo00?o2NX:ooooooooool00_l9jPX3ooooo`;o2NX:
dOooool003oooooo0ol9jPX01?oooooo2NX:o`WZ2_ooool2o`WZ2P;ooooo0ol9jP[Cooooo`00?_oo
ool5o`WZ2P05ooooool9jP[o2NX:o`WZ2_ooool00_l9jP[Fooooo`00??ooool3o`WZ2P03ooooool9
jP[o2NX:00?o2NX:00?oooooo`WZ2_l9jPX0f?ooool003_ooooo2ol9jP[Jooooo`00>_ooool9o`WZ
2]gooooo000iooooo`So2NX:goooool003Sooooo1ol9jP[Qooooo`00=oooool5o`WZ2^Cooooo000f
ooooo`Co2NX:i_ooool003Gooooo0ol9jP[Xooooo`00=?ooool00ol9jP[oooooooooo`3Yooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.812, 0}} -> {0.0231601, 0.178511, \
0.00340738, 0.00340738}},
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
    "AOG5.5"}]
}, Open  ]],

Cell["\<\
colsys3D = 
\t{Move[PointOfRays[{10,10}],-100],
\tPlanoConvexLens[100, 50, 10],
\tBoundary[108, GraphicDesign -> Off]};\
\>", "Input",
  CellLabel->"In[140]:=",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[colsys3D];", "Input",
  CellLabel->"In[141]:=",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .593 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0322525 1.03225 -0.201548 1.03225 [
[ 0 0 0 0 ]
[ 1 .593 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .593 L
0 .593 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.09295 .43973 m
.49313 .30654 L
s
.09295 .43973 m
.45459 .32919 L
s
.09295 .43973 m
.49326 .37059 L
s
0 g
.53833 .31671 m
.53003 .2894 L
s
.53003 .2894 m
.5439 .28494 L
s
.53003 .2894 m
.5193 .26352 L
s
.54367 .34375 m
.53833 .31671 L
s
.53833 .31671 m
.55222 .3123 L
s
.5193 .26352 m
.53318 .259 L
s
.5193 .26352 m
.5068 .24068 L
s
.5439 .28494 m
.55222 .3123 L
s
.53318 .259 m
.5439 .28494 L
s
.55222 .3123 m
.55761 .33937 L
s
.54367 .34375 m
.55761 .33937 L
s
.52071 .23611 m
.53318 .259 L
s
.5068 .24068 m
.52071 .23611 L
s
.51419 .35453 m .55972 .36447 L .54572 .36882 L .656 .751 .92 r
F
0 g
.54428 .39031 m
.54572 .36882 L
s
.54367 .34375 m
.5451 .36128 L
s
.51419 .35453 m .54266 .3456 L .55972 .36447 L .656 .751 .92 r
F
0 g
.55836 .38597 m
.55972 .36447 L
s
.55761 .33937 m
.55972 .36447 L
s
.54572 .36882 m
.55972 .36447 L
s
.49329 .22237 m .50741 .24708 L .47899 .2564 L .544 .324 .532 r
F
.49329 .22237 m .50725 .21774 L .50741 .24708 L F
0 g
.50725 .21774 m
.52071 .23611 L
s
.49329 .22237 m
.50725 .21774 L
s
.47963 .20982 m
.49329 .22237 L
s
.039 .916 .04 r
.49313 .30654 m
.52618 .29596 L
s
0 g
.49366 .20514 m
.50725 .21774 L
s
.53941 .40676 m
.54428 .39031 L
s
.54428 .39031 m
.55836 .38597 L
s
.48853 .33808 m .54266 .3456 L .51419 .35453 L .656 .751 .92 r
F
0 g
.51419 .35453 m
.54572 .36882 L
s
.55836 .38597 m
.55358 .40243 L
s
.47899 .2564 m .50756 .27681 L .4708 .28873 L .544 .324 .532 r
F
.47899 .2564 m .50741 .24708 L .50756 .27681 L F
0 g
.47899 .2564 m
.49329 .22237 L
s
.50725 .21774 m
.50741 .24708 L
s
.48853 .33808 m .52533 .32642 L .54266 .3456 L .656 .751 .92 r
F
.039 .916 .04 r
.09295 .43973 m
.48987 .33909 L
s
0 g
.54266 .3456 m
.55972 .36447 L
s
.039 .916 .04 r
.52618 .29596 m
.9314 .16632 L
s
0 0 0 r
2 Mabswid
.52618 .29596 Mdot
0 g
.5 Mabswid
.47963 .20982 m
.49366 .20514 L
s
.47963 .20982 m
.46671 .20399 L
s
.48083 .19926 m
.49366 .20514 L
s
.46806 .31964 m .52533 .32642 L .48853 .33808 L .656 .751 .92 r
F
.039 .916 .04 r
.48987 .33909 m
.5263 .3275 L
s
0 g
.48853 .33808 m
.51419 .35453 L
s
.039 .916 .04 r
.09295 .43973 m
.47113 .2869 L
s
0 g
.53133 .417 m
.53941 .40676 L
s
.53941 .40676 m
.55358 .40243 L
s
.4708 .28873 m .50772 .30694 L .46806 .31964 L .544 .324 .532 r
F
.4708 .28873 m .50756 .27681 L .50772 .30694 L F
0 g
.4708 .28873 m
.47899 .2564 L
s
.039 .916 .04 r
.47113 .2869 m
.50755 .27515 L
s
0 g
.50741 .24708 m
.50756 .27681 L
s
.55358 .40243 m
.5456 .41265 L
s
.039 .916 .04 r
.5263 .3275 m
.93488 .19718 L
s
0 0 0 r
2 Mabswid
.5263 .3275 Mdot
.46806 .31964 m .50772 .30694 L .52533 .32642 L .656 .751 .92 r
F
0 g
.5 Mabswid
.52533 .32642 m
.54266 .3456 L
s
.46671 .20399 m
.48083 .19926 L
s
.46671 .20399 m
.45542 .20541 L
s
.039 .916 .04 r
.50755 .27515 m
.91637 .14368 L
s
0 0 0 r
2 Mabswid
.50755 .27515 Mdot
.039 .916 .04 r
.5 Mabswid
.49326 .37059 m
.52678 .35989 L
s
0 g
.46962 .20064 m
.48083 .19926 L
s
.46806 .31964 m .50788 .33748 L .47063 .34926 L .544 .324 .532 r
F
.46806 .31964 m .50772 .30694 L .50788 .33748 L F
.45261 .29919 m .50772 .30694 L .46806 .31964 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.46806 .31964 Mdot
.039 .916 .04 r
.5 Mabswid
.09295 .43973 m
.46806 .31964 L
s
0 g
.46966 .30159 m
.4708 .28873 L
s
.039 .916 .04 r
.09295 .43973 m
.455 .26463 L
s
0 g
.52054 .42017 m
.53133 .417 L
s
.53133 .417 m
.5456 .41265 L
s
.039 .916 .04 r
.455 .26463 m
.4886 .25384 L
s
0 g
.5456 .41265 m
.5349 .41579 L
s
.039 .916 .04 r
.52678 .35989 m
.93761 .22732 L
s
0 0 0 r
2 Mabswid
.52678 .35989 Mdot
.45261 .29919 m .48983 .28715 L .50772 .30694 L .656 .751 .92 r
F
0 0 0 r
.50772 .30694 Mdot
.039 .916 .04 r
.5 Mabswid
.50772 .30694 m
.91948 .17512 L
s
0 g
.50772 .30694 m
.52533 .32642 L
s
.039 .916 .04 r
.46806 .31964 m
.50772 .30694 L
s
0 g
.50756 .27681 m
.50772 .30694 L
s
.45542 .20541 m
.44656 .21416 L
s
.46962 .20064 m
.45542 .20541 L
s
.039 .916 .04 r
.4886 .25384 m
.9013 .12276 L
s
0 0 0 r
2 Mabswid
.4886 .25384 Mdot
.47063 .34926 m .50804 .36843 L .47886 .37754 L .544 .324 .532 r
F
.47063 .34926 m .50788 .33748 L .50804 .36843 L F
.039 .916 .04 r
.5 Mabswid
.09295 .43973 m
.47095 .35093 L
s
0 g
.46806 .31964 m
.47063 .34926 L
s
.50772 .30694 m
.50788 .33748 L
s
.039 .916 .04 r
.47095 .35093 m
.50789 .33919 L
s
0 0 0 r
2 Mabswid
.47095 .35093 Mdot
0 g
.5 Mabswid
.46086 .20937 m
.46962 .20064 L
s
.44252 .27655 m .48983 .28715 L .45261 .29919 L .656 .751 .92 r
F
0 g
.45261 .29919 m
.46806 .31964 L
s
.039 .916 .04 r
.09295 .43973 m
.45188 .29794 L
s
0 g
.5077 .41588 m
.52054 .42017 L
s
.52054 .42017 m
.5349 .41579 L
s
0 0 0 r
2 Mabswid
.45188 .29794 Mdot
0 g
.5 Mabswid
.5349 .41579 m
.52215 .41146 L
s
.039 .916 .04 r
.50789 .33919 m
.92263 .20701 L
s
0 0 0 r
2 Mabswid
.50789 .33919 Mdot
.44252 .27655 m .47164 .26703 L .48983 .28715 L .656 .751 .92 r
F
.039 .916 .04 r
.5 Mabswid
.45188 .29794 m
.48882 .28604 L
s
0 g
.48983 .28715 m
.50772 .30694 L
s
.039 .916 .04 r
.48882 .28604 m
.90381 .15267 L
s
0 0 0 r
2 Mabswid
.48882 .28604 Mdot
0 g
.5 Mabswid
.44656 .21416 m
.46086 .20937 L
s
.44656 .21416 m
.44082 .22981 L
s
.47886 .37754 m .50821 .3998 L .49368 .40428 L .544 .324 .532 r
F
.47886 .37754 m .50804 .36843 L .50821 .3998 L F
0 g
.47063 .34926 m
.47886 .37754 L
s
.47886 .37754 m
.49368 .40428 L
s
.50788 .33748 m
.50804 .36843 L
s
.45522 .22501 m
.46086 .20937 L
s
.039 .916 .04 r
.45459 .32919 m
.48867 .31828 L
s
0 0 0 r
2 Mabswid
.45459 .32919 Mdot
0 g
.5 Mabswid
.49368 .40428 m
.5077 .41588 L
s
.5077 .41588 m
.52215 .41146 L
s
.43868 .25137 m .47164 .26703 L .44252 .27655 L .656 .751 .92 r
F
0 g
.44252 .27655 m
.45261 .29919 L
s
.50821 .3998 m
.52215 .41146 L
s
.50804 .36843 m
.50821 .3998 L
s
.039 .916 .04 r
.48867 .31828 m
.90719 .18419 L
s
0 0 0 r
2 Mabswid
.48867 .31828 Mdot
.43868 .25137 m .45316 .24658 L .47164 .26703 L .656 .751 .92 r
F
0 g
.5 Mabswid
.45316 .24658 m
.47164 .26703 L
s
.47164 .26703 m
.48983 .28715 L
s
.43868 .25137 m
.44252 .27655 L
s
.43868 .25137 m
.44082 .22981 L
s
.45522 .22501 m
.44082 .22981 L
s
.45316 .24658 m
.45522 .22501 L
s
.49368 .40428 m
.50821 .3998 L
s
.47947 .38604 m
.49368 .40428 L
s
.49405 .3815 m
.50821 .3998 L
s
.43868 .25137 m
.45316 .24658 L
s
.43868 .25137 m
.44036 .27737 L
s
.4661 .36239 m
.47947 .38604 L
s
.47947 .38604 m
.49405 .3815 L
s
.45316 .24658 m
.45491 .27262 L
s
.49405 .3815 m
.48072 .35779 L
s
.44036 .27737 m
.45491 .27262 L
s
.44036 .27737 m
.44578 .30596 L
s
.45458 .33502 m
.4661 .36239 L
s
.4661 .36239 m
.48072 .35779 L
s
.46039 .30125 m
.45491 .27262 L
s
.44578 .30596 m
.46039 .30125 L
s
.44578 .30596 m
.45458 .33502 L
s
.45458 .33502 m
.46921 .33036 L
s
.48072 .35779 m
.46921 .33036 L
s
.46921 .33036 m
.46039 .30125 L
s
0 0 0 r
2 Mabswid
.9314 .16632 Mdot
.93488 .19718 Mdot
.91637 .14368 Mdot
.93761 .22732 Mdot
.91948 .17512 Mdot
.9013 .12276 Mdot
.92263 .20701 Mdot
.90381 .15267 Mdot
.90719 .18419 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[141]:=",
  ImageSize->{288, 170.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000ZR000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00ooooool2ooooo`;o00007Ooo
ool00?oooooo0Oooool00ol9jP[o0000o`00000Mooooo`00oOooool3o`WZ2R3ooooo003jooooo`?o
2NX:8oooool00?Oooooo0ol9jPXVooooo`00m?ooool3o`WZ2RWooooo003`ooooo`Co2NX:4_ooool2
o`0001Sooooo003]ooooo`?o2NX:5?ooool2o`WZ2P;o00006?ooool00>[ooooo0ol9jPXDooooo`?o
2NX:7?ooool00>Oooooo0ol9jPXDooooo`Co2NX:0_l0000Looooo`00i?ooool3o`WZ2QCooooo1_l9
jPX00ooooooo0000o`00000Looooo`00hOooool3o`WZ2QCooooo1_l9jPXRooooo`00gOooool4o`WZ
2QCooooo1_l9jPXUooooo`00f_ooool3o`WZ2QGooooo1_l9jPX@ooooo`;o2NX:0_l0000Dooooo`00
eoooool3o`WZ2QGooooo1_l9jPX@ooooo`?o2NX:0_ooool2o`0001Cooooo003Dooooo`?o2NX:5Ooo
ool6o`WZ2Q3ooooo0ol9jPX2ooooo`;o00005oooool00=7ooooo0ol9jPXEooooo`Ko2NX:4?ooool3
o`WZ2P?ooooo0_l9jPX2o`0001Oooooo003=ooooo`Co2NX:5Oooool6o`WZ2Q3ooooo0ol9jPX3oooo
o`?o2NX:6oooool00<[ooooo0ol9jPXFooooo`Ko2NX:4?ooool3o`WZ2P?ooooo1?l9jPX2o`0001_o
oooo0037ooooo`?o2NX:5_ooool6o`WZ2Q3ooooo0ol9jPX3ooooo`Ko2NX:00?oooooo`000?l00000
6oooool00<Cooooo0ol9jPXEooooo`Oo2NX:3oooool4o`WZ2P?ooooo1_l9jPXQooooo`00`Oooool3
o`WZ2QGooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX?ooooo`?o2NX:1?ooool6o`WZ2RCooooo002m
ooooo`Co2NX:5Oooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2Poooooo0ol9jPX4ooooo`Ko2NX:4?oo
ool2o`WZ2P;o00004oooool008Gooooo2?l0000]ooooo`?o2NX:5_ooool3o`WZ2P04ooooool9jP[o
2NX:o`WZ2Poooooo0ol9jPX4ooooo`Ko2NX:4?ooool3o`WZ2P;ooooo0_l0000Cooooo`00Poooool5
o`0000Cooooo0_l0000Yooooo`?o2NX:5_ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2Poooooo0ol9
jPX4ooooo`Ko2NX:4?ooool3o`WZ2Q[ooooo0022ooooo`;o000000?oooooo`000?ooool00_l00000
0ooooooo0000o`000002ooooo`03o`000?oooooooooo02?ooooo0ol9jPXFooooo`?o2NX:00Cooooo
o`WZ2_l9jP[o2NX:3oooool3o`WZ2P?ooooo1ol9jPX@ooooo`?o2NX:0oooool00ol9jP[o0000o`00
000Gooooo`00POooool4o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo01oooooo0ol9jPXF
ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:3oooool3o`WZ2P?ooooo0ol9jPX01?oooooo2NX:o`WZ
2_l9jPX@ooooo`?o2NX:0oooool3o`WZ2P03ooooool0003o000001Oooooo0020ooooo`;o00000_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_oo
ool4o`WZ2QKooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX?ooooo`?o2NX:0oooool3o`WZ2P04oooo
ool9jP[o2NX:o`WZ2Q3ooooo0ol9jPX3ooooo`?o2NX:7Oooool0083ooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`03o`0001Sooooo0ol9jPXGooooo`Oo2NX:3_ooool4o`WZ2P?o
oooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX@ooooo`?o2NX:0oooool3o`WZ2R3ooooo001oooooo`05
o`000?ooooooooooooooool000002Oooool2o`0000;oRe:800?o0000ooooooooool04oooool3o`WZ
2QOooooo1_l9jPX?ooooo`?o2NX:1?ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2Poooooo1?l9jPX3
ooooo`?o2NX:8oooool007oooooo00Co0000ooooool0003o00002_ooool01?l0003oRe:8oh]BR?n;
DXP2o`00017ooooo0ol9jPXGooooo`Ko2NX:3oooool3o`WZ2PCooooo0ol9jPX01?oooooo2NX:o`WZ
2_l9jPX?ooooo`?o2NX:1?ooool3o`WZ2Q;ooooo0_l0000Booooo`00Ooooool2o`000003ooooool0
003ooooo00Sooooo00?o0000oh]BR?n;DXP00_n;DXP00ol0003oooooo`00000=ooooo`?o2NX:5ooo
ool6o`WZ2Poooooo0ol9jPX4ooooo`Oo2NX:3oooool3o`WZ2PCooooo0ol9jPXCooooo`;o2NX:0_l0
000Booooo`00O_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oh]BR?n;DXP00_n;
DXP01?l0003oooooooooool00009ooooo`?o2NX:5_ooool7o`WZ2Poooooo0ol9jPX4ooooo`Ko2NX:
4?ooool3o`WZ2PCooooo0ol9jPXCooooo`?o2NX:5_ooool007kooooo00Go0000oooooooooooooooo
o`000009ooooo`03o`000?n;DXSoRe:800;oRe:800?o0000ooooooooool00_l00004ooooo`Co2NX:
5_ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2Poooooo0ol9jPX4ooooo`Ko2NX:4?ooool3o`WZ2P?o
oooo1?l9jPXCooooo`?o2NX:6Oooool007kooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?n;DXSoRe:800?oRe:80ol000000ooooooo0000ooooo`03o`WZ2QOooooo0ol9jPX01?oooooo
2NX:o`WZ2_l9jPX?ooooo`?o2NX:1?ooool6o`WZ2Q3ooooo0ol9jPX3ooooo`?o2NX:5?ooool3o`WZ
2Qcooooo001nooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oRe:8oh]BR003oh]B
R003o`000?oooooooooo00?o2NX:5oooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2Pkooooo1?l9jPX3
ooooo`Oo2NX:4?ooool3o`WZ2P?ooooo0ol9jPXDooooo`?o2NX:7oooool007gooooo00Co0000oooo
oooooooooooo0_l00007ooooo`03o`000?n;DXSoRe:800CoRe:80ol9jPX2ooooo`03o`000?oooooo
oooo01;ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX>ooooo`?o2NX:1?ooool3o`WZ2P04ooooool9
jP[o2NX:o`WZ2Q3ooooo0ol9jPX3ooooo`?o2NX:5?ooool3o`WZ2R;ooooo001mooooo`Co000000?o
Yl3[o`000?ooool01_ooool01?l0003oRe:8oh]BR?n;DXP3o`WZ2P;o00001?ooool00ol0003ooooo
ooooo`0>ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:3_ooool3o`WZ2PCooooo0ol9jPX01?oooooo
2NX:o`WZ2_l9jPX?ooooo`Co2NX:0oooool3o`WZ2QCooooo0ol9jPXUooooo`00OOooool00ol0003o
Yl3[ojO0j`02ojO0j`;o00001_ooool3o`000007o`WZ2_n;DXSoRe:8oh]BR?l0003oooooo`000003
ooooo`03o`000?oooooooooo00_ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX>ooooo`?o2NX:1?oo
ool3o`WZ2P04ooooool9jP[o2NX:o`WZ2Poooooo0ol9jPX4ooooo`?o2NX:5?ooool3o`WZ2RSooooo
001mooooo`03o`000?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000oooool3o`WZ2P;o00001?n;
DXP00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Sooooo0ol9jPX01?oooooo2NX:o`WZ
2_l9jPX>ooooo`?o2NX:1?ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2Poooooo0ol9jPX4ooooo`?o
2NX:5?ooool3o`WZ2R_ooooo001mooooo`03o`000?nW`>_oYl3[00;oYl3[00Co0000ojO0jonW`>_o
00000_l9jPX00ooooooo0000oh]BR006oh]BR004o`000?ooooooooooo`0000;ooooo0_l00006oooo
o`?o2NX:00Coooooo`WZ2_l9jP[o2NX:3_ooool3o`WZ2PCooooo0ol9jPX01?oooooo2NX:o`WZ2_l9
jPX?ooooo`?o2NX:0oooool4o`WZ2QCooooo0ol9jPX^ooooo`00OOooool2o`0000?oYl3[00Go0000
ojO0jonW`>_oYl3[o`000002ooooo`03o`000?n;DXSoRe:800GoRe:800Co0000oooooooooooooooo
0_l000000ooooooo0000ooooo`02ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:3_ooool3o`WZ2PCo
oooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX?ooooo`?o2NX:0oooool3o`WZ2QGooooo0ol9jPXaoooo
o`00O_ooool01Ol0003oYl3[ojO0jonW`>_o000000CoYl3[0_l00008oh]BR005o`000?oooooooooo
ooooool000000oooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2Pkooooo0ol9jPX4ooooo`?o2NX:00Co
ooooo`WZ2_l9jP[o2NX:3oooool3o`WZ2P?ooooo0ol9jPXEooooo`?o2NX:=?ooool007kooooo00Go
0000ojO0jonW`>_oYl3[o`000004ojO0j`;o00002?n;DXP00ol0003oooooooooo`02ooooo`?o2NX:
00Co0000o`WZ2_l9jP[o2NX:3Oooool4o`WZ2PCooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX?oooo
o`?o2NX:0oooool3o`WZ2QGooooo0ol9jPXgooooo`00OOooool00ol9jP[o0000o`000003o`0000Go
Yl3[00?o0000oh]BR?n;DXP01_n;DXP2o`0000?o2NX:00Go0000o`WZ2_l9jP[o2NX:o`00000<oooo
o`?o2NX:1?ooool8o`WZ2Pkooooo1?l9jPX3ooooo`?o2NX:5?ooool4o`WZ2S[ooooo001kooooo`;o
2NX:00?oooooo`000?l000000_nW`>/00ol0003oYl3[ojO0j`04ojO0j`03o`000?n;DXSoRe:800?o
Re:80_l9jPX2o`000004ooooool9jP[o2NX:o`WZ2PCooooo00?o0000ooooooooool01_ooool3o`WZ
2PCooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX?ooooo`?o2NX:1?ooool3o`WZ2QCooooo0ol9jPXn
ooooo`00NOooool2o`WZ2P?ooooo0_l00002ojO0j`03o`000?nW`>_oYl3[00GoYl3[00?o0000oh]B
R?l9jPX00_l9jPX2oh]BR0?o2NX:0oooool01Ol0003ooooooooooooooooo000000Gooooo0ol9jPX4
ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:3oooool3o`WZ2PCooooo0ol9jPXDooooo`?o2NX:@Ooo
ool007Oooooo0_l9jPX5ooooo`03o`000?oooooo000000;oYl3[00?o0000ojO0jonW`>/01OnW`>/2
o`000005oh]BR?l9jP[o2NX:o`WZ2_l000001Oooool01?l0003oooooooooooooool2o`000004oooo
ool9jP[o2NX:o`WZ2PCooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX?ooooo`?o2NX:1?ooool3o`WZ
2QCooooo0ol9jPY4ooooo`00M?ooool3o`WZ2POooooo00?o0000ooooool000000_nW`>/00ol0003o
Yl3[ojO0j`04ojO0j`04o`WZ2_l0003o0000o`WZ2P?oRe:800?o0000ooooooooool00oooool01?l0
003oooooo`000?l00003o`WZ2PCooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX?ooooo`?o2NX:0ooo
ool4o`WZ2QCooooo0ol9jPY7ooooo`00L_ooool2o`WZ2P[ooooo00?o0000ooooool000000_nW`>/0
0ol0003oYl3[ojO0j`04o`WZ2P;oYl3[00?o0000oh]BR?n;DXP00_n;DXP00ol0003oooooooooo`04
ooooo`?o2NX:00Coooooo`000?oooooooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX?ooooo`?o2NX:
0oooool3o`WZ2QGooooo0ol9jPY:ooooo`00L?ooool2o`WZ2Pgooooo00Go0000ooooool0003oYl3[
o`000002o`WZ2POoYl3[00Go0000oh]BR?n;DXSoRe:8o`000003ooooo`04o`WZ2_l0003o0000o`00
00?ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX?ooooo`?o2NX:0oooool3o`WZ2QGooooo0ol9jPY=
ooooo`00K_ooool2o`WZ2Pkooooo00Oo2NX:o`000?l9jP[o0000o`WZ2_nW`>_o000000WoYl3[00Co
0000oh]BR?n;DXSo00000ol9jPX01?oooooo0000o`000?l00003o`WZ2P04ooooool9jP[o2NX:o`WZ
2Poooooo0ol9jPX3ooooo`?o2NX:5Oooool3o`WZ2U3ooooo001/ooooo`;o2NX:3_ooool3o`WZ2P03
o`000?oooooo000000?o00002_nW`>/00ol0003oRe:8o`000004ooooo`?o2NX:00Go0000o`WZ2_l9
jP[o2NX:o`00000=ooooo`Co2NX:0oooool3o`WZ2QGooooo0ol9jPYCooooo`00J_ooool2o`WZ2Pgo
oooo1?l9jPX2ooooo`Co000000?oYl3[o`000?nW`>/02_nW`>/3o`0000?o2NX:00Coooooo`WZ2_l9
jP[o2NX:0oooool00ol0003oooooooooo`08ooooo`?o2NX:1?ooool3o`WZ2QGooooo0ol9jPYFoooo
o`00J?ooool2o`WZ2Pgooooo1?l9jPX4ooooo`04o`000?ooooooooooooooo`;o00002_nW`>/2o`WZ
2P03o`000?l9jP[ooooo00?o2NX:0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo0ol9jPX4ooooo`?o2NX:5Oooool3o`WZ2UWooooo001Vooooo`;o2NX:3?ooool4o`WZ2PSo
oooo00Co0000oooooooooooooooo0_l00005ojO0j`Co2NX:0_n;DXP3o`WZ2PKooooo00?o0000oooo
ool000000_l00003ooooo`?o2NX:0oooool4o`WZ2QGooooo0ol9jPYLooooo`00I?ooool2o`WZ2Pco
oooo1?l9jPX:ooooo`03o`000?oooooooooo00;o2NX:00?o0000ojO0jonW`>/00ol9jPX2o`000007
oh]BR?l9jP[o2NX:o`WZ2_l0003oYl3[o`000006ooooo`;o00000_ooool01?l0003o2NX:o`WZ2_l9
jPX3ooooo`?o2NX:5Oooool4o`WZ2Uoooooo001Rooooo`;o2NX:2oooool4o`WZ2Pgooooo00Go0000
o`WZ2_l9jP[oooooo`WZ2P02o`000004o`WZ2_n;DXSoRe:8o`WZ2P;o000000Go2NX:oh]BR?n;DXSo
Re:8o`000002ojO0j`03o`000?oooooooooo00?ooooo00?o0000ooooool9jPX00_l9jPX3ooooo`?o
2NX:5Oooool3o`WZ2V?ooooo001Pooooo`;o2NX:2oooool4o`WZ2Pcooooo0ol9jPX01Ooooooo0000
o`WZ2_l9jP[ooooo00;o00000ol9jPX7oh]BR005o`000?nW`>_oYl3[ojO0jol000000oooool3o`WZ
2P;ooooo00Co0000o`WZ2_l9jP[o2NX:5Oooool3o`WZ2VKooooo001Nooooo`;o2NX:2oooool3o`WZ
2Pcooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX3o`0000;o2NX:00?o0000oh]BR?n;DXP02?n;DXP0
0ol0003oYl3[ojO0j`02ojO0j`;o000000Co2NX:oooooooooooo00000ol9jPXEooooo`?o2NX:JOoo
ool005cooooo0_l9jPX:ooooo`Co2NX:2oooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2P;ooooo00Go
2NX:o`000?l0003o0000ooooo`02o`0000[oRe:800?o0000ojO0jol9jPX00_l9jPX2o`000004oooo
ool9jP[o2NX:o`WZ2P?ooooo00?o0000ooooooooool03oooool3o`WZ2Vcooooo001Iooooo`?o2NX:
2_ooool3o`WZ2P_ooooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX2ooooo`?o2NX:0_ooool3o`000003
ooooool0003oRe:800WoRe:800?o0000o`WZ2_nW`>/00_nW`>/3o`WZ2P;ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`?o2NX:Koooool005Oooooo0_l9jPX:ooooo`Co2NX:2_ooool3o`WZ2P04
ooooool9jP[o2NX:o`WZ2P;ooooo0ol9jPX5ooooo`03o`000?oooooooooo00;ooooo00?o0000oh]B
R?n;DXP01on;DXP2o`0000?o2NX:0_nW`>/01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Wooooo0ol9jPYbooooo`00EOooool2o`WZ2P[ooooo0ol9jPX:ooooo`?o2NX:00Coooooo`WZ
2_l9jP[o2NX:0_ooool3o`WZ2PSooooo00?o0000ooooooooool00_ooool00ol0003oRe:8oh]BR005
oh]BR0;o2NX:0_l00006ojO0j`05o`000?ooooooooooo`000?ooool00_l00008ooooo`?o2NX:MOoo
ool005?ooooo0_l9jPX9ooooo`Co2NX:2Oooool3o`WZ2P05ooooool9jP[o2NX:o`WZ2_ooool01?l9
jPX<ooooo`05o`000?ooooooooooo`WZ2_l000001?n;DXP3o`WZ2P;oRe:800?o0000ojO0jonW`>/0
1_nW`>/01_l0003oooooo`000?l0003oooooo`0000Gooooo0ol9jPYhooooo`00DOooool2o`WZ2PWo
oooo0ol9jPX9ooooo`?o2NX:00Goooooo`WZ2_l9jP[o2NX:ooooo`03o`WZ2Poooooo00Go2NX:o`00
0?l9jP[o2NX:ooooo`02o`0000?o2NX:1On;DXP00ol0003oYl3[ojO0j`07ojO0j`;o00000_ooool0
0ol0003oooooooooo`03o`WZ2W_ooooo001?ooooo`;o2NX:2?ooool4o`WZ2PSooooo0ol9jPX01Ooo
oooo2NX:o`WZ2_l9jP[ooooo00?o2NX:3_ooool4o`WZ2P;ooooo00?o0000o`WZ2_l000000_l00008
oh]BR0;o00002OnW`>/00ol0003oooooooooo`03o`WZ2Wkooooo001=ooooo`;o2NX:2?ooool3o`WZ
2PSooooo0ol9jPX01Ooooooo2NX:o`WZ2_l9jP[ooooo00?o2NX:3Oooool4o`WZ2P?ooooo0ol9jPX0
0ol0003oooooo`000002o`0000SoRe:800Co0000ooooool0003o00001onW`>/3o`WZ2P03ooooool0
003ooooo07kooooo001;ooooo`;o2NX:1oooool4o`WZ2POooooo0ol9jPX00ooooooo2NX:o`WZ2P05
o`WZ2Pcooooo1?l9jPX3ooooo`Co2NX:0oooool00ol0003oooooooooo`03o`0000OoRe:800Co0000
oooooooooooooooo0ol000001?nW`>_o2NX:o`WZ2_l9jPX2ojO0j`03o`000?oooooo000007oooooo
0019ooooo`;o2NX:1oooool3o`WZ2POooooo2_l9jPX<ooooo`Co2NX:0_ooool5o`WZ2PSooooo0_l0
00000ooooooo0000o`000007oh]BR005o`000?ooooooooooooooool9jPX00_l000000ol9jP[o0000
ojO0j`04ojO0j`;o0000Ooooool004Oooooo0_l9jPX6ooooo`Co2NX:1_ooool6o`WZ2P04ooooool9
jP[o2NX:o`WZ2Pcooooo0ol9jPX2ooooo`Co2NX:3Oooool01_l0003oooooooooool0003oRe:8o`00
00KoRe:800Co0000o`WZ2_l9jP[o2NX:1Oooool2o`0000;oYl3[0ol0001oooooo`00AOooool2o`WZ
2PKooooo0ol9jPX6ooooo`Ko2NX:00Coooooo`WZ2_l9jP[o2NX:2oooool4o`WZ2P03ooooool9jP[o
2NX:00;o2NX:4_ooool01Ol0003oooooo`000?n;DXSo000000KoRe:800?o0000ooooooooool02?oo
ool2o`0000;ooooo00?o0000ooooooooool0OOooool004?ooooo0_l9jPX5ooooo`?o2NX:1_ooool:
o`WZ2P[ooooo1?l9jPX00ooooooo2NX:o`WZ2P02o`WZ2QKooooo00?o0000ooooool000000_n;DXP0
0ol0003oRe:8oh]BR003oh]BR003o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00
001oooooo`00@?ooool3o`WZ2PGooooo0ol9jPX6ooooo`So2NX:2_ooool4o`WZ2P03ooooool9jP[o
2NX:00;o2NX:6?ooool3o`WZ2P03o`000?l9jP[o000000;oRe:800?o0000oh]BR?n;DXP00_n;DXP0
0ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000Ooooool003kooooo0_l9jPX5
ooooo`?o2NX:1_ooool8o`WZ2PWooooo2Ol9jPXGooooo`Go2NX:1?ooool2o`0000;oRe:800?o0000
oh]BR?n;DXP00_n;DXP00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000Oooo
ool003cooooo0_l9jPX5ooooo`?o2NX:1Oooool8o`WZ2PSooooo2?l9jPXFooooo`Ko2NX:2Oooool2
o`000004oh]BR?l0003o0000o`0000?oRe:800?o0000ooooooooool02?ooool01Ol0003ooooooooo
oooooooo000007oooooo000jooooo`;o2NX:1?ooool3o`WZ2PGooooo2?l9jPX7ooooo`So2NX:5?oo
ool6o`WZ2Q3ooooo0_l00002oh]BR005o`000?n;DXSoRe:8oh]BR?l000002_ooool00ol0003ooooo
o`000002o`0007oooooo000hooooo`;o2NX:1?ooool3o`WZ2PCooooo1ol9jPX7ooooo`So2NX:4_oo
ool6o`WZ2QKooooo0_l00003oh]BR004o`000?n;DXSoRe:8o`0000[ooooo0_l00002ooooo`03o`00
0?oooooooooo07gooooo000fooooo`;o2NX:0oooool3o`WZ2PCooooo1ol9jPX6ooooo`So2NX:4Ooo
ool5o`WZ2Qgooooo0_l00003oh]BR003o`000?n;DXSo000000[ooooo00Co0000oooooooooooo0000
P?ooool003Cooooo0_l9jPX3ooooo`?o2NX:0oooool7o`WZ2PGooooo2?l9jPX?ooooo`Ko2NX:8ooo
ool2o`0000?oRe:80_l00009ooooo`05o`000?ooooooooooooooool00000P?ooool003;ooooo0_l9
jPX2ooooo`?o2NX:0oooool7o`WZ2PCooooo1ol9jPX>ooooo`Ko2NX::_ooool00ol0003oRe:8oh]B
R003o`0000Wooooo00Go0000ooooooooooooooooo`000020ooooo`00<?ooool2o`WZ2P;ooooo0ol9
jPX2ooooo`Ko2NX:1?ooool7o`WZ2Pcooooo1_l9jPXaooooo`;o00000oooool00ol0003ooooooooo
o`06ooooo`Co0000POooool002kooooo0_l9jPX2ooooo`;o2NX:0_ooool6o`WZ2P?ooooo1ol9jPX;
ooooo`Go2NX:>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l00002
ooooo`03o`000?oooooooooo07oooooo000/ooooo`;o2NX:00Goooooo`WZ2_l9jP[o2NX:ooooo`06
o`WZ2P;ooooo1ol9jPX9ooooo`Ko2NX:?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo0000P_ooool002[ooooo0_l9jPX01?oooooo2NX:o`WZ2_oo
ool6o`WZ2P03ooooool9jP[o2NX:00Go2NX:1oooool6o`WZ2TGooooo00?o0000ooooooooool01Ol0
00000ooooooo0000o`000002o`0008?ooooo000Xooooo`[o2NX:0_ooool5o`WZ2PKooooo1_l9jPY<
ooooo`?o00000oooool4o`0008Gooooo000Uooooo`[o2NX:00?oooooo`WZ2_l9jPX00ol9jPX5oooo
o`Go2NX:EOooool3o`0008Wooooo000Sooooo`ko2NX:0oooool6o`WZ2^Kooooo000Qooooo`co2NX:
00?oooooo`WZ2_l9jPX01?l9jP[/ooooo`007oooool?o`WZ2_;ooooo000Mooooo`_o2NX:n?ooool0
01_ooooo2?l9jP[mooooo`006_ooool3o`WZ2_oooooo1?ooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {169.75, 0}} -> {0.0299816, 0.195248, \
0.00338426, 0.00338426}},
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
    "AOG5.5"}]
}, Open  ]],

Cell["\<\
colsys32 = 
\t{Move[PointOfRays[{10,10}, NumberOfRays->32],-100],
\tPlanoConvexLens[100, 50, 10],
\tBoundary[108, GraphicDesign -> Off]};\
\>", "Input",
  CellLabel->"In[142]:=",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 FindLensParameters", "Subsection",
  CellTags->{"AOG0.", "5.2", "AOG5.", "AOG5.2"}],

Cell[CellGroupData[{

Cell["?FindLensParameters", "Input",
  CellLabel->"In[143]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    \("FindLensParameters[opticalsystem, options] is a function that \
determines the paraxial lens characteristics of an imaging system.\n\n\
FindLensParameters returns complete information about focal length, principle \
planes, field stop, and pupils. In addition to the necessary lens elements, \
the opticalsystem parameter should include a light source. FindLensParameters \
is also capable of analyzing asigmatic imaging systems with the \
ABCDContruction->FullForm option setting.\n\nSee also: FieldStopSurface, \
FocalLength, BackFocalLength, BackFocalPoint, FrontFocalLength, \
FrontFocalPoint, EntrancePupilDistance, EntrancePupilPosition, \
EntrancePupilBoundary, EntrancePupilOffset, EntrancePupilRotationMatrix, \
ExitPupilDistance, ExitPupilPosition, ExitPupilBoundary, ExitPupilOffset, \
ExitPupilRotationMatrix, PrinciplePointSeparation, PrinciplePoints, and \
ABCDMatrix."\)], "Print",
  CellTags->{"Info3314357110-3725464", "AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[FindLensParameters]", "Input",
  CellLabel->"In[144]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    \({SpatialScale \[Rule] 1, ParentFunction \[Rule] FindLensParameters, 
      RunningCommentary \[Rule] False, TimeConstraint \[Rule] 10, 
      ABCDConstruction \[Rule] Horizontal, SkipSimplify \[Rule] {}, 
      FocalFraction \[Rule] Automatic, WeightingFunction \[Rule] 1, 
      FindPupils \[Rule] True, FieldStopPosition \[Rule] Automatic, 
      FocusType \[Rule] FocusDiameter, FindImagePoint \[Rule] False, 
      FocalPoint \[Rule] Automatic, NumberOfFilledRays \[Rule] 7, 
      InfinityFocusAngle \[Rule] 0.`, FilterTrace \[Rule] True, 
      ParaxialReductionRatio \[Rule] 0.002`}\)], "Output",
  CellLabel->"Out[144]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindLensParameters[sys]", "Input",
  CellLabel->"In[145]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {208.`, 0.`, 0.`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(WedgeOfRays[10, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(OpticalMedium \[Rule] Air\), 
        ",", "\<\"-Options-\"\>", 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(SourceID \[Rule] 19920\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", \(WaveLength \[Rule] 0.532`\)}], 
      "}"}]], "Output",
  CellLabel->"Out[145]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[TextData[{
  StyleBox["FindLensParameters", "Input"],
  " can also be used with astigmatic imaging systems. For example, you can \
check the focal length along each astigmatic axis."
}], "Text",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[CellGroupData[{

Cell["\<\
FindLensParameters[offaxis3D,ABCDConstruction->Full3D,FindPupils->False]\
\>", "Input",
  CellLabel->"In[146]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(ABCDConstruction \[Rule] Full3D\), 
        ",", \(AngularMagnification \[Rule] {\(-1.2464337861714014`\), \
\(-1.0915955343088417`\)}\), 
        ",", \(BackFocalLength \[Rule] {39.485013802263495`, 
            41.708552037504006`}\), 
        ",", \(BackFocalPoint \[Rule] {{57.847139891996214`, \
\(-14.815427008975622`\), 0}, {59.988748406614256`, \(-15.413453140254186`\), 
              0}}\), ",", \(ExitPupilBoundary \[Rule] {{\(-50.`\), \
\(-50.`\)}, {\(-50.`\), \(-50.`\)}}\), 
        ",", \(ExitPupilDistance \[Rule] {0, 0}\), 
        ",", \(ExitPupilOffset \[Rule] {{0, 0}, {0, 0}}\), 
        ",", \(ExitPupilPosition \[Rule] {{19.817012764638733`, \
\(-4.195834472443554`\), 0}, {19.817012764638733`, \(-4.195834472443554`\), 
              0}}\), ",", \(ExitPupilRotationMatrix \[Rule] \
{{{0.9631534464647291`, \(-0.2689524838389013`\), 0}, {0.26895248383890136`, 
                0.963153446464729`, 0}, {0, 0, 
                1}}, {{0.96315344646473`, \(-0.26895248383889797`\), 
                0}, {0.26895248383889797`, 0.9631534464647299`, 0}, {0, 0, 
                1}}}\), ",", \(FieldStopPosition \[Rule] {2, 2}\), 
        ",", \(FieldStopSurface \[Rule] {{IntersectionNumber \[Rule] 2, 
              SurfaceNumber \[Rule] 2, 
              ComponentNumber \[Rule] 1}, {IntersectionNumber \[Rule] 2, 
              SurfaceNumber \[Rule] 2, ComponentNumber \[Rule] 1}}\), 
        ",", \(FindPupils \[Rule] False\), 
        ",", \(FocalLength \[Rule] {45.79737407145489`, 
            48.985393983982966`}\), 
        ",", \(ImagePlaneTilt \[Rule] {0.9631534464647278`, \
\(-0.26895248383890547`\), 0}\), 
        ",", \(ImagePoint \[Rule] {108.`, \(-28.820190577214504`\), 0.`}\), 
        ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(BiConvexLens[50, 50, 20]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Boundary[{0, \(-54\), \(-54\)}, {108, 54, 
                        54}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{{0.8621676373989785`, 
                10.290804067447606`}, {\(-0.021835313056153834`\), 
                0.8992416763944976`}}, {{0.8514487410500707`, 
                13.334753922691144`}, {\(-0.020414248384466923`\), 
                0.8547561188227063`}}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              
              TagBox[\(Move[
                  PointOfRays[{10, 10}], {\(-90.5`\), 
                    30.`}, \(-18.33993103355537`\)]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(OpticalMedium \[Rule] Air\), 
        ",", "\<\"-Options-\"\>", ",", \(SourceID \[Rule] {20240, 20240}\), 
        ",", \(SystemABCDMatrix \[Rule] {{{\(-1.1369978533943406`\), \
\(-19.106322781000188`\)}, {\(-0.021835313056153834`\), \
\(-1.2464337861714014`\)}}, {{\(-1.0176089997643019`\), \(-5.428435949643884`\
\)}, {\(-0.02041424838446692`\), \(-1.0915955343088417`\)}}}\), 
        ",", \(TransverseMagnification \[Rule] {\(-1.1369978533943406`\), \
\(-1.0176089997643019`\)}\), ",", \(WaveFrontID \[Rule] {1, 1}\), 
        ",", \(WaveLength \[Rule] {0.532`, 0.532`}\)}], "}"}]], "Output",
  CellLabel->"Out[146]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell["\<\
Here we can see that it has two focal lengths for each direction.\
\>", "Text",
  CellTags->{"AOG5.", "AOG5.2", "AOG0."}],

Cell[CellGroupData[{

Cell["FocalLength/.%", "Input",
  CellLabel->"In[147]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    \({45.79737407145489`, 48.985393983982966`}\)], "Output",
  CellLabel->"Out[147]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindLensParameters[sys,FindImagePoint->True]", "Input",
  CellLabel->"In[148]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {206.0122947692871`, 0, 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(WedgeOfRays[10, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(OpticalMedium \[Rule] Air\), 
        ",", "\<\"-Options-\"\>", 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(SourceID \[Rule] 19920\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", \(WaveLength \[Rule] 0.532`\)}], 
      "}"}]], "Output",
  CellLabel->"Out[148]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ImagePoint/.%", "Input",
  CellLabel->"In[149]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    \({206.0122947692871`, 0, 0}\)], "Output",
  CellLabel->"Out[149]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindLensParameters[sys,FindImagePoint->True,FocalFraction->0]\
\>", "Input",
  CellLabel->"In[150]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {207.28232192993164`, 0, 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(WedgeOfRays[10, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(OpticalMedium \[Rule] Air\), 
        ",", "\<\"-Options-\"\>", 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(SourceID \[Rule] 19920\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", \(WaveLength \[Rule] 0.532`\)}], 
      "}"}]], "Output",
  CellLabel->"Out[150]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ImagePoint/.%", "Input",
  CellLabel->"In[151]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    \({207.28232192993164`, 0, 0}\)], "Output",
  CellLabel->"Out[151]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindLensParameters[sys,FindImagePoint->True,FocalFraction->1]\
\>", "Input",
  CellLabel->"In[152]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalFraction \[Rule] 1\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {205.65307998657227`, 0, 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(WedgeOfRays[10, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(OpticalMedium \[Rule] Air\), 
        ",", "\<\"-Options-\"\>", 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(SourceID \[Rule] 19920\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", \(WaveLength \[Rule] 0.532`\)}], 
      "}"}]], "Output",
  CellLabel->"Out[152]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ImagePoint/.%", "Input",
  CellLabel->"In[153]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    \({205.65307998657227`, 0, 0}\)], "Output",
  CellLabel->"Out[153]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindLensParameters[sys,FindImagePoint->True,FocalFraction->.5]\
\>", "Input",
  CellLabel->"In[154]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalFraction \[Rule] 0.5`\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {206.46770095825195`, 0, 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(WedgeOfRays[10, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(OpticalMedium \[Rule] Air\), 
        ",", "\<\"-Options-\"\>", 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(SourceID \[Rule] 19920\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", \(WaveLength \[Rule] 0.532`\)}], 
      "}"}]], "Output",
  CellLabel->"Out[154]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ImagePoint/.%", "Input",
  CellLabel->"In[155]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[BoxData[
    \({206.46770095825195`, 0, 0}\)], "Output",
  CellLabel->"Out[155]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.3 PupilFunction", "Subsection",
  CellTags->{"AOG0.", "5.3", "AOG5.", "AOG5.3"}],

Cell[CellGroupData[{

Cell["?PupilFunction", "Input",
  CellLabel->"In[156]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[BoxData[
    \("PupilFunction[system, options] is a function designed to find and \
extract the optical path difference and intensity profile on a spherical \
surface at the exit pupil of an imaging system. \n\nPupilFunction first calls \
FindLensParameters to characterize the system. Then, PupilFunction calculates \
a wavefront function and the intensity mapping function at the exit pupil. \
This information can be used together to calculate the complex field at the \
exit pupil. As input, PupilFunction takes either an optical system or the \
returned output from FindLensParameters. The optical system must contain a \
light source followed by the imaging optics with the approximate focal \
surface as its last element. For FindImagePoint->True, the last system \
element need not be the exact focal surface, since the exact focal surface \
position is automatically determined. When the default FindImagePoint->False \
is given, the last system element is assumed to be the exact focal surface. \
In addition, the light source need only contain a small number of rays (since \
the actual number of rays is internally specified). PupilFunction uses \
information from FindLensParameters about the field stop position. When \
FindPupils->False is used, the optical surface preceding the image surface is \
taken as the field stop. The user can also give as input a specific focal \
point or exit pupil position with the FocalPoint and ExitPupilPosition \
options. \n\nNote: PupilFunction works equally well for both point sources \
and planar sources, as long as the described imaging system contains a focus. \
If a one-dimensional light source is used (ie. WedgeOfRays or LineOfRays), \
then a one-dimensional pupil function is calculated. If a two-dimensional \
light source is used (ie. PointOfRays or GridOfRays), then the \
two-dimensional pupil function is determined. \n\nPupilFunction works \
together with both PointSpreadFunction and OpticalTransferFunction. \
PupilFunction is also a label used with the RenderedParameters option. See \
also: FindLensParameters, PupilIntensityFunction, PointSpreadFunction, PF, \
and OpticalTransferFunction."\)], "Print",
  CellTags->{"Info3314357173-7371059", "AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[PupilFunction]", "Input",
  CellLabel->"In[157]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[BoxData[
    \({SpatialScale \[Rule] 1, NumberOfRays \[Rule] 32, 
      FocalFraction \[Rule] Automatic, FindImagePoint \[Rule] False, 
      GeometricPointSpreadFunction \[Rule] False, FindPupils \[Rule] True, 
      ZernikeFit \[Rule] True, ZernikeOrder \[Rule] 8, 
      FieldStopPosition \[Rule] Automatic, PlotPoints \[Rule] 32, 
      InterpolationOrder \[Rule] 1, FilterTrace \[Rule] True, 
      RenderedParameters \[Rule] {OpticalPathDifference}, 
      SeidelAberrations \[Rule] True, Plot2D \[Rule] True, 
      KernelScale \[Rule] Relative, SmoothKernelSize \[Rule] 1.25`, 
      SmoothKernelRange \[Rule] 3, InterpolatingFunction \[Rule] True, 
      SampleFactor \[Rule] 2, IntensitySetting \[Rule] Automatic, 
      Energy \[Rule] Automatic, IntensityScale \[Rule] 1, 
      CosineCompensation \[Rule] True, 
      ColorFunction \[Rule] \((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ \
0.65`, 1, #1\ 0.9` + 0.1`] &)\), 
      ParaxialReductionRatio \[Rule] 0.002`}\)], "Output",
  CellLabel->"Out[157]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["PupilFunction[lensparameters]", "Input",
  CellLabel->"In[158]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0475462 -20721.4 353.467 [
[.02454 -0.0125 -9 -9 ]
[.02454 -0.0125 9 0 ]
[.26227 -0.0125 -6 -9 ]
[.26227 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.73773 -0.0125 -3 -9 ]
[.73773 -0.0125 3 0 ]
[.97546 -0.0125 -6 -9 ]
[.97546 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04208 -42 -4.5 ]
[-0.0125 .04208 0 4.5 ]
[-0.0125 .13044 -42 -4.5 ]
[-0.0125 .13044 0 4.5 ]
[-0.0125 .21881 -36 -4.5 ]
[-0.0125 .21881 0 4.5 ]
[-0.0125 .30718 -42 -4.5 ]
[-0.0125 .30718 0 4.5 ]
[-0.0125 .39554 -42 -4.5 ]
[-0.0125 .39554 0 4.5 ]
[-0.0125 .48391 -42 -4.5 ]
[-0.0125 .48391 0 4.5 ]
[-0.0125 .57228 -36 -4.5 ]
[-0.0125 .57228 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02454 0 m
.02454 .00625 L
s
[(-10)] .02454 -0.0125 0 1 Mshowa
.26227 0 m
.26227 .00625 L
s
[(-5)] .26227 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.73773 0 m
.73773 .00625 L
s
[(5)] .73773 -0.0125 0 1 Mshowa
.97546 0 m
.97546 .00625 L
s
[(10)] .97546 -0.0125 0 1 Mshowa
.125 Mabswid
.07208 0 m
.07208 .00375 L
s
.11963 0 m
.11963 .00375 L
s
.16718 0 m
.16718 .00375 L
s
.21472 0 m
.21472 .00375 L
s
.30982 0 m
.30982 .00375 L
s
.35736 0 m
.35736 .00375 L
s
.40491 0 m
.40491 .00375 L
s
.45245 0 m
.45245 .00375 L
s
.54755 0 m
.54755 .00375 L
s
.59509 0 m
.59509 .00375 L
s
.64264 0 m
.64264 .00375 L
s
.69018 0 m
.69018 .00375 L
s
.78528 0 m
.78528 .00375 L
s
.83282 0 m
.83282 .00375 L
s
.88037 0 m
.88037 .00375 L
s
.92792 0 m
.92792 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04208 m
.00625 .04208 L
s
[(58.6235)] -0.0125 .04208 1 0 Mshowa
0 .13044 m
.00625 .13044 L
s
[(58.6238)] -0.0125 .13044 1 0 Mshowa
0 .21881 m
.00625 .21881 L
s
[(58.624)] -0.0125 .21881 1 0 Mshowa
0 .30718 m
.00625 .30718 L
s
[(58.6243)] -0.0125 .30718 1 0 Mshowa
0 .39554 m
.00625 .39554 L
s
[(58.6245)] -0.0125 .39554 1 0 Mshowa
0 .48391 m
.00625 .48391 L
s
[(58.6248)] -0.0125 .48391 1 0 Mshowa
0 .57228 m
.00625 .57228 L
s
[(58.625)] -0.0125 .57228 1 0 Mshowa
.125 Mabswid
0 .05975 m
.00375 .05975 L
s
0 .07742 m
.00375 .07742 L
s
0 .0951 m
.00375 .0951 L
s
0 .11277 m
.00375 .11277 L
s
0 .14812 m
.00375 .14812 L
s
0 .16579 m
.00375 .16579 L
s
0 .18346 m
.00375 .18346 L
s
0 .20114 m
.00375 .20114 L
s
0 .23648 m
.00375 .23648 L
s
0 .25416 m
.00375 .25416 L
s
0 .27183 m
.00375 .27183 L
s
0 .2895 m
.00375 .2895 L
s
0 .32485 m
.00375 .32485 L
s
0 .34252 m
.00375 .34252 L
s
0 .3602 m
.00375 .3602 L
s
0 .37787 m
.00375 .37787 L
s
0 .41322 m
.00375 .41322 L
s
0 .43089 m
.00375 .43089 L
s
0 .44856 m
.00375 .44856 L
s
0 .46624 m
.00375 .46624 L
s
0 .50158 m
.00375 .50158 L
s
0 .51926 m
.00375 .51926 L
s
0 .53693 m
.00375 .53693 L
s
0 .5546 m
.00375 .5546 L
s
0 .0244 m
.00375 .0244 L
s
0 .00673 m
.00375 .00673 L
s
0 .58995 m
.00375 .58995 L
s
0 .60762 m
.00375 .60762 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02454 .61178 m
.02454 .61803 L
s
.26227 .61178 m
.26227 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.73773 .61178 m
.73773 .61803 L
s
.97546 .61178 m
.97546 .61803 L
s
.125 Mabswid
.07208 .61428 m
.07208 .61803 L
s
.11963 .61428 m
.11963 .61803 L
s
.16718 .61428 m
.16718 .61803 L
s
.21472 .61428 m
.21472 .61803 L
s
.30982 .61428 m
.30982 .61803 L
s
.35736 .61428 m
.35736 .61803 L
s
.40491 .61428 m
.40491 .61803 L
s
.45245 .61428 m
.45245 .61803 L
s
.54755 .61428 m
.54755 .61803 L
s
.59509 .61428 m
.59509 .61803 L
s
.64264 .61428 m
.64264 .61803 L
s
.69018 .61428 m
.69018 .61803 L
s
.78528 .61428 m
.78528 .61803 L
s
.83282 .61428 m
.83282 .61803 L
s
.88037 .61428 m
.88037 .61803 L
s
.92792 .61428 m
.92792 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04208 m
1 .04208 L
s
.99375 .13044 m
1 .13044 L
s
.99375 .21881 m
1 .21881 L
s
.99375 .30718 m
1 .30718 L
s
.99375 .39554 m
1 .39554 L
s
.99375 .48391 m
1 .48391 L
s
.99375 .57228 m
1 .57228 L
s
.125 Mabswid
.99625 .05975 m
1 .05975 L
s
.99625 .07742 m
1 .07742 L
s
.99625 .0951 m
1 .0951 L
s
.99625 .11277 m
1 .11277 L
s
.99625 .14812 m
1 .14812 L
s
.99625 .16579 m
1 .16579 L
s
.99625 .18346 m
1 .18346 L
s
.99625 .20114 m
1 .20114 L
s
.99625 .23648 m
1 .23648 L
s
.99625 .25416 m
1 .25416 L
s
.99625 .27183 m
1 .27183 L
s
.99625 .2895 m
1 .2895 L
s
.99625 .32485 m
1 .32485 L
s
.99625 .34252 m
1 .34252 L
s
.99625 .3602 m
1 .3602 L
s
.99625 .37787 m
1 .37787 L
s
.99625 .41322 m
1 .41322 L
s
.99625 .43089 m
1 .43089 L
s
.99625 .44856 m
1 .44856 L
s
.99625 .46624 m
1 .46624 L
s
.99625 .50158 m
1 .50158 L
s
.99625 .51926 m
1 .51926 L
s
.99625 .53693 m
1 .53693 L
s
.99625 .5546 m
1 .5546 L
s
.99625 .0244 m
1 .0244 L
s
.99625 .00673 m
1 .00673 L
s
.99625 .58995 m
1 .58995 L
s
.99625 .60762 m
1 .60762 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .55564 Mdot
.05462 .59478 Mdot
.08541 .60332 Mdot
.11618 .58725 Mdot
.14694 .55204 Mdot
.17769 .50271 Mdot
.20842 .44379 Mdot
.23915 .37936 Mdot
.26986 .31306 Mdot
.30056 .24812 Mdot
.33126 .18732 Mdot
.36195 .13305 Mdot
.39263 .08728 Mdot
.42331 .05159 Mdot
.45399 .02714 Mdot
.48466 .01472 Mdot
.51534 .01472 Mdot
.54601 .02714 Mdot
.57669 .05159 Mdot
.60737 .08728 Mdot
.63805 .13305 Mdot
.66874 .18732 Mdot
.69944 .24812 Mdot
.73014 .31306 Mdot
.76085 .37936 Mdot
.79158 .44379 Mdot
.82231 .50271 Mdot
.85306 .55204 Mdot
.88382 .58725 Mdot
.91459 .60332 Mdot
.94538 .59478 Mdot
.97619 .55564 Mdot
.5 Mabswid
.02381 .55564 m
.03837 .57413 L
.04579 .58356 L
.04987 .58874 L
.05187 .59128 L
.05372 .59363 L
.0547 .5948 L
.0552 .59494 L
.05574 .59509 L
.05794 .5957 L
.06178 .59676 L
.06929 .59885 L
.07385 .60011 L
.07819 .60132 L
.08209 .6024 L
.08316 .60269 L
.08429 .60301 L
.08485 .60316 L
.08537 .60331 L
.08634 .60283 L
.10137 .59499 L
.10923 .59088 L
.11352 .58864 L
.1146 .58808 L
.11562 .58754 L
.11654 .58685 L
.11753 .58571 L
.12111 .58161 L
.12494 .57723 L
.13308 .56792 L
.14738 .55135 L
.17895 .5003 L
.20935 .44184 L
.23858 .38055 L
.2697 .3134 L
.29965 .25004 L
.3315 .18689 L
.36218 .1327 L
.39168 .0887 L
.40814 .06924 L
.41591 .06019 L
.42309 .05185 L
.42671 .04888 L
.43055 .04582 L
.43863 .03937 L
.44631 .03326 L
.44966 .03059 L
.45143 .02917 L
.45331 .02767 L
.45433 .02699 L
Mistroke
.45526 .02662 L
.45706 .02589 L
.46062 .02445 L
.46847 .02127 L
.47537 .01848 L
.47913 .01695 L
.48265 .01553 L
.48357 .01516 L
.48444 .01481 L
.48544 .01472 L
.48636 .01472 L
.49043 .01472 L
.49758 .01472 L
.5054 .01472 L
.50969 .01472 L
.51179 .01472 L
.5127 .01472 L
.51371 .01472 L
.5146 .01472 L
.51543 .01475 L
.51631 .01511 L
.51724 .01549 L
.52105 .01703 L
.52915 .02031 L
.53658 .02332 L
.54342 .02609 L
.54438 .02648 L
.54542 .02689 L
.54639 .02744 L
.54729 .02815 L
.54923 .0297 L
.55137 .03141 L
.55998 .03827 L
.56808 .04473 L
.57559 .05071 L
.58274 .05863 L
.59035 .06747 L
.60641 .08617 L
.63561 .12941 L
.66671 .18373 L
.69664 .24257 L
.72846 .30951 L
.75912 .3756 L
.78859 .43753 L
.81997 .49823 L
.85018 .54742 L
.86557 .56637 L
.87368 .57565 L
.87812 .58073 L
.88029 .58322 L
Mistroke
.88228 .58549 L
.88318 .58652 L
.88417 .58743 L
.8851 .58792 L
.88597 .58837 L
.88993 .59044 L
.89836 .59485 L
.9055 .59857 L
.90925 .60053 L
.91129 .6016 L
.91321 .6026 L
.91419 .60311 L
.91474 .60328 L
.91524 .60314 L
.91747 .60252 L
.9214 .60143 L
.92911 .59929 L
.9361 .59735 L
.93992 .59629 L
.94352 .59529 L
.94437 .59506 L
.94527 .59481 L
.94626 .59366 L
.94717 .5925 L
.9512 .58739 L
.9583 .57836 L
.97438 .55794 L
.97619 .55564 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[158]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00<?ooool3o`0000Cooooo0_l0000dooooo`?o0000=?ooool2o`0003Oo
oooo0ol0000cooooo`?o00001?ooool2o`0000Cooooo000aooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000<_ooool01Ol0003ooooooooooooooooo000003;ooooo00Co0000oooo
oooooooo0000=Oooool01Ol0003ooooooooooooooooo000003?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`00:Oooool5o`0000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000/ooooo`Go00001Oooool00ol0003oooooooooo`0`ooooo`04o`00
0?ooooooooooo`0003Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo000aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=_ooool00ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`0003Wooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo000a
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000<_ooool4o`0003?ooooo00Co
0000oooooooooooo0000=Oooool4o`0003Cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`00<?ooool2o`0000Cooooo00Co0000oooooooooooo0000<_ooool00ol0003o
ooooooooo`0dooooo`04o`000?ooooooooooo`0003Gooooo00?o0000ooooooooool0=?ooool2o`00
00Cooooo00Co0000oooooooooooo00000oooool0037ooooo00?o0000ooooooooool00oooool2o`00
03?ooooo1Ol0000cooooo`;o0000=_ooool5o`0003?ooooo00?o0000ooooooooool00oooool2o`00
00Cooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000]oooo
oo;o00000Oooool002gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`;o0000
0Oooool002gooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`1fooooo`7o00000Ooo
ool002gooooo00?o0000ooooooooool0L?ooool=o`00077ooooo0Ol00001ooooo`00;Oooool00ol0
003oooooooooo`1]ooooo`?o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`02o`00
00?ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`;o0000KOooool2o`00007o
oooo000]ooooo`03o`000?oooooooooo06[ooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo
0_l0001/ooooo`7o00000Oooool00004ooooool0003o0000o`0000?ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00002ooooo`Go00000_ooool3o`0000?ooooo0ol00005ooooo`03o`00
0?oooooooooo06Sooooo1?l00009ooooo`03o`000?oooooooooo00Sooooo0ol0001[ooooo`7o0000
0Oooool00007o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0J?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0J?oo
ool1o`00007ooooo0004ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo0_l0001Wooooo`;o00003Oooool00ol0003ooooooooo
o`0<ooooo`;o0000Ioooool2o`00007ooooo0004ooooo`03o`000?oooooooooo00?o00002?ooool4
o`0000Gooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1Uooooo`7o00000Oooool000Co00000_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooool000000ol00005ooooo`03o`000?oooooooooo06;ooooo0ol0000@ooooo`03o`000?oo
oooooooo00oooooo0_l0001Uooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooooooooooooo
o`000?oooooo000000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`1Rooooo`;o
00004Oooool00ol0003oooooooooo`0?ooooo`;o0000IOooool1o`00007ooooo0005o`0000;ooooo
0ol0000:ooooo`;o00000oooool3o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1Rooooo`7o00000Oooool002gooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0HOooool2o`00007ooooo000]
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo067ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Poooo
o`7o00000Oooool002gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0Goooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo05gooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Mooooo`7o00000Ooo
ool002gooooo00?o0000ooooooooool0Foooool2o`0001Sooooo00?o0000ooooooooool05oooool2
o`0005gooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1Kooooo`;o00006?ooool00ol0
003oooooooooo`0Gooooo`;o0000GOooool1o`00007ooooo000]ooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05[o
oooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Jooooo`7o00000Oooool002gooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0F_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`1Hooooo`7o00000Oooool002gooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0Eoooool2o`00007ooooo00001?oooooo0000o`000?l00003ooooo`?o00001?ooool00ol0003o
ooooooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol00003ooooo`?o00001Oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`1Gooooo`7o00000Oooool00007o`000?ooooooooooooooool0003oooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0Eoooool1o`00007ooooo0004ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
EOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
E_ooool1o`00007ooooo0004ooooo`03o`000?oooooooooo00?o00002?ooool4o`0000Gooooo00?o
0000ooooooooool00_ooool2o`0000?ooooo0ol00005ooooo`;o0000E?ooool2o`00023ooooo00?o
0000ooooooooool07_ooool2o`0005Gooooo0_l00001ooooo`001?l00002ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Doooool2o`00023ooooo00?o0000ooooooooool07_ooool2o`0005Kooooo0Ol00001ooooo`0000?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0E?ooool1o`00007ooooo0005o`0000;o
oooo0ol0000:ooooo`;o00000oooool3o`0000?ooooo0ol00003ooooo`?o00001Oooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1Cooooo`7o00000Oooool002gooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0D_ooool2o`00007ooooo
000]ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo05;ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1B
ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0DOooool1o`00007ooooo000]ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo04oooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1@ooooo`7o0000
0Oooool002gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0Coooool1o`00007ooooo000]ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo04oooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1>ooooo`7o00000Oooool002go
oooo00?o0000ooooooooool0C?ooool2o`0002Oooooo00?o0000ooooooooool09_ooool2o`0004go
oooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`1<ooooo`;o00009oooool00ol0003ooooo
ooooo`0Vooooo`;o0000C_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04cooooo0Ol0
0001ooooo`00;Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`1<ooooo`7o00000Oooool002gooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0B_ooool2o`00007ooooo000]ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04_ooooo0Ol00001ooooo`00
1oooool3o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go0000
0oooool3o`0000Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0B_ooool1o`00007ooooo0006ooooo`07o`000?oo
ooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`1:ooooo`7o00000Oooool000[ooooo00?o0000ooooool000000oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooooooo
ool5o`0000Cooooo0_l0001:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`18ooooo`;o00000Oooool000[ooooo00?o0000ooooooooool00ol00008
ooooo`Co00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0BOooool1o`00007ooooo0006ooooo`Co00000_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`18ooooo`7o00000Oooool000Kooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00005ooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04So
oooo0Ol00001ooooo`001_ooool5o`0000;ooooo0ol0000:ooooo`;o00000oooool3o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`16ooooo`;o00000Oooool002gooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0Aoooool1o`00007ooooo000]ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Kooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`15ooooo`;o0000;_ooool00ol0003oooooooooo`0]oooo
o`;o0000Aoooool1o`00007ooooo000]ooooo`03o`000?oooooooooo04Gooooo0_l0000^ooooo`03
o`000?oooooooooo02gooooo0_l00017ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
A?ooool2o`00007ooooo000]ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04Cooooo0Ol00001ooooo`00;Oooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`14ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0@oooool1o`00
007ooooo000]ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo04;ooooo0_l00001ooooo`00;Oooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`12ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0@_ooool1o`00007ooooo000]
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo047ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`10oooo
o`;o00000Oooool002gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0@?ooool1o`00007ooooo00001?oooooo0000
o`000?l00003ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000?o
oooo0ol00002ooooo`?o00001Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`10ooooo`7o00000Oooool00007o`00
0?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03oooooo0Ol00001ooooo`001?oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo03oooooo0Ol00001ooooo`001?ooool00ol0003oooooooooo`03o`0000Sooooo
1?l00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Go
oooo0_l00010ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0mooooo`;o00000Oooool000Co00000_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03gooooo0_l0000foooo
o`03o`000?oooooooooo03Cooooo0_l00010ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0?Oooool2o`0003Kooooo00?o0000ooooooooool0=?ooool3o`0003oooooo0Ol0
0001ooooo`001Ol00002ooooo`?o00002_ooool2o`0000?ooooo0ol00005ooooo`04o`000?oooooo
ooooooooo`?o00001Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0mooooo`7o00000Oooool002gooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0>oooool2o`00007ooooo000]ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03cooooo0Ol00001oooo
o`00;Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0looooo`7o00000Oooool002gooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
>oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03[ooooo0_l00001ooooo`00;Oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0jooooo`7o00000Oooool002gooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>_ooool1o`00
007ooooo000]ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0Ol00001ooooo`00;Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0hooooo`;o00000Oooool002gooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>Oooool1o`00007ooooo000]
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo03Sooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0hoooo
o`7o00000Oooool002gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0=oooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo03Kooooo0_l0000mooooo`03o`000?oooooooooo03cooooo0_l0000gooooo`;o0000
0Oooool00004ooooool0003o0000o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo
0ol00002ooooo`Go00000oooool3o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo03Kooooo
0_l0000mooooo`03o`000?oooooooooo03cooooo0_l0000hooooo`7o00000Oooool00007o`000?oo
ooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03Kooooo0Ol00001ooooo`001?ooool0
0ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03Gooooo0Ol00001ooooo`001?ooool00ol0003oooooooooo`03o`0000Sooooo1?l0
0005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`;o0000=Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0=?ooool2o`00007ooooo0004o`0000;ooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooo000000;ooooo1?l00005ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03Cooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0=?ooool1o`00007ooooo0005o`0000;ooooo0ol0000:ooooo`;o
00000oooool3o`0000Gooooo00?o0000ooooooooool01Ol00004ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03?o
oooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0booooo`;o00000Oooool002gooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0<oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03;ooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0booooo`7o00000Oooool002gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0<Oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo033ooooo0_l00001ooooo`00;Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`0`ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0;_ooool2
o`0004Gooooo00?o0000ooooooooool0@oooool2o`00037ooooo0Ol00001ooooo`00;Oooool00ol0
003oooooooooo`0^ooooo`;o0000AOooool00ol0003oooooooooo`13ooooo`;o0000<Oooool1o`00
007ooooo000]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo02kooooo0_l00001ooooo`00;Oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0^ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0;_ooool1o`00007ooooo000]
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo02gooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0/oooo
o`;o00000Oooool002gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool0;?ooool1o`00007ooooo00001?oooooo0000
o`000?l00003ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000?o
oooo0ol00002ooooo`?o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0[ooooo`7o00000Oooool00007o`00
0?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02_ooooo0Ol00001ooooo`001?oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooooooo`Go000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`02ooooo`;o0000:oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool0:Oooool2o`00007ooooo0004ooooo`03o`000?oooooooooo00?o0000
2?ooool4o`0000Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooooooool3o`00
00Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0:_ooool1o`00007ooooo0004o`0000;ooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo02Wooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
0_l00002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Yooooo`7o
00000Oooool000Go00000_ooool3o`0000[ooooo0_l00003ooooo`?o00001Oooool01?l0003ooooo
ooooooooool3o`0000Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool0:?ooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo02Oooooo0_l0001<ooooo`03o`000?oooooooooo04_ooooo0_l0000Xooooo`;o0000
0Oooool002gooooo00?o0000ooooooooool09oooool2o`0004cooooo00?o0000ooooooooool0Booo
ool2o`0002Wooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Wooooo`7o00000Oooool0
02gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool09_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Co
oooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Uooooo`7o00000Oooool002gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool09?ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Cooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0Rooooo`;o00000Oooool002gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo057ooooo00?o0000oooooooo
ool08_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02;ooooo0Ol00001ooooo`00;Ooo
ool00ol0003oooooooooo`0Oooooo`?o0000Doooool00ol0003oooooooooo`1Booooo`;o00008_oo
ool1o`00007ooooo000]ooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`;o0000E?ooool0
0ol0003oooooooooo`1Booooo`;o00007?ooool2o`0000?ooooo0_l00001ooooo`00;Oooool00ol0
003oooooooooo`02ooooo`;o00007?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool06Oooool2o`0000Cooooo0Ol00001ooooo`001oooool3o`0000?o
oooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00000_ooool3o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?o
oooo0Ol00001ooooo`001_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool01?ooool1o`00007ooooo000:ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`05ooooo`7o00000Oooool000[ooooo00?o
0000ooooooooool00ol00008ooooo`Co00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo0_l00007ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool2o`00007ooooo0006ooooo`Co00000_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00oooool01_l0003ooooooooooooooooo0000ooooo`Co00001Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`1Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool1o`00007o
oooo0006ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo0Ol00001
ooooo`001_ooool5o`0000;ooooo0ol0000:ooooo`;o00000oooool3o`0000;ooooo1Ol00004oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool2o`0005_ooooo00?o0000oooo
ooooool0F_ooool2o`0000oooooo00?o0000ooooooooool02?ooool1o`00007ooooo000]ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool4o`0005_ooooo00?o0000oooooooo
ool0F_ooool4o`0000gooooo00?o0000ooooooooool01oooool2o`00007ooooo000]ooooo`03o`00
0?oooooooooo00Wooooo0ol00008ooooo`;o0000Goooool00ol0003oooooooooo`1Nooooo`;o0000
2?ooool3o`0000_ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`09ooooo`Ko00000ooo
ool2o`00067ooooo00?o0000ooooooooool0H?ooool01?l0003oooooooooooooool6o`0000cooooo
0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0?ooooo`?o0000Hoooool00ol0003ooooooooo
o`1Pooooo`Co00004_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo013ooooo0_l0001S
ooooo`03o`000?oooooooooo067ooooo0_l0000Booooo`;o00000Oooool002gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`00;Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool002goooool_l00001ooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00=_ooool3o`0005Sooooo0ol0000Gooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool02?ooool003Oooooo00?o0000ooooooooool0
F_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0
1oooool0037ooooo0ol00003ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000ooo
ool4o`000003ooooool0003o000000?o00001oooool3o`0000Cooooo1?l00003ooooo`;o00000_oo
ool6o`0000Kooooo1Ol00002ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`Co0000
0oooool2o`0000;ooooo1_l00007ooooo`03o`000?oooooooooo00?ooooo1?l000000ooooooo0000
o`000002o`0000;ooooo1?l00003ooooo`?o00000_ooool5o`0000?ooooo0_l000001?oooooo0000
ooooooooool2o`0000?ooooo0ol00009ooooo`Co000000?oooooo`000?l000000ol000000ooooooo
0000o`000002o`0000Cooooo0_l00003ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`00
0004ooooool0003o0000o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00Kooooo000`oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00006ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003ooooo`05o`000?oooooooooo
ooooool000001?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo
00002oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01_oo
ool0033ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo1Ol00002oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00Co0000oooooooo
oooo00000_ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go00001ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`03o`00
0?oooooooooo00?ooooo0ol00003ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5o`00
00Cooooo00?o0000ooooooooool01_ooool0033ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Sooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00003ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo000`ooooo`06
o`000?ooooooooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol00003
ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l0
0003ooooo`Co00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool3o`0000;ooooo1?l0
0003ooooo`Wo00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol0
0003ooooo`Co00000_ooool3o`0000Cooooo00Co0000oooooooooooooooo0_l000001?oooooo0000
o`000?ooool4o`0000?ooooo0ol00009ooooo`?o00000_ooool3o`0000Cooooo1?l000000ooooooo
0000o`000002o`0000?ooooo0_l00003ooooo`Co00000oooool3o`0000?ooooo0ol00005ooooo`03
o`000?oooooooooo00Kooooo000`ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool0037o
oooo0ol00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool3o`0000Wo
oooo1?l00009ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`?o00005_ooool00ol0003o
ooooooooo`02ooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`;o00004?ooool3o`0000[o
oooo00?o0000ooooooooool04?ooool2o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14.4316, 58.6231, \
0.0869639, 1.16978*^-5}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0475462 -1.45732 0.425431 [
[.02454 -0.0125 -9 -9 ]
[.02454 -0.0125 9 0 ]
[.26227 -0.0125 -6 -9 ]
[.26227 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.73773 -0.0125 -3 -9 ]
[.73773 -0.0125 3 0 ]
[.97546 -0.0125 -6 -9 ]
[.97546 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07423 -18 -4.5 ]
[-0.0125 .07423 0 4.5 ]
[-0.0125 .15931 -18 -4.5 ]
[-0.0125 .15931 0 4.5 ]
[-0.0125 .2444 -6 -4.5 ]
[-0.0125 .2444 0 4.5 ]
[-0.0125 .32948 -18 -4.5 ]
[-0.0125 .32948 0 4.5 ]
[-0.0125 .41457 -18 -4.5 ]
[-0.0125 .41457 0 4.5 ]
[-0.0125 .49966 -18 -4.5 ]
[-0.0125 .49966 0 4.5 ]
[-0.0125 .58474 -18 -4.5 ]
[-0.0125 .58474 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02454 0 m
.02454 .00625 L
s
[(-10)] .02454 -0.0125 0 1 Mshowa
.26227 0 m
.26227 .00625 L
s
[(-5)] .26227 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.73773 0 m
.73773 .00625 L
s
[(5)] .73773 -0.0125 0 1 Mshowa
.97546 0 m
.97546 .00625 L
s
[(10)] .97546 -0.0125 0 1 Mshowa
.125 Mabswid
.07208 0 m
.07208 .00375 L
s
.11963 0 m
.11963 .00375 L
s
.16718 0 m
.16718 .00375 L
s
.21472 0 m
.21472 .00375 L
s
.30982 0 m
.30982 .00375 L
s
.35736 0 m
.35736 .00375 L
s
.40491 0 m
.40491 .00375 L
s
.45245 0 m
.45245 .00375 L
s
.54755 0 m
.54755 .00375 L
s
.59509 0 m
.59509 .00375 L
s
.64264 0 m
.64264 .00375 L
s
.69018 0 m
.69018 .00375 L
s
.78528 0 m
.78528 .00375 L
s
.83282 0 m
.83282 .00375 L
s
.88037 0 m
.88037 .00375 L
s
.92792 0 m
.92792 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07423 m
.00625 .07423 L
s
[(3.6)] -0.0125 .07423 1 0 Mshowa
0 .15931 m
.00625 .15931 L
s
[(3.8)] -0.0125 .15931 1 0 Mshowa
0 .2444 m
.00625 .2444 L
s
[(4)] -0.0125 .2444 1 0 Mshowa
0 .32948 m
.00625 .32948 L
s
[(4.2)] -0.0125 .32948 1 0 Mshowa
0 .41457 m
.00625 .41457 L
s
[(4.4)] -0.0125 .41457 1 0 Mshowa
0 .49966 m
.00625 .49966 L
s
[(4.6)] -0.0125 .49966 1 0 Mshowa
0 .58474 m
.00625 .58474 L
s
[(4.8)] -0.0125 .58474 1 0 Mshowa
.125 Mabswid
0 .0955 m
.00375 .0955 L
s
0 .11677 m
.00375 .11677 L
s
0 .13804 m
.00375 .13804 L
s
0 .18058 m
.00375 .18058 L
s
0 .20186 m
.00375 .20186 L
s
0 .22313 m
.00375 .22313 L
s
0 .26567 m
.00375 .26567 L
s
0 .28694 m
.00375 .28694 L
s
0 .30821 m
.00375 .30821 L
s
0 .35076 m
.00375 .35076 L
s
0 .37203 m
.00375 .37203 L
s
0 .3933 m
.00375 .3933 L
s
0 .43584 m
.00375 .43584 L
s
0 .45711 m
.00375 .45711 L
s
0 .47839 m
.00375 .47839 L
s
0 .52093 m
.00375 .52093 L
s
0 .5422 m
.00375 .5422 L
s
0 .56347 m
.00375 .56347 L
s
0 .05295 m
.00375 .05295 L
s
0 .03168 m
.00375 .03168 L
s
0 .01041 m
.00375 .01041 L
s
0 .60601 m
.00375 .60601 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02454 .61178 m
.02454 .61803 L
s
.26227 .61178 m
.26227 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.73773 .61178 m
.73773 .61803 L
s
.97546 .61178 m
.97546 .61803 L
s
.125 Mabswid
.07208 .61428 m
.07208 .61803 L
s
.11963 .61428 m
.11963 .61803 L
s
.16718 .61428 m
.16718 .61803 L
s
.21472 .61428 m
.21472 .61803 L
s
.30982 .61428 m
.30982 .61803 L
s
.35736 .61428 m
.35736 .61803 L
s
.40491 .61428 m
.40491 .61803 L
s
.45245 .61428 m
.45245 .61803 L
s
.54755 .61428 m
.54755 .61803 L
s
.59509 .61428 m
.59509 .61803 L
s
.64264 .61428 m
.64264 .61803 L
s
.69018 .61428 m
.69018 .61803 L
s
.78528 .61428 m
.78528 .61803 L
s
.83282 .61428 m
.83282 .61803 L
s
.88037 .61428 m
.88037 .61803 L
s
.92792 .61428 m
.92792 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07423 m
1 .07423 L
s
.99375 .15931 m
1 .15931 L
s
.99375 .2444 m
1 .2444 L
s
.99375 .32948 m
1 .32948 L
s
.99375 .41457 m
1 .41457 L
s
.99375 .49966 m
1 .49966 L
s
.99375 .58474 m
1 .58474 L
s
.125 Mabswid
.99625 .0955 m
1 .0955 L
s
.99625 .11677 m
1 .11677 L
s
.99625 .13804 m
1 .13804 L
s
.99625 .18058 m
1 .18058 L
s
.99625 .20186 m
1 .20186 L
s
.99625 .22313 m
1 .22313 L
s
.99625 .26567 m
1 .26567 L
s
.99625 .28694 m
1 .28694 L
s
.99625 .30821 m
1 .30821 L
s
.99625 .35076 m
1 .35076 L
s
.99625 .37203 m
1 .37203 L
s
.99625 .3933 m
1 .3933 L
s
.99625 .43584 m
1 .43584 L
s
.99625 .45711 m
1 .45711 L
s
.99625 .47839 m
1 .47839 L
s
.99625 .52093 m
1 .52093 L
s
.99625 .5422 m
1 .5422 L
s
.99625 .56347 m
1 .56347 L
s
.99625 .05295 m
1 .05295 L
s
.99625 .03168 m
1 .03168 L
s
.99625 .01041 m
1 .01041 L
s
.99625 .60601 m
1 .60601 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .07423 m
1 .07423 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01658 m
.02741 .11587 L
.03076 .19253 L
.03837 .32467 L
.04218 .39086 L
.04309 .40665 L
.04406 .42339 L
.04488 .43243 L
.04579 .43952 L
.04778 .4551 L
.04994 .47202 L
.05372 .50159 L
.05571 .51715 L
.05788 .53413 L
.05887 .5419 L
.05943 .54624 L
.05993 .54762 L
.06183 .5525 L
.06639 .56417 L
.07056 .57485 L
.07246 .57971 L
.0735 .58237 L
.07447 .58485 L
.07497 .58535 L
.07551 .58569 L
.07666 .5864 L
.07869 .58766 L
.08634 .5924 L
.08833 .59363 L
.08885 .59396 L
.08941 .59431 L
.09043 .59458 L
.09137 .59471 L
.09223 .59483 L
.09422 .5951 L
.09831 .59567 L
.10047 .59597 L
.10279 .59629 L
.10384 .59644 L
.10484 .59657 L
.10574 .59661 L
.10672 .59665 L
.11037 .5968 L
.11836 .59714 L
.15004 .59815 L
.18055 .59902 L
.20988 .59977 L
.24111 .60049 L
.27117 .6011 L
.30312 .60167 L
Mistroke
.33391 .60213 L
.36352 .6025 L
.39502 .60282 L
.42536 .60304 L
.43334 .60312 L
.43553 .60314 L
.4361 .60315 L
.43672 .60315 L
.43731 .60316 L
.43784 .60316 L
.43885 .60316 L
.43981 .60316 L
.44197 .60316 L
.4456 .60316 L
.44945 .60316 L
.45042 .60316 L
.45147 .60316 L
.45206 .60316 L
.45261 .60316 L
.45313 .60316 L
.45368 .60317 L
.45759 .6032 L
.4614 .60323 L
.465 .60326 L
.46597 .60326 L
.46699 .60327 L
.46752 .60328 L
.46811 .60328 L
.46865 .60327 L
.46914 .60327 L
.47291 .60326 L
.47643 .60325 L
.47977 .60325 L
.48161 .60324 L
.48212 .60324 L
.48266 .60324 L
.48362 .60324 L
.48713 .60326 L
.49438 .6033 L
.49636 .60331 L
.49736 .60332 L
.49792 .60332 L
.49845 .60332 L
.50219 .6033 L
.50903 .60326 L
.51099 .60325 L
.51196 .60325 L
.51285 .60324 L
.51367 .60324 L
.51452 .60325 L
Mistroke
.51634 .60325 L
.52363 .60327 L
.52573 .60328 L
.52676 .60328 L
.52773 .60329 L
.52859 .60328 L
.52952 .60328 L
.53147 .60326 L
.54564 .60317 L
.55317 .60318 L
.555 .60318 L
.55696 .60318 L
.55754 .60318 L
.55809 .60318 L
.55858 .60318 L
.55911 .60317 L
.56112 .60315 L
.56565 .6031 L
.56984 .60306 L
.57184 .60304 L
.57282 .60303 L
.57372 .60302 L
.57467 .60302 L
.57569 .60302 L
.57785 .60302 L
.58134 .60301 L
.58507 .603 L
.58618 .603 L
.58722 .603 L
.58815 .603 L
.58917 .60299 L
.59013 .60298 L
.59115 .60297 L
.59297 .60294 L
.60889 .60278 L
.63823 .60248 L
.66948 .60209 L
.69955 .60162 L
.73152 .60106 L
.76232 .60043 L
.79195 .59973 L
.82347 .59892 L
.85382 .59803 L
.86933 .59757 L
.87354 .59747 L
.87747 .59735 L
.88158 .59718 L
.88607 .597 L
.88817 .59692 L
.88921 .59688 L
Mistroke
.89016 .59684 L
.89103 .5968 L
.89195 .59671 L
.89389 .59654 L
.89822 .59615 L
.90227 .59578 L
.90401 .59562 L
.90488 .59555 L
.90568 .59547 L
.90659 .59521 L
.90759 .59481 L
.90934 .5941 L
.91714 .59096 L
.91905 .59019 L
.9201 .58977 L
.92107 .58938 L
.92158 .58856 L
.92212 .5876 L
.92328 .58557 L
.92532 .58199 L
.92928 .57504 L
.93302 .56846 L
.93477 .56539 L
.93566 .56384 L
.93663 .56052 L
.93714 .55755 L
.93768 .55434 L
.93867 .54854 L
.94056 .53745 L
.94412 .51655 L
.94743 .49709 L
.94909 .48731 L
.95066 .47809 L
.95153 .47154 L
.95247 .45807 L
.95412 .43454 L
.96144 .32986 L
.96911 .19184 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[158]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008_ooool3o`0000Cooooo0_l0000eooooo`?o0000=Oooool2o`0003Sooooo0ol0000eoooo
o`?o00001?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000<oooool01Ol0003ooooooooooooooooo000003?ooooo00Co0000oooooooooooo0000=_oo
ool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000<ooooo`006oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000]ooooo`Go00001Oooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`00
03[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000cooooo000Sooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=oooool0
0ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000cooooo000Sooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000<oooool4o`0003Cooooo00Co0000oooooooooooo
0000=_ooool4o`0003Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000<oooo
o`008_ooool2o`0000Cooooo00Co0000oooooooooooo0000<oooool00ol0003oooooooooo`0eoooo
o`04o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool0=_ooool2o`0000Cooooo00Co0000
oooooooooooo00003?ooool002?ooooo00?o0000ooooooooool00oooool2o`0003Cooooo1Ol0000d
ooooo`;o0000=oooool5o`0003Gooooo00?o0000ooooooooool00oooool2o`0000gooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000NooooooSo00002_ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0007Wo
oooo00?o0000ooooooooool0N?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000:
ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`003Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00002?ooool4
o`0000Gooooon?l0000:ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo000:ooooo`?o00002_ooool2o`0000Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Gooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`002_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`002Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02?ooool000gooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l00006ooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`04ooooo`;o00002_ooool000_ooooo0_l00009ooooo`?o0000
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000=ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo000:ooooo`?o00002Oooool3o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0000Kooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo0_l00006ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`04ooooo`;o00002_ooool0
01kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`007_ooool2o`0000Kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02?ooool001Oooooo0ol00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo000Eooooo`Go00001?ooool2o`0000Kooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`005Oooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
01Kooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo000Gooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1_ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0000Oooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo0_l00007ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05ooooo`;o00002_ooool0
01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`007_ooool2o`0000Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool000_ooooo0ol00003ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03o`000?oooooooooo00Oooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oo
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00So
oooo0009ooooo`Go00002Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003ooooo
ooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01Oooool2o`0000[ooooo
0009ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo000:ooooo`03o`000?oooooo000000Sooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool000_ooooo0_l00008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03o`000?oooooooooo00Oooooo0ol0
0005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo0_l00007
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o00002?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool01_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool001kooooo0_l00008oooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`06oooo
o`;o00002_ooool001kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000;ooooo`?o00000ooo
ool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo000<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`Go00001oooool5o`00
00Cooooo0_l00009ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`07ooooo`;o00002_ooool000Wooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
00[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool000_ooooo0_l0000:ooooo`;o00001Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`;o00002Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool01oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`007_ooool2o`0000[ooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`;o00002_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool02?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0K?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`00
2oooool3o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`003?ooool00ol0003oooooooooo`06ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`Go00001oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000;ooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`09ooooo`;o0000
2_ooool000Wooooo00Co0000oooooooooooo00002?ooool4o`0000Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`002_ooool00ol0003oooooo`000008ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`002oooool2
o`0000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Sooooo000<ooooo`03o`000?oooooooooo00Sooooo0_l00005ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02?ooool001kooooo0_l0000<ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0:ooooo`;o00002_ooool001kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000
3?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
2oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0JOoo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02?ooool001kooooo0_l0000>ooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`0<ooooo`;o00002_ooool001kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Sooooo000;ooooo`?o00000oooool00ol0003oooooooooo`02oooo
o`?o00001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03
o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool02?ooool000Wooooo1Ol00007ooooo`05o`000?oooooooooooooo
ool000001?ooool2o`00013ooooo0_l0001Wooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool03oooool2o`0000[ooooo0009ooooo`04o`000?ooooooooooo`0000Wooooo0ol00005oooo
o`03o`000?oooooooooo013ooooo0_l0001Vooooo`03o`000?oooooooooo06Gooooo0_l0000Boooo
o`03o`000?oooooooooo00Sooooo000:ooooo`03o`000?oooooo000000Sooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo01;ooooo0_l0001Tooooo`03o`000?oooooooooo
06?ooooo0ol0000Cooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00002?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool04ooooolDo`00057ooooo00?o0000oooo
ooooool0DOoooolBo`0001Kooooo00?o0000ooooooooool02?ooool000cooooo00?o0000oooooooo
ool01oooool3o`0000Gooooo00?o0000ooooooooool09oooool]o`0002Cooooo00?o0000oooooooo
ool09?ooool]o`0002Sooooo00?o0000ooooooooool02?ooool001kooooo0_l0001Eoooood_o0000
E?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo000NooooooSo00002_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00<cooooo0ol0001Aooooo`00cOooool00ol0003oooooooooo`1@ooooo`00HOooool00ol0003o
ooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool3o`0000?o
oooo0ol00004ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00008ooooo`Go
000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003ooooo`?o00000_ooool3o`00
0003ooooool0003o000000Co00000_ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo
04oooooo001Qooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`00
0?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
04oooooo001Qooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`03o`000?oooooo000000;o
oooo1Ol00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000D?ooool0063ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`?o00000oooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000oooo
ool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`00001@ooooo`00H?ooool01Ol0003oooooo`000?oooooo000000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000?ooooo00?o0000ooooooooool00_ooool2o`000003oooo
ool0003o000000;ooooo0ol00002ooooo`Co00000_ooool4o`0000[ooooo00Co0000oooooooooooo
oooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0
003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`00001?ooooo`00H?ooool01Ol0003o
ooooo`000?oooooo000001Cooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1F
ooooo`00H?ooool6o`0001;ooooo1Ol0000Dooooo`03o`000?oooooooooo00Sooooo1Ol00008oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Foooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.1028, 3.31053, \
0.0850929, 0.00950999}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0475462 0.0147151 0.188044 [
[.02454 -0.0125 -9 -9 ]
[.02454 -0.0125 9 0 ]
[.26227 -0.0125 -6 -9 ]
[.26227 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.73773 -0.0125 -3 -9 ]
[.73773 -0.0125 3 0 ]
[.97546 -0.0125 -6 -9 ]
[.97546 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10874 -18 -4.5 ]
[-0.0125 .10874 0 4.5 ]
[-0.0125 .20276 -6 -4.5 ]
[-0.0125 .20276 0 4.5 ]
[-0.0125 .29678 -18 -4.5 ]
[-0.0125 .29678 0 4.5 ]
[-0.0125 .3908 -6 -4.5 ]
[-0.0125 .3908 0 4.5 ]
[-0.0125 .48483 -18 -4.5 ]
[-0.0125 .48483 0 4.5 ]
[-0.0125 .57885 -6 -4.5 ]
[-0.0125 .57885 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02454 0 m
.02454 .00625 L
s
[(-10)] .02454 -0.0125 0 1 Mshowa
.26227 0 m
.26227 .00625 L
s
[(-5)] .26227 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.73773 0 m
.73773 .00625 L
s
[(5)] .73773 -0.0125 0 1 Mshowa
.97546 0 m
.97546 .00625 L
s
[(10)] .97546 -0.0125 0 1 Mshowa
.125 Mabswid
.07208 0 m
.07208 .00375 L
s
.11963 0 m
.11963 .00375 L
s
.16718 0 m
.16718 .00375 L
s
.21472 0 m
.21472 .00375 L
s
.30982 0 m
.30982 .00375 L
s
.35736 0 m
.35736 .00375 L
s
.40491 0 m
.40491 .00375 L
s
.45245 0 m
.45245 .00375 L
s
.54755 0 m
.54755 .00375 L
s
.59509 0 m
.59509 .00375 L
s
.64264 0 m
.64264 .00375 L
s
.69018 0 m
.69018 .00375 L
s
.78528 0 m
.78528 .00375 L
s
.83282 0 m
.83282 .00375 L
s
.88037 0 m
.88037 .00375 L
s
.92792 0 m
.92792 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10874 m
.00625 .10874 L
s
[(0.5)] -0.0125 .10874 1 0 Mshowa
0 .20276 m
.00625 .20276 L
s
[(1)] -0.0125 .20276 1 0 Mshowa
0 .29678 m
.00625 .29678 L
s
[(1.5)] -0.0125 .29678 1 0 Mshowa
0 .3908 m
.00625 .3908 L
s
[(2)] -0.0125 .3908 1 0 Mshowa
0 .48483 m
.00625 .48483 L
s
[(2.5)] -0.0125 .48483 1 0 Mshowa
0 .57885 m
.00625 .57885 L
s
[(3)] -0.0125 .57885 1 0 Mshowa
.125 Mabswid
0 .03352 m
.00375 .03352 L
s
0 .05232 m
.00375 .05232 L
s
0 .07113 m
.00375 .07113 L
s
0 .08993 m
.00375 .08993 L
s
0 .12754 m
.00375 .12754 L
s
0 .14635 m
.00375 .14635 L
s
0 .16515 m
.00375 .16515 L
s
0 .18395 m
.00375 .18395 L
s
0 .22156 m
.00375 .22156 L
s
0 .24037 m
.00375 .24037 L
s
0 .25917 m
.00375 .25917 L
s
0 .27798 m
.00375 .27798 L
s
0 .31559 m
.00375 .31559 L
s
0 .33439 m
.00375 .33439 L
s
0 .35319 m
.00375 .35319 L
s
0 .372 m
.00375 .372 L
s
0 .40961 m
.00375 .40961 L
s
0 .42841 m
.00375 .42841 L
s
0 .44722 m
.00375 .44722 L
s
0 .46602 m
.00375 .46602 L
s
0 .50363 m
.00375 .50363 L
s
0 .52243 m
.00375 .52243 L
s
0 .54124 m
.00375 .54124 L
s
0 .56004 m
.00375 .56004 L
s
0 .59765 m
.00375 .59765 L
s
0 .61646 m
.00375 .61646 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02454 .61178 m
.02454 .61803 L
s
.26227 .61178 m
.26227 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.73773 .61178 m
.73773 .61803 L
s
.97546 .61178 m
.97546 .61803 L
s
.125 Mabswid
.07208 .61428 m
.07208 .61803 L
s
.11963 .61428 m
.11963 .61803 L
s
.16718 .61428 m
.16718 .61803 L
s
.21472 .61428 m
.21472 .61803 L
s
.30982 .61428 m
.30982 .61803 L
s
.35736 .61428 m
.35736 .61803 L
s
.40491 .61428 m
.40491 .61803 L
s
.45245 .61428 m
.45245 .61803 L
s
.54755 .61428 m
.54755 .61803 L
s
.59509 .61428 m
.59509 .61803 L
s
.64264 .61428 m
.64264 .61803 L
s
.69018 .61428 m
.69018 .61803 L
s
.78528 .61428 m
.78528 .61803 L
s
.83282 .61428 m
.83282 .61803 L
s
.88037 .61428 m
.88037 .61803 L
s
.92792 .61428 m
.92792 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10874 m
1 .10874 L
s
.99375 .20276 m
1 .20276 L
s
.99375 .29678 m
1 .29678 L
s
.99375 .3908 m
1 .3908 L
s
.99375 .48483 m
1 .48483 L
s
.99375 .57885 m
1 .57885 L
s
.125 Mabswid
.99625 .03352 m
1 .03352 L
s
.99625 .05232 m
1 .05232 L
s
.99625 .07113 m
1 .07113 L
s
.99625 .08993 m
1 .08993 L
s
.99625 .12754 m
1 .12754 L
s
.99625 .14635 m
1 .14635 L
s
.99625 .16515 m
1 .16515 L
s
.99625 .18395 m
1 .18395 L
s
.99625 .22156 m
1 .22156 L
s
.99625 .24037 m
1 .24037 L
s
.99625 .25917 m
1 .25917 L
s
.99625 .27798 m
1 .27798 L
s
.99625 .31559 m
1 .31559 L
s
.99625 .33439 m
1 .33439 L
s
.99625 .35319 m
1 .35319 L
s
.99625 .372 m
1 .372 L
s
.99625 .40961 m
1 .40961 L
s
.99625 .42841 m
1 .42841 L
s
.99625 .44722 m
1 .44722 L
s
.99625 .46602 m
1 .46602 L
s
.99625 .50363 m
1 .50363 L
s
.99625 .52243 m
1 .52243 L
s
.99625 .54124 m
1 .54124 L
s
.99625 .56004 m
1 .56004 L
s
.99625 .59765 m
1 .59765 L
s
.99625 .61646 m
1 .61646 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .55564 Mdot
.05462 .59478 Mdot
.08541 .60332 Mdot
.11618 .58725 Mdot
.14694 .55204 Mdot
.17769 .50271 Mdot
.20842 .44379 Mdot
.23915 .37936 Mdot
.26986 .31306 Mdot
.30056 .24812 Mdot
.33126 .18732 Mdot
.36195 .13305 Mdot
.39263 .08728 Mdot
.42331 .05159 Mdot
.45399 .02714 Mdot
.48466 .01472 Mdot
.51534 .01472 Mdot
.54601 .02714 Mdot
.57669 .05159 Mdot
.60737 .08728 Mdot
.63805 .13305 Mdot
.66874 .18732 Mdot
.69944 .24812 Mdot
.73014 .31306 Mdot
.76085 .37936 Mdot
.79158 .44379 Mdot
.82231 .50271 Mdot
.85306 .55204 Mdot
.88382 .58725 Mdot
.91459 .60332 Mdot
.94538 .59478 Mdot
.97619 .55564 Mdot
.5 Mabswid
.02381 .55564 m
.03837 .57413 L
.04579 .58356 L
.04987 .58874 L
.05187 .59128 L
.05372 .59363 L
.0547 .5948 L
.0552 .59494 L
.05574 .59509 L
.05794 .5957 L
.06178 .59676 L
.06929 .59885 L
.07385 .60011 L
.07819 .60132 L
.08209 .6024 L
.08316 .60269 L
.08429 .60301 L
.08485 .60316 L
.08537 .60331 L
.08634 .60283 L
.10137 .59499 L
.10923 .59088 L
.11352 .58864 L
.1146 .58808 L
.11562 .58754 L
.11654 .58685 L
.11753 .58571 L
.12111 .58161 L
.12494 .57723 L
.13308 .56792 L
.14738 .55135 L
.17895 .5003 L
.20935 .44184 L
.23858 .38055 L
.2697 .3134 L
.29965 .25004 L
.3315 .18689 L
.36218 .1327 L
.39168 .0887 L
.40814 .06924 L
.41591 .06019 L
.42309 .05185 L
.42671 .04888 L
.43055 .04582 L
.43863 .03937 L
.44631 .03326 L
.44966 .03059 L
.45143 .02917 L
.45331 .02767 L
.45433 .02699 L
Mistroke
.45526 .02662 L
.45706 .02589 L
.46062 .02445 L
.46847 .02127 L
.47537 .01848 L
.47913 .01695 L
.48265 .01553 L
.48357 .01516 L
.48444 .01481 L
.48544 .01472 L
.48636 .01472 L
.49043 .01472 L
.49758 .01472 L
.5054 .01472 L
.50969 .01472 L
.51179 .01472 L
.5127 .01472 L
.51371 .01472 L
.5146 .01472 L
.51543 .01475 L
.51631 .01511 L
.51724 .01549 L
.52105 .01703 L
.52915 .02031 L
.53658 .02332 L
.54342 .02609 L
.54438 .02648 L
.54542 .02689 L
.54639 .02744 L
.54729 .02815 L
.54923 .0297 L
.55137 .03141 L
.55998 .03827 L
.56808 .04473 L
.57559 .05071 L
.58274 .05863 L
.59035 .06747 L
.60641 .08617 L
.63561 .12941 L
.66671 .18373 L
.69664 .24257 L
.72846 .30951 L
.75912 .3756 L
.78859 .43753 L
.81997 .49823 L
.85018 .54742 L
.86557 .56637 L
.87368 .57565 L
.87812 .58073 L
.88029 .58322 L
Mistroke
.88228 .58549 L
.88318 .58652 L
.88417 .58743 L
.8851 .58792 L
.88597 .58837 L
.88993 .59044 L
.89836 .59485 L
.9055 .59857 L
.90925 .60053 L
.91129 .6016 L
.91321 .6026 L
.91419 .60311 L
.91474 .60328 L
.91524 .60314 L
.91747 .60252 L
.9214 .60143 L
.92911 .59929 L
.9361 .59735 L
.93992 .59629 L
.94352 .59529 L
.94437 .59506 L
.94527 .59481 L
.94626 .59366 L
.94717 .5925 L
.9512 .58739 L
.9583 .57836 L
.97438 .55794 L
.97619 .55564 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[158]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008_ooool3o`0000Cooooo0_l0000eooooo`?o0000=Oooool2o`0003Sooooo0ol0000eoooo
o`?o00001?ooool2o`0000gooooo000Sooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000<oooool01Ol0003ooooooooooooooooo000003?ooooo00Co0000oooooooooooo0000=_oo
ool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000<ooooo`006oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000]ooooo`Go00001Oooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`00
03[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000cooooo000Sooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=oooool0
0ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000cooooo000Sooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000<oooool4o`0003Cooooo00Co0000oooooooooooo
0000=_ooool4o`0003Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000<oooo
o`008_ooool2o`0000Cooooo00Co0000oooooooooooo0000<oooool00ol0003oooooooooo`0eoooo
o`04o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool0=_ooool2o`0000Cooooo00Co0000
oooooooooooo00003?ooool002?ooooo00?o0000ooooooooool00oooool2o`0003Cooooo1Ol0000d
ooooo`;o0000=oooool5o`0003Gooooo00?o0000ooooooooool00oooool2o`0000gooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000NooooooSo00002_ooool0
01Oooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001Ko
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool2o`00
07Gooooo2_l0001eooooo`;o00002_ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1booooo`Co00000_ooool01?l0003oooooooooooooool4o`0007Cooooo00?o0000
ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1`
ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`?o0000LOooool00ol0003oooooooooo`08
ooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06cooooo1?l00008
ooooo`03o`000?oooooooooo00Sooooo0_l0001_ooooo`03o`000?oooooooooo00Sooooo000Goooo
o`;o00001Oooool00ol0003oooooooooo`1/ooooo`;o00002_ooool00ol0003oooooooooo`08oooo
o`?o0000K_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0006_ooooo0_l0000<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo06Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0J?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0JOoo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool2o`0006Wooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool0IOooool2o`00017ooooo00?o0000ooooooooool04?ooool2o`00
06Oooooo00?o0000ooooooooool02?ooool001kooooo0_l0001Vooooo`;o00004Oooool00ol0003o
ooooooooo`0@ooooo`;o0000I_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00Sooooo000Noooo
o`;o0000Hoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0HOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo05gooooo0ol0000Hooooo`03o`000?oooooooooo01Oooooo0_l0001Pooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o0000G_ooool2o`0001Wooooo00?o0000ooooooooool05oooool2o`00
05oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00So
oooo000;ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool02?ooool000[ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo05_ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`02ooooo`;o0000Foooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0FOooool2o`0000[ooooo000:ooooo`04o`00
0?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool02?ooool000[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool02?ooool000_ooooo0_l00008ooooo`Go0000
1?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000F?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Eooo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0000Pooooo`03o`000?oooooo
oooo01oooooo0_l0001Hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
05Kooooo0_l0000Pooooo`03o`000?oooooooooo01oooooo0_l0001Hooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`007_ooool2o`0005Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05Cooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`08ooooo`007_ooool2o`0005?ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo057ooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00So
oooo000Nooooo`;o0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0C_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0
000Xooooo`03o`000?oooooooooo02Oooooo0_l0001@ooooo`03o`000?oooooooooo00Sooooo000F
ooooo`?o00001Oooool00ol0003oooooooooo`1>ooooo`;o0000:?ooool00ol0003oooooooooo`0W
ooooo`;o0000D?ooool00ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool02?ooool001Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Sooooo000Gooooo`03o`00
0?oooooooooo00Cooooo0_l0001>ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`1<ooooo`;o00002_ooool001Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo000Fooooo`;o00001_ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo000Gooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`08ooooo`007_ooool2o`0004co
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[o
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`;o0000BOooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0B?ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0Aooo
ool2o`0002oooooo00?o0000ooooooooool0;_ooool2o`0004Wooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool0Aoooool2o`0002oooooo00?o0000ooooooooool0;_ooool2
o`0004Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`08ooooo`007_ooool2o`0004Oooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo04Gooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`08
ooooo`007_ooool2o`0004Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo04?ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
2?ooool000[ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool01oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`08ooooo`002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l00013
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11
ooooo`;o00002_ooool000_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000oooooooo
ool01oooool4o`0000Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`08ooooo`00
2_ooool2o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`03o`000?oo
oooooooo03oooooo0_l0000gooooo`03o`000?oooooooooo03Kooooo0_l00011ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`;o0000@?ooool2o`0003Oooooo00?o0000ooooooooool0=_ooool2
o`00043ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0003oooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03cooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`;o0000?Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0>_ooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?ooool001kooooo0_l0
000jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0gooooo`;o00002_ooool001kooooo00?o0000ooooooooool0=oooool3o`0003kooooo00?o0000
ooooooooool0?Oooool2o`0003[ooooo00?o0000ooooooooool02?ooool001Gooooo1Ol00004oooo
o`03o`000?oooooooooo03Oooooo0_l0000oooooo`03o`000?oooooooooo03gooooo0ol0000ioooo
o`03o`000?oooooooooo00Sooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04ooooo`;o
0000>?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0=Oooool2o`0000[ooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`08ooooo`005Oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`005Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`08ooooo`005_oo
ool3o`0000Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`08ooooo`007_ooool2
o`0003Kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo03?ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000=?ooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0<Oooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000
A_ooool00ol0003oooooooooo`15ooooo`;o0000<_ooool00ol0003oooooooooo`08ooooo`007_oo
ool2o`00037ooooo0_l00016ooooo`03o`000?oooooooooo04Gooooo0_l0000aooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0002oooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo02gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`?o00001Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`;o0000;Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0:_ooool2o`0000[ooooo000<ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00So
oooo0009ooooo`05o`000?ooooooooooooooool000001oooool4o`0000Gooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`08ooooo`002Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00So
oooo000:ooooo`?o00002?ooool5o`0000Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0002Wooooo0_l0001>ooooo`03o`000?oooooooooo04cooooo0_l0
000Zooooo`;o00002_ooool001kooooo00?o0000ooooooooool0:?ooool2o`0004kooooo00?o0000
ooooooooool0C?ooool3o`0002[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
2?ooool001kooooo0_l0000Wooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Uooooo`;o00002_ooool001kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool001kooooo
0_l0000Tooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`0Rooooo`;o00002_ooool001kooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo027ooooo0_l0001Eooooo`03o`000?oooooooooo05Cooooo0_l0000Soooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`;o
0000EOooool00ol0003oooooooooo`1Dooooo`;o00007?ooool2o`0000Gooooo00?o0000oooooooo
ool02?ooool001kooooo0_l00003ooooo`;o00007?ooool00ol0003oooooooooo`1Eooooo`03o`00
0?oooooooooo05Kooooo00?o0000ooooooooool06Oooool2o`0000Cooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`005_ooool3o`0000Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
01Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001Oooooo0_l00005ooooo`;o
00002?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`00
6Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3_ooool2o`0005gooooo00?o0000ooooooooool0Foooool3o`00013ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`005Oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`;o0000GOooool00ol0003ooooo
ooooo`1Looooo`;o00003oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
000Fooooo`?o00001Oooool00ol0003oooooooooo`0:ooooo`;o00002oooool2o`0005oooooo00?o
0000ooooooooool0G_ooool2o`0000_ooooo0_l0000<ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`;o00002oooool4o`0000Oooooo0_l0001Qooooo`03o`000?oooooooooo063ooooo0_l00007
ooooo`Co00002oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00kooooo1ol0001Soooo
o`03o`000?oooooooooo06;ooooo0ol000001?oooooo0000o`000?l0000@ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0001Uooooo`03o`000?oooooooooo
06?ooooo0ol0000Cooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo07So
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo000NooooooSo00002_ooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool0033ooooo0ol0002:ooooo`03o`000?oooooooooo02_ooooo
0ol0000Eooooo`03o`000?oooooooooo01[ooooo000aooooo`03o`000?oooooooooo08Sooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo000[
ooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000?ooooo1?l00000
0ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co00000oooool2o`0000;ooooo1_l00006
ooooo`Co00000_ooool5o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol00002
ooooo`?o00000_ooool3o`0000Cooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo0ol0
0003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo1?l0
0003ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00000_ooool3o`0000;ooooo0ol0
00001?oooooo0000o`000?ooool4o`0000?ooooo0_l00002ooooo`[o00001Oooool00ol0003ooooo
ooooo`0Hooooo`00:_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`00:_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`03o`000?oooooooooo
00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5o`0000Sooooo00?o
0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`03o`00
0?oooooo000000;ooooo1Ol00003ooooo`04o`000?ooooooooooooooo`Go00000_ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00002ooooo`?o00001Oooool00ol0003oooooooooo`0Hooooo`00:_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Gooooo00Ko0000oooo
oooooooo0000ooooool00008ooooo`03o`000?oooooooooo01Sooooo000Zooooo`06o`000?oooooo
ooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol00003ooooo`;o0000
1Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co
00000oooool3o`0000Wooooo00Go0000oooooooooooo0000ooooo`03o`0000Cooooo1?l00002oooo
o`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`00
00?ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`Ko000000?oooooo`00
0?l000000oooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`03o`000?oooooooooo
00;ooooo0ol00002ooooo`Co00000oooool9o`0000?ooooo0ol00003ooooo`Co00001?ooool00ol0
003oooooooooo`0Hooooo`00:_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06Oooool002_ooooo0ol00009ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03Oooool3o`0000Wooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo0_l0000:
ooooo`Co00001?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool2o`0002kooooo00?o0000
ooooooooool06?ooool3o`0001Kooooo00?o0000ooooooooool00_ooool2o`0000_ooooo00?o0000
ooooooooool06_ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.1028, -0.338383, \
0.0850929, 0.0215154}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] 0.49966958432041564`\), 
        ",", \(BackFocalLength \[Rule] 93.35095557506479`\), 
        ",", \(BackFocalPoint \[Rule] {103.35095557506479`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] 0\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {0, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.583004929987583`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {3.416995070012417`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 1\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 1, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FindPupils \[Rule] True\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 99.93396050505237`\), 
        ",", \(FrontFocalLength \[Rule] 99.93396050505234`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-99.93396050505234`\), 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {102.50971221923828`, 0, 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(PlanoConvexLens[100, 50, 10]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[Screen[1], {103 + d, 103.`}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.9341264481391712`, 
              6.583004929987581`}, {\(-0.010006608313591684`\), 
              0.9999999999999998`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(Move[LineOfRays[20], {\(-50.`\), {y, 0}}]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 58.62342258649551`\), ",", 
        RowBox[{"OpticalLengthFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-10.015327705855315`\), 
                  10.015327705855315`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-10.015327705855315`\), 
                  10.015327705855315`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {58.62342258649551`, 
            58.62508781772297`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(ParaxialReductionRatio \[Rule] 0.002`\), 
        ",", \(Plot2D \[Rule] True\), ",", \(PlotPoints \[Rule] 32\), 
        ",", \(PrinciplePoints \[Rule] {{2.842170943040401`*^-14, 0, 
              0}, {3.416995070012419`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 3.4169950700123906`\), 
        ",", \(RayBoundary \[Rule] {\(-10.015327705855315`\), 
            10.015327705855315`}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] True\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 17849\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{0.003511874975144755`, 
              99.75859867874478`}, {\(-0.010006608313591682`\), 
              0.49966958432041564`}}\), 
        ",", \(TransverseMagnification \[Rule] 0.003511874975144755`\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-12.445282539239507`\), 
                  12.354576541926033`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[158]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["PupilFunction[sys3D]", "Input",
  CellLabel->"In[159]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0563098 -1.06488 5.06218 [
[.07768 -0.0125 -12 -9 ]
[.07768 -0.0125 12 0 ]
[.21845 -0.0125 -6 -9 ]
[.21845 -0.0125 6 0 ]
[.35923 -0.0125 -12 -9 ]
[.35923 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64077 -0.0125 -9 -9 ]
[.64077 -0.0125 9 0 ]
[.78155 -0.0125 -3 -9 ]
[.78155 -0.0125 3 0 ]
[.92232 -0.0125 -9 -9 ]
[.92232 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0488 -24 -4.5 ]
[-0.0125 .0488 0 4.5 ]
[-0.0125 .15004 -24 -4.5 ]
[-0.0125 .15004 0 4.5 ]
[-0.0125 .25129 -24 -4.5 ]
[-0.0125 .25129 0 4.5 ]
[-0.0125 .35253 -24 -4.5 ]
[-0.0125 .35253 0 4.5 ]
[-0.0125 .45377 -18 -4.5 ]
[-0.0125 .45377 0 4.5 ]
[-0.0125 .55502 -24 -4.5 ]
[-0.0125 .55502 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -60 0 ]
[.5 .63053 60 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07768 0 m
.07768 .00625 L
s
[(-7.5)] .07768 -0.0125 0 1 Mshowa
.21845 0 m
.21845 .00625 L
s
[(-5)] .21845 -0.0125 0 1 Mshowa
.35923 0 m
.35923 .00625 L
s
[(-2.5)] .35923 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64077 0 m
.64077 .00625 L
s
[(2.5)] .64077 -0.0125 0 1 Mshowa
.78155 0 m
.78155 .00625 L
s
[(5)] .78155 -0.0125 0 1 Mshowa
.92232 0 m
.92232 .00625 L
s
[(7.5)] .92232 -0.0125 0 1 Mshowa
.125 Mabswid
.10583 0 m
.10583 .00375 L
s
.13399 0 m
.13399 .00375 L
s
.16214 0 m
.16214 .00375 L
s
.1903 0 m
.1903 .00375 L
s
.24661 0 m
.24661 .00375 L
s
.27476 0 m
.27476 .00375 L
s
.30292 0 m
.30292 .00375 L
s
.33107 0 m
.33107 .00375 L
s
.38738 0 m
.38738 .00375 L
s
.41554 0 m
.41554 .00375 L
s
.44369 0 m
.44369 .00375 L
s
.47185 0 m
.47185 .00375 L
s
.52815 0 m
.52815 .00375 L
s
.55631 0 m
.55631 .00375 L
s
.58446 0 m
.58446 .00375 L
s
.61262 0 m
.61262 .00375 L
s
.66893 0 m
.66893 .00375 L
s
.69708 0 m
.69708 .00375 L
s
.72524 0 m
.72524 .00375 L
s
.75339 0 m
.75339 .00375 L
s
.8097 0 m
.8097 .00375 L
s
.83786 0 m
.83786 .00375 L
s
.86601 0 m
.86601 .00375 L
s
.89417 0 m
.89417 .00375 L
s
.04952 0 m
.04952 .00375 L
s
.02137 0 m
.02137 .00375 L
s
.95048 0 m
.95048 .00375 L
s
.97863 0 m
.97863 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0488 m
.00625 .0488 L
s
[(0.22)] -0.0125 .0488 1 0 Mshowa
0 .15004 m
.00625 .15004 L
s
[(0.24)] -0.0125 .15004 1 0 Mshowa
0 .25129 m
.00625 .25129 L
s
[(0.26)] -0.0125 .25129 1 0 Mshowa
0 .35253 m
.00625 .35253 L
s
[(0.28)] -0.0125 .35253 1 0 Mshowa
0 .45377 m
.00625 .45377 L
s
[(0.3)] -0.0125 .45377 1 0 Mshowa
0 .55502 m
.00625 .55502 L
s
[(0.32)] -0.0125 .55502 1 0 Mshowa
.125 Mabswid
0 .07411 m
.00375 .07411 L
s
0 .09942 m
.00375 .09942 L
s
0 .12473 m
.00375 .12473 L
s
0 .17535 m
.00375 .17535 L
s
0 .20066 m
.00375 .20066 L
s
0 .22598 m
.00375 .22598 L
s
0 .2766 m
.00375 .2766 L
s
0 .30191 m
.00375 .30191 L
s
0 .32722 m
.00375 .32722 L
s
0 .37784 m
.00375 .37784 L
s
0 .40315 m
.00375 .40315 L
s
0 .42846 m
.00375 .42846 L
s
0 .47908 m
.00375 .47908 L
s
0 .5044 m
.00375 .5044 L
s
0 .52971 m
.00375 .52971 L
s
0 .02349 m
.00375 .02349 L
s
0 .58033 m
.00375 .58033 L
s
0 .60564 m
.00375 .60564 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07768 .61178 m
.07768 .61803 L
s
.21845 .61178 m
.21845 .61803 L
s
.35923 .61178 m
.35923 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64077 .61178 m
.64077 .61803 L
s
.78155 .61178 m
.78155 .61803 L
s
.92232 .61178 m
.92232 .61803 L
s
.125 Mabswid
.10583 .61428 m
.10583 .61803 L
s
.13399 .61428 m
.13399 .61803 L
s
.16214 .61428 m
.16214 .61803 L
s
.1903 .61428 m
.1903 .61803 L
s
.24661 .61428 m
.24661 .61803 L
s
.27476 .61428 m
.27476 .61803 L
s
.30292 .61428 m
.30292 .61803 L
s
.33107 .61428 m
.33107 .61803 L
s
.38738 .61428 m
.38738 .61803 L
s
.41554 .61428 m
.41554 .61803 L
s
.44369 .61428 m
.44369 .61803 L
s
.47185 .61428 m
.47185 .61803 L
s
.52815 .61428 m
.52815 .61803 L
s
.55631 .61428 m
.55631 .61803 L
s
.58446 .61428 m
.58446 .61803 L
s
.61262 .61428 m
.61262 .61803 L
s
.66893 .61428 m
.66893 .61803 L
s
.69708 .61428 m
.69708 .61803 L
s
.72524 .61428 m
.72524 .61803 L
s
.75339 .61428 m
.75339 .61803 L
s
.8097 .61428 m
.8097 .61803 L
s
.83786 .61428 m
.83786 .61803 L
s
.86601 .61428 m
.86601 .61803 L
s
.89417 .61428 m
.89417 .61803 L
s
.04952 .61428 m
.04952 .61803 L
s
.02137 .61428 m
.02137 .61803 L
s
.95048 .61428 m
.95048 .61803 L
s
.97863 .61428 m
.97863 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0488 m
1 .0488 L
s
.99375 .15004 m
1 .15004 L
s
.99375 .25129 m
1 .25129 L
s
.99375 .35253 m
1 .35253 L
s
.99375 .45377 m
1 .45377 L
s
.99375 .55502 m
1 .55502 L
s
.125 Mabswid
.99625 .07411 m
1 .07411 L
s
.99625 .09942 m
1 .09942 L
s
.99625 .12473 m
1 .12473 L
s
.99625 .17535 m
1 .17535 L
s
.99625 .20066 m
1 .20066 L
s
.99625 .22598 m
1 .22598 L
s
.99625 .2766 m
1 .2766 L
s
.99625 .30191 m
1 .30191 L
s
.99625 .32722 m
1 .32722 L
s
.99625 .37784 m
1 .37784 L
s
.99625 .40315 m
1 .40315 L
s
.99625 .42846 m
1 .42846 L
s
.99625 .47908 m
1 .47908 L
s
.99625 .5044 m
1 .5044 L
s
.99625 .52971 m
1 .52971 L
s
.99625 .02349 m
1 .02349 L
s
.99625 .58033 m
1 .58033 L
s
.99625 .60564 m
1 .60564 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Wave Front Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.03837 .23 L
.05372 .39953 L
.05761 .43698 L
.06178 .46525 L
.06929 .50784 L
.07149 .52033 L
.07265 .52691 L
.07328 .53051 L
.07388 .53388 L
.0744 .53571 L
.07495 .53729 L
.07613 .54064 L
.07822 .54655 L
.08243 .55851 L
.08634 .56961 L
.08829 .57514 L
.08925 .57781 L
.09013 .57885 L
.09114 .58006 L
.09224 .58136 L
.09416 .58363 L
.09824 .58845 L
.10039 .59101 L
.1027 .59375 L
.10375 .59499 L
.10475 .59592 L
.10564 .59628 L
.10661 .59668 L
.11027 .59815 L
.11439 .59981 L
.11641 .60063 L
.11826 .60137 L
.11914 .60173 L
.11996 .60196 L
.12082 .60204 L
.12176 .60212 L
.12553 .60246 L
.12974 .60283 L
.13173 .603 L
.13357 .60317 L
.13451 .60325 L
.13551 .60328 L
.13651 .60327 L
.13761 .60326 L
.14143 .60322 L
.14574 .60319 L
.14786 .60317 L
.14889 .60316 L
.14983 .60315 L
Mistroke
.15077 .60312 L
.15165 .60309 L
.15359 .60301 L
.1577 .60284 L
.16489 .60256 L
.18106 .6019 L
.21095 .60069 L
.24273 .59953 L
.27334 .59855 L
.30278 .59774 L
.33412 .59699 L
.36428 .5964 L
.39634 .59589 L
.40413 .59576 L
.40619 .59572 L
.40726 .5957 L
.40785 .59569 L
.4084 .59569 L
.4094 .59568 L
.40992 .59567 L
.41049 .59567 L
.4124 .59565 L
.41945 .5956 L
.42723 .59553 L
.45695 .5953 L
.4649 .59522 L
.46707 .5952 L
.46827 .59519 L
.46885 .59519 L
.46938 .59518 L
.47033 .59518 L
.47134 .59518 L
.4735 .59518 L
.47734 .59518 L
.47936 .59519 L
.48152 .59519 L
.48339 .59519 L
.4839 .59519 L
.48446 .59519 L
.48546 .59518 L
.48639 .59518 L
.48737 .59517 L
.48911 .59516 L
.49649 .59512 L
.49751 .59512 L
.49862 .59511 L
.49912 .59511 L
.49966 .59511 L
.50062 .59511 L
.50155 .59511 L
Mistroke
.50241 .59511 L
.50438 .59512 L
.51123 .59515 L
.5132 .59516 L
.51417 .59517 L
.51507 .59517 L
.51589 .59517 L
.51676 .59517 L
.51859 .59517 L
.52247 .59516 L
.52656 .59515 L
.5287 .59515 L
.52929 .59515 L
.52992 .59515 L
.53051 .59515 L
.53105 .59515 L
.53518 .59518 L
.5508 .59528 L
.55481 .59529 L
.55858 .5953 L
.5595 .5953 L
.56047 .5953 L
.56098 .5953 L
.56153 .59531 L
.5625 .59532 L
.56684 .59538 L
.58166 .59552 L
.61135 .59587 L
.64277 .59638 L
.67302 .59697 L
.70516 .59773 L
.73613 .5986 L
.76592 .59955 L
.79762 .6007 L
.82814 .60195 L
.84348 .60259 L
.85749 .60308 L
.86119 .6032 L
.86314 .60326 L
.86421 .60329 L
.86522 .60332 L
.86618 .6033 L
.86722 .60327 L
.86903 .60323 L
.87255 .60316 L
.87666 .60307 L
.87872 .60302 L
.87929 .60301 L
.8799 .60299 L
.88047 .60296 L
Mistroke
.88099 .60286 L
.88873 .60136 L
.89247 .60063 L
.89436 .60026 L
.89487 .60016 L
.89543 .60005 L
.89644 .59943 L
.90355 .59457 L
.90561 .59316 L
.90785 .59162 L
.90888 .59092 L
.90998 .59017 L
.91051 .58981 L
.91101 .5892 L
.91195 .5875 L
.91964 .57355 L
.92354 .56646 L
.92452 .56469 L
.92545 .563 L
.92628 .56086 L
.92719 .55725 L
.92903 .54992 L
.931 .54206 L
.93517 .5254 L
.93877 .51103 L
.9426 .49104 L
.94947 .44027 L
.96325 .30971 L
.97619 .14194 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[159]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Joooo
o`?o00006Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo0_l0000Ioooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006_ooool3o`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00005?ooool0033ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00000I
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`00
0?ooooooooooo`0001Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Sooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Cooooo`00:?ooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003oooooooooo`0@ooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo000aooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04Oooool003;ooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo1?l0000Iooooo`05o`000?ooooooooooooooool000001oooool4o`0001Kooooo
00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Ioooo
o`Co00007Oooool00ol0003oooooooooo`05ooooo`Co00005?ooool002kooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
000Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Go
oooo000^ooooo`Go00001oooool5o`0001Sooooo1Ol0000Iooooo`?o00002?ooool5o`0001Kooooo
0_l0000Jooooo`?o00002?ooool5o`0001Sooooo1Ol0000Hooooo`Go00001oooool5o`0001?ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000QooooooSo0000
1oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001?ooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo07Sooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol000000ooooooo0000o`000003o`00
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Ooo
ool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool0N?ooool2o`0000Oooooo0007ooooo`04o`000?oooooo
ooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00007ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool01Oooool000Sooooo0_l00009ooooo`?o00000oooool3o`0000Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
1Oooool0027ooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0N?oo
ool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001Oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo07Sooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool2o`00
00Kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1hooooo`;o00001oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool01Oooool000Sooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00000ooo
ool3o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00009ooooo`04o`00
0?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo0007ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000000oooool2o`0000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool0027ooooo0_l00006ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00001oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`00
8Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001ooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool00ooo
ool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`;o00001oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool01?ooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`002?oo
ool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00009oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`04o`0000Gooooo0_l00008ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`04ooooo`;o00001oooool000Oooooo00Co0000oooo
oooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Wooooo0ol00004ooooo`;o0000
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`008Oooool2o`0000Sooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`008Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo0_l00009ooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05ooooo`;o
00001oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo0_l0
0009ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`05ooooo`;o00001oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0008ooooo`;o
00001?ooool01?l0003oooooooooooooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool0000:ooooo`04o`00
0?ooooooooooooooo`?o00001Oooool2o`0000[ooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`001oooool01?l0003ooooo
ooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`001oooool01?l0
003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`002?oo
ool2o`0000Wooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`008Oooool2o`0000[o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oo
oooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool0027ooooo0_l0000;ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`07ooooo`;o00001oooool0027ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo06_ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01Oooool0027ooooo0_l0000<ooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`08ooooo`;o00001oooool0027ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool000gooooo
00Co0000oooooooooooo00002Oooool2o`0000Gooooo0_l0000=ooooo`03o`000?oooooooooo06Wo
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`09ooooo`;o00001oooool000gooooo
00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05oooo
o`003_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0K?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00003_ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool02Oooool2
o`0000Oooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05
ooooo`008Oooool2o`0000oooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo00_ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1Oooool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`008Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`05ooooo`008Oooool2o`00013ooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`1Yooooo`03o`000?oooooooooo00cooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00002oooo
o`Go00001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`001oooool0
1?l0003oooooooooool0000;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo
0_l00005ooooo`03o`000?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0>ooooo`;o00001oooool000Oooooo00Co
0000oooooooooooo00002oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003ooooooooo
ool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
06Kooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo0008ooooo`;o00002Oooool3o`0000?o
oooo0ol00005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00005?ooool2o`0006?ooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0Aooooo`;o00001oooool0027ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`1Rooooo`;o00005Oooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0Gooooo`;o0000:ooooom/o`0002_ooooo0_l0000Gooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Wooooo0ol0000<oooooaco0000=?ooool0
0ol0003oooooooooo`0eoooooago00002oooool3o`0001Wooooo00?o0000ooooooooool01Oooool0
027ooooo0_l0000Mooooo`co0000D?ooool00ol0003oooooooooo`1Booooo`_o00006oooool2o`00
00Oooooo000Qooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`05ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`008Ooooooho`0000Oooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003Booooo`?o0000Boooool00=?ooooo00?o
0000ooooooooool0B_ooool0067ooooo00?o0000ooooool000000oooool4o`0000?ooooo00?o0000
ooooooooool00_ooool3o`0000Sooooo0ol00003ooooo`?o00001?ooool3o`0000;ooooo0ol00000
0ooooooo0000o`000002ooooo`;o00002?ooool5o`000005ooooool0003o0000o`000?ooool00_l0
0002ooooo`;o00000oooool3o`0000;ooooo0ol000000ooooooo0000o`000004o`0000;ooooo1Ol0
0003ooooo`;o00001?ooool00ol0003oooooooooo`19ooooo`00HOooool00ol0003oooooo`000002
ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Ko
oooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`19ooooo`00HOooool00ol0003oooooo`000003
ooooo`?o00000oooool00ol0003oooooo`000002ooooo`Go00002?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooo
oooo00000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000004[ooooo001Pooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool0
00002?ooool3o`0000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool00000B_ooool0063ooooo00Go0000ooooool0
003oooooo`000002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0ol00009oooo
o`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`00
00;ooooo1?l0000:ooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`0000?ooooo0ol00002
ooooo`Co00000oooool4o`000004ooooool0003o0000o`0000?ooooo1?l00002ooooo`;o000000?o
ooooo`000?l00000BOooool0063ooooo00Go0000ooooool0003oooooo`00000Jooooo`04o`000?oo
ooooooooo`0001Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0D?ooool0063ooooo1_l0000Hooooo`Go00005?oo
ool00ol0003oooooooooo`08ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0D?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.2791, 0.200697, \
0.0718497, 0.00079923}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0563098 0.602751 0.0617029 [
[.07768 -0.0125 -12 -9 ]
[.07768 -0.0125 12 0 ]
[.21845 -0.0125 -6 -9 ]
[.21845 -0.0125 6 0 ]
[.35923 -0.0125 -12 -9 ]
[.35923 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64077 -0.0125 -9 -9 ]
[.64077 -0.0125 9 0 ]
[.78155 -0.0125 -3 -9 ]
[.78155 -0.0125 3 0 ]
[.92232 -0.0125 -9 -9 ]
[.92232 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10913 -12 -4.5 ]
[-0.0125 .10913 0 4.5 ]
[-0.0125 .23253 -12 -4.5 ]
[-0.0125 .23253 0 4.5 ]
[-0.0125 .35594 -12 -4.5 ]
[-0.0125 .35594 0 4.5 ]
[-0.0125 .47934 -12 -4.5 ]
[-0.0125 .47934 0 4.5 ]
[-0.0125 .60275 -6 -4.5 ]
[-0.0125 .60275 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07768 0 m
.07768 .00625 L
s
[(-7.5)] .07768 -0.0125 0 1 Mshowa
.21845 0 m
.21845 .00625 L
s
[(-5)] .21845 -0.0125 0 1 Mshowa
.35923 0 m
.35923 .00625 L
s
[(-2.5)] .35923 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64077 0 m
.64077 .00625 L
s
[(2.5)] .64077 -0.0125 0 1 Mshowa
.78155 0 m
.78155 .00625 L
s
[(5)] .78155 -0.0125 0 1 Mshowa
.92232 0 m
.92232 .00625 L
s
[(7.5)] .92232 -0.0125 0 1 Mshowa
.125 Mabswid
.10583 0 m
.10583 .00375 L
s
.13399 0 m
.13399 .00375 L
s
.16214 0 m
.16214 .00375 L
s
.1903 0 m
.1903 .00375 L
s
.24661 0 m
.24661 .00375 L
s
.27476 0 m
.27476 .00375 L
s
.30292 0 m
.30292 .00375 L
s
.33107 0 m
.33107 .00375 L
s
.38738 0 m
.38738 .00375 L
s
.41554 0 m
.41554 .00375 L
s
.44369 0 m
.44369 .00375 L
s
.47185 0 m
.47185 .00375 L
s
.52815 0 m
.52815 .00375 L
s
.55631 0 m
.55631 .00375 L
s
.58446 0 m
.58446 .00375 L
s
.61262 0 m
.61262 .00375 L
s
.66893 0 m
.66893 .00375 L
s
.69708 0 m
.69708 .00375 L
s
.72524 0 m
.72524 .00375 L
s
.75339 0 m
.75339 .00375 L
s
.8097 0 m
.8097 .00375 L
s
.83786 0 m
.83786 .00375 L
s
.86601 0 m
.86601 .00375 L
s
.89417 0 m
.89417 .00375 L
s
.04952 0 m
.04952 .00375 L
s
.02137 0 m
.02137 .00375 L
s
.95048 0 m
.95048 .00375 L
s
.97863 0 m
.97863 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10913 m
.00625 .10913 L
s
[(-8)] -0.0125 .10913 1 0 Mshowa
0 .23253 m
.00625 .23253 L
s
[(-6)] -0.0125 .23253 1 0 Mshowa
0 .35594 m
.00625 .35594 L
s
[(-4)] -0.0125 .35594 1 0 Mshowa
0 .47934 m
.00625 .47934 L
s
[(-2)] -0.0125 .47934 1 0 Mshowa
0 .60275 m
.00625 .60275 L
s
[(0)] -0.0125 .60275 1 0 Mshowa
.125 Mabswid
0 .13998 m
.00375 .13998 L
s
0 .17083 m
.00375 .17083 L
s
0 .20168 m
.00375 .20168 L
s
0 .26338 m
.00375 .26338 L
s
0 .29424 m
.00375 .29424 L
s
0 .32509 m
.00375 .32509 L
s
0 .38679 m
.00375 .38679 L
s
0 .41764 m
.00375 .41764 L
s
0 .44849 m
.00375 .44849 L
s
0 .5102 m
.00375 .5102 L
s
0 .54105 m
.00375 .54105 L
s
0 .5719 m
.00375 .5719 L
s
0 .07828 m
.00375 .07828 L
s
0 .04742 m
.00375 .04742 L
s
0 .01657 m
.00375 .01657 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07768 .61178 m
.07768 .61803 L
s
.21845 .61178 m
.21845 .61803 L
s
.35923 .61178 m
.35923 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64077 .61178 m
.64077 .61803 L
s
.78155 .61178 m
.78155 .61803 L
s
.92232 .61178 m
.92232 .61803 L
s
.125 Mabswid
.10583 .61428 m
.10583 .61803 L
s
.13399 .61428 m
.13399 .61803 L
s
.16214 .61428 m
.16214 .61803 L
s
.1903 .61428 m
.1903 .61803 L
s
.24661 .61428 m
.24661 .61803 L
s
.27476 .61428 m
.27476 .61803 L
s
.30292 .61428 m
.30292 .61803 L
s
.33107 .61428 m
.33107 .61803 L
s
.38738 .61428 m
.38738 .61803 L
s
.41554 .61428 m
.41554 .61803 L
s
.44369 .61428 m
.44369 .61803 L
s
.47185 .61428 m
.47185 .61803 L
s
.52815 .61428 m
.52815 .61803 L
s
.55631 .61428 m
.55631 .61803 L
s
.58446 .61428 m
.58446 .61803 L
s
.61262 .61428 m
.61262 .61803 L
s
.66893 .61428 m
.66893 .61803 L
s
.69708 .61428 m
.69708 .61803 L
s
.72524 .61428 m
.72524 .61803 L
s
.75339 .61428 m
.75339 .61803 L
s
.8097 .61428 m
.8097 .61803 L
s
.83786 .61428 m
.83786 .61803 L
s
.86601 .61428 m
.86601 .61803 L
s
.89417 .61428 m
.89417 .61803 L
s
.04952 .61428 m
.04952 .61803 L
s
.02137 .61428 m
.02137 .61803 L
s
.95048 .61428 m
.95048 .61803 L
s
.97863 .61428 m
.97863 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .10913 m
1 .10913 L
s
.99375 .23253 m
1 .23253 L
s
.99375 .35594 m
1 .35594 L
s
.99375 .47934 m
1 .47934 L
s
.99375 .60275 m
1 .60275 L
s
.125 Mabswid
.99625 .13998 m
1 .13998 L
s
.99625 .17083 m
1 .17083 L
s
.99625 .20168 m
1 .20168 L
s
.99625 .26338 m
1 .26338 L
s
.99625 .29424 m
1 .29424 L
s
.99625 .32509 m
1 .32509 L
s
.99625 .38679 m
1 .38679 L
s
.99625 .41764 m
1 .41764 L
s
.99625 .44849 m
1 .44849 L
s
.99625 .5102 m
1 .5102 L
s
.99625 .54105 m
1 .54105 L
s
.99625 .5719 m
1 .5719 L
s
.99625 .07828 m
1 .07828 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01657 m
1 .01657 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.05372 .12043 L
.08634 .21815 L
.11698 .2952 L
.14644 .3575 L
.1778 .41271 L
.20799 .45646 L
.24008 .4943 L
.27099 .52354 L
.30073 .54601 L
.33237 .56476 L
.36283 .57856 L
.39213 .58852 L
.40841 .59282 L
.42332 .59605 L
.43888 .59875 L
.45333 .60067 L
.46803 .60209 L
.4758 .60261 L
.48011 .60284 L
.48408 .60301 L
.48795 .60314 L
.48992 .6032 L
.49204 .60324 L
.49315 .60326 L
.49416 .60328 L
.49519 .60329 L
.49614 .6033 L
.49725 .60331 L
.49784 .60331 L
.49846 .60332 L
.499 .60332 L
.4995 .60332 L
.50006 .60332 L
.50065 .60332 L
.50163 .60332 L
.50255 .60331 L
.50355 .6033 L
.50462 .60329 L
.50681 .60326 L
.5088 .60323 L
.51264 .60313 L
.51627 .603 L
.52379 .60264 L
.53176 .6021 L
.54605 .60074 L
.5612 .59873 L
.57538 .5963 L
.60544 .58921 L
.62183 .58415 L
Mistroke
.63739 .57848 L
.667 .56508 L
.69851 .54652 L
.72885 .52368 L
.76108 .49307 L
.79214 .45629 L
.82202 .41298 L
.85381 .35701 L
.88442 .29197 L
.91386 .2176 L
.94519 .12396 L
.97536 .01788 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[159]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Joooo
o`?o00006Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo0_l0000Ioooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006_ooool3o`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00006_ooool002[ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00000I
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`00
0?ooooooooooo`0001Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Sooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Iooooo`008_ooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003oooooooooo`0@ooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo000[ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool05oooool002cooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo1?l0000Iooooo`05o`000?ooooooooooooooool000001oooool4o`0001Kooooo
00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Ioooo
o`Co00007Oooool00ol0003oooooooooo`05ooooo`Co00006_ooool002Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
000Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01_o
oooo000Xooooo`Go00001oooool5o`0001Sooooo1Ol0000Iooooo`?o00002?ooool5o`0001Kooooo
0_l0000Jooooo`?o00002?ooool5o`0001Sooooo1Ol0000Hooooo`Go00001oooool5o`0001Wooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000KooooooSo0000
3Oooool001_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02oooool001_ooooo0_l00004ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00003Oooool001_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02oooool001_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02oooool001_ooooo0_l00006ooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`04ooooo`;o00003Ooo
ool001_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0;ooooo`006oooool2o`0000Sooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo0_l0000=ooooo`00
6oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00_ooooo000Cooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_o
oooo000Booooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo06cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00_ooooo000<ooooo`Go000000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool001?ooooo0ol0
0005ooooo`;o00002_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool02?ooool2o`0000gooooo000Booooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo000Booooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o
0000ooooooooool0K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo000C
ooooo`?o00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000
ooooooooool0K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1/oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`;o00003?ooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo06_ooooo00?o0000ooooooooool02_ooool2o`0000gooooo000Kooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1Zooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1Yooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Wo
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`1Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool001_ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0Ioooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02oooool001_ooooo0_l0000?ooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`0=ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool0
01_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02oooool001_ooooo0_l0000Aooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`0?ooooo`;o00003Oooool001_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo000Cooooo`?o00001Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo000Booooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo000<oooo
o`Go000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`;o00005?ooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04_ooool2o`00
00gooooo000Booooo`Co00001Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_o
oooo000Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0;ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool02oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool02oooool001_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02oooool001_ooooo0_l0000Gooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Eooooo`;o00003Ooo
ool001_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool001_ooooo0_l0000Joooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Hoooo
o`;o00003Oooool001_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`1Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`006oooool2o`0001kooooo00?o
0000ooooooooool0F?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01cooooo0_l0
000=ooooo`006oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Oooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo05Kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00_ooooo000Dooooo`?o00001?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo05Kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00_ooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0;ooooo`003?ooool5o`000003ooooool0003o000000?o00001?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0E_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00_ooooo000Booooo`04o`000?ooooooooooo`00
00Gooooo0_l0000Rooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`0Pooooo`;o00003Oooool001?ooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o00001Oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00_ooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool02oooool001_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo05;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0;ooooo`00
6oooool2o`0002Kooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo02Cooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo053ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02oooool0
01_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Koooo
o`;o0000:_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool0:?ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool001_ooooo0_l0
000`ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0^ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0;ooooo`004_ooool5o`0000Cooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool02oooool000cooooo1Ol00003ooooo`03o`000?oooooo
oooo00Cooooo0_l0000eooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0cooooo`;o00003Oooool001Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo000Booooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00_ooooo000Booooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
00_ooooo000Cooooo`?o00001Oooool00ol0003oooooooooo`0hooooo`;o0000?_ooool00ol0003o
ooooooooo`0mooooo`;o0000>_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0;
ooooo`006oooool2o`0003kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo03cooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool0@?ooool2o`0003Kooooo00?o0000ooooooooool0=Ooo
ool2o`0004;ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02oooool001_ooooo
0_l00016ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`14ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`17ooooo`;o0000;oooool00ol0003oooooooooo`0^
ooooo`;o0000BOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`19oooo
o`;o0000;Oooool00ol0003oooooooooo`0/ooooo`;o0000Boooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`1;ooooo`;o0000:oooool00ol0003oooooooooo`0Zooooo`;o
0000COooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1=ooooo`;o0000
:Oooool00ol0003oooooooooo`0Xooooo`;o0000Coooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`1?ooooo`;o00009oooool00ol0003oooooooooo`0Vooooo`;o0000DOoo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Aooooo`;o00009Oooool0
0ol0003oooooooooo`0Tooooo`;o0000Doooool00ol0003oooooooooo`0;ooooo`006oooool2o`00
05Cooooo0_l0000Sooooo`03o`000?oooooooooo02;ooooo0_l0001Dooooo`;o00003Oooool001_o
oooo00?o0000ooooooooool0EOooool2o`00027ooooo00?o0000ooooooooool08?ooool2o`0005Oo
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0Eoooool3o`0001kooooo
00?o0000ooooooooool07_ooool2o`0005Wooooo00?o0000ooooooooool02oooool001_ooooo00?o
0000ooooooooool0F_ooool3o`0001_ooooo00?o0000ooooooooool06_ooool4o`0005_ooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0GOooool4o`0001Oooooo00?o0000
ooooooooool05_ooool4o`0005oooooo00?o0000ooooooooool02oooool001Cooooo0_l00005oooo
o`03o`000?oooooooooo067ooooo1?l0000Cooooo`03o`000?oooooooooo01;ooooo1?l0001Soooo
o`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0IOooool4o`0000oooooo00?o0000ooooooooool03oooool3o`0006Oooooo00?o0000oooo
ooooool02oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Yoooo
o`[o00001Oooool00ol0003oooooooooo`04ooooo`_o0000J_ooool00ol0003oooooooooo`0;oooo
o`004oooool01?l0003oooooooooool00004ooooo`;o0000M?ooool<o`0007Cooooo0_l0000=oooo
o`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool0NOooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00_ooooo000Dooooo`;o00001Ooooooho`0000gooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo000]ooooo`?o0000R_ooool00ol0003oooooooooo`0[oooo
o`?o00005Oooool00ol0003oooooooooo`0Mooooo`00;_ooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Looooo`00
:?ooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003ooooo`Co0000
00?oooooo`000?l000000ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko0000
1_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o0000
0_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`?o
00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`Co
00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`?o
000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_ooool:o`0000Gooooo00?o0000oooo
ooooool06oooool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool002Oooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`0000Gooooo1Ol00008ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o00000oooool00ol0
003oooooo`000002ooooo`Go00000oooool01?l0003oooooooooooooool5o`0000;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00000_ooool3o`0000Gooooo00?o0000ooooooooool06oooool002Oooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00005ooooo`06o`000?oo
ooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`0Kooooo`009oooool01_l0003ooooo
oooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000oooool2o`00
00Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00002ooooo`;o00000oooool4
o`0000?ooooo0ol00009ooooo`05o`000?ooooooooooo`000?ooool00ol00004ooooo`Co00000_oo
ool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l0
0003ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00_ooool6o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o00000oooool4o`0000Cooooo00?o
0000ooooooooool06oooool002Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01cooooo000Xooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo0ol00009ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o0000
2_ooool4o`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0000^ooooo`03o`00
0?oooooooooo01Sooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000;ooooo`03o`00
0?oooooooooo01gooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.848, -10.5614, \
0.0718497, 0.0655698}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 5\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] False\), 
        ",", \(FindPupils \[Rule] True\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {208.`, 0.`, 0.`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 112.44620320200491`\), 
        ",", \(OpticalLengthFunction \[Rule] OpticalLengthFunction\), 
        ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          TagBox[\(CompiledFunction[
              If[#1 == 0 && #2 == 0, 
                0.009209855012944997`, \(-11.264683505117207`\) - 
                  3.4928810100798632`*^-9\ Cos[
                      2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                  1.927069336676206`*^-10\ Cos[
                      4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                  14.735634270869657`\ \((\(-1\) + 
                        0.013989456866883982`\ \((#1\^2 + #2\^2)\))\) - 
                  5.192913965285754`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.020984185300325975`\)\ \
\((#1\^2 + #2\^2)\) + 0.0001957049034304074`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  3.48243125803442`\ \((1 - 
                        0.04196837060065195`\ \((#1\^2 + #2\^2)\) + 
                        0.0002935573551456111`\ \((#1\^2 + #2\^2)\)\^2)\) + 
                  4.2201619160926165`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((\(-0.00024463112928800926`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 2.0533539788830346`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  3.3583450513275594`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((0.04196837060065195`\ \((#1\^2 + \
#2\^2)\) - 0.000978524517152037`\ \((#1\^2 + #2\^2)\)\^2 + 
                        5.133384947207587`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  0.020895062635046566`\ \((\(-1\) + 
                        0.0839367412013039`\ \((#1\^2 + #2\^2)\) - 
                        0.0014677867757280556`\ \((#1\^2 + #2\^2)\)\^2 + 
                        6.844513262943449`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  7.299818133179053`*^-8\ Cos[
                      6\ ArcTan[#1, #2]]\ \((\(-2.3955796420302074`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 1.9150204613352546`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  3.1429065958357665`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((0.0007338933878640278`\ \((#1\^2 \
+ #2\^2)\)\^2 - 0.000014373477852181243`\ \((#1\^2 + #2\^2)\)\^3 + 
                        6.702571614673391`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  1.2766741380438523`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.0699472843344199`\)\ \
\((#1\^2 + #2\^2)\) + 0.002935573551456111`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00003593369463045311`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.3405143229346782`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.00020471534013155693`\ \((1 - 
                        0.1398945686688398`\ \((#1\^2 + #2\^2)\) + 
                        0.004403360327184167`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.000047911592840604145`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.6756429036683477`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
              "-CompiledCode-"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {112.43069766768741`, 
            112.44620320200491`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(ParaxialReductionRatio \[Rule] 0.002`\), 
        ",", \(Plot2D \[Rule] True\), ",", \(PlotPoints \[Rule] 32\), 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(RayBoundary \[Rule] {{\(-8.456612676586712`\), 
              8.456612676586712`}, {\(-8.452840289871496`\), 
              8.452840289871496`}}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), 
        ",", \(ResidualFitError \[Rule] 7.230630203955897`*^-7\), 
        ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
              83.20322430145711`, 
            Astigmatism \[Rule] 0.000026554381242000656`, 
            FieldCurvature \[Rule] 17.31170436577689`, 
            Distortion \[Rule] 5.898318744074078`*^-13, 
            Coma \[Rule] \(-8.757302836470299`*^-13\)}\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 19474\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-11.347780623913327`\), 
                  11.347780623913327`}, {\(-11.34400823719811`\), 
                  11.34400823719811`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[159]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["PupilFunction[sys3D,Plot2D->False]", "Input",
  CellLabel->"In[161]:=",
  CellTags->{"AOG5.3", "AOG5.", "AOG0."}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.14863 .19854 -11.913 -9 ]
[.14863 .19854 .08697 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.53436 .04684 -5.21689 -9 ]
[.53436 .04684 .78311 0 ]
[.76879 .09909 0 -6.15987 ]
[.76879 .09909 12 2.84013 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93374 .35168 0 -5.92116 ]
[.93374 .35168 6 3.07884 ]
[.02105 .28428 -24 -2.75851 ]
[.02105 .28428 0 6.24149 ]
[.01243 .33834 -18 -2.80428 ]
[.01243 .33834 0 6.19572 ]
[.0035 .39433 -24 -2.85184 ]
[.0035 .39433 0 6.14816 ]
[-0.00576 .45234 -18 -2.9013 ]
[-0.00576 .45234 0 6.0987 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15784 .20788 m
.16245 .21255 L
s
[(-5)] .14863 .19854 .98551 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54215 .0574 m
.54605 .06267 L
s
[(5)] .53436 .04684 .73896 1 Mshowa
.125 Mabswid
.19385 .19378 m
.19658 .19662 L
s
.23036 .17949 m
.23305 .18236 L
s
.26739 .16498 m
.27005 .16789 L
s
.30496 .15028 m
.30757 .15322 L
s
.38172 .12022 m
.38425 .12323 L
s
.42095 .10486 m
.42343 .10791 L
s
.46076 .08927 m
.46319 .09236 L
s
.50115 .07345 m
.50354 .07658 L
s
.12234 .22178 m
.12513 .22455 L
s
.08732 .2355 m
.09015 .23823 L
s
.05278 .24902 m
.05564 .25172 L
s
.58378 .0411 m
.58606 .0443 L
s
.62603 .02455 m
.62826 .0278 L
s
.66893 .00776 m
.67111 .01103 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75648 .10363 m
.75033 .1059 L
s
[(-5)] .76879 .09909 -1 .36886 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92123 .35563 m
.91497 .3576 L
s
[(5)] .93374 .35168 -1 .31581 Mshowa
.125 Mabswid
.77494 .13186 m
.77124 .1332 L
s
.7929 .15934 m
.7892 .16066 L
s
.81041 .18611 m
.80669 .18742 L
s
.82746 .21219 m
.82374 .21348 L
s
.86028 .2624 m
.85654 .26365 L
s
.87608 .28657 m
.87234 .2878 L
s
.8915 .31015 m
.88775 .31137 L
s
.90654 .33316 m
.90279 .33437 L
s
.73752 .07463 m
.73384 .07601 L
s
.71804 .04482 m
.71436 .04622 L
s
.698 .01417 m
.69433 .01559 L
s
.93557 .37756 m
.93181 .37873 L
s
.94957 .39899 m
.94581 .40014 L
s
.96325 .41992 m
.95949 .42106 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03329 .27954 m
.03941 .27717 L
s
[(0.15)] .02105 .28428 1 -0.387 Mshowa
.02471 .33372 m
.03085 .3314 L
s
[(0.2)] .01243 .33834 1 -0.37683 Mshowa
.01582 .38982 m
.02198 .38756 L
s
[(0.25)] .0035 .39433 1 -0.36626 Mshowa
.00661 .44795 m
.01279 .44575 L
s
[(0.3)] -0.00576 .45234 1 -0.35527 Mshowa
.125 Mabswid
.0316 .29023 m
.03527 .28881 L
s
.02989 .30099 m
.03357 .29958 L
s
.02818 .31182 m
.03186 .31042 L
s
.02645 .32273 m
.03013 .32134 L
s
.02295 .34478 m
.02664 .3434 L
s
.02119 .35592 m
.02488 .35455 L
s
.01941 .36714 m
.0231 .36577 L
s
.01762 .37844 m
.02131 .37708 L
s
.014 .40128 m
.0177 .39993 L
s
.01217 .41282 m
.01587 .41148 L
s
.01033 .42444 m
.01403 .42311 L
s
.00847 .43615 m
.01218 .43483 L
s
.03497 .26893 m
.03864 .2675 L
s
.03664 .25839 m
.04031 .25696 L
s
.00472 .45983 m
.00843 .45852 L
s
.00283 .47179 m
.00654 .47049 L
s
.00092 .48385 m
.00463 .48255 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .428 .205 r
.39294 .65569 .40454 .62033 .41954 .66927 .40745 .72287 Metetra
.216 .619 0 r
.40745 .72287 .41954 .66927 .43593 .68743 .42394 .74845 Metetra
.446 .688 0 r
.42394 .74845 .43593 .68743 .45301 .68839 .44138 .75062 Metetra
.504 .704 0 r
.44138 .75062 .45301 .68839 .47033 .68494 .45912 .74682 Metetra
.518 .707 0 r
.45912 .74682 .47033 .68494 .48778 .68083 .477 .74223 Metetra
.525 .709 0 r
.477 .74223 .48778 .68083 .50535 .67658 .495 .73752 Metetra
.532 .711 0 r
.495 .73752 .50535 .67658 .52304 .67223 .51312 .73277 Metetra
.537 .713 0 r
.51312 .73277 .52304 .67223 .54085 .66778 .53136 .72796 Metetra
.543 .714 0 r
.53136 .72796 .54085 .66778 .55878 .66323 .54973 .72311 Metetra
.547 .715 0 r
.54973 .72311 .55878 .66323 .57683 .65858 .56821 .7182 Metetra
.551 .716 0 r
.56821 .7182 .57683 .65858 .595 .65382 .58683 .71325 Metetra
.554 .717 0 r
.58683 .71325 .595 .65382 .6133 .64897 .60557 .70824 Metetra
.556 .717 0 r
.60557 .70824 .6133 .64897 .63171 .64401 .62443 .70319 Metetra
.558 .718 0 r
.62443 .70319 .63171 .64401 .65025 .63895 .64343 .69809 Metetra
.559 .718 0 r
.64343 .69809 .65025 .63895 .66891 .63379 .66255 .69293 Metetra
.559 .718 0 r
.66255 .69293 .66891 .63379 .68769 .62853 .68181 .68773 Metetra
.559 .718 0 r
.68181 .68773 .68769 .62853 .70659 .62317 .70119 .68247 Metetra
.558 .718 0 r
.70119 .68247 .70659 .62317 .72562 .6177 .72071 .67716 Metetra
.557 .718 0 r
.72071 .67716 .72562 .6177 .74476 .61213 .74036 .6718 Metetra
.555 .717 0 r
.74036 .6718 .74476 .61213 .76403 .60645 .76014 .66639 Metetra
.552 .716 0 r
.76014 .66639 .76403 .60645 .78342 .60066 .78006 .66092 Metetra
.548 .715 0 r
.78006 .66092 .78342 .60066 .80293 .59477 .80012 .6554 Metetra
.544 .714 0 r
.80012 .6554 .80293 .59477 .82257 .58876 .82032 .64982 Metetra
.539 .713 0 r
.82032 .64982 .82257 .58876 .84233 .58265 .84065 .64419 Metetra
.533 .711 0 r
.84065 .64419 .84233 .58265 .8622 .57641 .86112 .63849 Metetra
.527 .71 0 r
.86112 .63849 .8622 .57641 .8822 .57007 .88174 .63274 Metetra
.52 .708 0 r
.88174 .63274 .8822 .57007 .90232 .56359 .90249 .6269 Metetra
.509 .705 0 r
.90249 .6269 .90232 .56359 .92253 .55669 .92334 .62059 Metetra
.471 .695 0 r
.92334 .62059 .92253 .55669 .9425 .54688 .94386 .61038 Metetra
.303 .647 0 r
.94386 .61038 .9425 .54688 .96082 .52356 .96211 .58171 Metetra
0 .494 .096 r
.96211 .58171 .96082 .52356 .97489 .46979 .97463 .51162 Metetra
.118 .585 0 r
.38208 .66321 .39294 .65569 .40745 .72287 .39627 .73744 Metetra
.808 .672 0 r
.39627 .73744 .40745 .72287 .42394 .74845 .41276 .76578 Metetra
.887 .435 0 r
.41276 .76578 .42394 .74845 .44138 .75062 .43038 .76821 Metetra
.903 .381 0 r
.43038 .76821 .44138 .75062 .45912 .74682 .44833 .76407 Metetra
.905 .374 0 r
.44833 .76407 .45912 .74682 .477 .74223 .46642 .75908 Metetra
.905 .374 0 r
.46642 .75908 .477 .74223 .495 .73752 .48463 .75402 Metetra
.905 .374 0 r
.48463 .75402 .495 .73752 .51312 .73277 .50296 .74894 Metetra
.905 .374 0 r
.50296 .74894 .51312 .73277 .53136 .72796 .52141 .74385 Metetra
.905 .374 0 r
.52141 .74385 .53136 .72796 .54973 .72311 .53999 .73874 Metetra
.905 .374 0 r
.53999 .73874 .54973 .72311 .56821 .7182 .55869 .73361 Metetra
.904 .374 0 r
.55869 .73361 .56821 .7182 .58683 .71325 .57751 .72847 Metetra
.904 .374 0 r
.57751 .72847 .58683 .71325 .60557 .70824 .59647 .72331 Metetra
.904 .374 0 r
.59647 .72331 .60557 .70824 .62443 .70319 .61555 .71814 Metetra
.904 .374 0 r
.61555 .71814 .62443 .70319 .64343 .69809 .63477 .71295 Metetra
.904 .375 0 r
.63477 .71295 .64343 .69809 .66255 .69293 .65411 .70774 Metetra
.904 .375 0 r
.65411 .70774 .66255 .69293 .68181 .68773 .6736 .70251 Metetra
.904 .375 0 r
.6736 .70251 .68181 .68773 .70119 .68247 .69321 .69726 Metetra
.904 .375 0 r
.69321 .69726 .70119 .68247 .72071 .67716 .71297 .692 Metetra
.904 .374 0 r
.71297 .692 .72071 .67716 .74036 .6718 .73287 .68671 Metetra
.904 .374 0 r
.73287 .68671 .74036 .6718 .76014 .66639 .7529 .68141 Metetra
.904 .374 0 r
.7529 .68141 .76014 .66639 .78006 .66092 .77308 .67609 Metetra
.905 .374 0 r
.77308 .67609 .78006 .66092 .80012 .6554 .79341 .67075 Metetra
.905 .374 0 r
.79341 .67075 .80012 .6554 .82032 .64982 .81388 .66538 Metetra
.905 .374 0 r
.81388 .66538 .82032 .64982 .84065 .64419 .8345 .66 Metetra
.905 .374 0 r
.8345 .66 .84065 .64419 .86112 .63849 .85527 .6546 Metetra
.905 .374 0 r
.85527 .6546 .86112 .63849 .88174 .63274 .8762 .64918 Metetra
.905 .374 0 r
.8762 .64918 .88174 .63274 .90249 .6269 .89728 .64372 Metetra
.904 .377 0 r
.89728 .64372 .90249 .6269 .92334 .62059 .91846 .63777 Metetra
.894 .41 0 r
.91846 .63777 .92334 .62059 .94386 .61038 .93928 .62755 Metetra
.84 .583 0 r
.93928 .62755 .94386 .61038 .96211 .58171 .95762 .59687 Metetra
.353 .662 0 r
.95762 .59687 .96211 .58171 .97463 .51162 .9697 .52038 Metetra
.265 .635 0 r
.3716 .65731 .38208 .66321 .39627 .73744 .38556 .73312 Metetra
.868 .496 0 r
.38556 .73312 .39627 .73744 .41276 .76578 .40202 .76205 Metetra
.95 .206 0 r
.40202 .76205 .41276 .76578 .43038 .76821 .41972 .76448 Metetra
.965 .145 0 r
.41972 .76448 .43038 .76821 .44833 .76407 .43777 .76019 Metetra
.966 .141 0 r
.43777 .76019 .44833 .76407 .46642 .75908 .45597 .75505 Metetra
.965 .145 0 r
.45597 .75505 .46642 .75908 .48463 .75402 .47428 .74983 Metetra
.965 .148 0 r
.47428 .74983 .48463 .75402 .50296 .74894 .49272 .74462 Metetra
.964 .151 0 r
.49272 .74462 .50296 .74894 .52141 .74385 .51128 .7394 Metetra
.963 .154 0 r
.51128 .7394 .52141 .74385 .53999 .73874 .52996 .73417 Metetra
.963 .156 0 r
.52996 .73417 .53999 .73874 .55869 .73361 .54877 .72893 Metetra
.962 .158 0 r
.54877 .72893 .55869 .73361 .57751 .72847 .5677 .72369 Metetra
.962 .16 0 r
.5677 .72369 .57751 .72847 .59647 .72331 .58677 .71844 Metetra
.961 .161 0 r
.58677 .71844 .59647 .72331 .61555 .71814 .60596 .71318 Metetra
.961 .162 0 r
.60596 .71318 .61555 .71814 .63477 .71295 .62529 .70791 Metetra
.961 .162 0 r
.62529 .70791 .63477 .71295 .65411 .70774 .64476 .70264 Metetra
.961 .163 0 r
.64476 .70264 .65411 .70774 .6736 .70251 .66436 .69735 Metetra
.961 .162 0 r
.66436 .69735 .6736 .70251 .69321 .69726 .6841 .69205 Metetra
.961 .162 0 r
.6841 .69205 .69321 .69726 .71297 .692 .70397 .68674 Metetra
.961 .161 0 r
.70397 .68674 .71297 .692 .73287 .68671 .72399 .68142 Metetra
.962 .16 0 r
.72399 .68142 .73287 .68671 .7529 .68141 .74416 .67609 Metetra
.962 .159 0 r
.74416 .67609 .7529 .68141 .77308 .67609 .76447 .67076 Metetra
.962 .157 0 r
.76447 .67076 .77308 .67609 .79341 .67075 .78493 .66541 Metetra
.963 .154 0 r
.78493 .66541 .79341 .67075 .81388 .66538 .80554 .66005 Metetra
.964 .152 0 r
.80554 .66005 .81388 .66538 .8345 .66 .82631 .65468 Metetra
.964 .149 0 r
.82631 .65468 .8345 .66 .85527 .6546 .84722 .6493 Metetra
.965 .145 0 r
.84722 .6493 .85527 .6546 .8762 .64918 .8683 .64391 Metetra
.966 .142 0 r
.8683 .64391 .8762 .64918 .89728 .64372 .88953 .63849 Metetra
.966 .142 0 r
.88953 .63849 .89728 .64372 .91846 .63777 .91087 .63259 Metetra
.957 .177 0 r
.91087 .63259 .91846 .63777 .93928 .62755 .93186 .62232 Metetra
.901 .385 0 r
.93186 .62232 .93928 .62755 .95762 .59687 .95034 .59113 Metetra
.548 .715 0 r
.95034 .59113 .95762 .59687 .9697 .52038 .96251 .51309 Metetra
.293 .644 0 r
.36111 .6483 .3716 .65731 .38556 .73312 .37487 .72449 Metetra
.879 .461 0 r
.37487 .72449 .38556 .73312 .40202 .76205 .3913 .75355 Metetra
.961 .162 0 r
.3913 .75355 .40202 .76205 .41972 .76448 .40905 .75596 Metetra
.977 .099 0 r
.40905 .75596 .41972 .76448 .43777 .76019 .42718 .7516 Metetra
.977 .097 0 r
.42718 .7516 .43777 .76019 .45597 .75505 .44545 .74638 Metetra
.976 .101 0 r
.44545 .74638 .45597 .75505 .47428 .74983 .46385 .74109 Metetra
.975 .106 0 r
.46385 .74109 .47428 .74983 .49272 .74462 .48237 .7358 Metetra
.974 .109 0 r
.48237 .7358 .49272 .74462 .51128 .7394 .50101 .73051 Metetra
.973 .113 0 r
.50101 .73051 .51128 .7394 .52996 .73417 .51978 .72521 Metetra
.973 .116 0 r
.51978 .72521 .52996 .73417 .54877 .72893 .53868 .71991 Metetra
.972 .118 0 r
.53868 .71991 .54877 .72893 .5677 .72369 .5577 .7146 Metetra
.971 .12 0 r
.5577 .7146 .5677 .72369 .58677 .71844 .57686 .70928 Metetra
.971 .122 0 r
.57686 .70928 .58677 .71844 .60596 .71318 .59614 .70395 Metetra
.971 .123 0 r
.59614 .70395 .60596 .71318 .62529 .70791 .61557 .69861 Metetra
.971 .124 0 r
.61557 .69861 .62529 .70791 .64476 .70264 .63512 .69327 Metetra
.971 .124 0 r
.63512 .69327 .64476 .70264 .66436 .69735 .65482 .68791 Metetra
.971 .124 0 r
.65482 .68791 .66436 .69735 .6841 .69205 .67465 .68254 Metetra
.971 .123 0 r
.67465 .68254 .6841 .69205 .70397 .68674 .69463 .67717 Metetra
.971 .122 0 r
.69463 .67717 .70397 .68674 .72399 .68142 .71475 .67178 Metetra
.971 .121 0 r
.71475 .67178 .72399 .68142 .74416 .67609 .73502 .66639 Metetra
.972 .119 0 r
.73502 .66639 .74416 .67609 .76447 .67076 .75544 .66098 Metetra
.972 .116 0 r
.75544 .66098 .76447 .67076 .78493 .66541 .776 .65557 Metetra
.973 .114 0 r
.776 .65557 .78493 .66541 .80554 .66005 .79672 .65014 Metetra
.974 .11 0 r
.79672 .65014 .80554 .66005 .82631 .65468 .81759 .64471 Metetra
.975 .107 0 r
.81759 .64471 .82631 .65468 .84722 .6493 .83862 .63927 Metetra
.976 .102 0 r
.83862 .63927 .84722 .6493 .8683 .64391 .85981 .63382 Metetra
.977 .098 0 r
.85981 .63382 .8683 .64391 .88953 .63849 .88116 .62833 Metetra
.977 .097 0 r
.88116 .62833 .88953 .63849 .91087 .63259 .90262 .62237 Metetra
.969 .132 0 r
.90262 .62237 .91087 .63259 .93186 .62232 .92373 .612 Metetra
.912 .347 0 r
.92373 .612 .93186 .62232 .95034 .59113 .94236 .58059 Metetra
.585 .725 0 r
.94236 .58059 .95034 .59113 .96251 .51309 .95474 .50208 Metetra
.295 .644 0 r
.35051 .63885 .36111 .6483 .37487 .72449 .36407 .71527 Metetra
.88 .459 0 r
.36407 .71527 .37487 .72449 .3913 .75355 .38046 .74441 Metetra
.962 .159 0 r
.38046 .74441 .3913 .75355 .40905 .75596 .39826 .7468 Metetra
.977 .096 0 r
.39826 .7468 .40905 .75596 .42718 .7516 .41646 .74238 Metetra
.978 .093 0 r
.41646 .74238 .42718 .7516 .44545 .74638 .43482 .7371 Metetra
.977 .098 0 r
.43482 .7371 .44545 .74638 .46385 .74109 .4533 .73175 Metetra
.976 .102 0 r
.4533 .73175 .46385 .74109 .48237 .7358 .4719 .7264 Metetra
.975 .106 0 r
.4719 .7264 .48237 .7358 .50101 .73051 .49062 .72104 Metetra
.974 .11 0 r
.49062 .72104 .50101 .73051 .51978 .72521 .50947 .71568 Metetra
.973 .113 0 r
.50947 .71568 .51978 .72521 .53868 .71991 .52846 .71031 Metetra
.973 .115 0 r
.52846 .71031 .53868 .71991 .5577 .7146 .54757 .70493 Metetra
.972 .117 0 r
.54757 .70493 .5577 .7146 .57686 .70928 .56681 .69955 Metetra
.972 .119 0 r
.56681 .69955 .57686 .70928 .59614 .70395 .58619 .69415 Metetra
.972 .12 0 r
.58619 .69415 .59614 .70395 .61557 .69861 .6057 .68874 Metetra
.971 .121 0 r
.6057 .68874 .61557 .69861 .63512 .69327 .62535 .68332 Metetra
.971 .121 0 r
.62535 .68332 .63512 .69327 .65482 .68791 .64514 .6779 Metetra
.971 .121 0 r
.64514 .6779 .65482 .68791 .67465 .68254 .66507 .67246 Metetra
.971 .12 0 r
.66507 .67246 .67465 .68254 .69463 .67717 .68514 .66702 Metetra
.972 .119 0 r
.68514 .66702 .69463 .67717 .71475 .67178 .70536 .66156 Metetra
.972 .118 0 r
.70536 .66156 .71475 .67178 .73502 .66639 .72573 .65609 Metetra
.973 .116 0 r
.72573 .65609 .73502 .66639 .75544 .66098 .74625 .65061 Metetra
.973 .113 0 r
.74625 .65061 .75544 .66098 .776 .65557 .76692 .64512 Metetra
.974 .11 0 r
.76692 .64512 .776 .65557 .79672 .65014 .78774 .63962 Metetra
.975 .107 0 r
.78774 .63962 .79672 .65014 .81759 .64471 .80872 .63411 Metetra
.976 .103 0 r
.80872 .63411 .81759 .64471 .83862 .63927 .82986 .62859 Metetra
.977 .099 0 r
.82986 .62859 .83862 .63927 .85981 .63382 .85116 .62306 Metetra
.978 .094 0 r
.85116 .62306 .85981 .63382 .88116 .62833 .87262 .6175 Metetra
.978 .093 0 r
.87262 .6175 .88116 .62833 .90262 .62237 .89419 .61145 Metetra
.969 .129 0 r
.89419 .61145 .90262 .62237 .92373 .612 .91542 .60098 Metetra
.913 .344 0 r
.91542 .60098 .92373 .612 .94236 .58059 .93421 .56937 Metetra
.587 .725 0 r
.93421 .56937 .94236 .58059 .95474 .50208 .94682 .49052 Metetra
.294 .644 0 r
.33978 .62927 .35051 .63885 .36407 .71527 .35313 .70592 Metetra
.879 .46 0 r
.35313 .70592 .36407 .71527 .38046 .74441 .36948 .73514 Metetra
.962 .16 0 r
.36948 .73514 .38046 .74441 .39826 .7468 .38734 .7375 Metetra
.977 .097 0 r
.38734 .7375 .39826 .7468 .41646 .74238 .40561 .73303 Metetra
.978 .094 0 r
.40561 .73303 .41646 .74238 .43482 .7371 .42405 .72768 Metetra
.977 .098 0 r
.42405 .72768 .43482 .7371 .4533 .73175 .44261 .72227 Metetra
.976 .103 0 r
.44261 .72227 .4533 .73175 .4719 .7264 .46129 .71686 Metetra
.975 .107 0 r
.46129 .71686 .4719 .7264 .49062 .72104 .4801 .71144 Metetra
.974 .11 0 r
.4801 .71144 .49062 .72104 .50947 .71568 .49904 .70601 Metetra
.973 .113 0 r
.49904 .70601 .50947 .71568 .52846 .71031 .5181 .70057 Metetra
.973 .116 0 r
.5181 .70057 .52846 .71031 .54757 .70493 .5373 .69513 Metetra
.972 .118 0 r
.5373 .69513 .54757 .70493 .56681 .69955 .55663 .68967 Metetra
.972 .119 0 r
.55663 .68967 .56681 .69955 .58619 .69415 .5761 .68421 Metetra
.971 .12 0 r
.5761 .68421 .58619 .69415 .6057 .68874 .5957 .67873 Metetra
.971 .121 0 r
.5957 .67873 .6057 .68874 .62535 .68332 .61545 .67325 Metetra
.971 .121 0 r
.61545 .67325 .62535 .68332 .64514 .6779 .63533 .66775 Metetra
.971 .121 0 r
.63533 .66775 .64514 .6779 .66507 .67246 .65536 .66224 Metetra
.971 .121 0 r
.65536 .66224 .66507 .67246 .68514 .66702 .67553 .65672 Metetra
.972 .12 0 r
.67553 .65672 .68514 .66702 .70536 .66156 .69585 .65119 Metetra
.972 .118 0 r
.69585 .65119 .70536 .66156 .72573 .65609 .71632 .64564 Metetra
.972 .116 0 r
.71632 .64564 .72573 .65609 .74625 .65061 .73693 .64009 Metetra
.973 .114 0 r
.73693 .64009 .74625 .65061 .76692 .64512 .75771 .63452 Metetra
.974 .111 0 r
.75771 .63452 .76692 .64512 .78774 .63962 .77864 .62894 Metetra
.974 .108 0 r
.77864 .62894 .78774 .63962 .80872 .63411 .79972 .62335 Metetra
.975 .104 0 r
.79972 .62335 .80872 .63411 .82986 .62859 .82097 .61775 Metetra
.976 .1 0 r
.82097 .61775 .82986 .62859 .85116 .62306 .84238 .61214 Metetra
.978 .095 0 r
.84238 .61214 .85116 .62306 .87262 .6175 .86395 .6065 Metetra
.978 .094 0 r
.86395 .6065 .87262 .6175 .89419 .61145 .88564 .60037 Metetra
.969 .129 0 r
.88564 .60037 .89419 .61145 .91542 .60098 .907 .58979 Metetra
.913 .345 0 r
.907 .58979 .91542 .60098 .93421 .56937 .92595 .55799 Metetra
.586 .725 0 r
.92595 .55799 .93421 .56937 .94682 .49052 .93878 .47879 Metetra
.293 .643 0 r
.32893 .61959 .33978 .62927 .35313 .70592 .34207 .69646 Metetra
.879 .461 0 r
.34207 .69646 .35313 .70592 .36948 .73514 .35837 .72576 Metetra
.961 .161 0 r
.35837 .72576 .36948 .73514 .38734 .7375 .37627 .72809 Metetra
.977 .098 0 r
.37627 .72809 .38734 .7375 .40561 .73303 .39463 .72356 Metetra
.978 .095 0 r
.39463 .72356 .40561 .73303 .42405 .72768 .41314 .71815 Metetra
.977 .099 0 r
.41314 .71815 .42405 .72768 .44261 .72227 .43178 .71268 Metetra
.975 .104 0 r
.43178 .71268 .44261 .72227 .46129 .71686 .45055 .7072 Metetra
.975 .108 0 r
.45055 .7072 .46129 .71686 .4801 .71144 .46944 .70171 Metetra
.974 .111 0 r
.46944 .70171 .4801 .71144 .49904 .70601 .48846 .69622 Metetra
.973 .114 0 r
.48846 .69622 .49904 .70601 .5181 .70057 .50762 .69071 Metetra
.972 .116 0 r
.50762 .69071 .5181 .70057 .5373 .69513 .5269 .6852 Metetra
.972 .118 0 r
.5269 .6852 .5373 .69513 .55663 .68967 .54632 .67967 Metetra
.972 .12 0 r
.54632 .67967 .55663 .68967 .5761 .68421 .56588 .67414 Metetra
.971 .121 0 r
.56588 .67414 .5761 .68421 .5957 .67873 .58558 .66859 Metetra
.971 .122 0 r
.58558 .66859 .5957 .67873 .61545 .67325 .60541 .66304 Metetra
.971 .122 0 r
.60541 .66304 .61545 .67325 .63533 .66775 .62539 .65747 Metetra
.971 .122 0 r
.62539 .65747 .63533 .66775 .65536 .66224 .64552 .65188 Metetra
.971 .121 0 r
.64552 .65188 .65536 .66224 .67553 .65672 .66579 .64629 Metetra
.971 .12 0 r
.66579 .64629 .67553 .65672 .69585 .65119 .68621 .64068 Metetra
.972 .119 0 r
.68621 .64068 .69585 .65119 .71632 .64564 .70678 .63506 Metetra
.972 .117 0 r
.70678 .63506 .71632 .64564 .73693 .64009 .7275 .62943 Metetra
.973 .115 0 r
.7275 .62943 .73693 .64009 .75771 .63452 .74838 .62378 Metetra
.974 .112 0 r
.74838 .62378 .75771 .63452 .77864 .62894 .76941 .61812 Metetra
.974 .108 0 r
.76941 .61812 .77864 .62894 .79972 .62335 .79061 .61246 Metetra
.975 .105 0 r
.79061 .61246 .79972 .62335 .82097 .61775 .81196 .60677 Metetra
.976 .1 0 r
.81196 .60677 .82097 .61775 .84238 .61214 .83349 .60108 Metetra
.977 .096 0 r
.83349 .60108 .84238 .61214 .86395 .6065 .85517 .59535 Metetra
.978 .095 0 r
.85517 .59535 .86395 .6065 .88564 .60037 .87698 .58913 Metetra
.969 .13 0 r
.87698 .58913 .88564 .60037 .907 .58979 .89846 .57845 Metetra
.913 .346 0 r
.89846 .57845 .907 .58979 .92595 .55799 .91757 .54646 Metetra
.584 .725 0 r
.91757 .54646 .92595 .55799 .93878 .47879 .93064 .46691 Metetra
.292 .643 0 r
.31794 .6098 .32893 .61959 .34207 .69646 .33086 .68689 Metetra
.879 .461 0 r
.33086 .68689 .34207 .69646 .35837 .72576 .34712 .71627 Metetra
.961 .162 0 r
.34712 .71627 .35837 .72576 .37627 .72809 .36507 .71857 Metetra
.977 .098 0 r
.36507 .71857 .37627 .72809 .39463 .72356 .3835 .71398 Metetra
.977 .096 0 r
.3835 .71398 .39463 .72356 .41314 .71815 .4021 .70851 Metetra
.976 .1 0 r
.4021 .70851 .41314 .71815 .43178 .71268 .42082 .70297 Metetra
.975 .104 0 r
.42082 .70297 .43178 .71268 .45055 .7072 .43967 .69742 Metetra
.974 .108 0 r
.43967 .69742 .45055 .7072 .46944 .70171 .45864 .69187 Metetra
.974 .112 0 r
.45864 .69187 .46944 .70171 .48846 .69622 .47775 .6863 Metetra
.973 .114 0 r
.47775 .6863 .48846 .69622 .50762 .69071 .49699 .68073 Metetra
.972 .117 0 r
.49699 .68073 .50762 .69071 .5269 .6852 .51637 .67515 Metetra
.972 .119 0 r
.51637 .67515 .5269 .6852 .54632 .67967 .53588 .66955 Metetra
.971 .12 0 r
.53588 .66955 .54632 .67967 .56588 .67414 .55553 .66395 Metetra
.971 .122 0 r
.55553 .66395 .56588 .67414 .58558 .66859 .57532 .65833 Metetra
.971 .122 0 r
.57532 .65833 .58558 .66859 .60541 .66304 .59525 .6527 Metetra
.971 .122 0 r
.59525 .6527 .60541 .66304 .62539 .65747 .61532 .64705 Metetra
.971 .122 0 r
.61532 .64705 .62539 .65747 .64552 .65188 .63555 .64139 Metetra
.971 .122 0 r
.63555 .64139 .64552 .65188 .66579 .64629 .65591 .63572 Metetra
.971 .121 0 r
.65591 .63572 .66579 .64629 .68621 .64068 .67643 .63004 Metetra
.972 .119 0 r
.67643 .63004 .68621 .64068 .70678 .63506 .69711 .62434 Metetra
.972 .117 0 r
.69711 .62434 .70678 .63506 .7275 .62943 .71793 .61863 Metetra
.973 .115 0 r
.71793 .61863 .7275 .62943 .74838 .62378 .73892 .6129 Metetra
.973 .112 0 r
.73892 .6129 .74838 .62378 .76941 .61812 .76006 .60717 Metetra
.974 .109 0 r
.76006 .60717 .76941 .61812 .79061 .61246 .78137 .60141 Metetra
.975 .105 0 r
.78137 .60141 .79061 .61246 .81196 .60677 .80283 .59565 Metetra
.976 .101 0 r
.80283 .59565 .81196 .60677 .83349 .60108 .82447 .58987 Metetra
.977 .097 0 r
.82447 .58987 .83349 .60108 .85517 .59535 .84627 .58406 Metetra
.977 .096 0 r
.84627 .58406 .85517 .59535 .87698 .58913 .8682 .57775 Metetra
.969 .131 0 r
.8682 .57775 .87698 .58913 .89846 .57845 .88981 .56696 Metetra
.912 .347 0 r
.88981 .56696 .89846 .57845 .91757 .54646 .90908 .53477 Metetra
.583 .724 0 r
.90908 .53477 .91757 .54646 .93064 .46691 .92239 .45489 Metetra
.291 .643 0 r
.30682 .59991 .31794 .6098 .33086 .68689 .31951 .67722 Metetra
.879 .462 0 r
.31951 .67722 .33086 .68689 .34712 .71627 .33572 .70667 Metetra
.961 .162 0 r
.33572 .70667 .34712 .71627 .36507 .71857 .35372 .70894 Metetra
.977 .099 0 r
.35372 .70894 .36507 .71857 .3835 .71398 .37223 .70429 Metetra
.977 .096 0 r
.37223 .70429 .3835 .71398 .4021 .70851 .39091 .69875 Metetra
.976 .101 0 r
.39091 .69875 .4021 .70851 .42082 .70297 .40971 .69314 Metetra
.975 .105 0 r
.40971 .69314 .42082 .70297 .43967 .69742 .42864 .68753 Metetra
.974 .109 0 r
.42864 .68753 .43967 .69742 .45864 .69187 .44771 .6819 Metetra
.973 .112 0 r
.44771 .6819 .45864 .69187 .47775 .6863 .4669 .67627 Metetra
.973 .115 0 r
.4669 .67627 .47775 .6863 .49699 .68073 .48623 .67062 Metetra
.972 .117 0 r
.48623 .67062 .49699 .68073 .51637 .67515 .50569 .66497 Metetra
.972 .119 0 r
.50569 .66497 .51637 .67515 .53588 .66955 .5253 .6593 Metetra
.971 .121 0 r
.5253 .6593 .53588 .66955 .55553 .66395 .54504 .65362 Metetra
.971 .122 0 r
.54504 .65362 .55553 .66395 .57532 .65833 .56492 .64793 Metetra
.971 .123 0 r
.56492 .64793 .57532 .65833 .59525 .6527 .58495 .64222 Metetra
.971 .123 0 r
.58495 .64222 .59525 .6527 .61532 .64705 .60512 .6365 Metetra
.971 .123 0 r
.60512 .6365 .61532 .64705 .63555 .64139 .62544 .63077 Metetra
.971 .122 0 r
.62544 .63077 .63555 .64139 .65591 .63572 .64591 .62502 Metetra
.971 .121 0 r
.64591 .62502 .65591 .63572 .67643 .63004 .66653 .61926 Metetra
.972 .12 0 r
.66653 .61926 .67643 .63004 .69711 .62434 .68731 .61348 Metetra
.972 .118 0 r
.68731 .61348 .69711 .62434 .71793 .61863 .70824 .60769 Metetra
.973 .116 0 r
.70824 .60769 .71793 .61863 .73892 .6129 .72933 .60188 Metetra
.973 .113 0 r
.72933 .60188 .73892 .6129 .76006 .60717 .75058 .59606 Metetra
.974 .11 0 r
.75058 .59606 .76006 .60717 .78137 .60141 .772 .59023 Metetra
.975 .106 0 r
.772 .59023 .78137 .60141 .80283 .59565 .79358 .58438 Metetra
.976 .102 0 r
.79358 .58438 .80283 .59565 .82447 .58987 .81533 .57852 Metetra
.977 .097 0 r
.81533 .57852 .82447 .58987 .84627 .58406 .83725 .57262 Metetra
.977 .096 0 r
.83725 .57262 .84627 .58406 .8682 .57775 .85929 .56622 Metetra
.969 .132 0 r
.85929 .56622 .8682 .57775 .88981 .56696 .88103 .55532 Metetra
.912 .348 0 r
.88103 .55532 .88981 .56696 .90908 .53477 .90048 .52294 Metetra
.582 .724 0 r
.90048 .52294 .90908 .53477 .92239 .45489 .91403 .4427 Metetra
.29 .643 0 r
.29557 .5899 .30682 .59991 .31951 .67722 .30802 .66743 Metetra
.878 .463 0 r
.30802 .66743 .31951 .67722 .33572 .70667 .32418 .69696 Metetra
.961 .163 0 r
.32418 .69696 .33572 .70667 .35372 .70894 .34223 .69919 Metetra
.976 .1 0 r
.34223 .69919 .35372 .70894 .37223 .70429 .36082 .69448 Metetra
.977 .097 0 r
.36082 .69448 .37223 .70429 .39091 .69875 .37957 .68887 Metetra
.976 .101 0 r
.37957 .68887 .39091 .69875 .40971 .69314 .39846 .68319 Metetra
.975 .105 0 r
.39846 .68319 .40971 .69314 .42864 .68753 .41748 .67751 Metetra
.974 .109 0 r
.41748 .67751 .42864 .68753 .44771 .6819 .43663 .67181 Metetra
.973 .112 0 r
.43663 .67181 .44771 .6819 .4669 .67627 .45591 .66611 Metetra
.973 .115 0 r
.45591 .66611 .4669 .67627 .48623 .67062 .47533 .66039 Metetra
.972 .118 0 r
.47533 .66039 .48623 .67062 .50569 .66497 .49488 .65466 Metetra
.972 .12 0 r
.49488 .65466 .50569 .66497 .5253 .6593 .51457 .64892 Metetra
.971 .121 0 r
.51457 .64892 .5253 .6593 .54504 .65362 .53441 .64317 Metetra
.971 .122 0 r
.53441 .64317 .54504 .65362 .56492 .64793 .55439 .6374 Metetra
.971 .123 0 r
.55439 .6374 .56492 .64793 .58495 .64222 .57451 .63162 Metetra
.971 .123 0 r
.57451 .63162 .58495 .64222 .60512 .6365 .59478 .62582 Metetra
.971 .123 0 r
.59478 .62582 .60512 .6365 .62544 .63077 .6152 .62001 Metetra
.971 .123 0 r
.6152 .62001 .62544 .63077 .64591 .62502 .63577 .61418 Metetra
.971 .122 0 r
.63577 .61418 .64591 .62502 .66653 .61926 .65649 .60834 Metetra
.971 .12 0 r
.65649 .60834 .66653 .61926 .68731 .61348 .67737 .60248 Metetra
.972 .118 0 r
.67737 .60248 .68731 .61348 .70824 .60769 .69841 .59661 Metetra
.972 .116 0 r
.69841 .59661 .70824 .60769 .72933 .60188 .71961 .59072 Metetra
.973 .113 0 r
.71961 .59072 .72933 .60188 .75058 .59606 .74097 .58481 Metetra
.974 .11 0 r
.74097 .58481 .75058 .59606 .772 .59023 .7625 .57889 Metetra
.975 .106 0 r
.7625 .57889 .772 .59023 .79358 .58438 .7842 .57296 Metetra
.976 .102 0 r
.7842 .57296 .79358 .58438 .81533 .57852 .80606 .56701 Metetra
.977 .098 0 r
.80606 .56701 .81533 .57852 .83725 .57262 .8281 .56102 Metetra
.977 .097 0 r
.8281 .56102 .83725 .57262 .85929 .56622 .85026 .55453 Metetra
.968 .133 0 r
.85026 .55453 .85929 .56622 .88103 .55532 .87213 .54352 Metetra
.912 .348 0 r
.87213 .54352 .88103 .55532 .90048 .52294 .89175 .51095 Metetra
.581 .724 0 r
.89175 .51095 .90048 .52294 .91403 .4427 .90556 .43037 Metetra
.289 .642 0 r
.28417 .57978 .29557 .5899 .30802 .66743 .29638 .65753 Metetra
.878 .463 0 r
.29638 .65753 .30802 .66743 .32418 .69696 .31249 .68712 Metetra
.961 .163 0 r
.31249 .68712 .32418 .69696 .34223 .69919 .33059 .68932 Metetra
.976 .1 0 r
.33059 .68932 .34223 .69919 .36082 .69448 .34925 .68454 Metetra
.977 .097 0 r
.34925 .68454 .36082 .69448 .37957 .68887 .36809 .67886 Metetra
.976 .101 0 r
.36809 .67886 .37957 .68887 .39846 .68319 .38706 .67312 Metetra
.975 .106 0 r
.38706 .67312 .39846 .68319 .41748 .67751 .40617 .66736 Metetra
.974 .11 0 r
.40617 .66736 .41748 .67751 .43663 .67181 .4254 .66159 Metetra
.973 .113 0 r
.4254 .66159 .43663 .67181 .45591 .66611 .44477 .65581 Metetra
.973 .116 0 r
.44477 .65581 .45591 .66611 .47533 .66039 .46428 .65003 Metetra
.972 .118 0 r
.46428 .65003 .47533 .66039 .49488 .65466 .48392 .64422 Metetra
.971 .12 0 r
.48392 .64422 .49488 .65466 .51457 .64892 .50371 .63841 Metetra
.971 .122 0 r
.50371 .63841 .51457 .64892 .53441 .64317 .52364 .63258 Metetra
.971 .123 0 r
.52364 .63258 .53441 .64317 .55439 .6374 .54371 .62673 Metetra
.971 .123 0 r
.54371 .62673 .55439 .6374 .57451 .63162 .56393 .62087 Metetra
.971 .124 0 r
.56393 .62087 .57451 .63162 .59478 .62582 .5843 .61499 Metetra
.971 .123 0 r
.5843 .61499 .59478 .62582 .6152 .62001 .60482 .6091 Metetra
.971 .123 0 r
.60482 .6091 .6152 .62001 .63577 .61418 .62549 .60319 Metetra
.971 .122 0 r
.62549 .60319 .63577 .61418 .65649 .60834 .64632 .59727 Metetra
.971 .12 0 r
.64632 .59727 .65649 .60834 .67737 .60248 .6673 .59133 Metetra
.972 .119 0 r
.6673 .59133 .67737 .60248 .69841 .59661 .68845 .58537 Metetra
.972 .116 0 r
.68845 .58537 .69841 .59661 .71961 .59072 .70976 .5794 Metetra
.973 .114 0 r
.70976 .5794 .71961 .59072 .74097 .58481 .73123 .57341 Metetra
.974 .11 0 r
.73123 .57341 .74097 .58481 .7625 .57889 .75287 .5674 Metetra
.975 .107 0 r
.75287 .5674 .7625 .57889 .7842 .57296 .77468 .56138 Metetra
.976 .103 0 r
.77468 .56138 .7842 .57296 .80606 .56701 .79666 .55535 Metetra
.977 .098 0 r
.79666 .55535 .80606 .56701 .8281 .56102 .81882 .54927 Metetra
.977 .097 0 r
.81882 .54927 .8281 .56102 .85026 .55453 .84111 .54269 Metetra
.968 .133 0 r
.84111 .54269 .85026 .55453 .87213 .54352 .86311 .53156 Metetra
.912 .349 0 r
.86311 .53156 .87213 .54352 .89175 .51095 .8829 .49879 Metetra
.58 .723 0 r
.8829 .49879 .89175 .51095 .90556 .43037 .89696 .41787 Metetra
.289 .642 0 r
.27263 .56954 .28417 .57978 .29638 .65753 .2846 .64751 Metetra
.878 .464 0 r
.2846 .64751 .29638 .65753 .31249 .68712 .30064 .67717 Metetra
.961 .164 0 r
.30064 .67717 .31249 .68712 .33059 .68932 .3188 .67933 Metetra
.976 .1 0 r
.3188 .67933 .33059 .68932 .34925 .68454 .33754 .67448 Metetra
.977 .098 0 r
.33754 .67448 .34925 .68454 .36809 .67886 .35646 .66873 Metetra
.976 .102 0 r
.35646 .66873 .36809 .67886 .38706 .67312 .37551 .66291 Metetra
.975 .106 0 r
.37551 .66291 .38706 .67312 .40617 .66736 .3947 .65708 Metetra
.974 .11 0 r
.3947 .65708 .40617 .66736 .4254 .66159 .41403 .65124 Metetra
.973 .113 0 r
.41403 .65124 .4254 .66159 .44477 .65581 .43348 .64539 Metetra
.972 .116 0 r
.43348 .64539 .44477 .65581 .46428 .65003 .45308 .63953 Metetra
.972 .118 0 r
.45308 .63953 .46428 .65003 .48392 .64422 .47282 .63365 Metetra
.971 .12 0 r
.47282 .63365 .48392 .64422 .50371 .63841 .4927 .62775 Metetra
.971 .122 0 r
.4927 .62775 .50371 .63841 .52364 .63258 .51272 .62184 Metetra
.971 .123 0 r
.51272 .62184 .52364 .63258 .54371 .62673 .53289 .61592 Metetra
.971 .124 0 r
.53289 .61592 .54371 .62673 .56393 .62087 .55321 .60998 Metetra
.971 .124 0 r
.55321 .60998 .56393 .62087 .5843 .61499 .57367 .60402 Metetra
.971 .124 0 r
.57367 .60402 .5843 .61499 .60482 .6091 .59429 .59805 Metetra
.971 .123 0 r
.59429 .59805 .60482 .6091 .62549 .60319 .61507 .59206 Metetra
.971 .122 0 r
.61507 .59206 .62549 .60319 .64632 .59727 .636 .58605 Metetra
.971 .121 0 r
.636 .58605 .64632 .59727 .6673 .59133 .6571 .58003 Metetra
.972 .119 0 r
.6571 .58003 .6673 .59133 .68845 .58537 .67835 .57399 Metetra
.972 .117 0 r
.67835 .57399 .68845 .58537 .70976 .5794 .69977 .56793 Metetra
.973 .114 0 r
.69977 .56793 .70976 .5794 .73123 .57341 .72135 .56185 Metetra
.974 .111 0 r
.72135 .56185 .73123 .57341 .75287 .5674 .74311 .55576 Metetra
.975 .107 0 r
.74311 .55576 .75287 .5674 .77468 .56138 .76503 .54965 Metetra
.976 .103 0 r
.76503 .54965 .77468 .56138 .79666 .55535 .78713 .54352 Metetra
.977 .099 0 r
.78713 .54352 .79666 .55535 .81882 .54927 .80941 .53735 Metetra
.977 .098 0 r
.80941 .53735 .81882 .54927 .84111 .54269 .83182 .53068 Metetra
.968 .133 0 r
.83182 .53068 .84111 .54269 .86311 .53156 .85396 .51944 Metetra
.912 .349 0 r
.85396 .51944 .86311 .53156 .8829 .49879 .87392 .48648 Metetra
.579 .723 0 r
.87392 .48648 .8829 .49879 .89696 .41787 .88825 .4052 Metetra
.288 .642 0 r
.26095 .55919 .27263 .56954 .2846 .64751 .27266 .63737 Metetra
.878 .464 0 r
.27266 .63737 .2846 .64751 .30064 .67717 .28864 .66709 Metetra
.961 .164 0 r
.28864 .66709 .30064 .67717 .3188 .67933 .30685 .66921 Metetra
.976 .101 0 r
.30685 .66921 .3188 .67933 .33754 .67448 .32567 .66429 Metetra
.977 .098 0 r
.32567 .66429 .33754 .67448 .35646 .66873 .34467 .65847 Metetra
.976 .102 0 r
.34467 .65847 .35646 .66873 .37551 .66291 .36381 .65258 Metetra
.975 .106 0 r
.36381 .65258 .37551 .66291 .3947 .65708 .38309 .64668 Metetra
.974 .11 0 r
.38309 .64668 .3947 .65708 .41403 .65124 .4025 .64076 Metetra
.973 .113 0 r
.4025 .64076 .41403 .65124 .43348 .64539 .42205 .63483 Metetra
.972 .116 0 r
.42205 .63483 .43348 .64539 .45308 .63953 .44173 .62889 Metetra
.972 .119 0 r
.44173 .62889 .45308 .63953 .47282 .63365 .46156 .62293 Metetra
.971 .12 0 r
.46156 .62293 .47282 .63365 .4927 .62775 .48153 .61696 Metetra
.971 .122 0 r
.48153 .61696 .4927 .62775 .51272 .62184 .50165 .61097 Metetra
.971 .123 0 r
.50165 .61097 .51272 .62184 .53289 .61592 .52192 .60497 Metetra
.971 .124 0 r
.52192 .60497 .53289 .61592 .55321 .60998 .54234 .59895 Metetra
.971 .124 0 r
.54234 .59895 .55321 .60998 .57367 .60402 .5629 .59291 Metetra
.971 .124 0 r
.5629 .59291 .57367 .60402 .59429 .59805 .58363 .58685 Metetra
.971 .123 0 r
.58363 .58685 .59429 .59805 .61507 .59206 .60451 .58078 Metetra
.971 .122 0 r
.60451 .58078 .61507 .59206 .636 .58605 .62554 .57468 Metetra
.971 .121 0 r
.62554 .57468 .636 .58605 .6571 .58003 .64674 .56858 Metetra
.972 .119 0 r
.64674 .56858 .6571 .58003 .67835 .57399 .66811 .56245 Metetra
.972 .117 0 r
.66811 .56245 .67835 .57399 .69977 .56793 .68964 .5563 Metetra
.973 .114 0 r
.68964 .5563 .69977 .56793 .72135 .56185 .71133 .55013 Metetra
.974 .111 0 r
.71133 .55013 .72135 .56185 .74311 .55576 .7332 .54395 Metetra
.975 .107 0 r
.7332 .54395 .74311 .55576 .76503 .54965 .75525 .53775 Metetra
.976 .103 0 r
.75525 .53775 .76503 .54965 .78713 .54352 .77747 .53153 Metetra
.977 .099 0 r
.77747 .53153 .78713 .54352 .80941 .53735 .79986 .52527 Metetra
.977 .098 0 r
.79986 .52527 .80941 .53735 .83182 .53068 .8224 .5185 Metetra
.968 .134 0 r
.8224 .5185 .83182 .53068 .85396 .51944 .84467 .50715 Metetra
.912 .35 0 r
.84467 .50715 .85396 .51944 .87392 .48648 .86481 .47399 Metetra
.579 .723 0 r
.86481 .47399 .87392 .48648 .88825 .4052 .87942 .39237 Metetra
.288 .642 0 r
.24911 .54872 .26095 .55919 .27266 .63737 .26056 .62711 Metetra
.878 .464 0 r
.26056 .62711 .27266 .63737 .28864 .66709 .27649 .65689 Metetra
.96 .164 0 r
.27649 .65689 .28864 .66709 .30685 .66921 .29474 .65896 Metetra
.976 .101 0 r
.29474 .65896 .30685 .66921 .32567 .66429 .31364 .65398 Metetra
.977 .098 0 r
.31364 .65398 .32567 .66429 .34467 .65847 .33273 .64808 Metetra
.976 .102 0 r
.33273 .64808 .34467 .65847 .36381 .65258 .35195 .64211 Metetra
.975 .106 0 r
.35195 .64211 .36381 .65258 .38309 .64668 .37132 .63613 Metetra
.974 .11 0 r
.37132 .63613 .38309 .64668 .4025 .64076 .39081 .63014 Metetra
.973 .113 0 r
.39081 .63014 .4025 .64076 .42205 .63483 .41045 .62413 Metetra
.972 .116 0 r
.41045 .62413 .42205 .63483 .44173 .62889 .43023 .61811 Metetra
.972 .119 0 r
.43023 .61811 .44173 .62889 .46156 .62293 .45015 .61208 Metetra
.971 .121 0 r
.45015 .61208 .46156 .62293 .48153 .61696 .47022 .60602 Metetra
.971 .122 0 r
.47022 .60602 .48153 .61696 .50165 .61097 .49043 .59995 Metetra
.971 .123 0 r
.49043 .59995 .50165 .61097 .52192 .60497 .5108 .59387 Metetra
.971 .124 0 r
.5108 .59387 .52192 .60497 .54234 .59895 .53131 .58776 Metetra
.97 .124 0 r
.53131 .58776 .54234 .59895 .5629 .59291 .55198 .58164 Metetra
.971 .124 0 r
.55198 .58164 .5629 .59291 .58363 .58685 .57281 .5755 Metetra
.971 .123 0 r
.57281 .5755 .58363 .58685 .60451 .58078 .59379 .56934 Metetra
.971 .122 0 r
.59379 .56934 .60451 .58078 .62554 .57468 .61494 .56316 Metetra
.971 .121 0 r
.61494 .56316 .62554 .57468 .64674 .56858 .63625 .55696 Metetra
.972 .119 0 r
.63625 .55696 .64674 .56858 .66811 .56245 .65772 .55075 Metetra
.972 .117 0 r
.65772 .55075 .66811 .56245 .68964 .5563 .67936 .54451 Metetra
.973 .114 0 r
.67936 .54451 .68964 .5563 .71133 .55013 .70117 .53826 Metetra
.974 .111 0 r
.70117 .53826 .71133 .55013 .7332 .54395 .72316 .53198 Metetra
.975 .107 0 r
.72316 .53198 .7332 .54395 .75525 .53775 .74532 .52569 Metetra
.976 .103 0 r
.74532 .52569 .75525 .53775 .77747 .53153 .76766 .51938 Metetra
.977 .099 0 r
.76766 .51938 .77747 .53153 .79986 .52527 .79018 .51302 Metetra
.977 .098 0 r
.79018 .51302 .79986 .52527 .8224 .5185 .81284 .50615 Metetra
.968 .134 0 r
.81284 .50615 .8224 .5185 .84467 .50715 .83525 .49468 Metetra
.911 .35 0 r
.83525 .49468 .84467 .50715 .86481 .47399 .85558 .46133 Metetra
.579 .723 0 r
.85558 .46133 .86481 .47399 .87942 .39237 .87047 .37937 Metetra
.288 .642 0 r
.23713 .53812 .24911 .54872 .26056 .62711 .24831 .61673 Metetra
.878 .465 0 r
.24831 .61673 .26056 .62711 .27649 .65689 .26417 .64656 Metetra
.96 .165 0 r
.26417 .64656 .27649 .65689 .29474 .65896 .28247 .64859 Metetra
.976 .101 0 r
.28247 .64859 .29474 .65896 .31364 .65398 .30145 .64353 Metetra
.977 .098 0 r
.30145 .64353 .31364 .65398 .33273 .64808 .32062 .63756 Metetra
.976 .102 0 r
.32062 .63756 .33273 .64808 .35195 .64211 .33994 .63151 Metetra
.975 .107 0 r
.33994 .63151 .35195 .64211 .37132 .63613 .35939 .62545 Metetra
.974 .11 0 r
.35939 .62545 .37132 .63613 .39081 .63014 .37897 .61938 Metetra
.973 .114 0 r
.37897 .61938 .39081 .63014 .41045 .62413 .3987 .61329 Metetra
.972 .116 0 r
.3987 .61329 .41045 .62413 .43023 .61811 .41857 .60719 Metetra
.972 .119 0 r
.41857 .60719 .43023 .61811 .45015 .61208 .43859 .60107 Metetra
.971 .121 0 r
.43859 .60107 .45015 .61208 .47022 .60602 .45875 .59494 Metetra
.971 .122 0 r
.45875 .59494 .47022 .60602 .49043 .59995 .47906 .58879 Metetra
.971 .123 0 r
.47906 .58879 .49043 .59995 .5108 .59387 .49952 .58262 Metetra
.971 .124 0 r
.49952 .58262 .5108 .59387 .53131 .58776 .52014 .57643 Metetra
.97 .124 0 r
.52014 .57643 .53131 .58776 .55198 .58164 .54091 .57022 Metetra
.97 .124 0 r
.54091 .57022 .55198 .58164 .57281 .5755 .56184 .56399 Metetra
.971 .124 0 r
.56184 .56399 .57281 .5755 .59379 .56934 .58293 .55775 Metetra
.971 .123 0 r
.58293 .55775 .59379 .56934 .61494 .56316 .60418 .55148 Metetra
.971 .121 0 r
.60418 .55148 .61494 .56316 .63625 .55696 .6256 .54519 Metetra
.972 .119 0 r
.6256 .54519 .63625 .55696 .65772 .55075 .64719 .53889 Metetra
.972 .117 0 r
.64719 .53889 .65772 .55075 .67936 .54451 .66894 .53256 Metetra
.973 .114 0 r
.66894 .53256 .67936 .54451 .70117 .53826 .69087 .52621 Metetra
.974 .111 0 r
.69087 .52621 .70117 .53826 .72316 .53198 .71297 .51984 Metetra
.975 .108 0 r
.71297 .51984 .72316 .53198 .74532 .52569 .73525 .51346 Metetra
.976 .103 0 r
.73525 .51346 .74532 .52569 .76766 .51938 .75771 .50705 Metetra
.977 .099 0 r
.75771 .50705 .76766 .51938 .79018 .51302 .78036 .5006 Metetra
.977 .098 0 r
.78036 .5006 .79018 .51302 .81284 .50615 .80314 .49363 Metetra
.968 .134 0 r
.80314 .49363 .81284 .50615 .83525 .49468 .82569 .48204 Metetra
.911 .35 0 r
.82569 .48204 .83525 .49468 .85558 .46133 .84621 .4485 Metetra
.578 .723 0 r
.84621 .4485 .85558 .46133 .87047 .37937 .86138 .3662 Metetra
.288 .642 0 r
.22499 .5274 .23713 .53812 .24831 .61673 .2359 .60621 Metetra
.878 .465 0 r
.2359 .60621 .24831 .61673 .26417 .64656 .25169 .6361 Metetra
.96 .165 0 r
.25169 .6361 .26417 .64656 .28247 .64859 .27004 .63808 Metetra
.976 .101 0 r
.27004 .63808 .28247 .64859 .30145 .64353 .2891 .63295 Metetra
.977 .098 0 r
.2891 .63295 .30145 .64353 .32062 .63756 .30836 .6269 Metetra
.976 .102 0 r
.30836 .6269 .32062 .63756 .33994 .63151 .32776 .62077 Metetra
.975 .107 0 r
.32776 .62077 .33994 .63151 .35939 .62545 .34729 .61463 Metetra
.974 .11 0 r
.34729 .61463 .35939 .62545 .37897 .61938 .36697 .60848 Metetra
.973 .114 0 r
.36697 .60848 .37897 .61938 .3987 .61329 .38679 .60231 Metetra
.972 .116 0 r
.38679 .60231 .3987 .61329 .41857 .60719 .40675 .59613 Metetra
.972 .119 0 r
.40675 .59613 .41857 .60719 .43859 .60107 .42686 .58993 Metetra
.971 .121 0 r
.42686 .58993 .43859 .60107 .45875 .59494 .44712 .58371 Metetra
.971 .122 0 r
.44712 .58371 .45875 .59494 .47906 .58879 .46753 .57747 Metetra
.971 .123 0 r
.46753 .57747 .47906 .58879 .49952 .58262 .48809 .57121 Metetra
.971 .124 0 r
.48809 .57121 .49952 .58262 .52014 .57643 .50881 .56494 Metetra
.97 .124 0 r
.50881 .56494 .52014 .57643 .54091 .57022 .52968 .55864 Metetra
.97 .124 0 r
.52968 .55864 .54091 .57022 .56184 .56399 .55072 .55233 Metetra
.971 .124 0 r
.55072 .55233 .56184 .56399 .58293 .55775 .57191 .54599 Metetra
.971 .123 0 r
.57191 .54599 .58293 .55775 .60418 .55148 .59328 .53963 Metetra
.971 .121 0 r
.59328 .53963 .60418 .55148 .6256 .54519 .6148 .53326 Metetra
.972 .119 0 r
.6148 .53326 .6256 .54519 .64719 .53889 .6365 .52686 Metetra
.972 .117 0 r
.6365 .52686 .64719 .53889 .66894 .53256 .65837 .52044 Metetra
.973 .114 0 r
.65837 .52044 .66894 .53256 .69087 .52621 .68041 .514 Metetra
.974 .111 0 r
.68041 .514 .69087 .52621 .71297 .51984 .70263 .50753 Metetra
.975 .108 0 r
.70263 .50753 .71297 .51984 .73525 .51346 .72504 .50105 Metetra
.976 .104 0 r
.72504 .50105 .73525 .51346 .75771 .50705 .74762 .49455 Metetra
.977 .099 0 r
.74762 .49455 .75771 .50705 .78036 .5006 .77039 .488 Metetra
.977 .098 0 r
.77039 .488 .78036 .5006 .80314 .49363 .7933 .48093 Metetra
.968 .134 0 r
.7933 .48093 .80314 .49363 .82569 .48204 .816 .46922 Metetra
.911 .35 0 r
.816 .46922 .82569 .48204 .84621 .4485 .8367 .43549 Metetra
.578 .723 0 r
.8367 .43549 .84621 .4485 .86138 .3662 .85217 .35284 Metetra
.288 .642 0 r
.2127 .51655 .22499 .5274 .2359 .60621 .22332 .59557 Metetra
.878 .465 0 r
.22332 .59557 .2359 .60621 .25169 .6361 .23904 .6255 Metetra
.96 .165 0 r
.23904 .6255 .25169 .6361 .27004 .63808 .25744 .62743 Metetra
.976 .101 0 r
.25744 .62743 .27004 .63808 .2891 .63295 .27658 .62222 Metetra
.977 .098 0 r
.27658 .62222 .2891 .63295 .30836 .6269 .29592 .61609 Metetra
.976 .102 0 r
.29592 .61609 .30836 .6269 .32776 .62077 .31541 .60989 Metetra
.975 .107 0 r
.31541 .60989 .32776 .62077 .34729 .61463 .33503 .60367 Metetra
.974 .11 0 r
.33503 .60367 .34729 .61463 .36697 .60848 .3548 .59743 Metetra
.973 .114 0 r
.3548 .59743 .36697 .60848 .38679 .60231 .37471 .59118 Metetra
.972 .116 0 r
.37471 .59118 .38679 .60231 .40675 .59613 .39477 .58491 Metetra
.972 .119 0 r
.39477 .58491 .40675 .59613 .42686 .58993 .41498 .57862 Metetra
.971 .121 0 r
.41498 .57862 .42686 .58993 .44712 .58371 .43533 .57232 Metetra
.971 .122 0 r
.43533 .57232 .44712 .58371 .46753 .57747 .45584 .566 Metetra
.971 .123 0 r
.45584 .566 .46753 .57747 .48809 .57121 .4765 .55965 Metetra
.971 .124 0 r
.4765 .55965 .48809 .57121 .50881 .56494 .49732 .55329 Metetra
.97 .124 0 r
.49732 .55329 .50881 .56494 .52968 .55864 .5183 .54691 Metetra
.97 .124 0 r
.5183 .54691 .52968 .55864 .55072 .55233 .53944 .5405 Metetra
.971 .124 0 r
.53944 .5405 .55072 .55233 .57191 .54599 .56074 .53407 Metetra
.971 .123 0 r
.56074 .53407 .57191 .54599 .59328 .53963 .58221 .52762 Metetra
.971 .121 0 r
.58221 .52762 .59328 .53963 .6148 .53326 .60385 .52115 Metetra
.972 .119 0 r
.60385 .52115 .6148 .53326 .6365 .52686 .62566 .51466 Metetra
.972 .117 0 r
.62566 .51466 .6365 .52686 .65837 .52044 .64765 .50815 Metetra
.973 .114 0 r
.64765 .50815 .65837 .52044 .68041 .514 .66981 .50161 Metetra
.974 .111 0 r
.66981 .50161 .68041 .514 .70263 .50753 .69215 .49505 Metetra
.975 .108 0 r
.69215 .49505 .70263 .50753 .72504 .50105 .71467 .48847 Metetra
.976 .103 0 r
.71467 .48847 .72504 .50105 .74762 .49455 .73738 .48187 Metetra
.977 .099 0 r
.73738 .48187 .74762 .49455 .77039 .488 .76027 .47521 Metetra
.977 .098 0 r
.76027 .47521 .77039 .488 .7933 .48093 .78332 .46804 Metetra
.968 .134 0 r
.78332 .46804 .7933 .48093 .816 .46922 .80616 .45622 Metetra
.911 .35 0 r
.80616 .45622 .816 .46922 .8367 .43549 .82706 .42229 Metetra
.578 .723 0 r
.82706 .42229 .8367 .43549 .85217 .35284 .84282 .3393 Metetra
.288 .642 0 r
.20025 .50558 .2127 .51655 .22332 .59557 .21057 .58479 Metetra
.878 .464 0 r
.21057 .58479 .22332 .59557 .23904 .6255 .22621 .61477 Metetra
.961 .164 0 r
.22621 .61477 .23904 .6255 .25744 .62743 .24467 .61665 Metetra
.976 .101 0 r
.24467 .61665 .25744 .62743 .27658 .62222 .26389 .61136 Metetra
.977 .098 0 r
.26389 .61136 .27658 .62222 .29592 .61609 .28332 .60515 Metetra
.976 .102 0 r
.28332 .60515 .29592 .61609 .31541 .60989 .30289 .59886 Metetra
.975 .106 0 r
.30289 .59886 .31541 .60989 .33503 .60367 .32261 .59255 Metetra
.974 .11 0 r
.32261 .59255 .33503 .60367 .3548 .59743 .34247 .58623 Metetra
.973 .113 0 r
.34247 .58623 .3548 .59743 .37471 .59118 .36247 .5799 Metetra
.972 .116 0 r
.36247 .5799 .37471 .59118 .39477 .58491 .38262 .57354 Metetra
.972 .119 0 r
.38262 .57354 .39477 .58491 .41498 .57862 .40292 .56717 Metetra
.971 .121 0 r
.40292 .56717 .41498 .57862 .43533 .57232 .42338 .56078 Metetra
.971 .122 0 r
.42338 .56078 .43533 .57232 .45584 .566 .44398 .55437 Metetra
.971 .123 0 r
.44398 .55437 .45584 .566 .4765 .55965 .46474 .54793 Metetra
.971 .124 0 r
.46474 .54793 .4765 .55965 .49732 .55329 .48567 .54148 Metetra
.97 .124 0 r
.48567 .54148 .49732 .55329 .5183 .54691 .50675 .535 Metetra
.971 .124 0 r
.50675 .535 .5183 .54691 .53944 .5405 .528 .52851 Metetra
.971 .123 0 r
.528 .52851 .53944 .5405 .56074 .53407 .54941 .52199 Metetra
.971 .122 0 r
.54941 .52199 .56074 .53407 .58221 .52762 .57099 .51544 Metetra
.971 .121 0 r
.57099 .51544 .58221 .52762 .60385 .52115 .59274 .50888 Metetra
.972 .119 0 r
.59274 .50888 .60385 .52115 .62566 .51466 .61466 .50229 Metetra
.972 .117 0 r
.61466 .50229 .62566 .51466 .64765 .50815 .63676 .49568 Metetra
.973 .114 0 r
.63676 .49568 .64765 .50815 .66981 .50161 .65904 .48904 Metetra
.974 .111 0 r
.65904 .48904 .66981 .50161 .69215 .49505 .68151 .48238 Metetra
.975 .107 0 r
.68151 .48238 .69215 .49505 .71467 .48847 .70415 .4757 Metetra
.976 .103 0 r
.70415 .4757 .71467 .48847 .73738 .48187 .72699 .469 Metetra
.977 .099 0 r
.72699 .469 .73738 .48187 .76027 .47521 .75001 .46225 Metetra
.977 .098 0 r
.75001 .46225 .76027 .47521 .78332 .46804 .77319 .45497 Metetra
.968 .134 0 r
.77319 .45497 .78332 .46804 .80616 .45622 .79617 .44303 Metetra
.911 .35 0 r
.79617 .44303 .80616 .45622 .82706 .42229 .81727 .40891 Metetra
.579 .723 0 r
.81727 .40891 .82706 .42229 .84282 .3393 .83334 .32558 Metetra
.288 .642 0 r
.18763 .49447 .20025 .50558 .21057 .58479 .19765 .57388 Metetra
.878 .464 0 r
.19765 .57388 .21057 .58479 .22621 .61477 .21322 .6039 Metetra
.961 .164 0 r
.21322 .6039 .22621 .61477 .24467 .61665 .23172 .60572 Metetra
.976 .101 0 r
.23172 .60572 .24467 .61665 .26389 .61136 .25102 .60035 Metetra
.977 .098 0 r
.25102 .60035 .26389 .61136 .28332 .60515 .27054 .59405 Metetra
.976 .102 0 r
.27054 .59405 .28332 .60515 .30289 .59886 .2902 .58768 Metetra
.975 .106 0 r
.2902 .58768 .30289 .59886 .32261 .59255 .31001 .58129 Metetra
.974 .11 0 r
.31001 .58129 .32261 .59255 .34247 .58623 .32996 .57488 Metetra
.973 .113 0 r
.32996 .57488 .34247 .58623 .36247 .5799 .35005 .56846 Metetra
.972 .116 0 r
.35005 .56846 .36247 .5799 .38262 .57354 .3703 .56202 Metetra
.972 .118 0 r
.3703 .56202 .38262 .57354 .40292 .56717 .3907 .55556 Metetra
.971 .12 0 r
.3907 .55556 .40292 .56717 .42338 .56078 .41125 .54908 Metetra
.971 .122 0 r
.41125 .54908 .42338 .56078 .44398 .55437 .43196 .54257 Metetra
.971 .123 0 r
.43196 .54257 .44398 .55437 .46474 .54793 .45282 .53605 Metetra
.971 .124 0 r
.45282 .53605 .46474 .54793 .48567 .54148 .47385 .5295 Metetra
.971 .124 0 r
.47385 .5295 .48567 .54148 .50675 .535 .49503 .52294 Metetra
.971 .124 0 r
.49503 .52294 .50675 .535 .528 .52851 .51639 .51634 Metetra
.971 .123 0 r
.51639 .51634 .528 .52851 .54941 .52199 .53791 .50973 Metetra
.971 .122 0 r
.53791 .50973 .54941 .52199 .57099 .51544 .5596 .50309 Metetra
.971 .121 0 r
.5596 .50309 .57099 .51544 .59274 .50888 .58147 .49643 Metetra
.972 .119 0 r
.58147 .49643 .59274 .50888 .61466 .50229 .60351 .48974 Metetra
.972 .117 0 r
.60351 .48974 .61466 .50229 .63676 .49568 .62572 .48303 Metetra
.973 .114 0 r
.62572 .48303 .63676 .49568 .65904 .48904 .64812 .47629 Metetra
.974 .111 0 r
.64812 .47629 .65904 .48904 .68151 .48238 .67071 .46954 Metetra
.975 .107 0 r
.67071 .46954 .68151 .48238 .70415 .4757 .69348 .46275 Metetra
.976 .103 0 r
.69348 .46275 .70415 .4757 .72699 .469 .71644 .45595 Metetra
.977 .099 0 r
.71644 .45595 .72699 .469 .75001 .46225 .73959 .44909 Metetra
.977 .098 0 r
.73959 .44909 .75001 .46225 .77319 .45497 .7629 .44171 Metetra
.968 .134 0 r
.7629 .44171 .77319 .45497 .79617 .44303 .78603 .42964 Metetra
.912 .349 0 r
.78603 .42964 .79617 .44303 .81727 .40891 .80733 .39533 Metetra
.579 .723 0 r
.80733 .39533 .81727 .40891 .83334 .32558 .82372 .31166 Metetra
.289 .642 0 r
.17484 .48323 .18763 .49447 .19765 .57388 .18456 .56283 Metetra
.878 .464 0 r
.18456 .56283 .19765 .57388 .21322 .6039 .20004 .59288 Metetra
.961 .164 0 r
.20004 .59288 .21322 .6039 .23172 .60572 .21859 .59465 Metetra
.976 .1 0 r
.21859 .59465 .23172 .60572 .25102 .60035 .23797 .5892 Metetra
.977 .097 0 r
.23797 .5892 .25102 .60035 .27054 .59405 .25758 .58281 Metetra
.976 .102 0 r
.25758 .58281 .27054 .59405 .2902 .58768 .27733 .57635 Metetra
.975 .106 0 r
.27733 .57635 .2902 .58768 .31001 .58129 .29723 .56988 Metetra
.974 .11 0 r
.29723 .56988 .31001 .58129 .32996 .57488 .31727 .56338 Metetra
.973 .113 0 r
.31727 .56338 .32996 .57488 .35005 .56846 .33746 .55687 Metetra
.973 .116 0 r
.33746 .55687 .35005 .56846 .3703 .56202 .35781 .55034 Metetra
.972 .118 0 r
.35781 .55034 .3703 .56202 .3907 .55556 .3783 .54378 Metetra
.971 .12 0 r
.3783 .54378 .3907 .55556 .41125 .54908 .39895 .53721 Metetra
.971 .122 0 r
.39895 .53721 .41125 .54908 .43196 .54257 .41976 .53062 Metetra
.971 .123 0 r
.41976 .53062 .43196 .54257 .45282 .53605 .44073 .524 Metetra
.971 .124 0 r
.44073 .524 .45282 .53605 .47385 .5295 .46186 .51736 Metetra
.971 .124 0 r
.46186 .51736 .47385 .5295 .49503 .52294 .48315 .5107 Metetra
.971 .124 0 r
.48315 .5107 .49503 .52294 .51639 .51634 .50461 .50401 Metetra
.971 .123 0 r
.50461 .50401 .51639 .51634 .53791 .50973 .52624 .4973 Metetra
.971 .122 0 r
.52624 .4973 .53791 .50973 .5596 .50309 .54805 .49056 Metetra
.971 .121 0 r
.54805 .49056 .5596 .50309 .58147 .49643 .57003 .4838 Metetra
.972 .119 0 r
.57003 .4838 .58147 .49643 .60351 .48974 .59218 .47701 Metetra
.972 .117 0 r
.59218 .47701 .60351 .48974 .62572 .48303 .61452 .4702 Metetra
.973 .114 0 r
.61452 .4702 .62572 .48303 .64812 .47629 .63704 .46336 Metetra
.974 .111 0 r
.63704 .46336 .64812 .47629 .67071 .46954 .65975 .4565 Metetra
.975 .107 0 r
.65975 .4565 .67071 .46954 .69348 .46275 .68264 .44961 Metetra
.976 .103 0 r
.68264 .44961 .69348 .46275 .71644 .45595 .70573 .4427 Metetra
.977 .099 0 r
.70573 .4427 .71644 .45595 .73959 .44909 .72901 .43574 Metetra
.977 .097 0 r
.72901 .43574 .73959 .44909 .7629 .44171 .75246 .42825 Metetra
.968 .133 0 r
.75246 .42825 .7629 .44171 .78603 .42964 .77574 .41606 Metetra
.912 .349 0 r
.77574 .41606 .78603 .42964 .80733 .39533 .79725 .38155 Metetra
.58 .723 0 r
.79725 .38155 .80733 .39533 .82372 .31166 .81396 .29755 Metetra
.289 .642 0 r
.16189 .47184 .17484 .48323 .18456 .56283 .17128 .55164 Metetra
.878 .463 0 r
.17128 .55164 .18456 .56283 .20004 .59288 .18668 .58172 Metetra
.961 .163 0 r
.18668 .58172 .20004 .59288 .21859 .59465 .20528 .58343 Metetra
.976 .1 0 r
.20528 .58343 .21859 .59465 .23797 .5892 .22475 .57789 Metetra
.977 .097 0 r
.22475 .57789 .23797 .5892 .25758 .58281 .24444 .57142 Metetra
.976 .101 0 r
.24444 .57142 .25758 .58281 .27733 .57635 .26428 .56487 Metetra
.975 .106 0 r
.26428 .56487 .27733 .57635 .29723 .56988 .28427 .5583 Metetra
.974 .109 0 r
.28427 .5583 .29723 .56988 .31727 .56338 .30441 .55172 Metetra
.973 .113 0 r
.30441 .55172 .31727 .56338 .33746 .55687 .32469 .54512 Metetra
.973 .116 0 r
.32469 .54512 .33746 .55687 .35781 .55034 .34513 .53849 Metetra
.972 .118 0 r
.34513 .53849 .35781 .55034 .3783 .54378 .36573 .53185 Metetra
.972 .12 0 r
.36573 .53185 .3783 .54378 .39895 .53721 .38648 .52518 Metetra
.971 .121 0 r
.38648 .52518 .39895 .53721 .41976 .53062 .40739 .51849 Metetra
.971 .123 0 r
.40739 .51849 .41976 .53062 .44073 .524 .42846 .51178 Metetra
.971 .123 0 r
.42846 .51178 .44073 .524 .46186 .51736 .44969 .50504 Metetra
.971 .124 0 r
.44969 .50504 .46186 .51736 .48315 .5107 .47109 .49828 Metetra
.971 .123 0 r
.47109 .49828 .48315 .5107 .50461 .50401 .49266 .4915 Metetra
.971 .123 0 r
.49266 .4915 .50461 .50401 .52624 .4973 .51441 .48469 Metetra
.971 .122 0 r
.51441 .48469 .52624 .4973 .54805 .49056 .53632 .47785 Metetra
.971 .12 0 r
.53632 .47785 .54805 .49056 .57003 .4838 .55842 .47099 Metetra
.972 .119 0 r
.55842 .47099 .57003 .4838 .59218 .47701 .58069 .4641 Metetra
.972 .116 0 r
.58069 .4641 .59218 .47701 .61452 .4702 .60315 .45718 Metetra
.973 .114 0 r
.60315 .45718 .61452 .4702 .63704 .46336 .62579 .45024 Metetra
.974 .11 0 r
.62579 .45024 .63704 .46336 .65975 .4565 .64862 .44327 Metetra
.975 .107 0 r
.64862 .44327 .65975 .4565 .68264 .44961 .67165 .43628 Metetra
.976 .103 0 r
.67165 .43628 .68264 .44961 .70573 .4427 .69486 .42926 Metetra
.977 .098 0 r
.69486 .42926 .70573 .4427 .72901 .43574 .71828 .42219 Metetra
.977 .097 0 r
.71828 .42219 .72901 .43574 .75246 .42825 .74186 .41459 Metetra
.968 .133 0 r
.74186 .41459 .75246 .42825 .77574 .41606 .76529 .40228 Metetra
.912 .349 0 r
.76529 .40228 .77574 .41606 .79725 .38155 .78701 .36758 Metetra
.58 .724 0 r
.78701 .36758 .79725 .38155 .81396 .29755 .80405 .28324 Metetra
.29 .643 0 r
.14876 .46032 .16189 .47184 .17128 .55164 .15783 .54031 Metetra
.878 .463 0 r
.15783 .54031 .17128 .55164 .18668 .58172 .17314 .57042 Metetra
.961 .163 0 r
.17314 .57042 .18668 .58172 .20528 .58343 .19179 .57206 Metetra
.977 .099 0 r
.19179 .57206 .20528 .58343 .22475 .57789 .21133 .56644 Metetra
.977 .097 0 r
.21133 .56644 .22475 .57789 .24444 .57142 .23112 .55988 Metetra
.976 .101 0 r
.23112 .55988 .24444 .57142 .26428 .56487 .25105 .55323 Metetra
.975 .105 0 r
.25105 .55323 .26428 .56487 .28427 .5583 .27113 .54658 Metetra
.974 .109 0 r
.27113 .54658 .28427 .5583 .30441 .55172 .29136 .5399 Metetra
.973 .112 0 r
.29136 .5399 .30441 .55172 .32469 .54512 .31174 .5332 Metetra
.973 .115 0 r
.31174 .5332 .32469 .54512 .34513 .53849 .33228 .52648 Metetra
.972 .118 0 r
.33228 .52648 .34513 .53849 .36573 .53185 .35297 .51974 Metetra
.972 .12 0 r
.35297 .51974 .36573 .53185 .38648 .52518 .37382 .51298 Metetra
.971 .121 0 r
.37382 .51298 .38648 .52518 .40739 .51849 .39483 .5062 Metetra
.971 .122 0 r
.39483 .5062 .40739 .51849 .42846 .51178 .41601 .49939 Metetra
.971 .123 0 r
.41601 .49939 .42846 .51178 .44969 .50504 .43735 .49255 Metetra
.971 .123 0 r
.43735 .49255 .44969 .50504 .47109 .49828 .45886 .48569 Metetra
.971 .123 0 r
.45886 .48569 .47109 .49828 .49266 .4915 .48054 .4788 Metetra
.971 .123 0 r
.48054 .4788 .49266 .4915 .51441 .48469 .50239 .47189 Metetra
.971 .122 0 r
.50239 .47189 .51441 .48469 .53632 .47785 .52443 .46495 Metetra
.971 .12 0 r
.52443 .46495 .53632 .47785 .55842 .47099 .54664 .45799 Metetra
.972 .118 0 r
.54664 .45799 .55842 .47099 .58069 .4641 .56903 .451 Metetra
.972 .116 0 r
.56903 .451 .58069 .4641 .60315 .45718 .59161 .44398 Metetra
.973 .113 0 r
.59161 .44398 .60315 .45718 .62579 .45024 .61437 .43693 Metetra
.974 .11 0 r
.61437 .43693 .62579 .45024 .64862 .44327 .63733 .42985 Metetra
.975 .106 0 r
.63733 .42985 .64862 .44327 .67165 .43628 .66048 .42275 Metetra
.976 .102 0 r
.66048 .42275 .67165 .43628 .69486 .42926 .68383 .41562 Metetra
.977 .098 0 r
.68383 .41562 .69486 .42926 .71828 .42219 .70738 .40844 Metetra
.977 .097 0 r
.70738 .40844 .71828 .42219 .74186 .41459 .73109 .40073 Metetra
.968 .132 0 r
.73109 .40073 .74186 .41459 .76529 .40228 .75467 .38829 Metetra
.912 .348 0 r
.75467 .38829 .76529 .40228 .78701 .36758 .77661 .35339 Metetra
.581 .724 0 r
.77661 .35339 .78701 .36758 .80405 .28324 .79399 .26872 Metetra
.291 .643 0 r
.13546 .44866 .14876 .46032 .15783 .54031 .14418 .52883 Metetra
.879 .462 0 r
.14418 .52883 .15783 .54031 .17314 .57042 .1594 .55896 Metetra
.961 .162 0 r
.1594 .55896 .17314 .57042 .19179 .57206 .1781 .56053 Metetra
.977 .099 0 r
.1781 .56053 .19179 .57206 .21133 .56644 .19773 .55482 Metetra
.977 .096 0 r
.19773 .55482 .21133 .56644 .23112 .55988 .2176 .54817 Metetra
.976 .1 0 r
.2176 .54817 .23112 .55988 .25105 .55323 .23763 .54144 Metetra
.975 .105 0 r
.23763 .54144 .25105 .55323 .27113 .54658 .2578 .53468 Metetra
.974 .109 0 r
.2578 .53468 .27113 .54658 .29136 .5399 .27813 .52791 Metetra
.973 .112 0 r
.27813 .52791 .29136 .5399 .31174 .5332 .2986 .52112 Metetra
.973 .115 0 r
.2986 .52112 .31174 .5332 .33228 .52648 .31924 .51431 Metetra
.972 .117 0 r
.31924 .51431 .33228 .52648 .35297 .51974 .34003 .50747 Metetra
.972 .119 0 r
.34003 .50747 .35297 .51974 .37382 .51298 .36098 .50061 Metetra
.971 .121 0 r
.36098 .50061 .37382 .51298 .39483 .5062 .38209 .49373 Metetra
.971 .122 0 r
.38209 .49373 .39483 .5062 .41601 .49939 .40337 .48682 Metetra
.971 .123 0 r
.40337 .48682 .41601 .49939 .43735 .49255 .42482 .47988 Metetra
.971 .123 0 r
.42482 .47988 .43735 .49255 .45886 .48569 .44644 .47292 Metetra
.971 .123 0 r
.44644 .47292 .45886 .48569 .48054 .4788 .46823 .46593 Metetra
.971 .122 0 r
.46823 .46593 .48054 .4788 .50239 .47189 .4902 .45891 Metetra
.971 .121 0 r
.4902 .45891 .50239 .47189 .52443 .46495 .51235 .45187 Metetra
.972 .12 0 r
.51235 .45187 .52443 .46495 .54664 .45799 .53468 .4448 Metetra
.972 .118 0 r
.53468 .4448 .54664 .45799 .56903 .451 .55719 .4377 Metetra
.973 .115 0 r
.55719 .4377 .56903 .451 .59161 .44398 .57989 .43057 Metetra
.973 .113 0 r
.57989 .43057 .59161 .44398 .61437 .43693 .60278 .42342 Metetra
.974 .11 0 r
.60278 .42342 .61437 .43693 .63733 .42985 .62586 .41623 Metetra
.975 .106 0 r
.62586 .41623 .63733 .42985 .66048 .42275 .64914 .40902 Metetra
.976 .102 0 r
.64914 .40902 .66048 .42275 .68383 .41562 .67262 .40178 Metetra
.977 .097 0 r
.67262 .40178 .68383 .41562 .70738 .40844 .69631 .39449 Metetra
.977 .096 0 r
.69631 .39449 .70738 .40844 .73109 .40073 .72016 .38666 Metetra
.969 .132 0 r
.72016 .38666 .73109 .40073 .75467 .38829 .7439 .37409 Metetra
.912 .347 0 r
.7439 .37409 .75467 .38829 .77661 .35339 .76605 .339 Metetra
.582 .724 0 r
.76605 .339 .77661 .35339 .79399 .26872 .78378 .25399 Metetra
.292 .643 0 r
.12197 .43684 .13546 .44866 .14418 .52883 .13035 .5172 Metetra
.879 .461 0 r
.13035 .5172 .14418 .52883 .1594 .55896 .14547 .54735 Metetra
.961 .161 0 r
.14547 .54735 .1594 .55896 .1781 .56053 .16422 .54886 Metetra
.977 .098 0 r
.16422 .54886 .1781 .56053 .19773 .55482 .18393 .54306 Metetra
.977 .095 0 r
.18393 .54306 .19773 .55482 .2176 .54817 .2039 .53631 Metetra
.976 .1 0 r
.2039 .53631 .2176 .54817 .23763 .54144 .22401 .52948 Metetra
.975 .104 0 r
.22401 .52948 .23763 .54144 .2578 .53468 .24428 .52263 Metetra
.974 .108 0 r
.24428 .52263 .2578 .53468 .27813 .52791 .2647 .51576 Metetra
.974 .111 0 r
.2647 .51576 .27813 .52791 .2986 .52112 .28527 .50887 Metetra
.973 .114 0 r
.28527 .50887 .2986 .52112 .31924 .51431 .306 .50196 Metetra
.972 .117 0 r
.306 .50196 .31924 .51431 .34003 .50747 .3269 .49502 Metetra
.972 .119 0 r
.3269 .49502 .34003 .50747 .36098 .50061 .34795 .48806 Metetra
.971 .12 0 r
.34795 .48806 .36098 .50061 .38209 .49373 .36917 .48108 Metetra
.971 .121 0 r
.36917 .48108 .38209 .49373 .40337 .48682 .39056 .47407 Metetra
.971 .122 0 r
.39056 .47407 .40337 .48682 .42482 .47988 .41211 .46703 Metetra
.971 .122 0 r
.41211 .46703 .42482 .47988 .44644 .47292 .43384 .45996 Metetra
.971 .122 0 r
.43384 .45996 .44644 .47292 .46823 .46593 .45575 .45287 Metetra
.971 .122 0 r
.45575 .45287 .46823 .46593 .4902 .45891 .47783 .44575 Metetra
.971 .121 0 r
.47783 .44575 .4902 .45891 .51235 .45187 .50009 .4386 Metetra
.972 .119 0 r
.50009 .4386 .51235 .45187 .53468 .4448 .52254 .43142 Metetra
.972 .117 0 r
.52254 .43142 .53468 .4448 .55719 .4377 .54517 .42421 Metetra
.973 .115 0 r
.54517 .42421 .55719 .4377 .57989 .43057 .56799 .41697 Metetra
.973 .112 0 r
.56799 .41697 .57989 .43057 .60278 .42342 .59101 .40971 Metetra
.974 .109 0 r
.59101 .40971 .60278 .42342 .62586 .41623 .61422 .40241 Metetra
.975 .105 0 r
.61422 .40241 .62586 .41623 .64914 .40902 .63763 .39509 Metetra
.976 .101 0 r
.63763 .39509 .64914 .40902 .67262 .40178 .66125 .38773 Metetra
.977 .097 0 r
.66125 .38773 .67262 .40178 .69631 .39449 .68506 .38032 Metetra
.977 .095 0 r
.68506 .38032 .69631 .39449 .72016 .38666 .70906 .37237 Metetra
.969 .131 0 r
.70906 .37237 .72016 .38666 .7439 .37409 .73295 .35967 Metetra
.912 .347 0 r
.73295 .35967 .7439 .37409 .76605 .339 .75533 .32439 Metetra
.583 .724 0 r
.75533 .32439 .76605 .339 .78378 .25399 .77342 .23905 Metetra
.293 .644 0 r
.1083 .42488 .12197 .43684 .13035 .5172 .11632 .50542 Metetra
.879 .46 0 r
.11632 .50542 .13035 .5172 .14547 .54735 .13135 .53559 Metetra
.961 .161 0 r
.13135 .53559 .14547 .54735 .16422 .54886 .15014 .53702 Metetra
.977 .097 0 r
.15014 .53702 .16422 .54886 .18393 .54306 .16994 .53113 Metetra
.978 .095 0 r
.16994 .53113 .18393 .54306 .2039 .53631 .18999 .52428 Metetra
.977 .099 0 r
.18999 .52428 .2039 .53631 .22401 .52948 .2102 .51735 Metetra
.976 .103 0 r
.2102 .51735 .22401 .52948 .24428 .52263 .23056 .51041 Metetra
.975 .107 0 r
.23056 .51041 .24428 .52263 .2647 .51576 .25108 .50344 Metetra
.974 .111 0 r
.25108 .50344 .2647 .51576 .28527 .50887 .27175 .49645 Metetra
.973 .114 0 r
.27175 .49645 .28527 .50887 .306 .50196 .29258 .48944 Metetra
.972 .116 0 r
.29258 .48944 .306 .50196 .3269 .49502 .31357 .4824 Metetra
.972 .118 0 r
.31357 .4824 .3269 .49502 .34795 .48806 .33473 .47534 Metetra
.972 .12 0 r
.33473 .47534 .34795 .48806 .36917 .48108 .35605 .46825 Metetra
.971 .121 0 r
.35605 .46825 .36917 .48108 .39056 .47407 .37755 .46113 Metetra
.971 .122 0 r
.37755 .46113 .39056 .47407 .41211 .46703 .39921 .45399 Metetra
.971 .122 0 r
.39921 .45399 .41211 .46703 .43384 .45996 .42105 .44682 Metetra
.971 .122 0 r
.42105 .44682 .43384 .45996 .45575 .45287 .44307 .43962 Metetra
.971 .121 0 r
.44307 .43962 .45575 .45287 .47783 .44575 .46527 .43239 Metetra
.971 .12 0 r
.46527 .43239 .47783 .44575 .50009 .4386 .48765 .42513 Metetra
.972 .119 0 r
.48765 .42513 .50009 .4386 .52254 .43142 .51021 .41784 Metetra
.972 .117 0 r
.51021 .41784 .52254 .43142 .54517 .42421 .53297 .41052 Metetra
.973 .114 0 r
.53297 .41052 .54517 .42421 .56799 .41697 .55592 .40317 Metetra
.974 .112 0 r
.55592 .40317 .56799 .41697 .59101 .40971 .57906 .39579 Metetra
.974 .108 0 r
.57906 .39579 .59101 .40971 .61422 .40241 .6024 .38838 Metetra
.975 .105 0 r
.6024 .38838 .61422 .40241 .63763 .39509 .62594 .38094 Metetra
.976 .1 0 r
.62594 .38094 .63763 .39509 .66125 .38773 .64969 .37347 Metetra
.977 .096 0 r
.64969 .37347 .66125 .38773 .68506 .38032 .67364 .36594 Metetra
.978 .095 0 r
.67364 .36594 .68506 .38032 .70906 .37237 .69778 .35787 Metetra
.969 .13 0 r
.69778 .35787 .70906 .37237 .73295 .35967 .72183 .34504 Metetra
.913 .346 0 r
.72183 .34504 .73295 .35967 .75533 .32439 .74444 .30956 Metetra
.584 .725 0 r
.74444 .30956 .75533 .32439 .77342 .23905 .76289 .22389 Metetra
.294 .644 0 r
.09444 .41277 .1083 .42488 .11632 .50542 .10209 .49348 Metetra
.879 .459 0 r
.10209 .49348 .11632 .50542 .13135 .53559 .11701 .52367 Metetra
.962 .16 0 r
.11701 .52367 .13135 .53559 .15014 .53702 .13585 .52502 Metetra
.977 .096 0 r
.13585 .52502 .15014 .53702 .16994 .53113 .15574 .51903 Metetra
.978 .094 0 r
.15574 .51903 .16994 .53113 .18999 .52428 .17588 .51209 Metetra
.977 .098 0 r
.17588 .51209 .18999 .52428 .2102 .51735 .19618 .50506 Metetra
.976 .103 0 r
.19618 .50506 .2102 .51735 .23056 .51041 .21664 .49801 Metetra
.975 .107 0 r
.21664 .49801 .23056 .51041 .25108 .50344 .23725 .49094 Metetra
.974 .11 0 r
.23725 .49094 .25108 .50344 .27175 .49645 .25802 .48385 Metetra
.973 .113 0 r
.25802 .48385 .27175 .49645 .29258 .48944 .27895 .47674 Metetra
.973 .115 0 r
.27895 .47674 .29258 .48944 .31357 .4824 .30005 .46959 Metetra
.972 .117 0 r
.30005 .46959 .31357 .4824 .33473 .47534 .32131 .46243 Metetra
.972 .119 0 r
.32131 .46243 .33473 .47534 .35605 .46825 .34274 .45523 Metetra
.971 .12 0 r
.34274 .45523 .35605 .46825 .37755 .46113 .36434 .44801 Metetra
.971 .121 0 r
.36434 .44801 .37755 .46113 .39921 .45399 .38611 .44076 Metetra
.971 .121 0 r
.38611 .44076 .39921 .45399 .42105 .44682 .40807 .43348 Metetra
.971 .121 0 r
.40807 .43348 .42105 .44682 .44307 .43962 .4302 .42617 Metetra
.971 .12 0 r
.4302 .42617 .44307 .43962 .46527 .43239 .45251 .41883 Metetra
.972 .119 0 r
.45251 .41883 .46527 .43239 .48765 .42513 .47501 .41146 Metetra
.972 .118 0 r
.47501 .41146 .48765 .42513 .51021 .41784 .4977 .40406 Metetra
.972 .116 0 r
.4977 .40406 .51021 .41784 .53297 .41052 .52058 .39662 Metetra
.973 .114 0 r
.52058 .39662 .53297 .41052 .55592 .40317 .54365 .38916 Metetra
.974 .111 0 r
.54365 .38916 .55592 .40317 .57906 .39579 .56692 .38166 Metetra
.975 .108 0 r
.56692 .38166 .57906 .39579 .6024 .38838 .59039 .37414 Metetra
.975 .104 0 r
.59039 .37414 .6024 .38838 .62594 .38094 .61407 .36658 Metetra
.976 .099 0 r
.61407 .36658 .62594 .38094 .64969 .37347 .63795 .35899 Metetra
.978 .095 0 r
.63795 .35899 .64969 .37347 .67364 .36594 .66204 .35134 Metetra
.978 .094 0 r
.66204 .35134 .67364 .36594 .69778 .35787 .68633 .34315 Metetra
.969 .129 0 r
.68633 .34315 .69778 .35787 .72183 .34504 .71054 .33018 Metetra
.913 .345 0 r
.71054 .33018 .72183 .34504 .74444 .30956 .73337 .29451 Metetra
.586 .725 0 r
.73337 .29451 .74444 .30956 .76289 .22389 .75221 .2085 Metetra
.295 .644 0 r
.08039 .40044 .09444 .41277 .10209 .49348 .08767 .48131 Metetra
.88 .459 0 r
.08767 .48131 .10209 .49348 .11701 .52367 .10248 .5115 Metetra
.962 .159 0 r
.10248 .5115 .11701 .52367 .13585 .52502 .12137 .51278 Metetra
.977 .096 0 r
.12137 .51278 .13585 .52502 .15574 .51903 .14134 .50669 Metetra
.978 .093 0 r
.14134 .50669 .15574 .51903 .17588 .51209 .16157 .49965 Metetra
.977 .098 0 r
.16157 .49965 .17588 .51209 .19618 .50506 .18197 .49252 Metetra
.976 .102 0 r
.18197 .49252 .19618 .50506 .21664 .49801 .20252 .48537 Metetra
.975 .106 0 r
.20252 .48537 .21664 .49801 .23725 .49094 .22323 .4782 Metetra
.974 .11 0 r
.22323 .4782 .23725 .49094 .25802 .48385 .2441 .47101 Metetra
.973 .113 0 r
.2441 .47101 .25802 .48385 .27895 .47674 .26513 .46379 Metetra
.973 .115 0 r
.26513 .46379 .27895 .47674 .30005 .46959 .28633 .45654 Metetra
.972 .117 0 r
.28633 .45654 .30005 .46959 .32131 .46243 .30769 .44927 Metetra
.972 .119 0 r
.30769 .44927 .32131 .46243 .34274 .45523 .32923 .44196 Metetra
.972 .12 0 r
.32923 .44196 .34274 .45523 .36434 .44801 .35094 .43463 Metetra
.971 .121 0 r
.35094 .43463 .36434 .44801 .38611 .44076 .37282 .42727 Metetra
.971 .121 0 r
.37282 .42727 .38611 .44076 .40807 .43348 .39489 .41988 Metetra
.971 .121 0 r
.39489 .41988 .40807 .43348 .4302 .42617 .41713 .41246 Metetra
.971 .12 0 r
.41713 .41246 .4302 .42617 .45251 .41883 .43956 .405 Metetra
.972 .119 0 r
.43956 .405 .45251 .41883 .47501 .41146 .46218 .39752 Metetra
.972 .118 0 r
.46218 .39752 .47501 .41146 .4977 .40406 .48499 .39 Metetra
.973 .116 0 r
.48499 .39 .4977 .40406 .52058 .39662 .50799 .38245 Metetra
.973 .113 0 r
.50799 .38245 .52058 .39662 .54365 .38916 .53119 .37487 Metetra
.974 .11 0 r
.53119 .37487 .54365 .38916 .56692 .38166 .55459 .36725 Metetra
.975 .107 0 r
.55459 .36725 .56692 .38166 .59039 .37414 .57819 .35961 Metetra
.976 .103 0 r
.57819 .35961 .59039 .37414 .61407 .36658 .602 .35192 Metetra
.977 .099 0 r
.602 .35192 .61407 .36658 .63795 .35899 .62602 .34421 Metetra
.978 .094 0 r
.62602 .34421 .63795 .35899 .66204 .35134 .65025 .33644 Metetra
.978 .093 0 r
.65025 .33644 .66204 .35134 .68633 .34315 .67468 .32812 Metetra
.969 .129 0 r
.67468 .32812 .68633 .34315 .71054 .33018 .69906 .31501 Metetra
.913 .344 0 r
.69906 .31501 .71054 .33018 .73337 .29451 .72213 .27915 Metetra
.587 .725 0 r
.72213 .27915 .73337 .29451 .75221 .2085 .74135 .19282 Metetra
.291 .643 0 r
.06625 .38724 .08039 .40044 .08767 .48131 .07317 .46797 Metetra
.878 .465 0 r
.07317 .46797 .08767 .48131 .10248 .5115 .08789 .49806 Metetra
.96 .167 0 r
.08789 .49806 .10248 .5115 .12137 .51278 .10681 .49925 Metetra
.975 .104 0 r
.10681 .49925 .12137 .51278 .14134 .50669 .12686 .49309 Metetra
.976 .101 0 r
.12686 .49309 .14134 .50669 .16157 .49965 .14718 .48597 Metetra
.975 .106 0 r
.14718 .48597 .16157 .49965 .18197 .49252 .16766 .47877 Metetra
.974 .11 0 r
.16766 .47877 .18197 .49252 .20252 .48537 .1883 .47153 Metetra
.973 .114 0 r
.1883 .47153 .20252 .48537 .22323 .4782 .20909 .46428 Metetra
.972 .117 0 r
.20909 .46428 .22323 .4782 .2441 .47101 .23005 .45699 Metetra
.972 .12 0 r
.23005 .45699 .2441 .47101 .26513 .46379 .25118 .44967 Metetra
.971 .122 0 r
.25118 .44967 .26513 .46379 .28633 .45654 .27247 .44233 Metetra
.97 .124 0 r
.27247 .44233 .28633 .45654 .30769 .44927 .29394 .43495 Metetra
.97 .126 0 r
.29394 .43495 .30769 .44927 .32923 .44196 .31557 .42755 Metetra
.97 .127 0 r
.31557 .42755 .32923 .44196 .35094 .43463 .33738 .42011 Metetra
.97 .127 0 r
.33738 .42011 .35094 .43463 .37282 .42727 .35937 .41264 Metetra
.97 .128 0 r
.35937 .41264 .37282 .42727 .39489 .41988 .38154 .40513 Metetra
.97 .128 0 r
.38154 .40513 .39489 .41988 .41713 .41246 .4039 .39759 Metetra
.97 .127 0 r
.4039 .39759 .41713 .41246 .43956 .405 .42644 .39001 Metetra
.97 .126 0 r
.42644 .39001 .43956 .405 .46218 .39752 .44917 .3824 Metetra
.97 .125 0 r
.44917 .3824 .46218 .39752 .48499 .39 .4721 .37476 Metetra
.971 .123 0 r
.4721 .37476 .48499 .39 .50799 .38245 .49522 .36707 Metetra
.971 .12 0 r
.49522 .36707 .50799 .38245 .53119 .37487 .51854 .35935 Metetra
.972 .118 0 r
.51854 .35935 .53119 .37487 .55459 .36725 .54206 .3516 Metetra
.973 .115 0 r
.54206 .3516 .55459 .36725 .57819 .35961 .56579 .3438 Metetra
.974 .111 0 r
.56579 .3438 .57819 .35961 .602 .35192 .58972 .33597 Metetra
.975 .107 0 r
.58972 .33597 .602 .35192 .62602 .34421 .61387 .3281 Metetra
.976 .102 0 r
.61387 .3281 .62602 .34421 .65025 .33644 .63824 .32017 Metetra
.976 .101 0 r
.63824 .32017 .65025 .33644 .67468 .32812 .6628 .31169 Metetra
.967 .137 0 r
.6628 .31169 .67468 .32812 .69906 .31501 .68733 .29842 Metetra
.911 .351 0 r
.68733 .29842 .69906 .31501 .72213 .27915 .71063 .26244 Metetra
.581 .724 0 r
.71063 .26244 .72213 .27915 .74135 .19282 .73026 .17605 Metetra
.243 .628 0 r
.0527 .36863 .06625 .38724 .07317 .46797 .05954 .44701 Metetra
.86 .523 0 r
.05954 .44701 .07317 .46797 .08789 .49806 .07423 .47613 Metetra
.941 .241 0 r
.07423 .47613 .08789 .49806 .10681 .49925 .09315 .47718 Metetra
.957 .18 0 r
.09315 .47718 .10681 .49925 .12686 .49309 .1132 .47107 Metetra
.958 .176 0 r
.1132 .47107 .12686 .49309 .14718 .48597 .13354 .46402 Metetra
.957 .179 0 r
.13354 .46402 .14718 .48597 .16766 .47877 .15404 .45685 Metetra
.956 .182 0 r
.15404 .45685 .16766 .47877 .1883 .47153 .17471 .44964 Metetra
.956 .184 0 r
.17471 .44964 .1883 .47153 .20909 .46428 .19554 .44239 Metetra
.955 .186 0 r
.19554 .44239 .20909 .46428 .23005 .45699 .21654 .43509 Metetra
.954 .188 0 r
.21654 .43509 .23005 .45699 .25118 .44967 .2377 .42774 Metetra
.954 .19 0 r
.2377 .42774 .25118 .44967 .27247 .44233 .25904 .42035 Metetra
.954 .191 0 r
.25904 .42035 .27247 .44233 .29394 .43495 .28055 .41291 Metetra
.953 .192 0 r
.28055 .41291 .29394 .43495 .31557 .42755 .30223 .40542 Metetra
.953 .193 0 r
.30223 .40542 .31557 .42755 .33738 .42011 .3241 .39789 Metetra
.953 .194 0 r
.3241 .39789 .33738 .42011 .35937 .41264 .34614 .3903 Metetra
.953 .194 0 r
.34614 .3903 .35937 .41264 .38154 .40513 .36837 .38267 Metetra
.953 .194 0 r
.36837 .38267 .38154 .40513 .4039 .39759 .39079 .37498 Metetra
.953 .193 0 r
.39079 .37498 .4039 .39759 .42644 .39001 .41339 .36724 Metetra
.953 .193 0 r
.41339 .36724 .42644 .39001 .44917 .3824 .43618 .35945 Metetra
.954 .192 0 r
.43618 .35945 .44917 .3824 .4721 .37476 .45917 .35161 Metetra
.954 .19 0 r
.45917 .35161 .4721 .37476 .49522 .36707 .48235 .34371 Metetra
.954 .189 0 r
.48235 .34371 .49522 .36707 .51854 .35935 .50574 .33576 Metetra
.955 .187 0 r
.50574 .33576 .51854 .35935 .54206 .3516 .52932 .32775 Metetra
.955 .185 0 r
.52932 .32775 .54206 .3516 .56579 .3438 .55312 .31969 Metetra
.956 .182 0 r
.55312 .31969 .56579 .3438 .58972 .33597 .57712 .31157 Metetra
.957 .18 0 r
.57712 .31157 .58972 .33597 .61387 .3281 .60133 .30339 Metetra
.957 .177 0 r
.60133 .30339 .61387 .3281 .63824 .32017 .62575 .29512 Metetra
.957 .177 0 r
.62575 .29512 .63824 .32017 .6628 .31169 .65038 .2863 Metetra
.948 .212 0 r
.65038 .2863 .6628 .31169 .68733 .29842 .67499 .27282 Metetra
.893 .415 0 r
.67499 .27282 .68733 .29842 .71063 .26244 .69849 .23728 Metetra
.518 .708 0 r
.69849 .23728 .71063 .26244 .73026 .17605 .71859 .15281 Metetra
.041 .556 0 r
.04197 .33047 .0527 .36863 .05954 .44701 .04984 .39833 Metetra
.773 .761 0 r
.04984 .39833 .05954 .44701 .07423 .47613 .06481 .42316 Metetra
.85 .553 0 r
.06481 .42316 .07423 .47613 .09315 .47718 .08361 .42359 Metetra
.866 .503 0 r
.08361 .42359 .09315 .47718 .1132 .47107 .10347 .41775 Metetra
.868 .496 0 r
.10347 .41775 .1132 .47107 .13354 .46402 .1236 .41104 Metetra
.869 .494 0 r
.1236 .41104 .13354 .46402 .15404 .45685 .14391 .40418 Metetra
.869 .493 0 r
.14391 .40418 .15404 .45685 .17471 .44964 .16439 .39722 Metetra
.869 .492 0 r
.16439 .39722 .17471 .44964 .19554 .44239 .18504 .39016 Metetra
.87 .491 0 r
.18504 .39016 .19554 .44239 .21654 .43509 .20587 .38301 Metetra
.87 .49 0 r
.20587 .38301 .21654 .43509 .2377 .42774 .22687 .37577 Metetra
.87 .49 0 r
.22687 .37577 .2377 .42774 .25904 .42035 .24805 .36843 Metetra
.87 .489 0 r
.24805 .36843 .25904 .42035 .28055 .41291 .2694 .361 Metetra
.87 .489 0 r
.2694 .361 .28055 .41291 .30223 .40542 .29094 .35348 Metetra
.87 .489 0 r
.29094 .35348 .30223 .40542 .3241 .39789 .31266 .34586 Metetra
.871 .488 0 r
.31266 .34586 .3241 .39789 .34614 .3903 .33456 .33814 Metetra
.871 .488 0 r
.33456 .33814 .34614 .3903 .36837 .38267 .35664 .33033 Metetra
.871 .488 0 r
.35664 .33033 .36837 .38267 .39079 .37498 .37892 .32241 Metetra
.87 .489 0 r
.37892 .32241 .39079 .37498 .41339 .36724 .40138 .3144 Metetra
.87 .489 0 r
.40138 .3144 .41339 .36724 .43618 .35945 .42402 .30629 Metetra
.87 .489 0 r
.42402 .30629 .43618 .35945 .45917 .35161 .44686 .29808 Metetra
.87 .49 0 r
.44686 .29808 .45917 .35161 .48235 .34371 .46989 .28976 Metetra
.87 .49 0 r
.46989 .28976 .48235 .34371 .50574 .33576 .49312 .28134 Metetra
.87 .491 0 r
.49312 .28134 .50574 .33576 .52932 .32775 .51654 .27282 Metetra
.869 .492 0 r
.51654 .27282 .52932 .32775 .55312 .31969 .54016 .26418 Metetra
.869 .493 0 r
.54016 .26418 .55312 .31969 .57712 .31157 .56398 .25544 Metetra
.869 .494 0 r
.56398 .25544 .57712 .31157 .60133 .30339 .58801 .24657 Metetra
.868 .496 0 r
.58801 .24657 .60133 .30339 .62575 .29512 .61223 .23758 Metetra
.867 .5 0 r
.61223 .23758 .62575 .29512 .65038 .2863 .63664 .22804 Metetra
.857 .53 0 r
.63664 .22804 .65038 .2863 .67499 .27282 .66107 .2144 Metetra
.804 .683 0 r
.66107 .2144 .67499 .27282 .69849 .23728 .68463 .18165 Metetra
.251 .63 0 r
.68463 .18165 .69849 .23728 .71859 .15281 .70538 .10637 Metetra
0 .362 .277 r
.03634 .26033 .04197 .33047 .04984 .39833 .04714 .30473 Metetra
0 .538 0 r
.04714 .30473 .04984 .39833 .06481 .42316 .06299 .31973 Metetra
.168 .603 0 r
.06299 .31973 .06481 .42316 .08361 .42359 .08156 .31827 Metetra
.214 .618 0 r
.08156 .31827 .08361 .42359 .10347 .41775 .10092 .31253 Metetra
.226 .622 0 r
.10092 .31253 .10347 .41775 .1236 .41104 .12054 .30612 Metetra
.234 .625 0 r
.12054 .30612 .1236 .41104 .14391 .40418 .14033 .29953 Metetra
.241 .627 0 r
.14033 .29953 .14391 .40418 .16439 .39722 .1603 .2928 Metetra
.247 .629 0 r
.1603 .2928 .16439 .39722 .18504 .39016 .18045 .28592 Metetra
.252 .631 0 r
.18045 .28592 .18504 .39016 .20587 .38301 .20078 .27889 Metetra
.257 .632 0 r
.20078 .27889 .20587 .38301 .22687 .37577 .22129 .27171 Metetra
.261 .633 0 r
.22129 .27171 .22687 .37577 .24805 .36843 .24197 .26439 Metetra
.264 .635 0 r
.24197 .26439 .24805 .36843 .2694 .361 .26283 .25692 Metetra
.267 .635 0 r
.26283 .25692 .2694 .361 .29094 .35348 .28388 .24931 Metetra
.269 .636 0 r
.28388 .24931 .29094 .35348 .31266 .34586 .3051 .24154 Metetra
.27 .636 0 r
.3051 .24154 .31266 .34586 .33456 .33814 .3265 .23363 Metetra
.27 .636 0 r
.3265 .23363 .33456 .33814 .35664 .33033 .34808 .22556 Metetra
.27 .636 0 r
.34808 .22556 .35664 .33033 .37892 .32241 .36985 .21734 Metetra
.269 .636 0 r
.36985 .21734 .37892 .32241 .40138 .3144 .3918 .20897 Metetra
.267 .636 0 r
.3918 .20897 .40138 .3144 .42402 .30629 .41392 .20044 Metetra
.265 .635 0 r
.41392 .20044 .42402 .30629 .44686 .29808 .43623 .19176 Metetra
.262 .634 0 r
.43623 .19176 .44686 .29808 .46989 .28976 .45872 .18292 Metetra
.258 .633 0 r
.45872 .18292 .46989 .28976 .49312 .28134 .4814 .17392 Metetra
.254 .631 0 r
.4814 .17392 .49312 .28134 .51654 .27282 .50426 .16476 Metetra
.248 .629 0 r
.50426 .16476 .51654 .27282 .54016 .26418 .5273 .15543 Metetra
.242 .628 0 r
.5273 .15543 .54016 .26418 .56398 .25544 .55052 .14594 Metetra
.236 .625 0 r
.55052 .14594 .56398 .25544 .58801 .24657 .57392 .13628 Metetra
.228 .623 0 r
.57392 .13628 .58801 .24657 .61223 .23758 .59751 .12644 Metetra
.218 .62 0 r
.59751 .12644 .61223 .23758 .63664 .22804 .62127 .11614 Metetra
.187 .609 0 r
.62127 .11614 .63664 .22804 .66107 .2144 .64511 .10303 Metetra
.062 .564 0 r
.64511 .10303 .66107 .2144 .68463 .18165 .66844 .0771 Metetra
0 .422 .213 r
.66844 .0771 .68463 .18165 .70538 .10637 .69004 .02247 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15784 .20788 m
.16245 .21255 L
s
[(-5)] .14863 .19854 .98551 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54215 .0574 m
.54605 .06267 L
s
[(5)] .53436 .04684 .73896 1 Mshowa
.125 Mabswid
.19385 .19378 m
.19658 .19662 L
s
.23036 .17949 m
.23305 .18236 L
s
.26739 .16498 m
.27005 .16789 L
s
.30496 .15028 m
.30757 .15322 L
s
.38172 .12022 m
.38425 .12323 L
s
.42095 .10486 m
.42343 .10791 L
s
.46076 .08927 m
.46319 .09236 L
s
.50115 .07345 m
.50354 .07658 L
s
.12234 .22178 m
.12513 .22455 L
s
.08732 .2355 m
.09015 .23823 L
s
.05278 .24902 m
.05564 .25172 L
s
.58378 .0411 m
.58606 .0443 L
s
.62603 .02455 m
.62826 .0278 L
s
.66893 .00776 m
.67111 .01103 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[161]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00boooool2o`0005?ooooo0038ooooo`?o000000?o
ooooo`000?ooool0D_ooool00<Kooooo0_l00004ooooo`;o0000D_ooool00<?ooooo0ol00002oooo
o`07o`000?ooooooooooooooool0003oooooo`00001Aooooo`00Woooool3o`0001kooooo0ol00009
ooooo`04o`000?oooooo0000o`00053ooooo002Nooooo`05o`000?ooooooooooooooool000006ooo
ool2o`0000cooooo00Co0000oooooooooooo0000D?ooool00:;ooooo00?o0000ooooooooool05_oo
ool3o`0000kooooo0_l00002ooooo`03o`000?oooooooooo04gooooo002Rooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0>ooooo`;o00000_ooool00ol0003oooooooooo`1=
ooooo`00W_ooool4o`0001Cooooo0ol0000Cooooo`;o00000oooool00ol0003oooooooooo`1<oooo
o`00W_ooool00ol0003oooooooooo`0Cooooo`;o00005_ooool2o`0000Cooooo00?o0000oooooooo
ool0Boooool009kooooo1Ol0000>ooooo`?o00005oooool01?l0003o06`fo`000?l00003ooooo`03
o`000?oooooooooo04_ooooo002^ooooo`Co00006Oooool01?l0003o06`fo`000?l00004ooooo`03
o`000?oooooooooo04[ooooo002/ooooo`;o00000oooool00ol0003oooooooooo`0Gooooo`04o`00
0?l0K3Ko0000o`0000Cooooo0_l0001;ooooo`00ZOooool3o`0001kooooo00?o0000o`1/=_l0K3H0
0_l00005ooooo`03o`000?oooooooooo04Wooooo002Wooooo`;o00008Oooool00ol0003o06`fo`1/
=P02o`0000Kooooo00?o0000ooooooooool0B?ooool00:Cooooo0ol0000Rooooo`07o`000?l0K3Ko
06`fo`1/=_l0003o06`fo`000005ooooo`03o`000?oooooooooo04Sooooo002Rooooo`;o00000_oo
ool00ol0003oooooooooo`0Pooooo`07o`000?l0K3Ko06`fo`1/=_l0003o06`fo`000006ooooo`03
o`000?oooooooooo04Oooooo002Oooooo`?o00001Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?l0K3Ko06`f00;o06`f00?o0000o`1/=_l000001oooool00ol0003oooooooooo`16ooooo`00WOoo
ool2o`0002Wooooo00?o0000o`1/=_l0K3H00_l0K3H00ol0003o06`fo`000007ooooo`03o`000?oo
oooooooo04Kooooo002Jooooo`?o0000:oooool00ol0003o06`fo`1/=P02o`1/=P03o`000?l0K3Ko
000000Sooooo00?o0000ooooooooool0AOooool009Oooooo0ol000000ooooooo0000ooooo`0Zoooo
o`03o`000?l0K3Ko06`f00?o06`f00?o0000o`1/=_l000002?ooool2o`0004Kooooo002Eooooo`;o
0000<?ooool00ol0003o06`fo`1/=P03o`1/=P04o`000?l0K3Ko06`fo`0000Sooooo00?o0000oooo
ooooool0A?ooool009;ooooo0ol0000aooooo`;o00001Ol0K3H01?l0003o06`fo`1/=_l00009oooo
o`03o`000?oooooooooo00_ooooo0ol0000eooooo`00T?ooool2o`0003?ooooo00?o0000o`n@0?l0
00001Ol0K3H01?l0003o06`fo`1/=_l0000:ooooo`03o`000?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`00000dooooo`00SOooool5o`0003;ooooo00Go0000o`n@0?l?T03o3i00o`000004
o`1/=P04o`000?l0K3Ko06`fo`0000[ooooo00?o0000ooooooooool00oooool5o`0000Gooooo00?o
0000ooooooooool0<_ooool006_ooooo0_l0000Nooooo`;o0000=_ooool00ol0003o3i00o`n@0002
o`n@0003o`000?l0K3Ko06`f00?o06`f00?o0000o`1/=_l000002oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03;ooooo001Zooooo`04o`000?ooooooooooo`0001[ooooo0ol0000g
ooooo`03o`000?l?T03o3i0000?o3i0000?o0000o`1/=_l0K3H00ol0K3H01?l0003o06`fo`1/=_l0
000;ooooo`03o`000?oooooooooo00Oooooo1?l0000eooooo`00J_ooool01?l0003oooooooooool0
000Gooooo`?o0000>?ooool2o`0000Ko3i0000?o0000o`1/=_l0K3H00ol0K3H01?l0003o06`fo`1/
=_l0000;ooooo`;o00002?ooool00ol0003oooooooooo`0fooooo`00J_ooool01?l0003ooooooooo
ool0000Eooooo`;o000000?oooooo`000?ooool0=oooool00ol0003o;i/0o`000006o`n@0003o`00
0?l0K3Ko06`f00?o06`f00Co0000o`1/=_l0K3Ko00002oooool2o`0000Sooooo1Ol0000dooooo`00
J_ooool01?l0003oooooooooool0000Booooo`?o00000oooool00ol0003oooooooooo`0dooooo`;o
00000_l_V`000ol0003o3i00o`n@0004o`n@0003o`000?l0K3Ko06`f00?o06`f00Co0000o`1/=_l0
K3Ko00003Oooool00ol0003oooooooooo`0nooooo`00J_ooool01?l0003oooooooooool0000@oooo
o`;o0000??ooool00ol0003o;i/0obnK0002obnK0003o`000?l?T03o3i0000Co3i0000?o0000o`1/
=_l0K3H00ol0K3H01?l0003o06`fo`1/=_l0000=ooooo`03o`000?oooooooooo03kooooo001[oooo
o`;o00003_ooool3o`0003_ooooo0ol00005obnK0003o`000?l?T03o3i0000Go3i0000?o0000o`1/
=_l0K3H00_l0K3H01Ol0003o06`fo`000?m0X@3o000000gooooo00?o0000ooooooooool0?Oooool0
07Wooooo0ol0000jooooo`?o00000_lgWP000ol0003o;i/0obnK0004obnK0003o`000?l?T03o3i00
00Co3i0000?o0000o`1/=_l0K3H00_l0K3H01Ol0003o06`fo`000?m0X@3o000000kooooo00?o0000
ooooooooool0??ooool007Kooooo0ol00003ooooo`03o`000?oooooooooo03Cooooo0ol00005ocNN
0003o`000?l_V`3o;i/000Co;i/000?o0000o`n@0?l?T0001?l?T0000ol0003o06`fo`1/=P02o`1/
=P05o`000?l0K3Ko0000od2Q0?l000003_ooool00ol0003oooooooooo`0looooo`00Loooool3o`00
03_ooooo0_l000000oljW`3o0000ocNN0005ocNN0003o`000?l_V`3o;i/000Co;i/000?o0000o`n@
0?l?T0001?l?T0000ol0003o06`fo`1/=P02o`1/=P;o00000_m0X@000ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo03_ooooo001aooooo`;o0000??ooool2o`0000?o>Yl000?o0000ocNN0?lg
WP001?lgWP000ol0003o;i/0obnK0004obnK0003o`000?l?T03o3i0000Co3i0000?o0000o`1/=_l0
K3H00_l0K3H2o`0000?o@:4000?o0000ooooooooool03?ooool2o`0003cooooo001^ooooo`Co0000
>oooool2o`0000Go>Yl000?o0000ocNN0?lgWP001OlgWP000ol0003o;i/0obnK0003obnK0003o`00
0?l?T03o3i0000Co3i0000?o0000o`1/=_l0K3H00_l0K3H2o`0000?o@:4000?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0jooooo`00K?ooool2o`0000Cooooo00?o0000ooooooooool0=_oo
ool2o`000003ocbO0?l0003o>Yl000Co>Yl000?o0000ocNN0?lgWP001OlgWP000ol0003o;i/0obnK
0003obnK0003o`000?l?T03o3i0000Co3i0000?o0000o`1/=_l0K3H00_l0K3H00ol0003o@:40od2Q
0002od2Q0003o`000?oooooooooo00kooooo00?o0000ooooooooool0>Oooool006Wooooo0ol0000m
ooooo`;o00000ollW`000ol0003o>Yl0ocZO0004ocZO0003o`000?lgWP3o=ih000Co=ih000?o0000
obnK0?l_V`000ol_V`000ol0003o3i00o`n@0005o`n@0005o`000?l0K3Ko06`fo`1/=_l000001?m0
X@000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Sooooo001Wooooo`;o0000?_ooool2
o`0000Go?9l000?o0000ocZO0?ljW`001?ljW`000ol0003o=ih0ocNN0004ocNN0003o`000?l_V`3o
;i/000Co;i/000?o0000o`n@0?l?T0001?l?T0001Ol0003o06`fo`1/=_l0K3Ko000000Go@:4000?o
0000ooooooooool03_ooool00ol0003oooooooooo`0hooooo`00I?ooool5o`0003_ooooo0ol00000
0olmX03o0000ocbO0004ocbO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocNN0?lgWP001?lgWP00
0ol0003o;i/0obnK0004obnK0003o`000?l?T03o3i0000Co3i0000Go0000o`1/=_l0K3Ko06`fo`00
0005od2Q0003o`000?oooooooooo00oooooo00?o0000ooooooooool0=oooool0067ooooo0ol0000m
ooooo`?o00001?lmX0000ol0003o?9l0ocbO0004ocbO0003o`000?ljW`3o>Yl000?o>Yl000?o0000
ocNN0?lgWP001?lgWP000ol0003o;i/0obnK0004obnK0003o`000?l?T03o3i0000Co3i0000?o0000
o`1/=_l0K3H00_l00005od2Q0003o`000?oooooooooo013ooooo00?o0000ooooooooool0=_ooool0
05oooooo0_l0000nooooo`;o000000?o?j40o`000?lmX0001?lmX0000ol0003o?9l0ocbO0004ocbO
0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocNN0?lgWP001?lgWP000ol0003o;i/0obnK0004obnK
0003o`000?l?T03o3i0000Co3i0000Ko0000o`1/=_l0K3Ko0000od2Q0?l00004od2Q00;o00004Ooo
ool2o`0003Oooooo001Looooo`?o0000?_ooool2o`0000?o?j4000?o0000ocfP0?lmX0000olmX000
0ol0003o?9l0ocbO0004ocbO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocNN0?lgWP001OlgWP00
0ol0003o;i/0obnK0003obnK0003o`000?l?T03o3i0000Co3i0000Ko0000o`1/=_l0K3Ko0000od2Q
0?l00003od2Q0003o`000?n4]@3o000001;ooooo00?o0000ooooooooool0=Oooool003Wooooo0ol0
000Nooooo`;o000000?oooooo`000?l00000??ooool2o`0000Go?j4000?o0000ocfP0?lmX0000olm
X0000ol0003o?9l0ocbO0004ocbO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocNN0?lgWP001Olg
WP000ol0003o;i/0obnK0003obnK0003o`000?l?T03o3i0000Co3i0000?o0000o`1/=_l000000_m0
X@001Ol0003o@:40od2Q0?m0X@3o000000;oQ;D000?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0eooooo`00>?ooool01Ol0003ooooooooooooooooo000001[ooooo0ol0000nooooo`?o0000
00?o@J40o`000?loX@001?loX@000ol0003o?J00ocfP0004ocfP0003o`000?llW`3o?9l000?o?9l0
00?o0000ocZO0?ljW`001?ljW`000ol0003o=ih0ocNN0004ocNN0003o`000?l_V`3o;i/000?o;i/0
00?o0000o`n@0?l?T0001Ol?T002o`0000;o@:4000Go0000od2Q0?m0X@3o@:40o`000002ohBe0003
o`000?oooooooooo013ooooo00?o0000ooooooooool0=?ooool003;ooooo1Ol00005ooooo`03o`00
0?oooooooooo01Kooooo0_l0000nooooo`?o00001?m1X@000ol0003o?j40ocnQ0003ocnQ0003o`00
0?lmX03o?J0000Co?J0000?o0000ocbO0?llW`000ollW`000ol0003o>Yl0ocZO0004ocZO0003o`00
0?lgWP3o=ih000Co=ih000?o0000obnK0?l_V`000ol_V`000ol0003o3i00o`n@0005o`n@00;o0000
0_m0X@001Ol0003o@:40od2Q0?m0X@3o000000?oQ;D000?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0cooooo`00??ooool00ol0003oooooooooo`0Cooooo`?o0000?Oooool3o`000003od:R
0?l0003o@J4000Co@J4000?o0000ocnQ0?loX@001?loX@000ol0003o?J00ocfP0003ocfP0003o`00
0?llW`3o?9l000?o?9l000?o0000ocZO0?ljW`001?ljW`000ol0003o=ih0ocNN0004ocNN0003o`00
0?l_V`3o;i/000Co;i/000?o0000o`n@0?l?T0001?l?T0001Ol0003o@:40od2Q0?m0X@3o000000?o
@:4000Go0000ohBe0?n4]@3oQ;D0o`00000Booooo`03o`000?oooooooooo03?ooooo000hooooo`Co
00004oooool3o`0000;ooooo00?o0000ooooooooool0>?ooool3o`0000Co@Z8000?o0000od6Q0?m1
X@000om1X@000ol0003o?j40ocnQ0004ocnQ0003o`000?lmX03o?J0000?o?J0000?o0000ocbO0?ll
W`001?llW`000ol0003o>Yl0ocZO0003ocZO0003o`000?lgWP3o=ih000Co=ih000?o0000obnK0?l_
V`001?l_V`000ol0003o3i00o`n@0004o`n@0005o`000?m0X@3o@:40od2Q0?l000000_m0X@000ol0
003oQ;D0ohBe0002ohBe00;o00004_ooool00ol0003oooooooooo`0booooo`00>?ooool00ol0003o
ooooooooo`0Booooo`;o0000?_ooool2o`000003od>R0?l0003o@Z8000Co@Z8000?o0000od6Q0?m1
X@000om1X@000ol0003o?j40ocnQ0004ocnQ0003o`000?lmX03o?J0000?o?J0000?o0000ocbO0?ll
W`001?llW`000ol0003o>Yl0ocZO0003ocZO0003o`000?lgWP3o=ih000Co=ih000?o0000obnK0?l_
V`001?l_V`000ol0003o3i00o`n@0004o`n@0005o`000?m0X@3o@:40od2Q0?l000000_m0X@001Ol0
003oQ;D0ohBe0?n4]@3o000000;oU;T000?o0000ooooooooool03oooool2o`0003?ooooo000hoooo
o`Go00003Oooool3o`0003kooooo0_l00003od>R0003o`000?m2XP3o@Z8000?o@Z8000?o0000od6Q
0?m1X@001?m1X@000ol0003o?j40ocnQ0003ocnQ0003o`000?lmX03o?J0000?o?J0000?o0000ocbO
0?llW`001?llW`000ol0003o>Yl0ocZO0003ocZO0003o`000?lgWP3o=ih000Go=ih000?o0000obnK
0?l_V`000ol_V`000ol0003o3i00o`n@0003o`n@00;o00000om0X@001?l0003o@:40od2Q0?l00003
ohBe0004o`000?nD^@3oU;T0o`0001;ooooo00?o0000ooooooooool0<Oooool004Sooooo0ol0000n
ooooo`;o00001Om3XP000ol0003o@Z80od:R0003od:R0003o`000?m1X@3o@J4000Co@J4000?o0000
ocnQ0?loX@000oloX@000ol0003o?J00ocfP0003ocfP0003o`000?llW`3o?9l000Co?9l000?o0000
ocZO0?ljW`000oljW`000ol0003o=ih0ocNN0005ocNN0003o`000?l_V`3o;i/000?o;i/000?o0000
o`n@0?l?T0000_l?T0001?l0003ocJh0olf^0?l00002od2Q0004o`000?m0X@3o@:40o`0000?oQ;D0
00Go0000oiBi0?nD^@3oU;T0o`00000Booooo`03o`000?oooooooooo033ooooo0015ooooo`?o0000
0_ooool00ol0003oooooooooo`0iooooo`?o000000?o@j80o`000?m3XP001?m3XP000ol0003o@Z80
od:R0004od:R0003o`000?m1X@3o@J4000?o@J4000?o0000ocnQ0?loX@000oloX@000ol0003o?J00
ocfP0003ocfP0003o`000?llW`3o?9l000Co?9l000?o0000ocZO0?ljW`000oljW`000ol0003o=ih0
ocNN0005ocNN0003o`000?l_V`3o;i/000?o;i/000?o0000o`n@0?l?T0000_l?T0001?l0003ocJh0
olf^0?l00002od2Q0003o`000?m0X@3o000000CoQ;D000Go0000oiBi0?nD^@3oU;T0o`00000Coooo
o`03o`000?oooooooooo02oooooo0013ooooo`;o0000?_ooool3o`0000Co@j8000?o0000od>R0?m3
XP000om3XP000ol0003o@Z80od:R0004od:R0003o`000?m1X@3o@J4000?o@J4000?o0000ocnQ0?lo
X@000oloX@000ol0003o?J00ocfP0003ocfP0003o`000?llW`3o?9l000Co?9l000?o0000ocZO0?lj
W`001?ljW`000ol0003o=ih0ocNN0004ocNN0003o`000?l_V`3o;i/000?o;i/000Go0000o`n@0?l?
T03o3i00o`000003olf^0006o`000?m0X@3o@:40o`000?m0X@3o00001?n4]@001?l0003oU;T0oiBi
0?nD^@02o`0001;ooooo00?o0000ooooooooool0;oooool0043ooooo0ol0000mooooo`?o000000?o
A:80o`000?m3XP001?m3XP000ol0003o@j80od>R0004od>R0003o`000?m2XP3o@Z8000?o@Z8000?o
0000od6Q0?m1X@000om1X@000ol0003o?j40ocnQ0003ocnQ0003o`000?lmX03o?J0000Co?J0000?o
0000ocbO0?llW`000ollW`000ol0003o>Yl0ocZO0004ocZO0003o`000?lgWP3o=ih000Co=ih000?o
0000obnK0?l_V`001?l_V`000ol0003o3i00o`000004olf^0006o`000?m0X@3o@:40o`000?m0X@3o
00000on4]@001Ol0003oU;T0oiBi0?nD^@3o000000;oU[T000?o0000ooooooooool04?ooool00ol0
003oooooooooo`0^ooooo`00?_ooool3o`0003cooooo0ol00004odBR0003o`000?m3XP3o@j8000?o
@j8000?o0000od>R0?m3XP001?m3XP000ol0003o@Z80od:R0003od:R0003o`000?m1X@3o@J4000?o
@J4000?o0000ocnQ0?loX@000oloX@000ol0003o?J00ocfP0004ocfP0003o`000?llW`3o?9l000Co
?9l000?o0000ocZO0?ljW`000oljW`000ol0003o=ih0ocNN0004ocNN0003o`000?l_V`3o;i/000Co
;i/000?o0000o`n@0?l000001Oo=[P001Ol0003o@:40o`000?m0X@3o000000?oQ;D000Go0000oiBi
0?nD^@3oU;T0o`000003oiJi0003o`000?oooooooooo013ooooo00?o0000ooooooooool0;Oooool0
03_ooooo0ol00003ooooo`03o`000?oooooooooo03Kooooo0ol000000om4XP3o0000odBR0004odBR
0003o`000?m3XP3o@j8000?o@j8000?o0000od>R0?m3XP001?m3XP000ol0003o@Z80od:R0003od:R
0003o`000?m1X@3o@J4000?o@J4000?o0000ocnQ0?loX@001?loX@000ol0003o?J00ocfP0003ocfP
0003o`000?llW`3o?9l000Co?9l000?o0000ocZO0?ljW`000oljW`000ol0003o=ih0ocNN0004ocNN
0003o`000?l_V`3o;i/000Co;i/00_l00006olf^0005o`000?m0X@3o0000od2Q0?l000000on4]@00
1Ol0003oU;T0oiBi0?nD^@3o000000?oU[T000?o0000ooooooooool04?ooool2o`0002kooooo000h
ooooo`?o0000??ooool3o`0000CoA:8000?o0000odBR0?m4XP000om4XP000ol0003o@j80od>R0004
od>R0003o`000?m3XP3o@j8000?o@j8000?o0000od:R0?m2XP000om2XP000ol0003o@J40od6Q0003
od6Q0003o`000?loX@3o?j4000Co?j4000?o0000ocfP0?lmX0000olmX0000ol0003o?9l0ocbO0004
ocbO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocNN0?lgWP001OlgWP000ol0003o;i/0obnK0002
obnK00;o00001oo=[P001?l0003o@:40o`000?l00004ohBe0005o`000?nD^@3oU;T0oiBi0?l00000
0onF^@02o`0001;ooooo00?o0000ooooooooool01oooool2o`0002?ooooo000fooooo`;o0000?Ooo
ool2o`000003odFR0?l0003oA:8000CoA:8000?o0000odBR0?m4XP000om4XP000ol0003o@j80od>R
0004od>R0003o`000?m3XP3o@j8000?o@j8000?o0000od:R0?m2XP000om2XP000ol0003o@J40od6Q
0003od6Q0003o`000?loX@3o?j4000Co?j4000?o0000ocfP0?lmX0000olmX0000ol0003o?9l0ocbO
0004ocbO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocNN0?lgWP001OlgWP000ol0003o;i/0obnK
0002o`000003om^70?l0003ocJh000OocJh000?o0000od2Q0?l000000on4]@000ol0003oU;T0oiBi
0002oiBi0004o`000?nF^@3oU[T0o`0000;oU[T000?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0002;ooooo000cooooo`?o000000?oooooo`000?l00000
>_ooool2o`0000?oAJ8000?o0000odBR0?m4XP000om4XP000ol0003oA:80odBR0003odBR0003o`00
0?m3XP3o@j8000Co@j8000?o0000od>R0?m3XP000om3XP000ol0003o@Z80od:R0003od:R0003o`00
0?m1X@3o@J4000Co@J4000?o0000ocnQ0?loX@000oloX@000ol0003o?J00ocfP0003ocfP0003o`00
0?llW`3o?9l000Co?9l000?o0000ocZO0?ljW`000oljW`000ol0003o=ih0ocNN0005ocNN00?o0000
0ooKQ`000ol0003ocJh0olf^0006olf^0003o`000?m0X@3o000000?oQ;D000Go0000oiBi0?nD^@3o
U;T0o`000003oiJi0005o`000?nF^@3oU[T0oiJi0?l000004Oooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0002;ooooo000aooooo`;o0000?_ooool2o`0000GoAJ8000?o0000odBR
0?m4XP000om4XP000ol0003oA:80odBR0003odBR0003o`000?m3XP3o@j8000Co@j8000?o0000od>R
0?m3XP000om3XP000ol0003o@Z80od:R0003od:R0003o`000?m1X@3o@J4000Co@J4000?o0000ocnQ
0?loX@000oloX@000ol0003o?J00ocfP0003ocfP0003o`000?llW`3o?9l000Co?9l000?o0000ocZO
0?ljW`001?ljW`000ol0003o=ih0ocNN0003ocNN00;o00001_oKQ`000ol0003ocJh0olf^0005olf^
0003o`000?m0X@3o000000?oQ;D000Go0000oiBi0?nD^@3oU;T0o`000003oiJi0005o`000?nF^@3o
U[T0oiJi0?l000004_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002;ooooo
000^ooooo`?o0000?Oooool3o`000003odFR0?l0003oAJ8000CoAJ8000?o0000odBR0?m4XP001?m4
XP000ol0003oA:80odBR0003odBR0003o`000?m3XP3o@j8000?o@j8000?o0000od>R0?m3XP000om3
XP000ol0003o@Z80od:R0004od:R0003o`000?m1X@3o@J4000?o@J4000?o0000ocnQ0?loX@000olo
X@000ol0003o?J00ocfP0003ocfP0003o`000?llW`3o?9l000Co?9l000?o0000ocZO0?ljW`001?lj
W`000ol0003o=ih0ocNN0003o`000003omeo0?l0003ofhL000GofhL000?o0000olf^0?o=[P001Oo=
[P000ol0003o@:40o`000003ohBe0005o`000?nD^@3oU;T0oiBi0?l000000onF^@001?l0003oU[T0
oiJi0?nF^@02o`0001;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000Roooo
o`00;?ooool3o`0003gooooo0_l00004odFR0003o`000?m5XP3oAJ8000?oAJ8000?o0000odBR0?m4
XP001?m4XP000ol0003oA:80odBR0003odBR0003o`000?m3XP3o@j8000?o@j8000?o0000od>R0?m3
XP000om3XP000ol0003o@Z80od:R0004od:R0003o`000?m1X@3o@J4000?o@J4000?o0000ocnQ0?lo
X@000oloX@000ol0003o?J00ocfP0003ocfP0003o`000?llW`3o?9l000Go?9l000?o0000ocZO0?lj
W`000oljW`03o`0000CogGl000?o0000om^70?oKQ`001?oKQ`000ol0003ocJh0olf^0006olf^00;o
00000on4]@001Ol0003oU;T0oiBi0?nD^@3o000000?oU[T000Co0000oiJi0?nF^@3o00000_nE^@00
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00008_oo
ool002Wooooo0ol00002ooooo`03o`000?oooooooooo03Sooooo0ol000000om5XP3o0000odFR0003
odFR0003o`000?m5XP3oAJ8000CoAJ8000?o0000odBR0?m4XP000om4XP000ol0003oA:80odBR0003
odBR0003o`000?m3XP3o@j8000?o@j8000?o0000od>R0?m3XP001?m3XP000ol0003o@Z80od:R0003
od:R0003o`000?m1X@3o@J4000?o@J4000?o0000ocnQ0?loX@000oloX@000ol0003o?J00ocfP0004
ocfP0003o`000?llW`3o?9l000Co?9l000?o0000ocZO0?ljW`000_ljW`02o`0000KogGl000?o0000
om^70?oKQ`001?oKQ`000ol0003ocJh0olf^0006olf^00;o00000_n4]@001Ol0003oU;T0oiBi0?nD
^@3o000000?oU[T000Go0000oiJi0?nF^@3oU[T0o`000003oiFi0003o`000?oooooooooo00kooooo
0_l00005ooooo`;o00008oooool002Kooooo0ol0000mooooo`?o00001?m5XP000ol0003oAJ80odFR
0002odFR0003o`000?m5XP3oAJ8000CoAJ8000?o0000odBR0?m4XP000om4XP000ol0003oA:80odBR
0003odBR0003o`000?m3XP3o@j8000?o@j8000?o0000od>R0?m3XP001?m3XP000ol0003o@Z80od:R
0003od:R0003o`000?m1X@3o@J4000?o@J4000?o0000ocnQ0?loX@000oloX@000ol0003o?J00ocfP
0004ocfP0003o`000?llW`3o?9l000Co?9l000?o0000ocZO0?l000000_l000000ooNOP3o0000omeo
0006omeo0003o`000?oKQ`3ofhL000CofhL000?o0000olf^0?o=[P001Oo=[P02o`0000;oQ;D000Go
0000oiBi0?nD^@3oU;T0o`000003oiJi0005o`000?nF^@3oU[T0oiJi0?l000000onE^@000ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02Oooooo000Tooooo`;o0000?Oooool3o`000003odBR
0?l0003oAJ8000CoAJ8000?o0000odFR0?m5XP000om5XP000ol0003oAJ80odFR0003odFR0003o`00
0?m4XP3oA:8000?oA:8000?o0000odBR0?m4XP000om4XP000ol0003o@j80od>R0003od>R0003o`00
0?m3XP3o@j8000Co@j8000?o0000od:R0?m2XP000om2XP000ol0003o@J40od6Q0003od6Q0003o`00
0?loX@3o?j4000?o?j4000?o0000ocfP0?lmX0001?lmX0000ol0003o?9l0ocbO0002ocbO00Co0000
1?oNOP000ol0003ogGl0omeo0005omeo0003o`000?oKQ`3ofhL000CofhL000?o0000olf^0?o=[P00
1?o=[P03o`0000;oQ;D000Go0000oiBi0?nD^@3oU;T0o`000003oiJi0005o`000?nF^@3oU[T0oiJi
0?l000000onE^@02o`00017ooooo00?o0000ooooooooool09oooool0027ooooo0ol000000ooooooo
0000ooooo`0jooooo`;o00001?m4XP000ol0003oAJ80odFR0003odFR0003o`000?m5XP3oAJ8000?o
AJ8000?o0000odFR0?m5XP000om5XP000ol0003oA:80odBR0003odBR0003o`000?m4XP3oA:8000?o
A:8000?o0000od>R0?m3XP001?m3XP000ol0003o@j80od>R0003od>R0003o`000?m2XP3o@Z8000?o
@Z8000?o0000od6Q0?m1X@000om1X@000ol0003o?j40ocnQ0004ocnQ0003o`000?lmX03o?J0000?o
?J0000?o0000ocbO0?l000000_l00002omin0003o`000?oNOP3ogWh000CogWh000?o0000omeo0?oM
O`001?oMO`000ol0003ofhL0om^70004om^70003o`000?o=[P3ocJh000;ocJh00ol000001OoTJP3o
0000ohBe0?n4]@3o000000?oU;T000Go0000oiJi0?nF^@3oU[T0o`000003oiJi0006o`000?nE^@3o
UKT0o`000?nE^@3o00004_ooool00ol0003oooooooooo`0Vooooo`008?ooool2o`0003cooooo0ol0
00000om4XP3o0000odBR0003odBR0003o`000?m5XP3oAJ8000?oAJ8000?o0000odFR0?m5XP000om5
XP000ol0003oAJ80odFR0003odFR0003o`000?m4XP3oA:8000?oA:8000?o0000odBR0?m4XP000om4
XP000ol0003o@j80od>R0004od>R0003o`000?m3XP3o@j8000?o@j8000?o0000od:R0?m2XP000om2
XP000ol0003o@J40od6Q0003od6Q0003o`000?loX@3o?j4000Co?j4000?o0000ocfP0?lmX0000_lm
X003o`0000GogWh000?o0000omin0?oNOP001?oNOP000ol0003ogGl0omeo0004omeo0003o`000?oK
Q`3ofhL000GofhL01?l000000oo=[P3o0000onAZ0002onAZ0003o`000?n4]@3o000000?oU;T000Co
0000oiJi0?nF^@3o00000onF^@001Ol0003oUKT0oiFi0?nE^@3o000000;oUKT000?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Uooooo`008?ooool3o`0003Sooooo0ol00004odBR0003o`00
0?m4XP3oA:8000;oA:8000?o0000odFR0?m5XP000om5XP000ol0003oAJ80odFR0003odFR0003o`00
0?m5XP3oAJ8000?oAJ8000?o0000odBR0?m4XP000om4XP000ol0003oA:80odBR0003odBR0003o`00
0?m3XP3o@j8000Co@j8000?o0000od>R0?m3XP000om3XP000ol0003o@Z80od:R0003od:R0003o`00
0?m1X@3o@J4000Co@J4000?o0000ocnQ0?loX@000oloX@000ol0003o?J00ocfP0002o`000003omin
0?l0003ogWh000KogWh000?o0000omin0?oNOP000ooNOP000ol0003ogGl0omeo0004omeo0003o`00
0?oKQ`3ofhL000?ofhL00ol00003olf^0003o`000?oTJP3oi6X000;oi6X00_l00003oiBi0005o`00
0?nF^@3oU[T0oiJi0?l000000onF^@001Ol0003oUKT0oiFi0?nE^@3o000000;oUKT000?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Uooooo`008?ooool01?l0003oooooooooool0000doooo
o`?o000000?o@j80o`000?m4XP001?m4XP000ol0003oA:80odBR0002odBR0003o`000?m5XP3oAJ80
00?oAJ8000?o0000odFR0?m5XP000om5XP000ol0003oAJ80odFR0003odFR0003o`000?m4XP3oA:80
00?oA:8000?o0000odBR0?m4XP000om4XP000ol0003o@j80od>R0004od>R0003o`000?m3XP3o@j80
00?o@j8000?o0000od:R0?m2XP000om2XP000ol0003o@J40od6Q0004od6Q0003o`000?loX@3o?j40
00?o?j400ol00003omin0003o`000?oNOP3ogWh000GogWh000?o0000omin0?oNOP000ooNOP000ol0
003ogGl0omeo0005omeo0003o`000?oKQ`3o000000;o00000_oKQ`001?l0003ocJh0olf^0?l00006
onAZ00;o00000_nD^@001Ol0003oU[T0oiJi0?nF^@3o000000?oU[T000Go0000oiFi0?nE^@3oUKT0
o`000002oiFi00;o00004_ooool2o`0002Gooooo000Pooooo`05o`000?ooooooooooooooool00000
<?ooool3o`0000Co@j8000?o0000odBR0?m4XP000om4XP000ol0003oA:80odBR0002odBR0003o`00
0?m5XP3oAJ8000CoAJ8000?o0000odFR0?m5XP000_m5XP000ol0003oAJ80odFR0003odFR0003o`00
0?m4XP3oA:8000CoA:8000?o0000odBR0?m4XP000_m4XP000ol0003o@j80od>R0004od>R0003o`00
0?m3XP3o@j8000?o@j8000?o0000od:R0?m2XP001?m2XP000ol0003o@J40od6Q0003od6Q0003o`00
0?loX@3o?j4000;o?j400_l00006omin0003o`000?oNOP3ogWh000CogWh000?o0000omin0?oNOP00
1?oNOP000ol0003ogGl0omeo0003omeo00?o00001OoKQ`001?l0003ocJh0olf^0?l00006onAZ00;o
00000_nD^@001Ol0003oU[T0oiJi0?nF^@3o000000?oU[T000Go0000oiFi0?nE^@3oUKT0o`000002
oiFi0003o`000?nD^@3o0000017ooooo0_l0000Uooooo`007oooool3o`0000?ooooo00?o0000oooo
ooooool0:_ooool3o`000003od:R0?l0003o@j8000Co@j8000?o0000odBR0?m4XP000om4XP000ol0
003oA:80odBR0002odBR0003o`000?m5XP3oAJ8000CoAJ8000?o0000odFR0?m5XP000_m5XP000ol0
003oAJ80odFR0003odFR0003o`000?m4XP3oA:8000CoA:8000?o0000odBR0?m4XP000_m4XP000ol0
003o@j80od>R0004od>R0003o`000?m3XP3o@j8000?o@j8000?o0000od:R0?m2XP001?m2XP000ol0
003o@J40od6Q0003od6Q0003o`000?loX@3o000000;o000000?ogWd0o`000?oNOP001OoNOP000ol0
003ogWh0omin0004omin0003o`000?oNOP3ogWh000CogWh000?o0000omeo0?oMO`000ol000000ooM
O`3o0000om^70006om^700;o00001_oTJP001_l0003ojET0o`000?l0003oU;T0o`0000?oU[T000Co
0000oiJi0?nF^@3o00000onE^@001?l0003oUKT0oiFi0?l00003oiBi0003o`000?oooooooooo00oo
oooo00?o0000ooooooooool08oooool001oooooo0ol00004ooooo`03o`000?oooooooooo02Oooooo
0_l00004od:R0003o`000?m3XP3o@j8000?o@j8000?o0000odBR0?m4XP000om4XP000ol0003oA:80
odBR0003odBR0003o`000?m5XP3oAJ8000?oAJ8000?o0000odFR0?m5XP000_m5XP000ol0003oAJ80
odFR0004odFR0003o`000?m4XP3oA:8000?oA:8000?o0000odBR0?m4XP000_m4XP000ol0003o@j80
od>R0004od>R0003o`000?m3XP3o@j8000?o@j8000?o0000od:R0?m2XP001?m2XP000ol0003o@J40
od6Q0002od6Q00?o00001?oNO@000ol0003ogWh0omin0004omin0003o`000?oNOP3ogWh000CogWh0
00?o0000omin0?oNOP001?oNOP03o`0000CogGl000?o0000om^70?oKQ`001?oKQ`02o`0000Koi6X0
00Co0000onUI0?oYF@3ojET00ol00002oiJi0005o`000?nF^@3oU[T0oiJi0?l000000onE^@001?l0
003oUKT0oiFi0?l00003oiBi0003o`000?oooooooooo013ooooo00?o0000ooooooooool08_ooool0
01oooooo0ol00005ooooo`03o`000?oooooooooo02?ooooo0ol000000om1X@3o0000od:R0003od:R
0003o`000?m3XP3o@j8000?o@j8000?o0000odBR0?m4XP000om4XP000ol0003oA:80odBR0003odBR
0003o`000?m5XP3oAJ8000?oAJ8000?o0000odFR0?m5XP000_m5XP000ol0003oAJ80odFR0004odFR
0003o`000?m4XP3oA:8000?oA:8000?o0000odBR0?m4XP000_m4XP000ol0003o@j80od>R0004od>R
0003o`000?m3XP3o@j8000Co@j8000?o0000od:R0?m2XP000om2XP000ol0003o@J40o`000002o`00
0003omim0?l0003ogWd000GogWd000?o0000omin0?oNOP000ooNOP000ol0003ogWh0omin0005omin
0003o`000?oNOP3ogWh000?o000000?ogWh0o`000?oMO`001?oMO`000ol0003ofhL0om^70002om^7
00;o000000?olSH0o`000?oTJP001OoTJP001?l0003ojET0onUI0?oYF@02o`0000?oU[T000Go0000
oiJi0?nF^@3oU[T0o`000003oiFi0004o`000?nE^@3oUKT0o`0000?oU;T00_l0000Aooooo`03o`00
0?oooooooooo02;ooooo000Oooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool07_oo
ool4o`0000Co@J4000?o0000od:R0?m2XP000_m2XP000ol0003o@j80od>R0003od>R0003o`000?m4
XP3oA:8000?oA:8000?o0000odBR0?m4XP000om4XP000ol0003oAJ80odFR0003odFR0003o`000?m5
XP3oAJ8000?oAJ8000?o0000odFR0?m5XP000om5XP000ol0003oA:80odBR0003odBR0003o`000?m4
XP3oA:8000;oA:8000?o0000od>R0?m3XP001?m3XP000ol0003o@j80od>R0004od>R0003o`000?m2
XP3o@Z8000;o@Z800ol00004omim0003o`000?oNO@3ogWd000CogWd000?o0000omin0?oNOP001?oN
OP000ol0003ogWh0omin0004omin00?o00001?oNOP000ol0003ogGl0omeo0004omeo0004o`000?oK
Q`3ofhL0o`0000ColSH000?o0000onAZ0?oTJP000_oTJP000ol0003ojET0onUI0003onUI00;o0000
0_nF^@001Ol0003oU[T0oiJi0?nF^@3o000000?oUKT000Co0000oiFi0?nE^@3o00000onD^@000ol0
003oU;T0o`00000Aooooo`03o`000?oooooooooo027ooooo0006ooooo`;o00001?ooool00ol0003o
ooooooooo`02ooooo`?o00000oooool3o`0000Gooooo00Co0000ooooool0003o00001_ooool00ol0
003oooooooooo`0Iooooo`Co00000om0X@000ol0003o@J40od6Q0002od6Q0003o`000?m2XP3o@Z80
00;o@Z8000?o0000od>R0?m3XP000om3XP000ol0003oA:80odBR0003odBR0003o`000?m4XP3oA:80
00?oA:8000?o0000odFR0?m5XP000om5XP000ol0003oAJ80odFR0003odFR0003o`000?m5XP3oAJ80
00?oAJ8000?o0000odBR0?m4XP000om4XP000ol0003oA:80odBR0003odBR0003o`000?m3XP3o@j80
00Co@j8000?o0000od>R0?m3XP000om3XP000ol0003o@Z80od:R0002o`000003omim0?l0003ogWd0
00GogWd000?o0000omim0?oNO@000ooNO@000ol0003ogWh0omin0004omin0003o`000?oNOP3ogWh0
00;ogWh00ol00006omin0003o`000?oMO`3ogGl000CogGl00ol00005oo8f0003o`000?oTJP3oi6X0
00;oi6X000?o0000onUI0?oYF@000ooYF@001Ol0003oU[T0o`000?nF^@3o000000?oU[T000Co0000
oiFi0?nE^@3o00000onE^@001?l0003oU;T0oiBi0?l00003oiBi0003o`000?oooooooooo00oooooo
00?o0000ooooooooool08?ooool000Gooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool4o`0000Oooooo00?o0000oooooooo
ool05Oooool3o`000003ocnQ0?l0003o@:4000Co@:4000?o0000od6Q0?m1X@000_m1X@000ol0003o
@Z80od:R0002od:R0003o`000?m3XP3o@j8000Co@j8000?o0000odBR0?m4XP000_m4XP000ol0003o
A:80odBR0003odBR0003o`000?m5XP3oAJ8000?oAJ8000?o0000odFR0?m5XP000om5XP000ol0003o
AJ80odFR0003odFR0003o`000?m4XP3oA:8000?oA:8000?o0000odBR0?m4XP000om4XP000ol0003o
@j80od>R0004od>R0003o`000?m3XP3o@j8000?o@j800ol00003omim0003o`000?oNO@3ogWd000Co
gWd000?o0000omim0?oNO@001?oNO@000ol0003ogWh0omin0003omin0003o`000?oNOP3o000000;o
00000_oNOP000ol0003ogWh0omin0004omin0003o`000?oMO`3ogGl000?ogGl00_l00008oo8f0004
o`000?oTJP3oi6X0o`0000GojET000Co0000onUH0?l0003oU[T00_l00002oiJi0005o`000?nE^@3o
UKT0oiFi0?l000000_nE^@001Ol0003oU;T0oiBi0?nD^@3o000000?oU;T000?o0000ooooooooool0
3oooool2o`00027ooooo0005ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000oooooooo
ool04_ooool2o`0000Co?j4000?o0000od2Q0?m0X@000om0X@000ol0003o@J40od6Q0002od6Q0003
o`000?m2XP3o@Z8000;o@Z8000?o0000od>R0?m3XP001?m3XP000ol0003oA:80odBR0002odBR0003
o`000?m4XP3oA:8000?oA:8000?o0000odFR0?m5XP000om5XP000ol0003oAJ80odFR0003odFR0003
o`000?m5XP3oAJ8000?oAJ8000?o0000odBR0?m4XP000om4XP000ol0003oA:80odBR0003odBR0003
o`000?m3XP3o@j8000Co@j8000?o0000od>R0?m3XP000_m3XP02o`0000KogWd000?o0000omim0?oN
O@000ooNO@000ol0003ogWd0omim0004omim0003o`000?oNOP3ogWh000;ogWh00ol00005omin0003
o`000?oNOP3ogWh000GogWh000?o0000omeo0?l000000_l000000ood;@3o0000oo8f0007oo8f0003
o`000?oTJP3o000000GojET000Co0000onUH0?oYF03ojEP00_l00003oiJi0005o`000?nE^@3oUKT0
oiFi0?l000000_nE^@001Ol0003oU;T0oiBi0?nD^@3o000000?oU;T00_l0000Aooooo`03o`000?oo
oooooooo01oooooo0005ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo0_l00009ooooo`03o`000?oooooooooo00kooooo
0ol000000olmX03o0000ocnQ0003ocnQ0003o`000?m0X@3o@:4000?o@:4000?o0000od6Q0?m1X@00
0_m1X@000ol0003o@Z80od:R0003od:R0003o`000?m3XP3o@j8000?o@j8000?o0000odBR0?m4XP00
0_m4XP000ol0003oA:80odBR0003odBR0003o`000?m5XP3oAJ8000?oAJ8000?o0000odFR0?m5XP00
0om5XP000ol0003oAJ80odFR0003odFR0003o`000?m4XP3oA:8000?oA:8000?o0000odBR0?m4XP00
0om4XP000ol0003o@j80od>R0004od>R0003o`000?m3XP3o000000;o000000?ogWd0o`000?oNO@00
1OoNO@000ol0003ogWd0omim0003omim0003o`000?oNO@3ogWd000CogWd000?o0000omin0?l00000
0_l00002omin0003o`000?oNOP3ogWh000CogWh000?o0000omin0?oNOP000_oNOP04o`0000Gom2d0
00?o0000oo8f0?ob=P001Oob=P000ol0003oi6X0o`000005onUI0003o`000?oYF03ojEP000;ojEP0
0_l00002oiJi0005o`000?nE^@3oUKT0oiFi0?l000000_nE^@001Ol0003oU;T0oiBi0?nD^@3o0000
00;oU;T000?o0000oiBi0?l000004_ooool00ol0003oooooooooo`0Nooooo`001Oooool01?l0003o
ooooooooool00009ooooo`04o`000?ooooooooooooooo`Co00001?ooool2o`000004ooooool0003o
05a6o`0000Wooooo00?o0000ooooooooool02oooool2o`0000Co?J0000?o0000ocnQ0?loX@000_lo
X@000ol0003o@:40od2Q0003od2Q0003o`000?m1X@3o@J4000;o@J4000?o0000od:R0?m2XP000om2
XP000ol0003o@j80od>R0003od>R0003o`000?m4XP3oA:8000;oA:8000?o0000odBR0?m4XP000om4
XP000ol0003oAJ80odFR0003odFR0003o`000?m5XP3oAJ8000?oAJ8000?o0000odFR0?m5XP000om5
XP000ol0003oA:80odBR0004odBR0003o`000?m4XP3oA:8000;oA:8000?o0000od>R0?m3XP000_m3
XP04o`0000CogWd000?o0000omim0?oNO@001?oNO@000ol0003ogWd0omim0003omim0003o`000?oN
O@3ogWd000?ogWd00ol00005omin0003o`000?oNOP3ogWh000CogWh000?o0000omin0?l000000_l0
0002oo@]0003o`000?od;@3om2d000Gom2d000?o0000oo8f0?ob=P001?ob=P02o`0000GojET000?o
0000onUH0?oYF0000ooYF0001Ol0003oU[T0o`000?nF^@3o000000?oUKT000Co0000oiFi0?nE^@3o
00000onD^@001?l0003oU;T0oiBi0?l00002oiBi0003o`000?oooooooooo00oooooo00?o0000oooo
ooooool07_ooool000Gooooo00Co0000oooooooooooo00002?ooool2o`0000?ooooo00?o0000oooo
ooooool01Oooool01_l0003oooooooooool0003o05a6o`0000[ooooo0_l00008ooooo`?o000000?o
>il0o`000?lmX0000olmX0000ol0003o?j40ocnQ0002ocnQ0003o`000?m0X@3o@:4000?o@:4000?o
0000od6Q0?m1X@000_m1X@000ol0003o@Z80od:R0003od:R0003o`000?m3XP3o@j8000?o@j8000?o
0000odBR0?m4XP000om4XP000ol0003oA:80odBR0002odBR0003o`000?m5XP3oAJ8000?oAJ8000?o
0000odFR0?m5XP000om5XP000ol0003oAJ80odFR0003odFR0003o`000?m4XP3oA:8000CoA:8000?o
0000odBR0?m4XP000_m4XP000ol0003o@j80o`000002o`0000;ogWd000?o0000omim0?oNO@001?oN
O@000ol0003ogWd0omim0003omim0003o`000?oNO@3ogWd000CogWd000?o0000omim0?l000000_l0
0002omim0003o`000?oNOP3ogWh000?ogWh000?o0000omin0?oNOP000ooNOP03o`0000Kom2d000?o
0000oo@]0?od;@001?od;@000ol0003olSH0oo8f0002oo8f00;o000000?omb<0o`000?oYF@000ooY
F@000ol0003ojEP0onUH0003onUH0004o`000?oYF03o0000oiJi00;o00000_nE^@001Ol0003oUKT0
oiFi0?nE^@3o000000;oU;T000Go0000oiBi0?nD^@3oU;T0o`000002oiBi00;o00004Oooool00ol0
003oooooooooo`0Mooooo`001_ooool2o`0000[ooooo00Co0000oooooooooooooooo1Ol00003oooo
o`05o`000?ooooooooooo`000?l0G4H00_l0000;ooooo`03o`000?oooooooooo00;ooooo0ol00004
oc^O0003o`000?lmX03o?J0000;o?J0000?o0000ocnQ0?loX@000_loX@000ol0003o@:40od2Q0003
od2Q0003o`000?m1X@3o@J4000;o@J4000?o0000od:R0?m2XP000om2XP000ol0003o@j80od>R0003
od>R0003o`000?m4XP3oA:8000?oA:8000?o0000odBR0?m4XP000_m4XP000ol0003oAJ80odFR0003
odFR0003o`000?m5XP3oAJ8000?oAJ8000?o0000odFR0?m5XP001?m5XP000ol0003oA:80odBR0003
odBR0004o`000?m4XP3oA:80odBR00?o00001OoNO@000ol0003ogWd0omim0004omim0003o`000?oN
O@3ogWd000?ogWd000?o0000omim0?oNO@000ooNO@03o`0000GogWd000?o0000omin0?oNOP001?oN
OP000ol0003ogWh0o`000002o`000003oo@^0?l0003om2d000Kom2d000?o0000oo@]0?od;@001Ood
;@001?l0003olSH0o`000?l00004ooLS0005o`000?oYF@3ojET0onUI0?l000001?oYF0001?l0003o
jEP0onUH0?oYF002o`0000?oUKT000Go0000oiFi0?nE^@3oUKT0o`000002oiBi0005o`000?nD^@3o
U;T0oiBi0?l000000_nD^@000ol0003oU;T0o`00000Aooooo`03o`000?oooooooooo01cooooo000N
ooooo`;o000000Koooooo`000?l0G4Ko0000o`290?l0000;ooooo`Co000000?o>Il0o`000?lkW`00
1?lkW`000ol0003o?J00ocfP0002ocfP0003o`000?loX@3o?j4000;o?j4000?o0000od2Q0?m0X@00
0om0X@000ol0003o@J40od6Q0002od6Q0003o`000?m2XP3o@Z8000?o@Z8000?o0000od>R0?m3XP00
0om3XP000ol0003oA:80odBR0003odBR0003o`000?m4XP3oA:8000;oA:8000?o0000odFR0?m5XP00
0om5XP000ol0003oAJ80odFR0003odFR0003o`000?m5XP3oAJ8000CoAJ8000?o0000odBR0?m4XP00
0om4XP04o`000003omim0?l0003ogWd000KogWd000?o0000omim0?oNO@000ooNO@000ol0003ogWd0
omim0004omim0003o`000?oNO@3o000000;o000000?ogWd0o`000?oNO@001OoNO@000ol0003ogWh0
omin0003omin00?o00001Ood;P000ol0003om2d0oo@]0005oo@]0003o`000?od;@3om2d000Com2d0
0_l00007ooLS0003o`000?oYF@3o000000GojEP000?o0000onUH0?oYF0000_oYF002o`0000;oUKT0
00Co0000oiFi0?nE^@3o00000onD^@001Ol0003oU;T0oiBi0?nD^@3o000000;oU;T000Co0000oiBi
0?nD^@3o00004?ooool2o`0001gooooo000Nooooo`04o`000?ooooooooooooooo`;o00000_l0R@00
0ol0003oooooooooo`06ooooo`?o00001?liW`000ol0003o>il0oc^O0003oc^O0003o`000?lmX03o
?J0000;o?J0000?o0000ocnQ0?loX@000_loX@000ol0003o@:40od2Q0003od2Q0003o`000?m1X@3o
@J4000;o@J4000?o0000od:R0?m2XP000om2XP000ol0003o@j80od>R0003od>R0003o`000?m4XP3o
A:8000?oA:8000?o0000odBR0?m4XP000_m4XP000ol0003oAJ80odFR0004odFR0003o`000?m5XP3o
AJ8000?oAJ8000?o0000odFR0?m5XP000om5XP000ol0003oA:80odBR0002odBR00;o00001?oNO@00
0ol0003ogWd0omim0005omim0003o`000?oNO@3ogWd000?ogWd000?o0000omim0?oNO@001?oNO@02
o`0000CogWd000?o0000omim0?oNO@001OoNO@000ol0003ogWh0o`000002o`000003oo@^0?l0003o
m2h000Gom2h000?o0000oo@]0?od;@001Ood;@001?l0003om2d0oo@]0?od;@03o`000003ooTI0?l0
003omb<000Komb<00_l00005onUH0003o`000?oYF03ojEP000?ojEP000Go0000oiFi0?l0003oUKT0
o`000002oiFi0005o`000?nD^@3oU;T0oiBi0?l000000_nD^@001?l0003oU;T0oiBi0?l00003oiBi
0003o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool001kooooo00Co0000oooooooo
oooooooo0_l00003o`2900So00000_lfWP000ol0003o>Il0ocVO0002ocVO0003o`000?lkW`3o>il0
00?o>il000?o0000ocfP0?lmX0000_lmX0000ol0003o?j40ocnQ0002ocnQ0003o`000?m0X@3o@:40
00?o@:4000?o0000od6Q0?m1X@000_m1X@000ol0003o@Z80od:R0003od:R0003o`000?m3XP3o@j80
00?o@j8000?o0000odBR0?m4XP000om4XP000ol0003oA:80odBR0002odBR0003o`000?m5XP3oAJ80
00CoAJ8000?o0000odFR0?m5XP000om5XP000ol0003oAJ80odFR0003odFR0003o`000?m4XP3o0000
00;o000000?ogWd0o`000?oNO@001?oNO@000ol0003ogWd0omim0004omim0003o`000?oNO@3ogWd0
00?ogWd000Co0000omim0?oNO@3ogWd01?l00005omim0003o`000?oNO@3ogWd000CogWd00ol00005
oo@^0003o`000?od;P3om2h000Com2h000?o0000oo@]0?od;@001?od;@001?l0003om2d0o`000?l0
0005ooTI0003o`000?og8`3omb<000?omb<000?o0000ooPQ0?l000001?oYF0000ol0003ojEP0onUH
0003onUH0004o`000?oYF03o0000oiFi00;o00000_nE^@001Ol0003oU;T0oiBi0?nD^@3o000000;o
U;T000Co0000oiBi0?nD^@3o00000onD^@02o`00017ooooo00?o0000ooooooooool06_ooool001go
oooo0ol00002ooooo`;o00000ol0R@000ol0003o:iX0ob^J0002ob^J0003o`000?lfWP3o=Yh000;o
=Yh000?o0000ocVO0?liW`000_liW`000ol0003o>il0oc^O0003oc^O0003o`000?lmX03o?J0000;o
?J0000?o0000ocnQ0?loX@000_loX@000ol0003o@:40od2Q0003od2Q0003o`000?m1X@3o@J4000;o
@J4000?o0000od:R0?m2XP000om2XP000ol0003o@j80od>R0003od>R0003o`000?m4XP3oA:8000?o
A:8000?o0000odBR0?m4XP000om4XP000ol0003oAJ80odFR0003odFR0003o`000?m5XP3oAJ8000?o
AJ8000?o0000odFR0?m5XP000_m5XP03o`0000CogWd000?o0000omim0?oNO@000ooNO@000ol0003o
gWd0omim0004omim0003o`000?oNO@3ogWd000CogWd00ol00003omim0003o`000?oNO@3ogWd000Co
gWd000?o0000omim0?oNO@000ol000000ood;`3o0000oo@^0005oo@^0003o`000?od;P3om2h000Go
m2h000?o0000oo@]0?od;@000ood;@02o`0000SonAT000?o0000ooLS0?og8`000_l00003ooPQ0005
o`000?oYF03ojEP0onUH0?l000001?oYF0001?l0003ojEP0onUH0?oYF002o`0000?oUKT000Go0000
oiBi0?nD^@3oU;T0o`000002oiBi0004o`000?nD^@3oU;T0o`0000?oU;T000?o0000oiBi0?l00000
4?ooool00ol0003oooooooooo`0Jooooo`007Oooool00ol0003oooooooooo`02ooooo`;o00000ol0
R@000ol0003o:iX0ob^J0002ob^J0003o`000?lfWP3o=Yh000;o=Yh000?o0000ocVO0?liW`000_li
W`000ol0003o>il0oc^O0003oc^O0003o`000?lmX03o?J0000;o?J0000?o0000ocnQ0?loX@000_lo
X@000ol0003o@:40od2Q0003od2Q0003o`000?m1X@3o@J4000?o@J4000?o0000od:R0?m2XP000_m2
XP000ol0003o@j80od>R0003od>R0003o`000?m4XP3oA:8000?oA:8000?o0000odBR0?m4XP000om4
XP000ol0003oAJ80odFR0003odFR0003o`000?m5XP3oAJ8000?oAJ8000?o0000odFR0?l000000_l0
00000ooNO03o0000omim0005omim0003o`000?oNO@3ogWd000;ogWd000?o0000omim0?oNO@001?oN
O@001?l0003ogWd0omim0?oNO@04o`0000GogWd000?o0000omim0?oNO@001?oNO@03o`0000Gom2l0
00?o0000oo@^0?od;P001?od;P000ol0003om2h0oo@^0004oo@^0003o`000?od;@3om2d000?o0000
00?onAX0o`000?oi6@001ooi6@000ol0003omb<0o`000006ooPQ0003o`000?oYF03o000000GojEP0
00?o0000onUH0?oYF0000_oYF002o`0000;oUKT000Co0000oiBi0?nD^@3o00000onD^@001?l0003o
U;T0oiBi0?l00002oiBi0005o`000?nD^@3oU;T0oiBi0?l000004?ooool00ol0003oooooooooo`0I
ooooo`007Oooool3o`0000;ooooo0_l00003o`290003o`000?l[VP3o:iX000;o:iX000?o0000ocJN
0?lfWP000_lfWP000ol0003o>Il0ocVO0002ocVO0003o`000?lkW`3o>il000?o>il000?o0000ocfP
0?lmX0000_lmX0000ol0003o?j40ocnQ0002ocnQ0003o`000?m0X@3o@:4000?o@:4000?o0000od6Q
0?m1X@000om1X@000ol0003o@Z80od:R0002od:R0003o`000?m3XP3o@j8000?o@j8000?o0000odBR
0?m4XP000om4XP000ol0003oA:80odBR0003odBR0003o`000?m5XP3oAJ8000?oAJ8000?o0000odFR
0?m5XP000_m5XP03o`0000CogW`000?o0000omim0?oNO@001?oNO@000ol0003ogWd0omim0003omim
0003o`000?oNO@3ogWd000CogWd00ol00003omim0003o`000?oNO@3ogWd000CogWd000?o0000omim
0?oNO@000_oNO@02o`0000Oom2l000?o0000oo@^0?od;P001?od;P000ol0003om2h0oo@^0003oo@^
00Co00001Ooi6P000ol0003onAT0ooTI0004ooTI00?o00001ooh8@02o`0000GojEP000?o0000onUH
0?oYF0000ooYF004o`0000?oU;T000Co0000oiBi0?nD^@3o00000onD^@001?l0003oU;T0oiBi0?l0
0003oiBi0003o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool001gooooo00?o0000
ooooooooool00_ooool2o`0000?o08T000?o0000ob^J0?l[VP000_l[VP000ol0003o=Yh0ocJN0002
ocJN0003o`000?liW`3o>Il000;o>Il000?o0000oc^O0?lkW`000olkW`000ol0003o?J00ocfP0002
ocfP0003o`000?loX@3o?j4000;o?j4000?o0000od2Q0?m0X@001?m0X@000ol0003o@J40od6Q0002
od6Q0003o`000?m2XP3o@Z8000;o@Z8000?o0000od>R0?m3XP000om3XP000ol0003oA:80odBR0003
odBR0003o`000?m4XP3oA:8000?oA:8000?o0000odFR0?m5XP000om5XP000ol0003oAJ80o`000002
o`000003omil0?l0003ogW`000GogW`000?o0000omim0?oNO@000ooNO@000ol0003ogWd0omim0003
omim0004o`000?oNO@3ogWd0omim00Co00001OoNO@000ol0003ogWd0omim0004omim0003o`000?oN
O@3o000000;o000000?om2l0o`000?od;`001ood;`000ol0003om2h0oo@^0003oo@^0003o`000?od
;P3om2h000?o00000_oi6`000ol0003onAX0ooTJ0005ooTJ0003o`000?oi6@3onAT000?o00000_oj
5`000ol0003on240ooPQ0004ooPQ0003o`000?oh8@3o000000CojEP000?o0000onUH0?oYF0000ooY
F0000ol0003ojEP0onUH0002o`0000?oU;T000Co0000oiBi0?nD^@3o00000_nD^@001Ol0003oU;T0
oiBi0?nD^@3o000000?oU;T00_l0000@ooooo`;o00006Oooool000[ooooo0_l00004ooooo`04o`00
0?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`02ooooo`;o00000ol0R@000ol0003o
:iX0ob^J0002ob^J0003o`000?lfWP3o=Yh000;o=Yh000?o0000ocVO0?liW`000_liW`000ol0003o
>il0oc^O0003oc^O0003o`000?lmX03o?J0000;o?J0000?o0000ocnQ0?loX@000_loX@000ol0003o
@:40od2Q0004od2Q0003o`000?m1X@3o@J4000;o@J4000?o0000od:R0?m2XP000_m2XP000ol0003o
@j80od>R0004od>R0003o`000?m4XP3oA:8000;oA:8000?o0000odBR0?m4XP000om4XP000ol0003o
AJ80odFR0002odFR00?o00001?oNO0000ol0003ogW`0omil0004omil0003o`000?oNO@3ogWd000?o
gWd000?o0000omim0?oNO@000ooNO@04o`0000?ogWd000?o0000omim0?oNO@000ooNO@000ol0003o
gWd0omim0003omim00?o00001Ood;`000ol0003om2l0oo@_0005oo@_0003o`000?od;P3om2h000?o
m2h00ol00006ooTK0003o`000?oi6P3onAX000ConAX00ol00006ooXG0004o`000?oh8@3on240ooPQ
00;o00000ooh8@001Ol0003ojEP0onUH0?oYF03o000000CojEP000?o0000onUH0?oYF0000_oYF000
1Ol0003oU;T0oiBi0?nD^@3o000000;oU;T000Co0000oiBi0?nD^@3o00000onD^@001_l0003oU;T0
oiBi0?l0003oU;T0o`00017ooooo00?o0000ooooooooool01Oooool3o`0000oooooo0009ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02
ooooo`;o00000ol0R@000ol0003o:iX0ob^J0002ob^J0003o`000?lfWP3o=Yh000;o=Yh000?o0000
ocVO0?liW`000_liW`000ol0003o>il0oc^O0003oc^O0003o`000?lmX03o?J0000;o?J0000?o0000
ocnQ0?loX@000oloX@000ol0003o@:40od2Q0003od2Q0003o`000?m1X@3o@J4000;o@J4000?o0000
od:R0?m2XP000_m2XP000ol0003o@j80od>R0004od>R0003o`000?m4XP3oA:8000;oA:8000?o0000
odBR0?m4XP000om4XP000ol0003oAJ80o`000002o`000003omil0?l0003ogW`000GogW`000?o0000
omil0?oNO0000ooNO0000ol0003ogWd0omim0003omim0004o`000?oNO@3ogWd0omim00?o00001_oN
O@000ol0003ogWd0omim0004omim0003o`000?oNO@3o000000;o000000?om300o`000?od;`001_od
;`000ol0003om2l0oo@_0004oo@_0003o`000?od;P3om2h000?o000000?onA`0o`000?oi6`001ooi
6`000ol0003onAX0ooTJ0003o`000003ooXH0?l0003onQL000OonQL000?o0000ooPQ0?l000001_oh
8@000ol0003ojEP0o`000005onUH0003o`000?oYF03ojEP000;ojEP00_l00002oiBi0004o`000?nD
^@3oU;T0o`0000;oU;T000Go0000oiBi0?nD^@3oU;T0o`000002oiBi0004o`000?nD^@3oU;T0o`00
017ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000kooooo0009oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`0000?ooooo0_l00003
o`290003o`000?l[VP3o:iX000;o:iX000?o0000ocJN0?lfWP000_lfWP000ol0003o>Il0ocVO0002
ocVO0003o`000?lkW`3o>il000?o>il000?o0000ocfP0?lmX0000_lmX0000ol0003o?j40ocnQ0003
ocnQ0003o`000?m0X@3o@:4000?o@:4000?o0000od6Q0?m1X@000_m1X@000ol0003o@Z80od:R0003
od:R0003o`000?m3XP3o@j8000?o@j8000?o0000odBR0?m4XP000_m4XP000ol0003oA:80odBR0002
odBR00?o00001?oNO0000ol0003ogW`0omil0004omil0003o`000?oNO03ogW`000?ogW`000?o0000
omim0?oNO@001?oNO@03o`0000?ogWd000?o0000omim0?oNO@000ooNO@000ol0003ogWd0omim0003
omim00?o00001Ood<0000ol0003om2l0oo@_0004oo@_0003o`000?od;`3om2l000Com2l00ol00005
ooTL0003o`000?oi6`3onA/000ConA/01?l00005ooXH0003o`000?oj5`3onQL000ConQL00ol00007
ooPQ00;o00001OoYF0000ol0003ojEP0onUH0002onUH0003o`000?oYF03o000000;o00000_nD^@00
1Ol0003oU;T0oiBi0?nD^@3o000000;oU;T000Go0000oiBi0?nD^@3oU;T0o`000002oiBi0003o`00
0?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`002Ooo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003o08T0o`290?l0R@3o000000Co:iX000?o0000ocJN0?lfWP000_lfWP000ol0003o
>Il0ocVO0002ocVO0003o`000?lkW`3o>il000?o>il000?o0000ocfP0?lmX0000olmX0000ol0003o
?j40ocnQ0002ocnQ0003o`000?m0X@3o@:4000?o@:4000?o0000od6Q0?m1X@000_m1X@000ol0003o
@Z80od:R0003od:R0003o`000?m3XP3o@j8000?o@j8000?o0000odBR0?m4XP000_m4XP000ol0003o
A:80o`000002o`000003omim0?l0003ogW`000GogW`000?o0000omil0?oNO0000ooNO0000ol0003o
gW`0omil0003omil0003o`000?oNO@3ogWd000;ogWd00ol00005omim0003o`000?oNO@3ogWd000Co
gWd000?o0000omim0?l000000_l000000ood<03o0000oo@`0005oo@`0003o`000?od;`3om2l000Go
m2l000?o0000oo@_0?od;`000ol000000ooi7@3o0000ooTL0006ooTL0003o`000?oi6`3onA/000?o
00000_oj6@000ol0003onQP0ooXH0005ooXH0003o`000?oj5`3onQL000?o00000ooj60000ol0003o
n240ooPQ0002ooPQ00;o000000?on240o`000?oYF0000ooYF0000ol0003ojEP0onUH0002onUH0004
o`000?oYF03ojEP0onUH00;o00000_nD^@001Ol0003oU;T0oiBi0?nD^@3o000000;oU;T000Go0000
oiBi0?nD^@3oU;T0o`000002oiBi00;o00004Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00cooooo0009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Cooooo0_l00002o`290003o`000?l[VP3o:iX000;o:iX0
00?o0000ocJN0?lfWP000_lfWP000ol0003o>Il0ocVO0002ocVO0003o`000?lkW`3o>il000?o>il0
00?o0000ocfP0?lmX0000olmX0000ol0003o?j40ocnQ0002ocnQ0003o`000?m0X@3o@:4000?o@:40
00?o0000od6Q0?m1X@000_m1X@000ol0003o@Z80od:R0003od:R0003o`000?m3XP3o@j8000?o@j80
00Co0000odBR0?m4XP3oA:800ol00004omim0003o`000?oNO03ogW`000CogW`000?o0000omil0?oN
O0000ooNO0000ol0003ogW`0omil0004omil00Co00000_oNO@000ol0003ogWd0omim0003omim0003
o`000?oNO@3ogWd000?ogWd00ol00005oo@`0003o`000?od<03om30000Com30000?o0000oo@_0?od
;`000ood;`04o`0000GonAd000?o0000ooTL0?oi70001?oi7003o`0000KonQT000?o0000ooXH0?oj
60001?oj6003o`0000OonQP000Co0000ooPQ0?l0003o00001?oh8@001Ol0003ojEP0onUH0?oYF03o
000000CojEP000?o0000onUH0?oYF0000_oYF0001?l0003oU;T0oiBi0?l00003oiBi0004o`000?nD
^@3oU;T0o`0000?oU;T000Ko0000oiBi0?nD^@3o0000oi>i0?l0000Aooooo`04o`000?oooooooooo
ooooo`Co00003oooool000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000?ooooo0_l00005ooooo`;o00000_l0R@000ol0003o:iX0ob^J0002ob^J0003o`000?lf
WP3o=Yh000;o=Yh000?o0000ocVO0?liW`000_liW`000ol0003o>il0oc^O0004oc^O0003o`000?lm
X03o?J0000;o?J0000?o0000ocnQ0?loX@000_loX@000ol0003o@:40od2Q0003od2Q0003o`000?m1
X@3o@J4000;o@J4000?o0000od:R0?m2XP000om2XP000ol0003o@j80od>R0003od>R00Co000000?o
gWd0o`000?oNO@001OoNO@000ol0003ogW`0omil0003omil0003o`000?oNO03ogW`000?ogW`000?o
0000omil0?oNO0000_oNO003o`0000GogWd000?o0000omim0?oNO@001?oNO@000ol0003ogWd0o`00
0002o`000003oo@a0?l0003om30000Gom30000?o0000oo@`0?od<0001?od<0000ol0003om2l0oo@_
0003o`0000;on1h000?o0000ooTM0?oi7@001Ooi7@000ol0003onA`0ooTL0003o`0000;onAX000?o
0000ooXI0?oj6@001Ooj6@000ol0003onQP0ooXH0003o`000003ooXH0?l0003onQP000OonQP00_l0
0007ooPQ0003o`000?oYF03o000000CojEP000?o0000onUH0?oYF0000ooYF002o`000005oiBi0?l0
003oU;T0oiBi0?l000000onD^@001?l0003oU;T0oiBi0?l00002oiBi0004o`000?nC^@3oTkT0o`00
013ooooo0ol00002ooooo`03o`000?oooooooooo013ooooo000:ooooo`;o00002Oooool3o`0000Co
oooo00?o0000ooooooooool01?ooool2o`0000;o08T000?o0000ob^J0?l[VP000_l[VP000ol0003o
=Yh0ocJN0002ocJN0003o`000?liW`3o>Il000;o>Il000?o0000oc^O0?lkW`001?lkW`000ol0003o
?J00ocfP0002ocfP0003o`000?loX@3o?j4000;o?j4000?o0000od2Q0?m0X@000om0X@000ol0003o
@J40od6Q0002od6Q0003o`000?m2XP3o@Z8000?o@Z8000?o0000od>R0?m3XP000_m3XP02o`0000Co
gWd000?o0000omim0?oNO@001?oNO@000ol0003ogW`0omil0003omil0003o`000?oNO03ogW`000Co
gW`01?l00002omil0003o`000?oNO@3ogWd000?ogWd000?o0000omim0?oNO@000ooNO@03o`0000Go
m34000?o0000oo@`0?od<0001?od<0000ol0003om300oo@`0003oo@`00?o00001_oh7P000ol0003o
nAd0ooTM0004ooTM00?o00001_oi6P000ol0003onQT0ooXI0004ooXI00?o00001Ooj60000ol0003o
nQP0ooXH0002ooXH00?o000000?onQP0o`000?oh8@001_oh8@02o`0000GojEP000?o0000onUH0?oY
F0000_oYF0000ol0003ojET0o`000002o`0000;oU;T000Go0000oiBi0?nD^@3oU;T0o`000002oiBi
0004o`000?nD^@3oU;T0o`0000;oTkT00_l0000Aooooo`03o`000?oooooooooo00Go00003_ooool0
01cooooo00?o0000ooooooooool01?ooool2o`0000;o08T000?o0000ob^J0?l[VP000_l[VP000ol0
003o=Yh0ocJN0002ocJN0003o`000?liW`3o>Il000?o>Il000?o0000oc^O0?lkW`000olkW`000ol0
003o?J00ocfP0002ocfP0003o`000?loX@3o?j4000;o?j4000?o0000od2Q0?m0X@000om0X@000ol0
003o@J40od6Q0002od6Q0003o`000?m2XP3o@Z8000?o@Z8000?o0000od>R0?l000000_l000000ooN
O@3o0000omim0004omim0003o`000?oNO@3ogWd000?ogWd000?o0000omil0?oNO0000ooNO0000ol0
003ogW`0omil0002omil00?o00001OoNO0000ol0003ogWd0omim0004omim0003o`000?oNO@3o0000
00;o000000?olc40o`000?od<@001Ood<@000ol0003om300oo@`0004oo@`0003o`000?od<03om300
00?o00000_oh7P000ol0003on1h0ooPN0005ooPN0003o`000?oi7@3onAd000?o000000?onA/0o`00
0?oi6P001ooi6P000ol0003onQT0ooXI0003o`000003ooTI0?l0003onQP000KonQP000Co0000ooXH
0?l0003o00001Ooj60000ol0003on240ooPQ0002ooPQ00;o000000?on240o`000?oYF0000ooYF000
0ol0003ojEP0onUH0002onUH0003o`000?oYF@3ojET000;o00000onD^@001Ol0003oU;T0oiBi0?nD
^@3o000000;oU;T000Co0000oiBi0?nD^@3o00000_nC^@000ol0003oTkT0o`00000Aooooo`03o`00
0?oooooooooo01;ooooo000Looooo`;o00001Oooool2o`0000;o08T000?o0000ob^J0?l[VP000_l[
VP000ol0003o=Yh0ocJN0003ocJN0003o`000?liW`3o>Il000;o>Il000?o0000oc^O0?lkW`000olk
W`000ol0003o?J00ocfP0002ocfP0003o`000?loX@3o?j4000;o?j4000?o0000od2Q0?m0X@000om0
X@000ol0003o@J40od6Q0002od6Q0003o`000?m2XP3o@Z8000;o@Z800ol00004omim0003o`000?oN
O@3ogWd000?ogWd000?o0000omim0?oNO@000ooNO@000ol0003ogW`0omil0004omil00Co00000_oN
O0000ol0003ogW`0omil0003omil0003o`000?oNO@3ogWd000?ogWd00ol00005oo<a0003o`000?od
<@3om34000Com34000?o0000oo@`0?od<0000ood<003o`0000Kon1h000?o0000ooPN0?oh7P001?oh
7P03o`0000GonA/000?o0000ooTJ0?oi6P001?oi6P04o`0000GonAT000?o0000ooXH0?oj60001?oj
6002o`0000SonQP000Co0000ooPQ0?l0003o00001?oh8@001?l0003ojEP0onUH0?l00005onUH0004
o`000?oYF@3ojET0onUI00;o00000_nD^@001?l0003oU;T0oiBi0?l00003oiBi0006o`000?nD^@3o
U;T0o`000?nC^@3o00000onC^@000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo
000Looooo`03o`000?oooooooooo00Cooooo0_l00002o`290003o`000?l[VP3o:iX000;o:iX000?o
0000ocJN0?lfWP000olfWP000ol0003o>Il0ocVO0002ocVO0003o`000?lkW`3o>il000?o>il000?o
0000ocfP0?lmX0000_lmX0000ol0003o?j40ocnQ0002ocnQ0003o`000?m0X@3o@:4000?o@:4000?o
0000od6Q0?m1X@000_m1X@000ol0003o@Z80o`000002o`000003omim0?l0003ogWd000GogWd000?o
0000omim0?oNO@000_oNO@000ol0003ogWd0omim0003omim0003o`000?oNO03ogW`000;ogW`00ol0
0005omil0003o`000?oNO03ogW`000CogW`000?o0000omim0?l000000_l000000ooc<@3o0000oo<a
0005oo<a0003o`000?od<@3om34000Com34000?o0000oo@`0?od<0000ol00002ooPO0003o`000?oh
7P3on1h000Gon1h000?o0000ooPN0?oh7P000ol000000ooi703o0000ooTK0006ooTK0003o`000?oi
6P3onAX000?o00000_oi6P000ol0003onAT0ooTI0005ooTI0003o`000?oj603onQP000?o00000_oj
60000ol0003onQP0ooXH0004ooXH00?o00001ooh8@000ol0003ojEP0o`000004onUH0003o`000?oY
F@3ojET000;ojET000Go0000oiBi0?l0003oU;T0o`000002oiBi0004o`000?nD^@3oU;T0o`0000?o
U;T000?o0000oi>i0?l000000onC^@000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017o
oooo000Kooooo`03o`000?oooooooooo00Gooooo0_l00003o`290003o`000?l[VP3o:iX000;o:iX0
00?o0000ocJN0?lfWP000_lfWP000ol0003o>Il0ocVO0002ocVO0003o`000?lkW`3o>il000?o>il0
00?o0000ocfP0?lmX0000_lmX0000ol0003o?j40ocnQ0002ocnQ0003o`000?m0X@3o@:4000?o@:40
00Co0000od6Q0?m1X@3o@J400ol00004omim0003o`000?oNO@3ogWd000CogWd000?o0000omim0?oN
O@000_oNO@000ol0003ogWd0omim0004omim00Co00000_oNO0000ol0003ogW`0omil0003omil0003
o`000?oNO03ogW`000?ogW`00ol00005oo<a0003o`000?oc<@3olc4000Colc4000?o0000oo@a0?od
<@000ood<@03o`0000Kon1l000?o0000ooPN0?oh7P001?oh7P03o`0000GonA`000?o0000ooTK0?oi
6`001?oi6`03o`0000KonAX000?o0000ooTI0?oi6@001?oi6@03o`0000KonQP000?o0000ooXH0?oj
60000ol00002ooXH0003o`000?oh8@3on24000Gon2400_l00005onUH0009o`000?oYF@3ojET0onUI
0?l0003ojET0o`000?nD^@3o000000?oU;T000Co0000oiBi0?nD^@3o00000_nD^@001?l0003oTkT0
oi>i0?l00003oi>i00;o00004Oooool00ol0003oooooooooo`0@ooooo`006oooool2o`0000Kooooo
0_l00003o`290003o`000?l[VP3o:iX000;o:iX000?o0000ocJN0?lfWP000_lfWP000ol0003o>Il0
ocVO0002ocVO0003o`000?lkW`3o>il000?o>il000?o0000ocfP0?lmX0000_lmX0000ol0003o?j40
ocnQ0002ocnQ0003o`000?m0X@3o@:4000?o@:401?l000000ooNO@3o0000omim0005omim0003o`00
0?oNO@3ogWd000?ogWd000?o0000omim0?oNO@000_oNO@000ol0003ogWd0omim0002omim00?o0000
1OoNO0000ol0003ogW`0omil0004omil0003o`000?oNO03o000000;o000000?olc40o`000?oc<@00
1Ooc<@000ol0003olc40oo<a0004oo<a0003o`000?od<@3om34000?o00000_oh7`000ol0003on1l0
ooPO0005ooPO0003o`000?oh7P3on1h000?o000000?onA`0o`000?oi70001_oi70000ol0003onA/0
ooTK0003o`0000;onA/000?o0000ooTJ0?oi6P001Ooi6P000ol0003onAT0ooTI0003o`0000;onAT0
00?o0000ooXH0?oj60001?oj6003o`0000KonQP000?o0000ooPQ0?oh8@000_oh8@02o`000003ooPQ
0?l0003ojEP000?ojEP000?o0000onUI0?oYF@000_oYF@000ol0003ojET0onUI0002o`0000?oU;T0
00Co0000oiBi0?nD^@3o00000_nD^@001?l0003oTkT0oi>i0?l00003oi>i0003o`000?nC^@3o0000
013ooooo00?o0000ooooooooool04?ooool001_ooooo00?o0000ooooooooool01_ooool01Ol0003o
08T0o`290?l0R@3o000000Co:iX000?o0000ocJN0?lfWP000_lfWP000ol0003o>Il0ocVO0002ocVO
0003o`000?lkW`3o>il000?o>il000?o0000ocfP0?lmX0000_lmX0000ol0003o?j40ocnQ0002ocnQ
0003o`000?m0X@3o@:4000;o@:400_l00004omim0003o`000?oNO@3ogWd000CogWd000?o0000omim
0?oNO@000ooNO@000ol0003ogWd0omim0003omim00Co00000_oNO@000ol0003ogW`0omil0003omil
0003o`000?oNO03ogW`000?ogW`00ol00005oo<a0003o`000?oc<@3olc4000Colc4000?o0000oo<a
0?oc<@000ooc<@03o`0000Kon1l000?o0000ooPO0?oh7`001?oh7`03o`0000GonA`000?o0000ooTL
0?oi70001?oi7003o`0000KonA/000?o0000ooTJ0?oi6P001?oi6P03o`0000KonAT000?o0000ooXH
0?oj60000ol000000ooj603o0000ooXH0007ooXH0004o`000?oh8@3o0000o`0000Con24000Co0000
onUH0?oYF03o00001?oYF@000ol0003ojET0onUI0002onUI00;o00000_nD^@001?l0003oU;T0oiBi
0?l00002oiBi0004o`000?nC^@3oTkT0o`0000;oTkT000Co0000oi>i0?nC^@3o00004Oooool00ol0
003oooooooooo`0?ooooo`006oooool2o`0000Oooooo00Go0000o`290?l0R@3o08T0o`000004ob^J
0003o`000?lfWP3o=Yh000;o=Yh000?o0000ocVO0?liW`000_liW`000ol0003o>il0oc^O0003oc^O
0003o`000?lmX03o?J0000;o?J0000?o0000ocnQ0?loX@000_loX@000ol0003o@:40o`000002o`00
0003omim0?l0003ogWd000CogWd000?o0000omim0?oNO@000ooNO@000ol0003ogWd0omim0003omim
0003o`000?oNO@3ogWd000;ogWd00_l00005omim0003o`000?oNO03ogW`000CogW`000?o0000omil
0?l000000_l000000ooc<@3o0000oo<a0005oo<a0003o`000?oc<@3olc4000Colc4000?o0000oo<a
0?oc<@000ol00002ooPP0003o`000?oh7`3on1l000Gon1l000?o0000ooPO0?oh7`000ol000000ooi
7@3o0000ooTL0006ooTL0003o`000?oi703onA`000?o00000_oi70000ol0003onA/0ooTK0005ooTK
0003o`000?oi6P3onAX000?o00000_oi6P000ol0003onAT0ooTI0004ooTI00?o00001Ooj60000ol0
003onQP0ooXH0004ooXH00?o00001ooh8@000ol0003ojEP0o`000003onUI0003o`000?oYF@3ojET0
00?ojET01?l00002oiBi0007o`000?nD^@3oU;T0oiBi0?l0003oTkT0o`000003oi>i0003o`000?nC
^@3oTkT000;o00004?ooool00ol0003oooooooooo`0?ooooo`006oooool00ol0003oooooooooo`06
ooooo`05o`000?l0R@3o08T0o`290?l000001?l[VP000ol0003o=Yh0ocJN0002ocJN0003o`000?li
W`3o>Il000;o>Il000?o0000oc^O0?lkW`000olkW`000ol0003o?J00ocfP0002ocfP0004o`000?lo
X@3o?j40ocnQ00?o00001?oNO@000ol0003ogWd0omim0003omim0003o`000?oNO@3ogWd000?ogWd0
00?o0000omim0?oNO@001?oNO@04o`000003omim0?l0003ogWd000CogWd000?o0000omil0?oNO000
0ooNO003o`0000Golc4000?o0000oo<a0?oc<@001?oc<@000ol0003olc40oo<a0003oo<a00?o0000
1_oh80000ol0003on1l0ooPO0004ooPO00?o00001Ooi7@000ol0003onA`0ooTL0004ooTL00?o0000
1_oi70000ol0003onA/0ooTK0002ooTK00Go00001_oi6P000ol0003onAT0ooTI0003o`000003ooTI
0?l0003onQP000KonQP000?o0000ooXH0?oj60000ol00002ooXH0003o`000?oh8@3on24000Gon240
0_l00004onUI0003o`000?oYF@3ojET000;ojET000?o0000onUI0?oYF@000_l00002oiBi0007o`00
0?nD^@3oU;T0oiBi0?l0003oTkT0o`000003oi>i0006o`000?nC^@3oTkT0o`000?nD^@3o00004?oo
ool00ol0003oooooooooo`0>ooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0002ooooo`?o00001Oooool00ol0003oooooooooo`06ooooo`05o`000?l0R@3o08T0o`290?l00000
1?l[VP000ol0003o=Yh0ocJN0002ocJN0003o`000?liW`3o>Il000;o>Il000?o0000oc^O0?lkW`00
0olkW`000ol0003o?J00ocfP0002ocfP00Co000000?ogWd0o`000?oNO@001OoNO@000ol0003ogWd0
omim0002omim0003o`000?oNO@3ogWd000?ogWd000?o0000omim0?oNO@000_oNO@03o`0000CogWd0
00?o0000omim0?oNO@001?oNO@000ol0003ogW`0o`000002o`000003oo<a0?l0003olc4000Golc40
00?o0000oo<a0?oc<@001?oc<@000ol0003olc40oo<a0003o`0000;on20000?o0000ooPP0?oh8000
1Ooh80000ol0003on1l0ooPO0003o`000003ooPN0?l0003onAd000KonAd000?o0000ooTL0?oi7000
0ol00002ooTM0003o`000?oi703onA`000ConA`01Ol00004ooTK0003o`000?oi6P3onAX000ConAX0
0ol00005ooTI0003o`000?oj603onQP000ConQP00ol00006ooXH0003o`000?oh8@3on24000;on240
0_l00002ooLQ0004o`000?oYF@3ojET0o`0000CojET000?o0000onUI0?oYF@000_oYF@001?l0003o
U;T0oiBi0?l00002oiBi0004o`000?nC^@3oTkT0o`0000?oTkT000?o0000oi>i0?l000000onD^@00
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00001Ooooooo0000oooooooooooo
000000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01_ooool01Ol0003o08T0o`290?l0R@3o000000Co:iX000?o0000ocJN0?lf
WP000_lfWP000ol0003o>Il0ocVO0002ocVO0003o`000?lkW`3o>il000?o>il000Co0000ocfP0?lm
X03o?J000_l00004omim0003o`000?oNO@3ogWd000CogWd000?o0000omim0?oNO@000_oNO@000ol0
003ogWd0omim0004omim00Co00000_oNO@000ol0003ogWd0omim0002omim0003o`000?oNO@3ogWd0
00?ogWd00ol00005oo<a0003o`000?oc<@3olc4000Colc4000?o0000oo<a0?oc<@000ooc<@03o`00
00Kon20000?o0000ooPP0?oh80001?oh8003o`0000Gon1h000?o0000ooTM0?oi7@001?oi7@03o`00
00KonAd000?o0000ooTL0?oi70000ol00002ooTL0003o`000?oi6`3onA/000GonA/000?o0000ooTJ
0?oi6P000ol000000ooi6P3o0000ooTI0006ooTI0003o`000?oj603onQP000?o000000?onQP0o`00
0?oj60001ooj60001?l0003on240o`000?l00005ooLQ0003o`000?oYF@3o000000CojET000?o0000
onUI0?oYF@000_oYF@02o`000005oiBi0?l0003oU;T0oiBi0?l000000_nC^@001ol0003oTkT0oi>i
0?nC^@3o0000oi>i0?l000000onD^@000ol0003oooooooooo`0>ooooo`;o00003_ooool00005oooo
ool0003oooooooooool000002Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooo
o`;o00002?ooool01Ol0003o08T0o`290?l0R@3o000000Co:iX000?o0000ocJN0?lfWP000_lfWP00
0ol0003o>Il0ocVO0002ocVO0003o`000?lkW`3o>il000?o>il01?l000000ooNOP3o0000omim0004
omim0003o`000?oNO@3ogWd000?ogWd000?o0000omim0?oNO@000_oNO@000ol0003ogWd0omim0002
omim00?o00001OoNO@000ol0003ogWd0omim0003omim0003o`000?oNO@3o000000;o000000?olc40
o`000?oc<@001Ooc<@000ol0003olc40oo<a0004oo<a0003o`000?oc<@3olc4000?o00000_oh8000
0ol0003on200ooPP0005ooPP0003o`000?oh803on20000?o000000?on1h0o`000?oh7P001_oh7P00
0ol0003onAd0ooTM0003o`0000;on1d000?o0000ooTM0?oi7@001?oi7@03o`0000KonA`000?o0000
ooTK0?oi6`001?oi6`03o`0000GonAX000?o0000ooTI0?oi6@001?oi6@03o`0000GonQP000?o0000
ooXH0?oj60001?oj6003o`0000Oomb400_l00004onUI0003o`000?oYF@3ojET000;ojET000?o0000
onUI0?l000000_l00002oiBi0004o`000?nC^@3oTkT0o`0000;oTkT000Co0000oi>i0?nC^@3o0000
0onD^@02o`0000oooooo0_l0000>ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000009ooooo`;o00000_l0R@000ol0003o
:iX0ob^J0002ob^J0003o`000?lfWP3o=Yh000;o=Yh000?o0000ocVO0?liW`000_liW`000ol0003o
>il0oc^O0002oc^O00;o00001?oNOP000ol0003ogWd0omim0003omim0003o`000?oNO@3ogWd000?o
gWd000?o0000omim0?oNO@000ooNO@04o`0000;ogWd000?o0000omim0?oNO@000ooNO@000ol0003o
gWd0omim0002omim00?o00001Ooc<@000ol0003olc40oo<a0004oo<a0003o`000?oc<@3olc4000?o
lc400ol00006ooPP0003o`000?oh803on20000Con2000ol00005ooPN0003o`000?oh7P3on1h000Co
n1h00ol00006ooPM0003o`000?oi7@3onAd000?o000000?onAd0o`000?oi70001ooi70000ol0003o
nA/0ooTK0003o`000003ooTK0?l0003onAX000KonAX000?o0000ooTI0?oi6@000ol000000ooi6P3o
0000ooXH0006ooXH0003o`000?oj603onQP000?o00000_oj60000ol0003omb40ooLQ0002ooLQ00?o
000000?omb80o`000?oYF@000_oYF@000ol0003ojET0onUI0002onUI0003o`000?oYF@3ojET000;o
00000onD^@001?l0003oTkT0oi>i0?l00002oi>i0004o`000?nC^@3oTkT0o`0000?oU;T000?o0000
oiBi0?l000004?ooool00ol0003oooooooooo`0;ooooo`0000Goooooo`000?ooooooooooo`000007
ooooo`06o`000?ooooooooooooooool0003ooooo1?l00004ooooo`03o`000?oooooooooo00Oooooo
0_l00002o`290003o`000?l[VP3o:iX000;o:iX000?o0000ocJN0?lfWP000_lfWP000ol0003o>Il0
ocVO0002ocVO0003o`000?lkW`3o000000;o000000?ogWh0o`000?oNOP001?oNOP000ol0003ogWd0
omim0002omim0003o`000?oNO@3ogWd000?ogWd000Co0000omim0?oNO@3ogWd00ol00005omim0003
o`000?oNO@3ogWd000CogWd01?l000000ooc<@3o0000oo<a0006oo<a0003o`000?oc<@3olc4000?o
lc4000?o0000oo<a0?oc<@000ol00002ooPP0003o`000?oh803on20000Gon20000?o0000ooPP0?oh
80000ol000000ooh7P3o0000ooPN0006ooPN0003o`000?oh7P3on1h000?o00000_oh7P000ol0003o
n1d0ooPM0004ooPM00?o00001Ooi7@000ol0003onA`0ooTL0004ooTL00Co00001Ooi6`000ol0003o
nAX0ooTJ0004ooTJ00?o00001Ooi6P000ol0003onQP0ooXH0004ooXH00?o00001_oj60001?l0003o
mb40o`000?l00005ooLR0004o`000?oYF@3ojET0o`0000CojET000Co0000onUI0?oYF@3ojET00_l0
0002oiBi0003o`000?nC^@3o000000?oTkT000Co0000oi>i0?nC^@3o00000_nD^@001?l0003oU;T0
oiBi0?l0000@ooooo`03o`000?oooooooooo00_ooooo00001Ooooooo0000oooooooooooo000000Oo
oooo00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo0_l00009ooooo`;o000000?o08T0
o`000?l[VP000ol[VP000ol0003o=Yh0ocJN0002ocJN0003o`000?liW`3o>Il000Co00001?oNOP00
0ol0003ogWh0omin0003omin0003o`000?oNO@3ogWd000;ogWd000?o0000omim0?oNO@001?oNO@03
o`0000;ogWd000?o0000omim0?oNO@000ooNO@000ol0003ogWd0omim0003omim00;o00001Ooc<@00
0ol0003olc40oo<a0004oo<a0003o`000?oc<@3olc4000?olc400ol00006ooPP0003o`000?oh803o
n20000Con2000ol00005ooPN0003o`000?oh7P3on1h000Con1h00ol00006ooPN0003o`000?oh7@3o
n1d000?o000000?on1d0o`000?oi7@001_oi7@000ol0003onA`0ooTL0003o`0000;onA`000?o0000
ooTK0?oi6`001Ooi6`000ol0003onAX0ooTJ0003o`000003ooTK0?l0003onAX000KonAX000?o0000
ooXH0?oj60000ol00002ooXI0003o`000?oj603onQP000ConQP00_l00007ooLR0003o`000?oYF@3o
000000CojET000?o0000onUI0?oYF@000_oYF@04o`0000;oTkT000Oo0000oi>i0?nC^@3oTkT0o`00
0?nC^@3o000000?oU;T000?o0000oiBi0?nD^@000_l0000@ooooo`03o`000?oooooooooo00[ooooo
0002ooooo`;o00002Oooool3o`0000;ooooo1Ol00003ooooo`03o`000?oooooooooo00Sooooo00Co
0000olG20?l0003o00001?l[VP001?l0003o=Yh0ocJN0?lfWP04o`0000;ogWh000?o0000omin0?oN
OP000ooNOP000ol0003ogWh0omin0003omin0003o`000?oNO@3ogWd000;ogWd000Co0000omim0?oN
O@3ogWd01?l00004omim0003o`000?oNO@3ogWd000CogWd000?o0000omim0?l000000_l000000ood
<03o0000oo<a0005oo<a0003o`000?oc<@3olc4000Colc4000?o0000oo<a0?l000000_l00002ooPP
0003o`000?oh803on20000Gon20000?o0000ooPP0?oh80000ol000000ooh7P3o0000ooPN0006ooPN
0003o`000?oh7P3on1h000?o00000_oh7P000ol0003on1h0ooPN0004ooPN00?o00001Ooh7@000ol0
003onAd0ooTM0004ooTM00?o00001_oi70000ol0003onA/0ooTK0004ooTK00?o00001Ooi6`000ol0
003onAX0ooTJ0004ooTJ00?o00001_oj6@000ol0003onQP0ooXH0003o`000003ooXH0?l0003omb80
00Komb800_l00004onUI0003o`000?oYF@3ojET000;ojET000?o0000onUI0?oYF@000_l00002oi>i
0007o`000?nC^@3oTkT0oi>i0?l0003oTkT0o`000003oiBi0006o`000?nD^@3oU;T0o`000?nD^@3o
00004?ooool00ol0003oooooooooo`09ooooo`006_ooool00ol0003oooooooooo`08ooooo`04o`00
0?o5`P3o0000o`0000Co:iX01?l000000ooMP03o0000omin0003omin0003o`000?oNOP3ogWh000Co
gWh000?o0000omin0?oNOP000_oNOP000ol0003ogWd0omim0003omim00?o00000ooNO@000ol0003o
gWd0omim0002omim0003o`000?oNO@3ogWd000?ogWd00ol00005oo@`0003o`000?oc<@3olc4000?o
lc4000?o0000oo<a0?oc<@001?oc<@02o`0000Kon20000?o0000ooPP0?oh80001?oh8003o`0000Go
n1h000?o0000ooPN0?oh7P001?oh7P03o`0000Kon1h000?o0000ooPN0?oh7P000ol000000ooh7P3o
0000ooPM0006ooPM0003o`000?oi7@3onAd000?o00000_oi7@000ol0003onA`0ooTL0005ooTL0003
o`000?oi6`3onA/000?o00000_oi70000ol0003onA/0ooTK0004ooTK0003o`000?oi6P3onAX000?o
00000_oi6P000ol0003onQT0ooXI0004ooXI00?o00001Ooj60000ol0003omb80ooLR0002ooLR00;o
00000_og8P001Ol0003ojET0onUI0?oYF@3o000000CojET000Go0000onUI0?oYF@3ojET0o`000002
oi>i0004o`000?nC^@3oTkT0o`0000;oTkT000Oo0000oiBi0?nD^@3oU;T0o`000?nD^@3o000000;o
U;T000?o0000ooooooooool03_ooool2o`0000[ooooo000Iooooo`;o00002_ooool00ol0003oaL80
olG20006o`0000CogH0000?o0000omin0?oNOP000ooNOP000ol0003ogWh0omin0003omin0003o`00
0?oNOP3ogWh000;ogWh000Co0000omim0?oNO@3ogWd00ol00005omim0003o`000?oNO@3ogWd000?o
gWd000?o0000omim0?l000000_l000000ood<03o0000oo@`0005oo@`0003o`000?oc<@3olc4000Co
lc4000?o0000oo<a0?oc<@000ol000000ooh803o0000ooPP0006ooPP0003o`000?oh803on20000?o
00000_oh7P000ol0003on1h0ooPN0004ooPN0003o`000?oh7P3on1h000?o00000_oh7P000ol0003o
n1h0ooPN0004ooPN00?o00001Ooh7P000ol0003on1d0ooPM0004ooPM00?o00001_oi7@000ol0003o
nA`0ooTL0004ooTL00?o00001_oi70001?l0003onA/0ooTK0?oi6`05o`0000KonAX000?o0000ooXI
0?oj6@000ol000000ooj6@3o0000ooXH0006ooXH0004o`000?og8P3o0000o`0000Gomb8000?o0000
onUI0?l000001?oYF@000ol0003ojET0onUI0002onUI00;o000000GoTkT0o`000?nC^@3oTkT0o`00
0002oi>i0007o`000?nD^@3oU;T0oiBi0?l0003oU;T0o`000002oiBi00;o00004?ooool00ol0003o
ooooooooo`08ooooo`006Oooool00ol0003oooooooooo`09ooooo`04o`000?o5`P3oaL80o`0000Co
fHd000?o0000omf00?oMP0000_oMP0000ol0003ogWh0omin0003omin0003o`000?oNOP3ogWh000?o
gWh000?o0000omin0?oNOP000ooNOP03o`0000;ogWd000?o0000omim0?oNO@000ooNO@000ol0003o
gWd0omim0002omim00?o00001Ood<0000ol0003om300oo@`0004oo@`0003o`000?oc<@3olc4000?o
lc400ol00005ooPP0003o`000?oh803on20000Con2000ol00006ooPN0004o`000?oh7P3on1h0ooPN
00Go00001_oh7P000ol0003on1h0ooPN0003o`0000;on1h000?o0000ooPN0?oh7P001?oh7P000ol0
003on1d0ooPM0003o`0000;on1d000?o0000ooTM0?oi7@001Ooi7@000ol0003onA`0ooTL0003o`00
00;onA`000?o0000ooTL0?oi70001?oi7004o`0000ConA/000?o0000ooTJ0?oi6P001?oi6P03o`00
00GonQT000?o0000ooXH0?oj60001?oj6002o`0000Oomb800_l00004onUI0003o`000?oYF@3ojET0
00;ojET000Co0000onUI0?l0003o00000onC^@001?l0003oTkT0oi>i0?l00002oiBi0004o`000?nD
^@3oU;T0o`0000;oU;T000?o0000oiBi0?l000003_ooool3o`0000Wooooo000Iooooo`03o`000?oo
oooooooo00Wooooo00Co0000olG20?o5`P3o00001?oIS@000ol0003ogH00omf00003omf00003o`00
0?oNOP3ogWh000;ogWh000?o0000omin0?oNOP000ooNOP000ol0003ogWh0omin0004o`0000CogWd0
00?o0000omim0?oNO@001?oNO@04o`000003oo@`0?l0003om30000Gom30000?o0000oo@`0?od<000
1?od<0000ol0003olc40oo<a0003o`000003ooPP0?l0003on20000Kon20000?o0000ooPP0?oh8000
0ol00002ooPN0003o`000?oh7P3on1h000Con1h01?l00005ooPN0003o`000?oh7P3on1h000?on1h0
0ol00006ooPN0003o`000?oh7P3on1h000?on1h00ol00006ooPM0003o`000?oi7@3onAd000ConAd0
0ol00006ooTL0003o`000?oi703onA`000?o000000?onA`0o`000?oi6`001_oi6`000ol0003onAX0
ooTJ0003o`000003ooTJ0?l0003onQT000KonQT000?o0000ooXH0?oj60000ol000000ooj603o0000
ooLR0005ooLR0003o`000?og8P3o000000CojET000Go0000onUI0?oYF@3ojET0o`000002onUI00;o
00000onC^@001?l0003oTkT0oi>i0?l00002oiBi0004o`000?nD^@3oU;T0o`0000;oU;T000Co0000
oiBi0?nD^@3o00002_ooool3o`0000;ooooo00?o0000ooooooooool01oooool001Wooooo0_l0000:
ooooo`04o`000?o5`P3oaL80o`0000CofHd000?o0000omf00?oMP0000ooMP0000ol0003ogWh0omin
0002omin0003o`000?oNOP3ogWh000?ogWh00ol00003omin0003o`000?oNO@3ogWd000;ogWd000?o
0000omim0?oNO@000ooNO@02o`0000Gom30000?o0000oo@`0?od<0001?od<0000ol0003om300oo@`
0003oo@`00?o00001Ooh80000ol0003on200ooPP0004ooPP00?o00001_oh7P000ol0003on1h0ooPN
0003o`0000;on1h000?o0000ooPN0?oh7P001Ooh7P000ol0003on1h0o`000002o`0000;on1h000?o
0000ooPN0?oh7P001Ooh7P000ol0003on1h0o`000002o`0000?on1h000?o0000ooPM0?oh7@001?oh
7@000ol0003onAd0ooTM0003o`0000;onAd000?o0000ooTL0?oi70001?oi7003o`0000GonA`000?o
0000ooTK0?oi6`001?oi6`03o`0000GonAX000?o0000ooXI0?oj6@001?oj6@03o`0000GonQP000Co
0000ooLR0?og8P3omb800_l00003ooLR0004o`000?oYF@3ojET0o`0000CojET000Co0000onUI0?oY
F@3ojET00_l00002oi>i0003o`000?nC^@3o000000?oU;T000Ko0000oiBi0?nD^@3o0000oiBi0?l0
0003oiBi0003o`000?oooooooooo00Gooooo0ol00005ooooo`03o`000?oooooooooo00Oooooo000I
ooooo`03o`000?oooooooooo00[ooooo00Co0000olG20?o5`P3o00001?oIS@000ol0003ogH00omf0
0002omf00003o`000?oNOP3ogWh000?ogWh000?o0000omin0?l000000ol00005omin0003o`000?oN
O@3ogWd000?ogWd000?o0000omim0?l000000_l000000ood;`3o0000oo@`0005oo@`0003o`000?od
<03om30000?om30000?o0000oo@`0?od<0000ol00002ooPO0003o`000?oh803on20000Con20000?o
0000ooPP0?oh80000ol00003ooPN0003o`000?oh7P3on1h000?on1h00ol00006ooPN0003o`000?oh
7P3on1h000Con1h00_l00006ooPN0003o`000?oh7P3on1h000Con1h00_l00007ooPN0004o`000?oh
7@3on1d0ooPM00Go00001_oi7@000ol0003onA`0ooTL0003o`000003ooTL0?l0003onA`000KonA`0
00?o0000ooTK0?oi6`000ol000000ooi6`3o0000ooTJ0006ooTJ0003o`000?oj6@3onQT000?o0000
00?onQT0o`000?oj60001_oj60000ol0003omb80o`000006ooLR0003o`000?oYF@3o000000?ojET0
00?o0000onUI0?oYF@000_oYF@04o`0000;oTkT000Oo0000oiBi0?nD^@3oU;T0o`000?nD^@3o0000
00;oU;T000Co0000oiBi0?nD^@3oU;T00_l00002ooooo`Co00002?ooool00ol0003oooooooooo`07
ooooo`006Oooool00ol0003oooooooooo`0:ooooo`04o`000?o5`P3oaL80o`0000CofHd000?o0000
omf00?oMP0000_oMP0000ol0003ogWh0omin0002omin00?o00000ooNOP000ol0003ogWh0omin0003
omin0003o`000?oNO@3ogWd000;ogWd00ol00005oo@_0003o`000?od<03om30000?om30000?o0000
oo@`0?od<0000ood<003o`0000Kon1l000?o0000ooPP0?oh80000ooh8003o`0000Oon1h000?o0000
ooPN0?l000000_l00002ooPN0003o`000?oh7P3on1h000Gon1h000?o0000ooPN0?oh7P000ol00000
0ooh7`3o0000ooPN0006ooPN0003o`000?oh7P3on1h000?o00000_oh7P000ol0003on1h0ooPN0004
ooPN00Co00001?oh7P000ol0003onAd0ooTM0004ooTM00?o00001Ooi70000ol0003onA`0ooTL0004
ooTL00?o00001Ooi6`000ol0003onAX0ooTJ0004ooTJ00?o00001Ooj6@000ol0003onQP0ooXH0004
ooXH00;o00001oog8P02o`0000?ojET000?o0000onUI0?oYF@000_oYF@000ol0003ojET0onUI0002
o`0000;oTkT000Oo0000oiBi0?nD^@3oU;T0o`000?nD^@3o000000;oU;T000Ko0000oiBi0?nD^@3o
U;T0o`000?nD^@02o`0000gooooo00?o0000ooooooooool01_ooool001Sooooo0ol0000;ooooo`04
o`000?o5`P3oaL80o`0000CofHd000?o0000omf00?oMP0000_oMP0000ol0003ogWh0o`000002o`00
0003omin0?l0003ogWh000CogWh000?o0000omin0?oNOP000ooNOP04o`000003oo@_0?l0003om2l0
00Gom2l000?o0000oo@`0?od<0001?od<0000ol0003om300o`000002o`0000;on1l000?o0000ooPO
0?oh7`001Ooh7`000ol0003on200o`000002o`0000?on1h000?o0000ooPN0?oh7P001?oh7P02o`00
00Kon1h000?o0000ooPN0?oh7P001?oh7P03o`0000Gon1l000?o0000ooPN0?oh7P001?oh7P03o`00
00Kon1h000?o0000ooPN0?oh7P000ol000000ooh7P3o0000ooPN0006ooPN0003o`000?oi7@3onAd0
00?o000000?on1d0o`000?oi70001_oi70000ol0003onA`0ooTL0003o`000003ooTL0?l0003onA/0
00KonA/000?o0000ooTJ0?oi6P000ol00002ooTJ0003o`000?oj6@3onQT000ConQT000?o0000ooXH
0?oj60000ol00002ooXI0003o`000?og8P3omb8000;omb800_l000000oog8P3o0000onUI0002onUI
0003o`000?oYF@3ojET000;ojET000Go0000onUI0?oYF@3ojET0o`000002oi>i0004o`000?nD^@3o
U;T0o`0000;oU;T000Co0000oiBi0?nD^@3o00000_nD^@001?l0003oU;T0oiBi0?l0000>ooooo`03
o`000?oooooooooo00Kooooo0005ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1_ooool00ol0003oooooooooo`0:ooooo`04o`000?o5`P3oaL80o`0000CofHd000Co0000omf00?oM
P03ogH000ol00004omin0003o`000?oNOP3ogWh000?ogWh000?o0000omin0?oNOP000_oNOP02o`00
00Gom2l000?o0000oo@_0?od;`001?od;`000ol0003om300oo@`0003oo@`00?o00001Ooh7`000ol0
003on1l0ooPO0004ooPO00;o00001ooh7P000ol0003on1h0ooPN0003o`000003ooPN0?l0003on1h0
00Kon1h000?o0000ooPN0?oh7P000ol00002ooPO0003o`000?oh7`3on1l000Con1l000?o0000ooPN
0?oh7P000ol00002ooPO0003o`000?oh7P3on1h000Con1h00ol00005ooPN0003o`000?oh7P3on1h0
00Con1h00ol00005ooPM0003o`000?oi703onA`000ConA`00ol00005ooTL0003o`000?oi6`3onA/0
00ConA/00ol00006ooTJ0004o`000?oj6@3onQT0ooXI00Go00001_oj6@001?l0003omb80o`000?l0
0004ooLR0003o`000?oYF@3o000000CojET000?o0000onUI0?oYF@000_oYF@02o`000005oi>i0?l0
003oU;T0oiBi0?l000000_nD^@001?l0003oU;T0oiBi0?l00002oiBi0003o`000?nD^@3oU;T000;o
00003Oooool00ol0003oooooooooo`06ooooo`001?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0<ooooo`03o`000?o5`P3o0000
00CofHd000Ko0000omf00?l0003o0000omf00?l00005omin0003o`000?oNOP3ogWh000?ogWh000?o
0000omin0?l000000_l000000ood;P3o0000oo@_0005oo@_0003o`000?od;`3om2l000?om2l000?o
0000oo@`0?od<0000ol00003ooPN0003o`000?oh7`3on1l000?on1l000?o0000ooPO0?oh7`000ol0
0002ooPM0003o`000?oh7P3on1h000Con1h00ol00005ooPN0003o`000?oh7P3on1h000Con1h00ol0
0006ooPO0004o`000?oh7`3on1l0ooPO00Go00001_oh7`000ol0003on1h0ooPN0003o`000003ooPN
0?l0003on1h000Kon1h000?o0000ooPN0?oh7P000ol000000ooh7P3o0000ooPM0006ooPM0003o`00
0?oi703onA`000?o00000_oi7@000ol0003onA`0ooTL0004ooTL0003o`000?oi6`3onA/000?o0000
0_oi6`000ol0003onAX0ooTJ0004ooTJ00Co00001?oj6@000ol0003onQT0ooXI0004ooXI00;o0000
1_og8P02o`0000CojET000?o0000onUI0?oYF@000_oYF@001?l0003ojET0o`000?l00003oiBi0004
o`000?nD^@3oU;T0o`0000;oU;T000Co0000oiBi0?nD^@3o00000_nD^@000ol0003oU;T0o`00000<
ooooo`03o`000?oooooooooo00Kooooo0004ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool00_ooool2o`0000gooooo00?o0000olG20?l000000ooIS@03o`0000CogH0000?o0000
omin0?oNOP000ooNOP000ol0003ogWh0omin0004o`0000Gom2h000?o0000oo@_0?od;`000ood;`00
0ol0003om2l0oo@_0003oo@_00?o00001ooh7P001?l0003on1l0ooPO0?oh7`04o`0000Kon1d000?o
0000ooPN0?oh7P000ol00002ooPN0003o`000?oh7P3on1h000Con1h000?o0000ooPN0?oh7P000ol0
0002ooPO0003o`000?oh7`3on1l000Con1l01?l00004ooPO0003o`000?oh7`3on1l000Con1l00ol0
0005ooPN0003o`000?oh7P3on1h000Con1h00ol00005ooPN0003o`000?oh7@3on1d000Con1d00ol0
0006ooTM0004o`000?oi703onA`0ooTL00Go00001_oi6`000ol0003onAX0ooTJ0003o`000003ooTJ
0?l0003onQT000KonQT000?o0000ooXI0?oj6@000ol000000ooj6@3o0000ooLR0004ooLR0003o`00
0?og8P3o000000CojET000Go0000onUI0?oYF@3ojET0o`000002onUI00?o00000_nD^@000ol0003o
U;T0o`000003oiBi0006o`000?nD^@3oU;T0o`000?nD^@3o00000_nD^@000ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Kooooo0004ooooo`04o`000?ooooooooooo`0000Wooooo0_l00005
ooooo`03o`000?oooooooooo00gooooo1Ol000000ooIS@3o0000omf00004omf00003o`000?oNOP3o
gWh000;ogWh01?l00002oo@]0003o`000?od;P3om2h000Gom2h000?o0000oo@_0?od;`000ood;`00
0ol0003om2l0o`000002o`0000?on1d000?o0000ooPN0?oh7P001?oh7P04o`0000ConAd000?o0000
ooPM0?oh7@000ooh7@03o`0000Kon1h000?o0000ooPN0?oh7P000ooh7P03o`0000Kon1l000?o0000
ooPO0?oh7`000ol000000ooh7`3o0000ooPO0006ooPO0003o`000?oh7`3on1l000?o000000?on1l0
o`000?oh7P001_oh7P000ol0003on1h0ooPN0003o`0000;on1h000?o0000ooPN0?oh7P001?oh7P00
0ol0003on1d0ooPM0003o`0000;on1d000?o0000ooTM0?oi7@001?oi7@04o`0000ConA`000?o0000
ooTK0?oi6`001?oi6`03o`0000GonAX000?o0000ooXI0?oj6@000ooj6@04o`0000GonQT000?o0000
ooLR0?og8P000_l00003ooLR0004o`000?oYF@3ojET0o`0000CojET000Co0000onUI0?oYF@3ojET0
0_l00002oiBi0003o`000?nD^@3o000000;oU;T000Oo0000oiBi0?nD^@3oU;T0o`000?nD^@3o0000
00;oU;T00_l0000;ooooo`03o`000?oooooooooo00Kooooo0004ooooo`04o`000?ooooooooooo`00
00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`Co00001?oIS@000ol0
003ogH00omf00002omf00003o`000?oNOP3o000000;o000000?omBd0o`000?od;@001?od;@000ol0
003om2h0oo@^0004oo@^0004o`000?od;`3om2l0oo@_00Co00001ooh7@000ol0003on1h0ooPN0003
o`000003ooTL0?l0003onAd000KonAd000?o0000ooPM0?l000000_l00003ooPM0003o`000?oh7P3o
n1h000Con1h000?o0000ooPN0?l000000_l00003ooPN0003o`000?oh7`3on1l000?on1l00ol00005
ooPO0003o`000?oh7`3on1l000Con1l00ol00005ooPO0003o`000?oh7P3on1h000Con1h00ol00006
ooPN0004o`000?oh7P3on1h0ooPN00Go00001_oh7@000ol0003onAd0ooTM0003o`000003ooTM0?l0
003onA`000KonA`000?o0000ooTK0?oi6`000ol000000ooi6`3o0000ooTJ0005ooTJ0003o`000?oj
6@3onQT000?o00000_oj6@000ol0003onQT0ooXI0004ooXI0003o`000?og8P3o000000Komb8000?o
0000onUI0?l000000ooYF@000ol0003ojET0onUI0002onUI00Co00000_nD^@001?l0003oU;T0oiBi
0?l00002oiBi0004o`000?nD^@3oU;T0o`0000;oU;T000?o0000oiFi0?l000002_ooool00ol0003o
ooooooooo`06ooooo`001?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`09ooooo`?o00000_ooool2o`0000CofHd000Co0000omf0
0?oMP03ogH000ol00005ooD]0003o`000?od;@3om2d000?om2d000?o0000oo@^0?od;P000ood;P04
o`0000ConAd000?o0000ooPM0?oh7@001?oh7@03o`0000GonA`000?o0000ooTM0?oi7@001?oi7@02
o`0000Oon1d000Co0000ooPN0?oh7P3on1h01?l00007ooPN0003o`000?oh7`3o000000;o00000_oh
7`000ol0003on1l0ooPO0004ooPO0003o`000?oh7`3on1l000?o00000_oh7`000ol0003on1l0ooPO
0004ooPO0003o`000?oh7P3on1h000?o00000_oh7`000ol0003on1h0ooPN0004ooPN00Co00001?oh
7P000ol0003on1d0ooPM0004ooPM00?o00001Ooi7@000ol0003onA`0ooTL0004ooTL00?o00001Ooi
6`000ol0003onAX0ooTJ0003ooTJ00?o00001_oj6@001?l0003onQT0ooXI0?oj6@04o`0000Oomb80
0_l00003onUI0003o`000?oYF@3ojET000;ojET000?o0000onUI0?oYF@000_l00002oiBi0004o`00
0?nD^@3oU;T0o`0000;oU;T000Ko0000oiBi0?nD^@3o0000oiBi0?l00002oiFi0003o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01Oooool000Gooooo0_l00009ooooo`?o00001?ooool2o`00
00Sooooo0ol00005ooooo`;o00001?oIS@04o`000003oo@^0?l0003omBd000GomBd000?o0000oo@]
0?od;@001?od;@000ol0003om2h0o`000002o`0000;onA`000?o0000ooTM0?oi7@001?oi7@000ol0
003on1d0ooPM0003o`0000;onA`000?o0000ooTL0?oi70001?oi70000ol0003onAd0ooTM0003o`00
00;onAd000?o0000ooPM0?oh7@001?oh7@04o`0000Con1h000?o0000ooPN0?oh7P001?oh7P02o`00
00Kon1l000?o0000ooPO0?oh7`000ooh7`03o`0000Kon1l000Co0000ooPO0?oh7`3on1l01Ol00006
ooPO0003o`000?oh7P3on1h000?o000000?on1h0o`000?oh7P001_oh7P000ol0003on1d0ooPM0003
o`000003ooPM0?l0003onAd000KonAd000?o0000ooTL0?oi70000ol000000ooi703o0000ooTK0005
ooTK0003o`000?oi6P3onAX000?o00000_oi6P000ol0003onQT0ooXI0004ooXI00Co00001?oj6@00
0ol0003omb80ooLR0002ooLR00;o000000?omb80o`000?oYF@000_oYF@000ol0003ojET0onUI0002
onUI0004o`000?oYF@3ojET0onUI00;o000000GoU;T0o`000?nD^@3oU;T0o`000002oiBi0006o`00
0?nD^@3oU;T0o`000?nD^@3o00000_nE^@02o`0000[ooooo00?o0000ooooooooool01Oooool001So
oooo00?o0000ooooooooool00oooool3o`0000Wooooo1_l00005oo@^0003o`000?oe;@3omBd000Co
mBd000?o0000oo@]0?od;@000ood;@02o`0000KonA`000?o0000ooTM0?oi7@000ooi7@03o`0000Ko
nA`000?o0000ooTL0?oi70000ooi7003o`0000KonAd000?o0000ooPM0?oh7@000ol000000ooh7P3o
0000ooPN0006ooPN0003o`000?oh7P3on1h000?o000000?on1h0o`000?oh7`001_oh7`000ol0003o
n1l0o`000002o`0000?on1l000?o0000ooPO0?oh7`000ooh7`04o`0000Con1l000?o0000ooPO0?oh
7`001?oh7`03o`0000Gon1h000?o0000ooPN0?oh7P001?oh7P03o`0000Gon1d000?o0000ooTM0?oi
7@001?oi7@03o`0000GonA`000Co0000ooTK0?oi6`3onA/01Ol00006ooTJ0003o`000?oj6@3onQT0
00?o000000?onQT0o`000?oj6@001_oj6@001?l0003omb80o`000?l00004ooLR0003o`000?oYF@3o
000000CojET000?o0000onUI0?oYF@000_oYF@03o`0000?oU;T000Ko0000oiBi0?nD^@3o0000oiBi
0?l00002oiBi0006o`000?nE^@3oUKT0o`000?nE^@3o00002Oooool00ol0003oooooooooo`05oooo
o`005oooool2o`0000;ooooo0ol0000<ooooo`03o`000?o`?@3ol3d000;ol3d000?o0000oo@^0?od
;P001?od;P000ol0003omBd0ooD]0003ooD]0003o`000?od;@3om2d000?o00000_oi6`000ol0003o
nA`0ooTL0004ooTL0003o`000?oi7@3o000000;o00000_oi6`000ol0003onA`0ooTL0005ooTL0003
o`000?oi703o000000;o00000ooi70000ol0003onAd0ooTM0003ooTM00?o00001Ooh7P000ol0003o
n1h0ooPN0004ooPN00?o00001Ooh7P000ol0003on1l0ooPO0004ooPO00;o00001ooh7`000ol0003o
n1l0o`000002o`0000;on1l000?o0000ooPO0?oh7`001?oh7`000ol0003on1l0ooPO0003o`0000;o
n1l000?o0000ooPN0?oh7P001?oh7P000ol0003on1h0ooPN0003o`0000;on1h000?o0000ooPM0?oh
7@001?oh7@000ol0003onAd0ooTM0003o`0000;onAd000?o0000ooTL0?oi70000ooi7004o`0000Co
nA/000?o0000ooTJ0?oi6P001?oi6P03o`0000GonQT000?o0000ooXI0?oj6@001?oj6@02o`0000Ko
mb800_l00004onUI0003o`000?oYF@3ojET000;ojET000Co0000onUI0?l0003o00000onD^@001_l0
003oU;T0oiBi0?l0003oU;T0o`0000;oU;T000?o0000oiFi0?l000000_nE^@000ol0003ooooooooo
o`06ooooo`;o00001oooool001Oooooo1?l0000@ooooo`03o`000?o`?@3ol3d000;ol3d000?o0000
oo@^0?od;P000ood;P000ol0003omBd0ooD]0003ooD]00?o00001_oi6`000ol0003onA`0ooTL0003
ooTL00?o00001Ooi6`000ol0003onA`0ooTL0004ooTL00;o00001ooi70000ol0003onAd0o`000002
o`0000;on1d000?o0000ooPN0?oh7P001?oh7P000ol0003on1h0ooPN0003o`0000;on1h000?o0000
ooPN0?oh7P001?oh7P000ol0003on1l0ooPO0003o`0000;on1l000?o0000ooPO0?oh7`001?oh7`02
o`0000Kon1l000?o0000ooPO0?oh7`000ooh7`03o`0000Kon1l000Co0000ooPN0?oh7P3on1h01Ol0
0006ooPN0004o`000?oh7@3on1d0ooPM00Go00001_oi7@000ol0003onA`0o`000002o`000003ooTL
0?l0003onA/000KonA/000?o0000ooTJ0?oi6P000ol000000ooi6P3o0000ooXI0006ooXI0003o`00
0?oj6@3onQT000?o00000_oj6@001?l0003omb80ooLR0?og8P02o`000003ooLR0?l0003ojET000?o
jET000?o0000onUI0?oYF@000_oYF@000ol0003ojET0onUI0002o`0000;oU;T000?o0000oiBi0?l0
00000_nD^@001_l0003oU;T0oiBi0?l0003oUKT0o`0000;oUKT00_l00007ooooo`;o00001oooool0
01Oooooo0_l0000Cooooo`03o`000?o`?@3ol3d000;ol3d000?o0000oo@^0?od;P000ood;P000ol0
003omBd0o`000002o`0000;onAT000?o0000ooTK0?oi6`001Ooi6`000ol0003onA`0o`000002o`00
00?onAX000?o0000ooTK0?oi6`000ooi6`000ol0003onA`0ooTL0003o`0000;onA`000?o0000ooTL
0?oi70001?oi7002o`0000Kon1d000?o0000ooPN0?oh7P000ooh7P03o`0000Kon1h000Co0000ooPN
0?oh7P3on1h01Ol00006ooPO0003o`000?oh7`3on1l000?o000000?on1l0o`000?oh7`001_oh7`00
0ol0003on1l0o`000002o`0000;on1l000?o0000ooPO0?oh7`001?oh7`04o`0000Con1h000?o0000
ooPN0?oh7P001?oh7P04o`0000Con1d000?o0000ooTM0?oi7@001?oi7@02o`0000GonA`000?o0000
ooTK0?oi6`001?oi6`03o`0000GonAX000?o0000ooXI0?oj6@001?oj6@03o`0000KonQT000?o0000
ooLR0?l000001?og8P001?l0003ojET0onUI0?l00004onUI0004o`000?oYF@3ojET0onUI00;o0000
00GoU;T0o`000?nD^@3oU;T0o`000002oiBi0006o`000?nD^@3oU;T0o`000?nE^@3o00000_nE^@00
0ol0003oU[T0o`000006ooooo`;o00001oooool001Wooooo00?o0000ooooooooool04Oooool01Ol0
003ol3d0oo0m0?o`?@3o000000Gom2h00_l00006ooTI0003o`000?oi6`3onA/000ConA/00_l00007
ooTJ0004o`000?oi6`3onA/0ooTK00Co00001_oi70000ol0003onA`0ooTL0003o`000003ooTM0?l0
003on1d000Kon1d000?o0000ooPN0?l000000_l00003ooPN0003o`000?oh7P3on1h000?on1h01?l0
0004ooPO0003o`000?oh7`3on1l000Con1l00ol00005ooPO0003o`000?oh7`3on1l000Con1l00_l0
0006ooPO0003o`000?oh7`3on1l000?o000000?on1l0o`000?oh7P001_oh7P000ol0003on1h0ooPN
0003o`000003ooPN0?l0003on1d000Kon1d000?o0000ooTM0?oi7@000ol000000ooi7@3o0000ooTL
0005ooTL0003o`000?oi6`3onA/000?o00000_oi6`000ol0003onAX0ooTJ0004ooTJ0003o`000?oj
6@3onQT000?o00000_oj6@000ol0003onQT0ooXI0004ooXI00;o00001_og8P000ol0003ojET0o`00
0003onUI0006o`000?oYF@3ojET0onUI0?l0003ojET00ol00002oiBi0004o`000?nD^@3oU;T0o`00
00;oU;T000Go0000oiFi0?l0003oUKT0o`000002oiJi0003o`000?oooooooooo00?ooooo00?o0000
o`1n6?l000001oooool001[ooooo00?o0000ooooooooool04Oooool5o`000004oo@^0?l0003o0000
o`0000;onAX000?o0000ooTI0?oi6@001?oi6@000ol0003onA/0ooTK0003o`0000;onQT000?o0000
ooTJ0?oi6P001?oi6P04o`0000ConA/000?o0000ooTL0?oi70000ooi7003o`0000GonAd000?o0000
ooPM0?oh7@001?oh7@02o`0000Oon1h000?o0000ooPN0?l000000_l00002ooPN0003o`000?oh7`3o
n1l000Con1l000?o0000ooPO0?oh7`000ol00002ooPO0003o`000?oh7`3on1l000Con1l000?o0000
ooPO0?oh7`000ol00002ooPO0003o`000?oh7`3on1l000?on1l00ol00005ooPO0003o`000?oh7P3o
n1h000Con1h00ol00005ooPN0003o`000?oh7@3on1d000Con1d00ol00005ooTM0004o`000?oi703o
nA`0ooTL00Go00001_oi6`001?l0003onAX0ooTJ0?oi6P05o`0000KonQT000?o0000ooXI0?oj6@00
0ol000000ooj6@3o0000ooLR0005ooLR00;o00001?oYF@001Ol0003ojET0onUI0?oYF@3o000000;o
jET00_l00002oiBi0003o`000?nD^@3o000000;oU;T000Ko0000oiFi0?nE^@3o0000oiFi0?l00002
oiJi00;o00001?ooool01?l0003o07hHo`000?l00006ooooo`006oooool00ol0003oooooooooo`0A
ooooo`03o`000?oe:P3omBX000?o00001Ooi6P000ol0003onAT0ooTI0003ooTI00?o00001_oj6@00
0ol0003onAX0ooTJ0003o`000003ooTJ0?l0003onA/000KonA/000?o0000ooTL0?l000000_l00003
ooTL0003o`000?oi7@3onAd000?onAd000?o0000ooPM0?oh7@000ol00002ooPM0003o`000?oh7P3o
n1h000Con1h00_l00006ooPN0003o`000?oh7`3on1l000?on1l00ol00006ooPO0004o`000?oh7`3o
n1l0ooPO00Go00001_oh7`000ol0003on1l0o`000002o`0000;on1l000?o0000ooPO0?oh7`001?oh
7`000ol0003on1h0ooPN0003o`0000;on1h000?o0000ooPN0?oh7P001?oh7P000ol0003on1d0ooPM
0003o`0000;on1d000?o0000ooTM0?oi7@000ooi7@04o`0000ConA`000?o0000ooTK0?oi6`001?oi
6`04o`0000ConAX000?o0000ooXI0?oj6@001?oj6@03o`0000GonQT000Co0000ooLR0?og8P3omb80
0_l00002ooLR0004o`000?oYF@3ojET0o`0000?ojET000?o0000onUI0?oYF@000_oYF@02o`000004
oiBi0?l0003oU;T0o`0000;oU;T000Ko0000oiFi0?nE^@3o0000oiFi0?l00002oiJi0003o`000?nF
^@3o000000?ooooo00Co0000o`1n6?l0003o00001_ooool001cooooo0_l0000Booooo`03o`000?oe
:P3omBX000;omBX000?o0000ooTJ0?oi6P000ooi6P000ol0003onAT0o`000002o`0000?onQL000?o
0000ooXI0?oj6@000ooj6@03o`0000GonAX000?o0000ooTK0?oi6`001?oi6`02o`0000OonA`000Co
0000ooTM0?oi7@3onAd01?l00006ooPM0003o`000?oh7P3on1h000?o00000_oh7P000ol0003on1h0
ooPN0004ooPN0003o`000?oh7`3o000000;o00000ooh7`000ol0003on1l0ooPO0003ooPO00Co0000
1?oh7`000ol0003on1l0ooPO0004ooPO00;o00001_oh7`000ol0003on1l0ooPO0003ooPO00?o0000
1_oh7P001?l0003on1h0ooPN0?oh7P05o`0000Kon1d000?o0000ooTM0?l000000_l000000ooi7@3o
0000ooTL0006ooTL0003o`000?oi6`3onA/000?o000000?onA/0o`000?oi6P001_oi6P000ol0003o
nQT0ooXI0003o`000003ooXI0?l0003onQT000GonQT000Co0000ooLR0?l0003o00001Oog8P000ol0
003ojET0o`000002onUI0003o`000?oYF@3ojET000?ojET00ol00002oiBi0004o`000?nD^@3oU;T0
o`0000;oUKT000Go0000oiFi0?l0003oU[T0o`000003oiJi0005o`000?ooooooooooo`000?l0OQP0
0_l00006ooooo`007_ooool00ol0003oooooooooo`0@ooooo`03o`000?oe:P3omBX000;omBX000Co
0000ooTJ0?oi6P3onAX01?l00006ooXG0003o`000?oj6@3o000000;o00000_oj6@000ol0003onAX0
ooTJ0004ooTJ0003o`000?oi6`3onA/000?o00000_oi6`000ol0003onA`0ooTL0004ooTL00Co0000
1?oi7@000ol0003on1d0ooPM0003ooPM00?o00001_oh7P001?l0003on1h0ooPN0?oh7P04o`0000Oo
n1l000?o0000ooPO0?l000000_l000000ooh7`3o0000ooPO0006ooPO0003o`000?oh7`3on1l000?o
00000_oh7`000ol0003on1l0ooPO0004ooPO0003o`000?oh7`3o000000;o00000_oh7`000ol0003o
n1h0ooPN0004ooPN00Co00001?oh7P000ol0003on1d0ooPM0004ooPM00;o00001Ooi7@000ol0003o
nA`0ooTL0004ooTL00?o00001Ooi6`000ol0003onAX0ooTJ0004ooTJ00?o00001Ooj6@001?l0003o
nQT0ooXI0?oj6@04o`0000Oomb800_l00003onUI0003o`000?oYF@3ojET000;ojET000Co0000onUI
0?l0003o00000_nD^@001_l0003oU;T0oiBi0?l0003oUKT0o`0000;oUKT000?o0000oiJi0?l00000
0onF^@03o`0000;o07hH0_l00006ooooo`007oooool00ol0003oooooooooo`0@ooooo`So00001?oj
60000ol0003onQL0ooXG0003ooXG00?o00001Ooj6@000ol0003onAX0ooTJ0003ooTJ00?o00001_oi
6`000ol0003onA`0ooTL0003o`000003ooTL0?l0003onAd000KonAd000?o0000ooPM0?l000000_l0
0003ooPM0003o`000?oh7P3on1h000?on1h01?l00004ooPN0003o`000?oh7`3on1l000Con1l00_l0
0005ooPO0003o`000?oh7`3on1l000Con1l00ol00006ooPO0004o`000?oh7`3on1l0ooPO00Co0000
1_oh7`000ol0003on1h0ooPN0003o`000003ooPN0?l0003on1h000Kon1h000?o0000ooPM0?oh7@00
0ol000000ooh7@3o0000ooTM0005ooTM0003o`000?oi703onA`000?o00000_oi70000ol0003onA/0
ooTK0004ooTK0003o`000?oi6P3onAX000?o000000?onAX0o`000?oj6@001Ooj6@04o`0000ConQT0
00?o0000ooLR0?og8P000_og8P02o`000005ooLR0?l0003ojET0onUI0?l000001?oYF@001?l0003o
jET0onUI0?oYF@02o`000007oiBi0?l0003oU;T0oiBi0?l0003oUKT0o`000002oiFi0003o`000?nF
^@3o000000?oU[T000?o0000oiFi0?l000000_l0OQP2o`0000Kooooo000Pooooo`03o`000?oooooo
oooo013ooooo00Go0000ooHX0?of:03omRP0o`000007ooXH0003o`000?oj5`3o000000;o00000ooj
60000ol0003onQT0ooXI0003ooXI0003o`000?oi6P3o000000;o00000ooi6P000ol0003onA/0ooTK
0003ooTK00?o00001Ooi70000ol0003onAd0ooTM0004ooTM00;o00001ooh7@000ol0003on1h0o`00
0002o`0000;on1h000?o0000ooPN0?oh7P001?oh7P000ol0003on1l0ooPO0003o`0000;on1l000?o
0000ooPO0?oh7`000ooh7`000ol0003on1l0ooPO0003o`0000;on1l000?o0000ooPO0?oh7`001?oh
7`04o`0000Con1l000?o0000ooPO0?oh7`000ooh7`03o`0000Gon1h000?o0000ooPN0?oh7P001?oh
7P03o`0000Gon1d000Co0000ooTM0?oi7@3onAd01Ol00006ooTL0004o`000?oi6`3onA/0ooTK00Go
00001Ooi6P000ol0003onQT0ooXI0003o`000003ooXI0?l0003onQT000KonQT000Co0000ooLR0?l0
003o00001?og8P000ol0003ojET0o`000003onUI0003o`000?oYF@3ojET000;ojET000?o0000oiBi
0?l000000onD^@000ol0003oUKT0o`000002oiFi0003o`000?nF^@3o000000;oU[T000?o0000oiFi
0?nE^@000_l000000ol0OQSo0000o`000006ooooo`008Oooool2o`00017ooooo00Go0000ooHX0?of
:03omRP0o`000006ooXH00;o00001ooj60001?l0003onQT0ooXI0?oj6@04o`0000KonAX000?o0000
ooTK0?l000000_l00003ooTK0003o`000?oi703onA`000?onA`000?o0000ooTM0?oi7@000ol00002
ooTM0003o`000?oh7@3on1d000Con1d00_l00006ooPN0003o`000?oh7P3on1h000?on1h00ol00006
ooPO0004o`000?oh7`3on1l0ooPO00Co00001_oh7`000ol0003on1l0ooPO0003o`000003ooPO0?l0
003on1l000Kon1l000?o0000ooPO0?l000000_l00002ooPO0003o`000?oh7P3on1h000Con1h000?o
0000ooPN0?oh7P000ol00002ooPN0003o`000?oh7@3on1d000?on1d01?l00004ooTM0003o`000?oi
703onA`000ConA`01?l00003ooTK0003o`000?oi6P3onAX000ConAX00ol00005ooXI0003o`000?oj
6@3onQT000ConQT00_l00006ooLR00;o00001?oYF@001_l0003ojET0onUI0?oYF@3o0000onUI00;o
00000onD^@001Ol0003oUKT0o`000?nE^@3o000000;oU[T000Co0000oiJi0?nF^@3o00000_nE^@00
1_l0003oS;L0o`000?l0003oooooo`0000Gooooo000Sooooo`03o`000?oooooooooo00oooooo1Ol0
0002ooXH00?o00000_oj60000ol0003onQP0ooXH0004ooXH00Co00001?oj6@000ol0003onAX0ooTJ
0003ooTJ00?o00001_oi6`001?l0003onA`0ooTL0?oi7004o`0000KonAd000?o0000ooPM0?oh7@00
0ol00002ooPN0003o`000?oh7P3on1h000Con1h000?o0000ooPN0?l000000_l00002ooPN0003o`00
0?oh7`3on1l000Con1l01?l00004ooPO0003o`000?oh7`3on1l000?on1l00ol00005ooPO0003o`00
0?oh7`3on1l000Con1l00_l00006ooPO0004o`000?oh7P3on1h0ooPN00Go00001_oh7P000ol0003o
n1d0o`000002o`000003ooPM0?l0003onAd000KonAd000?o0000ooTL0?oi70000ol000000ooi703o
0000ooTK0005ooTK0003o`000?oi6P3onAX000?o00000_oi6P000ol0003onQT0ooXI0004ooXI0003
o`000?oj6@3onQT000?o000000?onQT0o`000?og8P000oog8P02o`000003ooLR0?l0003ojET000;o
jET000Go0000onUI0?oYF@3ojET0o`000003onUI00;o000000OoU;T0o`000?nE^@3oUKT0o`000?nE
^@3o000000;oU[T000Co0000oiJi0?nF^@3o00000_nE^@001_l0003oS;L0o`000?l0003oooooo`00
00Gooooo000Tooooo`03o`000?oooooooooo013ooooo00?o0000ooHX0?l000000_l00006ooXH0003
o`000?oj603onQP000?o000000?onQP0o`000?oj6@001_oj6@000ol0003onAX0o`000002o`0000?o
nAX000?o0000ooTK0?oi6`000ooi6`04o`0000ConA`000?o0000ooTM0?oi7@000ooi7@03o`0000Ko
n1h000Co0000ooPN0?oh7P3on1h01?l00006ooPN0003o`000?oh7`3on1l000?o000000?on1l0o`00
0?oh7`001_oh7`000ol0003on1l0o`000002o`0000;on1l000?o0000ooPO0?oh7`001?oh7`000ol0
003on1l0ooPO0003o`0000;on1l000?o0000ooPO0?oh7`000ooh7`04o`0000Con1h000?o0000ooPN
0?oh7P001?oh7P02o`0000Gon1d000?o0000ooTM0?oi7@001?oi7@03o`0000GonA`000Co0000ooTK
0?oi6`3onA/01Ol00006ooTJ0004o`000?oj6@3onQT0ooXI00Go00001Ooj6@001?l0003omb80o`00
0?l00004ooLR0003o`000?oYF@3o000000CojET000Co0000onUI0?oYF@3ojET01?l00002oiFi0003
o`000?nE^@3o000000;oU[T000Ko0000oiJi0?nF^@3o0000oiFi0?l00002ohbg0004o`000?oooooo
ooooo`0000Gooooo000Uooooo`03o`000?oooooooooo013ooooo00Go0000ooHX0?of:03omRP0o`00
0005ooXH00?o00001Ooj60000ol0003onQT0ooXI0004ooXI00;o00001ooi6P000ol0003onA/0o`00
0002o`000003ooTK0?l0003onA`000KonA`000?o0000ooTM0?l000000_l00003ooTM0003o`000?oh
7P3on1h000?on1h01?l00004ooPN0003o`000?oh7P3on1h000?on1h00ol00005ooPO0003o`000?oh
7`3on1l000Con1l00_l00006ooPO0004o`000?oh7`3on1l0ooPO00Go00001_oh7`000ol0003on1l0
o`000002o`0000;on1l000?o0000ooPN0?oh7P001?oh7P000ol0003on1h0ooPN0003o`000003ooPN
0?l0003on1d000Gon1d000?o0000ooTM0?oi7@000ol00002ooTM0003o`000?oi703onA`000?onA`0
1?l00004ooTK0003o`000?oi6P3onAX000ConAX01?l00003ooXI0003o`000?oj6@3onQT000ConQT0
0_l00006ooLR00;o00001?oYF@001Ol0003ojET0onUI0?oYF@3o000000;ojET00_l00002oiFi0005
o`000?nE^@3o0000oiJi0?l000000onF^@000ol0003oUKT0o`000002ohbg0004o`000?oooooooooo
o`0000Gooooo000Vooooo`03o`000?oooooooooo013ooooo1Ol000001?oj603o0000o`000?l00003
ooXH0003o`000?oj603onQP000?onQP000?o0000ooXI0?oj6@000ol00002ooTI0003o`000?oi6P3o
nAX000ConAX00_l00005ooTK0003o`000?oi703onA`000ConA`00_l00007ooTM0003o`000?oh7P3o
000000;o000000?on1h0o`000?oh7P001_oh7P000ol0003on1h0o`000002o`0000?on1l000?o0000
ooPO0?oh7`000ooh7`000ol0003on1l0ooPO0003o`0000;on1l000?o0000ooPO0?oh7`000ooh7`04
o`0000Con1l000?o0000ooPO0?oh7`001?oh7`02o`0000Kon1l000Co0000ooPN0?oh7P3on1h01Ol0
0005ooPN0004o`000?oh7@3on1d0ooPM00Go00001_oi7@000ol0003onA`0o`000002o`000003ooTL
0?l0003onA/000KonA/000?o0000ooTJ0?oi6P000ol000000ooi6P3o0000ooXI0005ooXI0003o`00
0?oj6@3onQT000?o00000_oj6@001?l0003omb80ooLR0?og8P02o`0000;omb8000Go0000onUI0?oY
F@3ojET0o`000003onUI0007o`000?oYF@3ojET0onUI0?l0003oUKT0o`000002oiFi0003o`000?nF
^@3o000000;oU[T000Go0000oiFi0?nE^@3o0000ohbg0002o`0000;ooooo00?o0000ooooooooool0
0oooool002Oooooo0_l0000Booooo`03o`000?of:@3o000000;o00001_oj60001?l0003onQP0ooXH
0?oj6004o`0000KonAT000?o0000ooTJ0?oi6P000ol00002ooTJ0003o`000?oi6`3onA/000?onA/0
00?o0000ooTL0?oi70000ol00002ooTL0003o`000?oi7@3onAd000ConAd00_l00005ooPN0003o`00
0?oh7P3on1h000Con1h00_l00007ooPO0004o`000?oh7`3on1l0ooPO00Co00001_oh7`000ol0003o
n1l0o`000002o`0000;on1l000?o0000ooPO0?oh7`001?oh7`000ol0003on1l0ooPO0003o`0000;o
n1l000?o0000ooPO0?oh7`000ooh7`04o`0000Con1h000?o0000ooPN0?oh7P000ooh7P04o`0000Co
n1d000?o0000ooTM0?oi7@001?oi7@02o`0000GonA`000?o0000ooTK0?oi6`001?oi6`03o`0000Go
nAX000Co0000ooXI0?oj6@3onQT01Ol00006ooXI0003o`000?og8P3o000000Gomb8000?o0000onUI
0?l000000ooYF@000ol0003ojET0onUI0002onUI00?o00000_nE^@000ol0003oU[T0o`000002oiJi
0005o`000?nE^@3oUKT0o`000?n<]`000_l00002ooooo`03o`000?oooooooooo00?ooooo000Yoooo
o`03o`000?oooooooooo013ooooo00Go0000ooHY0?of:@3omRT0o`000005ooXH00Co00001?oj6000
0ol0003onAT0ooTI0003ooTI00?o00001_oi6P001?l0003onA/0ooTK0?oi6`04o`0000KonA`000?o
0000ooTM0?oi7@000ol00002ooTM0003o`000?oh7P3on1h000?on1h000?o0000ooPN0?oh7P000ol0
0002ooPN0003o`000?oh7`3on1l000Con1l01?l00003ooPO0003o`000?oh7`3on1l000Con1l00_l0
0006ooPO0004o`000?oh7`3on1l0ooPO00Go00001_oh7`000ol0003on1l0o`000002o`000003ooPO
0?l0003on1h000Kon1h000?o0000ooPN0?l000000_l00002ooPN0003o`000?oh7@3on1d000Con1d0
00?o0000ooTM0?oi7@000ol000000ooi7@3o0000ooTL0005ooTL0003o`000?oi6`3onA/000?o0000
00?onA/0o`000?oi6P001Ooi6P04o`0000ConQT000?o0000ooXI0?oj6@001?oj6@02o`0000Komb80
0_l00003onUI0003o`000?oYF@3ojET000;ojET000Co0000onUH0?l0003o00000_nE^@000ol0003o
U[T0o`000002oiJi0005o`000?nE^@3oUKT0o`000?n<]`000_l00002ooooo`03o`000?oooooooooo
00?ooooo000Zooooo`03o`000?oooooooooo013ooooo1Ol000001?oj603o0000o`000?l00003ooXI
0003o`000?oj603onQP000?onQP000?o0000ooTI0?l000000_l00003ooTI0003o`000?oi6P3onAX0
00?onAX01?l00004ooTK0003o`000?oi703onA`000?onA`00ol00006ooTM0004o`000?oh7P3on1h0
ooPN00Co00001_oh7P000ol0003on1l0ooPO0003o`0000;on1l000?o0000ooPO0?oh7`000ooh7`00
0ol0003on1l0ooPO0003o`0000;on1l000?o0000ooPO0?oh7`000ooh7`04o`0000Con1l000?o0000
ooPO0?oh7`001?oh7`02o`0000Gon1l000?o0000ooPN0?oh7P001?oh7P02o`0000Kon1h000Co0000
ooPM0?oh7@3on1d01Ol00005ooTM0004o`000?oi703onA`0ooTL00Go00001Ooi6`000ol0003onAX0
ooTJ0003o`000003ooTJ0?l0003onQT000KonQT000?o0000ooXI0?oj6@000ol000000ooj603o0000
ooLR0003ooLR00;o000000?omb80o`000?oYF@000_oYF@001Ol0003ojET0onUI0?oYF@3o000000?o
jEP000?o0000oiFi0?l000000_nF^@001_l0003oU[T0oiJi0?l0003oUKT0o`0000;oS;L00_l00003
ooooo`03o`000?oooooooooo00;ooooo000[ooooo`03o`000?oooooooooo013ooooo00?o0000ooHY
0?of:@000ol00006ooXI0004o`000?oj603onQP0ooXH00Co00001_oi6@000ol0003onAX0o`000002
o`0000?onAX000?o0000ooTK0?oi6`000ooi6`000ol0003onA`0o`000002o`0000?onA`000?o0000
ooTM0?oi7@000ooi7@04o`0000Con1h000?o0000ooPN0?oh7P000ooh7P03o`0000Kon1l000Co0000
ooPO0?oh7`3on1l01?l00006ooPO0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1l0ooPO
0004ooPO0003o`000?oh7`3on1l000?o000000?on1l0o`000?oh7`001Ooh7`000ol0003on1h0ooPN
0003o`000003ooPN0?l0003on1h000Gon1h01?l00004ooPM0003o`000?oi7@3onAd000?onAd01?l0
0004ooTL0003o`000?oi6`3onA/000?onA/00ol00005ooTJ0003o`000?oj6@3onQT000ConQT00ol0
0005ooXH0004o`000?og8P3o0000o`0000Comb8000?o0000onUI0?l000001?oYF@001?l0003ojEP0
onUH0?oYF003o`0000;oU[T000Ko0000oiJi0?nF^@3o0000oiFi0?l00002ohbg0003o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool002cooooo0_l0000Aooooo`03o`000?of:@3omRT0
00;omRT000?o0000ooXI0?oj6@000ooj6@04o`0000ConQP000?o0000ooTI0?oi6@000ooi6@02o`00
00OonAX000Co0000ooTK0?oi6`3onA/00ol00007ooTL0003o`000?oi7@3o000000;o00000_oi7@00
0ol0003on1h0ooPN0004ooPN0003o`000?oh7P3o000000;o00000_oh7P000ol0003on1l0ooPO0004
ooPO00Co00000ooh7`000ol0003on1l0ooPO0004ooPO00;o00001_oh7`001?l0003on1l0ooPO0?oh
7`05o`0000Gon1l000Co0000ooPO0?oh7`3on1l01Ol00005ooPN0003o`000?oh7P3on1h000?o0000
0_oh7P000ol0003on1d0ooPM0004ooPM0003o`000?oi7@3o000000;o00000_oi7@000ol0003onA`0
ooTL0004ooTL0003o`000?oi6`3o000000;o00000_oi6`000ol0003onAX0ooTJ0004ooTJ0003o`00
0?oj6@3onQT000?o000000?onQT0o`000?oj60001Ooj6002o`0000Komb8000?o0000onUI0?l00000
0ooYF@001_l0003ojEP0onUH0?oYF03o0000onUH00;o00000_nF^@000ol0003oU[T0o`000002oiFi
0004o`000?n<]`3o0000o`0000Cooooo00?o0000ooooooooool00_ooool002kooooo00?o0000oooo
ooooool03oooool00ol0003omRT0ooHY0002ooHY0003o`000?oj6@3o000000;o000000?onQT0o`00
0?oj60001_oj60000ol0003onAT0o`000002o`0000;onAT000?o0000ooTJ0?oi6P001?oi6P04o`00
00?onA/000?o0000ooTL0?oi70001?oi7002o`0000KonAd000Co0000ooPN0?oh7P3on1h01?l00006
ooPN0003o`000?oh7`3on1l000?o00000_oh7`000ol0003on1l0ooPO0003ooPO0003o`000?oh7`3o
n1l000?o00000_oh7`000ol0003on1l0ooPO0003ooPO00Co00001?oh7`000ol0003on1l0ooPO0003
ooPO00Co00001?oh7`000ol0003on1h0ooPN0003ooPN00?o00001_oh7P001?l0003on1d0ooPM0?oh
7@04o`0000KonAd000Co0000ooTL0?oi703onA`01?l00006ooTK0004o`000?oi6P3onAX0ooTJ00Go
00001Ooj6@000ol0003onQP0ooXH0003o`000003ooXH0?l0003omb8000Gomb800_l00003onUI0003
o`000?oYF03ojEP000;ojEP000?o0000onUH0?oYF0000ol00002oiJi0005o`000?nE^@3oUKT0o`00
0?n<]`000_l00004ooooo`03o`000?oooooooooo00;ooooo000_ooooo`03o`000?oooooooooo00oo
oooo1_l00005ooXI0003o`000?oj603onQP000ConQP00_l00006ooTI0003o`000?oi6P3onAX000?o
00000_oi6`000ol0003onA/0ooTK0003ooTK0003o`000?oi703onA`000?o00000_oi70000ol0003o
nAd0ooTM0003ooTM00Co00001?oh7P000ol0003on1h0ooPN0003ooPN00?o00001_oh7`001?l0003o
n1l0ooPO0?oh7`04o`0000Kon1l000?o0000ooPO0?l000000_l000000ooh7`3o0000ooPO0006ooPO
0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1l0ooPO0004ooPO0003o`000?oh7P3o0000
00;o00000_oh7P000ol0003on1h0ooPN0004ooPN00Co00000ooh7@000ol0003onAd0ooTM0004ooTM
00Co00000ooi70000ol0003onA/0ooTK0004ooTK00Co00000ooi6P000ol0003onQT0ooXI0004ooXI
00?o00001Ooj60000ol0003omb80ooLR0003o`000003ooPQ0?l0003ojET000;ojET000Go0000onUH
0?oYF03ojEP0o`000003onUH00?o00000_nF^@001Ol0003oUKT0oiFi0?l0003oS;L000;o00001?oo
ool00ol0003oooooooooo`02ooooo`00<?ooool00ol0003oooooooooo`0?ooooo`03o`000?of:@3o
mRT000;omRT000?o0000ooXI0?oj6@000ooj6@000ol0003onQP0ooXH0003o`0000;onQP000?o0000
ooTI0?oi6@000ooi6@03o`0000KonA/000Co0000ooTK0?oi6`3onA/01?l00006ooTL0003o`000?oi
7@3o000000;o00000ooh7@000ol0003on1h0ooPN0003ooPN0003o`000?oh7P3o000000;o00000_oh
7P000ol0003on1l0ooPO0004ooPO00Co00000ooh7`000ol0003on1l0ooPO0004ooPO00;o00001Ooh
7`000ol0003on1l0ooPO0004ooPO00;o00001_oh7`001?l0003on1l0ooPO0?oh7`04o`0000Kon1h0
00?o0000ooPN0?oh7P000ol000000ooh7P3o0000ooPM0005ooPM0003o`000?oi7@3onAd000?o0000
0_oi7@000ol0003onA`0ooTL0003ooTL0003o`000?oi6`3onA/000?o00000_oi6`000ol0003onAX0
ooTJ0003ooTJ0003o`000?oj6@3onQT000?o00000_oj6@000ol0003onQP0ooXH0003ooXH00?o0000
1Ooh8@000ol0003ojET0o`000003onUH0006o`000?oYF03ojEP0onUH0?l0003ojEP00_l00002oiJi
0003o`000?nE^@3o000000;oS;L00_l00004ooooo`03o`000?oooooooooo00;ooooo000aooooo`;o
00004?ooool00ol0003omRT0ooHY0002ooHY0004o`000?oj6@3onQT0ooXI00Co00001_oj60000ol0
003onAT0o`000002o`0000?onAT000?o0000ooTK0?oi6`000ooi6`04o`0000ConA`000?o0000ooTL
0?oi70000ooi7002o`0000Oon1d000Co0000ooPN0?oh7P3on1h00ol00006ooPN0003o`000?oh7`3o
n1l000?o00000_oh7`000ol0003on1l0ooPO0003ooPO0003o`000?oh7`3on1l000?o00000_oh7`00
0ol0003on1l0ooPO0003ooPO0003o`000?oh7`3on1l000?o00000_oh7`000ol0003on1l0ooPO0003
ooPO00Co00001?oh7`000ol0003on1h0ooPN0003ooPN00?o00001Ooh7P000ol0003on1d0ooPM0003
ooPM00?o00001_oi7@001?l0003onA`0ooTL0?oi7004o`0000KonA/000Co0000ooTJ0?oi6P3onAX0
1?l00006ooXI0003o`000?oj603o000000;o000000?onQP0o`000?oh8@001Ooh8@02o`0000CojEP0
00Go0000onUH0?oYF03ojEP0o`000002onUH00;o000000CoU[T0o`000?nE^@3o00000_n<]`02o`00
00Cooooo00?o0000ooooooooool00_ooool003?ooooo00?o0000ooooooooool03_ooool8o`0000Co
nQT000?o0000ooXH0?oj60000ooj6003o`0000KonAT000?o0000ooTK0?l000000_l00002ooTK0003
o`000?oi703onA`000ConA`000?o0000ooTL0?l000000_l00002ooTL0003o`000?oh7@3on1d000Co
n1d01?l00003ooPN0003o`000?oh7P3on1h000?on1h00ol00006ooPO0004o`000?oh7`3on1l0ooPO
00Co00001_oh7`001?l0003on1l0ooPO0?oh7`04o`0000Kon1l000?o0000ooPO0?l000000_l00002
ooPO0003o`000?oh7`3on1l000Con1l000?o0000ooPN0?l000000_l00002ooPN0003o`000?oh7P3o
n1h000Con1h000?o0000ooPM0?l000000_l00002ooPM0003o`000?oi7@3onAd000ConAd01?l00003
ooTL0003o`000?oi6`3onA/000ConA/01?l00003ooTJ0003o`000?oj6@3onQT000ConQT00_l00005
ooXH0004o`000?oh8@3on240ooPQ00;o00000_oh8@001?l0003ojEP0onUH0?l00003onUH0007o`00
0?oYF03ojEP0onUH0?l0003oU[T0o`000002oiFi0005o`000?n<]`3o0000oeZY0?l000001Oooool0
0ol0003oooooooooo`01ooooo`00=?ooool00ol0003oooooooooo`0?ooooo`03o`000?of:@3omRT0
00;omRT000?o0000ooXI0?oj6@000ooj6@000ol0003onQP0o`000002o`0000?onQP000?o0000ooTI
0?oi6@000ooi6@02o`0000KonA/000Co0000ooTL0?oi703onA`01?l00006ooTL0003o`000?oh7@3o
n1d000?o00000_oh7@000ol0003on1h0ooPN0003ooPN0003o`000?oh7P3o000000;o00000ooh7P00
0ol0003on1l0ooPO0003ooPO00Co00000ooh7`000ol0003on1l0ooPO0004ooPO00Co00000ooh7`00
0ol0003on1l0ooPO0004ooPO00;o00001_oh7`001?l0003on1l0ooPO0?oh7`04o`0000Kon1h000Co
0000ooPN0?oh7P3on1h01?l00006ooPM0003o`000?oi7@3onAd000?o000000?onAd0o`000?oi7000
1Ooi70000ol0003onA/0ooTK0003o`000003ooTK0?l0003onAX000GonAX000?o0000ooXI0?oj6@00
0ol000000ooj603o0000ooXH0005ooXH0003o`000?oh8@3o000000Gon24000?o0000onUH0?l00000
0_oYF0001_l0003ojEP0onUH0?oYF03o0000onUH00;o00000_nE^@001?l0003oS;L0o`000?l00006
ooooo`03o`000?oooooooooo007ooooo000eooooo`03o`000?oooooooooo00oooooo00?o0000ooHY
0?of:@000_of:@001?l0003onQT0ooXI0?oj6@03o`0000OonQP000?o0000ooTI0?l000000_l00002
ooTJ0003o`000?oi6`3onA/000?onA/01?l00004ooTL0003o`000?oi703onA`000?onA`00ol00006
ooPM0004o`000?oh7P3on1h0ooPN00?o00001ooh7P000ol0003on1l0o`000002o`0000;on1l000?o
0000ooPO0?oh7`000ooh7`000ol0003on1l0ooPO0003o`0000;on1l000?o0000ooPO0?oh7`000ooh
7`000ol0003on1l0ooPO0003o`0000;on1l000?o0000ooPO0?oh7`000ooh7`04o`0000?on1l000?o
0000ooPN0?oh7P001?oh7P04o`0000?on1h000?o0000ooPM0?oh7@001?oh7@03o`0000GonAd000Co
0000ooTL0?oi703onA`01Ol00005ooTK0004o`000?oi6P3onAX0ooTJ00Go00001Ooj60001?l0003o
nQP0ooXH0?oj6004o`0000Kon2400_l00003onUH0005o`000?oYF03ojEP0onUH0?l000000_oYF002
o`000003oiFi0?l0003oS;L000;o00001_ooool00ol0003oooooooooo`01ooooo`00=_ooool2o`00
013ooooo2?l00003ooTI0003o`000?oj603onQP000ConQP00_l00006ooTJ0003o`000?oi6`3o0000
00;o00000ooi6`000ol0003onA`0ooTL0003ooTL0003o`000?oi703o000000;o00000_oi70000ol0
003on1d0ooPM0004ooPM00Co00000ooh7P000ol0003on1h0ooPN0004ooPN00;o00001_oh7`001?l0
003on1l0ooPO0?oh7`04o`0000Kon1l000Co0000ooPO0?oh7`3on1l01?l00006ooPO0003o`000?oh
7`3o000000;o00000_oh7`000ol0003on1l0ooPO0003ooPO0003o`000?oh7P3on1h000?o00000_oh
7P000ol0003on1h0ooPN0003ooPN0003o`000?oh7@3on1d000?o000000?on1d0o`000?oi7@001Ooi
7@04o`0000?onA`000?o0000ooTK0?oi6`001?oi6`04o`0000?onAX000?o0000ooXH0?oj60001?oj
6004o`0000?onQP000?o0000ooPQ0?oh8@000_oh8@02o`000005ooPQ0?l0003ojEP0onUH0?l00000
0ooYF0001ol0003ojEP0onUH0?oYF03o0000oiFi0?l000000_n<]`02o`0000Kooooo00?o0000oooo
ooooool00Oooool003Sooooo00?o0000ooooooooool03_ooool00ol0003omRT0ooHY0002ooHY0003
o`000?oi6@3onAT000?onAT000?o0000ooXH0?oj60000ol00002ooXH0003o`000?oi6P3onAX000?o
nAX00ol00006ooTK0004o`000?oi703onA`0ooTL00?o00001_oi70000ol0003on1d0ooPM0003o`00
00;on1d000?o0000ooPN0?oh7P000ooh7P000ol0003on1h0ooPN0003o`0000;on1h000?o0000ooPO
0?oh7`000ooh7`04o`0000?on1l000?o0000ooPO0?oh7`001?oh7`04o`0000?on1l000?o0000ooPO
0?oh7`001?oh7`02o`0000Kon1l000Co0000ooPO0?oh7`3on1l01?l00006ooPN0004o`000?oh7P3o
n1h0ooPN00Co00001Ooh7@000ol0003onAd0ooTM0003o`0000;onA`000?o0000ooTL0?oi70000ooi
70000ol0003onA/0ooTK0003o`000003ooTK0?l0003onAX000GonAX000?o0000ooXH0?oj60000ol0
00000ooj603o0000ooXH0005ooXH0004o`000?oh8@3o0000o`0000Con24000?o0000onUH0?l00000
0_oYF0001_l0003ojEP0onUH0?oYF03o0000onUH00;o00000_n<]`02o`0000Kooooo00?o0000oooo
ooooool00Oooool003Wooooo00?o0000ooooooooool03_ooool00ol0003omRT0ooHY0002ooHY0004
o`000?oi6@3onAT0ooTI00Co00001_oj60000ol0003onAX0o`000002o`0000?onAX000?o0000ooTK
0?oi6`000ooi6`04o`0000?onA`000?o0000ooTL0?oi70000ooi7003o`0000Kon1d000Co0000ooPN
0?oh7P3on1h01?l00006ooPN0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1l0ooPO0003
ooPO0003o`000?oh7`3on1l000?o00000_oh7`000ol0003on1l0ooPO0003ooPO0003o`000?oh7`3o
n1l000?o000000?on1l0o`000?oh7`001Ooh7`04o`0000?on1l000?o0000ooPN0?oh7P001?oh7P04
o`0000Con1h000Co0000ooPM0?oh7@3on1d01?l00006ooTL0004o`000?oi703onA`0ooTL00Co0000
1Ooi6`001?l0003onAX0ooTJ0?oi6P05o`0000GonQP000Co0000ooXH0?oj603onQP01?l00006ooPQ
00;o00000ooYF0001Ol0003ojEP0onUH0?oYF03o000000;ojEP01?l00007ooooo`03o`000?oooooo
oooo007ooooo000jooooo`03o`000?oooooooooo00kooooo2?l00004ooTI00;o00000ooj6003o`00
00OonAX000?o0000ooTK0?l000000_l00002ooTK0003o`000?oi703onA`000?onA`000?o0000ooTL
0?l000000_l00003ooTM0003o`000?oh7@3on1d000?on1d01?l00003ooPN0003o`000?oh7P3on1h0
00Con1h00_l00006ooPO0004o`000?oh7`3on1l0ooPO00Co00001_oh7`001?l0003on1l0ooPO0?oh
7`04o`0000Gon1l000?o0000ooPO0?oh7`000ol00002ooPO0003o`000?oh7`3on1l000?on1l000?o
0000ooPN0?oh7P000ol000000ooh7P3o0000ooPN0005ooPN00Co00000ooh7@000ol0003onA`0ooTL
0004ooTL00Co00000ooi70000ol0003onA/0ooTK0003ooTK00Co00001?oi6@000ol0003onQP0ooXH
0003ooXH00Co00001?oj60000ol0003on240ooPQ0003o`000005ooPQ0?l0003ojEP0onUH0?l00000
0ooYF0001?l0003ojEP0onUH0?oYF004o`0000Sooooo0Ol00001ooooo`7ooooo000kooooo`03o`00
0?oooooooooo00oooooo0_l00003ooHY0003o`000?oi6@3onAT000?onAT01?l00003ooXI0003o`00
0?oi6P3onAX000ConAX00_l00006ooTK0004o`000?oi703onA`0ooTL00?o00001ooi7@000ol0003o
n1d0o`000002o`0000;on1d000?o0000ooPN0?oh7P000ooh7P000ol0003on1h0ooPN0003o`0000;o
n1h000?o0000ooPO0?oh7`000ooh7`04o`0000?on1l000?o0000ooPO0?oh7`001?oh7`04o`0000Co
n1l000Co0000ooPO0?oh7`3on1l01?l00006ooPO0004o`000?oh7`3on1l0ooPO00Co00001Ooh7P00
0ol0003on1h0ooPN0003o`000003ooPN0?l0003on1d000Gon1d000?o0000ooTL0?oi70000ol00000
0ooi703o0000ooTL0005ooTL0003o`000?oi6`3o000000;o00000_oi6P000ol0003onAT0ooTI0004
ooTI0003o`000?oj603o000000;o00000_oj60000ol0003onQP0ooXH0003ooXH00?o00001Ooh8@00
0ol0003ojEP0o`000002onUH0005o`000?oYF03ojEP0onUH0?l000000_oVHP02o`0000Sooooo0Ol0
0001ooooo`7ooooo000looooo`;o00004Oooool5o`000004ooTI0?l0003o0000o`0000;onAT000?o
0000ooXI0?oj6@000ooj6@000ol0003onAX0ooTJ0003o`0000;onAX000?o0000ooTK0?oi6`000ooi
6`04o`0000?onA`000?o0000ooTM0?oi7@001?oi7@02o`0000Kon1d000Co0000ooPN0?oh7P3on1h0
1?l00006ooPN0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1l0ooPO0003ooPO0003o`00
0?oh7`3on1l000?o00000_oh7`000ol0003on1l0ooPO0003ooPO00Co00000ooh7`000ol0003on1l0
ooPO0004ooPO00Co00000ooh7`000ol0003on1h0ooPN0003ooPN00?o00001Ooh7P001?l0003on1d0
ooPM0?oh7@05o`0000GonA`000Co0000ooTL0?oi703onA`01?l00006ooTJ0004o`000?oi6@3onAT0
ooTI00Co00001_oj60000ol0003onQP0o`000002o`0000;onQP000?o0000ooPQ0?oh8@000ooh8@02
o`0000?ojEP000Go0000onUH0?oYF03ojEP0o`000002onIR00;o00002?ooool1o`00007ooooo0Ooo
ool003kooooo00?o0000ooooooooool03oooool00ol0003omRT0ooHY0002o`0000KonAT000Co0000
ooXI0?oj6@3onQT01?l00006ooTJ0003o`000?oi6`3o000000;o00000_oi6`000ol0003onA`0ooTL
0003ooTL0003o`000?oi7@3onAd000?o00000_oi7@000ol0003on1d0ooPM0003ooPM00Co00000ooh
7P000ol0003on1h0ooPN0004ooPN00;o00001_oh7`001?l0003on1l0ooPO0?oh7`04o`0000Kon1l0
00?o0000ooPO0?l000000_l00002ooPO0003o`000?oh7`3on1l000?on1l000?o0000ooPO0?oh7`00
0ol000000ooh7`3o0000ooPO0005ooPO0003o`000?oh7P3o000000;o00000_oh7P000ol0003on1h0
ooPN0003ooPN00Co00001?oi7@000ol0003onA`0ooTL0003ooTL00Co00000ooi6`000ol0003onAX0
ooTJ0004ooTJ00Co00000ooi6@000ol0003onQP0ooXH0004ooXH00;o00001_oj60000ol0003on240
o`000002o`000005ooPQ0?l0003ojEP0onUH0?l000000ooYF0001?l0003oiV80onIR0?l00002oooo
o`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000oooooo`03o`000?oooooooooo00oo
oooo00Go0000ooHY0?of:@3omRT0o`000005ooTI00Co00001?oj6@000ol0003onAX0ooTJ0003ooTJ
00;o00001_oi6`001?l0003onA`0ooTL0?oi7004o`0000KonAd000?o0000ooPM0?l000000_l00002
ooPM0003o`000?oh7P3on1h000?on1h000?o0000ooPN0?oh7P000ol00002ooPN0003o`000?oh7`3o
n1l000?on1l01?l00003ooPO0003o`000?oh7`3on1l000Con1l00_l00006ooPO0004o`000?oh7`3o
n1l0ooPO00Co00001Ooh7`001?l0003on1l0ooPO0?oh7`04o`0000Kon1h000?o0000ooPN0?l00000
0_l00002ooPN0003o`000?oi7@3onAd000ConAd000?o0000ooTL0?l000000_l00002ooTL0003o`00
0?oi6`3onA/000?onA/000?o0000ooTJ0?oi6P000ol000000ooi6P3o0000ooTI0005ooTI0003o`00
0?oj603onQP000?o000000?onQP0o`000?oj60001Ooj6002o`0000Gon24000?o0000onUH0?l00000
0ooYF0000ol0003oiV80o`000004ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo
0010ooooo`03o`000?oooooooooo00oooooo1Ol000001?oi6@3o0000o`000?l00003ooTI0003o`00
0?oj6@3onQT000?onQT000?o0000ooTJ0?l000000_l00002ooTJ0003o`000?oi6`3onA/000?onA/0
1?l00004ooTL00;o00000ooi7@03o`0000Kon1d000Co0000ooPN0?oh7P3on1h01?l00006ooPN0003
o`000?oh7`3o000000;o00000_oh7`000ol0003on1l0ooPO0003ooPO0003o`000?oh7`3on1l000?o
000000?on1l0o`000?oh7`001Ooh7`04o`0000?on1l000?o0000ooPO0?oh7`000ooh7`04o`0000Co
n1l000Co0000ooPN0?oh7P3on1h01?l00006ooPN0004o`000?oi7@3onAd0ooTM00Co00001_oi7000
1?l0003onA/0ooTK0?oi6`04o`0000GonAX000Co0000ooTI0?oi6@3onAT01Ol00005ooXH0003o`00
0?oj603onQP000?o000000?onQL0o`000?oh8@001?oh8@03o`0000;ojEP000Co0000onIR0?oVHP3o
00001Oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00@Oooool2o`00017ooooo
00?o0000ooHY0?l000000_l00006ooTI0004o`000?oj6@3onQT0ooXI00Co00001Ooi6P000ol0003o
nA/0o`000002o`0000;onA/000?o0000ooTL0?oi70001?oi7004o`0000?onAd000?o0000ooPM0?oh
7@000ooh7@04o`0000Con1h000Co0000ooPN0?oh7P3on1h01?l00006ooPO0004o`000?oh7`3on1l0
ooPO00Co00001Ooh7`000ol0003on1l0ooPO0003o`0000;on1l000?o0000ooPO0?oh7`000ooh7`00
0ol0003on1l0o`000002o`0000;on1l000?o0000ooPO0?oh7`000ooh7`04o`0000Con1h000?o0000
ooPN0?oh7P000ooh7P04o`0000?onAd000?o0000ooTL0?oi70001?oi7004o`0000?onA/000?o0000
ooTJ0?oi6P000ooi6P04o`0000ConAT000Co0000ooXH0?oj603onQP01Ol00005ooXG0003o`000?oh
8@3o000000;o00000ooh8@001Ol0003ojEP0o`000?oVHP3o000000Kooooo00?o0000ooooooooool0
0oooool1o`00007ooooo0Oooool004?ooooo00?o0000ooooooooool03oooool01Ol0003omRT0ooHY
0?of:@3o000000GonAT01?l00004ooXI0004o`000?oi6P3onAX0ooTJ00?o00001_oi6`000ol0003o
nA`0ooTL0003o`0000;onA`000?o0000ooTM0?oi7@000ooi7@000ol0003on1d0o`000002o`0000;o
n1d000?o0000ooPN0?oh7P000ooh7P04o`0000Con1h000?o0000ooPO0?oh7`000ooh7`04o`0000Co
n1l000Co0000ooPO0?oh7`3on1l01?l00006ooPO0004o`000?oh7`3on1l0ooPO00?o00001_oh7`00
0ol0003on1l0o`000002o`0000;on1h000?o0000ooPN0?oh7P001?oh7P000ol0003on1h0o`000002
o`0000;on1d000?o0000ooTM0?oi7@000ooi7@000ol0003onA`0ooTL0003o`000003ooTL0?l0003o
nA/000GonA/000?o0000ooTJ0?l000000_l00002ooTJ0003o`000?oi6@3onAT000?onAT01?l00003
ooXH0003o`000?oj5`3onQL000ConQL00_l00006ooPQ00;o00000_oVHP000ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00A?ooool00ol0003oooooooooo`0?oooo
o`Go000000ConAT0o`000?l0003o00000_oi6@000ol0003onQT0ooXI0003ooXI00Co00000ooi6P00
0ol0003onA/0ooTK0003ooTK00?o00001_oi70001?l0003onAd0ooTM0?oi7@03o`0000Kon1d000?o
0000ooPN0?l000000_l00002ooPN0003o`000?oh7P3on1h000Con1h000?o0000ooPO0?l000000_l0
0002ooPO0003o`000?oh7`3on1l000?on1l01?l00003ooPO0003o`000?oh7`3on1l000Con1l01?l0
0003ooPO0003o`000?oh7`3on1l000?on1l00_l00006ooPN0004o`000?oh7P3on1h0ooPN00Co0000
1_oh7@001?l0003onAd0ooTM0?oi7@04o`0000GonA`000Co0000ooTK0?oi6`3onA/01?l00006ooTJ
0003o`000?oi6@3o000000;o00000_oj6@000ol0003onQP0ooXH0003ooXH0003o`000?oj5`3onQL0
00?o000000?onQP0o`000?oh8@000ooh8@02o`000004oo@]0?l0003oiV80o`0000Wooooo00?o0000
ooooooooool00_ooool1o`00007ooooo0015ooooo`03o`000?oooooooooo00oooooo00?o0000ooDZ
0?oe:P000ol00005ooTI0003o`000?oj6@3o000000;o00000_oj6@000ol0003onAX0ooTJ0003ooTJ
0003o`000?oi6`3o000000;o00000ooi6`000ol0003onA`0ooTL0003ooTL00Co00000ooi70000ol0
003on1d0ooPM0003ooPM00;o00001_oh7P001?l0003on1h0ooPN0?oh7P04o`0000Kon1l000?o0000
ooPO0?l000000_l00002ooPO0003o`000?oh7`3on1l000?on1l000?o0000ooPO0?oh7`000ol00000
0ooh7`3o0000ooPO0005ooPO0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1h0ooPN0003
ooPN00Co00000ooh7P000ol0003on1d0ooPM0004ooPM00Co00001?oi7@001?l0003onA`0ooTL0?oi
7005o`0000ConA/000Co0000ooTJ0?oi6P3onAX01?l00006ooXI0004o`000?oj603onQP0ooXH00Co
00001Ooj60001?l0003on240o`000?l00003oo@]00;o00002oooool01Ol0003ooooooooooooooooo
0000007ooooo0016ooooo`;o00004?ooool00ol0003omBX0ooDZ0002ooDZ0004o`000?oi6@3onAT0
ooTI00?o00001_oj6@001?l0003onAX0ooTJ0?oi6P04o`0000KonA/000?o0000ooTL0?l000000_l0
0002ooTL0003o`000?oi703onA`000?onA`000?o0000ooPM0?l000000_l00002ooPM0003o`000?oh
7P3on1h000?on1h01?l00004ooPN0003o`000?oh7`3on1l000?on1l00_l00006ooPO0004o`000?oh
7`3on1l0ooPO00Co00001Ooh7`001?l0003on1l0ooPO0?oh7`04o`0000Kon1l000?o0000ooPN0?l0
00000_l00002ooPN0003o`000?oh7P3on1h000?on1h000?o0000ooPM0?oh7@000ol000000ooh7@3o
0000ooTM0005ooTM00Co00000_oi70000ol0003onA/0ooTK0004ooTK00Co00000ooi6P000ol0003o
nQT0ooXI0004ooXI00Co00000_oj6@000ol0003onQP0ooXH0004ooXH00?o000000Com2d0o`000?l0
003o00003Oooool01Ol0003ooooooooooooooooo0000007ooooo0018ooooo`03o`000?oooooooooo
00kooooo2?l00003ooTI0003o`000?oj6@3onQT000?onQT01?l00004ooTJ0004o`000?oi6`3onA/0
ooTK00Co00001_oi70001?l0003onA`0ooTL0?oi7004o`0000Gon1d000?o0000ooPN0?l000000_l0
0002ooPN0003o`000?oh7P3on1h000Con1h000?o0000ooPO0?l000000_l00002ooPO0003o`000?oh
7`3on1l000?on1l01?l00003ooPO0003o`000?oh7`3on1l000?on1l01?l00004ooPO0004o`000?oh
7`3on1l0ooPO00Co00001_oh7P001?l0003on1h0ooPN0?oh7P04o`0000Gon1d000?o0000ooTM0?oi
7@000ol000000ooi7@3o0000ooTL0004ooTL0003o`000?oi6`3onA/000?o000000?onA/0o`000?oi
6P001Ooi6P000ol0003onQT0ooXI0003o`000003ooTJ0?l0003onQT000ConQT000?o0000ooXH0?oj
60000ol00002ooLT00;o00004Oooool01?l0003oooooooooool00001ooooo`00BOooool00ol0003o
ooooooooo`0>ooooo`03o`000?oe:P3omBX000;omBX000?o0000ooTI0?oi6@000ooi6@000ol0003o
nQT0o`000002o`0000;onQT000?o0000ooTJ0?oi6P000ooi6P04o`0000ConA/000?o0000ooTL0?oi
70000ooi7004o`0000ConA`000Co0000ooPM0?oh7@3on1d00ol00006ooPN0004o`000?oh7P3on1h0
ooPN00Co00001_oh7`000ol0003on1l0o`000002o`0000;on1l000?o0000ooPO0?oh7`000ooh7`00
0ol0003on1l0o`000002o`0000;on1l000?o0000ooPO0?oh7`000ooh7`04o`0000?on1l000?o0000
ooPN0?oh7P001?oh7P04o`0000Con1h000Co0000ooPM0?oh7@3on1d01?l00005ooTM0004o`000?oi
703onA`0ooTL00Co00001Ooi6`001?l0003onAX0ooTJ0?oi6P05o`0000GonAX000Co0000ooXI0?oj
6@3onQT01?l00002ooLT00?o00005?ooool00ol0003oooooo`000001ooooo`00B_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oe:P3omBX000;omBX000Co0000ooTI0?oi6@3onAT00ol00006ooXI
0003o`000?oi6P3o000000;o00000ooi6P000ol0003onA/0ooTK0003ooTK0003o`000?oi703o0000
00;o00000_oi70000ol0003onA`0ooTL0003ooTL00Co00000ooh7@000ol0003on1h0ooPN0003ooPN
00Co00001?oh7P001?l0003on1l0ooPO0?oh7`04o`0000Kon1l000Co0000ooPO0?oh7`3on1l01?l0
0005ooPO0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1l0ooPO0003ooPO0003o`000?oh
7P3on1h000?o000000?on1h0o`000?oh7P001Ooh7P04o`0000?on1d000?o0000ooTM0?oi7@000ooi
7@04o`0000?onA`000?o0000ooTK0?oi6`000ooi6`04o`0000ConA/000Co0000ooTJ0?oi6P3onAX0
1_l00002ooLT00Co00005oooool00ol0003oooooo`000001ooooo`00Boooool2o`0000oooooo2?l0
0003ooTI0003o`000?oj6@3onQT000?onQT00ol00006ooTJ0004o`000?oi6`3onA/0ooTK00Co0000
1Ooi70000ol0003onA`0o`000002o`0000;onA`000?o0000ooPM0?oh7@000ooh7@000ol0003on1h0
o`000002o`0000;on1h000?o0000ooPN0?oh7P000ooh7P04o`0000?on1h000?o0000ooPO0?oh7`00
1?oh7`04o`0000Con1l000Co0000ooPO0?oh7`3on1l00ol00006ooPO0004o`000?oh7`3on1l0ooPO
00Co00001Ooh7P000ol0003on1h0ooPN0003o`000003ooPN0?l0003on1d000Gon1d000?o0000ooTM
0?l000000_l000000ooi703o0000ooTL0005ooTL0003o`000?oi6`3o000000;o00000_oi70000ol0
003onA/0ooTK0003ooTK00Co00001?og9@04o`0001cooooo0Ol00001ooooo`7o0000001=ooooo`03
o`000?oooooooooo00kooooo0_l00002ooDZ0003o`000?oi6@3onAT000?onAT000?o0000ooXI0?l0
00000_l00003ooXI0003o`000?oi6P3onAX000?onAX01?l00004ooTK0004o`000?oi703onA`0ooTL
00?o00001_oi70001?l0003on1d0ooPM0?oh7@04o`0000Gon1h000?o0000ooPN0?l000000_l00002
ooPN0003o`000?oh7P3on1h000?on1h000?o0000ooPO0?oh7`000ol000000ooh7`3o0000ooPO0005
ooPO00Co00000ooh7`000ol0003on1l0ooPO0003ooPO00Co00001?oh7P001?l0003on1h0ooPN0?oh
7P04o`0000Gon1h000Co0000ooPM0?oh7@3on1d01?l00005ooTL0004o`000?oi703onA`0ooTL00Co
00001_oi70000ol0003onA/0o`000002o`0000;omRH000?o0000ooLU0?og9@000ol0000Qooooo`;o
0000001>ooooo`03o`000?oooooooooo00oooooo1?l00003ooTI00Co00001_oj6@000ol0003onAX0
o`000002o`0000;onAX000?o0000ooTK0?oi6`000ooi6`04o`0000?onA`000?o0000ooTL0?oi7000
0ooi7004o`0000ConAd000Co0000ooPN0?oh7P3on1h00ol00006ooPN0004o`000?oh7P3on1h0ooPN
00Co00001Ooh7`000ol0003on1l0ooPO0003o`000003ooPO0?l0003on1l000Gon1l000?o0000ooPO
0?l000000_l00002ooPO0003o`000?oh7P3on1h000?on1h01?l00003ooPN0003o`000?oh7P3on1h0
00?on1h01?l00004ooTM0004o`000?oi703onA`0ooTL00Go00001?oi7@001?l0003onA`0ooTL0?oi
7005o`0000?omRH01?l0000Sooooo`?o0000001?ooooo`03o`000?oooooooooo00oooooo00?o0000
ooDY0?l000000ol00004ooTI00;o00000ooj6@03o`0000KonAX000?o0000ooTK0?l000000_l00002
ooTK0003o`000?oi703onA`000?onA`000?o0000ooTL0?l000000_l00002ooTL0003o`000?oi7@3o
nAd000?onAd01?l00003ooPN0003o`000?oh7P3on1h000?on1h01?l00004ooPN0004o`000?oh7`3o
n1l0ooPO00Co00001Ooh7`001?l0003on1l0ooPO0?oh7`04o`0000Kon1l000?o0000ooPN0?l00000
0_l000000ooh7P3o0000ooPN0005ooPN0003o`000?oh7P3o000000;o00000_oh7P000ol0003onAd0
ooTM0003ooTM00Co00000ooh7@000ol0003onAd0ooTM0003ooTM00Co00001?of9P04o`0002?ooooo
1?l00003ooooo`00D?ooool00ol0003oooooooooo`0?ooooo`05o`000?oe:@3omBT0ooDY0?l00000
1Ooi6@04o`0000?onQT000?o0000ooTJ0?oi6P000ooi6P02o`0000KonA/000Co0000ooTL0?oi703o
nA`01?l00005ooTL0003o`000?oi7@3o000000;o00000_oi7@000ol0003on1h0ooPN0003ooPN0003
o`000?oh7P3o000000;o00000_oh7P000ol0003on1h0ooPN0003ooPN00Co00001?oh7`001?l0003o
n1l0ooPO0?oh7`05o`0000Con1l000Co0000ooPO0?oh7`3on1l01?l00005ooPN0004o`000?oh7P3o
n1h0ooPN00Co00001_oh7P000ol0003onAd0o`000002o`000003ooPN0?l0003on1d000Gon1d000?o
0000ooTM0?l000000_l00002ooHW0003o`000?of9P3omRH000?o00008oooool4o`0000Oooooo001A
ooooo`;o00004?ooool5o`000004ooTI0?l0003o0000o`0000;onAT000?o0000ooXI0?oj6@000ooj
6@000ol0003onAX0o`000002o`0000;onAX000?o0000ooTK0?oi6`000ooi6`04o`0000ConA`000Co
0000ooTL0?oi703onA`00ol00006ooTM0004o`000?oh7P3on1h0ooPN00Co00001Ooh7P000ol0003o
n1h0o`000002o`0000;on1h000?o0000ooPO0?oh7`000ooh7`04o`0000?on1l000?o0000ooPO0?oh
7`000ooh7`04o`0000?on1h000?o0000ooPN0?oh7P000ooh7P04o`0000Con1h000Co0000ooPN0?oh
7P3on1h01?l00005ooPN0004o`000?oh7@3on1d0ooPM00Go00000oof9`04o`0002;ooooo1?l0000;
ooooo`00Doooool00ol0003oooooooooo`0>ooooo`03o`000?of:@3omRT000?o00001Ooi6@001?l0
003onQT0ooXI0?oj6@04o`0000GonAX000?o0000ooTK0?l000000_l00002ooTK0003o`000?oi703o
nA`000?onA`01?l00003ooTL0003o`000?oi7@3onAd000?onAd01?l00004ooPM0004o`000?oh7P3o
n1h0ooPN00Co00001Ooh7P000ol0003on1l0o`000002o`0000;on1h000?o0000ooPO0?oh7`000ooh
7`000ol0003on1l0o`000002o`0000;on1h000?o0000ooPN0?oh7P000ooh7P000ol0003on1h0o`00
0002o`0000;on1h000?o0000ooPN0?oh7P000ooh7P04o`0000Con1h000Co0000ooPN0?oh7P3on1h0
1Ol00003ooHX00Go00008oooool3o`0000oooooo001Dooooo`03o`000?oooooooooo00kooooo00?o
0000ooHY0?of:@000_of:@001?l0003onAT0ooTI0?oi6@05o`0000ConQT000Co0000ooTJ0?oi6P3o
nAX01?l00005ooTK0003o`000?oi703o000000;o00000_oi6`000ol0003onA`0ooTL0003ooTL0003
o`000?oi7@3o000000;o00000_oi7@000ol0003on1d0ooPM0003ooPM00Co00001?oh7P001?l0003o
n1h0ooPN0?oh7P03o`0000Kon1h000Co0000ooPO0?oh7`3on1l01?l00005ooPN0004o`000?oh7P3o
n1h0ooPN00Co00001Ooh7P000ol0003on1h0o`000002o`0000;on1l000?o0000ooPN0?oh7P000ooh
7P04o`0000ComRP01?l0000Tooooo`Co00004_ooool005Gooooo00?o0000ooooooooool03_ooool8
o`0000?onAT000?o0000ooXI0?oj6@000ooj6@04o`0000ConAT000Co0000ooTK0?oi6`3onA/01?l0
0005ooTK0004o`000?oi703onA`0ooTL00Co00001Ooi7@000ol0003on1d0o`000002o`0000;on1d0
00?o0000ooPN0?oh7P000ooh7P04o`0000?on1h000?o0000ooPN0?oh7P000ooh7P04o`0000Con1h0
00Co0000ooPN0?oh7P3on1h01Ol00004ooPN0004o`000?oh7P3on1h0ooPN00?o00001_oh7`000ol0
003on1h0o`000002o`0000;omRP000?o0000ooHX0?of:0000ol0000Tooooo`Co00005_ooool005Ko
oooo0_l0000@ooooo`05o`000?of:@3omRT0ooHY0?l000001Ooi6@000ol0003onQT0o`000002o`00
00;onQP000?o0000ooTI0?oi6@000ooi6@04o`0000ConAX000Co0000ooTK0?oi6`3onA/01Ol00004
ooTL0004o`000?oi7@3onAd0ooTM00Co00001Ooh7@000ol0003on1h0o`000002o`000003ooPN0?l0
003on1h000Gon1h000?o0000ooPN0?l000000_l000000ooh7P3o0000ooPN0005ooPN00Co00000_oh
7P000ol0003on1h0ooPN0004ooPN00Co00000ooh7`001?l0003on1l0ooPO0?oh7`05o`0000?omRP0
1?l0000Sooooo`Co00006_ooool005Sooooo00?o0000ooooooooool03_ooool5o`0000?onAT01?l0
0005ooXH0003o`000?oi6@3o000000;o00000_oi6@000ol0003onAX0ooTJ0003ooTJ00Co00000ooi
6`000ol0003onA`0ooTL0003ooTL00Co00001?oi7@001?l0003on1d0ooPM0?oh7@03o`0000Gon1h0
00Co0000ooPN0?oh7P3on1h01?l00005ooPN0003o`000?oh7P3on1h000?o000000?on1h0o`000?oh
7P001?oh7P000ol0003on1h0ooPN0003o`000003ooPO0?l0003on1l000Con1l01?l00004ooHY00Co
00008oooool4o`0001kooooo001Iooooo`03o`000?oooooooooo00kooooo00?o0000ooHY0?of:@00
1?l00004ooTI0004o`000?oj603onQP0ooXH00Co00001Ooi6@000ol0003onAX0o`000002o`0000;o
nAX000?o0000ooTK0?oi6`000ooi6`000ol0003onA`0o`000002o`000003ooTL0?l0003onAd000Go
nAd01?l00003ooPM0004o`000?oh7P3on1h0ooPN00Go00001?oh7P001?l0003on1h0ooPN0?oh7P04
o`0000Gon1h000Co0000ooPN0?oh7P3on1h01?l00005ooPO0003o`000?oh7`3o000000;o00000oof
:@000ol0003omRT0o`000002o`0002?ooooo1?l0000Rooooo`00F_ooool00ol0003oooooooooo`0>
ooooo`05o`000?of:@3omRT0ooHY0?l000001Ooi6@04o`0000ConQP000Co0000ooTI0?oi6@3onAT0
0ol00006ooTJ0004o`000?oi6`3onA/0ooTK00?o00001Ooi70000ol0003onAd0ooTM0003o`000003
ooTM0?l0003on1d000Con1d01?l00003ooPN0003o`000?oh7P3on1h000?on1h01?l00004ooPN0004
o`000?oh7P3on1h0ooPN00Go00001?oh7`001?l0003on1l0ooPO0?oh7`05o`0000?omRT00ol0000R
ooooo`Co00009_ooool005_ooooo0_l0000?ooooo`Go000000ConAT0o`000?l0003o00000_oi6@00
0ol0003onQP0ooXH0003ooXH00Co00000ooi6@000ol0003onAX0ooTJ0003ooTJ00Co00000ooi6`00
1?l0003onA`0ooTL0?oi7004o`0000GonAd000?o0000ooPM0?l000000_l00002ooTM0003o`000?oh
7P3on1h000?on1h000?o0000ooPN0?l000000_l00002ooPN0003o`000?oh7P3on1h000?on1h01?l0
0004ooPO0004o`000?oh7`3on1l0ooPO00Go00000_of:@06o`00027ooooo1?l0000Zooooo`00GOoo
ool00ol0003oooooooooo`0=ooooo`03o`000?of:@3omRT000?o00001Ooi6@000ol0003onQP0o`00
0002o`0000;onQP000?o0000ooTI0?oi6@000ooi6@000ol0003onAX0o`000002o`000003ooTJ0?l0
003onA/000ConA/01?l00004ooTL0004o`000?oi7@3onAd0ooTM00Co00001Ooi7@001?l0003on1h0
ooPN0?oh7P04o`0000Gon1h000?o0000ooPN0?l000000_l00002ooPO0003o`000?oh7`3on1l000?o
n1l01?l00003ooHY00Co00009?ooool3o`0002kooooo001Nooooo`03o`000?oooooooooo00gooooo
00?o0000ooHY0?of:@000_of:@001?l0003onAT0ooTI0?oi6@04o`0000GonQP000Co0000ooTI0?oi
6@3onAT01?l00004ooTJ0003o`000?oi6`3o000000;o00000_oi6`000ol0003onA`0ooTL0003ooTL
00Co00001?oi70001?l0003onAd0ooTM0?oi7@05o`0000Con1d000Co0000ooPN0?oh7P3on1h01?l0
0005ooPO0003o`000?oh7`3o000000;o00000_of:@000ol0003omRT0o`000002o`0002Cooooo1?l0
000aooooo`00Goooool00ol0003oooooooooo`0=ooooo`So00001?oj6@001?l0003onQP0ooXH0?oj
6005o`0000ConAT000?o0000ooTJ0?oi6P001?l00005ooTK0003o`000?oi703o000000;o00000_oi
70000ol0003onA`0ooTL0003ooTL00Co00000ooi7@000ol0003on1d0ooPM0003ooPM00Co00001?oh
7`001?l0003on1l0ooPO0?oh7`04o`0000?omRT00ol0000Sooooo`Co0000=Oooool0063ooooo0_l0
000?ooooo`05o`000?of:@3omRT0ooHY0?l000001Ooj6@04o`0000?onQP000?o0000ooTI0?oi6@00
0ooi6@03o`0000ConAX000Co0000ooTK0?oi6`3onA/01?l00005ooTL0003o`000?oi703o000000;o
00000_oi70000ol0003onAd0ooTM0003ooTM0003o`000?oh7@3o000000;o000000?on1h0o`000?oh
7`001Ooh7`04o`0000?omRT01?l0000Rooooo`Co0000>Oooool006;ooooo00?o0000ooooooooool0
3Oooool5o`000004ooXI0?l0003o0000o`0000;onQT000?o0000ooXH0?oj60000ooj60000ol0003o
nAT0o`000002o`000003ooXI0?l0003onAX000ConAX01?l00004ooTK0004o`000?oi703onA`0ooTL
00Co00001Ooi70001?l0003onAd0ooTM0?oi7@03o`0000Gon1h000?o0000ooPO0?oh7`000ol00002
ooHY0003o`000?of:@3o000000;o00008_ooool4o`0003gooooo001Sooooo`03o`000?oooooooooo
00gooooo00?o0000ooHY0?of:@000ol00005ooXI0004o`000?oj603onQP0ooXH00?o00001Ooj6@00
0ol0003onAX0o`000002o`0000;onAX000?o0000ooTK0?oi6`000ooi6`04o`0000ConA`000Co0000
ooTL0?oi703onA`01Ol00003ooPN0004o`000?oh7P3on1h0ooPN00Go00000oof:@03o`00027ooooo
1?l00011ooooo`00I?ooool00ol0003oooooooooo`0=ooooo`03o`000?of:@3omRT000;omRT000Co
0000ooXI0?oj6@3onQT01Ol00003ooXH0004o`000?oj6@3onQT0ooXI00Co00001Ooi6P000ol0003o
nA/0o`000002o`0000;onA/000?o0000ooTL0?oi70000ooi7004o`0000?onAd000Co0000ooPN0?oh
7P3on1h01Ol00003ooHX00Go00008?ooool4o`0004Gooooo001Uooooo`03o`000?oooooooooo00go
oooo2?l00004ooXI0003o`000?oj603onQP000Go00001?oj6@001?l0003onAX0ooTJ0?oi6P04o`00
00GonA/000?o0000ooTL0?l000000_l000000ooi703o0000ooTM0004ooTM00Co00001?of:004o`00
027ooooo1?l00019ooooo`00I_ooool2o`0000oooooo00Go0000ooHY0?of:@3omRT0o`000005ooXI
00?o00000ooj60000ol0003onQT0ooXI0003ooXI00Co00001?oi6P001?l0003onA/0ooTK0?oi6`04
o`0000ConA`000?o0000ooTM0?l000000_l00003ooHW0003o`000?of:03o000000;o00008Oooool4
o`0004gooooo001Xooooo`03o`000?oooooooooo00gooooo1Ol000001_oj6@3o0000o`000?l0003o
nQP0o`0000GonQP000?o0000ooXI0?l000000_l00002ooXI0003o`000?oi6P3onAX000?onAX01?l0
0004ooTK0003o`000?oi703onA`000Go00000oof9`03o`00027ooooo0ol0001Aooooo`00JOooool0
0ol0003oooooooooo`0>ooooo`03o`000?of:03o000000;o00001?oj60001?l0003onQP0ooXH0?oj
6004o`0000GonQT000?o0000ooTJ0?l000000_l00002ooTK0003o`000?oi6`3onA/000?onA/00ol0
0003ooHW00Go00008?ooool4o`0005Cooooo001Zooooo`03o`000?oooooooooo00kooooo1Ol00002
ooXH00Go00001?oj5`001?l0003onQT0ooXI0?oj6@04o`0000GonA/000?o0000ooTK0?l000000_l0
0002ooHV00Co00008Oooool4o`0005Sooooo001[ooooo`;o00003oooool00ol0003omRP0ooHX0003
o`0000ConQP000Co0000ooXG0?oj5`3onQL01Ol00004ooTI0004o`000?oi6`3onA/0ooTK00Co0000
00ComRH0o`000?l0003o00008Oooool4o`0005cooooo001]ooooo`03o`000?oooooooooo00gooooo
00Go0000ooHX0?of:03omRP0o`000004ooXH00Co00001?oj60001?l0003onAT0ooTI0?oi6@05o`00
00;ombD00ol0000Pooooo`Co0000H?ooool006kooooo00?o0000ooooooooool03Oooool5o`000003
ooXH0?l0003o000000;onQT000?o0000ooXH0?oj60000ooj6004o`0000;ombD01Ol0000Oooooo`Co
0000I?ooool006oooooo00?o0000ooooooooool03_ooool01?l0003omRT0o`000?l00005ooXI0003
o`000?oj603o000000;o00000oog9003o`00023ooooo1?l0001Xooooo`00L?ooool2o`0000kooooo
1Ol00003ooXI00Go000000Comb@0o`000?l0003o00007oooool4o`0006cooooo001booooo`03o`00
0?oooooooooo00_ooooo00Co0000oooooooooooooooo1?l00003ooLU00?o00007oooool3o`00073o
oooo001cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool4o`0001kooooo
1?l0001cooooo`00M?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0
001gooooo`00MOooool2o`0000Wooooo00?o0000ooooooooool07_ooool4o`0007_ooooo001goooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool4o`0007oooooo001hooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`0008?ooooo001iooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`0008Oooooo001jooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03_ooool4o`0008_ooooo001kooooo`;o00000oooool0
0ol0003oooooooooo`0;ooooo`?o0000Soooool007gooooo00Co0000oooooooooooo00002Oooool4
o`0009;ooooo001nooooo`03o`000?oooooo000000Gooooo1?l0002Fooooo`00Ooooool2o`000003
ooooool0003o000000;o0000V_ooool0083ooooo0_l0002Nooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00dOooool3o`0004cooooo003Booooo`03o`000?oooooooooo04_ooooo
001Pooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol0
0008ooooo`?o00000oooool3o`0000Cooooo0ol00002ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0000Sooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000?ooooo
0ol00002ooooo`?o000000?oooooo`000?l000001?l00002ooooo`Go00000oooool2o`0000Cooooo
00?o0000ooooooooool0B_ooool0063ooooo00?o0000ooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04o`000?oooooooooo
o`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0B_ooool0063ooooo00?o0000ooooool000000oooool3o`0000?ooooo00?o
0000ooooool000000_ooool5o`0000Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001;
ooooo`00Goooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooo
oooooooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000Sooooo0ol00003oooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003o
ooooooooool0003oooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000004_ooooo001Oooooo`05o`000?oooooo0000ooooool000000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00002Oooool00ol0003oooooooooo`02
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l00002ooooo`Co00002_ooool0
1?l0003oooooooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000?ooooo1?l0
00001?oooooo0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o000004[ooooo
001Oooooo`05o`000?oooooo0000ooooool000006_ooool01?l0003oooooooooool0000Dooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo057ooooo001Oooooo`Ko00006?ooool5o`0001Cooooo00?o0000ooooooooool0
2?ooool5o`0000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo057ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0832956, 0.053572, \
0.00360937, 0.00360937}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.14863 .19854 -11.913 -9 ]
[.14863 .19854 .08697 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.53436 .04684 -5.21689 -9 ]
[.53436 .04684 .78311 0 ]
[.76879 .09909 0 -6.15987 ]
[.76879 .09909 12 2.84013 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93374 .35168 0 -5.92116 ]
[.93374 .35168 6 3.07884 ]
[.02467 .26162 -18 -2.73937 ]
[.02467 .26162 0 6.26063 ]
[.0132 .33353 -18 -2.8002 ]
[.0132 .33353 0 6.1998 ]
[.00117 .40889 -18 -2.86424 ]
[.00117 .40889 0 6.13576 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15784 .20788 m
.16245 .21255 L
s
[(-5)] .14863 .19854 .98551 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54215 .0574 m
.54605 .06267 L
s
[(5)] .53436 .04684 .73896 1 Mshowa
.125 Mabswid
.19385 .19378 m
.19658 .19662 L
s
.23036 .17949 m
.23305 .18236 L
s
.26739 .16498 m
.27005 .16789 L
s
.30496 .15028 m
.30757 .15322 L
s
.38172 .12022 m
.38425 .12323 L
s
.42095 .10486 m
.42343 .10791 L
s
.46076 .08927 m
.46319 .09236 L
s
.50115 .07345 m
.50354 .07658 L
s
.12234 .22178 m
.12513 .22455 L
s
.08732 .2355 m
.09015 .23823 L
s
.05278 .24902 m
.05564 .25172 L
s
.58378 .0411 m
.58606 .0443 L
s
.62603 .02455 m
.62826 .0278 L
s
.66893 .00776 m
.67111 .01103 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75648 .10363 m
.75033 .1059 L
s
[(-5)] .76879 .09909 -1 .36886 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92123 .35563 m
.91497 .3576 L
s
[(5)] .93374 .35168 -1 .31581 Mshowa
.125 Mabswid
.77494 .13186 m
.77124 .1332 L
s
.7929 .15934 m
.7892 .16066 L
s
.81041 .18611 m
.80669 .18742 L
s
.82746 .21219 m
.82374 .21348 L
s
.86028 .2624 m
.85654 .26365 L
s
.87608 .28657 m
.87234 .2878 L
s
.8915 .31015 m
.88775 .31137 L
s
.90654 .33316 m
.90279 .33437 L
s
.73752 .07463 m
.73384 .07601 L
s
.71804 .04482 m
.71436 .04622 L
s
.698 .01417 m
.69433 .01559 L
s
.93557 .37756 m
.93181 .37873 L
s
.94957 .39899 m
.94581 .40014 L
s
.96325 .41992 m
.95949 .42106 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03689 .25684 m
.043 .25445 L
s
[(-30)] .02467 .26162 1 -0.39125 Mshowa
.02547 .3289 m
.03161 .32658 L
s
[(-20)] .0132 .33353 1 -0.37773 Mshowa
.0135 .40441 m
.01967 .40217 L
s
[(-10)] .00117 .40889 1 -0.3635 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(0)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03465 .27098 m
.03832 .26956 L
s
.03239 .28526 m
.03606 .28384 L
s
.0301 .29967 m
.03378 .29826 L
s
.0278 .31422 m
.03148 .31282 L
s
.02312 .34372 m
.02681 .34233 L
s
.02075 .35867 m
.02444 .3573 L
s
.01836 .37377 m
.02205 .37241 L
s
.01594 .38902 m
.01964 .38766 L
s
.01104 .41995 m
.01475 .41861 L
s
.00856 .43564 m
.01226 .43431 L
s
.00605 .45148 m
.00976 .45016 L
s
.00351 .46748 m
.00722 .46617 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .121 .21 r
.3945 .61459 .40512 .60371 .42106 .61881 .41056 .62885 Metetra
0 .271 .291 r
.41056 .62885 .42106 .61881 .43734 .63181 .42697 .64104 Metetra
0 .364 .275 r
.42697 .64104 .43734 .63181 .45395 .64285 .4437 .6513 Metetra
0 .427 .206 r
.4437 .6513 .45395 .64285 .47084 .65206 .46073 .65977 Metetra
0 .482 .117 r
.46073 .65977 .47084 .65206 .488 .65958 .47802 .66658 Metetra
0 .53 .019 r
.47802 .66658 .488 .65958 .50541 .66551 .49555 .67185 Metetra
.083 .572 0 r
.49555 .67185 .50541 .66551 .52304 .66998 .51331 .67572 Metetra
.181 .607 0 r
.51331 .67572 .52304 .66998 .54087 .6731 .53127 .67828 Metetra
.273 .637 0 r
.53127 .67828 .54087 .6731 .55889 .67496 .54942 .67965 Metetra
.356 .662 0 r
.54942 .67965 .55889 .67496 .57708 .67565 .56775 .6799 Metetra
.427 .683 0 r
.56775 .6799 .57708 .67565 .59543 .67523 .58623 .67911 Metetra
.487 .699 0 r
.58623 .67911 .59543 .67523 .61393 .67379 .60486 .67736 Metetra
.534 .712 0 r
.60486 .67736 .61393 .67379 .63256 .67136 .62363 .67468 Metetra
.567 .72 0 r
.62363 .67468 .63256 .67136 .6513 .66798 .64252 .67113 Metetra
.588 .725 0 r
.64252 .67113 .6513 .66798 .67015 .66368 .66153 .66672 Metetra
.594 .727 0 r
.66153 .66672 .67015 .66368 .6891 .65847 .68063 .66146 Metetra
.588 .725 0 r
.68063 .66146 .6891 .65847 .70813 .65233 .69983 .65535 Metetra
.567 .72 0 r
.69983 .65535 .70813 .65233 .72722 .64525 .7191 .64837 Metetra
.534 .712 0 r
.7191 .64837 .72722 .64525 .74637 .6372 .73843 .64048 Metetra
.487 .699 0 r
.73843 .64048 .74637 .6372 .76554 .62813 .7578 .63164 Metetra
.427 .683 0 r
.7578 .63164 .76554 .62813 .78473 .61797 .7772 .62178 Metetra
.356 .662 0 r
.7772 .62178 .78473 .61797 .8039 .60665 .79659 .61083 Metetra
.273 .637 0 r
.79659 .61083 .8039 .60665 .82303 .59409 .81597 .59869 Metetra
.181 .607 0 r
.81597 .59869 .82303 .59409 .84209 .58017 .83528 .58526 Metetra
.083 .572 0 r
.83528 .58526 .84209 .58017 .86105 .56478 .85451 .57042 Metetra
0 .53 .019 r
.85451 .57042 .86105 .56478 .87986 .54781 .87361 .55405 Metetra
0 .482 .117 r
.87361 .55405 .87986 .54781 .89848 .52912 .89254 .536 Metetra
0 .427 .206 r
.89254 .536 .89848 .52912 .91686 .50856 .91125 .51614 Metetra
0 .364 .275 r
.91125 .51614 .91686 .50856 .93496 .486 .92969 .49431 Metetra
0 .271 .291 r
.92969 .49431 .93496 .486 .9527 .46127 .9478 .47035 Metetra
0 .121 .21 r
.9478 .47035 .9527 .46127 .97003 .43424 .96552 .4441 Metetra
0 .271 .291 r
.38372 .62336 .3945 .61459 .41056 .62885 .3999 .6368 Metetra
0 .369 .271 r
.3999 .6368 .41056 .62885 .42697 .64104 .41644 .64821 Metetra
0 .437 .192 r
.41644 .64821 .42697 .64104 .4437 .6513 .43329 .65771 Metetra
0 .496 .091 r
.43329 .65771 .4437 .6513 .46073 .65977 .45044 .66546 Metetra
.023 .548 0 r
.45044 .66546 .46073 .65977 .47802 .66658 .46785 .67159 Metetra
.14 .593 0 r
.46785 .67159 .47802 .66658 .49555 .67185 .48551 .67623 Metetra
.254 .631 0 r
.48551 .67623 .49555 .67185 .51331 .67572 .50339 .67951 Metetra
.362 .664 0 r
.50339 .67951 .51331 .67572 .53127 .67828 .52147 .68154 Metetra
.46 .692 0 r
.52147 .68154 .53127 .67828 .54942 .67965 .53975 .68242 Metetra
.547 .715 0 r
.53975 .68242 .54942 .67965 .56775 .6799 .5582 .68225 Metetra
.621 .734 0 r
.5582 .68225 .56775 .6799 .58623 .67911 .57681 .6811 Metetra
.682 .749 0 r
.57681 .6811 .58623 .67911 .60486 .67736 .59557 .67905 Metetra
.73 .76 0 r
.59557 .67905 .60486 .67736 .62363 .67468 .61448 .67613 Metetra
.764 .768 0 r
.61448 .67613 .62363 .67468 .64252 .67113 .63351 .6724 Metetra
.773 .761 0 r
.63351 .6724 .64252 .67113 .66153 .66672 .65265 .66788 Metetra
.774 .757 0 r
.65265 .66788 .66153 .66672 .68063 .66146 .67191 .66258 Metetra
.773 .761 0 r
.67191 .66258 .68063 .66146 .69983 .65535 .69126 .65649 Metetra
.764 .768 0 r
.69126 .65649 .69983 .65535 .7191 .64837 .7107 .64959 Metetra
.73 .76 0 r
.7107 .64959 .7191 .64837 .73843 .64048 .73021 .64186 Metetra
.682 .749 0 r
.73021 .64186 .73843 .64048 .7578 .63164 .74977 .63323 Metetra
.621 .734 0 r
.74977 .63323 .7578 .63164 .7772 .62178 .76936 .62365 Metetra
.547 .715 0 r
.76936 .62365 .7772 .62178 .79659 .61083 .78897 .61304 Metetra
.46 .692 0 r
.78897 .61304 .79659 .61083 .81597 .59869 .80857 .6013 Metetra
.362 .664 0 r
.80857 .6013 .81597 .59869 .83528 .58526 .82813 .58833 Metetra
.254 .631 0 r
.82813 .58833 .83528 .58526 .85451 .57042 .84762 .57401 Metetra
.14 .593 0 r
.84762 .57401 .85451 .57042 .87361 .55405 .86699 .5582 Metetra
.023 .548 0 r
.86699 .5582 .87361 .55405 .89254 .536 .88622 .54078 Metetra
0 .496 .091 r
.88622 .54078 .89254 .536 .91125 .51614 .90524 .52157 Metetra
0 .437 .192 r
.90524 .52157 .91125 .51614 .92969 .49431 .92401 .50044 Metetra
0 .369 .271 r
.92401 .50044 .92969 .49431 .9478 .47035 .94248 .47721 Metetra
0 .271 .291 r
.94248 .47721 .9478 .47035 .96552 .4441 .96056 .45173 Metetra
0 .364 .276 r
.37279 .63014 .38372 .62336 .3999 .6368 .3891 .6428 Metetra
0 .437 .193 r
.3891 .6428 .3999 .6368 .41644 .64821 .40575 .65345 Metetra
0 .501 .082 r
.40575 .65345 .41644 .64821 .43329 .65771 .42272 .66222 Metetra
.044 .557 0 r
.42272 .66222 .43329 .65771 .45044 .66546 .43998 .66928 Metetra
.175 .605 0 r
.43998 .66928 .45044 .66546 .46785 .67159 .45751 .67476 Metetra
.304 .647 0 r
.45751 .67476 .46785 .67159 .48551 .67623 .47529 .6788 Metetra
.427 .683 0 r
.47529 .6788 .48551 .67623 .50339 .67951 .49329 .68151 Metetra
.54 .713 0 r
.49329 .68151 .50339 .67951 .52147 .68154 .51149 .68303 Metetra
.642 .739 0 r
.51149 .68303 .52147 .68154 .53975 .68242 .52989 .68345 Metetra
.73 .76 0 r
.52989 .68345 .53975 .68242 .5582 .68225 .54846 .68288 Metetra
.777 .75 0 r
.54846 .68288 .5582 .68225 .57681 .6811 .56719 .68138 Metetra
.791 .716 0 r
.56719 .68138 .57681 .6811 .59557 .67905 .58608 .67903 Metetra
.801 .69 0 r
.58608 .67903 .59557 .67905 .61448 .67613 .60511 .67588 Metetra
.809 .671 0 r
.60511 .67588 .61448 .67613 .63351 .6724 .62427 .67198 Metetra
.813 .659 0 r
.62427 .67198 .63351 .6724 .65265 .66788 .64356 .66735 Metetra
.814 .655 0 r
.64356 .66735 .65265 .66788 .67191 .66258 .66296 .662 Metetra
.813 .659 0 r
.66296 .662 .67191 .66258 .69126 .65649 .68246 .65592 Metetra
.809 .671 0 r
.68246 .65592 .69126 .65649 .7107 .64959 .70205 .6491 Metetra
.801 .69 0 r
.70205 .6491 .7107 .64959 .73021 .64186 .72173 .6415 Metetra
.791 .716 0 r
.72173 .6415 .73021 .64186 .74977 .63323 .74146 .63307 Metetra
.777 .75 0 r
.74146 .63307 .74977 .63323 .76936 .62365 .76125 .62374 Metetra
.73 .76 0 r
.76125 .62374 .76936 .62365 .78897 .61304 .78106 .61345 Metetra
.642 .739 0 r
.78106 .61345 .78897 .61304 .80857 .6013 .80087 .60208 Metetra
.54 .713 0 r
.80087 .60208 .80857 .6013 .82813 .58833 .82066 .58954 Metetra
.427 .683 0 r
.82066 .58954 .82813 .58833 .84762 .57401 .84039 .57571 Metetra
.304 .647 0 r
.84039 .57571 .84762 .57401 .86699 .5582 .86003 .56044 Metetra
.175 .605 0 r
.86003 .56044 .86699 .5582 .88622 .54078 .87953 .54359 Metetra
.044 .557 0 r
.87953 .54359 .88622 .54078 .90524 .52157 .89886 .52501 Metetra
0 .501 .082 r
.89886 .52501 .90524 .52157 .92401 .50044 .91794 .50454 Metetra
0 .437 .193 r
.91794 .50454 .92401 .50044 .94248 .47721 .93674 .48201 Metetra
0 .364 .276 r
.93674 .48201 .94248 .47721 .96056 .45173 .95518 .45724 Metetra
0 .427 .206 r
.36173 .63505 .37279 .63014 .3891 .6428 .37815 .64697 Metetra
0 .496 .091 r
.37815 .64697 .3891 .6428 .40575 .65345 .39491 .6569 Metetra
.044 .557 0 r
.39491 .6569 .40575 .65345 .42272 .66222 .41199 .66498 Metetra
.187 .609 0 r
.41199 .66498 .42272 .66222 .43998 .66928 .42937 .67138 Metetra
.33 .655 0 r
.42937 .67138 .43998 .66928 .45751 .67476 .44701 .67624 Metetra
.467 .694 0 r
.44701 .67624 .45751 .67476 .47529 .6788 .4649 .6797 Metetra
.594 .727 0 r
.4649 .6797 .47529 .6788 .49329 .68151 .48301 .68188 Metetra
.709 .755 0 r
.48301 .68188 .49329 .68151 .51149 .68303 .50133 .68291 Metetra
.779 .746 0 r
.50133 .68291 .51149 .68303 .52989 .68345 .51984 .68289 Metetra
.798 .698 0 r
.51984 .68289 .52989 .68345 .54846 .68288 .53853 .68193 Metetra
.814 .656 0 r
.53853 .68193 .54846 .68288 .56719 .68138 .55738 .6801 Metetra
.827 .621 0 r
.55738 .6801 .56719 .68138 .58608 .67903 .57639 .67747 Metetra
.836 .594 0 r
.57639 .67747 .58608 .67903 .60511 .67588 .59554 .6741 Metetra
.843 .574 0 r
.59554 .6741 .60511 .67588 .62427 .67198 .61483 .67003 Metetra
.847 .563 0 r
.61483 .67003 .62427 .67198 .64356 .66735 .63425 .66528 Metetra
.848 .559 0 r
.63425 .66528 .64356 .66735 .66296 .662 .65378 .65988 Metetra
.847 .563 0 r
.65378 .65988 .66296 .662 .68246 .65592 .67343 .6538 Metetra
.843 .574 0 r
.67343 .6538 .68246 .65592 .70205 .6491 .69317 .64704 Metetra
.836 .594 0 r
.69317 .64704 .70205 .6491 .72173 .6415 .713 .63956 Metetra
.827 .621 0 r
.713 .63956 .72173 .6415 .74146 .63307 .73291 .63131 Metetra
.814 .656 0 r
.73291 .63131 .74146 .63307 .76125 .62374 .75287 .62222 Metetra
.798 .698 0 r
.75287 .62222 .76125 .62374 .78106 .61345 .77287 .61222 Metetra
.779 .746 0 r
.77287 .61222 .78106 .61345 .80087 .60208 .79289 .6012 Metetra
.709 .755 0 r
.79289 .6012 .80087 .60208 .82066 .58954 .81289 .58906 Metetra
.594 .727 0 r
.81289 .58906 .82066 .58954 .84039 .57571 .83286 .57567 Metetra
.467 .694 0 r
.83286 .57567 .84039 .57571 .86003 .56044 .85274 .56089 Metetra
.33 .655 0 r
.85274 .56089 .86003 .56044 .87953 .54359 .87251 .54459 Metetra
.187 .609 0 r
.87251 .54459 .87953 .54359 .89886 .52501 .89212 .52659 Metetra
.044 .557 0 r
.89212 .52659 .89886 .52501 .91794 .50454 .91151 .50674 Metetra
0 .496 .091 r
.91151 .50674 .91794 .50454 .93674 .48201 .93062 .48486 Metetra
0 .427 .206 r
.93062 .48486 .93674 .48201 .95518 .45724 .9494 .46077 Metetra
0 .482 .118 r
.35054 .63821 .36173 .63505 .37815 .64697 .36706 .64943 Metetra
.022 .548 0 r
.36706 .64943 .37815 .64697 .39491 .6569 .38393 .65868 Metetra
.175 .605 0 r
.38393 .65868 .39491 .6569 .41199 .66498 .40112 .66612 Metetra
.329 .655 0 r
.40112 .66612 .41199 .66498 .42937 .67138 .41861 .6719 Metetra
.48 .697 0 r
.41861 .6719 .42937 .67138 .44701 .67624 .43636 .67617 Metetra
.621 .734 0 r
.43636 .67617 .44701 .67624 .4649 .6797 .45436 .67908 Metetra
.75 .765 0 r
.45436 .67908 .4649 .6797 .48301 .68188 .47258 .68076 Metetra
.791 .717 0 r
.47258 .68076 .48301 .68188 .50133 .68291 .49101 .68133 Metetra
.813 .659 0 r
.49101 .68133 .50133 .68291 .51984 .68289 .50963 .6809 Metetra
.831 .609 0 r
.50963 .6809 .51984 .68289 .53853 .68193 .52842 .67956 Metetra
.845 .567 0 r
.52842 .67956 .53853 .68193 .55738 .6801 .54739 .67741 Metetra
.857 .532 0 r
.54739 .67741 .55738 .6801 .57639 .67747 .56651 .67452 Metetra
.865 .505 0 r
.56651 .67452 .57639 .67747 .59554 .6741 .58578 .67093 Metetra
.871 .486 0 r
.58578 .67093 .59554 .6741 .61483 .67003 .60519 .6667 Metetra
.875 .475 0 r
.60519 .6667 .61483 .67003 .63425 .66528 .62473 .66184 Metetra
.876 .471 0 r
.62473 .66184 .63425 .66528 .65378 .65988 .6444 .65638 Metetra
.875 .475 0 r
.6444 .65638 .65378 .65988 .67343 .6538 .66418 .6503 Metetra
.871 .486 0 r
.66418 .6503 .67343 .6538 .69317 .64704 .68407 .64359 Metetra
.865 .505 0 r
.68407 .64359 .69317 .64704 .713 .63956 .70405 .63621 Metetra
.857 .532 0 r
.70405 .63621 .713 .63956 .73291 .63131 .72412 .62812 Metetra
.845 .567 0 r
.72412 .62812 .73291 .63131 .75287 .62222 .74425 .61924 Metetra
.831 .609 0 r
.74425 .61924 .75287 .62222 .77287 .61222 .76443 .6095 Metetra
.813 .659 0 r
.76443 .6095 .77287 .61222 .79289 .6012 .78464 .59879 Metetra
.791 .717 0 r
.78464 .59879 .79289 .6012 .81289 .58906 .80485 .58701 Metetra
.75 .765 0 r
.80485 .58701 .81289 .58906 .83286 .57567 .82503 .57403 Metetra
.621 .734 0 r
.82503 .57403 .83286 .57567 .85274 .56089 .84516 .55971 Metetra
.48 .697 0 r
.84516 .55971 .85274 .56089 .87251 .54459 .86518 .54391 Metetra
.329 .655 0 r
.86518 .54391 .87251 .54459 .89212 .52659 .88505 .52645 Metetra
.175 .605 0 r
.88505 .52645 .89212 .52659 .91151 .50674 .90472 .50717 Metetra
.022 .548 0 r
.90472 .50717 .91151 .50674 .93062 .48486 .92414 .48589 Metetra
0 .482 .118 r
.92414 .48589 .93062 .48486 .9494 .46077 .94324 .46242 Metetra
0 .53 .019 r
.33922 .63975 .35054 .63821 .36706 .64943 .35584 .65031 Metetra
.139 .593 0 r
.35584 .65031 .36706 .64943 .38393 .65868 .37281 .65892 Metetra
.304 .647 0 r
.37281 .65892 .38393 .65868 .40112 .66612 .39011 .66575 Metetra
.466 .694 0 r
.39011 .66575 .40112 .66612 .41861 .6719 .4077 .67095 Metetra
.621 .734 0 r
.4077 .67095 .41861 .6719 .43636 .67617 .42555 .67468 Metetra
.763 .768 0 r
.42555 .67468 .43636 .67617 .45436 .67908 .44366 .67708 Metetra
.797 .701 0 r
.44366 .67708 .45436 .67908 .47258 .68076 .46198 .67829 Metetra
.821 .636 0 r
.46198 .67829 .47258 .68076 .49101 .68133 .48052 .67843 Metetra
.841 .578 0 r
.48052 .67843 .49101 .68133 .50963 .6809 .49924 .67761 Metetra
.858 .528 0 r
.49924 .67761 .50963 .6809 .52842 .67956 .51815 .67593 Metetra
.871 .486 0 r
.51815 .67593 .52842 .67956 .54739 .67741 .53722 .67348 Metetra
.882 .452 0 r
.53722 .67348 .54739 .67741 .56651 .67452 .55646 .67033 Metetra
.889 .426 0 r
.55646 .67033 .56651 .67452 .58578 .67093 .57584 .66653 Metetra
.895 .408 0 r
.57584 .66653 .58578 .67093 .60519 .6667 .59537 .66214 Metetra
.898 .397 0 r
.59537 .66214 .60519 .6667 .62473 .66184 .61503 .65717 Metetra
.899 .393 0 r
.61503 .65717 .62473 .66184 .6444 .65638 .63482 .65165 Metetra
.898 .397 0 r
.63482 .65165 .6444 .65638 .66418 .6503 .65473 .64556 Metetra
.895 .408 0 r
.65473 .64556 .66418 .6503 .68407 .64359 .67476 .63889 Metetra
.889 .426 0 r
.67476 .63889 .68407 .64359 .70405 .63621 .69488 .6316 Metetra
.882 .452 0 r
.69488 .6316 .70405 .63621 .72412 .62812 .7151 .62364 Metetra
.871 .486 0 r
.7151 .62364 .72412 .62812 .74425 .61924 .7354 .61495 Metetra
.858 .528 0 r
.7354 .61495 .74425 .61924 .76443 .6095 .75575 .60544 Metetra
.841 .578 0 r
.75575 .60544 .76443 .6095 .78464 .59879 .77614 .59501 Metetra
.821 .636 0 r
.77614 .59501 .78464 .59879 .80485 .58701 .79655 .58356 Metetra
.797 .701 0 r
.79655 .58356 .80485 .58701 .82503 .57403 .81694 .57095 Metetra
.763 .768 0 r
.81694 .57095 .82503 .57403 .84516 .55971 .83729 .55704 Metetra
.621 .734 0 r
.83729 .55704 .84516 .55971 .86518 .54391 .85754 .54168 Metetra
.466 .694 0 r
.85754 .54168 .86518 .54391 .88505 .52645 .87767 .52471 Metetra
.304 .647 0 r
.87767 .52471 .88505 .52645 .90472 .50717 .89761 .50595 Metetra
.139 .593 0 r
.89761 .50595 .90472 .50717 .92414 .48589 .91732 .48522 Metetra
0 .53 .019 r
.91732 .48522 .92414 .48589 .94324 .46242 .93672 .46233 Metetra
.082 .572 0 r
.32778 .63975 .33922 .63975 .35584 .65031 .34449 .64971 Metetra
.254 .631 0 r
.34449 .64971 .35584 .65031 .37281 .65892 .36156 .65774 Metetra
.427 .683 0 r
.36156 .65774 .37281 .65892 .39011 .66575 .37896 .66401 Metetra
.594 .727 0 r
.37896 .66401 .39011 .66575 .4077 .67095 .39664 .66868 Metetra
.75 .765 0 r
.39664 .66868 .4077 .67095 .42555 .67468 .4146 .6719 Metetra
.797 .702 0 r
.4146 .6719 .42555 .67468 .44366 .67708 .4328 .67383 Metetra
.824 .629 0 r
.4328 .67383 .44366 .67708 .46198 .67829 .45123 .6746 Metetra
.846 .563 0 r
.45123 .6746 .46198 .67829 .48052 .67843 .46987 .67434 Metetra
.865 .505 0 r
.46987 .67434 .48052 .67843 .49924 .67761 .4887 .67315 Metetra
.88 .456 0 r
.4887 .67315 .49924 .67761 .51815 .67593 .50771 .67115 Metetra
.893 .415 0 r
.50771 .67115 .51815 .67593 .53722 .67348 .52689 .66842 Metetra
.902 .382 0 r
.52689 .66842 .53722 .67348 .55646 .67033 .54623 .66503 Metetra
.909 .357 0 r
.54623 .66503 .55646 .67033 .57584 .66653 .56573 .66104 Metetra
.914 .339 0 r
.56573 .66104 .57584 .66653 .59537 .66214 .58537 .65649 Metetra
.917 .329 0 r
.58537 .65649 .59537 .66214 .61503 .65717 .60515 .65142 Metetra
.918 .326 0 r
.60515 .65142 .61503 .65717 .63482 .65165 .62506 .64583 Metetra
.917 .329 0 r
.62506 .64583 .63482 .65165 .65473 .64556 .64509 .63972 Metetra
.914 .339 0 r
.64509 .63972 .65473 .64556 .67476 .63889 .66525 .63308 Metetra
.909 .357 0 r
.66525 .63308 .67476 .63889 .69488 .6316 .68552 .62586 Metetra
.902 .382 0 r
.68552 .62586 .69488 .6316 .7151 .62364 .70588 .61802 Metetra
.893 .415 0 r
.70588 .61802 .7151 .62364 .7354 .61495 .72633 .60948 Metetra
.88 .456 0 r
.72633 .60948 .7354 .61495 .75575 .60544 .74684 .60017 Metetra
.865 .505 0 r
.74684 .60017 .75575 .60544 .77614 .59501 .76741 .58999 Metetra
.846 .563 0 r
.76741 .58999 .77614 .59501 .79655 .58356 .78801 .57883 Metetra
.824 .629 0 r
.78801 .57883 .79655 .58356 .81694 .57095 .8086 .56654 Metetra
.797 .702 0 r
.8086 .56654 .81694 .57095 .83729 .55704 .82915 .553 Metetra
.75 .765 0 r
.82915 .553 .83729 .55704 .85754 .54168 .84964 .53804 Metetra
.594 .727 0 r
.84964 .53804 .85754 .54168 .87767 .52471 .87 .52151 Metetra
.427 .683 0 r
.87 .52151 .87767 .52471 .89761 .50595 .8902 .50321 Metetra
.254 .631 0 r
.8902 .50321 .89761 .50595 .91732 .48522 .91017 .48297 Metetra
.082 .572 0 r
.91017 .48297 .91732 .48522 .93672 .46233 .92986 .46059 Metetra
.18 .607 0 r
.31622 .63833 .32778 .63975 .34449 .64971 .33302 .64774 Metetra
.361 .664 0 r
.33302 .64774 .34449 .64971 .36156 .65774 .35018 .65524 Metetra
.54 .713 0 r
.35018 .65524 .36156 .65774 .37896 .66401 .36767 .661 Metetra
.709 .755 0 r
.36767 .661 .37896 .66401 .39664 .66868 .38545 .66518 Metetra
.791 .717 0 r
.38545 .66518 .39664 .66868 .4146 .6719 .40351 .66794 Metetra
.821 .637 0 r
.40351 .66794 .4146 .6719 .4328 .67383 .42181 .66944 Metetra
.846 .563 0 r
.42181 .66944 .4328 .67383 .45123 .6746 .44033 .66981 Metetra
.868 .498 0 r
.44033 .66981 .45123 .6746 .46987 .67434 .45907 .66917 Metetra
.885 .441 0 r
.45907 .66917 .46987 .67434 .4887 .67315 .478 .66766 Metetra
.899 .393 0 r
.478 .66766 .4887 .67315 .50771 .67115 .49712 .66536 Metetra
.91 .354 0 r
.49712 .66536 .50771 .67115 .52689 .66842 .5164 .66237 Metetra
.919 .322 0 r
.5164 .66237 .52689 .66842 .54623 .66503 .53584 .65875 Metetra
.926 .298 0 r
.53584 .65875 .54623 .66503 .56573 .66104 .55545 .65458 Metetra
.93 .282 0 r
.55545 .65458 .56573 .66104 .58537 .65649 .57519 .64988 Metetra
.933 .272 0 r
.57519 .64988 .58537 .65649 .60515 .65142 .59509 .6447 Metetra
.934 .268 0 r
.59509 .6447 .60515 .65142 .62506 .64583 .61512 .63905 Metetra
.933 .272 0 r
.61512 .63905 .62506 .64583 .64509 .63972 .63527 .63291 Metetra
.93 .282 0 r
.63527 .63291 .64509 .63972 .66525 .63308 .65556 .62628 Metetra
.926 .298 0 r
.65556 .62628 .66525 .63308 .68552 .62586 .67596 .61912 Metetra
.919 .322 0 r
.67596 .61912 .68552 .62586 .70588 .61802 .69646 .61137 Metetra
.91 .354 0 r
.69646 .61137 .70588 .61802 .72633 .60948 .71706 .60296 Metetra
.899 .393 0 r
.71706 .60296 .72633 .60948 .74684 .60017 .73773 .59383 Metetra
.885 .441 0 r
.73773 .59383 .74684 .60017 .76741 .58999 .75846 .58386 Metetra
.868 .498 0 r
.75846 .58386 .76741 .58999 .78801 .57883 .77923 .57293 Metetra
.846 .563 0 r
.77923 .57293 .78801 .57883 .8086 .56654 .80001 .56093 Metetra
.821 .637 0 r
.80001 .56093 .8086 .56654 .82915 .553 .82077 .54771 Metetra
.791 .717 0 r
.82077 .54771 .82915 .553 .84964 .53804 .84146 .5331 Metetra
.709 .755 0 r
.84146 .5331 .84964 .53804 .87 .52151 .86206 .51694 Metetra
.54 .713 0 r
.86206 .51694 .87 .52151 .8902 .50321 .8825 .49905 Metetra
.361 .664 0 r
.8825 .49905 .8902 .50321 .91017 .48297 .90273 .47924 Metetra
.18 .607 0 r
.90273 .47924 .91017 .48297 .92986 .46059 .92269 .45731 Metetra
.272 .637 0 r
.30455 .63558 .31622 .63833 .33302 .64774 .32143 .6445 Metetra
.459 .692 0 r
.32143 .6445 .33302 .64774 .35018 .65524 .33868 .65152 Metetra
.641 .739 0 r
.33868 .65152 .35018 .65524 .36767 .661 .35625 .65681 Metetra
.779 .747 0 r
.35625 .65681 .36767 .661 .38545 .66518 .37412 .66056 Metetra
.813 .66 0 r
.37412 .66056 .38545 .66518 .40351 .66794 .39227 .66291 Metetra
.841 .579 0 r
.39227 .66291 .40351 .66794 .42181 .66944 .41067 .66401 Metetra
.865 .506 0 r
.41067 .66401 .42181 .66944 .44033 .66981 .42929 .66402 Metetra
.885 .441 0 r
.42929 .66402 .44033 .66981 .45907 .66917 .44812 .66305 Metetra
.901 .386 0 r
.44812 .66305 .45907 .66917 .478 .66766 .46715 .66123 Metetra
.914 .34 0 r
.46715 .66123 .478 .66766 .49712 .66536 .48636 .65866 Metetra
.925 .302 0 r
.48636 .65866 .49712 .66536 .5164 .66237 .50575 .65543 Metetra
.933 .272 0 r
.50575 .65543 .5164 .66237 .53584 .65875 .5253 .65161 Metetra
.939 .249 0 r
.5253 .65161 .53584 .65875 .55545 .65458 .545 .64726 Metetra
.943 .233 0 r
.545 .64726 .55545 .65458 .57519 .64988 .56486 .64243 Metetra
.945 .224 0 r
.56486 .64243 .57519 .64988 .59509 .6447 .58486 .63714 Metetra
.946 .221 0 r
.58486 .63714 .59509 .6447 .61512 .63905 .605 .63142 Metetra
.945 .224 0 r
.605 .63142 .61512 .63905 .63527 .63291 .62528 .62525 Metetra
.943 .233 0 r
.62528 .62525 .63527 .63291 .65556 .62628 .64569 .61861 Metetra
.939 .249 0 r
.64569 .61861 .65556 .62628 .67596 .61912 .66621 .61148 Metetra
.933 .272 0 r
.66621 .61148 .67596 .61912 .69646 .61137 .68685 .6038 Metetra
.925 .302 0 r
.68685 .6038 .69646 .61137 .71706 .60296 .70759 .59551 Metetra
.914 .34 0 r
.70759 .59551 .71706 .60296 .73773 .59383 .72841 .58651 Metetra
.901 .386 0 r
.72841 .58651 .73773 .59383 .75846 .58386 .7493 .57671 Metetra
.885 .441 0 r
.7493 .57671 .75846 .58386 .77923 .57293 .77024 .566 Metetra
.865 .506 0 r
.77024 .566 .77923 .57293 .80001 .56093 .7912 .55423 Metetra
.841 .579 0 r
.7912 .55423 .80001 .56093 .82077 .54771 .81215 .54127 Metetra
.813 .66 0 r
.81215 .54127 .82077 .54771 .84146 .5331 .83305 .52696 Metetra
.779 .747 0 r
.83305 .52696 .84146 .5331 .86206 .51694 .85386 .51112 Metetra
.641 .739 0 r
.85386 .51112 .86206 .51694 .8825 .49905 .87452 .49357 Metetra
.459 .692 0 r
.87452 .49357 .8825 .49905 .90273 .47924 .895 .47413 Metetra
.272 .637 0 r
.895 .47413 .90273 .47924 .92269 .45731 .91521 .45258 Metetra
.355 .662 0 r
.29277 .63157 .30455 .63558 .32143 .6445 .30972 .64006 Metetra
.546 .715 0 r
.30972 .64006 .32143 .6445 .33868 .65152 .32705 .64666 Metetra
.729 .76 0 r
.32705 .64666 .33868 .65152 .35625 .65681 .3447 .65155 Metetra
.798 .698 0 r
.3447 .65155 .35625 .65681 .37412 .66056 .36266 .65491 Metetra
.831 .61 0 r
.36266 .65491 .37412 .66056 .39227 .66291 .3809 .65689 Metetra
.858 .529 0 r
.3809 .65689 .39227 .66291 .41067 .66401 .39938 .65765 Metetra
.88 .456 0 r
.39938 .65765 .41067 .66401 .42929 .66402 .4181 .65733 Metetra
.899 .393 0 r
.4181 .65733 .42929 .66402 .44812 .66305 .43702 .65607 Metetra
.914 .34 0 r
.43702 .65607 .44812 .66305 .46715 .66123 .45615 .65398 Metetra
.927 .295 0 r
.45615 .65398 .46715 .66123 .48636 .65866 .47546 .65116 Metetra
.936 .259 0 r
.47546 .65116 .48636 .65866 .50575 .65543 .49494 .64771 Metetra
.944 .23 0 r
.49494 .64771 .50575 .65543 .5253 .65161 .51459 .6437 Metetra
.949 .209 0 r
.51459 .6437 .5253 .65161 .545 .64726 .5344 .63919 Metetra
.953 .194 0 r
.5344 .63919 .545 .64726 .56486 .64243 .55436 .63422 Metetra
.955 .186 0 r
.55436 .63422 .56486 .64243 .58486 .63714 .57447 .62883 Metetra
.956 .183 0 r
.57447 .62883 .58486 .63714 .605 .63142 .59472 .62304 Metetra
.955 .186 0 r
.59472 .62304 .605 .63142 .62528 .62525 .61512 .61682 Metetra
.953 .194 0 r
.61512 .61682 .62528 .62525 .64569 .61861 .63564 .61018 Metetra
.949 .209 0 r
.63564 .61018 .64569 .61861 .66621 .61148 .65629 .60307 Metetra
.944 .23 0 r
.65629 .60307 .66621 .61148 .68685 .6038 .67706 .59543 Metetra
.936 .259 0 r
.67706 .59543 .68685 .6038 .70759 .59551 .69794 .58721 Metetra
.927 .295 0 r
.69794 .58721 .70759 .59551 .72841 .58651 .7189 .57832 Metetra
.914 .34 0 r
.7189 .57832 .72841 .58651 .7493 .57671 .73995 .56866 Metetra
.899 .393 0 r
.73995 .56866 .7493 .57671 .77024 .566 .76105 .55811 Metetra
.88 .456 0 r
.76105 .55811 .77024 .566 .7912 .55423 .78218 .54653 Metetra
.858 .529 0 r
.78218 .54653 .7912 .55423 .81215 .54127 .80331 .53379 Metetra
.831 .61 0 r
.80331 .53379 .81215 .54127 .83305 .52696 .8244 .51971 Metetra
.798 .698 0 r
.8244 .51971 .83305 .52696 .85386 .51112 .84541 .50414 Metetra
.729 .76 0 r
.84541 .50414 .85386 .51112 .87452 .49357 .86629 .48687 Metetra
.546 .715 0 r
.86629 .48687 .87452 .49357 .895 .47413 .88699 .46772 Metetra
.355 .662 0 r
.88699 .46772 .895 .47413 .91521 .45258 .90744 .44649 Metetra
.426 .683 0 r
.28087 .62638 .29277 .63157 .30972 .64006 .2979 .63449 Metetra
.62 .734 0 r
.2979 .63449 .30972 .64006 .32705 .64666 .31529 .64073 Metetra
.777 .75 0 r
.31529 .64073 .32705 .64666 .3447 .65155 .33303 .64528 Metetra
.814 .656 0 r
.33303 .64528 .3447 .65155 .36266 .65491 .35107 .6483 Metetra
.845 .567 0 r
.35107 .6483 .36266 .65491 .3809 .65689 .36939 .64997 Metetra
.871 .487 0 r
.36939 .64997 .3809 .65689 .39938 .65765 .38796 .65043 Metetra
.893 .415 0 r
.38796 .65043 .39938 .65765 .4181 .65733 .40676 .64983 Metetra
.91 .354 0 r
.40676 .64983 .4181 .65733 .43702 .65607 .42578 .6483 Metetra
.925 .302 0 r
.42578 .6483 .43702 .65607 .45615 .65398 .445 .64597 Metetra
.936 .259 0 r
.445 .64597 .45615 .65398 .47546 .65116 .4644 .64293 Metetra
.945 .224 0 r
.4644 .64293 .47546 .65116 .49494 .64771 .48398 .63929 Metetra
.952 .197 0 r
.48398 .63929 .49494 .64771 .51459 .6437 .50373 .6351 Metetra
.957 .177 0 r
.50373 .6351 .51459 .6437 .5344 .63919 .52364 .63044 Metetra
.961 .163 0 r
.52364 .63044 .5344 .63919 .55436 .63422 .5437 .62536 Metetra
.963 .155 0 r
.5437 .62536 .55436 .63422 .57447 .62883 .56392 .61987 Metetra
.964 .152 0 r
.56392 .61987 .57447 .62883 .59472 .62304 .58428 .61399 Metetra
.963 .155 0 r
.58428 .61399 .59472 .62304 .61512 .61682 .60479 .60773 Metetra
.961 .163 0 r
.60479 .60773 .61512 .61682 .63564 .61018 .62543 .60106 Metetra
.957 .177 0 r
.62543 .60106 .63564 .61018 .65629 .60307 .6462 .59395 Metetra
.952 .197 0 r
.6462 .59395 .65629 .60307 .67706 .59543 .6671 .58634 Metetra
.945 .224 0 r
.6671 .58634 .67706 .59543 .69794 .58721 .6881 .57817 Metetra
.936 .259 0 r
.6881 .57817 .69794 .58721 .7189 .57832 .70921 .56935 Metetra
.925 .302 0 r
.70921 .56935 .7189 .57832 .73995 .56866 .7304 .55978 Metetra
.91 .354 0 r
.7304 .55978 .73995 .56866 .76105 .55811 .75166 .54935 Metetra
.893 .415 0 r
.75166 .54935 .76105 .55811 .78218 .54653 .77295 .53791 Metetra
.871 .487 0 r
.77295 .53791 .78218 .54653 .80331 .53379 .79425 .52533 Metetra
.845 .567 0 r
.79425 .52533 .80331 .53379 .8244 .51971 .81552 .51144 Metetra
.814 .656 0 r
.81552 .51144 .8244 .51971 .84541 .50414 .83672 .49606 Metetra
.777 .75 0 r
.83672 .49606 .84541 .50414 .86629 .48687 .85781 .47901 Metetra
.62 .734 0 r
.85781 .47901 .86629 .48687 .88699 .46772 .87872 .46009 Metetra
.426 .683 0 r
.87872 .46009 .88699 .46772 .90744 .44649 .8994 .4391 Metetra
.486 .699 0 r
.26887 .62005 .28087 .62638 .2979 .63449 .28596 .62786 Metetra
.681 .749 0 r
.28596 .62786 .2979 .63449 .31529 .64073 .30342 .63381 Metetra
.791 .717 0 r
.30342 .63381 .31529 .64073 .33303 .64528 .32123 .63806 Metetra
.827 .621 0 r
.32123 .63806 .33303 .64528 .35107 .6483 .33934 .64081 Metetra
.857 .532 0 r
.33934 .64081 .35107 .6483 .36939 .64997 .35774 .6422 Metetra
.882 .453 0 r
.35774 .6422 .36939 .64997 .38796 .65043 .37639 .64241 Metetra
.902 .382 0 r
.37639 .64241 .38796 .65043 .40676 .64983 .39528 .64157 Metetra
.919 .322 0 r
.39528 .64157 .40676 .64983 .42578 .6483 .41439 .63983 Metetra
.933 .272 0 r
.41439 .63983 .42578 .6483 .445 .64597 .4337 .63729 Metetra
.944 .23 0 r
.4337 .63729 .445 .64597 .4644 .64293 .45319 .63406 Metetra
.952 .197 0 r
.45319 .63406 .4644 .64293 .48398 .63929 .47287 .63024 Metetra
.959 .171 0 r
.47287 .63024 .48398 .63929 .50373 .6351 .49271 .6259 Metetra
.964 .152 0 r
.49271 .6259 .50373 .6351 .52364 .63044 .51272 .62111 Metetra
.967 .139 0 r
.51272 .62111 .52364 .63044 .5437 .62536 .53289 .6159 Metetra
.969 .131 0 r
.53289 .6159 .5437 .62536 .56392 .61987 .55321 .61032 Metetra
.969 .129 0 r
.55321 .61032 .56392 .61987 .58428 .61399 .57368 .60436 Metetra
.969 .131 0 r
.57368 .60436 .58428 .61399 .60479 .60773 .59429 .59804 Metetra
.967 .139 0 r
.59429 .59804 .60479 .60773 .62543 .60106 .61505 .59133 Metetra
.964 .152 0 r
.61505 .59133 .62543 .60106 .6462 .59395 .63594 .5842 Metetra
.959 .171 0 r
.63594 .5842 .6462 .59395 .6671 .58634 .65696 .57659 Metetra
.952 .197 0 r
.65696 .57659 .6671 .58634 .6881 .57817 .6781 .56844 Metetra
.944 .23 0 r
.6781 .56844 .6881 .57817 .70921 .56935 .69934 .55966 Metetra
.933 .272 0 r
.69934 .55966 .70921 .56935 .7304 .55978 .72067 .55015 Metetra
.919 .322 0 r
.72067 .55015 .7304 .55978 .75166 .54935 .74207 .53979 Metetra
.902 .382 0 r
.74207 .53979 .75166 .54935 .77295 .53791 .76352 .52845 Metetra
.882 .453 0 r
.76352 .52845 .77295 .53791 .79425 .52533 .78499 .51598 Metetra
.857 .532 0 r
.78499 .51598 .79425 .52533 .81552 .51144 .80643 .50221 Metetra
.827 .621 0 r
.80643 .50221 .81552 .51144 .83672 .49606 .82782 .48696 Metetra
.791 .717 0 r
.82782 .48696 .83672 .49606 .85781 .47901 .84909 .47006 Metetra
.681 .749 0 r
.84909 .47006 .85781 .47901 .87872 .46009 .87021 .4513 Metetra
.486 .699 0 r
.87021 .4513 .87872 .46009 .8994 .4391 .8911 .43048 Metetra
.533 .711 0 r
.25677 .61264 .26887 .62005 .28596 .62786 .27391 .62022 Metetra
.729 .76 0 r
.27391 .62022 .28596 .62786 .30342 .63381 .29143 .62593 Metetra
.801 .69 0 r
.29143 .62593 .30342 .63381 .32123 .63806 .3093 .62995 Metetra
.836 .594 0 r
.3093 .62995 .32123 .63806 .33934 .64081 .32749 .63247 Metetra
.865 .506 0 r
.32749 .63247 .33934 .64081 .35774 .6422 .34596 .63366 Metetra
.889 .426 0 r
.34596 .63366 .35774 .6422 .37639 .64241 .36469 .63366 Metetra
.909 .357 0 r
.36469 .63366 .37639 .64241 .39528 .64157 .38366 .63262 Metetra
.926 .298 0 r
.38366 .63262 .39528 .64157 .41439 .63983 .40285 .63069 Metetra
.939 .249 0 r
.40285 .63069 .41439 .63983 .4337 .63729 .42225 .62798 Metetra
.949 .209 0 r
.42225 .62798 .4337 .63729 .45319 .63406 .44184 .62459 Metetra
.957 .177 0 r
.44184 .62459 .45319 .63406 .47287 .63024 .4616 .62062 Metetra
.964 .152 0 r
.4616 .62062 .47287 .63024 .49271 .6259 .48154 .61614 Metetra
.968 .134 0 r
.48154 .61614 .49271 .6259 .51272 .62111 .50165 .61123 Metetra
.971 .121 0 r
.50165 .61123 .51272 .62111 .53289 .6159 .52192 .60591 Metetra
.973 .114 0 r
.52192 .60591 .53289 .6159 .55321 .61032 .54234 .60023 Metetra
.974 .112 0 r
.54234 .60023 .55321 .61032 .57368 .60436 .56292 .5942 Metetra
.973 .114 0 r
.56292 .5942 .57368 .60436 .59429 .59804 .58364 .58781 Metetra
.971 .121 0 r
.58364 .58781 .59429 .59804 .61505 .59133 .60451 .58105 Metetra
.968 .134 0 r
.60451 .58105 .61505 .59133 .63594 .5842 .62552 .57388 Metetra
.964 .152 0 r
.62552 .57388 .63594 .5842 .65696 .57659 .64666 .56625 Metetra
.957 .177 0 r
.64666 .56625 .65696 .57659 .6781 .56844 .66792 .55809 Metetra
.949 .209 0 r
.66792 .55809 .6781 .56844 .69934 .55966 .6893 .54932 Metetra
.939 .249 0 r
.6893 .54932 .69934 .55966 .72067 .55015 .71076 .53982 Metetra
.926 .298 0 r
.71076 .53982 .72067 .55015 .74207 .53979 .73231 .52949 Metetra
.909 .357 0 r
.73231 .52949 .74207 .53979 .76352 .52845 .75391 .51819 Metetra
.889 .426 0 r
.75391 .51819 .76352 .52845 .78499 .51598 .77553 .50577 Metetra
.865 .506 0 r
.77553 .50577 .78499 .51598 .80643 .50221 .79713 .49206 Metetra
.836 .594 0 r
.79713 .49206 .80643 .50221 .82782 .48696 .81869 .47689 Metetra
.801 .69 0 r
.81869 .47689 .82782 .48696 .84909 .47006 .84015 .46007 Metetra
.729 .76 0 r
.84015 .46007 .84909 .47006 .87021 .4513 .86145 .4414 Metetra
.533 .711 0 r
.86145 .4414 .87021 .4513 .8911 .43048 .88254 .42066 Metetra
.566 .72 0 r
.24458 .60418 .25677 .61264 .27391 .62022 .26175 .61158 Metetra
.763 .768 0 r
.26175 .61158 .27391 .62022 .29143 .62593 .27932 .61712 Metetra
.808 .671 0 r
.27932 .61712 .29143 .62593 .3093 .62995 .29725 .62098 Metetra
.843 .575 0 r
.29725 .62098 .3093 .62995 .32749 .63247 .3155 .62334 Metetra
.871 .487 0 r
.3155 .62334 .32749 .63247 .34596 .63366 .33404 .62436 Metetra
.895 .408 0 r
.33404 .62436 .34596 .63366 .36469 .63366 .35285 .6242 Metetra
.914 .34 0 r
.35285 .6242 .36469 .63366 .38366 .63262 .3719 .62302 Metetra
.93 .282 0 r
.3719 .62302 .38366 .63262 .40285 .63069 .39117 .62094 Metetra
.943 .234 0 r
.39117 .62094 .40285 .63069 .42225 .62798 .41065 .61808 Metetra
.953 .194 0 r
.41065 .61808 .42225 .62798 .44184 .62459 .43033 .61456 Metetra
.961 .163 0 r
.43033 .61456 .44184 .62459 .4616 .62062 .45019 .61047 Metetra
.967 .139 0 r
.45019 .61047 .4616 .62062 .48154 .61614 .47022 .60587 Metetra
.971 .121 0 r
.47022 .60587 .48154 .61614 .50165 .61123 .49043 .60085 Metetra
.974 .109 0 r
.49043 .60085 .50165 .61123 .52192 .60591 .51079 .59543 Metetra
.976 .102 0 r
.51079 .59543 .52192 .60591 .54234 .60023 .53132 .58966 Metetra
.976 .1 0 r
.53132 .58966 .54234 .60023 .56292 .5942 .552 .58355 Metetra
.976 .102 0 r
.552 .58355 .56292 .5942 .58364 .58781 .57283 .57709 Metetra
.974 .109 0 r
.57283 .57709 .58364 .58781 .60451 .58105 .59381 .57026 Metetra
.971 .121 0 r
.59381 .57026 .60451 .58105 .62552 .57388 .61494 .56304 Metetra
.967 .139 0 r
.61494 .56304 .62552 .57388 .64666 .56625 .63619 .55536 Metetra
.961 .163 0 r
.63619 .55536 .64666 .56625 .66792 .55809 .65758 .54716 Metetra
.953 .194 0 r
.65758 .54716 .66792 .55809 .6893 .54932 .67908 .53835 Metetra
.943 .234 0 r
.67908 .53835 .6893 .54932 .71076 .53982 .70068 .52884 Metetra
.93 .282 0 r
.70068 .52884 .71076 .53982 .73231 .52949 .72236 .51849 Metetra
.914 .34 0 r
.72236 .51849 .73231 .52949 .75391 .51819 .7441 .50718 Metetra
.895 .408 0 r
.7441 .50718 .75391 .51819 .77553 .50577 .76587 .49476 Metetra
.871 .487 0 r
.76587 .49476 .77553 .50577 .79713 .49206 .78764 .48105 Metetra
.843 .575 0 r
.78764 .48105 .79713 .49206 .81869 .47689 .80936 .46589 Metetra
.808 .671 0 r
.80936 .46589 .81869 .47689 .84015 .46007 .83098 .44907 Metetra
.763 .768 0 r
.83098 .44907 .84015 .46007 .86145 .4414 .85247 .43041 Metetra
.566 .72 0 r
.85247 .43041 .86145 .4414 .88254 .42066 .87374 .40969 Metetra
.586 .725 0 r
.23229 .59468 .24458 .60418 .26175 .61158 .2495 .60198 Metetra
.772 .762 0 r
.2495 .60198 .26175 .61158 .27932 .61712 .26711 .60742 Metetra
.813 .66 0 r
.26711 .60742 .27932 .61712 .29725 .62098 .28509 .61117 Metetra
.846 .563 0 r
.28509 .61117 .29725 .62098 .3155 .62334 .30339 .61342 Metetra
.875 .475 0 r
.30339 .61342 .3155 .62334 .33404 .62436 .322 .61433 Metetra
.898 .397 0 r
.322 .61433 .33404 .62436 .35285 .6242 .34087 .61407 Metetra
.917 .329 0 r
.34087 .61407 .35285 .6242 .3719 .62302 .35999 .61278 Metetra
.933 .272 0 r
.35999 .61278 .3719 .62302 .39117 .62094 .37935 .61059 Metetra
.945 .224 0 r
.37935 .61059 .39117 .62094 .41065 .61808 .39891 .60763 Metetra
.955 .186 0 r
.39891 .60763 .41065 .61808 .43033 .61456 .41867 .604 Metetra
.963 .155 0 r
.41867 .604 .43033 .61456 .45019 .61047 .43862 .59981 Metetra
.969 .131 0 r
.43862 .59981 .45019 .61047 .47022 .60587 .45875 .59512 Metetra
.973 .114 0 r
.45875 .59512 .47022 .60587 .49043 .60085 .47905 .59 Metetra
.976 .102 0 r
.47905 .59 .49043 .60085 .51079 .59543 .49951 .58449 Metetra
.977 .095 0 r
.49951 .58449 .51079 .59543 .53132 .58966 .52014 .57863 Metetra
.978 .093 0 r
.52014 .57863 .53132 .58966 .552 .58355 .54092 .57243 Metetra
.977 .095 0 r
.54092 .57243 .552 .58355 .57283 .57709 .56186 .56589 Metetra
.976 .102 0 r
.56186 .56589 .57283 .57709 .59381 .57026 .58295 .55899 Metetra
.973 .114 0 r
.58295 .55899 .59381 .57026 .61494 .56304 .60419 .55169 Metetra
.969 .131 0 r
.60419 .55169 .61494 .56304 .63619 .55536 .62556 .54394 Metetra
.963 .155 0 r
.62556 .54394 .63619 .55536 .65758 .54716 .64707 .53567 Metetra
.955 .186 0 r
.64707 .53567 .65758 .54716 .67908 .53835 .66869 .5268 Metetra
.945 .224 0 r
.66869 .5268 .67908 .53835 .70068 .52884 .69042 .51722 Metetra
.933 .272 0 r
.69042 .51722 .70068 .52884 .72236 .51849 .71224 .50681 Metetra
.917 .329 0 r
.71224 .50681 .72236 .51849 .7441 .50718 .73411 .49544 Metetra
.898 .397 0 r
.73411 .49544 .7441 .50718 .76587 .49476 .75603 .48295 Metetra
.875 .475 0 r
.75603 .48295 .76587 .49476 .78764 .48105 .77794 .46919 Metetra
.846 .563 0 r
.77794 .46919 .78764 .48105 .80936 .46589 .79981 .45396 Metetra
.813 .66 0 r
.79981 .45396 .80936 .46589 .83098 .44907 .8216 .43709 Metetra
.772 .762 0 r
.8216 .43709 .83098 .44907 .85247 .43041 .84325 .41836 Metetra
.586 .725 0 r
.84325 .41836 .85247 .43041 .87374 .40969 .86469 .39757 Metetra
.593 .727 0 r
.21991 .58415 .23229 .59468 .2495 .60198 .23714 .59142 Metetra
.774 .758 0 r
.23714 .59142 .2495 .60198 .26711 .60742 .25479 .59682 Metetra
.814 .656 0 r
.25479 .59682 .26711 .60742 .28509 .61117 .27281 .60053 Metetra
.848 .559 0 r
.27281 .60053 .28509 .61117 .30339 .61342 .29116 .60273 Metetra
.876 .471 0 r
.29116 .60273 .30339 .61342 .322 .61433 .30982 .60359 Metetra
.899 .393 0 r
.30982 .60359 .322 .61433 .34087 .61407 .32876 .60326 Metetra
.918 .326 0 r
.32876 .60326 .34087 .61407 .35999 .61278 .34795 .60191 Metetra
.934 .269 0 r
.34795 .60191 .35999 .61278 .37935 .61059 .36738 .59965 Metetra
.946 .221 0 r
.36738 .59965 .37935 .61059 .39891 .60763 .38702 .59662 Metetra
.956 .183 0 r
.38702 .59662 .39891 .60763 .41867 .604 .40686 .59293 Metetra
.964 .152 0 r
.40686 .59293 .41867 .604 .43862 .59981 .4269 .58865 Metetra
.969 .129 0 r
.4269 .58865 .43862 .59981 .45875 .59512 .44712 .58389 Metetra
.974 .112 0 r
.44712 .58389 .45875 .59512 .47905 .59 .46751 .57868 Metetra
.976 .1 0 r
.46751 .57868 .47905 .59 .49951 .58449 .48807 .57309 Metetra
.978 .093 0 r
.48807 .57309 .49951 .58449 .52014 .57863 .5088 .56715 Metetra
.979 .091 0 r
.5088 .56715 .52014 .57863 .54092 .57243 .52969 .56086 Metetra
.978 .093 0 r
.52969 .56086 .54092 .57243 .56186 .56589 .55073 .55423 Metetra
.976 .1 0 r
.55073 .55423 .56186 .56589 .58295 .55899 .57193 .54724 Metetra
.974 .112 0 r
.57193 .54724 .58295 .55899 .60419 .55169 .59328 .53984 Metetra
.969 .129 0 r
.59328 .53984 .60419 .55169 .62556 .54394 .61477 .532 Metetra
.964 .152 0 r
.61477 .532 .62556 .54394 .64707 .53567 .63639 .52363 Metetra
.956 .183 0 r
.63639 .52363 .64707 .53567 .66869 .5268 .65814 .51465 Metetra
.946 .221 0 r
.65814 .51465 .66869 .5268 .69042 .51722 .67999 .50497 Metetra
.934 .269 0 r
.67999 .50497 .69042 .51722 .71224 .50681 .70194 .49445 Metetra
.918 .326 0 r
.70194 .49445 .71224 .50681 .73411 .49544 .72395 .48297 Metetra
.899 .393 0 r
.72395 .48297 .73411 .49544 .75603 .48295 .746 .47036 Metetra
.876 .471 0 r
.746 .47036 .75603 .48295 .77794 .46919 .76805 .45648 Metetra
.848 .559 0 r
.76805 .45648 .77794 .46919 .79981 .45396 .79007 .44112 Metetra
.814 .656 0 r
.79007 .44112 .79981 .45396 .8216 .43709 .81201 .42411 Metetra
.774 .758 0 r
.81201 .42411 .8216 .43709 .84325 .41836 .83381 .40524 Metetra
.593 .727 0 r
.83381 .40524 .84325 .41836 .86469 .39757 .85541 .38431 Metetra
.586 .725 0 r
.20746 .57256 .21991 .58415 .23714 .59142 .2247 .57988 Metetra
.772 .762 0 r
.2247 .57988 .23714 .59142 .25479 .59682 .24237 .58531 Metetra
.813 .66 0 r
.24237 .58531 .25479 .59682 .27281 .60053 .26042 .58904 Metetra
.846 .563 0 r
.26042 .58904 .27281 .60053 .29116 .60273 .27881 .59125 Metetra
.875 .475 0 r
.27881 .59125 .29116 .60273 .30982 .60359 .29752 .59211 Metetra
.898 .397 0 r
.29752 .59211 .30982 .60359 .32876 .60326 .31651 .59178 Metetra
.917 .329 0 r
.31651 .59178 .32876 .60326 .34795 .60191 .33577 .5904 Metetra
.933 .272 0 r
.33577 .5904 .34795 .60191 .36738 .59965 .35527 .58812 Metetra
.945 .224 0 r
.35527 .58812 .36738 .59965 .38702 .59662 .37498 .58506 Metetra
.955 .186 0 r
.37498 .58506 .38702 .59662 .40686 .59293 .39491 .58132 Metetra
.963 .155 0 r
.39491 .58132 .40686 .59293 .4269 .58865 .41503 .577 Metetra
.969 .131 0 r
.41503 .577 .4269 .58865 .44712 .58389 .43534 .57217 Metetra
.973 .114 0 r
.43534 .57217 .44712 .58389 .46751 .57868 .45582 .5669 Metetra
.976 .102 0 r
.45582 .5669 .46751 .57868 .48807 .57309 .47648 .56124 Metetra
.977 .095 0 r
.47648 .56124 .48807 .57309 .5088 .56715 .4973 .55521 Metetra
.978 .093 0 r
.4973 .55521 .5088 .56715 .52969 .56086 .51829 .54883 Metetra
.977 .095 0 r
.51829 .54883 .52969 .56086 .55073 .55423 .53944 .5421 Metetra
.976 .102 0 r
.53944 .5421 .55073 .55423 .57193 .54724 .56075 .535 Metetra
.973 .114 0 r
.56075 .535 .57193 .54724 .59328 .53984 .58221 .5275 Metetra
.969 .131 0 r
.58221 .5275 .59328 .53984 .61477 .532 .60381 .51953 Metetra
.963 .155 0 r
.60381 .51953 .61477 .532 .63639 .52363 .62555 .51103 Metetra
.955 .186 0 r
.62555 .51103 .63639 .52363 .65814 .51465 .64742 .50192 Metetra
.945 .224 0 r
.64742 .50192 .65814 .51465 .67999 .50497 .66939 .49209 Metetra
.933 .272 0 r
.66939 .49209 .67999 .50497 .70194 .49445 .69146 .48141 Metetra
.917 .329 0 r
.69146 .48141 .70194 .49445 .72395 .48297 .7136 .46976 Metetra
.898 .397 0 r
.7136 .46976 .72395 .48297 .746 .47036 .73578 .45698 Metetra
.875 .475 0 r
.73578 .45698 .746 .47036 .76805 .45648 .75797 .44291 Metetra
.846 .563 0 r
.75797 .44291 .76805 .45648 .79007 .44112 .78012 .42736 Metetra
.813 .66 0 r
.78012 .42736 .79007 .44112 .81201 .42411 .8022 .41014 Metetra
.772 .762 0 r
.8022 .41014 .81201 .42411 .83381 .40524 .82415 .39106 Metetra
.586 .725 0 r
.82415 .39106 .83381 .40524 .85541 .38431 .8459 .36989 Metetra
.566 .72 0 r
.19495 .55991 .20746 .57256 .2247 .57988 .21218 .56733 Metetra
.763 .768 0 r
.21218 .56733 .2247 .57988 .24237 .58531 .22985 .57286 Metetra
.808 .671 0 r
.22985 .57286 .24237 .58531 .26042 .58904 .24792 .57668 Metetra
.843 .575 0 r
.24792 .57668 .26042 .58904 .27881 .59125 .26635 .57896 Metetra
.871 .487 0 r
.26635 .57896 .27881 .59125 .29752 .59211 .2851 .57988 Metetra
.895 .408 0 r
.2851 .57988 .29752 .59211 .31651 .59178 .30414 .57959 Metetra
.914 .34 0 r
.30414 .57959 .31651 .59178 .33577 .5904 .32345 .57824 Metetra
.93 .282 0 r
.32345 .57824 .33577 .5904 .35527 .58812 .34301 .57598 Metetra
.943 .234 0 r
.34301 .57598 .35527 .58812 .37498 .58506 .3628 .57291 Metetra
.953 .194 0 r
.3628 .57291 .37498 .58506 .39491 .58132 .3828 .56916 Metetra
.961 .163 0 r
.3828 .56916 .39491 .58132 .41503 .577 .40301 .56481 Metetra
.967 .139 0 r
.40301 .56481 .41503 .577 .43534 .57217 .4234 .55994 Metetra
.971 .121 0 r
.4234 .55994 .43534 .57217 .45582 .5669 .44398 .55462 Metetra
.974 .109 0 r
.44398 .55462 .45582 .5669 .47648 .56124 .46473 .54889 Metetra
.976 .102 0 r
.46473 .54889 .47648 .56124 .4973 .55521 .48565 .54279 Metetra
.976 .1 0 r
.48565 .54279 .4973 .55521 .51829 .54883 .50674 .53632 Metetra
.976 .102 0 r
.50674 .53632 .51829 .54883 .53944 .5421 .528 .52948 Metetra
.974 .109 0 r
.528 .52948 .53944 .5421 .56075 .535 .54941 .52226 Metetra
.971 .121 0 r
.54941 .52226 .56075 .535 .58221 .5275 .57098 .51462 Metetra
.967 .139 0 r
.57098 .51462 .58221 .5275 .60381 .51953 .59269 .50651 Metetra
.961 .163 0 r
.59269 .50651 .60381 .51953 .62555 .51103 .61454 .49785 Metetra
.953 .194 0 r
.61454 .49785 .62555 .51103 .64742 .50192 .63653 .48857 Metetra
.943 .234 0 r
.63653 .48857 .64742 .50192 .66939 .49209 .65862 .47854 Metetra
.93 .282 0 r
.65862 .47854 .66939 .49209 .69146 .48141 .68081 .46767 Metetra
.914 .34 0 r
.68081 .46767 .69146 .48141 .7136 .46976 .70307 .4558 Metetra
.895 .408 0 r
.70307 .4558 .7136 .46976 .73578 .45698 .72538 .44278 Metetra
.871 .487 0 r
.72538 .44278 .73578 .45698 .75797 .44291 .74769 .42846 Metetra
.843 .575 0 r
.74769 .42846 .75797 .44291 .78012 .42736 .76998 .41265 Metetra
.808 .671 0 r
.76998 .41265 .78012 .42736 .8022 .41014 .79219 .39515 Metetra
.763 .768 0 r
.79219 .39515 .8022 .41014 .82415 .39106 .81427 .37577 Metetra
.566 .72 0 r
.81427 .37577 .82415 .39106 .8459 .36989 .83616 .35429 Metetra
.533 .711 0 r
.18237 .54614 .19495 .55991 .21218 .56733 .19959 .55375 Metetra
.729 .76 0 r
.19959 .55375 .21218 .56733 .22985 .57286 .21726 .55944 Metetra
.801 .69 0 r
.21726 .55944 .22985 .57286 .24792 .57668 .23534 .56341 Metetra
.836 .594 0 r
.23534 .56341 .24792 .57668 .26635 .57896 .25378 .56582 Metetra
.865 .506 0 r
.25378 .56582 .26635 .57896 .2851 .57988 .27256 .56685 Metetra
.889 .426 0 r
.27256 .56685 .2851 .57988 .30414 .57959 .29165 .56665 Metetra
.909 .357 0 r
.29165 .56665 .30414 .57959 .32345 .57824 .31101 .56538 Metetra
.926 .298 0 r
.31101 .56538 .32345 .57824 .34301 .57598 .33063 .56317 Metetra
.939 .249 0 r
.33063 .56317 .34301 .57598 .3628 .57291 .35048 .56014 Metetra
.949 .209 0 r
.35048 .56014 .3628 .57291 .3828 .56916 .37056 .55641 Metetra
.957 .177 0 r
.37056 .55641 .3828 .56916 .40301 .56481 .39084 .55206 Metetra
.964 .152 0 r
.39084 .55206 .40301 .56481 .4234 .55994 .41131 .54717 Metetra
.968 .134 0 r
.41131 .54717 .4234 .55994 .44398 .55462 .43198 .54181 Metetra
.971 .121 0 r
.43198 .54181 .44398 .55462 .46473 .54889 .45282 .53603 Metetra
.973 .114 0 r
.45282 .53603 .46473 .54889 .48565 .54279 .47384 .52984 Metetra
.974 .112 0 r
.47384 .52984 .48565 .54279 .50674 .53632 .49503 .52328 Metetra
.973 .114 0 r
.49503 .52328 .50674 .53632 .528 .52948 .51639 .51633 Metetra
.971 .121 0 r
.51639 .51633 .528 .52948 .54941 .52226 .53791 .50898 Metetra
.968 .134 0 r
.53791 .50898 .54941 .52226 .57098 .51462 .55958 .50119 Metetra
.964 .152 0 r
.55958 .50119 .57098 .51462 .59269 .50651 .58141 .4929 Metetra
.957 .177 0 r
.58141 .4929 .59269 .50651 .61454 .49785 .60337 .48405 Metetra
.949 .209 0 r
.60337 .48405 .61454 .49785 .63653 .48857 .62547 .47455 Metetra
.939 .249 0 r
.62547 .47455 .63653 .48857 .65862 .47854 .64768 .4643 Metetra
.926 .298 0 r
.64768 .4643 .65862 .47854 .68081 .46767 .66998 .45317 Metetra
.909 .357 0 r
.66998 .45317 .68081 .46767 .70307 .4558 .69236 .44103 Metetra
.889 .426 0 r
.69236 .44103 .70307 .4558 .72538 .44278 .71479 .42772 Metetra
.865 .506 0 r
.71479 .42772 .72538 .44278 .74769 .42846 .73723 .41308 Metetra
.836 .594 0 r
.73723 .41308 .74769 .42846 .76998 .41265 .75964 .39694 Metetra
.801 .69 0 r
.75964 .39694 .76998 .41265 .79219 .39515 .78197 .37909 Metetra
.729 .76 0 r
.78197 .37909 .79219 .39515 .81427 .37577 .80417 .35933 Metetra
.533 .711 0 r
.80417 .35933 .81427 .37577 .83616 .35429 .82618 .33747 Metetra
.486 .699 0 r
.16976 .5312 .18237 .54614 .19959 .55375 .18695 .53906 Metetra
.681 .749 0 r
.18695 .53906 .19959 .55375 .21726 .55944 .2046 .54499 Metetra
.791 .717 0 r
.2046 .54499 .21726 .55944 .23534 .56341 .22267 .54917 Metetra
.827 .621 0 r
.22267 .54917 .23534 .56341 .25378 .56582 .24112 .55177 Metetra
.857 .532 0 r
.24112 .55177 .25378 .56582 .27256 .56685 .25992 .55296 Metetra
.882 .453 0 r
.25992 .55296 .27256 .56685 .29165 .56665 .27904 .55291 Metetra
.902 .382 0 r
.27904 .55291 .29165 .56665 .31101 .56538 .29845 .55176 Metetra
.919 .322 0 r
.29845 .55176 .31101 .56538 .33063 .56317 .31811 .54965 Metetra
.933 .272 0 r
.31811 .54965 .33063 .56317 .35048 .56014 .33803 .5467 Metetra
.944 .23 0 r
.33803 .5467 .35048 .56014 .37056 .55641 .35817 .54301 Metetra
.952 .197 0 r
.35817 .54301 .37056 .55641 .39084 .55206 .37852 .53868 Metetra
.959 .171 0 r
.37852 .53868 .39084 .55206 .41131 .54717 .39908 .5338 Metetra
.964 .152 0 r
.39908 .5338 .41131 .54717 .43198 .54181 .41983 .52841 Metetra
.967 .139 0 r
.41983 .52841 .43198 .54181 .45282 .53603 .44076 .52258 Metetra
.969 .131 0 r
.44076 .52258 .45282 .53603 .47384 .52984 .46188 .51632 Metetra
.969 .129 0 r
.46188 .51632 .47384 .52984 .49503 .52328 .48316 .50966 Metetra
.969 .131 0 r
.48316 .50966 .49503 .52328 .51639 .51633 .50462 .50259 Metetra
.967 .139 0 r
.50462 .50259 .51639 .51633 .53791 .50898 .52624 .49509 Metetra
.964 .152 0 r
.52624 .49509 .53791 .50898 .55958 .50119 .54802 .48712 Metetra
.959 .171 0 r
.54802 .48712 .55958 .50119 .58141 .4929 .56996 .47864 Metetra
.952 .197 0 r
.56996 .47864 .58141 .4929 .60337 .48405 .59203 .46957 Metetra
.944 .23 0 r
.59203 .46957 .60337 .48405 .62547 .47455 .61424 .45982 Metetra
.933 .272 0 r
.61424 .45982 .62547 .47455 .64768 .4643 .63656 .44929 Metetra
.919 .322 0 r
.63656 .44929 .64768 .4643 .66998 .45317 .65898 .43786 Metetra
.902 .382 0 r
.65898 .43786 .66998 .45317 .69236 .44103 .68148 .4254 Metetra
.882 .453 0 r
.68148 .4254 .69236 .44103 .71479 .42772 .70402 .41174 Metetra
.857 .532 0 r
.70402 .41174 .71479 .42772 .73723 .41308 .72657 .39672 Metetra
.827 .621 0 r
.72657 .39672 .73723 .41308 .75964 .39694 .74909 .38017 Metetra
.791 .717 0 r
.74909 .38017 .75964 .39694 .78197 .37909 .77154 .36189 Metetra
.681 .749 0 r
.77154 .36189 .78197 .37909 .80417 .35933 .79386 .34169 Metetra
.486 .699 0 r
.79386 .34169 .80417 .35933 .82618 .33747 .81598 .31936 Metetra
.426 .683 0 r
.15713 .51502 .16976 .5312 .18695 .53906 .17426 .5232 Metetra
.62 .734 0 r
.17426 .5232 .18695 .53906 .2046 .54499 .19188 .52943 Metetra
.777 .75 0 r
.19188 .52943 .2046 .54499 .22267 .54917 .20993 .53388 Metetra
.814 .656 0 r
.20993 .53388 .22267 .54917 .24112 .55177 .22838 .53673 Metetra
.845 .567 0 r
.22838 .53673 .24112 .55177 .25992 .55296 .24719 .53815 Metetra
.871 .487 0 r
.24719 .53815 .25992 .55296 .27904 .55291 .26633 .5383 Metetra
.893 .415 0 r
.26633 .5383 .27904 .55291 .29845 .55176 .28577 .53731 Metetra
.91 .354 0 r
.28577 .53731 .29845 .55176 .31811 .54965 .30548 .53534 Metetra
.925 .302 0 r
.30548 .53534 .31811 .54965 .33803 .5467 .32545 .53249 Metetra
.936 .259 0 r
.32545 .53249 .33803 .5467 .35817 .54301 .34565 .52888 Metetra
.945 .224 0 r
.34565 .52888 .35817 .54301 .37852 .53868 .36607 .52461 Metetra
.952 .197 0 r
.36607 .52461 .37852 .53868 .39908 .5338 .3867 .51974 Metetra
.957 .177 0 r
.3867 .51974 .39908 .5338 .41983 .52841 .40753 .51435 Metetra
.961 .163 0 r
.40753 .51435 .41983 .52841 .44076 .52258 .42855 .50847 Metetra
.963 .155 0 r
.42855 .50847 .44076 .52258 .46188 .51632 .44976 .50214 Metetra
.964 .152 0 r
.44976 .50214 .46188 .51632 .48316 .50966 .47114 .49538 Metetra
.963 .155 0 r
.47114 .49538 .48316 .50966 .50462 .50259 .4927 .48818 Metetra
.961 .163 0 r
.4927 .48818 .50462 .50259 .52624 .49509 .51442 .48052 Metetra
.957 .177 0 r
.51442 .48052 .52624 .49509 .54802 .48712 .53631 .47236 Metetra
.952 .197 0 r
.53631 .47236 .54802 .48712 .56996 .47864 .55834 .46366 Metetra
.945 .224 0 r
.55834 .46366 .56996 .47864 .59203 .46957 .58053 .45433 Metetra
.936 .259 0 r
.58053 .45433 .59203 .46957 .61424 .45982 .60284 .44429 Metetra
.925 .302 0 r
.60284 .44429 .61424 .45982 .63656 .44929 .62527 .43345 Metetra
.91 .354 0 r
.62527 .43345 .63656 .44929 .65898 .43786 .6478 .42167 Metetra
.893 .415 0 r
.6478 .42167 .65898 .43786 .68148 .4254 .67041 .40882 Metetra
.871 .487 0 r
.67041 .40882 .68148 .4254 .70402 .41174 .69306 .39475 Metetra
.845 .567 0 r
.69306 .39475 .70402 .41174 .72657 .39672 .71572 .37929 Metetra
.814 .656 0 r
.71572 .37929 .72657 .39672 .74909 .38017 .73835 .36227 Metetra
.777 .75 0 r
.73835 .36227 .74909 .38017 .77154 .36189 .7609 .3435 Metetra
.62 .734 0 r
.7609 .3435 .77154 .36189 .79386 .34169 .78332 .32277 Metetra
.426 .683 0 r
.78332 .32277 .79386 .34169 .81598 .31936 .80555 .29989 Metetra
.355 .662 0 r
.1445 .49751 .15713 .51502 .17426 .5232 .16156 .50609 Metetra
.546 .715 0 r
.16156 .50609 .17426 .5232 .19188 .52943 .17912 .51268 Metetra
.729 .76 0 r
.17912 .51268 .19188 .52943 .20993 .53388 .19714 .51747 Metetra
.798 .698 0 r
.19714 .51747 .20993 .53388 .22838 .53673 .21557 .52063 Metetra
.831 .61 0 r
.21557 .52063 .22838 .53673 .24719 .53815 .23438 .52233 Metetra
.858 .529 0 r
.23438 .52233 .24719 .53815 .26633 .5383 .25353 .52271 Metetra
.88 .456 0 r
.25353 .52271 .26633 .5383 .28577 .53731 .27299 .52194 Metetra
.899 .393 0 r
.27299 .52194 .28577 .53731 .30548 .53534 .29273 .52014 Metetra
.914 .34 0 r
.29273 .52014 .30548 .53534 .32545 .53249 .31274 .51744 Metetra
.927 .295 0 r
.31274 .51744 .32545 .53249 .34565 .52888 .333 .51394 Metetra
.936 .259 0 r
.333 .51394 .34565 .52888 .36607 .52461 .35348 .50974 Metetra
.944 .23 0 r
.35348 .50974 .36607 .52461 .3867 .51974 .37419 .50491 Metetra
.949 .209 0 r
.37419 .50491 .3867 .51974 .40753 .51435 .39509 .49952 Metetra
.953 .194 0 r
.39509 .49952 .40753 .51435 .42855 .50847 .4162 .49361 Metetra
.955 .186 0 r
.4162 .49361 .42855 .50847 .44976 .50214 .43749 .48722 Metetra
.956 .183 0 r
.43749 .48722 .44976 .50214 .47114 .49538 .45896 .48035 Metetra
.955 .186 0 r
.45896 .48035 .47114 .49538 .4927 .48818 .48062 .47301 Metetra
.953 .194 0 r
.48062 .47301 .4927 .48818 .51442 .48052 .50244 .46518 Metetra
.949 .209 0 r
.50244 .46518 .51442 .48052 .53631 .47236 .52443 .45681 Metetra
.944 .23 0 r
.52443 .45681 .53631 .47236 .55834 .46366 .54657 .44785 Metetra
.936 .259 0 r
.54657 .44785 .55834 .46366 .58053 .45433 .56886 .43824 Metetra
.927 .295 0 r
.56886 .43824 .58053 .45433 .60284 .44429 .59128 .42788 Metetra
.914 .34 0 r
.59128 .42788 .60284 .44429 .62527 .43345 .61382 .41667 Metetra
.899 .393 0 r
.61382 .41667 .62527 .43345 .6478 .42167 .63645 .40449 Metetra
.88 .456 0 r
.63645 .40449 .6478 .42167 .67041 .40882 .65916 .39121 Metetra
.858 .529 0 r
.65916 .39121 .67041 .40882 .69306 .39475 .68192 .37667 Metetra
.831 .61 0 r
.68192 .37667 .69306 .39475 .71572 .37929 .70468 .36071 Metetra
.798 .698 0 r
.70468 .36071 .71572 .37929 .73835 .36227 .72741 .34315 Metetra
.729 .76 0 r
.72741 .34315 .73835 .36227 .7609 .3435 .75006 .32381 Metetra
.546 .715 0 r
.75006 .32381 .7609 .3435 .78332 .32277 .77257 .30248 Metetra
.355 .662 0 r
.77257 .30248 .78332 .32277 .80555 .29989 .79489 .27897 Metetra
.272 .637 0 r
.13189 .47858 .1445 .49751 .16156 .50609 .14887 .48761 Metetra
.459 .692 0 r
.14887 .48761 .16156 .50609 .17912 .51268 .16636 .49463 Metetra
.641 .739 0 r
.16636 .49463 .17912 .51268 .19714 .51747 .18432 .49982 Metetra
.779 .747 0 r
.18432 .49982 .19714 .51747 .21557 .52063 .20272 .50335 Metetra
.813 .66 0 r
.20272 .50335 .21557 .52063 .23438 .52233 .2215 .50537 Metetra
.841 .579 0 r
.2215 .50537 .23438 .52233 .25353 .52271 .24065 .50606 Metetra
.865 .506 0 r
.24065 .50606 .25353 .52271 .27299 .52194 .26012 .50554 Metetra
.885 .441 0 r
.26012 .50554 .27299 .52194 .29273 .52014 .27989 .50396 Metetra
.901 .386 0 r
.27989 .50396 .29273 .52014 .31274 .51744 .29994 .50144 Metetra
.914 .34 0 r
.29994 .50144 .31274 .51744 .333 .51394 .32024 .49808 Metetra
.925 .302 0 r
.32024 .49808 .333 .51394 .35348 .50974 .34078 .49398 Metetra
.933 .272 0 r
.34078 .49398 .35348 .50974 .37419 .50491 .36154 .48921 Metetra
.939 .249 0 r
.36154 .48921 .37419 .50491 .39509 .49952 .38252 .48383 Metetra
.943 .233 0 r
.38252 .48383 .39509 .49952 .4162 .49361 .4037 .4779 Metetra
.945 .224 0 r
.4037 .4779 .4162 .49361 .43749 .48722 .42508 .47144 Metetra
.946 .221 0 r
.42508 .47144 .43749 .48722 .45896 .48035 .44664 .46447 Metetra
.945 .224 0 r
.44664 .46447 .45896 .48035 .48062 .47301 .46839 .45698 Metetra
.943 .233 0 r
.46839 .45698 .48062 .47301 .50244 .46518 .49031 .44895 Metetra
.939 .249 0 r
.49031 .44895 .50244 .46518 .52443 .45681 .51239 .44034 Metetra
.933 .272 0 r
.51239 .44034 .52443 .45681 .54657 .44785 .53464 .43111 Metetra
.925 .302 0 r
.53464 .43111 .54657 .44785 .56886 .43824 .55703 .42118 Metetra
.914 .34 0 r
.55703 .42118 .56886 .43824 .59128 .42788 .57955 .41046 Metetra
.901 .386 0 r
.57955 .41046 .59128 .42788 .61382 .41667 .60219 .39885 Metetra
.885 .441 0 r
.60219 .39885 .61382 .41667 .63645 .40449 .62493 .38623 Metetra
.865 .506 0 r
.62493 .38623 .63645 .40449 .65916 .39121 .64774 .37246 Metetra
.841 .579 0 r
.64774 .37246 .65916 .39121 .68192 .37667 .67059 .35739 Metetra
.813 .66 0 r
.67059 .35739 .68192 .37667 .70468 .36071 .69345 .34086 Metetra
.779 .747 0 r
.69345 .34086 .70468 .36071 .72741 .34315 .71627 .3227 Metetra
.641 .739 0 r
.71627 .3227 .72741 .34315 .75006 .32381 .73901 .30271 Metetra
.459 .692 0 r
.73901 .30271 .75006 .32381 .77257 .30248 .7616 .28071 Metetra
.272 .637 0 r
.7616 .28071 .77257 .30248 .79489 .27897 .784 .2565 Metetra
.18 .607 0 r
.11934 .45811 .13189 .47858 .14887 .48761 .1362 .46766 Metetra
.361 .664 0 r
.1362 .46766 .14887 .48761 .16636 .49463 .1536 .47518 Metetra
.54 .713 0 r
.1536 .47518 .16636 .49463 .18432 .49982 .17149 .48082 Metetra
.709 .755 0 r
.17149 .48082 .18432 .49982 .20272 .50335 .18984 .48477 Metetra
.791 .717 0 r
.18984 .48477 .20272 .50335 .2215 .50537 .20859 .48718 Metetra
.821 .637 0 r
.20859 .48718 .2215 .50537 .24065 .50606 .22772 .4882 Metetra
.846 .563 0 r
.22772 .4882 .24065 .50606 .26012 .50554 .24719 .48799 Metetra
.868 .498 0 r
.24719 .48799 .26012 .50554 .27989 .50396 .26697 .48667 Metetra
.885 .441 0 r
.26697 .48667 .27989 .50396 .29994 .50144 .28704 .48436 Metetra
.899 .393 0 r
.28704 .48436 .29994 .50144 .32024 .49808 .30737 .48116 Metetra
.91 .354 0 r
.30737 .48116 .32024 .49808 .34078 .49398 .32796 .47718 Metetra
.919 .322 0 r
.32796 .47718 .34078 .49398 .36154 .48921 .34878 .47249 Metetra
.926 .298 0 r
.34878 .47249 .36154 .48921 .38252 .48383 .36983 .46715 Metetra
.93 .282 0 r
.36983 .46715 .38252 .48383 .4037 .4779 .39108 .4612 Metetra
.933 .272 0 r
.39108 .4612 .4037 .4779 .42508 .47144 .41254 .45468 Metetra
.934 .268 0 r
.41254 .45468 .42508 .47144 .44664 .46447 .43418 .44759 Metetra
.933 .272 0 r
.43418 .44759 .44664 .46447 .46839 .45698 .45602 .43994 Metetra
.93 .282 0 r
.45602 .43994 .46839 .45698 .49031 .44895 .47803 .43171 Metetra
.926 .298 0 r
.47803 .43171 .49031 .44895 .51239 .44034 .50021 .42285 Metetra
.919 .322 0 r
.50021 .42285 .51239 .44034 .53464 .43111 .52255 .41331 Metetra
.91 .354 0 r
.52255 .41331 .53464 .43111 .55703 .42118 .54504 .40303 Metetra
.899 .393 0 r
.54504 .40303 .55703 .42118 .57955 .41046 .56766 .39191 Metetra
.885 .441 0 r
.56766 .39191 .57955 .41046 .60219 .39885 .5904 .37986 Metetra
.868 .498 0 r
.5904 .37986 .60219 .39885 .62493 .38623 .61323 .36674 Metetra
.846 .563 0 r
.61323 .36674 .62493 .38623 .64774 .37246 .63614 .35243 Metetra
.821 .637 0 r
.63614 .35243 .64774 .37246 .67059 .35739 .65908 .33678 Metetra
.791 .717 0 r
.65908 .33678 .67059 .35739 .69345 .34086 .68203 .31962 Metetra
.709 .755 0 r
.68203 .31962 .69345 .34086 .71627 .3227 .70493 .30079 Metetra
.54 .713 0 r
.70493 .30079 .71627 .3227 .73901 .30271 .72775 .2801 Metetra
.361 .664 0 r
.72775 .2801 .73901 .30271 .7616 .28071 .75042 .25735 Metetra
.18 .607 0 r
.75042 .25735 .7616 .28071 .784 .2565 .77288 .23237 Metetra
.082 .572 0 r
.10687 .43598 .11934 .45811 .1362 .46766 .1236 .44612 Metetra
.254 .631 0 r
.1236 .44612 .1362 .46766 .1536 .47518 .14089 .45418 Metetra
.427 .683 0 r
.14089 .45418 .1536 .47518 .17149 .48082 .15869 .46034 Metetra
.594 .727 0 r
.15869 .46034 .17149 .48082 .18984 .48477 .17696 .46476 Metetra
.75 .765 0 r
.17696 .46476 .18984 .48477 .20859 .48718 .19566 .4676 Metetra
.797 .702 0 r
.19566 .4676 .20859 .48718 .22772 .4882 .21475 .46901 Metetra
.824 .629 0 r
.21475 .46901 .22772 .4882 .24719 .48799 .2342 .46914 Metetra
.846 .563 0 r
.2342 .46914 .24719 .48799 .26697 .48667 .25398 .46812 Metetra
.865 .505 0 r
.25398 .46812 .26697 .48667 .28704 .48436 .27407 .46605 Metetra
.88 .456 0 r
.27407 .46605 .28704 .48436 .30737 .48116 .29443 .46306 Metetra
.893 .415 0 r
.29443 .46306 .30737 .48116 .32796 .47718 .31505 .45922 Metetra
.902 .382 0 r
.31505 .45922 .32796 .47718 .34878 .47249 .33592 .45463 Metetra
.909 .357 0 r
.33592 .45463 .34878 .47249 .36983 .46715 .35702 .44933 Metetra
.914 .339 0 r
.35702 .44933 .36983 .46715 .39108 .4612 .37834 .44337 Metetra
.917 .329 0 r
.37834 .44337 .39108 .4612 .41254 .45468 .39987 .43679 Metetra
.918 .326 0 r
.39987 .43679 .41254 .45468 .43418 .44759 .4216 .42959 Metetra
.917 .329 0 r
.4216 .42959 .43418 .44759 .45602 .43994 .44352 .42177 Metetra
.914 .339 0 r
.44352 .42177 .45602 .43994 .47803 .43171 .46561 .41331 Metetra
.909 .357 0 r
.46561 .41331 .47803 .43171 .50021 .42285 .48789 .40418 Metetra
.902 .382 0 r
.48789 .40418 .50021 .42285 .52255 .41331 .51032 .39431 Metetra
.893 .415 0 r
.51032 .39431 .52255 .41331 .54504 .40303 .5329 .38365 Metetra
.88 .456 0 r
.5329 .38365 .54504 .40303 .56766 .39191 .55562 .3721 Metetra
.865 .505 0 r
.55562 .3721 .56766 .39191 .5904 .37986 .57845 .35955 Metetra
.846 .563 0 r
.57845 .35955 .5904 .37986 .61323 .36674 .60137 .34589 Metetra
.824 .629 0 r
.60137 .34589 .61323 .36674 .63614 .35243 .62437 .33099 Metetra
.797 .702 0 r
.62437 .33099 .63614 .35243 .65908 .33678 .64739 .3147 Metetra
.75 .765 0 r
.64739 .3147 .65908 .33678 .68203 .31962 .67042 .29686 Metetra
.594 .727 0 r
.67042 .29686 .68203 .31962 .70493 .30079 .6934 .27729 Metetra
.427 .683 0 r
.6934 .27729 .70493 .30079 .72775 .2801 .71629 .25583 Metetra
.254 .631 0 r
.71629 .25583 .72775 .2801 .75042 .25735 .73902 .23227 Metetra
.082 .572 0 r
.73902 .23227 .75042 .25735 .77288 .23237 .76153 .20645 Metetra
0 .53 .019 r
.09453 .41206 .10687 .43598 .1236 .44612 .1111 .42283 Metetra
.139 .593 0 r
.1111 .42283 .1236 .44612 .14089 .45418 .12825 .4315 Metetra
.304 .647 0 r
.12825 .4315 .14089 .45418 .15869 .46034 .14594 .43822 Metetra
.466 .694 0 r
.14594 .43822 .15869 .46034 .17696 .46476 .16412 .44317 Metetra
.621 .734 0 r
.16412 .44317 .17696 .46476 .19566 .4676 .18275 .44649 Metetra
.763 .768 0 r
.18275 .44649 .19566 .4676 .21475 .46901 .20179 .44834 Metetra
.797 .701 0 r
.20179 .44834 .21475 .46901 .2342 .46914 .2212 .44885 Metetra
.821 .636 0 r
.2212 .44885 .2342 .46914 .25398 .46812 .24097 .44816 Metetra
.841 .578 0 r
.24097 .44816 .25398 .46812 .27407 .46605 .26105 .44637 Metetra
.858 .528 0 r
.26105 .44637 .27407 .46605 .29443 .46306 .28142 .4436 Metetra
.871 .486 0 r
.28142 .4436 .29443 .46306 .31505 .45922 .30207 .43994 Metetra
.882 .452 0 r
.30207 .43994 .31505 .45922 .33592 .45463 .32298 .43545 Metetra
.889 .426 0 r
.32298 .43545 .33592 .45463 .35702 .44933 .34413 .43021 Metetra
.895 .408 0 r
.34413 .43021 .35702 .44933 .37834 .44337 .36551 .42425 Metetra
.898 .397 0 r
.36551 .42425 .37834 .44337 .39987 .43679 .3871 .4176 Metetra
.899 .393 0 r
.3871 .4176 .39987 .43679 .4216 .42959 .4089 .41029 Metetra
.898 .397 0 r
.4089 .41029 .4216 .42959 .44352 .42177 .43089 .40229 Metetra
.895 .408 0 r
.43089 .40229 .44352 .42177 .46561 .41331 .45307 .3936 Metetra
.889 .426 0 r
.45307 .3936 .46561 .41331 .48789 .40418 .47543 .38417 Metetra
.882 .452 0 r
.47543 .38417 .48789 .40418 .51032 .39431 .49795 .37395 Metetra
.871 .486 0 r
.49795 .37395 .51032 .39431 .5329 .38365 .52062 .36287 Metetra
.858 .528 0 r
.52062 .36287 .5329 .38365 .55562 .3721 .54342 .35084 Metetra
.841 .578 0 r
.54342 .35084 .55562 .3721 .57845 .35955 .56634 .33777 Metetra
.821 .636 0 r
.56634 .33777 .57845 .35955 .60137 .34589 .58935 .32353 Metetra
.797 .701 0 r
.58935 .32353 .60137 .34589 .62437 .33099 .61243 .30799 Metetra
.763 .768 0 r
.61243 .30799 .62437 .33099 .64739 .3147 .63553 .291 Metetra
.621 .734 0 r
.63553 .291 .64739 .3147 .67042 .29686 .65863 .27241 Metetra
.466 .694 0 r
.65863 .27241 .67042 .29686 .6934 .27729 .68168 .25206 Metetra
.304 .647 0 r
.68168 .25206 .6934 .27729 .71629 .25583 .70462 .22976 Metetra
.139 .593 0 r
.70462 .22976 .71629 .25583 .73902 .23227 .72741 .20533 Metetra
0 .53 .019 r
.72741 .20533 .73902 .23227 .76153 .20645 .74996 .17861 Metetra
0 .482 .118 r
.08236 .3862 .09453 .41206 .1111 .42283 .09874 .39766 Metetra
.022 .548 0 r
.09874 .39766 .1111 .42283 .12825 .4315 .11573 .40698 Metetra
.175 .605 0 r
.11573 .40698 .12825 .4315 .14594 .43822 .13328 .41433 Metetra
.329 .655 0 r
.13328 .41433 .14594 .43822 .16412 .44317 .15134 .41984 Metetra
.48 .697 0 r
.15134 .41984 .16412 .44317 .18275 .44649 .16988 .42369 Metetra
.621 .734 0 r
.16988 .42369 .18275 .44649 .20179 .44834 .18885 .42601 Metetra
.75 .765 0 r
.18885 .42601 .20179 .44834 .2212 .44885 .20821 .42695 Metetra
.791 .717 0 r
.20821 .42695 .2212 .44885 .24097 .44816 .22794 .42662 Metetra
.813 .659 0 r
.22794 .42662 .24097 .44816 .26105 .44637 .24801 .42515 Metetra
.831 .609 0 r
.24801 .42515 .26105 .44637 .28142 .4436 .26838 .42263 Metetra
.845 .567 0 r
.26838 .42263 .28142 .4436 .30207 .43994 .28905 .41915 Metetra
.857 .532 0 r
.28905 .41915 .30207 .43994 .32298 .43545 .30998 .41479 Metetra
.865 .505 0 r
.30998 .41479 .32298 .43545 .34413 .43021 .33117 .40962 Metetra
.871 .486 0 r
.33117 .40962 .34413 .43021 .36551 .42425 .35259 .40366 Metetra
.875 .475 0 r
.35259 .40366 .36551 .42425 .3871 .4176 .37424 .39696 Metetra
.876 .471 0 r
.37424 .39696 .3871 .4176 .4089 .41029 .3961 .38952 Metetra
.875 .475 0 r
.3961 .38952 .4089 .41029 .43089 .40229 .41817 .38133 Metetra
.871 .486 0 r
.41817 .38133 .43089 .40229 .45307 .3936 .44042 .37239 Metetra
.865 .505 0 r
.44042 .37239 .45307 .3936 .47543 .38417 .46286 .36264 Metetra
.857 .532 0 r
.46286 .36264 .47543 .38417 .49795 .37395 .48546 .35204 Metetra
.845 .567 0 r
.48546 .35204 .49795 .37395 .52062 .36287 .50821 .34052 Metetra
.831 .609 0 r
.50821 .34052 .52062 .36287 .54342 .35084 .5311 .32799 Metetra
.813 .659 0 r
.5311 .32799 .54342 .35084 .56634 .33777 .5541 .31434 Metetra
.791 .717 0 r
.5541 .31434 .56634 .33777 .58935 .32353 .57718 .29947 Metetra
.75 .765 0 r
.57718 .29947 .58935 .32353 .61243 .30799 .60033 .28324 Metetra
.621 .734 0 r
.60033 .28324 .61243 .30799 .63553 .291 .62351 .26551 Metetra
.48 .697 0 r
.62351 .26551 .63553 .291 .65863 .27241 .64667 .24612 Metetra
.329 .655 0 r
.64667 .24612 .65863 .27241 .68168 .25206 .66977 .22492 Metetra
.175 .605 0 r
.66977 .22492 .68168 .25206 .70462 .22976 .69277 .20173 Metetra
.022 .548 0 r
.69277 .20173 .70462 .22976 .72741 .20533 .71559 .17638 Metetra
0 .482 .118 r
.71559 .17638 .72741 .20533 .74996 .17861 .73818 .14869 Metetra
0 .427 .206 r
.0704 .35825 .08236 .3862 .09874 .39766 .08656 .37045 Metetra
0 .496 .091 r
.08656 .37045 .09874 .39766 .11573 .40698 .10336 .38047 Metetra
.044 .557 0 r
.10336 .38047 .11573 .40698 .13328 .41433 .12075 .38848 Metetra
.187 .609 0 r
.12075 .38848 .13328 .41433 .15134 .41984 .13868 .39461 Metetra
.33 .655 0 r
.13868 .39461 .15134 .41984 .16988 .42369 .1571 .39903 Metetra
.467 .694 0 r
.1571 .39903 .16988 .42369 .18885 .42601 .17598 .40186 Metetra
.594 .727 0 r
.17598 .40186 .18885 .42601 .20821 .42695 .19527 .40325 Metetra
.709 .755 0 r
.19527 .40325 .20821 .42695 .22794 .42662 .21495 .40332 Metetra
.779 .746 0 r
.21495 .40332 .22794 .42662 .24801 .42515 .23498 .40219 Metetra
.798 .698 0 r
.23498 .40219 .24801 .42515 .26838 .42263 .25534 .39994 Metetra
.814 .656 0 r
.25534 .39994 .26838 .42263 .28905 .41915 .276 .39668 Metetra
.827 .621 0 r
.276 .39668 .28905 .41915 .30998 .41479 .29695 .39246 Metetra
.836 .594 0 r
.29695 .39246 .30998 .41479 .33117 .40962 .31816 .38736 Metetra
.843 .574 0 r
.31816 .38736 .33117 .40962 .35259 .40366 .33962 .38142 Metetra
.847 .563 0 r
.33962 .38142 .35259 .40366 .37424 .39696 .36132 .37465 Metetra
.848 .559 0 r
.36132 .37465 .37424 .39696 .3961 .38952 .38323 .36708 Metetra
.847 .563 0 r
.38323 .36708 .3961 .38952 .41817 .38133 .40536 .3587 Metetra
.843 .574 0 r
.40536 .3587 .41817 .38133 .44042 .37239 .42768 .34949 Metetra
.836 .594 0 r
.42768 .34949 .44042 .37239 .46286 .36264 .45019 .33941 Metetra
.827 .621 0 r
.45019 .33941 .46286 .36264 .48546 .35204 .47286 .32841 Metetra
.814 .656 0 r
.47286 .32841 .48546 .35204 .50821 .34052 .49569 .31641 Metetra
.798 .698 0 r
.49569 .31641 .50821 .34052 .5311 .32799 .51865 .30334 Metetra
.779 .746 0 r
.51865 .30334 .5311 .32799 .5541 .31434 .54172 .28908 Metetra
.709 .755 0 r
.54172 .28908 .5541 .31434 .57718 .29947 .56488 .27354 Metetra
.594 .727 0 r
.56488 .27354 .57718 .29947 .60033 .28324 .58809 .25658 Metetra
.467 .694 0 r
.58809 .25658 .60033 .28324 .62351 .26551 .61133 .23806 Metetra
.33 .655 0 r
.61133 .23806 .62351 .26551 .64667 .24612 .63454 .21782 Metetra
.187 .609 0 r
.63454 .21782 .64667 .24612 .66977 .22492 .65769 .19572 Metetra
.044 .557 0 r
.65769 .19572 .66977 .22492 .69277 .20173 .68073 .17159 Metetra
0 .496 .091 r
.68073 .17159 .69277 .20173 .71559 .17638 .70358 .14526 Metetra
0 .427 .206 r
.70358 .14526 .71559 .17638 .73818 .14869 .72618 .11656 Metetra
0 .364 .276 r
.0587 .32806 .0704 .35825 .08656 .37045 .07462 .34103 Metetra
0 .437 .193 r
.07462 .34103 .08656 .37045 .10336 .38047 .09121 .3518 Metetra
0 .501 .082 r
.09121 .3518 .10336 .38047 .12075 .38848 .10841 .3605 Metetra
.044 .557 0 r
.10841 .3605 .12075 .38848 .13868 .39461 .12618 .36729 Metetra
.175 .605 0 r
.12618 .36729 .13868 .39461 .1571 .39903 .14446 .37231 Metetra
.304 .647 0 r
.14446 .37231 .1571 .39903 .17598 .40186 .16322 .37569 Metetra
.427 .683 0 r
.16322 .37569 .17598 .40186 .19527 .40325 .18242 .37757 Metetra
.54 .713 0 r
.18242 .37757 .19527 .40325 .21495 .40332 .20203 .37807 Metetra
.642 .739 0 r
.20203 .37807 .21495 .40332 .23498 .40219 .22201 .3773 Metetra
.73 .76 0 r
.22201 .3773 .23498 .40219 .25534 .39994 .24233 .37535 Metetra
.777 .75 0 r
.24233 .37535 .25534 .39994 .276 .39668 .26298 .37232 Metetra
.791 .716 0 r
.26298 .37232 .276 .39668 .29695 .39246 .28392 .36826 Metetra
.801 .69 0 r
.28392 .36826 .29695 .39246 .31816 .38736 .30514 .36325 Metetra
.809 .671 0 r
.30514 .36325 .31816 .38736 .33962 .38142 .32663 .35731 Metetra
.813 .659 0 r
.32663 .35731 .33962 .38142 .36132 .37465 .34836 .35049 Metetra
.814 .655 0 r
.34836 .35049 .36132 .37465 .38323 .36708 .37032 .34279 Metetra
.813 .659 0 r
.37032 .34279 .38323 .36708 .40536 .3587 .3925 .3342 Metetra
.809 .671 0 r
.3925 .3342 .40536 .3587 .42768 .34949 .41487 .32471 Metetra
.801 .69 0 r
.41487 .32471 .42768 .34949 .45019 .33941 .43744 .31427 Metetra
.791 .716 0 r
.43744 .31427 .45019 .33941 .47286 .32841 .46018 .30284 Metetra
.777 .75 0 r
.46018 .30284 .47286 .32841 .49569 .31641 .48307 .29034 Metetra
.73 .76 0 r
.48307 .29034 .49569 .31641 .51865 .30334 .5061 .27669 Metetra
.642 .739 0 r
.5061 .27669 .51865 .30334 .54172 .28908 .52923 .2618 Metetra
.54 .713 0 r
.52923 .2618 .54172 .28908 .56488 .27354 .55245 .24555 Metetra
.427 .683 0 r
.55245 .24555 .56488 .27354 .58809 .25658 .57572 .22781 Metetra
.304 .647 0 r
.57572 .22781 .58809 .25658 .61133 .23806 .59901 .20846 Metetra
.175 .605 0 r
.59901 .20846 .61133 .23806 .63454 .21782 .62227 .18733 Metetra
.044 .557 0 r
.62227 .18733 .63454 .21782 .65769 .19572 .64545 .16429 Metetra
0 .501 .082 r
.64545 .16429 .65769 .19572 .68073 .17159 .66851 .13917 Metetra
0 .437 .193 r
.66851 .13917 .68073 .17159 .70358 .14526 .69138 .11182 Metetra
0 .364 .276 r
.69138 .11182 .70358 .14526 .72618 .11656 .71398 .08207 Metetra
0 .271 .291 r
.04733 .29548 .0587 .32806 .07462 .34103 .06298 .30925 Metetra
0 .369 .271 r
.06298 .30925 .07462 .34103 .09121 .3518 .07932 .32079 Metetra
0 .437 .192 r
.07932 .32079 .09121 .3518 .10841 .3605 .09631 .33022 Metetra
0 .496 .091 r
.09631 .33022 .10841 .3605 .12618 .36729 .11388 .3377 Metetra
.023 .548 0 r
.11388 .3377 .12618 .36729 .14446 .37231 .132 .34335 Metetra
.14 .593 0 r
.132 .34335 .14446 .37231 .16322 .37569 .15062 .34732 Metetra
.254 .631 0 r
.15062 .34732 .16322 .37569 .18242 .37757 .16971 .34972 Metetra
.362 .664 0 r
.16971 .34972 .18242 .37757 .20203 .37807 .18922 .35067 Metetra
.46 .692 0 r
.18922 .35067 .20203 .37807 .22201 .3773 .20912 .35028 Metetra
.547 .715 0 r
.20912 .35028 .22201 .3773 .24233 .37535 .2294 .34865 Metetra
.621 .734 0 r
.2294 .34865 .24233 .37535 .26298 .37232 .25001 .34586 Metetra
.682 .749 0 r
.25001 .34586 .26298 .37232 .28392 .36826 .27093 .34197 Metetra
.73 .76 0 r
.27093 .34197 .28392 .36826 .30514 .36325 .29215 .33705 Metetra
.764 .768 0 r
.29215 .33705 .30514 .36325 .32663 .35731 .31365 .33114 Metetra
.773 .761 0 r
.31365 .33114 .32663 .35731 .34836 .35049 .3354 .32425 Metetra
.774 .757 0 r
.3354 .32425 .34836 .35049 .37032 .34279 .35739 .31641 Metetra
.773 .761 0 r
.35739 .31641 .37032 .34279 .3925 .3342 .3796 .30761 Metetra
.764 .768 0 r
.3796 .30761 .3925 .3342 .41487 .32471 .40203 .29782 Metetra
.73 .76 0 r
.40203 .29782 .41487 .32471 .43744 .31427 .42465 .28701 Metetra
.682 .749 0 r
.42465 .28701 .43744 .31427 .46018 .30284 .44744 .27513 Metetra
.621 .734 0 r
.44744 .27513 .46018 .30284 .48307 .29034 .47038 .2621 Metetra
.547 .715 0 r
.47038 .2621 .48307 .29034 .5061 .27669 .49346 .24786 Metetra
.46 .692 0 r
.49346 .24786 .5061 .27669 .52923 .2618 .51665 .23229 Metetra
.362 .664 0 r
.51665 .23229 .52923 .2618 .55245 .24555 .53992 .21529 Metetra
.254 .631 0 r
.53992 .21529 .55245 .24555 .57572 .22781 .56324 .19675 Metetra
.14 .593 0 r
.56324 .19675 .57572 .22781 .59901 .20846 .58656 .17652 Metetra
.023 .548 0 r
.58656 .17652 .59901 .20846 .62227 .18733 .60986 .15447 Metetra
0 .496 .091 r
.60986 .15447 .62227 .18733 .64545 .16429 .63306 .13044 Metetra
0 .437 .192 r
.63306 .13044 .64545 .16429 .66851 .13917 .65613 .1043 Metetra
0 .369 .271 r
.65613 .1043 .66851 .13917 .69138 .11182 .679 .07589 Metetra
0 .271 .291 r
.679 .07589 .69138 .11182 .71398 .08207 .7016 .04506 Metetra
0 .121 .21 r
.03634 .26033 .04733 .29548 .06298 .30925 .05169 .27494 Metetra
0 .271 .291 r
.05169 .27494 .06298 .30925 .07932 .32079 .06776 .28727 Metetra
0 .364 .275 r
.06776 .28727 .07932 .32079 .09631 .33022 .0845 .29746 Metetra
0 .427 .206 r
.0845 .29746 .09631 .33022 .11388 .3377 .10185 .30565 Metetra
0 .482 .117 r
.10185 .30565 .11388 .3377 .132 .34335 .11978 .31197 Metetra
0 .53 .019 r
.11978 .31197 .132 .34335 .15062 .34732 .13824 .31653 Metetra
.083 .572 0 r
.13824 .31653 .15062 .34732 .16971 .34972 .15718 .31948 Metetra
.181 .607 0 r
.15718 .31948 .16971 .34972 .18922 .35067 .17658 .3209 Metetra
.273 .637 0 r
.17658 .3209 .18922 .35067 .20912 .35028 .19639 .32092 Metetra
.356 .662 0 r
.19639 .32092 .20912 .35028 .2294 .34865 .21659 .31962 Metetra
.427 .683 0 r
.21659 .31962 .2294 .34865 .25001 .34586 .23714 .31709 Metetra
.487 .699 0 r
.23714 .31709 .25001 .34586 .27093 .34197 .25803 .31338 Metetra
.534 .712 0 r
.25803 .31338 .27093 .34197 .29215 .33705 .27923 .30856 Metetra
.567 .72 0 r
.27923 .30856 .29215 .33705 .31365 .33114 .30071 .30267 Metetra
.588 .725 0 r
.30071 .30267 .31365 .33114 .3354 .32425 .32247 .29572 Metetra
.594 .727 0 r
.32247 .29572 .3354 .32425 .35739 .31641 .34448 .28774 Metetra
.588 .725 0 r
.34448 .28774 .35739 .31641 .3796 .30761 .36672 .27871 Metetra
.567 .72 0 r
.36672 .27871 .3796 .30761 .40203 .29782 .38918 .26861 Metetra
.534 .712 0 r
.38918 .26861 .40203 .29782 .42465 .28701 .41183 .25741 Metetra
.487 .699 0 r
.41183 .25741 .42465 .28701 .44744 .27513 .43466 .24506 Metetra
.427 .683 0 r
.43466 .24506 .44744 .27513 .47038 .2621 .45765 .23148 Metetra
.356 .662 0 r
.45765 .23148 .47038 .2621 .49346 .24786 .48078 .21661 Metetra
.273 .637 0 r
.48078 .21661 .49346 .24786 .51665 .23229 .50401 .20034 Metetra
.181 .607 0 r
.50401 .20034 .51665 .23229 .53992 .21529 .52732 .18257 Metetra
.083 .572 0 r
.52732 .18257 .53992 .21529 .56324 .19675 .55067 .16318 Metetra
0 .53 .019 r
.55067 .16318 .56324 .19675 .58656 .17652 .57402 .14205 Metetra
0 .482 .117 r
.57402 .14205 .58656 .17652 .60986 .15447 .59733 .11904 Metetra
0 .427 .206 r
.59733 .11904 .60986 .15447 .63306 .13044 .62055 .09401 Metetra
0 .364 .275 r
.62055 .09401 .63306 .13044 .65613 .1043 .64362 .06682 Metetra
0 .271 .291 r
.64362 .06682 .65613 .1043 .679 .07589 .66647 .03732 Metetra
0 .121 .21 r
.66647 .03732 .679 .07589 .7016 .04506 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15784 .20788 m
.16245 .21255 L
s
[(-5)] .14863 .19854 .98551 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54215 .0574 m
.54605 .06267 L
s
[(5)] .53436 .04684 .73896 1 Mshowa
.125 Mabswid
.19385 .19378 m
.19658 .19662 L
s
.23036 .17949 m
.23305 .18236 L
s
.26739 .16498 m
.27005 .16789 L
s
.30496 .15028 m
.30757 .15322 L
s
.38172 .12022 m
.38425 .12323 L
s
.42095 .10486 m
.42343 .10791 L
s
.46076 .08927 m
.46319 .09236 L
s
.50115 .07345 m
.50354 .07658 L
s
.12234 .22178 m
.12513 .22455 L
s
.08732 .2355 m
.09015 .23823 L
s
.05278 .24902 m
.05564 .25172 L
s
.58378 .0411 m
.58606 .0443 L
s
.62603 .02455 m
.62826 .0278 L
s
.66893 .00776 m
.67111 .01103 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[161]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00b_ooool2o`0005Cooooo0037ooooo`?o000000?oooooo`000?ooool0Doooool00<Gooooo
0_l00004ooooo`;o0000Doooool00<;ooooo0ol000000ooooooo0000ooooo`02ooooo`;o000000?o
ooooo`000?ooool0DOooool009gooooo0ol0000Pooooo`;o00001oooool00ol0003o01heo`000002
o`0005;ooooo002Looooo`05o`000?ooooooooooooooool000007?ooool3o`0000Wooooo00Ko0000
o`0N=Ol0003o0000ooooool0001Aooooo`00X?ooool00ol0003oooooooooo`0Gooooo`?o00002ooo
ool00ol0003o01heo`0N=@02o`0000;ooooo00?o0000ooooooooool0C_ooool00:3ooooo00?o0000
ooooooooool05Oooool3o`0000cooooo00Wo0000o`0N=Ol07SGo01heo`000?l07SGo0000ooooool0
0000D?ooool009cooooo1?l0000Eooooo`?o00003oooool01ol0003o01heo`0N=Ol07SGo0000o`0N
=Ol000000_ooool00ol0003oooooooooo`1=ooooo`00W?ooool00ol0003oooooooooo`0Dooooo`;o
00004Oooool00ol0003o01heo`0N=@03o`0N=@;o00000oooool00ol0003oooooooooo`1<ooooo`00
W?ooool5o`0000oooooo0ol0000Booooo`03o`000?l07SGo01he00Co01he0_l00003ooooo`03o`00
0?oooooooooo04cooooo002^ooooo`;o00005Oooool00ol0003o01heo`0N=@04o`0N=@03o`000?l0
7SGo000000?ooooo00?o0000ooooooooool0Boooool00:_ooooo0ol000000ooooooo0000ooooo`0C
ooooo`;o00001_l07SD00ol0003o01heo`000003ooooo`;o0000C?ooool00:Wooooo0_l0000Hoooo
o`04o`000?l0AD[o04E:o`0000Go01he00?o0000o`0N=Ol000001?ooool00ol0003oooooooooo`1:
ooooo`00Y_ooool3o`0001Wooooo00Go0000o`15B_l0AD[o04E:o`000005o`0N=@?o00001Oooool0
0ol0003oooooooooo`19ooooo`00Xoooool3o`0001cooooo00Go0000o`15B_l0AD[o04E:o`000005
o`0N=@04o`000?l0AD[o04E:o`0000Cooooo00?o0000ooooooooool0BOooool00:7ooooo0ol0000M
ooooo`03o`000?l0AD[o04E:00?o04E:00Co0000o`0N=Ol07SGo01he0_l00002o`15BP03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0B?ooool009kooooo0ol00003ooooo`03o`000?oooooo
oooo01Wooooo00?o0000o`15B_l0ADX01?l0ADX01?l0003o01heo`0N=Ol07SD2o`0000;o04E:00?o
0000ooooooooool01?ooool00ol0003oooooooooo`17ooooo`00W?ooool2o`00027ooooo00?o0000
o`15B_l0ADX01Ol0ADX01_l0003o01heo`0N=Ol0003o04E:o`0000?o04E:00?o0000ooooooooool0
0oooool00ol0003oooooooooo`17ooooo`00VOooool3o`0002;ooooo0_l00008o`15BP;o00000_l0
ADX01Ol0003o04E:o`15B_l0AD[o000000Kooooo00?o0000ooooooooool0A_ooool009Oooooo0ol0
000Sooooo`03o`000?l0GDKo000000So04E:00Go0000o`15B_l0AD[o04E:o`000003o`15BP03o`00
0?oooooooooo00Cooooo0_l00017ooooo`00U?ooool3o`0002Gooooo00Go0000o`1MA_l0GDKo05e6
o`000007o`15BP05o`000?l0AD[o04E:o`15B_l000001?l0ADX00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo04Gooooo002Booooo`;o00009oooool00ol0003o05e6o`1MAP02o`1MAP03o`00
0?l0AD[o04E:00Co04E:0_l00003o`15BP03o`000?l0AD[o04E:00;o04E:00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`?o0000=_ooool008oooooo0ol0000Xooooo`03o`000?l0
GDKo05e600?o05e600?o0000o`15B_l0ADX00ol0ADX01?l0003o05i5o`1NAOl00002o`15BP03o`00
0?l0AD[o04E:00;o04E:00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool00000=Oooool008gooooo0_l0000Zooooo`03o`000?l0GDKo05e600Go05e6
00Go0000o`15B_l0AD[o04E:o`000003o`1NA@04o`000?l0AD[o04E:o`0000?o04E:00?o0000o`1M
A_l000001oooool00ol0003oooooooooo`03ooooo`Go00001Oooool00ol0003oooooooooo`0coooo
o`00R_ooool3o`000003ooooool0003ooooo02Sooooo00?o0000o`1MA_l0GDH01_l0GDH01Ol0003o
04E:o`15B_l0AD[o000000?o05i500Co0000o`15B_l0AD[o00000_l0ADX01?l0003o05e6o`1MA_l0
0008ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<oooool006Sooooo0_l0000M
ooooo`?o0000;_ooool00ol0003o05e6o`1MAP06o`1MAP04o`000?l0AD[o04E:o`0000Go05i500?o
0000o`15B_l0ADX00_l00004o`1MAP03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool4o`0003Kooooo001Wooooo`04o`000?ooooooooooo`0001[ooooo0_l0000`ooooo`03o`000?l0
KCCo000000So05e60_l00006o`1NA@03o`000?l0AD[o04E:00;o00001?l0GDH00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=oooool006Oooooo00Co0000
oooooooooooo00005oooool3o`00037ooooo00Co0000o`1]=?l0KCCo00002?l0GDH00ol0003o05i5
o`1NA@05o`1NA@04o`000?l0AD[o04E:o`0000Go05e600?o0000ooooooooool01Oooool3o`0000So
oooo1Ol0000eooooo`00Ioooool01?l0003oooooooooool0000Eooooo`;o000000?oooooo`000?oo
ool0<?ooool01Ol0003o06ddo`1]=?l0KCCo000000So05e600?o0000o`1NAOl0GTD01_l0GTD3o`00
00Ko05e600?o0000ooooooooool01oooool00ol0003oooooooooo`0oooooo`00Ioooool01?l0003o
ooooooooool0000Booooo`?o0000=?ooool00ol0003o06ddo`1]=003o`1]=003o`000?l0GDKo05e6
00Co05e600?o0000o`1_<Ol000001ol0GTD00ol0003o05e6o`000006o`1MAP03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0?oooool006Oooooo00Co0000oooooooooooo00004?ooool2o`00
03Kooooo00?o0000o`1]=?l0KC@01?l0KC@00ol0003o05e6o`1MAP03o`1MAP04o`000?l0Kc7o06la
o`0000Oo05i500?o0000o`1MA_l000001ol0GDH00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03kooooo001Xooooo`;o00003_ooool3o`0003Oooooo00?o0000o`1]=?l0KC@01_l0KC@01Ol0
003o05e6o`1MA_l0GDKo000000?o06la00?o0000o`1NAOl0GTD01?l0GTD01?l0003o06lao`000?l0
0007o`1MAP03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?Oooool007Kooooo0_l00000
0ooooooo0000ooooo`0fooooo`;o00002?l0KC@01?l0003o05e6o`1MA_l00005o`1_<@03o`000?l0
GTGo05i500;o05i500?o0000o`1_<Ol0Kc400_l00006o`1MAP03o`000?l0KCCo000000Wooooo00?o
0000ooooooooool0?Oooool007?ooooo0ol0000jooooo`04o`000?l0Nago07/Mo`0000Oo06dd00?o
0000o`1MA_l000001_l0Kc401Ol0003o05i5o`1NAOl0GTGo000000Co06la00?o0000o`1MA_l0GDH0
0ol0GDH01?l0003o06ddo`1]=?l0000:ooooo`03o`000?oooooooooo03cooooo001`ooooo`?o0000
??ooool01Ol0003o07/Mo`1k7Ol0Nago000000Oo06dd0_l00007o`1_<@04o`000?l0GTGo05i5o`00
00Go06la00?o0000o`1MA_l0GDH00_l0GDH01Ol0003o06ddo`1]=?l0KCCo000000_ooooo00?o0000
ooooooooool0>oooool006kooooo0_l0000nooooo`03o`000?l0Nago07/M00;o07/M00?o0000o`1]
=?l0KC@01?l0KC@00ol0003o07hGo`000008o`1_<@;o00001_l0Kc400ol0003o05e6o`1MAP02o`1M
AP03o`000?l0KCCo06dd00;o06dd00?o0000ooooooooool01oooool2o`0003gooooo001[ooooo`Co
0000?_ooool00ol0003o07/Mo`1k7@04o`1k7@03o`000?l0KCCo06dd00;o06dd00Go0000o`1n5ol0
OQOo07hGo`000007o`1_<@03o`000?l0Kc7o06la00Go06la0_l00002o`1MAP03o`000?l0KCCo06dd
00?o06dd00?o0000ooooooooool02Oooool00ol0003oooooooooo`0jooooo`00JOooool2o`0000Co
oooo00?o0000ooooooooool0>Oooool2o`0000Oo07/M00Go0000o`1]=?l0KCCo06ddo`000004o`1n
5`03o`000?l0Kc7o06la00Go06la00?o0000o`1_<Ol0Kc401Ol0Kc42o`000003o`1MA_l0003o06dd
00Go06dd00?o0000ooooooooool02Oooool00ol0003oooooooooo`0jooooo`00I_ooool3o`00047o
oooo00?o0000o`271?l000001ol0Nad01?l0003o06ddo`1]=?l00005o`1n5`03o`000?l0Kc7o06la
00Co06la00?o0000o`205?l000001_l0Kc400ol0003o06lao`000008o`1]=003o`000?oooooooooo
00Wooooo00?o0000ooooooooool0>Oooool006?ooooo0ol00013ooooo`05o`000?l0Q`Co08L4o`27
1?l000001ol0Nad2o`0000Oo07hG00?o0000o`1_<Ol0Kc400_l0Kc401?l0003o080Do`205?l00006
o`1_<@03o`000?l0Kc7o000000So06dd00?o0000ooooooooool02_ooool00ol0003oooooooooo`0h
ooooo`00HOooool4o`0004?ooooo00?o0000o`271?l0Q`@00_l0Q`@00ol0003o07/Mo`1k7@05o`1k
7@03o`000?l0OQOo07hG00Ko07hG00Go0000o`1_<Ol0Kc7o06lao`000004o`205003o`000?l0Kc7o
06la00?o06la0_l000000ol0OQOo0000o`1]=006o`1]=003o`000?oooooooooo00[ooooo00?o0000
ooooooooool0>?ooool005oooooo0_l00016ooooo`03o`000?l0Q`Co08L400?o08L400?o0000o`1k
7Ol0Nad01?l0Nad2o`0000So07hG00Co0000o`1_<Ol0Kc7o00001Ol0P1@00ol0003o06lao`1_<@03
o`1_<@;o000000?o07hGo`000?l0KC@01Ol0KC@00ol0003o07/No`00000<ooooo`03o`000?oooooo
oooo03Oooooo001Looooo`?o0000Aoooool00ol0003o08L4o`271005o`271003o`000?l0Nago07/M
00;o07/M00Co0000o`F<0?l5S03o00002?l0OQL2o`0000Ko080D00?o0000o`1_<Ol0Kc400_l0Kc40
1Ol0003o07hGo`000?l0OQOo000000Go06dd00Co0000o`1k7_l0Nako00003?ooool2o`0003Sooooo
001Iooooo`?o0000B?ooool2o`0000So08L400Go0000o`1k7Ol0Nago07/Mo`000003o`F<0003o`00
0?l0OQOo07hG00Ko07hG00?o0000o`205?l0P1@01_l0P1@01?l0003o06lao`1_<Ol00002o`1n5`04
o`000?l0OQOo07hGo`0000?o06dd00Go0000o`1k7_l0Nako07/No`00000=ooooo`03o`000?oooooo
oooo03Kooooo000dooooo`?o00008?ooool2o`000003ooooool0003ooooo04Oooooo00?o0000oaFB
0?l000002?l0Q`@01?l0003o07/Mo`1k7Ol00005o`F<0003o`000?l0OQOo07hG00Co07hG0_l00008
o`205003o`000?l0Kc7o000000?o07hG00Co0000o`1n5ol0OQOo00000_l0KC@00ol0003o07/No`1k
7P03o`1k7P03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=Oooool003?ooooo00Go0000
ooooooooooooooooo`00000Looooo`?o0000Boooool01Ol0003o5I80oaFB0?lETP3o000000So08L4
0_l00006o`F<0003o`000?l0OQOo07hG00?o07hG00Co0000o`^>0?l;SP3o00002?l0P1@00ol0003o
07hGo`1n5`02o`1n5`06o`000?l0OQOo07hGo`000?l0KCCo00001_l0Nah00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03Cooooo000]ooooo`Go00001Oooool00ol0003oooooooooo`0Hoooo
o`;o0000COooool00ol0003o5I80oaFB0002oaFB0003o`000?l0Q`Co08L400Ko08L400?o0000o`F<
0?l5S0001Ol5S0000ol0003o07hGo`1n5`02o`1n5`05o`000?l;SP3o2hh0o`^>0?l000001ol0P1@2
o`0000Co07hG00Go0000o`1n5ol0OQOo07hGo`000007o`1k7P03o`000?oooooooooo00cooooo00?o
0000ooooooooool0=?ooool003Oooooo00?o0000ooooooooool05Oooool3o`0004kooooo00?o0000
oaFB0?lETP001?lETP000ol0003o08L4o`271004o`2710;o00002?l5S0001?l0003o07hGo`1n5ol0
0004o`^>0003o`000?l0P1Co080D00Co080D00Co0000o`^>0?l;SP3o00000ol0OQL01Ol0003o07hG
o`1n5ol0OQOo000000So07/N00?o0000ooooooooool03?ooool00ol0003oooooooooo`0cooooo`00
<oooool4o`0001Kooooo0_l000000ooooooo0000ooooo`1<ooooo`;o00001olETP000ol0003o08L4
o`271003o`271004o`000?lSU`3o8iL0o`0000Oo1H`000?o0000o`1n5ol000001_l;SP000ol0003o
080Do`205002o`205005o`000?l;SP3o2hh0o`^>0?l000000ol0OQL01_l0003o07hGo`1n5ol0003o
1H`0o`0000Oo07/N00?o0000ooooooooool03Oooool00ol0003oooooooooo`0booooo`00<oooool0
0ol0003oooooooooo`0Dooooo`?o0000D?ooool00ol0003o;Y/0o`000007oaFB0003o`000?l0Q`Co
08L400;o08L400Go0000ob>G0?lSU`3o8iL0o`000008o`F<0003o`000?l;SP3o2hh000Go2hh000Go
0000o`205?l0P1Co080Do`000004o`^>0007o`000?l0OQOo07hGo`1n5ol0003o07hGo`000002o`F<
0003o`000?l0Nako07/N00Co07/N00?o0000o`271?l000003Oooool2o`0003Cooooo000cooooo`Go
00004?ooool2o`0005;ooooo00Go0000objK0?l^V`3o;Y/0o`000007oaFB0004o`000?l0Q`Co08L4
o`0000Go8iL000?o0000o`F<0?l5S0001?l5S002o`0000Oo2hh000Co0000o`205?l0P1Co00001_l;
SP000ol0003o07hGo`1n5`02o`0000?o1H`000?o0000o`1k7_l0Nah00ol0Nah01?l0003o08L4o`27
1?l0000?ooooo`03o`000?oooooooooo037ooooo0015ooooo`?o0000Doooool00ol0003o;Y/0objK
0002objK0003o`000?lETP3o5I8000Go5I8000?o0000o`271?l000001_lSU`000ol0003o1H`0o`F<
0003o`F<0004o`000?l/VP3o;9X0o`0000Oo2hh00_l00007o`^>0004o`000?l0OQOo07hGo`0000Go
1H`000Go0000o`1k7_l0Nako07/No`000004o`271003o`000?oooooooooo00gooooo00?o0000oooo
ooooool0<?ooool004?ooooo0_l000000ooooooo0000ooooo`1Booooo`03o`000?l^V`3o;Y/000Co
;Y/000?o0000oaFB0?lETP001?lETP02o`0000Oo8iL000?o0000o`F<0?l5S0000_l5S0001Ol0003o
;9X0obbJ0?l/VP3o000000Ko2hh00_l00008o`^>0004o`000?l0OQOo0000o`0000Go1H`000Co0000
o`1k7_l0Nako00001Ol0Q`@00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo033ooooo0010
ooooo`?o0000EOooool2o`0000Oo;Y/000?o0000oaFB0?lETP000olETP000ol0003o@J40o`000008
ob>G0004o`000?l5S03o1H`0o`0000Co;9X000?o0000o`^>0?l;SP000ol;SP000ol0003o;i/0o`00
0009o`^>0003o`000?l5S03o000000Go1H`000?o0000o`1k7_l000001_l0Q`@00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02oooooo000mooooo`?o0000Eoooool00ol0003oAJ<0o`000007
objK0003o`000?lETP3o5I8000;o5I8000Go0000od6Q0?m1X@3o@J40o`000007ob>G0003o`000?l5
S03o000000Ko;9X000Go0000o`^>0?l;SP3o2hh0o`000003obnK0003o`000?l;SP3o2hh000Go2hh0
0_l000000ol5S03o0000o`F<0005o`F<0003o`000?l0Q`Co08L400Ko08L400?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0^ooooo`00>oooool2o`0005Sooooo0_l00003odFS0003o`000?l^
V`3o;Y/000Go;Y/000Co0000oaFB0?lETP3o00001?m1X@000ol0003o8iL0ob>G0005ob>G00;o0000
1ol/VP001?l0003o2hh0o`^>0?l00004obnK0003o`000?l;SP3o2hh000Co2hh000?o0000obbJ0?l/
VP000_l00006o`F<0003o`000?l0Q`Co08L400Ko08L400?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0^ooooo`00>?ooool3o`0000;ooooo00?o0000ooooooooool0E?ooool00ol0003oAJ<0
odFS0003odFS0003o`000?l^V`3o;Y/000Go;Y/000?o0000oaFB0?l000001Om1X@000ol0003o8iL0
ob>G0004ob>G0003o`000?m=Y@3o000000Oo;9X000?o0000o`^>0?l000001_l_V`000ol0003o2hh0
o`^>0002o`^>0004o`000?l/VP3o;9X0obbJ00;o00001Ol5S0000ol0003o8iL0o`000006o`271003
o`000?lDTP3o000000oooooo0_l0000_ooooo`00=_ooool2o`0005[ooooo0_l00006odFS0003o`00
0?l^V`3o;Y/000Go;Y/00_l00007od6Q0004o`000?lSU`3o8iL0ob>G00;o00000om=Y@000ol0003o
;9X0obbJ0005obbJ0003o`000?l_V`3o;i/000Ko;i/000Co0000o`^>0?l;SP3o00001?l/VP02o`00
00Co1H`000Co0000ob>G0?lSU`3o00001Ol0Q`@01?l0003o5980oaBB0?l0000Aooooo`03o`000?oo
oooooooo00Kooooo0_l0000Tooooo`00<oooool3o`0005[ooooo0_l000000omKZ@3o0000odFS0006
odFS0003o`000?l^V`3o;Y/000;o;Y/00_l000000omLZ@3o0000od6Q0006od6Q0004o`000?lSU`3o
8iL0o`0000GoCJD000?o0000obbJ0?l/VP001?l/VP02o`0000So;i/000?o0000o`^>0?l000001_l/
VP02o`0000;o1H`000?o0000ob>G0?lSU`000_lSU`001Ol0003o08L4o`271?l0Q`Co000000Co5980
00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0002?o
oooo000aooooo`?o0000Foooool00ol0003oFjT0oe^Y0002oe^Y0003o`000?m5X`3oAJ<000CoAJ<0
00Go0000objK0?l^V`3o;Y/0o`000004oebY0003o`000?m1X@3o@J4000Co@J4000?o0000ob>G0?l0
00001_m=Y@000ol0003o;9X0obbJ0003obbJ0004o`000?mDY`3oE:L0o`0000Oo;i/00_l00007obbJ
00;o000000?o1H`0o`000?lSU`001?lSU`001?l0003o08L4o`271?l00005oaBB0003o`000?oooooo
oooo00oooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Sooooo`00;_ooool3
o`0005cooooo0_l00005oe^Y0003o`000?m5X`3oAJ<000CoAJ<000Co0000objK0?l0003o00001OmL
Z@000ol0003o@J40od6Q0004od6Q00;o00002?m=Y@001Ol0003o;9X0obbJ0?l/VP3o000000?oE:L0
00?o0000obnK0?l_V`001?l_V`000ol0003oE:L0o`000007obbJ00?o00001_lSU`000ol0003o08L4
o`000006oaBB0003o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool0000Sooooo`00;?ooool2o`0005gooooo0_l00007oe^Y0003o`000?m5X`3oAJ<000CoAJ<0
0_l00007oebY0003o`000?m1X@3o@J4000?o@J4000?o0000off^0?l000002?m=Y@001?l0003o;9X0
obbJ0?l00004oeBW0003o`000?l_V`3o;i/000?o;i/000Go0000oeBW0?mDY`3oE:L0o`000007obbJ
0003o`000?lSU`3o8iL000Ko8iL000?o0000oaBB0?lDTP001_lDTP000ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00008oooool002Wooooo0ol0001Noooo
o`03o`000?m][P3o000000SoFjT000?o0000odFS0?m5X`000_m5X`000ol0003oMK40o`000008oebY
0005o`000?m1X@3o@J40od6Q0?l000000om][P000ol0003oCJD0odfU0005odfU0003o`000?l/VP3o
000000KoE:L000Go0000obnK0?l_V`3o;i/0o`000004oeBW0003o`000?l/VP3o;9X000Co;9X00_l0
0008ob>G0003o`000?lDTP3o598000Ko598000?o0000ooooooooool04?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002?ooooo000Vooooo`Co0000G_ooool2o`0000?oKJh000?o
0000oe^Y0?mKZ@001OmKZ@001Ol0003oAJ<0odFS0?m5X`3o000000?oMK4000?o0000oebY0?mLZ@00
1OmLZ@001?l0003o@J40od6Q0?l00004off^0003o`000?m=Y@3oCJD000GoCJD00_l00007oeBW0004
o`000?l_V`3o;i/0o`0000GoE:L000?o0000obbJ0?l/VP000ol/VP001?l0003oCJD0o`000?l00006
ob>G0003o`000?m1X@3o000000Ko598000?o0000objK0?l000004?ooool3o`0000Cooooo0_l0000T
ooooo`009?ooool2o`00067ooooo00?o0000off^0?m][P000om][P000ol0003oFjT0oe^Y0005oe^Y
0004o`000?m5X`3oAJ<0o`0000CoMK4000?o0000oebY0?mLZ@001OmLZ@000ol0003o@J40o`000006
off^0003o`000?m=Y@3oCJD000?oCJD000?o0000ogNa0?l000001omDY`000ol0003o;i/0o`000007
oeBW0005o`000?l/VP3o;9X0obbJ0?l000000_m=Y@02o`0000Go8iL000Co0000od6Q0?m1X@3o0000
1OlDTP001?l0003o;Y/0objK0?l0000Booooo`03o`000?oooooooooo02Sooooo000Qooooo`?o0000
HOooool2o`0000OoKJh000?o0000oe^Y0?mKZ@001OmKZ@02o`0000KoMK4000?o0000oebY0?mLZ@00
1?mLZ@02o`0000OoKJh000?o0000odfU0?m=Y@000_m=Y@001Ol0003oMk40ogNa0?mg/@3o000000Ko
E:L00_l00008oeBW0004o`000?l/VP3o;9X0o`0000;oCJD00_l000000om=Y@3o0000ob>G0002ob>G
0003o`000?m1X@3o@J4000;o@J4000Go0000oaBB0?lDTP3o5980o`000004objK0003o`000?oooooo
oooo013ooooo00?o0000ooooooooool09oooool001oooooo0_l0001Rooooo`;o000000?oO;80o`00
0?m][P001_m][P000ol0003oFjT0oe^Y0004oe^Y00;o00001ome/@000ol0003oG:T0oebY0003oebY
0003o`000?n:]P3o000000SoKJh000Co0000odfU0?m=Y@3o00001?mg/@000ol0003oE:L0oeBW0003
oeBW0003o`000?mj/P3o000000SoE:L000?o0000obbJ0?l000000ol000001?m=Y@3o0000odfU0?l0
0002ob>G0003o`000?m1X@3o@J4000?o@J4000Co0000oaBB0?lDTP3o00001Ol^V`000ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo02Oooooo000Looooo`?o000000?oooooo`000?ooool0Gooo
ool2o`0000CoO;8000?o0000off^0?m][P001Om][P001?l0003oFjT0oe^Y0?mKZ@02o`000003ohbg
0?l0003oMK4000OoMK4000?o0000oebY0?mLZ@000_l00003ohZf0003o`000?m][P3oKJh000GoKJh0
00?o0000odfU0?l000001_mg/@001Ol0003oE:L0oeBW0?mDY`3o000000?oN[8000?o0000oeBW0?mD
Y`001OmDY`03o`0000GoCJD00_l000000olSU`3o0000od6Q0005od6Q0003o`000?lDTP3o000000Ko
;Y/000?o0000ooooooooool04Oooool00ol0003oooooooooo`0Vooooo`006oooool2o`0006;ooooo
0_l00006ogbb0003o`000?m][P3oKJh000GoKJh000Co0000oe^Y0?l0003o00001?n<]`000ol0003o
MK40ogFa0005ogFa0003o`000?mLZ@3o000000GoR[H000?o0000off^0?m][P001Om][P02o`0000Oo
Mk4000Co0000oeBW0?mDY`3o00001?mj/P000ol0003oE:L0oeBW0002oeBW00?o000000?oMk40o`00
0?m=Y@001_m=Y@02o`0000So@J4000?o0000objK0?l^V`001_l^V`000ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo02Gooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooool0
0000Goooool2o`000003ohRf0?l0003oO;8000KoO;8000?o0000off^0?m][P001?m][P02o`0000Ko
S;L000?o0000ogFa0?me/@001Ome/@02o`0000OoR[H000?o0000off^0?m][P000_m][P02o`000003
oiRj0?l0003oMk4000KoMk4000?o0000oeBW0?l000001_mj/P04o`000003oeBW0?l0003oMk4000;o
Mk4000?o0000odfU0?m=Y@000om=Y@000ol0003oKJh0o`000007od6Q00;o00001ol^V`02o`0001?o
oooo0_l0000Vooooo`003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00001?ooool2o`000003ooooool0003ooooo05_ooooo0_l00004ohRf0003o`000?ml/P3oO;80
00CoO;8000?o0000off^0?m][P000om][P000ol0003oW[/0o`000007ohbg0003o`000?me/@3oMK40
00;oMK400_l000000onT_@3o0000ohZf0006ohZf0005o`000?m][P3oKJh0off^0?l000001?nH^P00
0ol0003oMk40ogNa0004ogNa00;o00001Omj/P04o`0000;oE:L000?o0000ogNa0?mg/@000_mg/@00
0ol0003oCJD0odfU0002odfU0003o`000?m][P3oKJh000;o00001Om1X@001?l0003oG:T0oebY0?l0
0005objK0004o`000?m5X`3oAJ<0o`0001;ooooo0_l0000Vooooo`001_ooool5o`0000Gooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`?o000000?oooooo`000?ooool0
F?ooool2o`0000KoR;H000?o0000ogbb0?ml/P001Oml/P000ol0003oKJh0off^0002o`0000?oW[/0
00?o0000ohbg0?n<]`001?n<]`001Ol0003oMK40ogFa0?me/@3o000000CoY;d000?o0000ohZf0?n:
]P001?n:]P001?l0003oKJh0o`000?l00005oiRj0003o`000?mg/@3oMk4000?oMk4000?o0000oijk
0?l000000_mj/P03o`0000?oN[8000?o0000oeBW0?l000001_mg/@001?l0003oCJD0odfU0?l00004
off^0003o`000?m1X@3o@J4000;o@J4000Go0000oebY0?mLZ@3oG:T0o`000004objK0005o`000?m5
X`3oAJ<0odFS0?l000005?ooool00ol0003oooooooooo`0Sooooo`003_ooool2o`0000?ooooo00Co
0000oooooooooooo00000oooool3o`000004o`0N=Ol0003oooooo`0005Kooooo0_l000000onA^03o
0000ohRf0006ohRf0003o`000?ml/P3oO;8000CoO;8000?o0000off^0?l000001OnN^`000ol0003o
S;L0ohbg0004ohbg0004o`000?me/@3o0000o`0000GoY;d000?o0000ohZf0?n:]P001?n:]P02o`00
00SoV;X000Go0000ogNa0?mg/@3oMk40o`000002oijk00?o00001_mj/P02o`0000OoMk4000?o0000
odfU0?l000001_m][P001?l0003o@J40od6Q0?l00005oebY0004o`000?l^V`3o;Y/0o`0000GoAJ<0
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Sooooo`004?ooool01?l0003ooooooooo
ool00002ooooo`07o`000?ooooooooooooooool0003oooooo`000002o`0N=@?o0000Doooool2o`00
00CoTKP000?o0000ohRf0?n8]P001?n8]P000ol0003oO;80ogbb0004ogbb00;o00001_nN^`000ol0
003oS;L0ohbg0004ohbg00;o00001onT_@000ol0003oR[H0ohZf0003ohZf0003o`000?ne`@3o0000
00SoV;X000Go0000ogNa0?mg/@3o0000oijk0002o`000003oijk0?l0003oN[8000GoN[8000?o0000
oijk0?l000002?mg/@000ol0003oKJh0off^0005off^0003o`000?m1X@3o000000KoG:T000?o0000
objK0?l000001_m5X`000ol0003oooooooooo`0Booooo`03o`000?oooooooooo02;ooooo000<oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`07o`000?oo
ooooooooo`000?l07SGo0000o`15BP02o`00053ooooo0_l00006oi6h0003o`000?n8]P3oR;H000Go
R;H000Co0000ogbb0?ml/P3oO;800_l000000on^_`3o0000oijk0006oijk0003o`000?n<]`3oS;L0
00;oS;L000?o0000ok[20?l000002?nT_@001Ol0003oR[H0ohZf0?n:]P3o000000?o]L4000?o0000
oiRj0?nH^P001OnH^P000ol0003oMk40o`000002o`0000CoW[/000Co0000ogZb0?mj/P3oN[800_l0
0003oijk0003o`000?mg/@3oMk4000CoMk400_l00008off^0003o`000?mLZ@3oG:T000KoG:T000?o
0000odFS0?m5X`001_m5X`000ol0003oooooooooo`0Booooo`03o`000?oooooooooo027ooooo000=
ooooo`?o00001?ooool2o`0000Cooooo0_l000001_oooooo0000o`0N=Ol07SGo0000o`15BP;o0000
C?ooool3o`000003oiJi0?l0003oTKP000GoTKP000?o0000ohRf0?n8]P001On8]P001?l0003oO;80
o`000?l00004ojjo0003o`000?nN^`3oW[/000CoW[/000?o0000ohbg0?n<]`000_l00003ok[20003
o`000?nT_@3oY;d000GoY;d000Co0000ohZf0?n:]P3o00001?ne`@000ol0003oV;X0oiRj0004oiRj
00?o00001onN^`001?l0003oN[80ogZb0?l00005oijk0003o`000?mg/@3oMk4000?oMk4000Co0000
oiRj0?nH^P3o00001_m][P03o`0000KoG:T00_l00007odFS00;o00005?ooool00ol0003ooooooooo
o`0Qooooo`006_ooool01?l0003oooooooooool00002o`0N=@03o`000?l0AD[o04E:00;o0000B?oo
ool3o`0000GoU[T000?o0000oi6h0?nA^0001?nA^0000ol0003oR;H0ohRf0004ohRf00;o00001_n^
_`000ol0003oW[/0oijk0004oijk0003o`000?n<]`3o000000Go^/8000?o0000ojBm0?nT_@001OnT
_@000ol0003oR[H0o`000006okG10003o`000?nH^P3oV;X000Co000000?o_l<0o`000?nN^`001_nN
^`000ol0003oN[80o`000007oijk0005o`000?mg/@3oMk40ogNa0?l000000onH^P000ol0003oKJh0
off^0003off^0003o`000?n:]P3oR[H000;o00001?mLZ@001?l0003oMK40ogFa0?l00005odFS0004
o`000?mJZ@3oFZT0o`0001?ooooo0_l0000Rooooo`006_ooool01ol0003ooooooooooooooooo0000
o`0N=Ol000000_l0ADX01?l0003o05e6o`000?l00013ooooo`?o000000?oV;X0o`000?nF^@001OnF
^@000ol0003oTKP0oi6h0004oi6h0004o`000?n8]P3oR;H0ohRf00?o000000?o^/80o`000?n^_`00
1_n^_`000ol0003oW[/0oijk0003oijk00;o00001onj`P000ol0003oY;d0ojBm0004ojBm00;o0000
1one`@03o`000003oiRj0?l0003o000000?o_l<000?o0000oijk0?nN^`001?nN^`02o`0000SoW[/0
00Co0000ogNa0?mg/@3o00001OnH^P001Ol0003oKJh0off^0?m][P3o000000?oR[H00_l00003oebY
0005o`000?me/@3oMK40ogFa0?l000001?m5X`001Ol0003oFZT0oeZY0?mJZ@3o000001Gooooo00?o
0000ooooooooool07oooool001Wooooo00?o0000ooooooooool00_ooool01?l0003o01heo`0N=Ol0
0002o`15BP04o`000?l0GDKo05e6o`0003oooooo0ol00005oiRj0003o`000?nF^@3oU[T000?oU[T0
00?o0000oi6h0?nA^0001?nA^0001?l0003oR;H0o`000?l00005ok[20003o`000?n^_`3o[[l000Co
[[l000Co0000oijk0?nN^`3oW[/00_l000000oo6_`3o0000ok[20006ok[20003o`000?nT_@3oY;d0
00?oY;d000?o0000olNn0?l000001?ne`@03o`000004okG10?l0003oV;X0o`0000Go_l<000?o0000
oijk0?nN^`000onN^`000ol0003o`l@0o`000008oijk0003o`000?mg/@3o000000KoV;X000Co0000
off^0?m][P3o00001On:]P02o`000003oebY0?l0003oMK4000CoMK4000Co0000odFS0?m5X`3o0000
1OmJZ@000ol0003oooooooooo`0Booooo`03o`000?oooooooooo01oooooo000Iooooo`;o00000ooo
ool2o`000005o`0N=Ol0003o04E:o`15B_l000000ol0GDH2o`0003[ooooo0ol000000onF^@3o0000
oiRj0005oiRj0003o`000?nF^@3oU[T000CoU[T000?o0000oi6h0?nA^0000onA^002o`0000Oo^/80
00?o0000ojjo0?n^_`001?n^_`001?l0003oW[/0o`000?l00004olJo0003o`000?nj`P3o^/8000Go
^/8000?o0000ojBm0?nT_@000_l00003olNn00Co00001?ne`@02o`0000Oo_l<000Go0000oijk0?nN
^`3oW[/0o`000003ol?40003o`000?nN^`3oW[/000GoW[/00_l00007oiRj0003o`000?m][P3o0000
00KoR[H000?o0000oebY0?l000001_me/@000ol0003oAJ<0o`000006oeZY0003o`000?oooooooooo
01?ooooo00?o0000ooooooooool07_ooool001Wooooo00?o0000ooooooooool00oooool3o`0000?o
04E:00Go0000o`1MA_l0GDKo0000o`1]=003o`0003Cooooo0ol00005oiJi0003o`000?nH^P3oV;X0
00?oV;X000?o0000oiJi0?nF^@001?nF^@001?l0003oTKP0oi6h0?nA^002o`000003ol?40?l0003o
^/8000Oo^/8000?o0000ojjo0?n^_`000on^_`02o`0000Koa[l000?o0000ok[20?nj`P001Onj`P00
0ol0003oY;d0o`000003olNn00?o00001One`@02o`000003olZg0?l0003o_l<000Ko_l<000Co0000
oijk0?nN^`3o00001?o3a0000ol0003oW[/0oijk0004oijk0003o`000?no``3o000000OoV;X00_l0
0008ohZf0003o`000?me/@3o000000KoMK4000?o0000oeZY0?mJZ@001_mJZ@000ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01gooooo000Iooooo`03o`000?oooooooooo00?ooooo00Co0000
o`15B_l0003o00000_l0ADX01Ol0003o05e6o`1MA_l0GDKo000000?o06dd0_l0000_ooooo`?o0000
00?oTKP0o`000?nF^@001OnF^@000ol0003oV;X0oiRj0004oiRj0003o`000?nF^@3oU[T000?oU[T0
00Co0000oi6h0?l0003o00001?o3a0000ol0003o^/80ok[20005ok[20004o`000?n^_`3o[[l0ojjo
00;o000000?ob[L0o`000?o6_`001_o6_`000ol0003o^/80ok[20004ok[200;o000000Coakh0o`00
0?l0003o00000oo7_P001Ol0003o]L40okG10?ne`@3o000000Cob[L000?o0000oko30?no``001?no
``000ol0003oW[/0o`000006ol?40003o`000?nN^`3oW[/000;oW[/000Go0000oko30?no``3o_l<0
o`000005oiRj0003o`000?ne`@3o000000OoR[H00_l000000ome/@3o0000ogFa0004ogFa00;o0000
1omJZ@02o`0001Gooooo00?o0000ooooooooool07Oooool001Wooooo00?o0000ooooooooool00ooo
ool00ol0003o04E:o`15BP02o`000003o`15B_l0003o05e600;o05e600Ko0000o`1]=?l0KCCo06dd
o`000?l0Nad2o`0002Wooooo1?l00005oi6h0003o`000?nF^@3oU[T000CoU[T000?o0000oiRj0?nH
^P000onH^P000ol0003oU[T0oiJi0003oiJi00;o00001_o3a0000ol0003o^/80ok[20005ok[20004
o`000?n^_`3o0000o`0000Cob[L000?o0000olJo0?o6_`001Oo6_`001?l0003o^/80ok[20?nj`P02
o`000003olbb0?l0003o000000Koakh000Co0000okG10?l0003o00001Oo:]`000ol0003o_l<0oko3
0004oko300;o00002?o3a0001?l0003oW[/0oijk0?l00004oko30003o`000?nH^P3oV;X000;oV;X0
00Go0000okG10?ne`@3o]L40o`000005ohZf0006o`000?nT_@3oY;d0o`000?me/@3o00000ome/@00
1?l0003oRkL0oh^g0?l00005oeZY0004o`000?m][P3oKJh0o`0001Gooooo00?o0000ooooooooool0
7?ooool001Wooooo0_l00005ooooo`04o`000?l0AD[o0000o`1NA@?o00000_l0GDH00ol0003o06dd
o`1]=002o`1]=003o`000?l0Nago07/M00Co00007oooool6o`0000;oR;H000?o0000oi6h0?nA^000
1?nA^0000ol0003oU[T0oiJi0004oiJi0003o`000?nH^P3oV;X000?oV;X000?o0000oiJi0?nF^@00
0ol000000oo5`P3o0000ol?40006ol?40003o`000?nj`P3o^/8000Co^/800_l00006olZg0003o`00
0?o6_`3oa[l000Goa[l000?o0000ok[20?l000001?l000000oo</P3o0000olNn0005olNn00;o0000
2?o:]`000ol0003o_l<0oko30002oko30003o`000?o</`3o000000So`l@000?o0000oijk0?l00000
1_no``001?l0003oV;X0oiRj0?l00004okG10003o`000?n:]P3oR[H000;oR[H000Go0000ojBm0?nT
_@3oY;d0o`000002ogFa0003o`000?me/@3o000000?oRkL000?o0000oeZY0?mJZ@000_mJZ@000ol0
003oKJh0off^0002off^0003o`000?oooooooooo017ooooo0_l0000Nooooo`006Oooool00ol0003o
ooooooooo`04ooooo`04o`000?l0AD[o04E:o`0000;o05i500Go0000o`1MA_l0GDKo05e6o`000003
o`1]=004o`000?l0Nago07/Mo`0000?o08L41Ol0000Eooooo`Go00000oml/P000ol0003oR;H0ohRf
0003ohRf0003o`000?nA^03oTKP000CoTKP000?o0000oiJi0?nF^@001?nF^@000ol0003oV;X0oiRj
0002oiRj00?o00001Oo5`P000ol0003o`l@0ol?40005ol?40004o`000?nj`P3o^/80ok[200;o0000
00?ocK00o`000?o:]`001_o:]`000ol0003oa[l0olJo0004olJo00Co00001?o</P000ol0003oakh0
olNn0003olNn0003o`000?o@Z03o000000Sob[L000?o0000oko30?no``000_l00003olbc0003o`00
0?o3a03o`l@000Go`l@00_l00007oko30003o`000?nH^P3o000000Ko]L4000Co0000ohZf0?n:]P3o
00001OnT_@001?l0003oMK40o`000?l00005oh^g0004o`000?mJZ@3oFZT0o`0000GoKJh000?o0000
ooooooooool04oooool00ol0003oooooooooo`0Kooooo`006?ooool00ol0003oooooooooo`05oooo
o`04o`000?l0AD[o04E:o`0000?o05i50_l000000ol0GDKo0000o`1]=002o`1]=005o`000?l0Nago
07/Mo`1k7Ol000000ol0Q`@01?l0003o5I80oaFB0?lETP0Eo`0000;oKJh000?o0000ogbb0?ml/P00
1?ml/P000ol0003oR;H0ohRf0002ohRf0003o`000?nA^03oTKP000CoTKP000?o0000oiJi0?nF^@00
1?nF^@000ol0003oV;X0o`000002o`000003olK10?l0003oaL8000GoaL8000?o0000ol?40?o3a000
1Oo3a0001?l0003o^/80o`000?l00004olf`0003o`000?o:]`3ob[L000Gob[L000Co0000olJo0?o6
_`3oa[l01?l00007olbb0003o`000?o7_P3oakh000;o00000oo@Z0000ol0003ob[L0olZg0005olZg
0003o`000?no``3o000000Goc;<000?o0000ol?40?o3a0000oo3a002o`000003olbc0?l0003o_l<0
00Ko_l<00_l00007okG10003o`000?n:]P3o000000KoY;d000Co0000ogFa0?l0003o00001On;]`00
0ol0003oFZT0o`000007off^0003o`000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool0
01Sooooo00?o0000ooooooooool01_ooool00ol0003o04E:o`000003o`1NA@04o`000?l0Kc7o0000
o`0000Co06dd00Co0000o`1k7Ol0Nago00001?l0Q`@00ol0003o5I80oaFB0002oaFB0003o`000?l^
V`3o;Y/000;o;Y/000?o0000odFS0?m5X`000_m5X`000ol0003oFjT0oe^Y0003oe^Y0003o`000?m]
[P3oKJh000?oKJh000?o0000ogbb0?ml/P000oml/P000ol0003oR;H0ohRf0003ohRf0003o`000?nA
^03oTKP000CoTKP000?o0000oiJi0?nF^@000onF^@02o`0000Goa/4000?o0000olG20?o5`P001?o5
`P000ol0003o`l@0ol?40004ol?400;o00001_o=/0000ol0003ob[L0olZg0005olZg00Co00001?o@
Y`000ol0003oc;80olbb0004olbb0003o`000?o7_P3o000000God:P000?o0000olZg0?o:]`001Oo:
]`02o`0000Ooc;<000Go0000ol?40?o3a03o`l@0o`000004olbc0003o`000?no``3o_l<000?o_l<0
00?o0000olZg0?l000001one`@02o`0000OoY;d00_l00002oh^g0003o`000?n;]`3oRkL000;oRkL0
0_l00007off^00;o00005Oooool00ol0003oooooooooo`0Jooooo`006?ooool3o`0000Kooooo00Co
0000o`15B_l0AD[o00000ol0GTD01?l0003o06lao`000?l00003o`1]=005o`000?l0Nago07/Mo`1k
7Ol000000ol0Q`@00ol0003o5I80oaFB0003oaFB0003o`000?l^V`3o;Y/000;o;Y/000?o0000odFS
0?m5X`000_m5X`000ol0003oFjT0oe^Y0003oe^Y0003o`000?m][P3oKJh000;oKJh000?o0000ogbb
0?ml/P000oml/P000ol0003oR;H0ohRf0003ohRf0003o`000?nA^03oTKP000CoTKP000?o0000oiJi
0?nF^@000ol000000oo5`P3o0000olK10004olK10003o`000?o5`P3oaL8000GoaL8000Co0000ol?4
0?o3a03o`l@00_l000000oo?Z`3o0000olf`0006olf`0003o`000?o:]`3ob[L000;ob[L01?l00006
om2W0003o`000?o</P3oc;8000Coc;800_l00007om2X0003o`000?o:]`3ob[L000?ob[L000?o0000
om:R0?l000001oo</`001?l0003o`l@0o`000?l00005olbc0003o`000?no``3o_l<000;o_l<000Go
0000olZg0?o:]`3ob[L0o`000005okG10003o`000?o7_`3o000000KoY;d000?o0000ok[20?l00000
0on;]`001_l0003oRkL0oh^g0?l0003oW[/0o`0000KoKJh000Co0000ogbb0?ml/P3o00005Oooool0
0ol0003oooooooooo`0Iooooo`002Oooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo
00Kooooo0_l000000ol0AD[o0000o`1NA@02o`1NA@03o`000?l0Kc7o06la00;o00000_l0KC@01Ol0
003o07/Mo`1k7Ol0Nago000000Co08L400?o0000oaFB0?lETP000_lETP000ol0003o;Y/0objK0002
objK0003o`000?m5X`3oAJ<000;oAJ<000?o0000oe^Y0?mKZ@000omKZ@000ol0003oKJh0off^0003
off^0003o`000?ml/P3oO;8000?oO;8000?o0000ohRf0?n8]P000on8]P000ol0003oTKP0oi6h0003
oi6h00?o00001Oo5`P000ol0003oa/40olK10003olK10003o`000?o5`P3oaL8000CoaL8000Co0000
ol?40?l0003o00001?o?Z`000ol0003ocK00olf`0004olf`0003o`000?o:]`3o000000Co000000?o
dih0o`000?o@Y`001_o@Y`000ol0003oc;80olbb0002olbb0003o`000?oDV`3o000000Sod:P000?o
0000olZg0?o:]`000_l00003om:R0003o`000?o</`3oc;<000Coc;<00_l00008olbc0004o`000?no
``3o_l<0o`0000Cob[L000?o0000okG10?ne`@000_ne`@001Ol0003oakl0olNo0?o7_`3o000000Co
Y;d000Go0000ok[20?nj`P3o^/80o`000002oh^g0003o`000?n;]`3o000000?oW[/000?o0000off^
0?m][P000_m][P000ol0003oO;80ogbb0002ogbb0003o`000?oooooooooo01?ooooo00?o0000oooo
ooooool06?ooool000[ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Oooooo0ol00003o`1NA@05o`000?l0Kc7o06lao`000?l0OQL01?l0
0003o`1k7@05o`000?l0Q`Co08L4o`271?l000001?lETP000ol0003o;Y/0objK0002objK0003o`00
0?m5X`3oAJ<000?oAJ<000?o0000oe^Y0?mKZ@000_mKZ@000ol0003oKJh0off^0003off^0003o`00
0?ml/P3oO;8000?oO;8000?o0000ohRf0?n8]P000on8]P000ol0003oTKP0oi6h0003o`000003ol?4
0?l0003oaL8000GoaL8000?o0000olK10?o6`@001?o6`@000ol0003oaL80olG20003olG200;o0000
1_o?Z`000ol0003ocK00olf`0003olf`00Go00001OoCWP000ol0003od:L0om2W0004om2W0003o`00
0?o</P3oc;8000;o00000ooDV`000ol0003od:P0om2X0005om2X0003o`000?o:]`3o000000GodZ80
00?o0000olbc0?o</`000oo</`000ol0003odZ40o`000008olbc0003o`000?no``3o000000Kob[L0
00Co0000okG10?ne`@3o00001Oo7_`001?l0003oY;d0ojBm0?l00005ok[20004o`000?n;]`3oRkL0
o`0000GoW[/000Co0000off^0?m][P3o00001Oml/P000ol0003oooooooooo`0Booooo`;o00002?oo
ool3o`0000oooooo0003ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01oooool01?l0003o05e6o`000?l00003o`1NA@04o`00
0?l0Kc7o06lao`0000?o07hG1Ol00004o`271003o`000?lETP3o5I8000;o5I8000?o0000objK0?l^
V`000_l^V`000ol0003oAJ<0odFS0002odFS0003o`000?mKZ@3oFjT000?oFjT000?o0000off^0?m]
[P000om][P000ol0003oO;80ogbb0002ogbb0004o`000?n8]P3oR;H0ohRf00Go00001Oo3a0000ol0
003oaL80olG20004olG20003o`000?o6`@3oa/4000?oa/4000?o0000olG20?o5`P000ol000000oo@
Z03o0000oln[0006oln[0003o`000?o=/03ocK0000;o000000?ocK00o`000?l000001ooCWP000ol0
003od:L0om2W0004om2W0003o`000?o</P3o000000Koe9/000?o0000om2X0?o@Z0001?o@Z002o`00
00OodZ8000?o0000olbc0?o</`000_l00003om:Q0003o`000?o</`3oc;<000Goc;<00_l00007olZg
0003o`000?ne`@3o000000Koakl000?o0000ojBm0?l000001_nj`P001Ol0003oRkL0o`000?nN^`3o
000000CoW[/000?o0000off^0?l000001oml/P000ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00000>ooooo`003?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`000?l0GDKo05e600;o0000
0_l0GTD01?l0003o06lao`1_<Ol00003o`1n5`04o`000?l5S03o1H`0o`F<00Ko00001?lETP000ol0
003o;Y/0objK0002objK0003o`000?m5X`3oAJ<000?oAJ<000?o0000oe^Y0?mKZ@000_mKZ@000ol0
003oKJh0off^0003off^0004o`000?ml/P3oO;80ogbb00Go00000onj`P000ol0003o`l@0ol?40004
ol?40003o`000?o5`P3oaL8000CoaL8000?o0000olK10?o6`@000oo6`@03o`0000God:P000?o0000
oln[0?o?Z`001?o?Z`03o`000005olf`0?l0003o0000omJH0?l000002?oCWP000ol0003od:L0om2W
0003om2W00;o00001ooDV`000ol0003od:P0om2X0002om2X00;o000000?oei<0o`000?oBXP001_oB
XP000ol0003oc;<0o`000006om:Q0003o`000?o</`3oc;<000?oc;<000?o0000om:S0?l000001oo:
]`02o`0000Ooakl00_l00007ok[200;o00000onN^`001?l0003oW[/0oijk0?nN^`02o`0000OoO;80
0_l0000Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool000Wooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool02Oooool01?l0003o05e6o`000?l0Kc43o`0000;o06la00?o0000o`1n5ol0OQL00_l0OQL01Ol0
003o1H`0o`F<0?l5S03o000000?o8iL01_l00004objK0003o`000?m5X`3oAJ<000?oAJ<000?o0000
oe^Y0?mKZ@000_mKZ@001?l0003oKJh0off^0?m][P06o`0000;o[[l000?o0000ok[20?nj`P001?nj
`P000ol0003o`l@0ol?40004ol?40003o`000?o5`P3oaL8000?oaL8000?o0000olK10?o6`@000ol0
00000oo@Y`3o0000om2X0005om2X0004o`000?o?Z`3ocj/0oln[00Co000000?ocK00o`000?l00000
1?oFV0000ol0003odih0om>N0005om>N0004o`000?o@Y`3od:L0om2W00;o000000?of940o`000?oD
V`001ooDV`001?l0003od:P0o`000?l00004omNC0003o`000?oBXP3odZ8000CodZ800_l00007om:Q
0004o`000?o</`3oc;<0olbc00;o00000ooBX`000ol0003ob[L0olZg0003olZg0003o`000?o@Z03o
000000Koakl000?o0000olbb0?l000001_nj`P000ol0003oa[l0o`000003oijk0006o`000?nN^`3o
W[/0o`000?n^_`3o00001_ml/P001?l0003oR;H0ohRf0?l0000Eooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03?ooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02Oooool01?l0003o05e6o`1MA_l00002
o`1_<@;o00000_l0Kc401Ol0003o07hGo`1n5ol0OQOo000000Co1H`000Go0000ob>G0?lSU`3o8iL0
o`000003od6Q01Co00000onN^`000ol0003o[[l0ojjo0003ojjo0003o`000?nj`P3o^/8000?o^/80
00?o0000ol?40?o3a0001?o3a0000ol0003oaL80olG20003olG200?o00001Oo@Y`000ol0003od:P0
om2X0004om2X00?o00000oo?Z`02o`0000OoeYP000?o0000om>N0?oCWP001?oCWP001?l0003od:L0
o`000?l00004omRA0003o`000?oDV`3oe9/000Goe9/00_l00006omNC0003o`000?oBXP3odZ8000?o
dZ8000?o0000omR@0?l000002?oBX@000ol0003oc;<0o`000006om:S0003o`000?o:]`3ob[L000;o
00000oo@Z0000ol0003oakl0olNo0002olNo0005o`000?o</P3oc;80olbb0?l000001?nj`P001Ol0
003oa[l0olJo0?o6_`3o000000?oW[/00_l00003ojjo0003o`000?ml/P3oO;8000;oO;8000Go0000
ohRf0?n8]P3oR;H0o`00000Fooooo`03o`000?oooooooooo00;ooooo1?l0000?ooooo`002_ooool3
o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo00Co0000o`1MA_l0GDKo00000ol0
Kc42o`000003o`1_<Ol0003o07hG00;o07hG00?o0000o`F<0?l5S0000_l5S0000ol0003o8iL0ob>G
0002ob>G0005o`000?m1X@3o@J40od6Q0?l000001?mLZ@000ol0003oMK40ogFa0003ogFa0003o`00
0?n<]`3oS;L000;oS;L000?o0000oijk0?nN^`001?nN^`000ol0003o[[l0ojjo0002ojjo0003o`00
0?nj`P3o^/8000Co^/8000?o0000ol?40?o3a0000oo3a0000ol0003oaL80olG20003o`000003om2X
0?l0003od:L000God:L000Co0000om2X0?o@Z03od:P01?l00002oln[00?o000000?oei80o`000?oF
V0001_oFV0000ol0003odih0om>N0004om>N00;o00001_oHT@000ol0003oe9/0omBK0003omBK00;o
000000?ofhL0o`000?oGT`001_oGT`000ol0003odZ80om:R0002o`0000?of90000?o0000om:Q0?oB
X@001OoBX@02o`0000OodZ<000?o0000olZg0?l000001_o@Z0001?l0003oakl0olNo0?l00005olbb
0004o`000?nj`P3o^/80o`0000Goa[l000?o0000oijk0?nN^`000_l00004ojjo0004o`000?ml/P3o
O;80o`0000GoR;H000?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000001;ooooo
000Gooooo`;o00002oooool00ol0003o05e6o`000003o`1_<@04o`000?l0P1Co0000o`0000Co07hG
00Go0000o`F<0?l5S03o1H`0o`000004ob>G0003o`000?m1X@3o@J4000;o@J4000?o0000oebY0?mL
Z@000_mLZ@000ol0003oMK40ogFa0003ogFa0003o`000?n<]`3oS;L000;oS;L000?o0000oijk0?nN
^`000onN^`000ol0003o[[l0ojjo0003ojjo0003o`000?nj`P3o^/8000?o^/8000?o0000ol?40?o3
a0000oo3a003o`0000God:P000?o0000om2W0?o@Y`001?o@Y`03o`0000?od:P00ol00005omNB0003
o`000?oFV03oeYP000GoeYP000?o0000om>N0?oCWP000ol000000ooKR03o0000omRA0006omRA0005
o`000?oDV`3oe9/0omBK0?l000001?oKQ`000ol0003oei<0omNC0004omNC0003o`000?oBXP3o0000
00Gof90000?o0000om:Q0?oBX@000ooBX@02o`000003omR@0?l0003odZ<000KodZ<00_l00007om2X
0003o`000?o7_`3o000000Koc;8000?o0000ok[20?l000001_o6_`001Ol0003oW[/0o`000?n^_`3o
000000Co[[l000?o0000ogbb0?l000001On8]P02o`0001Gooooo0_l00003ooooo`Go00003_ooool0
01Oooooo00?o0000ooooooooool02_ooool2o`000003o`1MA_l0003o06la00;o06la00?o0000o`20
5?l0P1@00_l00002o`1n5`03o`000?l5S03o1H`000;o1H`000Go0000ob>G0?lSU`3o8iL0o`000004
od6Q0003o`000?mLZ@3oG:T000;oG:T000?o0000ogFa0?me/@000ome/@000ol0003oS;L0ohbg0002
ohbg0003o`000?nN^`3oW[/000CoW[/000?o0000ojjo0?n^_`000on^_`000ol0003o^/80ok[20002
ok[20003o`000?o3a03o`l@000?o000000?ocj/0o`000?o@Z0001Oo@Z0001?l0003od:L0om2W0?o@
Y`04o`0000?od:P00_l000000ooHT03o0000omNB0006omNB0003o`000?oFV03oeYP000CoeYP00ol0
0005om^80003o`000?oHT@3of94000Cof94000Co0000omBK0?l0003o00001OoKQ`000ol0003oei<0
omNC0004omNC00;o00001ooHT0001Ol0003odZ40om:Q0?oBX@3o000000Cof90000?o0000om:S0?oB
X`000ooBX`000ol0003oei@0o`000007om2X00;o00001oo</P02o`0000Ooa[l00_l00003ojjo0004
o`000?n^_`3o[[l0ojjo00;o00001On8]P001?l0003oT;P0oi2h0?l0000Fooooo`03o`000?oooooo
oooo01?ooooo000Fooooo`03o`000?oooooooooo00cooooo0ol00003o`1_<@05o`000?l0P1Co080D
o`000?l;SP000ol00004o`F<0003o`000?lSU`3o8iL000;o8iL000?o0000od6Q0?m1X@000_m1X@00
0ol0003oG:T0oebY0002oebY0003o`000?me/@3oMK4000?oMK4000?o0000ohbg0?n<]`000_n<]`00
0ol0003oW[/0oijk0003oijk0003o`000?n^_`3o[[l000?o[[l000Co0000ok[20?nj`P3o^/801?l0
0005oln[0003o`000?o@Z03od:P000Cod:P00ol00003om2W0004o`000?o@Z03o0000o`0000Cof900
00?o0000omNB0?oGTP001?oGTP000ol0003oeYP0omJH0002omJH00;o000000?ogH40o`000?oKR000
1OoKR0000ol0003of940omRA0004omRA00;o00002?oKQ`001?l0003oei<0omNC0?oGT`02o`000003
omf10?l0003of90000Kof90000Co0000om:Q0?l0003o00001_oHT0000ol0003odZ<0om:S0002o`00
00?oei@000?o0000om2X0?o@Z0000oo@Z0000ol0003oe9`0o`000006olbb0003o`000?o@Y`3o0000
00Koa[l000?o0000olZg0?l000001?n^_`001Ol0003o[[l0o`000?nj`P3o000000CoR;H000?o0000
oi2h0?n@^0000_n@^0000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo000Foooo
o`03o`000?oooooooooo00cooooo00?o0000o`1]=?l000001?l0Kc401?l0003o080Do`205?l00003
o`^>00Go00001?lSU`000ol0003o@J40od6Q0002od6Q0003o`000?mLZ@3oG:T000;oG:T000?o0000
ogFa0?me/@000ome/@000ol0003oS;L0ohbg0002ohbg0003o`000?nN^`3oW[/000?oW[/000Co0000
ojjo0?n^_`3o[[l01_l00002olf`0003o`000?o?Z`3ocj/000Cocj/000?o0000om2X0?o@Z0000_o@
Z003o`0000God:L00_l00006omR@0003o`000?oGTP3oei8000Goei8000Co0000omJH0?l0003o0000
1?oMP@000ol0003ofhP0om^80004om^80004o`000?oHT@3of940omRA00;o000000?ogW`0o`000?oK
Q`001ooKQ`001?l0003oei<0o`000?l00004omf10003o`000?oHT03of90000Cof9000_l00008omR@
0003o`000?oBX`3o000000Koei@000?o0000om2X0?o@Z0000_l00003omBL0003o`000?o</P3oc;80
00;oc;8000Go0000om2W0?o@Y`3od:L0o`000004olJo0005o`000?o:]`3ob[L0olZg0?l000001?n^
_`001Ol0003o^/80ok[20?nj`P3o000000;oR;H000?o0000oi2h0?n@^0001?n@^0000ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo000Fooooo`;o00003Oooool00ol0003o06ddo`1]
=002o`0000;o06la00Co0000o`205?l0P1Co00000ol;SP001?l0003o;9X0obbJ0?l/VP06o`0000Co
@J4000?o0000oebY0?mLZ@000omLZ@000ol0003oMK40ogFa0002ogFa0003o`000?n<]`3oS;L000;o
S;L000Co0000oijk0?nN^`3oW[/01_l00003olZg0003o`000?o=/03ocK0000?ocK0000?o0000oln[
0?o?Z`001?o?Z`04o`0000;od:P000?o0000om2W0?o@Y`000ol000000ooIS`3o0000omR@0006omR@
0003o`000?oGTP3oei8000Coei800_l00006omf10003o`000?oKR03ofhP000CofhP000Co0000omRA
0?l0003o00001?oNO0000ol0003ofhL0om^70005om^700;o00001ooMP@001?l0003of900omR@0?oH
T002o`000003omio0?l0003of90000Oof9000_l00007omND0003o`000?o@Z03o000000Koe9`000Co
0000olbb0?o</P3o00001Oo@Y`001?l0003oa[l0olJo0?l00005olZg0003o`000?n^_`3o[[l000;o
00000onj`P000ol0003oR;H0o`000006oi2h00;o00005_ooool00ol0003oooooooooo`0Aooooo`00
5_ooool00ol0003oooooooooo`0=ooooo`04o`000?l0KCCo0000o`1n5`?o00000ol0P1@01Ol0003o
2hh0o`^>0?l;SP3o000000?o;9X000Co0000odfU0?m=Y@3oCJD02_l000000omLZ@3o0000ogFa0002
ogFa00[o00000oo6_`000ol0003ob[L0olZg0004olZg0003o`000?o=/03ocK0000?ocK0000Co0000
oln[0?o?Z`3ocj/01?l00004om2X00?o00001OoIS`000ol0003of900omR@0005omR@0004o`000?oG
TP3oei80omNB00;o000000?ogW`0o`000?oMP@001_oMP@000ol0003ofhP0om^80003om^800;o0000
1ooNO0000ol0003ofhL0om^70002om^700;o000000?ohG@0o`000?oMP@001_oMP@001?l0003of900
o`000?l00004omio0003o`000?oHT03of90000?of9000_l000000ooMP@3o0000omND0006omND00;o
00001ooDW0000ol0003oc;80o`000006om2W0003o`000?o6_`3o000000Kob[L000?o0000ojjo0?l0
00000_nj`P001Ol0003o^/80ok[20?nj`P3o000000KoT;P000Co0000oiJi0?nF^@3o00005_ooool0
0ol0003oooooooooo`0@ooooo`005_ooool00ol0003oooooooooo`0=ooooo`04o`000?l0KCCo06dd
o`0000?o07hG0_l00002o`205004o`000?l;SP3o2hh0o`0000Co;9X000Go0000odfU0?m=Y@3oCJD0
o`000004off^0004o`000?n:]P3oR[H0ohZf00Go00000_nT_@000ol0003o^/80ok[20002ok[20003
o`000?o6_`3oa[l000Coa[l000?o0000olZg0?o:]`000oo:]`000ol0003ocK00olf`0003olf`00Co
00000oo?Z`000ol0003od:P0o`000002o`000003omR@0?l0003ofHl000KofHl000?o0000omR@0?oH
T0001?oHT0001?l0003oei80o`000?l00004omil0003o`000?oMP@3ogH4000CogH4000?o0000om^8
0?oKR0000ol000000ooQL`3o0000omil0007omil0004o`000?oKQ`3o0000o`0000CohG@000?o0000
omf10?oMP@001?oMP@02o`0000OogWl000Go0000omR@0?oHT03of900o`000004omf10003o`000?oG
U03oei@000?oei@000?o0000om^70?l000001ooDW002o`0000Ood:L00_l00007olZg00;o00001?nj
`P001?l0003o^/80o`000?l00005oi2h0003o`000?nF^@3oU[T000;oU[T000?o0000ooooooooool0
4_ooool2o`0001;ooooo000Fooooo`03o`000?oooooooooo00gooooo00Co0000o`1]=?l0KCCo0000
0ol0OQL00ol0003o2hh0o`000002o`0000?o2hh000Go0000obbJ0?l/VP3o;9X0o`000004odfU0003
o`000?m][P3oKJh000;oKJh000?o0000ohZf0?n:]P000_n:]P000ol0003oY;d0ojBm0003ojBm0003
o`000?nj`P3o^/8000;o^/8000?o0000olJo0?o6_`000oo6_`000ol0003ob[L0olZg0004olZg0003
o`000?o=/03ocK0000Co00000oo?Z`04o`0000Gof90000?o0000omV?0?oIS`001?oIS`000ol0003o
f900omR@0004omR@00;o00001_oNO0000ol0003ogH40omf10004omf100?o00001OoQL`000ol0003o
gW`0omil0005omil00;o00001ooQM0001?l0003ogH40omf10?oMP@02o`000003on9`0?l0003ogWl0
00KogWl000Co0000omR@0?l0003o00001_oMP@000ol0003oei@0omND0002o`0000?ofhL000?o0000
omBL0?oDW0000ooDW0000ol0003of940o`000006om2W0003o`000?oCWP3o000000Kob[L000?o0000
olf`0?l000001Onj`P001?l0003o`l@0ol?40?l00003oi2h0003o`000?nF^@3oU[T000CoU[T000?o
0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`005_ooool00ol0003oooooooooo`0>
ooooo`;o000000?o06ddo`000?l0OQL00_l0OQL01?l0003o2hh0o`^>0?l;SP02o`0000;o2hh000Go
0000obbJ0?l/VP3o;9X0o`000003odfU0003o`000?m][P3oKJh000;oKJh000?o0000ohZf0?n:]P00
0on:]P000ol0003oY;d0ojBm0002ojBm0003o`000?nj`P3o^/8000;o^/8000?o0000olJo0?o6_`00
1?o6_`000ol0003ob[L0olZg0003olZg00?o00000oo=/004o`0000?oei8000?o0000omR@0?oHT000
1?oHT0000ol0003ofHl0omV?0004omV?0003o`000?oHT03of90000?o000000?oggT0o`000?oNO000
1_oNO0001?l0003ogH40omf10?oMP@02o`000003on=]0?l0003ohG<000KohG<000?o0000omil0?oN
O0000_oNO002o`000003onAZ0?l0003ohG@000KohG@000Co0000omf10?l0003o00001?oRL0000ol0
003ogWl0omio0004omio00;o00002?oMP@000ol0003oei@0o`000006om^70003o`000?oDW03oe9`0
00;o00000ooHT@000ol0003od:L0om2W0002om2W0005o`000?oCWP3odih0om>N0?l000001?o:]`00
1Ol0003ocK00olf`0?o=/03o000000?o^/800_l00003ol?40003o`000?n@^03o000000KoU[T00_l0
000Fooooo`03o`000?oooooooooo00kooooo000Eooooo`03o`000?oooooooooo00oooooo00?o0000
o`1k7_l000000_l00002o`1n5`06o`000?l;SP3o2hh0o`^>0?l0003o;i/00ol00003obbJ0003o`00
0?m=Y@3oCJD000;oCJD000?o0000off^0?m][P000_m][P000ol0003oR[H0ohZf0002ohZf0003o`00
0?nT_@3oY;d000?oY;d000?o0000ok[20?nj`P000_nj`P000ol0003oa[l0olJo0004olJo0003o`00
0?o:]`3o000000?o00000_o=/003o`000003omJH0?l0003oei8000Goei8000?o0000omR@0?oHT000
0ooHT0000ol0003ofHl0omV?0004omV?00?o00001OoON@000ol0003ogW`0omil0004omil0004o`00
0?oMP@3o0000o`0000Cohfd000?o0000on5c0?oQL`001OoQL`001?l0003ogW`0o`000?l00004onAZ
0003o`000?oQM03ohG@000CohG@00_l00007on9`0004o`000?oNO`3ogWl0omio00;o000000?ohW00
o`000?oMP@001ooMP@02o`0000OofhL000?o0000omBL0?l000001_oHT@001?l0003od:L0om2W0?l0
0005om>N0004o`000?o:]`3ob[L0o`0000GocK0000?o0000ok[20?l000000_o3a0000ol0003o`l@0
ol?40002o`0000KoU[T000Co0000oiNj0?nG^P3o00005Oooool00ol0003oooooooooo`0>ooooo`00
5Oooool00ol0003oooooooooo`0@ooooo`04o`000?l0Nako07/No`0000?o07hG00Go0000o`^>0?l;
SP3o2hh0o`000003obnK00Co00001Om=Y@000ol0003oKJh0off^0002off^0003o`000?n:]P3oR[H0
00;oR[H000?o0000ojBm0?nT_@000_nT_@000ol0003o^/80ok[20003ok[20003o`000?o6_`3oa[l0
00;oa[l00ol00002olZg00Co00001OoFV0000ol0003oei80omNB0003omNB0003o`000?oHT03of900
00Cof90000?o0000omV?0?oIS`000ol000000ooPN03o0000ommi0006ommi0003o`000?oNO03ogW`0
00?ogW`00_l00007on=]0003o`000?oQL`3ohG<000CohG<00_l00007onAZ0004o`000?oQM03ohG@0
on5d00;o000000?oiV@0o`000?oRL0001_oRL0001?l0003ogWl0o`000?l00004on9`0003o`000?oM
P@3ogH4000CogH4000?o0000on5d0?l000001ooKQ`02o`0000Oof94000?o0000om2W0?l000001_oC
WP000ol0003ob[L0o`000006olf`00;o00001?o3a002o`000003olG30?l0003oU[T000CoU[T000Go
0000oiNj0?nG^P3oUkX0o`00000Fooooo`03o`000?oooooooooo00gooooo000Eooooo`03o`000?oo
oooooooo013ooooo00Co0000o`1k7_l0Nako07/N0_l000000ol0OQOo0000o`^>0002o`^>0005o`00
0?l_V`3o;i/0obnK0?l000000_mDY`05o`000003odfU0?l0003oKJh000?oKJh000?o0000ohZf0?n:
]P000_n:]P000ol0003oY;d0ojBm0002ojBm0003o`000?nj`P3o^/8000?o^/8000?o0000olJo0?o6
_`001ol00002om>N0003o`000?oFV03oeYP000CoeYP000?o0000omNB0?oGTP001?oGTP000ol0003o
f900omR@0003omR@00?o00001OoPN0000ol0003oggT0ommi0004ommi0003o`000?oNO03ogW`000?o
000000?oiFP0o`000?oSK@001_oSK@000ol0003ohG<0on5c0002on5c00;o000000?oiV40o`000?oT
JP001_oTJP001?l0003ohG@0o`000?l00004onIT0003o`000?oRL03ohW0000CohW000_l00007on9`
0004o`000?oMP@3ogH40omf100;o00000ooQM0000ol0003ofhL0om^70003om^70003o`000?oNO03o
000000Oof9400_l00007om>N00;o00001_o=/0000ol0003ocZ/0o`000004ol?40005o`000?o5``3o
aL<0olG30?l000000onF^@000ol0003oUkX0oiNj0002oiNj00;o00005Oooool2o`0000kooooo000E
ooooo`;o00004_ooool01Ol0003o07/No`1k7_l0003o1H`000;o00001?l;SP001Ol0003o;i/0obnK
0?l_V`3o000000;oE:L000Co0000ogNa0?mg/@3oMk406_l00003om2W0003o`000?oCWP3odih000?o
dih000?o0000omJH0?oFV0001?oFV0000ol0003oei80omNB0003omNB0003o`000?oHT03of90000?o
000000?oggT0o`000?oPN0001_oPN0000ol0003oggT0ommi0003ommi00?o00001OoUJ0000ol0003o
hfd0on=]0005on=]0004o`000?oQL`3o0000o`0000CoiV4000?o0000onAZ0?oTJP001?oTJP02o`00
00OoiV@000Co0000on9`0?oRL03ohW000_l000000ooVHP3o0000on9`0007on9`0003o`000?oMP@3o
000000KohG@000?o0000om^70?oKQ`000_l00003omil0003o`000?oHT@3of94000?of94000?o0000
om^80?l000001_oCWP000ol0003oeYP0o`000005olf`0005o`000?o>Z`3ocZ/0olj[0?l000000_o3
a0000ol0003oaL<0o`000003olG30003o`000?nF^@3o000000CoUkX000?o0000oiJi0?l000005Ooo
ool2o`0000kooooo0007ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool04_ooool0
1?l0003o07/No`1k7_l00002o`F<00;o00000_l;SP001Ol0003o;i/0obnK0?l_V`3o000000?oE:L0
00?o0000ogNa0?mg/@000_mg/@000ol0003oV;X0oiRj0002oiRj0003o`000?ne`@3o]L4000;o]L40
00?o0000olNn0?o7_P000_o7_P000ol0003oc;80o`000002o`000003olbb0?l0003od:L000God:L0
00?o0000om>N0?oCWP000ooCWP000ol0003oeYP0omJH0003omJH0004o`000?oGTP3oei80omNB00Go
00001OoON@000ol0003oh7P0on1h0004on1h0003o`000?oON@3oggT000?o000000?oiFD0o`000?oU
J0001_oUJ0000ol0003ohfd0on=]0004on=]00;o00001ooVH@001?l0003oi6X0onAZ0?oTJP02o`00
0003onQJ0?l0003oiV@000KoiV@000Co0000on9`0?l0003o00001?oVHP000ol0003ohW00on9`0005
on9`00;o00001ooQM0000ol0003ofhL0o`000006omil0003o`000?oHT@3of94000;o00000ooKR000
1?l0003odih0om>N0?oCWP02o`0000?oeYP000Go0000olf`0?o=/03ocK00o`000004olj[0003o`00
0?o3a03o000000?oaL<000?o0000olG30?o5``000_l00004oiNj0005o`000?nF^@3oU[T0oiJi0?l0
00005_ooool00ol0003oooooooooo`0;ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool04_ooool01?l0003o07/No`1k7_l00002o`F<
0003o`000?l/VP3o000000;o00001?l_V`001?l0003oE:L0oeBW0?l00005ogNa0003o`000?nH^P3o
V;X000;oV;X000?o0000okG10?ne`@000_ne`@000ol0003oakh0olNn0003o`0000Goc;8000?o0000
om2W0?o@Y`000oo@Y`000ol0003odih0om>N0003om>N0003o`000?oFV03oeYP000?oeYP01?l00003
omil0003o`000?oON@3oggT000GoggT000?o0000on1h0?oPN0000ooPN003o`0000GoiFD000?o0000
onEX0?oUJ0001OoUJ0000ol0003ohfd0on=]0003o`000003onQK0?l0003oiV4000KoiV4000Co0000
onAZ0?l0003o00001?oXFP000ol0003oiV@0onIT0004onIT00;o00001ooVHP001?l0003ohW00on9`
0?oRL003o`000003onIT0?l0003ohG@000KohG@00_l00007omil0003o`000?oHT@3o000000KofhP0
00?o0000om>N0?l000001_oFV0000ol0003ocK00o`000005olj[00;o00001Oo5``02o`000003olK2
0?l0003oUkX000;oUkX000?o0000oiJi0?nF^@000onF^@000ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00_ooooo0005o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo01Cooooo0_l000001Ol0Nako0000o`F<0?l5S03o000000?o
;9X00_l00002obnK0005o`000?mDY`3oE:L0oeBW0?l000001?mg/@000ol0003oV;X0oiRj0002oiRj
0003o`000?ne`@3o]L4000;o]L400ol00003olNn0003o`000?o</P3oc;8000;oc;8000?o0000om2W
0?o@Y`001?o@Y`000ol0003odih0om>N0003om>N0003o`000?oFV03o000000;o000000?ogH40o`00
0?oNO0001OoNO0000ol0003oggT0ommi0004ommi0003o`000?oPN03oh7P000?o000000?oiV@0o`00
0?oUI@001_oUI@000ol0003oiFP0onEX0004onEX00?o00001OoXF`000ol0003oiV40onIQ0004onIQ
00;o00001ooXFP001?l0003oiV@0onIT0?oVI002o`000003onUG0?l0003oiV8000KoiV8000Co0000
on9`0?l0003o00001OoVI0000ol0003ohG@0on5d0002on5d00;o000000?oi6X0o`000?oNO0001_oN
O002o`0000OofhP00_l00007omJH00;o00001Oo>Z`000ol0003od:P0o`000005olG30007o`000?o6
`P3oa/80olK20?l0003oUkX0o`000006oiJi00;o00005Oooool00ol0003oooooooooo`0:ooooo`00
2?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool05?ooool01?l0003o08L4o`000?l00002o`F<0006o`000?l/VP3o;9X0obbJ0?l0003oE:L00ol0
0004oeBW0003o`000?mg/@3oMk4000;oMk4000?o0000oiRj0?nH^P000_nH^P04o`000003okG10?l0
003oakh000?oakh000?o0000olbb0?o</P000oo</P000ol0003od:L0om2W0003om2W0004o`000?oC
WP3odih0om>N00Co00001OoMP@000ol0003ogW`0omil0004omil0003o`000?oON@3oggT000?oggT0
0ol00005onIT0003o`000?oUI@3oiFD000GoiFD000?o0000onEX0?oUJ0000ol000000ooYEP3o0000
onQK0006onQK0004o`000?oVH@3oiV40onIQ00;o000000?oje80o`000?oXFP001_oXFP001?l0003o
iV@0o`000?l00004onUG0003o`000?oVHP3oiV8000CoiV800_l00008onIT0004o`000?oQM03o0000
o`0000Coi6X000?o0000omil0?oNO0000_oNO002o`000003on5c0?l0003ofhP000GofhP000?o0000
omf10?l000001_oFV0000ol0003oei<0o`000004olj[0005o`000?o@Z03od:P0om2X0?l000000oo5
``000ol0003oa/80o`000003olK20003o`000?nF^@3oU[T000CoU[T000Co0000oi2h0?n@^03o0000
5Oooool00ol0003oooooooooo`09ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo0_l0000Fooooo`03o`000?l0Q`Co000000?o1H`000Go0000obbJ0?l/VP3o
;9X0o`000003oeBW00Go00001?mg/@000ol0003oV;X0oiRj0003o`0000Go]L4000?o0000olNn0?o7
_P000_o7_P000ol0003oc;80olbb0002olbb0004o`000?o@Y`3od:L0om2W00Ko00000ooKR0000ol0
003ogH40omf10004omf10003o`000?oNO03ogW`000CogW`000?o0000ommi0?l000000_l000000ooU
I@3o0000onIT0006onIT0003o`000?oUI@3oiFD000CoiFD00ol00005onUF0003o`000?oXF`3oj5/0
00Coj5/000Co0000onIQ0?l0003o00001?o[DP000ol0003oj5X0onQJ0004onQJ00;o00001ooYE`00
1?l0003oiV80onIR0?oVHP02o`000003onUG0?l0003oiV@000OoiV@00_l00007onAZ0004o`000?oN
O03o0000o`0000CohG<000Co0000om^80?oKR03ofhP00_l00003omf10004o`000?oFV03oeYP0omJH
00;o00000ooGT`001?l0003ocZ/0olj[0?l00005om2X0003o`000?o5``3o000000?oa/8000Co0000
olK20?l0003o00001OnF^@000ol0003oT;P0oi2h0002oi2h0003o`000?oooooooooo01;ooooo0_l0
000:ooooo`001oooool2o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0Eooooo`03o`000?l0Q`Co08L400;o00000_l5S0001?l0003o;9X0obbJ0?l00003oeBW0004o`00
0?mj/P3oN[80ogZb00So00000_nH^P000ol0003o]L40okG10003okG10004o`000?o7_P3oakh0olNn
00[o00000ooHT@000ol0003ofhP0om^80004om^80003o`000?oMP@3ogH4000?ogH4000?o0000omil
0?oNO0001?oNO002o`0000GoiFD000?o0000onIT0?oVI0001?oVI0000ol0003oiFD0onEU0002onEU
00;o000000?ojU@0o`000?oYEP001_oYEP000ol0003oj5/0onQK0003onQK00;o00001oo[DP001?l0
003oj5X0onQJ0?oXFP02o`000003ona=0?l0003ojEL000KojEL000Co0000onIR0?l0003o00001?oY
E`000ol0003oiV@0onIT0004onIT0003o`000?oXFP3o000000Ooi6X00_l00007on5c0003o`000?oK
R03o000000KogH4000?o0000omJH0?l000001OoGT`000ol0003ocZ/0o`000006om2X00;o00001Oo6
`P001?l0003oaL<0olG30?l00003oiJi0003o`000?n@^03oT;P000;oT;P00_l0000Eooooo`03o`00
0?oooooooooo00Sooooo0008ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oo
oooooooo01Kooooo00Co0000o`271?l0003o8iL00ol00003obbJ0005o`000?mDY`3oE:L0oeBW0?l0
00000omj/P0Co`0000;od:P000?o0000omBK0?oDV`000_oDV`000ol0003of940omRA0004omRA0003
o`000?oKR03ofhP000CofhP000?o0000omf10?oMP@000ooMP@000ol0003ogW`0omil0003o`000003
onEX0?l0003oiFD000GoiFD000?o0000onIT0?oVI0001?oVI0001?l0003oiFD0o`000?l00004onYD
0003o`000?oYEP3ojEH000CojEH000?o0000onQK0?oXF`000ol000000oo]C03o0000on]B0006on]B
0004o`000?oXFP3o0000o`0000Cok4d000?o0000onUG0?oYE`001?oYE`02o`0000OojEL000Co0000
onIT0?oVI03oiV@00_l00003onQJ0003o`000?oTJP3oi6X000?oi6X000?o0000onIQ0?l000001ooQ
L`02o`0000OogH400_l00006omNC00;o00001_o@Z0000ol0003od:L0o`000004olK200;o00000oo5
``000ol0003oU[T0o`000004oi2h0004o`000?n8]P3oR;H0o`0001?ooooo0ol00009ooooo`005?oo
ool00ol0003oooooooooo`0Fooooo`04o`000?l0Q`Co08L4o`0000?o8iL00_l000000ol/VP3o0000
oeBW0002oeBW0003o`000?mj/P3oN[8000?o00000onN^`000ol0003o_l<0oko30002oko30003o`00
0?o:]`3ob[L000?ob[L000?o0000om2X0?o@Z0000oo@Z0000ol0003oe9/0omBK0002omBK0003o`00
0?oHT@3of94000Cof94000?o0000om^80?oKR0000ooKR0001?l0003ogH40omf10?oMP@05o`0000Go
iFP000?o0000onEU0?oUI@001?oUI@001?l0003oiV@0onIT0?oVI004o`0000OojU@000?o0000onUF
0?oYEP000ooYEP03o`0000GokD`000?o0000on]B0?o[DP001?o[DP02o`0000Ook4d000Co0000onUG
0?oYE`3ojEL00_l00002one;0003o`000?oYE`3ojEL000GojEL000?o0000onIT0?l000001_oXFP00
0ol0003oi6X0onAZ0002o`0000?oiV4000?o0000on5c0?oQL`000ooQL`000ol0003ohfd0o`000006
omf10003o`000?oNO03o000000Goei<000?o0000omR@0?l000001Oo@Z0001Ol0003od:L0om2W0?o@
Y`3o000000;oa/8000Co0000olG30?o5``3o00000_o5``02o`0000CoT;P000?o0000ohRf0?n8]P00
0_n8]P000ol0003oooooooooo`0=ooooo`?o00000_ooool00ol0003oooooooooo`07ooooo`004ooo
ool2o`0001Wooooo0ol00003ob>G0004o`000?m=Y@3o0000o`0000?oE:L00ol00002ogZb0003o`00
0?nN^`3oW[/000;oW[/000?o0000oko30?no``000_no``000ol0003ob[L0olZg0003olZg0003o`00
0?o@Z03od:P000;od:P000?o0000omBK0?oDV`000ooDV`000ol0003of940omRA0004omRA0004o`00
0?oKR03ofhP0om^800Go00000ooSK@000ol0003oiFP0onEX0005onEX0003o`000?oUI@3oiFD000?o
iFD01?l00003on]C0003o`000?oZE03ojU@000GojU@000?o0000onUF0?oYEP000ol000000oo^B03o
0000one<0006one<0003o`000?o[DP3oje8000?o000000?okTD0o`000?o/C@001_o/C@001?l0003o
jEL0o`000?l00005one;0003o`000?oYE`3ojEL000CojEL00_l00007onQJ0003o`000?oTJP3o0000
00KoiV4000?o0000on5c0?oQL`000_l00003on=]0004o`000?oMP@3ogH40omf100;o00000ooNO000
0ol0003oei<0omNC0002o`0000?of90000Go0000om2X0?o@Z03od:P0o`000004om2W0003o`000?o6
`P3o000000CoaL<00_l000000oo3a03o0000oi2h0002oi2h0003o`000?n8]P3oR;H000;oR;H000?o
0000ogbb0?l000002oooool3o`0000Gooooo00?o0000ooooooooool01oooool001?ooooo00?o0000
ooooooooool06?ooool01?l0003o5980o`000?l00003ob>G0003o`000?m=Y@3oCJD000Go00001?mj
/P000ol0003oW[/0oijk0002oijk0003o`000?no``3o_l<000;o_l<000?o0000olZg0?o:]`000_o:
]`000ol0003od:P0om2X0003om2X0003o`000?oDV`3oe9/000?oe9/000Co0000omRA0?oHT@3of940
1_l00002on5c0003o`000?oSK@3ohfd000Cohfd000?o0000onEX0?oUJ0001?oUJ0000ol0003oiFD0
onEU0003o`000003onYD0?l0003oje<000Goje<000?o0000onYD0?oZE0001?oZE003o`0000GokTP0
00?o0000one<0?o]C0001?o]C003o`0000GokTD000?o0000ona=0?o/C@001?o/C@02o`0000SokD/0
00?o0000onUG0?oYE`000ol000000oo/C@3o0000onQJ0006onQJ00;o00001ooVH@000ol0003ohG<0
o`000006on=]0003o`000?oMP@3o000000GogW`000?o0000omNC0?l000001_oHT0000ol0003od:P0
o`000005om2W00;o00001Oo5``001ol0003o`l@0ol?40?o3a03o0000oi2h0?l000001?n8]P001?l0
003oO;80ogbb0?ml/P02o`0000Gooooo1?l00008ooooo`03o`000?oooooooooo00Oooooo000Coooo
o`03o`000?oooooooooo01Wooooo00?o0000oaBB0?l000000olSU`04o`0000?oMk401_l00004oijk
0003o`000?no``3o_l<000;o_l<000?o0000olZg0?o:]`000oo:]`000ol0003od:P0om2X0002om2X
0004o`000?oDV`3oe9/0omBK00Ko00000ooNO0000ol0003ohG<0on5c0003on5c0003o`000?oSK@3o
hfd000Cohfd000?o0000onEX0?oUJ0000ooUJ003o`0000GojU@000?o0000on]C0?o[D`001?o[D`00
0ol0003ojU@0onYD0003o`000003oni50?l0003okTP000KokTP000Co0000one<0?o]C03okD`00_l0
00000oo`?`3o0000oni50006oni50003o`000?o/C@3ok4d000?o00000_o_@P000ol0003okD/0one;
0005one;00?o00001Oo/C@000ol0003oj5X0onQJ0002onQJ00;o000000?oje80o`000?oVH@001_oV
H@02o`0000Oohfd00_l00006omil00;o00001ooHT002o`0000God:L000Co0000om2X0?o@Z03o0000
0oo5``000ol0003o`l@0o`000002ol?400?o00000on8]P000ol0003oO;80ogbb0002ogbb0004o`00
0?m][P3o0000ooooo`?o00002oooool00ol0003oooooo`000008ooooo`004oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?lDTP3o598000?o000000Go8iL0o`000?m=Y@3oCJD0o`000003ogNa0004
o`000?nN^`3oW[/0oijk00Go000000?oW[/0o`000?no``000ono``000ol0003ob[L0olZg0002olZg
0004o`000?o@Z03od:P0om2X00Go00000ooKQ`000ol0003ogW`0omil0004omil0003o`000?oQL`3o
hG<000?ohG<000?o0000on=]0?oSK@000ooSK@000ol0003oiFP0onEX0003o`000003onUF0?l0003o
jU@000KojU@000?o0000on]C0?o[D`000oo[D`03o`0000GokTD000?o0000oni80?o^B0001?o^B000
1?l0003okD`0o`000?l00004oo0o0003o`000?o^A@3okTD000CokTD00ol00006onm20003o`000?o]
B`3okD/000;okD/00_l000000oo_@P3o0000ona=0006ona=0004o`000?oXFP3o0000o`0000Coje80
00?o0000onIQ0?oVH@000_oVH@02o`000003onQK0?l0003ohfd000Gohfd000?o0000onEX0?l00000
1OoNO0000ol0003oggT0o`000006omR@0004o`000?oIS`3ofHl0o`0000?od:L000?o0000om2X0?o@
Z0000_o@Z0000ol0003oaL<0o`000003ol?400;o00000onj`P000ol0003oR;H0o`000004ogbb0005
o`000?m][P3oKJh0off^0?l000003_ooool00ol0003oooooo`000008ooooo`004oooool2o`0001[o
oooo1?l000001?m1X@3o0000o`000?l00003odfU0005o`000?mg/@3oMk40ogNa0?l000000onN^`00
1?l0003o`l@0ol?40?o3a00?o`0000;oei<000?o0000om^70?oKQ`001?oKQ`000ol0003ogW`0omil
0004omil0003o`000?oQL`3ohG<000?ohG<000Co0000on=]0?oSK@3ohfd01?l00005onUF0003o`00
0?oZE03ojU@000CojU@000?o0000on]C0?o[D`000ol000000oo_A03o0000oni50006oni50003o`00
0?o^B03okTP000?okTP00_l00007oo0o0004o`000?o^A@3okTD0oni500;o000000?olCX0o`000?o_
@P001oo_@P001?l0003okD/0o`000?l00004onm20003o`000?o/C@3ok4d000Cok4d00_l00007on]B
0004o`000?oVH@3o0000o`0000Coj5/000Co0000on=]0?oSK@3ohfd00_l00003onEX0003o`000?oN
O03ogW`000;o00000ooON@001?l0003of900omR@0?oHT002o`0000CofHl000?o0000om2W0?l00000
1Oo@Z002o`0000Co`l@00_l00003ok[200;o00001?ml/P001ol0003oKJh0off^0?m][P3o0000oeZY
0?l000003?ooool01?l0003oooooooooool00008ooooo`004oooool00ol0003oooooooooo`0Foooo
o`?o000000Goooooo`000?lDTP3o5980o`000003od6Q00;o000000?oCJD0o`000?mg/@000omg/@00
1Ol0003oW[/0oijk0?nN^`3o000000Co`l@000?o0000olbc0?o</`000_o</`000ol0003odZ80om:R
0002om:R0003o`000?oGT`3oei<000?oei<000?o0000om^70?oKQ`000ooKQ`000ol0003ogW`0omil
0004omil0004o`000?oQL`3ohG<0on5c00Ko00000_oXF`000ol0003ojEH0onUF0005onUF0003o`00
0?oZE03ojU@000?ojU@00ol00005onm40003o`000?o^A@3okTD000CokTD000?o0000oni80?o^B000
0ol00002oo4k0003o`000?o`?`3ol3l000Col3l000Co0000oni50?l0003o00001?oa>P000ol0003o
kd80onm20005onm200;o00001oo_@P001?l0003ok4d0ona=0?o/C@02o`000003oni50?l0003oje80
00Koje800_l00007onQK0003o`000?oSK@3o000000GoiFP000?o0000omil0?l000001_oON@000ol0
003of900o`000006omV?00;o00001Oo@Z0000ol0003ocZ/0o`000003ol?40003o`000?nj`P3o0000
00;o^/8000?o0000ojjo0?l000000oml/P001Ol0003oKJh0off^0?m][P3o000000;oFZT00ol00009
ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`004oooool00ol0003oooooooooo`0Coooo
o`?o00001Oooool2o`000006oaBB0?l0003o@J40od6Q0?l0003oKJh00ol00003ogNa0003o`000?nN
^`3oW[/000;oW[/000?o0000ol?40?o3a0000_o3a0000ol0003oc;<0olbc0002olbc0003o`000?oB
XP3odZ8000;odZ8000?o0000omNC0?oGT`000ooGT`000ol0003ofhL0om^70003om^70003o`000?oN
O03ogW`000?ogW`01?l00003onIQ0003o`000?oXF`3oj5/000?oj5/000?o0000onUF0?oYEP001OoY
EP000ol0003ojU@0o`000002o`000003oni50?l0003okd@000Kokd@000?o0000oni50?o^A@000oo^
A@03o`0000KolC/000?o0000oo0o0?o`?`000oo`?`02o`0000OolCX000?o0000onm20?o_@P000_o_
@P02o`000003oo4i0?l0003okd8000Kokd8000Co0000ona=0?l0003o00001?o^A@000ol0003oje80
on]B0002on]B00;o000000?okD`0o`000?oXF`001_oXF`02o`0000KoiFP00_l00007ommi00;o0000
1_oIS`000ol0003of900o`000003om2X00;o00000oo>Z`000ol0003o`l@0o`000003ok[200;o0000
0on^_`000ol0003oO;80o`000003off^0004o`000?mJZ@3oFZT0o`0000?oAJ<00_l00006ooooo`;o
00000oooool00ol0003oooooooooo`06ooooo`004_ooool00ol0003oooooooooo`0Booooo`;o0000
2?ooool01?l0003o;Y/0o`000?l00003od6Q0004o`000?m][P3oKJh0off^00Go00000onN^`000ol0
003o`l@0ol?40003ol?40003o`000?o</`3oc;<000;oc;<000?o0000om:R0?oBXP000_oBXP000ol0
003oei<0omNC0003omNC0003o`000?oKQ`3ofhL000;ofhL000?o0000omil0?oNO0000ol000000ooT
JP3o0000onIQ0005onIQ0003o`000?oXF`3oj5/000?oj5/000?o0000onUF0?oYEP001?oYEP02o`00
00GokTD000?o0000onm40?o_A0001?o_A0000ol0003okTD0oni50003o`0000;olCT000?o0000oo4k
0?oa>`001Ooa>`000ol0003ol3l0o`000002o`0000;olSD000?o0000oo4j0?oa>P001Ooa>P001?l0
003okd80o`000?l00004oo4i0003o`000?o_@P3okd8000Cokd800_l00007oni50004o`000?o[DP3o
0000o`0000CokD`000?o0000onQK0?oXF`000_oXF`02o`000003onUG0?l0003oiFP000?oiFP00_l0
0002onEU0003o`000?oON@3oggT000;oggT00_l00002on1h0004o`000?oIS`3ofHl0omV?00;o0000
0ooHT0000ol0003od:P0o`000005olj[00?o00000onj`P02o`0000?o[[l00_l00003off^0004o`00
0?mJZ@3oFZT0o`0000?oAJ<000?o0000objK0?l^V`001ol00004ooooo`03o`000?oooooooooo00Ko
oooo000Booooo`;o00004?ooool3o`0000_ooooo00Co0000objK0?l^V`3o00000om1X@001?l0003o
KJh0off^0?l00003oiRj00Ko00001?o3a0000ol0003oc;<0olbc0002olbc0003o`000?oBXP3odZ80
00?odZ8000Co0000omNC0?oGT`3oei<02Ol00005onAZ0003o`000?oVH@3oiV4000CoiV4000?o0000
onQK0?oXF`000ooXF`000ol0003ojEH0onUF0003o`000003oni80?l0003okTD000GokTD000?o0000
onm40?o_A0000oo_A003o`0000KolCT000?o0000oo4k0?oa>`001?oa>`02o`0000KolSD000?o0000
oo4j0?oa>P001?oa>P02o`0000OolCT000?o0000onm20?o_@P000ol000000ooa>P3o0000oni50006
oni500;o00001oo]C0001?l0003oj5/0o`000?l00004onUG0004o`000?oUJ03o0000o`0000GoiFD0
00Co0000ommi0?l0003o00001OoPN0000ol0003ofHl0o`000005omR@00;o00001Oo>Z`001ol0003o
cK00olf`0?o=/03o0000ok[20?l000000_n^_`000ol0003o[[l0o`000002oijk0003o`000?m][P3o
000000;oFZT000Go0000odFS0?m5X`3oAJ<0o`000002objK0006o`000?lDTP3o0000o`271?l0003o
07/N0_l00004ooooo`03o`000?oooooooooo00Kooooo000Booooo`03o`000?oooooooooo00cooooo
0ol0000?ooooo`03o`000?l^V`3o;Y/000;o000000?o@J40o`000?m][P000_m][P001Ol0003oV;X0
oiRj0?nH^P3o000000?o_l<05?l00002omf10003o`000?oQM03ohG@000?ohG@000?o0000onAZ0?oT
JP001?oTJP000ol0003oiV40onIQ0003onIQ0004o`000?oXF`3oj5/0onQK00Go00001Oo^B0000ol0
003okTD0oni50004oni50003o`000?o_A03o000000;o00000_ob>0000ol0003olCT0oo4i0005oo4i
0003o`000?oa>`3olC/000?o000000?olc40o`000?ob=@001_ob=@000ol0003olCX0oo4j0003o`00
0003oo<b0?l0003olCT000KolCT00ol00005oo4j0003o`000?o^A@3okTD000;okTD00_l000000oo`
?`3o0000one<0006one<00;o00001_oYE`02o`0000OoiFD00_l00007on1h00;o00001OoHT0001?l0
003oei<0omNC0?l00003olj[0003o`000?o=/03ocK0000;ocK000_l00003ojjo00;o00000onN^`03
o`000003oeZY0?l0003oAJ<000;oAJ<000Wo0000objK0?l^V`3o0000oaBB0?l0003o08L4o`000?l0
Nah00_l00006ooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00Wooooo
0ol0000Booooo`05o`000?l^V`3o;Y/0o`000?mLZ@000ol00003off^0005o`000?nH^P3oV;X0oiRj
0?l000000ono``000ol0003oc;<0olbc0002olbc0003o`000?oBX@3odZ4000;odZ4000?o0000omR@
0?oHT0000ooHT0000ol0003ogH40omf10003omf10003o`000?oQM03ohG@000?ohG@000?o0000onAZ
0?oTJP001?oTJP001?l0003oiV40onIQ0?oVH@05o`0000?okD`000?o0000oni80?o^B0001Oo^B000
0ol0003okTD0oni50003oni500;o00001_ob>0000ol0003olCT0oo4i0004oo4i00?o00001Ooc<@00
0ol0003olSD0oo8e0004oo8e00?o00001Ooc<P000ol0003olCT0oo4i0002oo4i00;o000000?olc80
o`000?oa>P001_oa>P001?l0003okTD0o`000?l00004oo0o0003o`000?o]C03okD`000;okD`00_l0
00000oo^B03o0000onUG0003onUG00;o000000?ojU@0o`000?oUI@001OoUI@000ol0003oiV@0o`00
0006on1h0003o`000?oON@3o000000?of9000_l00004omNC0003o`000?o>Z`3o000000CocK0000?o
0000olZg0?l000000on^_`02o`0000;oW[/000Go0000oh^g0?n;]`3oRkL0o`000003odFS0009o`00
0?l^V`3o;Y/0o`000?lDTP3o0000o`271?l0003o07/N00;o00001oooool00ol0003oooooooooo`05
ooooo`004_ooool00ol0003oooooooooo`06ooooo`?o00005_ooool01?l0003o;Y/0objK0?l00003
oebY00Co00001?nH^P001Ol0003o_l<0oko30?no``3o000000Coc;<000?o0000om:Q0?oBX@000_oB
X@000ol0003of900omR@0003omR@0003o`000?oMP@3ogH4000?ogH4000?o0000on5d0?oQM0000ooQ
M0001?l0003oi6X0onAZ0?oTJP06o`0000;oje8000?o0000one<0?o]C0001?o]C0000ol0003okTP0
oni80004oni80003o`000?o^A@3okTD000?o000000?olCT0o`000?ob>0001_ob>0000ol0003olCT0
oo4i0003o`000003oo@_0?l0003olc4000Kolc4000?o0000oo8e0?ob=@000ol000000ood;@3o0000
oo<b0006oo<b0004o`000?oa>@3o0000o`0000Colc8000?o0000oo4j0?oa>P001?oa>P02o`0000Oo
l3l000Co0000one<0?l0003o00001?o^B0001?l0003ojEL0o`000?l00004onYD0004o`000?oUI@3o
iFD0onEU00;o00000ooVI0001?l0003oh7P0on1h0?oPN002o`0000?oggT000?o0000omR@0?l00000
1_oGT`02o`0000CocK0000Oo0000olZg0?o:]`3ob[L0o`000?n^_`3o000000;oW[/00_l00004oh^g
00;o000000[oAJ<0o`000?l^V`3o;Y/0o`000?lDTP3o0000o`271?l0003o07/N0_l00008ooooo`03
o`000?oooooooooo00Gooooo000Booooo`;o00001?ooool3o`0001[ooooo0_l000001Ol^V`3o0000
oebY0?mLZ@3o000000;oR[H01_l00004oko30003o`000?o</`3oc;<000;oc;<000?o0000om:Q0?oB
X@000_oBX@000ol0003of900omR@0003omR@0003o`000?oMP@3ogH4000;ogH4000Co0000on5d0?oQ
M03ohG@01_l00003onQJ0003o`000?o[DP3oje8000?oje8000?o0000one<0?o]C0001?o]C0001?l0
003okTP0oni80?o^B005o`0000GolCT000?o0000oo8h0?ob>0001?ob>003o`0000Gom2l000?o0000
oo<a0?oc<@001?oc<@03o`0000Gom2d000?o0000oo<b0?oc<P001?oc<P02o`0000Oolc8000?o0000
oo4j0?oa>P000ol00002oo8e0003o`000?o`?`3ol3l000Col3l00_l00006oni800;o00001ooZE000
0ol0003oiFD0o`000006onIT0003o`000?oPN03o000000GoggT00_l00006omNC0003o`000?oFV03o
000000?ocK0000?o0000olZg0?o:]`000_o:]`02o`0000?oW[/000?o0000oh^g0?n;]`000_n;]`00
0ol0003oMK40ogFa0002o`000004objK0?l0003o5980o`0000;o08L41?l00008ooooo`03o`000?oo
oooooooo00Gooooo000Aooooo`04o`000?ooooooooooooooo`?o00007Oooool01?l0003oAJ<0o`00
0?l00003oebY0004o`000?n:]P3oR[H0o`0000?o]L401_l00005olbc0003o`000?oBX@3odZ4000;o
dZ4000?o0000omR@0?oHT0000_oHT0001?l0003ogH40omf10?oMP@05o`0000?oiV@000?o0000onQJ
0?oXFP001?oXFP000ol0003oje80on]B0003on]B0003o`000?o]C03okD`000?okD`01?l00003oo4k
0003o`000?oa>@3olCT000GolCT000?o0000oo8h0?ob>0000ol000000ood;P3o0000oo@_0006oo@_
0003o`000?oc<@3olc4000?o000000?omRT0o`000?od;@001_od;@000ol0003olc80oo<b0003o`00
0003ooD[0?l0003olc8000Kolc800ol00006oo8e0003o`000?o`?`3ol3l000?o000000?olC/0o`00
0?o^B0000oo^B002o`000003oni50?l0003ojU@000KojU@00_l00007onIT00;o00001OoON@001?l0
003ogW`0omil0?l00003omNC00;o00000ooFV0000ol0003ocK00o`000004olZg0008o`000?o6_`3o
a[l0o`000?nN^`3o0000oh^g0?l00002oh^g0004o`000?me/@3oMK40o`0000;oG:T01?l000000ol0
Q`Co0000o`000002o`0000Wooooo00?o0000ooooooooool01Oooool000[ooooo0_l00005ooooo`Co
00008Oooool00ol0003oAJ<0odFS0002o`0000;oG:T000Co0000ohZf0?n:]P3o00000one`@001?l0
003ob[L0olZg0?o:]`0Do`0000;ohW0000?o0000onIT0?oVI0001?oVI0000ol0003oj5X0onQJ0004
onQJ0003o`000?o[DP3oje8000?oje8000?o0000one<0?l000000_l00002oo0o0003o`000?oa>`3o
lC/000?olC/000?o0000oo4i0?oa>@001?oa>@03o`0000Gom2h000?o0000oo@_0?od;`001?od;`03
o`0000GomRT000?o0000oo@]0?od;@001?od;@03o`0000GomB/000?o0000oo<b0?oc<P000_oc<P02
o`000003oo@]0?l0003olSD000KolSD00ol00005oo4k0004o`000?o^B03o0000o`0000CokTD000?o
0000onYD0?oZE0000_oZE002o`0000;oje<000?o0000onIT0?oVI0000_oVI002o`000003onEU0?l0
003oggT000;oggT00_l00004omil0003o`000?oGT`3o000000GoeYP00ol00003olZg0003o`000?o6
_`3oa[l000;oa[l00_l00002oh^g00;o00000_me/@001?l0003oG:T0oebY0?l00002od6Q0004o`00
0?lSU`3o0000o`F<00;o00002_ooool00ol0003oooooooooo`05ooooo`002Oooool01?l0003ooooo
ooooool00004ooooo`;o00009?ooool01?l0003oAJ<0o`000?me/@03o`0000?oR[H000Go0000okG1
0?ne`@3o]L40o`000003olZg0003o`000?oBX`3odZ<000?odZ<000?o0000omR@0?oHT0000_oHT000
0ol0003ogWl0omio0002omio0003o`000?oRL03ohW0000?ohW0000?o0000onIT0?oVI0001?oVI000
0ol0003oj5X0onQJ0003onQJ0004o`000?o[DP3oje80on]B00Co00001_o`?`000ol0003olC/0oo4k
0003oo4k0003o`000?oa>@3olCT000?o000000?om2l0o`000?od;P001_od;P000ol0003om2l0oo@_
0003o`000003ooHW0?l0003omRT000KomRT000?o0000oo@]0?od;@000ol000000oof9P3o0000ooD[
0006ooD[0004o`000?oc<P3o0000o`0000Com2d000?o0000oo8e0?ob=@000_ob=@02o`000003oo<a
0?l0003olC/000GolC/00_l00007oni50004o`000?oZE03o0000o`0000Goje<000Co0000onIT0?l0
003o00001?oUI@000ol0003oggT0o`000006omil00;o00001OoFV0001ol0003odih0om>N0?oCWP3o
0000olZg0?l000001?o6_`001Ol0003o^/80ok[20?l0003oRkL000;o000000GoMK40o`000?mLZ@3o
G:T0o`000002od6Q0004o`000?lSU`3o0000o`F<00?o00002_ooool00ol0003oooooooooo`05oooo
o`002Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo027ooooo00Co0000odFS
0?m5X`3o00000ome/@05o`0000?o]L4000Go0000olZg0?o:]`3ob[L0o`000005om:S0003o`000?oH
T03of90000;of90000?o0000omio0?oNO`000_oNO`000ol0003ohW00on9`0003on9`0003o`000?oV
I03oiV@000?oiV@000Co0000onQJ0?oXFP3oj5X01_l00003oni50003o`000?o`?`3ol3l000Gol3l0
00Co0000oo4k0?oa>`3olC/01?l00005oo@_0003o`000?od;P3om2h000Com2h00ol00005ooHW0003
o`000?of:@3omRT000ComRT00ol00005ooHV0003o`000?oe:`3omB/000ComB/00_l00007oo@]0004
o`000?ob=@3o0000o`0000Colc4000Co0000oo4k0?oa>`3olC/00_l000000ooa>@3o0000oni50006
oni500;o00001oo[D`02o`0000KoiFD00_l00006omil0003o`000?oMP@3o000000?oeYP00_l00004
om>N00;o00001?o6_`001?l0003o^/80ok[20?nj`P05o`0000;oG:T000Oo0000od6Q0?m1X@3o0000
ob>G0?l0003o1H`000?o00003?ooool00ol0003oooooooooo`04ooooo`002Oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo027ooooo0_l000001Om5X`3o0000ogFa0?me/@3o0000
00?oY;d01_l00003olZg0003o`000?oBX`3odZ<000?odZ<000?o0000omR@0?oHT0000_oHT0000ol0
003ogWl0omio0002omio0003o`000?oRL03ohW0000?ohW0000Co0000onIT0?oVI03oiV@01Ol00003
ona=0003o`000?o^A@3okTD000CokTD000?o0000oo0o0?o`?`001?o`?`04o`0000?olc4000?o0000
oo@_0?od;`001?od;`000ol0003om2h0oo@^0003o`000003ooHV0?l0003omRL000KomRL000?o0000
ooHY0?of:@000ol000000oog8`3o0000ooHV0006ooHV0003o`000?oe:`3omB/000?o00000_of9P00
0ol0003om2d0oo@]0004oo@]00;o00001ooc<@000ol0003olC/0o`000004oo4i0003o`000?o^A@3o
kTD000;okTD00_l00002onm40003o`000?o[D`3oje<000;oje<00_l00002onYD0004o`000?oUI@3o
iFD0onEU00;o00000_oUJ0001?l0003ogW`0omil0?oNO002o`0000?ogH4000?o0000omJH0?l00000
1OoCWP000ol0003od:L0o`000003olJo0005o`000?nj`P3o^/80ok[20?l000000_nT_@03o`000008
oebY0?l0003o@J40od6Q0?l0003o8iL0o`000?l5S004o`0000cooooo00?o0000ooooooooool01?oo
ool000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0Pooooo`03o`000?mJ
Z@3o000000;o00000_me/@001Ol0003oY;d0ojBm0?nT_@3o000000?oakl01_l00004om:S0003o`00
0?oHT03of90000;of90000?o0000omio0?oNO`000ooNO`001?l0003ohW00on9`0?oRL005o`0000?o
jEL000?o0000ona=0?o/C@000oo/C@000ol0003okTD0oni50004oni50003o`000?o`?`3ol3l000?o
000000?olSD0o`000?oc<@001Ooc<@000ol0003om2l0oo@_0003oo@_00?o00001Oof9P000ol0003o
mRL0ooHW0004ooHW00?o00001Oog8`000ol0003omRH0ooHV0004ooHV00?o00001_of9P000ol0003o
m2d0oo@]0003o`0000;omRT000?o0000oo<a0?oc<@001?oc<@02o`0000KolCT000Co0000oni50?l0
003o00001Oo_A0001?l0003oje<0o`000?l00005onYD0003o`000?oUI@3o000000GoiFP000?o0000
omil0?l000001OoMP@02o`0000Godih000Oo0000om2W0?o@Y`3od:L0o`000?o6_`3o000000;o^/80
0_l00002ojBm0003o`000?n:]P3oR[H000?o000000Go@J40o`000?lSU`3o0000o`F<0004o`0000go
oooo00?o0000ooooooooool01?ooool000Wooooo00Co0000oooooooooooo00002Oooool2o`00027o
oooo00Co0000oeZY0?mJZ@3oFZT00_l000000ome/@3o0000ojBm0002ojBm0005o`000?o7_`3oakl0
olNo0?l000000oo@Z00Do`0000;oiV8000?o0000onUG0?oYE`001?oYE`000ol0003ok4d0ona=0003
ona=0004o`000?o^A@3okTD0oni500Go00001Oob=@000ol0003olc40oo<a0004oo<a0003o`000?od
;`3o000000;o00000_of9`000ol0003omRH0ooHV0004ooHV0003o`000?of9`3omRL000?o000000?o
n240o`000?og8`001_og8`000ol0003omRH0ooHV0003o`0000;omb8000?o0000ooHV0?of9P001?of
9P03o`0000KomRT000?o0000oo<a0?oc<@000ol000000ood;`3o0000oo4i0005oo4i00;o00001oo_
A002o`0000OojU@00_l00006onEX00;o00001OoMP@001?l0003ofhP0om^80?l00003om>N0003o`00
0?o@Y`3od:L000;od:L00ol000000onj`P3o0000ojBm0002ojBm0004o`000?n:]P3oR[H0o`0000;o
KJh02Ol0000>ooooo`03o`000?oooooooooo00Cooooo000:ooooo`;o00003?ooool00ol0003ooooo
ooooo`0Oooooo`05o`000?mJZ@3oFZT0o`000?n;]`000_l00004ojBm0005o`000?o7_`3oakl0olNo
0?l000000oo@Z0000ol0003oei@0omND0002omND0003o`000?oMP@3ogH4000?ogH4000?o0000on9`
0?oRL0000_oRL0000ol0003oiV80onIR0003onIR0003o`000?oYE`3ojEL000CojEL000Co0000ona=
0?o/C@3ok4d01Ol00003oo4j0003o`000?ob=@3olSD000GolSD000Co0000oo<a0?oc<@3olc401?l0
0006ooHW0003o`000?of9P3omRH000?omRH00ol00005ooPQ0003o`000?og8`3omb<000Comb<00ol0
0006ooLR0003o`000?of9P3omRH000?o000000?omb<0o`000?of:@001_of:@03o`0000Gom2l000?o
0000oo4i0?oa>@000ol00002oo8h0003o`000?o_A03okd@000;okd@00_l00002oni50003o`000?oZ
E03ojU@000;ojU@00_l000000ooYE`3o0000onEX0003onEX00;o00000_oSK@001Ol0003ogH40omf1
0?oMP@3o000000CofhP000?o0000om>N0?l000001?o@Y`001Ol0003oc;80olbb0?o</P3o000000?o
Y;d000Co0000ohZf0?n:]P3o00000om][P000ol0003oCJD0odfU0005o`0000oooooo00?o0000oooo
ooooool01?ooool001Wooooo00?o0000ooooooooool07oooool01?l0003oFZT0oeZY0?l00002oh^g
00Go00001?o7_`001Ol0003od:P0om2X0?o@Z03o000000Coei@000?o0000omf10?oMP@000ooMP@00
0ol0003ohW00on9`0002on9`0003o`000?oVHP3oiV8000?oiV8000Co0000onUG0?oYE`3ojEL01_l0
0003onm20003o`000?oa>P3olCX000?olCX000?o0000oo8e0?ob=@001?ob=@04o`0000?omRT000?o
0000ooHW0?of9`001Oof9`000ol0003omRH0o`000002o`0000;on24000?o0000ooPQ0?oh8@001?oh
8@000ol0003omb<0ooLS0003o`0000;on1h000?o0000ooLR0?og8P001?og8P03o`0000Gomb<000?o
0000ooHY0?of:@000_of:@02o`000003ooHW0?l0003om2l000Gom2l00ol00006oo8h0004o`000?o_
A03o0000o`0000GokTD000Co0000onYD0?l0003o00001?oYE`001?l0003oiFP0o`000?l00005on=]
0003o`000?oMP@3o000000GofhP00_l00003om2W00;o00000oo</P001Ol0003oakl0o`000?nT_@3o
000000;oR[H000Ko0000off^0?m][P3oKJh0o`000?m=Y@06o`00013ooooo00?o0000ooooooooool0
1?ooool001[ooooo00?o0000ooooooooool07oooool2o`000005oeZY0?l0003oRkL0oh^g0?l00000
0_nj`P06o`0000Cod:P000?o0000omND0?oGU0000_oGU0000ol0003ogH40omf10003omf10003o`00
0?oRL03ohW0000;ohW0000Co0000onIR0?oVHP3oiV801Ol00003one;0003o`000?o_@P3okd8000Co
kd8000?o0000oo4j0?oa>P000ooa>P000ol0003olSD0oo8e0003o`000003oo@]0?l0003omRT000Go
mRT000?o0000ooHW0?of9`001?of9`02o`0000Kon24000?o0000ooPQ0?oh8@000ooh8@03o`0000Ko
n1h000?o0000ooLR0?og8P000ol000000ooh7P3o0000ooLS0006ooLS0004o`000?of:@3o0000o`00
00ComRL000Co0000oo@_0?od;`3om2l00_l000000ood;P3o0000oo8h0006oo8h00;o00001oo^A@02
o`0000KojEL00_l00007on=]00;o00001?oKR002o`0000;of94000?o0000om2W0?l000001?o</P00
0ol0003oakl0olNo0003o`000003ohZf0?l0003oKJh000;oKJh000?o0000odfU0?m=Y@001Ol0000A
ooooo`03o`000?oooooooooo00Cooooo000Kooooo`;o00007oooool01?l0003oKJh0o`000?l00003
oh^g0004o`000?nj`P3o^/80o`0000?oc;802ol00003omf100_o00000ooYE`000ol0003okD/0one;
0003one;0003o`000?o_@P3okd8000Cokd8000Co0000oo4j0?oa>P3olCX01?l00005oo@]0003o`00
0?of:@3omRT000ComRT000?o0000ooHW0?of9`000ol000000ooh8@3o0000ooPQ0006ooPQ0003o`00
0?oh8@3o000000;o00000_oi7@000ol0003on1h0ooPN0004ooPN00?o00001Ooh7P000ol0003omb<0
ooLS0004ooLS00;o00001oof9`000ol0003om2l0o`000004oo@^0003o`000?ob>03olSP000;olSP0
0_l00002oo4i0003o`000?o^A@3okTD000;okTD00_l000000oo^B03o0000onUG0003onUG00;o0000
0_oXF`000ol0003ohfd0on=]0002on=]00;o00000_oQL`001?l0003ofhP0o`000?l00004omRA00?o
00000oo</P001?l0003oakl0olNo0?l00003okG100?o000000CoKJh0o`000?m=Y@3oCJD01Ol0000C
ooooo`03o`000?oooooooooo00?ooooo000Mooooo`03o`000?oooooooooo01gooooo00?o0000off^
0?m][P001Ol00002ok[20003o`000?o</P3oc;8000;oc;8000Go0000omBL0?oDW03oe9`0o`000003
om^700Co00000ooQM0000ol0003oiV@0onIT0002onIT0003o`000?oYE`3ojEL000CojEL000?o0000
one;0?o]B`000oo]B`001?l0003okd80onm20?o_@P06o`0000?olc8000?o0000oo@]0?od;@001?od
;@001?l0003omRT0ooHY0?of:@05o`0000Gon24000?o0000ooPQ0?oh8@001?oh8@02o`0000KonAd0
00?o0000ooPN0?oh7P000ol000000ooi6`3o0000ooPN0006ooPN0003o`000?og8`3omb<000?o0000
0_oh8@000ol0003omRL0ooHW0004ooHW00;o00001_od;P001?l0003olSP0o`000?l00005oo4i0004
o`000?o^A@3o0000o`0000CokTP000Co0000onUG0?l0003o00001OoXF`001?l0003ohfd0o`000?l0
0004on5c00;o00001OoHT@001ol0003oe9`0omBL0?oDW03o0000olbb0?l000000_o7_`001Ol0003o
]L40okG10?ne`@3o000000;oV;X00ol000000om=Y@3o0000o`000003o`0001Cooooo00?o0000oooo
ooooool00oooool001kooooo00?o0000ooooooooool07Oooool01?l0003oKJh0off^0?l00002oijk
00?o000000?o^/80o`000?o</P000oo</P001Ol0003oe9`0omBL0?oDW03o000000CofhL000?o0000
on5d0?oQM0000ooQM0000ol0003oiV@0onIT0002onIT0003o`000?oYE`3ojEL000CojEL000Co0000
one;0?o]B`3okD/01Ol00003oo4i0003o`000?oc<P3olc8000Colc8000?o0000oo@]0?od;@000ood
;@04o`0000Comb<000?o0000ooPQ0?oh8@001?oh8@000ol0003on240ooPQ0003o`0000;onA`000?o
0000ooTM0?oi7@000ooi7@03o`0000GonA/000?o0000ooPN0?oh7P001?oh7P03o`0000Kon24000?o
0000ooHW0?of9`000ol000000oof9P3o0000oo@^0005oo@^00;o00001ooa>@02o`0000KokTP00_l0
0007onQK00;o00001OoQL`001?l0003ogW`0omil0?l00003omRA0003o`000?oDW03oe9`000;oe9`0
0ol000000oo7_`3o0000okG10002okG10004o`000?nH^P3oV;X0o`0000;oMk401_l000000ooooooo
0000ooooo`0Booooo`03o`000?oooooooooo00?ooooo000Oooooo`03o`000?oooooooooo01gooooo
0_l000001_m][P3o0000oijk0?nN^`3o0000olJo00?o00001?o</P001Ol0003oe9`0omBL0?oDW03o
000000CofhL000?o0000on5d0?oQM0000ooQM0000ol0003oiV@0onIT0002onIT0004o`000?oYE`3o
jEL0onUG00Ko00000oo_@P000ol0003olCT0oo4i0003oo4i0003o`000?oc<P3olc8000Colc8000?o
0000oo@]0?l000000_l00002ooHV0003o`000?og8`3omb<000Comb<000Co0000ooPQ0?oh8@3on240
1Ol00006ooTL0003o`000?oi7@3o000000;o000000?onAX0o`000?oi6`001_oi6`000ol0003on1h0
ooPN0003o`0000;onAd000?o0000ooPQ0?oh8@001?oh8@03o`0000GomRH000?o0000oo@^0?od;P00
0ol00002oo@_0003o`000?oa>@3olCT000;olCT00_l00002oo4k0004o`000?o^B03okTP0oni800;o
00000_o]C0000ol0003oj5/0onQK0002onQK00;o000000?oiV40o`000?oQL`000_oQL`02o`0000Co
gW`000?o0000omRA0?l000001?oDW0000ol0003od:P0om2X0002o`0000?o]L4000Co0000oiRj0?nH
^P3o00000_mg/@02o`000004obnK0?l0003o0000o`0000?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`03ooooo`008?ooool2o`0001gooooo00?o0000ogbb0?l000000_l00002oijk
0004o`000?o6_`3oa[l0olJo00[o00001?oKQ`000ol0003ohG@0on5d0002on5d0004o`000?oVI03o
iV@0onIT00Go00000oo/C@000ol0003okd80onm20004onm20003o`000?oa>@3olCT000?olCT000Co
0000oo<b0?oc<P3olc801?l00006ooHV0003o`000?og8`3omb<000?omb<01?l00004ooTM0003o`00
0?oi703onA`000ConA`00_l00005ooTJ0003o`000?oi6`3onA/000ConA/00ol00006ooTM0003o`00
0?oh8@3on24000?o00000_oh8@000ol0003omRH0ooHV0003ooHV00?o00001_od;`001?l0003olCT0
o`000?l00005oo4k0003o`000?o^B03o000000GokD`000Co0000onQK0?l0003o00001?oVH@000ol0
003ohG<0o`000006omil00;o00000ooDW002o`0000;od:P000Ko0000olZg0?o:]`3o0000okG10?l0
0002oiRj0003o`000?mg/@3o000000;o000000Co;i/0o`000?l0003o00001?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00?ooooo000Rooooo`03o`000?oooooooooo01_ooooo00Co
0000ogbb0?ml/P3oO;800_l000001OnN^`3o0000olJo0?o6_`3o000000Cod:L000Co0000omRA0?oH
T@3of9403_l00003onQJ0003o`000?o/C@3ok4d000?ok4d000?o0000onm20?o_@P001?o_@P001?l0
003olCT0oo4i0?oa>@05o`0000ComB/000?o0000ooHV0?of9P001?of9P000ol0003omb<0o`000002
o`000003ooPN0?l0003onAd000KonAd000?o0000ooTL0?oi70000ol000000ooi6@3o0000ooTJ0005
ooTJ0003o`000?oi6`3onA/000?o00000_oi6P000ol0003onAd0ooTM0004ooTM00?o00001_oh8@00
0ol0003omRH0o`000002o`0000;omRL000?o0000oo@_0?od;`001?od;`02o`0000OolC/00_l00006
one<00;o00001_oVH@03o`0000CogW`00_l00002om^70003o`000?oDW03o000000;od:P00_l00003
olZg00?o000000OoV;X0o`000?mg/@3o0000oeBW0?l0003o;i/000;o00001oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00?ooooo000Sooooo`03o`000?oooooooooo01_ooooo00Go
0000ogbb0?ml/P3o0000ojjo0002o`0000?oa[l000?o0000om2W0?o@Y`000_o@Y`001Ol0003of940
omRA0?oHT@3o000000CogW`000?o0000onAZ0?oTJP001?oTJP000ol0003oj5X0onQJ0002onQJ0003
o`000?o/C@3ok4d000?ok4d000Co0000onm20?o_@P3okd801_l00003oo<b0003o`000?oe:`3omB/0
00ComB/000Co0000ooHV0?of9P3omRH01?l00005ooPN0003o`000?oi7@3onAd000ConAd00ol00005
ooTI0003o`000?oi6P3onAX000?onAX00ol00006ooTJ0003o`000?oi7@3onAd000?o00000_oi7000
0ol0003on240ooPQ0004ooPQ00;o00001_of9`000ol0003om2l0oo@_0003o`0000;olc4000?o0000
oo4k0?oa>`000_oa>`02o`000003oo0o0?l0003okD`000?okD`00_l00002on]B0004o`000?oVH@3o
iV40onIQ00;o00000ooTJP001?l0003ogW`0o`000?l00004om^700?o000000?od:P0o`000?o:]`00
0oo:]`000ol0003o_l<0oko30009o`0000Wooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`0Kooooo`;o000000CoO;80o`000?n^_`3o[[l0
1Ol00004om2W0005o`000?oHT@3of940omRA0?l000001?oNO0000ol0003oi6X0onAZ0004onAZ0003
o`000?oXFP3oj5X000;oj5X000Co0000ona=0?o/C@3ok4d01Ol00003oo4j0003o`000?oc<P3olc80
00Colc8000Co0000ooD[0?oe:`3omB/01_l00004ooLR0003o`000?oh7P3on1h000?on1h000?o0000
ooTM0?oi7@000ol00002ooTJ0003o`000?oi6@3onAT000ConAT000?o0000ooTJ0?l000000_l00003
ooXH0003o`000?oi6P3onAX000?onAX00ol00006ooTL0003o`000?oh8@3on24000?o00000_oh8@00
0ol0003omRL0ooHW0003ooHW00?o00001_oc<@001?l0003olC/0o`000?l00004oo0o0004o`000?o]
C03o0000o`0000Goje8000?o0000onIQ0?l000001OoTJP02o`0000CofhL00_l00002omND00;o0000
0oo:]`02o`0000;o_l<000Oo0000oijk0?nN^`3o0000ogZb0?l0003oE:L000;o00002oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Uooooo`;o00007?ooool4o`0000?o
[[l000?o0000olZg0?l000002_l00004omil0004o`000?oTJP3oi6X0onAZ00_o00000oo^A@000ol0
003olCX0oo4j0003oo4j0003o`000?oc<P3olc8000?olc801?l00003ooHV0003o`000?og8P3omb80
00Gomb8000Co0000ooPN0?oh7P3on1h01?l00006ooTJ0004o`000?oi6@3onAT0ooTI00Co00001ooj
60000ol0003onAX0o`000002o`0000;onAT000?o0000ooTL0?oi70001?oi7003o`0000Kon24000?o
0000ooHW0?l000000_l00002ooHY0003o`000?oc<@3olc4000Colc400_l00006oo0o00;o00001oo[
DP02o`0000Coi6X00_l00002on5d0004o`000?oKQ`3o0000o`0000?oei@000Ko0000om:S0?oBX`3o
0000olZg0?l00003oko30007o`000?nN^`3oW[/0o`000?mj/P3o0000oeBW0002o`0000cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`009oooool00ol0003oooooooooo`0J
ooooo`03o`000?n8]P3oR;H000Go00000_o:]`000ol0003odih0om>N0002om>N0003o`000?oKR03o
fhP000Wo00000ooVH@000ol0003oje80on]B0003on]B0003o`000?o^A@3okTD000?okTD000?o0000
oo4j0?oa>P000ooa>P000ol0003olc80o`000002o`0000;om2d000?o0000ooHV0?of9P000oof9P00
0ol0003omb80ooLR0004ooLR00Co00001?oi6`000ol0003onAX0ooTJ0003ooTJ00Co00001?oj5`00
0ol0003onQP0ooXH0004ooXH00;o00001_oi6@000ol0003onA`0ooTL0003o`0000;onAd000?o0000
ooPQ0?oh8@001?oh8@02o`0000KomRT000?o0000oo<a0?oc<@000ol00002oo8e0004o`000?o`?`3o
l3l0oo0o00;o00000_o^A@000ol0003oje80on]B0002on]B00;o00000_oXFP001?l0003oi6X0o`00
0?l00004on5d00?o00000ooGU0001?l0003odZ<0om:S0?oBX`04o`000008oko30?l0003oW[/0oijk
0?l0003oN[80o`000?mDY`02o`0000kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`02ooooo`00:?ooool00ol0003oooooooooo`0Jooooo`03o`000?n8]P3o000000?o^/800ol00000
0oo:]`3o0000om>N0003om>N0003o`000?oKR03ofhP000;ofhP000?o0000on5c0?oQL`000_oQL`00
0ol0003oiV40onIQ0002onIQ0003o`000?o[DP3oje8000?oje8000?o0000oni50?o^A@000oo^A@00
1?l0003olCX0oo4j0?oa>P03o`0000Kom2d000?o0000ooHV0?of9P000oof9P000ol0003omb80ooLR
0003o`0000;on1h000?o0000ooTK0?oi6`001?oi6`000ol0003onAX0o`000002o`000003ooXH0?l0
003onQL000KonQL000?o0000ooXH0?oj60000ol00002ooXG0003o`000?oi6@3onAT000?onAT00ol0
0006ooTM0003o`000?oh8@3on24000?o000000?omb<0o`000?of:@001Oof:@03o`0000KolSD000?o
0000oo0o0?l000001Oo^A@001?l0003oje80o`000?l00004onQJ00?o00000ooQM002o`0000?ogH40
00?o0000omND0?l000000_oBX`02o`0000?oc;<00ol000001OnN^`3o0000ogZb0?l0003oE:L000;o
00004?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo000Yooooo`03o`00
0?oooooooooo01[ooooo0ol00003ok[20003o`000?o=/03o000000;o00001?oCWP000ol0003ofhP0
om^80002om^80003o`000?oQL`3ohG<000;ohG<000?o0000onIQ0?oVH@000_oVH@001?l0003oje80
on]B0?o[DP0;o`0000?olSD000?o0000oo@]0?od;@001?od;@001?l0003omRH0ooHV0?of9P04o`00
00Kon1h000Co0000ooTK0?oi6`3onA/01?l00005ooXH0003o`000?oj5`3onQL000ConQL00ol00006
ooXG0003o`000?oi6@3o000000;o00000_oi6P000ol0003onAd0ooTM0004ooTM00?o00001Oog8`00
0ol0003omRT0ooHY0003o`0000;om2d000?o0000oo8e0?ob=@001?ob=@02o`0000KokTD00_l00004
onQJ00;o00000ooVI0000ol0003ohG@0o`000005omf100?o000000?odZ<0o`000?o</`000oo</`00
0ol0003o`l@0ol?40007o`00017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`00:_ooool2o`0001_ooooo0ol00003ok[20004o`000?o=/03ocK00olf`01Oo00000oo]C000
0ol0003ol3l0oo0o0003oo0o0003o`000?ob=@3olSD000?olSD000Co0000oo@]0?od;@3om2d01_l0
0003ooLS0003o`000?oh7P3on1h000Con1h01?l00004ooTJ0003o`000?oj603onQP000?onQP000?o
0000ooXG0?oj5`000ol00002ooXG0003o`000?oj5`3onQL000ConQL00_l00006ooTJ0003o`000?oi
7@3onAd000?o00000_oh7P000ol0003omb<0ooLS0003ooLS00?o00001_od;@000ol0003olSD0oo8e
0003o`0000;olCX000?o0000oni50?o^A@000ol00002ona=0004o`000?oXFP3o0000o`0000GoiV@0
0_l00004omf100;o00000_oHT002o`0000?oc;<00_l000001_o3a03o0000o`000?nN^`3o0000ogNa
00?o00004oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo000/ooooo`03
o`000?oooooooooo01Wooooo00?o0000oi2h0?l000001?l00003olf`0005o`000?oFV03oeYP0omJH
0?l000001?oMP@000ol0003ohfd0on=]0002on=]0003o`000?oXF`3oj5/000;oj5/000?o0000one<
0?o]C0001?o]C0000ol0003ol3l0oo0o0003oo0o0004o`000?ob=@3olSD0oo8e00Go00001?of:@00
0ol0003omb<0ooLS0003ooLS0003o`000?oh7P3on1h000?o000000?onAd0o`000?oi6P001_oi6P00
1?l0003onQP0ooXH0?oj6004o`0000KonQL000?o0000ooXG0?oj5`000ol000000ooj603o0000ooTJ
0005ooTJ00?o00001_oh7P000ol0003omb<0o`000002o`0000;omRH000?o0000oo@]0?od;@001?od
;@03o`0000GolCX00ol00005ona=00?o00001?oVI002o`0000;ohW0000Co0000omf10?l0003o0000
0ooHT0001ol0003odZ40om:Q0?l0003oc;<0o`000?o3a0000_l000001?nN^`3o0000o`000?mg/@02
o`0001Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00;Oooool00ol0
003oooooooooo`0Iooooo`;o000000?oT;P0o`000?o3a0001_l00003omJH0003o`000?oMP@3ogH40
00;ogH4000?o0000on=]0?oSK@000_oSK@000ol0003oj5/0onQK0002onQK0003o`000?o]C03okD`0
00CokD`000Co0000oo0o0?o`?`3ol3l01Ol00004oo<a0003o`000?of:@3omRT000?omRT000Co0000
ooLS0?og8`3omb<01?l00005ooTM0003o`000?oi6P3onAX000ConAX01?l00003ooXG0003o`000?oj
5`3onQL000ConQL00ol00005ooXH0003o`000?oi6P3onAX000?o00000_oi6`000ol0003on1h0ooPN
0004ooPN00;o00001_of9P000ol0003om2d0oo@]0003o`0000;olc8000Co0000oo4j0?oa>P3olCX0
0_l00002onm20004o`000?o/C@3ok4d0ona=00;o00000ooYE`001?l0003oiV@0o`000?l00004on9`
00;o00000ooHT002o`0000?odZ401Ol000001?nN^`3o0000ogNa0?mg/@02o`0001Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00;_ooool00ol0003oooooooooo`0Ioooo
o`Co00000_o3a0000ol0003ocZ/0olj[0006o`0000CogH4000?o0000on=]0?oSK@000_oSK@000ol0
003oj5/0onQK0002onQK0004o`000?o]C03okD`0one<00Ko00000ooa>`000ol0003olc40oo<a0004
oo<a0004o`000?of:@3omRT0ooHY00Go00001?oh8@000ol0003onAd0ooTM0003ooTM0003o`000?oi
6P3onAX000?o00000_oi6@000ol0003onQL0ooXG0003ooXG0003o`000?oj5`3onQL000?o00000_oj
5`000ol0003onQP0ooXH0003ooXH00?o00001_oi6`000ol0003on1h0ooPN0003o`000003ooLR0?l0
003omRH000GomRH00ol00006oo<b0003o`000?oa>P3o000000Gokd8000?o0000ona=0?l000001OoY
E`02o`0000CohW000_l00002omio0003o`000?oHT03o000000?odZ400_l000001?o</`3o0000oko3
0?no``06o`0001Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00;ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?nF^@3oU[T000Co00000oo>Z`000ol0003oei<0omNC
000Co`0000CokTP000?o0000oo4k0?oa>`000ooa>`001?l0003olc40oo<a0?oc<@06o`0000?omRL0
00?o0000ooPQ0?oh8@001?oh8@001?l0003onAd0ooTM0?oi7@04o`0000KonAT000Co0000ooXG0?oj
5`3onQL01?l00006ooXG0003o`000?oj603o000000;o00000_oi6P000ol0003onA/0ooTK0004ooTK
00?o00001Oog8P000ol0003omRH0ooHV0003o`0000;omB/000?o0000oo<b0?oc<P001?oc<P02o`00
00Kokd800_l00004onUG00;o00000_oVHP001?l0003ohW00o`000?l00004omio00Co000000KodZ40
o`000?o</`3oc;<0o`000?no``02o`0000;oV;X00ol0000Kooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00Oooool0033ooooo0_l0000Jooooo`;o000000?oU[T0o`000?o5``001_l0
0003omNC0003o`000?oNO03ogW`000;ogW`000?o0000onEX0?oUJ0000_oUJ0000ol0003ojEL0onUG
0003onUG0003o`000?o^B03okTP000?okTP000Co0000oo4k0?oa>`3olC/01Ol00004oo@_0003o`00
0?of9`3omRL000?omRL000Co0000ooPQ0?oh8@3on2401_l00003ooTL0003o`000?oi6@3onAT000Co
nAT01?l00003ooXH0003o`000?oj5`3onQL000ConQL00_l00006ooTJ0003o`000?oi6`3onA/000?o
00000_oh7P000ol0003omb80ooLR0003ooLR00?o00001_oe:`000ol0003olc80oo<b0003o`0000;o
lCT000?o0000onm20?o_@P000ol00002one;0004o`000?oYE`3o0000o`0000CoiV800ol00003omio
00;o00000ooHT003o`000004olbc0?l0003o_l<0o`0000;oV;X00ol0000Nooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00Oooool003;ooooo00?o0000ooooooooool06Oooool3o`00
00;oaL<000?o0000om2X0?o@Z0001_l00004omil0003o`000?oUJ03oiFP000;oiFP000?o0000onUG
0?oYE`000ooYE`001?l0003okTP0oni80?o^B005o`0000?olCT000?o0000oo@_0?od;`001?od;`00
1?l0003omRL0ooHW0?of9`05o`0000Con24000?o0000ooTL0?oi70000ooi70000ol0003onAT0ooTI
0003o`0000;onAX000?o0000ooXH0?oj60000ooj60000ol0003onQL0ooXG0003o`0000;onAT000?o
0000ooTJ0?oi6P000ooi6P03o`0000Kon1h000?o0000ooLR0?l000000_l00002ooHV0003o`000?oe
:`3omB/000ComB/00ol00005oo4i00?o00001Oo]B`03o`0000?oiV800_l00003on9`0003o`000?oN
O`3o000000?of9000_l00002om:R00Go000000CoV;X0o`000?l0003o00008?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo007ooooo000cooooo`03o`000?oooooooooo01Wooooo00Ko
0000oiNj0?l0003o0000olG30?l00003om2X0003o`000?oHT03of90001Co00000oo^A@000ol0003o
lCT0oo4i0003oo4i0004o`000?od;`3om2l0oo@_00Ko00000oof9P000ol0003on240ooPQ0004ooPQ
0004o`000?oi703onA`0ooTL00Co00001_oi6P001?l0003onQP0ooXH0?oj6004o`0000KonAT000?o
0000ooTJ0?l000000_l00002ooTM0003o`000?oh7P3on1h000Con1h00_l00006ooHV0003o`000?oe
:`3omB/000?o00000ooc<P000ol0003olCT0o`000002o`0000?okd8000?o0000one;0?l000000_l0
0003onUG0003o`000?oVHP3o000000GohW000ol000000ooHT03o0000o`000002om:R00;o000000Co
b[L0o`000?ne`@3o]L401?l0000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0Oooool003Cooooo00?o0000ooooooooool06Oooool6o`0000?od:P000?o0000omR@0?oHT0000_oH
T0000ol0003oggT0ommi0002ommi0003o`000?oUI@3oiFD000;oiFD000?o0000onYD0?oZE0000_oZ
E0000ol0003okTD0oni50003oni50004o`000?oa>@3olCT0oo4i00Go00001?od;P000ol0003omRH0
ooHV0003ooHV0004o`000?oh8@3on240ooPQ00Ko00000ooi7@000ol0003onAX0ooTJ0004ooTJ00Co
00001?oi6P001?l0003onAT0ooTI0?oi6@04o`0000KonAd000?o0000ooPN0?oh7P000ol00002ooLS
0003o`000?of9P3omRH000?omRH00ol00006oo<b00;o00001_o_@P02o`0000KojEL00ol00002on9`
00?o00000_oMP@04o`000006om:R0?l0003ob[L0olZg0?l0003o]L401Ol0000Sooooo`03o`000?oo
oooooooo00Oooooo0Ol00001ooooo`7ooooo000eooooo`;o00006_ooool3o`0000;oa/801Ol00004
omR@0003o`000?oON@3oggT000;oggT000?o0000onEU0?oUI@000_oUI@000ol0003ojU@0onYD0002
onYD0004o`000?o^A@3okTD0oni500Go00001?ob>0000ol0003om2h0oo@^0003oo@^0004o`000?of
9P3omRH0ooHV00Go00001?oh8@000ol0003onAd0ooTM0003ooTM0003o`000?oi6P3onAX000?o0000
0_oi6`000ol0003onAX0ooTJ0003ooTJ00Co00001?oi70000ol0003onAd0ooTM0003ooTM00?o0000
1_og8`000ol0003omRH0o`000002o`0000?om2d000?o0000oo<b0?oc<P000ol00002oo4j0003o`00
0?o_@P3okd8000?o00000_o/C@000ol0003ojEL0onUG0003o`0000;oiV@00ol00003omf100;o0000
0ooGT`03o`000005olZg0?l0003o]L40o`000?n:]P000_l0000Vooooo`03o`000?oooooooooo00Ko
oooo0Ol00001ooooo`7ooooo000gooooo`03o`000?oooooooooo01Sooooo00?o0000oiJi0?l00000
1?l000000oo@Y`3o0000o`00000Fo`0000?okd@000?o0000oo8h0?ob>0001?ob>0001?l0003om2h0
oo@^0?od;P05o`0000?omRL000?o0000ooPQ0?oh8@001?oh8@001?l0003onAd0ooTM0?oi7@04o`00
00KonA/000?o0000ooTJ0?l000000_l00002ooTM0003o`000?oi703onA`000ConA`000?o0000ooTM
0?l000000_l00003ooPQ0004o`000?og8`3omb<0ooLS00Co00001_od;@03o`0000GolCX00ol00005
ona=00?o00000ooVI002o`0000?ohG@000?o0000omf10?l000000ooGT`02o`0000;od:P01_l0000X
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo000hooooo`03o`000?oooooooooo
01Sooooo0_l000000onF^@3o0000olG30006o`0000?ofHl000?o0000on1h0?oPN0000_oPN0000ol0
003oiV@0onIT0002onIT0003o`000?o[D`3oje<000;oje<000?o0000onm40?o_A0000oo_A0001?l0
003olSP0oo8h0?ob>006o`0000?om2l000?o0000ooHW0?of9`000oof9`001?l0003on240ooPQ0?oh
8@06o`0000Con1h000Co0000ooTK0?oi6`3onA/01?l00006ooTM0004o`000?oi703onA`0ooTL00Go
00001Ooh8@04o`0000ComRT000?o0000oo@]0?od;@000ol00003oo8e0003o`000?oa>P3o000000;o
00000oo^A@000ol0003ok4d0o`000002o`0000?oj5X000?o0000onIT0?l000001OoQM003o`000003
omNC0?l0003o000000;od:P01ol0000Zooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7o
oooo000iooooo`03o`000?oooooooooo01Wooooo0ol00002olG30003o`000?o@Z03od:P000Ko0000
1?oPN0000ol0003oiV@0onIT0002onIT0003o`000?o[D`3oje<000;oje<000Co0000onm40?o_A03o
kd@01Ol00004oo4i0003o`000?od;`3om2l000?om2l000Co0000ooHW0?of9`3omRL01Ol00004ooLS
0003o`000?oh7P3on1h000?on1h01?l00004ooPN0003o`000?oi7@3onAd000?onAd01?l00005ooPQ
0003o`000?oh8@3o000000;o00000_of9`000ol0003omRT0ooHY0003ooHY00?o00001_ob=@02o`00
00KokTD00_l00006onQJ00?o00000_oQM003o`0000;ofhL00ol000001_o@Z03o0000o`000?o7_P3o
0000ojBm00;o0000;Oooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00>_ooool2
o`0001[ooooo1_l00003om2X0003o`000?oHT03of90001?o00001?o^A@000ol0003olCT0oo4i0003
oo4i0004o`000?od;`3om2l0oo@_00Go00001?of:@000ol0003omb<0ooLS0003ooLS0003o`000?oh
7P3o000000;o00000_og8P000ol0003on1h0ooPN0004ooPN0003o`000?oi7@3o000000;o00000_oh
8@000ol0003on240ooPQ0004ooPQ00;o00001_of9`000ol0003omRT0o`000002o`0000?olc4000?o
0000oo8e0?ob=@000ol000000oo`?`3o0000oni50003oni500;o00000_o[DP000ol0003oj5X0onQJ
0003o`0000;oi6X00ol00003om^700;o00000_oDV`07o`00033ooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo0Oooool003cooooo00?o0000ooooooooool06Oooool9o`0000?of90000?o0000
ommi0?oON@000_oON@000ol0003oiFD0onEU0002onEU0003o`000?oZE03ojU@000;ojU@000?o0000
oni50?o^A@001?o^A@001?l0003olCT0oo4i0?oa>@05o`0000?olc4000?o0000ooHY0?of:@001?of
:@001?l0003omb<0ooLS0?og8`04o`0000Gomb8000Co0000ooPN0?oh7P3on1h01Ol00005ooPQ0003
o`000?oh8@3on24000?o000000?omRH0o`000?of9`001Oof9`03o`0000Golc400ol00005oo0o0004
o`000?o^A@3o0000o`0000Coje800ol00003onAZ00;o00000ooNO0001?l0003ofhL0o`000?oDV`03
o`000003olbb0?l0003o000000?o0000<Oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1
ooooo`00?Oooool00ol0003oooooooooo`0Jooooo`co00001?oON@000ol0003oiFD0onEU0002onEU
0003o`000?oZE03ojU@000;ojU@000Co0000oni50?o^A@3okTD01_l00003oo4k0003o`000?oc<@3o
lc4000?olc4000Co0000ooHY0?of:@3omRT01_l00004ooHV0004o`000?og8P3omb80ooLR00Go0000
1Oog8`001?l0003on240ooPQ0?oh8@04o`0000GomRH000?o0000ooHW0?of9`000ol00003oo@_0003
o`000?oc<@3o000000;o00000ooa>`001?l0003ol3l0oo0o0?o`?`05o`000004on]B0?l0003o0000
o`0000?oiV4000?o0000onAZ0?l000001OoNO005o`000003olbb0?l0003o000000?o0000=?ooool0
0ol0003oooooooooo`03ooooo`7o00000Oooool003kooooo00?o0000ooooooooool06oooool2o`00
0003ok[20?l0003o000000?o000000?oei<0o`000?l000004Ol00004oni80003o`000?oa>`3olC/0
00?olC/000Co0000oo<a0?oc<@3olc401Ol00004oo@]0003o`000?of9P3omRH000?omRH01?l00003
ooHV0003o`000?og8`3omb<000Comb<01?l00004ooHW0004o`000?of9P3omRH0ooHV00Co00001_od
;`02o`0000KolC/01?l00004one<00;o00001_oVH@03o`0000;ogW`01Ol00002om2W00Go0000=ooo
ool00ol0003oooooooooo`02ooooo`7o00000Oooool003oooooo0_l0000Looooo`?o000000?o^/80
o`000?o=/0001_l00004omil0003o`000?oUJ03oiFP000;oiFP000?o0000onUG0?oYE`000_oYE`02
o`0000CokTP000Co0000oo4k0?oa>`3olC/01Ol00003oo8e0003o`000?od;@3om2d000Com2d000?o
0000ooHV0?l000000_l00002ooD[0003o`000?of9P3omRH000?omRH000?o0000ooLS0?og8`000ol0
00000oof:@3o0000ooHW0005ooHW00Co00001?od;P000ol0003om2l0oo@_0003o`0000;olCT000?o
0000oo4k0?oa>`000ol00002oni80003o`000?o]C03okD`000?o00000_oXF`000ol0003oiV40onIQ
0003o`0000;ohG<01?l000000ooHT@3o0000om2W0006o`0003[ooooo00Go0000oooooooooooooooo
o`000001ooooo`00@Oooool00ol0003oooooooooo`0Kooooo`Co00000oo=/0000ol0003oeYP0o`00
000Ho`0000Col3l000?o0000oo8e0?ob=@000_ob=@001?l0003om2d0oo@]0?od;@05o`0000GomB/0
00Co0000ooHV0?of9P3omRH01?l00005ooHY0003o`000?of9`3omRL000?o00000ood;`001?l0003o
m2h0oo@^0?od;P04o`0000GolCT00ol00005oni800?o00001OoXF`04o`000004on5c0?l0003o0000
o`0000?ofhP02?l0000looooo`05o`000?ooooooooooooooool000000Oooool004;ooooo00?o0000
ooooooooool07?ooool7o`0000?oeYP00_l00003omf10003o`000?oSK@3ohfd000;ohfd000?o0000
onQK0?oXF`000_oXF`000ol0003okD`0one<0003one<0004o`000?o`?`3ol3l0oo0o00[o00001Ooc
<P001?l0003omB/0ooD[0?oe:`05o`0000Com2d000Co0000ooHY0?of:@3omRT01?l00006oo@_00Co
00001?ob>0000ol0003olCT0o`000002o`0000?okTD000?o0000oni80?l000000_l00003onUF0003
o`000?oXF`3o000000;o00000ooSK@03o`0000;ofhP02Ol0000oooooo`04o`000?ooooooooooo`00
007ooooo0013ooooo`03o`000?oooooooooo01kooooo3_l00004on=]0003o`000?oXF`3oj5/000;o
j5/000Co0000one<0?o]C03okD`01Ol00003oni50003o`000?oa>P3olCX000?olCX000Co0000oo<b
0?oc<P3olc801_l00004oo<b0004o`000?od;@3om2d0oo@]00Go00001?oc<@000ol0003om2l0oo@_
0003o`0000;olCT000Co0000oo8h0?ob>03olSP01Ol00005oni500?o00001OoYEP03o`0000;ohfd0
0ol00002omf100Co000000?odih0o`000?o:]`000_l00013ooooo`03o`000?oooooo0000007ooooo
0014ooooo`;o00008Oooool4o`0000Codih000?o0000om^80?l000003Ol00004on]B0003o`000?o^
A@3okTD000;okTD000Co0000oo4j0?oa>P3olCX01Ol00004oo4i0004o`000?oc<P3olc80oo<b00Ko
00001?ob=@001?l0003olc40oo<a0?oc<@04o`0000GolCT01?l00005onm40003o`000?o^A@3o0000
00;o00000ooZE0000ol0003ojEH0o`000002o`0000;oiFP01?l000001?oMP@3o0000o`000?l00003
omJH00Co0000AOooool00ol0003oooooo`000001ooooo`00A_ooool00ol0003oooooooooo`0Poooo
o`co00001?oQL`000ol0003oiV40onIQ0002onIQ0004o`000?o[DP3oje80on]B00[o00001?o_@P00
1?l0003olCT0oo4i0?oa>@05o`0000GolCX000Co0000oo8e0?ob=@3olSD01Ol00004oo4k0003o`00
0?oa>@3o000000;o00000oo^A@001?l0003okd@0onm40?o_A005o`0000?ojU@01Ol000001?oUJ03o
0000o`000?l00003omil00?o00000_oFV006o`0004Oooooo0Ol00001ooooo`7o00000017ooooo`03
o`000?oooooooooo02;ooooo1ol000000ooHT@3o0000o`00000<o`0000Coj5X000?o0000ona=0?o/
C@000_o/C@001?l0003okd80onm20?o_@P05o`0000Cokd8000Co0000oo4j0?oa>P3olCX01_l00004
oo0o0004o`000?oa>`3olC/0oo4k00Co00001Oo^A@04o`0000Coje<01?l00004onEU00Co000000Go
gW`0o`000?l0003o0000omNB0007o`0004_ooooo0_l0000004Sooooo00?o0000ooooooooool08ooo
ool3o`000003olbb0?l0003o000000Co00001?oNO0000ol0003oi6X0onAZ0002onAZ0004o`000?oX
FP3oj5X0onQJ00[o00001?o]B`001?l0003okd80onm20?o_@P05o`0000CokTD000Co0000oo0o0?o`
?`3ol3l01_l00004oni80003o`000?o^A@3o000000;o00000ooZE0000ol0003oje<0o`000002o`00
00?oiV@000?o0000onEU0?l000000_l00003ommi00Ko000000Cocj/0o`000?l0003o0000COooool3
o`000000BOooool2o`0002Kooooo1Ol000000ooDW03o0000o`00000<o`0000CoiV@000?o0000onUG
0?oYE`000_oYE`001?l0003okD/0one;0?o]B`05o`0000Cok4d000Co0000oni50?o^A@3okTD01Ol0
0005one<0004o`000?o^B03okTP0oni800Go00000ooZE004o`0000?oiV@01Ol00002ommi00Go0000
00?od:P0o`000?l000000_l0001<ooooo`Co00000oooool004_ooooo00?o0000ooooooooool09_oo
ool<o`0000CohG@000Co0000onIT0?oVI03oiV@02_l00004onUG0004o`000?o/C@3ok4d0ona=00Go
00001?o[DP001?l0003okD`0one<0?o]C006o`0000;ojEH01_l00002onEU00Go00000ooPN00;o`00
04_ooooo1?l00007ooooo`00C?ooool00ol0003oooooooooo`0Xooooo`Oo000000?oei@0o`000?l0
00001ol00004on9`0003o`000?oVHP3oiV8000;oiV8000Co0000onUG0?oYE`3ojEL01Ol00004onQJ
0004o`000?o[DP3oje80on]B00Go00000ooXF`05o`0000?oiFP01Ol00003ommi00Go000000?ofHl0
o`000?l000001Ol0001:ooooo`Co00002oooool004gooooo00?o0000ooooooooool0:ooooolJo`00
00CoiV@000Co0000onQJ0?oXFP3oj5X01Ol00003onIQ00Go00000ooSK@05o`0000?ogW`01Ol00002
omR@00So0000B_ooool3o`0000oooooo001>ooooo`;o0000;Oooool00ol0003oooooo`00000Mo`00
00?oi6X01Ol00003on5c00Go00000_oMP@06o`0000;oei802Ol0001:ooooo`Co00004_ooool0053o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03oooooa3o00000ooMP@0:o`0000;o
gW`01_l00002om^800Go00000ooFV00:o`0004[ooooo1?l0000Fooooo`00DOooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00_ooooo:_l0001=ooooo`Co00006_ooool005;ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0GoooooaCo0000Doooool4o`0001kooooo001C
ooooo`;o0000:?ooool00ol0003oooooooooo`1jooooo`Co00008_ooool005Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1fooooo`Co00009_ooool005Kooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1booooo`Co0000:_ooool005Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1^ooooo`Co0000;_ooool005Sooooo0_l0000Sooooo`03o`000?oo
oooooooo06_ooooo0ol0000booooo`00F_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo06Oooooo1?l0000eooooo`00Foooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
06?ooooo1?l0000iooooo`00G?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05oo
oooo1?l0000mooooo`00GOooool2o`0001kooooo00?o0000ooooooooool0Foooool4o`00047ooooo
001Oooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Eoooool4o`0004Gooooo001P
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Doooool4o`0004Wooooo001Qoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Coooool4o`0004gooooo001Rooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool3o`00057ooooo001Sooooo`;o0000
6?ooool00ol0003oooooooooo`18ooooo`Co0000E?ooool006Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`14ooooo`Co0000F?ooool006Kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`10ooooo`Co0000G?ooool006Oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0looooo`Co0000H?ooool006Sooooo0_l0000Cooooo`03o`000?oooooooooo03So
oooo1?l0001Tooooo`00J_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Cooooo
1?l0001Xooooo`00Joooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo1?l0
001/ooooo`00K?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo0ol0001`
ooooo`00KOooool2o`0000gooooo00?o0000ooooooooool0:_ooool4o`0007?ooooo001_ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09_ooool4o`0007Oooooo001`ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`0007_ooooo001aooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07_ooool4o`0007oooooo001booooo`;o00002?ooool0
0ol0003oooooooooo`0Jooooo`Co0000Poooool007Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Fooooo`Co0000Qoooool007Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Booooo`Co0000Roooool007Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0>ooooo`Co0000Soooool007Oooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo0ol0
002Cooooo`00NOooool01?l0003oooooooooool00009ooooo`Co0000U_ooool007[ooooo00?o0000
ooooool000001Oooool4o`0009[ooooo001kooooo`;o000000?oooooo`000?l000000_l0002Noooo
o`00O?ooool2o`000:;ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo000_ooooo`?o0000R_ooool00ol0003oooooooooo`0[ooooo`?o00005Oooool00ol0003o
ooooooooo`0Kooooo`00<?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Jooooo`00:_ooool3o`0000?ooooo0ol0
0004ooooo`;o00000_ooool5o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000ol0
0007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001_ooool4o`0000;ooooo1Ol0
00000ooooooo0000o`000003o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo0ol0
0004ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`?o00000oooool3o`0000Wooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`Co00000oooool00ol0003ooooo
ooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003o
oooo1?l00003ooooo`;o00000_ooool:o`0000Gooooo00?o0000ooooooooool06Oooool002Wooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooo`00000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool01?l0003o
ooooooooool00004ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06Oooool002Wooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool0
1_l0003oooooooooool0003oooooo`0000Gooooo1Ol00008ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooool0003oooooo`000002ooooo`?o00000oooool00ol0003oooooo`000002ooooo`Go
00000oooool01?l0003oooooooooooooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00000_ooool3o`0000Go
oooo00?o0000ooooooooool06Oooool002Wooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0
003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ool000000oooool01?l0003oooooooooool00005ooooo`06o`000?ooooooooooo`000?oooooo0000
2?ooool00ol0003oooooooooo`0Iooooo`00:Oooool01_l0003ooooooooooooooooo0000ooooo`Co
00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000oooool2o`0000Gooooo00?o0000oooooooo
ool02?ooool01?l0003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00009oooo
o`05o`000?ooooooooooo`000?ooool00ol00004ooooo`Co00000_ooool4o`0000;ooooo0ol00002
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l00003ooooo`?o00000oooool3
o`0000Wooooo00?o0000ooooooooool00_ooool6o`000003ooooool0003o000000?ooooo0_l00000
0ooooooo0000o`000002ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool4
o`0000?ooooo2Ol00003ooooo`?o00000oooool4o`0000Cooooo00?o0000ooooooooool06Oooool0
02Wooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo
000Zooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0ol0
0009ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool4o`0000Cooooo00?o
0000ooooooooool01?ooool2o`0000Cooooo0_l0000^ooooo`03o`000?oooooooooo01Sooooo0ol0
000Fooooo`03o`000?oooooooooo00;ooooo0_l0000;ooooo`03o`000?oooooooooo01_ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0625583, 0.0616488, \
0.00353712, 0.00353712}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 5\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] False\), 
        ",", \(FindPupils \[Rule] True\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {208.`, 0.`, 0.`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 112.44620320200491`\), 
        ",", \(OpticalLengthFunction \[Rule] OpticalLengthFunction\), 
        ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          TagBox[\(CompiledFunction[
              If[#1 == 0 && #2 == 0, 
                0.009209855012944997`, \(-11.264683505117207`\) - 
                  3.4928810100798632`*^-9\ Cos[
                      2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                  1.927069336676206`*^-10\ Cos[
                      4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                  14.735634270869657`\ \((\(-1\) + 
                        0.013989456866883982`\ \((#1\^2 + #2\^2)\))\) - 
                  5.192913965285754`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.020984185300325975`\)\ \
\((#1\^2 + #2\^2)\) + 0.0001957049034304074`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  3.48243125803442`\ \((1 - 
                        0.04196837060065195`\ \((#1\^2 + #2\^2)\) + 
                        0.0002935573551456111`\ \((#1\^2 + #2\^2)\)\^2)\) + 
                  4.2201619160926165`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((\(-0.00024463112928800926`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 2.0533539788830346`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  3.3583450513275594`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((0.04196837060065195`\ \((#1\^2 + \
#2\^2)\) - 0.000978524517152037`\ \((#1\^2 + #2\^2)\)\^2 + 
                        5.133384947207587`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  0.020895062635046566`\ \((\(-1\) + 
                        0.0839367412013039`\ \((#1\^2 + #2\^2)\) - 
                        0.0014677867757280556`\ \((#1\^2 + #2\^2)\)\^2 + 
                        6.844513262943449`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  7.299818133179053`*^-8\ Cos[
                      6\ ArcTan[#1, #2]]\ \((\(-2.3955796420302074`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 1.9150204613352546`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  3.1429065958357665`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((0.0007338933878640278`\ \((#1\^2 \
+ #2\^2)\)\^2 - 0.000014373477852181243`\ \((#1\^2 + #2\^2)\)\^3 + 
                        6.702571614673391`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  1.2766741380438523`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.0699472843344199`\)\ \
\((#1\^2 + #2\^2)\) + 0.002935573551456111`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00003593369463045311`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.3405143229346782`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.00020471534013155693`\ \((1 - 
                        0.1398945686688398`\ \((#1\^2 + #2\^2)\) + 
                        0.004403360327184167`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.000047911592840604145`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.6756429036683477`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
              "-CompiledCode-"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {112.43069766768741`, 
            112.44620320200491`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      SurfaceGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      SurfaceGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(ParaxialReductionRatio \[Rule] 0.002`\), 
        ",", \(Plot2D \[Rule] False\), ",", \(PlotPoints \[Rule] 32\), 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(RayBoundary \[Rule] {{\(-8.456612676586712`\), 
              8.456612676586712`}, {\(-8.452840289871496`\), 
              8.452840289871496`}}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), 
        ",", \(ResidualFitError \[Rule] 7.230630203955897`*^-7\), 
        ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
              83.20322430145711`, 
            Astigmatism \[Rule] 0.000026554381242000656`, 
            FieldCurvature \[Rule] 17.31170436577689`, 
            Distortion \[Rule] 5.898318744074078`*^-13, 
            Coma \[Rule] \(-8.757302836470299`*^-13\)}\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 19474\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-11.347780623913327`\), 
                  11.347780623913327`}, {\(-11.34400823719811`\), 
                  11.34400823719811`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[161]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["PupilFunction[offaxis3D,Plot2D->False]", "Input",
  CellLabel->"In[18]:=",
  CellTags->{"AOG5.3", "AOG5.", "AOG0."}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.145 .19996 -11.928 -9 ]
[.145 .19996 .072 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.53856 .04519 -5.2094 -9 ]
[.53856 .04519 .7906 0 ]
[.76828 .09829 0 -6.16064 ]
[.76828 .09829 12 2.83936 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93414 .35229 0 -5.9206 ]
[.93414 .35229 6 3.0794 ]
[.02084 .28565 -18 -2.75967 ]
[.02084 .28565 0 6.24033 ]
[.01043 .35087 -18 -2.8149 ]
[.01043 .35087 0 6.1851 ]
[-0.00042 .41888 -18 -2.87275 ]
[-0.00042 .41888 0 6.12725 ]
[-0.01175 .48989 -18 -2.93342 ]
[-0.01175 .48989 0 6.06658 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15423 .2093 m
.15884 .21396 L
s
[(-5)] .145 .19996 .988 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54634 .05576 m
.55023 .06104 L
s
[(5)] .53856 .04519 .73647 1 Mshowa
.125 Mabswid
.19091 .19493 m
.19364 .19777 L
s
.22813 .18036 m
.23082 .18323 L
s
.26589 .16558 m
.26854 .16848 L
s
.30419 .15058 m
.30681 .15352 L
s
.38251 .11991 m
.38504 .12293 L
s
.42255 .10423 m
.42503 .10729 L
s
.46319 .08832 m
.46563 .09141 L
s
.50445 .07216 m
.50683 .07529 L
s
.11806 .22346 m
.12086 .22623 L
s
.0824 .23742 m
.08523 .24016 L
s
.04723 .25119 m
.0501 .25389 L
s
.58887 .0391 m
.59115 .04231 L
s
.63207 .02219 m
.63429 .02544 L
s
.67594 .00501 m
.67811 .0083 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75597 .10284 m
.74981 .10511 L
s
[(-5)] .76828 .09829 -1 .36903 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92163 .35624 m
.91537 .35822 L
s
[(5)] .93414 .35229 -1 .31569 Mshowa
.125 Mabswid
.77453 .13124 m
.77083 .13258 L
s
.79261 .15889 m
.7889 .16021 L
s
.81021 .18582 m
.8065 .18712 L
s
.82736 .21205 m
.82364 .21334 L
s
.86037 .26253 m
.85663 .26378 L
s
.87625 .28683 m
.87251 .28807 L
s
.89175 .31054 m
.888 .31176 L
s
.90687 .33367 m
.90312 .33487 L
s
.73688 .07365 m
.7332 .07503 L
s
.71727 .04365 m
.71359 .04505 L
s
.6971 .01279 m
.69343 .01422 L
s
.93604 .37828 m
.93228 .37945 L
s
.95011 .39981 m
.94634 .40096 L
s
.96385 .42083 m
.96008 .42197 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03307 .28092 m
.03919 .27855 L
s
[(0.1)] .02084 .28565 1 -0.38674 Mshowa
.02272 .34626 m
.02886 .34396 L
s
[(0.2)] .01043 .35087 1 -0.37447 Mshowa
.01192 .41442 m
.01809 .41219 L
s
[(0.3)] -0.00042 .41888 1 -0.36161 Mshowa
.00064 .48557 m
.00684 .48341 L
s
[(0.4)] -0.01175 .48989 1 -0.34813 Mshowa
.125 Mabswid
.03104 .29377 m
.03471 .29236 L
s
.02898 .30673 m
.03266 .30533 L
s
.02691 .3198 m
.03059 .3184 L
s
.02482 .33298 m
.02851 .33159 L
s
.0206 .35967 m
.02429 .35829 L
s
.01845 .37318 m
.02215 .37182 L
s
.01629 .38681 m
.01999 .38545 L
s
.01412 .40056 m
.01781 .39921 L
s
.0097 .4284 m
.01341 .42707 L
s
.00747 .44251 m
.01118 .44119 L
s
.00521 .45674 m
.00892 .45543 L
s
.00294 .47109 m
.00665 .46979 L
s
.03509 .26817 m
.03876 .26675 L
s
.0371 .25553 m
.04076 .2541 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .471 .138 r
.39246 .66814 .40336 .65426 .41919 .68061 .40808 .7036 Metetra
.099 .578 0 r
.40808 .7036 .41919 .68061 .43592 .68811 .42487 .71532 Metetra
.205 .615 0 r
.42487 .71532 .43592 .68811 .45307 .68589 .44222 .71466 Metetra
.231 .624 0 r
.44222 .71466 .45307 .68589 .47039 .68125 .45978 .71097 Metetra
.238 .626 0 r
.45978 .71097 .47039 .68125 .48783 .67622 .47748 .70686 Metetra
.242 .627 0 r
.47748 .70686 .48783 .67622 .50538 .67108 .49529 .70267 Metetra
.245 .628 0 r
.49529 .70267 .50538 .67108 .52304 .66582 .51323 .69842 Metetra
.248 .629 0 r
.51323 .69842 .52304 .66582 .54081 .66046 .5313 .69411 Metetra
.249 .63 0 r
.5313 .69411 .54081 .66046 .5587 .65498 .54949 .68974 Metetra
.25 .63 0 r
.54949 .68974 .5587 .65498 .57669 .64938 .56781 .68531 Metetra
.251 .63 0 r
.56781 .68531 .57669 .64938 .5948 .64366 .58626 .68081 Metetra
.25 .63 0 r
.58626 .68081 .5948 .64366 .61301 .63781 .60484 .67624 Metetra
.249 .63 0 r
.60484 .67624 .61301 .63781 .63134 .63181 .62354 .6716 Metetra
.246 .629 0 r
.62354 .6716 .63134 .63181 .64977 .62568 .64238 .66688 Metetra
.243 .628 0 r
.64238 .66688 .64977 .62568 .66831 .61939 .66134 .66208 Metetra
.238 .626 0 r
.66134 .66208 .66831 .61939 .68695 .61294 .68044 .65718 Metetra
.233 .624 0 r
.68044 .65718 .68695 .61294 .7057 .60633 .69967 .65219 Metetra
.226 .622 0 r
.69967 .65219 .7057 .60633 .72456 .59954 .71902 .64709 Metetra
.218 .619 0 r
.71902 .64709 .72456 .59954 .74351 .59257 .73851 .64187 Metetra
.208 .616 0 r
.73851 .64187 .74351 .59257 .76256 .5854 .75813 .63654 Metetra
.197 .613 0 r
.75813 .63654 .76256 .5854 .78171 .57802 .77788 .63106 Metetra
.184 .608 0 r
.77788 .63106 .78171 .57802 .80095 .57043 .79775 .62543 Metetra
.17 .604 0 r
.79775 .62543 .80095 .57043 .82029 .56261 .81775 .61963 Metetra
.154 .598 0 r
.81775 .61963 .82029 .56261 .83971 .55455 .83787 .61365 Metetra
.137 .592 0 r
.83787 .61365 .83971 .55455 .85921 .54624 .85811 .60745 Metetra
.117 .585 0 r
.85811 .60745 .85921 .54624 .87879 .53767 .87846 .60103 Metetra
.095 .577 0 r
.87846 .60103 .87879 .53767 .89844 .52877 .89892 .59426 Metetra
.068 .566 0 r
.89892 .59426 .89844 .52877 .91811 .51911 .91937 .5863 Metetra
.015 .545 0 r
.91937 .5863 .91811 .51911 .93746 .50622 .93922 .57234 Metetra
0 .486 .11 r
.93922 .57234 .93746 .50622 .95565 .48389 .95677 .54018 Metetra
0 .361 .278 r
.95677 .54018 .95565 .48389 .97205 .449 .9708 .48319 Metetra
.023 .548 0 r
.38196 .66632 .39246 .66814 .40808 .7036 .39743 .70518 Metetra
.393 .673 0 r
.39743 .70518 .40808 .7036 .42487 .71532 .41424 .71862 Metetra
.561 .719 0 r
.41424 .71862 .42487 .71532 .44222 .71466 .43169 .71868 Metetra
.61 .731 0 r
.43169 .71868 .44222 .71466 .45978 .71097 .44937 .71547 Metetra
.63 .736 0 r
.44937 .71547 .45978 .71097 .47748 .70686 .46719 .71183 Metetra
.647 .74 0 r
.46719 .71183 .47748 .70686 .49529 .70267 .48515 .70815 Metetra
.664 .744 0 r
.48515 .70815 .49529 .70267 .51323 .69842 .50324 .70445 Metetra
.681 .749 0 r
.50324 .70445 .51323 .69842 .5313 .69411 .52146 .70074 Metetra
.698 .753 0 r
.52146 .70074 .5313 .69411 .54949 .68974 .53981 .69702 Metetra
.715 .757 0 r
.53981 .69702 .54949 .68974 .56781 .68531 .5583 .6933 Metetra
.732 .761 0 r
.5583 .6933 .56781 .68531 .58626 .68081 .57694 .68957 Metetra
.749 .765 0 r
.57694 .68957 .58626 .68081 .60484 .67624 .59571 .68583 Metetra
.766 .769 0 r
.59571 .68583 .60484 .67624 .62354 .6716 .61463 .6821 Metetra
.772 .762 0 r
.61463 .6821 .62354 .6716 .64238 .66688 .63369 .67836 Metetra
.776 .752 0 r
.63369 .67836 .64238 .66688 .66134 .66208 .6529 .67462 Metetra
.78 .743 0 r
.6529 .67462 .66134 .66208 .68044 .65718 .67226 .67089 Metetra
.784 .734 0 r
.67226 .67089 .68044 .65718 .69967 .65219 .69177 .66717 Metetra
.788 .725 0 r
.69177 .66717 .69967 .65219 .71902 .64709 .71144 .66345 Metetra
.791 .715 0 r
.71144 .66345 .71902 .64709 .73851 .64187 .73127 .65974 Metetra
.795 .706 0 r
.73127 .65974 .73851 .64187 .75813 .63654 .75125 .65605 Metetra
.798 .698 0 r
.75125 .65605 .75813 .63654 .77788 .63106 .7714 .65236 Metetra
.802 .689 0 r
.7714 .65236 .77788 .63106 .79775 .62543 .79171 .64869 Metetra
.805 .681 0 r
.79171 .64869 .79775 .62543 .81775 .61963 .81219 .64503 Metetra
.808 .673 0 r
.81219 .64503 .81775 .61963 .83787 .61365 .83285 .64139 Metetra
.811 .665 0 r
.83285 .64139 .83787 .61365 .85811 .60745 .85367 .63775 Metetra
.813 .659 0 r
.85367 .63775 .85811 .60745 .87846 .60103 .87467 .63412 Metetra
.815 .654 0 r
.87467 .63412 .87846 .60103 .89892 .59426 .89584 .63038 Metetra
.814 .655 0 r
.89584 .63038 .89892 .59426 .91937 .5863 .91706 .62544 Metetra
.798 .698 0 r
.91706 .62544 .91937 .5863 .93922 .57234 .93752 .61288 Metetra
.597 .728 0 r
.93752 .61288 .93922 .57234 .95677 .54018 .95496 .57588 Metetra
.041 .556 0 r
.95496 .57588 .95677 .54018 .9708 .48319 .96759 .50451 Metetra
.076 .569 0 r
.37157 .65781 .38196 .66632 .39743 .70518 .38695 .69752 Metetra
.491 .7 0 r
.38695 .69752 .39743 .70518 .41424 .71862 .40376 .71145 Metetra
.682 .749 0 r
.40376 .71145 .41424 .71862 .43169 .71868 .42127 .71168 Metetra
.741 .763 0 r
.42127 .71168 .43169 .71868 .44937 .71547 .43903 .70855 Metetra
.768 .769 0 r
.43903 .70855 .44937 .71547 .46719 .71183 .45693 .70499 Metetra
.774 .757 0 r
.45693 .70499 .46719 .71183 .48515 .70815 .47497 .70139 Metetra
.78 .744 0 r
.47497 .70139 .48515 .70815 .50324 .70445 .49314 .6978 Metetra
.786 .73 0 r
.49314 .6978 .50324 .70445 .52146 .70074 .51145 .6942 Metetra
.791 .715 0 r
.51145 .6942 .52146 .70074 .53981 .69702 .5299 .69062 Metetra
.797 .701 0 r
.5299 .69062 .53981 .69702 .5583 .6933 .54849 .68704 Metetra
.803 .685 0 r
.54849 .68704 .5583 .6933 .57694 .68957 .56722 .68348 Metetra
.809 .669 0 r
.56722 .68348 .57694 .68957 .59571 .68583 .5861 .67994 Metetra
.815 .652 0 r
.5861 .67994 .59571 .68583 .61463 .6821 .60512 .67642 Metetra
.822 .634 0 r
.60512 .67642 .61463 .6821 .63369 .67836 .6243 .67294 Metetra
.828 .616 0 r
.6243 .67294 .63369 .67836 .6529 .67462 .64363 .6695 Metetra
.835 .596 0 r
.64363 .6695 .6529 .67462 .67226 .67089 .66312 .6661 Metetra
.842 .576 0 r
.66312 .6661 .67226 .67089 .69177 .66717 .68277 .66275 Metetra
.849 .554 0 r
.68277 .66275 .69177 .66717 .71144 .66345 .70258 .65946 Metetra
.857 .531 0 r
.70258 .65946 .71144 .66345 .73127 .65974 .72256 .65625 Metetra
.865 .507 0 r
.72256 .65625 .73127 .65974 .75125 .65605 .74272 .65311 Metetra
.873 .481 0 r
.74272 .65311 .75125 .65605 .7714 .65236 .76305 .65007 Metetra
.881 .454 0 r
.76305 .65007 .7714 .65236 .79171 .64869 .78357 .64714 Metetra
.89 .425 0 r
.78357 .64714 .79171 .64869 .81219 .64503 .80428 .64432 Metetra
.899 .393 0 r
.80428 .64432 .81219 .64503 .83285 .64139 .82518 .64165 Metetra
.909 .36 0 r
.82518 .64165 .83285 .64139 .85367 .63775 .84628 .63913 Metetra
.918 .325 0 r
.84628 .63913 .85367 .63775 .87467 .63412 .86759 .63678 Metetra
.929 .287 0 r
.86759 .63678 .87467 .63412 .89584 .63038 .88912 .63454 Metetra
.937 .256 0 r
.88912 .63454 .89584 .63038 .91706 .62544 .91073 .63127 Metetra
.928 .288 0 r
.91073 .63127 .91706 .62544 .93752 .61288 .9316 .62016 Metetra
.857 .53 0 r
.9316 .62016 .93752 .61288 .95496 .57588 .94929 .58271 Metetra
.365 .665 0 r
.94929 .58271 .95496 .57588 .96759 .50451 .9617 .50693 Metetra
.078 .57 0 r
.36113 .64789 .37157 .65781 .38695 .69752 .37641 .68791 Metetra
.5 .703 0 r
.37641 .68791 .38695 .69752 .40376 .71145 .39322 .70203 Metetra
.697 .752 0 r
.39322 .70203 .40376 .71145 .42127 .71168 .41079 .70229 Metetra
.758 .767 0 r
.41079 .70229 .42127 .71168 .43903 .70855 .42861 .69912 Metetra
.773 .76 0 r
.42861 .69912 .43903 .70855 .45693 .70499 .44659 .69551 Metetra
.779 .746 0 r
.44659 .69551 .45693 .70499 .47497 .70139 .46469 .69187 Metetra
.785 .732 0 r
.46469 .69187 .47497 .70139 .49314 .6978 .48294 .68823 Metetra
.791 .717 0 r
.48294 .68823 .49314 .6978 .51145 .6942 .50132 .68458 Metetra
.797 .701 0 r
.50132 .68458 .51145 .6942 .5299 .69062 .51985 .68095 Metetra
.803 .685 0 r
.51985 .68095 .5299 .69062 .54849 .68704 .53851 .67733 Metetra
.81 .668 0 r
.53851 .67733 .54849 .68704 .56722 .68348 .55732 .67373 Metetra
.816 .65 0 r
.55732 .67373 .56722 .68348 .5861 .67994 .57628 .67015 Metetra
.823 .631 0 r
.57628 .67015 .5861 .67994 .60512 .67642 .59539 .6666 Metetra
.83 .611 0 r
.59539 .6666 .60512 .67642 .6243 .67294 .61465 .66308 Metetra
.837 .59 0 r
.61465 .66308 .6243 .67294 .64363 .6695 .63407 .65961 Metetra
.845 .568 0 r
.63407 .65961 .64363 .6695 .66312 .6661 .65364 .65618 Metetra
.853 .544 0 r
.65364 .65618 .66312 .6661 .68277 .66275 .67338 .65282 Metetra
.861 .519 0 r
.67338 .65282 .68277 .66275 .70258 .65946 .69329 .64953 Metetra
.87 .492 0 r
.69329 .64953 .70258 .65946 .72256 .65625 .71337 .64632 Metetra
.879 .462 0 r
.71337 .64632 .72256 .65625 .74272 .65311 .73362 .6432 Metetra
.888 .431 0 r
.73362 .6432 .74272 .65311 .76305 .65007 .75406 .64019 Metetra
.898 .397 0 r
.75406 .64019 .76305 .65007 .78357 .64714 .77468 .63731 Metetra
.909 .36 0 r
.77468 .63731 .78357 .64714 .80428 .64432 .7955 .63457 Metetra
.92 .32 0 r
.7955 .63457 .80428 .64432 .82518 .64165 .81652 .632 Metetra
.932 .276 0 r
.81652 .632 .82518 .64165 .84628 .63913 .83775 .62962 Metetra
.944 .228 0 r
.83775 .62962 .84628 .63913 .86759 .63678 .85919 .62745 Metetra
.958 .175 0 r
.85919 .62745 .86759 .63678 .88912 .63454 .88086 .62545 Metetra
.97 .127 0 r
.88086 .62545 .88912 .63454 .91073 .63127 .90264 .62256 Metetra
.966 .144 0 r
.90264 .62256 .91073 .63127 .9316 .62016 .92375 .61214 Metetra
.898 .398 0 r
.92375 .61214 .9316 .62016 .94929 .58271 .94176 .57565 Metetra
.504 .704 0 r
.94176 .57565 .94929 .58271 .9617 .50693 .95446 .49992 Metetra
.072 .568 0 r
.35056 .63779 .36113 .64789 .37641 .68791 .36576 .67804 Metetra
.494 .701 0 r
.36576 .67804 .37641 .68791 .39322 .70203 .38257 .69232 Metetra
.692 .751 0 r
.38257 .69232 .39322 .70203 .41079 .70229 .40018 .69258 Metetra
.753 .765 0 r
.40018 .69258 .41079 .70229 .42861 .69912 .41808 .68936 Metetra
.772 .762 0 r
.41808 .68936 .42861 .69912 .44659 .69551 .43612 .68568 Metetra
.778 .749 0 r
.43612 .68568 .44659 .69551 .46469 .69187 .4543 .68197 Metetra
.784 .734 0 r
.4543 .68197 .46469 .69187 .48294 .68823 .47262 .67826 Metetra
.79 .72 0 r
.47262 .67826 .48294 .68823 .50132 .68458 .49107 .67454 Metetra
.796 .704 0 r
.49107 .67454 .50132 .68458 .51985 .68095 .50967 .67084 Metetra
.802 .688 0 r
.50967 .67084 .51985 .68095 .53851 .67733 .52841 .66714 Metetra
.808 .671 0 r
.52841 .66714 .53851 .67733 .55732 .67373 .5473 .66346 Metetra
.815 .653 0 r
.5473 .66346 .55732 .67373 .57628 .67015 .56634 .6598 Metetra
.822 .634 0 r
.56634 .6598 .57628 .67015 .59539 .6666 .58552 .65617 Metetra
.829 .615 0 r
.58552 .65617 .59539 .6666 .61465 .66308 .60487 .65257 Metetra
.836 .594 0 r
.60487 .65257 .61465 .66308 .63407 .65961 .62437 .64902 Metetra
.844 .571 0 r
.62437 .64902 .63407 .65961 .65364 .65618 .64403 .64551 Metetra
.852 .547 0 r
.64403 .64551 .65364 .65618 .67338 .65282 .66385 .64206 Metetra
.86 .522 0 r
.66385 .64206 .67338 .65282 .69329 .64953 .68384 .63868 Metetra
.869 .494 0 r
.68384 .63868 .69329 .64953 .71337 .64632 .70401 .63538 Metetra
.878 .465 0 r
.70401 .63538 .71337 .64632 .73362 .6432 .72435 .63217 Metetra
.887 .433 0 r
.72435 .63217 .73362 .6432 .75406 .64019 .74487 .62906 Metetra
.897 .399 0 r
.74487 .62906 .75406 .64019 .77468 .63731 .76559 .62608 Metetra
.908 .361 0 r
.76559 .62608 .77468 .63731 .7955 .63457 .78649 .62324 Metetra
.92 .32 0 r
.78649 .62324 .7955 .63457 .81652 .632 .80761 .62056 Metetra
.932 .275 0 r
.80761 .62056 .81652 .632 .83775 .62962 .82893 .61808 Metetra
.945 .226 0 r
.82893 .61808 .83775 .62962 .85919 .62745 .85047 .61581 Metetra
.959 .171 0 r
.85047 .61581 .85919 .62745 .88086 .62545 .87223 .6137 Metetra
.971 .121 0 r
.87223 .6137 .88086 .62545 .90264 .62256 .89412 .61079 Metetra
.969 .131 0 r
.89412 .61079 .90264 .62256 .92375 .61214 .91539 .60072 Metetra
.904 .375 0 r
.91539 .60072 .92375 .61214 .94176 .57565 .93372 .56525 Metetra
.545 .714 0 r
.93372 .56525 .94176 .57565 .95446 .49992 .94681 .49045 Metetra
.065 .565 0 r
.33987 .62764 .35056 .63779 .36576 .67804 .35497 .6681 Metetra
.486 .699 0 r
.35497 .6681 .36576 .67804 .38257 .69232 .37178 .68253 Metetra
.685 .749 0 r
.37178 .68253 .38257 .69232 .40018 .69258 .38945 .68279 Metetra
.746 .764 0 r
.38945 .68279 .40018 .69258 .41808 .68936 .40741 .67951 Metetra
.771 .766 0 r
.40741 .67951 .41808 .68936 .43612 .68568 .42552 .67577 Metetra
.776 .752 0 r
.42552 .67577 .43612 .68568 .4543 .68197 .44377 .67198 Metetra
.782 .738 0 r
.44377 .67198 .4543 .68197 .47262 .67826 .46216 .6682 Metetra
.788 .724 0 r
.46216 .6682 .47262 .67826 .49107 .67454 .48069 .66441 Metetra
.794 .708 0 r
.48069 .66441 .49107 .67454 .50967 .67084 .49937 .66063 Metetra
.8 .693 0 r
.49937 .66063 .50967 .67084 .52841 .66714 .51819 .65685 Metetra
.807 .676 0 r
.51819 .65685 .52841 .66714 .5473 .66346 .53715 .6531 Metetra
.813 .658 0 r
.53715 .6531 .5473 .66346 .56634 .6598 .55627 .64936 Metetra
.82 .64 0 r
.55627 .64936 .56634 .6598 .58552 .65617 .57554 .64565 Metetra
.827 .62 0 r
.57554 .64565 .58552 .65617 .60487 .65257 .59496 .64196 Metetra
.834 .6 0 r
.59496 .64196 .60487 .65257 .62437 .64902 .61454 .63832 Metetra
.842 .578 0 r
.61454 .63832 .62437 .64902 .64403 .64551 .63428 .63472 Metetra
.849 .554 0 r
.63428 .63472 .64403 .64551 .66385 .64206 .65419 .63118 Metetra
.858 .529 0 r
.65419 .63118 .66385 .64206 .68384 .63868 .67427 .6277 Metetra
.866 .502 0 r
.67427 .6277 .68384 .63868 .70401 .63538 .69452 .6243 Metetra
.875 .473 0 r
.69452 .6243 .70401 .63538 .72435 .63217 .71495 .62099 Metetra
.885 .442 0 r
.71495 .62099 .72435 .63217 .74487 .62906 .73557 .61778 Metetra
.895 .408 0 r
.73557 .61778 .74487 .62906 .76559 .62608 .75637 .61469 Metetra
.905 .372 0 r
.75637 .61469 .76559 .62608 .78649 .62324 .77737 .61173 Metetra
.917 .332 0 r
.77737 .61173 .78649 .62324 .80761 .62056 .79857 .60893 Metetra
.929 .288 0 r
.79857 .60893 .80761 .62056 .82893 .61808 .81999 .60631 Metetra
.941 .239 0 r
.81999 .60631 .82893 .61808 .85047 .61581 .84162 .60391 Metetra
.955 .186 0 r
.84162 .60391 .85047 .61581 .87223 .6137 .86348 .60167 Metetra
.968 .136 0 r
.86348 .60167 .87223 .6137 .89412 .61079 .88547 .59867 Metetra
.966 .143 0 r
.88547 .59867 .89412 .61079 .91539 .60072 .9069 .58884 Metetra
.904 .375 0 r
.9069 .58884 .91539 .60072 .93372 .56525 .92551 .55427 Metetra
.562 .719 0 r
.92551 .55427 .93372 .56525 .94681 .49045 .93898 .48037 Metetra
.059 .563 0 r
.32905 .61744 .33987 .62764 .35497 .6681 .34406 .65811 Metetra
.479 .697 0 r
.34406 .65811 .35497 .6681 .37178 .68253 .36086 .67267 Metetra
.679 .748 0 r
.36086 .67267 .37178 .68253 .38945 .68279 .37858 .67293 Metetra
.741 .763 0 r
.37858 .67293 .38945 .68279 .40741 .67951 .39661 .66959 Metetra
.769 .769 0 r
.39661 .66959 .40741 .67951 .42552 .67577 .41479 .66578 Metetra
.775 .756 0 r
.41479 .66578 .42552 .67577 .44377 .67198 .43312 .66192 Metetra
.781 .742 0 r
.43312 .66192 .44377 .67198 .46216 .6682 .45158 .65806 Metetra
.787 .727 0 r
.45158 .65806 .46216 .6682 .48069 .66441 .47019 .6542 Metetra
.793 .712 0 r
.47019 .6542 .48069 .66441 .49937 .66063 .48894 .65034 Metetra
.799 .697 0 r
.48894 .65034 .49937 .66063 .51819 .65685 .50783 .64649 Metetra
.805 .68 0 r
.50783 .64649 .51819 .65685 .53715 .6531 .52688 .64266 Metetra
.811 .663 0 r
.52688 .64266 .53715 .6531 .55627 .64936 .54607 .63884 Metetra
.818 .645 0 r
.54607 .63884 .55627 .64936 .57554 .64565 .56542 .63505 Metetra
.825 .625 0 r
.56542 .63505 .57554 .64565 .59496 .64196 .58493 .63128 Metetra
.832 .605 0 r
.58493 .63128 .59496 .64196 .61454 .63832 .60459 .62755 Metetra
.84 .583 0 r
.60459 .62755 .61454 .63832 .63428 .63472 .62442 .62386 Metetra
.847 .56 0 r
.62442 .62386 .63428 .63472 .65419 .63118 .64442 .62023 Metetra
.855 .536 0 r
.64442 .62023 .65419 .63118 .67427 .6277 .66458 .61666 Metetra
.864 .509 0 r
.66458 .61666 .67427 .6277 .69452 .6243 .68492 .61317 Metetra
.873 .481 0 r
.68492 .61317 .69452 .6243 .71495 .62099 .70544 .60976 Metetra
.882 .451 0 r
.70544 .60976 .71495 .62099 .73557 .61778 .72615 .60644 Metetra
.892 .417 0 r
.72615 .60644 .73557 .61778 .75637 .61469 .74704 .60324 Metetra
.902 .382 0 r
.74704 .60324 .75637 .61469 .77737 .61173 .76814 .60017 Metetra
.914 .342 0 r
.76814 .60017 .77737 .61173 .79857 .60893 .78943 .59725 Metetra
.925 .299 0 r
.78943 .59725 .79857 .60893 .81999 .60631 .81094 .59451 Metetra
.938 .252 0 r
.81094 .59451 .81999 .60631 .84162 .60391 .83267 .59198 Metetra
.951 .2 0 r
.83267 .59198 .84162 .60391 .86348 .60167 .85462 .5896 Metetra
.964 .151 0 r
.85462 .5896 .86348 .60167 .88547 .59867 .87671 .58652 Metetra
.963 .156 0 r
.87671 .58652 .88547 .59867 .9069 .58884 .89829 .57688 Metetra
.904 .378 0 r
.89829 .57688 .9069 .58884 .92551 .55427 .91718 .54306 Metetra
.576 .722 0 r
.91718 .54306 .92551 .55427 .93898 .48037 .93102 .46994 Metetra
.053 .56 0 r
.3181 .6072 .32905 .61744 .34406 .65811 .33301 .64806 Metetra
.473 .696 0 r
.33301 .64806 .34406 .65811 .36086 .67267 .34981 .66273 Metetra
.674 .747 0 r
.34981 .66273 .36086 .67267 .37858 .67293 .36758 .66298 Metetra
.736 .761 0 r
.36758 .66298 .37858 .67293 .39661 .66959 .38568 .65958 Metetra
.764 .768 0 r
.38568 .65958 .39661 .66959 .41479 .66578 .40393 .6557 Metetra
.774 .759 0 r
.40393 .6557 .41479 .66578 .43312 .66192 .42233 .65178 Metetra
.779 .745 0 r
.42233 .65178 .43312 .66192 .45158 .65806 .44087 .64785 Metetra
.785 .731 0 r
.44087 .64785 .45158 .65806 .47019 .6542 .45955 .64392 Metetra
.791 .716 0 r
.45955 .64392 .47019 .6542 .48894 .65034 .47837 .63998 Metetra
.797 .7 0 r
.47837 .63998 .48894 .65034 .50783 .64649 .49735 .63606 Metetra
.804 .684 0 r
.49735 .63606 .50783 .64649 .52688 .64266 .51647 .63215 Metetra
.81 .667 0 r
.51647 .63215 .52688 .64266 .54607 .63884 .53575 .62825 Metetra
.817 .649 0 r
.53575 .62825 .54607 .63884 .56542 .63505 .55518 .62437 Metetra
.823 .63 0 r
.55518 .62437 .56542 .63505 .58493 .63128 .57477 .62052 Metetra
.831 .61 0 r
.57477 .62052 .58493 .63128 .60459 .62755 .59452 .61671 Metetra
.838 .589 0 r
.59452 .61671 .60459 .62755 .62442 .62386 .61443 .61293 Metetra
.846 .566 0 r
.61443 .61293 .62442 .62386 .64442 .62023 .63452 .60921 Metetra
.854 .542 0 r
.63452 .60921 .64442 .62023 .66458 .61666 .65477 .60555 Metetra
.862 .516 0 r
.65477 .60555 .66458 .61666 .68492 .61317 .6752 .60196 Metetra
.871 .488 0 r
.6752 .60196 .68492 .61317 .70544 .60976 .69581 .59845 Metetra
.88 .458 0 r
.69581 .59845 .70544 .60976 .72615 .60644 .71661 .59504 Metetra
.89 .425 0 r
.71661 .59504 .72615 .60644 .74704 .60324 .7376 .59174 Metetra
.9 .39 0 r
.7376 .59174 .74704 .60324 .76814 .60017 .75878 .58856 Metetra
.911 .352 0 r
.75878 .58856 .76814 .60017 .78943 .59725 .78018 .58553 Metetra
.923 .31 0 r
.78018 .58553 .78943 .59725 .81094 .59451 .80178 .58267 Metetra
.935 .263 0 r
.80178 .58267 .81094 .59451 .83267 .59198 .8236 .58001 Metetra
.948 .213 0 r
.8236 .58001 .83267 .59198 .85462 .5896 .84565 .57751 Metetra
.961 .164 0 r
.84565 .57751 .85462 .5896 .87671 .58652 .86785 .57434 Metetra
.96 .167 0 r
.86785 .57434 .87671 .58652 .89829 .57688 .88958 .56484 Metetra
.903 .38 0 r
.88958 .56484 .89829 .57688 .91718 .54306 .90872 .53164 Metetra
.587 .725 0 r
.90872 .53164 .91718 .54306 .93102 .46994 .92291 .45917 Metetra
.049 .559 0 r
.30701 .59691 .3181 .6072 .33301 .64806 .32182 .63795 Metetra
.468 .694 0 r
.32182 .63795 .33301 .64806 .34981 .66273 .33861 .65272 Metetra
.669 .746 0 r
.33861 .65272 .34981 .66273 .36758 .66298 .35644 .65296 Metetra
.731 .76 0 r
.35644 .65296 .36758 .66298 .38568 .65958 .3746 .6495 Metetra
.76 .767 0 r
.3746 .6495 .38568 .65958 .40393 .6557 .39293 .64555 Metetra
.773 .761 0 r
.39293 .64555 .40393 .6557 .42233 .65178 .4114 .64155 Metetra
.778 .748 0 r
.4114 .64155 .42233 .65178 .44087 .64785 .43001 .63755 Metetra
.784 .733 0 r
.43001 .63755 .44087 .64785 .45955 .64392 .44877 .63354 Metetra
.79 .719 0 r
.44877 .63354 .45955 .64392 .47837 .63998 .46768 .62954 Metetra
.796 .703 0 r
.46768 .62954 .47837 .63998 .49735 .63606 .48673 .62553 Metetra
.802 .687 0 r
.48673 .62553 .49735 .63606 .51647 .63215 .50593 .62155 Metetra
.809 .67 0 r
.50593 .62155 .51647 .63215 .53575 .62825 .52529 .61757 Metetra
.815 .653 0 r
.52529 .61757 .53575 .62825 .55518 .62437 .54481 .61361 Metetra
.822 .634 0 r
.54481 .61361 .55518 .62437 .57477 .62052 .56448 .60968 Metetra
.829 .614 0 r
.56448 .60968 .57477 .62052 .59452 .61671 .58432 .60578 Metetra
.836 .593 0 r
.58432 .60578 .59452 .61671 .61443 .61293 .60432 .60192 Metetra
.844 .571 0 r
.60432 .60192 .61443 .61293 .63452 .60921 .62449 .59811 Metetra
.852 .547 0 r
.62449 .59811 .63452 .60921 .65477 .60555 .64483 .59436 Metetra
.86 .521 0 r
.64483 .59436 .65477 .60555 .6752 .60196 .66536 .59069 Metetra
.869 .494 0 r
.66536 .59069 .6752 .60196 .69581 .59845 .68606 .58708 Metetra
.878 .464 0 r
.68606 .58708 .69581 .59845 .71661 .59504 .70695 .58357 Metetra
.888 .432 0 r
.70695 .58357 .71661 .59504 .7376 .59174 .72803 .58016 Metetra
.898 .398 0 r
.72803 .58016 .7376 .59174 .75878 .58856 .74932 .57688 Metetra
.909 .36 0 r
.74932 .57688 .75878 .58856 .78018 .58553 .7708 .57374 Metetra
.92 .318 0 r
.7708 .57374 .78018 .58553 .80178 .58267 .79251 .57077 Metetra
.932 .273 0 r
.79251 .57077 .80178 .58267 .8236 .58001 .81443 .568 Metetra
.945 .224 0 r
.81443 .568 .8236 .58001 .84565 .57751 .83658 .56537 Metetra
.958 .176 0 r
.83658 .56537 .84565 .57751 .86785 .57434 .85889 .56211 Metetra
.957 .177 0 r
.85889 .56211 .86785 .57434 .88958 .56484 .88076 .55272 Metetra
.902 .383 0 r
.88076 .55272 .88958 .56484 .90872 .53164 .90015 .52002 Metetra
.597 .728 0 r
.90015 .52002 .90872 .53164 .92291 .45917 .91467 .44808 Metetra
.045 .557 0 r
.29579 .58657 .30701 .59691 .32182 .63795 .31049 .62777 Metetra
.464 .693 0 r
.31049 .62777 .32182 .63795 .33861 .65272 .32728 .64263 Metetra
.665 .745 0 r
.32728 .64263 .33861 .65272 .35644 .65296 .34515 .64284 Metetra
.728 .76 0 r
.34515 .64284 .35644 .65296 .3746 .6495 .36339 .63932 Metetra
.756 .766 0 r
.36339 .63932 .3746 .6495 .39293 .64555 .38179 .6353 Metetra
.772 .763 0 r
.38179 .6353 .39293 .64555 .4114 .64155 .40033 .63124 Metetra
.777 .75 0 r
.40033 .63124 .4114 .64155 .43001 .63755 .41902 .62716 Metetra
.783 .736 0 r
.41902 .62716 .43001 .63755 .44877 .63354 .43786 .62308 Metetra
.789 .721 0 r
.43786 .62308 .44877 .63354 .46768 .62954 .45684 .619 Metetra
.795 .706 0 r
.45684 .619 .46768 .62954 .48673 .62553 .47597 .61492 Metetra
.801 .69 0 r
.47597 .61492 .48673 .62553 .50593 .62155 .49526 .61086 Metetra
.808 .673 0 r
.49526 .61086 .50593 .62155 .52529 .61757 .5147 .6068 Metetra
.814 .656 0 r
.5147 .6068 .52529 .61757 .54481 .61361 .5343 .60277 Metetra
.821 .637 0 r
.5343 .60277 .54481 .61361 .56448 .60968 .55406 .59875 Metetra
.828 .617 0 r
.55406 .59875 .56448 .60968 .58432 .60578 .57398 .59477 Metetra
.835 .597 0 r
.57398 .59477 .58432 .60578 .60432 .60192 .59407 .59083 Metetra
.843 .575 0 r
.59407 .59083 .60432 .60192 .62449 .59811 .61433 .58693 Metetra
.851 .551 0 r
.61433 .58693 .62449 .59811 .64483 .59436 .63477 .58309 Metetra
.859 .526 0 r
.63477 .58309 .64483 .59436 .66536 .59069 .65538 .57932 Metetra
.867 .499 0 r
.65538 .57932 .66536 .59069 .68606 .58708 .67618 .57563 Metetra
.876 .469 0 r
.67618 .57563 .68606 .58708 .70695 .58357 .69717 .57202 Metetra
.886 .438 0 r
.69717 .57202 .70695 .58357 .72803 .58016 .71835 .56852 Metetra
.896 .404 0 r
.71835 .56852 .72803 .58016 .74932 .57688 .73973 .56514 Metetra
.907 .367 0 r
.73973 .56514 .74932 .57688 .7708 .57374 .76131 .56189 Metetra
.918 .326 0 r
.76131 .56189 .7708 .57374 .79251 .57077 .78312 .55881 Metetra
.93 .281 0 r
.78312 .55881 .79251 .57077 .81443 .568 .80514 .55592 Metetra
.943 .232 0 r
.80514 .55592 .81443 .568 .83658 .56537 .8274 .55319 Metetra
.955 .185 0 r
.8274 .55319 .83658 .56537 .85889 .56211 .84981 .54984 Metetra
.955 .185 0 r
.84981 .54984 .85889 .56211 .88076 .55272 .87182 .54051 Metetra
.901 .385 0 r
.87182 .54051 .88076 .55272 .90015 .52002 .89144 .5082 Metetra
.605 .73 0 r
.89144 .5082 .90015 .52002 .91467 .44808 .90629 .43666 Metetra
.041 .556 0 r
.28443 .57616 .29579 .58657 .31049 .62777 .29901 .61752 Metetra
.46 .692 0 r
.29901 .61752 .31049 .62777 .32728 .64263 .31579 .63245 Metetra
.662 .744 0 r
.31579 .63245 .32728 .64263 .34515 .64284 .33373 .63264 Metetra
.725 .759 0 r
.33373 .63264 .34515 .64284 .36339 .63932 .35203 .62905 Metetra
.753 .765 0 r
.35203 .62905 .36339 .63932 .38179 .6353 .37051 .62497 Metetra
.771 .765 0 r
.37051 .62497 .38179 .6353 .40033 .63124 .38912 .62083 Metetra
.777 .752 0 r
.38912 .62083 .40033 .63124 .41902 .62716 .40789 .61668 Metetra
.782 .738 0 r
.40789 .61668 .41902 .62716 .43786 .62308 .4268 .61253 Metetra
.788 .723 0 r
.4268 .61253 .43786 .62308 .45684 .619 .44586 .60837 Metetra
.794 .708 0 r
.44586 .60837 .45684 .619 .47597 .61492 .46508 .60422 Metetra
.8 .692 0 r
.46508 .60422 .47597 .61492 .49526 .61086 .48444 .60008 Metetra
.807 .676 0 r
.48444 .60008 .49526 .61086 .5147 .6068 .50397 .59594 Metetra
.813 .658 0 r
.50397 .59594 .5147 .6068 .5343 .60277 .52365 .59183 Metetra
.82 .64 0 r
.52365 .59183 .5343 .60277 .55406 .59875 .5435 .58773 Metetra
.827 .62 0 r
.5435 .58773 .55406 .59875 .57398 .59477 .56351 .58367 Metetra
.834 .6 0 r
.56351 .58367 .57398 .59477 .59407 .59083 .58369 .57964 Metetra
.842 .578 0 r
.58369 .57964 .59407 .59083 .61433 .58693 .60404 .57566 Metetra
.849 .554 0 r
.60404 .57566 .61433 .58693 .63477 .58309 .62457 .57173 Metetra
.858 .529 0 r
.62457 .57173 .63477 .58309 .65538 .57932 .64528 .56788 Metetra
.866 .503 0 r
.64528 .56788 .65538 .57932 .67618 .57563 .66617 .56409 Metetra
.875 .474 0 r
.66617 .56409 .67618 .57563 .69717 .57202 .68725 .56039 Metetra
.885 .443 0 r
.68725 .56039 .69717 .57202 .71835 .56852 .70853 .55679 Metetra
.895 .409 0 r
.70853 .55679 .71835 .56852 .73973 .56514 .73001 .55331 Metetra
.905 .372 0 r
.73001 .55331 .73973 .56514 .76131 .56189 .7517 .54997 Metetra
.916 .332 0 r
.7517 .54997 .76131 .56189 .78312 .55881 .7736 .54679 Metetra
.928 .288 0 r
.7736 .54679 .78312 .55881 .80514 .55592 .79573 .54379 Metetra
.941 .24 0 r
.79573 .54379 .80514 .55592 .8274 .55319 .81809 .54095 Metetra
.953 .193 0 r
.81809 .54095 .8274 .55319 .84981 .54984 .84062 .53751 Metetra
.953 .192 0 r
.84062 .53751 .84981 .54984 .87182 .54051 .86277 .52821 Metetra
.901 .387 0 r
.86277 .52821 .87182 .54051 .89144 .5082 .88261 .49619 Metetra
.611 .731 0 r
.88261 .49619 .89144 .5082 .90629 .43666 .89778 .42493 Metetra
.039 .555 0 r
.27292 .5657 .28443 .57616 .29901 .61752 .28739 .60719 Metetra
.458 .691 0 r
.28739 .60719 .29901 .61752 .31579 .63245 .30416 .62218 Metetra
.66 .743 0 r
.30416 .62218 .31579 .63245 .33373 .63264 .32215 .62234 Metetra
.722 .758 0 r
.32215 .62234 .33373 .63264 .35203 .62905 .34053 .61869 Metetra
.75 .765 0 r
.34053 .61869 .35203 .62905 .37051 .62497 .35907 .61453 Metetra
.77 .766 0 r
.35907 .61453 .37051 .62497 .38912 .62083 .37777 .61032 Metetra
.776 .753 0 r
.37777 .61032 .38912 .62083 .40789 .61668 .39661 .6061 Metetra
.782 .739 0 r
.39661 .6061 .40789 .61668 .4268 .61253 .4156 .60188 Metetra
.788 .725 0 r
.4156 .60188 .4268 .61253 .44586 .60837 .43474 .59764 Metetra
.794 .71 0 r
.43474 .59764 .44586 .60837 .46508 .60422 .45404 .59342 Metetra
.8 .694 0 r
.45404 .59342 .46508 .60422 .48444 .60008 .47349 .5892 Metetra
.806 .677 0 r
.47349 .5892 .48444 .60008 .50397 .59594 .49309 .58499 Metetra
.813 .66 0 r
.49309 .58499 .50397 .59594 .52365 .59183 .51286 .58079 Metetra
.819 .642 0 r
.51286 .58079 .52365 .59183 .5435 .58773 .5328 .57662 Metetra
.826 .623 0 r
.5328 .57662 .5435 .58773 .56351 .58367 .5529 .57247 Metetra
.833 .602 0 r
.5529 .57247 .56351 .58367 .58369 .57964 .57317 .56836 Metetra
.841 .58 0 r
.57317 .56836 .58369 .57964 .60404 .57566 .59361 .5643 Metetra
.848 .557 0 r
.59361 .5643 .60404 .57566 .62457 .57173 .61423 .56028 Metetra
.857 .532 0 r
.61423 .56028 .62457 .57173 .64528 .56788 .63503 .55634 Metetra
.865 .506 0 r
.63503 .55634 .64528 .56788 .66617 .56409 .65602 .55246 Metetra
.874 .477 0 r
.65602 .55246 .66617 .56409 .68725 .56039 .67721 .54867 Metetra
.883 .446 0 r
.67721 .54867 .68725 .56039 .70853 .55679 .69858 .54498 Metetra
.893 .413 0 r
.69858 .54498 .70853 .55679 .73001 .55331 .72017 .54141 Metetra
.904 .377 0 r
.72017 .54141 .73001 .55331 .7517 .54997 .74196 .53797 Metetra
.915 .337 0 r
.74196 .53797 .7517 .54997 .7736 .54679 .76397 .53469 Metetra
.927 .293 0 r
.76397 .53469 .7736 .54679 .79573 .54379 .7862 .53159 Metetra
.94 .246 0 r
.7862 .53159 .79573 .54379 .81809 .54095 .80867 .52864 Metetra
.952 .199 0 r
.80867 .52864 .81809 .54095 .84062 .53751 .83131 .52511 Metetra
.952 .198 0 r
.83131 .52511 .84062 .53751 .86277 .52821 .8536 .51581 Metetra
.901 .388 0 r
.8536 .51581 .86277 .52821 .88261 .49619 .87366 .48397 Metetra
.617 .733 0 r
.87366 .48397 .88261 .49619 .89778 .42493 .88912 .41287 Metetra
.037 .554 0 r
.26126 .55518 .27292 .5657 .28739 .60719 .27562 .59679 Metetra
.455 .691 0 r
.27562 .59679 .28739 .60719 .30416 .62218 .29238 .61182 Metetra
.658 .743 0 r
.29238 .61182 .30416 .62218 .32215 .62234 .31042 .61194 Metetra
.72 .758 0 r
.31042 .61194 .32215 .62234 .34053 .61869 .32887 .60823 Metetra
.748 .764 0 r
.32887 .60823 .34053 .61869 .35907 .61453 .34749 .604 Metetra
.77 .767 0 r
.34749 .604 .35907 .61453 .37777 .61032 .36626 .59972 Metetra
.776 .754 0 r
.36626 .59972 .37777 .61032 .39661 .6061 .38518 .59543 Metetra
.781 .74 0 r
.38518 .59543 .39661 .6061 .4156 .60188 .40425 .59112 Metetra
.787 .726 0 r
.40425 .59112 .4156 .60188 .43474 .59764 .42347 .58682 Metetra
.793 .711 0 r
.42347 .58682 .43474 .59764 .45404 .59342 .44285 .58252 Metetra
.799 .695 0 r
.44285 .58252 .45404 .59342 .47349 .5892 .46238 .57822 Metetra
.805 .679 0 r
.46238 .57822 .47349 .5892 .49309 .58499 .48208 .57393 Metetra
.812 .662 0 r
.48208 .57393 .49309 .58499 .51286 .58079 .50193 .56965 Metetra
.819 .644 0 r
.50193 .56965 .51286 .58079 .5328 .57662 .52195 .5654 Metetra
.825 .624 0 r
.52195 .5654 .5328 .57662 .5529 .57247 .54214 .56117 Metetra
.833 .604 0 r
.54214 .56117 .5529 .57247 .57317 .56836 .5625 .55698 Metetra
.84 .582 0 r
.5625 .55698 .57317 .56836 .59361 .5643 .58304 .55283 Metetra
.848 .559 0 r
.58304 .55283 .59361 .5643 .61423 .56028 .60376 .54874 Metetra
.856 .535 0 r
.60376 .54874 .61423 .56028 .63503 .55634 .62466 .54471 Metetra
.864 .508 0 r
.62466 .54471 .63503 .55634 .65602 .55246 .64574 .54074 Metetra
.873 .48 0 r
.64574 .54074 .65602 .55246 .67721 .54867 .66702 .53687 Metetra
.883 .449 0 r
.66702 .53687 .67721 .54867 .69858 .54498 .6885 .53308 Metetra
.892 .416 0 r
.6885 .53308 .69858 .54498 .72017 .54141 .71019 .52942 Metetra
.903 .38 0 r
.71019 .52942 .72017 .54141 .74196 .53797 .73209 .52588 Metetra
.914 .341 0 r
.73209 .52588 .74196 .53797 .76397 .53469 .7542 .52251 Metetra
.926 .297 0 r
.7542 .52251 .76397 .53469 .7862 .53159 .77655 .51931 Metetra
.938 .25 0 r
.77655 .51931 .7862 .53159 .80867 .52864 .79912 .51626 Metetra
.95 .204 0 r
.79912 .51626 .80867 .52864 .83131 .52511 .82188 .51265 Metetra
.951 .202 0 r
.82188 .51265 .83131 .52511 .8536 .51581 .8443 .50332 Metetra
.9 .389 0 r
.8443 .50332 .8536 .51581 .87366 .48397 .86456 .47156 Metetra
.621 .734 0 r
.86456 .47156 .87366 .48397 .88912 .41287 .88032 .40049 Metetra
.035 .553 0 r
.24945 .54459 .26126 .55518 .27562 .59679 .26369 .58631 Metetra
.454 .69 0 r
.26369 .58631 .27562 .59679 .29238 .61182 .28045 .60137 Metetra
.656 .742 0 r
.28045 .60137 .29238 .61182 .31042 .61194 .29854 .60144 Metetra
.719 .758 0 r
.29854 .60144 .31042 .61194 .32887 .60823 .31706 .59766 Metetra
.747 .764 0 r
.31706 .59766 .32887 .60823 .34749 .604 .33576 .59336 Metetra
.77 .768 0 r
.33576 .59336 .34749 .604 .36626 .59972 .35461 .58901 Metetra
.775 .755 0 r
.35461 .58901 .36626 .59972 .38518 .59543 .3736 .58464 Metetra
.781 .741 0 r
.3736 .58464 .38518 .59543 .40425 .59112 .39275 .58027 Metetra
.787 .727 0 r
.39275 .58027 .40425 .59112 .42347 .58682 .41205 .57589 Metetra
.793 .712 0 r
.41205 .57589 .42347 .58682 .44285 .58252 .43151 .57151 Metetra
.799 .696 0 r
.43151 .57151 .44285 .58252 .46238 .57822 .45113 .56713 Metetra
.805 .68 0 r
.45113 .56713 .46238 .57822 .48208 .57393 .47091 .56277 Metetra
.812 .663 0 r
.47091 .56277 .48208 .57393 .50193 .56965 .49085 .55841 Metetra
.818 .645 0 r
.49085 .55841 .50193 .56965 .52195 .5654 .51096 .55408 Metetra
.825 .626 0 r
.51096 .55408 .52195 .5654 .54214 .56117 .53124 .54977 Metetra
.832 .605 0 r
.53124 .54977 .54214 .56117 .5625 .55698 .5517 .5455 Metetra
.84 .584 0 r
.5517 .5455 .5625 .55698 .58304 .55283 .57233 .54127 Metetra
.847 .561 0 r
.57233 .54127 .58304 .55283 .60376 .54874 .59314 .53709 Metetra
.855 .536 0 r
.59314 .53709 .60376 .54874 .62466 .54471 .61414 .53298 Metetra
.864 .51 0 r
.61414 .53298 .62466 .54471 .64574 .54074 .63532 .52893 Metetra
.873 .482 0 r
.63532 .52893 .64574 .54074 .66702 .53687 .6567 .52496 Metetra
.882 .451 0 r
.6567 .52496 .66702 .53687 .6885 .53308 .67829 .52109 Metetra
.892 .418 0 r
.67829 .52109 .6885 .53308 .71019 .52942 .70008 .51734 Metetra
.902 .382 0 r
.70008 .51734 .71019 .52942 .73209 .52588 .72208 .51371 Metetra
.913 .343 0 r
.72208 .51371 .73209 .52588 .7542 .52251 .7443 .51024 Metetra
.925 .3 0 r
.7443 .51024 .7542 .52251 .77655 .51931 .76676 .50695 Metetra
.938 .253 0 r
.76676 .50695 .77655 .51931 .79912 .51626 .78945 .50381 Metetra
.95 .208 0 r
.78945 .50381 .79912 .51626 .82188 .51265 .81232 .5001 Metetra
.95 .205 0 r
.81232 .5001 .82188 .51265 .8443 .50332 .83488 .49071 Metetra
.9 .39 0 r
.83488 .49071 .8443 .50332 .86456 .47156 .85534 .45895 Metetra
.624 .734 0 r
.85534 .45895 .86456 .47156 .88032 .40049 .87137 .38779 Metetra
.035 .553 0 r
.23749 .53393 .24945 .54459 .26369 .58631 .25161 .57575 Metetra
.453 .69 0 r
.25161 .57575 .26369 .58631 .28045 .60137 .26836 .59082 Metetra
.656 .742 0 r
.26836 .59082 .28045 .60137 .29854 .60144 .28651 .59084 Metetra
.718 .757 0 r
.28651 .59084 .29854 .60144 .31706 .59766 .3051 .58699 Metetra
.746 .764 0 r
.3051 .58699 .31706 .59766 .33576 .59336 .32387 .58262 Metetra
.77 .769 0 r
.32387 .58262 .33576 .59336 .35461 .58901 .34279 .57819 Metetra
.775 .755 0 r
.34279 .57819 .35461 .58901 .3736 .58464 .36187 .57375 Metetra
.781 .742 0 r
.36187 .57375 .3736 .58464 .39275 .58027 .3811 .5693 Metetra
.787 .727 0 r
.3811 .5693 .39275 .58027 .41205 .57589 .40048 .56485 Metetra
.793 .712 0 r
.40048 .56485 .41205 .57589 .43151 .57151 .42002 .5604 Metetra
.799 .697 0 r
.42002 .5604 .43151 .57151 .45113 .56713 .43973 .55594 Metetra
.805 .68 0 r
.43973 .55594 .45113 .56713 .47091 .56277 .45959 .5515 Metetra
.811 .663 0 r
.45959 .5515 .47091 .56277 .49085 .55841 .47962 .54707 Metetra
.818 .645 0 r
.47962 .54707 .49085 .55841 .51096 .55408 .49982 .54265 Metetra
.825 .626 0 r
.49982 .54265 .51096 .55408 .53124 .54977 .52019 .53827 Metetra
.832 .606 0 r
.52019 .53827 .53124 .54977 .5517 .5455 .54074 .53391 Metetra
.839 .585 0 r
.54074 .53391 .5517 .5455 .57233 .54127 .56147 .5296 Metetra
.847 .562 0 r
.56147 .5296 .57233 .54127 .59314 .53709 .58237 .52534 Metetra
.855 .537 0 r
.58237 .52534 .59314 .53709 .61414 .53298 .60347 .52114 Metetra
.863 .511 0 r
.60347 .52114 .61414 .53298 .63532 .52893 .62476 .51701 Metetra
.872 .483 0 r
.62476 .51701 .63532 .52893 .6567 .52496 .64624 .51296 Metetra
.882 .452 0 r
.64624 .51296 .6567 .52496 .67829 .52109 .66793 .509 Metetra
.891 .419 0 r
.66793 .509 .67829 .52109 .70008 .51734 .68982 .50516 Metetra
.902 .384 0 r
.68982 .50516 .70008 .51734 .72208 .51371 .71193 .50145 Metetra
.913 .345 0 r
.71193 .50145 .72208 .51371 .7443 .51024 .73427 .49789 Metetra
.925 .302 0 r
.73427 .49789 .7443 .51024 .76676 .50695 .75684 .49451 Metetra
.937 .255 0 r
.75684 .49451 .76676 .50695 .78945 .50381 .77964 .49127 Metetra
.949 .209 0 r
.77964 .49127 .78945 .50381 .81232 .5001 .80263 .48748 Metetra
.95 .207 0 r
.80263 .48748 .81232 .5001 .83488 .49071 .82533 .478 Metetra
.9 .391 0 r
.82533 .478 .83488 .49071 .85534 .45895 .84598 .44613 Metetra
.625 .735 0 r
.84598 .44613 .85534 .45895 .87137 .38779 .86229 .37476 Metetra
.034 .553 0 r
.22537 .52321 .23749 .53393 .25161 .57575 .23936 .5651 Metetra
.453 .69 0 r
.23936 .5651 .25161 .57575 .26836 .59082 .2561 .58016 Metetra
.655 .742 0 r
.2561 .58016 .26836 .59082 .28651 .59084 .27431 .58013 Metetra
.718 .757 0 r
.27431 .58013 .28651 .59084 .3051 .58699 .29297 .57621 Metetra
.746 .764 0 r
.29297 .57621 .3051 .58699 .32387 .58262 .31182 .57177 Metetra
.769 .769 0 r
.31182 .57177 .32387 .58262 .34279 .57819 .33082 .56727 Metetra
.775 .755 0 r
.33082 .56727 .34279 .57819 .36187 .57375 .34997 .56276 Metetra
.781 .742 0 r
.34997 .56276 .36187 .57375 .3811 .5693 .36928 .55823 Metetra
.787 .727 0 r
.36928 .55823 .3811 .5693 .40048 .56485 .38875 .5537 Metetra
.793 .713 0 r
.38875 .5537 .40048 .56485 .42002 .5604 .40838 .54917 Metetra
.799 .697 0 r
.40838 .54917 .42002 .5604 .43973 .55594 .42816 .54464 Metetra
.805 .681 0 r
.42816 .54464 .43973 .55594 .45959 .5515 .44812 .54012 Metetra
.811 .663 0 r
.44812 .54012 .45959 .5515 .47962 .54707 .46824 .53561 Metetra
.818 .645 0 r
.46824 .53561 .47962 .54707 .49982 .54265 .48853 .53112 Metetra
.825 .626 0 r
.48853 .53112 .49982 .54265 .52019 .53827 .50899 .52665 Metetra
.832 .606 0 r
.50899 .52665 .52019 .53827 .54074 .53391 .52963 .52222 Metetra
.839 .585 0 r
.52963 .52222 .54074 .53391 .56147 .5296 .55045 .51782 Metetra
.847 .562 0 r
.55045 .51782 .56147 .5296 .58237 .52534 .57146 .51348 Metetra
.855 .537 0 r
.57146 .51348 .58237 .52534 .60347 .52114 .59266 .5092 Metetra
.863 .511 0 r
.59266 .5092 .60347 .52114 .62476 .51701 .61405 .50498 Metetra
.872 .483 0 r
.61405 .50498 .62476 .51701 .64624 .51296 .63563 .50085 Metetra
.882 .453 0 r
.63563 .50085 .64624 .51296 .66793 .509 .65743 .49681 Metetra
.891 .42 0 r
.65743 .49681 .66793 .509 .68982 .50516 .67943 .49288 Metetra
.902 .384 0 r
.67943 .49288 .68982 .50516 .71193 .50145 .70165 .48909 Metetra
.913 .345 0 r
.70165 .48909 .71193 .50145 .73427 .49789 .7241 .48544 Metetra
.925 .302 0 r
.7241 .48544 .73427 .49789 .75684 .49451 .74678 .48198 Metetra
.937 .255 0 r
.74678 .48198 .75684 .49451 .77964 .49127 .7697 .47866 Metetra
.949 .21 0 r
.7697 .47866 .77964 .49127 .80263 .48748 .7928 .47477 Metetra
.95 .207 0 r
.7928 .47477 .80263 .48748 .82533 .478 .81564 .46518 Metetra
.9 .391 0 r
.81564 .46518 .82533 .478 .84598 .44613 .83648 .4331 Metetra
.626 .735 0 r
.83648 .4331 .84598 .44613 .86229 .37476 .85305 .36141 Metetra
.035 .553 0 r
.21309 .51241 .22537 .52321 .23936 .5651 .22695 .55437 Metetra
.453 .69 0 r
.22695 .55437 .23936 .5651 .2561 .58016 .24369 .56941 Metetra
.656 .742 0 r
.24369 .56941 .2561 .58016 .27431 .58013 .26194 .56931 Metetra
.719 .757 0 r
.26194 .56931 .27431 .58013 .29297 .57621 .28068 .56532 Metetra
.747 .764 0 r
.28068 .56532 .29297 .57621 .31182 .57177 .2996 .56081 Metetra
.77 .768 0 r
.2996 .56081 .31182 .57177 .33082 .56727 .31868 .55623 Metetra
.775 .755 0 r
.31868 .55623 .33082 .56727 .34997 .56276 .33792 .55165 Metetra
.781 .741 0 r
.33792 .55165 .34997 .56276 .36928 .55823 .35731 .54705 Metetra
.787 .727 0 r
.35731 .54705 .36928 .55823 .38875 .5537 .37686 .54244 Metetra
.793 .712 0 r
.37686 .54244 .38875 .5537 .40838 .54917 .39657 .53783 Metetra
.799 .697 0 r
.39657 .53783 .40838 .54917 .42816 .54464 .41644 .53323 Metetra
.805 .68 0 r
.41644 .53323 .42816 .54464 .44812 .54012 .43648 .52863 Metetra
.811 .663 0 r
.43648 .52863 .44812 .54012 .46824 .53561 .45669 .52404 Metetra
.818 .645 0 r
.45669 .52404 .46824 .53561 .48853 .53112 .47708 .51947 Metetra
.825 .626 0 r
.47708 .51947 .48853 .53112 .50899 .52665 .49763 .51492 Metetra
.832 .606 0 r
.49763 .51492 .50899 .52665 .52963 .52222 .51837 .51041 Metetra
.839 .584 0 r
.51837 .51041 .52963 .52222 .55045 .51782 .53929 .50593 Metetra
.847 .561 0 r
.53929 .50593 .55045 .51782 .57146 .51348 .56039 .50151 Metetra
.855 .537 0 r
.56039 .50151 .57146 .51348 .59266 .5092 .58169 .49715 Metetra
.864 .511 0 r
.58169 .49715 .59266 .5092 .61405 .50498 .60318 .49285 Metetra
.872 .482 0 r
.60318 .49285 .61405 .50498 .63563 .50085 .62487 .48863 Metetra
.882 .452 0 r
.62487 .48863 .63563 .50085 .65743 .49681 .64677 .48451 Metetra
.892 .419 0 r
.64677 .48451 .65743 .49681 .67943 .49288 .66889 .4805 Metetra
.902 .383 0 r
.66889 .4805 .67943 .49288 .70165 .48909 .69122 .47663 Metetra
.913 .344 0 r
.69122 .47663 .70165 .48909 .7241 .48544 .71378 .4729 Metetra
.925 .301 0 r
.71378 .4729 .7241 .48544 .74678 .48198 .73657 .46935 Metetra
.937 .255 0 r
.73657 .46935 .74678 .48198 .7697 .47866 .75961 .46595 Metetra
.949 .209 0 r
.75961 .46595 .7697 .47866 .7928 .47477 .78284 .46198 Metetra
.95 .206 0 r
.78284 .46198 .7928 .47477 .81564 .46518 .80581 .45224 Metetra
.9 .39 0 r
.80581 .45224 .81564 .46518 .83648 .4331 .82683 .41986 Metetra
.625 .735 0 r
.82683 .41986 .83648 .4331 .85305 .36141 .84367 .34772 Metetra
.036 .553 0 r
.20064 .50155 .21309 .51241 .22695 .55437 .21438 .54356 Metetra
.454 .69 0 r
.21438 .54356 .22695 .55437 .24369 .56941 .2311 .55855 Metetra
.657 .743 0 r
.2311 .55855 .24369 .56941 .26194 .56931 .24941 .55838 Metetra
.719 .758 0 r
.24941 .55838 .26194 .56931 .28068 .56532 .26822 .55432 Metetra
.748 .764 0 r
.26822 .55432 .28068 .56532 .2996 .56081 .28722 .54973 Metetra
.77 .768 0 r
.28722 .54973 .2996 .56081 .31868 .55623 .30638 .54508 Metetra
.775 .755 0 r
.30638 .54508 .31868 .55623 .33792 .55165 .3257 .54042 Metetra
.781 .741 0 r
.3257 .54042 .33792 .55165 .35731 .54705 .34517 .53574 Metetra
.787 .727 0 r
.34517 .53574 .35731 .54705 .37686 .54244 .3648 .53106 Metetra
.793 .712 0 r
.3648 .53106 .37686 .54244 .39657 .53783 .3846 .52638 Metetra
.799 .696 0 r
.3846 .52638 .39657 .53783 .41644 .53323 .40456 .5217 Metetra
.805 .68 0 r
.40456 .5217 .41644 .53323 .43648 .52863 .42469 .51702 Metetra
.812 .662 0 r
.42469 .51702 .43648 .52863 .45669 .52404 .44499 .51235 Metetra
.818 .644 0 r
.44499 .51235 .45669 .52404 .47708 .51947 .46546 .50771 Metetra
.825 .625 0 r
.46546 .50771 .47708 .51947 .49763 .51492 .48611 .50308 Metetra
.832 .605 0 r
.48611 .50308 .49763 .51492 .51837 .51041 .50695 .49849 Metetra
.84 .583 0 r
.50695 .49849 .51837 .51041 .53929 .50593 .52796 .49393 Metetra
.847 .56 0 r
.52796 .49393 .53929 .50593 .56039 .50151 .54917 .48943 Metetra
.855 .536 0 r
.54917 .48943 .56039 .50151 .58169 .49715 .57057 .48499 Metetra
.864 .509 0 r
.57057 .48499 .58169 .49715 .60318 .49285 .59216 .48061 Metetra
.873 .481 0 r
.59216 .48061 .60318 .49285 .62487 .48863 .61396 .47631 Metetra
.882 .451 0 r
.61396 .47631 .62487 .48863 .64677 .48451 .63597 .47211 Metetra
.892 .418 0 r
.63597 .47211 .64677 .48451 .66889 .4805 .65819 .46802 Metetra
.902 .382 0 r
.65819 .46802 .66889 .4805 .69122 .47663 .68064 .46407 Metetra
.914 .342 0 r
.68064 .46407 .69122 .47663 .71378 .4729 .70331 .46026 Metetra
.925 .299 0 r
.70331 .46026 .71378 .4729 .73657 .46935 .72623 .45664 Metetra
.938 .252 0 r
.72623 .45664 .73657 .46935 .75961 .46595 .74939 .45316 Metetra
.95 .207 0 r
.74939 .45316 .75961 .46595 .78284 .46198 .77274 .4491 Metetra
.95 .204 0 r
.77274 .4491 .78284 .46198 .80581 .45224 .79585 .43919 Metetra
.9 .39 0 r
.79585 .43919 .80581 .45224 .82683 .41986 .81704 .40641 Metetra
.623 .734 0 r
.81704 .40641 .82683 .41986 .84367 .34772 .83414 .33369 Metetra
.037 .554 0 r
.18802 .49061 .20064 .50155 .21438 .54356 .20162 .53265 Metetra
.456 .691 0 r
.20162 .53265 .21438 .54356 .2311 .55855 .21834 .54758 Metetra
.658 .743 0 r
.21834 .54758 .2311 .55855 .24941 .55838 .23671 .54734 Metetra
.721 .758 0 r
.23671 .54734 .24941 .55838 .26822 .55432 .25559 .5432 Metetra
.749 .765 0 r
.25559 .5432 .26822 .55432 .28722 .54973 .27467 .53854 Metetra
.77 .767 0 r
.27467 .53854 .28722 .54973 .30638 .54508 .29391 .53382 Metetra
.776 .754 0 r
.29391 .53382 .30638 .54508 .3257 .54042 .3133 .52908 Metetra
.782 .74 0 r
.3133 .52908 .3257 .54042 .34517 .53574 .33286 .52433 Metetra
.787 .726 0 r
.33286 .52433 .34517 .53574 .3648 .53106 .35258 .51957 Metetra
.793 .711 0 r
.35258 .51957 .3648 .53106 .3846 .52638 .37246 .51481 Metetra
.799 .695 0 r
.37246 .51481 .3846 .52638 .40456 .5217 .39251 .51005 Metetra
.806 .678 0 r
.39251 .51005 .40456 .5217 .42469 .51702 .41273 .5053 Metetra
.812 .661 0 r
.41273 .5053 .42469 .51702 .44499 .51235 .43312 .50055 Metetra
.819 .643 0 r
.43312 .50055 .44499 .51235 .46546 .50771 .45368 .49582 Metetra
.826 .624 0 r
.45368 .49582 .46546 .50771 .48611 .50308 .47443 .49112 Metetra
.833 .603 0 r
.47443 .49112 .48611 .50308 .50695 .49849 .49536 .48645 Metetra
.84 .582 0 r
.49536 .48645 .50695 .49849 .52796 .49393 .51648 .48181 Metetra
.848 .559 0 r
.51648 .48181 .52796 .49393 .54917 .48943 .53778 .47723 Metetra
.856 .534 0 r
.53778 .47723 .54917 .48943 .57057 .48499 .55928 .47271 Metetra
.865 .507 0 r
.55928 .47271 .57057 .48499 .59216 .48061 .58099 .46826 Metetra
.873 .479 0 r
.58099 .46826 .59216 .48061 .61396 .47631 .60289 .46388 Metetra
.883 .448 0 r
.60289 .46388 .61396 .47631 .63597 .47211 .62501 .4596 Metetra
.893 .415 0 r
.62501 .4596 .63597 .47211 .65819 .46802 .64734 .45544 Metetra
.903 .379 0 r
.64734 .45544 .65819 .46802 .68064 .46407 .6699 .4514 Metetra
.914 .339 0 r
.6699 .4514 .68064 .46407 .70331 .46026 .6927 .44752 Metetra
.926 .296 0 r
.6927 .44752 .70331 .46026 .72623 .45664 .71573 .44383 Metetra
.939 .249 0 r
.71573 .44383 .72623 .45664 .74939 .45316 .73901 .44028 Metetra
.951 .203 0 r
.73901 .44028 .74939 .45316 .77274 .4491 .76249 .43613 Metetra
.951 .201 0 r
.76249 .43613 .77274 .4491 .79585 .43919 .78574 .42602 Metetra
.9 .389 0 r
.78574 .42602 .79585 .43919 .81704 .40641 .8071 .39273 Metetra
.62 .733 0 r
.8071 .39273 .81704 .40641 .83414 .33369 .82445 .31931 Metetra
.04 .555 0 r
.17523 .47959 .18802 .49061 .20162 .53265 .1887 .52165 Metetra
.458 .691 0 r
.1887 .52165 .20162 .53265 .21834 .54758 .2054 .53651 Metetra
.66 .743 0 r
.2054 .53651 .21834 .54758 .23671 .54734 .22383 .53618 Metetra
.723 .758 0 r
.22383 .53618 .23671 .54734 .25559 .5432 .24279 .53197 Metetra
.751 .765 0 r
.24279 .53197 .25559 .5432 .27467 .53854 .26194 .52723 Metetra
.771 .766 0 r
.26194 .52723 .27467 .53854 .29391 .53382 .28126 .52243 Metetra
.776 .753 0 r
.28126 .52243 .29391 .53382 .3133 .52908 .30074 .51762 Metetra
.782 .739 0 r
.30074 .51762 .3133 .52908 .33286 .52433 .32037 .51279 Metetra
.788 .724 0 r
.32037 .51279 .33286 .52433 .35258 .51957 .34018 .50796 Metetra
.794 .709 0 r
.34018 .50796 .35258 .51957 .37246 .51481 .36014 .50312 Metetra
.8 .693 0 r
.36014 .50312 .37246 .51481 .39251 .51005 .38028 .49829 Metetra
.806 .677 0 r
.38028 .49829 .39251 .51005 .41273 .5053 .40059 .49345 Metetra
.813 .659 0 r
.40059 .49345 .41273 .5053 .43312 .50055 .42107 .48863 Metetra
.819 .641 0 r
.42107 .48863 .43312 .50055 .45368 .49582 .44174 .48382 Metetra
.826 .622 0 r
.44174 .48382 .45368 .49582 .47443 .49112 .46258 .47904 Metetra
.834 .601 0 r
.46258 .47904 .47443 .49112 .49536 .48645 .48361 .47429 Metetra
.841 .58 0 r
.48361 .47429 .49536 .48645 .51648 .48181 .50482 .46958 Metetra
.849 .556 0 r
.50482 .46958 .51648 .48181 .53778 .47723 .52623 .46492 Metetra
.857 .531 0 r
.52623 .46492 .53778 .47723 .55928 .47271 .54784 .46032 Metetra
.865 .505 0 r
.54784 .46032 .55928 .47271 .58099 .46826 .56964 .45579 Metetra
.874 .476 0 r
.56964 .45579 .58099 .46826 .60289 .46388 .59166 .45134 Metetra
.884 .445 0 r
.59166 .45134 .60289 .46388 .62501 .4596 .61389 .44698 Metetra
.894 .412 0 r
.61389 .44698 .62501 .4596 .64734 .45544 .63634 .44274 Metetra
.904 .375 0 r
.63634 .44274 .64734 .45544 .6699 .4514 .65901 .43864 Metetra
.915 .335 0 r
.65901 .43864 .6699 .4514 .6927 .44752 .68192 .43469 Metetra
.927 .292 0 r
.68192 .43469 .6927 .44752 .71573 .44383 .70508 .43092 Metetra
.94 .244 0 r
.70508 .43092 .71573 .44383 .73901 .44028 .72849 .42731 Metetra
.952 .197 0 r
.72849 .42731 .73901 .44028 .76249 .43613 .7521 .42307 Metetra
.953 .196 0 r
.7521 .42307 .76249 .43613 .78574 .42602 .77548 .41272 Metetra
.901 .388 0 r
.77548 .41272 .78574 .42602 .8071 .39273 .79701 .37882 Metetra
.615 .732 0 r
.79701 .37882 .8071 .39273 .82445 .31931 .81461 .30456 Metetra
.043 .556 0 r
.16226 .4685 .17523 .47959 .1887 .52165 .17559 .51056 Metetra
.462 .692 0 r
.17559 .51056 .1887 .52165 .2054 .53651 .19229 .52533 Metetra
.663 .744 0 r
.19229 .52533 .2054 .53651 .22383 .53618 .21077 .52491 Metetra
.726 .759 0 r
.21077 .52491 .22383 .53618 .24279 .53197 .2298 .52062 Metetra
.754 .766 0 r
.2298 .52062 .24279 .53197 .26194 .52723 .24904 .5158 Metetra
.771 .764 0 r
.24904 .5158 .26194 .52723 .28126 .52243 .26843 .51093 Metetra
.777 .751 0 r
.26843 .51093 .28126 .52243 .30074 .51762 .28799 .50604 Metetra
.783 .737 0 r
.28799 .50604 .30074 .51762 .32037 .51279 .30771 .50114 Metetra
.789 .722 0 r
.30771 .50114 .32037 .51279 .34018 .50796 .3276 .49623 Metetra
.795 .707 0 r
.3276 .49623 .34018 .50796 .36014 .50312 .34766 .49131 Metetra
.801 .691 0 r
.34766 .49131 .36014 .50312 .38028 .49829 .36788 .4864 Metetra
.807 .675 0 r
.36788 .4864 .38028 .49829 .40059 .49345 .38828 .48149 Metetra
.814 .657 0 r
.38828 .48149 .40059 .49345 .42107 .48863 .40886 .47659 Metetra
.82 .639 0 r
.40886 .47659 .42107 .48863 .44174 .48382 .42961 .4717 Metetra
.827 .619 0 r
.42961 .4717 .44174 .48382 .46258 .47904 .45055 .46684 Metetra
.834 .599 0 r
.45055 .46684 .46258 .47904 .48361 .47429 .47168 .46202 Metetra
.842 .577 0 r
.47168 .46202 .48361 .47429 .50482 .46958 .493 .45723 Metetra
.85 .553 0 r
.493 .45723 .50482 .46958 .52623 .46492 .51451 .45249 Metetra
.858 .528 0 r
.51451 .45249 .52623 .46492 .54784 .46032 .53622 .44782 Metetra
.867 .501 0 r
.53622 .44782 .54784 .46032 .56964 .45579 .55814 .44321 Metetra
.876 .472 0 r
.55814 .44321 .56964 .45579 .59166 .45134 .58026 .43868 Metetra
.885 .441 0 r
.58026 .43868 .59166 .45134 .61389 .44698 .6026 .43425 Metetra
.895 .407 0 r
.6026 .43425 .61389 .44698 .63634 .44274 .62517 .42994 Metetra
.906 .37 0 r
.62517 .42994 .63634 .44274 .65901 .43864 .64796 .42577 Metetra
.917 .33 0 r
.64796 .42577 .65901 .43864 .68192 .43469 .67099 .42175 Metetra
.929 .286 0 r
.67099 .42175 .68192 .43469 .70508 .43092 .69427 .41793 Metetra
.942 .237 0 r
.69427 .41793 .70508 .43092 .72849 .42731 .7178 .41425 Metetra
.954 .191 0 r
.7178 .41425 .72849 .42731 .7521 .42307 .74154 .40992 Metetra
.954 .19 0 r
.74154 .40992 .7521 .42307 .77548 .41272 .76506 .3993 Metetra
.901 .386 0 r
.76506 .3993 .77548 .41272 .79701 .37882 .78677 .36468 Metetra
.609 .731 0 r
.78677 .36468 .79701 .37882 .81461 .30456 .80461 .28945 Metetra
.046 .558 0 r
.1491 .45733 .16226 .4685 .17559 .51056 .16229 .49937 Metetra
.465 .693 0 r
.16229 .49937 .17559 .51056 .19229 .52533 .17898 .51403 Metetra
.667 .745 0 r
.17898 .51403 .19229 .52533 .21077 .52491 .19753 .51352 Metetra
.729 .76 0 r
.19753 .51352 .21077 .52491 .2298 .52062 .21663 .50915 Metetra
.757 .766 0 r
.21663 .50915 .2298 .52062 .24904 .5158 .23595 .50426 Metetra
.772 .763 0 r
.23595 .50426 .24904 .5158 .26843 .51093 .25542 .49931 Metetra
.778 .749 0 r
.25542 .49931 .26843 .51093 .28799 .50604 .27507 .49434 Metetra
.784 .735 0 r
.27507 .49434 .28799 .50604 .30771 .50114 .29487 .48936 Metetra
.789 .72 0 r
.29487 .48936 .30771 .50114 .3276 .49623 .31484 .48437 Metetra
.795 .705 0 r
.31484 .48437 .3276 .49623 .34766 .49131 .33499 .47938 Metetra
.802 .689 0 r
.33499 .47938 .34766 .49131 .36788 .4864 .3553 .47439 Metetra
.808 .672 0 r
.3553 .47439 .36788 .4864 .38828 .48149 .37579 .4694 Metetra
.815 .655 0 r
.37579 .4694 .38828 .48149 .40886 .47659 .39646 .46442 Metetra
.821 .636 0 r
.39646 .46442 .40886 .47659 .42961 .4717 .41732 .45946 Metetra
.828 .616 0 r
.41732 .45946 .42961 .4717 .45055 .46684 .43835 .45453 Metetra
.836 .595 0 r
.43835 .45453 .45055 .46684 .47168 .46202 .45958 .44962 Metetra
.843 .573 0 r
.45958 .44962 .47168 .46202 .493 .45723 .481 .44475 Metetra
.851 .55 0 r
.481 .44475 .493 .45723 .51451 .45249 .50261 .43994 Metetra
.859 .524 0 r
.50261 .43994 .51451 .45249 .53622 .44782 .52443 .43519 Metetra
.868 .497 0 r
.52443 .43519 .53622 .44782 .55814 .44321 .54645 .43051 Metetra
.877 .468 0 r
.54645 .43051 .55814 .44321 .58026 .43868 .56869 .42591 Metetra
.887 .436 0 r
.56869 .42591 .58026 .43868 .6026 .43425 .59115 .42141 Metetra
.897 .402 0 r
.59115 .42141 .6026 .43425 .62517 .42994 .61383 .41703 Metetra
.907 .364 0 r
.61383 .41703 .62517 .42994 .64796 .42577 .63674 .41279 Metetra
.919 .323 0 r
.63674 .41279 .64796 .42577 .67099 .42175 .65989 .40872 Metetra
.931 .279 0 r
.65989 .40872 .67099 .42175 .69427 .41793 .6833 .40484 Metetra
.944 .229 0 r
.6833 .40484 .69427 .41793 .7178 .41425 .70696 .4011 Metetra
.956 .182 0 r
.70696 .4011 .7178 .41425 .74154 .40992 .73083 .39668 Metetra
.956 .183 0 r
.73083 .39668 .74154 .40992 .76506 .3993 .75449 .38574 Metetra
.902 .384 0 r
.75449 .38574 .76506 .3993 .78677 .36468 .77636 .35028 Metetra
.602 .729 0 r
.77636 .35028 .78677 .36468 .80461 .28945 .79445 .27395 Metetra
.05 .559 0 r
.13576 .44609 .1491 .45733 .16229 .49937 .14881 .4881 Metetra
.47 .695 0 r
.14881 .4881 .16229 .49937 .17898 .51403 .16549 .50263 Metetra
.671 .746 0 r
.16549 .50263 .17898 .51403 .19753 .51352 .1841 .50201 Metetra
.733 .761 0 r
.1841 .50201 .19753 .51352 .21663 .50915 .20328 .49756 Metetra
.761 .767 0 r
.20328 .49756 .21663 .50915 .23595 .50426 .22267 .49259 Metetra
.773 .76 0 r
.22267 .49259 .23595 .50426 .25542 .49931 .24223 .48756 Metetra
.779 .747 0 r
.24223 .48756 .25542 .49931 .27507 .49434 .26195 .48252 Metetra
.785 .732 0 r
.26195 .48252 .27507 .49434 .29487 .48936 .28184 .47746 Metetra
.79 .718 0 r
.28184 .47746 .29487 .48936 .31484 .48437 .3019 .4724 Metetra
.797 .702 0 r
.3019 .4724 .31484 .48437 .33499 .47938 .32213 .46732 Metetra
.803 .686 0 r
.32213 .46732 .33499 .47938 .3553 .47439 .34254 .46226 Metetra
.809 .669 0 r
.34254 .46226 .3553 .47439 .37579 .4694 .36312 .45719 Metetra
.816 .651 0 r
.36312 .45719 .37579 .4694 .39646 .46442 .38389 .45214 Metetra
.823 .632 0 r
.38389 .45214 .39646 .46442 .41732 .45946 .40483 .4471 Metetra
.83 .613 0 r
.40483 .4471 .41732 .45946 .43835 .45453 .42597 .44208 Metetra
.837 .591 0 r
.42597 .44208 .43835 .45453 .45958 .44962 .44729 .4371 Metetra
.845 .569 0 r
.44729 .4371 .45958 .44962 .481 .44475 .46882 .43216 Metetra
.852 .545 0 r
.46882 .43216 .481 .44475 .50261 .43994 .49054 .42728 Metetra
.861 .519 0 r
.49054 .42728 .50261 .43994 .52443 .43519 .51246 .42245 Metetra
.869 .492 0 r
.51246 .42245 .52443 .43519 .54645 .43051 .5346 .4177 Metetra
.879 .462 0 r
.5346 .4177 .54645 .43051 .56869 .42591 .55695 .41303 Metetra
.888 .43 0 r
.55695 .41303 .56869 .42591 .59115 .42141 .57952 .40846 Metetra
.899 .395 0 r
.57952 .40846 .59115 .42141 .61383 .41703 .60232 .40402 Metetra
.909 .357 0 r
.60232 .40402 .61383 .41703 .63674 .41279 .62535 .39972 Metetra
.921 .316 0 r
.62535 .39972 .63674 .41279 .65989 .40872 .64863 .39559 Metetra
.933 .27 0 r
.64863 .39559 .65989 .40872 .6833 .40484 .67216 .39165 Metetra
.946 .22 0 r
.67216 .39165 .6833 .40484 .70696 .4011 .69595 .38787 Metetra
.959 .172 0 r
.69595 .38787 .70696 .4011 .73083 .39668 .71996 .38335 Metetra
.958 .174 0 r
.71996 .38335 .73083 .39668 .75449 .38574 .74376 .37206 Metetra
.902 .382 0 r
.74376 .37206 .75449 .38574 .77636 .35028 .76579 .33562 Metetra
.593 .727 0 r
.76579 .33562 .77636 .35028 .79445 .27395 .78413 .25805 Metetra
.055 .561 0 r
.12223 .43476 .13576 .44609 .14881 .4881 .13513 .47672 Metetra
.475 .696 0 r
.13513 .47672 .14881 .4881 .16549 .50263 .15181 .49111 Metetra
.675 .747 0 r
.15181 .49111 .16549 .50263 .1841 .50201 .17047 .49039 Metetra
.737 .762 0 r
.17047 .49039 .1841 .50201 .20328 .49756 .18973 .48585 Metetra
.766 .768 0 r
.18973 .48585 .20328 .49756 .22267 .49259 .2092 .4808 Metetra
.774 .758 0 r
.2092 .4808 .22267 .49259 .24223 .48756 .22884 .4757 Metetra
.78 .744 0 r
.22884 .4757 .24223 .48756 .26195 .48252 .24865 .47058 Metetra
.786 .73 0 r
.24865 .47058 .26195 .48252 .28184 .47746 .26862 .46544 Metetra
.792 .715 0 r
.26862 .46544 .28184 .47746 .3019 .4724 .28877 .4603 Metetra
.798 .699 0 r
.28877 .4603 .3019 .4724 .32213 .46732 .30909 .45515 Metetra
.804 .683 0 r
.30909 .45515 .32213 .46732 .34254 .46226 .32958 .45 Metetra
.811 .666 0 r
.32958 .45 .34254 .46226 .36312 .45719 .35026 .44486 Metetra
.817 .647 0 r
.35026 .44486 .36312 .45719 .38389 .45214 .37112 .43973 Metetra
.824 .628 0 r
.37112 .43973 .38389 .45214 .40483 .4471 .39216 .43461 Metetra
.831 .608 0 r
.39216 .43461 .40483 .4471 .42597 .44208 .4134 .42952 Metetra
.838 .587 0 r
.4134 .42952 .42597 .44208 .44729 .4371 .43483 .42447 Metetra
.846 .564 0 r
.43483 .42447 .44729 .4371 .46882 .43216 .45645 .41945 Metetra
.854 .54 0 r
.45645 .41945 .46882 .43216 .49054 .42728 .47828 .41449 Metetra
.863 .514 0 r
.47828 .41449 .49054 .42728 .51246 .42245 .50031 .40959 Metetra
.871 .486 0 r
.50031 .40959 .51246 .42245 .5346 .4177 .52256 .40477 Metetra
.881 .455 0 r
.52256 .40477 .5346 .4177 .55695 .41303 .54502 .40003 Metetra
.89 .423 0 r
.54502 .40003 .55695 .41303 .57952 .40846 .56771 .3954 Metetra
.901 .387 0 r
.56771 .3954 .57952 .40846 .60232 .40402 .59063 .3909 Metetra
.912 .349 0 r
.59063 .3909 .60232 .40402 .62535 .39972 .61378 .38655 Metetra
.923 .306 0 r
.61378 .38655 .62535 .39972 .64863 .39559 .63719 .38236 Metetra
.936 .26 0 r
.63719 .38236 .64863 .39559 .67216 .39165 .66085 .37838 Metetra
.949 .209 0 r
.66085 .37838 .67216 .39165 .69595 .38787 .68477 .37455 Metetra
.962 .16 0 r
.68477 .37455 .69595 .38787 .71996 .38335 .70892 .36994 Metetra
.961 .163 0 r
.70892 .36994 .71996 .38335 .74376 .37206 .73286 .35824 Metetra
.903 .379 0 r
.73286 .35824 .74376 .37206 .76579 .33562 .75506 .32069 Metetra
.583 .724 0 r
.75506 .32069 .76579 .33562 .78413 .25805 .77364 .24174 Metetra
.061 .563 0 r
.1085 .42335 .12223 .43476 .13513 .47672 .12125 .46525 Metetra
.482 .698 0 r
.12125 .46525 .13513 .47672 .15181 .49111 .13792 .47948 Metetra
.681 .748 0 r
.13792 .47948 .15181 .49111 .17047 .49039 .15665 .47864 Metetra
.743 .763 0 r
.15665 .47864 .17047 .49039 .18973 .48585 .17598 .47402 Metetra
.77 .768 0 r
.17598 .47402 .18973 .48585 .2092 .4808 .19553 .46889 Metetra
.775 .755 0 r
.19553 .46889 .2092 .4808 .22884 .4757 .21525 .46371 Metetra
.781 .741 0 r
.21525 .46371 .22884 .4757 .24865 .47058 .23514 .45851 Metetra
.787 .726 0 r
.23514 .45851 .24865 .47058 .26862 .46544 .2552 .4533 Metetra
.793 .711 0 r
.2552 .4533 .26862 .46544 .28877 .4603 .27544 .44808 Metetra
.799 .695 0 r
.27544 .44808 .28877 .4603 .30909 .45515 .29585 .44285 Metetra
.806 .679 0 r
.29585 .44285 .30909 .45515 .32958 .45 .31643 .43763 Metetra
.812 .661 0 r
.31643 .43763 .32958 .45 .35026 .44486 .3372 .43241 Metetra
.819 .643 0 r
.3372 .43241 .35026 .44486 .37112 .43973 .35816 .4272 Metetra
.826 .624 0 r
.35816 .4272 .37112 .43973 .39216 .43461 .3793 .422 Metetra
.833 .603 0 r
.3793 .422 .39216 .43461 .4134 .42952 .40064 .41684 Metetra
.84 .581 0 r
.40064 .41684 .4134 .42952 .43483 .42447 .42217 .41171 Metetra
.848 .558 0 r
.42217 .41171 .43483 .42447 .45645 .41945 .4439 .40662 Metetra
.856 .534 0 r
.4439 .40662 .45645 .41945 .47828 .41449 .46583 .40159 Metetra
.865 .507 0 r
.46583 .40159 .47828 .41449 .50031 .40959 .48797 .39662 Metetra
.874 .479 0 r
.48797 .39662 .50031 .40959 .52256 .40477 .51033 .39173 Metetra
.883 .448 0 r
.51033 .39173 .52256 .40477 .54502 .40003 .53291 .38693 Metetra
.893 .414 0 r
.53291 .38693 .54502 .40003 .56771 .3954 .55571 .38224 Metetra
.903 .378 0 r
.55571 .38224 .56771 .3954 .59063 .3909 .57875 .37768 Metetra
.915 .339 0 r
.57875 .37768 .59063 .3909 .61378 .38655 .60203 .37328 Metetra
.926 .295 0 r
.60203 .37328 .61378 .38655 .63719 .38236 .62557 .36905 Metetra
.939 .248 0 r
.62557 .36905 .63719 .38236 .66085 .37838 .64936 .36503 Metetra
.953 .196 0 r
.64936 .36503 .66085 .37838 .68477 .37455 .67342 .36116 Metetra
.965 .146 0 r
.67342 .36116 .68477 .37455 .70892 .36994 .69771 .35645 Metetra
.964 .151 0 r
.69771 .35645 .70892 .36994 .73286 .35824 .72179 .34429 Metetra
.904 .377 0 r
.72179 .34429 .73286 .35824 .75506 .32069 .74415 .30548 Metetra
.571 .721 0 r
.74415 .30548 .75506 .32069 .77364 .24174 .76298 .22499 Metetra
.067 .566 0 r
.09456 .41186 .1085 .42335 .12125 .46525 .10716 .45369 Metetra
.489 .7 0 r
.10716 .45369 .12125 .46525 .13792 .47948 .12383 .46775 Metetra
.687 .75 0 r
.12383 .46775 .13792 .47948 .15665 .47864 .14262 .46678 Metetra
.749 .764 0 r
.14262 .46678 .15665 .47864 .17598 .47402 .16203 .46207 Metetra
.771 .765 0 r
.16203 .46207 .17598 .47402 .19553 .46889 .18166 .45687 Metetra
.777 .751 0 r
.18166 .45687 .19553 .46889 .21525 .46371 .20146 .45161 Metetra
.783 .737 0 r
.20146 .45161 .21525 .46371 .23514 .45851 .22144 .44633 Metetra
.789 .722 0 r
.22144 .44633 .23514 .45851 .2552 .4533 .24158 .44103 Metetra
.795 .707 0 r
.24158 .44103 .2552 .4533 .27544 .44808 .26191 .43573 Metetra
.801 .691 0 r
.26191 .43573 .27544 .44808 .29585 .44285 .28241 .43042 Metetra
.807 .674 0 r
.28241 .43042 .29585 .44285 .31643 .43763 .30309 .42512 Metetra
.814 .656 0 r
.30309 .42512 .31643 .43763 .3372 .43241 .32395 .41983 Metetra
.821 .638 0 r
.32395 .41983 .3372 .43241 .35816 .4272 .345 .41454 Metetra
.828 .618 0 r
.345 .41454 .35816 .4272 .3793 .422 .36624 .40927 Metetra
.835 .597 0 r
.36624 .40927 .3793 .422 .40064 .41684 .38768 .40403 Metetra
.842 .575 0 r
.38768 .40403 .40064 .41684 .42217 .41171 .40931 .39883 Metetra
.85 .552 0 r
.40931 .39883 .42217 .41171 .4439 .40662 .43114 .39367 Metetra
.858 .527 0 r
.43114 .39367 .4439 .40662 .46583 .40159 .45319 .38857 Metetra
.867 .499 0 r
.45319 .38857 .46583 .40159 .48797 .39662 .47544 .38353 Metetra
.876 .47 0 r
.47544 .38353 .48797 .39662 .51033 .39173 .49791 .37857 Metetra
.886 .439 0 r
.49791 .37857 .51033 .39173 .53291 .38693 .52061 .37371 Metetra
.896 .405 0 r
.52061 .37371 .53291 .38693 .55571 .38224 .54353 .36896 Metetra
.906 .368 0 r
.54353 .36896 .55571 .38224 .57875 .37768 .56669 .36435 Metetra
.918 .327 0 r
.56669 .36435 .57875 .37768 .60203 .37328 .5901 .35989 Metetra
.93 .283 0 r
.5901 .35989 .60203 .37328 .62557 .36905 .61376 .35561 Metetra
.943 .234 0 r
.61376 .35561 .62557 .36905 .64936 .36503 .63769 .35156 Metetra
.956 .181 0 r
.63769 .35156 .64936 .36503 .67342 .36116 .66188 .34765 Metetra
.969 .13 0 r
.66188 .34765 .67342 .36116 .69771 .35645 .68631 .34283 Metetra
.967 .138 0 r
.68631 .34283 .69771 .35645 .72179 .34429 .71054 .33014 Metetra
.905 .374 0 r
.71054 .33014 .72179 .34429 .74415 .30548 .73306 .28988 Metetra
.557 .718 0 r
.73306 .28988 .74415 .30548 .76298 .22499 .75215 .20773 Metetra
.074 .568 0 r
.08042 .40026 .09456 .41186 .10716 .45369 .09287 .44199 Metetra
.496 .702 0 r
.09287 .44199 .10716 .45369 .12383 .46775 .10954 .45585 Metetra
.694 .752 0 r
.10954 .45585 .12383 .46775 .14262 .46678 .12839 .45476 Metetra
.755 .766 0 r
.12839 .45476 .14262 .46678 .16203 .46207 .14787 .44996 Metetra
.773 .761 0 r
.14787 .44996 .16203 .46207 .18166 .45687 .16759 .44466 Metetra
.778 .747 0 r
.16759 .44466 .18166 .45687 .20146 .45161 .18747 .43932 Metetra
.784 .733 0 r
.18747 .43932 .20146 .45161 .22144 .44633 .20753 .43395 Metetra
.79 .718 0 r
.20753 .43395 .22144 .44633 .24158 .44103 .22776 .42858 Metetra
.796 .703 0 r
.22776 .42858 .24158 .44103 .26191 .43573 .24817 .42319 Metetra
.803 .686 0 r
.24817 .42319 .26191 .43573 .28241 .43042 .26876 .4178 Metetra
.809 .669 0 r
.26876 .4178 .28241 .43042 .30309 .42512 .28954 .41241 Metetra
.816 .651 0 r
.28954 .41241 .30309 .42512 .32395 .41983 .3105 .40703 Metetra
.823 .633 0 r
.3105 .40703 .32395 .41983 .345 .41454 .33164 .40165 Metetra
.83 .613 0 r
.33164 .40165 .345 .41454 .36624 .40927 .35298 .3963 Metetra
.837 .592 0 r
.35298 .3963 .36624 .40927 .38768 .40403 .37452 .39097 Metetra
.844 .569 0 r
.37452 .39097 .38768 .40403 .40931 .39883 .39626 .38568 Metetra
.852 .545 0 r
.39626 .38568 .40931 .39883 .43114 .39367 .4182 .38043 Metetra
.861 .52 0 r
.4182 .38043 .43114 .39367 .45319 .38857 .44035 .37523 Metetra
.869 .492 0 r
.44035 .37523 .45319 .38857 .47544 .38353 .46271 .3701 Metetra
.878 .463 0 r
.46271 .3701 .47544 .38353 .49791 .37857 .4853 .36505 Metetra
.888 .431 0 r
.4853 .36505 .49791 .37857 .52061 .37371 .50811 .36009 Metetra
.898 .396 0 r
.50811 .36009 .52061 .37371 .54353 .36896 .53115 .35525 Metetra
.909 .358 0 r
.53115 .35525 .54353 .36896 .56669 .36435 .55443 .35053 Metetra
.92 .317 0 r
.55443 .35053 .56669 .36435 .5901 .35989 .57796 .34597 Metetra
.933 .272 0 r
.57796 .34597 .5901 .35989 .61376 .35561 .60175 .34158 Metetra
.946 .223 0 r
.60175 .34158 .61376 .35561 .63769 .35156 .6258 .3374 Metetra
.959 .168 0 r
.6258 .3374 .63769 .35156 .66188 .34765 .65013 .33336 Metetra
.972 .118 0 r
.65013 .33336 .66188 .34765 .68631 .34283 .67469 .32829 Metetra
.969 .13 0 r
.67469 .32829 .68631 .34283 .71054 .33014 .69905 .31489 Metetra
.904 .378 0 r
.69905 .31489 .71054 .33014 .73306 .28988 .72174 .27306 Metetra
.535 .712 0 r
.72174 .27306 .73306 .28988 .75215 .20773 .7411 .18939 Metetra
.079 .571 0 r
.06612 .38821 .08042 .40026 .09287 .44199 .07843 .42967 Metetra
.501 .703 0 r
.07843 .42967 .09287 .44199 .10954 .45585 .0951 .44323 Metetra
.697 .752 0 r
.0951 .44323 .10954 .45585 .12839 .45476 .11402 .44196 Metetra
.757 .766 0 r
.11402 .44196 .12839 .45476 .14787 .44996 .13359 .43702 Metetra
.773 .76 0 r
.13359 .43702 .14787 .44996 .16759 .44466 .15338 .4316 Metetra
.779 .747 0 r
.15338 .4316 .16759 .44466 .18747 .43932 .17335 .42612 Metetra
.785 .732 0 r
.17335 .42612 .18747 .43932 .20753 .43395 .1935 .42062 Metetra
.79 .718 0 r
.1935 .42062 .20753 .43395 .22776 .42858 .21382 .41511 Metetra
.797 .702 0 r
.21382 .41511 .22776 .42858 .24817 .42319 .23432 .40957 Metetra
.803 .686 0 r
.23432 .40957 .24817 .42319 .26876 .4178 .255 .40402 Metetra
.809 .67 0 r
.255 .40402 .26876 .4178 .28954 .41241 .27586 .39847 Metetra
.816 .652 0 r
.27586 .39847 .28954 .41241 .3105 .40703 .29692 .39291 Metetra
.822 .633 0 r
.29692 .39291 .3105 .40703 .33164 .40165 .31816 .38735 Metetra
.829 .614 0 r
.31816 .38735 .33164 .40165 .35298 .3963 .3396 .3818 Metetra
.836 .593 0 r
.3396 .3818 .35298 .3963 .37452 .39097 .36123 .37626 Metetra
.844 .571 0 r
.36123 .37626 .37452 .39097 .39626 .38568 .38307 .37074 Metetra
.851 .548 0 r
.38307 .37074 .39626 .38568 .4182 .38043 .40511 .36524 Metetra
.86 .523 0 r
.40511 .36524 .4182 .38043 .44035 .37523 .42737 .35978 Metetra
.868 .497 0 r
.42737 .35978 .44035 .37523 .46271 .3701 .44984 .35435 Metetra
.877 .468 0 r
.44984 .35435 .46271 .3701 .4853 .36505 .47252 .34897 Metetra
.886 .438 0 r
.47252 .34897 .4853 .36505 .50811 .36009 .49543 .34365 Metetra
.896 .405 0 r
.49543 .34365 .50811 .36009 .53115 .35525 .51858 .3384 Metetra
.906 .37 0 r
.51858 .3384 .53115 .35525 .55443 .35053 .54196 .33322 Metetra
.917 .331 0 r
.54196 .33322 .55443 .35053 .57796 .34597 .56558 .32814 Metetra
.928 .289 0 r
.56558 .32814 .57796 .34597 .60175 .34158 .58946 .32316 Metetra
.94 .244 0 r
.58946 .32316 .60175 .34158 .6258 .3374 .61359 .3183 Metetra
.953 .194 0 r
.61359 .3183 .6258 .3374 .65013 .33336 .63799 .31346 Metetra
.964 .15 0 r
.63799 .31346 .65013 .33336 .67469 .32829 .66261 .30741 Metetra
.959 .171 0 r
.66261 .30741 .67469 .32829 .69905 .31489 .68703 .29275 Metetra
.89 .425 0 r
.68703 .29275 .69905 .31489 .72174 .27306 .70987 .24974 Metetra
.472 .695 0 r
.70987 .24974 .72174 .27306 .7411 .18939 .7296 .16643 Metetra
.066 .566 0 r
.05201 .37325 .06612 .38821 .07843 .42967 .06434 .4133 Metetra
.472 .695 0 r
.06434 .4133 .07843 .42967 .0951 .44323 .08108 .42599 Metetra
.659 .743 0 r
.08108 .42599 .0951 .44323 .11402 .44196 .10007 .42425 Metetra
.715 .757 0 r
.10007 .42425 .11402 .44196 .13359 .43702 .11972 .41896 Metetra
.741 .763 0 r
.11972 .41896 .13359 .43702 .15338 .4316 .13959 .41318 Metetra
.764 .768 0 r
.13959 .41318 .15338 .4316 .17335 .42612 .15964 .40733 Metetra
.773 .76 0 r
.15964 .40733 .17335 .42612 .1935 .42062 .17987 .40143 Metetra
.778 .747 0 r
.17987 .40143 .1935 .42062 .21382 .41511 .20027 .39547 Metetra
.784 .734 0 r
.20027 .39547 .21382 .41511 .23432 .40957 .22085 .38947 Metetra
.789 .721 0 r
.22085 .38947 .23432 .40957 .255 .40402 .24162 .38343 Metetra
.795 .707 0 r
.24162 .38343 .255 .40402 .27586 .39847 .26256 .37733 Metetra
.8 .693 0 r
.26256 .37733 .27586 .39847 .29692 .39291 .2837 .37119 Metetra
.806 .678 0 r
.2837 .37119 .29692 .39291 .31816 .38735 .30502 .36501 Metetra
.812 .662 0 r
.30502 .36501 .31816 .38735 .3396 .3818 .32654 .35877 Metetra
.818 .646 0 r
.32654 .35877 .3396 .3818 .36123 .37626 .34825 .35248 Metetra
.824 .629 0 r
.34825 .35248 .36123 .37626 .38307 .37074 .37015 .34614 Metetra
.83 .611 0 r
.37015 .34614 .38307 .37074 .40511 .36524 .39226 .33975 Metetra
.836 .593 0 r
.39226 .33975 .40511 .36524 .42737 .35978 .41457 .3333 Metetra
.843 .574 0 r
.41457 .3333 .42737 .35978 .44984 .35435 .43709 .3268 Metetra
.85 .554 0 r
.43709 .3268 .44984 .35435 .47252 .34897 .45982 .32023 Metetra
.856 .533 0 r
.45982 .32023 .47252 .34897 .49543 .34365 .48276 .31359 Metetra
.864 .511 0 r
.48276 .31359 .49543 .34365 .51858 .3384 .50591 .30688 Metetra
.871 .488 0 r
.50591 .30688 .51858 .3384 .54196 .33322 .52929 .30009 Metetra
.878 .463 0 r
.52929 .30009 .54196 .33322 .56558 .32814 .55288 .2932 Metetra
.886 .438 0 r
.55288 .2932 .56558 .32814 .58946 .32316 .57669 .28621 Metetra
.894 .412 0 r
.57669 .28621 .58946 .32316 .61359 .3183 .60074 .2791 Metetra
.902 .384 0 r
.60074 .2791 .61359 .3183 .63799 .31346 .625 .27174 Metetra
.907 .365 0 r
.625 .27174 .63799 .31346 .66261 .30741 .64944 .26299 Metetra
.896 .402 0 r
.64944 .26299 .66261 .30741 .68703 .29275 .6737 .24628 Metetra
.825 .627 0 r
.6737 .24628 .68703 .29275 .70987 .24974 .69665 .20473 Metetra
.271 .637 0 r
.69665 .20473 .70987 .24974 .7296 .16643 .71704 .12905 Metetra
0 .53 .02 r
.03937 .3474 .05201 .37325 .06434 .4133 .05227 .38186 Metetra
.313 .65 0 r
.05227 .38186 .06434 .4133 .08108 .42599 .06927 .39171 Metetra
.465 .693 0 r
.06927 .39171 .08108 .42599 .10007 .42425 .08836 .3887 Metetra
.507 .704 0 r
.08836 .3887 .10007 .42425 .11972 .41896 .10805 .38251 Metetra
.523 .709 0 r
.10805 .38251 .11972 .41896 .13959 .41318 .12797 .37585 Metetra
.536 .712 0 r
.12797 .37585 .13959 .41318 .15964 .40733 .14806 .36905 Metetra
.548 .715 0 r
.14806 .36905 .15964 .40733 .17987 .40143 .16831 .36215 Metetra
.56 .718 0 r
.16831 .36215 .17987 .40143 .20027 .39547 .18875 .35514 Metetra
.572 .721 0 r
.18875 .35514 .20027 .39547 .22085 .38947 .20935 .34801 Metetra
.583 .724 0 r
.20935 .34801 .22085 .38947 .24162 .38343 .23013 .34076 Metetra
.594 .727 0 r
.23013 .34076 .24162 .38343 .26256 .37733 .25109 .33339 Metetra
.605 .73 0 r
.25109 .33339 .26256 .37733 .2837 .37119 .27222 .32589 Metetra
.615 .732 0 r
.27222 .32589 .2837 .37119 .30502 .36501 .29354 .31825 Metetra
.625 .735 0 r
.29354 .31825 .30502 .36501 .32654 .35877 .31503 .31046 Metetra
.634 .737 0 r
.31503 .31046 .32654 .35877 .34825 .35248 .3367 .30252 Metetra
.643 .739 0 r
.3367 .30252 .34825 .35248 .37015 .34614 .35856 .29442 Metetra
.651 .741 0 r
.35856 .29442 .37015 .34614 .39226 .33975 .3806 .28615 Metetra
.658 .743 0 r
.3806 .28615 .39226 .33975 .41457 .3333 .40282 .27769 Metetra
.664 .744 0 r
.40282 .27769 .41457 .3333 .43709 .3268 .42522 .26904 Metetra
.669 .746 0 r
.42522 .26904 .43709 .3268 .45982 .32023 .44781 .26017 Metetra
.674 .747 0 r
.44781 .26017 .45982 .32023 .48276 .31359 .47058 .25108 Metetra
.676 .747 0 r
.47058 .25108 .48276 .31359 .50591 .30688 .49353 .24175 Metetra
.678 .748 0 r
.49353 .24175 .50591 .30688 .52929 .30009 .51665 .23216 Metetra
.677 .748 0 r
.51665 .23216 .52929 .30009 .55288 .2932 .53996 .22228 Metetra
.675 .747 0 r
.53996 .22228 .55288 .2932 .57669 .28621 .56343 .2121 Metetra
.671 .746 0 r
.56343 .2121 .57669 .28621 .60074 .2791 .58708 .20159 Metetra
.663 .744 0 r
.58708 .20159 .60074 .2791 .625 .27174 .61089 .19064 Metetra
.645 .74 0 r
.61089 .19064 .625 .27174 .64944 .26299 .63482 .17848 Metetra
.57 .721 0 r
.63482 .17848 .64944 .26299 .6737 .24628 .65866 .16075 Metetra
.325 .653 0 r
.65866 .16075 .6737 .24628 .69665 .20473 .6817 .12654 Metetra
0 .495 .094 r
.6817 .12654 .69665 .20473 .71704 .12905 .70316 .07029 Metetra
0 .425 .21 r
.02968 .30231 .03937 .3474 .05227 .38186 .04415 .3243 Metetra
0 .521 .039 r
.04415 .3243 .05227 .38186 .06927 .39171 .06171 .32842 Metetra
.038 .554 0 r
.06171 .32842 .06927 .39171 .08836 .3887 .08085 .32331 Metetra
.055 .561 0 r
.08085 .32331 .08836 .3887 .10805 .38251 .10047 .31589 Metetra
.057 .562 0 r
.10047 .31589 .10805 .38251 .12797 .37585 .12029 .30806 Metetra
.058 .562 0 r
.12029 .30806 .12797 .37585 .14806 .36905 .14027 .30007 Metetra
.057 .562 0 r
.14027 .30007 .14806 .36905 .16831 .36215 .16041 .29193 Metetra
.055 .561 0 r
.16041 .29193 .16831 .36215 .18875 .35514 .18071 .28363 Metetra
.053 .56 0 r
.18071 .28363 .18875 .35514 .20935 .34801 .20117 .27518 Metetra
.051 .559 0 r
.20117 .27518 .20935 .34801 .23013 .34076 .22179 .26656 Metetra
.047 .558 0 r
.22179 .26656 .23013 .34076 .25109 .33339 .24258 .25778 Metetra
.043 .556 0 r
.24258 .25778 .25109 .33339 .27222 .32589 .26352 .24883 Metetra
.037 .554 0 r
.26352 .24883 .27222 .32589 .29354 .31825 .28463 .23969 Metetra
.031 .552 0 r
.28463 .23969 .29354 .31825 .31503 .31046 .3059 .23037 Metetra
.024 .549 0 r
.3059 .23037 .31503 .31046 .3367 .30252 .32733 .22086 Metetra
.016 .545 0 r
.32733 .22086 .3367 .30252 .35856 .29442 .34892 .21115 Metetra
.007 .542 0 r
.34892 .21115 .35856 .29442 .3806 .28615 .37067 .20124 Metetra
0 .537 .002 r
.37067 .20124 .3806 .28615 .40282 .27769 .39258 .19111 Metetra
0 .533 .013 r
.39258 .19111 .40282 .27769 .42522 .26904 .41464 .18077 Metetra
0 .527 .025 r
.41464 .18077 .42522 .26904 .44781 .26017 .43687 .1702 Metetra
0 .522 .038 r
.43687 .1702 .44781 .26017 .47058 .25108 .45924 .1594 Metetra
0 .515 .052 r
.45924 .1594 .47058 .25108 .49353 .24175 .48177 .14836 Metetra
0 .508 .067 r
.48177 .14836 .49353 .24175 .51665 .23216 .50445 .13707 Metetra
0 .5 .083 r
.50445 .13707 .51665 .23216 .53996 .22228 .52727 .12553 Metetra
0 .492 .1 r
.52727 .12553 .53996 .22228 .56343 .2121 .55024 .11373 Metetra
0 .482 .117 r
.55024 .11373 .56343 .2121 .58708 .20159 .57335 .10166 Metetra
0 .472 .136 r
.57335 .10166 .58708 .20159 .61089 .19064 .5966 .08929 Metetra
0 .46 .157 r
.5966 .08929 .61089 .19064 .63482 .17848 .61997 .07627 Metetra
0 .438 .19 r
.61997 .07627 .63482 .17848 .65866 .16075 .64337 .06071 Metetra
0 .387 .254 r
.64337 .06071 .65866 .16075 .6817 .12654 .6665 .03784 Metetra
0 .252 .283 r
.6665 .03784 .6817 .12654 .70316 .07029 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15423 .2093 m
.15884 .21396 L
s
[(-5)] .145 .19996 .988 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54634 .05576 m
.55023 .06104 L
s
[(5)] .53856 .04519 .73647 1 Mshowa
.125 Mabswid
.19091 .19493 m
.19364 .19777 L
s
.22813 .18036 m
.23082 .18323 L
s
.26589 .16558 m
.26854 .16848 L
s
.30419 .15058 m
.30681 .15352 L
s
.38251 .11991 m
.38504 .12293 L
s
.42255 .10423 m
.42503 .10729 L
s
.46319 .08832 m
.46563 .09141 L
s
.50445 .07216 m
.50683 .07529 L
s
.11806 .22346 m
.12086 .22623 L
s
.0824 .23742 m
.08523 .24016 L
s
.04723 .25119 m
.0501 .25389 L
s
.58887 .0391 m
.59115 .04231 L
s
.63207 .02219 m
.63429 .02544 L
s
.67594 .00501 m
.67811 .0083 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00boooool2o`0005?ooooo0038ooooo`?o000000?oooooo`000?ooool0
D_ooool00<Kooooo1?l00002ooooo`;o0000D_ooool00<?ooooo0ol00006ooooo`03o`000?oooooo
0000057ooooo002Pooooo`?o00007_ooool2o`0000Sooooo1?l0001Aooooo`00Woooool01Ol0003o
oooooooooooooooo000001[ooooo0ol00009ooooo`06o`000?l0@4So0000o`000?oooooo0000D?oo
ool00:?ooooo00?o0000ooooooooool05Oooool3o`0000_ooooo00?o0000o`10B?l0@4P00_l00002
ooooo`03o`000?oooooooooo04gooooo002Sooooo`03o`000?oooooooooo01?ooooo0_l00002oooo
o`03o`000?oooooooooo00Wooooo00?o0000o`10B?l0@4P00_l00002ooooo`03o`000?oooooooooo
04gooooo002Oooooo`Co00004oooool3o`0000oooooo00Co0000o`10B?l0@4So04180_l00003oooo
o`03o`000?oooooooooo04cooooo002Oooooo`03o`000?oooooooooo01;ooooo0_l0000Aooooo`03
o`000?l0@4So041800?o04180_l00003ooooo`03o`000?oooooooooo04_ooooo002Oooooo`Go0000
3Oooool3o`0001;ooooo00?o0000o`10B?l0@4P01?l0@4P2o`0000?ooooo00?o0000ooooooooool0
Boooool00:oooooo1?l0000Booooo`;o00001_l0@4P2o`0000Cooooo00?o0000ooooooooool0B_oo
ool00:cooooo0ol0000Eooooo`03o`000?l0Hd7o000000Ko04180_l00003ooooo`;o0000C?ooool0
0:[ooooo0_l0000Gooooo`04o`000?l0Hd7o06=1o`0000Ko04180_l00005ooooo`03o`000?oooooo
oooo04Wooooo002Wooooo`?o00006?ooool00ol0003o06=1o`1S@@02o`1S@@03o`000?l0@4So0418
00?o041800?o0000o`10B?l000001Oooool00ol0003oooooooooo`18ooooo`00YOooool2o`0001[o
oooo00?o0000o`1S@Ol0Hd400ol0Hd400ol0003o0418o`10B003o`10B003o`000?l0@4So000000Go
oooo00?o0000ooooooooool0B?ooool00:;ooooo0ol00002ooooo`03o`000?oooooooooo01Gooooo
0_l00006o`1S@@03o`000?l0@4So041800?o041800?o0000o`10B?l000001_ooool00ol0003ooooo
ooooo`17ooooo`00Woooool3o`0001cooooo00?o0000o`1`<?l000001_l0Hd400ol0003o0418o`10
B003o`10B003o`000?l0@4So000000Oooooo00?o0000ooooooooool0A_ooool009gooooo0_l0000M
ooooo`;o00000_l0L3000ol0003o06=1o`1S@@04o`1S@@03o`000?l0@4So041800?o041800Co0000
o`10B?l0@4So00001_ooool00ol0003oooooooooo`16ooooo`00V_ooool3o`0001kooooo00?o0000
o`1`<?l0L3000_l0L3000ol0003o06=1o`1S@@04o`1S@@03o`000?l0@4So041800?o041800Co0000
o`10B?l0@4So00001oooool00ol0003oooooooooo`15ooooo`00V?ooool2o`000003ooooool0003o
oooo01gooooo00?o0000o`1`<?l0L3001?l0L3000ol0003o06=1o`1S@@04o`1S@@03o`000?l0@4So
041800;o041800Co0000o`10B?l0@4So00001oooool2o`0004Kooooo002Eooooo`?o00008?ooool2
o`0000Oo070`00?o0000o`1S@Ol0Hd401?l0Hd400ol0003o0418o`10B002o`10B004o`000?l0@4So
0000o`0000Sooooo00?o0000ooooooooool0A?ooool009?ooooo0_l0000Qooooo`;o000000?o07DX
o`000?l0L3001_l0L3000ol0003o06=1o`1S@@04o`1S@@03o`000?l0@4So041800;o041800Co0000
o`10B?l0003o00002Oooool00ol0003oooooooooo`0;ooooo`?o0000=Oooool0093ooooo0ol0000Q
ooooo`;o00000ol0MBP00ol0003o070`o`1`<005o`1`<003o`000?l0Hd7o06=100Co06=100?o0000
o`10B?l0@4P00_l0@4P01Ol0003o0418o`000?l0OQSo000000Wooooo00?o0000ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000003Cooooo002>ooooo`?o00008Oooool2o`0000Go07DX00?o
0000o`1`<?l0L3001Ol0L3000ol0003o06=1o`1S@@04o`1S@@03o`000?l0@4So041800;o04180_l0
0002o`1n6003o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool5o`0000Gooooo00?o
0000ooooooooool0<_ooool008_ooooo0ol00002ooooo`03o`000?oooooooooo01gooooo0_l00000
0ol0N2;o0000o`1e:005o`1e:003o`000?l0L33o070`00Co070`00?o0000o`1S@Ol0Hd401?l0Hd40
0ol0003o0418o`10B003o`10B004o`000?l0OQSo07hHo`0000[ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0booooo`00J_ooool2o`0001gooooo0_l0000Sooooo`;o00000ol0N280
0ol0003o07DXo`1e:004o`1e:003o`000?l0L33o070`00Co070`00?o0000o`1S@Ol0Hd401Ol0Hd40
1?l0003o0418o`10B?l0@4P2o`0000;o07hH00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`07ooooo`Co0000=Oooool006Wooooo00Co0000oooooooooooo00006Oooool3o`0002?ooooo0_l0
0005o`1h8P03o`000?l0MBSo07DX00Co07DX00?o0000o`1`<?l0L3001Ol0L3000ol0003o06=1o`1S
@@04o`1S@@04o`000?l0@4So0418o`10B0;o00000_l0OQP00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool006Wooooo00Co0000oooooooooooo0000
5_ooool3o`0002Cooooo0_l000000ol0Nago0000o`1h8P05o`1h8P03o`000?l0MBSo07DX00?o07DX
00?o0000o`1`<?l0L3001Ol0L3000ol0003o06=1o`1S@@04o`1S@@04o`000?l0@4So0418o`10B0;o
00000ol0OQP00ol0003oooooooooo`07ooooo`?o00002?ooool5o`0003Cooooo001Yooooo`04o`00
0?ooooooooooo`0001Cooooo0_l00003ooooo`03o`000?oooooooooo01oooooo0_l00003o`1k7@03
o`000?l0N2;o07PR00Co07PR00?o0000o`1e:?l0MBP00ol0MBP00ol0003o070`o`1`<005o`1`<003
o`000?l0Hd7o06=100Co06=100Ko0000o`10B?l0@4So0000o`1n6?l00003o`1n6003o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0?_ooool006Wooooo00Co0000oooooooooooo00004Oooool3
o`0002Gooooo0_l00005o`1k7@03o`000?l0N2;o07PR00Co07PR00?o0000o`1e:?l0MBP00ol0MBP0
0ol0003o070`o`1`<005o`1`<003o`000?l0Hd7o06=100Co06=100Ko0000o`10B?l0@4So0000o`1n
6?l00003o`1n6003o`000?oooooooooo00[ooooo00?o0000ooooooooool0?_ooool006Wooooo00Co
0000oooooooooooo00003oooool2o`0002Oooooo00?o0000o`1m6Ol000001_l0Nad00ol0003o07PR
o`1h8P03o`1h8P03o`000?l0MBSo07DX00?o07DX00?o0000o`1`<?l0L3001Ol0L3000ol0003o06=1
o`1S@@04o`1S@@03o`000?l0@4So000000;o07hH00Go0000o`1n6?l0OQSo07hHo`00000=ooooo`03
o`000?oooooooooo03gooooo001Zooooo`;o00003Oooool3o`0002Oooooo0_l00002o`1m6@03o`00
0?l0Nago07/M00Co07/M00?o0000o`1h8_l0N2800ol0N2800ol0003o07DXo`1e:004o`1e:003o`00
0?l0L33o070`00Co070`00?o0000o`1S@Ol0Hd401Ol0Hd42o`0000;o07hH00Go0000o`1n6?l0OQSo
07hHo`00000=ooooo`03o`000?oooooooooo03gooooo001gooooo`;o00000_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?l0OAWo07dI00;o07dI00?o0000o`1k7Ol0Nad01?l0Nad00ol0003o07PR
o`1h8P03o`1h8P03o`000?l0MBSo07DX00Co07DX00?o0000o`1`<?l0L3001?l0L3000ol0003o06=1
o`1S@@05o`1S@@;o00000_l0OQP00ol0003o07hHo`1n6002o`1n6003o`000?oooooooooo00_ooooo
00?o0000ooooooooool0??ooool007Cooooo0ol0000Yooooo`;o00001Ol0OAT00ol0003o07/Mo`1k
7@04o`1k7@03o`000?l0N2;o07PR00?o07PR00?o0000o`1e:?l0MBP01?l0MBP00ol0003o070`o`1`
<005o`1`<003o`000?l0Hd7o06=100Co06=100Go0000o`1n6?l0OQSo07hHo`000004o`1n6003o`00
0?oooooooooo00cooooo00?o0000ooooooooool0>oooool007;ooooo0_l0000Zooooo`;o000000?o
07lEo`000?l0OAT01Ol0OAT00ol0003o07/Mo`1k7@03o`1k7@03o`000?l0N2;o07PR00Co07PR00?o
0000o`1e:?l0MBP00ol0MBP00ol0003o070`o`1`<005o`1`<003o`000?l0Hd7o06=100Co06=100Go
0000o`1n6?l0OQSo07hHo`000004o`1n6003o`000?oooooooooo00cooooo0_l0000looooo`00Kooo
ool3o`0002[ooooo0_l00003o`1o5@03o`000?l0OAWo07dI00Co07dI00?o0000o`1k7Ol0Nad00ol0
Nad00ol0003o07PRo`1h8P04o`1h8P03o`000?l0MBSo07DX00?o07DX00?o0000o`1`<?l0L3001Ol0
L3000ol0003o06=1o`1S@@03o`1S@@;o00000ol0OQP00ol0003o07hHo`1n6002o`1n6003o`000?oo
oooooooo00gooooo00?o0000ooooooooool0>_ooool006gooooo0_l000000ooooooo0000ooooo`0X
ooooo`;o00001Ol0OaD00ol0003o07dIo`1m6@04o`1m6@03o`000?l0Nago07/M00?o07/M00?o0000
o`1h8_l0N2801?l0N2800ol0003o07DXo`1e:003o`1e:003o`000?l0L33o070`00Go070`00?o0000
o`1S@Ol0Hd400_l0Hd400ol0003oDjL0o`000003o`1n6003o`000?l0OQSo07hH00;o07hH0_l0000?
ooooo`03o`000?oooooooooo03Wooooo001Zooooo`?o00001?ooool00ol0003oooooooooo`0Toooo
o`;o000000?o088Ao`000?l0OaD01?l0OaD00ol0003o07dIo`1m6@04o`1m6@03o`000?l0Nago07/M
00Co07/M00?o0000o`1h8_l0N2800ol0N2800ol0003o07DXo`1e:003o`1e:003o`000?l0L33o070`
00Go070`00?o0000o`1S@Ol0Hd400_l0Hd401?l0003oDjL0oe>W0?l00002o`1n6007o`000?l0OQSo
07hHo`1n6?l0003oAJ<0o`00000?ooooo`03o`000?oooooooooo03Wooooo001Xooooo`;o0000;?oo
ool2o`0000?o088A00?o0000o`1o5Ol0OaD01?l0OaD00ol0003o07dIo`1m6@03o`1m6@03o`000?l0
Nago07/M00Co07/M00?o0000o`1h8_l0N2800ol0N2800ol0003o07DXo`1e:004o`1e:003o`000?l0
L33o070`00Co070`00Go0000o`1S@Ol0Hd7o06=1o`000003oe>W0004o`000?l0OQSo07hHo`0000?o
07hH00Co0000odFS0?m5X`3o00003oooool00ol0003oooooooooo`0hooooo`00IOooool3o`0002co
oooo0_l00005o`224@03o`000?l0OaGo07lE00Co07lE00?o0000o`1m6Ol0OAT00ol0OAT00ol0003o
07/Mo`1k7@04o`1k7@03o`000?l0N2;o07PR00?o07PR00?o0000o`1e:?l0MBP01?l0MBP00ol0003o
070`o`1`<004o`1`<004o`000?l0Hd7o06=1o`0000CoDjL000Co0000o`1n6?l0OQSo00000ol0OQP0
1?l0003oAJ<0odFS0?l0000@ooooo`03o`000?oooooooooo03Oooooo001Rooooo`?o000000?ooooo
o`000?ooool0:_ooool2o`000003o`233Ol0003o088A00Co088A00?o0000o`1o5Ol0OaD01?l0OaD0
0ol0003o07dIo`1m6@03o`1m6@03o`000?l0Nago07/M00Co07/M00?o0000o`1h8_l0N2800ol0N280
0ol0003o07DXo`1e:004o`1e:003o`000?l0L33o070`00Go070`00?o0000o`1S@Ol000001?mCY`00
1?l0003o07hHo`1n6?l00003o`1n6004o`000?m5X`3oAJ<0o`00013ooooo00?o0000ooooooooool0
=oooool0063ooooo0_l0000^ooooo`;o00000ol0P`d00ol0003o088Ao`224@04o`224@03o`000?l0
OaGo07lE00?o07lE00?o0000o`1m6Ol0OAT00ol0OAT00ol0003o07/Mo`1k7@04o`1k7@03o`000?l0
N2;o07PR00Co07PR00?o0000o`1e:?l0MBP00ol0MBP00ol0003o070`o`1`<005o`1`<0;o00001OmC
Y`001ol0003o07hHo`1n6?l0OQSo0000o`1n6?l000001?m5X`000ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo03Kooooo001Mooooo`?o0000;_ooool2o`0000Go08<=00?o0000o`224Ol0PQ40
1?l0PQ400ol0003o07lEo`1o5@03o`1o5@03o`000?l0OAWo07dI00?o07dI00?o0000o`1k7Ol0Nad0
1?l0Nad00ol0003o07PRo`1h8P04o`1h8P03o`000?l0MBSo07DX00?o07DX00?o0000o`1`<?l0L300
1?l0L302o`0000OoDjL000Ko0000o`1n6?l0OQSo0000o`1n6?l00004odFS0003o`000?oooooooooo
00gooooo00?o0000ooooool00000=oooool005_ooooo0_l0000^ooooo`?o000000?o08D9o`000?l0
P`d01?l0P`d00ol0003o088Ao`224@04o`224@03o`000?l0OaGo07lE00?o07lE00?o0000o`1m6Ol0
OAT01?l0OAT00ol0003o07/Mo`1k7@03o`1k7@03o`000?l0N2;o07PR00Co07PR00?o0000o`1e:?l0
MBP00ol0MBP00ol0003o070`o`1`<003o`1`<003o`000?nA^03o000000OoDjL000Ko0000o`1n6?l0
OQSo0000o`1n6?l00005odFS0003o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool0
03Kooooo0ol0000Oooooo`?o000000?oooooo`000?ooool0:_ooool3o`0000Co08D900?o0000o`23
3Ol0P`d01?l0P`d00ol0003o088Ao`224@03o`224@03o`000?l0OaGo07lE00?o07lE00?o0000o`1m
6Ol0OAT01?l0OAT00ol0003o07/Mo`1k7@04o`1k7@03o`000?l0N2;o07PR00?o07PR00?o0000o`1e
:?l0MBP00ol0MBP01?l0003o070`o`1`<?l0L302o`0000;oTKP000?o0000oe>W0?mCY`001OmCY`00
1_l0003o07hHo`1n6?l0003o07hHo`0000GoAJ<000?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0dooooo`00=Oooool01Ol0003ooooooooooooooooo000001cooooo0_l0000^ooooo`;o0000
00?o08H6o`000?l0Q@T01?l0Q@T00ol0003o08<=o`233@04o`233@03o`000?l0PQ7o088A00?o088A
00?o0000o`1o5Ol0OaD00ol0OaD00ol0003o07dIo`1m6@04o`1m6@03o`000?l0Nago07/M00Co07/M
00?o0000o`1h8_l0N2800ol0N2800ol0003o07DXo`1e:004o`1e:003o`000?l0L33o000000CoTKP0
00?o0000oe>W0?mCY`001OmCY`000ol0003o07hHo`1n6002o`0000KoAJ<00_l0000Aooooo`03o`00
0?oooooooooo03?ooooo000_ooooo`Go00001Oooool00ol0003oooooooooo`0Gooooo`?o0000;_oo
ool2o`0000?o08H600?o0000o`252Ol0Q@T00ol0Q@T00ol0003o08<=o`233@04o`233@03o`000?l0
PQ7o088A00?o088A00?o0000o`1o5Ol0OaD01?l0OaD00ol0003o07dIo`1m6@03o`1m6@03o`000?l0
Nago07/M00Co07/M00?o0000o`1h8_l0N2800ol0N2800ol0003o07DXo`1e:004o`1e:0;o00001_nA
^0000ol0003oDjL0oe>W0004oe>W0003o`000?l0OQSo07hH00;o00001Om5X`000ol0003oN;40o`00
000Aooooo`03o`000?oooooooooo03?ooooo000iooooo`03o`000?oooooooooo01Gooooo0_l0000_
ooooo`;o00001Ol0QPH00ol0003o08D9o`252@04o`252@03o`000?l0P`go08<=00?o08<=00?o0000
o`224Ol0PQ400ol0PQ400ol0003o07lEo`1o5@04o`1o5@03o`000?l0OAWo07dI00?o07dI00?o0000
o`1k7Ol0Nad01?l0Nad00ol0003o07PRo`1h8P03o`1h8P03o`000?l0MBSo07DX00?o07DX0_l00007
oi6h0003o`000?mCY`3oDjL000GoDjL000Co0000o`1n6?l0003o00001Om5X`001?l0003oN;40ogRa
0?l0000Aooooo`03o`000?oooooooooo03;ooooo000eooooo`Co00005Oooool3o`000003ooooool0
003ooooo02cooooo0_l000000ol0R0?o0000o`261P04o`261P03o`000?l0Q@Wo08D900Co08D900?o
0000o`233Ol0P`d00ol0P`d00ol0003o088Ao`224@03o`224@03o`000?l0OaGo07lE00Co07lE00?o
0000o`1m6Ol0OAT00ol0OAT00ol0003o07/Mo`1k7@04o`1k7@03o`000?l0N2;o07PR00Co07PR00?o
0000o`1e:?l0MBP00_l000000onU_@3o0000oi6h0006oi6h0003o`000?mCY`3oDjL000GoDjL000Co
0000o`1n6?l0003o00001Om5X`001?l0003oN;40ogRa0?l0000Aooooo`03o`000?oooooooooo03;o
oooo000eooooo`03o`000?oooooooooo01Cooooo0_l0000`ooooo`;o00000ol0R0<00ol0003o08H6
o`261P04o`261P03o`000?l0Q@Wo08D900?o08D900?o0000o`233Ol0P`d00ol0P`d00ol0003o088A
o`224@04o`224@03o`000?l0OaGo07lE00?o07lE00?o0000o`1m6Ol0OAT00ol0OAT00ol0003o07/M
o`1k7@04o`1k7@03o`000?l0N2;o07PR00Co07PR0ol00003ojFm0003o`000?nA^03oTKP000GoTKP0
00?o0000oe>W0?mCY`001OmCY`000ol0003o07hHo`000006odFS0004o`000?mh/@3oN;40o`00017o
oooo0_l0000cooooo`00=Oooool5o`0000oooooo0ol0000`ooooo`;o00001Ol0R0<00ol0003o08H6
o`261P04o`261P03o`000?l0Q@Wo08D900?o08D900?o0000o`233Ol0P`d00ol0P`d00ol0003o088A
o`224@04o`224@03o`000?l0OaGo07lE00?o07lE00?o0000o`1m6Ol0OAT00ol0OAT00ol0003o07/M
o`1k7@04o`1k7@03o`000?l0N2;o07PR00?o07PR0_l00005ojFm0003o`000?nA^03oTKP000GoTKP0
00?o0000oe>W0?mCY`001OmCY`000ol0003o07hHo`000005odFS0003o`000?mh/@3oN;4000;oN;40
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0`ooooo`00A_ooool3o`00037ooooo0_l0
00000ol0R@3o0000o`280`04o`280`03o`000?l0QPKo08H600Co08H600?o0000o`252Ol0Q@T00ol0
Q@T00ol0003o08<=o`233@03o`233@03o`000?l0PQ7o088A00Co088A00?o0000o`1o5Ol0OaD00ol0
OaD00ol0003o07dIo`1m6@03o`1m6@03o`000?l0Nago07/M00Go07/M00?o0000o`1h8_l0N2800_l0
00000onY_P3o0000ojFm0005ojFm0003o`000?nA^03oTKP000CoTKP000?o0000oe>W0?mCY`001OmC
Y`000ol0003o07hHo`000005odFS0003o`000?mh/@3oN;4000;oN;4000?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0`ooooo`00A?ooool2o`0000;ooooo00?o0000ooooooooool0;Oooool2
o`0000?o08T000?o0000o`280ol0R0<01?l0R0<00ol0003o08H6o`261P03o`261P03o`000?l0Q@Wo
08D900?o08D900?o0000o`233Ol0P`d01?l0P`d00ol0003o088Ao`224@03o`224@03o`000?l0OaGo
07lE00?o07lE00?o0000o`1m6Ol0OAT01?l0OAT00ol0003o07/Mo`1k7@04o`1k7@?o00000onY_P00
0ol0003oYKd0ojFm0004ojFm0003o`000?nA^03oTKP000GoTKP000?o0000oe>W0?mCY`001OmCY`02
o`0000GoAJ<000?o0000ogRa0?mh/@000_mh/@02o`0001;ooooo00?o0000ooooooooool0;oooool0
047ooooo0ol0000booooo`;o00001Ol0R@000ol0003o08P3o`280`04o`280`03o`000?l0QPKo08H6
00?o08H600?o0000o`252Ol0Q@T00ol0Q@T00ol0003o08<=o`233@04o`233@03o`000?l0PQ7o088A
00?o088A00?o0000o`1o5Ol0OaD00ol0OaD00ol0003o07dIo`1m6@04o`1m6@03o`000?l0Nago07/M
00?o07/M0_l00005ojVn0003o`000?nU_@3oYKd000CoYKd000?o0000oi6h0?nA^0001OnA^0000ol0
003oDjL0oe>W0005oe>W00;o00001Om5X`001Ol0003oN;40ogRa0?mh/@3o000000;oR;H000?o0000
ooooooooool04?ooool00ol0003oooooooooo`0^ooooo`00?oooool2o`0003;ooooo0ol000000ol1
RP3o0000o`290004o`290003o`000?l0R0?o08P300Co08P300?o0000o`261_l0QPH00ol0QPH00ol0
003o08D9o`252@03o`252@03o`000?l0P`go08<=00Co08<=00?o0000o`224Ol0PQ400ol0PQ400ol0
003o07lEo`1o5@03o`1o5@03o`000?l0OAWo07dI00Co07dI00?o0000o`1k7Ol0Nad00ol000000on[
_P3o0000ojVn0005ojVn0003o`000?nU_@3oYKd000?oYKd000?o0000oi6h0?nA^0001OnA^0000ol0
003oDjL0oe>W0005oe>W00;o00001?m5X`000ol0003oN;40ogRa0002ogRa0005o`000?n8]P3oR;H0
ohRf0?l000004Oooool00ol0003oooooooooo`0^ooooo`00??ooool3o`00037ooooo0ol00004o`6:
0003o`000?l0R@3o08T000Co08T000?o0000o`280ol0R0<00ol0R0<00ol0003o08H6o`261P03o`26
1P03o`000?l0Q@Wo08D900Co08D900?o0000o`233Ol0P`d00ol0P`d00ol0003o088Ao`224@03o`22
4@03o`000?l0OaGo07lE00Co07lE00?o0000o`1m6Ol0OAT00ol0OAT3o`0000CoZkh000?o0000ojVn
0?nY_P001?nY_P000ol0003oYKd0ojFm0003ojFm0003o`000?nA^03oTKP000GoTKP000?o0000oe>W
0?mCY`001OmCY`02o`0000CoAJ<000?o0000ogRa0?mh/@000_mh/@001Ol0003oR;H0ohRf0?n8]P3o
000001;ooooo00?o0000ooooooooool0;Oooool003[ooooo0_l00003ooooo`03o`000?oooooooooo
02cooooo0_l000000ol4R`3o0000o`6:0004o`6:0003o`000?l0R@3o08T000Co08T000?o0000o`28
0ol0R0<00ol0R0<00ol0003o08H6o`261P03o`261P03o`000?l0Q@Wo08D900Co08D900?o0000o`23
3Ol0P`d00ol0P`d00ol0003o088Ao`224@03o`224@03o`000?l0OaGo07lE00Co07lE00?o0000o`1m
6Ol0OAT00_l0OAT2o`0000KoZkh000?o0000ojVn0?nY_P001?nY_P000ol0003oYKd0ojFm0004ojFm
0003o`000?nA^03oTKP000CoTKP000?o0000oe>W0?mCY`001?mCY`03o`0000CoAJ<000?o0000ogRa
0?mh/@000_mh/@001?l0003oR;H0ohRf0?n8]P02o`00017ooooo0_l0000^ooooo`00=oooool3o`00
03?ooooo00Go0000o`B;0?l4R`3o18/0o`000005o`6:0003o`000?l0R@3o08T000Co08T000?o0000
o`280ol0R0<00ol0R0<00ol0003o08H6o`261P04o`261P03o`000?l0Q@Wo08D900?o08D900?o0000
o`233Ol0P`d00ol0P`d00ol0003o088Ao`224@03o`224@03o`000?l0OaGo07lE00Co07lE00?o0000
o`1m6Ol000000_l000000on/_`3o0000oj^n0006oj^n0003o`000?nY_P3oZKh000?oZKh000?o0000
ojFm0?nU_@001?nU_@000ol0003oTKP0oi6h0005oi6h0003o`000?mCY`3oDjL000?oDjL000Co0000
om>P0?l0003o00000_m5X`000ol0003oN;40ogRa0003ogRa0006o`000?n8]P3oR;H0o`000?n>]`3o
00004_ooool00ol0003oooooooooo`06ooooo`;o00009?ooool003Gooooo0_l0000dooooo`;o0000
1?l4R`000ol0003o0HX0o`6:0004o`6:0003o`000?l0R@3o08T000?o08T000?o0000o`280ol0R0<0
0ol0R0<00ol0003o08H6o`261P04o`261P03o`000?l0Q@Wo08D900?o08D900?o0000o`233Ol0P`d0
0ol0P`d00ol0003o088Ao`224@04o`224@03o`000?l0OaGo07lE00;o07lE0ol00004ojbo0003o`00
0?n[_P3oZkh000GoZkh000?o0000ojVn0?nY_P000onY_P000ol0003oYKd0ojFm0004ojFm0003o`00
0?nA^03oTKP000GoTKP000?o0000oe>W0?mCY`000_mCY`000ol0003odj00om>P0002o`0000;oAJ<0
00?o0000ogRa0?mh/@000_mh/@001ol0003oR;H0ohRf0?n8]P3o0000ohjg0?l000004oooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`0002?ooooo000booooo`Co0000<_ooool3o`00
0003o`J<0?l0003o18/000?o18/000?o0000o`6:0?l1RP001?l1RP000ol0003o08T0o`290003o`29
0003o`000?l0R0?o08P300?o08P300?o0000o`261_l0QPH01?l0QPH00ol0003o08D9o`252@03o`25
2@03o`000?l0P`go08<=00?o08<=00?o0000o`224Ol0PQ401?l0PQ400ol0003o07lEo`1o5@02o`00
0003ojfo0?l0003o[;l000Go[;l000?o0000oj^n0?n[_P001?n[_P000ol0003oZKh0ojVn0004ojVn
0003o`000?nU_@3oYKd000?oYKd000?o0000oi6h0?nA^0001OnA^0000ol0003oDjL0oe>W0002oe>W
0003o`000?oCX03odj0000;o00000_m5X`000ol0003oN;40ogRa0002ogRa0005o`000?n8]P3oR;H0
ohRf0?l000000_n>]`000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00008oooool0033ooooo0_l0000cooooo`?o00001?l6S0000ol0003o18/0o`B;0003
o`B;0003o`000?l1RP3o0HX000?o0HX000?o0000o`290?l0R@000ol0R@000ol0003o08P3o`280`04
o`280`03o`000?l0QPKo08H600?o08H600?o0000o`252Ol0Q@T00ol0Q@T00ol0003o08<=o`233@04
o`233@03o`000?l0PQ7o088A00?o088A0ol00003ojfo0003o`000?n/_`3o[;l000Co[;l000?o0000
oj^n0?n[_P001?n[_P000ol0003oZKh0ojVn0004ojVn0003o`000?nU_@3oYKd000?oYKd000?o0000
oi6h0?nA^0001OnA^0001Ol0003oDjL0oe>W0?mCY`3o000000?odj000_l00002odFS0003o`000?mh
/@3oN;4000;oN;4000Go0000ohRf0?n8]P3oR;H0o`000002ohjg0003o`000?oooooooooo017ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool0000Sooooo`00;Oooool3o`0003?ooooo
0_l000000ol7S@3o0000o`J<0004o`J<0003o`000?l4R`3o18/000?o18/000?o0000o`6:0?l1RP00
0ol1RP000ol0003o08T0o`290003o`290003o`000?l0R0?o08P300Co08P300?o0000o`261_l0QPH0
0ol0QPH00ol0003o08D9o`252@03o`252@03o`000?l0P`go08<=00Co08<=00?o0000o`224Ol0PQ40
0_l0PQ42o`0000Ko[Kl000?o0000ojbo0?n/_`000on/_`000ol0003oZkh0oj^n0004oj^n0003o`00
0?nY_P3oZKh000CoZKh000?o0000ojFm0?nU_@000onU_@000ol0003oTKP0oi6h0005oi6h0004o`00
0?mCY`3oDjL0o`0000Godj0000?o0000odFS0?l000001Omh/@001Ol0003oR;H0ohRf0?n8]P3o0000
00;oS[L00_l0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool0
02[ooooo0ol0000dooooo`;o00000ol7S@000ol0003o1X`0o`J<0003o`J<0003o`000?l4R`3o18/0
00?o18/000?o0000o`6:0?l1RP000ol1RP000ol0003o08T0o`290004o`290003o`000?l0R0?o08P3
00?o08P300?o0000o`261_l0QPH00ol0QPH00ol0003o08D9o`252@03o`252@03o`000?l0P`go08<=
00Co08<=00?o0000o`224Ol000000_l000000on]_`3o0000ojfo0005ojfo0003o`000?n/_`3o[;l0
00?o[;l000?o0000oj^n0?n[_P001?n[_P000ol0003oZKh0ojVn0004ojVn0003o`000?nU_@3oYKd0
00CoYKd000?o0000oi6h0?nA^0001?nA^0001?l0003oDjL0oe>W0?l00005om>P0003o`000?m5X`3o
000000CoN;4000Go0000ohRf0?n8]P3oR;H0o`000002ohjg0004o`000?nB^03oT[P0o`0001;ooooo
0_l00003ooooo`04o`000?ooooooooooo`0002?ooooo000Xooooo`;o000000?oooooo`000?ooool0
<_ooool2o`0000Go1hd000?o0000o`J<0?l6S0000ol6S0000ol0003o18/0o`B;0003o`B;0003o`00
0?l1RP3o0HX000?o0HX000?o0000o`290?l0R@001?l0R@000ol0003o08P3o`280`03o`280`03o`00
0?l0QPKo08H600?o08H600?o0000o`252Ol0Q@T01?l0Q@T00ol0003o08<=o`233@02o`233@?o0000
1?n]_`000ol0003o[Kl0ojfo0004ojfo0003o`000?n/_`3o[;l000?o[;l000?o0000oj^n0?n[_P00
1?n[_P000ol0003oZKh0ojVn0004ojVn0003o`000?nU_@3oYKd000CoYKd000?o0000oi6h0?nA^000
1OnA^002o`0000Kodj0000?o0000odFS0?l000001?mh/@001Ol0003oR;H0ohRf0?n8]P3o000000;o
S[L000Go0000oi:h0?nB^03oT[P0o`00000@ooooo`03o`000?oooooo000000Cooooo0_l0000Toooo
o`009Oooool3o`0003Cooooo0ol000000ol9S@3o0000o`N=0004o`N=0003o`000?l6S03o1X`000Co
1X`000?o0000o`B;0?l4R`000_l4R`000ol0003o0HX0o`6:0003o`6:0003o`000?l0R@3o08T000Co
08T000?o0000o`280ol0R0<00ol0R0<00ol0003o08H6o`261P03o`261P03o`000?l0Q@Wo08D900Co
08D900?o0000o`233Ol0P`d00_l000000on]_`3o0000ojfo0004ojfo0003o`000?n]_`3o[Kl000Co
[Kl000?o0000ojbo0?n/_`001?n/_`000ol0003oZkh0oj^n0004oj^n0003o`000?nY_P3oZKh000Co
ZKh000?o0000ojFm0?nU_@000onU_@000ol0003oTKP0oi6h0005oi6h00;o00001OoCX002o`000003
odFS0?l0003oN;4000?oN;4000Go0000ohRf0?n8]P3oR;H0o`000002ohjg0005o`000?nB^03oT[P0
oi:h0?l000004oooool00ol0003oooooooooo`0Wooooo`008oooool2o`0003Gooooo0_l00004o`V=
0003o`000?l7S@3o1hd000?o1hd000?o0000o`J<0?l6S0001?l6S0000ol0003o18/0o`B;0002o`B;
0003o`000?l1RP3o0HX000Co0HX000?o0000o`290?l0R@000ol0R@000ol0003o08P3o`280`03o`28
0`03o`000?l0QPKo08H600Co08H600?o0000o`252Ol0Q@T00ol0Q@T3o`0000?o[Kl000?o0000ojfo
0?n]_`001?n]_`000ol0003o[Kl0ojfo0003ojfo0003o`000?n/_`3o[;l000Co[;l000?o0000oj^n
0?n[_P001?n[_P000ol0003oZKh0ojVn0004ojVn0003o`000?nU_@3oYKd000?oYKd000?o0000oi6h
0?nA^0001?nA^002o`0000?odj000ol000000ooCX03o0000o`000005ogRa0005o`000?n8]P3oR;H0
ohRf0?l000000_n>]`001?l0003oT[P0oi:h0?nB^002o`0001?ooooo00?o0000ooooooooool09_oo
ool0023ooooo0ol0000eooooo`;o000000?o2hh0o`000?l9S@000ol9S@000ol0003o1hd0o`N=0004
o`N=0003o`000?l6S03o1X`000?o1X`000?o0000o`B;0?l4R`000_l4R`000ol0003o0HX0o`6:0004
o`6:0003o`000?l0R@3o08T000?o08T000?o0000o`280ol0R0<00ol0R0<00ol0003o08H6o`261P04
o`261P03o`000?l0Q@Wo08D900;o08D90_l00005ojfo0003o`000?n]_`3o[Kl000Co[Kl000?o0000
ojfo0?n]_`001?n]_`000ol0003o[;l0ojbo0003ojbo0003o`000?n[_P3oZkh000CoZkh000?o0000
ojVn0?nY_P001?nY_P000ol0003oYKd0ojFm0003ojFm0003o`000?nA^03oTKP000;oTKP00_l00000
0ooUIP3o0000o`000002o`0000Godj0000?o0000ogRa0?mh/@000_mh/@001Ol0003oR;H0ohRf0?n8
]P3o000000;oS[L000Go0000oi:h0?nB^03oT[P0o`000002oiFi0003o`000?oooooooooo013ooooo
00?o0000ooooooooool09_ooool001kooooo0ol000000ooooooo0000ooooo`0booooo`;o00000ol;
SP000ol0003o2Hd0o`V=0003o`V=0003o`000?l7S@3o1hd000?o1hd000?o0000o`J<0?l6S0000ol6
S0000ol0003o18/0o`B;0003o`B;0003o`000?l1RP3o0HX000?o0HX000?o0000o`290?l0R@000ol0
R@000ol0003o08P3o`280`03o`280`03o`000?l0QPKo08H600Co08H600?o0000o`252Ol000000_l0
00000on/_`3o0000ojfo0005ojfo0003o`000?n]_`3o[Kl000?o[Kl000?o0000ojfo0?n]_`001?n]
_`000ol0003o[;l0ojbo0003ojbo0003o`000?n[_P3oZkh000CoZkh000?o0000ojVn0?nY_P001?nY
_P000ol0003oYKd0ojFm0004ojFm0005o`000?nA^03oTKP0o`000?oUIP000ol00008om>P00;o0000
0omh/@001Ol0003oR;H0ohRf0?n8]P3o000000;oS[L000Go0000oi:h0?nB^03oT[P0o`000002oiFi
0003o`000?oooooooooo017ooooo00?o0000ooooooooool09Oooool001oooooo00?o0000ooooool0
0000<_ooool2o`0000Go2hh000?o0000o`V=0?l9S@000ol9S@000ol0003o1hd0o`N=0003o`N=0003
o`000?l6S03o1X`000?o1X`000?o0000o`B;0?l4R`000ol4R`000ol0003o0HX0o`6:0003o`6:0003
o`000?l0R@3o08T000?o08T000?o0000o`280ol0R0<01?l0R0<00ol0003o08H6o`261P02o`261P?o
00001?n/_`000ol0003o[Kl0ojfo0004ojfo0003o`000?n]_`3o[Kl000?o[Kl000?o0000ojfo0?n]
_`001?n]_`000ol0003o[;l0ojbo0003ojbo0003o`000?n[_P3oZkh000CoZkh000?o0000ojVn0?nY
_P001?nY_P000ol0003oYKd0ojFm0004ojFm00Go00000ooUIP000ol0003odj00om>P0004om>P0004
o`000?oSK03o0000o`0000;oN;4000Go0000ohRf0?n8]P3oR;H0o`000002ohjg0005o`000?nB^03o
T[P0oi:h0?l000000onE^@000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Gooooo000O
ooooo`04o`000?ooooooooooo`0002kooooo0ol000000ol<SP3o0000o`^>0004o`^>0003o`000?l9
S@3o2Hd000?o2Hd000?o0000o`N=0?l7S@000ol7S@000ol0003o1X`0o`J<0003o`J<0003o`000?l4
R`3o18/000?o18/000?o0000o`6:0?l1RP000ol1RP000ol0003o08T0o`290003o`290003o`000?l0
R0?o08P300Co08P300?o0000o`261_l0QPH00_l000000on[_P3o0000ojbo0004ojbo0003o`000?n]
_`3o[Kl000Co[Kl000?o0000ojfo0?n]_`000on]_`000ol0003o[Kl0ojfo0004ojfo0003o`000?n/
_`3o[;l000Co[;l000?o0000oj^n0?n[_P000on[_P000ol0003oZKh0ojVn0005ojVn0003o`000?nU
_@3oYKd000;oYKd00ol00006onEV0003o`000?oCX03odj0000Codj0000Co0000on=/0?oSK03o0000
0_mh/@001Ol0003oR;H0ohRf0?n8]P3o000000;oS[L000Go0000oi:h0?nB^03oT[P0o`000003oiFi
0003o`000?oooooooooo013ooooo0_l0000Vooooo`007oooool01Ol0003ooooooooooooooooo0000
02_ooooo0_l00004o`b>0003o`000?l;SP3o2hh000?o2hh000?o0000o`V=0?l9S@000ol9S@000ol0
003o1hd0o`N=0003o`N=0003o`000?l6S03o1X`000?o1X`000?o0000o`B;0?l4R`000ol4R`000ol0
003o0HX0o`6:0003o`6:0003o`000?l0R@3o08T000Co08T000?o0000o`280ol0R0<00ol0R0<3o`00
00?oZkh000?o0000ojbo0?n/_`001?n/_`000ol0003o[Kl0ojfo0003ojfo0003o`000?n]_`3o[Kl0
00?o[Kl000?o0000ojfo0?n]_`001?n]_`000ol0003o[;l0ojbo0004ojbo0003o`000?n[_P3oZkh0
00?oZkh000?o0000ojVn0?nY_P001OnY_P000ol0003oYKd0o`000002o`000003onQM0?l0003oiFH0
00KoiFH000?o0000om>P0?oCX0000ooCX0001?l0003ohf`0on=/0?oSK002o`000005ogRa0?l0003o
R;H0ohRf0?l000000_n>]`001Ol0003oT[P0oi:h0?nB^03o000000CoUKT00_l0000Cooooo`03o`00
0?oooooooooo02?ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Ooo
ool3o`000003o`f?0?l0003o38h000?o38h000?o0000o`^>0?l;SP001?l;SP000ol0003o2Hd0o`V=
0002o`V=0003o`000?l7S@3o1hd000?o1hd000?o0000o`J<0?l6S0000ol6S0000ol0003o18/0o`B;
0003o`B;0003o`000?l1RP3o0HX000?o0HX000?o0000o`290?l0R@001?l0R@000ol0003o08P3o`28
0`02o`280`;o00001On[_P000ol0003o[;l0ojbo0004ojbo0003o`000?n]_`3o[Kl000?o[Kl000?o
0000ojfo0?n]_`001?n]_`000ol0003o[Kl0ojfo0004ojfo0003o`000?n/_`3o[;l000?o[;l000?o
0000oj^n0?n[_P001?n[_P000ol0003oZKh0ojVn0002ojVn00Co00001OoXG@000ol0003oiFH0onEV
0004onEV0003o`000?oCX03odj0000?odj0000?o0000on=/0?oSK0000_oSK002o`0000?oR;H000Co
0000ohjg0?n>]`3o00000onB^0001Ol0003oUKT0oiFi0?nE^@3o000000;oUkX000?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo027ooooo0ol00004o`f?0003o`000?l<SP3o38h000;o38h000?o0000o`^>0?l;SP00
1?l;SP000ol0003o2Hd0o`V=0002o`V=0003o`000?l7S@3o1hd000?o1hd000?o0000o`J<0?l6S000
0ol6S0000ol0003o18/0o`B;0003o`B;0003o`000?l1RP3o0HX000Co0HX000?o0000o`290?l0R@00
0ol0R@000ol0003o08P3o`000002o`000003ojVn0?l0003oZkh000GoZkh000?o0000ojbo0?n/_`00
0on/_`000ol0003o[Kl0ojfo0003ojfo0003o`000?n]_`3o[Kl000Co[Kl000?o0000ojfo0?n]_`00
1?n]_`000ol0003o[;l0ojbo0003ojbo0003o`000?n[_P3oZkh000CoZkh000?o0000ojVn0?l00000
0ol000000ooVHP3o0000onQM0005onQM0003o`000?oUIP3oiFH000GoiFH000Go0000om>P0?oCX03o
dj00o`000006on=/0005o`000?n8]P3oR;H0ohRf0?l000000_n>]`001Ol0003oT[P0oi:h0?nB^03o
000000?oUKT000Go0000oiNj0?nG^P3oUkX0o`00000Booooo`03o`000?oooooooooo02;ooooo000N
ooooo`;o00001_ooool00ol0003oooooooooo`0Nooooo`;o000000?o3Hl0o`000?l=S`001?l=S`00
0ol0003o38h0o`b>0002o`b>0003o`000?l;SP3o2hh000Co2hh000?o0000o`V=0?l9S@000_l9S@00
0ol0003o1hd0o`N=0003o`N=0003o`000?l6S03o1X`000?o1X`000?o0000o`B;0?l4R`000ol4R`00
0ol0003o0HX0o`6:0004o`6:0003o`000?l0R@3o08T000;o08T00ol00004ojVn0003o`000?n[_P3o
Zkh000CoZkh000?o0000ojbo0?n/_`000on/_`000ol0003o[Kl0ojfo0004ojfo0003o`000?n]_`3o
[Kl000?o[Kl000?o0000ojfo0?n]_`001?n]_`000ol0003o[;l0ojbo0003ojbo0003o`000?n[_P3o
Zkh000?oZkh01Ol00003onIR0003o`000?oXG@3oj5d000Coj5d000?o0000onEV0?oUIP001OoUIP00
1?l0003odj00om>P0?l00007on=/00;o00000_n8]P001?l0003oS[L0ohjg0?l00003oi:h0005o`00
0?nE^@3oUKT0oiFi0?l000000onG^P000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo027o
oooo000Mooooo`;o00002?ooool00ol0003oooooooooo`0Looooo`05o`000?l=S`3o3Hl0o`f?0?l0
00001Ol=S`000ol0003o38h0o`b>0003o`b>0003o`000?l;SP3o2hh000?o2hh000?o0000o`V=0?l9
S@000ol9S@000ol0003o1hd0o`N=0002o`N=0003o`000?l6S03o1X`000?o1X`000?o0000o`B;0?l4
R`000ol4R`000ol0003o0HX0o`6:0004o`6:0003o`000?l0R@3o000000;o000000?oZ;h0o`000?nY
_P001OnY_P000ol0003oZkh0oj^n0003oj^n0003o`000?n/_`3o[;l000?o[;l000?o0000ojfo0?n]
_`001?n]_`000ol0003o[Kl0ojfo0003ojfo0003o`000?n]_`3o[Kl000Co[Kl000?o0000ojbo0?n/
_`001?n/_`000ol0003oZkh0o`000004o`0000OoiV8000?o0000onQM0?oXG@001?oXG@000ol0003o
iFH0onEV0004onEV0004o`000?oCX03odj00o`0000Kohf`000Ko0000onMP0?l0003o0000ohRf0?l0
0002ohjg0004o`000?nB^03oT[P0o`0000CoUKT000Co0000oiNj0?nG^P3oUkX00_l0000Booooo`03
o`000?oooooooooo027ooooo000:ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo0_l00004o`f?0003o`00
0?l=S`3o3Hl000?o3Hl000?o0000o`b>0?l<SP000ol<SP000ol0003o2hh0o`^>0003o`^>0003o`00
0?l9S@3o2Hd000?o2Hd000?o0000o`N=0?l7S@000_l7S@000ol0003o1X`0o`J<0004o`J<0003o`00
0?l4R`3o18/000?o18/000?o0000o`6:0?l1RP000_l1RP03o`0000CoZ;h000?o0000ojVn0?nY_P00
1?nY_P000ol0003oZkh0oj^n0003oj^n0003o`000?n/_`3o[;l000Co[;l000?o0000ojfo0?n]_`00
0on]_`000ol0003o[Kl0ojfo0003ojfo0003o`000?n]_`3o[Kl000Co[Kl000?o0000ojbo0?n/_`00
0on/_`05o`0000?oi6T000?o0000onIR0?oVHP001?oVHP000ol0003oj5d0onQM0004onQM0003o`00
0?oUIP3oiFH000CoiFH000?o0000om>P0?l000001_oSK0001?l0003oif00onMP0?oWH002o`0000;o
S[L000Go0000oi:h0?nB^03oT[P0o`000003oiFi0005o`000?nG^P3oUkX0oiNj0?l000000_nJ^P00
0ol0003oooooooooo`0@ooooo`;o00008Oooool000Wooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool3
o`000003o`j?0?l0003o3Hl000?o3Hl000?o0000o`f?0?l=S`001?l=S`000ol0003o38h0o`b>0002
o`b>0003o`000?l;SP3o2hh000?o2hh000?o0000o`V=0?l9S@000ol9S@000ol0003o1hd0o`N=0002
o`N=0003o`000?l6S03o1X`000Co1X`000?o0000o`B;0?l4R`000ol4R`000ol0003o0HX0o`6:0002
o`000003ojJm0?l0003oZ;h000GoZ;h000?o0000ojVn0?nY_P000onY_P000ol0003oZkh0oj^n0003
oj^n0003o`000?n/_`3o[;l000Co[;l000?o0000ojfo0?n]_`000on]_`000ol0003o[Kl0ojfo0003
ojfo0003o`000?n]_`3o[Kl000Go[Kl000?o0000ojbo0?l000001?l00006onAY0003o`000?oVHP3o
iV8000CoiV8000?o0000onQM0?oXG@001?oXG@000ol0003oiFH0onEV0005onEV00;o00001_oSK000
0ol0003oif00onMP0002onMP0004o`000?n>]`3oS[L0o`0000?oT[P000Go0000oiFi0?nE^@3oUKT0
o`000003oiNj0005o`000?nJ^P3oV[X0oiZj0?l000004Oooool2o`00027ooooo0009ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`0000_ooooo00?o0000oooooooo
ool04Oooool3o`0000Co3Xl000?o0000o`f?0?l=S`000_l=S`000ol0003o3Hl0o`f?0004o`f?0003
o`000?l<SP3o38h000;o38h000?o0000o`^>0?l;SP000ol;SP000ol0003o2Hd0o`V=0003o`V=0003
o`000?l7S@3o1hd000?o1hd000?o0000o`J<0?l6S0000ol6S0000ol0003o18/0o`B;0003o`B;00?o
00000onV_@000ol0003oZ;h0ojRn0004ojRn0003o`000?nY_P3oZKh000?oZKh000?o0000oj^n0?n[
_P001?n[_P000ol0003o[;l0ojbo0003ojbo0003o`000?n]_`3o[Kl000?o[Kl000?o0000ojfo0?n]
_`001?n]_`000ol0003o[Kl0ojfo0002ojfo00Ko00000_oRL0000ol0003oi6T0onAY0004onAY0003
o`000?oVHP3oiV8000CoiV8000?o0000onQM0?oXG@001OoXG@000ol0003oiFH0onEV0003onEV00;o
00001_oSK0000ol0003oif00onMP0003onMP00;o000000?oS[L0o`000?nB^0000_nB^0001Ol0003o
UKT0oiFi0?nE^@3o000000?oUkX000Go0000oiZj0?nJ^P3oV[X0o`00000Booooo`03o`000?oooooo
oooo01oooooo0009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo0ol000000ol>S`3o0000o`j?0004
o`j?0003o`000?l=S`3o3Hl000?o3Hl000?o0000o`f?0?l=S`000ol=S`000ol0003o38h0o`b>0002
o`b>0003o`000?l;SP3o2hh000?o2hh000?o0000o`V=0?l9S@000ol9S@000ol0003o1hd0o`N=0003
o`N=0003o`000?l6S03o1X`000?o1X`000?o0000o`B;0?l4R`000_l4R`02o`0000KoY[d000?o0000
ojRn0?nX_P000onX_P000ol0003oZKh0ojVn0003ojVn0003o`000?n[_P3oZkh000CoZkh000?o0000
ojbo0?n/_`000on/_`000ol0003o[Kl0ojfo0003ojfo0003o`000?n]_`3o[Kl000Co[Kl000?o0000
ojfo0?l000001Ol00006on9`0003o`000?oTJ@3oi6T000Coi6T000?o0000onIR0?oVHP001?oVHP00
0ol0003oj5d0onQM0004onQM0003o`000?oUIP3oiFH000;oiFH000?o0000ooD[0?l000001OoSK000
0ol0003oif00onMP0003onMP0003o`000?oWG`3o000000;o00000onB^0001Ol0003oUKT0oiFi0?nE
^@3o000000?oUkX000Co0000oiZj0?nJ^P3oV[X00_l0000Booooo`03o`000?oooooooooo01kooooo
0009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00[ooooo0_l00004o`j?0003o`000?l>S`3o3Xl000?o3Xl0
00?o0000o`f?0?l=S`000ol=S`000ol0003o3Hl0o`f?0003o`f?0003o`000?l<SP3o38h000;o38h0
00?o0000o`^>0?l;SP000ol;SP000ol0003o2Hd0o`V=0003o`V=0003o`000?l7S@3o1hd000?o1hd0
00?o0000o`J<0?l6S0000ol6S0000ol0003o18/0o`000002o`000003ojBm0?l0003oY[d000GoY[d0
00?o0000ojRn0?nX_P000onX_P000ol0003oZKh0ojVn0004ojVn0003o`000?n[_P3oZkh000?oZkh0
00?o0000ojbo0?n/_`000on/_`000ol0003o[Kl0ojfo0004ojfo0003o`000?n]_`3o[Kl000;o[Kl0
1_l00003on1f0003o`000?oRL03ohW0000?ohW0000?o0000onAY0?oTJ@001?oTJ@000ol0003oiV80
onIR0004onIR0003o`000?oXG@3oj5d000Coj5d000?o0000onEV0?oUIP000_l00003ooD[0003o`00
0?oSK03ohf`000;ohf`000?o0000onMP0?oWH0000ooWH0000ol0003oiel0o`000002o`0000;oT[P0
00Go0000oiFi0?nE^@3oUKT0o`000003oiNj0007o`000?nJ^P3oV[X0oiZj0?l0003oVk/0o`00000C
ooooo`03o`000?oooooooooo01gooooo0009ooooo`04o`000?ooooooooooo`0000Sooooo0_l00006
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool3o`000003o`j?0?l0003o
3Xl000?o3Xl000?o0000o`j?0?l>S`000ol>S`000ol0003o3Hl0o`f?0003o`f?0003o`000?l=S`3o
3Hl000?o3Hl000?o0000o`b>0?l<SP000_l<SP000ol0003o2hh0o`^>0003o`^>0003o`000?l9S@3o
2Hd000?o2Hd000?o0000o`N=0?l7S@000ol7S@000ol0003o1X`0o`J<0002o`J<00?o00001?nT_@00
0ol0003oY[d0ojJm0004ojJm0003o`000?nX_P3oZ;h000?oZ;h000?o0000ojVn0?nY_P001?nY_P00
0ol0003oZkh0oj^n0003oj^n0003o`000?n/_`3o[;l000?o[;l000?o0000ojfo0?n]_`001?n]_`00
0ol0003o[Kl0o`000002o`000003omil0?l0003o000000Koh7H000?o0000on9`0?oRL0000ooRL000
0ol0003oi6T0onAY0004onAY0003o`000?oVHP3oiV8000CoiV8000?o0000onQM0?oXG@001OoXG@02
o`0000GomB/000Go0000on=/0?oSK03ohf`0o`000005onMP0004o`000?oWG`3oiel0onMO00;o0000
0_nB^0001Ol0003oUKT0oiFi0?nE^@3o000000?oUkX000Go0000oiZj0?nJ^P3oV[X0o`000002oi^k
0003o`000?oooooooooo013ooooo00?o0000ooooooooool07Oooool000[ooooo0_l0000:ooooo`03
o`000?oooooooooo00?ooooo0_l0000@ooooo`03o`000?oooooooooo00?ooooo0_l00004o`j?0003
o`000?l>S`3o3Xl000;o3Xl000?o0000o`j?0?l>S`001?l>S`000ol0003o3Hl0o`f?0002o`f?0003
o`000?l=S`3o3Hl000?o3Hl000?o0000o`b>0?l<SP000_l<SP000ol0003o2hh0o`^>0003o`^>0003
o`000?l9S@3o2Hd000Co2Hd000?o0000o`N=0?l7S@000_l7S@000ol0003o1X`0o`000002o`000003
oj:l0?l0003oY;d000GoY;d000?o0000ojJm0?nV_@000onV_@000ol0003oZ;h0ojRn0004ojRn0003
o`000?nY_P3oZKh000?oZKh000?o0000oj^n0?n[_P000on[_P000ol0003o[;l0ojbo0004ojbo0003
o`000?n]_`3o[Kl000;o[Kl00ol000001_oNO03o0000o`000?l0003ogW`0o`0000Koh7H000?o0000
on9`0?oRL0001?oRL0000ol0003oi6T0onAY0004onAY0003o`000?oVHP3oiV8000?oiV8000?o0000
onQM0?oXG@000ooXG@03o`0000OomB/000Co0000on=/0?oSK03o00001OoWH0002Ol0003oiel0onMO
0?oWG`3o0000oi:h0?l0003oT[P0o`000003oiFi0005o`000?nG^P3oUkX0oiNj0?l000000onJ^P00
1?l0003oVk/0oi^k0?l0000Cooooo`03o`000?oooooooooo01cooooo000Mooooo`;o00004?ooool5
o`000003o`j?0?l0003o3Xl000?o3Xl000?o0000o`j?0?l>S`000_l>S`000ol0003o3Xl0o`j?0004
o`j?0003o`000?l=S`3o3Hl000;o3Hl000?o0000o`f?0?l=S`000ol=S`000ol0003o38h0o`b>0002
o`b>0003o`000?l;SP3o2hh000Co2hh000?o0000o`V=0?l9S@000ol9S@001?l0003o1hd0o`N=0?l7
S@03o`0000CoX[`000?o0000ojBm0?nT_@001?nT_@000ol0003oY[d0ojJm0003ojJm0003o`000?nX
_P3oZ;h000CoZ;h000?o0000ojVn0?nY_P000onY_P000ol0003oZkh0oj^n0004oj^n0003o`000?n/
_`3o[;l000?o[;l000?o0000ojfo0?l000000_l000001?oMPP3o0000o`000?l00004omil0003o`00
0?oPMP3oh7H000Goh7H000?o0000on9`0?oRL0000ooRL0000ol0003oi6T0onAY0004onAY0003o`00
0?oVHP3oiV8000CoiV8000?o0000onQM0?l000000_l00002ooHV0003o`000?oe:`3omB/000GomB/0
00?o0000on=/0?l000001OoWH0002?l0003oiel0onMO0?oWG`3o0000onMP0?l0003oT[P00_l00003
oiFi0005o`000?nG^P3oUkX0oiNj0?l000000onJ^P000ol0003oVk/0oi^k0002o`0001;ooooo0_l0
000Mooooo`007?ooool2o`000003o`1/=Ol0003ooooo00gooooo0ol00004o`j?0003o`000?l>S`3o
3Xl000;o3Xl000?o0000o`j?0?l>S`000ol>S`000ol0003o3Xl0o`j?0003o`j?0003o`000?l=S`3o
3Hl000;o3Hl000?o0000o`f?0?l=S`000ol=S`000ol0003o38h0o`b>0002o`b>0003o`000?l;SP3o
2hh000Co2hh000?o0000o`V=0?l9S@000ol9S@04o`000003oinl0?l0003oX[`000GoX[`000?o0000
ojBm0?nT_@000onT_@000ol0003oY[d0ojJm0004ojJm0003o`000?nX_P3oZ;h000?oZ;h000?o0000
ojVn0?nY_P000onY_P000ol0003oZkh0oj^n0004oj^n0003o`000?n/_`3o[;l000Go000000KogH80
o`000?l0003o0000omf20?l00006omil0003o`000?oPMP3oh7H000Coh7H000?o0000on9`0?oRL000
0ooRL0000ol0003oi6T0onAY0004onAY0004o`000?oVHP3oiV80onIR00Go00001_of9P000ol0003o
mB/0ooD[0004ooD[00;o00001OoWH0000ol0003oiel0onMO0002onMO0003o`000?oWH03oif0000;o
00000onE^@001Ol0003oUkX0oiNj0?nG^P3o000000?oV[X000Co0000oi^k0?nK^`3o00000_nM^`00
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo000Looooo`Co00002oooool3o`00
0003o`j?0?l0003o3Xl000Co3Xl000?o0000o`j?0?l>S`000ol>S`000ol0003o3Xl0o`j?0002o`j?
0003o`000?l>S`3o3Xl000?o3Xl000?o0000o`f?0?l=S`000_l=S`000ol0003o3Hl0o`f?0003o`f?
0003o`000?l<SP3o38h000?o38h000?o0000o`^>0?l;SP000ol;SP000ol0003o2Hd0o`V=0002o`V=
00;o00001?nO_0000ol0003oX[`0oj:l0004oj:l0003o`000?nT_@3oY;d000?oY;d000?o0000ojJm
0?nV_@001?nV_@000ol0003oZ;h0ojRn0003ojRn0003o`000?nY_P3oZKh000CoZKh000?o0000oj^n
0?n[_P000_n[_P04o`0000?ofhP00ol00004omf20003o`000?oNO03ogW`000CogW`000?o0000on1f
0?oPMP001?oPMP000ol0003ohW00on9`0004on9`0004o`000?oTJ@3oi6T0onAY00Ko00000ooc<@00
0ol0003omRH0ooHV0005ooHV0003o`000?oe:`3omB/000?omB/000Co0000ooPQ0?oh8@3o00001?oW
H0001Ol0003oiel0onMO0?oWG`3o000000Coif000_l00002oiFi0005o`000?nG^P3oUkX0oiNj0?l0
00000onJ^P001?l0003oVk/0oi^k0?l00003oifk0003o`000?oooooooooo013ooooo00?o0000oooo
ooooool06_ooool001cooooo00Co0000ooooool0003o06`e0_l00007ooooo`;o00001?l>S`000ol0
003o3Xl0o`j?0003o`j?0003o`000?l>S`3o3Xl000?o3Xl000?o0000o`j?0?l>S`000_l>S`000ol0
003o3Xl0o`j?0003o`j?0003o`000?l=S`3o3Hl000;o3Hl000?o0000o`f?0?l=S`000ol=S`000ol0
003o38h0o`b>0003o`b>0003o`000?l;SP3o2hh000?o2hh000?o0000o`V=0?l000000_l000000onM
^`3o0000oinl0004oinl0003o`000?nR_03oX[`000?oX[`000?o0000ojBm0?nT_@001?nT_@000ol0
003oY[d0ojJm0003ojJm0003o`000?nX_P3oZ;h000?oZ;h000?o0000ojVn0?nY_P001?nY_P000ol0
003oZkh0o`000002o`000004omV=0?l0003ofhP0om^800?o000000?ofhP0o`000?oMPP001OoMPP00
0ol0003ogW`0omil0003omil0003o`000?oPMP3oh7H000Goh7H000?o0000on9`0?oRL0001ol00003
oo0n0003o`000?oc<@3olc4000Colc4000?o0000ooHV0?of9P001Oof9P000ol0003omB/0ooD[0002
o`0000Con24000Co0000onMP0?oWH03o00001?oWG`000ol0003oif00onMP0002onMP0005o`000?nE
^@3o0000oiFi0?l000000onG^P001Ol0003oV[X0oiZj0?nJ^P3o000000;oVk/000Go0000oifk0?nM
^`3oWK/0o`00000Cooooo`03o`000?oooooooooo01Wooooo000Looooo`06o`000?oooooo0000o`1/
=Ol0003o08D90ol000001_oooooo0000o`000?l0003o2Hd0o`0000Co3Xl000?o0000o`j?0?l>S`00
1?l>S`000ol0003o3Xl0o`j?0002o`j?0003o`000?l>S`3o3Xl000;o3Xl000?o0000o`j?0?l>S`00
0ol>S`000ol0003o3Hl0o`f?0002o`f?0003o`000?l=S`3o3Hl000Co3Hl000?o0000o`b>0?l<SP00
0_l<SP000ol0003o2hh0o`^>0002o`^>00?o00001?nM^`000ol0003oWk`0oinl0003oinl0003o`00
0?nR_03oX[`000?oX[`000?o0000ojBm0?nT_@001?nT_@000ol0003oY[d0ojJm0003ojJm0003o`00
0?nX_P3oZ;h000CoZ;h000?o0000ojVn0?nY_P000_nY_P03o`0000CofHd00ol00004om^80003o`00
0?oMPP3ogH8000CogH8000?o0000omil0?oNO0001?oNO0000ol0003oh7H0on1f0003on1f00Co0000
0oo]B@000ol0003ol3h0oo0n0005oo0n0003o`000?oc<@3olc4000Colc4000?o0000ooHV0?of9P00
1?of9P000ol0003omB/0o`000007ooPQ0003o`000?oWH03o000000?oiel000?o0000onMP0?oWH000
0_oWH0001?l0003oif40o`000?nE^@02o`0000?oUkX000Go0000oiZj0?nJ^P3oV[X0o`000002oi^k
0004o`000?nM^`3oWK/0oifk00;o00004_ooool00ol0003oooooooooo`0Iooooo`007?ooool01Ol0
003oooooo`000?l0K3Go000000Co08D900?o0000o`V=0?l9S@000_l9S@000ol0003o3Xl0o`j?0002
o`j?0003o`000?l>S`3o3Xl000Co3Xl000?o0000o`j?0?l>S`000_l>S`000ol0003o3Xl0o`j?0002
o`j?0003o`000?l>S`3o3Xl000?o3Xl000?o0000o`f?0?l=S`000_l=S`000ol0003o3Hl0o`f?0004
o`f?0003o`000?l<SP3o38h000;o38h000?o0000o`^>0?l000000_l000000onJ^P3o0000oifk0005
oifk0003o`000?nO_03oWk`000;oWk`000?o0000oj:l0?nR_0001?nR_0000ol0003oY;d0ojBm0003
ojBm0003o`000?nV_@3oY[d000?oY[d000?o0000ojRn0?nX_P001?nX_P000ol0003oZKh0o`000002
o`000004omNB0?l0003ofHd0omV=00?o000000?ofHd0o`000?oKR0001?oKR0000ol0003ogH80omf2
0005omf20003o`000?oNO03ogW`000?ogW`000?o0000on1f0?oPMP000ol000000ooZE03o0000one9
0005one90003o`000?o`?P3ol3h000Gol3h000?o0000oo<a0?oc<@000ooc<@000ol0003omRH0ooHV
0002ooHV00Co00002?oh8@02o`0000Coiel000Go0000onMP0?oWH03oif00o`000003onMQ00;o0000
0onG^P001Ol0003oV[X0oiZj0?nJ^P3o000000?oVk/000Ko0000oifk0?nM^`3o0000oijk0?l0000C
ooooo`03o`000?oooooooooo01Sooooo000Kooooo`;o000000Coooooo`000?l0K3Go00001?l0Q@T0
0ol0003o2Hd0o`V=0002o`V=0003o`000?l>S`3o3Xl000?o3Xl000?o0000o`j?0?l>S`000ol>S`00
0ol0003o3Xl0o`j?0002o`j?0003o`000?l>S`3o3Xl000;o3Xl000?o0000o`j?0?l>S`000ol>S`00
0ol0003o3Hl0o`f?0003o`f?0003o`000?l=S`3o3Hl000?o3Hl000Co0000o`b>0?l<SP3o38h00ol0
0004oiZj0003o`000?nM^`3oWK/000CoWK/000?o0000oinl0?nO_0000_nO_0000ol0003oX[`0oj:l
0004oj:l0003o`000?nT_@3oY;d000?oY;d000?o0000ojJm0?nV_@001?nV_@000ol0003oZ;h0ojRn
0002ojRn00?o00001OoGTP02o`0000CofHd000?o0000om^80?oKR0001?oKR0000ol0003ogH80omf2
0004omf20004o`000?oNO03ogW`0omil00Go00001OoZE0000ol0003okDT0one90004one90003o`00
0?o`?P3ol3h000Col3h000Co0000oo<a0?oc<@3olc401ol00004ooPN0003o`000?oh8@3on24000;o
n2400ol000000oog8`3o0000onMO0003onMO0005o`000?oWH03oif00onMP0?l000001?oWH@02o`00
00;oUkX000Go0000oiZj0?nJ^P3oV[X0o`000002oi^k0005o`000?nM^`3oWK/0oifk0?l000000_nN
^`000ol0003oooooooooo`0@ooooo`;o00006Oooool001cooooo00?o0000ooooool000000_l0K3D0
1Ol0003o08D9o`252Ol0Q@Wo000000Co2Hd000?o0000o`j?0?l>S`000ol>S`000ol0003o3Xl0o`j?
0003o`j?0003o`000?l>S`3o3Xl000;o3Xl000?o0000o`j?0?l>S`000_l>S`000ol0003o3Xl0o`j?
0003o`j?0003o`000?l=S`3o3Hl000?o3Hl000?o0000o`f?0?l=S`000ol=S`04o`000003oiRj0?l0
003oV[X000GoV[X000?o0000oifk0?nM^`000onM^`000ol0003oWk`0oinl0003oinl0003o`000?nR
_03oX[`000?oX[`000?o0000ojBm0?nT_@000onT_@000ol0003oY[d0ojJm0004ojJm0003o`000?nX
_P3o000000;o000000?oeYL0o`000?oGTP000_oGTP04o`0000KofHd000?o0000om^80?oKR0000ooK
R0000ol0003ogH80omf20003omf200Go00000ooWGP000ol0003ojU@0onYD0005onYD0003o`000?o]
B@3okDT000CokDT000Co0000oo0n0?o`?P3ol3h01_l00004ooD[0003o`000?oh7P3on1h000Gon1h0
00Co0000ooPQ0?l0003o00001Oog8`001?l0003oiel0onMO0?l00003onMP0003o`000?oWH@3oif40
00?oif4000Go0000oiNj0?l0003oUkX0o`000003oiZj0004o`000?nK^`3oVk/0o`0000?oWK/000Co
0000oijk0?nN^`3o00004oooool00ol0003oooooooooo`05ooooo`?o00003oooool001_ooooo00Oo
0000ooooooooooooooooo`000?l0K3Go000000?o08D900?o0000o`V=0?l9S@000ol9S@000ol0003o
3Xl0o`j?0002o`j?0003o`000?l>S`3o3Xl000?o3Xl000?o0000o`j?0?l>S`000_l>S`000ol0003o
3Xl0o`j?0002o`j?0003o`000?l>S`3o3Xl000Co3Xl000?o0000o`f?0?l=S`000_l=S`000ol0003o
3Hl0o`f?0002o`f?00;o00001?nH^P000ol0003oV[X0oiZj0004oiZj0003o`000?nM^`3oWK/000?o
WK/000?o0000oinl0?nO_0000onO_0000ol0003oX[`0oj:l0003oj:l0003o`000?nT_@3oY;d000Co
Y;d000?o0000ojJm0?nV_@001Ol00005omJG00?o00001?oGTP000ol0003ofHd0omV=0003omV=0003
o`000?oKR03ofhP000?ofhP000?o0000omf20?oMPP000ol00002onEW0003o`000?oWGP3oieh000Co
ieh000?o0000onYD0?oZE0001?oZE0000ol0003okDT0one90002one900Ko00000oob>@000ol0003o
mB/0ooD[0005ooD[0003o`000?oh7P3on1h000Con1h00_l00008ooLS0003o`000?oWG`3o000000?o
if0000?o0000onMQ0?oWH@000_oWH@001_l0003oiV40o`000?l0003oUkX0o`0000?oV[X000Co0000
oi^k0?nK^`3o00000onM^`000ol0003oW[/0oijk0002o`0001?ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000kooooo000Kooooo`;o00000_ooool00ol0003o06`eo`00
0003o`252@03o`000?l9S@3o2Hd000?o2Hd000?o0000o`j?0?l>S`000_l>S`000ol0003o3Xl0o`j?
0003o`j?0003o`000?l>S`3o3Xl000;o3Xl000?o0000o`j?0?l>S`000_l>S`000ol0003o3Xl0o`j?
0004o`j?0003o`000?l=S`3o3Hl000;o3Hl000?o0000o`f?0?l000000_l000000onE^@3o0000oiRj
0004oiRj0003o`000?nJ^P3oV[X000?oV[X000?o0000oifk0?nM^`001?nM^`000ol0003oWk`0oinl
0002oinl0003o`000?nR_03oX[`000?oX[`000?o0000ojBm0?nT_@000onT_@04o`0000?oe9`000Co
0000omJG0?oFU`3oeYL01?l00006omNB0003o`000?oIS@3ofHd000?ofHd000Co0000om^80?oKR03o
fhP01Ol00006onEW0003o`000?oWGP3oieh000Coieh000Co0000onYD0?oZE03ojU@01ol00003oni5
0003o`000?ob>@3olST000ColST000?o0000ooD[0?oe:`001Ooe:`000ol0003on1h0ooPN0003o`00
0003ooPQ0?l0003omb<000Oomb<00_l00003onMP0003o`000?oWH@3oif4000;oif4000Co0000onIQ
0?oVH@3oiV400_l00003oiZj0005o`000?nK^`3oVk/0oi^k0?l000000_nM^`001?l0003oW[/0oijk
0?l00002oink0003o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0<ooooo`001oooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00005ooooo`07o`00
0?ooooooooooooooool0003o06`eo`000004o`252@03o`000?l9S@3o2Hd000;o2Hd000?o0000o`j?
0?l>S`000_l>S`000ol0003o3Xl0o`j?0003o`j?0003o`000?l>S`3o3Xl000;o3Xl000?o0000o`j?
0?l>S`000ol>S`000ol0003o3Xl0o`j?0003o`j?0004o`000?l=S`3o3Hl0o`f?00?o00001?nE^@00
0ol0003oV;X0oiRj0003oiRj0003o`000?nJ^P3oV[X000?oV[X000?o0000oifk0?nM^`001?nM^`00
0ol0003oWk`0oinl0002oinl0003o`000?nR_03oX[`000CoX[`000?o0000ojBm0?l000000_l00000
0ooBX@3o0000omBL0005omBL00?o00001?oFU`000ol0003oei80omNB0003omNB0004o`000?oIS@3o
fHd0omV=00Ko00001?oRL0000ol0003oiFL0onEW0005onEW0003o`000?oWGP3oieh000?oieh01?l0
0004on]A0003o`000?o^A@3okTD000CokTD000?o0000oo8i0?ob>@001?ob>@000ol0003omB/0ooD[
0002ooD[00Go00001Ooh8@000ol0003omb<0ooLS0002ooLS00?o000000GomRH0o`000?oWH03oif00
o`000005onMQ0003o`000?oVH@3oiV4000;oiV400_l00002oiZj0005o`000?nK^`3oVk/0oi^k0?l0
00000_nM^`001?l0003oW[/0oijk0?l00003oink0003o`000?oooooooooo013ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0<ooooo`001_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00Oo0000ooooooooooooooooo`000?l0K3Go000000Co08D9
00?o0000o`V=0?l9S@000_l9S@000ol0003o3Xl0o`j?0002o`j?0003o`000?l>S`3o3Xl000?o3Xl0
00?o0000o`j?0?l>S`000ol>S`000ol0003o3Xl0o`j?0002o`j?0003o`000?l>S`3o3Xl000?o3Xl0
1?l000000onB^03o0000oiFi0005oiFi0003o`000?nH^P3oV;X000;oV;X000?o0000oiZj0?nJ^P00
1?nJ^P000ol0003oWK/0oifk0003oifk0003o`000?nO_03oWk`000;oWk`000?o0000oj:l0?nR_000
0onR_003o`0000GodZ4000?o0000omBL0?oDW0001?l00006omJG0003o`000?oGTP3oei8000?oei80
1?l00004on1g0003o`000?oRL03ohW0000CohW0000?o0000onEW0?oUI`001?oUI`000ol0003oieh0
onMN0003o`000003onQK0?l0003oje4000Koje4000?o0000oni50?o^A@001?o^A@001?l0003olST0
oo8i0?ob>@07o`0000Com2h000?o0000ooPQ0?oh8@001?oh8@001?l0003omb<0o`000?l00005ooHV
0003o`000?oWH03o000000Coif4000?o0000onIQ0?oVH@000ooVH@001Ol0003oV[X0o`000?nJ^P3o
000000;oVk/000Go0000oifk0?nM^`3oWK/0o`000002oijk0005o`000?nO^`3oWk/0oink0?l00000
4oooool01?l0003oooooooooooooool4o`0000oooooo0006ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?l0K3Go000000?o
08D900?o0000o`V=0?l9S@000_l9S@000ol0003o3Xl0o`j?0002o`j?0003o`000?l>S`3o3Xl000?o
3Xl000?o0000o`j?0?l>S`000ol>S`000ol0003o3Xl0o`j?0002o`j?0003o`000?l>S`3o3Xl000;o
3Xl00_l00004oi:h0003o`000?nE^@3oUKT000CoUKT000?o0000oiRj0?nH^P000_nH^P000ol0003o
V[X0oiZj0004oiZj0003o`000?nM^`3oWK/000?oWK/000?o0000oinl0?nO_0000onO_0000ol0003o
X[`0o`000002o`000003om6U0?l0003odZ4000GodZ400ol00004omBL0003o`000?oFU`3oeYL000?o
eYL000?o0000omNB0?oGTP000ol000000ooNO`3o0000on1g0006on1g0003o`000?oRL03ohW0000Co
hW0000Co0000onEW0?oUI`3oiFL01Ol00005onQK0003o`000?o[D@3oje4000Goje4000Co0000oni5
0?o^A@3okTD01_l00004oo4k0003o`000?od;P3om2h000Gom2h000Co0000ooPQ0?oh8@3on2401?l0
0007ooHV00;o00001OoWH@000ol0003oiV40onIQ0002onIQ0006o`000?oVHP3o0000o`000?nJ^P3o
00000_nK^`001Ol0003oWK/0oifk0?nM^`3o000000;oW[/000Co0000oink0?nO^`3oWk/00_l0000A
ooooo`?o00000_ooool00ol0003oooooooooo`0@ooooo`001_ooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?l0K3Go000000?o08D900?o0000
o`V=0?l9S@000_l9S@000ol0003o3Xl0o`j?0002o`j?0003o`000?l>S`3o3Xl000Co3Xl000?o0000
o`j?0?l>S`000_l>S`000ol0003o3Xl0o`j?0002o`j?0003o`000?l>S`3o000000;o000000?oSkL0
o`000?nB^0001?nB^0000ol0003oUKT0oiFi0003oiFi0003o`000?nH^P3oV;X000?oV;X000?o0000
oiZj0?nJ^P000onJ^P000ol0003oWK/0oifk0004oifk0003o`000?nO_03oWk`000Co00001OoAY@00
0ol0003odZ40om:Q0003o`000003om:Q0?l0003oe9`000Coe9`000Co0000omJG0?oFU`3oeYL01Ol0
0005omio0003o`000?oPM`3oh7L000Goh7L000Co0000on9`0?oRL03ohW001_l00004onEU0003o`00
0?oXF`3oj5/000Coj5/000?o0000on]A0?o[D@000_o[D@06o`0000CokTP000?o0000oo4k0?oa>`00
1?oa>`000ol0003om2h0oo@^0002oo@^00Ko00000oog9@000ol0003omRH0ooHV0004ooHV0003o`00
0?of:@3o000000Coif4000?o0000onIQ0?oVH@000_oVH@001?l0003oiV80onIR0?oVHP02o`0000?o
Vk/000Co0000oifk0?nM^`3o00000onN^`001?l0003oWk/0oink0?l00002oinl0003o`000?oooooo
oooo013ooooo00?o0000ooooooooool01Ol0000>ooooo`001_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`;o00000ol0
Q@T00ol0003o2Hd0o`V=0002o`V=0003o`000?l>S`3o3Xl000;o3Xl000?o0000o`j?0?l>S`001?l>
S`000ol0003o3Xl0o`j?0002o`j?0003o`000?l>S`3o3Xl000Co00001?n?]`000ol0003oT[P0oi:h
0003oi:h0003o`000?nE^@3oUKT000CoUKT000?o0000oiRj0?nH^P000_nH^P000ol0003oV[X0oiZj
0003oiZj0003o`000?nM^`3oWK/000?oWK/01?l00002olnY0003o`000?oAY@3odJD000CodJD00ol0
0004om:Q0003o`000?oDW03oe9`000?oe9`01?l00004omb50003o`000?oNO`3ogWl000CogWl000?o
0000on1g0?oPM`001?oPM`04o`0000?ohfh000?o0000onEU0?oUI@001OoUI@001?l0003oj5/0onQK
0?oXF`07o`0000Coje<000?o0000oni80?o^B0001?o^B0001?l0003olC/0oo4k0?oa>`07o`0000?o
lc8000?o0000ooLU0?og9@001?og9@001?l0003omRH0ooHV0?of9P02o`0000?omRT000Co0000onMQ
0?oWH@3o00001OoVH@000ol0003oiV80onIR0002onIR00;o00000_nK^`001?l0003oWK/0oifk0?l0
0002oijk0005o`000?nO^`3oWk/0oink0?l000000_nO_0000ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01;ooooo0006ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00Cooooo0_l00003o`252@03o`000?l9S@3o2Hd000;o
2Hd000?o0000o`j?0?l>S`000ol>S`000ol0003o3Xl0o`j?0003o`j?0004o`000?l>S`3o3Xl0o`j?
00Co00000_n<]`000ol0003oSkL0ohng0004ohng0003o`000?nB^03oT[P000;oT[P000?o0000oiFi
0?nE^@001?nE^@000ol0003oV;X0oiRj0002oiRj0003o`000?nJ^P3oV[X000CoV[X000?o0000oifk
0?l000000_l000000oo>[@3o0000olnY0004olnY0004o`000?oAY@3odJD0om6U00;o000000?odJD0
o`000?oBX@001?oBX@000ol0003oe9`0omBL0003o`0000;ofH`000?o0000omb50?oLQ@001?oLQ@00
0ol0003ogWl0omio0004omio0003o`000?oPM`3oh7L000?o000000?oh7H0o`000?oSKP001OoSKP00
0ol0003oiFD0onEU0004onEU00Co00001?oWGP000ol0003oje<0on]C0005on]C0004o`000?o^B03o
kTP0oni800Ko00000oo`?`000ol0003olc80oo<b0005oo<b0003o`000?og9@3ombD000CombD000?o
0000ooHV0?l000001_of:@000ol0003oif40o`000004onIQ0003o`000?oVHP3oiV8000?oiV8000Go
0000oi^k0?l0003oVk/0o`000002oifk0004o`000?nN^`3oW[/0o`0000?oWk/000?o0000oinl0?nO
_0000_l0000Booooo`03o`000?oooooooooo01;ooooo0007ooooo`;o00002Oooool3o`0000Gooooo
0_l00005ooooo`;o00000ol0Q@T00ol0003o2Hd0o`V=0002o`V=0003o`000?l>S`3o3Xl000?o3Xl0
00?o0000o`j?0?l>S`000ol>S`04o`000003ohVf0?l0003oS;L000?oS;L000?o0000ohng0?n?]`00
1?n?]`000ol0003oT[P0oi:h0003oi:h0003o`000?nE^@3oUKT000?oUKT000?o0000oiRj0?nH^P00
0_nH^P000ol0003oV[X0oiZj0003oiZj00?o00001Oo>[@000ol0003ocjT0olnY0003olnY00?o0000
1?oAY@001?l0003odZ40om:Q0?oBX@04o`0000KofH`000?o0000omb50?oLQ@001?oLQ@001?l0003o
gWl0omio0?oNO`05o`0000Goh7H000?o0000on=^0?oSKP001?oSKP000ol0003oiFD0onEU0003o`00
0003onEW0?l0003oieh000Koieh000?o0000on]C0?o[D`001?o[D`04o`0000?okD/000?o0000oo0o
0?o`?`001?o`?`000ol0003olc80oo<b0005oo<b0004o`000?og9@3ombD0ooLU00Co00001oof:@02
o`0000GoiV4000?o0000onIR0?oVHP000_oVHP000ol0003oiV80o`000002o`0000?oWK/000Co0000
oijk0?nN^`3o00000onO^`000ol0003oWk`0o`000002oj2l0003o`000?oooooooooo013ooooo00?o
0000ooooooooool04Oooool001[ooooo00?o0000ooooooooool01Oooool2o`0000;o08D900?o0000
o`V=0?l9S@000ol9S@000ol0003o3Xl0o`j?0002o`j?0003o`000?l>S`3o3Xl000;o3Xl00_l00004
ohVf0003o`000?n<]`3oS;L000?oS;L000?o0000ohng0?n?]`000on?]`000ol0003oT[P0oi:h0003
oi:h0003o`000?nE^@3oUKT000?oUKT000?o0000oiRj0?nH^P000onH^P000ol0003oV[X0o`000002
o`000003olba0?l0003ocZd000GocZd000?o0000olnY0?o?Z@001?l00006om6U00Co00000ooHTP00
0ol0003ofH`0omV<0005omV<0004o`000?oLQ@3og8D0omb500Ko00001?oNO@000ol0003oh7H0on1f
0004on1f0004o`000?oSKP3ohfh0on=^00Go00001OoUI`000ol0003oieh0onMN0005onMN0003o`00
0?o[D`3oje<000?o000000?ojUH0o`000?o]B`001Oo]B`000ol0003ol3l0oo0o0004oo0o0003o`00
0?oc<P3olc8000;olc801_l00004ooHX0003o`000?of:@3omRT000;omRT00_l000000ooe;03o0000
onIQ0003onIQ0003o`000?oVHP3oiV8000;oiV8000Co0000onIR0?oVHP3oiV800_l00002oifk0005
o`000?nN^`3oW[/0oijk0?l000000_nO^`001?l0003oWk`0oinl0?l00003oj2l0003o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool01Oooool2o`00
00?o08D900?o0000o`V=0?l9S@000_l9S@000ol0003o3Xl0o`j?0002o`j?0003o`000?l>S`3o0000
00;o000000?oQKD0o`000?n9]P001?n9]P000ol0003oS;L0ohbg0002ohbg0003o`000?n?]`3oSkL0
00CoSkL000?o0000oi:h0?nB^0000_nB^0000ol0003oUKT0oiFi0004oiFi0003o`000?nH^P3oV;X0
00Co00001Oo</@000ol0003ocZd0olj]0003olj]00?o00001?o?Z@000ol0003odJD0om6U0003o`00
0003omJG0?l0003of98000Gof98000?o0000omV<0?oIS0001?oIS004o`0000?og8D000?o0000omim
0?oNO@001OoNO@001?l0003oh7H0on1f0?oPMP06o`0000CohW0000?o0000onEW0?oUI`001?oUI`00
0ol0003oieh0onMN0002onMN00Go00001OoZEP000ol0003okD/0one;0004one;0004o`000?o`?`3o
l3l0oo0o00Oo00001?ob=@000ol0003omRP0ooHX0004ooHX0004o`000?of:@3o0000o`0000ComB`0
00Co0000onIQ0?oVH@3o00001OoVHP000ol0003oiV80onIR0002onIR00;o000000?oWK/0o`000?nN
^`000_nN^`001?l0003oWk/0oink0?l00002oinl0005o`000?nP_03oX;`0oj2l0?l000004Oooool2
o`0001;ooooo000Jooooo`03o`000?oooooooooo00Kooooo0_l00002o`252@03o`000?l9S@3o2Hd0
00;o2Hd000Co0000o`j?0?l>S`3o3Xl00ol00004ohFe0003o`000?n9]P3oRKH000?oRKH000?o0000
ohbg0?n<]`000_n<]`000ol0003oSkL0ohng0004ohng0003o`000?nB^03oT[P000;oT[P000?o0000
oiFi0?nE^@000onE^@04o`0000;obk@000?o0000olba0?o</@001Oo</@000ol0003ocZd0o`000002
o`000003olj]0?l0003ocjT000;ocjT01Ol00005omJG0003o`000?oHTP3of98000Cof98000?o0000
omV<0?oIS0000ol000000ooJR`3o0000omb50005omb50003o`000?oNO@3ogWd000CogWd01?l00004
on1h0003o`000?oRL03ohW0000CohW0000Co0000onEW0?oUI`3oiFL01ol00004onMP0003o`000?oZ
EP3ojUH000CojUH000Co0000one;0?o]B`3okD/01_l00004onm20003o`000?ob=@3olSD000GolSD0
00Co0000ooHX0?of:03omRP01?l00007ooD/0003o`000?oVH@3o000000CoiV8000?o0000onIR0?oV
HP000ooVHP02o`000005oifk0?l0003oW[/0oijk0?l000000onO^`001?l0003oWk`0oinl0?l00003
oj2l00;o00004_ooool00ol0003oooooooooo`0?ooooo`006Oooool2o`0000Sooooo00?o0000oe2V
0?l000000_l00004o`V=00Co000000?oPK@0o`000?n5]@001On5]@000ol0003oRKH0ohVf0002ohVf
0003o`000?n<]`3oS;L000?oS;L000?o0000ohng0?n?]`000on?]`000ol0003oT[P0oi:h0003oi:h
0003o`000?nE^@3o000000;o000000?obKP0o`000?o;]0001?o;]0000ol0003oc;40olba0003olba
00?o00001?o>[@04o`0000?oe9d000?o0000omJG0?oFU`001OoFU`001?l0003of980omRB0?oHTP05
o`0000GofX/000?o0000omb50?oLQ@001?oLQ@000ol0003ogWd0omim0003o`000003omeo0?l0003o
h7P000Koh7P000Co0000on9`0?oRL03ohW001_l00005onAY0003o`000?oWH03oif0000Coif0000Co
0000onYF0?oZEP3ojUH01_l00004ona>0003o`000?o_@P3okd8000Cokd8000?o0000oo8e0?ob=@00
0_ob=@06o`0000?omB`000?o0000ooD/0?oe;0001Ooe;002o`0000CoiV8000?o0000onIR0?oVHP00
0ooVHP000ol0003oiV<0o`000002o`0000;oW[/000Co0000oink0?nO^`3o00000onO_0001?l0003o
X;`0oj2l0?l00002oinl0003o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool001Wo
oooo00?o0000ooooooooool02?ooool00ol0003oD:H0oe2V0006o`0000CoPK@000?o0000ohFe0?n5
]@001?n5]@000ol0003oRKH0ohVf0003ohVf0003o`000?n<]`3oS;L000;oS;L000?o0000ohng0?n?
]`001?n?]`000ol0003oT[P0oi:h0004o`0000GobKP000?o0000ol^d0?o;]0000oo;]0000ol0003o
c;40o`000002o`0000;oc;4000?o0000olj]0?l000000_l00002om:R0003o`000?oDW@3oe9d000?o
e9d000?o0000omJG0?oFU`001?oFU`04o`0000Cof94000?o0000omZ;0?oJR`001?oJR`001?l0003o
g8D0omb50?oLQ@05o`0000GogGl000?o0000on1h0?oPN0001?oPN004o`0000CohW8000?o0000onAY
0?oTJ@001OoTJ@001?l0003oif00onMP0?oWH006o`0000CojET000?o0000ona>0?o/CP001?o/CP00
1?l0003okd80onm20?o_@P07o`0000?olSP000?o0000ooD/0?oe;0001?oe;0000ol0003omB`0ooD/
0002ooD/00;o00000_od;P001Ol0003oiV80onIR0?oVHP3o000000CoiV8000?o0000onIS0?oVH`00
0ol00002oijk0004o`000?nO^`3oWk/0o`0000;oWk`000Go0000oj2l0?nP_03oX;`0o`000002oinl
0003o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool001Wooooo00?o0000oooooooo
ool02?ooool01?l0003oD:H0oe2V0?l00004ogNa0003o`000?n1]03oPK@000?oPK@000?o0000ohFe
0?n5]@000on5]@000ol0003oRKH0ohVf0003ohVf0003o`000?n<]`3oS;L000;oS;L000?o0000ohng
0?n?]`000on?]`04o`0000;ob;/000?o0000olVh0?o9^0001?o9^0000ol0003obk@0ol^d0002ol^d
00?o00000oo</@04o`0000KodZ8000?o0000omBM0?oDW@000ooDW@000ol0003oeYL0omJG0003o`00
00;oeYL000?o0000omRA0?oHT@001?oHT@001?l0003ofX/0omZ;0?oJR`06o`0000CofhH000?o0000
omeo0?oMO`001?oMO`000ol0003oh7P0on1h0003o`0000;oggX000?o0000on9b0?oRLP001?oRLP00
0ol0003oi6T0onAY0004onAY00Co00000ooVH`000ol0003ojET0onUI0005onUI0004o`000?o/CP3o
k4h0ona>00Ko00000oo^A@000ol0003olSP0oo8h0005oo8h0003o`000?oe;03omB`000ComB`000Co
0000ooD/0?l0003o00001Ood;P000ol0003oiV80o`000005onIR0009o`000?oVH`3oiV<0onIS0?l0
003oW[/0o`000?nN^`3o000000;oWk/000Co0000oinl0?nO_03o00000onP_0000ol0003oWk`0oinl
0002o`0001;ooooo00?o0000ooooooooool03Oooool001Wooooo00?o0000ooooooooool02?ooool0
1Ol0003oD:H0oe2V0?m@YP3o000000CoMk4000?o0000oh6d0?n1]0000_n1]0000ol0003oQKD0ohFe
0004ohFe0003o`000?n9]P3oRKH000;oRKH000?o0000ohbg0?n<]`000on<]`000ol0003oSkL0o`00
0002o`000003olNo0?l0003ob;/000Cob;/000?o0000olVh0?o9^0001?o9^0001?l0003obk@0o`00
0?l00002ol^d00Co00001?o@YP000ol0003odZ80om:R0004om:R0004o`000?oDW@3oe9d0omBM00Co
00001_oFU`000ol0003of940omRA0003omRA00Co00001OoIS@000ol0003ofhH0om^60003om^60004
o`000?oMO`3ogGl0omeo00Go00001_oONP000ol0003ohW80on9b0004on9b0003o`000?oTJ@3oi6T0
00?o000000?ohf`0o`000?oVH`001OoVH`000ol0003ojET0onUI0004onUI00Co00000oo[D0000ol0
003okTD0oni50004oni50003o`000?ob>03olSP000GolSP000Co0000ooD/0?oe;03omB`01?l00007
oo@^00;o00001OoVHP000ol0003oiV<0onIS0002onIS00?o000000GoW[/0o`000?nO^`3oWk/0o`00
0002oinl0007o`000?nP_03oX;`0oj2l0?l0003oWk`0o`000002oink0003o`000?oooooooooo00oo
oooo00?o0000ooooooooool03Oooool001Sooooo0_l0000;ooooo`04o`000?m@YP3oD:H0o`0000Co
Mk4000?o0000oh6d0?n1]0000_n1]0000ol0003oQKD0ohFe0004ohFe0003o`000?n9]P3oRKH000;o
RKH000?o0000ohbg0?n<]`000_n<]`03o`0000Goakl000?o0000olRk0?o8^`000oo8^`000ol0003o
bKP0olVh0002olVh00?o000000Cobk@0o`000?l0003o00000_o?Z`000ol0003od:H0om2V0004om2V
0004o`000?oBXP3odZ80om:R00Ko00001?oDW0000ol0003oeYL0omJG0004omJG0003o`000?oHT@3o
000000;o00000_oGT`000ol0003ofHd0omV=0005omV=0004o`000?oKQP3ofhH0om^600Go00001OoM
P@000ol0003oggX0ommj0004ommj0004o`000?oRLP3ohW80on9b00Go00001OoSK0000ol0003oiV<0
onIS0004onIS0003o`000?oYF@3ojET000?o000000?oj5/0o`000?o[D0001Oo[D0000ol0003okTD0
oni50004oni50003o`000?ob>03olSP000;olSP01_l00004oo@^0003o`000?od;P3om2h000;om2h0
0_l000000ood<03o0000onIR0003onIR0003o`000?oVH`3oiV<000;oiV<000?o0000onIS0?oVH`00
0_l00002oink0005o`000?nO_03oWk`0oinl0?l000000onP_0000ol0003oWk`0o`000003oink0003
o`000?oooooooooo00kooooo0_l0000>ooooo`006Oooool00ol0003oooooooooo`09ooooo`04o`00
0?m@YP3oD:H0o`0000CoMk4000?o0000oh6d0?n1]0000on1]0000ol0003oQKD0ohFe0003ohFe0003
o`000?n9]P3oRKH000?oRKH01?l000000oo5`P3o0000olNo0005olNo0003o`000?o8^`3ob;/000Co
b;/02?l00006oln[0003o`000?o@YP3od:H000?od:H01?l00004om:R0003o`000?oDW03oe9`000Co
e9`000Co0000omJG0?oFU`3oeYL01?l00006omNC0003o`000?oIS@3ofHd000CofHd01?l00004om^8
0003o`000?oMP@3ogH4000CogH4000Co0000ommj0?oONP3oggX01_l00004on5d0003o`000?oSK03o
hf`000Cohf`000Co0000onIS0?oVH`3oiV<01Ol00005onQK0003o`000?o[D03oje0000Coje0000Co
0000oni50?o^A@3okTD01ol00003oo4j0003o`000?od;P3om2h000Gom2h000Co0000oo@^0?l0003o
00001?od<0001Ol0003oiV80onIR0?oVHP3o000000?oiV<000?o0000onIS0?oVH`000_oVH`02o`00
0003oink0?l0003oWk`000;oWk`000Co0000oj2l0?nP_03o00000_nO_0001Ol0003oWk/0oink0?nO
^`3o000001;ooooo00?o0000ooooooooool02oooool001Sooooo00?o0000ooooooooool02_ooool0
1Ol0003oD:H0oe2V0?m@YP3o000000CoMk4000?o0000oh6d0?n1]0000_n1]0000ol0003oQKD0ohFe
0004ohFe0003o`000?n9]P3oRKH000?o00001Oo5`P000ol0003oakl0olNo0004olNo0004o`000?o8
^`3ob;/0olRk00Ko00001?o=[`000ol0003ocj/0oln[0004oln[0003o`000?o@YP3o000000;o0000
0_o@YP000ol0003odZ80om:R0004om:R0004o`000?oDW03oe9`0omBL00Ko00001?oEV0000ol0003o
ei<0omNC0004omNC0003o`000?oIS@3ofHd000?o000000?ofHh0o`000?oKR0001_oKR0001?l0003o
gH40omf10?oMP@06o`0000CogW`000?o0000on5d0?oQM0001?oQM0001?l0003ohf`0on=/0?oSK006
o`0000CoiVD000?o0000onQK0?oXF`001?oXF`001?l0003oje00on]@0?o[D006o`0000CokTL000?o
0000oo4j0?oa>P001?oa>P000ol0003om2h0oo@^0002oo@^00Co00001ood<0000ol0003oiV80o`00
0004onIS0003o`000?oVH`3oiV<000;oiV<000Co0000oink0?l0003o00000_nO_0001Ol0003oX;`0
oj2l0?nP_03o000000;oWk`000Co0000oink0?nO^`3oWk/00_l0000Aooooo`03o`000?oooooooooo
00_ooooo000Hooooo`;o00003?ooool2o`000003oe2V0?l0003oMk4000?oMk4000?o0000oh6d0?n1
]0000_n1]0000ol0003oQKD0ohFe0003ohFe00Co00000_o3a0000ol0003oaL80olG20004olG20003
o`000?o7_`3oakl000?oakl01_l00002olbc0003o`000?o=[`3ocJl000CocJl000Co0000oln[0?o?
Z`3ocj/01?l00006om2V0003o`000?oBXP3odZ8000?odZ801?l00004om>N0003o`000?oEV03oeIP0
00CoeIP000Co0000omNC0?oGT`3oei<01Ol00005omV>0003o`000?oKR03ofhP000CofhP01?l00003
omb30003o`000?oNO03ogW`000GogW`000Co0000on5d0?oQM03ohG@01_l00004on=^0003o`000?oV
I@3oiVD000CoiVD000Co0000onQK0?oXF`3oj5/01_l00004on]B0003o`000?o^A`3okTL000CokTL0
00Co0000oo4j0?oa>P3olCX01ol00003oo@`0003o`000?od<03om30000Gom3000_l00004onIS0003
o`000?oVH`3oiV<000;oiV<000?o0000onIS0?l000000_l00002oinl0005o`000?nP_03oX;`0oj2l
0?l000000_nO_0001?l0003oWk/0oink0?l00002oijk0003o`000?oooooooooo00oooooo00?o0000
ooooooooool02_ooool000Gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005oooo
o`03o`000?oooooooooo00_ooooo00Co0000ogRa0?l0003o00001?mg/@000ol0003oPK@0oh6d0003
oh6d0003o`000?n5]@3o000000;o000000?o_L<0o`000?o3a0001?o3a0000ol0003oaL80olG20004
olG20003o`000?o7_`3oakl000Go00001_o</`000ol0003ocJl0olf_0003olf_00Co00001?o?Z`00
0ol0003od:H0om2V0004om2V0003o`000?oBXP3o000000;o00000_oBX`000ol0003odih0om>N0004
om>N0004o`000?oEV03oeIP0omFH00Ko00001?oGU0000ol0003ofHh0omV>0004omV>0003o`000?oK
R03ofhP000?o000000?ofXX0o`000?oLP`001OoLP`000ol0003ogW`0omil0004omil00Co00001?oQ
MP000ol0003ohfh0on=^0004on=^0004o`000?oVI@3oiVD0onIU00Ko00001?oXG@000ol0003oje80
on]B0004on]B0004o`000?o^A`3okTL0oni700Ko00000ooa?0000ol0003om300oo@`0005oo@`0003
o`000?od<03om30000;om3000_l00002oo<b0005o`000?oVH`3oiV<0onIS0?l000000ooVH`000ol0
003oiV<0onIS0003o`0000;oWk`000Oo0000oj2l0?nP_03oX;`0o`000?nO_03o000000?oWk/000Co
0000oijk0?nN^`3o00004_ooool00ol0003oooooooooo`09ooooo`001?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0<ooooo`04
o`000?mh/@3o0000o`0000CoMk4000?o0000oh6d0?n1]0001?l00005okg30003o`000?o3a03o`l@0
00?o`l@000?o0000olG20?o5`P000oo5`P04o`0000Cob[L000?o0000olbc0?o</`001?o</`000ol0
003ocJl0o`000002o`0000;ocJl000?o0000oln[0?o?Z`001?o?Z`001?l0003od:H0om2V0?o@YP04
o`0000KodZ<000?o0000om>N0?oCWP000ooCWP04o`0000GoeIX000?o0000omND0?oGU0000ooGU000
1?l0003ofHh0omV>0?oISP05o`0000GofXX000?o0000omb30?oLP`001?oLP`000ol0003ogW`0omil
0003o`000003omim0?l0003ohGH000KohGH000Co0000on=^0?oSKP3ohfh01_l00003onEV0003o`00
0?oXG@3oj5d000Goj5d000Co0000on]B0?o[DP3oje801_l00003one90003o`000?oa?03olC`000Co
lC`000?o0000oo@`0?od<0001Ood<0001?l0003om300o`000?l00005oo<b0003o`000?oVH`3o0000
00CoiV<000Wo0000onIS0?oVH`3oiV<0o`000?nO_03o0000oinl0?l000000onP_0000ol0003oWk`0
o`000003oink0003o`000?nN^`3oW[/000;o00004Oooool2o`0000[ooooo0004ooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?mh/@3o000000Oo00000ong`@000ol0003o_L<0okg30004okg30003o`000?o3a03o`l@000?o`l@0
00?o0000olG20?l000000_l00002olRk0003o`000?o:]`3ob[L000Cob[L000Co0000olbc0?o</`3o
c;<01?l00006olf_0003o`000?o?Z`3ocj/000?ocj/01?l00004om2W0003o`000?oBX`3odZ<000Co
dZ<000?o0000om>N0?l000000_l00002om>O0003o`000?oEVP3oeIX000GoeIX000Co0000omND0?oG
U03oei@01Ol00004omR@0003o`000?oJRP3ofXX000CofXX000Co0000omb30?oLP`3og8<01Ol00005
omim0003o`000?oQMP3ohGH000CohGH01?l00003on=_0003o`000?oUIP3oiFH000CoiFH000?o0000
onQM0?oXG@001?oXG@04o`0000?ojU@000?o0000one90?o]B@001?o]B@000ol0003olC`0oo4l0004
oo4l0003o`000?od<03om30000;om3001?l00007oo<b00;o00001?oVH`000ol0003oiV<0onIS0002
onIS00?o000000GoWk`0o`000?nP_03oX;`0o`000002oinl0007o`000?nO^`3oWk/0oink0?l0003o
W[/0o`000002oifk0003o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool000Cooooo
00Co0000oooooooooooo00002Oooool2o`0000Cooooo0_l0000@ooooo`;o00001?nX_P000ol0003o
]l40okO10004okO10003o`000?nm``3o_L<000?o_L<000Co0000ol?40?o3a03o`l@01?l00006olRk
0003o`000?o:]`3ob[L000?ob[L01?l00004ol^c0003o`000?o=[`3ocJl000CocJl000?o0000oln[
0?l000000_l00002olj/0003o`000?o@Y`3od:L000Cod:L000Co0000om:S0?oBX`3odZ<01?l00006
om>O0003o`000?oEVP3oeIX000CoeIX01?l00004omJF0003o`000?oHT03of90000?of90000Co0000
omZ:0?oJRP3ofXX01_l00004omb40003o`000?oNO@3ogWd000CogWd000?o0000on5f0?oQMP000ol0
00000ooPM`3o0000on=_0005on=_0003o`000?oUIP3oiFH000CoiFH000?o0000onQM0?oXG@000ol0
00000ooWGP3o0000onYD0005onYD0003o`000?o]B@3okDT000CokDT000Co0000oo4l0?oa?03olC`0
1ol00003oo<b0003o`000?oc<P3olc8000;olc800ol000000ooc<`3o0000onIS0002onIS0003o`00
0?oVH`3oiV<000;oiV<000?o0000onIS0?oVH`000_l00003oj2l0004o`000?nO_03oWk`0o`0000;o
Wk/000Co0000oijk0?nN^`3o00000_nM^`02o`0000oooooo0ol00009ooooo`001?ooool01?l0003o
ooooooooool0000;ooooo`05o`000?ooooooooooooooool000004_ooool2o`0000CoZ;h000?o0000
okO10?ng`@001?ng`@001?l0003o_L<0okg30?nm``07o`0000;oakl000?o0000olRk0?o8^`001?o8
^`000ol0003ob[L0o`000002o`0000?ob[L000?o0000ol^c0?o;/`000oo;/`001?l0003ocJl0olf_
0?o=[`04o`0000KocZ`000?o0000om2W0?o@Y`000oo@Y`04o`0000CodJ@000?o0000om>O0?oCW`00
1?oCW`000ol0003oeIX0omFJ0003o`000003omBK0?l0003oeYH000KoeYH000Co0000omR@0?oHT03o
f9001Ol00004omZ;0003o`000?oLQ03og8@000Cog8@000Co0000omim0?oNO@3ogWd01Ol00005on1g
0003o`000?oSK`3ohfl000Cohfl000Co0000onEV0?oUIP3oiFH01Ol00005onMN0003o`000?oZE03o
jU@000CojU@000Co0000one90?o]B@3okDT01_l00004oo0n0003o`000?oc<P3olc8000Colc8000Co
0000oo<b0?l0003o00001Ooc<`001?l0003oiV<0onIS0?l00003onIS0003o`000?oVH`3oiV<000;o
iV<00_l00002oj2l0004o`000?nO_03oWk`0o`0000;oWk/000Co0000oijk0?nN^`3o00000_nM^`00
0ol0003oW;/0o`00000;ooooo`?o00000_ooool00ol0003oooooooooo`07ooooo`001?ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Aooooo`;o00001?nX_P000ol0003o]l40okO10003okO100Co000000?oaL80o`000?l000000_l0
0005olNo0004o`000?o8^`3ob;/0olRk00Go00001_o:]`001?l0003obk<0ol^c0?o;/`05o`0000Co
cK0000?o0000olj/0?o>[0001?o>[0000ol0003od:L0o`000002o`0000;ocjT000?o0000om6T0?oA
Y0001?oAY0001?l0003odil0om>O0?oCW`05o`0000Goe9/000?o0000omJF0?oFUP001?oFUP04o`00
00Cof94000?o0000omZ;0?oJR`000ooJR`001?l0003og8@0omb40?oLQ006o`0000CogWl000?o0000
on1g0?oPM`001?oPM`001?l0003ohfl0on=_0?oSK`06o`0000CoiFP000?o0000onMN0?oWGP001?oW
GP001?l0003ojU@0onYD0?oZE006o`0000CokDX000?o0000oo0n0?o`?P001?o`?P001?l0003olc80
oo<b0?oc<P04o`0000Oolc<000?o0000onIS0?l000001?oVH`000ol0003oiV<0onIS0002onIS0007
o`000?nP_03o0000oj2l0?l0003oWk`0o`000003oink0006o`000?nN^`3oW[/0o`000?nM^`3o0000
0onL^`000ol0003oooooooooo`05ooooo`?o00001Oooool00ol0003oooooooooo`07ooooo`001Ooo
ool2o`0000Wooooo0ol00004ooooo`03o`000?oooooooooo01;ooooo0_l00004ojRn0003o`000?ng
`@3o000000;o00000_o1a003o`0000CoaL8000Co0000olNo0?o7_`3oakl01Ol00005olRk0003o`00
0?o:]`3ob[L000?ob[L01?l00004ol^d0003o`000?o=/03ocK0000?ocK0000Co0000olj/0?o>[03o
cZ`01?l00006olnY0003o`000?oAY03odJ@000?odJ@01?l00004om:P0003o`000?oDV`3oe9/000Co
e9/000?o0000omJF0?oFUP000ol000000ooFU`3o0000omRA0006omRA0004o`000?oJR`3ofX/0omZ;
00Go00001?oKQP000ol0003ogWl0omio0004omio0004o`000?oPM`3oh7L0on1g00Ko00001?oRL000
0ol0003oiFP0onEX0004onEX0004o`000?oWGP3oieh0onMN00Ko00001?oZE@000ol0003okDX0one:
0004one:0004o`000?o`?P3ol3h0oo0n00Ko00000ooc<`000ol0003olc<0oo<c0005oo<c00;o0000
1?oVH`000ol0003oiV<0onIS0002onIS0008o`000?oVI03o0000o`000?nP_03o0000oinl0?l00002
oink0007o`000?nN^`3oW[/0oijk0?l0003oWK/0o`000003oibk0004o`000?ooooooooooooooo`Co
00002?ooool00ol0003oooooooooo`07ooooo`005oooool2o`0001Cooooo2?l000001_o1a03o0000
o`000?l0003o`L@0o`0000GoaL801?l00004olNo0003o`000?o8^`3ob;/000Cob;/000?o0000olZg
0?l000000_l000000oo9^03o0000ol^d0006ol^d0004o`000?o=/03ocK00olf`00Go00001?o>[@00
0ol0003ocjT0olnY0004olnY0003o`000?oAY03o000000;o00000ooAY@000ol0003odZ00om:P0003
om:P0004o`000?oDV`3oe9/0omBK00Go00001OoFU`000ol0003of940omRA0004omRA00Co00000_oI
S0000ol0003ofhH0om^60005om^60004o`000?oNO`3ogWl0omio00Ko00001?oPN0000ol0003ohW00
on9`0004on9`0004o`000?oUJ03oiFP0onEX00Ko00001?oWG`000ol0003ojUD0onYE0004onYE0004
o`000?o]BP3okDX0one:00Ko00000oo`?`000ol0003olc<0oo<c0004oo<c0003o`000?oc<`3olc<0
00;olc<00_l00002oo<d0005o`000?oVH`3oiV<0onIS0?l000000ooVH`001?l0003oiV@0onIT0?oV
I002o`0000;oWk`000Co0000oink0?nO^`3o00000_nN^`001?l0003oWK/0oifk0?l00003oibk00Co
00003Oooool00ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`0Eooooo`;o0000
0_nb`003o`0000Go`L@000?o0000olG20?l000000_l00002olG20003o`000?o7_`3oakl000Coakl0
00Co0000olRk0?o8^`3ob;/01?l00005olVh0003o`000?o;]03obk@000Cobk@01?l00004olba0003
o`000?o>[@3ocZd000?ocZd000Co0000olnY0?o?Z@3ocjT01?l00007om6U0004o`000?oBX03odZ00
om:P00Go00001?oDW0000ol0003oeYL0omJG0004omJG0003o`000?oHT@3of94000?o000000?oei80
o`000?oIS0001?oIS0000ol0003ofhH0om^60004om^600Co00001?oMP0000ol0003oh7P0on1h0004
on1h0004o`000?oRL03ohW00on9`00Ko00001?oTJ@000ol0003oiel0onMO0004onMO0004o`000?oZ
E@3ojUD0onYE00Ko00000oo]B`000ol0003ol3l0oo0o0004oo0o0003o`000?oc<`3olc<000Colc<0
00Co0000oo<c0?l0003o00001Ooc=0000ol0003oiV<0o`000004onIS0003o`000?oVI03oiV@000;o
iV@00_l000001OnO_03o0000oink0?nO^`3o000000;oW[/000Co0000oifk0?nM^`3o00000_nL^`00
1?l0003oV[X0oiZj0?l0000>ooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooo
oooo01Kooooo0ol00003ok;00004o`000?o1a03o`L@0ol7400Co00001Oo5`P000ol0003oakl0olNo
0003olNo00Co00001?o8_0000ol0003obKP0olVh0003olVh0003o`000?o;]03obk@000?o000000?o
bkH0o`000?o</@001_o</@001?l0003ocZd0olj]0?o>[@05o`0000CocjX000?o0000om6U0?oAY@00
1?oAY@04o`0000CodZ4000?o0000omBL0?oDW0000ooDW0001?l0003oeYL0omJG0?oFU`05o`0000Go
ei8000?o0000omV<0?oIS0000ooIS0000ol0003ofhH0om^60003o`000003om^70?l0003ogH0000Ko
gH0000Co0000on1h0?oPN03oh7P01_l00004on9a0003o`000?oTJ@3oi6T000Coi6T000Co0000onMO
0?oWG`3oiel01_l00003onUF0003o`000?o]B`3okD/000CokD/000?o0000oo0o0?o`?`001?o`?`00
1?l0003olc<0oo<c0?oc<`04o`0000Oolc@00_l00004onIS0003o`000?oVI03oiV@000?oiV@000Co
0000oinl0?l0003o00000_nO^`001?l0003oW[/0oijk0?l00002oifk0004o`000?nL^`3oW;/0o`00
00;oV[X000?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`005oooool00ol0003o
ooooooooo`0Cooooo`?o000000?oooooo`000?l000001ol00004ol740003o`000?o5`P3oaL8000?o
aL8000?o0000olNo0?l000000_l00002olK00003o`000?o8_03ob;`000Cob;`000Co0000olVh0?o9
^03obKP01?l00005ol^f0003o`000?o</@3oc;4000Coc;401?l00004olf^0003o`000?o?ZP3ocjX0
00?ocjX000?o0000om6U0?oAY@000ol000000oo@YP3o0000om:Q0006om:Q0004o`000?oDW03oe9`0
omBL00Go00001?oFV0000ol0003oei80omNB0004omNB0004o`000?oIS03ofH`0omV<00Co00001OoK
Q`000ol0003ogH00omf00004omf000Co00000ooON@000ol0003ohW40on9a0005on9a0004o`000?oT
J@3oi6T0onAY00Ko00000ooWH@000ol0003ojEH0onUF0004onUF0003o`000?o]B`3okD/000CokD/0
00Co0000oo0o0?o`?`3ol3l01_l00004oo<d0003o`000?oc=03olc@000;olc@00_l000000ooc=03o
0000onIS0002onIS0003o`000?oVI03oiV@000?oiV@000Co0000onIT0?l0003o00000_nO^`001ol0
003oW[/0oijk0?nN^`3o0000oifk0?l000000onL^`000ol0003oV[X0oiZj0002o`0000gooooo00?o
0000ooooooooool01_ooool001Kooooo00?o0000ooooooooool04_ooool2o`0000Kooooo00?o0000
ok700?na`0000ona`0000ol0003o`L@0ol740003ol740004o`000?o5`P3oaL80olG200Co00001Oo6
`0000ol0003ob;`0olRl0003olRl00Co00001?o9^@000ol0003obkH0ol^f0003ol^f0003o`000?o<
/@3oc;4000?o00000_o</P000ol0003ocJh0olf^0004olf^0004o`000?o?ZP3ocjX0olnZ00Co0000
1Oo@YP000ol0003odZ40om:Q0004om:Q00Co00000ooCW@000ol0003oeYP0omJH0004omJH0004o`00
0?oGTP3oei80omNB00Ko00001?oIS@000ol0003ofhL0om^70003om^70003o`000?oMP03ogH0000?o
000000?ogH40o`000?oON@001OoON@000ol0003ohW40on9a0004on9a00Co00000ooTJP000ol0003o
if40onMQ0004onMQ0003o`000?oYEP3ojEH000CojEH000Co0000one;0?o]B`3okD/01_l00004oo10
0003o`000?oc=03olc@000Colc@000Co0000oo<d0?l0003o00001?oc=0001?l0003oiV<0onIS0?l0
0004onIT0004o`000?oVI03oiV@0onIT00;o000000?oWk/0o`000?nN^`000_nN^`000ol0003oWK/0
o`000003oibk0003o`000?nJ^P3o000000;oV;X000?o0000ooooooooool02Oooool2o`0000Sooooo
000Fooooo`03o`000?oooooooooo00oooooo0ol00009ooooo`03o`000?na`03o/L0000?o/L0000Co
0000ol740?o1a03o`L@01Ol00004olG30003o`000?o6`03oa/0000?oa/0000?o0000olRl0?l00000
0_l00003olNm0003o`000?o9^@3obKT000?obKT000Co0000ol^f0?o;]P3obkH01?l00006olbb0004
o`000?o=[P3ocJh0olf^00Ko00001?o?Z`000ol0003od:H0om2V0003om2V0003o`000?oBX@3odZ40
00?o000000?odZ80o`000?oCW@001OoCW@001?l0003oeYP0omJH0?oFV006o`0000Coei<000?o0000
omV=0?oIS@001?oIS@001?l0003ofhL0om^70?oKQ`04o`0000GogH4000?o0000ommi0?oON@001?oO
N@000ol0003ohW40on9a0003o`000003on9b0?l0003oi6X000Goi6X000?o0000onMQ0?oWH@001?oW
H@001?l0003ojEH0onUF0?oYEP06o`0000?ok4`000?o0000oo100?o`@0001Oo`@0001?l0003olc@0
oo<d0?oc=004o`0000Kolc@000?o0000onIS0?l000001?oVI0000ol0003oiV@0onIT0002onIT0004
o`000?nO^`3o0000o`0000;oW[/000Co0000oifk0?nM^`3o00000onL^`000ol0003oV[X0o`000002
oiRj0003o`000?oooooooooo00Wooooo0_l00008ooooo`005_ooool00ol0003oooooooooo`0<oooo
o`?o00003Oooool01?l0003o/L00ok700?na`005o`0000?o_l<000?o0000olG30?o5``001?o5``00
1?l0003oa/00olK00?o6`003o`0000Ooakd000Co0000olVi0?o9^@3obKT01Ol00004olZg0003o`00
0?o</P3oc;8000?oc;801?l00004olf_0003o`000?o?Z`3ocj/000Cocj/000Co0000om2V0?o@YP3o
d:H01?l00005om:R0003o`000?oCW@3odid000?odid01?l00004omFI0003o`000?oGT`3oei<000Co
ei<000Co0000omV=0?oIS@3ofHd01_l00003om^70003o`000?oMP@3ogH4000CogH4000Co0000ommi
0?oON@3oggT01Ol00005on9b0003o`000?oTJP3oi6X000Coi6X000Co0000onMQ0?oWH@3oif401_l0
0003onUG0003o`000?o/C03ok4`000Cok4`000?o0000oo100?o`@0000_o`@006o`0000?olSD000?o
0000oo<d0?oc=0001?oc=002o`0000GoiV@000Ko0000onIT0?oVI03oiV@0o`000?oVH`03o`0000;o
W[/000Co0000oifk0?nM^`3o00000_nL^`001?l0003oV[X0oiZj0?l00002oiRj00;o00002Oooool0
0ol0003o05a7o`000008ooooo`005Oooool2o`0000_ooooo0ol0000Aooooo`?o00000on__`000ol0
003o_l<0oko30003oko30004o`000?o5``3oaL<0olG300Ko00000oo6`@000ol0003oakd0olNm0004
olNm00Co00001?o9^P000ol0003ob[L0olZg0003olZg0003o`000?o</P3o000000;o00000_o</`00
0ol0003ocJl0olf_0004olf_0004o`000?o?Z`3ocj/0oln[00Ko00000oo@Y`000ol0003odZ80om:R
0004om:R0003o`000?oCW@3o000000;o00000_oCWP000ol0003oeIT0omFI0004omFI0004o`000?oG
T`3oei<0omNC00Ko00001?oISP000ol0003ofhL0om^70003om^70004o`000?oMP@3ogH40omf100Ko
00001?oONP000ol0003ohW80on9b0004on9b0004o`000?oTJP3oi6X0onAZ00Ko00000ooVH@000ol0
003ojEL0onUG0004onUG0004o`000?o/C03ok4`0ona<00Oo00000oo_@@000ol0003olSD0oo8e0004
oo8e0003o`000?oc=03olc@000?o00000_oc=0001Ol0003oiV@0onIT0?oVI03o000000CoiV@000?o
0000onIS0?l000000_l00002oijk0004o`000?nM^`3oWK/0o`0000;oW;/000Ko0000oiZj0?nJ^P3o
0000oiRj0?l00002oiJi0003o`000?oooooooooo00Kooooo00Co0000o`1LAol0003o00001oooool0
01Kooooo00?o0000ooooooooool01_ooool3o`0001Gooooo00?o0000ojno0?n__`000on__`001?l0
003o_l<0oko30?no``05o`0000CoaL@000?o0000olK10?o6`@000oo6`@000ol0003oakd0olNm0003
o`000003olNn0?l0003obKX000KobKX000Co0000olZg0?o:]`3ob[L00ol00006olbc0003o`000?o=
[`3ocJl000?ocJl01?l00004olj/0003o`000?o@Y`3od:L000?od:L000Co0000om:R0?oBXP3odZ80
1?l00006om>N0003o`000?oEV@3oeIT000?oeIT01?l00004omND0003o`000?oISP3ofHh000CofHh0
00Co0000om^70?oKQ`3ofhL01Ol00004omf10003o`000?oONP3oggX000CoggX000Co0000on9b0?oR
LP3ohW801_l00003onA[0003o`000?oVH@3oiV4000CoiV4000Co0000onUG0?oYE`3ojEL01_l00004
ona=0003o`000?o_@@3okd4000Cokd4000Co0000oo8e0?ob=@3olSD01Ol00006oo<d0003o`000?oV
I03o000000CoiV@000_o0000onIS0?oVH`3oiV<0o`000?nN^`3o0000oijk0?l0003oWK/0o`000003
oibk0006o`000?nJ^P3oV[X0o`000?nH^P3o00000_nF^@000ol0003oooooooooo`06ooooo`04o`00
0?l0G4Oo0000o`0000Oooooo000Fooooo`03o`000?oooooooooo00?ooooo0ol0000Iooooo`04o`00
0?n__`3o[kl0ojno00Go00001?nn``000ol0003oaL@0olG40003olG40004o`000?o6`@3oa/40olK1
00Co00001Oo7_P000ol0003obKX0olVj0004olVj00Co00000oo:]`000ol0003oc;<0olbc0004olbc
0003o`000?o=[`3o000000;o000000?ocK00o`000?o>[0001_o>[0001?l0003od:L0om2W0?o@Y`05
o`0000CodJ<000?o0000om>N0?oCWP001?oCWP000ol0003oeIT0o`000002o`000003omFI0?l0003o
ei@000Koei@000Co0000omV>0?oISP3ofHh01_l00003om^80003o`000?oMP@3ogH4000CogH4000Co
0000ommj0?oONP3oggX01_l00004on5c0003o`000?oTJ`3oi6/000?oi6/000Co0000onIQ0?oVH@3o
iV401_l00004onUH0003o`000?o/C@3ok4d000Cok4d000Co0000onm10?o_@@3okd401_l00003oo8e
0003o`000?oc=03olc@000Golc@00_l00004onIT0003o`000?oVH`3oiV<000;oiV<00_l000001OnN
^`3o0000o`000?nM^`3o000000?oW;/000?o0000oiZj0?l000000_nH^P000ol0003oU[T0oiJi0002
o`0000Kooooo00?o0000o`1LAol0G4L00_l00007ooooo`005Oooool01?l0003oooooooooooooool3
o`0001gooooo0ol00003ojjo0003o`000?nn``3o_/<000Co_/<000Co0000olG40?o5a03oaL@01Ol0
0004olK20003o`000?o7_P3oakh000?oakh000?o0000olVj0?o9^P000ol00002olRk0003o`000?o:
]`3ob[L000?ob[L000Co0000olbc0?o</`3oc;<01?l00005olf`0003o`000?o>[03ocZ`000CocZ`0
1?l00004om2X0003o`000?oAX`3odJ<000?odJ<000Co0000om>N0?oCWP3odih01?l00005omFI0003
o`000?oGU03oei@000Coei@01?l00004omV?0003o`000?oKR03ofhP000?ofhP000Co0000omf10?oM
P@3ogH401_l00004ommk0003o`000?oQL`3ohG<000CohG<000Co0000onA[0?oTJ`3oi6/01Ol00004
onIR0003o`000?oYF03ojEP000CojEP000Co0000ona=0?o/C@3ok4d01_l00003onm10003o`000?ob
=@3olSD000ColSD000?o0000oo<d0?oc=0000_oc=002o`000003oo<d0?l0003oiV@000?oiV@000Go
0000onIS0?oVH`3oiV<0o`000002onIS00;o00000_nM^`001ol0003oW;/0oibk0?nL^`3o0000oiZj
0?l000000_nH^P000ol0003oU[T0o`000002oi>h0003o`000?oooooooooo00?ooooo00?o0000o`1L
Aol0G4L00_l00007ooooo`005Oooool4o`0002;ooooo00?o0000ojjo0?n^_`000_n^_`000ol0003o
_/<0okk30003okk300Co00001?o4a0000ol0003oa/80olK20003olK20004o`000?o7_P3oakh0olNn
00Co00001_o8^`001?l0003ob[L0olZg0?o:]`05o`0000Cobk@000?o0000olf`0?o=/0000oo=/000
0ol0003ocZ`0olj/0003o`0000;ocZ`000?o0000om2X0?o@Z0001?o@Z0001?l0003odJ<0om6S0?oA
X`05o`0000Codil000?o0000omFI0?oEV@000ooEV@000ol0003oei@0omND0003o`000003omND0?l0
003ofHl000KofHl000Co0000om^80?oKR03ofhP01Ol00004omf20003o`000?oON`3ogg/000Cogg/0
00Co0000on5c0?oQL`3ohG<01_l00003onA[0003o`000?oVHP3oiV8000CoiV8000Co0000onUH0?oY
F03ojEP01_l00003ona=0003o`000?o_@@3okd4000Cokd4000?o0000oo8e0?ob=@001?ob=@001?l0
003olc@0o`000?l00004oo<d0004o`000?oVI03oiV@0o`0000?oiV<000?o0000onIS0?oVH`000_oV
H`02o`000005oifk0?l0003oW;/0oibk0?l000000_nJ^P001_l0003oV;X0oiRj0?l0003oU[T0o`00
00;oTkP000?o0000ooooooooool00_ooool01?l0003o05a7o`1LAol0G4L2o`0000Oooooo0002oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool2o`0002Gooooo00?o0000ojjo
0?n^_`000_n^_`000ol0003o_/<0o`000002o`0000;o_<<000?o0000olC40?o4a0001?o4a0001?l0
003oa/80olK20?o6`P05o`0000Coakl000?o0000olRk0?o8^`000oo8^`04o`0000CobKP000?o0000
ol^d0?o;]0000oo;]0001?l0003ocK00olf`0?o=/004o`0000KocZ`000Co0000om2X0?o@Z03od:P0
1_l00003om6T0003o`000?oCW`3odil000Codil000Co0000omFI0?oEV@3oeIT01?l00005omND0003
o`000?oIS`3ofHl000CofHl01?l00003omZ90003o`000?oMPP3ogH8000CogH8000Co0000ommk0?oO
N`3ogg/01_l00003on5c0003o`000?oTJ`3oi6/000Coi6/000Co0000onIR0?oVHP3oiV801_l00003
onUH0003o`000?o/C@3ok4d000Cok4d000?o0000onm10?o_@@001?o_@@001?l0003olSD0oo8e0?ob
=@04o`0000Oolc@000?o0000onIT0?l000000ooVH`000ol0003oiV<0onIS0002onIS0004o`000?nM
^`3o0000o`0000;oW;/000Ko0000oiZj0?nJ^P3o0000oiRj0?l00002oiJi0003o`000?nC^03oTkP0
00;o00000oooool01?l0003o05a7o`1LAol0G4L2o`0000Oooooo00001Ooooooo0000oooooooooooo
000000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`Oo00001Onl``00
0ol0003oa<@0olC40003olC400Co00001?o5`P000ol0003oakl0olNo0003olNo0003o`000?o8^`3o
000000;o00000_o8_0000ol0003obKP0olVh0004olVh0004o`000?o;]03obk@0ol^d00Go00001?o=
/0000ol0003ocZ`0olj/0003olj/00Co00001?o@Z0000ol0003odJ@0om6T0003om6T0004o`000?oC
W`3odil0om>O00Ko00000ooEVP000ol0003oei@0omND0004omND0003o`000?oIS`3ofHl000?o0000
00?of8l0o`000?oJR@001OoJR@001?l0003ogH80omf20?oMPP06o`0000Cogg/000?o0000on5c0?oQ
L`000ooQL`001?l0003oi6/0onA[0?oTJ`06o`0000?oiV8000?o0000onUH0?oYF0001?oYF0000ol0
003ok4d0ona=0004ona=0004o`000?o_@@3okd40onm100Ko00001?ob=@000ol0003olc@0oo<d0004
oo<d00;o00000ooVH`000ol0003oiV<0onIS0002onIS0004o`000?oVH`3o0000o`0000?oW;/000Ko
0000oiZj0?nJ^P3o0000oiRj0?l00002oiJi0007o`000?nC^03oTkP0o`000?n?^03o0000ooooo`02
o`0000?o05a70_l00007ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Go00001oooool0
0ol0003oooooooooo`0Tooooo`03o`000?n/_`3o[;l000;o[;l000?o0000okc30?nl``000onl``00
0ol0003oa<@0o`000002o`0000;o`/@000?o0000olG20?o5`P001?o5`P001?l0003oakl0olNo0?o7
_`03o`0000Kob;`000Co0000olVh0?o9^03obKP01_l00003ol^d0003o`000?o=/03ocK0000CocK00
00?o0000olj/0?l000000_l000000oo>[@3o0000om2X0006om2X0004o`000?oAY03odJ@0om6T00Go
00001?oCW`000ol0003oeIX0omFJ0003omFJ0004o`000?oGU03oei@0omND00Go00001OoHS`000ol0
003ofXT0omZ90003omZ900Co00001?oMPP000ol0003ogg/0ommk0004ommk0004o`000?oQL`3ohG<0
on5c00Go00000ooTJ`000ol0003oiV80onIR0004onIR0003o`000?oYF03ojEP000CojEP000Co0000
ona=0?o/C@3ok4d01_l00004onm10003o`000?ob=@3olSD000ColSD000?o0000oo<d0?oc=0000ol0
00000ooc=03o0000onIS0002onIS0005o`000?oVH`3oiV<0onIS0?l000000ooVH`02o`0000;oW;/0
00?o0000oiZj0?l000000_nH^P001_l0003oU[T0oiJi0?l0003oTkP0o`0000;oSkP00_l000001Ol0
O1co0000o`1LAol0G4Oo000000;ooooo00?o0000ooooooooool01?ooool00005ooooool0003ooooo
ooooool000001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo02Cooooo00?o
0000ojbo0?n/_`000_n/_`001?l0003o_<<0okc30?nl``03o`0000Ko`/@000Co0000olG20?o5`P3o
aL801_l00003olNo0003o`000?o8_03ob;`000?ob;`01?l00004olVh0003o`000?o;]03obk@000?o
bk@000Co0000olf`0?o=/03ocK001?l00005olj]0003o`000?o@Z03od:P000Cod:P01?l00003om6T
0003o`000?oCW`3odil000Codil000Co0000omFJ0?oEVP3oeIX01Ol00004omNE0003o`000?oHS`3o
f8l000Cof8l000?o0000omZ90?l000000_l000000ooJR@3o0000omf20006omf20004o`000?oON`3o
gg/0ommk00Ko00000_oQL`000ol0003oi6/0onA[0004onA[0003o`000?oVHP3oiV8000CoiV8000Co
0000onUH0?oYF03ojEP01_l00003ona=0003o`000?o_@@3okd4000Gokd4000Co0000oo8e0?ob=@3o
lSD01Ol00005oo<d0003o`000?oVH`3o000000CoiV<000Co0000onIS0?oVH`3oiV<00ol000001?nL
^`3o0000oiZj0?l00002oiRj0003o`000?nF^@3o000000;oTkP000Go0000ohnh0?n?^03o0000oh^f
0002o`0000;o05a700Co0000oooooooooooo00001_ooool00005ooooool0003oooooooooool00000
2?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo02Cooooo2?l00003ok_20003o`00
0?o2a03o`/@000?o`/@01?l00004olG30003o`000?o7_`3oakl000?oakl000?o0000olRl0?l00000
0_l00002olRl0003o`000?o9^03obKP000CobKP000Co0000ol^d0?o;]03obk@01Ol00004olba0003
o`000?o>[@3ocZd000?ocZd000?o0000om2X0?o@Z0000ol00002olnY0003o`000?oAY03odJ@000?o
dJ@000Co0000om>O0?oCW`3odil01_l00003omBJ0003o`000?oGU@3oeiD000CoeiD000Co0000omR?
0?oHS`3of8l01?l00005omZ90003o`000?oMPP3ogH8000CogH801?l00003ommk0003o`000?oQL`3o
hG<000?ohG<000?o0000onA[0?oTJ`001?oTJ`001?l0003oiV80onIR0?oVHP06o`0000CojEP000?o
0000ona=0?o/C@000oo/C@000ol0003okd40onm10002onm100Ko00000ooc=@000ol0003olc@0oo<d
0004oo<d00;o00001?oVH`001Ol0003oiV<0onIS0?oVH`3o000000;oiV<00_l00002oiZj0006o`00
0?nH^P3oV;X0o`000?nF^@3o00000_nC^0001Ol0003oSkP0ohnh0?l0003oRkH000;o000000?o05a7
o`000?l000000_ooool00ol0003oooooooooo`04ooooo`0000Goooooo`000?ooooooooooo`000009
ooooo`;o00002oooool2o`0002Gooooo00?o0000oj^n0?n[_P000_n[_P000ol0003o^l80ok_20003
ok_20003o`000?o2a03o000000;o00000oo1a0000ol0003oaL<0olG30003olG30004o`000?o7_`3o
akl0olNo00Co00001Oo8_0000ol0003obKP0olVh0003olVh00Co00001?o;]@000ol0003oc;40olba
0003olba0004o`000?o>[@3ocZd0olj]00Co00001_o?Z@001?l0003odJ@0om6T0?oAY005o`0000Co
dil000?o0000omBJ0?oDVP000ooDVP001?l0003oeiD0omNE0?oGU@06o`0000Cof8l000?o0000omZ9
0?oJR@000ooJR@000ol0003ogH80omf20003o`000003omb20?l0003ogg/000Gogg/000?o0000on5c
0?oQL`000ooQL`001?l0003oi6/0onA[0?oTJ`06o`0000CoiV8000?o0000onUH0?oYF0001?oYF000
1?l0003ok4d0ona=0?o/C@06o`0000?ol40000?o0000oo<e0?oc=@001?oc=@001?l0003olc@0oo<d
0?oc=002o`0000;olc<000Go0000onIS0?oVH`3oiV<0o`000003onIS0005o`000?oVH`3oiV<0onIS
0?l000000_nJ^P000ol0003oV;X0o`000002oiJi0006o`000?nC^03oTkP0o`000?n?^03o00000_n;
]P001Ol0003oPK@0o`000?mMZP3o000000;ooooo00?o0000ooooooooool01?ooool000;ooooo0_l0
000;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08oooool00ol0003oZkh0oj^n
0002oj^n0004o`000?nk`P3o^l80ok_200Co00001_o1a0001?l0003oaL<0olG30?o5``05o`0000Co
a/0000?o0000olRl0?o8_0000oo8_0000ol0003obKP0o`000002o`0000;obKT000?o0000ol^e0?o;
]@001?o;]@001?l0003oc;40olba0?o</@05o`0000CocZd000?o0000olnY0?o?Z@000oo?Z@04o`00
00?odJ@000?o0000om>O0?oCW`001?oCW`001?l0003oe9X0omBJ0?oDVP05o`0000CoeYD000?o0000
omR?0?oHS`001?oHS`001?l0003ofXT0omZ90?oJR@04o`0000Gog88000?o0000ommk0?oON`000ooO
N`001?l0003ohG<0on5c0?oQL`06o`0000Coi6/000?o0000onIR0?oVHP001?oVHP001?l0003ojEP0
onUH0?oYF006o`0000?ok4`000?o0000oo100?o`@0001?o`@0000ol0003olcD0oo<e0003oo<e0004
o`000?oc=03o0000o`0000Golc<000?o0000onIS0?l000000ooVH`000ol0003oiV<0onIS0002onIS
00;o000000CoV[X0o`000?nH^P3o00000_nF^@001_l0003oTkP0oi>h0?l0003oSkP0o`0000;oRkH0
00Go0000oh6d0?l0003oGJX0o`000002ooooo`03o`000?oooooooooo00Cooooo000Nooooo`03o`00
0?oooooooooo02?ooooo2?l00004ok[20003o`000?o1a03o`L@000?o`L@01?l00003olG30003o`00
0?o6`03oa/0000Coa/0000Co0000olRl0?o8_03ob;`00ol00006olVi0004o`000?o;]@3obkD0ol^e
00Ko00000oo</@000ol0003ocZd0olj]0004olj]0003o`000?o?Z@3o000000;o000000?ocjT0o`00
0?oAY0001OoAY0001?l0003odil0om>O0?oCW`06o`0000?oe9/000?o0000omJE0?oFU@001?oFU@00
1?l0003of8l0omR?0?oHS`06o`0000?ofXT000?o0000omb20?oLPP001?oLPP001?l0003ogg/0ommk
0?oON`05o`0000CohG<000?o0000onA[0?oTJ`001?oTJ`001?l0003oiV80onIR0?oVHP06o`0000?o
jEL000?o0000ona<0?o/C0001?o/C0001?l0003ol400oo100?o`@00:o`0000Oolc<00_l00003onIS
0003o`000?oVH`3oiV<000;oiV<000Co0000onIR0?l0003o00000_nH^P001?l0003oU[T0oiJi0?l0
0002oi>h0005o`000?n?^03o0000oh^f0?l000000_n1]0000ol0003oGJX0o`000002ooooo`03o`00
0?oooooooooo00Cooooo000Oooooo`03o`000?oooooooooo02Cooooo00?o0000ojZn0?nZ_P000_nZ
_P000ol0003o^/80ok[20003ok[20003o`000?o1a03o000000;o00000_o1a0000ol0003oaL<0olG3
0003olG30004o`000?o6`03oa/00olK000Ko00000oo8_@000ol0003obKT0olVi0003olVi00Co0000
1?o;]P000ol0003oc;40olba0003olba0004o`000?o>[@3ocZd0olj]00Co00001Oo?Z@000ol0003o
dJ@0om6T0003om6T00Co00001?oCX0000ol0003oe9/0omBK0003omBK0004o`000?oFU@3oeYD0omJE
00Ko00000ooHS`000ol0003ofXT0omZ90004omZ90004o`000?oLPP3og880omb200Ko00000ooON`00
0ol0003ohG<0on5c0004on5c0004o`000?oTJ`3oi6/0onA[00Ko00000ooVH@000ol0003ojEL0onUG
0004onUG0004o`000?o/C03ok4`0ona<00Ko00000oo`?`000ol0003olc@0oo<d0004oo<d0003o`00
0?oc<`3olc<000;olc<00_l000000ooc<P3o0000onIS0002onIS0005o`000?oVH`3oiV<0onIS0?l0
00000ooVHP02o`000004oiRj0?l0003oU[T0o`0000?oTkP000Go0000ohnh0?l0003oRkH0o`000002
oh6d00;o00001?ooool00ol0003oooooooooo`03ooooo`008?ooool2o`0002Gooooo00?o0000ojZn
0?nZ_P000_nZ_P001?l0003o^/80ok[20?nj`P03o`0000Ko`L@000Co0000olG30?o5``3oaL<01Ol0
0004olK00003o`000?o8_@3ob;d000?ob;d000?o0000olVi0?l000000_l00003olVi0003o`000?o;
]P3obkH000?obkH000Co0000olba0?o</@3oc;401Ol00004olj^0003o`000?o?Z@3ocjT000?ocjT0
00?o0000om6T0?l000000_l00003om6U0003o`000?oCX03odj0000?odj0000Co0000omBK0?oDV`3o
e9/01Ol00004omJE0003o`000?oHS`3of8l000?of8l000Co0000omZ90?oJR@3ofXT01_l00004omb2
0003o`000?oON`3ogg/000?ogg/000Co0000on5c0?oQL`3ohG<01_l00003onA[0003o`000?oVH@3o
iV4000CoiV4000Co0000onUG0?oYE`3ojEL01_l00003one<0003o`000?o`?`3ol3l000Col3l000?o
0000oo<d0?oc=0001?oc=0001?l0003olc<0o`000?l00004oo<b0003o`000?oVH`3o000000CoiV<0
00Co0000onIR0?oVHP3oiV800_l000001?nH^P3o0000oiJi0?l00002oi>h000:o`000?n?^03oSkP0
o`000?n;]P3o0000oh6d0?l0003oGJX0o`0000Cooooo00?o0000ooooooooool00oooool002;ooooo
00?o0000ooooooooool08oooool8o`0000?o^L8000?o0000ol740?o1a0000oo1a004o`0000CoaL@0
00?o0000olK00?o6`0000oo6`0001?l0003ob;d0olRm0?o8_@03o`0000OobKT000Co0000ol^f0?o;
]P3obkH01Ol00003olbb0003o`000?o>[P3ocZh000CocZh000Co0000olnY0?o?Z@3ocjT00ol00007
om6U0004o`000?oCX03odj00om>P00Go00000ooDV`000ol0003oeYD0omJE0004omJE0004o`000?oH
S`3of8l0omR?00Go00001?oJR@000ol0003og880omb20004omb20004o`000?oON`3ogg/0ommk00Go
00001?oQL`000ol0003oi6/0onA[0003onA[0004o`000?oVH@3oiV40onIQ00Ko00001?oYE`000ol0
003okD`0one<0003one<0003o`000?o`?`3ol3l000Col3l000Co0000oo<d0?oc=03olc@01?l00006
oo<b0003o`000?oVH`3o000000?oiV<000Ko0000onIR0?oVHP3oiV80o`000?oVHP02o`0000;oU[T0
00Co0000oi>h0?nC^03o00000_n?^0001ol0003oRkH0o`000?n1]03o0000oefZ0?l000001?ooool0
0ol0003oooooooooo`03ooooo`008oooool00ol0003oooooooooo`0Sooooo`03o`000?nY_P3oZKh0
00;oZKh000?o0000okW20?ni`P000oni`P000ol0003o`L@0o`000002o`0000?o`<<000?o0000olG4
0?o5a0000oo5a0001?l0003oa/00olK00?o6`005o`0000?ob;d000?o0000olVi0?o9^@001?o9^@04
o`0000?obkH000?o0000olbb0?o</P000oo</P001?l0003ocZh0olj^0?o>[P06o`0000?ocjT000?o
0000om6U0?oAY@001?oAY@04o`0000?odj0000?o0000omBK0?oDV`000ooDV`001?l0003oeYD0omJE
0?oFU@06o`0000?of8l000?o0000omZ90?oJR@001?oJR@001?l0003og880omb20?oLPP06o`0000?o
gg/000?o0000on5c0?oQL`001?oQL`001?l0003oi6/0onA[0?oTJ`05o`0000Coif4000?o0000onUG
0?oYE`001?oYE`000ol0003okD`0one<0003one<0004o`000?o`?`3ol3l0oo0o00Ko00000ooc<P00
0ol0003olc80oo<b0004oo<b00;o00000ooVH`000ol0003oiV80onIR0002onIR0003o`000?oVHP3o
000000;o000000GoU[T0o`000?nC^03oTkP0o`000002ohnh0007o`000?n;]P3o0000oh6d0?l0003o
GJX0o`000004ooooo`03o`000?oooooooooo00?ooooo000Tooooo`03o`000?oooooooooo02?ooooo
00?o0000ojVn0?nY_P000_nY_P001?l0003o^L80okW20?ni`P04o`0000Ko`<<000Co0000olG40?o5
a03oaL@01Ol00003olK10003o`000?o8_@3ob;d000?ob;d000?o0000olVi0?o9^@000ol00002olVj
0003o`000?o;]P3obkH000?obkH000Co0000olbb0?o</P3oc;801Ol00004olj^0003o`000?o?Z@3o
cjT000?ocjT000?o0000om6U0?oAY@000ol000000ooAY@3o0000om>P0005om>P0004o`000?oDV`3o
e9/0omBK00Go00001?oFU@000ol0003of8l0omR?0003omR?0004o`000?oJR@3ofXT0omZ900Ko0000
0ooMPP000ol0003ogg/0ommk0004ommk0004o`000?oQL`3ohG<0on5c00Ko00000ooTJP000ol0003o
if40onMQ0004onMQ0004o`000?oYE`3ojEL0onUG00co00000oo`?P000ol0003olc80oo<b0004oo<b
0003o`000?oc<P3olc8000?o000000?olc40o`000?oVH`000_oVH`001Ol0003oiV80onIR0?oVHP3o
000000?oiV800_l000001onF^@3o0000oi>h0?nC^03o0000ohnh0?l000000_n;]P001Ol0003oPK@0
o`000?mMZP3o000000Cooooo00?o0000ooooooooool00oooool002Gooooo00?o0000ooooooooool0
8oooool8o`0000Co^L8000?o0000ol330?o0``000oo0``04o`0000?oaL@000?o0000olK10?o6`@00
0oo6`@001?l0003ob;d0olRm0?o8_@04o`0000KobKX000Co0000ol^f0?o;]P3obkH01Ol00003olbb
0003o`000?o>[P3ocZh000CocZh000Co0000olnY0?o?Z@3ocjT01?l00005om6U0003o`000?oCX03o
dj0000?odj001?l00003omBK0003o`000?oFU@3oeYD000CoeYD000Co0000omR?0?oHS`3of8l01Ol0
0004omZ90003o`000?oMPP3ogH8000?ogH8000Co0000ommk0?oON`3ogg/01_l00003on9b0003o`00
0?oTJP3oi6X000Coi6X000Co0000onMQ0?oWH@3oif401_l00003onYF0003o`000?o]B`3okD/000?o
kD/000?o0000oo0n0?o`?P001?o`?P001?l0003olc80oo<b0?oc<P05o`0000Golc4000?o0000onIS
0?l000000ooVHP000ol0003oiV80onIR0002onIR0003o`000?nF^@3o000000?oTkP000?o0000ohnh
0?l000000_n;]P001Ol0003oPK@0o`000?mMZP3o000000Cooooo00?o0000ooooooooool00oooool0
02Kooooo0_l0000Uooooo`03o`000?nX_P3oZ;h000;oZ;h000?o0000okW20?ni`P000oni`P000ol0
003o`<<0o`000002o`0000;o_l<000?o0000olG40?o5a0000oo5a0001?l0003oa/40olK10?o6`@05
o`0000Coakd000?o0000olVj0?o9^P000oo9^P04o`0000?obkH000?o0000olbb0?o</P000oo</P00
1?l0003ocZh0olj^0?o>[P06o`0000?ocjT000?o0000om6U0?oAY@001?oAY@000ol0003odj00o`00
0002o`0000;odj0000?o0000omBK0?oDV`000ooDV`001?l0003oeYD0omJE0?oFU@06o`0000?of8l0
00?o0000omZ90?oJR@001?oJR@001?l0003ogH80omf20?oMPP05o`0000CoggX000?o0000on9b0?oR
LP000ooRLP001?l0003oi6X0onAZ0?oTJP06o`0000?oif0000?o0000onYF0?oZEP001?oZEP000ol0
003okD/0one;0003one;0004o`000?o`?P3ol3h0oo0n00Ko00001?oc<@000ol0003olc40oo<a0003
oo<a00;o00001?oVHP001_l0003oiV80onIR0?oVHP3o0000onMQ00?o00000_nC^0001Ol0003oSkP0
o`000?n;]P3o000000;oPK@00_l00005ooooo`03o`000?oooooooooo00?ooooo000Xooooo`03o`00
0?oooooooooo02?ooooo00?o0000ojRn0?nX_P000_nX_P001?l0003o^L80okW20?ni`P03o`0000Ko
_l<000Co0000olG40?o5a03oaL@01Ol00003olK10003o`000?o7_@3oakd000Coakd000?o0000olVj
0?l000000_l00002olVj0003o`000?o;]P3obkH000?obkH000Co0000olbb0?o</P3oc;801Ol00004
olj^0003o`000?o?Z@3ocjT000?ocjT000Co0000om6U0?oAY@3odJD01?l00006om>P0004o`000?oD
V`3oe9/0omBK00Go00001?oGU@000ol0003of8l0omR?0003omR?0004o`000?oJR@3ofXT0omZ900Ko
00000ooMPP000ol0003oggX0ommj0004ommj0004o`000?oRLP3ohW80on9b00Go00001?oTJ@000ol0
003oif00onMP0003onMP0003o`000?oZEP3ojUH000?ojUH000Co0000one;0?o]B`3okD/01_l00004
oo0m0003o`000?oc<@3olc4000Colc4000?o0000oo<a0?l000000_l00002oo@_0004o`000?oVHP3o
iV80o`0000?oiV8000go0000onMQ0?oWH@3oif40o`000?nC^03o0000oi>h0?l0003oSkP0o`000?n;
]P3o000000;oPK@00_l00006ooooo`03o`000?oooooooooo00;ooooo000Yooooo`03o`000?oooooo
oooo02?ooooo2?l00003okS20003o`000?no``3o_l<000?o_l<01?l00003olG40003o`000?o6`@3o
a/4000?oa/4000Co0000olNm0?o7_@3oakd01?l00006olVj0004o`000?o;]P3obkH0ol^f00Go0000
1?o</P000ol0003ocZh0olj^0003olj^0004o`000?o?Z@3ocjT0olnY00Go00000ooAY@000ol0003o
dj00om>P0004om>P00Co00000ooDVP000ol0003oeiD0omNE0004omNE0004o`000?oHS`3of8l0omR?
00Go00000ooKR0000ol0003ogH80omf20004omf20004o`000?oONP3oggX0ommj00Ko00000ooRLP00
0ol0003oi6T0onAY0004onAY0004o`000?oWH03oif00onMP00_o00001?o]B@000ol0003ol3d0oo0m
0004oo0m0004o`000?oc<@3olc40oo<a00Co00001_od;`000ol0003oiV80o`000003onIR0004o`00
0?oWH@3oif40onMQ00Co00000_n?^0001ol0003oRkH0o`000?n1]03o0000oefZ0?l000001_ooool0
0ol0003oooooooooo`02ooooo`00:_ooool00ol0003oooooooooo`0Sooooo`03o`000?nX_P3oZ;h0
00;oZ;h000?o0000okS20?nh`P000onh`P000ol0003o_l<0o`000002o`0000;o_l<000?o0000olG4
0?o5a0000oo5a0001?l0003oa/40olK10?o6`@05o`0000Coakd000?o0000olVj0?o9^P000oo9^P04
o`0000?obkH000?o0000olbb0?o</P001?o</P001?l0003ocZh0olj^0?o>[P05o`0000?ocjT000?o
0000om6U0?oAY@000ooAY@000ol0003odj00om>P0003o`0000;odj0000?o0000omBJ0?oDVP000ooD
VP001?l0003oeiD0omNE0?oGU@06o`0000?ofHl000?o0000om^80?oKR0000ooKR0001?l0003ogH80
omf20?oMPP06o`0000?oggX000?o0000on9b0?oRLP001?oRLP001?l0003oi6T0onAY0?oTJ@06o`00
00;oiel000?o0000onYD0?oZE0001?oZE0000ol0003okDT0one90004one90004o`000?o`?@3ol3d0
oo0m00Ko00000ood;`000ol0003om2l0oo@_0004oo@_00;o00000ooVHP001Ol0003oif40onMQ0?oW
H@3o000000;oif000_l00002ohnh0007o`000?n;]P3o0000oh6d0?l0003oGJX0o`000006ooooo`03
o`000?oooooooooo00;ooooo000[ooooo`;o00009?ooool00ol0003oZ;h0ojRn0002ojRn0004o`00
0?nh`P3o^<80okS200?o00001_no``001?l0003oaL@0olG40?o5a005o`0000Coa/4000?o0000olNm
0?o7_@000oo7_@000ol0003obKX0o`000002o`0000;obKX000?o0000ol^f0?o;]P000oo;]P001?l0
003oc;80olbb0?o</P06o`0000?ocZh000?o0000olnY0?o?Z@000oo?Z@001?l0003odJD0om6U0?oA
Y@04o`0000Kodj0000Co0000omBJ0?oDVP3oe9X01Ol00003omND0003o`000?oIS`3ofHl000CofHl0
00Co0000om^80?oKR03ofhP01Ol00004omf10003o`000?oONP3oggX000?oggX000Co0000on9b0?oR
LP3ohW801_l00003onEX0003o`000?oWG`3oiel000?oiel000?o0000onYD0?oZE0001?oZE0001?l0
003okDT0one90?o]B@06o`0000?olC/000?o0000oo@_0?od;`001?od;`001?l0003om2l0oo@_0?od
;`02o`000003oo@]0?l0003oiV8000;oiV8000Go0000onMQ0?oWH@3oif40o`000003onMP00;o0000
00SoSkP0o`000?n;]P3o0000oh6d0?l0003oGJX0o`0000Kooooo00?o0000ooooooooool00_ooool0
02gooooo00?o0000ooooooooool08_ooool8o`0000?o^<8000?o0000oko30?no``000ono``04o`00
00CoaL@000?o0000olK10?o6`@000oo6`@001?l0003oakd0olNm0?o7_@03o`0000KobKX000Co0000
ol^f0?o;]P3obkH01Ol00004olbb0003o`000?o>[P3ocZh000?ocZh000Co0000olnY0?o?Z@3ocjT0
1Ol00003om6U0003o`000?oCX03odj0000Codj001?l00003omFJ0003o`000?oGU03oei@000?oei@0
00Co0000omV?0?oIS`3ofHl01_l00003om^80003o`000?oMP@3ogH4000CogH4000Co0000ommj0?oO
NP3oggX01Ol00004on9a0003o`000?oUJ03oiFP000?oiFP000?o0000onMO0?oWG`000ooWG`001?l0
003ojU@0onYD0?oZE006o`0000?okTL000?o0000oo4k0?oa>`001?oa>`000ol0003om2l0oo@_0003
oo@_0004o`000?od;`3o0000o`0000Com2d000?o0000onIR0?l000000ooWH@000ol0003oif00onMP
0002onMP0003o`000?n?^03o000000;oRkH000Go0000oh6d0?l0003oGJX0o`000006ooooo`03o`00
0?oooooooooo00;ooooo000^ooooo`03o`000?oooooooooo02;ooooo00?o0000ojRn0?nX_P000_nX
_P000ol0003o^<80okS20003okS20003o`000?no``3o000000;o00000ono``000ol0003oaL@0olG4
0003olG40004o`000?o6`@3oa/40olK100Go00000oo7_@000ol0003obKX0olVj0003olVj00Co0000
0oo;]P000ol0003oc;80olbb0004olbb0004o`000?o>[P3ocZh0olj^00Go00000oo?Z@000ol0003o
dJD0om6U0003om6U0003o`000?oCX03odj0000?o00000_oCW`000ol0003oeIX0omFJ0003omFJ0004
o`000?oGU03oei@0omND00Go00001?oISP000ol0003ofhP0om^80003om^80004o`000?oMP@3ogH40
omf100Ko00000ooON@000ol0003ohW40on9a0004on9a0004o`000?oUJ03oiFP0onEX00_o00000oo[
D`000ol0003okTL0oni70004oni70003o`000?oa>`3olC/000?olC/000Co0000oo@_0?od;`3om2l0
1?l00006oo@]00;o00000ooWH@000ol0003oif00onMP0002onMP0004o`000?oWG`3o0000o`0000;o
RkH000Go0000oh6d0?l0003oGJX0o`000006ooooo`03o`000?oooooooooo00;ooooo000_ooooo`03
o`000?oooooooooo02;ooooo00?o0000ojRn0?nX_P000_nX_P001?l0003o^<80okS20?nh`P04o`00
00Ko_l<000Co0000olG40?o5a03oaL@01Ol00003olK10003o`000?o7_@3oakd000?oakd000?o0000
olVj0?l000000_l00002olVj0003o`000?o;]P3obkH000?obkH000Co0000olbb0?o</P3oc;801_l0
0003olj^0003o`000?o?Z@3ocjT000?ocjT000Co0000om6U0?oAY@3odJD01?l00006om>O0004o`00
0?oEVP3oeIX0omFJ00Go00000ooGU0000ol0003ofHh0omV>0004omV>0004o`000?oKR03ofhP0om^8
00Go00000ooMP0000ol0003oggT0ommi0004ommi0004o`000?oRL@3ohW40on9a00Ko00000_oUI`00
0ol0003oj5d0onQM0004onQM0003o`000?o[D`3oje<000?oje<000Co0000oni70?o^A`3okTL03?l0
0003ooD]0003o`000?od;@3om2d000;om2d00_l000000ooe:P3o0000onMQ0002onMQ0003o`000?oW
H03oif0000;oif0000?o0000onMO0?oWG`000ol00002oh6d00;o00001oooool00ol0003ooooooooo
o`02ooooo`00<?ooool00ol0003oooooooooo`0Rooooo`So00001?nh`@02o`0000?o_l<01Ol00003
olC40003o`000?o6`@3oa/4000?oa/4000Co0000olNm0?o7_@3oakd00ol00006olVj0004o`000?o;
]P3obkH0ol^f00Go00001?o</P000ol0003ocZh0olj^0003olj^0004o`000?o?Z@3ocjT0olnY00Go
00000ooAY0000ol0003odil0om>O0004om>O00Co00000ooEVP000ol0003oei@0omND0003omND0004
o`000?oISP3ofHh0omV>00Ko00000ooKQ`000ol0003ogH00omf00003omf00004o`000?oON@3oggT0
ommi00Ko00000ooRL0000ol0003oiFL0onEW0003onEW0003o`000?oXG@3oj5d000Coj5d000Co0000
on]C0?o[D`3oje<01Ol00004oni50003o`000?oa>@3olCT000;olCT000?o0000ooD]0?oe;@001?oe
;@001?l0003om2d0o`000?l00004ooDZ0003o`000?oWH@3o000000Coif0000Co0000onMO0?oWG`3o
iel00ol00002oh6d00;o00002?ooool00ol0003oooooooooo`01ooooo`00<Oooool2o`0002Cooooo
0_l00003ojNm00;o00000onh`@05o`0000?o_/<000?o0000olC40?o4a0000oo4a0001?l0003oa/40
olK10?o6`@05o`0000?oakd000?o0000olVj0?o9^P000oo9^P04o`0000?obkH000?o0000olbb0?o<
/P001?o</P001?l0003ocZh0olj^0?o>[P05o`0000?ocjT000?o0000om6T0?oAY0000ooAY0000ol0
003odil0om>O0003o`000003om>O0?l0003oeIX000GoeIX000Co0000omND0?oGU03oei@01Ol00003
omV=0003o`000?oKQ`3ofhL000CofhL000Co0000omf00?oMP03ogH001Ol00004on1h0003o`000?oR
L03ohW0000?ohW0000?o0000onEW0?oUI`000ooUI`001?l0003oj5d0onQM0?oXG@06o`0000?oje40
00?o0000oni50?o^A@001?o^A@000ol0003olCT0oo4i0002oo4i0004o`000?oe;@3omBd0ooD]00Co
00001_oe:P000ol0003oif40o`000003onMP0005o`000?oWG`3oiel0onMO0?l000000_oWG`001Ol0
003oPK@0o`000?mMZP3o000000Sooooo00?o0000ooooooooool00Oooool003?ooooo00?o0000oooo
ooooool08oooool8o`0000?o]l4000?o0000okk30?nn``000onn``001?l0003oa<@0olC40?o4a005
o`0000?oa/4000?o0000olNm0?o7_@000oo7_@000ol0003obKX0o`000002o`0000;obKX000?o0000
ol^f0?o;]P000oo;]P001?l0003oc;80olbb0?o</P06o`0000?ocZd000?o0000olnY0?o?Z@000oo?
Z@001?l0003odJ@0om6T0?oAY004o`0000Godil000Co0000omFJ0?oEVP3oeIX01_l00003omNC0003
o`000?oIS@3ofHd000?ofHd000Co0000om^70?oKQ`3ofhL01_l00003omeo0003o`000?oPN03oh7P0
00Coh7P000Co0000on9`0?oRL03ohW002ol00003onQL0003o`000?o[D@3oje4000Coje4000Co0000
oni50?o^A@3okTD02ol00004ooHY0003o`000?oe:P3omBX000?omBX00_l00004onMP0005o`000?oW
G`3oiel0onMO0?l000000_oWG`05o`0000Sooooo00?o0000ooooooooool00Oooool003Cooooo00?o
0000ooooooooool08oooool00ol0003oYkd0ojNm0002ojNm0003o`000?ng`@3o]l4000?o]l4000Co
0000okk30?nn``3o_/<01Ol00003olG40003o`000?o6`@3oa/4000?oa/4000Co0000olNm0?o7_@3o
akd01?l00005olVj0004o`000?o;]P3obkH0ol^f00Go00001?o</@000ol0003ocZd0olj]0003olj]
0004o`000?o?Z@3ocjT0olnY00Go00001?oAY0001?l0003odil0om>O0?oCW`05o`0000CoeIT000?o
0000omNC0?oGT`000ooGT`001?l0003ofHd0omV=0?oIS@05o`0000CofhH000?o0000omeo0?oMO`00
0ooMO`001?l0003oh7P0on1h0?oPN006o`0000;ohfh000?o0000onEU0?oUI@000ooUI@000ol0003o
j5`0onQL0004onQL0004o`000?o[D@3oje40on]A00Ko00000oo_@`000ol0003olSH0oo8f0003oo8f
0003o`000?of:@3omRT000ComRT000?o0000ooDZ0?l000000_l00002ooHW0004o`000?oWH03oif00
o`0000?oiel000Co0000onMO0?oWG`3o00000_oUI@02o`0000Wooooo00?o0000ooooooooool00Ooo
ool003Gooooo00?o0000ooooooooool08oooool00ol0003oYkd0ojNm0002ojNm0004o`000?ng`@3o
]l40okO100Go00000onn``000ol0003oaL@0olG40003olG40004o`000?o6`@3oa/40olK100Go0000
1?o7_@001?l0003obKX0olVj0?o9^P05o`0000?obkH000?o0000olba0?o</@001?o</@001?l0003o
cZd0olj]0?o>[@05o`0000?od:P000?o0000om6T0?oAY0000ooAY004o`0000?odih000?o0000omFI
0?oEV@001?oEV@001?l0003oei<0omNC0?oGT`05o`0000?ofHd000?o0000om^60?oKQP001?oKQP00
1?l0003ogGl0omeo0?oMO`05o`0000?oh7H000?o0000on=^0?oSKP000ooSKP000ol0003oiFD0onEU
0003onEU0004o`000?oXG03oj5`0onQL00Ko00000oo/C`000ol0003okd<0onm30004onm30003o`00
0?ob=P3olSH000?olSH000Co0000ooHY0?of:@3omRT01?l00006ooHW0003o`000?oWH03o000000;o
iel000Go0000onMO0?oWG`3oiel0o`000002onEU00;o00002Oooool00ol0003oooooooooo`01oooo
o`00=_ooool2o`0002Cooooo2?l00003okO10003o`000?nn``3o_/<000?o_/<000Co0000olG40?o5
a03oaL@01Ol00003olK10003o`000?o7_@3oakd000?oakd01?l00003olVi0003o`000?o;]P3obkH0
00?obkH000Co0000olba0?o</@3oc;401_l00003olj]0003o`000?o@Z03od:P000?od:P000?o0000
om6T0?l000000_l00002om6S0003o`000?oCWP3odih000?odih000Co0000omFI0?oEV@3oeIT01_l0
0003omNC0003o`000?oIS@3ofHd000?ofHd000Co0000om^60?oKQP3ofhH01_l00003omin0003o`00
0?oPMP3oh7H000?oh7H000?o0000on=^0?oSKP000ooSKP001?l0003oiFD0onEU0?oUI@05o`0000Co
jEX000?o0000ona?0?o/C`000oo/C`000ol0003okd<0onm30003onm30004o`000?ob=P3olSH0oo8f
00Ko00000oof9P000ol0003omRL0ooHW0004ooHW00;o00000ooWG`001?l0003oiel0onMO0?l00002
onEU00?o00002Oooool00ol0003oooooooooo`01ooooo`00>?ooool00ol0003oooooooooo`0Roooo
o`03o`000?nW_@3oYkd000;oYkd000?o0000okO10?ng`@000ong`@001?l0003o_/<0okk30?nn``05
o`0000?oaL@000?o0000olK10?o6`@000oo6`@000ol0003oakd0o`000002o`0000;oakd000?o0000
olVi0?o9^@000oo9^@001?l0003obkH0ol^f0?o;]P05o`0000?oc;4000?o0000olj]0?o>[@001?o>
[@001?l0003od:P0om2X0?o@Z004o`0000GodJ<000Co0000om>N0?oCWP3odih01Ol00003omFH0003
o`000?oGT`3oei<000Coei<000Co0000omV=0?oIS@3ofHd01Ol00003omb50003o`000?oNOP3ogWh0
00CogWh000Co0000on1f0?oPMP3oh7H02ol00003onIS0003o`000?oYFP3ojEX000CojEX000Co0000
ona?0?o/C`3ok4l02ol00003oo<c0003o`000?of9P3omRH000ComRH000?o0000ooHW0?of9`000ol0
00001Oog903o0000onMO0?oWG`3o000000?oiel000?o0000onEU0?oUI@000_l000000ooooooo0000
ooooo`08ooooo`7o00000Oooool1ooooo`00>Oooool00ol0003oooooooooo`0Rooooo`03o`000?nW
_@3oYkd000;oYkd000Co0000okO10?ng`@3o]l401Ol00003oko30003o`000?o5a03oaL@000?oaL@0
00Co0000olK10?o6`@3oa/401?l00005olNm0004o`000?o9^@3obKT0olVi00Go00000oo;]@000ol0
003oc;40olba0003olba0004o`000?o>[@3ocZd0olj]00Ko00001?o@Z0001?l0003odJ<0om6S0?oA
X`05o`0000?odid000?o0000omFH0?oEV0000ooEV0001?l0003oei<0omNC0?oGT`06o`0000?ofX`0
00?o0000omb50?oLQ@000ooLQ@001?l0003ogWh0omin0?oNOP06o`0000?ohGD000?o0000on=/0?oS
K0000_oSK0000ol0003oiV<0onIS0004onIS0004o`000?oYFP3ojEX0onUJ00Ko00000oo/C0000ol0
003ol400oo100002oo100003o`000?oc<`3olc<000Colc<000Co0000ooHV0?of9P3omRH01Ol00005
ooLT0003o`000?oWG`3o000000;oiel000?o0000onEU0?oUI@000_l00003ooooo`03o`000?oooooo
oooo00Kooooo0Ol00001ooooo`7ooooo000jooooo`03o`000?oooooooooo02;ooooo2?l00003okS2
0003o`000?no``3o_l<000?o_l<000Co0000olG40?o5a03oaL@01Ol00004olK10004o`000?o7_@3o
akd0olNm00Go00000oo9^@000ol0003obkD0ol^e0003ol^e0004o`000?o</@3oc;40olba00Go0000
0oo>[@000ol0003od:P0om2X0004om2X00Co00000ooBX`000ol0003odid0om>M0003om>M0004o`00
0?oEV03oeIP0omFH00Go00000ooHTP000ol0003ofX`0omZ<0004omZ<0004o`000?oLQ@3og8D0omb5
00Go00000ooNO0000ol0003ohGD0on5e0004on5e0003o`000?oSK03ohf`000;ohf`000Co0000onIS
0?oVH`3oiV<01_l00003onUG0003o`000?o/C03ok4`000Cok4`000?o0000oo100?o`@0000_o`@000
1?l0003olc<0oo<c0?oc<`06o`0000?omb8000?o0000ooLT0?og90001?og9002o`0000?oiel000?o
0000onEU0?oUI@000_l00003ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo000k
ooooo`03o`000?oooooooooo02;ooooo00?o0000ojNm0?nW_@000_nW_@000ol0003o^<80okS20003
okS20004o`000?no``3o_l<0oko300Go00001?o5a0001?l0003oa/40olK10?o6`@05o`0000?ob;d0
00?o0000olVi0?o9^@000oo9^@001?l0003obkD0ol^e0?o;]@05o`0000?oc;4000?o0000olj]0?o>
[@000oo>[@000ol0003od:P0om2X0003o`000003om2W0?l0003odZ<000GodZ<000Co0000om>M0?oC
W@3odid01Ol00003omJG0003o`000?oHTP3of98000?of98000Co0000omZ<0?oJS03ofX`01_l00003
omb40003o`000?oNO03ogW`000?ogW`000Co0000on5e0?oQM@3ohGD02ol00003onIQ0003o`000?oY
E`3ojEL000CojEL000Co0000ona<0?o/C03ok4`02ol00004oo@_0003o`000?og8P3omb8000?omb80
00Co0000ooLT0?og903omb@00_l000001Ooh8@3o0000onMO0?oWG`3o000000;oiFD00_l00005oooo
o`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000looooo`;o00008oooool00ol0003o
Ykd0ojNm0002ojNm0004o`000?nh`P3o^<80okS200Go00000ono``000ol0003oaL@0olG40003olG4
00Co00000oo6`0000ol0003ob;d0olRm0003olRm0004o`000?o9^@3obKT0olVi00Go00000oo;]@00
0ol0003oc;40olba0003olba0004o`000?o>[@3ocZd0olj]00Co00001Oo@Y`001?l0003odZ<0om:S
0?oBX`06o`0000?oe9d000?o0000omJG0?oFU`000ooFU`001?l0003of980omRB0?oHTP05o`0000?o
fXX000?o0000omb40?oLQ0001?oLQ0001?l0003ogW`0omil0?oNO005o`0000?ohG<000?o0000onAZ
0?oTJP000ooTJP000ol0003oiV40onIQ0003onIQ0004o`000?oYE`3ojEL0onUG00Ko00000oo]B@00
0ol0003ol3d0oo0m0003oo0m0003o`000?od;`3om2l000Com2l000?o0000ooLR0?og8P000_og8P00
1?l0003omb@0o`000?l00004ooPQ0003o`000?oWG`3o000000;oiFD00_l00006ooooo`03o`000?oo
oooooooo00Cooooo0Ol00001ooooo`7ooooo000nooooo`03o`000?oooooooooo027ooooo2?l00003
okS20003o`000?no``3o_l<000?o_l<000?o0000olG40?l000000_l00002olG40003o`000?o6`03o
a/0000?oa/0000Co0000olRm0?o8_@3ob;d01Ol00003olVi0003o`000?o;]@3obkD000?obkD000Co
0000olba0?o</@3oc;401Ol00004olj/0004o`000?o@Y`3od:L0om2W00Go00000ooBXP000ol0003o
e9d0omBM0004omBM0004o`000?oFU`3oeYL0omJG00Go00000ooHT0000ol0003ofXX0omZ:0003omZ:
0004o`000?oLQ03og8@0omb400Ko00000ooON`000ol0003ohG<0on5c0003on5c0003o`000?oTJP3o
i6X000?oi6X000Co0000onIQ0?oVH@3oiV401Ol00003onYD0003o`000?o]B@3okDT000CokDT000?o
0000oo0m0?o`?@000oo`?@001?l0003om2l0oo@_0?od;`09o`0000Kon2400_l00002onEU00;o0000
2?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00?oooool00ol0003ooooooooo
o`0Qooooo`03o`000?nX_P3oZ;h000;oZ;h000?o0000okS20?nh`P000onh`P001?l0003o_l<0oko3
0?no``04o`0000GoaL@000Co0000olK00?o6`03oa/001Ol00003olRl0003o`000?o9^@3obKT000?o
bKT000Co0000ol^e0?o;]@3obkD01Ol00004olf`0004o`000?o>[03ocZ`0olj/00Go00000oo@Y`00
0ol0003odZ80om:R0003om:R0004o`000?oDW@3oe9d0omBM00Ko00000ooFUP000ol0003of900omR@
0003omR@0004o`000?oJRP3ofXX0omZ:00Go00000ooMPP000ol0003ogg/0ommk0004ommk0004o`00
0?oQL`3ohG<0on5c00_o00000ooWG`000ol0003ojU@0onYD0003onYD0003o`000?o]B@3okDT000?o
kDT000Co0000oo0m0?o`?@3ol3d01_l00003ooD[0003o`000?oh7P3on1h000?on1h000Co0000ooPQ
0?oh8@3on2400_l00002ooLT0003o`000?oUI@3o000000Wooooo00?o0000ooooooooool00oooool1
o`00007ooooo0Oooool0043ooooo00?o0000ooooooooool08Oooool00ol0003oZ;h0ojRn0002ojRn
0004o`000?nh`P3o^<80okS200Go00001?no``001?l0003oaL@0olG40?o5a005o`0000?oa/0000?o
0000olRl0?o8_0000oo8_0001?l0003obKT0olVi0?o9^@05o`0000?obk@000?o0000olf`0?o=/000
0oo=/004o`0000?ocj/000?o0000om2W0?o@Y`000oo@Y`001?l0003odZ80om:R0?oBXP05o`0000?o
e9`000?o0000omJF0?oFUP001?oFUP001?l0003of900omR@0?oHT005o`0000?ofXT000?o0000omf2
0?oMPP000ooMPP001?l0003ogg/0ommk0?oON`06o`0000?ohW4000?o0000onEX0?oUJ0000_oUJ000
0ol0003oiel0onMO0004onMO0004o`000?oZE03ojU@0onYD00_o00000ooa>@000ol0003omB/0ooD[
0004ooD[0003o`000?oh7P3on1h000?on1h000?o0000ooPQ0?l000001?og9002o`0000_ooooo00?o
0000ooooooooool00oooool1o`00007ooooo0011ooooo`;o00008_ooool8o`0000Co^<8000Co0000
oko30?no``3o_l<01Ol00003olG30003o`000?o6`03oa/0000?oa/0000Co0000olRl0?o8_03ob;`0
1Ol00003olVh0003o`000?o;]03obk@000?obk@000?o0000olf`0?l000000_l00002olf_0003o`00
0?o?Z`3ocj/000?ocj/000Co0000om2W0?o@Y`3od:L01Ol00003om:Q0003o`000?oDW03oe9`000?o
e9`000Co0000omJF0?oFUP3oeYH01_l00003omR?0003o`000?oJR@3ofXT000?ofXT000Co0000omf2
0?oMPP3ogH801Ol00003ommi0003o`000?oRL@3ohW4000CohW4000?o0000onEX0?oUJ0000_oUJ000
1?l0003oiel0onMO0?oWG`06o`0000?oje4000?o0000oni60?o^AP000_o^AP000ol0003olCT0oo4i
0004oo4i0003o`000?oe:`3omB/000?omB/000Co0000ooPN0?oh7P3on1h01?l00003ooLT00;o0000
3_ooool00ol0003oooooooooo`02ooooo`7o00000Oooool004?ooooo00?o0000ooooooooool08Ooo
ool2o`0000?oZ;h000Co0000okS20?nh`P3o^<801Ol00003ol330003o`000?o5``3oaL<000?oaL<0
00Co0000olK00?o6`03oa/001Ol00003olRl0003o`000?o9^03obKP000?obKP000Co0000ol^d0?o;
]03obk@01?l00005olf_0004o`000?o?Z`3ocj/0oln[00Go00000ooAYP000ol0003odZ40om:Q0003
om:Q0004o`000?oDW03oe9`0omBL00Go00000ooGU@000ol0003of8l0omR?0004omR?0004o`000?oJ
R@3ofXT0omZ900Go00000ooMP0000ol0003oggT0ommi0003ommi0004o`000?oRL@3ohW40on9a00_o
00000ooXG0000ol0003oje40on]A0004on]A0003o`000?o^AP3okTH000;okTH000Co0000oo4i0?oa
>@3olCT03?l00004ooPP0003o`000?og903o0000017ooooo00Go0000ooooooooooooooooo`000001
ooooo`00A?ooool00ol0003oooooooooo`0Qooooo`So00000oni`P000ol0003o`<<0ol330003ol33
0004o`000?o5``3oaL<0olG300Go00000oo6_`000ol0003ob;`0olRl0003olRl0004o`000?o9^03o
bKP0olVh00Go00001?o;/`001?l0003ocJl0olf_0?o=[`05o`0000?ocjX000?o0000om6V0?oAYP00
0ooAYP001?l0003odZ40om:Q0?oBX@05o`0000?oe9X000?o0000omNE0?oGU@000ooGU@001?l0003o
f8l0omR?0?oHS`06o`0000;ofhL000?o0000omf00?oMP0001?oMP0001?l0003oggT0ommi0?oON@05
o`0000?ohfh000?o0000onEV0?oUIP000ooUIP000ol0003oj5`0onQL0003onQL0004o`000?o[D@3o
je40on]A00_o00000ooa>P000ol0003omB`0ooD/0004ooD/0004o`000?oh803on200ooPP00Co0000
4_ooool01Ol0003ooooooooooooooooo0000007ooooo0015ooooo`03o`000?oooooooooo027ooooo
0_l00003ojVn0003o`000?ni`P3o^L8000?o^L8000Co0000ol330?o0``3o`<<01Ol00003olG30003
o`000?o6_`3oa[l000?oa[l000Co0000olRl0?o8_03ob;`01Ol00004olZh0004o`000?o;/`3obk<0
ol^c00Go00000oo=[`000ol0003ocjX0olnZ0003olnZ0004o`000?oAYP3odJH0om6V00Go00000ooC
W`000ol0003oe9X0omBJ0003omBJ0004o`000?oGU@3oeiD0omNE00Go00000ooIS@000ol0003ofhL0
om^70003om^70004o`000?oMP03ogH00omf000Ko00000ooPM`000ol0003ohfh0on=^0003on=^0003
o`000?oUIP3oiFH000?oiFH000Co0000onQL0?oXG03oj5`01Ol00003on]A0003o`000?o^AP3okTH0
00CokTH000?o0000oo4j0?oa>P000_oa>P001?l0003omB`0ooD/0?oe;006o`0001Oooooo00Co0000
oooooooooooo00000Oooool004Kooooo00?o0000ooooooooool08Oooool2o`0000?oZKh000Co0000
okW20?ni`P3o^L801Ol00003ol740003o`000?o5``3oaL<000?oaL<000Co0000olJo0?o6_`3oa[l0
1Ol00004olRk0004o`000?o:^03ob[P0olZh00Go00000oo</`000ol0003ocJl0olf_0003olf_0004
o`000?o?ZP3ocjX0olnZ00Go00000ooAY@000ol0003odil0om>O0003om>O0004o`000?oDVP3oe9X0
omBJ00Go00000ooGT`000ol0003ofHd0omV=0003omV=0004o`000?oKQ`3ofhL0om^700Go00000ooN
OP000ol0003oh7L0on1g0004on1g0004o`000?oSKP3ohfh0on=^00_o00000_oXG0000ol0003oje40
on]A0004on]A0004o`000?o^AP3okTH0oni600_o00007_ooool00ol0003oooooo`000001ooooo`00
Aoooool2o`0002;ooooo2?l00003ok[20003o`000?o1a03o`L@000?o`L@000Co0000olG30?o5``3o
aL<01Ol00004olNo0004o`000?o8^`3ob;/0olRk00Go00000oo:]`000ol0003oc;<0olbc0003olbc
0004o`000?o=[`3ocJl0olf_00Go00000oo?Z@000ol0003odJD0om6U0003om6U0004o`000?oCW`3o
dil0om>O00Go00000ooEV@000ol0003oei<0omNC0003omNC0004o`000?oIS@3ofHd0omV=00Go0000
0ooLQ@000ol0003ogWh0omin0003omin0004o`000?oPM`3oh7L0on1g00Ko00000ooSKP000ol0003o
iFD0onEU0003onEU0003o`000?oXG03oj5`000;oj5`000Co0000on]A0?o[D@3oje402?l0000Woooo
o`03o`000?oooooo0000007ooooo0019ooooo`03o`000?oooooooooo023ooooo0_l00003ojZn0003
o`000?nj`P3o^/8000?o^/8000Co0000ol740?o1a03o`L@01Ol00003olG20003o`000?o7_`3oakl0
00?oakl01?l00003olRk0003o`000?o:]`3ob[L000?ob[L000Co0000olbc0?o</`3oc;<01Ol00002
olj^0003o`000?o?Z@3ocjT000CocjT000Co0000om6U0?oAY@3odJD01Ol00002om>N0003o`000?oE
V@3oeIT000CoeIT000Co0000omNC0?oGT`3oei<01Ol00003omZ<0003o`000?oLQ@3og8D000?og8D0
00Co0000omin0?oNOP3ogWh01Ol00003on5f0003o`000?oSKP3ohfh000Cohfh000Co0000onEU0?oU
I@3oiFD03Ol0000]ooooo`7o00000Oooool1o`000000B_ooool00ol0003oooooooooo`0Pooooo`;o
00000onZ_P001?l0003o^/80ok[20?nj`P05o`0000?o`/@000?o0000olG20?o5`P000oo5`P000ol0
003oakl0o`000002o`0000;oakh000?o0000olRk0?o8^`000oo8^`001?l0003ob[L0olZg0?o:]`05
o`0000;oc;8000?o0000olj^0?o>[P000oo>[P001?l0003ocjT0olnY0?o?Z@06o`0000;odJ<000?o
0000om>N0?oCWP000ooCWP001?l0003oeIT0omFI0?oEV@06o`0000;of98000?o0000omZ<0?oJS000
1?oJS0001?l0003og8D0omb50?oLQ@05o`0000?ogWd000?o0000on5f0?oQMP000ooQMP001?l0003o
hfh0on=^0?oSKP06o`0000;ohG@01Ol0000dooooo`;o0000001;ooooo`03o`000?oooooooooo027o
oooo1ol00003ok_20003o`000?o2a03o`/@000?o`/@000Co0000olG20?o5`P3oaL801?l00005olNn
0004o`000?o8^`3ob;/0olRk00Go00000_o;]P000ol0003oc;80olbb0003olbb0004o`000?o>[P3o
cZh0olj^00Go00000oo@Z0000ol0003odJ<0om6S0003om6S0004o`000?oCWP3odih0om>N00Go0000
0ooFV0000ol0003of980omRB0003omRB0004o`000?oJS03ofX`0omZ<00Ko00000_oLQ0000ol0003o
gWd0omim0004omim0004o`000?oQMP3ohGH0on5f00Go00000_oON`06o`0003Sooooo0ol0000004co
oooo0_l0000Rooooo`;o00000on[_P000ol0003o^l80ok_20002ok_20004o`000?o2a03o`/@0ol;4
00Go00001?o6`P001?l0003oakh0olNn0?o7_P05o`0000;obKX000?o0000ol^f0?o;]P000oo;]P00
1?l0003oc;80olbb0?o</P05o`0000?ocZd000?o0000om2X0?o@Z0000oo@Z0001?l0003odJ<0om6S
0?oAX`05o`0000?oe9d000?o0000omJH0?oFV0000ooFV0001?l0003of980omRB0?oHTP05o`0000Co
fX/000?o0000omb40?oLQ0000_oLQ0001?l0003ogWd0omim0?oNO@06o`0000;ogH401Ol0000joooo
o`Co00000oooool004kooooo00?o0000ooooooooool08?ooool=o`0000Co`l@000Co0000olK20?o6
`P3oa/801Ol00003olNm0003o`000?o9^P3obKX000;obKX000Co0000ol^f0?o;]P3obkH01Ol00003
olba0003o`000?o>[@3ocZd000?ocZd000Co0000om2X0?o@Z03od:P01Ol00004om:R0003o`000?oD
W@3oe9d000;oe9d000Co0000omJH0?oFV03oeYP01Ol00004omRA0004o`000?oJR`3ofX/0omZ;00[o
00000ooKQ`05o`0003_ooooo1?l00007ooooo`00Coooool00ol0003oooooooooo`0Pooooo`;o0000
0on/_`000ol0003o_<80okc20003okc20004o`000?o3a03o`l@0ol?400Go00000oo6`@000ol0003o
akd0olNm0003olNm0003o`000?o9^P3obKX000Go00000oo;]@000ol0003oc;40olba0003olba0004
o`000?o>[@3ocZd0olj]00Go00001?o@Y`001?l0003odZ80om:R0?oBXP0:o`0000CoeYL000Co0000
omRA0?oHT@3of9401Ol00004omNC0004o`000?oIS@3ofHd0omV=00Go0000?Oooool3o`0000_ooooo
001@ooooo`03o`000?oooooooooo023ooooo0_l00003ojbo0004o`000?nl`P3o_<80okc200Go0000
0oo4a0000ol0003oa/40olK10003olK10004o`000?o7_@3oakd0olNm00Co00000oo9^@000ol0003o
bkD0ol^e0003ol^e0004o`000?o</@3oc;40olba00Go00001?o>Z`001?l0003od:L0om2W0?o@Y`05
o`0000?odZ4000?o0000omBL0?oDW0000ooDW0001?l0003oeYL0omJG0?oFU`05o`0000?oeIP000Co
0000omNC0?oGT`3oei<01_l0000nooooo`Co00003_ooool0057ooooo00?o0000ooooooooool08?oo
ool8o`0000?o_L<000?o0000olC40?o4a0000oo4a0001?l0003oa/40olK10?o6`@05o`0000;ob;`0
00?o0000olVi0?o9^@000oo9^@001?l0003obkD0ol^e0?o;]@05o`0000CocK0000Co0000olj[0?o>
Z`3ocZ/01Ol00002om2V0003o`000?oBX@3odZ4000CodZ4000Co0000omBL0?oDW03oe9`01Ol00003
om>M0004o`000?oEV03oeIP0omFH00Go0000@?ooool4o`0001;ooooo001Booooo`;o00008Oooool0
0ol0003o[Kl0ojfo0002ojfo0003o`000?nm``3o_L<000?o_L<000Co0000olC40?o4a03oa<@01Ol0
0002olK00003o`000?o8_03ob;`000?ob;`000Co0000olVi0?o9^@3obKT01Ol00004ol^d0004o`00
0?o=/03ocK00olf`00Go00000_o?Z`000ol0003od:H0om2V0003om2V0004o`000?oBX@3odZ40om:Q
00Ko00000ooBXP001?l0003odid0om>M0?oCW@05o`00047ooooo1?l0000Fooooo`00E?ooool00ol0
003oooooooooo`0Oooooo`03o`000?n]_`3o[Kl000;o[Kl000Co0000okg30?nm``3o_L<01Ol00003
olG40003o`000?o6`03oa/0000;oa/0000Co0000olRl0?o8_03ob;`01Ol00004olZh0004o`000?o;
]03obk@0ol^d00Go00000_o=[`000ol0003ocj/0oln[0003oln[0004o`000?o@YP3od:H0om2V00Go
00001?o@YP001?l0003odZ80om:R0?oBXP05o`0004;ooooo1?l0000Jooooo`00EOooool00ol0003o
ooooooooo`0Oooooo`So00000onn``000ol0003oaL@0olG40003olG40003o`000?o6`03oa/0000Go
00001?o8^`001?l0003ob[P0olZh0?o:^005o`0000?oc;<000?o0000olf_0?o=[`000_o=[`001?l0
003ocj/0oln[0?o?Z`05o`0000Cocj/000Co0000om2V0?o@YP3od:H01Ol00013ooooo`Co00007_oo
ool005Kooooo00?o0000ooooooooool08?ooool00ol0003o[kl0ojno0002ojno0003o`000?nn``3o
_/<000;o_/<000Co0000olG40?o5a03oaL@01?l00004olNo0004o`000?o8^`3ob;/0olRk00Go0000
0oo:]`000ol0003oc;<0olbc0003olbc0003o`000?o=[`3ocJl000Go00001?o=[`001?l0003ocj/0
oln[0?o?Z`05o`0004Gooooo0ol0000Rooooo`00Eoooool2o`00027ooooo3Ol00003olG30004o`00
0?o7_`3oakl0olNo00Go00000oo8^`000ol0003ob[L0olZg0003olZg0004o`000?o</`3oc;<0olbc
00Co00001?o</`001?l0003ocJl0olf_0?o=[`05o`0004Kooooo1?l0000Uooooo`00FOooool00ol0
003oooooooooo`0Oooooo`03o`000?na`03o/L0000;o/L0000?o0000ol330?o0``000oo0``000ol0
003oaL<0olG30005o`0000?oakh000?o0000olRk0?o8^`000oo8^`001?l0003ob[L0olZg0?o:]`05
o`0000?ob[L000Co0000olbc0?o</`3oc;<01Ol00017ooooo`Co0000:Oooool005[ooooo00?o0000
ooooooooool07oooool00ol0003o/L00ok700002ok700004o`000?o0``3o`<<0ol3300Co00000oo5
`P000ol0003oakh0olNn0003olNn0004o`000?o8^`3ob;/0olRk00Go00000oo9^P001?l0003ob[L0
olZg0?o:]`05o`0004Sooooo1?l0000]ooooo`00Foooool00ol0003oooooooooo`0Oooooo`So0000
0_o2a0000ol0003oaL80olG20003olG20004o`000?o7_P3oakh0olNn00Go00000oo7_P001?l0003o
bKX0olVj0?o9^P05o`0004Wooooo1?l0000aooooo`00G?ooool00ol0003oooooooooo`0Oooooo`;o
00001?nb`0001Ol0003o`/@0ol;40?o2a03o000000?oaL801Ol00004olK10003o`000?o7_P3oakh0
00Go0000B_ooool4o`0003Gooooo001Mooooo`;o00008?ooool=o`0000?oa<@02Ol0001<ooooo`?o
0000>Oooool005oooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00003ojjo0004
o`000?nm``3o_L<0okg300Go0000DOooool4o`0003cooooo001Pooooo`03o`000?oooooooooo01co
oooo00Co0000oooooooooooooooo1ol0001Booooo`Co0000@?ooool0067ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Fooooo`Co0000A?ooool006;ooooo0_l0000Kooooo`03o`00
0?oooooooooo05;ooooo1?l00018ooooo`00I?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo04kooooo1?l0001<ooooo`00IOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo04_ooooo0ol0001@ooooo`00I_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Oooooo1?l0001Cooooo`00Ioooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?o
oooo1?l0001Gooooo`00J?ooool2o`0001Gooooo00?o0000ooooooooool0?oooool4o`0005_ooooo
001Zooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>oooool4o`0005oooooo001[
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool4o`0006?ooooo001/oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=?ooool3o`0006Oooooo001]ooooo`;o
00004?ooool00ol0003oooooooooo`0`ooooo`Co0000J_ooool006oooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0]ooooo`Co0000K_ooool0073ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Yooooo`Co0000L_ooool0077ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Uooooo`Co0000M_ooool007;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Qooooo`Co0000N_ooool007?ooooo0_l00009ooooo`03o`000?oooooooooo01ko
oooo0ol0001nooooo`00MOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo
1?l00021ooooo`00M_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0
0025ooooo`00Moooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l00029
ooooo`00N?ooool2o`0000Cooooo00?o0000ooooooooool03_ooool4o`0008gooooo001jooooo`05
o`000?ooooooooooooooool000003?ooool4o`00097ooooo001kooooo`04o`000?ooooooooooo`00
00Wooooo0ol0002Eooooo`00O?ooool00ol0003oooooo`000005ooooo`Co0000V?ooool007gooooo
0_l000000ooooooo0000o`000002o`0009cooooo001nooooo`;o0000X?ooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00=3ooooo0ol0001=ooooo`00dOooool00ol0003ooooooooo
o`1<ooooo`00Goooool00ol0003oooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02
ooooo`?o00002?ooool3o`0000?ooooo0ol00004ooooo`?o00000_ooool3o`000003ooooool0003o
000000;ooooo0_l00008ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l0
0003ooooo`?o00000_ooool3o`000003ooooool0003o000000Co00000_ooool5o`0000?ooooo0_l0
0004ooooo`03o`000?oooooooooo04_ooooo001Oooooo`03o`000?oooooo000000;ooooo00Co0000
oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003o
ooooooooool00005ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo04_ooooo001Oooooo`03o`000?oooooo000000?ooooo0ol00003
ooooo`03o`000?oooooo000000;ooooo1Ol00008ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01?l0003oooooooooool00002oooo
o`?o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool00000C?ooool005kooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000008ooooo`?o
00000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`00001<ooooo`00G_ooool01Ol0003oooooo`000?oooooo0000
00;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Wooooo00?o0000oooo
ooooool00_ooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`Co00000_ooool4o`00
00[ooooo00Co0000oooooooooooooooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003
ooooo`Co000000Coooooo`000?l0003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`00
001;ooooo`00G_ooool01Ol0003oooooo`000?oooooo000001[ooooo00Co0000oooooooooooo0000
5?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`1Booooo`00G_ooool6o`0001Sooooo1Ol0000Dooooo`03o`000?oo
oooooooo00Sooooo1Ol00008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Booooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0756894, 0.0565345, \
0.00358287, 0.00358287}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.145 .19996 -11.928 -9 ]
[.145 .19996 .072 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.53856 .04519 -5.2094 -9 ]
[.53856 .04519 .7906 0 ]
[.76828 .09829 0 -6.16064 ]
[.76828 .09829 12 2.83936 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93414 .35229 0 -5.9206 ]
[.93414 .35229 6 3.0794 ]
[.02453 .2625 -24 -2.74012 ]
[.02453 .2625 0 6.25988 ]
[.01601 .31592 -24 -2.78527 ]
[.01601 .31592 0 6.21473 ]
[.00718 .37122 -24 -2.83219 ]
[.00718 .37122 0 6.16781 ]
[-0.00196 .42851 -24 -2.88096 ]
[-0.00196 .42851 0 6.11904 ]
[-0.01143 .4879 -6 -2.93172 ]
[-0.01143 .4879 0 6.06828 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15423 .2093 m
.15884 .21396 L
s
[(-5)] .145 .19996 .988 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54634 .05576 m
.55023 .06104 L
s
[(5)] .53856 .04519 .73647 1 Mshowa
.125 Mabswid
.19091 .19493 m
.19364 .19777 L
s
.22813 .18036 m
.23082 .18323 L
s
.26589 .16558 m
.26854 .16848 L
s
.30419 .15058 m
.30681 .15352 L
s
.38251 .11991 m
.38504 .12293 L
s
.42255 .10423 m
.42503 .10729 L
s
.46319 .08832 m
.46563 .09141 L
s
.50445 .07216 m
.50683 .07529 L
s
.11806 .22346 m
.12086 .22623 L
s
.0824 .23742 m
.08523 .24016 L
s
.04723 .25119 m
.0501 .25389 L
s
.58887 .0391 m
.59115 .04231 L
s
.63207 .02219 m
.63429 .02544 L
s
.67594 .00501 m
.67811 .0083 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75597 .10284 m
.74981 .10511 L
s
[(-5)] .76828 .09829 -1 .36903 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92163 .35624 m
.91537 .35822 L
s
[(5)] .93414 .35229 -1 .31569 Mshowa
.125 Mabswid
.77453 .13124 m
.77083 .13258 L
s
.79261 .15889 m
.7889 .16021 L
s
.81021 .18582 m
.8065 .18712 L
s
.82736 .21205 m
.82364 .21334 L
s
.86037 .26253 m
.85663 .26378 L
s
.87625 .28683 m
.87251 .28807 L
s
.89175 .31054 m
.888 .31176 L
s
.90687 .33367 m
.90312 .33487 L
s
.73688 .07365 m
.7332 .07503 L
s
.71727 .04365 m
.71359 .04505 L
s
.6971 .01279 m
.69343 .01422 L
s
.93604 .37828 m
.93228 .37945 L
s
.95011 .39981 m
.94634 .40096 L
s
.96385 .42083 m
.96008 .42197 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03675 .25772 m
.04286 .25533 L
s
[(-400)] .02453 .2625 1 -0.39109 Mshowa
.02827 .31124 m
.0344 .30891 L
s
[(-300)] .01601 .31592 1 -0.38105 Mshowa
.01949 .36666 m
.02564 .36438 L
s
[(-200)] .00718 .37122 1 -0.37063 Mshowa
.01039 .42407 m
.01656 .42185 L
s
[(-100)] -0.00196 .42851 1 -0.35979 Mshowa
.00096 .48358 m
.00715 .48142 L
s
[(0)] -0.01143 .4879 1 -0.34851 Mshowa
.125 Mabswid
.03508 .26828 m
.03875 .26685 L
s
.03339 .27891 m
.03706 .27749 L
s
.0317 .28961 m
.03537 .2882 L
s
.02999 .30039 m
.03366 .29898 L
s
.02654 .32217 m
.03022 .32078 L
s
.02479 .33318 m
.02848 .33179 L
s
.02304 .34426 m
.02672 .34288 L
s
.02127 .35542 m
.02496 .35404 L
s
.01769 .37798 m
.02139 .37662 L
s
.01589 .38938 m
.01958 .38802 L
s
.01407 .40086 m
.01777 .39951 L
s
.01224 .41242 m
.01594 .41108 L
s
.00853 .4358 m
.01224 .43447 L
s
.00666 .44762 m
.01037 .4463 L
s
.00477 .45952 m
.00848 .45821 L
s
.00287 .47151 m
.00659 .4702 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .1 .195 r
.39479 .6069 .40512 .60371 .42102 .61995 .41077 .62258 Metetra
0 .254 .284 r
.41077 .62258 .42102 .61995 .43728 .63441 .4271 .63649 Metetra
0 .364 .276 r
.4271 .63649 .43728 .63441 .45386 .64716 .44376 .64872 Metetra
0 .435 .195 r
.44376 .64872 .45386 .64716 .47075 .65828 .46073 .65935 Metetra
0 .499 .085 r
.46073 .65935 .47075 .65828 .48792 .66786 .47799 .66845 Metetra
.044 .557 0 r
.47799 .66845 .48792 .66786 .50535 .67597 .49552 .67611 Metetra
.181 .607 0 r
.49552 .67611 .50535 .67597 .52303 .68267 .51329 .68238 Metetra
.321 .652 0 r
.51329 .68238 .52303 .68267 .54094 .68804 .53129 .68735 Metetra
.458 .691 0 r
.53129 .68735 .54094 .68804 .55906 .69213 .5495 .69107 Metetra
.588 .725 0 r
.5495 .69107 .55906 .69213 .57737 .69501 .56791 .69359 Metetra
.706 .754 0 r
.56791 .69359 .57737 .69501 .59587 .69671 .58651 .69498 Metetra
.779 .746 0 r
.58651 .69498 .59587 .69671 .61453 .6973 .60527 .69527 Metetra
.799 .696 0 r
.60527 .69527 .61453 .6973 .63334 .69681 .62419 .69452 Metetra
.815 .654 0 r
.62419 .69452 .63334 .69681 .65229 .69528 .64325 .69275 Metetra
.827 .621 0 r
.64325 .69275 .65229 .69528 .67136 .69273 .66244 .68999 Metetra
.835 .598 0 r
.66244 .68999 .67136 .69273 .69055 .6892 .68174 .68628 Metetra
.839 .585 0 r
.68174 .68628 .69055 .6892 .70983 .68469 .70115 .68163 Metetra
.84 .583 0 r
.70115 .68163 .70983 .68469 .7292 .67921 .72065 .67605 Metetra
.837 .591 0 r
.72065 .67605 .7292 .67921 .74864 .67278 .74022 .66953 Metetra
.831 .61 0 r
.74022 .66953 .74864 .67278 .76814 .66538 .75985 .66209 Metetra
.821 .638 0 r
.75985 .66209 .76814 .66538 .78768 .65701 .77954 .65371 Metetra
.807 .675 0 r
.77954 .65371 .78768 .65701 .80724 .64764 .79925 .64436 Metetra
.789 .72 0 r
.79925 .64436 .80724 .64764 .8268 .63724 .81897 .63403 Metetra
.765 .768 0 r
.81897 .63403 .8268 .63724 .84635 .62577 .83869 .62267 Metetra
.658 .743 0 r
.83869 .62267 .84635 .62577 .86585 .61319 .85838 .61024 Metetra
.54 .713 0 r
.85838 .61024 .86585 .61319 .8853 .59944 .87801 .59667 Metetra
.414 .679 0 r
.87801 .59667 .8853 .59944 .90465 .58444 .89757 .58191 Metetra
.282 .64 0 r
.89757 .58191 .90465 .58444 .92387 .56812 .91701 .56587 Metetra
.148 .596 0 r
.91701 .56587 .92387 .56812 .94294 .55039 .9363 .54847 Metetra
.017 .546 0 r
.9363 .54847 .94294 .55039 .9618 .53113 .95541 .52959 Metetra
0 .489 .105 r
.95541 .52959 .9618 .53113 .98042 .51024 .97429 .50912 Metetra
0 .18 .246 r
.38431 .60878 .39479 .6069 .41077 .62258 .40037 .62393 Metetra
0 .331 .297 r
.40037 .62393 .41077 .62258 .4271 .63649 .41678 .63733 Metetra
0 .408 .23 r
.41678 .63733 .4271 .63649 .44376 .64872 .43352 .64907 Metetra
0 .477 .126 r
.43352 .64907 .44376 .64872 .46073 .65935 .45057 .65922 Metetra
.002 .539 0 r
.45057 .65922 .46073 .65935 .47799 .66845 .46791 .66788 Metetra
.144 .594 0 r
.46791 .66788 .47799 .66845 .49552 .67611 .48552 .67511 Metetra
.291 .643 0 r
.48552 .67511 .49552 .67611 .51329 .68238 .50338 .68098 Metetra
.439 .686 0 r
.50338 .68098 .51329 .68238 .53129 .68735 .52147 .68557 Metetra
.58 .724 0 r
.52147 .68557 .53129 .68735 .5495 .69107 .53978 .68893 Metetra
.713 .756 0 r
.53978 .68893 .5495 .69107 .56791 .69359 .55828 .69112 Metetra
.784 .734 0 r
.55828 .69112 .56791 .69359 .58651 .69498 .57698 .6922 Metetra
.807 .675 0 r
.57698 .6922 .58651 .69498 .60527 .69527 .59584 .69221 Metetra
.826 .623 0 r
.59584 .69221 .60527 .69527 .62419 .69452 .61486 .6912 Metetra
.841 .58 0 r
.61486 .6912 .62419 .69452 .64325 .69275 .63403 .68921 Metetra
.852 .546 0 r
.63403 .68921 .64325 .69275 .66244 .68999 .65333 .68625 Metetra
.86 .523 0 r
.65333 .68625 .66244 .68999 .68174 .68628 .67275 .68237 Metetra
.864 .511 0 r
.67275 .68237 .68174 .68628 .70115 .68163 .69227 .67758 Metetra
.864 .509 0 r
.69227 .67758 .70115 .68163 .72065 .67605 .71189 .67188 Metetra
.861 .519 0 r
.71189 .67188 .72065 .67605 .74022 .66953 .7316 .66528 Metetra
.855 .539 0 r
.7316 .66528 .74022 .66953 .75985 .66209 .75137 .65779 Metetra
.845 .568 0 r
.75137 .65779 .75985 .66209 .77954 .65371 .77119 .64939 Metetra
.831 .607 0 r
.77119 .64939 .77954 .65371 .79925 .64436 .79105 .64006 Metetra
.815 .655 0 r
.79105 .64006 .79925 .64436 .81897 .63403 .81093 .62977 Metetra
.794 .709 0 r
.81093 .62977 .81897 .63403 .83869 .62267 .83081 .6185 Metetra
.769 .769 0 r
.83081 .6185 .83869 .62267 .85838 .61024 .85067 .60619 Metetra
.65 .741 0 r
.85067 .60619 .85838 .61024 .87801 .59667 .87049 .59278 Metetra
.52 .708 0 r
.87049 .59278 .87801 .59667 .89757 .58191 .89024 .57822 Metetra
.383 .67 0 r
.89024 .57822 .89757 .58191 .91701 .56587 .90989 .56243 Metetra
.243 .628 0 r
.90989 .56243 .91701 .56587 .9363 .54847 .9294 .54531 Metetra
.103 .58 0 r
.9294 .54531 .9363 .54847 .95541 .52959 .94875 .52677 Metetra
0 .525 .03 r
.94875 .52677 .95541 .52959 .97429 .50912 .96788 .50669 Metetra
0 .27 .291 r
.37371 .60943 .38431 .60878 .40037 .62393 .38983 .62408 Metetra
0 .374 .267 r
.38983 .62408 .40037 .62393 .41678 .63733 .40631 .637 Metetra
0 .448 .176 r
.40631 .637 .41678 .63733 .43352 .64907 .42313 .64828 Metetra
0 .515 .053 r
.42313 .64828 .43352 .64907 .45057 .65922 .44026 .658 Metetra
.089 .574 0 r
.44026 .658 .45057 .65922 .46791 .66788 .45768 .66624 Metetra
.242 .627 0 r
.45768 .66624 .46791 .66788 .48552 .67511 .47537 .67307 Metetra
.397 .674 0 r
.47537 .67307 .48552 .67511 .50338 .68098 .49331 .67856 Metetra
.549 .716 0 r
.49331 .67856 .50338 .68098 .52147 .68557 .51149 .68279 Metetra
.694 .752 0 r
.51149 .68279 .52147 .68557 .53978 .68893 .52989 .68581 Metetra
.783 .737 0 r
.52989 .68581 .53978 .68893 .55828 .69112 .54849 .68769 Metetra
.809 .669 0 r
.54849 .68769 .55828 .69112 .57698 .6922 .56728 .68848 Metetra
.831 .608 0 r
.56728 .68848 .57698 .6922 .59584 .69221 .58624 .68822 Metetra
.849 .554 0 r
.58624 .68822 .59584 .69221 .61486 .6912 .60536 .68697 Metetra
.864 .511 0 r
.60536 .68697 .61486 .6912 .63403 .68921 .62463 .68475 Metetra
.874 .477 0 r
.62463 .68475 .63403 .68921 .65333 .68625 .64404 .68161 Metetra
.881 .454 0 r
.64404 .68161 .65333 .68625 .67275 .68237 .66357 .67756 Metetra
.884 .443 0 r
.66357 .67756 .67275 .68237 .69227 .67758 .68321 .67262 Metetra
.885 .442 0 r
.68321 .67262 .69227 .67758 .71189 .67188 .70296 .66681 Metetra
.881 .453 0 r
.70296 .66681 .71189 .67188 .7316 .66528 .72278 .66013 Metetra
.875 .474 0 r
.72278 .66013 .7316 .66528 .75137 .65779 .74269 .65257 Metetra
.865 .505 0 r
.74269 .65257 .75137 .65779 .77119 .64939 .76265 .64414 Metetra
.852 .545 0 r
.76265 .64414 .77119 .64939 .79105 .64006 .78265 .63481 Metetra
.836 .594 0 r
.78265 .63481 .79105 .64006 .81093 .62977 .80268 .62456 Metetra
.816 .651 0 r
.80268 .62456 .81093 .62977 .83081 .6185 .82272 .61335 Metetra
.792 .713 0 r
.82272 .61335 .83081 .6185 .85067 .60619 .84275 .60114 Metetra
.749 .765 0 r
.84275 .60114 .85067 .60619 .87049 .59278 .86275 .58787 Metetra
.617 .733 0 r
.86275 .58787 .87049 .59278 .89024 .57822 .88268 .57349 Metetra
.477 .697 0 r
.88268 .57349 .89024 .57822 .90989 .56243 .90253 .5579 Metetra
.332 .655 0 r
.90253 .5579 .90989 .56243 .9294 .54531 .92226 .54104 Metetra
.186 .609 0 r
.92226 .54104 .9294 .54531 .94875 .52677 .94182 .52279 Metetra
.044 .557 0 r
.94182 .52279 .94875 .52677 .96788 .50669 .96119 .50304 Metetra
0 .331 .298 r
.36297 .60893 .37371 .60943 .38983 .62408 .37915 .62312 Metetra
0 .411 .227 r
.37915 .62312 .38983 .62408 .40631 .637 .3957 .6356 Metetra
0 .483 .116 r
.3957 .6356 .40631 .637 .42313 .64828 .41259 .64645 Metetra
.022 .548 0 r
.41259 .64645 .42313 .64828 .44026 .658 .4298 .65576 Metetra
.175 .605 0 r
.4298 .65576 .44026 .658 .45768 .66624 .4473 .6636 Metetra
.335 .656 0 r
.4473 .6636 .45768 .66624 .47537 .67307 .46507 .67005 Metetra
.496 .702 0 r
.46507 .67005 .47537 .67307 .49331 .67856 .48309 .67519 Metetra
.652 .741 0 r
.48309 .67519 .49331 .67856 .51149 .68279 .50136 .67908 Metetra
.776 .753 0 r
.50136 .67908 .51149 .68279 .52989 .68581 .51984 .68179 Metetra
.806 .678 0 r
.51984 .68179 .52989 .68581 .54849 .68769 .53854 .68337 Metetra
.831 .608 0 r
.53854 .68337 .54849 .68769 .56728 .68848 .55742 .68389 Metetra
.852 .545 0 r
.55742 .68389 .56728 .68848 .58624 .68822 .57648 .68338 Metetra
.87 .492 0 r
.57648 .68338 .58624 .68822 .60536 .68697 .5957 .68189 Metetra
.883 .448 0 r
.5957 .68189 .60536 .68697 .62463 .68475 .61507 .67947 Metetra
.893 .415 0 r
.61507 .67947 .62463 .68475 .64404 .68161 .63459 .67614 Metetra
.899 .393 0 r
.63459 .67614 .64404 .68161 .66357 .67756 .65423 .67192 Metetra
.902 .382 0 r
.65423 .67192 .66357 .67756 .68321 .67262 .67398 .66684 Metetra
.902 .382 0 r
.67398 .66684 .68321 .67262 .70296 .66681 .69384 .66092 Metetra
.899 .394 0 r
.69384 .66092 .70296 .66681 .72278 .66013 .71379 .65415 Metetra
.892 .416 0 r
.71379 .65415 .72278 .66013 .74269 .65257 .73382 .64653 Metetra
.883 .448 0 r
.73382 .64653 .74269 .65257 .76265 .64414 .75392 .63806 Metetra
.87 .49 0 r
.75392 .63806 .76265 .64414 .78265 .63481 .77406 .62872 Metetra
.854 .54 0 r
.77406 .62872 .78265 .63481 .80268 .62456 .79424 .61849 Metetra
.835 .598 0 r
.79424 .61849 .80268 .62456 .82272 .61335 .81444 .60733 Metetra
.812 .662 0 r
.81444 .60733 .82272 .61335 .84275 .60114 .83463 .59519 Metetra
.785 .732 0 r
.83463 .59519 .84275 .60114 .86275 .58787 .85479 .58204 Metetra
.705 .754 0 r
.85479 .58204 .86275 .58787 .88268 .57349 .87491 .56779 Metetra
.563 .719 0 r
.87491 .56779 .88268 .57349 .90253 .5579 .89495 .55239 Metetra
.415 .679 0 r
.89495 .55239 .90253 .5579 .92226 .54104 .91487 .53574 Metetra
.264 .635 0 r
.91487 .53574 .92226 .54104 .94182 .52279 .93466 .51775 Metetra
.115 .584 0 r
.93466 .51775 .94182 .52279 .96119 .50304 .95425 .4983 Metetra
0 .366 .273 r
.3521 .60734 .36297 .60893 .37915 .62312 .36835 .62111 Metetra
0 .444 .182 r
.36835 .62111 .37915 .62312 .3957 .6356 .38496 .63318 Metetra
0 .514 .055 r
.38496 .63318 .3957 .6356 .41259 .64645 .40192 .64364 Metetra
.095 .576 0 r
.40192 .64364 .41259 .64645 .4298 .65576 .41919 .65257 Metetra
.257 .632 0 r
.41919 .65257 .4298 .65576 .4473 .6636 .43677 .66004 Metetra
.423 .682 0 r
.43677 .66004 .4473 .6636 .46507 .67005 .45462 .66615 Metetra
.588 .726 0 r
.45462 .66615 .46507 .67005 .48309 .67519 .47272 .67096 Metetra
.746 .764 0 r
.47272 .67096 .48309 .67519 .50136 .67908 .49107 .67454 Metetra
.797 .701 0 r
.49107 .67454 .50136 .67908 .51984 .68179 .50964 .67695 Metetra
.826 .623 0 r
.50964 .67695 .51984 .68179 .53854 .68337 .52842 .67825 Metetra
.85 .552 0 r
.52842 .67825 .53854 .68337 .55742 .68389 .5474 .67851 Metetra
.87 .489 0 r
.5474 .67851 .55742 .68389 .57648 .68338 .56655 .67776 Metetra
.887 .435 0 r
.56655 .67776 .57648 .68338 .5957 .68189 .58587 .67605 Metetra
.9 .392 0 r
.58587 .67605 .5957 .68189 .61507 .67947 .60535 .67343 Metetra
.909 .359 0 r
.60535 .67343 .61507 .67947 .63459 .67614 .62496 .66991 Metetra
.915 .338 0 r
.62496 .66991 .63459 .67614 .65423 .67192 .64471 .66554 Metetra
.917 .328 0 r
.64471 .66554 .65423 .67192 .67398 .66684 .66458 .66033 Metetra
.917 .329 0 r
.66458 .66033 .67398 .66684 .69384 .66092 .68456 .65429 Metetra
.914 .342 0 r
.68456 .65429 .69384 .66092 .71379 .65415 .70463 .64742 Metetra
.907 .365 0 r
.70463 .64742 .71379 .65415 .73382 .64653 .72479 .63974 Metetra
.898 .398 0 r
.72479 .63974 .73382 .64653 .75392 .63806 .74501 .63122 Metetra
.885 .44 0 r
.74501 .63122 .75392 .63806 .77406 .62872 .76529 .62186 Metetra
.87 .492 0 r
.76529 .62186 .77406 .62872 .79424 .61849 .78561 .61164 Metetra
.851 .551 0 r
.78561 .61164 .79424 .61849 .81444 .60733 .80596 .60051 Metetra
.828 .617 0 r
.80596 .60051 .81444 .60733 .83463 .59519 .82631 .58843 Metetra
.802 .688 0 r
.82631 .58843 .83463 .59519 .85479 .58204 .84664 .57536 Metetra
.772 .762 0 r
.84664 .57536 .85479 .58204 .87491 .56779 .86693 .56124 Metetra
.639 .738 0 r
.86693 .56124 .87491 .56779 .89495 .55239 .88715 .54598 Metetra
.489 .7 0 r
.88715 .54598 .89495 .55239 .91487 .53574 .90727 .52952 Metetra
.335 .656 0 r
.90727 .52952 .91487 .53574 .93466 .51775 .92726 .51174 Metetra
.182 .608 0 r
.92726 .51174 .93466 .51775 .95425 .4983 .94707 .49254 Metetra
0 .397 .243 r
.3411 .60475 .3521 .60734 .36835 .62111 .35741 .61813 Metetra
0 .473 .135 r
.35741 .61813 .36835 .62111 .38496 .63318 .37408 .62982 Metetra
.005 .541 0 r
.37408 .62982 .38496 .63318 .40192 .64364 .39111 .63991 Metetra
.164 .602 0 r
.39111 .63991 .40192 .64364 .41919 .65257 .40845 .64849 Metetra
.333 .656 0 r
.40845 .64849 .41919 .65257 .43677 .66004 .42609 .65563 Metetra
.504 .704 0 r
.42609 .65563 .43677 .66004 .45462 .66615 .44402 .66142 Metetra
.672 .746 0 r
.44402 .66142 .45462 .66615 .47272 .67096 .4622 .66592 Metetra
.783 .736 0 r
.4622 .66592 .47272 .67096 .49107 .67454 .48063 .66921 Metetra
.815 .652 0 r
.48063 .66921 .49107 .67454 .50964 .67695 .49929 .67134 Metetra
.843 .573 0 r
.49929 .67134 .50964 .67695 .52842 .67825 .51816 .67239 Metetra
.866 .501 0 r
.51816 .67239 .52842 .67825 .5474 .67851 .53722 .6724 Metetra
.886 .438 0 r
.53722 .6724 .5474 .67851 .56655 .67776 .55647 .67143 Metetra
.902 .385 0 r
.55647 .67143 .56655 .67776 .58587 .67605 .57588 .66951 Metetra
.914 .342 0 r
.57588 .66951 .58587 .67605 .60535 .67343 .59546 .6667 Metetra
.922 .31 0 r
.59546 .6667 .60535 .67343 .62496 .66991 .61518 .66301 Metetra
.928 .29 0 r
.61518 .66301 .62496 .66991 .64471 .66554 .63504 .65849 Metetra
.93 .281 0 r
.63504 .65849 .64471 .66554 .66458 .66033 .65502 .65314 Metetra
.93 .283 0 r
.65502 .65314 .66458 .66033 .68456 .65429 .67511 .64698 Metetra
.926 .296 0 r
.67511 .64698 .68456 .65429 .70463 .64742 .6953 .64003 Metetra
.92 .32 0 r
.6953 .64003 .70463 .64742 .72479 .63974 .71558 .63227 Metetra
.91 .354 0 r
.71558 .63227 .72479 .63974 .74501 .63122 .73593 .6237 Metetra
.898 .397 0 r
.73593 .6237 .74501 .63122 .76529 .62186 .75635 .61431 Metetra
.883 .449 0 r
.75635 .61431 .76529 .62186 .78561 .61164 .77681 .60408 Metetra
.864 .509 0 r
.77681 .60408 .78561 .61164 .80596 .60051 .7973 .59296 Metetra
.842 .576 0 r
.7973 .59296 .80596 .60051 .82631 .58843 .8178 .58093 Metetra
.817 .648 0 r
.8178 .58093 .82631 .58843 .84664 .57536 .83829 .56792 Metetra
.788 .725 0 r
.83829 .56792 .84664 .57536 .86693 .56124 .85875 .55389 Metetra
.707 .755 0 r
.85875 .55389 .86693 .56124 .88715 .54598 .87915 .53876 Metetra
.556 .717 0 r
.87915 .53876 .88715 .54598 .90727 .52952 .89946 .52244 Metetra
.4 .675 0 r
.89946 .52244 .90727 .52952 .92726 .51174 .91965 .50484 Metetra
.243 .628 0 r
.91965 .50484 .92726 .51174 .94707 .49254 .93967 .48586 Metetra
0 .424 .21 r
.32998 .60119 .3411 .60475 .35741 .61813 .34634 .61422 Metetra
0 .498 .088 r
.34634 .61422 .35741 .61813 .37408 .62982 .36307 .62557 Metetra
.063 .564 0 r
.36307 .62557 .37408 .62982 .39111 .63991 .38016 .63533 Metetra
.229 .623 0 r
.38016 .63533 .39111 .63991 .40845 .64849 .39757 .64359 Metetra
.403 .676 0 r
.39757 .64359 .40845 .64849 .42609 .65563 .41528 .65043 Metetra
.578 .723 0 r
.41528 .65043 .42609 .65563 .44402 .66142 .43328 .65592 Metetra
.747 .764 0 r
.43328 .65592 .44402 .66142 .4622 .66592 .45154 .66014 Metetra
.8 .693 0 r
.45154 .66014 .4622 .66592 .48063 .66921 .47005 .66315 Metetra
.831 .608 0 r
.47005 .66315 .48063 .66921 .49929 .67134 .48879 .66504 Metetra
.858 .529 0 r
.48879 .66504 .49929 .67134 .51816 .67239 .50774 .66584 Metetra
.88 .456 0 r
.50774 .66584 .51816 .67239 .53722 .6724 .52689 .66563 Metetra
.899 .393 0 r
.52689 .66563 .53722 .6724 .55647 .67143 .54623 .66444 Metetra
.914 .341 0 r
.54623 .66444 .55647 .67143 .57588 .66951 .56574 .66234 Metetra
.926 .299 0 r
.56574 .66234 .57588 .66951 .59546 .6667 .58542 .65934 Metetra
.934 .268 0 r
.58542 .65934 .59546 .6667 .61518 .66301 .60524 .65549 Metetra
.939 .248 0 r
.60524 .65549 .61518 .66301 .63504 .65849 .6252 .65082 Metetra
.941 .24 0 r
.6252 .65082 .63504 .65849 .65502 .65314 .64529 .64534 Metetra
.94 .243 0 r
.64529 .64534 .65502 .65314 .67511 .64698 .66549 .63907 Metetra
.937 .257 0 r
.66549 .63907 .67511 .64698 .6953 .64003 .6858 .63202 Metetra
.93 .282 0 r
.6858 .63202 .6953 .64003 .71558 .63227 .7062 .62418 Metetra
.921 .316 0 r
.7062 .62418 .71558 .63227 .73593 .6237 .72668 .61556 Metetra
.909 .36 0 r
.72668 .61556 .73593 .6237 .75635 .61431 .74723 .60613 Metetra
.893 .412 0 r
.74723 .60613 .75635 .61431 .77681 .60408 .76783 .59587 Metetra
.875 .473 0 r
.76783 .59587 .77681 .60408 .7973 .59296 .78846 .58476 Metetra
.854 .541 0 r
.78846 .58476 .7973 .59296 .8178 .58093 .80912 .57275 Metetra
.829 .614 0 r
.80912 .57275 .8178 .58093 .83829 .56792 .82976 .55979 Metetra
.801 .691 0 r
.82976 .55979 .83829 .56792 .85875 .55389 .85039 .54583 Metetra
.766 .769 0 r
.85039 .54583 .85875 .55389 .87915 .53876 .87096 .53079 Metetra
.614 .732 0 r
.87096 .53079 .87915 .53876 .89946 .52244 .89145 .51459 Metetra
.457 .691 0 r
.89145 .51459 .89946 .52244 .91965 .50484 .91183 .49714 Metetra
.297 .645 0 r
.91183 .49714 .91965 .50484 .93967 .48586 .93205 .47833 Metetra
0 .447 .177 r
.31873 .59672 .32998 .60119 .34634 .61422 .33514 .60943 Metetra
0 .52 .043 r
.33514 .60943 .34634 .61422 .36307 .62557 .35193 .62048 Metetra
.116 .584 0 r
.35193 .62048 .36307 .62557 .38016 .63533 .36907 .62995 Metetra
.289 .642 0 r
.36907 .62995 .38016 .63533 .39757 .64359 .38654 .63792 Metetra
.466 .694 0 r
.38654 .63792 .39757 .64359 .41528 .65043 .40432 .64447 Metetra
.643 .739 0 r
.40432 .64447 .41528 .65043 .43328 .65592 .42239 .6497 Metetra
.779 .746 0 r
.42239 .6497 .43328 .65592 .45154 .66014 .44073 .65366 Metetra
.814 .656 0 r
.44073 .65366 .45154 .66014 .47005 .66315 .45931 .65643 Metetra
.844 .569 0 r
.45931 .65643 .47005 .66315 .48879 .66504 .47813 .65808 Metetra
.87 .489 0 r
.47813 .65808 .48879 .66504 .50774 .66584 .49717 .65867 Metetra
.892 .417 0 r
.49717 .65867 .50774 .66584 .52689 .66563 .51641 .65824 Metetra
.91 .355 0 r
.51641 .65824 .52689 .66563 .54623 .66444 .53584 .65686 Metetra
.925 .302 0 r
.53584 .65686 .54623 .66444 .56574 .66234 .55545 .65457 Metetra
.936 .261 0 r
.55545 .65457 .56574 .66234 .58542 .65934 .57522 .65141 Metetra
.943 .231 0 r
.57522 .65141 .58542 .65934 .60524 .65549 .59514 .6474 Metetra
.948 .213 0 r
.59514 .6474 .60524 .65549 .6252 .65082 .61521 .64259 Metetra
.95 .206 0 r
.61521 .64259 .6252 .65082 .64529 .64534 .6354 .63698 Metetra
.949 .209 0 r
.6354 .63698 .64529 .64534 .66549 .63907 .65572 .6306 Metetra
.945 .224 0 r
.65572 .6306 .66549 .63907 .6858 .63202 .67615 .62346 Metetra
.939 .249 0 r
.67615 .62346 .6858 .63202 .7062 .62418 .69667 .61554 Metetra
.93 .284 0 r
.69667 .61554 .7062 .62418 .72668 .61556 .71727 .60685 Metetra
.917 .328 0 r
.71727 .60685 .72668 .61556 .74723 .60613 .73795 .59737 Metetra
.903 .381 0 r
.73795 .59737 .74723 .60613 .76783 .59587 .75868 .58709 Metetra
.885 .442 0 r
.75868 .58709 .76783 .59587 .78846 .58476 .77946 .57596 Metetra
.864 .51 0 r
.77946 .57596 .78846 .58476 .80912 .57275 .80026 .56395 Metetra
.839 .584 0 r
.80026 .56395 .80912 .57275 .82976 .55979 .82106 .55102 Metetra
.812 .662 0 r
.82106 .55102 .82976 .55979 .85039 .54583 .84184 .5371 Metetra
.78 .743 0 r
.84184 .5371 .85039 .54583 .87096 .53079 .86258 .52213 Metetra
.665 .745 0 r
.86258 .52213 .87096 .53079 .89145 .51459 .88325 .50602 Metetra
.507 .704 0 r
.88325 .50602 .89145 .51459 .91183 .49714 .90381 .48868 Metetra
.346 .659 0 r
.90381 .48868 .91183 .49714 .93205 .47833 .92423 .47 Metetra
0 .467 .144 r
.30737 .59139 .31873 .59672 .33514 .60943 .32382 .60383 Metetra
0 .538 .001 r
.32382 .60383 .33514 .60943 .35193 .62048 .34066 .6146 Metetra
.164 .602 0 r
.34066 .6146 .35193 .62048 .36907 .62995 .35785 .6238 Metetra
.341 .658 0 r
.35785 .6238 .36907 .62995 .38654 .63792 .37538 .63151 Metetra
.522 .709 0 r
.37538 .63151 .38654 .63792 .40432 .64447 .39323 .63782 Metetra
.7 .753 0 r
.39323 .63782 .40432 .64447 .42239 .6497 .41136 .64281 Metetra
.792 .714 0 r
.41136 .64281 .42239 .6497 .44073 .65366 .42977 .64654 Metetra
.826 .622 0 r
.42977 .64654 .44073 .65366 .45931 .65643 .44843 .64909 Metetra
.856 .535 0 r
.44843 .64909 .45931 .65643 .47813 .65808 .46733 .65052 Metetra
.881 .455 0 r
.46733 .65052 .47813 .65808 .49717 .65867 .48645 .65091 Metetra
.902 .383 0 r
.48645 .65091 .49717 .65867 .51641 .65824 .50578 .65029 Metetra
.919 .321 0 r
.50578 .65029 .51641 .65824 .53584 .65686 .5253 .64873 Metetra
.933 .27 0 r
.5253 .64873 .53584 .65686 .55545 .65457 .545 .64627 Metetra
.944 .23 0 r
.545 .64627 .55545 .65457 .57522 .65141 .56486 .64295 Metetra
.951 .201 0 r
.56486 .64295 .57522 .65141 .59514 .6474 .58489 .6388 Metetra
.956 .183 0 r
.58489 .6388 .59514 .6474 .61521 .64259 .60506 .63385 Metetra
.957 .177 0 r
.60506 .63385 .61521 .64259 .6354 .63698 .62536 .62812 Metetra
.956 .181 0 r
.62536 .62812 .6354 .63698 .65572 .6306 .64579 .62163 Metetra
.952 .196 0 r
.64579 .62163 .65572 .6306 .67615 .62346 .66633 .61439 Metetra
.946 .222 0 r
.66633 .61439 .67615 .62346 .69667 .61554 .68697 .60639 Metetra
.937 .257 0 r
.68697 .60639 .69667 .61554 .71727 .60685 .7077 .59763 Metetra
.925 .302 0 r
.7077 .59763 .71727 .60685 .73795 .59737 .72851 .58809 Metetra
.91 .355 0 r
.72851 .58809 .73795 .59737 .75868 .58709 .74937 .57776 Metetra
.892 .416 0 r
.74937 .57776 .75868 .58709 .77946 .57596 .77029 .56661 Metetra
.872 .484 0 r
.77029 .56661 .77946 .57596 .80026 .56395 .79123 .5546 Metetra
.848 .559 0 r
.79123 .5546 .80026 .56395 .82106 .55102 .81218 .54167 Metetra
.821 .638 0 r
.81218 .54167 .82106 .55102 .84184 .5371 .83312 .52777 Metetra
.79 .719 0 r
.83312 .52777 .84184 .5371 .86258 .52213 .85402 .51284 Metetra
.708 .755 0 r
.85402 .51284 .86258 .52213 .88325 .50602 .87486 .49678 Metetra
.55 .716 0 r
.87486 .49678 .88325 .50602 .90381 .48868 .8956 .47952 Metetra
.388 .672 0 r
.8956 .47952 .90381 .48868 .92423 .47 .91621 .46095 Metetra
0 .484 .114 r
.29588 .58524 .30737 .59139 .32382 .60383 .31237 .59743 Metetra
.037 .554 0 r
.31237 .59743 .32382 .60383 .34066 .6146 .32925 .60796 Metetra
.207 .616 0 r
.32925 .60796 .34066 .6146 .35785 .6238 .3465 .61693 Metetra
.388 .672 0 r
.3465 .61693 .35785 .6238 .37538 .63151 .36408 .62442 Metetra
.57 .721 0 r
.36408 .62442 .37538 .63151 .39323 .63782 .38199 .63051 Metetra
.749 .765 0 r
.38199 .63051 .39323 .63782 .41136 .64281 .40019 .63528 Metetra
.803 .686 0 r
.40019 .63528 .41136 .64281 .42977 .64654 .41867 .6388 Metetra
.836 .594 0 r
.41867 .6388 .42977 .64654 .44843 .64909 .4374 .64116 Metetra
.865 .506 0 r
.4374 .64116 .44843 .64909 .46733 .65052 .45638 .6424 Metetra
.889 .426 0 r
.45638 .6424 .46733 .65052 .48645 .65091 .47558 .6426 Metetra
.91 .355 0 r
.47558 .6426 .48645 .65091 .50578 .65029 .49499 .64182 Metetra
.927 .293 0 r
.49499 .64182 .50578 .65029 .5253 .64873 .5146 .64009 Metetra
.94 .243 0 r
.5146 .64009 .5253 .64873 .545 .64627 .53439 .63747 Metetra
.951 .203 0 r
.53439 .63747 .545 .64627 .56486 .64295 .55436 .634 Metetra
.958 .175 0 r
.55436 .634 .56486 .64295 .58489 .6388 .57448 .62971 Metetra
.962 .158 0 r
.57448 .62971 .58489 .6388 .60506 .63385 .59476 .62464 Metetra
.963 .152 0 r
.59476 .62464 .60506 .63385 .62536 .62812 .61517 .61879 Metetra
.962 .158 0 r
.61517 .61879 .62536 .62812 .64579 .62163 .63571 .61219 Metetra
.958 .173 0 r
.63571 .61219 .64579 .62163 .66633 .61439 .65636 .60485 Metetra
.952 .199 0 r
.65636 .60485 .66633 .61439 .68697 .60639 .67712 .59676 Metetra
.943 .235 0 r
.67712 .59676 .68697 .60639 .7077 .59763 .69797 .58793 Metetra
.931 .28 0 r
.69797 .58793 .7077 .59763 .72851 .58809 .71891 .57833 Metetra
.916 .333 0 r
.71891 .57833 .72851 .58809 .74937 .57776 .7399 .56795 Metetra
.899 .394 0 r
.7399 .56795 .74937 .57776 .77029 .56661 .76095 .55676 Metetra
.878 .463 0 r
.76095 .55676 .77029 .56661 .79123 .5546 .78204 .54472 Metetra
.855 .537 0 r
.78204 .54472 .79123 .5546 .81218 .54167 .80314 .53177 Metetra
.828 .617 0 r
.80314 .53177 .81218 .54167 .83312 .52777 .82423 .51788 Metetra
.798 .699 0 r
.82423 .51788 .83312 .52777 .85402 .51284 .84529 .50296 Metetra
.745 .764 0 r
.84529 .50296 .85402 .51284 .87486 .49678 .8663 .48694 Metetra
.586 .725 0 r
.8663 .48694 .87486 .49678 .8956 .47952 .88721 .46972 Metetra
.423 .682 0 r
.88721 .46972 .8956 .47952 .91621 .46095 .908 .45122 Metetra
0 .498 .087 r
.28428 .57828 .29588 .58524 .31237 .59743 .3008 .59027 Metetra
.069 .567 0 r
.3008 .59027 .31237 .59743 .32925 .60796 .31772 .6006 Metetra
.244 .628 0 r
.31772 .6006 .32925 .60796 .3465 .61693 .33501 .60937 Metetra
.427 .683 0 r
.33501 .60937 .3465 .61693 .36408 .62442 .35265 .61666 Metetra
.611 .731 0 r
.35265 .61666 .36408 .62442 .38199 .63051 .37061 .62256 Metetra
.774 .758 0 r
.37061 .62256 .38199 .63051 .40019 .63528 .38888 .62715 Metetra
.812 .662 0 r
.38888 .62715 .40019 .63528 .41867 .6388 .40742 .63049 Metetra
.844 .569 0 r
.40742 .63049 .41867 .6388 .4374 .64116 .42623 .63267 Metetra
.873 .482 0 r
.42623 .63267 .4374 .64116 .45638 .6424 .44528 .63375 Metetra
.897 .402 0 r
.44528 .63375 .45638 .6424 .47558 .6426 .46456 .63379 Metetra
.917 .331 0 r
.46456 .63379 .47558 .6426 .49499 .64182 .48406 .63284 Metetra
.933 .27 0 r
.48406 .63284 .49499 .64182 .5146 .64009 .50375 .63097 Metetra
.946 .22 0 r
.50375 .63097 .5146 .64009 .53439 .63747 .52364 .62821 Metetra
.956 .182 0 r
.52364 .62821 .53439 .63747 .55436 .634 .5437 .6246 Metetra
.963 .154 0 r
.5437 .6246 .55436 .634 .57448 .62971 .56392 .62018 Metetra
.967 .138 0 r
.56392 .62018 .57448 .62971 .59476 .62464 .5843 .61498 Metetra
.968 .133 0 r
.5843 .61498 .59476 .62464 .61517 .61879 .60482 .60903 Metetra
.967 .139 0 r
.60482 .60903 .61517 .61879 .63571 .61219 .62546 .60232 Metetra
.963 .155 0 r
.62546 .60232 .63571 .61219 .65636 .60485 .64623 .59488 Metetra
.956 .181 0 r
.64623 .59488 .65636 .60485 .67712 .59676 .66711 .58671 Metetra
.947 .217 0 r
.66711 .58671 .67712 .59676 .69797 .58793 .68809 .57779 Metetra
.935 .262 0 r
.68809 .57779 .69797 .58793 .71891 .57833 .70915 .56812 Metetra
.921 .315 0 r
.70915 .56812 .71891 .57833 .7399 .56795 .73028 .55768 Metetra
.904 .377 0 r
.73028 .55768 .7399 .56795 .76095 .55676 .75146 .54644 Metetra
.884 .445 0 r
.75146 .54644 .76095 .55676 .78204 .54472 .77269 .53435 Metetra
.861 .52 0 r
.77269 .53435 .78204 .54472 .80314 .53177 .79393 .52138 Metetra
.834 .6 0 r
.79393 .52138 .80314 .53177 .82423 .51788 .81517 .50746 Metetra
.804 .682 0 r
.81517 .50746 .82423 .51788 .84529 .50296 .83639 .49253 Metetra
.77 .766 0 r
.83639 .49253 .84529 .50296 .8663 .48694 .85756 .47652 Metetra
.616 .732 0 r
.85756 .47652 .8663 .48694 .88721 .46972 .87864 .45932 Metetra
.453 .69 0 r
.87864 .45932 .88721 .46972 .908 .45122 .8996 .44084 Metetra
0 .509 .065 r
.27255 .57056 .28428 .57828 .3008 .59027 .28911 .58237 Metetra
.096 .577 0 r
.28911 .58237 .3008 .59027 .31772 .6006 .30606 .59254 Metetra
.274 .638 0 r
.30606 .59254 .31772 .6006 .33501 .60937 .3234 .60114 Metetra
.459 .692 0 r
.3234 .60114 .33501 .60937 .35265 .61666 .34108 .60827 Metetra
.644 .739 0 r
.34108 .60827 .35265 .61666 .37061 .62256 .3591 .61401 Metetra
.782 .74 0 r
.3591 .61401 .37061 .62256 .38888 .62715 .37742 .61844 Metetra
.819 .643 0 r
.37742 .61844 .38888 .62715 .40742 .63049 .39603 .62163 Metetra
.851 .55 0 r
.39603 .62163 .40742 .63049 .42623 .63267 .41491 .62366 Metetra
.879 .462 0 r
.41491 .62366 .42623 .63267 .44528 .63375 .43403 .62459 Metetra
.902 .382 0 r
.43403 .62459 .44528 .63375 .46456 .63379 .45339 .62448 Metetra
.922 .312 0 r
.45339 .62448 .46456 .63379 .48406 .63284 .47297 .6234 Metetra
.938 .252 0 r
.47297 .6234 .48406 .63284 .50375 .63097 .49276 .62139 Metetra
.951 .203 0 r
.49276 .62139 .50375 .63097 .52364 .62821 .51273 .6185 Metetra
.96 .165 0 r
.51273 .6185 .52364 .62821 .5437 .6246 .53289 .61477 Metetra
.967 .138 0 r
.53289 .61477 .5437 .6246 .56392 .62018 .55321 .61023 Metetra
.971 .122 0 r
.55321 .61023 .56392 .62018 .5843 .61498 .57369 .60492 Metetra
.972 .118 0 r
.57369 .60492 .5843 .61498 .60482 .60903 .59431 .59885 Metetra
.971 .124 0 r
.59431 .59885 .60482 .60903 .62546 .60232 .61507 .59205 Metetra
.966 .14 0 r
.61507 .59205 .62546 .60232 .64623 .59488 .63595 .58451 Metetra
.96 .167 0 r
.63595 .58451 .64623 .59488 .66711 .58671 .65695 .57624 Metetra
.951 .203 0 r
.65695 .57624 .66711 .58671 .68809 .57779 .67804 .56724 Metetra
.939 .248 0 r
.67804 .56724 .68809 .57779 .70915 .56812 .69923 .5575 Metetra
.925 .302 0 r
.69923 .5575 .70915 .56812 .73028 .55768 .72049 .54698 Metetra
.908 .363 0 r
.72049 .54698 .73028 .55768 .75146 .54644 .74181 .53567 Metetra
.888 .432 0 r
.74181 .53567 .75146 .54644 .77269 .53435 .76317 .52353 Metetra
.865 .506 0 r
.76317 .52353 .77269 .53435 .79393 .52138 .78456 .51051 Metetra
.839 .586 0 r
.78456 .51051 .79393 .52138 .81517 .50746 .80595 .49655 Metetra
.809 .669 0 r
.80595 .49655 .81517 .50746 .83639 .49253 .82732 .48159 Metetra
.776 .753 0 r
.82732 .48159 .83639 .49253 .85756 .47652 .84865 .46555 Metetra
.64 .738 0 r
.84865 .46555 .85756 .47652 .87864 .45932 .8699 .44833 Metetra
.477 .696 0 r
.8699 .44833 .87864 .45932 .8996 .44084 .89103 .42985 Metetra
0 .518 .047 r
.26072 .56208 .27255 .57056 .28911 .58237 .2773 .57376 Metetra
.118 .585 0 r
.2773 .57376 .28911 .58237 .30606 .59254 .29428 .58379 Metetra
.297 .645 0 r
.29428 .58379 .30606 .59254 .3234 .60114 .31165 .59226 Metetra
.484 .698 0 r
.31165 .59226 .3234 .60114 .34108 .60827 .32938 .59926 Metetra
.67 .746 0 r
.32938 .59926 .34108 .60827 .3591 .61401 .34745 .60487 Metetra
.787 .725 0 r
.34745 .60487 .3591 .61401 .37742 .61844 .36583 .60917 Metetra
.824 .628 0 r
.36583 .60917 .37742 .61844 .39603 .62163 .3845 .61224 Metetra
.856 .535 0 r
.3845 .61224 .39603 .62163 .41491 .62366 .40344 .61414 Metetra
.883 .447 0 r
.40344 .61414 .41491 .62366 .43403 .62459 .42264 .61494 Metetra
.906 .368 0 r
.42264 .61494 .43403 .62459 .45339 .62448 .44207 .61472 Metetra
.926 .298 0 r
.44207 .61472 .45339 .62448 .47297 .6234 .46173 .61351 Metetra
.942 .238 0 r
.46173 .61351 .47297 .6234 .49276 .62139 .4816 .61138 Metetra
.954 .189 0 r
.4816 .61138 .49276 .62139 .51273 .6185 .50167 .60838 Metetra
.964 .152 0 r
.50167 .60838 .51273 .6185 .53289 .61477 .52192 .60453 Metetra
.97 .125 0 r
.52192 .60453 .53289 .61477 .55321 .61023 .54234 .59989 Metetra
.974 .11 0 r
.54234 .59989 .55321 .61023 .57369 .60492 .56292 .59447 Metetra
.975 .106 0 r
.56292 .59447 .57369 .60492 .59431 .59885 .58365 .58829 Metetra
.973 .113 0 r
.58365 .58829 .59431 .59885 .61507 .59205 .60452 .58139 Metetra
.969 .129 0 r
.60452 .58139 .61507 .59205 .63595 .58451 .62552 .57375 Metetra
.963 .156 0 r
.62552 .57375 .63595 .58451 .65695 .57624 .64663 .56539 Metetra
.953 .192 0 r
.64663 .56539 .65695 .57624 .67804 .56724 .66785 .5563 Metetra
.942 .238 0 r
.66785 .5563 .67804 .56724 .69923 .5575 .68916 .54647 Metetra
.928 .291 0 r
.68916 .54647 .69923 .5575 .72049 .54698 .71055 .53588 Metetra
.911 .353 0 r
.71055 .53588 .72049 .54698 .74181 .53567 .732 .52449 Metetra
.891 .421 0 r
.732 .52449 .74181 .53567 .76317 .52353 .7535 .51228 Metetra
.868 .496 0 r
.7535 .51228 .76317 .52353 .78456 .51051 .77503 .49919 Metetra
.842 .576 0 r
.77503 .49919 .78456 .51051 .80595 .49655 .79657 .48517 Metetra
.813 .659 0 r
.79657 .48517 .80595 .49655 .82732 .48159 .81809 .47015 Metetra
.78 .744 0 r
.81809 .47015 .82732 .48159 .84865 .46555 .83957 .45405 Metetra
.658 .743 0 r
.83957 .45405 .84865 .46555 .8699 .44833 .86098 .4368 Metetra
.495 .701 0 r
.86098 .4368 .8699 .44833 .89103 .42985 .88228 .41827 Metetra
0 .524 .034 r
.24878 .55285 .26072 .56208 .2773 .57376 .26537 .56444 Metetra
.133 .59 0 r
.26537 .56444 .2773 .57376 .29428 .58379 .28238 .57438 Metetra
.314 .65 0 r
.28238 .57438 .29428 .58379 .31165 .59226 .29978 .58275 Metetra
.502 .703 0 r
.29978 .58275 .31165 .59226 .32938 .59926 .31755 .58965 Metetra
.688 .75 0 r
.31755 .58965 .32938 .59926 .34745 .60487 .33566 .59516 Metetra
.791 .715 0 r
.33566 .59516 .34745 .60487 .36583 .60917 .35409 .59936 Metetra
.828 .618 0 r
.35409 .59936 .36583 .60917 .3845 .61224 .37282 .60232 Metetra
.859 .524 0 r
.37282 .60232 .3845 .61224 .40344 .61414 .39183 .60412 Metetra
.886 .437 0 r
.39183 .60412 .40344 .61414 .42264 .61494 .41109 .60482 Metetra
.909 .357 0 r
.41109 .60482 .42264 .61494 .44207 .61472 .43061 .60449 Metetra
.929 .287 0 r
.43061 .60449 .44207 .61472 .46173 .61351 .45035 .60319 Metetra
.944 .228 0 r
.45035 .60319 .46173 .61351 .4816 .61138 .4703 .60095 Metetra
.957 .18 0 r
.4703 .60095 .4816 .61138 .50167 .60838 .49046 .59785 Metetra
.966 .143 0 r
.49046 .59785 .50167 .60838 .52192 .60453 .5108 .5939 Metetra
.972 .117 0 r
.5108 .5939 .52192 .60453 .54234 .59989 .53132 .58915 Metetra
.976 .102 0 r
.53132 .58915 .54234 .59989 .56292 .59447 .552 .58363 Metetra
.977 .098 0 r
.552 .58363 .56292 .59447 .58365 .58829 .57284 .57736 Metetra
.975 .105 0 r
.57284 .57736 .58365 .58829 .60452 .58139 .59381 .57036 Metetra
.971 .122 0 r
.59381 .57036 .60452 .58139 .62552 .57375 .61492 .56263 Metetra
.964 .149 0 r
.61492 .56263 .62552 .57375 .64663 .56539 .63615 .55417 Metetra
.955 .185 0 r
.63615 .55417 .64663 .56539 .66785 .5563 .65749 .54499 Metetra
.944 .23 0 r
.65749 .54499 .66785 .5563 .68916 .54647 .67893 .53507 Metetra
.929 .284 0 r
.67893 .53507 .68916 .54647 .71055 .53588 .70045 .52438 Metetra
.913 .345 0 r
.70045 .52438 .71055 .53588 .732 .52449 .72203 .51291 Metetra
.893 .414 0 r
.72203 .51291 .732 .52449 .7535 .51228 .74367 .50061 Metetra
.87 .489 0 r
.74367 .50061 .7535 .51228 .77503 .49919 .76534 .48743 Metetra
.845 .568 0 r
.76534 .48743 .77503 .49919 .79657 .48517 .78702 .47333 Metetra
.816 .652 0 r
.78702 .47333 .79657 .48517 .81809 .47015 .80869 .45823 Metetra
.783 .737 0 r
.80869 .45823 .81809 .47015 .83957 .45405 .83033 .44206 Metetra
.671 .746 0 r
.83033 .44206 .83957 .45405 .86098 .4368 .85189 .42472 Metetra
.508 .705 0 r
.85189 .42472 .86098 .4368 .88228 .41827 .87335 .40613 Metetra
0 .527 .026 r
.23672 .54289 .24878 .55285 .26537 .56444 .25332 .55442 Metetra
.142 .594 0 r
.25332 .55442 .26537 .56444 .28238 .57438 .27035 .56429 Metetra
.324 .653 0 r
.27035 .56429 .28238 .57438 .29978 .58275 .28778 .57261 Metetra
.512 .706 0 r
.28778 .57261 .29978 .58275 .31755 .58965 .30558 .57944 Metetra
.699 .753 0 r
.30558 .57944 .31755 .58965 .33566 .59516 .32373 .58488 Metetra
.794 .709 0 r
.32373 .58488 .33566 .59516 .35409 .59936 .34221 .58901 Metetra
.83 .611 0 r
.34221 .58901 .35409 .59936 .37282 .60232 .361 .59189 Metetra
.861 .518 0 r
.361 .59189 .37282 .60232 .39183 .60412 .38007 .59362 Metetra
.888 .43 0 r
.38007 .59362 .39183 .60412 .41109 .60482 .3994 .59424 Metetra
.911 .351 0 r
.3994 .59424 .41109 .60482 .43061 .60449 .41899 .59382 Metetra
.93 .281 0 r
.41899 .59382 .43061 .60449 .45035 .60319 .43881 .59243 Metetra
.946 .222 0 r
.43881 .59243 .45035 .60319 .4703 .60095 .45884 .59011 Metetra
.958 .174 0 r
.45884 .59011 .4703 .60095 .49046 .59785 .47909 .58692 Metetra
.967 .137 0 r
.47909 .58692 .49046 .59785 .5108 .5939 .49952 .58288 Metetra
.974 .112 0 r
.49952 .58288 .5108 .5939 .53132 .58915 .52014 .57804 Metetra
.977 .097 0 r
.52014 .57804 .53132 .58915 .552 .58363 .54092 .57243 Metetra
.978 .093 0 r
.54092 .57243 .552 .58363 .57284 .57736 .56186 .56607 Metetra
.976 .1 0 r
.56186 .56607 .57284 .57736 .59381 .57036 .58295 .55897 Metetra
.972 .117 0 r
.58295 .55897 .59381 .57036 .61492 .56263 .60418 .55114 Metetra
.965 .144 0 r
.60418 .55114 .61492 .56263 .63615 .55417 .62552 .54259 Metetra
.956 .181 0 r
.62552 .54259 .63615 .55417 .65749 .54499 .64698 .53331 Metetra
.945 .226 0 r
.64698 .53331 .65749 .54499 .67893 .53507 .66854 .52329 Metetra
.931 .28 0 r
.66854 .52329 .67893 .53507 .70045 .52438 .69019 .5125 Metetra
.914 .341 0 r
.69019 .5125 .70045 .52438 .72203 .51291 .71191 .50093 Metetra
.894 .41 0 r
.71191 .50093 .72203 .51291 .74367 .50061 .73368 .48852 Metetra
.872 .484 0 r
.73368 .48852 .74367 .50061 .76534 .48743 .75549 .47524 Metetra
.846 .564 0 r
.75549 .47524 .76534 .48743 .78702 .47333 .77731 .46104 Metetra
.817 .647 0 r
.77731 .46104 .78702 .47333 .80869 .45823 .79913 .44583 Metetra
.785 .732 0 r
.79913 .44583 .80869 .45823 .83033 .44206 .82092 .42956 Metetra
.679 .748 0 r
.82092 .42956 .83033 .44206 .85189 .42472 .84264 .41212 Metetra
.515 .707 0 r
.84264 .41212 .85189 .42472 .87335 .40613 .86425 .39342 Metetra
0 .528 .023 r
.22457 .53218 .23672 .54289 .25332 .55442 .24117 .54369 Metetra
.145 .595 0 r
.24117 .54369 .25332 .55442 .27035 .56429 .25821 .55355 Metetra
.328 .654 0 r
.25821 .55355 .27035 .56429 .28778 .57261 .27565 .56183 Metetra
.516 .707 0 r
.27565 .56183 .28778 .57261 .30558 .57944 .29349 .56863 Metetra
.702 .754 0 r
.29349 .56863 .30558 .57944 .32373 .58488 .31168 .57403 Metetra
.795 .707 0 r
.31168 .57403 .32373 .58488 .34221 .58901 .3302 .57811 Metetra
.831 .609 0 r
.3302 .57811 .34221 .58901 .361 .59189 .34903 .58095 Metetra
.862 .516 0 r
.34903 .58095 .361 .59189 .38007 .59362 .36816 .58262 Metetra
.889 .428 0 r
.36816 .58262 .38007 .59362 .3994 .59424 .38756 .58318 Metetra
.912 .349 0 r
.38756 .58318 .3994 .59424 .41899 .59382 .40722 .58271 Metetra
.931 .279 0 r
.40722 .58271 .41899 .59382 .43881 .59243 .42711 .58125 Metetra
.946 .22 0 r
.42711 .58125 .43881 .59243 .45884 .59011 .44723 .57886 Metetra
.959 .172 0 r
.44723 .57886 .45884 .59011 .47909 .58692 .46756 .57559 Metetra
.968 .135 0 r
.46756 .57559 .47909 .58692 .49952 .58288 .48809 .57148 Metetra
.974 .11 0 r
.48809 .57148 .49952 .58288 .52014 .57804 .5088 .56656 Metetra
.977 .095 0 r
.5088 .56656 .52014 .57804 .54092 .57243 .52969 .56086 Metetra
.978 .092 0 r
.52969 .56086 .54092 .57243 .56186 .56607 .55073 .55441 Metetra
.977 .099 0 r
.55073 .55441 .56186 .56607 .58295 .55897 .57193 .54722 Metetra
.972 .116 0 r
.57193 .54722 .58295 .55897 .60418 .55114 .59327 .53929 Metetra
.966 .143 0 r
.59327 .53929 .60418 .55114 .62552 .54259 .61473 .53064 Metetra
.957 .179 0 r
.61473 .53064 .62552 .54259 .64698 .53331 .63631 .52126 Metetra
.945 .225 0 r
.63631 .52126 .64698 .53331 .66854 .52329 .658 .51113 Metetra
.931 .278 0 r
.658 .51113 .66854 .52329 .69019 .5125 .67977 .50024 Metetra
.914 .34 0 r
.67977 .50024 .69019 .5125 .71191 .50093 .70162 .48855 Metetra
.895 .408 0 r
.70162 .48855 .71191 .50093 .73368 .48852 .72353 .47603 Metetra
.872 .483 0 r
.72353 .47603 .73368 .48852 .75549 .47524 .74548 .46263 Metetra
.847 .563 0 r
.74548 .46263 .75549 .47524 .77731 .46104 .76744 .4483 Metetra
.818 .646 0 r
.76744 .4483 .77731 .46104 .79913 .44583 .78941 .43297 Metetra
.785 .731 0 r
.78941 .43297 .79913 .44583 .82092 .42956 .81134 .41656 Metetra
.681 .748 0 r
.81134 .41656 .82092 .42956 .84264 .41212 .83321 .39899 Metetra
.518 .707 0 r
.83321 .39899 .84264 .41212 .86425 .39342 .85498 .38014 Metetra
0 .527 .026 r
.21231 .52072 .22457 .53218 .24117 .54369 .2289 .53226 Metetra
.142 .594 0 r
.2289 .53226 .24117 .54369 .25821 .55355 .24595 .54212 Metetra
.324 .653 0 r
.24595 .54212 .25821 .55355 .27565 .56183 .26341 .55041 Metetra
.512 .706 0 r
.26341 .55041 .27565 .56183 .29349 .56863 .28126 .55721 Metetra
.699 .753 0 r
.28126 .55721 .29349 .56863 .31168 .57403 .29948 .56261 Metetra
.794 .709 0 r
.29948 .56261 .31168 .57403 .3302 .57811 .31805 .56667 Metetra
.83 .611 0 r
.31805 .56667 .3302 .57811 .34903 .58095 .33693 .56949 Metetra
.861 .518 0 r
.33693 .56949 .34903 .58095 .36816 .58262 .35611 .57113 Metetra
.888 .43 0 r
.35611 .57113 .36816 .58262 .38756 .58318 .37557 .57166 Metetra
.911 .351 0 r
.37557 .57166 .38756 .58318 .40722 .58271 .3953 .57114 Metetra
.93 .281 0 r
.3953 .57114 .40722 .58271 .42711 .58125 .41527 .56964 Metetra
.946 .222 0 r
.41527 .56964 .42711 .58125 .44723 .57886 .43547 .5672 Metetra
.958 .174 0 r
.43547 .5672 .44723 .57886 .46756 .57559 .45588 .56386 Metetra
.967 .137 0 r
.45588 .56386 .46756 .57559 .48809 .57148 .4765 .55969 Metetra
.974 .112 0 r
.4765 .55969 .48809 .57148 .5088 .56656 .49731 .55469 Metetra
.977 .097 0 r
.49731 .55469 .5088 .56656 .52969 .56086 .51829 .54892 Metetra
.978 .093 0 r
.51829 .54892 .52969 .56086 .55073 .55441 .53945 .54238 Metetra
.976 .1 0 r
.53945 .54238 .55073 .55441 .57193 .54722 .56075 .5351 Metetra
.972 .117 0 r
.56075 .5351 .57193 .54722 .59327 .53929 .5822 .52708 Metetra
.965 .144 0 r
.5822 .52708 .59327 .53929 .61473 .53064 .60378 .51833 Metetra
.956 .181 0 r
.60378 .51833 .61473 .53064 .63631 .52126 .62549 .50884 Metetra
.945 .226 0 r
.62549 .50884 .63631 .52126 .658 .51113 .64729 .4986 Metetra
.931 .28 0 r
.64729 .4986 .658 .51113 .67977 .50024 .6692 .48758 Metetra
.914 .341 0 r
.6692 .48758 .67977 .50024 .70162 .48855 .69118 .47577 Metetra
.894 .41 0 r
.69118 .47577 .70162 .48855 .72353 .47603 .71322 .46312 Metetra
.872 .484 0 r
.71322 .46312 .72353 .47603 .74548 .46263 .7353 .44958 Metetra
.846 .564 0 r
.7353 .44958 .74548 .46263 .76744 .4483 .75741 .43511 Metetra
.817 .647 0 r
.75741 .43511 .76744 .4483 .78941 .43297 .77952 .41962 Metetra
.785 .732 0 r
.77952 .41962 .78941 .43297 .81134 .41656 .8016 .40306 Metetra
.679 .748 0 r
.8016 .40306 .81134 .41656 .83321 .39899 .82361 .38532 Metetra
.515 .707 0 r
.82361 .38532 .83321 .39899 .85498 .38014 .84554 .3663 Metetra
0 .524 .034 r
.19996 .5085 .21231 .52072 .2289 .53226 .21654 .52009 Metetra
.133 .59 0 r
.21654 .52009 .2289 .53226 .24595 .54212 .23358 .53001 Metetra
.314 .65 0 r
.23358 .53001 .24595 .54212 .26341 .55041 .25105 .53834 Metetra
.502 .703 0 r
.25105 .53834 .26341 .55041 .28126 .55721 .26892 .54517 Metetra
.688 .75 0 r
.26892 .54517 .28126 .55721 .29948 .56261 .28716 .55059 Metetra
.791 .715 0 r
.28716 .55059 .29948 .56261 .31805 .56667 .30576 .55467 Metetra
.828 .618 0 r
.30576 .55467 .31805 .56667 .33693 .56949 .32468 .55749 Metetra
.859 .524 0 r
.32468 .55749 .33693 .56949 .35611 .57113 .34392 .55913 Metetra
.886 .437 0 r
.34392 .55913 .35611 .57113 .37557 .57166 .36344 .55965 Metetra
.909 .357 0 r
.36344 .55965 .37557 .57166 .3953 .57114 .38323 .55911 Metetra
.929 .287 0 r
.38323 .55911 .3953 .57114 .41527 .56964 .40327 .55758 Metetra
.944 .228 0 r
.40327 .55758 .41527 .56964 .43547 .5672 .42355 .5551 Metetra
.957 .18 0 r
.42355 .5551 .43547 .5672 .45588 .56386 .44405 .55172 Metetra
.966 .143 0 r
.44405 .55172 .45588 .56386 .4765 .55969 .46475 .54749 Metetra
.972 .117 0 r
.46475 .54749 .4765 .55969 .49731 .55469 .48566 .54243 Metetra
.976 .102 0 r
.48566 .54243 .49731 .55469 .51829 .54892 .50674 .53659 Metetra
.977 .098 0 r
.50674 .53659 .51829 .54892 .53945 .54238 .528 .52997 Metetra
.975 .105 0 r
.528 .52997 .53945 .54238 .56075 .5351 .54941 .5226 Metetra
.971 .122 0 r
.54941 .5226 .56075 .5351 .5822 .52708 .57097 .51449 Metetra
.964 .149 0 r
.57097 .51449 .5822 .52708 .60378 .51833 .59267 .50564 Metetra
.955 .185 0 r
.59267 .50564 .60378 .51833 .62549 .50884 .61449 .49603 Metetra
.944 .23 0 r
.61449 .49603 .62549 .50884 .64729 .4986 .63643 .48567 Metetra
.929 .284 0 r
.63643 .48567 .64729 .4986 .6692 .48758 .65846 .47453 Metetra
.913 .345 0 r
.65846 .47453 .6692 .48758 .69118 .47577 .68057 .46258 Metetra
.893 .414 0 r
.68057 .46258 .69118 .47577 .71322 .46312 .70274 .44978 Metetra
.87 .489 0 r
.70274 .44978 .71322 .46312 .7353 .44958 .72497 .43609 Metetra
.845 .568 0 r
.72497 .43609 .7353 .44958 .75741 .43511 .74721 .42145 Metetra
.816 .652 0 r
.74721 .42145 .75741 .43511 .77952 .41962 .76946 .40579 Metetra
.783 .737 0 r
.76946 .40579 .77952 .41962 .8016 .40306 .79168 .38903 Metetra
.671 .746 0 r
.79168 .38903 .8016 .40306 .82361 .38532 .81385 .37109 Metetra
.508 .705 0 r
.81385 .37109 .82361 .38532 .84554 .3663 .83592 .35187 Metetra
0 .518 .047 r
.18752 .4955 .19996 .5085 .21654 .52009 .20408 .50718 Metetra
.118 .585 0 r
.20408 .50718 .21654 .52009 .23358 .53001 .2211 .51719 Metetra
.297 .645 0 r
.2211 .51719 .23358 .53001 .25105 .53834 .23857 .52559 Metetra
.484 .698 0 r
.23857 .52559 .25105 .53834 .26892 .54517 .25645 .53249 Metetra
.67 .746 0 r
.25645 .53249 .26892 .54517 .28716 .55059 .27471 .53796 Metetra
.787 .725 0 r
.27471 .53796 .28716 .55059 .30576 .55467 .29334 .54208 Metetra
.824 .628 0 r
.29334 .54208 .30576 .55467 .32468 .55749 .3123 .54494 Metetra
.856 .535 0 r
.3123 .54494 .32468 .55749 .34392 .55913 .33158 .5466 Metetra
.883 .447 0 r
.33158 .5466 .34392 .55913 .36344 .55965 .35115 .54713 Metetra
.906 .368 0 r
.35115 .54713 .36344 .55965 .38323 .55911 .37101 .54659 Metetra
.926 .298 0 r
.37101 .54659 .38323 .55911 .40327 .55758 .39112 .54505 Metetra
.942 .238 0 r
.39112 .54505 .40327 .55758 .42355 .5551 .41147 .54255 Metetra
.954 .189 0 r
.41147 .54255 .42355 .5551 .44405 .55172 .43205 .53914 Metetra
.964 .152 0 r
.43205 .53914 .44405 .55172 .46475 .54749 .45285 .53487 Metetra
.97 .125 0 r
.45285 .53487 .46475 .54749 .48566 .54243 .47384 .52976 Metetra
.974 .11 0 r
.47384 .52976 .48566 .54243 .50674 .53659 .49503 .52385 Metetra
.975 .106 0 r
.49503 .52385 .50674 .53659 .528 .52997 .51639 .51716 Metetra
.973 .113 0 r
.51639 .51716 .528 .52997 .54941 .5226 .53791 .50971 Metetra
.969 .129 0 r
.53791 .50971 .54941 .5226 .57097 .51449 .55958 .5015 Metetra
.963 .156 0 r
.55958 .5015 .57097 .51449 .59267 .50564 .5814 .49254 Metetra
.953 .192 0 r
.5814 .49254 .59267 .50564 .61449 .49603 .60334 .48282 Metetra
.942 .238 0 r
.60334 .48282 .61449 .49603 .63643 .48567 .6254 .47233 Metetra
.928 .291 0 r
.6254 .47233 .63643 .48567 .65846 .47453 .64755 .46105 Metetra
.911 .353 0 r
.64755 .46105 .65846 .47453 .68057 .46258 .6698 .44895 Metetra
.891 .421 0 r
.6698 .44895 .68057 .46258 .70274 .44978 .6921 .43599 Metetra
.868 .496 0 r
.6921 .43599 .70274 .44978 .72497 .43609 .71446 .42212 Metetra
.842 .576 0 r
.71446 .42212 .72497 .43609 .74721 .42145 .73685 .40729 Metetra
.813 .659 0 r
.73685 .40729 .74721 .42145 .76946 .40579 .75924 .39143 Metetra
.78 .744 0 r
.75924 .39143 .76946 .40579 .79168 .38903 .7816 .37447 Metetra
.658 .743 0 r
.7816 .37447 .79168 .38903 .81385 .37109 .80391 .3563 Metetra
.495 .701 0 r
.80391 .3563 .81385 .37109 .83592 .35187 .82612 .33683 Metetra
0 .509 .065 r
.17501 .48168 .18752 .4955 .20408 .50718 .19153 .4935 Metetra
.096 .577 0 r
.19153 .4935 .20408 .50718 .2211 .51719 .20853 .50362 Metetra
.274 .638 0 r
.20853 .50362 .2211 .51719 .23857 .52559 .22599 .51214 Metetra
.459 .692 0 r
.22599 .51214 .23857 .52559 .25645 .53249 .24387 .51914 Metetra
.644 .739 0 r
.24387 .51914 .25645 .53249 .27471 .53796 .26214 .52469 Metetra
.782 .74 0 r
.26214 .52469 .27471 .53796 .29334 .54208 .28079 .52889 Metetra
.819 .643 0 r
.28079 .52889 .29334 .54208 .3123 .54494 .29978 .53181 Metetra
.851 .55 0 r
.29978 .53181 .3123 .54494 .33158 .5466 .3191 .53351 Metetra
.879 .462 0 r
.3191 .53351 .33158 .5466 .35115 .54713 .33873 .53408 Metetra
.902 .382 0 r
.33873 .53408 .35115 .54713 .37101 .54659 .35864 .53356 Metetra
.922 .312 0 r
.35864 .53356 .37101 .54659 .39112 .54505 .37881 .53203 Metetra
.938 .252 0 r
.37881 .53203 .39112 .54505 .41147 .54255 .39924 .52952 Metetra
.951 .203 0 r
.39924 .52952 .41147 .54255 .43205 .53914 .4199 .5261 Metetra
.96 .165 0 r
.4199 .5261 .43205 .53914 .45285 .53487 .44078 .52179 Metetra
.967 .138 0 r
.44078 .52179 .45285 .53487 .47384 .52976 .46187 .51665 Metetra
.971 .122 0 r
.46187 .51665 .47384 .52976 .49503 .52385 .48315 .51068 Metetra
.972 .118 0 r
.48315 .51068 .49503 .52385 .51639 .51716 .50461 .50392 Metetra
.971 .124 0 r
.50461 .50392 .51639 .51716 .53791 .50971 .52624 .49639 Metetra
.966 .14 0 r
.52624 .49639 .53791 .50971 .55958 .5015 .54803 .48809 Metetra
.96 .167 0 r
.54803 .48809 .55958 .5015 .5814 .49254 .56996 .47902 Metetra
.951 .203 0 r
.56996 .47902 .5814 .49254 .60334 .48282 .59202 .46918 Metetra
.939 .248 0 r
.59202 .46918 .60334 .48282 .6254 .47233 .6142 .45856 Metetra
.925 .302 0 r
.6142 .45856 .6254 .47233 .64755 .46105 .63649 .44713 Metetra
.908 .363 0 r
.63649 .44713 .64755 .46105 .6698 .44895 .65886 .43486 Metetra
.888 .432 0 r
.65886 .43486 .6698 .44895 .6921 .43599 .6813 .42172 Metetra
.865 .506 0 r
.6813 .42172 .6921 .43599 .71446 .42212 .70379 .40766 Metetra
.839 .586 0 r
.70379 .40766 .71446 .42212 .73685 .40729 .72631 .39262 Metetra
.809 .669 0 r
.72631 .39262 .73685 .40729 .75924 .39143 .74884 .37654 Metetra
.776 .753 0 r
.74884 .37654 .75924 .39143 .7816 .37447 .77134 .35932 Metetra
.64 .738 0 r
.77134 .35932 .7816 .37447 .80391 .3563 .79379 .34089 Metetra
.477 .696 0 r
.79379 .34089 .80391 .3563 .82612 .33683 .81614 .32114 Metetra
0 .498 .087 r
.16242 .467 .17501 .48168 .19153 .4935 .1789 .479 Metetra
.069 .567 0 r
.1789 .479 .19153 .4935 .20853 .50362 .19587 .48929 Metetra
.244 .628 0 r
.19587 .48929 .20853 .50362 .22599 .51214 .2133 .49795 Metetra
.427 .683 0 r
.2133 .49795 .22599 .51214 .24387 .51914 .23117 .50508 Metetra
.611 .731 0 r
.23117 .50508 .24387 .51914 .26214 .52469 .24945 .51075 Metetra
.774 .758 0 r
.24945 .51075 .26214 .52469 .28079 .52889 .26812 .51505 Metetra
.812 .662 0 r
.26812 .51505 .28079 .52889 .29978 .53181 .28714 .51806 Metetra
.844 .569 0 r
.28714 .51806 .29978 .53181 .3191 .53351 .30649 .51984 Metetra
.873 .482 0 r
.30649 .51984 .3191 .53351 .33873 .53408 .32616 .52046 Metetra
.897 .402 0 r
.32616 .52046 .33873 .53408 .35864 .53356 .34612 .51999 Metetra
.917 .331 0 r
.34612 .51999 .35864 .53356 .37881 .53203 .36636 .51848 Metetra
.933 .27 0 r
.36636 .51848 .37881 .53203 .39924 .52952 .38686 .51599 Metetra
.946 .22 0 r
.38686 .51599 .39924 .52952 .4199 .5261 .40759 .51256 Metetra
.956 .182 0 r
.40759 .51256 .4199 .5261 .44078 .52179 .42856 .50824 Metetra
.963 .154 0 r
.42856 .50824 .44078 .52179 .46187 .51665 .44974 .50306 Metetra
.967 .138 0 r
.44974 .50306 .46187 .51665 .48315 .51068 .47111 .49705 Metetra
.968 .133 0 r
.47111 .49705 .48315 .51068 .50461 .50392 .49268 .49023 Metetra
.967 .139 0 r
.49268 .49023 .50461 .50392 .52624 .49639 .51441 .48261 Metetra
.963 .155 0 r
.51441 .48261 .52624 .49639 .54803 .48809 .53631 .47422 Metetra
.956 .181 0 r
.53631 .47422 .54803 .48809 .56996 .47902 .55836 .46504 Metetra
.947 .217 0 r
.55836 .46504 .56996 .47902 .59202 .46918 .58054 .45507 Metetra
.935 .262 0 r
.58054 .45507 .59202 .46918 .6142 .45856 .60284 .4443 Metetra
.921 .315 0 r
.60284 .4443 .6142 .45856 .63649 .44713 .62525 .43271 Metetra
.904 .377 0 r
.62525 .43271 .63649 .44713 .65886 .43486 .64775 .42027 Metetra
.884 .445 0 r
.64775 .42027 .65886 .43486 .6813 .42172 .67032 .40694 Metetra
.861 .52 0 r
.67032 .40694 .6813 .42172 .70379 .40766 .69295 .39266 Metetra
.834 .6 0 r
.69295 .39266 .70379 .40766 .72631 .39262 .71561 .37739 Metetra
.804 .682 0 r
.71561 .37739 .72631 .39262 .74884 .37654 .73827 .36105 Metetra
.77 .766 0 r
.73827 .36105 .74884 .37654 .77134 .35932 .76091 .34357 Metetra
.616 .732 0 r
.76091 .34357 .77134 .35932 .79379 .34089 .78349 .32484 Metetra
.453 .69 0 r
.78349 .32484 .79379 .34089 .81614 .32114 .80599 .30478 Metetra
0 .484 .114 r
.14978 .45144 .16242 .467 .1789 .479 .16619 .46365 Metetra
.037 .554 0 r
.16619 .46365 .1789 .479 .19587 .48929 .18312 .47413 Metetra
.207 .616 0 r
.18312 .47413 .19587 .48929 .2133 .49795 .20053 .48298 Metetra
.388 .672 0 r
.20053 .48298 .2133 .49795 .23117 .50508 .21838 .49027 Metetra
.57 .721 0 r
.21838 .49027 .23117 .50508 .24945 .51075 .23666 .49609 Metetra
.749 .765 0 r
.23666 .49609 .24945 .51075 .26812 .51505 .25533 .50053 Metetra
.803 .686 0 r
.25533 .50053 .26812 .51505 .28714 .51806 .27436 .50365 Metetra
.836 .594 0 r
.27436 .50365 .28714 .51806 .30649 .51984 .29375 .50553 Metetra
.865 .506 0 r
.29375 .50553 .30649 .51984 .32616 .52046 .31346 .50623 Metetra
.889 .426 0 r
.31346 .50623 .32616 .52046 .34612 .51999 .33347 .50582 Metetra
.91 .355 0 r
.33347 .50582 .34612 .51999 .36636 .51848 .35376 .50436 Metetra
.927 .293 0 r
.35376 .50436 .36636 .51848 .38686 .51599 .37432 .5019 Metetra
.94 .243 0 r
.37432 .5019 .38686 .51599 .40759 .51256 .39513 .49849 Metetra
.951 .203 0 r
.39513 .49849 .40759 .51256 .42856 .50824 .41618 .49416 Metetra
.958 .175 0 r
.41618 .49416 .42856 .50824 .44974 .50306 .43744 .48896 Metetra
.962 .158 0 r
.43744 .48896 .44974 .50306 .47111 .49705 .45891 .4829 Metetra
.963 .152 0 r
.45891 .4829 .47111 .49705 .49268 .49023 .48058 .47602 Metetra
.962 .158 0 r
.48058 .47602 .49268 .49023 .51441 .48261 .50242 .46833 Metetra
.958 .173 0 r
.50242 .46833 .51441 .48261 .53631 .47422 .52443 .45984 Metetra
.952 .199 0 r
.52443 .45984 .53631 .47422 .55836 .46504 .54659 .45055 Metetra
.943 .235 0 r
.54659 .45055 .55836 .46504 .58054 .45507 .56889 .44045 Metetra
.931 .28 0 r
.56889 .44045 .58054 .45507 .60284 .4443 .59131 .42953 Metetra
.916 .333 0 r
.59131 .42953 .60284 .4443 .62525 .43271 .61385 .41777 Metetra
.899 .394 0 r
.61385 .41777 .62525 .43271 .64775 .42027 .63648 .40514 Metetra
.878 .463 0 r
.63648 .40514 .64775 .42027 .67032 .40694 .65918 .39159 Metetra
.855 .537 0 r
.65918 .39159 .67032 .40694 .69295 .39266 .68194 .37708 Metetra
.828 .617 0 r
.68194 .37708 .69295 .39266 .71561 .37739 .70473 .36156 Metetra
.798 .699 0 r
.70473 .36156 .71561 .37739 .73827 .36105 .72752 .34494 Metetra
.745 .764 0 r
.72752 .34494 .73827 .36105 .76091 .34357 .7503 .32715 Metetra
.586 .725 0 r
.7503 .32715 .76091 .34357 .78349 .32484 .77302 .3081 Metetra
.423 .682 0 r
.77302 .3081 .78349 .32484 .80599 .30478 .79564 .28768 Metetra
0 .467 .144 r
.13709 .43493 .14978 .45144 .16619 .46365 .15343 .44739 Metetra
0 .538 .001 r
.15343 .44739 .16619 .46365 .18312 .47413 .1703 .45811 Metetra
.164 .602 0 r
.1703 .45811 .18312 .47413 .20053 .48298 .18767 .46717 Metetra
.341 .658 0 r
.18767 .46717 .20053 .48298 .21838 .49027 .2055 .47466 Metetra
.522 .709 0 r
.2055 .47466 .21838 .49027 .23666 .49609 .22376 .48067 Metetra
.7 .753 0 r
.22376 .48067 .23666 .49609 .25533 .50053 .24242 .48527 Metetra
.792 .714 0 r
.24242 .48527 .25533 .50053 .27436 .50365 .26147 .48853 Metetra
.826 .622 0 r
.26147 .48853 .27436 .50365 .29375 .50553 .28088 .49053 Metetra
.856 .535 0 r
.28088 .49053 .29375 .50553 .31346 .50623 .30062 .49134 Metetra
.881 .455 0 r
.30062 .49134 .31346 .50623 .33347 .50582 .32067 .49102 Metetra
.902 .383 0 r
.32067 .49102 .33347 .50582 .35376 .50436 .34102 .48963 Metetra
.919 .321 0 r
.34102 .48963 .35376 .50436 .37432 .5019 .36164 .48722 Metetra
.933 .27 0 r
.36164 .48722 .37432 .5019 .39513 .49849 .38252 .48383 Metetra
.944 .23 0 r
.38252 .48383 .39513 .49849 .41618 .49416 .40364 .47951 Metetra
.951 .201 0 r
.40364 .47951 .41618 .49416 .43744 .48896 .42499 .47429 Metetra
.956 .183 0 r
.42499 .47429 .43744 .48896 .45891 .4829 .44655 .4682 Metetra
.957 .177 0 r
.44655 .4682 .45891 .4829 .48058 .47602 .46831 .46127 Metetra
.956 .181 0 r
.46831 .46127 .48058 .47602 .50242 .46833 .49026 .45351 Metetra
.952 .196 0 r
.49026 .45351 .50242 .46833 .52443 .45984 .51238 .44492 Metetra
.946 .222 0 r
.51238 .44492 .52443 .45984 .54659 .45055 .53465 .43551 Metetra
.937 .257 0 r
.53465 .43551 .54659 .45055 .56889 .44045 .55707 .42527 Metetra
.925 .302 0 r
.55707 .42527 .56889 .44045 .59131 .42953 .57961 .41419 Metetra
.91 .355 0 r
.57961 .41419 .59131 .42953 .61385 .41777 .60227 .40225 Metetra
.892 .416 0 r
.60227 .40225 .61385 .41777 .63648 .40514 .62503 .38941 Metetra
.872 .484 0 r
.62503 .38941 .63648 .40514 .65918 .39159 .64786 .37563 Metetra
.848 .559 0 r
.64786 .37563 .65918 .39159 .68194 .37708 .67075 .36087 Metetra
.821 .638 0 r
.67075 .36087 .68194 .37708 .70473 .36156 .69367 .34506 Metetra
.79 .719 0 r
.69367 .34506 .70473 .36156 .72752 .34494 .7166 .32814 Metetra
.708 .755 0 r
.7166 .32814 .72752 .34494 .7503 .32715 .73951 .31002 Metetra
.55 .716 0 r
.73951 .31002 .7503 .32715 .77302 .3081 .76236 .2906 Metetra
.388 .672 0 r
.76236 .2906 .77302 .3081 .79564 .28768 .78511 .26979 Metetra
0 .447 .177 r
.12437 .41741 .13709 .43493 .15343 .44739 .14063 .43017 Metetra
0 .52 .043 r
.14063 .43017 .15343 .44739 .1703 .45811 .15743 .44116 Metetra
.116 .584 0 r
.15743 .44116 .1703 .45811 .18767 .46717 .17474 .45048 Metetra
.289 .642 0 r
.17474 .45048 .18767 .46717 .2055 .47466 .19253 .4582 Metetra
.466 .694 0 r
.19253 .4582 .2055 .47466 .22376 .48067 .21077 .46442 Metetra
.643 .739 0 r
.21077 .46442 .22376 .48067 .24242 .48527 .22942 .46921 Metetra
.779 .746 0 r
.22942 .46921 .24242 .48527 .26147 .48853 .24847 .47265 Metetra
.814 .656 0 r
.24847 .47265 .26147 .48853 .28088 .49053 .26789 .4748 Metetra
.844 .569 0 r
.26789 .4748 .28088 .49053 .30062 .49134 .28766 .47574 Metetra
.87 .489 0 r
.28766 .47574 .30062 .49134 .32067 .49102 .30774 .47553 Metetra
.892 .417 0 r
.30774 .47553 .32067 .49102 .34102 .48963 .32814 .47422 Metetra
.91 .355 0 r
.32814 .47422 .34102 .48963 .36164 .48722 .34882 .47187 Metetra
.925 .302 0 r
.34882 .47187 .36164 .48722 .38252 .48383 .36976 .46852 Metetra
.936 .261 0 r
.36976 .46852 .38252 .48383 .40364 .47951 .39096 .46422 Metetra
.943 .231 0 r
.39096 .46422 .40364 .47951 .42499 .47429 .41239 .459 Metetra
.948 .213 0 r
.41239 .459 .42499 .47429 .44655 .4682 .43404 .45289 Metetra
.95 .206 0 r
.43404 .45289 .44655 .4682 .46831 .46127 .45589 .44591 Metetra
.949 .209 0 r
.45589 .44591 .46831 .46127 .49026 .45351 .47794 .43807 Metetra
.945 .224 0 r
.47794 .43807 .49026 .45351 .51238 .44492 .50016 .42939 Metetra
.939 .249 0 r
.50016 .42939 .51238 .44492 .53465 .43551 .52255 .41986 Metetra
.93 .284 0 r
.52255 .41986 .53465 .43551 .55707 .42527 .54508 .40948 Metetra
.917 .328 0 r
.54508 .40948 .55707 .42527 .57961 .41419 .56775 .39823 Metetra
.903 .381 0 r
.56775 .39823 .57961 .41419 .60227 .40225 .59053 .38609 Metetra
.885 .442 0 r
.59053 .38609 .60227 .40225 .62503 .38941 .61341 .37303 Metetra
.864 .51 0 r
.61341 .37303 .62503 .38941 .64786 .37563 .63637 .359 Metetra
.839 .584 0 r
.63637 .359 .64786 .37563 .67075 .36087 .65939 .34396 Metetra
.812 .662 0 r
.65939 .34396 .67075 .36087 .69367 .34506 .68244 .32785 Metetra
.78 .743 0 r
.68244 .32785 .69367 .34506 .7166 .32814 .7055 .31059 Metetra
.665 .745 0 r
.7055 .31059 .7166 .32814 .73951 .31002 .72853 .2921 Metetra
.507 .704 0 r
.72853 .2921 .73951 .31002 .76236 .2906 .75151 .27228 Metetra
.346 .659 0 r
.75151 .27228 .76236 .2906 .78511 .26979 .77439 .25103 Metetra
0 .424 .21 r
.11164 .39883 .12437 .41741 .14063 .43017 .1278 .41192 Metetra
0 .498 .088 r
.1278 .41192 .14063 .43017 .15743 .44116 .14451 .42322 Metetra
.063 .564 0 r
.14451 .42322 .15743 .44116 .17474 .45048 .16176 .43283 Metetra
.229 .623 0 r
.16176 .43283 .17474 .45048 .19253 .4582 .17949 .44082 Metetra
.403 .676 0 r
.17949 .44082 .19253 .4582 .21077 .46442 .19769 .44729 Metetra
.578 .723 0 r
.19769 .44729 .21077 .46442 .22942 .46921 .21633 .4523 Metetra
.747 .764 0 r
.21633 .4523 .22942 .46921 .24847 .47265 .23537 .45594 Metetra
.8 .693 0 r
.23537 .45594 .24847 .47265 .26789 .4748 .25479 .45827 Metetra
.831 .608 0 r
.25479 .45827 .26789 .4748 .28766 .47574 .27458 .45936 Metetra
.858 .529 0 r
.27458 .45936 .28766 .47574 .30774 .47553 .29469 .45928 Metetra
.88 .456 0 r
.29469 .45928 .30774 .47553 .32814 .47422 .31513 .45807 Metetra
.899 .393 0 r
.31513 .45807 .32814 .47422 .34882 .47187 .33585 .4558 Metetra
.914 .341 0 r
.33585 .4558 .34882 .47187 .36976 .46852 .35686 .45251 Metetra
.926 .299 0 r
.35686 .45251 .36976 .46852 .39096 .46422 .37812 .44824 Metetra
.934 .268 0 r
.37812 .44824 .39096 .46422 .41239 .459 .39963 .44303 Metetra
.939 .248 0 r
.39963 .44303 .41239 .459 .43404 .45289 .42137 .4369 Metetra
.941 .24 0 r
.42137 .4369 .43404 .45289 .45589 .44591 .44331 .42987 Metetra
.94 .243 0 r
.44331 .42987 .45589 .44591 .47794 .43807 .46546 .42196 Metetra
.937 .257 0 r
.46546 .42196 .47794 .43807 .50016 .42939 .48778 .41318 Metetra
.93 .282 0 r
.48778 .41318 .50016 .42939 .52255 .41986 .51028 .40353 Metetra
.921 .316 0 r
.51028 .40353 .52255 .41986 .54508 .40948 .53292 .39299 Metetra
.909 .36 0 r
.53292 .39299 .54508 .40948 .56775 .39823 .55571 .38156 Metetra
.893 .412 0 r
.55571 .38156 .56775 .39823 .59053 .38609 .57861 .36921 Metetra
.875 .473 0 r
.57861 .36921 .59053 .38609 .61341 .37303 .60162 .35591 Metetra
.854 .541 0 r
.60162 .35591 .61341 .37303 .63637 .359 .6247 .34162 Metetra
.829 .614 0 r
.6247 .34162 .63637 .359 .65939 .34396 .64785 .32628 Metetra
.801 .691 0 r
.64785 .32628 .65939 .34396 .68244 .32785 .67103 .30984 Metetra
.766 .769 0 r
.67103 .30984 .68244 .32785 .7055 .31059 .69421 .29221 Metetra
.614 .732 0 r
.69421 .29221 .7055 .31059 .72853 .2921 .71737 .27332 Metetra
.457 .691 0 r
.71737 .27332 .72853 .2921 .75151 .27228 .74048 .25306 Metetra
.297 .645 0 r
.74048 .25306 .75151 .27228 .77439 .25103 .76348 .23134 Metetra
0 .397 .243 r
.09892 .37912 .11164 .39883 .1278 .41192 .11496 .39257 Metetra
0 .473 .135 r
.11496 .39257 .1278 .41192 .14451 .42322 .13157 .40422 Metetra
.005 .541 0 r
.13157 .40422 .14451 .42322 .16176 .43283 .14873 .41415 Metetra
.164 .602 0 r
.14873 .41415 .16176 .43283 .17949 .44082 .16641 .42245 Metetra
.333 .656 0 r
.16641 .42245 .17949 .44082 .19769 .44729 .18456 .42919 Metetra
.504 .704 0 r
.18456 .42919 .19769 .44729 .21633 .4523 .20316 .43446 Metetra
.672 .746 0 r
.20316 .43446 .21633 .4523 .23537 .45594 .22218 .43832 Metetra
.783 .736 0 r
.22218 .43832 .23537 .45594 .25479 .45827 .2416 .44086 Metetra
.815 .652 0 r
.2416 .44086 .25479 .45827 .27458 .45936 .26139 .44213 Metetra
.843 .573 0 r
.26139 .44213 .27458 .45936 .29469 .45928 .28153 .44219 Metetra
.866 .501 0 r
.28153 .44219 .29469 .45928 .31513 .45807 .30199 .44111 Metetra
.886 .438 0 r
.30199 .44111 .31513 .45807 .33585 .4558 .32276 .43894 Metetra
.902 .385 0 r
.32276 .43894 .33585 .4558 .35686 .45251 .34382 .43572 Metetra
.914 .342 0 r
.34382 .43572 .35686 .45251 .37812 .44824 .36515 .43149 Metetra
.922 .31 0 r
.36515 .43149 .37812 .44824 .39963 .44303 .38673 .42629 Metetra
.928 .29 0 r
.38673 .42629 .39963 .44303 .42137 .4369 .40854 .42015 Metetra
.93 .281 0 r
.40854 .42015 .42137 .4369 .44331 .42987 .43058 .41308 Metetra
.93 .283 0 r
.43058 .41308 .44331 .42987 .46546 .42196 .45282 .4051 Metetra
.926 .296 0 r
.45282 .4051 .46546 .42196 .48778 .41318 .47524 .39622 Metetra
.92 .32 0 r
.47524 .39622 .48778 .41318 .51028 .40353 .49785 .38644 Metetra
.91 .354 0 r
.49785 .38644 .51028 .40353 .53292 .39299 .5206 .37574 Metetra
.898 .397 0 r
.5206 .37574 .53292 .39299 .55571 .38156 .5435 .36412 Metetra
.883 .449 0 r
.5435 .36412 .55571 .38156 .57861 .36921 .56652 .35155 Metetra
.864 .509 0 r
.56652 .35155 .57861 .36921 .60162 .35591 .58965 .338 Metetra
.842 .576 0 r
.58965 .338 .60162 .35591 .6247 .34162 .61286 .32341 Metetra
.817 .648 0 r
.61286 .32341 .6247 .34162 .64785 .32628 .63613 .30775 Metetra
.788 .725 0 r
.63613 .30775 .64785 .32628 .67103 .30984 .65943 .29094 Metetra
.707 .755 0 r
.65943 .29094 .67103 .30984 .69421 .29221 .68274 .27292 Metetra
.556 .717 0 r
.68274 .27292 .69421 .29221 .71737 .27332 .70603 .25359 Metetra
.4 .675 0 r
.70603 .25359 .71737 .27332 .74048 .25306 .72925 .23286 Metetra
.243 .628 0 r
.72925 .23286 .74048 .25306 .76348 .23134 .75236 .21062 Metetra
0 .366 .273 r
.08622 .35818 .09892 .37912 .11496 .39257 .10213 .37204 Metetra
0 .444 .182 r
.10213 .37204 .11496 .39257 .13157 .40422 .11863 .38407 Metetra
0 .514 .055 r
.11863 .38407 .13157 .40422 .14873 .41415 .13569 .39437 Metetra
.095 .576 0 r
.13569 .39437 .14873 .41415 .16641 .42245 .15328 .403 Metetra
.257 .632 0 r
.15328 .403 .16641 .42245 .18456 .42919 .17137 .41005 Metetra
.423 .682 0 r
.17137 .41005 .18456 .42919 .20316 .43446 .18993 .4156 Metetra
.588 .726 0 r
.18993 .4156 .20316 .43446 .22218 .43832 .20892 .41972 Metetra
.746 .764 0 r
.20892 .41972 .22218 .43832 .2416 .44086 .22832 .42248 Metetra
.797 .701 0 r
.22832 .42248 .2416 .44086 .26139 .44213 .24811 .42395 Metetra
.826 .623 0 r
.24811 .42395 .26139 .44213 .28153 .44219 .26826 .42419 Metetra
.85 .552 0 r
.26826 .42419 .28153 .44219 .30199 .44111 .28875 .42326 Metetra
.87 .489 0 r
.28875 .42326 .30199 .44111 .32276 .43894 .30955 .4212 Metetra
.887 .435 0 r
.30955 .4212 .32276 .43894 .34382 .43572 .33066 .41806 Metetra
.9 .392 0 r
.33066 .41806 .34382 .43572 .36515 .43149 .35204 .41389 Metetra
.909 .359 0 r
.35204 .41389 .36515 .43149 .38673 .42629 .37369 .40871 Metetra
.915 .338 0 r
.37369 .40871 .38673 .42629 .40854 .42015 .39558 .40256 Metetra
.917 .328 0 r
.39558 .40256 .40854 .42015 .43058 .41308 .4177 .39545 Metetra
.917 .329 0 r
.4177 .39545 .43058 .41308 .45282 .4051 .44003 .38741 Metetra
.914 .342 0 r
.44003 .38741 .45282 .4051 .47524 .39622 .46255 .37842 Metetra
.907 .365 0 r
.46255 .37842 .47524 .39622 .49785 .38644 .48525 .36851 Metetra
.898 .398 0 r
.48525 .36851 .49785 .38644 .5206 .37574 .50812 .35764 Metetra
.885 .44 0 r
.50812 .35764 .5206 .37574 .5435 .36412 .53113 .34582 Metetra
.87 .492 0 r
.53113 .34582 .5435 .36412 .56652 .35155 .55427 .33301 Metetra
.851 .551 0 r
.55427 .33301 .56652 .35155 .58965 .338 .57751 .31918 Metetra
.828 .617 0 r
.57751 .31918 .58965 .338 .61286 .32341 .60084 .30429 Metetra
.802 .688 0 r
.60084 .30429 .61286 .32341 .63613 .30775 .62424 .28828 Metetra
.772 .762 0 r
.62424 .28828 .63613 .30775 .65943 .29094 .64766 .27108 Metetra
.639 .738 0 r
.64766 .27108 .65943 .29094 .68274 .27292 .67109 .25262 Metetra
.489 .7 0 r
.67109 .25262 .68274 .27292 .70603 .25359 .69449 .23282 Metetra
.335 .656 0 r
.69449 .23282 .70603 .25359 .72925 .23286 .71783 .21158 Metetra
.182 .608 0 r
.71783 .21158 .72925 .23286 .75236 .21062 .74105 .18877 Metetra
0 .331 .298 r
.07359 .33593 .08622 .35818 .10213 .37204 .08934 .35024 Metetra
0 .411 .227 r
.08934 .35024 .10213 .37204 .11863 .38407 .1057 .36269 Metetra
0 .483 .116 r
.1057 .36269 .11863 .38407 .13569 .39437 .12265 .37338 Metetra
.022 .548 0 r
.12265 .37338 .13569 .39437 .15328 .403 .14015 .38238 Metetra
.175 .605 0 r
.14015 .38238 .15328 .403 .17137 .41005 .15816 .38977 Metetra
.335 .656 0 r
.15816 .38977 .17137 .41005 .18993 .4156 .17665 .39564 Metetra
.496 .702 0 r
.17665 .39564 .18993 .4156 .20892 .41972 .1956 .40004 Metetra
.652 .741 0 r
.1956 .40004 .20892 .41972 .22832 .42248 .21498 .40306 Metetra
.776 .753 0 r
.21498 .40306 .22832 .42248 .24811 .42395 .23475 .40475 Metetra
.806 .678 0 r
.23475 .40475 .24811 .42395 .26826 .42419 .2549 .40518 Metetra
.831 .608 0 r
.2549 .40518 .26826 .42419 .28875 .42326 .2754 .40441 Metetra
.852 .545 0 r
.2754 .40441 .28875 .42326 .30955 .4212 .29624 .40248 Metetra
.87 .492 0 r
.29624 .40248 .30955 .4212 .33066 .41806 .31738 .39945 Metetra
.883 .448 0 r
.31738 .39945 .33066 .41806 .35204 .41389 .33882 .39534 Metetra
.893 .415 0 r
.33882 .39534 .35204 .41389 .37369 .40871 .36052 .39019 Metetra
.899 .393 0 r
.36052 .39019 .37369 .40871 .39558 .40256 .38248 .38404 Metetra
.902 .382 0 r
.38248 .38404 .39558 .40256 .4177 .39545 .40468 .3769 Metetra
.902 .382 0 r
.40468 .3769 .4177 .39545 .44003 .38741 .42709 .36878 Metetra
.899 .394 0 r
.42709 .36878 .44003 .38741 .46255 .37842 .44971 .35969 Metetra
.892 .416 0 r
.44971 .35969 .46255 .37842 .48525 .36851 .47251 .34964 Metetra
.883 .448 0 r
.47251 .34964 .48525 .36851 .50812 .35764 .49548 .3386 Metetra
.87 .49 0 r
.49548 .3386 .50812 .35764 .53113 .34582 .5186 .32656 Metetra
.854 .54 0 r
.5186 .32656 .53113 .34582 .55427 .33301 .54185 .3135 Metetra
.835 .598 0 r
.54185 .3135 .55427 .33301 .57751 .31918 .56521 .29937 Metetra
.812 .662 0 r
.56521 .29937 .57751 .31918 .60084 .30429 .58866 .28414 Metetra
.785 .732 0 r
.58866 .28414 .60084 .30429 .62424 .28828 .61217 .26775 Metetra
.705 .754 0 r
.61217 .26775 .62424 .28828 .64766 .27108 .63571 .25014 Metetra
.563 .719 0 r
.63571 .25014 .64766 .27108 .67109 .25262 .65926 .23122 Metetra
.415 .679 0 r
.65926 .23122 .67109 .25262 .69449 .23282 .68277 .2109 Metetra
.264 .635 0 r
.68277 .2109 .69449 .23282 .71783 .21158 .70622 .1891 Metetra
.115 .584 0 r
.70622 .1891 .71783 .21158 .74105 .18877 .72955 .16568 Metetra
0 .27 .291 r
.06104 .31228 .07359 .33593 .08934 .35024 .07661 .32707 Metetra
0 .374 .267 r
.07661 .32707 .08934 .35024 .1057 .36269 .09283 .33998 Metetra
0 .448 .176 r
.09283 .33998 .1057 .36269 .12265 .37338 .10964 .35109 Metetra
0 .515 .053 r
.10964 .35109 .12265 .37338 .14015 .38238 .12703 .3605 Metetra
.089 .574 0 r
.12703 .3605 .14015 .38238 .15816 .38977 .14494 .36826 Metetra
.242 .627 0 r
.14494 .36826 .15816 .38977 .17665 .39564 .16336 .37447 Metetra
.397 .674 0 r
.16336 .37447 .17665 .39564 .1956 .40004 .18225 .37918 Metetra
.549 .716 0 r
.18225 .37918 .1956 .40004 .21498 .40306 .20158 .38248 Metetra
.694 .752 0 r
.20158 .38248 .21498 .40306 .23475 .40475 .22133 .38442 Metetra
.783 .737 0 r
.22133 .38442 .23475 .40475 .2549 .40518 .24147 .38507 Metetra
.809 .669 0 r
.24147 .38507 .2549 .40518 .2754 .40441 .26198 .38448 Metetra
.831 .608 0 r
.26198 .38448 .2754 .40441 .29624 .40248 .28283 .38269 Metetra
.849 .554 0 r
.28283 .38269 .29624 .40248 .31738 .39945 .304 .37977 Metetra
.864 .511 0 r
.304 .37977 .31738 .39945 .33882 .39534 .32548 .37574 Metetra
.874 .477 0 r
.32548 .37574 .33882 .39534 .36052 .39019 .34724 .37063 Metetra
.881 .454 0 r
.34724 .37063 .36052 .39019 .38248 .38404 .36926 .36448 Metetra
.884 .443 0 r
.36926 .36448 .38248 .38404 .40468 .3769 .39153 .35731 Metetra
.885 .442 0 r
.39153 .35731 .40468 .3769 .42709 .36878 .41402 .34912 Metetra
.881 .453 0 r
.41402 .34912 .42709 .36878 .44971 .35969 .43673 .33993 Metetra
.875 .474 0 r
.43673 .33993 .44971 .35969 .47251 .34964 .45962 .32972 Metetra
.865 .505 0 r
.45962 .32972 .47251 .34964 .49548 .3386 .48269 .31849 Metetra
.852 .545 0 r
.48269 .31849 .49548 .3386 .5186 .32656 .50592 .30622 Metetra
.836 .594 0 r
.50592 .30622 .5186 .32656 .54185 .3135 .52928 .29289 Metetra
.816 .651 0 r
.52928 .29289 .54185 .3135 .56521 .29937 .55275 .27845 Metetra
.792 .713 0 r
.55275 .27845 .56521 .29937 .58866 .28414 .57631 .26287 Metetra
.749 .765 0 r
.57631 .26287 .58866 .28414 .61217 .26775 .59993 .24607 Metetra
.617 .733 0 r
.59993 .24607 .61217 .26775 .63571 .25014 .62358 .228 Metetra
.477 .697 0 r
.62358 .228 .63571 .25014 .65926 .23122 .64724 .20858 Metetra
.332 .655 0 r
.64724 .20858 .65926 .23122 .68277 .2109 .67086 .18771 Metetra
.186 .609 0 r
.67086 .18771 .68277 .2109 .70622 .1891 .69441 .1653 Metetra
.044 .557 0 r
.69441 .1653 .70622 .1891 .72955 .16568 .71784 .14123 Metetra
0 .18 .246 r
.04861 .28712 .06104 .31228 .07661 .32707 .06399 .30242 Metetra
0 .331 .297 r
.06399 .30242 .07661 .32707 .09283 .33998 .08003 .31582 Metetra
0 .408 .23 r
.08003 .31582 .09283 .33998 .10964 .35109 .09669 .3274 Metetra
0 .477 .126 r
.09669 .3274 .10964 .35109 .12703 .3605 .11394 .33724 Metetra
.002 .539 0 r
.11394 .33724 .12703 .3605 .14494 .36826 .13174 .34541 Metetra
.144 .594 0 r
.13174 .34541 .14494 .36826 .16336 .37447 .15007 .35199 Metetra
.291 .643 0 r
.15007 .35199 .16336 .37447 .18225 .37918 .16889 .35704 Metetra
.439 .686 0 r
.16889 .35704 .18225 .37918 .20158 .38248 .18816 .36064 Metetra
.58 .724 0 r
.18816 .36064 .20158 .38248 .22133 .38442 .20787 .36285 Metetra
.713 .756 0 r
.20787 .36285 .22133 .38442 .24147 .38507 .22799 .36373 Metetra
.784 .734 0 r
.22799 .36373 .24147 .38507 .26198 .38448 .24849 .36334 Metetra
.807 .675 0 r
.24849 .36334 .26198 .38448 .28283 .38269 .26935 .36172 Metetra
.826 .623 0 r
.26935 .36172 .28283 .38269 .304 .37977 .29054 .35892 Metetra
.841 .58 0 r
.29054 .35892 .304 .37977 .32548 .37574 .31205 .35497 Metetra
.852 .546 0 r
.31205 .35497 .32548 .37574 .34724 .37063 .33385 .34992 Metetra
.86 .523 0 r
.33385 .34992 .34724 .37063 .36926 .36448 .35593 .34378 Metetra
.864 .511 0 r
.35593 .34378 .36926 .36448 .39153 .35731 .37826 .33657 Metetra
.864 .509 0 r
.37826 .33657 .39153 .35731 .41402 .34912 .40083 .32831 Metetra
.861 .519 0 r
.40083 .32831 .41402 .34912 .43673 .33993 .42361 .319 Metetra
.855 .539 0 r
.42361 .319 .43673 .33993 .45962 .32972 .4466 .30864 Metetra
.845 .568 0 r
.4466 .30864 .45962 .32972 .48269 .31849 .46976 .29721 Metetra
.831 .607 0 r
.46976 .29721 .48269 .31849 .50592 .30622 .49309 .2847 Metetra
.815 .655 0 r
.49309 .2847 .50592 .30622 .52928 .29289 .51655 .27108 Metetra
.794 .709 0 r
.51655 .27108 .52928 .29289 .55275 .27845 .54013 .2563 Metetra
.769 .769 0 r
.54013 .2563 .55275 .27845 .57631 .26287 .56379 .24033 Metetra
.65 .741 0 r
.56379 .24033 .57631 .26287 .59993 .24607 .58752 .2231 Metetra
.52 .708 0 r
.58752 .2231 .59993 .24607 .62358 .228 .61129 .20455 Metetra
.383 .67 0 r
.61129 .20455 .62358 .228 .64724 .20858 .63505 .18459 Metetra
.243 .628 0 r
.63505 .18459 .64724 .20858 .67086 .18771 .65877 .16313 Metetra
.103 .58 0 r
.65877 .16313 .67086 .18771 .69441 .1653 .68241 .14007 Metetra
0 .525 .03 r
.68241 .14007 .69441 .1653 .71784 .14123 .70593 .11529 Metetra
0 .1 .195 r
.03634 .26033 .04861 .28712 .06399 .30242 .0515 .27619 Metetra
0 .254 .284 r
.0515 .27619 .06399 .30242 .08003 .31582 .06734 .29012 Metetra
0 .364 .276 r
.06734 .29012 .08003 .31582 .09669 .3274 .08383 .30219 Metetra
0 .435 .195 r
.08383 .30219 .09669 .3274 .11394 .33724 .10093 .31249 Metetra
0 .499 .085 r
.10093 .31249 .11394 .33724 .13174 .34541 .1186 .32109 Metetra
.044 .557 0 r
.1186 .32109 .13174 .34541 .15007 .35199 .13682 .32807 Metetra
.181 .607 0 r
.13682 .32807 .15007 .35199 .16889 .35704 .15554 .33349 Metetra
.321 .652 0 r
.15554 .33349 .16889 .35704 .18816 .36064 .17475 .33742 Metetra
.458 .691 0 r
.17475 .33742 .18816 .36064 .20787 .36285 .1944 .33992 Metetra
.588 .725 0 r
.1944 .33992 .20787 .36285 .22799 .36373 .21448 .34106 Metetra
.706 .754 0 r
.21448 .34106 .22799 .36373 .24849 .36334 .23496 .34088 Metetra
.779 .746 0 r
.23496 .34088 .24849 .36334 .26935 .36172 .25581 .33943 Metetra
.799 .696 0 r
.25581 .33943 .26935 .36172 .29054 .35892 .27701 .33677 Metetra
.815 .654 0 r
.27701 .33677 .29054 .35892 .31205 .35497 .29854 .33292 Metetra
.827 .621 0 r
.29854 .33292 .31205 .35497 .33385 .34992 .32038 .32792 Metetra
.835 .598 0 r
.32038 .32792 .33385 .34992 .35593 .34378 .3425 .32179 Metetra
.839 .585 0 r
.3425 .32179 .35593 .34378 .37826 .33657 .36489 .31456 Metetra
.84 .583 0 r
.36489 .31456 .37826 .33657 .40083 .32831 .38753 .30622 Metetra
.837 .591 0 r
.38753 .30622 .40083 .32831 .42361 .319 .41039 .29679 Metetra
.831 .61 0 r
.41039 .29679 .42361 .319 .4466 .30864 .43345 .28626 Metetra
.821 .638 0 r
.43345 .28626 .4466 .30864 .46976 .29721 .45671 .27462 Metetra
.807 .675 0 r
.45671 .27462 .46976 .29721 .49309 .2847 .48012 .26185 Metetra
.789 .72 0 r
.48012 .26185 .49309 .2847 .51655 .27108 .50368 .24792 Metetra
.765 .768 0 r
.50368 .24792 .51655 .27108 .54013 .2563 .52736 .23279 Metetra
.658 .743 0 r
.52736 .23279 .54013 .2563 .56379 .24033 .55113 .2164 Metetra
.54 .713 0 r
.55113 .2164 .56379 .24033 .58752 .2231 .57496 .19871 Metetra
.414 .679 0 r
.57496 .19871 .58752 .2231 .61129 .20455 .59882 .17963 Metetra
.282 .64 0 r
.59882 .17963 .61129 .20455 .63505 .18459 .62268 .15909 Metetra
.148 .596 0 r
.62268 .15909 .63505 .18459 .65877 .16313 .6465 .137 Metetra
.017 .546 0 r
.6465 .137 .65877 .16313 .68241 .14007 .67023 .11324 Metetra
0 .489 .105 r
.67023 .11324 .68241 .14007 .70593 .11529 .69383 .08771 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15423 .2093 m
.15884 .21396 L
s
[(-5)] .145 .19996 .988 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54634 .05576 m
.55023 .06104 L
s
[(5)] .53856 .04519 .73647 1 Mshowa
.125 Mabswid
.19091 .19493 m
.19364 .19777 L
s
.22813 .18036 m
.23082 .18323 L
s
.26589 .16558 m
.26854 .16848 L
s
.30419 .15058 m
.30681 .15352 L
s
.38251 .11991 m
.38504 .12293 L
s
.42255 .10423 m
.42503 .10729 L
s
.46319 .08832 m
.46563 .09141 L
s
.50445 .07216 m
.50683 .07529 L
s
.11806 .22346 m
.12086 .22623 L
s
.0824 .23742 m
.08523 .24016 L
s
.04723 .25119 m
.0501 .25389 L
s
.58887 .0391 m
.59115 .04231 L
s
.63207 .02219 m
.63429 .02544 L
s
.67594 .00501 m
.67811 .0083 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00c?ooool2o`0005;ooooo0039
ooooo`?o000000?oooooo`000?ooool0DOooool00<Oooooo0_l000001?oooooo0000ooooooooool2
o`00057ooooo002Qooooo`?o00008?ooool3o`0000Kooooo0ol0001@ooooo`00X?ooool01Ol0003o
oooooooooooooooo000001gooooo0_l00009ooooo`03o`000?oooooo0000053ooooo002Tooooo`03
o`000?oooooooooo01Oooooo1?l0000;ooooo`04o`000?ooooooooooo`0004oooooo002Tooooo`03
o`000?oooooooooo01Gooooo1?l0000=ooooo`05o`000?ooooooooooooooool00000C_ooool00:3o
oooo1?l0000Fooooo`;o00004Oooool01Ol0003ooooooooooooooooo000004kooooo002Pooooo`03
o`000?oooooooooo01Cooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0Boooool00:3ooooo1Ol0000@ooooo`;o00005oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo04[ooooo002booooo`?o00006Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo04[ooooo002`ooooo`;o000000?oooooo`000?ooool06Oooool00ol0003oooooooooo`02
ooooo`;o0000Boooool00:gooooo0ol0000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0BOooool00:_ooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0B?ooool00:Oooooo1?l0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Aoooool00:Gooooo0ol0000Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Aooo
ool00:?ooooo0_l00003ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`16ooooo`00X?ooool3o`0002_ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`15ooooo`00W_ooool2o`0002kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`15ooooo`00Voooool3o`00033ooooo00?o0000ooooooooool01oooool2o`0004Kooooo
002Iooooo`;o0000<oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04?ooooo002F
ooooo`?o0000=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo0ol0000d
ooooo`00U?ooool2o`0003Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`05o`000?ooooooooooooooool00000<oooool0097ooooo0ol0000jooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool5o`0000Gooooo00?o0000ooooooooool0<Oooool008ko
oooo0ol000000ooooooo0000ooooo`0iooooo`;o00003Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo037ooooo001/ooooo`;o00007_ooool2o`0003kooooo00Co0000o`1m6_l0OA[o
00003Oooool00ol0003oooooooooo`08ooooo`Co0000=?ooool006_ooooo00Co0000oooooooooooo
00006_ooool3o`0003oooooo00Go0000o`1m6_l0OA[o07dJo`00000>ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0=Oooool006_ooooo00Co0000oooooooooooo00006?ooool2o`00
047ooooo00?o0000o`1m6_l0OAX00_l0OAX2o`0000cooooo0_l00009ooooo`Go0000<oooool006_o
oooo00Co0000oooooooooooo00005Oooool3o`000003ooooool0003ooooo03oooooo00?o0000o`1m
6_l0OAX00ol0OAX2o`0000kooooo00?o0000ooooooooool0?_ooool006_ooooo00Co0000oooooooo
oooo00004oooool2o`0004Cooooo00?o0000o`1m6_l0OAX01?l0OAX2o`0000oooooo00?o0000oooo
ooooool0?Oooool006_ooooo00Co0000oooooooooooo00004?ooool3o`0004Kooooo00?o0000o`1m
6_l0OAX01?l0OAX00ol0003o07dJo`00000>ooooo`03o`000?oooooooooo03gooooo001/ooooo`;o
00003_ooool3o`0004Sooooo00?o0000o`B;0?l000001Ol0OAX3o`0000oooooo00?o0000oooooooo
ool0??ooool007[ooooo1?l00018ooooo`04o`000?l4R`3o18/0o`0000Go07dJ00Co0000o`261ol0
QPOo00003oooool00ol0003oooooooooo`0kooooo`00Moooool3o`0004_ooooo00?o0000o`B;0?l4
R`000_l4R`001?l0003o07dJo`1m6_l0OAX2o`0000;o08H700?o0000ooooooooool03Oooool00ol0
003oooooooooo`0kooooo`00MOooool2o`0004gooooo00?o0000o`B;0?l4R`000ol4R`001_l0003o
07dJo`1m6_l0003o08H7o`0000?o08H700?o0000ooooooooool03?ooool2o`0003cooooo001boooo
o`?o0000C_ooool00ol0003o18/0o`B;0004o`B;0003o`000?l0OA[o000000;o08H700Go0000o`26
1ol0QPOo08H7o`00000?ooooo`03o`000?oooooooooo03[ooooo001`ooooo`;o000000?oooooo`00
0?ooool0C?ooool2o`0000So18/000Go0000o`261ol0QPOo08H7o`000003o`261`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0>Oooool006gooooo0ol0001@ooooo`03o`000?lUV03o0000
00Oo18/00_l00003o`261`03o`000?l0QPOo08H700;o08H700?o0000ooooooooool03_ooool00ol0
003oooooooooo`0hooooo`00Joooool2o`00057ooooo0_l00003obFH0003o`000?l4R`3o18/000?o
18/000Co0000oaZD0?lJU03o00000_l0QPL01?l0003o08H7o`261ol0QPL2o`00013ooooo00?o0000
ooooooooool0>?ooool006Sooooo0ol0001Booooo`03o`000?lUV03o9IP000?o9IP000?o0000o`B;
0?l4R`000_l4R`001Ol0003o6Y@0oaZD0?lJU03o000000;o08H700Co0000o`261ol0QPOo00000_l;
SP000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Oooooo001Vooooo`;o000000?ooooo
o`000?ooool0DOooool00ol0003o9IP0obFH0005obFH0004o`000?l4R`3o18/0o`0000Go6Y@000Go
0000o`261ol0003o08H7o`000004o`^>0003o`000?oooooooooo00kooooo00?o0000ooooooooool0
=_ooool006?ooooo0ol0001Eooooo`03o`000?lUV03o9IP000Ko9IP000?o0000o`B;0?l000001_lJ
U0001?l0003o08H7o`261ol00005o`^>0003o`000?oooooooooo00kooooo0_l0000gooooo`00HOoo
ool2o`0005Oooooo0_l00009obFH0003o`000?lJU03o6Y@000Go6Y@000Co0000o`261ol0003o0000
1_l;SP000ol0003oooooooooo`0=ooooo`;o0000=oooool005kooooo0ol0001Hooooo`04o`000?m8
X`3oB:<0o`0000Oo9IP00_l00008oaZD0003o`000?l;SP3o000000Ko2hh00_l0000@ooooo`03o`00
0?oooooooooo03Cooooo000iooooo`?o00007oooool3o`000003ooooool0003ooooo05Oooooo00Go
0000odRS0?m8X`3oB:<0o`000006obFH0004o`000?lnX03o?Z00o`0000Ko6Y@00_l000000ol;SP3o
0000o`^>0004o`^>0003o`000?lMU@3o0000013ooooo00?o0000ooooooooool0=?ooool003Sooooo
00Go0000ooooooooooooooooo`00000Looooo`;o0000G?ooool00ol0003oB:<0odRS0003odRS0003
o`000?lUV03o9IP000;o9IP000Go0000ocjP0?lnX03o?Z00o`000005oaZD0003o`000?l_V`3o;i/0
00;o00001?l;SP001Ol0003o7ID0oafE0?lMU@3o0000013ooooo00?o0000ooooooooool0<oooool0
03;ooooo1Ol00005ooooo`03o`000?oooooooooo01Oooooo0ol0001Mooooo`03o`000?m8X`3oB:<0
00GoB:<000Co0000obFH0?lUV03o00001OlnX0001Ol0003o6Y@0oaZD0?lJU03o000000?o;i/00_l0
0003o`^>0003o`000?lMU@3o7ID000;o7ID000?o0000ooooooooool03oooool00ol0003ooooooooo
o`0booooo`00??ooool00ol0003oooooooooo`0Eooooo`;o0000G_ooool2o`0000SoB:<000?o0000
obFH0?l000001_lnX0001?l0003o6Y@0oaZD0?l00005obnK0004o`000?l;SP3o2hh0o`0000Ko7ID0
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0booooo`00>?ooool4o`0001Gooooo0ol0
00000ooooooo0000ooooo`1Looooo`03o`000?mY[@3o000000SoB:<00_l00007ocjP0003o`000?lJ
U03o000000Ko;i/000?o0000o`^>0?l000001olMU@000ol0003oooooooooo`0?ooooo`;o0000<_oo
ool003Sooooo00?o0000ooooooooool05?ooool2o`00067ooooo00Go0000ofV]0?mY[@3oJJd0o`00
0006odRS0003o`000?mRZ`3o000000Oo?Z000_l00007obnK00;o00002?lMU@02o`00013ooooo0_l0
000booooo`00>?ooool5o`0000oooooo0ol0001Rooooo`03o`000?mY[@3oJJd000;oJJd000?o0000
odRS0?m8X`000_m8X`02o`0000?oHZ/000?o0000ocjP0?lnX0000olnX0000ol0003oE:L0o`000007
obnK00;o00001olMU@000ol0003o;Y/0o`00000Aooooo`03o`000?oooooooooo033ooooo001:oooo
o`;o0000I?ooool00ol0003oJJd0ofV]0004ofV]0004o`000?m8X`3oB:<0o`0000GoHZ/000?o0000
ocjP0?lnX0000_lnX0001Ol0003oE:L0oeBW0?mDY`3o000000Go;i/00_l000000om3XP3o0000oafE
0004oafE0005o`000?l^V`3o;Y/0objK0?l000004Oooool00ol0003oooooooooo`0_ooooo`00Aooo
ool3o`000003ooooool0003ooooo067ooooo0_l00007ofV]0003o`000?m8X`3o000000OoHZ/000Co
0000ocjP0?lnX03o00001?mDY`000ol0003o;i/0obnK0002obnK0005o`000?m3XP3o0000od>R0?l0
00001?lMU@000ol0003o;Y/0objK0002objK0003o`000?oooooooooo013ooooo00?o0000oooooooo
ool0;_ooool004Cooooo0ol0001Vooooo`03o`000?n:]P3o000000OoJJd00_l00008of:[0003o`00
0?lnX03o000000KoE:L000Co0000obnK0?l_V`3o00000_m3XP001?l0003o@j80od>R0?l00002oafE
0003o`000?l^V`3o;Y/000?o;Y/000?o0000ooooooooool04?ooool00ol0003oooooooooo`0^oooo
o`00@_ooool2o`0006Oooooo0_l00003ohZf0003o`000?mY[@3oJJd000?oJJd000?o0000ohFe0?l0
00002?mRZ`02o`0000OoE:L000?o0000obnK0?l000000om3XP001_l0003o@j80od>R0?l0003o7ID0
o`0000Oo;Y/000?o0000ooooooooool04?ooool00ol0003oooooooooo`0]ooooo`00?oooool3o`00
06Sooooo00?o0000ohZf0?n:]P000on:]P000ol0003oJJd0ofV]0002ofV]0005o`000?n5]@3oQKD0
ohFe0?l000001_mRZ`000ol0003oN[80o`000007oeBW00;o00001?m3XP001Ol0003o@j80od>R0?m3
XP3o000000So;Y/000?o0000ooooooooool04Oooool00ol0003oooooooooo`0/ooooo`00?Oooool2
o`0000?ooooo00?o0000ooooooooool0Hoooool2o`0000OoR[H000Co0000ofV]0?mY[@3o00001On5
]@000ol0003oHZ/0of:[0002of:[0005o`000?mj/P3oN[80ogZb0?l000001OmDY`000ol0003oJZd0
o`000004od>R0003o`000?m3XP3o@j8000;o00001ol^V`02o`0001;ooooo0_l0000^ooooo`00>_oo
ool3o`0006[ooooo00?o0000ojRn0?l000001on:]P000ol0003oJJd0o`000006ohFe0005o`000?mR
Z`3oHZ/0of:[0?l000001?mj/P000ol0003oE:L0oeBW0002oeBW0005o`000?mZ[@3oJZd0ofZ]0?l0
00001?m3XP02o`0000;oEJL000?o0000objK0?l^V`000ol^V`001?l0003o?Z00ocjP0?l0000Coooo
o`03o`000?oooooooooo00Kooooo0_l0000Sooooo`00=oooool3o`0006_ooooo0_l00003ojRn0003
o`000?n:]P3oR[H000CoR[H00_l00008ohFe0003o`000?mRZ`3o000000KoN[8000Co0000oeBW0?mD
Y`3o00001?mZ[@000ol0003o@j80od>R0002od>R0005o`000?mEY`3oEJL0oeFW0?l000001?l^V`00
0ol0003o?Z00ocjP0002ocjP0003o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool0000Rooooo`00=Oooool4o`0006_ooooo00?o0000ojRn0?nX_P000onX_P00
0ol0003oR[H0ohZf0003ohZf0003o`000?nV_@3o000000SoQKD00_l00007ogZb0003o`000?mDY`3o
000000KoJZd000?o0000od>R0?m3XP000_l00004oeFW0004o`000?l^V`3o;Y/0o`0000Go?Z0000?o
0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002;ooooo
000cooooo`;o0000K_ooool00ol0003oZ;h0ojRn0005ojRn0005o`000?n:]P3oR[H0ohZf0?l00000
0onV_@000ol0003oQKD0ohFe0004ohFe0003o`000?nM^`3o000000OoN[800_l00007ofZ]0005o`00
0?m3XP3o0000oeFW0?l000001?mEY`000ol0003o;Y/0o`000007ocjP0003o`000?oooooooooo017o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000Rooooo`00<?ooool3o`0006ko
oooo0_l00008ojRn0004o`000?n:]P3oR[H0o`0000CoY[d000?o0000ohFe0?n5]@000_n5]@02o`00
00?oWK/000?o0000ogZb0?mj/P000omj/P000ol0003oT;P0o`000007ofZ]00;o00000_mEY`000ol0
003oEJL0oeFW0002oeFW00;o00001olnX002o`0001?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool0000Rooooo`00;Oooool3o`00073ooooo00?o0000ol?40?l000002?nX_P000ol0
003oR[H0o`000006ojJm0004o`000?n5]@3oQKD0o`0000GoWK/000?o0000ogZb0?mj/P000_mj/P00
1Ol0003oT;P0oi2h0?n@^03o000000GoJZd000?o0000ogfc0?l000000_mEY`001ol0003oEJL0oeFW
0?mEY`3o0000ofJ/0?l000001_lnX0001?l0003oC:D0odbU0?l0000Cooooo`;o00000oooool01?l0
003oooooooooool0000Rooooo`00:oooool2o`000003ooooool0003ooooo06kooooo0_l00003ol?4
0003o`000?nX_P3oZ;h000GoZ;h00_l00007ojJm0003o`000?n5]@3o000000OoWK/000Co0000ogZb
0?mj/P3o00001?n@^0000ol0003oJZd0ofZ]0002ofZ]0007o`000?mm/`3oOK<0ogfc0?l0003oEJL0
o`000002oeFW0005o`000?mV[03oIZ`0ofJ/0?l000001?lnX0001Ol0003oC:D0odbU0?m<Y@3o0000
01;ooooo00?o0000ooooool000001?ooool2o`0002?ooooo000Xooooo`?o0000L_ooool00ol0003o
`l@0ol?40004ol?40003o`000?nX_P3oZ;h000?oZ;h000?o0000olC40?l000001onV_@02o`0000So
WK/000?o0000ogZb0?l000001_n@^0001?l0003oJZd0ofZ]0?l00005ogfc00;o000000?oEJL0o`00
0?mV[0001?mV[0001?l0003o?Z00ocjP0?l00005odbU0003o`000?oooooooooo017ooooo00?o0000
ooooooooool09oooool002Kooooo0_l0001cooooo`;o00001oo3a0001?l0003oZ;h0ojRn0?nX_P02
o`0000?oa<@000?o0000ojJm0?nV_@000onV_@000ol0003o_l<0o`000008oifk00;o00001on@^000
0ol0003oJZd0o`000003ogfc00Ko00001_mV[0000ol0003o?Z00o`000006odbU0003o`000?oooooo
oooo01;ooooo00?o0000ooooooooool09_ooool002?ooooo0ol0001cooooo`;o000000?obKP0o`00
0?o3a0001oo3a0000ol0003oZ;h0o`000005olC40003o`000?nV_@3oY[d000;oY[d000Go0000oko3
0?no``3o_l<0o`000006oifk0003o`000?nd`@3o000000OoT;P00_l000001?mm/`3o0000o`000?l0
0003ogfc00?o00001_mV[002o`0000OoC:D00_l0000Dooooo`03o`000?oooooooooo02Gooooo000R
ooooo`;o0000Loooool2o`0000CobKP000?o0000ol?40?o3a0001Oo3a002o`0000Ooa<@000Co0000
ojJm0?nV_@3o00001Ono``000ol0003oWK/0oifk0002oifk0005o`000?nd`@3o]<40okC10?l00000
1On@^004o`0000GoOK<000Go0000ohjg0?l0003oIZ`0o`000004ofJ/0003o`000?md/03o000000Ko
C:D000?o0000oeRX0?l000005?ooool00ol0003oooooooooo`0Uooooo`003_ooool3o`0000?ooooo
0_l00004ooooo`;o00001_ooool00ol0003oooooo`00001`ooooo`;o00001oo9^0000ol0003o`l@0
ol?40003ol?40003o`000?o;]@3o000000Ooa<@000?o0000ojJm0?l000001_no``001Ol0003oWK/0
oifk0?nM^`3o000000Co]<4000Co0000oi2h0?n@^03oT;P00ol00002oj>l0003o`000?mm/`3oOK<0
00;oOK<000Oo0000ohjg0?n>]`3oS[L0o`000?mV[03o000000;oIZ`000Go0000ogB`0?md/03oM;00
o`000004odbU0005o`000?mHZ03oF:P0oeRX0?l000005?ooool00ol0003oooooooooo`0Tooooo`00
3oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`;o000000?oooooo`000?ooool0KOooool00ol0003ocZ`0o`000007olVh
0004o`000?o3a03o`l@0ol?400;o00000oo;]@000ol0003oa<@0olC40004olC400;o00002?no``00
0ol0003oWK/0o`000006okC100Co00001OnS_0001?l0003oOK<0ogfc0?l00005ohjg00;o000000?o
IZ`0o`000?md/0001?md/0001?l0003oC:D0odbU0?l00005oeRX0003o`000?oooooooooo017ooooo
0_l0000Uooooo`001_ooool5o`000003ooooool0003o000000?o00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo1?l000000ooooooo0000ooooo`1Zooooo`;o
00000oo>[0000ol0003obKP0olVh0005olVh0003o`000?o3a03o000000GobkD000?o0000olC40?o4
a0000oo4a0000ol0003ob[H0o`000008oko300;o00001?nd`@04o`000003oi2h0?l0003oXk`000Go
Xk`000?o0000ogfc0?l000001_n>]`000ol0003oIZ`0o`000006ogB`0003o`000?m<Y@3o000000Oo
F:P000?o0000ooooooooool04Oooool00ol0003oooooooooo`0Sooooo`003?ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
1ol0003oooooo`000?l06C7o0000ooooool00000JOooool00ol0003ocZ`0olj/0003olj/0003o`00
0?o9^03obKP000GobKP00_l00007ol^e0003o`000?o4a03oa<@000;o00000oo:]P000ol0003o_l<0
oko30004oko30004o`000?o8^`3o0000okC100?o00000ond`@02o`0000OoXk`00_l00007ohjg00;o
000000?oM;00o`000?md/0001?md/002o`0000OoF:P00_l0000Dooooo`03o`000?oooooooooo02;o
oooo000=ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`;o000000Koooooo`000?l06C7o0000ooooool0001Vooooo`;o00001oo>
[0001?l0003obKP0olVh0?o9^003o`000003om2W0?l0003obkD000KobkD000?o0000olC40?l00000
1_o:]P001?l0003o_l<0oko30?no``02o`000004olRk0?l0003o0000o`0000Go]<4000?o0000olG3
0?l000001_nS_0000ol0003o]<40o`000006ohjg0005o`000?nM^`3o0000ogB`0?l000001?md/000
0ol0003oPK@0o`000006oeRX0004o`000?mS[03oHj`0o`0001Cooooo00?o0000ooooooooool08Ooo
ool000kooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool01Ol0003oooooooooool0003o01Ta00;o000000?oooooo`000?ooool0H_ooool2o`000003
om:S0?l0003ocZ`000KocZ`000Co0000olVh0?l0003o00001Oo@Y`000ol0003obkD0ol^e0004ol^e
00;o00002?o:]P001?l0003o_l<0o`000?o8^`02o`0000?ob;/000?o0000okC10?nd`@000_l00003
olG30003o`000?nS_03oXk`000;oXk`000Go0000okC10?nd`@3o]<40o`000004ohjg0007o`000?nM
^`3oWK/0oifk0?l0003oM;00o`000002ogB`0005o`000?n1]03oPK@0oh6d0?l000001?mHZ0000ol0
003oHj`0of>/0002of>/0003o`000?oooooooooo017ooooo00?o0000ooooooooool08Oooool000oo
oooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l00005ooooo`04o`000?ooooooooooo`00
00;o01Ta0_l000000ooooooo0000ooooo`1Oooooo`;o00001?oBX`000ol0003ocZ`0olj/0004olj/
00;o00002?o@Y`001?l0003obkD0ol^e0?o;]@02o`000003om2V0?l0003ob[H000Oob[H01?l00005
olRk0003o`000?nd`@3o000000KoaL<000Co0000oj>l0?nS_03o00001Ond`@001?l0003oS[L0ohjg
0?l00005oifk0004o`000?md/03o0000o`0000GoPK@000Co0000oeRX0?mHZ03o00001OmS[0000ol0
003oooooooooo`0Booooo`03o`000?oooooooooo023ooooo000Qooooo`0;o`000?oooooooooooooo
ool0003o01Tao`000?l0@DSo0000ooooool00000GOooool2o`0000KodZ<000?o0000olj/0?o>[000
0oo>[0000ol0003oe9/0o`000008om2W0004o`000?o;]@3o0000o`0000Cod:H000?o0000olZf0?o:
]P000oo:]P04o`0000Oob;/00_l00007olG30003o`000?nS_03o000000Ko]<4000?o0000ohjg0?l0
00001_nM^`001?l0003oM;00o`000?l00005oh6d0003o`000?mHZ03o000000KoHj`00_l0000Coooo
o`;o00008Oooool0023ooooo0_l00003ooooo`;o000000?o01Tao`000?l0@DP00ol0001Jooooo`;o
000000?oe9`0o`000?oBX`001_oBX`000ol0003ocZ`0olj/0002o`0000?oe9/000?o0000om2W0?o@
Y`001Oo@Y`02o`0000Ood:H000?o0000olZf0?l000000_l00004olnY0003o`000?o8^`3ob;/000?o
b;/000?o0000olf`0?l000001oo5``02o`0000Oo]<400_l00007oifk00;o000000?oPK@0o`000?n1
]0001?n1]002o`0000KoHj`000?o0000ofb^0?l000005?ooool00ol0003oooooooooo`0Oooooo`00
8?ooool00ol0003oooooooooo`03ooooo`?o000000?o0458o`000?l0GDH00_l0001Gooooo`;o0000
1?oDW0000ol0003odZ<0om:S0004om:S0003o`000?o>[03o000000Koe9/000?o0000om2W0?o@Y`00
0oo@Y`000ol0003oeYP0o`000006om2V00Go00001_o?Z@000ol0003ob;/0olRk0002o`0000?ocK00
00?o0000olG30?o5``000oo5``000ol0003obKT0o`000006okC10003o`000?o4a03o000000KoWK/0
00?o0000ojZn0?l000000_n1]0001ol0003oPK@0oh6d0?n1]03o0000ohbg0?l000001OmS[0001Ol0
003oK:h0ofb^0?m/[P3o000001Cooooo00?o0000ooooooooool07_ooool0023ooooo0_l00004oooo
o`03o`000?l0;Sko000000;o045800Co0000o`1MA_l0003o0000E?ooool2o`0000Koe9`000?o0000
om:S0?oBX`001?oBX`02o`0000Ooe9/000Co0000om2W0?o@Y`3od:L00_l00003omJH0003o`000?o@
YP3od:H000?o000000?od:H0o`000?l000002?o?Z@000ol0003ob;/0o`000006olf`0003o`000?o5
``3oaL<000;o00000oo9^@000ol0003o]<40okC10002okC10005o`000?o4a03oa<@0olC40?l00000
1?nM^`001Ol0003oZ[h0ojZn0?nZ_P3o000000;oPK@000?o0000oh6d0?l000000on<]`001Ol0003o
Hj`0of>/0?mS[03o000000GoK:h000?o0000ooooooooool04_ooool00ol0003oooooooooo`0Moooo
o`008?ooool00ol0003oooooooooo`04ooooo`05o`000?l0;Sko0000o`11B?l000000_l0GDH2o`00
053ooooo0ol000000ooFU`3o0000omBL0006omBL0004o`000?oBX`3odZ<0om:S00;o000000?of940
o`000?oDV`001ooDV`000ol0003od:L0o`000005omJH00?o00000oo@YP000ol0003oeIT0o`000008
olnY00;o00001oo=/0000ol0003oaL<0o`000006olVi0004o`000?nd`@3o]<40o`0000Goa<@000Co
0000oifk0?nM^`3o00001OnZ_P001?l0003oPK@0oh6d0?l00005ohbg0003o`000?mS[03o000000Ko
K:h000?o0000ooooooooool04_ooool00ol0003oooooooooo`0Mooooo`008?ooool00ol0003ooooo
ooooo`04ooooo`09o`000?l0;Sko0000o`000?l0@DSo0000o`1MA_l0003o06la00;o0000Boooool3
o`0000GoeYL000?o0000omBL0?oDW0001?oDW0001?l0003odZ<0o`000?l00004omRA0003o`000?oD
V`3oe9/000Goe9/00_l00003omJH00?o000000CoeYP0o`000?o@YP3od:H00_l00003omFI0003o`00
0?o?Z@3ocjT000CocjT000?o0000om>M0?l000001oo=/002o`0000OobKT000?o0000okC10?l00000
1_o4a0000ol0003oWK/0o`000006ojZn0004o`000?n1]03o0000o`0000GoS;L00_l00007ofb^00;o
00005?ooool00ol0003oooooooooo`0Looooo`007oooool3o`0000Gooooo00?o0000o`0^?_l0;Sh0
0ol00002o`1MAP04o`000?l0Kc7o06lao`0004Oooooo0ol000000ooGU@3o0000omJG0006omJG0003
o`000?oDW03oe9`000?oe9`00_l00007omRA0003o`000?oDV`3oe9/000;oe9/00_l000000ooJR`3o
0000o`000002o`0000CoeYP000?o0000om2V0?l000001_oEV@001?l0003ocjT0olnY0?o?Z@02o`00
00?odid000?o0000olf`0?o=/0000oo=/0000ol0003odJD0o`000007olVi00;o00001oo4a002o`00
00OoZ[h00_l00002ohbg0007o`000?n<]`3oS;L0ohbg0?l0003oU[T0o`000006ofb^0003o`000?mc
/03o000001Cooooo0_l0000Mooooo`002oooool3o`0000Cooooo0_l00004ooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`?o000000Go05A<o`000?l0GDKo05e6o`000003o`1_<@;o0000@_oo
ool3o`0000GoeiD000?o0000omJG0?oFU`001?oFU`000ol0003oe9`0omBL0003o`000003omZ90?l0
003of94000Oof94000Co0000omBK0?l0003o00000_oJR`03o`0000KoeYP00_l00008omFI0003o`00
0?o?Z@3o000000Godid000?o0000olf`0?o=/0000_o=/0001Ol0003odJD0om6U0?oAY@3o000000Go
bKT000?o0000olf`0?l000001_o4a0000ol0003oakh0o`000006ojZn0003o`000?ne`@3o000000?o
S;L000?o0000ohbg0?l000000onF^@000ol0003oK:h0ofb^0002ofb^0005o`000?mc/03oLk00og>`
0?l000005?ooool00ol0003oooooooooo`0Kooooo`002_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Kooooo00Go0000o`15B_l0003o0000o`1DC002o`000006o`1MA_l0003o06lao`1_<Ol0
003o07lE0_l0000mooooo`?o000000?oeYD0o`000?oGU@001OoGU@000ol0003oeYL0omJG0004omJG
00?o00001OoJR@000ol0003of940omRA0005omRA00;o000000CofX/0o`000?l0003o00000ooJR`00
1?l0003oeYP0omJH0?oFV002o`000003omZ:0?l0003oeIT000OoeIT00_l00007om>M0004o`000?o=
/03ocK00o`0000GodJD000?o0000olVi0?o9^@000_l00003olf`0003o`000?o4a03oa<@000;oa<@0
00Go0000olNn0?o7_P3oakh0o`000004ojZn0005o`000?ne`@3o]L40okG10?l000000_n<]`02o`00
00GoU[T000Co0000ofb^0?m/[P3o00001?mc/0000ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01[ooooo0004ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Sooooo00Ko0000o`15B_l0003o05A<
o`000?l0J3X2o`0000?o06la00?o0000o`1o5Ol0OaD00_l0000hooooo`?o00001OoFU@000ol0003o
eiD0omNE0004omNE0004o`000?oFU`3oeYL0omJG00;o000000?og8@0o`000?oJR@001_oJR@000ol0
003of940omRA0002omRA00Go00001_oJR`001?l0003oeYP0o`000?l00004omZ:0003o`000?oEV@3o
eIT000CoeIT000?o0000omV=0?l000001ooCW@000ol0003ocK00o`000006om6U0003o`000?o9^@3o
000000KocK0000Co0000olC40?o4a03o00001Oo7_P001?l0003oZ[h0ojZn0?l00005okG10004o`00
0?n<]`3o0000o`0000GoU[T000?o0000ofb^0?l000001Omc/002o`0001Cooooo00?o0000oooooooo
ool06_ooool000cooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`07ooooo`08o`000?l0AD[o04E:o`000?l0E4co0000o`1X
>_l00003o`1_<@05o`000?l0OaGo07lEo`000?l;SP000ol0000booooo`?o000000?oeIT0o`000?oF
U@001OoFU@000ol0003oeiD0omNE0004omNE0004o`000?oFU`3o0000o`0000Cog8@000?o0000omZ9
0?oJR@001OoJR@000ol0003of940o`000003o`0000;ogH4000?o0000omZ;0?oJR`001?oJR`02o`00
00OofXX000Co0000omFI0?oEV@3oeIT00_l00003omV=0003o`000?oCW@3odid000Codid00_l00007
om6U00;o00001oo=/0000ol0003oa<@0o`000006olNn0003o`000?nZ_P3o000000Ko]L400_l00002
oiJi0003o`000?nF^@3oU[T000;oU[T00_l00005og>`0003o`000?mj/P3o000001Gooooo00?o0000
ooooooooool06Oooool000kooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003o04E:o`00
0002o`0000;o06Pj0_l00002o`1_<@04o`000?l0OaGo07lEo`0000?o2hh01?l0000Yooooo`Go0000
1OoEV@000ol0003oeYD0omJE0004omJE0003o`000?oGU@3oeiD000?oeiD00_l00007omb40003o`00
0?oJR@3ofXT000CofXT00ol00006omf10004o`000?oJR`3ofX/0omZ;00;o000000?ogWd0o`000?oJ
RP001ooJRP000ol0003oeIT0o`000006omV=0004o`000?oCW@3odid0om>M00;o000000?oei<0o`00
0?oAY@001OoAY@000ol0003oe9d0o`000007olf`00;o00001oo7_P02o`0000Ko]L4000?o0000okk3
0?l000000onF^@001_l0003oU[T0oiJi0?l0003oWK/0o`0000CoLk0000Go0000ogZb0?mj/P3oN[80
o`00000Eooooo`03o`000?oooooooooo01Sooooo000:ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool02?ooool00ol0003o04E:o`15BP03o`000003o`1X>_l0003o07XP00?o00000ol0OaD01?l0
003o2hh0o`^>0?l00003objK00Go00007oooool5o`0000?odih000?o0000omFI0?oEV@001?oEV@00
0ol0003oeYD0omJE0004omJE0003o`000?oGU@3oeiD000?o000000?ogH80o`000?oLQ0001_oLQ000
1?l0003ofXT0omZ90?oJR@03o`000003ommi0?l0003ogH4000KogH4000Co0000omZ;0?l0003o0000
1?oNO@000ol0003ofXX0omZ:0005omZ:00;o00001ooIS@001?l0003odid0o`000?l00004omNC0004
o`000?oAY@3odJD0om6U00;o00000ooDW@000ol0003ocK00olf`0003olf`0003o`000?o?Z@3o0000
00Koakh000?o0000olZh0?l000001One`@001Ol0003o_/<0okk30?nn``3o000000;oU[T000?o0000
oiJi0?l000000onM^`001?l0003oLk00og>`0?l00005ogZb0003o`000?oooooooooo01;ooooo0_l0
000Iooooo`002oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`09
ooooo`05o`000?l0AD[o0000o`1OA?l000000_l0J3X01?l0003o07XPo`1j8?l0NR02o`000003o`1o
5Ol0003o2hh000;o2hh000Go0000objK0?l^V`3o;Y/0o`000003oe:V00Go00005?ooool6o`0000;o
d:L000?o0000om>N0?oCWP001?oCWP000ol0003oeIT0omFI0004omFI0003o`000?oFU@3oeYD000?o
eYD00ol00005omf20003o`000?oLQ03og8@000Gog8@01?l00004ommi0003o`000?oMP@3ogH4000Co
gH400_l00007omim0004o`000?oJRP3ofXX0omZ:00?o000000?ogWd0o`000?oIS@001_oIS@02o`00
00Ooei<000?o0000om6U0?l000001_oDW@000ol0003ocK00olf`0002o`0000?ocjT000Co0000olNn
0?o7_P3oakh00_l00003olZh0005o`000?ne`@3o]L40okG10?l000001Onn``001?l0003oU[T0oiJi
0?l00004oifk0003o`000?mc/03o000000KoN[800_l0000Cooooo`;o00001oooool3o`0000oooooo
000Nooooo`03o`000?oooooooooo00[ooooo0_l000000ol0AD[o0000o`1OA002o`000006o`1X>_l0
003o07XPo`1j8?l0003o08T00ol00002o`^>0003o`000?l^V`3o;Y/000;o;Y/000Go0000oe:V0?mB
YP3oDZH0o`000003ogF`01Co00000oo</P000ol0003od:L0om2W0003om2W0003o`000?oCWP3odih0
00Codih000?o0000omFI0?oEV@000ooEV@000ol0003oeYD0omJE0003o`000003omf20?l0003ogH80
00KogH8000Co0000omb40?oLQ03og8@01Ol00007ommi0004o`000?oMP@3ogH40omf100;o000000?o
hW80o`000?oNO@001_oNO@001?l0003ofXX0o`000?l00005omim0003o`000?oIS@3ofHd000?ofHd0
00?o0000omf20?l000001ooGT`02o`0000Ooe9d000?o0000olf`0?l000001_o?Z@000ol0003oakh0
o`000006olZh0003o`000?ne`@3o000000Ko_/<000Go0000oiJi0?l0003oWK/0o`000003oifk00;o
00001_mj/P000ol0003oO[<0o`00000Eooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`007_ooool2o`0000cooooo0ol000000ol0GdCo0000o`1b;@02o`0000?o
07XP00Co0000o`290?l0R@3o08T00_l000000ol;SP3o0000objK0002objK0003o`000?mBYP3oDZH0
00;oDZH000Go0000ogF`0?me/03oMK00o`000004oiJi0003o`000?nd`@3o]<4000?o]<4000?o0000
olNn0?o7_P000_o7_P000ol0003oc;80olbb0004olbb0003o`000?o@Y`3od:L000?od:L000?o0000
om>N0?oCWP001?oCWP001?l0003oeIT0omFI0?oEV@04o`0000GogH8000?o0000omf20?oMPP001OoM
PP06o`000003on5c0?l0003oggT000KoggT000Co0000omf10?l0003o00001?oRLP000ol0003ogWd0
omim0004omim00;o00002?oNO@000ol0003ofHd0omV=0002o`0000?ogH8000?o0000omNC0?oGT`00
0ooGT`000ol0003ofXX0o`000007omBM00;o00001oo?Z@02o`0000Oob[P00_l00007okk300;o0000
0onM^`001Ol0003oWK/0o`000?nS_03o000000GoN[8000Go0000ogjc0?mn/`3oO[<0o`00000Doooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool001kooooo00?o0000oooooooo
ool03?ooool2o`0000;o05m400Co0000o`1b;Ol0LRgo00000_l0NR001_l0003o08T0o`290?l0R@3o
0000obBH00;o00001?l^V`001Ol0003oDZH0oe:V0?mBYP3o000000CoMK0000?o0000oiJi0?nF^@00
0_nF^@000ol0003o]<40okC10003okC10003o`000?o7_P3oakh000;oakh000?o0000olbb0?o</P00
0oo</P000ol0003od:L0om2W0003om2W0003o`000?oCWP3odih000Codih01?l00002omb50003o`00
0?oMPP3ogH8000GogH8000?o0000omf20?oMPP000_oMPP05o`0000GohG<000?o0000ommi0?oON@00
1?oON@02o`0000OohW8000Co0000omim0?oNO@3ogWd00_l000000ooRL03o0000omim0007omim0003
o`000?oIS@3o000000KogH8000?o0000omNC0?oGT`000_l00003omZ:0003o`000?oDW@3oe9d000?o
e9d000?o0000omJE0?l000001_o?Z@000ol0003odZ<0o`000006olZh0003o`000?o</P3o000000Ko
_/<000?o0000olG40?l000000onM^`02o`0000?oXk`000Go0000ogZb0?mj/P3oN[80o`000004ogjc
0003o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<oooo
o`007_ooool00ol0003oooooooooo`0<ooooo`06o`000?l0E4co0000o`000?l0GdCo00000_l0LRd2
o`000003o`1j8?l0003o08T000;o08T000?o0000obBH0?lTV0001Ol00004oe:V0003o`000?me/03o
MK0000;oMK0000?o0000oiJi0?nF^@000_nF^@000ol0003o]<40okC10002okC10003o`000?o7_P3o
akh000?oakh000?o0000olbb0?o</P000oo</P000ol0003od:L0om2W0003om2W0003o`000?oCWP3o
dih000?o000000?ofX/0o`000?oLQ@001?oLQ@000ol0003ogH80omf20005omf200Ko000000?ohW40
o`000?oQL`001_oQL`001?l0003oggT0ommi0?oON@02o`000003onAZ0?l0003ohW8000KohW8000Co
0000omim0?l0003o00001?oRL0000ol0003ogWd0omim0005omim00;o00001ooMPP000ol0003oei<0
o`000006omZ:0003o`000?oDW@3oe9d000;o00000ooFU@001?l0003ocjT0olnY0?o?Z@02o`0000?o
dZ<000?o0000olZh0?o:^0000_o:^0001Ol0003oc;80olbb0?o</P3o000000?o_/<00_l00003olG4
0003o`000?nM^`3oWK/000;o00001?nS_0000ol0003oN[80o`000006ogjc0003o`000?oooooooooo
01?ooooo00Co0000oooooooooooooooo1?l0000?ooooo`007_ooool2o`0000kooooo0_l000000ol0
JC[o0000o`000002o`1b;@04o`000?l0P`go0000o`0000?o08T000Co0000obBH0?lTV03o00000om:
Y006o`0000CoMK0000?o0000oiJi0?nF^@000_nF^@000ol0003o]<40okC10003okC10003o`000?o7
_P3oakh000;oakh000?o0000olbb0?o</P000oo</P001?l0003od:L0om2W0?o@Y`05o`0000GofX/0
00?o0000omb50?oLQ@000ooLQ@000ol0003ogH80omf20002omf200Go00001OoRL@000ol0003ohG<0
on5c0004on5c0004o`000?oON@3o0000o`0000Coi6X000?o0000on9b0?oRLP001?oRLP02o`0000Oo
hW0000?o0000omim0?oNO@000_oNO@02o`000003on9b0?l0003ogH8000KogH800_l00007omZ:0003
o`000?oDW@3o000000KoeYD000?o0000olnY0?l000001_oBX`001?l0003ob[P0olZh0?l00005olbb
0003o`000?nn``3o000000GoaL@000?o0000oifk0?l000000_nS_0001?l0003oXk`0oj>l0?nS_002
o`0000KoO[<00_l0000Eooooo`;o00000_ooool00ol0003oooooooooo`0@ooooo`007_ooool00ol0
003oooooooooo`0>ooooo`;o00000_l0JCX01?l0003o078]o`1b;Ol00002o`233@;o00000_l0R@00
1?l0003o99P0obBH0?l00003odZT0004o`000?m`[`3oL:l0og2_00Go000000?oMK00o`000?nF^@00
0onF^@000ol0003o]<40okC10002okC10003o`000?o7_P3oakh000?oakh000Co0000olbb0?o</P3o
c;801Ol00003omND0003o`000?oJR`3ofX/000CofX/000?o0000omb50?oLQ@001?oLQ@06o`000003
on9a0?l0003ohW4000KohW4000?o0000on5c0?oQL`000ooQL`02o`0000Ooi6X000Co0000on9b0?oR
LP3ohW800_l000000ooUI@3o0000on9`0007on9`0004o`000?oNO@3o0000o`0000CohW8000?o0000
omf20?oMPP000ooMPP000ol0003oggT0o`000007omZ:00;o00001ooFU@02o`0000OodZ<000?o0000
olZh0?l000001_o</P02o`0000KoaL@00_l00004oj>l0005o`000?nS_03o0000ojRn0?l000001Omn
/`001?l0003oP[@0oh:d0?l0000Cooooo`03o`000?oooooo000000;ooooo1Ol0000>ooooo`007Ooo
ool3o`0000oooooo00?o0000o`1MAOl000000_l0JCX3o`0000;o08<=00?o0000oaJB0?l000000_l0
0003obBH0005o`000?m:Y03oBZ@0odZT0?l000000om`[`001?l0003oU;T0oiBi0?nD^@0Eo`0000;o
dil000?o0000omND0?oGU0001?oGU0000ol0003ofX/0omZ;0004omZ;0004o`000?oLQ@3og8D0omb5
00Go00001OoRL@000ol0003ohW40on9a0004on9a0003o`000?oQL`3ohG<000?o000000?oiV@0o`00
0?oTJP001_oTJP001?l0003ohW80o`000?l00004onEU0003o`000?oRL03ohW0000GohW000_l00007
on9b0003o`000?oMPP3ogH8000;o00000ooON@000ol0003ofXX0omZ:0003omZ:0003o`000?oMPP3o
000000KoeYD000?o0000omV?0?l000001ooBX`02o`0000Koc;8000?o0000olf^0?l000001Oo5a000
0ol0003oa/00o`000004oj>l00;o00000onX_P001Ol0003oO[<0ogjc0?mn/`3o000000CoP[@000?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`007Oooool00ol0003oooooooooo`0@
ooooo`06o`000?l0GDGo0000o`1Y>_l0003o07/M0_l00002o`233@04o`000?lFTP3o5Y80oaJB00;o
000000?o99P0o`000?m:Y0000om:Y0001Ol0003oL:l0og2_0?m`[`3o000000CoU;T000?o0000okK1
0?nf`@000_nf`@000ol0003ob;/0olRk0002olRk0003o`000?o>[03ocZ`000?ocZ`000?o0000om>O
0?oCW`000ooCW`000ol0003oei@0omND0004omND0003o`000?oJR`3ofX/000?ofX/01_l000000ooQ
M03o0000on9a0005on9a0003o`000?oRL@3ohW4000CohW400ol00005onIT0003o`000?oTJP3oi6X0
00Coi6X00_l00007onEU0003o`000?oRL03ohW0000;ohW000_l000000ooUI@3o0000on9b0006on9b
0003o`000?oMPP3o000000KoggT000?o0000omZ:0?oJRP000_l00003omf20004o`000?oFU@3oeYD0
omJE00;o00000ooIS`000ol0003odZ<0om:S0003om:S0003o`000?oCW@3o000000Goc;8000Go0000
olf^0?o=[P3ocJh0o`000003olG40005o`000?o6`03oa/00olK00?l000000onS_002o`0000CoZ;h0
00?o0000ogjc0?l000001On2]002o`0001Cooooo00?o0000ooooooooool04_ooool000Sooooo1Ol0
0003ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool04Oooool00ol0003o05e5o`00
0002o`000003o`1k7Ol0003o08<=00;o08<=00Go0000oaJB0?lFTP3o0000ocfP0003o`0000?oBZ@0
00?o0000og2_0?m`[`000_m`[`000ol0003oU;T0oiBi0002oiBi0003o`000?nf`@3o]/4000;o]/40
00?o0000olRk0?o8^`000_o8^`000ol0003ocZ`0olj/0003olj/0003o`000?oCW`3odil000?odil0
00?o0000omND0?oGU0000ooGU0001?l0003ofX/0omZ;0?oJR`05o`0000GohG@000?o0000on9a0?oR
L@001?oRL@001?l0003ohW40on9a0?oRL@02o`000003onIQ0?l0003oiV@000KoiV@000Co0000onAZ
0?oTJP3oi6X00_l000000ooXG@3o0000onEU0007onEU0004o`000?oRL03o0000o`0000CoiFD000?o
0000on9b0?oRLP001?oRLP02o`0000OoggT000?o0000omZ:0?l000001_oMPP000ol0003oeYD0o`00
0006omV?0003o`000?oBX`3odZ<000;o00000ooCW@001Ol0003oc;80olbb0?o</P3o000000GocJh0
00?o0000olG40?l000001Oo6`0000ol0003oXk`0o`000002ojRn0004o`000?nX_P3oZ;h0ojRn00;o
00001On2]0000ol0003oPk@0o`00000Eooooo`03o`000?oooooooooo017ooooo0009ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`;o00004_ooool01?l0003o05e5o`000?l0LBh2o`000005o`1k7Ol0003o0000o`233Ol00000
0olFTP001?l0003o?J00ocfP0?lmX005o`0000?oL:l000?o0000oiBi0?nD^@000_nD^@000ol0003o
]/40okK10002okK10003o`000?o8^`3ob;/000?ob;/000?o0000olj/0?o>[0000oo>[0000ol0003o
dil0om>O0003om>O0004o`000?oGU03oei@0omND00Go00000ooONP000ol0003ohG@0on5d0005on5d
0003o`000?oRL@3ohW4000?ohW4000Co0000on9a0?l0003o00001?oVH@000ol0003oiV@0onIT0004
onIT0004o`000?oTJP3o0000o`0000Coj5d000?o0000onEU0?oUI@001OoUI@02o`0000OoiFD000Co
0000on9b0?oRLP3ohW800_l000000ooTJ@3o0000ommi0006ommi00;o00001ooMPP02o`0000OofHl0
00?o0000om:S0?l000001_oCW@000ol0003oc;80o`000006olf^00;o00001_o6`002o`0000?oZ;h0
00Ko0000ojRn0?nX_P3o0000oj^n0?l00004oh:d0005o`000?n3]03oPk@0oh>d0?l000005Oooool0
0ol0003oooooooooo`0@ooooo`000_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04_oo
ool02?l0003o05e5o`000?l0LBko0000o`1k7Ol0003o1H`00ol00003oaJB0004o`000?lmX03o?J00
o`0000?oIJ`01_l00004oiBi0003o`000?nf`@3o]/4000;o]/4000?o0000olRk0?o8^`000_o8^`00
0ol0003ocZ`0olj/0003olj/0004o`000?oCW`3odil0om>O00Wo00001_oONP000ol0003ohG@0on5d
0004on5d0004o`000?oRL@3ohW40on9a00Co00001ooVH@000ol0003oiV@0onIT0003onIT00;o0000
1ooXG@000ol0003oiFD0onEU0002onEU00;o000000?oj5X0o`000?oUI@001_oUI@001?l0003ohW80
o`000?l00004onAY0003o`000?oON@3oggT000;oggT00_l000000ooRL@3o0000omf20005omf20003
o`000?oON`3o000000OofHl00_l00007om>M00;o00001_o=[P000ol0003ocj/0o`000005olK00003
o`000?o7_P3o000000CoZ;h00_l00003oj^n0004o`000?n2]03oP[@0o`0000GoPk@000?o0000oooo
ooooool04_ooool2o`00017ooooo000;ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool3
o`0000;o074^0ol00003o`F<00;o000000?o5Y80o`000?lmX0000_lmX0001Ol0003oIJ`0ofF/0?mU
[03o000000?oS;L01_l00004okK10003o`000?o8^`3ob;/000?ob;/000Co0000olj/0?o>[03ocZ`0
1Ol00002omV=00?o00001?oMPP000ol0003oggX0ommj0004ommj0003o`000?oQM03ohG@000?ohG@0
1?l00004onIQ0003o`000?oVH@3oiV4000GoiV4000?o0000onIT0?l000000_l000000ooYE`3o0000
onQM0007onQM0004o`000?oUI@3o0000o`0000Coj5X000?o0000onEU0?oUI@001?oUI@02o`0000Oo
i6T000Co0000ommi0?l0003o00001?oRL@001?l0003ogH80omf20?oMPP02o`0000?ogg/000?o0000
omV?0?oIS`000_oIS`02o`000003omZ90?l0003odid000Godid000?o0000omFI0?l000001Oo=[P00
1Ol0003ocj/0oln[0?o?Z`3o000000;oa/000_l00003olNn0004o`000?nX_P3oZ;h0ojRn00;o0000
0on[_P000ol0003oP[@0o`000005oh>d00;o00005Oooool00ol0003oooooooooo`0?ooooo`002?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo01?ooooo0ol000000ol0LBko0000o`233P02o`00
00;o1H`000?o0000obbJ0?l000000_l00003ocfP0005o`000?mU[03oIJ`0ofF/0?l000000on<]`00
1?l0003o/L00ok700?na`00?o`0000;oe9/000?o0000omV=0?oIS@000_l00002omV=0003o`000?oM
PP3ogH8000?ogH8000?o0000ommj0?oONP001?oONP000ol0003ohG@0o`000002o`000003onIT0?l0
003oiV4000KoiV4000?o0000onIQ0?oVH@001?oVH@02o`0000GojEL000?o0000onQM0?oXG@001OoX
G@02o`0000Ooj5X000Co0000onEU0?oUI@3oiFD00_l000000ooXG03o0000onAY0006onAY00;o0000
1ooRL@000ol0003ogH80o`000006ommk0004o`000?oIS`3o0000o`0000CofXT000Co0000om>M0?oC
W@3odid00_l00003omFI0005o`000?o=[P3ocJh0olf^0?l000001?o?Z`000ol0003oa/00o`000006
olNn0003o`000?nX_P3o000000;oZkh000?o0000oj^n0?n[_P000_l00005oh>d0004o`000?n4]03o
Q;@0o`0001Gooooo00?o0000ooooooooool03_ooool000Sooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0Eooooo`;o00000_l0LBh01?l0003o08<>o`233_l00002o`F<0004o`000?l/VP3o;9X0
obbJ00Co00000omU[0000ol0003oS;L0ohbg0002ohbg0005o`000?na`03o/L00ok700?l000001?o8
_0000ol0003ocj/0oln[0003oln[0003o`000?oDV`3oe9/000;oe9/00ol00005omV=0003o`000?oM
PP3ogH8000?ogH8000Co0000ommj0?oONP3oggX01?l00005onIT0003o`000?oVH@3oiV4000GoiV40
00?o0000onIQ0?oVH@000ol000000ooZE03o0000onUG0005onUG0003o`000?oXG@3oj5d000;oj5d0
0_l000000oo[D@3o0000onQJ0006onQJ0004o`000?oUI@3o0000o`0000Coj5`000?o0000onAY0?oT
J@000_oTJ@02o`000003onMQ0?l0003ohW4000KohW400_l00007ommk00;o00001ooJR@000ol0003o
did0o`000006omFI0003o`000?o=[P3o000000Gocj/00_l00007olNn00;o00000on[_P000ol0003o
Zkh0o`000002ojfo0005o`000?n3]03oPk@0oh>d0?l000001?n4]0000ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00kooooo0009ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`03
o`000?oooooooooo01Gooooo00Ko0000o`1U?_l0003o0000o`1a;_l00002o`233P;o000000Go1H`0
o`000?l/VP3o;9X0o`000002oeFW00?o00000_mU[0000ol0003oS;L0ohbg0002ohbg0005o`000?na
`03o/L00ok700?l000001?o8_0000ol0003ocj/0oln[0003oln[00Co00000_oDV`000ol0003ofHd0
omV=0003omV=0004o`000?oMPP3ogH80omf200Ko00000ooTJP000ol0003oiV@0onIT0004onIT0003
o`000?oVH@3oiV4000CoiV400ol00005onYD0003o`000?oYE`3ojEL000CojEL000Co0000onQM0?l0
003o00001?o[D@000ol0003oj5X0onQJ0004onQJ00;o00001ooXG0001?l0003oi6T0o`000?l00004
onMQ0003o`000?oRL@3ohW4000;ohW400_l000000ooTJP3o0000ommk0005ommk0003o`000?oPMP3o
000000OofXT00_l00007omFI00;o00001Oo?Z`000ol0003od:P0o`000006olNn0003o`000?o8_03o
000000?oZkh00_l00004ojfo0003o`000?n3]03o000000GoQ;@00_l0000Dooooo`03o`000?oooooo
oooo00gooooo000Looooo`;o00005oooool2o`000003o`1i8_l0003o000000;o08<>00Co0000oaRC
0?l0003o00000ol/VP001Ol0003oEJL0oeFW0?l0003oO[<000?o00001?n<]`000ol0003o/L00ok70
0002ok700003o`000?o8_03ob;`000;ob;`000?o0000oln[0?o?Z`001?l00005omBK0004o`000?oI
S@3ofHd0omV=00Go00000ooRLP000ol0003oi6X0onAZ0004onAZ0003o`000?oVI03oiV@000CoiV@0
00?o0000onIQ0?oVH@000ol000000ooZD`3o0000onYD0006onYD0003o`000?oYE`3ojEL000?ojEL0
0_l00007on]A0004o`000?oXFP3oj5X0onQJ00;o000000?oje00o`000?oXG0001_oXG002o`0000Oo
if4000Co0000on9a0?l0003o00001?oTJP001?l0003ogg/0ommk0?oON`02o`0000?oh7H000?o0000
omZ90?oJR@000_oJR@02o`000003omb50?l0003oeIT000GoeIT000?o0000omJF0?l000001?o?Z`00
1Ol0003od:P0om2X0?o@Z03o000000?oakh00_l00003olRl0003o`000?n[_P3o000000;o[Kl000Co
0000ojfo0?n]_`3o[Kl00_l00005ohBd0003o`000?n3]03o000001Cooooo00?o0000ooooooooool0
3Oooool001cooooo00?o0000ooooooooool05_ooool00ol0003o06`eo`000002o`1i8P04o`000?l0
P`ko08<>o`0000;o69<00_l00002obbJ0004o`000?mEY`3oEJL0o`0000?oO[<02Ol000000ona`03o
0000olRl0002olRl00?o00000oo?Z`001?l0003oe9/0omBK0?oDV`06o`0000;ogWd000?o0000on9b
0?oRLP001?oRLP000ol0003oi6X0onAZ0004onAZ0003o`000?oVI03oiV@000?oiV@00ol00005onYC
0003o`000?oZE03ojU@000CojU@000?o0000onUG0?oYE`000ol000000oo]B`3o0000on]A0006on]A
0004o`000?oXFP3o0000o`0000Coje0000?o0000onQL0?oXG0000_oXG002o`000003onYC0?l0003o
if4000Koif400_l00007onAZ0003o`000?oON`3o000000Koh7H000Co0000omZ90?l0003o00001?oL
Q@001?l0003oeIT0omFI0?oEV@02o`0000?oeYH000Co0000oln[0?o?Z`3o00001Oo@Z0000ol0003o
akh0o`000006olRl0003o`000?n]_`3o[Kl000;o[Kl000Go0000ojfo0?l0003o[[l0o`000004ohBd
0005o`000?n3]03oPk@0oh>d0?l000004oooool2o`0000kooooo000Looooo`03o`000?oooooooooo
01Oooooo00?o0000o`1/=Ol000000_l0NB82o`000005o`233_l0003o69<0o`000?m1X@000ol00003
oeFW0004o`000?mn/`3oO[<0o`0000CoY[d000Co0000olK00?o6`03oa/003ol00003omZ;0003o`00
0?oNO@3ogWd000?ogWd000?o0000on9b0?oRLP001?oRLP000ol0003oi6X0onAZ0003onAZ0003o`00
0?oVI03oiV@000?o000000?ojUH0o`000?oZD`001_oZD`000ol0003ojU@0onYD0003onYD00?o0000
1Oo]B`000ol0003oje40on]A0004on]A00;o00001oo[D0001?l0003oj5`0o`000?l00004onYC0003
o`000?oWH@3oif4000;oif400_l000000ooXFP3o0000onAZ0006onAZ00;o00001ooPMP02o`0000Oo
g8D000?o0000omFI0?l000001OoFUP000ol0003ocj/0o`000006om2X00;o00001_o8_002o`0000Co
[Kl00_l00003ojjo0004o`000?n4]03oQ;@0o`0000GoPk@000?o0000ooooooooool04_ooool00ol0
003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`0Hooooo`06o`000?l0K3Go0000o`1i
8_l0003o0HX00_l00002oaRC0004o`000?m1X@3o@J40od6Q00;o000000?oEJL0o`000?mn/`000_mn
/`000ol0003oY[d0ojJm0002ojJm0003o`000?o6`03o000000?o00001?o>[@000ol0003oe9/0omBK
0002omBK0003o`000?oJR`3ofX/000CofX/000?o0000omim0?oNO@000ooNO@000ol0003ohW80on9b
0003on9b0004o`000?oTJP3oi6X0onAZ00Go00001OoZEP000ol0003ojU<0onYC0004onYC0003o`00
0?oZE03ojU@000?o000000?okTP0o`000?o]B`001_o]B`000ol0003oje40on]A0003o`000003oni8
0?l0003oje0000Koje000_l00007onYC0004o`000?oWH@3o0000o`0000Coj5X000?o0000onAZ0?oT
JP000_oTJP02o`000003onIT0?l0003oh7H000Goh7H000?o0000on9a0?l000001ooLQ@02o`0000Ko
eYH00_l00006om2X0003o`000?o@YP3o000000Gob;`000Co0000olRk0?o8^`3o00000on]_`02o`00
00?o[[l000?o0000ohBd0?l000001On3]0000ol0003oP[@0o`00000Cooooo`03o`000?oooooooooo
00_ooooo000Kooooo`;o00006oooool00ol0003o06`eo`000002o`0000;o0HX00_l000001_lHT`3o
0000od6Q0?m1X@3o0000ofb^00?o00000omn/`000ol0003oY[d0ojJm0003o`0000Coa/0000?o0000
olj]0?o>[@000_o>[@000ol0003oe9/0omBK0002omBK0003o`000?oJR`3ofX/000CofX/000?o0000
omim0?oNO@000ooNO@001?l0003ohW80on9b0?oRLP05o`0000?oj5/000?o0000onYF0?oZEP001OoZ
EP000ol0003ojU<0onYC0003onYC00?o00001Oo^B0000ol0003okD/0one;0004one;00?o00001Oo^
B0000ol0003oje00on]@0002on]@00;o000000?okTP0o`000?oZD`001_oZD`02o`0000Ooj5X000Co
0000onAZ0?l0003o00001?oVI0001?l0003oh7H0on1f0?oPMP02o`0000?ohW4000?o0000omb50?oL
Q@000_oLQ@02o`0000;ogH4000Co0000omJF0?oFUP3oeYH00_l00002omNC0004o`000?o@Z03od:P0
om2X00;o00000oo@YP001Ol0003ob;`0olRl0?o8_03o000000Cob;/000?o0000ojfo0?l000000_n^
_`000ol0003o[[l0ojjo0002o`0000GoPk@000Go0000oh:d0?n2]03oP[@0o`00000Cooooo`03o`00
0?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo01_ooooo0_l000001_l0OaKo0000o`00
0?l1RP3o0000obVJ00;o00000om1X@001?l0003oK:h0ofb^0?m/[P06o`0000;oY[d000?o0000olK0
0?o6`0000oo6`0000ol0003ocZd0olj]0002olj]0003o`000?oDV`3oe9/000;oe9/000?o0000omZ;
0?oJR`000ooJR`001?l0003ogWd0omim0?oNO@06o`0000;oiV@000?o0000onQK0?oXF`001?oXF`00
0ol0003ojUH0onYF0004onYF0003o`000?oZD`3ojU<000?o000000?okTL0o`000?o^B0001_o^B000
0ol0003okD/0one;0003o`000003onm10?l0003okTP000KokTP000Co0000on]@0?l0003o00001?o^
B0000ol0003ojU<0onYC0002onYC00;o000000?ok4d0o`000?oXFP001_oXFP02o`0000OoiV@000?o
0000on1f0?l000001_oRL@001?l0003og8D0o`000?l00005omf10003o`000?oFUP3o000000Goei<0
00?o0000om2X0?l000001_o@YP000ol0003ob;`0o`000005olRk00;o00000on^_`000ol0003o[[l0
o`000002ojfo0005o`000?n3]03oPk@0oh>d0?l000001?n2]002o`0001?ooooo00?o0000oooooooo
ool02Oooool001_ooooo0_l0000Looooo`?o000000Go07lFo`000?l1RP3o0HX0o`000002obVJ0005
o`000?m1X@3o@J40od6Q0?l000000_m/[P03o`000003oiJi0?l0003o000000Co00001?o6`0000ol0
003ocZd0olj]0002olj]0003o`000?oDV`3oe9/000?oe9/000Co0000omZ;0?oJR`3ofX/01Ol00003
on=_0003o`000?oVI03oiV@000?oiV@000?o0000onQK0?oXF`001?oXF`000ol0003ojUH0onYF0003
onYF00?o00001Oo^A`000ol0003okTP0oni80004oni800?o00001Oo_@@000ol0003okTP0oni80004
oni800;o00001oo^B0001?l0003ojU<0o`000?l00004ona=0003o`000?oXFP3oj5X000;oj5X00_l0
00000ooZE@3o0000onIT0006onIT00;o00001ooRL@02o`0000OogH400_l00006omNC00;o00001oo@
YP02o`0000Gob;/000?o0000olRk0?l000000on^_`02o`0000Co[Kl000?o0000oh>d0?l000001?n2
]0000ol0003oO[<0o`00000Cooooo`;o00002_ooool001_ooooo00?o0000ooooooooool07?ooool3
o`000005o`1o5_l0003o0000o`6:0?l000000_lYVP08o`0000?oU[T000Co0000okk30?nn``3o_/<0
5?l00002omim0003o`000?oSK`3ohfl000Cohfl000?o0000onIT0?oVI0000ooVI0000ol0003oj5/0
onQK0004onQK0003o`000?oZEP3o000000;o00000_o]BP000ol0003okTL0oni70004oni70003o`00
0?o^B03okTP000?o000000?ol3h0o`000?o_@@001_o_@@000ol0003okTP0oni80003o`000003oo0o
0?l0003okTP000KokTP00_l00007ona=0004o`000?oXFP3o0000o`0000CojUD000?o0000onIT0?oV
I0000_oVI002o`000003onMP0?l0003ohW4000GohW4000?o0000on=^0?l000001_oMP@000ol0003o
gWh0o`000005omNC0003o`000?oHT@3o000000Kod:H000?o0000om6U0?l000000oo8^`02o`0000?o
b;/000?o0000ojjo0?l000000_n]_`001?l0003o[Kl0ojfo0?n]_`02o`0000CoP[@000Go0000ogjc
0?mn/`3oO[<0o`00000Cooooo`03o`000?oooooooooo00Sooooo0007ooooo`?o00001?ooool2o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo01gooooo0_l000000ol0OaKo0000oa2@0002o`00
00;o:IX01_l00002ofb^0005o`000?nF^@3oU[T0oiJi0?l000000onn``000ol0003oc;<0olbc0002
olbc0003o`000?oCW`3odil000;odil000?o0000omV=0?oIS@000ooIS@000ol0003ogWd0omim0003
omim0003o`000?oSK`3ohfl000Cohfl000?o0000onIT0?oVI0000ooVI0001?l0003oj5/0onQK0?oX
F`04o`0000KokDX000?o0000oni70?o^A`000oo^A`03o`0000Gol3h000?o0000onm10?o_@@001?o_
@@03o`0000Gol3l000?o0000oni80?o^B0000_o^B002o`000003onm10?l0003ok4d000Kok4d00_l0
0007onYE0004o`000?oVI03o0000o`0000Coif0000Co0000on9a0?oRL@3ohW400_l00003on=^0004
o`000?oMP@3ogH40omf100;o00000ooNOP000ol0003oei<0omNC0002o`0000?of94000Co0000om2V
0?o@YP3od:H00_l00003om6U0003o`000?o8^`3o000000Kob;/000?o0000ojfo0?n]_`000_n]_`00
1Ol0003o[Kl0o`000?n[_P3o000000?oP[@000?o0000ogjc0?mn/`000_mn/`02o`00017ooooo0ol0
0009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0Mooooo`03o`000?l0LRgo000000;o0000
0_l@T004o`0000;oEJL000?o0000oh6d0?l000000_l00004oiJi0005o`000?nn``3o_/<0okk30?l0
00001?o</`000ol0003odil0om>O0002om>O0003o`000?oIS@3ofHd000?ofHd000?o0000omim0?oN
O@000ooNO@000ol0003ohfl0on=_0003on=_0004o`000?oVI03oiV@0onIT00Ko00000oo/C`000ol0
003okDX0one:0005one:0003o`000?o^A`3o000000;o000000?ol3d0o`000?o`?P001_o`?P001?l0
003okd40onm10?o_@@02o`0000;olCT000?o0000oo0o0?o`?`001?o`?`001?l0003okTP0o`000?l0
0004onm10003o`000?o/C@3ok4d000;ok4d00_l000000oo^A`3o0000onYE0006onYE00;o00001ooW
H0000ol0003ohW40o`000006on=^0003o`000?oMP@3o000000GogWh000?o0000omNC0?l000001_oH
T@000ol0003od:H0o`000005om6U00;o00001_o8^`02o`0000Co[Kl00_l00003oj^n0003o`000?n2
]03o000000CoO[<000?o0000ogZb0?l000003_ooool3o`0000;ooooo00?o0000ooooooooool01ooo
ool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000oooool2o`00023ooooo0_l000000ol0Q@_o0000o`000002o`000004ocZO
0?l0003o0000o`0000;oEJL000Co0000oh6d0?n1]03oPK@01Ol00004okk30003o`000?o</`3oc;<0
00;oc;<000?o0000om>O0?oCW`000_oCW`000ol0003ofHd0omV=0003omV=0003o`000?oNO@3ogWd0
00?ogWd000Co0000on=_0?oSK`3ohfl01Ol00003onUG0003o`000?o/C`3ok4l000Cok4l000?o0000
one:0?o]BP001?o]BP02o`0000Gol3d000?o0000oo0n0?o`?P001?o`?P001?l0003okd40o`000?l0
0005oo4i0003o`000?o`?`3ol3l000?ol3l00_l00007onm10004o`000?o/C@3o0000o`0000CokTL0
00?o0000onYE0?oZE@000_oZE@02o`000003on]@0?l0003oif0000Koif000_l00007on=^00;o0000
1_oNOP02o`0000Oof9400_l00005om6U0003o`000?oAY@3o000000Gob;/000Co0000olRk0?o8^`3o
00000on]_`02o`0000?oZkh00_l00004ogjc0005o`000?mj/P3oN[80ogZb0?l000002_ooool3o`00
00Gooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07oooool3
o`0000;o08D;0ol00003ocZO00;o000000?oEJL0o`000?n1]0000_n1]0000ol0003o[;h0ojbn000:
o`000003olbc0?l0003odil000?odil000Co0000omV=0?oIS@3ofHd02ol00003onIR0003o`000?oY
E`3ojEL000?ojEL000?o0000ona?0?o/C`001?o/C`000ol0003okDX0one:0003o`000003oo0o0?l0
003ol3d000Gol3d000?o0000oo0n0?o`?P000oo`?P02o`0000SolCT000?o0000oo0o0?l000000_l0
00000oob>03o0000onm10006onm100;o00001oo^A`001?l0003ojUD0o`000?l00004on]@0003o`00
0?oWH03oif0000;oif000_l00002onQL0003o`000?oSKP3ohfh000;ohfh00_l000000ooTJ`3o0000
omin0004omin0003o`000?oNO@3o000000Kof94000?o0000omR@0?l000000ooAY@02o`0000?odJD0
00Go0000olRk0?o8^`3ob;/0o`000004olRk0003o`000?n]_`3o000000;oZkh000Go0000oj^n0?l0
003oZ;h0o`000003ogjc0003o`000?mj/P3oN[8000?oN[8000?o0000ooooooooool00oooool4o`00
00Sooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07?ooool3
o`000007ooooool0003o07LTo`000?l0Q@_o0000oafE0002o`0000;o>Yl000?o0000ofN]0?l00000
0_l00003oh6d0005o`000?n/_P3o[;h0ojbn0?l000000oo8_0001?l0003od:H0om2V0?o@YP0:o`00
00;ogH0000?o0000on9`0?oRL0000ooRL0000ol0003oiV80onIR0004onIR0003o`000?oYE`3ojEL0
00?ojEL000Co0000ona?0?o/C`3ok4l01Ol00005oo0o0003o`000?o`?@3ol3d000Col3d000?o0000
oo0n0?l000000_l00002oo8e0003o`000?oa>@3olCT000GolCT00_l00005oo8h0003o`000?o_@@3o
kd4000;okd400_l000000ooa?03o0000oni70006oni700;o00001oo[D0001?l0003oif00o`000?l0
0005onQL0004o`000?oSKP3o0000o`0000Coi6/000?o0000omin0?oNOP000_l00003omim0004o`00
0?oHT@3of940omRA00;o00000ooHT0000ol0003odJD0o`000006om6U0003o`000?o8^`3o000000Go
b;/00_l00004oj^n0007o`000?nX_P3oZ;h0ojRn0?l0003oO[<0o`000005ogZb00;o00000_ooool3
o`0000gooooo00?o0000ooooooooool01_ooool000Oooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool2o`0001[ooooo0ol00005ooooo`03o`000?l0
MbCo000000;o00000_lMU@001?l0003o>Yl0ocZO0?l00003ofN]00Go00000on/_P001Ol0003ob;`0
olRl0?o8_03o000000Cod:H000?o0000omNB0?oGTP000_oGTP000ol0003ogH00omf00003omf00003
o`000?oRL03ohW0000?ohW0000?o0000onIR0?oVHP001?oVHP001?l0003ojEL0onUG0?oYE`05o`00
00?okd@000?o0000oo0o0?o`?`001Oo`?`001?l0003ol3d0oo0m0?o`?@04o`0000KolSD000?o0000
oo4i0?oa>@000_oa>@02o`000003oo<b0?l0003olSP000GolSP000Co0000onm10?l0003o00001?oa
?0000ol0003okTL0oni70002oni700;o000000?okd<0o`000?o[D0001_o[D002o`0000Ooj5`00_l0
0006onA[0003o`000?oNOP3o000000KogWd000?o0000omRA0?l000001OoHT002o`0000OodJD00_l0
0005olRk0003o`000?o8_03o000000?oZkh00_l00004ojRn0003o`000?mj/P3oN[8000?oN[8000?o
0000og>`0?mc/0000_l0000@ooooo`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00001?ooool00ol0003oooooooooo`0Fooooo`?o00002Oooool5
o`0000;o7ID00_l000001OljW`3o0000ofN]0?mW[@3o000000?oTkT01_l00003olRl0003o`000?o@
YP3od:H000;od:H000?o0000omNB0?oGTP000_oGTP000ol0003ogH00omf00003omf00003o`000?oR
L03ohW0000?ohW0000Co0000onIR0?oVHP3oiV801_l00003one<0003o`000?o_A03okd@000?okd@0
00?o0000oo0o0?o`?`001?o`?`04o`0000?olc@000?o0000oo8e0?ob=@001Oob=@001?l0003olCT0
o`000?l00004oo<b0003o`000?ob>03olSP000?olSP00_l00007oo4l0004o`000?o^A`3o0000o`00
00Cokd<000?o0000on]@0?o[D0000_o[D002o`000003ona=0?l0003oj5`000Goj5`000?o0000onUJ
0?l000001_oTJ`02o`0000OogWd00_l00005omR@0003o`000?oHT03o000000KodJD000?o0000om6U
0?l000000oo8^`02o`0000?ob;`000?o0000oj^n0?l000000_nX_P001_l0003oZ;h0ojRn0?l0003o
Xk`0o`0000?oN[8000?o0000og>`0?mc/0000_mc/0000ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Kooooo000Jooooo`03o`000?oooooooooo01Cooooo0_l0000=ooooo`?o000000Go08T0
o`000?lMU@3o0000odVT0003o`0000;oIjd000Go0000oi>i0?nC^@3oTkT0o`000003oko300Ko0000
1?o@YP000ol0003oei80omNB0002omNB0003o`000?oMP03ogH0000?ogH0000Co0000on9`0?oRL03o
hW001Ol00003onUG0003o`000?o]C03okD`000CokD`000?o0000onm40?o_A0000oo_A0000ol0003o
l3l0oo0o0003o`000003oo8f0?l0003olc@000Golc@000?o0000oo8e0?ob=@001?ob=@02o`0000Oo
lc8000?o0000oo8h0?l000000_l00002oo<b0003o`000?oa?03olC`000ColC`00_l00007onm30004
o`000?o[D03o0000o`0000Cok4d000Co0000onQL0?oXG03oj5`00_l00003onUJ0004o`000?oTJ`3o
i6/0onA[00;o00000_oTJ@000ol0003ogWd0omim0002omim00;o00000_oON`001Ol0003of900omR@
0?oHT03o000000?of90000Co0000om6U0?oAY@3odJD00_l00003om6U0003o`000?o8^`3o000000Go
b;`00_l00004ojRn00;o00000onS_0000ol0003oN[80o`000004og>`0003o`000?m/[P3o000000oo
oooo00?o0000ooooooooool01_ooool001Wooooo0_l0000Cooooo`?o00004?ooool01?l0003o07/M
o`000?l0R@03o`0000?oBJ@00_l000000omW[@3o0000oi>i0002oi>i0005o`000?no``3o_l<0oko3
0?l000000oo</@0Do`0000?oiV@000?o0000onUG0?oYE`000ooYE`000ol0003okD`0one<0004one<
0004o`000?o_A03okd@0onm400Co00001Oob=P000ol0003olc@0oo<d0004oo<d0003o`000?ob=@3o
lSD000?o000000?om2h0o`000?oc<P001_oc<P02o`0000Kolc8000Co0000oo4l0?oa?03olC`00_l0
00000oob=`3o0000onm30006onm300;o00001oo/C@000ol0003oj5`0o`000006onUJ0003o`000?oT
J`3o000000Goi6T000Co0000omim0?l0003o00001OoON`000ol0003of900o`000005omR@0003o`00
0?oAY@3o000000GodJD00_l00005olRl0004o`000?o7_P3oakh0o`0000?oZ;h000?o0000oj>l0?nS
_0000_nS_002o`0000CoLk0000Go0000ofb^0?m/[P3oK:h0o`00000>ooooo`03o`000?oooooooooo
00Kooooo000Iooooo`03o`000?oooooooooo00oooooo0ol0000Dooooo`05o`000?l0Nago0000o`00
0?lYVP000_l00002odVT0004o`000?mg/@3o0000o`0000CoTkT000Go0000oko30?no``3o_l<0o`00
0003olba0003o`000?oDV`3oe9/000?oe9/000?o0000om^70?oKQ`000_oKQ`000ol0003ohG@0on5d
0002on5d0003o`000?oVI03oiV@000CoiV@000?o0000onUG0?oYE`000ooYE`000ol0003okD`0one<
0003one<00Co00000ooa>`000ol0003olSH0oo8f0004oo8f0003o`000?oc=03olc@000?olc@00ol0
0005oo@^0003o`000?oc<P3olc8000;olc800_l000000ooe;03o0000oo<b0006oo<b0003o`000?oa
?03o000000ColSL000?o0000onm30?o_@`000_o_@`02o`000003oo0o0?l0003ok4d000Kok4d00_l0
0007onUJ00;o00001_oTJ@02o`0000Oogg/00_l00006omR@00;o00001OoAY@001?l0003od:H0om2V
0?l00003olRl0003o`000?o7_P3oakh000;oakh000Go0000ojRn0?l0003oXk`0o`000002oj>l0003
o`000?nM^`3o000000?oLk0000?o0000ofb^0?m/[P000_m/[P02o`0000gooooo00?o0000oooooooo
ool01_ooool001Wooooo00?o0000ooooooooool03?ooool3o`0001Sooooo0_l000001?l9S@3o0000
obVJ0?lYVP02o`000004odVT0?l0003oMk40ogNa00Go00001?no``001Ol0003oc;40olba0?o</@3o
000000Goe9/000?o0000om^70?oKQ`000_oKQ`000ol0003ohG@0on5d0002on5d0003o`000?oVI03o
iV@000CoiV@000?o0000onUG0?oYE`000_oYE`000ol0003okD`0one<0003o`000003onm20?l0003o
lC/000GolC/000?o0000oo8f0?ob=P000oob=P000ol0003olc@0oo<d0003o`000003oo@]0?l0003o
m2h000Kom2h000Co0000oo<b0?l0003o00001?oe;0000ol0003olc80oo<b0004oo<b00;o00001_ob
=`001?l0003okd<0o`000?l00004oo0o0003o`000?o/C@3ok4d000;ok4d00_l00002one:0003o`00
0?oYFP3ojEX000;ojEX00_l000000ooYF03o0000onAY0004onAY0003o`000?oTJ03o000000Kogg/0
00?o0000ommk0?l000001?oHT002o`0000;of90000Go0000om6U0?oAY@3odJD0o`000004om2V0003
o`000?o8_03o000000Goakh00_l00003oj>l00;o00000onM^`000ol0003oLk00o`000004ofb^0004
o`000?mS[03oHj`0o`0000cooooo00?o0000ooooooooool01_ooool001Wooooo0_l0000:ooooo`?o
00006oooool01Ol0003o07lFo`000?l9S@3o000000;o:IX01?l00002ogNa0003o`000?nT_@3oY;d0
00Ko00001?o</@000ol0003oe9/0omBK0003omBK0003o`000?oKQ`3ofhL000;ofhL000?o0000on5d
0?oQM0000_oQM0001?l0003oiV@0onIT0?oVI00:o`0000Gokd8000?o0000oo4k0?oa>`001?oa>`00
1?l0003olSH0oo8f0?ob=P04o`0000Gom2d000?o0000oo@^0?od;P001?od;P02o`0000OomB`000?o
0000oo<b0?oc<P000ol00002oo@^0003o`000?ob=`3olSL000?olSL00_l00007oo0o0004o`000?o/
C@3o0000o`0000GokDX000Co0000onUJ0?l0003o00001?oYF0000ol0003oi6T0onAY0002o`0000?o
i6P000Co0000ommk0?oON`3ogg/00_l00003ommk0004o`000?oHT03o0000o`0000Gof90000?o0000
om6U0?l000001Oo@YP02o`0000Goakh000?o0000olK00?l000000onS_002o`0000?oWK/00_l00003
ofb^00;o00000omS[002o`0000cooooo00?o0000ooooooooool01Oooool001Wooooo00?o0000oooo
ooooool01_ooool3o`0001oooooo00Co0000o`1o5_l0003o2Hd00_l000001?lYVP3o0000oeNX0?mG
Z002o`000003ogNa0?l0003oY;d000;oY;d000?o0000olNn0?o7_P006Ol00003onQJ0003o`000?o/
C@3ok4d000;ok4d000?o0000onm20?o_@P001Oo_@P001?l0003olC/0oo4k0?oa>`06o`0000?om2h0
00?o0000oo@]0?od;@001?od;@000ol0003om2h0oo@^0003o`0000;omRP000?o0000ooD/0?oe;000
1?oe;003o`0000Kom2h000?o0000oo8g0?l000000_l00002oo<c0003o`000?o`?`3ol3l000Col3l0
0_l00007one:00;o00001_oYF0000ol0003oi6T0o`000006onAX0003o`000?oON`3o000000Gogg/0
0_l00007omR@00;o00001Oo@YP000ol0003od:P0o`000003olNn00;o00000oo6`0001Ol0003oXk`0
o`000?nM^`3o000000;oWK/000Ko0000oiJi0?nF^@3o0000ofb^0?l00004of>/0004o`000?mHZ03o
F:P0o`0000_ooooo00?o0000ooooooooool01Oooool001Wooooo00?o0000ooooooooool00oooool3
o`0002?ooooo00Go0000o`1o5_l0003o0000ocBM0003o`000003oeNX0?l0003oQKD000?o00000onT
_@001Ol0003oakh0olNn0?o7_P3o000000Cod:L000?o0000omRA0?oHT@000_oHT@000ol0003ogWd0
omim0002omim0003o`000?oTJP3oi6X000?oi6X000?o0000onQJ0?oXFP000ooXFP000ol0003ok4d0
ona=0002ona=0003o`000?o_@P3okd8000Cokd801?l00003oo<c0003o`000?od;P3om2h000Com2h0
00Co0000oo@]0?od;@3om2d01Ol00006ooHX0003o`000?oe;03omB`000?o000000?omRL0o`000?od
;P001_od;P02o`0000Kolc<000?o0000oo0o0?o`?`000ol00002oo4l0003o`000?o]BP3okDX000;o
kDX00_l000000oo]B03o0000onUH0005onUH00;o00001ooTJ002o`0000Gogg/000?o0000ommk0?l0
00001_oHT0000ol0003of940o`000003om2V00;o00000oo@Z0000ol0003oakh0o`000005olK000;o
00000onM^`02o`0000CoU[T000?o0000of>/0?mS[0000_mS[0001?l0003oF:P0oeRX0?mHZ002o`00
00[ooooo00?o0000ooooooooool01Oooool001Sooooo0ol000001?oooooo0000o`000?l0000Woooo
o`;o000000?o4I40o`000?ldW@000_ldW@03o`0000?oQKD01Ol00003olNn0003o`000?o@Y`3od:L0
00;od:L000?o0000omRA0?oHT@000_oHT@000ol0003ogWd0omim0002omim0003o`000?oTJP3oi6X0
00?oi6X000?o0000onQJ0?oXFP000ooXFP000ol0003ok4d0ona=0002ona=0003o`000?o_@P3okd80
00?o000000?olCX0o`000?oc<`001Ooc<`000ol0003om2h0oo@^0003oo@^00Co00001?of9P000ol0
003omRP0ooHX0004ooHX00?o00001Oof9`000ol0003om2h0oo@^0002oo@^00;o000000?omBX0o`00
0?oc<`001Ooc<`03o`0000KolC`000Co0000one:0?l0003o00001?o]B0001?l0003ojEP0onUH0?oY
F002o`0000;ojEL000?o0000onAX0?oTJ0000_oTJ002o`0000;oiFP000Go0000ommk0?oON`3ogg/0
o`000003ommk0004o`000?oHT03of900omR@00;o00000ooHT@000ol0003od:H0o`000005om2X00;o
00001Oo6`0002?l0003oaL@0olG40?l0003oWK/0o`000?nF^@3o00000onF^@02o`0000?oHj`000Go
0000oeRX0?mHZ03oF:P0o`000002odbU0003o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool0017ooooo0_l00005ooooo`Co0000:_ooool01Ol0003o088@o`000?lAT@3o000000;o=9d0
00Co0000of>/0?l0003o00000_n5]@001?l0003o/l00ok?00?nc`006o`0000Cod:L000?o0000omRA
0?oHT@000_oHT@000ol0003ogWd0omim0002omim0003o`000?oTJP3oi6X000?oi6X000?o0000onQJ
0?oXFP000_oXFP001?l0003ok4d0ona=0?o/C@04o`0000GolCX000?o0000oo<c0?oc<`001?oc<`00
0ol0003om2h0o`000002o`0000;omRP000?o0000ooHV0?of9P001?of9P000ol0003omRP0ooHX0003
o`000003ooLS0?l0003omRL000KomRL000Co0000oo@^0?l0003o00001?oe:P001?l0003olc<0oo<c
0?oc<`02o`000003oo<a0?l0003olC`000KolC`00_l00007one80003o`000?oYF03o000000GojEL0
00Co0000onAX0?l0003o00001OoUJ0000ol0003ogg/0o`000005ommk0003o`000?oHT03o000000Go
f9400_l00005om2X0004o`000?o?Z`3ocj/0o`0000?oa/0000?o0000olG40?o5a0000_o5a0001ol0
003oU[T0oiJi0?nF^@3o0000oiJi0?l000000_n<]`000ol0003oHj`0o`000003oeRX0004o`000?m<
Y@3oC:D0odbU00;o00002?ooool00ol0003oooooooooo`05ooooo`004?ooool01?l0003ooooooooo
ool00004ooooo`;o0000;Oooool01?l0003o088@o`000?lAT@02o`000004ocBM0?l0003oHj`0of>/
00;o000000?oQKD0o`000?nc`0000_nc`0001?l0003ob[H0olZf0?o:]P0;o`0000CogWd000Co0000
onAZ0?oTJP3oi6X02ol00004oni50003o`000?oa>P3olCX000?olCX000Co0000oo<c0?oc<`3olc<0
1?l00006ooHX0003o`000?of9P3omRH000?omRH00ol00005ooLS0003o`000?of9`3omRL000ComRL0
0_l00007ooDZ0003o`000?oc<`3o000000Colc4000?o0000oo4l0?oa?0000_oa?002o`0000;olCX0
00?o0000one80?o]B0001?o]B002o`0000KojEL00_l00007onEX00;o00001_oON`02o`0000Gof940
00Co0000omNC0?oGT`3o00000oo@Z0000ol0003ocj/0oln[0002oln[0003o`000?o6`03o000000Co
aL@000?o0000okk30?l000000_nF^@02o`0000?oS;L00_l00003oeRX0005o`000?m<Y@3oC:D0odbU
0?l000000_lnX0000ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo000@ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0:oooool00ol0003o088@o`000005o`00
00;oHj`01?l00003ok?00005o`000?o:]P3ob[H0olZf0?l000001?oCW`001?l0003ofhP0om^80?oK
R009o`0000?oiV8000?o0000on]B0?o[DP000oo[DP000ol0003okTD0oni50004oni50004o`000?oa
>P3olCX0oo4j00Go00000ooe;0000ol0003omRP0ooHX0005ooHX0003o`000?of9P3o000000;o0000
00?omb80o`000?og8`001_og8`000ol0003omRL0ooHW0003o`0000;omb<000?o0000ooDZ0?oe:P00
1?oe:P02o`0000Kolc4000Co0000oo4l0?l0003o00001Ooa>P000ol0003okDP0one80003o`000003
oni70?l0003ojEL000?ojEL00_l00002onUG0003o`000?oUJ03oiFP000;oiFP00_l000000ooTJ03o
0000ommk0003ommk00;o000000?ogWd0o`000?oHT@000_oHT@02o`0000Coei<000?o0000om2X0?l0
00001Oo?Z`02o`0000CoaL@000Ko0000okk30?nn``3o_/<0o`000?nF^@02o`0000;oS;L000Ko0000
oh6d0?n1]03o0000oeRX0?l00003odbU0004o`000?lnX03o?Z00ocjP00;o00001oooool00ol0003o
ooooooooo`04ooooo`004?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02_o
oooo1Ol00002ocjP00;o000000CoHj`0o`000?nA^03oTKP01Ol00003olZf0003o`000?oCW`3odil0
00;odil000?o0000om^80?oKR0000_oKR0000ol0003ohG@0on5d0003on5d0003o`000?oVHP3oiV80
00;oiV8000?o0000on]B0?o[DP000oo[DP001?l0003okTD0oni50?o^A@06o`0000?olc<000?o0000
ooD/0?oe;0000ooe;0000ol0003omRP0ooHX0004ooHX00;o00001Oog8P000ol0003omb<0ooLS0004
ooLS00?o00001_og8`000ol0003omBX0ooDZ0003o`0000;omRL000?o0000oo<a0?oc<@000ooc<@02
o`0000OolCX00ol00005oni70004o`000?oYE`3o0000o`0000GojEL000Co0000onEX0?l0003o0000
1?oTJ0001?l0003ogg/0o`000?l00004omim0003o`000?oHT@3o000000Koei<00_l00005oln[0003
o`000?o=[P3o000000?oaL@000?o0000okk30?nn``000_nn``02o`0000;oS;L00_l00004oh6d0005
o`000?m<Y@3oC:D0odbU0?l000000olnX0001?l0003o;Y/0objK0?l00006ooooo`03o`000?oooooo
oooo00Cooooo000@ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0;?ooool2
o`000005oaRC0?l0003o?Z00o`000?m][P000ol000000onA^03o0000oko30002oko300Ko00001?oC
W`000ol0003ofhP0om^80002om^80003o`000?oQM03ohG@000?ohG@000?o0000onIR0?oVHP000_oV
HP001?l0003oje80on]B0?o[DP05o`0000?ol3h000?o0000oo<c0?oc<`001?oc<`000ol0003omB`0
ooD/0003ooD/0003o`000?of:03omRP000?o000000?omb<0o`000?og8P001Oog8P000ol0003omb<0
ooLS0003o`0000;on1l000?o0000ooLS0?og8`001?og8`03o`0000KomRL000?o0000oo<a0?l00000
0_l00002oo@_0003o`000?oa>P3olCX000;olCX00_l000000ooa>@3o0000oni70005oni700;o0000
1ooYE`02o`0000Koi6P00_l00006omim00;o00001_oGT`000ol0003oeYH0o`000003oln[00;o0000
0oo=[P000ol0003oaL@0o`000004okk30006o`000?ne`@3o]L40o`000?n<]`3o00001?n1]0001Ol0
003oM;00o`000?m<Y@3o000000?o?Z0000Co0000objK0?l^V`3o;Y/00_l00005ooooo`03o`000?oo
oooooooo00Cooooo000@ooooo`04o`000?ooooooooooo`0000Wooooo0_l0000]ooooo`;o000000Co
69<0o`000?l0003o00000om][P03o`0000?o_l<000Co0000olf_0?o=[`3ocJl06Ol00003one;0003
o`000?o`?P3ol3h000?ol3h000?o0000oo<c0?oc<`001?oc<`001?l0003omB`0ooD/0?oe;004o`00
00Gomb<000?o0000ooLR0?og8P000oog8P03o`0000Kon1l000?o0000ooLS0?og8`000ol000000ooh
8@3o0000ooHW0006ooHW00;o00001_od;`001?l0003olCX0o`000?l00004oo4i0004o`000?o^A`3o
kTL0oni700;o00000_o^A`000ol0003ojEL0onUG0002onUG00;o00000_oYE`001?l0003oi6P0onAX
0?oTJ002o`0000;oi6T000Co0000omim0?oNO@3ogWd00_l00002omin0004o`000?oGT`3oei<0omNC
00;o00000ooFUP000ol0003ocj/0o`000005olf^00;o00000onn``02o`0000?o]L400_l000001On1
]03o0000oh6d0?n1]03o000000?oM;0000Go0000ocjP0?lnX03o?Z00o`000003objK0003o`000?lM
U@3o7ID000;o00000oooool00ol0003oooooooooo`04ooooo`004Oooool2o`0000cooooo00?o0000
ooooooooool0:oooool6o`0000;oKJh000Co0000oibk0?l0003o00000ono``001Ol0003ocJl0olf_
0?o=[`3o000000CoeYP000?o0000omf10?oMP@000ooMP@000ol0003ohfd0on=]0002on=]0003o`00
0?oXFP3oj5X000;oj5X000?o0000one;0?o]B`001?o]B`000ol0003ol3h0oo0n0003oo0n0004o`00
0?oc<`3olc<0oo<c00Ko00000oof9`000ol0003omb<0ooLS0004ooLS0003o`000?og8P3o000000;o
00000ooh7P000ol0003on1l0ooPO0003ooPO00?o00001Ooh8@000ol0003omRL0ooHW0002ooHW00;o
000000?omRH0o`000?od;`001Ood;`02o`0000OolCT000?o0000oni70?l000001Oo^A`001?l0003o
jEL0o`000?l00005onUG0003o`000?oTJ03o000000Goi6T000?o0000omim0?l000001OoNOP000ol0
003oei<0o`000005omJF00;o00001Oo=[P001_l0003oc;80olbb0?l0003o_/<0o`0000Co]L4000?o
0000ojZn0?l000000_n1]002o`0000?oM;0000Go0000ofJ/0?l0003o?Z00o`000003objK0004o`00
0?lMU@3o7ID0o`0000;o2hh01?l00006ooooo`008?ooool00ol0003oooooooooo`0[ooooo`Co0000
00GoAZ<0o`000?l0003oKJh0o`000002oibk00Go00000oo=[`000ol0003oeYP0omJH0002omJH0003
o`000?oMP@3ogH4000?ogH4000?o0000on=]0?oSK@000_oSK@000ol0003oj5X0onQJ0002onQJ0003
o`000?o]B`3okD/000CokD/000Co0000oo0n0?o`?P3ol3h01Ol00003oo@^0003o`000?of9`3omRL0
00ComRL000Co0000ooLS0?og8`3omb<01?l00007ooPN0003o`000?oh7`3o000000;o000000?onA`0
o`000?oh8@001_oh8@001?l0003omRL0o`000?l00004ooHV0004o`000?od;`3om2l0oo@_00;o0000
0_od;P000ol0003olCT0oo4i0004oo4i00;o00001_o^A`02o`0000OojEL00_l00006onAY00;o0000
1_oNOP02o`0000CoeYH00_l000000ooEV@3o0000olf^0002olf^00;o00000oo</P02o`0000Co]L40
00Ko0000ojZn0?nZ_P3oZ[h0o`000?n1]002o`0000;oM;0000Go0000ofJ/0?mV[03oIZ`0o`000003
objK0004o`000?lMU@3o7ID0o`0000;o2hh000?o0000o`261ol0QPL00_l00006ooooo`008Oooool0
0ol0003oooooooooo`0[ooooo`;o000000?o7YD0o`000?l000001?l00003oibk0003o`000?o6`P3o
000000Go00001?oFV0000ol0003ogH40omf10003omf10003o`000?oSK@3ohfd000;ohfd000?o0000
onQJ0?oXFP000_oXFP001?l0003okD/0one;0?o]B`06o`0000;olSP000?o0000oo@^0?od;P001?od
;P000ol0003omRL0ooHW0003ooHW00Co00001?oh7`000ol0003on1h0ooPN0004ooPN00;o00001Ooi
70000ol0003on240ooPQ0004ooPQ00;o00001_of9P001?l0003om2l0o`000?l00005oo@^0003o`00
0?oa>@3olCT000?o000000?olCT0o`000?o^A`000oo^A`02o`0000;okTL000?o0000onUG0?oYE`00
0_oYE`02o`000003onUH0?l0003oi6T000?oi6T00_l000000ooTJ`3o0000omin0003omin00;o0000
0_oMP@001?l0003oeYH0o`000?l00004omFI0003o`000?o=[P3o000000Coc;8000?o0000olZh0?l0
00000one`@000ol0003oZ[h0ojZn0002ojZn00;o000000CoM;00o`000?md/03o00000omV[0001Ol0
003oEJL0o`000?l^V`3o000000;o7ID000Co0000o`^>0?l;SP3o00000_l0QPL3o`0000Kooooo000R
ooooo`03o`000?oooooooooo02_ooooo0ol000000om<Y@3o0000o`000002ogFa00Go00000oo6`P00
0ol0003ocjT0o`00000Ho`0000?okTD000?o0000oo8h0?ob>0000oob>0000ol0003om2h0oo@^0004
oo@^0003o`000?of9`3o000000;o000000?omb<0o`000?oh7`001_oh7`000ol0003on1h0ooPN0003
o`000003ooTK0?l0003onA`000GonA`000?o0000ooPQ0?oh8@000ol00002ooPO0003o`000?of9P3o
mRH000?omRH00_l00007oo@^00?o00001Ooa>@001?l0003okTL0o`000?l00005oni70004o`000?oY
E`3o0000o`0000CojEP000Co0000onAY0?l0003o00001?oTJ`001?l0003ogWh0o`000?l00004omf1
00;o00001_oEV@03o`0000?oc;8000Oo0000olZh0?o:^03ob[P0o`000?ne`@3o000000CoZ[h000Ko
0000oifk0?nM^`3o0000ogB`0?l00003ofJ/0003o`000?mEY`3oEJL000?o000000Go7ID0o`000?l;
SP3o2hh0o`000002o`261`;o00000_ooool00ol0003oooooooooo`03ooooo`008oooool2o`0002co
oooo0ol00002odbU0004o`000?me/@3oMK40o`0000;oY;d01_l00003olnY0005o`000?oHT@3of940
omRA0?l000001?oON`000ol0003oiFH0onEV0002onEV0003o`000?oZE03ojU@000?ojU@000?o0000
oni50?o^A@000oo^A@000ol0003olSP0oo8h0003oo8h0004o`000?od;P3om2h0oo@^00Co00001Oog
8`000ol0003on1l0ooPO0004ooPO00?o00001Ooi6`000ol0003onA`0ooTL0003ooTL00?o00001_oh
7`000ol0003omRH0o`000002o`0000;omb@000?o0000oo@^0?od;P000_od;P02o`000003oo@]0?l0
003olCT000GolCT00_l00007oni700;o00001_oYF002o`0000Koi6/00_l00005omf10004o`000?oL
Q@3og8D0o`0000?oeIT00_l00003om>M0003o`000?o</P3o000000Cob[P00ol00003ojZn0004o`00
0?nM^`3oWK/0oifk00;o000000CoIZ`0o`000?mV[03o00000_mEY`001?l0003o@j80od>R0?m3XP02
o`000004o`^>0?l0003o08H7o`261`;o00000oooool00ol0003oooooooooo`03ooooo`009Oooool0
0ol0003oooooooooo`0Zooooo`?o00000_m<Y@04o`0000;oY;d000Co0000olRm0?o8_@3ob;d01_l0
0003omRA0003o`000?oON`3ogg/000;ogg/000?o0000onEV0?oUIP000_oUIP000ol0003ojU@0onYD
0003onYD0003o`000?o^A@3okTD000?okTD000Co0000oo8h0?ob>03olSP01Ol00004ooDZ0003o`00
0?og8`3omb<000?omb<000?o0000ooPO0?oh7`000ol00002ooTL0003o`000?oi6`3onA/000ConA/0
00?o0000ooTL0?l000000_l00002ooTJ0003o`000?oh7`3on1l000Con1l00_l00006ooLT0004o`00
0?od;P3o0000o`0000Com2d000Co0000oo4i0?oa>@3olCT00_l00002oo4i0003o`000?o^A`3okTL0
00;okTL00_l00002one80004o`000?oYF03ojEP0onUH00;o00000_oYFP001?l0003oi6/0onA[0?oT
J`02o`0000;ohfh000Go0000omf10?oMP@3ogH40o`000004omb50003o`000?oEV@3o000000Godid0
0_l00004olZh0007o`000?o7_P3oakh0olNn0?l0003oZ[h0o`000003oifk0006o`000?n>]`3oS[L0
o`000?mV[03o00000_mEY`001Ol0003o@j80od>R0?m3XP3o000000;o;i/00_l000000ol0QPOo0000
o`000004ooooo`03o`000?oooooooooo00?ooooo000Vooooo`03o`000?oooooooooo02[ooooo1?l0
00000om<Y@3o0000og^b0003o`000003ojBm0?l0003ob;d000;ob;d000Co0000om6T0?oAY03odJ@0
1_l00004ommk0003o`000?oUIP3oiFH000;oiFH000Co0000onYD0?oZE03ojU@02ol00003oo<c0003
o`000?oe:P3omBX000ComBX000Co0000ooLS0?og8`3omb<01?l00006ooTL0004o`000?oi6`3onA/0
ooTK00Co00001_oi6P000ol0003on1l0ooPO0003o`0000;on1d000?o0000ooLT0?og90000oog9002
o`0000Oom2d000?o0000oo4i0?l000001Ooa>@001?l0003okTL0o`000?l00005one80003o`000?oY
F03o000000GojEX000?o0000onA[0?l000001OoSKP000ol0003ogH40o`000005omb500;o00001OoC
W@000ol0003odZ<0o`000003olZh0003o`000?o7_P3oakh000;oakh00_l00003oifk0004o`000?n>
]`3oS[L0ohjg00?o000000?oEJL0o`000?m3XP000_m3XP001?l0003o;i/0obnK0?l00002oaZD00;o
00001Oooool00ol0003oooooooooo`03ooooo`009oooool00ol0003oooooooooo`0Zooooo`Ko0000
0_mk/P04o`0000?ob;d000Go0000om6T0?oAY03odJ@0o`000003omV<00ko00000oo/C`000ol0003o
l400oo100003oo100003o`000?oc<`3olc<000?olc<000Co0000ooDZ0?oe:P3omBX01_l00003ooPO
0003o`000?oi703onA`000ConA`01?l00004ooXI0003o`000?oi6P3onAX000?onAX00ol00006ooPM
0003o`000?og903o000000;o00000_og90000ol0003om2d0oo@]0004oo@]00;o00001_oa>@02o`00
00OokDP00_l00006onUJ00;o00001_oSKP02o`0000Gog8D000?o0000omZ90?l000000ooCW@02o`00
00?odZ<000?o0000olZh0?l000001?o7_P001_l0003oa<@0olC40?l0003oWK/0o`0000?oS[L000Go
0000ogfc0?mm/`3oOK<0o`000003od>R0004o`000?l_V`3o;i/0o`0000;o6Y@000?o0000o`B;0?l0
00001Oooool00ol0003oooooooooo`03ooooo`00:?ooool2o`0002_ooooo0_l000000olTV03o0000
oe2V0002o`000004og^b0?l0003oZkh0oj^n00Go00000ooAY0000ol0003ofH`0omV<0002omV<0003
o`000?oQMP3ohGH000;ohGH000?o0000onIQ0?oVH@000_oVH@000ol0003ok4l0ona?0003ona?0003
o`000?o`@03ol40000?ol40000Co0000oo<c0?oc<`3olc<01Ol00004ooHV0003o`000?oh7`3on1l0
00?on1l000?o0000ooTL0?oi70000ol000000ooi6P3o0000ooXI0006ooXI0003o`000?oi6P3o0000
00;o00000_oi6@000ol0003on1d0ooPM0004ooPM00;o00001_og90000ol0003om2d0oo@]0003o`00
00;om2h000Co0000oo4i0?oa>@3olCT00_l00002oo4j0003o`000?o]B03okDP000;okDP00_l00000
0oo]BP3o0000onUJ0003onUJ00;o000000?oj5`0o`000?oSKP000ooSKP02o`000003on9a0?l0003o
g8D000;og8D00_l00003omZ90003o`000?oCW@3o000000GodZ<00_l00003olNn00;o00000oo4a002
o`0000?oS[L000Wo0000ogfc0?mm/`3oOK<0o`000?mZ[@3o0000od>R0?l000000_l_V`001_l0003o
6Y@0oaZD0?l0003o18/0o`0000Kooooo00?o0000ooooooooool00oooool002[ooooo00?o0000oooo
ooooool0:Oooool9o`0000;oZkh000?o0000olVi0?o9^@001_l00004omV<0003o`000?oQMP3ohGH0
00;ohGH000?o0000onIQ0?oVH@000_oVH@000ol0003ok4l0ona?0003ona?0004o`000?o`@03ol400
oo1000Go00001?od<0000ol0003omRH0ooHV0003ooHV0004o`000?oh7`3on1l0ooPO00Co00001Ooi
6P000ol0003onQT0ooXI0004ooXI00;o00001_oi6@000ol0003on1d0ooPM0003o`0000;on1d000?o
0000ooLT0?og90000oog9003o`0000Kom2h000?o0000oo4i0?l000001Ooa>P001?l0003okDP0o`00
0?l00004one:0004o`000?oYFP3o0000o`0000Coj5`000Co0000on=^0?l0003o00001?oRL@000ol0
003og8D0o`000005omZ900?o00000ooBX`02o`0000;ocjT000?o0000olNn0?l000001?o4a0001_l0
003o]<40okC10?l0003oS[L0o`0000?oOK<000?o0000ofZ]0?mZ[@000ol000001ol_V`3o0000oaZD
0?lJU03o0000o`B;0?l000002?ooool00ol0003oooooooooo`02ooooo`00:oooool00ol0003ooooo
ooooo`0Yooooo`Ko00000_n0/`04o`0000?obKT000?o0000om:P0?oBX0006Ol00003oo4l0003o`00
0?od<03om30000Com30000Co0000ooHV0?of9P3omRH01Ol00004ooPM0003o`000?oi6P3onAX000?o
nAX000?o0000ooXI0?oj6@000ol00002ooXG0003o`000?oi6@3onAT000?onAT00ol00006ooPM0003
o`000?og903o000000;o00000_og90000ol0003om2h0oo@^0004oo@^00;o00001_oa>P02o`0000Ko
kDX00_l00006onQL00;o00001_oRL@03o`0000?ofXT00_l00003omV?0003o`000?oBX`3o000000Co
cjT00_l00003olC400;o00000ond`@02o`0000?oOK<000Go0000ofZ]0?mZ[@3o0000oeBW0004o`00
0004oaZD0?l0003o18/0o`0000Wooooo00?o0000ooooooooool00_ooool002cooooo00?o0000oooo
ooooool0:Oooool01Ol0003o08H6o`000?l0003oDZL000;o000000?oP;<0o`000?n`_`001_l00003
om:P0003o`000?oKR03ofhP000;ofhP000Go0000on9b0?oRLP3ohW80o`000006onMN0003o`000?o]
C03okD`000;okD`000?o0000oo4l0?oa?0000ooa?0001?l0003om300oo@`0?od<006o`0000;omb@0
00?o0000ooPM0?oh7@001Ooh7@001?l0003onAX0ooTJ0?oi6P04o`0000KonQL000?o0000ooTI0?l0
00000_l00002ooXI0003o`000?oh7@3on1d000Con1d00_l00006ooLT0003o`000?od;P3om2h000?o
000000?om2l0o`000?oa>P000ooa>P02o`0000;olC`000Co0000one:0?o]BP3okDX00_l00002ona=
0004o`000?oXG03oj5`0onQL00;o00000_oWH0001?l0003ohW40on9a0?oRL@02o`0000?oh7H000?o
0000omZ90?l000001OoIS`02o`0000CocjT000Ko0000olf`0?o=/03o0000olC40?l00004okC10006
o`000?nS_03oXk`0o`000?mm/`3o00000_mZ[@000ol0003oE:L0oeBW0002o`000003ocjP0?l0003o
000000;o00002_ooool00ol0003oooooooooo`02ooooo`00;Oooool00ol0003oooooooooo`0Yoooo
o`Wo00000on`_`000ol0003ob[L0o`000005o`0000CofhP000Go0000on9b0?oRLP3ohW80o`000006
onMN0003o`000?o]C03okD`000;okD`000Co0000oo4l0?oa?03olC`01Ol00003oo@^0003o`000?og
903omb@000?omb@000?o0000ooPM0?oh7@001?oh7@04o`0000?onQP000?o0000ooXG0?oj5`001?oj
5`02o`0000KonQT000?o0000ooPM0?oh7@000ol000000ooh7@3o0000ooLT0005ooLT00?o00001Ood
;`001?l0003olCX0o`000?l00005oo4l0003o`000?o]BP3o000000Gok4d000?o0000onQL0?l00000
1OoWH0000ol0003ohW40o`000005on1f00;o00001OoIS`000ol0003oeYD0o`000003olnY0004o`00
0?o=/03ocK00olf`00?o00000ond`@001?l0003oXk`0oj>l0?nS_003o`000005ofZ]0?l0003oE:L0
oeBW0?l000000_lnX0001?l0003o9IP0obFH0?l0000;ooooo`03o`000?oooooooooo00;ooooo000^
ooooo`;o0000:oooool5o`0000;oPk@01Ol00003olZg0003o`000?oCWP3o000000[o00000ooWGP0;
o`0000;olCX000?o0000oo@^0?od;P001?od;P000ol0003omb@0ooLT0003ooLT0003o`000?oh7@3o
n1d000?o00000_oi70000ol0003onQP0ooXH0003ooXH0003o`000?oj5`3onQL000?o000000?onQL0
o`000?oj6@001Ooj6@03o`0000Gon1d000?o0000ooLT0?og90000ol00002ooHV0003o`000?od;`3o
m2l000?om2l00_l00007oo4l00;o00001_o/C@02o`0000Koif000_l00004on1f00;o000000?ogg/0
o`000?oIS`000_oIS`02o`0000?oeYD000?o0000olnY0?l000000oo=/0001ol0003obKT0olVi0?o9
^@3o0000okC10?l000000onS_0000ol0003oT;P0oi2h0003o`000004oeBW0?l0003o?Z00ocjP00;o
000000?o9IP0o`000?ooool02oooool00ol0003oooooooooo`02ooooo`00<?ooool00ol0003ooooo
ooooo`0Yooooo`?o000000GoDjL0o`000?l0003oPk@0o`000002ok;000Ko00000_oCWP001Ol0003o
fhH0om^60?oKQP3o000000?ohVl01?l00003onQK0003o`000?o]B@3okDT000?okDT000?o0000oo4j
0?oa>P000_oa>P000ol0003om2h0oo@^0004oo@^0004o`000?og903omb@0ooLT00Co00001_oi7000
1?l0003onQP0ooXH0?oj6004o`0000GonQL000?o0000ooXI0?oj6@000ol00002ooTI0003o`000?oh
7@3on1d000?on1d00ol00006ooHV0003o`000?od;`3o000000;o00000_oc<@000ol0003olC`0oo4l
0002oo4l00;o000000?ol3l0o`000?o/C@000oo/C@02o`000003on]@0?l0003oif0000?oif000_l0
0002onIT0004o`000?oPMP3o0000o`0000Cogg/000?o0000omV?0?l000001OoFU@02o`0000?ocK00
00?o0000olVi0?o9^@000_o9^@02o`0000?oXk`000Co0000oi2h0?n@^03o00000_mj/P03o`000005
ocjP0?l0003o9IP0obFH0?l000003Oooool00ol0003oooooooooo`02ooooo`00<Oooool00ol0003o
ooooooooo`0Zooooo`?o000000CoDjL0o`000?l0003o00000onb`0000ol0003obkD0ol^e0005o`00
00?ofhH000?o0000on9_0?oRK`000ooRK`000ol0003oj5/0onQK0002onQK0003o`000?o]B@3okDT0
00?okDT000?o0000oo4j0?oa>P000_oa>P001?l0003om2h0oo@^0?od;P06o`0000?omb<000?o0000
ooTL0?oi70001?oi7004o`0000?onQP000?o0000ooXG0?oj5`000ooj5`03o`0000KonAT000?o0000
ooPM0?l000000_l00002ooPO0003o`000?of9P3omRH000ComRH00_l00006oo<a0004o`000?oa?03o
0000o`0000Col3l000Co0000ona=0?l0003o00001?o[D0001?l0003oif00o`000?l00004onIT00;o
00001_oON`02o`0000CoeYD00_l00002omBM0003o`000?o=/03o000000CobKT000Ko0000olG30?o5
``3o0000oj>l0?l00002oi2h0004o`000?mj/P3oN[80o`0000;oHZ/00ol000001?lUV03o0000oooo
ool0000<ooooo`03o`000?oooooooooo00;ooooo000booooo`03o`000?oooooooooo02_ooooo1?l0
00000on4]03o0000o`000003o`0000?obkD000?o0000omBL0?l000001Ol00005on9_0003o`000?oX
F`3oj5/000;oj5/000Co0000one90?o]B@3okDT02_l00004ooD/0003o`000?og8`3omb<000?omb<0
00?o0000ooTL0?oi70000ol00002ooTL0003o`000?oj603onQP000?onQP000?o0000ooXG0?l00000
0_l00002ooXG0003o`000?oi6@3onAT000ConAT00_l00006ooPO0003o`000?of9P3omRH000?o0000
00?omRL0o`000?oc<@001Ooc<@03o`0000Gol3l00ol00005on]@00?o00000ooVI002o`0000;oi6X0
00Co0000ommk0?oON`3ogg/00_l00002omf20004o`000?oFU@3o0000o`0000Coe9d00_l00003olVi
00;o00000oo5``03o`000005oi2h0?l0003oN[80ogZb0?l000000_mRZ`000ol0003oB:<0odRS0002
o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00<oooool2o`00
02cooooo1_l00002ok?100Ko00000ooDW0000ol0003og8@0o`00000>o`0000?okTL000?o0000oo8h
0?ob>0000_ob>0000ol0003omB`0ooD/0004ooD/0004o`000?og8`3omb<0ooLS00Co00001_oi7000
1?l0003onQP0ooXH0?oj6003o`0000KonQL000?o0000ooTI0?oi6@000ol00002ooTJ0003o`000?oh
7`3on1l000?on1l00ol00005ooHW0003o`000?oc<@3olc4000?o00000ooc<`000ol0003ol3l0o`00
0002o`0000?okd<000?o0000on]@0?l000000_l00003onYE0003o`000?oVI03o000000Goi6X000?o
0000ommk0?l000001?oMPP03o`0000?oe9d00_l00002om6U0003o`000?o9^@3o000000?oaL<00_l0
0002okC100?o000000GoN[80o`000?mRZ`3oHZ/0o`000002odRS0003o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00=Oooool00ol0003ooooooooo
o`0[ooooo`Go00000onc`@000ol0003obk@0ol^d0006o`0000?og8@000?o0000on=^0?oSKP000_oS
KP000ol0003ojET0onUI0002onUI0003o`000?o^A`3okTL000?okTL000?o0000oo8h0?ob>0000_ob
>0001?l0003omB`0ooD/0?oe;006o`0000?omb8000?o0000ooTL0?oi70001?oi7004o`0000?onQP0
00?o0000ooXG0?oj5`000ooj5`03o`0000KonAX000?o0000ooPO0?l000000_l00002ooPQ0003o`00
0?of9`3omRL000?omRL00ol00006oo<c00;o00001_o_@`02o`0000KojUD00_l00006onAZ00;o0000
0ooMPP02o`0000?ofXX000?o0000omBM0?l000001?oAY@03o`000003olG30?l0003o000000?o]<40
00?o0000oifk0?nM^`000ol000000omRZ`3o0000odRS0002o`0000Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`01ooooo`00=_ooool00ol0003oooooooooo`0[ooooo`04o`000?m@
YP3o0000oh>d00Go00000oo;]0000ol0003oe9/0omBK0006o`0000Cohfh000?o0000onUI0?oYF@00
0_oYF@001?l0003okTL0oni70?o^A`0:o`0000ComB`000?o0000ooLR0?og8P000oog8P000ol0003o
nA`0ooTL0003o`000003ooTL0?l0003onQP000GonQP000?o0000ooXG0?l000000_l00002ooXI0003
o`000?oi6P3onAX000ConAX00_l00006ooPQ0003o`000?of9`3o000000;o00000_oe:P000ol0003o
lc<0oo<c0002oo<c00;o000000?olSL0o`000?o_@`000oo_@`02o`000003oni70?l0003ojUD000?o
jUD00_l000000ooXFP3o0000onAZ0003onAZ00;o00000_oRL@000ol0003ogH80o`000005omZ:00;o
00000ooAY@02o`0000;ocK000_l00003okC100;o00000_nM^`000ol0003oQKD0ohFe0002o`000003
odRS0?l0003ooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00
=oooool00ol0003oooooooooo`0[ooooo`Ko000000?o//00o`000?l000001?l00003omBK0003o`00
0?oLQ03og8@000ko00000oo^A`000ol0003olSP0oo8h0002oo8h0003o`000?oe;03omB`000ComB`0
00Co0000ooLR0?og8P3omb801?l00005ooTL0004o`000?oj603onQP0ooXH00Co00001_oj6@000ol0
003onAX0ooTJ0003o`000003ooTL0?l0003on24000Gon2400_l00006ooDZ0004o`000?oc<`3o0000
o`0000ColSL000Co0000onm30?l0003o00001?o^A`001?l0003ojUD0o`000?l00004onQJ0004o`00
0?oTJP3o0000o`0000CohW400_l00004omZ:00;o00000_oGT`000ol0003odJD0o`000003olf`0006
o`000?o8^`3ob;/0o`000?nd`@3o00000onM^`001Ol0003oQKD0ohFe0?l0003oJJd000;o00003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo007ooooo000hooooo`03o`000?oooooo
oooo02_ooooo1ol000001?nb`03o0000ol^e0?o;]@06o`0000Cog8@000Go0000on=]0?oSK@3ohfd0
o`000005onUI0003o`000?o^A`3okTL000;okTL000?o0000oo8h0?ob>0000_ob>0001?l0003omB`0
ooD/0?oe;006o`0000?omb<000?o0000ooTL0?oi70000ooi7004o`0000ConAX000?o0000ooXI0?oj
6@000ooj6@03o`0000GonA`000?o0000ooPQ0?oh8@000ol00002ooLS0003o`000?oe:P3omBX000?o
mBX00ol00005oo8g00?o00001Oo^A`03o`0000Goj5X00ol00003on9a00;o00000_oON@001?l0003o
fXX0o`000?l00004omNC00;o00000oo=/0001?l0003ob;/0olRk0?o8^`04o`000003oifk0?l0003o
QKD000;o000000?oJJd0o`000?ooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo007ooooo000iooooo`;o0000;?ooool9o`0000?obkD000?o0000omBL0?oDW0002ol00003onUI
00oo00001?oe;0000ol0003omb<0ooLS0003ooLS0003o`000?oi703o000000;o00000_oh7@000ol0
003onAX0ooTJ0004ooTJ0003o`000?oj6@3o000000;o00000_oi6`000ol0003onA`0ooTL0003ooTL
00?o00001_og8`000ol0003omBX0o`000002o`0000?om2h000?o0000oo8g0?l000000_l00003oo4l
0003o`000?o^A`3o000000;o00000oo/C@000ol0003oj5X0o`000002o`0000?oif4000?o0000on9a
0?l000001?oON@03o`0000?oei<00_l00002om>M0003o`000?o=/03o000000;ob;/00_l00003oko3
00;o000000GoQKD0o`000?mY[@3oJJd0o`00000@ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00Oooool003_ooooo00?o0000ooooooooool0:oooool5o`0000;o/;l01Ol00003omBL
0003o`000?oLQ03og8@000;og8@000?o0000on=^0?oSKP001?l00003onUI0003o`000?o^A`3okTL0
00;okTL000?o0000oo8h0?ob>0000oob>0000ol0003omB`0ooD/0003ooD/0004o`000?og8`3omb<0
ooLS00Co00001Ooh7@001?l0003onAX0ooTJ0?oi6P05o`0000GonA/000?o0000ooTL0?l000000_l0
0002ooPO0003o`000?og8`3omb<000Comb<00_l00006oo@^00;o00001_oa?002o`0000Kok4d00_l0
0006onMQ00;o00000ooON@02o`0000?ogH8000?o0000omNC0?l000001?oCW@03o`000003olRk0?l0
003o_l<000?o_l<000?o0000ojJm0?l000000_l000000omY[@3o0000ooooo`0Aooooo`03o`000?oo
oooooooo00Kooooo0Ol00001ooooo`7ooooo000looooo`03o`000?oooooooooo02cooooo2?l00000
0oo:]`3o0000o`000004o`0000Cog8@000?o0000on=^0?oSKP000_oSKP000ol0003ojET0onUI0002
onUI0003o`000?o^A`3okTL000;okTL000Co0000oo8h0?ob>03olSP02ol00004ooLT0004o`000?oh
7@3on1d0ooPM00Go00001Ooi70001?l0003onA/0ooTK0?oi6`04o`0000Gon1l000?o0000ooLS0?og
8`000ol00002ooHW0003o`000?od;P3om2h000?o000000?olc80o`000?oa?0000ooa?002o`000003
onm10?l0003ok4d000?ok4d00_l000000ooZD`3o0000onMQ0003onMQ00;o00000_oTJ@000ol0003o
ggT0o`000005omf200;o00000ooCW@02o`0000;ocjT00_l00003oko300;o000000CoY[d0o`000?n:
]P3oR[H00_l0000Cooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo000mooooo`03
o`000?oooooooooo02gooooo2?l000001?o:]`3o0000om>N0?oCWP0Ho`0000?olCX000?o0000oo@^
0?od;P001?od;P001?l0003omb@0ooLT0?og9005o`0000?on1l000?o0000ooTL0?oi70001?oi7004
o`0000Con1h000Co0000ooPO0?oh7`3on1l01?l00005ooHW00?o00001Ooc<P001?l0003olC`0o`00
0?l00004onm10004o`000?o/C@3o0000o`0000CojU<000Co0000onMQ0?l0003o00001?oTJ@02o`00
00CogH800_l00002omV=0003o`000?oCW@3o000000?ocjT000Ko0000olZf0?o:]P3o0000oko30?l0
0002ojJm0004o`000?n:]P3oR[H0o`0001Kooooo00?o0000ooooooooool01Oooool1o`00007ooooo
0Oooool003kooooo0_l0000^ooooo`;o00000_me/@06o`0000Codih000Go0000om^60?oKQP3ofhH0
o`000004on9_0003o`000?oXF`3oj5/000;oj5/000?o0000one90?o]B@000_o]B@000ol0003olCX0
oo4j0003oo4j0004o`000?od;P3om2h0oo@^00Ko00000oof9P000ol0003on1l0ooPO0003ooPO0003
o`000?oi703onA`000?o000000?on1l0o`000?oh7P001Ooh7P04o`0000Comb<000?o0000ooHW0?l0
00000_l00002ooD/0003o`000?oc<P3olc8000?olc800ol00005onm100?o00001OoZD`03o`0000?o
i6T00_l00002on9b0004o`000?oMPP3o0000o`0000CofHd00_l00003olnY0004o`000?o:]P3ob[H0
olZf00?o000000GoY[d0o`000?n:]P3oR[H0o`00000Hooooo`03o`000?oooooooooo00Cooooo0Ol0
0001ooooo`7ooooo0010ooooo`03o`000?oooooooooo02gooooo1_l00002olVi00[o00001?oRK`00
0ol0003oj5/0onQK0002onQK0003o`000?o]B@3okDT000;okDT000Co0000oo4j0?oa>P3olCX01Ol0
0004oo@`0003o`000?of9P3omRH000?omRH000Co0000ooPO0?oh7`3on1l01?l00005ooPO0003o`00
0?oh7P3on1h000?o000000?omb80o`000?og8`001Oog8`02o`0000KomB`000?o0000oo<b0?l00000
0_l00003oo8h0003o`000?o_@@3o000000;o00000oo^B0000ol0003ojU<0o`000002o`0000?oj5`0
00?o0000onAY0?l000001?oRLP02o`0000CofHd00_l00002omFI0003o`000?o?Z@3o000000;ob[H0
0_l00002olC400?o000000?oR[H0o`000?ooool06Oooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool1ooooo`00@Oooool00ol0003oooooooooo`0]ooooo`;o000000?oKJh0o`000?l000001Ol0
0003om:P0003o`000?oKR03ofhP001?o00000ooa?0000ol0003om300oo@`0004oo@`0004o`000?of
9P3omRH0ooHV00Go00001?og8`001?l0003on1l0ooPO0?oh7`04o`0000Gomb8000?o0000ooLS0?og
8`000ol00002ooHX0003o`000?oe;03omB`000?omB`00_l00006oo8h00;o00001_o^B002o`0000Ko
j5`00_l00003on9b00;o00000_oNO@001?l0003ofHd0o`000?l00004omFI00?o000000Cob[H0o`00
0?o4a03oa<@00_l00002ojRn00;o00006oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1
ooooo`00@_ooool00ol0003oooooooooo`0^ooooo`;o000000GoKJh0o`000?l0003o0000olRm0006
o`0000CofhP000Go0000on9b0?oRLP3ohW80o`000004onMN0003o`000?o]C03okD`000?okD`000?o
0000oo4l0?oa?0000_oa?0001?l0003om300oo@`0?od<006o`0000?omBX000?o0000ooLS0?og8`00
0oog8`04o`0000?omb<000?o0000ooLR0?og8P000oog8P03o`0000KomRP000?o0000ooD/0?l00000
0_l00002oo<b0003o`000?ob>03olSP000?o00000_o`?`000ol0003okTP0oni80003o`0000;oje00
00?o0000onQL0?oXG0000ol00002onEU0003o`000?oRLP3o000000CogWd00ol00003omFI00;o0000
0_o@YP03o`000004olC40?l0003oZ;h0ojRn00;o00007_ooool00ol0003oooooooooo`03ooooo`7o
00000Oooool004?ooooo00?o0000ooooooooool0;oooool3o`000003oibk0?l0003o000000?o0000
00?odJ@0o`000?l000002Ol00004onMN0004o`000?o]C03okD`0one<00[o00000ooc<`000ol0003o
mBX0ooDZ0004ooDZ0003o`000?og8`3o000000;o00000_of9`000ol0003omb<0ooLS0003ooLS0003
o`000?og8P3o000000;o00000oof9P001?l0003omRP0ooHX0?of:004o`0000Golc800ol00005oo0o
00?o00001Oo[D003o`0000GoiFD00_l00003omim00;o00000ooJRP000ol0003oeIT0o`000002om2V
00;o00000_o;]@03o`000003ojRn0?l0003ooooo023ooooo00?o0000ooooooooool00_ooool1o`00
007ooooo0014ooooo`;o0000<Oooool5o`000003olK20?l0003o000000Co00000ooIS0000ol0003o
hGH0on5f0009o`0000?ok4l000?o0000oo100?o`@0000oo`@0000ol0003olc<0oo<c0002oo<c0004
o`000?oe:P3omBX0ooDZ00Go00001Oof9`001?l0003omb<0ooLS0?og8`04o`0000GomRH01?l00004
oo@^0003o`000?oc<P3o000000;o00000_oa>@001?l0003ol3l0oo0o0?o`?`02o`0000;okTP000Co
0000on]@0?o[D03oje000_l00003onQJ0003o`000?oUI@3o000000;o00000_oRL0000ol0003ogWd0
o`000005omZ:00?o000000Cod:H0o`000?o;]@3obkD00_l00002ol?400;o00008oooool01Ol0003o
oooooooooooooooo0000007ooooo0016ooooo`03o`000?oooooooooo033ooooo2?l000000oo?Z@3o
0000o`000004o`0000CohGH000?o0000onIQ0?oVH@000_oVH@000ol0003ok4l0ona?0002ona?0004
o`000?o`@03ol400oo1000[o00001Ood;P001?l0003omRL0ooHW0?of9`05o`0000ComRP000?o0000
ooHV0?l000000_l00002oo@]0003o`000?od;P3om2h000?om2h00ol00005oo4i0003o`000?o`?`3o
000000GokTP000?o0000on]@0?l000001OoXFP02o`0000GohW000ol00002omZ:00?o00000_oFV003
o`000004ol^e0?l0003o`l@0ol?400;o00009Oooool01Ol0003ooooooooooooooooo0000007ooooo
0017ooooo`03o`000?oooooooooo037ooooo1?l000000ono``3o0000o`000004o`000003omRA0?l0
003o0000017o00000oo^A@000ol0003olSP0oo8h0003oo8h0004o`000?od;P3om2h0oo@^00Ko0000
1?oe;0001?l0003omRP0ooHX0?of:003o`0000Kom2d000?o0000oo@^0?l000000_l00003oo8e0004
o`000?oa>@3olCT0oo4i00Co00001Oo^B002o`0000Coj5X00_l00002onEU0003o`000?oRL03o0000
00;o00000_oNO@03o`0000?oeYP00_l00002om2W00?o000000?o`l@0o`000?ooool09oooool01?l0
003oooooooooool00001ooooo`00B?ooool00ol0003oooooooooo`0booooo`Oo000000?ocJl0o`00
0?l000001?l00004ommk0003o`000?oUIP3oiFH000;oiFH000?o0000onYD0?oZE0000_oZE0000ol0
003okTD0oni50002oni50004o`000?ob>03olSP0oo8h00Go00001?oc<`001?l0003omB`0ooD/0?oe
;006o`0000?om2h000Co0000oo@]0?od;@3om2d01?l00006oo8e00Co00001?o_@@000ol0003okTP0
o`000002o`0000;oje4000Co0000onQJ0?l0003o00001?oUI@02o`0000?ogWd00_l00003omZ;0003
o`000?oFV03o000000;od:L00_l00002olVh00;o0000:_ooool00ol0003oooooo`000001ooooo`00
BOooool2o`0003Cooooo0ol000000onc`03o0000o`000004o`000003omJH0?l0003o000001Ko0000
1?o`?P001?l0003olc<0oo<c0?oc<`05o`0000?olc<000?o0000oo@^0?od;P000ood;P04o`0000Co
lc@000?o0000oo8e0?ob=@000ol00002oo0n0004o`000?o_@@3okd40onm100Co00001Oo[D@04o`00
0004onEU0?l0003o0000o`0000;ohW8000?o0000omim0?l000001OoJR`03o`000004om2W0?l0003o
bKP0olVh00;o0000;?ooool00ol0003oooooo`000001ooooo`00Boooool00ol0003oooooooooo`0b
ooooo`Oo000000?ob[H0o`000?l000001?l00004omf10003o`000?oSK@3ohfd000;ohfd000?o0000
onQJ0?oXFP000_oXFP000ol0003okD/0one;0002one;0004o`000?o`?P3ol3h0oo0n00Go00000ooa
>P000ol0003olc<0oo<c0003oo<c0003o`000?od;P3o000000;o00000oob=P001?l0003olc@0oo<d
0?oc=004o`0000Gol3h01?l00004one;0003o`000?o[D@3o000000;o00000ooXG@02o`0000GohW80
0ol00002omZ;00?o00000_oDV`03o`000003olVh0?l0003ooooo02kooooo0Ol00001ooooo`7o0000
001<ooooo`03o`000?oooooooooo03?ooooo2_l000000ooCW`3o0000o`00000Fo`0000CokTD000?o
0000oo4j0?oa>P000_oa>P001?l0003olc<0oo<c0?oc<`04o`0000GolSH01?l00004oo0m0003o`00
0?o`?P3o000000;o00000oo^B0001?l0003okD/0one;0?o]B`04o`0000;oj5d00ol00002onAZ0003
o`000?oRLP3o000000;o00000_oMP@04o`000004omBK0?l0003o0000o`0000;ocZ`00_l0000aoooo
o`;o0000001=ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Ol000000oo7_P3o
0000o`000004o`0000CofhP000Go0000on5d0?oQM03ohG@0o`000005onIR0003o`000?o[DP3oje80
00;oje8000Co0000oni50?o^A@3okTD02_l00004oo4k0003o`000?ob=P3o000000;o00000oo`?`00
1?l0003ol3d0oo0m0?o`?@03o`0000KokTP01?l00003onUG00?o00001OoTJP03o`000004omf10?l0
003o0000o`0000?of9400ol000001?o>[03o0000o`000?l0000booooo`?o0000001>ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool01?ooool7o`000003om2W0?l0003o000000Wo0000
0ooVHP0:o`0000Cok4d000?o0000onm20?o_@P000_o_@P001?l0003olC/0oo4k0?oa>`03o`0000Ko
l3l01?l00003oni70003o`000?o^B03okTP000?o00000_oZE0000ol0003ojEL0o`000002o`0000?o
iV@000?o0000onAZ0?l000000_l00002ommi00?o00000_oHT@03o`0000;odZ<00_l0000aooooo`Co
00000oooool004oooooo0_l0000`ooooo`03o`000?oooooooooo00Oooooo2?l00004omRA0003o`00
0?oNO@3ogWd000Co00000ooTJP000ol0003oj5X0onQJ0002onQJ0004o`000?o/C@3ok4d0ona=00_o
00000oo_A0000ol0003ol3l0oo0o0003o`0000;okDX000Co0000oni70?o^A`3okTL01?l00005onYD
00?o00001OoVI003o`000004ommi0?l0003o0000o`0000;ofXT01?l000001?oBX`3o0000o`000?l0
000`ooooo`?o00001oooool0057ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09
oooooago00001?oYE`000ol0003okD`0one<0002one<0004o`000?o_A03okd@0onm400Go00000oo]
BP05o`0000CojU<000?o0000onYD0?l000000_l00003onIQ0003o`000?oVI03o000000;o00000_oQ
L`03o`000004omZ90?l0003o0000o`0000?oe9`00_l0000_ooooo`Co00002_ooool005;ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0=ooooo`?o000000?ob;`0o`000?l000001?l0
0004om^70003o`000?oQM03ohG@000;ohG@000?o0000onIT0?oVI0000_oVI0001?l0003ojEL0onUG
0?oYE`0:o`0000?ok4l01Ol00004onYF0004o`000?oZD`3ojU<0onYC00Co00000ooVH@05o`000004
on5c0?l0003o0000o`0000;og8@01?l000001?oDW03o0000o`000?l0000]ooooo`Co00003_ooool0
05?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0@ooooo`Go000000?od:H0o`00
0?l000004Ol00004onIR0004o`000?oYE`3ojEL0onUG00Go00001?oXF`001?l0003ojUH0onYF0?oZ
EP05o`0000;oiV401Ol00003on9a00Co000000Cog8@0o`000?l0003o00000ooFU`02o`0002cooooo
1?l0000Booooo`00E?ooool2o`0002_ooooo00?o0000ooooooooool04oooool<o`0000CogH0000?o
0000on9`0?oRL0000_oRL0001?l0003oiV80onIR0?oVHP05o`0000?oiV@000Co0000onQK0?oXF`3o
j5/01_l00003onIT00Co00001?oRL@04o`0000?ogH800ol00002omJG00?o0000:_ooool4o`0001Ko
oooo001Fooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05_ooool6o`0000;odil0
3_l00003on=_0004o`000?oVI03oiV@0onIT00Go00001?oTJP000ol0003oiV@0o`000002o`0000?o
hG@000?o0000on9a0?l000000_l00002omf20003o`000?oMPP3o000000;o000000?oeiD0o`000?l0
00000_l0000Zooooo`?o00006_ooool005Oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Ioooooa[o00000ooRLP0:o`0000?ohG@01?l00003omf200Oo0000:_ooool4o`0001gooooo
001Hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07OoooolIo`0000?ogH8000Co
0000ommj0?oONP3oggX01_l00002omb500So0000:_ooool4o`00027ooooo001Iooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool08ooooolWo`0002Wooooo1?l0000Uooooo`00F_ooool2
o`0002Gooooo00?o0000ooooooooool0:?oooolCo`0000;od:L01Ol0000]ooooo`Co0000:Oooool0
05cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0dooooo`Wo0000;oooool3o`00
02gooooo001Mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0J?ooool4o`00033o
oooo001Nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0I?ooool4o`0003Cooooo
001Oooooo`;o00008?ooool00ol0003oooooooooo`1Pooooo`Co0000>?ooool0067ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`1Mooooo`?o0000??ooool006;ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1Iooooo`Co0000?oooool006?ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Eooooo`Co0000@oooool006Cooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Aooooo`Co0000Aoooool006Gooooo0_l0000Jooooo`03o`000?oo
oooooooo04gooooo1?l0001;ooooo`00Ioooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo04[ooooo0ol0001?ooooo`00J?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Kooooo1?l0001Booooo`00JOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04;o
oooo1?l0001Fooooo`00J_ooool2o`0001Gooooo00?o0000ooooooooool0?_ooool4o`0005[ooooo
001/ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>_ooool4o`0005kooooo001]
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool3o`0006;ooooo001^oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool4o`0006Gooooo001_ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;oooool4o`0006Wooooo001`ooooo`;o0000
3_ooool00ol0003oooooooooo`0/ooooo`Co0000KOooool007;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Yooooo`?o0000LOooool007?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Uooooo`Co0000M?ooool007Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Qooooo`Co0000N?ooool007Gooooo0_l00009ooooo`03o`000?oooooooooo01go
oooo1?l0001looooo`00Moooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo
1?l00020ooooo`00N?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0
0024ooooo`00NOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l00027
ooooo`00N_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002;oooo
o`00Noooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`0008oooooo001mooooo`04o`00
0?ooooooooooo`0000Sooooo1?l0002Cooooo`00O_ooool00ol0003oooooo`000005ooooo`?o0000
Uoooool007oooooo0_l000000ooooooo0000o`000002o`0009[ooooo0020ooooo`;o0000W_ooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool003;ooooo0ol0002:ooooo`03o`000?oo
oooooooo02_ooooo0ol0000Eooooo`03o`000?oooooooooo01Sooooo000cooooo`03o`000?oooooo
oooo08Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01Oooooo000]ooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`00
00?ooooo1?l000000ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co00000oooool2o`00
00;ooooo1_l00006ooooo`Co00000_ooool5o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000ol00002ooooo`?o00000_ooool3o`0000Cooooo0ol00002ooooo`?o000000Coooooo`00
0?l0003ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00000_ooool3
o`0000;ooooo0ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00002ooooo`[o00001Ooo
ool00ol0003oooooooooo`0Fooooo`00;?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`00
;?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`03
o`000?oooooooooo00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5
o`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol0
0003ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`04o`000?ooooooooooooooo`Go0000
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00002ooooo`?o00001Oooool00ol0003oooooooooo`0Fooooo`00;?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool3o`0000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`07o`000?oooooo
0000ooooool0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Go
oooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo01Kooooo000/oooo
o`06o`000?ooooooooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol0
0003ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo
0_l00003ooooo`Co00000oooool3o`0000Wooooo00Go0000oooooooooooo0000ooooo`03o`0000Co
oooo1?l00002ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o
00000_ooool4o`0000?ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`Ko
000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`03
o`000?oooooooooo00;ooooo0ol00002ooooo`Co00000oooool9o`0000?ooooo0ol00003ooooo`Co
00001?ooool00ol0003oooooooooo`0Fooooo`00;?ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool05oooool002gooooo0ol00009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03Oooool3o`0000Wooooo1?l00009ooooo`03o`000?oooooooooo
00;ooooo0_l0000:ooooo`Co00001?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool2o`00
02kooooo00?o0000ooooooooool06?ooool3o`0001Kooooo00?o0000ooooooooool00_ooool2o`00
00_ooooo00?o0000ooooooooool06?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0889714, 0.0513614, \
0.00362915, 0.00362915}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-1.2464337861714014`\)\), 
        ",", \(BackFocalLength \[Rule] 39.485013802263495`\), 
        ",", \(BackFocalPoint \[Rule] {57.847139891996214`, \
\(-14.815427008975622`\), 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-57.42551421082294`\), \
\(-57.42551421082294`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-14.85946576992335`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {14.537193111455208`, \
\(-3.077944022847568`\), 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] \
{{\(-0.9783119619871903`\), 0.2071369233931379`, 
              0}, {\(-0.2071369233931379`\), \(-0.9783119619871903`\), 
              0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] 0\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {19.817012764638733`, \
\(-4.195834472443554`\), 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{0.9631534464647291`, \
\(-0.2689524838389013`\), 0}, {0.26895248383890136`, 0.963153446464729`, 
              0}, {0, 0, 1}}\), ",", \(FieldStopPosition \[Rule] 2\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 2, 
            SurfaceNumber \[Rule] 2, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] False\), 
        ",", \(FindPupils \[Rule] True\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 45.79737407145489`\), 
        ",", \(FrontFocalLength \[Rule] 38.259408199433885`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-36.31607577162287`\), 
            12.038478156339174`, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {0.9631534464647278`, \
\(-0.26895248383890547`\), 0}\), 
        ",", \(ImagePoint \[Rule] {108.`, \(-28.820190577214504`\), 0.`}\), 
        ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(BiConvexLens[50, 50, 20]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-54\), \(-54\)}, {108, 54, 
                        54}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.8621676373989785`, 
              10.290804067447606`}, {\(-0.021835313056153834`\), 
              0.8992416763944976`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              
              TagBox[\(Move[
                  PointOfRays[{10, 10}], {\(-90.5`\), 
                    30.`}, \(-18.33993103355537`\)]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 126.14733252713481`\), 
        ",", \(OpticalLengthFunction \[Rule] OpticalLengthFunction\), 
        ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(CompiledFunction[
              If[#1 == 0 && #2 == 
                    0, \(-0.22239884599059243`\), \(-138.2326745506011`\) + 
                  6.526140774343678`\ Cos[
                      ArcTan[#1, #2]]\ \@\(#1\^2 + #2\^2\) - 
                  0.8245724421603335`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) - 
                  0.0006224814484630803`\ Cos[
                      3\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(3/2\) - 
                  2.634305291569473`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                  6.374863095176883`*^-8\ Cos[
                      5\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(5/2\) + 
                  4.4462969629460914`*^-10\ Cos[
                      6\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^3 - 
                  160.6637579475793`\ \((\(-1\) + 
                        0.014350078540430368`\ \((#1\^2 + #2\^2)\))\) + 
                  26.724692435974987`\ Cos[
                      ArcTan[#1, #2]]\ \((\(-0.16941120706984156`\)\ \
\@\(#1\^2 + #2\^2\) + 
                        0.001823298095311004`\ \((#1\^2 + \
#2\^2)\)\^\(3/2\))\) - 
                  3.432715510157807`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.02152511781064555`\)\ \((#1\
\^2 + #2\^2)\) + 0.00020592475411652014`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  23.601410847698492`\ \((1 - 
                        0.0430502356212911`\ \((#1\^2 + #2\^2)\) + 
                        0.0003088871311747802`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  0.2316193120729457`\ Cos[
                      3\ ArcTan[#1, #2]]\ \((\(-0.0024310641270813386`\)\ \
\((#1\^2 + #2\^2)\)\^\(3/2\) + 
                        0.000021803725725274998`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) - 
                  0.7114211201683713`\ Cos[
                      ArcTan[#1, #2]]\ \((0.2541168106047623`\ \@\(#1\^2 + #2\
\^2\) - 0.007293192381244016`\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                        0.000043607451450549996`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) - 
                  0.003617687253202599`\ Cos[
                      4\ ArcTan[#1, #2]]\ \((\(-0.00025740594264565017`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 2.216277296243157`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  0.1844986134853204`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((0.0430502356212911`\ \((#1\^2 + \
#2\^2)\) - 0.0010296237705826007`\ \((#1\^2 + #2\^2)\)\^2 + 
                        5.540693240607892`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  1.0016236726951588`\ \((\(-1\) + 
                        0.0861004712425822`\ \((#1\^2 + #2\^2)\) - 
                        0.001544435655873901`\ \((#1\^2 + #2\^2)\)\^2 + 
                        7.387590987477189`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) + 
                  0.002050031619723582`\ Cos[
                      5\ ArcTan[#1, #2]]\ \((\(-0.00002616447087033`\)\ \((#1\
\^2 + #2\^2)\)\^\(5/2\) + 
                        2.1901962364218882`*^-7\ \((#1\^2 + \
#2\^2)\)\^\(7/2\))\) - 
                  0.014960935992357349`\ Cos[
                      3\ ArcTan[#1, #2]]\ \((0.006077660317703347`\ \((#1\^2 \
+ #2\^2)\)\^\(3/2\) - 0.00013082235435165`\ \((#1\^2 + #2\^2)\)\^\(5/2\) + 
                        6.570588709265665`*^-7\ \((#1\^2 + #2\^2)\)\^\(7/2\))\
\) - 0.11368650526823329`\ Cos[
                      ArcTan[#1, #2]]\ \((\(-0.3388224141396831`\)\ \@\(#1\^2 \
+ #2\^2\) + 0.018232980953110038`\ \((#1\^2 + #2\^2)\)\^\(3/2\) - 
                        0.0002616447087033`\ \((#1\^2 + #2\^2)\)\^\(5/2\) + 
                        1.095098118210944`*^-6\ \((#1\^2 + #2\^2)\)\^\(7/2\))\
\) + 0.0007733398527797466`\ Cos[
                      6\ ArcTan[#1, #2]]\ \((\(-2.585656845617016`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 2.120250217897464`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  0.0027072702745064505`\ Cos[
                      4\ ArcTan[#1, #2]]\ \((0.0007722178279369505`\ \((#1\^2 \
+ #2\^2)\)\^2 - 0.000015513941073702098`\ \((#1\^2 + #2\^2)\)\^3 + 
                        7.420875762641123`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.013500744339898577`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.07175039270215183`\)\ \((#1\
\^2 + #2\^2)\) + 0.003088871311747802`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00003878485268425525`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.4841751525282246`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.05369506796546849`\ \((1 - 
                        0.14350078540430367`\ \((#1\^2 + #2\^2)\) + 
                        0.0046333069676217035`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00005171313691234033`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.855218940660281`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
              "-CompiledCode-"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {125.93717482355947`, 
            126.14733252713481`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      SurfaceGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      SurfaceGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), 
        ",", \(Plot2D \[Rule] False\), ",", \(PlotPoints \[Rule] 32\), 
        ",", \(PrinciplePoints \[Rule] {{7.155085576474569`, \
\(-2.37185157231203`\), 0}, {13.737241216040012`, \(-2.4981094991585326`\), 
              0}}\), ",", \(PrinciplePointSeparation \[Rule] 
          6.583366458549512`\), 
        ",", \(RayBoundary \[Rule] {{\(-8.288874640788183`\), 
              8.288874640788183`}, {\(-8.406343835324218`\), 
              8.406343835324218`}}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), 
        ",", \(ResidualFitError \[Rule] 0.0015507727683519638`\), 
        ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
              533.2421404370176`, Astigmatism \[Rule] 221.48787424562232`, 
            FieldCurvature \[Rule] 152.34904843567907`, 
            Distortion \[Rule] 22.301430120259024`, 
            Coma \[Rule] 83.39343467033268`}\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 1351\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.1369978533943406`\), \
\(-19.106322781000188`\)}, {\(-0.021835313056153834`\), \
\(-1.2464337861714014`\)}}\), 
        ",", \(TransverseMagnification \[Rule] \(-1.1369978533943406`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-11.186152654965799`\), 
                  11.186152654965795`}, {\(-11.303621849501834`\), 
                  11.303621849501834`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[18]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
pupfun = PupilFunction[sys3D, FindImagePoint->True, FocalFraction->0]\
\>", "Input",
  CellLabel->"In[19]:=",
  CellTags->{"AOG5.3", "AOG5.", "AOG0."}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0563124 -1.06546 5.06368 [
[.07766 -0.0125 -12 -9 ]
[.07766 -0.0125 12 0 ]
[.21844 -0.0125 -6 -9 ]
[.21844 -0.0125 6 0 ]
[.35922 -0.0125 -12 -9 ]
[.35922 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64078 -0.0125 -9 -9 ]
[.64078 -0.0125 9 0 ]
[.78156 -0.0125 -3 -9 ]
[.78156 -0.0125 3 0 ]
[.92234 -0.0125 -9 -9 ]
[.92234 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04855 -24 -4.5 ]
[-0.0125 .04855 0 4.5 ]
[-0.0125 .14983 -24 -4.5 ]
[-0.0125 .14983 0 4.5 ]
[-0.0125 .2511 -24 -4.5 ]
[-0.0125 .2511 0 4.5 ]
[-0.0125 .35237 -24 -4.5 ]
[-0.0125 .35237 0 4.5 ]
[-0.0125 .45365 -18 -4.5 ]
[-0.0125 .45365 0 4.5 ]
[-0.0125 .55492 -24 -4.5 ]
[-0.0125 .55492 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -60 0 ]
[.5 .63053 60 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07766 0 m
.07766 .00625 L
s
[(-7.5)] .07766 -0.0125 0 1 Mshowa
.21844 0 m
.21844 .00625 L
s
[(-5)] .21844 -0.0125 0 1 Mshowa
.35922 0 m
.35922 .00625 L
s
[(-2.5)] .35922 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64078 0 m
.64078 .00625 L
s
[(2.5)] .64078 -0.0125 0 1 Mshowa
.78156 0 m
.78156 .00625 L
s
[(5)] .78156 -0.0125 0 1 Mshowa
.92234 0 m
.92234 .00625 L
s
[(7.5)] .92234 -0.0125 0 1 Mshowa
.125 Mabswid
.10581 0 m
.10581 .00375 L
s
.13397 0 m
.13397 .00375 L
s
.16213 0 m
.16213 .00375 L
s
.19028 0 m
.19028 .00375 L
s
.24659 0 m
.24659 .00375 L
s
.27475 0 m
.27475 .00375 L
s
.30291 0 m
.30291 .00375 L
s
.33106 0 m
.33106 .00375 L
s
.38738 0 m
.38738 .00375 L
s
.41553 0 m
.41553 .00375 L
s
.44369 0 m
.44369 .00375 L
s
.47184 0 m
.47184 .00375 L
s
.52816 0 m
.52816 .00375 L
s
.55631 0 m
.55631 .00375 L
s
.58447 0 m
.58447 .00375 L
s
.61262 0 m
.61262 .00375 L
s
.66894 0 m
.66894 .00375 L
s
.69709 0 m
.69709 .00375 L
s
.72525 0 m
.72525 .00375 L
s
.75341 0 m
.75341 .00375 L
s
.80972 0 m
.80972 .00375 L
s
.83787 0 m
.83787 .00375 L
s
.86603 0 m
.86603 .00375 L
s
.89419 0 m
.89419 .00375 L
s
.0495 0 m
.0495 .00375 L
s
.02134 0 m
.02134 .00375 L
s
.9505 0 m
.9505 .00375 L
s
.97866 0 m
.97866 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04855 m
.00625 .04855 L
s
[(0.22)] -0.0125 .04855 1 0 Mshowa
0 .14983 m
.00625 .14983 L
s
[(0.24)] -0.0125 .14983 1 0 Mshowa
0 .2511 m
.00625 .2511 L
s
[(0.26)] -0.0125 .2511 1 0 Mshowa
0 .35237 m
.00625 .35237 L
s
[(0.28)] -0.0125 .35237 1 0 Mshowa
0 .45365 m
.00625 .45365 L
s
[(0.3)] -0.0125 .45365 1 0 Mshowa
0 .55492 m
.00625 .55492 L
s
[(0.32)] -0.0125 .55492 1 0 Mshowa
.125 Mabswid
0 .07387 m
.00375 .07387 L
s
0 .09919 m
.00375 .09919 L
s
0 .12451 m
.00375 .12451 L
s
0 .17515 m
.00375 .17515 L
s
0 .20046 m
.00375 .20046 L
s
0 .22578 m
.00375 .22578 L
s
0 .27642 m
.00375 .27642 L
s
0 .30174 m
.00375 .30174 L
s
0 .32706 m
.00375 .32706 L
s
0 .37769 m
.00375 .37769 L
s
0 .40301 m
.00375 .40301 L
s
0 .42833 m
.00375 .42833 L
s
0 .47897 m
.00375 .47897 L
s
0 .50429 m
.00375 .50429 L
s
0 .5296 m
.00375 .5296 L
s
0 .02324 m
.00375 .02324 L
s
0 .58024 m
.00375 .58024 L
s
0 .60556 m
.00375 .60556 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07766 .61178 m
.07766 .61803 L
s
.21844 .61178 m
.21844 .61803 L
s
.35922 .61178 m
.35922 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64078 .61178 m
.64078 .61803 L
s
.78156 .61178 m
.78156 .61803 L
s
.92234 .61178 m
.92234 .61803 L
s
.125 Mabswid
.10581 .61428 m
.10581 .61803 L
s
.13397 .61428 m
.13397 .61803 L
s
.16213 .61428 m
.16213 .61803 L
s
.19028 .61428 m
.19028 .61803 L
s
.24659 .61428 m
.24659 .61803 L
s
.27475 .61428 m
.27475 .61803 L
s
.30291 .61428 m
.30291 .61803 L
s
.33106 .61428 m
.33106 .61803 L
s
.38738 .61428 m
.38738 .61803 L
s
.41553 .61428 m
.41553 .61803 L
s
.44369 .61428 m
.44369 .61803 L
s
.47184 .61428 m
.47184 .61803 L
s
.52816 .61428 m
.52816 .61803 L
s
.55631 .61428 m
.55631 .61803 L
s
.58447 .61428 m
.58447 .61803 L
s
.61262 .61428 m
.61262 .61803 L
s
.66894 .61428 m
.66894 .61803 L
s
.69709 .61428 m
.69709 .61803 L
s
.72525 .61428 m
.72525 .61803 L
s
.75341 .61428 m
.75341 .61803 L
s
.80972 .61428 m
.80972 .61803 L
s
.83787 .61428 m
.83787 .61803 L
s
.86603 .61428 m
.86603 .61803 L
s
.89419 .61428 m
.89419 .61803 L
s
.0495 .61428 m
.0495 .61803 L
s
.02134 .61428 m
.02134 .61803 L
s
.9505 .61428 m
.9505 .61803 L
s
.97866 .61428 m
.97866 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04855 m
1 .04855 L
s
.99375 .14983 m
1 .14983 L
s
.99375 .2511 m
1 .2511 L
s
.99375 .35237 m
1 .35237 L
s
.99375 .45365 m
1 .45365 L
s
.99375 .55492 m
1 .55492 L
s
.125 Mabswid
.99625 .07387 m
1 .07387 L
s
.99625 .09919 m
1 .09919 L
s
.99625 .12451 m
1 .12451 L
s
.99625 .17515 m
1 .17515 L
s
.99625 .20046 m
1 .20046 L
s
.99625 .22578 m
1 .22578 L
s
.99625 .27642 m
1 .27642 L
s
.99625 .30174 m
1 .30174 L
s
.99625 .32706 m
1 .32706 L
s
.99625 .37769 m
1 .37769 L
s
.99625 .40301 m
1 .40301 L
s
.99625 .42833 m
1 .42833 L
s
.99625 .47897 m
1 .47897 L
s
.99625 .50429 m
1 .50429 L
s
.99625 .5296 m
1 .5296 L
s
.99625 .02324 m
1 .02324 L
s
.99625 .58024 m
1 .58024 L
s
.99625 .60556 m
1 .60556 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Wave Front Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.03837 .23004 L
.05372 .39959 L
.05761 .43704 L
.06178 .46531 L
.06929 .5079 L
.07149 .52039 L
.07265 .52696 L
.07328 .53056 L
.07388 .53394 L
.0744 .53576 L
.07495 .53734 L
.07613 .54069 L
.07822 .5466 L
.08243 .55856 L
.08634 .56965 L
.08829 .57518 L
.08925 .57785 L
.09013 .57889 L
.09114 .58009 L
.09224 .5814 L
.09416 .58367 L
.09824 .58849 L
.10039 .59104 L
.1027 .59378 L
.10375 .59502 L
.10475 .59595 L
.10564 .59631 L
.10661 .5967 L
.11027 .59818 L
.11439 .59984 L
.11641 .60065 L
.11826 .6014 L
.11914 .60175 L
.11996 .60198 L
.12082 .60206 L
.12176 .60214 L
.12553 .60247 L
.12974 .60284 L
.13173 .60302 L
.13357 .60318 L
.13451 .60326 L
.13551 .60329 L
.13651 .60328 L
.13761 .60327 L
.14143 .60323 L
.14574 .60319 L
.14786 .60317 L
.14889 .60316 L
.14983 .60315 L
Mistroke
.15077 .60312 L
.15165 .60309 L
.15359 .60301 L
.1577 .60284 L
.16489 .60255 L
.18106 .60189 L
.21095 .60067 L
.24273 .5995 L
.27334 .59851 L
.30278 .59768 L
.33412 .59693 L
.36428 .59633 L
.39634 .59582 L
.40413 .59568 L
.40619 .59565 L
.40726 .59563 L
.40785 .59562 L
.4084 .59561 L
.4094 .5956 L
.41049 .59559 L
.4124 .59558 L
.41945 .59553 L
.42723 .59545 L
.45695 .59522 L
.46087 .59518 L
.46511 .59514 L
.46706 .59512 L
.46813 .59511 L
.46912 .5951 L
.46997 .5951 L
.47088 .5951 L
.47282 .5951 L
.47668 .5951 L
.48034 .5951 L
.48194 .59511 L
.48363 .59511 L
.48452 .59511 L
.48549 .5951 L
.48638 .5951 L
.48722 .59509 L
.49481 .59505 L
.49666 .59504 L
.49864 .59503 L
.49922 .59503 L
.49977 .59502 L
.50027 .59502 L
.5008 .59503 L
.50282 .59504 L
.51714 .59509 L
.5244 .59507 L
Mistroke
.52649 .59507 L
.52848 .59507 L
.52934 .59507 L
.53026 .59506 L
.53127 .59507 L
.53221 .59508 L
.5367 .59512 L
.54078 .59515 L
.54276 .59517 L
.5438 .59518 L
.54491 .59519 L
.54587 .59519 L
.54642 .59519 L
.54693 .5952 L
.5488 .5952 L
.55275 .59521 L
.55649 .59521 L
.55812 .59522 L
.55986 .59522 L
.56076 .59522 L
.56175 .59523 L
.56351 .59526 L
.57928 .59543 L
.61042 .59579 L
.64038 .59627 L
.67225 .59689 L
.70294 .59762 L
.73246 .59844 L
.76388 .59944 L
.79412 .60054 L
.82626 .60185 L
.84238 .60254 L
.84946 .60283 L
.85723 .60308 L
.86084 .60319 L
.86283 .60325 L
.86381 .60329 L
.86472 .60331 L
.86556 .60332 L
.86646 .6033 L
.86837 .60326 L
.87171 .60319 L
.87586 .6031 L
.87789 .60305 L
.87878 .60303 L
.87975 .60301 L
.88063 .60295 L
.88146 .60279 L
.88325 .60244 L
.88703 .60171 L
Mistroke
.89092 .60095 L
.89297 .60056 L
.8941 .60034 L
.89465 .60023 L
.89515 .60013 L
.89607 .59971 L
.89705 .59904 L
.89914 .59761 L
.90283 .59509 L
.90635 .59268 L
.90821 .59141 L
.90924 .59071 L
.9102 .59006 L
.91111 .58905 L
.91211 .58726 L
.91383 .58412 L
.91721 .57801 L
.92076 .57157 L
.92456 .56467 L
.9251 .5637 L
.92568 .56264 L
.92624 .56111 L
.92675 .55908 L
.92874 .55113 L
.93264 .53558 L
.93668 .51944 L
.93881 .51097 L
.93997 .50634 L
.94053 .50409 L
.94105 .50204 L
.942 .49558 L
.94301 .48807 L
.94517 .47218 L
.94894 .44428 L
.96189 .32557 L
.97619 .14203 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Joooo
o`?o00006Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo0_l0000Ioooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006_ooool3o`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00005?ooool0033ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00000I
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`00
0?ooooooooooo`0001Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Sooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Cooooo`00:?ooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003oooooooooo`0@ooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo000aooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04Oooool003;ooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo1?l0000Iooooo`05o`000?ooooooooooooooool000001oooool4o`0001Kooooo
00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Ioooo
o`Co00007Oooool00ol0003oooooooooo`05ooooo`Co00005?ooool002kooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
000Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Go
oooo000^ooooo`Go00001oooool5o`0001Sooooo1Ol0000Iooooo`?o00002?ooool5o`0001Kooooo
0_l0000Jooooo`?o00002?ooool5o`0001Sooooo1Ol0000Hooooo`Go00001oooool5o`0001?ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000QooooooSo0000
1oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001?ooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo07Sooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol000000ooooooo0000o`000003o`00
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Ooo
ool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool0N?ooool2o`0000Oooooo0007ooooo`04o`000?oooooo
ooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00007ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool01Oooool000Sooooo0_l00009ooooo`?o00000oooool3o`0000Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
1Oooool0027ooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0N?oo
ool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001Oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo07Sooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool2o`00
00Gooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1hooooo`;o00001oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool01Oooool000Sooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00000ooo
ool3o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00009ooooo`04o`00
0?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo0007ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000000oooool2o`0000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool0027ooooo0_l00006ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00001oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001ooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool00ooo
ool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`008Oooool2o`0000Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`002?oo
ool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00009oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`04o`0000Gooooo0_l00007ooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`04ooooo`;o00001oooool000Oooooo00Co0000oooo
oooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Wooooo0ol00004ooooo`;o0000
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`008Oooool2o`0000Sooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`008Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo0_l00009ooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05ooooo`;o
00001oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo000Qooooo`;o00002Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool01Oooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0008ooooo`;o
00001?ooool01?l0003oooooooooooooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool0000:ooooo`04o`00
0?ooooooooooooooo`?o00001Oooool2o`0000[ooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`001oooool01?l0003ooooo
ooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`001oooool01?l0
003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`002?oo
ool2o`0000Wooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`008Oooool2o`0000[o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oo
oooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool0027ooooo0_l0000;ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`08ooooo`;o00001oooool0027ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo06_ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01Oooool0027ooooo0_l0000<ooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool0K?ooool00ol0003oooooooooo`09ooooo`;o00001oooool0027ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Gooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool000gooooo
00Co0000oooooooooooo00002Oooool2o`0000Gooooo0_l0000=ooooo`03o`000?oooooooooo06Wo
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`09ooooo`;o00001oooool000gooooo
00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05oooo
o`003_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0K?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00003_ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool02Oooool2
o`0000Oooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05
ooooo`008Oooool2o`0000oooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo00_ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1Oooool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`008Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`05ooooo`008Oooool2o`00013ooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo00gooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00002oooo
o`Go00001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`001oooool0
1?l0003oooooooooool0000;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo
0_l00005ooooo`03o`000?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0>ooooo`;o00001oooool000Oooooo00Co
0000oooooooooooo00002oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003ooooooooo
ool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
06Kooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo0008ooooo`;o00002Oooool3o`0000?o
oooo0ol00005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00005?ooool2o`0006?ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`0@ooooo`;o00001oooool0027ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`1Rooooo`;o00005Oooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02[oooooK?l0000[ooooo`;o00005ooo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Hooooo`Co00003?oooolL
o`0003Cooooo00?o0000ooooooooool0=OoooolLo`0000cooooo1?l0000Hooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`;o00007Oooool<o`00053ooooo00?o0000ooooooooool0DOooool<o`00
01_ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0027ooooon?l0
0007ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00d_ooool3o`0004_ooooo
003Cooooo`03o`000?oooooooooo04[ooooo001Qooooo`03o`000?oooooo000000?ooooo1?l00003
ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`?o00000oooool3o`0000Cooooo0ol00002
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Sooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l0
0002ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool0BOooool0067ooooo00?o0000
ooooool000000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool00000
3?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00006ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0BOooool0067ooooo00?o0000
ooooool000000oooool3o`0000?ooooo00?o0000ooooool000000_ooool5o`0000Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`00001:ooooo`00H?ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooo
oooooooooooo000000Sooooo0ol00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000004[ooooo001Pooooo`05
o`000?oooooo0000ooooool000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`?o00002Oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00;ooooo1?l00002ooooo`Co00002_ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00003
ooooo`?o00000_ooool4o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co00000_oo
ool2o`000003ooooool0003o000004Wooooo001Pooooo`05o`000?oooooo0000ooooool000006_oo
ool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo053ooooo001Pooooo`Ko00006?oo
ool5o`0001Cooooo00?o0000ooooooooool02?ooool5o`0000Sooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo053ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.2786, 0.200752, \
0.0718464, 0.000798993}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0563124 0.603316 0.114984 [
[.07766 -0.0125 -12 -9 ]
[.07766 -0.0125 12 0 ]
[.21844 -0.0125 -6 -9 ]
[.21844 -0.0125 6 0 ]
[.35922 -0.0125 -12 -9 ]
[.35922 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64078 -0.0125 -9 -9 ]
[.64078 -0.0125 9 0 ]
[.78156 -0.0125 -3 -9 ]
[.78156 -0.0125 3 0 ]
[.92234 -0.0125 -9 -9 ]
[.92234 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0284 -12 -4.5 ]
[-0.0125 .0284 0 4.5 ]
[-0.0125 .14338 -12 -4.5 ]
[-0.0125 .14338 0 4.5 ]
[-0.0125 .25836 -12 -4.5 ]
[-0.0125 .25836 0 4.5 ]
[-0.0125 .37335 -12 -4.5 ]
[-0.0125 .37335 0 4.5 ]
[-0.0125 .48833 -12 -4.5 ]
[-0.0125 .48833 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07766 0 m
.07766 .00625 L
s
[(-7.5)] .07766 -0.0125 0 1 Mshowa
.21844 0 m
.21844 .00625 L
s
[(-5)] .21844 -0.0125 0 1 Mshowa
.35922 0 m
.35922 .00625 L
s
[(-2.5)] .35922 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64078 0 m
.64078 .00625 L
s
[(2.5)] .64078 -0.0125 0 1 Mshowa
.78156 0 m
.78156 .00625 L
s
[(5)] .78156 -0.0125 0 1 Mshowa
.92234 0 m
.92234 .00625 L
s
[(7.5)] .92234 -0.0125 0 1 Mshowa
.125 Mabswid
.10581 0 m
.10581 .00375 L
s
.13397 0 m
.13397 .00375 L
s
.16213 0 m
.16213 .00375 L
s
.19028 0 m
.19028 .00375 L
s
.24659 0 m
.24659 .00375 L
s
.27475 0 m
.27475 .00375 L
s
.30291 0 m
.30291 .00375 L
s
.33106 0 m
.33106 .00375 L
s
.38738 0 m
.38738 .00375 L
s
.41553 0 m
.41553 .00375 L
s
.44369 0 m
.44369 .00375 L
s
.47184 0 m
.47184 .00375 L
s
.52816 0 m
.52816 .00375 L
s
.55631 0 m
.55631 .00375 L
s
.58447 0 m
.58447 .00375 L
s
.61262 0 m
.61262 .00375 L
s
.66894 0 m
.66894 .00375 L
s
.69709 0 m
.69709 .00375 L
s
.72525 0 m
.72525 .00375 L
s
.75341 0 m
.75341 .00375 L
s
.80972 0 m
.80972 .00375 L
s
.83787 0 m
.83787 .00375 L
s
.86603 0 m
.86603 .00375 L
s
.89419 0 m
.89419 .00375 L
s
.0495 0 m
.0495 .00375 L
s
.02134 0 m
.02134 .00375 L
s
.9505 0 m
.9505 .00375 L
s
.97866 0 m
.97866 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0284 m
.00625 .0284 L
s
[(-5)] -0.0125 .0284 1 0 Mshowa
0 .14338 m
.00625 .14338 L
s
[(-4)] -0.0125 .14338 1 0 Mshowa
0 .25836 m
.00625 .25836 L
s
[(-3)] -0.0125 .25836 1 0 Mshowa
0 .37335 m
.00625 .37335 L
s
[(-2)] -0.0125 .37335 1 0 Mshowa
0 .48833 m
.00625 .48833 L
s
[(-1)] -0.0125 .48833 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .05139 m
.00375 .05139 L
s
0 .07439 m
.00375 .07439 L
s
0 .09739 m
.00375 .09739 L
s
0 .12038 m
.00375 .12038 L
s
0 .16638 m
.00375 .16638 L
s
0 .18937 m
.00375 .18937 L
s
0 .21237 m
.00375 .21237 L
s
0 .23537 m
.00375 .23537 L
s
0 .28136 m
.00375 .28136 L
s
0 .30436 m
.00375 .30436 L
s
0 .32736 m
.00375 .32736 L
s
0 .35035 m
.00375 .35035 L
s
0 .39635 m
.00375 .39635 L
s
0 .41934 m
.00375 .41934 L
s
0 .44234 m
.00375 .44234 L
s
0 .46534 m
.00375 .46534 L
s
0 .51133 m
.00375 .51133 L
s
0 .53433 m
.00375 .53433 L
s
0 .55732 m
.00375 .55732 L
s
0 .58032 m
.00375 .58032 L
s
0 .0054 m
.00375 .0054 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07766 .61178 m
.07766 .61803 L
s
.21844 .61178 m
.21844 .61803 L
s
.35922 .61178 m
.35922 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64078 .61178 m
.64078 .61803 L
s
.78156 .61178 m
.78156 .61803 L
s
.92234 .61178 m
.92234 .61803 L
s
.125 Mabswid
.10581 .61428 m
.10581 .61803 L
s
.13397 .61428 m
.13397 .61803 L
s
.16213 .61428 m
.16213 .61803 L
s
.19028 .61428 m
.19028 .61803 L
s
.24659 .61428 m
.24659 .61803 L
s
.27475 .61428 m
.27475 .61803 L
s
.30291 .61428 m
.30291 .61803 L
s
.33106 .61428 m
.33106 .61803 L
s
.38738 .61428 m
.38738 .61803 L
s
.41553 .61428 m
.41553 .61803 L
s
.44369 .61428 m
.44369 .61803 L
s
.47184 .61428 m
.47184 .61803 L
s
.52816 .61428 m
.52816 .61803 L
s
.55631 .61428 m
.55631 .61803 L
s
.58447 .61428 m
.58447 .61803 L
s
.61262 .61428 m
.61262 .61803 L
s
.66894 .61428 m
.66894 .61803 L
s
.69709 .61428 m
.69709 .61803 L
s
.72525 .61428 m
.72525 .61803 L
s
.75341 .61428 m
.75341 .61803 L
s
.80972 .61428 m
.80972 .61803 L
s
.83787 .61428 m
.83787 .61803 L
s
.86603 .61428 m
.86603 .61803 L
s
.89419 .61428 m
.89419 .61803 L
s
.0495 .61428 m
.0495 .61803 L
s
.02134 .61428 m
.02134 .61803 L
s
.9505 .61428 m
.9505 .61803 L
s
.97866 .61428 m
.97866 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0284 m
1 .0284 L
s
.99375 .14338 m
1 .14338 L
s
.99375 .25836 m
1 .25836 L
s
.99375 .37335 m
1 .37335 L
s
.99375 .48833 m
1 .48833 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .05139 m
1 .05139 L
s
.99625 .07439 m
1 .07439 L
s
.99625 .09739 m
1 .09739 L
s
.99625 .12038 m
1 .12038 L
s
.99625 .16638 m
1 .16638 L
s
.99625 .18937 m
1 .18937 L
s
.99625 .21237 m
1 .21237 L
s
.99625 .23537 m
1 .23537 L
s
.99625 .28136 m
1 .28136 L
s
.99625 .30436 m
1 .30436 L
s
.99625 .32736 m
1 .32736 L
s
.99625 .35035 m
1 .35035 L
s
.99625 .39635 m
1 .39635 L
s
.99625 .41934 m
1 .41934 L
s
.99625 .44234 m
1 .44234 L
s
.99625 .46534 m
1 .46534 L
s
.99625 .51133 m
1 .51133 L
s
.99625 .53433 m
1 .53433 L
s
.99625 .55732 m
1 .55732 L
s
.99625 .58032 m
1 .58032 L
s
.99625 .0054 m
1 .0054 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.05372 .14978 L
.08634 .26894 L
.11698 .35778 L
.14644 .42521 L
.1778 .48059 L
.20799 .52057 L
.22338 .5367 L
.24008 .55141 L
.27099 .57205 L
.28635 .57964 L
.30263 .58607 L
.31793 .59083 L
.33192 .59425 L
.34695 .59708 L
.36311 .59933 L
.37781 .60078 L
.38613 .60141 L
.39385 .60187 L
.40203 .60227 L
.40974 .60256 L
.41666 .60277 L
.42415 .60294 L
.43151 .60307 L
.43958 .60317 L
.44365 .6032 L
.44802 .60323 L
.45214 .60326 L
.45589 .60328 L
.45961 .60329 L
.46357 .6033 L
.46694 .6033 L
.47067 .60331 L
.47275 .60331 L
.47466 .60331 L
.47675 .60332 L
.47896 .60332 L
.48088 .60332 L
.48267 .60332 L
.48464 .60332 L
.48574 .60332 L
.48674 .60332 L
.48853 .60332 L
.48954 .60332 L
.49049 .60332 L
.49149 .60332 L
.49241 .60332 L
.49291 .60332 L
.49347 .60332 L
.49447 .60332 L
Mistroke
.49541 .60332 L
.49626 .60332 L
.49724 .60332 L
.49816 .60332 L
.49902 .60332 L
.49981 .60332 L
.50068 .60332 L
.50159 .60332 L
.5026 .60332 L
.50351 .60332 L
.50402 .60332 L
.50457 .60332 L
.50557 .60332 L
.5065 .60332 L
.50749 .60332 L
.50834 .60332 L
.50927 .60332 L
.51037 .60332 L
.51137 .60332 L
.51246 .60332 L
.51362 .60332 L
.51557 .60332 L
.51667 .60332 L
.51769 .60332 L
.51974 .60332 L
.52162 .60332 L
.52368 .60332 L
.52586 .60331 L
.52953 .60331 L
.53162 .60331 L
.53356 .6033 L
.53719 .6033 L
.54051 .60329 L
.54434 .60327 L
.54796 .60326 L
.55542 .60321 L
.55919 .60318 L
.56336 .60313 L
.57071 .60303 L
.57761 .6029 L
.58521 .60272 L
.59322 .60246 L
.60005 .60218 L
.60754 .6018 L
.6227 .60074 L
.63119 .59995 L
.63892 .59909 L
.65375 .59697 L
.66984 .59386 L
.68521 .58995 L
Mistroke
.7015 .58458 L
.73081 .57106 L
.74584 .56178 L
.76201 .54972 L
.79394 .51836 L
.8247 .47672 L
.85428 .42374 L
.88577 .35064 L
.91608 .26102 L
.94828 .14154 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Joooo
o`?o00006Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo0_l0000Ioooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006_ooool3o`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00006_ooool002[ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00000I
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`00
0?ooooooooooo`0001Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Sooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Iooooo`008_ooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003oooooooooo`0@ooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo000[ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool05oooool002cooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo1?l0000Iooooo`05o`000?ooooooooooooooool000001oooool4o`0001Kooooo
00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Ioooo
o`Co00007Oooool00ol0003oooooooooo`05ooooo`Co00006_ooool002Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
000Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01_o
oooo000Xooooo`Go00001oooool5o`0001Sooooo1Ol0000Iooooo`?o00002?ooool5o`0001Kooooo
0_l0000Jooooo`?o00002?ooool5o`0001Sooooo1Ol0000Hooooo`Go00001oooool5o`0001Wooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000KooooooSo0000
3Oooool001_ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo
0_l0000=ooooo`006oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`004oooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;oooo
o`004_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`003?ooool5o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00_ooooo000Fooooo`03o`000?oooooooooo00;ooooo
0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`03ooooo`;o00003Oooool001;ooooo1?l00005ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02oooool001;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00_ooooo000Booooo`Go00001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool001_ooooo0_l00006ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`04ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00001oooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01Oooool2o`0000gooooo000K
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo06oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`006oooool2
o`0000Sooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo
oooo00Kooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00002Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool2o`0000gooooo000Koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo000Dooooo`?o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00_ooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`003?ooool5o`000003ooooool0003o000000?o00001?ooool2o`00
00[ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
00Wooooo0_l0000=ooooo`004_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool001?ooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o00001Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00003?ooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool02oooool2o`0000gooooo000Kooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
01_ooooo0_l0000=ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`0<ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Xooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`1Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Sooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00_ooooo000Kooooo`;o00003oooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool03_ooool2o`0000gooooo000Kooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo06Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`1Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`006oooool2o`00017ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00oooooo
0_l0000=ooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool001?ooooo0ol00005oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool001;ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool000co
oooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0;ooooo`005?ooool2o`0000Gooooo0_l0000Booooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Aooooo`;o00003Oooool001Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo000B
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00_ooooo000Cooooo`?o00001Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool001_o
oooo0_l0000Dooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`0Booooo`;o00003Oooool001_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00_ooooo000Kooooo`;o00005_ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool05?ooool2o`0000gooooo000Kooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`006oooool2o`0001Sooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Kooooo0_l0
000=ooooo`006oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`;o00006_ooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool06?ooool2o`0000gooooo000Kooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0;ooooo`004_ooool5o`0000Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02oooool000cooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`005Oooool00ol0003ooooooooo
o`03ooooo`;o00007?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool06_ooool2o`0000gooooo000Booooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo000Booooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo000C
ooooo`?o00001Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0;ooooo`006oooool2o`0001oooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01gooooo0_l0000=ooooo`006ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00_o
oooo000Kooooo`;o00008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool07oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo000Kooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0;ooooo`006oooool2o`0002Cooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02;ooooo0_l0000=ooooo`006oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02oooool001_ooooo0_l0000X
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0V
ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo000Cooooo`?o0000
1Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo000Dooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`003?ooool5
o`0000?ooooo00?o0000ooooooooool01?ooool2o`0002_ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Wooooo0_l0000=ooooo`005?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool001Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00_o
oooo000Cooooo`;o00001_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo
000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`;o0000;oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0;Oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0;ooooo`006oooool2o`0003Gooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo03?ooooo0_l0000=ooooo`006oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`0hooooo`;o0000?_ooool00ol0003oooooooooo`0moooo
o`;o0000>_ooool00ol0003oooooooooo`0;ooooo`006oooool2o`0003_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03Wooooo0_l0000=ooooo`00
6oooool00ol0003oooooooooo`0kooooo`;o0000>oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0?Ooo
ool2o`0003Wooooo00?o0000ooooooooool0>Oooool2o`0003kooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0
003oooooooooo`10ooooo`;o0000=_ooool00ol0003oooooooooo`0fooooo`;o0000@Oooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`12ooooo`;o0000=?ooool00ol0003o
ooooooooo`0cooooo`?o0000@oooool00ol0003oooooooooo`0;ooooo`006oooool2o`0004Gooooo
0_l0000booooo`03o`000?oooooooooo033ooooo0ol00015ooooo`;o00003Oooool001_ooooo00?o
0000ooooooooool0A_ooool2o`00033ooooo00?o0000ooooooooool0;Oooool3o`0004Wooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0B?ooool3o`0002gooooo00?o0000
ooooooooool0:Oooool4o`0004cooooo00?o0000ooooooooool02oooool001Cooooo0_l00005oooo
o`03o`000?oooooooooo04_ooooo0ol0000Zooooo`03o`000?oooooooooo02Gooooo1?l0001@oooo
o`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0C_ooool8o`0002;ooooo00?o0000ooooooooool08_ooool3o`0005Cooooo00?o0000oooo
ooooool02oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Foooo
o`[o00006?ooool00ol0003oooooooooo`0Fooooo`co0000Eoooool00ol0003oooooooooo`0;oooo
o`004oooool01?l0003oooooooooool00004ooooo`;o0000HOoooolao`0006;ooooo0_l0000=oooo
o`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool0NOooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00_ooooo000Dooooo`;o00001Ooooooho`0000gooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo000]ooooo`?o0000R_ooool00ol0003oooooooooo`0[oooo
o`?o00005Oooool00ol0003oooooooooo`0Mooooo`00;_ooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Looooo`00
:?ooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003ooooo`Co0000
00?oooooo`000?l000000ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko0000
1_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o0000
0_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`?o
00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`Co
00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`?o
000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_ooool:o`0000Gooooo00?o0000oooo
ooooool06oooool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool002Oooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`0000Gooooo1Ol00008ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o00000oooool00ol0
003oooooo`000002ooooo`Go00000oooool01?l0003oooooooooooooool5o`0000;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00000_ooool3o`0000Gooooo00?o0000ooooooooool06oooool002Oooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00005ooooo`06o`000?oo
ooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`0Kooooo`009oooool01_l0003ooooo
oooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000oooool2o`00
00Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00002ooooo`;o00000oooool4
o`0000?ooooo0ol00009ooooo`05o`000?ooooooooooo`000?ooool00ol00004ooooo`Co00000_oo
ool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l0
0003ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00_ooool6o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o00000oooool4o`0000Cooooo00?o
0000ooooooooool06oooool002Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01cooooo000Xooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo0ol00009ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o0000
2_ooool4o`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0000^ooooo`03o`00
0?oooooooooo01Sooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000;ooooo`03o`00
0?oooooooooo01gooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.8475, -5.67237, \
0.0718464, 0.0351862}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 5\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FindPupils \[Rule] True\), ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {207.28232192993164`, 0, 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 112.44620808978891`\), 
        ",", \(OpticalLengthFunction \[Rule] OpticalLengthFunction\), 
        ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          TagBox[\(CompiledFunction[
              If[#1 == 0 && #2 == 0, 
                0.000022271117373179214`, \(-6.853627285348719`\) - 
                  3.532109641994116`*^-9\ Cos[
                      2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                  1.9515319104050795`*^-10\ Cos[
                      4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                  10.310895376241149`\ \((\(-1\) + 
                        0.013990424917235709`\ \((#1\^2 + #2\^2)\))\) - 
                  5.251099192578527`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.020985637375853565`\)\ \
\((#1\^2 + #2\^2)\) + 0.0001957319893648098`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  3.4781206500308235`\ \((1 - 
                        0.04197127475170713`\ \((#1\^2 + #2\^2)\) + 
                        0.0002935979840472147`\ \((#1\^2 + #2\^2)\)\^2)\) + 
                  4.27139394586925`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((\(-0.00024466498670601227`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 2.0537802758321623`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  3.396256590938641`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((0.04197127475170713`\ \((#1\^2 + \
#2\^2)\) - 0.000978659946824049`\ \((#1\^2 + #2\^2)\)\^2 + 
                        5.134450689580406`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  0.02108223618211115`\ \((\(-1\) + 
                        0.08394254950341426`\ \((#1\^2 + #2\^2)\) - 
                        0.0014679899202360734`\ \((#1\^2 + #2\^2)\)\^2 + 
                        6.845934252773875`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  7.380096153526266`*^-8\ Cos[
                      6\ ArcTan[#1, #2]]\ \((\(-2.396076988470856`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 1.9155505830353006`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  3.180054365542885`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((0.0007339949601180367`\ \((#1\^2 \
+ #2\^2)\)\^2 - 0.000014376461930825136`\ \((#1\^2 + #2\^2)\)\^3 + 
                        6.704427040623552`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  1.291385970907799`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.06995212458617854`\)\ \((#1\
\^2 + #2\^2)\) + 0.0029359798404721468`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00003594115482706284`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.3408854081247104`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.0002074059263440704`\ \((1 - 
                        0.13990424917235708`\ \((#1\^2 + #2\^2)\) + 
                        0.00440396976070822`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00004792153976941712`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.6761067601558881`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
              "-CompiledCode-"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {112.43537240553266`, 
            112.44620808978891`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), 
        ",", \(Plot2D \[Rule] True\), ",", \(PlotPoints \[Rule] 32\), 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(RayBoundary \[Rule] {{\(-8.4562214163056`\), 
              8.4562214163056`}, {\(-8.452646568455712`\), 
              8.452646568455712`}}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), 
        ",", \(ResidualFitError \[Rule] 7.313862904893167`*^-7\), 
        ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
              82.9255011275954`, Astigmatism \[Rule] 0.0000417323567305451`, 
            FieldCurvature \[Rule] \(-0.24683256227325023`\), 
            Distortion \[Rule] \(-3.777962952267033`*^-13\), 
            Coma \[Rule] 1.3460273542456333`*^-12}\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 584\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-11.347295107870586`\), 
                  11.347295107870586`}, {\(-11.343720260020696`\), 
                  11.343720260020696`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[19]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["PupilFunction[sys,FindPupils->False]", "Input",
  CellLabel->"In[20]:=",
  CellTags->{"AOG5.3", "AOG5.", "AOG0."}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0225709 -1425.46 21.8604 [
[.04858 -0.0125 -9 -9 ]
[.04858 -0.0125 9 0 ]
[.27429 -0.0125 -9 -9 ]
[.27429 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.72571 -0.0125 -6 -9 ]
[.72571 -0.0125 6 0 ]
[.95142 -0.0125 -6 -9 ]
[.95142 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05213 -30 -4.5 ]
[-0.0125 .05213 0 4.5 ]
[-0.0125 .16143 -36 -4.5 ]
[-0.0125 .16143 0 4.5 ]
[-0.0125 .27073 -30 -4.5 ]
[-0.0125 .27073 0 4.5 ]
[-0.0125 .38003 -36 -4.5 ]
[-0.0125 .38003 0 4.5 ]
[-0.0125 .48934 -30 -4.5 ]
[-0.0125 .48934 0 4.5 ]
[-0.0125 .59864 -36 -4.5 ]
[-0.0125 .59864 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04858 0 m
.04858 .00625 L
s
[(-20)] .04858 -0.0125 0 1 Mshowa
.27429 0 m
.27429 .00625 L
s
[(-10)] .27429 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.72571 0 m
.72571 .00625 L
s
[(10)] .72571 -0.0125 0 1 Mshowa
.95142 0 m
.95142 .00625 L
s
[(20)] .95142 -0.0125 0 1 Mshowa
.125 Mabswid
.09372 0 m
.09372 .00375 L
s
.13887 0 m
.13887 .00375 L
s
.18401 0 m
.18401 .00375 L
s
.22915 0 m
.22915 .00375 L
s
.31943 0 m
.31943 .00375 L
s
.36457 0 m
.36457 .00375 L
s
.40972 0 m
.40972 .00375 L
s
.45486 0 m
.45486 .00375 L
s
.54514 0 m
.54514 .00375 L
s
.59028 0 m
.59028 .00375 L
s
.63543 0 m
.63543 .00375 L
s
.68057 0 m
.68057 .00375 L
s
.77085 0 m
.77085 .00375 L
s
.81599 0 m
.81599 .00375 L
s
.86113 0 m
.86113 .00375 L
s
.90628 0 m
.90628 .00375 L
s
.00344 0 m
.00344 .00375 L
s
.99656 0 m
.99656 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05213 m
.00625 .05213 L
s
[(65.21)] -0.0125 .05213 1 0 Mshowa
0 .16143 m
.00625 .16143 L
s
[(65.215)] -0.0125 .16143 1 0 Mshowa
0 .27073 m
.00625 .27073 L
s
[(65.22)] -0.0125 .27073 1 0 Mshowa
0 .38003 m
.00625 .38003 L
s
[(65.225)] -0.0125 .38003 1 0 Mshowa
0 .48934 m
.00625 .48934 L
s
[(65.23)] -0.0125 .48934 1 0 Mshowa
0 .59864 m
.00625 .59864 L
s
[(65.235)] -0.0125 .59864 1 0 Mshowa
.125 Mabswid
0 .07399 m
.00375 .07399 L
s
0 .09585 m
.00375 .09585 L
s
0 .11771 m
.00375 .11771 L
s
0 .13957 m
.00375 .13957 L
s
0 .18329 m
.00375 .18329 L
s
0 .20515 m
.00375 .20515 L
s
0 .22701 m
.00375 .22701 L
s
0 .24887 m
.00375 .24887 L
s
0 .29259 m
.00375 .29259 L
s
0 .31445 m
.00375 .31445 L
s
0 .33631 m
.00375 .33631 L
s
0 .35817 m
.00375 .35817 L
s
0 .40189 m
.00375 .40189 L
s
0 .42375 m
.00375 .42375 L
s
0 .44562 m
.00375 .44562 L
s
0 .46748 m
.00375 .46748 L
s
0 .5112 m
.00375 .5112 L
s
0 .53306 m
.00375 .53306 L
s
0 .55492 m
.00375 .55492 L
s
0 .57678 m
.00375 .57678 L
s
0 .03027 m
.00375 .03027 L
s
0 .00841 m
.00375 .00841 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04858 .61178 m
.04858 .61803 L
s
.27429 .61178 m
.27429 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.72571 .61178 m
.72571 .61803 L
s
.95142 .61178 m
.95142 .61803 L
s
.125 Mabswid
.09372 .61428 m
.09372 .61803 L
s
.13887 .61428 m
.13887 .61803 L
s
.18401 .61428 m
.18401 .61803 L
s
.22915 .61428 m
.22915 .61803 L
s
.31943 .61428 m
.31943 .61803 L
s
.36457 .61428 m
.36457 .61803 L
s
.40972 .61428 m
.40972 .61803 L
s
.45486 .61428 m
.45486 .61803 L
s
.54514 .61428 m
.54514 .61803 L
s
.59028 .61428 m
.59028 .61803 L
s
.63543 .61428 m
.63543 .61803 L
s
.68057 .61428 m
.68057 .61803 L
s
.77085 .61428 m
.77085 .61803 L
s
.81599 .61428 m
.81599 .61803 L
s
.86113 .61428 m
.86113 .61803 L
s
.90628 .61428 m
.90628 .61803 L
s
.00344 .61428 m
.00344 .61803 L
s
.99656 .61428 m
.99656 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05213 m
1 .05213 L
s
.99375 .16143 m
1 .16143 L
s
.99375 .27073 m
1 .27073 L
s
.99375 .38003 m
1 .38003 L
s
.99375 .48934 m
1 .48934 L
s
.99375 .59864 m
1 .59864 L
s
.125 Mabswid
.99625 .07399 m
1 .07399 L
s
.99625 .09585 m
1 .09585 L
s
.99625 .11771 m
1 .11771 L
s
.99625 .13957 m
1 .13957 L
s
.99625 .18329 m
1 .18329 L
s
.99625 .20515 m
1 .20515 L
s
.99625 .22701 m
1 .22701 L
s
.99625 .24887 m
1 .24887 L
s
.99625 .29259 m
1 .29259 L
s
.99625 .31445 m
1 .31445 L
s
.99625 .33631 m
1 .33631 L
s
.99625 .35817 m
1 .35817 L
s
.99625 .40189 m
1 .40189 L
s
.99625 .42375 m
1 .42375 L
s
.99625 .44562 m
1 .44562 L
s
.99625 .46748 m
1 .46748 L
s
.99625 .5112 m
1 .5112 L
s
.99625 .53306 m
1 .53306 L
s
.99625 .55492 m
1 .55492 L
s
.99625 .57678 m
1 .57678 L
s
.99625 .03027 m
1 .03027 L
s
.99625 .00841 m
1 .00841 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .30605 Mdot
.05478 .46627 Mdot
.0857 .56058 Mdot
.11656 .60238 Mdot
.14737 .60332 Mdot
.17815 .57351 Mdot
.20889 .52172 Mdot
.2396 .45558 Mdot
.27029 .38161 Mdot
.30095 .30543 Mdot
.3316 .23178 Mdot
.36224 .1646 Mdot
.39286 .10711 Mdot
.42348 .06183 Mdot
.45409 .03062 Mdot
.4847 .01472 Mdot
.5153 .01472 Mdot
.54591 .03062 Mdot
.57652 .06183 Mdot
.60714 .10711 Mdot
.63776 .1646 Mdot
.6684 .23178 Mdot
.69905 .30543 Mdot
.72971 .38161 Mdot
.7604 .45558 Mdot
.79111 .52172 Mdot
.82185 .57351 Mdot
.85263 .60332 Mdot
.88344 .60238 Mdot
.9143 .56058 Mdot
.94522 .46627 Mdot
.97619 .30605 Mdot
.5 Mabswid
.02381 .30605 m
.03837 .38137 L
.04579 .41973 L
.04987 .44082 L
.05372 .46077 L
.05574 .4692 L
.05794 .4759 L
.06178 .48761 L
.06929 .51052 L
.0774 .53528 L
.08171 .54841 L
.08408 .55566 L
.08465 .55739 L
.08525 .55923 L
.08582 .56075 L
.08634 .56145 L
.08832 .56413 L
.09048 .56706 L
.09427 .57219 L
.1017 .58225 L
.11018 .59374 L
.1139 .59878 L
.11492 .60016 L
.11548 .60092 L
.11601 .60164 L
.1165 .60231 L
.11704 .6024 L
.11798 .60243 L
.12523 .60265 L
.13288 .60288 L
.13694 .603 L
.14125 .60313 L
.14494 .60324 L
.14594 .60328 L
.14647 .60329 L
.14703 .60331 L
.14752 .60317 L
.14806 .60265 L
.149 .60174 L
.16545 .5858 L
.17323 .57827 L
.1804 .56971 L
.18786 .55714 L
.19595 .54352 L
.21063 .51797 L
.24114 .45187 L
.27047 .38116 L
.3017 .30364 L
.33176 .23144 L
.36371 .16183 L
Mistroke
.39449 .1047 L
.41003 .08172 L
.4168 .07172 L
.4241 .0612 L
.43197 .05318 L
.43936 .04564 L
.44711 .03774 L
.45122 .03355 L
.4523 .03245 L
.45348 .03125 L
.45401 .0307 L
.45459 .03037 L
.45561 .02983 L
.4598 .02766 L
.46362 .02567 L
.47108 .02179 L
.47894 .01771 L
.48109 .01659 L
.48226 .01598 L
.48335 .01541 L
.48429 .01493 L
.48528 .01472 L
.48585 .01472 L
.48639 .01472 L
.4874 .01472 L
.49465 .01472 L
.5025 .01472 L
.50608 .01472 L
.50987 .01472 L
.51311 .01472 L
.514 .01472 L
.51495 .01472 L
.51584 .015 L
.51666 .01542 L
.53267 .02374 L
.53971 .0274 L
.54345 .02935 L
.54447 .02987 L
.54541 .03037 L
.5464 .03113 L
.54749 .03223 L
.55135 .03617 L
.55489 .03978 L
.56186 .04688 L
.56918 .05435 L
.57714 .06274 L
.58527 .07477 L
.59295 .08614 L
.60734 .10749 L
.63899 .1673 L
Mistroke
.66947 .23436 L
.69878 .30479 L
.72999 .38227 L
.76002 .45465 L
.79195 .52313 L
.8079 .55001 L
.81567 .56309 L
.81934 .56926 L
.82094 .57197 L
.82271 .57433 L
.82443 .576 L
.82625 .57777 L
.83008 .58148 L
.83703 .58821 L
.84502 .59594 L
.8488 .59961 L
.85046 .60122 L
.8514 .60213 L
.85229 .60299 L
.85316 .6033 L
.8541 .60327 L
.85601 .60322 L
.86006 .60309 L
.86741 .60287 L
.87153 .60274 L
.87586 .60261 L
.87956 .6025 L
.88057 .60247 L
.88165 .60244 L
.88268 .60241 L
.8836 .60216 L
.88453 .60091 L
.88539 .59974 L
.88736 .59707 L
.89134 .59169 L
.89847 .58203 L
.90673 .57083 L
.9108 .56532 L
.91278 .56264 L
.91371 .56138 L
.91457 .55975 L
.91548 .557 L
.91645 .55402 L
.91822 .54864 L
.92209 .53681 L
.93029 .5118 L
.93723 .49065 L
.94104 .47901 L
.94291 .47329 L
.94465 .46801 L
Mistroke
.94557 .46445 L
.94654 .4594 L
.94861 .44873 L
.95221 .43009 L
.95926 .39362 L
.97527 .3108 L
.97619 .30605 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<?ooool5o`0000?ooooo0_l0000_ooooo`?o00001?ooool2o`0002oooooo0_l0000boooo
o`?o00001?ooool2o`0002kooooo1Ol00003ooooo`;o00002_ooool0037ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000;Oooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000;_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Wooooo000Zooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002Oooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000;Ooo
ool01?l0003oooooooooool0000booooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000;oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo000cooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000;Oooool01?l0003oooooooooool0000booooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000<?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01oooool0033ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000]
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000]ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00009oooo
o`00<?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000;_ooool2
o`0000Cooooo00Co0000oooooooooooo0000;Oooool01?l0003oooooooooool0000aooooo`;o0000
1?ooool01?l0003oooooooooool0000]ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00009ooooo`00<Oooool3o`0000Cooooo0_l0000`ooooo`03o`000?oooooooooo
00?ooooo0_l0000_ooooo`;o0000<oooool00ol0003oooooooooo`03ooooo`;o0000;oooool3o`00
00Cooooo0_l0000:ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`009ooooooho`00007ooooo000Wooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`00007ooooo000Wooooo`;o0000
NOooool00ol0003oooooooooo`1hooooo`;o00000Oooool002Oooooo00?o0000ooooooooool0M?oo
ool;o`0007Gooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1booooo`Co00000_ooool0
1?l0003oooooooooooooool2o`000003ooooool0003ooooo07?ooooo0Ol00001ooooo`009oooool0
0ol0003oooooooooo`1`ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo077ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool2o`00077ooooo0Ol00001ooooo`009oooool2o`0006go
oooo0ol00009ooooo`03o`000?oooooooooo00Sooooo0_l0001^ooooo`;o00000Oooool002Oooooo
00?o0000ooooooooool0K?ooool2o`0000[ooooo00?o0000ooooooooool02?ooool2o`0006oooooo
0Ol00001ooooo`009oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool2o`0006gooooo0Ol00001ooooo`001oooool3o`0000?ooooo0ol00004
ooooo`04o`000?ooooooooooooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool0J_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0J_oo
ool1o`00007ooooo0006ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo06Wooooo0Ol00001ooooo`001_ooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0J?ooool1o`00007ooooo0006ooooo`Co00001_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool2o`0006Wooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Kooooo
0_l00001ooooo`001_ooool00ol0003oooooooooo`03ooooo`Co00002?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Vooooo`7o0000
0Oooool000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`0000Kooooo00?o0000ooooooooool0IOooool2o`00017ooooo
00?o0000ooooooooool04?ooool2o`0006Oooooo0Ol00001ooooo`002?ooool2o`0000;ooooo1Ol0
0008ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Gooooo0_l0
000Aooooo`03o`000?oooooooooo013ooooo0_l0001Wooooo`7o00000Oooool002Oooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0I?ooool1o`00007ooooo000Wooooo`;o0000IOooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0H_ooool2o`00007ooooo000Wooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo06?ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Rooooo`7o0000
0Oooool002Oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0H_ooool1o`00007ooooo000Wooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06;ooooo0Ol00001ooooo`009oooool2o`00067ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo063ooooo0_l00001ooooo`009oooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`1Pooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Goooool1o`00007ooooo
000Wooooo`03o`000?oooooooooo05gooooo0_l0000Iooooo`03o`000?oooooooooo01Oooooo0_l0
001Pooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0GOooool2o`0001Wooooo00?o0000
ooooooooool05oooool2o`00063ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1Moooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Moooo
o`7o00000Oooool002Oooooo0_l0001Nooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1Looooo`;o00000Oooool002Oooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
G?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05cooooo0Ol00001ooooo`009oooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1Kooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Foooool1o`00
007ooooo000Wooooo`;o0000Foooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0FOooool2o`00007ooooo000Wooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Wooooo
0Ol00001ooooo`009oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`1Iooooo`7o00000Oooool00004ooooool0003o
0000o`0000?ooooo0ol00004ooooo`04o`000?ooooooooooooooo`Go00000_ooool3o`0000?ooooo
0ol00005ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo05Sooooo0Ol00001ooooo`0000Oo0000oooooooooooooooo
o`000?oooooo000000?ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo05Sooooo0Ol00001ooooo`0000Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0Eoooool1o`00007ooooo0004o`0000Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool2o`0005Oooooo0_l0000Pooooo`03o`000?oooooooooo01oooooo0_l0001Goooo
o`;o00000Oooool00003o`000?oooooooooo00?ooooo1?l00008ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000ooooooooool0E_ooool2
o`00023ooooo00?o0000ooooooooool07oooool2o`0005Sooooo0Ol00001ooooo`0000?oooooo`00
0?ooool00oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000_ooool2
o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Fooooo`7o00000Oooool0
00;ooooo0_l00002ooooo`Go00002?ooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo05Gooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1Eoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Eoooo
o`7o00000Oooool002Oooooo0_l0001Fooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`1Dooooo`;o00000Oooool002Oooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
E?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05Cooooo0Ol00001ooooo`009oooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1Cooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Doooool1o`00
007ooooo000Wooooo`;o0000E?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0DOooool2o`00007ooooo000Wooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo
0Ol00001ooooo`009oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1Booooo`7o00000Oooool002Oooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0DOooool1o`00007ooooo000Wooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo057ooooo0Ol00001oooo
o`009oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1@ooooo`7o00000Oooool002Oooooo0_l0001Aooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1?ooooo`;o0000
0Oooool002Oooooo00?o0000ooooooooool0C_ooool2o`0002Sooooo00?o0000ooooooooool09_oo
ool2o`00057ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1>ooooo`;o0000:?ooool0
0ol0003oooooooooo`0Vooooo`;o0000DOooool1o`00007ooooo000Wooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
04oooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1>ooooo`7o00000Oooool002Oooooo
0_l0001>ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1=ooooo`;o00000Oooool002Oooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0COooool1o`00007ooooo000W
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo04gooooo0Ol00001ooooo`001oooool3o`0000?ooooo0ol00004oooo
o`04o`000?ooooooooooooooo`Go000000?oooooo`000?l000000ol00004ooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo04cooooo0Ol00001ooooo`001_ooool01ol0003ooooooooooooooooo0000ooooool000000ooo
ool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`1<ooooo`7o00000Oooool000Kooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo04_ooooo0Ol00001ooooo`001_ooool4o`0000Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
0_l0001<ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`1:ooooo`;o00000Oooool000Kooooo00?o0000ooooooooool00oooool4o`0000Sooooo00Oo
0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`1;ooooo`7o00000Oooool000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0B_ooool1o`00007ooooo0008ooooo`;o00000_ooool5o`0000So
oooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1:ooooo`7o00000Oooool002Oooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0BOooool1o`00007ooooo000Wooooo`;o0000B_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0B?ooool2o`00007ooooo000W
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo04Sooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`18oooo
o`7o00000Oooool002Oooooo00?o0000ooooooooool00_ooool2o`0004?ooooo0_l0000_ooooo`03
o`000?oooooooooo02kooooo0_l00012ooooo`;o00001Oooool1o`00007ooooo000Wooooo`03o`00
0?oooooooooo00;ooooo0_l00013ooooo`;o0000;oooool00ol0003oooooooooo`0^ooooo`;o0000
@_ooool2o`0000Gooooo0Ol00001ooooo`009oooool2o`0000Cooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`02ooooo`;o00000Oooool002Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`009oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00oooool1o`00
007ooooo000Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`04ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`009oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool1o`00007ooooo000W
ooooo`;o00001Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00?ooooo0_l00001
ooooo`009oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool01?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`05ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`009ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Ooo
ool1o`00007ooooo000Wooooo`;o00001_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00Cooooo0_l00001ooooo`009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool01Oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`7o00000Oooool00004oooo
ool0003o0000o`0000?ooooo0ol00004ooooo`04o`000?ooooooooooooooo`Go000000?oooooo`00
0?l000000ol00002ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool01_ooool1o`00007ooooo00001ol0003ooooooooooooooooo0000
ooooool000000oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`00
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`00
1?l00006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`03o`000?oooooooooo03Kooooo
0_l0000gooooo`03o`000?oooooooooo03Kooooo0_l0000hooooo`03o`000?oooooooooo00Gooooo
0_l00001ooooo`0000?o0000ooooooooool00oooool4o`0000Sooooo00Oo0000oooooooooooooooo
o`000?oooooo000000?ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0=_ooool2o`0003Oooooo00?o0000ooooooooool0=_ooool2o`0003Oo
oooo00?o0000ooooooooool01oooool1o`00007ooooo00000ooooooo0000ooooo`03ooooo`03o`00
0?oooooooooo00Wooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool01oooool1o`00007ooooo0002ooooo`;o00000_ooool5o`0000Sooooo0ol00003ooooo`?o
00000_ooool5o`0000Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00Oooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool01oooool1o`00007ooooo000Wooooo`;o00002?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Kooooo0_l00001ooooo`009oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02?ooool1
o`00007ooooo000Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`08ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`009oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02?ooool1o`00007ooooo
000Wooooo`;o00002Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo0_l0
0001ooooo`009oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool02Oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`09ooooo`7o00000Oooool002Oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`00
9oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
2Oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0:ooooo`7o00000Oooool002Oooooo0_l0000:ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool02Oooool2o`00007ooooo000Wooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0:ooooo`7o00000Oooool002Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Zooooo`?o0000?_ooool00ol0003o
ooooooooo`0mooooo`;o0000;Oooool00ol0003oooooooooo`0:ooooo`7o00000Oooool002Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Zooooo`;o0000?oooool00ol0003ooooo
ooooo`0mooooo`;o0000;Oooool00ol0003oooooooooo`0:ooooo`7o00000Oooool002Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00[ooooo0Ol0
0001ooooo`009oooool2o`0000_ooooo0_l0000[ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0Yooooo`;o00002oooool2o`00007ooooo000Woooo
o`03o`000?oooooooooo00[ooooo0_l0000[ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Xooooo`;o00003?ooool1o`00007ooooo000Wooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0;ooooo`7o
00000Oooool000Oooooo0ol00003ooooo`?o00001?ooool01?l0003oooooooooooooool5o`0000;o
oooo0ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0<ooooo`7o00000Oooool000Kooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00?ooooo00?o0000ooooooooool01_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool03?ooool1o`00007ooooo0006ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?oo
ool1o`00007ooooo0006ooooo`Co00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00;ooooo0_l00005ooooo`;o00003Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00_ooooo0_l00001ooooo`001_ooool00ol0003oooooooooo`03ooooo`Co00002?ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool1o`00007ooooo0007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01ol0003ooooooooooooooooo
0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0=ooooo`7o00000Oooool000Sooooo0_l00002
ooooo`Go00002?ooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0=ooooo`7o00000Oooool002Oooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00gooooo0Ol00001oooo
o`009oooool2o`0000oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0=ooooo`;o
00000Oooool002Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00kooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01kooooo0_l00016ooooo`03o`000?oooooooooo04Gooooo0_l0000Pooooo`03o`000?oo
oooooooo00oooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01kooooo0_l00016ooooo`03o`000?oooooooooo04Gooooo0_l0000Pooooo`03o`000?oooooo
oooo00oooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool03oooool1o`00007ooooo000Wooooo`;o00004Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00oooooo0_l00001ooooo`009oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04?ooool1o`00007ooooo
000Wooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0@ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo017ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04Oooool1o`00007ooooo000Wooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Aooooo`7o
00000Oooool002Oooooo0_l0000Cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
4Oooool2o`00007ooooo000Wooooo`03o`000?oooooooooo017ooooo0_l0000Hooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Eooooo`;o00005?oo
ool1o`00007ooooo000Wooooo`03o`000?oooooooooo017ooooo0ol0000Fooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Dooooo`;o00005?ooool1
o`00007ooooo000Wooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Cooooo`7o00000Oooool002Oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Aooooo`;o0000C_ooool00ol0003oooooooooo`1<ooooo`;o00005?ooool00ol0003o
ooooooooo`0Dooooo`7o00000Oooool002Oooooo0_l0000Eooooo`03o`000?oooooooooo017ooooo
0_l0001>ooooo`03o`000?oooooooooo04cooooo0ol0000Cooooo`03o`000?oooooooooo01?ooooo
0_l00001ooooo`009oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo0_l0
001?ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Eooooo`7o00000Oooool002Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Kooooo0Ol00001ooooo`0000Coooooo`000?l0003o00000oooool3
o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00000oooool3o`0000Gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo0Ol0
0001ooooo`0000Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool0
1_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Hooooo`7o00000Oooool00005o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Iooooo`7o00000Oooool000Co00001_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo0_l0000Jooooo`;o
00001_ooool2o`0005Gooooo00?o0000ooooooooool0E?ooool2o`0000Kooooo0_l0000Jooooo`;o
00000Oooool00003o`000?oooooooooo00?ooooo1?l00008ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool06Oooool:o`0005Go
oooo00?o0000ooooooooool0E?ooool:o`0001_ooooo0Ol00001ooooo`0000?oooooo`000?ooool0
0oooool00ol0003oooooooooo`09ooooo`07o`000?ooooooooooooooool0003oooooo`000003oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1ioooo
o`7o00000Oooool000;ooooo0_l00002ooooo`Go00002?ooool3o`0000?ooooo0ol00002ooooo`Go
00001?ooool2o`0000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo0_l00001ooooo`009ooooooho`00007ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo000cooooo`?o0000F?ooool3o`0001Oooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`0;ooooo`00=?ooool00ol0003oooooooooo`1Jooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0:ooooo`00;_oo
ool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003ooooo`Co000000?o
ooooo`000?l000000ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001_oo
ool5o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o0000
0_ooool6o`0000Oooooo00?o0000ooooooooool00oooool4o`000003ooooool0003o000000;o0000
0_ooool4o`0000?ooooo0ol00002ooooo`Go00000oooool2o`000004ooooool0003oooooooooo`;o
00000oooool3o`0000Wooooo1?l000000ooooooo0000o`000003o`000003ooooool0003o000000;o
00001?ooool2o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`00
0?l0003o00000oooool3o`0000Gooooo00?o0000ooooooooool02Oooool002gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?oo
ool01_l0003oooooooooool0003oooooo`0000Kooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0000;ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`09ooooo`00;Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`03ooooo`?o00000oooool01?l0003oooooooooool00002oooo
o`?o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00007ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo00?o0000ooooooooool0
0oooool3o`0000?ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`Go00001?ooool00ol0
003oooooooooo`09ooooo`00;Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00?ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool002gooooo00Ko0000oooooooo
ooooooooo`000?ooool4o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000?ooooo0_l00005
ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l0
0003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool4o`0000?ooooo2Ol0
0003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool3o`0000?ooooo1?l0
0002ooooo`?o00001?ooool01?l0003oooooooooooooool2o`000004ooooool0003o0000ooooo`Co
00000oooool3o`0000Wooooo0ol00002ooooo`?o00001?ooool4o`000003ooooool0003o000000;o
00000oooool2o`0000?ooooo1?l00003ooooo`?o00000oooool3o`0000Gooooo00?o0000oooooooo
ool02Oooool002gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`00;_ooool3o`0000Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`?o00002Oooool4o`0000Wo
oooo00?o0000ooooooooool00_ooool2o`0000[ooooo0ol0000Fooooo`03o`000?oooooooooo00;o
oooo0_l0000=ooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`?o00002_ooool00ol0003o
ooooooooo`0@ooooo`;o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.2147, 65.2052, 0.17925, \
0.000185076}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0225709 -1.42333 0.879427 [
[.04858 -0.0125 -9 -9 ]
[.04858 -0.0125 9 0 ]
[.27429 -0.0125 -9 -9 ]
[.27429 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.72571 -0.0125 -6 -9 ]
[.72571 -0.0125 6 0 ]
[.95142 -0.0125 -6 -9 ]
[.95142 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0717 -18 -4.5 ]
[-0.0125 .0717 0 4.5 ]
[-0.0125 .15964 -18 -4.5 ]
[-0.0125 .15964 0 4.5 ]
[-0.0125 .24758 -18 -4.5 ]
[-0.0125 .24758 0 4.5 ]
[-0.0125 .33553 -6 -4.5 ]
[-0.0125 .33553 0 4.5 ]
[-0.0125 .42347 -18 -4.5 ]
[-0.0125 .42347 0 4.5 ]
[-0.0125 .51141 -18 -4.5 ]
[-0.0125 .51141 0 4.5 ]
[-0.0125 .59935 -18 -4.5 ]
[-0.0125 .59935 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04858 0 m
.04858 .00625 L
s
[(-20)] .04858 -0.0125 0 1 Mshowa
.27429 0 m
.27429 .00625 L
s
[(-10)] .27429 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.72571 0 m
.72571 .00625 L
s
[(10)] .72571 -0.0125 0 1 Mshowa
.95142 0 m
.95142 .00625 L
s
[(20)] .95142 -0.0125 0 1 Mshowa
.125 Mabswid
.09372 0 m
.09372 .00375 L
s
.13887 0 m
.13887 .00375 L
s
.18401 0 m
.18401 .00375 L
s
.22915 0 m
.22915 .00375 L
s
.31943 0 m
.31943 .00375 L
s
.36457 0 m
.36457 .00375 L
s
.40972 0 m
.40972 .00375 L
s
.45486 0 m
.45486 .00375 L
s
.54514 0 m
.54514 .00375 L
s
.59028 0 m
.59028 .00375 L
s
.63543 0 m
.63543 .00375 L
s
.68057 0 m
.68057 .00375 L
s
.77085 0 m
.77085 .00375 L
s
.81599 0 m
.81599 .00375 L
s
.86113 0 m
.86113 .00375 L
s
.90628 0 m
.90628 .00375 L
s
.00344 0 m
.00344 .00375 L
s
.99656 0 m
.99656 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0717 m
.00625 .0717 L
s
[(1.7)] -0.0125 .0717 1 0 Mshowa
0 .15964 m
.00625 .15964 L
s
[(1.8)] -0.0125 .15964 1 0 Mshowa
0 .24758 m
.00625 .24758 L
s
[(1.9)] -0.0125 .24758 1 0 Mshowa
0 .33553 m
.00625 .33553 L
s
[(2)] -0.0125 .33553 1 0 Mshowa
0 .42347 m
.00625 .42347 L
s
[(2.1)] -0.0125 .42347 1 0 Mshowa
0 .51141 m
.00625 .51141 L
s
[(2.2)] -0.0125 .51141 1 0 Mshowa
0 .59935 m
.00625 .59935 L
s
[(2.3)] -0.0125 .59935 1 0 Mshowa
.125 Mabswid
0 .08929 m
.00375 .08929 L
s
0 .10687 m
.00375 .10687 L
s
0 .12446 m
.00375 .12446 L
s
0 .14205 m
.00375 .14205 L
s
0 .17723 m
.00375 .17723 L
s
0 .19482 m
.00375 .19482 L
s
0 .21241 m
.00375 .21241 L
s
0 .22999 m
.00375 .22999 L
s
0 .26517 m
.00375 .26517 L
s
0 .28276 m
.00375 .28276 L
s
0 .30035 m
.00375 .30035 L
s
0 .31794 m
.00375 .31794 L
s
0 .35311 m
.00375 .35311 L
s
0 .3707 m
.00375 .3707 L
s
0 .38829 m
.00375 .38829 L
s
0 .40588 m
.00375 .40588 L
s
0 .44106 m
.00375 .44106 L
s
0 .45865 m
.00375 .45865 L
s
0 .47623 m
.00375 .47623 L
s
0 .49382 m
.00375 .49382 L
s
0 .529 m
.00375 .529 L
s
0 .54659 m
.00375 .54659 L
s
0 .56418 m
.00375 .56418 L
s
0 .58177 m
.00375 .58177 L
s
0 .05411 m
.00375 .05411 L
s
0 .03652 m
.00375 .03652 L
s
0 .01893 m
.00375 .01893 L
s
0 .00134 m
.00375 .00134 L
s
0 .61694 m
.00375 .61694 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04858 .61178 m
.04858 .61803 L
s
.27429 .61178 m
.27429 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.72571 .61178 m
.72571 .61803 L
s
.95142 .61178 m
.95142 .61803 L
s
.125 Mabswid
.09372 .61428 m
.09372 .61803 L
s
.13887 .61428 m
.13887 .61803 L
s
.18401 .61428 m
.18401 .61803 L
s
.22915 .61428 m
.22915 .61803 L
s
.31943 .61428 m
.31943 .61803 L
s
.36457 .61428 m
.36457 .61803 L
s
.40972 .61428 m
.40972 .61803 L
s
.45486 .61428 m
.45486 .61803 L
s
.54514 .61428 m
.54514 .61803 L
s
.59028 .61428 m
.59028 .61803 L
s
.63543 .61428 m
.63543 .61803 L
s
.68057 .61428 m
.68057 .61803 L
s
.77085 .61428 m
.77085 .61803 L
s
.81599 .61428 m
.81599 .61803 L
s
.86113 .61428 m
.86113 .61803 L
s
.90628 .61428 m
.90628 .61803 L
s
.00344 .61428 m
.00344 .61803 L
s
.99656 .61428 m
.99656 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0717 m
1 .0717 L
s
.99375 .15964 m
1 .15964 L
s
.99375 .24758 m
1 .24758 L
s
.99375 .33553 m
1 .33553 L
s
.99375 .42347 m
1 .42347 L
s
.99375 .51141 m
1 .51141 L
s
.99375 .59935 m
1 .59935 L
s
.125 Mabswid
.99625 .08929 m
1 .08929 L
s
.99625 .10687 m
1 .10687 L
s
.99625 .12446 m
1 .12446 L
s
.99625 .14205 m
1 .14205 L
s
.99625 .17723 m
1 .17723 L
s
.99625 .19482 m
1 .19482 L
s
.99625 .21241 m
1 .21241 L
s
.99625 .22999 m
1 .22999 L
s
.99625 .26517 m
1 .26517 L
s
.99625 .28276 m
1 .28276 L
s
.99625 .30035 m
1 .30035 L
s
.99625 .31794 m
1 .31794 L
s
.99625 .35311 m
1 .35311 L
s
.99625 .3707 m
1 .3707 L
s
.99625 .38829 m
1 .38829 L
s
.99625 .40588 m
1 .40588 L
s
.99625 .44106 m
1 .44106 L
s
.99625 .45865 m
1 .45865 L
s
.99625 .47623 m
1 .47623 L
s
.99625 .49382 m
1 .49382 L
s
.99625 .529 m
1 .529 L
s
.99625 .54659 m
1 .54659 L
s
.99625 .56418 m
1 .56418 L
s
.99625 .58177 m
1 .58177 L
s
.99625 .05411 m
1 .05411 L
s
.99625 .03652 m
1 .03652 L
s
.99625 .01893 m
1 .01893 L
s
.99625 .00134 m
1 .00134 L
s
.99625 .61694 m
1 .61694 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .0717 m
1 .0717 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .0169 m
.03076 .18428 L
.03837 .31655 L
.04221 .38328 L
.04274 .39249 L
.04332 .40249 L
.04386 .41052 L
.04436 .41455 L
.04632 .43027 L
.05372 .48972 L
.05735 .51888 L
.05785 .52289 L
.0584 .52727 L
.05939 .53227 L
.06036 .53492 L
.06126 .53738 L
.06554 .54913 L
.06956 .56013 L
.07175 .56615 L
.07283 .5691 L
.07382 .57181 L
.07472 .57273 L
.07567 .57343 L
.07768 .57492 L
.08221 .57826 L
.08634 .5813 L
.08815 .58263 L
.08917 .58333 L
.09011 .58354 L
.09368 .58432 L
.09742 .58514 L
.10154 .58605 L
.10325 .58643 L
.10415 .58663 L
.10509 .58673 L
.10683 .58692 L
.10843 .5871 L
.11574 .58791 L
.14524 .59066 L
.17664 .59314 L
.20687 .5952 L
.239 .59705 L
.26995 .59855 L
.29973 .59977 L
.33141 .60083 L
.36192 .60165 L
.39125 .60227 L
.39962 .60245 L
.40375 .60254 L
.40478 .60256 L
Mistroke
.40575 .60259 L
.40663 .6026 L
.40757 .60261 L
.41103 .60264 L
.4147 .60268 L
.42248 .60276 L
.45254 .60306 L
.46054 .60316 L
.46255 .60318 L
.46445 .6032 L
.46615 .60322 L
.46712 .60323 L
.46801 .60323 L
.47177 .60323 L
.47579 .60322 L
.47993 .60322 L
.48094 .60322 L
.48147 .60322 L
.48202 .60321 L
.48264 .60322 L
.48321 .60322 L
.48432 .60323 L
.49173 .60328 L
.49387 .6033 L
.49491 .60331 L
.49588 .60331 L
.49676 .60332 L
.49768 .60332 L
.49861 .60331 L
.49964 .60331 L
.51387 .60323 L
.51789 .60324 L
.52226 .60325 L
.52426 .60325 L
.52536 .60326 L
.52639 .60326 L
.52727 .60326 L
.52821 .60325 L
.53022 .60323 L
.54514 .60308 L
.57524 .60278 L
.57911 .60275 L
.58326 .60272 L
.58527 .60271 L
.58626 .6027 L
.58717 .60269 L
.588 .60268 L
.58888 .60266 L
.59073 .60262 L
.59853 .60245 L
Mistroke
.60706 .6023 L
.63637 .60168 L
.66757 .60085 L
.69761 .59985 L
.72954 .59857 L
.7603 .59707 L
.78988 .59545 L
.82136 .59334 L
.85167 .59097 L
.86715 .58962 L
.88388 .58799 L
.89174 .58709 L
.89604 .58642 L
.90005 .58579 L
.90347 .58526 L
.90446 .5851 L
.90539 .58495 L
.90623 .58457 L
.90714 .58416 L
.91115 .58233 L
.91492 .58062 L
.91842 .57903 L
.91938 .57859 L
.92039 .57813 L
.92126 .57678 L
.9222 .57516 L
.93024 .5613 L
.93233 .55768 L
.93431 .55427 L
.93484 .55335 L
.93541 .55238 L
.93602 .54976 L
.93659 .54657 L
.93867 .53498 L
.94276 .51206 L
.9465 .49112 L
.9483 .48107 L
.94925 .47577 L
.95026 .47012 L
.95123 .46079 L
.9521 .44887 L
.95382 .4256 L
.96167 .31895 L
.96898 .18734 L
.97585 .02283 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`009oooool5o`0000?ooooo0_l0000_ooooo`?o00001?ooool2o`0002oooooo0_l0000boooo
o`?o00001?ooool2o`0002kooooo1Ol00003ooooo`;o00004oooool002Sooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000;Oooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000;_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001;ooooo000Qooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002Oooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000;Ooo
ool01?l0003oooooooooool0000booooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000;oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001;ooooo000Zooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000;Oooool01?l0003oooooooooool0000booooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000<?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool04?ooool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000]
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000]ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Boooo
o`009oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000;_ooool2
o`0000Cooooo00Co0000oooooooooooo0000;Oooool01?l0003oooooooooool0000aooooo`;o0000
1?ooool01?l0003oooooooooool0000]ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Booooo`00:?ooool3o`0000Cooooo0_l0000`ooooo`03o`000?oooooooooo
00?ooooo0_l0000_ooooo`;o0000<oooool00ol0003oooooooooo`03ooooo`;o0000;oooool3o`00
00Cooooo0_l0000Cooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`007_oooooho`0000[ooooo000Nooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?oo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00_oo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
00[ooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00ooooooho`0000[ooooo
000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000:oooo
o`;o00002Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`07ooooo`Go00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool00oooool2o`0000[o
oooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`002_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`07ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo000;ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`;o
00001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool01?ooool2o`0000[ooooo000;ooooo`03o`000?oooooooooo00Sooooo0ol00005ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`002_ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool02?oo
ool3o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`04ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Kooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Kooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`007_ooool2o`0000Kooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo000:ooooo`?o00001?ooool00ol0003ooooooooo
o`02ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03
o`000?oooooooooo00Sooooo1?l00004ooooo`;o00001_ooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool01?ooool2o`0000[ooooo000;ooooo`03o`00
0?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02?ooool000[ooooo0_l00009ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`00
0?oooooooooo00Sooooo0ol00005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool001kooooo0_l00007ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`05ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Oooooo00?o
0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Gooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Oooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`08ooooo`007_ooool2o`0000Oooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo000Eooooo`Go00001?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001Sooooo00?o0000oooo
ooooool00oooool2o`0000Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo00Gooooo0_l0000:ooooo`005Oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`005Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`005_ooool3o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0000Sooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo00Kooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000So
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Ko
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`;o00002?ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool01_ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o00002Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool01oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool000Wooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo
0ol00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000[ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`04ooooo`;o00002Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool01oooool2o`0000[ooooo000<ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`000008
ooooo`;o00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000:oooo
o`?o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool001kooooo0_l00009ooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`08ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
01kooooo0_l0000:ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`08ooooo`;o00002_ooool001kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool001kooooo0_l0000:
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`08
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[oooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000oooooooo
ool0K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`08ooooo`007_ooool2o`0000_ooooo00?o0000ooooooooool0Joooool0
0ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0K?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`Go00000oooool01?l0003o
ooooooooooooool5o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[oooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08oooo
o`002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Cooooo0_l0000<ooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool0Joooool00ol0003oooooooooo`0:ooooo`;o00002_ooool000cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02?ooool000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool0Joooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0009ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`08ooooo`002_ooool3o`0000Wooooo0ol00005oooo
o`;o00003?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool02oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0J_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02?ooool001kooooo0_l0000>ooooo`03o`000?oooooooooo
06Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0<ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0J?ooool2o`0000oooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`08ooooo`007_ooool2o`0000oooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo00gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0001Wooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00004_oo
ool2o`0006Gooooo00?o0000ooooooooool0I?ooool2o`0001;ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`0Cooooo`?o0000H_ooool00ol0003oooooooooo`1Pooooo`Co00005Oooool0
0ol0003oooooooooo`08ooooo`002Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00?o0000ooooooooool05_ooool9o`0005Wooooo00?o0000ooooooooool0E_ooool:o`00
01Wooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool07oooool?o`0004[ooooo00?o0000
ooooooooool0BOooool=o`0002?ooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo3ol0000koooo
o`03o`000?oooooooooo03[ooooo3ol0000`ooooo`03o`000?oooooooooo00Sooooo000<ooooo`03
o`000?oooooooooo00Sooooo0_l00005ooooo`;o0000?_oooolNo`0001gooooo00?o0000oooooooo
ool07?oooolNo`0003kooooo0_l0000:ooooo`002Oooool01Ol0003ooooooooooooooooo000000_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Kooooocco0000GOooool00ol0003o
ooooooooo`08ooooo`002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`08ooooo`002_ooool3o`0000Wooooo0ol00005ooooo`;o00002_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000[o
oooo000NooooooSo00002_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00<co
oooo0ol0001Aooooo`00cOooool00ol0003oooooooooo`1@ooooo`00HOooool00ol0003oooooo`00
0003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool3o`0000?ooooo0ol0
0004ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00008ooooo`Go000000Go
ooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003ooooo`?o00000_ooool3o`000003oooo
ool0003o000000Co00000_ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04oooooo
001Qooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
ooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04oooooo
001Qooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`03o`000?oooooo000000;ooooo1Ol0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`Go00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000D?ooool0063ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`?o00000oooool2o`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001@
ooooo`00H?ooool01Ol0003oooooo`000?oooooo000000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000?ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o
000000;ooooo0ol00002ooooo`Co00000_ooool4o`0000[ooooo00Co0000oooooooooooooooo1?l0
0002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0003o0000
0oooool4o`0000;ooooo0_l000000ooooooo0000o`00001?ooooo`00H?ooool01Ol0003oooooo`00
0?oooooo000001Cooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Fooooo`00
H?ooool6o`0001;ooooo1Ol0000Dooooo`03o`000?oooooooooo00Sooooo1Ol00008ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Fooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-27.6014, 1.56285, 0.17925, \
0.00460055}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0225709 0.0147151 0.0116297 [
[.04858 -0.0125 -9 -9 ]
[.04858 -0.0125 9 0 ]
[.27429 -0.0125 -9 -9 ]
[.27429 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.72571 -0.0125 -6 -9 ]
[.72571 -0.0125 6 0 ]
[.95142 -0.0125 -6 -9 ]
[.95142 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13101 -12 -4.5 ]
[-0.0125 .13101 0 4.5 ]
[-0.0125 .24731 -12 -4.5 ]
[-0.0125 .24731 0 4.5 ]
[-0.0125 .36361 -12 -4.5 ]
[-0.0125 .36361 0 4.5 ]
[-0.0125 .4799 -12 -4.5 ]
[-0.0125 .4799 0 4.5 ]
[-0.0125 .5962 -12 -4.5 ]
[-0.0125 .5962 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04858 0 m
.04858 .00625 L
s
[(-20)] .04858 -0.0125 0 1 Mshowa
.27429 0 m
.27429 .00625 L
s
[(-10)] .27429 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.72571 0 m
.72571 .00625 L
s
[(10)] .72571 -0.0125 0 1 Mshowa
.95142 0 m
.95142 .00625 L
s
[(20)] .95142 -0.0125 0 1 Mshowa
.125 Mabswid
.09372 0 m
.09372 .00375 L
s
.13887 0 m
.13887 .00375 L
s
.18401 0 m
.18401 .00375 L
s
.22915 0 m
.22915 .00375 L
s
.31943 0 m
.31943 .00375 L
s
.36457 0 m
.36457 .00375 L
s
.40972 0 m
.40972 .00375 L
s
.45486 0 m
.45486 .00375 L
s
.54514 0 m
.54514 .00375 L
s
.59028 0 m
.59028 .00375 L
s
.63543 0 m
.63543 .00375 L
s
.68057 0 m
.68057 .00375 L
s
.77085 0 m
.77085 .00375 L
s
.81599 0 m
.81599 .00375 L
s
.86113 0 m
.86113 .00375 L
s
.90628 0 m
.90628 .00375 L
s
.00344 0 m
.00344 .00375 L
s
.99656 0 m
.99656 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13101 m
.00625 .13101 L
s
[(10)] -0.0125 .13101 1 0 Mshowa
0 .24731 m
.00625 .24731 L
s
[(20)] -0.0125 .24731 1 0 Mshowa
0 .36361 m
.00625 .36361 L
s
[(30)] -0.0125 .36361 1 0 Mshowa
0 .4799 m
.00625 .4799 L
s
[(40)] -0.0125 .4799 1 0 Mshowa
0 .5962 m
.00625 .5962 L
s
[(50)] -0.0125 .5962 1 0 Mshowa
.125 Mabswid
0 .03797 m
.00375 .03797 L
s
0 .06123 m
.00375 .06123 L
s
0 .08449 m
.00375 .08449 L
s
0 .10775 m
.00375 .10775 L
s
0 .15427 m
.00375 .15427 L
s
0 .17753 m
.00375 .17753 L
s
0 .20079 m
.00375 .20079 L
s
0 .22405 m
.00375 .22405 L
s
0 .27057 m
.00375 .27057 L
s
0 .29383 m
.00375 .29383 L
s
0 .31709 m
.00375 .31709 L
s
0 .34035 m
.00375 .34035 L
s
0 .38687 m
.00375 .38687 L
s
0 .41013 m
.00375 .41013 L
s
0 .43338 m
.00375 .43338 L
s
0 .45664 m
.00375 .45664 L
s
0 .50316 m
.00375 .50316 L
s
0 .52642 m
.00375 .52642 L
s
0 .54968 m
.00375 .54968 L
s
0 .57294 m
.00375 .57294 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04858 .61178 m
.04858 .61803 L
s
.27429 .61178 m
.27429 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.72571 .61178 m
.72571 .61803 L
s
.95142 .61178 m
.95142 .61803 L
s
.125 Mabswid
.09372 .61428 m
.09372 .61803 L
s
.13887 .61428 m
.13887 .61803 L
s
.18401 .61428 m
.18401 .61803 L
s
.22915 .61428 m
.22915 .61803 L
s
.31943 .61428 m
.31943 .61803 L
s
.36457 .61428 m
.36457 .61803 L
s
.40972 .61428 m
.40972 .61803 L
s
.45486 .61428 m
.45486 .61803 L
s
.54514 .61428 m
.54514 .61803 L
s
.59028 .61428 m
.59028 .61803 L
s
.63543 .61428 m
.63543 .61803 L
s
.68057 .61428 m
.68057 .61803 L
s
.77085 .61428 m
.77085 .61803 L
s
.81599 .61428 m
.81599 .61803 L
s
.86113 .61428 m
.86113 .61803 L
s
.90628 .61428 m
.90628 .61803 L
s
.00344 .61428 m
.00344 .61803 L
s
.99656 .61428 m
.99656 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13101 m
1 .13101 L
s
.99375 .24731 m
1 .24731 L
s
.99375 .36361 m
1 .36361 L
s
.99375 .4799 m
1 .4799 L
s
.99375 .5962 m
1 .5962 L
s
.125 Mabswid
.99625 .03797 m
1 .03797 L
s
.99625 .06123 m
1 .06123 L
s
.99625 .08449 m
1 .08449 L
s
.99625 .10775 m
1 .10775 L
s
.99625 .15427 m
1 .15427 L
s
.99625 .17753 m
1 .17753 L
s
.99625 .20079 m
1 .20079 L
s
.99625 .22405 m
1 .22405 L
s
.99625 .27057 m
1 .27057 L
s
.99625 .29383 m
1 .29383 L
s
.99625 .31709 m
1 .31709 L
s
.99625 .34035 m
1 .34035 L
s
.99625 .38687 m
1 .38687 L
s
.99625 .41013 m
1 .41013 L
s
.99625 .43338 m
1 .43338 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .50316 m
1 .50316 L
s
.99625 .52642 m
1 .52642 L
s
.99625 .54968 m
1 .54968 L
s
.99625 .57294 m
1 .57294 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .30605 Mdot
.05478 .46627 Mdot
.0857 .56058 Mdot
.11656 .60238 Mdot
.14737 .60332 Mdot
.17815 .57351 Mdot
.20889 .52172 Mdot
.2396 .45558 Mdot
.27029 .38161 Mdot
.30095 .30543 Mdot
.3316 .23178 Mdot
.36224 .1646 Mdot
.39286 .10711 Mdot
.42348 .06183 Mdot
.45409 .03062 Mdot
.4847 .01472 Mdot
.5153 .01472 Mdot
.54591 .03062 Mdot
.57652 .06183 Mdot
.60714 .10711 Mdot
.63776 .1646 Mdot
.6684 .23178 Mdot
.69905 .30543 Mdot
.72971 .38161 Mdot
.7604 .45558 Mdot
.79111 .52172 Mdot
.82185 .57351 Mdot
.85263 .60332 Mdot
.88344 .60238 Mdot
.9143 .56058 Mdot
.94522 .46627 Mdot
.97619 .30605 Mdot
.5 Mabswid
.02381 .30605 m
.03837 .38137 L
.04579 .41973 L
.04987 .44082 L
.05372 .46077 L
.05574 .4692 L
.05794 .4759 L
.06178 .48761 L
.06929 .51052 L
.0774 .53528 L
.08171 .54841 L
.08408 .55566 L
.08465 .55739 L
.08525 .55923 L
.08582 .56075 L
.08634 .56145 L
.08832 .56413 L
.09048 .56706 L
.09427 .57219 L
.1017 .58225 L
.11018 .59374 L
.1139 .59878 L
.11492 .60016 L
.11548 .60092 L
.11601 .60164 L
.1165 .60231 L
.11704 .6024 L
.11798 .60243 L
.12523 .60265 L
.13288 .60288 L
.13694 .603 L
.14125 .60313 L
.14494 .60324 L
.14594 .60328 L
.14647 .60329 L
.14703 .60331 L
.14752 .60317 L
.14806 .60265 L
.149 .60174 L
.16545 .5858 L
.17323 .57827 L
.1804 .56971 L
.18786 .55714 L
.19595 .54352 L
.21063 .51797 L
.24114 .45187 L
.27047 .38116 L
.3017 .30364 L
.33176 .23144 L
.36371 .16183 L
Mistroke
.39449 .1047 L
.41003 .08172 L
.4168 .07172 L
.4241 .0612 L
.43197 .05318 L
.43936 .04564 L
.44711 .03774 L
.45122 .03355 L
.4523 .03245 L
.45348 .03125 L
.45401 .0307 L
.45459 .03037 L
.45561 .02983 L
.4598 .02766 L
.46362 .02567 L
.47108 .02179 L
.47894 .01771 L
.48109 .01659 L
.48226 .01598 L
.48335 .01541 L
.48429 .01493 L
.48528 .01472 L
.48585 .01472 L
.48639 .01472 L
.4874 .01472 L
.49465 .01472 L
.5025 .01472 L
.50608 .01472 L
.50987 .01472 L
.51311 .01472 L
.514 .01472 L
.51495 .01472 L
.51584 .015 L
.51666 .01542 L
.53267 .02374 L
.53971 .0274 L
.54345 .02935 L
.54447 .02987 L
.54541 .03037 L
.5464 .03113 L
.54749 .03223 L
.55135 .03617 L
.55489 .03978 L
.56186 .04688 L
.56918 .05435 L
.57714 .06274 L
.58527 .07477 L
.59295 .08614 L
.60734 .10749 L
.63899 .1673 L
Mistroke
.66947 .23436 L
.69878 .30479 L
.72999 .38227 L
.76002 .45465 L
.79195 .52313 L
.8079 .55001 L
.81567 .56309 L
.81934 .56926 L
.82094 .57197 L
.82271 .57433 L
.82443 .576 L
.82625 .57777 L
.83008 .58148 L
.83703 .58821 L
.84502 .59594 L
.8488 .59961 L
.85046 .60122 L
.8514 .60213 L
.85229 .60299 L
.85316 .6033 L
.8541 .60327 L
.85601 .60322 L
.86006 .60309 L
.86741 .60287 L
.87153 .60274 L
.87586 .60261 L
.87956 .6025 L
.88057 .60247 L
.88165 .60244 L
.88268 .60241 L
.8836 .60216 L
.88453 .60091 L
.88539 .59974 L
.88736 .59707 L
.89134 .59169 L
.89847 .58203 L
.90673 .57083 L
.9108 .56532 L
.91278 .56264 L
.91371 .56138 L
.91457 .55975 L
.91548 .557 L
.91645 .55402 L
.91822 .54864 L
.92209 .53681 L
.93029 .5118 L
.93723 .49065 L
.94104 .47901 L
.94291 .47329 L
.94465 .46801 L
Mistroke
.94557 .46445 L
.94654 .4594 L
.94861 .44873 L
.95221 .43009 L
.95926 .39362 L
.97527 .3108 L
.97619 .30605 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`009?ooool5o`0000?ooooo0_l0000_ooooo`?o00001?ooool2o`0002oooooo0_l0000boooo
o`?o00001?ooool2o`0002kooooo1Ol00003ooooo`;o00005_ooool002Gooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000;Oooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000;_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001Gooooo000Nooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002Oooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000;Ooo
ool01?l0003oooooooooool0000booooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000;oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Gooooo000Wooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000;Oooool01?l0003oooooooooool0000booooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000<?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool04oooool002Cooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000]
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000]ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Eoooo
o`009?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000;_ooool2
o`0000Cooooo00Co0000oooooooooooo0000;Oooool01?l0003oooooooooool0000aooooo`;o0000
1?ooool01?l0003oooooooooool0000]ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Eooooo`009Oooool3o`0000Cooooo0_l0000`ooooo`03o`000?oooooooooo
00?ooooo0_l0000_ooooo`;o0000<oooool00ol0003oooooooooo`03ooooo`;o0000;oooool3o`00
00Cooooo0_l0000Fooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`006ooooooho`0000gooooo000Dooooo`;o00001Oooool2o`0000[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0_l0000=ooooo`00
4oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004ooooo`;o
0000MOooool;o`0007Cooooo0_l0000=ooooo`004oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo07;ooooo1?l00002ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`00
0?ooool0Loooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo073ooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`;o0000LOooool00ol0003oooooooooo`0;ooooo`005?ooool2o`0000Gooooo00?o0000oooooooo
ool0K?ooool3o`0000Wooooo00?o0000ooooooooool02?ooool2o`0006oooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0K?ooool2o`0000[ooooo00?o0000ooooooooool0
2?ooool2o`0006oooooo00?o0000ooooooooool02oooool001_ooooo0_l0001/ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool2o`0006cooooo0_l0000=ooooo`006oooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0JOooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool02oooool001_ooooo0_l0001V
ooooo`;o00004Oooool00ol0003oooooooooo`0@ooooo`;o0000I_ooool2o`0000gooooo000Koooo
o`03o`000?oooooooooo06Gooooo0_l0000Aooooo`03o`000?oooooooooo013ooooo0_l0001Woooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool02oooool001_ooooo0_l0001Sooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Qooooo`;o00003Oooool001_o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0;
ooooo`006oooool2o`0005kooooo0_l0000Iooooo`03o`000?oooooooooo01Oooooo0_l0001Ooooo
o`;o00003Oooool001_ooooo00?o0000ooooooooool0GOooool2o`0001Wooooo00?o0000oooooooo
ool05oooool2o`00063ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`0;ooooo`003_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0;ooooo`003_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001Looooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Jooooo`;o00003Oooool0
00kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool02oooool000kooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool02oooool0
00gooooo0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0;ooooo`003_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05So
oooo00?o0000ooooooooool02oooool001_ooooo0_l0001Iooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Gooooo`;o00003Oooool001_ooooo00?o
0000ooooooooool0F?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0Eoooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1F
ooooo`;o00008?ooool00ol0003oooooooooo`0Oooooo`;o0000F?ooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`1Fooooo`;o00008?ooool00ol0003oooooooooo`0Ooooo
o`;o0000F?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
2oooool001_ooooo0_l0001Fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`1Dooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`006oooool2o`0005Cooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05;ooooo0_l0
000=ooooo`006oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo05;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool0D_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0D_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool02ooo
ool001_ooooo0_l0001Aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1?ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1>ooooo`;o0000:?ooool00ol0003o
ooooooooo`0Vooooo`;o0000DOooool00ol0003oooooooooo`0;ooooo`003?ooool5o`0000?ooooo
0_l00005ooooo`03o`000?oooooooooo04kooooo0_l0000Xooooo`03o`000?oooooooooo02Kooooo
0_l0001Aooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00_o
oooo000>ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo00_ooooo000?ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`02ooooo`;o0000C_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0COooool2o`0000gooooo000<ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool02oooool000cooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0;
ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool02oooool001_ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o0000C?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0B_oo
ool2o`0000gooooo000Kooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool02oooool0
01_ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool02oooool001_ooooo0_l0001:ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`18ooooo`;o00003Oooool001_ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00;ooooo0_l00013ooooo`;o
0000;oooool00ol0003oooooooooo`0^ooooo`;o0000@_ooool2o`0000Gooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool00_ooool2o`0004?ooooo0_l0000_ooooo`03o`00
0?oooooooooo02kooooo0_l00012ooooo`;o00001Oooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0;ooooo`006oooool2o`0000Cooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`02ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool001_ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool001_ooooo0_l00005oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool00oooool2o`0000gooooo000Kooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo000=ooooo`?o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02oooool000cooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool0013ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo
000>ooooo`;o00000oooool01?l0003oooooooooool00004ooooo`;o00001_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`004?ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool000cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Kooooo0_l0000gooooo`03o`000?oo
oooooooo03Kooooo0_l0000hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool001_ooooo0_l00007ooooo`03o`000?oooooooooo03Kooooo0_l0000gooooo`03o`000?oooooo
oooo03Kooooo0_l0000gooooo`03o`000?oooooooooo00Kooooo0_l0000=ooooo`006oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;
ooooo`006oooool2o`0000Sooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07oooo
o`;o00003Oooool001_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool0
01_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool001_ooooo0_l0000:ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool02?ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0:_ooool3o`0003kooooo00?o0000ooooooooool0?Oooool2o`0002gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`006oooool2o`0000_ooooo00?o0000ooooooooool0
:_ooool2o`0003oooooo00?o0000ooooooooool0?Oooool2o`0002gooooo00?o0000ooooooooool0
2Oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo00[ooooo0_l0000[ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Yooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`003_ooool3o`00
00?ooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo0_l0000[ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Xooooo`;o00003?ooool00ol0
003oooooooooo`0;ooooo`003oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`003?ooool5o`0000;ooooo00Co0000oooooooo
oooo00001?ooool2o`0000cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;oooo
o`;o00003Oooool000cooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo000=ooooo`03o`000?oooooo000000?ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000?ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`003oooool00ol0003oooooooooo`02oooo
o`;o00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`00
6oooool2o`0000kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0<ooooo`;o0000
3Oooool001_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool0
01_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Nooooo`;o0000A_ooool00ol0003oooooooooo`15ooooo`;o00008?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool07_ooool2o`0004Kooooo00?o0000ooooooooool0AOooool2o`00023ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`006oooool2o`00013ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0>ooooo`;o00003Oooool001_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool02oooool001_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02ooo
ool001_ooooo0_l0000Booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool2
o`0000gooooo000Kooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo017o
oooo0_l0000Hooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`0Eooooo`;o00005?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooo
ooooo`0Aooooo`?o00005_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool05?ooool2o`0001Cooooo00?o0000ooooooooool02oooool001_ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool02oooool001_ooooo0_l0000Eooooo`03o`000?oooooooooo017ooooo0_l0001>
ooooo`03o`000?oooooooooo04cooooo0_l0000Dooooo`03o`000?oooooooooo01?ooooo0_l0000=
ooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo0_l0001>oooo
o`03o`000?oooooooooo04cooooo0ol0000Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02oooool001_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?ooooo`;o
0000Coooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`003Ooo
ool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo000<ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo
000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0001Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`;o00003Oooool0013ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo
0_l00006ooooo`;o0000EOooool00ol0003oooooooooo`1Dooooo`;o00001_ooool2o`0001_ooooo
00?o0000ooooooooool02oooool000cooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool06Oooool:o`0005Gooooo00?o0000ooooooooool0E?ooool:o`0001_ooooo
00?o0000ooooooooool02oooool000cooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003ooooo
ooooo`0;ooooo`003?ooool5o`0000?ooooo0_l00005ooooo`;o00002_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000gooooo000K
ooooooSo00003Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool002gooooo0ol0
002:ooooo`03o`000?oooooooooo02_ooooo0ol0000Eooooo`03o`000?oooooooooo01gooooo000^
ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01cooooo000Xooooo`?o00000oooool3o`0000Cooooo0_l00002oooo
o`Go00000_ooool3o`0000?ooooo1?l000000ooooooo0000o`000003o`0000Oooooo0ol00004oooo
o`Co00000oooool2o`0000;ooooo1_l00006ooooo`Co00000_ooool5o`000003ooooool0003o0000
00?o000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool3o`0000Cooooo0ol00002oooo
o`?o000000Coooooo`000?l0003ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol00002
ooooo`Go00000_ooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l0
0002ooooo`[o00001Oooool00ol0003oooooooooo`0Kooooo`009oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000cooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Kooooo`009oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool3
o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`?o00000oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
oooo1Ol00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`00
0?oooooo00001Oooool5o`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oo
oooo000000;ooooo0ol00003ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`04o`000?oo
ooooooooooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00002ooooo`?o00001Oooool00ol0003ooooooooo
o`0Kooooo`009oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool3o`0000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?ooooooooooooooool0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0000Gooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooo
oooo01_ooooo000Wooooo`06o`000?ooooooooooooooool0003ooooo1?l00002ooooo`Co00000_oo
ool3o`0000Cooooo0ol00003ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?oo
ooooooooo`0000;ooooo0_l00003ooooo`Co00000oooool3o`0000Wooooo00Go0000oooooooooooo
0000ooooo`03o`0000Cooooo1?l00002ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`?o00000_ooool4o`0000?ooooo0ol00003ooooo`?o00002Oooool00ol0003o
ooooooooo`02ooooo`Ko000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o
oooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Co00000oooool9o`0000?o
oooo0ol00003ooooo`Co00001?ooool00ol0003oooooooooo`0Kooooo`009oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool002Sooooo0ol00009oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool3o`0000Wooooo1?l00009oooo
o`03o`000?oooooooooo00;ooooo0_l0000:ooooo`Co00001?ooool00ol0003oooooooooo`04oooo
o`;o00001?ooool2o`0002kooooo00?o0000ooooooooool06?ooool3o`0001Kooooo00?o0000oooo
ooooool00_ooool2o`0000_ooooo00?o0000ooooooooool07Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-27.0636, -5.47142, 0.17925, \
0.347889}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] 0.49966958432041564`\), 
        ",", \(BackFocalLength \[Rule] 93.35095557506479`\), 
        ",", \(BackFocalPoint \[Rule] {153.3509555750648`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] 0\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {60.`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 2\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 2, 
            SurfaceNumber \[Rule] 2, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] False\), 
        ",", \(FindPupils \[Rule] False\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 99.93396050505237`\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {150.`, 0.`, 0.`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[100, 50, 10], 50.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[Screen[50], {x, 150.`}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.9341264481391712`, 
              6.583004929987581`}, {\(-0.010006608313591684`\), 
              0.9999999999999998`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(LineOfRays[45, NumberOfRays \[Rule] 11]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 65.20828852147574`\), ",", 
        RowBox[{"OpticalLengthFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-21.097513133117054`\), 
                  21.097513133117054`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-21.097513133117054`\), 
                  21.097513133117054`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {65.20828852147574`, 
            65.23521414537726`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), 
        ",", \(Plot2D \[Rule] True\), ",", \(PlotPoints \[Rule] 32\), 
        ",", \(RayBoundary \[Rule] {\(-21.097513133117054`\), 
            21.097513133117054`}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] True\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 2190\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{0.033531699915919685`, 
              98.25958992578354`}, {\(-0.010006608313591682`\), 
              0.49966958432041564`}}\), 
        ",", \(TransverseMagnification \[Rule] 0.033531699915919685`\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-26.243763648517525`\), 
                  25.99769744301042`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[20]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
PSF[sys, NumberOfPoints->2048, NumberOfRays->256, FocalFraction->0]\
\>", "Input",
  CellLabel->"In[26]:=",
  CellTags->{"AOG5.3", "AOG5.", "AOG0."}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0209743 -445.395 7.60785 [
[.08051 -0.0125 -9 -9 ]
[.08051 -0.0125 9 0 ]
[.29026 -0.0125 -9 -9 ]
[.29026 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70974 -0.0125 -6 -9 ]
[.70974 -0.0125 6 0 ]
[.91949 -0.0125 -6 -9 ]
[.91949 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12084 -30 -4.5 ]
[-0.0125 .12084 0 4.5 ]
[-0.0125 .273 -30 -4.5 ]
[-0.0125 .273 0 4.5 ]
[-0.0125 .42516 -24 -4.5 ]
[-0.0125 .42516 0 4.5 ]
[-0.0125 .57731 -30 -4.5 ]
[-0.0125 .57731 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08051 0 m
.08051 .00625 L
s
[(-20)] .08051 -0.0125 0 1 Mshowa
.29026 0 m
.29026 .00625 L
s
[(-10)] .29026 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70974 0 m
.70974 .00625 L
s
[(10)] .70974 -0.0125 0 1 Mshowa
.91949 0 m
.91949 .00625 L
s
[(20)] .91949 -0.0125 0 1 Mshowa
.125 Mabswid
.12246 0 m
.12246 .00375 L
s
.16441 0 m
.16441 .00375 L
s
.20636 0 m
.20636 .00375 L
s
.24831 0 m
.24831 .00375 L
s
.33221 0 m
.33221 .00375 L
s
.37415 0 m
.37415 .00375 L
s
.4161 0 m
.4161 .00375 L
s
.45805 0 m
.45805 .00375 L
s
.54195 0 m
.54195 .00375 L
s
.5839 0 m
.5839 .00375 L
s
.62585 0 m
.62585 .00375 L
s
.66779 0 m
.66779 .00375 L
s
.75169 0 m
.75169 .00375 L
s
.79364 0 m
.79364 .00375 L
s
.83559 0 m
.83559 .00375 L
s
.87754 0 m
.87754 .00375 L
s
.03857 0 m
.03857 .00375 L
s
.96143 0 m
.96143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12084 m
.00625 .12084 L
s
[(58.56)] -0.0125 .12084 1 0 Mshowa
0 .273 m
.00625 .273 L
s
[(58.58)] -0.0125 .273 1 0 Mshowa
0 .42516 m
.00625 .42516 L
s
[(58.6)] -0.0125 .42516 1 0 Mshowa
0 .57731 m
.00625 .57731 L
s
[(58.62)] -0.0125 .57731 1 0 Mshowa
.125 Mabswid
0 .15888 m
.00375 .15888 L
s
0 .19692 m
.00375 .19692 L
s
0 .23496 m
.00375 .23496 L
s
0 .31104 m
.00375 .31104 L
s
0 .34908 m
.00375 .34908 L
s
0 .38712 m
.00375 .38712 L
s
0 .4632 m
.00375 .4632 L
s
0 .50124 m
.00375 .50124 L
s
0 .53927 m
.00375 .53927 L
s
0 .0828 m
.00375 .0828 L
s
0 .04476 m
.00375 .04476 L
s
0 .00673 m
.00375 .00673 L
s
0 .61535 m
.00375 .61535 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08051 .61178 m
.08051 .61803 L
s
.29026 .61178 m
.29026 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.70974 .61178 m
.70974 .61803 L
s
.91949 .61178 m
.91949 .61803 L
s
.125 Mabswid
.12246 .61428 m
.12246 .61803 L
s
.16441 .61428 m
.16441 .61803 L
s
.20636 .61428 m
.20636 .61803 L
s
.24831 .61428 m
.24831 .61803 L
s
.33221 .61428 m
.33221 .61803 L
s
.37415 .61428 m
.37415 .61803 L
s
.4161 .61428 m
.4161 .61803 L
s
.45805 .61428 m
.45805 .61803 L
s
.54195 .61428 m
.54195 .61803 L
s
.5839 .61428 m
.5839 .61803 L
s
.62585 .61428 m
.62585 .61803 L
s
.66779 .61428 m
.66779 .61803 L
s
.75169 .61428 m
.75169 .61803 L
s
.79364 .61428 m
.79364 .61803 L
s
.83559 .61428 m
.83559 .61803 L
s
.87754 .61428 m
.87754 .61803 L
s
.03857 .61428 m
.03857 .61803 L
s
.96143 .61428 m
.96143 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12084 m
1 .12084 L
s
.99375 .273 m
1 .273 L
s
.99375 .42516 m
1 .42516 L
s
.99375 .57731 m
1 .57731 L
s
.125 Mabswid
.99625 .15888 m
1 .15888 L
s
.99625 .19692 m
1 .19692 L
s
.99625 .23496 m
1 .23496 L
s
.99625 .31104 m
1 .31104 L
s
.99625 .34908 m
1 .34908 L
s
.99625 .38712 m
1 .38712 L
s
.99625 .4632 m
1 .4632 L
s
.99625 .50124 m
1 .50124 L
s
.99625 .53927 m
1 .53927 L
s
.99625 .0828 m
1 .0828 L
s
.99625 .04476 m
1 .04476 L
s
.99625 .00673 m
1 .00673 L
s
.99625 .61535 m
1 .61535 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .12084 m
1 .12084 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .01472 Mdot
.02762 .03412 Mdot
.03143 .05301 Mdot
.03524 .0714 Mdot
.03904 .08929 Mdot
.04285 .10671 Mdot
.04665 .12365 Mdot
.05045 .14012 Mdot
.05424 .15615 Mdot
.05804 .17173 Mdot
.06183 .18688 Mdot
.06562 .20161 Mdot
.06941 .21592 Mdot
.0732 .22983 Mdot
.07698 .24334 Mdot
.08077 .25646 Mdot
.08455 .26921 Mdot
.08833 .28158 Mdot
.09211 .29359 Mdot
.09589 .30524 Mdot
.09966 .31655 Mdot
.10344 .32752 Mdot
.10721 .33816 Mdot
.11098 .34847 Mdot
.11475 .35847 Mdot
.11852 .36816 Mdot
.12228 .37755 Mdot
.12605 .38664 Mdot
.12981 .39545 Mdot
.13357 .40398 Mdot
.13733 .41223 Mdot
.14109 .42021 Mdot
.14485 .42793 Mdot
.1486 .4354 Mdot
.15236 .44261 Mdot
.15611 .44959 Mdot
.15987 .45633 Mdot
.16362 .46284 Mdot
.16737 .46912 Mdot
.17112 .47518 Mdot
.17486 .48103 Mdot
.17861 .48668 Mdot
.18235 .49211 Mdot
.1861 .49736 Mdot
.18984 .50241 Mdot
.19358 .50727 Mdot
.19732 .51195 Mdot
.20106 .51645 Mdot
.2048 .52078 Mdot
.20854 .52495 Mdot
.21228 .52895 Mdot
.21601 .53279 Mdot
.21975 .53648 Mdot
.22348 .54001 Mdot
.22721 .54341 Mdot
.23095 .54666 Mdot
.23468 .54978 Mdot
.23841 .55276 Mdot
.24214 .55561 Mdot
.24587 .55834 Mdot
.24959 .56095 Mdot
.25332 .56345 Mdot
.25705 .56582 Mdot
.26077 .56809 Mdot
.2645 .57026 Mdot
.26822 .57232 Mdot
.27194 .57428 Mdot
.27566 .57614 Mdot
.27939 .57792 Mdot
.28311 .5796 Mdot
.28683 .5812 Mdot
.29055 .58271 Mdot
.29427 .58415 Mdot
.29798 .58551 Mdot
.3017 .58679 Mdot
.30542 .588 Mdot
.30913 .58915 Mdot
.31285 .59022 Mdot
.31656 .59124 Mdot
.32028 .59219 Mdot
.32399 .59309 Mdot
.32771 .59393 Mdot
.33142 .59472 Mdot
.33513 .59545 Mdot
.33884 .59614 Mdot
.34256 .59678 Mdot
.34627 .59738 Mdot
.34998 .59793 Mdot
.35369 .59845 Mdot
.3574 .59892 Mdot
.36111 .59936 Mdot
.36481 .59977 Mdot
.36852 .60015 Mdot
.37223 .60049 Mdot
.37594 .6008 Mdot
.37965 .60109 Mdot
.38335 .60135 Mdot
.38706 .60159 Mdot
.39076 .60181 Mdot
.39447 .602 Mdot
.39818 .60218 Mdot
.40188 .60234 Mdot
.40559 .60248 Mdot
.40929 .6026 Mdot
.413 .60271 Mdot
.4167 .60281 Mdot
.4204 .60289 Mdot
.42411 .60297 Mdot
.42781 .60303 Mdot
.43151 .60308 Mdot
.43522 .60313 Mdot
.43892 .60317 Mdot
.44262 .6032 Mdot
.44633 .60323 Mdot
.45003 .60325 Mdot
.45373 .60327 Mdot
.45743 .60328 Mdot
.46113 .60329 Mdot
.46484 .6033 Mdot
.46854 .60331 Mdot
.47224 .60331 Mdot
.47594 .60332 Mdot
.47964 .60332 Mdot
.48334 .60332 Mdot
.48705 .60332 Mdot
.49075 .60332 Mdot
.49445 .60332 Mdot
.49815 .60332 Mdot
.50185 .60332 Mdot
.50555 .60332 Mdot
.50925 .60332 Mdot
.51295 .60332 Mdot
.51666 .60332 Mdot
.52036 .60332 Mdot
.52406 .60332 Mdot
.52776 .60331 Mdot
.53146 .60331 Mdot
.53516 .6033 Mdot
.53887 .60329 Mdot
.54257 .60328 Mdot
.54627 .60327 Mdot
.54997 .60325 Mdot
.55367 .60323 Mdot
.55738 .6032 Mdot
.56108 .60317 Mdot
.56478 .60313 Mdot
.56849 .60308 Mdot
.57219 .60303 Mdot
.57589 .60297 Mdot
.5796 .60289 Mdot
.5833 .60281 Mdot
.587 .60271 Mdot
.59071 .6026 Mdot
.59441 .60248 Mdot
.59812 .60234 Mdot
.60182 .60218 Mdot
.60553 .602 Mdot
.60924 .60181 Mdot
.61294 .60159 Mdot
.61665 .60135 Mdot
.62035 .60109 Mdot
.62406 .6008 Mdot
.62777 .60049 Mdot
.63148 .60015 Mdot
.63519 .59977 Mdot
.63889 .59936 Mdot
.6426 .59892 Mdot
.64631 .59845 Mdot
.65002 .59793 Mdot
.65373 .59738 Mdot
.65744 .59678 Mdot
.66116 .59614 Mdot
.66487 .59545 Mdot
.66858 .59472 Mdot
.67229 .59393 Mdot
.67601 .59309 Mdot
.67972 .59219 Mdot
.68344 .59124 Mdot
.68715 .59022 Mdot
.69087 .58915 Mdot
.69458 .588 Mdot
.6983 .58679 Mdot
.70202 .58551 Mdot
.70573 .58415 Mdot
.70945 .58271 Mdot
.71317 .5812 Mdot
.71689 .5796 Mdot
.72061 .57792 Mdot
.72434 .57614 Mdot
.72806 .57428 Mdot
.73178 .57232 Mdot
.7355 .57026 Mdot
.73923 .56809 Mdot
.74295 .56582 Mdot
.74668 .56345 Mdot
.75041 .56095 Mdot
.75413 .55834 Mdot
.75786 .55561 Mdot
.76159 .55276 Mdot
.76532 .54978 Mdot
.76905 .54666 Mdot
.77279 .54341 Mdot
.77652 .54001 Mdot
.78025 .53648 Mdot
.78399 .53279 Mdot
.78772 .52895 Mdot
.79146 .52495 Mdot
.7952 .52078 Mdot
.79894 .51645 Mdot
.80268 .51195 Mdot
.80642 .50727 Mdot
.81016 .50241 Mdot
.8139 .49736 Mdot
.81765 .49211 Mdot
.82139 .48668 Mdot
.82514 .48103 Mdot
.82888 .47518 Mdot
.83263 .46912 Mdot
.83638 .46284 Mdot
.84013 .45633 Mdot
.84389 .44959 Mdot
.84764 .44261 Mdot
.8514 .4354 Mdot
.85515 .42793 Mdot
.85891 .42021 Mdot
.86267 .41223 Mdot
.86643 .40398 Mdot
.87019 .39545 Mdot
.87395 .38664 Mdot
.87772 .37755 Mdot
.88148 .36816 Mdot
.88525 .35847 Mdot
.88902 .34847 Mdot
.89279 .33816 Mdot
.89656 .32752 Mdot
.90034 .31655 Mdot
.90411 .30524 Mdot
.90789 .29359 Mdot
.91167 .28158 Mdot
.91545 .26921 Mdot
.91923 .25646 Mdot
.92302 .24334 Mdot
.9268 .22983 Mdot
.93059 .21592 Mdot
.93438 .20161 Mdot
.93817 .18688 Mdot
.94196 .17173 Mdot
.94576 .15615 Mdot
.94955 .14012 Mdot
.95335 .12365 Mdot
.95715 .10671 Mdot
.96096 .08929 Mdot
.96476 .0714 Mdot
.96857 .05301 Mdot
.97238 .03412 Mdot
.97619 .01472 Mdot
.5 Mabswid
.02381 .01472 m
.03853 .08687 L
.05458 .15753 L
.06965 .21682 L
.08415 .26786 L
.09958 .31632 L
.11444 .35765 L
.13023 .3964 L
.14544 .4291 L
.16007 .45669 L
.17564 .4822 L
.19063 .50343 L
.20504 .52105 L
.22039 .53709 L
.23516 .55016 L
.25087 .5618 L
.26599 .57109 L
.28054 .57844 L
.29603 .58479 L
.31093 .58967 L
.32678 .59372 L
.34204 .59669 L
.35672 .59884 L
.36417 .5997 L
.37234 .6005 L
.38739 .60161 L
.39482 .60202 L
.40279 .60237 L
.41088 .60265 L
.41854 .60285 L
.42613 .603 L
.43315 .60311 L
.44026 .60318 L
.4443 .60322 L
.4481 .60324 L
.45185 .60326 L
.45579 .60328 L
.45916 .60329 L
.46284 .6033 L
.46676 .60331 L
.47031 .60331 L
.47127 .60331 L
.47179 .60331 L
.47228 .60331 L
.47254 .60331 L
.47281 .60331 L
.47339 .60331 L
.47442 .60331 L
.47539 .60331 L
.47643 .60332 L
Mistroke
.47829 .60332 L
.47925 .60332 L
.48028 .60332 L
.48215 .60332 L
.48271 .60332 L
.48302 .60332 L
.4833 .60332 L
.48355 .60332 L
.48381 .60332 L
.48436 .60332 L
.48636 .60332 L
.48684 .60332 L
.48708 .60332 L
.48735 .60332 L
.48791 .60332 L
.48842 .60332 L
.48936 .60332 L
.48985 .60332 L
.49037 .60332 L
.49084 .60332 L
.4911 .60332 L
.49135 .60332 L
.49225 .60332 L
.49311 .60332 L
.49402 .60332 L
.4945 .60332 L
.49477 .60332 L
.49502 .60332 L
.49595 .60332 L
.49704 .60332 L
.49752 .60332 L
.49777 .60332 L
.49804 .60332 L
.49853 .60332 L
.49898 .60332 L
.49987 .60332 L
.50081 .60332 L
.5013 .60332 L
.50158 .60332 L
.50183 .60332 L
.50226 .60332 L
.50273 .60332 L
.50356 .60332 L
.5044 .60332 L
.50481 .60332 L
.50519 .60332 L
.50565 .60332 L
.50614 .60332 L
.50699 .60332 L
.50799 .60332 L
Mistroke
.50843 .60332 L
.50891 .60332 L
.50939 .60332 L
.50982 .60332 L
.51069 .60332 L
.51169 .60332 L
.51213 .60332 L
.5126 .60332 L
.51305 .60332 L
.51346 .60332 L
.51427 .60332 L
.51605 .60332 L
.51651 .60332 L
.51699 .60332 L
.51787 .60332 L
.51987 .60332 L
.52096 .60332 L
.52199 .60332 L
.52298 .60332 L
.52347 .60332 L
.52391 .60332 L
.52432 .60331 L
.52475 .60331 L
.52566 .60331 L
.52666 .60331 L
.52759 .60331 L
.5285 .60331 L
.52946 .60331 L
.5315 .60331 L
.53518 .6033 L
.53852 .60329 L
.54233 .60328 L
.54583 .60327 L
.54969 .60325 L
.55376 .60323 L
.55736 .6032 L
.56122 .60317 L
.5682 .60309 L
.57627 .60296 L
.58393 .60279 L
.5915 .60257 L
.59851 .60232 L
.61344 .60156 L
.62162 .60099 L
.62931 .60035 L
.64403 .59874 L
.65967 .59639 L
.67474 .59337 L
.68924 .58962 L
.70466 .58454 L
Mistroke
.71951 .57842 L
.7353 .57037 L
.7505 .56088 L
.76513 .54993 L
.7807 .53604 L
.79568 .52022 L
.81009 .50249 L
.82543 .48057 L
.8402 .45621 L
.8559 .42639 L
.87102 .3935 L
.88557 .35764 L
.90105 .31443 L
.91595 .26753 L
.93178 .21141 L
.94704 .15072 L
.96172 .08569 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00=Oooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00005Oooool003Kooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001Cooooo000_ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Cooooo000hooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool04_ooool003Gooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Doooo
o`00=Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Dooooo`00=_ooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Eooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`009?oooooho`0000Cooooo000Tooooo`;o00001oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Gooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool00_oo
ool2o`0007Cooooo00?o0000ooooooooool0L_ooool2o`0000Gooooo00?o0000ooooooooool00_oo
ool002Cooooo00?o0000ooooooooool00_ooool2o`0007Cooooo00?o0000ooooooooool0L_ooool2
o`0000Gooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo000Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool002Cooooo00?o
0000ooooooooool00oooool2o`0007?ooooo00?o0000ooooooooool0L_ooool2o`0000Gooooo00?o
0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool00oooool2o`0007?ooooo00?o0000
ooooooooool0L_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`009?ooool2o`0000Gooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`00
9?ooool00ol0003oooooooooo`04ooooo`;o0000L_ooool00ol0003oooooooooo`1aooooo`;o0000
1_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`04ooooo`;o0000L_oo
ool00ol0003oooooooooo`1aooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`009?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`009?ooool00ol0003oooooooooo`05ooooo`;o0000LOooool00ol0003ooooo
ooooo`1`ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooooooo
o`05ooooo`;o0000LOooool00ol0003oooooooooo`1`ooooo`;o00001oooool00ol0003ooooooooo
o`02ooooo`009?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo000Toooo
o`;o00001oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool01Oooool2o`0000Cooooo000Tooooo`03o`000?oooooooooo00Kooooo0_l0001`ooooo`03
o`000?oooooooooo06oooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`00
0?oooooooooo00Kooooo0_l0001`ooooo`03o`000?oooooooooo06oooooo0_l00008ooooo`03o`00
0?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Kooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool002Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0Koooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo00Oo
oooo0_l0001_ooooo`03o`000?oooooooooo06kooooo0_l00009ooooo`03o`000?oooooooooo00;o
oooo0004ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo
0ol00005ooooo`03o`000?oooooooooo00Oooooo0_l0001_ooooo`03o`000?oooooooooo06kooooo
0_l00009ooooo`03o`000?oooooooooo00;ooooo0003ooooo`07o`000?ooooooooooooooool0003o
ooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooooooooooooooo`000?oooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00;ooooo0007ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`02ooooo`001oooool00ol0003oooooooooo`03o`0000cooooo00?o0000ooooool0
00000ol00005ooooooSo00001?ooool000?ooooo1?l00002ooooo`05o`000?ooooooooooooooool0
00001oooool4o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`;o
0000K_ooool00ol0003oooooooooo`1]ooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`00
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`02ooooo`000oooool5o`0000;ooooo0ol00008ooooo`Go00000oooool2o`0000Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooooooo
o`09ooooo`;o0000KOooool00ol0003oooooooooo`1/ooooo`;o00002oooool00ol0003ooooooooo
o`02ooooo`009?ooool00ol0003oooooooooo`09ooooo`;o0000KOooool00ol0003oooooooooo`1/
ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0K?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00_ooool002Cooooo00?o0000ooooooooool02_ooool2o`0006cooooo00?o0000ooooooooool0
Joooool2o`0000cooooo00?o0000ooooooooool00_ooool002Cooooo0_l0000;ooooo`;o0000K?oo
ool00ol0003oooooooooo`1[ooooo`;o00002oooool2o`0000Cooooo000Tooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1[ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0;ooooo`;o0000Joooool00ol0003o
ooooooooo`1Zooooo`;o00003Oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooo
ooooo`0;ooooo`;o0000Joooool00ol0003oooooooooo`1Zooooo`;o00003Oooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo000T
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooo
ooooool02oooool2o`0006_ooooo00?o0000ooooooooool0JOooool2o`0000kooooo00?o0000oooo
ooooool00_ooool002Cooooo00?o0000ooooooooool02oooool2o`0006_ooooo00?o0000oooooooo
ool0JOooool2o`0000kooooo00?o0000ooooooooool00_ooool002Cooooo0_l0000=ooooo`03o`00
0?oooooooooo06Wooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0<ooooo`;o0000
1?ooool002Cooooo00?o0000ooooooooool03?ooool2o`0006[ooooo00?o0000ooooooooool0J?oo
ool2o`0000oooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool03?ooool2
o`0006[ooooo00?o0000ooooooooool0J?ooool2o`0000oooooo00?o0000ooooooooool00_ooool0
02Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
06Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo00gooooo
0_l0001Yooooo`03o`000?oooooooooo06Oooooo0_l0000@ooooo`03o`000?oooooooooo00;ooooo
000Tooooo`03o`000?oooooooooo00gooooo0_l0001Yooooo`03o`000?oooooooooo06Oooooo0_l0
000@ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool002Cooooo00?o0000ooooooooool03_ooool2o`0006Sooooo00?o0000oooo
ooooool0I_ooool2o`00017ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooooooo
ool03_ooool2o`0006Sooooo00?o0000ooooooooool0I_ooool2o`00017ooooo00?o0000oooooooo
ool00_ooool002Cooooo0_l0000@ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`0?ooooo`;o00001?ooool002Cooooo00?o0000ooooooooool03ooo
ool2o`0006Oooooo00?o0000ooooooooool0IOooool2o`0001;ooooo00?o0000ooooooooool00_oo
ool002Cooooo00?o0000ooooooooool03oooool2o`0006Oooooo00?o0000ooooooooool0IOooool2
o`0001;ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;o
oooo000Tooooo`03o`000?oooooooooo013ooooo0_l0001Vooooo`03o`000?oooooooooo06Cooooo
0_l0000Cooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo013ooooo0_l0
001Vooooo`03o`000?oooooooooo06Cooooo0_l0000Cooooo`03o`000?oooooooooo00;ooooo0004
ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol00005
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool000?ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool01ol0003ooooooooo
oooooooo0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017o
oooo0_l0001Uooooo`03o`000?oooooooooo06?ooooo0_l0000Dooooo`03o`000?oooooooooo00;o
oooo0007ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
o`000003ooooo`03o`000?oooooooooo00;ooooo0_l0000Booooo`;o0000IOooool00ol0003ooooo
ooooo`1Sooooo`;o00004oooool2o`0000Cooooo0007ooooo`03o`000?oooooooooo00?o00003?oo
ool00ol0003oooooooooo`03o`0000Gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`02ooooo`000oooool4o`0000;ooooo00Go0000ooooooooooooooooo`000007ooooo`Co00000_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool04_ooool2o`0006Cooooo
00?o0000ooooooooool0Hoooool2o`0001Cooooo00?o0000ooooooooool00_ooool000?ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool04_ooool2o`0006Co
oooo00?o0000ooooooooool0Hoooool2o`0001Cooooo00?o0000ooooooooool00_ooool000?ooooo
1Ol00002ooooo`?o00002?ooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool04oooool2o`0006?ooooo00?o
0000ooooooooool0H_ooool2o`0001Gooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000
ooooooooool04oooool2o`0006?ooooo00?o0000ooooooooool0H_ooool2o`0001Gooooo00?o0000
ooooooooool00_ooool002Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02oooo
o`009?ooool00ol0003oooooooooo`0Dooooo`;o0000H_ooool00ol0003oooooooooo`1Qooooo`;o
00005_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Dooooo`;o0000
H_ooool00ol0003oooooooooo`1Qooooo`;o00005_ooool00ol0003oooooooooo`02ooooo`009?oo
ool2o`0001Oooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo01Cooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`0Eooooo`;o0000HOooool0
0ol0003oooooooooo`1Pooooo`;o00005oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0
003oooooooooo`0Eooooo`;o0000HOooool00ol0003oooooooooo`1Pooooo`;o00005oooool00ol0
003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Fooooo`;o0000H?ooool00ol0003o
ooooooooo`1Oooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooo
ooooo`0Fooooo`;o0000H?ooool00ol0003oooooooooo`1Oooooo`;o00006?ooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05kooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo000T
ooooo`03o`000?oooooooooo01Oooooo0_l0001Oooooo`03o`000?oooooooooo05kooooo0_l0000I
ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo01Oooooo0_l0001Ooooo
o`03o`000?oooooooooo05kooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo000Tooooo`03
o`000?oooooooooo01Sooooo0_l0001Nooooo`03o`000?oooooooooo05gooooo0_l0000Jooooo`03
o`000?oooooooooo00;ooooo000Tooooo`;o00006Oooool2o`0005kooooo00?o0000ooooooooool0
GOooool2o`0001Wooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00;ooooo000Tooooo`03o`000?oooooooooo01Wooooo0_l0001Mooooo`03o`000?oooooo
oooo05cooooo0_l0000Kooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo
01Wooooo0_l0001Mooooo`03o`000?oooooooooo05cooooo0_l0000Kooooo`03o`000?oooooooooo
00;ooooo000Tooooo`03o`000?oooooooooo01[ooooo0_l0001Looooo`03o`000?oooooooooo05_o
oooo0_l0000Looooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo01[ooooo
0_l0001Looooo`03o`000?oooooooooo05_ooooo0_l0000Looooo`03o`000?oooooooooo00;ooooo
000Tooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000
ooooooooool06_ooool2o`0005cooooo00?o0000ooooooooool0F_ooool2o`0001gooooo00?o0000
ooooooooool00_ooool002Cooooo00?o0000ooooooooool06_ooool2o`0005cooooo00?o0000oooo
ooooool0F_ooool2o`0001gooooo00?o0000ooooooooool00_ooool002Cooooo0_l0000Looooo`;o
0000Foooool00ol0003oooooooooo`1Iooooo`;o00007Oooool2o`0000Cooooo000Tooooo`03o`00
0?oooooooooo01_ooooo0_l0001Kooooo`03o`000?oooooooooo05Wooooo0_l0000Nooooo`03o`00
0?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo01cooooo0_l0001Jooooo`03o`000?oo
oooooooo05Sooooo0_l0000Oooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooo
oooo01cooooo0_l0001Jooooo`03o`000?oooooooooo05Sooooo0_l0000Oooooo`03o`000?oooooo
oooo00;ooooo000Tooooo`03o`000?oooooooooo01gooooo0_l0001Iooooo`03o`000?oooooooooo
05Oooooo0_l0000Pooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo01go
oooo0_l0001Iooooo`03o`000?oooooooooo05Oooooo0_l0000Pooooo`03o`000?oooooooooo00;o
oooo000Tooooo`03o`000?oooooooooo01kooooo0_l0001Hooooo`03o`000?oooooooooo05Kooooo
0_l0000Qooooo`03o`000?oooooooooo00;ooooo000:ooooo`?o00000oooool3o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool07_ooool2o`0005Sooooo00?o
0000ooooooooool0E_ooool2o`00027ooooo00?o0000ooooooooool00_ooool000Wooooo00Oo0000
ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool07oooool2o`0005Oooooo00?o0000oooooooo
ool0E_ooool2o`00027ooooo00?o0000ooooooooool00_ooool000gooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`0Oooooo`;o0000Eoooool00ol0003oooooooooo`1Fooooo`;o00008Oooool00ol0003o
ooooooooo`02ooooo`003Oooool00ol0003oooooooooo`03o`0000Sooooo1?l00005ooooo`;o0000
8Oooool2o`0005Kooooo00?o0000ooooooooool0EOooool2o`00027ooooo0_l00004ooooo`002Ooo
ool4o`0000;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool08?ooool2o`0005Kooooo00?o0000ooooooooool0EOooool2o`0002;ooooo
00?o0000ooooooooool00_ooool000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`;o0000
EOooool00ol0003oooooooooo`1Dooooo`;o00008oooool00ol0003oooooooooo`02ooooo`002Ooo
ool5o`0000;ooooo0ol0000:ooooo`;o00001Oooool00ol0003oooooooooo`0Qooooo`;o0000EOoo
ool00ol0003oooooooooo`1Dooooo`;o00008oooool00ol0003oooooooooo`02ooooo`009?ooool0
0ol0003oooooooooo`0Rooooo`;o0000E?ooool00ol0003oooooooooo`1Cooooo`;o00009?ooool0
0ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Rooooo`?o0000Doooool00ol0
003oooooooooo`1Booooo`?o00009?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003o
ooooooooo`0Sooooo`;o0000Doooool00ol0003oooooooooo`1Booooo`;o00009Oooool00ol0003o
ooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Sooooo`?o0000D_ooool00ol0003ooooo
ooooo`1Aooooo`;o00009_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooooooo
o`0Tooooo`;o0000D_ooool00ol0003oooooooooo`1Aooooo`;o00009_ooool00ol0003ooooooooo
o`02ooooo`009?ooool2o`0002Gooooo0ol0001Aooooo`03o`000?oooooooooo053ooooo0_l0000V
ooooo`;o00001?ooool002Cooooo00?o0000ooooooooool09Oooool3o`00053ooooo00?o0000oooo
ooooool0Coooool3o`0002Oooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooooooo
ool09_ooool2o`00053ooooo00?o0000ooooooooool0Coooool2o`0002Sooooo00?o0000oooooooo
ool00_ooool002Cooooo00?o0000ooooooooool09_ooool3o`0004oooooo00?o0000ooooooooool0
C_ooool2o`0002Wooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool09ooo
ool2o`0004oooooo00?o0000ooooooooool0COooool3o`0002Wooooo00?o0000ooooooooool00_oo
ool002Cooooo00?o0000ooooooooool09oooool2o`0004oooooo00?o0000ooooooooool0COooool2
o`0002[ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0:?ooool2o`00
04kooooo00?o0000ooooooooool0C?ooool2o`0002_ooooo00?o0000ooooooooool00_ooool002Co
oooo00?o0000ooooooooool0:?ooool3o`0004gooooo00?o0000ooooooooool0Boooool3o`0002_o
oooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0:Oooool3o`0004cooooo
00?o0000ooooooooool0B_ooool3o`0002cooooo00?o0000ooooooooool00_ooool002Cooooo00?o
0000ooooooooool0:_ooool2o`0004cooooo00?o0000ooooooooool0B_ooool2o`0002gooooo00?o
0000ooooooooool00_ooool002Cooooo0_l0000/ooooo`;o0000Boooool00ol0003oooooooooo`19
ooooo`;o0000;Oooool2o`0000Cooooo000Tooooo`03o`000?oooooooooo02_ooooo0ol0001:oooo
o`03o`000?oooooooooo04Wooooo0_l0000^ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03
o`000?oooooooooo02cooooo0ol00019ooooo`03o`000?oooooooooo04Sooooo0ol0000^ooooo`03
o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo02gooooo0ol00018ooooo`03o`00
0?oooooooooo04Oooooo0ol0000_ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oo
oooooooo02kooooo0ol00017ooooo`03o`000?oooooooooo04Kooooo0ol0000`ooooo`03o`000?oo
oooooooo00;ooooo000Tooooo`03o`000?oooooooooo02oooooo0ol00016ooooo`03o`000?oooooo
oooo04Gooooo0ol0000aooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo
033ooooo0ol00015ooooo`03o`000?oooooooooo04Cooooo0ol0000booooo`03o`000?oooooooooo
00;ooooo000Tooooo`03o`000?oooooooooo037ooooo0ol00014ooooo`03o`000?oooooooooo04?o
oooo0ol0000cooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo03;ooooo
0ol00013ooooo`03o`000?oooooooooo04;ooooo0ol0000dooooo`03o`000?oooooooooo00;ooooo
000Tooooo`;o0000=?ooool2o`0004?ooooo00?o0000ooooooooool0@Oooool3o`0003Cooooo0_l0
0004ooooo`009?ooool00ol0003oooooooooo`0cooooo`Co0000@Oooool00ol0003oooooooooo`0o
ooooo`Co0000=_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0doooo
o`Co0000@?ooool00ol0003oooooooooo`0nooooo`Co0000=oooool00ol0003oooooooooo`02oooo
o`009?ooool00ol0003oooooooooo`0fooooo`?o0000?oooool00ol0003oooooooooo`0mooooo`?o
0000>Oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0gooooo`Co0000
?Oooool00ol0003oooooooooo`0looooo`?o0000>_ooool00ol0003oooooooooo`02ooooo`009?oo
ool00ol0003oooooooooo`0hooooo`Co0000??ooool00ol0003oooooooooo`0kooooo`Co0000>_oo
ool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0jooooo`Co0000>_ooool0
0ol0003oooooooooo`0iooooo`Co0000??ooool00ol0003oooooooooo`02ooooo`001?ooool3o`00
00?ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00001?ooool00ol0
003oooooooooo`0kooooo`Go0000>?ooool00ol0003oooooooooo`0gooooo`Go0000?Oooool00ol0
003oooooooooo`02ooooo`000oooool01ol0003ooooooooooooooooo0000ooooool000000oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03gooooo1?l0000gooooo`03o`000?oooooooooo03Gooooo
1Ol0000oooooo`03o`000?oooooooooo00;ooooo0007ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool2o`00043ooooo1?l0000eooooo`03o`000?oooooooooo03?ooooo1Ol00010ooooo`;o0000
1?ooool000Oooooo00?o0000ooooooooool00ol00008ooooo`Co00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo043ooooo1_l0000booooo`03o`000?oooooooooo037ooooo1Ol0
0013ooooo`03o`000?oooooooooo00;ooooo0003ooooo`Co00000_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0@_ooool7o`0002oooooo00?o0000ooooooooool0;_ooool6o`0004Gooooo
00?o0000ooooooooool00_ooool000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0AOooool8o`0002_ooooo00?o0000ooooooooool0:_ooool8o`0004Oo
oooo00?o0000ooooooooool00_ooool000?ooooo1Ol00002ooooo`?o00002_ooool2o`0000?ooooo
0ol00005ooooo`03o`000?oooooooooo04Sooooo2Ol0000Wooooo`03o`000?oooooooooo02Kooooo
2Ol0001:ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo04_ooooo3?l0
000Qooooo`03o`000?oooooooooo01oooooo3?l0001>ooooo`03o`000?oooooooooo00;ooooo000T
ooooo`03o`000?oooooooooo04ooooooE?l0001Aooooo`03o`000?oooooooooo00;ooooo000Toooo
o`03o`000?oooooooooo05KoooooAOl0001Iooooo`03o`000?oooooooooo00;ooooo000Tooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`02ooooo`00
9?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`009?oooooho`0000Cooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo000`ooooo`?o0000F?ooool3o`0001Oooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0>ooooo`00<Oooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0=ooooo`00:oooool3
o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003ooooo`Co000000?ooooo
o`000?l000000ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001_ooool5
o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_oo
ool6o`0000Oooooo00?o0000ooooooooool00oooool4o`000003ooooool0003o000000;o00000_oo
ool4o`0000?ooooo0ol00002ooooo`Go00000oooool2o`000004ooooool0003oooooooooo`;o0000
0oooool3o`0000Wooooo1?l000000ooooooo0000o`000003o`000003ooooool0003o000000;o0000
1?ooool2o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0
003o00000oooool3o`0000Gooooo00?o0000ooooooooool03?ooool002[ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000Kooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004oooo
o`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0000;ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0<ooooo`00:_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooooooo`03ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`?o
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00007ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo00?o0000ooooooooool00ooo
ool3o`0000?ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`Go00001?ooool00ol0003o
ooooooooo`0<ooooo`00:_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool3
o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?o
oooo00Ko0000oooooooooooo0000ooooool00005ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool002[ooooo00Ko0000oooooooooooo
ooooo`000?ooool4o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000?ooooo0_l00005oooo
o`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003
ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool4o`0000?ooooo2Ol00003
ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool3o`0000?ooooo1?l00002
ooooo`?o00001?ooool01?l0003oooooooooooooool2o`000004ooooool0003o0000ooooo`Co0000
0oooool3o`0000Wooooo0ol00002ooooo`?o00001?ooool4o`000003ooooool0003o000000;o0000
0oooool2o`0000?ooooo1?l00003ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool0
3?ooool002[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`00:oooool3o`0000Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`?o00002Oooool4o`0000Wooooo
00?o0000ooooooooool00_ooool2o`0000[ooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo
0_l0000=ooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`?o00002_ooool00ol0003ooooo
ooooo`0@ooooo`;o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool03_ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-30.8598, 58.5377, 0.192895, \
0.000531799}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0209743 -1.33926 0.877595 [
[.08051 -0.0125 -9 -9 ]
[.08051 -0.0125 9 0 ]
[.29026 -0.0125 -9 -9 ]
[.29026 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70974 -0.0125 -6 -9 ]
[.70974 -0.0125 6 0 ]
[.91949 -0.0125 -6 -9 ]
[.91949 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06489 -18 -4.5 ]
[-0.0125 .06489 0 4.5 ]
[-0.0125 .15265 -18 -4.5 ]
[-0.0125 .15265 0 4.5 ]
[-0.0125 .24041 -18 -4.5 ]
[-0.0125 .24041 0 4.5 ]
[-0.0125 .32817 -18 -4.5 ]
[-0.0125 .32817 0 4.5 ]
[-0.0125 .41593 -6 -4.5 ]
[-0.0125 .41593 0 4.5 ]
[-0.0125 .50369 -18 -4.5 ]
[-0.0125 .50369 0 4.5 ]
[-0.0125 .59145 -18 -4.5 ]
[-0.0125 .59145 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08051 0 m
.08051 .00625 L
s
[(-20)] .08051 -0.0125 0 1 Mshowa
.29026 0 m
.29026 .00625 L
s
[(-10)] .29026 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70974 0 m
.70974 .00625 L
s
[(10)] .70974 -0.0125 0 1 Mshowa
.91949 0 m
.91949 .00625 L
s
[(20)] .91949 -0.0125 0 1 Mshowa
.125 Mabswid
.12246 0 m
.12246 .00375 L
s
.16441 0 m
.16441 .00375 L
s
.20636 0 m
.20636 .00375 L
s
.24831 0 m
.24831 .00375 L
s
.33221 0 m
.33221 .00375 L
s
.37415 0 m
.37415 .00375 L
s
.4161 0 m
.4161 .00375 L
s
.45805 0 m
.45805 .00375 L
s
.54195 0 m
.54195 .00375 L
s
.5839 0 m
.5839 .00375 L
s
.62585 0 m
.62585 .00375 L
s
.66779 0 m
.66779 .00375 L
s
.75169 0 m
.75169 .00375 L
s
.79364 0 m
.79364 .00375 L
s
.83559 0 m
.83559 .00375 L
s
.87754 0 m
.87754 .00375 L
s
.03857 0 m
.03857 .00375 L
s
.96143 0 m
.96143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06489 m
.00625 .06489 L
s
[(1.6)] -0.0125 .06489 1 0 Mshowa
0 .15265 m
.00625 .15265 L
s
[(1.7)] -0.0125 .15265 1 0 Mshowa
0 .24041 m
.00625 .24041 L
s
[(1.8)] -0.0125 .24041 1 0 Mshowa
0 .32817 m
.00625 .32817 L
s
[(1.9)] -0.0125 .32817 1 0 Mshowa
0 .41593 m
.00625 .41593 L
s
[(2)] -0.0125 .41593 1 0 Mshowa
0 .50369 m
.00625 .50369 L
s
[(2.1)] -0.0125 .50369 1 0 Mshowa
0 .59145 m
.00625 .59145 L
s
[(2.2)] -0.0125 .59145 1 0 Mshowa
.125 Mabswid
0 .08244 m
.00375 .08244 L
s
0 .1 m
.00375 .1 L
s
0 .11755 m
.00375 .11755 L
s
0 .1351 m
.00375 .1351 L
s
0 .1702 m
.00375 .1702 L
s
0 .18776 m
.00375 .18776 L
s
0 .20531 m
.00375 .20531 L
s
0 .22286 m
.00375 .22286 L
s
0 .25796 m
.00375 .25796 L
s
0 .27552 m
.00375 .27552 L
s
0 .29307 m
.00375 .29307 L
s
0 .31062 m
.00375 .31062 L
s
0 .34572 m
.00375 .34572 L
s
0 .36327 m
.00375 .36327 L
s
0 .38083 m
.00375 .38083 L
s
0 .39838 m
.00375 .39838 L
s
0 .43348 m
.00375 .43348 L
s
0 .45103 m
.00375 .45103 L
s
0 .46859 m
.00375 .46859 L
s
0 .48614 m
.00375 .48614 L
s
0 .52124 m
.00375 .52124 L
s
0 .53879 m
.00375 .53879 L
s
0 .55635 m
.00375 .55635 L
s
0 .5739 m
.00375 .5739 L
s
0 .04734 m
.00375 .04734 L
s
0 .02979 m
.00375 .02979 L
s
0 .01224 m
.00375 .01224 L
s
0 .609 m
.00375 .609 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08051 .61178 m
.08051 .61803 L
s
.29026 .61178 m
.29026 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.70974 .61178 m
.70974 .61803 L
s
.91949 .61178 m
.91949 .61803 L
s
.125 Mabswid
.12246 .61428 m
.12246 .61803 L
s
.16441 .61428 m
.16441 .61803 L
s
.20636 .61428 m
.20636 .61803 L
s
.24831 .61428 m
.24831 .61803 L
s
.33221 .61428 m
.33221 .61803 L
s
.37415 .61428 m
.37415 .61803 L
s
.4161 .61428 m
.4161 .61803 L
s
.45805 .61428 m
.45805 .61803 L
s
.54195 .61428 m
.54195 .61803 L
s
.5839 .61428 m
.5839 .61803 L
s
.62585 .61428 m
.62585 .61803 L
s
.66779 .61428 m
.66779 .61803 L
s
.75169 .61428 m
.75169 .61803 L
s
.79364 .61428 m
.79364 .61803 L
s
.83559 .61428 m
.83559 .61803 L
s
.87754 .61428 m
.87754 .61803 L
s
.03857 .61428 m
.03857 .61803 L
s
.96143 .61428 m
.96143 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06489 m
1 .06489 L
s
.99375 .15265 m
1 .15265 L
s
.99375 .24041 m
1 .24041 L
s
.99375 .32817 m
1 .32817 L
s
.99375 .41593 m
1 .41593 L
s
.99375 .50369 m
1 .50369 L
s
.99375 .59145 m
1 .59145 L
s
.125 Mabswid
.99625 .08244 m
1 .08244 L
s
.99625 .1 m
1 .1 L
s
.99625 .11755 m
1 .11755 L
s
.99625 .1351 m
1 .1351 L
s
.99625 .1702 m
1 .1702 L
s
.99625 .18776 m
1 .18776 L
s
.99625 .20531 m
1 .20531 L
s
.99625 .22286 m
1 .22286 L
s
.99625 .25796 m
1 .25796 L
s
.99625 .27552 m
1 .27552 L
s
.99625 .29307 m
1 .29307 L
s
.99625 .31062 m
1 .31062 L
s
.99625 .34572 m
1 .34572 L
s
.99625 .36327 m
1 .36327 L
s
.99625 .38083 m
1 .38083 L
s
.99625 .39838 m
1 .39838 L
s
.99625 .43348 m
1 .43348 L
s
.99625 .45103 m
1 .45103 L
s
.99625 .46859 m
1 .46859 L
s
.99625 .48614 m
1 .48614 L
s
.99625 .52124 m
1 .52124 L
s
.99625 .53879 m
1 .53879 L
s
.99625 .55635 m
1 .55635 L
s
.99625 .5739 m
1 .5739 L
s
.99625 .04734 m
1 .04734 L
s
.99625 .02979 m
1 .02979 L
s
.99625 .01224 m
1 .01224 L
s
.99625 .609 m
1 .609 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06489 m
1 .06489 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01666 m
.02466 .17548 L
.02558 .29571 L
.02602 .35404 L
.02644 .39825 L
.02682 .42085 L
.02723 .44538 L
.02772 .47466 L
.02817 .50127 L
.02865 .51078 L
.02918 .52124 L
.02962 .53009 L
.03004 .53813 L
.03053 .54052 L
.03097 .54271 L
.03144 .545 L
.03188 .54716 L
.03212 .54743 L
.03239 .54772 L
.03285 .54823 L
.03329 .54872 L
.03375 .54923 L
.03415 .54937 L
.03459 .54953 L
.03853 .55071 L
.05458 .55494 L
.06998 .55878 L
.0848 .56226 L
.10056 .56579 L
.11574 .56897 L
.13034 .57185 L
.14587 .57465 L
.16083 .57727 L
.17521 .57963 L
.19053 .582 L
.20527 .58413 L
.22094 .58629 L
.23604 .5882 L
.25055 .58989 L
.266 .5916 L
.28088 .5931 L
.29669 .5946 L
.31192 .59588 L
.32657 .59704 L
.34216 .59814 L
.35717 .5991 L
.3716 .59992 L
.38697 .60069 L
.40176 .60134 L
.41749 .60193 L
Mistroke
.43263 .60239 L
.4472 .60275 L
.45534 .60291 L
.46271 .60304 L
.46316 .60304 L
.46364 .60304 L
.46409 .60304 L
.46451 .60305 L
.46497 .60306 L
.46541 .60307 L
.46589 .60308 L
.46614 .60309 L
.4664 .60309 L
.46692 .60309 L
.4674 .60309 L
.46767 .60309 L
.46796 .6031 L
.46823 .6031 L
.46849 .60311 L
.46942 .60313 L
.46989 .60313 L
.47015 .60312 L
.4704 .60311 L
.47085 .60308 L
.47134 .60306 L
.47181 .60304 L
.47223 .60308 L
.47304 .60314 L
.47345 .60317 L
.4739 .60316 L
.47439 .60314 L
.47483 .60311 L
.47508 .6031 L
.47534 .60308 L
.47583 .60311 L
.47629 .60314 L
.47677 .60318 L
.47718 .60321 L
.47763 .6032 L
.47809 .60317 L
.47852 .60315 L
.47898 .60313 L
.47948 .60314 L
.47994 .60317 L
.48038 .6032 L
.48078 .60323 L
.48121 .60324 L
.48168 .60321 L
.48221 .60318 L
.48247 .60317 L
Mistroke
.48275 .60315 L
.48302 .60315 L
.48326 .60317 L
.48373 .6032 L
.48423 .60324 L
.48471 .60327 L
.48516 .60325 L
.48566 .60323 L
.48592 .60321 L
.4862 .6032 L
.48645 .60318 L
.48672 .60318 L
.48719 .60321 L
.48765 .60324 L
.48814 .60327 L
.48861 .60329 L
.48903 .60327 L
.48952 .60324 L
.49005 .60321 L
.49032 .60319 L
.49062 .60321 L
.49115 .60324 L
.49165 .60327 L
.49191 .60329 L
.49219 .60331 L
.49243 .6033 L
.49269 .60328 L
.49316 .60326 L
.49363 .60323 L
.49412 .60321 L
.49438 .60322 L
.49467 .60324 L
.49517 .60327 L
.49565 .6033 L
.49591 .60332 L
.49616 .60331 L
.49663 .60328 L
.49708 .60325 L
.4975 .60323 L
.49796 .60322 L
.49839 .60325 L
.49878 .60327 L
.49924 .6033 L
.49973 .60332 L
.5002 .60329 L
.50063 .60327 L
.5011 .60324 L
.50159 .60322 L
.50206 .60324 L
.50249 .60327 L
Mistroke
.50299 .6033 L
.50327 .60331 L
.50353 .60331 L
.50401 .60328 L
.50452 .60325 L
.505 .60323 L
.50528 .60321 L
.50553 .60322 L
.50647 .60327 L
.50672 .60329 L
.507 .6033 L
.50729 .6033 L
.50757 .60329 L
.50807 .60326 L
.50833 .60324 L
.50862 .60322 L
.50888 .60321 L
.50913 .60321 L
.50961 .60323 L
.51011 .60326 L
.51037 .60327 L
.51066 .60329 L
.51116 .60328 L
.51162 .60325 L
.5121 .60322 L
.51253 .6032 L
.51303 .6032 L
.51329 .60321 L
.51357 .60323 L
.51404 .60325 L
.51455 .60328 L
.51483 .60326 L
.5151 .60325 L
.51561 .60322 L
.51589 .6032 L
.51621 .60318 L
.5165 .60317 L
.51677 .60318 L
.51763 .60322 L
.51811 .60324 L
.51855 .60324 L
.51879 .60322 L
.51906 .60321 L
.51956 .60318 L
.52005 .60315 L
.5205 .60315 L
.52075 .60316 L
.52102 .60318 L
.52151 .6032 L
.52198 .60322 L
Mistroke
.52241 .6032 L
.52296 .60317 L
.52348 .60313 L
.52395 .60311 L
.52421 .60312 L
.52445 .60313 L
.52532 .60317 L
.52576 .60319 L
.52625 .60316 L
.52672 .60313 L
.52724 .60309 L
.52772 .60307 L
.52817 .60309 L
.52898 .60312 L
.52943 .60314 L
.52986 .60312 L
.53071 .60307 L
.53119 .60303 L
.53164 .60303 L
.53213 .60305 L
.53266 .60308 L
.53312 .60309 L
.53339 .60309 L
.53363 .60307 L
.53451 .60301 L
.535 .60298 L
.53544 .60299 L
.5357 .603 L
.53596 .60301 L
.53644 .60303 L
.53669 .60303 L
.53696 .60305 L
.53726 .60302 L
.53753 .60301 L
.53803 .60297 L
.53831 .60295 L
.53856 .60293 L
.53902 .60292 L
.53951 .60294 L
.54 .60296 L
.54026 .60297 L
.54051 .60298 L
.54095 .60297 L
.54143 .60293 L
.54194 .6029 L
.54243 .60286 L
.5427 .60286 L
.543 .60287 L
.54351 .60289 L
.544 .60291 L
Mistroke
.54446 .60292 L
.54471 .6029 L
.54499 .60288 L
.54547 .60285 L
.54593 .60281 L
.54642 .60279 L
.54683 .60281 L
.54729 .60282 L
.54777 .60284 L
.54822 .60285 L
.54862 .60282 L
.54906 .60278 L
.54953 .60275 L
.5498 .60273 L
.55004 .60272 L
.55047 .60273 L
.55095 .60275 L
.55137 .60276 L
.55181 .60277 L
.55219 .60275 L
.5526 .60272 L
.55304 .60269 L
.55351 .60265 L
.55396 .60264 L
.55437 .60266 L
.55479 .60267 L
.55525 .60268 L
.55575 .60268 L
.55622 .60265 L
.55674 .60261 L
.55724 .60257 L
.55769 .60256 L
.55817 .60257 L
.55863 .60259 L
.55905 .6026 L
.55955 .60259 L
.55999 .60255 L
.5608 .60249 L
.56126 .60246 L
.56168 .60247 L
.56214 .60249 L
.56263 .6025 L
.5631 .60251 L
.56352 .60248 L
.56402 .60244 L
.56428 .60242 L
.56455 .60239 L
.5648 .60237 L
.56506 .60237 L
.56553 .60238 L
Mistroke
.56605 .60239 L
.56655 .60241 L
.56682 .60241 L
.56711 .60239 L
.56763 .60234 L
.56813 .6023 L
.5684 .60228 L
.56865 .60226 L
.56915 .60227 L
.5696 .60229 L
.57004 .6023 L
.57052 .60231 L
.57096 .60227 L
.57137 .60224 L
.57185 .6022 L
.5721 .60218 L
.57237 .60215 L
.57286 .60217 L
.57332 .60218 L
.57378 .60219 L
.57428 .6022 L
.57475 .60216 L
.57518 .60212 L
.5757 .60207 L
.57619 .60204 L
.57643 .60205 L
.57669 .60205 L
.57724 .60207 L
.57772 .60208 L
.57815 .60207 L
.57863 .60202 L
.57914 .60198 L
.57955 .60194 L
.57999 .60192 L
.58048 .60193 L
.58093 .60194 L
.58136 .60195 L
.58183 .60195 L
.58227 .60191 L
.58268 .60187 L
.58308 .60184 L
.58345 .6018 L
.58389 .6018 L
.58428 .60181 L
.58472 .60182 L
.5852 .60183 L
.58565 .60181 L
.58606 .60177 L
.58653 .60173 L
.58679 .60171 L
Mistroke
.58706 .60168 L
.58755 .60167 L
.588 .60168 L
.58847 .60169 L
.58897 .6017 L
.58944 .60167 L
.58987 .60163 L
.59039 .60158 L
.59088 .60154 L
.59112 .60153 L
.59138 .60153 L
.59194 .60154 L
.59238 .60155 L
.59285 .60156 L
.59309 .60154 L
.59336 .60151 L
.59383 .60147 L
.59428 .60142 L
.59476 .60138 L
.59521 .60139 L
.59563 .6014 L
.59602 .6014 L
.59645 .60141 L
.59691 .60138 L
.59734 .60134 L
.59779 .6013 L
.5982 .60126 L
.59857 .60123 L
.59898 .60124 L
.59944 .60125 L
.59988 .60125 L
.60013 .60126 L
.60039 .60126 L
.60086 .60121 L
.60169 .60113 L
.60217 .60108 L
.60261 .60108 L
.6031 .60109 L
.60362 .6011 L
.6039 .6011 L
.60417 .60109 L
.60442 .60107 L
.60468 .60104 L
.60516 .60099 L
.60543 .60096 L
.60567 .60094 L
.60616 .60092 L
.60659 .60092 L
.6071 .60093 L
.60757 .60094 L
Mistroke
.60806 .60091 L
.60832 .60088 L
.6086 .60085 L
.6091 .6008 L
.60957 .60075 L
.60999 .60075 L
.61045 .60076 L
.61099 .60076 L
.61126 .60077 L
.6115 .60077 L
.61176 .60074 L
.61203 .60072 L
.61262 .60065 L
.61286 .60063 L
.61313 .6006 L
.6136 .60057 L
.61409 .60058 L
.61463 .60059 L
.6151 .60059 L
.61536 .60058 L
.61561 .60055 L
.61616 .6005 L
.61666 .60044 L
.61712 .60039 L
.61756 .6004 L
.61807 .6004 L
.61853 .60041 L
.61879 .60041 L
.61904 .60041 L
.6193 .60038 L
.61958 .60035 L
.62004 .60029 L
.62055 .60024 L
.62084 .60021 L
.62111 .60021 L
.6217 .60022 L
.62221 .60022 L
.6225 .60022 L
.62276 .60022 L
.62323 .60016 L
.62374 .60011 L
.62418 .60006 L
.62465 .60001 L
.62491 .60002 L
.62515 .60002 L
.62562 .60002 L
.62615 .60003 L
.62641 .60003 L
.6267 .6 L
.62764 .59989 L
Mistroke
.62791 .59986 L
.62816 .59983 L
.62864 .59982 L
.62908 .59982 L
.6295 .59983 L
.62995 .59983 L
.63043 .5998 L
.64488 .59898 L
.66027 .59798 L
.67508 .59692 L
.69082 .59568 L
.70599 .59436 L
.72057 .59299 L
.7361 .59141 L
.75104 .58976 L
.76541 .58806 L
.78071 .58612 L
.79543 .58412 L
.81109 .58184 L
.82617 .57949 L
.84068 .577 L
.85611 .57432 L
.87097 .57154 L
.88677 .56844 L
.90198 .56524 L
.91662 .56196 L
.9322 .55828 L
.9472 .55452 L
.95473 .55254 L
.96161 .5507 L
.96334 .55024 L
.96425 .54996 L
.96475 .5498 L
.96522 .54964 L
.96566 .54948 L
.96615 .54915 L
.96699 .54857 L
.96741 .54829 L
.96785 .54717 L
.96864 .54484 L
.96911 .54345 L
.96954 .54037 L
.97003 .53404 L
.9705 .52805 L
.9709 .52289 L
.97133 .51388 L
.9718 .49374 L
.97224 .47511 L
.97271 .45514 L
.97321 .4257 L
Mistroke
.97368 .37608 L
.97412 .3306 L
.97464 .27588 L
.97513 .21037 L
.97564 .11691 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;oooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00006oooool0033ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001[ooooo000Yooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001[ooooo000booooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool06?ooool002oooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Joooo
o`00;oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Jooooo`00<?ooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Kooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`007_oooooho`0000[ooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`08ooooo`007_oo
ool2o`0007Wooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`002_ooool3o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002oooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool000_ooooo00?o0000ooooooooool01oooool4o`0000Gooooon?l0000:ooooo`002oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`002_ooool2o`0000[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Wooooo
0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo0_l0
0004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o0000
2_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo000:ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`02ooooo`;o00002_ooool000_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool000[ooooo0_l00009ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oo
oooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo0_l0
0004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o0000
2_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo000:ooooo`?o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000Cooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool000_ooooo00?o0000oooo
ooooool02?ooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`002oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000:ooooo`;o00002Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`002oooool00ol0003oooooooooo`08ooooo`?o00001Oooool2o`0000Cooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool00_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool00_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool2
o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000[o
oooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool02?ooool4o`0000Cooooo0_l00004
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02
ooooo`;o00002_ooool000_ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002_ooool2o`00
00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool000_ooooo00?o0000ooooooooool02?ooool3o`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool00_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool2
o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001Go
oooo1Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001Kooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo000Gooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000E
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo000Eooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Sooooo000Fooooo`?o00001Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool5o`00
00?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool000cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`000009ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool01Ol0003ooooooooooooooooo000000Sooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02?ooool000[ooooo0ol0000:ooooo`03o`000?oooooooooo00Cooooo0_l0
0005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`03ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Gooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool3o`0006oo
oooo00?o0000ooooooooool0KOooool4o`0000Sooooo00?o0000ooooooooool02?ooool001kooooo
0_l0000:ooooo`Co0000Joooool00ol0003oooooooooo`1Zooooo`?o00002oooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo00gooooo1?l0001Wooooo`03o`000?oooooooooo06Kooooo1?l0
000?ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo017ooooo2?l0001O
ooooo`03o`000?oooooooooo05oooooo1ol0000Cooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo01Wooooo1?l0001Kooooo`03o`000?oooooooooo05_ooooo1?l0000Joooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo01gooooo0ol0001Hooooo`03
o`000?oooooooooo05Sooooo0ol0000Nooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000
8Oooool8o`00053ooooo00?o0000ooooooooool0D?ooool8o`00023ooooo0_l0000:ooooo`002Ooo
ool5o`0000?ooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo02Sooooo
0ol0001=ooooo`03o`000?oooooooooo04Wooooo1ol0000Yooooo`03o`000?oooooooooo00Sooooo
000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0[ooooo`So0000AOooool00ol0003oooooooooo`15ooooo`Co0000<?ooool00ol0003o
ooooooooo`08ooooo`002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0<oooool;o`0003[ooooo00?o0000ooooooooool0>_ooool;o`0003Cooooo
00?o0000ooooooooool02?ooool000cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`03ooooo`;o0000?oooool7o`0003?ooooo00?o0000ooooooooool0<_ooool8o`0003kooooo0_l0
000:ooooo`002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo04Gooooo3ol0000Tooooo`03o`000?oooooooooo02?ooooo
3ol00017ooooo`03o`000?oooooooooo00Sooooo0009ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0E?oooolCo`00017o
oooo00?o0000ooooooooool03ooooolDo`0005Kooooo00?o0000ooooooooool02?ooool000[ooooo
0ol00009ooooo`?o00001Oooool00ol0003oooooooooo`1WooooobCo0000JOooool00ol0003ooooo
ooooo`08ooooo`007_ooool2o`0007Wooooo00?o0000ooooooooool0N?ooool2o`0000[ooooo000N
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Sooooo000NooooooSo00002_ooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00<cooooo0ol0001Aooooo`00cOooool00ol0003oooooooooo`1@oooo
o`00HOooool00ol0003oooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o
00000_ooool3o`0000?ooooo0ol00004ooooo`?o00000_ooool3o`000003ooooool0003o000000;o
oooo0_l00008ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003oooo
o`?o00000_ooool3o`000003ooooool0003o000000Co00000_ooool5o`0000?ooooo0_l00004oooo
o`03o`000?oooooooooo04oooooo001Qooooo`03o`000?oooooo000000;ooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003ooooooooo
ool00005ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo04oooooo001Qooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`03
o`000?oooooo000000;ooooo1Ol00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`?o0000
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
D?ooool0063ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`?o00000ooo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000
oooooooooooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`00001@ooooo`00H?ooool01Ol0003oooooo`000?oooooo000000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo00?o0000ooooooooool0
0_ooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`Co00000_ooool4o`0000[ooooo
00Co0000oooooooooooooooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co
000000Coooooo`000?l0003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`00001?oooo
o`00H?ooool01Ol0003oooooo`000?oooooo000001Cooooo00Co0000oooooooooooo00005?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1Fooooo`00H?ooool6o`0001;ooooo1Ol0000Dooooo`03o`000?oooooooooo
00Sooooo1Ol00008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Fooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.7025, 1.47032, 0.192895, \
0.00461015}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0209743 0.603319 0.00404738 [
[.08051 -0.0125 -9 -9 ]
[.08051 -0.0125 9 0 ]
[.29026 -0.0125 -9 -9 ]
[.29026 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70974 -0.0125 -6 -9 ]
[.70974 -0.0125 6 0 ]
[.91949 -0.0125 -6 -9 ]
[.91949 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03669 -24 -4.5 ]
[-0.0125 .03669 0 4.5 ]
[-0.0125 .11763 -24 -4.5 ]
[-0.0125 .11763 0 4.5 ]
[-0.0125 .19858 -24 -4.5 ]
[-0.0125 .19858 0 4.5 ]
[-0.0125 .27953 -18 -4.5 ]
[-0.0125 .27953 0 4.5 ]
[-0.0125 .36048 -18 -4.5 ]
[-0.0125 .36048 0 4.5 ]
[-0.0125 .44142 -18 -4.5 ]
[-0.0125 .44142 0 4.5 ]
[-0.0125 .52237 -18 -4.5 ]
[-0.0125 .52237 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08051 0 m
.08051 .00625 L
s
[(-20)] .08051 -0.0125 0 1 Mshowa
.29026 0 m
.29026 .00625 L
s
[(-10)] .29026 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70974 0 m
.70974 .00625 L
s
[(10)] .70974 -0.0125 0 1 Mshowa
.91949 0 m
.91949 .00625 L
s
[(20)] .91949 -0.0125 0 1 Mshowa
.125 Mabswid
.12246 0 m
.12246 .00375 L
s
.16441 0 m
.16441 .00375 L
s
.20636 0 m
.20636 .00375 L
s
.24831 0 m
.24831 .00375 L
s
.33221 0 m
.33221 .00375 L
s
.37415 0 m
.37415 .00375 L
s
.4161 0 m
.4161 .00375 L
s
.45805 0 m
.45805 .00375 L
s
.54195 0 m
.54195 .00375 L
s
.5839 0 m
.5839 .00375 L
s
.62585 0 m
.62585 .00375 L
s
.66779 0 m
.66779 .00375 L
s
.75169 0 m
.75169 .00375 L
s
.79364 0 m
.79364 .00375 L
s
.83559 0 m
.83559 .00375 L
s
.87754 0 m
.87754 .00375 L
s
.03857 0 m
.03857 .00375 L
s
.96143 0 m
.96143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03669 m
.00625 .03669 L
s
[(-140)] -0.0125 .03669 1 0 Mshowa
0 .11763 m
.00625 .11763 L
s
[(-120)] -0.0125 .11763 1 0 Mshowa
0 .19858 m
.00625 .19858 L
s
[(-100)] -0.0125 .19858 1 0 Mshowa
0 .27953 m
.00625 .27953 L
s
[(-80)] -0.0125 .27953 1 0 Mshowa
0 .36048 m
.00625 .36048 L
s
[(-60)] -0.0125 .36048 1 0 Mshowa
0 .44142 m
.00625 .44142 L
s
[(-40)] -0.0125 .44142 1 0 Mshowa
0 .52237 m
.00625 .52237 L
s
[(-20)] -0.0125 .52237 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .05692 m
.00375 .05692 L
s
0 .07716 m
.00375 .07716 L
s
0 .0974 m
.00375 .0974 L
s
0 .13787 m
.00375 .13787 L
s
0 .15811 m
.00375 .15811 L
s
0 .17834 m
.00375 .17834 L
s
0 .21882 m
.00375 .21882 L
s
0 .23906 m
.00375 .23906 L
s
0 .25929 m
.00375 .25929 L
s
0 .29977 m
.00375 .29977 L
s
0 .32 m
.00375 .32 L
s
0 .34024 m
.00375 .34024 L
s
0 .38071 m
.00375 .38071 L
s
0 .40095 m
.00375 .40095 L
s
0 .42119 m
.00375 .42119 L
s
0 .46166 m
.00375 .46166 L
s
0 .4819 m
.00375 .4819 L
s
0 .50213 m
.00375 .50213 L
s
0 .54261 m
.00375 .54261 L
s
0 .56285 m
.00375 .56285 L
s
0 .58308 m
.00375 .58308 L
s
0 .01645 m
.00375 .01645 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08051 .61178 m
.08051 .61803 L
s
.29026 .61178 m
.29026 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.70974 .61178 m
.70974 .61803 L
s
.91949 .61178 m
.91949 .61803 L
s
.125 Mabswid
.12246 .61428 m
.12246 .61803 L
s
.16441 .61428 m
.16441 .61803 L
s
.20636 .61428 m
.20636 .61803 L
s
.24831 .61428 m
.24831 .61803 L
s
.33221 .61428 m
.33221 .61803 L
s
.37415 .61428 m
.37415 .61803 L
s
.4161 .61428 m
.4161 .61803 L
s
.45805 .61428 m
.45805 .61803 L
s
.54195 .61428 m
.54195 .61803 L
s
.5839 .61428 m
.5839 .61803 L
s
.62585 .61428 m
.62585 .61803 L
s
.66779 .61428 m
.66779 .61803 L
s
.75169 .61428 m
.75169 .61803 L
s
.79364 .61428 m
.79364 .61803 L
s
.83559 .61428 m
.83559 .61803 L
s
.87754 .61428 m
.87754 .61803 L
s
.03857 .61428 m
.03857 .61803 L
s
.96143 .61428 m
.96143 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03669 m
1 .03669 L
s
.99375 .11763 m
1 .11763 L
s
.99375 .19858 m
1 .19858 L
s
.99375 .27953 m
1 .27953 L
s
.99375 .36048 m
1 .36048 L
s
.99375 .44142 m
1 .44142 L
s
.99375 .52237 m
1 .52237 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .05692 m
1 .05692 L
s
.99625 .07716 m
1 .07716 L
s
.99625 .0974 m
1 .0974 L
s
.99625 .13787 m
1 .13787 L
s
.99625 .15811 m
1 .15811 L
s
.99625 .17834 m
1 .17834 L
s
.99625 .21882 m
1 .21882 L
s
.99625 .23906 m
1 .23906 L
s
.99625 .25929 m
1 .25929 L
s
.99625 .29977 m
1 .29977 L
s
.99625 .32 m
1 .32 L
s
.99625 .34024 m
1 .34024 L
s
.99625 .38071 m
1 .38071 L
s
.99625 .40095 m
1 .40095 L
s
.99625 .42119 m
1 .42119 L
s
.99625 .46166 m
1 .46166 L
s
.99625 .4819 m
1 .4819 L
s
.99625 .50213 m
1 .50213 L
s
.99625 .54261 m
1 .54261 L
s
.99625 .56285 m
1 .56285 L
s
.99625 .58308 m
1 .58308 L
s
.99625 .01645 m
1 .01645 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .01472 Mdot
.02762 .03412 Mdot
.03143 .05301 Mdot
.03524 .0714 Mdot
.03904 .08929 Mdot
.04285 .10671 Mdot
.04665 .12365 Mdot
.05045 .14012 Mdot
.05424 .15615 Mdot
.05804 .17173 Mdot
.06183 .18688 Mdot
.06562 .20161 Mdot
.06941 .21592 Mdot
.0732 .22983 Mdot
.07698 .24334 Mdot
.08077 .25646 Mdot
.08455 .26921 Mdot
.08833 .28158 Mdot
.09211 .29359 Mdot
.09589 .30524 Mdot
.09966 .31655 Mdot
.10344 .32752 Mdot
.10721 .33816 Mdot
.11098 .34847 Mdot
.11475 .35847 Mdot
.11852 .36816 Mdot
.12228 .37755 Mdot
.12605 .38664 Mdot
.12981 .39545 Mdot
.13357 .40398 Mdot
.13733 .41223 Mdot
.14109 .42021 Mdot
.14485 .42793 Mdot
.1486 .4354 Mdot
.15236 .44261 Mdot
.15611 .44959 Mdot
.15987 .45633 Mdot
.16362 .46284 Mdot
.16737 .46912 Mdot
.17112 .47518 Mdot
.17486 .48103 Mdot
.17861 .48668 Mdot
.18235 .49211 Mdot
.1861 .49736 Mdot
.18984 .50241 Mdot
.19358 .50727 Mdot
.19732 .51195 Mdot
.20106 .51645 Mdot
.2048 .52078 Mdot
.20854 .52495 Mdot
.21228 .52895 Mdot
.21601 .53279 Mdot
.21975 .53648 Mdot
.22348 .54001 Mdot
.22721 .54341 Mdot
.23095 .54666 Mdot
.23468 .54978 Mdot
.23841 .55276 Mdot
.24214 .55561 Mdot
.24587 .55834 Mdot
.24959 .56095 Mdot
.25332 .56345 Mdot
.25705 .56582 Mdot
.26077 .56809 Mdot
.2645 .57026 Mdot
.26822 .57232 Mdot
.27194 .57428 Mdot
.27566 .57614 Mdot
.27939 .57792 Mdot
.28311 .5796 Mdot
.28683 .5812 Mdot
.29055 .58271 Mdot
.29427 .58415 Mdot
.29798 .58551 Mdot
.3017 .58679 Mdot
.30542 .588 Mdot
.30913 .58915 Mdot
.31285 .59022 Mdot
.31656 .59124 Mdot
.32028 .59219 Mdot
.32399 .59309 Mdot
.32771 .59393 Mdot
.33142 .59472 Mdot
.33513 .59545 Mdot
.33884 .59614 Mdot
.34256 .59678 Mdot
.34627 .59738 Mdot
.34998 .59793 Mdot
.35369 .59845 Mdot
.3574 .59892 Mdot
.36111 .59936 Mdot
.36481 .59977 Mdot
.36852 .60015 Mdot
.37223 .60049 Mdot
.37594 .6008 Mdot
.37965 .60109 Mdot
.38335 .60135 Mdot
.38706 .60159 Mdot
.39076 .60181 Mdot
.39447 .602 Mdot
.39818 .60218 Mdot
.40188 .60234 Mdot
.40559 .60248 Mdot
.40929 .6026 Mdot
.413 .60271 Mdot
.4167 .60281 Mdot
.4204 .60289 Mdot
.42411 .60297 Mdot
.42781 .60303 Mdot
.43151 .60308 Mdot
.43522 .60313 Mdot
.43892 .60317 Mdot
.44262 .6032 Mdot
.44633 .60323 Mdot
.45003 .60325 Mdot
.45373 .60327 Mdot
.45743 .60328 Mdot
.46113 .60329 Mdot
.46484 .6033 Mdot
.46854 .60331 Mdot
.47224 .60331 Mdot
.47594 .60332 Mdot
.47964 .60332 Mdot
.48334 .60332 Mdot
.48705 .60332 Mdot
.49075 .60332 Mdot
.49445 .60332 Mdot
.49815 .60332 Mdot
.50185 .60332 Mdot
.50555 .60332 Mdot
.50925 .60332 Mdot
.51295 .60332 Mdot
.51666 .60332 Mdot
.52036 .60332 Mdot
.52406 .60332 Mdot
.52776 .60331 Mdot
.53146 .60331 Mdot
.53516 .6033 Mdot
.53887 .60329 Mdot
.54257 .60328 Mdot
.54627 .60327 Mdot
.54997 .60325 Mdot
.55367 .60323 Mdot
.55738 .6032 Mdot
.56108 .60317 Mdot
.56478 .60313 Mdot
.56849 .60308 Mdot
.57219 .60303 Mdot
.57589 .60297 Mdot
.5796 .60289 Mdot
.5833 .60281 Mdot
.587 .60271 Mdot
.59071 .6026 Mdot
.59441 .60248 Mdot
.59812 .60234 Mdot
.60182 .60218 Mdot
.60553 .602 Mdot
.60924 .60181 Mdot
.61294 .60159 Mdot
.61665 .60135 Mdot
.62035 .60109 Mdot
.62406 .6008 Mdot
.62777 .60049 Mdot
.63148 .60015 Mdot
.63519 .59977 Mdot
.63889 .59936 Mdot
.6426 .59892 Mdot
.64631 .59845 Mdot
.65002 .59793 Mdot
.65373 .59738 Mdot
.65744 .59678 Mdot
.66116 .59614 Mdot
.66487 .59545 Mdot
.66858 .59472 Mdot
.67229 .59393 Mdot
.67601 .59309 Mdot
.67972 .59219 Mdot
.68344 .59124 Mdot
.68715 .59022 Mdot
.69087 .58915 Mdot
.69458 .588 Mdot
.6983 .58679 Mdot
.70202 .58551 Mdot
.70573 .58415 Mdot
.70945 .58271 Mdot
.71317 .5812 Mdot
.71689 .5796 Mdot
.72061 .57792 Mdot
.72434 .57614 Mdot
.72806 .57428 Mdot
.73178 .57232 Mdot
.7355 .57026 Mdot
.73923 .56809 Mdot
.74295 .56582 Mdot
.74668 .56345 Mdot
.75041 .56095 Mdot
.75413 .55834 Mdot
.75786 .55561 Mdot
.76159 .55276 Mdot
.76532 .54978 Mdot
.76905 .54666 Mdot
.77279 .54341 Mdot
.77652 .54001 Mdot
.78025 .53648 Mdot
.78399 .53279 Mdot
.78772 .52895 Mdot
.79146 .52495 Mdot
.7952 .52078 Mdot
.79894 .51645 Mdot
.80268 .51195 Mdot
.80642 .50727 Mdot
.81016 .50241 Mdot
.8139 .49736 Mdot
.81765 .49211 Mdot
.82139 .48668 Mdot
.82514 .48103 Mdot
.82888 .47518 Mdot
.83263 .46912 Mdot
.83638 .46284 Mdot
.84013 .45633 Mdot
.84389 .44959 Mdot
.84764 .44261 Mdot
.8514 .4354 Mdot
.85515 .42793 Mdot
.85891 .42021 Mdot
.86267 .41223 Mdot
.86643 .40398 Mdot
.87019 .39545 Mdot
.87395 .38664 Mdot
.87772 .37755 Mdot
.88148 .36816 Mdot
.88525 .35847 Mdot
.88902 .34847 Mdot
.89279 .33816 Mdot
.89656 .32752 Mdot
.90034 .31655 Mdot
.90411 .30524 Mdot
.90789 .29359 Mdot
.91167 .28158 Mdot
.91545 .26921 Mdot
.91923 .25646 Mdot
.92302 .24334 Mdot
.9268 .22983 Mdot
.93059 .21592 Mdot
.93438 .20161 Mdot
.93817 .18688 Mdot
.94196 .17173 Mdot
.94576 .15615 Mdot
.94955 .14012 Mdot
.95335 .12365 Mdot
.95715 .10671 Mdot
.96096 .08929 Mdot
.96476 .0714 Mdot
.96857 .05301 Mdot
.97238 .03412 Mdot
.97619 .01472 Mdot
.5 Mabswid
.02381 .01472 m
.03853 .08687 L
.05458 .15753 L
.06965 .21682 L
.08415 .26786 L
.09958 .31632 L
.11444 .35765 L
.13023 .3964 L
.14544 .4291 L
.16007 .45669 L
.17564 .4822 L
.19063 .50343 L
.20504 .52105 L
.22039 .53709 L
.23516 .55016 L
.25087 .5618 L
.26599 .57109 L
.28054 .57844 L
.29603 .58479 L
.31093 .58967 L
.32678 .59372 L
.34204 .59669 L
.35672 .59884 L
.36417 .5997 L
.37234 .6005 L
.38739 .60161 L
.39482 .60202 L
.40279 .60237 L
.41088 .60265 L
.41854 .60285 L
.42613 .603 L
.43315 .60311 L
.44026 .60318 L
.4443 .60322 L
.4481 .60324 L
.45185 .60326 L
.45579 .60328 L
.45916 .60329 L
.46284 .6033 L
.46676 .60331 L
.47031 .60331 L
.47127 .60331 L
.47179 .60331 L
.47228 .60331 L
.47254 .60331 L
.47281 .60331 L
.47339 .60331 L
.47442 .60331 L
.47539 .60331 L
.47643 .60332 L
Mistroke
.47829 .60332 L
.47925 .60332 L
.48028 .60332 L
.48215 .60332 L
.48271 .60332 L
.48302 .60332 L
.4833 .60332 L
.48355 .60332 L
.48381 .60332 L
.48436 .60332 L
.48636 .60332 L
.48684 .60332 L
.48708 .60332 L
.48735 .60332 L
.48791 .60332 L
.48842 .60332 L
.48936 .60332 L
.48985 .60332 L
.49037 .60332 L
.49084 .60332 L
.4911 .60332 L
.49135 .60332 L
.49225 .60332 L
.49311 .60332 L
.49402 .60332 L
.4945 .60332 L
.49477 .60332 L
.49502 .60332 L
.49595 .60332 L
.49704 .60332 L
.49752 .60332 L
.49777 .60332 L
.49804 .60332 L
.49853 .60332 L
.49898 .60332 L
.49987 .60332 L
.50081 .60332 L
.5013 .60332 L
.50158 .60332 L
.50183 .60332 L
.50226 .60332 L
.50273 .60332 L
.50356 .60332 L
.5044 .60332 L
.50481 .60332 L
.50519 .60332 L
.50565 .60332 L
.50614 .60332 L
.50699 .60332 L
.50799 .60332 L
Mistroke
.50843 .60332 L
.50891 .60332 L
.50939 .60332 L
.50982 .60332 L
.51069 .60332 L
.51169 .60332 L
.51213 .60332 L
.5126 .60332 L
.51305 .60332 L
.51346 .60332 L
.51427 .60332 L
.51605 .60332 L
.51651 .60332 L
.51699 .60332 L
.51787 .60332 L
.51987 .60332 L
.52096 .60332 L
.52199 .60332 L
.52298 .60332 L
.52347 .60332 L
.52391 .60332 L
.52432 .60331 L
.52475 .60331 L
.52566 .60331 L
.52666 .60331 L
.52759 .60331 L
.5285 .60331 L
.52946 .60331 L
.5315 .60331 L
.53518 .6033 L
.53852 .60329 L
.54233 .60328 L
.54583 .60327 L
.54969 .60325 L
.55376 .60323 L
.55736 .6032 L
.56122 .60317 L
.5682 .60309 L
.57627 .60296 L
.58393 .60279 L
.5915 .60257 L
.59851 .60232 L
.61344 .60156 L
.62162 .60099 L
.62931 .60035 L
.64403 .59874 L
.65967 .59639 L
.67474 .59337 L
.68924 .58962 L
.70466 .58454 L
Mistroke
.71951 .57842 L
.7353 .57037 L
.7505 .56088 L
.76513 .54993 L
.7807 .53604 L
.79568 .52022 L
.81009 .50249 L
.82543 .48057 L
.8402 .45621 L
.8559 .42639 L
.87102 .3935 L
.88557 .35764 L
.90105 .31443 L
.91595 .26753 L
.93178 .21141 L
.94704 .15072 L
.96172 .08569 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<_ooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00006?ooool003?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001Oooooo000/ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Oooooo000eooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool05Oooool003;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Goooo
o`00<_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Gooooo`00<oooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Hooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`008Ooooooho`0000Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`02ooooo`;o0000M?ooool00ol0003oooooooooo`1booooo`;o00001Ooo
ool00ol0003oooooooooo`05ooooo`008Oooool2o`0000?ooooo0_l0001dooooo`03o`000?oooooo
oooo07;ooooo0_l00004ooooo`;o00001oooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`003Oooool3o`0000Cooooo0ol00003ooooo`;o00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`001_ooool5o`0000?ooooo00Co0000oooooooooooo
oooo1Ol00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool2o`00
07?ooooo00?o0000ooooooooool0L_ooool2o`0000Gooooo00?o0000ooooooooool01Oooool000ko
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`02ooooo`;o00001?ooool2o`0007?ooooo00?o0000ooooooooool0L_ooool2
o`0000Cooooo0_l00007ooooo`003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo000=ooooo`;o00001Oooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool2o`00
07;ooooo00?o0000ooooooooool0LOooool2o`0000Kooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool01?ooool2o`0007;ooooo00?o0000ooooooooool0LOooool2o`0000Ko
oooo00?o0000ooooooooool01Oooool0027ooooo0_l00006ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`04ooooo`;o00001oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Gooooo0_l0001aoooo
o`03o`000?oooooooooo073ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo00Gooooo0_l0001aooooo`03o`000?oooooooooo073ooooo0_l00007ooooo`03
o`000?oooooooooo00Gooooo000Qooooo`;o00001oooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool01Oooool2o`0000Oooooo000Qooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01_ooool2
o`00073ooooo00?o0000ooooooooool0Koooool2o`0000Sooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool01_ooool2o`00073ooooo00?o0000ooooooooool0Koooool2o`00
00Sooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`008Oooool2o`0000Sooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`1_ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo000=ooooo`?o00000_ooool5o`0000?ooooo0_l00005
ooooo`03o`000?oooooooooo00Oooooo0_l0001_ooooo`03o`000?oooooooooo06kooooo0_l00009
ooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Oooooo0_l0
001_ooooo`03o`000?oooooooooo06kooooo0_l00009ooooo`03o`000?oooooooooo00Gooooo0006
ooooo`Go00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo000>
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00;ooooo0_l00009ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`07ooooo`;o00001oooool000kooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`;o0000K_ooool00ol0003oooooooooo`1]ooooo`;o00002_ooool00ol0003ooooo
ooooo`05ooooo`003Oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool02?ooool2o`0006kooooo00?o0000oooooooo
ool0KOooool2o`0000[ooooo00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool0
0_ooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1Oooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`008Oooool2
o`0000[ooooo0_l0001]ooooo`03o`000?oooooooooo06cooooo0_l0000:ooooo`;o00001oooool0
027ooooo00?o0000ooooooooool02Oooool2o`0006gooooo00?o0000ooooooooool0K?ooool2o`00
00_ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`05ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00[ooooo0_l0001/ooooo`03o`000?oooooooooo06_ooooo0_l0
000<ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00002oooool2o`0006cooooo00?o0000
ooooooooool0Joooool2o`0000_ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool02oooool2o`0006_ooooo00?o0000ooooooooool0
J_ooool2o`0000gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02ooo
ool2o`0006_ooooo00?o0000ooooooooool0J_ooool2o`0000gooooo00?o0000ooooooooool01Ooo
ool0027ooooo0_l0000<ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`0;ooooo`;o00001oooool0027ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1Yooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`05ooooo`003Oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003o
ooooooooo`0;ooooo`;o0000Joooool00ol0003oooooooooo`1Yooooo`;o00003_ooool00ol0003o
ooooooooo`05ooooo`003_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0;ooooo`;o0000Joooool00ol0
003oooooooooo`1Yooooo`;o00003_ooool00ol0003oooooooooo`05ooooo`001_ooool5o`0000?o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo06Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`003_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool2o`0000gooooo0_l0001Zooooo`03o`000?oooooooooo06Sooooo0_l0000>ooooo`;o00001ooo
ool000kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool03?ooool2o`0006[ooooo00?o0000ooooooooool0
J?ooool2o`0000oooooo00?o0000ooooooooool01Oooool000gooooo0_l00004ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o0000
1Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
J?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oo
oooooooo00gooooo0_l0001Yooooo`03o`000?oooooooooo06Oooooo0_l0000@ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`;o00003_ooool2o`0006Wooooo00?o0000ooooooooool0Ioooool2
o`0000oooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00kooooo0_l0001Xooooo`03o`000?oooooooooo06Ko
oooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00kooooo
0_l0001Xooooo`03o`000?oooooooooo06Kooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000@
ooooo`;o0000Ioooool00ol0003oooooooooo`1Uooooo`;o00004Oooool2o`0000Oooooo000Qoooo
o`03o`000?oooooooooo00oooooo0_l0001Wooooo`03o`000?oooooooooo06Gooooo0_l0000Boooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0@ooooo`;o0000I_ooool00ol0003oooooooooo`1Tooooo`;o00004ooo
ool00ol0003oooooooooo`05ooooo`008Oooool2o`00017ooooo0_l0001Vooooo`03o`000?oooooo
oooo06Cooooo0_l0000Booooo`;o00001oooool0027ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`05ooooo`004oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo017o
oooo0_l0001Uooooo`03o`000?oooooooooo06?ooooo0_l0000Dooooo`03o`000?oooooooooo00Go
oooo000Booooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo017ooooo0_l0001Uooooo`03o`000?oooooooooo06?ooooo0_l0000Doooo
o`03o`000?oooooooooo00Gooooo000<ooooo`Go000000?oooooo`000?ooool00_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`05ooooo`004oooool3o`0000?ooooo00Co0000oooooooooooo00001?ooool2o`00
01?ooooo0_l0001Tooooo`03o`000?oooooooooo06?ooooo0_l0000Cooooo`;o00001oooool001;o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool04_ooool2o`0006Cooooo00?o0000ooooooooool0Hoooool2o`0001Cooooo00?o0000
ooooooooool01Oooool001;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`004oooool3
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo01?ooooo0_l0001Sooooo`03o`000?oooooo
oooo06;ooooo0_l0000Eooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
01?ooooo0_l0001Sooooo`03o`000?oooooooooo06;ooooo0_l0000Eooooo`03o`000?oooooooooo
00Gooooo000Qooooo`;o00005_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool04oooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo01Cooooo
0_l0001Rooooo`03o`000?oooooooooo067ooooo0_l0000Fooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo01Cooooo0_l0001Rooooo`03o`000?oooooooooo067ooooo0_l0
000Fooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool01Oooool0027ooooo00?o0000ooooooooool05Oooool2o`00067ooooo00?o0000oooo
ooooool0H?ooool2o`0001Oooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000Fooooo`;o
0000HOooool00ol0003oooooooooo`1Pooooo`;o00005_ooool2o`0000Oooooo000Qooooo`03o`00
0?oooooooooo01Kooooo0_l0001Pooooo`03o`000?oooooooooo05oooooo0_l0000Hooooo`03o`00
0?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Kooooo0_l0001Pooooo`03o`000?oo
oooooooo05oooooo0_l0000Hooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool05oooool2o`00
05oooooo00?o0000ooooooooool0G_ooool2o`0001Wooooo00?o0000ooooooooool01Oooool0027o
oooo0_l0000Hooooo`;o0000Goooool00ol0003oooooooooo`1Nooooo`;o00006?ooool2o`0000Oo
oooo000Qooooo`03o`000?oooooooooo01Sooooo0_l0001Nooooo`03o`000?oooooooooo05gooooo
0_l0000Jooooo`03o`000?oooooooooo00Gooooo000Cooooo`?o00001?ooool2o`0000Gooooo00?o
0000ooooooooool06?ooool2o`0005kooooo00?o0000ooooooooool0GOooool2o`0001[ooooo00?o
0000ooooooooool01Oooool001;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`003?oo
ool5o`000003ooooool0003ooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Wooooo0_l0001Mooooo`03o`000?oooooooooo05cooooo
0_l0000Kooooo`03o`000?oooooooooo00Gooooo000Booooo`Co00000oooool01?l0003ooooooooo
ool00004ooooo`;o00006_ooool2o`0005gooooo00?o0000ooooooooool0G?ooool2o`0001[ooooo
0_l00007ooooo`004_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool06_ooool2o`0005cooooo00?o0000ooooooooool0Foooool2o`0001cooooo
00?o0000ooooooooool01Oooool001?ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo01[ooooo0_l0001Looooo`03o`000?oooooooooo05_ooooo
0_l0000Looooo`03o`000?oooooooooo00Gooooo000Dooooo`;o00001?ooool2o`0000Gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0J
ooooo`;o0000G?ooool00ol0003oooooooooo`1Jooooo`;o00007Oooool00ol0003oooooooooo`05
ooooo`008Oooool2o`0001_ooooo0_l0001Looooo`03o`000?oooooooooo05[ooooo0_l0000Loooo
o`;o00001oooool0027ooooo00?o0000ooooooooool06oooool2o`0005_ooooo00?o0000oooooooo
ool0FOooool2o`0001kooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0
6oooool2o`0005_ooooo00?o0000ooooooooool0FOooool2o`0001kooooo00?o0000ooooooooool0
1Oooool0027ooooo00?o0000ooooooooool07?ooool2o`0005[ooooo00?o0000ooooooooool0F?oo
ool2o`0001oooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool07?ooool2
o`0005[ooooo00?o0000ooooooooool0F?ooool2o`0001oooooo00?o0000ooooooooool01Oooool0
027ooooo0_l0000Nooooo`;o0000FOooool00ol0003oooooooooo`1Gooooo`;o00007oooool2o`00
00Oooooo000Qooooo`03o`000?oooooooooo01gooooo0_l0001Iooooo`03o`000?oooooooooo05Oo
oooo0_l0000Pooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01kooooo
0_l0001Hooooo`03o`000?oooooooooo05Kooooo0_l0000Qooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo01kooooo0_l0001Hooooo`03o`000?oooooooooo05Kooooo0_l0
000Qooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01oooooo0_l0001G
ooooo`03o`000?oooooooooo05Kooooo0_l0000Qooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`;o00008?ooool2o`0005Oooooo00?o0000ooooooooool0E_ooool2o`00023ooooo0_l00007oooo
o`008Oooool00ol0003oooooooooo`0Pooooo`;o0000E_ooool00ol0003oooooooooo`1Eooooo`;o
00008_ooool00ol0003oooooooooo`05ooooo`005?ooool3o`0000?ooooo0_l00005ooooo`03o`00
0?oooooooooo023ooooo0_l0001Fooooo`03o`000?oooooooooo05Gooooo0_l0000Rooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo027ooooo0_l0001Eooooo`03o`000?oooooooooo05Cooooo
0_l0000Sooooo`03o`000?oooooooooo00Gooooo000<ooooo`Go000000?oooooo`000?l000000ol0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool08Oooool2o`0005Gooooo
00?o0000ooooooooool0E?ooool2o`0002?ooooo00?o0000ooooooooool01Oooool001;ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00004ooooo`;o00008oooool2o`0005Co
oooo00?o0000ooooooooool0Doooool2o`0002?ooooo0_l00007ooooo`004oooool00ol0003ooooo
o`000003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool08_ooool3o`0005?o
oooo00?o0000ooooooooool0D_ooool3o`0002Cooooo00?o0000ooooooooool01Oooool001Cooooo
0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool08oooool2o`0005?o
oooo00?o0000ooooooooool0D_ooool2o`0002Gooooo00?o0000ooooooooool01Oooool001Gooooo
00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool08oooool3o`0005;ooooo
00?o0000ooooooooool0DOooool2o`0002Kooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool09?ooool2o`0005;ooooo00?o0000ooooooooool0DOooool2o`0002Kooooo00?o
0000ooooooooool01Oooool0027ooooo0_l0000Uooooo`?o0000DOooool00ol0003oooooooooo`1@
ooooo`;o00009_ooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo02Gooooo0ol0001@oooo
o`03o`000?oooooooooo04oooooo0ol0000Wooooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo02Kooooo0_l0001@ooooo`03o`000?oooooooooo04oooooo0_l0000Xooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo02Kooooo0ol0001?ooooo`03o`00
0?oooooooooo04kooooo0_l0000Yooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oo
oooooooo02Oooooo0_l0001?ooooo`03o`000?oooooooooo04gooooo0ol0000Yooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`;o0000:?ooool2o`0004oooooo00?o0000ooooooooool0COooool2
o`0002Wooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0Xooooo`;o0000C_ooool00ol0
003oooooooooo`1<ooooo`;o0000:oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003o
ooooooooo`0Xooooo`?o0000COooool00ol0003oooooooooo`1;ooooo`?o0000:oooool00ol0003o
ooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Yooooo`?o0000C?ooool00ol0003ooooo
ooooo`1:ooooo`?o0000;?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooooooo
o`0Zooooo`;o0000C?ooool00ol0003oooooooooo`1:ooooo`;o0000;Oooool00ol0003ooooooooo
o`05ooooo`008Oooool2o`0002cooooo0_l0001;ooooo`03o`000?oooooooooo04Wooooo0_l0000]
ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0:oooool3o`0004[ooooo00?o0000oooo
ooooool0BOooool2o`0002kooooo00?o0000ooooooooool01Oooool001;ooooo1Ol00003ooooo`;o
00001Oooool00ol0003oooooooooo`0/ooooo`?o0000BOooool00ol0003oooooooooo`18ooooo`?o
0000;_ooool00ol0003oooooooooo`05ooooo`004oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;Oooool3o`0004Sooooo00?o0000oooo
ooooool0Aoooool3o`0002oooooo00?o0000ooooooooool01Oooool000cooooo1Ol00003ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0^oooo
o`?o0000Aoooool00ol0003oooooooooo`16ooooo`?o0000<?ooool00ol0003oooooooooo`05oooo
o`005Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool2o`00
033ooooo0ol00016ooooo`03o`000?oooooooooo04Gooooo0ol0000`ooooo`;o00001oooool001;o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0<?ooool3o`0004Gooooo00?o0000ooooooooool0A?ooool3o`0003;ooooo00?o0000
ooooooooool01Oooool001;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0<Oooool3o`0004Cooooo00?o0000ooooooooool0@ooo
ool3o`0003?ooooo00?o0000ooooooooool01Oooool001?ooooo0ol00004ooooo`;o00001Oooool0
0ol0003oooooooooo`0booooo`?o0000@oooool00ol0003oooooooooo`12ooooo`?o0000=?ooool0
0ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0cooooo`;o0000@oooool00ol0
003oooooooooo`11ooooo`?o0000=Oooool00ol0003oooooooooo`05ooooo`008Oooool2o`0003Co
oooo1?l00011ooooo`03o`000?oooooooooo03oooooo1?l0000eooooo`;o00001oooool0027ooooo
00?o0000ooooooooool0=?ooool4o`00043ooooo00?o0000ooooooooool0?_ooool4o`0003Oooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0=_ooool3o`0003oooooo00?o
0000ooooooooool0?Oooool3o`0003Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000
ooooooooool0=oooool4o`0003gooooo00?o0000ooooooooool0??ooool3o`0003[ooooo00?o0000
ooooooooool01Oooool0027ooooo00?o0000ooooooooool0>?ooool4o`0003cooooo00?o0000oooo
ooooool0>oooool4o`0003[ooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000kooooo`Co
0000>_ooool00ol0003oooooooooo`0iooooo`Co0000>oooool2o`0000Oooooo000Qooooo`03o`00
0?oooooooooo03_ooooo1Ol0000hooooo`03o`000?oooooooooo03Oooooo1Ol0000mooooo`03o`00
0?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo03gooooo1?l0000gooooo`03o`000?oo
oooooooo03Gooooo1Ol0000oooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo03oooooo1?l0000eooooo`03o`000?oooooooooo03?ooooo1Ol00011ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo043ooooo1_l0000booooo`03o`000?oooooooooo
037ooooo1Ol00013ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000@oooool7o`0002oo
oooo00?o0000ooooooooool0;_ooool6o`0004Cooooo0_l00007ooooo`008Oooool00ol0003ooooo
ooooo`15ooooo`So0000:oooool00ol0003oooooooooo`0Zooooo`So0000Aoooool00ol0003ooooo
ooooo`05ooooo`006_ooool2o`0000Gooooo00?o0000ooooooooool0B?ooool9o`0002Oooooo00?o
0000ooooooooool09_ooool9o`0004[ooooo00?o0000ooooooooool01Oooool001Wooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1;ooooo`co00008Oooool00ol0003ooooooooo
o`0Oooooo`co0000C_ooool00ol0003oooooooooo`05ooooo`006Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo04ooooooE?l0001Aooooo`03o`000?oooooooooo00Gooooo000I
ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001GooooodGo0000F?ooool2o`0000Oooooo000I
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00Gooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool001[ooooo0_l00005ooooooSo00001oooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool003?ooooo0ol0002:ooooo`03o`000?oooooooooo02_ooooo0ol0
000Eooooo`03o`000?oooooooooo01Oooooo000dooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Kooooo000^oooo
o`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000?ooooo1?l000000ooo
oooo0000o`000003o`0000Oooooo0ol00004ooooo`Co00000oooool2o`0000;ooooo1_l00006oooo
o`Co00000_ooool5o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol00002oooo
o`?o00000_ooool3o`0000Cooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo0ol00003
ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo1?l00003
ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00000_ooool3o`0000;ooooo0ol00000
1?oooooo0000o`000?ooool4o`0000?ooooo0_l00002ooooo`[o00001Oooool00ol0003ooooooooo
o`0Eooooo`00;Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`00;Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`03o`000?oooooooooo00;o
oooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5o`0000Sooooo00?o0000
ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`03o`000?oo
oooo000000;ooooo1Ol00003ooooo`04o`000?ooooooooooooooo`Go00000_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0002ooooo`?o00001Oooool00ol0003oooooooooo`0Eooooo`00;Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Gooooo00Ko0000oooooooo
oooo0000ooooool00008ooooo`03o`000?oooooooooo01Gooooo000]ooooo`06o`000?oooooooooo
ooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol00003ooooo`;o00001Ooo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co0000
0oooool3o`0000Wooooo00Go0000oooooooooooo0000ooooo`03o`0000Cooooo1?l00002ooooo`Co
00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`0000?o
oooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`Ko000000?oooooo`000?l0
00000oooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`03o`000?oooooooooo00;o
oooo0ol00002ooooo`Co00000oooool9o`0000?ooooo0ol00003ooooo`Co00001?ooool00ol0003o
ooooooooo`0Eooooo`00;Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool05_ooool002kooooo0ol00009ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03Oooool3o`0000Wooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo0_l0000:oooo
o`Co00001?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool2o`0002kooooo00?o0000oooo
ooooool06?ooool3o`0001Kooooo00?o0000ooooooooool00_ooool2o`0000_ooooo00?o0000oooo
ooooool05oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-30.2812, -161.15, 0.192895, \
0.999621}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.824662 0.00972763 0.000270038 [
[.0052 -0.00277 -12 -9 ]
[.0052 -0.00277 12 0 ]
[.17014 -0.00277 -12 -9 ]
[.17014 -0.00277 12 0 ]
[.33507 -0.00277 -12 -9 ]
[.33507 -0.00277 12 0 ]
[.5 -0.00277 -3 -9 ]
[.5 -0.00277 3 0 ]
[.66493 -0.00277 -9 -9 ]
[.66493 -0.00277 9 0 ]
[.82986 -0.00277 -9 -9 ]
[.82986 -0.00277 9 0 ]
[.9948 -0.00277 -9 -9 ]
[.9948 -0.00277 9 0 ]
[.01131 .14475 -18 -4.5 ]
[.01131 .14475 0 4.5 ]
[.01131 .27977 -24 -4.5 ]
[.01131 .27977 0 4.5 ]
[.01131 .41478 -24 -4.5 ]
[.01131 .41478 0 4.5 ]
[.01131 .5498 -24 -4.5 ]
[.01131 .5498 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0052 .00973 m
.0052 .01598 L
s
[(-0.6)] .0052 -0.00277 0 1 Mshowa
.17014 .00973 m
.17014 .01598 L
s
[(-0.4)] .17014 -0.00277 0 1 Mshowa
.33507 .00973 m
.33507 .01598 L
s
[(-0.2)] .33507 -0.00277 0 1 Mshowa
.5 .00973 m
.5 .01598 L
s
[(0)] .5 -0.00277 0 1 Mshowa
.66493 .00973 m
.66493 .01598 L
s
[(0.2)] .66493 -0.00277 0 1 Mshowa
.82986 .00973 m
.82986 .01598 L
s
[(0.4)] .82986 -0.00277 0 1 Mshowa
.9948 .00973 m
.9948 .01598 L
s
[(0.6)] .9948 -0.00277 0 1 Mshowa
.125 Mabswid
.04644 .00973 m
.04644 .01348 L
s
.08767 .00973 m
.08767 .01348 L
s
.1289 .00973 m
.1289 .01348 L
s
.21137 .00973 m
.21137 .01348 L
s
.2526 .00973 m
.2526 .01348 L
s
.29383 .00973 m
.29383 .01348 L
s
.3763 .00973 m
.3763 .01348 L
s
.41753 .00973 m
.41753 .01348 L
s
.45877 .00973 m
.45877 .01348 L
s
.54123 .00973 m
.54123 .01348 L
s
.58247 .00973 m
.58247 .01348 L
s
.6237 .00973 m
.6237 .01348 L
s
.70617 .00973 m
.70617 .01348 L
s
.7474 .00973 m
.7474 .01348 L
s
.78863 .00973 m
.78863 .01348 L
s
.8711 .00973 m
.8711 .01348 L
s
.91233 .00973 m
.91233 .01348 L
s
.95356 .00973 m
.95356 .01348 L
s
.25 Mabswid
0 .00973 m
1 .00973 L
s
.02381 .14475 m
.03006 .14475 L
s
[(500)] .01131 .14475 1 0 Mshowa
.02381 .27977 m
.03006 .27977 L
s
[(1000)] .01131 .27977 1 0 Mshowa
.02381 .41478 m
.03006 .41478 L
s
[(1500)] .01131 .41478 1 0 Mshowa
.02381 .5498 m
.03006 .5498 L
s
[(2000)] .01131 .5498 1 0 Mshowa
.125 Mabswid
.02381 .03673 m
.02756 .03673 L
s
.02381 .06374 m
.02756 .06374 L
s
.02381 .09074 m
.02756 .09074 L
s
.02381 .11774 m
.02756 .11774 L
s
.02381 .17175 m
.02756 .17175 L
s
.02381 .19875 m
.02756 .19875 L
s
.02381 .22576 m
.02756 .22576 L
s
.02381 .25276 m
.02756 .25276 L
s
.02381 .30677 m
.02756 .30677 L
s
.02381 .33377 m
.02756 .33377 L
s
.02381 .36078 m
.02756 .36078 L
s
.02381 .38778 m
.02756 .38778 L
s
.02381 .44179 m
.02756 .44179 L
s
.02381 .46879 m
.02756 .46879 L
s
.02381 .4958 m
.02756 .4958 L
s
.02381 .5228 m
.02756 .5228 L
s
.02381 .57681 m
.02756 .57681 L
s
.02381 .60381 m
.02756 .60381 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01574 m
.02434 .01522 L
.02487 .01567 L
.0254 .01521 L
.02593 .01534 L
.02646 .01525 L
.02699 .01494 L
.02752 .01522 L
.02805 .01472 L
.02858 .0152 L
.02911 .01474 L
.02964 .0151 L
.03017 .01507 L
.0307 .01496 L
.03123 .01539 L
.03176 .01494 L
.03229 .0155 L
.03282 .01499 L
.03335 .01533 L
.03388 .01516 L
.03442 .01502 L
.03495 .0153 L
.03548 .01482 L
.03601 .0154 L
.03654 .01489 L
.03707 .01535 L
.0376 .01529 L
.03813 .01523 L
.03866 .01565 L
.03919 .01523 L
.03972 .0158 L
.04025 .01528 L
.04078 .01563 L
.04131 .01541 L
.04184 .01527 L
.04237 .01548 L
.0429 .01501 L
.04343 .01549 L
.04396 .015 L
.04449 .01538 L
.04502 .01528 L
.04555 .01528 L
.04608 .01555 L
.04661 .01527 L
.04714 .01572 L
.04767 .01524 L
.0482 .01561 L
.04873 .01531 L
.04926 .01527 L
.04979 .01535 L
Mistroke
.05032 .01497 L
.05085 .01535 L
.05138 .01488 L
.05191 .01529 L
.05244 .01512 L
.05297 .01522 L
.05351 .01544 L
.05404 .01522 L
.05457 .01572 L
.0551 .01525 L
.05563 .01571 L
.05616 .01544 L
.05669 .01545 L
.05722 .01559 L
.05775 .01524 L
.05828 .01566 L
.05881 .01521 L
.05934 .01564 L
.05987 .01549 L
.0604 .01555 L
.06093 .0158 L
.06146 .01552 L
.06199 .01597 L
.06252 .01551 L
.06305 .01583 L
.06358 .01558 L
.06411 .01545 L
.06464 .01554 L
.06517 .01518 L
.0657 .01545 L
.06623 .01508 L
.06676 .01539 L
.06729 .01526 L
.06782 .01533 L
.06835 .01556 L
.06888 .01537 L
.06941 .01576 L
.06994 .01543 L
.07047 .01574 L
.071 .01554 L
.07153 .01551 L
.07206 .01561 L
.0726 .01534 L
.07313 .01563 L
.07366 .01529 L
.07419 .01567 L
.07472 .01551 L
.07525 .0156 L
.07578 .01586 L
.07631 .01559 L
Mistroke
.07684 .01602 L
.07737 .01564 L
.0779 .01594 L
.07843 .01573 L
.07896 .01564 L
.07949 .01583 L
.08002 .01544 L
.08055 .01582 L
.08108 .01548 L
.08161 .01577 L
.08214 .01573 L
.08267 .01565 L
.0832 .01599 L
.08373 .01561 L
.08426 .01594 L
.08479 .01561 L
.08532 .0157 L
.08585 .01558 L
.08638 .01538 L
.08691 .0156 L
.08744 .01523 L
.08797 .01558 L
.0885 .0154 L
.08903 .0156 L
.08956 .01573 L
.09009 .01567 L
.09062 .01606 L
.09115 .01577 L
.09169 .01609 L
.09222 .0159 L
.09275 .01594 L
.09328 .01592 L
.09381 .01573 L
.09434 .01598 L
.09487 .01561 L
.0954 .01597 L
.09593 .01579 L
.09646 .01589 L
.09699 .01603 L
.09752 .01583 L
.09805 .01618 L
.09858 .01576 L
.09911 .01607 L
.09964 .01582 L
.10017 .01574 L
.1007 .0159 L
.10123 .01554 L
.10176 .01594 L
.10229 .01559 L
.10282 .01589 L
Mistroke
.10335 .01592 L
.10388 .01576 L
.10441 .01614 L
.10494 .01576 L
.10547 .01606 L
.106 .01577 L
.10653 .01583 L
.10706 .01582 L
.10759 .01557 L
.10812 .01593 L
.10865 .01561 L
.10918 .01599 L
.10971 .01594 L
.11024 .01607 L
.11078 .01633 L
.11131 .01609 L
.11184 .01652 L
.11237 .01614 L
.1129 .01631 L
.11343 .01618 L
.11396 .01599 L
.11449 .01614 L
.11502 .01578 L
.11555 .01613 L
.11608 .01584 L
.11661 .01603 L
.11714 .01614 L
.11767 .01597 L
.1182 .01627 L
.11873 .01596 L
.11926 .01622 L
.11979 .01593 L
.12032 .01596 L
.12085 .01601 L
.12138 .01572 L
.12191 .01609 L
.12244 .01578 L
.12297 .01614 L
.1235 .01608 L
.12403 .01609 L
.12456 .01645 L
.12509 .01601 L
.12562 .01646 L
.12615 .01611 L
.12668 .01616 L
.12721 .01622 L
.12774 .01594 L
.12827 .01633 L
.1288 .01596 L
.12934 .01639 L
Mistroke
.12987 .01635 L
.1304 .01634 L
.13093 .01669 L
.13146 .01633 L
.13199 .01667 L
.13252 .01628 L
.13305 .01636 L
.13358 .01625 L
.13411 .01594 L
.13464 .01624 L
.13517 .01584 L
.1357 .01619 L
.13623 .01607 L
.13676 .01619 L
.13729 .01644 L
.13782 .01613 L
.13835 .01661 L
.13888 .0162 L
.13941 .01632 L
.13994 .01632 L
.14047 .01603 L
.141 .01634 L
.14153 .01601 L
.14206 .01638 L
.14259 .01628 L
.14312 .0164 L
.14365 .01669 L
.14418 .01645 L
.14471 .01684 L
.14524 .01651 L
.14577 .01669 L
.1463 .01654 L
.14683 .01635 L
.14736 .01662 L
.14789 .01618 L
.14843 .01657 L
.14896 .01639 L
.14949 .01646 L
.15002 .01666 L
.15055 .01637 L
.15108 .01678 L
.15161 .0163 L
.15214 .01652 L
.15267 .01644 L
.1532 .01613 L
.15373 .01652 L
.15426 .01612 L
.15479 .0165 L
.15532 .01643 L
.15585 .01647 L
Mistroke
.15638 .01678 L
.15691 .01643 L
.15744 .01684 L
.15797 .01651 L
.1585 .01658 L
.15903 .0166 L
.15956 .01637 L
.16009 .01674 L
.16062 .01638 L
.16115 .01685 L
.16168 .0168 L
.16221 .01677 L
.16274 .0172 L
.16327 .01675 L
.1638 .0171 L
.16433 .01674 L
.16486 .0167 L
.16539 .01671 L
.16592 .01629 L
.16645 .01671 L
.16698 .01631 L
.16752 .01658 L
.16805 .01672 L
.16858 .01654 L
.16911 .01697 L
.16964 .01661 L
.17017 .01691 L
.1707 .01672 L
.17123 .01658 L
.17176 .01682 L
.17229 .01644 L
.17282 .0168 L
.17335 .01665 L
.17388 .01682 L
.17441 .01696 L
.17494 .01681 L
.17547 .01723 L
.176 .01679 L
.17653 .01708 L
.17706 .01699 L
.17759 .01674 L
.17812 .01712 L
.17865 .01674 L
.17918 .01711 L
.17971 .01701 L
.18024 .01702 L
.18077 .01729 L
.1813 .01686 L
.18183 .0172 L
.18236 .01682 L
Mistroke
.18289 .01679 L
.18342 .01681 L
.18395 .01651 L
.18448 .01688 L
.18501 .01659 L
.18554 .01696 L
.18607 .01706 L
.18661 .01691 L
.18714 .01736 L
.18767 .01696 L
.1882 .01719 L
.18873 .017 L
.18926 .0169 L
.18979 .0171 L
.19032 .01675 L
.19085 .01729 L
.19138 .01707 L
.19191 .01725 L
.19244 .0176 L
.19297 .01719 L
.1935 .01764 L
.19403 .01719 L
.19456 .01722 L
.19509 .01723 L
.19562 .01679 L
.19615 .01724 L
.19668 .01689 L
.19721 .01715 L
.19774 .01734 L
.19827 .01715 L
.1988 .01753 L
.19933 .01714 L
.19986 .01736 L
.20039 .0171 L
.20092 .01689 L
.20145 .01719 L
.20198 .01672 L
.20251 .01719 L
.20304 .01719 L
.20357 .01722 L
.2041 .01767 L
.20463 .01738 L
.20516 .01777 L
.2057 .01747 L
.20623 .01744 L
.20676 .01758 L
.20729 .01713 L
.20782 .01756 L
.20835 .01732 L
.20888 .01748 L
Mistroke
.20941 .01771 L
.20994 .01744 L
.21047 .01785 L
.211 .01739 L
.21153 .01747 L
.21206 .01746 L
.21259 .01703 L
.21312 .01741 L
.21365 .01715 L
.21418 .01736 L
.21471 .01752 L
.21524 .01747 L
.21577 .01779 L
.2163 .01744 L
.21683 .0177 L
.21736 .01747 L
.21789 .01727 L
.21842 .01759 L
.21895 .01725 L
.21948 .01767 L
.22001 .0177 L
.22054 .01777 L
.22107 .01813 L
.2216 .01775 L
.22213 .01809 L
.22266 .01778 L
.22319 .01763 L
.22372 .01783 L
.22425 .01744 L
.22479 .0178 L
.22532 .01765 L
.22585 .01781 L
.22638 .01798 L
.22691 .01761 L
.22744 .018 L
.22797 .01755 L
.2285 .01753 L
.22903 .01771 L
.22956 .01728 L
.23009 .01771 L
.23062 .0176 L
.23115 .01783 L
.23168 .01812 L
.23221 .01789 L
.23274 .01832 L
.23327 .01789 L
.2338 .018 L
.23433 .01807 L
.23486 .01763 L
.23539 .01806 L
Mistroke
.23592 .01778 L
.23645 .01808 L
.23698 .01833 L
.23751 .01803 L
.23804 .01851 L
.23857 .018 L
.2391 .01808 L
.23963 .01819 L
.24016 .01764 L
.24069 .01801 L
.24122 .01776 L
.24175 .01796 L
.24228 .01819 L
.24281 .01793 L
.24334 .01832 L
.24388 .0179 L
.24441 .01807 L
.24494 .01818 L
.24547 .01768 L
.246 .01818 L
.24653 .01802 L
.24706 .01825 L
.24759 .01861 L
.24812 .01829 L
.24865 .01872 L
.24918 .01842 L
.24971 .01845 L
.25024 .01851 L
.25077 .01799 L
.2513 .01839 L
.25183 .01825 L
.25236 .01834 L
.25289 .01854 L
.25342 .01823 L
.25395 .01862 L
.25448 .01829 L
.25501 .01827 L
.25554 .01833 L
.25607 .01788 L
.2566 .01841 L
.25713 .01834 L
.25766 .01832 L
.25819 .01867 L
.25872 .01845 L
.25925 .01877 L
.25978 .01851 L
.26031 .01839 L
.26084 .01853 L
.26137 .01827 L
.2619 .01876 L
Mistroke
.26244 .01865 L
.26297 .01868 L
.2635 .01913 L
.26403 .01885 L
.26456 .01906 L
.26509 .0187 L
.26562 .01852 L
.26615 .01874 L
.26668 .01832 L
.26721 .01862 L
.26774 .01859 L
.26827 .01856 L
.2688 .01902 L
.26933 .01865 L
.26986 .01873 L
.27039 .01864 L
.27092 .01855 L
.27145 .01881 L
.27198 .01845 L
.27251 .0189 L
.27304 .01908 L
.27357 .01899 L
.2741 .01943 L
.27463 .01895 L
.27516 .01908 L
.27569 .01914 L
.27622 .01874 L
.27675 .01902 L
.27728 .0188 L
.27781 .01916 L
.27834 .01937 L
.27887 .01898 L
.2794 .0194 L
.27993 .01906 L
.28046 .01899 L
.28099 .01906 L
.28153 .01857 L
.28206 .01904 L
.28259 .01899 L
.28312 .01903 L
.28365 .01938 L
.28418 .01895 L
.28471 .01944 L
.28524 .01928 L
.28577 .01888 L
.2863 .01939 L
.28683 .01915 L
.28736 .01949 L
.28789 .01967 L
.28842 .01944 L
Mistroke
.28895 .0199 L
.28948 .01952 L
.29001 .01949 L
.29054 .01939 L
.29107 .01896 L
.2916 .01952 L
.29213 .01927 L
.29266 .01928 L
.29319 .01973 L
.29372 .01943 L
.29425 .01974 L
.29478 .01941 L
.29531 .01918 L
.29584 .01958 L
.29637 .0192 L
.2969 .01956 L
.29743 .01969 L
.29796 .01958 L
.29849 .0202 L
.29902 .01974 L
.29955 .01971 L
.30008 .01986 L
.30062 .01954 L
.30115 .01995 L
.30168 .01968 L
.30221 .01988 L
.30274 .0204 L
.30327 .01986 L
.3038 .02011 L
.30433 .01988 L
.30486 .01952 L
.30539 .0199 L
.30592 .01944 L
.30645 .01963 L
.30698 .02002 L
.30751 .01988 L
.30804 .02023 L
.30857 .01991 L
.3091 .01999 L
.30963 .02025 L
.31016 .01977 L
.31069 .02014 L
.31122 .02025 L
.31175 .0203 L
.31228 .02066 L
.31281 .02023 L
.31334 .0204 L
.31387 .02036 L
.3144 .02001 L
.31493 .02028 L
Mistroke
.31546 .02002 L
.31599 .02038 L
.31652 .0207 L
.31705 .02022 L
.31758 .02054 L
.31811 .02039 L
.31864 .02013 L
.31917 .02024 L
.31971 .01992 L
.32024 .02041 L
.32077 .02062 L
.3213 .02045 L
.32183 .02095 L
.32236 .02065 L
.32289 .02073 L
.32342 .02086 L
.32395 .0203 L
.32448 .02082 L
.32501 .02096 L
.32554 .02079 L
.32607 .02112 L
.3266 .0208 L
.32713 .02093 L
.32766 .02079 L
.32819 .02026 L
.32872 .0207 L
.32925 .02068 L
.32978 .02074 L
.33031 .0211 L
.33084 .02085 L
.33137 .02117 L
.3319 .02107 L
.33243 .02071 L
.33296 .021 L
.33349 .02092 L
.33402 .02125 L
.33455 .02141 L
.33508 .02112 L
.33561 .02165 L
.33614 .02141 L
.33667 .02105 L
.3372 .02133 L
.33773 .02112 L
.33826 .02144 L
.3388 .02152 L
.33933 .02123 L
.33986 .02163 L
.34039 .02128 L
.34092 .02109 L
.34145 .02123 L
Mistroke
.34198 .02093 L
.34251 .02154 L
.34304 .02172 L
.34357 .02145 L
.3441 .02207 L
.34463 .02186 L
.34516 .02166 L
.34569 .02177 L
.34622 .02143 L
.34675 .02196 L
.34728 .02204 L
.34781 .02175 L
.34834 .02226 L
.34887 .02197 L
.3494 .02177 L
.34993 .02185 L
.35046 .02144 L
.35099 .02189 L
.35152 .02209 L
.35205 .02188 L
.35258 .02225 L
.35311 .02209 L
.35364 .0221 L
.35417 .02207 L
.3547 .02171 L
.35523 .02234 L
.35576 .02251 L
.35629 .02231 L
.35682 .02278 L
.35735 .02258 L
.35789 .02254 L
.35842 .02256 L
.35895 .02213 L
.35948 .02257 L
.36001 .02267 L
.36054 .02245 L
.36107 .02272 L
.3616 .02237 L
.36213 .02245 L
.36266 .02259 L
.36319 .02213 L
.36372 .02275 L
.36425 .02312 L
.36478 .02288 L
.36531 .02323 L
.36584 .02294 L
.36637 .02293 L
.3669 .02313 L
.36743 .02263 L
.36796 .02316 L
Mistroke
.36849 .02357 L
.36902 .02318 L
.36955 .0235 L
.37008 .0232 L
.37061 .02293 L
.37114 .02328 L
.37167 .02288 L
.3722 .02309 L
.37273 .02364 L
.37326 .02342 L
.37379 .02353 L
.37432 .02334 L
.37485 .02327 L
.37538 .02374 L
.37591 .02345 L
.37645 .02372 L
.37698 .02436 L
.37751 .02401 L
.37804 .02405 L
.37857 .0239 L
.3791 .02359 L
.37963 .02404 L
.38016 .02383 L
.38069 .0238 L
.38122 .02432 L
.38175 .02399 L
.38228 .02397 L
.38281 .02399 L
.38334 .02374 L
.38387 .02443 L
.3844 .02455 L
.38493 .0243 L
.38546 .02484 L
.38599 .02463 L
.38652 .0244 L
.38705 .02454 L
.38758 .02435 L
.38811 .02499 L
.38864 .0252 L
.38917 .02468 L
.3897 .02511 L
.39023 .02485 L
.39076 .02436 L
.39129 .02478 L
.39182 .02462 L
.39235 .02491 L
.39288 .0256 L
.39341 .02505 L
.39394 .02508 L
.39447 .02542 L
Mistroke
.395 .0251 L
.39554 .02546 L
.39607 .02565 L
.3966 .02571 L
.39713 .02624 L
.39766 .02567 L
.39819 .02529 L
.39872 .02573 L
.39925 .02549 L
.39978 .02565 L
.40031 .026 L
.40084 .02582 L
.40137 .02619 L
.4019 .02599 L
.40243 .02556 L
.40296 .02622 L
.40349 .02638 L
.40402 .0264 L
.40455 .02686 L
.40508 .02644 L
.40561 .02651 L
.40614 .02687 L
.40667 .02632 L
.4072 .0267 L
.40773 .02733 L
.40826 .02691 L
.40879 .02686 L
.40932 .02665 L
.40985 .02648 L
.41038 .02704 L
.41091 .02695 L
.41144 .02714 L
.41197 .02794 L
.4125 .02757 L
.41303 .02739 L
.41356 .02766 L
.41409 .02739 L
.41463 .02797 L
.41516 .02833 L
.41569 .02773 L
.41622 .02808 L
.41675 .0281 L
.41728 .02752 L
.41781 .02796 L
.41834 .02815 L
.41887 .02827 L
.4194 .02889 L
.41993 .02834 L
.42046 .0281 L
.42099 .02891 L
Mistroke
.42152 .02877 L
.42205 .02882 L
.42258 .02947 L
.42311 .02928 L
.42364 .02931 L
.42417 .02925 L
.4247 .02883 L
.42523 .02947 L
.42576 .02979 L
.42629 .02935 L
.42682 .02964 L
.42735 .0295 L
.42788 .02935 L
.42841 .03015 L
.42894 .03017 L
.42947 .03026 L
.43 .03117 L
.43053 .03069 L
.43106 .0301 L
.43159 .03063 L
.43212 .03069 L
.43265 .03098 L
.43318 .03138 L
.43372 .03083 L
.43425 .03098 L
.43478 .03134 L
.43531 .03084 L
.43584 .03134 L
.43637 .03217 L
.4369 .03197 L
.43743 .0321 L
.43796 .03207 L
.43849 .03181 L
.43902 .03267 L
.43955 .03305 L
.44008 .03264 L
.44061 .03297 L
.44114 .0328 L
.44167 .03242 L
.4422 .033 L
.44273 .03309 L
.44326 .03329 L
.44379 .03426 L
.44432 .03381 L
.44485 .03327 L
.44538 .03432 L
.44591 .03476 L
.44644 .03467 L
.44697 .03509 L
.4475 .03472 L
Mistroke
.44803 .0345 L
.44856 .03502 L
.44909 .03491 L
.44962 .03529 L
.45015 .03624 L
.45068 .03589 L
.45121 .0356 L
.45174 .03606 L
.45227 .03615 L
.45281 .03693 L
.45334 .03781 L
.45387 .03715 L
.4544 .03699 L
.45493 .03769 L
.45546 .03752 L
.45599 .03774 L
.45652 .03842 L
.45705 .03816 L
.45758 .03835 L
.45811 .03887 L
.45864 .0386 L
.45917 .03947 L
.4597 .04087 L
.46023 .04031 L
.46076 .03985 L
.46129 .04054 L
.46182 .04063 L
.46235 .04103 L
.46288 .04182 L
.46341 .04142 L
.46394 .0414 L
.46447 .04237 L
.465 .04258 L
.46553 .04298 L
.46606 .04398 L
.46659 .04392 L
.46712 .04394 L
.46765 .04469 L
.46818 .04469 L
.46871 .04516 L
.46924 .04649 L
.46977 .04611 L
.4703 .04538 L
.47083 .04659 L
.47136 .04771 L
.4719 .04808 L
.47243 .04892 L
.47296 .04909 L
.47349 .04907 L
.47402 .05046 L
Mistroke
.47455 .05125 L
.47508 .05078 L
.47561 .05137 L
.47614 .05225 L
.47667 .05244 L
.4772 .05364 L
.47773 .05508 L
.47826 .05519 L
.47879 .05578 L
.47932 .05707 L
.47985 .05748 L
.48038 .05825 L
.48091 .05984 L
.48144 .06029 L
.48197 .0605 L
.4825 .06191 L
.48303 .06324 L
.48356 .06457 L
.48409 .06651 L
.48462 .06724 L
.48515 .06745 L
.48568 .06981 L
.48621 .07238 L
.48674 .07271 L
.48727 .07338 L
.4878 .07585 L
.48833 .07863 L
.48886 .08208 L
.48939 .08606 L
.48992 .0882 L
.49045 .08952 L
.49099 .09217 L
.49152 .09358 L
.49205 .09183 L
.49258 .08996 L
.49311 .09003 L
.49364 .09274 L
.49417 .10169 L
.4947 .11932 L
.49523 .14515 L
.49576 .18283 L
.49629 .23702 L
.49682 .30258 L
.49735 .36999 L
.49788 .43758 L
.49841 .50465 L
.49894 .56043 L
.49947 .59336 L
.5 .60332 L
.50053 .59337 L
Mistroke
.50106 .56043 L
.50159 .50464 L
.50212 .43758 L
.50265 .36999 L
.50318 .30258 L
.50371 .23702 L
.50424 .18283 L
.50477 .14514 L
.5053 .11932 L
.50583 .10169 L
.50636 .09274 L
.50689 .09003 L
.50742 .08996 L
.50795 .09183 L
.50848 .09358 L
.50901 .09217 L
.50955 .08952 L
.51008 .0882 L
.51061 .08606 L
.51114 .08208 L
.51167 .07863 L
.5122 .07584 L
.51273 .07338 L
.51326 .07271 L
.51379 .07237 L
.51432 .06981 L
.51485 .06745 L
.51538 .06724 L
.51591 .06651 L
.51644 .06457 L
.51697 .06324 L
.5175 .06191 L
.51803 .0605 L
.51856 .06029 L
.51909 .05984 L
.51962 .05825 L
.52015 .05748 L
.52068 .05706 L
.52121 .05577 L
.52174 .05519 L
.52227 .05508 L
.5228 .05363 L
.52333 .05244 L
.52386 .05225 L
.52439 .05136 L
.52492 .05078 L
.52545 .05125 L
.52598 .05046 L
.52651 .04907 L
.52704 .04909 L
Mistroke
.52757 .04892 L
.5281 .04808 L
.52864 .04771 L
.52917 .04658 L
.5297 .04538 L
.53023 .04611 L
.53076 .04649 L
.53129 .04517 L
.53182 .04469 L
.53235 .04469 L
.53288 .04394 L
.53341 .04392 L
.53394 .04398 L
.53447 .04298 L
.535 .04258 L
.53553 .04237 L
.53606 .0414 L
.53659 .04142 L
.53712 .04182 L
.53765 .04103 L
.53818 .04063 L
.53871 .04054 L
.53924 .03985 L
.53977 .04031 L
.5403 .04087 L
.54083 .03947 L
.54136 .0386 L
.54189 .03886 L
.54242 .03835 L
.54295 .03816 L
.54348 .03842 L
.54401 .03774 L
.54454 .03752 L
.54507 .03769 L
.5456 .03699 L
.54613 .03715 L
.54666 .03781 L
.54719 .03693 L
.54773 .03615 L
.54826 .03606 L
.54879 .0356 L
.54932 .0359 L
.54985 .03624 L
.55038 .03529 L
.55091 .03492 L
.55144 .03502 L
.55197 .0345 L
.5525 .03472 L
.55303 .03509 L
.55356 .03467 L
Mistroke
.55409 .03476 L
.55462 .03432 L
.55515 .03327 L
.55568 .03381 L
.55621 .03426 L
.55674 .03329 L
.55727 .03309 L
.5578 .033 L
.55833 .03242 L
.55886 .0328 L
.55939 .03297 L
.55992 .03264 L
.56045 .03305 L
.56098 .03267 L
.56151 .03181 L
.56204 .03207 L
.56257 .0321 L
.5631 .03197 L
.56363 .03217 L
.56416 .03134 L
.56469 .03084 L
.56522 .03134 L
.56575 .03098 L
.56628 .03083 L
.56682 .03138 L
.56735 .03098 L
.56788 .03069 L
.56841 .03063 L
.56894 .0301 L
.56947 .0307 L
.57 .03117 L
.57053 .03026 L
.57106 .03017 L
.57159 .03014 L
.57212 .02935 L
.57265 .0295 L
.57318 .02964 L
.57371 .02936 L
.57424 .02979 L
.57477 .02947 L
.5753 .02883 L
.57583 .02925 L
.57636 .02931 L
.57689 .02928 L
.57742 .02947 L
.57795 .02882 L
.57848 .02877 L
.57901 .02891 L
.57954 .0281 L
.58007 .02834 L
Mistroke
.5806 .02889 L
.58113 .02827 L
.58166 .02815 L
.58219 .02796 L
.58272 .02752 L
.58325 .0281 L
.58378 .02808 L
.58431 .02773 L
.58484 .02833 L
.58537 .02797 L
.58591 .02739 L
.58644 .02766 L
.58697 .02739 L
.5875 .02757 L
.58803 .02794 L
.58856 .02714 L
.58909 .02695 L
.58962 .02703 L
.59015 .02648 L
.59068 .02665 L
.59121 .02686 L
.59174 .02691 L
.59227 .02733 L
.5928 .0267 L
.59333 .02632 L
.59386 .02687 L
.59439 .02651 L
.59492 .02644 L
.59545 .02686 L
.59598 .0264 L
.59651 .02638 L
.59704 .02622 L
.59757 .02556 L
.5981 .02599 L
.59863 .02619 L
.59916 .02582 L
.59969 .026 L
.60022 .02565 L
.60075 .0255 L
.60128 .02573 L
.60181 .02529 L
.60234 .02567 L
.60287 .02624 L
.6034 .02571 L
.60393 .02565 L
.60446 .02546 L
.605 .0251 L
.60553 .02542 L
.60606 .02508 L
.60659 .02505 L
Mistroke
.60712 .0256 L
.60765 .02491 L
.60818 .02462 L
.60871 .02478 L
.60924 .02436 L
.60977 .02485 L
.6103 .02511 L
.61083 .02469 L
.61136 .0252 L
.61189 .02499 L
.61242 .02435 L
.61295 .02453 L
.61348 .0244 L
.61401 .02463 L
.61454 .02484 L
.61507 .0243 L
.6156 .02455 L
.61613 .02443 L
.61666 .02374 L
.61719 .02399 L
.61772 .02397 L
.61825 .02399 L
.61878 .02432 L
.61931 .0238 L
.61984 .02383 L
.62037 .02403 L
.6209 .02359 L
.62143 .0239 L
.62196 .02405 L
.62249 .02401 L
.62302 .02436 L
.62355 .02372 L
.62409 .02345 L
.62462 .02373 L
.62515 .02327 L
.62568 .02334 L
.62621 .02352 L
.62674 .02342 L
.62727 .02364 L
.6278 .02309 L
.62833 .02288 L
.62886 .02328 L
.62939 .02293 L
.62992 .0232 L
.63045 .0235 L
.63098 .02318 L
.63151 .02357 L
.63204 .02316 L
.63257 .02263 L
.6331 .02313 L
Mistroke
.63363 .02293 L
.63416 .02294 L
.63469 .02323 L
.63522 .02288 L
.63575 .02312 L
.63628 .02275 L
.63681 .02213 L
.63734 .02258 L
.63787 .02245 L
.6384 .02237 L
.63893 .02272 L
.63946 .02245 L
.63999 .02267 L
.64052 .02257 L
.64105 .02213 L
.64158 .02256 L
.64211 .02254 L
.64265 .02258 L
.64318 .02278 L
.64371 .02231 L
.64424 .02251 L
.64477 .02234 L
.6453 .02171 L
.64583 .02207 L
.64636 .0221 L
.64689 .02209 L
.64742 .02225 L
.64795 .02188 L
.64848 .02209 L
.64901 .02189 L
.64954 .02145 L
.65007 .02185 L
.6506 .02177 L
.65113 .02197 L
.65166 .02226 L
.65219 .02175 L
.65272 .02204 L
.65325 .02195 L
.65378 .02144 L
.65431 .02177 L
.65484 .02166 L
.65537 .02186 L
.6559 .02207 L
.65643 .02145 L
.65696 .02172 L
.65749 .02154 L
.65802 .02093 L
.65855 .02123 L
.65908 .02109 L
.65961 .02128 L
Mistroke
.66014 .02163 L
.66067 .02123 L
.6612 .02152 L
.66174 .02144 L
.66227 .02113 L
.6628 .02133 L
.66333 .02105 L
.66386 .02142 L
.66439 .02165 L
.66492 .02112 L
.66545 .02141 L
.66598 .02125 L
.66651 .02092 L
.66704 .021 L
.66757 .02071 L
.6681 .02107 L
.66863 .02116 L
.66916 .02085 L
.66969 .0211 L
.67022 .02074 L
.67075 .02068 L
.67128 .02069 L
.67181 .02026 L
.67234 .02079 L
.67287 .02093 L
.6734 .0208 L
.67393 .02112 L
.67446 .02079 L
.67499 .02096 L
.67552 .02081 L
.67605 .0203 L
.67658 .02086 L
.67711 .02073 L
.67764 .02065 L
.67817 .02095 L
.6787 .02045 L
.67923 .02062 L
.67976 .02041 L
.68029 .01992 L
.68083 .02024 L
.68136 .02013 L
.68189 .02039 L
.68242 .02054 L
.68295 .02022 L
.68348 .0207 L
.68401 .02037 L
.68454 .02002 L
.68507 .02027 L
.6856 .02001 L
.68613 .02036 L
Mistroke
.68666 .0204 L
.68719 .02023 L
.68772 .02066 L
.68825 .0203 L
.68878 .02025 L
.68931 .02014 L
.68984 .01977 L
.69037 .02025 L
.6909 .01999 L
.69143 .01991 L
.69196 .02023 L
.69249 .01988 L
.69302 .02002 L
.69355 .01963 L
.69408 .01944 L
.69461 .0199 L
.69514 .01952 L
.69567 .01988 L
.6962 .02011 L
.69673 .01986 L
.69726 .02039 L
.69779 .01988 L
.69832 .01968 L
.69885 .01995 L
.69938 .01955 L
.69992 .01986 L
.70045 .01971 L
.70098 .01975 L
.70151 .0202 L
.70204 .01958 L
.70257 .01969 L
.7031 .01956 L
.70363 .0192 L
.70416 .01958 L
.70469 .01918 L
.70522 .01941 L
.70575 .01974 L
.70628 .01944 L
.70681 .01973 L
.70734 .01928 L
.70787 .01927 L
.7084 .01952 L
.70893 .01896 L
.70946 .01939 L
.70999 .01949 L
.71052 .01952 L
.71105 .0199 L
.71158 .01944 L
.71211 .01967 L
.71264 .01949 L
Mistroke
.71317 .01915 L
.7137 .01939 L
.71423 .01888 L
.71476 .01928 L
.71529 .01944 L
.71582 .01896 L
.71635 .01938 L
.71688 .01903 L
.71741 .01899 L
.71794 .01904 L
.71847 .01857 L
.71901 .01906 L
.71954 .01899 L
.72007 .01906 L
.7206 .0194 L
.72113 .01898 L
.72166 .01937 L
.72219 .01916 L
.72272 .0188 L
.72325 .01902 L
.72378 .01874 L
.72431 .01914 L
.72484 .01908 L
.72537 .01896 L
.7259 .01943 L
.72643 .01899 L
.72696 .01908 L
.72749 .0189 L
.72802 .01845 L
.72855 .01881 L
.72908 .01855 L
.72961 .01864 L
.73014 .01873 L
.73067 .01866 L
.7312 .01902 L
.73173 .01856 L
.73226 .01859 L
.73279 .01862 L
.73332 .01832 L
.73385 .01874 L
.73438 .01852 L
.73491 .01871 L
.73544 .01906 L
.73597 .01885 L
.7365 .01913 L
.73703 .01868 L
.73756 .01865 L
.7381 .01876 L
.73863 .01827 L
.73916 .01853 L
Mistroke
.73969 .01839 L
.74022 .01851 L
.74075 .01877 L
.74128 .01845 L
.74181 .01867 L
.74234 .01831 L
.74287 .01834 L
.7434 .01841 L
.74393 .01788 L
.74446 .01833 L
.74499 .01826 L
.74552 .01829 L
.74605 .01862 L
.74658 .01824 L
.74711 .01854 L
.74764 .01834 L
.74817 .01825 L
.7487 .01839 L
.74923 .01799 L
.74976 .01851 L
.75029 .01845 L
.75082 .01842 L
.75135 .01872 L
.75188 .01829 L
.75241 .01861 L
.75294 .01825 L
.75347 .01802 L
.754 .01818 L
.75453 .01768 L
.75506 .01818 L
.75559 .01807 L
.75612 .0179 L
.75666 .01832 L
.75719 .01793 L
.75772 .01819 L
.75825 .01796 L
.75878 .01777 L
.75931 .01801 L
.75984 .01765 L
.76037 .0182 L
.7609 .01808 L
.76143 .01801 L
.76196 .01851 L
.76249 .01803 L
.76302 .01833 L
.76355 .01807 L
.76408 .01778 L
.76461 .01806 L
.76514 .01764 L
.76567 .01807 L
Mistroke
.7662 .018 L
.76673 .01789 L
.76726 .01832 L
.76779 .0179 L
.76832 .01812 L
.76885 .01783 L
.76938 .0176 L
.76991 .0177 L
.77044 .01728 L
.77097 .01771 L
.7715 .01753 L
.77203 .01755 L
.77256 .018 L
.77309 .01761 L
.77362 .01798 L
.77415 .0178 L
.77468 .01766 L
.77521 .0178 L
.77575 .01744 L
.77628 .01783 L
.77681 .01763 L
.77734 .01778 L
.77787 .01808 L
.7784 .01775 L
.77893 .01813 L
.77946 .01777 L
.77999 .0177 L
.78052 .01767 L
.78105 .01725 L
.78158 .01759 L
.78211 .01727 L
.78264 .01747 L
.78317 .01769 L
.7837 .01744 L
.78423 .01779 L
.78476 .01747 L
.78529 .01752 L
.78582 .01736 L
.78635 .01716 L
.78688 .01741 L
.78741 .01703 L
.78794 .01746 L
.78847 .01747 L
.789 .0174 L
.78953 .01785 L
.79006 .01744 L
.79059 .01771 L
.79112 .01748 L
.79165 .01733 L
.79218 .01756 L
Mistroke
.79271 .01713 L
.79324 .01758 L
.79377 .01744 L
.7943 .01748 L
.79484 .01777 L
.79537 .01738 L
.7959 .01767 L
.79643 .01722 L
.79696 .0172 L
.79749 .01718 L
.79802 .01672 L
.79855 .01719 L
.79908 .01688 L
.79961 .0171 L
.80014 .01735 L
.80067 .01715 L
.8012 .01753 L
.80173 .01715 L
.80226 .01734 L
.80279 .01714 L
.80332 .01689 L
.80385 .01724 L
.80438 .01678 L
.80491 .01723 L
.80544 .01721 L
.80597 .0172 L
.8065 .01764 L
.80703 .01719 L
.80756 .01761 L
.80809 .01725 L
.80862 .01708 L
.80915 .01728 L
.80968 .01675 L
.81021 .0171 L
.81074 .0169 L
.81127 .01701 L
.8118 .01718 L
.81233 .01696 L
.81286 .01736 L
.81339 .01691 L
.81393 .01706 L
.81446 .01695 L
.81499 .01659 L
.81552 .01688 L
.81605 .01651 L
.81658 .01682 L
.81711 .01678 L
.81764 .01683 L
.81817 .0172 L
.8187 .01687 L
Mistroke
.81923 .0173 L
.81976 .01702 L
.82029 .01701 L
.82082 .0171 L
.82135 .01674 L
.82188 .01712 L
.82241 .01673 L
.82294 .017 L
.82347 .01708 L
.824 .0168 L
.82453 .01723 L
.82506 .01681 L
.82559 .01697 L
.82612 .01681 L
.82665 .01665 L
.82718 .0168 L
.82771 .01644 L
.82824 .01683 L
.82877 .01658 L
.8293 .01672 L
.82983 .01691 L
.83036 .01661 L
.83089 .01698 L
.83142 .01654 L
.83195 .01672 L
.83248 .01657 L
.83302 .01632 L
.83355 .01671 L
.83408 .01628 L
.83461 .01672 L
.83514 .01669 L
.83567 .01675 L
.8362 .0171 L
.83673 .01675 L
.83726 .01721 L
.83779 .01677 L
.83832 .0168 L
.83885 .01685 L
.83938 .01638 L
.83991 .01674 L
.84044 .01636 L
.84097 .0166 L
.8415 .01658 L
.84203 .01651 L
.84256 .01685 L
.84309 .01643 L
.84362 .01679 L
.84415 .01647 L
.84468 .01643 L
.84521 .01649 L
Mistroke
.84574 .01612 L
.84627 .01653 L
.8468 .01612 L
.84733 .01644 L
.84786 .01651 L
.84839 .01631 L
.84892 .01678 L
.84945 .01637 L
.84998 .01667 L
.85051 .01646 L
.85104 .0164 L
.85157 .01657 L
.85211 .01618 L
.85264 .01663 L
.85317 .01635 L
.8537 .01655 L
.85423 .01669 L
.85476 .01651 L
.85529 .01684 L
.85582 .01644 L
.85635 .0167 L
.85688 .01639 L
.85741 .01629 L
.85794 .01638 L
.85847 .01601 L
.859 .01634 L
.85953 .01603 L
.86006 .01633 L
.86059 .01632 L
.86112 .0162 L
.86165 .01661 L
.86218 .01613 L
.86271 .01645 L
.86324 .01618 L
.86377 .01608 L
.8643 .01619 L
.86483 .01584 L
.86536 .01624 L
.86589 .01593 L
.86642 .01626 L
.86695 .01635 L
.86748 .01628 L
.86801 .01668 L
.86854 .01632 L
.86907 .0167 L
.8696 .01633 L
.87013 .01635 L
.87066 .01639 L
.8712 .01596 L
.87173 .01634 L
Mistroke
.87226 .01593 L
.87279 .01622 L
.87332 .01616 L
.87385 .01612 L
.87438 .01646 L
.87491 .01601 L
.87544 .01646 L
.87597 .01608 L
.8765 .01609 L
.87703 .01614 L
.87756 .01578 L
.87809 .0161 L
.87862 .01571 L
.87915 .01602 L
.87968 .01595 L
.88021 .01593 L
.88074 .01622 L
.88127 .01595 L
.8818 .01628 L
.88233 .01596 L
.88286 .01614 L
.88339 .01602 L
.88392 .01584 L
.88445 .01613 L
.88498 .01577 L
.88551 .01615 L
.88604 .01599 L
.88657 .01618 L
.8871 .01631 L
.88763 .01614 L
.88816 .01653 L
.88869 .01608 L
.88922 .01633 L
.88976 .01606 L
.89029 .01594 L
.89082 .01599 L
.89135 .0156 L
.89188 .01594 L
.89241 .01556 L
.89294 .01583 L
.89347 .01583 L
.894 .01577 L
.89453 .01606 L
.89506 .01575 L
.89559 .01615 L
.89612 .01576 L
.89665 .01592 L
.89718 .01589 L
.89771 .01558 L
.89824 .01595 L
Mistroke
.89877 .01553 L
.8993 .0159 L
.89983 .01574 L
.90036 .01582 L
.90089 .01607 L
.90142 .01576 L
.90195 .01619 L
.90248 .01583 L
.90301 .01604 L
.90354 .01589 L
.90407 .01579 L
.9046 .01597 L
.90513 .01561 L
.90566 .01599 L
.90619 .01573 L
.90672 .01592 L
.90725 .01594 L
.90778 .01589 L
.90831 .0161 L
.90885 .01576 L
.90938 .01606 L
.90991 .01566 L
.91044 .01573 L
.91097 .01561 L
.9115 .01539 L
.91203 .01558 L
.91256 .01522 L
.91309 .0156 L
.91362 .01538 L
.91415 .01558 L
.91468 .01571 L
.91521 .01561 L
.91574 .01594 L
.91627 .0156 L
.9168 .01599 L
.91733 .01565 L
.91786 .01573 L
.91839 .01578 L
.91892 .01547 L
.91945 .01582 L
.91998 .01544 L
.92051 .01583 L
.92104 .01564 L
.92157 .01573 L
.9221 .01594 L
.92263 .01563 L
.92316 .01602 L
.92369 .01559 L
.92422 .01587 L
.92475 .0156 L
Mistroke
.92528 .01551 L
.92581 .01567 L
.92634 .01528 L
.92687 .01564 L
.9274 .01533 L
.92794 .01561 L
.92847 .01551 L
.929 .01554 L
.92953 .01575 L
.93006 .01543 L
.93059 .01576 L
.93112 .01537 L
.93165 .01556 L
.93218 .01533 L
.93271 .01526 L
.93324 .0154 L
.93377 .01507 L
.9343 .01546 L
.93483 .01518 L
.93536 .01554 L
.93589 .01545 L
.93642 .01557 L
.93695 .01583 L
.93748 .0155 L
.93801 .01598 L
.93854 .01552 L
.93907 .0158 L
.9396 .01555 L
.94013 .01548 L
.94066 .01564 L
.94119 .01521 L
.94172 .01566 L
.94225 .01523 L
.94278 .01559 L
.94331 .01545 L
.94384 .01544 L
.94437 .01572 L
.9449 .01525 L
.94543 .01572 L
.94596 .01522 L
.94649 .01544 L
.94703 .01522 L
.94756 .01511 L
.94809 .01529 L
.94862 .01488 L
.94915 .01535 L
.94968 .01496 L
.95021 .01535 L
.95074 .01527 L
.95127 .01531 L
Mistroke
.9518 .01562 L
.95233 .01524 L
.95286 .01572 L
.95339 .01527 L
.95392 .01555 L
.95445 .01529 L
.95498 .01527 L
.95551 .01538 L
.95604 .01499 L
.95657 .01549 L
.9571 .01501 L
.95763 .01548 L
.95816 .01528 L
.95869 .01541 L
.95922 .01563 L
.95975 .01527 L
.96028 .0158 L
.96081 .01523 L
.96134 .01565 L
.96187 .01524 L
.9624 .01529 L
.96293 .01535 L
.96346 .01488 L
.96399 .0154 L
.96452 .01482 L
.96505 .0153 L
.96558 .01503 L
.96612 .01516 L
.96665 .01534 L
.96718 .01499 L
.96771 .0155 L
.96824 .01493 L
.96877 .01539 L
.9693 .01496 L
.96983 .01507 L
.97036 .0151 L
.97089 .01473 L
.97142 .0152 L
.97195 .01472 L
.97248 .01522 L
.97301 .01494 L
.97354 .01524 L
.97407 .01535 L
.9746 .01521 L
.97513 .01568 L
.97566 .01522 L
.97619 .01574 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001_ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0ol0000Jooooo`;o00001?ooool01?l0003oooooooooooooool5
o`0001kooooo0_l0000Qooooo`;o00001?ooool01?l0003oooooooooooooool5o`0001_ooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0ol0000Jooooo`;o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00001oooool001Gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000001Wooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Hooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00007Oooool01?l0003oooooooooool0
000Oooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00006_ooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Kooooo000>ooooo`Go00000_ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000004_ooool5o`0000;ooooo00Co0000oooooooooooo
00001oooool5o`0001;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool07Oooool01?l0003oooooooooool0000Oooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool06_ooool01?l0003oooooooooool00007ooooo`Go00006Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool001Gooooo00Co0000oooooooo
oooo00001oooool4o`0001[ooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
000Jooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool07?ooool01?l0003ooooo
ooooool0000Oooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool06Oooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0001[ooooo00Co0000oooooooooooo0000
1oooool4o`0000Oooooo000Eooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
6oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000001[ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000001gooooo00Co0000oooooooooooo00007ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000006_ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000001[ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`08ooooo`005Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo01[ooooo00Co0000oooooooooooo00002Oooool2o`0001[ooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000001gooooo00Co0000oooooooooooo00007oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000006_ooool01?l0003ooooooooo
ool00009ooooo`;o00006_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Oo
oooo000Fooooo`;o00002_ooool2o`0001_ooooo0_l0000;ooooo`03o`000?oooooooooo01Wooooo
0_l00009ooooo`?o00007oooool2o`00027ooooo0_l00009ooooo`?o00007?ooool2o`0000_ooooo
00?o0000ooooooooool06Oooool2o`0000[ooooo0_l00007ooooo`00oooooolQooooo`007_ooool0
0ol0003oooooooooo`3oooooo`007_ooool00ol0003oooooooooo`3oooooo`007_ooool00ol0003o
ooooooooo`3oooooo`006?ooooolo`0000cooooo000Jooooo`04o`000?ooooooooooooooobko0000
00?oooooo`000?ooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02go0000
1?ooool00ol0003oooooooooo`0;ooooo`007_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooo000002Wo0000DooooolXo`000003ooooool0003o000003Gooooo000Nooooo`03o`000?oooooo
oooo04Sooooo4ol0000eoooooa;o0000GOooool001kooooo00?o0000ooooooooool0FOooool:o`00
02Gooooo2_l0001]ooooo`007_ooool00ol0003oooooooooo`1Qooooo`Ko00007?ooool7o`0007Go
oooo000Nooooo`;o0000Ioooool4o`0001Oooooo1?l0001jooooo`007_ooool00ol0003ooooooooo
o`1Yooooo`?o00004_ooool4o`0007gooooo000Nooooo`03o`000?oooooooooo06_ooooo0ol0000?
ooooo`?o0000Ooooool001kooooo00?o0000ooooooooool0KOooool2o`0000gooooo0_l00021oooo
o`007_ooool00ol0003oooooooooo`1^ooooo`;o00002oooool2o`0008;ooooo000Nooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`22ooooo`007_oo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo0_l00024ooooo`007_ooool2
o`00077ooooo0_l00007ooooo`03o`000?oooooooooo08?ooooo000Nooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool01?ooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`24ooooo`007_ooool00ol0003ooooo
ooooo`1aooooo`;o00001Oooool00ol0003oooooooooo`24ooooo`007_ooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Q?ooool001kooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Cooooo000Noooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`25oooo
o`007_ooool2o`0007?ooooo0_l00002ooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`02o`0008Oooooo000Nooooo`03o`000?oooooooooo07?ooooo00Co
0000oooooooooooo0000R?ooool001kooooo00?o0000ooooooooool0Loooool01?l0003ooooooooo
ool00028ooooo`007_ooool00ol0003oooooooooo`1cooooo`04o`000?ooooooooooo`0008Sooooo
000Nooooo`03o`000?oooooooooo07?ooooo00Co0000oooooooooooo0000R?ooool001kooooo00?o
0000ooooooooool0Loooool01?l0003oooooooooool00028ooooo`007_ooool2o`0007Cooooo00Co
0000oooooooooooo0000R?ooool001kooooo00?o0000ooooooooool0Loooool01?l0003ooooooooo
ool00028ooooo`007_ooool00ol0003oooooooooo`1cooooo`04o`000?ooooooooooo`0008Sooooo
000Nooooo`03o`000?oooooooooo07?ooooo00Co0000oooooooooooo0000R?ooool000[ooooo0ol0
0004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0M?ooool00ol0003oooooo`00
0028ooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooool0
0000R?ooool000gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M?ooool00ol0003oooooo`000028oooo
o`003Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool3o`0007Cooooo00?o0000ooooool00000R?ooool000Wooooo1?l00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooo000008Sooooo0009ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Cooooo
00?o0000ooooool00000R?ooool000Wooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0M?ooool00ol0003oooooo`000028ooooo`007_ooool00ol0003oooooooooo`1d
ooooo`03o`000?oooooo000008Sooooo000Nooooo`03o`000?oooooooooo07Cooooo00?o0000oooo
ool00000R?ooool001kooooo0_l0001eooooo`03o`000?oooooo000008Sooooo000Nooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooool00000R?ooool001kooooo00?o0000ooooooooool0M?oo
ool00ol0003oooooo`000028ooooo`007_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooo
000008Sooooo000Nooooo`03o`000?oooooooooo07Cooooo00?o0000ooooool00000R?ooool001ko
oooo00?o0000ooooooooool0M?ooool00ol0003oooooo`000028ooooo`007_ooool00ol0003ooooo
ooooo`1dooooo`03o`000?oooooo000008Sooooo000Nooooo`;o0000MOooool00ol0003oooooo`00
0028ooooo`007_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooo000008Sooooo000Noooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooool00000R?ooool001kooooo00?o0000oooooooo
ool0M?ooool00ol0003oooooo`000028ooooo`007_ooool00ol0003oooooooooo`1dooooo`03o`00
0?oooooo000008Sooooo000Nooooo`03o`000?oooooooooo07Cooooo00?o0000ooooool00000R?oo
ool001kooooo00?o0000ooooooooool0M?ooool00ol0003oooooo`000028ooooo`007_ooool2o`00
07Gooooo00?o0000ooooool00000R?ooool001kooooo00?o0000ooooooooool0M?ooool00ol0003o
ooooo`000028ooooo`007_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooo000008Sooooo
000Nooooo`03o`000?oooooooooo07Cooooo00?o0000ooooool00000R?ooool001kooooo00?o0000
ooooooooool0M?ooool00ol0003oooooo`000028ooooo`007_ooool00ol0003oooooooooo`1doooo
o`03o`000?oooooo000008Sooooo000Nooooo`03o`000?oooooooooo07Cooooo00?o0000ooooool0
0000R?ooool001kooooo0_l0001eooooo`03o`000?oooooo000008Sooooo000Nooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooool00000R?ooool001kooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooo`000028ooooo`007_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooo0000
08Sooooo0004ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooo000008Sooooo0005ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0M?ooool00ol0003oooooo`000028ooooo`001Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`?o0000M?ooool00ol0003oooooo`000028ooooo`001Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Cooooo00?o0000oooo
ool00000R?ooool000Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooo000008Sooooo0004ooooo`;o00001?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooo000008Sooooo0005ooooo`03o`000?oooooooooo00?ooooo
0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
o`000028ooooo`007_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooo000008Sooooo000N
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooool00000R?ooool001kooooo0_l0001eoooo
o`03o`000?oooooo000008Sooooo000Nooooo`03o`000?oooooooooo07Cooooo00?o0000ooooool0
0000R?ooool001kooooo00?o0000ooooooooool0M?ooool00ol0003oooooo`000028ooooo`007_oo
ool00ol0003oooooooooo`1dooooo`03o`000?oooooo000008Sooooo000Nooooo`03o`000?oooooo
oooo07Cooooo00?o0000ooooool00000R?ooool001kooooo00?o0000ooooooooool0M?ooool00ol0
003oooooo`000028ooooo`007_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooo000008So
oooo000Nooooo`;o0000MOooool00ol0003oooooo`000028ooooo`007_ooool00ol0003ooooooooo
o`1dooooo`;o0000ROooool001kooooo00?o0000ooooooooool0M?ooool2o`0008Wooooo000Noooo
o`03o`000?oooooooooo07Cooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o
0000ROooool001kooooo00?o0000ooooooooool0M?ooool2o`0008Wooooo000Nooooo`03o`000?oo
oooooooo07Cooooo0_l00029ooooo`007_ooool2o`0007Gooooo0_l00029ooooo`007_ooool00ol0
003oooooooooo`1dooooo`;o0000ROooool001kooooo00?o0000ooooooooool0M?ooool2o`0008Wo
oooo000Nooooo`03o`000?oooooooooo07Cooooo0_l00029ooooo`007_ooool00ol0003ooooooooo
o`1dooooo`;o0000ROooool001kooooo00?o0000ooooooooool0M?ooool2o`0008Wooooo000Noooo
o`03o`000?oooooooooo07Cooooo0_l00029ooooo`007_ooool2o`0007Gooooo0_l00029ooooo`00
7_ooool00ol0003oooooooooo`1dooooo`;o0000ROooool001kooooo00?o0000ooooooooool0M?oo
ool2o`0008Wooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l00029ooooo`001?ooool3o`00
00?ooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0M?ooool2o`00
08Wooooo0005ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1dooooo`;o0000ROooool000Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool3o`0007Cooooo
0_l00029ooooo`001Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Co
oooo0_l00029ooooo`001Oooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Cooooo0_l00029
ooooo`001?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0M?ooool2o`0008Wooooo0005
ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`03o`000?oo
oooooooo07Cooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o0000ROooool0
01kooooo00?o0000ooooooooool0M?ooool2o`0008Wooooo000Nooooo`;o0000MOooool2o`0008Wo
oooo000Nooooo`03o`000?oooooooooo07Cooooo0_l00029ooooo`007_ooool00ol0003ooooooooo
o`1dooooo`;o0000ROooool001kooooo00?o0000ooooooooool0M?ooool2o`0008Wooooo000Noooo
o`03o`000?oooooooooo07Cooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o
0000ROooool001kooooo00?o0000ooooooooool0M?ooool2o`0008Wooooo000Nooooo`;o0000MOoo
ool2o`0008Wooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l00029ooooo`007_ooool00ol0
003oooooooooo`1dooooo`;o0000ROooool001kooooo00?o0000ooooooooool0M?ooool2o`0008Wo
oooo000Nooooo`03o`000?oooooooooo07Cooooo0_l00029ooooo`007_ooool00ol0003ooooooooo
o`1dooooo`;o0000ROooool001kooooo00?o0000ooooooooool0M?ooool2o`0008Wooooo000Noooo
o`;o0000MOooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l00029ooooo`00
7_ooool00ol0003oooooooooo`1dooooo`;o0000ROooool001kooooo00?o0000ooooooooool0M?oo
ool2o`0008Wooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l00029ooooo`007_ooool00ol0
003oooooooooo`1dooooo`;o0000ROooool001kooooo0_l0001eooooo`;o0000ROooool001kooooo
00?o0000ooooooooool0M?ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l0
0029ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o0000ROooool001kooooo00?o0000oooo
ooooool0M?ooool2o`0008Wooooo0003ooooo`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o
00001Oooool00ol0003oooooooooo`1dooooo`;o0000ROooool000Cooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1dooooo`;o0000ROooool000Gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool3o`0007Cooooo0_l00029ooooo`001_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M?ooool2o`0008Wooooo0003oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1dooooo`;o
0000ROooool000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo07Cooooo0_l00029ooooo`001?ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2
o`0000Gooooo00?o0000ooooooooool0M?ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo
07Cooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o0000ROooool001kooooo
0_l0001eooooo`;o0000ROooool001kooooo00?o0000ooooooooool0MOooool00ol0003ooooooooo
o`27ooooo`007_ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo08Oooooo000Noooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0Qoooool001kooooo00?o0000oooooooo
ool0MOooool00ol0003oooooooooo`27ooooo`007_ooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo08Oooooo000Nooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0Qooo
ool001kooooo0_l0001fooooo`03o`000?oooooooooo08Oooooo000Nooooo`03o`000?oooooooooo
0?oooooo000Nooooo`03o`000?oooooooooo0?oooooo000Nooooo`03o`000?oooooooooo0?oooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo001Sooooo`?o0000DOooool3o`0006Ko
oooo001Tooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0IOooool003Wooooo0ol0
0004ooooo`?o00000_ooool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o0000
2Oooool3o`0000?ooooo0ol00002ooooo`?o00001?ooool3o`0000?ooooo1?l00002ooooo`Co0000
1oooool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00000oooool3o`0000;o
oooo0ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003ooooo`;o00001?ooool00ol0003o
ooooooooo`07ooooo`?o00001Oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0
003ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?oooooo`00
0?l00000;Oooool003[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005oooo
o`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
0000;_ooool003[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`Go00000_oo
ool3o`0000;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooo
oooo00000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000Wooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002
ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
02cooooo000jooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo0_l00003
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`07o`000?ooooooooooooooool0003o
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`?o
00000oooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool01?l0003oooooooooool00006ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo02cooooo000jooooo`04o`000?ooooooooooo`00
00;ooooo0ol00002ooooo`?o00000oooool4o`0000;ooooo1?l00009ooooo`03o`000?oooooooooo
00;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo0_l00004oooo
o`?o00002_ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4
o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0
003o000000Sooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Co0000
0oooool3o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l0000_ooooo`00>_oo
ool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo
00007?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000oooo
ooooool0@Oooool003Wooooo1?l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool3o`0001_ooooo0_l00008ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool5o`0001Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0jooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.725901, -179.095, \
0.00483183, 14.7558}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] 0.49966958432041564`\), 
        ",", \(BackFocalLength \[Rule] 93.35095557506479`\), 
        ",", \(BackFocalPoint \[Rule] {153.3509555750648`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] 1.1548749586253269`\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] 0\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {50.`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.583004929987583`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {53.41699507001242`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 1\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 1, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] False\), 
        ",", \(FindPupils \[Rule] True\), ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 99.93396050505237`\), 
        ",", \(FrequencyCutoff \[Rule] 832.8527023200849`\), 
        ",", \(FrontFocalLength \[Rule] 99.93396050505234`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-49.93396050505234`\), 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {153.3515167236328`, 0, 0}\), 
        ",", \(ImageSampleSize \[Rule] 0.0006430261462279103`\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[100, 50, 10], 50.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[Screen[50], {x, 150.`}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(IntensityTransform \[Rule] True\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.9341264481391712`, 
              6.583004929987581`}, {\(-0.010006608313591684`\), 
              0.9999999999999998`}}\), ",", \(NormalizePlot \[Rule] False\), 
        ",", \(NumberOfPoints \[Rule] 2048\), 
        ",", \(NumberOfRays \[Rule] 256\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(LineOfRays[45, NumberOfRays \[Rule] 11]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 58.623418168034135`\), ",", 
        
        RowBox[{"OpticalLengthFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-22.703523173378176`\), 
                  22.703523173378176`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-22.703523173378176`\), 
                  22.703523173378176`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {58.546050203027676`, 
            58.623418168034135`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PaddingFactor \[Rule] Automatic\), 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.6578157475911522`\), 
                  0.6584587737373802`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] True\), 
        ",", \(PlotPoints \[Rule] 64\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.6578157475911522`\), 
                  0.6584587737373802`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{50.00000000000003`, 0, 
              0}, {53.41699507001243`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 3.4169950700124048`\), 
        ",", \(RayBoundary \[Rule] {\(-22.703523173378176`\), 
            22.703523173378176`}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {PointSpreadFunction, 
            OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] True\), 
        ",", \(ShowPerfectCase \[Rule] False\), 
        ",", \(SignalPlotCutoff \[Rule] 0.01`\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 2190\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.028407457959089465`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{0.033531699915919685`, 
              98.25958992578354`}, {\(-0.010006608313591682`\), 
              0.49966958432041564`}}\), 
        ",", \(TransverseMagnification \[Rule] 0.033531699915919685`\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-23.384982224770795`\), 
                  23.35495197952244`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[26]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.4 Zernike Polynomials and Seidel Aberrations", "Subsection",
  CellTags->{"AOG0.", "5.4", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{

Cell["?ZernikeFit", "Input",
  CellLabel->"In[27]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[BoxData[
    \("ZernikeFit[{{coordinatepoint, opticalpathlength},...}, options] is a \
utility function that attempts to find a Zernike polynomial equation fit to \
the wavefront data as given by a list of two-dimensional coordinates and \
optical path length values (in wavelength units).\n\nZernikeFit->True is also \
a option that indicates the use of a Zernike polynomial equation fit to a \
wavefront. ZernikeFit->False usually indicates the use of an Interpolation \
function instead.\n\n See also: ZernikePolynomial, ZernikeOrder, \
SeidelAberrations,  and ResidualFitError."\)], "Print",
  CellTags->{"Info3313756493-3229688", "AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?SeidelAberrations", "Input",
  CellLabel->"In[28]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[BoxData[
    \("SeidelAberrations is a rule returned by ZernikeFit that gives the \
primary-Seidel aberration terms for the given wavefront.\n\n These Seidel \
aberration terms are called SphericalAberration (B),  Astigmatism (C), \
FieldCurvature (D), Distortion (E), and Coma (F), and are given by the \
equation: phasedifference = -1/4 B rho^4 - C yo^2 rho^2 Cos[theta]^2 - 1/2 D \
yo^2 rho^2 + E yo^3 rho Cos[theta] + F yo rho^3 Cos[theta]. See also: \
ZernikeFit, ZernikePolynomial, ResidualFitError, and ZernikeOrder."\)], \
"Print",
  CellTags->{"Info3313756493-6366474", "AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],

Cell[TextData[{
  StyleBox["ZernikeFit", "Input"],
  " may be called directly. ",
  StyleBox["SeidelAberrations", "Input"],
  " is one of the results returned by ",
  StyleBox["ZernikeFit", "Input"],
  "."
}], "Text",
  CellLabel->"In[73]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{

Cell["\<\
ZernikeFit[ReadTurboRays[TurboTrace[colsys32, \
ReportedSurfaces->Last],{SurfaceCoordinates,OpticalLength}]]\
\>", "Input",
  CellLabel->"In[29]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(ResidualFitError \[Rule] 2.528143964807474`*^-7\), 
        ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
              4199.565609496804`, 
            Astigmatism \[Rule] \(-0.3674817785287542`\), 
            FieldCurvature \[Rule] \(-2066.074081886578`\), 
            Distortion \[Rule] \(-6.297181442009891`*^-12\), 
            Coma \[Rule] 1.1038935179793206`*^-11}\), ",", 
        RowBox[{"ZernikePolynomial", "\[Rule]", 
          
          TagBox[\(CompiledFunction[
              If[#1 == 0 && #2 == 0, 
                213.2480751380951`, \(\(213.2394348352914`\)\(\
\[InvisibleSpace]\)\) - 
                  1.3282002225000779`*^-9\ Cos[
                      2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                  1.4659753859254313`*^-10\ Cos[
                      4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                  0.01315166344752725`\ \((\(-1\) + 
                        0.013836140242371764`\ \((#1\^2 + #2\^2)\))\) - 
                  1.990701156673646`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.020754210363557644`\)\ \
\((#1\^2 + #2\^2)\) + 0.00019143877680657937`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  0.004736151495641903`\ \((1 - 
                        0.04150842072711529`\ \((#1\^2 + #2\^2)\) + 
                        0.00028715816520986904`\ \((#1\^2 + #2\^2)\)\^2)\) + 
                  2.5530111538861066`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((\(-0.00023929847100822422`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 1.9865803227929543`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  1.2777674575034328`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((0.04150842072711529`\ \((#1\^2 + \
#2\^2)\) - 0.0009571938840328969`\ \((#1\^2 + #2\^2)\)\^2 + 
                        4.966450806982386`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  0.00024039924879779603`\ \((\(-1\) + 
                        0.08301684145423058`\ \((#1\^2 + #2\^2)\) - 
                        0.0014357908260493452`\ \((#1\^2 + #2\^2)\)\^2 + 
                        6.621934409309847`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  2.1015428899858962`*^-8\ Cos[
                      6\ ArcTan[#1, #2]]\ \((\(-2.3176770432584464`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 1.8324402632599656`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  1.4464367516677119`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((0.0007178954130246726`\ \((#1\^2 \
+ #2\^2)\)\^2 - 0.00001390606225955068`\ \((#1\^2 + #2\^2)\)\^3 + 
                        6.41354092140988`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  4.750963775479129`*^-8\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.06918070121185882`\)\ \((#1\
\^2 + #2\^2)\) + 0.0028715816520986904`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.0000347651556488767`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.282708184281976`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.00001560839700928764`\ \((1 - 
                        0.13836140242371764`\ \((#1\^2 + #2\^2)\) + 
                        0.004307372478148035`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00004635354086516893`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.6033852303524698`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
              "-CompiledCode-"]\),
            False,
            Editable->False]}]}], "}"}]], "Output",
  CellLabel->"Out[29]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],

Cell[TextData[{
  "When ",
  StyleBox["Compiled->False", "Input"],
  " is given, the output is left uncompiled."
}], "Text",
  CellLabel->"In[73]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{

Cell["\<\
ZernikeFit[ReadTurboRays[TurboTrace[colsys32, \
ReportedSurfaces->Last],{SurfaceCoordinates,OpticalLength}],Compiled->False]
\
\>", "Input",
  CellLabel->"In[30]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[BoxData[
    \({ResidualFitError \[Rule] 2.528143964807474`*^-7, 
      SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
            4199.565609496804`, Astigmatism \[Rule] \(-0.3674817785287542`\), 
          FieldCurvature \[Rule] \(-2066.074081886578`\), 
          Distortion \[Rule] \(-6.297181442009891`*^-12\), 
          Coma \[Rule] 1.1038935179793206`*^-11}, 
      ZernikePolynomial \[Rule] 
        If[#1 == 0 && #2 == 0, 
          213.2480751380951`, \(\(213.2394348352914`\)\(\[InvisibleSpace]\)\) \
- 1.3282002225000779`*^-9\ Cos[2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
            1.4659753859254313`*^-10\ Cos[
                4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
            0.01315166344752725`\ \((\(-1\) + 
                  0.013836140242371764`\ \((#1\^2 + #2\^2)\))\) - 
            1.990701156673646`*^-7\ Cos[
                2\ ArcTan[#1, #2]]\ \((\(-0.020754210363557644`\)\ \((#1\^2 + \
#2\^2)\) + 0.00019143877680657937`\ \((#1\^2 + #2\^2)\)\^2)\) - 
            0.004736151495641903`\ \((1 - 
                  0.04150842072711529`\ \((#1\^2 + #2\^2)\) + 
                  0.00028715816520986904`\ \((#1\^2 + #2\^2)\)\^2)\) + 
            2.5530111538861066`*^-6\ Cos[
                4\ ArcTan[#1, #2]]\ \((\(-0.00023929847100822422`\)\ \((#1\^2 \
+ #2\^2)\)\^2 + 1.9865803227929543`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
            1.2777674575034328`*^-7\ Cos[
                2\ ArcTan[#1, #2]]\ \((0.04150842072711529`\ \((#1\^2 + \
#2\^2)\) - 0.0009571938840328969`\ \((#1\^2 + #2\^2)\)\^2 + 
                  4.966450806982386`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
            0.00024039924879779603`\ \((\(-1\) + 
                  0.08301684145423058`\ \((#1\^2 + #2\^2)\) - 
                  0.0014357908260493452`\ \((#1\^2 + #2\^2)\)\^2 + 
                  6.621934409309847`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
            2.1015428899858962`*^-8\ Cos[
                6\ ArcTan[#1, #2]]\ \((\(-2.3176770432584464`*^-6\)\ \((#1\^2 \
+ #2\^2)\)\^3 + 1.8324402632599656`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
            1.4464367516677119`*^-6\ Cos[
                4\ ArcTan[#1, #2]]\ \((0.0007178954130246726`\ \((#1\^2 + \
#2\^2)\)\^2 - 0.00001390606225955068`\ \((#1\^2 + #2\^2)\)\^3 + 
                  6.41354092140988`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
            4.750963775479129`*^-8\ Cos[
                
                2\ ArcTan[#1, #2]]\ \((\(-0.06918070121185882`\)\ \((#1\^2 + \
#2\^2)\) + 0.0028715816520986904`\ \((#1\^2 + #2\^2)\)\^2 - 
                  0.0000347651556488767`\ \((#1\^2 + #2\^2)\)\^3 + 
                  1.282708184281976`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
            0.00001560839700928764`\ \((1 - 
                  0.13836140242371764`\ \((#1\^2 + #2\^2)\) + 
                  0.004307372478148035`\ \((#1\^2 + #2\^2)\)\^2 - 
                  0.00004635354086516893`\ \((#1\^2 + #2\^2)\)\^3 + 
                  1.6033852303524698`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)]}\)], \
"Output",
  CellLabel->"Out[30]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],

Cell[TextData[{
  StyleBox["ZernikeFit", "Input"],
  " is also used internally by ",
  StyleBox["PupilFunction", "Input"],
  " for three-dimesional sources when the option ",
  StyleBox["ZernikeFit->True", "Input"],
  " is set."
}], "Text",
  CellLabel->"In[73]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{

Cell["ZernikeFit/.Options[PupilFunction]", "Input",
  CellLabel->"In[31]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[31]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],

Cell[TextData[{
  StyleBox["ZernikeFit", "Input"],
  " is also used internally by ",
  StyleBox["PupilFunction", "Input"],
  " for three-dimensional light sources. ",
  StyleBox["SeidelAberrations", "Input"],
  " is also returned by ",
  StyleBox["PupilFunction", "Input"],
  "."
}], "Text",
  CellLabel->"In[73]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{

Cell["\<\
{OpticalPathDifference,ResidualFitError,SeidelAberrations}/.
\tPupilFunction[offaxis3D,FindImagePoint->True,Plot2D->False,ZernikeFit->True]\
\
\>", "Input",
  CellLabel->"In[32]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.14456 .20014 -11.9298 -9 ]
[.14456 .20014 .07017 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.53907 .04499 -5.20849 -9 ]
[.53907 .04499 .79151 0 ]
[.76796 .09781 0 -6.16112 ]
[.76796 .09781 12 2.83888 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93439 .35267 0 -5.92025 ]
[.93439 .35267 6 3.07975 ]
[.0225 .2752 -18 -2.75083 ]
[.0225 .2752 0 6.24917 ]
[.01163 .34334 -18 -2.80851 ]
[.01163 .34334 0 6.19149 ]
[.00027 .41455 -18 -2.86906 ]
[.00027 .41455 0 6.13094 ]
[-0.01162 .48906 -18 -2.93271 ]
[-0.01162 .48906 0 6.06729 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15379 .20947 m
.1584 .21414 L
s
[(-5)] .14456 .20014 .98831 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54685 .05556 m
.55074 .06084 L
s
[(5)] .53907 .04499 .73616 1 Mshowa
.125 Mabswid
.19056 .19507 m
.19329 .19791 L
s
.22786 .18047 m
.23055 .18334 L
s
.2657 .16565 m
.26835 .16856 L
s
.3041 .15061 m
.30671 .15356 L
s
.38261 .11987 m
.38514 .12289 L
s
.42275 .10415 m
.42523 .10721 L
s
.46349 .0882 m
.46592 .09129 L
s
.50485 .072 m
.50724 .07514 L
s
.11754 .22366 m
.12034 .22643 L
s
.08179 .23766 m
.08463 .24039 L
s
.04655 .25146 m
.04942 .25416 L
s
.5895 .03886 m
.59178 .04207 L
s
.6328 .0219 m
.63503 .02515 L
s
.67679 .00468 m
.67896 .00796 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75565 .10235 m
.74949 .10462 L
s
[(-5)] .76796 .09781 -1 .36914 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92187 .35662 m
.91562 .35859 L
s
[(5)] .93439 .35267 -1 .31561 Mshowa
.125 Mabswid
.77429 .13086 m
.77059 .1322 L
s
.79243 .15861 m
.78872 .15994 L
s
.8101 .18564 m
.80638 .18694 L
s
.82731 .21196 m
.82359 .21325 L
s
.86042 .26262 m
.85669 .26387 L
s
.87636 .287 m
.87262 .28823 L
s
.8919 .31078 m
.88816 .31199 L
s
.90707 .33398 m
.90332 .33518 L
s
.73649 .07305 m
.73281 .07443 L
s
.7168 .04292 m
.71312 .04433 L
s
.69654 .01194 m
.69287 .01337 L
s
.93632 .37872 m
.93257 .37989 L
s
.95044 .40031 m
.94667 .40146 L
s
.96422 .4214 m
.96045 .42254 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03473 .27044 m
.04085 .26807 L
s
[(0.1)] .0225 .2752 1 -0.3887 Mshowa
.02391 .33872 m
.03006 .33641 L
s
[(0.2)] .01163 .34334 1 -0.37589 Mshowa
.01261 .41008 m
.01877 .40785 L
s
[(0.3)] .00027 .41455 1 -0.36243 Mshowa
.00077 .48474 m
.00697 .48258 L
s
[(0.4)] -0.01162 .48906 1 -0.34829 Mshowa
.125 Mabswid
.03261 .28386 m
.03628 .28244 L
s
.03046 .2974 m
.03414 .29599 L
s
.0283 .31105 m
.03198 .30965 L
s
.02612 .32483 m
.0298 .32343 L
s
.02169 .35274 m
.02538 .35136 L
s
.01945 .36688 m
.02314 .36552 L
s
.01719 .38116 m
.02088 .3798 L
s
.01491 .39555 m
.01861 .3942 L
s
.01028 .42474 m
.01399 .42341 L
s
.00794 .43954 m
.01165 .43821 L
s
.00557 .45447 m
.00928 .45315 L
s
.00318 .46953 m
.0069 .46823 L
s
.03684 .25714 m
.04051 .2557 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .437 .192 r
.3928 .65922 .4037 .64439 .41941 .67341 .40827 .6981 Metetra
.041 .556 0 r
.40827 .6981 .41941 .67341 .43605 .6828 .42496 .71217 Metetra
.157 .599 0 r
.42496 .71217 .43605 .6828 .45316 .68122 .44228 .71225 Metetra
.187 .609 0 r
.44228 .71225 .45316 .68122 .47046 .67671 .45983 .70864 Metetra
.195 .612 0 r
.45983 .70864 .47046 .67671 .48788 .67173 .47751 .70449 Metetra
.198 .613 0 r
.47751 .70449 .48788 .67173 .5054 .66661 .49531 .70026 Metetra
.202 .614 0 r
.49531 .70026 .5054 .66661 .52304 .66139 .51324 .69598 Metetra
.204 .615 0 r
.51324 .69598 .52304 .66139 .54079 .65606 .5313 .69166 Metetra
.206 .616 0 r
.5313 .69166 .54079 .65606 .55866 .65061 .54948 .68728 Metetra
.207 .616 0 r
.54948 .68728 .55866 .65061 .57663 .64504 .56778 .68285 Metetra
.208 .616 0 r
.56778 .68285 .57663 .64504 .59471 .63934 .58622 .67836 Metetra
.207 .616 0 r
.58622 .67836 .59471 .63934 .6129 .63351 .60478 .67382 Metetra
.206 .616 0 r
.60478 .67382 .6129 .63351 .6312 .62754 .62347 .6692 Metetra
.204 .615 0 r
.62347 .6692 .6312 .62754 .64961 .62142 .6423 .66452 Metetra
.202 .614 0 r
.6423 .66452 .64961 .62142 .66813 .61515 .66125 .65976 Metetra
.198 .613 0 r
.66125 .65976 .66813 .61515 .68675 .60872 .68034 .65491 Metetra
.193 .611 0 r
.68034 .65491 .68675 .60872 .70548 .60211 .69956 .64997 Metetra
.186 .609 0 r
.69956 .64997 .70548 .60211 .72431 .59531 .7189 .64494 Metetra
.179 .607 0 r
.7189 .64494 .72431 .59531 .74324 .58833 .73838 .63979 Metetra
.17 .603 0 r
.73838 .63979 .74324 .58833 .76227 .58114 .75799 .63452 Metetra
.16 .6 0 r
.75799 .63452 .76227 .58114 .78139 .57374 .77773 .62912 Metetra
.148 .596 0 r
.77773 .62912 .78139 .57374 .8006 .56611 .7976 .62357 Metetra
.134 .591 0 r
.7976 .62357 .8006 .56611 .81991 .55825 .8176 .61786 Metetra
.119 .586 0 r
.8176 .61786 .81991 .55825 .83929 .55012 .83771 .61196 Metetra
.102 .579 0 r
.83771 .61196 .83929 .55012 .85876 .54174 .85795 .60585 Metetra
.084 .572 0 r
.85795 .60585 .85876 .54174 .87831 .53306 .87831 .59951 Metetra
.063 .564 0 r
.87831 .59951 .87831 .53306 .89792 .52408 .89877 .59287 Metetra
.038 .554 0 r
.89877 .59287 .89792 .52408 .91757 .51456 .91928 .5855 Metetra
0 .538 .001 r
.91928 .5855 .91757 .51456 .93706 .50297 .93947 .57444 Metetra
0 .495 .094 r
.93947 .57444 .93706 .50297 .95569 .48421 .95799 .54966 Metetra
0 .391 .25 r
.95799 .54966 .95569 .48421 .97251 .45237 .97296 .49923 Metetra
0 .519 .044 r
.38231 .65777 .3928 .65922 .40827 .6981 .39761 .70023 Metetra
.336 .656 0 r
.39761 .70023 .40827 .6981 .42496 .71217 .41431 .71613 Metetra
.522 .709 0 r
.41431 .71613 .42496 .71217 .44228 .71225 .43173 .71693 Metetra
.576 .723 0 r
.43173 .71693 .44228 .71225 .45983 .70864 .44941 .71375 Metetra
.597 .728 0 r
.44941 .71375 .45983 .70864 .47751 .70449 .46722 .71003 Metetra
.613 .732 0 r
.46722 .71003 .47751 .70449 .49531 .70026 .48517 .70627 Metetra
.628 .736 0 r
.48517 .70627 .49531 .70026 .51324 .69598 .50325 .70251 Metetra
.644 .74 0 r
.50325 .70251 .51324 .69598 .5313 .69166 .52146 .69875 Metetra
.661 .744 0 r
.52146 .69875 .5313 .69166 .54948 .68728 .5398 .695 Metetra
.677 .748 0 r
.5398 .695 .54948 .68728 .56778 .68285 .55829 .69124 Metetra
.694 .752 0 r
.55829 .69124 .56778 .68285 .58622 .67836 .57691 .6875 Metetra
.711 .756 0 r
.57691 .6875 .58622 .67836 .60478 .67382 .59567 .68377 Metetra
.728 .76 0 r
.59567 .68377 .60478 .67382 .62347 .6692 .61458 .68004 Metetra
.745 .764 0 r
.61458 .68004 .62347 .6692 .6423 .66452 .63363 .67633 Metetra
.763 .768 0 r
.63363 .67633 .6423 .66452 .66125 .65976 .65283 .67263 Metetra
.772 .763 0 r
.65283 .67263 .66125 .65976 .68034 .65491 .67218 .66894 Metetra
.776 .754 0 r
.67218 .66894 .68034 .65491 .69956 .64997 .69168 .66528 Metetra
.78 .744 0 r
.69168 .66528 .69956 .64997 .7189 .64494 .71134 .66164 Metetra
.784 .735 0 r
.71134 .66164 .7189 .64494 .73838 .63979 .73116 .65802 Metetra
.788 .725 0 r
.73116 .65802 .73838 .63979 .75799 .63452 .75115 .65442 Metetra
.791 .715 0 r
.75115 .65442 .75799 .63452 .77773 .62912 .77129 .65085 Metetra
.795 .706 0 r
.77129 .65085 .77773 .62912 .7976 .62357 .79161 .6473 Metetra
.799 .697 0 r
.79161 .6473 .7976 .62357 .8176 .61786 .81209 .64378 Metetra
.802 .688 0 r
.81209 .64378 .8176 .61786 .83771 .61196 .83275 .6403 Metetra
.805 .679 0 r
.83275 .6403 .83771 .61196 .85795 .60585 .85359 .63683 Metetra
.808 .671 0 r
.85359 .63683 .85795 .60585 .87831 .59951 .8746 .63339 Metetra
.811 .664 0 r
.8746 .63339 .87831 .59951 .89877 .59287 .89579 .62992 Metetra
.812 .661 0 r
.89579 .62992 .89877 .59287 .91928 .5855 .91711 .62589 Metetra
.804 .682 0 r
.91711 .62589 .91928 .5855 .93947 .57444 .93806 .6174 Metetra
.721 .758 0 r
.93806 .6174 .93947 .57444 .95799 .54966 .95685 .59078 Metetra
.22 .62 0 r
.95685 .59078 .95799 .54966 .97296 .49923 .97086 .52907 Metetra
.005 .541 0 r
.37195 .64934 .38231 .65777 .39761 .70023 .38714 .69259 Metetra
.434 .685 0 r
.38714 .69259 .39761 .70023 .41431 .71613 .40385 .70894 Metetra
.646 .74 0 r
.40385 .70894 .41431 .71613 .43173 .71693 .42132 .70989 Metetra
.71 .755 0 r
.42132 .70989 .43173 .71693 .44941 .71375 .43907 .70678 Metetra
.737 .762 0 r
.43907 .70678 .44941 .71375 .46722 .71003 .45697 .70313 Metetra
.759 .767 0 r
.45697 .70313 .46722 .71003 .48517 .70627 .475 .69945 Metetra
.772 .762 0 r
.475 .69945 .48517 .70627 .50325 .70251 .49316 .69578 Metetra
.778 .749 0 r
.49316 .69578 .50325 .70251 .52146 .69875 .51146 .69212 Metetra
.783 .736 0 r
.51146 .69212 .52146 .69875 .5398 .695 .52989 .68848 Metetra
.789 .722 0 r
.52989 .68848 .5398 .695 .55829 .69124 .54847 .68487 Metetra
.795 .707 0 r
.54847 .68487 .55829 .69124 .57691 .6875 .56719 .68128 Metetra
.801 .691 0 r
.56719 .68128 .57691 .6875 .59567 .68377 .58606 .67774 Metetra
.807 .675 0 r
.58606 .67774 .59567 .68377 .61458 .68004 .60507 .67423 Metetra
.813 .657 0 r
.60507 .67423 .61458 .68004 .63363 .67633 .62424 .67075 Metetra
.82 .639 0 r
.62424 .67075 .63363 .67633 .65283 .67263 .64356 .66733 Metetra
.827 .62 0 r
.64356 .66733 .65283 .67263 .67218 .66894 .66303 .66397 Metetra
.834 .599 0 r
.66303 .66397 .67218 .66894 .69168 .66528 .68267 .66067 Metetra
.842 .577 0 r
.68267 .66067 .69168 .66528 .71134 .66164 .70248 .65745 Metetra
.85 .554 0 r
.70248 .65745 .71134 .66164 .73116 .65802 .72245 .65431 Metetra
.858 .529 0 r
.72245 .65431 .73116 .65802 .75115 .65442 .7426 .65126 Metetra
.866 .502 0 r
.7426 .65126 .75115 .65442 .77129 .65085 .76293 .64833 Metetra
.875 .474 0 r
.76293 .64833 .77129 .65085 .79161 .6473 .78345 .64551 Metetra
.884 .443 0 r
.78345 .64551 .79161 .6473 .81209 .64378 .80415 .64283 Metetra
.894 .41 0 r
.80415 .64283 .81209 .64378 .83275 .6403 .82506 .64031 Metetra
.904 .375 0 r
.82506 .64031 .83275 .6403 .85359 .63683 .84617 .63797 Metetra
.915 .337 0 r
.84617 .63797 .85359 .63683 .8746 .63339 .8675 .63581 Metetra
.926 .297 0 r
.8675 .63581 .8746 .63339 .89579 .62992 .88904 .63385 Metetra
.936 .258 0 r
.88904 .63385 .89579 .62992 .91711 .62589 .91076 .63155 Metetra
.938 .253 0 r
.91076 .63155 .91711 .62589 .93806 .6174 .93216 .62483 Metetra
.896 .405 0 r
.93216 .62483 .93806 .6174 .95685 .59078 .95131 .59892 Metetra
.672 .746 0 r
.95131 .59892 .95685 .59078 .97086 .52907 .96531 .53444 Metetra
.008 .542 0 r
.36153 .63943 .37195 .64934 .38714 .69259 .37663 .68288 Metetra
.443 .687 0 r
.37663 .68288 .38714 .69259 .40385 .70894 .39332 .69937 Metetra
.659 .743 0 r
.39332 .69937 .40385 .70894 .42132 .70989 .41085 .70034 Metetra
.726 .759 0 r
.41085 .70034 .42132 .70989 .43907 .70678 .42867 .69719 Metetra
.754 .766 0 r
.42867 .69719 .43907 .70678 .45697 .70313 .44663 .69349 Metetra
.771 .765 0 r
.44663 .69349 .45697 .70313 .475 .69945 .46473 .68976 Metetra
.777 .752 0 r
.46473 .68976 .475 .69945 .49316 .69578 .48297 .68604 Metetra
.782 .738 0 r
.48297 .68604 .49316 .69578 .51146 .69212 .50134 .68234 Metetra
.788 .723 0 r
.50134 .68234 .51146 .69212 .52989 .68848 .51985 .67865 Metetra
.794 .708 0 r
.51985 .67865 .52989 .68848 .54847 .68487 .5385 .67499 Metetra
.801 .692 0 r
.5385 .67499 .54847 .68487 .56719 .68128 .5573 .67136 Metetra
.807 .675 0 r
.5573 .67136 .56719 .68128 .58606 .67774 .57625 .66778 Metetra
.814 .656 0 r
.57625 .66778 .58606 .67774 .60507 .67423 .59534 .66422 Metetra
.821 .637 0 r
.59534 .66422 .60507 .67423 .62424 .67075 .61459 .66071 Metetra
.828 .616 0 r
.61459 .66071 .62424 .67075 .64356 .66733 .63399 .65726 Metetra
.836 .594 0 r
.63399 .65726 .64356 .66733 .66303 .66397 .65356 .65387 Metetra
.844 .57 0 r
.65356 .65387 .66303 .66397 .68267 .66067 .67329 .65055 Metetra
.853 .545 0 r
.67329 .65055 .68267 .66067 .70248 .65745 .69318 .64732 Metetra
.861 .517 0 r
.69318 .64732 .70248 .65745 .72245 .65431 .71325 .64418 Metetra
.871 .487 0 r
.71325 .64418 .72245 .65431 .7426 .65126 .7335 .64114 Metetra
.881 .455 0 r
.7335 .64114 .7426 .65126 .76293 .64833 .75393 .63823 Metetra
.891 .421 0 r
.75393 .63823 .76293 .64833 .78345 .64551 .77455 .63545 Metetra
.902 .383 0 r
.77455 .63545 .78345 .64551 .80415 .64283 .79536 .63284 Metetra
.914 .341 0 r
.79536 .63284 .80415 .64283 .82506 .64031 .81638 .63041 Metetra
.926 .295 0 r
.81638 .63041 .82506 .64031 .84617 .63797 .83762 .62819 Metetra
.94 .245 0 r
.83762 .62819 .84617 .63797 .8675 .63581 .85907 .62621 Metetra
.954 .19 0 r
.85907 .62621 .8675 .63581 .88904 .63385 .88076 .62447 Metetra
.968 .133 0 r
.88076 .62447 .88904 .63385 .91076 .63155 .90263 .62249 Metetra
.974 .109 0 r
.90263 .62249 .91076 .63155 .93216 .62483 .92424 .61639 Metetra
.936 .258 0 r
.92424 .61639 .93216 .62483 .95131 .59892 .94371 .59153 Metetra
.789 .723 0 r
.94371 .59153 .95131 .59892 .96531 .53444 .95807 .52781 Metetra
.002 .539 0 r
.35099 .62934 .36153 .63943 .37663 .68288 .36599 .67292 Metetra
.435 .685 0 r
.36599 .67292 .37663 .68288 .39332 .69937 .38268 .68951 Metetra
.652 .741 0 r
.38268 .68951 .39332 .69937 .41085 .70034 .40026 .69047 Metetra
.718 .757 0 r
.40026 .69047 .41085 .70034 .42867 .69719 .41814 .68727 Metetra
.746 .764 0 r
.41814 .68727 .42867 .69719 .44663 .69349 .43617 .68351 Metetra
.769 .769 0 r
.43617 .68351 .44663 .69349 .46473 .68976 .45434 .67971 Metetra
.775 .756 0 r
.45434 .67971 .46473 .68976 .48297 .68604 .47265 .67592 Metetra
.781 .742 0 r
.47265 .67592 .48297 .68604 .50134 .68234 .4911 .67214 Metetra
.786 .728 0 r
.4911 .67214 .50134 .68234 .51985 .67865 .50968 .66839 Metetra
.793 .712 0 r
.50968 .66839 .51985 .67865 .5385 .67499 .52841 .66465 Metetra
.799 .696 0 r
.52841 .66465 .5385 .67499 .5573 .67136 .54728 .66095 Metetra
.805 .679 0 r
.54728 .66095 .5573 .67136 .57625 .66778 .56631 .65728 Metetra
.812 .661 0 r
.56631 .65728 .57625 .66778 .59534 .66422 .58548 .65365 Metetra
.819 .642 0 r
.58548 .65365 .59534 .66422 .61459 .66071 .60481 .65006 Metetra
.827 .621 0 r
.60481 .65006 .61459 .66071 .63399 .65726 .62429 .64652 Metetra
.834 .599 0 r
.62429 .64652 .63399 .65726 .65356 .65387 .64394 .64304 Metetra
.843 .575 0 r
.64394 .64304 .65356 .65387 .67329 .65055 .66375 .63963 Metetra
.851 .549 0 r
.66375 .63963 .67329 .65055 .69318 .64732 .68373 .63631 Metetra
.86 .522 0 r
.68373 .63631 .69318 .64732 .71325 .64418 .70389 .63307 Metetra
.869 .492 0 r
.70389 .63307 .71325 .64418 .7335 .64114 .72422 .62994 Metetra
.879 .46 0 r
.72422 .62994 .7335 .64114 .75393 .63823 .74474 .62692 Metetra
.89 .425 0 r
.74474 .62692 .75393 .63823 .77455 .63545 .76544 .62405 Metetra
.901 .386 0 r
.76544 .62405 .77455 .63545 .79536 .63284 .78635 .62132 Metetra
.913 .344 0 r
.78635 .62132 .79536 .63284 .81638 .63041 .80746 .61878 Metetra
.926 .298 0 r
.80746 .61878 .81638 .63041 .83762 .62819 .82878 .61645 Metetra
.939 .246 0 r
.82878 .61645 .83762 .62819 .85907 .62621 .85033 .61436 Metetra
.954 .19 0 r
.85033 .61436 .85907 .62621 .88076 .62447 .87211 .6125 Metetra
.969 .13 0 r
.87211 .6125 .88076 .62447 .90263 .62249 .89408 .61045 Metetra
.976 .102 0 r
.89408 .61045 .90263 .62249 .92424 .61639 .91583 .60454 Metetra
.941 .239 0 r
.91583 .60454 .92424 .61639 .94371 .59153 .93557 .58058 Metetra
.798 .698 0 r
.93557 .58058 .94371 .59153 .95807 .52781 .95034 .51818 Metetra
0 .536 .005 r
.34033 .61919 .35099 .62934 .36599 .67292 .35523 .6629 Metetra
.426 .683 0 r
.35523 .6629 .36599 .67292 .38268 .68951 .37191 .67959 Metetra
.643 .739 0 r
.37191 .67959 .38268 .68951 .40026 .69047 .38954 .68054 Metetra
.709 .755 0 r
.38954 .68054 .40026 .69047 .41814 .68727 .40748 .67728 Metetra
.737 .762 0 r
.40748 .67728 .41814 .68727 .43617 .68351 .42559 .67345 Metetra
.76 .767 0 r
.42559 .67345 .43617 .68351 .45434 .67971 .44383 .66958 Metetra
.773 .761 0 r
.44383 .66958 .45434 .67971 .47265 .67592 .46221 .66572 Metetra
.778 .747 0 r
.46221 .66572 .47265 .67592 .4911 .67214 .48073 .66188 Metetra
.784 .733 0 r
.48073 .66188 .4911 .67214 .50968 .66839 .49939 .65804 Metetra
.79 .718 0 r
.49939 .65804 .50968 .66839 .52841 .66465 .51819 .65423 Metetra
.797 .702 0 r
.51819 .65423 .52841 .66465 .54728 .66095 .53714 .65045 Metetra
.803 .685 0 r
.53714 .65045 .54728 .66095 .56631 .65728 .55624 .6467 Metetra
.81 .668 0 r
.55624 .6467 .56631 .65728 .58548 .65365 .5755 .64298 Metetra
.817 .649 0 r
.5755 .64298 .58548 .65365 .60481 .65006 .59491 .63931 Metetra
.824 .628 0 r
.59491 .63931 .60481 .65006 .62429 .64652 .61447 .63568 Metetra
.832 .607 0 r
.61447 .63568 .62429 .64652 .64394 .64304 .6342 .63212 Metetra
.84 .583 0 r
.6342 .63212 .64394 .64304 .66375 .63963 .6541 .62861 Metetra
.848 .558 0 r
.6541 .62861 .66375 .63963 .68373 .63631 .67416 .62519 Metetra
.857 .531 0 r
.67416 .62519 .68373 .63631 .70389 .63307 .6944 .62185 Metetra
.866 .502 0 r
.6944 .62185 .70389 .63307 .72422 .62994 .71482 .61862 Metetra
.876 .471 0 r
.71482 .61862 .72422 .62994 .74474 .62692 .73543 .61549 Metetra
.886 .436 0 r
.73543 .61549 .74474 .62692 .76544 .62405 .75622 .6125 Metetra
.897 .399 0 r
.75622 .6125 .76544 .62405 .78635 .62132 .77722 .60966 Metetra
.909 .358 0 r
.77722 .60966 .78635 .62132 .80746 .61878 .79842 .60699 Metetra
.922 .312 0 r
.79842 .60699 .80746 .61878 .82878 .61645 .81983 .60453 Metetra
.935 .262 0 r
.81983 .60453 .82878 .61645 .85033 .61436 .84147 .60229 Metetra
.95 .207 0 r
.84147 .60229 .85033 .61436 .87211 .6125 .86334 .60028 Metetra
.964 .149 0 r
.86334 .60028 .87211 .6125 .89408 .61045 .88541 .59811 Metetra
.972 .119 0 r
.88541 .59811 .89408 .61045 .91583 .60454 .90728 .59229 Metetra
.939 .247 0 r
.90728 .59229 .91583 .60454 .93557 .58058 .92727 .56908 Metetra
.801 .691 0 r
.92727 .56908 .93557 .58058 .95034 .51818 .94243 .50791 Metetra
0 .534 .01 r
.32953 .609 .34033 .61919 .35523 .6629 .34433 .65284 Metetra
.418 .68 0 r
.34433 .65284 .35523 .6629 .37191 .67959 .36101 .66961 Metetra
.635 .737 0 r
.36101 .66961 .37191 .67959 .38954 .68054 .37868 .67054 Metetra
.701 .753 0 r
.37868 .67054 .38954 .68054 .40748 .67728 .3967 .66723 Metetra
.729 .76 0 r
.3967 .66723 .40748 .67728 .42559 .67345 .41487 .66333 Metetra
.752 .765 0 r
.41487 .66333 .42559 .67345 .44383 .66958 .43318 .6594 Metetra
.771 .766 0 r
.43318 .6594 .44383 .66958 .46221 .66572 .45164 .65547 Metetra
.776 .752 0 r
.45164 .65547 .46221 .66572 .48073 .66188 .47023 .65155 Metetra
.782 .738 0 r
.47023 .65155 .48073 .66188 .49939 .65804 .48897 .64764 Metetra
.788 .723 0 r
.48897 .64764 .49939 .65804 .51819 .65423 .50785 .64375 Metetra
.794 .708 0 r
.50785 .64375 .51819 .65423 .53714 .65045 .52688 .63989 Metetra
.801 .691 0 r
.52688 .63989 .53714 .65045 .55624 .6467 .54606 .63606 Metetra
.808 .674 0 r
.54606 .63606 .55624 .6467 .5755 .64298 .56539 .63226 Metetra
.814 .655 0 r
.56539 .63226 .5755 .64298 .59491 .63931 .58488 .6285 Metetra
.822 .635 0 r
.58488 .6285 .59491 .63931 .61447 .63568 .60453 .62479 Metetra
.829 .614 0 r
.60453 .62479 .61447 .63568 .6342 .63212 .62434 .62114 Metetra
.837 .591 0 r
.62434 .62114 .6342 .63212 .6541 .62861 .64432 .61754 Metetra
.845 .566 0 r
.64432 .61754 .6541 .62861 .67416 .62519 .66448 .61402 Metetra
.854 .54 0 r
.66448 .61402 .67416 .62519 .6944 .62185 .6848 .61059 Metetra
.863 .511 0 r
.6848 .61059 .6944 .62185 .71482 .61862 .70531 .60725 Metetra
.873 .48 0 r
.70531 .60725 .71482 .61862 .73543 .61549 .72601 .60402 Metetra
.883 .447 0 r
.72601 .60402 .73543 .61549 .75622 .6125 .74689 .60092 Metetra
.894 .41 0 r
.74689 .60092 .75622 .6125 .77722 .60966 .76798 .59796 Metetra
.906 .37 0 r
.76798 .59796 .77722 .60966 .79842 .60699 .78927 .59517 Metetra
.918 .326 0 r
.78927 .59517 .79842 .60699 .81983 .60453 .81078 .59258 Metetra
.931 .277 0 r
.81078 .59258 .81983 .60453 .84147 .60229 .83251 .59021 Metetra
.945 .223 0 r
.83251 .59021 .84147 .60229 .86334 .60028 .85447 .58806 Metetra
.96 .167 0 r
.85447 .58806 .86334 .60028 .88541 .59811 .87663 .58576 Metetra
.967 .136 0 r
.87663 .58576 .88541 .59811 .90728 .59229 .89864 .58001 Metetra
.937 .256 0 r
.89864 .58001 .90728 .59229 .92727 .56908 .91885 .55741 Metetra
.803 .686 0 r
.91885 .55741 .92727 .56908 .94243 .50791 .93439 .49729 Metetra
0 .532 .015 r
.31861 .59875 .32953 .609 .34433 .65284 .3333 .64272 Metetra
.412 .678 0 r
.3333 .64272 .34433 .65284 .36101 .66961 .34997 .65957 Metetra
.628 .736 0 r
.34997 .65957 .36101 .66961 .37868 .67054 .36769 .66049 Metetra
.695 .752 0 r
.36769 .66049 .37868 .67054 .3967 .66723 .38577 .65712 Metetra
.722 .758 0 r
.38577 .65712 .3967 .66723 .41487 .66333 .40402 .65315 Metetra
.745 .764 0 r
.40402 .65315 .41487 .66333 .43318 .6594 .42241 .64915 Metetra
.769 .769 0 r
.42241 .64915 .43318 .6594 .45164 .65547 .44093 .64514 Metetra
.775 .756 0 r
.44093 .64514 .45164 .65547 .47023 .65155 .4596 .64115 Metetra
.78 .742 0 r
.4596 .64115 .47023 .65155 .48897 .64764 .47841 .63717 Metetra
.786 .728 0 r
.47841 .63717 .48897 .64764 .50785 .64375 .49737 .63321 Metetra
.793 .712 0 r
.49737 .63321 .50785 .64375 .52688 .63989 .51648 .62927 Metetra
.799 .696 0 r
.51648 .62927 .52688 .63989 .54606 .63606 .53574 .62536 Metetra
.806 .679 0 r
.53574 .62536 .54606 .63606 .56539 .63226 .55515 .62148 Metetra
.812 .66 0 r
.55515 .62148 .56539 .63226 .58488 .6285 .57473 .61764 Metetra
.82 .641 0 r
.57473 .61764 .58488 .6285 .60453 .62479 .59446 .61384 Metetra
.827 .62 0 r
.59446 .61384 .60453 .62479 .62434 .62114 .61436 .6101 Metetra
.835 .597 0 r
.61436 .6101 .62434 .62114 .64432 .61754 .63443 .60641 Metetra
.843 .573 0 r
.63443 .60641 .64432 .61754 .66448 .61402 .65467 .6028 Metetra
.852 .547 0 r
.65467 .6028 .66448 .61402 .6848 .61059 .67508 .59927 Metetra
.861 .519 0 r
.67508 .59927 .6848 .61059 .70531 .60725 .69568 .59583 Metetra
.87 .489 0 r
.69568 .59583 .70531 .60725 .72601 .60402 .71647 .5925 Metetra
.88 .456 0 r
.71647 .5925 .72601 .60402 .74689 .60092 .73745 .5893 Metetra
.891 .42 0 r
.73745 .5893 .74689 .60092 .76798 .59796 .75863 .58623 Metetra
.903 .381 0 r
.75863 .58623 .76798 .59796 .78927 .59517 .78001 .58333 Metetra
.915 .338 0 r
.78001 .58333 .78927 .59517 .81078 .59258 .80161 .58061 Metetra
.928 .29 0 r
.80161 .58061 .81078 .59258 .83251 .59021 .82344 .57811 Metetra
.942 .238 0 r
.82344 .57811 .83251 .59021 .85447 .58806 .8455 .57583 Metetra
.956 .182 0 r
.8455 .57583 .85447 .58806 .87663 .58576 .86776 .57341 Metetra
.964 .151 0 r
.86776 .57341 .87663 .58576 .89864 .58001 .88989 .56769 Metetra
.935 .264 0 r
.88989 .56769 .89864 .58001 .91885 .55741 .91032 .5456 Metetra
.804 .682 0 r
.91032 .5456 .91885 .55741 .93439 .49729 .92621 .48636 Metetra
0 .53 .02 r
.30755 .58846 .31861 .59875 .3333 .64272 .32213 .63255 Metetra
.406 .677 0 r
.32213 .63255 .3333 .64272 .34997 .65957 .33879 .64947 Metetra
.622 .734 0 r
.33879 .64947 .34997 .65957 .36769 .66049 .35656 .65036 Metetra
.689 .75 0 r
.35656 .65036 .36769 .66049 .38577 .65712 .37471 .64693 Metetra
.716 .757 0 r
.37471 .64693 .38577 .65712 .40402 .65315 .39303 .6429 Metetra
.739 .762 0 r
.39303 .6429 .40402 .65315 .42241 .64915 .41149 .63882 Metetra
.762 .768 0 r
.41149 .63882 .42241 .64915 .44093 .64514 .43009 .63475 Metetra
.773 .76 0 r
.43009 .63475 .44093 .64514 .4596 .64115 .44883 .63069 Metetra
.779 .746 0 r
.44883 .63069 .4596 .64115 .47841 .63717 .46772 .62663 Metetra
.785 .732 0 r
.46772 .62663 .47841 .63717 .49737 .63321 .48676 .62259 Metetra
.791 .716 0 r
.48676 .62259 .49737 .63321 .51648 .62927 .50595 .61858 Metetra
.797 .7 0 r
.50595 .61858 .51648 .62927 .53574 .62536 .52529 .61459 Metetra
.804 .683 0 r
.52529 .61459 .53574 .62536 .55515 .62148 .54479 .61063 Metetra
.811 .665 0 r
.54479 .61063 .55515 .62148 .57473 .61764 .56445 .6067 Metetra
.818 .646 0 r
.56445 .6067 .57473 .61764 .59446 .61384 .58426 .60282 Metetra
.825 .625 0 r
.58426 .60282 .59446 .61384 .61436 .6101 .60425 .59899 Metetra
.833 .603 0 r
.60425 .59899 .61436 .6101 .63443 .60641 .62441 .59522 Metetra
.841 .579 0 r
.62441 .59522 .63443 .60641 .65467 .6028 .64473 .59152 Metetra
.85 .554 0 r
.64473 .59152 .65467 .6028 .67508 .59927 .66524 .58789 Metetra
.859 .526 0 r
.66524 .58789 .67508 .59927 .69568 .59583 .68593 .58436 Metetra
.868 .496 0 r
.68593 .58436 .69568 .59583 .71647 .5925 .70681 .58093 Metetra
.878 .464 0 r
.70681 .58093 .71647 .5925 .73745 .5893 .72788 .57762 Metetra
.889 .429 0 r
.72788 .57762 .73745 .5893 .75863 .58623 .74916 .57445 Metetra
.9 .39 0 r
.74916 .57445 .75863 .58623 .78001 .58333 .77064 .57143 Metetra
.912 .348 0 r
.77064 .57143 .78001 .58333 .80161 .58061 .79233 .5686 Metetra
.925 .301 0 r
.79233 .5686 .80161 .58061 .82344 .57811 .81426 .56598 Metetra
.939 .25 0 r
.81426 .56598 .82344 .57811 .8455 .57583 .83642 .56357 Metetra
.953 .196 0 r
.83642 .56357 .8455 .57583 .86776 .57341 .85878 .56105 Metetra
.961 .164 0 r
.85878 .56105 .86776 .57341 .88989 .56769 .88104 .55534 Metetra
.933 .272 0 r
.88104 .55534 .88989 .56769 .91032 .5456 .90168 .53365 Metetra
.805 .679 0 r
.90168 .53365 .91032 .5456 .92621 .48636 .9179 .47513 Metetra
0 .528 .023 r
.29636 .5781 .30755 .58846 .32213 .63255 .31082 .62231 Metetra
.401 .675 0 r
.31082 .62231 .32213 .63255 .33879 .64947 .32747 .6393 Metetra
.617 .733 0 r
.32747 .6393 .33879 .64947 .35656 .65036 .34529 .64017 Metetra
.684 .749 0 r
.34529 .64017 .35656 .65036 .37471 .64693 .36351 .63667 Metetra
.711 .756 0 r
.36351 .63667 .37471 .64693 .39303 .6429 .3819 .63257 Metetra
.734 .761 0 r
.3819 .63257 .39303 .6429 .41149 .63882 .40044 .62843 Metetra
.757 .766 0 r
.40044 .62843 .41149 .63882 .43009 .63475 .41911 .62428 Metetra
.772 .763 0 r
.41911 .62428 .43009 .63475 .44883 .63069 .43793 .62014 Metetra
.778 .749 0 r
.43793 .62014 .44883 .63069 .46772 .62663 .4569 .61601 Metetra
.784 .735 0 r
.4569 .61601 .46772 .62663 .48676 .62259 .47602 .6119 Metetra
.79 .72 0 r
.47602 .6119 .48676 .62259 .50595 .61858 .49528 .60781 Metetra
.796 .704 0 r
.49528 .60781 .50595 .61858 .52529 .61459 .51471 .60374 Metetra
.802 .687 0 r
.51471 .60374 .52529 .61459 .54479 .61063 .53429 .5997 Metetra
.809 .669 0 r
.53429 .5997 .54479 .61063 .56445 .6067 .55403 .59569 Metetra
.816 .65 0 r
.55403 .59569 .56445 .6067 .58426 .60282 .57394 .59173 Metetra
.824 .629 0 r
.57394 .59173 .58426 .60282 .60425 .59899 .59401 .58781 Metetra
.831 .608 0 r
.59401 .58781 .60425 .59899 .62441 .59522 .61425 .58395 Metetra
.839 .584 0 r
.61425 .58395 .62441 .59522 .64473 .59152 .63467 .58016 Metetra
.848 .559 0 r
.63467 .58016 .64473 .59152 .66524 .58789 .65527 .57645 Metetra
.857 .532 0 r
.65527 .57645 .66524 .58789 .68593 .58436 .67605 .57282 Metetra
.866 .502 0 r
.67605 .57282 .68593 .58436 .70681 .58093 .69703 .5693 Metetra
.876 .471 0 r
.69703 .5693 .70681 .58093 .72788 .57762 .7182 .56589 Metetra
.887 .436 0 r
.7182 .56589 .72788 .57762 .74916 .57445 .73957 .56261 Metetra
.898 .398 0 r
.73957 .56261 .74916 .57445 .77064 .57143 .76115 .55949 Metetra
.91 .356 0 r
.76115 .55949 .77064 .57143 .79233 .5686 .78294 .55655 Metetra
.922 .311 0 r
.78294 .55655 .79233 .5686 .81426 .56598 .80497 .55382 Metetra
.936 .26 0 r
.80497 .55382 .81426 .56598 .83642 .56357 .82723 .55129 Metetra
.95 .207 0 r
.82723 .55129 .83642 .56357 .85878 .56105 .8497 .54865 Metetra
.958 .175 0 r
.8497 .54865 .85878 .56105 .88104 .55534 .87207 .54293 Metetra
.931 .278 0 r
.87207 .54293 .88104 .55534 .90168 .53365 .89291 .52156 Metetra
.806 .676 0 r
.89291 .52156 .90168 .53365 .9179 .47513 .90945 .46361 Metetra
0 .527 .026 r
.28502 .56769 .29636 .5781 .31082 .62231 .29937 .61202 Metetra
.397 .674 0 r
.29937 .61202 .31082 .62231 .32747 .6393 .316 .62905 Metetra
.613 .732 0 r
.316 .62905 .32747 .6393 .34529 .64017 .33388 .62989 Metetra
.68 .748 0 r
.33388 .62989 .34529 .64017 .36351 .63667 .35217 .62634 Metetra
.707 .755 0 r
.35217 .62634 .36351 .63667 .3819 .63257 .37063 .62217 Metetra
.73 .76 0 r
.37063 .62217 .3819 .63257 .40044 .62843 .38924 .61795 Metetra
.753 .765 0 r
.38924 .61795 .40044 .62843 .41911 .62428 .40799 .61373 Metetra
.771 .765 0 r
.40799 .61373 .41911 .62428 .43793 .62014 .42689 .60952 Metetra
.777 .752 0 r
.42689 .60952 .43793 .62014 .4569 .61601 .44593 .60532 Metetra
.782 .738 0 r
.44593 .60532 .4569 .61601 .47602 .6119 .46513 .60112 Metetra
.789 .723 0 r
.46513 .60112 .47602 .6119 .49528 .60781 .48448 .59696 Metetra
.795 .707 0 r
.48448 .59696 .49528 .60781 .51471 .60374 .50399 .59281 Metetra
.801 .69 0 r
.50399 .59281 .51471 .60374 .53429 .5997 .52365 .58869 Metetra
.808 .672 0 r
.52365 .58869 .53429 .5997 .55403 .59569 .54348 .5846 Metetra
.815 .653 0 r
.54348 .5846 .55403 .59569 .57394 .59173 .56347 .58056 Metetra
.822 .633 0 r
.56347 .58056 .57394 .59173 .59401 .58781 .58363 .57656 Metetra
.83 .611 0 r
.58363 .57656 .59401 .58781 .61425 .58395 .60397 .57261 Metetra
.838 .588 0 r
.60397 .57261 .61425 .58395 .63467 .58016 .62448 .56873 Metetra
.846 .563 0 r
.62448 .56873 .63467 .58016 .65527 .57645 .64517 .56493 Metetra
.855 .537 0 r
.64517 .56493 .65527 .57645 .67605 .57282 .66605 .56121 Metetra
.865 .508 0 r
.66605 .56121 .67605 .57282 .69703 .5693 .68712 .55759 Metetra
.874 .476 0 r
.68712 .55759 .69703 .5693 .7182 .56589 .70838 .55409 Metetra
.885 .442 0 r
.70838 .55409 .7182 .56589 .73957 .56261 .72985 .55072 Metetra
.896 .404 0 r
.72985 .55072 .73957 .56261 .76115 .55949 .75153 .54749 Metetra
.908 .363 0 r
.75153 .54749 .76115 .55949 .78294 .55655 .77343 .54444 Metetra
.92 .318 0 r
.77343 .54444 .78294 .55655 .80497 .55382 .79556 .5416 Metetra
.934 .268 0 r
.79556 .5416 .80497 .55382 .82723 .55129 .81792 .53896 Metetra
.947 .216 0 r
.81792 .53896 .82723 .55129 .8497 .54865 .8405 .53622 Metetra
.955 .184 0 r
.8405 .53622 .8497 .54865 .87207 .54293 .863 .53048 Metetra
.93 .283 0 r
.863 .53048 .87207 .54293 .89291 .52156 .88403 .50933 Metetra
.807 .674 0 r
.88403 .50933 .89291 .52156 .90945 .46361 .90086 .45179 Metetra
0 .526 .029 r
.27355 .55722 .28502 .56769 .29937 .61202 .28777 .60165 Metetra
.393 .673 0 r
.28777 .60165 .29937 .61202 .316 .62905 .30439 .61873 Metetra
.61 .731 0 r
.30439 .61873 .316 .62905 .33388 .62989 .32232 .61953 Metetra
.676 .747 0 r
.32232 .61953 .33388 .62989 .35217 .62634 .34067 .61592 Metetra
.704 .754 0 r
.34067 .61592 .35217 .62634 .37063 .62217 .35921 .61168 Metetra
.726 .759 0 r
.35921 .61168 .37063 .62217 .38924 .61795 .37789 .60739 Metetra
.749 .765 0 r
.37789 .60739 .38924 .61795 .40799 .61373 .39672 .6031 Metetra
.77 .767 0 r
.39672 .6031 .40799 .61373 .42689 .60952 .4157 .59881 Metetra
.776 .754 0 r
.4157 .59881 .42689 .60952 .44593 .60532 .43482 .59453 Metetra
.782 .74 0 r
.43482 .59453 .44593 .60532 .46513 .60112 .4541 .59027 Metetra
.788 .725 0 r
.4541 .59027 .46513 .60112 .48448 .59696 .47353 .58603 Metetra
.794 .709 0 r
.47353 .58603 .48448 .59696 .50399 .59281 .49312 .5818 Metetra
.8 .692 0 r
.49312 .5818 .50399 .59281 .52365 .58869 .51288 .5776 Metetra
.807 .675 0 r
.51288 .5776 .52365 .58869 .54348 .5846 .53279 .57343 Metetra
.814 .656 0 r
.53279 .57343 .54348 .5846 .56347 .58056 .55287 .5693 Metetra
.821 .636 0 r
.55287 .5693 .56347 .58056 .58363 .57656 .57312 .56522 Metetra
.829 .615 0 r
.57312 .56522 .58363 .57656 .60397 .57261 .59355 .56119 Metetra
.837 .592 0 r
.59355 .56119 .60397 .57261 .62448 .56873 .61415 .55723 Metetra
.845 .567 0 r
.61415 .55723 .62448 .56873 .64517 .56493 .63494 .55333 Metetra
.854 .54 0 r
.63494 .55333 .64517 .56493 .66605 .56121 .65591 .54953 Metetra
.863 .512 0 r
.65591 .54953 .66605 .56121 .68712 .55759 .67708 .54582 Metetra
.873 .48 0 r
.67708 .54582 .68712 .55759 .70838 .55409 .69844 .54222 Metetra
.883 .447 0 r
.69844 .54222 .70838 .55409 .72985 .55072 .72001 .53875 Metetra
.894 .41 0 r
.72001 .53875 .72985 .55072 .75153 .54749 .74179 .53543 Metetra
.906 .369 0 r
.74179 .53543 .75153 .54749 .77343 .54444 .7638 .53228 Metetra
.919 .324 0 r
.7638 .53228 .77343 .54444 .79556 .5416 .78603 .52933 Metetra
.932 .275 0 r
.78603 .52933 .79556 .5416 .81792 .53896 .8085 .52659 Metetra
.946 .223 0 r
.8085 .52659 .81792 .53896 .8405 .53622 .83118 .52375 Metetra
.954 .191 0 r
.83118 .52375 .8405 .53622 .863 .53048 .85381 .51796 Metetra
.929 .287 0 r
.85381 .51796 .863 .53048 .88403 .50933 .87502 .49695 Metetra
.808 .673 0 r
.87502 .49695 .88403 .50933 .90086 .45179 .89214 .43969 Metetra
0 .525 .03 r
.26192 .54667 .27355 .55722 .28777 .60165 .27602 .59121 Metetra
.391 .673 0 r
.27602 .59121 .28777 .60165 .30439 .61873 .29262 .60832 Metetra
.607 .73 0 r
.29262 .60832 .30439 .61873 .32232 .61953 .3106 .60909 Metetra
.674 .747 0 r
.3106 .60909 .32232 .61953 .34067 .61592 .32903 .60541 Metetra
.701 .753 0 r
.32903 .60541 .34067 .61592 .35921 .61168 .34764 .6011 Metetra
.724 .759 0 r
.34764 .6011 .35921 .61168 .37789 .60739 .3664 .59674 Metetra
.747 .764 0 r
.3664 .59674 .37789 .60739 .39672 .6031 .38531 .59237 Metetra
.769 .769 0 r
.38531 .59237 .39672 .6031 .4157 .59881 .40436 .58801 Metetra
.775 .755 0 r
.40436 .58801 .4157 .59881 .43482 .59453 .42357 .58366 Metetra
.781 .741 0 r
.42357 .58366 .43482 .59453 .4541 .59027 .44293 .57932 Metetra
.787 .727 0 r
.44293 .57932 .4541 .59027 .47353 .58603 .46244 .575 Metetra
.793 .711 0 r
.46244 .575 .47353 .58603 .49312 .5818 .48212 .5707 Metetra
.8 .694 0 r
.48212 .5707 .49312 .5818 .51288 .5776 .50195 .56642 Metetra
.806 .677 0 r
.50195 .56642 .51288 .5776 .53279 .57343 .52196 .56217 Metetra
.813 .658 0 r
.52196 .56217 .53279 .57343 .55287 .5693 .54213 .55796 Metetra
.821 .638 0 r
.54213 .55796 .55287 .5693 .57312 .56522 .56247 .55379 Metetra
.828 .617 0 r
.56247 .55379 .57312 .56522 .59355 .56119 .58299 .54968 Metetra
.836 .594 0 r
.58299 .54968 .59355 .56119 .61415 .55723 .60368 .54563 Metetra
.844 .57 0 r
.60368 .54563 .61415 .55723 .63494 .55333 .62457 .54165 Metetra
.853 .543 0 r
.62457 .54165 .63494 .55333 .65591 .54953 .64564 .53776 Metetra
.862 .515 0 r
.64564 .53776 .65591 .54953 .67708 .54582 .6669 .53396 Metetra
.872 .484 0 r
.6669 .53396 .67708 .54582 .69844 .54222 .68837 .53027 Metetra
.882 .45 0 r
.68837 .53027 .69844 .54222 .72001 .53875 .71004 .52671 Metetra
.893 .413 0 r
.71004 .52671 .72001 .53875 .74179 .53543 .73192 .5233 Metetra
.905 .373 0 r
.73192 .5233 .74179 .53543 .7638 .53228 .75403 .52005 Metetra
.917 .329 0 r
.75403 .52005 .7638 .53228 .78603 .52933 .77637 .517 Metetra
.931 .28 0 r
.77637 .517 .78603 .52933 .8085 .52659 .79895 .51416 Metetra
.944 .229 0 r
.79895 .51416 .8085 .52659 .83118 .52375 .82175 .51122 Metetra
.952 .197 0 r
.82175 .51122 .83118 .52375 .85381 .51796 .8445 .50537 Metetra
.928 .291 0 r
.8445 .50537 .85381 .51796 .87502 .49695 .86589 .48443 Metetra
.808 .671 0 r
.86589 .48443 .87502 .49695 .89214 .43969 .88327 .4273 Metetra
0 .525 .032 r
.25015 .53607 .26192 .54667 .27602 .59121 .26412 .58071 Metetra
.389 .672 0 r
.26412 .58071 .27602 .59121 .29262 .60832 .2807 .59784 Metetra
.606 .73 0 r
.2807 .59784 .29262 .60832 .3106 .60909 .29873 .59856 Metetra
.672 .746 0 r
.29873 .59856 .3106 .60909 .32903 .60541 .31723 .59481 Metetra
.699 .753 0 r
.31723 .59481 .32903 .60541 .34764 .6011 .33592 .59043 Metetra
.722 .758 0 r
.33592 .59043 .34764 .6011 .3664 .59674 .35476 .58599 Metetra
.745 .764 0 r
.35476 .58599 .3664 .59674 .38531 .59237 .37374 .58156 Metetra
.768 .769 0 r
.37374 .58156 .38531 .59237 .40436 .58801 .39287 .57712 Metetra
.775 .756 0 r
.39287 .57712 .40436 .58801 .42357 .58366 .41216 .5727 Metetra
.78 .742 0 r
.41216 .5727 .42357 .58366 .44293 .57932 .4316 .56828 Metetra
.786 .728 0 r
.4316 .56828 .44293 .57932 .46244 .575 .4512 .56388 Metetra
.793 .712 0 r
.4512 .56388 .46244 .575 .48212 .5707 .47096 .5595 Metetra
.799 .696 0 r
.47096 .5595 .48212 .5707 .50195 .56642 .49089 .55514 Metetra
.806 .678 0 r
.49089 .55514 .50195 .56642 .52196 .56217 .51098 .55082 Metetra
.813 .66 0 r
.51098 .55082 .52196 .56217 .54213 .55796 .53124 .54653 Metetra
.82 .64 0 r
.53124 .54653 .54213 .55796 .56247 .55379 .55167 .54228 Metetra
.828 .619 0 r
.55167 .54228 .56247 .55379 .58299 .54968 .57228 .53809 Metetra
.835 .596 0 r
.57228 .53809 .58299 .54968 .60368 .54563 .59307 .53395 Metetra
.844 .571 0 r
.59307 .53395 .60368 .54563 .62457 .54165 .61405 .52989 Metetra
.852 .545 0 r
.61405 .52989 .62457 .54165 .64564 .53776 .63522 .52591 Metetra
.862 .517 0 r
.63522 .52591 .64564 .53776 .6669 .53396 .65659 .52202 Metetra
.871 .486 0 r
.65659 .52202 .6669 .53396 .68837 .53027 .67816 .51825 Metetra
.882 .453 0 r
.67816 .51825 .68837 .53027 .71004 .52671 .69993 .51459 Metetra
.892 .416 0 r
.69993 .51459 .71004 .52671 .73192 .5233 .72192 .51109 Metetra
.904 .376 0 r
.72192 .51109 .73192 .5233 .75403 .52005 .74414 .50775 Metetra
.916 .332 0 r
.74414 .50775 .75403 .52005 .77637 .517 .76659 .50461 Metetra
.93 .284 0 r
.76659 .50461 .77637 .517 .79895 .51416 .78928 .50167 Metetra
.943 .233 0 r
.78928 .50167 .79895 .51416 .82175 .51122 .81219 .49864 Metetra
.951 .201 0 r
.81219 .49864 .82175 .51122 .8445 .50537 .83507 .49272 Metetra
.927 .293 0 r
.83507 .49272 .8445 .50537 .86589 .48443 .85663 .47176 Metetra
.809 .671 0 r
.85663 .47176 .86589 .48443 .88327 .4273 .87427 .41462 Metetra
0 .524 .032 r
.23822 .52539 .25015 .53607 .26412 .58071 .25206 .57012 Metetra
.388 .672 0 r
.25206 .57012 .26412 .58071 .2807 .59784 .26862 .58726 Metetra
.605 .73 0 r
.26862 .58726 .2807 .59784 .29873 .59856 .28671 .58794 Metetra
.671 .746 0 r
.28671 .58794 .29873 .59856 .31723 .59481 .30528 .58412 Metetra
.698 .753 0 r
.30528 .58412 .31723 .59481 .33592 .59043 .32404 .57966 Metetra
.721 .758 0 r
.32404 .57966 .33592 .59043 .35476 .58599 .34295 .57516 Metetra
.744 .763 0 r
.34295 .57516 .35476 .58599 .37374 .58156 .36202 .57065 Metetra
.767 .769 0 r
.36202 .57065 .37374 .58156 .39287 .57712 .38123 .56614 Metetra
.774 .757 0 r
.38123 .56614 .39287 .57712 .41216 .5727 .4006 .56164 Metetra
.78 .743 0 r
.4006 .56164 .41216 .5727 .4316 .56828 .42012 .55714 Metetra
.786 .728 0 r
.42012 .55714 .4316 .56828 .4512 .56388 .43981 .55267 Metetra
.792 .713 0 r
.43981 .55267 .4512 .56388 .47096 .5595 .45965 .54821 Metetra
.799 .696 0 r
.45965 .54821 .47096 .5595 .49089 .55514 .47967 .54377 Metetra
.805 .679 0 r
.47967 .54377 .49089 .55514 .51098 .55082 .49985 .53937 Metetra
.812 .66 0 r
.49985 .53937 .51098 .55082 .53124 .54653 .5202 .535 Metetra
.82 .641 0 r
.5202 .535 .53124 .54653 .55167 .54228 .54073 .53067 Metetra
.827 .619 0 r
.54073 .53067 .55167 .54228 .57228 .53809 .56143 .52639 Metetra
.835 .597 0 r
.56143 .52639 .57228 .53809 .59307 .53395 .58232 .52218 Metetra
.843 .572 0 r
.58232 .52218 .59307 .53395 .61405 .52989 .6034 .51803 Metetra
.852 .546 0 r
.6034 .51803 .61405 .52989 .63522 .52591 .62467 .51397 Metetra
.861 .518 0 r
.62467 .51397 .63522 .52591 .65659 .52202 .64613 .51 Metetra
.871 .487 0 r
.64613 .51 .65659 .52202 .67816 .51825 .66781 .50613 Metetra
.881 .454 0 r
.66781 .50613 .67816 .51825 .69993 .51459 .68969 .5024 Metetra
.892 .418 0 r
.68969 .5024 .69993 .51459 .72192 .51109 .71179 .4988 Metetra
.903 .378 0 r
.71179 .4988 .72192 .51109 .74414 .50775 .73411 .49537 Metetra
.916 .334 0 r
.73411 .49537 .74414 .50775 .76659 .50461 .75667 .49214 Metetra
.929 .286 0 r
.75667 .49214 .76659 .50461 .78928 .50167 .77947 .48911 Metetra
.943 .235 0 r
.77947 .48911 .78928 .50167 .81219 .49864 .8025 .48599 Metetra
.951 .203 0 r
.8025 .48599 .81219 .49864 .83507 .49272 .82551 .47999 Metetra
.927 .294 0 r
.82551 .47999 .83507 .49272 .85663 .47176 .84724 .45894 Metetra
.809 .67 0 r
.84724 .45894 .85663 .47176 .87427 .41462 .86512 .40165 Metetra
0 .524 .033 r
.22614 .51464 .23822 .52539 .25206 .57012 .23984 .55946 Metetra
.388 .672 0 r
.23984 .55946 .25206 .57012 .26862 .58726 .25639 .5766 Metetra
.604 .73 0 r
.25639 .5766 .26862 .58726 .28671 .58794 .27452 .57722 Metetra
.671 .746 0 r
.27452 .57722 .28671 .58794 .30528 .58412 .29317 .57333 Metetra
.698 .753 0 r
.29317 .57333 .30528 .58412 .32404 .57966 .312 .5688 Metetra
.721 .758 0 r
.312 .5688 .32404 .57966 .34295 .57516 .33099 .56422 Metetra
.743 .763 0 r
.33099 .56422 .34295 .57516 .36202 .57065 .35013 .55964 Metetra
.767 .769 0 r
.35013 .55964 .36202 .57065 .38123 .56614 .36943 .55506 Metetra
.774 .757 0 r
.36943 .55506 .38123 .56614 .4006 .56164 .38888 .55048 Metetra
.78 .743 0 r
.38888 .55048 .4006 .56164 .42012 .55714 .40849 .54591 Metetra
.786 .729 0 r
.40849 .54591 .42012 .55714 .43981 .55267 .42826 .54136 Metetra
.792 .713 0 r
.42826 .54136 .43981 .55267 .45965 .54821 .44819 .53682 Metetra
.799 .697 0 r
.44819 .53682 .45965 .54821 .47967 .54377 .46829 .53231 Metetra
.805 .679 0 r
.46829 .53231 .47967 .54377 .49985 .53937 .48856 .52782 Metetra
.812 .661 0 r
.48856 .52782 .49985 .53937 .5202 .535 .50901 .52337 Metetra
.82 .641 0 r
.50901 .52337 .5202 .535 .54073 .53067 .52963 .51896 Metetra
.827 .62 0 r
.52963 .51896 .54073 .53067 .56143 .52639 .55043 .51461 Metetra
.835 .597 0 r
.55043 .51461 .56143 .52639 .58232 .52218 .57142 .51031 Metetra
.843 .573 0 r
.57142 .51031 .58232 .52218 .6034 .51803 .59259 .50608 Metetra
.852 .547 0 r
.59259 .50608 .6034 .51803 .62467 .51397 .61396 .50193 Metetra
.861 .518 0 r
.61396 .50193 .62467 .51397 .64613 .51 .63553 .49788 Metetra
.871 .488 0 r
.63553 .49788 .64613 .51 .66781 .50613 .65731 .49393 Metetra
.881 .454 0 r
.65731 .49393 .66781 .50613 .68969 .5024 .6793 .49011 Metetra
.892 .418 0 r
.6793 .49011 .68969 .5024 .71179 .4988 .70151 .48643 Metetra
.903 .378 0 r
.70151 .48643 .71179 .4988 .73411 .49537 .72394 .48292 Metetra
.916 .334 0 r
.72394 .48292 .73411 .49537 .75667 .49214 .74662 .4796 Metetra
.929 .286 0 r
.74662 .4796 .75667 .49214 .77947 .48911 .76953 .47649 Metetra
.942 .235 0 r
.76953 .47649 .77947 .48911 .8025 .48599 .79268 .47328 Metetra
.951 .203 0 r
.79268 .47328 .8025 .48599 .82551 .47999 .81582 .46718 Metetra
.927 .294 0 r
.81582 .46718 .82551 .47999 .84724 .45894 .83771 .44597 Metetra
.809 .67 0 r
.83771 .44597 .84724 .45894 .86512 .40165 .85583 .38839 Metetra
0 .524 .032 r
.21389 .50381 .22614 .51464 .23984 .55946 .22745 .54871 Metetra
.388 .672 0 r
.22745 .54871 .23984 .55946 .25639 .5766 .24398 .56584 Metetra
.605 .73 0 r
.24398 .56584 .25639 .5766 .27452 .57722 .26217 .5664 Metetra
.672 .746 0 r
.26217 .5664 .27452 .57722 .29317 .57333 .28089 .56244 Metetra
.699 .753 0 r
.28089 .56244 .29317 .57333 .312 .5688 .2998 .55784 Metetra
.721 .758 0 r
.2998 .55784 .312 .5688 .33099 .56422 .31887 .55319 Metetra
.744 .763 0 r
.31887 .55319 .33099 .56422 .35013 .55964 .33809 .54853 Metetra
.767 .769 0 r
.33809 .54853 .35013 .55964 .36943 .55506 .35747 .54387 Metetra
.774 .757 0 r
.35747 .54387 .36943 .55506 .38888 .55048 .377 .53922 Metetra
.78 .743 0 r
.377 .53922 .38888 .55048 .40849 .54591 .39669 .53457 Metetra
.786 .728 0 r
.39669 .53457 .40849 .54591 .42826 .54136 .41655 .52995 Metetra
.792 .713 0 r
.41655 .52995 .42826 .54136 .44819 .53682 .43657 .52533 Metetra
.799 .696 0 r
.43657 .52533 .44819 .53682 .46829 .53231 .45676 .52074 Metetra
.806 .679 0 r
.45676 .52074 .46829 .53231 .48856 .52782 .47712 .51618 Metetra
.813 .66 0 r
.47712 .51618 .48856 .52782 .50901 .52337 .49766 .51165 Metetra
.82 .64 0 r
.49766 .51165 .50901 .52337 .52963 .51896 .51838 .50716 Metetra
.827 .619 0 r
.51838 .50716 .52963 .51896 .55043 .51461 .53927 .50272 Metetra
.835 .597 0 r
.53927 .50272 .55043 .51461 .57142 .51031 .56036 .49834 Metetra
.843 .572 0 r
.56036 .49834 .57142 .51031 .59259 .50608 .58164 .49403 Metetra
.852 .546 0 r
.58164 .49403 .59259 .50608 .61396 .50193 .60311 .48981 Metetra
.861 .518 0 r
.60311 .48981 .61396 .50193 .63553 .49788 .62479 .48567 Metetra
.871 .487 0 r
.62479 .48567 .63553 .49788 .65731 .49393 .64667 .48164 Metetra
.881 .454 0 r
.64667 .48164 .65731 .49393 .6793 .49011 .66877 .47774 Metetra
.892 .417 0 r
.66877 .47774 .6793 .49011 .70151 .48643 .69109 .47398 Metetra
.904 .377 0 r
.69109 .47398 .70151 .48643 .72394 .48292 .71363 .47039 Metetra
.916 .334 0 r
.71363 .47039 .72394 .48292 .74662 .4796 .73642 .46699 Metetra
.929 .285 0 r
.73642 .46699 .74662 .4796 .76953 .47649 .75946 .4638 Metetra
.943 .234 0 r
.75946 .4638 .76953 .47649 .79268 .47328 .78273 .4605 Metetra
.951 .202 0 r
.78273 .4605 .79268 .47328 .81582 .46718 .80599 .45429 Metetra
.927 .294 0 r
.80599 .45429 .81582 .46718 .83771 .44597 .82804 .43284 Metetra
.809 .67 0 r
.82804 .43284 .83771 .44597 .85583 .38839 .84639 .37482 Metetra
0 .525 .031 r
.20148 .49291 .21389 .50381 .22745 .54871 .2149 .53789 Metetra
.39 .672 0 r
.2149 .53789 .22745 .54871 .24398 .56584 .23141 .555 Metetra
.606 .73 0 r
.23141 .555 .24398 .56584 .26217 .5664 .24965 .55549 Metetra
.673 .746 0 r
.24965 .55549 .26217 .5664 .28089 .56244 .26844 .55146 Metetra
.7 .753 0 r
.26844 .55146 .28089 .56244 .2998 .55784 .28743 .54679 Metetra
.722 .758 0 r
.28743 .54679 .2998 .55784 .31887 .55319 .30658 .54206 Metetra
.745 .764 0 r
.30658 .54206 .31887 .55319 .33809 .54853 .32588 .53732 Metetra
.769 .769 0 r
.32588 .53732 .33809 .54853 .35747 .54387 .34534 .53259 Metetra
.775 .756 0 r
.34534 .53259 .35747 .54387 .377 .53922 .36495 .52786 Metetra
.781 .742 0 r
.36495 .52786 .377 .53922 .39669 .53457 .38473 .52313 Metetra
.787 .727 0 r
.38473 .52313 .39669 .53457 .41655 .52995 .40468 .51843 Metetra
.793 .712 0 r
.40468 .51843 .41655 .52995 .43657 .52533 .42479 .51374 Metetra
.799 .695 0 r
.42479 .51374 .43657 .52533 .45676 .52074 .44507 .50907 Metetra
.806 .678 0 r
.44507 .50907 .45676 .52074 .47712 .51618 .46552 .50443 Metetra
.813 .659 0 r
.46552 .50443 .47712 .51618 .49766 .51165 .48615 .49982 Metetra
.82 .639 0 r
.48615 .49982 .49766 .51165 .51838 .50716 .50696 .49525 Metetra
.828 .618 0 r
.50696 .49525 .51838 .50716 .53927 .50272 .52796 .49074 Metetra
.836 .595 0 r
.52796 .49074 .53927 .50272 .56036 .49834 .54915 .48628 Metetra
.844 .571 0 r
.54915 .48628 .56036 .49834 .58164 .49403 .57052 .48189 Metetra
.853 .545 0 r
.57052 .48189 .58164 .49403 .60311 .48981 .5921 .47758 Metetra
.862 .516 0 r
.5921 .47758 .60311 .48981 .62479 .48567 .61388 .47337 Metetra
.871 .485 0 r
.61388 .47337 .62479 .48567 .64667 .48164 .63587 .46926 Metetra
.882 .452 0 r
.63587 .46926 .64667 .48164 .66877 .47774 .65808 .46528 Metetra
.893 .415 0 r
.65808 .46528 .66877 .47774 .69109 .47398 .68051 .46144 Metetra
.904 .375 0 r
.68051 .46144 .69109 .47398 .71363 .47039 .70318 .45777 Metetra
.917 .331 0 r
.70318 .45777 .71363 .47039 .73642 .46699 .72608 .4543 Metetra
.93 .283 0 r
.72608 .4543 .73642 .46699 .75946 .4638 .74924 .45103 Metetra
.943 .232 0 r
.74924 .45103 .75946 .4638 .78273 .4605 .77263 .44766 Metetra
.952 .2 0 r
.77263 .44766 .78273 .4605 .80599 .45429 .79603 .44131 Metetra
.927 .292 0 r
.79603 .44131 .80599 .45429 .82804 .43284 .81823 .41954 Metetra
.809 .671 0 r
.81823 .41954 .82804 .43284 .84639 .37482 .83681 .36095 Metetra
0 .525 .03 r
.1889 .48193 .20148 .49291 .2149 .53789 .20217 .52698 Metetra
.392 .673 0 r
.20217 .52698 .2149 .53789 .23141 .555 .21866 .54406 Metetra
.608 .731 0 r
.21866 .54406 .23141 .555 .24965 .55549 .23695 .54448 Metetra
.675 .747 0 r
.23695 .54448 .24965 .55549 .26844 .55146 .25582 .54037 Metetra
.702 .753 0 r
.25582 .54037 .26844 .55146 .28743 .54679 .27489 .53562 Metetra
.724 .759 0 r
.27489 .53562 .28743 .54679 .30658 .54206 .29411 .53082 Metetra
.747 .764 0 r
.29411 .53082 .30658 .54206 .32588 .53732 .3135 .52601 Metetra
.77 .768 0 r
.3135 .52601 .32588 .53732 .34534 .53259 .33304 .5212 Metetra
.775 .755 0 r
.33304 .5212 .34534 .53259 .36495 .52786 .35274 .51639 Metetra
.781 .741 0 r
.35274 .51639 .36495 .52786 .38473 .52313 .3726 .51159 Metetra
.787 .726 0 r
.3726 .51159 .38473 .52313 .40468 .51843 .39263 .50681 Metetra
.793 .71 0 r
.39263 .50681 .40468 .51843 .42479 .51374 .41283 .50204 Metetra
.8 .694 0 r
.41283 .50204 .42479 .51374 .44507 .50907 .43321 .49729 Metetra
.807 .676 0 r
.43321 .49729 .44507 .50907 .46552 .50443 .45375 .49257 Metetra
.813 .657 0 r
.45375 .49257 .46552 .50443 .48615 .49982 .47448 .48789 Metetra
.821 .637 0 r
.47448 .48789 .48615 .49982 .50696 .49525 .49539 .48324 Metetra
.828 .616 0 r
.49539 .48324 .50696 .49525 .52796 .49074 .51648 .47865 Metetra
.836 .593 0 r
.51648 .47865 .52796 .49074 .54915 .48628 .53777 .47411 Metetra
.845 .569 0 r
.53777 .47411 .54915 .48628 .57052 .48189 .55925 .46964 Metetra
.853 .542 0 r
.55925 .46964 .57052 .48189 .5921 .47758 .58093 .46526 Metetra
.863 .514 0 r
.58093 .46526 .5921 .47758 .61388 .47337 .60282 .46097 Metetra
.872 .483 0 r
.60282 .46097 .61388 .47337 .63587 .46926 .62492 .45678 Metetra
.883 .449 0 r
.62492 .45678 .63587 .46926 .65808 .46528 .64724 .45272 Metetra
.894 .412 0 r
.64724 .45272 .65808 .46528 .68051 .46144 .66979 .44881 Metetra
.905 .372 0 r
.66979 .44881 .68051 .46144 .70318 .45777 .69257 .44507 Metetra
.918 .328 0 r
.69257 .44507 .70318 .45777 .72608 .4543 .7156 .44153 Metetra
.931 .279 0 r
.7156 .44153 .72608 .4543 .74924 .45103 .73887 .43819 Metetra
.945 .227 0 r
.73887 .43819 .74924 .45103 .77263 .44766 .76239 .43474 Metetra
.953 .195 0 r
.76239 .43474 .77263 .44766 .79603 .44131 .78592 .42825 Metetra
.928 .29 0 r
.78592 .42825 .79603 .44131 .81823 .41954 .80828 .40609 Metetra
.808 .672 0 r
.80828 .40609 .81823 .41954 .83681 .36095 .82707 .34676 Metetra
0 .526 .028 r
.17615 .47088 .1889 .48193 .20217 .52698 .18927 .51599 Metetra
.394 .674 0 r
.18927 .51599 .20217 .52698 .21866 .54406 .20573 .53302 Metetra
.611 .731 0 r
.20573 .53302 .21866 .54406 .23695 .54448 .22408 .53337 Metetra
.678 .748 0 r
.22408 .53337 .23695 .54448 .25582 .54037 .24302 .52918 Metetra
.705 .754 0 r
.24302 .52918 .25582 .54037 .27489 .53562 .26217 .52436 Metetra
.727 .759 0 r
.26217 .52436 .27489 .53562 .29411 .53082 .28148 .51948 Metetra
.75 .765 0 r
.28148 .51948 .29411 .53082 .3135 .52601 .30094 .51459 Metetra
.77 .767 0 r
.30094 .51459 .3135 .52601 .33304 .5212 .32056 .50971 Metetra
.776 .753 0 r
.32056 .50971 .33304 .5212 .35274 .51639 .34035 .50482 Metetra
.782 .739 0 r
.34035 .50482 .35274 .51639 .3726 .51159 .3603 .49994 Metetra
.788 .724 0 r
.3603 .49994 .3726 .51159 .39263 .50681 .38042 .49509 Metetra
.794 .708 0 r
.38042 .49509 .39263 .50681 .41283 .50204 .40071 .49024 Metetra
.801 .692 0 r
.40071 .49024 .41283 .50204 .43321 .49729 .42118 .48541 Metetra
.807 .674 0 r
.42118 .48541 .43321 .49729 .45375 .49257 .44182 .48061 Metetra
.814 .655 0 r
.44182 .48061 .45375 .49257 .47448 .48789 .46264 .47585 Metetra
.822 .635 0 r
.46264 .47585 .47448 .48789 .49539 .48324 .48365 .47112 Metetra
.829 .614 0 r
.48365 .47112 .49539 .48324 .51648 .47865 .50484 .46645 Metetra
.837 .591 0 r
.50484 .46645 .51648 .47865 .53777 .47411 .52623 .46184 Metetra
.846 .566 0 r
.52623 .46184 .53777 .47411 .55925 .46964 .54782 .4573 Metetra
.854 .539 0 r
.54782 .4573 .55925 .46964 .58093 .46526 .5696 .45283 Metetra
.864 .51 0 r
.5696 .45283 .58093 .46526 .60282 .46097 .5916 .44847 Metetra
.873 .479 0 r
.5916 .44847 .60282 .46097 .62492 .45678 .61381 .44421 Metetra
.884 .445 0 r
.61381 .44421 .62492 .45678 .64724 .45272 .63625 .44008 Metetra
.895 .408 0 r
.63625 .44008 .64724 .45272 .66979 .44881 .65891 .4361 Metetra
.906 .367 0 r
.65891 .4361 .66979 .44881 .69257 .44507 .68181 .43228 Metetra
.919 .322 0 r
.68181 .43228 .69257 .44507 .7156 .44153 .70496 .42868 Metetra
.932 .273 0 r
.70496 .42868 .7156 .44153 .73887 .43819 .72836 .42528 Metetra
.946 .221 0 r
.72836 .42528 .73887 .43819 .76239 .43474 .75201 .42176 Metetra
.954 .189 0 r
.75201 .42176 .76239 .43474 .78592 .42825 .77566 .41511 Metetra
.929 .286 0 r
.77566 .41511 .78592 .42825 .80828 .40609 .79817 .39246 Metetra
.808 .673 0 r
.79817 .39246 .80828 .40609 .82707 .34676 .81717 .33225 Metetra
0 .527 .025 r
.16322 .45974 .17615 .47088 .18927 .51599 .17618 .50491 Metetra
.398 .675 0 r
.17618 .50491 .18927 .51599 .20573 .53302 .19263 .52188 Metetra
.614 .732 0 r
.19263 .52188 .20573 .53302 .22408 .53337 .21103 .52215 Metetra
.681 .748 0 r
.21103 .52215 .22408 .53337 .24302 .52918 .23004 .51789 Metetra
.708 .755 0 r
.23004 .51789 .24302 .52918 .26217 .52436 .24927 .51299 Metetra
.731 .76 0 r
.24927 .51299 .26217 .52436 .28148 .51948 .26866 .50803 Metetra
.754 .766 0 r
.26866 .50803 .28148 .51948 .30094 .51459 .2882 .50307 Metetra
.771 .765 0 r
.2882 .50307 .30094 .51459 .32056 .50971 .30791 .4981 Metetra
.777 .751 0 r
.30791 .4981 .32056 .50971 .34035 .50482 .32778 .49314 Metetra
.783 .737 0 r
.32778 .49314 .34035 .50482 .3603 .49994 .34782 .48819 Metetra
.789 .722 0 r
.34782 .48819 .3603 .49994 .38042 .49509 .36803 .48325 Metetra
.795 .706 0 r
.36803 .48325 .38042 .49509 .40071 .49024 .38841 .47833 Metetra
.802 .689 0 r
.38841 .47833 .40071 .49024 .42118 .48541 .40897 .47342 Metetra
.808 .671 0 r
.40897 .47342 .42118 .48541 .44182 .48061 .42971 .46854 Metetra
.815 .652 0 r
.42971 .46854 .44182 .48061 .46264 .47585 .45063 .4637 Metetra
.823 .632 0 r
.45063 .4637 .46264 .47585 .48365 .47112 .47173 .4589 Metetra
.83 .61 0 r
.47173 .4589 .48365 .47112 .50484 .46645 .49303 .45415 Metetra
.838 .587 0 r
.49303 .45415 .50484 .46645 .52623 .46184 .51452 .44946 Metetra
.847 .562 0 r
.51452 .44946 .52623 .46184 .54782 .4573 .53621 .44485 Metetra
.856 .535 0 r
.53621 .44485 .54782 .4573 .5696 .45283 .55811 .44031 Metetra
.865 .506 0 r
.55811 .44031 .5696 .45283 .5916 .44847 .58021 .43587 Metetra
.875 .474 0 r
.58021 .43587 .5916 .44847 .61381 .44421 .60254 .43154 Metetra
.885 .44 0 r
.60254 .43154 .61381 .44421 .63625 .44008 .62509 .42734 Metetra
.896 .402 0 r
.62509 .42734 .63625 .44008 .65891 .4361 .64787 .42329 Metetra
.908 .361 0 r
.64787 .42329 .65891 .4361 .68181 .43228 .67089 .41942 Metetra
.921 .316 0 r
.67089 .41942 .68181 .43228 .70496 .42868 .69416 .41575 Metetra
.934 .266 0 r
.69416 .41575 .70496 .42868 .72836 .42528 .71769 .4123 Metetra
.948 .213 0 r
.71769 .4123 .72836 .42528 .75201 .42176 .74146 .40871 Metetra
.956 .181 0 r
.74146 .40871 .75201 .42176 .77566 .41511 .76526 .40187 Metetra
.93 .281 0 r
.76526 .40187 .77566 .41511 .79817 .39246 .78791 .37865 Metetra
.807 .675 0 r
.78791 .37865 .79817 .39246 .81717 .33225 .80712 .3174 Metetra
0 .529 .022 r
.15011 .44852 .16322 .45974 .17618 .50491 .16291 .49374 Metetra
.402 .676 0 r
.16291 .49374 .17618 .50491 .19263 .52188 .17933 .51065 Metetra
.619 .733 0 r
.17933 .51065 .19263 .52188 .21103 .52215 .19779 .51083 Metetra
.685 .749 0 r
.19779 .51083 .21103 .52215 .23004 .51789 .21688 .50649 Metetra
.713 .756 0 r
.21688 .50649 .23004 .51789 .24927 .51299 .23619 .50151 Metetra
.736 .761 0 r
.23619 .50151 .24927 .51299 .26866 .50803 .25565 .49648 Metetra
.759 .767 0 r
.25565 .49648 .26866 .50803 .2882 .50307 .27528 .49144 Metetra
.772 .762 0 r
.27528 .49144 .2882 .50307 .30791 .4981 .29508 .4864 Metetra
.778 .748 0 r
.29508 .4864 .30791 .4981 .32778 .49314 .31504 .48136 Metetra
.784 .734 0 r
.31504 .48136 .32778 .49314 .34782 .48819 .33516 .47632 Metetra
.79 .719 0 r
.33516 .47632 .34782 .48819 .36803 .48325 .35546 .47131 Metetra
.796 .703 0 r
.35546 .47131 .36803 .48325 .38841 .47833 .37593 .46631 Metetra
.803 .686 0 r
.37593 .46631 .38841 .47833 .40897 .47342 .39658 .46132 Metetra
.81 .668 0 r
.39658 .46132 .40897 .47342 .42971 .46854 .41742 .45637 Metetra
.817 .648 0 r
.41742 .45637 .42971 .46854 .45063 .4637 .43843 .45145 Metetra
.824 .628 0 r
.43843 .45145 .45063 .4637 .47173 .4589 .45964 .44658 Metetra
.832 .606 0 r
.45964 .44658 .47173 .4589 .49303 .45415 .48104 .44175 Metetra
.84 .583 0 r
.48104 .44175 .49303 .45415 .51452 .44946 .50263 .43699 Metetra
.848 .557 0 r
.50263 .43699 .51452 .44946 .53621 .44485 .52443 .43229 Metetra
.857 .53 0 r
.52443 .43229 .53621 .44485 .55811 .44031 .54644 .42769 Metetra
.867 .501 0 r
.54644 .42769 .55811 .44031 .58021 .43587 .56865 .42318 Metetra
.877 .469 0 r
.56865 .42318 .58021 .43587 .60254 .43154 .59109 .41878 Metetra
.887 .434 0 r
.59109 .41878 .60254 .43154 .62509 .42734 .61376 .41451 Metetra
.898 .396 0 r
.61376 .41451 .62509 .42734 .64787 .42329 .63666 .4104 Metetra
.91 .354 0 r
.63666 .4104 .64787 .42329 .67089 .41942 .6598 .40647 Metetra
.923 .308 0 r
.6598 .40647 .67089 .41942 .69416 .41575 .6832 .40275 Metetra
.937 .257 0 r
.6832 .40275 .69416 .41575 .71769 .4123 .70686 .39925 Metetra
.951 .203 0 r
.70686 .39925 .71769 .4123 .74146 .40871 .73077 .3956 Metetra
.959 .172 0 r
.73077 .3956 .74146 .40871 .76526 .40187 .75469 .38856 Metetra
.932 .276 0 r
.75469 .38856 .76526 .40187 .78791 .37865 .7775 .36465 Metetra
.806 .677 0 r
.7775 .36465 .78791 .37865 .80712 .3174 .79691 .30219 Metetra
0 .531 .018 r
.13682 .43722 .15011 .44852 .16291 .49374 .14945 .48249 Metetra
.408 .677 0 r
.14945 .48249 .16291 .49374 .17933 .51065 .16585 .49932 Metetra
.624 .735 0 r
.16585 .49932 .17933 .51065 .19779 .51083 .18436 .49942 Metetra
.691 .751 0 r
.18436 .49942 .19779 .51083 .21688 .50649 .20353 .49499 Metetra
.718 .757 0 r
.20353 .49499 .21688 .50649 .23619 .50151 .22291 .48993 Metetra
.741 .763 0 r
.22291 .48993 .23619 .50151 .25565 .49648 .24246 .48482 Metetra
.764 .768 0 r
.24246 .48482 .25565 .49648 .27528 .49144 .26218 .4797 Metetra
.774 .759 0 r
.26218 .4797 .27528 .49144 .29508 .4864 .28205 .47458 Metetra
.779 .745 0 r
.28205 .47458 .29508 .4864 .31504 .48136 .3021 .46946 Metetra
.785 .73 0 r
.3021 .46946 .31504 .48136 .33516 .47632 .32232 .46435 Metetra
.791 .715 0 r
.32232 .46435 .33516 .47632 .35546 .47131 .3427 .45926 Metetra
.798 .699 0 r
.3427 .45926 .35546 .47131 .37593 .46631 .36327 .45418 Metetra
.804 .682 0 r
.36327 .45418 .37593 .46631 .39658 .46132 .38402 .44912 Metetra
.811 .663 0 r
.38402 .44912 .39658 .46132 .41742 .45637 .40494 .44409 Metetra
.818 .644 0 r
.40494 .44409 .41742 .45637 .43843 .45145 .42606 .43909 Metetra
.826 .623 0 r
.42606 .43909 .43843 .45145 .45964 .44658 .44737 .43414 Metetra
.834 .601 0 r
.44737 .43414 .45964 .44658 .48104 .44175 .46887 .42924 Metetra
.842 .577 0 r
.46887 .42924 .48104 .44175 .50263 .43699 .49057 .42441 Metetra
.85 .552 0 r
.49057 .42441 .50263 .43699 .52443 .43229 .51247 .41964 Metetra
.859 .524 0 r
.51247 .41964 .52443 .43229 .54644 .42769 .53459 .41496 Metetra
.869 .494 0 r
.53459 .41496 .54644 .42769 .56865 .42318 .55692 .41039 Metetra
.879 .461 0 r
.55692 .41039 .56865 .42318 .59109 .41878 .57947 .40592 Metetra
.889 .426 0 r
.57947 .40592 .59109 .41878 .61376 .41451 .60226 .4016 Metetra
.901 .387 0 r
.60226 .4016 .61376 .41451 .63666 .4104 .62528 .39743 Metetra
.913 .345 0 r
.62528 .39743 .63666 .4104 .6598 .40647 .64855 .39344 Metetra
.926 .298 0 r
.64855 .39344 .6598 .40647 .6832 .40275 .67207 .38968 Metetra
.94 .246 0 r
.67207 .38968 .6832 .40275 .70686 .39925 .69586 .38613 Metetra
.954 .191 0 r
.69586 .38613 .70686 .39925 .73077 .3956 .7199 .38242 Metetra
.962 .16 0 r
.7199 .38242 .73077 .3956 .75469 .38856 .74397 .37515 Metetra
.933 .269 0 r
.74397 .37515 .75469 .38856 .7775 .36465 .76692 .35046 Metetra
.805 .68 0 r
.76692 .35046 .7775 .36465 .79691 .30219 .78653 .28662 Metetra
0 .533 .014 r
.12333 .42584 .13682 .43722 .14945 .48249 .13579 .47115 Metetra
.414 .679 0 r
.13579 .47115 .14945 .48249 .16585 .49932 .15217 .4879 Metetra
.63 .736 0 r
.15217 .4879 .16585 .49932 .18436 .49942 .17074 .48789 Metetra
.697 .752 0 r
.17074 .48789 .18436 .49942 .20353 .49499 .18998 .48338 Metetra
.724 .759 0 r
.18998 .48338 .20353 .49499 .22291 .48993 .20944 .47825 Metetra
.747 .764 0 r
.20944 .47825 .22291 .48993 .24246 .48482 .22908 .47305 Metetra
.77 .768 0 r
.22908 .47305 .24246 .48482 .26218 .4797 .24887 .46786 Metetra
.775 .755 0 r
.24887 .46786 .26218 .4797 .28205 .47458 .26884 .46266 Metetra
.781 .741 0 r
.26884 .46266 .28205 .47458 .3021 .46946 .28897 .45746 Metetra
.787 .726 0 r
.28897 .45746 .3021 .46946 .32232 .46435 .30928 .45227 Metetra
.793 .711 0 r
.30928 .45227 .32232 .46435 .3427 .45926 .32976 .4471 Metetra
.8 .694 0 r
.32976 .4471 .3427 .45926 .36327 .45418 .35042 .44194 Metetra
.806 .677 0 r
.35042 .44194 .36327 .45418 .38402 .44912 .37126 .43681 Metetra
.813 .659 0 r
.37126 .43681 .38402 .44912 .40494 .44409 .39228 .4317 Metetra
.82 .639 0 r
.39228 .4317 .40494 .44409 .42606 .43909 .4135 .42663 Metetra
.828 .618 0 r
.4135 .42663 .42606 .43909 .44737 .43414 .43491 .4216 Metetra
.836 .595 0 r
.43491 .4216 .44737 .43414 .46887 .42924 .45651 .41663 Metetra
.844 .571 0 r
.45651 .41663 .46887 .42924 .49057 .42441 .47832 .41172 Metetra
.852 .545 0 r
.47832 .41172 .49057 .42441 .51247 .41964 .50033 .40689 Metetra
.862 .517 0 r
.50033 .40689 .51247 .41964 .53459 .41496 .52256 .40214 Metetra
.871 .486 0 r
.52256 .40214 .53459 .41496 .55692 .41039 .545 .3975 Metetra
.881 .453 0 r
.545 .3975 .55692 .41039 .57947 .40592 .56768 .39298 Metetra
.892 .417 0 r
.56768 .39298 .57947 .40592 .60226 .4016 .59058 .38859 Metetra
.904 .378 0 r
.59058 .38859 .60226 .4016 .62528 .39743 .61372 .38437 Metetra
.916 .334 0 r
.61372 .38437 .62528 .39743 .64855 .39344 .63712 .38035 Metetra
.929 .286 0 r
.63712 .38035 .64855 .39344 .67207 .38968 .66077 .37654 Metetra
.943 .233 0 r
.66077 .37654 .67207 .38968 .69586 .38613 .68469 .37296 Metetra
.957 .177 0 r
.68469 .37296 .69586 .38613 .7199 .38242 .70888 .36919 Metetra
.965 .146 0 r
.70888 .36919 .7199 .38242 .74397 .37515 .73308 .36166 Metetra
.935 .262 0 r
.73308 .36166 .74397 .37515 .76692 .35046 .75618 .33607 Metetra
.804 .683 0 r
.75618 .33607 .76692 .35046 .78653 .28662 .77598 .27065 Metetra
0 .535 .008 r
.10965 .41437 .12333 .42584 .13579 .47115 .12193 .45973 Metetra
.421 .681 0 r
.12193 .45973 .13579 .47115 .15217 .4879 .13829 .47638 Metetra
.637 .738 0 r
.13829 .47638 .15217 .4879 .17074 .48789 .15691 .47627 Metetra
.704 .754 0 r
.15691 .47627 .17074 .48789 .18998 .48338 .17623 .47168 Metetra
.732 .76 0 r
.17623 .47168 .18998 .48338 .20944 .47825 .19578 .46646 Metetra
.755 .766 0 r
.19578 .46646 .20944 .47825 .22908 .47305 .21549 .46119 Metetra
.771 .764 0 r
.21549 .46119 .22908 .47305 .24887 .46786 .23537 .45591 Metetra
.777 .751 0 r
.23537 .45591 .24887 .46786 .26884 .46266 .25542 .45063 Metetra
.783 .737 0 r
.25542 .45063 .26884 .46266 .28897 .45746 .27564 .44535 Metetra
.789 .722 0 r
.27564 .44535 .28897 .45746 .30928 .45227 .29604 .44009 Metetra
.795 .706 0 r
.29604 .44009 .30928 .45227 .32976 .4471 .31661 .43483 Metetra
.802 .689 0 r
.31661 .43483 .32976 .4471 .35042 .44194 .33737 .4296 Metetra
.808 .672 0 r
.33737 .4296 .35042 .44194 .37126 .43681 .3583 .42439 Metetra
.815 .653 0 r
.3583 .42439 .37126 .43681 .39228 .4317 .37943 .41921 Metetra
.822 .633 0 r
.37943 .41921 .39228 .4317 .4135 .42663 .40074 .41406 Metetra
.83 .611 0 r
.40074 .41406 .4135 .42663 .43491 .4216 .42225 .40896 Metetra
.838 .588 0 r
.42225 .40896 .43491 .4216 .45651 .41663 .44396 .40392 Metetra
.846 .564 0 r
.44396 .40392 .45651 .41663 .47832 .41172 .46588 .39894 Metetra
.855 .537 0 r
.46588 .39894 .47832 .41172 .50033 .40689 .488 .39404 Metetra
.864 .508 0 r
.488 .39404 .50033 .40689 .52256 .40214 .51034 .38923 Metetra
.874 .477 0 r
.51034 .38923 .52256 .40214 .545 .3975 .5329 .38452 Metetra
.884 .444 0 r
.5329 .38452 .545 .3975 .56768 .39298 .55569 .37994 Metetra
.895 .407 0 r
.55569 .37994 .56768 .39298 .59058 .38859 .57872 .37551 Metetra
.907 .366 0 r
.57872 .37551 .59058 .38859 .61372 .38437 .60199 .37124 Metetra
.919 .322 0 r
.60199 .37124 .61372 .38437 .63712 .38035 .62551 .36718 Metetra
.933 .272 0 r
.62551 .36718 .63712 .38035 .66077 .37654 .64929 .36334 Metetra
.947 .218 0 r
.64929 .36334 .66077 .37654 .68469 .37296 .67335 .35973 Metetra
.961 .161 0 r
.67335 .35973 .68469 .37296 .70888 .36919 .69768 .35591 Metetra
.969 .131 0 r
.69768 .35591 .70888 .36919 .73308 .36166 .72202 .3481 Metetra
.938 .253 0 r
.72202 .3481 .73308 .36166 .75618 .33607 .74527 .32146 Metetra
.802 .687 0 r
.74527 .32146 .75618 .33607 .77598 .27065 .76527 .25428 Metetra
0 .537 .003 r
.09576 .40283 .10965 .41437 .12193 .45973 .10786 .44822 Metetra
.429 .683 0 r
.10786 .44822 .12193 .45973 .13829 .47638 .12419 .46477 Metetra
.646 .74 0 r
.12419 .46477 .13829 .47638 .15691 .47627 .14288 .46455 Metetra
.712 .756 0 r
.14288 .46455 .15691 .47627 .17623 .47168 .16227 .45987 Metetra
.74 .762 0 r
.16227 .45987 .17623 .47168 .19578 .46646 .1819 .45457 Metetra
.764 .768 0 r
.1819 .45457 .19578 .46646 .21549 .46119 .2017 .44921 Metetra
.773 .759 0 r
.2017 .44921 .21549 .46119 .23537 .45591 .22167 .44386 Metetra
.779 .746 0 r
.22167 .44386 .23537 .45591 .25542 .45063 .2418 .4385 Metetra
.785 .731 0 r
.2418 .4385 .25542 .45063 .27564 .44535 .26211 .43314 Metetra
.791 .716 0 r
.26211 .43314 .27564 .44535 .29604 .44009 .2826 .42779 Metetra
.797 .7 0 r
.2826 .42779 .29604 .44009 .31661 .43483 .30327 .42246 Metetra
.804 .683 0 r
.30327 .42246 .31661 .43483 .33737 .4296 .32411 .41715 Metetra
.811 .665 0 r
.32411 .41715 .33737 .4296 .3583 .42439 .34515 .41186 Metetra
.818 .646 0 r
.34515 .41186 .3583 .42439 .37943 .41921 .36637 .40661 Metetra
.825 .626 0 r
.36637 .40661 .37943 .41921 .40074 .41406 .38779 .40139 Metetra
.833 .604 0 r
.38779 .40139 .40074 .41406 .42225 .40896 .4094 .39622 Metetra
.841 .581 0 r
.4094 .39622 .42225 .40896 .44396 .40392 .43122 .3911 Metetra
.849 .555 0 r
.43122 .3911 .44396 .40392 .46588 .39894 .45324 .38606 Metetra
.858 .528 0 r
.45324 .38606 .46588 .39894 .488 .39404 .47548 .38109 Metetra
.867 .499 0 r
.47548 .38109 .488 .39404 .51034 .38923 .49793 .37622 Metetra
.877 .467 0 r
.49793 .37622 .51034 .38923 .5329 .38452 .52061 .37146 Metetra
.888 .432 0 r
.52061 .37146 .5329 .38452 .55569 .37994 .54352 .36682 Metetra
.899 .395 0 r
.54352 .36682 .55569 .37994 .57872 .37551 .56667 .36233 Metetra
.911 .353 0 r
.56667 .36233 .57872 .37551 .60199 .37124 .59006 .35802 Metetra
.923 .307 0 r
.59006 .35802 .60199 .37124 .62551 .36718 .61371 .35392 Metetra
.937 .257 0 r
.61371 .35392 .62551 .36718 .64929 .36334 .63763 .35005 Metetra
.951 .201 0 r
.63763 .35005 .64929 .36334 .67335 .35973 .66183 .34642 Metetra
.966 .142 0 r
.66183 .34642 .67335 .35973 .69768 .35591 .68629 .34254 Metetra
.973 .113 0 r
.68629 .34254 .69768 .35591 .72202 .3481 .71079 .33439 Metetra
.94 .244 0 r
.71079 .33439 .72202 .3481 .74527 .32146 .73418 .30655 Metetra
.8 .693 0 r
.73418 .30655 .74527 .32146 .76527 .25428 .75437 .23742 Metetra
.004 .54 0 r
.08167 .39117 .09576 .40283 .10786 .44822 .09359 .43659 Metetra
.438 .686 0 r
.09359 .43659 .10786 .44822 .12419 .46477 .10989 .45302 Metetra
.655 .742 0 r
.10989 .45302 .12419 .46477 .14288 .46455 .12864 .45269 Metetra
.721 .758 0 r
.12864 .45269 .14288 .46455 .16227 .45987 .14811 .44791 Metetra
.749 .765 0 r
.14811 .44791 .16227 .45987 .1819 .45457 .16782 .44253 Metetra
.77 .767 0 r
.16782 .44253 .1819 .45457 .2017 .44921 .1877 .43708 Metetra
.776 .754 0 r
.1877 .43708 .2017 .44921 .22167 .44386 .20776 .43164 Metetra
.781 .74 0 r
.20776 .43164 .22167 .44386 .2418 .4385 .22798 .42619 Metetra
.787 .726 0 r
.22798 .42619 .2418 .4385 .26211 .43314 .24838 .42075 Metetra
.793 .71 0 r
.24838 .42075 .26211 .43314 .2826 .42779 .26896 .41532 Metetra
.8 .694 0 r
.26896 .41532 .2826 .42779 .30327 .42246 .28972 .4099 Metetra
.806 .677 0 r
.28972 .4099 .30327 .42246 .32411 .41715 .31066 .40451 Metetra
.813 .659 0 r
.31066 .40451 .32411 .41715 .34515 .41186 .33179 .39914 Metetra
.82 .639 0 r
.33179 .39914 .34515 .41186 .36637 .40661 .35312 .39379 Metetra
.828 .618 0 r
.35312 .39379 .36637 .40661 .38779 .40139 .37464 .38849 Metetra
.835 .596 0 r
.37464 .38849 .38779 .40139 .4094 .39622 .39635 .38323 Metetra
.843 .572 0 r
.39635 .38323 .4094 .39622 .43122 .3911 .41828 .37803 Metetra
.852 .547 0 r
.41828 .37803 .43122 .3911 .45324 .38606 .44041 .3729 Metetra
.861 .519 0 r
.44041 .3729 .45324 .38606 .47548 .38109 .46276 .36785 Metetra
.87 .489 0 r
.46276 .36785 .47548 .38109 .49793 .37622 .48532 .36289 Metetra
.88 .457 0 r
.48532 .36289 .49793 .37622 .52061 .37146 .50812 .35804 Metetra
.891 .421 0 r
.50812 .35804 .52061 .37146 .54352 .36682 .53115 .35331 Metetra
.902 .383 0 r
.53115 .35331 .54352 .36682 .56667 .36233 .55442 .34873 Metetra
.914 .341 0 r
.55442 .34873 .56667 .36233 .59006 .35802 .57794 .34433 Metetra
.927 .294 0 r
.57794 .34433 .59006 .35802 .61371 .35392 .60172 .34013 Metetra
.941 .242 0 r
.60172 .34013 .61371 .35392 .63763 .35005 .62576 .33615 Metetra
.955 .185 0 r
.62576 .33615 .63763 .35005 .66183 .34642 .65009 .3324 Metetra
.97 .126 0 r
.65009 .3324 .66183 .34642 .68629 .34254 .67469 .32835 Metetra
.977 .099 0 r
.67469 .32835 .68629 .34254 .71079 .33439 .69932 .31969 Metetra
.941 .24 0 r
.69932 .31969 .71079 .33439 .73418 .30655 .72285 .29046 Metetra
.796 .703 0 r
.72285 .29046 .73418 .30655 .75437 .23742 .74325 .21935 Metetra
.009 .542 0 r
.06743 .37905 .08167 .39117 .09359 .43659 .07916 .42433 Metetra
.444 .687 0 r
.07916 .42433 .09359 .43659 .10989 .45302 .09546 .44055 Metetra
.66 .743 0 r
.09546 .44055 .10989 .45302 .12864 .45269 .11426 .44006 Metetra
.726 .759 0 r
.11426 .44006 .12864 .45269 .14811 .44791 .13381 .43516 Metetra
.753 .766 0 r
.13381 .43516 .14811 .44791 .16782 .44253 .15361 .42964 Metetra
.771 .765 0 r
.15361 .42964 .16782 .44253 .1877 .43708 .17358 .42407 Metetra
.776 .752 0 r
.17358 .42407 .1877 .43708 .20776 .43164 .19372 .4185 Metetra
.782 .738 0 r
.19372 .4185 .20776 .43164 .22798 .42619 .21403 .41291 Metetra
.788 .724 0 r
.21403 .41291 .22798 .42619 .24838 .42075 .23452 .40733 Metetra
.794 .709 0 r
.23452 .40733 .24838 .42075 .26896 .41532 .25519 .40175 Metetra
.8 .693 0 r
.25519 .40175 .26896 .41532 .28972 .4099 .27604 .39617 Metetra
.807 .676 0 r
.27604 .39617 .28972 .4099 .31066 .40451 .29708 .39061 Metetra
.813 .658 0 r
.29708 .39061 .31066 .40451 .33179 .39914 .31831 .38506 Metetra
.82 .638 0 r
.31831 .38506 .33179 .39914 .35312 .39379 .33973 .37953 Metetra
.828 .618 0 r
.33973 .37953 .35312 .39379 .37464 .38849 .36135 .37403 Metetra
.835 .596 0 r
.36135 .37403 .37464 .38849 .39635 .38323 .38317 .36855 Metetra
.843 .573 0 r
.38317 .36855 .39635 .38323 .41828 .37803 .40519 .36312 Metetra
.852 .548 0 r
.40519 .36312 .41828 .37803 .44041 .3729 .42743 .35773 Metetra
.86 .521 0 r
.42743 .35773 .44041 .3729 .46276 .36785 .44988 .3524 Metetra
.869 .492 0 r
.44988 .3524 .46276 .36785 .48532 .36289 .47255 .34713 Metetra
.879 .461 0 r
.47255 .34713 .48532 .36289 .50812 .35804 .49545 .34194 Metetra
.889 .427 0 r
.49545 .34194 .50812 .35804 .53115 .35331 .51858 .33683 Metetra
.9 .39 0 r
.51858 .33683 .53115 .35331 .55442 .34873 .54195 .33182 Metetra
.911 .35 0 r
.54195 .33182 .55442 .34873 .57794 .34433 .56557 .32692 Metetra
.923 .306 0 r
.56557 .32692 .57794 .34433 .60172 .34013 .58944 .32216 Metetra
.936 .258 0 r
.58944 .32216 .60172 .34013 .62576 .33615 .61357 .31753 Metetra
.95 .206 0 r
.61357 .31753 .62576 .33615 .65009 .3324 .63798 .31303 Metetra
.963 .152 0 r
.63798 .31303 .65009 .3324 .67469 .32835 .66264 .30806 Metetra
.968 .133 0 r
.66264 .30806 .67469 .32835 .69932 .31969 .68731 .29817 Metetra
.929 .285 0 r
.68731 .29817 .69932 .31969 .72285 .29046 .71093 .26744 Metetra
.78 .743 0 r
.71093 .26744 .72285 .29046 .74325 .21935 .7316 .19569 Metetra
0 .537 .003 r
.05339 .36396 .06743 .37905 .07916 .42433 .0651 .40792 Metetra
.417 .68 0 r
.0651 .40792 .07916 .42433 .09546 .44055 .08144 .42331 Metetra
.624 .735 0 r
.08144 .42331 .09546 .44055 .11426 .44006 .10031 .42238 Metetra
.686 .75 0 r
.10031 .42238 .11426 .44006 .13381 .43516 .11994 .41715 Metetra
.712 .756 0 r
.11994 .41715 .13381 .43516 .15361 .42964 .13982 .41131 Metetra
.733 .761 0 r
.13982 .41131 .15361 .42964 .17358 .42407 .15986 .40539 Metetra
.754 .766 0 r
.15986 .40539 .17358 .42407 .19372 .4185 .18008 .39944 Metetra
.771 .766 0 r
.18008 .39944 .19372 .4185 .21403 .41291 .20048 .39345 Metetra
.776 .753 0 r
.20048 .39345 .21403 .41291 .23452 .40733 .22105 .38743 Metetra
.781 .74 0 r
.22105 .38743 .23452 .40733 .25519 .40175 .2418 .38137 Metetra
.787 .727 0 r
.2418 .38137 .25519 .40175 .27604 .39617 .26273 .37528 Metetra
.792 .713 0 r
.26273 .37528 .27604 .39617 .29708 .39061 .28385 .36917 Metetra
.798 .698 0 r
.28385 .36917 .29708 .39061 .31831 .38506 .30516 .36301 Metetra
.804 .683 0 r
.30516 .36301 .31831 .38506 .33973 .37953 .32666 .35682 Metetra
.81 .666 0 r
.32666 .35682 .33973 .37953 .36135 .37403 .34835 .3506 Metetra
.816 .649 0 r
.34835 .3506 .36135 .37403 .38317 .36855 .37024 .34434 Metetra
.823 .631 0 r
.37024 .34434 .38317 .36855 .40519 .36312 .39233 .33804 Metetra
.83 .612 0 r
.39233 .33804 .40519 .36312 .42743 .35773 .41463 .3317 Metetra
.837 .593 0 r
.41463 .3317 .42743 .35773 .44988 .3524 .43713 .32531 Metetra
.844 .572 0 r
.43713 .32531 .44988 .3524 .47255 .34713 .45985 .31888 Metetra
.851 .549 0 r
.45985 .31888 .47255 .34713 .49545 .34194 .48277 .31239 Metetra
.859 .526 0 r
.48277 .31239 .49545 .34194 .51858 .33683 .50592 .30585 Metetra
.866 .501 0 r
.50592 .30585 .51858 .33683 .54195 .33182 .52928 .29924 Metetra
.875 .475 0 r
.52928 .29924 .54195 .33182 .56557 .32692 .55287 .29255 Metetra
.883 .448 0 r
.55287 .29255 .56557 .32692 .58944 .32216 .57669 .28578 Metetra
.892 .419 0 r
.57669 .28578 .58944 .32216 .61357 .31753 .60073 .2789 Metetra
.9 .388 0 r
.60073 .2789 .61357 .31753 .63798 .31303 .625 .27185 Metetra
.908 .36 0 r
.625 .27185 .63798 .31303 .66264 .30806 .64948 .26407 Metetra
.907 .365 0 r
.64948 .26407 .66264 .30806 .68731 .29817 .67396 .25152 Metetra
.863 .511 0 r
.67396 .25152 .68731 .29817 .71093 .26744 .69753 .22033 Metetra
.55 .716 0 r
.69753 .22033 .71093 .26744 .7316 .19569 .71865 .15379 Metetra
0 .5 .083 r
.04086 .33771 .05339 .36396 .0651 .40792 .05316 .37584 Metetra
.26 .633 0 r
.05316 .37584 .0651 .40792 .08144 .42331 .06976 .38822 Metetra
.428 .683 0 r
.06976 .38822 .08144 .42331 .10031 .42238 .08872 .38603 Metetra
.476 .696 0 r
.08872 .38603 .10031 .42238 .11994 .41715 .10838 .37997 Metetra
.492 .7 0 r
.10838 .37997 .11994 .41715 .13982 .41131 .12828 .37331 Metetra
.504 .704 0 r
.12828 .37331 .13982 .41131 .15986 .40539 .14835 .36652 Metetra
.516 .707 0 r
.14835 .36652 .15986 .40539 .18008 .39944 .1686 .35963 Metetra
.527 .71 0 r
.1686 .35963 .18008 .39944 .20048 .39345 .18901 .35263 Metetra
.539 .713 0 r
.18901 .35263 .20048 .39345 .22105 .38743 .2096 .34553 Metetra
.55 .716 0 r
.2096 .34553 .22105 .38743 .2418 .38137 .23036 .33832 Metetra
.562 .719 0 r
.23036 .33832 .2418 .38137 .26273 .37528 .2513 .33099 Metetra
.573 .722 0 r
.2513 .33099 .26273 .37528 .28385 .36917 .27241 .32355 Metetra
.583 .724 0 r
.27241 .32355 .28385 .36917 .30516 .36301 .2937 .31597 Metetra
.594 .727 0 r
.2937 .31597 .30516 .36301 .32666 .35682 .31518 .30825 Metetra
.604 .73 0 r
.31518 .30825 .32666 .35682 .34835 .3506 .33683 .30038 Metetra
.614 .732 0 r
.33683 .30038 .34835 .3506 .37024 .34434 .35867 .29235 Metetra
.623 .734 0 r
.35867 .29235 .37024 .34434 .39233 .33804 .38069 .28416 Metetra
.631 .736 0 r
.38069 .28416 .39233 .33804 .41463 .3317 .4029 .27579 Metetra
.639 .738 0 r
.4029 .27579 .41463 .3317 .43713 .32531 .42528 .26722 Metetra
.646 .74 0 r
.42528 .26722 .43713 .32531 .45985 .31888 .44785 .25845 Metetra
.652 .741 0 r
.44785 .25845 .45985 .31888 .48277 .31239 .47061 .24945 Metetra
.656 .742 0 r
.47061 .24945 .48277 .31239 .50592 .30585 .49354 .24021 Metetra
.66 .743 0 r
.49354 .24021 .50592 .30585 .52928 .29924 .51666 .23071 Metetra
.661 .744 0 r
.51666 .23071 .52928 .29924 .55287 .29255 .53995 .22091 Metetra
.661 .744 0 r
.53995 .22091 .55287 .29255 .57669 .28578 .56342 .21081 Metetra
.659 .743 0 r
.56342 .21081 .57669 .28578 .60073 .2789 .58705 .20036 Metetra
.654 .742 0 r
.58705 .20036 .60073 .2789 .625 .27185 .61086 .18952 Metetra
.643 .739 0 r
.61086 .18952 .625 .27185 .64948 .26407 .6348 .17787 Metetra
.597 .728 0 r
.6348 .17787 .64948 .26407 .67396 .25152 .65875 .1627 Metetra
.421 .681 0 r
.65875 .1627 .67396 .25152 .69753 .22033 .68214 .13493 Metetra
.033 .552 0 r
.68214 .13493 .69753 .22033 .71865 .15379 .704 .08401 Metetra
0 .391 .25 r
.03138 .29164 .04086 .33771 .05316 .37584 .04536 .31639 Metetra
0 .498 .087 r
.04536 .31639 .05316 .37584 .06976 .38822 .06259 .32243 Metetra
0 .537 .002 r
.06259 .32243 .06976 .38822 .08872 .38603 .0816 .31801 Metetra
.018 .546 0 r
.0816 .31801 .08872 .38603 .10838 .37997 .10116 .31076 Metetra
.021 .547 0 r
.10116 .31076 .10838 .37997 .12828 .37331 .12094 .30301 Metetra
.022 .548 0 r
.12094 .30301 .12828 .37331 .14835 .36652 .14088 .29508 Metetra
.021 .547 0 r
.14088 .29508 .14835 .36652 .1686 .35963 .16098 .28701 Metetra
.021 .547 0 r
.16098 .28701 .1686 .35963 .18901 .35263 .18124 .27877 Metetra
.019 .546 0 r
.18124 .27877 .18901 .35263 .2096 .34553 .20167 .27037 Metetra
.017 .546 0 r
.20167 .27037 .2096 .34553 .23036 .33832 .22226 .26181 Metetra
.014 .544 0 r
.22226 .26181 .23036 .33832 .2513 .33099 .24301 .25307 Metetra
.01 .543 0 r
.24301 .25307 .2513 .33099 .27241 .32355 .26392 .24415 Metetra
.005 .541 0 r
.26392 .24415 .27241 .32355 .2937 .31597 .28499 .23505 Metetra
0 .538 0 r
.28499 .23505 .2937 .31597 .31518 .30825 .30623 .22575 Metetra
0 .536 .006 r
.30623 .22575 .31518 .30825 .33683 .30038 .32763 .21626 Metetra
0 .533 .013 r
.32763 .21626 .33683 .30038 .35867 .29235 .34919 .20656 Metetra
0 .529 .022 r
.34919 .20656 .35867 .29235 .38069 .28416 .37091 .19664 Metetra
0 .525 .031 r
.37091 .19664 .38069 .28416 .4029 .27579 .39278 .1865 Metetra
0 .52 .041 r
.39278 .1865 .4029 .27579 .42528 .26722 .41482 .17613 Metetra
0 .515 .052 r
.41482 .17613 .42528 .26722 .44785 .25845 .437 .16552 Metetra
0 .51 .064 r
.437 .16552 .44785 .25845 .47061 .24945 .45935 .15467 Metetra
0 .503 .077 r
.45935 .15467 .47061 .24945 .49354 .24021 .48184 .14355 Metetra
0 .496 .091 r
.48184 .14355 .49354 .24021 .51666 .23071 .50448 .13218 Metetra
0 .488 .106 r
.50448 .13218 .51666 .23071 .53995 .22091 .52727 .12053 Metetra
0 .48 .122 r
.52727 .12053 .53995 .22091 .56342 .21081 .5502 .10861 Metetra
0 .47 .139 r
.5502 .10861 .56342 .21081 .58705 .20036 .57326 .09639 Metetra
0 .46 .157 r
.57326 .09639 .58705 .20036 .61086 .18952 .59646 .08388 Metetra
0 .448 .176 r
.59646 .08388 .61086 .18952 .6348 .17787 .61979 .07088 Metetra
0 .43 .202 r
.61979 .07088 .6348 .17787 .65875 .1627 .64318 .05621 Metetra
0 .39 .251 r
.64318 .05621 .65875 .1627 .68214 .13493 .6664 .03589 Metetra
0 .294 .302 r
.6664 .03589 .68214 .13493 .704 .08401 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15379 .20947 m
.1584 .21414 L
s
[(-5)] .14456 .20014 .98831 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54685 .05556 m
.55074 .06084 L
s
[(5)] .53907 .04499 .73616 1 Mshowa
.125 Mabswid
.19056 .19507 m
.19329 .19791 L
s
.22786 .18047 m
.23055 .18334 L
s
.2657 .16565 m
.26835 .16856 L
s
.3041 .15061 m
.30671 .15356 L
s
.38261 .11987 m
.38514 .12289 L
s
.42275 .10415 m
.42523 .10721 L
s
.46349 .0882 m
.46592 .09129 L
s
.50485 .072 m
.50724 .07514 L
s
.11754 .22366 m
.12034 .22643 L
s
.08179 .23766 m
.08463 .24039 L
s
.04655 .25146 m
.04942 .25416 L
s
.5895 .03886 m
.59178 .04207 L
s
.6328 .0219 m
.63503 .02515 L
s
.67679 .00468 m
.67896 .00796 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00boooool2o`0005?ooooo0038ooooo`?o000000?oooooo`000?ooool0
D_ooool00<Kooooo0_l000001?oooooo0000ooooooooool2o`0005;ooooo0033ooooo`?o00001_oo
ool00ol0003oooooo`00001Aooooo`00X?ooool3o`0001gooooo0ol00008ooooo`Co0000DOooool0
09oooooo00Go0000ooooooooooooooooo`00000Jooooo`;o00002_ooool00ol0003o04]=o`000002
ooooo`03o`000?oooooooooo04kooooo002Sooooo`03o`000?oooooooooo01Gooooo0ol0000;oooo
o`03o`000?l0Bdgo04]=00;o00000_ooool00ol0003oooooooooo`1=ooooo`00Xoooool00ol0003o
ooooooooo`0Cooooo`;o00000_ooool00ol0003oooooooooo`09ooooo`03o`000?l0Bdgo04]=00;o
00000_ooool00ol0003oooooooooo`1=ooooo`00Woooool4o`0001?ooooo0ol0000?ooooo`04o`00
0?l0Bdgo04]=o`1;C@;o00000oooool00ol0003oooooooooo`1<ooooo`00Woooool00ol0003ooooo
ooooo`0Booooo`;o00004Oooool00ol0003o04]=o`1;C@03o`1;C@03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Boooool009oooooo1Ol0000=ooooo`?o00004Oooool2o`0000Ko04]=00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1;ooooo`00[oooool4o`00017ooooo00?o0000
o`1S@?l000001_l0Bdd2o`0000Cooooo00?o0000ooooooooool0B_ooool00:cooooo0ol0000Doooo
o`04o`000?l0Hd3o06=0o`0000Ko04]=0_l00003ooooo`;o0000C?ooool00:Wooooo0ol0000Foooo
o`05o`000?l0Hd3o06=0o`1S@?l000001_l0Bdd2o`0000Gooooo00?o0000ooooooooool0BOooool0
0:Oooooo0_l0000Hooooo`03o`000?l0Hd3o06=000?o06=000?o0000o`1;COl0Bdd00ol0Bdd2o`00
00Kooooo00?o0000ooooooooool0B?ooool00:Cooooo0ol0000Hooooo`;o00001_l0Hd000ol0003o
04]=o`1;C@03o`1;C@;o00001_ooool00ol0003oooooooooo`18ooooo`00X_ooool2o`0000?ooooo
00?o0000ooooooooool04oooool2o`000003o`1^<ol0003o06=000Go06=000?o0000o`1;COl0Bdd0
0ol0Bdd00ol0003o04]=o`000006ooooo`03o`000?oooooooooo04Oooooo002Oooooo`?o00006_oo
ool01Ol0003o06hco`1^<ol0KS?o000000Ko06=000?o0000o`1;COl0Bdd00ol0Bdd00ol0003o04]=
o`000007ooooo`03o`000?oooooooooo04Kooooo002Mooooo`;o00006oooool2o`0000Co06hc00?o
0000o`1S@?l0Hd001?l0Hd000ol0003o04]=o`1;C@03o`1;C@03o`000?l0Bdgo000000Oooooo00?o
0000ooooooooool0A_ooool009[ooooo0ol0000Kooooo`;o00001ol0KS<00ol0003o06=0o`1S@003
o`1S@003o`000?l0Bdgo04]=00?o04]=00?o0000o`1;COl000002?ooool00ol0003oooooooooo`15
ooooo`00V?ooool2o`000003ooooool0003ooooo01[ooooo00?o0000o`1b;Ol000001ol0KS<00ol0
003o06=0o`1S@003o`1S@003o`000?l0Bdgo04]=00?o04]=00?o0000o`1;COl000001oooool3o`00
04Kooooo002Eooooo`?o00007Oooool2o`0000;o078]00?o0000o`1^<ol0KS<01Ol0KS<00ol0003o
06=0o`1S@004o`1S@003o`000?l0Bdgo04]=00;o04]=00Co0000o`1;COl0Bdgo00002?ooool00ol0
003oooooooooo`14ooooo`00T_ooool3o`0001oooooo00?o0000o`1b;Ol0LRd00_l0LRd00ol0003o
06hco`1^<`05o`1^<`03o`000?l0Hd3o06=000Co06=000?o0000o`1;COl0Bdd00_l0Bdd01?l0003o
04]=o`1;COl00009ooooo`03o`000?oooooooooo00_ooooo0ol0000eooooo`00T?ooool2o`00023o
oooo0_l00005o`1b;@03o`000?l0KS?o06hc00Go06hc00?o0000o`1S@?l0Hd001?l0Hd000ol0003o
04]=o`1;C@02o`1;C@04o`000?l0Bdgo04]=o`0000[ooooo00?o0000ooooooooool02Oooool01Ol0
003ooooooooooooooooo000003Cooooo002=ooooo`Co00007oooool2o`000003o`1e:?l0003o078]
00Go078]00?o0000o`1^<ol0KS<01?l0KS<00ol0003o06=0o`1S@004o`1S@003o`000?l0Bdgo04]=
00;o04]=00Co0000o`1;COl0Bdgo00002_ooool00ol0003oooooooooo`03ooooo`Go00001Oooool0
0ol0003oooooooooo`0booooo`00Roooool2o`00027ooooo0_l00003o`1e:003o`000?l0LRgo078]
00Co078]00?o0000o`1^<ol0KS<01?l0KS<00ol0003o06=0o`1S@004o`1S@003o`000?l0Bdgo04]=
00?o04]=0ol0000;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<_ooool006[o
oooo0_l0000Looooo`?o00008Oooool2o`0000Go07DX00?o0000o`1b;Ol0LRd01?l0LRd00ol0003o
06hco`1^<`05o`1^<`03o`000?l0Hd3o06=000?o06=000?o0000o`1;COl0Bdd00ol0Bdd2o`000003
o`R=0?l0003ooooo00[ooooo00?o0000ooooooooool01oooool4o`0003Gooooo001Yooooo`04o`00
0?ooooooooooo`0001Wooooo0_l0000Rooooo`;o000000?o07PSo`000?l0MBP01Ol0MBP00ol0003o
078]o`1b;@03o`1b;@03o`000?l0KS?o06hc00Go06hc00?o0000o`1S@?l0Hd001?l0Hd000ol0003o
04]=o`1;C@02o`1;C@04o`000?l8S@3o28d0o`0000_ooooo0_l00008ooooo`03o`000?oooooooooo
03Kooooo001Yooooo`04o`000?ooooooooooo`0001Kooooo0ol0000Rooooo`;o00000ol0N2<00ol0
003o07DXo`1e:004o`1e:003o`000?l0LRgo078]00?o078]00?o0000o`1^<ol0KS<01Ol0KS<00ol0
003o06=0o`1S@004o`1S@003o`000?l0Bdgo04]=00;o04]=00Co0000o`R=0?l8S@3o00002_ooool0
0ol0003oooooo`000008ooooo`Go0000=?ooool006Wooooo00Co0000oooooooooooo00005?ooool2
o`0000?ooooo00?o0000ooooooooool07Oooool2o`0000Go07PS00?o0000o`1e:?l0MBP01?l0MBP0
0ol0003o078]o`1b;@03o`1b;@03o`000?l0KS?o06hc00Go06hc00?o0000o`1S@?l0Hd001?l0Hd00
1?l0003o04]=o`1;COl0Bdd2o`0000;o28d000?o0000ooooooooool02oooool00ol0003ooooooooo
o`0nooooo`00JOooool01?l0003oooooooooool0000Aooooo`?o00008oooool2o`000003o`1j7ol0
003o07PS00Go07PS00?o0000o`1e:?l0MBP00ol0MBP00ol0003o078]o`1b;@03o`1b;@03o`000?l0
KS?o06hc00Go06hc00?o0000o`1S@?l0Hd001?l0Hd001?l0003o04]=o`1;COl0Bdd2o`0000;o28d0
00?o0000ooooooooool02oooool00ol0003oooooooooo`0nooooo`00JOooool01?l0003ooooooooo
ool0000>ooooo`?o00009?ooool2o`0000?o07XO00?o0000o`1h8ol0N2<01?l0N2<00ol0003o07DX
o`1e:003o`1e:003o`000?l0LRgo078]00Co078]00?o0000o`1^<ol0KS<01?l0KS<00ol0003o06=0
o`1S@004o`1S@004o`000?l0Bdgo04]=o`1;C@;o00000ol8S@000ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo03gooooo001Zooooo`;o00003Oooool2o`0002Gooooo0_l00005o`1j7`03o`00
0?l0N2?o07PS00Co07PS00?o0000o`1e:?l0MBP00ol0MBP00ol0003o078]o`1b;@04o`1b;@03o`00
0?l0KS?o06hc00Co06hc00?o0000o`1S@?l0Hd001?l0Hd001_l0003o04]=o`1;COl0003o28d0o`00
00?o28d000?o0000ooooooooool02oooool00ol0003oooooooooo`0mooooo`00M_ooool3o`0000;o
oooo00?o0000ooooooooool08?ooool2o`000003o`1l6ol0003o07XO00Co07XO00?o0000o`1h8ol0
N2<01?l0N2<00ol0003o07DXo`1e:003o`1e:003o`000?l0LRgo078]00Co078]00?o0000o`1^<ol0
KS<01Ol0KS<00ol0003o06=0o`1S@003o`1S@006o`000?l0Bdgo04]=o`000?l8S@3o00000ol8S@00
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03cooooo001dooooo`;o00009_ooool2o`00
00?o07`K00?o0000o`1j7ol0NQl01?l0NQl00ol0003o07PSo`1h8`03o`1h8`03o`000?l0MBSo07DX
00Co07DX00?o0000o`1b;Ol0LRd00ol0LRd00ol0003o06hco`1^<`05o`1^<`03o`000?l0Hd3o06=0
00Co06=00_l00002o`R=0005o`000?l8S@3o28d0o`R=0?l000003oooool00ol0003oooooooooo`0k
ooooo`00LOooool3o`0002Kooooo0_l00005o`1l6`03o`000?l0NQoo07XO00Co07XO00?o0000o`1h
8ol0N2<00ol0N2<00ol0003o07DXo`1e:004o`1e:003o`000?l0LRgo078]00?o078]00?o0000o`1^
<ol0KS<01Ol0KS<00ol0003o06=0o`1S@004o`1S@0;o00000_l8S@000ol0003o28d0o`R=0002o`R=
0003o`000?oooooooooo00_ooooo0_l0000mooooo`00Koooool2o`0002Oooooo0_l000000ol0OQOo
0000o`1l6`04o`1l6`03o`000?l0NQoo07XO00Co07XO00?o0000o`1h8ol0N2<00ol0N2<00ol0003o
07DXo`1e:004o`1e:003o`000?l0LRgo078]00?o078]00?o0000o`1^<ol0KS<01Ol0KS<00ol0003o
06=0o`1S@004o`1S@005o`000?l8S@3o28d0o`R=0?l000001?l8S@000ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo03[ooooo001/ooooo`?o000000?oooooo`000?ooool09?ooool2o`0000?o
07hG00?o0000o`1l6ol0O1/01?l0O1/00ol0003o07XOo`1j7`03o`1j7`03o`000?l0N2?o07PS00Co
07PS00?o0000o`1e:?l0MBP00ol0MBP00ol0003o078]o`1b;@03o`1b;@03o`000?l0KS?o06hc00Go
06hc00?o0000o`1S@?l0Hd001?l0Hd001Ol0003o28d0o`R=0?l8S@3o000000Co28d000?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0iooooo`00JOooool3o`0000Gooooo00?o0000oooooooo
ool08?ooool2o`0000Go07hG00?o0000o`1l6ol0O1/01?l0O1/00ol0003o07XOo`1j7`03o`1j7`03
o`000?l0N2?o07PS00Co07PS00?o0000o`1e:?l0MBP00ol0MBP00ol0003o078]o`1b;@04o`1b;@03
o`000?l0KS?o06hc00Co06hc00?o0000o`1S@?l0Hd000ol0Hd02o`0000?o28d000?o0000o`R=0?l8
S@000_l8S@000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Wooooo001Wooooo`;o0000
:Oooool2o`000003o`204ol0003o07hG00Co07hG00?o0000o`1l6ol0O1/01?l0O1/00ol0003o07XO
o`1j7`03o`1j7`03o`000?l0N2?o07PS00Co07PS00?o0000o`1e:?l0MBP00ol0MBP00ol0003o078]
o`1b;@04o`1b;@03o`000?l0KS?o06hc00Co06hc00?o0000o`1S@?l0Hd000_l0Hd000ol0003oJjh0
o`000003o`R=0003o`000?l8S@3o28d000;o28d000?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0hooooo`00I?ooool3o`0002Wooooo0_l00003o`204`03o`000?l0OQOo07hG00Co07hG00?o
0000o`1l6ol0O1/00ol0O1/00ol0003o07XOo`1j7`03o`1j7`03o`000?l0N2?o07PS00Co07PS00?o
0000o`1e:?l0MBP00ol0MBP00ol0003o078]o`1b;@04o`1b;@03o`000?l0KS?o06hc00Go06hc00Co
0000o`1S@?l0Hd3o00000om[[P001?l0003o28d0o`R=0?l00005o`R=0003o`000?oooooooooo00oo
oooo00?o0000ooooooooool0=oooool006;ooooo0_l00002ooooo`03o`000?oooooooooo02Gooooo
0_l00005o`204`03o`000?l0OQOo07hG00Co07hG00?o0000o`1l6ol0O1/00ol0O1/00ol0003o07XO
o`1j7`03o`1j7`03o`000?l0N2?o07PS00Co07PS00?o0000o`1e:?l0MBP01?l0MBP00ol0003o078]
o`1b;@03o`1b;@03o`000?l0KS?o06hc00Go06hc00?o0000o`1S@?l000001?m[[P001?l0003o28d0
o`R=0?l00005o`R=0003o`000?oooooooooo00oooooo00?o0000ooooooooool0=oooool005oooooo
0ol0000Zooooo`;o000000?o088@o`000?l0P1<01?l0P1<00ol0003o07hGo`1n5`04o`1n5`03o`00
0?l0O1_o07`K00?o07`K00?o0000o`1j7ol0NQl00ol0NQl00ol0003o07PSo`1h8`04o`1h8`03o`00
0?l0MBSo07DX00Co07DX00?o0000o`1b;Ol0LRd00ol0LRd00ol0003o06hco`1^<`05o`1^<`;o0000
1Om[[P001Ol0003o28d0o`R=0?l8S@3o000000Co28d000?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0fooooo`00GOooool2o`0002_ooooo0_l00003o`224003o`000?l0P1?o080C00Co080C
00?o0000o`1n5ol0OQL00ol0OQL00ol0003o07`Ko`1l6`03o`1l6`03o`000?l0NQoo07XO00Co07XO
00?o0000o`1h8ol0N2<00ol0N2<00ol0003o07DXo`1e:004o`1e:003o`000?l0LRgo078]00?o078]
00?o0000o`1^<ol0KS<01?l0KS<2o`0000KoJjh000Go0000o`R=0?l8S@3o28d0o`000003o`R=00;o
00004Oooool00ol0003oooooo`00000gooooo`00F_ooool3o`0002_ooooo0_l00005o`224003o`00
0?l0P1?o080C00Co080C00?o0000o`1n5ol0OQL00ol0OQL00ol0003o07`Ko`1l6`03o`1l6`03o`00
0?l0NQoo07XO00Co07XO00?o0000o`1h8ol0N2<01?l0N2<00ol0003o07DXo`1e:003o`1e:003o`00
0?l0LRgo078]00?o078]00?o0000o`1^<ol0KS<00ol0KS<00ol0003oV;X0o`000006of^^0005o`00
0?l8S@3o28d0o`R=0?l000000ol8S@000ol0003oS;L0o`00000Booooo`03o`000?oooooooooo03Go
oooo000fooooo`?o00007oooool2o`0000;ooooo00?o0000ooooooooool09oooool2o`000003o`23
3Ol0003o088@00Co088@00?o0000o`204ol0P1<01?l0P1<00ol0003o07hGo`1n5`03o`1n5`03o`00
0?l0O1_o07`K00?o07`K00?o0000o`1j7ol0NQl01?l0NQl00ol0003o07PSo`1h8`04o`1h8`03o`00
0?l0MBSo07DX00?o07DX00?o0000o`1b;Ol0LRd01?l0LRd00ol0003o06hco`1^<`02o`0000;oV;X0
00?o0000of^^0?m[[P001?m[[P001Ol0003o28d0o`R=0?l8S@3o000000?o28d000?o0000ohbg0?l0
00004oooool00ol0003oooooooooo`0dooooo`00=Oooool01Ol0003ooooooooooooooooo000001_o
oooo0ol0000/ooooo`;o00000ol0P`d00ol0003o088@o`224004o`224003o`000?l0P1?o080C00?o
080C00?o0000o`1n5ol0OQL00ol0OQL00ol0003o07`Ko`1l6`04o`1l6`03o`000?l0NQoo07XO00?o
07XO00?o0000o`1h8ol0N2<01?l0N2<00ol0003o07DXo`1e:003o`1e:003o`000?l0LRgo078]00Co
078]00?o0000o`1^<ol000001?nH^P000ol0003oJjh0of^^0005of^^0004o`000?l8S@3o28d0o`00
00;o28d000Co0000ohbg0?n<]`3o00005?ooool00ol0003oooooooooo`0cooooo`00;oooool5o`00
00Gooooo00?o0000ooooooooool05_ooool3o`0002gooooo0_l00005o`233@03o`000?l0PQ3o088@
00Co088@00?o0000o`204ol0P1<00ol0P1<00ol0003o07hGo`1n5`03o`1n5`03o`000?l0O1_o07`K
00Co07`K00?o0000o`1j7ol0NQl00ol0NQl00ol0003o07PSo`1h8`04o`1h8`03o`000?l0MBSo07DX
00?o07DX00?o0000o`1b;Ol0LRd01?l0LRd2o`0000KoV;X000?o0000of^^0?m[[P001?m[[P001?l0
003o28d0o`R=0?l00002o`R=0005o`000?n<]`3oS;L0ohbg0?l000004oooool00ol0003ooooooooo
o`0cooooo`00>Oooool00ol0003oooooooooo`0Dooooo`;o0000;_ooool2o`000003o`252_l0003o
08<=00Co08<=00?o0000o`224?l0PQ001?l0PQ000ol0003o080Co`204`03o`204`03o`000?l0OQOo
07hG00?o07hG00?o0000o`1l6ol0O1/01?l0O1/00ol0003o07XOo`1j7`03o`1j7`03o`000?l0N2?o
07PS00Co07PS00?o0000o`1e:?l0MBP01?l0MBP00ol0003o078]o`1b;@02o`1b;@;o00001onH^P00
0ol0003oJjh0of^^0004of^^0004o`000?l8S@3o28d0o`0000;o28d000Go0000ohbg0?n<]`3oS;L0
o`00000Dooooo`03o`000?oooooooooo03;ooooo000eooooo`Co00005?ooool3o`0000;ooooo00?o
0000ooooooooool0:Oooool2o`0000?o08D:00?o0000o`233Ol0P`d01?l0P`d00ol0003o088@o`22
4003o`224003o`000?l0P1?o080C00?o080C00?o0000o`1n5ol0OQL01?l0OQL00ol0003o07`Ko`1l
6`03o`1l6`03o`000?l0NQoo07XO00?o07XO00?o0000o`1h8ol0N2<01?l0N2<00ol0003o07DXo`1e
:004o`1e:003o`000?l0LRgo078]00;o000000?oY;d0o`000?nH^P001_nH^P000ol0003oJjh0of^^
0004of^^0006o`000?l8S@3o28d0o`000?l8S@3o00001?n<]`000ol0003oooooooooo`0Booooo`03
o`000?oooooooooo03;ooooo000eooooo`03o`000?oooooooooo01?ooooo0_l0000_ooooo`;o0000
1Ol0Q@X00ol0003o08<=o`233@04o`233@03o`000?l0PQ3o088@00?o088@00?o0000o`204ol0P1<0
0ol0P1<00ol0003o07hGo`1n5`04o`1n5`03o`000?l0O1_o07`K00?o07`K00?o0000o`1j7ol0NQl0
0ol0NQl00ol0003o07PSo`1h8`04o`1h8`03o`000?l0MBSo07DX00Co07DX0ol00003ojBm0003o`00
0?nH^P3oV;X000GoV;X000?o0000of^^0?m[[P001?m[[P001_l0003o28d0o`R=0?l0003o28d0o`00
00CoS;L000?o0000ooooooooool04_ooool2o`0003?ooooo000eooooo`Go00003_ooool3o`0002ko
oooo0ol000000ol0QPOo0000o`252P04o`252P03o`000?l0P`go08<=00Co08<=00?o0000o`224?l0
PQ000ol0PQ000ol0003o080Co`204`03o`204`03o`000?l0OQOo07hG00Co07hG00?o0000o`1l6ol0
O1/00ol0O1/00ol0003o07XOo`1j7`03o`1j7`03o`000?l0N2?o07PS00Go07PS00?o0000o`1e:?l0
MBP00_l0MBP2o`0000GoY;d000?o0000oiRj0?nH^P001OnH^P000ol0003oJjh0of^^0005of^^0005
o`000?l8S@3o0000o`R=0?l000001On<]`000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
033ooooo0016ooooo`;o0000;_ooool3o`0000Co08H700?o0000o`252_l0Q@X01?l0Q@X00ol0003o
08<=o`233@03o`233@03o`000?l0PQ3o088@00?o088@00?o0000o`204ol0P1<01?l0P1<00ol0003o
07hGo`1n5`03o`1n5`03o`000?l0O1_o07`K00?o07`K00?o0000o`1j7ol0NQl01?l0NQl00ol0003o
07PSo`1h8`04o`1h8`03o`000?l0MBSo000000;o000000?oYkd0o`000?nT_@001OnT_@000ol0003o
V;X0oiRj0004oiRj0003o`000?m[[P3oJjh000GoJjh000Co0000o`R=0?l0003o00001_n<]`000ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo0013ooooo`?o00000_ooool00ol0003o
ooooooooo`0Yooooo`;o000000?o08L5o`000?l0QPL01?l0QPL00ol0003o08D:o`252P04o`252P03
o`000?l0P`go08<=00?o08<=00?o0000o`224?l0PQ000ol0PQ000ol0003o080Co`204`04o`204`03
o`000?l0OQOo07hG00?o07hG00?o0000o`1l6ol0O1/00ol0O1/00ol0003o07XOo`1j7`04o`1j7`03
o`000?l0N2?o07PS00?o07PS0ol00004ojNm0003o`000?nT_@3oY;d000CoY;d000?o0000oiRj0?nH
^P001OnH^P000ol0003oJjh0of^^0004of^^0004o`000?l8S@3o0000o`0000KoS;L000?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0_ooooo`00@Oooool2o`0002oooooo0_l00003o`271@03
o`000?l0QPOo08H700?o08H700?o0000o`252_l0Q@X01?l0Q@X00ol0003o08<=o`233@03o`233@03
o`000?l0PQ3o088@00?o088@00?o0000o`204ol0P1<01?l0P1<00ol0003o07hGo`1n5`03o`1n5`03
o`000?l0O1_o07`K00?o07`K00?o0000o`1j7ol0NQl01?l0NQl00ol0003o07PSo`1h8`03o`000003
ojRn0?l0003oYkd000CoYkd000?o0000ojBm0?nT_@001?nT_@000ol0003oV;X0oiRj0005oiRj0003
o`000?m[[P3oJjh000CoJjh000Co0000o`R=0?l0003o00001_n<]`02o`0001Kooooo00?o0000oooo
ooooool0;_ooool003kooooo0ol0000_ooooo`;o00001Ol0Q`D00ol0003o08H7o`261`04o`261`03
o`000?l0Q@[o08D:00?o08D:00?o0000o`233Ol0P`d00ol0P`d00ol0003o088@o`224004o`224003
o`000?l0P1?o080C00?o080C00?o0000o`1n5ol0OQL00ol0OQL00ol0003o07`Ko`1l6`04o`1l6`03
o`000?l0NQoo07XO00?o07XO0ol00004ojRn0003o`000?nW_@3oYkd000CoYkd000?o0000ojBm0?nT
_@000onT_@000ol0003oV;X0oiRj0005oiRj0003o`000?m[[P3oJjh000CoJjh000?o0000o`R=0?l0
00001_n<]`000ol0003oakh0o`00000Fooooo`03o`000?oooooooooo02kooooo000kooooo`Co0000
;oooool2o`000003o`280ol0003o08L500Co08L500?o0000o`261ol0QPL01?l0QPL00ol0003o08D:
o`252P03o`252P03o`000?l0P`go08<=00?o08<=00?o0000o`224?l0PQ001?l0PQ000ol0003o080C
o`204`03o`204`03o`000?l0OQOo07hG00?o07hG00?o0000o`1l6ol0O1/01?l0O1/00ol0003o07XO
o`1j7`02o`1j7`;o00001_nX_P000ol0003oYkd0ojNm0004ojNm0003o`000?nT_@3oY;d000?oY;d0
00?o0000oiRj0?nH^P001OnH^P000ol0003oJjh0of^^0004of^^0003o`000?l8S@3o000000KoS;L0
00Co0000olNn0?o7_P3o00005_ooool00ol0003oooooooooo`0]ooooo`00>Oooool2o`0000Cooooo
00?o0000ooooooooool0:oooool01Ol0003o08P3o`280ol0R0?o000000Ko08L500?o0000o`261ol0
QPL00ol0QPL00ol0003o08D:o`252P03o`252P03o`000?l0P`go08<=00Co08<=00?o0000o`224?l0
PQ000ol0PQ000ol0003o080Co`204`03o`204`03o`000?l0OQOo07hG00?o07hG00?o0000o`1l6ol0
O1/01?l0O1/00ol0003o07XOo`1j7`02o`000003ojVn0?l0003oZ;h000KoZ;h000?o0000ojNm0?nW
_@000onW_@000ol0003oY;d0ojBm0004ojBm0003o`000?nH^P3oV;X000CoV;X000?o0000of^^0?m[
[P001Om[[P02o`0000KoS;L000Co0000olNn0?o7_P3o00005_ooool2o`0002kooooo000fooooo`?o
0000<_ooool2o`0000Co08P300?o0000o`271Ol0Q`D01?l0Q`D00ol0003o08H7o`261`03o`261`03
o`000?l0Q@[o08D:00?o08D:00?o0000o`233Ol0P`d01?l0P`d00ol0003o088@o`224003o`224003
o`000?l0P1?o080C00?o080C00?o0000o`1n5ol0OQL01?l0OQL00ol0003o07`Ko`1l6`03o`1l6`?o
00000onY_P000ol0003oZ;h0ojRn0005ojRn0003o`000?nW_@3oYkd000?oYkd000?o0000ojBm0?nT
_@001?nT_@000ol0003oV;X0oiRj0004oiRj0003o`000?m[[P3oJjh000GoJjh000?o0000ohbg0?l0
00001On<]`001?l0003oakh0olNn0?l0000Gooooo`03o`000?oooooooooo00Kooooo0_l0000Toooo
o`00=?ooool2o`0003;ooooo0ol000000ol0R@7o0000o`280`03o`280`03o`000?l0Q`Go08L500Co
08L500?o0000o`261ol0QPL00ol0QPL00ol0003o08D:o`252P03o`252P03o`000?l0P`go08<=00Co
08<=00?o0000o`224?l0PQ000ol0PQ000ol0003o080Co`204`03o`204`03o`000?l0OQOo07hG00Co
07hG00?o0000o`1l6ol0O1/00_l0O1/2o`0000KoZKh000?o0000ojRn0?nX_P001?nX_P000ol0003o
Ykd0ojNm0003ojNm0003o`000?nT_@3oY;d000CoY;d000?o0000oiRj0?nH^P001OnH^P000ol0003o
Jjh0of^^0004of^^0003o`000?n<]`3o000000CoS;L000?o0000olNn0?o7_P000_o7_P000ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00008oooool0037o
oooo1Ol0000_ooooo`?o00001?l0R@400ol0003o08P3o`280`03o`280`03o`000?l0Q`Go08L500?o
08L500?o0000o`261ol0QPL00ol0QPL00ol0003o08D:o`252P04o`252P03o`000?l0P`go08<=00?o
08<=00?o0000o`224?l0PQ000ol0PQ000ol0003o080Co`204`03o`204`03o`000?l0OQOo07hG00Co
07hG00?o0000o`1l6ol0O1/00_l000000onY_P3o0000ojVn0005ojVn0003o`000?nX_P3oZ;h000Co
Z;h000?o0000ojNm0?nW_@001?nW_@000ol0003oY;d0ojBm0003ojBm0003o`000?nH^P3oV;X000Go
V;X000?o0000of^^0?m[[P001?m[[P000ol0003oS;L0o`000004ohbg0003o`000?o7_P3oakh000;o
akh000?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
02?ooooo000_ooooo`;o0000<_ooool2o`000003o`290?l0003o08T100Co08T100?o0000o`280ol0
R0<00ol0R0<00ol0003o08L5o`271@03o`271@03o`000?l0QPOo08H700?o08H700?o0000o`252_l0
Q@X01?l0Q@X00ol0003o08<=o`233@03o`233@03o`000?l0PQ3o088@00?o088@00?o0000o`204ol0
P1<01?l0P1<00ol0003o07hGo`1n5`03o`1n5`?o00000onY_P000ol0003oZKh0ojVn0004ojVn0003
o`000?nX_P3oZ;h000CoZ;h000?o0000ojNm0?nW_@001?nW_@000ol0003oY;d0ojBm0003ojBm0003
o`000?nH^P3oV;X000GoV;X000?o0000of^^0?m[[P000om[[P001?l0003og880o`000?l00004ohbg
0003o`000?o7_P3oakh000;oakh00_l0000Gooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00008oooool002cooooo0ol0000booooo`;o00000ol0R@000ol0003o08T1o`290@03o`29
0@03o`000?l0R0?o08P300?o08P300?o0000o`271Ol0Q`D00ol0Q`D00ol0003o08H7o`261`03o`26
1`03o`000?l0Q@[o08D:00Co08D:00?o0000o`233Ol0P`d00ol0P`d00ol0003o088@o`224003o`22
4003o`000?l0P1?o080C00Co080C00?o0000o`1n5ol0OQL00_l0OQL2o`0000KoZKh000?o0000ojVn
0?nY_P000onY_P000ol0003oZ;h0ojRn0004ojRn0003o`000?nW_@3oYkd000CoYkd000?o0000ojBm
0?nT_@000onT_@000ol0003oV;X0oiRj0005oiRj0003o`000?m[[P3oJjh000;oJjh000?o0000omb2
0?oLPP000_l00003ohbg0003o`000?o7_P3oakh000;oakh000Co0000ol^c0?o;/`3o00005oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo000Zooooo`;o0000<oooool2
o`0000Go08T000?o0000o`290Ol0R@400ol0R@400ol0003o08P3o`280`03o`280`03o`000?l0Q`Go
08L500?o08L500?o0000o`261ol0QPL01?l0QPL00ol0003o08D:o`252P03o`252P03o`000?l0P`go
08<=00?o08<=00?o0000o`224?l0PQ000ol0PQ000ol0003o080Co`204`04o`204`03o`000?l0OQOo
000000;o000000?oZ;h0o`000?nY_P001OnY_P000ol0003oZKh0ojVn0003ojVn0003o`000?nX_P3o
Z;h000CoZ;h000?o0000ojNm0?nW_@001?nW_@000ol0003oY;d0ojBm0004ojBm0003o`000?nH^P3o
V;X000CoV;X000Go0000of^^0?m[[P3oJjh0o`000003omb200;o00000on<]`000ol0003oakh0olNn
0002olNn0005o`000?o;/`3obk<0ol^c0?l000005_ooool2o`0000?ooooo00Co0000oooooooooooo
00008oooool002Oooooo0ol000000ooooooo0000ooooo`0_ooooo`?o000000?o0HX0o`000?l0R@00
1?l0R@000ol0003o08T1o`290@04o`290@03o`000?l0R0?o08P300;o08P300?o0000o`271Ol0Q`D0
0ol0Q`D00ol0003o08H7o`261`04o`261`03o`000?l0Q@[o08D:00?o08D:00?o0000o`233Ol0P`d0
0ol0P`d00ol0003o088@o`224004o`224003o`000?l0P1?o080C00;o080C0ol00004ojRn0003o`00
0?nY_P3oZKh000CoZKh000?o0000ojVn0?nY_P001?nY_P000ol0003oZ;h0ojRn0004ojRn0003o`00
0?nW_@3oYkd000?oYkd000?o0000ojBm0?nT_@001?nT_@000ol0003oV;X0oiRj0004oiRj0005o`00
0?m[[P3oJjh0of^^0?l000001?oLPP001Ol0003oS;L0ohbg0?n<]`3o000000Coakh000Go0000ol^c
0?o;/`3obk<0o`00000Eooooo`03o`000?oooooo000000Cooooo0_l0000Tooooo`009?ooool3o`00
03?ooooo0_l00004o`6:0003o`000?l0R@3o08T000?o08T000?o0000o`290Ol0R@401?l0R@400ol0
003o08P3o`280`02o`280`03o`000?l0Q`Go08L500Co08L500?o0000o`261ol0QPL00ol0QPL00ol0
003o08D:o`252P03o`252P03o`000?l0P`go08<=00?o08<=00?o0000o`224?l0PQ001?l0PQ000ol0
003o080Co`204`02o`000003ojNm0?l0003oZ;h000CoZ;h000?o0000ojVn0?nY_P001?nY_P000ol0
003oZKh0ojVn0004ojVn0003o`000?nX_P3oZ;h000CoZ;h000?o0000ojNm0?nW_@001?nW_@000ol0
003oY;d0ojBm0003ojBm0003o`000?nH^P3oV;X000GoV;X000?o0000of^^0?l000001?oLPP02o`00
00?oS;L000Go0000olNn0?o7_P3oakh0o`000004ol^c00;o00005oooool00ol0003oooooooooo`0W
ooooo`008_ooool2o`0003Cooooo0_l000000ol2R`3o0000o`6:0003o`6:0003o`000?l0R@3o08T0
00Co08T000?o0000o`290Ol0R@400ol0R@400ol0003o08P3o`280`02o`280`03o`000?l0Q`Go08L5
00Co08L500?o0000o`261ol0QPL00ol0QPL00ol0003o08D:o`252P03o`252P03o`000?l0P`go08<=
00Co08<=00?o0000o`224?l0PQ000ol0PQ03o`0000?oYkd000?o0000ojRn0?nX_P001?nX_P000ol0
003oZKh0ojVn0003ojVn0003o`000?nY_P3oZKh000CoZKh000?o0000ojRn0?nX_P001?nX_P000ol0
003oYkd0ojNm0004ojNm0003o`000?nT_@3oY;d000?oY;d000?o0000oiRj0?nH^P001OnH^P02o`00
00;og8800ol000001OoLPP3o0000ohbg0?n<]`3o000000Coakh000Go0000ol^c0?o;/`3obk<0o`00
0002olba0003o`000?oooooooooo01Gooooo00?o0000ooooooooool09_ooool001oooooo0ol0000d
ooooo`;o00000ol2R`000ol0003o0HX0o`6:0003o`6:0003o`000?l0R@3o08T000?o08T000?o0000
o`290Ol0R@400ol0R@400ol0003o08P3o`280`03o`280`03o`000?l0Q`Go08L500?o08L500?o0000
o`261ol0QPL00ol0QPL00ol0003o08D:o`252P03o`252P03o`000?l0P`go08<=00Co08<=00?o0000
o`224?l0PQ000_l0PQ02o`0000GoYkd000?o0000ojRn0?nX_P001?nX_P000ol0003oZKh0ojVn0004
ojVn0003o`000?nY_P3oZKh000?oZKh000?o0000ojRn0?nX_P001?nX_P000ol0003oYkd0ojNm0004
ojNm0003o`000?nT_@3oY;d000?oY;d000?o0000oiRj0?nH^P001?nH^P05o`0000Gog88000?o0000
ohbg0?l000001?o7_P001Ol0003obk<0ol^c0?o;/`3o000000;oc;4000?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Vooooo`007_ooool2o`0000;ooooo00?o0000ooooooooool0;oooool2
o`0000Go0X/000?o0000o`6:0?l1RP000ol1RP000ol0003o08T0o`290003o`290003o`000?l0R@7o
08T100?o08T100?o0000o`280ol0R0<00ol0R0<00ol0003o08L5o`271@03o`271@03o`000?l0QPOo
08H700?o08H700?o0000o`252_l0Q@X01?l0Q@X00ol0003o08<=o`233@03o`233@03o`000?l0PQ3o
000000;o000000?oY[d0o`000?nW_@001OnW_@000ol0003oZ;h0ojRn0003ojRn0003o`000?nY_P3o
ZKh000CoZKh000?o0000ojVn0?nY_P000onY_P000ol0003oZ;h0ojRn0004ojRn0003o`000?nW_@3o
Ykd000CoYkd000?o0000ojBm0?nT_@001?nT_@000ol0003oV;X0oiRj0005o`0000Sog8800ol00004
olNn0005o`000?o;/`3obk<0ol^c0?l000000oo</@000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02Gooooo000Nooooo`03o`000?oooooo0000033ooooo0ol000000ol3R`3o0000o`:;0004
o`:;0003o`000?l1RP3o0HX000?o0HX000?o0000o`290?l0R@000ol0R@000ol0003o08T1o`290@03
o`290@03o`000?l0R0?o08P300?o08P300?o0000o`271Ol0Q`D00ol0Q`D00ol0003o08H7o`261`03
o`261`03o`000?l0Q@[o08D:00Co08D:00?o0000o`233Ol0P`d00_l0P`d3o`0000CoY[d000?o0000
ojNm0?nW_@001?nW_@000ol0003oZ;h0ojRn0003ojRn0003o`000?nY_P3oZKh000CoZKh000?o0000
ojVn0?nY_P001?nY_P000ol0003oZ;h0ojRn0003ojRn0003o`000?nW_@3oYkd000CoYkd000?o0000
ojBm0?nT_@001?nT_@05o`0000;oj5d000?o0000omb20?oLPP001_oLPP000ol0003oS;L0o`000003
olNn0003o`000?o;/`3obk<000;obk<000Go0000olba0?o</@3oc;40o`00000Gooooo`03o`000?oo
oooooooo02Gooooo000Nooooo`04o`000?ooooooooooo`0002gooooo0_l00004o`>;0003o`000?l2
R`3o0X/000?o0X/000?o0000o`6:0?l1RP000ol1RP000ol0003o08T0o`290003o`290003o`000?l0
R@7o08T100?o08T100?o0000o`280ol0R0<00ol0R0<00ol0003o08L5o`271@03o`271@03o`000?l0
QPOo08H700?o08H700?o0000o`252_l0Q@X01?l0Q@X00ol0003o08<=o`000002o`000003ojFm0?l0
003oY[d000CoY[d000?o0000ojNm0?nW_@001?nW_@000ol0003oZ;h0ojRn0003ojRn0003o`000?nY
_P3oZKh000CoZKh000?o0000ojVn0?nY_P001?nY_P000ol0003oZ;h0ojRn0003ojRn0003o`000?nW
_@3oYkd000GoYkd000?o0000ojBm0?nT_@000_nT_@03o`0000Koj5d000?o0000omb20?oLPP001_oL
PP02o`0000?oakh000Go0000ol^c0?o;/`3obk<0o`000004olba00;o00005_ooool2o`0002Kooooo
000Nooooo`;o00000_ooool00ol0003oooooooooo`0Wooooo`?o000000?o18/0o`000?l3R`000ol3
R`000ol0003o0X/0o`:;0004o`:;0003o`000?l1RP3o0HX000;o0HX000?o0000o`290?l0R@000ol0
R@000ol0003o08T1o`290@03o`290@03o`000?l0R0?o08P300?o08P300?o0000o`271Ol0Q`D00ol0
Q`D00ol0003o08H7o`261`04o`261`03o`000?l0Q@[o08D:00;o08D:0ol00004ojFm0003o`000?nV
_@3oY[d000CoY[d000?o0000ojNm0?nW_@000onW_@000ol0003oZ;h0ojRn0003ojRn0003o`000?nY
_P3oZKh000CoZKh000?o0000ojVn0?nY_P001?nY_P000ol0003oZ;h0ojRn0004ojRn0003o`000?nW
_@3oYkd000CoYkd000?o0000ojBm0?l000000_l000000ooXG03o0000onQM0006onQM0003o`000?oL
PP3og88000Kog88000?o0000olNn0?l000000_o7_P001Ol0003obk<0ol^c0?o;/`3o000000?oc;40
00Co0000olf_0?o=[`3o00005oooool00ol0003oooooooooo`0Sooooo`007Oooool2o`0000Cooooo
00?o0000ooooooooool08oooool3o`0000Co18/000?o0000o`>;0?l3R`000_l3R`000ol0003o0X/0
o`:;0004o`:;0003o`000?l1RP3o0HX000;o0HX000?o0000o`290?l0R@000ol0R@000ol0003o08T1
o`290@03o`290@03o`000?l0R0?o08P300?o08P300?o0000o`271Ol0Q`D00ol0Q`D00ol0003o08H7
o`261`04o`261`03o`000?l0Q@[o08D:00;o000000?oXk`0o`000?nU_@001?nU_@000ol0003oY[d0
ojJm0004ojJm0003o`000?nW_@3oYkd000?oYkd000?o0000ojRn0?nX_P001?nX_P000ol0003oZKh0
ojVn0004ojVn0003o`000?nY_P3oZKh000?oZKh000?o0000ojRn0?nX_P001?nX_P000ol0003oYkd0
ojNm0002ojNm00Co00001OoXG0000ol0003oj5d0onQM0004onQM0003o`000?oLPP3og88000Kog880
00Ko0000olNn0?o7_P3o0000olNn0?l00003ol^c0005o`000?o</@3oc;40olba0?l000000oo=[`00
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02?ooooo000;ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01oooooo0ol000000ol4R`3o0000o`B;0004o`B;0003o`000?l3R`3o0h/000;o0h/000?o0000o`:;
0?l2R`001?l2R`000ol0003o0HX0o`6:0002o`6:0003o`000?l0R@3o08T000?o08T000?o0000o`29
0Ol0R@400ol0R@400ol0003o08P3o`280`03o`280`03o`000?l0Q`Go08L500Co08L500?o0000o`26
1ol0QPL00ol0QPL3o`0000?oXk`000?o0000ojFm0?nU_@001?nU_@000ol0003oY[d0ojJm0003ojJm
0003o`000?nW_@3oYkd000?oYkd000?o0000ojRn0?nX_P001?nX_P000ol0003oZKh0ojVn0004ojVn
0003o`000?nY_P3oZKh000?oZKh000?o0000ojRn0?nX_P001?nX_P000ol0003oYkd0o`000003o`00
0003onIS0?l0003oj5`000Goj5`000?o0000onQM0?oXG@001?oXG@000ol0003og880omb20005omb2
0004o`000?o]B03o0000olNn00;o00000oo;/`000ol0003oc;40olba0002olba0005o`000?o=[`3o
cJl0olf_0?l000005oooool00ol0003oooooooooo`0Rooooo`002_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Looooo`;o00001?l4R`000ol0003o18/0o`B;0003o`B;0003o`000?l3R`3o0h/000?o0h/000?o
0000o`:;0?l2R`000ol2R`000ol0003o0HX0o`6:0003o`6:0003o`000?l0R@3o08T000;o08T000?o
0000o`290Ol0R@400ol0R@400ol0003o08P3o`280`03o`280`03o`000?l0Q`Go08L500Co08L500?o
0000o`261ol0QPL00_l0QPL2o`0000GoXk`000?o0000ojFm0?nU_@001?nU_@000ol0003oY[d0ojJm
0003ojJm0003o`000?nW_@3oYkd000CoYkd000?o0000ojRn0?nX_P000onX_P000ol0003oZKh0ojVn
0004ojVn0003o`000?nY_P3oZKh000CoZKh000?o0000ojRn0?nX_P000_nX_P05o`0000?oiV<000?o
0000onQL0?oXG0001?oXG0000ol0003oj5d0onQM0005onQM0003o`000?oLPP3og88000?og88000Co
0000one80?o]B03o00000_o7_P001Ol0003obk<0ol^c0?o;/`3o000000?oc;4000?o0000olf_0?o=
[`000_o=[`02o`0001Oooooo00?o0000ooooooooool08Oooool000[ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`0Iooooo`;o
000000?o1H`0o`000?l4R`000ol4R`000ol0003o18/0o`B;0003o`B;0003o`000?l3R`3o0h/000?o
0h/000?o0000o`:;0?l2R`000ol2R`000ol0003o0HX0o`6:0003o`6:0003o`000?l0R@3o08T000;o
08T000?o0000o`290Ol0R@401?l0R@400ol0003o08P3o`280`03o`280`03o`000?l0Q`Go08L500?o
08L500?o0000o`261ol000000_l000000onQ_03o0000oj>l0005oj>l0003o`000?nU_@3oYKd000?o
YKd000?o0000ojJm0?nV_@000onV_@000ol0003oYkd0ojNm0004ojNm0003o`000?nX_P3oZ;h000?o
Z;h000?o0000ojVn0?nY_P001?nY_P000ol0003oZKh0ojVn0004ojVn0003o`000?nX_P3o000000Co
00001ooVH`000ol0003oj5`0onQL0004onQL0003o`000?oXG@3oj5d000Coj5d000?o0000omb20?oL
PP000_oLPP000ol0003okDP0one80002one80004o`000?o7_P3o0000o`0000;obk<000Go0000olba
0?o</@3oc;40o`000003olf_0004o`000?o=[P3ocJh0o`0001Kooooo00?o0000ooooooooool08Ooo
ool000[ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05_ooool2o`0000?o1H`000?o0000o`B;0?l4R`000_l4
R`000ol0003o18/0o`B;0004o`B;0003o`000?l3R`3o0h/000;o0h/000?o0000o`:;0?l2R`000ol2
R`000ol0003o0HX0o`6:0003o`6:0003o`000?l0R@3o08T000;o08T000?o0000o`290Ol0R@401?l0
R@400ol0003o08P3o`280`03o`280`03o`000?l0Q`Go08L500;o08L50ol00004oj6l0003o`000?nS
_03oXk`000CoXk`000?o0000ojFm0?nU_@000onU_@000ol0003oY[d0ojJm0004ojJm0003o`000?nW
_@3oYkd000?oYkd000?o0000ojRn0?nX_P000onX_P000ol0003oZKh0ojVn0004ojVn0003o`000?nY
_P3oZKh000?oZKh01Ol00003onA[0003o`000?oVH`3oiV<000CoiV<000?o0000onQL0?oXG0001?oX
G0000ol0003oj5d0onQM0004onQM0005o`000?oLPP3og880omb20?l000001Oo]B002o`0000;obk<0
00?o0000ol^c0?l000000oo</@001Ol0003ocJl0olf_0?o=[`3o000000?ocJh000?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Pooooo`002_ooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`;o
00001Ol5S0000ol0003o18/0o`B;0002o`B;0003o`000?l4R`3o18/000Co18/000?o0000o`>;0?l3
R`000_l3R`000ol0003o0X/0o`:;0003o`:;0003o`000?l1RP3o0HX000?o0HX000?o0000o`290?l0
R@000ol0R@000ol0003o08T1o`290@03o`290@03o`000?l0R0?o08P300?o08P300?o0000o`271Ol0
00000_l000000onO^`3o0000oj6l0005oj6l0003o`000?nS_03oXk`000?oXk`000?o0000ojFm0?nU
_@000onU_@000ol0003oY[d0ojJm0004ojJm0003o`000?nW_@3oYkd000?oYkd000?o0000ojRn0?nX
_P000onX_P000ol0003oZKh0ojVn0005ojVn0003o`000?nY_P3o000000Co00001_oTJ`000ol0003o
iV<0onIS0004onIS0003o`000?oXG03oj5`000Coj5`000?o0000onQM0?oXG@001?oXG@001?l0003o
g880omb20?l00007one80003o`000?o;/`3obk<000;o00001?o</@001Ol0003ocJl0olf_0?o=[`3o
000000?ocJh000?o0000ooooooooool05?ooool2o`00027ooooo000:ooooo`04o`000?oooooooooo
o`0000Sooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool3
o`000003o`F<0?l0003o1H`000Co1H`000?o0000o`B;0?l4R`000ol4R`000ol0003o18/0o`B;0003
o`B;0003o`000?l3R`3o0h/000;o0h/000?o0000o`:;0?l2R`000ol2R`000ol0003o0HX0o`6:0003
o`6:0003o`000?l0R@3o08T000?o08T000?o0000o`290Ol0R@400ol0R@400ol0003o08P3o`280`02
o`280`?o00001?nO^`000ol0003oXK`0oj6l0004oj6l0003o`000?nS_03oXk`000?oXk`000?o0000
ojFm0?nU_@001?nU_@000ol0003oY[d0ojJm0003ojJm0003o`000?nW_@3oYkd000?oYkd000?o0000
ojRn0?nX_P001?nX_P000ol0003oZKh0ojVn0002ojVn00Ko00000_oRLP000ol0003oi6/0onA[0004
onA[0003o`000?oVH`3oiV<000GoiV<000?o0000onQL0?oXG0001?oXG0000ol0003oj5d0onQM0004
onQM00;o00002?o]B0001Ol0003obk<0ol^c0?o;/`3o000000?oc;4000Go0000olf_0?o=[`3ocJl0
o`000004olf^00;o00005_ooool00ol0003oooooooooo`0Oooooo`002oooool2o`0000[ooooo00?o
0000ooooooooool00_ooool3o`0000_ooooo00?o0000ooooooooool03?ooool2o`0000Co1H`000?o
0000o`F<0?l5S0000ol5S0000ol0003o18/0o`B;0003o`B;0003o`000?l4R`3o18/000?o18/000?o
0000o`>;0?l3R`000_l3R`000ol0003o0X/0o`:;0003o`:;0003o`000?l1RP3o0HX000?o0HX000?o
0000o`290?l0R@000ol0R@000ol0003o08T1o`290@03o`290@03o`000?l0R0?o000000;o000000?o
WK/0o`000?nO^`001OnO^`000ol0003oXK`0oj6l0003oj6l0003o`000?nS_03oXk`000?oXk`000?o
0000ojFm0?nU_@001?nU_@000ol0003oY[d0ojJm0003ojJm0003o`000?nW_@3oYkd000?oYkd000?o
0000ojRn0?nX_P001?nX_P000ol0003oZKh0o`000005o`0000KohW8000?o0000onA[0?oTJ`001?oT
J`000ol0003oiV<0onIS0004onIS0003o`000?oXG03oj5`000Coj5`000?o0000onQM0?oXG@000ooX
G@02o`0000SokDP000?o0000oo0m0?l000000_o;/`02o`0000;oc;4000Go0000olf_0?o=[`3ocJl0
o`000003olf^0003o`000?o>[P3o000001Oooooo00?o0000ooooooooool07_ooool001cooooo0ol0
000<ooooo`03o`000?oooooooooo00Sooooo0ol000000ol5S03o0000o`F<0003o`F<0003o`000?l5
S03o1H`000Co1H`000?o0000o`B;0?l4R`000_l4R`000ol0003o18/0o`B;0003o`B;0003o`000?l3
R`3o0h/000;o0h/000?o0000o`:;0?l2R`000ol2R`000ol0003o0HX0o`6:0003o`6:0003o`000?l0
R@3o08T000?o08T000?o0000o`290Ol0R@400_l0R@43o`0000CoWK/000?o0000oink0?nO^`001?nO
^`000ol0003oXK`0oj6l0003oj6l0003o`000?nS_03oXk`000CoXk`000?o0000ojFm0?nU_@000onU
_@000ol0003oY[d0ojJm0003ojJm0003o`000?nW_@3oYkd000CoYkd000?o0000ojRn0?nX_P000_nX
_P06o`0000?oggT000?o0000on9b0?oRLP000ooRLP000ol0003oi6/0onA[0004onA[0003o`000?oV
H`3oiV<000CoiV<000?o0000onQL0?oXG0001?oXG0001?l0003oj5d0onQM0?oXG@02o`000003ooLR
0?l0003okDP000KokDP000_o0000oo0m0?o`?@3ol3d0o`000?o;/`3o0000olba0?l0003oc;40o`00
0003olf_0007o`000?o=[P3ocJh0olf^0?l0003ocZh0o`00000Hooooo`03o`000?oooooooooo01go
oooo000Looooo`;o000000?o06@oo`000?ooool02oooool2o`0000Kooooo0_l00004o`F<0003o`00
0?l5S03o1H`000;o1H`000?o0000o`F<0?l5S0001?l5S0000ol0003o18/0o`B;0002o`B;0003o`00
0?l4R`3o18/000?o18/000?o0000o`>;0?l3R`000_l3R`000ol0003o0X/0o`:;0003o`:;0003o`00
0?l1RP3o0HX000Co0HX000?o0000o`290?l0R@000_l0R@000ol0003o08T1o`000002o`000003oiZj
0?l0003oWK/000GoWK/000?o0000oink0?nO^`000onO^`000ol0003oXK`0oj6l0003oj6l0003o`00
0?nS_03oXk`000CoXk`000?o0000ojFm0?nU_@000onU_@000ol0003oY[d0ojJm0004ojJm0003o`00
0?nW_@3oYkd000?oYkd000?o0000ojRn0?l000000_l000000ooMP03o0000o`000006ommi0003o`00
0?oRLP3ohW8000?ohW8000?o0000onA[0?oTJ`001?oTJ`000ol0003oiV<0onIS0004onIS0003o`00
0?oXG03oj5`000Goj5`00ol00004ooLR0003o`000?o]B03okDP000?okDP000?o0000oo0m0?o`?@00
0_o`?@02o`0000;oc;4000?o0000olba0?l000000oo=[`001Ol0003ocJh0olf^0?o=[P3o000000;o
cZh000?o0000ooooooooool05Oooool00ol0003oooooooooo`0Mooooo`007?ooool01?l0003ooooo
o`000?l0000>ooooo`03o`000?oooooooooo00?o000000?o1H`0o`000?l5S0000ol5S0000ol0003o
1H`0o`F<0002o`F<0003o`000?l5S03o1H`000Co1H`000?o0000o`B;0?l4R`000_l4R`000ol0003o
18/0o`B;0003o`B;0003o`000?l3R`3o0h/000;o0h/000?o0000o`:;0?l2R`001?l2R`000ol0003o
0HX0o`6:0003o`6:0004o`000?l0R@3o08T0o`2900?o00001?nJ^P000ol0003oWK/0oifk0004oifk
0003o`000?nO^`3oWk/000?oWk/000?o0000oj6l0?nQ_0001?nQ_0000ol0003oXk`0oj>l0003oj>l
0003o`000?nU_@3oYKd000?oYKd000?o0000ojJm0?nV_@001?nV_@000ol0003oYkd0ojNm0005o`00
0006omf00?l0003o0000o`000?oMP03o00001_oON@000ol0003ohW80on9b0004on9b0003o`000?oT
J`3oi6/000Coi6/000?o0000onIS0?oVH`001?oVH`001?l0003oj5`0onQL0?oXG004o`0000Oomb80
00?o0000one80?o]B0000_o]B0000ol0003ol3d0oo0m0003oo0m0005o`000?o</@3oc;40olba0?l0
00000oo=[`001Ol0003ocJh0olf^0?o=[P3o000000?ocZh000?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Looooo`007?ooool3o`000003o`1T?ol0003ooooo00cooooo0ol00004o`F<0003
o`000?l5S03o1H`000;o1H`000?o0000o`F<0?l5S0000ol5S0000ol0003o1H`0o`F<0003o`F<0003
o`000?l4R`3o18/000;o18/000?o0000o`B;0?l4R`000ol4R`000ol0003o0h/0o`>;0002o`>;0003
o`000?l2R`3o0X/000Co0X/000?o0000o`6:0?l1RP000ol1RP04o`000003oiRj0?l0003oV[X000Go
V[X000?o0000oifk0?nM^`000onM^`000ol0003oWk/0oink0003oink0003o`000?nQ_03oXK`000Co
XK`000?o0000oj>l0?nS_0000onS_0000ol0003oYKd0ojFm0004ojFm0003o`000?nV_@3oY[d000;o
Y[d01?l00003om^600?o00001?oMP0000ol0003oggT0ommi0005ommi0003o`000?oRLP3ohW8000?o
hW8000?o0000onA[0?oTJ`001?oTJ`000ol0003oiV<0onIS0003onIS00Go00000oof9P000ol0003o
mb80ooLR0005ooLR0005o`000?o]B03okDP0one80?l000001_o`?@001?l0003oc;40olba0?o</@02
o`0000;ocJl000Go0000olf^0?o=[P3ocJh0o`000003olj^00;o00005oooool2o`0001gooooo000L
ooooo`03o`000?oooooo000000;o06@o0_l00008ooooo`?o000000?o18/0o`000?l5S0001?l5S000
0ol0003o1H`0o`F<0002o`F<0003o`000?l5S03o1H`000?o1H`000?o0000o`F<0?l5S0000ol5S000
0ol0003o18/0o`B;0002o`B;0003o`000?l4R`3o18/000?o18/000?o0000o`>;0?l3R`000ol3R`00
0ol0003o0X/0o`:;0003o`:;0003o`000?l1RP3o0HX000;o0HX00_l00004oiRj0003o`000?nJ^P3o
V[X000CoV[X000?o0000oifk0?nM^`000onM^`000ol0003oWk/0oink0004oink0003o`000?nQ_03o
XK`000?oXK`000?o0000oj>l0?nS_0000onS_0000ol0003oYKd0ojFm0004ojFm0003o`000?nV_@3o
000000;o000000CofH`0o`000?oKQP3ofhH00ol000000ooKQP3o0000omf00005omf00003o`000?oO
N@3oggT000CoggT000?o0000on9b0?oRLP000ooRLP000ol0003oi6/0onA[0004onA[0003o`000?oV
H`3oiV<000?o000000?olc@0o`000?of9P001_of9P000ol0003omb80ooLR0005ooLR0003o`000?o]
B03o000000Kol3d000?o0000oo0n0?l000000_o</@02o`0000;ocJl000Go0000olf^0?o=[P3ocJh0
o`000002olj^0004o`000?o>[@3ocZd0o`0001Oooooo00?o0000ooooooooool06oooool001cooooo
00?o0000ooooool000000_l0I3l01?l0003o07lFo`000?l00003ooooo`?o00001?l4R`000ol0003o
1H`0o`F<0003o`F<0003o`000?l5S03o1H`000?o1H`000?o0000o`F<0?l5S0000_l5S0000ol0003o
1H`0o`F<0003o`F<0003o`000?l4R`3o18/000;o18/000?o0000o`B;0?l4R`000ol4R`000ol0003o
0h/0o`>;0003o`>;0003o`000?l2R`3o0X/000?o0X/000?o0000o`6:0?l000000_l000000onE^@3o
0000oiRj0004oiRj0003o`000?nJ^P3oV[X000?oV[X000?o0000oifk0?nM^`000onM^`000ol0003o
Wk/0oink0004oink0003o`000?nQ_03oXK`000?oXK`000?o0000oj>l0?nS_0001?nS_0000ol0003o
YKd0ojFm0002ojFm00?o00001?oIS003o`0000CofhH000?o0000omf00?oMP0001?oMP0000ol0003o
ggT0ommi0004ommi0003o`000?oRLP3ohW8000CohW8000Co0000onA[0?oTJ`3oi6/01Ol00005oo<d
0003o`000?of9P3omRH000ComRH000?o0000ooLR0?og8P001Oog8P02o`0000Kol3d000Co0000oo0n
0?o`?P3ol3h00_l00002olf_0003o`000?o=[`3o000000;ocJh000Go0000olj^0?o>[P3ocZh0o`00
0003olj]0003o`000?oooooooooo01Gooooo00?o0000ooooooooool06_ooool001_ooooo00Co0000
ooooool0003o00000_l0I3l01?l0003o07lFo`1o5_l0OaH3o`0000;o08T000?o0000o`B;0?l4R`00
0_l4R`000ol0003o1H`0o`F<0004o`F<0003o`000?l5S03o1H`000;o1H`000?o0000o`F<0?l5S000
0_l5S0000ol0003o1H`0o`F<0003o`F<0003o`000?l4R`3o18/000;o18/000?o0000o`B;0?l4R`00
1?l4R`000ol0003o0h/0o`>;0002o`>;0003o`000?l2R`3o0X/000;o0X/00ol00004oiFi0003o`00
0?nH^P3oV;X000?oV;X000?o0000oiZj0?nJ^P000onJ^P000ol0003oWK/0oifk0004oifk0003o`00
0?nO^`3oWk/000?oWk/000?o0000oj6l0?nQ_0000onQ_0000ol0003oXk`0oj>l0004oj>l0003o`00
0?nU_@3o000000;o000000Cof980o`000?oIS03ofH`00ol000000ooIS03o0000om^60004om^60003
o`000?oMP03ogH0000GogH0000?o0000ommi0?oON@001?oON@000ol0003ohW80on9b0007o`0000?o
kd8000?o0000oo<d0?oc=0001?oc=0000ol0003omRH0ooHV0005ooHV0004o`000?og8P3omb80ooLR
00?o000000?onQT0o`000?o`?@001?o`?@000ol0003ol3h0oo0n0003oo0n0005o`000?o=[`3ocJl0
olf_0?l000000oo=[P001Ol0003ocZh0olj^0?o>[P3o000000?ocZd000?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Iooooo`006oooool2o`000005ooooool0003o06@oo`1T?ol000000ol0
OaH00ol0003o08T0o`290002o`290003o`000?l4R`3o18/000;o18/000?o0000o`F<0?l5S0001?l5
S0000ol0003o1H`0o`F<0002o`F<0003o`000?l5S03o1H`000;o1H`000?o0000o`F<0?l5S0000ol5
S0000ol0003o18/0o`B;0002o`B;0003o`000?l4R`3o18/000Co18/000?o0000o`>;0?l3R`000_l3
R`000ol0003o0X/0o`000002o`000003oi:h0?l0003oUKT000GoUKT000?o0000oiRj0?nH^P000_nH
^P000ol0003oV[X0oiZj0004oiZj0003o`000?nM^`3oWK/000?oWK/000?o0000oink0?nO^`000onO
^`000ol0003oXK`0oj6l0004oj6l0003o`000?nS_03oXk`000Go00001?oHTP03o`0000CofH`000?o
0000om^60?oKQP001?oKQP000ol0003ogH00omf00004omf00004o`000?oON@3oggT0ommi00Ko0000
0oo/CP000ol0003okd80onm20005onm20003o`000?oc=03olc@000Colc@000?o0000ooHV0?of9P00
1?of9P001?l0003omb80o`000?l00005ooXI0005o`000?o`?@3ol3d0oo0m0?l000001_o`?P001?l0
003ocJl0olf_0?o=[`02o`0000;ocJh000Co0000olj^0?o>[P3o00001?o>[@02o`0001Oooooo00?o
0000ooooooooool06Oooool001_ooooo00Oo0000ooooooooooooooooo`000?l0I3oo000000?o07lF
00?o0000o`290?l0R@000_l0R@000ol0003o18/0o`B;0003o`B;0003o`000?l5S03o1H`000?o1H`0
00?o0000o`F<0?l5S0000_l5S0000ol0003o1H`0o`F<0002o`F<0003o`000?l5S03o1H`000?o1H`0
00?o0000o`B;0?l4R`000ol4R`000ol0003o18/0o`B;0003o`B;0004o`000?l3R`3o0h/0o`>;00?o
00001?nB^0000ol0003oUKT0oiFi0004oiFi0003o`000?nH^P3oV;X000;oV;X000?o0000oiZj0?nJ
^P001?nJ^P000ol0003oWK/0oifk0003oifk0003o`000?nO^`3oWk/000?oWk/000?o0000oj6l0?nQ
_0000onQ_004o`0000?oeYL000?o0000omRB0?oHTP000ol000000ooHTP3o0000omV<0005omV<0003
o`000?oKQP3ofhH000?ofhH000?o0000omf00?oMP0000ooMP005o`0000?ojET000?o0000ona>0?o/
CP001?o/CP000ol0003okd80onm20005onm20003o`000?oc=03olc@000?olc@000?o0000ooHV0?of
9P000_of9P04o`0000SonQT000?o0000oo0m0?l000001_o`?P000ol0003ol400o`000002olf_00;o
00000_o=[P001?l0003ocZh0olj^0?l00003olj]0004o`000?o>[03ocZ`0o`0001Oooooo00?o0000
ooooooooool06?ooool001_ooooo00Go0000ooooooooooooooooo`000002o`1T?`04o`000?l0OaKo
07lFo`0000Co08T000?o0000o`B;0?l4R`000ol4R`000ol0003o1H`0o`F<0003o`F<0003o`000?l5
S03o1H`000;o1H`000?o0000o`F<0?l5S0000_l5S0000ol0003o1H`0o`F<0003o`F<0003o`000?l4
R`3o18/000?o18/000?o0000o`B;0?l4R`000ol4R`04o`000003ohnh0?l0003oT[P000GoT[P000?o
0000oiFi0?nE^@000onE^@000ol0003oV;X0oiRj0003oiRj0003o`000?nJ^P3oV[X000?oV[X000?o
0000oifk0?nM^`000onM^`000ol0003oWk/0oink0004oink0003o`000?nQ_03o000000;o000000?o
e9`0o`000?oFU`001OoFU`02o`0000Cof98000?o0000omV<0?oIS0001?oIS0000ol0003ofhH0om^6
0003om^60003o`000?oMP03ogH0000?o00000_oVH`000ol0003ojET0onUI0004onUI0003o`000?o/
CP3ok4h000Cok4h000?o0000onm20?o_@P001?o_@P001?l0003olc@0oo<d0?oc=007o`0000Con200
00?o0000ooXI0?oj6@001?oj6@03o`0000Kol3h000Co0000oo100?o`@03ol4000_l00002olf^00;o
00000oo>[P001Ol0003ocZd0olj]0?o>[@3o000000?ocZ`000?o0000ooooooooool05?ooool2o`00
01Wooooo000Kooooo`?o000000Goooooo`000?l0I3oo06@oo`000002o`1o5P03o`000?l0R@3o08T0
00?o08T000?o0000o`B;0?l4R`000_l4R`000ol0003o1H`0o`F<0003o`F<0003o`000?l5S03o1H`0
00;o1H`000?o0000o`F<0?l5S0000_l5S0000ol0003o1H`0o`F<0004o`F<0003o`000?l4R`3o18/0
00;o18/000?o0000o`B;0?l4R`000_l4R`02o`0000CoSkP000?o0000oi:h0?nB^0001?nB^0000ol0
003oUKT0oiFi0003oiFi0003o`000?nH^P3oV;X000?oV;X000?o0000oiZj0?nJ^P000onJ^P000ol0
003oWK/0oifk0003oifk0003o`000?nO^`3oWk/000?oWk/00ol00005omBL0003o`000?oFU`3oeYL0
00Co00001_oHTP000ol0003ofH`0omV<0003omV<0004o`000?oKQP3ofhH0om^600Go00001_oVH`00
0ol0003ojET0onUI0004onUI0003o`000?o/CP3ok4h000Cok4h000Co0000onm20?o_@P3okd801_l0
0005oo@_0003o`000?oh803on20000Con20000?o0000ooXI0?oj6@000ol00002ooTL0003o`000?o`
?P3ol3h000?ol3h000?o0000oo100?o`@0000oo`@0001Ol0003ocJh0olf^0?o=[P3o000000;ocZh0
00?o0000olj]0?o>[@000_o>[@001?l0003ocZ`0olj/0?o>[002o`0001Kooooo00?o0000oooooooo
ool01Oooool3o`0000oooooo0008ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Co
oooo00Go0000ooooooooooooooooo`000002o`1T?`05o`000?l0OaKo07lFo`1o5_l000001?l0R@00
0ol0003o18/0o`B;0002o`B;0003o`000?l5S03o1H`000?o1H`000?o0000o`F<0?l5S0000_l5S000
0ol0003o1H`0o`F<0002o`F<0003o`000?l5S03o1H`000Co1H`000?o0000o`B;0?l4R`000_l4R`00
0ol0003o18/0o`000002o`000003ohbg0?l0003oSkP000CoSkP000?o0000oi:h0?nB^0000onB^000
0ol0003oUKT0oiFi0004oiFi0003o`000?nH^P3oV;X000;oV;X000?o0000oiZj0?nJ^P000onJ^P00
0ol0003oWK/0oifk0004oifk0003o`000?nO^`3o000000;o000000?odZ40o`000?oDW0001OoDW003
o`0000CoeYL000?o0000omRB0?oHTP000ooHTP000ol0003ofH`0omV<0003omV<00Co00001?oSK@00
0ol0003oiV<0onIS0005onIS0003o`000?oYF@3ojET000?ojET000?o0000ona>0?o/CP000_o/CP06
o`0000Col3d000?o0000oo@_0?od;`001Ood;`001?l0003on200ooPP0?oh8005o`0000KonA`000Go
0000oo0n0?o`?P3ol3h0o`000005oo100003o`000?o_@`3o000000;ocJh000Co0000olj^0?o>[P3o
00000oo>[@000ol0003ocZ`0olj/0002olj/0003o`000?o>[03o000001Kooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000kooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?l0I3oo
000000?o07lF00?o0000o`290?l0R@000_l0R@000ol0003o18/0o`B;0002o`B;0003o`000?l5S03o
1H`000?o1H`000?o0000o`F<0?l5S0000_l5S0000ol0003o1H`0o`F<0003o`F<0003o`000?l5S03o
1H`000?o1H`000Co0000o`B;0?l4R`3o18/00ol00004ohbg0003o`000?n?^03oSkP000?oSkP000?o
0000oi:h0?nB^0000onB^0000ol0003oUKT0oiFi0004oiFi0003o`000?nH^P3oV;X000;oV;X000?o
0000oiZj0?nJ^P001?nJ^P000ol0003oWK/0oifk0005o`0000GodZ4000?o0000omBL0?oDW0000ol0
00000ooDW03o0000omJG0004omJG0003o`000?oHTP3of98000?of98000?o0000omV<0?oIS0000ol0
0002on5f0003o`000?oSK@3ohfd000Cohfd000?o0000onIS0?oVH`001?oVH`001?l0003ojET0onUI
0?oYF@07o`0000CokD/000?o0000oo0m0?o`?@001?o`?@000ol0003om2l0oo@_0002oo@_00Ko0000
0oog90000ol0003onA`0ooTL0006ooTL0003o`000?o`?P3o000000Gol40000Co0000onm30?o_@`3o
kd<00_l000001?o>[P3o0000olj^0?l00003olj]0005o`000?o>[03ocZ`0olj/0?l000000oo>[000
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool0
00Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000o`1T?ol000000ol0OaH00ol0003o08T0o`290002o`290003o`000?l4R`3o
18/000;o18/000?o0000o`F<0?l5S0000ol5S0000ol0003o1H`0o`F<0002o`F<0003o`000?l5S03o
1H`000?o1H`000?o0000o`F<0?l5S0000ol5S004o`000003ohVf0?l0003oS;L000GoS;L000?o0000
ohnh0?n?^0000_n?^0000ol0003oT[P0oi:h0004oi:h0003o`000?nE^@3oUKT000?oUKT000?o0000
oiRj0?nH^P000_nH^P000ol0003oV[X0oiZj0003oiZj00Co00000oo@YP000ol0003odZ40om:Q0004
om:Q00?o00001?oDW0000ol0003oeYL0omJG0003omJG0004o`000?oHTP3of980omRB00Go00001_oQ
MP000ol0003ohfd0on=]0004on=]0004o`000?oVH`3oiV<0onIS00Ko00001?oYE`000ol0003okD/0
one;0005one;0004o`000?o`?@3ol3d0oo0m00Oo00000ooc<`000ol0003omb@0ooLT0004ooLT0003
o`000?oi703onA`000ConA`00ol00005oo100003o`000?o_@`3okd<000?okd<000Co0000olj^0?o>
[P3o00001?o>[@001Ol0003ocZ`0olj/0?o>[03o000000?ocZ`000?o0000ooooooooool05?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo0007ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000o`1T?ol000000ol0OaH0
0ol0003o08T0o`290002o`290003o`000?l4R`3o18/000;o18/000?o0000o`F<0?l5S0000ol5S000
0ol0003o1H`0o`F<0003o`F<0003o`000?l5S03o1H`000;o1H`000?o0000o`F<0?l5S0000_l5S002
o`0000CoRKH000?o0000ohbg0?n<]`001?n<]`000ol0003oSkP0ohnh0002ohnh0003o`000?nB^03o
T[P000CoT[P000?o0000oiFi0?nE^@000onE^@000ol0003oV;X0oiRj0003oiRj0003o`000?nJ^P3o
000000;o000000?ocjX0o`000?o@YP001Oo@YP000ol0003odZ40om:Q0003o`000003om:Q0?l0003o
e9`000Coe9`000Co0000omJG0?oFU`3oeYL01_l00004omim0003o`000?oQMP3ohGH000GohGH000Co
0000on=]0?oSK@3ohfd01_l00003onIR0003o`000?oYE`3ojEL000GojEL000?o0000one;0?o]B`00
0_o]B`06o`0000?okd4000?o0000oo<c0?oc<`001Ooc<`000ol0003omb@0ooLT0004ooLT0003o`00
0?oi703onA`000?o00000ooh8@001Ol0003ol400oo100?o`@03o000000Gokd<00_l00002olj^00;o
00000_o>[@000ol0003ocZ`0olj/0002olj/0004o`000?o>[03ocZ`0olj/00;o00005_ooool01?l0
003oooooooooooooool4o`0000oooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo0_l00003o`1o5P03o`000?l0
R@3o08T000;o08T000?o0000o`B;0?l4R`000_l4R`000ol0003o1H`0o`F<0004o`F<0003o`000?l5
S03o1H`000;o1H`000?o0000o`F<0?l5S0000_l5S0000ol0003o1H`0o`000002o`000003ohJe0?l0
003oRKH000CoRKH000?o0000ohbg0?n<]`000on<]`000ol0003oSkP0ohnh0003ohnh0003o`000?nB
^03oT[P000?oT[P000?o0000oiFi0?nE^@000onE^@000ol0003oV;X0oiRj0002oiRj00?o00001Oo?
ZP000ol0003od:H0om2V0003om2V00?o00001?oBX@000ol0003oe9`0omBL0003omBL00Co00001?oL
Q@000ol0003ogWd0omim0004omim0003o`000?oQMP3ohGH000CohGH01?l00003onA[0003o`000?oV
HP3oiV8000CoiV8000?o0000onUG0?oYE`001?oYE`05o`0000?ok4h000?o0000onm10?o_@@001?o_
@@000ol0003olc<0oo<c0005oo<c0004o`000?og903omb@0ooLT00Go00001ooh8@000ol0003ol400
o`000005onm30005o`000?o^A03okT@0o`000?o>[P000_l00002olj]0005o`000?o>[03ocZ`0olj/
0?l000000oo>[0000ol0003ocZ`0o`00000Fooooo`;o00000_ooool00ol0003oooooooooo`0@oooo
o`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`04ooooo`;o00000ol0OaH00ol0003o08T0o`290002o`290003o`000?l4R`3o
18/000;o18/000?o0000o`F<0?l5S0001?l5S0000ol0003o1H`0o`F<0002o`F<0004o`000?l5S03o
1H`0o`F<00?o00001?n6]@000ol0003oRKH0ohVf0003ohVf0003o`000?n<]`3oS;L000?oS;L000?o
0000ohnh0?n?^0000on?^0000ol0003oT[P0oi:h0003oi:h0003o`000?nE^@3oUKT000CoUKT01?l0
00000oo=[P3o0000olnZ0005olnZ0003o`000?o@YP3od:H000?o000000?od:H0o`000?oBX@001?oB
X@000ol0003oe9`0omBL0003o`0000;ofX`000?o0000omb50?oLQ@001?oLQ@000ol0003ogWd0omim
0004omim0003o`000?oQMP3ohGH000?o000000?ohG@0o`000?oTJ`001OoTJ`000ol0003oiV80onIR
0004onIR0003o`000?oYE`3ojEL000?o00000_oYFP000ol0003ok4h0ona>0004ona>0003o`000?o_
@@3okd4000Cokd4000?o0000oo<c0?oc<`000_oc<`06o`0000ComRT000?o0000ooPQ0?oh8@001?oh
8@03o`0000Gokd<000Co0000oni40?o^A03okT@00_l00002olj]0003o`000?o>[@3o000000?ocZ`0
00Go0000olj/0?o>[03ocZ`0o`000002olj/0003o`000?oooooooooo01;ooooo00?o0000ooooool0
00000_ooool5o`0000kooooo0008ooooo`;o00002Oooool3o`0000Cooooo0_l00006ooooo`;o0000
0_l0OaH00ol0003o08T0o`290002o`290003o`000?l4R`3o18/000?o18/000?o0000o`F<0?l5S000
0ol5S0000ol0003o1H`0o`F<0002o`F<00Co000000?oQ;@0o`000?n6]@001On6]@000ol0003oRKH0
ohVf0002ohVf0003o`000?n<]`3oS;L000CoS;L000?o0000ohnh0?n?^0000_n?^0000ol0003oT[P0
oi:h0004oi:h0003o`000?nE^@3oUKT000Co00001Oo=[P000ol0003ocjX0olnZ0003olnZ00?o0000
1?o@YP001?l0003odZ40om:Q0?oBX@05o`0000KofX`000?o0000omb50?oLQ@001?oLQ@001?l0003o
gWd0omim0?oNO@05o`0000GohG@000?o0000onA[0?oTJ`001?oTJ`001?l0003oiV80onIR0?oVHP05
o`0000KojEX000?o0000ona>0?o/CP001?o/CP001?l0003okd40onm10?o_@@07o`0000ColSL000?o
0000ooHY0?of:@001?of:@000ol0003on240ooPQ0003o`0000;ombD000?o0000onm30?o_@`000_o_
@`000ol0003okT@0oni40003oni40005o`000?o>[@3ocZd0olj]0?l000001?o>[0001Ol0003ocZ`0
olj/0?o>[03o000000;ocZ`000?o0000ooooooooool05Oooool00ol0003oooooooooo`0Booooo`00
6_ooool00ol0003oooooooooo`05ooooo`;o00000_l0OaH00ol0003o08T0o`290002o`290003o`00
0?l4R`3o18/000?o18/000?o0000o`F<0?l5S0000ol5S0000ol0003o1H`0o`F<0003o`0000CoQ;@0
00?o0000ohJe0?n6]@001?n6]@000ol0003oRKH0ohVf0003ohVf0003o`000?n<]`3oS;L000?oS;L0
00?o0000ohnh0?n?^0000_n?^0000ol0003oT[P0oi:h0003oi:h00Co00000oo</P000ol0003ocJh0
olf^0004olf^0003o`000?o?ZP3ocjX000;o00000_o?ZP000ol0003od:H0om2V0002om2V00Co0000
1?oGTP000ol0003ofX`0omZ<0005omZ<0004o`000?oLQ@3og8D0omb500Ko00001?oNO@000ol0003o
hG@0on5d0004on5d0004o`000?oTJ`3oi6/0onA[00Ko00001?oVI@000ol0003ojEX0onUJ0005onUJ
0004o`000?o/CP3ok4h0ona>00Ko00001?o^A@000ol0003olSL0oo8g0005oo8g0004o`000?of:@3o
mRT0ooHY00Go00001_og9@001?l0003okd<0onm30?l00006oni40004o`000?o>[@3ocZd0olj]00;o
00000_o>[0001Ol0003ocZ`0olj/0?o>[03o000000?ocZ`00_l0000Fooooo`03o`000?oooooooooo
01;ooooo000Jooooo`03o`000?oooooooooo00Gooooo0_l00002o`1o5P03o`000?l0R@3o08T000?o
08T000?o0000o`B;0?l4R`000_l4R`000ol0003o1H`0o`F<0002o`F<00Co00000_n1]0000ol0003o
Q;@0ohBd0003ohBd0003o`000?n6]@3oQ[D000?oQ[D000?o0000ohVf0?n9]P000on9]P000ol0003o
S;L0ohbg0003ohbg0003o`000?n?^03oSkP000?oSkP000?o0000oi:h0?l000000_l000000oo:]P3o
0000olbb0005olbb0003o`000?o=[P3ocJh000?ocJh00ol00004olnZ0003o`000?o@YP3o000000;o
00000_oEV0000ol0003oei80omNB0004omNB0003o`000?oJS03ofX`000CofX`01?l00003omb40003
o`000?oNO@3ogWd000GogWd000Co0000on5d0?oQM03ohG@01_l00004on=^0003o`000?oVI@3oiVD0
00CoiVD000?o0000onUJ0?oYFP000_oYFP06o`0000Coje8000?o0000oni50?o^A@001?o^A@000ol0
003olSL0oo8g0002oo8g00Ko00000ood;@000ol0003ombD0ooLU0005ooLU0003o`000?o_@`3o0000
00KokT@000?o0000oni60?l000000_o>[@02o`0000;ocZ`000Go0000olj/0?o>[03ocZ`0o`000002
olj/0004o`000?o?Z`3ocj/0o`0001Kooooo00?o0000ooooooooool04Oooool001Wooooo00?o0000
ooooooooool01oooool2o`0000;o07lF00?o0000o`290?l0R@000_l0R@000ol0003o18/0o`B;0002
o`B;0003o`000?l5S03o000000;o000000?oOK<0o`000?n1]0000on1]0000ol0003oQ;@0ohBd0003
ohBd0003o`000?n6]@3oQ[D000CoQ[D000?o0000ohVf0?n9]P000_n9]P000ol0003oS;L0ohbg0003
ohbg0003o`000?n?^03oSkP000;oSkP00ol00005olZf0003o`000?o</P3oc;8000?oc;8000?o0000
olf^0?o=[P000ol000000oo=[P3o0000olnZ0002olnZ00Co00001_oEV0000ol0003oei80omNB0004
omNB0003o`000?oJS03ofX`000?o000000?ofX`0o`000?oLQ0001OoLQ0000ol0003ogWd0omim0004
omim00Co00001?oPM`000ol0003ohfh0on=^0004on=^0004o`000?oVI@3oiVD0onIU00Oo00001?oX
G@000ol0003oje80on]B0004on]B0004o`000?o^A@3okTD0oni500Oo00000ooa>`000ol0003om2d0
oo@]0004oo@]0003o`000?og9@3ombD000CombD00_l00006oni40004o`000?o^AP3okTH0oni600;o
00000_o>[0000ol0003ocZ`0o`000003olj/0004o`000?o>[03ocZ`0o`0000?ocj/000?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0@ooooo`006Oooool2o`0000Sooooo00Go0000od:R0?l0
003o07lFo`000004o`290004o`000?l4R`3o18/0o`B;00?o00001?mm/`000ol0003oPK@0oh6d0003
oh6d0003o`000?n4]03oQ;@000;oQ;@000?o0000ohJe0?n6]@001?n6]@000ol0003oRKH0ohVf0002
ohVf0003o`000?n<]`3oS;L000CoS;L01?l000000oo9^P3o0000olZf0006olZf0003o`000?o</P3o
c;8000;oc;800ol00004olf^00Co00000ooCWP000ol0003oeIP0omFH0005omFH0004o`000?oGTP3o
ei80omNB00Go00001OoJS0000ol0003og8@0omb40004omb40003o`000?oNO@3ogWd000?o000000?o
gGl0o`000?oPM`001_oPM`001?l0003ohfh0on=^0?oSKP06o`0000CoiFP000?o0000onQM0?oXG@00
1OoXG@001?l0003oje80on]B0?o[DP06o`0000?okDT000?o0000oo4k0?oa>`001Ooa>`000ol0003o
m2d0oo@]0004oo@]0003o`000?og9@3ombD000?o000000?omRP0o`000?o^A0001?o^A0000ol0003o
kTH0oni60003oni60005o`000?o>[03ocZ`0olj/0?l000000oo>[0001Ol0003ocZ`0olj/0?o>[03o
000000?ocj/000?o0000ooooooooool05?ooool2o`00017ooooo000Iooooo`03o`000?oooooooooo
00Sooooo00Co0000od:R0?l0003o00001?l0R@04o`000003ogVb0?l0003oOK<000GoOK<000?o0000
oh6d0?n1]0000_n1]0000ol0003oQ;@0ohBd0003ohBd0003o`000?n6]@3oQ[D000?oQ[D000?o0000
ohVf0?n9]P000on9]P000ol0003oS;L0ohbg0004o`0000GobKX000?o0000olZf0?o:]P001?o:]P00
0ol0003oc;80o`000002o`000004olbb0?l0003ocJh0olf^00?o000000?odJ<0o`000?oCWP001OoC
WP000ol0003oeIP0omFH0004omFH00Co00001?oGTP000ol0003ofX`0omZ<0004omZ<0004o`000?oL
Q03og8@0omb400Go00001OoMO`000ol0003oh7L0on1g0004on1g00Co00001?oRL@000ol0003oiFP0
onEX0004onEX0003o`000?oXG@3oj5d000Coj5d01?l00003onYE0003o`000?o]B@3okDT000CokDT0
00?o0000oo4k0?oa>`001Ooa>`001?l0003om2d0oo@]0?od;@05o`0000GomRP000Go0000oni40?o^
A03okT@0o`000005oni600;o00000oo>[0001Ol0003ocZ`0olj/0?o>[03o000000;ocZ`000Oo0000
oln[0?o?Z`3ocj/0o`000?o?Z`3o000001Kooooo00?o0000ooooooooool03oooool001Wooooo00?o
0000ooooooooool02?ooool00ol0003o@Z80od:R0006o`0000CoNK8000?o0000ogfc0?mm/`001?mm
/`000ol0003oPK@0oh6d0002oh6d0003o`000?n4]03oQ;@000?oQ;@000?o0000ohJe0?n6]@000on6
]@000ol0003oRKH0ohVf0002ohVf00Co00000oo7_@000ol0003obKX0olVj0004olVj0003o`000?o:
]P3ob[H000;ob[H00ol00003olbb00Co00001OoAX`000ol0003odih0om>N0004om>N0003o`000?oE
V03oeIP000?o000000?oeIP0o`000?oGTP001_oGTP001?l0003ofX`0omZ<0?oJS006o`0000CofhL0
00?o0000omeo0?oMO`001?oMO`000ol0003oh7L0on1g0003o`0000;oggX000?o0000on9a0?oRL@00
1?oRL@000ol0003oiFP0onEX0004onEX0003o`000?oXG@3oj5d000?o000000?oif00o`000?oZE@00
1OoZE@000ol0003okDT0one90004one90003o`000?oa>`3olC/000;olC/01_l00004oo@`0003o`00
0?of:03omRP000ComRP000?o0000oni40?l000001Oo^AP001?l0003okTL0oni70?l00002olj/00;o
00000_o>[0001?l0003ocZ`0olj/0?l00003oln[0004o`000?o?Z`3ocj/0o`0001Kooooo00?o0000
ooooooooool03_ooool001Wooooo00?o0000ooooooooool02?ooool01?l0003o@Z80od:R0?l00004
off^0003o`000?mi/P3oNK8000?oNK8000?o0000ogfc0?mm/`000omm/`000ol0003oPK@0oh6d0003
oh6d0003o`000?n4]03oQ;@000;oQ;@000?o0000ohJe0?n6]@001?n6]@04o`000003olK00?l0003o
akd000Goakd000?o0000olVj0?o9^P000oo9^P000ol0003ob[H0o`000002o`0000;ob[H01?l00004
om2X0003o`000?oAX`3odJ<000?odJ<000Co0000om>N0?oCWP3odih01Ol00005omFH0003o`000?oG
TP3oei8000Coei801?l00004omV>0003o`000?oKQ`3ofhL000CofhL000Co0000omeo0?oMO`3ogGl0
1Ol00006ommj0003o`000?oRL@3ohW4000CohW4000Co0000onEX0?oUJ03oiFP01Ol00005onMP0003
o`000?oZE@3ojUD000CojUD000Co0000one90?o]B@3okDT01ol00004oo0n0003o`000?od<03om300
00Com30000Co0000ooHX0?of:03omRP01?l00005oni60003o`000?o^A`3okTL000;okTL00_l00002
olj/00;o00000oo>[0001Ol0003ocj/0oln[0?o?Z`3o000000;ocj/000?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0>ooooo`006Oooool2o`0000[ooooo00?o0000od:R0?l000001?m][P00
0ol0003oNK80ogVb0003ogVb0003o`000?mm/`3oOK<000CoOK<000?o0000oh6d0?n1]0000_n1]000
0ol0003oQ;@0ohBd0003ohBd0003o`000?n6]@3oQ[D000Co00001Oo6`0000ol0003oakd0olNm0004
olNm0004o`000?o9^P3obKX0olVj00?o00000_o:]P03o`000003olj]0?l0003od:P000Kod:P000Co
0000om6S0?oAX`3odJ<01Ol00005om>N0003o`000?oEV03oeIP000?oeIP000?o0000omNB0?oGTP00
0ol00002omND0003o`000?oISP3ofHh000CofHh000Co0000om^70?oKQ`3ofhL01_l00005omf20003
o`000?oONP3oggX000CoggX000Co0000on9a0?oRL@3ohW401_l00004onAZ0003o`000?oWH03oif00
00Coif0000Co0000onYE0?oZE@3ojUD01_l00004one<0003o`000?o`?P3ol3h000Gol3h000Co0000
oo@`0?od<03om3001_l00004ooD/0005o`000?o^AP3okTH0oni60?l000001_o^A`001Ol0003ocZ`0
olj/0?o>[03o000000;ocZ`000Go0000oln[0?o?Z`3ocj/0o`000003oln[00;o00005_ooool00ol0
003oooooooooo`0=ooooo`006Oooool00ol0003oooooooooo`09ooooo`04o`000?m2XP3o@Z80o`00
00CoKJh000?o0000ogVb0?mi/P000_mi/P000ol0003oOK<0ogfc0004ogfc0003o`000?n1]03oPK@0
00;oPK@000?o0000ohBd0?n4]0000_n4]004o`0000?oaL@000?o0000olK00?o6`0001?o6`0000ol0
003oakd0olNm0003olNm0003o`000?o9^P3o000000Ko00001Oo>[@000ol0003od:P0om2X0004om2X
00Co00001?oAX`000ol0003odih0om>N0004om>N0004o`000?oEV03oeIP0omFH00Co00001_oGU000
0ol0003ofHh0omV>0003omV>00Co00001OoJR@000ol0003ogH80omf20004omf20004o`000?oONP3o
ggX0ommj00Ko00001?oQL`000ol0003oi6X0onAZ0004onAZ0004o`000?oWH03oif00onMP00Ko0000
1?oYF0000ol0003okD`0one<0004one<0003o`000?o`?P3ol3h000;ol3h01_l00003oo<c0003o`00
0?oe;03omB`000GomB`000?o0000oni60?l000001_o^A`000ol0003okDT0o`000002olj/0004o`00
0?o>[03ocZ`0o`0000?ocj/000Co0000oln[0?o?Z`3o00000_o?Z`000ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00gooooo000Hooooo`03o`000?oooooooooo00[ooooo00Co0000od:R0?m2
XP3o00001?m][P000ol0003oNK80ogVb0003ogVb0003o`000?mm/`3oOK<000?oOK<000?o0000oh6d
0?n1]0000on1]004o`000003ol740?l0003oaL@000GoaL@000?o0000olK00?o6`0000oo6`0000ol0
003oakd0olNm0002olNm00Go00001Oo</@000ol0003ocZd0olj]0003olj]0003o`000?o@Z03od:P0
00?o000000?od:P0o`000?oAX`001_oAX`001?l0003odih0om>N0?oCWP06o`0000CoeIX000?o0000
omND0?oGU0001?oGU0000ol0003ofHh0o`000002o`0000;of90000?o0000omZ90?oJR@001OoJR@00
1?l0003ogH80omf20?oMPP06o`0000CogW`000?o0000on5c0?oQL`001?oQL`001?l0003oi6X0onAZ
0?oTJP06o`0000CoiV<000?o0000onUH0?oYF0001?oYF0001?l0003okD`0one<0?o]C007o`0000?o
kd4000?o0000oo<c0?oc<`001?oc<`000ol0003omB`0ooD/0004ooD/00;o00001_o^A`001?l0003o
kDT0one90?o]B@02o`000004olj/0?l0003ocZ`0o`0000?ocj/000Co0000oln[0?o?Z`3o00000oo?
Z`000ol0003oooooooooo`0Booooo`;o00003_ooool001Sooooo00?o0000ooooooooool02oooool0
0ol0003o@Z80o`000004off^0003o`000?mi/P3oNK8000?oNK8000?o0000ogfc0?mm/`000omm/`00
0ol0003oPK@0oh6d0002oh6d00;o00001Oo1a0000ol0003oaL@0olG40004olG40003o`000?o6`03o
a/0000?oa/001Ol00002ol^e0003o`000?o</@3oc;4000Goc;4000Co0000olj]0?o>[@3ocZd01?l0
0005om2X0003o`000?oAX`3odJ<000CodJ<01?l00004om>P0003o`000?oEVP3oeIX000CoeIX000Co
0000omND0?oGU03oei@01?l00006omR@0003o`000?oJR@3ofXT000CofXT01?l00003omb40003o`00
0?oNO03ogW`000GogW`000Co0000on5c0?oQL`3ohG<01_l00004on=]0003o`000?oVH`3oiV<000Co
iV<000Co0000onUH0?oYF03ojEP01_l00003ona>0003o`000?o_@@3okd4000Gokd4000?o0000oo<c
0?oc<`001?oc<`000ol0003omB`0ooD/0003o`000003oo@^0?l0003okTL000CokTL000?o0000one9
0?o]B@000oo]B@001?l0003ocZ`0olj/0?l00003oln[0005o`000?o?Z`3ocj/0oln[0?l000000oo?
Z`000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo000Hooooo`?o00002oooool0
1?l0003o@Z80od:R0?l00004off^0003o`000?mi/P3oNK8000;oNK8000?o0000ogfc0?mm/`001?mm
/`04o`000003ok_20?l0003o`L@000Go`L@000?o0000olG40?o5a0001?o5a0000ol0003oa/00olK0
0005o`0000GobkD000?o0000olba0?o</@001?o</@04o`0000CocZd000?o0000om2X0?o@Z0000oo@
Z0000ol0003odJ<0om6S0003o`000003om6U0?l0003odj0000Kodj0000Co0000omFJ0?oEVP3oeIX0
1_l00004omJF0003o`000?oHT03of90000Cof90000?o0000omZ90?oJR@000ol000000ooJR`3o0000
omb40005omb40003o`000?oNO03ogW`000CogW`01?l00003on5f0003o`000?oSK@3ohfd000Gohfd0
00Co0000onIS0?oVH`3oiV<01_l00003onQJ0003o`000?o/CP3ok4h000Cok4h000?o0000onm10?o_
@@001?o_@@000ol0003olc<0oo<c0002oo<c00Go00001Ood;P001Ol0003okTL0oni70?o^A`3o0000
00GokDT00_l00002olj/00;o00000_o?Z`001?l0003ocj/0oln[0?l00003oln[0003o`000?o?Z`3o
000001Gooooo00?o0000ooooooooool02oooool000Gooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00005ooooo`03o`000?oooooooooo00cooooo00?o0000od:R0?l000001?m][P000ol0
003oNK80ogVb0003ogVb0003o`000?mm/`3oOK<000Co00001Onk`P000ol0003o`L@0ol740004ol74
0004o`000?o5a03oaL@0olG400Ko00001?o9^@000ol0003obkD0ol^e0003ol^e0003o`000?o</@3o
c;4000?o000000?oc;40o`000?o>[@001_o>[@001?l0003od:P0om2X0?o@Z004o`0000GodJD000?o
0000om>P0?oCX0001?oCX004o`0000Coe9`000?o0000omJF0?oFUP001?oFUP001?l0003of900omR@
0?oHT005o`0000GofX/000?o0000omb40?oLQ0001?oLQ0000ol0003ogW`0omil0003o`000003omin
0?l0003ohGH000GohGH000?o0000on=]0?oSK@001?oSK@04o`0000?oiFD000?o0000onQJ0?oXFP00
1?oXFP000ol0003ok4h0ona>0004ona>0004o`000?o_@@3okd40onm100Oo00001?ob=P000ol0003o
m2h0oo@^0004oo@^0003o`000?o^A`3o000000GokDT000Go0000one:0?o]BP3o0000olj/0002o`00
00;ocj/000Co0000oln[0?o?Z`3o00000oo?Z`001?l0003ocj/0oln[0?l0000Eooooo`03o`000?oo
oooooooo00[ooooo0004ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00gooooo0_l00004off^0003o`000?mi/P3oNK8000;oNK80
1?l00003okK10003o`000?nk`P3o^l8000Co^l8000?o0000ol740?o1a0000oo1a006o`000003olRl
0?l0003obKT000KobKT000Co0000ol^e0?o;]@3obkD01?l00005olba0003o`000?o>[@3ocZd000Co
cZd01?l00004olnZ0003o`000?oAY@3odJD000?odJD000?o0000om>P0?oCX0000ol00002om:R0003
o`000?oDW03oe9`000Coe9`000Co0000omJF0?oFUP3oeYH01_l00004omRB0003o`000?oJR`3ofX/0
00CofX/000Co0000omb40?oLQ03og8@01Ol00005omin0003o`000?oQMP3ohGH000CohGH000?o0000
on=]0?oSK@000ol000000ooSK`3o0000onEU0005onEU0003o`000?oXFP3oj5X000Coj5X000Co0000
ona>0?o/CP3ok4h01_l00004onm40003o`000?ob=P3olSH000GolSH000Co0000oo@^0?od;P3om2h0
1?l00005one90004o`000?o]BP3okDX0one:00;o00000_o?Z`02o`0000?ocj/000Go0000oln[0?o?
Z`3ocj/0o`000002oln[0003o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool000Co
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo0_l00004off^00Co000000?o[kl0o`000?nf`@001Onf`@000ol0003o^l80ok_20004ok_2
0003o`000?o1a03o000000Go00001Oo8_0000ol0003obKT0olVi0004olVi00Co00001?o;]@000ol0
003oc;40olba0003olba0003o`000?o>[@3ocZd000?o00000_o=[P000ol0003ocjX0olnZ0004olnZ
0004o`000?oAY@3odJD0om6U00Co00001_oBXP000ol0003oe9`0omBL0003omBL00Co00001?oFV000
0ol0003of980omRB0004omRB0004o`000?oJR`3ofX/0omZ;00Ko00001?oKQP000ol0003ogWh0omin
0004omin0004o`000?oQMP3ohGH0on5f00Go00001OoSK`000ol0003oiFD0onEU0004onEU0004o`00
0?oXFP3oj5X0onQJ00Ko00001?o[D0000ol0003okd@0onm40004onm40003o`000?ob=P3olSH000;o
lSH01_l00004oo@`0005o`000?o]B@3okDT0one90?l000001Oo]BP001Ol0003ocj/0oln[0?o?Z`3o
000000;ocj/000Go0000oln[0?o?Z`3ocj/0o`000003oln[00;o00005Oooool2o`0000[ooooo0004
ooooo`04o`000?ooooooooooo`0000Wooooo0_l00004ooooo`;o00004Oooool6o`0000Go[kl000?o
0000okK10?nf`@001?nf`@001?l0003o^l80ok_20?nk`P07o`0000?oa/0000?o0000olRl0?o8_000
0oo8_0000ol0003obKT0olVi0003o`0000;obKT000?o0000ol^e0?o;]@001?o;]@001?l0003oc;40
olba0?o</@04o`0000KocJh000Co0000olnZ0?o?ZP3ocjX01_l00004om2W0003o`000?oBXP3odZ80
00CodZ8000?o0000omBL0?l000000_l00002om>N0003o`000?oFV03oeYP000CoeYP000Co0000omRB
0?oHTP3of9801_l00004omV=0003o`000?oKQP3ofhH000CofhH000Co0000omin0?oNOP3ogWh01_l0
0004on1h0003o`000?oSK`3ohfl000Cohfl000Co0000onEU0?oUI@3oiFD01_l00004onQL0003o`00
0?o[D03oje0000Coje0000Co0000onm40?o_A03okd@01ol00003oo8h0003o`000?od<03om30000Go
m30000?o0000one90?l000001Oo]BP000ol0003okDX0o`000002oln[0004o`000?o?Z`3ocj/0o`00
00?ocj/000Ko0000oln[0?o?Z`3o0000oln[0?l0000Eooooo`;o00002_ooool000Cooooo00Co0000
oooooooooooo00002oooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000oinl0?nO_000
0_nO_0000ol0003o[kl0ojno0003ojno0003o`000?nf`@3o]/4000?o]/401?l00002olG300;o0000
00?oaL<0o`000?o6`0001?o6`0001?l0003ob;`0olRl0?o8_004o`0000KobKT000Co0000ol^e0?o;
]@3obkD01_l00004olbc0003o`000?o=[P3ocJh000?ocJh01?l00004olj/0003o`000?o@Y`3od:L0
00Cod:L000Co0000om:R0?oBXP3odZ801?l00006om>N0003o`000?oFV03oeYP000?oeYP01?l00004
omNC0003o`000?oIS@3ofHd000CofHd000Co0000om^60?oKQP3ofhH01_l00004omf00003o`000?oP
N03oh7P000Coh7P000Co0000on=_0?oSK`3ohfl01_l00004onEV0003o`000?oXG03oj5`000Coj5`0
00Co0000on]@0?o[D03oje001_l00003oni50003o`000?ob>03olSP000GolSP000?o0000oo@`0?od
<0000ood<003o`0000GokDX000Co0000one:0?o]BP3okDX00_l000001?o?Z`3o0000oln[0?l00003
oln[0004o`000?o?Z`3ocj/0o`0000;ocj/000?o0000ooooooooool04_ooool3o`0000Wooooo0004
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo01;ooooo00?o0000oinl0?nO_0000_nO_0000ol0003o[kl0ojno0003ojno0003o`00
0?nf`@3o000000;o00000_o0a004o`0000CoaL<000Co0000olK00?o6`03oa/001Ol00004olNm0003
o`000?o9^@3obKT000?obKT01?l00004olZg0003o`000?o</`3oc;<000Coc;<000?o0000olf^0?l0
00000_l00002olf`0003o`000?o>[03ocZ`000CocZ`000Co0000om2W0?o@Y`3od:L01_l00004om6S
0003o`000?oCWP3odih000Codih000?o0000omJH0?l000000_l00002omFI0003o`000?oGT`3oei<0
00Coei<000Co0000omV=0?oIS@3ofHd01_l00004om^70003o`000?oMP03ogH0000CogH0000Co0000
on1h0?oPN03oh7P01_l00004on9`0003o`000?oUIP3oiFH000CoiFH000Co0000onQL0?oXG03oj5`0
1_l00003on]B0003o`000?o^A@3okTD000CokTD000?o0000oo8h0?ob>0001?ob>0000ol0003om300
oo@`0003o`0000;olc4000?o0000one:0?o]BP000_o]BP000ol0003okDX0one:0003one:0004o`00
0?o?Z`3ocj/0o`0000?ocj/000Go0000oln[0?o?Z`3ocj/0o`000002oln[00;o00004?ooool3o`00
00;ooooo00?o0000ooooooooool01oooool000Gooooo0_l00009ooooo`?o00001?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?nO_03oWk`000;oWk`000Co0000ojno0?n__`3o[kl01?l00002ol34
00Co00001_o5``04o`0000Coa/4000?o0000olNm0?o7_@000oo7_@000ol0003obKT0o`000002o`00
00;ob;/000?o0000olZg0?o:]`001?o:]`001?l0003oc;<0olbc0?o</`04o`0000KocK0000?o0000
olj/0?o>[0000oo>[004o`0000Cod:P000?o0000om6S0?oAX`001?oAX`001?l0003odih0om>N0?oC
WP04o`0000KoeIT000?o0000omNC0?oGT`000ooGT`04o`0000CofHh000?o0000om^70?oKQ`001?oK
Q`001?l0003ogH00omf00?oMP006o`0000CoggT000?o0000on9`0?oRL0001?oRL0001?l0003oiFH0
onEV0?oUIP06o`0000?oied000?o0000on]B0?o[DP001?o[DP000ol0003okTD0oni50004oni50004
o`000?ob>03olSP0oo8h00Go00001_oc<@001?l0003okDX0one:0?l00005one:00;o00000_o?Z`02
o`0000;ocj/000Co0000oln[0?o?Z`3o00000oo?Z`000ol0003ocZ/0o`00000<ooooo`?o00001Ooo
ool00ol0003oooooooooo`07ooooo`005oooool2o`0001Gooooo2?l00003okW200?o00001?o0a000
0ol0003oaL<0olG30003o`000003olG40?l0003oa/4000Koa/4000Co0000olNm0?o7_@3oakd01?l0
0005olRk0003o`000?o:]`3ob[L000?ob[L01?l00004ol^d0003o`000?o=/03ocK0000CocK0000?o
0000olj/0?l000000_l00002olj]0003o`000?o@Z03od:P000Cod:P000Co0000om6S0?oAX`3odJ<0
1_l00004om>O0003o`000?oEV@3oeIT000CoeIT000?o0000omNC0?l000000_l000000ooGU@3o0000
omV>0006omV>0004o`000?oKQ`3ofhL0om^700Ko00001?oMP@000ol0003oggT0ommi0004ommi0004
o`000?oRL03ohW00on9`00Ko00000ooUJ0000ol0003oied0onMM0004onMM0003o`000?o[DP3oje80
00Coje8000Co0000oni50?o^A@3okTD01_l00004oo4j0003o`000?oc<@3olc4000Colc4000?o0000
one:0?l000001Oo]BP001Ol0003okD/0one;0?l0003ocj/000;o00000_o?Z`001?l0003ocj/0oln[
0?l00002oln[0005o`000?o>Z`3ocZ/0olj[0?l000001oooool4o`0000Sooooo00?o0000oooooooo
ool01oooool001Oooooo00?o0000ooooooooool05Oooool00ol0003oZ;h0ojRn0002ojRn0003o`00
0?ni`P3o000000;o00000_ni`P001?l0003o`<@0ol340?o0a004o`0000GoaL@000?o0000olK10?o6
`@001?o6`@04o`0000Coakh000?o0000olRk0?o8^`000oo8^`000ol0003ob[L0o`000002o`0000?o
bKP000?o0000ol^d0?o;]0000oo;]0001?l0003ocK00olf`0?o=/004o`0000KocZd000?o0000om2X
0?o@Z0000oo@Z004o`0000CodJ@000?o0000om>O0?oCW`001?oCW`001?l0003oeIT0omFI0?oEV@04
o`0000GoeiD000?o0000omV>0?oISP001?oISP04o`0000?ofhP000?o0000omf10?oMP@001OoMP@00
1?l0003oggT0ommi0?oON@06o`0000?ohW4000?o0000onEX0?oUJ0001?oUJ0000ol0003oied0onMM
0004onMM0004o`000?o[DP3oje80on]B00Ko00001?o^A`000ol0003olCX0oo4j0004oo4j0004o`00
0?oc<@3olc40oo<a00Co00001Oo]BP001?l0003okD/0one;0?o]B`02o`0000;ocj/00_l00003oln[
0004o`000?o?Z`3ocj/0o`0000?ocZ/000?o0000ooooooooool00_ooool3o`0000gooooo00?o0000
ooooooooool01_ooool001Oooooo00?o0000ooooooooool05_ooool00ol0003oZ;h0ojRn0003o`00
00Go^L801?l00004oko30003o`000?o5a03oaL@000?oaL@000?o0000olK10?o6`@000ol00002olG2
0003o`000?o7_P3oakh000Coakh000Co0000olRk0?o8^`3ob;/00ol00007olVh0004o`000?o;]03o
bk@0ol^d00Go00001?o</@000ol0003ocZd0olj]0004olj]0003o`000?o@Z03o000000;o00000_o?
Z@000ol0003odJ@0om6T0004om6T0004o`000?oCW`3odil0om>O00Ko00001?oDV`000ol0003oeiD0
omNE0003omNE0003o`000?oISP3ofHh000?o000000?of8l0o`000?oKR0001OoKR0000ol0003ogH40
omf10004omf100Co00000ooONP000ol0003ohW40on9a0004on9a0003o`000?oUJ03oiFP000CoiFP0
00Co0000onMM0?oWG@3oied01_l00004on]C0003o`000?o^A`3okTL000CokTL000Co0000oo4j0?oa
>P3olCX01_l00004oo<c0005o`000?o]BP3okDX0one:0?l000001Oo]B`001Ol0003ocj/0oln[0?o?
Z`3o000000;ocj/000Go0000oln[0?o?Z`3ocj/0o`000002olj[0003o`000?o>[03o000000?o0000
4?ooool00ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`0Fooooo`?o00000onX
_P000ol0003o^L80o`000002o`0000?o^<8000?o0000oko30?no``000ono``001?l0003oaL@0olG4
0?o5a004o`0000KoaL8000Co0000olNn0?o7_P3oakh01_l00003olRl0003o`000?o9^03obKP000Co
bKP01?l00004ol^f0003o`000?o</@3oc;4000?oc;4000Co0000olj]0?o>[@3ocZd01?l00006olnY
0003o`000?oAY03odJ@000?odJ@01?l00004om:P0003o`000?oDV`3oe9/000Coe9/000Co0000omNE
0?oGU@3oeiD01?l00005omR?0003o`000?oKR03ofhP000CofhP000?o0000omf10?oMP@000ol00000
0ooMPP3o0000ommj0005ommj0003o`000?oRL@3ohW4000CohW4000Co0000onEX0?oUJ03oiFP01_l0
0004onMO0003o`000?o[D`3oje<000Coje<000Co0000oni70?o^A`3okTL01_l00003oo4k0003o`00
0?oc<`3olc<000Golc<000?o0000one:0?l000001Oo]B`000ol0003okD/0o`000002oln[00;o0000
00?ocj/0o`000?o?Z`000_o?Z`001?l0003ocZ/0olj[0?l00002olj/0003o`000?oooooooooo013o
oooo00?o0000ooooooooool01_ooool001Kooooo0_l0000Eooooo`?o00000_ooool7o`0000Ko^<80
00Co0000oko30?no``3o_l<01Ol00004ol?40003o`000?o5`P3oaL8000?oaL801?l00004olK00003
o`000?o8_03ob;`000?ob;`000?o0000olVh0?o9^0000ol000000oo9^@3o0000ol^f0006ol^f0004
o`000?o</@3oc;40olba00Go00001?o=[P000ol0003ocjT0olnY0004olnY0003o`000?oAY03o0000
00;o000000?odJD0o`000?oBX0001_oBX0001?l0003oe9/0omBK0?oDV`06o`0000CoeYH000?o0000
omR?0?oHS`000ooHS`001?l0003ofhP0om^80?oKR005o`0000GogH8000?o0000ommj0?oONP001?oO
NP001?l0003ohW40on9a0?oRL@06o`0000Coi6T000?o0000onMO0?oWG`001?oWG`001?l0003oje<0
on]C0?o[D`06o`0000?okTP000?o0000oo4k0?oa>`001?oa>`000ol0003olc<0oo<c0004oo<c00;o
00001Oo]B`001?l0003okD/0one;0?o]B`02o`000004oln[0?l0003ocj/0o`0000;ocj/000Go0000
olj[0?o>Z`3ocZ/0o`000002olj/0003o`000?oooooooooo013ooooo00?o0000ooooooooool01_oo
ool001Kooooo00?o0000ooooooooool04_ooool2o`0000Oooooo00?o0000ojNm0?nW_@000_nW_@00
0ol0003o^<80okS20003okS200Co00001?nm``000ol0003o`l@0ol?40003ol?40003o`000?o5`P3o
000000;o00000_o5``000ol0003oa/00olK00004olK00004o`000?o8_03ob;`0olRl00Co00001Oo9
^@000ol0003obkH0ol^f0004ol^f00Co00001?o</P000ol0003ocJh0olf^0003olf^0004o`000?o?
Z@3ocjT0olnY00Co00001OoAY@000ol0003odZ00om:P0004om:P00Co00001?oDW0000ol0003oeYH0
omJF0004omJF0004o`000?oHS`3of8l0omR?00Go00001?oJR@000ol0003ogH80omf20004omf20004
o`000?oONP3oggX0ommj00Ko00001?oRLP000ol0003oi6T0onAY0004onAY0004o`000?oWG`3oiel0
onMO00Ko00000ooZE0000ol0003okTP0oni80004oni80003o`000?oa>`3olC/000ColC/000?o0000
oo<c0?oc<`000ol00002oo<c0005o`000?o]B`3okD/0one;0?l000001Oo]B`001?l0003ocj/0oln[
0?l00003oln[0004o`000?o>Z`3ocZ/0o`0000?ocZ`00_l0000@ooooo`;o00002?ooool001Kooooo
00?o0000ooooooooool03oooool3o`0000[ooooo00?o0000ojNm0?nW_@000_nW_@000ol0003o^<80
o`000002o`000003okK10?l0003o_L<000Ko_L<000Co0000ol?40?o3a03o`l@01?l00005olG30003
o`000?o6`03oa/0000?oa/001?l00004olNm0003o`000?o9^@3obKT000?obKT000?o0000ol^f0?o;
]P000ol000000oo:]`3o0000olbb0006olbb0004o`000?o=[P3ocJh0olf^00Go00001?o?Z`000ol0
003odJD0om6U0003om6U0003o`000?oBX03odZ0000?o00000_oBX@000ol0003oe9`0omBL0004omBL
0004o`000?oFUP3oeYH0omJF00Ko00000ooHT0000ol0003ofXT0omZ90004omZ90004o`000?oMPP3o
gH80omf200Ko00001?oON`000ol0003ohW80on9b0004on9b0004o`000?oTJ@3oi6T0onAY00Ko0000
0ooWG`000ol0003ojU@0onYD0004onYD0003o`000?o^B03okTP000CokTP000Co0000oo4k0?oa>`3o
lC/01Ol00006oo<c0003o`000?o]B`3o000000GokD/00_l00002oln[00;o00000_o?Z`001?l0003o
cZ/0olj[0?l00002olj/0004o`000?o>[03ocZ`0o`0000oooooo0_l00008ooooo`005_ooool00ol0
003oooooooooo`0<ooooo`?o00003_ooool6o`0000Go]/4000?o0000okg30?nm``001?nm``04o`00
00Co`L@000?o0000olG30?o5``000oo5``000ol0003oa/00o`000002o`0000?oa/4000?o0000olNm
0?o7_@000oo7_@001?l0003obKT0olVi0?o9^@04o`0000Gob[L000?o0000olbb0?o</P001?o</P04
o`0000?ocJl000?o0000oln[0?o?Z`001?o?Z`001?l0003odJD0om6U0?oAY@04o`0000KodZ4000Co
0000omBL0?oDW03oe9`01_l00004omJG0003o`000?oHT03of90000?of90000Co0000omZ90?oJR@3o
fXT01_l00004omb30003o`000?oON`3ogg/000Cogg/000Co0000on9b0?oRLP3ohW801_l00003onAZ
0003o`000?oWG`3oiel000Coiel000Co0000onYD0?oZE03ojU@03Ol00003oo4k0003o`000?oc<`3o
lc<000Colc<00ol00005one;0005o`000?o]B`3okD/0o`000?o?Z`000_l000000oo?Z`3o0000olj[
0002olj[0004o`000?o>[03ocZ`0o`0000;ocZ`000?o0000ooooooooool03?ooool00ol0003o06@o
o`000008ooooo`005Oooool2o`0000_ooooo0ol0000Booooo`03o`000?nU_@3oYKd000;oYKd000?o
0000okK10?nf`@000onf`@000ol0003o_L<0okg30003o`0000;o^l8000?o0000ol740?o1a0001?o1
a0001?l0003oaL<0olG30?o5``03o`0000Ooa/4000Co0000olNm0?o7_@3oakd01Ol00004olRj0003
o`000?o:]`3ob[L000?ob[L000?o0000olbb0?o</P000ol00002ol^c0003o`000?o=[`3ocJl000?o
cJl000Co0000oln[0?o?Z`3ocj/01_l00004om2V0003o`000?oBX@3odZ4000?odZ401?l00004omBM
0003o`000?oFU`3oeYL000CoeYL000Co0000omR@0?oHT03of9001Ol00004omZ:0003o`000?oLP`3o
g8<000Cog8<000Co0000ommk0?oON`3ogg/01_l00003on5c0003o`000?oTJP3oi6X000Coi6X000Co
0000onMO0?oWG`3oiel01_l00003onYE0003o`000?o]B03okDP000CokDP000?o0000oo4k0?oa>`00
1?oa>`000ol0003olc<0oo<c0003o`0000;olc<000?o0000one;0?o]B`000_o]B`001?l0003okD/0
one;0?o]B`02o`0000;ocj/00_l00002olj[0005o`000?o>[03ocZ`0olj/0?l000000_o>[002o`00
00gooooo00Co0000o`1T?ol0003o00001oooool001Kooooo00?o0000ooooooooool01_ooool3o`00
01Kooooo00?o0000ojFm0?nU_@000_nU_@001?l0003o]/40okK10?nf`@04o`0000Ko^l8000Co0000
ol740?o1a03o`L@01_l00003olG40003o`000?o6`@3oa/4000Coa/401?l00003olNn0003o`000?o8
^P3ob;X000Cob;X000Co0000olZg0?o:]`3ob[L01?l00006ol^c0004o`000?o=[`3ocJl0olf_00Go
00001?o>Z`000ol0003od:H0om2V0004om2V0003o`000?oBX@3o000000;o000000?odZ80o`000?oD
W@001_oDW@001?l0003oeYL0omJG0?oFU`06o`0000?of94000?o0000omZ:0?oJRP001?oJRP001?l0
003og8<0omb30?oLP`06o`0000CogW`000?o0000on5c0?oQL`000ooQL`001?l0003oi6X0onAZ0?oT
JP06o`0000?oif0000?o0000onYE0?oZE@001?oZE@000ol0003okDP0one80004one80004o`000?oa
>`3olC/0oo4k00Go00001_oc<`001?l0003okD/0one;0?l00005one;0005o`000?o?Z`3ocj/0oln[
0?l000000_o>Z`001ol0003ocZ`0olj/0?o>[03o0000olj/0?l000000_o>[@000ol0003ooooooooo
o`0:ooooo`04o`000?l0I3oo0000o`0000Oooooo000Fooooo`03o`000?oooooooooo00?ooooo0ol0
000Jooooo`So00001?nd`@000ol0003o^l80ok_20003ok_200Co00001?no``000ol0003oaL@0olG4
0003olG40003o`000?o6`@3oa/4000?o000000?oa/80o`000?o7_P001Oo7_P001?l0003ob;X0olRj
0?o8^P06o`0000?ob[P000?o0000ol^c0?o;/`001?o;/`04o`0000CocK0000?o0000olj[0?o>Z`00
0oo>Z`001?l0003od:H0om2V0?o@YP04o`0000GodZ8000?o0000omBM0?oDW@001?oDW@04o`0000?o
eYL000?o0000omRA0?oHT@001?oHT@001?l0003ofXX0omZ:0?oJRP06o`0000Cog8@000?o0000omil
0?oNO0001?oNO0001?l0003ohG<0on5c0?oQL`05o`0000?oi6X000?o0000onMP0?oWH0001?oWH000
0ol0003ojUD0onYE0004onYE0004o`000?o]B03okDP0one800Ko00001?oa?0000ol0003olc<0oo<c
0004oo<c0003o`000?o]B`3o000000GokD/000?o0000one;0?l000000_o?Z`02o`000005olj[0?l0
003ocZ`0olj/0?l000000_o>[0001Ol0003ocZd0olj]0?o>[@3o000000[ooooo00?o0000o`1T?ol0
I3l00_l00007ooooo`005Oooool01?l0003oooooooooooooool3o`0001oooooo00?o0000oj>l0?nS
_0000_nS_0000ol0003o]<40okC10003okC10003o`000?nk`P3o000000;o00000oni`P000ol0003o
_l<0oko30003oko30004o`000?o5a03oaL@0olG400Co00001Oo6`P000ol0003oakh0olNn0003olNn
00Co00001?o8^`000ol0003ob[P0olZh0003olZh0003o`000?o;/`3obk<000?o000000?obk@0o`00
0?o=/0001_o=/0001?l0003ocZ/0olj[0?o>Z`05o`0000Cod:L000?o0000om:R0?oBXP000ooBXP00
0ol0003oe9d0omBM0003o`000003om>M0?l0003oeYL000GoeYL000?o0000omRA0?oHT@000ooHT@04
o`0000CofX/000?o0000omb40?oLQ0001?oLQ0001?l0003ogW`0omil0?oNO006o`0000;ohG@000?o
0000onAZ0?oTJP001?oTJP000ol0003oif00onMP0004onMP0004o`000?oZE@3ojUD0onYE00Ko0000
1?o]B@000ol0003olC`0oo4l0004oo4l0004o`000?oc<`3olc<0oo<c00Co00001Oo]B`001?l0003o
kD/0one;0?o]B`02o`000003olj[0?l0003o000000?ocZ`000Co0000olj/0?o>[03o00000oo>[@00
0ol0003oooooooooo`08ooooo`03o`000?l0I3oo06@o00;o00001oooool001Gooooo1?l0000Soooo
o`03o`000?nS_03oXk`000;oXk`000Co0000okC10?nd`@3o]<401?l00006okW20004o`000?no``3o
_l<0oko300Go00001?o3a0000ol0003oa/80olK20003olK20003o`000?o7_P3o000000;o00000oo7
_`000ol0003ob;/0olRk0003olRk0004o`000?o:^03ob[P0olZh00Co00001Oo;]0000ol0003ocK00
olf`0004olf`00Co00000oo>[0000ol0003od:L0om2W0004om2W0004o`000?oBXP3odZ80om:R00Co
00001OoCW@000ol0003oeYL0omJG0004omJG0003o`000?oHT@3o000000;o000000?of980o`000?oJ
R`001_oJR`001?l0003og8@0omb40?oLQ006o`0000?ogW`000?o0000on5d0?oQM0000ooQM0000ol0
003oi6X0onAZ0004onAZ0004o`000?oWH03oif00onMP00Ko00001?oZE@000ol0003okDT0one90004
one90004o`000?oa?03olC`0oo4l00Ko00001?oc<`001Ol0003okD/0one;0?o]B`3o000000GokD/0
00Co0000olj[0?o>Z`3o00000oo>[0001?l0003ocZ`0olj/0?l00002olj]0003o`000?o>[@3o0000
00Sooooo00Co0000o`1T?ol0I3oo06@o0_l00007ooooo`000_ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool3o`0000Cooooo0_l0000Vooooo`So00001?nb`0000ol0003o^L80okW20003okW2
00Co00001?nm``000ol0003o`l@0ol?40003ol?40004o`000?o6`P3oa/80olK200?o00001oo7_`00
1?l0003ob;/0olRk0?o8^`05o`0000CobKP000?o0000ol^d0?o;]0000oo;]0000ol0003ocK00olf`
0003o`0000;ocK4000?o0000olj/0?o>[0000oo>[0001?l0003od:L0om2W0?o@Y`06o`0000?odZ<0
00?o0000om>M0?oCW@001?oCW@001?l0003oeYL0omJG0?oFU`04o`0000Gof98000?o0000omZ;0?oJ
R`001?oJR`04o`0000?og8@000?o0000omil0?oNO0001?oNO0000ol0003ohG@0on5d0003on5d0004
o`000?oTJP3oi6X0onAZ00Ko00001?oWH0000ol0003ojUD0onYE0004onYE0004o`000?o]B@3okDT0
one900Ko00000ooa?0000ol0003olc<0oo<c0005oo<c0003o`000?o]B`3o000000GokD/00_l00002
olj[00;o00000_o>[0000ol0003ocZ`0o`000003olj]0004o`000?o>[@3ocZd0o`0000Kooooo0_l0
0003o`1T?`;o00001oooool00005ooooool0003oooooooooool000002_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Gooooo00?o0000oj6l0?nQ_0000_nQ_0000ol0003o//00ok;0
0003ok;00003o`000?ni`P3o000000;o000000?o]l40o`000?nm``001_nm``001?l0003o`l@0ol?4
0?o3a005o`0000?oaL<000?o0000olNo0?o7_`001?o7_`04o`0000?ob;`000?o0000olVh0?o9^000
1?o9^0001?l0003obk@0ol^d0?o;]004o`0000KocK4000Co0000olj/0?o>[03ocZ`01Ol00004om2X
0003o`000?oBX`3odZ<000?odZ<000Co0000om>M0?oCW@3odid01_l00004omJH0003o`000?oHTP3o
f98000?of98000?o0000omZ;0?oJR`000ol000000ooJR`3o0000omb40005omb40003o`000?oNO03o
gW`000?ogW`000Co0000on5d0?oQM03ohG@01_l00004onA[0003o`000?oWH03oif0000Coif0000Co
0000onYE0?oZE@3ojUD01_l00003one90003o`000?oa?03olC`000ColC`000?o0000oo<c0?oc<`00
1?oc<`02o`0000GokD/000?o0000one:0?o]BP000_l000001?o>[03o0000olj/0?l00002olj/0005
o`000?o>[@3ocZd0olj]0?l000000_o>[@02o`0000Cooooo00?o0000o`1n6?l000000ol0I3l2o`00
00Oooooo00001Ooooooo0000oooooooooooo000000Oooooo1Ol00007ooooo`03o`000?oooooooooo
02Gooooo00?o0000oj6l0?nQ_0000_nQ_0001?l0003o//00ok;00?nb`003o`0000Go]l4000?o0000
okg30?nm``001?nm``04o`0000?o`/@000?o0000olG30?o5``000oo5``000ol0003oakl0olNo0003
o`0000;oa/0000?o0000olRl0?o8_0000oo8_0001?l0003obKP0olVh0?o9^006o`0000?obkD000?o
0000olfa0?o=/@001?o=/@04o`0000?ocZd000?o0000om2X0?o@Z0001?o@Z0001?l0003odZ<0om:S
0?oBX`05o`0000Codih000?o0000omJH0?oFV0001?oFV0001?l0003of980omRB0?oHTP04o`0000Go
fX/000?o0000omb40?oLQ0001?oLQ0001?l0003ogW`0omil0?oNO005o`0000CohG@000?o0000onA[
0?oTJ`001?oTJ`001?l0003oif00onMP0?oWH006o`0000?ojUD000?o0000one90?o]B@001?o]B@00
0ol0003olC`0oo4l0004oo4l0003o`000?oc<`3olc<000?o000000?olc<0o`000?o]B`000oo]B`00
0ol0003okDX0one:0002one:0003o`000?o>[03ocZ`000;o00000_o>[0001?l0003ocZd0olj]0?l0
0003olj]0003o`000?o=[P3o000000;ooooo00Co0000o`1n6?l0OQSo00000ol0I3l00ol0003ooooo
o`000006ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool09Oooool8o`0000?o/<0000?o0000okO10?ng`@000ong`@000ol0003o
_L<0okg30003o`0000;o_<8000?o0000ol;40?o2a0000oo2a0001?l0003oaL<0olG30?o5``04o`00
00Koa/0000Co0000olRl0?o8_03ob;`01Ol00004olVi0003o`000?o;]@3obkD000?obkD000?o0000
olfa0?o=/@000ol000000oo</@3o0000olj]0005olj]0004o`000?o@Z03od:P0om2X00Ko00000ooA
X`000ol0003odih0om>N0004om>N0004o`000?oFV03oeYP0omJH00Ko00000ooGTP000ol0003ofX/0
omZ;0004omZ;0004o`000?oLQ03og8@0omb400Ko00000ooNO0000ol0003ohG@0on5d0004on5d0004
o`000?oTJ`3oi6/0onA[00Ko00000ooWH0000ol0003ojUD0onYE0004onYE0003o`000?o]B@3okDT0
00?okDT000?o0000oo4l0?oa?0000_oa?005o`0000Golc<000Co0000one;0?o]B`3o00001Oo]BP00
1Ol0003ocZ`0olj/0?o>[03o000000;ocZ`000Co0000olj]0?o>[@3o00000_o>[@001_l0003ocJh0
olf^0?l0003oooooo`0000?o07hH00Oo0000o`1T?ol0I3oo06@oo`000?oooooo000000Kooooo0000
1Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooool000002_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?nO_03oWk`000;oWk`000?o0000ok300?n``0000on``0001?l0003o]l40okO1
0?ng`@04o`0000Ko_<8000Co0000ol;40?o2a03o`/@01Ol00004olG30003o`000?o6`03oa/0000?o
a/001?l00004olRm0003o`000?o9^@3obKT000?obKT000Co0000ol^e0?o;]@3obkD01?l00005olba
0003o`000?o>[@3ocZd000?ocZd01?l00004om2X0003o`000?oAX`3odJ<000?odJ<000Co0000om>N
0?oCWP3odih01_l00004omFH0003o`000?oGTP3oei8000?oei8000Co0000omZ;0?oJR`3ofX/01_l0
0003omb40003o`000?oNO03ogW`000CogW`000Co0000on5d0?oQM03ohG@01_l00004onA[0003o`00
0?oWH03oif0000?oif0000Co0000onYE0?oZE@3ojUD03Ol00003oo4k0003o`000?oc<`3olc<000Co
lc<000?o0000one;0?l000001Oo]BP000ol0003okDT0o`000002olj/00?o00000oo>[@001?l0003o
cZd0olj]0?l00002olf^00;o00001?l0OQP01ol0003o06@oo`1T?ol0I3oo0000ooooool000001_oo
ool00005ooooool0003oooooooooool000002Oooool2o`0000_ooooo0_l0000Vooooo`03o`000?nO
_03oWk`000;oWk`000Co0000ok300?n``03o/<001Ol00004okK10003o`000?nl`P3o_<8000?o_<80
1?l00004ol740003o`000?o5``3oaL<000?oaL<000?o0000olK00?l000000_l000000oo6`03o0000
olRm0006olRm0004o`000?o9^@3obKT0olVi00Go00001?o;]@000ol0003oc;40olba0003olba0003
o`000?o>[@3o000000;o00000_o>[@000ol0003od:P0om2X0004om2X0004o`000?oAX`3odJ<0om6S
00Go00001?oCWP000ol0003oeIP0omFH0004omFH0004o`000?oGTP3oei80omNB00Go00001?oJS000
0ol0003og8@0omb40003omb40004o`000?oNO03ogW`0omil00Ko00001?oQM0000ol0003oi6/0onA[
0004onA[0004o`000?oWH03oif00onMP00Go00000ooZE0000ol0003okTP0oni80004oni80003o`00
0?oa>`3olC/000ColC/000Co0000oo<c0?oc<`3olc<01?l00005one:0004o`000?o]B@3okDT0one9
00;o000000?ocZ`0o`000?l000000_o>[@001ol0003ocZd0olj]0?o>[@3o0000olf^0?l000000_o=
[`001Ol0003o07hHo`1n6?l0OQSo000000?o06@o00?o0000ooooool000001_ooool000;ooooo0_l0
000;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09?ooool8o`0000Co[kl000?o
0000okK10?nf`@000onf`@000ol0003o_<80o`000002o`0000;o^l8000?o0000ol740?o1a0001?o1
a0001?l0003oaL<0olG30?o5``03o`0000Goa/0000?o0000olRm0?o8_@001?o8_@04o`0000?obKT0
00?o0000ol^e0?o;]@001?o;]@001?l0003oc;40olba0?o</@03o`0000KocZd000Co0000om2X0?o@
Z03od:P01_l00003om6S0003o`000?oCWP3odih000Codih000Co0000omFH0?oEV03oeIP01_l00003
omNB0003o`000?oJS03ofX`000CofX`000Co0000omb40?oLQ03og8@01Ol00004omil0003o`000?oQ
M03ohG@000CohG@000Co0000onA[0?oTJ`3oi6/01_l00003onMP0003o`000?oZE03ojU@000?ojU@0
00?o0000oni80?o^B0001?o^B0001?l0003olC/0oo4k0?oa>`06o`0000Colc8000Go0000one:0?o]
BP3okDX0o`000004one900;o00000_o>[0001?l0003ocZd0olj]0?l00003olj]0003o`000?o=[P3o
000000;ocJl000Go0000o`1n6?l0OQSo07hHo`000002o`1T?`;o000000?oooooo`000?ooool01Ooo
ool001kooooo00?o0000ooooooooool09Oooool00ol0003oW[/0oijk0002oijk0003o`000?n__`3o
[kl000?o[kl000Co0000okK10?nf`@3o]/400ol00006ok_20004o`000?o1a03o`L@0ol7400Ko0000
0oo5a0000ol0003oa/00olK00003olK00003o`000?o8_@3ob;d000?o00000_o7_@000ol0003obKT0
olVi0003olVi0004o`000?o;]@3obkD0ol^e00Ko00000oo</@000ol0003ocZd0olj]0003olj]00Co
00001?o@Z0000ol0003odJ<0om6S0003om6S0004o`000?oCWP3odih0om>N00Ko00000ooEV0000ol0
003oei80omNB0004omNB0004o`000?oJS03ofX`0omZ<00Ko00000ooLQ0000ol0003ogW`0omil0004
omil0004o`000?oQM03ohG@0on5d00Ko00000ooTJP000ol0003oif00onMP0004onMP0003o`000?oZ
E03ojU@000?ojU@000Co0000oni80?o^B03okTP01_l00004oo4j0003o`000?oc<P3olc8000Colc80
00?o0000one:0?l000001?o]B@000ol0003okTP0o`000002olj/00;o000000GocZd0o`000?o>[@3o
cZd0o`000002olf^0003o`000?o=[`3ocJl000;o00000_l0OQP00ol0003o06@oo`1T?`02o`000003
ooooool0003ooooo00Gooooo000Oooooo`03o`000?oooooooooo02Gooooo00?o0000oijk0?nN^`00
0_nN^`001?l0003o[kl0ojno0?n__`05o`0000?o]L4000?o0000ok_20?nk`P000onk`P04o`0000Co
_l<000?o0000olG40?o5a0000oo5a0001?l0003oa/00olK00?o6`004o`0000Koakd000Co0000olVi
0?o9^@3obKT01Ol00004ol^f0003o`000?o</@3oc;4000?oc;4000?o0000olj]0?l000000_l00002
olj]0003o`000?o@Z03od:P000Cod:P000Co0000om6S0?oAX`3odJ<01Ol00004om>N0003o`000?oE
V03oeIP000?oeIP000Co0000omNB0?oGTP3oei801_l00004omZ;0003o`000?oLQ03og8@000?og8@0
00Co0000omil0?oNO03ogW`01_l00003on5c0003o`000?oTJP3oi6X000Coi6X000Co0000onMP0?oW
H03oif003?l00004oni70003o`000?oa>P3olCX000ColCX000Co0000oo<b0?oc<P3olc801?l00004
one90004o`000?o^B03okTP0oni800;o00000_o>[@001Ol0003ocZd0olj]0?o>[@3o000000;ocJh0
00?o0000olf_0?l000000_o=/0000ol0003o07hHo`000002o`1T?`;o00000_ooool00ol0003ooooo
ooooo`03ooooo`008?ooool2o`0002Kooooo2?l00003ojjo0003o`000?ne`@3o]L4000?o]L4000?o
0000ok_20?l000000_l00003ok[20003o`000?no``3o_l<000?o_l<000Co0000olG40?o5a03oaL@0
1Ol00004olK10003o`000?o7_@3oakd000?oakd01?l00003olVj0003o`000?o;]P3obkH000CobkH0
00Co0000olba0?o</@3oc;400ol00006olj]0003o`000?o@Z03od:P000?od:P01?l00003om6T0003
o`000?oCWP3odih000Codih000Co0000omFH0?oEV03oeIP01Ol00004omNB0003o`000?oJR`3ofX/0
00CofX/000Co0000omb40?oLQ03og8@01Ol00004omil0003o`000?oQL`3ohG<000?ohG<000Co0000
onAZ0?oTJP3oi6X01_l00003onMO0003o`000?oZE03ojU@000CojU@000?o0000oni70?o^A`001?o^
A`001?l0003olCX0oo4j0?oa>P06o`0000?om30000Go0000one90?o]B@3okDT0o`000005oni80004
o`000?o>[@3ocZd0o`0000?ocZd000?o0000olf^0?l000000_o=[`002_l0003ocK00olf`0?l0003o
07hHo`000?l0I3oo0000ocRN0?l00002ooooo`03o`000?oooooooooo00?ooooo000Rooooo`03o`00
0?oooooooooo02Cooooo00?o0000oifk0?nM^`000_nM^`000ol0003o[[l0ojjo0003ojjo0004o`00
0?ne`@3o]L40okG100Co00001_nj`P001?l0003o_l<0oko30?no``05o`0000?oaL@000?o0000olK1
0?o6`@001?o6`@000ol0003oakd0o`000002o`0000;oakd000?o0000olVj0?o9^P000oo9^P001?l0
003obkH0ol^f0?o;]P06o`0000?oc;8000?o0000olj]0?o>[@001?o>[@000ol0003od:P0o`000002
o`0000;ocjT000?o0000om6T0?oAY0000ooAY0001?l0003odih0om>N0?oCWP06o`0000?oeIP000?o
0000omNB0?oGTP001?oGTP001?l0003ofX/0omZ;0?oJR`06o`0000?og8@000?o0000omil0?oNO000
1?oNO0001?l0003ohG<0on5c0?oQL`05o`0000?oi6T000?o0000onMO0?oWG`001?oWG`000ol0003o
jU@0onYD0004onYD0004o`000?o^A`3okTL0oni700Ko00000oob>@000ol0003om300oo@`0004oo@`
0003o`000?o]B@3o000000GokTP00_l00002olj]00;o000000GocZd0o`000?o=[P3ocJh0o`000002
olf_0003o`000?o=/03ocK0000?o000000Co06@oo`000?lhWP3o00000_ooool00ol0003ooooooooo
o`03ooooo`008oooool00ol0003oooooooooo`0Tooooo`03o`000?nM^`3oWK/000;oWK/000Co0000
ojjo0?n^_`3o[[l01Ol00004okC10003o`000?nj`P3o^/8000?o^/801?l00003oko30003o`000?o5
a03oaL@000?oaL@000Co0000olK10?o6`@3oa/401?l00006olNm0004o`000?o9^P3obKX0olVj00Go
00001?o:]P000ol0003oc;80olbb0003olbb0004o`000?o>[@3ocZd0olj]00Co00001_o?Z@001?l0
003odJ@0om6T0?oAY005o`0000Codih000?o0000omFH0?oEV0000ooEV0001?l0003oei80omNB0?oG
TP06o`0000?ofX/000?o0000omb40?oLQ0001?oLQ0001?l0003ogW`0omil0?oNO006o`0000?ohG<0
00?o0000onAY0?oTJ@000ooTJ@000ol0003oiel0onMO0004onMO0004o`000?oZE03ojU@0onYD00Ko
00000oo^AP000ol0003olST0oo8i0004oo8i0003o`000?od<03om30000?om3000_l00005oni80003
o`000?o^A`3okTL000;o00000_o>[@02o`0000;ocJh000Ko0000olf_0?o=[`3o0000olf`0?l00002
olbb00Go00000_ooool00ol0003oooooooooo`03ooooo`009?ooool00ol0003oooooooooo`0Toooo
o`So00001?n]_`000ol0003o]<40okC10003okC10003o`000?nj`P3o000000;o00000_ni`P000ol0
003o_l<0oko30003oko30004o`000?o5a03oaL@0olG400Go00001?o6`@000ol0003oakd0olNm0003
olNm00Co00000oo9^P000ol0003ob[H0olZf0004olZf0004o`000?o</P3oc;80olbb00Go00001?o>
[@000ol0003ocjT0olnY0003olnY00Co00000ooAY0000ol0003odih0om>N0004om>N0004o`000?oE
V03oeIP0omFH00Go00001?oHTP000ol0003ofX/0omZ;0003omZ;0004o`000?oLQ03og8@0omb400Ko
00000ooON`000ol0003ohG<0on5c0004on5c0003o`000?oTJ@3oi6T000?oi6T000Co0000onMO0?oW
G`3oiel01_l00003on]B0003o`000?o^AP3okTH000CokTH000?o0000oo8i0?ob>@000oob>@000ol0
003om300oo@`0003o`000003oo@_0?l0003okTP000?okTP000?o0000oni70?o^A`000_o^A`000ol0
003ocZd0olj]0002o`0000;ocJh000?o0000olf_0?l000000_o=/0002?l0003oc;80olbb0?l0003o
bKT0o`000?n/_P3o00000_ooool00ol0003oooooooooo`03ooooo`009Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?nL^`3oW;/000;oW;/000?o0000ojfo0?n]_`000on]_`001?l0003o]<40okC1
0?nd`@03o`0000Ko^L8000Co0000oko30?no``3o_l<01Ol00004olC40003o`000?o6`@3oa/4000?o
a/4000?o0000olNm0?l000000_l00002olNn0003o`000?o9^P3obKX000?obKX000Co0000olZf0?o:
]P3ob[H01_l00003olbb0003o`000?o>[@3ocZd000CocZd000?o0000olnY0?l000000_l000000oo?
Z03o0000om6T0005om6T0004o`000?oCWP3odih0om>N00Ko00000ooEV0000ol0003of980omRB0004
omRB0004o`000?oJR`3ofX/0omZ;00Go00001?oLP`000ol0003ogg/0ommk0003ommk0004o`000?oQ
L`3ohG<0on5c00co00000ooWGP000ol0003oje80on]B0004on]B0003o`000?o^AP3okTH000?okTH0
00Co0000oo8i0?ob>@3olST01Ol00005oo@_0004o`000?o^B03okTP0o`0000GokTL00_l00002olj]
0003o`000?o=[P3o000000;ocJl000Co0000olf`0?o=/03o00000_o</P001Ol0003obKT0o`000?n/
_P3o000000;ooooo00?o0000ooooooooool00oooool002Kooooo0_l0000Vooooo`03o`000?nL^`3o
W;/000;oW;/000Co0000ojfo0?n]_`3o[Kl01Ol00003ok?00003o`000?ni`P3o^L8000?o^L801?l0
0003okk30003o`000?o4a03oa<@000Coa<@000Co0000olK10?o6`@3oa/400ol00006olNn0004o`00
0?o9^P3obKX0olVj00Go00001?o:]P000ol0003oc;80olbb0003olbb0004o`000?o>[@3ocZd0olj]
00Co00001Oo?Z0000ol0003odJ@0om6T0003om6T00Co00001?oCWP000ol0003oeIP0omFH0003omFH
0004o`000?oHTP3of980omRB00Ko00000ooJR`000ol0003og8<0omb30004omb30004o`000?oON`3o
gg/0ommk00Go00000ooRLP000ol0003oi6P0onAX0003onAX0003o`000?oWGP3oieh000Coieh000Co
0000on]B0?o[DP3oje803?l00004oo8g0003o`000?od;`3om2l000?om2l000?o0000oni80?l00000
1Oo^A`000ol0003okTD0oni50002o`000003olf^0?l0003o000000;ocJl000Co0000olf`0?o=/03o
00000_o</P001?l0003obKT0o`000?l00003ooooo`03o`000?oooooooooo00?ooooo000Xooooo`03
o`000?oooooooooo02Cooooo2?l00003ojbo0003o`000?nc`03o/l0000?o/l0000?o0000okW20?l0
00000_l00002okS20003o`000?nn``3o_/<000?o_/<000Co0000olC40?o4a03oa<@01_l00003olK1
0003o`000?o7_P3oakh000?oakh01?l00004olVj0003o`000?o:]P3ob[H000?ob[H000Co0000olbb
0?o</P3oc;801Ol00003olj]0003o`000?o?Z03ocjP000CocjP000?o0000om6T0?l000000_l00002
om6S0003o`000?oCWP3odih000Codih000Co0000omFH0?oEV03oeIP01Ol00003omRA0003o`000?oJ
R`3ofX/000CofX/000Co0000omb30?oLP`3og8<01_l00002ommj0003o`000?oRLP3ohW8000CohW80
00?o0000onAX0?oTJ0000ooTJ0001?l0003oieh0onMN0?oWGP06o`0000Coje4000?o0000onm40?o_
A0000oo_A0000ol0003olSL0oo8g0004oo8g0004o`000?od;`3om2l0oo@_00?o00001Oo^A`000ol0
003okTD0oni50002oni50004o`000?o=[P3ocJh0o`0000;ocJl000?o0000olf`0?l000000_o</P00
0ol0003obKT0olVi0002o`0000Cooooo00?o0000ooooooooool00_ooool002Wooooo00?o0000oooo
ooooool09?ooool00ol0003oVk/0oi^k0002oi^k0003o`000?n/_`3o[;l000?o[;l000Co0000ok?0
0?nc`03o/l000ol00006okS20004o`000?nn``3o_/<0okk300Go00001?o4a0000ol0003oa/40olK1
0003olK10003o`000?o7_P3o000000;o00000_o7_P000ol0003obKX0olVj0004olVj0004o`000?o:
]P3ob[H0olZf00Go00000oo</P000ol0003ocZd0olj]0003olj]0004o`000?o?Z03ocjP0olnX00Co
00001_oAX`001?l0003odih0om>N0?oCWP06o`0000?oeYP000?o0000omRA0?oHT@000ooHT@001?l0
003ofX/0omZ;0?oJR`06o`0000?og8<000?o0000ommj0?oONP000ooONP000ol0003ohW80on9b0004
on9b0004o`000?oTJ03oi6P0onAX00Go00001?oXG0000ol0003oje40on]A0004on]A0003o`000?o_
A03okd@000?okd@000Co0000oo8g0?ob=`3olSL01_l00003ooD/0005o`000?o^A`3okTL0oni70?l0
00001?o^A@02o`0000;ocJh000Ko0000olf_0?o=[`3o0000olf`0?l00002olbb0005o`000?o9^@3o
0000ojbn0?l000001?ooool00ol0003oooooooooo`02ooooo`00:_ooool00ol0003oooooooooo`0T
ooooo`03o`000?nK^`3oVk/000;oVk/000Co0000ojbo0?n/_`3o[;l01Ol00003ok?00003o`000?nh
`P3o^<8000?o^<801?l00004okk30003o`000?o4a03oa<@000?oa<@000Co0000olK10?o6`@3oa/40
0ol00006olNn0004o`000?o9^P3obKX0olVj00Ko00000oo:]P000ol0003oc;80olbb0003olbb0004
o`000?o>[@3ocZd0olj]00Go00001?o@Z0000ol0003odJ<0om6S0003om6S00Co00000ooCW@000ol0
003oeYP0omJH0004omJH0004o`000?oHT@3of940omRA00Go00001?oJRP000ol0003og8<0omb30003
omb30003o`000?oONP3oggX000?oggX000Co0000on9b0?oRLP3ohW801_l00003onEW0003o`000?oX
G03oj5`000Coj5`000Co0000on]A0?o[D@3oje403?l00003oo<d0003o`000?oe;03omB`000ComB`0
00?o0000oni70?l000001?o^A@000ol0003okd<0onm30002o`000003olf_0?l0003o000000;ocK00
00So0000olbb0?o</P3o0000olVi0?l0003o[;h0o`0000Cooooo00?o0000ooooooooool00_ooool0
02_ooooo0_l0000Uooooo`So00000on/_P000ol0003o/l00ok?00003ok?00003o`000?nh`P3o0000
00;o00000onh`P000ol0003o_/<0okk30003okk30004o`000?o4a03oa<@0olC400Go00000oo6`@00
0ol0003oakh0olNn0003olNn00Co00001?o9^P000ol0003ob[H0olZf0003olZf0004o`000?o</P3o
c;80olbb00Go00000oo>[@000ol0003od:P0om2X0004om2X0003o`000?oAX`3o000000;o000000?o
dZ<0o`000?oCW@001OoCW@001?l0003oeYP0omJH0?oFV006o`0000?of94000?o0000omZ:0?oJRP00
1?oJRP001?l0003og8<0omb30?oLP`0;o`0000?ohW4000?o0000onEW0?oUI`001?oUI`001?l0003o
j5`0onQL0?oXG006o`0000?ok4l000?o0000onm20?o_@P000oo_@P000ol0003olc@0oo<d0004oo<d
0004o`000?oe;03omB`0ooD/00Co00001?o^A@000ol0003okd<0onm30002onm30004o`000?o=[`3o
cJl0o`0000;ocK0000Go0000olbb0?o</P3o0000olVi0002o`0000Gooooo00?o0000ooooooooool0
0_ooool002gooooo00?o0000ooooooooool08oooool00ol0003oVkX0oi^j0002oi^j0003o`000?n/
_P3o[;h000?o[;h000Co0000ok?00?nc`03o/l001?l00006okS20004o`000?nn``3o_/<0okk300Go
00000oo4a0000ol0003oa/40olK10003olK10003o`000?o7_P3o000000;o00000_o7_P000ol0003o
bKX0olVj0004olVj0004o`000?o:]P3ob[H0olZf00Go00000oo</P000ol0003ocZd0olj]0003olj]
0004o`000?o@Z03od:P0om2X00Co00001OoBX`000ol0003odid0om>M0003om>M00Co00001?oFU`00
0ol0003of940omRA0003omRA0004o`000?oJRP3ofXX0omZ:00Ko00000_oMPP000ol0003oggT0ommi
0004ommi0003o`000?oRL@3ohW4000?ohW4000Co0000onEW0?oUI`3oiFL01_l00003onQK0003o`00
0?o/C`3ok4l000Cok4l000?o0000onm20?o_@P000oo_@P001?l0003olc@0oo<d0?oc=006o`0000?o
mRT000Go0000oni50?o^A@3okTD0o`000005onm30003o`000?o=[`3ocJl000;o000000KocK00o`00
0?o</P3oc;80o`000?o9^@02o`0000Gooooo00?o0000ooooooooool00_ooool002kooooo00?o0000
ooooooooool08oooool00ol0003oVkX0oi^j0002oi^j0004o`000?n/_P3o[;h0ojbn00Go00001?nb
`002o`0000?o^<801Ol00003okk30003o`000?o4a03oa<@000?oa<@000Co0000olK10?o6`@3oa/40
1?l00005olNn0004o`000?o9^P3obKX0olVj00Ko00000oo;]P000ol0003oc;80olbb0003olbb0004
o`000?o>[@3ocZd0olj]00Go00001?o@Z0000ol0003odZ<0om:S0003om:S0003o`000?oCW@3o0000
00;o00000_oDW@000ol0003oeYL0omJG0004omJG0004o`000?oHT@3of940omRA00Go00000ooJR@00
0ol0003ogH80omf20003omf20003o`000?oON@3oggT000CoggT000Co0000on9a0?oRL@3ohW401Ol0
0004onEU0003o`000?oXF`3oj5/000?oj5/000?o0000ona?0?o/C`000oo/C`001?l0003okd80onm2
0?o_@P06o`0000?olc8000?o0000ooHY0?of:@001?of:@000ol0003okTD0o`000005onm30004o`00
0?o_@@3o0000olf_00?o00000_o</P000ol0003obKT0olVi0002o`0000Gooooo00?o0000oooooooo
ool00_ooool002oooooo00?o0000ooooooooool08oooool8o`0000Co[;h000?o0000ok;00?nb`000
0onb`004o`0000?o^<8000?o0000okk30?nn``000onn``001?l0003oa<@0olC40?o4a005o`0000Co
a/4000Co0000olNn0?o7_P3oakh01Ol00004olVj0003o`000?o;]P3obkH000?obkH000Co0000olbb
0?o</P3oc;801Ol00003olj]0003o`000?o@Z03od:P000Cod:P000Co0000om:S0?oBX`3odZ<00ol0
0006omBM0004o`000?oFU`3oeYL0omJG00Ko00000ooHT0000ol0003ofXT0omZ90003omZ90003o`00
0?oMPP3ogH8000?ogH8000Co0000ommi0?oON@3oggT01_l00003on=_0003o`000?oUI@3oiFD000Co
iFD000Co0000onQK0?oXF`3oj5/02ol00003oo0o0003o`000?oc<P3olc8000Colc8000?o0000ooHY
0?of:@000oof:@02o`0000Gokd<000?o0000onm10?o_@@000_l00002olf`0008o`000?o</P3oc;80
o`000?o9^@3o0000ojbn0?l00005ooooo`03o`000?oooooooooo00;ooooo000`ooooo`03o`000?oo
oooooooo02Cooooo00?o0000oiZj0?nJ^P000_nJ^P000ol0003o[;h0ojbn0003ojbn0003o`000?nb
`03o000000;o00000_nb`0000ol0003o^<80okS20003okS20004o`000?nn``3o_/<0okk300Go0000
0oo4a0000ol0003oa/40olK10003olK100Co00000oo7_@000ol0003obKX0olVj0004olVj0004o`00
0?o;]P3obkH0ol^f00Go00000oo</@000ol0003ocZd0olj]0003olj]0004o`000?o@Z03od:P0om2X
00Ko00000ooBXP000ol0003oe9d0omBM0003omBM00Co00000ooFUP000ol0003of900omR@0004omR@
0003o`000?oJR@3ofXT000;ofXT000Co0000omf20?oMPP3ogH801_l00003on1h0003o`000?oSK`3o
hfl000Cohfl000Co0000onEU0?oUI@3oiFD01_l00002onUI0003o`000?o/C@3ok4d000Cok4d000?o
0000oo0o0?o`?`000oo`?`000ol0003olc80oo<b0003oo<b0003o`000?of:@3omRT000?o00000_of
9P001Ol0003okd<0onm30?o_@`3o000000Cokd4000?o0000olf`0?o=/0000_l000000oo</P3o0000
olVi0002o`0000Oooooo00?o0000ooooooooool00Oooool0037ooooo0_l0000Uooooo`03o`000?nJ
^P3oV[X000;oV[X000Co0000ojbn0?n/_P3o[;h00ol00006ok;00004o`000?nh`P3o^<80okS200Go
00000onn``000ol0003oa<@0olC40003olC40003o`000?o6`@3o000000;o00000_o6`@000ol0003o
akd0olNm0003olNm0004o`000?o9^P3obKX0olVj00Ko00000oo;]P000ol0003oc;40olba0003olba
0004o`000?o>[@3ocZd0olj]00Go00000oo@Y`000ol0003odZ80om:R0004om:R0003o`000?oDW@3o
000000;o00000_oDW0000ol0003oeYH0omJF0003omJF0004o`000?oHT03of900omR@00_o00001?oM
P0000ol0003oh7P0on1h0003on1h0004o`000?oSK`3ohfl0on=_00Ko00000ooVH`000ol0003ojET0
onUI0003onUI0003o`000?o/C@3ok4d000Cok4d000Co0000oo0o0?o`?`3ol3l02_l00006ooHV0003
o`000?o_@`3o000000Gokd4000?o0000olf`0?o=/0000_l000000oo</P3o0000olVi0002o`0000Oo
oooo00?o0000ooooooooool00Oooool003?ooooo00?o0000ooooooooool08oooool8o`0000?oZkh0
00?o0000ok;00?nb`0000onb`004o`0000?o^<8000?o0000okk30?nn``000onn``001?l0003oa<@0
olC40?o4a003o`0000Koa/4000Co0000olNm0?o7_@3oakd01Ol00004olVj0003o`000?o;]P3obkH0
00?obkH000Co0000olba0?o</@3oc;401Ol00003olj/0003o`000?o@Y`3od:L000?od:L000Co0000
om:R0?oBXP3odZ801?l00006omBL0004o`000?oFUP3oeYH0omJF00Go00000ooIS`000ol0003ofhP0
om^80003om^80003o`000?oMP03ogH0000CogH0000Co0000on1h0?oPN03oh7P01Ol00003on=]0003
o`000?oVH`3oiV<000CoiV<000?o0000onUI0?oYF@000ooYF@001?l0003ok4d0ona=0?o/C@06o`00
00;olC`000?o0000oo@^0?od;P001?od;P000ol0003omRH0ooHV0004ooHV00;o00001Oo_@@001?l0
003ol3l0o`000?l00002olbb00;o000000?obKT0o`000?l000001oooool00ol0003oooooooooo`01
ooooo`00=?ooool00ol0003oooooooooo`0Tooooo`05o`000?nJ^P3oV[X0oiZj0?l000001On[_P00
0ol0003o//00o`000002o`0000;o//0000?o0000okS20?nh`P000onh`P001?l0003o_/<0okk30?nn
``05o`0000?oa<@000?o0000olK10?o6`@000oo6`@04o`0000?oakd000?o0000olVj0?o9^P001?o9
^P001?l0003obkH0ol^f0?o;]P05o`0000?oc;4000?o0000olj/0?o>[0000oo>[0001?l0003od:L0
om2W0?o@Y`05o`0000CodZ8000?o0000omBL0?oDW0000ooDW004o`0000;oeYD000?o0000omV?0?oI
S`001?oIS`000ol0003ofhP0om^80003om^80004o`000?oMP03ogH00omf000Ko00000ooPMP000ol0
003ohfd0on=]0003on=]0004o`000?oVH`3oiV<0onIS00co00000oo]BP000ol0003olC`0oo4l0003
oo4l0003o`000?od;P3om2h000Com2h000?o0000ooHV0?of9P000ol000000oog8P3o0000onm10003
onm10005o`000?o`?`3ol3l0oo0o0?l000000oo</P001?l0003obKT0o`000?l00007ooooo`03o`00
0?oooooooooo007ooooo000eooooo`03o`000?oooooooooo02Cooooo1Ol00003oj^n00Co00001Onb
`0001?l0003o^<80okS20?nh`P05o`0000?o_/<000?o0000olC40?o4a0000oo4a0000ol0003oa/40
o`000002o`0000;oa/4000?o0000olNm0?o7_@000oo7_@001?l0003obKX0olVj0?o9^P06o`0000?o
bkD000?o0000olba0?o</@000oo</@001?l0003ocZ`0olj/0?o>[005o`0000?od:L000?o0000om:R
0?oBXP001?oBXP000ol0003oe9`0o`000002o`0000;oe9/000?o0000omJE0?oFU@000_oFU@000ol0
003ofHl0omV?0003omV?0004o`000?oKR03ofhP0om^800Ko00000ooNOP000ol0003oh7H0on1f0004
on1f0004o`000?oSK@3ohfd0on=]00Go00000ooWH@000ol0003ojUH0onYF0003onYF0003o`000?o]
BP3okDX000CokDX000?o0000oo4l0?oa?0000ooa?0001?l0003om2h0oo@^0?od;P05o`0000Gomb80
00Co0000onm10?o_@@3o00001?o`?`02o`000003olbb0?l0003obKT000;o00002?ooool00ol0003o
ooooooooo`01ooooo`00=_ooool2o`0002Gooooo00?o0000oiZj0?nJ^P001?l00004oj^n0004o`00
0?nb`03o//00ok;000Go00000onh`P000ol0003o_/<0okk30003okk30004o`000?o4a03oa<@0olC4
00Co00001Oo6`@001?l0003oakd0olNm0?o7_@05o`0000?obKT000?o0000ol^e0?o;]@001?o;]@00
1?l0003oc;40olba0?o</@05o`0000?ocZ`000?o0000om2W0?o@Y`000oo@Y`001?l0003odZ80om:R
0?oBXP04o`0000Koe9/000?o0000omJE0?oFU@000_oFU@001?l0003ofHl0omV?0?oIS`05o`0000Co
fhH000?o0000omin0?oNOP000ooNOP001?l0003oh7H0on1f0?oPMP06o`0000?oi6/000?o0000onMQ
0?oWH@000ooWH@000ol0003ojUH0onYF0003onYF0004o`000?o]BP3okDX0one:00co00000ooe:P00
0ol0003omb80ooLR0004ooLR0003o`000?o_@@3o000000Col3l000?o0000oo0m0?o`?@000_l00000
0oo9^@3o0000o`000008ooooo`03o`000?oooooooooo007ooooo000hooooo`03o`000?oooooooooo
02?ooooo00?o0000oiZj0?nJ^P000_nJ^P001?l0003oZkh0oj^n0?n[_P05o`0000?o//0000?o0000
okS20?nh`P000onh`P001?l0003o_/<0okk30?nn``05o`0000Coa<@000Co0000olK10?o6`@3oa/40
1Ol00003olRm0003o`000?o9^@3obKT000?obKT000Co0000ol^e0?o;]@3obkD01_l00003olf`0003
o`000?o>[03ocZ`000?ocZ`000Co0000om2W0?o@Y`3od:L01Ol00004om:Q0004o`000?oDV`3oe9/0
omBK00_o00000ooIS@000ol0003ofhH0om^60004om^60004o`000?oNOP3ogWh0omin00Go00000ooQ
M0000ol0003oi6/0onA[0004onA[0004o`000?oWH@3oif40onMQ00_o00000oo^AP000ol0003olCT0
oo4i0003oo4i0003o`000?oe:P3omBX000ComBX000Co0000ooLR0?og8P3omb801?l00004oo0o0003
o`000?o`?@3ol3d000;ol3d01?l00009ooooo`7o00000Oooool1ooooo`00>Oooool00ol0003ooooo
ooooo`0Sooooo`So00000on/_P000ol0003o//00ok;00003ok;00004o`000?nh`P3o^<80okS200Go
00000ono``000ol0003oa<@0olC40003olC400Co00000oo6`@000ol0003ob;d0olRm0003olRm0004
o`000?o9^@3obKT0olVi00Go00000oo;]0000ol0003ocK00olf`0004olf`0004o`000?o>[03ocZ`0
olj/00Go00000oo@YP000ol0003odZ40om:Q0003om:Q00Co00000ooEVP000ol0003oei@0omND0004
omND0003o`000?oIS@3ofHd000;ofHd000Co0000om^60?oKQP3ofhH01_l00003omim0003o`000?oQ
M03ohG@000?ohG@000Co0000onA[0?oTJ`3oi6/01_l00002onMN0003o`000?o[D`3oje<000Coje<0
00?o0000oni60?o^AP000oo^AP000ol0003olCT0oo4i0003oo4i0004o`000?oe:P3omBX0ooDZ00Ko
00000ooh7P001Ol0003ol3l0oo0o0?o`?`3o000000Col3d000Ko0000onm20?o_@P3o0000ooooool0
0008ooooo`7o00000Oooool1ooooo`00>_ooool00ol0003oooooooooo`0Sooooo`03o`000?nK^P3o
VkX000;oVkX000?o0000ojbn0?n/_P000on/_P001?l0003o//00ok;00?nb`005o`0000?o^L8000?o
0000oko30?no``000ono``000ol0003oa<@0o`000002o`0000;oaL@000?o0000olK10?o6`@000oo6
`@001?l0003ob;d0olRm0?o8_@05o`0000?obKT000?o0000ol^d0?o;]0000oo;]0001?l0003ocK00
olf`0?o=/006o`0000?ocj/000?o0000om2V0?o@YP000oo@YP000ol0003odZ40o`000002o`0000;o
dil000?o0000omFJ0?oEVP000ooEVP001?l0003oei@0omND0?oGU00;o`0000?og8@000?o0000omim
0?oNO@001?oNO@001?l0003ohG@0on5d0?oQM005o`0000?oi6P000?o0000onMN0?oWGP000ooWGP00
0ol0003oje<0on]C0004on]C0004o`000?o^AP3okTH0oni600_o00000oof9P000ol0003on1h0ooPN
0004ooPN0003o`000?o`?`3o000000Col3d000Oo0000onm20?o_@P3okd80o`000?oooooo000000So
oooo0Ol00001ooooo`7ooooo000kooooo`03o`000?oooooooooo02?ooooo00?o0000oi^j0?nK^P00
0_nK^P001?l0003o[;h0ojbn0?n/_P05o`0000?o/l0000?o0000okW20?ni`P000oni`P001?l0003o
_l<0oko30?no``04o`0000GoaL@000Co0000olK10?o6`@3oa/401Ol00003olRl0003o`000?o9^@3o
bKT000?obKT000Co0000ol^d0?o;]03obk@01Ol00003olf_0003o`000?o?Z`3ocj/000Cocj/000Co
0000om2V0?o@YP3od:H01?l00005om>O0004o`000?oEVP3oeIX0omFJ00Go00000ooGTP000ol0003o
fX`0omZ<0003omZ<0003o`000?oLQ03og8@000?og8@000Co0000omim0?oNO@3ogWd01_l00003on9b
0003o`000?oTJ03oi6P000?oi6P000?o0000onMN0?oWGP000ooWGP001?l0003oje<0on]C0?o[D`06
o`0000;okd<000?o0000oo<d0?oc=0000ooc=0000ol0003omRH0ooHV0004ooHV0003o`000?oh7P3o
n1h000?on1h00_l00004oo0m0005o`000?o_@P3okd80onm20?l000000oooool00ol0003ooooooooo
o`05ooooo`7o00000Oooool1ooooo`00??ooool2o`0002Cooooo2?l00003ojbo0003o`000?nc`03o
/l0000?o/l0000Co0000okW20?ni`P3o^L801Ol00004oko30004o`000?o5a03oaL@0olG400Go0000
0oo6`0000ol0003ob;`0olRl0003olRl0004o`000?o9^@3obKT0olVi00Go00000oo;]0000ol0003o
cJl0olf_0003olf_0004o`000?o?Z`3ocj/0oln[00Ko00001?oAY@001?l0003odil0om>O0?oCW`05
o`0000?oeIP000?o0000omNB0?oGTP000ooGTP000ol0003ofX`0omZ<0003omZ<0004o`000?oLQ03o
g8@0omb400Go00000ooONP000ol0003ohW80on9b0004on9b0004o`000?oTJ03oi6P0onAX00_o0000
0oo/C`000ol0003okd<0onm30003onm30003o`000?oc=03olc@000?olc@000?o0000ooHV0?of9P00
0oof9P000ol0003on1h0ooPN0003o`000003ooTJ0?l0003ol3d000;ol3d000Go0000onm20?o_@P3o
kd80o`000005ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000nooooo`03o`00
0?oooooooooo02?ooooo00Go0000oi^j0?nK^P3oVkX0o`000005ojbo0004o`000?nc`03o/l00ok?0
00Go00000oni`P000ol0003o_l<0oko30003oko300Co00000oo5``000ol0003oa/00olK00003olK0
0004o`000?o8_03ob;`0olRl00Go00000oo:^0000ol0003obk@0ol^d0003ol^d0004o`000?o=[`3o
cJl0olf_00Go00001?o?ZP001?l0003odJD0om6U0?oAY@06o`0000?odih000?o0000omFH0?oEV000
0ooEV0001?l0003oei80omNB0?oGTP0;o`0000?og88000?o0000ommj0?oONP000ooONP001?l0003o
hW80on9b0?oRLP06o`0000?oiFH000?o0000onQK0?oXF`000_oXF`000ol0003ok4l0ona?0004ona?
0003o`000?o_@`3okd<000?okd<000Co0000oo<d0?oc=03olc@02_l00005ooTJ0003o`000?o`?@3o
000000?okd8000?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1
ooooo`00?oooool00ol0003oooooooooo`0Sooooo`05o`000?nK^P3oVkX0oi^j0?l000000on/_`05
o`0000?o]<4000?o0000okW20?ni`P000oni`P000ol0003o_l<0o`000002o`0000;o`<<000?o0000
olG30?o5``000oo5``001?l0003oa/00olK00?o6`005o`0000?ob;`000?o0000olZh0?o:^0000oo:
^0001?l0003obk@0ol^d0?o;]005o`0000CocJh000Co0000olnZ0?o?ZP3ocjX01Ol00003om6T0003
o`000?oCWP3odih000Codih000Co0000omFH0?oEV03oeIP01Ol00003omR@0003o`000?oJRP3ofXX0
00;ofXX000?o0000omb20?oLPP001?oLPP001?l0003oggX0ommj0?oONP05o`0000?ohVl000?o0000
onEV0?oUIP001?oUIP000ol0003oj5/0onQK0002onQK0004o`000?o/C`3ok4l0ona?00co00000ood
<0000ol0003on240ooPQ0003ooPQ0003o`000?oi6P3onAX000?onAX00_l00003onm20003o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool0043ooooo00?o0000
ooooooooool08oooool7o`0000?o[Kl000?o0000okC10?nd`@000ond`@001?l0003o^L80okW20?ni
`P04o`0000Go`<<000Co0000olG30?o5``3oaL<01Ol00003olNo0003o`000?o8_03ob;`000?ob;`0
00Co0000olZh0?o:^03ob[P01Ol00004olbc0004o`000?o=[P3ocJh0olf^00Go00000oo?Z0000ol0
003odJ@0om6T0003om6T0004o`000?oCWP3odih0om>N00Ko00000ooFU`000ol0003of900omR@0003
omR@0003o`000?oJRP3ofXX000;ofXX000Co0000omb20?oLPP3og8801_l00003on1h0003o`000?oR
K`3ohVl000?ohVl000Co0000onEV0?oUIP3oiFH02ol00003one<0003o`000?o`?P3ol3h000?ol3h0
00?o0000oo@`0?od<0001?od<0000ol0003on240ooPQ0003ooPQ0003o`000?oi6P3o000000;o0000
0_oi6`000ol0003okd80o`00000:ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00@Ooo
ool2o`0002Cooooo0_l00002oibk0003o`000?n]_`3o[Kl000?o[Kl000Co0000okC10?nd`@3o]<40
1Ol00004ok[20004o`000?o0``3o`<<0ol3300Go00000oo5``000ol0003oakl0olNo0003olNo0004
o`000?o8_03ob;`0olRl00Go00000oo:]`000ol0003oc;<0olbc0003olbc00Co00000oo>[@000ol0
003ocjP0olnX0003olnX0004o`000?oAY03odJ@0om6T00Go00000ooDW@000ol0003oeYL0omJG0004
omJG0004o`000?oHT03of900omR@00[o00000ooMP0000ol0003oh7P0on1h0004on1h0004o`000?oR
K`3ohVl0on9_00Go00000ooVHP000ol0003ojEP0onUH0003onUH0003o`000?o]C03okD`000?okD`0
00?o0000oo0n0?o`?P000oo`?P001?l0003om300oo@`0?od<00:o`0000GonA/00_l0000<ooooo`03
o`000?oooooooooo00;ooooo0Ol00001ooooo`00@oooool00ol0003oooooooooo`0Sooooo`Co0000
0on]_`05o`0000Co]<4000Co0000ok[20?nj`P3o^/801Ol00003ol740003o`000?o5``3oaL<000?o
aL<000Co0000olNo0?o7_`3oakl01Ol00003olRk0003o`000?o:]`3ob[L000?ob[L000?o0000olbc
0?l000000_l00002olbb0003o`000?o>[@3ocZd000?ocZd000Co0000olnX0?o?Z03ocjP01Ol00003
om:R0003o`000?oDW@3oe9d000?oe9d000Co0000omJG0?oFU`3oeYL01_l00002omV>0003o`000?oK
Q`3ofhL000?ofhL000?o0000omf00?oMP0000ooMP0001?l0003oh7P0on1h0?oPN006o`0000?ohf`0
00?o0000onIR0?oVHP000ooVHP000ol0003ojEP0onUH0003onUH0004o`000?o]C03okD`0one<00_o
00000ood<0000ol0003omb80ooLR0004ooLR0003o`000?oi6`3o000000;o00003oooool01Ol0003o
oooooooooooooooo0000007ooooo0014ooooo`03o`000?oooooooooo02?ooooo00?o0000oibk0?l0
00000ol00003ojjo0003o`000?nd`@3o]<4000?o]<401?l00003ok_20003o`000?o1a03o`L@000?o
`L@000Co0000olG30?o5``3oaL<01Ol00003olNn0003o`000?o8^`3ob;/000?ob;/000Co0000olZg
0?o:]`3ob[L01?l00005olbb0004o`000?o>[@3ocZd0olj]00Go00000oo@Y`000ol0003odZ80om:R
0003om:R0004o`000?oDW@3oe9d0omBM00Go00000ooGU@000ol0003ofHh0omV>0003omV>0003o`00
0?oKQ`3ofhL000?ofhL000Co0000omf00?oMP03ogH001Ol00003on5e0003o`000?oSK03ohf`000Co
hf`000Co0000onIR0?oVHP3oiV802ol00003one;0003o`000?o`?P3ol3h000?ol3h000?o0000oo@`
0?od<0000ood<0001?l0003omb80ooLR0?og8P04o`0001;ooooo00Go0000ooooooooooooooooo`00
0001ooooo`00AOooool00ol0003oooooooooo`0Sooooo`05o`000?nL^`3oW;/0oibk0?l000001?n^
_`000ol0003o]<40o`000002o`0000;o]/4000?o0000ok_20?nk`P000onk`P001?l0003o`L@0ol74
0?o1a005o`0000?oaL8000?o0000olNn0?o7_P000oo7_P001?l0003ob;/0olRk0?o8^`05o`0000Co
bkH000Co0000olbb0?o</P3oc;801Ol00003olj/0003o`000?o@Y`3od:L000?od:L000Co0000om:R
0?oBXP3odZ801Ol00003omBK0003o`000?oGU@3oeiD000?oeiD000Co0000omV>0?oISP3ofHh02ol0
0003omim0003o`000?oQM@3ohGD000?ohGD000Co0000on=/0?oSK03ohf`01_l00002onIR0003o`00
0?oYE`3ojEL000CojEL000?o0000one;0?o]B`000oo]B`001?l0003ol3h0oo0n0?o`?P0;o`0001Oo
oooo00Co0000oooooooooooo00000Oooool004Kooooo00?o0000ooooooooool08oooool;o`0000Go
]/4000Co0000ok_20?nk`P3o^l801Ol00003ol?40003o`000?o5`P3oaL8000?oaL8000Co0000olNn
0?o7_P3oakh01Ol00004olVj0004o`000?o;]P3obkH0ol^f00Go00000oo=/0000ol0003ocZ`0olj/
0003olj/0004o`000?o@Y`3od:L0om2W00Go00000ooBX0000ol0003oe9/0omBK0003omBK0004o`00
0?oGU@3oeiD0omNE00Go00000ooIS0000ol0003og8D0omb50002omb50003o`000?oNO@3ogWd000Co
gWd000Co0000on5e0?oQM@3ohGD01Ol00003onA[0003o`000?oVHP3oiV8000?oiV8000Co0000onUG
0?oYE`3ojEL03_l0000Qooooo`03o`000?oooooo0000007ooooo0017ooooo`;o00009?ooool01Ol0
003oWK/0oifk0?nM^`3o000000Go[kl000Co0000okK10?nf`@3o]/401Ol00003okg30003o`000?o3
a03o`l@000?o`l@000Co0000olG20?o5`P3oaL801Ol00004olNm0004o`000?o9^P3obKX0olVj00Go
00000_o;]@000ol0003ocK00olf`0004olf`0004o`000?o>[03ocZ`0olj/00Go00000_oAYP000ol0
003odZ00om:P0004om:P0004o`000?oDV`3oe9/0omBK00Go00000ooGT`000ol0003ofH`0omV<0003
omV<0003o`000?oLQ@3og8D000;og8D000Co0000omim0?oNO@3ogWd01_l00002on5d0003o`000?oT
J`3oi6/000Coi6/000Co0000onIR0?oVHP3oiV802?l0000/ooooo`03o`000?oooooo0000007ooooo
0019ooooo`03o`000?oooooooooo02;ooooo00Go0000oifk0?nM^`3oWK/0o`000003ojno00Go0000
0ong`@000ol0003o_L<0okg30003okg30004o`000?o3a03o`l@0ol?400Go00001?o6`@001?l0003o
akd0olNm0?o7_@05o`0000;obKT000?o0000ol^e0?o;]@000oo;]@001?l0003ocK00olf`0?o=/006
o`0000;ocj/000?o0000om6V0?oAYP000ooAYP001?l0003odZ00om:P0?oBX006o`0000;oeIT000?o
0000omNC0?oGT`001?oGT`001?l0003ofH`0omV<0?oIS00:o`0000CogW`000?o0000on5d0?oQM000
0_oQM0001?l0003oi6/0onA[0?oTJ`08o`0003?ooooo0Ol00001ooooo`7o0000001:ooooo`03o`00
0?oooooooooo02;ooooo1ol00003ok2o0003o`000?ng`@3o]l4000?o]l4000Co0000okg30?nm``3o
_L<01Ol00003olC40003o`000?o6`@3oa/4000?oa/401?l00002olRl0003o`000?o9^@3obKT000?o
bKT000Co0000ol^e0?o;]@3obkD01Ol00003olf_0003o`000?o?Z`3ocj/000?ocj/000Co0000om6V
0?oAYP3odJH01Ol00003om>N0003o`000?oEV@3oeIT000?oeIT000Co0000omNC0?oGT`3oei<01_l0
0002omZ;0003o`000?oLQ03og8@000Cog8@000Co0000omil0?oNO03ogW`03Ol0000iooooo`;o0000
001;ooooo`03o`000?oooooooooo02;ooooo00Go0000oink0?nO^`3oWk/0o`000005ok2o0004o`00
0?ng`@3o]l40okO100Go00000onn``000ol0003oa<@0olC40003olC40003o`000?o6`@3o000000;o
000000?oa/00o`000?o8_0001?o8_0001?l0003obKT0olVi0?o9^@05o`0000?oc;<000?o0000olf_
0?o=[`000oo=[`001?l0003ocj/0oln[0?o?Z`05o`0000?odJ@000?o0000om>N0?oCWP000ooCWP00
1?l0003oeIT0omFI0?oEV@05o`0000?of94000?o0000omZ;0?oJR`000ooJR`001?l0003og8@0omb4
0?oLQ006o`0000;ofhL01Ol0000nooooo`?o0000001<ooooo`;o00008oooool01Ol0003oWk/0oink
0?nO^`3o000000?o/;l01Ol00003okS20003o`000?nn``3o_/<000?o_/<000Co0000olC40?o4a03o
a<@00ol00005olK00004o`000?o8_03ob;`0olRl00Go00000oo:]`000ol0003oc;<0olbc0003olbc
0004o`000?o=[`3ocJl0olf_00Go00000oo?Z@000ol0003odJ@0om6T0003om6T0004o`000?oCWP3o
dih0om>N00Go00000ooFV0000ol0003of940omRA0003omRA0004o`000?oJR`3ofX/0omZ;00Go0000
0ooIS@05o`0003oooooo1?l00003ooooo`00C_ooool00ol0003oooooooooo`0Qooooo`Oo00000ona
`0000ol0003o^<80okS20003okS20004o`000?nn``3o_/<0okk300Go00000oo5a0001?l0003oa/00
olK00?o6`005o`0000?ob;/000?o0000olZg0?o:]`000oo:]`001?l0003oc;<0olbc0?o</`05o`00
00?ocZd000?o0000olnY0?o?Z@000oo?Z@001?l0003odJ@0om6T0?oAY005o`0000?odid000?o0000
omJH0?oFV0000ooFV0001?l0003of940omRA0?oHT@05o`0000?oei<01Ol00010ooooo`Co00001ooo
ool004oooooo00?o0000ooooooooool08Oooool2o`0000;oX;`000?o0000ok700?na`0000ona`000
1?l0003o^<80okS20?nh`P05o`0000Co`<<000?o0000olG40?o5a0001Ol00003olNo0003o`000?o8
^`3ob;/000?ob;/000Co0000olZg0?o:]`3ob[L01Ol00003olbb0003o`000?o>[@3ocZd000?ocZd0
00Co0000olnY0?o?Z@3ocjT01Ol00003om:S0003o`000?oCW@3odid000?odid000Co0000omJH0?oF
V03oeYP01Ol00002omFI00Ko0000@_ooool3o`0000_ooooo001@ooooo`03o`000?oooooooooo027o
oooo1Ol00003ok7000Go00001?nj`P001?l0003o`<<0ol330?o0``04o`0000?oaL8000?o0000olNo
0?o7_`000oo7_`001?l0003ob;/0olRk0?o8^`05o`0000?obkH000?o0000olbb0?o</P000oo</P00
1?l0003ocZd0olj]0?o>[@05o`0000?od:L000?o0000om:S0?oBX`000ooBX`001?l0003odid0om>M
0?oCW@05o`0000;odih01Ol00014ooooo`Co00003_ooool0057ooooo00?o0000ooooooooool08Ooo
ool00ol0003oX[`0oj:l0004o`0000Co/l0000Co0000ok[20?nj`P3o^/801Ol00002ol;40003o`00
0?o5`P3oaL8000?oaL8000Co0000olNo0?o7_`3oakl01Ol00003olVj0003o`000?o;]P3obkH000?o
bkH000Co0000olbb0?o</P3oc;801Ol00003olj/0004o`000?o@Y`3od:L0om2W00_o00000_oAX`05
o`0004Gooooo1?l0000Booooo`00D_ooool2o`0002;ooooo00?o0000oj:l0?nR_0000_nR_0001?l0
003o/l00ok?00?nc`005o`0000?o_<<000?o0000ol;40?o2a0000_o2a0001?l0003oaL80olG20?o5
`P05o`0000?oakd000?o0000olVj0?o9^P000oo9^P001?l0003obkH0ol^f0?o;]P05o`0000?ocK40
00Co0000olj/0?o>[03ocZ`01Ol00004olj/0004o`000?o@Z03od:P0om2X00Go0000A_ooool4o`00
01Kooooo001Dooooo`03o`000?oooooooooo023ooooo2?l00003okG10003o`000?nl``3o_<<000?o
_<<000?o0000ol;40?o2a0001Ol00003olK10003o`000?o7_@3oakd000?oakd000Co0000olVj0?o9
^P3obKX01Ol00003ol^e0004o`000?o=/@3ocK40olfa00Go00001?o=/0001?l0003ocZ`0olj/0?o>
[005o`0004Oooooo1?l0000Jooooo`00EOooool00ol0003oooooooooo`0Pooooo`03o`000?nT_@3o
Y;d000;oY;d000?o0000okG10?ne`@000one`@001?l0003o_<<0okc30?nl``04o`0000?oa<@000?o
0000olK10?o6`@000oo6`@001?l0003oakd0olNm0?o7_@05o`0000?obKT000Co0000ol^e0?o;]@3o
bkD01Ol00004ol^d0004o`000?o=/03ocK00olf`00Go0000B?ooool4o`0001kooooo001Fooooo`03
o`000?oooooooooo023ooooo00?o0000ojBm0?nT_@000_nT_@001?l0003o]L40okG10?ne`@05o`00
00;o_/<000?o0000olC40?o4a0000oo4a0001?l0003oa/40olK10?o6`@05o`0000Cob;`000?o0000
olVi0?o9^@001Ol00004olVh0004o`000?o;]03obk@0ol^d00Go0000B_ooool3o`0002;ooooo001G
ooooo`;o00008Oooool8o`0000?o]l4000?o0000okk30?nn``000_nn``001?l0003oa<@0olC40?o4
a005o`0000Coa/0000Co0000olRl0?o8_03ob;`01?l00004olRl0004o`000?o9^03obKP0olVh00Go
0000Boooool4o`0002Gooooo001Iooooo`03o`000?oooooooooo023ooooo00?o0000ojJm0?nV_@00
0_nV_@000ol0003o]l40okO10002okO10003o`000?nn``3o_/<000Go00001?o5``001?l0003oa/00
olK00?o6`005o`0000?oakl000Co0000olRl0?o8_03ob;`01Ol0001<ooooo`Co0000:Oooool005[o
oooo00?o0000ooooooooool08?ooool<o`0000Co`L@000Co0000olG30?o5``3oaL<01Ol00003olG3
0004o`000?o7_`3oakl0olNo00Go0000COooool4o`0002gooooo001Kooooo`03o`000?oooooooooo
023ooooo00?o0000ojRn0?nX_P000_nX_P000ol0003o^L80okW20002okW20004o`000?o1a03o`L@0
ol7400Go00001?o2a0000ol0003oaL<0olG30005o`0004kooooo1?l0000aooooo`00G?ooool00ol0
003oooooooooo`0Pooooo`03o`000?nX_P3oZ;h000;oZ;h000?o0000okW20?ni`P001Ol00004okc3
0004o`000?o2a03o`/@0ol;400Co0000Coooool4o`0003Gooooo001Mooooo`;o00008?ooool8o`00
00Co]L4000Co0000okc30?nl``3o_<<01Ol0001@ooooo`?o0000>Oooool005oooooo00?o0000oooo
ooooool07Oooool01?l0003oooooooooool00003ojFm0004o`000?ne`@3o]L40okG100Go0000DOoo
ool4o`0003cooooo001Pooooo`03o`000?oooooooooo01cooooo00Co0000oooooooooooooooo1ol0
001Booooo`Co0000@?ooool0067ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1F
ooooo`Co0000A?ooool006;ooooo0_l0000Kooooo`03o`000?oooooooooo05;ooooo1?l00018oooo
o`00I?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04kooooo1?l0001<ooooo`00
IOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04_ooooo0ol0001@ooooo`00I_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo1?l0001Cooooo`00Ioooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo1?l0001Gooooo`00J?ooool2o`00
01Gooooo00?o0000ooooooooool0?oooool4o`0005_ooooo001Zooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0>oooool4o`0005oooooo001[ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0=oooool4o`0006?ooooo001/ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0=?ooool3o`0006Oooooo001]ooooo`;o00004?ooool00ol0003oooooooooo`0`
ooooo`Co0000J_ooool006oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0]oooo
o`Co0000K_ooool0073ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`Co
0000L_ooool0077ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`Co0000
M_ooool007;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000N_oo
ool007?ooooo0_l00009ooooo`03o`000?oooooooooo01kooooo0ol0001nooooo`00MOooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo1?l00021ooooo`00M_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l00025ooooo`00Moooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l00029ooooo`00N?ooool2o`0000Cooooo00?o
0000ooooooooool03_ooool4o`0008gooooo001jooooo`05o`000?ooooooooooooooool000003?oo
ool4o`00097ooooo001kooooo`04o`000?ooooooooooo`0000Wooooo0ol0002Eooooo`00O?ooool0
0ol0003oooooo`000005ooooo`Co0000V?ooool007gooooo0_l000000ooooooo0000o`000002o`00
09cooooo001nooooo`;o0000X?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0=3ooooo0ol0001=ooooo`00dOooool00ol0003oooooooooo`1<ooooo`00Goooool00ol0003ooooo
o`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00002?ooool3o`0000?ooooo
0ol00004ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00008ooooo`Go0000
00Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003ooooo`?o00000_ooool3o`000003
ooooool0003o000000Co00000_ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04_o
oooo001Oooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003o
oooooooooooooooo000000cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`06
o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`000?oo
ooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_o
oooo001Oooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`03o`000?oooooo000000;ooooo
1Ol00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02
ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000C?ooool005kooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00;ooooo00Go0000ooooooooooooooooo`000008ooooo`?o00000oooool2o`0000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool0
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
001<ooooo`00G_ooool01Ol0003oooooo`000?oooooo000000;ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_ooool3o`0000Wooooo00?o0000ooooooooool00_ooool2o`000003ooooool0
003o000000;ooooo0ol00002ooooo`Co00000_ooool4o`0000[ooooo00Co0000oooooooooooooooo
1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0003o
00000oooool4o`0000;ooooo0_l000000ooooooo0000o`00001;ooooo`00G_ooool01Ol0003ooooo
o`000?oooooo000001[ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Boooo
o`00G_ooool6o`0001Sooooo1Ol0000Dooooo`03o`000?oooooooooo00Sooooo1Ol00008ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Booooo`00
oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0755573, 0.0565859, \
0.00358241, 0.00358241}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.14456 .20014 -11.9298 -9 ]
[.14456 .20014 .07017 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.53907 .04499 -5.20849 -9 ]
[.53907 .04499 .79151 0 ]
[.76796 .09781 0 -6.16112 ]
[.76796 .09781 12 2.83888 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93439 .35267 0 -5.92025 ]
[.93439 .35267 6 3.07975 ]
[.0228 .27335 -6 -2.74927 ]
[.0228 .27335 0 6.25073 ]
[.01031 .35161 -12 -2.81553 ]
[.01031 .35161 0 6.18447 ]
[-0.00282 .43394 -18 -2.88559 ]
[-0.00282 .43394 0 6.11441 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15379 .20947 m
.1584 .21414 L
s
[(-5)] .14456 .20014 .98831 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54685 .05556 m
.55074 .06084 L
s
[(5)] .53907 .04499 .73616 1 Mshowa
.125 Mabswid
.19056 .19507 m
.19329 .19791 L
s
.22786 .18047 m
.23055 .18334 L
s
.2657 .16565 m
.26835 .16856 L
s
.3041 .15061 m
.30671 .15356 L
s
.38261 .11987 m
.38514 .12289 L
s
.42275 .10415 m
.42523 .10721 L
s
.46349 .0882 m
.46592 .09129 L
s
.50485 .072 m
.50724 .07514 L
s
.11754 .22366 m
.12034 .22643 L
s
.08179 .23766 m
.08463 .24039 L
s
.04655 .25146 m
.04942 .25416 L
s
.5895 .03886 m
.59178 .04207 L
s
.6328 .0219 m
.63503 .02515 L
s
.67679 .00468 m
.67896 .00796 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75565 .10235 m
.74949 .10462 L
s
[(-5)] .76796 .09781 -1 .36914 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92187 .35662 m
.91562 .35859 L
s
[(5)] .93439 .35267 -1 .31561 Mshowa
.125 Mabswid
.77429 .13086 m
.77059 .1322 L
s
.79243 .15861 m
.78872 .15994 L
s
.8101 .18564 m
.80638 .18694 L
s
.82731 .21196 m
.82359 .21325 L
s
.86042 .26262 m
.85669 .26387 L
s
.87636 .287 m
.87262 .28823 L
s
.8919 .31078 m
.88816 .31199 L
s
.90707 .33398 m
.90332 .33518 L
s
.73649 .07305 m
.73281 .07443 L
s
.7168 .04292 m
.71312 .04433 L
s
.69654 .01194 m
.69287 .01337 L
s
.93632 .37872 m
.93257 .37989 L
s
.95044 .40031 m
.94667 .40146 L
s
.96422 .4214 m
.96045 .42254 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03503 .26859 m
.04114 .26621 L
s
[(0)] .0228 .27335 1 -0.38905 Mshowa
.0226 .34701 m
.02875 .34471 L
s
[(50)] .01031 .35161 1 -0.37433 Mshowa
.00953 .42951 m
.0157 .42729 L
s
[(100)] -0.00282 .43394 1 -0.35876 Mshowa
.125 Mabswid
.03259 .28396 m
.03626 .28254 L
s
.03013 .29949 m
.03381 .29808 L
s
.02765 .31517 m
.03133 .31377 L
s
.02514 .33101 m
.02882 .32962 L
s
.02004 .36317 m
.02373 .3618 L
s
.01745 .3795 m
.02115 .37814 L
s
.01484 .396 m
.01854 .39465 L
s
.0122 .41266 m
.0159 .41132 L
s
.00683 .44652 m
.01054 .44521 L
s
.00411 .46372 m
.00782 .46241 L
s
.00135 .4811 m
.00507 .4798 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.103 .579 0 r
.39166 .68941 .40185 .69744 .41813 .71576 .40802 .70548 Metetra
.362 .664 0 r
.40802 .70548 .41813 .71576 .43484 .73046 .4248 .71803 Metetra
.622 .734 0 r
.4248 .71803 .43484 .73046 .45192 .74189 .44192 .72743 Metetra
.79 .718 0 r
.44192 .72743 .45192 .74189 .46931 .75038 .45936 .73401 Metetra
.835 .596 0 r
.45936 .73401 .46931 .75038 .48698 .75627 .47706 .7381 Metetra
.87 .489 0 r
.47706 .7381 .48698 .75627 .50488 .75986 .49498 .74003 Metetra
.897 .4 0 r
.49498 .74003 .50488 .75986 .52299 .76146 .5131 .74008 Metetra
.916 .332 0 r
.5131 .74008 .52299 .76146 .54128 .76134 .53138 .73855 Metetra
.93 .283 0 r
.53138 .73855 .54128 .76134 .55972 .75977 .54981 .73568 Metetra
.938 .252 0 r
.54981 .73568 .55972 .75977 .5783 .75697 .56838 .73171 Metetra
.942 .235 0 r
.56838 .73171 .5783 .75697 .59701 .75317 .58707 .72685 Metetra
.943 .231 0 r
.58707 .72685 .59701 .75317 .61583 .74855 .60587 .72129 Metetra
.942 .237 0 r
.60587 .72129 .61583 .74855 .63477 .74328 .62477 .71519 Metetra
.939 .25 0 r
.62477 .71519 .63477 .74328 .65382 .73751 .64379 .70871 Metetra
.934 .268 0 r
.64379 .70871 .65382 .73751 .67297 .73135 .66291 .70196 Metetra
.928 .289 0 r
.66291 .70196 .67297 .73135 .69223 .7249 .68213 .69503 Metetra
.922 .312 0 r
.68213 .69503 .69223 .7249 .7116 .71824 .70147 .688 Metetra
.915 .336 0 r
.70147 .688 .7116 .71824 .73108 .71142 .72092 .68092 Metetra
.908 .36 0 r
.72092 .68092 .73108 .71142 .75067 .70445 .74048 .67382 Metetra
.901 .385 0 r
.74048 .67382 .75067 .70445 .77037 .69734 .76016 .66669 Metetra
.894 .41 0 r
.76016 .66669 .77037 .69734 .79017 .69005 .77996 .6595 Metetra
.887 .436 0 r
.77996 .6595 .79017 .69005 .81007 .68252 .79987 .65221 Metetra
.878 .463 0 r
.79987 .65221 .81007 .68252 .83007 .67467 .81988 .64473 Metetra
.869 .494 0 r
.81988 .64473 .83007 .67467 .85013 .66638 .83999 .63695 Metetra
.858 .528 0 r
.83999 .63695 .85013 .66638 .87025 .65747 .86017 .62871 Metetra
.845 .568 0 r
.86017 .62871 .87025 .65747 .89039 .64777 .8804 .61983 Metetra
.829 .616 0 r
.8804 .61983 .89039 .64777 .91051 .63703 .90065 .61009 Metetra
.808 .672 0 r
.90065 .61009 .91051 .63703 .93056 .62497 .92087 .59921 Metetra
.783 .737 0 r
.92087 .59921 .93056 .62497 .95048 .61127 .94099 .58688 Metetra
.69 .751 0 r
.94099 .58688 .95048 .61127 .97019 .59555 .96096 .57274 Metetra
.529 .71 0 r
.96096 .57274 .97019 .59555 .9896 .57739 .98067 .55637 Metetra
.091 .575 0 r
.38141 .67959 .39166 .68941 .40802 .70548 .39785 .69357 Metetra
.317 .651 0 r
.39785 .69357 .40802 .70548 .4248 .71803 .41469 .70414 Metetra
.537 .713 0 r
.41469 .70414 .4248 .71803 .44192 .72743 .43187 .71166 Metetra
.736 .761 0 r
.43187 .71166 .44192 .72743 .45936 .73401 .44935 .71647 Metetra
.8 .694 0 r
.44935 .71647 .45936 .73401 .47706 .7381 .46708 .71892 Metetra
.828 .616 0 r
.46708 .71892 .47706 .7381 .49498 .74003 .48502 .71931 Metetra
.849 .555 0 r
.48502 .71931 .49498 .74003 .5131 .74008 .50315 .71795 Metetra
.863 .512 0 r
.50315 .71795 .5131 .74008 .53138 .73855 .52144 .71511 Metetra
.872 .484 0 r
.52144 .71511 .53138 .73855 .54981 .73568 .53987 .71105 Metetra
.876 .471 0 r
.53987 .71105 .54981 .73568 .56838 .73171 .55843 .706 Metetra
.876 .47 0 r
.55843 .706 .56838 .73171 .58707 .72685 .57709 .70017 Metetra
.874 .477 0 r
.57709 .70017 .58707 .72685 .60587 .72129 .59587 .69375 Metetra
.869 .492 0 r
.59587 .69375 .60587 .72129 .62477 .71519 .61475 .6869 Metetra
.864 .511 0 r
.61475 .6869 .62477 .71519 .64379 .70871 .63373 .67976 Metetra
.857 .532 0 r
.63373 .67976 .64379 .70871 .66291 .70196 .65282 .67245 Metetra
.849 .554 0 r
.65282 .67245 .66291 .70196 .68213 .69503 .67202 .66507 Metetra
.842 .577 0 r
.67202 .66507 .68213 .69503 .70147 .688 .69132 .6577 Metetra
.834 .599 0 r
.69132 .6577 .70147 .688 .72092 .68092 .71074 .65037 Metetra
.827 .62 0 r
.71074 .65037 .72092 .68092 .74048 .67382 .73028 .64312 Metetra
.82 .639 0 r
.73028 .64312 .74048 .67382 .76016 .66669 .74994 .63595 Metetra
.813 .658 0 r
.74994 .63595 .76016 .66669 .77996 .6595 .76973 .62884 Metetra
.807 .676 0 r
.76973 .62884 .77996 .6595 .79987 .65221 .78964 .62174 Metetra
.8 .694 0 r
.78964 .62174 .79987 .65221 .81988 .64473 .80967 .61457 Metetra
.792 .713 0 r
.80967 .61457 .81988 .64473 .83999 .63695 .82981 .60722 Metetra
.784 .734 0 r
.82981 .60722 .83999 .63695 .86017 .62871 .85004 .59955 Metetra
.774 .758 0 r
.85004 .59955 .86017 .62871 .8804 .61983 .87035 .59138 Metetra
.735 .761 0 r
.87035 .59138 .8804 .61983 .90065 .61009 .8907 .58251 Metetra
.667 .745 0 r
.8907 .58251 .90065 .61009 .92087 .59921 .91105 .57266 Metetra
.584 .725 0 r
.91105 .57266 .92087 .59921 .94099 .58688 .93135 .56155 Metetra
.483 .698 0 r
.93135 .56155 .94099 .58688 .96096 .57274 .95154 .54881 Metetra
.362 .664 0 r
.95154 .54881 .96096 .57274 .98067 .55637 .97152 .53405 Metetra
.064 .565 0 r
.37111 .66835 .38141 .67959 .39785 .69357 .38762 .6804 Metetra
.258 .633 0 r
.38762 .6804 .39785 .69357 .41469 .70414 .40452 .68914 Metetra
.441 .687 0 r
.40452 .68914 .41469 .70414 .43187 .71166 .42176 .69494 Metetra
.601 .729 0 r
.42176 .69494 .43187 .71166 .44935 .71647 .43928 .69813 Metetra
.732 .761 0 r
.43928 .69813 .44935 .71647 .46708 .71892 .45705 .69907 Metetra
.784 .735 0 r
.45705 .69907 .46708 .71892 .48502 .71931 .47502 .69806 Metetra
.799 .696 0 r
.47502 .69806 .48502 .71931 .50315 .71795 .49316 .6954 Metetra
.808 .671 0 r
.49316 .6954 .50315 .71795 .52144 .71511 .51146 .69137 Metetra
.813 .66 0 r
.51146 .69137 .52144 .71511 .53987 .71105 .52989 .68622 Metetra
.813 .66 0 r
.52989 .68622 .53987 .71105 .55843 .706 .54844 .68019 Metetra
.81 .668 0 r
.54844 .68019 .55843 .706 .57709 .70017 .5671 .67347 Metetra
.804 .683 0 r
.5671 .67347 .57709 .70017 .59587 .69375 .58586 .66625 Metetra
.797 .701 0 r
.58586 .66625 .59587 .69375 .61475 .6869 .60472 .65871 Metetra
.789 .722 0 r
.60472 .65871 .61475 .6869 .63373 .67976 .62367 .65096 Metetra
.78 .744 0 r
.62367 .65096 .63373 .67976 .65282 .67245 .64273 .64315 Metetra
.771 .765 0 r
.64273 .64315 .65282 .67245 .67202 .66507 .6619 .63535 Metetra
.739 .762 0 r
.6619 .63535 .67202 .66507 .69132 .6577 .68118 .62764 Metetra
.704 .754 0 r
.68118 .62764 .69132 .6577 .71074 .65037 .70057 .62008 Metetra
.672 .746 0 r
.70057 .62008 .71074 .65037 .73028 .64312 .72009 .61268 Metetra
.644 .739 0 r
.72009 .61268 .73028 .64312 .74994 .63595 .73973 .60546 Metetra
.618 .733 0 r
.73973 .60546 .74994 .63595 .76973 .62884 .75951 .5984 Metetra
.595 .727 0 r
.75951 .5984 .76973 .62884 .78964 .62174 .77942 .59144 Metetra
.572 .722 0 r
.77942 .59144 .78964 .62174 .80967 .61457 .79946 .58453 Metetra
.55 .716 0 r
.79946 .58453 .80967 .61457 .82981 .60722 .81962 .57754 Metetra
.526 .71 0 r
.81962 .57754 .82981 .60722 .85004 .59955 .83989 .57036 Metetra
.498 .702 0 r
.83989 .57036 .85004 .59955 .87035 .59138 .86026 .56281 Metetra
.463 .693 0 r
.86026 .56281 .87035 .59138 .8907 .58251 .8807 .55469 Metetra
.419 .68 0 r
.8807 .55469 .8907 .58251 .91105 .57266 .90117 .54575 Metetra
.362 .664 0 r
.90117 .54575 .91105 .57266 .93135 .56155 .92162 .53569 Metetra
.291 .643 0 r
.92162 .53569 .93135 .56155 .95154 .54881 .942 .52419 Metetra
.204 .615 0 r
.942 .52419 .95154 .54881 .97152 .53405 .96221 .51084 Metetra
.027 .55 0 r
.36074 .656 .37111 .66835 .38762 .6804 .37733 .66629 Metetra
.19 .61 0 r
.37733 .66629 .38762 .6804 .40452 .68914 .39429 .67336 Metetra
.34 .658 0 r
.39429 .67336 .40452 .68914 .42176 .69494 .41159 .67758 Metetra
.467 .694 0 r
.41159 .67758 .42176 .69494 .43928 .69813 .42915 .6793 Metetra
.566 .72 0 r
.42915 .6793 .43928 .69813 .45705 .69907 .44696 .67886 Metetra
.636 .738 0 r
.44696 .67886 .45705 .69907 .47502 .69806 .46496 .67658 Metetra
.68 .748 0 r
.46496 .67658 .47502 .69806 .49316 .6954 .48312 .67274 Metetra
.7 .753 0 r
.48312 .67274 .49316 .6954 .51146 .69137 .50144 .66762 Metetra
.701 .753 0 r
.50144 .66762 .51146 .69137 .52989 .68622 .51987 .66149 Metetra
.687 .75 0 r
.51987 .66149 .52989 .68622 .54844 .68019 .53842 .65455 Metetra
.66 .743 0 r
.53842 .65455 .54844 .68019 .5671 .67347 .55707 .64702 Metetra
.626 .735 0 r
.55707 .64702 .5671 .67347 .58586 .66625 .57582 .63909 Metetra
.588 .725 0 r
.57582 .63909 .58586 .66625 .60472 .65871 .59467 .6309 Metetra
.547 .715 0 r
.59467 .6309 .60472 .65871 .62367 .65096 .61361 .62261 Metetra
.507 .704 0 r
.61361 .62261 .62367 .65096 .64273 .64315 .63265 .61432 Metetra
.468 .694 0 r
.63265 .61432 .64273 .64315 .6619 .63535 .65179 .60613 Metetra
.432 .684 0 r
.65179 .60613 .6619 .63535 .68118 .62764 .67105 .59811 Metetra
.4 .675 0 r
.67105 .59811 .68118 .62764 .70057 .62008 .69042 .59032 Metetra
.372 .667 0 r
.69042 .59032 .70057 .62008 .72009 .61268 .70992 .58278 Metetra
.348 .66 0 r
.70992 .58278 .72009 .61268 .73973 .60546 .72955 .5755 Metetra
.328 .654 0 r
.72955 .5755 .73973 .60546 .75951 .5984 .74931 .56845 Metetra
.311 .649 0 r
.74931 .56845 .75951 .5984 .77942 .59144 .76922 .56161 Metetra
.296 .645 0 r
.76922 .56161 .77942 .59144 .79946 .58453 .78926 .5549 Metetra
.283 .64 0 r
.78926 .5549 .79946 .58453 .81962 .57754 .80945 .54822 Metetra
.269 .636 0 r
.80945 .54822 .81962 .57754 .83989 .57036 .82976 .54145 Metetra
.253 .631 0 r
.82976 .54145 .83989 .57036 .86026 .56281 .85018 .53443 Metetra
.233 .624 0 r
.85018 .53443 .86026 .56281 .8807 .55469 .87069 .52696 Metetra
.206 .616 0 r
.87069 .52696 .8807 .55469 .90117 .54575 .89126 .5188 Metetra
.17 .603 0 r
.89126 .5188 .90117 .54575 .92162 .53569 .91185 .50967 Metetra
.123 .587 0 r
.91185 .50967 .92162 .53569 .942 .52419 .93239 .49924 Metetra
.062 .564 0 r
.93239 .49924 .942 .52419 .96221 .51084 .95281 .48714 Metetra
0 .532 .016 r
.35031 .64285 .36074 .656 .37733 .66629 .36696 .65153 Metetra
.12 .586 0 r
.36696 .65153 .37733 .66629 .39429 .67336 .38399 .65708 Metetra
.241 .627 0 r
.38399 .65708 .39429 .67336 .41159 .67758 .40134 .65987 Metetra
.339 .657 0 r
.40134 .65987 .41159 .67758 .42915 .6793 .41896 .66026 Metetra
.411 .678 0 r
.41896 .66026 .42915 .6793 .44696 .67886 .4368 .65857 Metetra
.458 .691 0 r
.4368 .65857 .44696 .67886 .46496 .67658 .45484 .65512 Metetra
.481 .698 0 r
.45484 .65512 .46496 .67658 .48312 .67274 .47303 .65022 Metetra
.484 .698 0 r
.47303 .65022 .48312 .67274 .50144 .66762 .49137 .64412 Metetra
.472 .695 0 r
.49137 .64412 .50144 .66762 .51987 .66149 .50982 .63709 Metetra
.447 .688 0 r
.50982 .63709 .51987 .66149 .53842 .65455 .52837 .62934 Metetra
.414 .679 0 r
.52837 .62934 .53842 .65455 .55707 .64702 .54703 .62108 Metetra
.375 .668 0 r
.54703 .62108 .55707 .64702 .57582 .63909 .56577 .61248 Metetra
.335 .656 0 r
.56577 .61248 .57582 .63909 .59467 .6309 .58461 .60372 Metetra
.294 .644 0 r
.58461 .60372 .59467 .6309 .61361 .62261 .60354 .59492 Metetra
.255 .632 0 r
.60354 .59492 .61361 .62261 .63265 .61432 .62257 .5862 Metetra
.219 .62 0 r
.62257 .5862 .63265 .61432 .65179 .60613 .64169 .57765 Metetra
.186 .609 0 r
.64169 .57765 .65179 .60613 .67105 .59811 .66093 .56934 Metetra
.158 .599 0 r
.66093 .56934 .67105 .59811 .69042 .59032 .68029 .56133 Metetra
.134 .591 0 r
.68029 .56133 .69042 .59032 .70992 .58278 .69977 .55365 Metetra
.115 .584 0 r
.69977 .55365 .70992 .58278 .72955 .5755 .71939 .54629 Metetra
.099 .578 0 r
.71939 .54629 .72955 .5755 .74931 .56845 .73915 .53925 Metetra
.087 .574 0 r
.73915 .53925 .74931 .56845 .76922 .56161 .75905 .53249 Metetra
.078 .57 0 r
.75905 .53249 .76922 .56161 .78926 .5549 .77911 .52595 Metetra
.071 .567 0 r
.77911 .52595 .78926 .5549 .80945 .54822 .79931 .51952 Metetra
.064 .565 0 r
.79931 .51952 .80945 .54822 .82976 .54145 .81965 .5131 Metetra
.056 .562 0 r
.81965 .5131 .82976 .54145 .85018 .53443 .84012 .50652 Metetra
.046 .558 0 r
.84012 .50652 .85018 .53443 .87069 .52696 .8607 .49961 Metetra
.032 .552 0 r
.8607 .49961 .87069 .52696 .89126 .5188 .88136 .49212 Metetra
.011 .543 0 r
.88136 .49212 .89126 .5188 .91185 .50967 .90206 .48379 Metetra
0 .53 .018 r
.90206 .48379 .91185 .50967 .93239 .49924 .92274 .4743 Metetra
0 .512 .058 r
.92274 .4743 .93239 .49924 .95281 .48714 .94335 .46328 Metetra
0 .512 .059 r
.33979 .62914 .35031 .64285 .36696 .65153 .35652 .63637 Metetra
.052 .56 0 r
.35652 .63637 .36696 .65153 .38399 .65708 .37361 .64055 Metetra
.148 .596 0 r
.37361 .64055 .38399 .65708 .40134 .65987 .39102 .64206 Metetra
.222 .621 0 r
.39102 .64206 .40134 .65987 .41896 .66026 .40869 .64124 Metetra
.273 .637 0 r
.40869 .64124 .41896 .66026 .4368 .65857 .42658 .63842 Metetra
.301 .646 0 r
.42658 .63842 .4368 .65857 .45484 .65512 .44466 .63394 Metetra
.308 .648 0 r
.44466 .63394 .45484 .65512 .47303 .65022 .46289 .62807 Metetra
.3 .646 0 r
.46289 .62807 .47303 .65022 .49137 .64412 .48124 .62109 Metetra
.278 .639 0 r
.48124 .62109 .49137 .64412 .50982 .63709 .49972 .61325 Metetra
.247 .629 0 r
.49972 .61325 .50982 .63709 .52837 .62934 .51829 .60476 Metetra
.211 .617 0 r
.51829 .60476 .52837 .62934 .54703 .62108 .53695 .59584 Metetra
.171 .604 0 r
.53695 .59584 .54703 .62108 .56577 .61248 .5557 .58665 Metetra
.132 .59 0 r
.5557 .58665 .56577 .61248 .58461 .60372 .57454 .57737 Metetra
.093 .576 0 r
.57454 .57737 .58461 .60372 .60354 .59492 .59347 .56811 Metetra
.058 .562 0 r
.59347 .56811 .60354 .59492 .62257 .5862 .61249 .55899 Metetra
.026 .549 0 r
.61249 .55899 .62257 .5862 .64169 .57765 .63161 .55011 Metetra
0 .537 .002 r
.63161 .55011 .64169 .57765 .66093 .56934 .65084 .54153 Metetra
0 .527 .026 r
.65084 .54153 .66093 .56934 .68029 .56133 .67019 .53332 Metetra
0 .518 .045 r
.67019 .53332 .68029 .56133 .69977 .55365 .68966 .52549 Metetra
0 .511 .06 r
.68966 .52549 .69977 .55365 .71939 .54629 .70927 .51805 Metetra
0 .506 .072 r
.70927 .51805 .71939 .54629 .73915 .53925 .72903 .511 Metetra
0 .502 .08 r
.72903 .511 .73915 .53925 .75905 .53249 .74894 .5043 Metetra
0 .499 .085 r
.74894 .5043 .75905 .53249 .77911 .52595 .769 .49788 Metetra
0 .497 .089 r
.769 .49788 .77911 .52595 .79931 .51952 .78922 .49166 Metetra
0 .496 .091 r
.78922 .49166 .79931 .51952 .81965 .5131 .80959 .48553 Metetra
0 .495 .093 r
.80959 .48553 .81965 .5131 .84012 .50652 .8301 .47932 Metetra
0 .493 .096 r
.8301 .47932 .84012 .50652 .8607 .49961 .85074 .47288 Metetra
0 .49 .102 r
.85074 .47288 .8607 .49961 .88136 .49212 .87148 .46596 Metetra
0 .485 .113 r
.87148 .46596 .88136 .49212 .90206 .48379 .89228 .45832 Metetra
0 .476 .13 r
.89228 .45832 .90206 .48379 .92274 .4743 .9131 .44964 Metetra
0 .461 .154 r
.9131 .44964 .92274 .4743 .94335 .46328 .93386 .43956 Metetra
0 .491 .102 r
.32919 .61511 .33979 .62914 .35652 .63637 .34598 .62104 Metetra
0 .534 .011 r
.34598 .62104 .35652 .63637 .37361 .64055 .36315 .624 Metetra
.064 .565 0 r
.36315 .624 .37361 .64055 .39102 .64206 .38062 .62435 Metetra
.119 .585 0 r
.38062 .62435 .39102 .64206 .40869 .64124 .39834 .62245 Metetra
.153 .597 0 r
.39834 .62245 .40869 .64124 .42658 .63842 .41628 .61864 Metetra
.167 .602 0 r
.41628 .61864 .42658 .63842 .44466 .63394 .4344 .61322 Metetra
.163 .601 0 r
.4344 .61322 .44466 .63394 .46289 .62807 .45267 .60649 Metetra
.146 .595 0 r
.45267 .60649 .46289 .62807 .48124 .62109 .47106 .59872 Metetra
.12 .586 0 r
.47106 .59872 .48124 .62109 .49972 .61325 .48956 .59015 Metetra
.086 .573 0 r
.48956 .59015 .49972 .61325 .51829 .60476 .50816 .58101 Metetra
.05 .559 0 r
.50816 .58101 .51829 .60476 .53695 .59584 .52684 .57149 Metetra
.012 .544 0 r
.52684 .57149 .53695 .59584 .5557 .58665 .5456 .56178 Metetra
0 .528 .025 r
.5456 .56178 .5557 .58665 .57454 .57737 .56445 .55201 Metetra
0 .512 .059 r
.56445 .55201 .57454 .57737 .59347 .56811 .58338 .54234 Metetra
0 .497 .089 r
.58338 .54234 .59347 .56811 .61249 .55899 .60241 .53286 Metetra
0 .483 .116 r
.60241 .53286 .61249 .55899 .63161 .55011 .62153 .52368 Metetra
0 .47 .139 r
.62153 .52368 .63161 .55011 .65084 .54153 .64076 .51485 Metetra
0 .459 .157 r
.64076 .51485 .65084 .54153 .67019 .53332 .66011 .50644 Metetra
0 .45 .172 r
.66011 .50644 .67019 .53332 .68966 .52549 .67958 .49847 Metetra
0 .443 .183 r
.67958 .49847 .68966 .52549 .70927 .51805 .69919 .49095 Metetra
0 .438 .191 r
.69919 .49095 .70927 .51805 .72903 .511 .71896 .48388 Metetra
0 .434 .196 r
.71896 .48388 .72903 .511 .74894 .5043 .73887 .47721 Metetra
0 .432 .199 r
.73887 .47721 .74894 .5043 .769 .49788 .75895 .47088 Metetra
0 .432 .2 r
.75895 .47088 .769 .49788 .78922 .49166 .77919 .46483 Metetra
0 .432 .2 r
.77919 .46483 .78922 .49166 .80959 .48553 .79959 .45892 Metetra
0 .432 .199 r
.79959 .45892 .80959 .48553 .8301 .47932 .82014 .45303 Metetra
0 .433 .198 r
.82014 .45303 .8301 .47932 .85074 .47288 .84084 .44698 Metetra
0 .432 .2 r
.84084 .44698 .85074 .47288 .87148 .46596 .86165 .44055 Metetra
0 .429 .204 r
.86165 .44055 .87148 .46596 .89228 .45832 .88254 .43348 Metetra
0 .423 .212 r
.88254 .43348 .89228 .45832 .9131 .44964 .90347 .42549 Metetra
0 .413 .225 r
.90347 .42549 .9131 .44964 .93386 .43956 .92439 .41621 Metetra
0 .47 .14 r
.31848 .60096 .32919 .61511 .34598 .62104 .33535 .60574 Metetra
0 .508 .067 r
.33535 .60574 .34598 .62104 .36315 .624 .35257 .60762 Metetra
0 .535 .009 r
.35257 .60762 .36315 .624 .38062 .62435 .37011 .60695 Metetra
.031 .551 0 r
.37011 .60695 .38062 .62435 .39834 .62245 .38789 .60409 Metetra
.052 .56 0 r
.38789 .60409 .39834 .62245 .41628 .61864 .40589 .59939 Metetra
.055 .561 0 r
.40589 .59939 .41628 .61864 .4344 .61322 .42406 .59314 Metetra
.045 .557 0 r
.42406 .59314 .4344 .61322 .45267 .60649 .44237 .58565 Metetra
.023 .548 0 r
.44237 .58565 .45267 .60649 .47106 .59872 .46081 .57718 Metetra
0 .536 .006 r
.46081 .57718 .47106 .59872 .48956 .59015 .47934 .56797 Metetra
0 .521 .039 r
.47934 .56797 .48956 .59015 .50816 .58101 .49797 .55824 Metetra
0 .505 .073 r
.49797 .55824 .50816 .58101 .52684 .57149 .51668 .54819 Metetra
0 .488 .107 r
.51668 .54819 .52684 .57149 .5456 .56178 .53546 .538 Metetra
0 .47 .139 r
.53546 .538 .5456 .56178 .56445 .55201 .55433 .52781 Metetra
0 .453 .168 r
.55433 .52781 .56445 .55201 .58338 .54234 .57328 .51776 Metetra
0 .437 .192 r
.57328 .51776 .58338 .54234 .60241 .53286 .59232 .50796 Metetra
0 .422 .213 r
.59232 .50796 .60241 .53286 .62153 .52368 .61145 .4985 Metetra
0 .408 .23 r
.61145 .4985 .62153 .52368 .64076 .51485 .63069 .48944 Metetra
0 .397 .243 r
.63069 .48944 .64076 .51485 .66011 .50644 .65005 .48085 Metetra
0 .388 .253 r
.65005 .48085 .66011 .50644 .67958 .49847 .66953 .47274 Metetra
0 .38 .261 r
.66953 .47274 .67958 .49847 .69919 .49095 .68915 .46514 Metetra
0 .375 .266 r
.68915 .46514 .69919 .49095 .71896 .48388 .70892 .45802 Metetra
0 .372 .268 r
.70892 .45802 .71896 .48388 .73887 .47721 .72885 .45137 Metetra
0 .371 .27 r
.72885 .45137 .73887 .47721 .75895 .47088 .74895 .44511 Metetra
0 .371 .269 r
.74895 .44511 .75895 .47088 .77919 .46483 .76921 .43918 Metetra
0 .372 .268 r
.76921 .43918 .77919 .46483 .79959 .45892 .78965 .43346 Metetra
0 .374 .266 r
.78965 .43346 .79959 .45892 .82014 .45303 .81024 .42782 Metetra
0 .376 .265 r
.81024 .42782 .82014 .45303 .84084 .44698 .83099 .42209 Metetra
0 .377 .263 r
.83099 .42209 .84084 .44698 .86165 .44055 .85187 .41606 Metetra
0 .377 .264 r
.85187 .41606 .86165 .44055 .88254 .43348 .87285 .40948 Metetra
0 .374 .267 r
.87285 .40948 .88254 .43348 .90347 .42549 .8939 .40206 Metetra
0 .366 .273 r
.8939 .40206 .90347 .42549 .92439 .41621 .91494 .39346 Metetra
0 .449 .174 r
.30766 .58686 .31848 .60096 .33535 .60574 .32459 .59064 Metetra
0 .484 .115 r
.32459 .59064 .33535 .60574 .35257 .60762 .34189 .59156 Metetra
0 .506 .07 r
.34189 .59156 .35257 .60762 .37011 .60695 .35949 .59 Metetra
0 .52 .042 r
.35949 .59 .37011 .60695 .38789 .60409 .37734 .58631 Metetra
0 .525 .031 r
.37734 .58631 .38789 .60409 .40589 .59939 .39539 .58083 Metetra
0 .523 .034 r
.39539 .58083 .40589 .59939 .42406 .59314 .41362 .57386 Metetra
0 .516 .049 r
.41362 .57386 .42406 .59314 .44237 .58565 .43198 .5657 Metetra
0 .505 .073 r
.43198 .5657 .44237 .58565 .46081 .57718 .45047 .55661 Metetra
0 .491 .101 r
.45047 .55661 .46081 .57718 .47934 .56797 .46905 .54683 Metetra
0 .474 .132 r
.46905 .54683 .47934 .56797 .49797 .55824 .48771 .53658 Metetra
0 .456 .163 r
.48771 .53658 .49797 .55824 .51668 .54819 .50646 .52607 Metetra
0 .437 .192 r
.50646 .52607 .51668 .54819 .53546 .538 .52528 .51545 Metetra
0 .418 .218 r
.52528 .51545 .53546 .538 .55433 .52781 .54418 .50488 Metetra
0 .4 .241 r
.54418 .50488 .55433 .52781 .57328 .51776 .56315 .4945 Metetra
0 .382 .259 r
.56315 .4945 .57328 .51776 .59232 .50796 .58221 .4844 Metetra
0 .366 .273 r
.58221 .4844 .59232 .50796 .61145 .4985 .60137 .47469 Metetra
0 .352 .284 r
.60137 .47469 .61145 .4985 .63069 .48944 .62063 .46542 Metetra
0 .34 .292 r
.62063 .46542 .63069 .48944 .65005 .48085 .64 .45666 Metetra
0 .331 .298 r
.64 .45666 .65005 .48085 .66953 .47274 .6595 .44842 Metetra
0 .323 .301 r
.6595 .44842 .66953 .47274 .68915 .46514 .67914 .44072 Metetra
0 .318 .304 r
.67914 .44072 .68915 .46514 .70892 .45802 .69893 .43356 Metetra
0 .315 .305 r
.69893 .43356 .70892 .45802 .72885 .45137 .71888 .4269 Metetra
0 .315 .305 r
.71888 .4269 .72885 .45137 .74895 .44511 .739 .42069 Metetra
0 .316 .305 r
.739 .42069 .74895 .44511 .76921 .43918 .7593 .41485 Metetra
0 .318 .304 r
.7593 .41485 .76921 .43918 .78965 .43346 .77977 .40927 Metetra
0 .321 .302 r
.77977 .40927 .78965 .43346 .81024 .42782 .80041 .40383 Metetra
0 .325 .301 r
.80041 .40383 .81024 .42782 .83099 .42209 .82122 .39836 Metetra
0 .328 .299 r
.82122 .39836 .83099 .42209 .85187 .41606 .84216 .39265 Metetra
0 .329 .298 r
.84216 .39265 .85187 .41606 .87285 .40948 .86323 .38647 Metetra
0 .328 .299 r
.86323 .38647 .87285 .40948 .8939 .40206 .88437 .37953 Metetra
0 .324 .301 r
.88437 .37953 .8939 .40206 .91494 .39346 .90554 .37149 Metetra
0 .43 .201 r
.2967 .57296 .30766 .58686 .32459 .59064 .31371 .57588 Metetra
0 .461 .154 r
.31371 .57588 .32459 .59064 .34189 .59156 .33108 .57598 Metetra
0 .481 .12 r
.33108 .57598 .34189 .59156 .35949 .59 .34874 .57365 Metetra
0 .491 .101 r
.34874 .57365 .35949 .59 .37734 .58631 .36666 .56924 Metetra
0 .494 .096 r
.36666 .56924 .37734 .58631 .39539 .58083 .38478 .56308 Metetra
0 .49 .104 r
.38478 .56308 .39539 .58083 .41362 .57386 .40307 .55549 Metetra
0 .48 .121 r
.40307 .55549 .41362 .57386 .43198 .5657 .42149 .54675 Metetra
0 .467 .145 r
.42149 .54675 .43198 .5657 .45047 .55661 .44003 .53712 Metetra
0 .45 .172 r
.44003 .53712 .45047 .55661 .46905 .54683 .45866 .52685 Metetra
0 .432 .199 r
.45866 .52685 .46905 .54683 .48771 .53658 .47738 .51615 Metetra
0 .412 .226 r
.47738 .51615 .48771 .53658 .50646 .52607 .49617 .50523 Metetra
0 .392 .249 r
.49617 .50523 .50646 .52607 .52528 .51545 .51503 .49424 Metetra
0 .372 .269 r
.51503 .49424 .52528 .51545 .54418 .50488 .53397 .48333 Metetra
0 .352 .284 r
.53397 .48333 .54418 .50488 .56315 .4945 .55298 .47265 Metetra
0 .334 .296 r
.55298 .47265 .56315 .4945 .58221 .4844 .57208 .46229 Metetra
0 .317 .304 r
.57208 .46229 .58221 .4844 .60137 .47469 .59126 .45235 Metetra
0 .296 .303 r
.59126 .45235 .60137 .47469 .62063 .46542 .61055 .44289 Metetra
0 .269 .29 r
.61055 .44289 .62063 .46542 .64 .45666 .62996 .43396 Metetra
0 .247 .28 r
.62996 .43396 .64 .45666 .6595 .44842 .64948 .4256 Metetra
0 .232 .273 r
.64948 .4256 .6595 .44842 .67914 .44072 .66915 .41782 Metetra
0 .222 .268 r
.66915 .41782 .67914 .44072 .69893 .43356 .68897 .4106 Metetra
0 .217 .265 r
.68897 .4106 .69893 .43356 .71888 .4269 .70895 .40392 Metetra
0 .216 .265 r
.70895 .40392 .71888 .4269 .739 .42069 .72911 .39772 Metetra
0 .219 .267 r
.72911 .39772 .739 .42069 .7593 .41485 .74944 .39194 Metetra
0 .226 .27 r
.74944 .39194 .7593 .41485 .77977 .40927 .76995 .38647 Metetra
0 .234 .274 r
.76995 .38647 .77977 .40927 .80041 .40383 .79065 .38117 Metetra
0 .244 .279 r
.79065 .38117 .80041 .40383 .82122 .39836 .81151 .3759 Metetra
0 .254 .283 r
.81151 .3759 .82122 .39836 .84216 .39265 .83253 .37045 Metetra
0 .261 .287 r
.83253 .37045 .84216 .39265 .86323 .38647 .85367 .36458 Metetra
0 .263 .288 r
.85367 .36458 .86323 .38647 .88437 .37953 .87492 .35802 Metetra
0 .258 .286 r
.87492 .35802 .88437 .37953 .90554 .37149 .8962 .35044 Metetra
0 .414 .224 r
.28561 .55939 .2967 .57296 .31371 .57588 .30268 .56158 Metetra
0 .441 .186 r
.30268 .56158 .31371 .57588 .33108 .57598 .32012 .561 Metetra
0 .458 .159 r
.32012 .561 .33108 .57598 .34874 .57365 .33785 .55802 Metetra
0 .466 .146 r
.33785 .55802 .34874 .57365 .36666 .56924 .35584 .553 Metetra
0 .466 .146 r
.35584 .553 .36666 .56924 .38478 .56308 .37403 .54627 Metetra
0 .46 .156 r
.37403 .54627 .38478 .56308 .40307 .55549 .39238 .53814 Metetra
0 .449 .174 r
.39238 .53814 .40307 .55549 .42149 .54675 .41088 .52891 Metetra
0 .434 .197 r
.41088 .52891 .42149 .54675 .44003 .53712 .42948 .51882 Metetra
0 .415 .221 r
.42948 .51882 .44003 .53712 .45866 .52685 .44817 .50813 Metetra
0 .395 .245 r
.44817 .50813 .45866 .52685 .47738 .51615 .46695 .49704 Metetra
0 .374 .266 r
.46695 .49704 .47738 .51615 .49617 .50523 .48579 .48576 Metetra
0 .353 .284 r
.48579 .48576 .49617 .50523 .51503 .49424 .50471 .47445 Metetra
0 .332 .297 r
.50471 .47445 .51503 .49424 .53397 .48333 .5237 .46325 Metetra
0 .311 .306 r
.5237 .46325 .53397 .48333 .55298 .47265 .54276 .45231 Metetra
0 .273 .292 r
.54276 .45231 .55298 .47265 .57208 .46229 .5619 .44172 Metetra
0 .236 .275 r
.5619 .44172 .57208 .46229 .59126 .45235 .58113 .43157 Metetra
0 .206 .26 r
.58113 .43157 .59126 .45235 .61055 .44289 .60046 .42193 Metetra
0 .183 .247 r
.60046 .42193 .61055 .44289 .62996 .43396 .6199 .41286 Metetra
0 .165 .237 r
.6199 .41286 .62996 .43396 .64948 .4256 .63947 .40438 Metetra
0 .152 .23 r
.63947 .40438 .64948 .4256 .66915 .41782 .65918 .3965 Metetra
0 .144 .225 r
.65918 .3965 .66915 .41782 .68897 .4106 .67904 .38921 Metetra
0 .14 .222 r
.67904 .38921 .68897 .4106 .70895 .40392 .69906 .3825 Metetra
0 .14 .222 r
.69906 .3825 .70895 .40392 .72911 .39772 .71925 .3763 Metetra
0 .144 .224 r
.71925 .3763 .72911 .39772 .74944 .39194 .73963 .37055 Metetra
0 .15 .228 r
.73963 .37055 .74944 .39194 .76995 .38647 .7602 .36514 Metetra
0 .158 .234 r
.7602 .36514 .76995 .38647 .79065 .38117 .78094 .35996 Metetra
0 .168 .239 r
.78094 .35996 .79065 .38117 .81151 .3759 .80187 .35483 Metetra
0 .179 .245 r
.80187 .35483 .81151 .3759 .83253 .37045 .82296 .34956 Metetra
0 .187 .25 r
.82296 .34956 .83253 .37045 .85367 .36458 .84419 .34394 Metetra
0 .193 .253 r
.84419 .34394 .85367 .36458 .87492 .35802 .86553 .33767 Metetra
0 .192 .252 r
.86553 .33767 .87492 .35802 .8962 .35044 .88693 .33044 Metetra
0 .399 .241 r
.27436 .54624 .28561 .55939 .30268 .56158 .2915 .54784 Metetra
0 .424 .21 r
.2915 .54784 .30268 .56158 .32012 .561 .309 .5467 Metetra
0 .439 .189 r
.309 .5467 .32012 .561 .33785 .55802 .32681 .5432 Metetra
0 .445 .18 r
.32681 .5432 .33785 .55802 .35584 .553 .34487 .53768 Metetra
0 .443 .183 r
.34487 .53768 .35584 .553 .37403 .54627 .36313 .53048 Metetra
0 .435 .195 r
.36313 .53048 .37403 .54627 .39238 .53814 .38156 .52191 Metetra
0 .422 .212 r
.38156 .52191 .39238 .53814 .41088 .52891 .40012 .51226 Metetra
0 .406 .233 r
.40012 .51226 .41088 .52891 .42948 .51882 .41879 .50179 Metetra
0 .386 .255 r
.41879 .50179 .42948 .51882 .44817 .50813 .43756 .49074 Metetra
0 .365 .274 r
.43756 .49074 .44817 .50813 .46695 .49704 .4564 .47933 Metetra
0 .343 .291 r
.4564 .47933 .46695 .49704 .48579 .48576 .47532 .46775 Metetra
0 .32 .303 r
.47532 .46775 .48579 .48576 .50471 .47445 .4943 .45616 Metetra
0 .286 .298 r
.4943 .45616 .50471 .47445 .5237 .46325 .51334 .44471 Metetra
0 .241 .277 r
.51334 .44471 .5237 .46325 .54276 .45231 .53246 .43354 Metetra
0 .202 .258 r
.53246 .43354 .54276 .45231 .5619 .44172 .55166 .42274 Metetra
0 .169 .24 r
.55166 .42274 .5619 .44172 .58113 .43157 .57095 .41241 Metetra
0 .144 .224 r
.57095 .41241 .58113 .43157 .60046 .42193 .59033 .40262 Metetra
0 .123 .211 r
.59033 .40262 .60046 .42193 .6199 .41286 .60982 .3934 Metetra
0 .108 .201 r
.60982 .3934 .6199 .41286 .63947 .40438 .62944 .3848 Metetra
0 .098 .194 r
.62944 .3848 .63947 .40438 .65918 .3965 .6492 .37683 Metetra
0 .091 .189 r
.6492 .37683 .65918 .3965 .67904 .38921 .66911 .36948 Metetra
0 .089 .186 r
.66911 .36948 .67904 .38921 .69906 .3825 .68918 .36272 Metetra
0 .089 .187 r
.68918 .36272 .69906 .3825 .71925 .3763 .70943 .3565 Metetra
0 .092 .189 r
.70943 .3565 .71925 .3763 .73963 .37055 .72986 .35075 Metetra
0 .098 .194 r
.72986 .35075 .73963 .37055 .7602 .36514 .75049 .34538 Metetra
0 .106 .2 r
.75049 .34538 .7602 .36514 .78094 .35996 .7713 .34025 Metetra
0 .116 .206 r
.7713 .34025 .78094 .35996 .80187 .35483 .79229 .33521 Metetra
0 .126 .213 r
.79229 .33521 .80187 .35483 .82296 .34956 .81346 .33008 Metetra
0 .135 .219 r
.81346 .33008 .82296 .34956 .84419 .34394 .83477 .32462 Metetra
0 .142 .223 r
.83477 .32462 .84419 .34394 .86553 .33767 .85621 .31857 Metetra
0 .144 .224 r
.85621 .31857 .86553 .33767 .88693 .33044 .87772 .31159 Metetra
0 .387 .254 r
.26294 .5336 .27436 .54624 .2915 .54784 .28014 .53475 Metetra
0 .411 .227 r
.28014 .53475 .2915 .54784 .309 .5467 .29771 .53318 Metetra
0 .424 .21 r
.29771 .53318 .309 .5467 .32681 .5432 .31559 .52926 Metetra
0 .428 .205 r
.31559 .52926 .32681 .5432 .34487 .53768 .33372 .52335 Metetra
0 .425 .209 r
.33372 .52335 .34487 .53768 .36313 .53048 .35206 .51577 Metetra
0 .416 .221 r
.35206 .51577 .36313 .53048 .38156 .52191 .37057 .50686 Metetra
0 .402 .238 r
.37057 .50686 .38156 .52191 .40012 .51226 .38921 .49688 Metetra
0 .384 .257 r
.38921 .49688 .40012 .51226 .41879 .50179 .40796 .4861 Metetra
0 .363 .276 r
.40796 .4861 .41879 .50179 .43756 .49074 .42681 .47476 Metetra
0 .341 .292 r
.42681 .47476 .43756 .49074 .4564 .47933 .44573 .46308 Metetra
0 .318 .304 r
.44573 .46308 .4564 .47933 .47532 .46775 .46472 .45124 Metetra
0 .279 .295 r
.46472 .45124 .47532 .46775 .4943 .45616 .48377 .43942 Metetra
0 .23 .272 r
.48377 .43942 .4943 .45616 .51334 .44471 .50289 .42776 Metetra
0 .188 .25 r
.50289 .42776 .51334 .44471 .53246 .43354 .52208 .4164 Metetra
0 .153 .23 r
.52208 .4164 .53246 .43354 .55166 .42274 .54135 .40542 Metetra
0 .125 .212 r
.54135 .40542 .55166 .42274 .57095 .41241 .5607 .39493 Metetra
0 .102 .197 r
.5607 .39493 .57095 .41241 .59033 .40262 .58015 .38499 Metetra
0 .084 .183 r
.58015 .38499 .59033 .40262 .60982 .3934 .59971 .37565 Metetra
0 .072 .173 r
.59971 .37565 .60982 .3934 .62944 .3848 .61939 .36694 Metetra
0 .063 .165 r
.61939 .36694 .62944 .3848 .6492 .37683 .63921 .35888 Metetra
0 .058 .16 r
.63921 .35888 .6492 .37683 .66911 .36948 .65918 .35145 Metetra
0 .056 .158 r
.65918 .35145 .66911 .36948 .68918 .36272 .67932 .34463 Metetra
0 .056 .159 r
.67932 .34463 .68918 .36272 .70943 .3565 .69963 .33837 Metetra
0 .059 .162 r
.69963 .33837 .70943 .3565 .72986 .35075 .72012 .3326 Metetra
0 .065 .167 r
.72012 .3326 .72986 .35075 .75049 .34538 .74081 .32723 Metetra
0 .072 .173 r
.74081 .32723 .75049 .34538 .7713 .34025 .7617 .32212 Metetra
0 .081 .18 r
.7617 .32212 .7713 .34025 .79229 .33521 .78277 .31713 Metetra
0 .09 .188 r
.78277 .31713 .79229 .33521 .81346 .33008 .80402 .31207 Metetra
0 .099 .195 r
.80402 .31207 .81346 .33008 .83477 .32462 .82542 .30671 Metetra
0 .107 .2 r
.82542 .30671 .83477 .32462 .85621 .31857 .84695 .30078 Metetra
0 .11 .202 r
.84695 .30078 .85621 .31857 .87772 .31159 .86857 .29397 Metetra
0 .379 .262 r
.25134 .52154 .26294 .5336 .28014 .53475 .26859 .52237 Metetra
0 .401 .239 r
.26859 .52237 .28014 .53475 .29771 .53318 .28622 .52049 Metetra
0 .413 .225 r
.28622 .52049 .29771 .53318 .31559 .52926 .30417 .51627 Metetra
0 .416 .221 r
.30417 .51627 .31559 .52926 .33372 .52335 .32238 .51006 Metetra
0 .412 .226 r
.32238 .51006 .33372 .52335 .35206 .51577 .3408 .50222 Metetra
0 .402 .238 r
.3408 .50222 .35206 .51577 .37057 .50686 .3594 .49304 Metetra
0 .387 .254 r
.3594 .49304 .37057 .50686 .38921 .49688 .37812 .48281 Metetra
0 .368 .272 r
.37812 .48281 .38921 .49688 .40796 .4861 .39696 .47179 Metetra
0 .347 .288 r
.39696 .47179 .40796 .4861 .42681 .47476 .41589 .46023 Metetra
0 .324 .301 r
.41589 .46023 .42681 .47476 .44573 .46308 .4349 .44834 Metetra
0 .291 .3 r
.4349 .44834 .44573 .46308 .46472 .45124 .45398 .4363 Metetra
0 .239 .276 r
.45398 .4363 .46472 .45124 .48377 .43942 .47312 .42429 Metetra
0 .194 .253 r
.47312 .42429 .48377 .43942 .50289 .42776 .49232 .41246 Metetra
0 .155 .231 r
.49232 .41246 .50289 .42776 .52208 .4164 .51159 .40093 Metetra
0 .122 .211 r
.51159 .40093 .52208 .4164 .54135 .40542 .53094 .3898 Metetra
0 .096 .192 r
.53094 .3898 .54135 .40542 .5607 .39493 .55037 .37917 Metetra
0 .076 .176 r
.55037 .37917 .5607 .39493 .58015 .38499 .5699 .36911 Metetra
0 .061 .163 r
.5699 .36911 .58015 .38499 .59971 .37565 .58953 .35965 Metetra
0 .05 .152 r
.58953 .35965 .59971 .37565 .61939 .36694 .60929 .35084 Metetra
0 .043 .145 r
.60929 .35084 .61939 .36694 .63921 .35888 .62919 .34268 Metetra
0 .038 .14 r
.62919 .34268 .63921 .35888 .65918 .35145 .64923 .33517 Metetra
0 .037 .138 r
.64923 .33517 .65918 .35145 .67932 .34463 .66944 .32828 Metetra
0 .037 .139 r
.66944 .32828 .67932 .34463 .69963 .33837 .68983 .32196 Metetra
0 .04 .142 r
.68983 .32196 .69963 .33837 .72012 .3326 .7104 .31615 Metetra
0 .045 .147 r
.7104 .31615 .72012 .3326 .74081 .32723 .73117 .31074 Metetra
0 .051 .154 r
.73117 .31074 .74081 .32723 .7617 .32212 .75213 .30562 Metetra
0 .059 .162 r
.75213 .30562 .7617 .32212 .78277 .31713 .77329 .30063 Metetra
0 .068 .17 r
.77329 .30063 .78277 .31713 .80402 .31207 .79462 .29558 Metetra
0 .077 .177 r
.79462 .29558 .80402 .31207 .82542 .30671 .81612 .29025 Metetra
0 .084 .183 r
.81612 .29025 .82542 .30671 .84695 .30078 .83776 .28438 Metetra
0 .088 .186 r
.83776 .28438 .84695 .30078 .86857 .29397 .85949 .27764 Metetra
0 .374 .267 r
.23953 .51009 .25134 .52154 .26859 .52237 .25684 .51074 Metetra
0 .395 .245 r
.25684 .51074 .26859 .52237 .28622 .52049 .27453 .50866 Metetra
0 .406 .233 r
.27453 .50866 .28622 .52049 .30417 .51627 .29255 .50426 Metetra
0 .409 .23 r
.29255 .50426 .30417 .51627 .32238 .51006 .31084 .49787 Metetra
0 .404 .236 r
.31084 .49787 .32238 .51006 .3408 .50222 .32934 .48985 Metetra
0 .393 .248 r
.32934 .48985 .3408 .50222 .3594 .49304 .34802 .48049 Metetra
0 .377 .263 r
.34802 .48049 .3594 .49304 .37812 .48281 .36684 .47009 Metetra
0 .358 .28 r
.36684 .47009 .37812 .48281 .39696 .47179 .38578 .45891 Metetra
0 .337 .294 r
.38578 .45891 .39696 .47179 .41589 .46023 .4048 .44719 Metetra
0 .313 .306 r
.4048 .44719 .41589 .46023 .4349 .44834 .42391 .43514 Metetra
0 .267 .289 r
.42391 .43514 .4349 .44834 .45398 .4363 .44308 .42295 Metetra
0 .217 .265 r
.44308 .42295 .45398 .4363 .47312 .42429 .46231 .4108 Metetra
0 .173 .242 r
.46231 .4108 .47312 .42429 .49232 .41246 .48161 .39883 Metetra
0 .136 .22 r
.48161 .39883 .49232 .41246 .51159 .40093 .50098 .38717 Metetra
0 .105 .199 r
.50098 .38717 .51159 .40093 .53094 .3898 .52042 .37592 Metetra
0 .081 .18 r
.52042 .37592 .53094 .3898 .55037 .37917 .53994 .36517 Metetra
0 .062 .164 r
.53994 .36517 .55037 .37917 .5699 .36911 .55956 .35499 Metetra
0 .048 .151 r
.55956 .35499 .5699 .36911 .58953 .35965 .57929 .34543 Metetra
0 .038 .14 r
.57929 .34543 .58953 .35965 .60929 .35084 .59913 .33651 Metetra
0 .032 .132 r
.59913 .33651 .60929 .35084 .62919 .34268 .61911 .32826 Metetra
0 .028 .128 r
.61911 .32826 .62919 .34268 .64923 .33517 .63925 .32066 Metetra
0 .027 .126 r
.63925 .32066 .64923 .33517 .66944 .32828 .65954 .31369 Metetra
0 .027 .127 r
.65954 .31369 .66944 .32828 .68983 .32196 .68002 .3073 Metetra
0 .03 .13 r
.68002 .3073 .68983 .32196 .7104 .31615 .70068 .30142 Metetra
0 .034 .135 r
.70068 .30142 .7104 .31615 .73117 .31074 .72154 .29595 Metetra
0 .04 .142 r
.72154 .29595 .73117 .31074 .75213 .30562 .74259 .29077 Metetra
0 .048 .15 r
.74259 .29077 .75213 .30562 .77329 .30063 .76384 .28573 Metetra
0 .056 .159 r
.76384 .28573 .77329 .30063 .79462 .29558 .78527 .28065 Metetra
0 .065 .167 r
.78527 .28065 .79462 .29558 .81612 .29025 .80687 .27529 Metetra
0 .072 .173 r
.80687 .27529 .81612 .29025 .83776 .28438 .82862 .26939 Metetra
0 .076 .177 r
.82862 .26939 .83776 .28438 .85949 .27764 .85045 .26264 Metetra
0 .372 .268 r
.22751 .49929 .23953 .51009 .25684 .51074 .24486 .49987 Metetra
0 .393 .248 r
.24486 .49987 .25684 .51074 .27453 .50866 .26261 .49774 Metetra
0 .404 .235 r
.26261 .49774 .27453 .50866 .29255 .50426 .2807 .49326 Metetra
0 .406 .233 r
.2807 .49326 .29255 .50426 .31084 .49787 .29907 .4868 Metetra
0 .401 .239 r
.29907 .4868 .31084 .49787 .32934 .48985 .31766 .47869 Metetra
0 .39 .251 r
.31766 .47869 .32934 .48985 .34802 .48049 .33643 .46924 Metetra
0 .374 .266 r
.33643 .46924 .34802 .48049 .36684 .47009 .35535 .45875 Metetra
0 .355 .282 r
.35535 .45875 .36684 .47009 .38578 .45891 .37438 .44747 Metetra
0 .333 .296 r
.37438 .44747 .38578 .45891 .4048 .44719 .39351 .43565 Metetra
0 .31 .307 r
.39351 .43565 .4048 .44719 .42391 .43514 .41272 .42351 Metetra
0 .259 .286 r
.41272 .42351 .42391 .43514 .44308 .42295 .432 .41122 Metetra
0 .209 .262 r
.432 .41122 .44308 .42295 .46231 .4108 .45134 .39897 Metetra
0 .166 .238 r
.45134 .39897 .46231 .4108 .48161 .39883 .47075 .3869 Metetra
0 .13 .216 r
.47075 .3869 .48161 .39883 .50098 .38717 .49022 .37514 Metetra
0 .1 .195 r
.49022 .37514 .50098 .38717 .52042 .37592 .50976 .36379 Metetra
0 .076 .176 r
.50976 .36379 .52042 .37592 .53994 .36517 .52939 .35294 Metetra
0 .058 .16 r
.52939 .35294 .53994 .36517 .55956 .35499 .54911 .34267 Metetra
0 .044 .147 r
.54911 .34267 .55956 .35499 .57929 .34543 .56894 .33301 Metetra
0 .035 .136 r
.56894 .33301 .57929 .34543 .59913 .33651 .58889 .324 Metetra
0 .029 .128 r
.58889 .324 .59913 .33651 .61911 .32826 .60897 .31565 Metetra
0 .025 .124 r
.60897 .31565 .61911 .32826 .63925 .32066 .62921 .30796 Metetra
0 .024 .122 r
.62921 .30796 .63925 .32066 .65954 .31369 .6496 .30089 Metetra
0 .024 .123 r
.6496 .30089 .65954 .31369 .68002 .3073 .67018 .29441 Metetra
0 .027 .126 r
.67018 .29441 .68002 .3073 .70068 .30142 .69094 .28844 Metetra
0 .031 .131 r
.69094 .28844 .70068 .30142 .72154 .29595 .7119 .28288 Metetra
0 .037 .138 r
.7119 .28288 .72154 .29595 .74259 .29077 .73305 .27761 Metetra
0 .044 .146 r
.73305 .27761 .74259 .29077 .76384 .28573 .75441 .27248 Metetra
0 .052 .155 r
.75441 .27248 .76384 .28573 .78527 .28065 .77595 .2673 Metetra
0 .061 .163 r
.77595 .2673 .78527 .28065 .80687 .27529 .79766 .26185 Metetra
0 .068 .17 r
.79766 .26185 .80687 .27529 .82862 .26939 .81951 .25585 Metetra
0 .073 .173 r
.81951 .25585 .82862 .26939 .85045 .26264 .84147 .249 Metetra
0 .374 .267 r
.21526 .48912 .22751 .49929 .24486 .49987 .23265 .48979 Metetra
0 .395 .245 r
.23265 .48979 .24486 .49987 .26261 .49774 .25046 .48772 Metetra
0 .406 .233 r
.25046 .48772 .26261 .49774 .2807 .49326 .26861 .48328 Metetra
0 .409 .23 r
.26861 .48328 .2807 .49326 .29907 .4868 .28706 .47685 Metetra
0 .404 .236 r
.28706 .47685 .29907 .4868 .31766 .47869 .30573 .46875 Metetra
0 .393 .248 r
.30573 .46875 .31766 .47869 .33643 .46924 .3246 .4593 Metetra
0 .377 .263 r
.3246 .4593 .33643 .46924 .35535 .45875 .34362 .4488 Metetra
0 .358 .28 r
.34362 .4488 .35535 .45875 .37438 .44747 .36276 .4375 Metetra
0 .337 .294 r
.36276 .4375 .37438 .44747 .39351 .43565 .382 .42565 Metetra
0 .313 .306 r
.382 .42565 .39351 .43565 .41272 .42351 .40132 .41346 Metetra
0 .267 .289 r
.40132 .41346 .41272 .42351 .432 .41122 .42071 .40112 Metetra
0 .217 .265 r
.42071 .40112 .432 .41122 .45134 .39897 .44017 .38881 Metetra
0 .173 .242 r
.44017 .38881 .45134 .39897 .47075 .3869 .4597 .37668 Metetra
0 .136 .22 r
.4597 .37668 .47075 .3869 .49022 .37514 .47929 .36485 Metetra
0 .105 .199 r
.47929 .36485 .49022 .37514 .50976 .36379 .49895 .35343 Metetra
0 .081 .18 r
.49895 .35343 .50976 .36379 .52939 .35294 .5187 .34251 Metetra
0 .062 .164 r
.5187 .34251 .52939 .35294 .54911 .34267 .53854 .33215 Metetra
0 .048 .151 r
.53854 .33215 .54911 .34267 .56894 .33301 .55848 .3224 Metetra
0 .038 .14 r
.55848 .3224 .56894 .33301 .58889 .324 .57854 .3133 Metetra
0 .032 .132 r
.57854 .3133 .58889 .324 .60897 .31565 .59874 .30486 Metetra
0 .028 .128 r
.59874 .30486 .60897 .31565 .62921 .30796 .61909 .29707 Metetra
0 .027 .126 r
.61909 .29707 .62921 .30796 .6496 .30089 .6396 .2899 Metetra
0 .027 .127 r
.6396 .2899 .6496 .30089 .67018 .29441 .66029 .28331 Metetra
0 .03 .13 r
.66029 .28331 .67018 .29441 .69094 .28844 .68117 .27722 Metetra
0 .034 .135 r
.68117 .27722 .69094 .28844 .7119 .28288 .70224 .27154 Metetra
0 .04 .142 r
.70224 .27154 .7119 .28288 .73305 .27761 .72351 .26614 Metetra
0 .048 .15 r
.72351 .26614 .73305 .27761 .75441 .27248 .74497 .26087 Metetra
0 .056 .159 r
.74497 .26087 .75441 .27248 .77595 .2673 .76663 .25554 Metetra
0 .065 .167 r
.76663 .25554 .77595 .2673 .79766 .26185 .78846 .24993 Metetra
0 .072 .173 r
.78846 .24993 .79766 .26185 .81951 .25585 .81043 .24376 Metetra
0 .076 .177 r
.81043 .24376 .81951 .25585 .84147 .249 .83251 .23672 Metetra
0 .379 .262 r
.20278 .47958 .21526 .48912 .23265 .48979 .22019 .48047 Metetra
0 .401 .239 r
.22019 .48047 .23265 .48979 .25046 .48772 .23805 .47858 Metetra
0 .413 .225 r
.23805 .47858 .25046 .48772 .26861 .48328 .25626 .47431 Metetra
0 .416 .221 r
.25626 .47431 .26861 .48328 .28706 .47685 .27478 .46801 Metetra
0 .412 .226 r
.27478 .46801 .28706 .47685 .30573 .46875 .29354 .46003 Metetra
0 .402 .238 r
.29354 .46003 .30573 .46875 .3246 .4593 .31251 .45067 Metetra
0 .387 .254 r
.31251 .45067 .3246 .4593 .34362 .4488 .33163 .44023 Metetra
0 .368 .272 r
.33163 .44023 .34362 .4488 .36276 .4375 .35088 .42898 Metetra
0 .347 .288 r
.35088 .42898 .36276 .4375 .382 .42565 .37024 .41716 Metetra
0 .324 .301 r
.37024 .41716 .382 .42565 .40132 .41346 .38968 .40499 Metetra
0 .291 .3 r
.38968 .40499 .40132 .41346 .42071 .40112 .4092 .39265 Metetra
0 .239 .276 r
.4092 .39265 .42071 .40112 .44017 .38881 .42879 .38034 Metetra
0 .194 .253 r
.42879 .38034 .44017 .38881 .4597 .37668 .44844 .36818 Metetra
0 .155 .231 r
.44844 .36818 .4597 .37668 .47929 .36485 .46816 .35631 Metetra
0 .122 .211 r
.46816 .35631 .47929 .36485 .49895 .35343 .48796 .34484 Metetra
0 .096 .192 r
.48796 .34484 .49895 .35343 .5187 .34251 .50784 .33386 Metetra
0 .076 .176 r
.50784 .33386 .5187 .34251 .53854 .33215 .52781 .32344 Metetra
0 .061 .163 r
.52781 .32344 .53854 .33215 .55848 .3224 .54788 .31361 Metetra
0 .05 .152 r
.54788 .31361 .55848 .3224 .57854 .3133 .56807 .30443 Metetra
0 .043 .145 r
.56807 .30443 .57854 .3133 .59874 .30486 .5884 .29589 Metetra
0 .038 .14 r
.5884 .29589 .59874 .30486 .61909 .29707 .60888 .28799 Metetra
0 .037 .138 r
.60888 .28799 .61909 .29707 .6396 .2899 .62952 .28071 Metetra
0 .037 .139 r
.62952 .28071 .6396 .2899 .66029 .28331 .65033 .27399 Metetra
0 .04 .142 r
.65033 .27399 .66029 .28331 .68117 .27722 .67134 .26776 Metetra
0 .045 .147 r
.67134 .26776 .68117 .27722 .70224 .27154 .69253 .26192 Metetra
0 .051 .154 r
.69253 .26192 .70224 .27154 .72351 .26614 .71393 .25636 Metetra
0 .059 .162 r
.71393 .25636 .72351 .26614 .74497 .26087 .73552 .25091 Metetra
0 .068 .17 r
.73552 .25091 .74497 .26087 .76663 .25554 .75731 .24537 Metetra
0 .077 .177 r
.75731 .24537 .76663 .25554 .78846 .24993 .77926 .23954 Metetra
0 .084 .183 r
.77926 .23954 .78846 .24993 .81043 .24376 .80136 .23312 Metetra
0 .088 .186 r
.80136 .23312 .81043 .24376 .83251 .23672 .82357 .2258 Metetra
0 .387 .254 r
.19005 .47064 .20278 .47958 .22019 .48047 .20748 .47188 Metetra
0 .411 .227 r
.20748 .47188 .22019 .48047 .23805 .47858 .22537 .47032 Metetra
0 .424 .21 r
.22537 .47032 .23805 .47858 .25626 .47431 .24364 .46633 Metetra
0 .428 .205 r
.24364 .46633 .25626 .47431 .27478 .46801 .26223 .46027 Metetra
0 .425 .209 r
.26223 .46027 .27478 .46801 .29354 .46003 .28108 .4525 Metetra
0 .416 .221 r
.28108 .4525 .29354 .46003 .31251 .45067 .30014 .44332 Metetra
0 .402 .238 r
.30014 .44332 .31251 .45067 .33163 .44023 .31937 .43304 Metetra
0 .384 .257 r
.31937 .43304 .33163 .44023 .35088 .42898 .33873 .42191 Metetra
0 .363 .276 r
.33873 .42191 .35088 .42898 .37024 .41716 .35821 .41019 Metetra
0 .341 .292 r
.35821 .41019 .37024 .41716 .38968 .40499 .37779 .39809 Metetra
0 .318 .304 r
.37779 .39809 .38968 .40499 .4092 .39265 .39744 .38581 Metetra
0 .279 .295 r
.39744 .38581 .4092 .39265 .42879 .38034 .41717 .37352 Metetra
0 .23 .272 r
.41717 .37352 .42879 .38034 .44844 .36818 .43696 .36138 Metetra
0 .188 .25 r
.43696 .36138 .44844 .36818 .46816 .35631 .45682 .34951 Metetra
0 .153 .23 r
.45682 .34951 .46816 .35631 .48796 .34484 .47676 .33802 Metetra
0 .125 .212 r
.47676 .33802 .48796 .34484 .50784 .33386 .49678 .327 Metetra
0 .102 .197 r
.49678 .327 .50784 .33386 .52781 .32344 .5169 .31652 Metetra
0 .084 .183 r
.5169 .31652 .52781 .32344 .54788 .31361 .53712 .30664 Metetra
0 .072 .173 r
.53712 .30664 .54788 .31361 .56807 .30443 .55745 .29737 Metetra
0 .063 .165 r
.55745 .29737 .56807 .30443 .5884 .29589 .57793 .28874 Metetra
0 .058 .16 r
.57793 .28874 .5884 .29589 .60888 .28799 .59854 .28073 Metetra
0 .056 .158 r
.59854 .28073 .60888 .28799 .62952 .28071 .61933 .27331 Metetra
0 .056 .159 r
.61933 .27331 .62952 .28071 .65033 .27399 .64028 .26645 Metetra
0 .059 .162 r
.64028 .26645 .65033 .27399 .67134 .26776 .66143 .26005 Metetra
0 .065 .167 r
.66143 .26005 .67134 .26776 .69253 .26192 .68277 .25403 Metetra
0 .072 .173 r
.68277 .25403 .69253 .26192 .71393 .25636 .7043 .24826 Metetra
0 .081 .18 r
.7043 .24826 .71393 .25636 .73552 .25091 .72604 .24257 Metetra
0 .09 .188 r
.72604 .24257 .73552 .25091 .75731 .24537 .74796 .23678 Metetra
0 .099 .195 r
.74796 .23678 .75731 .24537 .77926 .23954 .77005 .23064 Metetra
0 .107 .2 r
.77005 .23064 .77926 .23954 .80136 .23312 .79228 .22389 Metetra
0 .11 .202 r
.79228 .22389 .80136 .23312 .82357 .2258 .81462 .2162 Metetra
0 .399 .241 r
.17707 .46224 .19005 .47064 .20748 .47188 .19449 .46398 Metetra
0 .424 .21 r
.19449 .46398 .20748 .47188 .22537 .47032 .21241 .46287 Metetra
0 .439 .189 r
.21241 .46287 .22537 .47032 .24364 .46633 .23072 .45928 Metetra
0 .445 .18 r
.23072 .45928 .24364 .46633 .26223 .46027 .24938 .45359 Metetra
0 .443 .183 r
.24938 .45359 .26223 .46027 .28108 .4525 .26831 .44613 Metetra
0 .435 .195 r
.26831 .44613 .28108 .4525 .30014 .44332 .28747 .43723 Metetra
0 .422 .212 r
.28747 .43723 .30014 .44332 .31937 .43304 .30681 .42718 Metetra
0 .406 .233 r
.30681 .42718 .31937 .43304 .33873 .42191 .32629 .41625 Metetra
0 .386 .255 r
.32629 .41625 .33873 .42191 .35821 .41019 .3459 .4047 Metetra
0 .365 .274 r
.3459 .4047 .35821 .41019 .37779 .39809 .36561 .39273 Metetra
0 .343 .291 r
.36561 .39273 .37779 .39809 .39744 .38581 .38541 .38056 Metetra
0 .32 .303 r
.38541 .38056 .39744 .38581 .41717 .37352 .40528 .36836 Metetra
0 .286 .298 r
.40528 .36836 .41717 .37352 .43696 .36138 .42522 .35627 Metetra
0 .241 .277 r
.42522 .35627 .43696 .36138 .45682 .34951 .44524 .34443 Metetra
0 .202 .258 r
.44524 .34443 .45682 .34951 .47676 .33802 .46534 .33295 Metetra
0 .169 .24 r
.46534 .33295 .47676 .33802 .49678 .327 .48551 .32191 Metetra
0 .144 .224 r
.48551 .32191 .49678 .327 .5169 .31652 .50579 .3114 Metetra
0 .123 .211 r
.50579 .3114 .5169 .31652 .53712 .30664 .52616 .30145 Metetra
0 .108 .201 r
.52616 .30145 .53712 .30664 .55745 .29737 .54666 .29211 Metetra
0 .098 .194 r
.54666 .29211 .55745 .29737 .57793 .28874 .56729 .28338 Metetra
0 .091 .189 r
.56729 .28338 .57793 .28874 .59854 .28073 .58807 .27525 Metetra
0 .089 .186 r
.58807 .27525 .59854 .28073 .61933 .27331 .60901 .26769 Metetra
0 .089 .187 r
.60901 .26769 .61933 .27331 .64028 .26645 .63012 .26066 Metetra
0 .092 .189 r
.63012 .26066 .64028 .26645 .66143 .26005 .65142 .25408 Metetra
0 .098 .194 r
.65142 .25408 .66143 .26005 .68277 .25403 .67292 .24784 Metetra
0 .106 .2 r
.67292 .24784 .68277 .25403 .7043 .24826 .69461 .24181 Metetra
0 .116 .206 r
.69461 .24181 .7043 .24826 .72604 .24257 .71649 .23584 Metetra
0 .126 .213 r
.71649 .23584 .72604 .24257 .74796 .23678 .73856 .22972 Metetra
0 .135 .219 r
.73856 .22972 .74796 .23678 .77005 .23064 .7608 .22322 Metetra
0 .142 .223 r
.7608 .22322 .77005 .23064 .79228 .22389 .78318 .21605 Metetra
0 .144 .224 r
.78318 .21605 .79228 .22389 .81462 .2162 .80565 .20789 Metetra
0 .414 .224 r
.16382 .4543 .17707 .46224 .19449 .46398 .18123 .45669 Metetra
0 .441 .186 r
.18123 .45669 .19449 .46398 .21241 .46287 .19916 .45616 Metetra
0 .458 .159 r
.19916 .45616 .21241 .46287 .23072 .45928 .21751 .45311 Metetra
0 .466 .146 r
.21751 .45311 .23072 .45928 .24938 .45359 .23622 .44789 Metetra
0 .466 .146 r
.23622 .44789 .24938 .45359 .26831 .44613 .25523 .44086 Metetra
0 .46 .156 r
.25523 .44086 .26831 .44613 .28747 .43723 .27448 .43233 Metetra
0 .449 .174 r
.27448 .43233 .28747 .43723 .30681 .42718 .29393 .42261 Metetra
0 .434 .197 r
.29393 .42261 .30681 .42718 .32629 .41625 .31354 .41197 Metetra
0 .415 .221 r
.31354 .41197 .32629 .41625 .3459 .4047 .33328 .40065 Metetra
0 .395 .245 r
.33328 .40065 .3459 .4047 .36561 .39273 .35313 .38889 Metetra
0 .374 .266 r
.35313 .38889 .36561 .39273 .38541 .38056 .37308 .37688 Metetra
0 .353 .284 r
.37308 .37688 .38541 .38056 .40528 .36836 .39311 .3648 Metetra
0 .332 .297 r
.39311 .3648 .40528 .36836 .42522 .35627 .41321 .35281 Metetra
0 .311 .306 r
.41321 .35281 .42522 .35627 .44524 .34443 .43339 .34103 Metetra
0 .273 .292 r
.43339 .34103 .44524 .34443 .46534 .33295 .45366 .32959 Metetra
0 .236 .275 r
.45366 .32959 .46534 .33295 .48551 .32191 .474 .31856 Metetra
0 .206 .26 r
.474 .31856 .48551 .32191 .50579 .3114 .49445 .30803 Metetra
0 .183 .247 r
.49445 .30803 .50579 .3114 .52616 .30145 .515 .29804 Metetra
0 .165 .237 r
.515 .29804 .52616 .30145 .54666 .29211 .53567 .28862 Metetra
0 .152 .23 r
.53567 .28862 .54666 .29211 .56729 .28338 .55647 .27979 Metetra
0 .144 .225 r
.55647 .27979 .56729 .28338 .58807 .27525 .57742 .27153 Metetra
0 .14 .222 r
.57742 .27153 .58807 .27525 .60901 .26769 .59854 .26382 Metetra
0 .14 .222 r
.59854 .26382 .60901 .26769 .63012 .26066 .61982 .2566 Metetra
0 .144 .224 r
.61982 .2566 .63012 .26066 .65142 .25408 .64129 .2498 Metetra
0 .15 .228 r
.64129 .2498 .65142 .25408 .67292 .24784 .66296 .2433 Metetra
0 .158 .234 r
.66296 .2433 .67292 .24784 .69461 .24181 .68481 .23697 Metetra
0 .168 .239 r
.68481 .23697 .69461 .24181 .71649 .23584 .70686 .23066 Metetra
0 .179 .245 r
.70686 .23066 .71649 .23584 .73856 .22972 .72909 .22415 Metetra
0 .187 .25 r
.72909 .22415 .73856 .22972 .7608 .22322 .75149 .2172 Metetra
0 .193 .253 r
.75149 .2172 .7608 .22322 .78318 .21605 .77402 .20953 Metetra
0 .192 .252 r
.77402 .20953 .78318 .21605 .80565 .20789 .79664 .20079 Metetra
0 .43 .201 r
.15032 .44672 .16382 .4543 .18123 .45669 .16769 .44991 Metetra
0 .461 .154 r
.16769 .44991 .18123 .45669 .19916 .45616 .18561 .45011 Metetra
0 .481 .12 r
.18561 .45011 .19916 .45616 .21751 .45311 .20399 .44773 Metetra
0 .491 .101 r
.20399 .44773 .21751 .45311 .23622 .44789 .22274 .44311 Metetra
0 .494 .096 r
.22274 .44311 .23622 .44789 .25523 .44086 .24182 .43662 Metetra
0 .49 .104 r
.24182 .43662 .25523 .44086 .27448 .43233 .26116 .42857 Metetra
0 .48 .121 r
.26116 .42857 .27448 .43233 .29393 .42261 .28072 .41927 Metetra
0 .467 .145 r
.28072 .41927 .29393 .42261 .31354 .41197 .30045 .40899 Metetra
0 .45 .172 r
.30045 .40899 .31354 .41197 .33328 .40065 .32033 .39799 Metetra
0 .432 .199 r
.32033 .39799 .33328 .40065 .35313 .38889 .34033 .38649 Metetra
0 .412 .226 r
.34033 .38649 .35313 .38889 .37308 .37688 .36043 .37471 Metetra
0 .392 .249 r
.36043 .37471 .37308 .37688 .39311 .3648 .38062 .36281 Metetra
0 .372 .269 r
.38062 .36281 .39311 .3648 .41321 .35281 .4009 .35096 Metetra
0 .352 .284 r
.4009 .35096 .41321 .35281 .43339 .34103 .42125 .33929 Metetra
0 .334 .296 r
.42125 .33929 .43339 .34103 .45366 .32959 .4417 .32791 Metetra
0 .317 .304 r
.4417 .32791 .45366 .32959 .474 .31856 .46223 .31691 Metetra
0 .296 .303 r
.46223 .31691 .474 .31856 .49445 .30803 .48286 .30638 Metetra
0 .269 .29 r
.48286 .30638 .49445 .30803 .515 .29804 .50359 .29635 Metetra
0 .247 .28 r
.50359 .29635 .515 .29804 .53567 .28862 .52445 .28687 Metetra
0 .232 .273 r
.52445 .28687 .53567 .28862 .55647 .27979 .54544 .27793 Metetra
0 .222 .268 r
.54544 .27793 .55647 .27979 .57742 .27153 .56658 .26954 Metetra
0 .217 .265 r
.56658 .26954 .57742 .27153 .59854 .26382 .58788 .26165 Metetra
0 .216 .265 r
.58788 .26165 .59854 .26382 .61982 .2566 .60936 .25422 Metetra
0 .219 .267 r
.60936 .25422 .61982 .2566 .64129 .2498 .63101 .24716 Metetra
0 .226 .27 r
.63101 .24716 .64129 .2498 .66296 .2433 .65286 .24036 Metetra
0 .234 .274 r
.65286 .24036 .66296 .2433 .68481 .23697 .6749 .23369 Metetra
0 .244 .279 r
.6749 .23369 .68481 .23697 .70686 .23066 .69713 .22698 Metetra
0 .254 .283 r
.69713 .22698 .70686 .23066 .72909 .22415 .71953 .22 Metetra
0 .261 .287 r
.71953 .22 .72909 .22415 .75149 .2172 .7421 .21253 Metetra
0 .263 .288 r
.7421 .21253 .75149 .2172 .77402 .20953 .76479 .20425 Metetra
0 .258 .286 r
.76479 .20425 .77402 .20953 .79664 .20079 .78756 .19483 Metetra
0 .449 .174 r
.13656 .43937 .15032 .44672 .16769 .44991 .15387 .44352 Metetra
0 .484 .115 r
.15387 .44352 .16769 .44991 .18561 .45011 .17176 .44461 Metetra
0 .506 .07 r
.17176 .44461 .18561 .45011 .20399 .44773 .19014 .44303 Metetra
0 .52 .042 r
.19014 .44303 .20399 .44773 .22274 .44311 .20894 .43914 Metetra
0 .525 .031 r
.20894 .43914 .22274 .44311 .24182 .43662 .22807 .4333 Metetra
0 .523 .034 r
.22807 .4333 .24182 .43662 .26116 .42857 .2475 .42584 Metetra
0 .516 .049 r
.2475 .42584 .26116 .42857 .28072 .41927 .26716 .41706 Metetra
0 .505 .073 r
.26716 .41706 .28072 .41927 .30045 .40899 .28701 .40724 Metetra
0 .491 .101 r
.28701 .40724 .30045 .40899 .32033 .39799 .30703 .39664 Metetra
0 .474 .132 r
.30703 .39664 .32033 .39799 .34033 .38649 .32718 .38548 Metetra
0 .456 .163 r
.32718 .38548 .34033 .38649 .36043 .37471 .34744 .37398 Metetra
0 .437 .192 r
.34744 .37398 .36043 .37471 .38062 .36281 .3678 .36232 Metetra
0 .418 .218 r
.3678 .36232 .38062 .36281 .4009 .35096 .38825 .35065 Metetra
0 .4 .241 r
.38825 .35065 .4009 .35096 .42125 .33929 .4088 .33912 Metetra
0 .382 .259 r
.4088 .33912 .42125 .33929 .4417 .32791 .42943 .32784 Metetra
0 .366 .273 r
.42943 .32784 .4417 .32791 .46223 .31691 .45016 .31691 Metetra
0 .352 .284 r
.45016 .31691 .46223 .31691 .48286 .30638 .47098 .30639 Metetra
0 .34 .292 r
.47098 .30639 .48286 .30638 .50359 .29635 .49192 .29634 Metetra
0 .331 .298 r
.49192 .29634 .50359 .29635 .52445 .28687 .51298 .28679 Metetra
0 .323 .301 r
.51298 .28679 .52445 .28687 .54544 .27793 .53418 .27774 Metetra
0 .318 .304 r
.53418 .27774 .54544 .27793 .56658 .26954 .55552 .2692 Metetra
0 .315 .305 r
.55552 .2692 .56658 .26954 .58788 .26165 .57703 .26112 Metetra
0 .315 .305 r
.57703 .26112 .58788 .26165 .60936 .25422 .5987 .25345 Metetra
0 .316 .305 r
.5987 .25345 .60936 .25422 .63101 .24716 .62056 .2461 Metetra
0 .318 .304 r
.62056 .2461 .63101 .24716 .65286 .24036 .64261 .23896 Metetra
0 .321 .302 r
.64261 .23896 .65286 .24036 .6749 .23369 .66484 .23189 Metetra
0 .325 .301 r
.66484 .23189 .6749 .23369 .69713 .22698 .68726 .2247 Metetra
0 .328 .299 r
.68726 .2247 .69713 .22698 .71953 .22 .70985 .21719 Metetra
0 .329 .298 r
.70985 .21719 .71953 .22 .7421 .21253 .73259 .2091 Metetra
0 .328 .299 r
.73259 .2091 .7421 .21253 .76479 .20425 .75546 .20011 Metetra
0 .324 .301 r
.75546 .20011 .76479 .20425 .78756 .19483 .77839 .18988 Metetra
0 .47 .14 r
.12256 .43209 .13656 .43937 .15387 .44352 .13978 .43737 Metetra
0 .508 .067 r
.13978 .43737 .15387 .44352 .17176 .44461 .15762 .43951 Metetra
0 .535 .009 r
.15762 .43951 .17176 .44461 .19014 .44303 .17598 .43888 Metetra
.031 .551 0 r
.17598 .43888 .19014 .44303 .20894 .43914 .19479 .43586 Metetra
.052 .56 0 r
.19479 .43586 .20894 .43914 .22807 .4333 .21398 .4308 Metetra
.055 .561 0 r
.21398 .4308 .22807 .4333 .2475 .42584 .23348 .42404 Metetra
.045 .557 0 r
.23348 .42404 .2475 .42584 .26716 .41706 .25323 .41589 Metetra
.023 .548 0 r
.25323 .41589 .26716 .41706 .28701 .40724 .27321 .40662 Metetra
0 .536 .006 r
.27321 .40662 .28701 .40724 .30703 .39664 .29336 .3965 Metetra
0 .521 .039 r
.29336 .3965 .30703 .39664 .32718 .38548 .31366 .38576 Metetra
0 .505 .073 r
.31366 .38576 .32718 .38548 .34744 .37398 .33408 .37461 Metetra
0 .488 .107 r
.33408 .37461 .34744 .37398 .3678 .36232 .35462 .36324 Metetra
0 .47 .139 r
.35462 .36324 .3678 .36232 .38825 .35065 .37526 .35182 Metetra
0 .453 .168 r
.37526 .35182 .38825 .35065 .4088 .33912 .396 .34047 Metetra
0 .437 .192 r
.396 .34047 .4088 .33912 .42943 .32784 .41683 .32932 Metetra
0 .422 .213 r
.41683 .32932 .42943 .32784 .45016 .31691 .43777 .31847 Metetra
0 .408 .23 r
.43777 .31847 .45016 .31691 .47098 .30639 .4588 .30798 Metetra
0 .397 .243 r
.4588 .30798 .47098 .30639 .49192 .29634 .47996 .29792 Metetra
0 .388 .253 r
.47996 .29792 .49192 .29634 .51298 .28679 .50123 .28831 Metetra
0 .38 .261 r
.50123 .28831 .51298 .28679 .53418 .27774 .52265 .27915 Metetra
0 .375 .266 r
.52265 .27915 .53418 .27774 .55552 .2692 .54421 .27045 Metetra
0 .372 .268 r
.54421 .27045 .55552 .2692 .57703 .26112 .56593 .26216 Metetra
0 .371 .27 r
.56593 .26216 .57703 .26112 .5987 .25345 .58783 .25422 Metetra
0 .371 .269 r
.58783 .25422 .5987 .25345 .62056 .2461 .6099 .24654 Metetra
0 .372 .268 r
.6099 .24654 .62056 .2461 .64261 .23896 .63216 .23901 Metetra
0 .374 .266 r
.63216 .23901 .64261 .23896 .66484 .23189 .65461 .23147 Metetra
0 .376 .265 r
.65461 .23147 .66484 .23189 .68726 .2247 .67723 .22374 Metetra
0 .377 .263 r
.67723 .22374 .68726 .2247 .70985 .21719 .70002 .2156 Metetra
0 .377 .264 r
.70002 .2156 .70985 .21719 .73259 .2091 .72296 .20678 Metetra
0 .374 .267 r
.72296 .20678 .73259 .2091 .75546 .20011 .746 .19697 Metetra
0 .366 .273 r
.746 .19697 .75546 .20011 .77839 .18988 .7691 .1858 Metetra
0 .491 .102 r
.10832 .42472 .12256 .43209 .13978 .43737 .12542 .4313 Metetra
0 .534 .011 r
.12542 .4313 .13978 .43737 .15762 .43951 .14318 .43463 Metetra
.064 .565 0 r
.14318 .43463 .15762 .43951 .17598 .43888 .1615 .43511 Metetra
.119 .585 0 r
.1615 .43511 .17598 .43888 .19479 .43586 .18031 .4331 Metetra
.153 .597 0 r
.18031 .4331 .19479 .43586 .21398 .4308 .19953 .42896 Metetra
.167 .602 0 r
.19953 .42896 .21398 .4308 .23348 .42404 .21909 .42303 Metetra
.163 .601 0 r
.21909 .42303 .23348 .42404 .25323 .41589 .23893 .41561 Metetra
.146 .595 0 r
.23893 .41561 .25323 .41589 .27321 .40662 .25901 .407 Metetra
.12 .586 0 r
.25901 .407 .27321 .40662 .29336 .3965 .2793 .39745 Metetra
.086 .573 0 r
.2793 .39745 .29336 .3965 .31366 .38576 .29975 .38721 Metetra
.05 .559 0 r
.29975 .38721 .31366 .38576 .33408 .37461 .32034 .37649 Metetra
.012 .544 0 r
.32034 .37649 .33408 .37461 .35462 .36324 .34106 .36548 Metetra
0 .528 .025 r
.34106 .36548 .35462 .36324 .37526 .35182 .3619 .35434 Metetra
0 .512 .059 r
.3619 .35434 .37526 .35182 .396 .34047 .38284 .34323 Metetra
0 .497 .089 r
.38284 .34323 .396 .34047 .41683 .32932 .40388 .33225 Metetra
0 .483 .116 r
.40388 .33225 .41683 .32932 .43777 .31847 .42503 .32151 Metetra
0 .47 .139 r
.42503 .32151 .43777 .31847 .4588 .30798 .44629 .31108 Metetra
0 .459 .157 r
.44629 .31108 .4588 .30798 .47996 .29792 .46767 .30101 Metetra
0 .45 .172 r
.46767 .30101 .47996 .29792 .50123 .28831 .48918 .29134 Metetra
0 .443 .183 r
.48918 .29134 .50123 .28831 .52265 .27915 .51083 .28207 Metetra
0 .438 .191 r
.51083 .28207 .52265 .27915 .54421 .27045 .53262 .27319 Metetra
0 .434 .196 r
.53262 .27319 .54421 .27045 .56593 .26216 .55458 .26466 Metetra
0 .432 .199 r
.55458 .26466 .56593 .26216 .58783 .25422 .57671 .25641 Metetra
0 .432 .2 r
.57671 .25641 .58783 .25422 .6099 .24654 .59902 .24836 Metetra
0 .432 .2 r
.59902 .24836 .6099 .24654 .63216 .23901 .62151 .24037 Metetra
0 .432 .199 r
.62151 .24037 .63216 .23901 .65461 .23147 .64418 .2323 Metetra
0 .433 .198 r
.64418 .2323 .65461 .23147 .67723 .22374 .66702 .22395 Metetra
0 .432 .2 r
.66702 .22395 .67723 .22374 .70002 .2156 .69002 .21509 Metetra
0 .429 .204 r
.69002 .21509 .70002 .2156 .72296 .20678 .71315 .20544 Metetra
0 .423 .212 r
.71315 .20544 .72296 .20678 .746 .19697 .73638 .19467 Metetra
0 .413 .225 r
.73638 .19467 .746 .19697 .7691 .1858 .75965 .18242 Metetra
0 .512 .059 r
.09387 .41701 .10832 .42472 .12542 .4313 .11081 .42507 Metetra
.052 .56 0 r
.11081 .42507 .12542 .4313 .14318 .43463 .12846 .42979 Metetra
.148 .596 0 r
.12846 .42979 .14318 .43463 .1615 .43511 .14672 .43153 Metetra
.222 .621 0 r
.14672 .43153 .1615 .43511 .18031 .4331 .1655 .43069 Metetra
.273 .637 0 r
.1655 .43069 .18031 .4331 .19953 .42896 .18472 .42761 Metetra
.301 .646 0 r
.18472 .42761 .19953 .42896 .21909 .42303 .20433 .42263 Metetra
.308 .648 0 r
.20433 .42263 .21909 .42303 .23893 .41561 .22425 .41607 Metetra
.3 .646 0 r
.22425 .41607 .23893 .41561 .25901 .407 .24443 .40822 Metetra
.278 .639 0 r
.24443 .40822 .25901 .407 .2793 .39745 .26484 .39935 Metetra
.247 .629 0 r
.26484 .39935 .2793 .39745 .29975 .38721 .28544 .38969 Metetra
.211 .617 0 r
.28544 .38969 .29975 .38721 .32034 .37649 .3062 .37948 Metetra
.171 .604 0 r
.3062 .37948 .32034 .37649 .34106 .36548 .32711 .36889 Metetra
.132 .59 0 r
.32711 .36889 .34106 .36548 .3619 .35434 .34814 .35811 Metetra
.093 .576 0 r
.34814 .35811 .3619 .35434 .38284 .34323 .36928 .34727 Metetra
.058 .562 0 r
.36928 .34727 .38284 .34323 .40388 .33225 .39055 .3365 Metetra
.026 .549 0 r
.39055 .3365 .40388 .33225 .42503 .32151 .41193 .3259 Metetra
0 .537 .002 r
.41193 .3259 .42503 .32151 .44629 .31108 .43342 .31554 Metetra
0 .527 .026 r
.43342 .31554 .44629 .31108 .46767 .30101 .45504 .30548 Metetra
0 .518 .045 r
.45504 .30548 .46767 .30101 .48918 .29134 .47679 .29575 Metetra
0 .511 .06 r
.47679 .29575 .48918 .29134 .51083 .28207 .49869 .28636 Metetra
0 .506 .072 r
.49869 .28636 .51083 .28207 .53262 .27319 .52074 .27728 Metetra
0 .502 .08 r
.52074 .27728 .53262 .27319 .55458 .26466 .54294 .26849 Metetra
0 .499 .085 r
.54294 .26849 .55458 .26466 .57671 .25641 .56532 .2599 Metetra
0 .497 .089 r
.56532 .2599 .57671 .25641 .59902 .24836 .58788 .25142 Metetra
0 .496 .091 r
.58788 .25142 .59902 .24836 .62151 .24037 .61061 .24292 Metetra
0 .495 .093 r
.61061 .24292 .62151 .24037 .64418 .2323 .63352 .23424 Metetra
0 .493 .096 r
.63352 .23424 .64418 .2323 .66702 .22395 .65659 .22518 Metetra
0 .49 .102 r
.65659 .22518 .66702 .22395 .69002 .21509 .67982 .21549 Metetra
0 .485 .113 r
.67982 .21549 .69002 .21509 .71315 .20544 .70316 .20488 Metetra
0 .476 .13 r
.70316 .20488 .71315 .20544 .73638 .19467 .72658 .19302 Metetra
0 .461 .154 r
.72658 .19302 .73638 .19467 .75965 .18242 .75003 .17952 Metetra
0 .532 .016 r
.07925 .40873 .09387 .41701 .11081 .42507 .09598 .41846 Metetra
.12 .586 0 r
.09598 .41846 .11081 .42507 .12846 .42979 .11348 .42473 Metetra
.241 .627 0 r
.11348 .42473 .12846 .42979 .14672 .43153 .13163 .42791 Metetra
.339 .657 0 r
.13163 .42791 .14672 .43153 .1655 .43069 .15036 .42839 Metetra
.411 .678 0 r
.15036 .42839 .1655 .43069 .18472 .42761 .16957 .42652 Metetra
.458 .691 0 r
.16957 .42652 .18472 .42761 .20433 .42263 .1892 .42264 Metetra
.481 .698 0 r
.1892 .42264 .20433 .42263 .22425 .41607 .20918 .41707 Metetra
.484 .698 0 r
.20918 .41707 .22425 .41607 .24443 .40822 .22945 .4101 Metetra
.472 .695 0 r
.22945 .4101 .24443 .40822 .26484 .39935 .24998 .402 Metetra
.447 .688 0 r
.24998 .402 .26484 .39935 .28544 .38969 .27072 .39303 Metetra
.414 .679 0 r
.27072 .39303 .28544 .38969 .3062 .37948 .29165 .3834 Metetra
.375 .668 0 r
.29165 .3834 .3062 .37948 .32711 .36889 .31273 .37332 Metetra
.335 .656 0 r
.31273 .37332 .32711 .36889 .34814 .35811 .33396 .36295 Metetra
.294 .644 0 r
.33396 .36295 .34814 .35811 .36928 .34727 .35533 .35244 Metetra
.255 .632 0 r
.35533 .35244 .36928 .34727 .39055 .3365 .37681 .34192 Metetra
.219 .62 0 r
.37681 .34192 .39055 .3365 .41193 .3259 .39843 .33149 Metetra
.186 .609 0 r
.39843 .33149 .41193 .3259 .43342 .31554 .42017 .32123 Metetra
.158 .599 0 r
.42017 .32123 .43342 .31554 .45504 .30548 .44204 .31119 Metetra
.134 .591 0 r
.44204 .31119 .45504 .30548 .47679 .29575 .46405 .30141 Metetra
.115 .584 0 r
.46405 .30141 .47679 .29575 .49869 .28636 .48621 .29188 Metetra
.099 .578 0 r
.48621 .29188 .49869 .28636 .52074 .27728 .50852 .28259 Metetra
.087 .574 0 r
.50852 .28259 .52074 .27728 .54294 .26849 .53099 .27349 Metetra
.078 .57 0 r
.53099 .27349 .54294 .26849 .56532 .2599 .55363 .26452 Metetra
.071 .567 0 r
.55363 .26452 .56532 .2599 .58788 .25142 .57645 .25555 Metetra
.064 .565 0 r
.57645 .25555 .58788 .25142 .61061 .24292 .59944 .24647 Metetra
.056 .562 0 r
.59944 .24647 .61061 .24292 .63352 .23424 .6226 .23709 Metetra
.046 .558 0 r
.6226 .23709 .63352 .23424 .65659 .22518 .64592 .22721 Metetra
.032 .552 0 r
.64592 .22721 .65659 .22518 .67982 .21549 .66938 .21657 Metetra
.011 .543 0 r
.66938 .21657 .67982 .21549 .70316 .20488 .69294 .20487 Metetra
0 .53 .018 r
.69294 .20487 .70316 .20488 .72658 .19302 .71657 .19176 Metetra
0 .512 .058 r
.71657 .19176 .72658 .19302 .75003 .17952 .7402 .17684 Metetra
.027 .55 0 r
.06449 .39956 .07925 .40873 .09598 .41846 .08097 .41116 Metetra
.19 .61 0 r
.08097 .41116 .09598 .41846 .11348 .42473 .09827 .41917 Metetra
.34 .658 0 r
.09827 .41917 .11348 .42473 .13163 .42791 .11628 .42398 Metetra
.467 .694 0 r
.11628 .42398 .13163 .42791 .15036 .42839 .13492 .42595 Metetra
.566 .72 0 r
.13492 .42595 .15036 .42839 .16957 .42652 .15409 .42545 Metetra
.636 .738 0 r
.15409 .42545 .16957 .42652 .1892 .42264 .17371 .42282 Metetra
.68 .748 0 r
.17371 .42282 .1892 .42264 .20918 .41707 .19373 .41837 Metetra
.7 .753 0 r
.19373 .41837 .20918 .41707 .22945 .4101 .21408 .4124 Metetra
.701 .753 0 r
.21408 .4124 .22945 .4101 .24998 .402 .23471 .4052 Metetra
.687 .75 0 r
.23471 .4052 .24998 .402 .27072 .39303 .25558 .39702 Metetra
.66 .743 0 r
.25558 .39702 .27072 .39303 .29165 .3834 .27667 .38807 Metetra
.626 .735 0 r
.27667 .38807 .29165 .3834 .31273 .37332 .29793 .37856 Metetra
.588 .725 0 r
.29793 .37856 .31273 .37332 .33396 .36295 .31936 .36867 Metetra
.547 .715 0 r
.31936 .36867 .33396 .36295 .35533 .35244 .34094 .35855 Metetra
.507 .704 0 r
.34094 .35855 .35533 .35244 .37681 .34192 .36266 .34833 Metetra
.468 .694 0 r
.36266 .34833 .37681 .34192 .39843 .33149 .38452 .33811 Metetra
.432 .684 0 r
.38452 .33811 .39843 .33149 .42017 .32123 .40651 .32797 Metetra
.4 .675 0 r
.40651 .32797 .42017 .32123 .44204 .31119 .42865 .31796 Metetra
.372 .667 0 r
.42865 .31796 .44204 .31119 .46405 .30141 .45093 .30812 Metetra
.348 .66 0 r
.45093 .30812 .46405 .30141 .48621 .29188 .47336 .29844 Metetra
.328 .654 0 r
.47336 .29844 .48621 .29188 .50852 .28259 .49594 .28891 Metetra
.311 .649 0 r
.49594 .28891 .50852 .28259 .53099 .27349 .5187 .27948 Metetra
.296 .645 0 r
.5187 .27948 .53099 .27349 .55363 .26452 .54162 .27006 Metetra
.283 .64 0 r
.54162 .27006 .55363 .26452 .57645 .25555 .56471 .26055 Metetra
.269 .636 0 r
.56471 .26055 .57645 .25555 .59944 .24647 .58797 .2508 Metetra
.253 .631 0 r
.58797 .2508 .59944 .24647 .6226 .23709 .6114 .24062 Metetra
.233 .624 0 r
.6114 .24062 .6226 .23709 .64592 .22721 .63498 .22981 Metetra
.206 .616 0 r
.63498 .22981 .64592 .22721 .66938 .21657 .65868 .21808 Metetra
.17 .603 0 r
.65868 .21808 .66938 .21657 .69294 .20487 .68247 .20514 Metetra
.123 .587 0 r
.68247 .20514 .69294 .20487 .71657 .19176 .70631 .1906 Metetra
.062 .564 0 r
.70631 .1906 .71657 .19176 .7402 .17684 .73012 .17407 Metetra
.064 .565 0 r
.04966 .38919 .06449 .39956 .08097 .41116 .06583 .40285 Metetra
.258 .633 0 r
.06583 .40285 .08097 .41116 .09827 .41917 .08288 .4128 Metetra
.441 .687 0 r
.08288 .4128 .09827 .41917 .11628 .42398 .1007 .41942 Metetra
.601 .729 0 r
.1007 .41942 .11628 .42398 .13492 .42595 .1192 .42306 Metetra
.732 .761 0 r
.1192 .42306 .13492 .42595 .15409 .42545 .13829 .4241 Metetra
.784 .735 0 r
.13829 .4241 .15409 .42545 .17371 .42282 .15789 .42287 Metetra
.799 .696 0 r
.15789 .42287 .17371 .42282 .19373 .41837 .17791 .41969 Metetra
.808 .671 0 r
.17791 .41969 .19373 .41837 .21408 .4124 .19832 .41487 Metetra
.813 .66 0 r
.19832 .41487 .21408 .4124 .23471 .4052 .21904 .40868 Metetra
.813 .66 0 r
.21904 .40868 .23471 .4052 .25558 .39702 .24003 .40139 Metetra
.81 .668 0 r
.24003 .40139 .25558 .39702 .27667 .38807 .26126 .39322 Metetra
.804 .683 0 r
.26126 .39322 .27667 .38807 .29793 .37856 .2827 .38438 Metetra
.797 .701 0 r
.2827 .38438 .29793 .37856 .31936 .36867 .30433 .37504 Metetra
.789 .722 0 r
.30433 .37504 .31936 .36867 .34094 .35855 .32613 .36537 Metetra
.78 .744 0 r
.32613 .36537 .34094 .35855 .36266 .34833 .34808 .3555 Metetra
.771 .765 0 r
.34808 .3555 .36266 .34833 .38452 .33811 .37018 .34552 Metetra
.739 .762 0 r
.37018 .34552 .38452 .33811 .40651 .32797 .39244 .33552 Metetra
.704 .754 0 r
.39244 .33552 .40651 .32797 .42865 .31796 .41484 .32555 Metetra
.672 .746 0 r
.41484 .32555 .42865 .31796 .45093 .30812 .4374 .31565 Metetra
.644 .739 0 r
.4374 .31565 .45093 .30812 .47336 .29844 .46012 .30581 Metetra
.618 .733 0 r
.46012 .30581 .47336 .29844 .49594 .28891 .48299 .29601 Metetra
.595 .727 0 r
.48299 .29601 .49594 .28891 .5187 .27948 .50604 .28619 Metetra
.572 .722 0 r
.50604 .28619 .5187 .27948 .54162 .27006 .52925 .27628 Metetra
.55 .716 0 r
.52925 .27628 .54162 .27006 .56471 .26055 .55264 .26614 Metetra
.526 .71 0 r
.55264 .26614 .56471 .26055 .58797 .2508 .57619 .25563 Metetra
.498 .702 0 r
.57619 .25563 .58797 .2508 .6114 .24062 .59989 .24455 Metetra
.463 .693 0 r
.59989 .24455 .6114 .24062 .63498 .22981 .62373 .23267 Metetra
.419 .68 0 r
.62373 .23267 .63498 .22981 .65868 .21808 .64769 .21971 Metetra
.362 .664 0 r
.64769 .21971 .65868 .21808 .68247 .20514 .67172 .20535 Metetra
.291 .643 0 r
.67172 .20535 .68247 .20514 .70631 .1906 .69577 .1892 Metetra
.204 .615 0 r
.69577 .1892 .70631 .1906 .73012 .17407 .71976 .17084 Metetra
.091 .575 0 r
.03481 .37721 .04966 .38919 .06583 .40285 .05061 .39315 Metetra
.317 .651 0 r
.05061 .39315 .06583 .40285 .08288 .4128 .06735 .40524 Metetra
.537 .713 0 r
.06735 .40524 .08288 .4128 .1007 .41942 .08494 .41385 Metetra
.736 .761 0 r
.08494 .41385 .1007 .41942 .1192 .42306 .10326 .41936 Metetra
.8 .694 0 r
.10326 .41936 .1192 .42306 .13829 .4241 .12223 .42211 Metetra
.828 .616 0 r
.12223 .42211 .13829 .4241 .15789 .42287 .14175 .42245 Metetra
.849 .555 0 r
.14175 .42245 .15789 .42287 .17791 .41969 .16176 .4207 Metetra
.863 .512 0 r
.16176 .4207 .17791 .41969 .19832 .41487 .18218 .41716 Metetra
.872 .484 0 r
.18218 .41716 .19832 .41487 .21904 .40868 .20297 .41213 Metetra
.876 .471 0 r
.20297 .41213 .21904 .40868 .24003 .40139 .22407 .40585 Metetra
.876 .47 0 r
.22407 .40585 .24003 .40139 .26126 .39322 .24543 .39856 Metetra
.874 .477 0 r
.24543 .39856 .26126 .39322 .2827 .38438 .26704 .39047 Metetra
.869 .492 0 r
.26704 .39047 .2827 .38438 .30433 .37504 .28886 .38177 Metetra
.864 .511 0 r
.28886 .38177 .30433 .37504 .32613 .36537 .31087 .37262 Metetra
.857 .532 0 r
.31087 .37262 .32613 .36537 .34808 .3555 .33305 .36314 Metetra
.849 .554 0 r
.33305 .36314 .34808 .3555 .37018 .34552 .35541 .35344 Metetra
.842 .577 0 r
.35541 .35344 .37018 .34552 .39244 .33552 .37793 .34361 Metetra
.834 .599 0 r
.37793 .34361 .39244 .33552 .41484 .32555 .40062 .3337 Metetra
.827 .62 0 r
.40062 .3337 .41484 .32555 .4374 .31565 .42346 .32373 Metetra
.82 .639 0 r
.42346 .32373 .4374 .31565 .46012 .30581 .44647 .31371 Metetra
.813 .658 0 r
.44647 .31371 .46012 .30581 .48299 .29601 .46965 .3036 Metetra
.807 .676 0 r
.46965 .3036 .48299 .29601 .50604 .28619 .493 .29335 Metetra
.8 .694 0 r
.493 .29335 .50604 .28619 .52925 .27628 .51652 .28286 Metetra
.792 .713 0 r
.51652 .28286 .52925 .27628 .55264 .26614 .5402 .27201 Metetra
.784 .734 0 r
.5402 .27201 .55264 .26614 .57619 .25563 .56405 .26063 Metetra
.774 .758 0 r
.56405 .26063 .57619 .25563 .59989 .24455 .58805 .24852 Metetra
.735 .761 0 r
.58805 .24852 .59989 .24455 .62373 .23267 .61217 .23544 Metetra
.667 .745 0 r
.61217 .23544 .62373 .23267 .64769 .21971 .63638 .22108 Metetra
.584 .725 0 r
.63638 .22108 .64769 .21971 .67172 .20535 .66065 .20511 Metetra
.483 .698 0 r
.66065 .20511 .67172 .20535 .69577 .1892 .68492 .18714 Metetra
.362 .664 0 r
.68492 .18714 .69577 .1892 .71976 .17084 .7091 .16673 Metetra
.103 .579 0 r
.02003 .36321 .03481 .37721 .05061 .39315 .03539 .38162 Metetra
.362 .664 0 r
.03539 .38162 .05061 .39315 .06735 .40524 .05177 .39606 Metetra
.622 .734 0 r
.05177 .39606 .06735 .40524 .08494 .41385 .06905 .40688 Metetra
.79 .718 0 r
.06905 .40688 .08494 .41385 .10326 .41936 .08714 .41444 Metetra
.835 .596 0 r
.08714 .41444 .10326 .41936 .12223 .42211 .10594 .41909 Metetra
.87 .489 0 r
.10594 .41909 .12223 .42211 .14175 .42245 .12535 .42117 Metetra
.897 .4 0 r
.12535 .42117 .14175 .42245 .16176 .4207 .1453 .42101 Metetra
.916 .332 0 r
.1453 .42101 .16176 .4207 .18218 .41716 .16572 .41891 Metetra
.93 .283 0 r
.16572 .41891 .18218 .41716 .20297 .41213 .18654 .41517 Metetra
.938 .252 0 r
.18654 .41517 .20297 .41213 .22407 .40585 .20772 .41003 Metetra
.942 .235 0 r
.20772 .41003 .22407 .40585 .24543 .39856 .2292 .40373 Metetra
.943 .231 0 r
.2292 .40373 .24543 .39856 .26704 .39047 .25096 .3965 Metetra
.942 .237 0 r
.25096 .3965 .26704 .39047 .28886 .38177 .27295 .38852 Metetra
.939 .25 0 r
.27295 .38852 .28886 .38177 .31087 .37262 .29517 .37995 Metetra
.934 .268 0 r
.29517 .37995 .31087 .37262 .33305 .36314 .31759 .37092 Metetra
.928 .289 0 r
.31759 .37092 .33305 .36314 .35541 .35344 .3402 .36155 Metetra
.922 .312 0 r
.3402 .36155 .35541 .35344 .37793 .34361 .36299 .3519 Metetra
.915 .336 0 r
.36299 .3519 .37793 .34361 .40062 .3337 .38595 .34205 Metetra
.908 .36 0 r
.38595 .34205 .40062 .3337 .42346 .32373 .40909 .33201 Metetra
.901 .385 0 r
.40909 .33201 .42346 .32373 .44647 .31371 .43241 .32178 Metetra
.894 .41 0 r
.43241 .32178 .44647 .31371 .46965 .3036 .4559 .31132 Metetra
.887 .436 0 r
.4559 .31132 .46965 .3036 .493 .29335 .47956 .30058 Metetra
.878 .463 0 r
.47956 .30058 .493 .29335 .51652 .28286 .50339 .28944 Metetra
.869 .494 0 r
.50339 .28944 .51652 .28286 .5402 .27201 .52739 .27778 Metetra
.858 .528 0 r
.52739 .27778 .5402 .27201 .56405 .26063 .55155 .26542 Metetra
.845 .568 0 r
.55155 .26542 .56405 .26063 .58805 .24852 .57584 .25214 Metetra
.829 .616 0 r
.57584 .25214 .58805 .24852 .61217 .23544 .60025 .23768 Metetra
.808 .672 0 r
.60025 .23768 .61217 .23544 .63638 .22108 .62474 .22174 Metetra
.783 .737 0 r
.62474 .22174 .63638 .22108 .66065 .20511 .64925 .20396 Metetra
.69 .751 0 r
.64925 .20396 .66065 .20511 .68492 .18714 .67373 .18394 Metetra
.529 .71 0 r
.67373 .18394 .68492 .18714 .7091 .16673 .6981 .16122 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15379 .20947 m
.1584 .21414 L
s
[(-5)] .14456 .20014 .98831 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54685 .05556 m
.55074 .06084 L
s
[(5)] .53907 .04499 .73616 1 Mshowa
.125 Mabswid
.19056 .19507 m
.19329 .19791 L
s
.22786 .18047 m
.23055 .18334 L
s
.2657 .16565 m
.26835 .16856 L
s
.3041 .15061 m
.30671 .15356 L
s
.38261 .11987 m
.38514 .12289 L
s
.42275 .10415 m
.42523 .10721 L
s
.46349 .0882 m
.46592 .09129 L
s
.50485 .072 m
.50724 .07514 L
s
.11754 .22366 m
.12034 .22643 L
s
.08179 .23766 m
.08463 .24039 L
s
.04655 .25146 m
.04942 .25416 L
s
.5895 .03886 m
.59178 .04207 L
s
.6328 .0219 m
.63503 .02515 L
s
.67679 .00468 m
.67896 .00796 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00b_ooool2o`0005Cooooo0037ooooo`?o000000?oooooo`000?ooool0Doooool00<Gooooo
0_l000001?oooooo0000ooooooooool2o`0005?ooooo0032ooooo`?o00001_ooool00ol0003ooooo
o`00001Booooo`00Woooool3o`0001kooooo0_l00009ooooo`?o0000D_ooool009kooooo00Go0000
ooooooooooooooooo`00000Jooooo`?o00002oooool01?l0003oooooooooool0001Aooooo`00X_oo
ool00ol0003oooooooooo`0Fooooo`;o00003_ooool01Ol0003ooooooooooooooooo0000053ooooo
002Rooooo`03o`000?oooooooooo01?ooooo0ol00002ooooo`03o`000?oooooooooo00_ooooo00Go
0000ooooooooooooooooo`00001@ooooo`00W_ooool4o`0001?ooooo0ol0000Cooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0COooool009kooooo00?o0000ooooooooool04_ooool2
o`0001Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1<ooooo`00W_ooool5o`00
00gooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C?ooool00:ko
oooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Boooool00:_ooooo
0ol00003ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool2o`0004cooooo
002Yooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04[ooooo002V
ooooo`?o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo002Toooo
o`;o00009_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo002Qooooo`?o
000000?oooooo`000?ooool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04So
oooo002Oooooo`;o00001Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0Aoooool009cooooo0ol0000]ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0Aoooool009[ooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0A_ooool009Oooooo1?l0000aooooo`03o`000?oooooooooo00Sooooo0_l00017oooo
o`00U?ooool3o`0003Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`15ooooo`00
T_ooool2o`0003Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`?o0000
=_ooool008oooooo0ol0000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000003Gooooo002=ooooo`?o0000??ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00?ooooo1Ol00005ooooo`03o`000?oooooooooo03?ooooo002:
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0cooooo`00J?ooool2o`0001kooooo0_l00013oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool4o`0003Kooooo001Wooooo`04
o`000?ooooooooooo`0001[ooooo0ol00015ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0gooooo`00Ioooool01?l0003oooooooooool0000Hoooo
o`;o0000B?ooool00ol0003oooooooooo`0;ooooo`?o00002?ooool5o`0003Gooooo001Wooooo`04
o`000?ooooooooooo`0001Gooooo0ol000000ooooooo0000ooooo`17ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0?oooool006Oooooo00Co0000oooooooooooo00004oooool2o`00
04gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0oooooo`00Ioooool01?l0003o
ooooooooool0000@ooooo`?o0000Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
03kooooo001Xooooo`;o00003oooool2o`0005;ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0mooooo`00M_ooool3o`000003ooooool0003ooooo057ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0mooooo`00Loooool3o`0005Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0looooo`00LOooool2o`0005[ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0kooooo`00K_ooool3o`0005cooooo00?o0000ooooooooool04Oooool2o`00
03gooooo001/ooooo`?o0000G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03[o
oooo001Yooooo`?o00000oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0>_ooool006Oooooo0_l0001Tooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0>Oooool006Cooooo0ol0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0>?ooool006;ooooo1?l0001Wooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0>?ooool005oooooo0ol0001/ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0=oooool005gooooo0_l0001_ooooo`03o`000?oooooooooo01Gooooo0_l0000hooooo`00F_oo
ool3o`00073ooooo0ol0000Gooooo`03o`000?oooooooooo03Kooooo001Hooooo`?o0000LOooool0
0ol0003oQkD0o`000004o`0001Gooooo00?o0000ooooooooool0=Oooool003Cooooo0ol0000Noooo
o`?o0000Loooool01?l0003oQkD0ohNe0?l00003oebY00Co00004oooool00ol0003oooooooooo`0d
ooooo`00<oooool01Ol0003ooooooooooooooooo000001_ooooo0_l0001eooooo`03o`000?n7]@3o
QkD000;o00000_mLZ@001?l0003o=9d0ocBM0?ldW@04o`00013ooooo00?o0000ooooooooool0=?oo
ool002gooooo1Ol00005ooooo`03o`000?oooooooooo01Kooooo0ol0001fooooo`08o`000?n7]@3o
QkD0o`000?mLZ@3o0000oebY0?l00003ocBM0004o`000?l?T03o3i00o`n@00Ko00003?ooool00ol0
003oooooooooo`0cooooo`00=oooool00ol0003oooooooooo`0Cooooo`Co0000Moooool01?l0003o
QkD0ohNe0?l00002oebY00;o00000_ldW@02o`0000;o3i000_l000000ol0P`ko0000o`1f9`02o`1f
9`Co00002_ooool00ol0003oooooooooo`0booooo`00<oooool4o`0001Cooooo0_l0001iooooo`Oo
000000GoG:T0o`000?ldW@3o=9d0o`000003o`n@0004o`000?l0P`ko0000o`0000;o07HW0_l00003
o`1Y>@?o00002?ooool2o`0003?ooooo000cooooo`03o`000?oooooooooo01;ooooo0ol0001joooo
o`04o`000?n``03o/<00o`0000?oNk801_l000001Ol?T03o0000o`000?l0P`ko000000;o07HW0_l0
0002o`1Y>@?o00000_l0GDD3o`0000Oooooo00?o0000ooooooooool0<Oooool003?ooooo1Ol0000>
ooooo`;o0000Noooool2o`000003ok300?l0003o000000;oNk800_l000000om:Y03o0000o`000002
oanF00Wo000000?o06Tio`000?l000000ol0GDD2o`0000?o059=00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0`ooooo`00@oooool4o`0007_ooooo00Co0000ok300?n``03o00000omk/P00
1Ol0003oBZ@0odZT0?l0003o7iH000?o000000Co08L4o`000?l0003o07TQ0_l00002o`1/=PCo0000
00?o05e5o`000?l000001?l0DTd4o`0000Gooooo00?o0000ooooooooool0<?ooool0047ooooo0_l0
001nooooo`04o`000?n``03o/<00o`0000;oNk800_l000001?m:Y03o0000o`000?lOUP02o`000004
o`271?l0003o0000o`1i8@;o00000_l0K3H2o`0000?o05m40ol00002o`1BC@?o00000ol0@TT2o`00
00Gooooo00?o0000ooooooooool0;oooool003kooooo0ol0001noooooaGo000000?o06`fo`000?l0
00000_l0Gd@3o`0000;o05=<1?l00002o`12B@?o00000_l0<D000ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02kooooo000looooo`;o0000P?ooool01?l0003ob;`0olRl0?l00002oiFi0005
o`000?mLZ@3oG:T0o`000?l[VP000_l000000ol2R`3o0000o`000003o`0000;o06dd1_l00002o`1C
C0?o00000ol0@dT3o`0000Go03500ol00003ooooo`03o`000?oooooooooo02kooooo000iooooo`Co
0000P?ooool01Ol0003ob;`0olRl0?l0003oUKT000;o000000?oG:T0o`000?l000000_l000000ol2
R`3o0000o`000003o`000005o`1]=?l0003o0000o`000?l0H4<00_l00002o`1DC0?o00001?l0@dT2
o`0000;o035000?o0000o`0a@?l0<D000ol00003o`0T>@03o`000?oooooooooo00;o0000;oooool0
03Oooooo0_l00004ooooo`03o`000?oooooooooo07cooooo00Ko0000olRl0?o8_03o0000oiFi0?l0
0002oebY00go000000Co0613o`000?l0003o05A<0ol00003o`12B@04o`000?l0@dWo0000o`0000Co
03500ol00006o`0T>@;o00000oooool00ol0003oooooooooo`0/ooooo`00=?ooool3o`0008Cooooo
00?o0000olRl0?o8_0003ol00002o`1P@`Oo00000ol0@TT5o`0000;o03500ol00003o`0T>@03o`00
0?l093Wo02@i00?o000000?o01`co`000?ooool00_ooool00ol0003oooooooooo`06ooooo`;o0000
9?ooool003;ooooo0_l00025ooooo`Ko000000?oJjh0o`000?l000002Ol00002o`1P@`Go00000ol0
@DP4o`0000Co02lo0ol00006o`0T>@?o00001Ol073<01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo00008oooool002oooooo0ol000000ooooooo0000ooooo`22oooooa3o0000
00?o0613o`000?l000001_l00002o`11B0?o00000_l0;Ch00ol0003o02loo`0_?`03o`0000?o028h
00?o0000o`0T>Ol093T00ol000000ol06c?o0000o`0L<`05o`0L<`;o00000_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0002?ooooo000/ooooo`?o0000Qoooool3o`0000;oZ[h0
3Ol000001?l0Ddgo0000o`000?l00003o`0nA`?o00001Ol0;Ch3o`0000Ko028h0ol00005o`0K<`03
o`000?l073?o01`c00?o00000_l05Rl01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0002?ooooo000Zooooo`;o0000R?ooool@o`0000;o059=1?l00002o`0nA`Co000000Co02/mo`00
0?l0;Cko02dn0ol00003o`0P=P03o`000?l08SSo028h00?o000000?o01Tao`000?l06c<01Ol06c<3
o`0000Ko01H_00Co0000oooooooooooo00001?ooool01?l0003oooooooooool0000Sooooo`009ooo
ool3o`0008Sooooo0ol000000onl`P3o0000o`000009o`0000;o059=0ol00003o`0kAPCo00000_l0
:cd6o`0000?o020f1Ol00005o`0I<@03o`000?l06c?o01/c00?o00000_l05Bh00ol0003o01H_o`0F
;`04o`0F;`;o000000?oooooo`000?l000000oooool01?l0003oooooooooool0000Sooooo`009Ooo
ool2o`0000;ooooo00?o0000ooooooooool0QOooool=o`0000;o055=1?l00002o`0kAP?o00000ol0
:3/4o`0000Co01dd1?l00004o`0G<004o`000?l06C7o01Tao`0I<@Go00001_l05Bh00ol0003o01H_
o`0F;`03o`000005o`0C;Ol0003o0000ooooool000001?ooool2o`0002Cooooo000Rooooo`?o0000
R_ooool=o`000005o`1ACOl0003o0000o`000?l0>DD01_l00002o`0X>`?o00000_l06c<2o`000004
o`0M=?l0003o0000o`0000;o01@^00?o0000o`0G<?l05c000ol05c04o`0000Go01<]00Co0000o`0E
;_l05Bko01D^1Ol00005o`0C;@04o`000?ooooooooooo`0002Wooooo000Pooooo`;o0000S?ooool:
o`000003o`1@C_l0003o000000Ko00000ol09SX5o`0000;o01/c1_l00006o`0D;P03o`000?l05c3o
000000;o00000_l04B/00ol0003o01<]o`0C;@04o`0C;@Co00000ol04R`00ol0003o01<]o`0C;@04
o`0C;@;o000000?oooooo`000?ooool0:?ooool001gooooo1?l0002;ooooo`go000000Co03Q4o`00
0?l0003o00000ol093T4o`0000Co01Ta1?l00004o`0B;0;o00000ol052h4o`0000Ko014[00?o0000
o`0C;Ol04bd00ol000000ol042[o0000o`0B;005o`0B;003o`000?l04bgo01<]00?o000000Go018/
o`000?ooooooooooo`00000Xooooo`007?ooool2o`0008_ooooo3?l00003o`0g@`?o00000_l093T3
o`0000?o01L`00?o0000o`0I<Ol000000_l00002o`0@:P03o`000?l04Rco018/00Co018/1?l00004
o`0?:@04o`000?l04B_o014[o`0A:`Go00001Ol042X01?l0003o018/o`0B;?l04R`5o`0000Go018/
00Co0000oooooooooooo00009oooool001cooooo00?o0000ooooool00000R?ooool<o`0000;o03M3
0ol00002o`0S>0?o00001Ol05c03o`0000Ko010Z00?o0000o`0B;?l04R`00ol000000ol03BOo0000
o`0?:@05o`0?:@Co00000ol03RP00ol0003o010Zo`0@:P04o`0@:PCo00000ol04B/00ol0003o018/
o`0B;004o`0B;004o`000?ooooooooooo`0002Oooooo000Looooo`04o`000?ooooooooooo`0008Go
oooo1ol000000ol0D4ko0000o`000003o`0g@`Co000000Co02<ho`000?l0003o00000ol05Rl00ol0
003o01L`o`000003o`0000;o00lY00Co0000o`0@:_l042[o010Z1Ol00004o`0=9`;o00000_l03bT3
o`0000;o00`V00?o0000o`0>:?l03RP00ol03RP00ol0003o010Zo`0@:P03o`000003o`0?:Ol0003o
014[00Go014[00?o0000o`0B;?l04R`00ol04R`2o`000003ooooool0003o000002Kooooo000Loooo
o`;o00000_ooool00ol0003oooooooooo`20ooooo`Oo000000?o051>o`000?l000000_l0=d<3o`00
00?o02<h0_l00005o`0F;`Co00001Ol03bT4o`0000Go00/U00Co0000o`0=9ol03BOo00dW1?l00006
o`0<9P04o`000?l03RSo00hXo`0>:0Co00001Ol03bT00ol0003o014[o`0A:`04o`0A:`03o`000?l0
4Rco000000;o000000?o01<]o`000?ooool00_ooool00ol0003oooooooooo`0Sooooo`005?ooool2
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`Go00000ol0DDd7
o`0000;o02<h0ol00002o`0F;`03o`000?l05Roo01H_00?o00000ol03RP00ol0003o00lYo`000002
o`0000;o00XT00?o0000o`0;9Ol02bD01?l02bD4o`0000;o00XT0_l00006o`0<9PCo00000_l03BL0
0ol0003o00lYo`0?:@05o`0?:@04o`000?l04B_o014[o`0A:`Co00001Ol04bd01?l0003ooooooooo
ool0000Uooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0N_ooool5o`0000;o055=1_l00003o`0T>@?o00001Ol05Rl3o`0000Ko00hX
0_l00006o`0:9003o`000?l02bGo00/U00?o000000?o00PRo`000?l02R@00ol02R@00ol0003o00XT
o`000002o`0<9P?o000000?o00/Uo`000?l03BL01?l03BL00ol0003o00lYo`0?:@04o`0?:@Co0000
0ol04R`00ol0003o01<]o`0C;@04o`0C;@04o`000?ooooooooooo`0002Cooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1fooooo`ko
00000_l093T3o`0000?o01L`00?o0000o`0F;ol000000_l00003o`0>:003o`000?l03RSo00hX00?o
00000_l02B<01?l0003o00XTo`0:9?l02R@5o`0000Go00PR00Co0000o`0:9?l02RCo00XT1Ol00005
o`0;9@03o`000?l03BOo00dW00?o00dW00?o0000o`0?:Ol03bT00ol000000ol042[o0000o`0B;005
o`0B;003o`000?l04bgo01<]00?o01<]0_l00002ooooo`03o`000?oooooooooo027ooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo0_l00007ooooo`03o`000?oooooooooo07?ooooo2_l00000
0ol0>dGo0000o`000002o`0V>P?o00001Ol05c04o`0000Go00hX0ol00005o`098`Co00001?l01b40
0ol0003o00PRo`088P03o`088PCo00000_l02B<2o`0000Ko00/U00Co0000o`0=9ol03BOo00dW1Ol0
0005o`0@:P03o`000?l04Rco018/00?o018/00?o0000o`0C;Ol04bd00ol000001Ol05Roo0000oooo
oooooooo000002?ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1_ooooo`_o000000?o03]5o`000?l000000_l09SX2o`0000?o01Ta
00?o0000o`0G<?l000000ol00003o`0>:003o`000?l03RSo000000;o00000ol02B<00ol0003o00TS
o`000002o`0000;o00HP00?o0000o`078Ol01b401?l01b400ol0003o00PRo`000002o`000003o`07
8Ol0003o00TS00Co00TS0_l00003o`0;9@Ko00000ol03RP00ol0003o010Zo`0@:P04o`0@:P04o`00
0?l04Rco018/o`0B;0Go00001Ol05Rl01?l0003oooooooooool0000Rooooo`004oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Joooool7o`00
0003o`1DC?l0003o000000?o03m71?l000000ol09S[o0000o`0I<@03o`0I<@Co00001_l03RP2o`00
00Ko00TS0_l00006o`068004o`000?l01b7o00LQo`078@Co00001Ol01b400ol0003o00TSo`098`02
o`098`Go00000ol032H00ol0003o00hXo`0>:004o`0>:003o`000?l042[o010Z00?o010Z1?l00003
o`0E;P03o`000?l05Roo01H_00Co01H_00Go0000ooooool0003oooooo`00000Qooooo`005?ooool2
o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Xooooo`Oo000000?o05A<
o`000?l000000_l0?dL3o`0000?o02Xl2?l00003o`0@:P03o`000?l03RSo00hX00?o00000_l02B<0
0ol0003o00TSo`098`03o`0000;o00HP00?o0000o`068?l01R000ol01R04o`0000?o00HP00?o0000
o`078Ol01b401?l01b400ol0003o00TSo`000004o`0000Ko00`V00?o0000o`0>:?l03RP00ol03RP0
0ol0003o010Zo`0@:P03o`000003o`0C;Ol0003o01D^00Go01D^00?o0000o`0F;ol05Rl00ol05Rl2
o`0000;ooooo00?o0000ooooooooool07oooool001[ooooo0_l0000<ooooo`03o`000?oooooooooo
06Gooooo3ol00002o`0Z?0?o000000?o01/co`000?l000000ol00005o`0@:P?o00001Ol02B<3o`00
00Ko00HP00?o0000o`068?l000000_l000000ol01Qoo0000o`068005o`068004o`000?l01b7o00LQ
o`078@Co00001?l02R@2o`0000Ko00`V00Co0000o`0>:?l03RSo00hX1?l00005o`0C;@03o`000?l0
5Bko01D^00?o01D^00?o0000o`0F;ol05Rl00ol000000ol073?o0000ooooo`02ooooo`03o`000?oo
oooooooo01kooooo000Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0H_ooool:
o`000003o`14B_l0003o000000?o02ho0ol00002o`0K<`Co00000ol04R`00ol0003o010Zo`000002
o`0000?o00/U00?o0000o`098ol000000_l00002o`078003o`000?l01R3o00HP00Co00HP0_l00005
o`067`03o`000?l01R3o00HP00?o00HP1?l00003o`088P03o`000?l02RCo00XT00?o00XT0_l00003
o`0<9PKo00000_l04B/00ol0003o01<]o`0C;@05o`0C;@03o`000?l05Bko01D^00;o01D^0ol00005
o`0L<`05o`000?ooooooooooooooool000007oooool001[ooooo00?o0000ooooooooool03Oooool2
o`0005oooooo3?l000000ol0A4[o0000o`0^?`02o`0^?`;o00000_l07cH5o`0000Go018/0_l00006
o`0;9@;o00001_l01b000ol0003o00HPo`068003o`000003o`067ol0003o00HO00Go00HO00?o0000
o`068?l000000_l000000ol01b7o0000o`088P05o`088P03o`000?l02RCo00XT00;o00XT1Ol00003
o`0?:@03o`000?l04B_o014[00?o014[00?o0000o`0C;Ol04bd01?l04bd00ol0003o01D^o`000002
o`000003o`0K<ol0003o01`c00Ko01`c00Co0000oooooooooooo00007oooool001[ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Jooooo`Oo000000?o05Y8o`000?l000000ol0Bdd4
o`000003o`0^?ol0003o01lf00?o000000?o01lfo`000?l000000_l00002o`0B;0?o00000_l032H0
0ol0003o00/Uo`0;9@03o`0000;o00PQ00?o0000o`078?l01b000ol01b03o`0000Go00HO00Co0000
o`067ol01Qoo00HO1?l00005o`078@03o`000?l022;o00PR00?o00PR00?o0000o`0:9?l02R@01Ol0
0006o`0?:@03o`000?l04B_o014[00?o014[00Co0000o`0C;Ol04bgo01<]1?l00005o`0K<`03o`00
0?l073?o01`c00Co01`c00Go0000ooooooooooooooooo`00000Nooooo`006_ooool2o`00017ooooo
00?o0000ooooooooool0F?ooool6o`000003o`1JB?l0003o000000?o04]=0_l00003o`0d@PCo0000
00Co01lfo`000?l0003o00000ol05Bh3o`0000Go00`V0ol00006o`088@03o`000?l01b3o000000;o
00000_l01Ql00ol0003o00HOo`067`03o`067`Co00000ol01R000ol0003o00LQo`078@04o`078@04
o`000?l022;o00PRo`088PCo00001?l03BL2o`0000Go00lY00Co0000o`0A:ol04B_o014[1_l00003
o`0I<@03o`000?l06c?o01/c00Co01/c00?o0000o`0L<ol073<00ol073<2o`0000;ooooo0_l0000M
ooooo`006_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05Cooooo3?l000000ol0
Bdgo0000o`000003o`0d@P?o00000_l093T3o`0000?o01D^0_l00002o`0?:@04o`000?l032Ko00`V
o`0<9P;o00000_l02B<00ol0003o00PQo`088@04o`088@;o00001_l01Ql00ol0003o00HOo`000002
o`000003o`068?l0003o00HP00Go00HP00?o0000o`078Ol01b400ol01b44o`0000;o00/U00?o0000
o`0=9ol03BL00ol03BL00ol0003o00dWo`000004o`0?:@Co00000ol05c000ol0003o01Tao`0I<@04
o`0I<@03o`000?l06c?o01/c00?o01/c00?o0000o`0L<ol073<00ol000000ol093Wo0000ooooo`02
ooooo`03o`000?oooooooooo01_ooooo000Iooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0D?ooool8o`000003o`1MAOl0003o000000?o055=1ol00003o`0T>@;o00000ol06S800ol0
003o01D^o`000005o`0?:@03o`000?l032Ko000000Go00TS00?o0000o`088Ol022400ol000000ol0
1b3o0000o`067`05o`067`;o00001Ol01R000ol0003o00HPo`068003o`068003o`000?l01b7o00LQ
00?o000000?o00XTo`000?l02bD01?l02bD00ol0003o00dWo`0=9`03o`0=9`;o000000Ko00lYo`00
0?l0003o0000o`0D;_l00006o`0G<003o`000?l06C7o01Ta00?o01Ta00Co0000o`0K<ol06c?o01/c
1Ol00005o`0T>@05o`000?ooooooooooooooool000007?ooool001Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1=ooooo`So00000_l0GDD01?l0003o055=o`1ACOl0DDd2o`000003
o`0lA_l0003o000000Co00000_l093T00ol0003o01Xbo`0J<P03o`0J<P?o00001Ol03bT2o`0000Ko
00TS0ol00005o`078003o`000?l01Qoo00HO00?o000000?o00LPo`000?l01R001Ol01R001?l0003o
00HPo`068?l01R04o`0000Go00XT00?o0000o`0;9Ol02bD00ol02bD01?l0003o00dWo`0=9ol03BL4
o`0000Go01@^00?o0000o`0G<?l05c000ol05c000ol0003o01Tao`0I<@03o`0I<@Co00000ol093T0
0ol0003o02@io`0T>@04o`0T>@05o`000?ooooooooooooooool000007?ooool001Wooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1:ooooo`ko000000?o055=o`000?l0?4H01?l00004
o`0[?@;o00001?l06S82o`0000?o01<]00?o0000o`0?:Ol000000_l00002o`0<9P04o`000?l02B?o
00TSo`098`;o000000?o00PRo`000?l01b001Ol01b03o`0000Go00LP00?o0000o`068?l01R000ol0
1R04o`0000;o00TS00?o0000o`0:9?l02R@01?l02R@01?l0003o00/Uo`0;9Ol02bD6o`0000?o018/
00?o0000o`0D;_l052h01?l052h00ol0003o01L`o`0G<002o`0G<003o`000?l06C7o01Ta00?o0000
00?o028ho`000?l093T01Ol093T00ol0003o02@io`0T>@03o`0T>@03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06Oooool001Wooooo0_l0000Gooooo`03o`000?oooooooooo04Oooooo2?l0
0002o`1Q@P;o00000ol0ED/4o`000003o`0lA_l0003o02/m00?o02/m0_l00002o`0O=P04o`000?l0
6S;o0000o`0000Go01<]0_l00006o`0<9P03o`000?l02B?o000000Co00PR00Co0000o`078?l01b3o
00LP0_l000000ol0227o0000o`078005o`078003o`000?l01R3o00HP00?o000000?o00TSo`000?l0
2B<01?l02B<00ol0003o00XTo`0:9003o`0:90Co00000ol042X00ol0003o018/o`0B;003o`0B;0;o
00001Ol052h01?l0003o01L`o`0G<?l05c04o`0000Go028h00?o0000o`0T>Ol093T00ol093T00ol0
003o02@io`0T>@03o`0T>@;o00001?ooool00ol0003oooooooooo`0Hooooo`006Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Cooooo2?l00002o`1Q@P;o00000ol0ED/3o`0000;o
04E:1?l000000ol0:cgo0000o`000004o`0O=P?o00001?l04bd2o`0000;o00lY00?o0000o`0<9_l0
32H00ol032H2o`0000Ko00PR00?o0000o`078?l000001?l022400ol0003o00LPo`078003o`0780?o
00001Ol02B<00ol0003o00TSo`098`03o`098`03o`000?l02RCo000000;o000000?o00lYo`000?l0
42X01Ol042X00ol0003o018/o`0B;003o`0B;003o`000?l052ko01@^00?o01@^1?l00002o`0P=P03
o`000?l08SSo028h00Co028h00?o0000o`0T>Ol093T00ol093T00ol0003o02@io`0T>@03o`000003
o`0a@?l0003ooooo00?ooooo0_l0000Iooooo`006Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo047ooooo4Ol00003o`15BP;o00000ol0<d83o`0000?o01lf0_l00003o`0H<@04o`00
0?l04bgo0000o`0000Go00lY00?o0000o`0<9_l000000_l00002o`0;9@03o`000?l022;o00PR00?o
00PR0_l00006o`088@03o`000?l01b3o000000;o000000?o00TSo`000?l02B<01Ol02B<00ol0003o
00TSo`098`03o`098`;o00001Ol03bT00ol0003o010Zo`0@:P04o`0@:P03o`000?l04Rco018/00;o
018/0_l000001_l052ko0000o`000?l0003o01ddo`0000Go020f00?o0000o`0R>?l08SP01?l08SP0
0ol0003o02@io`0T>@02o`0T>@?o00001Ol0<D000ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo0ol0000?ooooo`006?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
03kooooo2Ol000001?l0ISgo0000o`000?l0FTP7o`000003o`15B_l0003o03=200;o03=20_l00003
o`0W>P03o`000?l07cKo000000Go01Pa0_l00007o`0?:@;o00001_l02bD00ol0003o00PRo`000002
o`0000;o00TS00?o0000o`088Ol022400ol02242o`0000Go00TS00?o0000o`098ol02B<00ol02B<0
0ol0003o00TSo`098`03o`000003o`0>:?l0003o00lY00Go00lY00?o0000o`0@:_l042X00ol042X0
1?l0003o018/o`0B;?l04R`4o`0000Go01dd00?o0000o`0P=_l083H00ol083H00ol0003o028ho`0R
>003o`0R>003o`000?l093Wo000000;o000000?o0350o`000?l0<D001_l0<D000ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`006?oo
ool3o`0001_ooooo00?o0000ooooooooool0>oooool9o`0000;o06Hm1?l000000ol0FTSo0000o`00
0003o`1?CPCo000000?o03=2o`000?l09cX01?l09cX3o`0000?o01Pa0_l00002o`0D;P03o`000?l0
3bWo00lY00;o00lY0_l000000ol03RSo0000o`0;9@05o`0;9@;o00001_l02B<00ol0003o00PQo`00
0002o`000003o`0;9Ol0003o00TS00Go00TS00?o0000o`098ol02B<00_l02B<3o`0000Go00hX00?o
0000o`0?:Ol03bT00ol03bT01?l0003o010Zo`0@:_l042X6o`0000;o01/c0_l00005o`0M=003o`00
0?l083Ko020f00?o020f00Co0000o`0R>?l08SSo028h1?l00005o`0a@003o`000?l0<D3o035000Co
035000?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00co
oooo000:ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0hooooo`Go000000?o08<?o`000?l000001ol000000ol0FTSo0000o`000003o`1?CP;o0000
0ol0?DH3o`0000?o02Lj0_l00003o`0O=P03o`000?l0637o000000Go01@^00Co0000o`0?:Ol0003o
00001?l03RP00ol0003o00/Uo`0;9@03o`000003o`0<9_l0003o00TS00Go00TS0_l00005o`0;9@03
o`000?l02B?o00TS00?o00TS00?o0000o`098ol000000_l000000ol03RSo0000o`0>:006o`0>:003
o`000?l03bWo00lY00;o00lY1?l00003o`0I<@03o`000?l06c?o01/c00?o01/c0_l00004o`0M=004
o`000?l083Ko020fo`0P=PKo00000ol0;cl00ol0003o0350o`0a@004o`0a@003o`000?l0<D3o0350
00?o03500_l00004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool000Wo
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool07Oooool2o`0003Kooooo2Ol00002o`1[=`;o00000ol0Gd@4o`000003o`1?C_l0003o
000000?o03e60_l00003o`0`?`03o`000?l09c[o000000Go01lf0_l00006o`0D;P;o00001_l03RP3
o`0000Go00`V00Co0000o`098ol02B?o00TS0_l000000ol032Ko0000o`0;9@05o`0;9@03o`000?l0
2B?o00TS00;o00TS0_l00005o`0>:003o`000?l03RSo00hX00Co00hX00?o0000o`0?:Ol000000_l0
00000ol05c3o0000o`0I<@05o`0I<@03o`000?l06c?o01/c00?o01/c0_l00003o`0M=0Co00000ol0
;Ch00ol0003o02loo`0_?`04o`0_?`03o`000?l0<D3o035000?o035000?o0000o`0a@?l0<D000ol0
00000ol0@TWo0000ooooo`04ooooo`04o`000?ooooooooooooooo`Co00003oooool000gooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0<?ooool6o`000005o`271_l0003o0000o`000?l0JcL01?l00002o`1OA0;o
00000ol0E4`4o`000003o`0mA_l0003o000000Go030o0ol00003o`0O=P;o00000_l06S801?l0003o
01@^o`0D;_l052h2o`0000;o01<]00Co0000o`0>:?l03RSo00hX0_l000000ol03bWo0000o`0<9P05
o`0<9P04o`000?l02B?o0000o`0000Co00`V00?o0000o`0;9Ol02bD00ol02bD00ol0003o00TSo`00
0002o`000003o`0>:?l0003o00hX00Go00hX00?o0000o`0>:?l03RP00ol03RP2o`0000Go01L`00?o
0000o`0I<Ol06C400ol06C400ol0003o01/co`0K<`03o`0K<`Go000000?o02/mo`000?l0;Ch01Ol0
;Ch00ol0003o02loo`0_?`03o`0_?`03o`000?l0<D3o035000?o03500ol00005o`12B@04o`000?oo
ooooooooooooo`?o00000_ooool00ol0003oooooooooo`0@ooooo`003Oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000Qooooo`03o`000?oooooooooo02gooooo
1Ol00002o`271PKo000000?o06/go`000?l0Gd@00_l0Gd@01?l0003o05A<o`1DC?l0E4`2o`0000?o
04U<0ol00004o`0`?`;o00000ol09c/00ol0003o01lfo`000005o`0J<P03o`000?l052ko000000Go
01<]00?o0000o`0>:?l000001?l03bT00ol0003o00`Vo`0<9P03o`0<9P;o00001_l032H00ol0003o
00/Uo`0;9@03o`0;9@;o00001Ol03RP00ol0003o00hXo`0>:003o`0>:003o`000?l03RSo00hX00?o
000000?o01H_o`000?l05c001?l05c000ol0003o01Tao`0I<@03o`0I<@04o`000?l06c?o01/co`0K
<`Go00001?l0:cd00ol0003o02dno`0]?P03o`0]?P03o`000?l0;coo02lo00?o02lo00?o0000o`0a
@?l0<D000ol000000ol0@dWo0000o`12B@05o`12B@03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Ol0000>ooooo`002Oooool4o`0000?ooooo00Co0000oooooooooooo00000oooool3o`00
02;ooooo00?o0000ooooooooool0:_ooool<o`0000;o06la2?l000000ol0E4co0000o`19C002o`19
C0;o00000ol0>TD2o`000003o`0`?ol0003o02Lk00Co02Lk0_l00006o`0J<P;o00001_l04bd2o`00
00Ko00lY00?o0000o`0<9_l000000_l000000ol03bWo0000o`0<9P05o`0<9P03o`000?l02bGo00/U
00?o000000?o010Zo`000?l03RP01Ol03RP01?l0003o00hXo`0>:?l03RP4o`0000Go01H_00?o0000
o`0G<?l05c000ol05c000ol0003o01Tao`0I<@02o`0I<@Co00000ol0:3/00ol0003o02/mo`000003
o`0[?@03o`000?l0;Cko02dn00Co02dn00?o0000o`0_?ol0;cl00_l0;cl3o`0000Go04=900?o0000
o`12BOl0@TT00ol0@TT00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0009oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool2o`000003oaZD0?l0003o
oooo027ooooo00?o0000ooooooooool09oooool6o`000003o`>;0?l0003o000000?o00000_l0Kc42
o`0000;o06@o0_l00003o`1JB0Co000000?o04U<o`000?l0>TD01Ol0>TD3o`0000?o02Lk0_l00002
o`0R>004o`000?l06S;o01Xbo`0J<P;o00000_l06C401?l0003o01<]o`0C;Ol04bd2o`000003o`0D
;_l0003o00lY00Go00lY0_l00005o`0?:@03o`000?l032Ko00`V00?o00`V0ol00005o`0@:P03o`00
0?l03RSo00hX00?o00hX1?l00002o`0F;`03o`000?l05Roo01H_00Co01H_00?o0000o`0G<?l05c00
0ol05c000ol0003o01Tao`000002o`000003o`0V>_l0003o02Pk00Go02Pk00?o0000o`0[?Ol00000
0ol0:cd00ol0003o02dno`0]?P03o`0]?P03o`000?l0;coo000000;o000000?o0499o`000?l0@dT0
1Ol0@dT00ol0003o0499o`12B@04o`12B@03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4_ooool000Wooooo1Ol00003ooooo`;o00001?ooool01Ol0003oooooo`000?lJU03o000002;ooooo
00?o0000ooooooooool09?ooool6o`000006o`>;0?l0003o0000o`000?l0O1_o00000ol0Kc400ol0
003o06@oo`1T?`02o`0000?o05Y80_l00003o`1AC@?o00001?l0>TD2o`0000?o035000?o0000o`0W
>ol000001Ol08SP00ol0003o01Xbo`000005o`0I<@03o`000?l04bgo000000Co01@^00Co0000o`0?
:Ol03bWo00lY0_l000000ol04bgo0000o`0?:@05o`0?:@03o`000?l032Ko000000;o000000?o018/
o`000?l042X01Ol042X00ol0003o00hXo`0>:003o`000003o`0G<?l0003o01H_00Co01H_00?o0000
o`0F;ol05Rl00ol05Rl01?l0003o01L`o`0G<?l05c04o`0000Go02Hj00?o0000o`0X>ol0:3/00ol0
:3/00ol0003o02/mo`000003o`0[?@04o`000?l0;Cko02dno`0]?PCo00001Ol0@TT00ol0003o04=9
o`13B@03o`13B@03o`000?l0@TWo049900?o04990_l00006ooooo`03o`000?oooooooooo017ooooo
000Gooooo`06o`000?ooooooooooo`000?lJU03o00008_ooool00ol0003oooooooooo`0PoooooaOo
00000_l0FTP00ol0003o055=o`1AC@02o`1AC@06o`000?l0Ad_o04M;o`17Bol0003o03Y50_l00005
o`0a@0;o00001_l08SP2o`0000Ko01Ta0_l00006o`0D;P03o`000?l03bWo000000Co01<]00?o0000
o`0?:Ol03bT00ol03bT2o`0000Go018/00?o0000o`0@:_l042X00ol042X3o`0000Go01L`00?o0000
o`0F;ol05Rl00ol05Rl00ol0003o01H_o`0F;`02o`0F;`Co00000ol093T00ol0003o02Hjo`0V>P03
o`0V>P03o`000?l0:3_o02Pk00?o02Pk00?o0000o`0[?Ol0:cd01ol00003o`11B003o`000?l0@TWo
049900?o049900?o0000o`13BOl0@dT01?l0@dT00ol0003o0499o`000002o`000003o`1BCOl0003o
oooo00Kooooo00?o0000ooooooooool04?ooool001Oooooo0_l00002ooooo`?o00008_ooool00ol0
003oooooooooo`0Mooooo`_o000000?o084Bo`000?l000000_l0M2T2o`0000;o06Ti00?o0000o`1O
A?l0Gd@00_l0Gd@3o`0000?o055=00?o0000o`17Bol0Ad/00_l0Ad/2o`0000Ko035000Co0000o`0/
?Ol0;3go00000ol08SP2o`0000;o024g00Co0000o`0I<Ol06C7o01Ta0_l000000ol06S;o0000o`0D
;P05o`0D;P;o00001_l04bd00ol0003o00lYo`0?:@02o`000003o`0E;_l0003o018/00Go018/00?o
0000o`0@:_l000000_l000000ol06C7o0000o`0G<005o`0G<003o`000?l05Roo01H_00?o01H_00?o
0000o`0F;ol000000_l000000ol08cSo0000o`0T>@05o`0T>@03o`000?l09S[o02Hj00?o02Hj00?o
0000o`0X>ol0:3/00_l0:3/5o`0000;o03i700?o0000o`11B?l0@DP01?l0@DP00ol0003o0499o`12
B@03o`12B@03o`000?l0@dWo04=900;o04=90ol00005o`1BC@03o`000?oooooooooo00?ooooo0_l0
000Booooo`005oooool00ol0003oooooooooo`02ooooo`?o00008_ooool00ol0003oooooooooo`0I
ooooo`Ko000000Co=Yd0o`000?l0003o38l00_l00002o`214P05o`000?l0M2Wo07@Yo`1d:Ol00000
0ol0JCT00ol0003o05m4o`1OA002o`1OA007o`000?l0Ed[o05M:o`1GB_l0003o055=o`000004o`17
B`04o`000?l0?DKo03e6o`0000?o03500_l00004o`0/?@03o`000?l08SSo000000Go024g00?o0000
o`0I<Ol000001?l06S801?l0003o01@^o`0D;_l052h2o`000003o`0H<Ol0003o01<]00Go01<]00?o
0000o`0?:Ol000001?l05Bh00ol0003o018/o`0B;003o`0B;0;o00001Ol06C400ol0003o01L`o`0G
<003o`0G<003o`000?l05Roo01H_00?o01H_0_l00005o`0S>003o`000?l093Wo02@i00?o02@i00?o
0000o`0V>_l09SX00ol09SX00ol0003o02Pko`000002o`000003o`0kA_l0003o03i700;o03i700Co
0000o`0nAol0?TOo00001Ol0@DP00ol0003o0499o`12B@03o`12B@03o`000?l0@dWo000000;o0000
00?o05=<o`000?l0DTd01Ol0DTd00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo
000Gooooo`03o`000?oooooooooo00Cooooo0_l0000Rooooo`03o`000?oooooooooo01Gooooo1Ol0
00000omY[@3o0000o`00000?o`000003o`1Y>Ol0003o05m400;o05m40_l00004o`1GBP?o00000ol0
Ad/00ol0003o03e6o`0mAP02o`0mAP03o`000?l0<D3o000000Ko02`m0_l00006o`0Q=`;o00001_l0
6S800ol0003o01@^o`000004o`0H<@03o`000?l04bgo01<]00?o01<]0_l00006o`0E;P03o`000?l0
4Rco018/00;o000000?o01/co`000?l06C401?l06C400ol0003o01L`o`0G<004o`0G<003o`000?l0
5Roo000000;o000000?o02<ho`000?l08cP01?l08cP00ol0003o02@io`0T>@03o`0T>@04o`000?l0
9S[o02Hjo`0V>PCo00001Ol0>dH01?l0003o03i7o`0nAol00002o`0nA`03o`000?l0@DSo045800?o
045800?o0000o`12BOl0@TT00ol0@TT2o`0000Go05=<00?o0000o`1BCOl0DTd01?l0DTd00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00kooooo000Fooooo`03o`000?oooooooooo00Kooooo
0ol0000Qooooo`03o`000?oooooooooo01;ooooo2_l000000olFTP3o0000o`000002o`252@;o0000
0_l0NB42o`0000?o06hb1?l000000ol0GdCo0000o`1GBP03o`1GBP;o00000ol0DDd00ol0003o04M;
o`000005o`0mAP?o00001?l0;3d2o`000003o`0Z??l0003o024g00?o024g0_l000000ol08SSo0000
o`0J<P05o`0J<P;o00001_l063400ol0003o01<]o`000002o`000003o`0J<_l0003o01D^00Go01D^
00?o0000o`0B;?l000001?l06c<00ol0003o01Tao`0I<@03o`0I<@03o`000?l05c3o01L`00;o01L`
0ol00005o`0S>003o`000?l08cSo02<h00?o02<h00?o0000o`0T>Ol093T00_l093T4o`0000?o03U5
00?o0000o`0kA_l0>dH00ol0>dH01Ol0003o03i7o`0nAol0?TOo000000;o03i700?o0000o`11B?l0
@DP00ol0@DP00ol0003o0499o`000002o`000003o`1DC?l0003o05=<00Co05=<00?o0000o`1BCOl0
DTd01?l0DTd00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo000Fooooo`;o0000
2?ooool4o`00023ooooo00?o0000ooooooooool03oooool:o`0000;o5Y8000Go0000o`252Ol0Q@Wo
08D9o`000002o`1i8@;o00000ol0KS82o`0000?o06Dn1?l00002o`1GBP03o`000?l0DDgo055=00?o
055=0ol00003o`0mAP;o00000ol0=d<01?l0003o02`mo`000?l00004o`0Z?004o`000?l08COo0000
o`0000Co028h00Co0000o`0J<_l06S;o01Xb0_l000000ol07cKo0000o`0H<@05o`0H<@;o00001Ol0
6S800ol0003o01D^o`0E;P03o`0E;P;o00001Ol06c<00ol0003o01Tao`0I<@03o`0I<@03o`000?l0
5c3o000000;o000000?o02@io`000?l08cP01Ol08cP00ol0003o02<ho`0S>003o`0S>003o`000?l0
93Wo000000;o000000?o03Q4o`000?l0>DD01Ol0>DD00ol0003o03]6o`0kAP03o`0kAP07o`000?l0
?TOo03i7o`0nAol0003o03i7o`000003o`11B0Co00001Ol0E4`00ol0003o05=<o`1CC003o`1CC003
o`000?l0DTgo059=00?o059=0_l00007ooooo`03o`000?oooooooooo00gooooo000Fooooo`03o`00
0?oooooooooo00Wooooo1?l0000Oooooo`03o`000?oooooooooo00_ooooo6?l00002o`1^<P04o`00
0?l0ICko06Dno`1U?P;o00001?l0GDH3o`0000?o055=0_l00003o`1:C003o`000?l0?DKo000000Go
03M30_l00006o`0Z?0;o00001_l08SP01?l0003o01Xbo`000?l00004o`0O=P04o`000?l0637o01Pa
o`0H<@;o000000?o01lfo`000?l06S801Ol06S800ol0003o01D^o`000002o`000003o`0O=_l0003o
01/c00Go01/c00?o0000o`0I<Ol06C400_l06C42o`0000Go02@i00?o0000o`0S>?l08cP00ol08cP0
0ol0003o02<ho`0S>003o`0S>0;o00001Ol0>4@00ol0003o03U5o`0iA@03o`0iA@03o`000?l0>dKo
03]600?o03]600Ko0000o`0nAol0?TOo03i7o`000?l0?TL4o`0000;o05=<00?o0000o`1DC?l0E4`0
1?l0E4`00ol0003o05=<o`1CC003o`1CC003o`000?l0DTgo059=00?o000000?o05e5o`000?ooool0
1_ooool00ol0003oooooooooo`0=ooooo`005_ooool00ol0003oooooooooo`0:ooooo`Co00007ooo
ool2o`0000Sooooo2?l000001Om7X`3o0000o`000?l0003o7YH000?o000000Go08T1o`000?l0003o
0000o`1m6@02o`0000Co07</1?l000000ol0ICko0000o`1MAP03o`1MAP;o00000ol0EdX00ol0003o
055=o`000005o`1:C0;o00001Ol0=d<01?l0003o03E3o`0e@ol00003o`0Z?0;o000000?o02`mo`00
0?l08SP01Ol08SP2o`0000Ko01lf00Co0000o`0H<Ol0003o00001?l07cH00ol0003o01Xbo`0J<P03
o`0J<P;o00001Ol07cH00ol0003o01/co`0K<`03o`0K<`03o`000?l06C7o000000;o000000?o02Hj
o`000?l093T01Ol093T00ol0003o02<ho`0S>003o`0S>003o`000?l08cSo000000;o000000?o03M3
o`000?l0>4@01?l0>4@00ol0003o03U5o`0iA@03o`0iA@03o`000?l0>dKo03]600?o03]600?o0000
o`0nAol0?TL00ol000000ol0Ddgo0000o`1CC004o`1CC003o`000?l0E4co05A<00?o05A<00?o0000
o`1CC?l0Dd`00ol0Dd`3o`0000Go05e500?o0000ooooooooool01?ooool2o`0000kooooo000Foooo
o`03o`000?oooooooooo00_ooooo1?l0000Pooooo`04o`000?oooooooooooooooaKo00000_l0OAT0
0ol0003o07</o`1c;002o`1c;0;o00000ol0JSP4o`000003o`1MA_l0003o000000Go05M:0ol00003
o`1:C0;o00000_l0A4T01Ol0003o03M3o`0g@ol0=d?o000000Co03E300?o0000o`0Z??l000001?l0
;3d01?l0003o028ho`0R>?l08SP2o`000003o`0W>ol0003o01lf00Go01lf0_l00006o`0O=P04o`00
0?l06S;o01Xbo`0J<P;o000000?o02@io`000?l07cH01Ol07cH00ol0003o01/co`0K<`02o`0K<`;o
00001Ol09SX00ol0003o02@io`0T>@03o`0T>@04o`000?l08cSo02<ho`0S>0Co00001Ol0=d<00ol0
003o03Q4o`0hA003o`0hA003o`000?l0>DGo03U500?o03U500?o0000o`0kA_l0>dH01Ol00003o`1C
C@03o`000?l0Ddgo000000Co05=<00?o0000o`1DC?l0E4`01?l0E4`00ol0003o05=<o`000002o`00
0003o`1OA?l0003o05e500Go05e500?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`005_ooool00ol0003oooooooooo`0=ooooo`Co00007oooool>o`0000;o9IP00_l000000ol5S03o
0000o`000004o`214PCo000000?o07</o`000?l000000ol0JSP2o`0000?o06910ol00004o`1GBP;o
00000ol0DTd00ol0003o04Y<o`000005o`14B@03o`000?l0=d?o000000Go03E30_l00006o`0/?@03
o`000?l08SSo000000Co02Lk00Co0000o`0O=_l07cKo01lf0_l000000ol09c[o0000o`0O=P05o`0O
=P04o`000?l06S;o0000o`0000Co02@i00?o0000o`0O=_l07cH00ol07cH00ol0003o01/co`000002
o`000003o`0Z??l0003o02Hj00Go02Hj00?o0000o`0T>Ol093T00_l093T4o`0000;o03M300?o0000
o`0g@ol0=d<01?l0=d<00ol0003o03Q4o`0hA003o`0hA003o`000?l0>DGo03U500;o03U51?l00003
o`1BC@03o`000?l0Ddgo05==00?o05==0_l00005o`1CC003o`000?l0E4co05A<00;o05A<0ol00005
o`1OA003o`000?l0GDGo05e500?o05e500?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`005Oooool3o`00013ooooo1?l0000Jooooo`oo00000_lUV002o`0000;o1H`000?o0000o`21
4_l0PA800_l0PA82o`0000?o07LU1?l00002o`1Z>004o`000?l0HT7o0691o`1R@@;o00000ol0G4H2
o`000003o`1GB_l0003o059=00Co059=0_l00006o`14B@;o00001Ol0=D<00ol0003o03M3o`000006
o`0/?@;o00001_l09c/00ol0003o01lfo`000004o`0W>P03o`000?l07cKo01lf00?o01lf0_l00006
o`0T>@03o`000?l07cKo01lf00?o01lf0_l00005o`0Z?003o`000?l09S[o02Hj00?o02Hj00?o0000
o`0T>Ol000000_l000000ol0>4Co0000o`0g@`04o`0g@`03o`000?l0=d?o03M300?o03M300?o0000
o`0hA?l0>4@00ol0>4@00ol0003o03U5o`000002o`000003o`1ACOl0003o059=00Go059=00?o0000
o`1CCOl0Ddd00_l0Ddd2o`0000Go05=<00?o0000o`1DC?l000000_l000000ol0H4?o0000o`1OA005
o`1OA003o`000?l0GDGo05e500Co05e500?o0000ooooooooool01_ooool00ol0003oooooooooo`0:
ooooo`005Oooool00ol0003oooooooooo`0Booooo`Go00004_oooolLo`0000;o084B00Co0000o`1g
9Ol0MbGo07LU0_l00004o`1_<PCo000000?o0691o`000?l0G4H01Ol0G4H3o`0000?o059=0_l00002
o`1@CP04o`000?l0A4Wo04A9o`14B@;o00000_l0@TT01Ol0003o03E3o`0e@ol0=D?o000000?o03M3
00Co0000o`0/?Ol0;3go02`m0_l000000ol0<D3o0000o`0W>`05o`0W>`;o00001_l09cX00ol0003o
01lfo`0O=P02o`000003o`0[?Ol0003o02@i00Go02@i00?o0000o`0O=_l07cH00ol000000ol0;Soo
0000o`0Z?004o`0Z?003o`000?l09S[o02Hj00?o02Hj0_l00005o`0hA003o`000?l0=d?o03M300;o
03M300?o0000o`0g@ol0=d<01?l0=d<00ol0003o03Q4o`0hA004o`0000Go055=00?o0000o`1BCOl0
DTd00ol0DTd00ol0003o05==o`1CC@03o`1CC@;o00000_l0Dd`4o`0000Go061300?o0000o`1OA?l0
Gd@01?l0Gd@00ol0003o05e5o`1MA@02o`1MA@;o00002Oooool00ol0003oooooooooo`09ooooo`00
5Oooool00ol0003oooooooooo`0EoooooaSo000000?o[[l0o`000?l000001Ol000001Om>Y@3o0000
o`000?l0003o:IT000?o000000Co2hh0o`000?l0003o00001?l0Q0`4o`000003o`1g9Ol0003o06lb
00?o06lb0_l00003o`1W>`?o00001?l0G4H2o`0000?o05Q900?o0000o`1BCOl000001Ol0D4h00ol0
003o04A9o`000005o`12B@03o`000?l0=D?o000000Go03M300?o0000o`0/?Ol000001?l0<D001?l0
003o02Lko`0W>ol09c/2o`000003o`0`?ol0003o02Lj00Go02Lj00?o0000o`0O=_l000001?l0:cd0
0ol0003o02@io`0T>@03o`0T>@?o00001Ol0;Sl00ol0003o02Xlo`0Z?002o`0Z?003o`000?l09S[o
02Hj00?o000000?o03]5o`000?l0>4@01?l0>4@00ol0003o03M3o`0g@`03o`0g@`03o`000?l0=d?o
03M300;o03M31?l00003o`1@CP03o`000?l0DDgo055=00?o055=00?o0000o`1BCOl0DTd01?l0DTd0
0ol0003o05==o`1CC@02o`1CC@Co00000ol0H4<00ol0003o0613o`1P@`03o`1P@`03o`000?l0GdCo
05m400Co05m400?o0000o`1MAOl000000_l000000ol0JCWo0000ooooo`08ooooo`;o00002_ooool0
01Gooooo00?o0000ooooooooool05ooooolYo`0000;o08@<0ol00003o`1j7PCo00000_l0Kc801?l0
003o06Lko`1W>ol0Ic/2o`0000?o069100Co0000o`1LA_l0003o00001Ol0F4T2o`0000Ko051>0_l0
0006o`12B@;o00001_l0=d<2o`0000Ko035000?o0000o`0W>ol000001?l0<3l00ol0003o02Ljo`0W
>P03o`0W>P;o00001_l0:cd00ol0003o02@io`0T>@02o`000003o`0d@_l0003o02ho00Go02ho00?o
0000o`0Z??l0:S`00_l0:S`3o`0000Go03]500?o0000o`0hA?l0>4@00ol0>4@00ol0003o03M3o`0g
@`02o`0g@`03o`000?l0=d?o000000;o000000?o051>o`000?l0D4h01Ol0D4h00ol0003o055=o`1A
C@03o`1AC@03o`000?l0DTgo059=00?o059=00?o0000o`1CCOl000000_l000000ol0H4?o0000o`00
0005o`1P@`03o`000?l0H4?o061300?o061300?o0000o`1OA?l0Gd@00ol0Gd@2o`0000Go06Ti00?o
0000ooooooooool01_ooool2o`0000[ooooo000Eooooo`;o00006_oooolJo`0000;o:YX00ol00000
1?l>S`3o0000o`000?l00003o`2520Co00000_l0NQh3o`0000Co078/1?l000000ol0Ic_o0000o`1R
@@04o`1R@@?o00001Ol0F4T01?l0003o05I;o`1FBol00003o`1@CP;o00000_l0Cdh01?l0003o0499
o`12BOl0@TT2o`0000;o04A900Co0000o`0g@ol0=d?o03M30_l000000ol0?DKo0000o`0a@005o`0a
@0;o00001_l0<3l00ol0003o02Ljo`0W>P02o`000003o`0c@_l0003o02/m00Go02/m00?o0000o`0T
>Ol000001?l0=4800ol0003o02hoo`0^?`03o`0^?`03o`000?l0:Sco02Xl00;o000000?o03m7o`00
0?l0>dD01Ol0>dD00ol0003o03Q4o`0hA003o`0hA003o`000?l0=d?o03M300;o03M30_l00005o`1@
CP03o`000?l0D4ko051>00?o051>00?o0000o`1ACOl0DDd00ol0DDd00ol0003o059=o`1BC@03o`1B
C@;o00001Ol0H4<00ol0003o0613o`1P@`03o`1P@`03o`000?l0H4?o061300?o061300Co0000o`1O
A?l0GdCo05m40_l000000ol0K3Ko0000o`1Y>@04o`1Y>@03o`000?oooooooooo00Kooooo0ol00009
ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo01_ooooo4ol00004obNH00So00000_l0Q@P3o`0000Co07dJ0ol00004o`1b;0;o00000ol0K3H3
o`0000?o06910_l00003o`1NA@05o`000?l0F4Wo05Q9o`1HBOl000001?l0ET/00ol0003o051>o`00
0005o`1?CP03o`000?l0@TWo000000Go04A900?o0000o`0g@ol000001?l0?DH01?l0003o0350o`0a
@?l0<D02o`000003o`0jAOl0003o030o00Go030o00?o0000o`0W>_l000001?l0<d800ol0003o02/m
o`0[?@03o`0[?@;o00001Ol0=4800ol0003o02hoo`0^?`04o`0^?`;o00001?l0?dL00ol0003o03]5
o`0kA@03o`0kA@03o`000?l0>4Co03Q400?o03Q400?o0000o`0g@ol000000_l000000ol0D4ko0000
o`1@CP04o`1@CP03o`000?l0D4ko051>00Co051>00?o0000o`1ACOl0DDd00_l0DDd00ol0003o059=
o`1BC@03o`000003o`1OA?l0003o061300Co06130_l00004o`1P@`03o`000?l0H4?o061300?o0613
00Co0000o`1OA?l0003o00000ol0K3H00ol0003o06Tio`1Y>@04o`1Y>@03o`000?oooooooooo00;o
oooo0ol00002ooooo`03o`000?oooooooooo00Oooooo0002ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
01kooooo3?l00003oajE00Ko000000Co3Hl0o`000?l0003o00001?l0QPL3o`0000Co07dJ0_l00003
o`1e9`04o`000?l0LRco0000o`0000?o06`f0_l00003o`1V?003o`000?l0HT7o000000Ko05i500?o
0000o`1HBOl000001Ol0ET/2o`0000Ko04m>0_l00006o`14B@;o00001_l0?DH00ol0003o0350o`00
0004o`0jA@03o`000?l0<3oo030o00?o030o0_l00006o`0c@P03o`000?l0:cgo02/m00;o000000?o
03a6o`000?l0=4801Ol0=4800ol0003o02hoo`0^?`02o`0^?`;o00001Ol0?dL00ol0003o03]5o`0k
A@04o`0kA@03o`000?l0>4Co03Q400Co00001Ol0D4h00ol0003o051>o`1@CP03o`1@CP03o`000?l0
D4ko051>00?o051>00Co0000o`1ACOl0DDgo055=1?l00004o`1OA003o`000?l0H4?o061300Co0613
0_l00004o`1P@`03o`000?l0H4?o061300Co00001_l0K3H00ol0003o06Tio`1Y>@03o`1Y>@03o`00
0?oooooo000000;o00001Oooool00ol0003oooooooooo`07ooooo`000_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0Pooooo`go00001?l7S@05o`0000;o08H70ol00003o`1n60;o000000?o07dJo`000?l0
MBL01?l0MBL4o`0000;o06`f00?o0000o`1V??l0IS`00ol0IS`2o`0000Oo05i50ol00003o`1FB`;o
00000_l0ED/01?l0003o04m>o`1?C_l0Cdh2o`000003o`1@C_l0003o04A900Co04A900?o0000o`1:
C?l000001_l0?DH2o`0000Ko03Y500?o0000o`0`?ol0<3l00_l000000ol0?DKo0000o`0c@P05o`0c
@P03o`000?l0:cgo000000Co03a600?o0000o`0d@_l0=4800ol0=4800ol0003o02hoo`000002o`00
0003o`14B_l0003o03m700Go03m700?o0000o`0kAOl0>dD00_l0>dD4o`0000?o055=00?o0000o`1@
C_l0D4h00ol0D4h00ol0003o051>o`1@CP03o`1@CP03o`000?l0D4ko051>00?o051>1?l00002o`1O
A003o`000?l0GdCo05m400Co05m400?o0000o`1P@ol0H4<00ol0H4<2o`0000?o06131?l00003o`1]
=003o`000?l0K3Ko06`f00Co06`f00?o0000o`1Y>Ol0JCT00ol0JCT2o`0000Sooooo00?o0000oooo
ooooool01oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07oooool:o`0000?o08P21Ol00004
o`252PGo00001?l0OQP5o`000004o`1e9ol0003o0000o`0000Co06la0ol00003o`1V?0;o00000_l0
Hd400ol0003o05i5o`1NA@02o`1NA@;o00000ol0FdL00ol0003o05I;o`000005o`1EB`03o`000?l0
Cdko000000Co051>00Go0000o`14BOl0A4Wo04A9o`000003o`1:C004o`000?l0?DKo03e6o`0mAP;o
000000?o04M;o`000?l0>TD01Ol0>TD00ol0003o030oo`000004o`0mAP03o`000?l0<d;o03=200?o
03=20_l00005o`0lAP03o`000?l0=4;o03A200?o03A20_l00005o`14BP03o`000?l0?dOo03m700?o
03m700?o0000o`0kAOl0>dD00_l000000ol0DTgo0000o`1AC@05o`1AC@03o`000?l0D4ko051>00?o
051>00?o0000o`1@C_l0D4h00_l0D4h00ol0003o051>o`1@CP03o`000003o`1NA?l0003o05m400Co
05m400?o0000o`1OA?l0Gd@00ol0Gd@00ol0003o0613o`1P@`03o`1P@`03o`000?l0H4?o000000;o
000000?o06hco`000?l0KC@01Ol0KC@00ol0003o06`fo`1/=P03o`1/=P04o`000?l0JCWo06Tio`1Y
>@;o000000?o07HWo`000?ooool02?ooool00ol0003oooooooooo`06ooooo`000_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool2
o`0001gooooo0ol00005ooooo`So00001?l0PA45o`0000Go07dI1?l00004o`1g9@?o00001?l0Kc42
o`0000?o06Xh00?o0000o`1V??l000001Ol0Hd401?l0003o05i5o`000?l00005o`1KA`;o00001_l0
ED/2o`0000Ko051>00?o0000o`14BOl000001Ol0BT`00ol0003o03e6o`000004o`17B`03o`000?l0
>TGo03Y500?o03Y50_l00006o`0mAP03o`000?l0<d;o03=200;o000000?o04E:o`000?l0?4H01Ol0
?4H00ol0003o03A2o`0d@P02o`000003o`1;COl0003o04A:00Co04A:00?o0000o`0oAol0?dL00ol0
?dL00ol0003o03]5o`000004o`1BC@03o`000?l0DDgo055=00?o055=00?o0000o`1@C_l0D4h00ol0
D4h01?l0003o051>o`1@C_l0D4h4o`0000Co05i400?o0000o`1OA?l0Gd@00ol0Gd@00ol0003o05m4
o`1OA003o`1OA003o`000?l0H4?o061300?o06130_l000000ol0KS?o0000o`1^<`02o`1^<`03o`00
0?l0KCCo06dd00?o06dd00?o0000o`1/=_l0K3H01?l0K3H3o`0000?o07HW00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`0000?oooooo`000?l000001?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool06Oooool3o`0000[o
oooo2_l00004o`1k7P;o000000Co07dIo`000?l0003o00000ol0MbD00ol0003o07LUo`000002o`00
00?o074^0_l000000ol0Kc7o0000o`1Z>004o`1Z>0?o00001Ol0Hd43o`0000Co05]70_l00002o`1J
B004o`000?l0ED_o05E;o`1EB`;o000000?o05I;o`000?l0D4h01Ol0D4h2o`0000Ko04Y<0_l00006
o`17B`03o`000?l0>TGo03Y500;o000000?o04U<o`000?l0?DH01Ol0?DH00ol0003o03=2o`000004
o`15BP03o`000?l0?4Ko03a600?o03a600?o0000o`0d@_l000001?l0Bdd00ol0003o04A:o`14BP03
o`14BP03o`000?l0?dOo03m700;o03m70_l00005o`1BC@03o`000?l0DDgo055=00?o055=00?o0000
o`1@C_l0D4h00ol0D4h4o`0000;o05i500?o0000o`1NA?l0GT@01?l0GT@00ol0003o05m4o`1OA003
o`1OA003o`000?l0GdCo05m400?o05m400?o0000o`1P@ol000000_l000001Ol0KS;o0000o`1^<ol0
KS?o000000;o06hc00?o0000o`1]=?l0KC@01?l0KC@00ol0003o06`fo`1/=P02o`1/=P;o00001_l0
MRL00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo0002ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00001?ooool00ol0003oooooooooo`0Fooooo`?o00003_ooool5
o`0000?o07HW0_l00003o`1k7PGo00000ol0MbD4o`0000Ko074^0ol00003o`1Z>0;o00000ol0IS`0
0ol0003o06=1o`000002o`0000?o06130_l000000ol0FdOo0000o`1JB004o`1JB003o`000?l0ED_o
000000Co05I;00Co0000o`1@C_l0D4ko051>0_l00002o`1BC@04o`000?l0BTco04Y<o`1:C0;o0000
00?o055=o`000?l0Ad/01Ol0Ad/00ol0003o03Y5o`000004o`19C003o`000?l0?DKo03e600?o03e6
0_l00006o`15BP03o`000?l0?4Ko03a600;o03a60_l00005o`1;C@03o`000?l0A4[o04A:00?o04A:
00?o0000o`0oAol000000_l000000ol0E4co0000o`1BC@05o`1BC@03o`000?l0DDgo055=00?o055=
00?o0000o`1@C_l000000_l000000ol0GdCo0000o`1NA@04o`1NA@03o`000?l0GTCo05i400?o05i4
00?o0000o`1OA?l0Gd@00ol0Gd@01?l0003o05m4o`1OA?l0Gd@4o`0000Co06hb00Co0000o`1^<ol0
KS?o00000ol0KS<00ol0003o06ddo`1]=003o`1]=003o`000?l0K3Ko000000;o000000?o07TQo`00
0?l0MRL01Ol0MRL00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000Dooooo`03
o`000?oooooooooo01?ooooo0ol0000Cooooo`_o00000ol0MBP5o`0000Co074^0_l000001?l0LBko
0000o`000?l00003o`1/=@03o`000?l0JSSo000000Go06Hl0ol00006o`1P@`;o00001_l0FTP2o`00
00Ko05I;00?o0000o`1@C_l000001Ol0DTd00ol0003o04Y<o`000004o`1AC@03o`000?l0Ad_o04M;
00?o04M;0_l00006o`19C003o`000?l0?DKo03e600;o000000?o04m>o`000?l0ADX01Ol0ADX00ol0
003o03a6o`000002o`000003o`1ACOl0003o04]=00Go04]=00?o0000o`14B_l0A4X00_l0A4X2o`00
00Go05A<00?o0000o`1BCOl0DTd00ol0DTd00ol0003o055=o`1AC@02o`1AC@?o00001?l0Gd@00ol0
003o05i5o`1NA@03o`1NA@03o`000?l0GTCo05i400?o05i400?o0000o`1OA?l0Gd@00ol0Gd@4o`00
00;o06hb00?o0000o`1^<_l0KS801?l0KS801?l0003o06hco`1^<ol00002o`1^<`03o`000?l0KCCo
06dd00?o06dd0_l00005o`1i8@03o`000?l0MROo07HW00?o07HW00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`004oooool2o`0001;ooooo0ol0000Hooooo`Co00000ol0L2l5o`00
00Co070`0_l00003o`1a;PCo00001Ol0K3D3o`0000?o06Hl0_l00003o`1T?`04o`000?l0H4?o0613
o`1P@`;o00000_l0Gd@01?l0003o05Y8o`1JB?l0FTP2o`000003o`1KAol0003o05I;00Go05I;0_l0
0006o`1BC@;o00001_l0DDd00ol0003o04M;o`17B`02o`000003o`1ACOl0003o04U<00Go04U<00?o
0000o`0mA_l000001?l0Cdh00ol0003o04E:o`15BP03o`15BP;o00001Ol0DDd00ol0003o04]=o`1;
C@03o`1;C@03o`000?l0A4[o000000;o000000?o05M:o`000?l0E4`01?l0E4`00ol0003o059=o`1B
C@03o`1BC@03o`000?l0DDgo000000;o000000?o05m4o`000?l0Gd@01Ol0Gd@00ol0003o05i5o`1N
A@03o`1NA@03o`000?l0GTCo05i400?o05i400?o0000o`1OA?l000000_l000000ol0KS?o0000o`1^
<P04o`1^<P03o`000?l0KS;o06hb00?o06hb00Oo0000o`1^<ol0KS?o06hco`000?l0KS?o000000;o
06dd0ol000000ol0O1co0000o`1i8@04o`1i8@03o`000?l0MROo07HW00Co07HW00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`004oooool00ol0003oooooooooo`0?ooooo`;o0000
7Oooool5o`0000Co06`e0_l00003o`1`<0Go00001?l0KC@00ol0003o06`eo`000002o`0000?o06Ti
00?o0000o`1V??l000001_l0I3l00ol0003o0613o`000005o`1OA003o`000?l0FTSo000000Co05]7
00Co0000o`1FBol0ET_o05I;0_l000000ol0F4Wo0000o`1BC@04o`1BC@03o`000?l0Ed[o000000Ko
055=00?o0000o`17Bol000001?l0DDd00ol0003o04U<o`19C003o`19C0;o00001_l0Cdh00ol0003o
04E:o`15BP02o`000003o`1EBol0003o055=00Co055=00?o0000o`1;COl0Bdd00ol0Bdd2o`0000Go
05M:00?o0000o`1DC?l0E4`00ol0E4`00ol0003o059=o`1BC@02o`1BC@;o00001Ol0Gd@00ol0003o
05m4o`1OA003o`1OA003o`000?l0GTGo05i500?o05i500?o0000o`1NA?l0GT@00_l0GT@3o`0000Co
06hc00?o0000o`1^<_l0KS800ol0KS800ol0003o06hbo`1^<P03o`1^<P03o`000?l0KS?o06hc00;o
06hc1?l00004o`1l7003o`000?l0NB7o07TQ00Co07TQ00?o0000o`1f9ol0MRL00_l0MRL2o`0000Oo
oooo00?o0000ooooooooool01_ooool001?ooooo00?o0000ooooooooool03?ooool3o`00023ooooo
1Ol00003o`1/=@Go00001?l0K3D01?l0003o06ddo`1]=?l0KC@4o`0000Go06Ti0_l00007o`1T?`;o
00001_l0Gd@2o`0000Ko05]700?o0000o`1FBol000001?l0F4T01Ol0003o059=o`1BCOl0DTgo0000
00?o05M:00?o0000o`1ACOl0DDd00ol0DDd2o`0000Ko055=00?o0000o`19C?l0BD`00_l000000ol0
E4co0000o`1?CP05o`1?CP03o`000?l0AD[o000000Co05E;00?o0000o`1ACOl0DDd00ol0DDd00ol0
003o04]=o`1;C@02o`000003o`1JB?l0003o05M:00Co05M:00?o0000o`1DC?l0E4`00ol0E4`00ol0
003o059=o`000002o`000003o`1Q@_l0003o05m400Co05m400?o0000o`1OA?l0Gd@00ol0Gd@00ol0
003o05i5o`1NA@03o`1NA@03o`000?l0GTCo000000;o000000?o06hco`000?l0KS<01Ol0KS<00ol0
003o06hbo`1^<P03o`1^<P03o`000?l0KS;o06hb00?o06hb00?o0000o`1^<ol000000_l000000ol0
OA[o0000o`1l7005o`1l7003o`000?l0NB7o07TQ00?o07TQ00?o0000o`1f9ol000000_l000000ol0
P`ko0000ooooo`07ooooo`03o`000?oooooooooo00Gooooo000Cooooo`03o`000?oooooooooo00Wo
oooo0ol0000Uooooo`03o`000?l0Hd7o000000?o00000ol0JCX00ol0003o06`eo`1/=@03o`1/=@Co
00001?l0JSP00ol0003o06Tio`000002o`0000;o06Ll00?o0000o`1T?ol0I3l00_l0I3l2o`0000;o
06=000Co0000o`1OA?l0GdCo05m40_l000000ol0H4?o0000o`1KA`05o`1KA`;o00001_l0F4T00ol0
003o059=o`000005o`1GBP03o`000?l0DDgo055=00;o000000?o05M:o`000?l0DDd01Ol0DDd00ol0
003o04U<o`000004o`1DC003o`000?l0Cdko04m>00?o04m>0_l00005o`1EB`03o`000?l0DDgo055=
00?o055=00?o0000o`1;COl000000ol0FTP00ol0003o05M:o`1GBP04o`1GBP03o`000?l0E4co05A<
00;o05A<0_l00005o`1Q@P03o`000?l0GdCo05m400?o05m400?o0000o`1OA?l0Gd@00ol0Gd@00ol0
003o05i5o`1NA@04o`0000Go06hc00?o0000o`1^<ol0KS<00ol0KS<00ol0003o06hbo`1^<P03o`1^
<P03o`000?l0KS;o06hb00;o06hb0ol00003o`1m6P03o`000?l0OA[o000000Go07`L00?o0000o`1i
8Ol0NB400ol0NB42o`0000Go08<>00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`004oooool00ol0003oooooooooo`06ooooo`?o0000:Oooool01Ol0003o06=1o`1S@Ol0Hd7o0000
00Co06Tj00?o0000o`1/=Ol000000_l00002o`1Y>@03o`000?l0JSSo06Xh00?o06Xh0_l00006o`1W
?004o`000?l0I3oo0000o`0000Go06=000?o0000o`1OA?l000001?l0H4<01?l0003o05]7o`1KAol0
FdL2o`000003o`1NAOl0003o05Q900Go05Q90_l00006o`1GBP03o`000?l0DDgo000000Co05M:00?o
0000o`1ACOl0DDd00ol0DDd2o`0000Go05A<00Co0000o`1?C_l0Cdko04m>0_l000000ol0FTSo0000
o`1EB`04o`1EB`03o`000?l0DDgo055=00?o055=0_l00005o`1JB003o`000?l0Ed[o05M:00?o05M:
00?o0000o`1DC?l000000_l000000ol0Hd3o0000o`1Q@P04o`1Q@P03o`000?l0GdCo05m400?o05m4
00?o0000o`1OA?l0Gd@00_l0Gd@4o`0000?o06hb00?o0000o`1^<ol0KS<00ol0KS<00ol0003o06hc
o`1^<`03o`1^<`03o`000?l0KS;o06hb00?o06hb00?o0000o`1^<_l000000_l000000ol0OQSo0000
o`1m6P04o`1m6P;o00001Ol0O1`01?l0003o07TQo`1i8Ol0NB42o`000003o`271?l0003o08<>00Co
08<>00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`004oooool2o`0000Cooooo
0ol0000]ooooo`_o00001Ol0JCT00ol0003o06Xho`000002o`0000;o06Pj00?o0000o`1W??l0Ic`0
0ol0Ic`3o`0000Ko06=00_l00006o`1P@`03o`000?l0FdOo000000Co05i500Co0000o`1HBOl0F4Wo
05Q90_l000000ol0G4Ko0000o`1GBP05o`1GBP;o00001_l0EdX00ol0003o055=o`1AC@02o`000003
o`1JB?l0003o05A<00Co05A<00Co0000o`1?C_l0003o00001?l0FTP00ol0003o05E;o`1EB`03o`1E
B`03o`000?l0DDgo000000;o000000?o05e5o`000?l0FTP01?l0FTP00ol0003o05M:o`1GBP03o`1G
BP;o00001Ol0Hd000ol0003o0652o`1Q@P03o`1Q@P03o`000?l0GdCo05m400;o05m400?o0000o`1O
A?l000000_l000000ol0Kc;o0000o`1^<P05o`1^<P03o`000?l0KS?o06hc00?o06hc00?o0000o`1^
<ol0KS<00ol0KS<00ol0003o06hbo`1^<P04o`0000Go07hH00?o0000o`1m6_l0OAX00_l0OAX00ol0
003o07dJo`000005o`1l70?o00000ol0Q`@00ol0003o08<>o`233P04o`233P03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool001;ooooo00Co0000oooooooooooooooo0ol0000boooo
o`05o`000?l0HD?o0653o`1Q@ol000001?l0ISd01?l0003o06Tio`1Y>Ol0JCT4o`0000Go06Pj00?o
0000o`1W??l000000_l00003o`1V?@04o`000?l0Hd3o06=0o`1S@0;o000000?o06@oo`000?l0H4<0
1Ol0H4<2o`0000Ko05i500?o0000o`1HBOl000001?l0G4H01?l0003o05M:o`1GB_l0EdX2o`000003
o`1MA_l0003o05M:00Go05M:00?o0000o`1ACOl000001?l0FTP00ol0003o05A<o`1DC002o`1DC0;o
00001_l0FTP00ol0003o05E;o`1EB`02o`1EB`?o00001Ol0GDD00ol0003o05Y8o`1JB002o`1JB004
o`000?l0Ed[o05M:o`1GBP;o000000?o06Dno`000?l0Hd001?l0Hd000ol0003o0652o`1Q@P03o`1Q
@P03o`000?l0GdCo05m400;o05m40_l00005o`1_<P03o`000?l0KS;o06hb00?o06hb00?o0000o`1^
<ol0KS<00ol0KS<00ol0003o06hco`1^<`02o`1^<`Co00000ol0OQL00ol0003o07hHo`1n6003o`1n
6003o`000?l0OA[o07dJ00?o07dJ0_l00004o`1l70;o00001_l0Q`@00ol0003o08<>o`233P03o`23
3P03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool001;ooooo1?l0000fooooo`Go
00000_l0ISd5o`0000Co06Lk00?o0000o`1X>_l0J3X00_l0J3X3o`0000Ko06Hm00?o0000o`1S@?l0
00001?l0I3l01?l0003o0613o`1P@ol0H4<2o`000003o`1S@Ol0003o05i500Go05i50_l00006o`1L
AP03o`000?l0Ed[o000000Co05e600?o0000o`1GB_l0EdX00ol0EdX2o`0000Go05Y800?o0000o`1D
C?l0E4`00_l000000ol0GdCo0000o`1JB005o`1JB003o`000?l0ED_o05E;00;o000000?o0652o`00
0?l0GDD01Ol0GDD00ol0003o05Y8o`1JB003o`1JB0?o00000ol0ICh00ol0003o06=0o`1S@004o`1S
@003o`000?l0HD;o065200;o065200?o0000o`1OA?l000000_l000000ol0L33o0000o`1_<P04o`1_
<P03o`000?l0KS;o06hb00Co06hb00?o0000o`1^<ol0KS<00_l0KS<00ol0003o06hco`000002o`00
0003o`1n5ol0003o07hG00Go07hG00?o0000o`1n6?l0OQP00ol0OQP00ol0003o07dJo`1m6P03o`1m
6P03o`000?l0O1co000000;o000000?o0X/0o`000?l0Q`@01Ol0Q`@00ol0003o08<>o`233P03o`23
3P;o00001Oooool00ol0003oooooooooo`05ooooo`004_ooool2o`0003Wooooo00?o0000o`1OA?l0
Gd@00ol00004o`1U?P03o`000?l0Ic_o06Lk00?o06Lk00Co0000o`1X>_l0003o00000ol0Ic/00ol0
003o06Hmo`1V?@03o`1V?@;o00001_l0I3l00ol0003o0613o`000004o`1S@@04o`000?l0GTGo05i5
o`1NA@;o000000?o0691o`000?l0G4H01Ol0G4H2o`0000Ko05e600?o0000o`1GB_l0EdX00_l00000
0ol0GdCo0000o`1JB004o`1JB003o`000?l0E4co000000Co05m400?o0000o`1JB?l0FTP01?l0FTP2
o`0000Co065200?o0000o`1MAOl0GDD00ol0GDD00ol0003o05Y8o`1JB002o`1JB0;o00001_l0ICh0
0ol0003o06=0o`1S@003o`1S@003o`000?l0HD;o065200;o06520_l00005o`1`<003o`000?l0Kc;o
06lb00;o06lb00?o0000o`1^<_l0KS801?l0KS800ol0003o06hco`1^<`02o`1^<`;o00001Ol0OQL0
0ol0003o07hGo`1n5`03o`1n5`03o`000?l0OQSo07hH00?o07hH00?o0000o`1m6_l0OAX00ol0OAX2
o`0000Go0X/000?o0000o`271?l0Q`@00ol0Q`@01?l0003o08<>o`233_l0P`h2o`000003o`n@0?l0
003ooooo00Cooooo00?o0000ooooooooool01Oooool001Cooooo00?o0000ooooooooool0=oooool0
0ol0003o05m4o`1OA002o`1OA003o`000?l0ICko06Dn00;o06Dn00Co0000o`1W>ol0Ic_o06Lk0ol0
0006o`1W>`03o`000?l0ISgo000000;o00000_l0Ic`00ol0003o06@oo`1T?`03o`1T?`;o00001_l0
Hd400ol0003o05i5o`000004o`1R@@04o`000?l0G4Ko05a6o`1LAP;o000000?o0691o`000?l0GDH0
1Ol0GDH00ol0003o05M:o`000004o`1OA003o`000?l0FTSo05Y800;o05Y80_l00005o`1OA003o`00
0?l0FTSo05Y800?o05Y80_l00005o`1Q@P03o`000?l0GDGo05e500Co05e51?l000000ol0J3[o0000
o`1U?P05o`1U?P03o`000?l0Hd3o06=000?o06=000?o0000o`1Q@_l000000_l000000ol0LBko0000
o`1`<004o`1`<003o`000?l0Kc;o06lb00?o06lb00?o0000o`1^<_l0KS800ol0KS800ol0003o06hc
o`000002o`000003o`1o5_l0003o07hG00Co07hG00?o0000o`1n5ol0OQL01?l0OQL00ol0003o07hH
o`1n6002o`1n6003o`000?l0OA[o07dJ00?o000000?o28d0o`000?l2R`001?l2R`000ol0003o08L4
o`271004o`2710?o00001?l?T0000ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
000Eooooo`03o`000?oooooooooo03Oooooo3Ol00003o`1W?003o`000?l0Ic_o06Lk00?o06Lk0_l0
0006o`1W?003o`000?l0I3oo000000;o00000_l0IS`00ol0003o06=1o`1S@@03o`1S@@;o00001_l0
HT400ol0003o05a6o`000004o`1R@@03o`000?l0GDKo05e600?o05e60_l00005o`1OA003o`000?l0
FTSo05Y800;o000000?o06@oo`000?l0Gd@01Ol0Gd@00ol0003o05Y8o`1JB002o`000003o`1V?Ol0
003o065200Go065200?o0000o`1MAOl0GDD00_l0GDD2o`0000Go06Pj00?o0000o`1U?_l0ICh00ol0
ICh00ol0003o06=0o`1S@003o`1S@0;o00001Ol0LBh00ol0003o070`o`1`<003o`1`<003o`000?l0
Kc;o06lb00;o06lb00?o0000o`1^<_l0KS800ol0KS82o`0000Go07lF00?o0000o`1n5ol0OQL00_l0
OQL00ol0003o07hGo`1n5`04o`1n5`03o`000?l0OQSo07hH00;o07hH0ol00004o`R=00;o00001Ol2
R`000ol0003o08L4o`271002o`2710;o00001_l?T0000ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo000Fooooo`03o`000?oooooooooo03Sooooo00Go0000o`1OA?l0GdCo05m4o`00
0004o`1T?`03o`000?l0Icco06Ll00?o06Ll00?o0000o`1W>ol000000_l00002o`1X>P03o`000?l0
Icco06Ll00?o06Ll0_l00006o`1V?003o`000?l0Hd7o000000;o000000?o06Hlo`000?l0HT401Ol0
HT42o`0000Go069100Co0000o`1MA_l0GDKo05e60_l000000ol0ICko0000o`1OA004o`1OA003o`00
0?l0FTSo000000Co06@o00?o0000o`1OA?l0Gd@00ol0Gd@00ol0003o05Y8o`000004o`1V?@03o`00
0?l0HD;o065200?o065200?o0000o`1MAOl0GDD00_l000000ol0K3Ko0000o`1X>P04o`1X>P03o`00
0?l0ICko06Dn00Co06Dn00?o0000o`1S@?l000000_l000000ol0Lbco0000o`1a;P04o`1a;P03o`00
0?l0L33o070`00?o070`00?o0000o`1_<_l0Kc800_l0Kc800ol0003o06hbo`1^<P03o`000003o`1o
5Ol0003o07lF00Co07lF00?o0000o`1n5ol0OQL00ol0OQL00ol0003o07hGo`1n5`03o`1n5`03o`00
0?l0OQSo000000;o000000?o2hh0o`000?l8S@001Ol8S@02o`0000Co0X/000?o0000o`271?l0Q`@0
0_l000000olOUP3o0000o`n@0005o`n@0003o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool001Oooooo0_l0000iooooo`05o`000?l0GdCo05m4o`1OA?l000001?l0I3l01?l0003o06Ll
o`1W??l0Ic`3o`0000Ko06Pj00?o0000o`1W??l000000_l000000ol0JCWo0000o`1V?005o`1V?0;o
00001Ol0IS`01?l0003o0691o`1R@Ol0HT42o`000003o`1W>ol0003o069100Co069100Co0000o`1M
A_l0003o00001?l0ICh00ol0003o05m4o`1OA002o`1OA0;o00001Ol0I3l00ol0003o05m4o`1OA003
o`1OA0;o00001Ol0ISd00ol0003o0652o`1Q@P03o`1Q@P03o`000?l0GDGo000000Co06`f00?o0000
o`1X>_l0J3X00ol0J3X00ol0003o06Dno`1U?P02o`1U?P?o00001?l0Lb`00ol0003o074^o`1a;P04
o`1a;P03o`000?l0L33o070`00;o070`00Co0000o`1_<_l0Kc;o06lb1?l00004o`1o5@03o`000?l0
OaKo07lF00?o07lF00?o0000o`1n5ol0OQL00ol0OQL00ol0003o07hGo`1n5`03o`1n5`;o00001Ol;
SP000ol0003o28d0o`R=0003o`R=0003o`000?l2R`3o000000?o0X/000?o0000o`271?l000001?lO
UP000ol0003o3i00o`n@0004o`n@0003o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool001Wooooo00?o0000ooooooooool0=oooool<o`0000?o06Lk00?o0000o`1X>_l0J3X00ol0J3X2
o`0000Go06Ti00Co0000o`1V??l0ISco06Hl0_l000000ol0JSSo0000o`1V?005o`1V?003o`000?l0
HT7o000000Co06Lk00?o0000o`1R@Ol0HT400_l0HT42o`0000Ko06Dn00?o0000o`1OA?l0Gd@00_l0
00000ol0JCWo0000o`1T?`05o`1T?`03o`000?l0GdCo05m400;o000000?o06/go`000?l0ISd01Ol0
ISd00ol0003o0652o`1Q@P02o`1Q@P;o00001Ol0K3H00ol0003o06Pjo`1X>P03o`1X>P03o`000?l0
ICko000000;o000000?o07DXo`000?l0Lb`01Ol0Lb`00ol0003o074^o`1a;P03o`1a;P03o`000?l0
L33o070`00;o070`1?l00002o`205003o`000?l0OaGo07lE00Co07lE00?o0000o`1o5_l0OaH00ol0
OaH00ol0003o07hGo`1n5`02o`1n5`03o`000?l0OQOo07hG00?o000000?o3Xl0o`000?l;SP001?l;
SP000ol0003o28d0o`R=0003o`R=0003o`000?l2R`3o000000?o0X/00_l00005oanF0003o`000?l?
T03o3i0000?o3i000_l00004ooooo`03o`000?oooooooooo00Cooooo000Jooooo`03o`000?oooooo
oooo03Oooooo00Go0000o`1OA?l0GdCo05m4o`000004o`1U?P03o`000?l0Ic_o06Lk00?o06Lk00?o
0000o`1X>_l000000_l000000ol0JSSo0000o`1Y>@05o`1Y>@03o`000?l0ISco000000Co06Xh00?o
0000o`1V??l0IS`00ol0IS`2o`0000Go06Lk00?o0000o`1R@Ol000000_l000000ol0JSSo0000o`1U
?P05o`1U?P03o`000?l0GdCo000000Co06Ti00?o0000o`1T?ol0I3l00ol0I3l00ol0003o05m4o`00
0004o`1[=`03o`000?l0ISgo06Hm00?o06Hm00?o0000o`1Q@_l000000_l000000ol0Kc7o0000o`1/
=P05o`1/=P03o`000?l0J3[o06Pj00;o06Pj0_l00005o`1e:003o`000?l0Lbco07</00?o07</00?o
0000o`1a;_l0LBh00ol0LBh00ol0003o070`o`000002o`000003o`214_l0003o080D00Co080D00?o
0000o`1o5Ol0OaD00ol0OaD00ol0003o07lFo`1o5P03o`1o5P03o`000?l0OQOo07hG00;o07hG0ol0
0004o`j?0003o`000?l;SP3o2hh000?o2hh000?o0000o`R=0?l8S@001?l8S@000ol0003o0X/0o`00
0002o`000003ob^J0?l0003o7iH000Go7iH000Oo0000o`n@0?l?T03o3i00o`000?ldW@3o000000Co
oooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool0=oooool01Ol0003o05m4
o`1OA?l0GdCo000000Co06Dn00Co0000o`1W>ol0Ic_o06Lk0ol00005o`1Z>003o`000?l0JCWo06Ti
00?o06Ti0_l00006o`1Z>003o`000?l0ISco000000;o000000?o06`fo`000?l0Ic/01?l0Ic/2o`00
00Go06Xh00?o0000o`1U?_l0ICh00ol0ICh2o`0000Ko06Ti00?o0000o`1T?ol0I3l00_l0I3l2o`00
00Go06/g00?o0000o`1V?Ol0ISd00ol0ISd2o`0000Go06la00?o0000o`1/=_l0K3H00ol0K3H00ol0
003o06Pjo`1X>P02o`000003o`1h8ol0003o07DX00Co07DX00?o0000o`1c;?l0Lb`00ol0Lb`00ol0
003o074^o`1a;P03o`1a;P;o00001Ol0PA800ol0003o080Do`205002o`205003o`000?l0OaGo07lE
00?o07lE00?o0000o`1o5_l0OaH00ol0OaH00ol0003o07hGo`000002o`000003oa2@0?l0003o3Xl0
00Go3Xl000?o0000o`^>0?l;SP000ol;SP000ol0003o28d0o`R=0002o`R=00?o000000Go:iX0o`00
0?l[VP3o:iX0o`000006oanF0004o`000?l?T03o3i00o`0000?o=9d000Go0000oooooooooooooooo
o`000006ooooo`007?ooool2o`0003Sooooo3?l00003o`1Y>@03o`000?l0JSSo06Xh00?o06Xh00?o
0000o`1Y>Ol000000_l000000ol0K3Go0000o`1Z>005o`1Z>0;o00001Ol0K3H00ol0003o06Lko`1W
>`02o`000003o`1_<_l0003o06Xh00Go06Xh00?o0000o`1U?_l0ICh00_l000000ol0KS;o0000o`1Y
>@05o`1Y>@03o`000?l0I3oo000000;o000000?o06lao`000?l0JcL01Ol0JcL00ol0003o06Hmo`1V
?@02o`000003o`1c:ol0003o06la00Co06la00?o0000o`1/=_l0K3H00ol0K3H00ol0003o06Pjo`00
0004o`1h8`03o`000?l0MBSo07DX00?o07DX00?o0000o`1c;?l0Lb`00ol0Lb`00ol0003o074^o`00
0002o`000003o`223ol0003o084B00Co084B00?o0000o`205?l0P1@00ol0P1@00ol0003o07lEo`1o
5@03o`1o5@03o`000?l0OaKo07lF00Co00001Ol@T0000ol0003o3Xl0o`j?0003o`j?0003o`000?l;
SP3o2hh000?o2hh000?o0000o`R=0?l8S@000_l000001OldW@3o0000ob^J0?l[VP3o000000?o:iX0
00?o0000oanF0?lOUP000olOUP000ol0003o3i00o`000004ocBM0003o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool001kooooo00?o0000ooooooooool0=_ooool01?l0003o0653o`1Q
@ol00005o`1V?@03o`000?l0JCWo06Ti00?o06Ti00Co0000o`1Z>?l0JSSo06Xh0ol00005o`1/=@04
o`000?l0JSSo06Xho`1Z>0;o000000?o06lao`000?l0K3H01?l0K3H00ol0003o06Lko`000004o`1_
<P03o`000?l0JSSo06Xh00?o06Xh00?o0000o`1U?_l000001?l0KS800ol0003o06Tio`1Y>@03o`1Y
>@;o00001Ol0Kc400ol0003o06/go`1[=`03o`1[=`03o`000?l0ISgo000000Co07<[00?o0000o`1_
<Ol0Kc400ol0Kc400ol0003o06`fo`1/=P02o`1/=P;o00001Ol0N2<00ol0003o07DXo`1e:003o`1e
:003o`000?l0Lbco07</00;o07</0ol00004o`223`03o`000?l0PA;o084B00?o084B00?o0000o`20
5?l0P1@00ol0P1@00ol0003o07lEo`1o5@02o`1o5@Co00000olBT@000ol0003o4900oa2@0003oa2@
0003o`000?l>S`3o3Xl000?o3Xl000?o0000o`^>0?l;SP000ol;SP000ol0003o28d0o`000004ocBM
0004o`000?l[VP3o:iX0o`0000;o:iX000?o0000oanF0?lOUP000olOUP02o`0000Ko=9d000Go0000
ooooooooooooooooo`000005ooooo`007oooool00ol0003oooooooooo`0fooooo`04o`000?l0HD?o
0653o`0000Go06Hm00Co0000o`1Y>Ol0JCWo06Ti1Ol00003o`1]=003o`000?l0K3Go06`e00?o06`e
00?o0000o`1Z>?l000001?l0Kc400ol0003o06`fo`1/=P02o`1/=P;o00001_l0Kc800ol0003o06Xh
o`1Z>002o`1Z>0;o00001_l0KS800ol0003o06Tio`1Y>@02o`000003o`1d:Ol0003o06la00Co06la
00?o0000o`1[=ol0JcL00ol0JcL2o`0000Go07<[00?o0000o`1_<Ol0Kc400ol0Kc400ol0003o06`f
o`000002o`000003o`1k7Ol0003o07PS00Co07PS00?o0000o`1e:?l0MBP00ol0MBP00ol0003o07</
o`000002o`000003o`242ol0003o088?00Go088?00?o0000o`214_l0PA800ol0PA800ol0003o080D
o`205002o`205003o`000?l0OaGo000000;o000000?o4i40o`000?lBT@001?lBT@000ol0003o4900
oa2@0004oa2@0003o`000?l>S`3o3Xl000;o3Xl000?o0000o`^>0?l;SP000ol;SP02o`0000Go=9d0
00Oo0000ob^J0?l[VP3o:iX0o`000?l[VP3o000000?o7iH00_l000000om:Y03o0000ocBM0005ocBM
0005o`000?ooooooooooooooool000001Oooool0023ooooo00?o0000ooooooooool0=_ooool4o`00
00?o06Hm1Ol00002o`1/=@03o`000?l0KCCo06dd00Co06dd00Co0000o`1/=Ol0K3Go06`e0ol00006
o`1_<@06o`000?l0K3Ko06`fo`000?l0LRco00001_l0Kc800ol0003o06Xho`000002o`000003o`1c
;?l0003o06hb00Go06hb00?o0000o`1Y>Ol000001?l0M2T00ol0003o06lao`1_<@03o`1_<@03o`00
0?l0JcOo06/g00;o000000?o07PSo`000?l0Lb/01Ol0Lb/00ol0003o06lao`1_<@02o`1_<@;o0000
1Ol0Nad00ol0003o07PSo`1h8`03o`1h8`03o`000?l0MBSo07DX00;o07DX0_l00005o`242`03o`00
0?l0PPoo088?00?o088?00?o0000o`214_l0PA800ol0PA800ol0003o080Do`205002o`2050;o0000
1OlCT@000ol0003o4Y40oa:A0003oa:A0003o`000?l@T03o490000?o490000?o0000o`j?0?l>S`00
0ol>S`000ol0003o2hh0o`000002o`000003oc^O0?l0003o=9d000Co=9d000?o0000ob^J0?l[VP00
0_l[VP000ol0003o:iX0o`000002o`0000CoBZ@000?o0000ocBM0?ldW@000oldW@001Ol0003ooooo
oooooooooooo000000Gooooo000Qooooo`;o0000=_ooool00ol0003o06=1o`1S@@04o`0000;o06Tj
00?o0000o`1/=Ol0K3D00ol0K3D00ol0003o06ddo`1]=003o`1]=0Co00000_l0LBh00ol0003o06la
o`1_<@04o`1_<@03o`000?l0K3Ko000000?o078/00?o0000o`1_<_l0Kc800ol0Kc82o`0000Go07</
00?o0000o`1^<_l0KS800ol0KS82o`0000Go07@Y00?o0000o`1_<Ol0Kc400ol0Kc400ol0003o06/g
o`000004o`1h8`03o`000?l0Lb_o07<[00?o07<[00?o0000o`1_<Ol0Kc400_l000000ol0OaKo0000
o`1k7@04o`1k7@03o`000?l0N2?o07PS00?o07PS00?o0000o`1e:?l0MBP00_l000000ol0QPKo0000
o`242`04o`242`03o`000?l0PPoo088?00?o088?00?o0000o`214_l0PA800ol0PA800ol0003o080D
o`000002o`000003oaJB0?l0003o4i4000Co4i4000?o0000oa:A0?lBT@000olBT@000ol0003o4900
oa2@0003oa2@0004o`000?l>S`3o3Xl0o`j?00Co00001?lkW`000ol0003o=9d0ocBM0004ocBM0004
o`000?l[VP3o:iX0ob^J00?o00001_m:Y0000ol0003o=9d0ocBM0003ocBM00;o00000_ooool00ol0
003oooooooooo`03ooooo`008oooool00ol0003oooooooooo`0dooooo`05o`000?l0Hd7o06=1o`1S
@Ol000001?l0JCX00ol0003o06`eo`1/=@03o`1/=@03o`000?l0KCCo000000;o000000?o074^o`00
0?l0LBh01?l0LBh00ol0003o06lao`1_<@03o`1_<@;o00001Ol0LR`00ol0003o06lbo`1_<P02o`00
0003o`1g9Ol0003o07</00Go07</00?o0000o`1^<_l0KS800_l000000ol0NB7o0000o`1d:@05o`1d
:@03o`000?l0Kc7o06la00;o06la0_l00005o`1h8`03o`000?l0Lb_o07<[00?o07<[00?o0000o`1_
<Ol000001?l0OaH00ol0003o07/Mo`1k7@03o`1k7@03o`000?l0N2?o07PS00;o07PS00?o0000o`1e
:?l000001?l0QPH00ol0003o08@;o`242`02o`242`03o`000?l0PPoo088?00?o088?00?o0000o`21
4_l0PA800ol0PA82o`0000Go5Y8000?o0000oa>A0?lCT@000_lCT@000ol0003o4Y40oa:A0003oa:A
0003o`000?l@T03o490000?o49001?l00002od2Q0003o`000?lkW`3o>il000Co>il000?o0000ocBM
0?ldW@000oldW@000ol0003o:iX0ob^J0004o`0000OoBZ@000?o0000ocBM0?ldW@000_l000001OmL
Z@3o0000oooooooooooo000000Gooooo000Tooooo`03o`000?oooooooooo03Cooooo00Go0000o`1S
@Ol0Hd7o06=1o`000004o`1Y>P04o`000?l0K3Go06`eo`1/=@?o00001Ol0LBh00ol0003o074^o`1a
;P03o`1a;P03o`000?l0Kc7o000000;o000000?o07DWo`000?l0LR`01?l0LR`00ol0003o06lbo`00
0004o`1g9@03o`000?l0Lbco07</00?o07</00?o0000o`1^<_l000001?l0NB400ol0003o07@Yo`1d
:@03o`1d:@03o`000?l0Kc7o000000;o000000?o07`Ko`000?l0N2<01Ol0N2<00ol0003o07<[o`1c
:`02o`1c:`;o00001Ol0OaH00ol0003o07/Mo`1k7@03o`1k7@03o`000?l0N2?o07PS00;o07PS0_l0
0005o`261P03o`000?l0Q0_o08@;00?o08@;00?o0000o`223ol0PPl00ol0PPl00ol0003o084Bo`00
0002o`000003oaVC0?l0003o5Y8000Co5Y8000?o0000oa>A0?lCT@000olCT@000ol0003o4Y40oa:A
0003oa:A0003o`000?l@T03o000000;o000000?oA:80o`000?m0X@001?m0X@000ol0003o>il0oc^O
0003oc^O0003o`000?ldW@3o=9d000?o=9d000?o0000ob^J0?l000000omLZ@02o`0000KoBZ@000?o
0000ocBM0?l000001?mLZ@001?l0003oooooooooool00004ooooo`009Oooool00ol0003ooooooooo
o`0dooooo`co00000_l0L3000ol0003o074^o`1a;P04o`1a;P03o`000?l0LBko074^00;o074^0_l0
0005o`1e9`03o`000?l0LRco078/00;o078/0_l00005o`1g9@03o`000?l0Lbco07</00?o07</0_l0
0005o`1i8@03o`000?l0M2Wo07@Y00?o07@Y0_l00005o`1l6`03o`000?l0N2?o07PS00?o07PS00?o
0000o`1c:ol000000_l000000ol0P`oo0000o`1o5P05o`1o5P03o`000?l0Nago07/M00;o07/M00?o
0000o`1h8ol000000_l000000ol0R@3o0000o`261P04o`261P03o`000?l0Q0_o08@;00?o08@;00?o
0000o`223ol0PPl00_l0PPl3o`0000Co6I<000?o0000oaJB0?lFTP000olFTP000ol0003o4i40oa>A
0003oa>A0003o`000?lBT@3o4Y4000;o4Y400ol00005odBR0003o`000?m0X@3o@:4000;o@:4000?o
0000oc^O0?lkW`000olkW`000ol0003o=9d0ocBM0003ocBM00;o00001OmLZ@000ol0003oBZ@0odZT
0004odZT00;o00001OmLZ@001?l0003oooooooooool00004ooooo`009_ooool2o`0003Gooooo00Co
0000o`1V?Ol0ISgo00001?l0K3D00ol0003o070`o`1`<003o`1`<003o`000?l0LBko074^00?o074^
00?o0000o`1a;_l000000_l000000ol0MbGo0000o`1e9`04o`1e9`03o`000?l0LRco000000;o0000
00?o07XNo`000?l0MbD01Ol0MbD00ol0003o07</o`1c;002o`000003o`1m6Ol0003o07TQ00Go07TQ
00?o0000o`1d:Ol0M2T00_l000000ol0PA;o0000o`1l6`04o`1l6`03o`000?l0N2?o07PS00?o07PS
0_l00004o`233`03o`000?l0OaKo07lF00Co07lF00?o0000o`1k7Ol0Nad00_l0Nad2o`0000Go08T0
00?o0000o`261_l0QPH00ol0QPH00ol0003o08@;o`242`02o`242`03o`000?l0PPoo000000;o0000
00?o7ID0o`000?lIT`001OlIT`000ol0003o5Y80oaJB0003oaJB0003o`000?lCT@3o4i4000;o4i40
00?o0000oa:A0?l000000_l000000om8X`3o0000odBR0005odBR0003o`000?m0X@3o@:4000?o@:40
00?o0000oc^O0?lkW`000olkW`000ol0003o=9d0o`000002o`000003of^^0?l0003oG:T000CoG:T0
0_l00004odZT0003o`000?mk/P3o000000GoG:T000Co0000oooooooooooo00001?ooool002Sooooo
00?o0000ooooooooool0<oooool01?l0003o06Hmo`1V?Ol00004o`1/=@03o`000?l0L33o070`00?o
070`00Co0000o`1a;_l0LBko074^0ol00005o`1g9@03o`000?l0MBOo07DW00;o07DW0_l00005o`1j
7P03o`000?l0MbGo07LU00?o07LU00?o0000o`1c;?l000001?l0OAT00ol0003o07TQo`1i8@03o`1i
8@03o`000?l0M2Wo000000Co084B00?o0000o`1l6ol0O1/00ol0O1/00ol0003o07PSo`1h8`02o`00
0003o`271_l0003o08<?00Co08<?00?o0000o`1o5_l0OaH00ol0OaH00ol0003o07/Mo`000002o`00
0003o`J<0?l0003o08T000Co08T000?o0000o`261_l0QPH00ol0QPH00ol0003o08@;o`242`02o`24
2`;o00001OlMU@000ol0003o6I<0oaVC0003oaVC0003o`000?lFTP3o5Y8000?o5Y8000?o0000oa>A
0?lCT@000_lCT@02o`0000GoB:<000?o0000odBR0?m4XP000om4XP000ol0003o@:40od2Q0003od2Q
0003o`000?lkW`3o>il000;o>il00ol00005of^^0003o`000?mLZ@3oG:T000?oG:T000?o0000odZT
0?m:Y0000_l00002og^b0003o`000?mLZ@3oG:T000CoG:T000?o0000ooooool000001?ooool002Wo
oooo00?o0000ooooooooool0<oooool4o`0000Co06`e00Co0000o`1`<?l0L33o070`1Ol00002o`1g
9@03o`000?l0MbGo07LU00?o07LU00?o0000o`1e9ol000000_l000000ol0OA[o0000o`1j7P05o`1j
7P03o`000?l0MbGo07LU00;o07LU0_l00005o`1m6@03o`000?l0NB7o07TQ00?o07TQ0_l00005o`21
4P03o`000?l0O1_o07`K00?o07`K00?o0000o`1h8ol000000ol0Q`H00ol0003o08<?o`233`03o`23
3`03o`000?l0OaKo07lF00?o07lF0_l00004o`J<0003o`000?l0R@3o08T000Co08T000?o0000o`26
1_l0QPH00_l0QPH00ol0003o08@;o`000002o`000003ob:G0?l0003o7ID000Co7ID000?o0000oaVC
0?lIT`000olIT`000ol0003o5Y80oaJB0003oaJB0003o`000?lCT@3o000000;o000000?oBjD0o`00
0?m8X`001?m8X`000ol0003oA:80odBR0004odBR0003o`000?m0X@3o@:4000;o@:4000?o0000oc^O
0?l000000_l000000omf/@3o0000of^^0005of^^0003o`000?mLZ@3oG:T000?oG:T00ol00005og^b
0003o`000?mLZ@3oG:T000;oG:T00_l000000ooooooo0000ooooo`03ooooo`00:_ooool00ol0003o
ooooooooo`0booooo`03o`000?l0JCWo06Ti00Wo00000_l0MBP00ol0003o07LUo`1g9@03o`1g9@03
o`000?l0MbGo07LU00;o07LU0_l00005o`1m6P03o`000?l0NQko07XN00?o07XN00?o0000o`1g9Ol0
00000_l000000ol0PA;o0000o`1m6@05o`1m6@03o`000?l0NB7o07TQ00;o000000?o08D9o`000?l0
PA801Ol0PA800ol0003o07`Ko`1l6`02o`1l6`;o00001Ol0Q`H00ol0003o08<?o`233`02o`233`04
o`000?l0OaKo07lFo`1o5P;o000000?o3Xl0o`000?l6S0001?l6S0000ol0003o08T0o`290003o`29
0003o`000?l0QPKo08H600;o08H60_l00005ob:G0003o`000?lMU@3o7ID000;o7ID000?o0000oaVC
0?lIT`000olIT`000ol0003o5Y80oaJB0003oaJB00;o00001Om;Y@000ol0003oB:<0odRS0002odRS
0003o`000?m4XP3oA:8000CoA:8000?o0000od2Q0?m0X@000_m0X@02o`0000GoM[4000?o0000of^^
0?m[[P001?m[[P000ol0003oG:T0oebY0002oebY00;o00001_mk/P001Ol0003oG:T0oebY0?mLZ@3o
000000;oQkD00_l00004ooooo`00:oooool2o`0003?ooooo00Co0000o`1Y>Ol0JCWo00001?l0L2l0
0ol0003o07DXo`1e:003o`1e:003o`000?l0MbGo07LU00?o07LU00Ko0000o`1g9Ol0003o0000o`1n
6?l00006o`1m6P03o`000?l0NQko07XN00;o07XN0_l00005o`214P03o`000?l0OAWo07dI00?o07dI
00?o0000o`1i8Ol000001?l0Q@T00ol0003o084Bo`214P03o`214P03o`000?l0O1_o07`K00;o0000
00?o0h/0o`000?l0Q`H01?l0Q`H00ol0003o08<?o`233`03o`233`?o00000ol>S`000ol0003o1X`0
o`J<0003o`J<0003o`000?l0R@3o08T000?o08T000?o0000o`261_l000000_l000000olXV@3o0000
ob:G0004ob:G0003o`000?lMU@3o7ID000?o7ID000?o0000oaVC0?lIT`000olIT`000ol0003o5Y80
o`000002o`000003odnV0?l0003oBjD000CoBjD000?o0000odRS0?m8X`000om8X`000ol0003oA:80
odBR0003odBR0003o`000?m0X@3o000000;o000000?oOk<0o`000?mf/@001?mf/@000ol0003oJjh0
of^^0004of^^0003o`000?mLZ@3oG:T000;o000000?oUKT0o`000?l000001Omk/P001?l0003oG:T0
oebY0?l00003ohNe00;o00001?ooool002gooooo00?o0000ooooooooool0<Oooool01?l0003o06Ti
o`1Y>Ol00004o`1`;`03o`000?l0MBSo07DX00?o07DX00Co0000o`1g9Ol0MbGo07LU0ol00004o`1n
6003o`000?l0OA[o07dJ00?o07dJ00?o0000o`1j7_l000000_l000000ol0Q0co0000o`214P05o`21
4P03o`000?l0OAWo07dI00;o07dI0_l00005o`252@03o`000?l0PA;o084B00?o084B00?o0000o`1l
6ol000000ol3R`000ol0003o08L6o`271P03o`271P03o`000?l0P`oo08<?00;o08<?0_l00006o`j?
0003o`000?l6S03o1X`000;o1X`000?o0000o`290?l0R@000ol0R@02o`0000Co:9T000?o0000ob:G
0?lRU`000olRU`000ol0003o7ID0oafE0003oafE0003o`000?lIT`3o6I<000;o6I<00ol00004odnV
0003o`000?m;Y@3oBjD000?oBjD000?o0000odRS0?m8X`000om8X`000ol0003oA:80odBR0003odBR
00;o00001Omo/`000ol0003oM[40ogJa0002ogJa0003o`000?m[[P3oJjh000CoJjh000?o0000oebY
0?l000001?nE^@02o`0000GoNk800_l00005ohNe00;o00000oooool002kooooo00?o0000oooooooo
ool0<Oooool4o`0000Co070_00Co0000o`1e:?l0MBSo07DX1Ol00002o`1m6@03o`000?l0OQSo07hH
00?o07hH00?o0000o`1m6_l0OAX00_l0OAX2o`0000Go08@<00?o0000o`214_l0PA800ol0PA800ol0
003o07dIo`000002o`000003o`290Ol0003o08D900Go08D900?o0000o`214_l0PA800_l0PA82o`00
00Go0h/000?o0000o`271_l0Q`H00ol0Q`H4o`000003oaNC0?l0003o3Xl000Go3Xl000?o0000o`J<
0?l6S0000ol6S0000ol0003o08T0o`000002o`000003obnK0?l0003o:9T000Co:9T000?o0000ob:G
0?lRU`000olRU`000ol0003o7ID0oafE0002oafE0003o`000?lIT`3o000000;o000000?oDjL0o`00
0?m?YP001Om?YP000ol0003oBjD0od^U0003od^U0003o`000?m8X`3oB:<000;oB:<000?o0000odBR
0?m4XP000ol000000on6]@3o0000ognc0004ognc0003o`000?mf/@3oM[4000?oM[4000?o0000of^^
0?m[[P000om[[P02o`0000GoUKT000?o0000og^b0?l000000omk/P02o`0000KoQkD00_l00003oooo
o`00;oooool00ol0003oooooooooo`0`ooooo`03o`000?l0KS?o06hc00Wo00000_l0Nah00ol0003o
07dIo`1m6@03o`1m6@03o`000?l0OQSo07hH00;o07hH00?o0000o`1m6_l000000_l000000ol0Q@So
0000o`243005o`243003o`000?l0PA;o084B00;o084B0_l00005o`290@03o`000?l0Q@Wo08D900?o
08D900?o0000o`214_l000000_l000000ol<S`3o0000o`>;0004o`>;0003o`000?l0Q`Ko08L600;o
08L60_l00005oaNC0003o`000?l>S`3o3Xl000?o3Xl000?o0000o`J<0?l6S0000_l6S003o`0000Co
;i/000?o0000obRI0?lXV@000olXV@000ol0003o8YL0ob:G0003ob:G0003o`000?lMU@3o7ID000;o
7ID00_l00005oe>W0003o`000?m?YP3oCjH000?oCjH000?o0000od^U0?m;Y@000om;Y@000ol0003o
B:<0odRS0002odRS00?o00001?n6]@000ol0003oOk<0ognc0003ognc0003o`000?mf/@3oM[4000?o
M[4000Co0000of^^0?m[[P3oJjh00_l000000onZ_P3o0000oiFi0005oiFi00;o00000_mk/P000ol0
003o/<00o`000007ohNe0003o`000?oooooooooo007ooooo000`ooooo`03o`000?oooooooooo033o
oooo00Co0000o`1^<ol0KS?o00001?l0MRL00ol0003o07/No`1k7P03o`1k7P03o`000?l0OAWo07dI
00;o07dI00?o0000o`1n6?l0OQP00_l0OQP2o`0000Go08D800?o0000o`243?l0Q0`00ol0Q0`00ol0
003o084Bo`000002o`000003o`F<0?l0003o08T100Co08T100?o0000o`252Ol0Q@T00ol0Q@T2o`00
00Go38l000?o0000o`>;0?l3R`000_l3R`000ol0003o08L6o`271P02o`000003ob6G0?l0003o5i<0
00Co5i<000?o0000o`j?0?l>S`001?l>S`04o`000003ocRN0?l0003o;i/000Go;i/000?o0000obRI
0?lXV@000_lXV@000ol0003o8YL0ob:G0003ob:G0003o`000?lMU@3o000000;o000000?oFJP0o`00
0?mCY`001?mCY`000ol0003oCjH0odnV0003odnV0003o`000?m;Y@3oBjD000?oBjD000?o0000odRS
0?l000000_l000000on<]`3o0000ohJe0005ohJe0003o`000?mo/`3oOk<000?oOk<000?o0000ogJa
0?mf/@000_mf/@001?l0003oJjh0o`000?l00003ojZn0003o`000?nE^@3oUKT000CoUKT000Co0000
og^b0?l0003o00000on``0000ol0003oQkD0ohNe0003ohNe00;o00000oooool0037ooooo0_l0000a
ooooo`04o`000?l0KS?o06hco`0000Co07HW00?o0000o`1k7_l0Nah00ol0Nah01_l0003o07dIo`1m
6Ol0OAWo0000o`1n60?o000000?o08H7o`000?l0Q@P01Ol0Q@P00ol0003o08@<o`243002o`2430;o
00001Ol5S0000ol0003o08T1o`290@03o`290@03o`000?l0Q@Wo08D900;o000000?o5Y80o`000?l<
S`001?l<S`000ol0003o0h/0o`>;0003o`>;00;o00001?lQU`000ol0003o5i<0oaNC0003oaNC0003
o`000?l>S`3o3Xl000;o3Xl00_l00005ocRN0003o`000?l_V`3o;i/000?o;i/000?o0000obRI0?lX
V@000_lXV@000ol0003o8YL0ob:G0003ob:G00;o00001OmIZ0000ol0003oDjL0oe>W0002oe>W0003
o`000?m?YP3oCjH000?oCjH000?o0000od^U0?m;Y@000om;Y@02o`0000GoS;L000?o0000ohJe0?n6
]@000on6]@000ol0003oOk<0ognc0003ognc0003o`000?mf/@3oM[4000;oM[400_l00006ojZn0003
o`000?nE^@3oUKT000?oUKT000Co0000og^b0?l0003o00000on``0000ol0003oQkD0ohNe0002ohNe
0003o`000?oooooo000000?ooooo000cooooo`03o`000?oooooooooo02oooooo1?l00004o`1f9`03
o`000?l0Nako07/N00;o07/N00?o0000o`1m6Ol0OAT00ol00005o`261`03o`000?l0Q@So08D800?o
08D800?o0000o`243?l000000_l000000ol;SP3o0000o`F<0004o`F<0003o`000?l0R@7o08T100?o
08T100?o0000o`252Ol000001?lFTP000ol0003o38l0o`b?0002o`b?0003o`000?l3R`3o0h/000;o
0h/00_l00005ob6G0003o`000?lGT`3o5i<000?o5i<000?o0000o`j?0?l>S`000_l000000om1X@3o
0000ocRN0004ocRN0003o`000?l_V`3o;i/000?o;i/000?o0000obRI0?lXV@000olXV@000ol0003o
8YL0o`000002o`000003oenZ0?l0003oFJP000CoFJP000?o0000oe>W0?mCY`000omCY`000ol0003o
CjH0odnV0003odnV0003o`000?m;Y@3o000000;o000000?oT[P0o`000?n<]`001?n<]`000ol0003o
Q[D0ohJe0003ohJe0003o`000?mo/`3oOk<000?oOk<000?o0000ogJa0?l000000_l000000onl`P3o
0000ojZn0005ojZn0003o`000?nE^@3oUKT000?oUKT00_l00002ok300005o`000?n``03o/<00ok30
0?l000000_n7]@001?l0003oooooooooool00003ooooo`00=?ooool00ol0003oooooooooo`0_oooo
o`03o`000?l0LRco000000co00000_l0Q@X00ol0003o08H7o`261`04o`261`03o`000?l0Q@So08D8
00;o08D80_l00005o`^>0003o`000?l5S03o1H`000?o1H`000?o0000o`290Ol0R@400_l0R@42o`00
00Go5Y8000?o0000o`b?0?l<S`000ol<S`04o`000003ob^J0?l0003o8IL000Go8IL000?o0000oaNC
0?lGT`000_lGT`000ol0003o3Xl0o`000004od6Q0003o`000?lhWP3o>9h000;o>9h000?o0000obnK
0?l_V`000ol_V`000ol0003o:9T0obRI0002obRI00?o00001?mOZP000ol0003oFJP0oeVX0003oeVX
0003o`000?mCY`3oDjL000?oDjL000?o0000odnV0?m?YP000_m?YP03o`0000CoT[P000?o0000ohbg
0?n<]`000on<]`000ol0003oQ[D0ohJe0003ohJe0003o`000?mo/`3oOk<000?oOk<00_l00005okc2
0003o`000?nZ_P3oZ[h000?oZ[h000Co0000oiFi0?nE^@3oUKT00_l000001Oo8_03o0000ok300?n`
`03o000000?o/<0000?o0000ohNe0?l000000oooool00ol0003oooooooooo`01ooooo`00=Oooool0
0ol0003oooooooooo`0_ooooo`03o`000?l0LRco000000Co07/M00?o0000o`214Ol0PA400_l0PA40
0ol0003o08D:o`252P02o`252P03o`000?l0QPOo08H700?o08H700?o0000o`252?l000000_l00000
0ol>S`3o0000o`^>0004o`^>0003o`000?l5S03o1H`000?o1H`000?o0000o`290Ol000000_l00000
0olNUP3o0000oaJB0004oaJB0003o`000?l<S`3o38l000;o38l00_l00005ob^J0003o`000?lQU`3o
8IL000?o8IL000?o0000oaNC0?lGT`000_lGT`02o`0000Go@J4000?o0000ocRN0?lhWP000olhWP00
0ol0003o;i/0obnK0003obnK00Co000000?oIZ`0o`000?mOZP001OmOZP000ol0003oFJP0oeVX0003
oeVX0003o`000?mCY`3oDjL000;oDjL000?o0000odnV0?l000000_l000000onH^P3o0000oi:h0005
oi:h0003o`000?n<]`3oS;L000?oS;L000?o0000ohJe0?n6]@000on6]@000ol0003oOk<0o`000002
o`000003olK20?l0003o_<8000Co_<8000?o0000ojZn0?nZ_P001?nZ_P03o`0000Cob;`000Co0000
ok300?n``03o00000_n``002o`0000Gooooo0Ol00001ooooo`7ooooo000fooooo`;o0000<?ooool3
o`0000Co07/M00?o0000o`214Ol0PA400_l0PA400ol0003o08D:o`252P02o`252P04o`000?l0QPOo
08H7o`261`?o00001Ol>S`000ol0003o2hh0o`^>0003o`^>0003o`000?l5S03o1H`000;o1H`00_l0
0005oajF0003o`000?lFTP3o5Y8000?o5Y801?l000000olfW@3o0000ob^J0004ob^J0003o`000?lQ
U`3o8IL000?o8IL000?o0000oaNC0?l000000_l000000om;Y03o0000od6Q0004od6Q0003o`000?lh
WP3o>9h000?o>9h000?o0000obnK0?l_V`000_l_V`02o`0000GoIZ`000?o0000oenZ0?mOZP000omO
ZP000ol0003oFJP0oeVX0003oeVX0003o`000?mCY`3oDjL000;oDjL00_l00005oiRj0003o`000?nB
^03oT[P000?oT[P000?o0000ohbg0?n<]`000on<]`000ol0003oQ[D0ohJe0002ohJe00?o00001?o6
`P000ol0003o_<80okc20004okc20003o`000?nZ_P3oZ[h000;oZ[h00_l00006olRl0004o`000?n`
`03o/<00ok3000;o00001oooool1o`00007ooooo0Oooool003Sooooo00?o0000ooooooooool0;Ooo
ool01?l0003o07PSo`000?l00004o`1k7@03o`000?l0PA7o084A00;o084A00?o0000o`252_l0Q@X0
1Ol00002o`f?0003o`000?l>S`3o3Xl000?o3Xl000?o0000o`^>0?l;SP000ol;SP000ol0003o1H`0
o`000002o`000003obFH0?l0003o7YH000Co7YH000?o0000oaJB0?lFTP000_lFTP02o`0000Go=Yd0
00?o0000ob^J0?l[VP000ol[VP000ol0003o8IL0ob6G0002ob6G00;o00001Om;Y0000ol0003o@J40
od6Q0003od6Q0003o`000?lhWP3o>9h000;o>9h000?o0000obnK0?l000000_l000000om^[`3o0000
ofJ/0004ofJ/0003o`000?mOZP3oGjX000?oGjX000?o0000oeVX0?mIZ0000omIZ0000ol0003oDjL0
o`000002o`000003oijk0?l0003oV;X000CoV;X000?o0000oi:h0?nB^0000onB^0000ol0003oS;L0
ohbg0003ohbg0003o`000?n6]@3o000000;o000000?ob;/0o`000?o6`P001Oo6`P000ol0003o_<80
okc20003okc20003o`000?nZ_P3oZ[h000;o000000?ocZ`0o`000?o8_0001Oo8_0000ol0003o/<00
ok300002o`0000Sooooo0Ol00001ooooo`7ooooo000iooooo`03o`000?oooooooooo02gooooo00?o
0000o`1h8ol0N2<03?l00002o`N=0003o`000?l=S`3o3Hl000?o3Hl000?o0000o`j?0?l>S`000ol>
S`000ol0003o2hh0o`^>0002o`^>00;o00001OlUV0000ol0003o7YH0oajF0002oajF0003o`000?lF
TP3o5Y8000;o000000?o?j40o`000?lfW@001?lfW@000ol0003o:iX0ob^J0003ob^J0003o`000?lQ
U`3o8IL000;o000000?oEJL0o`000?m;Y0001?m;Y0000ol0003o@J40od6Q0003od6Q0003o`000?lh
WP3o>9h000;o>9h00_l00005ofj_0003o`000?mV[03oIZ`000;oIZ`000?o0000oenZ0?mOZP000omO
ZP000ol0003oFJP0oeVX0003oeVX00;o00001OnN^`000ol0003oV;X0oiRj0002oiRj0003o`000?nB
^03oT[P000?oT[P000?o0000ohbg0?n<]`000on<]`02o`0000Gob;/000?o0000olK20?o6`P000oo6
`P000ol0003o_<80okc20003okc20003o`000?nZ_P3o000000CocZ`000?o0000olRl0?o8_0001?o8
_002o`0000;ooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool003[ooooo00?o0000
ooooooooool0;Oooool00ol0003o07PSo`000004o`224@03o`000?l0R0;o08P200;o08P200?o0000
o`N=0?l7S@000_l7S@000ol0003o3Hl0o`f?0003o`f?0003o`000?l>S`3o3Xl000;o3Xl000?o0000
o`^>0?l000000_l000000olYV@3o0000obFH0004obFH0003o`000?lNUP3o7YH000?o7YH00_l00004
ocnQ0003o`000?lfW@3o=Yd000?o=Yd000?o0000ob^J0?l[VP000_l[VP000ol0003o8IL0o`000004
oeFW0003o`000?m;Y03oBj@000?oBj@000?o0000od6Q0?m1X@000_m1X@000ol0003o>9h0o`000002
o`000003ogNa0?l0003oKZl000CoKZl000?o0000ofJ/0?mV[0000omV[0000ol0003oGjX0oenZ0003
oenZ0003o`000?mIZ03o000000;o000000?oY;d0o`000?nN^`001?nN^`000ol0003oV;X0oiRj0003
oiRj0003o`000?nB^03oT[P000?oT[P000?o0000ohbg0?l000000_l000000oo:]P3o0000olRk0004
olRk0003o`000?o6`P3oa/8000?oa/8000?o0000okc20?nl`P000onl`P02o`0000GocZ`000?o0000
olRl0?o8_0000oo8_002o`0000Cooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool0
03_ooooo0_l0000^ooooo`?o00001?l0PQ400ol0003o08P2o`280P02o`280P03o`000?l7S@3o1hd0
00;o1hd000?o0000o`f?0?l=S`000_l=S`001?l0003o3Xl0o`j?0?l>S`03o`0000Go:IT000?o0000
obFH0?lUV0000_lUV0000ol0003o7YH0oajF0002oajF00;o00001OloX@000ol0003o=Yd0ocJM0003
ocJM0003o`000?l[VP3o:iX000;o:iX00_l00005oeFW0003o`000?m;Y03oBj@000?oBj@000?o0000
od6Q0?m1X@000_m1X@02o`0000GoMk4000?o0000ofj_0?m^[`000_m^[`000ol0003oIZ`0ofJ/0003
ofJ/0003o`000?mOZP3oGjX000;oGjX00ol00004ojBm0003o`000?nN^`3oW[/000?oW[/000?o0000
oiRj0?nH^P000onH^P000ol0003oT[P0oi:h0002oi:h00?o00001Oo:]P000ol0003ob;/0olRk0002
olRk0003o`000?o6`P3oa/8000?oa/8000Co0000okc20?nl`P3o_<800_l000000ooDW@3o0000olj/
0005olj/0005o`000?o8_03ob;`0olRl0?l000001oooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool1ooooo`00?Oooool00ol0003oooooooooo`0[ooooo`04o`000?l0OA[o0000o`0000Co088A
00Go0000o`280_l0R0;o08P2o`000004o`N=0004o`000?l=S`3o3Hl0o`f?00Go00000_lZVP000ol0
003o:IT0obVI0003obVI0003o`000?lUV03o9IP000?o9IP01?l000000om7X`3o0000ocnQ0005ocnQ
0003o`000?lfW@3o=Yd000;o=Yd000?o0000ob^J0?l000000_l000000omOZ`3o0000oeFW0005oeFW
0003o`000?m;Y03oBj@000;oBj@000?o0000od6Q0?l000000_l000000on1]03o0000ogNa0004ogNa
0003o`000?m^[`3oKZl000?oKZl000?o0000ofJ/0?mV[0000_mV[0000ol0003oGjX0o`000002o`00
0003ojbn0?l0003oY;d000GoY;d000?o0000oijk0?nN^`000onN^`000ol0003oV;X0oiRj0002oiRj
0003o`000?nB^03o000000;o000000?oc;40o`000?o:]P001Oo:]P000ol0003ob;/0olRk0003olRk
0003o`000?o6`P3oa/8000?oa/800ol00003omBM0003o`000?o>[03ocZ`000CocZ`000Co0000olRl
0?o8_03o00002?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00?_ooool00ol0
003oooooooooo`0[ooooo`03o`000?l0OA[o07dJ00Go00000ol0R0801?l0003o1hd0o`N=0?l7S@05
o`0000;o9iP000?o0000obZJ0?lZVP000olZVP000ol0003o:IT0obVI0002obVI0003o`000?lUV03o
9IP000;o9IP00_l00005odNS0003o`000?loX@3o?j4000?o?j4000?o0000ocJM0?lfW@000_lfW@02
o`0000GoGj/000?o0000oeFW0?mEY`000omEY`000ol0003oBj@0od^T0002od^T00;o00001On1]000
0ol0003oMk40ogNa0002ogNa0003o`000?m^[`3oKZl000?oKZl000?o0000ofJ/0?mV[0000_mV[002
o`0000Go[;h000?o0000ojBm0?nT_@000onT_@000ol0003oW[/0oijk0003oijk0003o`000?nH^P3o
V;X000;oV;X00_l00005olba0003o`000?o:]P3ob[H000?ob[H000?o0000olRk0?o8^`000oo8^`00
0ol0003oa/80olK20002olK200;o00001_oDW@000ol0003ocZ`0olj/0003olj/0003o`000?o8_03o
000000[ooooo00?o0000ooooooooool00oooool1o`00007ooooo000oooooo`03o`000?oooooooooo
02[ooooo00Co0000o`1m6_l0OA[o00000ol0R088o`0000;o7YD000?o0000obNH0?lWV0000olWV000
0ol0003o:YX0obZJ0003obZJ0003o`000?lYV@3o:IT000;o:IT01?l000000om<Y@3o0000odNS0004
odNS0003o`000?loX@3o?j4000?o?j4000?o0000ocJM0?l000000_l000000omY[@3o0000oen[0004
oen[0003o`000?mEY`3oEJL000?oEJL000?o0000od^T0?l000000_l000000on<]`3o0000oh6d0004
oh6d0003o`000?mg/@3oMk4000?oMk4000?o0000ofj_0?m^[`000_m^[`000ol0003oIZ`0o`000002
o`000003okC10?l0003o[;h000Co[;h000?o0000ojBm0?nT_@000onT_@000ol0003oW[/0oijk0003
oijk0003o`000?nH^P3o000000;o000000?ocZd0o`000?o</@001?o</@000ol0003ob[H0olZf0004
olZf0003o`000?o8^`3ob;/000;ob;/000?o0000olK20?l000000_l000000ooHT@3o0000omBM0005
omBM0003o`000?o>[03ocZ`000?ocZ`00_l0000<ooooo`03o`000?oooooooooo00;ooooo0Ol00001
ooooo`00@?ooool2o`0002_ooooo0_l000000ol0OA[o0000o`280P02o`280P05o`000?l@T03o4900
oa2@0?l000001OlNU@000ol0003o9iP0obNH0002obNH0003o`000?lZVP3o:YX000?o:YX000?o0000
obVI0?lYV@000ol00005odbU0003o`000?m7X`3oAj<000?oAj<000?o0000ocnQ0?loX@000_loX@02
o`0000GoJJd000?o0000oen[0?mOZ`000omOZ`000ol0003oEJL0oeFW0002oeFW00;o00001On<]`00
0ol0003oPK@0oh6d0002oh6d0003o`000?mg/@3oMk4000?oMk4000?o0000ofj_0?m^[`000_m^[`02
o`0000Go]<4000?o0000ojbn0?n/_P000_n/_P000ol0003oY;d0ojBm0003ojBm0003o`000?nN^`3o
W[/000?oW[/00_l00005olj]0003o`000?o</@3oc;4000;oc;4000?o0000olZf0?o:]P001?o:]P00
0ol0003ob;/0olRk0002olRk00;o00001OoHT@000ol0003oe9d0omBM0003omBM0004o`000?o>[03o
cZ`0olj/00;o00003oooool01Ol0003ooooooooooooooooo0000007ooooo0012ooooo`03o`000?oo
oooooooo02Sooooo00?o0000o`233ol000000_l00003o`280P05o`000?l@T03o4900oa2@0?l00000
1OlNU@000ol0003o9iP0obNH0002obNH0003o`000?lZVP3o:YX000;o:YX00ol00002odjU0003o`00
0?m<Y@3oC:D000?oC:D000?o0000odNS0?m7X`000om7X`000ol0003o?j40o`000002o`000003og:`
0?l0003oJJd000CoJJd000?o0000oen[0?mOZ`000omOZ`000ol0003oEJL0oeFW0002o`000003oiJi
0?l0003oS;L000CoS;L000?o0000oh6d0?n1]0000on1]0000ol0003oMk40ogNa0002ogNa0003o`00
0?m^[`3o000000;o000000?o_L<0o`000?nd`@001?nd`@000ol0003o[;h0ojbn0003ojbn0003o`00
0?nT_@3oY;d000?oY;d000?o0000oijk0?l000000_l000000oo@Z03o0000olj]0004olj]0003o`00
0?o</@3oc;4000?oc;4000?o0000olZf0?o:]P000oo:]P000ol0003ob;/0o`000002o`000003om^7
0?l0003of94000Cof94000?o0000omBM0?oDW@001?oDW@03o`00017ooooo00Go0000oooooooooooo
ooooo`000001ooooo`00@oooool00ol0003oooooooooo`0Xooooo`04o`000?l0P`oo08<?o`233`Co
00001?l@T0000ol0003o7YD0oajE0002oajE0003o`000?lWV03o9iP000;o9iP000?o0000obZJ0?l0
00000_l000000om=Y@3o0000odjU0003odjU0003o`000?m<Y@3oC:D000?oC:D000?o0000odNS0?m7
X`000_m7X`02o`0000GoL[0000?o0000ofV]0?mY[@000omY[@000ol0003oGj/0oen[0002oen[0003
o`000?mEY`3o000000?oU[T000?o0000ohbg0?n<]`000on<]`000ol0003oPK@0oh6d0003oh6d0003
o`000?mg/@3oMk4000;oMk400_l00005okg30003o`000?nd`@3o]<4000;o]<4000?o0000ojbn0?n/
_P000on/_P000ol0003oY;d0ojBm0002ojBm00?o00001?o@Z0000ol0003ocZd0olj]0003olj]0003
o`000?o</@3oc;4000?oc;4000?o0000olZf0?o:]P000oo:]P02o`0000GofhL000?o0000omRA0?oH
T@000ooHT@000ol0003oe9d0omBM0002omBM00;o00005?ooool01?l0003oooooooooool00001oooo
o`00A?ooool00ol0003oooooooooo`0Xooooo`04o`000?l0P`oo08<?o`0000;o3Hl04Ol00005odfU
0005o`000?m>Y@3oCZD0odjU0?l000001Om<Y@000ol0003oAj<0o`000002o`000003ogRa0?l0003o
L[0000CoL[0000?o0000ofV]0?mY[@000omY[@000ol0003oGj/0oen[0002oen[00;o00001OnF^@00
0ol0003oS;L0ohbg0003ohbg0003o`000?n1]03oPK@000;oPK@000?o0000ogNa0?l000000_l00000
0oo5``3o0000okg30004okg30003o`000?nd`@3o]<4000?o]<4000?o0000ojbn0?n/_P000_n/_P00
0ol0003oY;d0o`000002o`000003om6S0?l0003od:P000God:P000?o0000olj]0?o>[@000oo>[@00
0ol0003oc;40olba0002olba0003o`000?o:]P3ob[H000?o000000?ogWh0o`000?oKQ`001?oKQ`00
0ol0003of940omRA0003omRA0003o`000?oDW@3oe9d000;o00005oooool00ol0003oooooo`000001
ooooo`00AOooool2o`0002Wooooo0_l000001Ol0P`oo0000o`f?0?l=S`3o000000Co9IP000?o0000
ocRN0?lhWP000_lhWP000ol0003oAJ<0odFS0002odFS0003o`000?m=Y@3oCJD000?oCJD000?o0000
odjU0?m>Y@000_m>Y@000ol0003oC:D0odbU0002odbU00;o00001Omh/@000ol0003oL[00og:`0003
og:`0003o`000?mY[@3oJJd000;oJJd000?o0000oen[0?l000000_l000000onP_03o0000oiJi0004
oiJi0003o`000?n<]`3oS;L000?oS;L000?o0000oh6d0?n1]0000_n1]002o`0000GoaL<000?o0000
okg30?nm``000_nm``000ol0003o]<40okC10003okC10003o`000?n/_P3o[;h000;o[;h00_l00005
om6S0003o`000?o@Z03od:P000?od:P000?o0000olj]0?o>[@000oo>[@000ol0003oc;40olba0002
olba00?o00001?oNOP000ol0003ofhL0om^70003om^70003o`000?oHT@3of94000?of94000?o0000
omBM0?l000006Oooool00ol0003oooooo`000001ooooo`00Aoooool00ol0003oooooooooo`0Woooo
o`Co00000_l=S`000ol0003o9IP0obFH0002obFH0003o`000?lhWP3o>9h000;o>9h000?o0000odFS
0?m5X`000_m5X`000ol0003oCJD0odfU0002odfU0003o`000?m>Y@3oCZD000;oCZD000?o0000odbU
0?l000000_l000000omk/P3o0000ogRa0004ogRa0003o`000?mb/03oL[0000?oL[0000?o0000ofV]
0?mY[@000_mY[@02o`0000CoX;`000?o0000oiJi0?nF^@000onF^@000ol0003oS;L0ohbg0003ohbg
0003o`000?n1]03o000000;o000000?oakh0o`000?o5``001?o5``000ol0003o_L<0okg30003okg3
0003o`000?nd`@3o]<4000;o]<4000?o0000ojbn0?l000000_l000000ooCWP3o0000om6S0004om6S
0003o`000?o@Z03od:P000?od:P000?o0000olj]0?o>[@000oo>[@000ol0003oc;40o`000002o`00
0003on1f0?l0003ogWh000GogWh000?o0000om^70?oKQ`000ooKQ`000ol0003of940omRA0002omRA
00;o00006oooool1o`00007ooooo0Ol0000004Sooooo00?o0000ooooooooool09oooool00ol0003o
08P4o`281002o`000003o`f?0?l0003o9IP000?o9IP000?o0000ocRN0?lhWP000_lhWP001Ol0003o
AJ<0odFS0?m5X`3o000000GoCJD000?o0000odjU0?m>Y@000ol00005og^b0003o`000?mh/@3oN;40
00?oN;4000?o0000og:`0?mb/0000_mb/0000ol0003oJJd0o`000002o`000003ojRn0?l0003oX;`0
00CoX;`000?o0000oiJi0?nF^@000_nF^@000ol0003oS;L0ohbg0003ohbg00;o00001?o7_P000ol0
003oaL<0olG30003olG30003o`000?nm``3o_L<000?o_L<000?o0000okC10?nd`@000_nd`@02o`00
00Godih000?o0000om6S0?oAX`000_oAX`000ol0003od:P0om2X0003om2X0003o`000?o>[@3ocZd0
00?ocZd00_l00005on1f0003o`000?oNOP3ogWh000?ogWh000?o0000om^70?oKQ`000ooKQ`000ol0
003of940omRA0002o`0001kooooo0_l0000004Wooooo00?o0000ooooooooool09oooool3o`000003
oajF0?l0003o000000Co9IP000?o0000ocRN0?lhWP000_lhWP001Ol0003oAJ<0odFS0?m5X`3o0000
00?oCJD01Ol00002og^b0003o`000?mk/P3oNk8000?oNk8000?o0000ogRa0?mh/@000omh/@000ol0
003oL[00og:`0002og:`00;o00001?nX_P000ol0003oX;`0oj2l0003oj2l0003o`000?nF^@3oU[T0
00?oU[T000?o0000ohbg0?l000000_l000000oo9^03o0000olNn0004olNn0003o`000?o5``3oaL<0
00?oaL<000?o0000okg30?nm``000_nm``000ol0003o]<40o`000002o`000003omFI0?l0003odih0
00Codih000?o0000om6S0?oAX`000ooAX`000ol0003od:P0om2X0003om2X0003o`000?o>[@3o0000
00;o000000?ohfl0o`000?oPMP001?oPMP000ol0003ogWh0omin0003omin0003o`000?oKQ`3ofhL0
00?ofhL000?o0000omRA0?l000007oooool3o`000000B_ooool2o`0002Oooooo00Co0000o`J<0?l0
003o00000_lNUP0Ao`0000;oMK0000?o0000og^b0?mk/P000omk/P000ol0003oNk80og^b0003og^b
0003o`000?mh/@3oN;4000;oN;4000?o0000og:`0?l000000_l000000on__`3o0000ojRn0004ojRn
0003o`000?nP_03oX;`000;oX;`000?o0000oiJi0?nF^@000_nF^@03o`0000CobKP000?o0000olNn
0?o7_P000oo7_P000ol0003oaL<0olG30003olG30003o`000?nm``3o_L<000;o_L<00_l00005omFI
0003o`000?oCWP3odih000;odih000?o0000om6S0?oAX`000ooAX`000ol0003od:P0om2X0002om2X
00?o00001OoSK`000ol0003oh7H0on1f0002on1f0003o`000?oNOP3ogWh000?ogWh000?o0000om^7
0?oKQ`000ooKQ`02o`0001cooooo1?l00003ooooo`00C?ooool00ol0003oooooooooo`0Uooooo`03
o`000?l6S03o000000;o7YH000?o0000ocfP0?lmX0000_lmX0000ol0003oEZP0oeJX0002oeJX0005
o`000?mY[@3oJJd0ofV]0?l000001Ome/0000ol0003oNk80og^b0002og^b0003o`000?mk/P3oNk80
00?oNk8000Co0000ogRa0?mh/@3oN;400ol00004ojno0003o`000?nX_P3oZ;h000?oZ;h000?o0000
oj2l0?nP_0000onP_004o`000003olbc0?l0003obKP000GobKP000?o0000olNn0?o7_P000_o7_P00
0ol0003oaL<0olG30003olG30003o`000?nm``3o000000;o000000?oei<0o`000?oEV@001?oEV@00
0ol0003odih0om>N0003om>N0003o`000?oAX`3odJ<000;odJ<000?o0000om2X0?l000000_l00000
0ooTJ03o0000on=_0005on=_0003o`000?oPMP3oh7H000?oh7H000?o0000omin0?oNOP000ooNOP00
0ol0003ofhL0o`000002o`0001[ooooo1?l00007ooooo`00COooool00ol0003oooooooooo`0Uoooo
o`06o`000?l6S03o0000o`000?lNUP3o00001?lmX0000ol0003oEZP0oeJX0002oeJX0005o`000?mY
[@3oJJd0ofV]0?l000001?me/0000ol0003oNk80og^b0003og^b0003o`000?mk/P3oNk8000;oNk80
1?l00002ok?00003o`000?n__`3o[kl000?o[kl000?o0000ojRn0?nX_P000_nX_P000ol0003oX;`0
oj2l0002oj2l00;o00001Oo</`000ol0003obKP0olVh0003olVh0003o`000?o7_P3oakh000;oakh0
00?o0000olG30?o5``000oo5``02o`0000Coei<000?o0000omFI0?oEV@000ooEV@000ol0003odih0
om>N0003om>N0003o`000?oAX`3odJ<000;odJ<00_l00005onAX0003o`000?oSK`3ohfl000?ohfl0
00?o0000on1f0?oPMP000ooPMP000ol0003ogWh0omin0002omin00?o00006Oooool4o`0000_ooooo
001>ooooo`03o`000?oooooooooo02Gooooo0_l000001?l`W03o0000o`000?l00004ocfP0005o`00
0?mFZ03oEZP0oeJX0?l000001?mY[@000ol0003oMK00ogF`0002ogF`0003o`000?mk/P3oNk8000;o
Nk8000?o0000og^b0?l000000_l000000onc`03o0000ok?00004ok?00003o`000?n__`3o[kl000;o
[kl000?o0000ojRn0?nX_P000onX_P04o`000003olf^0?l0003oc;<000Coc;<000?o0000olVh0?o9
^0000oo9^0000ol0003oakh0olNn0003olNn0003o`000?o5``3o000000;o000000?ofHd0o`000?oG
T`001?oGT`000ol0003oeIT0omFI0003omFI0003o`000?oCWP3odih000;odih000?o0000om6S0?l0
00000_l000000ooVHP3o0000onAX0004onAX0003o`000?oSK`3ohfl000Cohfl000?o0000on1f0?oP
MP000_oPMP000ol0003ogWh0o`000002o`0001Wooooo0ol0000?ooooo`00Coooool2o`0002Kooooo
0_l00003oc2L00Go00000omFZ0000ol0003oJJd0ofV]0002ofV]0003o`000?me/03oMK0000;oMK00
00Co0000og^b0?mk/P3oNk800ol00004ok?00003o`000?nc`03o/l0000?o/l0000?o0000ojno0?n_
_`000_n__`000ol0003oZ;h0ojRn0002ojRn00;o00001Oo=[P000ol0003oc;<0olbc0002olbc0003
o`000?o9^03obKP000?obKP000?o0000olNn0?o7_P000_o7_P03o`0000CofHd000?o0000omNC0?oG
T`000ooGT`000ol0003oeIT0omFI0003omFI0003o`000?oCWP3odih000;odih00_l00005onIR0003
o`000?oTJ03oi6P000;oi6P000?o0000on=_0?oSK`001?oSK`000ol0003oh7H0on1f0002on1f00;o
00006?ooool4o`0001;ooooo001Aooooo`03o`000?oooooooooo02Cooooo0_l00002oc2L0004o`00
0?mGZ03oEjP0oeNX01;o00000_n^_`000ol0003o/l00ok?00003ok?00003o`000?nc`03o/l0000;o
/l0000?o0000ojno0?n__`000on__`04o`000003oln[0?l0003ocJh000CocJh000?o0000olbc0?o<
/`000oo</`000ol0003obKP0olVh0003olVh00Co000000?ofhP0o`000?oIS@001OoIS@000ol0003o
ei<0omNC0002omNC0003o`000?oEV@3oeIT000?oeIT000?o0000om>N0?l000000_l000000ooXG03o
0000onIR0004onIR0003o`000?oTJ03oi6P000?oi6P000?o0000on=_0?oSK`000ooSK`000ol0003o
h7H0o`000002o`0001Kooooo1?l0000Fooooo`00D_ooool00ol0003oooooooooo`0Tooooo`?o0000
00?o<9`0o`000?mGZ0000_mGZ0001Ol0003oMk40ogNa0?mg/@3o000000CoT;P000?o0000oj:l0?nR
_0000_nR_0000ol0003o[[l0ojjo0003ojjo0003o`000?nc`03o/l0000;o/l0000?o0000ok?00?nc
`0000onc`0000ol0003o[kl0ojno0003o`0000Gocj/000?o0000olf^0?o=[P000oo=[P000ol0003o
c;<0olbc0002olbc0003o`000?o9^03obKP000;obKP00_l00005om^80003o`000?oIS@3ofHd000?o
fHd000?o0000omNC0?oGT`000_oGT`000ol0003oeIT0omFI0003omFI00;o00001OoXG0000ol0003o
iV80onIR0002onIR0003o`000?oTJ03oi6P000?oi6P000?o0000on=_0?oSK`000ooSK`02o`0001Go
oooo1?l0000Jooooo`00Doooool00ol0003oooooooooo`0Tooooo`Go00000omGZ0001Ol0003oMk40
ogNa0?mg/@3o000000CoT;P000?o0000oj:l0?nR_0000_nR_0000ol0003o[[l0ojjo0002ojjo0003
o`000?nc`03o/l0000;o/l0000?o0000ok?00?nc`0000_nc`004o`0000;od:P000?o0000oln[0?o?
Z`000oo?Z`000ol0003ocJh0olf^0003olf^0003o`000?o</`3oc;<000;oc;<000?o0000olVh0?l0
00000_l000000ooMPP3o0000om^80004om^80003o`000?oIS@3ofHd000?ofHd000?o0000omNC0?oG
T`000ooGT`000ol0003oeIT0o`000002o`000003onYF0?l0003oj5`000Coj5`000?o0000onIR0?oV
HP000ooVHP000ol0003oi6P0onAX0002onAX0003o`000?oSK`3ohfl000?o00004oooool4o`0001ko
oooo001Dooooo`;o00009Oooool2o`0000;o@Z800_l000000omGZ03o0000ogNa0002ogNa0003o`00
0?n@^03oT;P000;oT;P000?o0000oj:l0?nR_0000onR_0000ol0003o[[l0ojjo0002ojjo0003o`00
0?nc`03o/l0000;o/l001?l000000oo@Z03o0000om2X0004om2X0003o`000?o?Z`3ocj/000?ocj/0
00?o0000olf^0?o=[P000_o=[P001?l0003oc;<0olbc0?o</`03o`0000GogH8000?o0000om^80?oK
R0000_oKR0000ol0003ofHd0omV=0003omV=0003o`000?oGT`3oei<000;oei<00ol00004onYF0003
o`000?oXG03oj5`000?oj5`000?o0000onIR0?oVHP000ooVHP000ol0003oi6P0onAX0002onAX00?o
00004_ooool4o`0002;ooooo001Fooooo`03o`000?oooooooooo02Cooooo0ol000000om`[`3o0000
o`000004ogNa0003o`000?n@^03oT;P000;oT;P000?o0000oj:l0?nR_0000_nR_0000ol0003o[[l0
ojjo0002ojjo0003o`000?nc`03o/l0000?o00001Oo@Z0000ol0003od:P0om2X0002om2X0003o`00
0?o?Z`3ocj/000?ocj/000?o0000olf^0?o=[P000_o=[P04o`0000;ogWd000?o0000omf20?oMPP00
0ooMPP000ol0003ofhP0om^80003om^80003o`000?oIS@3ofHd000?ofHd01?l000000oo/C`3o0000
onYF0005onYF0003o`000?oXG03oj5`000?oj5`000?o0000onIR0?oVHP000_oVHP000ol0003oi6P0
o`000002o`00017ooooo1?l0000Vooooo`00Eoooool00ol0003oooooooooo`0Tooooo`?o00000_m`
[`05o`0000CoT;P000Co0000oj:l0?nR_03oX[`02Ol00002olj[0003o`000?o@Z03od:P000?od:P0
00?o0000om2X0?o@Z0000oo@Z0000ol0003ocj/0oln[0002oln[0003o`000?o=[P3o000000;o0000
00?oggX0o`000?oNO@001?oNO@000ol0003ogH80omf20003omf20003o`000?oKR03ofhP000;ofhP0
00?o0000omV=0?oIS@000_oIS@02o`0000Gok4l000?o0000onYF0?oZEP000ooZEP000ol0003oj5`0
onQL0003onQL0003o`000?oVHP3oiV8000;oiV800_l0000Aooooo`?o0000:_ooool005Sooooo00?o
0000ooooooooool08oooool3o`0000;oL:l000Co0000oiVj0?nI^P3oVKX02Ol00002olRl0003o`00
0?o</P3oc;8000;oc;8000?o0000olj[0?o>Z`000_o>Z`000ol0003od:P0om2X0003om2X0003o`00
0?o@Z03od:P000;od:P000?o0000oln[0?o?Z`000_o?Z`02o`0000GoggX000?o0000omim0?oNO@00
0_oNO@000ol0003ogH80omf20003omf20003o`000?oKR03ofhP000;ofhP000?o0000omV=0?l00000
0_l000000oo]B@3o0000ona?0004ona?0003o`000?oZEP3ojUH000?ojUH000?o0000onQL0?oXG000
0ooXG0000ol0003oiV80o`000002o`0000oooooo1?l0000]ooooo`00FOooool2o`0002?ooooo1Ol0
00000om`[`3o0000oiVj0002oiVj0003o`000?nk`P3o^l8000;o^l8000?o0000olRl0?o8_0000oo8
_0000ol0003oc;80olbb0002olbb0005o`000?o>Z`3ocZ/0olj[0?l000001Oo@Z0000ol0003od:P0
om2X0002om2X0003o`000?o?Z`3o000000;o000000?oh7P0o`000?oONP001?oONP000ol0003ogWd0
omim0003omim0003o`000?oMPP3ogH8000;ogH8000Co0000om^80?oKR03ofhP00ol00005one90003
o`000?o/C`3ok4l000;ok4l000?o0000onYF0?oZEP000ooZEP000ol0003oj5`0onQL0003onQL00;o
00003_ooool4o`00037ooooo001Kooooo`03o`000?oooooooooo023ooooo00Go0000ooooool0003o
0000ohVf0003o`0000?oVKX000?o0000ok_20?nk`P000_nk`P000ol0003ob;`0olRl0002olRl0003
o`000?o</P3oc;8000;oc;8000?o0000olj[0?o>Z`000_o>Z`000ol0003od:P0om2X0002om2X0004
o`000?o@Z03od:P0om2X00?o00001OoPN0000ol0003oggX0ommj0002ommj0003o`000?oNO@3ogWd0
00?ogWd000?o0000omf20?oMPP000_oMPP04o`0000;okd@000?o0000one90?o]B@000oo]B@000ol0
003ok4l0ona?0003ona?0003o`000?oZEP3ojUH000?ojUH000?o0000onQL0?l000000_l0000<oooo
o`Co0000=Oooool005cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`02o`0000?o
RKH01Ol00004ok_20005o`000?o8_03ob;`0olRl0?l000001?o</P000ol0003ocZ/0olj[0002olj[
0004o`000?o@Z03od:P0om2X00Go00000_oPN0000ol0003oh7P0on1h0003on1h0003o`000?oONP3o
ggX000?oggX000?o0000omim0?oNO@000_oNO@000ol0003ogH80o`000002o`000003oo0o0?l0003o
kd@000Cokd@000?o0000one90?o]B@000_o]B@000ol0003ok4l0ona?0003ona?0003o`000?oZEP3o
jUH000;ojUH00ol0000;ooooo`Co0000>Oooool005gooooo00?o0000ooooooooool07_ooool01?l0
003oooooooooooooool2o`0000;oRKH000Co0000okc20?nl`P3o_<801_l00004olRl0003o`000?o<
/P3oc;8000;oc;8000?o0000olj[0?o>Z`001Ol00002ommk0003o`000?oPN03oh7P000?oh7P000?o
0000on1h0?oPN0000ooPN0000ol0003oggX0ommj0002ommj0003o`000?oNO@3ogWd000;ogWd00_l0
0005oo0o0003o`000?o_A03okd@000;okd@000?o0000one90?o]B@000oo]B@000ol0003ok4l0ona?
0002ona?0003o`000?oZEP3o000000;o00002_ooool4o`0003gooooo001Nooooo`;o00007_ooool0
0ol0003oooooooooo`03ooooo`;o000000?oRKH0o`000?nl`P000_nl`P001?l0003oc;40olba0?o<
/@0=o`0000;og8<000?o0000ommk0?oON`000ooON`000ol0003oh7P0on1h0002on1h0003o`000?oP
N03oh7P000?oh7P000?o0000ommj0?oONP000_oONP000ol0003ogWd0o`000002o`000003oo4l0?l0
003ol3l000Col3l000?o0000onm40?o_A0000oo_A0000ol0003okDT0one90002one90003o`000?o/
C`3ok4l000;ok4l00_l00009ooooo`Co0000@Oooool0063ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`04ooooo`Co00000onl`P001Ol0003oc;40olba0?o</@3o000000?odid000?o
0000omV>0?oISP000_oISP000ol0003og8<0omb30003omb30003o`000?oON`3ogg/000;ogg/000?o
0000on1h0?oPN0000ooPN0000ol0003oh7P0on1h0002on1h0004o`000?oONP3oggX0ommj00?o0000
1Ooa?0000ol0003ol3l0oo0o0002oo0o0003o`000?o_A03okd@000?okd@000?o0000one90?o]B@00
0_o]B@000ol0003ok4l0o`000002o`0000Sooooo0ol00015ooooo`00HOooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000oink0?nO^`000_l000000onl`P3o0000olba
0003olba0005o`000?oCW@3odid0om>M0?l000001?oISP000ol0003og8<0omb30002omb30003o`00
0?oON`3ogg/000?ogg/000?o0000on1h0?oPN0000_oPN0000ol0003oh7P0on1h0002on1h00Co0000
0_oa>`000ol0003olC`0oo4l0003oo4l0003o`000?o`?`3ol3l000?ol3l000?o0000onm40?o_A000
0_o_A0001?l0003okDT0one90?o]B@03o`0000Oooooo1?l00018ooooo`00H_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Kooooo0ol000000oo:]`3o0000o`000004olba0005o`00
0?oCW@3odid0om>M0?l000001?oISP000ol0003og8<0omb30003omb30003o`000?oON`3ogg/000;o
gg/000?o0000on1h0?oPN0000_oPN0000ol0003oh7P0o`000002o`000003oo4l0?l0003olC/000?o
lC/000?o0000oo4l0?oa?0000ooa?0000ol0003ol3l0oo0o0003oo0o0003o`000?o_A03okd@000;o
kd@01?l00006ooooo`Co0000C?ooool006?ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`08ooooo`;o00000_o:]`05o`0000Codid000?o0000omV>0?oISP000_oISP000ol0003og8<0
omb30002omb30003o`000?oON`3ogg/000;ogg/000Co0000on1h0?oPN03oh7P00ol00004oo4l0003
o`000?oa>`3olC/000?olC/000?o0000oo4l0?oa?0000ooa?0000ol0003ol3l0oo0o0002oo0o0003
o`000?o_A03o000000;o00001_ooool4o`00053ooooo001Tooooo`;o00006?ooool00ol0003ooooo
ooooo`09ooooo`04o`000?o:]`3ob[L0o`0000?oeIP01_l00004omV>0004o`000?oLP`3og8<0omb3
00[o00000_o`@0000ol0003olC`0oo4l0003oo4l0003o`000?oa>`3olC/000;olC/000?o0000oo4l
0?oa?0000ooa?0000ol0003ol3l0oo0o0002oo0o00;o00001Oooool4o`0005Cooooo001Vooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool2o`000003olZg0?l0003oeIP000;o
eIP000Co0000omim0?oNO@3ogWd02Ol00002onYD0003o`000?o^B03okTP000;okTP000?o0000oo10
0?o`@0000oo`@0000ol0003olC`0oo4l0002oo4l0003o`000?oa>`3olC/000;olC/000?o0000oo4l
0?oa?0000ooa?0000ol0003ol3l0o`000002o`0000?ooooo1?l0001Hooooo`00Ioooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00cooooo0ol00003omFH0005o`000?oNO@3ogWd0omim
0?l000001?oUIP000ol0003ojU@0onYD0003onYD0003o`000?o^B03okTP000;okTP000?o0000oo10
0?o`@0000_o`@0000ol0003olC`0oo4l0002oo4l0003o`000?oa>`3olC/000?olC/000?o0000oo4l
0?oa?0001?l00002ooooo`Co0000G?ooool006Sooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oEV03oeIP000;oeIP000Go0000omim0?oNO@3ogWd0o`000004onEV
0003o`000?oZE03ojU@000;ojU@000?o0000oni80?o^B0000_o^B0000ol0003ol400oo100002oo10
0003o`000?oa?03olC`000?olC`000?o0000oo4k0?oa>`001Ol00003ooooo`?o0000H?ooool006Wo
oooo0_l0000Cooooo`03o`000?oooooooooo00oooooo1Ol00004omim0005o`000?oUIP3oiFH0onEV
0?l000001?oZE0000ol0003okTP0oni80002oni80003o`000?o`@03ol40000?ol40000?o0000oo4l
0?oa?0001Ol00004ooooo`Co0000Hoooool006_ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Cooooo`Ko00001?oUIP000ol0003ojU@0onYD0002onYD0003o`000?o^B03okTP000;o
kTP000?o0000oo100?o`@0001Ol00005ooooo`Co0000Ioooool006cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Hooooo`Ko00000_oZE00:o`0000Kooooo1?l0001[ooooo`00KOoo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo0ol0000<ooooo`Co0000Kooo
ool006kooooo0_l0000=ooooo`03o`000?oooooooooo02Wooooo1?l0001cooooo`00L?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0001gooooo`00LOooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02;ooooo0ol0001kooooo`00L_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0001nooooo`00Loooool2o`0000Sooooo00?o
0000ooooooooool06_ooool4o`0008;ooooo001eooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05_ooool4o`0008Kooooo001fooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04_ooool4o`0008[ooooo001gooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03_ooool4o`0008kooooo001hooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000
T_ooool007[ooooo00Co0000oooooooooooo00002Oooool3o`0009Kooooo001kooooo`03o`000?oo
oooo000000Gooooo1?l0002Iooooo`00O?ooool2o`000003ooooool0003o000000;o0000WOooool0
07gooooo0_l0002Qooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00;oooool3
o`0008[ooooo00?o0000ooooooooool0:oooool3o`0001Gooooo00?o0000ooooooooool06oooool0
033ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool06_ooool002[ooooo0ol00003ooooo`?o00001?ooool2o`0000;o
oooo1Ol00002ooooo`?o00000oooool4o`000003ooooool0003o000000?o00001oooool3o`0000Co
oooo1?l00003ooooo`;o00000_ooool6o`0000Kooooo1?l00002ooooo`Go000000?oooooo`000?l0
00000ol000000ooooooo0000o`000003o`0000;ooooo0ol00002ooooo`?o00001?ooool3o`0000;o
oooo0ol000001?oooooo0000o`000?ooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool00_ooool3o`00
00;ooooo1Ol00002ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`Co00000oooool2
o`0000;ooooo2_l00005ooooo`03o`000?oooooooooo01Wooooo000Yooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000003?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Wooooo000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00003oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ooooool5o`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Ko0000oooooooooooo
0000ooooool00005ooooo`Go00002?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo0000
ooooool000000_ooool3o`0000?ooooo00?o0000ooooool000000_ooool5o`0000?ooooo00Co0000
oooooooooooooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000;ooooo0ol00005ooooo`03o`000?oooooo
oooo01Wooooo000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`?o0000
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l0
0003ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooooooooooooooo
o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00Co
0000oooooooooooo00001Oooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000oooo
ooooool06Oooool002Wooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000;ooooo1?l00002
ooooo`?o00001?ooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00Co0000
oooooooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002Oooool01Ol0003ooooooooo
ool0003ooooo00?o00001?ooool4o`0000;ooooo1?l00002ooooo`?o00000_ooool2o`000003oooo
ool0003o000000;ooooo0ol00002ooooo`Co00000oooool3o`0000?ooooo0ol00009ooooo`03o`00
0?oooooooooo00;ooooo1_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000
0_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1?l00003ooooo`Wo0000
0oooool3o`0000?ooooo1?l00004ooooo`03o`000?oooooooooo01Wooooo000Yooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`00:_ooool3o`0000Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`?o00002Oooool4o`0000Wo
oooo00?o0000ooooooooool00_ooool2o`0000[ooooo1?l00004ooooo`03o`000?oooooooooo00Co
oooo0_l00004ooooo`;o0000;_ooool00ol0003oooooooooo`0Hooooo`?o00005_ooool00ol0003o
ooooooooo`02ooooo`;o00002oooool00ol0003oooooooooo`0Kooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0666135, 0.0600694, \
0.00355125, 0.00355125}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(CompiledFunction[
            If[#1 == 0 && #2 == 0, 
              3.149852620040084`, \
\(\(61.263559006376596`\)\(\[InvisibleSpace]\)\) - 
                0.5995013053549445`\ Cos[
                    ArcTan[#1, #2]]\ \@\(#1\^2 + #2\^2\) - 
                0.827998126926662`\ Cos[
                    2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) - 
                0.0005780932196429912`\ Cos[
                    3\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(3/2\) - 
                2.7883176369774045`*^-6\ Cos[
                    4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                6.166951977329706`*^-8\ Cos[
                    5\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(5/2\) + 
                5.50593448371445`*^-10\ Cos[
                    6\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^3 + 
                35.76918571206005`\ \((\(-1\) + 
                      0.014433811738429392`\ \((#1\^2 + #2\^2)\))\) + 
                26.61233421594999`\ Cos[
                    ArcTan[#1, #2]]\ \((\(-0.169904748246948`\)\ \@\(#1\^2 + \
#2\^2\) + 0.0018392798622462667`\ \((#1\^2 + #2\^2)\)\^\(3/2\))\) - 
                3.6394995515708306`\ Cos[
                    2\ ArcTan[#1, #2]]\ \((\(-0.021650717607644088`\)\ \
\((#1\^2 + #2\^2)\) + 0.0002083349213004221`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                23.370714360729597`\ \((1 - 
                      0.043301435215288175`\ \((#1\^2 + #2\^2)\) + 
                      0.0003125023819506331`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                0.22381221088389475`\ Cos[
                    3\ ArcTan[#1, #2]]\ \((\(-0.0024523731496616887`\)\ \((#1\
\^2 + #2\^2)\)\^\(3/2\) + 
                      0.000022123182721622465`\ \((#1\^2 + #2\^2)\)\^\(5/2\))\
\) - 0.6006852931258754`\ Cos[
                    ArcTan[#1, #2]]\ \((0.254857122370422`\ \@\(#1\^2 + #2\^2\
\) - 0.007357119448985067`\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                      0.00004424636544324493`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) - 
                0.0031318094445710086`\ Cos[
                    4\ ArcTan[#1, #2]]\ \((\(-0.0002604186516255276`\)\ \((#1\
\^2 + #2\^2)\)\^2 + 2.255300274443097`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                0.2053592225731745`\ Cos[
                    2\ ArcTan[#1, #2]]\ \((0.043301435215288175`\ \((#1\^2 + \
#2\^2)\) - 0.0010416746065021105`\ \((#1\^2 + #2\^2)\)\^2 + 
                      5.6382506861077425`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                1.0866615810366962`\ \((\(-1\) + 
                      0.08660287043057635`\ \((#1\^2 + #2\^2)\) - 
                      0.0015625119097531657`\ \((#1\^2 + #2\^2)\)\^2 + 
                      7.51766758147699`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) + 
                0.00223708546918555`\ Cos[
                    5\ ArcTan[#1, #2]]\ \((\(-0.000026547819265946955`\)\ \
\((#1\^2 + #2\^2)\)\^\(5/2\) + 
                      2.235252981211408`*^-7\ \((#1\^2 + #2\^2)\)\^\(7/2\))\) \
- 0.015043047509433327`\ Cos[
                    3\ ArcTan[#1, #2]]\ \((0.006130932874154222`\ \((#1\^2 + \
#2\^2)\)\^\(3/2\) - 0.0001327390963297348`\ \((#1\^2 + #2\^2)\)\^\(5/2\) + 
                      6.705758943634224`*^-7\ \((#1\^2 + #2\^2)\)\^\(7/2\))\) \
- 0.1094298986441623`\ Cos[
                    ArcTan[#1, #2]]\ \((\(-0.339809496493896`\)\ \@\(#1\^2 + \
#2\^2\) + 0.018392798622462667`\ \((#1\^2 + #2\^2)\)\^\(3/2\) - 
                      0.0002654781926594696`\ \((#1\^2 + #2\^2)\)\^\(5/2\) + 
                      1.117626490605704`*^-6\ \((#1\^2 + #2\^2)\)\^\(7/2\))\) \
+ 0.0008506612405088334`\ Cos[
                    6\ ArcTan[#1, #2]]\ \((\(-2.6311836535169465`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 2.1701719716626532`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                0.0032414341117366617`\ Cos[
                    4\ ArcTan[#1, #2]]\ \((0.0007812559548765829`\ \((#1\^2 + \
#2\^2)\)\^2 - 0.00001578710192110168`\ \((#1\^2 + #2\^2)\)\^3 + 
                      7.595601900819286`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                0.014822549949117863`\ Cos[
                    2\ ArcTan[#1, #2]]\ \((\(-0.07216905869214696`\)\ \
\((#1\^2 + #2\^2)\) + 0.0031250238195063315`\ \((#1\^2 + #2\^2)\)\^2 - 
                      0.000039467754802754194`\ \((#1\^2 + #2\^2)\)\^3 + 
                      1.5191203801638572`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                0.06046789458356166`\ \((1 - 
                      0.14433811738429392`\ \((#1\^2 + #2\^2)\) + 
                      0.004687535729259497`\ \((#1\^2 + #2\^2)\)\^2 - 
                      0.00005262367307033893`\ \((#1\^2 + #2\^2)\)\^3 + 
                      1.8989004752048216`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
            "-CompiledCode-"]\),
          False,
          Editable->False], ",", "0.0016102275055979252`", 
        ",", \({SphericalAberration \[Rule] 591.9715477220698`, 
          Astigmatism \[Rule] 220.6525325044598`, 
          FieldCurvature \[Rule] \(-661.5986912990095`\), 
          Distortion \[Rule] \(-61.04182755608818`\), 
          Coma \[Rule] 81.71148989922129`}\)}], "}"}]], "Output",
  CellLabel->"Out[32]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
{OpticalPathDifference,ResidualFitError,SeidelAberrations}/.
\tPupilFunction[colsys3D,FindImagePoint->True,Plot2D->False,ZernikeFit->True]\
\
\>", "Input",
  CellLabel->"In[33]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.15804 .19483 -11.8743 -9 ]
[.15804 .19483 .12568 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.52352 .0511 -5.23624 -9 ]
[.52352 .0511 .76376 0 ]
[.77305 .1056 0 -6.15354 ]
[.77305 .1056 12 2.84646 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93042 .3466 0 -5.92583 ]
[.93042 .3466 6 3.07417 ]
[.01869 .29912 -24 -2.77105 ]
[.01869 .29912 0 6.22895 ]
[.00953 .35653 -18 -2.81971 ]
[.00953 .35653 0 6.18029 ]
[2e-05 .41611 -24 -2.87039 ]
[2e-05 .41611 0 6.12961 ]
[-0.00985 .47797 -18 -2.92321 ]
[-0.00985 .47797 0 6.07679 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.16722 .20421 m
.17181 .2089 L
s
[(-5)] .15804 .19483 .97905 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.53137 .06162 m
.53529 .06688 L
s
[(5)] .52352 .0511 .74541 1 Mshowa
.125 Mabswid
.20145 .19081 m
.20417 .19365 L
s
.23614 .17722 m
.23883 .1801 L
s
.2713 .16345 m
.27395 .16637 L
s
.30694 .1495 m
.30955 .15245 L
s
.37969 .12101 m
.38222 .12403 L
s
.41682 .10647 m
.41931 .10953 L
s
.45447 .09173 m
.45691 .09482 L
s
.49265 .07678 m
.49505 .0799 L
s
.13343 .21744 m
.13622 .22022 L
s
.10009 .2305 m
.10291 .23324 L
s
.06718 .24338 m
.07003 .2461 L
s
.57064 .04624 m
.57294 .04944 L
s
.61047 .03065 m
.61273 .03387 L
s
.65089 .01482 m
.65309 .01808 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.76073 .11012 m
.75457 .11239 L
s
[(-5)] .77305 .1056 -1 .36745 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.91791 .35056 m
.91166 .35254 L
s
[(5)] .93042 .3466 -1 .31685 Mshowa
.125 Mabswid
.77825 .13692 m
.77454 .13826 L
s
.79532 .16304 m
.79161 .16436 L
s
.81198 .18851 m
.80826 .18982 L
s
.82822 .21336 m
.8245 .21465 L
s
.85955 .26128 m
.85582 .26253 L
s
.87466 .28439 m
.87092 .28563 L
s
.88941 .30696 m
.88567 .30818 L
s
.90383 .32901 m
.90008 .33022 L
s
.74276 .08263 m
.73907 .08401 L
s
.72431 .05441 m
.72063 .05581 L
s
.70536 .02543 m
.70169 .02685 L
s
.93168 .37162 m
.92792 .3728 L
s
.94514 .39221 m
.94138 .39337 L
s
.95831 .41235 m
.95454 .41349 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03094 .29441 m
.03706 .29206 L
s
[(0.15)] .01869 .29912 1 -0.38421 Mshowa
.02182 .35194 m
.02797 .34965 L
s
[(0.2)] .00953 .35653 1 -0.3734 Mshowa
.01236 .41164 m
.01853 .40941 L
s
[(0.25)] 2e-05 .41611 1 -0.36214 Mshowa
.00254 .47363 m
.00873 .47146 L
s
[(0.3)] -0.00985 .47797 1 -0.3504 Mshowa
.125 Mabswid
.02914 .30575 m
.03282 .30434 L
s
.02733 .31717 m
.03101 .31577 L
s
.02551 .32868 m
.02919 .32729 L
s
.02367 .34027 m
.02735 .33888 L
s
.01995 .36371 m
.02365 .36234 L
s
.01808 .37556 m
.02177 .37419 L
s
.01619 .3875 m
.01988 .38614 L
s
.01428 .39952 m
.01798 .39818 L
s
.01042 .42385 m
.01413 .42252 L
s
.00847 .43615 m
.01218 .43483 L
s
.00651 .44855 m
.01022 .44723 L
s
.00453 .46104 m
.00824 .45973 L
s
.03272 .28315 m
.03639 .28173 L
s
.03449 .27198 m
.03816 .27055 L
s
.03625 .26088 m
.03992 .25945 L
s
.00053 .48631 m
.00424 .48502 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .343 .29 r
.39361 .63803 .40505 .60573 .4202 .64726 .40826 .69819 Metetra
0 .516 .05 r
.40826 .69819 .4202 .64726 .43656 .66253 .42467 .72242 Metetra
.108 .581 0 r
.42467 .72242 .43656 .66253 .45355 .66248 .44198 .7251 Metetra
.15 .597 0 r
.44198 .7251 .45355 .66248 .47075 .65828 .45958 .72186 Metetra
.16 .6 0 r
.45958 .72186 .47075 .65828 .48807 .65347 .47733 .7177 Metetra
.165 .602 0 r
.47733 .7177 .48807 .65347 .5055 .64857 .4952 .71339 Metetra
.168 .603 0 r
.4952 .71339 .5055 .64857 .52305 .64364 .5132 .70898 Metetra
.172 .604 0 r
.5132 .70898 .52305 .64364 .54071 .63866 .53132 .70449 Metetra
.175 .605 0 r
.53132 .70449 .54071 .63866 .55849 .63364 .54956 .6999 Metetra
.178 .606 0 r
.54956 .6999 .55849 .63364 .57638 .62857 .56793 .69522 Metetra
.18 .607 0 r
.56793 .69522 .57638 .62857 .59439 .62347 .58643 .69045 Metetra
.182 .608 0 r
.58643 .69045 .59439 .62347 .61252 .61832 .60505 .68559 Metetra
.184 .608 0 r
.60505 .68559 .61252 .61832 .63076 .61313 .6238 .68063 Metetra
.185 .609 0 r
.6238 .68063 .63076 .61313 .64912 .60789 .64267 .67559 Metetra
.185 .609 0 r
.64267 .67559 .64912 .60789 .66761 .60261 .66167 .67044 Metetra
.186 .609 0 r
.66167 .67044 .66761 .60261 .68621 .59729 .6808 .66521 Metetra
.186 .609 0 r
.6808 .66521 .68621 .59729 .70494 .59192 .70005 .65987 Metetra
.185 .609 0 r
.70005 .65987 .70494 .59192 .7238 .58651 .71944 .65445 Metetra
.184 .608 0 r
.71944 .65445 .7238 .58651 .74277 .58105 .73895 .64892 Metetra
.183 .608 0 r
.73895 .64892 .74277 .58105 .76188 .57554 .75859 .6433 Metetra
.181 .607 0 r
.75859 .6433 .76188 .57554 .78111 .56999 .77835 .63758 Metetra
.179 .607 0 r
.77835 .63758 .78111 .56999 .80046 .56439 .79825 .63176 Metetra
.176 .606 0 r
.79825 .63176 .80046 .56439 .81995 .55875 .81828 .62584 Metetra
.173 .605 0 r
.81828 .62584 .81995 .55875 .83957 .55305 .83843 .61981 Metetra
.17 .604 0 r
.83843 .61981 .83957 .55305 .85932 .54731 .85871 .61369 Metetra
.166 .602 0 r
.85871 .61369 .85932 .54731 .8792 .54152 .87913 .60746 Metetra
.162 .601 0 r
.87913 .60746 .8792 .54152 .89921 .53567 .89967 .6011 Metetra
.156 .599 0 r
.89967 .6011 .89921 .53567 .91934 .52957 .9203 .59436 Metetra
.135 .591 0 r
.9203 .59436 .91934 .52957 .93936 .52151 .94073 .58476 Metetra
.041 .556 0 r
.94073 .58476 .93936 .52151 .95823 .50372 .95949 .56132 Metetra
0 .437 .192 r
.95949 .56132 .95823 .50372 .97378 .4617 .97362 .50414 Metetra
0 .496 .091 r
.38283 .6449 .39361 .63803 .40826 .69819 .39712 .71368 Metetra
.52 .708 0 r
.39712 .71368 .40826 .69819 .42467 .72242 .41349 .74243 Metetra
.789 .721 0 r
.41349 .74243 .42467 .72242 .44198 .7251 .43095 .74661 Metetra
.81 .667 0 r
.43095 .74661 .44198 .7251 .45958 .72186 .44876 .7439 Metetra
.815 .652 0 r
.44876 .7439 .45958 .72186 .47733 .7177 .46673 .74012 Metetra
.819 .643 0 r
.46673 .74012 .47733 .7177 .4952 .71339 .48483 .73614 Metetra
.822 .635 0 r
.48483 .73614 .4952 .71339 .5132 .70898 .50307 .73204 Metetra
.824 .627 0 r
.50307 .73204 .5132 .70898 .53132 .70449 .52143 .72781 Metetra
.827 .621 0 r
.52143 .72781 .53132 .70449 .54956 .6999 .53992 .72346 Metetra
.829 .615 0 r
.53992 .72346 .54956 .6999 .56793 .69522 .55855 .71899 Metetra
.831 .61 0 r
.55855 .71899 .56793 .69522 .58643 .69045 .57731 .71439 Metetra
.832 .606 0 r
.57731 .71439 .58643 .69045 .60505 .68559 .59619 .70966 Metetra
.833 .603 0 r
.59619 .70966 .60505 .68559 .6238 .68063 .61521 .70481 Metetra
.834 .6 0 r
.61521 .70481 .6238 .68063 .64267 .67559 .63436 .69984 Metetra
.834 .599 0 r
.63436 .69984 .64267 .67559 .66167 .67044 .65364 .69473 Metetra
.835 .598 0 r
.65364 .69473 .66167 .67044 .6808 .66521 .67305 .6895 Metetra
.834 .599 0 r
.67305 .6895 .6808 .66521 .70005 .65987 .69259 .68414 Metetra
.834 .6 0 r
.69259 .68414 .70005 .65987 .71944 .65445 .71226 .67865 Metetra
.833 .602 0 r
.71226 .67865 .71944 .65445 .73895 .64892 .73205 .67303 Metetra
.832 .604 0 r
.73205 .67303 .73895 .64892 .75859 .6433 .75198 .66728 Metetra
.831 .608 0 r
.75198 .66728 .75859 .6433 .77835 .63758 .77204 .6614 Metetra
.83 .613 0 r
.77204 .6614 .77835 .63758 .79825 .63176 .79223 .65538 Metetra
.828 .618 0 r
.79223 .65538 .79825 .63176 .81828 .62584 .81254 .64922 Metetra
.826 .624 0 r
.81254 .64922 .81828 .62584 .83843 .61981 .83298 .64293 Metetra
.823 .631 0 r
.83298 .64293 .83843 .61981 .85871 .61369 .85355 .6365 Metetra
.82 .639 0 r
.85355 .6365 .85871 .61369 .87913 .60746 .87425 .62993 Metetra
.817 .648 0 r
.87425 .62993 .87913 .60746 .89967 .6011 .89507 .6232 Metetra
.813 .659 0 r
.89507 .6232 .89967 .6011 .9203 .59436 .91598 .61598 Metetra
.802 .688 0 r
.91598 .61598 .9203 .59436 .94073 .58476 .93663 .60544 Metetra
.716 .757 0 r
.93663 .60544 .94073 .58476 .95949 .56132 .95535 .57895 Metetra
.191 .611 0 r
.95535 .57895 .95949 .56132 .97362 .50414 .9689 .51435 Metetra
.021 .547 0 r
.37243 .6384 .38283 .6449 .39712 .71368 .38645 .71018 Metetra
.776 .754 0 r
.38645 .71018 .39712 .71368 .41349 .74243 .40275 .74077 Metetra
.865 .506 0 r
.40275 .74077 .41349 .74243 .43095 .74661 .42028 .74556 Metetra
.888 .431 0 r
.42028 .74556 .43095 .74661 .44876 .7439 .43819 .74302 Metetra
.895 .407 0 r
.43819 .74302 .44876 .7439 .46673 .74012 .45627 .73931 Metetra
.899 .393 0 r
.45627 .73931 .46673 .74012 .48483 .73614 .47449 .73539 Metetra
.903 .38 0 r
.47449 .73539 .48483 .73614 .50307 .73204 .49284 .73133 Metetra
.906 .368 0 r
.49284 .73133 .50307 .73204 .52143 .72781 .51132 .72714 Metetra
.909 .358 0 r
.51132 .72714 .52143 .72781 .53992 .72346 .52994 .72282 Metetra
.912 .349 0 r
.52994 .72282 .53992 .72346 .55855 .71899 .5487 .71836 Metetra
.914 .341 0 r
.5487 .71836 .55855 .71899 .57731 .71439 .56758 .71377 Metetra
.916 .334 0 r
.56758 .71377 .57731 .71439 .59619 .70966 .5866 .70904 Metetra
.917 .329 0 r
.5866 .70904 .59619 .70966 .61521 .70481 .60576 .70417 Metetra
.918 .326 0 r
.60576 .70417 .61521 .70481 .63436 .69984 .62504 .69917 Metetra
.919 .323 0 r
.62504 .69917 .63436 .69984 .65364 .69473 .64446 .69403 Metetra
.919 .322 0 r
.64446 .69403 .65364 .69473 .67305 .6895 .66402 .68876 Metetra
.919 .323 0 r
.66402 .68876 .67305 .6895 .69259 .68414 .6837 .68334 Metetra
.919 .324 0 r
.6837 .68334 .69259 .68414 .71226 .67865 .70352 .67778 Metetra
.918 .327 0 r
.70352 .67778 .71226 .67865 .73205 .67303 .72346 .67208 Metetra
.916 .332 0 r
.72346 .67208 .73205 .67303 .75198 .66728 .74354 .66624 Metetra
.915 .338 0 r
.74354 .66624 .75198 .66728 .77204 .6614 .76375 .66025 Metetra
.913 .345 0 r
.76375 .66025 .77204 .6614 .79223 .65538 .78409 .65411 Metetra
.91 .353 0 r
.78409 .65411 .79223 .65538 .81254 .64922 .80456 .64783 Metetra
.908 .363 0 r
.80456 .64783 .81254 .64922 .83298 .64293 .82515 .6414 Metetra
.904 .374 0 r
.82515 .6414 .83298 .64293 .85355 .6365 .84588 .63483 Metetra
.901 .387 0 r
.84588 .63483 .85355 .6365 .87425 .62993 .86673 .6281 Metetra
.897 .4 0 r
.86673 .6281 .87425 .62993 .89507 .6232 .88771 .62119 Metetra
.892 .418 0 r
.88771 .62119 .89507 .6232 .91598 .61598 .90877 .61376 Metetra
.879 .459 0 r
.90877 .61376 .91598 .61598 .93663 .60544 .92955 .60276 Metetra
.829 .614 0 r
.92955 .60276 .93663 .60544 .95535 .57895 .94832 .57489 Metetra
.385 .671 0 r
.94832 .57489 .95535 .57895 .9689 .51435 .96176 .5074 Metetra
.043 .556 0 r
.36204 .62859 .37243 .6384 .38645 .71018 .37582 .70187 Metetra
.792 .715 0 r
.37582 .70187 .38645 .71018 .40275 .74077 .39205 .73356 Metetra
.884 .444 0 r
.39205 .73356 .40275 .74077 .42028 .74556 .40961 .7387 Metetra
.909 .36 0 r
.40961 .7387 .42028 .74556 .43819 .74302 .4276 .73618 Metetra
.916 .334 0 r
.4276 .73618 .43819 .74302 .45627 .73931 .44576 .73244 Metetra
.92 .318 0 r
.44576 .73244 .45627 .73931 .47449 .73539 .46407 .72848 Metetra
.924 .303 0 r
.46407 .72848 .47449 .73539 .49284 .73133 .48251 .72438 Metetra
.928 .29 0 r
.48251 .72438 .49284 .73133 .51132 .72714 .50108 .72015 Metetra
.931 .279 0 r
.50108 .72015 .51132 .72714 .52994 .72282 .5198 .71578 Metetra
.934 .269 0 r
.5198 .71578 .52994 .72282 .5487 .71836 .53864 .71127 Metetra
.936 .26 0 r
.53864 .71127 .5487 .71836 .56758 .71377 .55763 .70663 Metetra
.938 .253 0 r
.55763 .70663 .56758 .71377 .5866 .70904 .57675 .70185 Metetra
.939 .247 0 r
.57675 .70185 .5866 .70904 .60576 .70417 .596 .69693 Metetra
.94 .243 0 r
.596 .69693 .60576 .70417 .62504 .69917 .61539 .69187 Metetra
.941 .24 0 r
.61539 .69187 .62504 .69917 .64446 .69403 .63492 .68667 Metetra
.941 .239 0 r
.63492 .68667 .64446 .69403 .66402 .68876 .65457 .68132 Metetra
.941 .24 0 r
.65457 .68132 .66402 .68876 .6837 .68334 .67437 .67584 Metetra
.941 .242 0 r
.67437 .67584 .6837 .68334 .70352 .67778 .69429 .67021 Metetra
.94 .245 0 r
.69429 .67021 .70352 .67778 .72346 .67208 .71435 .66444 Metetra
.938 .25 0 r
.71435 .66444 .72346 .67208 .74354 .66624 .73455 .65852 Metetra
.937 .257 0 r
.73455 .65852 .74354 .66624 .76375 .66025 .75487 .65246 Metetra
.935 .265 0 r
.75487 .65246 .76375 .66025 .78409 .65411 .77533 .64625 Metetra
.932 .274 0 r
.77533 .64625 .78409 .65411 .80456 .64783 .79592 .63989 Metetra
.929 .285 0 r
.79592 .63989 .80456 .64783 .82515 .6414 .81663 .63337 Metetra
.926 .297 0 r
.81663 .63337 .82515 .6414 .84588 .63483 .83748 .62671 Metetra
.922 .311 0 r
.83748 .62671 .84588 .63483 .86673 .6281 .85846 .61989 Metetra
.918 .326 0 r
.85846 .61989 .86673 .6281 .88771 .62119 .87956 .61289 Metetra
.913 .346 0 r
.87956 .61289 .88771 .62119 .90877 .61376 .90075 .60534 Metetra
.899 .392 0 r
.90075 .60534 .90877 .61376 .92955 .60276 .92164 .59404 Metetra
.847 .562 0 r
.92164 .59404 .92955 .60276 .94832 .57489 .94049 .56528 Metetra
.428 .683 0 r
.94049 .56528 .94832 .57489 .96176 .5074 .95397 .49611 Metetra
.042 .556 0 r
.35154 .61831 .36204 .62859 .37582 .70187 .36509 .69282 Metetra
.795 .705 0 r
.36509 .69282 .37582 .70187 .39205 .73356 .38123 .72545 Metetra
.891 .422 0 r
.38123 .72545 .39205 .73356 .40961 .7387 .39882 .73089 Metetra
.916 .334 0 r
.39882 .73089 .40961 .7387 .4276 .73618 .41689 .72838 Metetra
.923 .307 0 r
.41689 .72838 .4276 .73618 .44576 .73244 .43513 .72459 Metetra
.928 .29 0 r
.43513 .72459 .44576 .73244 .46407 .72848 .45352 .72057 Metetra
.932 .276 0 r
.45352 .72057 .46407 .72848 .48251 .72438 .47205 .71641 Metetra
.935 .262 0 r
.47205 .71641 .48251 .72438 .50108 .72015 .49071 .71212 Metetra
.938 .251 0 r
.49071 .71212 .50108 .72015 .5198 .71578 .50951 .70769 Metetra
.941 .24 0 r
.50951 .70769 .5198 .71578 .53864 .71127 .52845 .70312 Metetra
.943 .231 0 r
.52845 .70312 .53864 .71127 .55763 .70663 .54752 .69842 Metetra
.945 .224 0 r
.54752 .69842 .55763 .70663 .57675 .70185 .56674 .69357 Metetra
.947 .218 0 r
.56674 .69357 .57675 .70185 .596 .69693 .58609 .68859 Metetra
.948 .214 0 r
.58609 .68859 .596 .69693 .61539 .69187 .60558 .68347 Metetra
.949 .211 0 r
.60558 .68347 .61539 .69187 .63492 .68667 .6252 .6782 Metetra
.949 .21 0 r
.6252 .6782 .63492 .68667 .65457 .68132 .64496 .67279 Metetra
.949 .211 0 r
.64496 .67279 .65457 .68132 .67437 .67584 .66486 .66724 Metetra
.948 .213 0 r
.66486 .66724 .67437 .67584 .69429 .67021 .68489 .66154 Metetra
.947 .216 0 r
.68489 .66154 .69429 .67021 .71435 .66444 .70506 .6557 Metetra
.946 .221 0 r
.70506 .6557 .71435 .66444 .73455 .65852 .72536 .64971 Metetra
.944 .228 0 r
.72536 .64971 .73455 .65852 .75487 .65246 .7458 .64357 Metetra
.942 .236 0 r
.7458 .64357 .75487 .65246 .77533 .64625 .76637 .63729 Metetra
.94 .246 0 r
.76637 .63729 .77533 .64625 .79592 .63989 .78707 .63085 Metetra
.937 .257 0 r
.78707 .63085 .79592 .63989 .81663 .63337 .80791 .62426 Metetra
.933 .27 0 r
.80791 .62426 .81663 .63337 .83748 .62671 .82888 .61752 Metetra
.93 .284 0 r
.82888 .61752 .83748 .62671 .85846 .61989 .84998 .61062 Metetra
.925 .299 0 r
.84998 .61062 .85846 .61989 .87956 .61289 .8712 .60354 Metetra
.92 .319 0 r
.8712 .60354 .87956 .61289 .90075 .60534 .89252 .59589 Metetra
.906 .368 0 r
.89252 .59589 .90075 .60534 .92164 .59404 .91352 .58433 Metetra
.852 .546 0 r
.91352 .58433 .92164 .59404 .94049 .56528 .93245 .55476 Metetra
.434 .685 0 r
.93245 .55476 .94049 .56528 .95397 .49611 .94601 .48416 Metetra
.038 .554 0 r
.34093 .60795 .35154 .61831 .36509 .69282 .35422 .68359 Metetra
.798 .699 0 r
.35422 .68359 .36509 .69282 .38123 .72545 .37027 .71709 Metetra
.895 .407 0 r
.37027 .71709 .38123 .72545 .39882 .73089 .3879 .7228 Metetra
.921 .315 0 r
.3879 .7228 .39882 .73089 .41689 .72838 .40604 .72029 Metetra
.929 .288 0 r
.40604 .72029 .41689 .72838 .43513 .72459 .42437 .71644 Metetra
.933 .271 0 r
.42437 .71644 .43513 .72459 .45352 .72057 .44284 .71237 Metetra
.937 .256 0 r
.44284 .71237 .45352 .72057 .47205 .71641 .46145 .70815 Metetra
.941 .242 0 r
.46145 .70815 .47205 .71641 .49071 .71212 .4802 .7038 Metetra
.944 .23 0 r
.4802 .7038 .49071 .71212 .50951 .70769 .49908 .69931 Metetra
.946 .22 0 r
.49908 .69931 .50951 .70769 .52845 .70312 .51811 .69468 Metetra
.949 .211 0 r
.51811 .69468 .52845 .70312 .54752 .69842 .53728 .68991 Metetra
.951 .204 0 r
.53728 .68991 .54752 .69842 .56674 .69357 .55659 .685 Metetra
.952 .198 0 r
.55659 .685 .56674 .69357 .58609 .68859 .57604 .67995 Metetra
.953 .194 0 r
.57604 .67995 .58609 .68859 .60558 .68347 .59562 .67476 Metetra
.954 .191 0 r
.59562 .67476 .60558 .68347 .6252 .6782 .61535 .66942 Metetra
.954 .19 0 r
.61535 .66942 .6252 .6782 .64496 .67279 .63521 .66395 Metetra
.954 .19 0 r
.63521 .66395 .64496 .67279 .66486 .66724 .65521 .65832 Metetra
.954 .192 0 r
.65521 .65832 .66486 .66724 .68489 .66154 .67535 .65256 Metetra
.953 .196 0 r
.67535 .65256 .68489 .66154 .70506 .6557 .69562 .64664 Metetra
.951 .201 0 r
.69562 .64664 .70506 .6557 .72536 .64971 .71604 .64058 Metetra
.95 .208 0 r
.71604 .64058 .72536 .64971 .7458 .64357 .73658 .63437 Metetra
.947 .216 0 r
.73658 .63437 .7458 .64357 .76637 .63729 .75727 .62801 Metetra
.945 .226 0 r
.75727 .62801 .76637 .63729 .78707 .63085 .77809 .6215 Metetra
.942 .237 0 r
.77809 .6215 .78707 .63085 .80791 .62426 .79904 .61483 Metetra
.939 .25 0 r
.79904 .61483 .80791 .62426 .82888 .61752 .82013 .60801 Metetra
.935 .264 0 r
.82013 .60801 .82888 .61752 .84998 .61062 .84135 .60103 Metetra
.931 .28 0 r
.84135 .60103 .84998 .61062 .8712 .60354 .8627 .59386 Metetra
.925 .3 0 r
.8627 .59386 .8712 .60354 .89252 .59589 .88414 .58611 Metetra
.911 .35 0 r
.88414 .58611 .89252 .59589 .91352 .58433 .90527 .5743 Metetra
.856 .535 0 r
.90527 .5743 .91352 .58433 .93245 .55476 .92429 .54397 Metetra
.435 .685 0 r
.92429 .54397 .93245 .55476 .94601 .48416 .93794 .47204 Metetra
.034 .553 0 r
.33019 .59754 .34093 .60795 .35422 .68359 .34322 .67421 Metetra
.8 .695 0 r
.34322 .67421 .35422 .68359 .37027 .71709 .35918 .70852 Metetra
.899 .393 0 r
.35918 .70852 .37027 .71709 .3879 .7228 .37684 .71447 Metetra
.926 .298 0 r
.37684 .71447 .3879 .7228 .40604 .72029 .39505 .71196 Metetra
.933 .27 0 r
.39505 .71196 .40604 .72029 .42437 .71644 .41346 .70806 Metetra
.938 .253 0 r
.41346 .70806 .42437 .71644 .44284 .71237 .43201 .70393 Metetra
.942 .238 0 r
.43201 .70393 .44284 .71237 .46145 .70815 .45071 .69965 Metetra
.945 .224 0 r
.45071 .69965 .46145 .70815 .4802 .7038 .46954 .69523 Metetra
.948 .212 0 r
.46954 .69523 .4802 .7038 .49908 .69931 .48852 .69068 Metetra
.951 .202 0 r
.48852 .69068 .49908 .69931 .51811 .69468 .50764 .68599 Metetra
.953 .193 0 r
.50764 .68599 .51811 .69468 .53728 .68991 .5269 .68115 Metetra
.955 .185 0 r
.5269 .68115 .53728 .68991 .55659 .685 .5463 .67618 Metetra
.957 .18 0 r
.5463 .67618 .55659 .685 .57604 .67995 .56584 .67106 Metetra
.958 .175 0 r
.56584 .67106 .57604 .67995 .59562 .67476 .58553 .6658 Metetra
.958 .172 0 r
.58553 .6658 .59562 .67476 .61535 .66942 .60535 .6604 Metetra
.959 .171 0 r
.60535 .6604 .61535 .66942 .63521 .66395 .62532 .65485 Metetra
.959 .172 0 r
.62532 .65485 .63521 .66395 .65521 .65832 .64542 .64915 Metetra
.958 .174 0 r
.64542 .64915 .65521 .65832 .67535 .65256 .66567 .64331 Metetra
.957 .177 0 r
.66567 .64331 .67535 .65256 .69562 .64664 .68605 .63733 Metetra
.956 .183 0 r
.68605 .63733 .69562 .64664 .71604 .64058 .70657 .63119 Metetra
.954 .189 0 r
.70657 .63119 .71604 .64058 .73658 .63437 .72723 .6249 Metetra
.952 .198 0 r
.72723 .6249 .73658 .63437 .75727 .62801 .74803 .61847 Metetra
.95 .207 0 r
.74803 .61847 .75727 .62801 .77809 .6215 .76897 .61187 Metetra
.947 .219 0 r
.76897 .61187 .77809 .6215 .79904 .61483 .79004 .60513 Metetra
.943 .232 0 r
.79004 .60513 .79904 .61483 .82013 .60801 .81125 .59823 Metetra
.94 .246 0 r
.81125 .59823 .82013 .60801 .84135 .60103 .83259 .59117 Metetra
.935 .262 0 r
.83259 .59117 .84135 .60103 .8627 .59386 .85407 .58392 Metetra
.93 .283 0 r
.85407 .58392 .8627 .59386 .88414 .58611 .87563 .57606 Metetra
.916 .335 0 r
.87563 .57606 .88414 .58611 .90527 .5743 .89688 .564 Metetra
.859 .526 0 r
.89688 .564 .90527 .5743 .92429 .54397 .916 .53297 Metetra
.435 .685 0 r
.916 .53297 .92429 .54397 .93794 .47204 .92976 .45979 Metetra
.031 .551 0 r
.31931 .58709 .33019 .59754 .34322 .67421 .33209 .6647 Metetra
.801 .69 0 r
.33209 .6647 .34322 .67421 .35918 .70852 .34795 .69974 Metetra
.903 .381 0 r
.34795 .69974 .35918 .70852 .37684 .71447 .36564 .70592 Metetra
.93 .283 0 r
.36564 .70592 .37684 .71447 .39505 .71196 .38392 .7034 Metetra
.937 .254 0 r
.38392 .7034 .39505 .71196 .41346 .70806 .40241 .69944 Metetra
.942 .237 0 r
.40241 .69944 .41346 .70806 .43201 .70393 .42105 .69524 Metetra
.946 .222 0 r
.42105 .69524 .43201 .70393 .45071 .69965 .43982 .69091 Metetra
.949 .208 0 r
.43982 .69091 .45071 .69965 .46954 .69523 .45875 .68643 Metetra
.952 .196 0 r
.45875 .68643 .46954 .69523 .48852 .69068 .47781 .68181 Metetra
.955 .186 0 r
.47781 .68181 .48852 .69068 .50764 .68599 .49702 .67705 Metetra
.957 .176 0 r
.49702 .67705 .50764 .68599 .5269 .68115 .51637 .67214 Metetra
.959 .169 0 r
.51637 .67214 .5269 .68115 .5463 .67618 .53587 .6671 Metetra
.961 .163 0 r
.53587 .6671 .5463 .67618 .56584 .67106 .55551 .66192 Metetra
.962 .159 0 r
.55551 .66192 .56584 .67106 .58553 .6658 .57529 .65659 Metetra
.963 .156 0 r
.57529 .65659 .58553 .6658 .60535 .6604 .59522 .65111 Metetra
.963 .155 0 r
.59522 .65111 .60535 .6604 .62532 .65485 .61528 .64549 Metetra
.963 .155 0 r
.61528 .64549 .62532 .65485 .64542 .64915 .63549 .63973 Metetra
.962 .157 0 r
.63549 .63973 .64542 .64915 .66567 .64331 .65584 .63381 Metetra
.961 .161 0 r
.65584 .63381 .66567 .64331 .68605 .63733 .67633 .62775 Metetra
.96 .166 0 r
.67633 .62775 .68605 .63733 .70657 .63119 .69697 .62154 Metetra
.958 .173 0 r
.69697 .62154 .70657 .63119 .72723 .6249 .71774 .61517 Metetra
.956 .181 0 r
.71774 .61517 .72723 .6249 .74803 .61847 .73865 .60865 Metetra
.954 .191 0 r
.73865 .60865 .74803 .61847 .76897 .61187 .75971 .60198 Metetra
.951 .203 0 r
.75971 .60198 .76897 .61187 .79004 .60513 .7809 .59515 Metetra
.947 .216 0 r
.7809 .59515 .79004 .60513 .81125 .59823 .80223 .58817 Metetra
.944 .23 0 r
.80223 .58817 .81125 .59823 .83259 .59117 .82369 .58103 Metetra
.94 .246 0 r
.82369 .58103 .83259 .59117 .85407 .58392 .84529 .57369 Metetra
.934 .267 0 r
.84529 .57369 .85407 .58392 .87563 .57606 .86698 .56573 Metetra
.92 .32 0 r
.86698 .56573 .87563 .57606 .89688 .564 .88835 .55343 Metetra
.861 .517 0 r
.88835 .55343 .89688 .564 .916 .53297 .90759 .52174 Metetra
.435 .685 0 r
.90759 .52174 .916 .53297 .92976 .45979 .92149 .44742 Metetra
.028 .55 0 r
.30831 .57659 .31931 .58709 .33209 .6647 .32081 .65505 Metetra
.803 .687 0 r
.32081 .65505 .33209 .6647 .34795 .69974 .33657 .69076 Metetra
.906 .37 0 r
.33657 .69076 .34795 .69974 .36564 .70592 .3543 .69713 Metetra
.933 .27 0 r
.3543 .69713 .36564 .70592 .38392 .7034 .37265 .69459 Metetra
.941 .24 0 r
.37265 .69459 .38392 .7034 .40241 .69944 .39122 .69058 Metetra
.946 .223 0 r
.39122 .69058 .40241 .69944 .42105 .69524 .40994 .68632 Metetra
.95 .208 0 r
.40994 .68632 .42105 .69524 .43982 .69091 .4288 .68191 Metetra
.953 .194 0 r
.4288 .68191 .43982 .69091 .45875 .68643 .44781 .67737 Metetra
.956 .182 0 r
.44781 .67737 .45875 .68643 .47781 .68181 .46696 .67268 Metetra
.959 .171 0 r
.46696 .67268 .47781 .68181 .49702 .67705 .48626 .66786 Metetra
.961 .162 0 r
.48626 .66786 .49702 .67705 .51637 .67214 .50571 .66289 Metetra
.963 .154 0 r
.50571 .66289 .51637 .67214 .53587 .6671 .5253 .65777 Metetra
.965 .148 0 r
.5253 .65777 .53587 .6671 .55551 .66192 .54503 .65252 Metetra
.966 .144 0 r
.54503 .65252 .55551 .66192 .57529 .65659 .56491 .64711 Metetra
.966 .141 0 r
.56491 .64711 .57529 .65659 .59522 .65111 .58494 .64157 Metetra
.967 .14 0 r
.58494 .64157 .59522 .65111 .61528 .64549 .60511 .63587 Metetra
.966 .14 0 r
.60511 .63587 .61528 .64549 .63549 .63973 .62542 .63003 Metetra
.966 .142 0 r
.62542 .63003 .63549 .63973 .65584 .63381 .64588 .62404 Metetra
.965 .146 0 r
.64588 .62404 .65584 .63381 .67633 .62775 .66648 .6179 Metetra
.964 .151 0 r
.66648 .6179 .67633 .62775 .69697 .62154 .68722 .61161 Metetra
.962 .158 0 r
.68722 .61161 .69697 .62154 .71774 .61517 .7081 .60517 Metetra
.96 .167 0 r
.7081 .60517 .71774 .61517 .73865 .60865 .72913 .59857 Metetra
.957 .177 0 r
.72913 .59857 .73865 .60865 .75971 .60198 .7503 .59182 Metetra
.955 .188 0 r
.7503 .59182 .75971 .60198 .7809 .59515 .77161 .58491 Metetra
.951 .201 0 r
.77161 .58491 .7809 .59515 .80223 .58817 .79306 .57784 Metetra
.947 .216 0 r
.79306 .57784 .80223 .58817 .82369 .58103 .81465 .57061 Metetra
.943 .232 0 r
.81465 .57061 .82369 .58103 .84529 .57369 .83638 .56318 Metetra
.938 .253 0 r
.83638 .56318 .84529 .57369 .86698 .56573 .8582 .55511 Metetra
.923 .308 0 r
.8582 .55511 .86698 .56573 .88835 .55343 .87969 .54259 Metetra
.864 .51 0 r
.87969 .54259 .88835 .55343 .90759 .52174 .89905 .51029 Metetra
.435 .685 0 r
.89905 .51029 .90759 .52174 .92149 .44742 .9131 .43492 Metetra
.025 .549 0 r
.29717 .56605 .30831 .57659 .32081 .65505 .3094 .64527 Metetra
.804 .683 0 r
.3094 .64527 .32081 .65505 .33657 .69076 .32506 .68156 Metetra
.908 .361 0 r
.32506 .68156 .33657 .69076 .3543 .69713 .34281 .6881 Metetra
.936 .258 0 r
.34281 .6881 .3543 .69713 .37265 .69459 .36123 .68554 Metetra
.944 .228 0 r
.36123 .68554 .37265 .69459 .39122 .69058 .37988 .68147 Metetra
.949 .21 0 r
.37988 .68147 .39122 .69058 .40994 .68632 .39868 .67714 Metetra
.953 .195 0 r
.39868 .67714 .40994 .68632 .4288 .68191 .41763 .67267 Metetra
.956 .181 0 r
.41763 .67267 .4288 .68191 .44781 .67737 .43672 .66806 Metetra
.959 .169 0 r
.43672 .66806 .44781 .67737 .46696 .67268 .45596 .66331 Metetra
.962 .158 0 r
.45596 .66331 .46696 .67268 .48626 .66786 .47535 .65841 Metetra
.964 .149 0 r
.47535 .65841 .48626 .66786 .50571 .66289 .49489 .65337 Metetra
.966 .141 0 r
.49489 .65337 .50571 .66289 .5253 .65777 .51458 .64819 Metetra
.968 .135 0 r
.51458 .64819 .5253 .65777 .54503 .65252 .53441 .64286 Metetra
.969 .131 0 r
.53441 .64286 .54503 .65252 .56491 .64711 .55439 .63738 Metetra
.969 .128 0 r
.55439 .63738 .56491 .64711 .58494 .64157 .57451 .63176 Metetra
.97 .127 0 r
.57451 .63176 .58494 .64157 .60511 .63587 .59478 .62599 Metetra
.97 .127 0 r
.59478 .62599 .60511 .63587 .62542 .63003 .6152 .62007 Metetra
.969 .13 0 r
.6152 .62007 .62542 .63003 .64588 .62404 .63576 .614 Metetra
.968 .133 0 r
.63576 .614 .64588 .62404 .66648 .6179 .65647 .60779 Metetra
.967 .139 0 r
.65647 .60779 .66648 .6179 .68722 .61161 .67733 .60141 Metetra
.965 .145 0 r
.67733 .60141 .68722 .61161 .7081 .60517 .69833 .59489 Metetra
.963 .154 0 r
.69833 .59489 .7081 .60517 .72913 .59857 .71947 .58821 Metetra
.961 .164 0 r
.71947 .58821 .72913 .59857 .7503 .59182 .74076 .58137 Metetra
.958 .176 0 r
.74076 .58137 .7503 .59182 .77161 .58491 .76219 .57437 Metetra
.954 .189 0 r
.76219 .57437 .77161 .58491 .79306 .57784 .78376 .56722 Metetra
.951 .203 0 r
.78376 .56722 .79306 .57784 .81465 .57061 .80547 .5599 Metetra
.946 .22 0 r
.80547 .5599 .81465 .57061 .83638 .56318 .82732 .55239 Metetra
.941 .241 0 r
.82732 .55239 .83638 .56318 .8582 .55511 .84927 .54421 Metetra
.926 .297 0 r
.84927 .54421 .8582 .55511 .87969 .54259 .87089 .53148 Metetra
.866 .503 0 r
.87089 .53148 .87969 .54259 .89905 .51029 .89039 .49861 Metetra
.435 .685 0 r
.89039 .49861 .89905 .51029 .9131 .43492 .90461 .4223 Metetra
.023 .548 0 r
.28589 .55546 .29717 .56605 .3094 .64527 .29784 .63536 Metetra
.805 .681 0 r
.29784 .63536 .3094 .64527 .32506 .68156 .31339 .67214 Metetra
.911 .353 0 r
.31339 .67214 .32506 .68156 .34281 .6881 .33117 .67882 Metetra
.939 .248 0 r
.33117 .67882 .34281 .6881 .36123 .68554 .34967 .67623 Metetra
.947 .218 0 r
.34967 .67623 .36123 .68554 .37988 .68147 .36839 .6721 Metetra
.952 .2 0 r
.36839 .6721 .37988 .68147 .39868 .67714 .38728 .66771 Metetra
.955 .184 0 r
.38728 .66771 .39868 .67714 .41763 .67267 .40631 .66317 Metetra
.959 .171 0 r
.40631 .66317 .41763 .67267 .43672 .66806 .42549 .65849 Metetra
.962 .158 0 r
.42549 .65849 .43672 .66806 .45596 .66331 .44482 .65367 Metetra
.965 .147 0 r
.44482 .65367 .45596 .66331 .47535 .65841 .4643 .6487 Metetra
.967 .138 0 r
.4643 .6487 .47535 .65841 .49489 .65337 .48393 .64359 Metetra
.969 .131 0 r
.48393 .64359 .49489 .65337 .51458 .64819 .50371 .63833 Metetra
.97 .125 0 r
.50371 .63833 .51458 .64819 .53441 .64286 .52364 .63293 Metetra
.971 .12 0 r
.52364 .63293 .53441 .64286 .55439 .63738 .54371 .62738 Metetra
.972 .117 0 r
.54371 .62738 .55439 .63738 .57451 .63176 .56394 .62168 Metetra
.972 .116 0 r
.56394 .62168 .57451 .63176 .59478 .62599 .58431 .61584 Metetra
.972 .117 0 r
.58431 .61584 .59478 .62599 .6152 .62007 .60484 .60984 Metetra
.972 .119 0 r
.60484 .60984 .6152 .62007 .63576 .614 .62551 .60369 Metetra
.971 .122 0 r
.62551 .60369 .63576 .614 .65647 .60779 .64632 .59739 Metetra
.97 .128 0 r
.64632 .59739 .65647 .60779 .67733 .60141 .66729 .59094 Metetra
.968 .135 0 r
.66729 .59094 .67733 .60141 .69833 .59489 .6884 .58433 Metetra
.966 .143 0 r
.6884 .58433 .69833 .59489 .71947 .58821 .70966 .57756 Metetra
.963 .153 0 r
.70966 .57756 .71947 .58821 .74076 .58137 .73106 .57064 Metetra
.96 .165 0 r
.73106 .57064 .74076 .58137 .76219 .57437 .75261 .56356 Metetra
.957 .178 0 r
.75261 .56356 .76219 .57437 .78376 .56722 .77431 .55631 Metetra
.953 .193 0 r
.77431 .55631 .78376 .56722 .80547 .5599 .79615 .5489 Metetra
.949 .209 0 r
.79615 .5489 .80547 .5599 .82732 .55239 .81812 .5413 Metetra
.944 .231 0 r
.81812 .5413 .82732 .55239 .84927 .54421 .8402 .53301 Metetra
.928 .288 0 r
.8402 .53301 .84927 .54421 .87089 .53148 .86195 .52008 Metetra
.868 .498 0 r
.86195 .52008 .87089 .53148 .89039 .49861 .88159 .48672 Metetra
.435 .685 0 r
.88159 .48672 .89039 .49861 .90461 .4223 .89601 .40955 Metetra
.021 .547 0 r
.27447 .54484 .28589 .55546 .29784 .63536 .28613 .62531 Metetra
.806 .679 0 r
.28613 .62531 .29784 .63536 .31339 .67214 .30158 .66251 Metetra
.912 .346 0 r
.30158 .66251 .31339 .67214 .33117 .67882 .31939 .6693 Metetra
.941 .24 0 r
.31939 .6693 .33117 .67882 .34967 .67623 .33796 .66668 Metetra
.949 .209 0 r
.33796 .66668 .34967 .67623 .36839 .6721 .35676 .66248 Metetra
.954 .191 0 r
.35676 .66248 .36839 .6721 .38728 .66771 .37572 .65802 Metetra
.958 .176 0 r
.37572 .65802 .38728 .66771 .40631 .66317 .39484 .65342 Metetra
.961 .162 0 r
.39484 .65342 .40631 .66317 .42549 .65849 .41411 .64867 Metetra
.964 .149 0 r
.41411 .64867 .42549 .65849 .44482 .65367 .43353 .64377 Metetra
.967 .139 0 r
.43353 .64377 .44482 .65367 .4643 .6487 .4531 .63873 Metetra
.969 .129 0 r
.4531 .63873 .4643 .6487 .48393 .64359 .47282 .63355 Metetra
.971 .122 0 r
.47282 .63355 .48393 .64359 .50371 .63833 .49269 .62822 Metetra
.973 .116 0 r
.49269 .62822 .50371 .63833 .52364 .63293 .51272 .62274 Metetra
.974 .111 0 r
.51272 .62274 .52364 .63293 .54371 .62738 .53289 .61711 Metetra
.974 .108 0 r
.53289 .61711 .54371 .62738 .56394 .62168 .55322 .61134 Metetra
.975 .107 0 r
.55322 .61134 .56394 .62168 .58431 .61584 .57369 .60541 Metetra
.975 .108 0 r
.57369 .60541 .58431 .61584 .60484 .60984 .59432 .59933 Metetra
.974 .11 0 r
.59432 .59933 .60484 .60984 .62551 .60369 .6151 .5931 Metetra
.973 .113 0 r
.6151 .5931 .62551 .60369 .64632 .59739 .63602 .58672 Metetra
.972 .119 0 r
.63602 .58672 .64632 .59739 .66729 .59094 .6571 .58018 Metetra
.97 .126 0 r
.6571 .58018 .66729 .59094 .6884 .58433 .67833 .57349 Metetra
.968 .134 0 r
.67833 .57349 .6884 .58433 .70966 .57756 .6997 .56663 Metetra
.966 .144 0 r
.6997 .56663 .70966 .57756 .73106 .57064 .72122 .55962 Metetra
.963 .156 0 r
.72122 .55962 .73106 .57064 .75261 .56356 .74289 .55245 Metetra
.959 .169 0 r
.74289 .55245 .75261 .56356 .77431 .55631 .76471 .54511 Metetra
.956 .184 0 r
.76471 .54511 .77431 .55631 .79615 .5489 .78667 .53761 Metetra
.951 .201 0 r
.78667 .53761 .79615 .5489 .81812 .5413 .80878 .52991 Metetra
.946 .222 0 r
.80878 .52991 .81812 .5413 .8402 .53301 .83098 .52152 Metetra
.93 .28 0 r
.83098 .52152 .8402 .53301 .86195 .52008 .85287 .5084 Metetra
.869 .494 0 r
.85287 .5084 .86195 .52008 .88159 .48672 .87267 .47459 Metetra
.434 .685 0 r
.87267 .47459 .88159 .48672 .89601 .40955 .88729 .39668 Metetra
.019 .547 0 r
.2629 .53417 .27447 .54484 .28613 .62531 .27428 .61512 Metetra
.806 .677 0 r
.27428 .61512 .28613 .62531 .30158 .66251 .28962 .65267 Metetra
.914 .341 0 r
.28962 .65267 .30158 .66251 .31939 .6693 .30745 .65953 Metetra
.943 .233 0 r
.30745 .65953 .31939 .6693 .33796 .66668 .32609 .65686 Metetra
.951 .202 0 r
.32609 .65686 .33796 .66668 .35676 .66248 .34498 .6526 Metetra
.955 .184 0 r
.34498 .6526 .35676 .66248 .37572 .65802 .36402 .64807 Metetra
.959 .169 0 r
.36402 .64807 .37572 .65802 .39484 .65342 .38322 .64339 Metetra
.963 .155 0 r
.38322 .64339 .39484 .65342 .41411 .64867 .40257 .63857 Metetra
.966 .143 0 r
.40257 .63857 .41411 .64867 .43353 .64377 .42208 .63361 Metetra
.969 .132 0 r
.42208 .63361 .43353 .64377 .4531 .63873 .44174 .62849 Metetra
.971 .122 0 r
.44174 .62849 .4531 .63873 .47282 .63355 .46156 .62323 Metetra
.973 .115 0 r
.46156 .62323 .47282 .63355 .49269 .62822 .48152 .61783 Metetra
.974 .109 0 r
.48152 .61783 .49269 .62822 .51272 .62274 .50164 .61227 Metetra
.975 .104 0 r
.50164 .61227 .51272 .62274 .53289 .61711 .52192 .60657 Metetra
.976 .101 0 r
.52192 .60657 .53289 .61711 .55322 .61134 .54234 .60071 Metetra
.976 .1 0 r
.54234 .60071 .55322 .61134 .57369 .60541 .56292 .5947 Metetra
.976 .101 0 r
.56292 .5947 .57369 .60541 .59432 .59933 .58366 .58854 Metetra
.976 .103 0 r
.58366 .58854 .59432 .59933 .6151 .5931 .60454 .58223 Metetra
.975 .106 0 r
.60454 .58223 .6151 .5931 .63602 .58672 .62558 .57576 Metetra
.974 .112 0 r
.62558 .57576 .63602 .58672 .6571 .58018 .64676 .56914 Metetra
.972 .119 0 r
.64676 .56914 .6571 .58018 .67833 .57349 .6681 .56235 Metetra
.97 .127 0 r
.6681 .56235 .67833 .57349 .6997 .56663 .68959 .55541 Metetra
.967 .137 0 r
.68959 .55541 .6997 .56663 .72122 .55962 .71123 .54831 Metetra
.964 .149 0 r
.71123 .54831 .72122 .55962 .74289 .55245 .73302 .54105 Metetra
.961 .162 0 r
.73302 .54105 .74289 .55245 .76471 .54511 .75496 .53362 Metetra
.957 .177 0 r
.75496 .53362 .76471 .54511 .78667 .53761 .77705 .52602 Metetra
.953 .194 0 r
.77705 .52602 .78667 .53761 .80878 .52991 .79928 .51823 Metetra
.947 .216 0 r
.79928 .51823 .80878 .52991 .83098 .52152 .82162 .50972 Metetra
.932 .274 0 r
.82162 .50972 .83098 .52152 .85287 .5084 .84364 .49644 Metetra
.87 .49 0 r
.84364 .49644 .85287 .5084 .87267 .47459 .8636 .46224 Metetra
.434 .685 0 r
.8636 .46224 .87267 .47459 .88729 .39668 .87846 .38369 Metetra
.018 .546 0 r
.25118 .52346 .2629 .53417 .27428 .61512 .26227 .60481 Metetra
.807 .676 0 r
.26227 .60481 .27428 .61512 .28962 .65267 .27751 .6426 Metetra
.915 .338 0 r
.27751 .6426 .28962 .65267 .30745 .65953 .29537 .6495 Metetra
.944 .229 0 r
.29537 .6495 .30745 .65953 .32609 .65686 .31408 .64679 Metetra
.952 .198 0 r
.31408 .64679 .32609 .65686 .34498 .6526 .33304 .64246 Metetra
.957 .18 0 r
.33304 .64246 .34498 .6526 .36402 .64807 .35217 .63786 Metetra
.961 .164 0 r
.35217 .63786 .36402 .64807 .38322 .64339 .37145 .63311 Metetra
.964 .15 0 r
.37145 .63311 .38322 .64339 .40257 .63857 .39089 .62821 Metetra
.967 .138 0 r
.39089 .62821 .40257 .63857 .42208 .63361 .41048 .62317 Metetra
.97 .127 0 r
.41048 .62317 .42208 .63361 .44174 .62849 .43023 .61798 Metetra
.972 .117 0 r
.43023 .61798 .44174 .62849 .46156 .62323 .45014 .61265 Metetra
.974 .11 0 r
.45014 .61265 .46156 .62323 .48152 .61783 .4702 .60716 Metetra
.976 .104 0 r
.4702 .60716 .48152 .61783 .50164 .61227 .49042 .60153 Metetra
.977 .099 0 r
.49042 .60153 .50164 .61227 .52192 .60657 .51079 .59574 Metetra
.977 .096 0 r
.51079 .59574 .52192 .60657 .54234 .60071 .53132 .5898 Metetra
.978 .095 0 r
.53132 .5898 .54234 .60071 .56292 .5947 .552 .58371 Metetra
.977 .096 0 r
.552 .58371 .56292 .5947 .58366 .58854 .57284 .57747 Metetra
.977 .098 0 r
.57284 .57747 .58366 .58854 .60454 .58223 .59383 .57107 Metetra
.976 .101 0 r
.59383 .57107 .60454 .58223 .62558 .57576 .61497 .56451 Metetra
.975 .107 0 r
.61497 .56451 .62558 .57576 .64676 .56914 .63627 .5578 Metetra
.973 .114 0 r
.63627 .5578 .64676 .56914 .6681 .56235 .65773 .55093 Metetra
.971 .122 0 r
.65773 .55093 .6681 .56235 .68959 .55541 .67933 .54389 Metetra
.968 .132 0 r
.67933 .54389 .68959 .55541 .71123 .54831 .70109 .5367 Metetra
.966 .144 0 r
.70109 .5367 .71123 .54831 .73302 .54105 .723 .52934 Metetra
.962 .158 0 r
.723 .52934 .73302 .54105 .75496 .53362 .74507 .52182 Metetra
.958 .172 0 r
.74507 .52182 .75496 .53362 .77705 .52602 .76728 .51412 Metetra
.954 .189 0 r
.76728 .51412 .77705 .52602 .79928 .51823 .78964 .50623 Metetra
.949 .211 0 r
.78964 .50623 .79928 .51823 .82162 .50972 .8121 .49762 Metetra
.933 .27 0 r
.8121 .49762 .82162 .50972 .84364 .49644 .83427 .48418 Metetra
.871 .488 0 r
.83427 .48418 .84364 .49644 .8636 .46224 .8544 .44966 Metetra
.434 .685 0 r
.8544 .44966 .8636 .46224 .87846 .38369 .86952 .37057 Metetra
.018 .546 0 r
.23931 .51271 .25118 .52346 .26227 .60481 .25011 .59435 Metetra
.807 .675 0 r
.25011 .59435 .26227 .60481 .27751 .6426 .26524 .63231 Metetra
.915 .336 0 r
.26524 .63231 .27751 .6426 .29537 .6495 .28313 .63922 Metetra
.945 .226 0 r
.28313 .63922 .29537 .6495 .31408 .64679 .30191 .63644 Metetra
.953 .195 0 r
.30191 .63644 .31408 .64679 .33304 .64246 .32095 .63204 Metetra
.957 .177 0 r
.32095 .63204 .33304 .64246 .35217 .63786 .34016 .62737 Metetra
.961 .161 0 r
.34016 .62737 .35217 .63786 .37145 .63311 .35953 .62255 Metetra
.965 .147 0 r
.35953 .62255 .37145 .63311 .39089 .62821 .37905 .61758 Metetra
.968 .135 0 r
.37905 .61758 .39089 .62821 .41048 .62317 .39873 .61246 Metetra
.971 .124 0 r
.39873 .61246 .41048 .62317 .43023 .61798 .41857 .6072 Metetra
.973 .114 0 r
.41857 .6072 .43023 .61798 .45014 .61265 .43857 .60178 Metetra
.975 .107 0 r
.43857 .60178 .45014 .61265 .4702 .60716 .45873 .59621 Metetra
.976 .101 0 r
.45873 .59621 .4702 .60716 .49042 .60153 .47904 .5905 Metetra
.977 .096 0 r
.47904 .5905 .49042 .60153 .51079 .59574 .49951 .58463 Metetra
.978 .093 0 r
.49951 .58463 .51079 .59574 .53132 .5898 .52014 .57861 Metetra
.978 .092 0 r
.52014 .57861 .53132 .5898 .552 .58371 .54092 .57243 Metetra
.978 .092 0 r
.54092 .57243 .552 .58371 .57284 .57747 .56186 .5661 Metetra
.978 .095 0 r
.56186 .5661 .57284 .57747 .59383 .57107 .58296 .55961 Metetra
.977 .098 0 r
.58296 .55961 .59383 .57107 .61497 .56451 .60422 .55297 Metetra
.975 .104 0 r
.60422 .55297 .61497 .56451 .63627 .5578 .62563 .54617 Metetra
.974 .111 0 r
.62563 .54617 .63627 .5578 .65773 .55093 .6472 .5392 Metetra
.972 .119 0 r
.6472 .5392 .65773 .55093 .67933 .54389 .66892 .53208 Metetra
.969 .129 0 r
.66892 .53208 .67933 .54389 .70109 .5367 .6908 .52479 Metetra
.966 .141 0 r
.6908 .52479 .70109 .5367 .723 .52934 .71283 .51733 Metetra
.963 .155 0 r
.71283 .51733 .723 .52934 .74507 .52182 .73501 .50971 Metetra
.959 .169 0 r
.73501 .50971 .74507 .52182 .76728 .51412 .75735 .50192 Metetra
.955 .186 0 r
.75735 .50192 .76728 .51412 .78964 .50623 .77984 .49392 Metetra
.949 .208 0 r
.77984 .49392 .78964 .50623 .8121 .49762 .80244 .48521 Metetra
.934 .268 0 r
.80244 .48521 .8121 .49762 .83427 .48418 .82475 .47162 Metetra
.871 .486 0 r
.82475 .47162 .83427 .48418 .8544 .44966 .84507 .43685 Metetra
.434 .685 0 r
.84507 .43685 .8544 .44966 .86952 .37057 .86045 .35732 Metetra
.018 .546 0 r
.22728 .50191 .23931 .51271 .25011 .59435 .23779 .58376 Metetra
.807 .675 0 r
.23779 .58376 .25011 .59435 .26524 .63231 .25282 .6218 Metetra
.916 .335 0 r
.25282 .6218 .26524 .63231 .28313 .63922 .27073 .62867 Metetra
.945 .225 0 r
.27073 .62867 .28313 .63922 .30191 .63644 .28958 .62583 Metetra
.953 .194 0 r
.28958 .62583 .30191 .63644 .32095 .63204 .3087 .62136 Metetra
.958 .176 0 r
.3087 .62136 .32095 .63204 .34016 .62737 .32799 .61661 Metetra
.962 .16 0 r
.32799 .61661 .34016 .62737 .35953 .62255 .34744 .61171 Metetra
.965 .146 0 r
.34744 .61171 .35953 .62255 .37905 .61758 .36705 .60667 Metetra
.968 .134 0 r
.36705 .60667 .37905 .61758 .39873 .61246 .38682 .60147 Metetra
.971 .123 0 r
.38682 .60147 .39873 .61246 .41857 .6072 .40675 .59613 Metetra
.973 .113 0 r
.40675 .59613 .41857 .6072 .43857 .60178 .42684 .59063 Metetra
.975 .106 0 r
.42684 .59063 .43857 .60178 .45873 .59621 .44709 .58498 Metetra
.976 .1 0 r
.44709 .58498 .45873 .59621 .47904 .5905 .4675 .57918 Metetra
.978 .095 0 r
.4675 .57918 .47904 .5905 .49951 .58463 .48807 .57323 Metetra
.978 .092 0 r
.48807 .57323 .49951 .58463 .52014 .57861 .5088 .56712 Metetra
.979 .091 0 r
.5088 .56712 .52014 .57861 .54092 .57243 .52969 .56086 Metetra
.978 .092 0 r
.52969 .56086 .54092 .57243 .56186 .5661 .55073 .55444 Metetra
.978 .094 0 r
.55073 .55444 .56186 .5661 .58296 .55961 .57194 .54786 Metetra
.977 .097 0 r
.57194 .54786 .58296 .55961 .60422 .55297 .59331 .54113 Metetra
.976 .103 0 r
.59331 .54113 .60422 .55297 .62563 .54617 .61483 .53423 Metetra
.974 .11 0 r
.61483 .53423 .62563 .54617 .6472 .5392 .63651 .52717 Metetra
.972 .118 0 r
.63651 .52717 .6472 .5392 .66892 .53208 .65835 .51995 Metetra
.969 .129 0 r
.65835 .51995 .66892 .53208 .6908 .52479 .68035 .51256 Metetra
.966 .14 0 r
.68035 .51256 .6908 .52479 .71283 .51733 .7025 .50501 Metetra
.963 .154 0 r
.7025 .50501 .71283 .51733 .73501 .50971 .72481 .49729 Metetra
.959 .169 0 r
.72481 .49729 .73501 .50971 .75735 .50192 .74727 .48939 Metetra
.955 .185 0 r
.74727 .48939 .75735 .50192 .77984 .49392 .76989 .48129 Metetra
.95 .207 0 r
.76989 .48129 .77984 .49392 .80244 .48521 .79262 .47247 Metetra
.934 .267 0 r
.79262 .47247 .80244 .48521 .82475 .47162 .81507 .45876 Metetra
.871 .486 0 r
.81507 .45876 .82475 .47162 .84507 .43685 .83558 .42379 Metetra
.434 .685 0 r
.83558 .42379 .84507 .43685 .86045 .35732 .85125 .34393 Metetra
.018 .546 0 r
.21508 .49106 .22728 .50191 .23779 .58376 .22531 .57303 Metetra
.807 .675 0 r
.22531 .57303 .23779 .58376 .25282 .6218 .24023 .61105 Metetra
.915 .336 0 r
.24023 .61105 .25282 .6218 .27073 .62867 .25818 .61785 Metetra
.945 .226 0 r
.25818 .61785 .27073 .62867 .28958 .62583 .2771 .61494 Metetra
.953 .195 0 r
.2771 .61494 .28958 .62583 .3087 .62136 .2963 .61039 Metetra
.957 .177 0 r
.2963 .61039 .3087 .62136 .32799 .61661 .31567 .60557 Metetra
.961 .161 0 r
.31567 .60557 .32799 .61661 .34744 .61171 .3352 .6006 Metetra
.965 .147 0 r
.3352 .6006 .34744 .61171 .36705 .60667 .3549 .59547 Metetra
.968 .135 0 r
.3549 .59547 .36705 .60667 .38682 .60147 .37476 .5902 Metetra
.971 .124 0 r
.37476 .5902 .38682 .60147 .40675 .59613 .39478 .58477 Metetra
.973 .114 0 r
.39478 .58477 .40675 .59613 .42684 .59063 .41496 .57919 Metetra
.975 .107 0 r
.41496 .57919 .42684 .59063 .44709 .58498 .4353 .57346 Metetra
.976 .101 0 r
.4353 .57346 .44709 .58498 .4675 .57918 .45581 .56758 Metetra
.977 .096 0 r
.45581 .56758 .4675 .57918 .48807 .57323 .47647 .56154 Metetra
.978 .093 0 r
.47647 .56154 .48807 .57323 .5088 .56712 .4973 .55534 Metetra
.978 .092 0 r
.4973 .55534 .5088 .56712 .52969 .56086 .51829 .54899 Metetra
.978 .093 0 r
.51829 .54899 .52969 .56086 .55073 .55444 .53945 .54248 Metetra
.978 .095 0 r
.53945 .54248 .55073 .55444 .57194 .54786 .56076 .53581 Metetra
.977 .098 0 r
.56076 .53581 .57194 .54786 .59331 .54113 .58223 .52898 Metetra
.975 .104 0 r
.58223 .52898 .59331 .54113 .61483 .53423 .60387 .52199 Metetra
.974 .111 0 r
.60387 .52199 .61483 .53423 .63651 .52717 .62567 .51483 Metetra
.972 .119 0 r
.62567 .51483 .63651 .52717 .65835 .51995 .64762 .50751 Metetra
.969 .13 0 r
.64762 .50751 .65835 .51995 .68035 .51256 .66974 .50003 Metetra
.966 .141 0 r
.66974 .50003 .68035 .51256 .7025 .50501 .69201 .49237 Metetra
.963 .155 0 r
.69201 .49237 .7025 .50501 .72481 .49729 .71445 .48454 Metetra
.959 .17 0 r
.71445 .48454 .72481 .49729 .74727 .48939 .73704 .47655 Metetra
.955 .186 0 r
.73704 .47655 .74727 .48939 .76989 .48129 .75978 .46834 Metetra
.949 .208 0 r
.75978 .46834 .76989 .48129 .79262 .47247 .78264 .45941 Metetra
.934 .268 0 r
.78264 .45941 .79262 .47247 .81507 .45876 .80524 .4456 Metetra
.871 .486 0 r
.80524 .4456 .81507 .45876 .83558 .42379 .82596 .4105 Metetra
.434 .685 0 r
.82596 .4105 .83558 .42379 .85125 .34393 .84193 .33042 Metetra
.018 .546 0 r
.20272 .48017 .21508 .49106 .22531 .57303 .21266 .56215 Metetra
.807 .676 0 r
.21266 .56215 .22531 .57303 .24023 .61105 .22749 .60007 Metetra
.915 .338 0 r
.22749 .60007 .24023 .61105 .25818 .61785 .24547 .60677 Metetra
.944 .229 0 r
.24547 .60677 .25818 .61785 .2771 .61494 .26446 .60377 Metetra
.952 .198 0 r
.26446 .60377 .2771 .61494 .2963 .61039 .28374 .59915 Metetra
.957 .18 0 r
.28374 .59915 .2963 .61039 .31567 .60557 .30319 .59425 Metetra
.961 .164 0 r
.30319 .59425 .31567 .60557 .3352 .6006 .32281 .5892 Metetra
.964 .15 0 r
.32281 .5892 .3352 .6006 .3549 .59547 .34259 .58399 Metetra
.967 .138 0 r
.34259 .58399 .3549 .59547 .37476 .5902 .36253 .57863 Metetra
.97 .127 0 r
.36253 .57863 .37476 .5902 .39478 .58477 .38264 .57312 Metetra
.972 .118 0 r
.38264 .57312 .39478 .58477 .41496 .57919 .40291 .56746 Metetra
.974 .11 0 r
.40291 .56746 .41496 .57919 .4353 .57346 .42335 .56165 Metetra
.975 .104 0 r
.42335 .56165 .4353 .57346 .45581 .56758 .44395 .55567 Metetra
.977 .099 0 r
.44395 .55567 .45581 .56758 .47647 .56154 .46472 .54954 Metetra
.977 .096 0 r
.46472 .54954 .47647 .56154 .4973 .55534 .48565 .54326 Metetra
.978 .095 0 r
.48565 .54326 .4973 .55534 .51829 .54899 .50674 .53682 Metetra
.977 .096 0 r
.50674 .53682 .51829 .54899 .53945 .54248 .528 .53021 Metetra
.977 .098 0 r
.528 .53021 .53945 .54248 .56076 .53581 .54942 .52345 Metetra
.976 .101 0 r
.54942 .52345 .56076 .53581 .58223 .52898 .571 .51652 Metetra
.975 .107 0 r
.571 .51652 .58223 .52898 .60387 .52199 .59275 .50943 Metetra
.973 .114 0 r
.59275 .50943 .60387 .52199 .62567 .51483 .61466 .50218 Metetra
.971 .122 0 r
.61466 .50218 .62567 .51483 .64762 .50751 .63673 .49476 Metetra
.968 .133 0 r
.63673 .49476 .64762 .50751 .66974 .50003 .65897 .48717 Metetra
.965 .144 0 r
.65897 .48717 .66974 .50003 .69201 .49237 .68137 .47941 Metetra
.962 .158 0 r
.68137 .47941 .69201 .49237 .71445 .48454 .70392 .47148 Metetra
.958 .173 0 r
.70392 .47148 .71445 .48454 .73704 .47655 .72664 .46337 Metetra
.954 .189 0 r
.72664 .46337 .73704 .47655 .75978 .46834 .74952 .45506 Metetra
.949 .211 0 r
.74952 .45506 .75978 .46834 .78264 .45941 .77251 .44602 Metetra
.933 .27 0 r
.77251 .44602 .78264 .45941 .80524 .4456 .79526 .43212 Metetra
.871 .488 0 r
.79526 .43212 .80524 .4456 .82596 .4105 .81619 .39695 Metetra
.434 .685 0 r
.81619 .39695 .82596 .4105 .84193 .33042 .83248 .31676 Metetra
.02 .547 0 r
.19019 .46922 .20272 .48017 .21266 .56215 .19984 .55113 Metetra
.806 .677 0 r
.19984 .55113 .21266 .56215 .22749 .60007 .21459 .58885 Metetra
.914 .342 0 r
.21459 .58885 .22749 .60007 .24547 .60677 .2326 .59541 Metetra
.943 .233 0 r
.2326 .59541 .24547 .60677 .26446 .60377 .25166 .59232 Metetra
.951 .203 0 r
.25166 .59232 .26446 .60377 .28374 .59915 .27102 .58762 Metetra
.955 .185 0 r
.27102 .58762 .28374 .59915 .30319 .59425 .29055 .58264 Metetra
.959 .169 0 r
.29055 .58264 .30319 .59425 .32281 .5892 .31025 .57751 Metetra
.963 .155 0 r
.31025 .57751 .32281 .5892 .34259 .58399 .33011 .57222 Metetra
.966 .143 0 r
.33011 .57222 .34259 .58399 .36253 .57863 .35014 .56678 Metetra
.969 .132 0 r
.35014 .56678 .36253 .57863 .38264 .57312 .37034 .56118 Metetra
.971 .123 0 r
.37034 .56118 .38264 .57312 .40291 .56746 .3907 .55543 Metetra
.973 .115 0 r
.3907 .55543 .40291 .56746 .42335 .56165 .41123 .54953 Metetra
.974 .109 0 r
.41123 .54953 .42335 .56165 .44395 .55567 .43193 .54347 Metetra
.975 .104 0 r
.43193 .54347 .44395 .55567 .46472 .54954 .4528 .53725 Metetra
.976 .101 0 r
.4528 .53725 .46472 .54954 .48565 .54326 .47383 .53087 Metetra
.976 .1 0 r
.47383 .53087 .48565 .54326 .50674 .53682 .49502 .52433 Metetra
.976 .101 0 r
.49502 .52433 .50674 .53682 .528 .53021 .51638 .51764 Metetra
.976 .103 0 r
.51638 .51764 .528 .53021 .54942 .52345 .53791 .51078 Metetra
.975 .107 0 r
.53791 .51078 .54942 .52345 .571 .51652 .55961 .50375 Metetra
.973 .112 0 r
.55961 .50375 .571 .51652 .59275 .50943 .58147 .49656 Metetra
.972 .119 0 r
.58147 .49656 .59275 .50943 .61466 .50218 .60349 .48921 Metetra
.97 .127 0 r
.60349 .48921 .61466 .50218 .63673 .49476 .62568 .48168 Metetra
.967 .138 0 r
.62568 .48168 .63673 .49476 .65897 .48717 .64804 .47399 Metetra
.964 .149 0 r
.64804 .47399 .65897 .48717 .68137 .47941 .67056 .46612 Metetra
.961 .163 0 r
.67056 .46612 .68137 .47941 .70392 .47148 .69324 .45808 Metetra
.957 .177 0 r
.69324 .45808 .70392 .47148 .72664 .46337 .71608 .44987 Metetra
.953 .194 0 r
.71608 .44987 .72664 .46337 .74952 .45506 .73909 .44144 Metetra
.947 .216 0 r
.73909 .44144 .74952 .45506 .77251 .44602 .76221 .4323 Metetra
.932 .275 0 r
.76221 .4323 .77251 .44602 .79526 .43212 .78512 .41832 Metetra
.87 .49 0 r
.78512 .41832 .79526 .43212 .81619 .39695 .80626 .38315 Metetra
.434 .685 0 r
.80626 .38315 .81619 .39695 .83248 .31676 .82289 .30296 Metetra
.021 .547 0 r
.17749 .45822 .19019 .46922 .19984 .55113 .18686 .53995 Metetra
.806 .679 0 r
.18686 .53995 .19984 .55113 .21459 .58885 .20151 .57739 Metetra
.912 .347 0 r
.20151 .57739 .21459 .58885 .2326 .59541 .21957 .58377 Metetra
.941 .24 0 r
.21957 .58377 .2326 .59541 .25166 .59232 .2387 .58059 Metetra
.949 .209 0 r
.2387 .58059 .25166 .59232 .27102 .58762 .25813 .5758 Metetra
.954 .192 0 r
.25813 .5758 .27102 .58762 .29055 .58264 .27774 .57074 Metetra
.958 .176 0 r
.27774 .57074 .29055 .58264 .31025 .57751 .29752 .56552 Metetra
.961 .162 0 r
.29752 .56552 .31025 .57751 .33011 .57222 .31747 .56015 Metetra
.964 .15 0 r
.31747 .56015 .33011 .57222 .35014 .56678 .33759 .55462 Metetra
.967 .139 0 r
.33759 .55462 .35014 .56678 .37034 .56118 .35788 .54894 Metetra
.969 .13 0 r
.35788 .54894 .37034 .56118 .3907 .55543 .37833 .54311 Metetra
.971 .122 0 r
.37833 .54311 .3907 .55543 .41123 .54953 .39895 .53711 Metetra
.973 .116 0 r
.39895 .53711 .41123 .54953 .43193 .54347 .41975 .53096 Metetra
.974 .111 0 r
.41975 .53096 .43193 .54347 .4528 .53725 .44071 .52465 Metetra
.974 .109 0 r
.44071 .52465 .4528 .53725 .47383 .53087 .46184 .51817 Metetra
.975 .107 0 r
.46184 .51817 .47383 .53087 .49502 .52433 .48314 .51154 Metetra
.974 .108 0 r
.48314 .51154 .49502 .52433 .51638 .51764 .50461 .50474 Metetra
.974 .11 0 r
.50461 .50474 .51638 .51764 .53791 .51078 .52624 .49778 Metetra
.973 .114 0 r
.52624 .49778 .53791 .51078 .55961 .50375 .54805 .49066 Metetra
.972 .119 0 r
.54805 .49066 .55961 .50375 .58147 .49656 .57002 .48337 Metetra
.97 .126 0 r
.57002 .48337 .58147 .49656 .60349 .48921 .59216 .47591 Metetra
.968 .134 0 r
.59216 .47591 .60349 .48921 .62568 .48168 .61447 .46828 Metetra
.965 .145 0 r
.61447 .46828 .62568 .48168 .64804 .47399 .63694 .46048 Metetra
.963 .156 0 r
.63694 .46048 .64804 .47399 .67056 .46612 .65958 .4525 Metetra
.959 .17 0 r
.65958 .4525 .67056 .46612 .69324 .45808 .68239 .44435 Metetra
.955 .184 0 r
.68239 .44435 .69324 .45808 .71608 .44987 .70536 .43603 Metetra
.951 .201 0 r
.70536 .43603 .71608 .44987 .73909 .44144 .7285 .42749 Metetra
.946 .223 0 r
.7285 .42749 .73909 .44144 .76221 .4323 .75176 .41824 Metetra
.93 .281 0 r
.75176 .41824 .76221 .4323 .78512 .41832 .77482 .40419 Metetra
.869 .494 0 r
.77482 .40419 .78512 .41832 .80626 .38315 .79619 .36909 Metetra
.434 .685 0 r
.79619 .36909 .80626 .38315 .82289 .30296 .81317 .28901 Metetra
.023 .548 0 r
.16461 .44716 .17749 .45822 .18686 .53995 .1737 .52861 Metetra
.805 .681 0 r
.1737 .52861 .18686 .53995 .20151 .57739 .18828 .56567 Metetra
.91 .353 0 r
.18828 .56567 .20151 .57739 .21957 .58377 .20637 .57185 Metetra
.939 .248 0 r
.20637 .57185 .21957 .58377 .2387 .58059 .22557 .56856 Metetra
.947 .218 0 r
.22557 .56856 .2387 .58059 .25813 .5758 .24508 .56369 Metetra
.951 .2 0 r
.24508 .56369 .25813 .5758 .27774 .57074 .26477 .55854 Metetra
.955 .185 0 r
.26477 .55854 .27774 .57074 .29752 .56552 .28463 .55324 Metetra
.959 .171 0 r
.28463 .55324 .29752 .56552 .31747 .56015 .30467 .54778 Metetra
.962 .159 0 r
.30467 .54778 .31747 .56015 .33759 .55462 .32487 .54217 Metetra
.965 .148 0 r
.32487 .54217 .33759 .55462 .35788 .54894 .34525 .5364 Metetra
.967 .139 0 r
.34525 .5364 .35788 .54894 .37833 .54311 .36579 .53047 Metetra
.969 .131 0 r
.36579 .53047 .37833 .54311 .39895 .53711 .38651 .52438 Metetra
.97 .125 0 r
.38651 .52438 .39895 .53711 .41975 .53096 .4074 .51814 Metetra
.971 .12 0 r
.4074 .51814 .41975 .53096 .44071 .52465 .42846 .51173 Metetra
.972 .118 0 r
.42846 .51173 .44071 .52465 .46184 .51817 .44969 .50516 Metetra
.972 .116 0 r
.44969 .50516 .46184 .51817 .48314 .51154 .47109 .49843 Metetra
.972 .117 0 r
.47109 .49843 .48314 .51154 .50461 .50474 .49266 .49153 Metetra
.972 .119 0 r
.49266 .49153 .50461 .50474 .52624 .49778 .51441 .48447 Metetra
.971 .123 0 r
.51441 .48447 .52624 .49778 .54805 .49066 .53632 .47724 Metetra
.97 .128 0 r
.53632 .47724 .54805 .49066 .57002 .48337 .55841 .46984 Metetra
.968 .135 0 r
.55841 .46984 .57002 .48337 .59216 .47591 .58066 .46228 Metetra
.966 .143 0 r
.58066 .46228 .59216 .47591 .61447 .46828 .60309 .45454 Metetra
.963 .154 0 r
.60309 .45454 .61447 .46828 .63694 .46048 .62568 .44663 Metetra
.96 .165 0 r
.62568 .44663 .63694 .46048 .65958 .4525 .64844 .43854 Metetra
.957 .178 0 r
.64844 .43854 .65958 .4525 .68239 .44435 .67138 .43028 Metetra
.953 .193 0 r
.67138 .43028 .68239 .44435 .70536 .43603 .69448 .42184 Metetra
.949 .21 0 r
.69448 .42184 .70536 .43603 .7285 .42749 .71774 .41318 Metetra
.943 .231 0 r
.71774 .41318 .7285 .42749 .75176 .41824 .74114 .40383 Metetra
.928 .288 0 r
.74114 .40383 .75176 .41824 .77482 .40419 .76435 .38973 Metetra
.867 .498 0 r
.76435 .38973 .77482 .40419 .79619 .36909 .78595 .35476 Metetra
.435 .685 0 r
.78595 .35476 .79619 .36909 .81317 .28901 .8033 .2749 Metetra
.025 .549 0 r
.15154 .43604 .16461 .44716 .1737 .52861 .16036 .51711 Metetra
.804 .683 0 r
.16036 .51711 .1737 .52861 .18828 .56567 .17487 .55371 Metetra
.908 .361 0 r
.17487 .55371 .18828 .56567 .20637 .57185 .193 .55964 Metetra
.936 .258 0 r
.193 .55964 .20637 .57185 .22557 .56856 .21228 .55623 Metetra
.944 .229 0 r
.21228 .55623 .22557 .56856 .24508 .56369 .23186 .55127 Metetra
.949 .211 0 r
.23186 .55127 .24508 .56369 .26477 .55854 .25163 .54604 Metetra
.953 .196 0 r
.25163 .54604 .26477 .55854 .28463 .55324 .27158 .54065 Metetra
.956 .182 0 r
.27158 .54065 .28463 .55324 .30467 .54778 .29169 .53511 Metetra
.959 .169 0 r
.29169 .53511 .30467 .54778 .32487 .54217 .31198 .5294 Metetra
.962 .159 0 r
.31198 .5294 .32487 .54217 .34525 .5364 .33245 .52354 Metetra
.964 .149 0 r
.33245 .52354 .34525 .5364 .36579 .53047 .35308 .51752 Metetra
.966 .142 0 r
.35308 .51752 .36579 .53047 .38651 .52438 .37389 .51134 Metetra
.968 .136 0 r
.37389 .51134 .38651 .52438 .4074 .51814 .39488 .505 Metetra
.969 .131 0 r
.39488 .505 .4074 .51814 .42846 .51173 .41604 .49849 Metetra
.969 .129 0 r
.41604 .49849 .42846 .51173 .44969 .50516 .43737 .49182 Metetra
.97 .127 0 r
.43737 .49182 .44969 .50516 .47109 .49843 .45887 .48499 Metetra
.97 .128 0 r
.45887 .48499 .47109 .49843 .49266 .49153 .48055 .47799 Metetra
.969 .13 0 r
.48055 .47799 .49266 .49153 .51441 .48447 .5024 .47083 Metetra
.968 .134 0 r
.5024 .47083 .51441 .48447 .53632 .47724 .52443 .46349 Metetra
.967 .139 0 r
.52443 .46349 .53632 .47724 .55841 .46984 .54662 .45599 Metetra
.965 .146 0 r
.54662 .45599 .55841 .46984 .58066 .46228 .56899 .44831 Metetra
.963 .154 0 r
.56899 .44831 .58066 .46228 .60309 .45454 .59154 .44046 Metetra
.961 .164 0 r
.59154 .44046 .60309 .45454 .62568 .44663 .61425 .43244 Metetra
.958 .176 0 r
.61425 .43244 .62568 .44663 .64844 .43854 .63714 .42424 Metetra
.954 .189 0 r
.63714 .42424 .64844 .43854 .67138 .43028 .66019 .41586 Metetra
.951 .204 0 r
.66019 .41586 .67138 .43028 .69448 .42184 .68342 .4073 Metetra
.946 .22 0 r
.68342 .4073 .69448 .42184 .71774 .41318 .70682 .39853 Metetra
.941 .242 0 r
.70682 .39853 .71774 .41318 .74114 .40383 .73035 .38906 Metetra
.926 .297 0 r
.73035 .38906 .74114 .40383 .76435 .38973 .75372 .37494 Metetra
.866 .504 0 r
.75372 .37494 .76435 .38973 .78595 .35476 .77556 .34016 Metetra
.435 .685 0 r
.77556 .34016 .78595 .35476 .8033 .2749 .79329 .26062 Metetra
.028 .55 0 r
.13829 .42486 .15154 .43604 .16036 .51711 .14684 .50544 Metetra
.803 .687 0 r
.14684 .50544 .16036 .51711 .17487 .55371 .16129 .54148 Metetra
.906 .371 0 r
.16129 .54148 .17487 .55371 .193 .55964 .17947 .54713 Metetra
.933 .27 0 r
.17947 .54713 .193 .55964 .21228 .55623 .19882 .5436 Metetra
.941 .241 0 r
.19882 .5436 .21228 .55623 .23186 .55127 .21848 .53855 Metetra
.945 .223 0 r
.21848 .53855 .23186 .55127 .25163 .54604 .23833 .53323 Metetra
.949 .208 0 r
.23833 .53323 .25163 .54604 .27158 .54065 .25835 .52776 Metetra
.953 .194 0 r
.25835 .52776 .27158 .54065 .29169 .53511 .27855 .52212 Metetra
.956 .182 0 r
.27855 .52212 .29169 .53511 .31198 .5294 .29893 .51633 Metetra
.959 .171 0 r
.29893 .51633 .31198 .5294 .33245 .52354 .31948 .51037 Metetra
.961 .162 0 r
.31948 .51037 .33245 .52354 .35308 .51752 .34021 .50425 Metetra
.963 .155 0 r
.34021 .50425 .35308 .51752 .37389 .51134 .36111 .49798 Metetra
.964 .149 0 r
.36111 .49798 .37389 .51134 .39488 .505 .38219 .49154 Metetra
.965 .144 0 r
.38219 .49154 .39488 .505 .41604 .49849 .40344 .48493 Metetra
.966 .142 0 r
.40344 .48493 .41604 .49849 .43737 .49182 .42488 .47816 Metetra
.966 .14 0 r
.42488 .47816 .43737 .49182 .45887 .48499 .44648 .47123 Metetra
.966 .141 0 r
.44648 .47123 .45887 .48499 .48055 .47799 .46827 .46412 Metetra
.966 .143 0 r
.46827 .46412 .48055 .47799 .5024 .47083 .49022 .45685 Metetra
.965 .147 0 r
.49022 .45685 .5024 .47083 .52443 .46349 .51236 .44941 Metetra
.964 .152 0 r
.51236 .44941 .52443 .46349 .54662 .45599 .53467 .44179 Metetra
.962 .159 0 r
.53467 .44179 .54662 .45599 .56899 .44831 .55715 .43401 Metetra
.96 .167 0 r
.55715 .43401 .56899 .44831 .59154 .44046 .57981 .42604 Metetra
.957 .177 0 r
.57981 .42604 .59154 .44046 .61425 .43244 .60265 .4179 Metetra
.954 .189 0 r
.60265 .4179 .61425 .43244 .63714 .42424 .62566 .40959 Metetra
.951 .202 0 r
.62566 .40959 .63714 .42424 .66019 .41586 .64884 .40109 Metetra
.947 .216 0 r
.64884 .40109 .66019 .41586 .68342 .4073 .67219 .39241 Metetra
.943 .233 0 r
.67219 .39241 .68342 .4073 .70682 .39853 .69572 .38351 Metetra
.938 .254 0 r
.69572 .38351 .70682 .39853 .73035 .38906 .71939 .37394 Metetra
.923 .308 0 r
.71939 .37394 .73035 .38906 .75372 .37494 .74292 .3598 Metetra
.864 .51 0 r
.74292 .3598 .75372 .37494 .77556 .34016 .765 .32527 Metetra
.435 .685 0 r
.765 .32527 .77556 .34016 .79329 .26062 .78313 .24618 Metetra
.031 .551 0 r
.12484 .4136 .13829 .42486 .14684 .50544 .13314 .4936 Metetra
.801 .69 0 r
.13314 .4936 .14684 .50544 .16129 .54148 .14754 .52899 Metetra
.902 .382 0 r
.14754 .52899 .16129 .54148 .17947 .54713 .16577 .53432 Metetra
.93 .284 0 r
.16577 .53432 .17947 .54713 .19882 .5436 .18519 .53067 Metetra
.937 .255 0 r
.18519 .53067 .19882 .5436 .21848 .53855 .20493 .52553 Metetra
.942 .238 0 r
.20493 .52553 .21848 .53855 .23833 .53323 .22485 .52012 Metetra
.946 .222 0 r
.22485 .52012 .23833 .53323 .25835 .52776 .24496 .51455 Metetra
.949 .209 0 r
.24496 .51455 .25835 .52776 .27855 .52212 .26524 .50882 Metetra
.952 .197 0 r
.26524 .50882 .27855 .52212 .29893 .51633 .2857 .50293 Metetra
.955 .186 0 r
.2857 .50293 .29893 .51633 .31948 .51037 .30634 .49688 Metetra
.957 .177 0 r
.30634 .49688 .31948 .51037 .34021 .50425 .32716 .49067 Metetra
.959 .169 0 r
.32716 .49067 .34021 .50425 .36111 .49798 .34815 .48429 Metetra
.961 .164 0 r
.34815 .48429 .36111 .49798 .38219 .49154 .36933 .47775 Metetra
.962 .159 0 r
.36933 .47775 .38219 .49154 .40344 .48493 .39068 .47104 Metetra
.962 .156 0 r
.39068 .47104 .40344 .48493 .42488 .47816 .41221 .46417 Metetra
.963 .155 0 r
.41221 .46417 .42488 .47816 .44648 .47123 .43392 .45713 Metetra
.963 .156 0 r
.43392 .45713 .44648 .47123 .46827 .46412 .45581 .44992 Metetra
.962 .158 0 r
.45581 .44992 .46827 .46412 .49022 .45685 .47787 .44253 Metetra
.961 .161 0 r
.47787 .44253 .49022 .45685 .51236 .44941 .50012 .43498 Metetra
.96 .167 0 r
.50012 .43498 .51236 .44941 .53467 .44179 .52254 .42725 Metetra
.958 .173 0 r
.52254 .42725 .53467 .44179 .55715 .43401 .54514 .41935 Metetra
.956 .182 0 r
.54514 .41935 .55715 .43401 .57981 .42604 .56792 .41127 Metetra
.954 .192 0 r
.56792 .41127 .57981 .42604 .60265 .4179 .59087 .40301 Metetra
.951 .203 0 r
.59087 .40301 .60265 .4179 .62566 .40959 .61401 .39458 Metetra
.947 .216 0 r
.61401 .39458 .62566 .40959 .64884 .40109 .63731 .38596 Metetra
.944 .231 0 r
.63731 .38596 .64884 .40109 .67219 .39241 .6608 .37715 Metetra
.939 .247 0 r
.6608 .37715 .67219 .39241 .69572 .38351 .68445 .36813 Metetra
.934 .268 0 r
.68445 .36813 .69572 .38351 .71939 .37394 .70826 .35845 Metetra
.919 .321 0 r
.70826 .35845 .71939 .37394 .74292 .3598 .73195 .3443 Metetra
.861 .517 0 r
.73195 .3443 .74292 .3598 .765 .32527 .75428 .31009 Metetra
.435 .685 0 r
.75428 .31009 .765 .32527 .78313 .24618 .77281 .23155 Metetra
.034 .553 0 r
.1112 .40226 .12484 .4136 .13314 .4936 .11925 .48156 Metetra
.799 .695 0 r
.11925 .48156 .13314 .4936 .14754 .52899 .13362 .51622 Metetra
.899 .394 0 r
.13362 .51622 .14754 .52899 .16577 .53432 .1519 .52121 Metetra
.925 .299 0 r
.1519 .52121 .16577 .53432 .18519 .53067 .17139 .51742 Metetra
.933 .271 0 r
.17139 .51742 .18519 .53067 .20493 .52553 .1912 .51218 Metetra
.938 .254 0 r
.1912 .51218 .20493 .52553 .22485 .52012 .2112 .50668 Metetra
.942 .239 0 r
.2112 .50668 .22485 .52012 .24496 .51455 .23139 .50102 Metetra
.945 .225 0 r
.23139 .50102 .24496 .51455 .26524 .50882 .25175 .4952 Metetra
.948 .213 0 r
.25175 .4952 .26524 .50882 .2857 .50293 .2723 .48921 Metetra
.951 .203 0 r
.2723 .48921 .2857 .50293 .30634 .49688 .29303 .48306 Metetra
.953 .194 0 r
.29303 .48306 .30634 .49688 .32716 .49067 .31393 .47675 Metetra
.955 .186 0 r
.31393 .47675 .32716 .49067 .34815 .48429 .33502 .47027 Metetra
.957 .18 0 r
.33502 .47027 .34815 .48429 .36933 .47775 .35629 .46363 Metetra
.958 .176 0 r
.35629 .46363 .36933 .47775 .39068 .47104 .37774 .45682 Metetra
.958 .173 0 r
.37774 .45682 .39068 .47104 .41221 .46417 .39937 .44984 Metetra
.959 .172 0 r
.39937 .44984 .41221 .46417 .43392 .45713 .42118 .44269 Metetra
.958 .172 0 r
.42118 .44269 .43392 .45713 .45581 .44992 .44317 .43537 Metetra
.958 .174 0 r
.44317 .43537 .45581 .44992 .47787 .44253 .46535 .42787 Metetra
.957 .178 0 r
.46535 .42787 .47787 .44253 .50012 .43498 .4877 .42021 Metetra
.956 .183 0 r
.4877 .42021 .50012 .43498 .52254 .42725 .51024 .41236 Metetra
.954 .19 0 r
.51024 .41236 .52254 .42725 .54514 .41935 .53295 .40434 Metetra
.952 .198 0 r
.53295 .40434 .54514 .41935 .56792 .41127 .55585 .39614 Metetra
.949 .208 0 r
.55585 .39614 .56792 .41127 .59087 .40301 .57892 .38777 Metetra
.946 .219 0 r
.57892 .38777 .59087 .40301 .61401 .39458 .60218 .37921 Metetra
.943 .232 0 r
.60218 .37921 .61401 .39458 .63731 .38596 .62561 .37046 Metetra
.939 .247 0 r
.62561 .37046 .63731 .38596 .6608 .37715 .64922 .36153 Metetra
.935 .263 0 r
.64922 .36153 .6608 .37715 .68445 .36813 .67301 .35238 Metetra
.93 .283 0 r
.67301 .35238 .68445 .36813 .70826 .35845 .69695 .34258 Metetra
.916 .335 0 r
.69695 .34258 .70826 .35845 .73195 .3443 .7208 .32845 Metetra
.859 .526 0 r
.7208 .32845 .73195 .3443 .75428 .31009 .74339 .2946 Metetra
.435 .685 0 r
.74339 .2946 .75428 .31009 .77281 .23155 .76234 .21674 Metetra
.038 .554 0 r
.09736 .39084 .1112 .40226 .11925 .48156 .10517 .46933 Metetra
.798 .7 0 r
.10517 .46933 .11925 .48156 .13362 .51622 .11951 .50317 Metetra
.895 .407 0 r
.11951 .50317 .13362 .51622 .1519 .52121 .13785 .50779 Metetra
.921 .316 0 r
.13785 .50779 .1519 .52121 .17139 .51742 .15741 .50386 Metetra
.928 .288 0 r
.15741 .50386 .17139 .51742 .1912 .51218 .1773 .49852 Metetra
.933 .271 0 r
.1773 .49852 .1912 .51218 .2112 .50668 .19738 .49293 Metetra
.937 .257 0 r
.19738 .49293 .2112 .50668 .23139 .50102 .21765 .48717 Metetra
.94 .243 0 r
.21765 .48717 .23139 .50102 .25175 .4952 .23809 .48125 Metetra
.943 .231 0 r
.23809 .48125 .25175 .4952 .2723 .48921 .25872 .47517 Metetra
.946 .221 0 r
.25872 .47517 .2723 .48921 .29303 .48306 .27954 .46892 Metetra
.948 .212 0 r
.27954 .46892 .29303 .48306 .31393 .47675 .30053 .4625 Metetra
.95 .204 0 r
.30053 .4625 .31393 .47675 .33502 .47027 .32171 .45592 Metetra
.952 .199 0 r
.32171 .45592 .33502 .47027 .35629 .46363 .34308 .44917 Metetra
.953 .194 0 r
.34308 .44917 .35629 .46363 .37774 .45682 .36462 .44225 Metetra
.954 .192 0 r
.36462 .44225 .37774 .45682 .39937 .44984 .38635 .43516 Metetra
.954 .19 0 r
.38635 .43516 .39937 .44984 .42118 .44269 .40827 .4279 Metetra
.954 .191 0 r
.40827 .4279 .42118 .44269 .44317 .43537 .43036 .42047 Metetra
.953 .193 0 r
.43036 .42047 .44317 .43537 .46535 .42787 .45264 .41286 Metetra
.952 .196 0 r
.45264 .41286 .46535 .42787 .4877 .42021 .47511 .40508 Metetra
.951 .202 0 r
.47511 .40508 .4877 .42021 .51024 .41236 .49776 .39712 Metetra
.949 .208 0 r
.49776 .39712 .51024 .41236 .53295 .40434 .52059 .38898 Metetra
.947 .216 0 r
.52059 .38898 .53295 .40434 .55585 .39614 .5436 .38066 Metetra
.945 .226 0 r
.5436 .38066 .55585 .39614 .57892 .38777 .56679 .37215 Metetra
.942 .238 0 r
.56679 .37215 .57892 .38777 .60218 .37921 .59017 .36347 Metetra
.938 .25 0 r
.59017 .36347 .60218 .37921 .62561 .37046 .61373 .35459 Metetra
.935 .264 0 r
.61373 .35459 .62561 .37046 .64922 .36153 .63747 .34553 Metetra
.93 .28 0 r
.63747 .34553 .64922 .36153 .67301 .35238 .66139 .33625 Metetra
.925 .301 0 r
.66139 .33625 .67301 .35238 .69695 .34258 .68547 .32634 Metetra
.911 .351 0 r
.68547 .32634 .69695 .34258 .7208 .32845 .70948 .31222 Metetra
.856 .535 0 r
.70948 .31222 .7208 .32845 .74339 .2946 .73232 .2788 Metetra
.435 .685 0 r
.73232 .2788 .74339 .2946 .76234 .21674 .7517 .20172 Metetra
.042 .556 0 r
.08331 .3793 .09736 .39084 .10517 .46933 .0909 .45685 Metetra
.795 .705 0 r
.0909 .45685 .10517 .46933 .11951 .50317 .10524 .48977 Metetra
.89 .423 0 r
.10524 .48977 .11951 .50317 .13785 .50779 .12364 .494 Metetra
.916 .335 0 r
.12364 .494 .13785 .50779 .15741 .50386 .14327 .48991 Metetra
.923 .308 0 r
.14327 .48991 .15741 .50386 .1773 .49852 .16323 .48447 Metetra
.928 .291 0 r
.16323 .48447 .1773 .49852 .19738 .49293 .18339 .47878 Metetra
.931 .277 0 r
.18339 .47878 .19738 .49293 .21765 .48717 .20373 .47293 Metetra
.935 .263 0 r
.20373 .47293 .21765 .48717 .23809 .48125 .22426 .4669 Metetra
.938 .251 0 r
.22426 .4669 .23809 .48125 .25872 .47517 .24498 .46072 Metetra
.941 .241 0 r
.24498 .46072 .25872 .47517 .27954 .46892 .26587 .45436 Metetra
.943 .232 0 r
.26587 .45436 .27954 .46892 .30053 .4625 .28696 .44784 Metetra
.945 .225 0 r
.28696 .44784 .30053 .4625 .32171 .45592 .30823 .44115 Metetra
.947 .219 0 r
.30823 .44115 .32171 .45592 .34308 .44917 .32969 .43429 Metetra
.948 .215 0 r
.32969 .43429 .34308 .44917 .36462 .44225 .35133 .42727 Metetra
.948 .212 0 r
.35133 .42727 .36462 .44225 .38635 .43516 .37316 .42006 Metetra
.949 .211 0 r
.37316 .42006 .38635 .43516 .40827 .4279 .39517 .41269 Metetra
.949 .212 0 r
.39517 .41269 .40827 .4279 .43036 .42047 .41737 .40514 Metetra
.948 .214 0 r
.41737 .40514 .43036 .42047 .45264 .41286 .43976 .39741 Metetra
.947 .217 0 r
.43976 .39741 .45264 .41286 .47511 .40508 .46234 .38951 Metetra
.946 .222 0 r
.46234 .38951 .47511 .40508 .49776 .39712 .48509 .38143 Metetra
.944 .229 0 r
.48509 .38143 .49776 .39712 .52059 .38898 .50804 .37317 Metetra
.942 .237 0 r
.50804 .37317 .52059 .38898 .5436 .38066 .53117 .36472 Metetra
.939 .247 0 r
.53117 .36472 .5436 .38066 .56679 .37215 .55449 .35609 Metetra
.936 .258 0 r
.55449 .35609 .56679 .37215 .59017 .36347 .57799 .34728 Metetra
.933 .27 0 r
.57799 .34728 .59017 .36347 .61373 .35459 .60167 .33828 Metetra
.929 .284 0 r
.60167 .33828 .61373 .35459 .63747 .34553 .62554 .32908 Metetra
.925 .3 0 r
.62554 .32908 .63747 .34553 .66139 .33625 .64959 .31967 Metetra
.92 .32 0 r
.64959 .31967 .66139 .33625 .68547 .32634 .6738 .30965 Metetra
.906 .368 0 r
.6738 .30965 .68547 .32634 .70948 .31222 .69798 .29556 Metetra
.852 .546 0 r
.69798 .29556 .70948 .31222 .73232 .2788 .72108 .26262 Metetra
.434 .685 0 r
.72108 .26262 .73232 .2788 .7517 .20172 .74089 .18645 Metetra
.043 .556 0 r
.06912 .36716 .08331 .3793 .0909 .45685 .07654 .44344 Metetra
.791 .716 0 r
.07654 .44344 .0909 .45685 .10524 .48977 .09089 .47527 Metetra
.884 .445 0 r
.09089 .47527 .10524 .48977 .12364 .494 .10936 .47902 Metetra
.908 .361 0 r
.10936 .47902 .12364 .494 .14327 .48991 .12906 .47475 Metetra
.915 .335 0 r
.12906 .47475 .14327 .48991 .16323 .48447 .14909 .46919 Metetra
.92 .319 0 r
.14909 .46919 .16323 .48447 .18339 .47878 .16932 .46338 Metetra
.924 .305 0 r
.16932 .46338 .18339 .47878 .20373 .47293 .18974 .4574 Metetra
.927 .292 0 r
.18974 .4574 .20373 .47293 .22426 .4669 .21034 .45126 Metetra
.93 .28 0 r
.21034 .45126 .22426 .4669 .24498 .46072 .23114 .44496 Metetra
.933 .27 0 r
.23114 .44496 .24498 .46072 .26587 .45436 .25212 .43849 Metetra
.935 .262 0 r
.25212 .43849 .26587 .45436 .28696 .44784 .27328 .43185 Metetra
.937 .254 0 r
.27328 .43185 .28696 .44784 .30823 .44115 .29464 .42504 Metetra
.939 .249 0 r
.29464 .42504 .30823 .44115 .32969 .43429 .31618 .41806 Metetra
.94 .245 0 r
.31618 .41806 .32969 .43429 .35133 .42727 .33792 .41091 Metetra
.941 .242 0 r
.33792 .41091 .35133 .42727 .37316 .42006 .35984 .40359 Metetra
.941 .241 0 r
.35984 .40359 .37316 .42006 .39517 .41269 .38195 .3961 Metetra
.941 .241 0 r
.38195 .3961 .39517 .41269 .41737 .40514 .40424 .38843 Metetra
.94 .243 0 r
.40424 .38843 .41737 .40514 .43976 .39741 .42673 .38059 Metetra
.939 .247 0 r
.42673 .38059 .43976 .39741 .46234 .38951 .4494 .37256 Metetra
.938 .252 0 r
.4494 .37256 .46234 .38951 .48509 .38143 .47227 .36436 Metetra
.936 .258 0 r
.47227 .36436 .48509 .38143 .50804 .37317 .49532 .35598 Metetra
.934 .266 0 r
.49532 .35598 .50804 .37317 .53117 .36472 .51856 .34742 Metetra
.932 .276 0 r
.51856 .34742 .53117 .36472 .55449 .35609 .54199 .33867 Metetra
.929 .286 0 r
.54199 .33867 .55449 .35609 .57799 .34728 .5656 .32973 Metetra
.926 .299 0 r
.5656 .32973 .57799 .34728 .60167 .33828 .58941 .32061 Metetra
.922 .312 0 r
.58941 .32061 .60167 .33828 .62554 .32908 .6134 .3113 Metetra
.918 .328 0 r
.6134 .3113 .62554 .32908 .64959 .31967 .63757 .30177 Metetra
.912 .347 0 r
.63757 .30177 .64959 .31967 .6738 .30965 .66192 .29165 Metetra
.899 .393 0 r
.66192 .29165 .6738 .30965 .69798 .29556 .68624 .27762 Metetra
.847 .563 0 r
.68624 .27762 .69798 .29556 .72108 .26262 .7096 .2453 Metetra
.427 .683 0 r
.7096 .2453 .72108 .26262 .74089 .18645 .72986 .17032 Metetra
.019 .546 0 r
.05529 .35114 .06912 .36716 .07654 .44344 .06277 .42435 Metetra
.775 .756 0 r
.06277 .42435 .07654 .44344 .09089 .47527 .07723 .45417 Metetra
.863 .511 0 r
.07723 .45417 .09089 .47527 .10936 .47902 .09577 .45713 Metetra
.887 .435 0 r
.09577 .45713 .10936 .47902 .12906 .47475 .11552 .45252 Metetra
.893 .412 0 r
.11552 .45252 .12906 .47475 .14909 .46919 .1356 .44672 Metetra
.898 .398 0 r
.1356 .44672 .14909 .46919 .16932 .46338 .15587 .44067 Metetra
.901 .385 0 r
.15587 .44067 .16932 .46338 .18974 .4574 .17633 .43448 Metetra
.905 .373 0 r
.17633 .43448 .18974 .4574 .21034 .45126 .19698 .42812 Metetra
.908 .363 0 r
.19698 .42812 .21034 .45126 .23114 .44496 .21781 .42161 Metetra
.91 .354 0 r
.21781 .42161 .23114 .44496 .25212 .43849 .23883 .41494 Metetra
.912 .346 0 r
.23883 .41494 .25212 .43849 .27328 .43185 .26004 .40812 Metetra
.914 .34 0 r
.26004 .40812 .27328 .43185 .29464 .42504 .28144 .40113 Metetra
.916 .335 0 r
.28144 .40113 .29464 .42504 .31618 .41806 .30302 .39399 Metetra
.917 .331 0 r
.30302 .39399 .31618 .41806 .33792 .41091 .3248 .38668 Metetra
.917 .329 0 r
.3248 .38668 .33792 .41091 .35984 .40359 .34676 .37922 Metetra
.918 .328 0 r
.34676 .37922 .35984 .40359 .38195 .3961 .36891 .37159 Metetra
.917 .328 0 r
.36891 .37159 .38195 .3961 .40424 .38843 .39125 .36379 Metetra
.917 .33 0 r
.39125 .36379 .40424 .38843 .42673 .38059 .41379 .35583 Metetra
.916 .333 0 r
.41379 .35583 .42673 .38059 .4494 .37256 .43651 .3477 Metetra
.915 .338 0 r
.43651 .3477 .4494 .37256 .47227 .36436 .45942 .3394 Metetra
.913 .343 0 r
.45942 .3394 .47227 .36436 .49532 .35598 .48253 .33093 Metetra
.911 .35 0 r
.48253 .33093 .49532 .35598 .51856 .34742 .50582 .32229 Metetra
.909 .359 0 r
.50582 .32229 .51856 .34742 .54199 .33867 .5293 .31348 Metetra
.906 .369 0 r
.5293 .31348 .54199 .33867 .5656 .32973 .55298 .30449 Metetra
.903 .38 0 r
.55298 .30449 .5656 .32973 .58941 .32061 .57685 .29532 Metetra
.899 .392 0 r
.57685 .29532 .58941 .32061 .6134 .3113 .6009 .28597 Metetra
.895 .406 0 r
.6009 .28597 .6134 .3113 .63757 .30177 .62515 .27641 Metetra
.89 .423 0 r
.62515 .27641 .63757 .30177 .66192 .29165 .64957 .26631 Metetra
.878 .464 0 r
.64957 .26631 .66192 .29165 .68624 .27762 .67401 .25254 Metetra
.828 .618 0 r
.67401 .25254 .68624 .27762 .7096 .2453 .69759 .22141 Metetra
.381 .67 0 r
.69759 .22141 .7096 .2453 .72986 .17032 .71835 .14911 Metetra
0 .492 .098 r
.04359 .31986 .05529 .35114 .06277 .42435 .05204 .38342 Metetra
.502 .703 0 r
.05204 .38342 .06277 .42435 .07723 .45417 .06695 .40807 Metetra
.784 .733 0 r
.06695 .40807 .07723 .45417 .09577 .45713 .08557 .4092 Metetra
.805 .681 0 r
.08557 .4092 .09577 .45713 .11552 .45252 .10528 .40382 Metetra
.81 .666 0 r
.10528 .40382 .11552 .45252 .1356 .44672 .12529 .39742 Metetra
.814 .657 0 r
.12529 .39742 .1356 .44672 .15587 .44067 .14548 .39084 Metetra
.817 .649 0 r
.14548 .39084 .15587 .44067 .17633 .43448 .16585 .38413 Metetra
.819 .642 0 r
.16585 .38413 .17633 .43448 .19698 .42812 .1864 .3773 Metetra
.821 .636 0 r
.1864 .3773 .19698 .42812 .21781 .42161 .20713 .37035 Metetra
.823 .63 0 r
.20713 .37035 .21781 .42161 .23883 .41494 .22803 .36328 Metetra
.825 .625 0 r
.22803 .36328 .23883 .41494 .26004 .40812 .24912 .35608 Metetra
.826 .621 0 r
.24912 .35608 .26004 .40812 .28144 .40113 .27039 .34876 Metetra
.828 .618 0 r
.27039 .34876 .28144 .40113 .30302 .39399 .29184 .34132 Metetra
.828 .616 0 r
.29184 .34132 .30302 .39399 .3248 .38668 .31347 .33375 Metetra
.829 .615 0 r
.31347 .33375 .3248 .38668 .34676 .37922 .33529 .32605 Metetra
.829 .614 0 r
.33529 .32605 .34676 .37922 .36891 .37159 .35729 .31823 Metetra
.829 .614 0 r
.35729 .31823 .36891 .37159 .39125 .36379 .37948 .31027 Metetra
.829 .615 0 r
.37948 .31027 .39125 .36379 .41379 .35583 .40186 .30219 Metetra
.828 .617 0 r
.40186 .30219 .41379 .35583 .43651 .3477 .42442 .29398 Metetra
.827 .62 0 r
.42442 .29398 .43651 .3477 .45942 .3394 .44717 .28563 Metetra
.826 .623 0 r
.44717 .28563 .45942 .3394 .48253 .33093 .47012 .27715 Metetra
.824 .628 0 r
.47012 .27715 .48253 .33093 .50582 .32229 .49325 .26854 Metetra
.822 .633 0 r
.49325 .26854 .50582 .32229 .5293 .31348 .51658 .25979 Metetra
.82 .639 0 r
.51658 .25979 .5293 .31348 .55298 .30449 .5401 .25089 Metetra
.818 .646 0 r
.5401 .25089 .55298 .30449 .57685 .29532 .56381 .24186 Metetra
.815 .653 0 r
.56381 .24186 .57685 .29532 .6009 .28597 .58772 .23269 Metetra
.812 .662 0 r
.58772 .23269 .6009 .28597 .62515 .27641 .61182 .22335 Metetra
.808 .673 0 r
.61182 .22335 .62515 .27641 .64957 .26631 .63611 .21356 Metetra
.797 .701 0 r
.63611 .21356 .64957 .26631 .67401 .25254 .66045 .20065 Metetra
.696 .752 0 r
.66045 .20065 .67401 .25254 .69759 .22141 .68415 .17269 Metetra
.179 .607 0 r
.68415 .17269 .69759 .22141 .71835 .14911 .7055 .10839 Metetra
0 .335 .295 r
.03634 .26033 .04359 .31986 .05204 .38342 .04741 .30296 Metetra
0 .506 .071 r
.04741 .30296 .05204 .38342 .06695 .40807 .06333 .31741 Metetra
.079 .57 0 r
.06333 .31741 .06695 .40807 .08557 .4092 .08198 .31532 Metetra
.119 .585 0 r
.08198 .31532 .08557 .4092 .10528 .40382 .10144 .30872 Metetra
.128 .589 0 r
.10144 .30872 .10528 .40382 .12529 .39742 .12114 .30145 Metetra
.132 .59 0 r
.12114 .30145 .12529 .39742 .14548 .39084 .14101 .29406 Metetra
.136 .591 0 r
.14101 .29406 .14548 .39084 .16585 .38413 .16103 .28661 Metetra
.139 .593 0 r
.16103 .28661 .16585 .38413 .1864 .3773 .18121 .27909 Metetra
.142 .594 0 r
.18121 .27909 .1864 .3773 .20713 .37035 .20155 .2715 Metetra
.145 .595 0 r
.20155 .2715 .20713 .37035 .22803 .36328 .22206 .26384 Metetra
.147 .595 0 r
.22206 .26384 .22803 .36328 .24912 .35608 .24273 .25611 Metetra
.148 .596 0 r
.24273 .25611 .24912 .35608 .27039 .34876 .26357 .24831 Metetra
.15 .596 0 r
.26357 .24831 .27039 .34876 .29184 .34132 .28457 .24044 Metetra
.151 .597 0 r
.28457 .24044 .29184 .34132 .31347 .33375 .30575 .2325 Metetra
.151 .597 0 r
.30575 .2325 .31347 .33375 .33529 .32605 .32709 .22448 Metetra
.152 .597 0 r
.32709 .22448 .33529 .32605 .35729 .31823 .34862 .2164 Metetra
.152 .597 0 r
.34862 .2164 .35729 .31823 .37948 .31027 .37031 .20823 Metetra
.151 .597 0 r
.37031 .20823 .37948 .31027 .40186 .30219 .39219 .19999 Metetra
.15 .597 0 r
.39219 .19999 .40186 .30219 .42442 .29398 .41424 .19168 Metetra
.149 .596 0 r
.41424 .19168 .42442 .29398 .44717 .28563 .43648 .18329 Metetra
.147 .596 0 r
.43648 .18329 .44717 .28563 .47012 .27715 .4589 .17481 Metetra
.146 .595 0 r
.4589 .17481 .47012 .27715 .49325 .26854 .48151 .16627 Metetra
.143 .594 0 r
.48151 .16627 .49325 .26854 .51658 .25979 .5043 .15764 Metetra
.14 .593 0 r
.5043 .15764 .51658 .25979 .5401 .25089 .52729 .14893 Metetra
.137 .592 0 r
.52729 .14893 .5401 .25089 .56381 .24186 .55047 .14013 Metetra
.134 .591 0 r
.55047 .14013 .56381 .24186 .58772 .23269 .57384 .13126 Metetra
.13 .589 0 r
.57384 .13126 .58772 .23269 .61182 .22335 .59741 .12229 Metetra
.124 .587 0 r
.59741 .12229 .61182 .22335 .63611 .21356 .62117 .11302 Metetra
.105 .58 0 r
.62117 .11302 .63611 .21356 .66045 .20065 .64505 .10163 Metetra
.015 .545 0 r
.64505 .10163 .66045 .20065 .68415 .17269 .66858 .07981 Metetra
0 .428 .205 r
.66858 .07981 .68415 .17269 .7055 .10839 .69061 .03224 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16722 .20421 m
.17181 .2089 L
s
[(-5)] .15804 .19483 .97905 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.53137 .06162 m
.53529 .06688 L
s
[(5)] .52352 .0511 .74541 1 Mshowa
.125 Mabswid
.20145 .19081 m
.20417 .19365 L
s
.23614 .17722 m
.23883 .1801 L
s
.2713 .16345 m
.27395 .16637 L
s
.30694 .1495 m
.30955 .15245 L
s
.37969 .12101 m
.38222 .12403 L
s
.41682 .10647 m
.41931 .10953 L
s
.45447 .09173 m
.45691 .09482 L
s
.49265 .07678 m
.49505 .0799 L
s
.13343 .21744 m
.13622 .22022 L
s
.10009 .2305 m
.10291 .23324 L
s
.06718 .24338 m
.07003 .2461 L
s
.57064 .04624 m
.57294 .04944 L
s
.61047 .03065 m
.61273 .03387 L
s
.65089 .01482 m
.65309 .01808 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00c?ooool2o`0005;ooooo0039ooooo`?o000000?o
ooooo`000?ooool0DOooool00<Oooooo0_l00004ooooo`;o0000DOooool00<Cooooo0ol00006oooo
o`03o`000?oooooo0000053ooooo0032ooooo`;o00002Oooool00ol0003oooooo`00001@ooooo`00
_oooool3o`000003ooooool0003ooooo00Sooooo00Co0000oooooooooooo0000Coooool009gooooo
0ol0000Mooooo`;o00003_ooool01Ol0003ooooooooooooooooo000004kooooo002Looooo`05o`00
0?ooooooooooooooool000006Oooool3o`00013ooooo00?o0000ooooooooool00_l0001>ooooo`00
X?ooool00ol0003oooooooooo`0Dooooo`?o00004oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo04_ooooo002Pooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1;ooooo`00W?ooool4
o`0001;ooooo0ol0000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B_ooool0
09cooooo00?o0000ooooooooool04Oooool2o`0001[ooooo0_l00006ooooo`03o`000?oooooooooo
04Wooooo002Looooo`Go00003?ooool3o`0001cooooo00?o0000o`1]=?l000001Oooool00ol0003o
ooooooooo`19ooooo`00Zoooool2o`000003ooooool0003ooooo01_ooooo00Co0000o`1]=?l0KCCo
00001_ooool00ol0003oooooooooo`18ooooo`00Z?ooool3o`00023ooooo00Co0000o`1]=?l0KCCo
00001oooool00ol0003oooooooooo`17ooooo`00Y_ooool2o`0002;ooooo00Go0000o`1]=?l0KCCo
06ddo`000006ooooo`;o0000BOooool00:?ooooo0ol0000Tooooo`05o`000?l0KCCo06ddo`1]=?l0
00002?ooool00ol0003oooooooooo`16ooooo`00XOooool3o`0002Gooooo00?o0000o`1]=?l0KC@0
0_l0KC@2o`0000Sooooo00?o0000ooooooooool0AOooool009kooooo0ol00003ooooo`03o`000?oo
oooooooo02;ooooo00?o0000o`1]=?l0KC@00_l0KC@2o`0000Sooooo00?o0000ooooooooool0AOoo
ool009cooooo0_l0000Zooooo`03o`000?l0KCCo06dd00?o06dd0_l00009ooooo`03o`000?oooooo
oooo04Cooooo002Iooooo`?o0000;?ooool00ol0003o06ddo`1]=003o`1]=0;o00002_ooool00ol0
003oooooooooo`13ooooo`00Uoooool4o`0002cooooo00?o0000o`1]=?l0KC@01?l0KC@2o`0000[o
oooo00?o0000ooooooooool0@oooool009Cooooo0ol0000_ooooo`;o00001_l0KC@00ol0003o06dd
o`00000:ooooo`03o`000?oooooooooo04;ooooo002Booooo`;o0000<Oooool00ol0003o0h/0o`00
0006o`1]=003o`000?l0KCCo000000Wooooo00?o0000ooooool00000@oooool008oooooo0ol0000b
ooooo`04o`000?l3R`3o0h/0o`0000Ko06dd00?o0000o`1]=?l000002oooool00ol0003ooooooooo
o`0;ooooo`?o0000<oooool006cooooo0_l0000Nooooo`Go0000<_ooool00ol0003o0h/0o`>;0002
o`>;0003o`000?l0KCCo06dd00?o06dd00?o0000o`1]=?l000003?ooool00ol0003oooooooooo`09
ooooo`05o`000?ooooooooooooooool00000<_ooool006_ooooo00Co0000oooooooooooo00006ooo
ool2o`0003Kooooo00?o0000o`>;0?l3R`000ol3R`000ol0003o06ddo`1]=003o`1]=003o`000?l0
KCCo000000cooooo00?o0000ooooooooool00oooool5o`0000Gooooo00?o0000ooooooooool0<?oo
ool006_ooooo00Co0000oooooooooooo00006?ooool3o`0003Kooooo0_l00006o`>;0003o`000?l0
KCCo06dd00?o06dd00Co0000o`1]=?l0KCCo00003?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo033ooooo001[ooooo`04o`000?ooooooooooo`0001Kooooo0_l0000gooooo`;o0000
00?o6Y@0o`000?l3R`001Ol3R`000ol0003o06ddo`1]=003o`1]=004o`000?l0KCCo06ddo`0000go
oooo00?o0000ooooooooool01oooool4o`0003?ooooo001[ooooo`04o`000?ooooooooooo`0001?o
oooo0ol000000ooooooo0000ooooo`0dooooo`;o00000olJU0000ol0003o0h/0o`>;0004o`>;0003
o`000?l0KCCo06dd00?o06dd00Co0000o`1]=?l0KCCo00003Oooool2o`0000Sooooo00?o0000oooo
ooooool0=?ooool006_ooooo00Co0000oooooooooooo00004Oooool2o`0003Sooooo0_l00005oaZD
0003o`000?l3R`3o0h/000Co0h/000?o0000o`1]=?l0KC@00ol0KC@01?l0003o06ddo`1]=?l0000<
ooooo`03o`000?oooooo000000Sooooo1Ol0000booooo`00K?ooool2o`0000oooooo0ol0000hoooo
o`;o000000?o7iH0o`000?lJU0001OlJU0000ol0003o0h/0o`>;0004o`>;0003o`000?l0KCCo06dd
00;o06dd00Co0000o`1]=?l0003o00003oooool00ol0003oooooooooo`0looooo`00Noooool2o`00
03Wooooo0_l00003oanF0003o`000?lJU03o6Y@000Co6Y@000?o0000o`>;0?l3R`001?l3R`000ol0
003o06ddo`1]=002o`1]=005o`000?l0KCCo0000obfK0?l000003_ooool00ol0003oooooooooo`0l
ooooo`00N?ooool3o`000003ooooool0003ooooo03Gooooo0ol00005oanF0003o`000?lJU03o6Y@0
00Co6Y@000?o0000o`>;0?l3R`001?l3R`000ol0003o06ddo`1]=003o`1]=0;o000000?o;I/0o`00
0?ooool03_ooool00ol0003oooooooooo`0kooooo`00M_ooool2o`0003Sooooo0ol00002ob6F0003
o`000?lOUP3o7iH000Co7iH000?o0000oaZD0?lJU0000olJU0000ol0003o0h/0o`>;0004o`>;0003
o`000?l0KCCo06dd00?o06dd00Co0000obfK0?l]V`3o00004?ooool00ol0003oooooooooo`0joooo
o`00Loooool3o`0003Oooooo0ol00005ob6F0003o`000?lOUP3o7iH000Co7iH000?o0000oaZD0?lJ
U0000olJU0000ol0003o0h/0o`>;0004o`>;0003o`000?l0KCCo06dd00?o06dd00Go0000obfK0?l]
V`3o;I/0o`00000?ooooo`03o`000?oooooooooo03[ooooo001aooooo`;o0000=oooool3o`000003
ob:G0?l0003o8IH000Go8IH000?o0000oanF0?lOUP001?lOUP000ol0003o6Y@0oaZD0003oaZD0003
o`000?l3R`3o0h/000Co0h/000?o0000o`1]=?l0KC@00ol0KC@01Ol0003o;I/0obfK0?l]V`3o0000
013ooooo00?o0000ooooooooool0>Oooool006kooooo0ol00002ooooo`03o`000?oooooooooo037o
oooo0ol00004ob:G0003o`000?lQUP3o8IH000Co8IH000?o0000oanF0?lOUP001?lOUP000ol0003o
6Y@0oaZD0003oaZD0003o`000?l3R`3o0h/000Co0h/000?o0000o`1]=?l0KC@00_l0KC@2o`0000?o
;I/000?o0000ooooooooool03Oooool00ol0003oooooo`00000jooooo`00K?ooool2o`0003Oooooo
0_l000000olSU`3o0000ob:G0004ob:G0003o`000?lQUP3o8IH000Go8IH000?o0000oanF0?lOUP00
0olOUP000ol0003o6Y@0oaZD0004oaZD0003o`000?l3R`3o0h/000Co0h/000Co0000o`1]=?l0KCCo
06dd0_l00003obfK0003o`000?oooooooooo00oooooo00?o0000ooooooooool0>?ooool006Wooooo
0ol0000gooooo`;o00000olSU`000ol0003o8YL0ob:G0004ob:G0003o`000?lQUP3o8IH000Co8IH0
00?o0000oanF0?lOUP000olOUP000ol0003o6Y@0oaZD0004oaZD0003o`000?l3R`3o0h/000Co0h/0
00Co0000o`1]=?l0KCCo06dd0_l00004obfK0003o`000?oooooooooo00oooooo00?o0000oooooooo
ool0=oooool006Oooooo0_l0000hooooo`;o00001OlSU`000ol0003o8YL0ob:G0004ob:G0003o`00
0?lQUP3o8IH000Co8IH000?o0000oanF0?lOUP000olOUP000ol0003o6Y@0oaZD0004oaZD0003o`00
0?l3R`3o0h/000Co0h/000Ko0000o`1]=?l0KCCo0000obfK0?l00004obfK0003o`000?oooooooooo
013ooooo00?o0000ooooooooool0=_ooool006Cooooo0ol00002ooooo`03o`000?oooooooooo03;o
oooo0ol000000olSU`3o0000ob>G0005ob>G0003o`000?lRU`3o8YL000?o8YL000?o0000ob6F0?lQ
UP001?lQUP000ol0003o7iH0oanF0004oanF0003o`000?lJU03o6Y@000?o6Y@000?o0000o`>;0?l3
R`001?l3R`001_l0003o06ddo`1]=?l0003o;I/0o`0000Co;I/000?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0fooooo`00HOooool3o`0003Oooooo0ol00004ob>G0003o`000?lSU`3o8iL0
00Co8iL000?o0000ob:G0?lRU`000olRU`000ol0003o8IH0ob6F0004ob6F0003o`000?lOUP3o7iH0
00Co7iH000?o0000oaZD0?lJU0000olJU0000ol0003o0h/0o`>;0004o`>;0006o`000?l0KCCo06dd
o`000?l]V`3o00001?l]V`02o`0001;ooooo00?o0000ooooooooool0=Oooool005oooooo0_l0000g
ooooo`?o000000?o99P0o`000?lSU`001?lSU`000ol0003o8iL0ob>G0004ob>G0003o`000?lRU`3o
8YL000?o8YL000?o0000ob6F0?lQUP001?lQUP000ol0003o7iH0oanF0004oanF0003o`000?lJU03o
6Y@000?o6Y@000?o0000o`>;0?l3R`001?l3R`000ol0003o06ddo`000002obfK0005o`000?l]V`3o
;I/0obfK0?l000000_mQZ`000ol0003oooooooooo`0?ooooo`;o0000=_ooool003cooooo0ol0000M
ooooo`?o000000?oooooo`000?ooool0<oooool3o`0000Co99P000?o0000ob>G0?lSU`001?lSU`00
0ol0003o8iL0ob>G0003ob>G0003o`000?lRU`3o8YL000?o8YL000?o0000ob6F0?lQUP001?lQUP00
0ol0003o7iH0oanF0004oanF0003o`000?lJU03o6Y@000Co6Y@000?o0000o`>;0?l3R`001?l3R`02
o`0000;o;I/000Go0000obfK0?l]V`3o;I/0o`000002of6[0003o`000?oooooooooo00oooooo0_l0
000fooooo`00>oooool01Ol0003ooooooooooooooooo000001[ooooo0_l0000fooooo`?o000000?o
9IP0o`000?lTV0001?lTV0000ol0003o8iL0ob>G0004ob>G0003o`000?lSU`3o8iL000?o8iL000?o
0000ob:G0?lRU`000olRU`000ol0003o8IH0ob6F0004ob6F0003o`000?lOUP3o7iH000Co7iH000?o
0000oaZD0?lJU0001?lJU0000ol0003o0h/0o`>;0004o`>;00;o00000_l]V`001Ol0003o;I/0obfK
0?l]V`3o000000?oHJ/000?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`00=Ooo
ool5o`0000Gooooo00?o0000ooooooooool05Oooool3o`0003Gooooo0ol00004obFH0003o`000?lT
V03o99P000?o99P000?o0000ob>G0?lSU`001?lSU`000ol0003o8iL0ob>G0003ob>G0003o`000?lR
U`3o8YL000Co8YL000?o0000ob6F0?lQUP000olQUP000ol0003o7iH0oanF0004oanF0003o`000?lJ
U03o6Y@000Co6Y@000?o0000o`>;0?l3R`001?l3R`001Ol0003o;I/0obfK0?l]V`3o000000?o;I/0
00Go0000of6[0?mQZ`3oHJ/0o`00000Booooo`03o`000?oooooooooo03?ooooo000oooooo`03o`00
0?oooooooooo01?ooooo0_l0000fooooo`;o000000?o9IP0o`000?lUV0001?lUV0000ol0003o99P0
obBH0004obBH0003o`000?lSU`3o8iL000?o8iL000?o0000ob>G0?lSU`000olSU`000ol0003o8YL0
ob:G0004ob:G0003o`000?lQUP3o8IH000Co8IH000?o0000oanF0?lOUP000olOUP000ol0003o6Y@0
oaZD0004oaZD0003o`000?l3R`3o0h/000Co0h/000Go0000obfK0?l]V`3o;I/0o`000002obfK0003
o`000?mQZ`3oHJ/000;oHJ/00_l0000Booooo`03o`000?oooooooooo03;ooooo000kooooo`Co0000
4oooool3o`000003ooooool0003ooooo03?ooooo0_l00003obFH0003o`000?lUV03o9IP000?o9IP0
00?o0000obBH0?lTV0001?lTV0000ol0003o8iL0ob>G0003ob>G0003o`000?lSU`3o8iL000Co8iL0
00?o0000ob:G0?lRU`000olRU`000ol0003o8IH0ob6F0004ob6F0003o`000?lOUP3o7iH000Co7iH0
00?o0000oaZD0?lJU0000olJU0000ol0003o0h/0o`>;0003o`>;00;o00000ol]V`001?l0003o;I/0
obfK0?l00003of6[0004o`000?m][P3oKJh0o`0001;ooooo00?o0000ooooooooool0<Oooool003_o
oooo00?o0000ooooooooool04_ooool2o`0003Oooooo0_l00005obFH0003o`000?lUV03o9IP000Co
9IP000?o0000obBH0?lTV0000olTV0000ol0003o8iL0ob>G0003ob>G0003o`000?lSU`3o8iL000Co
8iL000?o0000ob:G0?lRU`000olRU`000ol0003o8IH0ob6F0004ob6F0003o`000?lOUP3o7iH000Co
7iH000?o0000oaZD0?lJU0000olJU0000ol0003o0h/0o`>;0002o`>;0004o`000?nb`03o//00o`00
00;o;I/000Co0000obfK0?l]V`3o00000omQZ`001Ol0003oKJh0off^0?m][P3o0000017ooooo00?o
0000ooooooooool0<Oooool003_ooooo1Ol0000=ooooo`?o0000=_ooool3o`000003obJH0?l0003o
9IP000Co9IP000?o0000obFH0?lUV0001?lUV0000ol0003o99P0obBH0003obBH0003o`000?lSU`3o
8iL000?o8iL000?o0000ob>G0?lSU`001?lSU`000ol0003o8YL0ob:G0003ob:G0003o`000?lQUP3o
8IH000Co8IH000?o0000oanF0?lOUP001?lOUP000ol0003o6Y@0oaZD0003oaZD0005o`000?l3R`3o
0h/0o`>;0?l000000onb`0001_l0003o;I/0obfK0?l0003o;I/0o`0000CoHJ/000Go0000off^0?m]
[P3oKJh0o`00000Aooooo`;o0000<_ooool004_ooooo0ol0000eooooo`?o00001?lVV0000ol0003o
9IP0obFH0004obFH0003o`000?lUV03o9IP000?o9IP000?o0000obBH0?lTV0000olTV0000ol0003o
8iL0ob>G0004ob>G0003o`000?lSU`3o8iL000?o8iL000?o0000ob:G0?lRU`000olRU`000ol0003o
8IH0ob6F0004ob6F0003o`000?lOUP3o7iH000Co7iH000?o0000oaZD0?lJU0001?lJU0000ol0003o
0h/0o`000004ok;00006o`000?l]V`3o;I/0o`000?l]V`3o00001?mQZ`001?l0003oKJh0off^0?m]
[P02o`0001;ooooo00?o0000ooooooooool0;oooool004Sooooo0ol0000eooooo`?o000000?o9YP0
o`000?lVV0001?lVV0000ol0003o9IP0obFH0004obFH0003o`000?lUV03o9IP000?o9IP000?o0000
obBH0?lTV0000olTV0000ol0003o8iL0ob>G0004ob>G0003o`000?lSU`3o8iL000?o8iL000?o0000
ob:G0?lRU`000olRU`000ol0003o8IH0ob6F0004ob6F0003o`000?lOUP3o7iH000Co7iH000?o0000
oaZD0?lJU0001?lJU002o`0000Ko//0000Go0000obfK0?l0003o;I/0o`000003of6[0005o`000?m]
[P3oKJh0off^0?l000000_m_[`000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo
0016ooooo`;o0000=_ooool2o`0000Co9YP000?o0000obJH0?lVV0000olVV0000ol0003o9IP0obFH
0004obFH0003o`000?lUV03o9IP000?o9IP000?o0000obBH0?lTV0000olTV0000ol0003o8iL0ob>G
0004ob>G0003o`000?lSU`3o8iL000?o8iL000?o0000ob:G0?lRU`001?lRU`000ol0003o8IH0ob6F
0003ob6F0003o`000?lOUP3o7iH000Co7iH000?o0000oaZD0?lJU0000olJU002o`0000Oo//0000Go
0000obfK0?l0003o;I/0o`000003of6[0005o`000?m][P3oKJh0off^0?l000000om_[`000ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo02kooooo0013ooooo`?o0000=Oooool3o`000003obJH
0?l0003o9YP000?o9YP000?o0000obJH0?lVV0001?lVV0000ol0003o9IP0obFH0003obFH0003o`00
0?lUV03o9IP000?o9IP000?o0000obBH0?lTV0000olTV0000ol0003o8iL0ob>G0004ob>G0003o`00
0?lSU`3o8iL000?o8iL000?o0000ob:G0?lRU`001?lRU`000ol0003o8IH0ob6F0003ob6F0003o`00
0?lOUP3o7iH000Co7iH000?o0000oaZD0?lJU0000_lJU0000ol0003oc;<0o`000007ok;00004o`00
0?l]V`3o0000o`0000CoHJ/000Go0000off^0?m][P3oKJh0o`000003ofn_0003o`000?oooooooooo
013ooooo00?o0000ooooooooool0;Oooool0047ooooo0_l00002ooooo`03o`000?oooooooooo033o
oooo0ol00004obJH0003o`000?lVV03o9YP000;o9YP000?o0000obJH0?lVV0001?lVV0000ol0003o
9IP0obFH0003obFH0003o`000?lUV03o9IP000?o9IP000?o0000obBH0?lTV0000olTV0000ol0003o
8iL0ob>G0004ob>G0003o`000?lSU`3o8iL000Co8iL000?o0000ob:G0?lRU`000olRU`000ol0003o
8IH0ob6F0003ob6F0003o`000?lOUP3o7iH000Go7iH000Co0000oaZD0?l0003o00000_o</`000ol0
003o//00ok;00006ok;00003o`000?l]V`3o000000CoHJ/000Go0000off^0?m][P3oKJh0o`000003
ofn_00;o00004Oooool00ol0003oooooooooo`0]ooooo`00?_ooool3o`0003Cooooo0ol000000olV
V03o0000obJH0004obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0
003o9IP0obFH0003obFH0003o`000?lUV03o9IP000?o9IP000?o0000obBH0?lTV0001?lTV0000ol0
003o8iL0ob>G0003ob>G0003o`000?lSU`3o8iL000Co8iL000?o0000ob:G0?lRU`000olRU`000ol0
003o8IH0ob6F0004ob6F0003o`000?lOUP3o7iH000Co7iH00_l00005olbc0003o`000?nb`03o//00
00Go//0000?o0000obfK0?l000000omQZ`001Ol0003oKJh0off^0?m][P3o000000?oKjl000Co0000
ofn_0?m_[`3o00004Oooool00ol0003oooooooooo`0/ooooo`00??ooool2o`0003Cooooo0ol00004
obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003
obJH0003o`000?lUV03o9IP000?o9IP000?o0000obFH0?lUV0000olUV0000ol0003o99P0obBH0004
obBH0003o`000?lSU`3o8iL000Co8iL000?o0000ob>G0?lSU`000olSU`000ol0003o8YL0ob:G0003
ob:G0003o`000?lQUP3o8IH000Co8IH000?o0000oanF0?lOUP000_lOUP03o`0000Koc;<000?o0000
ok;00?nb`0001Onb`0000ol0003o;I/0o`000003of6[0005o`000?m][P3oKJh0off^0?l000000om_
[`001Ol0003oKjl0ofn_0?m_[`3o000000oooooo0ol00008ooooo`;o00008oooool003Wooooo0ol0
000cooooo`?o000000?o9YP0o`000?lVV0001?lVV0000ol0003o9YP0obJH0003obJH0003o`000?lV
V03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o9IP0obFH0003obFH0003o`000?lU
V03o9IP000Co9IP000?o0000obBH0?lTV0000olTV0000ol0003o8iL0ob>G0004ob>G0003o`000?lS
U`3o8iL000?o8iL000?o0000ob:G0?lRU`000olRU`000ol0003o8IH0ob6F0004ob6F0003o`000?lO
UP3o000000;o00000_o>[0000ol0003oc;<0olbc0004olbc0003o`000?nb`03o//0000Ko//000_l0
0003of6[0005o`000?m][P3oKJh0off^0?l000000om_[`001Ol0003oKjl0ofn_0?m_[`3o0000017o
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000Rooooo`00=_ooool3o`0003Co
oooo0_l00004obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o
9YP0obJH0003obJH0003o`000?lVV03o9YP000?o9YP000?o0000obFH0?lUV0000olUV0000ol0003o
9IP0obFH0004obFH0003o`000?lTV03o99P000?o99P000?o0000ob>G0?lSU`001?lSU`000ol0003o
8iL0ob>G0003ob>G0003o`000?lRU`3o8YL000?o8YL000?o0000ob6F0?lQUP000olQUP03o`0000Go
cZ`000?o0000olbc0?o</`001Oo</`000ol0003o//00ok;00005ok;000;o00000omQZ`001Ol0003o
KJh0off^0?m][P3o000000?oKjl000Co0000ofn_0?m_[`3oKjl00_l0000Aooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00008_ooool003Cooooo0_l0000eooooo`;o000000?o9YP0
o`000?lVV0000olVV0000ol0003o9YP0obJH0003obJH0003o`000?lVV03o9YP000?o9YP000?o0000
obJH0?lVV0000olVV0000ol0003o9YP0obJH0003obJH0003o`000?lUV03o9IP000Co9IP000?o0000
obFH0?lUV0000olUV0000ol0003o99P0obBH0003obBH0003o`000?lSU`3o8iL000Co8iL000?o0000
ob>G0?lSU`000olSU`000ol0003o8YL0ob:G0004ob:G0003o`000?lQUP3o8IH000;o000000?ocjT0
o`000?o>[0001_o>[0000ol0003oc;<0olbc0004olbc0003o`000?nb`03o//0000Go//000_l00002
of6[0005o`000?m][P3oKJh0off^0?l000000om_[`001Ol0003oKjl0ofn_0?m_[`3o000000;oKjl0
00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002;o
oooo000aooooo`?o0000=Oooool2o`0000?o9YP000?o0000obJH0?lVV0000_lVV0000ol0003o9YP0
obJH0003obJH0003o`000?lVV03o9YP000Co9YP000?o0000obJH0?lVV0000_lVV0000ol0003o9YP0
obJH0003obJH0003o`000?lUV03o9IP000Co9IP000?o0000obFH0?lUV0000olUV0000ol0003o99P0
obBH0003obBH0003o`000?lSU`3o8iL000Co8iL000?o0000ob>G0?lSU`000olSU`000ol0003o8YL0
ob:G0004ob:G00?o00000oo?Z@000ol0003ocZ`0olj/0005olj/0003o`000?o</`3oc;<000Coc;<0
00?o0000ok;00?nb`0001?nb`0000ol0003odih0o`000002of6[0005o`000?m][P3oKJh0off^0?l0
00000om_[`001Ol0003oKjl0ofn_0?m_[`3o000000?oKjl000?o0000ooooooooool03_ooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0002;ooooo000_ooooo`;o00000_ooool00ol0
003oooooooooo`0aooooo`;o00001OlVV0000ol0003o9YP0obJH0002obJH0003o`000?lVV03o9YP0
00?o9YP000?o0000obJH0?lVV0001?lVV0000ol0003o9YP0obJH0002obJH0003o`000?lVV03o9YP0
00?o9YP000?o0000obFH0?lUV0001?lUV0000ol0003o9IP0obFH0003obFH0003o`000?lTV03o99P0
00?o99P000?o0000ob>G0?lSU`001?lSU`000ol0003o8iL0ob>G0004ob>G0003o`000?lRU`3o8YL0
00;o8YL00_l00006olnY0003o`000?o>[03ocZ`000CocZ`000?o0000olbc0?o</`001?o</`000ol0
003o//00ok;00003ok;00004o`000?oCWP3odih0o`0000;oHJ/000Go0000off^0?m][P3oKJh0o`00
0003ofn_0005o`000?m_[`3oKjl0ofn_0?l000000om_[`000ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00008_ooool002cooooo0ol0000eooooo`?o0000
00?o9YP0o`000?lVV0001?lVV0000ol0003o9YP0obJH0002obJH0003o`000?lVV03o9YP000Co9YP0
00?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0002obJH0003o`000?lVV03o9YP000Co9YP0
00?o0000obFH0?lUV0000olUV0000ol0003o9IP0obFH0003obFH0003o`000?lTV03o99P000?o99P0
00?o0000ob>G0?lSU`001?lSU`000ol0003o8iL0ob>G0004ob>G0003o`000?lRU`3o000000;o0000
00?od:L0o`000?o?Z@001Oo?Z@000ol0003ocZ`0olj/0004olj/0003o`000?o</`3oc;<000Goc;<0
00Go0000ok;00?nb`03o//00o`000003om>N00;o000000?oHJ/0o`000?m][P000_m][P001Ol0003o
Kjl0ofn_0?m_[`3o000000?oKjl000Co0000ofn_0?m_[`3oKjl00_l0000?ooooo`;o00001Oooool2
o`0002?ooooo000Yooooo`?o0000=Oooool3o`0000Co9YP000?o0000obJH0?lVV0000olVV0000ol0
003o9YP0obJH0002obJH0003o`000?lVV03o9YP000Co9YP000?o0000obJH0?lVV0000olVV0000ol0
003o9YP0obJH0002obJH0003o`000?lVV03o9YP000Co9YP000?o0000obFH0?lUV0000olUV0000ol0
003o9IP0obFH0003obFH0003o`000?lTV03o99P000?o99P000?o0000ob>G0?lSU`001OlSU`000ol0
003o8iL0ob>G0002ob>G00?o00001?o@Y`000ol0003ocjT0olnY0004olnY0003o`000?o>[03ocZ`0
00GocZ`000?o0000olbc0?o</`001?o</`001Ol0003o//00ok;00?nb`03o000000?odih00ol00003
off^0005o`000?m_[`3oKjl0ofn_0?l000000om_[`001ol0003oKjl0ofn_0?m_[`3o0000ofn_0?l0
00004Oooool00ol0003oooooooooo`0Wooooo`009oooool4o`0003?ooooo0ol000000olVV03o0000
obJH0004obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0
obJH0003obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0
obJH0003obJH0003o`000?lUV03o9IP000?o9IP000?o0000obFH0?lUV0000olUV0000ol0003o99P0
obBH0004obBH0003o`000?lSU`3o8iL000Co8iL000?o0000ob>G0?l000000_l000000ooAY@3o0000
om2W0005om2W0003o`000?o?Z@3ocjT000CocjT000?o0000olj/0?o>[0001?o>[0000ol0003oc;<0
olbc0004olbc0004o`000?nb`03o//00o`0000?odih00_l000000ooCWP3o0000off^0002off^0005
o`000?m_[`3oKjl0ofn_0?l000000om_[`001Ol0003oKjl0ofn_0?m_[`3o000000;oKjl000?o0000
ooooooooool03oooool00ol0003oooooooooo`0Vooooo`009Oooool2o`0003Gooooo0_l00004obJH
0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003obJH
0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003obJH
0003o`000?lVV03o9YP000?o9YP000?o0000obFH0?lUV0000olUV0000ol0003o9IP0obFH0003obFH
0003o`000?lTV03o99P000Co99P000?o0000ob>G0?lSU`000olSU`03o`0000CodJD000?o0000om2W
0?o@Y`001?o@Y`000ol0003ocjT0olnY0004olnY0003o`000?o>[03ocZ`000CocZ`000?o0000olbc
0?o</`001Oo</`02o`000008om>N0?l0003o0000o`000?oCWP3o0000om>N0?l00003off^0005o`00
0?m_[`3oKjl0ofn_0?l000000om_[`001Ol0003oKjl0ofn_0?m_[`3o000000;oKjl000?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Vooooo`008_ooool3o`0003Cooooo0ol000000olUV03o
0000obJH0003obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0001?lVV0000ol0003o
9YP0obJH0002obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o
9YP0obJH0003obJH0003o`000?lVV03o9YP000?o9YP000?o0000obFH0?lUV0000olUV0000ol0003o
9IP0obFH0004obFH0003o`000?lTV03o99P000?o99P000?o0000ob>G0?lSU`000ol000000ooAX`3o
0000om6U0005om6U0003o`000?o@Y`3od:L000?od:L000?o0000olnY0?o?Z@001?o?Z@000ol0003o
cZ`0olj/0004olj/0003o`000?o</`3oc;<000Coc;<01?l00005om>N0003o`000?oHT03o000000;o
KJh000Go0000ofn_0?m_[`3oKjl0o`000003ofn_0005o`000?m_[`3oKjl0ofn_0?l000000_m_[`02
o`00017ooooo00?o0000ooooooooool09Oooool0027ooooo0_l0000cooooo`?o00001?lUV0000ol0
003o9YP0obJH0002obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0001?lVV0000ol0
003o9YP0obJH0002obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0
003o9YP0obJH0003obJH0003o`000?lVV03o9YP000?o9YP000?o0000obFH0?lUV0000olUV0000ol0
003o9IP0obFH0004obFH0003o`000?lTV03o99P000?o99P00ol00004om6S0003o`000?oAY@3odJD0
00CodJD000?o0000om2W0?o@Y`001?o@Y`000ol0003ocjT0olnY0003olnY0003o`000?o>[03ocZ`0
00CocZ`000Co0000olbc0?o</`3oc;<01Ol00006om>N0004o`000?oHT03o0000omR@00;o00001?m_
[`001?l0003oKjl0ofn_0?l00003ofn_0007o`000?m_[`3oKjl0ofn_0?l0003oKjl0o`00000Aoooo
o`03o`000?oooooooooo02Cooooo000Qooooo`?o0000;oooool3o`000003obFH0?l0003o9IP000Co
9IP000?o0000obJH0?lVV0000_lVV0000ol0003o9YP0obJH0004obJH0003o`000?lVV03o9YP000?o
9YP000?o0000obJH0?lVV0000_lVV0000ol0003o9YP0obJH0003obJH0003o`000?lVV03o9YP000?o
9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003obJH0003o`000?lUV03o9IP000Co
9IP000?o0000obFH0?lUV0000olUV0000ol0003o99P0obBH0002obBH00;o00001ooAX`000ol0003o
dJD0om6U0003om6U0003o`000?o@Y`3od:L000Cod:L000?o0000olnY0?o?Z@001?o?Z@000ol0003o
cZ`0olj/0004olj/00Co00001?oPMP000ol0003odih0om>N0002om>N0007o`000?oHT03of900omR@
0?l0003of900o`000003ofn_0005o`000?m_[`3oKjl0ofn_0?l000000om_[`001?l0003oKjl0ofn_
0?l00003ofn_0003o`000?oooooooooo00kooooo0_l0000Uooooo`008Oooool01?l0003ooooooooo
ool0000/ooooo`;o00001?lUV0000ol0003o9IP0obFH0003obFH0003o`000?lVV03o9YP000;o9YP0
00?o0000obJH0?lVV0001?lVV0000ol0003o9YP0obJH0003obJH0003o`000?lVV03o9YP000;o9YP0
00?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003obJH0003o`000?lVV03o9YP000?o9YP0
00?o0000obJH0?lVV0000olVV0000ol0003o9IP0obFH0004obFH0003o`000?lUV03o9IP000?o9IP0
00?o0000obBH0?l000000_l000000ooBXP3o0000om6S0006om6S0003o`000?oAY@3odJD000?odJD0
00?o0000om2W0?o@Y`001?o@Y`000ol0003ocjT0olnY0004olnY0003o`000?o>[03ocZ`000;ocZ`0
0ol00007on1f0003o`000?oCWP3odih000;odih000Oo0000omR@0?oHT03of900o`000?oHT03o0000
00?oKjl000Go0000ofn_0?m_[`3oKjl0o`000003ofn_0004o`000?m_[`3oKjl0o`0000?oKjl000?o
0000ooooooooool03oooool00ol0003oooooooooo`0Sooooo`008Oooool01Ol0003ooooooooooooo
oooo000002Sooooo0ol000000olUV03o0000obFH0003obFH0003o`000?lUV03o9IP000?o9IP000?o
0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003obJH0003o`000?lVV03o9YP000?o9YP000?o
0000obJH0?lVV0000_lVV0000ol0003o9YP0obJH0003obJH0003o`000?lVV03o9YP000?o9YP000?o
0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003obJH0003o`000?lUV03o9IP000Co9IP000?o
0000obFH0?lUV0000_lUV003o`0000CodZ8000?o0000om6S0?oAX`001OoAX`000ol0003odJD0om6U
0003om6U0003o`000?o@Y`3od:L000Cod:L000?o0000olnY0?o?Z@001?o?Z@000ol0003ocZ`0o`00
0003o`000003on=/0?l0003oh7H000Ooh7H000Co0000om>N0?oCWP3o00001OoHT0000ol0003ofX/0
o`000002ofn_0005o`000?m_[`3oKjl0ofn_0?l000000om_[`001?l0003oKjl0ofn_0?l00003ofn_
00;o00004Oooool00ol0003oooooooooo`0Rooooo`008?ooool3o`0000?ooooo00?o0000oooooooo
ool08oooool2o`0000Co9IP000?o0000obFH0?lUV0000_lUV0000ol0003o9IP0obFH0003obFH0003
o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003obJH0003
o`000?lVV03o9YP000;o9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003obJH0003
o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0001?lVV0000ol0003o9IP0obFH0003obFH0003
o`000?lUV03o000000;o000000?odZ00o`000?oBXP001OoBXP000ol0003odJ<0om6S0004om6S0003
o`000?oAY@3odJD000CodJD000?o0000om2W0?o@Y`001?o@Y`000ol0003ocjT0olnY0002olnY00Go
00001?oSK0000ol0003oh7H0on1f0005on1f0003o`000?oCWP3o000000Gof90000Oo0000omZ;0?l0
003ofX/0o`000?m_[`3o000000?oKjl000Co0000ofn_0?m_[`3o00000om_[`001?l0003oKjl0ofn_
0?l00002ofn_0003o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool0023ooooo0ol0
0004ooooo`03o`000?oooooooooo01oooooo0ol000000olTV03o0000obFH0003obFH0003o`000?lU
V03o9IP000;o9IP000?o0000obFH0?lUV0001?lUV0000ol0003o9YP0obJH0002obJH0003o`000?lV
V03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0002obJH0003o`000?lV
V03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003obJH0003o`000?lV
V03o9YP000Co9YP000?o0000obFH0?lUV0000_lUV003o`0000CodZ0000?o0000om:R0?oBXP001?oB
XP000ol0003odJ<0om6S0004om6S0003o`000?oAY@3odJD000CodJD000?o0000om2W0?o@Y`001?o@
Y`000ol0003ocjT0o`000002o`000003olnY0?l0003o000000Kohf`000?o0000on1f0?oPMP001OoP
MP02o`0000Kof90000?o0000omZ;0?oJR`000ol00003ofn_0005o`000?m_[`3oKjl0ofn_0?l00000
0om_[`001?l0003oKjl0ofn_0?l00003ofn_0003o`000?oooooooooo00kooooo00?o0000oooooooo
ool08Oooool0023ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Kooooo`?o0000
1?lTV0000ol0003o9IP0obFH0002obFH0003o`000?lUV03o9IP000;o9IP000?o0000obFH0?lUV000
1?lUV0000ol0003o9YP0obJH0002obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV000
0olVV0000ol0003o9YP0obJH0002obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV000
1?lVV0000ol0003o9YP0obJH0003obJH0003o`000?lVV03o9YP000?o9YP000?o0000obFH0?lUV000
0_l000000ooCW`3o0000om:P0005om:P0003o`000?oBXP3odZ8000?odZ8000?o0000om6S0?oAX`00
1OoAX`000ol0003odJD0om6U0003om6U0003o`000?o@Y`3od:L000Cod:L00_l00002olnY00;o0000
00?oiFL0o`000?oSK0001_oSK0000ol0003oh7H0on1f0003on1f0003o`000?oVI03o000000Gof900
00Oo0000omZ;0?oJR`3ofX/0o`000?oJR`3o000000?oKjl000Go0000ofn_0?m_[`3oKjl0o`000002
ofn_0005o`000?m_[`3oKjl0ofn_0?l000000om_[`000ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo027ooooo000Pooooo`Co00001Oooool00ol0003oooooooooo`0Gooooo`?o000000?o8iL0
o`000?lTV0001?lTV0000ol0003o9IP0obFH0002obFH0003o`000?lUV03o9IP000?o9IP000?o0000
obFH0?lUV0000olUV0000ol0003o9YP0obJH0002obJH0003o`000?lVV03o9YP000?o9YP000?o0000
obJH0?lVV0000olVV0000ol0003o9YP0obJH0002obJH0003o`000?lVV03o9YP000?o9YP000?o0000
obJH0?lVV0001?lVV0000ol0003o9YP0obJH0003obJH0003o`000?lVV03o9YP000?o9YP00ol00003
om>O0003o`000?oBX03odZ0000CodZ0000?o0000om:R0?oBXP001?oBXP000ol0003odJ<0om6S0004
om6S0003o`000?oAY@3odJD000?odJD000Co0000om2W0?o@Y`3od:L00ol000001?o@Y`3o0000o`00
0?l00004onEW0003o`000?oSK03ohf`000Gohf`000?o0000on1f0?oPMP000_l00003onIT0005o`00
0?oHT03of900omR@0?l000001OoJR`02o`0000?oKjl000Go0000ofn_0?m_[`3oKjl0o`000002ofn_
0005o`000?m_[`3oKjl0ofn_0?l000000om_[`02o`00013ooooo0_l0000Qooooo`008?ooool01?l0
003oooooo`000?l00006ooooo`03o`000?oooooooooo01Cooooo0_l00004ob>G0003o`000?lTV03o
99P000?o99P000?o0000obFH0?lUV0000_lUV0000ol0003o9IP0obFH0003obFH0003o`000?lUV03o
9IP000?o9IP000?o0000obJH0?lVV0000_lVV0000ol0003o9YP0obJH0003obJH0003o`000?lVV03o
9YP000?o9YP000?o0000obJH0?lVV0000_lVV0000ol0003o9YP0obJH0004obJH0003o`000?lVV03o
9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0002obJH00;o00001_oCW`00
0ol0003odZ00om:P0003om:P0003o`000?oBXP3odZ8000CodZ8000?o0000om6S0?oAX`001?oAX`00
0ol0003odJD0om6U0003om6U00Co00000_o@Y`03o`0000KoiFL000?o0000on=/0?oSK0001OoSK000
0ol0003oh7H0o`000006onIT0004o`000?oHT03of900o`0000GofX/00ol00002ofn_0005o`000?m_
[`3oKjl0ofn_0?l000000_m_[`001?l0003oKjl0ofn_0?l00003ofn_0004o`000?m_[`3oKjl0o`00
00oooooo0_l0000Qooooo`008?ooool4o`0000Oooooo00?o0000ooooooooool04?ooool3o`000003
ob:G0?l0003o8iL000?o8iL000?o0000obBH0?lTV0000olTV0000ol0003o9IP0obFH0002obFH0003
o`000?lUV03o9IP000?o9IP000?o0000obFH0?lUV0000olUV0000ol0003o9YP0obJH0002obJH0003
o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0002obJH0003
o`000?lVV03o9YP000Co9YP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003obJH0003
o`000?lVV03o000000;o000000?odih0o`000?oCW`001OoCW`000ol0003odZ00om:P0004om:P0003
o`000?oBXP3odZ8000?odZ8000?o0000om6S0?oAX`001?oAX`001?l0003odJD0om6U0?oAY@04o`00
0004om2W0?l0003o0000o`0000;oiV@000?o0000onEW0?oUI`001OoUI`000ol0003ohf`0on=/0004
on=/00;o00001ooVI0000ol0003of900o`000005omZ;0004o`000?oKR03o0000om^800;o00000om_
[`001Ol0003oKjl0ofn_0?m_[`3o000000;oKjl000Go0000ofn_0?m_[`3oKjl0o`000002ofn_0003
o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool001oooooo0_l000000ooooooo0000
o`000008ooooo`03o`000?oooooooooo00gooooo0_l00004ob:G0003o`000?lSU`3o8iL000;o8iL0
00?o0000obBH0?lTV0000olTV0000ol0003o9IP0obFH0002obFH0003o`000?lUV03o9IP000?o9IP0
00?o0000obFH0?lUV0000olUV0000ol0003o9YP0obJH0002obJH0003o`000?lVV03o9YP000?o9YP0
00?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003obJH0003o`000?lVV03o9YP000?o9YP0
00?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0002obJH00?o00001?oCWP000ol0003odil0
om>O0004om>O0003o`000?oBX03odZ0000CodZ0000?o0000om:R0?oBXP000ooBXP000ol0003odJ<0
om6S0004om6S00Co00000_oAY@03o`0000KoiV@000?o0000onEW0?oUI`001?oUI`001?l0003ohf`0
on=/0?oSK003o`000003onUH0?l0003oiV@000KoiV@00_l00006omZ;0006o`000?oKR03ofhP0o`00
0?oKR03o00000om_[`001Ol0003oKjl0ofn_0?m_[`3o000000;oKjl000Go0000ofn_0?m_[`3oKjl0
o`000002ofn_00;o00004?ooool00ol0003oooooooooo`0Nooooo`001_ooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000?ooooo0ol00005ooooo`06o`000?ooooooooooo`000?l0ED_o
00002?ooool00ol0003oooooooooo`09ooooo`?o000000?o8IL0o`000?lRU`000olRU`000ol0003o
8iL0ob>G0002ob>G0003o`000?lTV03o99P000?o99P000?o0000obFH0?lUV0000_lUV0000ol0003o
9IP0obFH0003obFH0003o`000?lUV03o9IP000?o9IP000?o0000obJH0?lVV0000_lVV0000ol0003o
9YP0obJH0003obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0000ol0003o
9YP0obJH0003obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?l000000_l000000ooCW@3o
0000om>N0005om>N0003o`000?oCW`3odil000?odil000?o0000om:P0?oBX0001?oBX0000ol0003o
dZ80om:R0004om:R0004o`000?oAX`3odJ<0om6S00Co000000KodJD0o`000?l0003o0000onMQ0?l0
0007onIT0003o`000?oUI`3oiFL000CoiFL000Co0000on=/0?l0003o00001OoYF0000ol0003oiV@0
onIT0003onIT0003o`000?oWGP3o000000GofX/000?o0000om^80?oKR0000_oKR002o`0000?oKjl0
00Co0000ofn_0?m_[`3o00000om_[`001Ol0003oKjl0ofn_0?m_[`3o000000;oKjl000?o0000ofn_
0?l000004?ooool00ol0003oooooooooo`0Mooooo`001Oooool01?l0003oooooooooool00009oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`;o000000Cooooo
o`000?l0ED_o00002Oooool00ol0003oooooooooo`05ooooo`?o00001?lQU`000ol0003o8YL0ob:G
0002ob:G0003o`000?lSU`3o8iL000;o8iL000?o0000obBH0?lTV0000olTV0000ol0003o9IP0obFH
0002obFH0003o`000?lUV03o9IP000?o9IP000?o0000obFH0?lUV0000olUV0000ol0003o9YP0obJH
0002obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0001?lVV0000ol0003o9YP0obJH
0002obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000_lVV003o`0000Codid000?o
0000om>N0?oCWP001?oCWP000ol0003odil0om>O0003om>O0003o`000?oBX03odZ0000CodZ0000?o
0000om:R0?oBXP001?oBXP04o`0000;odJ<00ol00005onMQ0003o`000?oVI03oiV@000GoiV@000?o
0000onEW0?oUI`000ooUI`02o`0000SojEP000?o0000onIT0?oVI0000_l00003onMN0005o`000?oJ
R`3ofX/0omZ;0?l000001OoKR003o`0000;oKjl000Co0000ofn_0?m_[`3o00000_m_[`001Ol0003o
Kjl0ofn_0?m_[`3o000000;oKjl000Go0000ofn_0?m_[`3oKjl0o`00000?ooooo`03o`000?oooooo
oooo01gooooo0005ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooo`000?l0ED/00_l00009ooooo`;o00000_oo
ool3o`000003ob2F0?l0003o8IL000Co8IL000?o0000ob:G0?lRU`000_lRU`000ol0003o8iL0ob>G
0003ob>G0003o`000?lTV03o99P000;o99P000?o0000obFH0?lUV0000_lUV0000ol0003o9IP0obFH
0003obFH0003o`000?lUV03o9IP000?o9IP000?o0000obJH0?lVV0000_lVV0000ol0003o9YP0obJH
0003obJH0003o`000?lVV03o9YP000Co9YP000?o0000obJH0?lVV0000_lVV0000ol0003o9YP0obJH
0003obJH0003o`000?lVV03o000000;o000000?oe9d0o`000?oCW@001OoCW@000ol0003odih0om>N
0003om>N0003o`000?oCW`3odil000Codil000?o0000om:P0?oBX0001?oBX0001?l0003odZ80om:R
0?oBXP03o`0000?odJ<00_l000000ooWGP3o0000onMQ0005onMQ0003o`000?oVI03oiV@000GoiV@0
00?o0000onEW0?oUI`000ol000000oo[D`3o0000onUH0007onUH0003o`000?oVI03o000000Koieh0
00Co0000omZ;0?oJR`3o00001?oKR0001?l0003ofhH0o`000?oKQP02o`0000?oKjl000Co0000ofn_
0?m_[`3o00000om_[`001?l0003oKjl0ofn_0?l00003ofn_0003o`000?oooooooooo00gooooo0_l0
000Nooooo`001Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooooooool2o`000003o`214_l0003ooooo00Sooooo
0ol00004ob2F0003o`000?lQU`3o8IL000?o8IL000?o0000ob:G0?lRU`000_lRU`000ol0003o8iL0
ob>G0003ob>G0003o`000?lTV03o99P000;o99P000?o0000obFH0?lUV0000_lUV0000ol0003o9IP0
obFH0003obFH0003o`000?lUV03o9IP000?o9IP000?o0000obJH0?lVV0000_lVV0000ol0003o9YP0
obJH0004obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000_lVV0000ol0003o9YP0
obJH0002obJH00?o00001?oDW@000ol0003odid0om>M0004om>M0003o`000?oCWP3odih000?odih0
00?o0000om>O0?oCW`001?oCW`000ol0003odZ00om:P0004om:P00Co00000ooBXP03o`0000Coieh0
00?o0000onMQ0?oWH@001?oWH@000ol0003oiV@0onIT0004onIT00?o00001Oo[D`000ol0003ojEP0
onUH0004onUH00?o00001ooWGP000ol0003ofX/0o`000005om^80006o`000?oKQP3ofhH0o`000?oK
QP3o00000om_[`001?l0003oKjl0ofn_0?l00003ofn_0004o`000?m_[`3oKjl0o`0000?oKjl00_l0
000@ooooo`03o`000?oooooooooo01_ooooo0005ooooo`04o`000?ooooooooooo`0000Wooooo00Co
0000oooooooooooooooo1?l00005ooooo`;o00000_ooool2o`0000;o084B00Co0000oooooooooooo
oooo1Ol00002oajE0003o`000?lPUP3o89H000;o89H000?o0000ob6G0?lQU`000olQU`000ol0003o
8YL0ob:G0002ob:G0003o`000?lSU`3o8iL000?o8iL000?o0000obBH0?lTV0000_lTV0000ol0003o
9IP0obFH0002obFH0003o`000?lUV03o9IP000?o9IP000?o0000obFH0?lUV0000olUV0000ol0003o
9YP0obJH0002obJH0003o`000?lVV03o9YP000Co9YP000?o0000obJH0?lVV0000olVV0000ol0003o
9YP0obJH0002obJH0003o`000?lVV03o000000;o000000?oe9d0o`000?oDW@001OoDW@000ol0003o
did0om>M0003om>M0003o`000?oCWP3odih000?odih000?o0000om>O0?oCW`001?oCW`000ol0003o
dZ00om:P0003om:P00;o00001OoBXP02o`0000Koieh000?o0000onMQ0?oWH@001OoWH@001?l0003o
iV@0onIT0?oVI002o`000003ona?0?l0003oje<000Koje<000?o0000onUH0?oYF0000ol00002on]A
0003o`000?oWGP3oieh000Goieh00_l00005om^80003o`000?oKQP3ofhH000;ofhH00_l00003ofn_
0004o`000?m_[`3oKjl0o`0000?oKjl000Co0000ofn_0?m_[`3o00000om_[`02o`00013ooooo00?o
0000ooooooooool06oooool000Gooooo00Co0000oooooooooooo00002?ooool2o`0000?ooooo00?o
0000ooooooooool01Oooool2o`0000?ooooo0_l00003o`214P?o00000_lDT@000ol0003o7YD0oajE
0002oajE0003o`000?lPUP3o89H000;o89H000?o0000ob6G0?lQU`000olQU`000ol0003o8YL0ob:G
0002ob:G0003o`000?lSU`3o8iL000?o8iL000?o0000obBH0?lTV0000_lTV0000ol0003o9IP0obFH
0003obFH0003o`000?lUV03o9IP000;o9IP000?o0000obFH0?lUV0000olUV0000ol0003o9YP0obJH
0003obJH0003o`000?lVV03o9YP000?o9YP000?o0000obJH0?lVV0000olVV0001?l0003o9YP0obJH
0?lVV003o`0000Coe9d000?o0000omBM0?oDW@001?oDW@000ol0003odid0om>M0003om>M0003o`00
0?oCWP3odih000Codih000?o0000om>O0?oCW`000ooCW`000ol0003odZ00om:P0003o`0000;odZ00
00?o0000om:R0?l000000_l000000ooXF`3o0000onMN0006onMN0003o`000?oWH@3oif4000Coif40
00Co0000onIT0?l0003o00001?o/C`000ol0003oje<0on]C0004on]C00?o00001_o[D@000ol0003o
ieh0onMN0002onMN00;o000000?ojET0o`000?oKR0000ooKR0000ol0003ofhH0om^60003om^600?o
000000?oKjl0o`000?m_[`000_m_[`001?l0003oKjl0ofn_0?l00003ofn_0004o`000?m_[`3oKjl0
o`0000;oKjl000?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`001_ooool2o`00
00[ooooo00Co0000oooooooooooooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0_l00003
o`214P03o`000?lDT@3o594000;o594000?o0000oajE0?lNU@000_lNU@000ol0003o89H0ob2F0002
ob2F0003o`000?lQU`3o8IL000?o8IL000?o0000ob:G0?lRU`000_lRU`000ol0003o8iL0ob>G0003
ob>G0003o`000?lTV03o99P000;o99P000?o0000obFH0?lUV0000olUV0000ol0003o9IP0obFH0002
obFH0003o`000?lUV03o9IP000?o9IP000?o0000obJH0?lVV0000olVV0000ol0003o9YP0obJH0003
obJH0003o`000?lVV03o9YP000?o9YP01?l000000ooDW@3o0000omBM0005omBM0003o`000?oDW@3o
e9d000?oe9d000?o0000om>M0?oCW@000ooCW@000ol0003odih0om>N0004om>N0003o`000?oCW`3o
dil000?odil00ol00003om:P00Co00001OoXF`000ol0003oieh0onMN0004onMN0003o`000?oWH@3o
if4000?oif400ol00007ona?0004o`000?o[D`3oje<0on]C00;o000000?ok4`0o`000?o[D@001oo[
D@001?l0003oieh0o`000?l00004onUI0005o`000?oKR03ofhP0om^80?l000001?oKQP001?l0003o
g8@0o`000?oLQ002o`0000;oKjl000Go0000ofn_0?m_[`3oKjl0o`000002ofn_0005o`000?m_[`3o
Kjl0ofn_0?l000000_m_[`02o`00013ooooo00?o0000ooooooooool06Oooool001kooooo0_l00003
ooooo`;o00000ol0PA800ol0003o5940oaBA0002oaBA0003o`000?lNU@3o7YD000;o7YD000?o0000
ob2F0?lPUP000_lPUP000ol0003o8IL0ob6G0003ob6G0003o`000?lRU`3o8YL000;o8YL000?o0000
ob>G0?lSU`000olSU`000ol0003o99P0obBH0003obBH0003o`000?lUV03o9IP000;o9IP000?o0000
obFH0?lUV0000_lUV0000ol0003o9IP0obFH0004obFH0003o`000?lVV03o9YP000;o9YP000?o0000
obJH0?lVV0000olVV0000ol0003o9YP0obJH0002obJH00;o00001?oDW@000ol0003oe9d0omBM0004
omBM0003o`000?oDW@3oe9d000?oe9d000?o0000om>M0?oCW@001?oCW@000ol0003odih0om>N0003
om>N0003o`000?oCW`3odil000?o000000?odil0o`000?oBX0000ol00002onUI0003o`000?oXF`3o
j5/000Coj5/000?o0000onMN0?oWGP001?oWGP000ol0003oif40onMQ0003o`0000;okD`000?o0000
ona?0?o/C`001Oo/C`001?l0003oje<0o`000?l00004ona<0003o`000?o[D@3oje4000Goje400_l0
0007onUI0003o`000?oKR03o000000GofhH000Ko0000omb40?oLQ03o0000omb40?l00002ofn_0005
o`000?m_[`3oKjl0ofn_0?l000000_m_[`001Ol0003oKjl0ofn_0?m_[`3o000000;oKjl000?o0000
ofn_0?l000003oooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`02oooo
o`;o00000ol0PA800ol0003o5940oaBA0002oaBA0003o`000?lNU@3o7YD000;o7YD000?o0000ob2F
0?lPUP000_lPUP000ol0003o8IL0ob6G0003ob6G0003o`000?lRU`3o8YL000;o8YL000?o0000ob>G
0?lSU`000olSU`000ol0003o99P0obBH0003obBH0003o`000?lUV03o9IP000;o9IP000?o0000obFH
0?lUV0000_lUV0000ol0003o9IP0obFH0004obFH0003o`000?lVV03o9YP000;o9YP000?o0000obJH
0?lVV0000olVV0000ol0003o9YP0o`000002o`000003omBM0?l0003oe9d000Coe9d000?o0000omBM
0?oDW@000ooDW@000ol0003oe9d0omBM0003omBM0003o`000?oCW@3odid000Codid000?o0000om>N
0?oCWP000ooCWP03o`0000?odil00ol00006onUI0003o`000?oXF`3oj5/000Coj5/000?o0000onMN
0?oWGP000ooWGP03o`0000KokD`000?o0000ona?0?o/C`001?o/C`02o`0000Ook4`000Co0000on]A
0?o[D@3oje400ol000000oo/C@3o0000onUI0006onUI00;o00001OoKQP000ol0003og8@0omb40002
omb400;o00000_m_[`001Ol0003oKjl0ofn_0?m_[`3o000000;oKjl000Go0000ofn_0?m_[`3oKjl0
o`000002ofn_0004o`000?m_[`3oKjl0o`0000kooooo0_l00007ooooo`?o00004?ooool001kooooo
00?o0000ooooooooool00_ooool2o`0000?o084B00?o0000oaBA0?lDT@000_lDT@000ol0003o7YD0
oajE0002oajE0003o`000?lPUP3o89H000;o89H000?o0000ob6G0?lQU`000olQU`000ol0003o8YL0
ob:G0002ob:G0003o`000?lSU`3o8iL000?o8iL000?o0000obBH0?lTV0000olTV0000ol0003o9IP0
obFH0002obFH0003o`000?lUV03o9IP000?o9IP000?o0000obFH0?lUV0000olUV0000ol0003o9YP0
obJH0002obJH0003o`000?lVV03o9YP000;o9YP00ol00004omBM0003o`000?oDW@3oe9d000?oe9d0
00?o0000omBM0?oDW@000ooDW@000ol0003oe9d0omBM0004omBM0003o`000?oCW@3odid000?odid0
00?o0000om>N0?oCWP001?l00003om>O00;o000000?ojEL0o`000?oYF@001_oYF@000ol0003oj5/0
onQK0004onQK0003o`000?oWGP3oieh000?o000000?okDT0o`000?o]C0001oo]C0000ol0003ok4l0
ona?0003o`000003one80?l0003ok4`000Kok4`000Co0000on]A0?l0003o00001Oo/C@000ol0003o
jET0onUI0003onUI0003o`000?oZE@3o000000CofhH000?o0000omb40?oLQ0000ooLQ003o`000003
ofn_0?l0003oKjl000;oKjl000Co0000ofn_0?m_[`3o00000om_[`000ol0003oKjl0o`000003ofn_
0003o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000oooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00003o`214P03o`000?lDT@3o5940
00;o594000?o0000oajE0?lNU@000_lNU@000ol0003o89H0ob2F0002ob2F0003o`000?lQU`3o8IL0
00?o8IL000?o0000ob:G0?lRU`000olRU`000ol0003o8iL0ob>G0002ob>G0003o`000?lTV03o99P0
00?o99P000?o0000obFH0?lUV0000_lUV0000ol0003o9IP0obFH0003obFH0003o`000?lUV03o9IP0
00?o9IP000?o0000obJH0?lVV0000_lVV0000ol0003o9YP0o`000002o`000003om>M0?l0003oe9d0
00Goe9d000?o0000omBM0?oDW@000_oDW@000ol0003oe9d0omBM0003omBM0003o`000?oDW@3oe9d0
00Coe9d000?o0000om>M0?oCW@000ooCW@03o`0000Codih00ol00004onUG0003o`000?oYF@3ojET0
00GojET000?o0000onQK0?oXF`000ooXF`03o`0000GokDT000?o0000one<0?o]C0001Oo]C003o`00
00GokDP000?o0000ona<0?o/C0001?o/C002o`0000Sok4d000?o0000onUI0?oYF@000_l00003onYE
0005o`000?oKQP3ofhH0om^60?l000001?oLQ0000ol0003ogH80o`000002o`0000?oKjl000Go0000
ofn_0?m_[`3oKjl0o`000002ofn_0004o`000?m_[`3oKjl0o`0000?oKjl00_l0000?ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03Oooool001gooooo0ol00004ooooo`05o`000?l0
PA;o084Bo`214_l000001?lDT@000ol0003o7YD0oajE0002oajE0003o`000?lPUP3o89H000;o89H0
00?o0000ob6G0?lQU`000olQU`000ol0003o8YL0ob:G0003ob:G0003o`000?lSU`3o8iL000;o8iL0
00?o0000obBH0?lTV0000olTV0000ol0003o9IP0obFH0002obFH0003o`000?lUV03o9IP000?o9IP0
00?o0000obFH0?lUV0000olUV0001?l0003o9YP0obJH0?lVV003o`0000Codid000?o0000omBM0?oD
W@001?oDW@000ol0003oe9d0omBM0003omBM0003o`000?oDW@3oe9d000?oe9d000?o0000omBM0?oD
W@000ooDW@000ol0003odid0om>M0004o`0000Godih00_l00006onUG0003o`000?oYF@3ojET000Go
jET000Co0000onQK0?oXF`3oj5/00_l000000oo^AP3o0000one90006one90003o`000?o]C03okD`0
00;okD`00_l000000oo^A@3o0000one80006one80003o`000?o/C03ok4`000?o00000_o^A`000ol0
003ok4d0ona=0005ona=0003o`000?oYF@3o000000KojUD000?o0000om^60?l000001OoLQ0000ol0
003ogH80omf20002o`0000?oKjl000Co0000ofn_0?m_[`3o00000om_[`001?l0003oKjl0ofn_0?l0
0003ofn_00;o00004?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo000M
ooooo`03o`000?oooooooooo00Cooooo0_l00002o`214P03o`000?lDT@3o594000;o594000?o0000
oajE0?lNU@000_lNU@000ol0003o89H0ob2F0002ob2F0003o`000?lQU`3o8IL000Co8IL000?o0000
ob:G0?lRU`000_lRU`000ol0003o8iL0ob>G0002ob>G0003o`000?lTV03o99P000?o99P000?o0000
obFH0?lUV0000_lUV0000ol0003o9IP0obFH0003obFH0003o`000?lUV03o9IP000?o9IP01?l00000
0ooCWP3o0000om>M0005om>M0003o`000?oDW@3oe9d000?oe9d000?o0000omBM0?oDW@000ooDW@00
0ol0003oe9d0omBM0003omBM0003o`000?oDW@3oe9d000?oe9d00ol00004om>M0003o`000?oCWP3o
000000;o000000?ojUH0o`000?oYE`001_oYE`000ol0003ojET0onUI0004onUI0004o`000?oXF`3o
0000o`0000CokTH000?o0000one90?o]B@001Oo]B@001?l0003okD`0o`000?l00004oni50003o`00
0?o]B03okDP000CokDP00ol00006oni70003o`000?o/C@3ok4d000Cok4d00_l00007onYE00;o0000
1OoLQ0000ol0003ogH80omf20002omf20005o`000?m_[`3oKjl0ofn_0?l000000_m_[`001Ol0003o
Kjl0ofn_0?m_[`3o000000;oKjl000Co0000ofn_0?m_[`3o00000_m_[`000ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00;ooooo1?l0000@ooooo`007Oooool3o`0000Cooooo0_l00002o`21
4P03o`000?lDT@3o594000;o594000?o0000oajE0?lNU@000_lNU@000ol0003o89H0ob2F0002ob2F
0003o`000?lQU`3o8IL000Co8IL000?o0000ob:G0?lRU`000_lRU`000ol0003o8iL0ob>G0002ob>G
0003o`000?lTV03o99P000?o99P000?o0000obFH0?lUV0000_lUV0000ol0003o9IP0obFH0003obFH
0003o`000?lUV03o9IP000;o9IP00_l00004om>N0003o`000?oCW@3odid000Codid000?o0000omBM
0?oDW@000ooDW@000ol0003oe9d0omBM0003omBM0003o`000?oDW@3oe9d000?oe9d000Co0000omBM
0?oDW@3oe9d00ol00005om>M00?o00001OoZEP000ol0003ojEL0onUG0005onUG0003o`000?oYF@3o
jET000?ojET00_l00007oni60003o`000?o]B@3okDT000?okDT00ol00007oni50004o`000?o]B03o
kDP0one800;o000000?okd<0o`000?o^A`001oo^A`000ol0003ok4d0ona=0003o`000003oni80?l0
003ojUD000GojUD000?o0000on]B0?l000001?oLQ0000ol0003ogH80omf20002omf20003o`000?oM
P@3o000000;oKjl000Co0000ofn_0?m_[`3o00000om_[`001?l0003oKjl0ofn_0?l00002ofn_0003
o`000?m_[`3oKjl000;o00003oooool01Ol0003ooooooooooooooooo000001?ooooo000Mooooo`03
o`000?oooooooooo00Cooooo0_l00002o`214P03o`000?lDT@3o594000;o594000?o0000oajE0?lN
U@000_lNU@000ol0003o89H0ob2F0003ob2F0003o`000?lQU`3o8IL000?o8IL000?o0000ob:G0?lR
U`000_lRU`000ol0003o8iL0ob>G0002ob>G0003o`000?lTV03o99P000?o99P000?o0000obFH0?lU
V0000_lUV0000ol0003o9IP0obFH0003obFH0003o`000?lUV03o000000;o000000?odih0o`000?oC
WP001?oCWP000ol0003odid0om>M0003om>M0003o`000?oDW@3oe9d000?oe9d000?o0000omBM0?oD
W@000ooDW@000ol0003oe9d0omBM0003omBM00Co00000ooDW@000ol0003odid0o`000002o`000003
onYE0?l0003ojUH000KojUH000?o0000onUG0?oYE`001?oYE`000ol0003ojET0onUI0003o`000003
onm40?l0003okTH000KokTH000?o0000one90?o]B@000ol00002onm20003o`000?o^A@3okTD000Go
kTD000Co0000one80?l0003o00001?o_@`000ol0003okTL0oni70004oni700Co00001Oo^B0001?l0
003ojUD0onYE0?oZE@02o`0000?oje8000Go0000omb40?oLQ03og8@0o`000004omf20003o`000?oM
P@3o000000;o00000om_[`001ol0003oKjl0ofn_0?m_[`3o0000ofn_0?l000000om_[`001_l0003o
Kjl0ofn_0?l0003oKjl0o`0000gooooo0ol00002ooooo`Go00003oooool000[ooooo0_l00004oooo
o`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`04ooooo`;o00000_l0PA80
0ol0003o5940oaBA0002oaBA0003o`000?lNU@3o7YD000;o7YD000?o0000ob2F0?lPUP000olPUP00
0ol0003o8IL0ob6G0003ob6G0003o`000?lRU`3o8YL000;o8YL000?o0000ob>G0?lSU`000olSU`00
0ol0003o99P0obBH0002obBH0003o`000?lUV03o9IP000;o9IP000?o0000obFH0?lUV0000_lUV003
o`0000Codih000?o0000om>N0?oCWP000ooCWP000ol0003odid0om>M0003om>M0003o`000?oDW@3o
e9d000Coe9d000?o0000omBM0?oDW@000ooDW@000ol0003oe9d0omBM0003o`0000Goe9d00ol00005
onYE0003o`000?oZEP3ojUH000CojUH000?o0000onUG0?oYE`001?oYE`03o`0000Gokd@000?o0000
oni60?o^AP001?o^AP03o`0000Kokd8000?o0000oni50?o^A@001?o^A@02o`0000Ookd<000?o0000
oni70?o^A`000ol00002onm30003o`000?o^B03okTP000GokTP000?o0000onYE0?l000001_o[DP00
0ol0003og8@0o`000004omf20004o`000?oMP@3ogH40omf100;o00000om_[`001?l0003oKjl0ofn_
0?l00002ofn_0005o`000?m_[`3oKjl0ofn_0?l000000_m_[`001?l0003oKjl0ofn_0?l0000>oooo
o`03o`000?oooooooooo01Cooooo0009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`04ooooo`;o00000_l0PA800ol0003o5940oaBA0002
oaBA0003o`000?lNU@3o7YD000?o7YD000?o0000ob2F0?lPUP000_lPUP000ol0003o8IL0ob6G0003
ob6G0003o`000?lRU`3o8YL000;o8YL000?o0000ob>G0?lSU`000olSU`000ol0003o99P0obBH0002
obBH0003o`000?lUV03o9IP000;o9IP000?o0000obFH0?l000000_l000000ooCW`3o0000om>N0005
om>N0003o`000?oCWP3odih000;odih000?o0000om>M0?oCW@000ooCW@000ol0003oe9d0omBM0004
omBM0003o`000?oDW@3oe9d000?oe9d00ol00003omBM0003o`000?oDW@3o000000;o000000?ojU@0
o`000?oZE@001_oZE@000ol0003ojUH0onYF0004onYF0003o`000?oYE`3ojEL000?o000000?okd80
o`000?o_A0001_o_A0000ol0003okTH0oni60003o`0000;ol3l000?o0000onm20?o_@P001Oo_@P00
0ol0003okTD0oni50003o`000003oo0o0?l0003okd<000Kokd<00ol00006onm30003o`000?o^B03o
kTP000CokTP00_l00007on]B00;o00001?oMPP000ol0003ogH40omf10003omf100;o000000?oKjl0
o`000?m_[`000_m_[`001?l0003oKjl0ofn_0?l00003ofn_0003o`000?m_[`3o000000?oKjl000?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`002Oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00?ooooo0ol00005ooooo`;o00000_l0PA800ol0003o5940oaBA
0003oaBA0003o`000?lNU@3o7YD000;o7YD000?o0000ob2F0?lPUP000_lPUP000ol0003o8IL0ob6G
0003ob6G0003o`000?lRU`3o8YL000;o8YL000?o0000ob>G0?lSU`000olSU`000ol0003o99P0obBH
0002obBH0004o`000?lUV03o9IP0obFH00?o00001?oCW`000ol0003odih0om>N0004om>N0003o`00
0?oCWP3odih000;odih000?o0000om>M0?oCW@001?oCW@000ol0003oe9d0omBM0003omBM0003o`00
0?oDW@3oe9d000Co00001?oDW@03o`0000GojU@000?o0000onYE0?oZE@001?oZE@000ol0003ojUH0
onYF0004onYF00?o00001Oo_@P000ol0003okd@0onm40004onm400?o00001_o`?`000ol0003okd80
onm20004onm200?o00001Oo`?`000ol0003okd<0onm30002onm300;o000000?ol3l0o`000?o_@`00
1oo_@`000ol0003okTP0oni80003o`000003onm40?l0003oje8000Goje8000?o0000ona>0?l00000
1?oMPP000ol0003ogH40omf10002omf10003o`000?oMO`3o000000;o00000om_[`001?l0003oKjl0
ofn_0?l00002ofn_0004o`000?m_[`3oKjl0o`0000?oKjl00_l0000?ooooo`03o`000?oooooooooo
01;ooooo0009ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`;o00000ol0PA800ol0003o5940oaBA0002oaBA0003o`000?lNU@3o7YD0
00;o7YD000?o0000ob2F0?lPUP000_lPUP000ol0003o8IL0ob6G0003ob6G0003o`000?lRU`3o8YL0
00;o8YL000?o0000ob>G0?lSU`000olSU`000ol0003o99P0obBH0002obBH00Co000000?odZ40o`00
0?oCW`001OoCW`000ol0003odih0om>N0003om>N0003o`000?oCWP3odih000;odih000?o0000om>M
0?oCW@001?oCW@000ol0003oe9d0omBM0003omBM00?o00001?oDW@04o`000003onYC0?l0003ojU@0
00GojU@000?o0000onYE0?oZE@001OoZE@000ol0003ojUH0onYF0003o`000003oo100?l0003okd80
00Kokd8000Co0000onm40?o_A03okd@00_l000000ooa?03o0000oo0o0007oo0o0003o`000?o_@P3o
kd8000?o000000?olC`0o`000?o`?`001_o`?`001?l0003okd<0o`000?l00004oo0o0003o`000?o_
@`3okd<000Gokd<00ol00005onm40004o`000?o[DP3oje80on]B00;o00000oo/CP001?l0003ogH80
omf20?l00005omf10005o`000?oMO`3o0000omeo0?l000000om_[`001?l0003oKjl0ofn_0?l00002
ofn_0004o`000?m_[`3oKjl0o`0000?oKjl00_l0000?ooooo`03o`000?oooooooooo01;ooooo0009
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Kooooo00Go0000o`214_l0PA;o084Bo`000004oaBA0003o`000?lNU@3o7YD000;o
7YD000?o0000ob2F0?lPUP000_lPUP000ol0003o8IL0ob6G0003ob6G0003o`000?lRU`3o8YL000;o
8YL000?o0000ob>G0?lSU`000olSU`001?l0003o99P0obBH0?lTV002o`0000CodZ4000?o0000om>O
0?oCW`001?oCW`000ol0003odih0om>N0003om>N0003o`000?oCWP3odih000?odih000?o0000om>M
0?oCW@000ooCW@000ol0003oe9d0omBM0004o`0000Goe9d00_l00005onYC0003o`000?oZE03ojU@0
00CojU@000?o0000onYE0?oZE@001?oZE@03o`0000Gol40000?o0000onm20?o_@P001?o_@P001?l0
003okd@0o`000?l00004oo4l0003o`000?o`?`3ol3l000Gol3l00ol00005oo4l0003o`000?o`?`3o
l3l000Col3l00_l00007oo0o0004o`000?o_@`3okd<0onm300?o000000?ol3l0o`000?o_A0001_o_
A0000ol0003oje80o`000006ona>0003o`000?oMPP3o000000CogH4000Co0000omeo0?oMO`3ogGl0
0_l00003ofn_0003o`000?m_[`3o000000?oKjl000Co0000ofn_0?m_[`3o00000_m_[`001?l0003o
Kjl0ofn_0?l0000?ooooo`;o00004_ooool000Wooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000?ooooo0_l00007ooooo`05o`000?l0PA;o084Bo`214_l000001?lD
T@000ol0003o7YD0oajE0002oajE0003o`000?lPUP3o89H000;o89H000?o0000ob6G0?lQU`000olQ
U`000ol0003o8YL0ob:G0002ob:G0003o`000?lSU`3o8iL000?o8iL01?l000000ooBXP3o0000om:Q
0004om:Q0003o`000?oCW`3odil000?odil000?o0000om>N0?oCWP000ooCWP000ol0003odih0om>N
0003om>N0003o`000?oCW@3odid000?odid00ol00004omBM0003o`000?oDW@3o000000;o000000?o
je<0o`000?oZD`001?oZD`000ol0003ojU@0onYD0005onYD0004o`000?oZE@3ojUD0onYE00;o0000
00?ol3l0o`000?o`@0001_o`@0000ol0003okd80onm20003onm200;o00001ooa?0001?l0003ol3l0
oo0o0?o`?`03o`000003oo4i0?l0003olC`000KolC`000?o0000oo0o0?o`?`000ol000000ooa>`3o
0000oo0o0006oo0o0004o`000?o_@`3o0000o`0000Gol3l000?o0000onm40?o_A0000oo_A003o`00
00Ook4h00_l00004omf10003o`000?oMO`3ogGl000;ogGl00ol000001Om_[`3o0000ofn_0?m_[`3o
000000?oKjl000Co0000ofn_0?m_[`3o00000_m_[`000ol0003oKjl0ofn_0002o`0000oooooo00?o
0000ooooooooool04?ooool000[ooooo0_l00009ooooo`?o00001?ooool00ol0003oooooooooo`06
ooooo`05o`000?l0PA;o084Bo`214_l000001?lDT@000ol0003o7YD0oajE0002oajE0003o`000?lP
UP3o89H000;o89H000?o0000ob6G0?lQU`000olQU`000ol0003o8YL0ob:G0002ob:G0003o`000?lS
U`3o8iL000Co00001?oBXP000ol0003odZ40om:Q0003om:Q0003o`000?oCW`3odil000?odil000?o
0000om>N0?oCWP001?oCWP000ol0003odih0om>N0002om>N0003o`000?oCW@3odid000Co00001OoD
W@03o`0000Goje<000?o0000onYC0?oZD`000ooZD`000ol0003ojU@0onYD0004onYD0004o`000?oZ
E@3o0000o`0000Col3l000?o0000oo100?o`@0001?o`@0000ol0003okd80onm20003o`000003oo4j
0?l0003olC`000KolC`000Co0000oo0o0?l0003o00001Ooa>@000ol0003olC`0oo4l0004oo4l00?o
00001Ooa>`000ol0003ol3l0oo0o0004oo0o00;o00001oo`?`000ol0003okd@0onm40003o`0000;o
l44000?o0000ona>0?o/CP001?o/CP000ol0003okD`0o`000004omf10008o`000?oMO`3ogGl0omeo
0?l0003ogWh0o`000?oNOP02o`0000;oKjl000Oo0000ofn_0?m_[`3oKjl0o`000?m_[`3o000000?o
Kjl000Ko0000ofn_0?m_[`3o0000ofn_0?l0000>ooooo`03o`000?oooooooooo013ooooo000Loooo
o`03o`000?oooooooooo00Kooooo00Go0000o`214_l0PA;o084Bo`000004oaBA0003o`000?lNU@3o
7YD000;o7YD000?o0000ob2F0?lPUP000_lPUP000ol0003o8IL0ob6G0003ob6G0004o`000?lRU`3o
8YL0ob:G00Co00000ooAY0000ol0003odZ80om:R0003om:R0003o`000?oBX@3odZ4000;odZ4000?o
0000om>O0?oCW`000ooCW`000ol0003odih0om>N0004om>N0003o`000?oCWP3odih000;odih00ol0
0004om>M0003o`000?oDW@3o000000;o000000?ojU@0o`000?o[D`001Oo[D`000ol0003ojU<0onYC
0004onYC0003o`000?oZE03ojU@000?ojU@00_l00007oo0o0003o`000?o`@03ol40000?ol4000ol0
0005oo4j0003o`000?oa?03olC`000ColC`00_l00008oo4i0003o`000?oa?03olC`000?o000000?o
lSP0o`000?oa>`001_oa>`000ol0003ol3l0oo0o0003o`000003oo4k0?l0003ol3l000Kol3l00ol0
0006oo110004o`000?o/CP3ok4h0ona>00;o00000oo]C0001?l0003ogH40omf10?l00004omeo0006
o`000?oNOP3ogWh0o`000?oNOP3o00000_m_[`001?l0003oKjl0ofn_0?l00002ofn_0005o`000?m_
[`3oKjl0ofn_0?l000000_m_[`001?l0003oKjl0ofn_0?l0000>ooooo`03o`000?oooooooooo00oo
oooo000Looooo`;o00001oooool01Ol0003o084Bo`214_l0PA;o000000Co594000?o0000oajE0?lN
U@000_lNU@000ol0003o89H0ob2F0002ob2F0003o`000?lQU`3o8IL000?o8IL01?l000000ooAYP3o
0000om6T0004om6T0003o`000?oBXP3odZ8000?odZ8000?o0000om:Q0?oBX@000_oBX@000ol0003o
dil0om>O0004om>O0003o`000?oCWP3odih000?odih000?o0000om>N0?oCWP000ol00005om>M00?o
00001OoZE0000ol0003oje<0on]C0004on]C0003o`000?oZD`3ojU<000?ojU<000?o0000onYD0?oZ
E0000ol000000oo`?P3o0000oo0o0006oo0o0003o`000?o`@03ol40000?o000000?olSP0o`000?oa
>P001_oa>P000ol0003olC`0oo4l0003o`0000;olSL000?o0000oo4i0?oa>@001Ooa>@03o`0000Go
lSP000?o0000oo4k0?oa>`001?oa>`03o`0000GolC/000?o0000oo0o0?o`?`000_o`?`02o`000003
oo4k0?l0003ol44000Ool44000?o0000ona>0?l000001_o]C0000ol0003ogH40o`000003omeo0003
o`000?oNOP3ogWh000;ogWh00_l00002ofn_0004o`000?m_[`3oKjl0o`0000;oKjl000Oo0000ofn_
0?m_[`3oKjl0o`000?m_[`3o000000?oKjl000?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0>ooooo`006oooool00ol0003oooooooooo`07ooooo`;o00000_l0PA800ol0003o5940oaBA0002
oaBA0003o`000?lNU@3o7YD000;o7YD000?o0000ob2F0?lPUP000_lPUP000ol0003o8IL0ob6G0002
ob6G00;o00001?oAYP000ol0003odJ@0om6T0003om6T0003o`000?oBXP3odZ8000?odZ8000?o0000
om:Q0?oBX@000_oBX@000ol0003odil0om>O0004om>O0003o`000?oCWP3odih000?odih00ol00003
om>N0003o`000?oCW@3o000000;o000000?ojU@0o`000?oZE0001OoZE0000ol0003oje<0on]C0004
on]C0003o`000?oZD`3ojU<000?ojU<00ol00005oo0n0003o`000?o`?`3ol3l000Col3l00ol00005
oo8h0003o`000?oa>P3olCX000ColCX00ol00006oo8g0003o`000?oa>@3olCT000;olCT00_l00000
0oob=@3o0000oo8h0006oo8h0003o`000?oa>`3olC/000?o000000?olSL0o`000?oa>`001_oa>`00
1?l0003ol3l0o`000?l00004oo4k0003o`000?o`@@3ol44000Col4400ol00007one<00;o00001?oM
O`000ol0003ogWh0omin0002omin00Co00000om_[`001?l0003oKjl0ofn_0?l00002ofn_0004o`00
0?m_[`3oKjl0o`0000?oKjl00_l0000>ooooo`03o`000?oooooooooo00kooooo000Kooooo`03o`00
0?oooooooooo00Sooooo00Co0000o`214_l0PA;o00001?lDT@000ol0003o7YD0oajE0002oajE0003
o`000?lPUP3o89H000;o89H000?o0000ob6G0?l000000_l000000oo@Z03o0000om6V0004om6V0003
o`000?oAY03odJ@000?odJ@000?o0000om:R0?oBXP000_oBXP000ol0003odZ40om:Q0003om:Q0003
o`000?oCW`3odil000?odil000?o0000om>N0?oCWP001?l00004om>N00?o00001OoZE0000ol0003o
jU@0onYD0004onYD0003o`000?o[D`3oje<000?oje<000?o0000onYC0?oZD`000ol000000oo`?@3o
0000oo0n0006oo0n0003o`000?o`?`3ol3l000?o000000?olSL0o`000?ob>0001_ob>0000ol0003o
lCX0oo4j0003o`0000;olSD000?o0000oo8g0?ob=`001Oob=`001?l0003olCT0o`000?l00004oo8e
0003o`000?ob>03olSP000ColSP00ol00005oo8g0003o`000?oa>`3olC/000ColC/00_l00007oo4k
0003o`000?o`@@3ol44000?o00000_o`?@000ol0003okD`0one<0003one<00;o000000?okDT0o`00
0?oMO`000_oMO`000ol0003ogWh0omin0002omin0003o`000?oNO@3o000000;o00000om_[`001?l0
003oKjl0ofn_0?l00002ofn_0004o`000?m_[`3oKjl0o`0000?oKjl00_l0000>ooooo`;o00003ooo
ool001_ooooo0_l00009ooooo`;o000000?o084Bo`000?lDT@000olDT@000ol0003o7YD0oajE0002
oajE0004o`000?lPUP3o89H0ob2F00?o00001?o@Z0000ol0003odJH0om6V0003om6V0003o`000?oA
Y03odJ@000?odJ@000?o0000om:R0?oBXP000ooBXP000ol0003odZ40om:Q0002om:Q0003o`000?oC
W`3odil000?odil00ol00004om>N00Co000000?ojUD0o`000?oZE0001OoZE0000ol0003ojU@0onYD
0004onYD0003o`000?o[D`3oje<000?oje<00ol00005oo0m0003o`000?o`?P3ol3h000Col3h00ol0
0005oo8g0003o`000?ob>03olSP000ColSP00ol00006oo8e0003o`000?ob=`3olSL000ColSL00_l0
0007oo8e0003o`000?ob>03olSP000?o000000?olc<0o`000?ob=`001_ob=`000ol0003olC/0oo4k
0003o`000003oo8g0?l0003olC/000KolC/00ol00006oo0m0005o`000?o]C03okD`0one<0?l00000
1?o]B@000ol0003ogGl0o`000005omin0003o`000?oNO@3ogWd000;o00000om_[`000ol0003oKjl0
o`000003ofn_0004o`000?m_[`3oKjl0o`0000;oKjl000Co0000ofn_0?m_[`3o00003oooool00ol0
003oooooooooo`0<ooooo`006oooool00ol0003oooooooooo`08ooooo`04o`000?n0/`3o0000o`00
00Co594000?o0000oajE0?lNU@000_lNU@04o`000003olnZ0?l0003od:P000Cod:P000?o0000om6V
0?oAYP000ooAYP000ol0003odJ@0om6T0003om6T0003o`000?oBXP3odZ8000?odZ8000?o0000om:Q
0?oBX@000_oBX@000ol0003odil0om>O0004o`0000Godih00_l00005onYE0003o`000?oZE03ojU@0
00CojU@000?o0000onYD0?oZE0000ooZE0000ol0003oje<0on]C0003o`000003oo0m0?l0003ol3d0
00Kol3d000?o0000oo0n0?o`?P000ol00002oo8f0003o`000?ob=`3olSL000ColSL000?o0000oo8h
0?ob>0000ol00002oo<c0003o`000?ob=@3olSD000GolSD000?o0000oo8g0?ob=`000ol000000ooc
<P3o0000oo8e0006oo8e00?o00001Ooc<`000ol0003olSL0oo8g0004oo8g00?o00001Oob=`000ol0
003olC/0oo4k0002oo4k00;o000000?olSP0o`000?o`?@001_o`?@001?l0003okD`0o`000?l00005
one90003o`000?oMO`3o000000CogWh000?o0000omim0?oNO@000_oNO@02o`000005ofn_0?l0003o
Kjl0ofn_0?l000000om_[`001?l0003oKjl0ofn_0?l00002ofn_0004o`000?m_[`3oKjl0o`0000oo
oooo00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool02Oooool3o`0000Co5940
00?o0000oajE0?lNU@000ol00004olnZ0003o`000?o@Z03od:P000Cod:P000?o0000om6V0?oAYP00
0_oAYP000ol0003odJ@0om6T0003om6T0003o`000?oBXP3odZ8000?odZ8000?o0000om:Q0?oBX@00
0_oBX@03o`0000Codil000?o0000om>N0?l000000_l000000ooYE`3o0000onYE0005onYE0003o`00
0?oZE03ojU@000?ojU@000Co0000onYD0?oZE03ojU@01Ol00005oo0m0003o`000?o`?@3ol3d000Co
l3d00ol00006oo8f0003o`000?ob=`3olSL000?olSL00ol00006oo<c0003o`000?ob=@3olSD000Co
lSD00ol00005oo<b0003o`000?ob=@3olSD000;olSD00_l000000ood<@3o0000oo<c0006oo<c0003
o`000?ob=`3olSL000?o000000?olc<0o`000?ob=`001_ob=`001?l0003olC/0o`000?l00004oo8h
0003o`000?o`?@3ol3d000Col3d00_l00007one900;o00001?oNOP000ol0003ogWd0omim0002omim
0003o`000?oNO03o000000;o00000_m_[`001ol0003oKjl0ofn_0?m_[`3o0000ofn_0?l000000om_
[`000ol0003oKjl0ofn_0002o`0000oooooo00?o0000ooooooooool02oooool001_ooooo0_l0000:
ooooo`03o`000?n0/`3o000000Oo00000_o>[P000ol0003ocjX0olnZ0003olnZ0003o`000?o@Z03o
d:P000?od:P000?o0000om6V0?oAYP000_oAYP000ol0003odJ@0om6T0003om6T0003o`000?oBXP3o
dZ8000?odZ8000?o0000om:Q0?l000000ol00005om>O00?o00001OoYE`000ol0003ojUD0onYE0003
onYE0003o`000?oZE03ojU@000?ojU@01?l00004oo0m0003o`000?o`?@3ol3d000Col3d000?o0000
oo0m0?o`?@000ol00002oo8f0003o`000?ob=P3olSH000GolSH000?o0000oo8g0?l000000_l00002
oo<b0003o`000?oc<`3olc<000Golc<000?o0000oo8e0?ob=@000ol000000ood<03o0000oo<b0006
oo<b0004o`000?ob=@3o0000o`0000Com34000?o0000oo<c0?oc<`001?oc<`03o`0000Golc<000?o
0000oo8g0?ob=`001?ob=`02o`0000OolSP000?o0000oo0m0?o`?@000ol00002oo4k0003o`000?o]
B@3okDT000;okDT00_l00002oni70005o`000?oNOP3ogWh0omin0?l000001?oNO@001Ol0003ogW`0
o`000?oNO03o000000;oKjl000Co0000ofn_0?m_[`3o00000_m_[`001ol0003oKjl0ofn_0?m_[`3o
0000ofn_0?l000000_m_[`000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0002
ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000;ooooo0ol00004ooooo`;o00002ooo
ool00ol0003oP;<0o`000004olRk0003o`000?o>[P3ocZh000;ocZh000?o0000olnZ0?o?ZP000oo?
ZP000ol0003od:P0om2X0003om2X0003o`000?oAYP3odJH000?odJH000?o0000om6T0?oAY0000_oA
Y0000ol0003odZ80om:R0002om:R00?o00001?oBX@000ol0003odil0o`000002o`000003onUH0?l0
003ojEL000GojEL000?o0000onYE0?oZE@001?oZE@000ol0003ojU@0o`000002o`000003oo0n0?l0
003ol3d000Kol3d000?o0000oo0m0?o`?@000oo`?@03o`0000KolSH000?o0000oo8f0?ob=P001?ob
=P02o`0000Kolc8000?o0000oo<c0?oc<`001?oc<`03o`0000Gom30000?o0000oo<b0?oc<P001?oc
<P02o`0000Oom34000?o0000oo<c0?oc<`000ol000000ood<03o0000oo<c0006oo<c0003o`000?ob
=`3olSL000?o00000_oc=0000ol0003olSP0oo8h0004oo8h00?o00001_oa>`001?l0003okDT0o`00
0?l00005oni70003o`000?oNOP3o000000CogWd000Co0000omil0?oNO03ogW`00_l00002ofn_0004
o`000?m_[`3oKjl0o`0000;oKjl000Oo0000ofn_0?m_[`3oKjl0o`000?m_[`3o000000;oKjl000?o
0000ooooooooool03Oooool2o`0000_ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`05o`000?ooooooooooooooool000003?ooool00ol0
003oP;<0o`000004olRk0003o`000?o>[P3ocZh000?ocZh000?o0000olnZ0?o?ZP000_o?ZP000ol0
003od:P0om2X0003om2X0003o`000?oAYP3odJH000?odJH000?o0000om6T0?oAY0000_oAY0000ol0
003odZ80o`000002o`0000;odZ8000?o0000om:Q0?oBX@001?l00005onUH0003o`000?oYE`3ojEL0
00CojEL000?o0000onYE0?oZE@000ooZE@02o`0000Gol3h000?o0000oo0m0?o`?@001Oo`?@000ol0
003ol3d0o`000002o`0000;olSH000?o0000oo8f0?ob=P001Oob=P000ol0003olSH0oo8f0003o`00
0003oo<a0?l0003olc8000Kolc8000?o0000oo<c0?oc<`000ol000000ood;P3o0000oo@`0006oo@`
0003o`000?oc<P3olc8000?o00000_od;P000ol0003om340oo@a0004oo@a00?o00001Ood<0000ol0
003olc<0oo<c0004oo<c00?o00001_oc=0000ol0003olSP0oo8h0003o`000003oo8e0?l0003olC/0
00KolC/00_l00007oni700;o00001?oNO@000ol0003ogW`0omil0002omil00Co00000om_[`001?l0
003oKjl0ofn_0?l00002ofn_0004o`000?m_[`3oKjl0o`0000;oKjl00_l0000?ooooo`03o`000?oo
oooooooo00Wooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?o0000oh2c0?l000001?o8^`000ol0003ocZh0
olj^0002olj^0003o`000?o?ZP3ocjX000;ocjX000?o0000om2X0?o@Z0000oo@Z0000ol0003odJH0
om6V0003om6V0003o`000?oAY03odJ@000;odJ@00_l00004om:R00Co00000_oXFP000ol0003ojEP0
onUH0004onUH0003o`000?oYE`3ojEL000CojEL000?o0000onYE0?oZE@000ol000000oo`?`3o0000
oo0n0005oo0n0003o`000?o`?@3ol3d000Col3d00_l00006oo8f0003o`000?ob=P3olSH000ColSH0
0ol00005oo<a0003o`000?oc<P3olc8000Colc800ol00005oo@^0003o`000?od<03om30000Com300
0ol00006oo@^0003o`000?od<@3om34000?o000000?om2d0o`000?od<0001_od<0000ol0003olc<0
oo<c0003o`000003oo@`0?l0003olc@000Kolc@00ol00005oo8e0003o`000?oa>`3olC/000;olC/0
0_l000000oob>@3o0000oni70005oni70003o`000?o^AP3o000000CogWd000Go0000omil0?oNO03o
gW`0o`000002omil00;o00000om_[`001?l0003oKjl0ofn_0?l00002ofn_0006o`000?m_[`3oKjl0
o`000?m_[`3o00000_m_[`000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo0000
1Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ooooool2o`0000cooooo00?o0000oh2c0?l000001?o8^`000ol0003ocZh0olj^0002olj^0003o`00
0?o?ZP3ocjX000?ocjX000?o0000om2X0?o@Z0000_o@Z0000ol0003odJH0om6V0003om6V0003o`00
0?oAY03o000000;o000000?odJ@0o`000?oBXP000ol000000ooXG03o0000onQJ0004onQJ0003o`00
0?oYF03ojEP000CojEP000?o0000onUG0?oYE`000ooYE`03o`0000Gol3l000?o0000oo0n0?o`?P00
1?o`?P000ol0003ol3d0oo0m0003o`000003oo8f0?l0003olSH000KolSH000?o0000oo8f0?ob=P00
0ol000000ood<03o0000oo<a0006oo<a0003o`000?oc<P3olc8000?o000000?om2d0o`000?od;P00
1_od;P000ol0003om300oo@`0003o`000003ooD/0?l0003om2h000Kom2h00ol00005oo@]0003o`00
0?od<03om30000Com3000ol00005oo@`0003o`000?oc=03olc@000;olc@00_l000000ooc<@3o0000
oo8e0006oo8e0004o`000?oa>`3o0000o`0000ColST000Co0000oni70?o^A`3okTL00_l00003oni6
0004o`000?oNO@3ogWd0o`0000CogW`000?o0000omil0?oNO0000_l00003ofn_0003o`000?m_[`3o
000000?oKjl000Ko0000ofn_0?m_[`3o0000ofn_0?l00002ofn_0003o`000?oooooooooo00gooooo
00?o0000ooooooooool02?ooool00005ooooool0003oooooooooool000001oooool01_l0003ooooo
oooooooooooo0000ooooo`Co00001?ooool00ol0003oooooooooo`0;ooooo`03o`000?n0/`3o0000
00Cob;/000?o0000olj^0?o>[P000_o>[P000ol0003ocjX0olnZ0003olnZ0003o`000?o@Z03od:P0
00;od:P000?o0000om6V0?oAYP000_oAYP03o`0000?odJ@00ol00005onQL0003o`000?oXFP3oj5X0
00?oj5X000?o0000onUH0?oYF0000ooYF0000ol0003ojEL0onUG0003o`0000;okd4000?o0000oo0o
0?o`?`001?o`?`000ol0003ol3h0oo0n0003oo0n00?o00001Oob=P000ol0003olSH0oo8f0004oo8f
00?o00001Ood<0000ol0003olc40oo<a0004oo<a00?o00001Ood;@000ol0003om2h0oo@^0004oo@^
00?o00001Ooe;0000ol0003om2h0oo@^0002oo@^00;o000000?omBX0o`000?od;@001_od;@000ol0
003om300oo@`0003o`000003ooD]0?l0003om30000Kom30000Co0000oo<d0?l0003o00001?oc<@00
0ol0003olSD0oo8e0004oo8e00;o00001oob>@000ol0003okTL0o`000006oni60003o`000?oNO@3o
000000?ogW`000?o0000omil0?oNO0000_oNO002o`000005ofn_0?l0003oKjl0ofn_0?l000000om_
[`000ol0003oKjl0o`000002ofn_0003o`000?m_[`3oKjl000;o00003Oooool3o`0000Wooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oo
oooo00?o0000ooooooooool03?ooool2o`0000Cob;/000?o0000olj^0?o>[P000oo>[P000ol0003o
cjX0olnZ0002olnZ0003o`000?o@Z03od:P000?od:P01?l00002om6V00Co000000?oiel0o`000?oX
G0001OoXG0000ol0003oj5X0onQJ0003onQJ0003o`000?oYF03ojEP000?ojEP00ol00006onm10003
o`000?o`?`3ol3l000?ol3l000?o0000oo0n0?o`?P000ol000000oob=`3o0000oo8f0006oo8f0003
o`000?ob=P3olSH000?o000000?om300o`000?od<0001_od<0000ol0003olc40oo<a0003o`000003
ooD/0?l0003om2d000Kom2d000?o0000oo@^0?od;P000ol000000ooe:P3o0000ooD/0006ooD/0004
o`000?od;P3o0000o`0000ComBX000?o0000oo@]0?od;@001?od;@03o`0000GomBd000?o0000oo@`
0?od<0001?od<002o`0000Oolc4000?o0000oo8e0?ob=@000ol000000ooc<`3o0000oo8i0006oo8i
00;o00001oo^AP02o`0000CogW`000Ko0000omil0?oNO03ogW`0o`000?oNO003o`0000;oKjl000Oo
0000ofn_0?m_[`3oKjl0o`000?m_[`3o000000;oKjl000Ko0000ofn_0?m_[`3o0000ofn_0?l00009
ooooo`?o00000_ooool00ol0003oooooooooo`07ooooo`000_ooool2o`0000Wooooo0ol00002oooo
o`Go00000_ooool3o`0000gooooo00?o0000oh2c0?l000001?o8^`000ol0003ocZh0olj^0002olj^
0003o`000?o?ZP3ocjX000;ocjX000Co0000om2X0?o@Z03od:P00ol00002om6V00Co00001OoWG`00
0ol0003oj5`0onQL0004onQL0003o`000?oXFP3oj5X000?oj5X000?o0000onUH0?l000000_l00002
onm30003o`000?o_@@3okd4000Gokd4000Co0000oo0o0?o`?`3ol3l01?l00005oo8g0003o`000?ob
=P3olSH000ColSH00ol00005oo@`0003o`000?od<03om30000Com3000ol00005ooD/0003o`000?od
;@3om2d000Com2d00ol00005ooDZ0003o`000?oe;03omB`000ComB`00_l00007ooDZ0003o`000?od
;@3om2d000?o000000?omRT0o`000?oe;@001_oe;@000ol0003om300oo@`0003o`0000;om2d000?o
0000oo<a0?oc<@001?oc<@03o`0000Golc<000?o0000oo8i0?ob>@000_ob>@02o`000003oo8g0?l0
003okTH000GokTH000?o0000oni50?l000000ooNO0000ol0003ogW`0omil0002omil0003o`000?oN
O03ogW`000;o00000_m_[`001?l0003oKjl0ofn_0?l00002ofn_0006o`000?m_[`3oKjl0o`000?m_
[`3o00000om_[`000ol0003oooooooooo`03ooooo`?o00001Oooool00ol0003oooooooooo`07oooo
o`006Oooool00ol0003oooooooooo`0>ooooo`;o00001?o8^`000ol0003ocZh0olj^0002olj^0003
o`000?o?ZP3ocjX000;ocjX01?l000000oo@Z03o0000o`000002o`0000?oiV8000?o0000onMO0?oW
G`001?oWG`000ol0003oj5`0onQL0003onQL0004o`000?oXFP3oj5X0onQJ00Co00001_o_@`000ol0
003okd40onm10004onm100Co00000oob>0000ol0003olSL0oo8g0004oo8g0003o`000?ob=P3olSH0
00?o00000_od<@000ol0003om300oo@`0004oo@`0003o`000?od<03om30000?o000000?omB`0o`00
0?oe;0001_oe;0000ol0003om2d0oo@]0003o`000003ooHY0?l0003omBX000KomBX000?o0000ooD/
0?oe;0000ol00002ooHX0003o`000?oe:P3omBX000ComBX00ol00005ooHY0003o`000?oe;@3omBd0
00ComBd00ol00006oo@]0003o`000?oc<@3olc4000?o000000?om2l0o`000?oc<`001_oc<`001?l0
003olST0o`000?l00004oo8g0004o`000?o^AP3okTH0oni600;o00000oo^A@000ol0003ogW`0o`00
0004omil0004o`000?oNO03ogW`0omil00;o00000_m_[`001?l0003oKjl0ofn_0?l00002ofn_0003
o`000?m_[`3o000000;oKjl000Ko0000ofn_0?m_[`3oKjl0o`000?ooool4o`0000Sooooo00?o0000
ooooooooool01oooool001Wooooo00?o0000ooooooooool03_ooool2o`0000Cob;/000?o0000olj^
0?o>[P000_o>[P000ol0003ocjX0olnZ0007o`000003onEU0?l0003oiV8000GoiV8000?o0000onMO
0?oWG`000ooWG`000ol0003oj5`0onQL0003onQL00Co00000oo^A@000ol0003okd<0onm30005onm3
0003o`000?o_@@3okd4000?o000000?olCT0o`000?ob>0001Oob>0000ol0003olSL0oo8g0003oo8g
00?o00001_od<@000ol0003om300oo@`0003oo@`00?o00001Ooe;0000ol0003omB`0ooD/0004ooD/
00?o00001Oof:@000ol0003omBX0ooDZ0004ooDZ00?o00001_of:0000ol0003omBX0ooDZ0003o`00
0003ooHW0?l0003omRT000KomRT000?o0000ooD]0?oe;@000ol00002ooDZ0003o`000?od;@3om2d0
00Com2d00ol00005oo@_0003o`000?oc<`3olc<000Colc<00_l00007oo8g0003o`000?o^AP3o0000
00GokTD000?o0000omil0?l000000ooNO0000ol0003ogW`0omil0002omil00Co00000om_[`001_l0
003oKjl0ofn_0?l0003oKjl0o`0000;oKjl000Co0000ofn_0?m_[`3oKjl00_l0000=ooooo`03o`00
0?oooooooooo00Kooooo000Iooooo`;o00004?ooool00ol0003ob;/0olRk0002olRk0003o`000?o>
[P3ocZh000;ocZh00ol000001?o?ZP3o0000o`000?l00005onEU0003o`000?oVHP3oiV8000?oiV80
00?o0000onMO0?oWG`001?oWG`000ol0003oj5`0o`000002o`000003oni70?l0003okTD000GokTD0
00?o0000onm30?o_@`001?o_@`03o`0000GolCT000?o0000oo8h0?ob>0001?ob>0000ol0003olSL0
o`000002o`0000;olc4000?o0000oo@a0?od<@001Ood<@000ol0003om300o`000002o`0000;omB`0
00?o0000ooD/0?oe;0001?oe;0000ol0003omB`0ooD/0003o`000003ooHX0?l0003omRT000KomRT0
00?o0000ooDZ0?oe:P000ol00002ooHV0003o`000?of:03omRP000ComRP00ol00005ooHW0003o`00
0?of:@3omRT000ComRT00ol00006ooDZ0003o`000?od;@3om2d000?o000000?omB/0o`000?od;`00
1_od;`000ol0003olc<0oo<c0003o`0000;olc4000?o0000oo8g0?ob=`001?ob=`02o`0000KokTD0
0_l00004omil0005o`000?oNO03ogW`0omil0?l000000_oNO002o`0000?oKjl000?o0000ofn_0?l0
00000_m_[`001?l0003oKjl0ofn_0?l00002ofn_0004o`000?m_[`3oKjl0o`0000cooooo00?o0000
ooooooooool01_ooool001Wooooo00?o0000ooooooooool03oooool2o`0000?ob;/000?o0000olj^
0?l000001_l00002onAY0003o`000?oUI@3oiFD000CoiFD000?o0000onIR0?oVHP000ooVHP000ol0
003oiel0onMO0003onMO00;o00001Oo^A`000ol0003okTD0oni50004oni50003o`000?o_@`3okd<0
00?o00000_oa>`000ol0003olCT0oo4i0004oo4i0004o`000?ob>03olSP0oo8h00Co00001_oc<@00
0ol0003om340oo@a0004oo@a00;o00001_oe;0000ol0003omB`0ooD/0003ooD/00?o00001Oof:000
0ol0003omRT0ooHY0004ooHY00?o00001_of9P000ol0003omRP0ooHX0003o`000003ooLU0?l0003o
mRL000KomRL000?o0000ooHY0?of:@000ol000000oof9`3o0000ooDZ0006ooDZ00?o00001Ooe:`00
0ol0003om2l0oo@_0004oo@_00?o00001_oc<@000ol0003olSL0oo8g0003o`000003oo8f0?l0003o
kTD000?okTD00_l00002onm40004o`000?oNO03ogW`0o`0000CogW`000Go0000omil0?oNO03ogW`0
o`000003ofn_0003o`000?m_[`3o000000;oKjl000Co0000ofn_0?m_[`3o00000_m_[`001?l0003o
Kjl0ofn_0?l0000<ooooo`03o`000?oooooooooo00Kooooo000Iooooo`03o`000?oooooooooo013o
oooo2Ol000000ooSK`3o0000onAY0004onAY0003o`000?oUI@3oiFD000?oiFD000?o0000onIR0?oV
HP000ooVHP000ol0003oiel0onMO0003o`000003one:0?l0003okTL000GokTL000?o0000oni50?o^
A@000oo^A@03o`0000KolC/000?o0000oo4i0?oa>@000ooa>@04o`0000Colc8000?o0000oo<a0?oc
<@001?oc<@000ol0003om340oo@a0003o`0000;omB`000?o0000ooD/0?oe;0001?oe;0000ol0003o
mB`0o`000002o`0000?omRL000?o0000ooHX0?of:0000oof:0000ol0003omRT0ooHY0003o`0000;o
mbD000?o0000ooHV0?of9P001?of9P03o`0000GombD000?o0000ooHW0?of9`001?of9`03o`0000Go
mRL000?o0000ooDZ0?oe:P000_oe:P02o`000003ooHW0?l0003omB/000KomB/000?o0000oo@_0?od
;`000ol00002oo@]0003o`000?oc<@3olc4000Colc400ol00005oo8f0004o`000?o^A@3o0000o`00
00Gokd@000?o0000omil0?l000000ooNO0000ol0003ogW`0omil0002omil00;o000000GoKjl0o`00
0?m_[`3oKjl0o`000002ofn_0004o`000?m_[`3oKjl0o`0000;oKjl000?o0000ofn_0?m_[`000_l0
000;ooooo`03o`000?oooooooooo00Kooooo000Hooooo`03o`000?oooooo0000017ooooo1_l00005
on=_0003o`000?oTJ@3oi6T000?oi6T000?o0000onEU0?oUI@000ooUI@001?l0003oiV80onIR0?oV
HP04o`0000GokDX000?o0000oni70?o^A`001?o^A`000ol0003okTD0o`000002o`0000;ol3d000?o
0000oo4k0?oa>`001Ooa>`000ol0003olCT0o`000002o`0000;olc@000?o0000oo<b0?oc<P001?oc
<P001?l0003olc40oo<a0?oc<@05o`0000KomB`000Co0000ooD/0?oe;03omB`01?l00007ooHW0004
o`000?of:03omRP0ooHX00Co00001_og9@000ol0003omRH0ooHV0003o`000003ooLS0?l0003ombD0
00KombD000?o0000ooHW0?of9`000ol000000oog903o0000ooHW0006ooHW0004o`000?oe:P3o0000
o`0000ComRL000?o0000ooD[0?oe:`001?oe:`03o`0000Kom2d000?o0000oo<a0?oc<@000ol00000
0ood<03o0000oo8f0005oo8f00;o00001oo_A002o`0000?ogW`000?o0000omil0?oNO0000_oNO000
0ol0003ogW`0o`000002o`0000;oKjl000?o0000ofn_0?l000000om_[`001_l0003oKjl0ofn_0?l0
003oKjl0o`0000;oKjl000?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`006?oo
ool2o`00013ooooo1?l00003omb20003o`000?oSK`3ohfl000?ohfl000?o0000onAY0?oTJ@000ooT
J@000ol0003oiFD0onEU0003onEU00Co00000oo/CP000ol0003okDX0one:0004one:0004o`000?o^
A`3okTL0oni700Go00001Oo`?@000ol0003olC/0oo4k0004oo4k00;o00001_oc=0000ol0003olc80
oo<b0003oo<b00Co00001?oe;@000ol0003omB`0ooD/0004ooD/00Co00001?of9`000ol0003omRL0
ooHW0004ooHW00Co00001?og90000ol0003ombD0ooLU0003ooLU00?o00001Oog8`000ol0003ombD0
ooLU0004ooLU00?o00001Oog90000ol0003omRL0ooHW0004ooHW00;o00001oof9`000ol0003omB/0
ooD[0003o`0000;omRT000?o0000oo@]0?od;@001?od;@03o`0000Gom30000Co0000oo8f0?ob=P3o
lSH00_l000000oob=@3o0000onm40005onm40003o`000?o_A03o000000?ogW`000?o0000omil0?oN
O0000_oNO0000ol0003ogW`0omil0002o`0000;oKjl000?o0000ofn_0?l000000_m_[`001ol0003o
Kjl0ofn_0?m_[`3o0000ofn_0?l000000_m_[`000ol0003oooooooooo`08ooooo`;o00001oooool0
01Sooooo00?o0000ooooooooool03?ooool3o`0000Cooooo00Go0000omb20?oLPP3og880o`000005
on=_0003o`000?oTJ@3oi6T000?oi6T000?o0000onEU0?l000000_l00002on]A0003o`000?o/CP3o
k4h000?ok4h000?o0000one:0?o]BP000oo]BP04o`0000Gol40000?o0000oo0m0?o`?@000oo`?@00
0ol0003olC/0oo4k0003o`000003oo8f0?l0003olc@000Kolc@000?o0000oo<b0?l000000_l00002
oo@^0003o`000?oe;@3omBd000ComBd000?o0000ooD/0?oe;0000ol000000oof9`3o0000ooHW0006
ooHW0003o`000?of9`3omRL000?o000000?omb@0o`000?og90001_og90000ol0003ombD0o`000002
o`0000;omb8000?o0000ooLS0?og8`001?og8`000ol0003ombD0ooLU0003o`000003ooLR0?l0003o
mb@000Komb@000?o0000ooHW0?of9`000ol00002ooLU0003o`000?of9`3omRL000ComRL00ol00006
ooHY0003o`000?od;@3om2d000?o000000?omB`0o`000?od<0001Ood<0001?l0003olSH0o`000?l0
0004oo8e0004o`000?o_A03okd@0onm400;o00000oo_A0000ol0003ogW`0o`000004omil0004o`00
0?oNO03ogW`0omil00;o000000GoKjl0o`000?m_[`3oKjl0o`000002ofn_0004o`000?m_[`3oKjl0
o`0000;oKjl000?o0000ofn_0?m_[`000_l00009ooooo`;o00001oooool001Sooooo0ol00009oooo
o`?o00001oooool00ol0003og880omb20002omb20003o`000?oSK`3ohfl000;ohfl000Co0000onAY
0?oTJ@3oi6T01?l00006on]A0003o`000?o/CP3ok4h000?ok4h000?o0000one:0?l000000_l00002
onm30003o`000?o`@03ol40000Gol40000Co0000oo0m0?o`?@3ol3d01?l00005oo8f0003o`000?oc
=03olc@000Colc@00_l00006oo@^0003o`000?oe;@3omBd000?omBd00ol00005ooHW0003o`000?of
9`3omRL000ComRL00ol00005ooLT0003o`000?og903omb@000Comb@00_l00006ooLR0003o`000?og
8`3omb<000?omb<00ol00005ooLR0003o`000?og903omb@000Comb@00ol00006ooLU0003o`000?of
9`3omRL000?o00000_of9P000ol0003omRT0ooHY0004ooHY00?o00001Ooe;0000ol0003om300oo@`
0003oo@`00;o00001oob=@000ol0003okd@0o`000005onm400;o00001?oNO0000ol0003ogW`0omil
0002omil00Co00000_m_[`001?l0003oKjl0ofn_0?l00002ofn_0008o`000?m_[`3oKjl0o`000?m_
[`3o0000ofn_0?l00009ooooo`;o00001oooool001Sooooo00?o0000ooooooooool01_ooool3o`00
00_ooooo1Ol00003on=_00Go00000ooZE@000ol0003oje40on]A0005on]A0004o`000?o/CP3ok4h0
ona>00?o00001_o_@`000ol0003ol400oo100004oo1000Co00001?ob>0000ol0003olSH0oo8f0003
oo8f0003o`000?oc=03olc@000?o000000?om2l0o`000?od;P001_od;P000ol0003omBd0o`000002
o`0000;omRP000?o0000ooHW0?of9`001?of9`000ol0003omRL0ooHW0003o`000003ooLS0?l0003o
mb@000Komb@000?o0000ooLT0?og90000ol000000ooh8@3o0000ooLR0006ooLR0003o`000?og8`3o
000000;o000000?on200o`000?og8P001_og8P000ol0003omb@0ooLT0003o`0000;omb8000?o0000
ooLU0?og9@001?og9@03o`0000KomRH000?o0000ooHY0?of:@000ol000000oof:03o0000ooD/0005
ooD/0003o`000?od<03om30000?o00000_od;`000ol0003olSD0oo8e0004oo8e00;o00001Oo_A000
0ol0003okd@0o`000004omil0005o`000?oNO03ogW`0omil0?l000000_oNO@02o`0000;oKjl000Co
0000ofn_0?m_[`3o00000_m_[`001_l0003oKjl0ofn_0?l0003oKjl0o`0000;oKjl000?o0000oooo
ooooool01_ooool2o`0000Oooooo0005ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001Oooool00ol0003oooooooooo`03ooooo`?o00003oooool00ol0003ohW40on9a0004o`0000?o
j5`000?o0000onYE0?oZE@000ooZE@000ol0003oje40on]A0004on]A00Co00000oo^AP000ol0003o
kd<0onm30004onm30003o`000?o`@03ol40000?o000000?olC/0o`000?ob>0001_ob>0001?l0003o
lSH0oo8f0?ob=P04o`0000Gom2l000?o0000oo@^0?od;P001?od;P02o`0000KomRP000?o0000ooHW
0?of9`000oof9`03o`0000Gomb<000?o0000ooLT0?og90001?og9003o`0000Gon24000?o0000ooLR
0?og8P001?og8P02o`0000Gon20000?o0000ooLR0?og8P001?og8P03o`0000Komb8000?o0000ooLU
0?og9@000ol000000oog8`3o0000ooHV0006ooHV00?o00001Oof:0000ol0003omB`0ooD/0003ooD/
00?o00001_od;`000ol0003olSD0oo8e0003o`0000;olc@000Go0000onm40?o_A03okd@0o`000003
onm40004o`000?oNO03ogW`0o`0000CogW`000Oo0000omim0?oNO@3ogWd0o`000?m_[`3o000000?o
Kjl000Ko0000ofn_0?m_[`3o0000ofn_0?l00002ofn_0004o`000?m_[`3oKjl0o`0000Sooooo0_l0
0007ooooo`001?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooooooool3o`0001?ooooo00Go0000on9a0?oRL@3ohW40o`000005onQL
0003o`000?oZE@3ojUD000?ojUD000?o0000on]A0?o[D@000ol000000oo]BP3o0000oni60005oni6
0003o`000?o_@`3okd<000?okd<00ol00005oo4k0003o`000?ob>03olSP000ColSP01?l00004oo<a
0003o`000?od;`3om2l000?om2l000?o0000oo@^0?od;P000ol000000oof:@3o0000ooHX0006ooHX
0003o`000?of9`3o000000;o00000_og90000ol0003omb<0ooLS0004ooLS0003o`000?og903omb@0
00?o000000?on200o`000?oh8@001_oh8@000ol0003omb80ooLR0003o`0000;on1l000?o0000ooPP
0?oh80000ooh80000ol0003omb80ooLR0003o`0000;on20000?o0000ooLR0?og8P001?og8P03o`00
00Gomb<000?o0000ooHV0?of9P000_of9P02o`000003ooLT0?l0003omRP000GomRP000?o0000ooD/
0?oe;0000ol00002ooD[0003o`000?od;`3om2l000Com2l00ol00006oo<d0003o`000?o_A03o0000
00Gokd@000?o0000omil0?l000000ooNO0001?l0003ogWd0omim0?oNO@04o`0000?oKjl000Ko0000
ofn_0?m_[`3o0000ofn_0?l00002ofn_0003o`000?m_[`3oKjl000;o00001_ooool00ol0003o06la
o`000007ooooo`001?ooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooooooo`Co
00005oooool01Ol0003ohW40on9a0?oRL@3o000000Goj5`000Co0000onYE0?oZE@3ojUD01?l00005
one:0003o`000?o^AP3okTH000CokTH000?o0000onm30?l000000_l00002oo0n0003o`000?oa>`3o
lC/000ColC/000?o0000oo8h0?ob>0000ol000000ooc<`3o0000oo<a0006oo<a0004o`000?od;`3o
m2l0oo@_00Co00001Oof:@000ol0003omRP0ooHX0004ooHX00;o00001_og90000ol0003omb<0ooLS
0003ooLS00?o00001Ooh80000ol0003on240ooPQ0004ooPQ00?o00001_oh7`001?l0003on200ooPP
0?oh8004o`0000Kon20000?o0000ooLR0?og8P000ol000000ooh803o0000ooLS0006ooLS0004o`00
0?of9P3o0000o`0000Comb@000?o0000ooHX0?of:0000oof:003o`0000KomB/000?o0000oo@_0?od
;`000ol00002oo@_0003o`000?oc=03olc@000Colc@00_l00006onm400;o00000ooNO0000ol0003o
gWd0omim0002omim0004o`000?oNOP3o0000o`0000?oKjl000?o0000ofn_0?l000000_m_[`001?l0
003oKjl0ofn_0?l00002ofn_0003o`000?m_[`3o000000Gooooo00?o0000o`1_<Ol000001oooool0
00Cooooo00Co0000oooooooooooo00002Oooool2o`0000Cooooo0_l0000Jooooo`Go00000ooXG005
o`0000?ok4h000?o0000one:0?o]BP001?o]BP001?l0003okTH0oni60?o^AP04o`0000Kol3h000?o
0000oo4k0?oa>`000ooa>`03o`0000Golc<000?o0000oo<a0?oc<@001?oc<@04o`0000?omB/000?o
0000ooHY0?of:@001?of:@000ol0003omRP0ooHX0003o`000003ooLT0?l0003omb@000Komb@000?o
0000ooLS0?l000000_l00002ooPP0003o`000?oh803on20000Con20000?o0000ooPQ0?oh8@000ol0
0002ooPN0003o`000?oh7`3on1l000Con1l01?l00003ooPN0003o`000?oh803on20000Con2000ol0
0005ooPP0003o`000?og8`3omb<000Comb<00_l00006ooLT0003o`000?of:03omRP000?o00000_of
9`000ol0003omB/0ooD[0004ooD[00?o00001_od;`000ol0003olc@0oo<d0003o`000003oo8e0?l0
003okd@000?okd@00_l000000oo^A@3o0000omil0002omil0005o`000?oNO@3ogWd0omim0?l00000
0ooNOP001?l0003oKjl0ofn_0?l00002ofn_0006o`000?m_[`3oKjl0o`000?m_[`3o00000_m_[`00
1?l0003oKjl0ofn_0?l00005ooooo`03o`000?l0Kc7o000000Oooooo0004ooooo`04o`000?oooooo
ooooo`0000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oS
K03ohf`000Co00000ooZE@000ol0003ok4h0ona>0003ona>0003o`000?o]BP3okDX000?okDX01?l0
0004onm10003o`000?o`?P3ol3h000Col3h000?o0000oo4k0?l000000_l00002oo8f0003o`000?oc
<`3olc<000Colc<000?o0000oo<a0?oc<@000ol000000ood;@3o0000ooD[0005ooD[0004o`000?of
:@3omRT0ooHY00Go00001Oog90000ol0003omb@0ooLT0004ooLT00;o00001_oh80001?l0003on200
ooPP0?oh8005o`0000Kon1h000?o0000ooPO0?oh7`000ol000000ooi7@3o0000ooPN0005ooPN0003
o`000?oh803on20000?o00000_oh7P000ol0003on200ooPP0004ooPP0003o`000?og8`3omb<000?o
00000_og8P000ol0003omb@0ooLT0003ooLT00?o00001_of9`000ol0003omB/0ooD[0003o`0000;o
mB/000?o0000oo@_0?od;`001?od;`03o`0000GolSD000Co0000onm40?l0003o00001?o^A@000ol0
003ogW`0o`000003omim0009o`000?oNOP3ogWh0omin0?l0003ogWl0o`000?m_[`3o000000;oKjl0
00Ko0000ofn_0?m_[`3o0000ofn_0?l00002ofn_0003o`000?m_[`3oKjl000;o00000oooool00ol0
003o06lao`1_<@02o`0000Kooooo0004ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo01Sooooo00Go0000on=/0?oSK03ohf`0o`00
0005onYE0003o`000?o/CP3ok4h000?ok4h000?o0000one:0?l000000_l00002oni50003o`000?o_
@@3okd4000Cokd4000Co0000oo0n0?o`?P3ol3h01?l00006oo8f0003o`000?oc<`3olc<000?olc<0
0ol00005oo@]0003o`000?oe:`3omB/000?omB/01?l00004ooHV0003o`000?og903omb@000Comb@0
00?o0000ooLT0?og90000ol00002ooPQ0003o`000?oh803on20000?on2001?l00004ooPM0003o`00
0?oh7P3on1h000Con1h00ol00005ooTM0003o`000?oh7P3on1h000?on1h00ol00006ooPN0004o`00
0?oh803on200ooPP00Go00001_og8P000ol0003omb@0o`000002o`0000;omb@000?o0000ooHW0?of
9`001?of9`03o`0000KomB/000?o0000oo@_0?od;`000ol000000ood;`3o0000oo8e0005oo8e00;o
00001_o^A@02o`0000CogWd000Ko0000omin0?oNOP3ogWh0o`000?oNO`03o`0000;oKjl000?o0000
ofn_0?l000000_m_[`001?l0003oKjl0ofn_0?l00002ofn_0003o`000?m_[`3o000000;ooooo00?o
0000o`1_<Ol0Kc400_l00006ooooo`001Oooool2o`0000Wooooo0ol00008ooooo`03o`000?oooooo
oooo01Sooooo00Go0000on=/0?oSK03ohf`0o`000005onYE0004o`000?o/CP3ok4h0ona>00Co0000
1Oo^A@000ol0003okd40onm10003onm100Co00001?oa>@000ol0003olSH0oo8f0004oo8f0003o`00
0?oc<`3o000000;o00000_od;`000ol0003om2d0oo@]0004oo@]0003o`000?oe:`3o000000;o0000
0_of9`000ol0003omRH0ooHV0004ooHV0004o`000?og903omb@0ooLT00Go00001_oh8@000ol0003o
n200o`000002o`0000;on1d000?o0000ooPM0?oh7@001?oh7@000ol0003on1h0ooPN0003o`000003
ooTL0?l0003onAd000KonAd000?o0000ooPN0?l000000_l00002ooTL0003o`000?oh7P3on1h000Co
n1h01?l00004ooPO0003o`000?og8P3omb8000Comb800_l00006ooLT0003o`000?of9`3omRL000?o
00000_of9`000ol0003omB/0ooD[0004ooD[00?o00001Ood;`001?l0003olSD0oo8e0?ob=@02o`00
00;olSH000Co0000oni50?o^A@3okTD00_l00002oni60004o`000?oNO@3ogWd0o`0000?ogWh000Co
0000omio0?oNO`3ogWl00_l00002ofn_0003o`000?m_[`3o000000;oKjl000Ko0000ofn_0?m_[`3o
0000ofn_0?l00002ofn_0004o`000?ooooooooooo`0000;o06la0_l00006ooooo`007?ooool2o`00
01Wooooo1Ol00003onYE00Go00001?o]B@000ol0003okTD0oni50003oni50003o`000?o_@@3o0000
00;o00000_oa?@000ol0003olCT0oo4i0004oo4i0004o`000?ob=P3olSH0oo8f00Co00001_od;`00
0ol0003om2d0oo@]0003oo@]00;o00001_of9`000ol0003omRH0ooHV0003ooHV00Co00001?oh8@00
0ol0003on240ooPQ0004ooPQ00;o00001_oh7@000ol0003on1d0ooPM0003ooPM00?o00001Ooi7000
0ol0003onAd0ooTM0004ooTM00;o00001_oi70000ol0003on1h0ooPN0003o`000003ooTM0?l0003o
n1l000Kon1l000?o0000ooLR0?og8P000ol000000ooh8@3o0000ooLT0005ooLT00?o00001_of9`00
0ol0003omB/0ooD[0003o`000003ooD[0?l0003om2l000Gom2l000Co0000oo8e0?l0003o00001Oob
=P000ol0003okTD0o`000005oni60003o`000?oNO@3o000000;ogWh000?o0000omio0?oNO`000ooN
O`000ol0003oKjl0o`000002ofn_0004o`000?m_[`3oKjl0o`0000;oKjl000?o0000ofn_0?l00000
0_m_[`03o`0000?o06la0_l00006ooooo`007_ooool00ol0003oooooooooo`0Hooooo`03o`000?oU
J03o000000?o00001?o[D0000ol0003okDT0one90003one90004o`000?o^A@3okTD0oni500Co0000
1Ooa?@000ol0003olCT0oo4i0003oo4i00Co00001?oc<P000ol0003om2l0oo@_0004oo@_0003o`00
0?od;@3o000000;o000000?omRT0o`000?of9`001_of9`000ol0003omRH0o`000002o`0000;omb80
00?o0000ooPQ0?oh8@001?oh8@000ol0003on240ooPQ0003o`000003ooPN0?l0003on1d000Kon1d0
00?o0000ooPM0?l000000_l000000ooi6`3o0000ooTL0006ooTL0003o`000?oi7@3onAd000?o0000
0_oi6`000ol0003onA`0ooTL0003ooTL00?o00001Ooi7@000ol0003on1l0ooPO0004ooPO00?o0000
1Ooh8@000ol0003omb@0ooLT0003o`0000;omb<000?o0000ooHW0?of9`001?of9`03o`0000GomB/0
00?o0000oo@_0?od;`000ood;`02o`0000OolSH00_l00006oni600;o00000ooNOP000ol0003ogWl0
omio0002omio0004o`000?oMP03o0000o`0000;oKjl000?o0000ofn_0?l000000om_[`000ol0003o
Kjl0o`000002ofn_0003o`000?m][P3o000000?o06la0_l00006ooooo`007oooool00ol0003ooooo
ooooo`0Hooooo`04o`000?oUJ03oiFP0o`0000Koje0000Co0000one90?o]B@3okDT01Ol00004oo11
0003o`000?oa?@3olCd000?olCd000?o0000oo4i0?l000000_l00002oo8e0003o`000?oc<P3olc80
00Colc8000Co0000oo@_0?od;`3om2l01?l00005ooHY0003o`000?of9`3omRL000ComRL00_l00006
ooLR0003o`000?oh8@3on24000?on2400ol00005ooPN0003o`000?oh7@3on1d000Con1d00_l00005
ooTK0003o`000?oi703onA`000ConA`00ol00006ooTK0003o`000?oi703o000000;o000000?onA/0
o`000?oi7@001_oi7@000ol0003on1l0ooPO0003o`0000;on1h000?o0000ooPQ0?oh8@000ooh8@03
o`0000Komb<000?o0000ooHW0?of9`000ol000000oof9`3o0000ooD[0005ooD[0003o`000?od;`3o
m2l000?o00000_od<0000ol0003olSH0oo8f0002oo8f00;o000000?olSL0o`000?o^AP001?o^AP00
0ol0003okTL0o`000002omin0003o`000?oNO`3ogWl000;ogWl000?o0000omf00?oMP0000_l00002
ofn_0003o`000?m_[`3o000000;oKjl000Ko0000ofn_0?m_[`3o0000ofn_0?l00002off^00;o0000
00Co06lao`000?l0003o00001_ooool0023ooooo00?o0000ooooooooool06?ooool4o`0000?oje00
1_l00002oni50003o`000?o`@@3ol44000Gol44000Co0000oo4m0?oa?@3olCd00ol00006oo8e0003
o`000?oc<P3olc8000?olc801?l00004ooD[0003o`000?of:@3omRT000?omRT000?o0000ooHW0?of
9`000ol00002ooLT0003o`000?og8P3omb8000Comb8000?o0000ooPQ0?l000000_l00002ooPN0003
o`000?oh7P3on1h000Con1h000?o0000ooPM0?oh7@000ol00002ooTK0003o`000?oi6`3onA/000?o
nA/000?o0000ooTL0?oi70000ol00002ooTJ0003o`000?oi6`3onA/000ConA/00_l00005ooTK0003
o`000?oi7@3onAd000ConAd00ol00006ooPN0003o`000?oh8@3o000000;o00000_oh8@000ol0003o
mb<0ooLS0004ooLS00?o00001Oof9`000ol0003omB/0ooD[0003ooD[00?o00001_od<0001?l0003o
lSH0o`000?l00004oo8g0003o`000?o^AP3okTH000;o00000oo^A`000ol0003ogWh0o`000004omio
0007o`000?oMP03ogH00omf00?l0003oKjl0o`000002ofn_0004o`000?m_[`3oKjl0o`0000;oKjl0
00?o0000ofn_0?l000000_m][P001_l0003oHZ/0o`000?l0003oooooo`0000Kooooo000Qooooo`;o
00006?ooool00ol0003oiV@0onIT0004o`0000?ok4`000?o0000oni50?o^A@000oo^A@000ol0003o
l440oo110004oo1100Co00000oob>0000ol0003olSD0oo8e0004oo8e0003o`000?oc<P3o000000;o
00000_od;P000ol0003omB/0ooD[0004ooD[0004o`000?of:@3omRT0ooHY00Co00001_og90001?l0
003omb80ooLR0?og8P04o`0000Kon1h000Co0000ooPN0?oh7P3on1h01Ol00006ooTK0004o`000?oi
6`3onA/0ooTK00Co00001_oi6P000ol0003onA/0ooTK0003o`000003ooTI0?l0003onA/000GonA/0
00?o0000ooTM0?oi7@000ol00002ooTL0003o`000?oh7P3on1h000Con1h00_l00006ooPQ0003o`00
0?og8`3omb<000?o000000?omb@0o`000?of9`001Oof9`000ol0003omB/0ooD[0003o`0000;omB`0
00?o0000oo@`0?od<0001?od<002o`0000KolSL000?o0000oni60?l000001Oo^A`02o`0000CogWl0
00Ko0000omf00?oMP03ogH00o`000?oMPP02o`0000;oKjl000Co0000ofn_0?m_[`3o00000_m_[`00
0ol0003oKjl0o`000002off^0004o`000?mRZ`3o0000o`0000;ooooo00?o0000ooooooooool00ooo
ool002?ooooo00?o0000ooooooooool05_ooool01Ol0003oiV@0onIT0?oVI03o000000Gok4`000?o
0000oni50?o^A@000oo^A@000ol0003ol440oo110003o`000003oo4l0?l0003olSP000GolSP000Co
0000oo8e0?ob=@3olSD01?l00006oo@^0003o`000?oe:`3omB/000?omB/01?l00004ooHV0003o`00
0?og903omb@000?omb@01?l00004ooPO0003o`000?oh7P3on1h000?on1h01?l00004ooTK0003o`00
0?oi6`3onA/000ConA/01?l00003ooTI0003o`000?oi6P3onAX000ConAX00ol00005ooTI0003o`00
0?oi6`3onA/000?onA/00ol00006ooTL0003o`000?oh7P3on1h000?o000000?on1h0o`000?oh8@00
1Ooh8@03o`0000Gomb@000?o0000ooHW0?of9`000oof9`03o`0000KomB`000?o0000oo@`0?od<000
0ol000000ooc<@3o0000oo8g0005oo8g00;o00001Oo^A`001?l0003okDT0one90?l00003omio0004
o`000?oMP03ogH00o`0000?ogH8000Co0000ofn_0?m_[`3o00000_m_[`000ol0003oKjl0o`000002
ofn_0003o`000?m][P3o000000;oHZ/00_l00002ooooo`03o`000?oooooooooo00?ooooo000Toooo
o`03o`000?oooooooooo01Kooooo00Go0000onIT0?oVI03oiV@0o`000005ona<0004o`000?o^A@3o
kTD0oni500Co00001Ooa?0000ol0003olSP0oo8h0003oo8h00Co00001?oc<@000ol0003om2h0oo@^
0004oo@^0003o`000?oe:`3o000000;o00000_of:0000ol0003omRH0ooHV0004ooHV0003o`000?og
903o000000;o000000?on240o`000?oh7`001_oh7`000ol0003on1h0o`000002o`0000;onA`000?o
0000ooTK0?oi6`001?oi6`000ol0003onA/0ooTK0003o`000003ooTI0?l0003onAT000GonAT000?o
0000ooTJ0?oi6P000ol00002ooXI0003o`000?oi6@3onAT000ConAT000?o0000ooTK0?l000000_l0
0002ooTJ0003o`000?oi703onA`000ConA`00ol00005ooPN0003o`000?oh8@3on24000?o000000?o
n240o`000?og90001_og90000ol0003omRL0o`000002o`0000;omRP000?o0000ooD/0?oe;0001?oe
;003o`0000Golc4000?o0000oo8g0?ob=`000ol000000oob>03o0000oni70002oni700;o00001?o]
B@000ol0003ogWl0o`000003omf00007o`000?oMPP3ogH80omf20?l0003oKjl0o`000003ofn_0003
o`000?m_[`3o000000;oKjl000?o0000off^0?l000000_mRZ`02o`0000;ooooo00?o0000oooooooo
ool00oooool002Gooooo00?o0000ooooooooool05_ooool5o`0000?ok4`01Ol00004onm10003o`00
0?oa?03olC`000?olC`000?o0000oo8h0?l000000_l00002oo8e0003o`000?oc<@3olc4000Colc40
00Co0000oo@^0?od;P3om2h01?l00006ooHX0004o`000?of9P3omRH0ooHV00Co00001Ooh8@000ol0
003on1l0ooPO0004ooPO00;o00001_oi70000ol0003onA/0ooTK0003ooTK00?o00001Ooi6@000ol0
003onAT0ooTI0003ooTI00?o00001_oj6@001?l0003onAT0ooTI0?oi6@04o`0000KonAX000?o0000
ooTL0?oi70000ol00002ooTL0003o`000?oh7P3on1h000?on1h00ol00005ooPQ0003o`000?og903o
mb@000Comb@00_l00006ooHX0003o`000?oe;03omB`000?o000000?om2d0o`000?oc<@001Ooc<@03
o`0000GolSP000?o0000oni70?l000001_o]B@02o`0000?ogH0000Ko0000omf20?oMPP3ogH80o`00
0?oLQ002o`0000?oKjl000?o0000ofn_0?l000000_m_[`001?l0003oKJh0o`000?mRZ`02o`0000?o
oooo00?o0000ooooooooool00oooool002Kooooo00?o0000ooooooooool05oooool00ol0003oiV40
o`000003o`0000CokTP000?o0000onm10?o_@@000oo_@@001?l0003olC`0oo4l0?oa?004o`0000Go
lSD000?o0000oo<a0?oc<@000ooc<@04o`0000ComB/000?o0000ooHX0?of:0000oof:004o`0000Co
mb<000?o0000ooPQ0?oh8@000ooh8@000ol0003on1l0ooPO0003o`0000;onAd000?o0000ooTL0?oi
70001?oi70000ol0003onA/0o`000002o`0000;onAT000?o0000ooTI0?oi6@001?oi6@000ol0003o
nAT0o`000002o`0000;onQP000?o0000ooXI0?oj6@001?oj6@04o`0000ConQT000?o0000ooTJ0?oi
6P000ooi6P03o`0000KonA`000?o0000ooPN0?l000000_l00002ooPN0003o`000?oh8@3on24000Co
n24000?o0000ooLT0?og90000ol000000oog903o0000ooHX0005ooHX00?o00001Ood;@000ol0003o
lc40oo<a0003o`0000;olc<000?o0000oo8h0?ob>0000oob>002o`0000KokDT000?o0000one<0?l0
00000ooMP0001?l0003ogH80omf20?l00003omb400;o000000OoKjl0o`000?m_[`3oKjl0o`000?m_
[`3o000000;oKJh000Co0000of:[0?l0003o00000oooool00ol0003oooooooooo`03ooooo`009ooo
ool2o`0001Sooooo00Go0000onIQ0?oVH@3oiV40o`000005oni80004o`000?o_@@3okd40onm100Go
00001?oa>@000ol0003olSD0oo8e0003oo8e0003o`000?oc<@3o000000;o00000ood;P000ol0003o
mB/0ooD[0003ooD[0003o`000?of:03o000000;o00000_og9@000ol0003omb<0ooLS0004ooLS0004
o`000?oh8@3on240ooPQ00Co00001_oi7@001?l0003onA`0ooTL0?oi7004o`0000KonAT000Co0000
ooTI0?oi6@3onAT01?l00006ooXH0003o`000?oj6@3onQT000?o00000_oj60000ol0003onQT0ooXI
0004ooXI0003o`000?oi6P3o000000;o00000_oi6P000ol0003onA`0ooTL0004ooTL00;o00001_oh
7P001?l0003on240ooPQ0?oh8@05o`0000Gomb@000?o0000ooHX0?of:0000ol00002ooHY0003o`00
0?od;@3om2d000?om2d00ol00006oo<c0003o`000?ob>03o000000;o00000_oa>`001?l0003okDT0
one90?o]B@02o`0000?okD`000?o0000omf00?l000000ooMPP001_l0003og8@0omb40?oLQ03o0000
om^600;o00000_m_[`000ol0003oKjl0o`000002off^0004o`000?mRZ`3o0000o`0000?ooooo00?o
0000ooooooooool00oooool002Wooooo00?o0000ooooooooool05_ooool5o`0000?okTP01Ol00003
oo0m0003o`000?oa>@3olCT000ColCT000Co0000oo8e0?ob=@3olSD00ol00007oo@^0004o`000?oe
:`3omB/0ooD[00?o00001_og9@000ol0003omb<0ooLS0003ooLS00Co00001?oh7`000ol0003onAd0
ooTM0003ooTM00Co00001?oi6P000ol0003onAT0ooTI0003ooTI00Co00001?oj60000ol0003onQP0
ooXH0003ooXH00?o00001_oj60001?l0003onQT0ooXI0?oj6@04o`0000KonAX000?o0000ooTL0?oi
70000ol000000ooi703o0000ooPN0005ooPN00Co00001?og8@000ol0003omb@0ooLT0003ooLT00?o
00001_of:@000ol0003om2d0o`000002o`0000;om2l000?o0000oo<c0?oc<`001?oc<`02o`0000Ko
lC/000?o0000one90?l000001Oo]C002o`0000?ogH8000Wo0000omb40?oLQ03og8@0o`000?oKQP3o
0000om^60?l000000_m_[`000ol0003oKjl0o`000002off^0003o`000?mRZ`3o000000Gooooo00?o
0000ooooooooool00_ooool002[ooooo00?o0000ooooooooool05_ooool00ol0003oieh0onMN0004
o`0000;okTD000?o0000oo0m0?o`?@001?o`?@001?l0003olCT0oo4i0?oa>@06o`0000?olc8000?o
0000oo@^0?od;P001?od;P04o`0000?omRP000?o0000ooLU0?og9@001?og9@000ol0003omb<0o`00
0002o`0000;on24000?o0000ooPO0?oh7`001?oh7`000ol0003onAd0o`000002o`000003ooTK0?l0
003onAX000KonAX000?o0000ooTI0?l000000_l00002ooXH0003o`000?oj603onQP000ConQP000?o
0000ooXH0?l000000_l00002ooXG0003o`000?oj603onQP000ConQP01?l00003ooXH0003o`000?oi
6P3onAX000ConAX00ol00005ooTL0003o`000?oh7P3on1h000?o00000_oh7`000ol0003omb40ooLQ
0004ooLQ0003o`000?og903o000000;o00000_of9P000ol0003omRT0ooHY0004ooHY00;o00001_od
;`000ol0003olc<0oo<c0003o`000003oo8e0?l0003olC/000GolC/00_l00004one<00;o000000?o
k4h0o`000?oMPP000_oMPP001?l0003og8@0omb40?l00003om^600;o000000OoKjl0o`000?m_[`3o
Kjl0o`000?m][P3o000000;oHZ/000?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`00:oooool00ol0003oooooooooo`0Fooooo`04o`000?oWGP3oieh0o`0000GokTD000?o0000oo0m
0?o`?@000oo`?@04o`0000ColSH000?o0000oo<b0?oc<P000ooc<P000ol0003om2h0oo@^0003o`00
0003ooD[0?l0003omRP000GomRP000Co0000ooLU0?og9@3ombD01?l00006ooPQ0004o`000?oh7`3o
n1l0ooPO00Co00001Ooi6`000ol0003onAX0ooTJ0004ooTJ00;o00001_oj60001?l0003onQP0ooXH
0?oj6004o`0000KonQL000?o0000ooXH0?oj60000ol000000ooj603o0000ooXH0005ooXH0003o`00
0?oi6P3onAX000?o00000_oi6P000ol0003onA`0ooTL0003ooTL00?o00001_oh7`001?l0003omb40
ooLQ0?og8@04o`0000KomRH000?o0000ooHY0?of:@000ol000000ooe:`3o0000oo@_0005oo@_00?o
00001Oob=@000ol0003olC/0oo4k0003o`0000;ol3d000Co0000one<0?l0003o00001?o/CP000ol0
003ogH80o`000003omb40004o`000?oKQP3ofhH0om^600Co00000_m_[`001?l0003oKJh0o`000?mR
Z`02o`0000Gooooo00?o0000ooooooooool00_ooool002cooooo0_l0000Gooooo`;o000000?oieh0
o`000?o^A@001?o^A@000ol0003ol3d0o`000002o`0000;olCX000?o0000oo8f0?ob=P001?ob=P00
1?l0003olc80oo<b0?oc<P04o`0000GomB/000?o0000ooHX0?of:0000oof:004o`0000Comb<000?o
0000ooPQ0?oh8@000ooh8@04o`0000ConAd000?o0000ooTK0?oi6`000ooi6`000ol0003onAX0ooTJ
0003o`0000;onQT000?o0000ooXH0?oj60000ooj6004o`0000ConQL000?o0000ooXG0?oj5`000ooj
5`03o`0000GonQP000?o0000ooXH0?oj60000ooj6003o`0000KonAX000?o0000ooTL0?l000000_l0
0002ooTM0003o`000?oh7`3on1l000Con1l01?l00003ooLS0003o`000?of9P3omRH000ComRH00ol0
0005ooD[0003o`000?od;`3om2l000?o000000?olc40o`000?ob=@001Oob=@03o`0000Gol3d00_l0
0006ona>00;o00000ooLQ0002Ol0003ofhH0om^60?oKQP3o0000om^80?l0003ofhP0o`000002ofn_
0004o`000?m][P3o0000of:[00;o00001Oooool00ol0003oooooooooo`02ooooo`00;_ooool00ol0
003oooooooooo`0Fooooo`?o00000oo^A@04o`0000GolCX000?o0000oo8f0?ob=P000oob=P04o`00
00Com2l000?o0000ooD[0?oe:`000ooe:`000ol0003omRP0o`000002o`0000?omRH000?o0000ooLS
0?og8`000oog8`000ol0003on240o`000002o`000003ooPO0?l0003onAd000KonAd000Co0000ooTK
0?oi6`3onA/01?l00006ooXI0003o`000?oj603o000000;o000000?onQL0o`000?oj5`001_oj5`00
0ol0003onQL0o`000002o`0000;onQL000?o0000ooXH0?oj60001?oj60000ol0003onQP0o`000002
o`0000;onQT000?o0000ooTJ0?oi6P001?oi6P02o`0000KonAd000?o0000ooPO0?oh7`000ol00002
ooPP0003o`000?og8`3omb<000?omb<000?o0000ooHV0?of9P000ol000000oof9`3o0000ooD[0005
ooD[00?o00001Ooc<@000ol0003olSD0oo8e0003o`000003oo8h0?l0003ol3d000?ol3d00_l00002
oo100004o`000?o/CP3ok4h0ona>00;o000000?oje40o`000?oLQ0000_oLQ0001Ol0003ofhH0om^6
0?oKQP3o000000;ofhP00_l000001om_[`3o0000off^0?m][P3o0000of:[0?l000001_ooool00ol0
003oooooooooo`02ooooo`00;oooool00ol0003oooooooooo`0Fooooo`03o`000?oXG03o000000;o
00001?o_@P000ol0003olCX0oo4j0003oo4j0003o`000?ob=P3o000000;o00000_oc<`000ol0003o
m2l0oo@_0004oo@_0004o`000?oe:`3omB/0ooD[00?o00001oof9P001?l0003omb<0ooLS0?og8`03
o`0000Gon1l000?o0000ooTM0?oi7@001?oi7@04o`0000?onAX000?o0000ooXI0?oj6@001?oj6@02
o`0000GonQL000?o0000ooXG0?oj5`001?oj5`02o`0000KonQL000Co0000ooXH0?oj603onQP01?l0
0006ooXI0003o`000?oi6P3onAX000?o00000_oi6`000ol0003onAd0ooTM0003ooTM00?o00001_oh
80001?l0003omb<0ooLS0?og8`04o`0000GomRL000?o0000ooD[0?oe:`000ol00002oo@]0003o`00
0?oc<@3olc4000?olc400ol00005oo8h0004o`000?o`?@3o0000o`0000Gol40000?o0000ona>0?l0
00001?o[D@000ol0003og8@0o`000003om^60004o`000?oKR03ofhP0om^800Co00000_m][P000ol0
003oHZ/0o`000006ooooo`03o`000?oooooooooo00;ooooo000`ooooo`03o`000?oooooooooo01Ko
oooo0_l000000ooXG03o0000onm20004onm20004o`000?oa>P3olCX0oo4j00?o00001_oc<`000ol0
003om2l0oo@_0003oo@_00Co00000oof:@000ol0003omRH0ooHV0004ooHV00Co00000ooh8@000ol0
003on1l0ooPO0003ooPO0003o`000?oi7@3onAd000?o00000_oi70000ol0003onAX0ooTJ0003ooTJ
0003o`000?oj6@3onQT000?o00000_oj60000ol0003onQL0ooXG0003ooXG0003o`000?oj5`3onQL0
00?o00000_oj5`000ol0003onQL0ooXG0003ooXG00Co00001?oj60000ol0003onQT0ooXI0003ooXI
00?o00001_oi6`000ol0003onAd0o`000002o`0000;on1h000?o0000ooPP0?oh80001?oh8004o`00
00Comb@000Co0000ooHW0?of9`3omRL01?l00006oo@]0003o`000?oc<@3o000000;o00000ooc<`00
1?l0003olSP0oo8h0?ob>004o`0000Kol4000_l00005on]A00?o00000ooKQP001?l0003ofhP0om^8
0?l00002omZ;00;o00000_m][P000ol0003oHZ/0o`000006ooooo`03o`000?oooooooooo00;ooooo
000aooooo`;o00005oooool4o`0000?okd801Ol00003oo8g0003o`000?oc<`3olc<000Colc<000?o
0000oo@_0?l000000_l00002ooD]0003o`000?of:@3omRT000?omRT000?o0000ooHV0?of9P000ol0
00000oog903o0000ooPQ0005ooPQ0004o`000?oh7`3on1l0ooPO00Co00001_oi70001?l0003onAX0
ooTJ0?oi6P04o`0000KonQP000Co0000ooXG0?oj5`3onQL01?l00006ooXG0003o`000?oj5`3o0000
00;o00000_oj5`000ol0003onQP0ooXH0004ooXH0003o`000?oj6@3o000000;o00000_oi6@000ol0
003onA/0ooTK0004ooTK00;o00001_oh7P000ol0003on200ooPP0003o`000003ooLR0?l0003omb@0
00Gomb@01?l00004ooDZ0004o`000?od;@3om2d0oo@]00Co00001_oc<`04o`0000ColC/000?o0000
oo100?o`@0000ol000000oo_A03o0000on]A0002on]A00;o00000ooZE@000ol0003ofhH0o`000003
om^80003o`000?oJR`3ofX/000;o000000GoKJh0o`000?mRZ`3oHZ/0o`000007ooooo`03o`000?oo
oooooooo007ooooo000cooooo`03o`000?oooooooooo01Gooooo00?o0000onQJ0?oXFP000ol00003
oo0o0003o`000?ob=`3olSL000?olSL000Co0000oo<c0?oc<`3olc<01?l00006ooD]0004o`000?of
:@3omRT0ooHY00Co00001Oog90000ol0003on240ooPQ0003ooPQ00Co00001?oh7P000ol0003onA`0
ooTL0003ooTL00Co00000ooi6@000ol0003onQP0ooXH0004ooXH00Co00000ooj5`000ol0003onQL0
ooXG0004ooXG00;o00001_oj5`001?l0003onQP0ooXH0?oj6004o`0000KonAT000?o0000ooTK0?oi
6`000ol000000ooi703o0000ooPN0005ooPN00?o00001Oog8P000ol0003omb@0ooLT0003o`000003
ooHW0?l0003omBX000GomBX01?l00004oo@`0003o`000?oc<`3olc<000?o000000?olSL0o`000?oa
>`001Ooa>`03o`0000Gokd@000?o0000on]A0?l000001OoZE@02o`0000?ofhP000Co0000omZ;0?oJ
R`3ofX/01?l000000omRZ`3o0000ooooo`07ooooo`03o`000?oooooooooo007ooooo000dooooo`03
o`000?oooooooooo01Gooooo0_l000000ooXFP3o0000oo0o0004oo0o0004o`000?ob=`3olSL0oo8g
00Go00001?od<@000ol0003omBd0ooD]0003ooD]00Co00001?of9`000ol0003omb@0ooLT0003ooLT
0003o`000?oh8@3o000000;o00000_oh80000ol0003on1h0ooPN0004ooPN0003o`000?oi703o0000
00;o00000_oi6`000ol0003onAT0ooTI0003ooTI0003o`000?oj603onQP000?o00000_oj60000ol0
003onQL0ooXG0003ooXG0003o`000?oj5`3onQL000?o00000_oj5`000ol0003onQL0ooXG0003ooXG
00Co00000ooj6@000ol0003onAT0ooTI0004ooTI00?o00001Ooi70000ol0003on1h0ooPN0003o`00
00;on20000?o0000ooLR0?og8P000oog8P03o`0000GomRL000?o0000ooDZ0?oe:P000ol000000ooe
;@3o0000oo@`0005oo@`00?o00001Oob=`000ol0003olC/0oo4k0003o`000003oo0n0?l0003okd@0
00Gokd@00_l00005onYE0003o`000?oYF@3o000000?ofhP000Co0000omZ;0?oJR`3o00000_oHS`04
o`0000Sooooo00?o0000ooooooooool00Oooool003Gooooo00?o0000ooooooooool05_ooool3o`00
00?ol3l01Ol00004oo8e0003o`000?od<@3om34000?om34000?o0000ooD]0?l000000_l00002ooD[
0003o`000?of9`3omRL000ComRL000Co0000ooLT0?og903omb@00ol00006ooPP0004o`000?oh7P3o
n1h0ooPN00Co00001_oi6`001?l0003onAT0ooTI0?oi6@04o`0000KonQP000Co0000ooXG0?oj5`3o
nQL01?l00006ooXG0003o`000?oj5`3o000000;o00000_oj60000ol0003onQT0ooXI0003ooXI0003
o`000?oi6@3onAT000?o00000_oi6`000ol0003onA`0ooTL0003ooTL00?o00001_oh80000ol0003o
mb80o`000002o`0000;omb@000?o0000ooHW0?of9`000oof9`03o`0000GomBd000?o0000oo@`0?od
<0000ol000000ooc<`3o0000oo8g0005oo8g00?o00001Oo`?P000ol0003okd@0onm40003o`000003
oni80?l0003ojUD000;ojUD00_l00003onUI0003o`000?oKR03o000000?ofX/000Oo0000omR?0?oH
S`3of8l0o`000?oDW@3o000000Sooooo00?o0000ooooooooool00Oooool003Kooooo0_l0000Goooo
o`03o`000?oYF03o000000;o00001?o`?@000ol0003olSD0oo8e0003oo8e0004o`000?od<@3om340
oo@a00?o00001_oe:`001?l0003omRL0ooHW0?of9`06o`0000?omb<000?o0000ooPP0?oh80000ooh
8004o`0000ConAd000?o0000ooTK0?oi6`000ooi6`04o`0000?onAT000?o0000ooXH0?oj60001?oj
6004o`0000?onQL000?o0000ooXG0?oj5`001?oj5`02o`0000KonQP000Co0000ooXI0?oj6@3onQT0
1?l00006ooTK0003o`000?oi703o000000;o00000_oh7P000ol0003on200ooPP0004ooPP00;o0000
1_og90000ol0003omRL0o`000002o`0000;omRT000?o0000ooD]0?oe;@000ooe;@03o`0000Golc<0
00?o0000oo8g0?ob=`000ol000000ooa>P3o0000oo0n0005oo0n00?o00001Oo^B0000ol0003ojUD0
o`000005onUI00;o00000ooJR`001?l0003of8l0omR?0?oHS`02o`000003omBM0?l0003ooooo00Oo
oooo00?o0000ooooooooool00Oooool003Sooooo00?o0000ooooooooool05Oooool2o`000003onUH
0?l0003ol3d000Col3d000Co0000oo8e0?ob=@3olSD01Ol00003oo@_0003o`000?oe:`3omB/000?o
mB/01?l00004ooHV0003o`000?og8`3omb<000?omb<000?o0000ooPP0?l000000_l00002ooPO0003
o`000?oi7@3onAd000ConAd000?o0000ooTK0?l000000_l00002ooTK0003o`000?oi6@3onAT000?o
nAT000?o0000ooXH0?oj60000ol00002ooXH0003o`000?oj5`3onQL000?onQL000?o0000ooXG0?oj
5`000ol00002ooXH0003o`000?oj603onQP000?onQP01?l00004ooTJ0004o`000?oi6`3onA/0ooTK
00Co00001_oh7P000ol0003on200ooPP0003o`000003ooLR0?l0003omb@000Gomb@00_l00006ooHY
0003o`000?oe;@3o000000;o00000_od<0000ol0003olc<0oo<c0003oo<c00?o00001Ooa>P000ol0
003ol3h0oo0n0003o`000003onm30?l0003okTP000GokTP00_l00004onUI00;o000000?oieh0o`00
0?oJR`000_oJR`001?l0003of8l0omR?0?l00002omBM0003o`000?oooooooooo00Oooooo00?o0000
ooooooooool00Oooool003Wooooo00?o0000ooooooooool05Oooool4o`0000?ol3d01Ol00003oo<c
0003o`000?od;`3om2l000?om2l000?o0000ooD[0?l000000_l00003ooHY0003o`000?of9P3omRH0
00?omRH000Co0000ooLS0?og8`3omb<00ol00006ooPO0004o`000?oi7@3onAd0ooTM00Co00001_oi
6`001?l0003onAT0ooTI0?oi6@04o`0000KonQP000Co0000ooXG0?oj5`3onQL01?l00006ooXH0003
o`000?oj603o000000;o00000_oi6@000ol0003onAX0ooTJ0003ooTJ00Co00000ooi70000ol0003o
n1h0ooPN0004ooPN00?o00001Oog8P000ol0003omb@0ooLT0003o`000003ooHW0?l0003omRT000Go
mRT00_l00006oo@`0003o`000?oc<`3o000000;o00000_ob=`000ol0003olCX0oo4j0003oo4j00?o
00001Oo_@`000ol0003okTP0oni80003o`0000;ok4`000Co0000onUI0?l0003o00001?oWGP000ol0
003ofX/0o`000002omR?0006o`000?oDW@3oe9d0o`000?oooooo00002?ooool00ol0003ooooooooo
o`01ooooo`00>_ooool00ol0003oooooooooo`0Eooooo`03o`000?oYE`3ojEL000?o00000ooa>`00
0ol0003olc<0oo<c0003oo<c0004o`000?od;`3om2l0oo@_00Co00001_of:@001?l0003omRH0ooHV
0?of9P05o`0000?omb8000?o0000ooPO0?oh7`000ooh7`04o`0000ConA`000?o0000ooTK0?oi6`00
0ooi6`04o`0000?onAT000?o0000ooXH0?oj60001?oj6004o`0000ConQP000Co0000ooXH0?oj603o
nQP01?l00006ooTI0003o`000?oi6P3o000000;o00000_oi70000ol0003onA`0ooTL0003ooTL0003
o`000?oh7P3on1h000?o00000_oh80000ol0003omb80ooLR0003ooLR00?o00001Oof9`000ol0003o
mRT0ooHY0003o`000003oo@]0?l0003om30000Gom3000_l00006oo8g0003o`000?oa>P3o000000;o
00000oo`?P001?l0003okd<0onm30?o_@`04o`0000Gok4`00_l00006onMN00;o00000ooHS`000ol0
003oe9d0o`000003ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo000kooooo`03
o`000?oooooooooo01Gooooo0_l000000ooYE`3o0000oo4k0004oo4k0004o`000?oc<`3olc<0oo<c
00Go00001?od;P000ol0003omRT0ooHY0003ooHY00Co00000oog9@000ol0003omb80ooLR0003ooLR
0003o`000?oh7`3o000000;o00000ooh7`000ol0003onA`0ooTL0003ooTL0003o`000?oi6`3o0000
00;o00000_oi6`000ol0003onAT0ooTI0003ooTI0003o`000?oj603onQP000?o00000_oj6@000ol0
003onQP0ooXH0003ooXH00Co00000ooi6@000ol0003onAT0ooTI0004ooTI00;o00001_oi70001?l0
003onA`0ooTL0?oi7004o`0000Kon20000?o0000ooLR0?l000000_l00002ooLU0003o`000?of9`3o
mRL000?omRL00ol00005oo@]0003o`000?od<03om30000?o000000?olc<0o`000?ob=`001Oob=`02
o`0000Kol3h01?l00004oni70003o`000?o/C03o000000;o000000?oje40o`000?oWGP000ooWGP02
o`0000;oiV@000?o0000omR?0?l000000_oDW@001Ol0003ooooooooooooooooo000000Sooooo0Ol0
0001ooooo`7ooooo000looooo`;o00005oooool3o`0000?olC/01Ol00003oo<b0003o`000?od;P3o
m2h000Com2h000?o0000ooHY0?l000000_l00002ooHY0003o`000?og9@3ombD000?ombD000Co0000
ooLR0?og8P3omb801?l00006ooPO0004o`000?oi703onA`0ooTL00?o00001_oi6`001?l0003onAT0
ooTI0?oi6@04o`0000KonQT000?o0000ooXH0?l000000_l00002ooTI0003o`000?oi6@3onAT000?o
nAT000?o0000ooTI0?oi6@000ol00002ooTK0003o`000?oi703onA`000?onA`01?l00004ooPO0004
o`000?oh803on200ooPP00Co00001_og9@000ol0003omRL0o`000002o`0000?omBX000Co0000oo@]
0?od;@3om2d01?l00005oo<c0003o`000?ob=`3olSL000?o00000_oa>`000ol0003ol3h0oo0n0003
o`000003onm30?l0003okTL000GokTL00_l00005on]A0004o`000?oWGP3o0000o`0000CoiV@00ol0
00000ooDW@3o0000ooooo`04ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000n
ooooo`03o`000?oooooooooo01Gooooo00?o0000onYF0?l000000_l00003oo4j0003o`000?oc<P3o
lc8000?olc8000Co0000oo@^0?od;P3om2h01?l00006ooHY0004o`000?og9@3ombD0ooLU00Go0000
1?og8P001?l0003on1l0ooPO0?oh7`06o`0000?onAd000?o0000ooTK0?oi6`000ooi6`04o`0000Co
nAX000Co0000ooXI0?oj6@3onQT01?l00006ooTI0004o`000?oi6@3onAT0ooTI00Co00001_oi6`00
0ol0003onA`0o`000002o`0000;on1h000?o0000ooPO0?oh7`000ooh7`04o`0000Comb<000Co0000
ooLU0?og9@3ombD01?l00006ooDZ00Co00001?od<0001?l0003olc<0oo<c0?oc<`04o`0000GolC/0
0ol00005onm30003o`000?o^A`3okTL000?o000000?ok4`0o`000?o[D@001?o[D@03o`0000?oiV@0
0_l00002on5e00;o00001oooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00?ooo
ool00ol0003oooooooooo`0Eooooo`?o00001Ooa>P001?l0003olc80oo<b0?oc<P05o`0000Com2d0
00?o0000ooHY0?of:@000oof:@04o`0000?ombD000?o0000ooLR0?og8P000oog8P04o`0000Con1l0
00?o0000ooTM0?oi7@000ooi7@000ol0003onA/0o`000002o`0000;onA`000?o0000ooTJ0?oi6P00
0ooi6P04o`0000ConAX000?o0000ooTI0?oi6@000ooi6@04o`0000ConA/000Co0000ooTK0?oi6`3o
nA/01?l00006ooPN0003o`000?oh7`3o000000;o00000_og8P000ol0003omb<0ooLS0003ooLS00Co
00001?of:0000ol0003omBX0ooDZ0003o`000003oo@^0?l0003om30000Gom3001?l00004oo8h0003
o`000?oa>`3o000000;o000000?ol3l0o`000?o_@`001Oo_@`03o`0000Gok4`000?o0000on]A0?l0
00000_l00003onUH0004o`000?oVI03o0000on5e00?o00002_ooool00ol0003oooooooooo`03oooo
o`7o00000Oooool1ooooo`00@?ooool00ol0003oooooooooo`0Eooooo`?o00000ooa>P05o`0000Co
lc4000?o0000oo@]0?od;@000ood;@000ol0003omRT0o`000002o`0000;omRP000?o0000ooLU0?og
9@000oog9@000ol0003omb80o`000002o`0000;omb8000?o0000ooPO0?oh7`001?oh7`001?l0003o
nAd0ooTM0?oi7@04o`0000GonA`000?o0000ooTJ0?l000000_l00002ooTK0003o`000?oi6P3onAX0
00ConAX000?o0000ooTI0?l000000_l00002ooTK0003o`000?oi6`3onA/000?onA/01?l00004ooPM
0004o`000?oh7P3on1h0ooPN00Co00001_og8P000ol0003omb<0o`000002o`0000;omRH000?o0000
ooHX0?of:0000oof:003o`0000Gom2h000?o0000oo@`0?od<0000ol000000ooc=03o0000oo8h0005
oo8h00;o00001Oo`?`000ol0003okd<0onm30003o`0000;okTP000Co0000ona<0?o/C03ok4`01?l0
0006onUH00Co00003Oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00@Oooool2
o`0001Kooooo00?o0000onYF0?l000000_l00004oo4i0003o`000?oc<@3olc4000?olc4000Co0000
oo@]0?od;@3om2d01?l00005ooHX0004o`000?og9@3ombD0ooLU00?o00001_og8P001?l0003on1l0
ooPO0?oh7`06o`0000Con1d000Co0000ooTL0?oi703onA`00ol00006ooTK0004o`000?oi6P3onAX0
ooTJ00Co00001_oi6`000ol0003onA/0o`000002o`0000;on1d000?o0000ooPM0?oh7@000ooh7@04
o`0000?on24000?o0000ooLR0?og8P001?og8P02o`0000KomRH000?o0000ooHX0?l000000_l00002
ooD/0003o`000?od;P3om2h000?om2h00ol00005oo<d0003o`000?ob>03olSP000?o000000?olC`0
o`000?o`?`001?o`?`03o`0000GokTP01?l00004on]C0003o`000?oYF03ojEP000Co00004Oooool0
0ol0003oooooooooo`03ooooo`7o00000Oooool004?ooooo00?o0000ooooooooool05?ooool2o`00
0003onYF0?l0003olCT000ColCT000Co0000oo<a0?oc<@3olc401Ol00004ooD]0004o`000?of:03o
mRP0ooHX00Go00000oog9@000ol0003omb80ooLR0003ooLR00Co00001?oh80000ol0003on1d0ooPM
0003ooPM00Co00000ooi7@000ol0003onA/0ooTK0003ooTK00Co00001?oi70001?l0003onA/0ooTK
0?oi6`04o`0000Kon1d000?o0000ooPM0?l000000_l00002ooPP0003o`000?oh8@3on24000?on240
00?o0000ooLR0?og8P000ol000000oog9@3o0000ooHV0005ooHV00;o00001_oe;0000ol0003om2h0
o`000002o`0000;olc8000?o0000oo<d0?oc=0000ooc=003o`0000GolC`000?o0000oo0o0?l00000
0_l00003oni50003o`000?o^B03o000000;o000000?ok4l0o`000?o[D`001Oo[D`04o`0001Gooooo
00?o0000ooooooooool00_ooool1o`00007ooooo0014ooooo`03o`000?oooooooooo01Cooooo1?l0
0003oo4i00Go00000ooc<@000ol0003omBd0ooD]0003ooD]00Co00000oof:@000ol0003ombD0ooLU
0003ooLU0003o`000?og8P3o000000;o00000oog8`000ol0003on200ooPP0003ooPP0003o`000?oh
7@3o000000;o00000_oh7`000ol0003onAd0ooTM0003ooTM0003o`000?oi6`3o000000;o00000_oi
7@000ol0003onA`0ooTL0003ooTL00Co00001?oh7@000ol0003on1d0ooPM0003ooPM00;o00001_oh
80001?l0003on240ooPQ0?oh8@04o`0000GombD000?o0000ooHV0?of9P000ol00002ooDZ0004o`00
0?oe;03omB`0ooD/00Co00001_oc<P000ol0003olc@0o`000002o`0000;olCT000Co0000oo4l0?oa
?03olC`01?l00006oni500;o00001Oo/C`000ol0003oje<0on]C0005o`0001Oooooo00?o0000oooo
ooooool00_ooool1o`00007ooooo0015ooooo`03o`000?oooooooooo01Cooooo00?o0000onYE0?oZ
E@000ol00003oo4i0003o`000?oc<@3olc4000?olc4000?o0000ooD]0?l000000_l00002oo@]0003
o`000?of:@3omRT000?omRT000Co0000ooLU0?og9@3ombD01?l00006ooLS0004o`000?oh803on200
ooPP00Co00001Ooh7`001?l0003onAd0ooTM0?oi7@04o`0000GonAd000?o0000ooTL0?l000000_l0
0002ooPN0003o`000?oh7@3on1d000Con1d000?o0000ooPM0?l000000_l00002ooPP0003o`000?oh
803on20000?on2001?l00004ooLT0004o`000?og9@3ombD0ooLU00Co00001Ooe:P04o`0000Com300
00Co0000oo<b0?oc<P3olc801?l00005oo4i00Co00001?o_@@000ol0003okTD0oni50003o`0000;o
kD`000Co0000ona?0?o/C`3ok4l01_l0000Kooooo`05o`000?ooooooooooooooool000000Oooool0
04Kooooo0_l0000Eooooo`;o000000?ojUD0o`000?oa>@001?oa>@001?l0003olc40oo<a0?oc<@04
o`0000Gom2d000Co0000ooHY0?of:@3omRT01Ol00004ooHV0004o`000?og8`3omb<0ooLS00Ko0000
1?oh8@001?l0003on1l0ooPO0?oh7`05o`0000Con1l000Co0000ooTM0?oi7@3onAd01?l00005ooPN
0004o`000?oh7@3on1d0ooPM00Co00001_oh80000ol0003on200o`000002o`0000;omb<000?o0000
ooLT0?og90000oog9004o`0000ComRT000?o0000ooDZ0?l000000_l00002oo@^0003o`000?od<03o
m30000?om3001?l00004oo8g0003o`000?oa>@3o000000;o00000_o`?P000ol0003okd40onm10003
onm100?o00001Oo]C007o`0001oooooo00Co0000oooooooooooo00000Oooool004Sooooo00?o0000
ooooooooool05?ooool3o`0000?olCT01Ol00004oo<a0004o`000?od;@3om2d0oo@]00Go00000oof
:@000ol0003omRH0ooHV0003ooHV00Co00001?og90000ol0003on240ooPQ0003ooPQ00Co00000ooh
8@000ol0003on1l0ooPO0003ooPO00Co00001?oh7`001?l0003on1h0ooPN0?oh7P05o`0000Con200
00Co0000ooPP0?oh803on2001?l00006ooLS0003o`000?og903o000000;o00000_of:0000ol0003o
mRT0ooHY0003ooHY00;o00001_od;P000ol0003om300o`000002o`0000;olcD000?o0000oo8g0?ob
=`000oob=`02o`0000Kol3h000?o0000onm10?l000000_l00003one80003o`000?o]C03o000000;o
000000Coiel0o`000?l0003o00008oooool00ol0003oooooo`000001ooooo`00BOooool00ol0003o
ooooooooo`0Dooooo`Go00000ooa>@000ol0003olc40oo<a0003oo<a00Co00000ood;P000ol0003o
mRT0ooHY0003ooHY0003o`000?of9P3o000000;o00000_of9`000ol0003omb@0ooLT0004ooLT0003
o`000?oh8@3o000000;o00000_og8`000ol0003on240ooPQ0003ooPQ0003o`000?oh7`3o000000;o
00000_oh8@000ol0003on1l0ooPO0003ooPO00Co00000ooh8@000ol0003on200ooPP0003ooPP00Co
00001?og8`001?l0003omb<0ooLS0?og8`04o`0000KomRP000?o0000ooHY0?l000000_l00002oo@]
0004o`000?od;P3om2h0oo@^00Co00001_oc=@000ol0003olSL0o`000002o`0000;olC`000Co0000
oo0n0?o`?P3ol3h01?l00006one800Ko00009_ooool00ol0003oooooo`000001ooooo`00B_ooool0
0ol0003oooooooooo`0Eooooo`?o00001?oa>@000ol0003olc40o`000002o`0000;olc8000?o0000
oo@^0?od;P000ood;P001?l0003omRT0ooHY0?of:@04o`0000GomRL000Co0000ooLT0?og903omb@0
1?l00006ooLS0004o`000?oh8@3on240ooPQ00Co00001Ooh8@000ol0003on1l0o`000002o`0000;o
mb8000?o0000ooPQ0?oh8@000ooh8@000ol0003on200o`000002o`0000;omb@000?o0000ooLS0?og
8`000oog8`04o`0000ComRL000Co0000ooHX0?of:03omRP01?l00005oo@]00Co00001?oc<`001?l0
003olcD0oo<e0?oc=@04o`0000GolC`01?l00004oni60003o`000?o]B03okDP000Go0000:oooool1
o`00007ooooo0Ol0000004_ooooo0_l0000Fooooo`03o`000?oZEP3o000000Ko00001Ooc<P001?l0
003om2h0oo@^0?od;P05o`0000ComB/000Co0000ooHW0?of9`3omRL01Ol00004ooHV0004o`000?og
8`3omb<0ooLS00Ko00001?og8`001?l0003on240ooPQ0?oh8@04o`0000Gomb8000Co0000ooPQ0?oh
8@3on2401?l00005ooLT0003o`000?og8`3o000000;o00000_of9`000ol0003omRL0ooHW0003ooHW
00Co00001?oe;0000ol0003om2d0o`000002o`0000;olc8000?o0000oo<c0?oc<`000ooc<`04o`00
00ColCX000?o0000oo4l0?l000000_l00003onm30004o`000?o^AP3okTH0oni600Ko0000;oooool2
o`000000COooool00ol0003oooooooooo`0Dooooo`?o00001Ooa>P001?l0003olc80oo<b0?oc<P05
o`0000Com2l000Co0000ooD[0?oe:`3omB/01Ol00003ooHY0003o`000?of9P3omRH000?omRH01?l0
0004ooLU0003o`000?og8`3omb<000?omb<01?l00004ooLT0004o`000?og8P3omb80ooLR00Go0000
1?og90001?l0003omb@0ooLT0?og9004o`0000GomRL000?o0000ooHW0?l000000_l00002ooD/0003
o`000?oe;03omB`000?omB`00ol00005oo<b0003o`000?oc<`3o000000;o00000_ob>0000ol0003o
lCX0oo4j0003oo4j00;o00001_o_@`07o`00037ooooo0ol0000004kooooo00?o0000ooooooooool0
5?ooool3o`0000?olCX01Ol00003oo<c0003o`000?od;`3om2l000?om2l01?l00003ooD]0003o`00
0?of:@3omRT000?omRT000?o0000ooHV0?l000000_l00002ooHX0003o`000?og9@3ombD000CombD0
00?o0000ooLS0?l000000_l00002ooHV0003o`000?og903omb@000?omb@01?l00004ooLU0004o`00
0?og903omb@0ooLT00Go00001?of9`001?l0003omRL0ooHW0?of9`04o`0000GomB`000?o0000ooD/
0?l000000_l00003oo@a0004o`000?oc<P3olc80oo<b00?o00001_ob>0000ol0003olCX0o`000002
o`0000;okd4000?o0000onm30?o_@`000ol000001?oYF03o0000o`000?l0000`ooooo`Co00000ooo
ool004oooooo00?o0000ooooooooool05?ooool00ol0003ojEL0o`000002o`0000?olC/000?o0000
oo<c0?oc<`000ooc<`000ol0003om2l0o`000002o`0000;om30000?o0000ooD]0?oe;@000ooe;@00
1?l0003omRT0ooHY0?of:@04o`0000GomRP000Co0000ooLU0?og9@3ombD01?l00006ooHV0003o`00
0?og903o000000;o000000?omRL0o`000?og9@001Oog9@04o`0000;omRP000?o0000ooHW0?of9`00
1?of9`04o`0000ComB/000Co0000ooD/0?oe;03omB`00ol00006oo@a00Co00000oob=`001?l0003o
lSP0oo8h0?ob>004o`0000Gokd401ol0000`ooooo`?o00001oooool0053ooooo00?o0000oooooooo
ool05?ooool4o`0000ColC/000Co0000oo<c0?oc<`3olc<01?l00005oo@`0004o`000?oe;@3omBd0
ooD]00Go00001?oe:`001?l0003omRP0ooHX0?of:005o`0000ComRP000Co0000ooHV0?of9P3omRH0
1?l00005ooHW0003o`000?og9@3ombD000?o000000?omRT0o`000?of:0001?of:0000ol0003omRL0
ooHW0003o`0000;omB`000Co0000ooD[0?oe:`3omB/01_l00003oo@`0003o`000?od<@3om34000?o
000000?olSH0o`000?ob=`001?ob=`04o`0000Col3l000?o0000onm10?l000001Ol0000`ooooo`Co
00002_ooool0057ooooo0_l0000Fooooo`[o00001?ob=@001?l0003om300oo@`0?od<005o`0000Co
m2l000Co0000ooD[0?oe:`3omB/01Ol00004ooD[0004o`000?of:03omRP0ooHX00Go00001?of:@00
1?l0003omRL0ooHW0?of9`04o`0000GomRT000Co0000ooHX0?of:03omRP01?l00005ooD/00Co0000
1?od<0001?l0003om300oo@`0?od<004o`0000GolSH000?o0000oo8g0?l000000_l00003oo0n0004
o`000?o`?`3ol3l0oo0o00Ko0000;oooool4o`0000kooooo001Cooooo`03o`000?oooooooooo01Co
oooo0_l000000ooYF03o0000oo0m0003oo0m0004o`000?ob=@3olSD0oo8e00Go00001?oc<`001?l0
003om2l0oo@_0?od;`05o`0000?om2h000?o0000ooD[0?oe:`000ooe:`04o`0000ComB/000Co0000
ooHY0?of:@3omRT01Ol00004ooD[0004o`000?of:@3omRT0ooHY00Go00001?oe;0000ol0003omB`0
o`000002o`0000;om30000?o0000oo@`0?od<0000ood<004o`0000ColSH000Co0000oo8f0?ob=P3o
lSH01?l00005oo0n00Ko0000;oooool4o`0001;ooooo001Dooooo`03o`000?oooooooooo01Cooooo
1?l00002oo0m00Go00000oob=`000ol0003olc<0oo<c0003oo<c00Co00000ooc<@000ol0003om2h0
oo@^0003oo@^0003o`000?oe:`3o000000;o00000_od;P000ol0003omB/0ooD[0003ooD[00Co0000
0ood;@000ol0003omB/0ooD[0003ooD[00Co00001?od;P001?l0003omB`0ooD/0?oe;004o`0000Go
m30000?o0000oo@`0?l000000_l00002oo8e0003o`000?ob=P3olSH000?olSH01?l00004oo0m0003
o`000?o`?P3o000000Co0000;oooool4o`0001Kooooo001Eooooo`03o`000?oooooooooo01Cooooo
00?o0000onUJ0?oYFP000_l00004oo0o0003o`000?ob=`3olSL000;olSL000?o0000oo<c0?l00000
0_l00002oo8e0003o`000?oc<@3olc4000?olc4000Co0000oo@^0?od;P3om2h01?l00005oo@^0003
o`000?oe:`3o000000;o00000_od;`000ol0003om2d0oo@]0003oo@]0003o`000?oe:`3o000000;o
00000_od;`000ol0003om2h0oo@^0003oo@^00Co00001?oc<@001?l0003om300oo@`0?od<003o`00
00KolSD000?o0000oo8f0?l000000_l00002oo0m0004o`000?o`?@3ol3d0oo0m00Ko0000;oooool3
o`0001[ooooo001Fooooo`;o00005Oooool5o`0000Col3l000?o0000oo8g0?ob=`001?l00005oo8e
0004o`000?oc<@3olc40oo<a00Go00001?oc<@001?l0003om2h0oo@^0?od;P04o`0000Gom2l000Co
0000oo@]0?od;@3om2d01?l00005oo@_0003o`000?od;P3o000000;o00000_oc<P000ol0003olc40
oo<a0003oo<a00Co00000oob=P001?l0003olSD0oo8e0?ob=@04o`0000Gol3d01ol0000^ooooo`Co
00007Oooool005Sooooo00?o0000ooooooooool05?ooool00ol0003oj5`0o`000007o`0000ColCX0
00Co0000oo8e0?ob=@3olSD01Ol00004oo<e0004o`000?oc<@3olc40oo<a00Go00001?oc<P001?l0
003om2l0oo@_0?od;`05o`0000Colc4000Co0000oo@_0?od;`3om2l01?l00005oo<b0003o`000?oc
<@3o000000;o00000_ob=P001?l0003olSH0oo8f0?ob=P05o`0000Col3d000?o0000oo0m0?l00000
1Ol0000^ooooo`Co00008Oooool005Wooooo00?o0000ooooooooool05?ooool2o`000003onQL0?l0
003okd8000Cokd8000?o0000oo4j0?oa>P001Ol00004oo8i0004o`000?oc=@3olcD0oo<e00Go0000
1?ob=@001?l0003olc80oo<b0?oc<P05o`0000Colc<000Co0000oo<a0?oc<@3olc401Ol00004oo<d
0004o`000?oc<P3olc80oo<b00?o00001Oob=P04o`0000Col3d000Co0000oo0m0?o`?@3ol3d01_l0
000]ooooo`Co00009Oooool005[ooooo00?o0000ooooooooool05Oooool3o`0000?okd801?l00004
oo0m0004o`000?ob>@3olST0oo8i00Go00001?ob>0001?l0003olSD0oo8e0?ob=@05o`0000ColSH0
00Co0000oo<c0?oc<`3olc<01Ol00003oo8f0004o`000?oc=03olc@0oo<d00Ko00000oob=`000ol0
003olSH0o`000002o`0000?ol3h000Co0000oo0m0?o`?@3ol3d01ol0000]ooooo`Co0000:Oooool0
05_ooooo0_l0000Fooooo`Go00000oo^A@001?l0003ol3d0oo0m0?o`?@05o`0000?olC`000?o0000
oo8h0?ob>0000oob>004o`0000?olCT000?o0000oo8f0?ob=P000oob=P04o`0000?olSP000Co0000
oo8f0?ob=P3olSH01Ol00004oo4i0004o`000?ob=`3olSL0oo8g00Co00001Oo`?P06o`0002oooooo
0ol0000]ooooo`00GOooool00ol0003oooooooooo`0Dooooo`Co00000_o^A@05o`0000?okd4000?o
0000oo4l0?oa?0000ooa?0000ol0003olSP0o`000002o`0000;olC`000?o0000oo4i0?oa>@000ooa
>@000ol0003olSH0o`000002o`0000;olCX000?o0000oo8h0?ob>0000_ob>004o`0000ColC/000Co
0000oo4i0?oa>@3olCT01Ol00004oo0o0003o`000?o`?P3o000000Co0000;oooool4o`00033ooooo
001Nooooo`03o`000?oooooooooo01Cooooo00?o0000onMQ0?oWH@000_l00003oni80003o`000?o_
@@3okd4000?okd4000Co0000oo4l0?oa?03olC`01?l00005oo4l0004o`000?oa>@3olCT0oo4i00Co
00001Ooa>P001?l0003olSP0o`000?l00003oo0m0004o`000?oa>`3olC/0oo4k00Go00001?o`@000
1?l0003ol3l0oo0o0?o`?`05o`0002kooooo1?l0000dooooo`00Goooool00ol0003oooooooooo`0D
ooooo`Go00000oo^B0001?l0003okd40onm10?o_@@05o`0000Col40000Co0000oo4l0?oa?03olC`0
1Ol00004oo0m0004o`000?oa>P3olCX0oo4j00?o00001Oo`?@04o`0000Cokd8000Co0000oo100?o`
@03ol4001ol0000]ooooo`Co0000>?ooool0063ooooo0_l0000Fooooo`03o`000?oVI03o000000Oo
00001?o^A@001?l0003ol400oo100?o`@005o`0000Cokd4000Co0000oo0m0?o`?@3ol3d01Ol00003
oo100003o`000?o`?@3o000000;o00000oo_A0001?l0003okd80onm20?o_@P07o`0002oooooo0ol0
000looooo`00H_ooool00ol0003oooooooooo`0Dooooo`;o000000?oiV@0o`000?o]C0000oo]C000
1?l0003okTD0oni50?o^A@05o`0000CokTD000Co0000onm10?o_@@3okd401Ol00003onm30004o`00
0?o`@03ol400oo1000Co00001Oo_A007o`0002oooooo1?l0000oooooo`00Hoooool00ol0003ooooo
ooooo`0Eooooo`?o00000_o]C005o`0000CokDT000Co0000oni50?o^A@3okTD01Ol00003oni60004
o`000?o_@`3okd<0onm300Go00001?o^A`000ol0003okd@0o`000002o`000004onUI0?l0003o0000
o`0002kooooo1?l00013ooooo`00I?ooool00ol0003oooooooooo`0Eooooo`Co00001?o[D0001?l0
003okDT0one90?o]B@05o`0000CokDX000?o0000oni60?o^AP001Ol00004one:0004o`000?o^A`3o
kTL0oni700Oo0000;Oooool4o`0004Oooooo001Uooooo`03o`000?oooooooooo01Kooooo0_l00003
on]@00Go00001?o/CP001?l0003okDX0one:0?o]BP04o`0000Cok4d000Co0000one:0?o]BP3okDX0
1ol0000^ooooo`Co0000Boooool006Kooooo0_l0000Gooooo`Co00001?oZE@001?l0003ok4h0ona>
0?o/CP05o`0000?oje4000Co0000ona=0?o/C@3ok4d02?l0000_ooooo`?o0000Coooool006Sooooo
00?o0000ooooooooool05Oooool3o`0000?ojUD01Ol00003onYE0004o`000?o[D@3oje40on]A00So
0000<?ooool4o`0005;ooooo001Yooooo`03o`000?oooooooooo01Gooooo1Ol00004onQL0003o`00
0?oZE@3ojUD000So0000<Oooool4o`0005Kooooo001Zooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool03?l0000booooo`Co0000F_ooool006_ooooo0_l0000Dooooo`03o`000?oooooo
oooo00Cooooo1?l0000booooo`Co0000G_ooool006gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0gooooo`?o0000H_ooool006kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0cooooo`Co0000IOooool006oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0_ooooo`Co0000JOooool0073ooooo0_l0000>ooooo`03o`000?oooooooooo02cooooo1?l0
001]ooooo`00L_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0001a
ooooo`00Loooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0001doooo
o`00M?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0001hooooo`00
MOooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`0007cooooo001gooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool06Oooool4o`00083ooooo001hooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05_ooool3o`0008Cooooo001iooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04_ooool4o`0008Oooooo001jooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03_ooool4o`0008_ooooo001kooooo`;o00000oooool00ol0003ooooo
ooooo`0:ooooo`Co0000Soooool007gooooo00Co0000oooooooooooo00002?ooool4o`0009?ooooo
001nooooo`03o`000?oooooo000000Gooooo0ol0002Gooooo`00Ooooool2o`000003ooooool0003o
000000;o0000V_ooool0083ooooo0_l0002Nooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00dOooool3o`0004cooooo003Booooo`03o`000?oooooooooo04_ooooo001Pooooo`03
o`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`?o
00000oooool3o`0000Cooooo0ol00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000So
oooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000?ooooo0ol00002oooo
o`?o000000?oooooo`000?l000001?l00002ooooo`Go00000oooool2o`0000Cooooo00?o0000oooo
ooooool0B_ooool0063ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004oooo
o`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04o`000?ooooooooooo`0000Gooooo
00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0B_ooool0063ooooo00?o0000ooooool000000oooool3o`0000?ooooo00?o0000ooooool0
00000_ooool5o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001;ooooo`00Gooo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000Sooooo0ol00003ooooo`;o00000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0
003oooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000004_ooooo001Oooooo`05o`000?oooooo0000ooooool000000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000;ooooo1?l00002ooooo`Co00002_ooool01?l0003ooooo
ooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000?ooooo1?l000001?oooooo
0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o000004[ooooo001Oooooo`05
o`000?oooooo0000ooooool000006_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo057ooooo001Oooooo`Ko00006?ooool5o`0001Cooooo00?o0000ooooooooool02?ooool5o`00
00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
057ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0869132, 0.052163, \
0.00362198, 0.00362198}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.15804 .19483 -11.8743 -9 ]
[.15804 .19483 .12568 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.52352 .0511 -5.23624 -9 ]
[.52352 .0511 .76376 0 ]
[.77305 .1056 0 -6.15354 ]
[.77305 .1056 12 2.84646 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93042 .3466 0 -5.92583 ]
[.93042 .3466 6 3.07417 ]
[.02412 .26509 -6 -2.7423 ]
[.02412 .26509 0 6.2577 ]
[.01223 .33959 -12 -2.80533 ]
[.01223 .33959 0 6.19467 ]
[-0.00025 .41779 -12 -2.87182 ]
[-0.00025 .41779 0 6.12818 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.16722 .20421 m
.17181 .2089 L
s
[(-5)] .15804 .19483 .97905 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.53137 .06162 m
.53529 .06688 L
s
[(5)] .52352 .0511 .74541 1 Mshowa
.125 Mabswid
.20145 .19081 m
.20417 .19365 L
s
.23614 .17722 m
.23883 .1801 L
s
.2713 .16345 m
.27395 .16637 L
s
.30694 .1495 m
.30955 .15245 L
s
.37969 .12101 m
.38222 .12403 L
s
.41682 .10647 m
.41931 .10953 L
s
.45447 .09173 m
.45691 .09482 L
s
.49265 .07678 m
.49505 .0799 L
s
.13343 .21744 m
.13622 .22022 L
s
.10009 .2305 m
.10291 .23324 L
s
.06718 .24338 m
.07003 .2461 L
s
.57064 .04624 m
.57294 .04944 L
s
.61047 .03065 m
.61273 .03387 L
s
.65089 .01482 m
.65309 .01808 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.76073 .11012 m
.75457 .11239 L
s
[(-5)] .77305 .1056 -1 .36745 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.91791 .35056 m
.91166 .35254 L
s
[(5)] .93042 .3466 -1 .31685 Mshowa
.125 Mabswid
.77825 .13692 m
.77454 .13826 L
s
.79532 .16304 m
.79161 .16436 L
s
.81198 .18851 m
.80826 .18982 L
s
.82822 .21336 m
.8245 .21465 L
s
.85955 .26128 m
.85582 .26253 L
s
.87466 .28439 m
.87092 .28563 L
s
.88941 .30696 m
.88567 .30818 L
s
.90383 .32901 m
.90008 .33022 L
s
.74276 .08263 m
.73907 .08401 L
s
.72431 .05441 m
.72063 .05581 L
s
.70536 .02543 m
.70169 .02685 L
s
.93168 .37162 m
.92792 .3728 L
s
.94514 .39221 m
.94138 .39337 L
s
.95831 .41235 m
.95454 .41349 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26031 m
.04245 .25793 L
s
[(0)] .02412 .26509 1 -0.3906 Mshowa
.02451 .33496 m
.03065 .33265 L
s
[(10)] .01223 .33959 1 -0.37659 Mshowa
.01209 .41332 m
.01826 .41109 L
s
[(20)] -0.00025 .41779 1 -0.36182 Mshowa
.125 Mabswid
.03402 .27496 m
.03769 .27354 L
s
.03168 .28975 m
.03535 .28833 L
s
.02931 .30467 m
.03299 .30327 L
s
.02692 .31975 m
.0306 .31835 L
s
.02207 .35033 m
.02576 .34895 L
s
.01962 .36585 m
.02331 .36448 L
s
.01713 .38152 m
.02083 .38016 L
s
.01463 .39734 m
.01832 .39599 L
s
.00953 .42946 m
.01324 .42813 L
s
.00695 .44576 m
.01066 .44444 L
s
.00434 .46223 m
.00805 .46092 L
s
.00171 .47886 m
.00542 .47756 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.923 .31 0 r
.38807 .78396 .39888 .78231 .41595 .78803 .40533 .78675 Metetra
.952 .199 0 r
.40533 .78675 .41595 .78803 .43332 .79038 .42287 .78631 Metetra
.969 .131 0 r
.42287 .78631 .43332 .79038 .45094 .78989 .44062 .78319 Metetra
.976 .102 0 r
.44062 .78319 .45094 .78989 .46874 .78703 .45855 .77788 Metetra
.975 .106 0 r
.45855 .77788 .46874 .78703 .4867 .78229 .47662 .77087 Metetra
.968 .135 0 r
.47662 .77087 .4867 .78229 .50479 .77609 .49479 .76259 Metetra
.956 .181 0 r
.49479 .76259 .50479 .77609 .52299 .76883 .51305 .75346 Metetra
.942 .237 0 r
.51305 .75346 .52299 .76883 .54127 .76089 .53139 .74385 Metetra
.926 .297 0 r
.53139 .74385 .54127 .76089 .55965 .75259 .5498 .73407 Metetra
.91 .356 0 r
.5498 .73407 .55965 .75259 .57811 .74421 .56829 .72442 Metetra
.894 .41 0 r
.56829 .72442 .57811 .74421 .59666 .736 .58686 .71514 Metetra
.88 .457 0 r
.58686 .71514 .59666 .736 .61531 .72816 .60553 .70642 Metetra
.869 .495 0 r
.60553 .70642 .61531 .72816 .63408 .72085 .6243 .69843 Metetra
.86 .522 0 r
.6243 .69843 .63408 .72085 .65297 .71419 .6432 .6913 Metetra
.855 .538 0 r
.6432 .6913 .65297 .71419 .67201 .70828 .66225 .6851 Metetra
.853 .544 0 r
.66225 .6851 .67201 .70828 .69121 .70315 .68145 .67987 Metetra
.855 .538 0 r
.68145 .67987 .69121 .70315 .71058 .6988 .70085 .67564 Metetra
.86 .522 0 r
.70085 .67564 .71058 .6988 .73014 .69521 .72044 .67235 Metetra
.869 .495 0 r
.72044 .67235 .73014 .69521 .74989 .6923 .74024 .66994 Metetra
.88 .457 0 r
.74024 .66994 .74989 .6923 .76985 .68994 .76027 .66829 Metetra
.894 .41 0 r
.76027 .66829 .76985 .68994 .79002 .68798 .78053 .66725 Metetra
.91 .356 0 r
.78053 .66725 .79002 .68798 .81037 .68622 .80101 .66661 Metetra
.926 .297 0 r
.80101 .66661 .81037 .68622 .83091 .6844 .8217 .66614 Metetra
.942 .237 0 r
.8217 .66614 .83091 .6844 .85161 .68223 .84259 .66554 Metetra
.956 .181 0 r
.84259 .66554 .85161 .68223 .87242 .67937 .86365 .66446 Metetra
.968 .135 0 r
.86365 .66446 .87242 .67937 .8933 .67542 .88481 .66253 Metetra
.975 .106 0 r
.88481 .66253 .8933 .67542 .91418 .66997 .90604 .6593 Metetra
.976 .102 0 r
.90604 .6593 .91418 .66997 .93498 .66251 .92724 .65429 Metetra
.969 .131 0 r
.92724 .65429 .93498 .66251 .9556 .65255 .94833 .64697 Metetra
.952 .199 0 r
.94833 .64697 .9556 .65255 .97592 .63952 .96918 .63678 Metetra
.923 .31 0 r
.96918 .63678 .97592 .63952 .99581 .62286 .98967 .62312 Metetra
.951 .2 0 r
.37721 .78228 .38807 .78396 .40533 .78675 .39465 .78228 Metetra
.969 .128 0 r
.39465 .78228 .40533 .78675 .42287 .78631 .41234 .7792 Metetra
.976 .101 0 r
.41234 .7792 .42287 .78631 .44062 .78319 .43024 .77359 Metetra
.974 .112 0 r
.43024 .77359 .44062 .78319 .45855 .77788 .44829 .76596 Metetra
.964 .151 0 r
.44829 .76596 .45855 .77788 .47662 .77087 .46646 .75682 Metetra
.949 .211 0 r
.46646 .75682 .47662 .77087 .49479 .76259 .48472 .7466 Metetra
.93 .283 0 r
.48472 .7466 .49479 .76259 .51305 .75346 .50304 .73572 Metetra
.909 .359 0 r
.50304 .73572 .51305 .75346 .53139 .74385 .52143 .72454 Metetra
.887 .434 0 r
.52143 .72454 .53139 .74385 .5498 .73407 .53988 .71339 Metetra
.866 .503 0 r
.53988 .71339 .5498 .73407 .56829 .72442 .55839 .70256 Metetra
.846 .564 0 r
.55839 .70256 .56829 .72442 .58686 .71514 .57698 .69228 Metetra
.829 .615 0 r
.57698 .69228 .58686 .71514 .60553 .70642 .59565 .68274 Metetra
.815 .654 0 r
.59565 .68274 .60553 .70642 .6243 .69843 .61442 .67412 Metetra
.804 .683 0 r
.61442 .67412 .6243 .69843 .6432 .6913 .63332 .66653 Metetra
.798 .7 0 r
.63332 .66653 .6432 .6913 .66225 .6851 .65237 .66006 Metetra
.795 .705 0 r
.65237 .66006 .66225 .6851 .68145 .67987 .67158 .65474 Metetra
.798 .7 0 r
.67158 .65474 .68145 .67987 .70085 .67564 .69098 .65059 Metetra
.804 .683 0 r
.69098 .65059 .70085 .67564 .72044 .67235 .71059 .64757 Metetra
.815 .654 0 r
.71059 .64757 .72044 .67235 .74024 .66994 .73043 .64561 Metetra
.829 .615 0 r
.73043 .64561 .74024 .66994 .76027 .66829 .75051 .6446 Metetra
.846 .564 0 r
.75051 .6446 .76027 .66829 .78053 .66725 .77083 .64439 Metetra
.866 .503 0 r
.77083 .64439 .78053 .66725 .80101 .66661 .79141 .64478 Metetra
.887 .434 0 r
.79141 .64478 .80101 .66661 .8217 .66614 .81224 .64554 Metetra
.909 .359 0 r
.81224 .64554 .8217 .66614 .84259 .66554 .83329 .64637 Metetra
.93 .283 0 r
.83329 .64637 .84259 .66554 .86365 .66446 .85455 .64695 Metetra
.949 .211 0 r
.85455 .64695 .86365 .66446 .88481 .66253 .87597 .64688 Metetra
.964 .151 0 r
.87597 .64688 .88481 .66253 .90604 .6593 .89749 .64572 Metetra
.974 .112 0 r
.89749 .64572 .90604 .6593 .92724 .65429 .91905 .64299 Metetra
.976 .101 0 r
.91905 .64299 .92724 .65429 .94833 .64697 .94056 .63815 Metetra
.969 .128 0 r
.94056 .63815 .94833 .64697 .96918 .63678 .96189 .63064 Metetra
.951 .2 0 r
.96189 .63064 .96918 .63678 .98967 .62312 .98293 .61983 Metetra
.968 .133 0 r
.36629 .77776 .37721 .78228 .39465 .78228 .38391 .77512 Metetra
.976 .101 0 r
.38391 .77512 .39465 .78228 .41234 .7792 .40177 .76955 Metetra
.973 .114 0 r
.40177 .76955 .41234 .7792 .43024 .77359 .41981 .76161 Metetra
.962 .16 0 r
.41981 .76161 .43024 .77359 .44829 .76596 .43798 .75183 Metetra
.944 .231 0 r
.43798 .75183 .44829 .76596 .46646 .75682 .45624 .74069 Metetra
.921 .316 0 r
.45624 .74069 .46646 .75682 .48472 .7466 .47458 .72867 Metetra
.895 .406 0 r
.47458 .72867 .48472 .7466 .50304 .73572 .49297 .71616 Metetra
.868 .495 0 r
.49297 .71616 .50304 .73572 .52143 .72454 .51141 .70354 Metetra
.841 .579 0 r
.51141 .70354 .52143 .72454 .53988 .71339 .5299 .69112 Metetra
.815 .652 0 r
.5299 .69112 .53988 .71339 .55839 .70256 .54843 .67919 Metetra
.792 .714 0 r
.54843 .67919 .55839 .70256 .57698 .69228 .56703 .66798 Metetra
.771 .765 0 r
.56703 .66798 .57698 .69228 .59565 .68274 .58571 .6577 Metetra
.706 .755 0 r
.58571 .6577 .59565 .68274 .61442 .67412 .60448 .64849 Metetra
.655 .742 0 r
.60448 .64849 .61442 .67412 .63332 .66653 .62338 .64048 Metetra
.624 .735 0 r
.62338 .64048 .63332 .66653 .65237 .66006 .64241 .63374 Metetra
.614 .732 0 r
.64241 .63374 .65237 .66006 .67158 .65474 .66162 .62832 Metetra
.624 .735 0 r
.66162 .62832 .67158 .65474 .69098 .65059 .68102 .62423 Metetra
.655 .742 0 r
.68102 .62423 .69098 .65059 .71059 .64757 .70064 .62144 Metetra
.706 .755 0 r
.70064 .62144 .71059 .64757 .73043 .64561 .7205 .61988 Metetra
.771 .765 0 r
.7205 .61988 .73043 .64561 .75051 .6446 .74061 .61944 Metetra
.792 .714 0 r
.74061 .61944 .75051 .6446 .77083 .64439 .76099 .61998 Metetra
.815 .652 0 r
.76099 .61998 .77083 .64439 .79141 .64478 .78164 .62131 Metetra
.841 .579 0 r
.78164 .62131 .79141 .64478 .81224 .64554 .80257 .62318 Metetra
.868 .495 0 r
.80257 .62318 .81224 .64554 .83329 .64637 .82376 .62532 Metetra
.895 .406 0 r
.82376 .62532 .83329 .64637 .85455 .64695 .84519 .6274 Metetra
.921 .316 0 r
.84519 .6274 .85455 .64695 .87597 .64688 .86683 .62904 Metetra
.944 .231 0 r
.86683 .62904 .87597 .64688 .89749 .64572 .88861 .62979 Metetra
.962 .16 0 r
.88861 .62979 .89749 .64572 .91905 .64299 .91049 .62917 Metetra
.973 .114 0 r
.91049 .62917 .91905 .64299 .94056 .63815 .93237 .62664 Metetra
.976 .101 0 r
.93237 .62664 .94056 .63815 .96189 .63064 .95414 .62162 Metetra
.968 .133 0 r
.95414 .62162 .96189 .63064 .98293 .61983 .97568 .61348 Metetra
.976 .103 0 r
.35532 .77087 .36629 .77776 .38391 .77512 .37312 .76576 Metetra
.974 .111 0 r
.37312 .76576 .38391 .77512 .40177 .76955 .39114 .75787 Metetra
.962 .159 0 r
.39114 .75787 .40177 .76955 .41981 .76161 .40931 .74776 Metetra
.942 .237 0 r
.40931 .74776 .41981 .76161 .43798 .75183 .42761 .73597 Metetra
.916 .332 0 r
.42761 .73597 .43798 .75183 .45624 .74069 .44597 .72301 Metetra
.887 .435 0 r
.44597 .72301 .45624 .74069 .47458 .72867 .4644 .70931 Metetra
.855 .537 0 r
.4644 .70931 .47458 .72867 .49297 .71616 .48285 .69531 Metetra
.822 .633 0 r
.48285 .69531 .49297 .71616 .51141 .70354 .50134 .68136 Metetra
.79 .718 0 r
.50134 .68136 .51141 .70354 .5299 .69112 .51986 .66777 Metetra
.731 .76 0 r
.51986 .66777 .5299 .69112 .54843 .67919 .53842 .65484 Metetra
.618 .733 0 r
.53842 .65484 .54843 .67919 .56703 .66798 .55704 .64278 Metetra
.526 .709 0 r
.55704 .64278 .56703 .66798 .58571 .6577 .57572 .6318 Metetra
.455 .69 0 r
.57572 .6318 .58571 .6577 .60448 .64849 .59449 .62205 Metetra
.404 .676 0 r
.59449 .62205 .60448 .64849 .62338 .64048 .61338 .61364 Metetra
.375 .668 0 r
.61338 .61364 .62338 .64048 .64241 .63374 .63241 .60666 Metetra
.365 .665 0 r
.63241 .60666 .64241 .63374 .66162 .62832 .65161 .60114 Metetra
.375 .668 0 r
.65161 .60114 .66162 .62832 .68102 .62423 .671 .5971 Metetra
.404 .676 0 r
.671 .5971 .68102 .62423 .70064 .62144 .69062 .59451 Metetra
.455 .69 0 r
.69062 .59451 .70064 .62144 .7205 .61988 .71049 .5933 Metetra
.526 .709 0 r
.71049 .5933 .7205 .61988 .74061 .61944 .73062 .59336 Metetra
.618 .733 0 r
.73062 .59336 .74061 .61944 .76099 .61998 .75104 .59457 Metetra
.731 .76 0 r
.75104 .59457 .76099 .61998 .78164 .62131 .77175 .59672 Metetra
.79 .718 0 r
.77175 .59672 .78164 .62131 .80257 .62318 .79276 .5996 Metetra
.822 .633 0 r
.79276 .5996 .80257 .62318 .82376 .62532 .81406 .60292 Metetra
.855 .537 0 r
.81406 .60292 .82376 .62532 .84519 .6274 .83564 .60636 Metetra
.887 .435 0 r
.83564 .60636 .84519 .6274 .86683 .62904 .85746 .60955 Metetra
.916 .332 0 r
.85746 .60955 .86683 .62904 .88861 .62979 .87948 .61204 Metetra
.942 .237 0 r
.87948 .61204 .88861 .62979 .91049 .62917 .90163 .61335 Metetra
.962 .159 0 r
.90163 .61335 .91049 .62917 .93237 .62664 .92384 .61294 Metetra
.974 .111 0 r
.92384 .61294 .93237 .62664 .95414 .62162 .946 .61023 Metetra
.976 .103 0 r
.946 .61023 .95414 .62162 .97568 .61348 .96799 .60456 Metetra
.975 .105 0 r
.3443 .76204 .35532 .77087 .37312 .76576 .36228 .75464 Metetra
.964 .149 0 r
.36228 .75464 .37312 .76576 .39114 .75787 .38045 .74461 Metetra
.944 .228 0 r
.38045 .74461 .39114 .75787 .40931 .74776 .39877 .7325 Metetra
.917 .33 0 r
.39877 .7325 .40931 .74776 .42761 .73597 .41718 .71888 Metetra
.884 .444 0 r
.41718 .71888 .42761 .73597 .44597 .72301 .43565 .70423 Metetra
.848 .558 0 r
.43565 .70423 .44597 .72301 .4644 .70931 .45416 .68902 Metetra
.811 .665 0 r
.45416 .68902 .4644 .70931 .48285 .69531 .47268 .67364 Metetra
.773 .761 0 r
.47268 .67364 .48285 .69531 .50134 .68136 .49123 .65848 Metetra
.632 .736 0 r
.49123 .65848 .50134 .68136 .51986 .66777 .50979 .64383 Metetra
.499 .702 0 r
.50979 .64383 .51986 .66777 .53842 .65484 .52837 .62998 Metetra
.388 .672 0 r
.52837 .62998 .53842 .65484 .55704 .64278 .547 .61715 Metetra
.299 .645 0 r
.547 .61715 .55704 .64278 .57572 .6318 .56569 .60554 Metetra
.232 .624 0 r
.56569 .60554 .57572 .6318 .59449 .62205 .58446 .59529 Metetra
.186 .609 0 r
.58446 .59529 .59449 .62205 .61338 .61364 .60335 .58652 Metetra
.158 .599 0 r
.60335 .58652 .61338 .61364 .63241 .60666 .62237 .5793 Metetra
.149 .596 0 r
.62237 .5793 .63241 .60666 .65161 .60114 .64156 .57368 Metetra
.158 .599 0 r
.64156 .57368 .65161 .60114 .671 .5971 .66095 .56967 Metetra
.186 .609 0 r
.66095 .56967 .671 .5971 .69062 .59451 .68056 .56724 Metetra
.232 .624 0 r
.68056 .56724 .69062 .59451 .71049 .5933 .70043 .56633 Metetra
.299 .645 0 r
.70043 .56633 .71049 .5933 .73062 .59336 .72058 .56684 Metetra
.388 .672 0 r
.72058 .56684 .73062 .59336 .75104 .59457 .74102 .56863 Metetra
.499 .702 0 r
.74102 .56863 .75104 .59457 .77175 .59672 .76178 .57152 Metetra
.632 .736 0 r
.76178 .57152 .77175 .59672 .79276 .5996 .78285 .57529 Metetra
.773 .761 0 r
.78285 .57529 .79276 .5996 .81406 .60292 .80425 .57967 Metetra
.811 .665 0 r
.80425 .57967 .81406 .60292 .83564 .60636 .82594 .58433 Metetra
.848 .558 0 r
.82594 .58433 .83564 .60636 .85746 .60955 .84792 .5889 Metetra
.884 .444 0 r
.84792 .5889 .85746 .60955 .87948 .61204 .87014 .59297 Metetra
.917 .33 0 r
.87014 .59297 .87948 .61204 .90163 .61335 .89253 .59603 Metetra
.944 .228 0 r
.89253 .59603 .90163 .61335 .92384 .61294 .91503 .59756 Metetra
.964 .149 0 r
.91503 .59756 .92384 .61294 .946 .61023 .93754 .59695 Metetra
.975 .105 0 r
.93754 .59695 .946 .61023 .96799 .60456 .95994 .59356 Metetra
.969 .132 0 r
.33322 .75169 .3443 .76204 .36228 .75464 .35137 .7422 Metetra
.95 .207 0 r
.35137 .7422 .36228 .75464 .38045 .74461 .3697 .7302 Metetra
.922 .311 0 r
.3697 .7302 .38045 .74461 .39877 .7325 .38816 .71628 Metetra
.888 .431 0 r
.38816 .71628 .39877 .7325 .41718 .71888 .40669 .70098 Metetra
.849 .556 0 r
.40669 .70098 .41718 .71888 .43565 .70423 .42527 .6848 Metetra
.807 .675 0 r
.42527 .6848 .43565 .70423 .45416 .68902 .44386 .66821 Metetra
.748 .764 0 r
.44386 .66821 .45416 .68902 .47268 .67364 .46246 .6516 Metetra
.573 .722 0 r
.46246 .6516 .47268 .67364 .49123 .65848 .48106 .63533 Metetra
.421 .681 0 r
.48106 .63533 .49123 .65848 .50979 .64383 .49967 .61972 Metetra
.293 .643 0 r
.49967 .61972 .50979 .64383 .52837 .62998 .51829 .60504 Metetra
.189 .61 0 r
.51829 .60504 .52837 .62998 .547 .61715 .53694 .59152 Metetra
.107 .581 0 r
.53694 .59152 .547 .61715 .56569 .60554 .55564 .57932 Metetra
.047 .558 0 r
.55564 .57932 .56569 .60554 .58446 .59529 .57441 .56862 Metetra
.006 .541 0 r
.57441 .56862 .58446 .59529 .60335 .58652 .59329 .55951 Metetra
0 .531 .018 r
.59329 .55951 .60335 .58652 .62237 .5793 .61231 .55208 Metetra
0 .527 .025 r
.61231 .55208 .62237 .5793 .64156 .57368 .63149 .54636 Metetra
0 .531 .018 r
.63149 .54636 .64156 .57368 .66095 .56967 .65087 .54237 Metetra
.006 .541 0 r
.65087 .54237 .66095 .56967 .68056 .56724 .67048 .54007 Metetra
.047 .558 0 r
.67048 .54007 .68056 .56724 .70043 .56633 .69035 .53942 Metetra
.107 .581 0 r
.69035 .53942 .70043 .56633 .72058 .56684 .7105 .54031 Metetra
.189 .61 0 r
.7105 .54031 .72058 .56684 .74102 .56863 .73097 .54261 Metetra
.293 .643 0 r
.73097 .54261 .74102 .56863 .76178 .57152 .75176 .54614 Metetra
.421 .681 0 r
.75176 .54614 .76178 .57152 .78285 .57529 .77288 .5507 Metetra
.573 .722 0 r
.77288 .5507 .78285 .57529 .80425 .57967 .79435 .556 Metetra
.748 .764 0 r
.79435 .556 .80425 .57967 .82594 .58433 .81615 .56175 Metetra
.807 .675 0 r
.81615 .56175 .82594 .58433 .84792 .5889 .83826 .56757 Metetra
.849 .556 0 r
.83826 .56757 .84792 .5889 .87014 .59297 .86064 .57304 Metetra
.888 .431 0 r
.86064 .57304 .87014 .59297 .89253 .59603 .88325 .57767 Metetra
.922 .311 0 r
.88325 .57767 .89253 .59603 .91503 .59756 .90601 .58093 Metetra
.95 .207 0 r
.90601 .58093 .91503 .59756 .93754 .59695 .92883 .58223 Metetra
.969 .132 0 r
.92883 .58223 .93754 .59695 .95994 .59356 .95158 .5809 Metetra
.958 .175 0 r
.32206 .74021 .33322 .75169 .35137 .7422 .34038 .72882 Metetra
.932 .276 0 r
.34038 .72882 .35137 .7422 .3697 .7302 .35887 .71505 Metetra
.897 .399 0 r
.35887 .71505 .3697 .7302 .38816 .71628 .37747 .69948 Metetra
.857 .532 0 r
.37747 .69948 .38816 .71628 .40669 .70098 .39613 .68267 Metetra
.812 .662 0 r
.39613 .68267 .40669 .70098 .42527 .6848 .41482 .66512 Metetra
.751 .765 0 r
.41482 .66512 .42527 .6848 .44386 .66821 .4335 .64728 Metetra
.556 .717 0 r
.4335 .64728 .44386 .66821 .46246 .6516 .45218 .62955 Metetra
.384 .671 0 r
.45218 .62955 .46246 .6516 .48106 .63533 .47085 .6123 Metetra
.238 .626 0 r
.47085 .6123 .48106 .63533 .49967 .61972 .4895 .59583 Metetra
.119 .585 0 r
.4895 .59583 .49967 .61972 .51829 .60504 .50816 .58041 Metetra
.025 .549 0 r
.50816 .58041 .51829 .60504 .53694 .59152 .52683 .56625 Metetra
0 .518 .046 r
.52683 .56625 .53694 .59152 .55564 .57932 .54555 .55354 Metetra
0 .493 .097 r
.54555 .55354 .55564 .57932 .57441 .56862 .56434 .54242 Metetra
0 .475 .131 r
.56434 .54242 .57441 .56862 .59329 .55951 .58322 .53301 Metetra
0 .464 .15 r
.58322 .53301 .59329 .55951 .61231 .55208 .60223 .52537 Metetra
0 .46 .156 r
.60223 .52537 .61231 .55208 .63149 .54636 .62141 .51955 Metetra
0 .464 .15 r
.62141 .51955 .63149 .54636 .65087 .54237 .64078 .51556 Metetra
0 .475 .131 r
.64078 .51556 .65087 .54237 .67048 .54007 .66039 .51337 Metetra
0 .493 .097 r
.66039 .51337 .67048 .54007 .69035 .53942 .68026 .51293 Metetra
0 .518 .046 r
.68026 .51293 .69035 .53942 .7105 .54031 .70041 .51415 Metetra
.025 .549 0 r
.70041 .51415 .7105 .54031 .73097 .54261 .72089 .51688 Metetra
.119 .585 0 r
.72089 .51688 .73097 .54261 .75176 .54614 .74171 .52098 Metetra
.238 .626 0 r
.74171 .52098 .75176 .54614 .77288 .5507 .76288 .52621 Metetra
.384 .671 0 r
.76288 .52621 .77288 .5507 .79435 .556 .78441 .53233 Metetra
.556 .717 0 r
.78441 .53233 .79435 .556 .81615 .56175 .80629 .53903 Metetra
.751 .765 0 r
.80629 .53903 .81615 .56175 .83826 .56757 .82852 .54594 Metetra
.812 .662 0 r
.82852 .54594 .83826 .56757 .86064 .57304 .85105 .55265 Metetra
.857 .532 0 r
.85105 .55265 .86064 .57304 .88325 .57767 .87384 .55868 Metetra
.897 .399 0 r
.87384 .55868 .88325 .57767 .90601 .58093 .89682 .56349 Metetra
.932 .276 0 r
.89682 .56349 .90601 .58093 .92883 .58223 .91991 .56649 Metetra
.958 .175 0 r
.91991 .56649 .92883 .58223 .95158 .5809 .94299 .56701 Metetra
.944 .229 0 r
.31082 .72795 .32206 .74021 .34038 .72882 .32931 .71486 Metetra
.911 .35 0 r
.32931 .71486 .34038 .72882 .35887 .71505 .34796 .6995 Metetra
.871 .487 0 r
.34796 .6995 .35887 .71505 .37747 .69948 .3667 .68246 Metetra
.825 .626 0 r
.3667 .68246 .37747 .69948 .39613 .68267 .38549 .6643 Metetra
.775 .756 0 r
.38549 .6643 .39613 .68267 .41482 .66512 .40429 .64552 Metetra
.579 .723 0 r
.40429 .64552 .41482 .66512 .4335 .64728 .42307 .62658 Metetra
.387 .671 0 r
.42307 .62658 .4335 .64728 .45218 .62955 .44183 .60787 Metetra
.222 .621 0 r
.44183 .60787 .45218 .62955 .47085 .6123 .46057 .58974 Metetra
.086 .573 0 r
.46057 .58974 .47085 .6123 .4895 .59583 .47928 .5725 Metetra
0 .529 .021 r
.47928 .5725 .4895 .59583 .50816 .58041 .49798 .55641 Metetra
0 .49 .102 r
.49798 .55641 .50816 .58041 .52683 .56625 .51669 .54169 Metetra
0 .457 .161 r
.51669 .54169 .52683 .56625 .54555 .55354 .53543 .52851 Metetra
0 .431 .201 r
.53543 .52851 .54555 .55354 .56434 .54242 .55424 .51702 Metetra
0 .412 .226 r
.55424 .51702 .56434 .54242 .58322 .53301 .57313 .50733 Metetra
0 .4 .24 r
.57313 .50733 .58322 .53301 .60223 .52537 .59215 .4995 Metetra
0 .396 .244 r
.59215 .4995 .60223 .52537 .62141 .51955 .61132 .49358 Metetra
0 .4 .24 r
.61132 .49358 .62141 .51955 .64078 .51556 .6307 .48958 Metetra
0 .412 .226 r
.6307 .48958 .64078 .51556 .66039 .51337 .6503 .48748 Metetra
0 .431 .201 r
.6503 .48748 .66039 .51337 .68026 .51293 .67017 .48721 Metetra
0 .457 .161 r
.67017 .48721 .68026 .51293 .70041 .51415 .69033 .4887 Metetra
0 .49 .102 r
.69033 .4887 .70041 .51415 .72089 .51688 .71082 .4918 Metetra
0 .529 .021 r
.71082 .4918 .72089 .51688 .74171 .52098 .73166 .49637 Metetra
.086 .573 0 r
.73166 .49637 .74171 .52098 .76288 .52621 .75286 .50219 Metetra
.222 .621 0 r
.75286 .50219 .76288 .52621 .78441 .53233 .77444 .50902 Metetra
.387 .671 0 r
.77444 .50902 .78441 .53233 .80629 .53903 .7964 .51653 Metetra
.579 .723 0 r
.7964 .51653 .80629 .53903 .82852 .54594 .81872 .5244 Metetra
.775 .756 0 r
.81872 .5244 .82852 .54594 .85105 .55265 .84138 .53219 Metetra
.825 .626 0 r
.84138 .53219 .85105 .55265 .87384 .55868 .86433 .53943 Metetra
.871 .487 0 r
.86433 .53943 .87384 .55868 .89682 .56349 .88751 .5456 Metetra
.911 .35 0 r
.88751 .5456 .89682 .56349 .91991 .56649 .91084 .55009 Metetra
.944 .229 0 r
.91084 .55009 .91991 .56649 .94299 .56701 .9342 .55225 Metetra
.929 .286 0 r
.29948 .71523 .31082 .72795 .32931 .71486 .31814 .70063 Metetra
.891 .422 0 r
.31814 .70063 .32931 .71486 .34796 .6995 .33694 .68387 Metetra
.845 .568 0 r
.33694 .68387 .34796 .6995 .3667 .68246 .35583 .66554 Metetra
.794 .71 0 r
.35583 .66554 .3667 .68246 .38549 .6643 .37475 .64619 Metetra
.643 .739 0 r
.37475 .64619 .38549 .6643 .40429 .64552 .39366 .62633 Metetra
.429 .683 0 r
.39366 .62633 .40429 .64552 .42307 .62658 .41255 .60642 Metetra
.243 .628 0 r
.41255 .60642 .42307 .62658 .44183 .60787 .43141 .58683 Metetra
.088 .574 0 r
.43141 .58683 .44183 .60787 .46057 .58974 .45022 .56793 Metetra
0 .523 .035 r
.45022 .56793 .46057 .58974 .47928 .5725 .46899 .55002 Metetra
0 .477 .128 r
.46899 .55002 .47928 .5725 .49798 .55641 .48775 .53334 Metetra
0 .436 .194 r
.48775 .53334 .49798 .55641 .51669 .54169 .5065 .51812 Metetra
0 .401 .239 r
.5065 .51812 .51669 .54169 .53543 .52851 .52528 .50453 Metetra
0 .373 .267 r
.52528 .50453 .53543 .52851 .55424 .51702 .54411 .49271 Metetra
0 .353 .284 r
.54411 .49271 .55424 .51702 .57313 .50733 .56302 .48276 Metetra
0 .341 .292 r
.56302 .48276 .57313 .50733 .59215 .4995 .58204 .47475 Metetra
0 .336 .295 r
.58204 .47475 .59215 .4995 .61132 .49358 .60123 .46874 Metetra
0 .341 .292 r
.60123 .46874 .61132 .49358 .6307 .48958 .62061 .46472 Metetra
0 .353 .284 r
.62061 .46472 .6307 .48958 .6503 .48748 .64021 .46267 Metetra
0 .373 .267 r
.64021 .46267 .6503 .48748 .67017 .48721 .66008 .46254 Metetra
0 .401 .239 r
.66008 .46254 .67017 .48721 .69033 .4887 .68025 .46424 Metetra
0 .436 .194 r
.68025 .46424 .69033 .4887 .71082 .4918 .70075 .46766 Metetra
0 .477 .128 r
.70075 .46766 .71082 .4918 .73166 .49637 .72161 .47263 Metetra
0 .523 .035 r
.72161 .47263 .73166 .49637 .75286 .50219 .74285 .47894 Metetra
.088 .574 0 r
.74285 .47894 .75286 .50219 .77444 .50902 .76448 .48636 Metetra
.243 .628 0 r
.76448 .48636 .77444 .50902 .7964 .51653 .7865 .49458 Metetra
.429 .683 0 r
.7865 .49458 .7964 .51653 .81872 .5244 .8089 .50325 Metetra
.643 .739 0 r
.8089 .50325 .81872 .5244 .84138 .53219 .83167 .51197 Metetra
.794 .71 0 r
.83167 .51197 .84138 .53219 .86433 .53943 .85476 .52026 Metetra
.845 .568 0 r
.85476 .52026 .86433 .53943 .88751 .5456 .87811 .5276 Metetra
.891 .422 0 r
.87811 .5276 .88751 .5456 .91084 .55009 .90165 .53339 Metetra
.929 .286 0 r
.90165 .53339 .91084 .55009 .9342 .55225 .92526 .53696 Metetra
.913 .343 0 r
.28801 .70232 .29948 .71523 .31814 .70063 .30684 .68641 Metetra
.87 .49 0 r
.30684 .68641 .31814 .70063 .33694 .68387 .3258 .66844 Metetra
.82 .641 0 r
.3258 .66844 .33694 .68387 .35583 .66554 .34484 .64898 Metetra
.747 .764 0 r
.34484 .64898 .35583 .66554 .37475 .64619 .36389 .62861 Metetra
.512 .706 0 r
.36389 .62861 .37475 .64619 .39366 .62633 .38293 .60781 Metetra
.302 .646 0 r
.38293 .60781 .39366 .62633 .41255 .60642 .40193 .58705 Metetra
.125 .587 0 r
.40193 .58705 .41255 .60642 .43141 .58683 .42088 .56671 Metetra
0 .531 .018 r
.42088 .56671 .43141 .58683 .45022 .56793 .43978 .54714 Metetra
0 .477 .126 r
.43978 .54714 .45022 .56793 .46899 .55002 .45863 .52863 Metetra
0 .429 .204 r
.45863 .52863 .46899 .55002 .48775 .53334 .47745 .51144 Metetra
0 .386 .255 r
.47745 .51144 .48775 .53334 .5065 .51812 .49625 .49579 Metetra
0 .35 .286 r
.49625 .49579 .5065 .51812 .52528 .50453 .51507 .48183 Metetra
0 .321 .303 r
.51507 .48183 .52528 .50453 .54411 .49271 .53393 .46971 Metetra
0 .289 .3 r
.53393 .46971 .54411 .49271 .56302 .48276 .55287 .45953 Metetra
0 .261 .287 r
.55287 .45953 .56302 .48276 .58204 .47475 .57192 .45137 Metetra
0 .252 .282 r
.57192 .45137 .58204 .47475 .60123 .46874 .59112 .44526 Metetra
0 .261 .287 r
.59112 .44526 .60123 .46874 .62061 .46472 .61051 .4412 Metetra
0 .289 .3 r
.61051 .4412 .62061 .46472 .64021 .46267 .63012 .43919 Metetra
0 .321 .303 r
.63012 .43919 .64021 .46267 .66008 .46254 .65 .43916 Metetra
0 .35 .286 r
.65 .43916 .66008 .46254 .68025 .46424 .67019 .44104 Metetra
0 .386 .255 r
.67019 .44104 .68025 .46424 .70075 .46766 .6907 .44471 Metetra
0 .429 .204 r
.6907 .44471 .70075 .46766 .72161 .47263 .71158 .45 Metetra
0 .477 .126 r
.71158 .45 .72161 .47263 .74285 .47894 .73285 .45672 Metetra
0 .531 .018 r
.73285 .45672 .74285 .47894 .76448 .48636 .75452 .46462 Metetra
.125 .587 0 r
.75452 .46462 .76448 .48636 .7865 .49458 .77659 .47342 Metetra
.302 .646 0 r
.77659 .47342 .7865 .49458 .8089 .50325 .79907 .48277 Metetra
.512 .706 0 r
.79907 .48277 .8089 .50325 .83167 .51197 .82194 .49227 Metetra
.747 .764 0 r
.82194 .49227 .83167 .51197 .85476 .52026 .84515 .50145 Metetra
.82 .641 0 r
.84515 .50145 .85476 .52026 .87811 .5276 .86865 .50977 Metetra
.87 .49 0 r
.86865 .50977 .87811 .5276 .90165 .53339 .89237 .51666 Metetra
.913 .343 0 r
.89237 .51666 .90165 .53339 .92526 .53696 .91621 .52143 Metetra
.898 .395 0 r
.27641 .68946 .28801 .70232 .30684 .68641 .2954 .67245 Metetra
.851 .55 0 r
.2954 .67245 .30684 .68641 .3258 .66844 .31452 .65344 Metetra
.797 .702 0 r
.31452 .65344 .3258 .66844 .34484 .64898 .3337 .63303 Metetra
.636 .738 0 r
.3337 .63303 .34484 .64898 .36389 .62861 .3529 .61178 Metetra
.402 .676 0 r
.3529 .61178 .36389 .62861 .38293 .60781 .37206 .59019 Metetra
.199 .613 0 r
.37206 .59019 .38293 .60781 .40193 .58705 .39118 .56871 Metetra
.032 .552 0 r
.39118 .56871 .40193 .58705 .42088 .56671 .41024 .54772 Metetra
0 .492 .098 r
.41024 .54772 .42088 .56671 .43978 .54714 .42923 .52757 Metetra
0 .437 .192 r
.42923 .52757 .43978 .54714 .45863 .52863 .44816 .50856 Metetra
0 .387 .254 r
.44816 .50856 .45863 .52863 .47745 .51144 .46705 .49093 Metetra
0 .342 .291 r
.46705 .49093 .47745 .51144 .49625 .49579 .48592 .4749 Metetra
0 .3 .304 r
.48592 .4749 .49625 .49579 .51507 .48183 .5048 .46062 Metetra
0 .235 .275 r
.5048 .46062 .51507 .48183 .53393 .46971 .5237 .44824 Metetra
0 .192 .253 r
.5237 .44824 .53393 .46971 .55287 .45953 .54268 .43786 Metetra
0 .169 .239 r
.54268 .43786 .55287 .45953 .57192 .45137 .56176 .42955 Metetra
0 .161 .235 r
.56176 .42955 .57192 .45137 .59112 .44526 .58099 .42334 Metetra
0 .169 .239 r
.58099 .42334 .59112 .44526 .61051 .4412 .6004 .41924 Metetra
0 .192 .253 r
.6004 .41924 .61051 .4412 .63012 .43919 .62003 .41725 Metetra
0 .235 .275 r
.62003 .41725 .63012 .43919 .65 .43916 .63993 .41729 Metetra
0 .3 .304 r
.63993 .41729 .65 .43916 .67019 .44104 .66013 .4193 Metetra
0 .342 .291 r
.66013 .4193 .67019 .44104 .6907 .44471 .68066 .42315 Metetra
0 .387 .254 r
.68066 .42315 .6907 .44471 .71158 .45 .70157 .4287 Metetra
0 .437 .192 r
.70157 .4287 .71158 .45 .73285 .45672 .72287 .43574 Metetra
0 .492 .098 r
.72287 .43574 .73285 .45672 .75452 .46462 .74457 .44404 Metetra
.032 .552 0 r
.74457 .44404 .75452 .46462 .77659 .47342 .7667 .45331 Metetra
.199 .613 0 r
.7667 .45331 .77659 .47342 .79907 .48277 .78925 .46321 Metetra
.402 .676 0 r
.78925 .46321 .79907 .48277 .82194 .49227 .8122 .47334 Metetra
.636 .738 0 r
.8122 .47334 .82194 .49227 .84515 .50145 .83552 .48323 Metetra
.797 .702 0 r
.83552 .48323 .84515 .50145 .86865 .50977 .85916 .49237 Metetra
.851 .55 0 r
.85916 .49237 .86865 .50977 .89237 .51666 .88304 .50015 Metetra
.898 .395 0 r
.88304 .50015 .89237 .51666 .91621 .52143 .90707 .50592 Metetra
.885 .441 0 r
.26465 .67685 .27641 .68946 .2954 .67245 .28381 .65893 Metetra
.834 .599 0 r
.28381 .65893 .2954 .67245 .31452 .65344 .30308 .63907 Metetra
.777 .752 0 r
.30308 .63907 .31452 .65344 .3337 .63303 .32241 .61788 Metetra
.545 .715 0 r
.32241 .61788 .3337 .63303 .3529 .61178 .34175 .5959 Metetra
.315 .65 0 r
.34175 .5959 .3529 .61178 .37206 .59019 .36105 .57366 Metetra
.118 .585 0 r
.36105 .57366 .37206 .59019 .39118 .56871 .38029 .55157 Metetra
0 .521 .039 r
.38029 .55157 .39118 .56871 .41024 .54772 .39946 .53005 Metetra
0 .46 .156 r
.39946 .53005 .41024 .54772 .42923 .52757 .41855 .50942 Metetra
0 .403 .237 r
.41855 .50942 .42923 .52757 .44816 .50856 .43758 .48998 Metetra
0 .351 .285 r
.43758 .48998 .44816 .50856 .46705 .49093 .45656 .47198 Metetra
0 .302 .305 r
.45656 .47198 .46705 .49093 .48592 .4749 .4755 .45562 Metetra
0 .219 .266 r
.4755 .45562 .48592 .4749 .5048 .46062 .49444 .44107 Metetra
0 .162 .236 r
.49444 .44107 .5048 .46062 .5237 .44824 .5134 .42847 Metetra
0 .126 .213 r
.5134 .42847 .5237 .44824 .54268 .43786 .53243 .4179 Metetra
0 .106 .2 r
.53243 .4179 .54268 .43786 .56176 .42955 .55155 .40945 Metetra
0 .1 .195 r
.55155 .40945 .56176 .42955 .58099 .42334 .57081 .40315 Metetra
0 .106 .2 r
.57081 .40315 .58099 .42334 .6004 .41924 .59026 .39901 Metetra
0 .126 .213 r
.59026 .39901 .6004 .41924 .62003 .41725 .60992 .397 Metetra
0 .162 .236 r
.60992 .397 .62003 .41725 .63993 .41729 .62984 .39709 Metetra
0 .219 .266 r
.62984 .39709 .63993 .41729 .66013 .4193 .65007 .39918 Metetra
0 .302 .305 r
.65007 .39918 .66013 .4193 .68066 .42315 .67063 .40317 Metetra
0 .351 .285 r
.67063 .40317 .68066 .42315 .70157 .4287 .69157 .40891 Metetra
0 .403 .237 r
.69157 .40891 .70157 .4287 .72287 .43574 .7129 .41619 Metetra
0 .46 .156 r
.7129 .41619 .72287 .43574 .74457 .44404 .73465 .42479 Metetra
0 .521 .039 r
.73465 .42479 .74457 .44404 .7667 .45331 .75683 .43442 Metetra
.118 .585 0 r
.75683 .43442 .7667 .45331 .78925 .46321 .77944 .44474 Metetra
.315 .65 0 r
.77944 .44474 .78925 .46321 .8122 .47334 .80247 .45537 Metetra
.545 .715 0 r
.80247 .45537 .8122 .47334 .83552 .48323 .82588 .46583 Metetra
.777 .752 0 r
.82588 .46583 .83552 .48323 .85916 .49237 .84964 .4756 Metetra
.834 .599 0 r
.84964 .4756 .85916 .49237 .88304 .50015 .87367 .48409 Metetra
.885 .441 0 r
.87367 .48409 .88304 .50015 .90707 .50592 .89787 .49063 Metetra
.874 .477 0 r
.25271 .66466 .26465 .67685 .28381 .65893 .27203 .64602 Metetra
.82 .638 0 r
.27203 .64602 .28381 .65893 .30308 .63907 .29146 .6255 Metetra
.731 .76 0 r
.29146 .6255 .30308 .63907 .32241 .61788 .31094 .60368 Metetra
.475 .696 0 r
.31094 .60368 .32241 .61788 .34175 .5959 .33042 .58113 Metetra
.248 .629 0 r
.33042 .58113 .34175 .5959 .36105 .57366 .34986 .55836 Metetra
.059 .563 0 r
.34986 .55836 .36105 .57366 .38029 .55157 .36923 .53579 Metetra
0 .497 .089 r
.36923 .53579 .38029 .55157 .39946 .53005 .38852 .51383 Metetra
0 .434 .196 r
.38852 .51383 .39946 .53005 .41855 .50942 .40773 .49282 Metetra
0 .376 .265 r
.40773 .49282 .41855 .50942 .43758 .48998 .42686 .47303 Metetra
0 .322 .302 r
.42686 .47303 .43758 .48998 .45656 .47198 .44593 .45472 Metetra
0 .237 .276 r
.44593 .45472 .45656 .47198 .4755 .45562 .46496 .4381 Metetra
0 .163 .236 r
.46496 .4381 .4755 .45562 .49444 .44107 .48397 .42332 Metetra
0 .113 .205 r
.48397 .42332 .49444 .44107 .5134 .42847 .50301 .41052 Metetra
0 .083 .182 r
.50301 .41052 .5134 .42847 .53243 .4179 .5221 .39979 Metetra
0 .066 .168 r
.5221 .39979 .53243 .4179 .55155 .40945 .54128 .39122 Metetra
0 .061 .163 r
.54128 .39122 .55155 .40945 .57081 .40315 .56059 .38482 Metetra
0 .066 .168 r
.56059 .38482 .57081 .40315 .59026 .39901 .58007 .38062 Metetra
0 .083 .182 r
.58007 .38062 .59026 .39901 .60992 .397 .59978 .37859 Metetra
0 .113 .205 r
.59978 .37859 .60992 .397 .62984 .39709 .61974 .37869 Metetra
0 .163 .236 r
.61974 .37869 .62984 .39709 .65007 .39918 .64 .38083 Metetra
0 .237 .276 r
.64 .38083 .65007 .39918 .67063 .40317 .6606 .38491 Metetra
0 .322 .302 r
.6606 .38491 .67063 .40317 .69157 .40891 .68156 .39076 Metetra
0 .376 .265 r
.68156 .39076 .69157 .40891 .7129 .41619 .70294 .39821 Metetra
0 .434 .196 r
.70294 .39821 .7129 .41619 .73465 .42479 .72473 .40702 Metetra
0 .497 .089 r
.72473 .40702 .73465 .42479 .75683 .43442 .74696 .41691 Metetra
.059 .563 0 r
.74696 .41691 .75683 .43442 .77944 .44474 .76963 .42754 Metetra
.248 .629 0 r
.76963 .42754 .77944 .44474 .80247 .45537 .79274 .43852 Metetra
.475 .696 0 r
.79274 .43852 .80247 .45537 .82588 .46583 .81624 .44939 Metetra
.731 .76 0 r
.81624 .44939 .82588 .46583 .84964 .4756 .84011 .45962 Metetra
.82 .638 0 r
.84011 .45962 .84964 .4756 .87367 .48409 .86426 .46862 Metetra
.874 .477 0 r
.86426 .46862 .87367 .48409 .89787 .49063 .88862 .47574 Metetra
.866 .504 0 r
.24058 .653 .25271 .66466 .27203 .64602 .26005 .63385 Metetra
.81 .666 0 r
.26005 .63385 .27203 .64602 .29146 .6255 .27963 .61283 Metetra
.681 .748 0 r
.27963 .61283 .29146 .6255 .31094 .60368 .29926 .59056 Metetra
.426 .682 0 r
.29926 .59056 .31094 .60368 .33042 .58113 .31889 .56758 Metetra
.202 .614 0 r
.31889 .56758 .33042 .58113 .34986 .55836 .33847 .54441 Metetra
.018 .546 0 r
.33847 .54441 .34986 .55836 .36923 .53579 .35798 .52148 Metetra
0 .479 .123 r
.35798 .52148 .36923 .53579 .38852 .51383 .3774 .49919 Metetra
0 .415 .222 r
.3774 .49919 .38852 .51383 .40773 .49282 .39673 .47788 Metetra
0 .356 .282 r
.39673 .47788 .40773 .49282 .42686 .47303 .41597 .45782 Metetra
0 .294 .302 r
.41597 .45782 .42686 .47303 .44593 .45472 .43515 .43927 Metetra
0 .195 .254 r
.43515 .43927 .44593 .45472 .46496 .4381 .45428 .42243 Metetra
0 .127 .214 r
.45428 .42243 .46496 .4381 .48397 .42332 .47339 .40746 Metetra
0 .083 .182 r
.47339 .40746 .48397 .42332 .50301 .41052 .4925 .39449 Metetra
0 .056 .159 r
.4925 .39449 .50301 .41052 .5221 .39979 .51167 .38363 Metetra
0 .043 .145 r
.51167 .38363 .5221 .39979 .54128 .39122 .53091 .37494 Metetra
0 .038 .14 r
.53091 .37494 .54128 .39122 .56059 .38482 .55029 .36846 Metetra
0 .043 .145 r
.55029 .36846 .56059 .38482 .58007 .38062 .56983 .36419 Metetra
0 .056 .159 r
.56983 .36419 .58007 .38062 .59978 .37859 .58958 .36212 Metetra
0 .083 .182 r
.58958 .36212 .59978 .37859 .61974 .37869 .60959 .3622 Metetra
0 .127 .214 r
.60959 .3622 .61974 .37869 .64 .38083 .6299 .36435 Metetra
0 .195 .254 r
.6299 .36435 .64 .38083 .6606 .38491 .65054 .36846 Metetra
0 .294 .302 r
.65054 .36846 .6606 .38491 .68156 .39076 .67156 .37438 Metetra
0 .356 .282 r
.67156 .37438 .68156 .39076 .70294 .39821 .69297 .38192 Metetra
0 .415 .222 r
.69297 .38192 .70294 .39821 .72473 .40702 .71482 .39085 Metetra
0 .479 .123 r
.71482 .39085 .72473 .40702 .74696 .41691 .7371 .4009 Metetra
.018 .546 0 r
.7371 .4009 .74696 .41691 .76963 .42754 .75984 .41171 Metetra
.202 .614 0 r
.75984 .41171 .76963 .42754 .79274 .43852 .78301 .42291 Metetra
.426 .682 0 r
.78301 .42291 .79274 .43852 .81624 .44939 .8066 .43404 Metetra
.681 .748 0 r
.8066 .43404 .81624 .44939 .84011 .45962 .83056 .44456 Metetra
.81 .666 0 r
.83056 .44456 .84011 .45962 .86426 .46862 .85483 .4539 Metetra
.866 .504 0 r
.85483 .4539 .86426 .46862 .88862 .47574 .87932 .46137 Metetra
.861 .52 0 r
.22824 .64196 .24058 .653 .26005 .63385 .24785 .62249 Metetra
.804 .683 0 r
.24785 .62249 .26005 .63385 .27963 .61283 .26758 .60116 Metetra
.65 .741 0 r
.26758 .60116 .27963 .61283 .29926 .59056 .28736 .57859 Metetra
.396 .674 0 r
.28736 .57859 .29926 .59056 .31889 .56758 .30714 .55534 Metetra
.175 .605 0 r
.30714 .55534 .31889 .56758 .33847 .54441 .32686 .5319 Metetra
0 .536 .006 r
.32686 .5319 .33847 .54441 .35798 .52148 .34651 .50873 Metetra
0 .468 .142 r
.34651 .50873 .35798 .52148 .3774 .49919 .36607 .48621 Metetra
0 .404 .236 r
.36607 .48621 .3774 .49919 .39673 .47788 .38553 .46467 Metetra
0 .344 .29 r
.38553 .46467 .39673 .47788 .41597 .45782 .4049 .44442 Metetra
0 .266 .289 r
.4049 .44442 .41597 .45782 .43515 .43927 .4242 .42569 Metetra
0 .171 .241 r
.4242 .42569 .43515 .43927 .45428 .42243 .44344 .40868 Metetra
0 .108 .201 r
.44344 .40868 .45428 .42243 .47339 .40746 .46265 .39357 Metetra
0 .067 .168 r
.46265 .39357 .47339 .40746 .4925 .39449 .48186 .38047 Metetra
0 .043 .145 r
.48186 .38047 .4925 .39449 .51167 .38363 .50111 .36949 Metetra
0 .031 .131 r
.50111 .36949 .51167 .38363 .53091 .37494 .52044 .3607 Metetra
0 .027 .126 r
.52044 .3607 .53091 .37494 .55029 .36846 .53989 .35412 Metetra
0 .031 .131 r
.53989 .35412 .55029 .36846 .56983 .36419 .5595 .34978 Metetra
0 .043 .145 r
.5595 .34978 .56983 .36419 .58958 .36212 .57932 .34766 Metetra
0 .067 .168 r
.57932 .34766 .58958 .36212 .60959 .3622 .59939 .34769 Metetra
0 .108 .201 r
.59939 .34769 .60959 .3622 .6299 .36435 .61976 .34981 Metetra
0 .171 .241 r
.61976 .34981 .6299 .36435 .65054 .36846 .64046 .35391 Metetra
0 .266 .289 r
.64046 .35391 .65054 .36846 .67156 .37438 .66152 .35983 Metetra
0 .344 .29 r
.66152 .35983 .67156 .37438 .69297 .38192 .683 .36739 Metetra
0 .404 .236 r
.683 .36739 .69297 .38192 .71482 .39085 .7049 .37636 Metetra
0 .468 .142 r
.7049 .37636 .71482 .39085 .7371 .4009 .72724 .38646 Metetra
0 .536 .006 r
.72724 .38646 .7371 .4009 .75984 .41171 .75004 .39734 Metetra
.175 .605 0 r
.75004 .39734 .75984 .41171 .78301 .42291 .77329 .40863 Metetra
.396 .674 0 r
.77329 .40863 .78301 .42291 .8066 .43404 .79695 .41986 Metetra
.65 .741 0 r
.79695 .41986 .8066 .43404 .83056 .44456 .821 .43051 Metetra
.804 .683 0 r
.821 .43051 .83056 .44456 .85483 .4539 .84537 .43999 Metetra
.861 .52 0 r
.84537 .43999 .85483 .4539 .87932 .46137 .86997 .44762 Metetra
.859 .525 0 r
.21567 .63159 .22824 .64196 .24785 .62249 .23541 .612 Metetra
.802 .689 0 r
.23541 .612 .24785 .62249 .26758 .60116 .25528 .59054 Metetra
.64 .738 0 r
.25528 .59054 .26758 .60116 .28736 .57859 .27521 .56784 Metetra
.386 .671 0 r
.27521 .56784 .28736 .57859 .30714 .55534 .29514 .54445 Metetra
.166 .602 0 r
.29514 .54445 .30714 .55534 .32686 .5319 .31501 .52088 Metetra
0 .533 .014 r
.31501 .52088 .32686 .5319 .34651 .50873 .33481 .49757 Metetra
0 .465 .149 r
.33481 .49757 .34651 .50873 .36607 .48621 .35451 .47491 Metetra
0 .4 .24 r
.35451 .47491 .36607 .48621 .38553 .46467 .37411 .45326 Metetra
0 .34 .293 r
.37411 .45326 .38553 .46467 .4049 .44442 .39362 .43288 Metetra
0 .256 .285 r
.39362 .43288 .4049 .44442 .4242 .42569 .41305 .41403 Metetra
0 .164 .237 r
.41305 .41403 .4242 .42569 .44344 .40868 .43241 .39691 Metetra
0 .101 .196 r
.43241 .39691 .44344 .40868 .46265 .39357 .45173 .38169 Metetra
0 .062 .164 r
.45173 .38169 .46265 .39357 .48186 .38047 .47106 .36849 Metetra
0 .039 .14 r
.47106 .36849 .48186 .38047 .50111 .36949 .49041 .35741 Metetra
0 .027 .126 r
.49041 .35741 .50111 .36949 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .027 .126 r
.52938 .34187 .53989 .35412 .5595 .34978 .54907 .33745 Metetra
0 .039 .14 r
.54907 .33745 .5595 .34978 .57932 .34766 .56897 .33524 Metetra
0 .062 .164 r
.56897 .33524 .57932 .34766 .59939 .34769 .58912 .33521 Metetra
0 .101 .196 r
.58912 .33521 .59939 .34769 .61976 .34981 .60955 .33726 Metetra
0 .164 .237 r
.60955 .33726 .61976 .34981 .64046 .35391 .63032 .3413 Metetra
0 .256 .285 r
.63032 .3413 .64046 .35391 .66152 .35983 .65145 .34716 Metetra
0 .34 .293 r
.65145 .34716 .66152 .35983 .683 .36739 .67299 .35467 Metetra
0 .4 .24 r
.67299 .35467 .683 .36739 .7049 .37636 .69495 .36359 Metetra
0 .465 .149 r
.69495 .36359 .7049 .37636 .72724 .38646 .71736 .37364 Metetra
0 .533 .014 r
.71736 .37364 .72724 .38646 .75004 .39734 .74023 .38448 Metetra
.166 .602 0 r
.74023 .38448 .75004 .39734 .77329 .40863 .76355 .39573 Metetra
.386 .671 0 r
.76355 .39573 .77329 .40863 .79695 .41986 .78729 .40691 Metetra
.64 .738 0 r
.78729 .40691 .79695 .41986 .821 .43051 .81142 .41752 Metetra
.802 .689 0 r
.81142 .41752 .821 .43051 .84537 .43999 .83589 .42694 Metetra
.859 .525 0 r
.83589 .42694 .84537 .43999 .86997 .44762 .86059 .43452 Metetra
.861 .52 0 r
.20285 .62189 .21567 .63159 .23541 .612 .22272 .60238 Metetra
.804 .683 0 r
.22272 .60238 .23541 .612 .25528 .59054 .24273 .58097 Metetra
.65 .741 0 r
.24273 .58097 .25528 .59054 .27521 .56784 .2628 .5583 Metetra
.396 .674 0 r
.2628 .5583 .27521 .56784 .29514 .54445 .28287 .53492 Metetra
.175 .605 0 r
.28287 .53492 .29514 .54445 .31501 .52088 .3029 .51134 Metetra
0 .536 .006 r
.3029 .51134 .31501 .52088 .33481 .49757 .32285 .48802 Metetra
0 .468 .142 r
.32285 .48802 .33481 .49757 .35451 .47491 .3427 .46534 Metetra
0 .404 .236 r
.3427 .46534 .35451 .47491 .37411 .45326 .36245 .44364 Metetra
0 .344 .29 r
.36245 .44364 .37411 .45326 .39362 .43288 .3821 .42321 Metetra
0 .266 .289 r
.3821 .42321 .39362 .43288 .41305 .41403 .40167 .40431 Metetra
0 .171 .241 r
.40167 .40431 .41305 .41403 .43241 .39691 .42116 .38713 Metetra
0 .108 .201 r
.42116 .38713 .43241 .39691 .45173 .38169 .44062 .37184 Metetra
0 .067 .168 r
.44062 .37184 .45173 .38169 .47106 .36849 .46007 .35857 Metetra
0 .043 .145 r
.46007 .35857 .47106 .36849 .49041 .35741 .47954 .34741 Metetra
0 .031 .131 r
.47954 .34741 .49041 .35741 .50984 .34853 .49907 .33845 Metetra
0 .027 .126 r
.49907 .33845 .50984 .34853 .52938 .34187 .51872 .3317 Metetra
0 .031 .131 r
.51872 .3317 .52938 .34187 .54907 .33745 .53851 .32719 Metetra
0 .043 .145 r
.53851 .32719 .54907 .33745 .56897 .33524 .55851 .32489 Metetra
0 .067 .168 r
.55851 .32489 .56897 .33524 .58912 .33521 .57874 .32476 Metetra
0 .108 .201 r
.57874 .32476 .58912 .33521 .60955 .33726 .59926 .32671 Metetra
0 .171 .241 r
.59926 .32671 .60955 .33726 .63032 .3413 .6201 .33063 Metetra
0 .266 .289 r
.6201 .33063 .63032 .3413 .65145 .34716 .64131 .33638 Metetra
0 .344 .29 r
.64131 .33638 .65145 .34716 .67299 .35467 .66293 .34376 Metetra
0 .404 .236 r
.66293 .34376 .67299 .35467 .69495 .36359 .68496 .35255 Metetra
0 .468 .142 r
.68496 .35255 .69495 .36359 .71736 .37364 .70745 .36245 Metetra
0 .536 .006 r
.70745 .36245 .71736 .37364 .74023 .38448 .73039 .37313 Metetra
.175 .605 0 r
.73039 .37313 .74023 .38448 .76355 .39573 .75378 .3842 Metetra
.396 .674 0 r
.75378 .3842 .76355 .39573 .78729 .40691 .7776 .3952 Metetra
.65 .741 0 r
.7776 .3952 .78729 .40691 .81142 .41752 .80181 .40559 Metetra
.804 .683 0 r
.80181 .40559 .81142 .41752 .83589 .42694 .82636 .41477 Metetra
.861 .52 0 r
.82636 .41477 .83589 .42694 .86059 .43452 .85115 .42208 Metetra
.866 .504 0 r
.18978 .61283 .20285 .62189 .22272 .60238 .20976 .59359 Metetra
.81 .666 0 r
.20976 .59359 .22272 .60238 .24273 .58097 .22989 .57242 Metetra
.681 .748 0 r
.22989 .57242 .24273 .58097 .2628 .5583 .2501 .54995 Metetra
.426 .682 0 r
.2501 .54995 .2628 .5583 .28287 .53492 .27032 .52673 Metetra
.202 .614 0 r
.27032 .52673 .28287 .53492 .3029 .51134 .2905 .50329 Metetra
.018 .546 0 r
.2905 .50329 .3029 .51134 .32285 .48802 .3106 .48006 Metetra
0 .479 .123 r
.3106 .48006 .32285 .48802 .3427 .46534 .33061 .45745 Metetra
0 .415 .222 r
.33061 .45745 .3427 .46534 .36245 .44364 .35052 .4358 Metetra
0 .356 .282 r
.35052 .4358 .36245 .44364 .3821 .42321 .37032 .4154 Metetra
0 .294 .302 r
.37032 .4154 .3821 .42321 .40167 .40431 .39004 .39651 Metetra
0 .195 .254 r
.39004 .39651 .40167 .40431 .42116 .38713 .40968 .37932 Metetra
0 .127 .214 r
.40968 .37932 .42116 .38713 .44062 .37184 .42928 .364 Metetra
0 .083 .182 r
.42928 .364 .44062 .37184 .46007 .35857 .44886 .35069 Metetra
0 .056 .159 r
.44886 .35069 .46007 .35857 .47954 .34741 .46846 .33948 Metetra
0 .043 .145 r
.46846 .33948 .47954 .34741 .49907 .33845 .48813 .33044 Metetra
0 .038 .14 r
.48813 .33044 .49907 .33845 .51872 .3317 .50789 .32361 Metetra
0 .043 .145 r
.50789 .32361 .51872 .3317 .53851 .32719 .5278 .319 Metetra
0 .056 .159 r
.5278 .319 .53851 .32719 .55851 .32489 .5479 .31659 Metetra
0 .083 .182 r
.5479 .31659 .55851 .32489 .57874 .32476 .56824 .31633 Metetra
0 .127 .214 r
.56824 .31633 .57874 .32476 .59926 .32671 .58885 .31814 Metetra
0 .195 .254 r
.58885 .31814 .59926 .32671 .6201 .33063 .60979 .32191 Metetra
0 .294 .302 r
.60979 .32191 .6201 .33063 .64131 .33638 .63109 .32748 Metetra
0 .356 .282 r
.63109 .32748 .64131 .33638 .66293 .34376 .65279 .33466 Metetra
0 .415 .222 r
.65279 .33466 .66293 .34376 .68496 .35255 .67491 .34322 Metetra
0 .479 .123 r
.67491 .34322 .68496 .35255 .70745 .36245 .69748 .35287 Metetra
.018 .546 0 r
.69748 .35287 .70745 .36245 .73039 .37313 .7205 .36328 Metetra
.202 .614 0 r
.7205 .36328 .73039 .37313 .75378 .3842 .74396 .37404 Metetra
.426 .682 0 r
.74396 .37404 .75378 .3842 .7776 .3952 .76786 .38469 Metetra
.681 .748 0 r
.76786 .38469 .7776 .3952 .80181 .40559 .79215 .39469 Metetra
.81 .666 0 r
.79215 .39469 .80181 .40559 .82636 .41477 .81677 .40344 Metetra
.866 .504 0 r
.81677 .40344 .82636 .41477 .85115 .42208 .84164 .41027 Metetra
.874 .477 0 r
.17646 .60433 .18978 .61283 .20976 .59359 .19653 .58558 Metetra
.82 .638 0 r
.19653 .58558 .20976 .59359 .22989 .57242 .21677 .56483 Metetra
.731 .76 0 r
.21677 .56483 .22989 .57242 .2501 .54995 .2371 .54273 Metetra
.475 .696 0 r
.2371 .54273 .2501 .54995 .27032 .52673 .25746 .51983 Metetra
.248 .629 0 r
.25746 .51983 .27032 .52673 .2905 .50329 .27779 .49665 Metetra
.059 .563 0 r
.27779 .49665 .2905 .50329 .3106 .48006 .29805 .47364 Metetra
0 .497 .089 r
.29805 .47364 .3106 .48006 .33061 .45745 .31822 .45121 Metetra
0 .434 .196 r
.31822 .45121 .33061 .45745 .35052 .4358 .33829 .4297 Metetra
0 .376 .265 r
.33829 .4297 .35052 .4358 .37032 .4154 .35825 .40941 Metetra
0 .322 .302 r
.35825 .40941 .37032 .4154 .39004 .39651 .37813 .39058 Metetra
0 .237 .276 r
.37813 .39058 .39004 .39651 .40968 .37932 .39793 .37344 Metetra
0 .163 .236 r
.39793 .37344 .40968 .37932 .42928 .364 .41768 .35813 Metetra
0 .113 .205 r
.41768 .35813 .42928 .364 .44886 .35069 .43742 .34481 Metetra
0 .083 .182 r
.43742 .34481 .44886 .35069 .46846 .33948 .45717 .33357 Metetra
0 .066 .168 r
.45717 .33357 .46846 .33948 .48813 .33044 .47697 .32447 Metetra
0 .061 .163 r
.47697 .32447 .48813 .33044 .50789 .32361 .49687 .31756 Metetra
0 .066 .168 r
.49687 .31756 .50789 .32361 .5278 .319 .51691 .31285 Metetra
0 .083 .182 r
.51691 .31285 .5278 .319 .5479 .31659 .53713 .31031 Metetra
0 .113 .205 r
.53713 .31031 .5479 .31659 .56824 .31633 .55758 .30989 Metetra
0 .163 .236 r
.55758 .30989 .56824 .31633 .58885 .31814 .57831 .31152 Metetra
0 .237 .276 r
.57831 .31152 .58885 .31814 .60979 .32191 .59936 .31507 Metetra
0 .322 .302 r
.59936 .31507 .60979 .32191 .63109 .32748 .62076 .3204 Metetra
0 .376 .265 r
.62076 .3204 .63109 .32748 .65279 .33466 .64256 .32731 Metetra
0 .434 .196 r
.64256 .32731 .65279 .33466 .67491 .34322 .66477 .33555 Metetra
0 .497 .089 r
.66477 .33555 .67491 .34322 .69748 .35287 .68743 .34485 Metetra
.059 .563 0 r
.68743 .34485 .69748 .35287 .7205 .36328 .71053 .35486 Metetra
.248 .629 0 r
.71053 .35486 .7205 .36328 .74396 .37404 .73408 .36517 Metetra
.475 .696 0 r
.73408 .36517 .74396 .37404 .76786 .38469 .75806 .37531 Metetra
.731 .76 0 r
.75806 .37531 .76786 .38469 .79215 .39469 .78242 .38475 Metetra
.82 .638 0 r
.78242 .38475 .79215 .39469 .81677 .40344 .80712 .39287 Metetra
.874 .477 0 r
.80712 .39287 .81677 .40344 .84164 .41027 .83205 .399 Metetra
.885 .441 0 r
.16287 .59628 .17646 .60433 .19653 .58558 .18301 .57822 Metetra
.834 .599 0 r
.18301 .57822 .19653 .58558 .21677 .56483 .20335 .55809 Metetra
.777 .752 0 r
.20335 .55809 .21677 .56483 .2371 .54273 .2238 .53653 Metetra
.545 .715 0 r
.2238 .53653 .2371 .54273 .25746 .51983 .24429 .51411 Metetra
.315 .65 0 r
.24429 .51411 .25746 .51983 .27779 .49665 .26476 .49133 Metetra
.118 .585 0 r
.26476 .49133 .27779 .49665 .29805 .47364 .28518 .46867 Metetra
0 .521 .039 r
.28518 .46867 .29805 .47364 .31822 .45121 .30551 .44653 Metetra
0 .46 .156 r
.30551 .44653 .31822 .45121 .33829 .4297 .32574 .42525 Metetra
0 .403 .237 r
.32574 .42525 .33829 .4297 .35825 .40941 .34588 .40514 Metetra
0 .351 .285 r
.34588 .40514 .35825 .40941 .37813 .39058 .36592 .38646 Metetra
0 .302 .305 r
.36592 .38646 .37813 .39058 .39793 .37344 .38589 .36941 Metetra
0 .219 .266 r
.38589 .36941 .39793 .37344 .41768 .35813 .40581 .35417 Metetra
0 .162 .236 r
.40581 .35417 .41768 .35813 .43742 .34481 .42571 .34086 Metetra
0 .126 .213 r
.42571 .34086 .43742 .34481 .45717 .33357 .44561 .32961 Metetra
0 .106 .2 r
.44561 .32961 .45717 .33357 .47697 .32447 .46557 .32046 Metetra
0 .1 .195 r
.46557 .32046 .47697 .32447 .49687 .31756 .48562 .31347 Metetra
0 .106 .2 r
.48562 .31347 .49687 .31756 .51691 .31285 .5058 .30864 Metetra
0 .126 .213 r
.5058 .30864 .51691 .31285 .53713 .31031 .52617 .30595 Metetra
0 .162 .236 r
.52617 .30595 .53713 .31031 .55758 .30989 .54675 .30535 Metetra
0 .219 .266 r
.54675 .30535 .55758 .30989 .57831 .31152 .56761 .30676 Metetra
0 .302 .305 r
.56761 .30676 .57831 .31152 .59936 .31507 .58878 .31005 Metetra
0 .351 .285 r
.58878 .31005 .59936 .31507 .62076 .3204 .6103 .31507 Metetra
0 .403 .237 r
.6103 .31507 .62076 .3204 .64256 .32731 .6322 .32162 Metetra
0 .46 .156 r
.6322 .32162 .64256 .32731 .66477 .33555 .65452 .32946 Metetra
0 .521 .039 r
.65452 .32946 .66477 .33555 .68743 .34485 .67728 .33829 Metetra
.118 .585 0 r
.67728 .33829 .68743 .34485 .71053 .35486 .70047 .34777 Metetra
.315 .65 0 r
.70047 .34777 .71053 .35486 .73408 .36517 .72411 .35749 Metetra
.545 .715 0 r
.72411 .35749 .73408 .36517 .75806 .37531 .74817 .36696 Metetra
.777 .752 0 r
.74817 .36696 .75806 .37531 .78242 .38475 .77261 .37565 Metetra
.834 .599 0 r
.77261 .37565 .78242 .38475 .80712 .39287 .79736 .38294 Metetra
.885 .441 0 r
.79736 .38294 .80712 .39287 .83205 .399 .82235 .38815 Metetra
.898 .395 0 r
.14903 .58851 .16287 .59628 .18301 .57822 .16922 .57136 Metetra
.851 .55 0 r
.16922 .57136 .18301 .57822 .20335 .55809 .18963 .55205 Metetra
.797 .702 0 r
.18963 .55205 .20335 .55809 .2238 .53653 .21018 .53122 Metetra
.636 .738 0 r
.21018 .53122 .2238 .53653 .24429 .51411 .23079 .50943 Metetra
.402 .676 0 r
.23079 .50943 .24429 .51411 .26476 .49133 .2514 .4872 Metetra
.199 .613 0 r
.2514 .4872 .26476 .49133 .28518 .46867 .27197 .46502 Metetra
.032 .552 0 r
.27197 .46502 .28518 .46867 .30551 .44653 .29246 .44327 Metetra
0 .492 .098 r
.29246 .44327 .30551 .44653 .32574 .42525 .31286 .42233 Metetra
0 .437 .192 r
.31286 .42233 .32574 .42525 .34588 .40514 .33317 .40249 Metetra
0 .387 .254 r
.33317 .40249 .34588 .40514 .36592 .38646 .35339 .38402 Metetra
0 .342 .291 r
.35339 .38402 .36592 .38646 .38589 .36941 .37354 .36713 Metetra
0 .3 .304 r
.37354 .36713 .38589 .36941 .40581 .35417 .39364 .35199 Metetra
0 .235 .275 r
.39364 .35199 .40581 .35417 .42571 .34086 .41371 .33874 Metetra
0 .192 .253 r
.41371 .33874 .42571 .34086 .44561 .32961 .43379 .3275 Metetra
0 .169 .239 r
.43379 .3275 .44561 .32961 .46557 .32046 .45391 .31832 Metetra
0 .161 .235 r
.45391 .31832 .46557 .32046 .48562 .31347 .47412 .31124 Metetra
0 .169 .239 r
.47412 .31124 .48562 .31347 .5058 .30864 .49446 .30629 Metetra
0 .192 .253 r
.49446 .30629 .5058 .30864 .52617 .30595 .51498 .30343 Metetra
0 .235 .275 r
.51498 .30343 .52617 .30595 .54675 .30535 .53572 .30261 Metetra
0 .3 .304 r
.53572 .30261 .54675 .30535 .56761 .30676 .55672 .30375 Metetra
0 .342 .291 r
.55672 .30375 .56761 .30676 .58878 .31005 .57802 .30672 Metetra
0 .387 .254 r
.57802 .30672 .58878 .31005 .6103 .31507 .59967 .31136 Metetra
0 .437 .192 r
.59967 .31136 .6103 .31507 .6322 .32162 .6217 .31747 Metetra
0 .492 .098 r
.6217 .31747 .6322 .32162 .65452 .32946 .64413 .3248 Metetra
.032 .552 0 r
.64413 .3248 .65452 .32946 .67728 .33829 .667 .33306 Metetra
.199 .613 0 r
.667 .33306 .67728 .33829 .70047 .34777 .6903 .34188 Metetra
.402 .676 0 r
.6903 .34188 .70047 .34777 .72411 .35749 .71403 .35085 Metetra
.636 .738 0 r
.71403 .35085 .72411 .35749 .74817 .36696 .73816 .35948 Metetra
.797 .702 0 r
.73816 .35948 .74817 .36696 .77261 .37565 .76267 .36724 Metetra
.851 .55 0 r
.76267 .36724 .77261 .37565 .79736 .38294 .78749 .37349 Metetra
.898 .395 0 r
.78749 .37349 .79736 .38294 .82235 .38815 .81253 .37754 Metetra
.913 .343 0 r
.13496 .58081 .14903 .58851 .16922 .57136 .15515 .5648 Metetra
.87 .49 0 r
.15515 .5648 .16922 .57136 .18963 .55205 .17562 .54652 Metetra
.82 .641 0 r
.17562 .54652 .18963 .55205 .21018 .53122 .19625 .52659 Metetra
.747 .764 0 r
.19625 .52659 .21018 .53122 .23079 .50943 .21696 .50561 Metetra
.512 .706 0 r
.21696 .50561 .23079 .50943 .2514 .4872 .2377 .48409 Metetra
.302 .646 0 r
.2377 .48409 .2514 .4872 .27197 .46502 .25841 .46252 Metetra
.125 .587 0 r
.25841 .46252 .27197 .46502 .29246 .44327 .27906 .44129 Metetra
0 .531 .018 r
.27906 .44129 .29246 .44327 .31286 .42233 .29963 .42079 Metetra
0 .477 .126 r
.29963 .42079 .31286 .42233 .33317 .40249 .32012 .40131 Metetra
0 .429 .204 r
.32012 .40131 .33317 .40249 .35339 .38402 .34052 .38312 Metetra
0 .386 .255 r
.34052 .38312 .35339 .38402 .37354 .36713 .36085 .36644 Metetra
0 .35 .286 r
.36085 .36644 .37354 .36713 .39364 .35199 .38114 .35146 Metetra
0 .321 .303 r
.38114 .35146 .39364 .35199 .41371 .33874 .40139 .3383 Metetra
0 .289 .3 r
.40139 .3383 .41371 .33874 .43379 .3275 .42165 .32709 Metetra
0 .261 .287 r
.42165 .32709 .43379 .3275 .45391 .31832 .44196 .31789 Metetra
0 .252 .282 r
.44196 .31789 .45391 .31832 .47412 .31124 .46235 .31074 Metetra
0 .261 .287 r
.46235 .31074 .47412 .31124 .49446 .30629 .48287 .30565 Metetra
0 .289 .3 r
.48287 .30565 .49446 .30629 .51498 .30343 .50355 .30259 Metetra
0 .321 .303 r
.50355 .30259 .51498 .30343 .53572 .30261 .52445 .30152 Metetra
0 .35 .286 r
.52445 .30152 .53572 .30261 .55672 .30375 .5456 .30234 Metetra
0 .386 .255 r
.5456 .30234 .55672 .30375 .57802 .30672 .56706 .30493 Metetra
0 .429 .204 r
.56706 .30493 .57802 .30672 .59967 .31136 .58885 .30912 Metetra
0 .477 .126 r
.58885 .30912 .59967 .31136 .6217 .31747 .61102 .3147 Metetra
0 .531 .018 r
.61102 .3147 .6217 .31747 .64413 .3248 .63358 .32143 Metetra
.125 .587 0 r
.63358 .32143 .64413 .3248 .667 .33306 .65656 .32898 Metetra
.302 .646 0 r
.65656 .32898 .667 .33306 .6903 .34188 .67997 .337 Metetra
.512 .706 0 r
.67997 .337 .6903 .34188 .71403 .35085 .7038 .34507 Metetra
.747 .764 0 r
.7038 .34507 .71403 .35085 .73816 .35948 .72802 .35269 Metetra
.82 .641 0 r
.72802 .35269 .73816 .35948 .76267 .36724 .7526 .3593 Metetra
.87 .49 0 r
.7526 .3593 .76267 .36724 .78749 .37349 .77747 .36429 Metetra
.913 .343 0 r
.77747 .36429 .78749 .37349 .81253 .37754 .80255 .36696 Metetra
.929 .286 0 r
.12066 .57295 .13496 .58081 .15515 .5648 .14084 .5583 Metetra
.891 .422 0 r
.14084 .5583 .15515 .5648 .17562 .54652 .16132 .54125 Metetra
.845 .568 0 r
.16132 .54125 .17562 .54652 .19625 .52659 .182 .52243 Metetra
.794 .71 0 r
.182 .52243 .19625 .52659 .21696 .50561 .20281 .50243 Metetra
.643 .739 0 r
.20281 .50243 .21696 .50561 .2377 .48409 .22366 .48177 Metetra
.429 .683 0 r
.22366 .48177 .2377 .48409 .25841 .46252 .2445 .46095 Metetra
.243 .628 0 r
.2445 .46095 .25841 .46252 .27906 .44129 .2653 .44037 Metetra
.088 .574 0 r
.2653 .44037 .27906 .44129 .29963 .42079 .28604 .42041 Metetra
0 .523 .035 r
.28604 .42041 .29963 .42079 .32012 .40131 .30671 .40139 Metetra
0 .477 .128 r
.30671 .40139 .32012 .40131 .34052 .38312 .32729 .38356 Metetra
0 .436 .194 r
.32729 .38356 .34052 .38312 .36085 .36644 .34782 .36717 Metetra
0 .401 .239 r
.34782 .36717 .36085 .36644 .38114 .35146 .36829 .35239 Metetra
0 .373 .267 r
.36829 .35239 .38114 .35146 .40139 .3383 .38874 .33937 Metetra
0 .353 .284 r
.38874 .33937 .40139 .3383 .42165 .32709 .4092 .32822 Metetra
0 .341 .292 r
.4092 .32822 .42165 .32709 .44196 .31789 .4297 .319 Metetra
0 .336 .295 r
.4297 .319 .44196 .31789 .46235 .31074 .45028 .31177 Metetra
0 .341 .292 r
.45028 .31177 .46235 .31074 .48287 .30565 .47098 .30653 Metetra
0 .353 .284 r
.47098 .30653 .48287 .30565 .50355 .30259 .49185 .30326 Metetra
0 .373 .267 r
.49185 .30326 .50355 .30259 .52445 .30152 .51292 .3019 Metetra
0 .401 .239 r
.51292 .3019 .52445 .30152 .5456 .30234 .53425 .30235 Metetra
0 .436 .194 r
.53425 .30235 .5456 .30234 .56706 .30493 .55587 .30449 Metetra
0 .477 .128 r
.55587 .30449 .56706 .30493 .58885 .30912 .57782 .30815 Metetra
0 .523 .035 r
.57782 .30815 .58885 .30912 .61102 .3147 .60013 .31311 Metetra
.088 .574 0 r
.60013 .31311 .61102 .3147 .63358 .32143 .62284 .31911 Metetra
.243 .628 0 r
.62284 .31911 .63358 .32143 .65656 .32898 .64595 .32583 Metetra
.429 .683 0 r
.64595 .32583 .65656 .32898 .67997 .337 .66947 .33291 Metetra
.643 .739 0 r
.66947 .33291 .67997 .337 .7038 .34507 .6934 .3399 Metetra
.794 .71 0 r
.6934 .3399 .7038 .34507 .72802 .35269 .71771 .34632 Metetra
.845 .568 0 r
.71771 .34632 .72802 .35269 .7526 .3593 .74236 .35159 Metetra
.891 .422 0 r
.74236 .35159 .7526 .3593 .77747 .36429 .76728 .3551 Metetra
.929 .286 0 r
.76728 .3551 .77747 .36429 .80255 .36696 .79238 .35613 Metetra
.944 .229 0 r
.10618 .56461 .12066 .57295 .14084 .5583 .12629 .55155 Metetra
.911 .35 0 r
.12629 .55155 .14084 .5583 .16132 .54125 .14676 .53595 Metetra
.871 .487 0 r
.14676 .53595 .16132 .54125 .182 .52243 .16747 .51844 Metetra
.825 .626 0 r
.16747 .51844 .182 .52243 .20281 .50243 .18834 .4996 Metetra
.775 .756 0 r
.18834 .4996 .20281 .50243 .22366 .48177 .20928 .47998 Metetra
.579 .723 0 r
.20928 .47998 .22366 .48177 .2445 .46095 .23024 .46006 Metetra
.387 .671 0 r
.23024 .46006 .2445 .46095 .2653 .44037 .25119 .44027 Metetra
.222 .621 0 r
.25119 .44027 .2653 .44037 .28604 .42041 .27209 .42097 Metetra
.086 .573 0 r
.27209 .42097 .28604 .42041 .30671 .40139 .29292 .40249 Metetra
0 .529 .021 r
.29292 .40249 .30671 .40139 .32729 .38356 .3137 .38512 Metetra
0 .49 .102 r
.3137 .38512 .32729 .38356 .34782 .36717 .33441 .36908 Metetra
0 .457 .161 r
.33441 .36908 .34782 .36717 .36829 .35239 .35509 .35456 Metetra
0 .431 .201 r
.35509 .35456 .36829 .35239 .38874 .33937 .37574 .34171 Metetra
0 .412 .226 r
.37574 .34171 .38874 .33937 .4092 .32822 .3964 .33065 Metetra
0 .4 .24 r
.3964 .33065 .4092 .32822 .4297 .319 .4171 .32144 Metetra
0 .396 .244 r
.4171 .32144 .4297 .319 .45028 .31177 .43789 .31413 Metetra
0 .4 .24 r
.43789 .31413 .45028 .31177 .47098 .30653 .45879 .30873 Metetra
0 .412 .226 r
.45879 .30873 .47098 .30653 .49185 .30326 .47985 .30521 Metetra
0 .431 .201 r
.47985 .30521 .49185 .30326 .51292 .3019 .50112 .30352 Metetra
0 .457 .161 r
.50112 .30352 .51292 .3019 .53425 .30235 .52263 .30355 Metetra
0 .49 .102 r
.52263 .30355 .53425 .30235 .55587 .30449 .54443 .30517 Metetra
0 .529 .021 r
.54443 .30517 .55587 .30449 .57782 .30815 .56655 .30821 Metetra
.086 .573 0 r
.56655 .30821 .57782 .30815 .60013 .31311 .58902 .31244 Metetra
.222 .621 0 r
.58902 .31244 .60013 .31311 .62284 .31911 .61187 .31759 Metetra
.387 .671 0 r
.61187 .31759 .62284 .31911 .64595 .32583 .63512 .32335 Metetra
.579 .723 0 r
.63512 .32335 .64595 .32583 .66947 .33291 .65876 .32932 Metetra
.775 .756 0 r
.65876 .32932 .66947 .33291 .6934 .3399 .6828 .33507 Metetra
.825 .626 0 r
.6828 .33507 .6934 .3399 .71771 .34632 .7072 .34008 Metetra
.871 .487 0 r
.7072 .34008 .71771 .34632 .74236 .35159 .73192 .3438 Metetra
.911 .35 0 r
.73192 .3438 .74236 .35159 .76728 .3551 .75688 .34558 Metetra
.944 .229 0 r
.75688 .34558 .76728 .3551 .79238 .35613 .782 .34473 Metetra
.958 .175 0 r
.09155 .55544 .10618 .56461 .12629 .55155 .11156 .54421 Metetra
.932 .276 0 r
.11156 .54421 .12629 .55155 .14676 .53595 .13197 .53028 Metetra
.897 .399 0 r
.13197 .53028 .14676 .53595 .16747 .51844 .15267 .51429 Metetra
.857 .532 0 r
.15267 .51429 .16747 .51844 .18834 .4996 .17357 .49681 Metetra
.812 .662 0 r
.17357 .49681 .18834 .4996 .20928 .47998 .19458 .4784 Metetra
.751 .765 0 r
.19458 .4784 .20928 .47998 .23024 .46006 .21565 .45954 Metetra
.556 .717 0 r
.21565 .45954 .23024 .46006 .25119 .44027 .23672 .44066 Metetra
.384 .671 0 r
.23672 .44066 .25119 .44027 .27209 .42097 .25777 .42215 Metetra
.238 .626 0 r
.25777 .42215 .27209 .42097 .29292 .40249 .27877 .40434 Metetra
.119 .585 0 r
.27877 .40434 .29292 .40249 .3137 .38512 .29973 .38751 Metetra
.025 .549 0 r
.29973 .38751 .3137 .38512 .33441 .36908 .32064 .3719 Metetra
0 .518 .046 r
.32064 .3719 .33441 .36908 .35509 .35456 .34151 .3577 Metetra
0 .493 .097 r
.34151 .3577 .35509 .35456 .37574 .34171 .36237 .34506 Metetra
0 .475 .131 r
.36237 .34506 .37574 .34171 .3964 .33065 .38324 .33411 Metetra
0 .464 .15 r
.38324 .33411 .3964 .33065 .4171 .32144 .40416 .32492 Metetra
0 .46 .156 r
.40416 .32492 .4171 .32144 .43789 .31413 .42516 .31753 Metetra
0 .464 .15 r
.42516 .31753 .43789 .31413 .45879 .30873 .44627 .31196 Metetra
0 .475 .131 r
.44627 .31196 .45879 .30873 .47985 .30521 .46754 .30816 Metetra
0 .493 .097 r
.46754 .30816 .47985 .30521 .50112 .30352 .48901 .30609 Metetra
0 .518 .046 r
.48901 .30609 .50112 .30352 .52263 .30355 .51072 .30564 Metetra
.025 .549 0 r
.51072 .30564 .52263 .30355 .54443 .30517 .53271 .30667 Metetra
.119 .585 0 r
.53271 .30667 .54443 .30517 .56655 .30821 .55501 .30899 Metetra
.238 .626 0 r
.55501 .30899 .56655 .30821 .58902 .31244 .57765 .31238 Metetra
.384 .671 0 r
.57765 .31238 .58902 .31244 .61187 .31759 .60067 .31656 Metetra
.556 .717 0 r
.60067 .31656 .61187 .31759 .63512 .32335 .62406 .3212 Metetra
.751 .765 0 r
.62406 .3212 .63512 .32335 .65876 .32932 .64783 .3259 Metetra
.812 .662 0 r
.64783 .3259 .65876 .32932 .6828 .33507 .67198 .33022 Metetra
.857 .532 0 r
.67198 .33022 .6828 .33507 .7072 .34008 .69646 .33363 Metetra
.897 .399 0 r
.69646 .33363 .7072 .34008 .73192 .3438 .72125 .33557 Metetra
.932 .276 0 r
.72125 .33557 .73192 .3438 .75688 .34558 .74625 .33539 Metetra
.958 .175 0 r
.74625 .33539 .75688 .34558 .782 .34473 .77137 .33239 Metetra
.969 .132 0 r
.07684 .54504 .09155 .55544 .11156 .54421 .09668 .53588 Metetra
.95 .207 0 r
.09668 .53588 .11156 .54421 .13197 .53028 .11699 .52385 Metetra
.922 .311 0 r
.11699 .52385 .13197 .53028 .15267 .51429 .13764 .50959 Metetra
.888 .431 0 r
.13764 .50959 .15267 .51429 .17357 .49681 .15854 .49367 Metetra
.849 .556 0 r
.15854 .49367 .17357 .49681 .19458 .4784 .17959 .47665 Metetra
.807 .675 0 r
.17959 .47665 .19458 .4784 .21565 .45954 .20073 .45901 Metetra
.748 .764 0 r
.20073 .45901 .21565 .45954 .23672 .44066 .22191 .44121 Metetra
.573 .722 0 r
.22191 .44121 .23672 .44066 .25777 .42215 .2431 .42361 Metetra
.421 .681 0 r
.2431 .42361 .25777 .42215 .27877 .40434 .26426 .40658 Metetra
.293 .643 0 r
.26426 .40658 .27877 .40434 .29973 .38751 .28539 .39038 Metetra
.189 .61 0 r
.28539 .39038 .29973 .38751 .32064 .3719 .30649 .37528 Metetra
.107 .581 0 r
.30649 .37528 .32064 .3719 .34151 .3577 .32757 .36146 Metetra
.047 .558 0 r
.32757 .36146 .34151 .3577 .36237 .34506 .34864 .34909 Metetra
.006 .541 0 r
.34864 .34909 .36237 .34506 .38324 .33411 .36973 .33829 Metetra
0 .531 .018 r
.36973 .33829 .38324 .33411 .40416 .32492 .39086 .32913 Metetra
0 .527 .025 r
.39086 .32913 .40416 .32492 .42516 .31753 .41208 .32166 Metetra
0 .531 .018 r
.41208 .32166 .42516 .31753 .44627 .31196 .43341 .31589 Metetra
.006 .541 0 r
.43341 .31589 .44627 .31196 .46754 .30816 .4549 .31179 Metetra
.047 .558 0 r
.4549 .31179 .46754 .30816 .48901 .30609 .47659 .30929 Metetra
.107 .581 0 r
.47659 .30929 .48901 .30609 .51072 .30564 .4985 .30829 Metetra
.189 .61 0 r
.4985 .30829 .51072 .30564 .53271 .30667 .52069 .30864 Metetra
.293 .643 0 r
.52069 .30864 .53271 .30667 .55501 .30899 .54319 .31015 Metetra
.421 .681 0 r
.54319 .31015 .55501 .30899 .57765 .31238 .56601 .31259 Metetra
.573 .722 0 r
.56601 .31259 .57765 .31238 .60067 .31656 .58919 .31565 Metetra
.748 .764 0 r
.58919 .31565 .60067 .31656 .62406 .3212 .61274 .31901 Metetra
.807 .675 0 r
.61274 .31901 .62406 .3212 .64783 .3259 .63665 .32227 Metetra
.849 .556 0 r
.63665 .32227 .64783 .3259 .67198 .33022 .6609 .32496 Metetra
.888 .431 0 r
.6609 .32496 .67198 .33022 .69646 .33363 .68548 .32655 Metetra
.922 .311 0 r
.68548 .32655 .69646 .33363 .72125 .33557 .71032 .32648 Metetra
.95 .207 0 r
.71032 .32648 .72125 .33557 .74625 .33539 .73535 .32409 Metetra
.969 .132 0 r
.73535 .32409 .74625 .33539 .77137 .33239 .76047 .31869 Metetra
.975 .105 0 r
.06212 .53297 .07684 .54504 .09668 .53588 .08174 .52611 Metetra
.964 .149 0 r
.08174 .52611 .09668 .53588 .11699 .52385 .10189 .51622 Metetra
.944 .228 0 r
.10189 .51622 .11699 .52385 .13764 .50959 .12244 .5039 Metetra
.917 .33 0 r
.12244 .5039 .13764 .50959 .15854 .49367 .14329 .48974 Metetra
.884 .444 0 r
.14329 .48974 .15854 .49367 .17959 .47665 .16435 .4743 Metetra
.848 .558 0 r
.16435 .4743 .17959 .47665 .20073 .45901 .18553 .45806 Metetra
.811 .665 0 r
.18553 .45806 .20073 .45901 .22191 .44121 .2068 .44148 Metetra
.773 .761 0 r
.2068 .44148 .22191 .44121 .2431 .42361 .2281 .42494 Metetra
.632 .736 0 r
.2281 .42494 .2431 .42361 .26426 .40658 .2494 .4088 Metetra
.499 .702 0 r
.2494 .4088 .26426 .40658 .28539 .39038 .2707 .39334 Metetra
.388 .672 0 r
.2707 .39334 .28539 .39038 .30649 .37528 .29198 .37883 Metetra
.299 .645 0 r
.29198 .37883 .30649 .37528 .32757 .36146 .31325 .36547 Metetra
.232 .624 0 r
.31325 .36547 .32757 .36146 .34864 .34909 .33453 .35341 Metetra
.186 .609 0 r
.33453 .35341 .34864 .34909 .36973 .33829 .35584 .34278 Metetra
.158 .599 0 r
.35584 .34278 .36973 .33829 .39086 .32913 .3772 .33368 Metetra
.149 .596 0 r
.3772 .33368 .39086 .32913 .41208 .32166 .39864 .32613 Metetra
.158 .599 0 r
.39864 .32613 .41208 .32166 .43341 .31589 .42021 .32015 Metetra
.186 .609 0 r
.42021 .32015 .43341 .31589 .4549 .31179 .44192 .3157 Metetra
.232 .624 0 r
.44192 .3157 .4549 .31179 .47659 .30929 .46383 .31272 Metetra
.299 .645 0 r
.46383 .31272 .47659 .30929 .4985 .30829 .48597 .3111 Metetra
.388 .672 0 r
.48597 .3111 .4985 .30829 .52069 .30864 .50837 .31068 Metetra
.499 .702 0 r
.50837 .31068 .52069 .30864 .54319 .31015 .53106 .31127 Metetra
.632 .736 0 r
.53106 .31127 .54319 .31015 .56601 .31259 .55408 .31262 Metetra
.773 .761 0 r
.55408 .31262 .56601 .31259 .58919 .31565 .57744 .31443 Metetra
.811 .665 0 r
.57744 .31443 .58919 .31565 .61274 .31901 .60114 .31635 Metetra
.848 .558 0 r
.60114 .31635 .61274 .31901 .63665 .32227 .62518 .31797 Metetra
.884 .444 0 r
.62518 .31797 .63665 .32227 .6609 .32496 .64956 .31882 Metetra
.917 .33 0 r
.64956 .31882 .6609 .32496 .68548 .32655 .67422 .31838 Metetra
.944 .228 0 r
.67422 .31838 .68548 .32655 .71032 .32648 .69911 .31605 Metetra
.964 .149 0 r
.69911 .31605 .71032 .32648 .73535 .32409 .72416 .3112 Metetra
.975 .105 0 r
.72416 .3112 .73535 .32409 .76047 .31869 .74926 .30313 Metetra
.976 .103 0 r
.04747 .51872 .06212 .53297 .08174 .52611 .0668 .51441 Metetra
.974 .111 0 r
.0668 .51441 .08174 .52611 .10189 .51622 .08673 .50687 Metetra
.962 .159 0 r
.08673 .50687 .10189 .51622 .12244 .5039 .10713 .49671 Metetra
.942 .237 0 r
.10713 .49671 .12244 .5039 .14329 .48974 .12789 .48453 Metetra
.916 .332 0 r
.12789 .48453 .14329 .48974 .16435 .4743 .1489 .47086 Metetra
.887 .435 0 r
.1489 .47086 .16435 .4743 .18553 .45806 .1701 .45619 Metetra
.855 .537 0 r
.1701 .45619 .18553 .45806 .2068 .44148 .19142 .44099 Metetra
.822 .633 0 r
.19142 .44099 .2068 .44148 .2281 .42494 .2128 .42566 Metetra
.79 .718 0 r
.2128 .42566 .2281 .42494 .2494 .4088 .23423 .41054 Metetra
.731 .76 0 r
.23423 .41054 .2494 .4088 .2707 .39334 .25568 .39593 Metetra
.618 .733 0 r
.25568 .39593 .2707 .39334 .29198 .37883 .27713 .3821 Metetra
.526 .709 0 r
.27713 .3821 .29198 .37883 .31325 .36547 .29859 .36926 Metetra
.455 .69 0 r
.29859 .36926 .31325 .36547 .33453 .35341 .32008 .35757 Metetra
.404 .676 0 r
.32008 .35757 .33453 .35341 .35584 .34278 .3416 .34716 Metetra
.375 .668 0 r
.3416 .34716 .35584 .34278 .3772 .33368 .36319 .33812 Metetra
.365 .665 0 r
.36319 .33812 .3772 .33368 .39864 .32613 .38486 .33048 Metetra
.375 .668 0 r
.38486 .33048 .39864 .32613 .42021 .32015 .40665 .32427 Metetra
.404 .676 0 r
.40665 .32427 .42021 .32015 .44192 .3157 .4286 .31944 Metetra
.455 .69 0 r
.4286 .31944 .44192 .3157 .46383 .31272 .45074 .31593 Metetra
.526 .709 0 r
.45074 .31593 .46383 .31272 .48597 .3111 .47311 .31361 Metetra
.618 .733 0 r
.47311 .31361 .48597 .3111 .50837 .31068 .49573 .31232 Metetra
.731 .76 0 r
.49573 .31232 .50837 .31068 .53106 .31127 .51863 .31187 Metetra
.79 .718 0 r
.51863 .31187 .53106 .31127 .55408 .31262 .54184 .31199 Metetra
.822 .633 0 r
.54184 .31199 .55408 .31262 .57744 .31443 .56538 .31239 Metetra
.855 .537 0 r
.56538 .31239 .57744 .31443 .60114 .31635 .58924 .31269 Metetra
.887 .435 0 r
.58924 .31269 .60114 .31635 .62518 .31797 .61343 .31248 Metetra
.916 .332 0 r
.61343 .31248 .62518 .31797 .64956 .31882 .63792 .31129 Metetra
.942 .237 0 r
.63792 .31129 .64956 .31882 .67422 .31838 .66266 .30859 Metetra
.962 .159 0 r
.66266 .30859 .67422 .31838 .69911 .31605 .68761 .30377 Metetra
.974 .111 0 r
.68761 .30377 .69911 .31605 .72416 .3112 .71266 .29621 Metetra
.976 .103 0 r
.71266 .29621 .72416 .3112 .74926 .30313 .73773 .28521 Metetra
.968 .133 0 r
.033 .50176 .04747 .51872 .0668 .51441 .05197 .50021 Metetra
.976 .101 0 r
.05197 .50021 .0668 .51441 .08673 .50687 .07161 .49525 Metetra
.973 .114 0 r
.07161 .49525 .08673 .50687 .10713 .49671 .0918 .48748 Metetra
.962 .16 0 r
.0918 .48748 .10713 .49671 .12789 .48453 .1124 .47747 Metetra
.944 .231 0 r
.1124 .47747 .12789 .48453 .1489 .47086 .13333 .46577 Metetra
.921 .316 0 r
.13333 .46577 .1489 .47086 .1701 .45619 .15449 .45286 Metetra
.895 .406 0 r
.15449 .45286 .1701 .45619 .19142 .44099 .17583 .43921 Metetra
.868 .495 0 r
.17583 .43921 .19142 .44099 .2128 .42566 .19727 .42522 Metetra
.841 .579 0 r
.19727 .42522 .2128 .42566 .23423 .41054 .21879 .41125 Metetra
.815 .652 0 r
.21879 .41125 .23423 .41054 .25568 .39593 .24036 .39761 Metetra
.792 .714 0 r
.24036 .39761 .25568 .39593 .27713 .3821 .26197 .38456 Metetra
.771 .765 0 r
.26197 .38456 .27713 .3821 .29859 .36926 .28361 .37231 Metetra
.706 .755 0 r
.28361 .37231 .29859 .36926 .32008 .35757 .30529 .36104 Metetra
.655 .742 0 r
.30529 .36104 .32008 .35757 .3416 .34716 .32703 .35089 Metetra
.624 .735 0 r
.32703 .35089 .3416 .34716 .36319 .33812 .34883 .34193 Metetra
.614 .732 0 r
.34883 .34193 .36319 .33812 .38486 .33048 .37074 .33421 Metetra
.624 .735 0 r
.37074 .33421 .38486 .33048 .40665 .32427 .39277 .32774 Metetra
.655 .742 0 r
.39277 .32774 .40665 .32427 .4286 .31944 .41495 .32249 Metetra
.706 .755 0 r
.41495 .32249 .4286 .31944 .45074 .31593 .43733 .31837 Metetra
.771 .765 0 r
.43733 .31837 .45074 .31593 .47311 .31361 .45992 .31527 Metetra
.792 .714 0 r
.45992 .31527 .47311 .31361 .49573 .31232 .48277 .31301 Metetra
.815 .652 0 r
.48277 .31301 .49573 .31232 .51863 .31187 .50589 .3114 Metetra
.841 .579 0 r
.50589 .3114 .51863 .31187 .54184 .31199 .5293 .31016 Metetra
.868 .495 0 r
.5293 .31016 .54184 .31199 .56538 .31239 .55302 .30897 Metetra
.895 .406 0 r
.55302 .30897 .56538 .31239 .58924 .31269 .57705 .30748 Metetra
.921 .316 0 r
.57705 .30748 .58924 .31269 .61343 .31248 .60137 .30524 Metetra
.944 .231 0 r
.60137 .30524 .61343 .31248 .63792 .31129 .62597 .30179 Metetra
.962 .16 0 r
.62597 .30179 .63792 .31129 .66266 .30859 .65079 .29659 Metetra
.973 .114 0 r
.65079 .29659 .66266 .30859 .68761 .30377 .67578 .28904 Metetra
.976 .101 0 r
.67578 .28904 .68761 .30377 .71266 .29621 .70083 .27852 Metetra
.968 .133 0 r
.70083 .27852 .71266 .29621 .73773 .28521 .72585 .26436 Metetra
.951 .2 0 r
.01883 .48152 .033 .50176 .05197 .50021 .03736 .48295 Metetra
.969 .128 0 r
.03736 .48295 .05197 .50021 .07161 .49525 .05665 .48077 Metetra
.976 .101 0 r
.05665 .48077 .07161 .49525 .0918 .48748 .07655 .47559 Metetra
.974 .112 0 r
.07655 .47559 .0918 .48748 .1124 .47747 .09694 .46796 Metetra
.964 .151 0 r
.09694 .46796 .1124 .47747 .13333 .46577 .11772 .45842 Metetra
.949 .211 0 r
.11772 .45842 .13333 .46577 .15449 .45286 .1388 .44745 Metetra
.93 .283 0 r
.1388 .44745 .15449 .45286 .17583 .43921 .1601 .43552 Metetra
.909 .359 0 r
.1601 .43552 .17583 .43921 .19727 .42522 .18156 .42303 Metetra
.887 .434 0 r
.18156 .42303 .19727 .42522 .21879 .41125 .20315 .41035 Metetra
.866 .503 0 r
.20315 .41035 .21879 .41125 .24036 .39761 .22482 .39778 Metetra
.846 .564 0 r
.22482 .39778 .24036 .39761 .26197 .38456 .24656 .3856 Metetra
.829 .615 0 r
.24656 .3856 .26197 .38456 .28361 .37231 .26836 .37403 Metetra
.815 .654 0 r
.26836 .37403 .28361 .37231 .30529 .36104 .29022 .36324 Metetra
.804 .683 0 r
.29022 .36324 .30529 .36104 .32703 .35089 .31216 .35337 Metetra
.798 .7 0 r
.31216 .35337 .32703 .35089 .34883 .34193 .33418 .34451 Metetra
.795 .705 0 r
.33418 .34451 .34883 .34193 .37074 .33421 .3563 .3367 Metetra
.798 .7 0 r
.3563 .3367 .37074 .33421 .39277 .32774 .37857 .32996 Metetra
.804 .683 0 r
.37857 .32996 .39277 .32774 .41495 .32249 .40099 .32423 Metetra
.815 .654 0 r
.40099 .32423 .41495 .32249 .43733 .31837 .4236 .31944 Metetra
.829 .615 0 r
.4236 .31944 .43733 .31837 .45992 .31527 .44643 .31547 Metetra
.846 .564 0 r
.44643 .31547 .45992 .31527 .48277 .31301 .4695 .31214 Metetra
.866 .503 0 r
.4695 .31214 .48277 .31301 .50589 .3114 .49284 .30923 Metetra
.887 .434 0 r
.49284 .30923 .50589 .3114 .5293 .31016 .51645 .30648 Metetra
.909 .359 0 r
.51645 .30648 .5293 .31016 .55302 .30897 .54036 .30355 Metetra
.93 .283 0 r
.54036 .30355 .55302 .30897 .57705 .30748 .56455 .30007 Metetra
.949 .211 0 r
.56455 .30007 .57705 .30748 .60137 .30524 .58901 .2956 Metetra
.964 .151 0 r
.58901 .2956 .60137 .30524 .62597 .30179 .61372 .28968 Metetra
.974 .112 0 r
.61372 .28968 .62597 .30179 .65079 .29659 .63861 .28175 Metetra
.976 .101 0 r
.63861 .28175 .65079 .29659 .67578 .28904 .66362 .27124 Metetra
.969 .128 0 r
.66362 .27124 .67578 .28904 .70083 .27852 .68866 .25753 Metetra
.951 .2 0 r
.68866 .25753 .70083 .27852 .72585 .26436 .71361 .23997 Metetra
.923 .31 0 r
.00511 .4574 .01883 .48152 .03736 .48295 .02311 .46198 Metetra
.952 .199 0 r
.02311 .46198 .03736 .48295 .05665 .48077 .04196 .46279 Metetra
.969 .131 0 r
.04196 .46279 .05665 .48077 .07655 .47559 .0615 .4604 Metetra
.976 .102 0 r
.0615 .4604 .07655 .47559 .09694 .46796 .08161 .45534 Metetra
.975 .106 0 r
.08161 .45534 .09694 .46796 .11772 .45842 .10218 .44814 Metetra
.968 .135 0 r
.10218 .44814 .11772 .45842 .1388 .44745 .12312 .43929 Metetra
.956 .181 0 r
.12312 .43929 .1388 .44745 .1601 .43552 .14434 .42925 Metetra
.942 .237 0 r
.14434 .42925 .1601 .43552 .18156 .42303 .16577 .41841 Metetra
.926 .297 0 r
.16577 .41841 .18156 .42303 .20315 .41035 .18738 .40715 Metetra
.91 .356 0 r
.18738 .40715 .20315 .41035 .22482 .39778 .20911 .39577 Metetra
.894 .41 0 r
.20911 .39577 .22482 .39778 .24656 .3856 .23096 .38457 Metetra
.88 .457 0 r
.23096 .38457 .24656 .3856 .26836 .37403 .25289 .37375 Metetra
.869 .495 0 r
.25289 .37375 .26836 .37403 .29022 .36324 .27492 .3635 Metetra
.86 .522 0 r
.27492 .3635 .29022 .36324 .31216 .35337 .29704 .35395 Metetra
.855 .538 0 r
.29704 .35395 .31216 .35337 .33418 .34451 .31926 .34521 Metetra
.853 .544 0 r
.31926 .34521 .33418 .34451 .3563 .3367 .3416 .3373 Metetra
.855 .538 0 r
.3416 .3373 .3563 .3367 .37857 .32996 .36409 .33025 Metetra
.86 .522 0 r
.36409 .33025 .37857 .32996 .40099 .32423 .38674 .324 Metetra
.869 .495 0 r
.38674 .324 .40099 .32423 .4236 .31944 .40959 .31848 Metetra
.88 .457 0 r
.40959 .31848 .4236 .31944 .44643 .31547 .43265 .31354 Metetra
.894 .41 0 r
.43265 .31354 .44643 .31547 .4695 .31214 .45595 .30902 Metetra
.91 .356 0 r
.45595 .30902 .4695 .31214 .49284 .30923 .4795 .30469 Metetra
.926 .297 0 r
.4795 .30469 .49284 .30923 .51645 .30648 .50332 .30026 Metetra
.942 .237 0 r
.50332 .30026 .51645 .30648 .54036 .30355 .52741 .29541 Metetra
.956 .181 0 r
.52741 .29541 .54036 .30355 .56455 .30007 .55176 .28976 Metetra
.968 .135 0 r
.55176 .28976 .56455 .30007 .58901 .2956 .57635 .28287 Metetra
.975 .106 0 r
.57635 .28287 .58901 .2956 .61372 .28968 .60115 .27426 Metetra
.976 .102 0 r
.60115 .27426 .61372 .28968 .63861 .28175 .6261 .26339 Metetra
.969 .131 0 r
.6261 .26339 .63861 .28175 .66362 .27124 .65113 .2497 Metetra
.952 .199 0 r
.65113 .2497 .66362 .27124 .68866 .25753 .67614 .23258 Metetra
.923 .31 0 r
.67614 .23258 .68866 .25753 .71361 .23997 .70101 .21142 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16722 .20421 m
.17181 .2089 L
s
[(-5)] .15804 .19483 .97905 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.53137 .06162 m
.53529 .06688 L
s
[(5)] .52352 .0511 .74541 1 Mshowa
.125 Mabswid
.20145 .19081 m
.20417 .19365 L
s
.23614 .17722 m
.23883 .1801 L
s
.2713 .16345 m
.27395 .16637 L
s
.30694 .1495 m
.30955 .15245 L
s
.37969 .12101 m
.38222 .12403 L
s
.41682 .10647 m
.41931 .10953 L
s
.45447 .09173 m
.45691 .09482 L
s
.49265 .07678 m
.49505 .0799 L
s
.13343 .21744 m
.13622 .22022 L
s
.10009 .2305 m
.10291 .23324 L
s
.06718 .24338 m
.07003 .2461 L
s
.57064 .04624 m
.57294 .04944 L
s
.61047 .03065 m
.61273 .03387 L
s
.65089 .01482 m
.65309 .01808 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oaoooool2
o`0005Oooooo0034ooooo`?o000000?oooooo`000?ooool0E_ooool00<;ooooo0_l00004ooooo`;o
0000E_ooool00;oooooo0ol00006ooooo`03o`000?oooooo000005Gooooo002looooo`?o00002Ooo
ool00ol0003oooooo`00001Eooooo`00^_ooool2o`0000?ooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooool0001Dooooo`00Uoooool3o`0001gooooo0ol0000>ooooo`05o`000?oooooo
ooooooooool00000Doooool009Kooooo00Go0000ooooooooooooooooo`00000Jooooo`;o00004Ooo
ool01?l0003oooooooooooooool2o`0005;ooooo002Jooooo`03o`000?oooooooooo01Gooooo0ol0
000Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0D?ooool009[ooooo00?o0000
ooooooooool04oooool2o`0000;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo04oooooo002Fooooo`Co00004oooool3o`0001Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1?ooooo`00U_ooool00ol0003oooooooooo`0Aooooo`?o
00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04kooooo002Fooooo`Go0000
3Oooool2o`0001oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1=ooooo`00YOoo
ool3o`000003ooooool0003ooooo01kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1=ooooo`00Xoooool2o`0002Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<
ooooo`00X?ooool3o`0002Kooooo00?o0000ooooooooool01Oooool2o`0004gooooo002Nooooo`;o
0000:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04_ooooo002Kooooo`Co0000
:_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04[ooooo002Iooooo`;o00001?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B_oo
ool009Kooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool0
09?ooooo0ol0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0B?ooool0097o
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0B?ooool008kooooo
0ol00003ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02_ooool2o`0004Sooooo
002<ooooo`;o0000>oooool00ol0003oooooooooo`0:ooooo`;o0000B?ooool008Wooooo0ol0000m
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool3o`0003Oooooo0027oooo
o`?o0000?oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00Go0000oooo
ooooooooooooo`00000fooooo`00I?ooool2o`0001kooooo0ol00002ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`Go00001Oooool00ol0
003oooooooooo`0dooooo`00Hoooool01?l0003oooooooooool0000Jooooo`?o0000A_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=?ooool006?o
oooo00Co0000oooooooooooo00006?ooool2o`0004Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`08ooooo`Co0000=oooool006?ooooo00Co0000oooooooooooo00005Oooool3o`00
04_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Sooooo001Sooooo`04o`000?ooooooooooo`0001?ooooo0_l00003ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool03Oooool3o`0000Sooooo1Ol0000fooooo`00Hoooool01?l0003o
ooooooooool0000@ooooo`?o0000D?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
047ooooo001Tooooo`;o00003oooool2o`0005?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`10ooooo`00L_ooool3o`0005Gooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`10ooooo`00Koooool3o`0000?ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo03oooooo001]ooooo`;o0000Foooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo03kooooo001Zooooo`?o0000GOooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo03kooooo001Xooooo`Co0000G_ooool00ol0003oooooooooo`0Cooooo`;o
0000?_ooool006Gooooo0ol00004ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0looooo`00Hoooool2o`0006Gooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0looooo`00H?ooool3o`0006Oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0kooooo`00G_ooool2o`000003ooooool0003ooooo06Oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0jooooo`00Foooool3o`0006cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0jooooo`00F?ooool3o`00073ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0iooooo`00E_ooool2o`0007?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0hooooo`00<oooool3o`0001gooooo0ol00002ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool05_ooool2o`0003[ooooo000booooo`05o`000?oooooooooo
ooooool000006_ooool2o`0007Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0g
ooooo`00;?ooool5o`0000Gooooo00?o0000ooooooooool05Oooool3o`0007[ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0gooooo`00=_ooool00ol0003oooooooooo`0Cooooo`;o
0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Kooooo000booooo`Co0000
4oooool3o`0000;ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo03Gooooo000booooo`03o`000?oooooooooo017ooooo0ol00022ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0=Oooool003;ooooo1Ol0000=ooooo`;o0000QOooool0
0ol0003oooooooooo`0Kooooo`;o0000=Oooool0047ooooo1Ol00025ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0<oooool003oooooo0_l0002:ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0<oooool003cooooo0ol0002<ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0<_ooool003[ooooo0_l0002?ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0<Oooool003Oooooo0ol000000ooooooo0000ooooo`2>ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0<Oooool003Cooooo0ol00005ooooo`03o`000?oooooooooo
08cooooo0_l0000Pooooo`03o`000?oooooooooo033ooooo000booooo`;o0000U_ooool3o`00023o
oooo0_l0000aooooo`00;oooool4o`0009Kooooo00Go0000ona?0?l0003ok4l0o`00000Pooooo`03
o`000?oooooooooo00Oooooo0_l0000Vooooo`00;Oooool2o`0000?ooooo00?o0000ooooooooool0
Toooool01?l0003ok4l0ona?0?o/C`02o`00027ooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool0000Uooooo`00:_ooool3o`0009[ooooo00?o0000ona?0?o/C`000_o/C`02o`0002;o
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Uooooo`00:?ooool2o`0009co
oooo00?o0000ona?0?o/C`000oo/C`000ol0003ok4l0o`00000Qooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00009Oooool002Gooooo1Ol0002Jooooo`;o00001_o/C`000ol0003o
k4l0o`00000Rooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00009Oooool002?o
oooo0_l0002Nooooo`03o`000?oc<P3o000000Kok4l000?o0000ona?0?l000008oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0002Gooooo000Pooooo`?o0000W_ooool2o`0000?o
lc8000?o0000ona?0?o/C`000oo/C`001?l0003ok4l0o`000?l0000Qooooo`;o00001Oooool2o`00
02Kooooo000Mooooo`Co0000Woooool00ol0003olc80oo<b0003oo<b0003o`000?o/C`3ok4l000?o
k4l00_l000000ooc<`3o0000ooooo`0Rooooo`03o`000?oooooooooo02[ooooo000Kooooo`;o0000
0oooool00ol0003oooooooooo`2Looooo`03o`000?oc<P3olc8000Golc8000Co0000ona?0?o/C`3o
k4l00_l00003oo<c0003o`000?oooooooooo027ooooo00?o0000ooooooooool0:Oooool001Sooooo
0ol0002Rooooo`;o00002?oc<P04o`000003oo<c0?l0003olc<000;olc<000?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Yooooo`005oooool2o`000:7ooooo0ol000000ooh8@3o0000oo<b
0005oo<b00?o000000?ok4l0o`000?oc<`000_oc<`001Ol0003olc<0oo<c0?oc<`3o000002?ooooo
00?o0000ooooooooool0:?ooool001Oooooo0ol0002Nooooo`;o00001Ooh8@000ol0003olc80oo<b
0003o`0000;olc800_l00005oo<c0004o`000?oc<`3olc<0o`0002Cooooo00?o0000ooooooooool0
9oooool001Oooooo00Co0000oooooooooooo0000Voooool2o`0000Oon2400ol00003oo<b00;o0000
00?on200o`000?oc<`001Ooc<`000ol0003olc<0o`00000Tooooo`;o0000:?ooool0013ooooo0_l0
0005ooooo`05o`000?ooooooooooooooool00000Uoooool3o`000003ooTJ0?l0003on24000?on240
0ol000000ooh8@3o0000oo<b0002oo<b0003o`000?oh803on20000;on20000?o0000oo<c0?oc<`00
0ooc<`001?l0003olc<0o`000?l0000Tooooo`03o`000?oooooooooo02Kooooo000?ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Booooo`;o
00001Ooi6P04o`0000Con24000Co0000oo<b0?l0003o00001_oh80000ol0003olc<0oo<c0003oo<c
0003o`000?og8P3o000002Gooooo00?o0000ooooooooool09Oooool000oooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo08oooooo0_l00005ooTJ
00Co00001_oh8@02o`0000Son20000Co0000oo<c0?oc<`3olc<00_l000001?og8P3o0000ooLR0?l0
000Tooooo`03o`000?oooooooooo02Gooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo0_l0
0006ooooo`03o`000?oooooooooo08cooooo0_l000001?oi6`3o0000ooTJ0?oi6P03o`0000ConAX0
00?o0000ooPQ0?oh8@000ol00002ooTI0003o`000?oh803on20000Kon20000?o0000oo<c0?l00000
1?og8P000ol0003omb80o`00000Tooooo`03o`000?oooooooooo02Cooooo000?ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`29ooooo`;o0000
1?oi6`02o`0000OonAX00ol00006ooTI0003o`000?oh803on20000Con2000ol00005ooLR0004o`00
0?og8P3omb80o`0002?ooooo00?o0000ooooooooool09?ooool000oooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Gooooo0ol00003ooTK00?o
000000?onA/0o`000?oi6P000ooi6P03o`000003ooTL0?l0003onAT000OonAT000?o0000ooPP0?oh
80000ol00002ooTI0003o`000?og8P3omb8000Comb8000Co0000ooLR0?l0003o00008oooool2o`00
02Cooooo000@ooooo`;o00001?ooool2o`0000Wooooo00?o0000ooooooooool0POooool3o`0000?o
mb800ol00005ooTK0004o`000?oi6P3o0000o`0000GonA`000?o0000ooTI0?oi6@001?oi6@04o`00
00KonAT000?o0000ooLR0?og8P000_og8P03o`000003ooTJ0?l0003ooooo02?ooooo00?o0000oooo
ooooool08_ooool001Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1kooooo`Go
00000oog8P03o`000003ooLR0?l0003onA/000?onA/01?l00008ooTL0003o`000?oi6@3onAT000?o
00000_oi7@000ol0003onAT0ooTI0006ooTI0004o`000?og8P3o0000o`0000;onAX000Co0000ooTJ
0?oi6P3o00008oooool00ol0003oooooooooo`0Rooooo`005Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo07?ooooo1ol00005oo@^00?o00000_og8P07o`0000ComRH000?o0000ooTL
0?oi70001?oi7004o`0000KonAd000?o0000ooTI0?oi6@001?oi6@03o`0000GonAX000Co0000ooTJ
0?oi6P3o00008oooool00ol0003oooooooooo`0Qooooo`005Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo06gooooo1Ol00005oo4l00;o00000_od;P08o`0000GolSH000?o0000ooHV
0?of9P001?of9P000ol0003onA`0ooTL0003o`0000;omRP000?o0000ooTM0?oi7@001_oi7@000ol0
003onAT0ooTI0003o`0000;onA`000?o0000ooTJ0?oi6P001?oi6P000ol0003onAX0o`00000Toooo
o`03o`000?oooooooooo023ooooo000Eooooo`;o00003_ooool00ol0003oooooooooo`1Xooooo`Co
00001?o]C002o`0000?olC`01ol00005oni80003o`000?ob=P3olSH000ColSH000Co0000ooHV0?of
9P3omRH01Ol00006ooHX0003o`000?oi7@3onAd000ConAd01?l00006ooTL0003o`000?oi6P3onAX0
00ConAX00ol0000Sooooo`03o`000?oooooooooo023ooooo000Eooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0Hoooool6o`0000GokD`02?l00003onQK0003o`000?o^B03okTP000;o
kTP03Ol00005oo4k0003o`000?of:03omRP000ComRP000?o0000ooTM0?oi7@000ol00002ooHX0003
o`000?oi703onA`000KonA`000?o0000ooTJ0?oi6P001?l000000ooi6P3o0000ooooo`0Sooooo`;o
00008?ooool001Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Looooo`Ko0000
1?oXF`0Go`0000GoiFL000?o0000on]@0?o[D0001?o[D0001?l0003olC/0oo4k0?oa>`0<o`0000Ko
mRP000?o0000ooTL0?oi70001?oi7004o`0000ConAX000?o0000ooTJ0?l000008oooool2o`00023o
oooo000Eooooo`03o`000?oooooooooo013ooooo0_l0001Fooooo`Ko00001?oTJ00]o`0000GojU@0
0_l00005oo4l0003o`000?of:03omRP000ComRP000?o0000ooTL0?oi70000ol00002ooHV0003o`00
0?oi6P3onAX000ConAX000?o0000ooTJ0?l000008oooool00ol0003oooooooooo`0Nooooo`005?oo
ool00ol0003oooooo`00000Cooooo`03o`000?oooooooooo04kooooo1Ol00003on5d00go00000ol0
6C44o`0000Go010[00Co0000o`0E;_l05Bko01D^;Ol00006ooHV0003o`000?oi6P3onAX000ConAX0
0ol0000Sooooo`03o`000?oooooooooo01gooooo000Dooooo`;o00005Oooool00ol0003ooooooooo
o`1:ooooo`?o00000_oNOP08o`000003o`12BOl0003o000000?o02/m1?l000000ol06C7o0000o`00
0002o`0000;o00lY00Co0000o`0@:ol042_o010[1_l00004o`0>:003o`000?l05Bko01D^00;o01D^
00?o0000o`0P=_l083H00_l083H00ol0003o0351o`0a@@0>o`000003on9a0?l0003ojU@000?ojU@0
00?o0000oo4j0?oa>P001?oa>P000ol0003omRH0ooHV0005ooHV0003o`000?oi6P3onAX000Co0000
00?on240o`000?ooool08oooool00ol0003oooooooooo`0Looooo`005?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo04Kooooo3Ol00002o`12B@;o00000_l0:cd3o`0000?o01/c0ol0
0005o`0?:@Co00001?l02bD01?l0003o00hXo`0>:?l03RP<o`000003o`0P=_l0003o035100?o0351
00?o0000o`1;COl000003_l000000ooZE03o0000oo4j0005oo4j0003o`000?of9P3omRH000;omRH0
1Ol00004ooPQ0003o`000?oh8@3o000002?ooooo00?o0000ooooooooool07?ooool001Cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`12oooooaOo00000_l06c<3o`0000?o010[00?o
0000o`0?:Ol000000_l00003o`098`04o`000?l02bGo00/Uo`0;9@Go00001?l02bD00ol0003o014[
o`0A:`02o`0A:`03o`000?l06c?o01/c00Ko000000?o0351o`000?l0Bdd00_l0Bdd;o`000003on=^
0?l0003o000000_o00001?oc=0000ol0003on240ooPQ0003ooPQ0003o`000?oh8@3o000002?ooooo
0_l0000Looooo`005?ooool3o`0001Oooooo00?o0000ooooooooool0??ooool6o`000003olbc0?l0
003o000000Go00000_l0FTP2o`000004o`19C?l0003o0000o`0a@0;o00000ol083H3o`0000Ko010[
0ol00005o`098`Co00000ol01b400ol0003o00/Uo`0;9@04o`0;9@03o`000?l04B_o014[00;o014[
00?o0000o`0K<ol06c<00ol06c<00ol0003o02/mo`000006o`000003o`1KB?l0003o0000017o0000
00?ok4l0o`000?oc=0001Ooc=0000ol0003on240ooPQ0002ooPQ00Co00008_ooool2o`0000Oooooo
0ol0000Booooo`005?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Oooooo4?l0
0002o`1JB0;o00000_l0BD`01?l0003o0350o`0a@?l00002o`0P=P?o00000ol05Bh00ol0003o010[
o`0@:`03o`0000?o00/U00?o0000o`098ol000000_l00002o`068003o`000?l01b7o00LQ00?o00LQ
00Co0000o`0;9Ol02bGo00/U4?l000000ol0:cgo0000o`14B@02o`14B@Co000000?o05]8o`000?l0
00002_l000001?oKR03o0000onEV0?oUIP0=o`000004ooD/0?l0003omB`0o`0002?ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo0000017ooooo0006ooooo`?o00001?ooool2
o`0000Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0dooooo`;o000000GofX/0
o`000?l0003o0000ol^d000Go`000003o`0P=_l0003o01D^00?o01D^0ol00006o`0;9@;o00001_l0
1R001?l0003o00LQo`078Ol01b45o`0000Co00TS00?o0000o`0?:Ol03bT00_l03bT00ol0003o01Tb
o`0I<P02o`0I<P03o`000?l0:Cco000000;o00001?l0A4T00ol0003o05Q:o`000002o`000003o`1Z
>?l0003o000000ko000000?oiFH0o`000?o^AP001?o^AP000ol0003omB`0ooD/0002ooD/0003o`00
0?oe;03o000002?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`001ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0aoooooa7o000000?o05m4o`000?l000000_l0DTd2o`0000;o03a6
0ol000001?l0:Cco0000o`0P=_l00003o`0E;P;o00000ol03RP00ol0003o00/Uo`0;9@03o`0000;o
00LQ00?o0000o`068?l01R000ol01R04o`0000?o00HP00?o0000o`098ol02B<01?l02B<00ol0003o
00lYo`0?:@02o`0?:@03o`000?l06C;o01Tb00;o01Tb00Co0000o`0Y??l0:Cco02Tl1?l000000ol0
A4Wo0000o`1HBP02o`1HBP;o00000_l0JSP7o`000004ol^e0?l0003o0000o`0000;ogW`01ol00000
0oo^AP3o0000ooD/0003ooD/0003o`000?oe;03o000002?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0?ooooo`001oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0^ooooo`Co000000?oc;<0
o`000?l000002?l000001Ol0KS?o0000o`000?l0GdCo000000;o059=0_l000001?l0?4Ko0000o`00
0?l00004o`0Y?0Co000000?o01D^o`000?l03RP01?l03RP3o`0000Ko00LQ00?o0000o`068?l00000
0_l00002o`057P03o`000?l01R3o00HP00?o00HP00Co0000o`098ol02B?o00TS3?l000000ol06C;o
0000o`0Y?002o`0Y?003o`000?l0@DSo045800Go000000?o05Q:o`000?l000000_l000000ol0NQoo
0000o`000006o`000003ol^e0?l0003o000000?o000000CogW`0o`000?oYF@3ojET02_l0000Roooo
o`03o`000?oooooooooo00;ooooo1?l0000Booooo`001oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo0_l0000Nooooo`03o`000?oooooooooo02[ooooo4?l00002o`1^
<`_o00001?l0:C`2o`0000?o01`d0ol00003o`0>:0;o00000_l02bD00ol0003o00LQo`078@04o`07
8@;o00001_l01Ah01?l0003o00HPo`068?l01R05o`0000?o00/U00?o0000o`0A:ol04B/00_l04B/0
1?l0003o01/co`0K<ol06c<7o`0000?o045800?o0000o`1GBol0Ed/00ol000000ol0Icco0000o`00
0002o`1j7`[o00000_oHT@07o`000007onUI0?l0003olCX0oo4j0?l0003olCX0o`00000Sooooo`05
o`000?ooooooooooooooool000005Oooool000Oooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_oooolGo`00
00?o05U91ol00002o`0Y?003o`000?l073Co01`d00;o01`d00Oo0000o`0E;_l05Bko01D^o`000?l0
3RSo000000Go00/U00?o0000o`078Ol01b400ol00002o`068003o`000?l01Ako00DN00?o00DN1?l0
0002o`078@03o`000?l02bGo00/U00Co00/U00?o0000o`0A:ol04B/00_l04B/00ol0003o01/co`0K
<`02o`0K<`04o`000?l0:cgo02/mo`0[?@Co000000?o0458o`000?l0Ed/00ol0Ed/2o`000005o`1W
??l0003o0000o`000?l0NQl00_l000000ol?T03o0000o`000008o`000004omRA0?l0003oi6`0onA/
00Ko000000?olCX0o`000?ooool08?ooool00ol0003oooooo`000002ooooo`Go00004Oooool000Ko
oooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Sooooo`;o00000_oLQ@0>o`0000;o07@Y00Go0000o`1V?Ol0003o0000o`1IB@03
o`0000;o04a=00?o0000o`0hA?l0>4@00_l0>4@3o`0000?o01`d00?o0000o`0E;_l05Bh00_l05Bh2
o`0000Ko00/U0ol00006o`068003o`000?l01Ako000000;o000000?o00HPo`000?l01b401?l01b40
0ol0003o00/Uo`0;9@03o`0;9@03o`000?l04B_o014[00?o014[00?o0000o`0K<ol06c<00_l06c<0
1Ol0003o02/mo`0[?Ol0:cgo000000;o04A90ol00003o`1GB`03o`000?l0ISgo000000;o000000?o
07LTo`000?l000002_l00002om6T00Go000000?oi6`0o`000?o]B@000_o]B@03o`0002;ooooo00?o
0000ooooooooool05_ooool000Oooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`;o00000_oLQ@0<o`000003o`242ol0003o
000000;o07@Y00?o0000o`1V?Ol000000ol000001Ol0FDWo0000o`1<COl0C4go000000Co03Q400Oo
0000o`0Y??l0:Cco02Tlo`000?l073Co000000Co01D^00Co0000o`0A:ol04B_o00000ol02bD2o`00
00;o00TS00?o0000o`068?l01R001?l01R02o`0000Go00HP00?o0000o`078Ol01b400ol01b401?l0
003o00/Uo`0;9Ol02bD=o`0000Co02/m00?o0000o`14BOl0A4T00_l0A4T3o`000004o`1GBol0003o
06Hmo`1V?@;o00000ol0Mb@4o`0000;o?j401_l000001?oAY03o0000omim0?oNO@03o`0000;okDT0
00Co0000one90?o]B@3o00008_ooool00ol0003oooooooooo`0Eooooo`004_ooool3o`0002;ooooo
00?o0000ooooooooool07Oooool>o`000005oa^D0?l0003o0000o`242ol000000ol0M2T5o`0000;o
05U900Co0000o`1<COl0C4go00000ol0>4@2o`0000Co02Tl0ol00003o`0E;P03o`000?l04B_o014[
00;o014[00?o0000o`0;9Ol000001Ol02B<00ol0003o00HPo`068003o`000003o`078Ol0003o00HP
00Go00HP00Co0000o`078Ol01b7o00LQ1Ol00002o`0>:003o`000?l05Bko01D^00?o01D^00Co0000
o`0P=_l083Ko020f1Ol000000ol0:cgo0000o`14B@02o`14B@03o`000?l0F4[o05Q:00?o00000ol0
ISd3o`000003o`1g9?l0003o000000Co000000Go?j40o`000?l0003o0000olbc0003o`0000CogWd0
1Ol000000oo]B@3o0000ooooo`0Qooooo`03o`000?oooooooooo01Cooooo000Booooo`03o`000?oo
oooooooo02?ooooo0_l0000Jooooo`?o000000?ogWh0o`000?l000001ol00002odbU0003o`000?lK
U03o000000Wo00000ol0HT47o`000003o`0hA?l0003o02Tl00Co02Tl00Oo0000o`0P=_l083Ko020f
o`000?l05Bko000000Go014[0_l00006o`098`?o00001Ol01b400ol0003o00HPo`068003o`0680Co
00000_l02bD00ol0003o00hXo`0>:003o`0>:003o`000?l05Bko01D^00?o01D^00Go0000o`0P=_l0
83Ko020fo`000003o`0a@@Go000000?o04A9o`000?l0F4X00ol0F4X3o`000003o`1V?Ol0003o07LV
00?o00000_l0R@49o`000003olbc0?l0003o000000?o000000?ogWd0o`000?oYE`001Ol0000Poooo
o`03o`000?oooooooooo01Cooooo000Booooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool05?ooool<o`0000;oQ[D000?o0000odbU0?m<Y@001Ol000001?l0OA[o0000o`000?l00002o`1_
<@05o`000?l0HT7o0691o`1R@Ol000000ol0EdX01?l0003o04e>o`1=C_l0CDh2o`0000Co02Tl00?o
0000o`0P=_l083H00_l083H2o`0000Go014[00Co0000o`0?:Ol03bWo00000ol02B<2o`000003o`0;
9Ol0003o00LQ00Go00LQ00?o0000o`068?l01R000ol000000ol02B?o0000o`0;9@04o`0;9@03o`00
0?l03RSo00hX00?o00hX00?o0000o`0E;_l05Bh00ol05Bh01Ol0003o020fo`0P=_l083Ko000000Co
035100?o0000o`1;COl0Bdd00ol00003o`1HBP03o`000?l0Icco06Ll00?o00000ol0MbH2o`0000;o
08T10_l000000olcW@3o0000o`000006o`0000;ofH`01ol000000ooYE`3o0000ooooo`0Nooooo`;o
00005Oooool001;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Aooooo`;o0000
0ooQM0000ol0003oe9d0omBM0002o`0000;oaL<000?o0000ohJe0?n6]@001Ol000000ol6S03o0000
o`000004o`0000;o06la00?o0000o`1R@Ol0HT400_l00003o`1GBP05o`000?l0CDko04e>o`1=C_l0
00000_l0?4H2o`000003o`0Y??l0003o020f00?o020f00Co0000o`0K<ol06c?o00000ol04B/00ol0
003o00lYo`0?:@02o`0?:@03o`000?l02B?o000000Co00/U00?o0000o`078Ol01b400ol01b43o`00
00Go00TS00?o0000o`0;9Ol02bD00ol02bD00ol0003o00hXo`0>:002o`0>:003o`000?l05Bko01D^
00?o01D^00?o0000o`0P=_l083H00_l083H00ol0003o0351o`0a@@02o`0a@@03o`000?l0Bdgo04]=
00;o04]=0_l00002o`1HBP03o`000?l0Icco06Ll00;o06Ll0_l000000ol0MbKo0000o`280`03o`00
0003obbJ0?l0003o000000[o00000_oIS002o`0000;oiFD00ol0000Pooooo`03o`000?oooooooooo
01;ooooo000Booooo`;o0000:?ooool00ol0003oooooooooo`0>ooooo`;o00000ooQM002o`000003
omBM0?l0003o000000?oaL<01_l000000ol`W03o0000o`000002o`0000;o07dJ00Go0000o`1_<Ol0
Kc7o06lao`000002o`1R@@03o`000?l0Ed[o05M:00;o05M:00Go0000o`1=C_l0CDko04e>o`000004
o`0lAP?o00000ol083H00ol0003o01/co`0K<`02o`0K<`03o`000?l04B_o000000Go00lY0_l00006
o`0;9@03o`000?l01b7o000000;o000000?o00/Uo`000?l02B<01Ol02B<01?l0003o00/Uo`0;9Ol0
2bDGo`000003o`0a@Ol0003o04]=00;o04]=00?o0000o`1KB?l000000_l00004o`1W?003o`000?l0
MbCo000000;o00000_l0R0<2o`0000;o;9X00_l00002off^00_o00001?oUI@000ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01;ooooo000Booooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool02oooool4o`0000;ohG@02ol000000omS[03o0000o`00000Ao`0000;o05M:00Go0000
o`1=C_l0CDko04e>o`000004o`0lAP07o`000?l0<D7o0351o`0a@Ol0003o020fo`000005o`0K<`;o
00001Ol03bT00ol0003o014[o`000006o`0;9@;o00001Ol02bD00ol0003o00TSo`098`03o`098`Co
00000ol042/00ol0003o01D^o`0E;P02o`0E;P03o`000?l073Co01`d00?o01`d00?o0000o`0Y??l0
:C`00_l0:C`01?l0003o03a6o`0lA_l0?4H4o`0000;o04]=00Co0000o`1KB?l0FdSo05]80ol00002
o`1W?003o`000?l0MbCo07LT00;o00000ol0R0<2o`0000;o;9X00_l00002off^00;o000000Go^l80
o`000?l0003o0000omFI0006o`000003onEU0?l0003ooooo01kooooo00?o0000ooooooooool04Ooo
ool0017ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`;o00001?oTJ004
o`0000?ob[H00_l000001?nN^`3o0000o`000?mS[006o`0000?o08L500Co0000o`1j8?l0NR3o0000
0ol0KC@01?l0003o06=1o`1S@Ol0Hd44o`000003o`1=C_l0003o03a600?o03a600?o0000o`0a@Ol0
<D400_l0<D42o`0000Go01/c00Co0000o`0I<_l06C;o00000ol03bT01Ol0003o014[o`0A:ol04B_o
000000?o00/U0_l000000ol03RSo0000o`0;9@05o`0;9@03o`000?l02B?o000000;o000000?o00lY
o`000?l042/01Ol042/00ol0003o01D^o`0E;P02o`0E;P03o`000?l073Co01`d00?o01`d00?o0000
o`0Y??l0:C`00_l0:C`00ol0003o03a6o`0lAP02o`0lAP03o`000?l0DTgo000000;o00000ol0FdP0
0ol0003o06Xho`1Z>003o`0000Co07LT0_l000000ol0R0?o0000obZJ0007o`000005ojjo0?l0003o
0000o`000?oAX`000ol000001?oRL03o0000on9`0?oRL003o`0001kooooo00?o0000ooooooooool0
4Oooool0017ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`05ooooo`;o00001?oT
J002o`0000;of90000?o0000olZf0?o:]P000_l00002oijk00Ko00000_lNU@001Ol0003o08L5o`27
1Ol0Q`Go000000;o07XP00Go0000o`1]=?l0KCCo06ddo`000003o`1S@@03o`000?l0FDSo05U800;o
05U80_l00003o`0lAP03o`000?l0<D7o035100;o035100Co0000o`0[?Ol0:cgo00000ol06c<00ol0
003o01Tbo`0I<P02o`0I<P03o`000?l03bWo000000Go014[00?o0000o`0;9Ol000001?l03RP00ol0
003o00/Uo`0;9@03o`0;9@;o00001Ol03bT00ol0003o010[o`0@:`04o`0@:`03o`000?l05Bko01D^
00;o01D^00?o0000o`0L=?l073@00_l073@00ol0003o02Tlo`0Y?003o`0Y?003o`000?l0?4Ko03a6
00;o03a600Co0000o`1BCOl0DTgo059=0ol000000ol0FdSo0000o`1Z>003o`1Z>0;o00000_l0Mb@0
0ol0003o08T1o`000002o`0000?o:YX00_l000000omU[03o0000o`000002ojjo00;o00000_oAX`03
o`0000CohW0000?o0000ooooooooool07Oooool2o`00017ooooo000Aooooo`;o0000;Oooool00ol0
003oooooooooo`02ooooo`Co00000_oTJ002o`0000?of9002_l00002od^T0004o`000?lNU@3o7YD0
o`0000?o08L500Co0000o`1j8?l0NR3o00000ol0KC@01Ol0003o06=1o`1S@Ol0Hd7o000000Co05U8
00Ko0000o`1BCOl0DTgo0000o`0lA_l00004o`0a@@03o`000?l0:cgo02/m00;o02/m00?o0000o`0K
<ol000001Ol06C82o`0000Ko014[0_l00006o`0>:003o`000?l02bGo000000;o000000?o010[o`00
0?l03bT01Ol03bT00ol0003o010[o`0@:`03o`0@:`03o`000?l05Bko01D^00;o01D^00?o0000o`0L
=?l073@00_l073@00ol0003o02Tlo`0Y?003o`0Y?003o`000?l0?4Ko03a600;o03a600Go0000o`1B
COl0DTgo059=o`000002o`1P@`?o00000ol0JSP01_l0003o07XOo`000?l0003o07LTo`0000;o08T1
0_l00004obZJ00;o000000?oIJ`0o`000?l000000_n^_`03o`000003om6S0?l0003o000000?o0000
00?ohW00o`000?ooool07Oooool2o`00017ooooo000Aooooo`03o`000?oooooooooo02gooooo00Co
0000ooooool0003o00001?oXF`09o`0000;o^l801Ol00002od^T0004o`000?lNU@3o7YD0o`0000?o
08L500Co0000o`1j8?l0NR3o00000ol0KC@01Ol0003o06=1o`1S@Ol0Hd7o000000Co05U800?o0000
o`1BCOl0DTd00_l0DTd2o`0000?o035100?o0000o`0[?Ol0:cd00ol0:cd2o`0000Go01Tb00?o0000
o`0K<ol000001Ol04B/00ol0003o01D^o`000006o`0>:0;o00001Ol042/00ol0003o00lYo`0?:@03
o`0?:@04o`000?l042_o010[o`0@:aSo00001?l0DTd00ol0003o0613o`1P@`02o`1P@`?o000000Co
06Xho`000?l0NQoo07XO0_l00004o`290@;o00000_lZVP000ol0003oHZ/0o`000006o`000003olnZ
0?l0003o000000;o00000_oONP03o`0001kooooo00?o0000ooooooooool03oooool0017ooooo00?o
0000ooooooooool0;Oooool2o`0000Coj5/00_l00004omf00003o`000?o@YP3o000000Go000000?o
Ok<0o`000?m;Y0000_m;Y00Ao`000003o`1S@Ol0003o05U800?o05U800?o0000o`1BCOl0DTd00_l0
DTd01_l0003o04]=o`1;COl0003o0351o`0000Go02/m00Co0000o`0Y??l0:Cco00000ol06C801Ol0
003o01/co`0K<ol06c?o000000?o014[00Go0000o`0E;_l05Bko01D^o`000003o`0>:0;o000000?o
01D^o`000?l042/01Ol042/00ol0003o00lYo`0?:@02o`0?:@Co00000ol06c<00ol0003o020fo`0P
=P02o`0P=P03o`000?l0:Cco02Tl00;o02Tl00?o0000o`0hA?l0>4@00ol0>4@01?l0003o04e>o`1=
C_l0CDh4o`0000;o059=00Go0000o`1P@ol0H4?o0613o`000002o`1_<P?o00000ol0NQl2o`0000;o
08T100Ko0000obbJ0?l0003o0000obZJ0?l00002of:[00;o00000_nV_@02o`0000?ocjX01?l00002
ommj0003o`000?oooooooooo01cooooo00?o0000ooooooooool03_ooool0017ooooo00?o0000oooo
ooooool0:oooool4o`0000;oj5/00_l00004omf000;o000000God:H0o`000?l0003o0000ok_2000:
o`0000?o5Y8000Go0000o`252?l0Q@So08D8o`000003o`1j8004o`000?l0Kc7o06lao`1_<@?o0000
0_l0FDP00ol0003o059=o`1BC@02o`1BC@03o`000?l0Bdgo04]=00;o04]=0_l00003o`0[?@;o0000
1?l0:C`00ol0003o01Tbo`000005o`0K<`03o`000?l04B_o000000Go01D^00?o0000o`0>:?l00000
1?l05Bh00ol0003o010[o`0@:`03o`0@:`03o`000?l03bWo000000;o000000?o01Tao`000?l06c<0
1Ol06c<00ol0003o020fo`0P=P02o`0P=P03o`000?l0:Cco02Tl00;o02Tl00?o0000o`0hA?l0>4@0
0ol0>4@01Ol0003o04e>o`1=C_l0CDko000000;o05U80ol00004o`1P@`03o`000?l0Kc;o06lb00;o
06lb0_l000000ol0NQoo0000o`B;0004o`0000;o;9X00_l00004of:[00;o00000_nV_@02o`0000;o
cjX000?o0000omf10?oMP@001?l0000Nooooo`03o`000?oooooooooo00gooooo000Aooooo`03o`00
0?oooooooooo02[ooooo00?o0000one<0?o]C0000_o]C005o`0000;ogH002_l00003of^^0004o`00
0?llX03o?:00o`0000?o5Y8000Go0000o`252?l0Q@So08D8o`000003o`1j8005o`000?l0Kc7o06la
o`1_<Ol000000ol0Ic`3o`0000?o059=00?o0000o`1;COl0Bdd00_l0Bdd01_l0003o04A9o`14BOl0
003o02/mo`0000Ko02Tl0_l00006o`0K<`;o00001_l05Bh2o`0000Ko01D^00?o0000o`0@:ol042/0
0_l042/2o`0000Go01Ta00?o0000o`0K<ol06c<00ol06c<00ol0003o020fo`0P=P03o`0P=P03o`00
0?l0:Cco02Tl00;o02Tl00?o0000o`0hA?l0>4@00_l0>4@00ol0003o04e>o`1=CP02o`1=CP03o`00
0?l0FDSo05U800;o05U80ol00002o`1P@`06o`000?l0Kc;o06lbo`1_<_l0003o07lF0ol00003o`B;
00;o00000ol/VP02o`0000;oHZ/000?o0000oj>l0?l000001ol00004omf100;o00007Oooool00ol0
003oooooooooo`0=ooooo`004?ooool3o`0002Wooooo0_l00004one<0003o`000?oSK`3ohfl000?o
hfl01?l00003olZg0004o`000?nQ_03oXK`0o`0000?oJjh000Co0000ocbP0?llX03o00000olFTP00
1Ol0003o08D8o`252?l0Q@So000000?o07XP00Go0000o`1_<Ol0Kc7o06lao`000004o`1W?006o`00
0?l0H4?o0613o`000?l0DTgo00001?l0Bdd00ol0003o04A9o`14B@02o`14B@03o`000?l0:Cco02Tl
00Co02Tl00?o0000o`0[?Ol000001Ol06c<00ol0003o020fo`000005o`0E;P03o`000?l073Co0000
00Ko01D^00?o0000o`0@:ol000000_l000000ol06c?o0000o`0I<@04o`0I<@03o`000?l06c?o01/c
00?o01/c00?o0000o`0P=_l083H00ol083H00ol0003o02Tlo`0Y?002o`0Y?003o`000?l0>4Co03Q4
00;o03Q400?o0000o`1=C_l0CDh00_l0CDh00ol0003o05U8o`1IB002o`1IB003o`000?l0Icco06Ll
00?o00001?l0Kc800ol0003o07lFo`1o5P02o`0000Co18/00_l000000ol/VP3o0000ofF/0004o`00
00?oXk`00_l00002olf^00;o00001?oMP@000ol0003oooooooooo`0Kooooo`;o00003_ooool00003
ooooool0003o000000?o00000oooool2o`0000Gooooo00?o0000ooooooooool0:?ooool00ol0003o
kD`0one<0003one<0004o`000?oSK`3ohfl0on=_00?o000000?oei@0o`000?l000000_o:]`02o`00
00;oXK`000Go0000of^^0?m[[P3oJjh0o`000002ocbP0005o`000?lFTP3o5Y80oaJB0?l000000ol0
Q@P01Ol0003o07XPo`1j8?l0NR3o000000?o06la00?o0000o`1W??l0Ic`00_l0Ic`01?l0003o0613
o`1P@ol0H4<3o`0000?o04]=00?o0000o`14BOl0A4T00_l0A4T00ol0003o0458o`000003o`0Y?0;o
00000ol0:cd01Ol0003o01/co`0K<ol06c?o000000?o020f00Go0000o`0E;_l05Bko01D^o`000003
o`0L=003o`000?l05Bko01D^00?o01D^0_l00005o`0K<`03o`000?l06C7o01Ta00?o01Ta00?o0000
o`0K<ol06c<00ol06c<00ol0003o020fo`0P=P0<o`000003o`0hA?l0003o04e>00?o04e>00?o0000
o`1IB?l0FDP00_l0FDP00ol0003o06Llo`1W?002o`1W?0?o00000_l0Kc801?l0003o07lFo`1o5_l0
OaH2o`0000;o18/000?o0000oc>M0?l000000_l00003ofF/00;o00001?nS_002o`0000;ocJh00ol0
0002omf10003o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Kooooo
1Ol00002one<0003o`000?oSK`3ohfl000?o00000_oGU0001Ol0003ob[L0olZg0?o:]`3o000000?o
XK`000Co0000of^^0?m[[P3oJjh03_l000000ol0NR3o0000o`1_<@02o`1_<@03o`000?l0Icco06Ll
00;o06Ll00Go0000o`1P@ol0H4?o0613o`000003o`1KB003o`000?l0Bdgo000000Co04A900Oo0000
o`11B?l0@DSo0458o`000?l0:Cco000000Ko02/m00?o0000o`0K<ol000001Ol083H00ol0003o01D^
o`000005o`0L=003o`000?l05Bko01D^00;o000000?o020fo`000?l06c<01?l06c<00ol0003o01Ta
o`0I<@03o`0I<@04o`000?l06c?o01/co`0K<`Go00000ol0<D000ol0003o03a6o`0lAP02o`0lAP04
o`000?l0C4go04a=o`1<C@Go000000?o04e>o`000?l0FDP01?l0FDP01Ol0003o06Llo`1W??l0Icco
000000;o07DW0ol00003o`1o5P06o`000?l?T03o0000o`000?l4R`3o00000_lcW@02o`0000CoIJ`0
0_l00002oj>l0003o`000?o=/03o000000;o00000_oLQ@03o`0001kooooo00?o0000ooooooooool0
2oooool000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo02?ooooo0ol00005oo4l01Oo000000GoHZ/0o`000?lhWP3o>9h0o`000004oaJB0004
o`000?l0Q`Co08L4o`2710Ko00000ol0Ic`01Ol0003o0613o`1P@ol0H4?o000000Go05]80_l00003
o`14B@03o`000?l0@DSo045800?o045800?o0000o`0[?Ol0:cd01Ol0:cd2o`0000Ko020f0_l00006
o`0L=003o`000?l05Bko000000Co020f00?o0000o`0K<ol06c<00ol06c<00ol0003o01Tao`0I<@02
o`0I<@Co00000_l0:cd00ol0003o0350o`0a@004o`0a@003o`000?l0?4Ko03a600;o03a600Go0000
o`1<COl0C4go04a=o`000003o`1GBPKo000000?o05U8o`000?l0Ic`00ol0Ic`00ol0003o07DWo`1e
9`02o`1e9`;o00000_l0OaH00ol0003o3i00o`n@0002o`0000Co<id00_l00002ofF/0006o`000?nV
_@3o0000o`000?nS_03o00000_o=/002o`0000Cog8D000?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0:ooooo`001?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool00_ooool2o`00027ooooo0ol00006oo4l00Co000000?oj5/0o`000?oNOP000_oNOP001Ol0003o
dZ80om:R0?oBXP3o000000CoaL8000Go0000oi:h0?nB^03oT[P0o`000002of:[0004o`000?lhWP3o
>9h0o`0000Co5Y8000Go0000o`271?l0Q`Co08L4o`000003o`1m6@06o`000?l0MBOo07DWo`000?l0
Icco00000ol0H4<00ol0003o05]8o`1KB003o`1KB006o`000?l0F4[o05Q:o`000?l0A4Wo00001_l0
@DP00ol0003o02/mo`0[?@04o`0[?@03o`000?l0<D7o000000Go020f00?o0000o`0Y??l000001_l0
73@2o`0000Go020f00?o0000o`0K<ol06c<00ol06c<00ol0003o01Tao`000002o`000003o`0Y??l0
003o02/m00Co02/m00?o0000o`0a@?l0<D000ol0<D000ol0003o03a6o`0lAP02o`0lAP03o`000?l0
C4go04a=00;o04a=00?o0000o`1GB_l0EdX00_l0EdX01?l0003o06=1o`1S@Ol0Hd45o`0000;o06Ll
00Ko0000o`1e9ol0MBOo07DWo`000?l0Q@T2o`000003o`1o5_l0003o3i0000;o3i000_l00002oc>M
0006o`000?m][P3o0000o`000?mU[03o00000_nV_@02o`0000CocK000ol00002omb50003o`000?oo
oooooooo01[ooooo0ol0000;ooooo`0000?oooooo`000?ooool00_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool2o`0000?om2h00ol0
00001?oa?03o0000o`000?l00002onQK00;o00000ooNOP001Ol0003odZ80om:R0?oBXP3o000000Co
aL8000Go0000oi:h0?nB^03oT[P0o`000002of:[0004o`000?lhWP3o>9h0o`0000Co5Y8000Go0000
o`271?l0Q`Co08L4o`000003o`1m6@03o`000?l0MBOo07DW00;o07DW0ol000000ol0H4?o0000o`1K
B004o`1KB003o`000?l0F4[o05Q:00;o05Q:00?o0000o`11B?l0@DP01?l0@DP00ol0003o04A9o`00
0003o`0[?@;o00000ol0<D401Ol0003o020fo`0P=_l083Ko000000?o02Tl00?o0000o`0L=?l073@0
0_l073@00ol0003o02Tlo`000006o`0P=P03o`000?l06c?o01/c00;o01/c0_l00005o`0Y?003o`00
0?l0:cgo02/m00;o02/m00?o0000o`0a@?l0<D000ol0<D000ol0003o03a6o`0lAP03o`0lAP05o`00
0?l0C4go04a=o`1<COl000001Ol0EdX00ol0003o06=1o`1S@@02o`1S@@03o`000?l0Kc7o06la00?o
00001?l0MBL00ol0003o08D9o`252@02o`0000?o3i0000Ko0000ocnQ0?l0003o0000oc>M0?l00002
off^00;o00001?nV_@03o`000004olf`0?l0003o0000om^600Co00006?ooool3o`0000;ooooo00?o
0000ooooooooool02Oooool00003ooooool0003ooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01Ol0003ooooooooooooooooo0000023ooooo00?o0000oo@^0?od;P001?od;P05o`0000;oj5/0
00?o0000omin0?oNOP000_oNOP001Ol0003odZ80om:R0?oBXP3o000000CoaL8000Go0000oi:h0?nB
^03oT[P0o`000002of:[0004o`000?lhWP3o>9h0o`0000Co5Y8000Go0000o`271?l0Q`Co08L4o`00
0003o`1m6@03o`000?l0MBOo07DW00;o07DW00Co0000o`1_<_l0Kc;o06lb0_l00004o`1KB003o`00
0?l0F4[o05Q:00?o05Q:00?o0000o`11B?l0@DP00ol0@DP01ol0003o04A9o`14BOl0A4Wo0000o`0[
?Ol000001_l0<D400ol0003o020fo`000005o`0Y?004o`000?l073Co01`do`0000?o02Tl00?o0000
o`0P=_l083H00ol083H00ol0003o01/co`000002o`000003o`0[?Ol0003o02Tl00Co02Tl00?o0000
o`0[?Ol0:cd00ol0:cd00ol0003o0350o`0a@003o`0a@003o`000?l0?4Ko03a600;o03a600?o0000
o`1<COl0C4d00_l0C4d00ol0003o05M:o`1GBP02o`1GBP03o`000?l0Hd7o06=100?o06=100?o0000
o`1_<Ol0Kc400_l0Kc42o`0000;o07DW00?o0000o`252Ol0Q@T00_l0Q@T2o`0000;o3i0000?o0000
ocnQ0?loX@000_l00004off^00;o00000_nV_@000ol0003ocJh0olf^0004o`0000?ofhH00_l0000D
ooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`000_ooool3o`0000Cooooo0_l00004oooo
o`03o`000?oooooooooo01cooooo0ol00003oo@^00Co00001?o^B004o`0000;ogWh000Go0000om:R
0?oBXP3odZ80o`000004olG20004o`000?nB^03oT[P0oi:h00Wo00000_lFTP001Ol0003o08L4o`27
1?l0Q`Co000000?o07dI00?o0000o`1e9ol0MBL00_l0MBL00ol0003o06lbo`1_<P02o`1_<P06o`00
0?l0JSSo0000o`000?l0FdSo00001Ol0F4X00ol0003o05M;o`000003o`11B003o`000?l0A4Wo04A9
00?o04A900?o0000o`0a@Ol0<D401Ol0<D42o`0000Ko02Tl00?o0000o`0L=?l000001?l0:C`00ol0
003o020fo`0P=P03o`0P=P;o00001Ol0:cd00ol0003o02Tlo`0Y?003o`0Y?003o`000?l0:cgo02/m
00;o02/m00Co0000o`0a@?l0<D3o03503Ol00005o`1GBP03o`000?l0Hd7o06=100;o06=100?o0000
o`1_<Ol0Kc400_l0Kc400ol0003o07dIo`000002o`0000Co08D900Ko0000oajE0?l0003o0000o`n@
0?l00003ocnQ00;o00000_m][P000ol0003o[[l0o`000003o`0000CocJh01?l000000ooKQP3o0000
ooooo`0@ooooo`?o00002?ooool00ol0003oooooooooo`09ooooo`003oooool00ol0003ooooooooo
o`0Jooooo`;o00000oog8P05o`0000GokTP000?o0000onEW0?oUI`000_oUI`0@o`000003ohjg0?l0
003oHj/000;oHj/000?o0000ocjP0?lnX0002?l000000ol0OAWo0000o`1e9`03o`1e9`03o`000?l0
Kc;o06lb00;o06lb00?o0000o`1Z>?l0JSP00_l0JSP00ol0003o05Q:o`1HBP03o`1HBP07o`000?l0
Ed_o05M;o`1GBol0003o0458o`000005o`14B@;o00001_l0<D400ol0003o03a6o`000006o`0Y?0;o
00001Ol0:C`01?l0003o020fo`0P=_l083H2o`000003o`0a@?l0003o02/m00Go02/m00?o0000o`0Y
??l0:C`00_l0:C`01?l0003o02/mo`0[?Ol0:cd5o`0000;o04U<00?o0000o`1BCOl0DTd00ol0DTd0
1?l0003o05U9o`1IBOl0FDT5o`000003o`1GB_l0003o06=100?o06=100?o0000o`1_<Ol0Kc400ol0
Kc401?l0003o07dIo`1m6Ol0OAT2o`0000?o08D900?o0000oajE0?lNU@000_l00003ocnQ0003o`00
0?mi/P3o000000?o00000on^_`02o`0000CocJh000?o0000omb50?oLQ@000ol0000<ooooo`Co0000
3?ooool00ol0003oooooooooo`08ooooo`003oooool2o`0001Wooooo0_l00002ooLR00?o000000Co
mb80o`000?l0003o00001?o^B002o`0000CoiFL000Go0000omZ90?oJR@3ofXT0o`000004olnZ0005
o`000?no``3o_l<0oko30?l000000on>]`001Ol0003oHj/0of>[0?mSZ`3o000000;o?Z0000?o0000
oanF0?lOUP000_lOUP001?l0003o28d0o`R=0?l8S@03o`0000;o07DW00?o0000o`1_<_l0Kc800_l0
Kc800ol0003o06Xho`1Z>002o`1Z>003o`000?l0Icco000000?o05Q:00?o0000o`1GBol0Ed/00ol0
Ed/00ol0003o04A9o`14B@03o`14B@04o`000?l0Bdgo04]=o`0000?o03510_l00003o`0lAP03o`00
0?l0:Cco02Tl00;o02Tl00?o0000o`0hA?l000001_l0:C`3o`0000Co035000?o0000o`0[?Ol0:cd0
0ol0:cd01?l0003o02Tlo`0Y??l0:C`5o`0000;o049900?o0000o`19C?l0BD`00ol0BD`00ol0003o
059=o`1BC@03o`1BC@05o`000?l0FDWo05U9o`1IBOl000000ol0HT46o`000003o`1S@Ol0003o06la
00?o06la00Ko0000o`1m6Ol0OAWo07dIo`000?l8S@02o`000003o`252Ol0003o7YD000?o7YD00_l0
0002ocnQ0004o`000?mi/P3oNK80ogVb00;o00001?n^_`03o`000003olf^0?l0003o000000Cog8D0
00?o0000ooooooooool01_ooool3o`00013ooooo00?o0000ooooooooool02?ooool000oooooo00?o
0000ooooooooool05_ooool6o`0000;omb800_l00003oo8f00;o000000?okTP0o`000?oUI`000ooU
I`02o`0000?ofXT000?o0000olnZ0?o?ZP000_o?ZP001Ol0003o_l<0oko30?no``3o000000?oS[L0
00Go0000of>[0?mSZ`3oHj/0o`000002ocjP0003o`000?lOUP3o7iH000;o7iH000?o0000o`R=0?l8
S@000_l8S@000ol0003o08D9o`252@03o`0000?o06lb00?o0000o`1Z>?l0JSP00_l0JSP01ol0003o
06Llo`1W??l0Icco0000o`1HB_l000001Ol0Ed/00ol0003o05Q:o`000003o`14B@03o`000?l0Bdgo
04]=00;o04]=00?o0000o`0a@Ol000001Ol0?4H00ol0003o02Tlo`0Y?002o`0000?o03Q400?o0000
o`0Y??l0:C`00_l0:C`2o`0000Ko035000?o0000o`0[?Ol0:cd00ol0:cd4o`0000;o041800?o0000
o`12BOl0@TT00ol0@TT00ol0003o04U<o`19C002o`19C003o`000?l0DTgo059=00?o059=00?o0000
o`1IBOl0FDT00_l0FDT00ol0003o0691o`1R@@02o`1R@@04o`000?l0KCCo06ddo`1]=0Co00000_l0
Kc400ol0003o07dIo`1m6@02o`1m6@03o`000?l8S@3o28d000;o00001?lNU@001_l0003oD:H0o`00
0?l0003o?j40o`0000CoNK800_l00002ojjo0003o`000?o?ZP3ocjX000?o00001?oLQ@000ol0003o
ooooooooo`03ooooo`?o00004oooool00ol0003oooooooooo`08ooooo`003oooool00ol0003ooooo
ooooo`0Cooooo`So000000?omb80o`000?l000001_ob=P04o`0000;oiFL000?o0000omZ90?oJR@00
0_oJR@000ol0003ocjX0olnZ0002olnZ0005o`000?no``3o_l<0oko30?l000000on>]`001Ol0003o
Hj/0of>[0?mSZ`3o000000;o?Z0000?o0000oanF0?lOUP000_lOUP000ol0003o28d0o`R=0002o`R=
0005o`000?l0Q@Wo08D9o`252Ol000000_l0OaH00ol0003o06lbo`000004o`1Z>003o`000?l0Icco
06Ll00?o06Ll00?o0000o`1GBol0Ed/00ol0Ed/01ol0003o05Q:o`1HB_l0F4[o0000o`14BOl00000
1_l0Bdd00ol0003o03a6o`0lAP04o`0lAP03o`000?l0:Cco000000Go03Q400?o0000o`0Y??l0:C`0
0_l000000ol0?4Ko0000o`0a@005o`0a@004o`000?l0:cgo02/mo`0[?@;o000000?o0499o`000?l0
@4P01?l0@4P00ol0003o0499o`12B@02o`12B@03o`000?l0BDco04U<00?o04U<00?o0000o`1BCOl0
DTd00_l0DTd00ol0003o05U9o`1IB@02o`1IB@03o`000?l0HT7o069100?o069100Go0000o`1]=?l0
KCCo06ddo`000002o`1j80Co00000ol0OAT00ol0003o28d0o`R=0002o`R=00;o00000olNU@000ol0
003oD:H0oe2V0002o`0000CoNK8000Ko0000ok_20?l0003o0000ojjo0?l00004olnZ00?o00000_oL
Q@000ol0003oooooo`000002o`0001Kooooo00?o0000ooooooooool02?ooool000kooooo1Ol0000>
ooooo`Co000000?onA/0o`000?l000001?oi6`03o`0000GolSH00_l00004on]@00Wo00000_o?ZP00
1Ol0003o_l<0oko30?no``3o000000?oS[L000Go0000of>[0?mSZ`3oHj/0o`000002ocjP0003o`00
0?lOUP3o7iH000;o7iH000?o0000o`R=0?l8S@000_l8S@001Ol0003o08D9o`252Ol0Q@Wo000000Co
07lF0_l00003o`1Z>003o`000?l0Icco06Ll00Co06Ll0_l00003o`1GB`03o`000?l0F4[o05Q:00?o
05Q:00?o0000o`1;COl0Bdd01?l0Bdd2o`0000Ko03a60_l00006o`0hA003o`000?l0:Cco000000Co
03a600?o0000o`0a@?l0<D001?l0<D03o`0000?o049900?o0000o`10B?l0@4P00ol0@4P00ol0003o
0499o`12B@03o`12B@03o`000?l0BDco04U<00;o04U<00?o0000o`1BCOl0DTd00ol0DTd00ol0003o
05U9o`1IB@02o`1IB@03o`000?l0HT7o069100;o069100?o0000o`1]=?l0KC@00_l0KC@00ol0003o
07XPo`1j8002o`1j80?o00000_l0OAT01_l0003o28d0o`R=0?l8S@3o0000oc:L00?o000000?o7YD0
o`000?m@YP000_m@YP03o`0000;oNK8000?o0000ok_20?nk`P000_l00004olnZ00;o000000?ogH40
o`000?l000000_l0000Iooooo`03o`000?oooooooooo00Sooooo000>ooooo`;o00000oo/C`05o`00
00Cooooo1Ol00002ooTJ00Co00000ooi6`02o`0000?omRH00ol000000oob=P3o0000on]@0004on]@
0003o`000?oSK`3ohfl000;ohfl000?o0000omV>0?oISP000_oISP0Co`0000;o7iH000?o0000o`R=
0?l8S@000_l8S@001Ol0003o08D9o`252Ol0Q@Wo000000Go07lF00Go0000o`1j7ol0003o06Xho`00
0006o`1W?006o`000?l0ISgo06Hmo`000?l0Ed_o00001_l0F4X00ol0003o04]=o`1;C@03o`1;C@04
o`000?l0DTgo059=o`0000Co03a600?o0000o`1=C_l000001_l0>4@2o`0000Ko03a600?o0000o`0a
@?l0<D000_l0<D02o`0000Ko049900?o0000o`10B?l0@4P00ol0@4P00ol0003o0499o`12B@02o`12
B@03o`000?l0BDco04U<00;o04U<00Co0000o`1BCOl0DTgo059=1_l000000ol0FDWo0000o`1R@@04
o`1R@@05o`000?l0KCCo06ddo`1]=?l000001?l0NR000ol0003o08L4o`271003o`0000Co28d000Co
0000oc:L0?lbW03o<Y`00_l00003oe2V0003o`000?n;]`3oRkL000?o00001?nk`P03o`0000;ocjX0
00?o0000omf10?oMP@000_oMP@02o`0001Sooooo00?o0000ooooooooool02?ooool000kooooo00?o
0000ooooool000000oo/C`001?l0003olc80oo<b0?oc<P04o`0000?on2401?l00004ooTJ0003o`00
0?oi6`3o000000OomRH00ol00004on]@0003o`000?oSK`3ohfl000;ohfl000?o0000omV>0?oISP00
0_oISP001Ol0003ocZ`0olj/0?o>[03o000000?o`<<000?o0000oiBi0?nD^@000_nD^@001Ol0003o
KJh0off^0?m][P3o000000;oCJD01?l00002o`R=0005o`000?l0Q@Wo08D9o`252Ol000001Ol0OaH0
1?l0003o07XOo`1j7ol0NQl2o`0000Go06Ll00?o0000o`1V?Ol0ISd00_l0ISd00ol0003o05Q:o`1H
BP04o`1HBP03o`000?l0FdSo000000?o04]=00?o0000o`1BCOl0DTd00_l0DTd01?l0003o03a6o`0l
A_l00003o`1=CP03o`000?l0>4Co03Q400;o03Q400?o0000o`1<COl000001_l0?4H00ol0003o0350
o`000002o`000003o`19C?l0003o049900Go049900?o0000o`10B?l0@4P00ol0@4P01?l0003o0499
o`12BOl0@TT:o`0000;o05m400Co0000o`1V?Ol0ISgo06Hm1_l000000ol0HT7o0000o`1]=003o`1]
=003o`000?l0NR3o07XP00;o07XP00?o0000o`271?l0Q`@00_l0Q`@3o`0000;o28d000?o0000oc:L
0?lbW0000_lbW003o`000003oe2V0?l0003oRkL000?oRkL00_l00002ok_20003o`000?oAX`3odJ<0
00Co00001?oMP@000ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo000>ooooo`03
o`000?oooooo000000Cok4l000?o0000oo<b0?oc<P000_oc<P000ol0003on240ooPQ0004o`0000Ko
nAX00ol00006ooHV0004o`000?oa>`3olC/0oo4k00;o000000?oje00o`000?oSK`000ooSK`001?l0
003ofHh0omV>0?oISP02o`0000?ocZ`000Go0000ol330?o0``3o`<<0o`000004oiBi0005o`000?m]
[P3oKJh0off^0?l000001?m=Y@000ol0003o<Y`0oc:L0004o`000003o`252Ol0003o07lF00Co07lF
00?o0000o`1j7ol0NQl00_l0NQl00ol0003o07LTo`000003o`1W?003o`000?l0ISgo06Hm00?o06Hm
00?o0000o`1HB_l0F4X00ol0F4X01ol0003o05]8o`1KB?l0FdSo0000o`1;COl000001Ol0DTd00ol0
003o03a6o`000005o`1=CP04o`000?l0>4Co03Q4o`0000?o04a=00?o0000o`0lA_l0?4H00ol0?4H2
o`0000Go04U<00?o0000o`12BOl0@TT00ol0@TT00ol0003o0418o`10B003o`10B0Co00000_l0EdX0
0ol0003o05Y8o`1JB002o`1JB003o`000?l0GdCo05m400?o05m400?o0000o`1V?Ol0ISd00_l0ISd0
1?l0003o06lao`1_<Ol0Kc47o`0000Co07XP00?o0000o`271?l0Q`@00_l0Q`@00ol0003o7iH0oanF
0003o`0000Co<Y`000?o0000ofJ]0?mV[@000ol00003oh^g0003o`000?o6`03o000000?o00001?oA
X`04o`0000;ogH4000?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`003_ooool0
1?l0003oooooooooool00003ona?0003o`000?oc<P3olc8000;olc800ol00004ooPQ0003o`000?oi
6P3onAX000?o00000ooi70001?l0003omRH0ooHV0?of9P02o`0000GolC/01?l00002on=_0005o`00
0?oISP3ofHh0omV>0?l000001?o>[0001Ol0003o`<<0ol330?o0``3o000000CoU;T000Go0000off^
0?m][P3oKJh0o`000004odfU0005o`000?lbW03o<Y`0oc:L0?l000000olNU@02o`0000Co07lF00?o
0000o`1j7ol0NQl00_l0NQl01ol0003o07LTo`1g9?l0MbCo0000o`1W??l000001Ol0ISd00ol0003o
06Llo`000003o`1HBP03o`000?l0FdSo05]800?o05]800?o0000o`1BCOl0DTd01Ol0DTd00ol0003o
04e>o`1=CP04o`1=CP03o`000?l0>4Co000000Co04a=00?o0000o`0lA_l0?4H00_l0?4H00ol0003o
059=o`000005o`19C003o`000?l0@TWo049900Co049900?o0000o`10B?l000000_l000000ol0ET_o
0000o`1GBP04o`1GBP03o`000?l0FTSo05Y800;o05Y800?o0000o`1OA?l0Gd@00_l0Gd@00ol0003o
06Hmo`1V?@03o`1V?@03o`000?l0Kc7o06la00;o06la00Co0000o`1j8?l0NR3o07XP1?l00002o`1j
8003o`000?l0Q`Co08L400;o08L400?o0000oanF0?lOUP000_lOUP02o`0000?o<Y`000?o0000ofJ]
0?mV[@000_mV[@02o`0000;oRkL000Co0000olK00?o6`03oa/000_l00004om6S00;o000000?oggX0
o`000?l000000_l0000Gooooo`03o`000?oooooooooo00Oooooo000>ooooo`04o`000?oooooooooo
o`0000Cok4l01?l00002oo<b0004o`000?oh8@3on240ooPQ00Co00001ooi70000ol0003omRH0o`00
0005oo4k00;o00001?oZE008o`0000;ocZ`000Go0000ol330?o0``3o`<<0o`000004oiBi0005o`00
0?m][P3oKJh0off^0?l000001?m=Y@001Ol0003o<Y`0oc:L0?lbW03o000000Co7YD000Ko0000o`n@
0?l0003o0000o`1o5_l00004o`1j7`03o`000?l0MbCo07LT00?o07LT00?o0000o`1V?Ol0ISd00ol0
ISd01ol0003o06Llo`1W??l0Icco0000o`1HB_l000001_l0FdP00ol0003o059=o`1BC@04o`1BC@;o
00001_l0CDh2o`0000Ko04a=00Co0000o`0lA_l0?4Ko00000ol0DTd00ol0003o04U<o`19C003o`19
C003o`000?l0@TWo049900;o04990ol00004o`1FB`03o`000?l0Ed[o05M:00?o05M:00?o0000o`1J
B?l0FTP00_l0FTP00ol0003o05m4o`1OA003o`1OA003o`000?l0ISgo06Hm00;o06Hm00?o0000o`1_
<Ol0Kc400ol0Kc401Ol0003o07XPo`1j8?l0NR3o000000;o08D80ol00004o`271003o`000?lOUP3o
7iH000;o7iH000Ko0000odfU0?l0003o0000oc:L0?l00004ofJ]0006o`000?nR_03o0000o`000?n;
]`3o00001?o6`003o`0000;odJ<000?o0000ommj0?oONP000_oONP02o`0001Kooooo00?o0000oooo
ooooool01oooool000kooooo0_l000001?oooooo0000ona?0?o/C`03o`0000?olc801_l00004ooTI
0003o`000?oi703onA`000ConA`01?l00002oo4k00;o00001OoZE0001Ol0003ohW40on9a0?oRL@3o
000000CofHh02?l00002oiBi0005o`000?m][P3oKJh0off^0?l000001?m=Y@001Ol0003o<Y`0oc:L
0?lbW03o000000Co7YD000?o0000o`n@0?l?T0000_l?T002o`0000?o07XO00?o0000o`1g9?l0Mb@0
0ol0Mb@00ol0003o07LVo`000003o`1V?@03o`000?l0Icco06Ll00?o06Ll00?o0000o`1KB?l0FdP0
1?l0FdP00ol0003o0613o`000004o`1BC@04o`000?l0FDSo05U8o`0000Co04e>00?o0000o`1GB_l0
00001_l0C4d00ol0003o03a6o`000004o`1BC@03o`000?l0BDco04U<00?o04U<00?o0000o`12BOl0
00000_l000000ol0Ed[o0000o`1FB`05o`1FB`03o`000?l0Ed[o05M:00?o05M:00?o0000o`1JB?l0
FTP00_l0FTP00ol0003o05m4o`1OA002o`1OA003o`000?l0ISgo06Hm00?o06Hm00?o0000o`1_<Ol0
Kc400_l0Kc400ol0003o07XPo`1j8002o`1j8003o`000?l0Q@So08D800;o08D80ol00002o`271003
o`000?lOUP3o7iH000;o7iH000?o0000odfU0?m=Y@000_l00005ofJ]0003o`000?nR_03oX[`000;o
00001?o6`0000ol0003oeIT0omFI0004o`0000CoggX000?o0000ooooooooool05?ooool00ol0003o
ooooooooo`07ooooo`003Oooool01?l0003oooooooooooooool9o`0000Con20000?o0000ooTI0?oi
6@001?oi6@000ol0003onA`0ooTL0003o`0000ComRP00ol00004onYD00;o00000ooRL@000ol0003o
fHh0omV>0002omV>0003o`000?o?Z@3ocjT000;ocjT000Co0000olK10?o6`@3oa/402?l00002odfU
0005o`000?lbW03o<Y`0oc:L0?l000001?lNU@000ol0003o3i00o`n@0003o`n@0005o`000?l4R`3o
0000o`1j7ol000001Ol0Mb@01ol0003o07LVo`1g9_l0MbKo0000o`1V?Ol000001Ol0Ic`2o`0000Go
05]800Go0000o`1P@ol0H4?o0613o`000002o`1BC@03o`000?l0FDSo05U800;o05U800Co0000o`1=
C_l0CDko00000ol0EdX00ol0003o04a=o`1<C@03o`1<C@;o00001_l0DTd00ol0003o04U<o`19C002
o`19C0;o00001Ol0EdX00ol0003o05I;o`1FB`03o`1FB`03o`000?l0Ed[o05M:00?o05M:00?o0000
o`1JB?l0FTP00_l0FTP00ol0003o05m4o`1OA002o`1OA003o`000?l0ISgo06Hm00?o06Hm00?o0000
o`1_<Ol0Kc400_l0Kc400ol0003o07XPo`1j8002o`1j8003o`000?l0Q@So08D800;o08D800?o0000
oaJB0?lFTP000ol00004oanF0003o`000?m=Y@3oCJD000;oCJD00_l00003ofJ]0003o`000?nR_03o
X[`000;oX[`00_l00003olK00003o`000?oEV@3oeIT000;oeIT00ol00003ommj0003o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01oooool000gooooo1?l000000ooooooo0000oo<c0003oo<c
0003o`000?oh803on20000Gon20000?o0000ooTI0?oi6@000ooi6@03o`0000KomRP000Co0000oo4l
0?oa?03olC`00_l000000ooZE03o0000on9a0003on9a0003o`000?oISP3ofHh000;ofHh000?o0000
olnY0?o?Z@000_o?Z@001Ol0003oa/40olK10?o6`@3o000000CoY;d000Co0000oh>d0?n3]03oPk@0
1?l000000olbW03o0000oajE0003oajE0003o`000?l?T03o3i0000?o3i0000Go0000o`B;0?l4R`3o
18/0o`000005o`1g9003o`000?l0MbKo07LV00?o07LV00?o0000o`1W??l0Ic`00ol0Ic`01?l0003o
06Xho`1Z>?l00003o`1KB003o`000?l0H4?o061300;o061300?o0000o`1BCOl000001Ol0FDP00ol0
003o04e>o`000004o`1GBP03o`000?l0C4go04a=00;o04a=00?o0000o`1IBOl000001_l0DTd00ol0
003o04U<o`19C002o`000003o`1JB?l0003o05M:00Co05M:00?o0000o`1FBol0ET/00ol0ET/00ol0
003o05M:o`1GBP03o`1GBP04o`000?l0FTSo05Y8o`1JB0_o000000?o06Hmo`000?l0Kc401?l0Kc40
0ol0003o07XPo`1j8002o`1j8003o`000?l0Q@So08D800;o08D800?o0000oaJB0?lFTP000_lFTP03
o`0000;o7iH000Ko0000odfU0?m=Y@3oCJD0o`000?n3]002o`000003ofJ]0?l0003oX[`000?oX[`0
00?o0000olbc0?l000000_l000000oo6`03o0000omFI0002omFI00;o000000?ohW00o`000?l00000
0_l0000Eooooo`03o`000?oooooooooo00Oooooo000=ooooo`;o00001?ooool00ol0003olc<0oo<c
0002oo<c0003o`000?oh803on20000Gon20000?o0000ooTI0?l000000_l00003ooTM0004o`000?of
:03omRP0ooHX00;o00001Ooa?004o`0000;ohW4000?o0000omV>0?oISP000_oISP000ol0003ocjT0
olnY0002olnY0005o`000?o6`@3oa/40olK10?l000001?nT_@000ol0003oPk@0oh>d0002oh>d0004
o`000?mV[@3oIZd0ofJ]00;o00001?lNU@000ol0003o3i00o`n@0002o`n@0003o`000?l4R`3o18/0
00;o18/00_l00003o`1g9003o`000?l0MbKo07LV00?o07LV00?o0000o`1g9?l000000ol0Ic`00ol0
003o06Xho`1Z>002o`1Z>003o`000?l0FdSo000000Ko061300?o0000o`1IB?l0FDP01Ol0FDP00ol0
003o05M:o`1GBP04o`1GBP04o`000?l0C4go04a=o`0000?o05U900?o0000o`1BCOl0DTd00ol0DTd0
0ol0003o04U<o`000004o`1JB003o`000?l0Ed[o05M:00?o05M:00?o0000o`1FBol0ET/00ol0ET/0
0ol0003o05M:o`1GBP06o`0000;o06Ti00?o0000o`1^<ol0KS<00_l0KS<01?l0003o07@Yo`1d:Ol0
M2T:o`0000;o07XP00?o0000o`252?l0Q@P00_l0Q@P00ol0003o5Y80oaJB0002oaJB0003o`000?ln
X03o?Z0000?o00001?m=Y@000ol0003oPk@0oh>d0003o`0000CoX[`000Co0000olbc0?o</`3oc;<0
0_l00004omFI00;o00000ooRL002o`0001Cooooo00?o0000ooooooooool01oooool000oooooo00?o
0000ooooooooool00_ooool00ol0003olc<0oo<c0002oo<c0003o`000?oh803on20000Con2000_l0
0007ooTM0003o`000?of:03o000000KolC`000?o0000onYD0?oZE0000_oZE004o`0000;ofHh000?o
0000olnY0?o?Z@000_o?Z@001Ol0003oa/40olK10?o6`@3o000000CoY;d000?o0000oh>d0?n3]000
0_n3]0000ol0003oIZd0ofJ]0002ofJ]0006o`000?m@YP3o0000o`000?lNU@3o00001?l?T0000ol0
003o18/0o`B;0002o`B;0006o`000?l0R@7o08T1o`000?l0MbCo00001Ol0MbH01ol0003o07LTo`1g
9?l0MbCo0000o`1W??l000001_l0JSP00ol0003o0613o`1P@`04o`1P@`;o00001_l0FDP2o`0000Ko
05M:00?o0000o`1<COl000001?l0FDT00ol0003o059=o`1BC@03o`1BC@;o00001Ol0FTP00ol0003o
05M:o`1GBP03o`1GBP03o`000?l0ET_o05I;00;o05I;1?l00003o`1V?@03o`000?l0JCWo06Ti00?o
06Ti00?o0000o`1^<ol0KS<00_l0KS<00ol0003o07@Yo`1d:@02o`1d:@03o`000?l0OA[o07dJ00;o
07dJ00?o0000o`271Ol0Q`D00ol00005o`252003o`000?lFTP3o5Y8000;o5Y8000?o0000ocjP0?ln
X0000_lnX002o`0000;oCJD000?o0000oh>d0?n3]0000_n3]003o`0000?oX[`000?o0000olbc0?o<
/`000_o</`03o`0000;oeIT00_l00003on9`0003o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01_ooool0013ooooo00?o0000ooooooooool00_ooool00ol0003olc<0oo<c0002oo<c0003o`00
0?oh803on20000?o00000_oi6@000ol0003onAd0ooTM0004ooTM00?o00001Ooa?0000ol0003ojU@0
onYD0002onYD0003o`000?oSKP3ohfh000;ohfh01?l00002olnY0005o`000?o6`@3oa/40olK10?l0
00001?nT_@000ol0003oPk@0oh>d0002oh>d0003o`000?mV[@3oIZd000;oIZd000?o0000oe2V0?m@
YP000_m@YP02o`0000?o3i0000?o0000o`B;0?l4R`000_l4R`000ol0003o08T1o`290@02o`290@03
o`000?l0MbKo07LV00?o07LV00?o0000o`1g9?l0Mb@00ol0Mb@00ol0003o06Xho`1Z>004o`1Z>0;o
00001Ol0H4<01?l0003o06Llo`1W??l00004o`1IB004o`000?l0Hd7o06=1o`0000Go05M:0_l00006
o`1IB@03o`000?l0DTgo059=00;o000000?o05m4o`000?l0FTP01Ol0FTP00ol0003o05M:o`1GBP02
o`1GBP03o`000?l0ET_o000000;o000000?o06Dno`000?l0ISd01?l0ISd00ol0003o06Tio`1Y>@03
o`1Y>@03o`000?l0KS?o06hc00;o06hc00?o0000o`1d:Ol0M2T00ol0M2T00ol0003o07dJo`1m6P02
o`1m6P03o`000?l0Q`Go08L500;o08L51?l000000ol0Q@So0000oaJB0003oaJB0003o`000?lnX03o
?Z0000;o?Z0000Ko0000off^0?l0003o0000odfU0?l00003oh>d0003o`000?no``3o_l<000Co0000
1?o</`000ol0003ofH`0omV<0003o`000003on9`0?l0003ohW0000;ohW0000?o0000ooooooooool0
4_ooool00ol0003oooooooooo`06ooooo`004Oooool00ol0003oooooooooo`02ooooo`Oo00001_oi
6@001?l0003onAd0ooTM0?oi7@02o`0000?omRP00ol000000ooa?03o0000onYD0003onYD0003o`00
0?oSKP3ohfh000?ohfh000Co0000om^80?oKR03ofhP02?l00002ojBm0003o`000?n3]03oPk@000;o
Pk@000?o0000ofJ]0?mV[@000_mV[@000ol0003oD:H0oe2V0002oe2V0006o`000?loX@3o?j40o`00
0?l?T03o00001?l4R`000ol0003o08T1o`290@03o`290@;o00000ol0MbH00ol0003o07LTo`1g9003
o`1g90;o00001Ol0JSP01?l0003o06lbo`1_<_l00003o`1P@`03o`000?l0Icco06Ll00;o06Ll00Co
0000o`1IB?l0FDSo00000ol0Hd400ol0003o05M:o`1GBP02o`1GBP03o`000?l0HT7o000000Ko05U9
00?o0000o`1BCOl000001?l0Gd@00ol0003o05Y8o`1JB003o`1JB003o`000?l0Ed[o05M:00;o05M:
0_l00005o`1U?P03o`000?l0ISgo06Hm00?o06Hm00?o0000o`1Y>Ol0JCT00ol0JCT00ol0003o06hc
o`1^<`02o`1^<`03o`000?l0M2Wo07@Y00;o07@Y00?o0000o`1m6_l0OAX00_l0OAX00ol0003o08L5
o`271@02o`271@04o`000?lFTP3o5Y80oaJB00Go00000_lFTP000ol0003o?Z00ocjP0002ocjP0003
o`000?m][P3oKJh000;o00001?n3]0000ol0003o_l<0oko30002oko300Co00000_o</`000ol0003o
fH`0omV<0002omV<00Go000000?ohW00o`000?ooool04_ooool00ol0003oooooooooo`06ooooo`00
4_ooool2o`0000;ooooo00?o0000ooLR0?og8P000oog8P000ol0003onAT0ooTI0005ooTI0003o`00
0?oi7@3o000000OomRP01?l00002onYD0003o`000?oSKP3ohfh000?ohfh000?o0000om^80?oKR000
0_oKR0000ol0003odj00om>P0002om>P0003o`000?o;]@3obkD000Co00000_n3]0000ol0003oIZd0
ofJ]0002ofJ]0003o`000?m@YP3oD:H000;oD:H000?o0000ocnQ0?loX@000_loX@02o`0000Co18/0
00?o0000o`290Ol0R@400_l0R@401_l0003o08P3o`280ol0003o07LVo`0000Go07LT00Co0000o`1j
7ol0NQoo00000ol0JSP00ol0003o06lbo`1_<P02o`1_<P03o`000?l0H4?o000000Go06Ll00?o0000
o`1IB?l000001Ol0Hd401?l0003o05M:o`1GB_l00003o`1R@@03o`000?l0FDWo05U900?o05U90_l0
0005o`1OA003o`000?l0FTSo05Y800?o05Y800?o0000o`1GB_l000000_l000000ol0ISgo0000o`1U
?P04o`1U?P03o`000?l0ISgo06Hm00?o06Hm00?o0000o`1Y>Ol0JCT00ol0JCT00ol0003o06hco`1^
<`02o`1^<`03o`000?l0M2Wo07@Y00;o07@Y00?o0000o`1m6_l0OAX00ol0OAX00ol0003o08L5o`27
1@02o`271@03o`000?lFTP3o5Y8000;o5Y8000?o0000ocRN0?lhWP000ol00004ocjP0003o`000?m]
[P3oKJh000;oKJh00ol00002oh>d0003o`000?no``3o_l<000;o_l<000?o0000om6T0?oAY0000ol0
0004omV<0003o`000?oUI@3o000000;oiFD00ol0000Booooo`03o`000?oooooooooo00Kooooo000D
ooooo`04o`000?ooooooooooo`0000Gomb8000?o0000ooTI0?oi6@001?oi6@03o`0000GomRP00_l0
0004oo4j00?o00001?oSKP000ol0003ofhP0om^80002om^80003o`000?oCX03odj0000;odj0000?o
0000ol^e0?o;]@000_o;]@000ol0003o_l<0oko30004o`0000;oIZd000?o0000oe2V0?m@YP000_m@
YP000ol0003o?j40ocnQ0003ocnQ0006o`000?lcW@3o0000o`000?l4R`3o00001?l0R@400ol0003o
08P3o`280`02o`280`03o`000?l0MbCo07LT00?o07LT00?o0000o`1j7ol0NQl00_l0NQl00ol0003o
06Xho`000006o`1_<P03o`000?l0Icco06Ll00Go06Ll00?o0000o`1S@Ol0Hd401?l0Hd400ol0003o
05M:o`000004o`1R@@03o`000?l0FDWo05U900;o05U900?o0000o`1V?Ol000001_l0Gd@00ol0003o
05Y8o`1JB002o`1JB0;o00001Ol0ISd00ol0003o06Dno`1U?P03o`1U?P03o`000?l0ISgo06Hm00;o
06Hm00?o0000o`1Y>Ol0JCT00ol0JCT00ol0003o06hco`1^<`02o`1^<`03o`000?l0M2Wo07@Y00?o
07@Y00?o0000o`1m6_l0OAX00_l0OAX00ol0003o08L5o`271@02o`271@03o`000?lFTP3o5Y8000;o
5Y8000?o0000ocRN0?lhWP000olhWP02o`0000;o?Z0000?o0000off^0?m][P000_m][P000ol0003o
Y;d0ojBm0003o`0000Go_l<000?o0000om6T0?oAY0000_oAY003o`0000;ofH`000?o0000onEU0?l0
00000ooUI@000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo000Eooooo`04o`00
0?ooooooooooo`0000Gomb8000?o0000ooTI0?oi6@000ol00003ooTL00;o000000?omRP0o`000?l0
00001Ooa>P001?l0003ok4l0ona?0?o/C`02o`000003on=^0?l0003ofhP000?ofhP000?o0000om>P
0?oCX0000_oCX0000ol0003obkD0ol^e0002ol^e0005o`000?no``3o_l<0oko30?l000000onR_003
o`0000?oD:H000?o0000ocnQ0?loX@000oloX@000ol0003o<id0oc>M0002oc>M00;o00000ol0R@40
0ol0003o08P3o`280`03o`280`;o00000ol0Mb@00ol0003o07XOo`1j7`04o`1j7`03o`000?l0Kc;o
06lb00Go06lb00?o0000o`1W??l0Ic`01?l0Ic`2o`0000Ko06=10_l00006o`1R@@04o`000?l0FDWo
05U9o`0000?o06Hm00?o0000o`1OA?l0Gd@00ol0Gd@00ol0003o05Y8o`000002o`000003o`1Y>Ol0
003o06Hm00Co06Hm00?o0000o`1U?_l0ICh00ol0ICh00ol0003o06Hmo`1V?@03o`1V?@03o`000?l0
JCWo06Ti017o000000?o07dJo`000?l0Q`D01?l0Q`D00ol0003o5Y80oaJB0002oaJB0003o`000?lh
WP3o>9h000;o>9h000?o0000of>[0?l000000ol00004off^0003o`000?nT_@3oY;d000;oY;d00ol0
0002oko30003o`000?oAY03odJ@000;odJ@000?o0000omim0?oNO@001?l000000ooUI@3o0000onEU
0002onEU0003o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool001Kooooo00Co0000
oooooooooooo00000oog8P04o`0000OonA`00ol00004oo4j00;o00001Oo/C`04o`0000;ofhP000?o
0000om>P0?oCX0000_oCX0000ol0003obkD0ol^e0002ol^e0005o`000?no``3o_l<0oko30?l00000
1OnR_0001Ol0003oRkL0o`000?m@YP3o000000Go?j4000?o0000oc>M0?lcW@000_lcW@001_l0003o
;9X0obbJ0?l0003o08T1o`0000Go08P300Ko0000o`290Ol0R@7o0000o`1g9?l00007o`1j7`03o`00
0?l0Kc;o06lb00Co06lb00?o0000o`1e9ol000001?l0Ic`01?l0003o06lao`1_<Ol00004o`1S@@03
o`000?l0KCCo000000Ko069100?o0000o`1IBOl000001?l0ISd00ol0003o05m4o`1OA003o`1OA0;o
00001Ol0JCT00ol0003o06Hmo`1V?@03o`1V?@03o`000?l0ICko06Dn00;o06Dn00Co0000o`1V?Ol0
ISgo06Hm1Ol00003o`1i8@03o`000?l0OQSo07hH00;o07hH00?o0000o`242ol0Q0/00_l0Q0/01?l0
003o1X`0o`J<0?l6S006o`000003o`271Ol0003o5Y8000?o5Y8000?o0000ocRN0?lhWP000olhWP00
1?l0003oHj/0of>[0?mSZ`03o`0000?oKJh000Go0000ojBm0?nT_@3oY;d0o`000002ol^e00?o0000
1OoAY0000ol0003ogWd0omim0002omim00Go000000?oiFD0o`000?ooool04?ooool00ol0003ooooo
ooooo`06ooooo`005oooool2o`000004ooooool0003o0000o`0000ConAX00_l00003ooTL00;o0000
0oof9P02o`000003oo4j0?l0003ok4l000Gok4l000?o0000onEV0?oUIP000_oUIP04o`0000;odj00
00?o0000ol^e0?o;]@000_o;]@001Ol0003o_l<0oko30?no``3o000000GoX[`000Co0000oh^g0?n;
]`3oRkL00_l00004ocnQ0003o`000?lcW@3o<id000;o<id000?o0000obbJ0?l/VP000_l/VP000ol0
003o08P3o`280`03o`280`03o`000?l0R@7o08T100;o08T100?o0000o`1j7ol0NQl01Ol0NQl00ol0
003o07lFo`000004o`1_<P05o`000?l0MBOo07DWo`1e9ol000000_l0Ic`00ol0003o06lao`1_<@02
o`1_<@04o`000?l0Hd7o06=1o`0000?o06dd00?o0000o`1R@Ol0HT400ol0HT42o`0000Ko06Hm00?o
0000o`1OA?l0Gd@00_l000000ol0KS?o0000o`1Y>@04o`1Y>@03o`000?l0ISgo06Hm00?o06Hm00?o
0000o`1U?_l0ICh00_l0ICh4o`0000;o07HV00?o0000o`1i8Ol0NB400ol0NB400ol0003o07hHo`1n
6003o`1n6003o`000?l0Q0_o08@;00;o08@;00?o0000o`J<0?l6S0000_l6S0001?l0003o7YD0oajE
0?lNU@04o`0000;o5Y8000?o0000ocRN0?lhWP000olhWP001Ol0003oHj/0of>[0?mSZ`3o000000;o
U;T01?l00004ojBm0003o`000?o;]@3obkD000;obkD00ol00003om6T0003o`000?oNO@3ogWd000;o
gWd000Co0000onUG0?l0003ojEL00ol0000Aooooo`03o`000?oooooooooo00Gooooo000Iooooo`03
o`000?oooooo000000OonAX000?o0000ooTL0?l000001_of9P03o`0000Cok4l00_l00004onEV0003
o`000?oNO03ogW`000;ogW`01?l00002ol^e0005o`000?no``3o_l<0oko30?l000001OnR_0000ol0
003oRkL0oh^g0002oh^g0006o`000?mi/P3o0000o`000?loX@3o00001?lcW@000ol0003o;9X0obbJ
0003obbJ00;o00000ol0R0<00ol0003o08T1o`290@03o`290@;o00001Ol0NQl01Ol0003o07lFo`1o
5_l0OaKo000000;o06lb00?o0000o`1e9ol0MBL00_l0MBL00ol0003o06Llo`000005o`1_<@03o`00
0?l0Hd7o000000Co06dd00?o0000o`1R@Ol0HT400_l0HT400ol0003o06lao`000006o`1V?@03o`00
0?l0GdCo000000?o06hc00?o0000o`1Y>Ol0JCT01?l0JCT00ol0003o06Hmo`1V?@02o`1V?@03o`00
0?l0ICko000000;o000000?o07DWo`000?l0MRH01?l0MRH00ol0003o07TQo`1i8@03o`1i8@03o`00
0?l0OQSo07hH00;o07hH00?o0000o`242ol0Q0/00_l0Q0/00ol0003o1X`0o`J<0003o`J<0003o`00
0?lNU@3o7YD000;o7YD000?o0000ocbP0?l000000ol00004ocRN0003o`000?mSZ`3oHj/000;oHj/0
00?o0000oiBi0?nD^@000_nD^@04o`0000;oY;d000Go0000ol^e0?o;]@3obkD0o`000002omRA00Co
00001OoNO@000ol0003ojEL0o`000002onUG0003o`000?oooooooooo00oooooo00?o0000oooooooo
ool01Oooool001[ooooo00?o0000ooooool000001_oi6P03o`0000ComRH00_l00003oo<d00;o0000
00?ok4l0o`000?oUIP000ooUIP02o`0000CogW`000?o0000omRA0?oHT@000_oHT@04o`000003oko3
0?l0003oX[`000CoX[`000?o0000oh^g0?n;]`000_n;]`000ol0003oNK80ogVb0002ogVb00;o0000
0olcW@000ol0003o;9X0obbJ0003obbJ0006o`000?lZVP3o:YX0o`000?l0R0?o00001Ol0R@401?l0
003o18/0o`B;0?l00003o`1j7`03o`000?l0OaKo07lF00;o07lF00?o0000o`1_<_l000001_l0MBL0
0ol0003o06lao`1_<@05o`1_<@03o`000?l0KCCo06dd00Co06dd00Co0000o`1R@Ol0HT7o00000ol0
Kc400ol0003o06Hmo`1V?@03o`1V?@;o00001Ol0KS<00ol0003o06Tio`1Y>@03o`1Y>@03o`000?l0
ISgo06Hm00;o06Hm0_l00005o`1e9`03o`000?l0MRKo07HV00;o07HV00?o0000o`1i8Ol0NB400ol0
NB400ol0003o07hHo`1n6003o`1n6005o`000?l0Q0_o08@;o`242ol000001Ol6S0000ol0003o7YD0
oajE0002oajE0003o`000?llX03o?:0000;o?:001?l00002ocRN0005o`000?mSZ`3oHj/0of>[0?l0
00001OnD^@000ol0003oa/40olK10003o`0000CobkD000?o0000omRA0?oHT@000_oHT@04o`0000;o
gWd000Co0000onUG0?oYE`3o00000_oYE`000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Gooooo000Kooooo`03o`000?oooooo000000;onAX00ol00003ooTJ00;o000000?omRH0o`000?oc
=0001Ooc=004o`0000;oiFH000?o0000omil0?oNO0000ooNO0000ol0003of940omRA0002omRA0003
o`000?oAY03odJ@000;odJ@00_l00004oj:l0003o`000?n;]`3oRkL000;oRkL000?o0000ogVb0?mi
/P000_mi/P001_l0003oKJh0off^0?l0003o<id0o`0000Go;9X000?o0000obZJ0?lZVP000_lZVP00
0ol0003o08T1o`290@03o`290@03o`000?l4R`3o18/000;o18/000?o0000o`1j7ol000001_l0OaH0
0ol0003o07DWo`1e9`05o`1e9`03o`000?l0Kc7o06la00Co06la0_l00006o`1]=003o`000?l0HT7o
000000Co06la00?o0000o`1V?Ol0ISd00_l0ISd00ol0003o07@Yo`000005o`1^<`03o`000?l0JCWo
06Ti00?o06Ti00?o0000o`1V?Ol000000_l000000ol0MRKo0000o`1e9`04o`1e9`03o`000?l0MRKo
07HV00?o07HV00?o0000o`1i8Ol0NB400_l0NB400ol0003o07hHo`1n6003o`1n6003o`000?l0Q0_o
08@;00;o08@;00?o0000o`J<0?l6S0000ol6S0000ol0003o7YD0oajE0002oajE0005o`000?llX03o
?:00ocbP0?l000000omRZ`05o`0000;oHj/000?o0000oiBi0?nD^@000onD^@000ol0003oa/40olK1
0002olK100?o00000_o;]@000ol0003of940omRA0002omRA0003o`000?oTK03oi6`000?o00000_oY
E`001?l0003ojEL0onUG0?l0000@ooooo`03o`000?oooooooooo00Gooooo000Looooo`Co00001ooi
6P03o`0000Golc@000?o0000oni60?o^AP000_o^AP03o`0000CogW`000?o0000omRA0?oHT@000_oH
T@000ol0003odJ@0om6T0003om6T0006o`000?o</`3o0000o`000?nR_03o00001?n;]`000ol0003o
NK80ogVb0002ogVb0003o`000?m][P3oKJh000;oKJh000?o0000obbJ0?l/VP000ol/VP000ol0003o
:YX0obZJ0003obZJ0003o`000?l0R@7o08T100;o08T100?o0000o`B;0?l4R`001?l4R`000ol0003o
07lFo`1o5P05o`1o5P03o`000?l0MBOo07DW00Co07DW00?o0000o`1m6Ol000001?l0Kc401?l0003o
07XPo`1j8?l00005o`1]=0;o00001_l0Kc401?l0003o06Hmo`1V?Ol00002o`1d:@03o`000?l0KS?o
06hc00?o06hc00?o0000o`1Y>Ol0JCT00ol0JCT2o`0000Go07HV00?o0000o`1e9ol0MBL00ol0MBL0
0ol0003o07HVo`1f9P02o`1f9P03o`000?l0NB7o07TQ00;o07TQ00?o0000o`1n6?l0OQP00ol0OQP0
0ol0003o08@;o`242`02o`242`03o`000?l6S03o1X`000?o1X`000?o0000oajE0?lNU@000_lNU@00
0ol0003o?:00ocbP0002ocbP0003o`000?mRZ`3oHZ/000;oHZ/000?o0000ohjg0?n>]`000ol00005
oiBi0003o`000?o6`@3oa/4000;oa/4000?o0000om>P0?oCX0000ol00005omRA0003o`000?oTK03o
i6`000;oi6`01?l000000ooYE`3o0000ooooo`0?ooooo`03o`000?oooooooooo00Gooooo000Noooo
o`03o`000?oooooo000000ConAX00_l00003ooPQ0005o`000?oc=03olc@0oo<d0?l000001Oo^AP00
0ol0003ojET0onUI0002o`000003omil0?l0003of94000?of94000?o0000om6T0?oAY0000ooAY000
0ol0003oc;<0olbc0002olbc00?o00000_n;]`000ol0003oNK80ogVb0002ogVb0003o`000?m][P3o
KJh000?oKJh00_l00003obbJ0003o`000?lZVP3o:YX000?o:YX000?o0000obbJ0?l000000ol0R@40
0ol0003o18/0o`B;0003o`B;00;o00001_l0OaH00ol0003o08D9o`000004o`1e9`05o`000?l0OAWo
07dIo`1m6Ol000000_l0Kc401Ol0003o07XPo`1j8?l0NR3o000000Co06dd00?o0000o`1j8?l00000
1_l0Kc400ol0003o06Hmo`000004o`1d:@03o`000?l0KS?o06hc00?o06hc00?o0000o`1Y>Ol00000
0_l000000ol0NB7o0000o`1f9P04o`1f9P03o`000?l0MBOo07DW00?o07DW00?o0000o`1f9_l0MRH0
0_l0MRH00ol0003o07TQo`1i8@03o`1i8@03o`000?l0OQSo07hH00So00001Ol6S0000ol0003o7YD0
oajE0002oajE0003o`000?llX03o?:0000;o?:0000?o0000of:[0?mRZ`000omRZ`000ol0003oS[L0
ohjg0002ohjg00?o00000_nD^@000ol0003oa/40olK10003olK10003o`000?oCX03odj0000;odj00
0ol00002omRA0003o`000?oTK03oi6`000;oi6`000Co0000one90?o]B@3okDT00ol0000?ooooo`03
o`000?oooooooooo00Gooooo000Oooooo`04o`000?oooooo0000ooTJ00;o00001_oh8@000ol0003o
lc@0o`000005oni60003o`000?oYF@3ojET000;ojET01?l00002omRA0003o`000?oAY03odJ@000?o
dJ@000?o0000olbc0?o</`000_o</`001?l0003oa/00olK00?o6`003o`0000?oNK8000?o0000off^
0?m][P000om][P001_l0003oIJ`0ofF/0?l0003o;9X0o`0000Go:YX000Oo0000obbJ0?l/VP3o;9X0
o`000?l0R@7o000000Go18/000Co0000o`n@0?l?T03o00001?l0OaH01Ol0003o08D9o`252Ol0Q@Wo
000000;o07DW00?o0000o`1m6Ol0OAT00_l0OAT00ol0003o06lao`000005o`1j8004o`000?l0KCCo
06ddo`0000?o07XP00?o0000o`1_<Ol0Kc400ol0Kc42o`0000Go07@Y00?o0000o`1^<ol0KS<00_l0
KS<3o`0000Co07TQ00?o0000o`1f9_l0MRH01?l0MRH00ol0003o07DWo`1e9`02o`1e9`04o`000?l0
MRKo07HVo`1f9P[o00000ol<SP001?l0003o6i@0oa^D0?lKU00;o`000003oajE0?l0003o?:0000?o
?:0000?o0000of:[0?mRZ`000_mRZ`000ol0003oS[L0ohjg0002ohjg0003o`000?o0``3o`<<000Co
00001?o6`@000ol0003odj00om>P0002om>P0003o`000?oNO03ogW`000?o00001OoTK0001?l0003o
kDT0one90?o]B@02o`00013ooooo00?o0000ooooooooool01?ooool0023ooooo00Co0000ooooool0
003o00001ooh8@03o`0000CokTH000?o0000onUI0?oYF@000_oYF@000ol0003oi6`0onA/0002onA/
00?o00001?oAY0000ol0003oc;<0olbc0002olbc0003o`000?o6`03oa/0000;oa/0000Ko0000ok_2
0?nk`P3o0000ogVb0?l00005off^0003o`000?mU[03oIJ`000;oIJ`00_l00004obZJ0003o`000?l/
VP3o;9X000?o;9X000?o0000o`B;0?l4R`000ol4R`000ol0003o3i00o`n@0002o`n@0004o`000?l0
OaKo07lFo`0000Co08D900?o0000o`1e9ol000001_l0OAT00ol0003o07XPo`1j8004o`1j8003o`00
0?l0KCCo000000Co07XP00?o0000o`1_<Ol0Kc400_l0Kc400ol0003o07dJo`000005o`1d:@03o`00
0?l0KS?o06hc00;o000000?o07hHo`000?l0NB401Ol0NB400ol0003o07HVo`1f9P03o`1f9P03o`00
0?l0MBOo07DW00;o07DW1?l00002o`271003o`000?l1RP3o0HX000;o0HX000?o0000o`b>0?l<SP00
0ol<SP000ol0003o6i@0oa^D0002oa^D0003o`000?l`W03o<9`000?o<9`000Co0000od^T0?m;Y03o
Bj@01Ol000000ollX03o0000of:[0004of:[0003o`000?n>]`3oS[L000;oS[L000?o0000ol330?o0
``000_o0``03o`0000;oa/4000?o0000om>P0?oCX0000ooCX0000ol0003ogW`0omil0002omil00Go
000000Ooi6`0o`000?o]B@3okDT0o`000?o]B@3o000000oooooo00?o0000ooooooooool01?ooool0
027ooooo00Co0000oooooooooooo00001?oh8@02o`0000?omB`00_l000000oo^AP3o0000onUI0003
onUI0003o`000?oTK03oi6`000;oi6`000Co0000omim0?oNO@3ogWd00_l000000ooAY03o0000olbc
0003olbc0003o`000?o6`03oa/0000;oa/0000?o0000ok_20?nk`P000_nk`P02o`0000CoKJh000?o
0000ofF/0?mU[0000omU[0000ol0003oHZ/0o`000003obZJ0003o`000?l/VP3o;9X000?o;9X00_l0
0003o`B;0003o`000?l?T03o3i0000?o3i0000?o0000o`1o5_l000001Ol0Q@T2o`0000Oo07dI00?o
0000o`1j8?l0NR001Ol0NR000ol0003o07XPo`1j8003o`1j8003o`000?l0Kc7o06la00;o00000_l0
OAX00ol0003o07@Yo`1d:@04o`1d:@;o00001?l0OQP00ol0003o07TQo`1i8@03o`1i8@03o`000?l0
MRKo07HV00?o07HV00?o0000o`1e9ol000000_l000000ol0QPKo0000o`271004o`271003o`000?l1
RP3o0HX000;o0HX000?o0000o`b>0?l<SP000ol<SP000ol0003o6i@0oa^D0002oa^D0003o`000?l`
W03o<9`000;o<9`000?o0000od^T0?m;Y0000_m;Y0001?l0003oJjh0of^^0?m[[P05o`0000;oHZ/0
00?o0000ohjg0?n>]`000_n>]`000ol0003o`<<0ol330002ol330003o`000?o?Z@3ocjT000Co0000
1?oCX0000ol0003ogW`0omil0002omil0003o`000?oYF@3ojET000;ojET01_l000000oo]B@3o0000
ooooo`0=ooooo`03o`000?oooooooooo00Cooooo000Rooooo`;o000000?oooooo`000?oh8@000_l0
0006ooD/00Co00000_oYF@000ol0003oi6`0onA/0002onA/0003o`000?oNO@3ogWd000?ogWd01?l0
0002olbc0003o`000?o6`03oa/0000;oa/0000?o0000ok_20?nk`P000onk`P001_l0003o[[l0o`00
0?l0003oKJh0o`0000GoIJ`000Oo0000of:[0?mRZ`3oHZ/0o`000?lZVP3o000000Go;9X000Ko0000
oc>M0?lcW@3o0000o`B;0?l00007o`n@0003o`000?l0Q@Wo08D900?o08D900?o0000o`R=0?l00000
1_l0OAT00ol0003o08L4o`000005o`1j80;o00001_l0NR02o`0000Go07dJ00?o0000o`1d:Ol0M2T0
0_l0M2T2o`0000Go07hH00?o0000o`1i8Ol0NB400ol0NB400ol0003o07HVo`1f9P03o`1f9P;o0000
1?l0QPH00ol0003o08L4o`271003o`271003o`000?l1RP3o0HX000;o0HX000?o0000o`b>0?l<SP00
0ol<SP000ol0003o6i@0oa^D0002oa^D0003o`000?l`W03o<9`000?o<9`000?o0000od^T0?m;Y000
0_m;Y0000ol0003oJjh0of^^0002of^^0003o`000?nB^03oT[P000?o00001On>]`000ol0003o`<<0
ol330002ol330003o`000?o?Z@3ocjT000;ocjT00ol00003om>P0003o`000?oNO03ogW`000;ogW`0
00?o0000onUI0?oYF@000ooYF@001?l0003olCX0oo4j0?oa>P03o`0000gooooo00?o0000oooooooo
ool01?ooool002Cooooo00Co0000ooooool0003o00001Ooe;002o`0000ColCX00ol00003onA/0003
o`000?oNO@3ogWd000?ogWd000?o0000omV<0?oIS0000_oIS003o`0000?oa/0000?o0000ok_20?nk
`P000onk`P000ol0003o[[l0ojjo0002ojjo0003o`000?mU[03oIJ`000?oIJ`000?o0000of:[0?mR
Z`000omRZ`000ol0003o;9X0obbJ0003obbJ0003o`000?lcW@3o<id000;o<id000?o0000o`n@0?l?
T0001Ol?T002o`0000Co08D900Go0000o`R=0?l8S@3o28d0o`000004o`1m6@04o`000?l0Q`Co08L4
o`0000Co07XP00Co0000o`252?l0Q@So00001?l0NR02o`0000Ko07dJ00Oo0000o`1d:Ol0M2Wo07@Y
o`000?l0Q0_o000000Ko07hH00?o0000o`1i8Ol0NB400ol0NB400ol0003o07HVo`000002o`000003
o`271?l0003o08H600Co08H600?o0000o`271?l0Q`@00_l0Q`@00ol0003o0HX0o`6:0003o`6:0003
o`000?l<SP3o38h000;o38h000?o0000oa^D0?lKU0000olKU0000ol0003o<9`0oc2L0002oc2L0003
o`000?m;Y03oBj@000;oBj@000?o0000of^^0?m[[P000om[[P000ol0003oT[P0oi:h0002oi:h00Co
000000?oS[L0o`000?o0``000oo0``000ol0003ocjT0olnY0002olnY0003o`000?oKR03ofhP000Co
00001OoNO0000ol0003ojET0onUI0003onUI0006o`000?oa>P3olCX0o`000?oa>P3o00003Oooool0
0ol0003oooooooooo`04ooooo`009Oooool00ol0003oooooooooo`02o`000003ooD/0?l0003o0000
00GolCX000Oo0000one90?o]B@3okDT0o`000?oTK03o000000GogWd000?o0000omV<0?oIS0000ooI
S0001_l0003oeIT0omFI0?l0003oa/00o`0000Go^l8000?o0000ojjo0?n^_`000on^_`02o`0000?o
IJ`000?o0000of:[0?mRZ`000omRZ`000ol0003oIJ`0o`000003obbJ0003o`000?lcW@3o<id000?o
<id000?o0000o`n@0?l?T0001?l?T0001?l0003o7YD0oajE0?l00002o`252@03o`000?l8S@3o28d0
00?o28d000Co0000o`1m6Ol0OAWo00001?l0Q`@01?l0003o07XPo`1j8?l00003o`252007o`000?l0
NR3o07XPo`1j8?l0003o08L5o`000006o`1m6P04o`000?l0M2Wo07@Yo`0000?o08@;00?o0000o`1n
6?l0OQP00ol0OQP00ol0003o07TQo`1i8@02o`1i8@?o00001?l0Q`@00ol0003o08H6o`261P03o`26
1P03o`000?l0Q`Co08L400?o08L400?o0000o`6:0?l1RP000_l1RP000ol0003o38h0o`b>0002o`b>
0003o`000?lKU03o6i@000?o6i@000?o0000oc2L0?l`W0000_l`W0000ol0003oBj@0od^T0003od^T
0003o`000?m[[P3oJjh000;oJjh000?o0000oi:h0?nB^0000_nB^0001?l0003o_l<0oko30?no``05
o`0000;o`<<000?o0000olnY0?o?Z@000_o?Z@000ol0003ofhP0om^80002om^800Go000000?ogW`0
o`000?oYF@001?oYF@001ol0003olCX0oo4j0?oa>P3o0000oo4j0?l000003?ooool00ol0003ooooo
ooooo`04ooooo`009_ooool01?l0003oooooooooooooool2o`0000ColCX00_l00005one900;o0000
1?oNO@000ol0003ofH`0omV<0003omV<0003o`000?oEV@3oeIT000;oeIT00_l00004ok_20003o`00
0?n^_`3o[[l000?o[[l000Ko0000ojJm0?nV_@3o0000ofF/0?l00005of:[0007o`000?mU[03oIJ`0
ofF/0?l0003o;9X0o`000005oc>M0003o`000?loX@3o000000Co3i0000Oo0000oajE0?lNU@3o7YD0
o`000?l0Q@Wo000000Ko28d000?o0000o`1m6Ol000001Ol0Q`@00ol0003o07XPo`000004o`252004
o`000?l0NR3o07XPo`0000?o08L500?o0000o`1m6_l0OAX01?l0OAX2o`0000Co08@;00?o0000o`1n
6?l0OQP00ol0OQP00ol0003o07TQo`000002o`000003o`6:0?l0003o08L400Go08L400?o0000o`26
1_l0QPH00_l0QPH00ol0003o08L4o`271003o`271003o`000?l1RP3o0HX000;o0HX000?o0000o`b>
0?l<SP000ol<SP000ol0003o6i@0oa^D0002oa^D0003o`000?l`W03o<9`000?o<9`000?o0000od^T
0?m;Y0000_m;Y0000ol0003oJjh0of^^0003of^^0003o`000?nB^03oT[P000;oT[P000?o0000oko3
0?no``000_no``000ol0003ocZ`0olj/0003o`0000GocjT000?o0000om^80?oKR0000_oKR0001?l0
003oiFH0onEV0?oUIP06o`000003onUI0?l0003olCX000?olCX00_l0000<ooooo`03o`000?oooooo
oooo00Cooooo000Wooooo`;o00000oooool2o`000003oo4j0?l0003okDT000GokDT000?o0000onUG
0?oYE`000_l000000ooNO@3o0000omV<0004omV<0003o`000?oEV@3oeIT000?oeIT000Ko0000om6S
0?l0003o0000ok_20?l00005ojjo0003o`000?nV_@3oY[d000;oY[d000?o0000of:[0?mRZ`000omR
Z`000ol0003oIJ`0ofF/0003ofF/0003o`000?lcW@3o<id000?o<id000Go0000ocnQ0?loX@3o?j40
o`000002o`n@0003o`000?lNU@3o7YD000?o7YD000?o0000o`R=0?l8S@001Ol8S@02o`0000Ko08L4
0_l00006o`2520;o00001?l0Q`D00ol0003o07dJo`1m6P03o`1m6P;o00001_l0Q0/00ol0003o07hH
o`1n6002o`1n60;o00001Ol1RP000ol0003o08L4o`271003o`271003o`000?l0QPKo08H600;o08H6
00?o0000o`271?l0Q`@00ol0Q`@01?l0003o0HX0o`6:0?l1RP0Fo`000003od^T0?l0003oJjh000Co
Jjh000?o0000oi:h0?nB^0000_nB^0000ol0003o_l<0oko30003oko30003o`000?o>[03ocZ`000;o
cZ`01?l000000oo?Z@3o0000om^80004om^80003o`000?oUIP3oiFH000;oiFH000Co0000oni60?o^
AP3okTH02Ol0000<ooooo`03o`000?oooooooooo00?ooooo000Yooooo`03o`000?oooooooooo00;o
oooo0_l00005one90003o`000?oYE`3ojEL000?ojEL00_l00004omV<0003o`000?oEV@3oeIT000?o
eIT000?o0000om6S0?oAX`000_oAX`000ol0003o[[l0ojjo0003ojjo0003o`000?nV_@3oY[d000?o
Y[d00_l00003of:[0003o`000?mU[03oIJ`000CoIJ`000?o0000oc>M0?lcW@000_lcW@000ol0003o
?j40ocnQ0002ocnQ0003o`000?l?T03o000000Ko7YD000?o0000o`R=0?l8S@001?l8S@000ol0003o
7iH0o`000005o`271003o`000?lFTP3o000000Ko08D800?o0000o`271Ol0Q`D01?l0Q`D00ol0003o
07dJo`1m6P02o`000003o`J<0?l0003o08@;00Go08@;00?o0000o`1n6?l0OQP00_l000000ol<SP3o
0000o`6:0004o`6:0003o`000?l0Q`Co08L400?o08L400?o0000o`261_l0QPH00ol0QPH00ol0003o
08L4o`271006o`0000;o;i/000?o0000oc^O0?lkW`000_lkW`000ol0003oC:D0odbU0003odbU0003
o`000?mS[03oHj`000;oHj`000Co0000ognc0?mo/`3oOk<01_l000000om[[P3o0000oi:h0004oi:h
0003o`000?no``3o_l<000;o_l<000?o0000olj/0?o>[0000_o>[0001?l0003ofHh0omV>0?oISP05
o`0000;ofhP000?o0000onEV0?oUIP000ooUIP000ol0003okTH0oni60002oni60003o`000?oe;03o
mB`000;omB`00_l0000<ooooo`03o`000?oooooooooo00?ooooo000Zooooo`03o`000?oooooooooo
00?ooooo00Go0000one90?o]B@3okDT0o`000005onUG0003o`000?oUI@3oiFD000;o000000?ofH`0
o`000?oEV@001?oEV@000ol0003odJ<0om6S0002om6S0003o`000?o?ZP3o000000?o[[l000?o0000
ojJm0?nV_@000onV_@001_l0003oXk`0oj>l0?l0003oHZ/0o`0000KoIJ`000?o0000off^0?l00000
0olcW@000ol0003o?j40ocnQ0003ocnQ0003o`000?lNU@3o7YD000Co7YD000?o0000oc:L0?l00000
1?l8S@001Ol0003o7iH0oanF0?lOUP3o000000?o08L400Go0000oaJB0?lFTP3o5Y80o`000004o`25
20;o00001_l0Q`D00ol0003o07dJo`000004o`J<0003o`000?l0Q0_o08@;00?o08@;00?o0000o`1n
6?l000001?l<SP000ol0003o0HX0o`6:0003o`6:0003o`000?l0Q`Co08L400?o08L400?o0000o`26
1_l0QPH01Ol00003obRI0003o`000?l_V`3o;i/000?o;i/000?o0000oc^O0?lkW`000_lkW`000ol0
003oC:D0odbU0003odbU0003o`000?mS[03oHj`000;oHj`000?o0000ognc0?mo/`000_mo/`001?l0
003oXK`0oj6l0?nQ_006o`000003oi:h0?l0003o_l<000Co_l<000?o0000olj/0?o>[0000_o>[000
0ol0003ofHh0omV>0002omV>0003o`000?oSKP3ohfh000?o00001OoUIP000ol0003okTH0oni60003
oni60003o`000?oe;03omB`000;omB`00_l0000;ooooo`03o`000?oooooooooo00?ooooo000[oooo
o`03o`000?oooooooooo00?ooooo00?o0000one90?l000001OoYE`000ol0003oiFD0onEU0003onEU
00;o00001?oEV@000ol0003odJ<0om6S0002om6S0007o`000?o?ZP3ocjX0olnZ0?l0003o[[l0o`00
0005ojJm0003o`000?nS_03oXk`000;oXk`00_l00005ofF/0007o`000?m][P3oKJh0off^0?l0003o
<id0o`000006ocnQ0003o`000?lNU@3o7YD000?o7YD000Go0000oc:L0?lbW03o<Y`0o`000002o`R=
0003o`000?lOUP3o7iH000;o7iH000Co0000o`271?l0Q`Co00001?lFTP001Ol0003o08D8o`252?l0
Q@So000000;o5Y8000?o0000o`271Ol0Q`D01?l0Q`D00ol0003o1X`0o`J<0003o`J<0003o`000?l0
Q0_o08@;00?o08@;0_l00005o`b>0003o`000?l1RP3o0HX000?o0HX000?o0000o`271?l0Q`@00_l0
Q`@4o`0000;o9YP000?o0000obRI0?lXV@000olXV@000ol0003o;i/0obnK0003obnK0003o`000?lk
W`3o>il000;o>il000?o0000odbU0?m<Y@000om<Y@000ol0003oHj`0of>/0002of>/0003o`000?mo
/`3oOk<000?oOk<000?o0000oj6l0?nQ_0000_nQ_0001?l0003oaL80olG20?o5`P05o`0000;o_l<0
00?o0000olj/0?o>[0000_o>[0000ol0003ofHh0omV>0003omV>0003o`000?oSKP3ohfh000;ohfh0
1?l000000ooUIP3o0000oni60004oni60003o`000?oe;03omB`000?omB`00_l0000:ooooo`03o`00
0?oooooooooo00?ooooo000/ooooo`;o00001?ooool2o`0000CojEL000?o0000onEU0?oUI@000ooU
I@000ol0003ohW00on9`0002o`000003omFI0?l0003odJ<000?odJ<000?o0000olnZ0?o?ZP000oo?
ZP02o`0000CoY[d000?o0000oj>l0?nS_0000onS_0000ol0003oY[d0o`000003ofF/0003o`000?m]
[P3oKJh000?oKJh000?o0000ocnQ0?loX@001?loX@000ol0003oD:H0o`000003oajE0003o`000?lb
W03o<Y`000;o<Y`000?o0000o`R=0?l000001OlOUP000ol0003o08L4o`000005oaJB0004o`000?l0
Q@So08D8o`0000?o5Y8000?o0000o`271Ol0Q`D00ol0Q`D2o`0000Ko1X`000?o0000o`242ol0Q0/0
0_l000000olKU03o0000o`b>0004o`b>0003o`000?l1RP3o0HX000?o0HX000?o0000o`271?l00000
0_l000000olXV@3o0000obJH0004obJH0003o`000?lXV@3o:9T000?o:9T000?o0000obnK0?l_V`00
0ol_V`000ol0003o>il0oc^O0002oc^O0003o`000?m<Y@3oC:D000?oC:D000?o0000of>/0?mS[000
0_mS[0000ol0003oOk<0ognc0002ognc0003o`000?nQ_03oXK`000;oXK`000?o0000olG20?o5`P00
0oo5`P000ol0003ocjX0olnZ0003o`0000CocZ`000?o0000omV>0?oISP000ooISP000ol0003ohfh0
on=^0002on=^0004o`000?o/C`3ok4l0ona?013o00002Oooool00ol0003oooooooooo`03ooooo`00
;_ooool00ol0003oooooooooo`03ooooo`;o000000?ojEL0o`000?oUI@001?oUI@000ol0003ohW00
on9`0002on9`00?o00000ooAX`000ol0003ocjX0olnZ0003olnZ0003o`000?o=[P3ocJh000;o0000
00?oY[d0o`000?nS_0001?nS_0001ol0003oY[d0ojJm0?nV_@3o0000ofF/0?l000001_m][P000ol0
003o?j40ocnQ0003ocnQ0007o`000?m@YP3oD:H0oe2V0?l0003o7YD0o`000006oc:L0003o`000?lO
UP3o7iH000Go7iH000?o0000oaJB0?lFTP001OlFTP02o`0000Go5Y8000Go0000o`271Ol0Q`Go08L5
o`000002oajE0003o`000?l6S03o1X`000?o1X`000?o0000o`242ol000001?lKU0000ol0003o38h0
o`b>0003o`b>0003o`000?l1RP3o0HX000;o0HX00_l00005obRI0003o`000?lVV03o9YP000;o9YP0
00?o0000obRI0?lXV@000olXV@000ol0003o;i/0obnK0003obnK0003o`000?lkW`3o>il000;o>il0
00?o0000odbU0?m<Y@000om<Y@000ol0003oHj`0of>/0002of>/0003o`000?mo/`3oOk<000?oOk<0
00?o0000oj6l0?nQ_0000_nQ_0000ol0003oaL80olG20002olG20003o`000?o?ZP3ocjX000?ocjX0
1?l000000oo>[03o0000omV>0004omV>0003o`000?oSKP3ohfh000;ohfh000?o0000ona?0?o/C`00
0_o/C`000ol0003olc@0oo<d0003oo<d0003o`000?oh8@3on24000?on2400_l00009ooooo`03o`00
0?oooooooooo00?ooooo000_ooooo`03o`000?oooooooooo00Cooooo0_l00004onEU0003o`000?oR
L03ohW0000;ohW0000Oo0000ommj0?oONP3oggX0o`000?oAX`3o000000GocjX000?o0000olf^0?o=
[P000oo=[P000ol0003oXk`0oj>l0003oj>l0003o`000?nV_@3oY[d000?oY[d000?o0000off^0?m]
[P001?m][P000ol0003oNK80o`000003ocnQ0003o`000?m@YP3oD:H000?oD:H000?o0000oc:L0?lb
W0001OlbW0000ol0003o7iH0oanF0005oanF0003o`000?lFTP3o5Y8000Go5Y8000?o0000oaJB0?lF
TP001?lFTP001?l0003o08L5o`271Ol00003oajE0003o`000?l6S03o1X`000?o1X`00_l00005oa^D
0003o`000?l<SP3o38h000?o38h000?o0000o`6:0?l1RP000_l000000ol_V`3o0000obRI0004obRI
0003o`000?lVV03o9YP000?o9YP000?o0000obRI0?lXV@000_lXV@000ol0003o;i/0obnK0003obnK
0003o`000?lkW`3o>il000;o>il000?o0000odbU0?m<Y@000om<Y@000ol0003oHj`0of>/0002of>/
0003o`000?mo/`3oOk<000?oOk<000?o0000oj6l0?nQ_0000_nQ_0000ol0003oaL80olG20003olG2
0003o`000?o?ZP3ocjX000;ocjX000Co0000omV>0?oISP3ofHh01_l000000ooISP3o0000on=^0004
on=^0003o`000?o/C`3ok4l000;ok4l000?o0000oo<d0?oc=0000ooc=0000ol0003on240ooPQ0003
ooPQ00;o00002?ooool00ol0003oooooooooo`03ooooo`00<?ooool00ol0003oooooooooo`05oooo
o`;o000000?oiFD0o`000?oRL0000ooRL0000ol0003oggX0ommj0003ommj00;o00001?o?ZP000ol0
003ocJh0olf^0003olf^0003o`000?o=/03o000000?oXk`000?o0000ojJm0?nV_@000onV_@02o`00
00GoKJh000Oo0000ogVb0?mi/P3oNK80o`000?loX@3o000000KoD:H000?o0000oc:L0?lbW0001?lb
W0000ol0003oCJD0o`000005oanF0003o`000?lnX03o000000Go5Y800_l00006oaJB0003o`000?l0
Q`Go000000Go7YD000Oo0000o`J<0?l6S03o1X`0o`000?l`W03o000000Ko6i@000?o0000o`b>0?l<
SP000_l<SP000ol0003o0HX0o`000004obnK0003o`000?lXV@3o:9T000;o:9T000?o0000obJH0?lV
V0000olVV0000ol0003o:9T0obRI0003obRI0003o`000?l_V`3o;i/001Oo000000?oOk<0o`000?nQ
_0000onQ_0000ol0003oaL80olG20003olG20003o`000?o?ZP3ocjX000?ocjX000Go0000omV>0?oI
SP3ofHh0o`000004on9a00Ko000000?ohfh0o`000?o/C`001?o/C`000ol0003olc@0oo<d0003oo<d
0004o`000?oh8@3on240ooPQ00Co00002?ooool00ol0003oooooooooo`02ooooo`00<Oooool2o`00
00Oooooo0_l00003on9`0003o`000?oONP3oggX000?oggX000?o0000omf10?oMP@000_l000000oo?
ZP3o0000olf^0004olf^0007o`000?o=/03ocK00olf`0?l0003oXk`0o`000005ojJm0004o`000?n^
_`3o[[l0o`0000?oKJh000?o0000ogVb0?mi/P000omi/P000ol0003oD:H0oe2V0004oe2V0003o`00
0?mV[@3o000000Co<Y`000Co0000odfU0?m=Y@3o00001?lOUP001?l0003o?Z00ocjP0?l00004oaJB
0004o`000?lhWP3o>9h0o`0000Go5Y800_l00006oajE0004o`000?l6S03o1X`0o`0000?o<9`000?o
0000oa^D0?lKU0000olKU0000ol0003o38h0o`b>0002o`b>00;o00001Ol_V`000ol0003o:9T0obRI
0003obRI0003o`000?lVV03o9YP000;o9YP000Co0000obRI0?lXV@3o:9T01Ol00003ofN]0003o`00
0?md/03oM;0000;oM;0000?o0000ohJe0?n6]@000on6]@000ol0003oW[/0oijk0002oijk0004o`00
0?nk`P3o^l80ok_200Ko000000?oXK`0o`000?o5`P000oo5`P000ol0003ocjX0olnZ0003olnZ0003
o`000?oISP3ofHh000;ofHh000?o0000on9a0?oRL@000ooRL@001?l0003ojU@0onYD0?oZE00Ao`00
00?onAX000?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`00<oooool00ol0003o
ooooooooo`06ooooo`03o`000?oRL03o000000GoggX000?o0000omf10?oMP@000ooMP@000ol0003o
cJh0olf^0003olf^0003o`000?o=/03ocK0000?ocK0000?o0000ojJm0?nV_@000onV_@000ol0003o
[[l0ojjo0002ojjo0003o`000?m][P3o000000KoNK8000?o0000oe2V0?m@YP000om@YP001Ol0003o
IZd0ofJ]0?mV[@3o000000;o<Y`000?o0000odfU0?m=Y@000_m=Y@001?l0003o7iH0oanF0?l00004
ocjP0004o`000?lFTP3o5Y80o`0000?o>9h000?o0000oaJB0?lFTP000_lFTP000ol0003o?:00o`00
0006oajE0003o`000?l6S03o000000Co<9`000?o0000oa^D0?lKU0000olKU0000ol0003o38h0o`00
0002o`000003oc^O0?l0003o;i/000Go;i/000?o0000obRI0?lXV@000_lXV@000ol0003o9YP0obJH
0002obJH00Co00000_mOZ`000ol0003oIjd0ofN]0003ofN]0003o`000?md/03oM;0000?oM;0000?o
0000ohJe0?n6]@000_n6]@000ol0003oW[/0oijk0003oijk0003o`000?nk`P3o^l8000;o^l8000Co
0000olZg0?o:]`3ob[L01Ol00002olG20003o`000?o?ZP3ocjX000;ocjX000?o0000omV>0?oISP00
0ooISP000ol0003ohW40on9a0003on9a0003o`000?oZE03ojU@000;ojU@000?o0000oo4j0?oa>P00
0ooa>P000ol0003omRH0ooHV0003ooHV0003o`000?oi6P3onAX000?onAX00_l00007ooooo`03o`00
0?oooooooooo00;ooooo000dooooo`03o`000?oooooooooo00Kooooo0_l00004ommj0003o`000?oM
P@3ogH4000?ogH4000?o0000omb50?l000000oo=[P000ol0003ocK00olf`0004olf`00;o00000onV
_@000ol0003o[[l0ojjo0004ojjo0003o`000?mi/P3oNK8000CoNK8000?o0000oh^g0?l000000om@
YP000ol0003oIZd0ofJ]0002ofJ]0003o`000?lbW03o000000GoCJD000?o0000oanF0?l000001Oln
X0000ol0003o5Y80o`000005ocRN0004o`000?lFTP3o5Y80o`0000?o?:0000?o0000oajE0?lNU@00
0olNU@02o`0000Ko<9`000?o0000oa^D0?lKU0000_lKU002o`0000Go>il000?o0000obnK0?l_V`00
0ol_V`000ol0003o:9T0obRI0002obRI0003o`000?lVV03o000000;o000000?oGJX0o`000?mOZ`00
1?mOZ`000ol0003oIjd0ofN]0003ofN]0003o`000?md/03oM;0000;oM;0000?o0000ohJe0?n6]@00
0on6]@000ol0003oW[/0oijk0002oijk0003o`000?nk`P3o^l8000;o^l8000?o0000olZg0?o:]`00
0_o:]`001?l0003odZ80om:R0?oBXP06o`0000;ocjX000?o0000omV>0?oISP000_oISP000ol0003o
hW40on9a0003on9a0003o`000?oZE03ojU@000?ojU@000?o0000oo4j0?oa>P000ooa>P000ol0003o
mRH0ooHV0003ooHV0003o`000?oi6P3onAX000?onAX00_l00006ooooo`03o`000?oooooooooo00;o
oooo000eooooo`03o`000?oooooooooo00Oooooo0_l000000ooONP3o0000omf10004omf10007o`00
0?oLQ@3og8D0omb50?l0003ocJh0o`000006olf`0006o`000?o=[P3ocJh0o`000?nV_@3o00001_n^
_`02o`0000GoNK8000Oo0000oh^g0?n;]`3oRkL0o`000?m@YP3o000000KoIZd000?o0000odfU0?m=
Y@001Om=Y@000ol0003o?Z00ocjP0005ocjP0003o`000?lhWP3o>9h000Co>9h000?o0000oaJB0?l0
00001?llX0000ol0003o7YD0oajE0002oajE0003o`000?m;Y03o000000Ko<9`000?o0000oa^D0?lK
U0000_l000000om<Y@3o0000oc^O0004oc^O0003o`000?l_V`3o;i/000?o;i/000Co0000obRI0?lX
V@3o:9T00ol00005oefZ0003o`000?mOZ`3oGj/000;oGj/000?o0000ofN]0?mW[@000omW[@000ol0
003oM;00ogB`0003ogB`0003o`000?n6]@3oQ[D000;oQ[D000?o0000oijk0?nN^`000onN^`000ol0
003o^l80ok_20002ok_20003o`000?o:]`3ob[L000;ob[L000?o0000om:R0?oBXP000_oBXP001?l0
003ofXT0omZ90?oJR@0<o`000003on9a0?l0003ojU@000CojU@000?o0000oo4j0?oa>P000ooa>P00
0ol0003omRH0ooHV0003ooHV0003o`000?oi6P3onAX000?o000000?onAX0o`000?l000001Oooool0
0ol0003oooooooooo`02ooooo`00=_ooool2o`0000Wooooo00?o0000omf10?oMP@000ooMP@000ol0
003og8D0omb50003omb500;o00001Oo=/0000ol0003ocJh0olf^0002olf^0003o`000?n^_`3o[[l0
00Co[[l000Co0000ok_20?nk`P3o00000omi/P000ol0003oRkL0oh^g0003oh^g0003o`000?mV[@3o
IZd000GoIZd000?o0000odfU0?m=Y@001?m=Y@02o`0000Ko?Z000_l00007ocRN0003o`000?llX03o
?:0000Co?:0000Co0000oajE0?lNU@3o00000om;Y0000ol0003o<9`0oc2L0003oc2L0003o`000?lK
U03o000000CoC:D000?o0000oc^O0?lkW`000olkW`000ol0003o;i/0obnK0002obnK00Co00000_mO
Z`000ol0003oGJX0oefZ0003oefZ0003o`000?mOZ`3oGj/000?oGj/000?o0000ofN]0?mW[@000_mW
[@000ol0003oM;00ogB`0003ogB`0003o`000?n6]@3oQ[D000;oQ[D000?o0000oijk0?nN^`000onN
^`000ol0003o^l80ok_20002ok_20003o`000?o:]`3ob[L000;ob[L000?o0000om:R0?oBXP000ooB
XP000ol0003ofXT0omZ90002omZ90003o`000?oSK`3ohfl000?ohfl000Co0000onYD0?oZE03ojU@0
5_l00005ooTJ00;o00001?ooool00ol0003oooooooooo`02ooooo`00>?ooool00ol0003ooooooooo
o`07ooooo`05o`000?oMP@3ogH40omf10?l000001OoLQ@001?l0003ofhH0om^60?l00003olf`0003
o`000?o=[P3ocJh000?ocJh000?o0000ojjo0?n^_`000on^_`000ol0003o^l80ok_20002ok_20003
o`000?mi/P3o000000KoRkL000?o0000ofJ]0?mV[@001?mV[@000ol0003oPk@0o`000004odfU0004
o`000?m][P3oKJh0o`0000Co?Z0000Co0000of>[0?mSZ`3o00001OlhWP02o`0000Ko?:0000?o0000
oajE0?l000001?m;Y0000ol0003o<9`0oc2L0003oc2L00;o00001Om<Y@000ol0003o>il0oc^O0003
oc^O0003o`000?l_V`3o;i/000;o000000?oIjd0o`000?mOZ`001?mOZ`000ol0003oGJX0oefZ0003
oefZ0003o`000?mOZ`3oGj/000;oGj/000?o0000ofN]0?mW[@000_mW[@000ol0003oM;00ogB`0003
ogB`0003o`000?n6]@3oQ[D000?oQ[D000?o0000oijk0?nN^`000_nN^`000ol0003o^l80ok_20002
ok_20003o`000?o:]`3ob[L000?ob[L000?o0000om:R0?oBXP000_oBXP000ol0003ofXT0omZ90003
omZ90003o`000?oSK`3ohfl000?ohfl000?o0000onYD0?oZE0000_oZE0000ol0003olC`0oo4l0003
oo4l0003o`000?of:03omRP000?omRP000?o0000ooTL0?oi70000ooi70000ol0003onAX0ooTJ0002
ooTJ00?o000000?omb80o`000?ooool00_ooool00ol0003oooooooooo`02ooooo`00>Oooool00ol0
003oooooooooo`07ooooo`03o`000?oMP@3o000000Gog8D000?o0000om^60?oKQP000_oKQP000ol0
003ocK00o`000005olf^0003o`000?o?ZP3o000000?o[[l000?o0000ok_20?nk`P001?nk`P000ol0
003oRkL0oh^g0004oh^g0003o`000?nR_03o000000CoIZd000Go0000oh>d0?n3]03oPk@0o`000002
odfU0003o`000?m][P3oKJh000;oKJh000Co0000ocjP0?lnX03o00000omSZ`000ol0003o>9h0ocRN
0002ocRN0004o`000?mRZ`3oHZ/0o`0000Go?:000_l00006od^T0007o`000?l`W03o<9`0oc2L0?l0
003oHj`0o`000006odbU0003o`000?lkW`3o>il000;o>il000?o0000obnK0?l000001?mW[@000ol0
003oGj/0oen[0002oen[0003o`000?mMZP3oGJX000?oGJX000?o0000oen[0?mOZ`000_mOZ`000ol0
003oIjd0ofN]0003ofN]0003o`000?md/03oM;0001;o000000?o^l80o`000?o:]`000oo:]`000ol0
003odZ80om:R0003om:R0003o`000?oJR@3ofXT000?ofXT000?o0000on=_0?oSK`000_oSK`000ol0
003ojU@0onYD0003onYD0003o`000?oa?03olC`000?olC`000?o0000ooHX0?of:0000oof:0000ol0
003onA`0ooTL0003ooTL0004o`000?oi6P3o0000o`0000?omb801?l00002ooooo`03o`000?oooooo
oooo007ooooo000jooooo`03o`000?oooooooooo00Oooooo0_l00004omb50003o`000?oKQP3ofhH0
00?ofhH00_l00005olf^0007o`000?o?ZP3ocjX0olnZ0?l0003o[[l0o`000006ok_200;o00001On;
]`001Ol0003oX[`0oj:l0?nR_03o000000;oIZd000?o0000oh>d0?n3]0000_n3]0000ol0003oCJD0
o`000005off^0003o`000?lnX03o000000GoHj/000Co0000ocRN0?lhWP3o00000omRZ`000ol0003o
?:00ocbP0002ocbP0003o`000?m[[P3o000000KoBj@000Co0000oc2L0?l`W03o00000omS[0000ol0
003oC:D0odbU0003odbU0003o`000?lkW`3o>il000;o>il00_l00005ofN]0003o`000?mOZ`3oGj/0
00?oGj/000?o0000oefZ0?mMZP000_mMZP001?l0003oGj/0oen[0?mOZ`0:o`0000?o]<4000?o0000
olG30?o5``000_o5``000ol0003ob[H0olZf0003olZf0004o`000?o@YP3od:H0om2V00_o000000?o
dZ80o`000?oJR@001?oJR@000ol0003ohfl0on=_0003on=_0003o`000?oZE03ojU@000?ojU@000?o
0000oo4l0?oa?0000_oa?0000ol0003omRP0ooHX0003ooHX0004o`000?oi703onA`0ooTL00Co0000
1?og8P03o`000003oo<c0?l0003o000000;o00000oooool003_ooooo0_l00009ooooo`;o000000?o
g8D0o`000?oKQP001?oKQP001?l0003og8D0omb50?l00003olf^0003o`000?o?ZP3ocjX000?ocjX0
0_l00005ok_20004o`000?o6`03oa/00o`0000?oRkL000?o0000oj:l0?nR_0000_nR_0000ol0003o
IZd0o`000006oh>d0003o`000?m][P3oKJh000GoKJh000?o0000of>[0?mSZ`001?mSZ`000ol0003o
>9h0o`000005of:[0004o`000?llX03o?:00o`0000?oJjh000?o0000od^T0?m;Y0000om;Y0000ol0
003o<9`0o`000004of>/0003o`000?m<Y@3oC:D000?oC:D000?o0000oc^O0?l000000_l000000omd
/03o0000ofN]0004ofN]0003o`000?mOZ`3oGj/000?oGj/000?o0000oefZ0?mMZP000_mMZP04o`00
00;oWk`000?o0000ojNm0?nW_@000_nW_@000ol0003o]<40okC10004okC10003o`000?o5``3oaL<0
00;oaL<000?o0000olZf0?o:]P000oo:]P001Ol0003od:H0om2V0?o@YP3o000000Goei@000Co0000
omin0?oNOP3ogWh03?l000000ooSK`3o0000onYD0004onYD0003o`000?oa?03olC`000;olC`000Co
0000ooHX0?of:03omRP01_l00004ooTI0004o`000?og8P3o0000o`0000;olc<00_l000001?o/C`3o
0000ooooool00003ooooo`00?Oooool00ol0003oooooooooo`08ooooo`03o`000?oKQP3ofhH000?o
fhH000?o0000omb50?oLQ@000_oLQ@000ol0003ocJh0o`000005olnZ0004o`000?oAX`3odJ<0o`00
00?o^l8000?o0000olK00?o6`0000_o6`0000ol0003oRkL0o`000006oj:l0003o`000?n3]03oPk@0
00CoPk@00_l00006off^00;o00001omSZ`000ol0003oHZ/0of:[0004of:[0003o`000?llX03o0000
00CoJjh000?o0000od^T0?m;Y0000om;Y002o`0000KoHj`000?o0000odbU0?m<Y@000_m<Y@02o`00
00CoM;0000?o0000ofN]0?mW[@001?mW[@000ol0003oGj/0oen[0002oen[0003o`000?mMZP3o0000
00;o000000?oWK/0o`000?nO_0001?nO_0000ol0003oYkd0ojNm0002ojNm0003o`000?nd`@3o]<40
00?o]<4000?o0000olG30?o5``000_o5``000ol0003ob[H0olZf0003olZf0003o`000?o@YP3od:H0
00;od:H000?o0000omND0?oGU0000ooGU0000ol0003ogWh0omin0002omin0003o`000?oUI`3oiFL0
00?oiFL000Co0000on]@0?o[D03oje004?l00004ooTM0003o`000?oi6@3onAT000?onAT00_l00003
oo<c00Co00000_ooool00ol0003oooooooooo`01ooooo`00?_ooool00ol0003oooooooooo`08oooo
o`05o`000?oKQP3ofhH0om^60?l000001_oLQ@000ol0003ocjX0olnZ0003olnZ0003o`000?oAX`3o
dJ<000;odJ<000?o0000ok_20?l000001_o6`0000ol0003oX[`0oj:l0004oj:l00;o00001On3]000
1?l0003oY;d0ojBm0?l00004off^0004o`000?nD^@3oU;T0o`0000GoHj/00_l00007of:[0003o`00
0?m[[P3oJjh000CoJjh000Oo0000od^T0?m;Y03oBj@0o`000?mo/`3o000000KoHj`000?o0000odbU
0?m<Y@000_l000000on6]@3o0000ogB`0004ogB`0003o`000?mW[@3oIjd000?oIjd000?o0000oen[
0?mOZ`000_mOZ`02o`0000GoWK/000?o0000oinl0?nO_0000_nO_0000ol0003oYkd0ojNm0002ojNm
0003o`000?nd`@3o]<4000Co]<4000?o0000olG30?o5``000_o5``000ol0003ob[H0olZf0003olZf
0005o`000?o@YP3od:H0om2V0?l000001OoGU0000ol0003ogWh0omin0003omin0003o`000?oUI`3o
iFL000?oiFL000?o0000on]@0?o[D0000_o[D0000ol0003olC/0oo4k0003oo4k0003o`000?of:03o
mRP000?omRP000?o0000ooTM0?oi7@001?oi7@000ol0003onAT0o`000002o`0000;on20000?o0000
oo<c0?l000000_o/C`02o`0000;ooooo00?o0000ooooooooool00Oooool003oooooo00?o0000oooo
ooooool02?ooool00ol0003ofhH0o`000006omb50003o`000?oMP@3o000000?ocjX000?o0000om6S
0?oAX`001?oAX`000ol0003oa/00olK00004olK000;o00001OnR_0001?l0003o_l<0oko30?l00003
oh>d0003o`000?nT_@3oY;d000;oY;d000Co0000off^0?m][P3o00000onD^@000ol0003oHj/0of>[
0002of>[0004o`000?n>]`3oS[L0o`0000GoHZ/00_l00006of^^0004o`000?m;Y03oBj@0o`0000;o
Ok<000?o0000of>/0?mS[0001?mS[0000ol0003oC:D0o`000003ohJe0003o`000?md/03oM;0000?o
M;0000?o0000ofN]0?mW[@000omW[@000ol0003oGj/0o`000002o`000003oinl0?l0003oWK/000Co
WK/000?o0000oinl0?nO_0000_nO_0000ol0003oYkd0ojNm0003ojNm0003o`000?nd`@3o]<4000?o
]<4000?o0000olG30?o5``000_o5``000ol0003ob[H0olZf0003olZf0003o`000?o@YP3od:H000;o
d:H000?o0000omND0?oGU0000ooGU0000ol0003ogWh0omin0003omin0003o`000?oUI`3oiFL000;o
iFL000?o0000on]@0?o[D0000oo[D0000ol0003olC/0oo4k0003oo4k0003o`000?of:03omRP000?o
mRP000Co0000ooTM0?oi7@3onAd01?l00005ooPP00?o000000Ook4l0o`000?ooooooooooo`000?oo
oooo000000?ooooo0010ooooo`;o00002Oooool2o`0000Gog8D000Oo0000omf10?oMP@3ogH40o`00
0?o?ZP3o000000KodJ<00_l00005olK00004o`000?o</`3oc;<0o`0000?oX[`000?o0000oko30?no
``000_no``000ol0003oPk@0o`000005ojBm0003o`000?m][P3o000000GoU;T000Co0000of>[0?mS
Z`3o00000on>]`000ol0003oHZ/0of:[0002of:[0004o`000?nB^03oT[P0o`0000GoJjh000?o0000
od^T0?l000001?mo/`000ol0003oHj`0of>/0003of>/00;o00001On6]@000ol0003oM;00ogB`0002
ogB`0003o`000?mW[@3oIjd000?oIjd00_l00004oinl0003o`000?nM^`3oWK/000?oWK/000?o0000
oinl0?nO_0000onO_0000ol0003oYkd0ojNm0002ojNm0003o`000?nd`@3o]<4000?o]<4000?o0000
olG30?o5``000_o5``000ol0003ob[H0olZf0003olZf0003o`000?o@YP3od:H000;od:H000?o0000
omND0?oGU0000ooGU0000ol0003ogWh0omin0003omin0003o`000?oUI`3oiFL000;oiFL000?o0000
on]@0?o[D0000oo[D0000ol0003olC/0oo4k0003oo4k0004o`000?of:03omRP0ooHX00Ko00000ooi
6@001?l0003on200ooPP0?oh8002o`0000;olc800_l00003ooooo`03o`000?oooooo000000?ooooo
0012ooooo`03o`000?oooooooooo00Sooooo00Go0000omb50?oLQ@3og8D0o`000005omf10003o`00
0?oAX`3odJ<000CodJ<000Co0000omFI0?oEV@3o00000oo6`0000ol0003oc;<0olbc0002olbc0003
o`000?nR_03o000000Ko_l<000?o0000ojBm0?nT_@001OnT_@000ol0003oU;T0oiBi0004oiBi0003
o`000?mSZ`3o000000GoS[L000Co0000of:[0?mRZ`3o00000onB^0000ol0003oJjh0of^^0003of^^
00;o00001Omo/`000ol0003oHj`0of>/0002of>/0003o`000?nN^`3o000000GoQ[D000?o0000ogB`
0?md/0000omd/0000ol0003oIjd0o`000002o`000003ojNm0?l0003oWk`000CoWk`000?o0000oifk
0?nM^`000onM^`000ol0003oWk`0oinl0002oinl0003o`000?nW_@3oYkd000;oYkd000Co0000okC1
0?nd`@3o]<408ol000000ooUI`3o0000on]@0003on]@0004o`000?oa>`3olC/0oo4k00Ko00000ooi
70000ol0003onAT0ooTI0004ooTI0003o`000?oh803o000000;olc800_l00006ooooo`03o`000?oo
oooo000000;ooooo0013ooooo`03o`000?oooooooooo00Sooooo00?o0000omb50?l000001OoMP@02
o`0000GodJ<000?o0000omFI0?oEV@000_oEV@000ol0003oa/00o`000006olbc0003o`000?no``3o
_l<000Go_l<000?o0000ojBm0?nT_@001?nT_@02o`0000KoU;T00_l00006ohjg0003o`000?mRZ`3o
000000GoT[P000Oo0000of^^0?m[[P3oJjh0o`000?nQ_03o000000GoOk<000?o0000of>/0?mS[000
0_l00002oijk0003o`000?n6]@3oQ[D000?oQ[D000?o0000ogB`0?md/0000_md/003o`0000CoYkd0
00?o0000oinl0?nO_0000onO_0000ol0003oWK/0oifk0003oifk0003o`000?nO_03oWk`000;oWk`0
00Co0000ojNm0?nW_@3oYkd01Ol00003om2W0003o`000?oDW@3oe9d000;oe9d000?o0000omR@0?oH
T0000ooHT0000ol0003ogH00omf00002omf00003o`000?oSK`3ohfl000?ohfl000?o0000onQK0?oX
F`000ooXF`001?l0003okTP0oni80?o^B00:o`0000?omRH000?o0000ooTL0?oi70001?oi70000ol0
003onAT0ooTI0003ooTI00?o000000?olc80o`000?ooool02?ooool2o`0000;ooooo0014ooooo`03
o`000?oooooooooo00Sooooo00?o0000omf10?oMP@000ooMP@001?l0003oggX0ommj0?l00003om6S
0003o`000?oEV@3oeIT000CoeIT000?o0000olbc0?o</`001?o</`02o`0000Ko_l<000?o0000ol^e
0?l000001?nT_@001?l0003oa/40olK10?l00004oiBi0003o`000?o0``3o000000KoS[L00_l00006
oi:h0004o`000?m[[P3oJjh0o`0000?oXK`000?o0000ognc0?mo/`000omo/`02o`0000GoW[/000?o
0000ohJe0?n6]@000on6]@04o`000003okC10?l0003oYkd000GoYkd000?o0000oinl0?nO_0000_nO
_0000ol0003oWK/0oifk0003oifk0004o`000?nO_03oWk`0oinl00Go00000_o=[P000ol0003od:L0
om2W0003om2W0003o`000?oDW@3oe9d000?oe9d000?o0000omR@0?oHT0000ooHT0000ol0003ogH00
omf00002omf00003o`000?oSK`3ohfl000?ohfl000?o0000onQK0?oXF`000ooXF`001Ol0003okTP0
oni80?o^B03o000000GolSH000?o0000ooHV0?of9P001?of9P000ol0003onA`0ooTL0003ooTL0003
o`000?oi6@3onAT000?o00000_oh8@02o`0000Wooooo0ol00002ooooo`00AOooool00ol0003ooooo
ooooo`08ooooo`05o`000?oMP@3ogH40omf10?l000001?oONP000ol0003odJ<0o`000006omFI00;o
00001Oo</`001?l0003odJ@0om6T0?l00004oko30005o`000?o;]@3obkD0ol^e0?l000000_nT_@00
0ol0003oa/40olK10002olK10004o`000?nD^@3oU;T0o`0000?o`<<000?o0000ohjg0?n>]`000_n>
]`000ol0003o_l<0o`000006oi:h0003o`000?m[[P3o000000CoXK`000?o0000ognc0?mo/`000_mo
/`02o`0000KoW[/000?o0000ohJe0?n6]@000_n6]@02o`0000Go]<4000?o0000ojNm0?nW_@000onW
_@000ol0003oWk`0oinl0003oinl0003o`000?nM^`3oWK/000Ko00000_o</`000ol0003ocJh0olf^
0003olf^0003o`000?o@Y`3od:L000?od:L000?o0000omBM0?oDW@000_oDW@000ol0003of900omR@
0003omR@0003o`000?oMP03ogH0000;ogH0000?o0000on=_0?oSK`000ooSK`000ol0003oj5/0onQK
0003onQK0003o`000?o^B03okTP000;okTP000?o0000oo8f0?ob=P000oob=P000ol0003omRH0ooHV
0003ooHV0004o`000?oi703onA`0ooTL00Go00000ooh8@02o`0000Oooooo1?l00005ooooo`00A_oo
ool2o`0000Wooooo00?o0000omf10?l000001_oONP02o`0000GoeIT000Co0000omV<0?oIS03o0000
0oo</`000ol0003odJ@0om6T0002om6T0004o`000?no``3o_l<0o`0000CobkD000?o0000ojBm0?l0
00001Oo6`@000ol0003oU;T0o`000005ol330004o`000?n>]`3oS[L0o`0000?o_l<000?o0000oi:h
0?nB^0000onB^002o`0000GoXK`000?o0000ognc0?mo/`000_l000000onk`P3o0000oijk0005oijk
0003o`000?n6]@3oQ[D000;o000000?oaL<0o`000?nd`@001?nd`@000ol0003oYkd0ojNm0003ojNm
0003o`000?nO_03oWk`000;oWk`01?l00003ol^d0003o`000?o</`3oc;<000?oc;<000?o0000olf^
0?o=[P000_o=[P000ol0003od:L0om2W0003om2W0003o`000?oDW@3oe9d000?oe9d000?o0000omR@
0?oHT0000_oHT0000ol0003ogH00omf00003omf00003o`000?oSK`3ohfl000;ohfl000?o0000onQK
0?oXF`000ooXF`000ol0003okTP0oni80003oni80003o`000?ob=P3olSH000;olSH000Co0000ooHV
0?of9P3omRH01_l00004ooTJ0004o`000?oh8@3o0000o`0000Gooooo1?l00009ooooo`00B?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oONP3oggX000CoggX000Co0000on9`0?oRL03o00000ooE
V@000ol0003ofH`0omV<0002omV<0003o`000?o</`3o000000GodJ@000?o0000oko30?l000001_o;
]@000ol0003oa/40olK10005olK10003o`000?o0``3o`<<000Co`<<000?o0000ohjg0?l000001?no
``000ol0003oT[P0oi:h0002oi:h0003o`000?o5`P3o000000KoXK`00_l00004ok_20003o`000?nN
^`3oW[/000CoW[/00_l00004olG30003o`000?nd`@3o]<4000?o]<4000?o0000ojNm0?nW_@000onW
_@04o`000003olbc0?l0003obk@000Gobk@000?o0000olbc0?o</`000_o</`000ol0003ocJh0olf^
0003olf^0003o`000?o@Y`3od:L000;od:L000?o0000omBM0?oDW@000ooDW@000ol0003of900omR@
0003omR@0003o`000?oMP03ogH0000;ogH0000?o0000on=_0?oSK`000ooSK`000ol0003oj5/0onQK
0003onQK0003o`000?o^B03okTP000_o00000ooi6`000ol0003onAX0ooTJ0004ooTJ00;o00001?oo
ool3o`0000gooooo0019ooooo`03o`000?oooooooooo00Kooooo00?o0000ommj0?oONP000ooONP00
0ol0003ohW00on9`0002on9`0003o`000?oEV@3o000000KofH`000?o0000om6T0?oAY0001OoAY000
0ol0003obkD0ol^e0004ol^e00;o00001_o6`@02o`0000Oo`<<000?o0000oko30?no``001?no``00
1?l0003oT[P0oi:h0?l00003olG20003o`000?nQ_03oXK`000;oXK`00_l00005ok_20003o`000?nN
^`3oW[/000?oW[/00_l00005olG30003o`000?nd`@3o]<4000?o]<4000?o0000ojNm0?nW_@000_nW
_@02o`0000Goc;<000?o0000ol^d0?o;]0000oo;]0000ol0003oc;<0olbc0003olbc0003o`000?o=
[P3ocJh000;ocJh000?o0000om2W0?o@Y`000oo@Y`000ol0003oe9d0omBM000Lo`0000?om2h000?o
0000ooLR0?og8P000oog8P000ol0003onA/0ooTK0003ooTK0003o`000?oi6P3onAX000?o00000_oo
ool4o`00013ooooo001:ooooo`03o`000?oooooooooo00Kooooo00Go0000ommj0?oONP3oggX0o`00
0005on9`00;o00001_oIS002o`0000KodJ@00_l00005ol^e0004o`000?oCX03odj00o`0000Coa/40
00Co0000olnY0?o?Z@3o00001Oo0``02o`0000Ko_l<000?o0000oi:h0?l000001?o5`P001ol0003o
XK`0oj6l0?nQ_03o0000olZg0?l000001_nk`P000ol0003oW[/0oijk0002o`000003olZf0?l0003o
aL<000GoaL<000?o0000okC10?nd`@000_nd`@000ol0003oYkd0o`000002o`000003olf^0?l0003o
c;<000Coc;<000?o0000ol^d0?o;]0000oo;]0000ol0003oc;<0olbc0003olbc0004o`000?o=[P3o
cJh0olf^00[o00000ooQM0000ol0003oi6P0onAX0002onAX0003o`000?oXF`3oj5/000?oj5/000?o
0000one<0?o]C0000_o]C0000ol0003olC`0oo4l0003oo4l0003o`000?od;P3om2h000Com2h000?o
0000ooLR0?og8P000oog8P001?l0003onA/0ooTK0?oi6`04o`000003ooooool0003o000000;o0000
5?ooool004_ooooo0_l00007ooooo`03o`000?oONP3o000000GohW0000?o0000onEU0?l000001OoI
S0001?l0003ogWd0omim0?l00004om6T0004o`000?oHT@3of940o`0000?obkD000?o0000om>P0?oC
X0000_oCX0001?l0003oa/40olK10?l00003olnY0003o`000?o0``3o`<<000;o`<<000Co0000olj/
0?o>[03o00001Ono``02o`0000GoaL8000Co0000oj6l0?nQ_03o00000oo:]`000ol0003o^l80ok_2
0003ok_20003o`000?nN^`3o000000Cob[H000?o0000olG30?o5``000oo5``000ol0003o]<40okC1
0002okC100;o00001Oo=[P000ol0003oc;<0olbc0003olbc0003o`000?o;]03obk@000?obk@000?o
0000olbc0?o</`001_l00002omb50003o`000?oNOP3ogWh000;ogWh000?o0000on5d0?oQM0001?oQ
M0000ol0003oi6P0onAX0002onAX0003o`000?oXF`3oj5/000?oj5/000?o0000one<0?o]C0000_o]
C0000ol0003olC`0oo4l0003oo4l0003o`000?od;P3om2h000?om2h000Co0000ooLR0?og8P3omb80
1_l000000ooooooo0000o`000002o`0001Sooooo001=ooooo`03o`000?oooooooooo00Gooooo00?o
0000on9`0?oRL0000ooRL0001Ol0003oiFD0onEU0?oUI@3o000000?ofH`000?o0000omim0?oNO@00
0_oNO@001?l0003odJ@0om6T0?l00004omRA0003o`000?o;]@3o000000Godj0000?o0000olK10?l0
00001Oo?Z@001?l0003o`<<0ol330?l00003olj/0003o`000?no``3o_l<000;o_l<000?o0000olnZ
0?l000001_o5`P02o`0000Cob[L000?o0000ok_20?nk`P000onk`P02o`0000Gob[H000?o0000olG3
0?o5``000oo5``000ol0003o]<40o`000002o`000003om2W0?l0003ocJh000CocJh000?o0000olbc
0?o</`000oo</`000ol0003obk@0ol^d0002ol^d00Co00000ooJR@000ol0003og8D0omb50003omb5
0003o`000?oNOP3ogWh000;ogWh000?o0000on5d0?oQM0000ooQM0000ol0003oi6P0onAX0002onAX
0003o`000?oXF`3oj5/000?oj5/000?o0000one<0?o]C0000oo]C0000ol0003olC`0oo4l0002oo4l
0004o`000?od;P3om2h0oo@^00Ko00000oooool4o`0001cooooo001>ooooo`03o`000?oooooooooo
00Gooooo00Go0000on9`0?oRL03ohW00o`000005onEU0003o`000?oIS03o000000GogWd000?o0000
om6T0?l000001_oHT@000ol0003odj00om>P0005om>P0003o`000?o?Z@3ocjT000CocjT000?o0000
ol330?l000001Oo>[0001?l0003o_l<0oko30?l00003olnZ0003o`000?o5`P3oaL8000;oaL800_l0
0006olZg0007o`000?nk`P3o^l80ok_20?l0003od:H0o`000006olZf0003o`000?o5``3oaL<000;o
aL<00_l00005om2W0003o`000?o=[P3ocJh000?ocJh000?o0000olbc0?o</`000_o</`000ol0003o
bk@0o`000002o`000003omZ;0?l0003ofXT000CofXT000?o0000omb50?oLQ@000ooLQ@000ol0003o
gWh0omin0002omin0003o`000?oQM03ohG@000?ohG@000?o0000onAX0?oTJ0000ooTJ0000ol0003o
j5/0onQK0002onQK0003o`000?o]C03okD`000?okD`000Co0000oo4l0?oa?03olC`01Ol00006oooo
o`?o00008?ooool004oooooo00?o0000ooooooooool01Oooool00ol0003ohW00o`000006onEU00;o
00001_oNO@02o`0000Kof9400_l00006om>P00;o00001_o?Z@02o`0000KocZ`000?o0000oko30?l0
00001?o?ZP001ol0003oaL80olG20?o5`P3o0000om:R0?l000001_o:]`001?l0003o^l80ok_20?l0
0003om2V0003o`000?o:]P3ob[H000?ob[H000?o0000olG30?o5``000_l000000ooDW@3o0000om2W
0004om2W0003o`000?o=[P3ocJh000?ocJh000?o0000olbc0?o</`000_o</`02o`0000GofX/000?o
0000omZ90?oJR@000ooJR@000ol0003og8D0omb50003omb50003o`000?oNOP3ogWh000;ogWh000?o
0000on5d0?oQM0000ooQM0000ol0003oi6P0onAX0002onAX0004o`000?oXF`3oj5/0onQK00_o0000
1oooool4o`0002?ooooo001@ooooo`;o00001_ooool00ol0003oiFD0onEU0004onEU0003o`000?oY
E`3o000000GogWd000?o0000onA/0?l000001OoHT@001?l0003ogW`0omil0?l00004om>P0004o`00
0?oKR03ofhP0o`0000CocjT000?o0000omV>0?l000001_o>[002o`0000GocjX000Co0000olG20?o5
`P3o00000ooBXP000ol0003ob[L0olZg0003olZg0003o`000?nk`P3o000000Cod:H000?o0000olZf
0?o:]P000oo:]P000ol0003oaL<0o`000004omBM0003o`000?o@Y`3od:L000?od:L000?o0000olf^
0?o=[P000_o=[P000ol0003oc;<0o`000002o`000003omZ90?l0003ofX/000CofX/000?o0000omZ9
0?oJR@000ooJR@000ol0003og8D0omb50003omb50003o`000?oNOP3ogWh000;ogWh000Co0000on5d
0?oQM03ohG@02ol0000>ooooo`Co00009oooool005;ooooo00?o0000ooooooooool00oooool00ol0
003oiFD0onEU0003onEU0005o`000?oYE`3ojEL0onUG0?l000000ooNO@001Ol0003oi6`0onA/0?oT
K03o000000?of94000?o0000omil0?oNO0000_oNO0001?l0003odj00om>P0?l00004om^80004o`00
0?o?Z@3ocjT0o`0000?ofHh000?o0000olj/0?o>[0000_o>[0000ol0003ofHh0o`000006olnZ00;o
00001?oBXP000ol0003ob[L0olZg0003olZg00;o00001_o@YP000ol0003ob[H0olZf0002olZf00;o
00001OoDW@000ol0003od:L0om2W0003om2W0003o`000?o=[P3ocJh000;ocJh00_l00005omZ90003
o`000?oJR`3ofX/000?ofX/000?o0000omZ90?oJR@000_oJR@000ol0003og8D0omb50003omb50004
o`000?oNOP3ogWh0omin00Go00005Oooool4o`0002_ooooo001Cooooo`03o`000?oooooooooo00?o
oooo00Go0000onEU0?oUI@3oiFD0o`000005onUG0003o`000?oNO@3o000000Goi6`000?o0000omRA
0?l000001OoNO0000ol0003odj00o`000005om^80003o`000?o?Z@3o000000GofHh000Co0000olj/
0?o>[03o00000ooISP000ol0003ocjX0olnZ0002olnZ00;o00001_oBXP000ol0003ob[L0olZg0002
o`000003omND0?l0003od:H000God:H000?o0000olZf0?o:]P000_l000000ooHT03o0000omBM0005
omBM0003o`000?o@Y`3od:L000;od:L000?o0000olf^0?l000000_l000000ooLQ@3o0000omZ90004
omZ90003o`000?oJR`3ofX/000?ofX/000?o0000omZ90?oJR@000ooJR@000ol0003og8D0omb50006
o`0001Kooooo1?l0000_ooooo`00E?ooool00ol0003oooooooooo`03ooooo`03o`000?oUI@3o0000
00KojEL00_l00006onA/00;o00001_oNO002o`0000KofhP00_l00006omV>0003o`000?o>[03o0000
00CofHh000?o0000olnZ0?o?ZP000_l000000ooJR@3o0000om:R0005om:R0003o`000?o:]`3o0000
00Coei@000?o0000om2V0?o@YP000oo@YP000ol0003ob[H0o`000004omR@0003o`000?oDW@3oe9d0
00?oe9d000?o0000om2W0?o@Y`000_o@Y`02o`0000Gog8D000?o0000omZ90?oJR@000ooJR@000ol0
003ofX/0omZ;0002omZ;0004o`000?oJR@3ofXT0omZ900Go00006Oooool3o`0003?ooooo001Eoooo
o`;o00001?ooool2o`0000GojEL000?o0000one90?l000001OoTK0000ol0003ojET0o`000005omil
0003o`000?oUIP3o000000GofhP000?o0000on=^0?l000001_oISP02o`0000GofHh000?o0000olnZ
0?l000001?oJR@000ol0003odZ80om:R0003om:R00;o00001OoGU0000ol0003od:H0om2V0003om2V
00;o00001OoHT0000ol0003oe9d0omBM0003omBM0003o`000?o@Y`3o000000;o000000?ogWh0o`00
0?oLQ@001?oLQ@000ol0003ofXT0omZ90003omZ90004o`000?oJR`3ofX/0omZ;00Go00006_ooool4
o`0003Kooooo001Gooooo`03o`000?oooooooooo00?ooooo00Go0000onUG0?oYE`3ojEL0o`000003
one90005o`000?oTK03oi6`0onA/0?l000000ooYF@001Ol0003ogW`0omil0?oNO03o000000?oiFH0
00Go0000om^80?oKR03ofhP0o`000003on=^0003o`000?oISP3ofHh000;ofHh000?o0000on9a0?l0
00001OoISP02o`0000KofXT000?o0000om:R0?oBXP000_l000000ooNOP3o0000omND0005omND0003
o`000?o@YP3od:H000;o000000?ogH00o`000?oHT0001OoHT0000ol0003oe9d0omBM0002omBM00;o
00001OoNOP000ol0003og8D0omb50003omb50003o`000?oJR@3ofXT000;ofXT01?l0000Kooooo`Co
0000>_ooool005Sooooo00?o0000ooooooooool00oooool00ol0003ojEL0o`000005one90003o`00
0?oTK03o000000GojET000?o0000omil0?l000001OoUIP000ol0003ofhP0o`000005on=^0004o`00
0?oISP3ofHh0o`0000?ohW4000Oo0000omV>0?oISP3ofHh0o`000?oSK`3o000000KofXT000?o0000
om:R0?l000001?oNOP000ol0003oei@0omND0003omND0003o`000?o@YP3o000000CogH0000?o0000
omR@0?oHT0000ooHT0000ol0003oe9d0o`000002o`000003on5d0?l0003ogWh000CogWh000?o0000
omb50?oLQ@000ooLQ@000ol0003ofXT0o`000002o`0001_ooooo1?l0000nooooo`00FOooool00ol0
003oooooooooo`03ooooo`03o`000?o]B@3okDT000CokDT00_l00006onUI00;o00001_oUIP02o`00
00Kohfh000?o0000omV>0?l000001?oRL@001?l0003ofHh0omV>0?l00003on=_0003o`000?oJR@3o
fXT000?ofXT00_l00005omin0003o`000?oGU03oei@000?oei@00_l00005omf00003o`000?oHT03o
f90000?of9000_l00005on5d0003o`000?oNOP3ogWh000;ogWh000?o0000omb50?oLQ@000ooLQ@02
o`0001[ooooo1?l00012ooooo`00F_ooool2o`0000?ooooo00?o0000one90?o]B@000oo]B@000ol0
003olCX0o`000005onUI0003o`000?o^AP3o000000GoiFH000?o0000ona?0?l000001_oSKP02o`00
00GohW4000?o0000omV>0?l000001?oSK`000ol0003ofXT0omZ90002omZ90003o`000?oUI`3o0000
00KogWh000?o0000omND0?oGU0000_l000000ooSK`3o0000omf00005omf00003o`000?oHT03of900
00;o000000?oi6P0o`000?oQM0001?oQM0000ol0003ogWh0omin0003omin0003o`000?oLQ@3o0000
00;o00006?ooool4o`0004Kooooo001Looooo`05o`000?ooooooooooooooool000000oo]B@001Ol0
003olCX0oo4j0?oa>P3o000000?ojET000Go0000oni60?o^AP3okTH0o`000003onEV0005o`000?o/
C`3ok4l0ona?0?l000001?oSKP000ol0003ojU@0o`000005on9a00;o00001_oSK`001?l0003ofXT0
omZ90?l00003onEW0003o`000?oNOP3ogWh000?ogWh000?o0000omND0?l000001?oSK`000ol0003o
gH00omf00003omf00003o`000?oHT03o000000Coi6P000?o0000on5d0?oQM0000_oQM0000ol0003o
gWh0omin0002omin00?o00006?ooool3o`0004[ooooo001Mooooo`07o`000?ooooooooooooooool0
003okDT0o`000005oo4j0003o`000?oYF@3o000000GokTH000?o0000onEV0?l000001Oo/C`001?l0
003ohfh0on=^0?l00003onYD0007o`000?oRL@3ohW40on9a0?l0003ojU@0o`000006on=_0003o`00
0?oJR@3o000000CoiFL000?o0000omin0?oNOP000ooNOP02o`0000Kohfl000?o0000omf00?oMP000
0_oMP002o`0000Goi6P000?o0000on5d0?oQM0000ooQM004o`0001Oooooo1?l0001=ooooo`00G_oo
ool01Ol0003ooooooooooooooooo000000KolCX00_l00006oni600;o00001_o/C`000ol0003ohfh0
o`000004onYD0004o`000?oRL@3ohW40o`0000?ojU@000?o0000on=_0?oSK`000ooSK`02o`0000Ko
iFL000?o0000omin0?oNOP000_l000000ooXF`3o0000on=_0005on=_0003o`000?oMP03o000000;o
000000?oj5/0o`000?oTJ0001?oTJ0000ol0003ohG@0on5d0002on5d00;o00005_ooool4o`00057o
oooo001Oooooo`;o00000_ooool01?l0003olCX0oo4j0?oa>P02o`0000;omB`000Co0000oni60?o^
AP3okTH00_l000000ooc=03o0000ona?0005ona?00;o00001OoZE0000ol0003ohW40o`000005onYD
0003o`000?oSK`3ohfl000;o000000?oje00o`000?oUI`001OoUI`000ol0003ogWh0o`000004onQK
0003o`000?oSK`3ohfl000?ohfl00_l00005onQK0003o`000?oTJ03oi6P000?oi6P01?l0000Doooo
o`Co0000EOooool0067ooooo00Ko0000oooooooooooo0000oo4j0?l00005ooD/0003o`000?o^AP3o
000000Colc@000Co0000ona?0?o/C`3ok4l00_l000000ooa>P3o0000onYD0004onYD00;o00001_oZ
E0000ol0003ohfl0o`000004on]@0003o`000?oUI`3oiFL000?oiFL00_l00006onQK0003o`000?oS
K`3ohfl000;o000000?okD`0o`000?oXF`001?oXF`000ol0003oi6P0onAX0002onAX00;o00004ooo
ool4o`0005Wooooo001Rooooo`04o`000?ooooooooooo`0000KomB`00_l00006oo<d0003o`000?o/
C`3o000000ColCX000?o0000onYD0?oZE0000_l000000ooa?03o0000onYD0005onYD00;o00001_o[
D0000ol0003oiFL0onEW0002o`000003oni80?l0003oj5/000Goj5/000?o0000on=_0?l000001?o]
C0000ol0003oj5/0onQK0002onQK0003o`000?oTJ03o000000;o00004_ooool3o`0005gooooo001S
ooooo`04o`000?ooooooooooo`0000?omB`00_l000000ooh8@3o0000oo<d0005oo<d00;o00001Ooa
>P000ol0003ojU@0o`000004oo4l0004o`000?oZE03ojU@0onYD00;o000000?olC/0o`000?o[D000
1Oo[D0000ol0003oiFL0o`000004oni80003o`000?oXF`3oj5/000?oj5/00_l00005one<0003o`00
0?oXF`3oj5/000;oj5/00_l0000Aooooo`Co0000H?ooool006Cooooo0_l000001?oooooo0000ooD/
0?l00004ooPQ0004o`000?oc=03olc@0oo<d00;o000000?omRH0o`000?oa>P001?oa>P02o`0000Ko
lC`000?o0000onYD0?l000001?oa>`000ol0003oje00on]@0003on]@00;o00001_o^B0000ol0003o
j5/0o`000002o`000003oo4l0?l0003okD`000CokD`000?o0000onQK0?l000000_l0000?ooooo`Co
0000I?ooool006Kooooo00?o0000ooooool000001_oh8@000ol0003olc@0o`000004ooHV0003o`00
0?oa>P3olCX000;o000000?omRP0o`000?oa?0001Ooa?002o`0000KolC/000?o0000on]@0?l00000
0_l000000oob=P3o0000oni80005oni800;o00001Ooa?0000ol0003okD`0one<0002one<00;o0000
3_ooool4o`0006Sooooo001Wooooo`03o`000?oooooo000000Gon2400_l00005ooHV0003o`000?oa
>P3o000000ComRP000Co0000oo4l0?oa?03olC`00_l000000oof:03o0000oo4k0005oo4k00;o0000
1Oob=P001?l0003okTP0oni80?o^B002o`000003oo@^0?l0003olC`000ColC`000?o0000one<0?l0
00000_l0000<ooooo`Co0000K?ooool006Sooooo00Co0000ooooool0003on2400ol00002ooTJ0003
o`000?of9P3omRH000;omRH00_l00006ooHX0003o`000?oa?03o000000ComRP000Co0000oo4k0?oa
>`3olC/00_l000000oof9P3o0000oo8f0005oo8f0003o`000?o^B03o000000Com2h000?o0000oo4l
0?oa?0000_oa?002o`0000_ooooo1?l0001`ooooo`00JOooool01?l0003oooooo`000?l00005ooTJ
0004o`000?of9P3o0000o`0000;onA`000?o0000ooHX0?of:0000oof:002o`0000KomRP000?o0000
oo4k0?l000001?of9P000ol0003olSH0oo8f0003oo8f00;o00001Ood;P000ol0003olC`0oo4l0002
o`0000[ooooo0ol0001dooooo`00J_ooool2o`000003ooooool0003onAX000;onAX01?l00004ooTL
0003o`000?of:03o000000;o00000_oi7@000ol0003omRP0ooHX0003ooHX00;o00001_of9P000ol0
003olSH0o`000002o`000003ooLR0?l0003om2h000Com2h000?o0000oo4l0?l000002?ooool4o`00
07Oooooo001/ooooo`03o`000?oooooo000000;o00001?oi6P000ol0003onA`0ooTL0004o`0000Go
nAd000?o0000ooHX0?l000000_l00002ooTL0003o`000?of9P3omRH000?omRH00_l00005ooLR0003
o`000?od;P3om2h000;om2h00_l00005ooooo`Co0000Noooool006gooooo00Co0000oooooooooooo
00000ooi6P04o`0000ConAT000Co0000ooTM0?oi7@3onAd00ol00006ooTL0003o`000?of9P3o0000
00;o000000?onA/0o`000?og8P001?og8P000ol0003om2h0o`000002o`0000?ooooo1?l0001ooooo
o`00K_ooool00ol0003oooooooooo`03o`0000?omb8000Co0000ooTI0?oi6@3onAT01Ol00003ooTI
0003o`000?oi703onA`000?onA`00_l00005ooTK0004o`000?og8P3omb80ooLR00?o00000_ooool4
o`0008?ooooo001_ooooo`;o00000oooool7o`0000Con20000?o0000ooTI0?oi6@000_oi6@000ol0
003onA`0o`000002o`0000;onAX000?o0000ooTK0?oi6`000_oi6`04o`0000;ooooo0ol00027oooo
o`00LOooool00ol0003oooooooooo`03oooooa7o00001?oi6P001?l0003onA/0o`000?l00002oooo
o`Co0000R_ooool007;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooooaCo
0000S_ooool007?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000
T_ooool007Cooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002Fooooo`00M_ooool0
1?l0003oooooooooool00009ooooo`?o0000V_ooool007Oooooo00?o0000ooooool000001Oooool4
o`0009gooooo001hooooo`;o000000?oooooo`000?l000000_l0002Qooooo`00NOooool2o`000:Go
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000/ooooo`?o0000R_ooool00ol0
003oooooooooo`0[ooooo`?o00005Oooool00ol0003oooooooooo`0Nooooo`00;Oooool00ol0003o
ooooooooo`28ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Mooooo`009oooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo
0ol00003ooooo`Co000000?oooooo`000?l000000ol00007ooooo`?o00001?ooool4o`0000?ooooo
0_l00002ooooo`Ko00001_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003o`000003oooo
ool0003o000000?o00000_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3o`000004oooo
ool0003o0000ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000;o
oooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_ooool:o`00
00Gooooo00?o0000ooooooooool07?ooool002Kooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?oo
ool002Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00000_oo
ool00ol0003oooooooooo`02ooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`0000Go
oooo1Ol00008ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000002oooo
o`?o00000oooool00ol0003oooooo`000002ooooo`Go00000oooool01?l0003oooooooooooooool5
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00000_ooool3o`0000Gooooo00?o0000ooooooooool07?ooool002Ko
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0
0005ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`0Looooo`00
9_ooool01_l0003ooooooooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo0ol00004oooo
o`?o00000oooool2o`0000Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00002
ooooo`;o00000oooool4o`0000?ooooo0ol00009ooooo`05o`000?ooooooooooo`000?ooool00ol0
0004ooooo`Co00000_ooool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0000;ooooo1?l00003ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00_oo
ool6o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o00000ooo
ool4o`0000Cooooo00?o0000ooooooooool07?ooool002Kooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01gooooo000Wooooo`?o00002Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00gooooo0ol00009ooooo`Co00002Oooool00ol0003ooooo
ooooo`02ooooo`;o00002_ooool4o`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo
0_l0000^ooooo`03o`000?oooooooooo01Sooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo
0_l0000;ooooo`03o`000?oooooooooo01kooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0484986, 0.0647328, \
0.00350953, 0.00350953}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(CompiledFunction[
            If[#1 == 0 && #2 == 
                  0, \(-0.07627715110652229`\), \(\(21.130111719246354`\)\(\
\[InvisibleSpace]\)\) + 
                5.697048660645184`*^-9\ Cos[
                    2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) - 
                1.7574149910441521`*^-10\ Cos[
                    4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 + 
                12.758488739572979`\ \((\(-1\) + 
                      0.012653144071744893`\ \((#1\^2 + #2\^2)\))\) + 
                9.316500298313199`*^-7\ Cos[
                    2\ ArcTan[#1, #2]]\ \((\(-0.01897971610761734`\)\ \
\((#1\^2 + #2\^2)\) + 0.00016010205490033292`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                8.460919478531943`\ \((1 - 
                      0.03795943221523468`\ \((#1\^2 + #2\^2)\) + 
                      0.00024015308235049936`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                5.8556142465598055`*^-6\ Cos[
                    4\ ArcTan[#1, #2]]\ \((\(-0.00020012756862541615`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 1.5193457751272423`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) + 
                5.975099927832889`*^-7\ Cos[
                    2\ ArcTan[#1, #2]]\ \((0.03795943221523468`\ \((#1\^2 + \
#2\^2)\) - 0.0008005102745016646`\ \((#1\^2 + #2\^2)\)\^2 + 
                      3.7983644378181055`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                0.012562518481132398`\ \((\(-1\) + 
                      0.07591886443046936`\ \((#1\^2 + #2\^2)\) - 
                      0.0012007654117524968`\ \((#1\^2 + #2\^2)\)\^2 + 
                      5.064485917090807`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) + 
                1.3989860273983027`*^-7\ Cos[
                    6\ ArcTan[#1, #2]]\ \((\(-1.7725700709817826`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 1.2816333991654607`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                4.9492089474405346`*^-6\ Cos[
                    4\ ArcTan[#1, #2]]\ \((0.0006003827058762484`\ \((#1\^2 + \
#2\^2)\)\^2 - 0.000010635420425890695`\ \((#1\^2 + #2\^2)\)\^3 + 
                      4.485716897079113`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                2.2412576314082155`*^-7\ Cos[
                    2\ ArcTan[#1, #2]]\ \((\(-0.06326572035872446`\)\ \
\((#1\^2 + #2\^2)\) + 0.0024015308235049936`\ \((#1\^2 + #2\^2)\)\^2 - 
                      0.00002658855106472674`\ \((#1\^2 + #2\^2)\)\^3 + 
                      8.971433794158226`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                0.0004568292709131447`\ \((1 - 
                      0.12653144071744893`\ \((#1\^2 + #2\^2)\) + 
                      0.0036022962352574906`\ \((#1\^2 + #2\^2)\)\^2 - 
                      0.000035451401419635653`\ \((#1\^2 + #2\^2)\)\^3 + 
                      1.1214292242697782`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
            "-CompiledCode-"]\),
          False,
          Editable->False], ",", "1.2283068586045016`*^-6", 
        ",", \({SphericalAberration \[Rule] 201.3158811045179`, 
          Astigmatism \[Rule] 0.00014539481076208756`, 
          FieldCurvature \[Rule] \(-151.691748993035`\), 
          Distortion \[Rule] \(-1.6520393473120985`*^-14\), 
          Coma \[Rule] 5.312710648146108`*^-14}\)}], "}"}]], "Output",
  CellLabel->"Out[33]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.5 PointSpreadFunction", "Subsection",
  CellTags->{"AOG0.", "5.5", "AOG5.", "AOG5.5"}],

Cell[CellGroupData[{

Cell["?PointSpreadFunction", "Input",
  CellLabel->"In[34]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[BoxData[
    \("PointSpreadFunction[system, options] calculates the point spread \
function of the optical system at a particular wavelength. \n\n\
PointSpreadFunction first calls PupilFunction to calculate the exit pupil \
function. Finally, PointSpreadFunction calculates a point spread function by \
using the Fourier transform of the calculated complex field. As input, \
PointSpreadFunction takes either an optical system or the returned output \
from PupilFunction. The optical system must contain a light source followed \
by the imaging optics with the approximate focal surface as its last element. \
For FindImagePoint->True, the last system element need not be the exact focal \
surface, since the exact focal surface position is automatically determined. \
When the default FindImagePoint->False is given, the last system element is \
assumed to be the exact focal surface. In addition, the light source need \
only contain a small number of rays (since the actual number of rays is \
internally specified). When FindPupils->False is used, the optical surface \
preceding the image surface is taken as the field stop. The user can also \
give as input a specific focal point or exit pupil position with the \
FocalPoint and ExitPupilPosition options. \n\nNote: PointSpreadFunction works \
equally well for both point sources and planar sources, as long as the \
described imaging system contains a focus. If a one-dimensional light source \
is used (ie. WedgeOfRays or LineOfRays), then a one-dimensional point spread \
function is calculated. If a two-dimensional light source is used (ie. \
PointOfRays or GridOfRays), then the point spread calculations are carried \
out in two-dimensions. Warning: in general, one-dimensional and \
two-dimensional results are not fully equivalent to each other. \n\n\
PointSpreadFunction is also a label used with the RenderedParameters option. \
PointSpreadFunction is also the name of a returned rule from \
PointSpreadFunction that gives the point spread function result for a \
specific image point. See also: IntensityTransform, FindLensParameters, \
PupilFunction, PSF, and OpticalTransferFunction."\)], "Print",
  CellTags->{"Info3313756675-1546738", "AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[PointSpreadFunction]", "Input",
  CellLabel->"In[35]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[BoxData[
    \({SpatialScale \[Rule] 1, NumberOfPoints \[Rule] 128, 
      NumberOfRays \[Rule] Automatic, SignalPlotCutoff \[Rule] 0.01`, 
      PaddingFactor \[Rule] Automatic, FocalFraction \[Rule] Automatic, 
      FindImagePoint \[Rule] False, FindPupils \[Rule] True, 
      FieldStopPosition \[Rule] Automatic, ShowPerfectCase \[Rule] False, 
      NormalizePlot \[Rule] False, 
      GeometricPointSpreadFunction \[Rule] False, 
      InterpolationOrder \[Rule] 1, IntensityTransform \[Rule] True, 
      PlotPoints \[Rule] 64, FilterTrace \[Rule] True, 
      ColorFunction \[Rule] \((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ \
0.65`, 1, #1\ 0.9` + 0.1`] &)\), 
      RenderedParameters \[Rule] {PointSpreadFunction, 
          OpticalPathDifference}, Plot2D \[Rule] True}\)], "Output",
  CellLabel->"Out[35]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["PSF[pupfun,NumberOfPoints->128]", "Input",
  CellLabel->"In[36]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 7.54691 0.0093833 4.56039e-06 [
[.04719 -0.00312 -15 -9 ]
[.04719 -0.00312 15 0 ]
[.19812 -0.00312 -15 -9 ]
[.19812 -0.00312 15 0 ]
[.34906 -0.00312 -15 -9 ]
[.34906 -0.00312 15 0 ]
[.5 -0.00312 -3 -9 ]
[.5 -0.00312 3 0 ]
[.65094 -0.00312 -12 -9 ]
[.65094 -0.00312 12 0 ]
[.80188 -0.00312 -12 -9 ]
[.80188 -0.00312 12 0 ]
[.95281 -0.00312 -12 -9 ]
[.95281 -0.00312 12 0 ]
[.01131 .10059 -30 -4.5 ]
[.01131 .10059 0 4.5 ]
[.01131 .1918 -30 -4.5 ]
[.01131 .1918 0 4.5 ]
[.01131 .28301 -30 -4.5 ]
[.01131 .28301 0 4.5 ]
[.01131 .37421 -30 -4.5 ]
[.01131 .37421 0 4.5 ]
[.01131 .46542 -36 -4.5 ]
[.01131 .46542 0 4.5 ]
[.01131 .55663 -36 -4.5 ]
[.01131 .55663 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04719 .00938 m
.04719 .01563 L
s
[(-0.06)] .04719 -0.00312 0 1 Mshowa
.19812 .00938 m
.19812 .01563 L
s
[(-0.04)] .19812 -0.00312 0 1 Mshowa
.34906 .00938 m
.34906 .01563 L
s
[(-0.02)] .34906 -0.00312 0 1 Mshowa
.5 .00938 m
.5 .01563 L
s
[(0)] .5 -0.00312 0 1 Mshowa
.65094 .00938 m
.65094 .01563 L
s
[(0.02)] .65094 -0.00312 0 1 Mshowa
.80188 .00938 m
.80188 .01563 L
s
[(0.04)] .80188 -0.00312 0 1 Mshowa
.95281 .00938 m
.95281 .01563 L
s
[(0.06)] .95281 -0.00312 0 1 Mshowa
.125 Mabswid
.08492 .00938 m
.08492 .01313 L
s
.12265 .00938 m
.12265 .01313 L
s
.16039 .00938 m
.16039 .01313 L
s
.23586 .00938 m
.23586 .01313 L
s
.27359 .00938 m
.27359 .01313 L
s
.31133 .00938 m
.31133 .01313 L
s
.3868 .00938 m
.3868 .01313 L
s
.42453 .00938 m
.42453 .01313 L
s
.46227 .00938 m
.46227 .01313 L
s
.53773 .00938 m
.53773 .01313 L
s
.57547 .00938 m
.57547 .01313 L
s
.6132 .00938 m
.6132 .01313 L
s
.68867 .00938 m
.68867 .01313 L
s
.72641 .00938 m
.72641 .01313 L
s
.76414 .00938 m
.76414 .01313 L
s
.83961 .00938 m
.83961 .01313 L
s
.87735 .00938 m
.87735 .01313 L
s
.91508 .00938 m
.91508 .01313 L
s
.00945 .00938 m
.00945 .01313 L
s
.99055 .00938 m
.99055 .01313 L
s
.25 Mabswid
0 .00938 m
1 .00938 L
s
.02381 .10059 m
.03006 .10059 L
s
[(20000)] .01131 .10059 1 0 Mshowa
.02381 .1918 m
.03006 .1918 L
s
[(40000)] .01131 .1918 1 0 Mshowa
.02381 .28301 m
.03006 .28301 L
s
[(60000)] .01131 .28301 1 0 Mshowa
.02381 .37421 m
.03006 .37421 L
s
[(80000)] .01131 .37421 1 0 Mshowa
.02381 .46542 m
.03006 .46542 L
s
[(100000)] .01131 .46542 1 0 Mshowa
.02381 .55663 m
.03006 .55663 L
s
[(120000)] .01131 .55663 1 0 Mshowa
.125 Mabswid
.02381 .03219 m
.02756 .03219 L
s
.02381 .05499 m
.02756 .05499 L
s
.02381 .07779 m
.02756 .07779 L
s
.02381 .12339 m
.02756 .12339 L
s
.02381 .14619 m
.02756 .14619 L
s
.02381 .169 m
.02756 .169 L
s
.02381 .2146 m
.02756 .2146 L
s
.02381 .2374 m
.02756 .2374 L
s
.02381 .2602 m
.02756 .2602 L
s
.02381 .30581 m
.02756 .30581 L
s
.02381 .32861 m
.02756 .32861 L
s
.02381 .35141 m
.02756 .35141 L
s
.02381 .39702 m
.02756 .39702 L
s
.02381 .41982 m
.02756 .41982 L
s
.02381 .44262 m
.02756 .44262 L
s
.02381 .48822 m
.02756 .48822 L
s
.02381 .51103 m
.02756 .51103 L
s
.02381 .53383 m
.02756 .53383 L
s
.02381 .57943 m
.02756 .57943 L
s
.02381 .60223 m
.02756 .60223 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02741 .01476 L
.03076 .0148 L
.03265 .01483 L
.03444 .01485 L
.03542 .01486 L
.03598 .01487 L
.0365 .01489 L
.03741 .01498 L
.03837 .01508 L
.04567 .0158 L
.04768 .016 L
.04825 .01606 L
.0488 .01611 L
.04929 .01611 L
.04983 .01611 L
.05372 .01608 L
.05593 .01606 L
.05801 .01604 L
.05989 .01602 L
.0604 .01602 L
.06094 .01601 L
.06191 .01605 L
.06245 .01609 L
.06295 .01613 L
.06406 .01622 L
.06607 .01638 L
.07064 .01674 L
.07251 .01689 L
.07346 .01696 L
.07399 .017 L
.0745 .01698 L
.07668 .0169 L
.0787 .01682 L
.08235 .01668 L
.08428 .01661 L
.08527 .01657 L
.08583 .01655 L
.08634 .01653 L
.08686 .01653 L
.0874 .01653 L
.08841 .01653 L
.09028 .01653 L
.09395 .01654 L
.09579 .01654 L
.09777 .01654 L
.09835 .01655 L
.0989 .01655 L
.0994 .01654 L
.09994 .01653 L
Mistroke
.10197 .01648 L
.10551 .0164 L
.10738 .01635 L
.10935 .01631 L
.11018 .01629 L
.11107 .01627 L
.11205 .01623 L
.11297 .01619 L
.11629 .01602 L
.12048 .01582 L
.12231 .01573 L
.12328 .01568 L
.1243 .01565 L
.12522 .01569 L
.12624 .01573 L
.12803 .01581 L
.13155 .01596 L
.13352 .01604 L
.13559 .01613 L
.13612 .01615 L
.13668 .01617 L
.13729 .01615 L
.13786 .01613 L
.13994 .01608 L
.14376 .01597 L
.14585 .01591 L
.1478 .01586 L
.14875 .01583 L
.14977 .0159 L
.15035 .01596 L
.15091 .01602 L
.15194 .01614 L
.15575 .01656 L
.16436 .01735 L
.17997 .01845 L
.20962 .02078 L
.2175 .0214 L
.22136 .02181 L
.22306 .02198 L
.22402 .02208 L
.22491 .02208 L
.22578 .02202 L
.22672 .02196 L
.22862 .02183 L
.23263 .02156 L
.23493 .02141 L
.23548 .02137 L
.23606 .02133 L
.23656 .0213 L
.2371 .02129 L
Mistroke
.23811 .02132 L
.23905 .02135 L
.24117 .02142 L
.24501 .02154 L
.24705 .0216 L
.24816 .02164 L
.24871 .02166 L
.24921 .02167 L
.25021 .02169 L
.25129 .0217 L
.25317 .02172 L
.25685 .02176 L
.26041 .0218 L
.26378 .02183 L
.26766 .02185 L
.2712 .02187 L
.27211 .02188 L
.27308 .02188 L
.2739 .02189 L
.27481 .02196 L
.27579 .02214 L
.27684 .02233 L
.27874 .02267 L
.28211 .02329 L
.28578 .02396 L
.2868 .02414 L
.28737 .02421 L
.28789 .02425 L
.28985 .02442 L
.29413 .02479 L
.29602 .02495 L
.29702 .02503 L
.29807 .02512 L
.29899 .0252 L
.3 .02538 L
.30092 .02562 L
.30178 .02584 L
.33186 .0325 L
.33369 .03274 L
.33568 .033 L
.33659 .03312 L
.33755 .03331 L
.33927 .03379 L
.34341 .03495 L
.34716 .03599 L
.34819 .03628 L
.34876 .03644 L
.3493 .03659 L
.3498 .03669 L
.35034 .03673 L
Mistroke
.35129 .0368 L
.35581 .03712 L
.35963 .03739 L
.36067 .03747 L
.36125 .03751 L
.3618 .03755 L
.3623 .0376 L
.36286 .03772 L
.36383 .03792 L
.3716 .03951 L
.37367 .03994 L
.37426 .04006 L
.37482 .0402 L
.37533 .04039 L
.37587 .04059 L
.37984 .04207 L
.39463 .04649 L
.39818 .04728 L
.3992 .04751 L
.40017 .04786 L
.40104 .04833 L
.40198 .04884 L
.40616 .0511 L
.41006 .05321 L
.41416 .05624 L
.41852 .06048 L
.42052 .06242 L
.42261 .06446 L
.42348 .0653 L
.4244 .0662 L
.42542 .06806 L
.42636 .07034 L
.43361 .08782 L
.43572 .09289 L
.43622 .09411 L
.43675 .09539 L
.43771 .09893 L
.43856 .10387 L
.43949 .10931 L
.44143 .12056 L
.45558 .22162 L
.47063 .37377 L
.47902 .46251 L
.4831 .50412 L
.48488 .52224 L
.4868 .54181 L
.48782 .55018 L
.48876 .55433 L
.4906 .56249 L
.49464 .58041 L
Mistroke
.49679 .58994 L
.4988 .59884 L
.49981 .60332 L
.50037 .60251 L
.50089 .60023 L
.50319 .59006 L
.50702 .5731 L
.50904 .56416 L
.51118 .55466 L
.51208 .55068 L
.51305 .54339 L
.51411 .53254 L
.51511 .52236 L
.51875 .48531 L
.53398 .32324 L
.54203 .24328 L
.54646 .20304 L
.54863 .18328 L
.54958 .17461 L
.55063 .16674 L
.55257 .15546 L
.55463 .14352 L
.55897 .11836 L
.56086 .10742 L
.5619 .10138 L
.56288 .09644 L
.5638 .09422 L
.5648 .0918 L
.56654 .08757 L
.57021 .07867 L
.57214 .074 L
.57417 .06908 L
.57503 .06699 L
.57595 .06586 L
.57696 .06487 L
.57791 .06395 L
.58134 .06061 L
.58507 .05696 L
.5869 .05517 L
.5886 .0539 L
.59061 .05282 L
.5928 .05164 L
.59662 .04959 L
.59843 .04861 L
.59943 .04807 L
.60037 .0476 L
.60091 .04748 L
.60149 .04734 L
.60251 .04711 L
.60451 .04664 L
Mistroke
.61287 .04468 L
.64435 .03713 L
.67465 .03166 L
.69012 .02793 L
.70685 .02466 L
.71091 .02429 L
.7147 .0238 L
.71866 .0231 L
.72089 .02271 L
.72301 .02233 L
.7248 .02202 L
.72582 .02188 L
.72676 .02187 L
.73018 .02185 L
.73787 .02179 L
.74146 .02176 L
.74533 .02172 L
.74711 .02171 L
.74898 .02169 L
.74975 .02169 L
.75058 .02168 L
.75148 .02165 L
.75233 .02163 L
.75663 .02151 L
.75874 .02145 L
.76068 .0214 L
.7616 .02137 L
.76245 .02135 L
.76335 .02134 L
.76433 .0214 L
.76828 .02165 L
.77213 .0219 L
.77319 .02197 L
.77431 .02204 L
.77486 .02207 L
.77538 .02211 L
.77634 .02206 L
.77727 .02197 L
.77825 .02187 L
.78001 .02169 L
.78399 .02129 L
.7857 .02112 L
.78664 .02103 L
.78753 .02094 L
.78836 .02087 L
.78926 .02085 L
.79084 .02083 L
.79471 .02077 L
.7966 .02074 L
.79834 .02071 L
Mistroke
.7992 .0207 L
.80014 .02068 L
.80103 .02064 L
.80186 .02054 L
.80564 .02011 L
.81368 .01917 L
.82996 .01759 L
.83388 .0174 L
.83595 .0173 L
.83708 .01724 L
.83763 .01721 L
.83813 .01719 L
.83905 .0171 L
.84004 .01699 L
.84214 .01676 L
.84583 .01636 L
.84755 .01617 L
.84937 .01597 L
.85032 .01587 L
.85087 .01581 L
.85137 .01582 L
.85323 .01587 L
.85686 .01596 L
.86023 .01604 L
.86199 .01608 L
.86297 .0161 L
.86386 .0161 L
.86484 .01606 L
.86591 .01602 L
.86784 .01594 L
.87173 .01579 L
.87385 .01571 L
.87489 .01567 L
.87584 .01563 L
.87672 .01566 L
.87755 .0157 L
.87939 .01579 L
.88329 .01598 L
.88683 .01616 L
.88768 .0162 L
.88857 .01624 L
.88933 .01626 L
.89017 .01628 L
.89204 .01632 L
.89407 .01637 L
.8976 .01646 L
.89958 .01651 L
.90015 .01652 L
.90068 .01654 L
.90169 .01654 L
Mistroke
.90265 .01654 L
.90353 .01654 L
.90552 .01655 L
.90908 .01655 L
.91083 .01655 L
.91242 .01655 L
.91324 .01655 L
.9141 .01657 L
.91497 .0166 L
.91591 .01664 L
.91976 .01678 L
.92172 .01685 L
.92386 .01693 L
.92483 .01696 L
.92537 .01698 L
.92587 .017 L
.92675 .01696 L
.92772 .01688 L
.93496 .01634 L
.93705 .01618 L
.93755 .01614 L
.93809 .0161 L
.93905 .01606 L
.93998 .01607 L
.94083 .01608 L
.94278 .01609 L
.94687 .01611 L
.94795 .01612 L
.9491 .01612 L
.94966 .01613 L
.95019 .01613 L
.95118 .01613 L
.95193 .01606 L
.95261 .01599 L
.95417 .01584 L
.95745 .01552 L
.96042 .01523 L
.96188 .01509 L
.96251 .01503 L
.96321 .01496 L
.96395 .01491 L
.96465 .0149 L
.96621 .01488 L
.96951 .01483 L
.97619 .01473 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[36]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`009oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000Boooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool3o`00017ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00005oooool2o`0001[ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00004Oooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0ol0000Aooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000oooool3o`0000Gooooo000Vooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo00Co
0000oooooooooooo00006?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`007oooool5o`00
00;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool01oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01Ol0003o
ooooooooool0003ooooo00Go00002Oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000
6?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool04?ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01Ol0
000@ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00;ooooo000Vooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
oooooooo0000ooooo`04o`00017ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0
000Hooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0002ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
ooooool0003ooooo00Co00001Oooool002Kooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0001Cooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooo0000017ooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0
000Hooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo0000017ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0000Sooooo000Vooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000oooool2o`00017ooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0
000Hooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`;o00004Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01Oooool002Oooooo0_l0000:ooooo`;o00001?ooool2o`0001;ooooo
0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`;o00002_ooool2o`0000?ooooo
0ol0000Hooooo`;o00006_ooool2o`0000[ooooo0_l00003ooooo`?o00004_ooool2o`0000[ooooo
0_l00005ooooo`03o`000?oooooooooo013ooooo0_l0000:ooooo`;o00001?ooool2o`0000Gooooo
003oooooob7ooooo000Xooooo`03o`000?oooooooooo0?Gooooo000Xooooo`03o`000?oooooooooo
0?Gooooo000Xooooo`03o`000?oooooooooo0?Gooooo000Rooooooco00000_ooool002Cooooo00Co
0000oooooooooooooooo3?l00003oooooaCo00002Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo5?l00003ooooo`co00000oooool00ol0003oooooooooo`02ooooo`00:?oo
ool00ol0003oooooooooo`09ooooo`Co00004oooool9o`0009Oooooo2ol0000Aooooo`Go00005?oo
ool002Sooooo00?o0000ooooooooool0:OoooolHo`0006Sooooo6?l0000dooooo`00:?ooool00ol0
003oooooooooo`11ooooo`Oo0000F_ooool7o`0004cooooo000Xooooo`;o0000BOooool3o`0005?o
oooo1?l0001Cooooo`00:?ooool00ol0003oooooooooo`1;ooooo`Go0000Boooool3o`0005Oooooo
000Xooooo`03o`000?oooooooooo04oooooo1ol00011ooooo`Co0000F_ooool002Sooooo00?o0000
ooooooooool0EOooool4o`0003[ooooo1?l0001Nooooo`00:?ooool00ol0003oooooooooo`1Ioooo
o`Co0000<?ooool6o`0006;ooooo000Xooooo`03o`000?oooooooooo05cooooo0_l0000^ooooo`;o
0000Ioooool002Sooooo0_l0001Oooooo`;o0000:_ooool2o`0006Wooooo000Xooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Xooooo`00:?ooool0
0ol0003oooooooooo`1Pooooo`;o00009_ooool2o`0006_ooooo000Xooooo`03o`000?oooooooooo
067ooooo0_l0000Tooooo`;o0000K?ooool002Sooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo06_ooooo000Xooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`1[ooooo`00:?ooool2o`0006Cooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`1/ooooo`00:?ooool00ol0003oooooooooo`1S
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0K?ooool002Sooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06gooooo0007ooooo`Go
00000oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06gooooo0008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1Tooooo`;o00007oooool00ol0003oooooooooo`1]ooooo`002Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo06kooooo000:ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`?o0000IOooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo06kooooo0007ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`1^ooooo`001oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0K_ooool000Sooooo0ol00004
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Koooool002Sooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06oooooo000Xooooo`;o
0000Ioooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06oooooo000Xooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1_ooooo`00:?oo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Kooo
ool002Sooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo073ooooo000Xooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1`ooooo`00:?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0L?ooool002Sooooo0_l0001Xooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0L?ooool002Sooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo073ooooo000Xooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1`ooooo`00:?ooool00ol0003oooooooooo`1Woooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0L?ooool002Sooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo077ooooo000Xooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1aooooo`00:?oo
ool2o`0006Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1aooooo`00:?ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool0
02Sooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
077ooooo0009ooooo`?o00000oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Go
oooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo077o
oooo000:ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`1aooooo`001oooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool3o`00
06Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1aooooo`001oooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07;ooooo0008ooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0L_ooool000Wooooo0_l00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo07;ooooo000:ooooo`03o`000?oooooooooo00;o
oooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo06So
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1booooo`00:?ooool00ol0003ooooo
ooooo`1Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0L_ooool002Sooooo0_l0
001Zooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0L_ooool002Sooooo00?o0000
ooooooooool0JOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07;ooooo000Xoooo
o`03o`000?oooooooooo06Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1boooo
o`00:?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0Loooool002Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo07?ooooo000Xooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`1cooooo`00:?ooool2o`0006[ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`1cooooo`00:?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0Loooool002Sooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo07?ooooo000Xooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1cooooo`00:?ooool00ol0003ooooooooo
o`1Zooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Loooool002Sooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07?ooooo000Xoooo
o`;o0000Joooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07?ooooo000Xooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1dooooo`00
:?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
M?ooool000Sooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Ooo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0M?oo
ool000Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo07Cooooo0007ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`?o0000Joooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
07Cooooo0007ooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1dooooo`001ooo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0Joooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07Cooooo0008oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1[ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0M?ooool000Wooooo
0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`1[ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0M?ooool002Sooooo00?o
0000ooooooooool0Joooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07Cooooo000X
ooooo`;o0000K?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Gooooo000Xoooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1eoooo
o`00:?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0MOooool002Sooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo07Gooooo000Xooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`1eooooo`00:?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0MOooool002Sooooo0_l0001]ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0MOooool002Sooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo07Gooooo000Xooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1eooooo`00:?ooool00ol0003ooooooooo
o`1/ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0MOooool002Sooooo00?o0000
ooooooooool0K?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Kooooo000Xoooo
o`;o0000KOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Kooooo000Xooooo`03
o`000?oooooooooo06cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1fooooo`00
:?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
M_ooool002Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo07Kooooo0008ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2
o`0000Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo07Kooooo0007ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1fooooo`001oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool3o`0006gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1fooooo`002?ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0M_oo
ool000Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo07Kooooo0007ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1gooooo`002?ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1gooooo`00:?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0Moooool002Sooooo0_l0001_ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0Moooool002Sooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo07Oooooo000Xooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1gooooo`00:?ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0Moooool002Sooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Oooooo000Xooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1gooooo`00:?ooool2
o`0006oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1gooooo`00:?ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Moooool002So
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07So
oooo000Xooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1hooooo`00:?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0N?ooool002Sooooo0_l0001`ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0N?ooool002Sooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo07Sooooo000Xooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1hooooo`00:?ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0N?ooool000;ooooo0ol00004ooooo`;o00001?oo
ool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0Kooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07Sooooo0003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1h
ooooo`000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool3o`0006oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1hooooo`000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0NOooool000?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Wooooo
0002ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07Wooooo0003ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001?ooool2
o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0NOooool002Sooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo000Xooooo`;o0000LOooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo07Wooooo000Xooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1iooooo`00:?ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0NOooool002Sooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo000Xoooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1joooo
o`00:?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0N_ooool002Sooooo0_l0001aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
N_ooool002Sooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo07[ooooo000Xooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1jooooo`00:?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0N_ooool002Sooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo07[ooooo000Xooooo`;o0000L_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo07[ooooo000Xooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1jooooo`00:?ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_ooool000;ooooo0ol00002oooo
o`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07[ooooo0003ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1jooooo`000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Noooool000?ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool3o`00
07;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1kooooo`000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1kooooo`000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo07_ooooo0003ooooo`03o`000?oooooooooo00;ooooo0ol0
0004ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Noooool002Sooooo00?o0000
ooooooooool0Loooool01?l0003oooooooooool0001nooooo`00:?ooool00ol0003oooooooooo`1c
ooooo`04o`000?ooooooooooo`0007kooooo000Xooooo`;o0000M?ooool01?l0003oooooooooool0
001nooooo`00:?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooo000007oooooo000Xoooo
o`03o`000?oooooooooo07Cooooo0_l0001oooooo`00:?ooool00ol0003oooooooooo`1dooooo`;o
0000Ooooool002Sooooo00?o0000ooooooooool0M?ooool2o`0007oooooo000Xooooo`;o0000MOoo
ool2o`0007oooooo000Xooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0O_ooool0
02Sooooo00?o0000ooooooooool0mOooool002Sooooo00?o0000ooooooooool0mOooool002Sooooo
00?o0000ooooooooool0mOooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool006go
oooo0ol0001Aooooo`?o0000G?ooool006kooooo00?o0000ooooooooool0DOooool00ol0003ooooo
ooooo`1Kooooo`00@oooool3o`0000Cooooo0ol00002ooooo`Go000000Goooooo`000?l0003o0000
ooooo`02o`0000;ooooo0_l00009ooooo`?o00000oooool3o`0000;ooooo0ol00004ooooo`?o0000
0oooool4o`0000;ooooo1?l00007ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000;o
oooo0_l00003ooooo`?o00000_ooool3o`000003ooooool0003o000000Co00000_ooool5o`0000?o
oooo0_l00004ooooo`03o`000?oooooooooo00Oooooo0ol00005ooooo`;o000000?oooooo`000?l0
00000_l000001?oooooo0000o`000?ooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`00
00;ooooo0ol000000ooooooo0000o`00000Sooooo`00A?ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04
o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool0000Tooooo`00A?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo1Ol00002ooooo`?o00000_ooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go
00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool08_ooool004Cooooo0ol00002ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool02_ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00Oo
0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooo
ool0003oooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Wooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool08_ooool004Co
oooo00Co0000oooooooooooo00000_ooool3o`0000;ooooo0ol00003ooooo`Co00000_ooool4o`00
00Wooooo00?o0000ooooooooool00_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`?o00000oooool2o`0000Cooooo0ol0000:ooooo`04o`000?ooooooooooooooo`Co00000_ooool4
o`0000?ooooo0ol00002ooooo`Co00000oooool4o`000004ooooool0003o0000o`0000?ooooo1?l0
0002ooooo`;o000000?oooooo`000?l000002?ooool00ol0003oooooooooo`02ooooo`;o000000Co
ooooo`000?l0003ooooo1?l00003ooooo`?o00000_ooool4o`0000;ooooo0ol00004ooooo`?o0000
0_ooool4o`0002Gooooo0014ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooo00005?ooool00ol0003oooooooooo`0gooooo`00@oooool4o`0000[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0:ooooo`?o00006oooool2o`0000Sooooo1Ol00008ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`Go
00005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0845236, -10610.5, \
0.000528273, 874.229}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 5\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] {0.1261948886085015`, 
            0.12624689038504655`}\), ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FindPupils \[Rule] True\), ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrequencyCutoff \[Rule] {304.0619384331368`, 
            303.93423730280796`}\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {207.28232192993164`, 0, 0}\), 
        ",", \(ImageSampleSize \[Rule] {0.0016604590606381776`, 
            0.001661143294540086`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", \(NumberOfPoints \[Rule] 128\), 
        ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 112.44620808978891`\), 
        ",", \(OpticalLengthFunction \[Rule] OpticalLengthFunction\), 
        ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(CompiledFunction[
              If[#1 == 0 && #2 == 0, 
                0.000022271117373179214`, \(-6.853627285348719`\) - 
                  3.532109641994116`*^-9\ Cos[
                      2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                  1.9515319104050795`*^-10\ Cos[
                      4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                  10.310895376241149`\ \((\(-1\) + 
                        0.013990424917235709`\ \((#1\^2 + #2\^2)\))\) - 
                  5.251099192578527`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.020985637375853565`\)\ \
\((#1\^2 + #2\^2)\) + 0.0001957319893648098`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  3.4781206500308235`\ \((1 - 
                        0.04197127475170713`\ \((#1\^2 + #2\^2)\) + 
                        0.0002935979840472147`\ \((#1\^2 + #2\^2)\)\^2)\) + 
                  4.27139394586925`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((\(-0.00024466498670601227`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 2.0537802758321623`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  3.396256590938641`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((0.04197127475170713`\ \((#1\^2 + \
#2\^2)\) - 0.000978659946824049`\ \((#1\^2 + #2\^2)\)\^2 + 
                        5.134450689580406`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  0.02108223618211115`\ \((\(-1\) + 
                        0.08394254950341426`\ \((#1\^2 + #2\^2)\) - 
                        0.0014679899202360734`\ \((#1\^2 + #2\^2)\)\^2 + 
                        6.845934252773875`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  7.380096153526266`*^-8\ Cos[
                      6\ ArcTan[#1, #2]]\ \((\(-2.396076988470856`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 1.9155505830353006`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  3.180054365542885`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((0.0007339949601180367`\ \((#1\^2 \
+ #2\^2)\)\^2 - 0.000014376461930825136`\ \((#1\^2 + #2\^2)\)\^3 + 
                        6.704427040623552`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  1.291385970907799`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.06995212458617854`\)\ \((#1\
\^2 + #2\^2)\) + 0.0029359798404721468`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00003594115482706284`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.3408854081247104`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.0002074059263440704`\ \((1 - 
                        0.13990424917235708`\ \((#1\^2 + #2\^2)\) + 
                        0.00440396976070822`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00004792153976941712`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.6761067601558881`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
              "-CompiledCode-"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {112.43537240553266`, 
            112.44620808978891`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.10460892082020519`\), 
                  0.10626937988084338`}, {\(-0.10465202755602541`\), 
                  0.1063131708505655`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] True\), 
        ",", \(PlotPoints \[Rule] 32\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.10460892082020519`\), 
                  0.10626937988084338`}, {\(-0.10465202755602541`\), 
                  0.1063131708505655`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(RayBoundary \[Rule] {{\(-8.4562214163056`\), 
              8.4562214163056`}, {\(-8.452646568455712`\), 
              8.452646568455712`}}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), 
        ",", \(ResidualFitError \[Rule] 7.313862904893167`*^-7\), 
        ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
              82.9255011275954`, Astigmatism \[Rule] 0.0000417323567305451`, 
            FieldCurvature \[Rule] \(-0.24683256227325023`\), 
            Distortion \[Rule] \(-3.777962952267033`*^-13\), 
            Coma \[Rule] 1.3460273542456333`*^-12}\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 584\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.015686737510906584`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-11.347295107870586`\), 
                  11.347295107870586`}, {\(-11.343720260020696`\), 
                  11.343720260020696`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[36]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[Graphics3D]", "Input",
  CellLabel->"In[38]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[BoxData[
    \({AmbientLight \[Rule] GrayLevel[0], AspectRatio \[Rule] Automatic, 
      Axes \[Rule] False, AxesEdge \[Rule] Automatic, AxesLabel \[Rule] None, 
      AxesStyle \[Rule] Automatic, Background \[Rule] Automatic, 
      Boxed \[Rule] True, BoxRatios \[Rule] Automatic, 
      BoxStyle \[Rule] Automatic, ColorOutput \[Rule] Automatic, 
      DefaultColor \[Rule] Automatic, Epilog \[Rule] {}, 
      FaceGrids \[Rule] None, ImageSize \[Rule] Automatic, 
      Lighting \[Rule] True, 
      LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
            RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
            RGBColor[0, 1, 0]}, {{0.`, 1.`, 1.`}, RGBColor[0, 0, 1]}}, 
      Plot3Matrix \[Rule] Automatic, PlotLabel \[Rule] None, 
      PlotRange \[Rule] Automatic, PlotRegion \[Rule] Automatic, 
      PolygonIntersections \[Rule] True, Prolog \[Rule] {}, 
      RenderAll \[Rule] True, Shading \[Rule] True, 
      SphericalRegion \[Rule] False, Ticks \[Rule] Automatic, 
      ViewCenter \[Rule] Automatic, ViewPoint \[Rule] {1.3`, \(-2.4`\), 2.`}, 
      ViewVertical \[Rule] {0.`, 0.`, 1.`}, 
      DefaultFont \[RuleDelayed] $DefaultFont, 
      DisplayFunction \[RuleDelayed] $DisplayFunction, 
      FormatType \[RuleDelayed] $FormatType, 
      TextStyle \[RuleDelayed] $TextStyle}\)], "Output",
  CellLabel->"Out[38]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[Plot3D]", "Input",
  CellLabel->"In[45]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[BoxData[
    \({AmbientLight \[Rule] GrayLevel[0], AspectRatio \[Rule] Automatic, 
      Axes \[Rule] True, AxesEdge \[Rule] Automatic, AxesLabel \[Rule] None, 
      AxesStyle \[Rule] Automatic, Background \[Rule] Automatic, 
      Boxed \[Rule] True, BoxRatios \[Rule] {1, 1, 0.4`}, 
      BoxStyle \[Rule] Automatic, ClipFill \[Rule] Automatic, 
      ColorFunction \[Rule] Automatic, ColorFunctionScaling \[Rule] True, 
      ColorOutput \[Rule] Automatic, Compiled \[Rule] True, 
      DefaultColor \[Rule] Automatic, Epilog \[Rule] {}, 
      FaceGrids \[Rule] None, HiddenSurface \[Rule] True, 
      ImageSize \[Rule] Automatic, Lighting \[Rule] True, 
      LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
            RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
            RGBColor[0, 1, 0]}, {{0.`, 1.`, 1.`}, RGBColor[0, 0, 1]}}, 
      Mesh \[Rule] True, MeshStyle \[Rule] Automatic, 
      Plot3Matrix \[Rule] Automatic, PlotLabel \[Rule] None, 
      PlotPoints \[Rule] 15, PlotRange \[Rule] Automatic, 
      PlotRegion \[Rule] Automatic, Prolog \[Rule] {}, Shading \[Rule] True, 
      SphericalRegion \[Rule] False, Ticks \[Rule] Automatic, 
      ViewCenter \[Rule] Automatic, ViewPoint \[Rule] {1.3`, \(-2.4`\), 2.`}, 
      ViewVertical \[Rule] {0.`, 0.`, 1.`}, 
      DefaultFont \[RuleDelayed] $DefaultFont, 
      DisplayFunction \[RuleDelayed] $DisplayFunction, 
      FormatType \[RuleDelayed] $FormatType, 
      TextStyle \[RuleDelayed] $TextStyle}\)], "Output",
  CellLabel->"Out[45]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
PSF[pupfun, NumberOfPoints->128, Plot2D->False, PlotRange->All, \
PlotPoints->200, Mesh->False]\
\>", "Input",
  CellLabel->"In[46]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -93 0 ]
[.5 .82364 93 9 ]
[.09953 .21786 -30 -8.91358 ]
[.09953 .21786 0 .08642 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.59229 .02408 -20.4586 -9 ]
[.59229 .02408 3.54136 0 ]
[.74252 .05886 0 -6.19916 ]
[.74252 .05886 30 2.80084 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95341 .38181 0 -5.89358 ]
[.95341 .38181 24 3.10642 ]
[.02429 .26399 -6 -2.74138 ]
[.02429 .26399 0 6.25862 ]
[.01069 .34926 -30 -2.81353 ]
[.01069 .34926 0 6.18647 ]
[-0.00369 .43937 -36 -2.89023 ]
[-0.00369 .43937 0 6.10977 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Point Spread Intensity Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.1089 .22705 m
.11358 .23164 L
s
[(-0.05)] .09953 .21786 1 .9808 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.59985 .03481 m
.60363 .04017 L
s
[(0.05)] .59229 .02408 .70489 1 Mshowa
.125 Mabswid
.15407 .20936 m
.15683 .21216 L
s
.20005 .19136 m
.20277 .1942 L
s
.24686 .17303 m
.24953 .17592 L
s
.29452 .15436 m
.29714 .1573 L
s
.39251 .11599 m
.39503 .11902 L
s
.44289 .09627 m
.44534 .09934 L
s
.49421 .07617 m
.49661 .07929 L
s
.54652 .05569 m
.54886 .05886 L
s
.06452 .24443 m
.06737 .24714 L
s
.65421 .01352 m
.65641 .01679 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.73025 .06349 m
.72411 .06581 L
s
[(-0.05)] .74252 .05886 -1 .37759 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94088 .38569 m
.93461 .38763 L
s
[(0.05)] .95341 .38181 -1 .30968 Mshowa
.125 Mabswid
.75459 .10073 m
.75089 .10209 L
s
.7781 .13669 m
.7744 .13803 L
s
.80083 .17146 m
.79711 .17277 L
s
.82281 .20508 m
.81909 .20637 L
s
.86467 .26911 m
.86093 .27036 L
s
.88462 .29963 m
.88087 .30085 L
s
.90395 .3292 m
.9002 .3304 L
s
.92269 .35787 m
.91894 .35906 L
s
.70503 .02493 m
.70136 .02635 L
s
.95853 .41269 m
.95476 .41383 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03651 .25922 m
.04262 .25683 L
s
[(0)] .02429 .26399 1 -0.3908 Mshowa
.02297 .34465 m
.02912 .34235 L
s
[(50000)] .01069 .34926 1 -0.37477 Mshowa
.00866 .43495 m
.01484 .43274 L
s
[(100000)] -0.00369 .43937 1 -0.35773 Mshowa
.125 Mabswid
.03386 .27593 m
.03753 .27451 L
s
.03119 .29283 m
.03486 .29142 L
s
.02848 .30992 m
.03216 .30851 L
s
.02574 .32719 m
.02942 .32579 L
s
.02018 .36231 m
.02387 .36094 L
s
.01735 .38016 m
.02104 .3788 L
s
.01449 .39822 m
.01818 .39687 L
s
.01159 .41648 m
.01529 .41515 L
s
.0057 .45364 m
.00941 .45232 L
s
.00271 .47253 m
.00642 .47123 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.41007 .59365 m .41108 .59146 L .41254 .59287 L 0 .025 .123 r
F
.41007 .59365 m .40861 .59224 L .41108 .59146 L F
.41254 .59287 m .41355 .59067 L .41501 .59209 L 0 .024 .123 r
F
.41254 .59287 m .41108 .59146 L .41355 .59067 L F
.40861 .59224 m .40962 .59004 L .41108 .59146 L F
.40861 .59224 m .40715 .59083 L .40962 .59004 L F
.41501 .59209 m .41602 .5899 L .41748 .59132 L F
.41501 .59209 m .41355 .59067 L .41602 .5899 L F
.41108 .59146 m .41209 .58925 L .41355 .59067 L F
.41108 .59146 m .40962 .59004 L .41209 .58925 L F
.41748 .59132 m .4185 .58914 L .41995 .59055 L F
.41748 .59132 m .41602 .5899 L .4185 .58914 L F
.40715 .59083 m .40815 .58863 L .40962 .59004 L F
.40715 .59083 m .40568 .58942 L .40815 .58863 L F
.41355 .59067 m .41457 .58848 L .41602 .5899 L F
.41355 .59067 m .41209 .58925 L .41457 .58848 L F
.41995 .59055 m .42098 .58839 L .42243 .58979 L F
.41995 .59055 m .4185 .58914 L .42098 .58839 L F
.40962 .59004 m .41063 .58784 L .41209 .58925 L F
.40962 .59004 m .40815 .58863 L .41063 .58784 L F
.41602 .5899 m .41704 .58773 L .4185 .58914 L 0 .024 .122 r
F
.41602 .5899 m .41457 .58848 L .41704 .58773 L F
.42243 .58979 m .42345 .58765 L .42491 .58905 L 0 .024 .123 r
F
.42243 .58979 m .42098 .58839 L .42345 .58765 L F
.40568 .58942 m .40669 .58724 L .40815 .58863 L F
.40568 .58942 m .40421 .58802 L .40669 .58724 L F
.41209 .58925 m .4131 .58707 L .41457 .58848 L 0 .024 .122 r
F
.41209 .58925 m .41063 .58784 L .4131 .58707 L F
.4185 .58914 m .41952 .58699 L .42098 .58839 L F
.4185 .58914 m .41704 .58773 L .41952 .58699 L F
.42491 .58905 m .42594 .58692 L .42739 .58833 L 0 .024 .123 r
F
.42491 .58905 m .42345 .58765 L .42594 .58692 L F
.40815 .58863 m .40916 .58646 L .41063 .58784 L 0 .024 .122 r
F
.40815 .58863 m .40669 .58724 L .40916 .58646 L F
.41457 .58848 m .41558 .58634 L .41704 .58773 L F
.41457 .58848 m .4131 .58707 L .41558 .58634 L F
.42098 .58839 m .422 .58624 L .42345 .58765 L F
.42098 .58839 m .41952 .58699 L .422 .58624 L F
.42739 .58833 m .42842 .58617 L .42987 .5876 L 0 .024 .123 r
F
.42739 .58833 m .42594 .58692 L .42842 .58617 L F
.40421 .58802 m .40522 .58584 L .40669 .58724 L F
.40421 .58802 m .40274 .58661 L .40522 .58584 L F
.41063 .58784 m .41164 .5857 L .4131 .58707 L 0 .024 .122 r
F
.41063 .58784 m .40916 .58646 L .41164 .5857 L F
.41704 .58773 m .41806 .58561 L .41952 .58699 L F
.41704 .58773 m .41558 .58634 L .41806 .58561 L F
.42345 .58765 m .42448 .5855 L .42594 .58692 L 0 .024 .123 r
F
.42345 .58765 m .422 .58624 L .42448 .5855 L F
.42987 .5876 m .43091 .58536 L .43235 .58678 L F
.42987 .5876 m .42842 .58617 L .43091 .58536 L F
.40669 .58724 m .40769 .58507 L .40916 .58646 L 0 .024 .122 r
F
.40669 .58724 m .40522 .58584 L .40769 .58507 L F
.4131 .58707 m .41412 .58498 L .41558 .58634 L F
.4131 .58707 m .41164 .5857 L .41412 .58498 L F
.41952 .58699 m .42054 .58486 L .422 .58624 L F
.41952 .58699 m .41806 .58561 L .42054 .58486 L F
.42594 .58692 m .42697 .58474 L .42842 .58617 L 0 .024 .123 r
F
.42594 .58692 m .42448 .5855 L .42697 .58474 L F
.43235 .58678 m .4334 .58455 L .43484 .58596 L 0 .024 .122 r
F
.43235 .58678 m .43091 .58536 L .4334 .58455 L F
.40274 .58661 m .40374 .58446 L .40522 .58584 L 0 .024 .123 r
F
.40274 .58661 m .40127 .58523 L .40374 .58446 L F
.40916 .58646 m .41017 .58432 L .41164 .5857 L 0 .024 .122 r
F
.40916 .58646 m .40769 .58507 L .41017 .58432 L F
.41558 .58634 m .4166 .58426 L .41806 .58561 L F
.41558 .58634 m .41412 .58498 L .4166 .58426 L F
.422 .58624 m .42303 .58411 L .42448 .5855 L F
.422 .58624 m .42054 .58486 L .42303 .58411 L F
.42842 .58617 m .42946 .58394 L .43091 .58536 L F
.42842 .58617 m .42697 .58474 L .42946 .58394 L F
.43484 .58596 m .43589 .5838 L .43733 .58521 L F
.43484 .58596 m .4334 .58455 L .43589 .5838 L F
.40522 .58584 m .40622 .58368 L .40769 .58507 L F
.40522 .58584 m .40374 .58446 L .40622 .58368 L F
.41164 .5857 m .41265 .58361 L .41412 .58498 L F
.41164 .5857 m .41017 .58432 L .41265 .58361 L F
.41806 .58561 m .41908 .58351 L .42054 .58486 L 0 .024 .123 r
F
.41806 .58561 m .4166 .58426 L .41908 .58351 L F
.42448 .5855 m .42551 .58335 L .42697 .58474 L 0 .024 .122 r
F
.42448 .5855 m .42303 .58411 L .42551 .58335 L F
.43091 .58536 m .43195 .58313 L .4334 .58455 L F
.43091 .58536 m .42946 .58394 L .43195 .58313 L F
.43733 .58521 m .43838 .5831 L .43982 .58451 L F
.43733 .58521 m .43589 .5838 L .43838 .5831 L F
.40127 .58523 m .40227 .58308 L .40374 .58446 L 0 .024 .123 r
F
.40127 .58523 m .39979 .58387 L .40227 .58308 L F
.40769 .58507 m .4087 .58293 L .41017 .58432 L 0 .024 .122 r
F
.40769 .58507 m .40622 .58368 L .4087 .58293 L F
.41412 .58498 m .41513 .58291 L .4166 .58426 L 0 .024 .123 r
F
.41412 .58498 m .41265 .58361 L .41513 .58291 L F
.42054 .58486 m .42156 .58276 L .42303 .58411 L F
.42054 .58486 m .41908 .58351 L .42156 .58276 L F
.42697 .58474 m .428 .58255 L .42946 .58394 L 0 .024 .122 r
F
.42697 .58474 m .42551 .58335 L .428 .58255 L F
.4334 .58455 m .43444 .58238 L .43589 .5838 L F
.4334 .58455 m .43195 .58313 L .43444 .58238 L F
.43982 .58451 m .44087 .58241 L .44231 .58382 L 0 .024 .123 r
F
.43982 .58451 m .43838 .5831 L .44087 .58241 L F
.40374 .58446 m .40475 .5823 L .40622 .58368 L 0 .024 .122 r
F
.40374 .58446 m .40227 .58308 L .40475 .5823 L F
.41017 .58432 m .41118 .58223 L .41265 .58361 L F
.41017 .58432 m .4087 .58293 L .41118 .58223 L F
.4166 .58426 m .41761 .58216 L .41908 .58351 L 0 .024 .123 r
F
.4166 .58426 m .41513 .58291 L .41761 .58216 L F
.42303 .58411 m .42405 .582 L .42551 .58335 L F
.42303 .58411 m .42156 .58276 L .42405 .582 L F
.42946 .58394 m .43049 .58175 L .43195 .58313 L 0 .024 .122 r
F
.42946 .58394 m .428 .58255 L .43049 .58175 L F
.43589 .5838 m .43693 .58169 L .43838 .5831 L F
.43589 .5838 m .43444 .58238 L .43693 .58169 L F
.39979 .58387 m .40079 .5817 L .40227 .58308 L 0 .024 .123 r
F
.39979 .58387 m .39831 .58249 L .40079 .5817 L F
.44231 .58382 m .44337 .58165 L .44481 .58307 L F
.44231 .58382 m .44087 .58241 L .44337 .58165 L F
.40622 .58368 m .40723 .58154 L .4087 .58293 L 0 .024 .122 r
F
.40622 .58368 m .40475 .5823 L .40723 .58154 L F
.41265 .58361 m .41366 .58152 L .41513 .58291 L 0 .024 .123 r
F
.41265 .58361 m .41118 .58223 L .41366 .58152 L F
.41908 .58351 m .4201 .58141 L .42156 .58276 L F
.41908 .58351 m .41761 .58216 L .4201 .58141 L F
.42551 .58335 m .42654 .58121 L .428 .58255 L 0 .024 .122 r
F
.42551 .58335 m .42405 .582 L .42654 .58121 L F
.43195 .58313 m .43299 .581 L .43444 .58238 L F
.43195 .58313 m .43049 .58175 L .43299 .581 L F
.43838 .5831 m .43942 .58099 L .44087 .58241 L F
.43838 .5831 m .43693 .58169 L .43942 .58099 L F
.40227 .58308 m .40327 .5809 L .40475 .5823 L F
.40227 .58308 m .40079 .5817 L .40327 .5809 L F
.44481 .58307 m .44587 .58089 L .44731 .58232 L 0 .024 .123 r
F
.44481 .58307 m .44337 .58165 L .44587 .58089 L F
.4087 .58293 m .40971 .58084 L .41118 .58223 L F
.4087 .58293 m .40723 .58154 L .40971 .58084 L F
.41513 .58291 m .41615 .58078 L .41761 .58216 L F
.41513 .58291 m .41366 .58152 L .41615 .58078 L F
.42156 .58276 m .42259 .58066 L .42405 .582 L F
.42156 .58276 m .4201 .58141 L .42259 .58066 L F
.428 .58255 m .42904 .58042 L .43049 .58175 L 0 .024 .122 r
F
.428 .58255 m .42654 .58121 L .42904 .58042 L F
.43444 .58238 m .43548 .58031 L .43693 .58169 L F
.43444 .58238 m .43299 .581 L .43548 .58031 L F
.39831 .58249 m .39931 .58024 L .40079 .5817 L 0 .024 .123 r
F
.39831 .58249 m .39683 .58104 L .39931 .58024 L F
.44087 .58241 m .44192 .58023 L .44337 .58165 L F
.44087 .58241 m .43942 .58099 L .44192 .58023 L F
.40475 .5823 m .40575 .58014 L .40723 .58154 L 0 .024 .122 r
F
.40475 .5823 m .40327 .5809 L .40575 .58014 L F
.44731 .58232 m .44837 .58014 L .44981 .58156 L 0 .024 .123 r
F
.44731 .58232 m .44587 .58089 L .44837 .58014 L F
.41118 .58223 m .41219 .58013 L .41366 .58152 L F
.41118 .58223 m .40971 .58084 L .41219 .58013 L F
.41761 .58216 m .41864 .58001 L .4201 .58141 L F
.41761 .58216 m .41615 .58078 L .41864 .58001 L F
.42405 .582 m .42508 .57987 L .42654 .58121 L F
.42405 .582 m .42259 .58066 L .42508 .57987 L F
.43049 .58175 m .43153 .57968 L .43299 .581 L 0 .024 .122 r
F
.43049 .58175 m .42904 .58042 L .43153 .57968 L F
.43693 .58169 m .43798 .57961 L .43942 .58099 L F
.43693 .58169 m .43548 .58031 L .43798 .57961 L F
.40079 .5817 m .40179 .57945 L .40327 .5809 L F
.40079 .5817 m .39931 .58024 L .40179 .57945 L F
.44337 .58165 m .44442 .57947 L .44587 .58089 L 0 .024 .123 r
F
.44337 .58165 m .44192 .58023 L .44442 .57947 L F
.40723 .58154 m .40824 .57944 L .40971 .58084 L 0 .024 .122 r
F
.40723 .58154 m .40575 .58014 L .40824 .57944 L F
.44981 .58156 m .45087 .57938 L .45231 .58079 L 0 .024 .123 r
F
.44981 .58156 m .44837 .58014 L .45087 .57938 L F
.41366 .58152 m .41468 .57937 L .41615 .58078 L F
.41366 .58152 m .41219 .58013 L .41468 .57937 L F
.4201 .58141 m .42113 .57925 L .42259 .58066 L F
.4201 .58141 m .41864 .58001 L .42113 .57925 L F
.42654 .58121 m .42758 .57909 L .42904 .58042 L F
.42654 .58121 m .42508 .57987 L .42758 .57909 L F
.43299 .581 m .43403 .57898 L .43548 .58031 L 0 .024 .122 r
F
.43299 .581 m .43153 .57968 L .43403 .57898 L F
.39683 .58104 m .39783 .57879 L .39931 .58024 L F
.39683 .58104 m .39535 .57958 L .39783 .57879 L F
.43942 .58099 m .44048 .57885 L .44192 .58023 L 0 .024 .123 r
F
.43942 .58099 m .43798 .57961 L .44048 .57885 L F
.40327 .5809 m .40428 .5787 L .40575 .58014 L 0 .024 .122 r
F
.40327 .5809 m .40179 .57945 L .40428 .5787 L F
.44587 .58089 m .44693 .57871 L .44837 .58014 L 0 .024 .123 r
F
.44587 .58089 m .44442 .57947 L .44693 .57871 L F
.40971 .58084 m .41072 .57873 L .41219 .58013 L F
.40971 .58084 m .40824 .57944 L .41072 .57873 L F
.45231 .58079 m .45338 .57862 L .45482 .58001 L F
.45231 .58079 m .45087 .57938 L .45338 .57862 L F
.41615 .58078 m .41717 .57859 L .41864 .58001 L F
.41615 .58078 m .41468 .57937 L .41717 .57859 L F
.42259 .58066 m .42362 .57847 L .42508 .57987 L F
.42259 .58066 m .42113 .57925 L .42362 .57847 L F
.42904 .58042 m .43007 .57835 L .43153 .57968 L 0 .024 .122 r
F
.42904 .58042 m .42758 .57909 L .43007 .57835 L F
.43548 .58031 m .43652 .57828 L .43798 .57961 L 0 .024 .123 r
F
.43548 .58031 m .43403 .57898 L .43652 .57828 L F
.39931 .58024 m .40031 .578 L .40179 .57945 L 0 .024 .122 r
F
.39931 .58024 m .39783 .57879 L .40031 .578 L F
.44192 .58023 m .44298 .57807 L .44442 .57947 L 0 .024 .123 r
F
.44192 .58023 m .44048 .57885 L .44298 .57807 L F
.40575 .58014 m .40676 .578 L .40824 .57944 L 0 .024 .122 r
F
.40575 .58014 m .40428 .5787 L .40676 .578 L F
.44837 .58014 m .44943 .57797 L .45087 .57938 L 0 .024 .123 r
F
.44837 .58014 m .44693 .57871 L .44943 .57797 L F
.41219 .58013 m .41321 .57796 L .41468 .57937 L F
.41219 .58013 m .41072 .57873 L .41321 .57796 L F
.45482 .58001 m .45589 .57791 L .45732 .57928 L F
.45482 .58001 m .45338 .57862 L .45589 .57791 L F
.41864 .58001 m .41966 .57782 L .42113 .57925 L F
.41864 .58001 m .41717 .57859 L .41966 .57782 L F
.42508 .57987 m .42612 .57768 L .42758 .57909 L F
.42508 .57987 m .42362 .57847 L .42612 .57768 L F
.43153 .57968 m .43257 .57765 L .43403 .57898 L F
.43153 .57968 m .43007 .57835 L .43257 .57765 L F
.39535 .57958 m .39635 .57739 L .39783 .57879 L 0 .024 .122 r
F
.39535 .57958 m .39386 .57818 L .39635 .57739 L F
.43798 .57961 m .43903 .57751 L .44048 .57885 L 0 .024 .123 r
F
.43798 .57961 m .43652 .57828 L .43903 .57751 L F
.40179 .57945 m .4028 .57725 L .40428 .5787 L 0 .024 .122 r
F
.40179 .57945 m .40031 .578 L .4028 .57725 L F
.44442 .57947 m .44548 .57731 L .44693 .57871 L F
.44442 .57947 m .44298 .57807 L .44548 .57731 L F
.40824 .57944 m .40925 .57731 L .41072 .57873 L 0 .024 .123 r
F
.40824 .57944 m .40676 .578 L .40925 .57731 L F
.45087 .57938 m .45194 .57724 L .45338 .57862 L F
.45087 .57938 m .44943 .57797 L .45194 .57724 L F
.41468 .57937 m .4157 .57717 L .41717 .57859 L F
.41468 .57937 m .41321 .57796 L .4157 .57717 L F
.45732 .57928 m .4584 .5772 L .45983 .57858 L F
.45732 .57928 m .45589 .57791 L .4584 .5772 L F
.42113 .57925 m .42216 .57703 L .42362 .57847 L F
.42113 .57925 m .41966 .57782 L .42216 .57703 L F
.42758 .57909 m .42861 .57694 L .43007 .57835 L F
.42758 .57909 m .42612 .57768 L .42861 .57694 L F
.39783 .57879 m .39883 .57661 L .40031 .578 L 0 .024 .122 r
F
.39783 .57879 m .39635 .57739 L .39883 .57661 L F
.43403 .57898 m .43507 .57695 L .43652 .57828 L 0 .024 .123 r
F
.43403 .57898 m .43257 .57765 L .43507 .57695 L F
.44048 .57885 m .44153 .57673 L .44298 .57807 L F
.44048 .57885 m .43903 .57751 L .44153 .57673 L F
.40428 .5787 m .40528 .57656 L .40676 .578 L 0 .024 .122 r
F
.40428 .5787 m .4028 .57725 L .40528 .57656 L F
.44693 .57871 m .44799 .57659 L .44943 .57797 L 0 .024 .123 r
F
.44693 .57871 m .44548 .57731 L .44799 .57659 L F
.41072 .57873 m .41174 .57654 L .41321 .57796 L F
.41072 .57873 m .40925 .57731 L .41174 .57654 L F
.45338 .57862 m .45445 .57653 L .45589 .57791 L F
.45338 .57862 m .45194 .57724 L .45445 .57653 L F
.41717 .57859 m .4182 .57638 L .41966 .57782 L F
.41717 .57859 m .4157 .57717 L .4182 .57638 L F
.45983 .57858 m .46091 .5765 L .46234 .57787 L 0 .025 .123 r
F
.45983 .57858 m .4584 .5772 L .46091 .5765 L F
.42362 .57847 m .42466 .57625 L .42612 .57768 L 0 .024 .123 r
F
.42362 .57847 m .42216 .57703 L .42466 .57625 L F
.43007 .57835 m .43111 .57623 L .43257 .57765 L F
.43007 .57835 m .42861 .57694 L .43111 .57623 L F
.39386 .57818 m .39486 .57605 L .39635 .57739 L 0 .024 .122 r
F
.39386 .57818 m .39237 .57683 L .39486 .57605 L F
.40031 .578 m .40132 .57586 L .4028 .57725 L F
.40031 .578 m .39883 .57661 L .40132 .57586 L F
.43652 .57828 m .43757 .57617 L .43903 .57751 L 0 .025 .123 r
F
.43652 .57828 m .43507 .57695 L .43757 .57617 L F
.44298 .57807 m .44404 .57597 L .44548 .57731 L 0 .024 .123 r
F
.44298 .57807 m .44153 .57673 L .44404 .57597 L F
.40676 .578 m .40777 .57588 L .40925 .57731 L 0 .024 .122 r
F
.40676 .578 m .40528 .57656 L .40777 .57588 L F
.44943 .57797 m .4505 .57587 L .45194 .57724 L 0 .024 .123 r
F
.44943 .57797 m .44799 .57659 L .4505 .57587 L F
.41321 .57796 m .41423 .57574 L .4157 .57717 L F
.41321 .57796 m .41174 .57654 L .41423 .57574 L F
.45589 .57791 m .45696 .57583 L .4584 .5772 L 0 .025 .123 r
F
.45589 .57791 m .45445 .57653 L .45696 .57583 L F
.41966 .57782 m .42069 .5756 L .42216 .57703 L 0 .024 .123 r
F
.41966 .57782 m .4182 .57638 L .42069 .5756 L F
.42612 .57768 m .42715 .57551 L .42861 .57694 L F
.42612 .57768 m .42466 .57625 L .42715 .57551 L F
.46234 .57787 m .46343 .57567 L .46486 .57703 L 0 .025 .123 r
F
.46234 .57787 m .46091 .5765 L .46343 .57567 L F
.39635 .57739 m .39734 .57526 L .39883 .57661 L 0 .024 .122 r
F
.39635 .57739 m .39486 .57605 L .39734 .57526 L F
.43257 .57765 m .43361 .57553 L .43507 .57695 L 0 .025 .123 r
F
.43257 .57765 m .43111 .57623 L .43361 .57553 L F
.4028 .57725 m .4038 .57517 L .40528 .57656 L 0 .024 .122 r
F
.4028 .57725 m .40132 .57586 L .4038 .57517 L F
.43903 .57751 m .44008 .57539 L .44153 .57673 L 0 .025 .123 r
F
.43903 .57751 m .43757 .57617 L .44008 .57539 L F
.44548 .57731 m .44654 .57525 L .44799 .57659 L 0 .024 .123 r
F
.44548 .57731 m .44404 .57597 L .44654 .57525 L F
.40925 .57731 m .41026 .57511 L .41174 .57654 L F
.40925 .57731 m .40777 .57588 L .41026 .57511 L F
.45194 .57724 m .45301 .57516 L .45445 .57653 L F
.45194 .57724 m .4505 .57587 L .45301 .57516 L F
.4157 .57717 m .41673 .57496 L .4182 .57638 L F
.4157 .57717 m .41423 .57574 L .41673 .57496 L F
.4584 .5772 m .45948 .57512 L .46091 .5765 L 0 .025 .123 r
F
.4584 .5772 m .45696 .57583 L .45948 .57512 L F
.42216 .57703 m .42319 .57482 L .42466 .57625 L 0 .024 .122 r
F
.42216 .57703 m .42069 .5756 L .42319 .57482 L F
.46486 .57703 m .46595 .57484 L .46738 .5762 L 0 .024 .123 r
F
.46486 .57703 m .46343 .57567 L .46595 .57484 L F
.42861 .57694 m .42965 .57479 L .43111 .57623 L F
.42861 .57694 m .42715 .57551 L .42965 .57479 L F
.39237 .57683 m .39336 .5747 L .39486 .57605 L 0 .024 .122 r
F
.39237 .57683 m .39088 .57548 L .39336 .5747 L F
.39883 .57661 m .39983 .57452 L .40132 .57586 L F
.39883 .57661 m .39734 .57526 L .39983 .57452 L F
.43507 .57695 m .43612 .57474 L .43757 .57617 L 0 .025 .123 r
F
.43507 .57695 m .43361 .57553 L .43612 .57474 L F
.44153 .57673 m .44259 .57463 L .44404 .57597 L 0 .024 .123 r
F
.44153 .57673 m .44008 .57539 L .44259 .57463 L F
.40528 .57656 m .40629 .57449 L .40777 .57588 L 0 .024 .122 r
F
.40528 .57656 m .4038 .57517 L .40629 .57449 L F
.44799 .57659 m .44905 .57453 L .4505 .57587 L 0 .024 .123 r
F
.44799 .57659 m .44654 .57525 L .44905 .57453 L F
.41174 .57654 m .41276 .57431 L .41423 .57574 L F
.41174 .57654 m .41026 .57511 L .41276 .57431 L F
.45445 .57653 m .45552 .57446 L .45696 .57583 L 0 .025 .123 r
F
.45445 .57653 m .45301 .57516 L .45552 .57446 L F
.4182 .57638 m .41922 .5742 L .42069 .5756 L 0 .024 .122 r
F
.4182 .57638 m .41673 .57496 L .41922 .5742 L F
.42466 .57625 m .42569 .57407 L .42715 .57551 L F
.42466 .57625 m .42319 .57482 L .42569 .57407 L F
.46091 .5765 m .46199 .5743 L .46343 .57567 L 0 .025 .123 r
F
.46091 .5765 m .45948 .57512 L .46199 .5743 L F
.46738 .5762 m .46847 .57405 L .46989 .57539 L 0 .024 .122 r
F
.46738 .5762 m .46595 .57484 L .46847 .57405 L F
.39486 .57605 m .39585 .57392 L .39734 .57526 L F
.39486 .57605 m .39336 .5747 L .39585 .57392 L F
.43111 .57623 m .43216 .57407 L .43361 .57553 L 0 .024 .123 r
F
.43111 .57623 m .42965 .57479 L .43216 .57407 L F
.40132 .57586 m .40232 .57383 L .4038 .57517 L 0 .024 .122 r
F
.40132 .57586 m .39983 .57452 L .40232 .57383 L F
.43757 .57617 m .43863 .57395 L .44008 .57539 L 0 .025 .123 r
F
.43757 .57617 m .43612 .57474 L .43863 .57395 L F
.44404 .57597 m .4451 .57391 L .44654 .57525 L F
.44404 .57597 m .44259 .57463 L .4451 .57391 L F
.40777 .57588 m .40878 .57371 L .41026 .57511 L 0 .024 .123 r
F
.40777 .57588 m .40629 .57449 L .40878 .57371 L F
.4505 .57587 m .45157 .57382 L .45301 .57516 L 0 .025 .123 r
F
.4505 .57587 m .44905 .57453 L .45157 .57382 L F
.41423 .57574 m .41526 .57352 L .41673 .57496 L 0 .024 .122 r
F
.41423 .57574 m .41276 .57431 L .41526 .57352 L F
.42069 .5756 m .42172 .57343 L .42319 .57482 L F
.42069 .5756 m .41922 .5742 L .42172 .57343 L F
.45696 .57583 m .45804 .57375 L .45948 .57512 L 0 .025 .123 r
F
.45696 .57583 m .45552 .57446 L .45804 .57375 L F
.46343 .57567 m .46451 .57349 L .46595 .57484 L 0 .024 .123 r
F
.46343 .57567 m .46199 .5743 L .46451 .57349 L F
.42715 .57551 m .42819 .57335 L .42965 .57479 L F
.42715 .57551 m .42569 .57407 L .42819 .57335 L F
.46989 .57539 m .47099 .57329 L .47242 .57462 L 0 .024 .122 r
F
.46989 .57539 m .46847 .57405 L .47099 .57329 L F
.39088 .57548 m .39187 .5733 L .39336 .5747 L 0 .024 .123 r
F
.39088 .57548 m .38938 .57409 L .39187 .5733 L F
.39734 .57526 m .39834 .57317 L .39983 .57452 L 0 .024 .122 r
F
.39734 .57526 m .39585 .57392 L .39834 .57317 L F
.43361 .57553 m .43466 .57328 L .43612 .57474 L 0 .025 .123 r
F
.43361 .57553 m .43216 .57407 L .43466 .57328 L F
.4038 .57517 m .40481 .57314 L .40629 .57449 L 0 .024 .123 r
F
.4038 .57517 m .40232 .57383 L .40481 .57314 L F
.44008 .57539 m .44114 .57319 L .44259 .57463 L 0 .025 .123 r
F
.44008 .57539 m .43863 .57395 L .44114 .57319 L F
.44654 .57525 m .44761 .57319 L .44905 .57453 L F
.44654 .57525 m .4451 .57391 L .44761 .57319 L F
.41026 .57511 m .41128 .57292 L .41276 .57431 L 0 .024 .122 r
F
.41026 .57511 m .40878 .57371 L .41128 .57292 L F
.41673 .57496 m .41775 .57278 L .41922 .5742 L F
.41673 .57496 m .41526 .57352 L .41775 .57278 L F
.45301 .57516 m .45408 .57311 L .45552 .57446 L 0 .025 .123 r
F
.45301 .57516 m .45157 .57382 L .45408 .57311 L F
.42319 .57482 m .42423 .57269 L .42569 .57407 L 0 .024 .122 r
F
.42319 .57482 m .42172 .57343 L .42423 .57269 L F
.45948 .57512 m .46056 .57294 L .46199 .5743 L 0 .025 .123 r
F
.45948 .57512 m .45804 .57375 L .46056 .57294 L F
.46595 .57484 m .46704 .5727 L .46847 .57405 L 0 .024 .123 r
F
.46595 .57484 m .46451 .57349 L .46704 .5727 L F
.42965 .57479 m .4307 .57263 L .43216 .57407 L F
.42965 .57479 m .42819 .57335 L .4307 .57263 L F
.47242 .57462 m .47351 .57254 L .47494 .57385 L 0 .024 .122 r
F
.47242 .57462 m .47099 .57329 L .47351 .57254 L F
.39336 .5747 m .39436 .57251 L .39585 .57392 L 0 .024 .123 r
F
.39336 .5747 m .39187 .5733 L .39436 .57251 L F
.39983 .57452 m .40083 .57247 L .40232 .57383 L F
.39983 .57452 m .39834 .57317 L .40083 .57247 L F
.43612 .57474 m .43717 .57248 L .43863 .57395 L F
.43612 .57474 m .43466 .57328 L .43717 .57248 L F
.44259 .57463 m .44365 .57248 L .4451 .57391 L 0 .025 .123 r
F
.44259 .57463 m .44114 .57319 L .44365 .57248 L F
.40629 .57449 m .4073 .57236 L .40878 .57371 L 0 .024 .123 r
F
.40629 .57449 m .40481 .57314 L .4073 .57236 L F
.41276 .57431 m .41378 .57212 L .41526 .57352 L 0 .024 .122 r
F
.41276 .57431 m .41128 .57292 L .41378 .57212 L F
.44905 .57453 m .45012 .57248 L .45157 .57382 L 0 .025 .123 r
F
.44905 .57453 m .44761 .57319 L .45012 .57248 L F
.41922 .5742 m .42025 .57204 L .42172 .57343 L 0 .024 .122 r
F
.41922 .5742 m .41775 .57278 L .42025 .57204 L F
.45552 .57446 m .4566 .57239 L .45804 .57375 L 0 .025 .124 r
F
.45552 .57446 m .45408 .57311 L .4566 .57239 L F
.42569 .57407 m .42673 .57196 L .42819 .57335 L 0 .024 .122 r
F
.42569 .57407 m .42423 .57269 L .42673 .57196 L F
.46199 .5743 m .46308 .57213 L .46451 .57349 L 0 .025 .123 r
F
.46199 .5743 m .46056 .57294 L .46308 .57213 L F
.46847 .57405 m .46956 .57197 L .47099 .57329 L 0 .024 .123 r
F
.46847 .57405 m .46704 .5727 L .46956 .57197 L F
.38938 .57409 m .39037 .57189 L .39187 .5733 L F
.38938 .57409 m .38788 .57269 L .39037 .57189 L F
.47494 .57385 m .47604 .57176 L .47747 .57308 L 0 .024 .122 r
F
.47494 .57385 m .47351 .57254 L .47604 .57176 L F
.43216 .57407 m .43321 .57183 L .43466 .57328 L 0 .024 .123 r
F
.43216 .57407 m .4307 .57263 L .43321 .57183 L F
.39585 .57392 m .39685 .57176 L .39834 .57317 L 0 .024 .122 r
F
.39585 .57392 m .39436 .57251 L .39685 .57176 L F
.43863 .57395 m .43968 .57171 L .44114 .57319 L 0 .024 .123 r
F
.43863 .57395 m .43717 .57248 L .43968 .57171 L F
.40232 .57383 m .40332 .57178 L .40481 .57314 L F
.40232 .57383 m .40083 .57247 L .40332 .57178 L F
.40878 .57371 m .4098 .57155 L .41128 .57292 L F
.40878 .57371 m .4073 .57236 L .4098 .57155 L F
.4451 .57391 m .44616 .57177 L .44761 .57319 L 0 .025 .123 r
F
.4451 .57391 m .44365 .57248 L .44616 .57177 L F
.41526 .57352 m .41628 .57139 L .41775 .57278 L 0 .024 .122 r
F
.41526 .57352 m .41378 .57212 L .41628 .57139 L F
.45157 .57382 m .45264 .57176 L .45408 .57311 L 0 .025 .124 r
F
.45157 .57382 m .45012 .57248 L .45264 .57176 L F
.42172 .57343 m .42276 .5713 L .42423 .57269 L 0 .024 .122 r
F
.42172 .57343 m .42025 .57204 L .42276 .5713 L F
.45804 .57375 m .45912 .57158 L .46056 .57294 L 0 .025 .124 r
F
.45804 .57375 m .4566 .57239 L .45912 .57158 L F
.46451 .57349 m .4656 .57135 L .46704 .5727 L 0 .025 .123 r
F
.46451 .57349 m .46308 .57213 L .4656 .57135 L F
.42819 .57335 m .42923 .57123 L .4307 .57263 L 0 .024 .123 r
F
.42819 .57335 m .42673 .57196 L .42923 .57123 L F
.47099 .57329 m .47209 .57123 L .47351 .57254 L F
.47099 .57329 m .46956 .57197 L .47209 .57123 L F
.39187 .5733 m .39286 .5711 L .39436 .57251 L F
.39187 .5733 m .39037 .57189 L .39286 .5711 L F
.47747 .57308 m .47857 .57098 L .47999 .57231 L 0 .024 .122 r
F
.47747 .57308 m .47604 .57176 L .47857 .57098 L F
.43466 .57328 m .43572 .57102 L .43717 .57248 L 0 .024 .123 r
F
.43466 .57328 m .43321 .57183 L .43572 .57102 L F
.39834 .57317 m .39934 .57106 L .40083 .57247 L F
.39834 .57317 m .39685 .57176 L .39934 .57106 L F
.44114 .57319 m .4422 .57101 L .44365 .57248 L F
.44114 .57319 m .43968 .57171 L .4422 .57101 L F
.40481 .57314 m .40582 .571 L .4073 .57236 L 0 .025 .123 r
F
.40481 .57314 m .40332 .57178 L .40582 .571 L F
.41128 .57292 m .4123 .57075 L .41378 .57212 L 0 .024 .122 r
F
.41128 .57292 m .4098 .57155 L .4123 .57075 L F
.44761 .57319 m .44867 .57105 L .45012 .57248 L 0 .025 .123 r
F
.44761 .57319 m .44616 .57177 L .44867 .57105 L F
.41775 .57278 m .41878 .57065 L .42025 .57204 L 0 .024 .122 r
F
.41775 .57278 m .41628 .57139 L .41878 .57065 L F
.45408 .57311 m .45516 .57103 L .4566 .57239 L 0 .025 .124 r
F
.45408 .57311 m .45264 .57176 L .45516 .57103 L F
.42423 .57269 m .42526 .57057 L .42673 .57196 L 0 .024 .123 r
F
.42423 .57269 m .42276 .5713 L .42526 .57057 L F
.46056 .57294 m .46164 .57077 L .46308 .57213 L 0 .025 .123 r
F
.46056 .57294 m .45912 .57158 L .46164 .57077 L F
.38788 .57269 m .38887 .57049 L .39037 .57189 L 0 .024 .123 r
F
.38788 .57269 m .38638 .57128 L .38887 .57049 L F
.46704 .5727 m .46813 .57062 L .46956 .57197 L 0 .025 .123 r
F
.46704 .5727 m .4656 .57135 L .46813 .57062 L F
.4307 .57263 m .43174 .57044 L .43321 .57183 L 0 .024 .123 r
F
.4307 .57263 m .42923 .57123 L .43174 .57044 L F
.39436 .57251 m .39536 .57033 L .39685 .57176 L 0 .024 .122 r
F
.39436 .57251 m .39286 .5711 L .39536 .57033 L F
.47351 .57254 m .47462 .57044 L .47604 .57176 L 0 .024 .123 r
F
.47351 .57254 m .47209 .57123 L .47462 .57044 L F
.43717 .57248 m .43823 .57025 L .43968 .57171 L 0 .024 .122 r
F
.43717 .57248 m .43572 .57102 L .43823 .57025 L F
.47999 .57231 m .4811 .57019 L .48252 .57152 L F
.47999 .57231 m .47857 .57098 L .4811 .57019 L F
.40083 .57247 m .40183 .57036 L .40332 .57178 L 0 .025 .123 r
F
.40083 .57247 m .39934 .57106 L .40183 .57036 L F
.44365 .57248 m .44471 .57031 L .44616 .57177 L F
.44365 .57248 m .4422 .57101 L .44471 .57031 L F
.4073 .57236 m .40832 .57018 L .4098 .57155 L 0 .024 .123 r
F
.4073 .57236 m .40582 .571 L .40832 .57018 L F
.41378 .57212 m .4148 .57001 L .41628 .57139 L 0 .024 .122 r
F
.41378 .57212 m .4123 .57075 L .4148 .57001 L F
.45012 .57248 m .45119 .57032 L .45264 .57176 L 0 .025 .124 r
F
.45012 .57248 m .44867 .57105 L .45119 .57032 L F
.42025 .57204 m .42128 .56991 L .42276 .5713 L 0 .024 .123 r
F
.42025 .57204 m .41878 .57065 L .42128 .56991 L F
.4566 .57239 m .45768 .57022 L .45912 .57158 L 0 .025 .124 r
F
.4566 .57239 m .45516 .57103 L .45768 .57022 L F
.46308 .57213 m .46417 .56999 L .4656 .57135 L 0 .025 .123 r
F
.46308 .57213 m .46164 .57077 L .46417 .56999 L F
.42673 .57196 m .42777 .56983 L .42923 .57123 L 0 .024 .123 r
F
.42673 .57196 m .42526 .57057 L .42777 .56983 L F
.39037 .57189 m .39137 .56969 L .39286 .5711 L F
.39037 .57189 m .38887 .57049 L .39137 .56969 L F
.46956 .57197 m .47066 .56989 L .47209 .57123 L 0 .025 .123 r
F
.46956 .57197 m .46813 .57062 L .47066 .56989 L F
.43321 .57183 m .43426 .56963 L .43572 .57102 L 0 .024 .123 r
F
.43321 .57183 m .43174 .57044 L .43426 .56963 L F
.39685 .57176 m .39785 .56963 L .39934 .57106 L F
.39685 .57176 m .39536 .57033 L .39785 .56963 L F
.47604 .57176 m .47715 .56965 L .47857 .57098 L F
.47604 .57176 m .47462 .57044 L .47715 .56965 L F
.48252 .57152 m .48364 .56936 L .48506 .5707 L 0 .024 .122 r
F
.48252 .57152 m .4811 .57019 L .48364 .56936 L F
.43968 .57171 m .44074 .56955 L .4422 .57101 L 0 .024 .123 r
F
.43968 .57171 m .43823 .57025 L .44074 .56955 L F
.40332 .57178 m .40433 .56957 L .40582 .571 L 0 .025 .123 r
F
.40332 .57178 m .40183 .57036 L .40433 .56957 L F
.4098 .57155 m .41082 .56938 L .4123 .57075 L 0 .024 .123 r
F
.4098 .57155 m .40832 .57018 L .41082 .56938 L F
.44616 .57177 m .44723 .56959 L .44867 .57105 L 0 .025 .123 r
F
.44616 .57177 m .44471 .57031 L .44723 .56959 L F
.41628 .57139 m .4173 .56927 L .41878 .57065 L 0 .024 .123 r
F
.41628 .57139 m .4148 .57001 L .4173 .56927 L F
.45264 .57176 m .45371 .56959 L .45516 .57103 L 0 .025 .124 r
F
.45264 .57176 m .45119 .57032 L .45371 .56959 L F
.42276 .5713 m .42379 .56917 L .42526 .57057 L 0 .024 .123 r
F
.42276 .5713 m .42128 .56991 L .42379 .56917 L F
.45912 .57158 m .4602 .56941 L .46164 .57077 L 0 .025 .124 r
F
.45912 .57158 m .45768 .57022 L .4602 .56941 L F
.38638 .57128 m .38737 .56907 L .38887 .57049 L 0 .024 .123 r
F
.38638 .57128 m .38488 .56985 L .38737 .56907 L F
.4656 .57135 m .46669 .56926 L .46813 .57062 L 0 .025 .123 r
F
.4656 .57135 m .46417 .56999 L .46669 .56926 L F
.42923 .57123 m .43028 .56904 L .43174 .57044 L 0 .024 .123 r
F
.42923 .57123 m .42777 .56983 L .43028 .56904 L F
.39286 .5711 m .39386 .56893 L .39536 .57033 L 0 .024 .122 r
F
.39286 .5711 m .39137 .56969 L .39386 .56893 L F
.43572 .57102 m .43677 .56886 L .43823 .57025 L F
.43572 .57102 m .43426 .56963 L .43677 .56886 L F
.47209 .57123 m .47319 .5691 L .47462 .57044 L 0 .025 .123 r
F
.47209 .57123 m .47066 .56989 L .47319 .5691 L F
.47857 .57098 m .47968 .56885 L .4811 .57019 L 0 .024 .123 r
F
.47857 .57098 m .47715 .56965 L .47968 .56885 L F
.39934 .57106 m .40034 .56893 L .40183 .57036 L F
.39934 .57106 m .39785 .56963 L .40034 .56893 L F
.48506 .5707 m .48618 .56854 L .48759 .56988 L 0 .024 .122 r
F
.48506 .5707 m .48364 .56936 L .48618 .56854 L F
.4422 .57101 m .44326 .56886 L .44471 .57031 L 0 .024 .123 r
F
.4422 .57101 m .44074 .56955 L .44326 .56886 L F
.40582 .571 m .40683 .56874 L .40832 .57018 L F
.40582 .571 m .40433 .56957 L .40683 .56874 L F
.4123 .57075 m .41332 .56863 L .4148 .57001 L F
.4123 .57075 m .41082 .56938 L .41332 .56863 L F
.44867 .57105 m .44975 .56886 L .45119 .57032 L 0 .025 .123 r
F
.44867 .57105 m .44723 .56959 L .44975 .56886 L F
.41878 .57065 m .41981 .56852 L .42128 .56991 L 0 .024 .123 r
F
.41878 .57065 m .4173 .56927 L .41981 .56852 L F
.45516 .57103 m .45624 .56879 L .45768 .57022 L 0 .025 .124 r
F
.45516 .57103 m .45371 .56959 L .45624 .56879 L F
.42526 .57057 m .4263 .56842 L .42777 .56983 L 0 .024 .123 r
F
.42526 .57057 m .42379 .56917 L .4263 .56842 L F
.46164 .57077 m .46273 .56863 L .46417 .56999 L 0 .025 .123 r
F
.46164 .57077 m .4602 .56941 L .46273 .56863 L F
.38887 .57049 m .38987 .5683 L .39137 .56969 L 0 .024 .123 r
F
.38887 .57049 m .38737 .56907 L .38987 .5683 L F
.43174 .57044 m .43279 .56824 L .43426 .56963 L F
.43174 .57044 m .43028 .56904 L .43279 .56824 L F
.46813 .57062 m .46922 .56853 L .47066 .56989 L 0 .025 .123 r
F
.46813 .57062 m .46669 .56926 L .46922 .56853 L F
.39536 .57033 m .39635 .56822 L .39785 .56963 L 0 .024 .123 r
F
.39536 .57033 m .39386 .56893 L .39635 .56822 L F
.43823 .57025 m .43928 .56818 L .44074 .56955 L F
.43823 .57025 m .43677 .56886 L .43928 .56818 L F
.47462 .57044 m .47572 .56829 L .47715 .56965 L 0 .025 .123 r
F
.47462 .57044 m .47319 .5691 L .47572 .56829 L F
.4811 .57019 m .48222 .56803 L .48364 .56936 L 0 .024 .122 r
F
.4811 .57019 m .47968 .56885 L .48222 .56803 L F
.48759 .56988 m .48872 .56779 L .49013 .56913 L F
.48759 .56988 m .48618 .56854 L .48872 .56779 L F
.40183 .57036 m .40284 .56813 L .40433 .56957 L 0 .025 .123 r
F
.40183 .57036 m .40034 .56893 L .40284 .56813 L F
.44471 .57031 m .44578 .56814 L .44723 .56959 L F
.44471 .57031 m .44326 .56886 L .44578 .56814 L F
.40832 .57018 m .40934 .56793 L .41082 .56938 L 0 .024 .123 r
F
.40832 .57018 m .40683 .56874 L .40934 .56793 L F
.4148 .57001 m .41583 .56788 L .4173 .56927 L F
.4148 .57001 m .41332 .56863 L .41583 .56788 L F
.45119 .57032 m .45227 .56812 L .45371 .56959 L 0 .025 .124 r
F
.45119 .57032 m .44975 .56886 L .45227 .56812 L F
.42128 .56991 m .42232 .56776 L .42379 .56917 L 0 .024 .123 r
F
.42128 .56991 m .41981 .56852 L .42232 .56776 L F
.38488 .56985 m .38587 .56766 L .38737 .56907 L F
.38488 .56985 m .38338 .56841 L .38587 .56766 L F
.45768 .57022 m .45876 .56799 L .4602 .56941 L 0 .025 .124 r
F
.45768 .57022 m .45624 .56879 L .45876 .56799 L F
.46417 .56999 m .46526 .5679 L .46669 .56926 L 0 .025 .123 r
F
.46417 .56999 m .46273 .56863 L .46526 .5679 L F
.42777 .56983 m .42881 .56763 L .43028 .56904 L 0 .024 .123 r
F
.42777 .56983 m .4263 .56842 L .42881 .56763 L F
.39137 .56969 m .39236 .56755 L .39386 .56893 L F
.39137 .56969 m .38987 .5683 L .39236 .56755 L F
.43426 .56963 m .43531 .56748 L .43677 .56886 L F
.43426 .56963 m .43279 .56824 L .43531 .56748 L F
.47066 .56989 m .47176 .56772 L .47319 .5691 L 0 .025 .123 r
F
.47066 .56989 m .46922 .56853 L .47176 .56772 L F
.39785 .56963 m .39885 .56751 L .40034 .56893 L 0 .024 .123 r
F
.39785 .56963 m .39635 .56822 L .39885 .56751 L F
.47715 .56965 m .47826 .56748 L .47968 .56885 L F
.47715 .56965 m .47572 .56829 L .47826 .56748 L F
.48364 .56936 m .48476 .56721 L .48618 .56854 L 0 .024 .122 r
F
.48364 .56936 m .48222 .56803 L .48476 .56721 L F
.44074 .56955 m .4418 .56749 L .44326 .56886 L 0 .024 .123 r
F
.44074 .56955 m .43928 .56818 L .4418 .56749 L F
.49013 .56913 m .49126 .56709 L .49267 .56843 L 0 .024 .122 r
F
.49013 .56913 m .48872 .56779 L .49126 .56709 L F
.40433 .56957 m .40535 .56729 L .40683 .56874 L 0 .024 .123 r
F
.40433 .56957 m .40284 .56813 L .40535 .56729 L F
.41082 .56938 m .41184 .56718 L .41332 .56863 L F
.41082 .56938 m .40934 .56793 L .41184 .56718 L F
.44723 .56959 m .4483 .5674 L .44975 .56886 L 0 .025 .123 r
F
.44723 .56959 m .44578 .56814 L .4483 .5674 L F
.4173 .56927 m .41833 .56712 L .41981 .56852 L 0 .024 .123 r
F
.4173 .56927 m .41583 .56788 L .41833 .56712 L F
.45371 .56959 m .45479 .56734 L .45624 .56879 L 0 .025 .124 r
F
.45371 .56959 m .45227 .56812 L .45479 .56734 L F
.42379 .56917 m .42483 .567 L .4263 .56842 L 0 .024 .123 r
F
.42379 .56917 m .42232 .56776 L .42483 .567 L F
.4602 .56941 m .46129 .56723 L .46273 .56863 L 0 .025 .124 r
F
.4602 .56941 m .45876 .56799 L .46129 .56723 L F
.38737 .56907 m .38836 .5669 L .38987 .5683 L 0 .024 .123 r
F
.38737 .56907 m .38587 .56766 L .38836 .5669 L F
.43028 .56904 m .43133 .56683 L .43279 .56824 L F
.43028 .56904 m .42881 .56763 L .43133 .56683 L F
.46669 .56926 m .46779 .56716 L .46922 .56853 L 0 .025 .124 r
F
.46669 .56926 m .46526 .5679 L .46779 .56716 L F
.39386 .56893 m .39486 .56684 L .39635 .56822 L 0 .024 .123 r
F
.39386 .56893 m .39236 .56755 L .39486 .56684 L F
.43677 .56886 m .43782 .5668 L .43928 .56818 L F
.43677 .56886 m .43531 .56748 L .43782 .5668 L F
.47319 .5691 m .47429 .5669 L .47572 .56829 L 0 .025 .123 r
F
.47319 .5691 m .47176 .56772 L .47429 .5669 L F
.47968 .56885 m .48079 .56666 L .48222 .56803 L 0 .024 .123 r
F
.47968 .56885 m .47826 .56748 L .48079 .56666 L F
.48618 .56854 m .4873 .56645 L .48872 .56779 L 0 .024 .122 r
F
.48618 .56854 m .48476 .56721 L .4873 .56645 L F
.40034 .56893 m .40135 .56671 L .40284 .56813 L 0 .025 .123 r
F
.40034 .56893 m .39885 .56751 L .40135 .56671 L F
.44326 .56886 m .44432 .56677 L .44578 .56814 L F
.44326 .56886 m .4418 .56749 L .44432 .56677 L F
.40683 .56874 m .40785 .56647 L .40934 .56793 L 0 .024 .123 r
F
.40683 .56874 m .40535 .56729 L .40785 .56647 L F
.49267 .56843 m .4938 .56638 L .49521 .56773 L 0 .024 .122 r
F
.49267 .56843 m .49126 .56709 L .4938 .56638 L F
.41332 .56863 m .41435 .56644 L .41583 .56788 L 0 .024 .123 r
F
.41332 .56863 m .41184 .56718 L .41435 .56644 L F
.44975 .56886 m .45082 .56667 L .45227 .56812 L 0 .025 .123 r
F
.44975 .56886 m .4483 .5674 L .45082 .56667 L F
.41981 .56852 m .42084 .56635 L .42232 .56776 L 0 .024 .123 r
F
.41981 .56852 m .41833 .56712 L .42084 .56635 L F
.38338 .56841 m .38436 .56628 L .38587 .56766 L F
.38338 .56841 m .38187 .56703 L .38436 .56628 L F
.45624 .56879 m .45732 .56655 L .45876 .56799 L 0 .025 .124 r
F
.45624 .56879 m .45479 .56734 L .45732 .56655 L F
.4263 .56842 m .42734 .5662 L .42881 .56763 L 0 .024 .123 r
F
.4263 .56842 m .42483 .567 L .42734 .5662 L F
.46273 .56863 m .46382 .5665 L .46526 .5679 L 0 .025 .124 r
F
.46273 .56863 m .46129 .56723 L .46382 .5665 L F
.38987 .5683 m .39086 .56616 L .39236 .56755 L 0 .024 .123 r
F
.38987 .5683 m .38836 .5669 L .39086 .56616 L F
.43279 .56824 m .43384 .56606 L .43531 .56748 L F
.43279 .56824 m .43133 .56683 L .43384 .56606 L F
.46922 .56853 m .47032 .56634 L .47176 .56772 L 0 .025 .124 r
F
.46922 .56853 m .46779 .56716 L .47032 .56634 L F
.39635 .56822 m .39735 .56614 L .39885 .56751 L 0 .025 .123 r
F
.39635 .56822 m .39486 .56684 L .39735 .56614 L F
.47572 .56829 m .47683 .56608 L .47826 .56748 L F
.47572 .56829 m .47429 .5669 L .47683 .56608 L F
.43928 .56818 m .44034 .56612 L .4418 .56749 L F
.43928 .56818 m .43782 .5668 L .44034 .56612 L F
.48222 .56803 m .48333 .56585 L .48476 .56721 L 0 .024 .122 r
F
.48222 .56803 m .48079 .56666 L .48333 .56585 L F
.40284 .56813 m .40386 .56587 L .40535 .56729 L 0 .024 .123 r
F
.40284 .56813 m .40135 .56671 L .40386 .56587 L F
.48872 .56779 m .48984 .56574 L .49126 .56709 L 0 .024 .122 r
F
.48872 .56779 m .4873 .56645 L .48984 .56574 L F
.40934 .56793 m .41036 .56573 L .41184 .56718 L F
.40934 .56793 m .40785 .56647 L .41036 .56573 L F
.44578 .56814 m .44684 .56602 L .4483 .5674 L 0 .025 .123 r
F
.44578 .56814 m .44432 .56677 L .44684 .56602 L F
.49521 .56773 m .49635 .56563 L .49776 .567 L 0 .024 .122 r
F
.49521 .56773 m .4938 .56638 L .49635 .56563 L F
.41583 .56788 m .41686 .56568 L .41833 .56712 L 0 .024 .123 r
F
.41583 .56788 m .41435 .56644 L .41686 .56568 L F
.45227 .56812 m .45335 .5659 L .45479 .56734 L 0 .025 .124 r
F
.45227 .56812 m .45082 .56667 L .45335 .5659 L F
.42232 .56776 m .42336 .56558 L .42483 .567 L 0 .024 .123 r
F
.42232 .56776 m .42084 .56635 L .42336 .56558 L F
.45876 .56799 m .45985 .5658 L .46129 .56723 L 0 .025 .124 r
F
.45876 .56799 m .45732 .56655 L .45985 .5658 L F
.38587 .56766 m .38686 .56553 L .38836 .5669 L 0 .024 .123 r
F
.38587 .56766 m .38436 .56628 L .38686 .56553 L F
.42881 .56763 m .42986 .56539 L .43133 .56683 L F
.42881 .56763 m .42734 .5662 L .42986 .56539 L F
.46526 .5679 m .46635 .56577 L .46779 .56716 L 0 .025 .124 r
F
.46526 .5679 m .46382 .5665 L .46635 .56577 L F
.39236 .56755 m .39336 .56546 L .39486 .56684 L 0 .024 .123 r
F
.39236 .56755 m .39086 .56616 L .39336 .56546 L F
.43531 .56748 m .43636 .56538 L .43782 .5668 L F
.43531 .56748 m .43384 .56606 L .43636 .56538 L F
.47176 .56772 m .47286 .56551 L .47429 .5669 L 0 .025 .123 r
F
.47176 .56772 m .47032 .56634 L .47286 .56551 L F
.47826 .56748 m .47937 .56526 L .48079 .56666 L 0 .024 .123 r
F
.47826 .56748 m .47683 .56608 L .47937 .56526 L F
.39885 .56751 m .39986 .56534 L .40135 .56671 L 0 .025 .123 r
F
.39885 .56751 m .39735 .56614 L .39986 .56534 L F
.48476 .56721 m .48588 .56508 L .4873 .56645 L 0 .024 .122 r
F
.48476 .56721 m .48333 .56585 L .48588 .56508 L F
.40535 .56729 m .40636 .56504 L .40785 .56647 L F
.40535 .56729 m .40386 .56587 L .40636 .56504 L F
.4418 .56749 m .44286 .56539 L .44432 .56677 L 0 .025 .123 r
F
.4418 .56749 m .44034 .56612 L .44286 .56539 L F
.49126 .56709 m .49238 .56503 L .4938 .56638 L 0 .024 .122 r
F
.49126 .56709 m .48984 .56574 L .49238 .56503 L F
.41184 .56718 m .41286 .56499 L .41435 .56644 L 0 .024 .123 r
F
.41184 .56718 m .41036 .56573 L .41286 .56499 L F
.4483 .5674 m .44937 .56528 L .45082 .56667 L 0 .025 .123 r
F
.4483 .5674 m .44684 .56602 L .44937 .56528 L F
.49776 .567 m .49889 .56488 L .5003 .56626 L 0 .024 .122 r
F
.49776 .567 m .49635 .56563 L .49889 .56488 L F
.41833 .56712 m .41937 .5649 L .42084 .56635 L 0 .024 .123 r
F
.41833 .56712 m .41686 .56568 L .41937 .5649 L F
.45479 .56734 m .45587 .56513 L .45732 .56655 L 0 .025 .123 r
F
.45479 .56734 m .45335 .5659 L .45587 .56513 L F
.38187 .56703 m .38285 .56491 L .38436 .56628 L 0 .024 .123 r
F
.38187 .56703 m .38036 .56566 L .38285 .56491 L F
.42483 .567 m .42587 .56477 L .42734 .5662 L F
.42483 .567 m .42336 .56558 L .42587 .56477 L F
.46129 .56723 m .46238 .56509 L .46382 .5665 L 0 .025 .124 r
F
.46129 .56723 m .45985 .5658 L .46238 .56509 L F
.38836 .5669 m .38935 .5648 L .39086 .56616 L 0 .024 .123 r
F
.38836 .5669 m .38686 .56553 L .38935 .5648 L F
.43133 .56683 m .43238 .56462 L .43384 .56606 L F
.43133 .56683 m .42986 .56539 L .43238 .56462 L F
.46779 .56716 m .46889 .56496 L .47032 .56634 L 0 .025 .124 r
F
.46779 .56716 m .46635 .56577 L .46889 .56496 L F
.39486 .56684 m .39585 .56476 L .39735 .56614 L 0 .025 .123 r
F
.39486 .56684 m .39336 .56546 L .39585 .56476 L F
.47429 .5669 m .4754 .56468 L .47683 .56608 L F
.47429 .5669 m .47286 .56551 L .4754 .56468 L F
.43782 .5668 m .43888 .5647 L .44034 .56612 L F
.43782 .5668 m .43636 .56538 L .43888 .5647 L F
.48079 .56666 m .48191 .56444 L .48333 .56585 L 0 .024 .123 r
F
.48079 .56666 m .47937 .56526 L .48191 .56444 L F
.40135 .56671 m .40236 .56451 L .40386 .56587 L F
.40135 .56671 m .39986 .56534 L .40236 .56451 L F
.4873 .56645 m .48842 .56437 L .48984 .56574 L 0 .024 .122 r
F
.4873 .56645 m .48588 .56508 L .48842 .56437 L F
.40785 .56647 m .40887 .56431 L .41036 .56573 L F
.40785 .56647 m .40636 .56504 L .40887 .56431 L F
.44432 .56677 m .44539 .56464 L .44684 .56602 L 0 .025 .124 r
F
.44432 .56677 m .44286 .56539 L .44539 .56464 L F
.4938 .56638 m .49493 .56426 L .49635 .56563 L 0 .024 .123 r
F
.4938 .56638 m .49238 .56503 L .49493 .56426 L F
.41435 .56644 m .41538 .56423 L .41686 .56568 L F
.41435 .56644 m .41286 .56499 L .41538 .56423 L F
.45082 .56667 m .45189 .56452 L .45335 .5659 L 0 .025 .124 r
F
.45082 .56667 m .44937 .56528 L .45189 .56452 L F
.5003 .56626 m .50145 .56413 L .50285 .56552 L 0 .024 .123 r
F
.5003 .56626 m .49889 .56488 L .50145 .56413 L F
.42084 .56635 m .42188 .56412 L .42336 .56558 L F
.42084 .56635 m .41937 .5649 L .42188 .56412 L F
.45732 .56655 m .4584 .56439 L .45985 .5658 L 0 .025 .123 r
F
.45732 .56655 m .45587 .56513 L .4584 .56439 L F
.38436 .56628 m .38535 .56417 L .38686 .56553 L F
.38436 .56628 m .38285 .56491 L .38535 .56417 L F
.42734 .5662 m .42839 .56396 L .42986 .56539 L 0 .024 .123 r
F
.42734 .5662 m .42587 .56477 L .42839 .56396 L F
.46382 .5665 m .46491 .56438 L .46635 .56577 L 0 .025 .124 r
F
.46382 .5665 m .46238 .56509 L .46491 .56438 L F
.39086 .56616 m .39185 .56409 L .39336 .56546 L 0 .025 .123 r
F
.39086 .56616 m .38935 .5648 L .39185 .56409 L F
.43384 .56606 m .4349 .56393 L .43636 .56538 L 0 .024 .123 r
F
.43384 .56606 m .43238 .56462 L .4349 .56393 L F
.47032 .56634 m .47143 .56412 L .47286 .56551 L 0 .025 .124 r
F
.47032 .56634 m .46889 .56496 L .47143 .56412 L F
.47683 .56608 m .47794 .56386 L .47937 .56526 L 0 .024 .123 r
F
.47683 .56608 m .4754 .56468 L .47794 .56386 L F
.39735 .56614 m .39836 .56397 L .39986 .56534 L 0 .025 .123 r
F
.39735 .56614 m .39585 .56476 L .39836 .56397 L F
.48333 .56585 m .48445 .56367 L .48588 .56508 L 0 .024 .122 r
F
.48333 .56585 m .48191 .56444 L .48445 .56367 L F
.40386 .56587 m .40487 .56369 L .40636 .56504 L 0 .024 .123 r
F
.40386 .56587 m .40236 .56451 L .40487 .56369 L F
.44034 .56612 m .4414 .56397 L .44286 .56539 L 0 .025 .123 r
F
.44034 .56612 m .43888 .5647 L .4414 .56397 L F
.41036 .56573 m .41138 .56357 L .41286 .56499 L 0 .024 .123 r
F
.41036 .56573 m .40887 .56431 L .41138 .56357 L F
.48984 .56574 m .49097 .56365 L .49238 .56503 L F
.48984 .56574 m .48842 .56437 L .49097 .56365 L F
.44684 .56602 m .44791 .56388 L .44937 .56528 L 0 .025 .124 r
F
.44684 .56602 m .44539 .56464 L .44791 .56388 L F
.49635 .56563 m .49748 .56349 L .49889 .56488 L 0 .024 .123 r
F
.49635 .56563 m .49493 .56426 L .49748 .56349 L F
.41686 .56568 m .41789 .56344 L .41937 .5649 L F
.41686 .56568 m .41538 .56423 L .41789 .56344 L F
.45335 .5659 m .45442 .56377 L .45587 .56513 L 0 .025 .124 r
F
.45335 .5659 m .45189 .56452 L .45442 .56377 L F
.38036 .56566 m .38134 .56354 L .38285 .56491 L 0 .025 .123 r
F
.38036 .56566 m .37884 .56428 L .38134 .56354 L F
.50285 .56552 m .504 .56338 L .5054 .56476 L 0 .024 .123 r
F
.50285 .56552 m .50145 .56413 L .504 .56338 L F
.42336 .56558 m .4244 .56331 L .42587 .56477 L F
.42336 .56558 m .42188 .56412 L .4244 .56331 L F
.45985 .5658 m .46094 .56369 L .46238 .56509 L 0 .025 .124 r
F
.45985 .5658 m .4584 .56439 L .46094 .56369 L F
.38686 .56553 m .38785 .56343 L .38935 .5648 L 0 .025 .123 r
F
.38686 .56553 m .38535 .56417 L .38785 .56343 L F
.42986 .56539 m .43091 .56318 L .43238 .56462 L 0 .024 .122 r
F
.42986 .56539 m .42839 .56396 L .43091 .56318 L F
.46635 .56577 m .46745 .56357 L .46889 .56496 L 0 .025 .124 r
F
.46635 .56577 m .46491 .56438 L .46745 .56357 L F
.39336 .56546 m .39435 .56338 L .39585 .56476 L 0 .025 .123 r
F
.39336 .56546 m .39185 .56409 L .39435 .56338 L F
.47286 .56551 m .47397 .56329 L .4754 .56468 L F
.47286 .56551 m .47143 .56412 L .47397 .56329 L F
.43636 .56538 m .43742 .56324 L .43888 .5647 L F
.43636 .56538 m .4349 .56393 L .43742 .56324 L F
.47937 .56526 m .48048 .56303 L .48191 .56444 L 0 .024 .123 r
F
.47937 .56526 m .47794 .56386 L .48048 .56303 L F
.39986 .56534 m .40087 .56314 L .40236 .56451 L 0 .025 .123 r
F
.39986 .56534 m .39836 .56397 L .40087 .56314 L F
.40636 .56504 m .40738 .56296 L .40887 .56431 L 0 .024 .123 r
F
.40636 .56504 m .40487 .56369 L .40738 .56296 L F
.48588 .56508 m .487 .56293 L .48842 .56437 L F
.48588 .56508 m .48445 .56367 L .487 .56293 L F
.44286 .56539 m .44393 .5632 L .44539 .56464 L 0 .025 .124 r
F
.44286 .56539 m .4414 .56397 L .44393 .5632 L F
.41286 .56499 m .41389 .56281 L .41538 .56423 L 0 .024 .123 r
F
.41286 .56499 m .41138 .56357 L .41389 .56281 L F
.49238 .56503 m .49352 .56286 L .49493 .56426 L F
.49238 .56503 m .49097 .56365 L .49352 .56286 L F
.44937 .56528 m .45044 .56315 L .45189 .56452 L 0 .025 .124 r
F
.44937 .56528 m .44791 .56388 L .45044 .56315 L F
.49889 .56488 m .50004 .56273 L .50145 .56413 L 0 .024 .123 r
F
.49889 .56488 m .49748 .56349 L .50004 .56273 L F
.41937 .5649 m .4204 .56265 L .42188 .56412 L F
.41937 .5649 m .41789 .56344 L .4204 .56265 L F
.45587 .56513 m .45696 .56304 L .4584 .56439 L 0 .025 .124 r
F
.45587 .56513 m .45442 .56377 L .45696 .56304 L F
.38285 .56491 m .38384 .5628 L .38535 .56417 L 0 .025 .123 r
F
.38285 .56491 m .38134 .56354 L .38384 .5628 L F
.5054 .56476 m .50655 .56263 L .50796 .564 L 0 .024 .123 r
F
.5054 .56476 m .504 .56338 L .50655 .56263 L F
.42587 .56477 m .42692 .5625 L .42839 .56396 L 0 .024 .122 r
F
.42587 .56477 m .4244 .56331 L .42692 .5625 L F
.46238 .56509 m .46347 .563 L .46491 .56438 L 0 .025 .124 r
F
.46238 .56509 m .46094 .56369 L .46347 .563 L F
.38935 .5648 m .39035 .56272 L .39185 .56409 L 0 .025 .123 r
F
.38935 .5648 m .38785 .56343 L .39035 .56272 L F
.43238 .56462 m .43343 .56247 L .4349 .56393 L 0 .024 .123 r
F
.43238 .56462 m .43091 .56318 L .43343 .56247 L F
.46889 .56496 m .46999 .56273 L .47143 .56412 L 0 .025 .124 r
F
.46889 .56496 m .46745 .56357 L .46999 .56273 L F
.4754 .56468 m .47651 .56248 L .47794 .56386 L 0 .025 .123 r
F
.4754 .56468 m .47397 .56329 L .47651 .56248 L F
.39585 .56476 m .39686 .56259 L .39836 .56397 L F
.39585 .56476 m .39435 .56338 L .39686 .56259 L F
.48191 .56444 m .48303 .56225 L .48445 .56367 L 0 .024 .123 r
F
.48191 .56444 m .48048 .56303 L .48303 .56225 L F
.40236 .56451 m .40338 .56234 L .40487 .56369 L F
.40236 .56451 m .40087 .56314 L .40338 .56234 L F
.43888 .5647 m .43994 .56249 L .4414 .56397 L 0 .025 .123 r
F
.43888 .5647 m .43742 .56324 L .43994 .56249 L F
.40887 .56431 m .40989 .56224 L .41138 .56357 L 0 .024 .123 r
F
.40887 .56431 m .40738 .56296 L .40989 .56224 L F
.48842 .56437 m .48955 .5622 L .49097 .56365 L F
.48842 .56437 m .487 .56293 L .48955 .5622 L F
.44539 .56464 m .44646 .56244 L .44791 .56388 L 0 .025 .124 r
F
.44539 .56464 m .44393 .5632 L .44646 .56244 L F
.41538 .56423 m .41641 .56201 L .41789 .56344 L 0 .024 .123 r
F
.41538 .56423 m .41389 .56281 L .41641 .56201 L F
.49493 .56426 m .49607 .56207 L .49748 .56349 L F
.49493 .56426 m .49352 .56286 L .49607 .56207 L F
.45189 .56452 m .45297 .56242 L .45442 .56377 L 0 .025 .124 r
F
.45189 .56452 m .45044 .56315 L .45297 .56242 L F
.37884 .56428 m .37983 .56205 L .38134 .56354 L 0 .025 .123 r
F
.37884 .56428 m .37733 .56278 L .37983 .56205 L F
.42188 .56412 m .42292 .56185 L .4244 .56331 L 0 .024 .122 r
F
.42188 .56412 m .4204 .56265 L .42292 .56185 L F
.50145 .56413 m .50259 .56199 L .504 .56338 L 0 .024 .123 r
F
.50145 .56413 m .50004 .56273 L .50259 .56199 L F
.4584 .56439 m .45949 .56235 L .46094 .56369 L 0 .025 .124 r
F
.4584 .56439 m .45696 .56304 L .45949 .56235 L F
.42839 .56396 m .42944 .56172 L .43091 .56318 L 0 .024 .122 r
F
.42839 .56396 m .42692 .5625 L .42944 .56172 L F
.38535 .56417 m .38634 .56206 L .38785 .56343 L 0 .025 .123 r
F
.38535 .56417 m .38384 .5628 L .38634 .56206 L F
.50796 .564 m .50911 .56193 L .51051 .5633 L F
.50796 .564 m .50655 .56263 L .50911 .56193 L F
.46491 .56438 m .46601 .56219 L .46745 .56357 L 0 .025 .124 r
F
.46491 .56438 m .46347 .563 L .46601 .56219 L F
.39185 .56409 m .39285 .562 L .39435 .56338 L F
.39185 .56409 m .39035 .56272 L .39285 .562 L F
.4349 .56393 m .43595 .56177 L .43742 .56324 L 0 .025 .123 r
F
.4349 .56393 m .43343 .56247 L .43595 .56177 L F
.47143 .56412 m .47253 .5619 L .47397 .56329 L F
.47143 .56412 m .46999 .56273 L .47253 .5619 L F
.47794 .56386 m .47906 .56166 L .48048 .56303 L 0 .024 .123 r
F
.47794 .56386 m .47651 .56248 L .47906 .56166 L F
.39836 .56397 m .39937 .56176 L .40087 .56314 L 0 .025 .123 r
F
.39836 .56397 m .39686 .56259 L .39937 .56176 L F
.48445 .56367 m .48558 .5615 L .487 .56293 L 0 .024 .123 r
F
.48445 .56367 m .48303 .56225 L .48558 .5615 L F
.40487 .56369 m .40588 .56162 L .40738 .56296 L F
.40487 .56369 m .40338 .56234 L .40588 .56162 L F
.4414 .56397 m .44247 .56172 L .44393 .5632 L 0 .025 .123 r
F
.4414 .56397 m .43994 .56249 L .44247 .56172 L F
.41138 .56357 m .4124 .56147 L .41389 .56281 L 0 .024 .123 r
F
.41138 .56357 m .40989 .56224 L .4124 .56147 L F
.49097 .56365 m .4921 .5614 L .49352 .56286 L F
.49097 .56365 m .48955 .5622 L .4921 .5614 L F
.44791 .56388 m .44899 .56171 L .45044 .56315 L 0 .025 .124 r
F
.44791 .56388 m .44646 .56244 L .44899 .56171 L F
.41789 .56344 m .41892 .56121 L .4204 .56265 L 0 .024 .122 r
F
.41789 .56344 m .41641 .56201 L .41892 .56121 L F
.49748 .56349 m .49862 .56131 L .50004 .56273 L 0 .024 .123 r
F
.49748 .56349 m .49607 .56207 L .49862 .56131 L F
.45442 .56377 m .4555 .5617 L .45696 .56304 L 0 .025 .124 r
F
.45442 .56377 m .45297 .56242 L .4555 .5617 L F
.4244 .56331 m .42544 .56104 L .42692 .5625 L 0 .024 .122 r
F
.4244 .56331 m .42292 .56185 L .42544 .56104 L F
.38134 .56354 m .38233 .56132 L .38384 .5628 L 0 .025 .123 r
F
.38134 .56354 m .37983 .56205 L .38233 .56132 L F
.504 .56338 m .50515 .56125 L .50655 .56263 L F
.504 .56338 m .50259 .56199 L .50515 .56125 L F
.46094 .56369 m .46203 .56165 L .46347 .563 L 0 .025 .124 r
F
.46094 .56369 m .45949 .56235 L .46203 .56165 L F
.43091 .56318 m .43196 .56102 L .43343 .56247 L 0 .024 .123 r
F
.43091 .56318 m .42944 .56172 L .43196 .56102 L F
.38785 .56343 m .38884 .56134 L .39035 .56272 L 0 .025 .124 r
F
.38785 .56343 m .38634 .56206 L .38884 .56134 L F
.51051 .5633 m .51167 .56124 L .51307 .56263 L 0 .025 .123 r
F
.51051 .5633 m .50911 .56193 L .51167 .56124 L F
.46745 .56357 m .46855 .56135 L .46999 .56273 L 0 .025 .124 r
F
.46745 .56357 m .46601 .56219 L .46855 .56135 L F
.47397 .56329 m .47508 .5611 L .47651 .56248 L 0 .025 .123 r
F
.47397 .56329 m .47253 .5619 L .47508 .5611 L F
.39435 .56338 m .39535 .5612 L .39686 .56259 L 0 .025 .124 r
F
.39435 .56338 m .39285 .562 L .39535 .5612 L F
.48048 .56303 m .4816 .56088 L .48303 .56225 L 0 .024 .123 r
F
.48048 .56303 m .47906 .56166 L .4816 .56088 L F
.43742 .56324 m .43848 .56101 L .43994 .56249 L 0 .025 .123 r
F
.43742 .56324 m .43595 .56177 L .43848 .56101 L F
.40087 .56314 m .40188 .56096 L .40338 .56234 L F
.40087 .56314 m .39937 .56176 L .40188 .56096 L F
.487 .56293 m .48813 .56075 L .48955 .5622 L 0 .024 .123 r
F
.487 .56293 m .48558 .5615 L .48813 .56075 L F
.40738 .56296 m .4084 .5609 L .40989 .56224 L 0 .025 .123 r
F
.40738 .56296 m .40588 .56162 L .4084 .5609 L F
.44393 .5632 m .445 .56094 L .44646 .56244 L F
.44393 .5632 m .44247 .56172 L .445 .56094 L F
.41389 .56281 m .41492 .56066 L .41641 .56201 L 0 .024 .123 r
F
.41389 .56281 m .4124 .56147 L .41492 .56066 L F
.49352 .56286 m .49465 .5606 L .49607 .56207 L F
.49352 .56286 m .4921 .5614 L .49465 .5606 L F
.37733 .56278 m .37831 .56056 L .37983 .56205 L F
.37733 .56278 m .37582 .56128 L .37831 .56056 L F
.45044 .56315 m .45152 .56099 L .45297 .56242 L 0 .025 .124 r
F
.45044 .56315 m .44899 .56171 L .45152 .56099 L F
.4204 .56265 m .42144 .56041 L .42292 .56185 L 0 .024 .122 r
F
.4204 .56265 m .41892 .56121 L .42144 .56041 L F
.50004 .56273 m .50118 .56057 L .50259 .56199 L 0 .024 .123 r
F
.50004 .56273 m .49862 .56131 L .50118 .56057 L F
.45696 .56304 m .45804 .56101 L .45949 .56235 L 0 .026 .124 r
F
.45696 .56304 m .4555 .5617 L .45804 .56101 L F
.42692 .5625 m .42797 .56027 L .42944 .56172 L 0 .024 .122 r
F
.42692 .5625 m .42544 .56104 L .42797 .56027 L F
.38384 .5628 m .38483 .56059 L .38634 .56206 L 0 .025 .123 r
F
.38384 .5628 m .38233 .56132 L .38483 .56059 L F
.50655 .56263 m .50771 .56055 L .50911 .56193 L F
.50655 .56263 m .50515 .56125 L .50771 .56055 L F
.46347 .563 m .46457 .56084 L .46601 .56219 L 0 .026 .124 r
F
.46347 .563 m .46203 .56165 L .46457 .56084 L F
.43343 .56247 m .43449 .56032 L .43595 .56177 L 0 .024 .123 r
F
.43343 .56247 m .43196 .56102 L .43449 .56032 L F
.39035 .56272 m .39134 .56061 L .39285 .562 L 0 .025 .124 r
F
.39035 .56272 m .38884 .56134 L .39134 .56061 L F
.46999 .56273 m .4711 .56052 L .47253 .5619 L F
.46999 .56273 m .46855 .56135 L .4711 .56052 L F
.51307 .56263 m .51423 .56054 L .51563 .56193 L F
.51307 .56263 m .51167 .56124 L .51423 .56054 L F
.47651 .56248 m .47762 .5603 L .47906 .56166 L 0 .025 .123 r
F
.47651 .56248 m .47508 .5611 L .47762 .5603 L F
.39686 .56259 m .39787 .56038 L .39937 .56176 L F
.39686 .56259 m .39535 .5612 L .39787 .56038 L F
.48303 .56225 m .48415 .56012 L .48558 .5615 L 0 .024 .123 r
F
.48303 .56225 m .4816 .56088 L .48415 .56012 L F
.43994 .56249 m .44101 .56023 L .44247 .56172 L 0 .025 .123 r
F
.43994 .56249 m .43848 .56101 L .44101 .56023 L F
.40338 .56234 m .40439 .56023 L .40588 .56162 L F
.40338 .56234 m .40188 .56096 L .40439 .56023 L F
.48955 .5622 m .49068 .55994 L .4921 .5614 L 0 .024 .123 r
F
.48955 .5622 m .48813 .56075 L .49068 .55994 L F
.40989 .56224 m .41091 .56012 L .4124 .56147 L 0 .025 .123 r
F
.40989 .56224 m .4084 .5609 L .41091 .56012 L F
.44646 .56244 m .44753 .56022 L .44899 .56171 L 0 .025 .124 r
F
.44646 .56244 m .445 .56094 L .44753 .56022 L F
.41641 .56201 m .41744 .55985 L .41892 .56121 L 0 .024 .123 r
F
.41641 .56201 m .41492 .56066 L .41744 .55985 L F
.49607 .56207 m .49721 .55983 L .49862 .56131 L F
.49607 .56207 m .49465 .5606 L .49721 .55983 L F
.42292 .56185 m .42397 .55961 L .42544 .56104 L 0 .024 .122 r
F
.42292 .56185 m .42144 .56041 L .42397 .55961 L F
.37983 .56205 m .38081 .55984 L .38233 .56132 L 0 .024 .123 r
F
.37983 .56205 m .37831 .56056 L .38081 .55984 L F
.45297 .56242 m .45405 .56028 L .4555 .5617 L 0 .025 .124 r
F
.45297 .56242 m .45152 .56099 L .45405 .56028 L F
.50259 .56199 m .50374 .55983 L .50515 .56125 L 0 .025 .123 r
F
.50259 .56199 m .50118 .56057 L .50374 .55983 L F
.42944 .56172 m .43049 .55957 L .43196 .56102 L 0 .024 .122 r
F
.42944 .56172 m .42797 .56027 L .43049 .55957 L F
.45949 .56235 m .46058 .56031 L .46203 .56165 L 0 .026 .125 r
F
.45949 .56235 m .45804 .56101 L .46058 .56031 L F
.38634 .56206 m .38733 .55987 L .38884 .56134 L 0 .025 .124 r
F
.38634 .56206 m .38483 .56059 L .38733 .55987 L F
.50911 .56193 m .51027 .55986 L .51167 .56124 L 0 .025 .123 r
F
.50911 .56193 m .50771 .56055 L .51027 .55986 L F
.46601 .56219 m .46711 .56 L .46855 .56135 L 0 .025 .124 r
F
.46601 .56219 m .46457 .56084 L .46711 .56 L F
.47253 .5619 m .47364 .55973 L .47508 .5611 L 0 .025 .123 r
F
.47253 .5619 m .4711 .56052 L .47364 .55973 L F
.43595 .56177 m .43701 .55956 L .43848 .56101 L F
.43595 .56177 m .43449 .56032 L .43701 .55956 L F
.39285 .562 m .39385 .55981 L .39535 .5612 L 0 .025 .124 r
F
.39285 .562 m .39134 .56061 L .39385 .55981 L F
.47906 .56166 m .48017 .55953 L .4816 .56088 L 0 .025 .123 r
F
.47906 .56166 m .47762 .5603 L .48017 .55953 L F
.51563 .56193 m .5168 .55973 L .5182 .56112 L 0 .025 .124 r
F
.51563 .56193 m .51423 .56054 L .5168 .55973 L F
.39937 .56176 m .40038 .55956 L .40188 .56096 L 0 .025 .123 r
F
.39937 .56176 m .39787 .56038 L .40038 .55956 L F
.48558 .5615 m .4867 .55936 L .48813 .56075 L 0 .024 .123 r
F
.48558 .5615 m .48415 .56012 L .4867 .55936 L F
.44247 .56172 m .44354 .55944 L .445 .56094 L 0 .025 .123 r
F
.44247 .56172 m .44101 .56023 L .44354 .55944 L F
.40588 .56162 m .4069 .55951 L .4084 .5609 L F
.40588 .56162 m .40439 .56023 L .4069 .55951 L F
.4921 .5614 m .49323 .55913 L .49465 .5606 L 0 .024 .123 r
F
.4921 .5614 m .49068 .55994 L .49323 .55913 L F
.37582 .56128 m .3768 .55909 L .37831 .56056 L 0 .024 .122 r
F
.37582 .56128 m .3743 .5598 L .3768 .55909 L F
.4124 .56147 m .41343 .5593 L .41492 .56066 L 0 .025 .123 r
F
.4124 .56147 m .41091 .56012 L .41343 .5593 L F
.44899 .56171 m .45006 .5595 L .45152 .56099 L 0 .025 .124 r
F
.44899 .56171 m .44753 .56022 L .45006 .5595 L F
.41892 .56121 m .41996 .55905 L .42144 .56041 L 0 .024 .122 r
F
.41892 .56121 m .41744 .55985 L .41996 .55905 L F
.49862 .56131 m .49977 .55909 L .50118 .56057 L 0 .024 .123 r
F
.49862 .56131 m .49721 .55983 L .49977 .55909 L F
.42544 .56104 m .42649 .55884 L .42797 .56027 L 0 .024 .122 r
F
.42544 .56104 m .42397 .55961 L .42649 .55884 L F
.38233 .56132 m .38331 .55911 L .38483 .56059 L 0 .025 .123 r
F
.38233 .56132 m .38081 .55984 L .38331 .55911 L F
.4555 .5617 m .45659 .55958 L .45804 .56101 L 0 .026 .124 r
F
.4555 .5617 m .45405 .56028 L .45659 .55958 L F
.50515 .56125 m .5063 .55913 L .50771 .56055 L 0 .025 .123 r
F
.50515 .56125 m .50374 .55983 L .5063 .55913 L F
.43196 .56102 m .43301 .55887 L .43449 .56032 L 0 .024 .123 r
F
.43196 .56102 m .43049 .55957 L .43301 .55887 L F
.46203 .56165 m .46312 .5595 L .46457 .56084 L 0 .026 .125 r
F
.46203 .56165 m .46058 .56031 L .46312 .5595 L F
.38884 .56134 m .38983 .55914 L .39134 .56061 L 0 .025 .124 r
F
.38884 .56134 m .38733 .55987 L .38983 .55914 L F
.46855 .56135 m .46965 .55917 L .4711 .56052 L F
.46855 .56135 m .46711 .56 L .46965 .55917 L F
.51167 .56124 m .51283 .55915 L .51423 .56054 L F
.51167 .56124 m .51027 .55986 L .51283 .55915 L F
.47508 .5611 m .47619 .55895 L .47762 .5603 L 0 .025 .123 r
F
.47508 .5611 m .47364 .55973 L .47619 .55895 L F
.43848 .56101 m .43954 .55877 L .44101 .56023 L F
.43848 .56101 m .43701 .55956 L .43954 .55877 L F
.39535 .5612 m .39636 .55898 L .39787 .56038 L 0 .025 .124 r
F
.39535 .5612 m .39385 .55981 L .39636 .55898 L F
.4816 .56088 m .48272 .55876 L .48415 .56012 L 0 .025 .123 r
F
.4816 .56088 m .48017 .55953 L .48272 .55876 L F
.5182 .56112 m .51937 .55891 L .52077 .56031 L 0 .025 .124 r
F
.5182 .56112 m .5168 .55973 L .51937 .55891 L F
.40188 .56096 m .40289 .55883 L .40439 .56023 L 0 .025 .123 r
F
.40188 .56096 m .40038 .55956 L .40289 .55883 L F
.48813 .56075 m .48926 .55855 L .49068 .55994 L 0 .024 .123 r
F
.48813 .56075 m .4867 .55936 L .48926 .55855 L F
.445 .56094 m .44607 .55872 L .44753 .56022 L 0 .025 .123 r
F
.445 .56094 m .44354 .55944 L .44607 .55872 L F
.4084 .5609 m .40942 .55873 L .41091 .56012 L F
.4084 .5609 m .4069 .55951 L .40942 .55873 L F
.49465 .5606 m .49579 .55834 L .49721 .55983 L 0 .024 .122 r
F
.49465 .5606 m .49323 .55913 L .49579 .55834 L F
.41492 .56066 m .41595 .55848 L .41744 .55985 L 0 .024 .123 r
F
.41492 .56066 m .41343 .5593 L .41595 .55848 L F
.37831 .56056 m .3793 .55839 L .38081 .55984 L F
.37831 .56056 m .3768 .55909 L .3793 .55839 L F
.42144 .56041 m .42248 .55825 L .42397 .55961 L 0 .024 .122 r
F
.42144 .56041 m .41996 .55905 L .42248 .55825 L F
.45152 .56099 m .4526 .55878 L .45405 .56028 L 0 .025 .124 r
F
.45152 .56099 m .45006 .5595 L .4526 .55878 L F
.50118 .56057 m .50233 .55835 L .50374 .55983 L 0 .025 .123 r
F
.50118 .56057 m .49977 .55909 L .50233 .55835 L F
.42797 .56027 m .42901 .55813 L .43049 .55957 L 0 .024 .122 r
F
.42797 .56027 m .42649 .55884 L .42901 .55813 L F
.38483 .56059 m .38582 .55839 L .38733 .55987 L 0 .025 .123 r
F
.38483 .56059 m .38331 .55911 L .38582 .55839 L F
.45804 .56101 m .45913 .55888 L .46058 .56031 L 0 .026 .125 r
F
.45804 .56101 m .45659 .55958 L .45913 .55888 L F
.50771 .56055 m .50886 .55843 L .51027 .55986 L 0 .025 .124 r
F
.50771 .56055 m .5063 .55913 L .50886 .55843 L F
.46457 .56084 m .46566 .55865 L .46711 .56 L 0 .026 .124 r
F
.46457 .56084 m .46312 .5595 L .46566 .55865 L F
.43449 .56032 m .43554 .5581 L .43701 .55956 L 0 .024 .123 r
F
.43449 .56032 m .43301 .55887 L .43554 .5581 L F
.4711 .56052 m .4722 .5584 L .47364 .55973 L 0 .025 .124 r
F
.4711 .56052 m .46965 .55917 L .4722 .5584 L F
.39134 .56061 m .39234 .55835 L .39385 .55981 L F
.39134 .56061 m .38983 .55914 L .39234 .55835 L F
.47762 .5603 m .47874 .55817 L .48017 .55953 L 0 .025 .123 r
F
.47762 .5603 m .47619 .55895 L .47874 .55817 L F
.51423 .56054 m .5154 .55833 L .5168 .55973 L 0 .025 .124 r
F
.51423 .56054 m .51283 .55915 L .5154 .55833 L F
.39787 .56038 m .39888 .55817 L .40038 .55956 L 0 .025 .123 r
F
.39787 .56038 m .39636 .55898 L .39888 .55817 L F
.44101 .56023 m .44208 .55798 L .44354 .55944 L F
.44101 .56023 m .43954 .55877 L .44208 .55798 L F
.48415 .56012 m .48528 .558 L .4867 .55936 L F
.48415 .56012 m .48272 .55876 L .48528 .558 L F
.52077 .56031 m .52194 .55811 L .52333 .55951 L F
.52077 .56031 m .51937 .55891 L .52194 .55811 L F
.40439 .56023 m .4054 .5581 L .4069 .55951 L F
.40439 .56023 m .40289 .55883 L .4054 .5581 L F
.49068 .55994 m .49181 .55773 L .49323 .55913 L 0 .024 .123 r
F
.49068 .55994 m .48926 .55855 L .49181 .55773 L F
.3743 .5598 m .37527 .55767 L .3768 .55909 L 0 .024 .122 r
F
.3743 .5598 m .37278 .55836 L .37527 .55767 L F
.44753 .56022 m .44861 .558 L .45006 .5595 L 0 .025 .124 r
F
.44753 .56022 m .44607 .55872 L .44861 .558 L F
.41091 .56012 m .41194 .5579 L .41343 .5593 L 0 .025 .123 r
F
.41091 .56012 m .40942 .55873 L .41194 .5579 L F
.49721 .55983 m .49835 .5576 L .49977 .55909 L 0 .024 .123 r
F
.49721 .55983 m .49579 .55834 L .49835 .5576 L F
.41744 .55985 m .41847 .55769 L .41996 .55905 L F
.41744 .55985 m .41595 .55848 L .41847 .55769 L F
.42397 .55961 m .42501 .55748 L .42649 .55884 L 0 .024 .122 r
F
.42397 .55961 m .42248 .55825 L .42501 .55748 L F
.38081 .55984 m .3818 .55767 L .38331 .55911 L 0 .025 .123 r
F
.38081 .55984 m .3793 .55839 L .3818 .55767 L F
.45405 .56028 m .45514 .55808 L .45659 .55958 L 0 .026 .124 r
F
.45405 .56028 m .4526 .55878 L .45514 .55808 L F
.50374 .55983 m .50489 .55764 L .5063 .55913 L 0 .025 .123 r
F
.50374 .55983 m .50233 .55835 L .50489 .55764 L F
.43049 .55957 m .43154 .55743 L .43301 .55887 L 0 .024 .123 r
F
.43049 .55957 m .42901 .55813 L .43154 .55743 L F
.38733 .55987 m .38832 .55766 L .38983 .55914 L 0 .025 .124 r
F
.38733 .55987 m .38582 .55839 L .38832 .55766 L F
.46058 .56031 m .46167 .55807 L .46312 .5595 L 0 .026 .125 r
F
.46058 .56031 m .45913 .55888 L .46167 .55807 L F
.46711 .56 m .46821 .55782 L .46965 .55917 L 0 .025 .124 r
F
.46711 .56 m .46566 .55865 L .46821 .55782 L F
.51027 .55986 m .51143 .55771 L .51283 .55915 L F
.51027 .55986 m .50886 .55843 L .51143 .55771 L F
.47364 .55973 m .47475 .55762 L .47619 .55895 L F
.47364 .55973 m .4722 .5584 L .47475 .55762 L F
.43701 .55956 m .43808 .55731 L .43954 .55877 L 0 .024 .123 r
F
.43701 .55956 m .43554 .5581 L .43808 .55731 L F
.39385 .55981 m .39486 .55753 L .39636 .55898 L 0 .025 .124 r
F
.39385 .55981 m .39234 .55835 L .39486 .55753 L F
.48017 .55953 m .48129 .5574 L .48272 .55876 L 0 .025 .123 r
F
.48017 .55953 m .47874 .55817 L .48129 .5574 L F
.5168 .55973 m .51797 .5575 L .51937 .55891 L 0 .025 .124 r
F
.5168 .55973 m .5154 .55833 L .51797 .5575 L F
.40038 .55956 m .40139 .55743 L .40289 .55883 L 0 .025 .123 r
F
.40038 .55956 m .39888 .55817 L .40139 .55743 L F
.44354 .55944 m .44461 .55727 L .44607 .55872 L F
.44354 .55944 m .44208 .55798 L .44461 .55727 L F
.52333 .55951 m .52451 .55732 L .5259 .55872 L F
.52333 .55951 m .52194 .55811 L .52451 .55732 L F
.4867 .55936 m .48783 .55717 L .48926 .55855 L F
.4867 .55936 m .48528 .558 L .48783 .55717 L F
.49323 .55913 m .49437 .55694 L .49579 .55834 L 0 .024 .122 r
F
.49323 .55913 m .49181 .55773 L .49437 .55694 L F
.4069 .55951 m .40792 .55731 L .40942 .55873 L 0 .025 .124 r
F
.4069 .55951 m .4054 .5581 L .40792 .55731 L F
.3768 .55909 m .37778 .55697 L .3793 .55839 L 0 .024 .123 r
F
.3768 .55909 m .37527 .55767 L .37778 .55697 L F
.41343 .5593 m .41446 .55707 L .41595 .55848 L 0 .025 .123 r
F
.41343 .5593 m .41194 .5579 L .41446 .55707 L F
.45006 .5595 m .45114 .55729 L .4526 .55878 L 0 .025 .124 r
F
.45006 .5595 m .44861 .558 L .45114 .55729 L F
.41996 .55905 m .421 .55689 L .42248 .55825 L 0 .024 .123 r
F
.41996 .55905 m .41847 .55769 L .421 .55689 L F
.49977 .55909 m .50091 .55687 L .50233 .55835 L F
.49977 .55909 m .49835 .5576 L .50091 .55687 L F
.42649 .55884 m .42754 .55675 L .42901 .55813 L 0 .024 .122 r
F
.42649 .55884 m .42501 .55748 L .42754 .55675 L F
.38331 .55911 m .3843 .55694 L .38582 .55839 L 0 .025 .123 r
F
.38331 .55911 m .3818 .55767 L .3843 .55694 L F
.45659 .55958 m .45768 .55738 L .45913 .55888 L 0 .026 .125 r
F
.45659 .55958 m .45514 .55808 L .45768 .55738 L F
.5063 .55913 m .50745 .55693 L .50886 .55843 L 0 .025 .123 r
F
.5063 .55913 m .50489 .55764 L .50745 .55693 L F
.43301 .55887 m .43407 .55666 L .43554 .5581 L 0 .024 .123 r
F
.43301 .55887 m .43154 .55743 L .43407 .55666 L F
.46312 .5595 m .46422 .55723 L .46566 .55865 L 0 .026 .125 r
F
.46312 .5595 m .46167 .55807 L .46422 .55723 L F
.38983 .55914 m .39084 .55688 L .39234 .55835 L 0 .025 .124 r
F
.38983 .55914 m .38832 .55766 L .39084 .55688 L F
.46965 .55917 m .47076 .55706 L .4722 .5584 L F
.46965 .55917 m .46821 .55782 L .47076 .55706 L F
.43954 .55877 m .44061 .55652 L .44208 .55798 L 0 .024 .123 r
F
.43954 .55877 m .43808 .55731 L .44061 .55652 L F
.47619 .55895 m .4773 .55683 L .47874 .55817 L 0 .025 .124 r
F
.47619 .55895 m .47475 .55762 L .4773 .55683 L F
.51283 .55915 m .514 .55689 L .5154 .55833 L F
.51283 .55915 m .51143 .55771 L .514 .55689 L F
.39636 .55898 m .39737 .55673 L .39888 .55817 L 0 .025 .123 r
F
.39636 .55898 m .39486 .55753 L .39737 .55673 L F
.51937 .55891 m .52054 .5567 L .52194 .55811 L 0 .025 .124 r
F
.51937 .55891 m .51797 .5575 L .52054 .5567 L F
.48272 .55876 m .48385 .55663 L .48528 .558 L 0 .025 .123 r
F
.48272 .55876 m .48129 .5574 L .48385 .55663 L F
.40289 .55883 m .40391 .55668 L .4054 .5581 L 0 .025 .124 r
F
.40289 .55883 m .40139 .55743 L .40391 .55668 L F
.5259 .55872 m .52709 .55653 L .52848 .55792 L 0 .025 .123 r
F
.5259 .55872 m .52451 .55732 L .52709 .55653 L F
.37278 .55836 m .37375 .55623 L .37527 .55767 L 0 .024 .122 r
F
.37278 .55836 m .37125 .55691 L .37375 .55623 L F
.44607 .55872 m .44715 .55657 L .44861 .558 L 0 .025 .123 r
F
.44607 .55872 m .44461 .55727 L .44715 .55657 L F
.48926 .55855 m .49039 .55634 L .49181 .55773 L 0 .024 .123 r
F
.48926 .55855 m .48783 .55717 L .49039 .55634 L F
.49579 .55834 m .49693 .55621 L .49835 .5576 L F
.49579 .55834 m .49437 .55694 L .49693 .55621 L F
.40942 .55873 m .41045 .55647 L .41194 .5579 L 0 .025 .123 r
F
.40942 .55873 m .40792 .55731 L .41045 .55647 L F
.41595 .55848 m .41699 .55627 L .41847 .55769 L F
.41595 .55848 m .41446 .55707 L .41699 .55627 L F
.3793 .55839 m .38028 .55626 L .3818 .55767 L F
.3793 .55839 m .37778 .55697 L .38028 .55626 L F
.4526 .55878 m .45368 .55658 L .45514 .55808 L 0 .025 .124 r
F
.4526 .55878 m .45114 .55729 L .45368 .55658 L F
.42248 .55825 m .42353 .55611 L .42501 .55748 L 0 .024 .123 r
F
.42248 .55825 m .421 .55689 L .42353 .55611 L F
.50233 .55835 m .50348 .55614 L .50489 .55764 L 0 .025 .123 r
F
.50233 .55835 m .50091 .55687 L .50348 .55614 L F
.42901 .55813 m .43006 .55603 L .43154 .55743 L 0 .024 .123 r
F
.42901 .55813 m .42754 .55675 L .43006 .55603 L F
.38582 .55839 m .38681 .55621 L .38832 .55766 L 0 .025 .123 r
F
.38582 .55839 m .3843 .55694 L .38681 .55621 L F
.45913 .55888 m .46022 .55658 L .46167 .55807 L 0 .026 .125 r
F
.45913 .55888 m .45768 .55738 L .46022 .55658 L F
.50886 .55843 m .51002 .55621 L .51143 .55771 L 0 .025 .124 r
F
.50886 .55843 m .50745 .55693 L .51002 .55621 L F
.43554 .5581 m .43661 .55586 L .43808 .55731 L 0 .024 .123 r
F
.43554 .5581 m .43407 .55666 L .43661 .55586 L F
.46566 .55865 m .46677 .55641 L .46821 .55782 L 0 .026 .124 r
F
.46566 .55865 m .46422 .55723 L .46677 .55641 L F
.39234 .55835 m .39335 .55608 L .39486 .55753 L 0 .025 .124 r
F
.39234 .55835 m .39084 .55688 L .39335 .55608 L F
.4722 .5584 m .47331 .55629 L .47475 .55762 L F
.4722 .5584 m .47076 .55706 L .47331 .55629 L F
.5154 .55833 m .51657 .55606 L .51797 .5575 L F
.5154 .55833 m .514 .55689 L .51657 .55606 L F
.44208 .55798 m .44315 .55583 L .44461 .55727 L 0 .025 .123 r
F
.44208 .55798 m .44061 .55652 L .44315 .55583 L F
.39888 .55817 m .39989 .55601 L .40139 .55743 L 0 .025 .124 r
F
.39888 .55817 m .39737 .55673 L .39989 .55601 L F
.47874 .55817 m .47986 .55604 L .48129 .5574 L F
.47874 .55817 m .4773 .55683 L .47986 .55604 L F
.52194 .55811 m .52312 .55592 L .52451 .55732 L 0 .025 .123 r
F
.52194 .55811 m .52054 .5567 L .52312 .55592 L F
.48528 .558 m .4864 .5558 L .48783 .55717 L F
.48528 .558 m .48385 .55663 L .4864 .5558 L F
.49181 .55773 m .49295 .55555 L .49437 .55694 L 0 .024 .123 r
F
.49181 .55773 m .49039 .55634 L .49295 .55555 L F
.4054 .5581 m .40643 .55589 L .40792 .55731 L 0 .025 .124 r
F
.4054 .5581 m .40391 .55668 L .40643 .55589 L F
.52848 .55792 m .52966 .5558 L .53105 .55721 L 0 .025 .123 r
F
.52848 .55792 m .52709 .55653 L .52966 .5558 L F
.44861 .558 m .44968 .55586 L .45114 .55729 L 0 .025 .124 r
F
.44861 .558 m .44715 .55657 L .44968 .55586 L F
.37527 .55767 m .37625 .55556 L .37778 .55697 L 0 .024 .123 r
F
.37527 .55767 m .37375 .55623 L .37625 .55556 L F
.41194 .5579 m .41297 .55563 L .41446 .55707 L 0 .025 .123 r
F
.41194 .5579 m .41045 .55647 L .41297 .55563 L F
.49835 .5576 m .4995 .55548 L .50091 .55687 L 0 .024 .123 r
F
.49835 .5576 m .49693 .55621 L .4995 .55548 L F
.41847 .55769 m .41951 .55547 L .421 .55689 L F
.41847 .55769 m .41699 .55627 L .41951 .55547 L F
.42501 .55748 m .42605 .55537 L .42754 .55675 L F
.42501 .55748 m .42353 .55611 L .42605 .55537 L F
.3818 .55767 m .38279 .55553 L .3843 .55694 L 0 .025 .123 r
F
.3818 .55767 m .38028 .55626 L .38279 .55553 L F
.45514 .55808 m .45623 .55588 L .45768 .55738 L 0 .026 .124 r
F
.45514 .55808 m .45368 .55658 L .45623 .55588 L F
.50489 .55764 m .50604 .55543 L .50745 .55693 L 0 .025 .123 r
F
.50489 .55764 m .50348 .55614 L .50604 .55543 L F
.43154 .55743 m .4326 .55524 L .43407 .55666 L 0 .024 .123 r
F
.43154 .55743 m .43006 .55603 L .4326 .55524 L F
.38832 .55766 m .38932 .55544 L .39084 .55688 L 0 .025 .124 r
F
.38832 .55766 m .38681 .55621 L .38932 .55544 L F
.46167 .55807 m .46277 .55575 L .46422 .55723 L 0 .026 .125 r
F
.46167 .55807 m .46022 .55658 L .46277 .55575 L F
.46821 .55782 m .46932 .55565 L .47076 .55706 L 0 .026 .124 r
F
.46821 .55782 m .46677 .55641 L .46932 .55565 L F
.43808 .55731 m .43914 .55506 L .44061 .55652 L 0 .024 .123 r
F
.43808 .55731 m .43661 .55586 L .43914 .55506 L F
.51143 .55771 m .51259 .55539 L .514 .55689 L 0 .025 .124 r
F
.51143 .55771 m .51002 .55621 L .51259 .55539 L F
.39486 .55753 m .39587 .55529 L .39737 .55673 L 0 .025 .123 r
F
.39486 .55753 m .39335 .55608 L .39587 .55529 L F
.47475 .55762 m .47586 .55549 L .4773 .55683 L 0 .025 .124 r
F
.47475 .55762 m .47331 .55629 L .47586 .55549 L F
.51797 .5575 m .51914 .55526 L .52054 .5567 L F
.51797 .5575 m .51657 .55606 L .51914 .55526 L F
.48129 .5574 m .48241 .55525 L .48385 .55663 L F
.48129 .5574 m .47986 .55604 L .48241 .55525 L F
.40139 .55743 m .4024 .55528 L .40391 .55668 L F
.40139 .55743 m .39989 .55601 L .4024 .55528 L F
.37125 .55691 m .37222 .55478 L .37375 .55623 L 0 .024 .122 r
F
.37125 .55691 m .36972 .55546 L .37222 .55478 L F
.44461 .55727 m .44568 .55514 L .44715 .55657 L 0 .025 .123 r
F
.44461 .55727 m .44315 .55583 L .44568 .55514 L F
.52451 .55732 m .52569 .55514 L .52709 .55653 L F
.52451 .55732 m .52312 .55592 L .52569 .55514 L F
.48783 .55717 m .48896 .55496 L .49039 .55634 L F
.48783 .55717 m .4864 .5558 L .48896 .55496 L F
.49437 .55694 m .49551 .55483 L .49693 .55621 L 0 .024 .123 r
F
.49437 .55694 m .49295 .55555 L .49551 .55483 L F
.40792 .55731 m .40895 .55504 L .41045 .55647 L 0 .025 .123 r
F
.40792 .55731 m .40643 .55589 L .40895 .55504 L F
.53105 .55721 m .53224 .55507 L .53363 .5565 L 0 .025 .124 r
F
.53105 .55721 m .52966 .5558 L .53224 .55507 L F
.41446 .55707 m .4155 .55482 L .41699 .55627 L 0 .025 .123 r
F
.41446 .55707 m .41297 .55563 L .4155 .55482 L F
.45114 .55729 m .45223 .55516 L .45368 .55658 L 0 .025 .124 r
F
.45114 .55729 m .44968 .55586 L .45223 .55516 L F
.37778 .55697 m .37876 .55486 L .38028 .55626 L 0 .025 .123 r
F
.37778 .55697 m .37625 .55556 L .37876 .55486 L F
.50091 .55687 m .50206 .55475 L .50348 .55614 L 0 .024 .123 r
F
.50091 .55687 m .4995 .55548 L .50206 .55475 L F
.421 .55689 m .42204 .55468 L .42353 .55611 L F
.421 .55689 m .41951 .55547 L .42204 .55468 L F
.42754 .55675 m .42859 .55462 L .43006 .55603 L 0 .025 .123 r
F
.42754 .55675 m .42605 .55537 L .42859 .55462 L F
.3843 .55694 m .3853 .5548 L .38681 .55621 L F
.3843 .55694 m .38279 .55553 L .3853 .5548 L F
.45768 .55738 m .45877 .55508 L .46022 .55658 L 0 .026 .125 r
F
.45768 .55738 m .45623 .55588 L .45877 .55508 L F
.50745 .55693 m .50861 .5547 L .51002 .55621 L 0 .025 .123 r
F
.50745 .55693 m .50604 .55543 L .50861 .5547 L F
.43407 .55666 m .43513 .55443 L .43661 .55586 L 0 .024 .123 r
F
.43407 .55666 m .4326 .55524 L .43513 .55443 L F
.46422 .55723 m .46532 .55494 L .46677 .55641 L 0 .026 .124 r
F
.46422 .55723 m .46277 .55575 L .46532 .55494 L F
.39084 .55688 m .39184 .55466 L .39335 .55608 L 0 .025 .124 r
F
.39084 .55688 m .38932 .55544 L .39184 .55466 L F
.47076 .55706 m .47187 .5549 L .47331 .55629 L 0 .026 .124 r
F
.47076 .55706 m .46932 .55565 L .47187 .5549 L F
.44061 .55652 m .44168 .55438 L .44315 .55583 L 0 .024 .123 r
F
.44061 .55652 m .43914 .55506 L .44168 .55438 L F
.514 .55689 m .51516 .55457 L .51657 .55606 L 0 .025 .124 r
F
.514 .55689 m .51259 .55539 L .51516 .55457 L F
.39737 .55673 m .39838 .55459 L .39989 .55601 L F
.39737 .55673 m .39587 .55529 L .39838 .55459 L F
.4773 .55683 m .47842 .55468 L .47986 .55604 L F
.4773 .55683 m .47586 .55549 L .47842 .55468 L F
.52054 .5567 m .52172 .55449 L .52312 .55592 L F
.52054 .5567 m .51914 .55526 L .52172 .55449 L F
.48385 .55663 m .48497 .5544 L .4864 .5558 L 0 .025 .123 r
F
.48385 .55663 m .48241 .55525 L .48497 .5544 L F
.40391 .55668 m .40493 .55449 L .40643 .55589 L 0 .025 .124 r
F
.40391 .55668 m .4024 .55528 L .40493 .55449 L F
.49039 .55634 m .49153 .55416 L .49295 .55555 L 0 .024 .123 r
F
.49039 .55634 m .48896 .55496 L .49153 .55416 L F
.52709 .55653 m .52827 .55438 L .52966 .5558 L 0 .025 .123 r
F
.52709 .55653 m .52569 .55514 L .52827 .55438 L F
.44715 .55657 m .44822 .55445 L .44968 .55586 L 0 .025 .124 r
F
.44715 .55657 m .44568 .55514 L .44822 .55445 L F
.37375 .55623 m .37473 .5541 L .37625 .55556 L 0 .024 .123 r
F
.37375 .55623 m .37222 .55478 L .37473 .5541 L F
.41045 .55647 m .41148 .55418 L .41297 .55563 L 0 .025 .123 r
F
.41045 .55647 m .40895 .55504 L .41148 .55418 L F
.49693 .55621 m .49808 .55411 L .4995 .55548 L F
.49693 .55621 m .49551 .55483 L .49808 .55411 L F
.41699 .55627 m .41803 .55402 L .41951 .55547 L 0 .024 .123 r
F
.41699 .55627 m .4155 .55482 L .41803 .55402 L F
.53363 .5565 m .53483 .55433 L .53621 .55578 L 0 .025 .124 r
F
.53363 .5565 m .53224 .55507 L .53483 .55433 L F
.45368 .55658 m .45477 .55446 L .45623 .55588 L 0 .026 .124 r
F
.45368 .55658 m .45223 .55516 L .45477 .55446 L F
.38028 .55626 m .38126 .55412 L .38279 .55553 L 0 .025 .123 r
F
.38028 .55626 m .37876 .55486 L .38126 .55412 L F
.42353 .55611 m .42457 .55392 L .42605 .55537 L 0 .024 .123 r
F
.42353 .55611 m .42204 .55468 L .42457 .55392 L F
.50348 .55614 m .50463 .55403 L .50604 .55543 L 0 .025 .123 r
F
.50348 .55614 m .50206 .55475 L .50463 .55403 L F
.43006 .55603 m .43112 .55382 L .4326 .55524 L F
.43006 .55603 m .42859 .55462 L .43112 .55382 L F
.38681 .55621 m .38781 .55404 L .38932 .55544 L 0 .025 .124 r
F
.38681 .55621 m .3853 .5548 L .38781 .55404 L F
.46022 .55658 m .46132 .55427 L .46277 .55575 L 0 .026 .124 r
F
.46022 .55658 m .45877 .55508 L .46132 .55427 L F
.51002 .55621 m .51118 .55388 L .51259 .55539 L 0 .025 .124 r
F
.51002 .55621 m .50861 .5547 L .51118 .55388 L F
.43661 .55586 m .43767 .55362 L .43914 .55506 L 0 .024 .123 r
F
.43661 .55586 m .43513 .55443 L .43767 .55362 L F
.46677 .55641 m .46787 .5542 L .46932 .55565 L 0 .026 .124 r
F
.46677 .55641 m .46532 .55494 L .46787 .5542 L F
.39335 .55608 m .39436 .55389 L .39587 .55529 L 0 .025 .123 r
F
.39335 .55608 m .39184 .55466 L .39436 .55389 L F
.51657 .55606 m .51774 .55377 L .51914 .55526 L F
.51657 .55606 m .51516 .55457 L .51774 .55377 L F
.47331 .55629 m .47442 .5541 L .47586 .55549 L 0 .026 .124 r
F
.47331 .55629 m .47187 .5549 L .47442 .5541 L F
.39989 .55601 m .4009 .55388 L .4024 .55528 L 0 .025 .124 r
F
.39989 .55601 m .39838 .55459 L .4009 .55388 L F
.36972 .55546 m .3707 .55332 L .37222 .55478 L 0 .024 .122 r
F
.36972 .55546 m .36819 .55402 L .3707 .55332 L F
.44315 .55583 m .44422 .5537 L .44568 .55514 L 0 .025 .123 r
F
.44315 .55583 m .44168 .55438 L .44422 .5537 L F
.47986 .55604 m .48098 .55386 L .48241 .55525 L 0 .025 .124 r
F
.47986 .55604 m .47842 .55468 L .48098 .55386 L F
.52312 .55592 m .5243 .55371 L .52569 .55514 L F
.52312 .55592 m .52172 .55449 L .5243 .55371 L F
.4864 .5558 m .48753 .55355 L .48896 .55496 L 0 .025 .123 r
F
.4864 .5558 m .48497 .5544 L .48753 .55355 L F
.40643 .55589 m .40745 .55364 L .40895 .55504 L 0 .025 .124 r
F
.40643 .55589 m .40493 .55449 L .40745 .55364 L F
.49295 .55555 m .49409 .55345 L .49551 .55483 L 0 .025 .123 r
F
.49295 .55555 m .49153 .55416 L .49409 .55345 L F
.52966 .5558 m .53085 .55364 L .53224 .55507 L 0 .025 .124 r
F
.52966 .5558 m .52827 .55438 L .53085 .55364 L F
.41297 .55563 m .41401 .55338 L .4155 .55482 L 0 .025 .123 r
F
.41297 .55563 m .41148 .55418 L .41401 .55338 L F
.44968 .55586 m .45076 .55375 L .45223 .55516 L 0 .025 .124 r
F
.44968 .55586 m .44822 .55445 L .45076 .55375 L F
.37625 .55556 m .37723 .55339 L .37876 .55486 L 0 .025 .123 r
F
.37625 .55556 m .37473 .5541 L .37723 .55339 L F
.41951 .55547 m .42056 .55323 L .42204 .55468 L 0 .024 .123 r
F
.41951 .55547 m .41803 .55402 L .42056 .55323 L F
.4995 .55548 m .50064 .55339 L .50206 .55475 L 0 .025 .123 r
F
.4995 .55548 m .49808 .55411 L .50064 .55339 L F
.53621 .55578 m .53741 .55353 L .5388 .555 L 0 .025 .124 r
F
.53621 .55578 m .53483 .55433 L .53741 .55353 L F
.45623 .55588 m .45732 .55368 L .45877 .55508 L 0 .026 .124 r
F
.45623 .55588 m .45477 .55446 L .45732 .55368 L F
.38279 .55553 m .38378 .55338 L .3853 .5548 L 0 .025 .124 r
F
.38279 .55553 m .38126 .55412 L .38378 .55338 L F
.42605 .55537 m .4271 .55317 L .42859 .55462 L 0 .025 .123 r
F
.42605 .55537 m .42457 .55392 L .4271 .55317 L F
.50604 .55543 m .5072 .55329 L .50861 .5547 L F
.50604 .55543 m .50463 .55403 L .5072 .55329 L F
.46277 .55575 m .46387 .55347 L .46532 .55494 L 0 .025 .124 r
F
.46277 .55575 m .46132 .55427 L .46387 .55347 L F
.4326 .55524 m .43366 .553 L .43513 .55443 L 0 .024 .123 r
F
.4326 .55524 m .43112 .55382 L .43366 .553 L F
.38932 .55544 m .39032 .55327 L .39184 .55466 L 0 .025 .124 r
F
.38932 .55544 m .38781 .55404 L .39032 .55327 L F
.51259 .55539 m .51376 .55307 L .51516 .55457 L 0 .025 .123 r
F
.51259 .55539 m .51118 .55388 L .51376 .55307 L F
.43914 .55506 m .44021 .55293 L .44168 .55438 L 0 .024 .123 r
F
.43914 .55506 m .43767 .55362 L .44021 .55293 L F
.46932 .55565 m .47042 .55345 L .47187 .5549 L 0 .026 .124 r
F
.46932 .55565 m .46787 .5542 L .47042 .55345 L F
.39587 .55529 m .39687 .55319 L .39838 .55459 L 0 .025 .124 r
F
.39587 .55529 m .39436 .55389 L .39687 .55319 L F
.51914 .55526 m .52032 .55301 L .52172 .55449 L 0 .025 .123 r
F
.51914 .55526 m .51774 .55377 L .52032 .55301 L F
.47586 .55549 m .47698 .55327 L .47842 .55468 L 0 .026 .124 r
F
.47586 .55549 m .47442 .5541 L .47698 .55327 L F
.48241 .55525 m .48354 .55301 L .48497 .5544 L 0 .025 .124 r
F
.48241 .55525 m .48098 .55386 L .48354 .55301 L F
.4024 .55528 m .40342 .5531 L .40493 .55449 L F
.4024 .55528 m .4009 .55388 L .40342 .5531 L F
.52569 .55514 m .52688 .55295 L .52827 .55438 L F
.52569 .55514 m .5243 .55371 L .52688 .55295 L F
.48896 .55496 m .4901 .55275 L .49153 .55416 L 0 .025 .123 r
F
.48896 .55496 m .48753 .55355 L .4901 .55275 L F
.44568 .55514 m .44676 .55301 L .44822 .55445 L 0 .025 .124 r
F
.44568 .55514 m .44422 .5537 L .44676 .55301 L F
.37222 .55478 m .3732 .55263 L .37473 .5541 L 0 .024 .123 r
F
.37222 .55478 m .3707 .55332 L .3732 .55263 L F
.40895 .55504 m .40998 .55279 L .41148 .55418 L 0 .025 .123 r
F
.40895 .55504 m .40745 .55364 L .40998 .55279 L F
.4155 .55482 m .41653 .55257 L .41803 .55402 L 0 .024 .123 r
F
.4155 .55482 m .41401 .55338 L .41653 .55257 L F
.49551 .55483 m .49665 .55274 L .49808 .55411 L 0 .025 .123 r
F
.49551 .55483 m .49409 .55345 L .49665 .55274 L F
.53224 .55507 m .53344 .55287 L .53483 .55433 L 0 .025 .124 r
F
.53224 .55507 m .53085 .55364 L .53344 .55287 L F
.45223 .55516 m .45331 .55305 L .45477 .55446 L 0 .026 .124 r
F
.45223 .55516 m .45076 .55375 L .45331 .55305 L F
.37876 .55486 m .37974 .55264 L .38126 .55412 L 0 .025 .123 r
F
.37876 .55486 m .37723 .55339 L .37974 .55264 L F
.42204 .55468 m .42309 .55245 L .42457 .55392 L 0 .024 .123 r
F
.42204 .55468 m .42056 .55323 L .42309 .55245 L F
.50206 .55475 m .50321 .55266 L .50463 .55403 L 0 .025 .123 r
F
.50206 .55475 m .50064 .55339 L .50321 .55266 L F
.5388 .555 m .54 .55274 L .54138 .55423 L 0 .025 .124 r
F
.5388 .555 m .53741 .55353 L .54 .55274 L F
.45877 .55508 m .45987 .55287 L .46132 .55427 L 0 .026 .124 r
F
.45877 .55508 m .45732 .55368 L .45987 .55287 L F
.3853 .5548 m .38629 .55263 L .38781 .55404 L 0 .025 .124 r
F
.3853 .5548 m .38378 .55338 L .38629 .55263 L F
.42859 .55462 m .42964 .55236 L .43112 .55382 L 0 .025 .123 r
F
.42859 .55462 m .4271 .55317 L .42964 .55236 L F
.50861 .5547 m .50977 .55248 L .51118 .55388 L F
.50861 .5547 m .5072 .55329 L .50977 .55248 L F
.46532 .55494 m .46642 .55274 L .46787 .5542 L 0 .025 .124 r
F
.46532 .55494 m .46387 .55347 L .46642 .55274 L F
.43513 .55443 m .4362 .55218 L .43767 .55362 L 0 .024 .123 r
F
.43513 .55443 m .43366 .553 L .4362 .55218 L F
.39184 .55466 m .39284 .55252 L .39436 .55389 L 0 .025 .124 r
F
.39184 .55466 m .39032 .55327 L .39284 .55252 L F
.51516 .55457 m .51633 .55229 L .51774 .55377 L 0 .025 .123 r
F
.51516 .55457 m .51376 .55307 L .51633 .55229 L F
.47187 .5549 m .47298 .55266 L .47442 .5541 L 0 .026 .125 r
F
.47187 .5549 m .47042 .55345 L .47298 .55266 L F
.36819 .55402 m .36916 .55185 L .3707 .55332 L 0 .024 .122 r
F
.36819 .55402 m .36666 .55256 L .36916 .55185 L F
.44168 .55438 m .44275 .55225 L .44422 .5537 L 0 .025 .123 r
F
.44168 .55438 m .44021 .55293 L .44275 .55225 L F
.39838 .55459 m .39939 .55249 L .4009 .55388 L 0 .025 .124 r
F
.39838 .55459 m .39687 .55319 L .39939 .55249 L F
.52172 .55449 m .5229 .55225 L .5243 .55371 L F
.52172 .55449 m .52032 .55301 L .5229 .55225 L F
.47842 .55468 m .47954 .55245 L .48098 .55386 L F
.47842 .55468 m .47698 .55327 L .47954 .55245 L F
.48497 .5544 m .4861 .55215 L .48753 .55355 L 0 .025 .123 r
F
.48497 .5544 m .48354 .55301 L .4861 .55215 L F
.40493 .55449 m .40595 .55225 L .40745 .55364 L 0 .025 .124 r
F
.40493 .55449 m .40342 .5531 L .40595 .55225 L F
.49153 .55416 m .49266 .55203 L .49409 .55345 L 0 .025 .123 r
F
.49153 .55416 m .4901 .55275 L .49266 .55203 L F
.41148 .55418 m .41251 .552 L .41401 .55338 L F
.41148 .55418 m .40998 .55279 L .41251 .552 L F
.52827 .55438 m .52946 .55218 L .53085 .55364 L 0 .025 .124 r
F
.52827 .55438 m .52688 .55295 L .52946 .55218 L F
.44822 .55445 m .4493 .55231 L .45076 .55375 L F
.44822 .55445 m .44676 .55301 L .4493 .55231 L F
.37473 .5541 m .37571 .55191 L .37723 .55339 L 0 .025 .123 r
F
.37473 .5541 m .3732 .55263 L .37571 .55191 L F
.41803 .55402 m .41907 .55177 L .42056 .55323 L 0 .024 .123 r
F
.41803 .55402 m .41653 .55257 L .41907 .55177 L F
.49808 .55411 m .49922 .55201 L .50064 .55339 L 0 .025 .123 r
F
.49808 .55411 m .49665 .55274 L .49922 .55201 L F
.53483 .55433 m .53602 .55206 L .53741 .55353 L 0 .025 .124 r
F
.53483 .55433 m .53344 .55287 L .53602 .55206 L F
.45477 .55446 m .45586 .55227 L .45732 .55368 L 0 .026 .125 r
F
.45477 .55446 m .45331 .55305 L .45586 .55227 L F
.42457 .55392 m .42562 .55168 L .4271 .55317 L 0 .024 .123 r
F
.42457 .55392 m .42309 .55245 L .42562 .55168 L F
.38126 .55412 m .38226 .55189 L .38378 .55338 L 0 .025 .124 r
F
.38126 .55412 m .37974 .55264 L .38226 .55189 L F
.50463 .55403 m .50579 .55192 L .5072 .55329 L F
.50463 .55403 m .50321 .55266 L .50579 .55192 L F
.54138 .55423 m .54259 .55199 L .54397 .55348 L F
.54138 .55423 m .54 .55274 L .54259 .55199 L F
.46132 .55427 m .46242 .55208 L .46387 .55347 L F
.46132 .55427 m .45987 .55287 L .46242 .55208 L F
.43112 .55382 m .43218 .55153 L .43366 .553 L 0 .024 .123 r
F
.43112 .55382 m .42964 .55236 L .43218 .55153 L F
.38781 .55404 m .38881 .55189 L .39032 .55327 L 0 .025 .124 r
F
.38781 .55404 m .38629 .55263 L .38881 .55189 L F
.51118 .55388 m .51235 .55167 L .51376 .55307 L 0 .025 .123 r
F
.51118 .55388 m .50977 .55248 L .51235 .55167 L F
.43767 .55362 m .43874 .55148 L .44021 .55293 L 0 .024 .123 r
F
.43767 .55362 m .4362 .55218 L .43874 .55148 L F
.46787 .5542 m .46898 .55201 L .47042 .55345 L 0 .026 .124 r
F
.46787 .5542 m .46642 .55274 L .46898 .55201 L F
.39436 .55389 m .39536 .55182 L .39687 .55319 L 0 .025 .124 r
F
.39436 .55389 m .39284 .55252 L .39536 .55182 L F
.51774 .55377 m .51891 .55154 L .52032 .55301 L 0 .025 .123 r
F
.51774 .55377 m .51633 .55229 L .51891 .55154 L F
.47442 .5541 m .47554 .55184 L .47698 .55327 L 0 .026 .124 r
F
.47442 .5541 m .47298 .55266 L .47554 .55184 L F
.48098 .55386 m .4821 .55159 L .48354 .55301 L 0 .025 .124 r
F
.48098 .55386 m .47954 .55245 L .4821 .55159 L F
.3707 .55332 m .37167 .55115 L .3732 .55263 L 0 .024 .123 r
F
.3707 .55332 m .36916 .55185 L .37167 .55115 L F
.4009 .55388 m .40191 .55171 L .40342 .5531 L 0 .025 .124 r
F
.4009 .55388 m .39939 .55249 L .40191 .55171 L F
.44422 .5537 m .44529 .55154 L .44676 .55301 L F
.44422 .5537 m .44275 .55225 L .44529 .55154 L F
.5243 .55371 m .52548 .55148 L .52688 .55295 L F
.5243 .55371 m .5229 .55225 L .52548 .55148 L F
.48753 .55355 m .48867 .55133 L .4901 .55275 L 0 .025 .123 r
F
.48753 .55355 m .4861 .55215 L .48867 .55133 L F
.40745 .55364 m .40848 .5514 L .40998 .55279 L 0 .025 .124 r
F
.40745 .55364 m .40595 .55225 L .40848 .5514 L F
.41401 .55338 m .41504 .55121 L .41653 .55257 L 0 .025 .123 r
F
.41401 .55338 m .41251 .552 L .41504 .55121 L F
.49409 .55345 m .49523 .55131 L .49665 .55274 L F
.49409 .55345 m .49266 .55203 L .49523 .55131 L F
.53085 .55364 m .53205 .5514 L .53344 .55287 L 0 .025 .124 r
F
.53085 .55364 m .52946 .55218 L .53205 .5514 L F
.45076 .55375 m .45185 .5516 L .45331 .55305 L 0 .026 .124 r
F
.45076 .55375 m .4493 .55231 L .45185 .5516 L F
.37723 .55339 m .37822 .55115 L .37974 .55264 L 0 .025 .123 r
F
.37723 .55339 m .37571 .55191 L .37822 .55115 L F
.42056 .55323 m .4216 .55099 L .42309 .55245 L 0 .024 .123 r
F
.42056 .55323 m .41907 .55177 L .4216 .55099 L F
.53741 .55353 m .53861 .55125 L .54 .55274 L 0 .025 .124 r
F
.53741 .55353 m .53602 .55206 L .53861 .55125 L F
.50064 .55339 m .50179 .55127 L .50321 .55266 L F
.50064 .55339 m .49922 .55201 L .50179 .55127 L F
.45732 .55368 m .45841 .55148 L .45987 .55287 L 0 .026 .125 r
F
.45732 .55368 m .45586 .55227 L .45841 .55148 L F
.4271 .55317 m .42816 .55087 L .42964 .55236 L 0 .024 .123 r
F
.4271 .55317 m .42562 .55168 L .42816 .55087 L F
.38378 .55338 m .38477 .55115 L .38629 .55263 L 0 .025 .124 r
F
.38378 .55338 m .38226 .55189 L .38477 .55115 L F
.46387 .55347 m .46497 .55137 L .46642 .55274 L 0 .026 .124 r
F
.46387 .55347 m .46242 .55208 L .46497 .55137 L F
.5072 .55329 m .50836 .55111 L .50977 .55248 L 0 .025 .124 r
F
.5072 .55329 m .50579 .55192 L .50836 .55111 L F
.54397 .55348 m .54518 .55127 L .54656 .55276 L F
.54397 .55348 m .54259 .55199 L .54518 .55127 L F
.43366 .553 m .43472 .5507 L .4362 .55218 L 0 .024 .123 r
F
.43366 .553 m .43218 .55153 L .43472 .5507 L F
.51376 .55307 m .51493 .55089 L .51633 .55229 L 0 .025 .123 r
F
.51376 .55307 m .51235 .55167 L .51493 .55089 L F
.39032 .55327 m .39132 .55114 L .39284 .55252 L 0 .025 .124 r
F
.39032 .55327 m .38881 .55189 L .39132 .55114 L F
.47042 .55345 m .47154 .55122 L .47298 .55266 L 0 .026 .125 r
F
.47042 .55345 m .46898 .55201 L .47154 .55122 L F
.36666 .55256 m .36763 .55036 L .36916 .55185 L 0 .024 .122 r
F
.36666 .55256 m .36513 .55106 L .36763 .55036 L F
.44021 .55293 m .44128 .55079 L .44275 .55225 L 0 .025 .123 r
F
.44021 .55293 m .43874 .55148 L .44128 .55079 L F
.39687 .55319 m .39788 .55112 L .39939 .55249 L 0 .025 .124 r
F
.39687 .55319 m .39536 .55182 L .39788 .55112 L F
.52032 .55301 m .5215 .55078 L .5229 .55225 L 0 .025 .123 r
F
.52032 .55301 m .51891 .55154 L .5215 .55078 L F
.47698 .55327 m .4781 .55101 L .47954 .55245 L 0 .025 .124 r
F
.47698 .55327 m .47554 .55184 L .4781 .55101 L F
.48354 .55301 m .48467 .55073 L .4861 .55215 L F
.48354 .55301 m .4821 .55159 L .48467 .55073 L F
.40342 .5531 m .40444 .55087 L .40595 .55225 L F
.40342 .5531 m .40191 .55171 L .40444 .55087 L F
.4901 .55275 m .49124 .5506 L .49266 .55203 L 0 .025 .123 r
F
.4901 .55275 m .48867 .55133 L .49124 .5506 L F
.52688 .55295 m .52806 .55071 L .52946 .55218 L 0 .025 .124 r
F
.52688 .55295 m .52548 .55148 L .52806 .55071 L F
.40998 .55279 m .41101 .55062 L .41251 .552 L 0 .025 .123 r
F
.40998 .55279 m .40848 .5514 L .41101 .55062 L F
.3732 .55263 m .37418 .55042 L .37571 .55191 L 0 .024 .123 r
F
.3732 .55263 m .37167 .55115 L .37418 .55042 L F
.44676 .55301 m .44784 .55081 L .4493 .55231 L 0 .025 .124 r
F
.44676 .55301 m .44529 .55154 L .44784 .55081 L F
.41653 .55257 m .41757 .55042 L .41907 .55177 L 0 .025 .123 r
F
.41653 .55257 m .41504 .55121 L .41757 .55042 L F
.53344 .55287 m .53463 .55058 L .53602 .55206 L 0 .025 .124 r
F
.53344 .55287 m .53205 .5514 L .53463 .55058 L F
.49665 .55274 m .4978 .55056 L .49922 .55201 L F
.49665 .55274 m .49523 .55131 L .4978 .55056 L F
.42309 .55245 m .42414 .5502 L .42562 .55168 L 0 .024 .123 r
F
.42309 .55245 m .4216 .55099 L .42414 .5502 L F
.37974 .55264 m .38074 .55039 L .38226 .55189 L 0 .025 .123 r
F
.37974 .55264 m .37822 .55115 L .38074 .55039 L F
.45331 .55305 m .4544 .55084 L .45586 .55227 L 0 .026 .125 r
F
.45331 .55305 m .45185 .5516 L .4544 .55084 L F
.54 .55274 m .5412 .5505 L .54259 .55199 L 0 .025 .124 r
F
.54 .55274 m .53861 .55125 L .5412 .5505 L F
.50321 .55266 m .50437 .55052 L .50579 .55192 L F
.50321 .55266 m .50179 .55127 L .50437 .55052 L F
.45987 .55287 m .46096 .55071 L .46242 .55208 L 0 .026 .125 r
F
.45987 .55287 m .45841 .55148 L .46096 .55071 L F
.42964 .55236 m .4307 .55004 L .43218 .55153 L 0 .024 .123 r
F
.42964 .55236 m .42816 .55087 L .4307 .55004 L F
.38629 .55263 m .38729 .5504 L .38881 .55189 L 0 .025 .124 r
F
.38629 .55263 m .38477 .55115 L .38729 .5504 L F
.50977 .55248 m .51094 .5503 L .51235 .55167 L F
.50977 .55248 m .50836 .55111 L .51094 .5503 L F
.4362 .55218 m .43726 .55 L .43874 .55148 L 0 .024 .123 r
F
.4362 .55218 m .43472 .5507 L .43726 .55 L F
.46642 .55274 m .46753 .55066 L .46898 .55201 L 0 .026 .125 r
F
.46642 .55274 m .46497 .55137 L .46753 .55066 L F
.54656 .55276 m .54778 .55055 L .54916 .55203 L 0 .026 .124 r
F
.54656 .55276 m .54518 .55127 L .54778 .55055 L F
.51633 .55229 m .51751 .55015 L .51891 .55154 L 0 .025 .123 r
F
.51633 .55229 m .51493 .55089 L .51751 .55015 L F
.39284 .55252 m .39384 .55045 L .39536 .55182 L 0 .025 .124 r
F
.39284 .55252 m .39132 .55114 L .39384 .55045 L F
.47298 .55266 m .4741 .55039 L .47554 .55184 L 0 .026 .124 r
F
.47298 .55266 m .47154 .55122 L .4741 .55039 L F
.36916 .55185 m .37014 .54965 L .37167 .55115 L 0 .024 .122 r
F
.36916 .55185 m .36763 .55036 L .37014 .54965 L F
.44275 .55225 m .44382 .55007 L .44529 .55154 L 0 .025 .124 r
F
.44275 .55225 m .44128 .55079 L .44382 .55007 L F
.5229 .55225 m .52408 .55001 L .52548 .55148 L 0 .025 .123 r
F
.5229 .55225 m .5215 .55078 L .52408 .55001 L F
.47954 .55245 m .48067 .55016 L .4821 .55159 L 0 .025 .124 r
F
.47954 .55245 m .4781 .55101 L .48067 .55016 L F
.39939 .55249 m .4004 .55035 L .40191 .55171 L 0 .026 .124 r
F
.39939 .55249 m .39788 .55112 L .4004 .55035 L F
.4861 .55215 m .48724 .54992 L .48867 .55133 L 0 .025 .123 r
F
.4861 .55215 m .48467 .55073 L .48724 .54992 L F
.40595 .55225 m .40698 .55002 L .40848 .5514 L 0 .025 .124 r
F
.40595 .55225 m .40444 .55087 L .40698 .55002 L F
.41251 .552 m .41354 .54985 L .41504 .55121 L 0 .025 .123 r
F
.41251 .552 m .41101 .55062 L .41354 .54985 L F
.52946 .55218 m .53065 .54992 L .53205 .5514 L 0 .025 .124 r
F
.52946 .55218 m .52806 .55071 L .53065 .54992 L F
.49266 .55203 m .4938 .54988 L .49523 .55131 L 0 .025 .123 r
F
.49266 .55203 m .49124 .5506 L .4938 .54988 L F
.37571 .55191 m .37669 .54965 L .37822 .55115 L F
.37571 .55191 m .37418 .55042 L .37669 .54965 L F
.4493 .55231 m .45039 .55009 L .45185 .5516 L 0 .026 .124 r
F
.4493 .55231 m .44784 .55081 L .45039 .55009 L F
.41907 .55177 m .42011 .54963 L .4216 .55099 L 0 .024 .123 r
F
.41907 .55177 m .41757 .55042 L .42011 .54963 L F
.53602 .55206 m .53722 .54976 L .53861 .55125 L 0 .025 .124 r
F
.53602 .55206 m .53463 .55058 L .53722 .54976 L F
.49922 .55201 m .50037 .5498 L .50179 .55127 L F
.49922 .55201 m .4978 .55056 L .50037 .5498 L F
.42562 .55168 m .42668 .54938 L .42816 .55087 L 0 .024 .123 r
F
.42562 .55168 m .42414 .5502 L .42668 .54938 L F
.38226 .55189 m .38325 .54964 L .38477 .55115 L 0 .025 .123 r
F
.38226 .55189 m .38074 .55039 L .38325 .54964 L F
.45586 .55227 m .45695 .55006 L .45841 .55148 L 0 .026 .125 r
F
.45586 .55227 m .4544 .55084 L .45695 .55006 L F
.54259 .55199 m .5438 .54978 L .54518 .55127 L 0 .025 .124 r
F
.54259 .55199 m .5412 .5505 L .5438 .54978 L F
.43218 .55153 m .43324 .54921 L .43472 .5507 L 0 .024 .123 r
F
.43218 .55153 m .4307 .55004 L .43324 .54921 L F
.46242 .55208 m .46352 .55001 L .46497 .55137 L 0 .026 .125 r
F
.46242 .55208 m .46096 .55071 L .46352 .55001 L F
.50579 .55192 m .50695 .54972 L .50836 .55111 L 0 .025 .124 r
F
.50579 .55192 m .50437 .55052 L .50695 .54972 L F
.51235 .55167 m .51352 .54953 L .51493 .55089 L F
.51235 .55167 m .51094 .5503 L .51352 .54953 L F
.38881 .55189 m .38981 .54966 L .39132 .55114 L F
.38881 .55189 m .38729 .5504 L .38981 .54966 L F
.36513 .55106 m .3661 .54886 L .36763 .55036 L 0 .024 .122 r
F
.36513 .55106 m .36359 .54956 L .3661 .54886 L F
.46898 .55201 m .47009 .54988 L .47154 .55122 L 0 .026 .125 r
F
.46898 .55201 m .46753 .55066 L .47009 .54988 L F
.43874 .55148 m .43981 .5493 L .44128 .55079 L 0 .025 .123 r
F
.43874 .55148 m .43726 .55 L .43981 .5493 L F
.54916 .55203 m .55037 .54986 L .55175 .55135 L 0 .026 .125 r
F
.54916 .55203 m .54778 .55055 L .55037 .54986 L F
.51891 .55154 m .52009 .54941 L .5215 .55078 L 0 .025 .123 r
F
.51891 .55154 m .51751 .55015 L .52009 .54941 L F
.39536 .55182 m .39637 .54975 L .39788 .55112 L 0 .026 .125 r
F
.39536 .55182 m .39384 .55045 L .39637 .54975 L F
.47554 .55184 m .47666 .54957 L .4781 .55101 L 0 .025 .124 r
F
.47554 .55184 m .4741 .55039 L .47666 .54957 L F
.4821 .55159 m .48323 .54931 L .48467 .55073 L F
.4821 .55159 m .48067 .55016 L .48323 .54931 L F
.52548 .55148 m .52667 .54922 L .52806 .55071 L 0 .025 .123 r
F
.52548 .55148 m .52408 .55001 L .52667 .54922 L F
.48867 .55133 m .4898 .54919 L .49124 .5506 L F
.48867 .55133 m .48724 .54992 L .4898 .54919 L F
.37167 .55115 m .37265 .54892 L .37418 .55042 L 0 .024 .123 r
F
.37167 .55115 m .37014 .54965 L .37265 .54892 L F
.40191 .55171 m .40294 .54949 L .40444 .55087 L 0 .026 .124 r
F
.40191 .55171 m .4004 .55035 L .40294 .54949 L F
.44529 .55154 m .44637 .54932 L .44784 .55081 L 0 .025 .124 r
F
.44529 .55154 m .44382 .55007 L .44637 .54932 L F
.40848 .5514 m .40951 .54925 L .41101 .55062 L F
.40848 .5514 m .40698 .55002 L .40951 .54925 L F
.41504 .55121 m .41607 .54907 L .41757 .55042 L 0 .025 .123 r
F
.41504 .55121 m .41354 .54985 L .41607 .54907 L F
.53205 .5514 m .53324 .5491 L .53463 .55058 L 0 .025 .124 r
F
.53205 .5514 m .53065 .54992 L .53324 .5491 L F
.49523 .55131 m .49638 .54911 L .4978 .55056 L F
.49523 .55131 m .4938 .54988 L .49638 .54911 L F
.37822 .55115 m .37921 .54888 L .38074 .55039 L 0 .025 .123 r
F
.37822 .55115 m .37669 .54965 L .37921 .54888 L F
.4216 .55099 m .42265 .54884 L .42414 .5502 L 0 .024 .123 r
F
.4216 .55099 m .42011 .54963 L .42265 .54884 L F
.45185 .5516 m .45294 .54932 L .4544 .55084 L 0 .026 .125 r
F
.45185 .5516 m .45039 .55009 L .45294 .54932 L F
.53861 .55125 m .53982 .54901 L .5412 .5505 L 0 .025 .124 r
F
.53861 .55125 m .53722 .54976 L .53982 .54901 L F
.42816 .55087 m .42922 .54855 L .4307 .55004 L 0 .024 .123 r
F
.42816 .55087 m .42668 .54938 L .42922 .54855 L F
.50179 .55127 m .50295 .54903 L .50437 .55052 L 0 .025 .124 r
F
.50179 .55127 m .50037 .5498 L .50295 .54903 L F
.45841 .55148 m .45951 .54929 L .46096 .55071 L 0 .026 .125 r
F
.45841 .55148 m .45695 .55006 L .45951 .54929 L F
.38477 .55115 m .38577 .54889 L .38729 .5504 L 0 .025 .124 r
F
.38477 .55115 m .38325 .54964 L .38577 .54889 L F
.43472 .5507 m .43579 .54851 L .43726 .55 L 0 .024 .123 r
F
.43472 .5507 m .43324 .54921 L .43579 .54851 L F
.54518 .55127 m .54639 .54907 L .54778 .55055 L 0 .026 .124 r
F
.54518 .55127 m .5438 .54978 L .54639 .54907 L F
.50836 .55111 m .50952 .54891 L .51094 .5503 L 0 .025 .124 r
F
.50836 .55111 m .50695 .54972 L .50952 .54891 L F
.46497 .55137 m .46607 .54932 L .46753 .55066 L 0 .026 .125 r
F
.46497 .55137 m .46352 .55001 L .46607 .54932 L F
.51493 .55089 m .5161 .5488 L .51751 .55015 L 0 .025 .124 r
F
.51493 .55089 m .51352 .54953 L .5161 .5488 L F
.39132 .55114 m .39233 .54896 L .39384 .55045 L 0 .026 .124 r
F
.39132 .55114 m .38981 .54966 L .39233 .54896 L F
.47154 .55122 m .47265 .54904 L .4741 .55039 L 0 .026 .125 r
F
.47154 .55122 m .47009 .54988 L .47265 .54904 L F
.36763 .55036 m .36861 .54815 L .37014 .54965 L 0 .024 .122 r
F
.36763 .55036 m .3661 .54886 L .36861 .54815 L F
.5215 .55078 m .52268 .54862 L .52408 .55001 L 0 .025 .124 r
F
.5215 .55078 m .52009 .54941 L .52268 .54862 L F
.44128 .55079 m .44235 .54857 L .44382 .55007 L 0 .025 .123 r
F
.44128 .55079 m .43981 .5493 L .44235 .54857 L F
.55175 .55135 m .55297 .54918 L .55435 .55068 L 0 .026 .125 r
F
.55175 .55135 m .55037 .54986 L .55297 .54918 L F
.4781 .55101 m .47923 .54873 L .48067 .55016 L 0 .025 .124 r
F
.4781 .55101 m .47666 .54957 L .47923 .54873 L F
.48467 .55073 m .4858 .5485 L .48724 .54992 L 0 .025 .123 r
F
.48467 .55073 m .48323 .54931 L .4858 .5485 L F
.39788 .55112 m .39889 .54897 L .4004 .55035 L 0 .026 .125 r
F
.39788 .55112 m .39637 .54975 L .39889 .54897 L F
.40444 .55087 m .40547 .54864 L .40698 .55002 L 0 .025 .124 r
F
.40444 .55087 m .40294 .54949 L .40547 .54864 L F
.52806 .55071 m .52925 .54843 L .53065 .54992 L F
.52806 .55071 m .52667 .54922 L .52925 .54843 L F
.37418 .55042 m .37517 .54815 L .37669 .54965 L 0 .024 .123 r
F
.37418 .55042 m .37265 .54892 L .37517 .54815 L F
.49124 .5506 m .49238 .54845 L .4938 .54988 L 0 .025 .124 r
F
.49124 .5506 m .4898 .54919 L .49238 .54845 L F
.41101 .55062 m .41204 .54849 L .41354 .54985 L F
.41101 .55062 m .40951 .54925 L .41204 .54849 L F
.44784 .55081 m .44892 .54857 L .45039 .55009 L F
.44784 .55081 m .44637 .54932 L .44892 .54857 L F
.53463 .55058 m .53583 .54828 L .53722 .54976 L 0 .025 .123 r
F
.53463 .55058 m .53324 .5491 L .53583 .54828 L F
.41757 .55042 m .41861 .54827 L .42011 .54963 L F
.41757 .55042 m .41607 .54907 L .41861 .54827 L F
.4978 .55056 m .49895 .54832 L .50037 .5498 L 0 .025 .124 r
F
.4978 .55056 m .49638 .54911 L .49895 .54832 L F
.42414 .5502 m .42519 .54801 L .42668 .54938 L 0 .024 .123 r
F
.42414 .5502 m .42265 .54884 L .42519 .54801 L F
.38074 .55039 m .38173 .54813 L .38325 .54964 L 0 .025 .123 r
F
.38074 .55039 m .37921 .54888 L .38173 .54813 L F
.4544 .55084 m .45549 .54855 L .45695 .55006 L 0 .026 .125 r
F
.4544 .55084 m .45294 .54932 L .45549 .54855 L F
.5412 .5505 m .54241 .5483 L .5438 .54978 L 0 .025 .124 r
F
.5412 .5505 m .53982 .54901 L .54241 .5483 L F
.4307 .55004 m .43176 .54772 L .43324 .54921 L 0 .024 .122 r
F
.4307 .55004 m .42922 .54855 L .43176 .54772 L F
.50437 .55052 m .50553 .54823 L .50695 .54972 L 0 .025 .124 r
F
.50437 .55052 m .50295 .54903 L .50553 .54823 L F
.46096 .55071 m .46206 .54861 L .46352 .55001 L 0 .026 .125 r
F
.46096 .55071 m .45951 .54929 L .46206 .54861 L F
.38729 .5504 m .38829 .54815 L .38981 .54966 L 0 .025 .124 r
F
.38729 .5504 m .38577 .54889 L .38829 .54815 L F
.36359 .54956 m .36456 .54742 L .3661 .54886 L 0 .024 .122 r
F
.36359 .54956 m .36205 .54813 L .36456 .54742 L F
.51094 .5503 m .51211 .54814 L .51352 .54953 L 0 .025 .124 r
F
.51094 .5503 m .50952 .54891 L .51211 .54814 L F
.43726 .55 m .43833 .5478 L .43981 .5493 L 0 .025 .123 r
F
.43726 .55 m .43579 .54851 L .43833 .5478 L F
.54778 .55055 m .54899 .54837 L .55037 .54986 L 0 .026 .125 r
F
.54778 .55055 m .54639 .54907 L .54899 .54837 L F
.46753 .55066 m .46864 .54854 L .47009 .54988 L F
.46753 .55066 m .46607 .54932 L .46864 .54854 L F
.51751 .55015 m .51868 .54806 L .52009 .54941 L 0 .025 .124 r
F
.51751 .55015 m .5161 .5488 L .51868 .54806 L F
.4741 .55039 m .47521 .54821 L .47666 .54957 L 0 .026 .124 r
F
.4741 .55039 m .47265 .54904 L .47521 .54821 L F
.39384 .55045 m .39485 .54826 L .39637 .54975 L 0 .026 .125 r
F
.39384 .55045 m .39233 .54896 L .39485 .54826 L F
.48067 .55016 m .48179 .54789 L .48323 .54931 L 0 .025 .124 r
F
.48067 .55016 m .47923 .54873 L .48179 .54789 L F
.52408 .55001 m .52526 .54782 L .52667 .54922 L F
.52408 .55001 m .52268 .54862 L .52526 .54782 L F
.37014 .54965 m .37112 .54742 L .37265 .54892 L 0 .024 .122 r
F
.37014 .54965 m .36861 .54815 L .37112 .54742 L F
.44382 .55007 m .4449 .54781 L .44637 .54932 L 0 .025 .124 r
F
.44382 .55007 m .44235 .54857 L .4449 .54781 L F
.48724 .54992 m .48837 .54777 L .4898 .54919 L 0 .025 .123 r
F
.48724 .54992 m .4858 .5485 L .48837 .54777 L F
.55435 .55068 m .55558 .54843 L .55695 .54993 L 0 .026 .126 r
F
.55435 .55068 m .55297 .54918 L .55558 .54843 L F
.4004 .55035 m .40142 .54812 L .40294 .54949 L 0 .026 .125 r
F
.4004 .55035 m .39889 .54897 L .40142 .54812 L F
.40698 .55002 m .408 .54788 L .40951 .54925 L 0 .025 .124 r
F
.40698 .55002 m .40547 .54864 L .408 .54788 L F
.53065 .54992 m .53184 .54761 L .53324 .5491 L 0 .025 .123 r
F
.53065 .54992 m .52925 .54843 L .53184 .54761 L F
.37669 .54965 m .37768 .54737 L .37921 .54888 L 0 .024 .123 r
F
.37669 .54965 m .37517 .54815 L .37768 .54737 L F
.41354 .54985 m .41457 .54772 L .41607 .54907 L 0 .025 .124 r
F
.41354 .54985 m .41204 .54849 L .41457 .54772 L F
.4938 .54988 m .49495 .54767 L .49638 .54911 L F
.4938 .54988 m .49238 .54845 L .49495 .54767 L F
.45039 .55009 m .45147 .54781 L .45294 .54932 L F
.45039 .55009 m .44892 .54857 L .45147 .54781 L F
.53722 .54976 m .53843 .54753 L .53982 .54901 L 0 .025 .123 r
F
.53722 .54976 m .53583 .54828 L .53843 .54753 L F
.42011 .54963 m .42115 .54747 L .42265 .54884 L F
.42011 .54963 m .41861 .54827 L .42115 .54747 L F
.42668 .54938 m .42773 .54718 L .42922 .54855 L 0 .024 .123 r
F
.42668 .54938 m .42519 .54801 L .42773 .54718 L F
.50037 .5498 m .50153 .54754 L .50295 .54903 L 0 .025 .124 r
F
.50037 .5498 m .49895 .54832 L .50153 .54754 L F
.38325 .54964 m .38425 .54738 L .38577 .54889 L 0 .025 .123 r
F
.38325 .54964 m .38173 .54813 L .38425 .54738 L F
.45695 .55006 m .45805 .54779 L .45951 .54929 L 0 .026 .125 r
F
.45695 .55006 m .45549 .54855 L .45805 .54779 L F
.43324 .54921 m .43431 .54701 L .43579 .54851 L 0 .024 .122 r
F
.43324 .54921 m .43176 .54772 L .43431 .54701 L F
.5438 .54978 m .54501 .54759 L .54639 .54907 L 0 .025 .124 r
F
.5438 .54978 m .54241 .5483 L .54501 .54759 L F
.50695 .54972 m .50811 .54743 L .50952 .54891 L F
.50695 .54972 m .50553 .54823 L .50811 .54743 L F
.46352 .55001 m .46462 .54793 L .46607 .54932 L 0 .026 .125 r
F
.46352 .55001 m .46206 .54861 L .46462 .54793 L F
.38981 .54966 m .39081 .54745 L .39233 .54896 L 0 .025 .124 r
F
.38981 .54966 m .38829 .54815 L .39081 .54745 L F
.51352 .54953 m .51469 .54742 L .5161 .5488 L F
.51352 .54953 m .51211 .54814 L .51469 .54742 L F
.3661 .54886 m .36707 .54671 L .36861 .54815 L 0 .024 .122 r
F
.3661 .54886 m .36456 .54742 L .36707 .54671 L F
.43981 .5493 m .44088 .54707 L .44235 .54857 L 0 .025 .123 r
F
.43981 .5493 m .43833 .5478 L .44088 .54707 L F
.55037 .54986 m .5516 .54767 L .55297 .54918 L 0 .026 .125 r
F
.55037 .54986 m .54899 .54837 L .5516 .54767 L F
.47009 .54988 m .4712 .5477 L .47265 .54904 L F
.47009 .54988 m .46864 .54854 L .4712 .5477 L F
.47666 .54957 m .47778 .54737 L .47923 .54873 L 0 .025 .124 r
F
.47666 .54957 m .47521 .54821 L .47778 .54737 L F
.52009 .54941 m .52127 .54726 L .52268 .54862 L F
.52009 .54941 m .51868 .54806 L .52127 .54726 L F
.48323 .54931 m .48436 .54709 L .4858 .5485 L F
.48323 .54931 m .48179 .54789 L .48436 .54709 L F
.39637 .54975 m .39738 .54749 L .39889 .54897 L 0 .026 .125 r
F
.39637 .54975 m .39485 .54826 L .39738 .54749 L F
.52667 .54922 m .52785 .54702 L .52925 .54843 L 0 .025 .124 r
F
.52667 .54922 m .52526 .54782 L .52785 .54702 L F
.37265 .54892 m .37364 .54664 L .37517 .54815 L 0 .024 .123 r
F
.37265 .54892 m .37112 .54742 L .37364 .54664 L F
.40294 .54949 m .40396 .54727 L .40547 .54864 L 0 .026 .124 r
F
.40294 .54949 m .40142 .54812 L .40396 .54727 L F
.44637 .54932 m .44745 .54705 L .44892 .54857 L 0 .025 .124 r
F
.44637 .54932 m .4449 .54781 L .44745 .54705 L F
.4898 .54919 m .49094 .54704 L .49238 .54845 L F
.4898 .54919 m .48837 .54777 L .49094 .54704 L F
.55695 .54993 m .55818 .54759 L .55955 .54909 L 0 .026 .126 r
F
.55695 .54993 m .55558 .54843 L .55818 .54759 L F
.40951 .54925 m .41053 .54713 L .41204 .54849 L 0 .025 .124 r
F
.40951 .54925 m .408 .54788 L .41053 .54713 L F
.53324 .5491 m .53444 .5468 L .53583 .54828 L 0 .025 .123 r
F
.53324 .5491 m .53184 .54761 L .53444 .5468 L F
.37921 .54888 m .3802 .54663 L .38173 .54813 L F
.37921 .54888 m .37768 .54737 L .3802 .54663 L F
.41607 .54907 m .41711 .5469 L .41861 .54827 L 0 .025 .124 r
F
.41607 .54907 m .41457 .54772 L .41711 .5469 L F
.49638 .54911 m .49753 .54688 L .49895 .54832 L F
.49638 .54911 m .49495 .54767 L .49753 .54688 L F
.45294 .54932 m .45403 .54704 L .45549 .54855 L 0 .026 .124 r
F
.45294 .54932 m .45147 .54781 L .45403 .54704 L F
.53982 .54901 m .54102 .54683 L .54241 .5483 L 0 .025 .124 r
F
.53982 .54901 m .53843 .54753 L .54102 .54683 L F
.42265 .54884 m .42369 .54664 L .42519 .54801 L 0 .025 .123 r
F
.42265 .54884 m .42115 .54747 L .42369 .54664 L F
.42922 .54855 m .43028 .54635 L .43176 .54772 L 0 .024 .122 r
F
.42922 .54855 m .42773 .54718 L .43028 .54635 L F
.50295 .54903 m .50411 .54674 L .50553 .54823 L 0 .025 .124 r
F
.50295 .54903 m .50153 .54754 L .50411 .54674 L F
.38577 .54889 m .38677 .54664 L .38829 .54815 L F
.38577 .54889 m .38425 .54738 L .38677 .54664 L F
.45951 .54929 m .4606 .54711 L .46206 .54861 L 0 .026 .125 r
F
.45951 .54929 m .45805 .54779 L .4606 .54711 L F
.36205 .54813 m .36301 .54603 L .36456 .54742 L 0 .024 .122 r
F
.36205 .54813 m .3605 .54674 L .36301 .54603 L F
.43579 .54851 m .43685 .5463 L .43833 .5478 L 0 .024 .123 r
F
.43579 .54851 m .43431 .54701 L .43685 .5463 L F
.54639 .54907 m .54761 .54688 L .54899 .54837 L 0 .026 .124 r
F
.54639 .54907 m .54501 .54759 L .54761 .54688 L F
.50952 .54891 m .51069 .54667 L .51211 .54814 L 0 .025 .124 r
F
.50952 .54891 m .50811 .54743 L .51069 .54667 L F
.46607 .54932 m .46718 .54715 L .46864 .54854 L 0 .026 .126 r
F
.46607 .54932 m .46462 .54793 L .46718 .54715 L F
.39233 .54896 m .39334 .54674 L .39485 .54826 L 0 .026 .124 r
F
.39233 .54896 m .39081 .54745 L .39334 .54674 L F
.5161 .5488 m .51728 .54669 L .51868 .54806 L 0 .025 .124 r
F
.5161 .5488 m .51469 .54742 L .51728 .54669 L F
.47265 .54904 m .47377 .54685 L .47521 .54821 L 0 .026 .125 r
F
.47265 .54904 m .4712 .5477 L .47377 .54685 L F
.36861 .54815 m .36958 .54598 L .37112 .54742 L 0 .024 .122 r
F
.36861 .54815 m .36707 .54671 L .36958 .54598 L F
.47923 .54873 m .48035 .54654 L .48179 .54789 L 0 .025 .124 r
F
.47923 .54873 m .47778 .54737 L .48035 .54654 L F
.44235 .54857 m .44343 .5463 L .4449 .54781 L 0 .025 .123 r
F
.44235 .54857 m .44088 .54707 L .44343 .5463 L F
.52268 .54862 m .52386 .54644 L .52526 .54782 L 0 .025 .124 r
F
.52268 .54862 m .52127 .54726 L .52386 .54644 L F
.55297 .54918 m .5542 .54692 L .55558 .54843 L 0 .026 .125 r
F
.55297 .54918 m .5516 .54767 L .5542 .54692 L F
.4858 .5485 m .48694 .54636 L .48837 .54777 L 0 .025 .124 r
F
.4858 .5485 m .48436 .54709 L .48694 .54636 L F
.39889 .54897 m .39991 .54664 L .40142 .54812 L 0 .026 .125 r
F
.39889 .54897 m .39738 .54749 L .39991 .54664 L F
.52925 .54843 m .53045 .54619 L .53184 .54761 L 0 .025 .123 r
F
.52925 .54843 m .52785 .54702 L .53045 .54619 L F
.40547 .54864 m .40649 .54651 L .408 .54788 L 0 .026 .124 r
F
.40547 .54864 m .40396 .54727 L .40649 .54651 L F
.37517 .54815 m .37616 .54586 L .37768 .54737 L 0 .024 .123 r
F
.37517 .54815 m .37364 .54664 L .37616 .54586 L F
.55955 .54909 m .56079 .54674 L .56216 .54825 L 0 .026 .125 r
F
.55955 .54909 m .55818 .54759 L .56079 .54674 L F
.44892 .54857 m .45001 .5463 L .45147 .54781 L 0 .025 .124 r
F
.44892 .54857 m .44745 .54705 L .45001 .5463 L F
.49238 .54845 m .49352 .54626 L .49495 .54767 L F
.49238 .54845 m .49094 .54704 L .49352 .54626 L F
.53583 .54828 m .53703 .54605 L .53843 .54753 L 0 .025 .123 r
F
.53583 .54828 m .53444 .5468 L .53703 .54605 L F
.41204 .54849 m .41307 .54635 L .41457 .54772 L 0 .025 .124 r
F
.41204 .54849 m .41053 .54713 L .41307 .54635 L F
.41861 .54827 m .41966 .54608 L .42115 .54747 L F
.41861 .54827 m .41711 .5469 L .41966 .54608 L F
.38173 .54813 m .38272 .5459 L .38425 .54738 L 0 .025 .123 r
F
.38173 .54813 m .3802 .54663 L .38272 .5459 L F
.49895 .54832 m .5001 .54608 L .50153 .54754 L 0 .025 .124 r
F
.49895 .54832 m .49753 .54688 L .5001 .54608 L F
.45549 .54855 m .45659 .54629 L .45805 .54779 L 0 .026 .124 r
F
.45549 .54855 m .45403 .54704 L .45659 .54629 L F
.42519 .54801 m .42624 .5458 L .42773 .54718 L 0 .025 .123 r
F
.42519 .54801 m .42369 .54664 L .42624 .5458 L F
.43176 .54772 m .43282 .54563 L .43431 .54701 L 0 .024 .122 r
F
.43176 .54772 m .43028 .54635 L .43282 .54563 L F
.54241 .5483 m .54362 .54612 L .54501 .54759 L 0 .025 .124 r
F
.54241 .5483 m .54102 .54683 L .54362 .54612 L F
.50553 .54823 m .50669 .54595 L .50811 .54743 L F
.50553 .54823 m .50411 .54674 L .50669 .54595 L F
.38829 .54815 m .3893 .54594 L .39081 .54745 L F
.38829 .54815 m .38677 .54664 L .3893 .54594 L F
.46206 .54861 m .46316 .54642 L .46462 .54793 L 0 .026 .125 r
F
.46206 .54861 m .4606 .54711 L .46316 .54642 L F
.51211 .54814 m .51328 .54594 L .51469 .54742 L 0 .025 .124 r
F
.51211 .54814 m .51069 .54667 L .51328 .54594 L F
.36456 .54742 m .36552 .54532 L .36707 .54671 L 0 .024 .122 r
F
.36456 .54742 m .36301 .54603 L .36552 .54532 L F
.43833 .5478 m .4394 .54556 L .44088 .54707 L 0 .025 .123 r
F
.43833 .5478 m .43685 .5463 L .4394 .54556 L F
.54899 .54837 m .55021 .54618 L .5516 .54767 L 0 .026 .125 r
F
.54899 .54837 m .54761 .54688 L .55021 .54618 L F
.46864 .54854 m .46975 .5463 L .4712 .5477 L F
.46864 .54854 m .46718 .54715 L .46975 .5463 L F
.47521 .54821 m .47634 .54602 L .47778 .54737 L F
.47521 .54821 m .47377 .54685 L .47634 .54602 L F
.51868 .54806 m .51986 .54588 L .52127 .54726 L 0 .026 .124 r
F
.51868 .54806 m .51728 .54669 L .51986 .54588 L F
.48179 .54789 m .48292 .54574 L .48436 .54709 L 0 .025 .124 r
F
.48179 .54789 m .48035 .54654 L .48292 .54574 L F
.39485 .54826 m .39587 .54597 L .39738 .54749 L 0 .026 .125 r
F
.39485 .54826 m .39334 .54674 L .39587 .54597 L F
.37112 .54742 m .3721 .54519 L .37364 .54664 L 0 .024 .122 r
F
.37112 .54742 m .36958 .54598 L .3721 .54519 L F
.4449 .54781 m .44598 .54554 L .44745 .54705 L 0 .025 .124 r
F
.4449 .54781 m .44343 .5463 L .44598 .54554 L F
.52526 .54782 m .52645 .54562 L .52785 .54702 L F
.52526 .54782 m .52386 .54644 L .52645 .54562 L F
.55558 .54843 m .5568 .54608 L .55818 .54759 L 0 .026 .125 r
F
.55558 .54843 m .5542 .54692 L .5568 .54608 L F
.40142 .54812 m .40245 .5458 L .40396 .54727 L F
.40142 .54812 m .39991 .54664 L .40245 .5458 L F
.48837 .54777 m .48951 .54563 L .49094 .54704 L 0 .025 .124 r
F
.48837 .54777 m .48694 .54636 L .48951 .54563 L F
.53184 .54761 m .53304 .54537 L .53444 .5468 L 0 .025 .123 r
F
.53184 .54761 m .53045 .54619 L .53304 .54537 L F
.408 .54788 m .40903 .54576 L .41053 .54713 L 0 .026 .124 r
F
.408 .54788 m .40649 .54651 L .40903 .54576 L F
.56216 .54825 m .5634 .54592 L .56477 .54741 L 0 .026 .125 r
F
.56216 .54825 m .56079 .54674 L .5634 .54592 L F
.37768 .54737 m .37868 .54513 L .3802 .54663 L 0 .024 .123 r
F
.37768 .54737 m .37616 .54586 L .37868 .54513 L F
.45147 .54781 m .45256 .54555 L .45403 .54704 L 0 .025 .124 r
F
.45147 .54781 m .45001 .5463 L .45256 .54555 L F
.49495 .54767 m .4961 .54546 L .49753 .54688 L F
.49495 .54767 m .49352 .54626 L .4961 .54546 L F
.53843 .54753 m .53963 .54535 L .54102 .54683 L F
.53843 .54753 m .53703 .54605 L .53963 .54535 L F
.41457 .54772 m .41561 .54551 L .41711 .5469 L F
.41457 .54772 m .41307 .54635 L .41561 .54551 L F
.42115 .54747 m .4222 .54525 L .42369 .54664 L 0 .025 .123 r
F
.42115 .54747 m .41966 .54608 L .4222 .54525 L F
.50153 .54754 m .50269 .5453 L .50411 .54674 L 0 .025 .124 r
F
.50153 .54754 m .5001 .54608 L .50269 .5453 L F
.42773 .54718 m .42879 .54497 L .43028 .54635 L 0 .024 .123 r
F
.42773 .54718 m .42624 .5458 L .42879 .54497 L F
.38425 .54738 m .38525 .54517 L .38677 .54664 L 0 .025 .123 r
F
.38425 .54738 m .38272 .5459 L .38525 .54517 L F
.45805 .54779 m .45914 .5456 L .4606 .54711 L 0 .026 .125 r
F
.45805 .54779 m .45659 .54629 L .45914 .5456 L F
.43431 .54701 m .43537 .54491 L .43685 .5463 L 0 .024 .123 r
F
.43431 .54701 m .43282 .54563 L .43537 .54491 L F
.54501 .54759 m .54623 .54541 L .54761 .54688 L 0 .026 .124 r
F
.54501 .54759 m .54362 .54612 L .54623 .54541 L F
.50811 .54743 m .50927 .54519 L .51069 .54667 L 0 .025 .124 r
F
.50811 .54743 m .50669 .54595 L .50927 .54519 L F
.3605 .54674 m .36146 .54464 L .36301 .54603 L 0 .024 .122 r
F
.3605 .54674 m .35895 .54536 L .36146 .54464 L F
.39081 .54745 m .39182 .54524 L .39334 .54674 L 0 .025 .124 r
F
.39081 .54745 m .3893 .54594 L .39182 .54524 L F
.46462 .54793 m .46573 .54564 L .46718 .54715 L 0 .026 .126 r
F
.46462 .54793 m .46316 .54642 L .46573 .54564 L F
.51469 .54742 m .51586 .54522 L .51728 .54669 L 0 .026 .124 r
F
.51469 .54742 m .51328 .54594 L .51586 .54522 L F
.44088 .54707 m .44195 .54479 L .44343 .5463 L 0 .025 .123 r
F
.44088 .54707 m .4394 .54556 L .44195 .54479 L F
.36707 .54671 m .36804 .54457 L .36958 .54598 L 0 .024 .122 r
F
.36707 .54671 m .36552 .54532 L .36804 .54457 L F
.5516 .54767 m .55282 .54542 L .5542 .54692 L 0 .026 .125 r
F
.5516 .54767 m .55021 .54618 L .55282 .54542 L F
.4712 .5477 m .47232 .54545 L .47377 .54685 L F
.4712 .5477 m .46975 .5463 L .47232 .54545 L F
.47778 .54737 m .47891 .54519 L .48035 .54654 L 0 .026 .124 r
F
.47778 .54737 m .47634 .54602 L .47891 .54519 L F
.52127 .54726 m .52246 .54504 L .52386 .54644 L 0 .025 .124 r
F
.52127 .54726 m .51986 .54588 L .52246 .54504 L F
.48436 .54709 m .4855 .545 L .48694 .54636 L F
.48436 .54709 m .48292 .54574 L .4855 .545 L F
.39738 .54749 m .3984 .54514 L .39991 .54664 L 0 .026 .125 r
F
.39738 .54749 m .39587 .54597 L .3984 .54514 L F
.37364 .54664 m .37462 .5444 L .37616 .54586 L 0 .024 .122 r
F
.37364 .54664 m .3721 .54519 L .37462 .5444 L F
.52785 .54702 m .52905 .54479 L .53045 .54619 L 0 .025 .124 r
F
.52785 .54702 m .52645 .54562 L .52905 .54479 L F
.55818 .54759 m .55941 .54524 L .56079 .54674 L 0 .026 .125 r
F
.55818 .54759 m .5568 .54608 L .55941 .54524 L F
.44745 .54705 m .44854 .5448 L .45001 .5463 L 0 .025 .124 r
F
.44745 .54705 m .44598 .54554 L .44854 .5448 L F
.40396 .54727 m .40498 .54505 L .40649 .54651 L 0 .026 .124 r
F
.40396 .54727 m .40245 .5458 L .40498 .54505 L F
.53444 .5468 m .53564 .54462 L .53703 .54605 L 0 .025 .123 r
F
.53444 .5468 m .53304 .54537 L .53564 .54462 L F
.49094 .54704 m .49209 .54484 L .49352 .54626 L 0 .025 .124 r
F
.49094 .54704 m .48951 .54563 L .49209 .54484 L F
.56477 .54741 m .56601 .5451 L .56738 .54658 L 0 .026 .125 r
F
.56477 .54741 m .5634 .54592 L .56601 .5451 L F
.41053 .54713 m .41157 .54497 L .41307 .54635 L F
.41053 .54713 m .40903 .54576 L .41157 .54497 L F
.3802 .54663 m .3812 .54441 L .38272 .5459 L 0 .025 .123 r
F
.3802 .54663 m .37868 .54513 L .3812 .54441 L F
.45403 .54704 m .45512 .5448 L .45659 .54629 L 0 .025 .124 r
F
.45403 .54704 m .45256 .54555 L .45512 .5448 L F
.49753 .54688 m .49868 .54466 L .5001 .54608 L F
.49753 .54688 m .4961 .54546 L .49868 .54466 L F
.41711 .5469 m .41816 .54467 L .41966 .54608 L F
.41711 .5469 m .41561 .54551 L .41816 .54467 L F
.42369 .54664 m .42475 .5444 L .42624 .5458 L 0 .025 .123 r
F
.42369 .54664 m .4222 .54525 L .42475 .5444 L F
.54102 .54683 m .54223 .54465 L .54362 .54612 L 0 .025 .124 r
F
.54102 .54683 m .53963 .54535 L .54223 .54465 L F
.43028 .54635 m .43133 .54425 L .43282 .54563 L 0 .024 .123 r
F
.43028 .54635 m .42879 .54497 L .43133 .54425 L F
.50411 .54674 m .50527 .54451 L .50669 .54595 L 0 .025 .124 r
F
.50411 .54674 m .50269 .5453 L .50527 .54451 L F
.38677 .54664 m .38777 .54448 L .3893 .54594 L F
.38677 .54664 m .38525 .54517 L .38777 .54448 L F
.4606 .54711 m .46171 .54491 L .46316 .54642 L 0 .026 .125 r
F
.4606 .54711 m .45914 .5456 L .46171 .54491 L F
.43685 .5463 m .43792 .54417 L .4394 .54556 L 0 .025 .123 r
F
.43685 .5463 m .43537 .54491 L .43792 .54417 L F
.51069 .54667 m .51186 .54446 L .51328 .54594 L 0 .025 .124 r
F
.51069 .54667 m .50927 .54519 L .51186 .54446 L F
.54761 .54688 m .54883 .5447 L .55021 .54618 L 0 .026 .125 r
F
.54761 .54688 m .54623 .54541 L .54883 .5447 L F
.36301 .54603 m .36398 .54392 L .36552 .54532 L 0 .024 .122 r
F
.36301 .54603 m .36146 .54464 L .36398 .54392 L F
.39334 .54674 m .39435 .54447 L .39587 .54597 L 0 .026 .124 r
F
.39334 .54674 m .39182 .54524 L .39435 .54447 L F
.46718 .54715 m .4683 .54479 L .46975 .5463 L 0 .026 .125 r
F
.46718 .54715 m .46573 .54564 L .4683 .54479 L F
.44343 .5463 m .44451 .54402 L .44598 .54554 L 0 .025 .123 r
F
.44343 .5463 m .44195 .54479 L .44451 .54402 L F
.47377 .54685 m .47489 .54463 L .47634 .54602 L 0 .026 .125 r
F
.47377 .54685 m .47232 .54545 L .47489 .54463 L F
.51728 .54669 m .51845 .54439 L .51986 .54588 L 0 .026 .124 r
F
.51728 .54669 m .51586 .54522 L .51845 .54439 L F
.36958 .54598 m .37056 .54377 L .3721 .54519 L 0 .024 .123 r
F
.36958 .54598 m .36804 .54457 L .37056 .54377 L F
.48035 .54654 m .48148 .54438 L .48292 .54574 L 0 .026 .124 r
F
.48035 .54654 m .47891 .54519 L .48148 .54438 L F
.5542 .54692 m .55543 .54459 L .5568 .54608 L 0 .026 .125 r
F
.5542 .54692 m .55282 .54542 L .55543 .54459 L F
.52386 .54644 m .52505 .54421 L .52645 .54562 L 0 .025 .124 r
F
.52386 .54644 m .52246 .54504 L .52505 .54421 L F
.39991 .54664 m .40094 .5443 L .40245 .5458 L 0 .026 .124 r
F
.39991 .54664 m .3984 .54514 L .40094 .5443 L F
.48694 .54636 m .48807 .54426 L .48951 .54563 L 0 .025 .124 r
F
.48694 .54636 m .4855 .545 L .48807 .54426 L F
.53045 .54619 m .53164 .54395 L .53304 .54537 L 0 .025 .123 r
F
.53045 .54619 m .52905 .54479 L .53164 .54395 L F
.56079 .54674 m .56202 .54443 L .5634 .54592 L 0 .026 .125 r
F
.56079 .54674 m .55941 .54524 L .56202 .54443 L F
.37616 .54586 m .37714 .54366 L .37868 .54513 L 0 .024 .123 r
F
.37616 .54586 m .37462 .5444 L .37714 .54366 L F
.45001 .5463 m .4511 .54406 L .45256 .54555 L 0 .025 .124 r
F
.45001 .5463 m .44854 .5448 L .4511 .54406 L F
.40649 .54651 m .40752 .54431 L .40903 .54576 L 0 .026 .125 r
F
.40649 .54651 m .40498 .54505 L .40752 .54431 L F
.56738 .54658 m .56862 .5443 L .56999 .54577 L F
.56738 .54658 m .56601 .5451 L .56862 .5443 L F
.53703 .54605 m .53824 .54391 L .53963 .54535 L 0 .025 .124 r
F
.53703 .54605 m .53564 .54462 L .53824 .54391 L F
.49352 .54626 m .49467 .54404 L .4961 .54546 L F
.49352 .54626 m .49209 .54484 L .49467 .54404 L F
.41307 .54635 m .41411 .54411 L .41561 .54551 L 0 .026 .124 r
F
.41307 .54635 m .41157 .54497 L .41411 .54411 L F
.5001 .54608 m .50126 .54389 L .50269 .5453 L 0 .025 .124 r
F
.5001 .54608 m .49868 .54466 L .50126 .54389 L F
.41966 .54608 m .4207 .54382 L .4222 .54525 L F
.41966 .54608 m .41816 .54467 L .4207 .54382 L F
.38272 .5459 m .38372 .5437 L .38525 .54517 L 0 .025 .123 r
F
.38272 .5459 m .3812 .54441 L .38372 .5437 L F
.45659 .54629 m .45768 .54412 L .45914 .5456 L 0 .026 .125 r
F
.45659 .54629 m .45512 .5448 L .45768 .54412 L F
.42624 .5458 m .4273 .54356 L .42879 .54497 L 0 .025 .123 r
F
.42624 .5458 m .42475 .5444 L .4273 .54356 L F
.54362 .54612 m .54484 .54393 L .54623 .54541 L 0 .025 .124 r
F
.54362 .54612 m .54223 .54465 L .54484 .54393 L F
.50669 .54595 m .50785 .54376 L .50927 .54519 L F
.50669 .54595 m .50527 .54451 L .50785 .54376 L F
.43282 .54563 m .43388 .54352 L .43537 .54491 L 0 .025 .123 r
F
.43282 .54563 m .43133 .54425 L .43388 .54352 L F
.35895 .54536 m .35991 .54321 L .36146 .54464 L 0 .024 .122 r
F
.35895 .54536 m .3574 .54394 L .35991 .54321 L F
.3893 .54594 m .3903 .54378 L .39182 .54524 L 0 .025 .124 r
F
.3893 .54594 m .38777 .54448 L .3903 .54378 L F
.46316 .54642 m .46427 .54412 L .46573 .54564 L 0 .026 .125 r
F
.46316 .54642 m .46171 .54491 L .46427 .54412 L F
.4394 .54556 m .44048 .54338 L .44195 .54479 L 0 .025 .123 r
F
.4394 .54556 m .43792 .54417 L .44048 .54338 L F
.51328 .54594 m .51445 .54374 L .51586 .54522 L 0 .025 .124 r
F
.51328 .54594 m .51186 .54446 L .51445 .54374 L F
.55021 .54618 m .55144 .54394 L .55282 .54542 L 0 .026 .125 r
F
.55021 .54618 m .54883 .5447 L .55144 .54394 L F
.36552 .54532 m .36649 .54317 L .36804 .54457 L 0 .024 .123 r
F
.36552 .54532 m .36398 .54392 L .36649 .54317 L F
.46975 .5463 m .47087 .54394 L .47232 .54545 L 0 .026 .125 r
F
.46975 .5463 m .4683 .54479 L .47087 .54394 L F
.39587 .54597 m .39689 .54365 L .3984 .54514 L 0 .026 .124 r
F
.39587 .54597 m .39435 .54447 L .39689 .54365 L F
.47634 .54602 m .47746 .5438 L .47891 .54519 L 0 .026 .125 r
F
.47634 .54602 m .47489 .54463 L .47746 .5438 L F
.51986 .54588 m .52105 .54354 L .52246 .54504 L 0 .025 .124 r
F
.51986 .54588 m .51845 .54439 L .52105 .54354 L F
.5568 .54608 m .55804 .54375 L .55941 .54524 L 0 .026 .125 r
F
.5568 .54608 m .55543 .54459 L .55804 .54375 L F
.44598 .54554 m .44707 .54329 L .44854 .5448 L 0 .025 .123 r
F
.44598 .54554 m .44451 .54402 L .44707 .54329 L F
.3721 .54519 m .37308 .54296 L .37462 .5444 L 0 .024 .123 r
F
.3721 .54519 m .37056 .54377 L .37308 .54296 L F
.48292 .54574 m .48405 .54364 L .4855 .545 L 0 .026 .124 r
F
.48292 .54574 m .48148 .54438 L .48405 .54364 L F
.40245 .5458 m .40347 .54357 L .40498 .54505 L F
.40245 .5458 m .40094 .5443 L .40347 .54357 L F
.52645 .54562 m .52765 .54337 L .52905 .54479 L 0 .025 .124 r
F
.52645 .54562 m .52505 .54421 L .52765 .54337 L F
.53304 .54537 m .53424 .54319 L .53564 .54462 L 0 .025 .123 r
F
.53304 .54537 m .53164 .54395 L .53424 .54319 L F
.5634 .54592 m .56464 .54362 L .56601 .5451 L 0 .026 .125 r
F
.5634 .54592 m .56202 .54443 L .56464 .54362 L F
.48951 .54563 m .49065 .54346 L .49209 .54484 L 0 .026 .124 r
F
.48951 .54563 m .48807 .54426 L .49065 .54346 L F
.37868 .54513 m .37967 .54295 L .3812 .54441 L 0 .024 .123 r
F
.37868 .54513 m .37714 .54366 L .37967 .54295 L F
.45256 .54555 m .45366 .54333 L .45512 .5448 L 0 .025 .124 r
F
.45256 .54555 m .4511 .54406 L .45366 .54333 L F
.40903 .54576 m .41006 .54353 L .41157 .54497 L 0 .026 .125 r
F
.40903 .54576 m .40752 .54431 L .41006 .54353 L F
.56999 .54577 m .57124 .54356 L .5726 .54505 L F
.56999 .54577 m .56862 .5443 L .57124 .54356 L F
.4961 .54546 m .49725 .54323 L .49868 .54466 L 0 .025 .124 r
F
.4961 .54546 m .49467 .54404 L .49725 .54323 L F
.41561 .54551 m .41666 .54325 L .41816 .54467 L F
.41561 .54551 m .41411 .54411 L .41666 .54325 L F
.53963 .54535 m .54084 .54321 L .54223 .54465 L F
.53963 .54535 m .53824 .54391 L .54084 .54321 L F
.4222 .54525 m .42325 .54297 L .42475 .5444 L 0 .025 .123 r
F
.4222 .54525 m .4207 .54382 L .42325 .54297 L F
.50269 .5453 m .50385 .54312 L .50527 .54451 L 0 .025 .124 r
F
.50269 .5453 m .50126 .54389 L .50385 .54312 L F
.42879 .54497 m .42985 .54283 L .43133 .54425 L 0 .025 .123 r
F
.42879 .54497 m .4273 .54356 L .42985 .54283 L F
.38525 .54517 m .38625 .54301 L .38777 .54448 L 0 .025 .124 r
F
.38525 .54517 m .38372 .5437 L .38625 .54301 L F
.45914 .5456 m .46025 .54343 L .46171 .54491 L 0 .026 .125 r
F
.45914 .5456 m .45768 .54412 L .46025 .54343 L F
.50927 .54519 m .51044 .54304 L .51186 .54446 L 0 .025 .124 r
F
.50927 .54519 m .50785 .54376 L .51044 .54304 L F
.54623 .54541 m .54744 .54321 L .54883 .5447 L 0 .026 .125 r
F
.54623 .54541 m .54484 .54393 L .54744 .54321 L F
.43537 .54491 m .43644 .54277 L .43792 .54417 L 0 .025 .123 r
F
.43537 .54491 m .43388 .54352 L .43644 .54277 L F
.36146 .54464 m .36243 .54247 L .36398 .54392 L 0 .024 .123 r
F
.36146 .54464 m .35991 .54321 L .36243 .54247 L F
.39182 .54524 m .39283 .54302 L .39435 .54447 L 0 .026 .124 r
F
.39182 .54524 m .3903 .54378 L .39283 .54302 L F
.46573 .54564 m .46684 .54328 L .4683 .54479 L 0 .026 .125 r
F
.46573 .54564 m .46427 .54412 L .46684 .54328 L F
.44195 .54479 m .44303 .54259 L .44451 .54402 L 0 .025 .123 r
F
.44195 .54479 m .44048 .54338 L .44303 .54259 L F
.51586 .54522 m .51704 .5429 L .51845 .54439 L 0 .026 .124 r
F
.51586 .54522 m .51445 .54374 L .51704 .5429 L F
.55282 .54542 m .55405 .54313 L .55543 .54459 L 0 .026 .125 r
F
.55282 .54542 m .55144 .54394 L .55405 .54313 L F
.47232 .54545 m .47344 .54313 L .47489 .54463 L F
.47232 .54545 m .47087 .54394 L .47344 .54313 L F
.36804 .54457 m .36902 .54234 L .37056 .54377 L 0 .024 .123 r
F
.36804 .54457 m .36649 .54317 L .36902 .54234 L F
.3984 .54514 m .39943 .54282 L .40094 .5443 L 0 .025 .124 r
F
.3984 .54514 m .39689 .54365 L .39943 .54282 L F
.47891 .54519 m .48003 .543 L .48148 .54438 L 0 .026 .125 r
F
.47891 .54519 m .47746 .5438 L .48003 .543 L F
.52246 .54504 m .52364 .5427 L .52505 .54421 L 0 .025 .124 r
F
.52246 .54504 m .52105 .54354 L .52364 .5427 L F
.55941 .54524 m .56065 .54296 L .56202 .54443 L 0 .026 .125 r
F
.55941 .54524 m .55804 .54375 L .56065 .54296 L F
.37462 .5444 m .37561 .54222 L .37714 .54366 L 0 .024 .123 r
F
.37462 .5444 m .37308 .54296 L .37561 .54222 L F
.52905 .54479 m .53024 .54252 L .53164 .54395 L 0 .025 .124 r
F
.52905 .54479 m .52765 .54337 L .53024 .54252 L F
.44854 .5448 m .44963 .54257 L .4511 .54406 L F
.44854 .5448 m .44707 .54329 L .44963 .54257 L F
.4855 .545 m .48663 .54289 L .48807 .54426 L 0 .026 .125 r
F
.4855 .545 m .48405 .54364 L .48663 .54289 L F
.40498 .54505 m .40601 .54284 L .40752 .54431 L F
.40498 .54505 m .40347 .54357 L .40601 .54284 L F
.56601 .5451 m .56725 .54283 L .56862 .5443 L F
.56601 .5451 m .56464 .54362 L .56725 .54283 L F
.53564 .54462 m .53685 .54248 L .53824 .54391 L 0 .025 .124 r
F
.53564 .54462 m .53424 .54319 L .53685 .54248 L F
.49209 .54484 m .49323 .54263 L .49467 .54404 L F
.49209 .54484 m .49065 .54346 L .49323 .54263 L F
.3812 .54441 m .38219 .54224 L .38372 .5437 L 0 .025 .123 r
F
.3812 .54441 m .37967 .54295 L .38219 .54224 L F
.41157 .54497 m .41261 .54267 L .41411 .54411 L 0 .026 .125 r
F
.41157 .54497 m .41006 .54353 L .41261 .54267 L F
.45512 .5448 m .45622 .54264 L .45768 .54412 L 0 .026 .124 r
F
.45512 .5448 m .45366 .54333 L .45622 .54264 L F
.49868 .54466 m .49983 .54248 L .50126 .54389 L 0 .025 .124 r
F
.49868 .54466 m .49725 .54323 L .49983 .54248 L F
.41816 .54467 m .41921 .5424 L .4207 .54382 L F
.41816 .54467 m .41666 .54325 L .41921 .5424 L F
.5726 .54505 m .57386 .54282 L .57522 .54433 L 0 .026 .125 r
F
.5726 .54505 m .57124 .54356 L .57386 .54282 L F
.42475 .5444 m .4258 .54213 L .4273 .54356 L 0 .025 .123 r
F
.42475 .5444 m .42325 .54297 L .4258 .54213 L F
.54223 .54465 m .54345 .54248 L .54484 .54393 L 0 .025 .124 r
F
.54223 .54465 m .54084 .54321 L .54345 .54248 L F
.50527 .54451 m .50643 .54238 L .50785 .54376 L F
.50527 .54451 m .50385 .54312 L .50643 .54238 L F
.43133 .54425 m .4324 .5421 L .43388 .54352 L 0 .025 .123 r
F
.43133 .54425 m .42985 .54283 L .4324 .5421 L F
.38777 .54448 m .38878 .54232 L .3903 .54378 L 0 .025 .124 r
F
.38777 .54448 m .38625 .54301 L .38878 .54232 L F
.3574 .54394 m .35836 .54177 L .35991 .54321 L 0 .024 .122 r
F
.3574 .54394 m .35584 .54252 L .35836 .54177 L F
.46171 .54491 m .46281 .54265 L .46427 .54412 L 0 .026 .125 r
F
.46171 .54491 m .46025 .54343 L .46281 .54265 L F
.51186 .54446 m .51303 .54231 L .51445 .54374 L 0 .025 .124 r
F
.51186 .54446 m .51044 .54304 L .51303 .54231 L F
.54883 .5447 m .55005 .54247 L .55144 .54394 L 0 .026 .125 r
F
.54883 .5447 m .54744 .54321 L .55005 .54247 L F
.43792 .54417 m .43899 .54196 L .44048 .54338 L 0 .025 .123 r
F
.43792 .54417 m .43644 .54277 L .43899 .54196 L F
.4683 .54479 m .46941 .54243 L .47087 .54394 L 0 .026 .125 r
F
.4683 .54479 m .46684 .54328 L .46941 .54243 L F
.39435 .54447 m .39537 .54221 L .39689 .54365 L 0 .026 .124 r
F
.39435 .54447 m .39283 .54302 L .39537 .54221 L F
.36398 .54392 m .36495 .5417 L .36649 .54317 L 0 .024 .123 r
F
.36398 .54392 m .36243 .54247 L .36495 .5417 L F
.51845 .54439 m .51964 .54204 L .52105 .54354 L 0 .025 .124 r
F
.51845 .54439 m .51704 .5429 L .51964 .54204 L F
.44451 .54402 m .44559 .54185 L .44707 .54329 L 0 .025 .123 r
F
.44451 .54402 m .44303 .54259 L .44559 .54185 L F
.55543 .54459 m .55666 .54231 L .55804 .54375 L 0 .026 .125 r
F
.55543 .54459 m .55405 .54313 L .55666 .54231 L F
.47489 .54463 m .47601 .54233 L .47746 .5438 L F
.47489 .54463 m .47344 .54313 L .47601 .54233 L F
.40094 .5443 m .40196 .5421 L .40347 .54357 L 0 .025 .124 r
F
.40094 .5443 m .39943 .54282 L .40196 .5421 L F
.37056 .54377 m .37154 .54152 L .37308 .54296 L 0 .024 .123 r
F
.37056 .54377 m .36902 .54234 L .37154 .54152 L F
.48148 .54438 m .48261 .54224 L .48405 .54364 L 0 .026 .125 r
F
.48148 .54438 m .48003 .543 L .48261 .54224 L F
.52505 .54421 m .52624 .54187 L .52765 .54337 L 0 .025 .124 r
F
.52505 .54421 m .52364 .5427 L .52624 .54187 L F
.56202 .54443 m .56326 .54217 L .56464 .54362 L 0 .026 .125 r
F
.56202 .54443 m .56065 .54296 L .56326 .54217 L F
.53164 .54395 m .53284 .54176 L .53424 .54319 L 0 .025 .124 r
F
.53164 .54395 m .53024 .54252 L .53284 .54176 L F
.37714 .54366 m .37813 .5415 L .37967 .54295 L 0 .024 .123 r
F
.37714 .54366 m .37561 .54222 L .37813 .5415 L F
.4511 .54406 m .45219 .54185 L .45366 .54333 L 0 .025 .124 r
F
.4511 .54406 m .44963 .54257 L .45219 .54185 L F
.48807 .54426 m .48921 .54207 L .49065 .54346 L 0 .026 .125 r
F
.48807 .54426 m .48663 .54289 L .48921 .54207 L F
.56862 .5443 m .56987 .54207 L .57124 .54356 L F
.56862 .5443 m .56725 .54283 L .56987 .54207 L F
.40752 .54431 m .40855 .54207 L .41006 .54353 L F
.40752 .54431 m .40601 .54284 L .40855 .54207 L F
.49467 .54404 m .49582 .54181 L .49725 .54323 L 0 .025 .124 r
F
.49467 .54404 m .49323 .54263 L .49582 .54181 L F
.53824 .54391 m .53945 .54177 L .54084 .54321 L F
.53824 .54391 m .53685 .54248 L .53945 .54177 L F
.41411 .54411 m .41515 .54181 L .41666 .54325 L 0 .026 .124 r
F
.41411 .54411 m .41261 .54267 L .41515 .54181 L F
.4207 .54382 m .42176 .54154 L .42325 .54297 L 0 .025 .124 r
F
.4207 .54382 m .41921 .5424 L .42176 .54154 L F
.38372 .5437 m .38472 .54154 L .38625 .54301 L F
.38372 .5437 m .38219 .54224 L .38472 .54154 L F
.50126 .54389 m .50242 .54173 L .50385 .54312 L F
.50126 .54389 m .49983 .54248 L .50242 .54173 L F
.4273 .54356 m .42835 .54138 L .42985 .54283 L 0 .025 .123 r
F
.4273 .54356 m .4258 .54213 L .42835 .54138 L F
.45768 .54412 m .45878 .54196 L .46025 .54343 L 0 .026 .125 r
F
.45768 .54412 m .45622 .54264 L .45878 .54196 L F
.57522 .54433 m .57648 .54206 L .57784 .54359 L F
.57522 .54433 m .57386 .54282 L .57648 .54206 L F
.54484 .54393 m .54606 .54174 L .54744 .54321 L F
.54484 .54393 m .54345 .54248 L .54606 .54174 L F
.50785 .54376 m .50902 .54166 L .51044 .54304 L 0 .025 .124 r
F
.50785 .54376 m .50643 .54238 L .50902 .54166 L F
.43388 .54352 m .43495 .54133 L .43644 .54277 L F
.43388 .54352 m .4324 .5421 L .43495 .54133 L F
.35991 .54321 m .36088 .54102 L .36243 .54247 L 0 .024 .123 r
F
.35991 .54321 m .35836 .54177 L .36088 .54102 L F
.46427 .54412 m .46538 .54181 L .46684 .54328 L 0 .026 .125 r
F
.46427 .54412 m .46281 .54265 L .46538 .54181 L F
.3903 .54378 m .39131 .54158 L .39283 .54302 L 0 .026 .124 r
F
.3903 .54378 m .38878 .54232 L .39131 .54158 L F
.51445 .54374 m .51563 .54147 L .51704 .5429 L F
.51445 .54374 m .51303 .54231 L .51563 .54147 L F
.44048 .54338 m .44155 .54115 L .44303 .54259 L 0 .025 .123 r
F
.44048 .54338 m .43899 .54196 L .44155 .54115 L F
.47087 .54394 m .47198 .54164 L .47344 .54313 L 0 .026 .125 r
F
.47087 .54394 m .46941 .54243 L .47198 .54164 L F
.55144 .54394 m .55266 .54166 L .55405 .54313 L F
.55144 .54394 m .55005 .54247 L .55266 .54166 L F
.39689 .54365 m .39791 .5414 L .39943 .54282 L 0 .025 .124 r
F
.39689 .54365 m .39537 .54221 L .39791 .5414 L F
.36649 .54317 m .36747 .54087 L .36902 .54234 L 0 .024 .123 r
F
.36649 .54317 m .36495 .5417 L .36747 .54087 L F
.52105 .54354 m .52223 .54119 L .52364 .5427 L 0 .025 .124 r
F
.52105 .54354 m .51964 .54204 L .52223 .54119 L F
.55804 .54375 m .55927 .54153 L .56065 .54296 L 0 .026 .125 r
F
.55804 .54375 m .55666 .54231 L .55927 .54153 L F
.47746 .5438 m .47859 .54153 L .48003 .543 L F
.47746 .5438 m .47601 .54233 L .47859 .54153 L F
.44707 .54329 m .44815 .54113 L .44963 .54257 L 0 .025 .124 r
F
.44707 .54329 m .44559 .54185 L .44815 .54113 L F
.37308 .54296 m .37407 .54078 L .37561 .54222 L 0 .024 .123 r
F
.37308 .54296 m .37154 .54152 L .37407 .54078 L F
.52765 .54337 m .52884 .54103 L .53024 .54252 L 0 .025 .124 r
F
.52765 .54337 m .52624 .54187 L .52884 .54103 L F
.40347 .54357 m .4045 .54138 L .40601 .54284 L 0 .026 .125 r
F
.40347 .54357 m .40196 .5421 L .4045 .54138 L F
.56464 .54362 m .56588 .54138 L .56725 .54283 L F
.56464 .54362 m .56326 .54217 L .56588 .54138 L F
.48405 .54364 m .48519 .54148 L .48663 .54289 L F
.48405 .54364 m .48261 .54224 L .48519 .54148 L F
.53424 .54319 m .53545 .54104 L .53685 .54248 L 0 .025 .124 r
F
.53424 .54319 m .53284 .54176 L .53545 .54104 L F
.49065 .54346 m .4918 .54123 L .49323 .54263 L 0 .026 .125 r
F
.49065 .54346 m .48921 .54207 L .4918 .54123 L F
.37967 .54295 m .38066 .54078 L .38219 .54224 L 0 .025 .123 r
F
.37967 .54295 m .37813 .5415 L .38066 .54078 L F
.45366 .54333 m .45475 .54117 L .45622 .54264 L 0 .026 .124 r
F
.45366 .54333 m .45219 .54185 L .45475 .54117 L F
.41006 .54353 m .4111 .54122 L .41261 .54267 L 0 .026 .125 r
F
.41006 .54353 m .40855 .54207 L .4111 .54122 L F
.57124 .54356 m .57249 .54131 L .57386 .54282 L F
.57124 .54356 m .56987 .54207 L .57249 .54131 L F
.49725 .54323 m .4984 .54106 L .49983 .54248 L 0 .025 .124 r
F
.49725 .54323 m .49582 .54181 L .4984 .54106 L F
.41666 .54325 m .4177 .54097 L .41921 .5424 L F
.41666 .54325 m .41515 .54181 L .4177 .54097 L F
.42325 .54297 m .42431 .5407 L .4258 .54213 L 0 .025 .123 r
F
.42325 .54297 m .42176 .54154 L .42431 .5407 L F
.54084 .54321 m .54206 .54102 L .54345 .54248 L 0 .026 .124 r
F
.54084 .54321 m .53945 .54177 L .54206 .54102 L F
.50385 .54312 m .50501 .54099 L .50643 .54238 L F
.50385 .54312 m .50242 .54173 L .50501 .54099 L F
.38625 .54301 m .38725 .54084 L .38878 .54232 L 0 .025 .124 r
F
.38625 .54301 m .38472 .54154 L .38725 .54084 L F
.42985 .54283 m .43091 .54063 L .4324 .5421 L 0 .025 .123 r
F
.42985 .54283 m .42835 .54138 L .43091 .54063 L F
.57784 .54359 m .57911 .54127 L .58047 .54282 L 0 .026 .125 r
F
.57784 .54359 m .57648 .54206 L .57911 .54127 L F
.46025 .54343 m .46135 .5412 L .46281 .54265 L F
.46025 .54343 m .45878 .54196 L .46135 .5412 L F
.35584 .54252 m .3568 .54033 L .35836 .54177 L 0 .024 .123 r
F
.35584 .54252 m .35429 .54109 L .3568 .54033 L F
.54744 .54321 m .54867 .54099 L .55005 .54247 L 0 .026 .125 r
F
.54744 .54321 m .54606 .54174 L .54867 .54099 L F
.51044 .54304 m .51161 .54094 L .51303 .54231 L F
.51044 .54304 m .50902 .54166 L .51161 .54094 L F
.46684 .54328 m .46796 .54098 L .46941 .54243 L F
.46684 .54328 m .46538 .54181 L .46796 .54098 L F
.43644 .54277 m .43751 .5405 L .43899 .54196 L 0 .025 .124 r
F
.43644 .54277 m .43495 .54133 L .43751 .5405 L F
.36243 .54247 m .3634 .54023 L .36495 .5417 L 0 .024 .123 r
F
.36243 .54247 m .36088 .54102 L .3634 .54023 L F
.39283 .54302 m .39385 .54078 L .39537 .54221 L 0 .026 .124 r
F
.39283 .54302 m .39131 .54158 L .39385 .54078 L F
.51704 .5429 m .51822 .54061 L .51964 .54204 L 0 .025 .124 r
F
.51704 .5429 m .51563 .54147 L .51822 .54061 L F
.55405 .54313 m .55528 .54086 L .55666 .54231 L 0 .026 .125 r
F
.55405 .54313 m .55266 .54166 L .55528 .54086 L F
.47344 .54313 m .47456 .54085 L .47601 .54233 L F
.47344 .54313 m .47198 .54164 L .47456 .54085 L F
.44303 .54259 m .44411 .54041 L .44559 .54185 L 0 .025 .123 r
F
.44303 .54259 m .44155 .54115 L .44411 .54041 L F
.39943 .54282 m .40044 .5407 L .40196 .5421 L 0 .026 .124 r
F
.39943 .54282 m .39791 .5414 L .40044 .5407 L F
.52364 .5427 m .52483 .54037 L .52624 .54187 L 0 .025 .124 r
F
.52364 .5427 m .52223 .54119 L .52483 .54037 L F
.36902 .54234 m .37 .54003 L .37154 .54152 L 0 .024 .123 r
F
.36902 .54234 m .36747 .54087 L .37 .54003 L F
.56065 .54296 m .56189 .54076 L .56326 .54217 L 0 .026 .125 r
F
.56065 .54296 m .55927 .54153 L .56189 .54076 L F
.48003 .543 m .48117 .54076 L .48261 .54224 L F
.48003 .543 m .47859 .54153 L .48117 .54076 L F
.53024 .54252 m .53144 .54026 L .53284 .54176 L 0 .025 .124 r
F
.53024 .54252 m .52884 .54103 L .53144 .54026 L F
.44963 .54257 m .45071 .54041 L .45219 .54185 L F
.44963 .54257 m .44815 .54113 L .45071 .54041 L F
.37561 .54222 m .37659 .54006 L .37813 .5415 L 0 .025 .123 r
F
.37561 .54222 m .37407 .54078 L .37659 .54006 L F
.56725 .54283 m .5685 .54061 L .56987 .54207 L 0 .026 .125 r
F
.56725 .54283 m .56588 .54138 L .5685 .54061 L F
.40601 .54284 m .40704 .54063 L .40855 .54207 L F
.40601 .54284 m .4045 .54138 L .40704 .54063 L F
.48663 .54289 m .48777 .54065 L .48921 .54207 L F
.48663 .54289 m .48519 .54148 L .48777 .54065 L F
.49323 .54263 m .49438 .54039 L .49582 .54181 L 0 .026 .124 r
F
.49323 .54263 m .4918 .54123 L .49438 .54039 L F
.53685 .54248 m .53805 .54033 L .53945 .54177 L 0 .025 .124 r
F
.53685 .54248 m .53545 .54104 L .53805 .54033 L F
.41261 .54267 m .41365 .54037 L .41515 .54181 L 0 .026 .124 r
F
.41261 .54267 m .4111 .54122 L .41365 .54037 L F
.41921 .5424 m .42026 .54013 L .42176 .54154 L 0 .025 .124 r
F
.41921 .5424 m .4177 .54097 L .42026 .54013 L F
.38219 .54224 m .38319 .54006 L .38472 .54154 L F
.38219 .54224 m .38066 .54078 L .38319 .54006 L F
.57386 .54282 m .57512 .54053 L .57648 .54206 L 0 .026 .125 r
F
.57386 .54282 m .57249 .54131 L .57512 .54053 L F
.45622 .54264 m .45731 .54049 L .45878 .54196 L F
.45622 .54264 m .45475 .54117 L .45731 .54049 L F
.49983 .54248 m .50099 .54031 L .50242 .54173 L 0 .026 .124 r
F
.49983 .54248 m .4984 .54106 L .50099 .54031 L F
.4258 .54213 m .42686 .53992 L .42835 .54138 L 0 .025 .123 r
F
.4258 .54213 m .42431 .5407 L .42686 .53992 L F
.54345 .54248 m .54467 .54028 L .54606 .54174 L 0 .026 .125 r
F
.54345 .54248 m .54206 .54102 L .54467 .54028 L F
.50643 .54238 m .5076 .54028 L .50902 .54166 L F
.50643 .54238 m .50501 .54099 L .5076 .54028 L F
.58047 .54282 m .58173 .54048 L .58309 .54205 L F
.58047 .54282 m .57911 .54127 L .58173 .54048 L F
.4324 .5421 m .43346 .53983 L .43495 .54133 L 0 .025 .124 r
F
.4324 .5421 m .43091 .54063 L .43346 .53983 L F
.46281 .54265 m .46392 .54037 L .46538 .54181 L 0 .026 .125 r
F
.46281 .54265 m .46135 .5412 L .46392 .54037 L F
.38878 .54232 m .38978 .54009 L .39131 .54158 L 0 .026 .124 r
F
.38878 .54232 m .38725 .54084 L .38978 .54009 L F
.35836 .54177 m .35933 .53957 L .36088 .54102 L 0 .024 .123 r
F
.35836 .54177 m .3568 .54033 L .35933 .53957 L F
.46941 .54243 m .47053 .5402 L .47198 .54164 L 0 .026 .125 r
F
.46941 .54243 m .46796 .54098 L .47053 .5402 L F
.55005 .54247 m .55128 .54019 L .55266 .54166 L F
.55005 .54247 m .54867 .54099 L .55128 .54019 L F
.51303 .54231 m .51421 .5401 L .51563 .54147 L F
.51303 .54231 m .51161 .54094 L .51421 .5401 L F
.43899 .54196 m .44007 .53967 L .44155 .54115 L 0 .025 .123 r
F
.43899 .54196 m .43751 .5405 L .44007 .53967 L F
.39537 .54221 m .39638 .53998 L .39791 .5414 L 0 .026 .124 r
F
.39537 .54221 m .39385 .54078 L .39638 .53998 L F
.51964 .54204 m .52082 .53976 L .52223 .54119 L 0 .025 .124 r
F
.51964 .54204 m .51822 .54061 L .52082 .53976 L F
.36495 .5417 m .36593 .53939 L .36747 .54087 L 0 .024 .123 r
F
.36495 .5417 m .3634 .54023 L .36593 .53939 L F
.55666 .54231 m .55789 .5401 L .55927 .54153 L 0 .026 .125 r
F
.55666 .54231 m .55528 .54086 L .55789 .5401 L F
.47601 .54233 m .47714 .54006 L .47859 .54153 L F
.47601 .54233 m .47456 .54085 L .47714 .54006 L F
.44559 .54185 m .44667 .53968 L .44815 .54113 L 0 .025 .124 r
F
.44559 .54185 m .44411 .54041 L .44667 .53968 L F
.52624 .54187 m .52743 .53954 L .52884 .54103 L 0 .025 .123 r
F
.52624 .54187 m .52483 .54037 L .52743 .53954 L F
.37154 .54152 m .37253 .53928 L .37407 .54078 L 0 .024 .123 r
F
.37154 .54152 m .37 .54003 L .37253 .53928 L F
.40196 .5421 m .40298 .54 L .4045 .54138 L 0 .026 .125 r
F
.40196 .5421 m .40044 .5407 L .40298 .54 L F
.56326 .54217 m .56451 .53999 L .56588 .54138 L F
.56326 .54217 m .56189 .54076 L .56451 .53999 L F
.48261 .54224 m .48375 .53999 L .48519 .54148 L F
.48261 .54224 m .48117 .54076 L .48375 .53999 L F
.53284 .54176 m .53405 .53953 L .53545 .54104 L 0 .025 .124 r
F
.53284 .54176 m .53144 .54026 L .53405 .53953 L F
.45219 .54185 m .45328 .53971 L .45475 .54117 L 0 .026 .124 r
F
.45219 .54185 m .45071 .54041 L .45328 .53971 L F
.37813 .5415 m .37912 .53933 L .38066 .54078 L 0 .025 .123 r
F
.37813 .5415 m .37659 .54006 L .37912 .53933 L F
.56987 .54207 m .57113 .53984 L .57249 .54131 L 0 .026 .125 r
F
.56987 .54207 m .5685 .54061 L .57113 .53984 L F
.48921 .54207 m .49036 .53979 L .4918 .54123 L F
.48921 .54207 m .48777 .54065 L .49036 .53979 L F
.40855 .54207 m .40959 .53978 L .4111 .54122 L F
.40855 .54207 m .40704 .54063 L .40959 .53978 L F
.41515 .54181 m .4162 .53953 L .4177 .54097 L 0 .025 .124 r
F
.41515 .54181 m .41365 .54037 L .4162 .53953 L F
.49582 .54181 m .49697 .53964 L .4984 .54106 L 0 .026 .124 r
F
.49582 .54181 m .49438 .54039 L .49697 .53964 L F
.42176 .54154 m .42281 .53929 L .42431 .5407 L 0 .025 .124 r
F
.42176 .54154 m .42026 .54013 L .42281 .53929 L F
.53945 .54177 m .54066 .53956 L .54206 .54102 L 0 .026 .124 r
F
.53945 .54177 m .53805 .54033 L .54066 .53956 L F
.57648 .54206 m .57774 .53972 L .57911 .54127 L 0 .026 .125 r
F
.57648 .54206 m .57512 .54053 L .57774 .53972 L F
.38472 .54154 m .38572 .53934 L .38725 .54084 L 0 .025 .124 r
F
.38472 .54154 m .38319 .54006 L .38572 .53934 L F
.50242 .54173 m .50358 .53958 L .50501 .54099 L 0 .026 .125 r
F
.50242 .54173 m .50099 .54031 L .50358 .53958 L F
.42835 .54138 m .42942 .53915 L .43091 .54063 L 0 .025 .123 r
F
.42835 .54138 m .42686 .53992 L .42942 .53915 L F
.45878 .54196 m .45988 .53974 L .46135 .5412 L 0 .026 .125 r
F
.45878 .54196 m .45731 .54049 L .45988 .53974 L F
.35429 .54109 m .35525 .53889 L .3568 .54033 L 0 .024 .123 r
F
.35429 .54109 m .35273 .53964 L .35525 .53889 L F
.54606 .54174 m .54728 .53951 L .54867 .54099 L 0 .026 .125 r
F
.54606 .54174 m .54467 .54028 L .54728 .53951 L F
.46538 .54181 m .4665 .53955 L .46796 .54098 L F
.46538 .54181 m .46392 .54037 L .4665 .53955 L F
.50902 .54166 m .51019 .53957 L .51161 .54094 L F
.50902 .54166 m .5076 .54028 L .51019 .53957 L F
.58309 .54205 m .58436 .5397 L .58572 .54126 L 0 .026 .126 r
F
.58309 .54205 m .58173 .54048 L .58436 .5397 L F
.43495 .54133 m .43603 .53899 L .43751 .5405 L 0 .025 .123 r
F
.43495 .54133 m .43346 .53983 L .43603 .53899 L F
.36088 .54102 m .36185 .53877 L .3634 .54023 L 0 .024 .123 r
F
.36088 .54102 m .35933 .53957 L .36185 .53877 L F
.39131 .54158 m .39232 .5393 L .39385 .54078 L 0 .026 .124 r
F
.39131 .54158 m .38978 .54009 L .39232 .5393 L F
.47198 .54164 m .47311 .53944 L .47456 .54085 L 0 .026 .125 r
F
.47198 .54164 m .47053 .5402 L .47311 .53944 L F
.51563 .54147 m .51681 .53924 L .51822 .54061 L 0 .026 .124 r
F
.51563 .54147 m .51421 .5401 L .51681 .53924 L F
.55266 .54166 m .55389 .5394 L .55528 .54086 L 0 .026 .125 r
F
.55266 .54166 m .55128 .54019 L .55389 .5394 L F
.44155 .54115 m .44263 .53893 L .44411 .54041 L 0 .025 .123 r
F
.44155 .54115 m .44007 .53967 L .44263 .53893 L F
.52223 .54119 m .52342 .53894 L .52483 .54037 L 0 .025 .124 r
F
.52223 .54119 m .52082 .53976 L .52342 .53894 L F
.39791 .5414 m .39892 .53929 L .40044 .5407 L 0 .026 .125 r
F
.39791 .5414 m .39638 .53998 L .39892 .53929 L F
.36747 .54087 m .36846 .53854 L .37 .54003 L 0 .024 .123 r
F
.36747 .54087 m .36593 .53939 L .36846 .53854 L F
.55927 .54153 m .56051 .53935 L .56189 .54076 L 0 .026 .125 r
F
.55927 .54153 m .55789 .5401 L .56051 .53935 L F
.47859 .54153 m .47972 .53928 L .48117 .54076 L F
.47859 .54153 m .47714 .54006 L .47972 .53928 L F
.52884 .54103 m .53004 .53877 L .53144 .54026 L 0 .025 .123 r
F
.52884 .54103 m .52743 .53954 L .53004 .53877 L F
.44815 .54113 m .44924 .53896 L .45071 .54041 L 0 .025 .124 r
F
.44815 .54113 m .44667 .53968 L .44924 .53896 L F
.37407 .54078 m .37506 .53855 L .37659 .54006 L 0 .024 .123 r
F
.37407 .54078 m .37253 .53928 L .37506 .53855 L F
.56588 .54138 m .56713 .53921 L .5685 .54061 L 0 .026 .125 r
F
.56588 .54138 m .56451 .53999 L .56713 .53921 L F
.4045 .54138 m .40553 .53926 L .40704 .54063 L F
.4045 .54138 m .40298 .54 L .40553 .53926 L F
.48519 .54148 m .48633 .53916 L .48777 .54065 L F
.48519 .54148 m .48375 .53999 L .48633 .53916 L F
.4111 .54122 m .41214 .53893 L .41365 .54037 L 0 .026 .124 r
F
.4111 .54122 m .40959 .53978 L .41214 .53893 L F
.53545 .54104 m .53666 .5388 L .53805 .54033 L 0 .025 .124 r
F
.53545 .54104 m .53405 .53953 L .53666 .5388 L F
.4918 .54123 m .49294 .53895 L .49438 .54039 L 0 .026 .125 r
F
.4918 .54123 m .49036 .53979 L .49294 .53895 L F
.57249 .54131 m .57375 .53904 L .57512 .54053 L F
.57249 .54131 m .57113 .53984 L .57375 .53904 L F
.4177 .54097 m .41875 .53871 L .42026 .54013 L 0 .025 .124 r
F
.4177 .54097 m .4162 .53953 L .41875 .53871 L F
.38066 .54078 m .38165 .53858 L .38319 .54006 L F
.38066 .54078 m .37912 .53933 L .38165 .53858 L F
.45475 .54117 m .45585 .53902 L .45731 .54049 L 0 .026 .125 r
F
.45475 .54117 m .45328 .53971 L .45585 .53902 L F
.42431 .5407 m .42536 .53851 L .42686 .53992 L 0 .025 .123 r
F
.42431 .5407 m .42281 .53929 L .42536 .53851 L F
.4984 .54106 m .49956 .5389 L .50099 .54031 L 0 .026 .125 r
F
.4984 .54106 m .49697 .53964 L .49956 .5389 L F
.54206 .54102 m .54327 .53879 L .54467 .54028 L F
.54206 .54102 m .54066 .53956 L .54327 .53879 L F
.57911 .54127 m .58037 .53891 L .58173 .54048 L F
.57911 .54127 m .57774 .53972 L .58037 .53891 L F
.50501 .54099 m .50617 .53886 L .5076 .54028 L F
.50501 .54099 m .50358 .53958 L .50617 .53886 L F
.43091 .54063 m .43198 .53834 L .43346 .53983 L 0 .025 .123 r
F
.43091 .54063 m .42942 .53915 L .43198 .53834 L F
.46135 .5412 m .46246 .53893 L .46392 .54037 L 0 .026 .125 r
F
.46135 .5412 m .45988 .53974 L .46246 .53893 L F
.38725 .54084 m .38826 .53858 L .38978 .54009 L 0 .025 .124 r
F
.38725 .54084 m .38572 .53934 L .38826 .53858 L F
.3568 .54033 m .35777 .53814 L .35933 .53957 L 0 .024 .123 r
F
.3568 .54033 m .35525 .53889 L .35777 .53814 L F
.46796 .54098 m .46907 .5388 L .47053 .5402 L 0 .026 .125 r
F
.46796 .54098 m .4665 .53955 L .46907 .5388 L F
.54867 .54099 m .54989 .53872 L .55128 .54019 L F
.54867 .54099 m .54728 .53951 L .54989 .53872 L F
.43751 .5405 m .43859 .53815 L .44007 .53967 L 0 .025 .123 r
F
.43751 .5405 m .43603 .53899 L .43859 .53815 L F
.58572 .54126 m .58699 .53893 L .58835 .54046 L 0 .026 .126 r
F
.58572 .54126 m .58436 .5397 L .58699 .53893 L F
.51161 .54094 m .51279 .53873 L .51421 .5401 L 0 .026 .125 r
F
.51161 .54094 m .51019 .53957 L .51279 .53873 L F
.39385 .54078 m .39486 .53851 L .39638 .53998 L 0 .026 .124 r
F
.39385 .54078 m .39232 .5393 L .39486 .53851 L F
.3634 .54023 m .36438 .53792 L .36593 .53939 L 0 .024 .123 r
F
.3634 .54023 m .36185 .53877 L .36438 .53792 L F
.51822 .54061 m .51941 .53839 L .52082 .53976 L 0 .025 .124 r
F
.51822 .54061 m .51681 .53924 L .51941 .53839 L F
.47456 .54085 m .47568 .53866 L .47714 .54006 L 0 .026 .125 r
F
.47456 .54085 m .47311 .53944 L .47568 .53866 L F
.55528 .54086 m .55651 .53865 L .55789 .5401 L F
.55528 .54086 m .55389 .5394 L .55651 .53865 L F
.52483 .54037 m .52603 .53812 L .52743 .53954 L 0 .025 .123 r
F
.52483 .54037 m .52342 .53894 L .52603 .53812 L F
.37 .54003 m .37099 .53777 L .37253 .53928 L 0 .024 .123 r
F
.37 .54003 m .36846 .53854 L .37099 .53777 L F
.44411 .54041 m .4452 .5382 L .44667 .53968 L 0 .025 .124 r
F
.44411 .54041 m .44263 .53893 L .4452 .5382 L F
.40044 .5407 m .40146 .53862 L .40298 .54 L 0 .026 .125 r
F
.40044 .5407 m .39892 .53929 L .40146 .53862 L F
.56189 .54076 m .56313 .5386 L .56451 .53999 L F
.56189 .54076 m .56051 .53935 L .56313 .5386 L F
.48117 .54076 m .4823 .5385 L .48375 .53999 L F
.48117 .54076 m .47972 .53928 L .4823 .5385 L F
.53144 .54026 m .53264 .53802 L .53405 .53953 L 0 .025 .124 r
F
.53144 .54026 m .53004 .53877 L .53264 .53802 L F
.45071 .54041 m .4518 .53825 L .45328 .53971 L 0 .026 .124 r
F
.45071 .54041 m .44924 .53896 L .4518 .53825 L F
.37659 .54006 m .37759 .53781 L .37912 .53933 L 0 .025 .123 r
F
.37659 .54006 m .37506 .53855 L .37759 .53781 L F
.5685 .54061 m .56976 .53842 L .57113 .53984 L 0 .026 .125 r
F
.5685 .54061 m .56713 .53921 L .56976 .53842 L F
.40704 .54063 m .40808 .53841 L .40959 .53978 L F
.40704 .54063 m .40553 .53926 L .40808 .53841 L F
.48777 .54065 m .48892 .5383 L .49036 .53979 L F
.48777 .54065 m .48633 .53916 L .48892 .5383 L F
.41365 .54037 m .41469 .53811 L .4162 .53953 L 0 .025 .124 r
F
.41365 .54037 m .41214 .53893 L .41469 .53811 L F
.49438 .54039 m .49553 .53821 L .49697 .53964 L 0 .026 .125 r
F
.49438 .54039 m .49294 .53895 L .49553 .53821 L F
.42026 .54013 m .42131 .53789 L .42281 .53929 L 0 .025 .124 r
F
.42026 .54013 m .41875 .53871 L .42131 .53789 L F
.53805 .54033 m .53927 .53802 L .54066 .53956 L F
.53805 .54033 m .53666 .5388 L .53927 .53802 L F
.57512 .54053 m .57638 .53821 L .57774 .53972 L 0 .026 .125 r
F
.57512 .54053 m .57375 .53904 L .57638 .53821 L F
.38319 .54006 m .38419 .53784 L .38572 .53934 L 0 .025 .124 r
F
.38319 .54006 m .38165 .53858 L .38419 .53784 L F
.42686 .53992 m .42792 .53774 L .42942 .53915 L F
.42686 .53992 m .42536 .53851 L .42792 .53774 L F
.45731 .54049 m .45842 .53826 L .45988 .53974 L 0 .026 .125 r
F
.45731 .54049 m .45585 .53902 L .45842 .53826 L F
.50099 .54031 m .50215 .53816 L .50358 .53958 L F
.50099 .54031 m .49956 .5389 L .50215 .53816 L F
.35273 .53964 m .35369 .53745 L .35525 .53889 L 0 .024 .123 r
F
.35273 .53964 m .35117 .53819 L .35369 .53745 L F
.54467 .54028 m .54589 .53802 L .54728 .53951 L 0 .026 .125 r
F
.54467 .54028 m .54327 .53879 L .54589 .53802 L F
.58173 .54048 m .583 .53814 L .58436 .5397 L F
.58173 .54048 m .58037 .53891 L .583 .53814 L F
.46392 .54037 m .46503 .53812 L .4665 .53955 L F
.46392 .54037 m .46246 .53893 L .46503 .53812 L F
.43346 .53983 m .43454 .53748 L .43603 .53899 L 0 .025 .123 r
F
.43346 .53983 m .43198 .53834 L .43454 .53748 L F
.38978 .54009 m .3908 .53779 L .39232 .5393 L 0 .026 .124 r
F
.38978 .54009 m .38826 .53858 L .3908 .53779 L F
.5076 .54028 m .50877 .53814 L .51019 .53957 L 0 .026 .125 r
F
.5076 .54028 m .50617 .53886 L .50877 .53814 L F
.35933 .53957 m .36029 .53734 L .36185 .53877 L 0 .025 .123 r
F
.35933 .53957 m .35777 .53814 L .36029 .53734 L F
.55128 .54019 m .55251 .53793 L .55389 .5394 L 0 .026 .125 r
F
.55128 .54019 m .54989 .53872 L .55251 .53793 L F
.47053 .5402 m .47165 .53805 L .47311 .53944 L F
.47053 .5402 m .46907 .5388 L .47165 .53805 L F
.44007 .53967 m .44115 .5374 L .44263 .53893 L 0 .025 .123 r
F
.44007 .53967 m .43859 .53815 L .44115 .5374 L F
.58835 .54046 m .58963 .53816 L .59098 .53968 L 0 .027 .126 r
F
.58835 .54046 m .58699 .53893 L .58963 .53816 L F
.51421 .5401 m .51539 .53787 L .51681 .53924 L 0 .026 .125 r
F
.51421 .5401 m .51279 .53873 L .51539 .53787 L F
.36593 .53939 m .36691 .53707 L .36846 .53854 L 0 .024 .122 r
F
.36593 .53939 m .36438 .53792 L .36691 .53707 L F
.52082 .53976 m .52201 .53758 L .52342 .53894 L 0 .025 .124 r
F
.52082 .53976 m .51941 .53839 L .52201 .53758 L F
.39638 .53998 m .3974 .53782 L .39892 .53929 L 0 .026 .125 r
F
.39638 .53998 m .39486 .53851 L .3974 .53782 L F
.47714 .54006 m .47827 .53787 L .47972 .53928 L F
.47714 .54006 m .47568 .53866 L .47827 .53787 L F
.52743 .53954 m .52863 .53734 L .53004 .53877 L 0 .025 .123 r
F
.52743 .53954 m .52603 .53812 L .52863 .53734 L F
.55789 .5401 m .55913 .53791 L .56051 .53935 L 0 .026 .125 r
F
.55789 .5401 m .55651 .53865 L .55913 .53791 L F
.37253 .53928 m .37352 .53703 L .37506 .53855 L 0 .024 .123 r
F
.37253 .53928 m .37099 .53777 L .37352 .53703 L F
.44667 .53968 m .44776 .53748 L .44924 .53896 L 0 .025 .124 r
F
.44667 .53968 m .4452 .5382 L .44776 .53748 L F
.56451 .53999 m .56576 .5378 L .56713 .53921 L 0 .026 .125 r
F
.56451 .53999 m .56313 .5386 L .56576 .5378 L F
.48375 .53999 m .48489 .53766 L .48633 .53916 L F
.48375 .53999 m .4823 .5385 L .48489 .53766 L F
.40298 .54 m .40401 .53789 L .40553 .53926 L F
.40298 .54 m .40146 .53862 L .40401 .53789 L F
.53405 .53953 m .53525 .53728 L .53666 .5388 L 0 .025 .124 r
F
.53405 .53953 m .53264 .53802 L .53525 .53728 L F
.40959 .53978 m .41063 .53756 L .41214 .53893 L 0 .026 .125 r
F
.40959 .53978 m .40808 .53841 L .41063 .53756 L F
.49036 .53979 m .49151 .53745 L .49294 .53895 L F
.49036 .53979 m .48892 .5383 L .49151 .53745 L F
.57113 .53984 m .57238 .53762 L .57375 .53904 L F
.57113 .53984 m .56976 .53842 L .57238 .53762 L F
.37912 .53933 m .38012 .53705 L .38165 .53858 L 0 .025 .123 r
F
.37912 .53933 m .37759 .53781 L .38012 .53705 L F
.45328 .53971 m .45437 .53754 L .45585 .53902 L 0 .026 .125 r
F
.45328 .53971 m .4518 .53825 L .45437 .53754 L F
.4162 .53953 m .41725 .5373 L .41875 .53871 L 0 .025 .124 r
F
.4162 .53953 m .41469 .53811 L .41725 .5373 L F
.49697 .53964 m .49812 .53746 L .49956 .5389 L 0 .026 .125 r
F
.49697 .53964 m .49553 .53821 L .49812 .53746 L F
.42281 .53929 m .42386 .53711 L .42536 .53851 L 0 .025 .124 r
F
.42281 .53929 m .42131 .53789 L .42386 .53711 L F
.57774 .53972 m .57901 .53739 L .58037 .53891 L 0 .026 .125 r
F
.57774 .53972 m .57638 .53821 L .57901 .53739 L F
.54066 .53956 m .54188 .53723 L .54327 .53879 L 0 .026 .124 r
F
.54066 .53956 m .53927 .53802 L .54188 .53723 L F
.42942 .53915 m .43048 .53692 L .43198 .53834 L 0 .025 .124 r
F
.42942 .53915 m .42792 .53774 L .43048 .53692 L F
.38572 .53934 m .38673 .53707 L .38826 .53858 L F
.38572 .53934 m .38419 .53784 L .38673 .53707 L F
.45988 .53974 m .46099 .53744 L .46246 .53893 L 0 .026 .125 r
F
.45988 .53974 m .45842 .53826 L .46099 .53744 L F
.50358 .53958 m .50475 .53743 L .50617 .53886 L F
.50358 .53958 m .50215 .53816 L .50475 .53743 L F
.35525 .53889 m .35621 .5367 L .35777 .53814 L 0 .025 .123 r
F
.35525 .53889 m .35369 .53745 L .35621 .5367 L F
.54728 .53951 m .5485 .53723 L .54989 .53872 L 0 .026 .125 r
F
.54728 .53951 m .54589 .53802 L .5485 .53723 L F
.58436 .5397 m .58564 .53739 L .58699 .53893 L F
.58436 .5397 m .583 .53814 L .58564 .53739 L F
.43603 .53899 m .4371 .53662 L .43859 .53815 L 0 .025 .123 r
F
.43603 .53899 m .43454 .53748 L .4371 .53662 L F
.4665 .53955 m .46761 .53739 L .46907 .5388 L 0 .026 .125 r
F
.4665 .53955 m .46503 .53812 L .46761 .53739 L F
.39232 .5393 m .39334 .537 L .39486 .53851 L 0 .026 .124 r
F
.39232 .5393 m .3908 .53779 L .39334 .537 L F
.36185 .53877 m .36282 .53649 L .36438 .53792 L 0 .024 .123 r
F
.36185 .53877 m .36029 .53734 L .36282 .53649 L F
.51019 .53957 m .51137 .53729 L .51279 .53873 L 0 .026 .125 r
F
.51019 .53957 m .50877 .53814 L .51137 .53729 L F
.55389 .5394 m .55513 .53718 L .55651 .53865 L F
.55389 .5394 m .55251 .53793 L .55513 .53718 L F
.51681 .53924 m .51799 .53702 L .51941 .53839 L 0 .026 .124 r
F
.51681 .53924 m .51539 .53787 L .51799 .53702 L F
.47311 .53944 m .47423 .53729 L .47568 .53866 L 0 .026 .125 r
F
.47311 .53944 m .47165 .53805 L .47423 .53729 L F
.36846 .53854 m .36944 .5363 L .37099 .53777 L 0 .024 .122 r
F
.36846 .53854 m .36691 .53707 L .36944 .5363 L F
.44263 .53893 m .44372 .53668 L .4452 .5382 L 0 .025 .124 r
F
.44263 .53893 m .44115 .5374 L .44372 .53668 L F
.52342 .53894 m .52462 .53677 L .52603 .53812 L F
.52342 .53894 m .52201 .53758 L .52462 .53677 L F
.59098 .53968 m .59227 .53743 L .59362 .53894 L 0 .027 .126 r
F
.59098 .53968 m .58963 .53816 L .59227 .53743 L F
.47972 .53928 m .48085 .53708 L .4823 .5385 L 0 .026 .125 r
F
.47972 .53928 m .47827 .53787 L .48085 .53708 L F
.39892 .53929 m .39994 .53715 L .40146 .53862 L F
.39892 .53929 m .3974 .53782 L .39994 .53715 L F
.53004 .53877 m .53124 .53659 L .53264 .53802 L 0 .025 .124 r
F
.53004 .53877 m .52863 .53734 L .53124 .53659 L F
.56051 .53935 m .56176 .53716 L .56313 .5386 L 0 .026 .125 r
F
.56051 .53935 m .55913 .53791 L .56176 .53716 L F
.37506 .53855 m .37605 .53629 L .37759 .53781 L 0 .025 .123 r
F
.37506 .53855 m .37352 .53703 L .37605 .53629 L F
.44924 .53896 m .45033 .53675 L .4518 .53825 L 0 .026 .124 r
F
.44924 .53896 m .44776 .53748 L .45033 .53675 L F
.48633 .53916 m .48747 .5368 L .48892 .5383 L 0 .026 .125 r
F
.48633 .53916 m .48489 .53766 L .48747 .5368 L F
.56713 .53921 m .56838 .53701 L .56976 .53842 L F
.56713 .53921 m .56576 .5378 L .56838 .53701 L F
.40553 .53926 m .40656 .53703 L .40808 .53841 L F
.40553 .53926 m .40401 .53789 L .40656 .53703 L F
.41214 .53893 m .41318 .53674 L .41469 .53811 L F
.41214 .53893 m .41063 .53756 L .41318 .53674 L F
.49294 .53895 m .4941 .53672 L .49553 .53821 L F
.49294 .53895 m .49151 .53745 L .4941 .53672 L F
.53666 .5388 m .53787 .53648 L .53927 .53802 L 0 .025 .124 r
F
.53666 .5388 m .53525 .53728 L .53787 .53648 L F
.57375 .53904 m .57501 .53679 L .57638 .53821 L 0 .026 .125 r
F
.57375 .53904 m .57238 .53762 L .57501 .53679 L F
.41875 .53871 m .4198 .53649 L .42131 .53789 L 0 .025 .124 r
F
.41875 .53871 m .41725 .5373 L .4198 .53649 L F
.38165 .53858 m .38266 .5363 L .38419 .53784 L F
.38165 .53858 m .38012 .53705 L .38266 .5363 L F
.45585 .53902 m .45695 .53677 L .45842 .53826 L 0 .026 .125 r
F
.45585 .53902 m .45437 .53754 L .45695 .53677 L F
.42536 .53851 m .42642 .53633 L .42792 .53774 L 0 .025 .124 r
F
.42536 .53851 m .42386 .53711 L .42642 .53633 L F
.49956 .5389 m .50072 .53672 L .50215 .53816 L 0 .026 .125 r
F
.49956 .5389 m .49812 .53746 L .50072 .53672 L F
.58037 .53891 m .58164 .53664 L .583 .53814 L F
.58037 .53891 m .57901 .53739 L .58164 .53664 L F
.35117 .53819 m .35212 .53604 L .35369 .53745 L 0 .025 .123 r
F
.35117 .53819 m .3496 .53679 L .35212 .53604 L F
.54327 .53879 m .54449 .53646 L .54589 .53802 L 0 .026 .124 r
F
.54327 .53879 m .54188 .53723 L .54449 .53646 L F
.43198 .53834 m .43305 .53606 L .43454 .53748 L 0 .025 .123 r
F
.43198 .53834 m .43048 .53692 L .43305 .53606 L F
.46246 .53893 m .46357 .53663 L .46503 .53812 L 0 .026 .125 r
F
.46246 .53893 m .46099 .53744 L .46357 .53663 L F
.38826 .53858 m .38927 .53628 L .3908 .53779 L 0 .025 .124 r
F
.38826 .53858 m .38673 .53707 L .38927 .53628 L F
.50617 .53886 m .50734 .5367 L .50877 .53814 L 0 .026 .125 r
F
.50617 .53886 m .50475 .53743 L .50734 .5367 L F
.35777 .53814 m .35874 .53591 L .36029 .53734 L 0 .025 .123 r
F
.35777 .53814 m .35621 .5367 L .35874 .53591 L F
.43859 .53815 m .43967 .53587 L .44115 .5374 L F
.43859 .53815 m .4371 .53662 L .43967 .53587 L F
.54989 .53872 m .55112 .53645 L .55251 .53793 L 0 .026 .125 r
F
.54989 .53872 m .5485 .53723 L .55112 .53645 L F
.58699 .53893 m .58827 .53664 L .58963 .53816 L F
.58699 .53893 m .58564 .53739 L .58827 .53664 L F
.46907 .5388 m .47019 .53666 L .47165 .53805 L F
.46907 .5388 m .46761 .53739 L .47019 .53666 L F
.36438 .53792 m .36536 .53563 L .36691 .53707 L 0 .024 .123 r
F
.36438 .53792 m .36282 .53649 L .36536 .53563 L F
.39486 .53851 m .39588 .53631 L .3974 .53782 L 0 .026 .125 r
F
.39486 .53851 m .39334 .537 L .39588 .53631 L F
.51279 .53873 m .51397 .53642 L .51539 .53787 L F
.51279 .53873 m .51137 .53729 L .51397 .53642 L F
.51941 .53839 m .5206 .53622 L .52201 .53758 L 0 .026 .124 r
F
.51941 .53839 m .51799 .53702 L .5206 .53622 L F
.55651 .53865 m .55775 .53645 L .55913 .53791 L 0 .026 .125 r
F
.55651 .53865 m .55513 .53718 L .55775 .53645 L F
.47568 .53866 m .47681 .53649 L .47827 .53787 L F
.47568 .53866 m .47423 .53729 L .47681 .53649 L F
.52603 .53812 m .52722 .53598 L .52863 .53734 L 0 .025 .124 r
F
.52603 .53812 m .52462 .53677 L .52722 .53598 L F
.37099 .53777 m .37197 .53555 L .37352 .53703 L 0 .024 .123 r
F
.37099 .53777 m .36944 .5363 L .37197 .53555 L F
.4452 .5382 m .44628 .53595 L .44776 .53748 L 0 .025 .124 r
F
.4452 .5382 m .44372 .53668 L .44628 .53595 L F
.59362 .53894 m .59491 .5367 L .59626 .5382 L 0 .027 .126 r
F
.59362 .53894 m .59227 .53743 L .59491 .5367 L F
.4823 .5385 m .48344 .53624 L .48489 .53766 L 0 .026 .125 r
F
.4823 .5385 m .48085 .53708 L .48344 .53624 L F
.53264 .53802 m .53385 .53583 L .53525 .53728 L 0 .025 .124 r
F
.53264 .53802 m .53124 .53659 L .53385 .53583 L F
.56313 .5386 m .56438 .53635 L .56576 .5378 L 0 .026 .125 r
F
.56313 .5386 m .56176 .53716 L .56438 .53635 L F
.40146 .53862 m .40249 .53642 L .40401 .53789 L 0 .026 .126 r
F
.40146 .53862 m .39994 .53715 L .40249 .53642 L F
.48892 .5383 m .49006 .53595 L .49151 .53745 L 0 .026 .124 r
F
.48892 .5383 m .48747 .5368 L .49006 .53595 L F
.37759 .53781 m .37858 .53552 L .38012 .53705 L 0 .025 .123 r
F
.37759 .53781 m .37605 .53629 L .37858 .53552 L F
.40808 .53841 m .40911 .53618 L .41063 .53756 L 0 .026 .125 r
F
.40808 .53841 m .40656 .53703 L .40911 .53618 L F
.56976 .53842 m .57101 .5362 L .57238 .53762 L F
.56976 .53842 m .56838 .53701 L .57101 .5362 L F
.4518 .53825 m .4529 .53603 L .45437 .53754 L F
.4518 .53825 m .45033 .53675 L .4529 .53603 L F
.41469 .53811 m .41574 .53594 L .41725 .5373 L 0 .026 .124 r
F
.41469 .53811 m .41318 .53674 L .41574 .53594 L F
.53927 .53802 m .54048 .53567 L .54188 .53723 L 0 .025 .124 r
F
.53927 .53802 m .53787 .53648 L .54048 .53567 L F
.49553 .53821 m .49669 .53599 L .49812 .53746 L 0 .026 .125 r
F
.49553 .53821 m .4941 .53672 L .49669 .53599 L F
.57638 .53821 m .57764 .53596 L .57901 .53739 L F
.57638 .53821 m .57501 .53679 L .57764 .53596 L F
.42131 .53789 m .42236 .53571 L .42386 .53711 L 0 .025 .124 r
F
.42131 .53789 m .4198 .53649 L .42236 .53571 L F
.38419 .53784 m .3852 .53553 L .38673 .53707 L F
.38419 .53784 m .38266 .5363 L .3852 .53553 L F
.45842 .53826 m .45952 .53595 L .46099 .53744 L 0 .026 .125 r
F
.45842 .53826 m .45695 .53677 L .45952 .53595 L F
.42792 .53774 m .42898 .53552 L .43048 .53692 L 0 .025 .124 r
F
.42792 .53774 m .42642 .53633 L .42898 .53552 L F
.583 .53814 m .58428 .5359 L .58564 .53739 L 0 .026 .125 r
F
.583 .53814 m .58164 .53664 L .58428 .5359 L F
.50215 .53816 m .50331 .53599 L .50475 .53743 L F
.50215 .53816 m .50072 .53672 L .50331 .53599 L F
.35369 .53745 m .35465 .5353 L .35621 .5367 L 0 .025 .123 r
F
.35369 .53745 m .35212 .53604 L .35465 .5353 L F
.54589 .53802 m .54711 .53569 L .5485 .53723 L 0 .026 .125 r
F
.54589 .53802 m .54449 .53646 L .54711 .53569 L F
.43454 .53748 m .43561 .5352 L .4371 .53662 L 0 .025 .123 r
F
.43454 .53748 m .43305 .53606 L .43561 .5352 L F
.46503 .53812 m .46615 .5359 L .46761 .53739 L 0 .026 .125 r
F
.46503 .53812 m .46357 .53663 L .46615 .5359 L F
.3908 .53779 m .39181 .53549 L .39334 .537 L 0 .025 .124 r
F
.3908 .53779 m .38927 .53628 L .39181 .53549 L F
.36029 .53734 m .36127 .53506 L .36282 .53649 L 0 .025 .123 r
F
.36029 .53734 m .35874 .53591 L .36127 .53506 L F
.55251 .53793 m .55374 .53571 L .55513 .53718 L 0 .026 .125 r
F
.55251 .53793 m .55112 .53645 L .55374 .53571 L F
.44115 .5374 m .44223 .53515 L .44372 .53668 L 0 .025 .123 r
F
.44115 .5374 m .43967 .53587 L .44223 .53515 L F
.50877 .53814 m .50994 .53584 L .51137 .53729 L 0 .026 .125 r
F
.50877 .53814 m .50734 .5367 L .50994 .53584 L F
.58963 .53816 m .59091 .53591 L .59227 .53743 L 0 .026 .126 r
F
.58963 .53816 m .58827 .53664 L .59091 .53591 L F
.36691 .53707 m .36789 .53487 L .36944 .5363 L 0 .024 .123 r
F
.36691 .53707 m .36536 .53563 L .36789 .53487 L F
.51539 .53787 m .51657 .53557 L .51799 .53702 L 0 .026 .125 r
F
.51539 .53787 m .51397 .53642 L .51657 .53557 L F
.47165 .53805 m .47277 .53591 L .47423 .53729 L 0 .026 .126 r
F
.47165 .53805 m .47019 .53666 L .47277 .53591 L F
.52201 .53758 m .5232 .53541 L .52462 .53677 L 0 .026 .124 r
F
.52201 .53758 m .5206 .53622 L .5232 .53541 L F
.3974 .53782 m .39842 .53562 L .39994 .53715 L 0 .026 .125 r
F
.3974 .53782 m .39588 .53631 L .39842 .53562 L F
.47827 .53787 m .4794 .5357 L .48085 .53708 L F
.47827 .53787 m .47681 .53649 L .4794 .5357 L F
.52863 .53734 m .52983 .53521 L .53124 .53659 L 0 .025 .124 r
F
.52863 .53734 m .52722 .53598 L .52983 .53521 L F
.55913 .53791 m .56038 .5357 L .56176 .53716 L 0 .026 .125 r
F
.55913 .53791 m .55775 .53645 L .56038 .5357 L F
.37352 .53703 m .37451 .5348 L .37605 .53629 L 0 .024 .123 r
F
.37352 .53703 m .37197 .53555 L .37451 .5348 L F
.59626 .5382 m .59755 .53588 L .5989 .53739 L 0 .027 .126 r
F
.59626 .5382 m .59491 .5367 L .59755 .53588 L F
.48489 .53766 m .48603 .53538 L .48747 .5368 L 0 .026 .125 r
F
.48489 .53766 m .48344 .53624 L .48603 .53538 L F
.44776 .53748 m .44885 .53521 L .45033 .53675 L 0 .025 .124 r
F
.44776 .53748 m .44628 .53595 L .44885 .53521 L F
.56576 .5378 m .56701 .53554 L .56838 .53701 L 0 .026 .125 r
F
.56576 .5378 m .56438 .53635 L .56701 .53554 L F
.49151 .53745 m .49266 .53524 L .4941 .53672 L 0 .026 .124 r
F
.49151 .53745 m .49006 .53595 L .49266 .53524 L F
.53525 .53728 m .53646 .53501 L .53787 .53648 L 0 .025 .124 r
F
.53525 .53728 m .53385 .53583 L .53646 .53501 L F
.40401 .53789 m .40504 .53556 L .40656 .53703 L 0 .026 .126 r
F
.40401 .53789 m .40249 .53642 L .40504 .53556 L F
.41063 .53756 m .41167 .53536 L .41318 .53674 L 0 .026 .125 r
F
.41063 .53756 m .40911 .53618 L .41167 .53536 L F
.38012 .53705 m .38112 .53475 L .38266 .5363 L 0 .025 .123 r
F
.38012 .53705 m .37858 .53552 L .38112 .53475 L F
.57238 .53762 m .57364 .53536 L .57501 .53679 L 0 .026 .125 r
F
.57238 .53762 m .57101 .5362 L .57364 .53536 L F
.41725 .5373 m .41829 .53513 L .4198 .53649 L 0 .026 .124 r
F
.41725 .5373 m .41574 .53594 L .41829 .53513 L F
.45437 .53754 m .45548 .53525 L .45695 .53677 L 0 .026 .125 r
F
.45437 .53754 m .4529 .53603 L .45548 .53525 L F
.57901 .53739 m .58028 .53522 L .58164 .53664 L F
.57901 .53739 m .57764 .53596 L .58028 .53522 L F
.54188 .53723 m .5431 .53489 L .54449 .53646 L 0 .025 .124 r
F
.54188 .53723 m .54048 .53567 L .5431 .53489 L F
.49812 .53746 m .49928 .53525 L .50072 .53672 L 0 .026 .125 r
F
.49812 .53746 m .49669 .53599 L .49928 .53525 L F
.42386 .53711 m .42492 .53493 L .42642 .53633 L 0 .025 .124 r
F
.42386 .53711 m .42236 .53571 L .42492 .53493 L F
.3496 .53679 m .35055 .53466 L .35212 .53604 L 0 .025 .123 r
F
.3496 .53679 m .34803 .53541 L .35055 .53466 L F
.38673 .53707 m .38774 .53475 L .38927 .53628 L 0 .025 .124 r
F
.38673 .53707 m .3852 .53553 L .38774 .53475 L F
.46099 .53744 m .4621 .53513 L .46357 .53663 L 0 .026 .125 r
F
.46099 .53744 m .45952 .53595 L .4621 .53513 L F
.43048 .53692 m .43155 .53466 L .43305 .53606 L 0 .025 .124 r
F
.43048 .53692 m .42898 .53552 L .43155 .53466 L F
.4371 .53662 m .43818 .53445 L .43967 .53587 L 0 .025 .123 r
F
.4371 .53662 m .43561 .5352 L .43818 .53445 L F
.58564 .53739 m .58691 .53516 L .58827 .53664 L 0 .026 .125 r
F
.58564 .53739 m .58428 .5359 L .58691 .53516 L F
.5485 .53723 m .54973 .53492 L .55112 .53645 L F
.5485 .53723 m .54711 .53569 L .54973 .53492 L F
.50475 .53743 m .50591 .53525 L .50734 .5367 L 0 .026 .126 r
F
.50475 .53743 m .50331 .53599 L .50591 .53525 L F
.35621 .5367 m .35717 .5345 L .35874 .53591 L 0 .025 .123 r
F
.35621 .5367 m .35465 .5353 L .35717 .5345 L F
.39334 .537 m .39435 .53479 L .39588 .53631 L 0 .026 .124 r
F
.39334 .537 m .39181 .53549 L .39435 .53479 L F
.46761 .53739 m .46873 .53517 L .47019 .53666 L 0 .026 .126 r
F
.46761 .53739 m .46615 .5359 L .46873 .53517 L F
.36282 .53649 m .3638 .5342 L .36536 .53563 L 0 .024 .123 r
F
.36282 .53649 m .36127 .53506 L .3638 .5342 L F
.51137 .53729 m .51255 .53497 L .51397 .53642 L 0 .026 .125 r
F
.51137 .53729 m .50994 .53584 L .51255 .53497 L F
.55513 .53718 m .55637 .53499 L .55775 .53645 L F
.55513 .53718 m .55374 .53571 L .55637 .53499 L F
.51799 .53702 m .51918 .53477 L .5206 .53622 L F
.51799 .53702 m .51657 .53557 L .51918 .53477 L F
.36944 .5363 m .37042 .53414 L .37197 .53555 L 0 .024 .123 r
F
.36944 .5363 m .36789 .53487 L .37042 .53414 L F
.44372 .53668 m .4448 .53442 L .44628 .53595 L 0 .025 .124 r
F
.44372 .53668 m .44223 .53515 L .4448 .53442 L F
.59227 .53743 m .59356 .53519 L .59491 .5367 L 0 .027 .126 r
F
.59227 .53743 m .59091 .53591 L .59356 .53519 L F
.47423 .53729 m .47536 .53511 L .47681 .53649 L F
.47423 .53729 m .47277 .53591 L .47536 .53511 L F
.52462 .53677 m .52581 .53462 L .52722 .53598 L 0 .026 .124 r
F
.52462 .53677 m .5232 .53541 L .52581 .53462 L F
.48085 .53708 m .48199 .53486 L .48344 .53624 L 0 .026 .125 r
F
.48085 .53708 m .4794 .5357 L .48199 .53486 L F
.53124 .53659 m .53245 .53444 L .53385 .53583 L 0 .025 .124 r
F
.53124 .53659 m .52983 .53521 L .53245 .53444 L F
.39994 .53715 m .40097 .53489 L .40249 .53642 L 0 .026 .125 r
F
.39994 .53715 m .39842 .53562 L .40097 .53489 L F
.56176 .53716 m .563 .53488 L .56438 .53635 L F
.56176 .53716 m .56038 .5357 L .563 .53488 L F
.48747 .5368 m .48862 .53454 L .49006 .53595 L 0 .026 .124 r
F
.48747 .5368 m .48603 .53538 L .48862 .53454 L F
.5989 .53739 m .60019 .53503 L .60154 .53655 L 0 .027 .126 r
F
.5989 .53739 m .59755 .53588 L .60019 .53503 L F
.37605 .53629 m .37704 .53402 L .37858 .53552 L 0 .025 .123 r
F
.37605 .53629 m .37451 .5348 L .37704 .53402 L F
.45033 .53675 m .45143 .53447 L .4529 .53603 L 0 .026 .124 r
F
.45033 .53675 m .44885 .53521 L .45143 .53447 L F
.56838 .53701 m .56964 .53471 L .57101 .5362 L 0 .026 .125 r
F
.56838 .53701 m .56701 .53554 L .56964 .53471 L F
.53787 .53648 m .53908 .53419 L .54048 .53567 L 0 .025 .124 r
F
.53787 .53648 m .53646 .53501 L .53908 .53419 L F
.40656 .53703 m .4076 .53471 L .40911 .53618 L 0 .026 .125 r
F
.40656 .53703 m .40504 .53556 L .4076 .53471 L F
.4941 .53672 m .49525 .53452 L .49669 .53599 L F
.4941 .53672 m .49266 .53524 L .49525 .53452 L F
.41318 .53674 m .41422 .53457 L .41574 .53594 L F
.41318 .53674 m .41167 .53536 L .41422 .53457 L F
.57501 .53679 m .57628 .53453 L .57764 .53596 L F
.57501 .53679 m .57364 .53536 L .57628 .53453 L F
.38266 .5363 m .38366 .53398 L .3852 .53553 L 0 .025 .123 r
F
.38266 .5363 m .38112 .53475 L .38366 .53398 L F
.4198 .53649 m .42085 .53434 L .42236 .53571 L 0 .026 .124 r
F
.4198 .53649 m .41829 .53513 L .42085 .53434 L F
.45695 .53677 m .45805 .53444 L .45952 .53595 L 0 .026 .125 r
F
.45695 .53677 m .45548 .53525 L .45805 .53444 L F
.58164 .53664 m .58292 .53449 L .58428 .5359 L F
.58164 .53664 m .58028 .53522 L .58292 .53449 L F
.54449 .53646 m .54572 .53415 L .54711 .53569 L 0 .025 .124 r
F
.54449 .53646 m .5431 .53489 L .54572 .53415 L F
.42642 .53633 m .42748 .53412 L .42898 .53552 L F
.42642 .53633 m .42492 .53493 L .42748 .53412 L F
.50072 .53672 m .50188 .53451 L .50331 .53599 L 0 .026 .125 r
F
.50072 .53672 m .49928 .53525 L .50188 .53451 L F
.35212 .53604 m .35308 .5339 L .35465 .5353 L 0 .025 .124 r
F
.35212 .53604 m .35055 .53466 L .35308 .5339 L F
.43305 .53606 m .43412 .53379 L .43561 .5352 L 0 .025 .123 r
F
.43305 .53606 m .43155 .53466 L .43412 .53379 L F
.46357 .53663 m .46468 .5344 L .46615 .5359 L 0 .026 .125 r
F
.46357 .53663 m .4621 .53513 L .46468 .5344 L F
.38927 .53628 m .39028 .53396 L .39181 .53549 L 0 .025 .124 r
F
.38927 .53628 m .38774 .53475 L .39028 .53396 L F
.43967 .53587 m .44075 .53373 L .44223 .53515 L 0 .025 .123 r
F
.43967 .53587 m .43818 .53445 L .44075 .53373 L F
.55112 .53645 m .55235 .5342 L .55374 .53571 L 0 .026 .125 r
F
.55112 .53645 m .54973 .53492 L .55235 .5342 L F
.58827 .53664 m .58956 .53444 L .59091 .53591 L F
.58827 .53664 m .58691 .53516 L .58956 .53444 L F
.35874 .53591 m .35971 .53364 L .36127 .53506 L 0 .025 .123 r
F
.35874 .53591 m .35717 .5345 L .35971 .53364 L F
.50734 .5367 m .50852 .53439 L .50994 .53584 L 0 .026 .126 r
F
.50734 .5367 m .50591 .53525 L .50852 .53439 L F
.36536 .53563 m .36634 .53344 L .36789 .53487 L 0 .024 .123 r
F
.36536 .53563 m .3638 .5342 L .36634 .53344 L F
.51397 .53642 m .51515 .53411 L .51657 .53557 L 0 .026 .125 r
F
.51397 .53642 m .51255 .53497 L .51515 .53411 L F
.47019 .53666 m .47131 .53442 L .47277 .53591 L 0 .027 .126 r
F
.47019 .53666 m .46873 .53517 L .47131 .53442 L F
.39588 .53631 m .3969 .53409 L .39842 .53562 L 0 .026 .125 r
F
.39588 .53631 m .39435 .53479 L .3969 .53409 L F
.5206 .53622 m .52179 .53397 L .5232 .53541 L F
.5206 .53622 m .51918 .53477 L .52179 .53397 L F
.55775 .53645 m .55899 .53424 L .56038 .5357 L F
.55775 .53645 m .55637 .53499 L .55899 .53424 L F
.37197 .53555 m .37296 .5334 L .37451 .5348 L 0 .025 .123 r
F
.37197 .53555 m .37042 .53414 L .37296 .5334 L F
.47681 .53649 m .47794 .5343 L .4794 .5357 L 0 .027 .126 r
F
.47681 .53649 m .47536 .53511 L .47794 .5343 L F
.44628 .53595 m .44737 .53366 L .44885 .53521 L 0 .025 .124 r
F
.44628 .53595 m .4448 .53442 L .44737 .53366 L F
.59491 .5367 m .5962 .53437 L .59755 .53588 L 0 .027 .126 r
F
.59491 .5367 m .59356 .53519 L .5962 .53437 L F
.52722 .53598 m .52842 .53384 L .52983 .53521 L 0 .026 .124 r
F
.52722 .53598 m .52581 .53462 L .52842 .53384 L F
.48344 .53624 m .48458 .53401 L .48603 .53538 L 0 .026 .125 r
F
.48344 .53624 m .48199 .53486 L .48458 .53401 L F
.49006 .53595 m .49121 .53383 L .49266 .53524 L F
.49006 .53595 m .48862 .53454 L .49121 .53383 L F
.56438 .53635 m .56563 .53405 L .56701 .53554 L F
.56438 .53635 m .563 .53488 L .56563 .53405 L F
.60154 .53655 m .60284 .53418 L .60418 .5357 L 0 .027 .126 r
F
.60154 .53655 m .60019 .53503 L .60284 .53418 L F
.53385 .53583 m .53506 .53361 L .53646 .53501 L 0 .025 .124 r
F
.53385 .53583 m .53245 .53444 L .53506 .53361 L F
.40249 .53642 m .40352 .53403 L .40504 .53556 L 0 .026 .125 r
F
.40249 .53642 m .40097 .53489 L .40352 .53403 L F
.37858 .53552 m .37958 .53324 L .38112 .53475 L 0 .025 .123 r
F
.37858 .53552 m .37704 .53402 L .37958 .53324 L F
.40911 .53618 m .41015 .5339 L .41167 .53536 L 0 .026 .125 r
F
.40911 .53618 m .4076 .53471 L .41015 .5339 L F
.57101 .5362 m .57227 .53387 L .57364 .53536 L F
.57101 .5362 m .56964 .53471 L .57227 .53387 L F
.4529 .53603 m .454 .53369 L .45548 .53525 L F
.4529 .53603 m .45143 .53447 L .454 .53369 L F
.54048 .53567 m .5417 .53341 L .5431 .53489 L 0 .025 .124 r
F
.54048 .53567 m .53908 .53419 L .5417 .53341 L F
.41574 .53594 m .41678 .53377 L .41829 .53513 L 0 .026 .125 r
F
.41574 .53594 m .41422 .53457 L .41678 .53377 L F
.57764 .53596 m .57891 .5338 L .58028 .53522 L F
.57764 .53596 m .57628 .53453 L .57891 .5338 L F
.49669 .53599 m .49785 .53378 L .49928 .53525 L F
.49669 .53599 m .49525 .53452 L .49785 .53378 L F
.3852 .53553 m .38621 .53321 L .38774 .53475 L 0 .025 .124 r
F
.3852 .53553 m .38366 .53398 L .38621 .53321 L F
.42236 .53571 m .42342 .53355 L .42492 .53493 L 0 .026 .124 r
F
.42236 .53571 m .42085 .53434 L .42342 .53355 L F
.45952 .53595 m .46063 .53362 L .4621 .53513 L 0 .026 .125 r
F
.45952 .53595 m .45805 .53444 L .46063 .53362 L F
.34803 .53541 m .34898 .53325 L .35055 .53466 L 0 .025 .124 r
F
.34803 .53541 m .34646 .53401 L .34898 .53325 L F
.54711 .53569 m .54834 .5334 L .54973 .53492 L 0 .026 .124 r
F
.54711 .53569 m .54572 .53415 L .54834 .5334 L F
.42898 .53552 m .43005 .53325 L .43155 .53466 L 0 .025 .124 r
F
.42898 .53552 m .42748 .53412 L .43005 .53325 L F
.58428 .5359 m .58556 .53376 L .58691 .53516 L 0 .026 .125 r
F
.58428 .5359 m .58292 .53449 L .58556 .53376 L F
.43561 .5352 m .43668 .53305 L .43818 .53445 L 0 .025 .123 r
F
.43561 .5352 m .43412 .53379 L .43668 .53305 L F
.50331 .53599 m .50448 .53376 L .50591 .53525 L 0 .026 .126 r
F
.50331 .53599 m .50188 .53451 L .50448 .53376 L F
.35465 .5353 m .35561 .53311 L .35717 .5345 L 0 .025 .124 r
F
.35465 .5353 m .35308 .5339 L .35561 .53311 L F
.39181 .53549 m .39283 .53326 L .39435 .53479 L F
.39181 .53549 m .39028 .53396 L .39283 .53326 L F
.46615 .5359 m .46726 .53368 L .46873 .53517 L 0 .026 .125 r
F
.46615 .5359 m .46468 .5344 L .46726 .53368 L F
.36127 .53506 m .36224 .53278 L .3638 .5342 L 0 .025 .123 r
F
.36127 .53506 m .35971 .53364 L .36224 .53278 L F
.50994 .53584 m .51112 .53351 L .51255 .53497 L 0 .026 .125 r
F
.50994 .53584 m .50852 .53439 L .51112 .53351 L F
.44223 .53515 m .44332 .53299 L .4448 .53442 L 0 .025 .124 r
F
.44223 .53515 m .44075 .53373 L .44332 .53299 L F
.55374 .53571 m .55498 .53349 L .55637 .53499 L 0 .026 .125 r
F
.55374 .53571 m .55235 .5342 L .55498 .53349 L F
.59091 .53591 m .5922 .53373 L .59356 .53519 L 0 .027 .126 r
F
.59091 .53591 m .58956 .53444 L .5922 .53373 L F
.51657 .53557 m .51776 .53331 L .51918 .53477 L 0 .026 .125 r
F
.51657 .53557 m .51515 .53411 L .51776 .53331 L F
.36789 .53487 m .36887 .53272 L .37042 .53414 L 0 .025 .123 r
F
.36789 .53487 m .36634 .53344 L .36887 .53272 L F
.47277 .53591 m .4739 .5336 L .47536 .53511 L 0 .027 .126 r
F
.47277 .53591 m .47131 .53442 L .4739 .5336 L F
.5232 .53541 m .5244 .53317 L .52581 .53462 L 0 .026 .125 r
F
.5232 .53541 m .52179 .53397 L .5244 .53317 L F
.39842 .53562 m .39945 .53335 L .40097 .53489 L F
.39842 .53562 m .3969 .53409 L .39945 .53335 L F
.4794 .5357 m .48053 .53347 L .48199 .53486 L 0 .026 .126 r
F
.4794 .5357 m .47794 .5343 L .48053 .53347 L F
.59755 .53588 m .59884 .53351 L .60019 .53503 L 0 .027 .126 r
F
.59755 .53588 m .5962 .53437 L .59884 .53351 L F
.56038 .5357 m .56162 .5334 L .563 .53488 L 0 .026 .125 r
F
.56038 .5357 m .55899 .53424 L .56162 .5334 L F
.37451 .5348 m .3755 .53261 L .37704 .53402 L 0 .025 .123 r
F
.37451 .5348 m .37296 .5334 L .3755 .53261 L F
.48603 .53538 m .48717 .53317 L .48862 .53454 L 0 .026 .125 r
F
.48603 .53538 m .48458 .53401 L .48717 .53317 L F
.44885 .53521 m .44995 .5329 L .45143 .53447 L 0 .025 .124 r
F
.44885 .53521 m .44737 .53366 L .44995 .5329 L F
.52983 .53521 m .53104 .53306 L .53245 .53444 L 0 .026 .124 r
F
.52983 .53521 m .52842 .53384 L .53104 .53306 L F
.60418 .5357 m .60549 .53331 L .60683 .53483 L 0 .026 .126 r
F
.60418 .5357 m .60284 .53418 L .60549 .53331 L F
.56701 .53554 m .56826 .5332 L .56964 .53471 L 0 .026 .125 r
F
.56701 .53554 m .56563 .53405 L .56826 .5332 L F
.53646 .53501 m .53768 .53278 L .53908 .53419 L 0 .025 .124 r
F
.53646 .53501 m .53506 .53361 L .53768 .53278 L F
.40504 .53556 m .40608 .53318 L .4076 .53471 L 0 .026 .125 r
F
.40504 .53556 m .40352 .53403 L .40608 .53318 L F
.49266 .53524 m .49381 .53311 L .49525 .53452 L F
.49266 .53524 m .49121 .53383 L .49381 .53311 L F
.38112 .53475 m .38213 .53247 L .38366 .53398 L 0 .025 .123 r
F
.38112 .53475 m .37958 .53324 L .38213 .53247 L F
.57364 .53536 m .5749 .53302 L .57628 .53453 L 0 .026 .125 r
F
.57364 .53536 m .57227 .53387 L .5749 .53302 L F
.41167 .53536 m .41271 .53312 L .41422 .53457 L F
.41167 .53536 m .41015 .5339 L .41271 .53312 L F
.45548 .53525 m .45658 .53289 L .45805 .53444 L F
.45548 .53525 m .454 .53369 L .45658 .53289 L F
.5431 .53489 m .54432 .53267 L .54572 .53415 L 0 .025 .124 r
F
.5431 .53489 m .5417 .53341 L .54432 .53267 L F
.41829 .53513 m .41934 .53297 L .42085 .53434 L 0 .026 .125 r
F
.41829 .53513 m .41678 .53377 L .41934 .53297 L F
.58028 .53522 m .58155 .53308 L .58292 .53449 L F
.58028 .53522 m .57891 .5338 L .58155 .53308 L F
.49928 .53525 m .50045 .53303 L .50188 .53451 L F
.49928 .53525 m .49785 .53378 L .50045 .53303 L F
.38774 .53475 m .38875 .53243 L .39028 .53396 L 0 .025 .124 r
F
.38774 .53475 m .38621 .53321 L .38875 .53243 L F
.42492 .53493 m .42598 .53272 L .42748 .53412 L 0 .026 .124 r
F
.42492 .53493 m .42342 .53355 L .42598 .53272 L F
.4621 .53513 m .46321 .5329 L .46468 .5344 L 0 .026 .125 r
F
.4621 .53513 m .46063 .53362 L .46321 .5329 L F
.35055 .53466 m .35151 .53249 L .35308 .5339 L 0 .025 .124 r
F
.35055 .53466 m .34898 .53325 L .35151 .53249 L F
.43155 .53466 m .43262 .53239 L .43412 .53379 L F
.43155 .53466 m .43005 .53325 L .43262 .53239 L F
.54973 .53492 m .55096 .53269 L .55235 .5342 L 0 .026 .125 r
F
.54973 .53492 m .54834 .5334 L .55096 .53269 L F
.58691 .53516 m .5882 .53305 L .58956 .53444 L 0 .027 .126 r
F
.58691 .53516 m .58556 .53376 L .5882 .53305 L F
.43818 .53445 m .43925 .53233 L .44075 .53373 L 0 .025 .124 r
F
.43818 .53445 m .43668 .53305 L .43925 .53233 L F
.35717 .5345 m .35814 .53224 L .35971 .53364 L F
.35717 .5345 m .35561 .53311 L .35814 .53224 L F
.50591 .53525 m .50709 .53293 L .50852 .53439 L 0 .026 .126 r
F
.50591 .53525 m .50448 .53376 L .50709 .53293 L F
.3638 .5342 m .36478 .53202 L .36634 .53344 L 0 .025 .123 r
F
.3638 .5342 m .36224 .53278 L .36478 .53202 L F
.51255 .53497 m .51373 .53266 L .51515 .53411 L 0 .026 .125 r
F
.51255 .53497 m .51112 .53351 L .51373 .53266 L F
.39435 .53479 m .39537 .53256 L .3969 .53409 L F
.39435 .53479 m .39283 .53326 L .39537 .53256 L F
.46873 .53517 m .46985 .53292 L .47131 .53442 L 0 .027 .126 r
F
.46873 .53517 m .46726 .53368 L .46985 .53292 L F
.51918 .53477 m .52037 .53252 L .52179 .53397 L 0 .026 .125 r
F
.51918 .53477 m .51776 .53331 L .52037 .53252 L F
.4448 .53442 m .44589 .53223 L .44737 .53366 L 0 .025 .124 r
F
.4448 .53442 m .44332 .53299 L .44589 .53223 L F
.55637 .53499 m .55761 .53275 L .55899 .53424 L 0 .026 .125 r
F
.55637 .53499 m .55498 .53349 L .55761 .53275 L F
.59356 .53519 m .59485 .53291 L .5962 .53437 L 0 .027 .126 r
F
.59356 .53519 m .5922 .53373 L .59485 .53291 L F
.37042 .53414 m .3714 .53199 L .37296 .5334 L 0 .025 .123 r
F
.37042 .53414 m .36887 .53272 L .3714 .53199 L F
.47536 .53511 m .47649 .53278 L .47794 .5343 L 0 .027 .126 r
F
.47536 .53511 m .4739 .5336 L .47649 .53278 L F
.52581 .53462 m .52701 .53237 L .52842 .53384 L 0 .026 .125 r
F
.52581 .53462 m .5244 .53317 L .52701 .53237 L F
.60019 .53503 m .60149 .53265 L .60284 .53418 L 0 .026 .126 r
F
.60019 .53503 m .59884 .53351 L .60149 .53265 L F
.48199 .53486 m .48313 .53262 L .48458 .53401 L 0 .026 .125 r
F
.48199 .53486 m .48053 .53347 L .48313 .53262 L F
.563 .53488 m .56425 .53255 L .56563 .53405 L F
.563 .53488 m .56162 .5334 L .56425 .53255 L F
.40097 .53489 m .402 .53249 L .40352 .53403 L F
.40097 .53489 m .39945 .53335 L .402 .53249 L F
.48862 .53454 m .48977 .53245 L .49121 .53383 L F
.48862 .53454 m .48717 .53317 L .48977 .53245 L F
.37704 .53402 m .37804 .53182 L .37958 .53324 L 0 .025 .123 r
F
.37704 .53402 m .3755 .53261 L .37804 .53182 L F
.53245 .53444 m .53365 .53221 L .53506 .53361 L 0 .026 .124 r
F
.53245 .53444 m .53104 .53306 L .53365 .53221 L F
.60683 .53483 m .60814 .53244 L .60948 .53396 L 0 .026 .125 r
F
.60683 .53483 m .60549 .53331 L .60814 .53244 L F
.45143 .53447 m .45253 .53213 L .454 .53369 L 0 .026 .124 r
F
.45143 .53447 m .44995 .5329 L .45253 .53213 L F
.4076 .53471 m .40864 .53238 L .41015 .5339 L 0 .026 .125 r
F
.4076 .53471 m .40608 .53318 L .40864 .53238 L F
.56964 .53471 m .5709 .53235 L .57227 .53387 L F
.56964 .53471 m .56826 .5332 L .5709 .53235 L F
.53908 .53419 m .5403 .53199 L .5417 .53341 L 0 .025 .124 r
F
.53908 .53419 m .53768 .53278 L .5403 .53199 L F
.49525 .53452 m .49641 .53237 L .49785 .53378 L 0 .026 .125 r
F
.49525 .53452 m .49381 .53311 L .49641 .53237 L F
.57628 .53453 m .57754 .5323 L .57891 .5338 L F
.57628 .53453 m .5749 .53302 L .57754 .5323 L F
.38366 .53398 m .38467 .5317 L .38621 .53321 L 0 .025 .123 r
F
.38366 .53398 m .38213 .53247 L .38467 .5317 L F
.41422 .53457 m .41527 .53233 L .41678 .53377 L 0 .026 .125 r
F
.41422 .53457 m .41271 .53312 L .41527 .53233 L F
.45805 .53444 m .45916 .53209 L .46063 .53362 L F
.45805 .53444 m .45658 .53289 L .45916 .53209 L F
.54572 .53415 m .54694 .53194 L .54834 .5334 L 0 .025 .124 r
F
.54572 .53415 m .54432 .53267 L .54694 .53194 L F
.42085 .53434 m .42191 .53216 L .42342 .53355 L 0 .026 .125 r
F
.42085 .53434 m .41934 .53297 L .42191 .53216 L F
.34646 .53401 m .34741 .53173 L .34898 .53325 L 0 .025 .124 r
F
.34646 .53401 m .34489 .5325 L .34741 .53173 L F
.42748 .53412 m .42855 .53184 L .43005 .53325 L F
.42748 .53412 m .42598 .53272 L .42855 .53184 L F
.58292 .53449 m .58419 .53236 L .58556 .53376 L 0 .027 .126 r
F
.58292 .53449 m .58155 .53308 L .58419 .53236 L F
.50188 .53451 m .50305 .53228 L .50448 .53376 L 0 .026 .126 r
F
.50188 .53451 m .50045 .53303 L .50305 .53228 L F
.39028 .53396 m .3913 .53173 L .39283 .53326 L 0 .025 .124 r
F
.39028 .53396 m .38875 .53243 L .3913 .53173 L F
.43412 .53379 m .43519 .53164 L .43668 .53305 L F
.43412 .53379 m .43262 .53239 L .43519 .53164 L F
.46468 .5344 m .4658 .53219 L .46726 .53368 L 0 .026 .125 r
F
.46468 .5344 m .46321 .5329 L .4658 .53219 L F
.35308 .5339 m .35404 .53169 L .35561 .53311 L 0 .025 .124 r
F
.35308 .5339 m .35151 .53249 L .35404 .53169 L F
.35971 .53364 m .36068 .53136 L .36224 .53278 L 0 .025 .123 r
F
.35971 .53364 m .35814 .53224 L .36068 .53136 L F
.55235 .5342 m .55359 .53199 L .55498 .53349 L 0 .026 .125 r
F
.55235 .5342 m .55096 .53269 L .55359 .53199 L F
.50852 .53439 m .50969 .53207 L .51112 .53351 L F
.50852 .53439 m .50709 .53293 L .50969 .53207 L F
.58956 .53444 m .59085 .53233 L .5922 .53373 L 0 .027 .126 r
F
.58956 .53444 m .5882 .53305 L .59085 .53233 L F
.44075 .53373 m .44183 .5316 L .44332 .53299 L 0 .025 .124 r
F
.44075 .53373 m .43925 .53233 L .44183 .5316 L F
.51515 .53411 m .51634 .53187 L .51776 .53331 L 0 .026 .125 r
F
.51515 .53411 m .51373 .53266 L .51634 .53187 L F
.36634 .53344 m .36731 .5313 L .36887 .53272 L 0 .025 .123 r
F
.36634 .53344 m .36478 .53202 L .36731 .5313 L F
.47131 .53442 m .47244 .53209 L .4739 .5336 L 0 .027 .126 r
F
.47131 .53442 m .46985 .53292 L .47244 .53209 L F
.3969 .53409 m .39792 .53183 L .39945 .53335 L 0 .026 .125 r
F
.3969 .53409 m .39537 .53256 L .39792 .53183 L F
.52179 .53397 m .52298 .5317 L .5244 .53317 L F
.52179 .53397 m .52037 .53252 L .52298 .5317 L F
.5962 .53437 m .59749 .53204 L .59884 .53351 L 0 .027 .126 r
F
.5962 .53437 m .59485 .53291 L .59749 .53204 L F
.44737 .53366 m .44847 .53146 L .44995 .5329 L 0 .025 .124 r
F
.44737 .53366 m .44589 .53223 L .44847 .53146 L F
.55899 .53424 m .56024 .5319 L .56162 .5334 L 0 .026 .125 r
F
.55899 .53424 m .55761 .53275 L .56024 .5319 L F
.47794 .5343 m .47908 .53194 L .48053 .53347 L 0 .027 .126 r
F
.47794 .5343 m .47649 .53278 L .47908 .53194 L F
.37296 .5334 m .37395 .53119 L .3755 .53261 L 0 .025 .123 r
F
.37296 .5334 m .3714 .53199 L .37395 .53119 L F
.60284 .53418 m .60414 .53178 L .60549 .53331 L 0 .026 .125 r
F
.60284 .53418 m .60149 .53265 L .60414 .53178 L F
.48458 .53401 m .48572 .53179 L .48717 .53317 L F
.48458 .53401 m .48313 .53262 L .48572 .53179 L F
.52842 .53384 m .52963 .53157 L .53104 .53306 L F
.52842 .53384 m .52701 .53237 L .52963 .53157 L F
.40352 .53403 m .40456 .53164 L .40608 .53318 L F
.40352 .53403 m .402 .53249 L .40456 .53164 L F
.56563 .53405 m .56688 .5317 L .56826 .5332 L F
.56563 .53405 m .56425 .53255 L .56688 .5317 L F
.60948 .53396 m .61079 .53163 L .61213 .53316 L F
.60948 .53396 m .60814 .53244 L .61079 .53163 L F
.37958 .53324 m .38058 .53104 L .38213 .53247 L 0 .025 .123 r
F
.37958 .53324 m .37804 .53182 L .38058 .53104 L F
.53506 .53361 m .53627 .53137 L .53768 .53278 L 0 .026 .124 r
F
.53506 .53361 m .53365 .53221 L .53627 .53137 L F
.49121 .53383 m .49236 .53174 L .49381 .53311 L 0 .026 .125 r
F
.49121 .53383 m .48977 .53245 L .49236 .53174 L F
.57227 .53387 m .57353 .53149 L .5749 .53302 L F
.57227 .53387 m .5709 .53235 L .57353 .53149 L F
.454 .53369 m .45511 .53135 L .45658 .53289 L 0 .026 .124 r
F
.454 .53369 m .45253 .53213 L .45511 .53135 L F
.41015 .5339 m .4112 .53161 L .41271 .53312 L 0 .026 .125 r
F
.41015 .5339 m .40864 .53238 L .4112 .53161 L F
.5417 .53341 m .54292 .53126 L .54432 .53267 L 0 .025 .124 r
F
.5417 .53341 m .5403 .53199 L .54292 .53126 L F
.38621 .53321 m .38722 .53094 L .38875 .53243 L 0 .025 .123 r
F
.38621 .53321 m .38467 .5317 L .38722 .53094 L F
.41678 .53377 m .41783 .53152 L .41934 .53297 L 0 .026 .125 r
F
.41678 .53377 m .41527 .53233 L .41783 .53152 L F
.49785 .53378 m .49901 .53161 L .50045 .53303 L F
.49785 .53378 m .49641 .53237 L .49901 .53161 L F
.57891 .5338 m .58018 .53158 L .58155 .53308 L F
.57891 .5338 m .57754 .5323 L .58018 .53158 L F
.46063 .53362 m .46174 .53139 L .46321 .5329 L F
.46063 .53362 m .45916 .53209 L .46174 .53139 L F
.42342 .53355 m .42448 .53132 L .42598 .53272 L F
.42342 .53355 m .42191 .53216 L .42448 .53132 L F
.54834 .5334 m .54957 .53123 L .55096 .53269 L F
.54834 .5334 m .54694 .53194 L .54957 .53123 L F
.43005 .53325 m .43112 .53096 L .43262 .53239 L 0 .025 .124 r
F
.43005 .53325 m .42855 .53184 L .43112 .53096 L F
.34898 .53325 m .34994 .53097 L .35151 .53249 L F
.34898 .53325 m .34741 .53173 L .34994 .53097 L F
.58556 .53376 m .58684 .53165 L .5882 .53305 L 0 .027 .126 r
F
.58556 .53376 m .58419 .53236 L .58684 .53165 L F
.50448 .53376 m .50565 .53146 L .50709 .53293 L 0 .026 .126 r
F
.50448 .53376 m .50305 .53228 L .50565 .53146 L F
.43668 .53305 m .43776 .53092 L .43925 .53233 L 0 .025 .124 r
F
.43668 .53305 m .43519 .53164 L .43776 .53092 L F
.39283 .53326 m .39385 .53104 L .39537 .53256 L 0 .026 .124 r
F
.39283 .53326 m .3913 .53173 L .39385 .53104 L F
.35561 .53311 m .35658 .53081 L .35814 .53224 L 0 .025 .124 r
F
.35561 .53311 m .35404 .53169 L .35658 .53081 L F
.46726 .53368 m .46838 .53143 L .46985 .53292 L 0 .027 .126 r
F
.46726 .53368 m .4658 .53219 L .46838 .53143 L F
.51112 .53351 m .5123 .53124 L .51373 .53266 L 0 .026 .125 r
F
.51112 .53351 m .50969 .53207 L .5123 .53124 L F
.36224 .53278 m .36322 .5306 L .36478 .53202 L 0 .025 .123 r
F
.36224 .53278 m .36068 .53136 L .36322 .5306 L F
.55498 .53349 m .55622 .53126 L .55761 .53275 L 0 .026 .125 r
F
.55498 .53349 m .55359 .53199 L .55622 .53126 L F
.51776 .53331 m .51895 .53108 L .52037 .53252 L F
.51776 .53331 m .51634 .53187 L .51895 .53108 L F
.5922 .53373 m .59349 .53152 L .59485 .53291 L 0 .027 .126 r
F
.5922 .53373 m .59085 .53233 L .59349 .53152 L F
.44332 .53299 m .4444 .53082 L .44589 .53223 L 0 .025 .124 r
F
.44332 .53299 m .44183 .5316 L .4444 .53082 L F
.4739 .5336 m .47503 .53125 L .47649 .53278 L 0 .027 .126 r
F
.4739 .5336 m .47244 .53209 L .47503 .53125 L F
.36887 .53272 m .36985 .53056 L .3714 .53199 L 0 .025 .124 r
F
.36887 .53272 m .36731 .5313 L .36985 .53056 L F
.59884 .53351 m .60014 .53117 L .60149 .53265 L 0 .026 .126 r
F
.59884 .53351 m .59749 .53204 L .60014 .53117 L F
.39945 .53335 m .40048 .53099 L .402 .53249 L 0 .026 .125 r
F
.39945 .53335 m .39792 .53183 L .40048 .53099 L F
.5244 .53317 m .5256 .53088 L .52701 .53237 L F
.5244 .53317 m .52298 .5317 L .5256 .53088 L F
.56162 .5334 m .56287 .53105 L .56425 .53255 L F
.56162 .5334 m .56024 .5319 L .56287 .53105 L F
.44995 .5329 m .45104 .53068 L .45253 .53213 L 0 .025 .124 r
F
.44995 .5329 m .44847 .53146 L .45104 .53068 L F
.48053 .53347 m .48167 .53109 L .48313 .53262 L 0 .026 .126 r
F
.48053 .53347 m .47908 .53194 L .48167 .53109 L F
.60549 .53331 m .60679 .53091 L .60814 .53244 L 0 .026 .125 r
F
.60549 .53331 m .60414 .53178 L .60679 .53091 L F
.3755 .53261 m .37649 .53039 L .37804 .53182 L 0 .025 .123 r
F
.3755 .53261 m .37395 .53119 L .37649 .53039 L F
.48717 .53317 m .48832 .53107 L .48977 .53245 L 0 .026 .125 r
F
.48717 .53317 m .48572 .53179 L .48832 .53107 L F
.40608 .53318 m .40712 .53085 L .40864 .53238 L F
.40608 .53318 m .40456 .53164 L .40712 .53085 L F
.56826 .5332 m .56952 .53083 L .5709 .53235 L F
.56826 .5332 m .56688 .5317 L .56952 .53083 L F
.53104 .53306 m .53224 .53071 L .53365 .53221 L F
.53104 .53306 m .52963 .53157 L .53224 .53071 L F
.53768 .53278 m .53889 .53057 L .5403 .53199 L 0 .025 .124 r
F
.53768 .53278 m .53627 .53137 L .53889 .53057 L F
.61213 .53316 m .61345 .5309 L .61479 .53243 L 0 .026 .125 r
F
.61213 .53316 m .61079 .53163 L .61345 .5309 L F
.38213 .53247 m .38313 .53028 L .38467 .5317 L 0 .025 .123 r
F
.38213 .53247 m .38058 .53104 L .38313 .53028 L F
.5749 .53302 m .57617 .53077 L .57754 .5323 L 0 .026 .125 r
F
.5749 .53302 m .57353 .53149 L .57617 .53077 L F
.45658 .53289 m .45769 .53056 L .45916 .53209 L 0 .026 .124 r
F
.45658 .53289 m .45511 .53135 L .45769 .53056 L F
.49381 .53311 m .49496 .53099 L .49641 .53237 L 0 .026 .126 r
F
.49381 .53311 m .49236 .53174 L .49496 .53099 L F
.41271 .53312 m .41376 .53084 L .41527 .53233 L 0 .026 .125 r
F
.41271 .53312 m .4112 .53161 L .41376 .53084 L F
.54432 .53267 m .54554 .53052 L .54694 .53194 L 0 .026 .124 r
F
.54432 .53267 m .54292 .53126 L .54554 .53052 L F
.34489 .5325 m .34584 .53021 L .34741 .53173 L 0 .025 .124 r
F
.34489 .5325 m .34331 .53098 L .34584 .53021 L F
.41934 .53297 m .4204 .5307 L .42191 .53216 L 0 .026 .125 r
F
.41934 .53297 m .41783 .53152 L .4204 .5307 L F
.38875 .53243 m .38976 .53023 L .3913 .53173 L 0 .025 .124 r
F
.38875 .53243 m .38722 .53094 L .38976 .53023 L F
.50045 .53303 m .50161 .53084 L .50305 .53228 L 0 .027 .126 r
F
.50045 .53303 m .49901 .53161 L .50161 .53084 L F
.58155 .53308 m .58283 .53086 L .58419 .53236 L F
.58155 .53308 m .58018 .53158 L .58283 .53086 L F
.42598 .53272 m .42705 .53042 L .42855 .53184 L 0 .026 .125 r
F
.42598 .53272 m .42448 .53132 L .42705 .53042 L F
.46321 .5329 m .46433 .53069 L .4658 .53219 L F
.46321 .5329 m .46174 .53139 L .46433 .53069 L F
.43262 .53239 m .43369 .5302 L .43519 .53164 L 0 .025 .124 r
F
.43262 .53239 m .43112 .53096 L .43369 .5302 L F
.35151 .53249 m .35248 .53016 L .35404 .53169 L F
.35151 .53249 m .34994 .53097 L .35248 .53016 L F
.55096 .53269 m .5522 .53052 L .55359 .53199 L 0 .026 .125 r
F
.55096 .53269 m .54957 .53123 L .5522 .53052 L F
.50709 .53293 m .50826 .53063 L .50969 .53207 L F
.50709 .53293 m .50565 .53146 L .50826 .53063 L F
.35814 .53224 m .35912 .52994 L .36068 .53136 L 0 .025 .124 r
F
.35814 .53224 m .35658 .53081 L .35912 .52994 L F
.51373 .53266 m .51491 .53048 L .51634 .53187 L 0 .026 .125 r
F
.51373 .53266 m .5123 .53124 L .51491 .53048 L F
.5882 .53305 m .58949 .53094 L .59085 .53233 L 0 .027 .126 r
F
.5882 .53305 m .58684 .53165 L .58949 .53094 L F
.43925 .53233 m .44033 .53018 L .44183 .5316 L 0 .025 .124 r
F
.43925 .53233 m .43776 .53092 L .44033 .53018 L F
.46985 .53292 m .47097 .53059 L .47244 .53209 L 0 .027 .126 r
F
.46985 .53292 m .46838 .53143 L .47097 .53059 L F
.39537 .53256 m .3964 .5303 L .39792 .53183 L 0 .026 .125 r
F
.39537 .53256 m .39385 .53104 L .3964 .5303 L F
.36478 .53202 m .36575 .52988 L .36731 .5313 L 0 .025 .123 r
F
.36478 .53202 m .36322 .5306 L .36575 .52988 L F
.52037 .53252 m .52156 .53026 L .52298 .5317 L 0 .026 .125 r
F
.52037 .53252 m .51895 .53108 L .52156 .53026 L F
.59485 .53291 m .59614 .53065 L .59749 .53204 L 0 .027 .126 r
F
.59485 .53291 m .59349 .53152 L .59614 .53065 L F
.55761 .53275 m .55885 .53041 L .56024 .5319 L 0 .026 .125 r
F
.55761 .53275 m .55622 .53126 L .55885 .53041 L F
.44589 .53223 m .44698 .53004 L .44847 .53146 L 0 .025 .124 r
F
.44589 .53223 m .4444 .53082 L .44698 .53004 L F
.47649 .53278 m .47762 .53041 L .47908 .53194 L 0 .026 .125 r
F
.47649 .53278 m .47503 .53125 L .47762 .53041 L F
.60149 .53265 m .60279 .53031 L .60414 .53178 L F
.60149 .53265 m .60014 .53117 L .60279 .53031 L F
.402 .53249 m .40304 .53015 L .40456 .53164 L F
.402 .53249 m .40048 .53099 L .40304 .53015 L F
.3714 .53199 m .37239 .52975 L .37395 .53119 L 0 .025 .124 r
F
.3714 .53199 m .36985 .53056 L .37239 .52975 L F
.56425 .53255 m .5655 .53021 L .56688 .5317 L 0 .026 .125 r
F
.56425 .53255 m .56287 .53105 L .5655 .53021 L F
.52701 .53237 m .52821 .53006 L .52963 .53157 L F
.52701 .53237 m .5256 .53088 L .52821 .53006 L F
.48313 .53262 m .48427 .53026 L .48572 .53179 L F
.48313 .53262 m .48167 .53109 L .48427 .53026 L F
.60814 .53244 m .60945 .5301 L .61079 .53163 L F
.60814 .53244 m .60679 .53091 L .60945 .5301 L F
.45253 .53213 m .45363 .5299 L .45511 .53135 L 0 .026 .124 r
F
.45253 .53213 m .45104 .53068 L .45363 .5299 L F
.5709 .53235 m .57216 .52997 L .57353 .53149 L 0 .026 .125 r
F
.5709 .53235 m .56952 .53083 L .57216 .52997 L F
.37804 .53182 m .37904 .52961 L .38058 .53104 L 0 .025 .124 r
F
.37804 .53182 m .37649 .53039 L .37904 .52961 L F
.40864 .53238 m .40968 .5301 L .4112 .53161 L 0 .026 .125 r
F
.40864 .53238 m .40712 .53085 L .40968 .5301 L F
.53365 .53221 m .53486 .52985 L .53627 .53137 L 0 .026 .124 r
F
.53365 .53221 m .53224 .53071 L .53486 .52985 L F
.48977 .53245 m .49092 .53035 L .49236 .53174 L 0 .027 .126 r
F
.48977 .53245 m .48832 .53107 L .49092 .53035 L F
.5403 .53199 m .54152 .52984 L .54292 .53126 L 0 .026 .124 r
F
.5403 .53199 m .53889 .53057 L .54152 .52984 L F
.61479 .53243 m .61611 .53017 L .61745 .5317 L 0 .026 .126 r
F
.61479 .53243 m .61345 .5309 L .61611 .53017 L F
.38467 .5317 m .38568 .52951 L .38722 .53094 L 0 .025 .124 r
F
.38467 .5317 m .38313 .53028 L .38568 .52951 L F
.45916 .53209 m .46027 .52987 L .46174 .53139 L 0 .026 .125 r
F
.45916 .53209 m .45769 .53056 L .46027 .52987 L F
.57754 .5323 m .57882 .53005 L .58018 .53158 L F
.57754 .5323 m .57617 .53077 L .57882 .53005 L F
.41527 .53233 m .41632 .53002 L .41783 .53152 L F
.41527 .53233 m .41376 .53084 L .41632 .53002 L F
.49641 .53237 m .49757 .53021 L .49901 .53161 L 0 .027 .126 r
F
.49641 .53237 m .49496 .53099 L .49757 .53021 L F
.34741 .53173 m .34837 .52944 L .34994 .53097 L 0 .025 .124 r
F
.34741 .53173 m .34584 .53021 L .34837 .52944 L F
.54694 .53194 m .54817 .52981 L .54957 .53123 L 0 .026 .125 r
F
.54694 .53194 m .54554 .53052 L .54817 .52981 L F
.42191 .53216 m .42297 .52985 L .42448 .53132 L F
.42191 .53216 m .4204 .5307 L .42297 .52985 L F
.42855 .53184 m .42962 .52953 L .43112 .53096 L 0 .025 .124 r
F
.42855 .53184 m .42705 .53042 L .42962 .52953 L F
.50305 .53228 m .50422 .53004 L .50565 .53146 L 0 .027 .126 r
F
.50305 .53228 m .50161 .53084 L .50422 .53004 L F
.3913 .53173 m .39231 .52953 L .39385 .53104 L 0 .025 .124 r
F
.3913 .53173 m .38976 .53023 L .39231 .52953 L F
.58419 .53236 m .58548 .53014 L .58684 .53165 L 0 .027 .126 r
F
.58419 .53236 m .58283 .53086 L .58548 .53014 L F
.4658 .53219 m .46692 .52994 L .46838 .53143 L 0 .026 .126 r
F
.4658 .53219 m .46433 .53069 L .46692 .52994 L F
.43519 .53164 m .43626 .52947 L .43776 .53092 L 0 .025 .124 r
F
.43519 .53164 m .43369 .5302 L .43626 .52947 L F
.35404 .53169 m .35501 .52929 L .35658 .53081 L F
.35404 .53169 m .35248 .53016 L .35501 .52929 L F
.50969 .53207 m .51087 .52982 L .5123 .53124 L 0 .026 .125 r
F
.50969 .53207 m .50826 .53063 L .51087 .52982 L F
.36068 .53136 m .36166 .52917 L .36322 .5306 L 0 .025 .123 r
F
.36068 .53136 m .35912 .52994 L .36166 .52917 L F
.55359 .53199 m .55483 .5298 L .55622 .53126 L 0 .026 .125 r
F
.55359 .53199 m .5522 .53052 L .55483 .5298 L F
.51634 .53187 m .51752 .52971 L .51895 .53108 L F
.51634 .53187 m .51491 .53048 L .51752 .52971 L F
.47244 .53209 m .47357 .52974 L .47503 .53125 L F
.47244 .53209 m .47097 .53059 L .47357 .52974 L F
.59085 .53233 m .59214 .53012 L .59349 .53152 L 0 .027 .127 r
F
.59085 .53233 m .58949 .53094 L .59214 .53012 L F
.44183 .5316 m .44291 .5294 L .4444 .53082 L 0 .026 .124 r
F
.44183 .5316 m .44033 .53018 L .44291 .5294 L F
.39792 .53183 m .39895 .52948 L .40048 .53099 L 0 .026 .125 r
F
.39792 .53183 m .3964 .5303 L .39895 .52948 L F
.36731 .5313 m .36829 .52913 L .36985 .53056 L 0 .025 .124 r
F
.36731 .5313 m .36575 .52988 L .36829 .52913 L F
.59749 .53204 m .59879 .52979 L .60014 .53117 L 0 .027 .126 r
F
.59749 .53204 m .59614 .53065 L .59879 .52979 L F
.52298 .5317 m .52418 .52943 L .5256 .53088 L 0 .026 .125 r
F
.52298 .5317 m .52156 .53026 L .52418 .52943 L F
.56024 .5319 m .56148 .52955 L .56287 .53105 L F
.56024 .5319 m .55885 .53041 L .56148 .52955 L F
.47908 .53194 m .48022 .52957 L .48167 .53109 L F
.47908 .53194 m .47762 .53041 L .48022 .52957 L F
.60414 .53178 m .60545 .52944 L .60679 .53091 L F
.60414 .53178 m .60279 .53031 L .60545 .52944 L F
.40456 .53164 m .4056 .52939 L .40712 .53085 L F
.40456 .53164 m .40304 .53015 L .4056 .52939 L F
.44847 .53146 m .44956 .52926 L .45104 .53068 L 0 .026 .124 r
F
.44847 .53146 m .44698 .53004 L .44956 .52926 L F
.56688 .5317 m .56814 .52936 L .56952 .53083 L 0 .026 .125 r
F
.56688 .5317 m .5655 .53021 L .56814 .52936 L F
.37395 .53119 m .37494 .52893 L .37649 .53039 L 0 .025 .124 r
F
.37395 .53119 m .37239 .52975 L .37494 .52893 L F
.52963 .53157 m .53083 .52919 L .53224 .53071 L 0 .026 .124 r
F
.52963 .53157 m .52821 .53006 L .53083 .52919 L F
.48572 .53179 m .48687 .52954 L .48832 .53107 L 0 .026 .125 r
F
.48572 .53179 m .48427 .53026 L .48687 .52954 L F
.61079 .53163 m .61211 .52938 L .61345 .5309 L F
.61079 .53163 m .60945 .5301 L .61211 .52938 L F
.57353 .53149 m .5748 .52924 L .57617 .53077 L F
.57353 .53149 m .57216 .52997 L .5748 .52924 L F
.45511 .53135 m .45621 .52912 L .45769 .53056 L 0 .026 .124 r
F
.45511 .53135 m .45363 .5299 L .45621 .52912 L F
.53627 .53137 m .53749 .52904 L .53889 .53057 L 0 .025 .124 r
F
.53627 .53137 m .53486 .52985 L .53749 .52904 L F
.38058 .53104 m .38158 .52885 L .38313 .53028 L F
.38058 .53104 m .37904 .52961 L .38158 .52885 L F
.4112 .53161 m .41224 .52935 L .41376 .53084 L 0 .026 .125 r
F
.4112 .53161 m .40968 .5301 L .41224 .52935 L F
.34331 .53098 m .34427 .5287 L .34584 .53021 L 0 .025 .123 r
F
.34331 .53098 m .34174 .52947 L .34427 .5287 L F
.49236 .53174 m .49352 .52959 L .49496 .53099 L 0 .027 .126 r
F
.49236 .53174 m .49092 .53035 L .49352 .52959 L F
.54292 .53126 m .54414 .52911 L .54554 .53052 L 0 .026 .125 r
F
.54292 .53126 m .54152 .52984 L .54414 .52911 L F
.38722 .53094 m .38822 .5288 L .38976 .53023 L 0 .025 .124 r
F
.38722 .53094 m .38568 .52951 L .38822 .5288 L F
.61745 .5317 m .61877 .52945 L .62011 .53098 L 0 .027 .126 r
F
.61745 .5317 m .61611 .53017 L .61877 .52945 L F
.41783 .53152 m .41889 .5292 L .4204 .5307 L 0 .026 .125 r
F
.41783 .53152 m .41632 .53002 L .41889 .5292 L F
.46174 .53139 m .46286 .52919 L .46433 .53069 L F
.46174 .53139 m .46027 .52987 L .46286 .52919 L F
.58018 .53158 m .58146 .52933 L .58283 .53086 L 0 .027 .126 r
F
.58018 .53158 m .57882 .53005 L .58146 .52933 L F
.49901 .53161 m .50017 .52943 L .50161 .53084 L F
.49901 .53161 m .49757 .53021 L .50017 .52943 L F
.42448 .53132 m .42554 .52896 L .42705 .53042 L 0 .026 .125 r
F
.42448 .53132 m .42297 .52985 L .42554 .52896 L F
.43112 .53096 m .43219 .52876 L .43369 .5302 L 0 .025 .124 r
F
.43112 .53096 m .42962 .52953 L .43219 .52876 L F
.34994 .53097 m .35091 .52863 L .35248 .53016 L F
.34994 .53097 m .34837 .52944 L .35091 .52863 L F
.54957 .53123 m .5508 .5291 L .5522 .53052 L 0 .026 .125 r
F
.54957 .53123 m .54817 .52981 L .5508 .5291 L F
.50565 .53146 m .50683 .52922 L .50826 .53063 L 0 .027 .126 r
F
.50565 .53146 m .50422 .53004 L .50683 .52922 L F
.35658 .53081 m .35756 .52842 L .35912 .52994 L 0 .025 .124 r
F
.35658 .53081 m .35501 .52929 L .35756 .52842 L F
.39385 .53104 m .39487 .5288 L .3964 .5303 L 0 .026 .125 r
F
.39385 .53104 m .39231 .52953 L .39487 .5288 L F
.5123 .53124 m .51348 .52908 L .51491 .53048 L F
.5123 .53124 m .51087 .52982 L .51348 .52908 L F
.46838 .53143 m .46951 .5291 L .47097 .53059 L 0 .026 .126 r
F
.46838 .53143 m .46692 .52994 L .46951 .5291 L F
.58684 .53165 m .58813 .52943 L .58949 .53094 L 0 .027 .127 r
F
.58684 .53165 m .58548 .53014 L .58813 .52943 L F
.43776 .53092 m .43884 .52872 L .44033 .53018 L 0 .026 .124 r
F
.43776 .53092 m .43626 .52947 L .43884 .52872 L F
.36322 .5306 m .36419 .52844 L .36575 .52988 L 0 .025 .124 r
F
.36322 .5306 m .36166 .52917 L .36419 .52844 L F
.47503 .53125 m .47616 .52891 L .47762 .53041 L 0 .026 .125 r
F
.47503 .53125 m .47357 .52974 L .47616 .52891 L F
.55622 .53126 m .55746 .52894 L .55885 .53041 L F
.55622 .53126 m .55483 .5298 L .55746 .52894 L F
.51895 .53108 m .52014 .52889 L .52156 .53026 L F
.51895 .53108 m .51752 .52971 L .52014 .52889 L F
.59349 .53152 m .59479 .52926 L .59614 .53065 L 0 .027 .126 r
F
.59349 .53152 m .59214 .53012 L .59479 .52926 L F
.40048 .53099 m .40151 .52866 L .40304 .53015 L 0 .026 .125 r
F
.40048 .53099 m .39895 .52948 L .40151 .52866 L F
.60014 .53117 m .60144 .52894 L .60279 .53031 L F
.60014 .53117 m .59879 .52979 L .60144 .52894 L F
.4444 .53082 m .44549 .5286 L .44698 .53004 L F
.4444 .53082 m .44291 .5294 L .44549 .5286 L F
.56287 .53105 m .56412 .52871 L .5655 .53021 L F
.56287 .53105 m .56148 .52955 L .56412 .52871 L F
.5256 .53088 m .5268 .52859 L .52821 .53006 L F
.5256 .53088 m .52418 .52943 L .5268 .52859 L F
.48167 .53109 m .48282 .52873 L .48427 .53026 L F
.48167 .53109 m .48022 .52957 L .48282 .52873 L F
.60679 .53091 m .6081 .52864 L .60945 .5301 L F
.60679 .53091 m .60545 .52944 L .6081 .52864 L F
.36985 .53056 m .37084 .52829 L .37239 .52975 L 0 .025 .124 r
F
.36985 .53056 m .36829 .52913 L .37084 .52829 L F
.56952 .53083 m .57078 .52851 L .57216 .52997 L 0 .026 .125 r
F
.56952 .53083 m .56814 .52936 L .57078 .52851 L F
.40712 .53085 m .40816 .52865 L .40968 .5301 L F
.40712 .53085 m .4056 .52939 L .40816 .52865 L F
.45104 .53068 m .45214 .52848 L .45363 .5299 L 0 .026 .124 r
F
.45104 .53068 m .44956 .52926 L .45214 .52848 L F
.53224 .53071 m .53345 .52831 L .53486 .52985 L 0 .025 .124 r
F
.53224 .53071 m .53083 .52919 L .53345 .52831 L F
.37649 .53039 m .37749 .52814 L .37904 .52961 L F
.37649 .53039 m .37494 .52893 L .37749 .52814 L F
.48832 .53107 m .48947 .52881 L .49092 .53035 L 0 .027 .126 r
F
.48832 .53107 m .48687 .52954 L .48947 .52881 L F
.61345 .5309 m .61477 .52865 L .61611 .53017 L 0 .026 .125 r
F
.61345 .5309 m .61211 .52938 L .61477 .52865 L F
.45769 .53056 m .45879 .52843 L .46027 .52987 L F
.45769 .53056 m .45621 .52912 L .45879 .52843 L F
.53889 .53057 m .54011 .52831 L .54152 .52984 L 0 .026 .124 r
F
.53889 .53057 m .53749 .52904 L .54011 .52831 L F
.57617 .53077 m .57744 .52853 L .57882 .53005 L 0 .026 .125 r
F
.57617 .53077 m .5748 .52924 L .57744 .52853 L F
.38313 .53028 m .38413 .52808 L .38568 .52951 L 0 .025 .124 r
F
.38313 .53028 m .38158 .52885 L .38413 .52808 L F
.41376 .53084 m .41481 .52852 L .41632 .53002 L 0 .026 .125 r
F
.41376 .53084 m .41224 .52935 L .41481 .52852 L F
.34584 .53021 m .3468 .52792 L .34837 .52944 L 0 .025 .124 r
F
.34584 .53021 m .34427 .5287 L .3468 .52792 L F
.49496 .53099 m .49612 .5288 L .49757 .53021 L 0 .027 .126 r
F
.49496 .53099 m .49352 .52959 L .49612 .5288 L F
.4204 .5307 m .42146 .52835 L .42297 .52985 L 0 .026 .125 r
F
.4204 .5307 m .41889 .5292 L .42146 .52835 L F
.54554 .53052 m .54677 .52839 L .54817 .52981 L F
.54554 .53052 m .54414 .52911 L .54677 .52839 L F
.38976 .53023 m .39078 .52809 L .39231 .52953 L 0 .026 .124 r
F
.38976 .53023 m .38822 .5288 L .39078 .52809 L F
.42705 .53042 m .42812 .52807 L .42962 .52953 L F
.42705 .53042 m .42554 .52896 L .42812 .52807 L F
.62011 .53098 m .62144 .52872 L .62278 .53026 L 0 .027 .126 r
F
.62011 .53098 m .61877 .52945 L .62144 .52872 L F
.50161 .53084 m .50278 .52863 L .50422 .53004 L F
.50161 .53084 m .50017 .52943 L .50278 .52863 L F
.58283 .53086 m .58411 .5286 L .58548 .53014 L F
.58283 .53086 m .58146 .52933 L .58411 .5286 L F
.46433 .53069 m .46545 .52845 L .46692 .52994 L 0 .026 .126 r
F
.46433 .53069 m .46286 .52919 L .46545 .52845 L F
.35248 .53016 m .35345 .52777 L .35501 .52929 L 0 .025 .124 r
F
.35248 .53016 m .35091 .52863 L .35345 .52777 L F
.43369 .5302 m .43477 .52802 L .43626 .52947 L 0 .026 .124 r
F
.43369 .5302 m .43219 .52876 L .43477 .52802 L F
.50826 .53063 m .50944 .52842 L .51087 .52982 L 0 .026 .126 r
F
.50826 .53063 m .50683 .52922 L .50944 .52842 L F
.35912 .52994 m .36009 .52766 L .36166 .52917 L 0 .025 .123 r
F
.35912 .52994 m .35756 .52842 L .36009 .52766 L F
.5522 .53052 m .55344 .52837 L .55483 .5298 L 0 .026 .126 r
F
.5522 .53052 m .5508 .5291 L .55344 .52837 L F
.47097 .53059 m .4721 .52826 L .47357 .52974 L 0 .026 .125 r
F
.47097 .53059 m .46951 .5291 L .4721 .52826 L F
.51491 .53048 m .5161 .52833 L .51752 .52971 L 0 .026 .126 r
F
.51491 .53048 m .51348 .52908 L .5161 .52833 L F
.3964 .5303 m .39742 .52799 L .39895 .52948 L 0 .026 .125 r
F
.3964 .5303 m .39487 .5288 L .39742 .52799 L F
.44033 .53018 m .44142 .52791 L .44291 .5294 L F
.44033 .53018 m .43884 .52872 L .44142 .52791 L F
.58949 .53094 m .59078 .52861 L .59214 .53012 L 0 .027 .127 r
F
.58949 .53094 m .58813 .52943 L .59078 .52861 L F
.55885 .53041 m .5601 .52809 L .56148 .52955 L 0 .026 .125 r
F
.55885 .53041 m .55746 .52894 L .5601 .52809 L F
.47762 .53041 m .47876 .52807 L .48022 .52957 L F
.47762 .53041 m .47616 .52891 L .47876 .52807 L F
.36575 .52988 m .36673 .52769 L .36829 .52913 L 0 .025 .124 r
F
.36575 .52988 m .36419 .52844 L .36673 .52769 L F
.52156 .53026 m .52276 .52804 L .52418 .52943 L 0 .026 .125 r
F
.52156 .53026 m .52014 .52889 L .52276 .52804 L F
.59614 .53065 m .59744 .5284 L .59879 .52979 L 0 .027 .126 r
F
.59614 .53065 m .59479 .52926 L .59744 .5284 L F
.60279 .53031 m .6041 .52808 L .60545 .52944 L 0 .026 .125 r
F
.60279 .53031 m .60144 .52894 L .6041 .52808 L F
.40304 .53015 m .40407 .52792 L .4056 .52939 L F
.40304 .53015 m .40151 .52866 L .40407 .52792 L F
.5655 .53021 m .56676 .52788 L .56814 .52936 L F
.5655 .53021 m .56412 .52871 L .56676 .52788 L F
.44698 .53004 m .44807 .52782 L .44956 .52926 L F
.44698 .53004 m .44549 .5286 L .44807 .52782 L F
.52821 .53006 m .52942 .5277 L .53083 .52919 L 0 .026 .124 r
F
.52821 .53006 m .5268 .52859 L .52942 .5277 L F
.48427 .53026 m .48542 .528 L .48687 .52954 L 0 .026 .125 r
F
.48427 .53026 m .48282 .52873 L .48542 .528 L F
.60945 .5301 m .61077 .52791 L .61211 .52938 L F
.60945 .5301 m .6081 .52864 L .61077 .52791 L F
.37239 .52975 m .37339 .52745 L .37494 .52893 L 0 .025 .124 r
F
.37239 .52975 m .37084 .52829 L .37339 .52745 L F
.57216 .52997 m .57342 .52778 L .5748 .52924 L 0 .026 .125 r
F
.57216 .52997 m .57078 .52851 L .57342 .52778 L F
.53486 .52985 m .53608 .5275 L .53749 .52904 L 0 .025 .124 r
F
.53486 .52985 m .53345 .52831 L .53608 .5275 L F
.45363 .5299 m .45473 .5277 L .45621 .52912 L 0 .026 .125 r
F
.45363 .5299 m .45214 .52848 L .45473 .5277 L F
.40968 .5301 m .41072 .52791 L .41224 .52935 L F
.40968 .5301 m .40816 .52865 L .41072 .52791 L F
.37904 .52961 m .38004 .52737 L .38158 .52885 L 0 .025 .124 r
F
.37904 .52961 m .37749 .52814 L .38004 .52737 L F
.34174 .52947 m .34269 .52719 L .34427 .5287 L 0 .025 .123 r
F
.34174 .52947 m .34016 .52796 L .34269 .52719 L F
.49092 .53035 m .49207 .52805 L .49352 .52959 L 0 .027 .126 r
F
.49092 .53035 m .48947 .52881 L .49207 .52805 L F
.61611 .53017 m .61744 .52791 L .61877 .52945 L F
.61611 .53017 m .61477 .52865 L .61744 .52791 L F
.41632 .53002 m .41738 .52769 L .41889 .5292 L 0 .026 .125 r
F
.41632 .53002 m .41481 .52852 L .41738 .52769 L F
.54152 .52984 m .54274 .52758 L .54414 .52911 L F
.54152 .52984 m .54011 .52831 L .54274 .52758 L F
.57882 .53005 m .58009 .5278 L .58146 .52933 L F
.57882 .53005 m .57744 .52853 L .58009 .5278 L F
.46027 .52987 m .46138 .52774 L .46286 .52919 L F
.46027 .52987 m .45879 .52843 L .46138 .52774 L F
.38568 .52951 m .38668 .52736 L .38822 .5288 L 0 .025 .124 r
F
.38568 .52951 m .38413 .52808 L .38668 .52736 L F
.34837 .52944 m .34934 .52712 L .35091 .52863 L F
.34837 .52944 m .3468 .52792 L .34934 .52712 L F
.49757 .53021 m .49873 .52801 L .50017 .52943 L 0 .027 .126 r
F
.49757 .53021 m .49612 .5288 L .49873 .52801 L F
.42297 .52985 m .42403 .52748 L .42554 .52896 L 0 .026 .125 r
F
.42297 .52985 m .42146 .52835 L .42403 .52748 L F
.42962 .52953 m .43069 .5273 L .43219 .52876 L 0 .025 .124 r
F
.42962 .52953 m .42812 .52807 L .43069 .5273 L F
.54817 .52981 m .54941 .52767 L .5508 .5291 L 0 .026 .125 r
F
.54817 .52981 m .54677 .52839 L .54941 .52767 L F
.35501 .52929 m .35599 .5269 L .35756 .52842 L 0 .025 .123 r
F
.35501 .52929 m .35345 .52777 L .35599 .5269 L F
.50422 .53004 m .50539 .52782 L .50683 .52922 L 0 .027 .126 r
F
.50422 .53004 m .50278 .52863 L .50539 .52782 L F
.62278 .53026 m .62411 .52796 L .62544 .5295 L F
.62278 .53026 m .62144 .52872 L .62411 .52796 L F
.39231 .52953 m .39333 .52735 L .39487 .5288 L 0 .026 .125 r
F
.39231 .52953 m .39078 .52809 L .39333 .52735 L F
.46692 .52994 m .46804 .52761 L .46951 .5291 L 0 .026 .126 r
F
.46692 .52994 m .46545 .52845 L .46804 .52761 L F
.58548 .53014 m .58676 .52788 L .58813 .52943 L 0 .027 .126 r
F
.58548 .53014 m .58411 .5286 L .58676 .52788 L F
.51087 .52982 m .51205 .52768 L .51348 .52908 L F
.51087 .52982 m .50944 .52842 L .51205 .52768 L F
.43626 .52947 m .43734 .52726 L .43884 .52872 L 0 .026 .125 r
F
.43626 .52947 m .43477 .52802 L .43734 .52726 L F
.36166 .52917 m .36263 .52693 L .36419 .52844 L 0 .025 .124 r
F
.36166 .52917 m .36009 .52766 L .36263 .52693 L F
.47357 .52974 m .4747 .52744 L .47616 .52891 L 0 .026 .125 r
F
.47357 .52974 m .4721 .52826 L .4747 .52744 L F
.55483 .5298 m .55607 .52751 L .55746 .52894 L 0 .026 .126 r
F
.55483 .5298 m .55344 .52837 L .55607 .52751 L F
.39895 .52948 m .39999 .52718 L .40151 .52866 L 0 .026 .125 r
F
.39895 .52948 m .39742 .52799 L .39999 .52718 L F
.51752 .52971 m .51872 .52752 L .52014 .52889 L 0 .027 .126 r
F
.51752 .52971 m .5161 .52833 L .51872 .52752 L F
.56148 .52955 m .56273 .52725 L .56412 .52871 L 0 .026 .125 r
F
.56148 .52955 m .5601 .52809 L .56273 .52725 L F
.48022 .52957 m .48136 .52725 L .48282 .52873 L F
.48022 .52957 m .47876 .52807 L .48136 .52725 L F
.59214 .53012 m .59343 .52775 L .59479 .52926 L 0 .027 .127 r
F
.59214 .53012 m .59078 .52861 L .59343 .52775 L F
.44291 .5294 m .444 .5271 L .44549 .5286 L 0 .026 .125 r
F
.44291 .5294 m .44142 .52791 L .444 .5271 L F
.59879 .52979 m .60009 .52756 L .60144 .52894 L 0 .027 .126 r
F
.59879 .52979 m .59744 .5284 L .60009 .52756 L F
.52418 .52943 m .52538 .52719 L .5268 .52859 L 0 .026 .125 r
F
.52418 .52943 m .52276 .52804 L .52538 .52719 L F
.60545 .52944 m .60676 .52727 L .6081 .52864 L F
.60545 .52944 m .6041 .52808 L .60676 .52727 L F
.36829 .52913 m .36928 .52683 L .37084 .52829 L 0 .025 .124 r
F
.36829 .52913 m .36673 .52769 L .36928 .52683 L F
.56814 .52936 m .5694 .52704 L .57078 .52851 L 0 .026 .125 r
F
.56814 .52936 m .56676 .52788 L .5694 .52704 L F
.53083 .52919 m .53204 .52682 L .53345 .52831 L 0 .025 .124 r
F
.53083 .52919 m .52942 .5277 L .53204 .52682 L F
.4056 .52939 m .40663 .5272 L .40816 .52865 L 0 .026 .125 r
F
.4056 .52939 m .40407 .52792 L .40663 .5272 L F
.44956 .52926 m .45066 .52704 L .45214 .52848 L F
.44956 .52926 m .44807 .52782 L .45066 .52704 L F
.37494 .52893 m .37594 .52665 L .37749 .52814 L 0 .025 .124 r
F
.37494 .52893 m .37339 .52745 L .37594 .52665 L F
.48687 .52954 m .48802 .52727 L .48947 .52881 L 0 .026 .126 r
F
.48687 .52954 m .48542 .528 L .48802 .52727 L F
.61211 .52938 m .61343 .52717 L .61477 .52865 L 0 .026 .125 r
F
.61211 .52938 m .61077 .52791 L .61343 .52717 L F
.53749 .52904 m .53871 .52677 L .54011 .52831 L 0 .025 .124 r
F
.53749 .52904 m .53608 .5275 L .53871 .52677 L F
.5748 .52924 m .57607 .52705 L .57744 .52853 L 0 .026 .125 r
F
.5748 .52924 m .57342 .52778 L .57607 .52705 L F
.45621 .52912 m .45731 .527 L .45879 .52843 L F
.45621 .52912 m .45473 .5277 L .45731 .527 L F
.41224 .52935 m .41329 .52709 L .41481 .52852 L F
.41224 .52935 m .41072 .52791 L .41329 .52709 L F
.38158 .52885 m .38259 .52661 L .38413 .52808 L 0 .025 .124 r
F
.38158 .52885 m .38004 .52737 L .38259 .52661 L F
.34427 .5287 m .34522 .52642 L .3468 .52792 L 0 .025 .123 r
F
.34427 .5287 m .34269 .52719 L .34522 .52642 L F
.41889 .5292 m .41995 .52684 L .42146 .52835 L 0 .026 .125 r
F
.41889 .5292 m .41738 .52769 L .41995 .52684 L F
.49352 .52959 m .49468 .52724 L .49612 .5288 L 0 .027 .126 r
F
.49352 .52959 m .49207 .52805 L .49468 .52724 L F
.61877 .52945 m .6201 .52717 L .62144 .52872 L F
.61877 .52945 m .61744 .52791 L .6201 .52717 L F
.54414 .52911 m .54537 .52685 L .54677 .52839 L 0 .026 .125 r
F
.54414 .52911 m .54274 .52758 L .54537 .52685 L F
.58146 .52933 m .58274 .52707 L .58411 .5286 L 0 .027 .126 r
F
.58146 .52933 m .58009 .5278 L .58274 .52707 L F
.42554 .52896 m .42661 .5266 L .42812 .52807 L 0 .026 .124 r
F
.42554 .52896 m .42403 .52748 L .42661 .5266 L F
.38822 .5288 m .38924 .52665 L .39078 .52809 L F
.38822 .5288 m .38668 .52736 L .38924 .52665 L F
.35091 .52863 m .35188 .52626 L .35345 .52777 L 0 .025 .124 r
F
.35091 .52863 m .34934 .52712 L .35188 .52626 L F
.46286 .52919 m .46397 .527 L .46545 .52845 L 0 .026 .126 r
F
.46286 .52919 m .46138 .52774 L .46397 .527 L F
.50017 .52943 m .50134 .52722 L .50278 .52863 L 0 .027 .126 r
F
.50017 .52943 m .49873 .52801 L .50134 .52722 L F
.43219 .52876 m .43327 .52656 L .43477 .52802 L 0 .026 .124 r
F
.43219 .52876 m .43069 .5273 L .43327 .52656 L F
.35756 .52842 m .35853 .52614 L .36009 .52766 L 0 .025 .123 r
F
.35756 .52842 m .35599 .5269 L .35853 .52614 L F
.50683 .52922 m .508 .52703 L .50944 .52842 L 0 .027 .126 r
F
.50683 .52922 m .50539 .52782 L .508 .52703 L F
.46951 .5291 m .47064 .52677 L .4721 .52826 L 0 .026 .125 r
F
.46951 .5291 m .46804 .52761 L .47064 .52677 L F
.5508 .5291 m .55204 .52693 L .55344 .52837 L 0 .027 .126 r
F
.5508 .5291 m .54941 .52767 L .55204 .52693 L F
.62544 .5295 m .62678 .52708 L .62811 .52862 L F
.62544 .5295 m .62411 .52796 L .62678 .52708 L F
.39487 .5288 m .39589 .52652 L .39742 .52799 L 0 .026 .125 r
F
.39487 .5288 m .39333 .52735 L .39589 .52652 L F
.58813 .52943 m .58941 .52706 L .59078 .52861 L 0 .027 .126 r
F
.58813 .52943 m .58676 .52788 L .58941 .52706 L F
.51348 .52908 m .51467 .52695 L .5161 .52833 L F
.51348 .52908 m .51205 .52768 L .51467 .52695 L F
.47616 .52891 m .4773 .52663 L .47876 .52807 L 0 .026 .125 r
F
.47616 .52891 m .4747 .52744 L .4773 .52663 L F
.43884 .52872 m .43993 .52643 L .44142 .52791 L F
.43884 .52872 m .43734 .52726 L .43993 .52643 L F
.55746 .52894 m .55871 .52665 L .5601 .52809 L F
.55746 .52894 m .55607 .52751 L .55871 .52665 L F
.36419 .52844 m .36518 .52618 L .36673 .52769 L 0 .025 .124 r
F
.36419 .52844 m .36263 .52693 L .36518 .52618 L F
.40151 .52866 m .40255 .52644 L .40407 .52792 L 0 .026 .125 r
F
.40151 .52866 m .39999 .52718 L .40255 .52644 L F
.52014 .52889 m .52134 .52666 L .52276 .52804 L 0 .026 .126 r
F
.52014 .52889 m .51872 .52752 L .52134 .52666 L F
.59479 .52926 m .59608 .5269 L .59744 .5284 L 0 .027 .126 r
F
.59479 .52926 m .59343 .52775 L .59608 .5269 L F
.56412 .52871 m .56538 .52642 L .56676 .52788 L 0 .026 .125 r
F
.56412 .52871 m .56273 .52725 L .56538 .52642 L F
.48282 .52873 m .48396 .52652 L .48542 .528 L F
.48282 .52873 m .48136 .52725 L .48396 .52652 L F
.60144 .52894 m .60275 .52671 L .6041 .52808 L 0 .027 .126 r
F
.60144 .52894 m .60009 .52756 L .60275 .52671 L F
.5268 .52859 m .528 .52631 L .52942 .5277 L 0 .026 .125 r
F
.5268 .52859 m .52538 .52719 L .528 .52631 L F
.44549 .5286 m .44659 .5263 L .44807 .52782 L F
.44549 .5286 m .444 .5271 L .44659 .5263 L F
.6081 .52864 m .60942 .52653 L .61077 .52791 L F
.6081 .52864 m .60676 .52727 L .60942 .52653 L F
.37084 .52829 m .37183 .52597 L .37339 .52745 L 0 .025 .124 r
F
.37084 .52829 m .36928 .52683 L .37183 .52597 L F
.53345 .52831 m .53467 .526 L .53608 .5275 L F
.53345 .52831 m .53204 .52682 L .53467 .526 L F
.57078 .52851 m .57205 .5263 L .57342 .52778 L 0 .026 .125 r
F
.57078 .52851 m .5694 .52704 L .57205 .5263 L F
.40816 .52865 m .4092 .52648 L .41072 .52791 L F
.40816 .52865 m .40663 .5272 L .4092 .52648 L F
.45214 .52848 m .45324 .52626 L .45473 .5277 L F
.45214 .52848 m .45066 .52704 L .45324 .52626 L F
.37749 .52814 m .37849 .52588 L .38004 .52737 L 0 .025 .124 r
F
.37749 .52814 m .37594 .52665 L .37849 .52588 L F
.34016 .52796 m .34111 .52569 L .34269 .52719 L 0 .025 .123 r
F
.34016 .52796 m .33858 .52645 L .34111 .52569 L F
.48947 .52881 m .49062 .5265 L .49207 .52805 L 0 .027 .126 r
F
.48947 .52881 m .48802 .52727 L .49062 .5265 L F
.61477 .52865 m .6161 .52643 L .61744 .52791 L 0 .026 .126 r
F
.61477 .52865 m .61343 .52717 L .6161 .52643 L F
.54011 .52831 m .54134 .52604 L .54274 .52758 L 0 .026 .125 r
F
.54011 .52831 m .53871 .52677 L .54134 .52604 L F
.41481 .52852 m .41586 .52626 L .41738 .52769 L F
.41481 .52852 m .41329 .52709 L .41586 .52626 L F
.57744 .52853 m .57872 .52632 L .58009 .5278 L F
.57744 .52853 m .57607 .52705 L .57872 .52632 L F
.45879 .52843 m .4599 .52631 L .46138 .52774 L F
.45879 .52843 m .45731 .527 L .4599 .52631 L F
.38413 .52808 m .38514 .52587 L .38668 .52736 L 0 .025 .124 r
F
.38413 .52808 m .38259 .52661 L .38514 .52587 L F
.3468 .52792 m .34776 .52563 L .34934 .52712 L F
.3468 .52792 m .34522 .52642 L .34776 .52563 L F
.42146 .52835 m .42252 .52599 L .42403 .52748 L 0 .026 .125 r
F
.42146 .52835 m .41995 .52684 L .42252 .52599 L F
.49612 .5288 m .49729 .52644 L .49873 .52801 L 0 .027 .126 r
F
.49612 .5288 m .49468 .52724 L .49729 .52644 L F
.42812 .52807 m .42919 .52584 L .43069 .5273 L 0 .026 .124 r
F
.42812 .52807 m .42661 .5266 L .42919 .52584 L F
.35345 .52777 m .35442 .52541 L .35599 .5269 L 0 .025 .123 r
F
.35345 .52777 m .35188 .52626 L .35442 .52541 L F
.62144 .52872 m .62277 .52641 L .62411 .52796 L 0 .027 .126 r
F
.62144 .52872 m .6201 .52717 L .62277 .52641 L F
.54677 .52839 m .54801 .52613 L .54941 .52767 L 0 .026 .125 r
F
.54677 .52839 m .54537 .52685 L .54801 .52613 L F
.58411 .5286 m .58539 .52633 L .58676 .52788 L 0 .027 .126 r
F
.58411 .5286 m .58274 .52707 L .58539 .52633 L F
.50278 .52863 m .50395 .52642 L .50539 .52782 L F
.50278 .52863 m .50134 .52722 L .50395 .52642 L F
.46545 .52845 m .46657 .52615 L .46804 .52761 L F
.46545 .52845 m .46397 .527 L .46657 .52615 L F
.39078 .52809 m .39179 .52589 L .39333 .52735 L 0 .026 .125 r
F
.39078 .52809 m .38924 .52665 L .39179 .52589 L F
.43477 .52802 m .43585 .5258 L .43734 .52726 L F
.43477 .52802 m .43327 .52656 L .43585 .5258 L F
.36009 .52766 m .36107 .52542 L .36263 .52693 L 0 .025 .124 r
F
.36009 .52766 m .35853 .52614 L .36107 .52542 L F
.50944 .52842 m .51062 .52629 L .51205 .52768 L 0 .027 .126 r
F
.50944 .52842 m .508 .52703 L .51062 .52629 L F
.62811 .52862 m .62945 .5262 L .63078 .52772 L F
.62811 .52862 m .62678 .52708 L .62945 .5262 L F
.4721 .52826 m .47323 .52597 L .4747 .52744 L 0 .026 .125 r
F
.4721 .52826 m .47064 .52677 L .47323 .52597 L F
.39742 .52799 m .39845 .5257 L .39999 .52718 L F
.39742 .52799 m .39589 .52652 L .39845 .5257 L F
.55344 .52837 m .55468 .52607 L .55607 .52751 L 0 .027 .126 r
F
.55344 .52837 m .55204 .52693 L .55468 .52607 L F
.59078 .52861 m .59207 .52621 L .59343 .52775 L F
.59078 .52861 m .58941 .52706 L .59207 .52621 L F
.47876 .52807 m .4799 .52583 L .48136 .52725 L 0 .026 .125 r
F
.47876 .52807 m .4773 .52663 L .4799 .52583 L F
.5601 .52809 m .56135 .52581 L .56273 .52725 L F
.5601 .52809 m .55871 .52665 L .56135 .52581 L F
.44142 .52791 m .44251 .52559 L .444 .5271 L F
.44142 .52791 m .43993 .52643 L .44251 .52559 L F
.5161 .52833 m .51729 .52612 L .51872 .52752 L 0 .027 .126 r
F
.5161 .52833 m .51467 .52695 L .51729 .52612 L F
.59744 .5284 m .59874 .52606 L .60009 .52756 L F
.59744 .5284 m .59608 .5269 L .59874 .52606 L F
.52276 .52804 m .52396 .52579 L .52538 .52719 L 0 .026 .125 r
F
.52276 .52804 m .52134 .52666 L .52396 .52579 L F
.56676 .52788 m .56802 .52559 L .5694 .52704 L F
.56676 .52788 m .56538 .52642 L .56802 .52559 L F
.36673 .52769 m .36773 .52533 L .36928 .52683 L 0 .025 .124 r
F
.36673 .52769 m .36518 .52618 L .36773 .52533 L F
.52942 .5277 m .53063 .52543 L .53204 .52682 L 0 .026 .124 r
F
.52942 .5277 m .528 .52631 L .53063 .52543 L F
.6041 .52808 m .60541 .52591 L .60676 .52727 L 0 .027 .126 r
F
.6041 .52808 m .60275 .52671 L .60541 .52591 L F
.40407 .52792 m .40511 .52574 L .40663 .5272 L 0 .026 .125 r
F
.40407 .52792 m .40255 .52644 L .40511 .52574 L F
.48542 .528 m .48656 .52578 L .48802 .52727 L F
.48542 .528 m .48396 .52652 L .48656 .52578 L F
.44807 .52782 m .44917 .52552 L .45066 .52704 L F
.44807 .52782 m .44659 .5263 L .44917 .52552 L F
.37339 .52745 m .37439 .52516 L .37594 .52665 L 0 .025 .124 r
F
.37339 .52745 m .37183 .52597 L .37439 .52516 L F
.53608 .5275 m .5373 .52527 L .53871 .52677 L F
.53608 .5275 m .53467 .526 L .5373 .52527 L F
.61077 .52791 m .61209 .52579 L .61343 .52717 L 0 .026 .126 r
F
.61077 .52791 m .60942 .52653 L .61209 .52579 L F
.57342 .52778 m .57469 .52558 L .57607 .52705 L 0 .026 .125 r
F
.57342 .52778 m .57205 .5263 L .57469 .52558 L F
.45473 .5277 m .45583 .52555 L .45731 .527 L F
.45473 .5277 m .45324 .52626 L .45583 .52555 L F
.41072 .52791 m .41177 .52566 L .41329 .52709 L 0 .026 .126 r
F
.41072 .52791 m .4092 .52648 L .41177 .52566 L F
.38004 .52737 m .38104 .52511 L .38259 .52661 L 0 .025 .124 r
F
.38004 .52737 m .37849 .52588 L .38104 .52511 L F
.34269 .52719 m .34364 .52492 L .34522 .52642 L 0 .025 .123 r
F
.34269 .52719 m .34111 .52569 L .34364 .52492 L F
.49207 .52805 m .49323 .52568 L .49468 .52724 L 0 .027 .126 r
F
.49207 .52805 m .49062 .5265 L .49323 .52568 L F
.41738 .52769 m .41843 .52543 L .41995 .52684 L 0 .026 .125 r
F
.41738 .52769 m .41586 .52626 L .41843 .52543 L F
.61744 .52791 m .61877 .52568 L .6201 .52717 L 0 .027 .126 r
F
.61744 .52791 m .6161 .52643 L .61877 .52568 L F
.54274 .52758 m .54397 .52531 L .54537 .52685 L 0 .026 .125 r
F
.54274 .52758 m .54134 .52604 L .54397 .52531 L F
.58009 .5278 m .58137 .52557 L .58274 .52707 L 0 .027 .126 r
F
.58009 .5278 m .57872 .52632 L .58137 .52557 L F
.42403 .52748 m .4251 .52513 L .42661 .5266 L 0 .026 .124 r
F
.42403 .52748 m .42252 .52599 L .4251 .52513 L F
.34934 .52712 m .3503 .52478 L .35188 .52626 L 0 .025 .123 r
F
.34934 .52712 m .34776 .52563 L .3503 .52478 L F
.38668 .52736 m .3877 .52513 L .38924 .52665 L 0 .026 .125 r
F
.38668 .52736 m .38514 .52587 L .3877 .52513 L F
.46138 .52774 m .4625 .52555 L .46397 .527 L 0 .027 .126 r
F
.46138 .52774 m .4599 .52631 L .4625 .52555 L F
.35599 .5269 m .35696 .52466 L .35853 .52614 L 0 .025 .123 r
F
.35599 .5269 m .35442 .52541 L .35696 .52466 L F
.49873 .52801 m .4999 .52565 L .50134 .52722 L 0 .027 .126 r
F
.49873 .52801 m .49729 .52644 L .4999 .52565 L F
.43069 .5273 m .43176 .5251 L .43327 .52656 L 0 .026 .125 r
F
.43069 .5273 m .42919 .52584 L .43176 .5251 L F
.62411 .52796 m .62544 .52554 L .62678 .52708 L 0 .027 .126 r
F
.62411 .52796 m .62277 .52641 L .62544 .52554 L F
.46804 .52761 m .46917 .5253 L .47064 .52677 L 0 .026 .125 r
F
.46804 .52761 m .46657 .52615 L .46917 .5253 L F
.50539 .52782 m .50657 .52563 L .508 .52703 L 0 .027 .126 r
F
.50539 .52782 m .50395 .52642 L .50657 .52563 L F
.54941 .52767 m .55064 .52538 L .55204 .52693 L F
.54941 .52767 m .54801 .52613 L .55064 .52538 L F
.58676 .52788 m .58805 .52552 L .58941 .52706 L F
.58676 .52788 m .58539 .52633 L .58805 .52552 L F
.39333 .52735 m .39435 .52506 L .39589 .52652 L 0 .026 .125 r
F
.39333 .52735 m .39179 .52589 L .39435 .52506 L F
.63078 .52772 m .63212 .52532 L .63345 .52684 L 0 .027 .126 r
F
.63078 .52772 m .62945 .5262 L .63212 .52532 L F
.4747 .52744 m .47583 .52519 L .4773 .52663 L 0 .026 .125 r
F
.4747 .52744 m .47323 .52597 L .47583 .52519 L F
.43734 .52726 m .43843 .52495 L .43993 .52643 L F
.43734 .52726 m .43585 .5258 L .43843 .52495 L F
.36263 .52693 m .36361 .52467 L .36518 .52618 L 0 .025 .124 r
F
.36263 .52693 m .36107 .52542 L .36361 .52467 L F
.51205 .52768 m .51324 .52555 L .51467 .52695 L 0 .027 .126 r
F
.51205 .52768 m .51062 .52629 L .51324 .52555 L F
.55607 .52751 m .55732 .5252 L .55871 .52665 L 0 .026 .126 r
F
.55607 .52751 m .55468 .52607 L .55732 .5252 L F
.39999 .52718 m .40102 .52495 L .40255 .52644 L 0 .026 .125 r
F
.39999 .52718 m .39845 .5257 L .40102 .52495 L F
.59343 .52775 m .59472 .52535 L .59608 .5269 L 0 .027 .126 r
F
.59343 .52775 m .59207 .52621 L .59472 .52535 L F
.56273 .52725 m .56399 .52498 L .56538 .52642 L 0 .026 .125 r
F
.56273 .52725 m .56135 .52581 L .56399 .52498 L F
.48136 .52725 m .4825 .52509 L .48396 .52652 L F
.48136 .52725 m .4799 .52583 L .4825 .52509 L F
.444 .5271 m .4451 .52478 L .44659 .5263 L F
.444 .5271 m .44251 .52559 L .4451 .52478 L F
.51872 .52752 m .51991 .52525 L .52134 .52666 L 0 .027 .126 r
F
.51872 .52752 m .51729 .52612 L .51991 .52525 L F
.53204 .52682 m .53325 .52461 L .53467 .526 L 0 .025 .124 r
F
.53204 .52682 m .53063 .52543 L .53325 .52461 L F
.60009 .52756 m .6014 .52523 L .60275 .52671 L 0 .027 .126 r
F
.60009 .52756 m .59874 .52606 L .6014 .52523 L F
.52538 .52719 m .52658 .52492 L .528 .52631 L 0 .026 .125 r
F
.52538 .52719 m .52396 .52579 L .52658 .52492 L F
.36928 .52683 m .37028 .52448 L .37183 .52597 L 0 .025 .124 r
F
.36928 .52683 m .36773 .52533 L .37028 .52448 L F
.5694 .52704 m .57067 .52484 L .57205 .5263 L 0 .026 .125 r
F
.5694 .52704 m .56802 .52559 L .57067 .52484 L F
.60676 .52727 m .60808 .52516 L .60942 .52653 L 0 .027 .126 r
F
.60676 .52727 m .60541 .52591 L .60808 .52516 L F
.33858 .52645 m .33952 .52424 L .34111 .52569 L 0 .025 .123 r
F
.33858 .52645 m .33699 .52502 L .33952 .52424 L F
.40663 .5272 m .40767 .52503 L .4092 .52648 L 0 .026 .126 r
F
.40663 .5272 m .40511 .52574 L .40767 .52503 L F
.37594 .52665 m .37694 .52439 L .37849 .52588 L 0 .025 .124 r
F
.37594 .52665 m .37439 .52516 L .37694 .52439 L F
.45066 .52704 m .45176 .52474 L .45324 .52626 L 0 .026 .125 r
F
.45066 .52704 m .44917 .52552 L .45176 .52474 L F
.48802 .52727 m .48917 .525 L .49062 .5265 L 0 .027 .126 r
F
.48802 .52727 m .48656 .52578 L .48917 .525 L F
.53871 .52677 m .53993 .52454 L .54134 .52604 L 0 .026 .124 r
F
.53871 .52677 m .5373 .52527 L .53993 .52454 L F
.61343 .52717 m .61476 .52504 L .6161 .52643 L 0 .027 .126 r
F
.61343 .52717 m .61209 .52579 L .61476 .52504 L F
.57607 .52705 m .57734 .52484 L .57872 .52632 L 0 .026 .125 r
F
.57607 .52705 m .57469 .52558 L .57734 .52484 L F
.41329 .52709 m .41434 .52484 L .41586 .52626 L F
.41329 .52709 m .41177 .52566 L .41434 .52484 L F
.38259 .52661 m .3836 .52435 L .38514 .52587 L 0 .025 .124 r
F
.38259 .52661 m .38104 .52511 L .3836 .52435 L F
.34522 .52642 m .34618 .52413 L .34776 .52563 L F
.34522 .52642 m .34364 .52492 L .34618 .52413 L F
.45731 .527 m .45842 .52485 L .4599 .52631 L 0 .026 .126 r
F
.45731 .527 m .45583 .52555 L .45842 .52485 L F
.41995 .52684 m .42101 .52459 L .42252 .52599 L 0 .026 .125 r
F
.41995 .52684 m .41843 .52543 L .42101 .52459 L F
.49468 .52724 m .49584 .52486 L .49729 .52644 L 0 .027 .126 r
F
.49468 .52724 m .49323 .52568 L .49584 .52486 L F
.42661 .5266 m .42768 .52437 L .42919 .52584 L 0 .026 .124 r
F
.42661 .5266 m .4251 .52513 L .42768 .52437 L F
.6201 .52717 m .62144 .52491 L .62277 .52641 L 0 .027 .126 r
F
.6201 .52717 m .61877 .52568 L .62144 .52491 L F
.35188 .52626 m .35285 .52394 L .35442 .52541 L 0 .025 .123 r
F
.35188 .52626 m .3503 .52478 L .35285 .52394 L F
.54537 .52685 m .5466 .52457 L .54801 .52613 L 0 .026 .125 r
F
.54537 .52685 m .54397 .52531 L .5466 .52457 L F
.58274 .52707 m .58402 .52481 L .58539 .52633 L 0 .027 .126 r
F
.58274 .52707 m .58137 .52557 L .58402 .52481 L F
.46397 .527 m .46509 .52469 L .46657 .52615 L F
.46397 .527 m .4625 .52555 L .46509 .52469 L F
.38924 .52665 m .39025 .52437 L .39179 .52589 L 0 .026 .125 r
F
.38924 .52665 m .3877 .52513 L .39025 .52437 L F
.50134 .52722 m .50251 .52488 L .50395 .52642 L 0 .027 .126 r
F
.50134 .52722 m .4999 .52565 L .50251 .52488 L F
.35853 .52614 m .3595 .52393 L .36107 .52542 L 0 .025 .124 r
F
.35853 .52614 m .35696 .52466 L .3595 .52393 L F
.62678 .52708 m .62812 .52467 L .62945 .5262 L 0 .027 .126 r
F
.62678 .52708 m .62544 .52554 L .62812 .52467 L F
.43327 .52656 m .43434 .52433 L .43585 .5258 L 0 .026 .125 r
F
.43327 .52656 m .43176 .5251 L .43434 .52433 L F
.47064 .52677 m .47176 .5245 L .47323 .52597 L F
.47064 .52677 m .46917 .5253 L .47176 .5245 L F
.63345 .52684 m .6348 .52445 L .63612 .52595 L F
.63345 .52684 m .63212 .52532 L .6348 .52445 L F
.508 .52703 m .50918 .52489 L .51062 .52629 L 0 .027 .127 r
F
.508 .52703 m .50657 .52563 L .50918 .52489 L F
.58941 .52706 m .5907 .52467 L .59207 .52621 L 0 .027 .126 r
F
.58941 .52706 m .58805 .52552 L .5907 .52467 L F
.39589 .52652 m .39692 .52422 L .39845 .5257 L 0 .026 .125 r
F
.39589 .52652 m .39435 .52506 L .39692 .52422 L F
.55204 .52693 m .55328 .52452 L .55468 .52607 L 0 .027 .126 r
F
.55204 .52693 m .55064 .52538 L .55328 .52452 L F
.43993 .52643 m .44101 .5241 L .44251 .52559 L 0 .026 .125 r
F
.43993 .52643 m .43843 .52495 L .44101 .5241 L F
.4773 .52663 m .47844 .52441 L .4799 .52583 L F
.4773 .52663 m .47583 .52519 L .47844 .52441 L F
.55871 .52665 m .55996 .52436 L .56135 .52581 L F
.55871 .52665 m .55732 .5252 L .55996 .52436 L F
.59608 .5269 m .59738 .52453 L .59874 .52606 L 0 .027 .126 r
F
.59608 .5269 m .59472 .52535 L .59738 .52453 L F
.36518 .52618 m .36617 .52382 L .36773 .52533 L 0 .025 .124 r
F
.36518 .52618 m .36361 .52467 L .36617 .52382 L F
.51467 .52695 m .51586 .52472 L .51729 .52612 L 0 .027 .127 r
F
.51467 .52695 m .51324 .52555 L .51586 .52472 L F
.56538 .52642 m .56663 .52415 L .56802 .52559 L 0 .026 .125 r
F
.56538 .52642 m .56399 .52498 L .56663 .52415 L F
.40255 .52644 m .40358 .52425 L .40511 .52574 L F
.40255 .52644 m .40102 .52495 L .40358 .52425 L F
.52134 .52666 m .52253 .52438 L .52396 .52579 L 0 .027 .126 r
F
.52134 .52666 m .51991 .52525 L .52253 .52438 L F
.44659 .5263 m .44768 .524 L .44917 .52552 L 0 .026 .125 r
F
.44659 .5263 m .4451 .52478 L .44768 .524 L F
.528 .52631 m .52921 .52404 L .53063 .52543 L F
.528 .52631 m .52658 .52492 L .52921 .52404 L F
.48396 .52652 m .48511 .52435 L .48656 .52578 L 0 .026 .126 r
F
.48396 .52652 m .4825 .52509 L .48511 .52435 L F
.60275 .52671 m .60406 .52442 L .60541 .52591 L 0 .027 .126 r
F
.60275 .52671 m .6014 .52523 L .60406 .52442 L F
.37183 .52597 m .37283 .52367 L .37439 .52516 L 0 .025 .124 r
F
.37183 .52597 m .37028 .52448 L .37283 .52367 L F
.53467 .526 m .53589 .52388 L .5373 .52527 L F
.53467 .526 m .53325 .52461 L .53589 .52388 L F
.57205 .5263 m .57331 .52411 L .57469 .52558 L 0 .026 .125 r
F
.57205 .5263 m .57067 .52484 L .57331 .52411 L F
.60942 .52653 m .61075 .52441 L .61209 .52579 L 0 .027 .126 r
F
.60942 .52653 m .60808 .52516 L .61075 .52441 L F
.34111 .52569 m .34206 .52346 L .34364 .52492 L 0 .025 .123 r
F
.34111 .52569 m .33952 .52424 L .34206 .52346 L F
.37849 .52588 m .37949 .52362 L .38104 .52511 L 0 .025 .124 r
F
.37849 .52588 m .37694 .52439 L .37949 .52362 L F
.45324 .52626 m .45435 .52402 L .45583 .52555 L 0 .026 .125 r
F
.45324 .52626 m .45176 .52474 L .45435 .52402 L F
.4092 .52648 m .41024 .5242 L .41177 .52566 L 0 .027 .126 r
F
.4092 .52648 m .40767 .52503 L .41024 .5242 L F
.49062 .5265 m .49178 .52417 L .49323 .52568 L F
.49062 .5265 m .48917 .525 L .49178 .52417 L F
.54134 .52604 m .54256 .5238 L .54397 .52531 L 0 .026 .125 r
F
.54134 .52604 m .53993 .52454 L .54256 .5238 L F
.6161 .52643 m .61743 .52428 L .61877 .52568 L 0 .027 .126 r
F
.6161 .52643 m .61476 .52504 L .61743 .52428 L F
.41586 .52626 m .41691 .52402 L .41843 .52543 L 0 .026 .125 r
F
.41586 .52626 m .41434 .52484 L .41691 .52402 L F
.57872 .52632 m .58 .52407 L .58137 .52557 L 0 .027 .126 r
F
.57872 .52632 m .57734 .52484 L .58 .52407 L F
.42252 .52599 m .42359 .52375 L .4251 .52513 L 0 .026 .125 r
F
.42252 .52599 m .42101 .52459 L .42359 .52375 L F
.34776 .52563 m .34873 .5233 L .3503 .52478 L 0 .025 .124 r
F
.34776 .52563 m .34618 .52413 L .34873 .5233 L F
.38514 .52587 m .38615 .5236 L .3877 .52513 L 0 .026 .124 r
F
.38514 .52587 m .3836 .52435 L .38615 .5236 L F
.49729 .52644 m .49845 .52409 L .4999 .52565 L 0 .027 .126 r
F
.49729 .52644 m .49584 .52486 L .49845 .52409 L F
.4599 .52631 m .46102 .52409 L .4625 .52555 L F
.4599 .52631 m .45842 .52485 L .46102 .52409 L F
.35442 .52541 m .35539 .5232 L .35696 .52466 L 0 .025 .123 r
F
.35442 .52541 m .35285 .52394 L .35539 .5232 L F
.42919 .52584 m .43026 .52363 L .43176 .5251 L 0 .026 .125 r
F
.42919 .52584 m .42768 .52437 L .43026 .52363 L F
.62277 .52641 m .62411 .52405 L .62544 .52554 L 0 .027 .126 r
F
.62277 .52641 m .62144 .52491 L .62411 .52405 L F
.54801 .52613 m .54924 .52382 L .55064 .52538 L 0 .026 .125 r
F
.54801 .52613 m .5466 .52457 L .54924 .52382 L F
.58539 .52633 m .58668 .52401 L .58805 .52552 L 0 .027 .126 r
F
.58539 .52633 m .58402 .52481 L .58668 .52401 L F
.46657 .52615 m .46769 .52384 L .46917 .5253 L 0 .026 .126 r
F
.46657 .52615 m .46509 .52469 L .46769 .52384 L F
.62945 .5262 m .63079 .5238 L .63212 .52532 L F
.62945 .5262 m .62812 .52467 L .63079 .5238 L F
.50395 .52642 m .50513 .52411 L .50657 .52563 L 0 .027 .126 r
F
.50395 .52642 m .50251 .52488 L .50513 .52411 L F
.39179 .52589 m .39282 .52353 L .39435 .52506 L 0 .026 .125 r
F
.39179 .52589 m .39025 .52437 L .39282 .52353 L F
.63612 .52595 m .63747 .52358 L .6388 .52507 L F
.63612 .52595 m .6348 .52445 L .63747 .52358 L F
.47323 .52597 m .47437 .52373 L .47583 .52519 L F
.47323 .52597 m .47176 .5245 L .47437 .52373 L F
.36107 .52542 m .36205 .52319 L .36361 .52467 L 0 .025 .124 r
F
.36107 .52542 m .3595 .52393 L .36205 .52319 L F
.43585 .5258 m .43693 .52348 L .43843 .52495 L 0 .026 .125 r
F
.43585 .5258 m .43434 .52433 L .43693 .52348 L F
.59207 .52621 m .59336 .52382 L .59472 .52535 L 0 .027 .126 r
F
.59207 .52621 m .5907 .52467 L .59336 .52382 L F
.55468 .52607 m .55592 .52366 L .55732 .5252 L 0 .026 .126 r
F
.55468 .52607 m .55328 .52452 L .55592 .52366 L F
.39845 .5257 m .39948 .52347 L .40102 .52495 L 0 .026 .125 r
F
.39845 .5257 m .39692 .52422 L .39948 .52347 L F
.51062 .52629 m .5118 .52415 L .51324 .52555 L 0 .027 .127 r
F
.51062 .52629 m .50918 .52489 L .5118 .52415 L F
.44251 .52559 m .4436 .5233 L .4451 .52478 L 0 .026 .125 r
F
.44251 .52559 m .44101 .5241 L .4436 .5233 L F
.56135 .52581 m .5626 .52354 L .56399 .52498 L F
.56135 .52581 m .55996 .52436 L .5626 .52354 L F
.4799 .52583 m .48104 .52366 L .4825 .52509 L 0 .026 .126 r
F
.4799 .52583 m .47844 .52441 L .48104 .52366 L F
.59874 .52606 m .60004 .52371 L .6014 .52523 L 0 .027 .126 r
F
.59874 .52606 m .59738 .52453 L .60004 .52371 L F
.36773 .52533 m .36872 .52298 L .37028 .52448 L 0 .025 .124 r
F
.36773 .52533 m .36617 .52382 L .36872 .52298 L F
.51729 .52612 m .51848 .52383 L .51991 .52525 L 0 .027 .126 r
F
.51729 .52612 m .51586 .52472 L .51848 .52383 L F
.56802 .52559 m .56928 .52339 L .57067 .52484 L 0 .026 .125 r
F
.56802 .52559 m .56663 .52415 L .56928 .52339 L F
.52396 .52579 m .52516 .5235 L .52658 .52492 L F
.52396 .52579 m .52253 .52438 L .52516 .5235 L F
.53063 .52543 m .53184 .52322 L .53325 .52461 L F
.53063 .52543 m .52921 .52404 L .53184 .52322 L F
.44917 .52552 m .45027 .52321 L .45176 .52474 L F
.44917 .52552 m .44768 .524 L .45027 .52321 L F
.37439 .52516 m .37538 .52292 L .37694 .52439 L 0 .025 .124 r
F
.37439 .52516 m .37283 .52367 L .37538 .52292 L F
.60541 .52591 m .60673 .52366 L .60808 .52516 L 0 .027 .126 r
F
.60541 .52591 m .60406 .52442 L .60673 .52366 L F
.40511 .52574 m .40615 .52353 L .40767 .52503 L F
.40511 .52574 m .40358 .52425 L .40615 .52353 L F
.33699 .52502 m .33793 .5228 L .33952 .52424 L 0 .025 .124 r
F
.33699 .52502 m .3354 .5236 L .33793 .5228 L F
.48656 .52578 m .48772 .52356 L .48917 .525 L 0 .027 .126 r
F
.48656 .52578 m .48511 .52435 L .48772 .52356 L F
.5373 .52527 m .53852 .52315 L .53993 .52454 L 0 .026 .125 r
F
.5373 .52527 m .53589 .52388 L .53852 .52315 L F
.57469 .52558 m .57597 .52335 L .57734 .52484 L F
.57469 .52558 m .57331 .52411 L .57597 .52335 L F
.61209 .52579 m .61342 .52364 L .61476 .52504 L 0 .027 .126 r
F
.61209 .52579 m .61075 .52441 L .61342 .52364 L F
.41177 .52566 m .41282 .52338 L .41434 .52484 L F
.41177 .52566 m .41024 .5242 L .41282 .52338 L F
.34364 .52492 m .3446 .52265 L .34618 .52413 L 0 .025 .124 r
F
.34364 .52492 m .34206 .52346 L .3446 .52265 L F
.38104 .52511 m .38205 .52284 L .3836 .52435 L F
.38104 .52511 m .37949 .52362 L .38205 .52284 L F
.49323 .52568 m .49439 .52333 L .49584 .52486 L 0 .027 .126 r
F
.49323 .52568 m .49178 .52417 L .49439 .52333 L F
.45583 .52555 m .45694 .5233 L .45842 .52485 L 0 .026 .126 r
F
.45583 .52555 m .45435 .52402 L .45694 .5233 L F
.41843 .52543 m .41949 .52319 L .42101 .52459 L 0 .026 .125 r
F
.41843 .52543 m .41691 .52402 L .41949 .52319 L F
.54397 .52531 m .5452 .52305 L .5466 .52457 L F
.54397 .52531 m .54256 .5238 L .5452 .52305 L F
.61877 .52568 m .6201 .5235 L .62144 .52491 L 0 .027 .126 r
F
.61877 .52568 m .61743 .52428 L .6201 .5235 L F
.4251 .52513 m .42617 .52299 L .42768 .52437 L 0 .026 .125 r
F
.4251 .52513 m .42359 .52375 L .42617 .52299 L F
.3503 .52478 m .35127 .52247 L .35285 .52394 L 0 .025 .123 r
F
.3503 .52478 m .34873 .5233 L .35127 .52247 L F
.58137 .52557 m .58265 .5233 L .58402 .52481 L 0 .027 .126 r
F
.58137 .52557 m .58 .52407 L .58265 .5233 L F
.4999 .52565 m .50107 .52333 L .50251 .52488 L F
.4999 .52565 m .49845 .52409 L .50107 .52333 L F
.3877 .52513 m .38871 .52282 L .39025 .52437 L 0 .026 .125 r
F
.3877 .52513 m .38615 .5236 L .38871 .52282 L F
.62544 .52554 m .62678 .52319 L .62812 .52467 L 0 .027 .126 r
F
.62544 .52554 m .62411 .52405 L .62678 .52319 L F
.4625 .52555 m .46362 .52322 L .46509 .52469 L F
.4625 .52555 m .46102 .52409 L .46362 .52322 L F
.35696 .52466 m .35793 .52248 L .3595 .52393 L 0 .025 .124 r
F
.35696 .52466 m .35539 .5232 L .35793 .52248 L F
.43176 .5251 m .43284 .52287 L .43434 .52433 L 0 .026 .125 r
F
.43176 .5251 m .43026 .52363 L .43284 .52287 L F
.46917 .5253 m .47029 .52303 L .47176 .5245 L F
.46917 .5253 m .46769 .52384 L .47029 .52303 L F
.63212 .52532 m .63347 .52295 L .6348 .52445 L F
.63212 .52532 m .63079 .5238 L .63347 .52295 L F
.58805 .52552 m .58934 .52319 L .5907 .52467 L 0 .027 .126 r
F
.58805 .52552 m .58668 .52401 L .58934 .52319 L F
.55064 .52538 m .55188 .52296 L .55328 .52452 L 0 .026 .126 r
F
.55064 .52538 m .54924 .52382 L .55188 .52296 L F
.39435 .52506 m .39538 .52268 L .39692 .52422 L 0 .026 .125 r
F
.39435 .52506 m .39282 .52353 L .39538 .52268 L F
.6388 .52507 m .64016 .52283 L .64148 .52433 L F
.6388 .52507 m .63747 .52358 L .64016 .52283 L F
.50657 .52563 m .50775 .52338 L .50918 .52489 L 0 .027 .127 r
F
.50657 .52563 m .50513 .52411 L .50775 .52338 L F
.43843 .52495 m .43952 .52263 L .44101 .5241 L 0 .026 .125 r
F
.43843 .52495 m .43693 .52348 L .43952 .52263 L F
.59472 .52535 m .59602 .52301 L .59738 .52453 L 0 .027 .126 r
F
.59472 .52535 m .59336 .52382 L .59602 .52301 L F
.47583 .52519 m .47697 .52295 L .47844 .52441 L 0 .026 .126 r
F
.47583 .52519 m .47437 .52373 L .47697 .52295 L F
.55732 .5252 m .55856 .52283 L .55996 .52436 L 0 .026 .125 r
F
.55732 .5252 m .55592 .52366 L .55856 .52283 L F
.36361 .52467 m .3646 .52235 L .36617 .52382 L 0 .025 .124 r
F
.36361 .52467 m .36205 .52319 L .3646 .52235 L F
.40102 .52495 m .40205 .52275 L .40358 .52425 L 0 .026 .125 r
F
.40102 .52495 m .39948 .52347 L .40205 .52275 L F
.4451 .52478 m .44619 .52252 L .44768 .524 L F
.4451 .52478 m .4436 .5233 L .44619 .52252 L F
.56399 .52498 m .56525 .52272 L .56663 .52415 L F
.56399 .52498 m .5626 .52354 L .56525 .52272 L F
.51324 .52555 m .51443 .52331 L .51586 .52472 L 0 .027 .127 r
F
.51324 .52555 m .5118 .52415 L .51443 .52331 L F
.37028 .52448 m .37127 .52218 L .37283 .52367 L 0 .025 .124 r
F
.37028 .52448 m .36872 .52298 L .37127 .52218 L F
.6014 .52523 m .60271 .5229 L .60406 .52442 L 0 .027 .126 r
F
.6014 .52523 m .60004 .52371 L .60271 .5229 L F
.51991 .52525 m .52111 .52295 L .52253 .52438 L F
.51991 .52525 m .51848 .52383 L .52111 .52295 L F
.4825 .52509 m .48365 .52291 L .48511 .52435 L F
.4825 .52509 m .48104 .52366 L .48365 .52291 L F
.52658 .52492 m .52779 .52263 L .52921 .52404 L 0 .026 .125 r
F
.52658 .52492 m .52516 .5235 L .52779 .52263 L F
.53325 .52461 m .53447 .52249 L .53589 .52388 L F
.53325 .52461 m .53184 .52322 L .53447 .52249 L F
.57067 .52484 m .57193 .52264 L .57331 .52411 L F
.57067 .52484 m .56928 .52339 L .57193 .52264 L F
.45176 .52474 m .45286 .52248 L .45435 .52402 L F
.45176 .52474 m .45027 .52321 L .45286 .52248 L F
.37694 .52439 m .37794 .52216 L .37949 .52362 L 0 .025 .124 r
F
.37694 .52439 m .37538 .52292 L .37794 .52216 L F
.60808 .52516 m .6094 .5229 L .61075 .52441 L 0 .027 .126 r
F
.60808 .52516 m .60673 .52366 L .6094 .5229 L F
.33952 .52424 m .34047 .52199 L .34206 .52346 L 0 .025 .124 r
F
.33952 .52424 m .33793 .5228 L .34047 .52199 L F
.48917 .525 m .49033 .52272 L .49178 .52417 L 0 .027 .126 r
F
.48917 .525 m .48772 .52356 L .49033 .52272 L F
.40767 .52503 m .40872 .52269 L .41024 .5242 L F
.40767 .52503 m .40615 .52353 L .40872 .52269 L F
.53993 .52454 m .54115 .5224 L .54256 .5238 L 0 .026 .125 r
F
.53993 .52454 m .53852 .52315 L .54115 .5224 L F
.57734 .52484 m .57862 .52256 L .58 .52407 L 0 .027 .126 r
F
.57734 .52484 m .57597 .52335 L .57862 .52256 L F
.41434 .52484 m .41539 .52256 L .41691 .52402 L F
.41434 .52484 m .41282 .52338 L .41539 .52256 L F
.61476 .52504 m .61609 .52287 L .61743 .52428 L F
.61476 .52504 m .61342 .52364 L .61609 .52287 L F
.49584 .52486 m .49701 .52258 L .49845 .52409 L F
.49584 .52486 m .49439 .52333 L .49701 .52258 L F
.34618 .52413 m .34715 .52182 L .34873 .5233 L 0 .025 .124 r
F
.34618 .52413 m .3446 .52265 L .34715 .52182 L F
.3836 .52435 m .38461 .52207 L .38615 .5236 L 0 .026 .124 r
F
.3836 .52435 m .38205 .52284 L .38461 .52207 L F
.42101 .52459 m .42207 .52237 L .42359 .52375 L 0 .026 .125 r
F
.42101 .52459 m .41949 .52319 L .42207 .52237 L F
.45842 .52485 m .45954 .52254 L .46102 .52409 L 0 .027 .126 r
F
.45842 .52485 m .45694 .5233 L .45954 .52254 L F
.35285 .52394 m .35381 .52174 L .35539 .5232 L 0 .025 .123 r
F
.35285 .52394 m .35127 .52247 L .35381 .52174 L F
.62144 .52491 m .62278 .52265 L .62411 .52405 L 0 .027 .126 r
F
.62144 .52491 m .6201 .5235 L .62278 .52265 L F
.42768 .52437 m .42875 .52224 L .43026 .52363 L 0 .026 .125 r
F
.42768 .52437 m .42617 .52299 L .42875 .52224 L F
.5466 .52457 m .54784 .52229 L .54924 .52382 L F
.5466 .52457 m .5452 .52305 L .54784 .52229 L F
.58402 .52481 m .58531 .5225 L .58668 .52401 L 0 .027 .126 r
F
.58402 .52481 m .58265 .5233 L .58531 .5225 L F
.62812 .52467 m .62946 .52234 L .63079 .5238 L 0 .026 .126 r
F
.62812 .52467 m .62678 .52319 L .62946 .52234 L F
.50251 .52488 m .50369 .52258 L .50513 .52411 L 0 .027 .126 r
F
.50251 .52488 m .50107 .52333 L .50369 .52258 L F
.46509 .52469 m .46622 .52235 L .46769 .52384 L F
.46509 .52469 m .46362 .52322 L .46622 .52235 L F
.39025 .52437 m .39128 .52197 L .39282 .52353 L 0 .026 .125 r
F
.39025 .52437 m .38871 .52282 L .39128 .52197 L F
.6348 .52445 m .63615 .52209 L .63747 .52358 L F
.6348 .52445 m .63347 .52295 L .63615 .52209 L F
.5907 .52467 m .592 .52236 L .59336 .52382 L 0 .027 .126 r
F
.5907 .52467 m .58934 .52319 L .592 .52236 L F
.3595 .52393 m .36048 .52175 L .36205 .52319 L 0 .025 .124 r
F
.3595 .52393 m .35793 .52248 L .36048 .52175 L F
.47176 .5245 m .4729 .52225 L .47437 .52373 L 0 .026 .126 r
F
.47176 .5245 m .47029 .52303 L .4729 .52225 L F
.43434 .52433 m .43543 .52201 L .43693 .52348 L 0 .026 .125 r
F
.43434 .52433 m .43284 .52287 L .43543 .52201 L F
.55328 .52452 m .55452 .5221 L .55592 .52366 L F
.55328 .52452 m .55188 .52296 L .55452 .5221 L F
.39692 .52422 m .39795 .52193 L .39948 .52347 L F
.39692 .52422 m .39538 .52268 L .39795 .52193 L F
.44101 .5241 m .4421 .52184 L .4436 .5233 L F
.44101 .5241 m .43952 .52263 L .4421 .52184 L F
.64148 .52433 m .64284 .52208 L .64416 .5236 L F
.64148 .52433 m .64016 .52283 L .64284 .52208 L F
.50918 .52489 m .51037 .52265 L .5118 .52415 L 0 .028 .127 r
F
.50918 .52489 m .50775 .52338 L .51037 .52265 L F
.59738 .52453 m .59868 .5222 L .60004 .52371 L 0 .027 .126 r
F
.59738 .52453 m .59602 .52301 L .59868 .5222 L F
.55996 .52436 m .56121 .52202 L .5626 .52354 L 0 .026 .125 r
F
.55996 .52436 m .55856 .52283 L .56121 .52202 L F
.36617 .52382 m .36716 .52151 L .36872 .52298 L 0 .025 .124 r
F
.36617 .52382 m .3646 .52235 L .36716 .52151 L F
.47844 .52441 m .47958 .52218 L .48104 .52366 L 0 .027 .126 r
F
.47844 .52441 m .47697 .52295 L .47958 .52218 L F
.56663 .52415 m .5679 .52194 L .56928 .52339 L 0 .026 .125 r
F
.56663 .52415 m .56525 .52272 L .5679 .52194 L F
.51586 .52472 m .51705 .52241 L .51848 .52383 L 0 .027 .127 r
F
.51586 .52472 m .51443 .52331 L .51705 .52241 L F
.44768 .524 m .44878 .52175 L .45027 .52321 L 0 .026 .125 r
F
.44768 .524 m .44619 .52252 L .44878 .52175 L F
.52253 .52438 m .52374 .52207 L .52516 .5235 L 0 .027 .126 r
F
.52253 .52438 m .52111 .52295 L .52374 .52207 L F
.52921 .52404 m .53042 .5218 L .53184 .52322 L 0 .026 .125 r
F
.52921 .52404 m .52779 .52263 L .53042 .5218 L F
.37283 .52367 m .37383 .52144 L .37538 .52292 L 0 .025 .124 r
F
.37283 .52367 m .37127 .52218 L .37383 .52144 L F
.60406 .52442 m .60538 .52213 L .60673 .52366 L 0 .027 .126 r
F
.60406 .52442 m .60271 .5229 L .60538 .52213 L F
.40358 .52425 m .40462 .52203 L .40615 .52353 L F
.40358 .52425 m .40205 .52275 L .40462 .52203 L F
.3354 .5236 m .33634 .52134 L .33793 .5228 L 0 .025 .124 r
F
.3354 .5236 m .3338 .52216 L .33634 .52134 L F
.48511 .52435 m .48626 .52211 L .48772 .52356 L 0 .027 .126 r
F
.48511 .52435 m .48365 .52291 L .48626 .52211 L F
.53589 .52388 m .53711 .52176 L .53852 .52315 L 0 .026 .125 r
F
.53589 .52388 m .53447 .52249 L .53711 .52176 L F
.57331 .52411 m .57459 .52187 L .57597 .52335 L 0 .026 .126 r
F
.57331 .52411 m .57193 .52264 L .57459 .52187 L F
.49178 .52417 m .49294 .52188 L .49439 .52333 L 0 .027 .126 r
F
.49178 .52417 m .49033 .52272 L .49294 .52188 L F
.37949 .52362 m .3805 .52139 L .38205 .52284 L 0 .025 .124 r
F
.37949 .52362 m .37794 .52216 L .3805 .52139 L F
.34206 .52346 m .34302 .52117 L .3446 .52265 L F
.34206 .52346 m .34047 .52199 L .34302 .52117 L F
.41024 .5242 m .4113 .52185 L .41282 .52338 L 0 .027 .126 r
F
.41024 .5242 m .40872 .52269 L .4113 .52185 L F
.45435 .52402 m .45546 .52176 L .45694 .5233 L 0 .026 .125 r
F
.45435 .52402 m .45286 .52248 L .45546 .52176 L F
.61075 .52441 m .61207 .52211 L .61342 .52364 L 0 .027 .126 r
F
.61075 .52441 m .6094 .5229 L .61207 .52211 L F
.54256 .5238 m .54379 .52163 L .5452 .52305 L 0 .026 .125 r
F
.54256 .5238 m .54115 .5224 L .54379 .52163 L F
.41691 .52402 m .41797 .52175 L .41949 .52319 L 0 .026 .126 r
F
.41691 .52402 m .41539 .52256 L .41797 .52175 L F
.34873 .5233 m .34969 .52098 L .35127 .52247 L 0 .025 .123 r
F
.34873 .5233 m .34715 .52182 L .34969 .52098 L F
.58 .52407 m .58128 .52178 L .58265 .5233 L 0 .027 .126 r
F
.58 .52407 m .57862 .52256 L .58128 .52178 L F
.49845 .52409 m .49962 .52185 L .50107 .52333 L F
.49845 .52409 m .49701 .52258 L .49962 .52185 L F
.61743 .52428 m .61876 .52208 L .6201 .5235 L 0 .027 .127 r
F
.61743 .52428 m .61609 .52287 L .61876 .52208 L F
.42359 .52375 m .42465 .5216 L .42617 .52299 L 0 .026 .125 r
F
.42359 .52375 m .42207 .52237 L .42465 .5216 L F
.38615 .5236 m .38717 .52127 L .38871 .52282 L 0 .026 .124 r
F
.38615 .5236 m .38461 .52207 L .38717 .52127 L F
.62411 .52405 m .62545 .5218 L .62678 .52319 L 0 .027 .126 r
F
.62411 .52405 m .62278 .52265 L .62545 .5218 L F
.46102 .52409 m .46214 .52167 L .46362 .52322 L F
.46102 .52409 m .45954 .52254 L .46214 .52167 L F
.35539 .5232 m .35636 .52103 L .35793 .52248 L 0 .025 .124 r
F
.35539 .5232 m .35381 .52174 L .35636 .52103 L F
.63079 .5238 m .63214 .5215 L .63347 .52295 L 0 .026 .125 r
F
.63079 .5238 m .62946 .52234 L .63214 .5215 L F
.43026 .52363 m .43133 .52147 L .43284 .52287 L F
.43026 .52363 m .42875 .52224 L .43133 .52147 L F
.54924 .52382 m .55048 .52144 L .55188 .52296 L F
.54924 .52382 m .54784 .52229 L .55048 .52144 L F
.58668 .52401 m .58797 .5217 L .58934 .52319 L 0 .027 .126 r
F
.58668 .52401 m .58531 .5225 L .58797 .5217 L F
.46769 .52384 m .46882 .52155 L .47029 .52303 L 0 .026 .126 r
F
.46769 .52384 m .46622 .52235 L .46882 .52155 L F
.39282 .52353 m .39385 .52113 L .39538 .52268 L 0 .026 .125 r
F
.39282 .52353 m .39128 .52197 L .39385 .52113 L F
.50513 .52411 m .50631 .52187 L .50775 .52338 L 0 .027 .127 r
F
.50513 .52411 m .50369 .52258 L .50631 .52187 L F
.63747 .52358 m .63883 .52133 L .64016 .52283 L 0 .026 .125 r
F
.63747 .52358 m .63615 .52209 L .63883 .52133 L F
.59336 .52382 m .59466 .52158 L .59602 .52301 L 0 .027 .126 r
F
.59336 .52382 m .592 .52236 L .59466 .52158 L F
.55592 .52366 m .55717 .52128 L .55856 .52283 L 0 .026 .125 r
F
.55592 .52366 m .55452 .5221 L .55717 .52128 L F
.43693 .52348 m .43802 .52116 L .43952 .52263 L F
.43693 .52348 m .43543 .52201 L .43802 .52116 L F
.47437 .52373 m .4755 .52147 L .47697 .52295 L 0 .027 .126 r
F
.47437 .52373 m .4729 .52225 L .4755 .52147 L F
.36205 .52319 m .36303 .52091 L .3646 .52235 L 0 .025 .124 r
F
.36205 .52319 m .36048 .52175 L .36303 .52091 L F
.39948 .52347 m .40052 .52122 L .40205 .52275 L 0 .026 .125 r
F
.39948 .52347 m .39795 .52193 L .40052 .52122 L F
.4436 .5233 m .44469 .52108 L .44619 .52252 L F
.4436 .5233 m .4421 .52184 L .44469 .52108 L F
.60004 .52371 m .60135 .5214 L .60271 .5229 L 0 .027 .126 r
F
.60004 .52371 m .59868 .5222 L .60135 .5214 L F
.36872 .52298 m .36971 .52072 L .37127 .52218 L 0 .025 .124 r
F
.36872 .52298 m .36716 .52151 L .36971 .52072 L F
.5626 .52354 m .56386 .52121 L .56525 .52272 L 0 .026 .125 r
F
.5626 .52354 m .56121 .52202 L .56386 .52121 L F
.5118 .52415 m .51299 .52182 L .51443 .52331 L 0 .028 .127 r
F
.5118 .52415 m .51037 .52265 L .51299 .52182 L F
.64416 .5236 m .64553 .52133 L .64685 .52286 L 0 .027 .126 r
F
.64416 .5236 m .64284 .52208 L .64553 .52133 L F
.51848 .52383 m .51968 .52152 L .52111 .52295 L F
.51848 .52383 m .51705 .52241 L .51968 .52152 L F
.48104 .52366 m .48219 .52141 L .48365 .52291 L F
.48104 .52366 m .47958 .52218 L .48219 .52141 L F
.52516 .5235 m .52637 .52119 L .52779 .52263 L 0 .026 .125 r
F
.52516 .5235 m .52374 .52207 L .52637 .52119 L F
.56928 .52339 m .57055 .52117 L .57193 .52264 L F
.56928 .52339 m .5679 .52194 L .57055 .52117 L F
.45027 .52321 m .45138 .52101 L .45286 .52248 L F
.45027 .52321 m .44878 .52175 L .45138 .52101 L F
.53184 .52322 m .53305 .52106 L .53447 .52249 L F
.53184 .52322 m .53042 .5218 L .53305 .52106 L F
.37538 .52292 m .37638 .5207 L .37794 .52216 L 0 .025 .124 r
F
.37538 .52292 m .37383 .52144 L .37638 .5207 L F
.60673 .52366 m .60805 .52135 L .6094 .5229 L 0 .027 .126 r
F
.60673 .52366 m .60538 .52213 L .60805 .52135 L F
.40615 .52353 m .40719 .52118 L .40872 .52269 L F
.40615 .52353 m .40462 .52203 L .40719 .52118 L F
.33793 .5228 m .33888 .52051 L .34047 .52199 L 0 .025 .124 r
F
.33793 .5228 m .33634 .52134 L .33888 .52051 L F
.48772 .52356 m .48887 .52127 L .49033 .52272 L 0 .027 .126 r
F
.48772 .52356 m .48626 .52211 L .48887 .52127 L F
.49439 .52333 m .49556 .52115 L .49701 .52258 L F
.49439 .52333 m .49294 .52188 L .49556 .52115 L F
.53852 .52315 m .53974 .52099 L .54115 .5224 L 0 .026 .125 r
F
.53852 .52315 m .53711 .52176 L .53974 .52099 L F
.57597 .52335 m .57724 .52106 L .57862 .52256 L 0 .027 .126 r
F
.57597 .52335 m .57459 .52187 L .57724 .52106 L F
.41282 .52338 m .41387 .52102 L .41539 .52256 L F
.41282 .52338 m .4113 .52185 L .41387 .52102 L F
.3446 .52265 m .34556 .52033 L .34715 .52182 L 0 .025 .124 r
F
.3446 .52265 m .34302 .52117 L .34556 .52033 L F
.38205 .52284 m .38306 .52061 L .38461 .52207 L 0 .026 .124 r
F
.38205 .52284 m .3805 .52139 L .38306 .52061 L F
.61342 .52364 m .61474 .52132 L .61609 .52287 L 0 .027 .127 r
F
.61342 .52364 m .61207 .52211 L .61474 .52132 L F
.45694 .5233 m .45806 .52098 L .45954 .52254 L 0 .027 .126 r
F
.45694 .5233 m .45546 .52176 L .45806 .52098 L F
.41949 .52319 m .42055 .52094 L .42207 .52237 L 0 .026 .126 r
F
.41949 .52319 m .41797 .52175 L .42055 .52094 L F
.35127 .52247 m .35224 .52023 L .35381 .52174 L 0 .025 .124 r
F
.35127 .52247 m .34969 .52098 L .35224 .52023 L F
.5452 .52305 m .54643 .52086 L .54784 .52229 L 0 .026 .125 r
F
.5452 .52305 m .54379 .52163 L .54643 .52086 L F
.58265 .5233 m .58394 .52099 L .58531 .5225 L 0 .027 .126 r
F
.58265 .5233 m .58128 .52178 L .58394 .52099 L F
.6201 .5235 m .62144 .52125 L .62278 .52265 L 0 .027 .127 r
F
.6201 .5235 m .61876 .52208 L .62144 .52125 L F
.50107 .52333 m .50224 .52111 L .50369 .52258 L 0 .027 .126 r
F
.50107 .52333 m .49962 .52185 L .50224 .52111 L F
.42617 .52299 m .42723 .52084 L .42875 .52224 L 0 .026 .125 r
F
.42617 .52299 m .42465 .5216 L .42723 .52084 L F
.38871 .52282 m .38974 .52043 L .39128 .52197 L 0 .026 .124 r
F
.38871 .52282 m .38717 .52127 L .38974 .52043 L F
.62678 .52319 m .62813 .52097 L .62946 .52234 L 0 .027 .126 r
F
.62678 .52319 m .62545 .5218 L .62813 .52097 L F
.46362 .52322 m .46474 .5208 L .46622 .52235 L 0 .026 .126 r
F
.46362 .52322 m .46214 .52167 L .46474 .5208 L F
.63347 .52295 m .63482 .52066 L .63615 .52209 L 0 .026 .125 r
F
.63347 .52295 m .63214 .5215 L .63482 .52066 L F
.55188 .52296 m .55312 .52059 L .55452 .5221 L F
.55188 .52296 m .55048 .52144 L .55312 .52059 L F
.58934 .52319 m .59063 .5209 L .592 .52236 L 0 .027 .126 r
F
.58934 .52319 m .58797 .5217 L .59063 .5209 L F
.47029 .52303 m .47142 .52077 L .4729 .52225 L F
.47029 .52303 m .46882 .52155 L .47142 .52077 L F
.35793 .52248 m .3589 .52031 L .36048 .52175 L 0 .025 .124 r
F
.35793 .52248 m .35636 .52103 L .3589 .52031 L F
.43284 .52287 m .43392 .5206 L .43543 .52201 L 0 .026 .125 r
F
.43284 .52287 m .43133 .52147 L .43392 .5206 L F
.39538 .52268 m .39641 .52038 L .39795 .52193 L F
.39538 .52268 m .39385 .52113 L .39641 .52038 L F
.43952 .52263 m .4406 .52037 L .4421 .52184 L F
.43952 .52263 m .43802 .52116 L .4406 .52037 L F
.50775 .52338 m .50893 .52115 L .51037 .52265 L 0 .028 .127 r
F
.50775 .52338 m .50631 .52187 L .50893 .52115 L F
.59602 .52301 m .59733 .5208 L .59868 .5222 L 0 .027 .126 r
F
.59602 .52301 m .59466 .52158 L .59733 .5208 L F
.55856 .52283 m .55982 .52049 L .56121 .52202 L 0 .026 .125 r
F
.55856 .52283 m .55717 .52128 L .55982 .52049 L F
.64016 .52283 m .64152 .52057 L .64284 .52208 L F
.64016 .52283 m .63883 .52133 L .64152 .52057 L F
.3646 .52235 m .36559 .52007 L .36716 .52151 L 0 .025 .124 r
F
.3646 .52235 m .36303 .52091 L .36559 .52007 L F
.47697 .52295 m .47811 .52068 L .47958 .52218 L 0 .027 .126 r
F
.47697 .52295 m .4755 .52147 L .47811 .52068 L F
.44619 .52252 m .44729 .52033 L .44878 .52175 L 0 .026 .125 r
F
.44619 .52252 m .44469 .52108 L .44729 .52033 L F
.56525 .52272 m .56651 .52042 L .5679 .52194 L F
.56525 .52272 m .56386 .52121 L .56651 .52042 L F
.60271 .5229 m .60402 .5206 L .60538 .52213 L 0 .027 .126 r
F
.60271 .5229 m .60135 .5214 L .60402 .5206 L F
.37127 .52218 m .37226 .51999 L .37383 .52144 L 0 .025 .124 r
F
.37127 .52218 m .36971 .52072 L .37226 .51999 L F
.51443 .52331 m .51562 .52093 L .51705 .52241 L 0 .027 .127 r
F
.51443 .52331 m .51299 .52182 L .51562 .52093 L F
.40205 .52275 m .40309 .5205 L .40462 .52203 L 0 .026 .126 r
F
.40205 .52275 m .40052 .52122 L .40309 .5205 L F
.52111 .52295 m .52231 .52064 L .52374 .52207 L 0 .027 .126 r
F
.52111 .52295 m .51968 .52152 L .52231 .52064 L F
.52779 .52263 m .529 .52036 L .53042 .5218 L 0 .026 .125 r
F
.52779 .52263 m .52637 .52119 L .529 .52036 L F
.64685 .52286 m .64823 .52058 L .64954 .52213 L 0 .027 .126 r
F
.64685 .52286 m .64553 .52133 L .64823 .52058 L F
.3338 .52216 m .33475 .51984 L .33634 .52134 L 0 .025 .124 r
F
.3338 .52216 m .33221 .52068 L .33475 .51984 L F
.48365 .52291 m .4848 .5206 L .48626 .52211 L 0 .027 .126 r
F
.48365 .52291 m .48219 .52141 L .4848 .5206 L F
.57193 .52264 m .5732 .52038 L .57459 .52187 L 0 .026 .126 r
F
.57193 .52264 m .57055 .52117 L .5732 .52038 L F
.45286 .52248 m .45397 .52028 L .45546 .52176 L 0 .026 .125 r
F
.45286 .52248 m .45138 .52101 L .45397 .52028 L F
.53447 .52249 m .53569 .52031 L .53711 .52176 L F
.53447 .52249 m .53305 .52106 L .53569 .52031 L F
.40872 .52269 m .40977 .52032 L .4113 .52185 L 0 .026 .126 r
F
.40872 .52269 m .40719 .52118 L .40977 .52032 L F
.37794 .52216 m .37894 .51993 L .3805 .52139 L 0 .026 .124 r
F
.37794 .52216 m .37638 .5207 L .37894 .51993 L F
.6094 .5229 m .61072 .52054 L .61207 .52211 L 0 .027 .126 r
F
.6094 .5229 m .60805 .52135 L .61072 .52054 L F
.49033 .52272 m .49149 .52043 L .49294 .52188 L F
.49033 .52272 m .48887 .52127 L .49149 .52043 L F
.34047 .52199 m .34143 .51968 L .34302 .52117 L 0 .025 .124 r
F
.34047 .52199 m .33888 .52051 L .34143 .51968 L F
.34715 .52182 m .34811 .51949 L .34969 .52098 L 0 .025 .123 r
F
.34715 .52182 m .34556 .52033 L .34811 .51949 L F
.41539 .52256 m .41645 .52021 L .41797 .52175 L 0 .026 .126 r
F
.41539 .52256 m .41387 .52102 L .41645 .52021 L F
.57862 .52256 m .5799 .52026 L .58128 .52178 L 0 .027 .126 r
F
.57862 .52256 m .57724 .52106 L .5799 .52026 L F
.54115 .5224 m .54238 .52021 L .54379 .52163 L 0 .026 .126 r
F
.54115 .5224 m .53974 .52099 L .54238 .52021 L F
.49701 .52258 m .49817 .52043 L .49962 .52185 L 0 .027 .126 r
F
.49701 .52258 m .49556 .52115 L .49817 .52043 L F
.38461 .52207 m .38562 .51983 L .38717 .52127 L 0 .026 .124 r
F
.38461 .52207 m .38306 .52061 L .38562 .51983 L F
.61609 .52287 m .61742 .52052 L .61876 .52208 L 0 .027 .127 r
F
.61609 .52287 m .61474 .52132 L .61742 .52052 L F
.45954 .52254 m .46066 .52011 L .46214 .52167 L 0 .026 .126 r
F
.45954 .52254 m .45806 .52098 L .46066 .52011 L F
.42207 .52237 m .42313 .52016 L .42465 .5216 L 0 .027 .126 r
F
.42207 .52237 m .42055 .52094 L .42313 .52016 L F
.62278 .52265 m .62412 .52041 L .62545 .5218 L F
.62278 .52265 m .62144 .52125 L .62412 .52041 L F
.54784 .52229 m .54908 .52002 L .55048 .52144 L 0 .026 .125 r
F
.54784 .52229 m .54643 .52086 L .54908 .52002 L F
.35381 .52174 m .35478 .51952 L .35636 .52103 L 0 .025 .124 r
F
.35381 .52174 m .35224 .52023 L .35478 .51952 L F
.58531 .5225 m .5866 .5202 L .58797 .5217 L 0 .027 .126 r
F
.58531 .5225 m .58394 .52099 L .5866 .5202 L F
.62946 .52234 m .63081 .52014 L .63214 .5215 L F
.62946 .52234 m .62813 .52097 L .63081 .52014 L F
.39128 .52197 m .39231 .51959 L .39385 .52113 L 0 .026 .124 r
F
.39128 .52197 m .38974 .52043 L .39231 .51959 L F
.46622 .52235 m .46735 .52 L .46882 .52155 L 0 .026 .125 r
F
.46622 .52235 m .46474 .5208 L .46735 .52 L F
.50369 .52258 m .50486 .5204 L .50631 .52187 L 0 .027 .127 r
F
.50369 .52258 m .50224 .52111 L .50486 .5204 L F
.42875 .52224 m .42982 .52007 L .43133 .52147 L 0 .027 .126 r
F
.42875 .52224 m .42723 .52084 L .42982 .52007 L F
.63615 .52209 m .63751 .51988 L .63883 .52133 L 0 .026 .125 r
F
.63615 .52209 m .63482 .52066 L .63751 .51988 L F
.55452 .5221 m .55577 .51978 L .55717 .52128 L F
.55452 .5221 m .55312 .52059 L .55577 .51978 L F
.592 .52236 m .5933 .52015 L .59466 .52158 L 0 .027 .126 r
F
.592 .52236 m .59063 .5209 L .5933 .52015 L F
.43543 .52201 m .43651 .51974 L .43802 .52116 L 0 .026 .125 r
F
.43543 .52201 m .43392 .5206 L .43651 .51974 L F
.4729 .52225 m .47403 .51999 L .4755 .52147 L 0 .027 .126 r
F
.4729 .52225 m .47142 .52077 L .47403 .51999 L F
.39795 .52193 m .39898 .51967 L .40052 .52122 L 0 .026 .125 r
F
.39795 .52193 m .39641 .52038 L .39898 .51967 L F
.36048 .52175 m .36146 .51947 L .36303 .52091 L 0 .026 .124 r
F
.36048 .52175 m .3589 .52031 L .36146 .51947 L F
.59868 .5222 m .59999 .52 L .60135 .5214 L 0 .027 .126 r
F
.59868 .5222 m .59733 .5208 L .59999 .52 L F
.56121 .52202 m .56247 .5197 L .56386 .52121 L 0 .026 .125 r
F
.56121 .52202 m .55982 .52049 L .56247 .5197 L F
.4421 .52184 m .4432 .51964 L .44469 .52108 L F
.4421 .52184 m .4406 .52037 L .4432 .51964 L F
.36716 .52151 m .36814 .51929 L .36971 .52072 L 0 .025 .124 r
F
.36716 .52151 m .36559 .52007 L .36814 .51929 L F
.64284 .52208 m .64421 .5198 L .64553 .52133 L 0 .026 .126 r
F
.64284 .52208 m .64152 .52057 L .64421 .5198 L F
.51037 .52265 m .51156 .52033 L .51299 .52182 L 0 .028 .127 r
F
.51037 .52265 m .50893 .52115 L .51156 .52033 L F
.47958 .52218 m .48072 .5199 L .48219 .52141 L 0 .027 .126 r
F
.47958 .52218 m .47811 .52068 L .48072 .5199 L F
.51705 .52241 m .51825 .52004 L .51968 .52152 L 0 .027 .127 r
F
.51705 .52241 m .51562 .52093 L .51825 .52004 L F
.52374 .52207 m .52494 .51976 L .52637 .52119 L 0 .027 .126 r
F
.52374 .52207 m .52231 .52064 L .52494 .51976 L F
.44878 .52175 m .44988 .51959 L .45138 .52101 L 0 .026 .125 r
F
.44878 .52175 m .44729 .52033 L .44988 .51959 L F
.60538 .52213 m .60669 .51981 L .60805 .52135 L 0 .027 .126 r
F
.60538 .52213 m .60402 .5206 L .60669 .51981 L F
.5679 .52194 m .56916 .51964 L .57055 .52117 L 0 .026 .125 r
F
.5679 .52194 m .56651 .52042 L .56916 .51964 L F
.53042 .5218 m .53164 .5196 L .53305 .52106 L F
.53042 .5218 m .529 .52036 L .53164 .5196 L F
.37383 .52144 m .37482 .51926 L .37638 .5207 L 0 .026 .124 r
F
.37383 .52144 m .37226 .51999 L .37482 .51926 L F
.40462 .52203 m .40566 .51964 L .40719 .52118 L 0 .027 .126 r
F
.40462 .52203 m .40309 .5205 L .40566 .51964 L F
.33634 .52134 m .33729 .51899 L .33888 .52051 L 0 .025 .124 r
F
.33634 .52134 m .33475 .51984 L .33729 .51899 L F
.48626 .52211 m .48741 .51975 L .48887 .52127 L 0 .027 .126 r
F
.48626 .52211 m .4848 .5206 L .48741 .51975 L F
.64954 .52213 m .65092 .51982 L .65224 .52139 L F
.64954 .52213 m .64823 .52058 L .65092 .51982 L F
.4113 .52185 m .41235 .51948 L .41387 .52102 L 0 .026 .125 r
F
.4113 .52185 m .40977 .52032 L .41235 .51948 L F
.57459 .52187 m .57586 .51956 L .57724 .52106 L 0 .027 .126 r
F
.57459 .52187 m .5732 .52038 L .57586 .51956 L F
.49294 .52188 m .4941 .51971 L .49556 .52115 L F
.49294 .52188 m .49149 .52043 L .4941 .51971 L F
.34302 .52117 m .34398 .51883 L .34556 .52033 L 0 .025 .124 r
F
.34302 .52117 m .34143 .51968 L .34398 .51883 L F
.61207 .52211 m .61339 .51973 L .61474 .52132 L 0 .027 .126 r
F
.61207 .52211 m .61072 .52054 L .61339 .51973 L F
.3805 .52139 m .3815 .51916 L .38306 .52061 L 0 .026 .125 r
F
.3805 .52139 m .37894 .51993 L .3815 .51916 L F
.45546 .52176 m .45657 .5195 L .45806 .52098 L 0 .026 .126 r
F
.45546 .52176 m .45397 .52028 L .45657 .5195 L F
.53711 .52176 m .53833 .51952 L .53974 .52099 L 0 .027 .126 r
F
.53711 .52176 m .53569 .52031 L .53833 .51952 L F
.34969 .52098 m .35066 .51872 L .35224 .52023 L 0 .025 .124 r
F
.34969 .52098 m .34811 .51949 L .35066 .51872 L F
.41797 .52175 m .41903 .5194 L .42055 .52094 L 0 .026 .126 r
F
.41797 .52175 m .41645 .52021 L .41903 .5194 L F
.58128 .52178 m .58256 .51947 L .58394 .52099 L 0 .027 .126 r
F
.58128 .52178 m .5799 .52026 L .58256 .51947 L F
.54379 .52163 m .54503 .51942 L .54643 .52086 L F
.54379 .52163 m .54238 .52021 L .54503 .51942 L F
.38717 .52127 m .38819 .519 L .38974 .52043 L 0 .026 .124 r
F
.38717 .52127 m .38562 .51983 L .38819 .519 L F
.49962 .52185 m .50079 .51971 L .50224 .52111 L 0 .027 .126 r
F
.49962 .52185 m .49817 .52043 L .50079 .51971 L F
.46214 .52167 m .46326 .51924 L .46474 .5208 L 0 .026 .125 r
F
.46214 .52167 m .46066 .52011 L .46326 .51924 L F
.61876 .52208 m .6201 .51971 L .62144 .52125 L 0 .027 .127 r
F
.61876 .52208 m .61742 .52052 L .6201 .51971 L F
.42465 .5216 m .42572 .5194 L .42723 .52084 L 0 .027 .126 r
F
.42465 .5216 m .42313 .52016 L .42572 .5194 L F
.62545 .5218 m .6268 .51959 L .62813 .52097 L F
.62545 .5218 m .62412 .52041 L .6268 .51959 L F
.55048 .52144 m .55172 .51919 L .55312 .52059 L 0 .026 .125 r
F
.55048 .52144 m .54908 .52002 L .55172 .51919 L F
.63214 .5215 m .6335 .51931 L .63482 .52066 L 0 .027 .126 r
F
.63214 .5215 m .63081 .52014 L .6335 .51931 L F
.39385 .52113 m .39488 .51884 L .39641 .52038 L 0 .026 .124 r
F
.39385 .52113 m .39231 .51959 L .39488 .51884 L F
.58797 .5217 m .58926 .51942 L .59063 .5209 L 0 .027 .126 r
F
.58797 .5217 m .5866 .5202 L .58926 .51942 L F
.46882 .52155 m .46995 .51923 L .47142 .52077 L 0 .026 .126 r
F
.46882 .52155 m .46735 .52 L .46995 .51923 L F
.35636 .52103 m .35733 .51878 L .3589 .52031 L 0 .026 .124 r
F
.35636 .52103 m .35478 .51952 L .35733 .51878 L F
.43133 .52147 m .43241 .5192 L .43392 .5206 L 0 .027 .126 r
F
.43133 .52147 m .42982 .52007 L .43241 .5192 L F
.55717 .52128 m .55842 .51901 L .55982 .52049 L 0 .026 .125 r
F
.55717 .52128 m .55577 .51978 L .55842 .51901 L F
.50631 .52187 m .50749 .51969 L .50893 .52115 L 0 .028 .127 r
F
.50631 .52187 m .50486 .5204 L .50749 .51969 L F
.63883 .52133 m .6402 .5191 L .64152 .52057 L 0 .026 .125 r
F
.63883 .52133 m .63751 .51988 L .6402 .5191 L F
.43802 .52116 m .4391 .51895 L .4406 .52037 L F
.43802 .52116 m .43651 .51974 L .4391 .51895 L F
.59466 .52158 m .59596 .51939 L .59733 .5208 L 0 .027 .126 r
F
.59466 .52158 m .5933 .52015 L .59596 .51939 L F
.36303 .52091 m .36402 .51863 L .36559 .52007 L 0 .025 .124 r
F
.36303 .52091 m .36146 .51947 L .36402 .51863 L F
.4755 .52147 m .47664 .51918 L .47811 .52068 L 0 .027 .126 r
F
.4755 .52147 m .47403 .51999 L .47664 .51918 L F
.60135 .5214 m .60266 .51918 L .60402 .5206 L F
.60135 .5214 m .59999 .52 L .60266 .51918 L F
.56386 .52121 m .56512 .5189 L .56651 .52042 L 0 .026 .125 r
F
.56386 .52121 m .56247 .5197 L .56512 .5189 L F
.40052 .52122 m .40155 .51895 L .40309 .5205 L F
.40052 .52122 m .39898 .51967 L .40155 .51895 L F
.51299 .52182 m .51418 .51944 L .51562 .52093 L 0 .027 .127 r
F
.51299 .52182 m .51156 .52033 L .51418 .51944 L F
.44469 .52108 m .44579 .5189 L .44729 .52033 L 0 .026 .125 r
F
.44469 .52108 m .4432 .51964 L .44579 .5189 L F
.36971 .52072 m .3707 .51856 L .37226 .51999 L 0 .025 .124 r
F
.36971 .52072 m .36814 .51929 L .3707 .51856 L F
.51968 .52152 m .52088 .51918 L .52231 .52064 L 0 .027 .126 r
F
.51968 .52152 m .51825 .52004 L .52088 .51918 L F
.64553 .52133 m .64691 .51903 L .64823 .52058 L F
.64553 .52133 m .64421 .5198 L .64691 .51903 L F
.52637 .52119 m .52758 .51892 L .529 .52036 L 0 .026 .126 r
F
.52637 .52119 m .52494 .51976 L .52758 .51892 L F
.48219 .52141 m .48334 .51907 L .4848 .5206 L 0 .027 .126 r
F
.48219 .52141 m .48072 .5199 L .48334 .51907 L F
.33221 .52068 m .33316 .51833 L .33475 .51984 L 0 .025 .124 r
F
.33221 .52068 m .33061 .51919 L .33316 .51833 L F
.60805 .52135 m .60937 .51898 L .61072 .52054 L 0 .027 .126 r
F
.60805 .52135 m .60669 .51981 L .60937 .51898 L F
.57055 .52117 m .57182 .51883 L .5732 .52038 L 0 .026 .126 r
F
.57055 .52117 m .56916 .51964 L .57182 .51883 L F
.40719 .52118 m .40824 .51877 L .40977 .52032 L 0 .026 .125 r
F
.40719 .52118 m .40566 .51964 L .40824 .51877 L F
.45138 .52101 m .45248 .51885 L .45397 .52028 L 0 .026 .126 r
F
.45138 .52101 m .44988 .51959 L .45248 .51885 L F
.53305 .52106 m .53427 .51883 L .53569 .52031 L F
.53305 .52106 m .53164 .5196 L .53427 .51883 L F
.37638 .5207 m .37738 .51849 L .37894 .51993 L 0 .026 .125 r
F
.37638 .5207 m .37482 .51926 L .37738 .51849 L F
.33888 .52051 m .33984 .51814 L .34143 .51968 L 0 .025 .124 r
F
.33888 .52051 m .33729 .51899 L .33984 .51814 L F
.48887 .52127 m .49003 .51889 L .49149 .52043 L 0 .027 .126 r
F
.48887 .52127 m .48741 .51975 L .49003 .51889 L F
.65224 .52139 m .65362 .51898 L .65493 .52054 L F
.65224 .52139 m .65092 .51982 L .65362 .51898 L F
.41387 .52102 m .41493 .51867 L .41645 .52021 L 0 .026 .125 r
F
.41387 .52102 m .41235 .51948 L .41493 .51867 L F
.57724 .52106 m .57852 .51873 L .5799 .52026 L 0 .027 .126 r
F
.57724 .52106 m .57586 .51956 L .57852 .51873 L F
.34556 .52033 m .34653 .51798 L .34811 .51949 L 0 .025 .123 r
F
.34556 .52033 m .34398 .51883 L .34653 .51798 L F
.61474 .52132 m .61607 .51892 L .61742 .52052 L 0 .027 .126 r
F
.61474 .52132 m .61339 .51973 L .61607 .51892 L F
.49556 .52115 m .49672 .51901 L .49817 .52043 L F
.49556 .52115 m .4941 .51971 L .49672 .51901 L F
.45806 .52098 m .45917 .51863 L .46066 .52011 L 0 .026 .126 r
F
.45806 .52098 m .45657 .5195 L .45917 .51863 L F
.38306 .52061 m .38407 .51837 L .38562 .51983 L 0 .026 .125 r
F
.38306 .52061 m .3815 .51916 L .38407 .51837 L F
.53974 .52099 m .54097 .51872 L .54238 .52021 L 0 .027 .126 r
F
.53974 .52099 m .53833 .51952 L .54097 .51872 L F
.42055 .52094 m .42162 .51862 L .42313 .52016 L F
.42055 .52094 m .41903 .5194 L .42162 .51862 L F
.35224 .52023 m .35321 .51799 L .35478 .51952 L 0 .025 .124 r
F
.35224 .52023 m .35066 .51872 L .35321 .51799 L F
.46474 .5208 m .46587 .51845 L .46735 .52 L 0 .026 .125 r
F
.46474 .5208 m .46326 .51924 L .46587 .51845 L F
.38974 .52043 m .39076 .51816 L .39231 .51959 L 0 .026 .124 r
F
.38974 .52043 m .38819 .519 L .39076 .51816 L F
.58394 .52099 m .58522 .51869 L .5866 .5202 L 0 .027 .126 r
F
.58394 .52099 m .58256 .51947 L .58522 .51869 L F
.54643 .52086 m .54767 .51861 L .54908 .52002 L F
.54643 .52086 m .54503 .51942 L .54767 .51861 L F
.62144 .52125 m .62278 .51889 L .62412 .52041 L 0 .027 .127 r
F
.62144 .52125 m .6201 .51971 L .62278 .51889 L F
.50224 .52111 m .50342 .519 L .50486 .5204 L F
.50224 .52111 m .50079 .51971 L .50342 .519 L F
.55312 .52059 m .55437 .5184 L .55577 .51978 L 0 .026 .125 r
F
.55312 .52059 m .55172 .51919 L .55437 .5184 L F
.62813 .52097 m .62948 .51878 L .63081 .52014 L 0 .027 .126 r
F
.62813 .52097 m .6268 .51959 L .62948 .51878 L F
.42723 .52084 m .42831 .51861 L .42982 .52007 L F
.42723 .52084 m .42572 .5194 L .42831 .51861 L F
.63482 .52066 m .63619 .51852 L .63751 .51988 L F
.63482 .52066 m .6335 .51931 L .63619 .51852 L F
.59063 .5209 m .59193 .51868 L .5933 .52015 L F
.59063 .5209 m .58926 .51942 L .59193 .51868 L F
.39641 .52038 m .39744 .51813 L .39898 .51967 L 0 .026 .125 r
F
.39641 .52038 m .39488 .51884 L .39744 .51813 L F
.47142 .52077 m .47256 .51846 L .47403 .51999 L 0 .027 .126 r
F
.47142 .52077 m .46995 .51923 L .47256 .51846 L F
.43392 .5206 m .435 .51833 L .43651 .51974 L 0 .026 .125 r
F
.43392 .5206 m .43241 .5192 L .435 .51833 L F
.55982 .52049 m .56107 .51823 L .56247 .5197 L F
.55982 .52049 m .55842 .51901 L .56107 .51823 L F
.3589 .52031 m .35989 .51793 L .36146 .51947 L 0 .026 .124 r
F
.3589 .52031 m .35733 .51878 L .35989 .51793 L F
.4406 .52037 m .44169 .51822 L .4432 .51964 L 0 .026 .125 r
F
.4406 .52037 m .4391 .51895 L .44169 .51822 L F
.64152 .52057 m .64289 .51832 L .64421 .5198 L 0 .026 .126 r
F
.64152 .52057 m .6402 .5191 L .64289 .51832 L F
.50893 .52115 m .51012 .51887 L .51156 .52033 L 0 .028 .127 r
F
.50893 .52115 m .50749 .51969 L .51012 .51887 L F
.59733 .5208 m .59863 .5186 L .59999 .52 L 0 .027 .126 r
F
.59733 .5208 m .59596 .51939 L .59863 .5186 L F
.36559 .52007 m .36657 .51785 L .36814 .51929 L 0 .025 .124 r
F
.36559 .52007 m .36402 .51863 L .36657 .51785 L F
.47811 .52068 m .47925 .51837 L .48072 .5199 L 0 .027 .126 r
F
.47811 .52068 m .47664 .51918 L .47925 .51837 L F
.51562 .52093 m .51681 .51855 L .51825 .52004 L 0 .027 .127 r
F
.51562 .52093 m .51418 .51944 L .51681 .51855 L F
.60402 .5206 m .60534 .51837 L .60669 .51981 L 0 .027 .126 r
F
.60402 .5206 m .60266 .51918 L .60534 .51837 L F
.56651 .52042 m .56777 .51809 L .56916 .51964 L 0 .026 .125 r
F
.56651 .52042 m .56512 .5189 L .56777 .51809 L F
.52231 .52064 m .52351 .51832 L .52494 .51976 L 0 .027 .126 r
F
.52231 .52064 m .52088 .51918 L .52351 .51832 L F
.40309 .5205 m .40413 .51808 L .40566 .51964 L 0 .026 .125 r
F
.40309 .5205 m .40155 .51895 L .40413 .51808 L F
.44729 .52033 m .44839 .51816 L .44988 .51959 L 0 .026 .126 r
F
.44729 .52033 m .44579 .5189 L .44839 .51816 L F
.37226 .51999 m .37326 .51783 L .37482 .51926 L 0 .026 .125 r
F
.37226 .51999 m .3707 .51856 L .37326 .51783 L F
.529 .52036 m .53021 .51814 L .53164 .5196 L 0 .026 .126 r
F
.529 .52036 m .52758 .51892 L .53021 .51814 L F
.64823 .52058 m .6496 .51825 L .65092 .51982 L 0 .027 .126 r
F
.64823 .52058 m .64691 .51903 L .6496 .51825 L F
.33475 .51984 m .3357 .51746 L .33729 .51899 L 0 .025 .124 r
F
.33475 .51984 m .33316 .51833 L .3357 .51746 L F
.4848 .5206 m .48595 .51821 L .48741 .51975 L 0 .027 .126 r
F
.4848 .5206 m .48334 .51907 L .48595 .51821 L F
.40977 .52032 m .41082 .51794 L .41235 .51948 L 0 .026 .125 r
F
.40977 .52032 m .40824 .51877 L .41082 .51794 L F
.61072 .52054 m .61204 .51815 L .61339 .51973 L 0 .027 .126 r
F
.61072 .52054 m .60937 .51898 L .61204 .51815 L F
.5732 .52038 m .57448 .51799 L .57586 .51956 L 0 .026 .126 r
F
.5732 .52038 m .57182 .51883 L .57448 .51799 L F
.34143 .51968 m .34239 .51729 L .34398 .51883 L 0 .025 .124 r
F
.34143 .51968 m .33984 .51814 L .34239 .51729 L F
.49149 .52043 m .49265 .51818 L .4941 .51971 L 0 .027 .126 r
F
.49149 .52043 m .49003 .51889 L .49265 .51818 L F
.45397 .52028 m .45508 .51807 L .45657 .5195 L F
.45397 .52028 m .45248 .51885 L .45508 .51807 L F
.37894 .51993 m .37995 .51771 L .3815 .51916 L 0 .026 .125 r
F
.37894 .51993 m .37738 .51849 L .37995 .51771 L F
.53569 .52031 m .53691 .51802 L .53833 .51952 L 0 .027 .126 r
F
.53569 .52031 m .53427 .51883 L .53691 .51802 L F
.65493 .52054 m .65631 .51811 L .65762 .51965 L F
.65493 .52054 m .65362 .51898 L .65631 .51811 L F
.41645 .52021 m .41751 .51787 L .41903 .5194 L 0 .026 .125 r
F
.41645 .52021 m .41493 .51867 L .41751 .51787 L F
.34811 .51949 m .34908 .5172 L .35066 .51872 L 0 .025 .124 r
F
.34811 .51949 m .34653 .51798 L .34908 .5172 L F
.5799 .52026 m .58118 .51794 L .58256 .51947 L 0 .027 .126 r
F
.5799 .52026 m .57852 .51873 L .58118 .51794 L F
.46066 .52011 m .46178 .51777 L .46326 .51924 L 0 .026 .125 r
F
.46066 .52011 m .45917 .51863 L .46178 .51777 L F
.61742 .52052 m .61875 .51812 L .6201 .51971 L 0 .027 .126 r
F
.61742 .52052 m .61607 .51892 L .61875 .51812 L F
.38562 .51983 m .38664 .51756 L .38819 .519 L 0 .026 .125 r
F
.38562 .51983 m .38407 .51837 L .38664 .51756 L F
.54238 .52021 m .54362 .51792 L .54503 .51942 L 0 .027 .126 r
F
.54238 .52021 m .54097 .51872 L .54362 .51792 L F
.49817 .52043 m .49934 .51831 L .50079 .51971 L 0 .027 .127 r
F
.49817 .52043 m .49672 .51901 L .49934 .51831 L F
.39231 .51959 m .39333 .51741 L .39488 .51884 L 0 .026 .124 r
F
.39231 .51959 m .39076 .51816 L .39333 .51741 L F
.42313 .52016 m .4242 .51785 L .42572 .5194 L 0 .027 .126 r
F
.42313 .52016 m .42162 .51862 L .4242 .51785 L F
.46735 .52 m .46848 .5177 L .46995 .51923 L 0 .026 .125 r
F
.46735 .52 m .46587 .51845 L .46848 .5177 L F
.5866 .5202 m .58789 .51791 L .58926 .51942 L 0 .027 .126 r
F
.5866 .5202 m .58522 .51869 L .58789 .51791 L F
.54908 .52002 m .55032 .51779 L .55172 .51919 L F
.54908 .52002 m .54767 .51861 L .55032 .51779 L F
.62412 .52041 m .62546 .51808 L .6268 .51959 L 0 .027 .127 r
F
.62412 .52041 m .62278 .51889 L .62546 .51808 L F
.35478 .51952 m .35576 .51723 L .35733 .51878 L 0 .025 .124 r
F
.35478 .51952 m .35321 .51799 L .35576 .51723 L F
.63081 .52014 m .63217 .51797 L .6335 .51931 L 0 .027 .126 r
F
.63081 .52014 m .62948 .51878 L .63217 .51797 L F
.55577 .51978 m .55702 .51763 L .55842 .51901 L 0 .026 .125 r
F
.55577 .51978 m .55437 .5184 L .55702 .51763 L F
.50486 .5204 m .50604 .51828 L .50749 .51969 L 0 .028 .127 r
F
.50486 .5204 m .50342 .519 L .50604 .51828 L F
.42982 .52007 m .4309 .51774 L .43241 .5192 L 0 .027 .126 r
F
.42982 .52007 m .42831 .51861 L .4309 .51774 L F
.63751 .51988 m .63888 .51773 L .6402 .5191 L F
.63751 .51988 m .63619 .51852 L .63888 .51773 L F
.43651 .51974 m .43759 .51753 L .4391 .51895 L 0 .026 .125 r
F
.43651 .51974 m .435 .51833 L .43759 .51753 L F
.5933 .52015 m .5946 .51793 L .59596 .51939 L 0 .027 .127 r
F
.5933 .52015 m .59193 .51868 L .5946 .51793 L F
.47403 .51999 m .47517 .51765 L .47664 .51918 L 0 .027 .126 r
F
.47403 .51999 m .47256 .51846 L .47517 .51765 L F
.36146 .51947 m .36245 .51708 L .36402 .51863 L 0 .026 .124 r
F
.36146 .51947 m .35989 .51793 L .36245 .51708 L F
.39898 .51967 m .40002 .51741 L .40155 .51895 L 0 .026 .125 r
F
.39898 .51967 m .39744 .51813 L .40002 .51741 L F
.56247 .5197 m .56373 .51741 L .56512 .5189 L F
.56247 .5197 m .56107 .51823 L .56373 .51741 L F
.51156 .52033 m .51275 .51799 L .51418 .51944 L 0 .028 .127 r
F
.51156 .52033 m .51012 .51887 L .51275 .51799 L F
.64421 .5198 m .64559 .51753 L .64691 .51903 L 0 .027 .126 r
F
.64421 .5198 m .64289 .51832 L .64559 .51753 L F
.59999 .52 m .60131 .51776 L .60266 .51918 L F
.59999 .52 m .59863 .5186 L .60131 .51776 L F
.4432 .51964 m .44429 .51748 L .44579 .5189 L 0 .026 .126 r
F
.4432 .51964 m .44169 .51822 L .44429 .51748 L F
.36814 .51929 m .36913 .51713 L .3707 .51856 L 0 .026 .125 r
F
.36814 .51929 m .36657 .51785 L .36913 .51713 L F
.51825 .52004 m .51945 .51772 L .52088 .51918 L 0 .027 .126 r
F
.51825 .52004 m .51681 .51855 L .51945 .51772 L F
.48072 .5199 m .48187 .51754 L .48334 .51907 L F
.48072 .5199 m .47925 .51837 L .48187 .51754 L F
.33061 .51919 m .33156 .51686 L .33316 .51833 L 0 .025 .124 r
F
.33061 .51919 m .32901 .51773 L .33156 .51686 L F
.52494 .51976 m .52615 .51749 L .52758 .51892 L 0 .027 .126 r
F
.52494 .51976 m .52351 .51832 L .52615 .51749 L F
.60669 .51981 m .60801 .51753 L .60937 .51898 L F
.60669 .51981 m .60534 .51837 L .60801 .51753 L F
.40566 .51964 m .40671 .51722 L .40824 .51877 L 0 .026 .125 r
F
.40566 .51964 m .40413 .51808 L .40671 .51722 L F
.56916 .51964 m .57043 .51728 L .57182 .51883 L F
.56916 .51964 m .56777 .51809 L .57043 .51728 L F
.33729 .51899 m .33825 .51661 L .33984 .51814 L 0 .025 .124 r
F
.33729 .51899 m .3357 .51746 L .33825 .51661 L F
.48741 .51975 m .48857 .51734 L .49003 .51889 L 0 .027 .126 r
F
.48741 .51975 m .48595 .51821 L .48857 .51734 L F
.44988 .51959 m .45099 .51742 L .45248 .51885 L F
.44988 .51959 m .44839 .51816 L .45099 .51742 L F
.53164 .5196 m .53285 .51735 L .53427 .51883 L F
.53164 .5196 m .53021 .51814 L .53285 .51735 L F
.37482 .51926 m .37582 .51706 L .37738 .51849 L 0 .026 .125 r
F
.37482 .51926 m .37326 .51783 L .37582 .51706 L F
.65092 .51982 m .6523 .51742 L .65362 .51898 L 0 .027 .126 r
F
.65092 .51982 m .6496 .51825 L .6523 .51742 L F
.41235 .51948 m .41341 .51715 L .41493 .51867 L 0 .026 .125 r
F
.41235 .51948 m .41082 .51794 L .41341 .51715 L F
.61339 .51973 m .61472 .51733 L .61607 .51892 L 0 .027 .126 r
F
.61339 .51973 m .61204 .51815 L .61472 .51733 L F
.57586 .51956 m .57714 .51715 L .57852 .51873 L 0 .026 .125 r
F
.57586 .51956 m .57448 .51799 L .57714 .51715 L F
.34398 .51883 m .34494 .51644 L .34653 .51798 L 0 .025 .123 r
F
.34398 .51883 m .34239 .51729 L .34494 .51644 L F
.65762 .51965 m .65901 .51723 L .66032 .51876 L 0 .027 .126 r
F
.65762 .51965 m .65631 .51811 L .65901 .51723 L F
.45657 .5195 m .45769 .51722 L .45917 .51863 L F
.45657 .5195 m .45508 .51807 L .45769 .51722 L F
.53833 .51952 m .53956 .5172 L .54097 .51872 L F
.53833 .51952 m .53691 .51802 L .53956 .5172 L F
.4941 .51971 m .49527 .51748 L .49672 .51901 L 0 .027 .127 r
F
.4941 .51971 m .49265 .51818 L .49527 .51748 L F
.3815 .51916 m .38251 .51693 L .38407 .51837 L 0 .026 .125 r
F
.3815 .51916 m .37995 .51771 L .38251 .51693 L F
.41903 .5194 m .4201 .51708 L .42162 .51862 L 0 .026 .126 r
F
.41903 .5194 m .41751 .51787 L .4201 .51708 L F
.46326 .51924 m .46439 .51699 L .46587 .51845 L 0 .026 .125 r
F
.46326 .51924 m .46178 .51777 L .46439 .51699 L F
.35066 .51872 m .35163 .51645 L .35321 .51799 L 0 .025 .124 r
F
.35066 .51872 m .34908 .5172 L .35163 .51645 L F
.58256 .51947 m .58385 .51717 L .58522 .51869 L 0 .027 .126 r
F
.58256 .51947 m .58118 .51794 L .58385 .51717 L F
.6201 .51971 m .62143 .51731 L .62278 .51889 L F
.6201 .51971 m .61875 .51812 L .62143 .51731 L F
.38819 .519 m .38921 .51674 L .39076 .51816 L 0 .026 .125 r
F
.38819 .519 m .38664 .51756 L .38921 .51674 L F
.54503 .51942 m .54626 .51711 L .54767 .51861 L 0 .027 .126 r
F
.54503 .51942 m .54362 .51792 L .54626 .51711 L F
.50079 .51971 m .50197 .51759 L .50342 .519 L 0 .028 .127 r
F
.50079 .51971 m .49934 .51831 L .50197 .51759 L F
.55172 .51919 m .55297 .51701 L .55437 .5184 L 0 .027 .126 r
F
.55172 .51919 m .55032 .51779 L .55297 .51701 L F
.39488 .51884 m .3959 .5167 L .39744 .51813 L 0 .026 .125 r
F
.39488 .51884 m .39333 .51741 L .3959 .5167 L F
.42572 .5194 m .42679 .51705 L .42831 .51861 L 0 .027 .126 r
F
.42572 .5194 m .4242 .51785 L .42679 .51705 L F
.6268 .51959 m .62815 .51729 L .62948 .51878 L 0 .027 .127 r
F
.6268 .51959 m .62546 .51808 L .62815 .51729 L F
.58926 .51942 m .59056 .51717 L .59193 .51868 L 0 .027 .126 r
F
.58926 .51942 m .58789 .51791 L .59056 .51717 L F
.46995 .51923 m .47109 .51694 L .47256 .51846 L F
.46995 .51923 m .46848 .5177 L .47109 .51694 L F
.6335 .51931 m .63486 .51716 L .63619 .51852 L F
.6335 .51931 m .63217 .51797 L .63486 .51716 L F
.35733 .51878 m .35832 .51637 L .35989 .51793 L 0 .025 .124 r
F
.35733 .51878 m .35576 .51723 L .35832 .51637 L F
.55842 .51901 m .55968 .51687 L .56107 .51823 L 0 .026 .126 r
F
.55842 .51901 m .55702 .51763 L .55968 .51687 L F
.43241 .5192 m .43349 .51686 L .435 .51833 L 0 .027 .126 r
F
.43241 .5192 m .4309 .51774 L .43349 .51686 L F
.6402 .5191 m .64157 .51693 L .64289 .51832 L F
.6402 .5191 m .63888 .51773 L .64157 .51693 L F
.50749 .51969 m .50867 .51747 L .51012 .51887 L 0 .028 .128 r
F
.50749 .51969 m .50604 .51828 L .50867 .51747 L F
.4391 .51895 m .44019 .51679 L .44169 .51822 L 0 .026 .126 r
F
.4391 .51895 m .43759 .51753 L .44019 .51679 L F
.47664 .51918 m .47779 .51683 L .47925 .51837 L 0 .027 .126 r
F
.47664 .51918 m .47517 .51765 L .47779 .51683 L F
.36402 .51863 m .36501 .51629 L .36657 .51785 L 0 .026 .124 r
F
.36402 .51863 m .36245 .51708 L .36501 .51629 L F
.59596 .51939 m .59727 .51714 L .59863 .5186 L 0 .027 .127 r
F
.59596 .51939 m .5946 .51793 L .59727 .51714 L F
.51418 .51944 m .51538 .51711 L .51681 .51855 L F
.51418 .51944 m .51275 .51799 L .51538 .51711 L F
.56512 .5189 m .56638 .51659 L .56777 .51809 L 0 .026 .125 r
F
.56512 .5189 m .56373 .51741 L .56638 .51659 L F
.40155 .51895 m .4026 .51654 L .40413 .51808 L F
.40155 .51895 m .40002 .51741 L .4026 .51654 L F
.52088 .51918 m .52208 .51689 L .52351 .51832 L 0 .027 .126 r
F
.52088 .51918 m .51945 .51772 L .52208 .51689 L F
.60266 .51918 m .60398 .51693 L .60534 .51837 L F
.60266 .51918 m .60131 .51776 L .60398 .51693 L F
.64691 .51903 m .64828 .51674 L .6496 .51825 L F
.64691 .51903 m .64559 .51753 L .64828 .51674 L F
.48334 .51907 m .48449 .51666 L .48595 .51821 L F
.48334 .51907 m .48187 .51754 L .48449 .51666 L F
.33316 .51833 m .3341 .51599 L .3357 .51746 L 0 .025 .124 r
F
.33316 .51833 m .33156 .51686 L .3341 .51599 L F
.44579 .5189 m .44689 .51672 L .44839 .51816 L 0 .027 .126 r
F
.44579 .5189 m .44429 .51748 L .44689 .51672 L F
.52758 .51892 m .52879 .5167 L .53021 .51814 L F
.52758 .51892 m .52615 .51749 L .52879 .5167 L F
.3707 .51856 m .37169 .51641 L .37326 .51783 L 0 .026 .125 r
F
.3707 .51856 m .36913 .51713 L .37169 .51641 L F
.40824 .51877 m .40929 .5164 L .41082 .51794 L F
.40824 .51877 m .40671 .51722 L .40929 .5164 L F
.60937 .51898 m .61069 .51668 L .61204 .51815 L 0 .027 .126 r
F
.60937 .51898 m .60801 .51753 L .61069 .51668 L F
.57182 .51883 m .57309 .51642 L .57448 .51799 L 0 .026 .125 r
F
.57182 .51883 m .57043 .51728 L .57309 .51642 L F
.33984 .51814 m .3408 .51576 L .34239 .51729 L 0 .025 .123 r
F
.33984 .51814 m .33825 .51661 L .3408 .51576 L F
.49003 .51889 m .49119 .51662 L .49265 .51818 L 0 .027 .126 r
F
.49003 .51889 m .48857 .51734 L .49119 .51662 L F
.65362 .51898 m .655 .51656 L .65631 .51811 L F
.65362 .51898 m .6523 .51742 L .655 .51656 L F
.53427 .51883 m .5355 .51652 L .53691 .51802 L F
.53427 .51883 m .53285 .51735 L .5355 .51652 L F
.45248 .51885 m .45359 .51664 L .45508 .51807 L F
.45248 .51885 m .45099 .51742 L .45359 .51664 L F
.37738 .51849 m .37838 .51628 L .37995 .51771 L 0 .026 .125 r
F
.37738 .51849 m .37582 .51706 L .37838 .51628 L F
.41493 .51867 m .41599 .51637 L .41751 .51787 L F
.41493 .51867 m .41341 .51715 L .41599 .51637 L F
.34653 .51798 m .34749 .51566 L .34908 .5172 L 0 .025 .123 r
F
.34653 .51798 m .34494 .51644 L .34749 .51566 L F
.57852 .51873 m .5798 .51637 L .58118 .51794 L 0 .026 .126 r
F
.57852 .51873 m .57714 .51715 L .5798 .51637 L F
.61607 .51892 m .6174 .51655 L .61875 .51812 L 0 .027 .126 r
F
.61607 .51892 m .61472 .51733 L .6174 .51655 L F
.66032 .51876 m .66171 .51637 L .66302 .51788 L 0 .026 .126 r
F
.66032 .51876 m .65901 .51723 L .66171 .51637 L F
.45917 .51863 m .46029 .51636 L .46178 .51777 L F
.45917 .51863 m .45769 .51722 L .46029 .51636 L F
.54097 .51872 m .5422 .51638 L .54362 .51792 L 0 .027 .126 r
F
.54097 .51872 m .53956 .5172 L .5422 .51638 L F
.38407 .51837 m .38508 .51611 L .38664 .51756 L 0 .026 .125 r
F
.38407 .51837 m .38251 .51693 L .38508 .51611 L F
.42162 .51862 m .42269 .51629 L .4242 .51785 L 0 .027 .126 r
F
.42162 .51862 m .4201 .51708 L .42269 .51629 L F
.46587 .51845 m .46699 .51625 L .46848 .5177 L 0 .026 .125 r
F
.46587 .51845 m .46439 .51699 L .46699 .51625 L F
.49672 .51901 m .49789 .51677 L .49934 .51831 L 0 .028 .127 r
F
.49672 .51901 m .49527 .51748 L .49789 .51677 L F
.58522 .51869 m .58652 .5164 L .58789 .51791 L 0 .027 .126 r
F
.58522 .51869 m .58385 .51717 L .58652 .5164 L F
.62278 .51889 m .62412 .51653 L .62546 .51808 L F
.62278 .51889 m .62143 .51731 L .62412 .51653 L F
.39076 .51816 m .39178 .51599 L .39333 .51741 L 0 .026 .125 r
F
.39076 .51816 m .38921 .51674 L .39178 .51599 L F
.35321 .51799 m .35418 .51568 L .35576 .51723 L 0 .025 .124 r
F
.35321 .51799 m .35163 .51645 L .35418 .51568 L F
.54767 .51861 m .54891 .5163 L .55032 .51779 L 0 .027 .126 r
F
.54767 .51861 m .54626 .51711 L .54891 .5163 L F
.55437 .5184 m .55562 .51626 L .55702 .51763 L F
.55437 .5184 m .55297 .51701 L .55562 .51626 L F
.62948 .51878 m .63084 .51649 L .63217 .51797 L 0 .027 .127 r
F
.62948 .51878 m .62815 .51729 L .63084 .51649 L F
.42831 .51861 m .42939 .51617 L .4309 .51774 L 0 .027 .126 r
F
.42831 .51861 m .42679 .51705 L .42939 .51617 L F
.50342 .519 m .5046 .51687 L .50604 .51828 L 0 .028 .128 r
F
.50342 .519 m .50197 .51759 L .5046 .51687 L F
.47256 .51846 m .4737 .51611 L .47517 .51765 L 0 .027 .126 r
F
.47256 .51846 m .47109 .51694 L .4737 .51611 L F
.35989 .51793 m .36088 .51551 L .36245 .51708 L 0 .025 .124 r
F
.35989 .51793 m .35832 .51637 L .36088 .51551 L F
.59193 .51868 m .59323 .51643 L .5946 .51793 L 0 .027 .127 r
F
.59193 .51868 m .59056 .51717 L .59323 .51643 L F
.39744 .51813 m .39847 .51598 L .40002 .51741 L 0 .026 .125 r
F
.39744 .51813 m .3959 .5167 L .39847 .51598 L F
.435 .51833 m .43609 .51606 L .43759 .51753 L 0 .026 .126 r
F
.435 .51833 m .43349 .51686 L .43609 .51606 L F
.63619 .51852 m .63755 .51635 L .63888 .51773 L 0 .027 .126 r
F
.63619 .51852 m .63486 .51716 L .63755 .51635 L F
.56107 .51823 m .56233 .51603 L .56373 .51741 L F
.56107 .51823 m .55968 .51687 L .56233 .51603 L F
.51012 .51887 m .51131 .5166 L .51275 .51799 L 0 .028 .127 r
F
.51012 .51887 m .50867 .51747 L .51131 .5166 L F
.64289 .51832 m .64427 .51612 L .64559 .51753 L 0 .027 .126 r
F
.64289 .51832 m .64157 .51693 L .64427 .51612 L F
.51681 .51855 m .51801 .5163 L .51945 .51772 L 0 .027 .127 r
F
.51681 .51855 m .51538 .51711 L .51801 .5163 L F
.47925 .51837 m .4804 .51599 L .48187 .51754 L 0 .027 .126 r
F
.47925 .51837 m .47779 .51683 L .4804 .51599 L F
.44169 .51822 m .44279 .51605 L .44429 .51748 L F
.44169 .51822 m .44019 .51679 L .44279 .51605 L F
.36657 .51785 m .36756 .51558 L .36913 .51713 L 0 .026 .125 r
F
.36657 .51785 m .36501 .51629 L .36756 .51558 L F
.59863 .5186 m .59995 .51629 L .60131 .51776 L 0 .027 .127 r
F
.59863 .5186 m .59727 .51714 L .59995 .51629 L F
.40413 .51808 m .40518 .51568 L .40671 .51722 L 0 .026 .125 r
F
.40413 .51808 m .4026 .51654 L .40518 .51568 L F
.56777 .51809 m .56904 .51576 L .57043 .51728 L F
.56777 .51809 m .56638 .51659 L .56904 .51576 L F
.32901 .51773 m .32995 .51541 L .33156 .51686 L 0 .025 .124 r
F
.32901 .51773 m .3274 .51628 L .32995 .51541 L F
.52351 .51832 m .52472 .51607 L .52615 .51749 L 0 .027 .126 r
F
.52351 .51832 m .52208 .51689 L .52472 .51607 L F
.60534 .51837 m .60666 .51607 L .60801 .51753 L F
.60534 .51837 m .60398 .51693 L .60666 .51607 L F
.48595 .51821 m .48711 .51579 L .48857 .51734 L 0 .026 .126 r
F
.48595 .51821 m .48449 .51666 L .48711 .51579 L F
.3357 .51746 m .33665 .51513 L .33825 .51661 L 0 .025 .124 r
F
.3357 .51746 m .3341 .51599 L .33665 .51513 L F
.6496 .51825 m .65098 .51591 L .6523 .51742 L 0 .027 .126 r
F
.6496 .51825 m .64828 .51674 L .65098 .51591 L F
.41082 .51794 m .41188 .51564 L .41341 .51715 L 0 .026 .125 r
F
.41082 .51794 m .40929 .5164 L .41188 .51564 L F
.53021 .51814 m .53143 .51591 L .53285 .51735 L 0 .027 .126 r
F
.53021 .51814 m .52879 .5167 L .53143 .51591 L F
.61204 .51815 m .61337 .51585 L .61472 .51733 L F
.61204 .51815 m .61069 .51668 L .61337 .51585 L F
.44839 .51816 m .44949 .51595 L .45099 .51742 L F
.44839 .51816 m .44689 .51672 L .44949 .51595 L F
.57448 .51799 m .57575 .51557 L .57714 .51715 L 0 .026 .125 r
F
.57448 .51799 m .57309 .51642 L .57575 .51557 L F
.37326 .51783 m .37425 .51563 L .37582 .51706 L F
.37326 .51783 m .37169 .51641 L .37425 .51563 L F
.34239 .51729 m .34336 .51491 L .34494 .51644 L 0 .025 .123 r
F
.34239 .51729 m .3408 .51576 L .34336 .51491 L F
.65631 .51811 m .6577 .5157 L .65901 .51723 L 0 .027 .126 r
F
.65631 .51811 m .655 .51656 L .6577 .5157 L F
.49265 .51818 m .49381 .51591 L .49527 .51748 L F
.49265 .51818 m .49119 .51662 L .49381 .51591 L F
.53691 .51802 m .53814 .51568 L .53956 .5172 L F
.53691 .51802 m .5355 .51652 L .53814 .51568 L F
.41751 .51787 m .41858 .51558 L .4201 .51708 L 0 .026 .125 r
F
.41751 .51787 m .41599 .51637 L .41858 .51558 L F
.66302 .51788 m .66441 .5155 L .66572 .51699 L F
.66302 .51788 m .66171 .51637 L .66441 .5155 L F
.45508 .51807 m .45619 .5158 L .45769 .51722 L 0 .027 .126 r
F
.45508 .51807 m .45359 .51664 L .45619 .5158 L F
.37995 .51771 m .38095 .51548 L .38251 .51693 L 0 .026 .125 r
F
.37995 .51771 m .37838 .51628 L .38095 .51548 L F
.61875 .51812 m .62009 .51576 L .62143 .51731 L 0 .027 .126 r
F
.61875 .51812 m .6174 .51655 L .62009 .51576 L F
.58118 .51794 m .58247 .51561 L .58385 .51717 L F
.58118 .51794 m .5798 .51637 L .58247 .51561 L F
.34908 .5172 m .35005 .51489 L .35163 .51645 L 0 .025 .124 r
F
.34908 .5172 m .34749 .51566 L .35005 .51489 L F
.46178 .51777 m .4629 .51559 L .46439 .51699 L 0 .026 .126 r
F
.46178 .51777 m .46029 .51636 L .4629 .51559 L F
.54362 .51792 m .54485 .51558 L .54626 .51711 L 0 .027 .126 r
F
.54362 .51792 m .5422 .51638 L .54485 .51558 L F
.38664 .51756 m .38766 .5153 L .38921 .51674 L 0 .026 .125 r
F
.38664 .51756 m .38508 .51611 L .38766 .5153 L F
.4242 .51785 m .42528 .51549 L .42679 .51705 L 0 .027 .126 r
F
.4242 .51785 m .42269 .51629 L .42528 .51549 L F
.46848 .5177 m .46961 .51549 L .47109 .51694 L F
.46848 .5177 m .46699 .51625 L .46961 .51549 L F
.62546 .51808 m .62681 .51575 L .62815 .51729 L 0 .027 .127 r
F
.62546 .51808 m .62412 .51653 L .62681 .51575 L F
.58789 .51791 m .58919 .51566 L .59056 .51717 L 0 .027 .126 r
F
.58789 .51791 m .58652 .5164 L .58919 .51566 L F
.49934 .51831 m .50052 .51604 L .50197 .51759 L 0 .028 .127 r
F
.49934 .51831 m .49789 .51677 L .50052 .51604 L F
.39333 .51741 m .39435 .51528 L .3959 .5167 L 0 .026 .125 r
F
.39333 .51741 m .39178 .51599 L .39435 .51528 L F
.55032 .51779 m .55156 .51552 L .55297 .51701 L 0 .027 .126 r
F
.55032 .51779 m .54891 .5163 L .55156 .51552 L F
.35576 .51723 m .35674 .51481 L .35832 .51637 L 0 .025 .124 r
F
.35576 .51723 m .35418 .51568 L .35674 .51481 L F
.4309 .51774 m .43198 .5153 L .43349 .51686 L 0 .027 .126 r
F
.4309 .51774 m .42939 .51617 L .43198 .5153 L F
.63217 .51797 m .63353 .51566 L .63486 .51716 L 0 .027 .127 r
F
.63217 .51797 m .63084 .51649 L .63353 .51566 L F
.55702 .51763 m .55828 .5155 L .55968 .51687 L 0 .027 .126 r
F
.55702 .51763 m .55562 .51626 L .55828 .5155 L F
.36245 .51708 m .36344 .51472 L .36501 .51629 L 0 .025 .124 r
F
.36245 .51708 m .36088 .51551 L .36344 .51472 L F
.47517 .51765 m .47631 .51529 L .47779 .51683 L 0 .027 .126 r
F
.47517 .51765 m .4737 .51611 L .47631 .51529 L F
.43759 .51753 m .43868 .51532 L .44019 .51679 L F
.43759 .51753 m .43609 .51606 L .43868 .51532 L F
.50604 .51828 m .50723 .51606 L .50867 .51747 L 0 .028 .128 r
F
.50604 .51828 m .5046 .51687 L .50723 .51606 L F
.63888 .51773 m .64025 .51553 L .64157 .51693 L 0 .027 .126 r
F
.63888 .51773 m .63755 .51635 L .64025 .51553 L F
.5946 .51793 m .59591 .51564 L .59727 .51714 L 0 .027 .127 r
F
.5946 .51793 m .59323 .51643 L .59591 .51564 L F
.40002 .51741 m .40106 .51511 L .4026 .51654 L 0 .026 .125 r
F
.40002 .51741 m .39847 .51598 L .40106 .51511 L F
.56373 .51741 m .56499 .51519 L .56638 .51659 L 0 .026 .126 r
F
.56373 .51741 m .56233 .51603 L .56499 .51519 L F
.51275 .51799 m .51394 .51573 L .51538 .51711 L 0 .028 .127 r
F
.51275 .51799 m .51131 .5166 L .51394 .51573 L F
.64559 .51753 m .64696 .51531 L .64828 .51674 L 0 .027 .126 r
F
.64559 .51753 m .64427 .51612 L .64696 .51531 L F
.51945 .51772 m .52065 .51549 L .52208 .51689 L 0 .027 .127 r
F
.51945 .51772 m .51801 .5163 L .52065 .51549 L F
.48187 .51754 m .48302 .51513 L .48449 .51666 L 0 .027 .126 r
F
.48187 .51754 m .4804 .51599 L .48302 .51513 L F
.60131 .51776 m .60262 .51544 L .60398 .51693 L 0 .027 .127 r
F
.60131 .51776 m .59995 .51629 L .60262 .51544 L F
.40671 .51722 m .40776 .51487 L .40929 .5164 L 0 .026 .125 r
F
.40671 .51722 m .40518 .51568 L .40776 .51487 L F
.33156 .51686 m .3325 .51455 L .3341 .51599 L 0 .025 .124 r
F
.33156 .51686 m .32995 .51541 L .3325 .51455 L F
.57043 .51728 m .5717 .51489 L .57309 .51642 L 0 .026 .125 r
F
.57043 .51728 m .56904 .51576 L .5717 .51489 L F
.44429 .51748 m .44539 .51527 L .44689 .51672 L 0 .027 .126 r
F
.44429 .51748 m .44279 .51605 L .44539 .51527 L F
.52615 .51749 m .52736 .51527 L .52879 .5167 L F
.52615 .51749 m .52472 .51607 L .52736 .51527 L F
.36913 .51713 m .37012 .51486 L .37169 .51641 L 0 .026 .125 r
F
.36913 .51713 m .36756 .51558 L .37012 .51486 L F
.60801 .51753 m .60934 .5152 L .61069 .51668 L 0 .027 .126 r
F
.60801 .51753 m .60666 .51607 L .60934 .5152 L F
.48857 .51734 m .48973 .51506 L .49119 .51662 L F
.48857 .51734 m .48711 .51579 L .48973 .51506 L F
.33825 .51661 m .33921 .51429 L .3408 .51576 L 0 .025 .123 r
F
.33825 .51661 m .33665 .51513 L .33921 .51429 L F
.6523 .51742 m .65368 .51507 L .655 .51656 L 0 .027 .126 r
F
.6523 .51742 m .65098 .51591 L .65368 .51507 L F
.61472 .51733 m .61606 .51508 L .6174 .51655 L F
.61472 .51733 m .61337 .51585 L .61606 .51508 L F
.41341 .51715 m .41446 .51488 L .41599 .51637 L 0 .026 .125 r
F
.41341 .51715 m .41188 .51564 L .41446 .51488 L F
.57714 .51715 m .57842 .51479 L .5798 .51637 L F
.57714 .51715 m .57575 .51557 L .57842 .51479 L F
.53285 .51735 m .53408 .51507 L .5355 .51652 L 0 .027 .126 r
F
.53285 .51735 m .53143 .51591 L .53408 .51507 L F
.34494 .51644 m .34591 .51411 L .34749 .51566 L 0 .025 .123 r
F
.34494 .51644 m .34336 .51491 L .34591 .51411 L F
.45099 .51742 m .45209 .51516 L .45359 .51664 L 0 .027 .126 r
F
.45099 .51742 m .44949 .51595 L .45209 .51516 L F
.65901 .51723 m .6604 .51486 L .66171 .51637 L 0 .026 .125 r
F
.65901 .51723 m .6577 .5157 L .6604 .51486 L F
.37582 .51706 m .37682 .51484 L .37838 .51628 L F
.37582 .51706 m .37425 .51563 L .37682 .51484 L F
.66572 .51699 m .66712 .51469 L .66842 .51618 L F
.66572 .51699 m .66441 .5155 L .66712 .51469 L F
.53956 .5172 m .54079 .51484 L .5422 .51638 L 0 .027 .126 r
F
.53956 .5172 m .53814 .51568 L .54079 .51484 L F
.45769 .51722 m .4588 .51495 L .46029 .51636 L F
.45769 .51722 m .45619 .5158 L .4588 .51495 L F
.4201 .51708 m .42117 .51478 L .42269 .51629 L 0 .026 .126 r
F
.4201 .51708 m .41858 .51558 L .42117 .51478 L F
.49527 .51748 m .49644 .5152 L .49789 .51677 L 0 .027 .127 r
F
.49527 .51748 m .49381 .51591 L .49644 .5152 L F
.38251 .51693 m .38353 .51466 L .38508 .51611 L 0 .026 .125 r
F
.38251 .51693 m .38095 .51548 L .38353 .51466 L F
.62143 .51731 m .62278 .51499 L .62412 .51653 L 0 .027 .126 r
F
.62143 .51731 m .62009 .51576 L .62278 .51499 L F
.58385 .51717 m .58514 .51486 L .58652 .5164 L F
.58385 .51717 m .58247 .51561 L .58514 .51486 L F
.46439 .51699 m .46551 .51486 L .46699 .51625 L F
.46439 .51699 m .4629 .51559 L .46551 .51486 L F
.35163 .51645 m .3526 .51411 L .35418 .51568 L 0 .025 .124 r
F
.35163 .51645 m .35005 .51489 L .3526 .51411 L F
.54626 .51711 m .5475 .51477 L .54891 .5163 L 0 .027 .126 r
F
.54626 .51711 m .54485 .51558 L .5475 .51477 L F
.38921 .51674 m .39023 .51455 L .39178 .51599 L 0 .026 .125 r
F
.38921 .51674 m .38766 .5153 L .39023 .51455 L F
.42679 .51705 m .42787 .51461 L .42939 .51617 L 0 .027 .126 r
F
.42679 .51705 m .42528 .51549 L .42787 .51461 L F
.62815 .51729 m .6295 .51497 L .63084 .51649 L 0 .027 .127 r
F
.62815 .51729 m .62681 .51575 L .6295 .51497 L F
.35832 .51637 m .3593 .51394 L .36088 .51551 L 0 .025 .124 r
F
.35832 .51637 m .35674 .51481 L .3593 .51394 L F
.47109 .51694 m .47222 .51465 L .4737 .51611 L 0 .027 .126 r
F
.47109 .51694 m .46961 .51549 L .47222 .51465 L F
.59056 .51717 m .59186 .51493 L .59323 .51643 L 0 .027 .127 r
F
.59056 .51717 m .58919 .51566 L .59186 .51493 L F
.55297 .51701 m .55422 .51478 L .55562 .51626 L 0 .027 .126 r
F
.55297 .51701 m .55156 .51552 L .55422 .51478 L F
.50197 .51759 m .50315 .5153 L .5046 .51687 L 0 .028 .128 r
F
.50197 .51759 m .50052 .51604 L .50315 .5153 L F
.43349 .51686 m .43458 .51451 L .43609 .51606 L 0 .026 .126 r
F
.43349 .51686 m .43198 .5153 L .43458 .51451 L F
.3959 .5167 m .39693 .51456 L .39847 .51598 L 0 .027 .126 r
F
.3959 .5167 m .39435 .51528 L .39693 .51456 L F
.63486 .51716 m .63622 .51483 L .63755 .51635 L 0 .027 .127 r
F
.63486 .51716 m .63353 .51566 L .63622 .51483 L F
.47779 .51683 m .47893 .51445 L .4804 .51599 L 0 .027 .126 r
F
.47779 .51683 m .47631 .51529 L .47893 .51445 L F
.36501 .51629 m .366 .514 L .36756 .51558 L 0 .026 .124 r
F
.36501 .51629 m .36344 .51472 L .366 .514 L F
.55968 .51687 m .56094 .51465 L .56233 .51603 L 0 .027 .126 r
F
.55968 .51687 m .55828 .5155 L .56094 .51465 L F
.50867 .51747 m .50986 .5152 L .51131 .5166 L 0 .028 .128 r
F
.50867 .51747 m .50723 .51606 L .50986 .5152 L F
.4026 .51654 m .40364 .51424 L .40518 .51568 L 0 .026 .125 r
F
.4026 .51654 m .40106 .51511 L .40364 .51424 L F
.51538 .51711 m .51658 .51494 L .51801 .5163 L 0 .028 .127 r
F
.51538 .51711 m .51394 .51573 L .51658 .51494 L F
.64157 .51693 m .64295 .51471 L .64427 .51612 L 0 .027 .126 r
F
.64157 .51693 m .64025 .51553 L .64295 .51471 L F
.59727 .51714 m .59858 .51477 L .59995 .51629 L 0 .027 .127 r
F
.59727 .51714 m .59591 .51564 L .59858 .51477 L F
.56638 .51659 m .56765 .51434 L .56904 .51576 L 0 .026 .125 r
F
.56638 .51659 m .56499 .51519 L .56765 .51434 L F
.44019 .51679 m .44128 .51458 L .44279 .51605 L 0 .027 .126 r
F
.44019 .51679 m .43868 .51532 L .44128 .51458 L F
.3274 .51628 m .32834 .51397 L .32995 .51541 L 0 .026 .124 r
F
.3274 .51628 m .32579 .51482 L .32834 .51397 L F
.48449 .51666 m .48565 .51426 L .48711 .51579 L 0 .026 .125 r
F
.48449 .51666 m .48302 .51513 L .48565 .51426 L F
.52208 .51689 m .52329 .51468 L .52472 .51607 L 0 .027 .127 r
F
.52208 .51689 m .52065 .51549 L .52329 .51468 L F
.64828 .51674 m .64967 .51449 L .65098 .51591 L 0 .027 .126 r
F
.64828 .51674 m .64696 .51531 L .64967 .51449 L F
.3341 .51599 m .33505 .5137 L .33665 .51513 L 0 .025 .124 r
F
.3341 .51599 m .3325 .51455 L .33505 .5137 L F
.60398 .51693 m .6053 .51457 L .60666 .51607 L 0 .027 .126 r
F
.60398 .51693 m .60262 .51544 L .6053 .51457 L F
.40929 .5164 m .41035 .51413 L .41188 .51564 L 0 .026 .125 r
F
.40929 .5164 m .40776 .51487 L .41035 .51413 L F
.57309 .51642 m .57437 .51403 L .57575 .51557 L F
.57309 .51642 m .5717 .51489 L .57437 .51403 L F
.61069 .51668 m .61202 .51436 L .61337 .51585 L 0 .027 .126 r
F
.61069 .51668 m .60934 .5152 L .61202 .51436 L F
.3408 .51576 m .34176 .51344 L .34336 .51491 L 0 .025 .123 r
F
.3408 .51576 m .33921 .51429 L .34176 .51344 L F
.52879 .5167 m .53001 .51447 L .53143 .51591 L 0 .027 .126 r
F
.52879 .5167 m .52736 .51527 L .53001 .51447 L F
.44689 .51672 m .44799 .51448 L .44949 .51595 L F
.44689 .51672 m .44539 .51527 L .44799 .51448 L F
.655 .51656 m .65638 .51423 L .6577 .5157 L F
.655 .51656 m .65368 .51507 L .65638 .51423 L F
.37169 .51641 m .37269 .51407 L .37425 .51563 L 0 .026 .125 r
F
.37169 .51641 m .37012 .51486 L .37269 .51407 L F
.49119 .51662 m .49236 .51436 L .49381 .51591 L 0 .027 .126 r
F
.49119 .51662 m .48973 .51506 L .49236 .51436 L F
.5355 .51652 m .53672 .51422 L .53814 .51568 L F
.5355 .51652 m .53408 .51507 L .53672 .51422 L F
.6174 .51655 m .61874 .51432 L .62009 .51576 L F
.6174 .51655 m .61606 .51508 L .61874 .51432 L F
.41599 .51637 m .41705 .51409 L .41858 .51558 L 0 .026 .125 r
F
.41599 .51637 m .41446 .51488 L .41705 .51409 L F
.66171 .51637 m .66311 .51401 L .66441 .5155 L F
.66171 .51637 m .6604 .51486 L .66311 .51401 L F
.5798 .51637 m .58109 .51405 L .58247 .51561 L F
.5798 .51637 m .57842 .51479 L .58109 .51405 L F
.34749 .51566 m .34846 .51334 L .35005 .51489 L 0 .025 .123 r
F
.34749 .51566 m .34591 .51411 L .34846 .51334 L F
.45359 .51664 m .4547 .51431 L .45619 .5158 L 0 .027 .126 r
F
.45359 .51664 m .45209 .51516 L .4547 .51431 L F
.37838 .51628 m .37939 .51404 L .38095 .51548 L 0 .026 .125 r
F
.37838 .51628 m .37682 .51484 L .37939 .51404 L F
.46029 .51636 m .46141 .51419 L .4629 .51559 L 0 .027 .126 r
F
.46029 .51636 m .4588 .51495 L .46141 .51419 L F
.66842 .51618 m .66983 .51392 L .67114 .51543 L 0 .026 .125 r
F
.66842 .51618 m .66712 .51469 L .66983 .51392 L F
.5422 .51638 m .54344 .51404 L .54485 .51558 L 0 .027 .126 r
F
.5422 .51638 m .54079 .51484 L .54344 .51404 L F
.42269 .51629 m .42376 .51398 L .42528 .51549 L F
.42269 .51629 m .42117 .51478 L .42376 .51398 L F
.38508 .51611 m .3861 .51384 L .38766 .5153 L 0 .026 .125 r
F
.38508 .51611 m .38353 .51466 L .3861 .51384 L F
.62412 .51653 m .62547 .51423 L .62681 .51575 L 0 .027 .126 r
F
.62412 .51653 m .62278 .51499 L .62547 .51423 L F
.58652 .5164 m .58781 .51413 L .58919 .51566 L F
.58652 .5164 m .58514 .51486 L .58781 .51413 L F
.49789 .51677 m .49907 .51445 L .50052 .51604 L 0 .028 .127 r
F
.49789 .51677 m .49644 .5152 L .49907 .51445 L F
.35418 .51568 m .35516 .51325 L .35674 .51481 L 0 .025 .124 r
F
.35418 .51568 m .3526 .51411 L .35516 .51325 L F
.46699 .51625 m .46812 .51411 L .46961 .51549 L 0 .027 .126 r
F
.46699 .51625 m .46551 .51486 L .46812 .51411 L F
.54891 .5163 m .55016 .51399 L .55156 .51552 L F
.54891 .5163 m .5475 .51477 L .55016 .51399 L F
.42939 .51617 m .43047 .51373 L .43198 .5153 L 0 .026 .125 r
F
.42939 .51617 m .42787 .51461 L .43047 .51373 L F
.39178 .51599 m .3928 .51383 L .39435 .51528 L F
.39178 .51599 m .39023 .51455 L .3928 .51383 L F
.36088 .51551 m .36187 .51315 L .36344 .51472 L 0 .025 .124 r
F
.36088 .51551 m .3593 .51394 L .36187 .51315 L F
.4737 .51611 m .47484 .51382 L .47631 .51529 L 0 .027 .126 r
F
.4737 .51611 m .47222 .51465 L .47484 .51382 L F
.63084 .51649 m .63219 .51412 L .63353 .51566 L 0 .027 .127 r
F
.63084 .51649 m .6295 .51497 L .63219 .51412 L F
.59323 .51643 m .59454 .51413 L .59591 .51564 L F
.59323 .51643 m .59186 .51493 L .59454 .51413 L F
.43609 .51606 m .43718 .51378 L .43868 .51532 L 0 .027 .126 r
F
.43609 .51606 m .43458 .51451 L .43718 .51378 L F
.55562 .51626 m .55688 .51403 L .55828 .5155 L 0 .027 .127 r
F
.55562 .51626 m .55422 .51478 L .55688 .51403 L F
.5046 .51687 m .50578 .5145 L .50723 .51606 L 0 .028 .128 r
F
.5046 .51687 m .50315 .5153 L .50578 .5145 L F
.63755 .51635 m .63892 .514 L .64025 .51553 L 0 .027 .127 r
F
.63755 .51635 m .63622 .51483 L .63892 .514 L F
.39847 .51598 m .39951 .51368 L .40106 .51511 L 0 .027 .126 r
F
.39847 .51598 m .39693 .51456 L .39951 .51368 L F
.4804 .51599 m .48155 .51359 L .48302 .51513 L 0 .026 .126 r
F
.4804 .51599 m .47893 .51445 L .48155 .51359 L F
.56233 .51603 m .5636 .51379 L .56499 .51519 L 0 .027 .126 r
F
.56233 .51603 m .56094 .51465 L .5636 .51379 L F
.51131 .5166 m .5125 .51434 L .51394 .51573 L 0 .028 .128 r
F
.51131 .5166 m .50986 .5152 L .5125 .51434 L F
.40518 .51568 m .40622 .51342 L .40776 .51487 L 0 .026 .125 r
F
.40518 .51568 m .40364 .51424 L .40622 .51342 L F
.59995 .51629 m .60126 .51391 L .60262 .51544 L 0 .027 .127 r
F
.59995 .51629 m .59858 .51477 L .60126 .51391 L F
.51801 .5163 m .51922 .51415 L .52065 .51549 L 0 .028 .127 r
F
.51801 .5163 m .51658 .51494 L .51922 .51415 L F
.64427 .51612 m .64564 .51388 L .64696 .51531 L 0 .027 .126 r
F
.64427 .51612 m .64295 .51471 L .64564 .51388 L F
.56904 .51576 m .57031 .51346 L .5717 .51489 L 0 .026 .125 r
F
.56904 .51576 m .56765 .51434 L .57031 .51346 L F
.36756 .51558 m .36856 .51329 L .37012 .51486 L F
.36756 .51558 m .366 .514 L .36856 .51329 L F
.32995 .51541 m .33089 .51311 L .3325 .51455 L 0 .026 .124 r
F
.32995 .51541 m .32834 .51397 L .33089 .51311 L F
.48711 .51579 m .48827 .51354 L .48973 .51506 L 0 .026 .126 r
F
.48711 .51579 m .48565 .51426 L .48827 .51354 L F
.44279 .51605 m .44388 .51379 L .44539 .51527 L 0 .027 .126 r
F
.44279 .51605 m .44128 .51458 L .44388 .51379 L F
.33665 .51513 m .33761 .51286 L .33921 .51429 L 0 .025 .124 r
F
.33665 .51513 m .33505 .5137 L .33761 .51286 L F
.52472 .51607 m .52593 .51386 L .52736 .51527 L 0 .027 .127 r
F
.52472 .51607 m .52329 .51468 L .52593 .51386 L F
.60666 .51607 m .60798 .51369 L .60934 .5152 L 0 .027 .126 r
F
.60666 .51607 m .6053 .51457 L .60798 .51369 L F
.65098 .51591 m .65237 .51366 L .65368 .51507 L F
.65098 .51591 m .64967 .51449 L .65237 .51366 L F
.57575 .51557 m .57704 .51325 L .57842 .51479 L 0 .026 .125 r
F
.57575 .51557 m .57437 .51403 L .57704 .51325 L F
.41188 .51564 m .41293 .51339 L .41446 .51488 L F
.41188 .51564 m .41035 .51413 L .41293 .51339 L F
.34336 .51491 m .34431 .51264 L .34591 .51411 L 0 .025 .123 r
F
.34336 .51491 m .34176 .51344 L .34431 .51264 L F
.61337 .51585 m .61471 .51362 L .61606 .51508 L 0 .027 .126 r
F
.61337 .51585 m .61202 .51436 L .61471 .51362 L F
.6577 .5157 m .65909 .51339 L .6604 .51486 L 0 .026 .126 r
F
.6577 .5157 m .65638 .51423 L .65909 .51339 L F
.53143 .51591 m .53265 .51362 L .53408 .51507 L 0 .027 .126 r
F
.53143 .51591 m .53001 .51447 L .53265 .51362 L F
.44949 .51595 m .4506 .51367 L .45209 .51516 L F
.44949 .51595 m .44799 .51448 L .4506 .51367 L F
.37425 .51563 m .37526 .51327 L .37682 .51484 L 0 .026 .125 r
F
.37425 .51563 m .37269 .51407 L .37526 .51327 L F
.53814 .51568 m .53937 .51337 L .54079 .51484 L 0 .027 .126 r
F
.53814 .51568 m .53672 .51422 L .53937 .51337 L F
.66441 .5155 m .66582 .51319 L .66712 .51469 L 0 .026 .125 r
F
.66441 .5155 m .66311 .51401 L .66582 .51319 L F
.49381 .51591 m .49498 .51363 L .49644 .5152 L 0 .027 .127 r
F
.49381 .51591 m .49236 .51436 L .49498 .51363 L F
.62009 .51576 m .62143 .51356 L .62278 .51499 L 0 .027 .126 r
F
.62009 .51576 m .61874 .51432 L .62143 .51356 L F
.41858 .51558 m .41964 .51329 L .42117 .51478 L F
.41858 .51558 m .41705 .51409 L .41964 .51329 L F
.45619 .5158 m .45731 .51347 L .4588 .51495 L F
.45619 .5158 m .4547 .51431 L .45731 .51347 L F
.58247 .51561 m .58376 .51331 L .58514 .51486 L F
.58247 .51561 m .58109 .51405 L .58376 .51331 L F
.35005 .51489 m .35102 .51255 L .3526 .51411 L 0 .025 .124 r
F
.35005 .51489 m .34846 .51334 L .35102 .51255 L F
.38095 .51548 m .38197 .51321 L .38353 .51466 L 0 .026 .126 r
F
.38095 .51548 m .37939 .51404 L .38197 .51321 L F
.54485 .51558 m .54609 .51324 L .5475 .51477 L 0 .027 .126 r
F
.54485 .51558 m .54344 .51404 L .54609 .51324 L F
.4629 .51559 m .46402 .51346 L .46551 .51486 L F
.4629 .51559 m .46141 .51419 L .46402 .51346 L F
.67114 .51543 m .67255 .51315 L .67385 .51469 L 0 .026 .126 r
F
.67114 .51543 m .66983 .51392 L .67255 .51315 L F
.38766 .5153 m .38868 .51308 L .39023 .51455 L 0 .026 .125 r
F
.38766 .5153 m .3861 .51384 L .38868 .51308 L F
.42528 .51549 m .42635 .51311 L .42787 .51461 L 0 .026 .126 r
F
.42528 .51549 m .42376 .51398 L .42635 .51311 L F
.35674 .51481 m .35773 .51239 L .3593 .51394 L 0 .025 .124 r
F
.35674 .51481 m .35516 .51325 L .35773 .51239 L F
.62681 .51575 m .62816 .51347 L .6295 .51497 L 0 .027 .127 r
F
.62681 .51575 m .62547 .51423 L .62816 .51347 L F
.58919 .51566 m .59049 .51341 L .59186 .51493 L F
.58919 .51566 m .58781 .51413 L .59049 .51341 L F
.50052 .51604 m .5017 .5137 L .50315 .5153 L 0 .028 .128 r
F
.50052 .51604 m .49907 .51445 L .5017 .5137 L F
.43198 .5153 m .43307 .51294 L .43458 .51451 L 0 .026 .125 r
F
.43198 .5153 m .43047 .51373 L .43307 .51294 L F
.46961 .51549 m .47074 .51325 L .47222 .51465 L 0 .027 .126 r
F
.46961 .51549 m .46812 .51411 L .47074 .51325 L F
.55156 .51552 m .55281 .51325 L .55422 .51478 L F
.55156 .51552 m .55016 .51399 L .55281 .51325 L F
.39435 .51528 m .39538 .5131 L .39693 .51456 L F
.39435 .51528 m .3928 .51383 L .39538 .5131 L F
.36344 .51472 m .36443 .51244 L .366 .514 L 0 .025 .124 r
F
.36344 .51472 m .36187 .51315 L .36443 .51244 L F
.63353 .51566 m .63489 .51328 L .63622 .51483 L 0 .027 .127 r
F
.63353 .51566 m .63219 .51412 L .63489 .51328 L F
.47631 .51529 m .47746 .51297 L .47893 .51445 L 0 .027 .126 r
F
.47631 .51529 m .47484 .51382 L .47746 .51297 L F
.59591 .51564 m .59721 .51325 L .59858 .51477 L 0 .027 .127 r
F
.59591 .51564 m .59454 .51413 L .59721 .51325 L F
.40106 .51511 m .4021 .5128 L .40364 .51424 L 0 .026 .125 r
F
.40106 .51511 m .39951 .51368 L .4021 .5128 L F
.48302 .51513 m .48418 .51273 L .48565 .51426 L F
.48302 .51513 m .48155 .51359 L .48418 .51273 L F
.50723 .51606 m .50842 .51365 L .50986 .5152 L 0 .028 .128 r
F
.50723 .51606 m .50578 .5145 L .50842 .51365 L F
.55828 .5155 m .55954 .51316 L .56094 .51465 L 0 .027 .127 r
F
.55828 .5155 m .55688 .51403 L .55954 .51316 L F
.43868 .51532 m .43978 .51305 L .44128 .51458 L 0 .027 .126 r
F
.43868 .51532 m .43718 .51378 L .43978 .51305 L F
.64025 .51553 m .64162 .51316 L .64295 .51471 L 0 .027 .127 r
F
.64025 .51553 m .63892 .514 L .64162 .51316 L F
.51394 .51573 m .51514 .51357 L .51658 .51494 L 0 .028 .128 r
F
.51394 .51573 m .5125 .51434 L .51514 .51357 L F
.56499 .51519 m .56626 .51292 L .56765 .51434 L 0 .027 .126 r
F
.56499 .51519 m .5636 .51379 L .56626 .51292 L F
.32579 .51482 m .32673 .51255 L .32834 .51397 L 0 .026 .125 r
F
.32579 .51482 m .32418 .51341 L .32673 .51255 L F
.40776 .51487 m .40881 .51268 L .41035 .51413 L F
.40776 .51487 m .40622 .51342 L .40881 .51268 L F
.60262 .51544 m .60394 .51303 L .6053 .51457 L 0 .027 .126 r
F
.60262 .51544 m .60126 .51391 L .60394 .51303 L F
.5717 .51489 m .57298 .51259 L .57437 .51403 L 0 .026 .125 r
F
.5717 .51489 m .57031 .51346 L .57298 .51259 L F
.3325 .51455 m .33345 .51226 L .33505 .5137 L 0 .025 .124 r
F
.3325 .51455 m .33089 .51311 L .33345 .51226 L F
.52065 .51549 m .52186 .51333 L .52329 .51468 L 0 .028 .127 r
F
.52065 .51549 m .51922 .51415 L .52186 .51333 L F
.64696 .51531 m .64835 .51307 L .64967 .51449 L 0 .027 .126 r
F
.64696 .51531 m .64564 .51388 L .64835 .51307 L F
.60934 .5152 m .61066 .51284 L .61202 .51436 L F
.60934 .5152 m .60798 .51369 L .61066 .51284 L F
.33921 .51429 m .34016 .51201 L .34176 .51344 L 0 .025 .124 r
F
.33921 .51429 m .33761 .51286 L .34016 .51201 L F
.37012 .51486 m .37113 .51249 L .37269 .51407 L 0 .026 .125 r
F
.37012 .51486 m .36856 .51329 L .37113 .51249 L F
.48973 .51506 m .49089 .51284 L .49236 .51436 L 0 .027 .126 r
F
.48973 .51506 m .48827 .51354 L .49089 .51284 L F
.65368 .51507 m .65507 .51283 L .65638 .51423 L F
.65368 .51507 m .65237 .51366 L .65507 .51283 L F
.44539 .51527 m .44649 .51298 L .44799 .51448 L F
.44539 .51527 m .44388 .51379 L .44649 .51298 L F
.52736 .51527 m .52858 .51305 L .53001 .51447 L 0 .027 .127 r
F
.52736 .51527 m .52593 .51386 L .52858 .51305 L F
.57842 .51479 m .57971 .51253 L .58109 .51405 L 0 .026 .125 r
F
.57842 .51479 m .57704 .51325 L .57971 .51253 L F
.6604 .51486 m .6618 .51256 L .66311 .51401 L F
.6604 .51486 m .65909 .51339 L .6618 .51256 L F
.34591 .51411 m .34687 .51186 L .34846 .51334 L 0 .025 .123 r
F
.34591 .51411 m .34431 .51264 L .34687 .51186 L F
.41446 .51488 m .41552 .5126 L .41705 .51409 L 0 .026 .126 r
F
.41446 .51488 m .41293 .51339 L .41552 .5126 L F
.53408 .51507 m .5353 .51275 L .53672 .51422 L 0 .027 .126 r
F
.53408 .51507 m .53265 .51362 L .5353 .51275 L F
.61606 .51508 m .6174 .51287 L .61874 .51432 L F
.61606 .51508 m .61471 .51362 L .6174 .51287 L F
.45209 .51516 m .45321 .51283 L .4547 .51431 L F
.45209 .51516 m .4506 .51367 L .45321 .51283 L F
.37682 .51484 m .37783 .51247 L .37939 .51404 L 0 .026 .125 r
F
.37682 .51484 m .37526 .51327 L .37783 .51247 L F
.54079 .51484 m .54202 .51259 L .54344 .51404 L 0 .027 .126 r
F
.54079 .51484 m .53937 .51337 L .54202 .51259 L F
.66712 .51469 m .66853 .5124 L .66983 .51392 L 0 .026 .125 r
F
.66712 .51469 m .66582 .51319 L .66853 .5124 L F
.4588 .51495 m .45992 .5127 L .46141 .51419 L 0 .027 .126 r
F
.4588 .51495 m .45731 .51347 L .45992 .5127 L F
.42117 .51478 m .42223 .51249 L .42376 .51398 L F
.42117 .51478 m .41964 .51329 L .42223 .51249 L F
.62278 .51499 m .62413 .51282 L .62547 .51423 L 0 .027 .127 r
F
.62278 .51499 m .62143 .51356 L .62413 .51282 L F
.49644 .5152 m .49761 .51287 L .49907 .51445 L F
.49644 .5152 m .49498 .51363 L .49761 .51287 L F
.38353 .51466 m .38454 .51238 L .3861 .51384 L 0 .026 .125 r
F
.38353 .51466 m .38197 .51321 L .38454 .51238 L F
.3526 .51411 m .35358 .51169 L .35516 .51325 L 0 .025 .124 r
F
.3526 .51411 m .35102 .51255 L .35358 .51169 L F
.58514 .51486 m .58644 .5126 L .58781 .51413 L 0 .027 .126 r
F
.58514 .51486 m .58376 .51331 L .58644 .5126 L F
.5475 .51477 m .54875 .51247 L .55016 .51399 L F
.5475 .51477 m .54609 .51324 L .54875 .51247 L F
.42787 .51461 m .42895 .51224 L .43047 .51373 L 0 .026 .125 r
F
.42787 .51461 m .42635 .51311 L .42895 .51224 L F
.46551 .51486 m .46664 .51272 L .46812 .51411 L 0 .027 .127 r
F
.46551 .51486 m .46402 .51346 L .46664 .51272 L F
.67385 .51469 m .67527 .51239 L .67657 .51394 L 0 .027 .126 r
F
.67385 .51469 m .67255 .51315 L .67527 .51239 L F
.3593 .51394 m .36029 .51161 L .36187 .51315 L 0 .025 .124 r
F
.3593 .51394 m .35773 .51239 L .36029 .51161 L F
.39023 .51455 m .39125 .51235 L .3928 .51383 L 0 .027 .126 r
F
.39023 .51455 m .38868 .51308 L .39125 .51235 L F
.6295 .51497 m .63085 .5126 L .63219 .51412 L 0 .027 .127 r
F
.6295 .51497 m .62816 .51347 L .63085 .5126 L F
.47222 .51465 m .47336 .51239 L .47484 .51382 L 0 .027 .126 r
F
.47222 .51465 m .47074 .51325 L .47336 .51239 L F
.43458 .51451 m .43567 .51223 L .43718 .51378 L F
.43458 .51451 m .43307 .51294 L .43567 .51223 L F
.59186 .51493 m .59317 .51261 L .59454 .51413 L 0 .027 .127 r
F
.59186 .51493 m .59049 .51341 L .59317 .51261 L F
.50315 .5153 m .50433 .5129 L .50578 .5145 L 0 .028 .128 r
F
.50315 .5153 m .5017 .5137 L .50433 .5129 L F
.55422 .51478 m .55547 .5125 L .55688 .51403 L 0 .027 .127 r
F
.55422 .51478 m .55281 .51325 L .55547 .5125 L F
.47893 .51445 m .48008 .51211 L .48155 .51359 L 0 .026 .126 r
F
.47893 .51445 m .47746 .51297 L .48008 .51211 L F
.63622 .51483 m .63758 .51242 L .63892 .514 L 0 .027 .127 r
F
.63622 .51483 m .63489 .51328 L .63758 .51242 L F
.39693 .51456 m .39797 .51221 L .39951 .51368 L 0 .027 .126 r
F
.39693 .51456 m .39538 .5131 L .39797 .51221 L F
.366 .514 m .36699 .51172 L .36856 .51329 L 0 .026 .125 r
F
.366 .514 m .36443 .51244 L .36699 .51172 L F
.59858 .51477 m .59989 .51237 L .60126 .51391 L 0 .027 .127 r
F
.59858 .51477 m .59721 .51325 L .59989 .51237 L F
.40364 .51424 m .40468 .51198 L .40622 .51342 L 0 .026 .125 r
F
.40364 .51424 m .4021 .5128 L .40468 .51198 L F
.48565 .51426 m .4868 .51202 L .48827 .51354 L F
.48565 .51426 m .48418 .51273 L .4868 .51202 L F
.50986 .5152 m .51105 .51281 L .5125 .51434 L 0 .028 .128 r
F
.50986 .5152 m .50842 .51365 L .51105 .51281 L F
.56094 .51465 m .5622 .51229 L .5636 .51379 L 0 .027 .126 r
F
.56094 .51465 m .55954 .51316 L .5622 .51229 L F
.64295 .51471 m .64432 .51231 L .64564 .51388 L 0 .027 .127 r
F
.64295 .51471 m .64162 .51316 L .64432 .51231 L F
.32834 .51397 m .32928 .51168 L .33089 .51311 L 0 .026 .125 r
F
.32834 .51397 m .32673 .51255 L .32928 .51168 L F
.56765 .51434 m .56892 .51203 L .57031 .51346 L 0 .027 .126 r
F
.56765 .51434 m .56626 .51292 L .56892 .51203 L F
.51658 .51494 m .51778 .5128 L .51922 .51415 L 0 .028 .128 r
F
.51658 .51494 m .51514 .51357 L .51778 .5128 L F
.6053 .51457 m .60662 .51214 L .60798 .51369 L 0 .027 .126 r
F
.6053 .51457 m .60394 .51303 L .60662 .51214 L F
.44128 .51458 m .44238 .51225 L .44388 .51379 L F
.44128 .51458 m .43978 .51305 L .44238 .51225 L F
.57437 .51403 m .57565 .51181 L .57704 .51325 L 0 .026 .125 r
F
.57437 .51403 m .57298 .51259 L .57565 .51181 L F
.33505 .5137 m .336 .51142 L .33761 .51286 L 0 .025 .124 r
F
.33505 .5137 m .33345 .51226 L .336 .51142 L F
.64967 .51449 m .65105 .51225 L .65237 .51366 L 0 .027 .126 r
F
.64967 .51449 m .64835 .51307 L .65105 .51225 L F
.52329 .51468 m .5245 .51249 L .52593 .51386 L 0 .028 .127 r
F
.52329 .51468 m .52186 .51333 L .5245 .51249 L F
.41035 .51413 m .4114 .51193 L .41293 .51339 L 0 .026 .126 r
F
.41035 .51413 m .40881 .51268 L .4114 .51193 L F
.61202 .51436 m .61335 .51211 L .61471 .51362 L 0 .027 .126 r
F
.61202 .51436 m .61066 .51284 L .61335 .51211 L F
.34176 .51344 m .34272 .51121 L .34431 .51264 L 0 .025 .124 r
F
.34176 .51344 m .34016 .51201 L .34272 .51121 L F
.65638 .51423 m .65778 .51202 L .65909 .51339 L 0 .027 .126 r
F
.65638 .51423 m .65507 .51283 L .65778 .51202 L F
.37269 .51407 m .3737 .51168 L .37526 .51327 L 0 .026 .125 r
F
.37269 .51407 m .37113 .51249 L .3737 .51168 L F
.53001 .51447 m .53123 .51218 L .53265 .51362 L 0 .027 .127 r
F
.53001 .51447 m .52858 .51305 L .53123 .51218 L F
.44799 .51448 m .4491 .51217 L .4506 .51367 L F
.44799 .51448 m .44649 .51298 L .4491 .51217 L F
.49236 .51436 m .49352 .51213 L .49498 .51363 L 0 .027 .126 r
F
.49236 .51436 m .49089 .51284 L .49352 .51213 L F
.66311 .51401 m .66451 .51174 L .66582 .51319 L 0 .026 .125 r
F
.66311 .51401 m .6618 .51256 L .66451 .51174 L F
.53672 .51422 m .53795 .5119 L .53937 .51337 L 0 .027 .126 r
F
.53672 .51422 m .5353 .51275 L .53795 .5119 L F
.58109 .51405 m .58238 .5118 L .58376 .51331 L F
.58109 .51405 m .57971 .51253 L .58238 .5118 L F
.34846 .51334 m .34943 .51106 L .35102 .51255 L 0 .025 .124 r
F
.34846 .51334 m .34687 .51186 L .34943 .51106 L F
.41705 .51409 m .41811 .5118 L .41964 .51329 L 0 .027 .126 r
F
.41705 .51409 m .41552 .5126 L .41811 .5118 L F
.4547 .51431 m .45582 .51198 L .45731 .51347 L F
.4547 .51431 m .45321 .51283 L .45582 .51198 L F
.61874 .51432 m .62009 .51214 L .62143 .51356 L 0 .027 .127 r
F
.61874 .51432 m .6174 .51287 L .62009 .51214 L F
.37939 .51404 m .38041 .51166 L .38197 .51321 L 0 .026 .126 r
F
.37939 .51404 m .37783 .51247 L .38041 .51166 L F
.54344 .51404 m .54468 .51181 L .54609 .51324 L 0 .027 .126 r
F
.54344 .51404 m .54202 .51259 L .54468 .51181 L F
.66983 .51392 m .67125 .51162 L .67255 .51315 L 0 .026 .126 r
F
.66983 .51392 m .66853 .5124 L .67125 .51162 L F
.42376 .51398 m .42483 .51163 L .42635 .51311 L 0 .027 .126 r
F
.42376 .51398 m .42223 .51249 L .42483 .51163 L F
.35516 .51325 m .35615 .51084 L .35773 .51239 L 0 .025 .123 r
F
.35516 .51325 m .35358 .51169 L .35615 .51084 L F
.46141 .51419 m .46254 .51196 L .46402 .51346 L 0 .027 .127 r
F
.46141 .51419 m .45992 .5127 L .46254 .51196 L F
.3861 .51384 m .38712 .51161 L .38868 .51308 L 0 .026 .126 r
F
.3861 .51384 m .38454 .51238 L .38712 .51161 L F
.62547 .51423 m .62682 .51207 L .62816 .51347 L 0 .027 .127 r
F
.62547 .51423 m .62413 .51282 L .62682 .51207 L F
.49907 .51445 m .50024 .51211 L .5017 .5137 L 0 .028 .127 r
F
.49907 .51445 m .49761 .51287 L .50024 .51211 L F
.43047 .51373 m .43155 .51146 L .43307 .51294 L 0 .026 .125 r
F
.43047 .51373 m .42895 .51224 L .43155 .51146 L F
.58781 .51413 m .58911 .51189 L .59049 .51341 L 0 .027 .127 r
F
.58781 .51413 m .58644 .5126 L .58911 .51189 L F
.55016 .51399 m .5514 .51172 L .55281 .51325 L 0 .027 .126 r
F
.55016 .51399 m .54875 .51247 L .5514 .51172 L F
.36187 .51315 m .36285 .5109 L .36443 .51244 L 0 .025 .124 r
F
.36187 .51315 m .36029 .51161 L .36285 .5109 L F
.46812 .51411 m .46926 .51184 L .47074 .51325 L 0 .027 .127 r
F
.46812 .51411 m .46664 .51272 L .46926 .51184 L F
.63219 .51412 m .63355 .51173 L .63489 .51328 L 0 .027 .126 r
F
.63219 .51412 m .63085 .5126 L .63355 .51173 L F
.67657 .51394 m .67799 .51163 L .67929 .5132 L F
.67657 .51394 m .67527 .51239 L .67799 .51163 L F
.47484 .51382 m .47598 .51154 L .47746 .51297 L F
.47484 .51382 m .47336 .51239 L .47598 .51154 L F
.3928 .51383 m .39383 .51161 L .39538 .5131 L F
.3928 .51383 m .39125 .51235 L .39383 .51161 L F
.50578 .5145 m .50697 .51207 L .50842 .51365 L 0 .028 .128 r
F
.50578 .5145 m .50433 .5129 L .50697 .51207 L F
.59454 .51413 m .59584 .51173 L .59721 .51325 L 0 .027 .127 r
F
.59454 .51413 m .59317 .51261 L .59584 .51173 L F
.43718 .51378 m .43827 .51151 L .43978 .51305 L 0 .027 .126 r
F
.43718 .51378 m .43567 .51223 L .43827 .51151 L F
.48155 .51359 m .48271 .51126 L .48418 .51273 L 0 .026 .125 r
F
.48155 .51359 m .48008 .51211 L .48271 .51126 L F
.63892 .514 m .64028 .51156 L .64162 .51316 L 0 .027 .126 r
F
.63892 .514 m .63758 .51242 L .64028 .51156 L F
.55688 .51403 m .55813 .51162 L .55954 .51316 L 0 .027 .127 r
F
.55688 .51403 m .55547 .5125 L .55813 .51162 L F
.39951 .51368 m .40055 .51132 L .4021 .5128 L 0 .027 .126 r
F
.39951 .51368 m .39797 .51221 L .40055 .51132 L F
.60126 .51391 m .60257 .51148 L .60394 .51303 L F
.60126 .51391 m .59989 .51237 L .60257 .51148 L F
.5125 .51434 m .51369 .51205 L .51514 .51357 L 0 .028 .128 r
F
.5125 .51434 m .51105 .51281 L .51369 .51205 L F
.32418 .51341 m .32512 .51113 L .32673 .51255 L 0 .026 .125 r
F
.32418 .51341 m .32256 .512 L .32512 .51113 L F
.5636 .51379 m .56486 .51141 L .56626 .51292 L 0 .027 .126 r
F
.5636 .51379 m .5622 .51229 L .56486 .51141 L F
.40622 .51342 m .40727 .51123 L .40881 .51268 L 0 .026 .125 r
F
.40622 .51342 m .40468 .51198 L .40727 .51123 L F
.57031 .51346 m .57159 .51114 L .57298 .51259 L F
.57031 .51346 m .56892 .51203 L .57159 .51114 L F
.36856 .51329 m .36956 .51092 L .37113 .51249 L F
.36856 .51329 m .36699 .51172 L .36956 .51092 L F
.33089 .51311 m .33184 .51082 L .33345 .51226 L 0 .026 .124 r
F
.33089 .51311 m .32928 .51168 L .33184 .51082 L F
.60798 .51369 m .60931 .51129 L .61066 .51284 L 0 .027 .126 r
F
.60798 .51369 m .60662 .51214 L .60931 .51129 L F
.64564 .51388 m .64702 .5115 L .64835 .51307 L 0 .027 .127 r
F
.64564 .51388 m .64432 .51231 L .64702 .5115 L F
.48827 .51354 m .48943 .51133 L .49089 .51284 L 0 .027 .126 r
F
.48827 .51354 m .4868 .51202 L .48943 .51133 L F
.51922 .51415 m .52042 .51199 L .52186 .51333 L 0 .028 .128 r
F
.51922 .51415 m .51778 .5128 L .52042 .51199 L F
.44388 .51379 m .44499 .51144 L .44649 .51298 L 0 .027 .126 r
F
.44388 .51379 m .44238 .51225 L .44499 .51144 L F
.33761 .51286 m .33856 .51058 L .34016 .51201 L 0 .025 .124 r
F
.33761 .51286 m .336 .51142 L .33856 .51058 L F
.57704 .51325 m .57832 .51108 L .57971 .51253 L 0 .026 .125 r
F
.57704 .51325 m .57565 .51181 L .57832 .51108 L F
.65237 .51366 m .65376 .51144 L .65507 .51283 L 0 .027 .126 r
F
.65237 .51366 m .65105 .51225 L .65376 .51144 L F
.52593 .51386 m .52715 .51165 L .52858 .51305 L 0 .028 .127 r
F
.52593 .51386 m .5245 .51249 L .52715 .51165 L F
.34431 .51264 m .34527 .51042 L .34687 .51186 L 0 .025 .124 r
F
.34431 .51264 m .34272 .51121 L .34527 .51042 L F
.41293 .51339 m .41399 .51113 L .41552 .5126 L 0 .027 .126 r
F
.41293 .51339 m .4114 .51193 L .41399 .51113 L F
.65909 .51339 m .66049 .5112 L .6618 .51256 L F
.65909 .51339 m .65778 .51202 L .66049 .5112 L F
.53265 .51362 m .53388 .5113 L .5353 .51275 L F
.53265 .51362 m .53123 .51218 L .53388 .5113 L F
.61471 .51362 m .61604 .51137 L .6174 .51287 L F
.61471 .51362 m .61335 .51211 L .61604 .51137 L F
.37526 .51327 m .37627 .51088 L .37783 .51247 L 0 .026 .125 r
F
.37526 .51327 m .3737 .51168 L .37627 .51088 L F
.4506 .51367 m .45171 .51133 L .45321 .51283 L 0 .027 .127 r
F
.4506 .51367 m .4491 .51217 L .45171 .51133 L F
.53937 .51337 m .5406 .51114 L .54202 .51259 L 0 .027 .126 r
F
.53937 .51337 m .53795 .5119 L .5406 .51114 L F
.66582 .51319 m .66723 .51094 L .66853 .5124 L 0 .026 .125 r
F
.66582 .51319 m .66451 .51174 L .66723 .51094 L F
.49498 .51363 m .49615 .51136 L .49761 .51287 L 0 .027 .127 r
F
.49498 .51363 m .49352 .51213 L .49615 .51136 L F
.45731 .51347 m .45843 .5112 L .45992 .5127 L 0 .027 .126 r
F
.45731 .51347 m .45582 .51198 L .45843 .5112 L F
.35102 .51255 m .35199 .5102 L .35358 .51169 L 0 .025 .124 r
F
.35102 .51255 m .34943 .51106 L .35199 .5102 L F
.41964 .51329 m .42071 .51099 L .42223 .51249 L 0 .027 .126 r
F
.41964 .51329 m .41811 .5118 L .42071 .51099 L F
.58376 .51331 m .58506 .51109 L .58644 .5126 L F
.58376 .51331 m .58238 .5118 L .58506 .51109 L F
.62143 .51356 m .62278 .51141 L .62413 .51282 L 0 .028 .127 r
F
.62143 .51356 m .62009 .51214 L .62278 .51141 L F
.38197 .51321 m .38298 .51085 L .38454 .51238 L 0 .026 .126 r
F
.38197 .51321 m .38041 .51166 L .38298 .51085 L F
.54609 .51324 m .54733 .51106 L .54875 .51247 L 0 .027 .126 r
F
.54609 .51324 m .54468 .51181 L .54733 .51106 L F
.42635 .51311 m .42743 .51078 L .42895 .51224 L 0 .026 .125 r
F
.42635 .51311 m .42483 .51163 L .42743 .51078 L F
.35773 .51239 m .35871 .51007 L .36029 .51161 L 0 .025 .123 r
F
.35773 .51239 m .35615 .51084 L .35871 .51007 L F
.67255 .51315 m .67397 .51083 L .67527 .51239 L 0 .027 .126 r
F
.67255 .51315 m .67125 .51162 L .67397 .51083 L F
.38868 .51308 m .3897 .51087 L .39125 .51235 L F
.38868 .51308 m .38712 .51161 L .3897 .51087 L F
.46402 .51346 m .46515 .5112 L .46664 .51272 L 0 .027 .127 r
F
.46402 .51346 m .46254 .51196 L .46515 .5112 L F
.62816 .51347 m .62952 .5112 L .63085 .5126 L F
.62816 .51347 m .62682 .51207 L .62952 .5112 L F
.43307 .51294 m .43415 .51076 L .43567 .51223 L 0 .026 .126 r
F
.43307 .51294 m .43155 .51146 L .43415 .51076 L F
.5017 .5137 m .50288 .51132 L .50433 .5129 L 0 .028 .127 r
F
.5017 .5137 m .50024 .51211 L .50288 .51132 L F
.59049 .51341 m .59179 .51109 L .59317 .51261 L 0 .027 .127 r
F
.59049 .51341 m .58911 .51189 L .59179 .51109 L F
.55281 .51325 m .55407 .51097 L .55547 .5125 L 0 .027 .126 r
F
.55281 .51325 m .5514 .51172 L .55407 .51097 L F
.47074 .51325 m .47188 .51097 L .47336 .51239 L F
.47074 .51325 m .46926 .51184 L .47188 .51097 L F
.63489 .51328 m .63625 .51086 L .63758 .51242 L F
.63489 .51328 m .63355 .51173 L .63625 .51086 L F
.47746 .51297 m .47861 .51068 L .48008 .51211 L F
.47746 .51297 m .47598 .51154 L .47861 .51068 L F
.36443 .51244 m .36542 .51019 L .36699 .51172 L 0 .026 .124 r
F
.36443 .51244 m .36285 .5109 L .36542 .51019 L F
.67929 .5132 m .68071 .51083 L .68201 .51241 L 0 .027 .126 r
F
.67929 .5132 m .67799 .51163 L .68071 .51083 L F
.59721 .51325 m .59853 .51084 L .59989 .51237 L F
.59721 .51325 m .59584 .51173 L .59853 .51084 L F
.50842 .51365 m .50961 .51124 L .51105 .51281 L 0 .028 .128 r
F
.50842 .51365 m .50697 .51207 L .50961 .51124 L F
.39538 .5131 m .39642 .5107 L .39797 .51221 L 0 .027 .126 r
F
.39538 .5131 m .39383 .51161 L .39642 .5107 L F
.48418 .51273 m .48533 .51054 L .4868 .51202 L 0 .026 .126 r
F
.48418 .51273 m .48271 .51126 L .48533 .51054 L F
.64162 .51316 m .64299 .5107 L .64432 .51231 L 0 .027 .126 r
F
.64162 .51316 m .64028 .51156 L .64299 .5107 L F
.55954 .51316 m .5608 .51074 L .5622 .51229 L F
.55954 .51316 m .55813 .51162 L .5608 .51074 L F
.4021 .5128 m .40314 .51049 L .40468 .51198 L 0 .026 .126 r
F
.4021 .5128 m .40055 .51132 L .40314 .51049 L F
.60394 .51303 m .60526 .51059 L .60662 .51214 L 0 .027 .126 r
F
.60394 .51303 m .60257 .51148 L .60526 .51059 L F
.43978 .51305 m .44087 .51071 L .44238 .51225 L F
.43978 .51305 m .43827 .51151 L .44087 .51071 L F
.56626 .51292 m .56753 .51052 L .56892 .51203 L F
.56626 .51292 m .56486 .51141 L .56753 .51052 L F
.32673 .51255 m .32767 .51025 L .32928 .51168 L 0 .026 .125 r
F
.32673 .51255 m .32512 .51113 L .32767 .51025 L F
.57298 .51259 m .57426 .51036 L .57565 .51181 L F
.57298 .51259 m .57159 .51114 L .57426 .51036 L F
.33345 .51226 m .33439 .50999 L .336 .51142 L 0 .026 .124 r
F
.33345 .51226 m .33184 .51082 L .33439 .50999 L F
.51514 .51357 m .51634 .51129 L .51778 .5128 L 0 .028 .128 r
F
.51514 .51357 m .51369 .51205 L .51634 .51129 L F
.61066 .51284 m .612 .51056 L .61335 .51211 L 0 .027 .126 r
F
.61066 .51284 m .60931 .51129 L .612 .51056 L F
.37113 .51249 m .37213 .5101 L .3737 .51168 L 0 .026 .125 r
F
.37113 .51249 m .36956 .51092 L .37213 .5101 L F
.40881 .51268 m .40986 .51047 L .4114 .51193 L 0 .027 .126 r
F
.40881 .51268 m .40727 .51123 L .40986 .51047 L F
.64835 .51307 m .64973 .51071 L .65105 .51225 L 0 .027 .127 r
F
.64835 .51307 m .64702 .5115 L .64973 .51071 L F
.34016 .51201 m .34112 .50978 L .34272 .51121 L 0 .025 .124 r
F
.34016 .51201 m .33856 .51058 L .34112 .50978 L F
.52186 .51333 m .52307 .51112 L .5245 .51249 L 0 .028 .128 r
F
.52186 .51333 m .52042 .51199 L .52307 .51112 L F
.44649 .51298 m .4476 .51063 L .4491 .51217 L 0 .027 .127 r
F
.44649 .51298 m .44499 .51144 L .4476 .51063 L F
.65507 .51283 m .65647 .51064 L .65778 .51202 L 0 .027 .126 r
F
.65507 .51283 m .65376 .51144 L .65647 .51064 L F
.49089 .51284 m .49206 .51062 L .49352 .51213 L F
.49089 .51284 m .48943 .51133 L .49206 .51062 L F
.52858 .51305 m .5298 .51077 L .53123 .51218 L 0 .028 .127 r
F
.52858 .51305 m .52715 .51165 L .5298 .51077 L F
.57971 .51253 m .581 .51035 L .58238 .5118 L 0 .027 .126 r
F
.57971 .51253 m .57832 .51108 L .581 .51035 L F
.5353 .51275 m .53653 .51043 L .53795 .5119 L F
.5353 .51275 m .53388 .5113 L .53653 .51043 L F
.6618 .51256 m .66321 .51038 L .66451 .51174 L F
.6618 .51256 m .66049 .5112 L .66321 .51038 L F
.41552 .5126 m .41658 .5103 L .41811 .5118 L F
.41552 .5126 m .41399 .51113 L .41658 .5103 L F
.34687 .51186 m .34784 .50962 L .34943 .51106 L 0 .025 .124 r
F
.34687 .51186 m .34527 .51042 L .34784 .50962 L F
.45321 .51283 m .45432 .51049 L .45582 .51198 L 0 .027 .126 r
F
.45321 .51283 m .45171 .51133 L .45432 .51049 L F
.37783 .51247 m .37885 .51009 L .38041 .51166 L 0 .026 .125 r
F
.37783 .51247 m .37627 .51088 L .37885 .51009 L F
.6174 .51287 m .61874 .51064 L .62009 .51214 L 0 .027 .127 r
F
.6174 .51287 m .61604 .51137 L .61874 .51064 L F
.66853 .5124 m .66994 .51014 L .67125 .51162 L 0 .026 .126 r
F
.66853 .5124 m .66723 .51094 L .66994 .51014 L F
.54202 .51259 m .54326 .51038 L .54468 .51181 L 0 .027 .126 r
F
.54202 .51259 m .5406 .51114 L .54326 .51038 L F
.35358 .51169 m .35456 .50934 L .35615 .51084 L 0 .025 .123 r
F
.35358 .51169 m .35199 .5102 L .35456 .50934 L F
.42223 .51249 m .42331 .51015 L .42483 .51163 L 0 .027 .126 r
F
.42223 .51249 m .42071 .51099 L .42331 .51015 L F
.49761 .51287 m .49879 .51059 L .50024 .51211 L 0 .028 .127 r
F
.49761 .51287 m .49615 .51136 L .49879 .51059 L F
.45992 .5127 m .46105 .51045 L .46254 .51196 L 0 .027 .127 r
F
.45992 .5127 m .45843 .5112 L .46105 .51045 L F
.38454 .51238 m .38556 .51009 L .38712 .51161 L 0 .027 .126 r
F
.38454 .51238 m .38298 .51085 L .38556 .51009 L F
.58644 .5126 m .58774 .51038 L .58911 .51189 L 0 .027 .127 r
F
.58644 .5126 m .58506 .51109 L .58774 .51038 L F
.42895 .51224 m .43003 .51001 L .43155 .51146 L 0 .026 .125 r
F
.42895 .51224 m .42743 .51078 L .43003 .51001 L F
.62413 .51282 m .62548 .51068 L .62682 .51207 L 0 .028 .127 r
F
.62413 .51282 m .62278 .51141 L .62548 .51068 L F
.54875 .51247 m .54999 .51032 L .5514 .51172 L 0 .027 .126 r
F
.54875 .51247 m .54733 .51106 L .54999 .51032 L F
.36029 .51161 m .36127 .50936 L .36285 .5109 L 0 .025 .124 r
F
.36029 .51161 m .35871 .51007 L .36127 .50936 L F
.67527 .51239 m .67669 .51005 L .67799 .51163 L 0 .027 .126 r
F
.67527 .51239 m .67397 .51083 L .67669 .51005 L F
.63085 .5126 m .63222 .51031 L .63355 .51173 L 0 .027 .127 r
F
.63085 .5126 m .62952 .5112 L .63222 .51031 L F
.50433 .5129 m .50552 .5105 L .50697 .51207 L 0 .028 .127 r
F
.50433 .5129 m .50288 .51132 L .50552 .5105 L F
.46664 .51272 m .46777 .51032 L .46926 .51184 L F
.46664 .51272 m .46515 .5112 L .46777 .51032 L F
.39125 .51235 m .39228 .51011 L .39383 .51161 L 0 .027 .126 r
F
.39125 .51235 m .3897 .51087 L .39228 .51011 L F
.47336 .51239 m .4745 .5101 L .47598 .51154 L F
.47336 .51239 m .47188 .51097 L .4745 .5101 L F
.43567 .51223 m .43675 .51005 L .43827 .51151 L F
.43567 .51223 m .43415 .51076 L .43675 .51005 L F
.63758 .51242 m .63895 .50998 L .64028 .51156 L F
.63758 .51242 m .63625 .51086 L .63895 .50998 L F
.59317 .51261 m .59447 .5102 L .59584 .51173 L 0 .027 .127 r
F
.59317 .51261 m .59179 .51109 L .59447 .5102 L F
.48008 .51211 m .48123 .50982 L .48271 .51126 L 0 .027 .126 r
F
.48008 .51211 m .47861 .51068 L .48123 .50982 L F
.55547 .5125 m .55673 .51009 L .55813 .51162 L F
.55547 .5125 m .55407 .51097 L .55673 .51009 L F
.59989 .51237 m .60121 .50996 L .60257 .51148 L F
.59989 .51237 m .59853 .51084 L .60121 .50996 L F
.39797 .51221 m .39901 .5098 L .40055 .51132 L F
.39797 .51221 m .39642 .5107 L .39901 .5098 L F
.68201 .51241 m .68343 .50995 L .68473 .51152 L F
.68201 .51241 m .68071 .51083 L .68343 .50995 L F
.51105 .51281 m .51225 .51049 L .51369 .51205 L 0 .028 .128 r
F
.51105 .51281 m .50961 .51124 L .51225 .51049 L F
.36699 .51172 m .36799 .50939 L .36956 .51092 L 0 .026 .125 r
F
.36699 .51172 m .36542 .51019 L .36799 .50939 L F
.5622 .51229 m .56346 .50985 L .56486 .51141 L 0 .027 .126 r
F
.5622 .51229 m .5608 .51074 L .56346 .50985 L F
.64432 .51231 m .64569 .50989 L .64702 .5115 L F
.64432 .51231 m .64299 .5107 L .64569 .50989 L F
.60662 .51214 m .60794 .50973 L .60931 .51129 L F
.60662 .51214 m .60526 .51059 L .60794 .50973 L F
.40468 .51198 m .40573 .50973 L .40727 .51123 L F
.40468 .51198 m .40314 .51049 L .40573 .50973 L F
.32256 .512 m .3235 .50965 L .32512 .51113 L 0 .026 .126 r
F
.32256 .512 m .32095 .51053 L .3235 .50965 L F
.4868 .51202 m .48796 .50984 L .48943 .51133 L 0 .027 .126 r
F
.4868 .51202 m .48533 .51054 L .48796 .50984 L F
.56892 .51203 m .5702 .50963 L .57159 .51114 L 0 .026 .126 r
F
.56892 .51203 m .56753 .51052 L .5702 .50963 L F
.32928 .51168 m .33023 .50939 L .33184 .51082 L 0 .026 .125 r
F
.32928 .51168 m .32767 .51025 L .33023 .50939 L F
.44238 .51225 m .44348 .5099 L .44499 .51144 L 0 .027 .126 r
F
.44238 .51225 m .44087 .51071 L .44348 .5099 L F
.336 .51142 m .33695 .50915 L .33856 .51058 L 0 .026 .124 r
F
.336 .51142 m .33439 .50999 L .33695 .50915 L F
.57565 .51181 m .57694 .50964 L .57832 .51108 L 0 .027 .126 r
F
.57565 .51181 m .57426 .51036 L .57694 .50964 L F
.3737 .51168 m .37471 .5093 L .37627 .51088 L 0 .026 .125 r
F
.3737 .51168 m .37213 .5101 L .37471 .5093 L F
.51778 .5128 m .51898 .51049 L .52042 .51199 L 0 .029 .128 r
F
.51778 .5128 m .51634 .51129 L .51898 .51049 L F
.65105 .51225 m .65244 .50991 L .65376 .51144 L 0 .027 .127 r
F
.65105 .51225 m .64973 .51071 L .65244 .50991 L F
.61335 .51211 m .61469 .50982 L .61604 .51137 L 0 .027 .126 r
F
.61335 .51211 m .612 .51056 L .61469 .50982 L F
.4114 .51193 m .41245 .50965 L .41399 .51113 L F
.4114 .51193 m .40986 .51047 L .41245 .50965 L F
.5245 .51249 m .52571 .51026 L .52715 .51165 L 0 .028 .128 r
F
.5245 .51249 m .52307 .51112 L .52571 .51026 L F
.34272 .51121 m .34368 .50898 L .34527 .51042 L 0 .025 .124 r
F
.34272 .51121 m .34112 .50978 L .34368 .50898 L F
.4491 .51217 m .45021 .50982 L .45171 .51133 L 0 .027 .127 r
F
.4491 .51217 m .4476 .51063 L .45021 .50982 L F
.53123 .51218 m .53245 .50987 L .53388 .5113 L F
.53123 .51218 m .5298 .51077 L .53245 .50987 L F
.65778 .51202 m .65919 .50984 L .66049 .5112 L F
.65778 .51202 m .65647 .51064 L .65919 .50984 L F
.53795 .5119 m .53918 .50969 L .5406 .51114 L 0 .027 .126 r
F
.53795 .5119 m .53653 .51043 L .53918 .50969 L F
.66451 .51174 m .66592 .50956 L .66723 .51094 L F
.66451 .51174 m .66321 .51038 L .66592 .50956 L F
.49352 .51213 m .49469 .50984 L .49615 .51136 L 0 .027 .127 r
F
.49352 .51213 m .49206 .51062 L .49469 .50984 L F
.45582 .51198 m .45694 .50971 L .45843 .5112 L 0 .027 .126 r
F
.45582 .51198 m .45432 .51049 L .45694 .50971 L F
.58238 .5118 m .58368 .50963 L .58506 .51109 L F
.58238 .5118 m .581 .51035 L .58368 .50963 L F
.41811 .5118 m .41918 .50948 L .42071 .51099 L F
.41811 .5118 m .41658 .5103 L .41918 .50948 L F
.34943 .51106 m .3504 .50875 L .35199 .5102 L 0 .025 .124 r
F
.34943 .51106 m .34784 .50962 L .3504 .50875 L F
.38041 .51166 m .38142 .50931 L .38298 .51085 L 0 .026 .125 r
F
.38041 .51166 m .37885 .51009 L .38142 .50931 L F
.62009 .51214 m .62144 .50992 L .62278 .51141 L 0 .028 .127 r
F
.62009 .51214 m .61874 .51064 L .62144 .50992 L F
.35615 .51084 m .35713 .50856 L .35871 .51007 L 0 .025 .123 r
F
.35615 .51084 m .35456 .50934 L .35713 .50856 L F
.67125 .51162 m .67266 .50933 L .67397 .51083 L 0 .027 .126 r
F
.67125 .51162 m .66994 .51014 L .67266 .50933 L F
.54468 .51181 m .54592 .50964 L .54733 .51106 L F
.54468 .51181 m .54326 .51038 L .54592 .50964 L F
.42483 .51163 m .42591 .50931 L .42743 .51078 L F
.42483 .51163 m .42331 .51015 L .42591 .50931 L F
.50024 .51211 m .50142 .50981 L .50288 .51132 L 0 .028 .127 r
F
.50024 .51211 m .49879 .51059 L .50142 .50981 L F
.46254 .51196 m .46366 .50968 L .46515 .5112 L F
.46254 .51196 m .46105 .51045 L .46366 .50968 L F
.38712 .51161 m .38814 .50935 L .3897 .51087 L 0 .027 .126 r
F
.38712 .51161 m .38556 .51009 L .38814 .50935 L F
.43155 .51146 m .43263 .50931 L .43415 .51076 L F
.43155 .51146 m .43003 .51001 L .43263 .50931 L F
.58911 .51189 m .59042 .50959 L .59179 .51109 L 0 .027 .127 r
F
.58911 .51189 m .58774 .51038 L .59042 .50959 L F
.62682 .51207 m .62818 .50979 L .62952 .5112 L 0 .028 .127 r
F
.62682 .51207 m .62548 .51068 L .62818 .50979 L F
.5514 .51172 m .55266 .50958 L .55407 .51097 L 0 .027 .127 r
F
.5514 .51172 m .54999 .51032 L .55266 .50958 L F
.63355 .51173 m .63492 .50943 L .63625 .51086 L 0 .027 .126 r
F
.63355 .51173 m .63222 .51031 L .63492 .50943 L F
.67799 .51163 m .67941 .50924 L .68071 .51083 L F
.67799 .51163 m .67669 .51005 L .67941 .50924 L F
.36285 .5109 m .36384 .50866 L .36542 .51019 L 0 .026 .124 r
F
.36285 .5109 m .36127 .50936 L .36384 .50866 L F
.46926 .51184 m .4704 .50943 L .47188 .51097 L 0 .027 .127 r
F
.46926 .51184 m .46777 .51032 L .4704 .50943 L F
.50697 .51207 m .50816 .50969 L .50961 .51124 L 0 .028 .127 r
F
.50697 .51207 m .50552 .5105 L .50816 .50969 L F
.47598 .51154 m .47713 .50924 L .47861 .51068 L 0 .027 .126 r
F
.47598 .51154 m .4745 .5101 L .47713 .50924 L F
.59584 .51173 m .59715 .50931 L .59853 .51084 L F
.59584 .51173 m .59447 .5102 L .59715 .50931 L F
.64028 .51156 m .64165 .5091 L .64299 .5107 L F
.64028 .51156 m .63895 .50998 L .64165 .5091 L F
.39383 .51161 m .39487 .50919 L .39642 .5107 L F
.39383 .51161 m .39228 .51011 L .39487 .50919 L F
.55813 .51162 m .55939 .50919 L .5608 .51074 L F
.55813 .51162 m .55673 .51009 L .55939 .50919 L F
.48271 .51126 m .48386 .50908 L .48533 .51054 L F
.48271 .51126 m .48123 .50982 L .48386 .50908 L F
.60257 .51148 m .60389 .50907 L .60526 .51059 L F
.60257 .51148 m .60121 .50996 L .60389 .50907 L F
.43827 .51151 m .43936 .50923 L .44087 .51071 L F
.43827 .51151 m .43675 .51005 L .43936 .50923 L F
.40055 .51132 m .4016 .50896 L .40314 .51049 L F
.40055 .51132 m .39901 .5098 L .4016 .50896 L F
.68473 .51152 m .68616 .50906 L .68745 .51062 L F
.68473 .51152 m .68343 .50995 L .68616 .50906 L F
.56486 .51141 m .56613 .50896 L .56753 .51052 L F
.56486 .51141 m .56346 .50985 L .56613 .50896 L F
.60931 .51129 m .61064 .509 L .612 .51056 L F
.60931 .51129 m .60794 .50973 L .61064 .509 L F
.36956 .51092 m .37056 .50858 L .37213 .5101 L 0 .026 .125 r
F
.36956 .51092 m .36799 .50939 L .37056 .50858 L F
.51369 .51205 m .51489 .50975 L .51634 .51129 L 0 .028 .128 r
F
.51369 .51205 m .51225 .51049 L .51489 .50975 L F
.32512 .51113 m .32606 .50877 L .32767 .51025 L 0 .026 .125 r
F
.32512 .51113 m .3235 .50965 L .32606 .50877 L F
.64702 .5115 m .6484 .50911 L .64973 .51071 L 0 .027 .126 r
F
.64702 .5115 m .64569 .50989 L .6484 .50911 L F
.57159 .51114 m .57287 .50884 L .57426 .51036 L 0 .026 .126 r
F
.57159 .51114 m .5702 .50963 L .57287 .50884 L F
.33184 .51082 m .33278 .50855 L .33439 .50999 L 0 .026 .125 r
F
.33184 .51082 m .33023 .50939 L .33278 .50855 L F
.40727 .51123 m .40832 .50897 L .40986 .51047 L 0 .027 .126 r
F
.40727 .51123 m .40573 .50973 L .40832 .50897 L F
.44499 .51144 m .44609 .5091 L .4476 .51063 L F
.44499 .51144 m .44348 .5099 L .44609 .5091 L F
.48943 .51133 m .49059 .50911 L .49206 .51062 L 0 .027 .127 r
F
.48943 .51133 m .48796 .50984 L .49059 .50911 L F
.33856 .51058 m .33951 .50833 L .34112 .50978 L 0 .026 .124 r
F
.33856 .51058 m .33695 .50915 L .33951 .50833 L F
.52042 .51199 m .52163 .50962 L .52307 .51112 L 0 .028 .128 r
F
.52042 .51199 m .51898 .51049 L .52163 .50962 L F
.37627 .51088 m .37728 .50855 L .37885 .51009 L 0 .026 .125 r
F
.37627 .51088 m .37471 .5093 L .37728 .50855 L F
.65376 .51144 m .65515 .50912 L .65647 .51064 L 0 .027 .127 r
F
.65376 .51144 m .65244 .50991 L .65515 .50912 L F
.57832 .51108 m .57961 .50891 L .581 .51035 L 0 .027 .126 r
F
.57832 .51108 m .57694 .50964 L .57961 .50891 L F
.52715 .51165 m .52837 .50935 L .5298 .51077 L 0 .028 .127 r
F
.52715 .51165 m .52571 .51026 L .52837 .50935 L F
.53388 .5113 m .5351 .50899 L .53653 .51043 L 0 .027 .126 r
F
.53388 .5113 m .53245 .50987 L .5351 .50899 L F
.41399 .51113 m .41505 .50881 L .41658 .5103 L F
.41399 .51113 m .41245 .50965 L .41505 .50881 L F
.45171 .51133 m .45282 .509 L .45432 .51049 L 0 .027 .127 r
F
.45171 .51133 m .45021 .50982 L .45282 .509 L F
.34527 .51042 m .34624 .50817 L .34784 .50962 L 0 .025 .124 r
F
.34527 .51042 m .34368 .50898 L .34624 .50817 L F
.61604 .51137 m .61739 .50909 L .61874 .51064 L 0 .027 .127 r
F
.61604 .51137 m .61469 .50982 L .61739 .50909 L F
.66049 .5112 m .6619 .50901 L .66321 .51038 L F
.66049 .5112 m .65919 .50984 L .6619 .50901 L F
.66723 .51094 m .66864 .50874 L .66994 .51014 L 0 .027 .126 r
F
.66723 .51094 m .66592 .50956 L .66864 .50874 L F
.35199 .5102 m .35297 .50788 L .35456 .50934 L 0 .025 .124 r
F
.35199 .5102 m .3504 .50875 L .35297 .50788 L F
.5406 .51114 m .54184 .50895 L .54326 .51038 L 0 .027 .127 r
F
.5406 .51114 m .53918 .50969 L .54184 .50895 L F
.49615 .51136 m .49733 .50907 L .49879 .51059 L 0 .028 .127 r
F
.49615 .51136 m .49469 .50984 L .49733 .50907 L F
.42071 .51099 m .42178 .50863 L .42331 .51015 L 0 .027 .126 r
F
.42071 .51099 m .41918 .50948 L .42178 .50863 L F
.45843 .5112 m .45955 .50896 L .46105 .51045 L 0 .027 .127 r
F
.45843 .5112 m .45694 .50971 L .45955 .50896 L F
.38298 .51085 m .384 .50856 L .38556 .51009 L 0 .027 .126 r
F
.38298 .51085 m .38142 .50931 L .384 .50856 L F
.58506 .51109 m .58636 .50891 L .58774 .51038 L 0 .027 .127 r
F
.58506 .51109 m .58368 .50963 L .58636 .50891 L F
.42743 .51078 m .42851 .50855 L .43003 .51001 L 0 .027 .126 r
F
.42743 .51078 m .42591 .50931 L .42851 .50855 L F
.35871 .51007 m .35969 .50785 L .36127 .50936 L 0 .025 .124 r
F
.35871 .51007 m .35713 .50856 L .35969 .50785 L F
.67397 .51083 m .67539 .50853 L .67669 .51005 L 0 .027 .126 r
F
.67397 .51083 m .67266 .50933 L .67539 .50853 L F
.62278 .51141 m .62414 .50919 L .62548 .51068 L 0 .028 .128 r
F
.62278 .51141 m .62144 .50992 L .62414 .50919 L F
.54733 .51106 m .54858 .50891 L .54999 .51032 L 0 .027 .127 r
F
.54733 .51106 m .54592 .50964 L .54858 .50891 L F
.50288 .51132 m .50406 .50902 L .50552 .5105 L 0 .028 .127 r
F
.50288 .51132 m .50142 .50981 L .50406 .50902 L F
.62952 .5112 m .63088 .50889 L .63222 .51031 L F
.62952 .5112 m .62818 .50979 L .63088 .50889 L F
.46515 .5112 m .46629 .50878 L .46777 .51032 L 0 .027 .127 r
F
.46515 .5112 m .46366 .50968 L .46629 .50878 L F
.63625 .51086 m .63762 .50854 L .63895 .50998 L 0 .027 .126 r
F
.63625 .51086 m .63492 .50943 L .63762 .50854 L F
.3897 .51087 m .39072 .5086 L .39228 .51011 L F
.3897 .51087 m .38814 .50935 L .39072 .5086 L F
.59179 .51109 m .5931 .50869 L .59447 .5102 L 0 .027 .127 r
F
.59179 .51109 m .59042 .50959 L .5931 .50869 L F
.43415 .51076 m .43524 .50861 L .43675 .51005 L 0 .027 .126 r
F
.43415 .51076 m .43263 .50931 L .43524 .50861 L F
.47188 .51097 m .47302 .50855 L .4745 .5101 L F
.47188 .51097 m .4704 .50943 L .47302 .50855 L F
.55407 .51097 m .55532 .50869 L .55673 .51009 L 0 .027 .127 r
F
.55407 .51097 m .55266 .50958 L .55532 .50869 L F
.68071 .51083 m .68214 .50838 L .68343 .50995 L 0 .027 .126 r
F
.68071 .51083 m .67941 .50924 L .68214 .50838 L F
.59853 .51084 m .59984 .50843 L .60121 .50996 L F
.59853 .51084 m .59715 .50931 L .59984 .50843 L F
.50961 .51124 m .5108 .50896 L .51225 .51049 L 0 .028 .128 r
F
.50961 .51124 m .50816 .50969 L .5108 .50896 L F
.47861 .51068 m .47976 .50838 L .48123 .50982 L 0 .027 .126 r
F
.47861 .51068 m .47713 .50924 L .47976 .50838 L F
.64299 .5107 m .64436 .50831 L .64569 .50989 L F
.64299 .5107 m .64165 .5091 L .64436 .50831 L F
.39642 .5107 m .39746 .50828 L .39901 .5098 L F
.39642 .5107 m .39487 .50919 L .39746 .50828 L F
.5608 .51074 m .56206 .5083 L .56346 .50985 L F
.5608 .51074 m .55939 .50919 L .56206 .5083 L F
.36542 .51019 m .36641 .50786 L .36799 .50939 L 0 .026 .125 r
F
.36542 .51019 m .36384 .50866 L .36641 .50786 L F
.60526 .51059 m .60658 .50821 L .60794 .50973 L 0 .027 .126 r
F
.60526 .51059 m .60389 .50907 L .60658 .50821 L F
.68745 .51062 m .68888 .50818 L .69017 .50972 L F
.68745 .51062 m .68616 .50906 L .68888 .50818 L F
.40314 .51049 m .40419 .50819 L .40573 .50973 L F
.40314 .51049 m .4016 .50896 L .40419 .50819 L F
.56753 .51052 m .5688 .50807 L .5702 .50963 L 0 .026 .125 r
F
.56753 .51052 m .56613 .50896 L .5688 .50807 L F
.44087 .51071 m .44197 .50842 L .44348 .5099 L 0 .027 .126 r
F
.44087 .51071 m .43936 .50923 L .44197 .50842 L F
.32095 .51053 m .32189 .50807 L .3235 .50965 L 0 .026 .126 r
F
.32095 .51053 m .31933 .50895 L .32189 .50807 L F
.48533 .51054 m .48649 .50836 L .48796 .50984 L 0 .027 .126 r
F
.48533 .51054 m .48386 .50908 L .48649 .50836 L F
.32767 .51025 m .32862 .5079 L .33023 .50939 L 0 .026 .125 r
F
.32767 .51025 m .32606 .50877 L .32862 .5079 L F
.37213 .5101 m .37314 .50779 L .37471 .5093 L F
.37213 .5101 m .37056 .50858 L .37314 .50779 L F
.64973 .51071 m .65111 .50833 L .65244 .50991 L 0 .027 .126 r
F
.64973 .51071 m .6484 .50911 L .65111 .50833 L F
.33439 .50999 m .33535 .50771 L .33695 .50915 L 0 .026 .125 r
F
.33439 .50999 m .33278 .50855 L .33535 .50771 L F
.51634 .51129 m .51754 .50895 L .51898 .51049 L 0 .029 .128 r
F
.51634 .51129 m .51489 .50975 L .51754 .50895 L F
.57426 .51036 m .57555 .50811 L .57694 .50964 L 0 .027 .126 r
F
.57426 .51036 m .57287 .50884 L .57555 .50811 L F
.612 .51056 m .61333 .50826 L .61469 .50982 L F
.612 .51056 m .61064 .509 L .61333 .50826 L F
.4476 .51063 m .4487 .50831 L .45021 .50982 L 0 .027 .127 r
F
.4476 .51063 m .44609 .5091 L .4487 .50831 L F
.40986 .51047 m .41092 .50813 L .41245 .50965 L 0 .027 .126 r
F
.40986 .51047 m .40832 .50897 L .41092 .50813 L F
.34112 .50978 m .34207 .50751 L .34368 .50898 L 0 .026 .124 r
F
.34112 .50978 m .33951 .50833 L .34207 .50751 L F
.52307 .51112 m .52428 .50874 L .52571 .51026 L 0 .028 .128 r
F
.52307 .51112 m .52163 .50962 L .52428 .50874 L F
.5298 .51077 m .53102 .50843 L .53245 .50987 L 0 .028 .127 r
F
.5298 .51077 m .52837 .50935 L .53102 .50843 L F
.49206 .51062 m .49323 .50832 L .49469 .50984 L 0 .027 .127 r
F
.49206 .51062 m .49059 .50911 L .49323 .50832 L F
.53653 .51043 m .53776 .50825 L .53918 .50969 L F
.53653 .51043 m .5351 .50899 L .53776 .50825 L F
.65647 .51064 m .65787 .50834 L .65919 .50984 L F
.65647 .51064 m .65515 .50912 L .65787 .50834 L F
.37885 .51009 m .37986 .50779 L .38142 .50931 L 0 .026 .125 r
F
.37885 .51009 m .37728 .50855 L .37986 .50779 L F
.45432 .51049 m .45544 .50825 L .45694 .50971 L 0 .027 .127 r
F
.45432 .51049 m .45282 .509 L .45544 .50825 L F
.41658 .5103 m .41765 .50797 L .41918 .50948 L 0 .027 .126 r
F
.41658 .5103 m .41505 .50881 L .41765 .50797 L F
.581 .51035 m .58229 .50817 L .58368 .50963 L F
.581 .51035 m .57961 .50891 L .58229 .50817 L F
.34784 .50962 m .34881 .50729 L .3504 .50875 L 0 .025 .124 r
F
.34784 .50962 m .34624 .50817 L .34881 .50729 L F
.66321 .51038 m .66462 .50818 L .66592 .50956 L 0 .027 .127 r
F
.66321 .51038 m .6619 .50901 L .66462 .50818 L F
.61874 .51064 m .62009 .50836 L .62144 .50992 L 0 .028 .127 r
F
.61874 .51064 m .61739 .50909 L .62009 .50836 L F
.35456 .50934 m .35554 .50708 L .35713 .50856 L 0 .025 .124 r
F
.35456 .50934 m .35297 .50788 L .35554 .50708 L F
.66994 .51014 m .67136 .50792 L .67266 .50933 L 0 .027 .126 r
F
.66994 .51014 m .66864 .50874 L .67136 .50792 L F
.42331 .51015 m .42438 .50778 L .42591 .50931 L F
.42331 .51015 m .42178 .50863 L .42438 .50778 L F
.54326 .51038 m .5445 .50821 L .54592 .50964 L 0 .027 .127 r
F
.54326 .51038 m .54184 .50895 L .5445 .50821 L F
.49879 .51059 m .49997 .5083 L .50142 .50981 L 0 .028 .127 r
F
.49879 .51059 m .49733 .50907 L .49997 .5083 L F
.46105 .51045 m .46217 .50819 L .46366 .50968 L F
.46105 .51045 m .45955 .50896 L .46217 .50819 L F
.38556 .51009 m .38658 .50782 L .38814 .50935 L 0 .027 .126 r
F
.38556 .51009 m .384 .50856 L .38658 .50782 L F
.58774 .51038 m .58904 .50811 L .59042 .50959 L 0 .028 .127 r
F
.58774 .51038 m .58636 .50891 L .58904 .50811 L F
.43003 .51001 m .43111 .50786 L .43263 .50931 L 0 .027 .126 r
F
.43003 .51001 m .42851 .50855 L .43111 .50786 L F
.67669 .51005 m .67811 .50771 L .67941 .50924 L F
.67669 .51005 m .67539 .50853 L .67811 .50771 L F
.36127 .50936 m .36226 .50714 L .36384 .50866 L 0 .026 .124 r
F
.36127 .50936 m .35969 .50785 L .36226 .50714 L F
.62548 .51068 m .62684 .50829 L .62818 .50979 L 0 .028 .128 r
F
.62548 .51068 m .62414 .50919 L .62684 .50829 L F
.63222 .51031 m .63358 .50799 L .63492 .50943 L 0 .027 .127 r
F
.63222 .51031 m .63088 .50889 L .63358 .50799 L F
.50552 .5105 m .50671 .50823 L .50816 .50969 L 0 .028 .127 r
F
.50552 .5105 m .50406 .50902 L .50671 .50823 L F
.46777 .51032 m .46891 .50788 L .4704 .50943 L 0 .027 .127 r
F
.46777 .51032 m .46629 .50878 L .46891 .50788 L F
.54999 .51032 m .55125 .50818 L .55266 .50958 L 0 .028 .127 r
F
.54999 .51032 m .54858 .50891 L .55125 .50818 L F
.63895 .50998 m .64032 .50765 L .64165 .5091 L 0 .027 .126 r
F
.63895 .50998 m .63762 .50854 L .64032 .50765 L F
.59447 .5102 m .59578 .5078 L .59715 .50931 L F
.59447 .5102 m .5931 .50869 L .59578 .5078 L F
.55673 .51009 m .55799 .50779 L .55939 .50919 L F
.55673 .51009 m .55532 .50869 L .55799 .50779 L F
.4745 .5101 m .47565 .5077 L .47713 .50924 L F
.4745 .5101 m .47302 .50855 L .47565 .5077 L F
.39228 .51011 m .39331 .5077 L .39487 .50919 L F
.39228 .51011 m .39072 .5086 L .39331 .5077 L F
.68343 .50995 m .68486 .50751 L .68616 .50906 L F
.68343 .50995 m .68214 .50838 L .68486 .50751 L F
.60121 .50996 m .60253 .50754 L .60389 .50907 L F
.60121 .50996 m .59984 .50843 L .60253 .50754 L F
.39901 .5098 m .40005 .50742 L .4016 .50896 L 0 .026 .126 r
F
.39901 .5098 m .39746 .50828 L .40005 .50742 L F
.48123 .50982 m .48239 .50762 L .48386 .50908 L 0 .027 .126 r
F
.48123 .50982 m .47976 .50838 L .48239 .50762 L F
.56346 .50985 m .56473 .50741 L .56613 .50896 L F
.56346 .50985 m .56206 .5083 L .56473 .50741 L F
.43675 .51005 m .43785 .50779 L .43936 .50923 L 0 .027 .127 r
F
.43675 .51005 m .43524 .50861 L .43785 .50779 L F
.64569 .50989 m .64707 .50754 L .6484 .50911 L 0 .027 .126 r
F
.64569 .50989 m .64436 .50831 L .64707 .50754 L F
.69017 .50972 m .69161 .5073 L .6929 .50882 L 0 .026 .125 r
F
.69017 .50972 m .68888 .50818 L .69161 .5073 L F
.60794 .50973 m .60928 .50748 L .61064 .509 L 0 .027 .126 r
F
.60794 .50973 m .60658 .50821 L .60928 .50748 L F
.51225 .51049 m .51345 .50823 L .51489 .50975 L 0 .028 .128 r
F
.51225 .51049 m .5108 .50896 L .51345 .50823 L F
.36799 .50939 m .36899 .50705 L .37056 .50858 L 0 .026 .125 r
F
.36799 .50939 m .36641 .50786 L .36899 .50705 L F
.5702 .50963 m .57148 .50728 L .57287 .50884 L F
.5702 .50963 m .5688 .50807 L .57148 .50728 L F
.3235 .50965 m .32445 .50719 L .32606 .50877 L F
.3235 .50965 m .32189 .50807 L .32445 .50719 L F
.44348 .5099 m .44458 .50762 L .44609 .5091 L 0 .027 .126 r
F
.44348 .5099 m .44197 .50842 L .44458 .50762 L F
.40573 .50973 m .40678 .50742 L .40832 .50897 L F
.40573 .50973 m .40419 .50819 L .40678 .50742 L F
.33023 .50939 m .33117 .50706 L .33278 .50855 L 0 .026 .125 r
F
.33023 .50939 m .32862 .5079 L .33117 .50706 L F
.48796 .50984 m .48913 .50761 L .49059 .50911 L 0 .027 .127 r
F
.48796 .50984 m .48649 .50836 L .48913 .50761 L F
.37471 .5093 m .37571 .50705 L .37728 .50855 L 0 .026 .125 r
F
.37471 .5093 m .37314 .50779 L .37571 .50705 L F
.33695 .50915 m .33791 .50687 L .33951 .50833 L F
.33695 .50915 m .33535 .50771 L .33791 .50687 L F
.65244 .50991 m .65383 .50756 L .65515 .50912 L 0 .027 .127 r
F
.65244 .50991 m .65111 .50833 L .65383 .50756 L F
.51898 .51049 m .52019 .50808 L .52163 .50962 L 0 .028 .128 r
F
.51898 .51049 m .51754 .50895 L .52019 .50808 L F
.45021 .50982 m .45132 .50752 L .45282 .509 L 0 .027 .127 r
F
.45021 .50982 m .4487 .50831 L .45132 .50752 L F
.61469 .50982 m .61603 .50753 L .61739 .50909 L F
.61469 .50982 m .61333 .50826 L .61603 .50753 L F
.57694 .50964 m .57822 .50737 L .57961 .50891 L 0 .027 .126 r
F
.57694 .50964 m .57555 .50811 L .57822 .50737 L F
.41245 .50965 m .41352 .50728 L .41505 .50881 L F
.41245 .50965 m .41092 .50813 L .41352 .50728 L F
.53245 .50987 m .53368 .50754 L .5351 .50899 L 0 .027 .127 r
F
.53245 .50987 m .53102 .50843 L .53368 .50754 L F
.52571 .51026 m .52693 .50784 L .52837 .50935 L 0 .028 .128 r
F
.52571 .51026 m .52428 .50874 L .52693 .50784 L F
.34368 .50898 m .34464 .50669 L .34624 .50817 L 0 .026 .124 r
F
.34368 .50898 m .34207 .50751 L .34464 .50669 L F
.65919 .50984 m .66059 .50751 L .6619 .50901 L 0 .028 .127 r
F
.65919 .50984 m .65787 .50834 L .66059 .50751 L F
.49469 .50984 m .49587 .50752 L .49733 .50907 L F
.49469 .50984 m .49323 .50832 L .49587 .50752 L F
.41918 .50948 m .42025 .50711 L .42178 .50863 L 0 .027 .126 r
F
.41918 .50948 m .41765 .50797 L .42025 .50711 L F
.3504 .50875 m .35138 .5064 L .35297 .50788 L 0 .025 .124 r
F
.3504 .50875 m .34881 .50729 L .35138 .5064 L F
.38142 .50931 m .38244 .50704 L .384 .50856 L 0 .026 .126 r
F
.38142 .50931 m .37986 .50779 L .38244 .50704 L F
.53918 .50969 m .54042 .50751 L .54184 .50895 L 0 .027 .127 r
F
.53918 .50969 m .53776 .50825 L .54042 .50751 L F
.45694 .50971 m .45806 .50751 L .45955 .50896 L F
.45694 .50971 m .45544 .50825 L .45806 .50751 L F
.66592 .50956 m .66734 .50734 L .66864 .50874 L F
.66592 .50956 m .66462 .50818 L .66734 .50734 L F
.58368 .50963 m .58498 .50744 L .58636 .50891 L F
.58368 .50963 m .58229 .50817 L .58498 .50744 L F
.42591 .50931 m .42699 .50701 L .42851 .50855 L 0 .027 .126 r
F
.42591 .50931 m .42438 .50778 L .42699 .50701 L F
.35713 .50856 m .35811 .50636 L .35969 .50785 L 0 .025 .124 r
F
.35713 .50856 m .35554 .50708 L .35811 .50636 L F
.67266 .50933 m .67409 .5071 L .67539 .50853 L 0 .027 .126 r
F
.67266 .50933 m .67136 .50792 L .67409 .5071 L F
.62144 .50992 m .62279 .50763 L .62414 .50919 L 0 .028 .128 r
F
.62144 .50992 m .62009 .50836 L .62279 .50763 L F
.50142 .50981 m .50261 .50754 L .50406 .50902 L 0 .028 .127 r
F
.50142 .50981 m .49997 .5083 L .50261 .50754 L F
.54592 .50964 m .54717 .50748 L .54858 .50891 L F
.54592 .50964 m .5445 .50821 L .54717 .50748 L F
.46366 .50968 m .4648 .50728 L .46629 .50878 L F
.46366 .50968 m .46217 .50819 L .4648 .50728 L F
.38814 .50935 m .38917 .50708 L .39072 .5086 L 0 .027 .126 r
F
.38814 .50935 m .38658 .50782 L .38917 .50708 L F
.59042 .50959 m .59172 .50722 L .5931 .50869 L 0 .027 .127 r
F
.59042 .50959 m .58904 .50811 L .59172 .50722 L F
.62818 .50979 m .62954 .50739 L .63088 .50889 L 0 .028 .127 r
F
.62818 .50979 m .62684 .50829 L .62954 .50739 L F
.4704 .50943 m .47154 .507 L .47302 .50855 L 0 .027 .126 r
F
.4704 .50943 m .46891 .50788 L .47154 .507 L F
.63492 .50943 m .63628 .50709 L .63762 .50854 L 0 .027 .127 r
F
.63492 .50943 m .63358 .50799 L .63628 .50709 L F
.67941 .50924 m .68084 .50686 L .68214 .50838 L 0 .027 .126 r
F
.67941 .50924 m .67811 .50771 L .68084 .50686 L F
.64165 .5091 m .64303 .50686 L .64436 .50831 L F
.64165 .5091 m .64032 .50765 L .64303 .50686 L F
.43263 .50931 m .43372 .50716 L .43524 .50861 L 0 .027 .127 r
F
.43263 .50931 m .43111 .50786 L .43372 .50716 L F
.50816 .50969 m .50935 .50753 L .5108 .50896 L 0 .028 .128 r
F
.50816 .50969 m .50671 .50823 L .50935 .50753 L F
.59715 .50931 m .59847 .50692 L .59984 .50843 L 0 .027 .126 r
F
.59715 .50931 m .59578 .5078 L .59847 .50692 L F
.55939 .50919 m .56066 .5069 L .56206 .5083 L F
.55939 .50919 m .55799 .50779 L .56066 .5069 L F
.39487 .50919 m .39591 .5068 L .39746 .50828 L F
.39487 .50919 m .39331 .5077 L .39591 .5068 L F
.55266 .50958 m .55391 .5073 L .55532 .50869 L 0 .028 .127 r
F
.55266 .50958 m .55125 .50818 L .55391 .5073 L F
.36384 .50866 m .36483 .50633 L .36641 .50786 L 0 .026 .125 r
F
.36384 .50866 m .36226 .50714 L .36483 .50633 L F
.47713 .50924 m .47828 .50685 L .47976 .50838 L 0 .027 .126 r
F
.47713 .50924 m .47565 .5077 L .47828 .50685 L F
.68616 .50906 m .68759 .50664 L .68888 .50818 L 0 .026 .126 r
F
.68616 .50906 m .68486 .50751 L .68759 .50664 L F
.60389 .50907 m .60522 .50669 L .60658 .50821 L 0 .027 .126 r
F
.60389 .50907 m .60253 .50754 L .60522 .50669 L F
.31933 .50895 m .32027 .50649 L .32189 .50807 L 0 .026 .125 r
F
.31933 .50895 m .31772 .50737 L .32027 .50649 L F
.4016 .50896 m .40264 .50665 L .40419 .50819 L 0 .027 .126 r
F
.4016 .50896 m .40005 .50742 L .40264 .50665 L F
.56613 .50896 m .5674 .50652 L .5688 .50807 L 0 .026 .125 r
F
.56613 .50896 m .56473 .50741 L .5674 .50652 L F
.6929 .50882 m .69434 .50641 L .69563 .50793 L F
.6929 .50882 m .69161 .5073 L .69434 .50641 L F
.43936 .50923 m .44046 .50696 L .44197 .50842 L 0 .027 .127 r
F
.43936 .50923 m .43785 .50779 L .44046 .50696 L F
.48386 .50908 m .48502 .50687 L .48649 .50836 L 0 .027 .126 r
F
.48386 .50908 m .48239 .50762 L .48502 .50687 L F
.6484 .50911 m .64979 .50678 L .65111 .50833 L F
.6484 .50911 m .64707 .50754 L .64979 .50678 L F
.32606 .50877 m .32701 .50633 L .32862 .5079 L 0 .026 .125 r
F
.32606 .50877 m .32445 .50719 L .32701 .50633 L F
.37056 .50858 m .37156 .50627 L .37314 .50779 L F
.37056 .50858 m .36899 .50705 L .37156 .50627 L F
.61064 .509 m .61197 .50674 L .61333 .50826 L 0 .027 .126 r
F
.61064 .509 m .60928 .50748 L .61197 .50674 L F
.51489 .50975 m .5161 .50745 L .51754 .50895 L 0 .029 .128 r
F
.51489 .50975 m .51345 .50823 L .5161 .50745 L F
.57287 .50884 m .57415 .50654 L .57555 .50811 L 0 .027 .126 r
F
.57287 .50884 m .57148 .50728 L .57415 .50654 L F
.44609 .5091 m .4472 .50685 L .4487 .50831 L 0 .027 .127 r
F
.44609 .5091 m .44458 .50762 L .4472 .50685 L F
.33278 .50855 m .33374 .50623 L .33535 .50771 L 0 .026 .125 r
F
.33278 .50855 m .33117 .50706 L .33374 .50623 L F
.40832 .50897 m .40938 .50657 L .41092 .50813 L 0 .027 .126 r
F
.40832 .50897 m .40678 .50742 L .40938 .50657 L F
.52163 .50962 m .52284 .5072 L .52428 .50874 L 0 .028 .128 r
F
.52163 .50962 m .52019 .50808 L .52284 .5072 L F
.33951 .50833 m .34047 .50604 L .34207 .50751 L 0 .026 .125 r
F
.33951 .50833 m .33791 .50687 L .34047 .50604 L F
.37728 .50855 m .37829 .50632 L .37986 .50779 L F
.37728 .50855 m .37571 .50705 L .37829 .50632 L F
.49059 .50911 m .49176 .50678 L .49323 .50832 L 0 .027 .127 r
F
.49059 .50911 m .48913 .50761 L .49176 .50678 L F
.65515 .50912 m .65655 .50679 L .65787 .50834 L F
.65515 .50912 m .65383 .50756 L .65655 .50679 L F
.52837 .50935 m .52959 .50692 L .53102 .50843 L 0 .028 .127 r
F
.52837 .50935 m .52693 .50784 L .52959 .50692 L F
.5351 .50899 m .53633 .5068 L .53776 .50825 L 0 .027 .127 r
F
.5351 .50899 m .53368 .50754 L .53633 .5068 L F
.41505 .50881 m .41612 .50642 L .41765 .50797 L 0 .027 .126 r
F
.41505 .50881 m .41352 .50728 L .41612 .50642 L F
.45282 .509 m .45394 .50678 L .45544 .50825 L 0 .027 .127 r
F
.45282 .509 m .45132 .50752 L .45394 .50678 L F
.61739 .50909 m .61873 .50679 L .62009 .50836 L 0 .028 .127 r
F
.61739 .50909 m .61603 .50753 L .61873 .50679 L F
.57961 .50891 m .58091 .50662 L .58229 .50817 L 0 .027 .127 r
F
.57961 .50891 m .57822 .50737 L .58091 .50662 L F
.34624 .50817 m .34721 .50579 L .34881 .50729 L 0 .025 .124 r
F
.34624 .50817 m .34464 .50669 L .34721 .50579 L F
.35297 .50788 m .35395 .5056 L .35554 .50708 L F
.35297 .50788 m .35138 .5064 L .35395 .5056 L F
.42178 .50863 m .42286 .50625 L .42438 .50778 L 0 .027 .126 r
F
.42178 .50863 m .42025 .50711 L .42286 .50625 L F
.6619 .50901 m .66331 .50666 L .66462 .50818 L 0 .027 .127 r
F
.6619 .50901 m .66059 .50751 L .66331 .50666 L F
.49733 .50907 m .49851 .50676 L .49997 .5083 L 0 .028 .127 r
F
.49733 .50907 m .49587 .50752 L .49851 .50676 L F
.66864 .50874 m .67006 .5065 L .67136 .50792 L 0 .027 .126 r
F
.66864 .50874 m .66734 .50734 L .67006 .5065 L F
.384 .50856 m .38502 .50631 L .38658 .50782 L F
.384 .50856 m .38244 .50704 L .38502 .50631 L F
.54184 .50895 m .54308 .50676 L .5445 .50821 L 0 .028 .127 r
F
.54184 .50895 m .54042 .50751 L .54308 .50676 L F
.45955 .50896 m .46068 .50676 L .46217 .50819 L F
.45955 .50896 m .45806 .50751 L .46068 .50676 L F
.67539 .50853 m .67682 .50627 L .67811 .50771 L 0 .027 .126 r
F
.67539 .50853 m .67409 .5071 L .67682 .50627 L F
.58636 .50891 m .58766 .50663 L .58904 .50811 L 0 .028 .127 r
F
.58636 .50891 m .58498 .50744 L .58766 .50663 L F
.42851 .50855 m .42959 .5063 L .43111 .50786 L 0 .027 .126 r
F
.42851 .50855 m .42699 .50701 L .42959 .5063 L F
.46629 .50878 m .46742 .50637 L .46891 .50788 L 0 .027 .127 r
F
.46629 .50878 m .4648 .50728 L .46742 .50637 L F
.35969 .50785 m .36067 .50564 L .36226 .50714 L 0 .026 .124 r
F
.35969 .50785 m .35811 .50636 L .36067 .50564 L F
.62414 .50919 m .62549 .50673 L .62684 .50829 L 0 .028 .128 r
F
.62414 .50919 m .62279 .50763 L .62549 .50673 L F
.50406 .50902 m .50525 .50678 L .50671 .50823 L F
.50406 .50902 m .50261 .50754 L .50525 .50678 L F
.5931 .50869 m .59441 .50633 L .59578 .5078 L 0 .027 .127 r
F
.5931 .50869 m .59172 .50722 L .59441 .50633 L F
.63088 .50889 m .63224 .50649 L .63358 .50799 L 0 .028 .127 r
F
.63088 .50889 m .62954 .50739 L .63224 .50649 L F
.63762 .50854 m .63899 .50619 L .64032 .50765 L 0 .027 .126 r
F
.63762 .50854 m .63628 .50709 L .63899 .50619 L F
.54858 .50891 m .54983 .50675 L .55125 .50818 L 0 .028 .128 r
F
.54858 .50891 m .54717 .50748 L .54983 .50675 L F
.47302 .50855 m .47417 .50616 L .47565 .5077 L 0 .027 .126 r
F
.47302 .50855 m .47154 .507 L .47417 .50616 L F
.68214 .50838 m .68357 .506 L .68486 .50751 L F
.68214 .50838 m .68084 .50686 L .68357 .506 L F
.39072 .5086 m .39176 .5062 L .39331 .5077 L F
.39072 .5086 m .38917 .50708 L .39176 .5062 L F
.59984 .50843 m .60116 .50604 L .60253 .50754 L F
.59984 .50843 m .59847 .50692 L .60116 .50604 L F
.39746 .50828 m .3985 .50596 L .40005 .50742 L F
.39746 .50828 m .39591 .5068 L .3985 .50596 L F
.56206 .5083 m .56333 .50602 L .56473 .50741 L F
.56206 .5083 m .56066 .5069 L .56333 .50602 L F
.64436 .50831 m .64575 .5061 L .64707 .50754 L F
.64436 .50831 m .64303 .50686 L .64575 .5061 L F
.55532 .50869 m .55658 .50639 L .55799 .50779 L 0 .028 .127 r
F
.55532 .50869 m .55391 .5073 L .55658 .50639 L F
.68888 .50818 m .69032 .50577 L .69161 .5073 L 0 .026 .125 r
F
.68888 .50818 m .68759 .50664 L .69032 .50577 L F
.47976 .50838 m .48091 .50607 L .48239 .50762 L 0 .027 .126 r
F
.47976 .50838 m .47828 .50685 L .48091 .50607 L F
.60658 .50821 m .60791 .50595 L .60928 .50748 L F
.60658 .50821 m .60522 .50669 L .60791 .50595 L F
.5108 .50896 m .512 .50683 L .51345 .50823 L 0 .028 .128 r
F
.5108 .50896 m .50935 .50753 L .512 .50683 L F
.36641 .50786 m .36741 .50551 L .36899 .50705 L 0 .026 .125 r
F
.36641 .50786 m .36483 .50633 L .36741 .50551 L F
.43524 .50861 m .43633 .50633 L .43785 .50779 L 0 .028 .127 r
F
.43524 .50861 m .43372 .50716 L .43633 .50633 L F
.32189 .50807 m .32283 .50561 L .32445 .50719 L 0 .026 .125 r
F
.32189 .50807 m .32027 .50649 L .32283 .50561 L F
.5688 .50807 m .57008 .50573 L .57148 .50728 L F
.5688 .50807 m .5674 .50652 L .57008 .50573 L F
.69563 .50793 m .69708 .50565 L .69837 .50718 L F
.69563 .50793 m .69434 .50641 L .69708 .50565 L F
.40419 .50819 m .40524 .50587 L .40678 .50742 L 0 .027 .126 r
F
.40419 .50819 m .40264 .50665 L .40524 .50587 L F
.44197 .50842 m .44307 .50616 L .44458 .50762 L 0 .027 .127 r
F
.44197 .50842 m .44046 .50696 L .44307 .50616 L F
.32862 .5079 m .32957 .50551 L .33117 .50706 L 0 .026 .125 r
F
.32862 .5079 m .32701 .50633 L .32957 .50551 L F
.65111 .50833 m .65251 .50602 L .65383 .50756 L 0 .027 .126 r
F
.65111 .50833 m .64979 .50678 L .65251 .50602 L F
.37314 .50779 m .37414 .50556 L .37571 .50705 L 0 .026 .125 r
F
.37314 .50779 m .37156 .50627 L .37414 .50556 L F
.48649 .50836 m .48766 .5061 L .48913 .50761 L 0 .027 .127 r
F
.48649 .50836 m .48502 .50687 L .48766 .5061 L F
.51754 .50895 m .51875 .50656 L .52019 .50808 L 0 .028 .128 r
F
.51754 .50895 m .5161 .50745 L .51875 .50656 L F
.61333 .50826 m .61467 .506 L .61603 .50753 L 0 .027 .127 r
F
.61333 .50826 m .61197 .50674 L .61467 .506 L F
.33535 .50771 m .3363 .50539 L .33791 .50687 L 0 .026 .125 r
F
.33535 .50771 m .33374 .50623 L .3363 .50539 L F
.57555 .50811 m .57683 .50579 L .57822 .50737 L 0 .027 .126 r
F
.57555 .50811 m .57415 .50654 L .57683 .50579 L F
.4487 .50831 m .44981 .50608 L .45132 .50752 L 0 .027 .127 r
F
.4487 .50831 m .4472 .50685 L .44981 .50608 L F
.41092 .50813 m .41198 .5057 L .41352 .50728 L 0 .027 .126 r
F
.41092 .50813 m .40938 .50657 L .41198 .5057 L F
.52428 .50874 m .5255 .5063 L .52693 .50784 L 0 .028 .128 r
F
.52428 .50874 m .52284 .5072 L .5255 .5063 L F
.53102 .50843 m .53224 .50604 L .53368 .50754 L 0 .028 .127 r
F
.53102 .50843 m .52959 .50692 L .53224 .50604 L F
.34207 .50751 m .34304 .5052 L .34464 .50669 L 0 .026 .125 r
F
.34207 .50751 m .34047 .50604 L .34304 .5052 L F
.49323 .50832 m .4944 .50596 L .49587 .50752 L 0 .027 .127 r
F
.49323 .50832 m .49176 .50678 L .4944 .50596 L F
.65787 .50834 m .65927 .50597 L .66059 .50751 L 0 .028 .127 r
F
.65787 .50834 m .65655 .50679 L .65927 .50597 L F
.41765 .50797 m .41872 .50556 L .42025 .50711 L 0 .027 .126 r
F
.41765 .50797 m .41612 .50642 L .41872 .50556 L F
.37986 .50779 m .38087 .50558 L .38244 .50704 L F
.37986 .50779 m .37829 .50632 L .38087 .50558 L F
.34881 .50729 m .34979 .50488 L .35138 .5064 L 0 .025 .124 r
F
.34881 .50729 m .34721 .50579 L .34979 .50488 L F
.45544 .50825 m .45656 .50606 L .45806 .50751 L 0 .028 .127 r
F
.45544 .50825 m .45394 .50678 L .45656 .50606 L F
.53776 .50825 m .539 .50606 L .54042 .50751 L F
.53776 .50825 m .53633 .5068 L .539 .50606 L F
.42438 .50778 m .42546 .50547 L .42699 .50701 L 0 .027 .126 r
F
.42438 .50778 m .42286 .50625 L .42546 .50547 L F
.62009 .50836 m .62143 .50606 L .62279 .50763 L 0 .028 .127 r
F
.62009 .50836 m .61873 .50679 L .62143 .50606 L F
.58229 .50817 m .58359 .50587 L .58498 .50744 L F
.58229 .50817 m .58091 .50662 L .58359 .50587 L F
.66462 .50818 m .66603 .5058 L .66734 .50734 L 0 .027 .127 r
F
.66462 .50818 m .66331 .50666 L .66603 .5058 L F
.35554 .50708 m .35652 .50486 L .35811 .50636 L 0 .025 .124 r
F
.35554 .50708 m .35395 .5056 L .35652 .50486 L F
.67136 .50792 m .67279 .50566 L .67409 .5071 L 0 .027 .126 r
F
.67136 .50792 m .67006 .5065 L .67279 .50566 L F
.49997 .5083 m .50115 .50601 L .50261 .50754 L 0 .028 .127 r
F
.49997 .5083 m .49851 .50676 L .50115 .50601 L F
.46217 .50819 m .4633 .50586 L .4648 .50728 L F
.46217 .50819 m .46068 .50676 L .4633 .50586 L F
.38658 .50782 m .38761 .50557 L .38917 .50708 L 0 .027 .126 r
F
.38658 .50782 m .38502 .50631 L .38761 .50557 L F
.5445 .50821 m .54575 .50601 L .54717 .50748 L 0 .028 .128 r
F
.5445 .50821 m .54308 .50676 L .54575 .50601 L F
.46891 .50788 m .47005 .5055 L .47154 .507 L 0 .027 .126 r
F
.46891 .50788 m .46742 .50637 L .47005 .5055 L F
.67811 .50771 m .67954 .50543 L .68084 .50686 L F
.67811 .50771 m .67682 .50627 L .67954 .50543 L F
.62684 .50829 m .62819 .50582 L .62954 .50739 L 0 .028 .127 r
F
.62684 .50829 m .62549 .50673 L .62819 .50582 L F
.58904 .50811 m .59035 .50575 L .59172 .50722 L F
.58904 .50811 m .58766 .50663 L .59035 .50575 L F
.59578 .5078 m .5971 .50546 L .59847 .50692 L 0 .027 .126 r
F
.59578 .5078 m .59441 .50633 L .5971 .50546 L F
.63358 .50799 m .63494 .50558 L .63628 .50709 L 0 .027 .127 r
F
.63358 .50799 m .63224 .50649 L .63494 .50558 L F
.64032 .50765 m .6417 .5054 L .64303 .50686 L 0 .027 .126 r
F
.64032 .50765 m .63899 .50619 L .6417 .5054 L F
.43111 .50786 m .4322 .50558 L .43372 .50716 L 0 .027 .127 r
F
.43111 .50786 m .42959 .5063 L .4322 .50558 L F
.50671 .50823 m .5079 .5061 L .50935 .50753 L 0 .028 .128 r
F
.50671 .50823 m .50525 .50678 L .5079 .5061 L F
.68486 .50751 m .6863 .50515 L .68759 .50664 L 0 .026 .126 r
F
.68486 .50751 m .68357 .506 L .6863 .50515 L F
.39331 .5077 m .39435 .50532 L .39591 .5068 L 0 .027 .126 r
F
.39331 .5077 m .39176 .5062 L .39435 .50532 L F
.47565 .5077 m .4768 .50531 L .47828 .50685 L F
.47565 .5077 m .47417 .50616 L .4768 .50531 L F
.36226 .50714 m .36325 .50481 L .36483 .50633 L 0 .026 .125 r
F
.36226 .50714 m .36067 .50564 L .36325 .50481 L F
.60253 .50754 m .60385 .50519 L .60522 .50669 L 0 .027 .126 r
F
.60253 .50754 m .60116 .50604 L .60385 .50519 L F
.31772 .50737 m .31866 .50492 L .32027 .50649 L 0 .026 .125 r
F
.31772 .50737 m .3161 .50579 L .31866 .50492 L F
.56473 .50741 m .566 .50515 L .5674 .50652 L 0 .026 .126 r
F
.56473 .50741 m .56333 .50602 L .566 .50515 L F
.55799 .50779 m .55925 .5055 L .56066 .5069 L 0 .027 .127 r
F
.55799 .50779 m .55658 .50639 L .55925 .5055 L F
.40005 .50742 m .40109 .5052 L .40264 .50665 L 0 .027 .126 r
F
.40005 .50742 m .3985 .50596 L .40109 .5052 L F
.55125 .50818 m .5525 .50586 L .55391 .5073 L 0 .028 .128 r
F
.55125 .50818 m .54983 .50675 L .5525 .50586 L F
.69161 .5073 m .69306 .5049 L .69434 .50641 L 0 .026 .125 r
F
.69161 .5073 m .69032 .50577 L .69306 .5049 L F
.64707 .50754 m .64846 .50535 L .64979 .50678 L 0 .027 .126 r
F
.64707 .50754 m .64575 .5061 L .64846 .50535 L F
.32445 .50719 m .32539 .50476 L .32701 .50633 L 0 .026 .125 r
F
.32445 .50719 m .32283 .50561 L .32539 .50476 L F
.43785 .50779 m .43894 .50549 L .44046 .50696 L 0 .028 .127 r
F
.43785 .50779 m .43633 .50633 L .43894 .50549 L F
.36899 .50705 m .36999 .50473 L .37156 .50627 L 0 .026 .125 r
F
.36899 .50705 m .36741 .50551 L .36999 .50473 L F
.48239 .50762 m .48355 .5053 L .48502 .50687 L 0 .027 .126 r
F
.48239 .50762 m .48091 .50607 L .48355 .5053 L F
.57148 .50728 m .57276 .50497 L .57415 .50654 L 0 .026 .126 r
F
.57148 .50728 m .57008 .50573 L .57276 .50497 L F
.60928 .50748 m .61061 .50522 L .61197 .50674 L 0 .027 .126 r
F
.60928 .50748 m .60791 .50595 L .61061 .50522 L F
.51345 .50823 m .51465 .50605 L .5161 .50745 L 0 .029 .129 r
F
.51345 .50823 m .512 .50683 L .51465 .50605 L F
.69837 .50718 m .69983 .50489 L .70111 .50644 L 0 .026 .125 r
F
.69837 .50718 m .69708 .50565 L .69983 .50489 L F
.40678 .50742 m .40784 .50501 L .40938 .50657 L 0 .027 .126 r
F
.40678 .50742 m .40524 .50587 L .40784 .50501 L F
.44458 .50762 m .44569 .50541 L .4472 .50685 L 0 .027 .127 r
F
.44458 .50762 m .44307 .50616 L .44569 .50541 L F
.33117 .50706 m .33213 .50469 L .33374 .50623 L 0 .026 .125 r
F
.33117 .50706 m .32957 .50551 L .33213 .50469 L F
.52019 .50808 m .5214 .50568 L .52284 .5072 L 0 .028 .128 r
F
.52019 .50808 m .51875 .50656 L .5214 .50568 L F
.65383 .50756 m .65523 .50526 L .65655 .50679 L 0 .027 .127 r
F
.65383 .50756 m .65251 .50602 L .65523 .50526 L F
.48913 .50761 m .4903 .50525 L .49176 .50678 L F
.48913 .50761 m .48766 .5061 L .4903 .50525 L F
.37571 .50705 m .37672 .50484 L .37829 .50632 L 0 .026 .126 r
F
.37571 .50705 m .37414 .50556 L .37672 .50484 L F
.33791 .50687 m .33887 .50455 L .34047 .50604 L 0 .026 .125 r
F
.33791 .50687 m .3363 .50539 L .33887 .50455 L F
.52693 .50784 m .52815 .50539 L .52959 .50692 L 0 .028 .127 r
F
.52693 .50784 m .5255 .5063 L .52815 .50539 L F
.41352 .50728 m .41458 .50484 L .41612 .50642 L 0 .027 .126 r
F
.41352 .50728 m .41198 .5057 L .41458 .50484 L F
.45132 .50752 m .45243 .50535 L .45394 .50678 L 0 .028 .127 r
F
.45132 .50752 m .44981 .50608 L .45243 .50535 L F
.61603 .50753 m .61738 .50526 L .61873 .50679 L F
.61603 .50753 m .61467 .506 L .61738 .50526 L F
.53368 .50754 m .53491 .5053 L .53633 .5068 L F
.53368 .50754 m .53224 .50604 L .53491 .5053 L F
.57822 .50737 m .57952 .50502 L .58091 .50662 L 0 .027 .126 r
F
.57822 .50737 m .57683 .50579 L .57952 .50502 L F
.34464 .50669 m .34561 .50428 L .34721 .50579 L 0 .026 .124 r
F
.34464 .50669 m .34304 .5052 L .34561 .50428 L F
.42025 .50711 m .42133 .50471 L .42286 .50625 L 0 .027 .126 r
F
.42025 .50711 m .41872 .50556 L .42133 .50471 L F
.66059 .50751 m .66199 .50509 L .66331 .50666 L 0 .027 .127 r
F
.66059 .50751 m .65927 .50597 L .66199 .50509 L F
.49587 .50752 m .49705 .50519 L .49851 .50676 L 0 .028 .127 r
F
.49587 .50752 m .4944 .50596 L .49705 .50519 L F
.35138 .5064 m .35236 .50406 L .35395 .5056 L 0 .025 .124 r
F
.35138 .5064 m .34979 .50488 L .35236 .50406 L F
.38244 .50704 m .38346 .50485 L .38502 .50631 L 0 .027 .126 r
F
.38244 .50704 m .38087 .50558 L .38346 .50485 L F
.54042 .50751 m .54166 .50531 L .54308 .50676 L 0 .028 .128 r
F
.54042 .50751 m .539 .50606 L .54166 .50531 L F
.45806 .50751 m .45918 .50533 L .46068 .50676 L F
.45806 .50751 m .45656 .50606 L .45918 .50533 L F
.66734 .50734 m .66875 .50494 L .67006 .5065 L 0 .027 .127 r
F
.66734 .50734 m .66603 .5058 L .66875 .50494 L F
.42699 .50701 m .42807 .50473 L .42959 .5063 L 0 .027 .126 r
F
.42699 .50701 m .42546 .50547 L .42807 .50473 L F
.58498 .50744 m .58628 .50506 L .58766 .50663 L 0 .028 .127 r
F
.58498 .50744 m .58359 .50587 L .58628 .50506 L F
.62279 .50763 m .62414 .50516 L .62549 .50673 L F
.62279 .50763 m .62143 .50606 L .62414 .50516 L F
.4648 .50728 m .46593 .50495 L .46742 .50637 L 0 .027 .127 r
F
.4648 .50728 m .4633 .50586 L .46593 .50495 L F
.67409 .5071 m .67552 .50483 L .67682 .50627 L 0 .027 .126 r
F
.67409 .5071 m .67279 .50566 L .67552 .50483 L F
.35811 .50636 m .35909 .50413 L .36067 .50564 L 0 .026 .124 r
F
.35811 .50636 m .35652 .50486 L .35909 .50413 L F
.50261 .50754 m .5038 .50526 L .50525 .50678 L 0 .028 .128 r
F
.50261 .50754 m .50115 .50601 L .5038 .50526 L F
.47154 .507 m .47268 .50466 L .47417 .50616 L 0 .027 .126 r
F
.47154 .507 m .47005 .5055 L .47268 .50466 L F
.62954 .50739 m .63089 .50492 L .63224 .50649 L 0 .028 .127 r
F
.62954 .50739 m .62819 .50582 L .63089 .50492 L F
.59172 .50722 m .59303 .50486 L .59441 .50633 L 0 .027 .127 r
F
.59172 .50722 m .59035 .50575 L .59303 .50486 L F
.68084 .50686 m .68228 .50459 L .68357 .506 L 0 .027 .126 r
F
.68084 .50686 m .67954 .50543 L .68228 .50459 L F
.38917 .50708 m .3902 .50471 L .39176 .5062 L F
.38917 .50708 m .38761 .50557 L .3902 .50471 L F
.63628 .50709 m .63765 .50468 L .63899 .50619 L F
.63628 .50709 m .63494 .50558 L .63765 .50468 L F
.59847 .50692 m .59979 .50459 L .60116 .50604 L F
.59847 .50692 m .5971 .50546 L .59979 .50459 L F
.54717 .50748 m .54842 .50526 L .54983 .50675 L 0 .028 .128 r
F
.54717 .50748 m .54575 .50601 L .54842 .50526 L F
.39591 .5068 m .39695 .5045 L .3985 .50596 L 0 .027 .126 r
F
.39591 .5068 m .39435 .50532 L .39695 .5045 L F
.68759 .50664 m .68903 .50429 L .69032 .50577 L 0 .026 .125 r
F
.68759 .50664 m .6863 .50515 L .68903 .50429 L F
.47828 .50685 m .47943 .50451 L .48091 .50607 L 0 .027 .126 r
F
.47828 .50685 m .4768 .50531 L .47943 .50451 L F
.64303 .50686 m .64442 .50466 L .64575 .5061 L F
.64303 .50686 m .6417 .5054 L .64442 .50466 L F
.32027 .50649 m .32122 .50405 L .32283 .50561 L 0 .026 .125 r
F
.32027 .50649 m .31866 .50492 L .32122 .50405 L F
.60522 .50669 m .60655 .50445 L .60791 .50595 L 0 .027 .126 r
F
.60522 .50669 m .60385 .50519 L .60655 .50445 L F
.36483 .50633 m .36583 .50397 L .36741 .50551 L 0 .026 .125 r
F
.36483 .50633 m .36325 .50481 L .36583 .50397 L F
.5674 .50652 m .56868 .50434 L .57008 .50573 L 0 .026 .126 r
F
.5674 .50652 m .566 .50515 L .56868 .50434 L F
.56066 .5069 m .56193 .50463 L .56333 .50602 L 0 .027 .126 r
F
.56066 .5069 m .55925 .5055 L .56193 .50463 L F
.55391 .5073 m .55517 .50495 L .55658 .50639 L 0 .028 .127 r
F
.55391 .5073 m .5525 .50586 L .55517 .50495 L F
.50935 .50753 m .51055 .50542 L .512 .50683 L 0 .029 .129 r
F
.50935 .50753 m .5079 .5061 L .51055 .50542 L F
.43372 .50716 m .43481 .50474 L .43633 .50633 L 0 .028 .127 r
F
.43372 .50716 m .4322 .50558 L .43481 .50474 L F
.69434 .50641 m .6958 .50412 L .69708 .50565 L 0 .026 .125 r
F
.69434 .50641 m .69306 .5049 L .6958 .50412 L F
.40264 .50665 m .40369 .50444 L .40524 .50587 L 0 .027 .126 r
F
.40264 .50665 m .40109 .5052 L .40369 .50444 L F
.32701 .50633 m .32795 .50396 L .32957 .50551 L 0 .026 .125 r
F
.32701 .50633 m .32539 .50476 L .32795 .50396 L F
.44046 .50696 m .44156 .50469 L .44307 .50616 L 0 .028 .127 r
F
.44046 .50696 m .43894 .50549 L .44156 .50469 L F
.64979 .50678 m .65118 .5046 L .65251 .50602 L 0 .027 .127 r
F
.64979 .50678 m .64846 .50535 L .65118 .5046 L F
.37156 .50627 m .37257 .50401 L .37414 .50556 L 0 .026 .125 r
F
.37156 .50627 m .36999 .50473 L .37257 .50401 L F
.48502 .50687 m .48618 .50451 L .48766 .5061 L 0 .027 .127 r
F
.48502 .50687 m .48355 .5053 L .48618 .50451 L F
.5161 .50745 m .5173 .50516 L .51875 .50656 L 0 .029 .129 r
F
.5161 .50745 m .51465 .50605 L .5173 .50516 L F
.57415 .50654 m .57544 .50421 L .57683 .50579 L 0 .027 .126 r
F
.57415 .50654 m .57276 .50497 L .57544 .50421 L F
.61197 .50674 m .61331 .50448 L .61467 .506 L 0 .027 .127 r
F
.61197 .50674 m .61061 .50522 L .61331 .50448 L F
.40938 .50657 m .41044 .50413 L .41198 .5057 L 0 .027 .126 r
F
.40938 .50657 m .40784 .50501 L .41044 .50413 L F
.33374 .50623 m .33469 .50386 L .3363 .50539 L 0 .026 .125 r
F
.33374 .50623 m .33213 .50469 L .33469 .50386 L F
.70111 .50644 m .70257 .50413 L .70385 .50569 L 0 .027 .126 r
F
.70111 .50644 m .69983 .50489 L .70257 .50413 L F
.52284 .5072 m .52406 .50479 L .5255 .5063 L 0 .028 .128 r
F
.52284 .5072 m .5214 .50568 L .52406 .50479 L F
.4472 .50685 m .44831 .50466 L .44981 .50608 L 0 .028 .127 r
F
.4472 .50685 m .44569 .50541 L .44831 .50466 L F
.52959 .50692 m .53081 .50452 L .53224 .50604 L F
.52959 .50692 m .52815 .50539 L .53081 .50452 L F
.49176 .50678 m .49294 .5044 L .4944 .50596 L 0 .027 .127 r
F
.49176 .50678 m .4903 .50525 L .49294 .5044 L F
.34047 .50604 m .34144 .50369 L .34304 .5052 L 0 .026 .125 r
F
.34047 .50604 m .33887 .50455 L .34144 .50369 L F
.65655 .50679 m .65795 .50444 L .65927 .50597 L 0 .027 .127 r
F
.65655 .50679 m .65523 .50526 L .65795 .50444 L F
.41612 .50642 m .41719 .50399 L .41872 .50556 L 0 .027 .126 r
F
.41612 .50642 m .41458 .50484 L .41719 .50399 L F
.37829 .50632 m .3793 .50411 L .38087 .50558 L F
.37829 .50632 m .37672 .50484 L .3793 .50411 L F
.34721 .50579 m .34819 .50336 L .34979 .50488 L 0 .025 .124 r
F
.34721 .50579 m .34561 .50428 L .34819 .50336 L F
.45394 .50678 m .45505 .50463 L .45656 .50606 L 0 .028 .128 r
F
.45394 .50678 m .45243 .50535 L .45505 .50463 L F
.61873 .50679 m .62008 .50452 L .62143 .50606 L 0 .028 .127 r
F
.61873 .50679 m .61738 .50526 L .62008 .50452 L F
.53633 .5068 m .53757 .50456 L .539 .50606 L F
.53633 .5068 m .53491 .5053 L .53757 .50456 L F
.58091 .50662 m .5822 .50426 L .58359 .50587 L 0 .027 .127 r
F
.58091 .50662 m .57952 .50502 L .5822 .50426 L F
.42286 .50625 m .42393 .50391 L .42546 .50547 L 0 .027 .126 r
F
.42286 .50625 m .42133 .50471 L .42393 .50391 L F
.66331 .50666 m .66471 .50421 L .66603 .5058 L 0 .027 .127 r
F
.66331 .50666 m .66199 .50509 L .66471 .50421 L F
.35395 .5056 m .35493 .50331 L .35652 .50486 L 0 .025 .124 r
F
.35395 .5056 m .35236 .50406 L .35493 .50331 L F
.49851 .50676 m .49969 .50445 L .50115 .50601 L 0 .028 .127 r
F
.49851 .50676 m .49705 .50519 L .49969 .50445 L F
.38502 .50631 m .38604 .50411 L .38761 .50557 L 0 .027 .126 r
F
.38502 .50631 m .38346 .50485 L .38604 .50411 L F
.67006 .5065 m .67148 .50408 L .67279 .50566 L 0 .027 .127 r
F
.67006 .5065 m .66875 .50494 L .67148 .50408 L F
.62549 .50673 m .62684 .50425 L .62819 .50582 L 0 .028 .127 r
F
.62549 .50673 m .62414 .50516 L .62684 .50425 L F
.46742 .50637 m .46856 .50409 L .47005 .5055 L 0 .027 .127 r
F
.46742 .50637 m .46593 .50495 L .46856 .50409 L F
.46068 .50676 m .46181 .50443 L .4633 .50586 L 0 .028 .128 r
F
.46068 .50676 m .45918 .50533 L .46181 .50443 L F
.54308 .50676 m .54433 .50454 L .54575 .50601 L F
.54308 .50676 m .54166 .50531 L .54433 .50454 L F
.58766 .50663 m .58896 .50419 L .59035 .50575 L 0 .028 .127 r
F
.58766 .50663 m .58628 .50506 L .58896 .50419 L F
.67682 .50627 m .67825 .504 L .67954 .50543 L 0 .027 .126 r
F
.67682 .50627 m .67552 .50483 L .67825 .504 L F
.42959 .5063 m .43068 .504 L .4322 .50558 L 0 .027 .127 r
F
.42959 .5063 m .42807 .50473 L .43068 .504 L F
.63224 .50649 m .6336 .50402 L .63494 .50558 L F
.63224 .50649 m .63089 .50492 L .6336 .50402 L F
.59441 .50633 m .59572 .50399 L .5971 .50546 L F
.59441 .50633 m .59303 .50486 L .59572 .50399 L F
.47417 .50616 m .47532 .50382 L .4768 .50531 L 0 .027 .126 r
F
.47417 .50616 m .47268 .50466 L .47532 .50382 L F
.3161 .50579 m .31703 .50336 L .31866 .50492 L 0 .026 .125 r
F
.3161 .50579 m .31448 .50421 L .31703 .50336 L F
.63899 .50619 m .64037 .50389 L .6417 .5054 L 0 .027 .126 r
F
.63899 .50619 m .63765 .50468 L .64037 .50389 L F
.68357 .506 m .68501 .50375 L .6863 .50515 L F
.68357 .506 m .68228 .50459 L .68501 .50375 L F
.39176 .5062 m .39279 .50385 L .39435 .50532 L F
.39176 .5062 m .3902 .50471 L .39279 .50385 L F
.36067 .50564 m .36167 .50328 L .36325 .50481 L 0 .026 .125 r
F
.36067 .50564 m .35909 .50413 L .36167 .50328 L F
.50525 .50678 m .50644 .50459 L .5079 .5061 L 0 .029 .128 r
F
.50525 .50678 m .5038 .50526 L .50644 .50459 L F
.60116 .50604 m .60248 .50374 L .60385 .50519 L 0 .027 .126 r
F
.60116 .50604 m .59979 .50459 L .60248 .50374 L F
.69032 .50577 m .69177 .50343 L .69306 .5049 L 0 .026 .125 r
F
.69032 .50577 m .68903 .50429 L .69177 .50343 L F
.3985 .50596 m .39954 .50376 L .40109 .5052 L 0 .027 .126 r
F
.3985 .50596 m .39695 .5045 L .39954 .50376 L F
.32283 .50561 m .32378 .50322 L .32539 .50476 L 0 .026 .125 r
F
.32283 .50561 m .32122 .50405 L .32378 .50322 L F
.54983 .50675 m .55109 .50437 L .5525 .50586 L 0 .028 .128 r
F
.54983 .50675 m .54842 .50526 L .55109 .50437 L F
.55658 .50639 m .55784 .50406 L .55925 .5055 L 0 .028 .127 r
F
.55658 .50639 m .55517 .50495 L .55784 .50406 L F
.56333 .50602 m .5646 .50377 L .566 .50515 L 0 .027 .126 r
F
.56333 .50602 m .56193 .50463 L .5646 .50377 L F
.48091 .50607 m .48207 .50373 L .48355 .5053 L F
.48091 .50607 m .47943 .50451 L .48207 .50373 L F
.36741 .50551 m .36841 .50316 L .36999 .50473 L 0 .026 .125 r
F
.36741 .50551 m .36583 .50397 L .36841 .50316 L F
.57008 .50573 m .57136 .50358 L .57276 .50497 L 0 .027 .126 r
F
.57008 .50573 m .56868 .50434 L .57136 .50358 L F
.64575 .5061 m .64714 .50392 L .64846 .50535 L 0 .027 .127 r
F
.64575 .5061 m .64442 .50466 L .64714 .50392 L F
.43633 .50633 m .43743 .50388 L .43894 .50549 L F
.43633 .50633 m .43481 .50474 L .43743 .50388 L F
.60791 .50595 m .60925 .50371 L .61061 .50522 L 0 .027 .126 r
F
.60791 .50595 m .60655 .50445 L .60925 .50371 L F
.69708 .50565 m .69854 .50334 L .69983 .50489 L 0 .026 .125 r
F
.69708 .50565 m .6958 .50412 L .69854 .50334 L F
.40524 .50587 m .40629 .50358 L .40784 .50501 L 0 .027 .126 r
F
.40524 .50587 m .40369 .50444 L .40629 .50358 L F
.32957 .50551 m .33052 .50315 L .33213 .50469 L 0 .026 .125 r
F
.32957 .50551 m .32795 .50396 L .33052 .50315 L F
.512 .50683 m .5132 .50465 L .51465 .50605 L 0 .029 .129 r
F
.512 .50683 m .51055 .50542 L .5132 .50465 L F
.44307 .50616 m .44417 .50396 L .44569 .50541 L 0 .028 .127 r
F
.44307 .50616 m .44156 .50469 L .44417 .50396 L F
.51875 .50656 m .51996 .50428 L .5214 .50568 L 0 .029 .128 r
F
.51875 .50656 m .5173 .50516 L .51996 .50428 L F
.65251 .50602 m .65391 .50385 L .65523 .50526 L 0 .028 .127 r
F
.65251 .50602 m .65118 .5046 L .65391 .50385 L F
.41198 .5057 m .41305 .50326 L .41458 .50484 L 0 .026 .126 r
F
.41198 .5057 m .41044 .50413 L .41305 .50326 L F
.48766 .5061 m .48883 .50366 L .4903 .50525 L 0 .027 .127 r
F
.48766 .5061 m .48618 .50451 L .48883 .50366 L F
.5255 .5063 m .52671 .50389 L .52815 .50539 L 0 .028 .127 r
F
.5255 .5063 m .52406 .50479 L .52671 .50389 L F
.37414 .50556 m .37515 .5033 L .37672 .50484 L 0 .026 .126 r
F
.37414 .50556 m .37257 .50401 L .37515 .5033 L F
.3363 .50539 m .33726 .50302 L .33887 .50455 L 0 .026 .125 r
F
.3363 .50539 m .33469 .50386 L .33726 .50302 L F
.57683 .50579 m .57812 .50343 L .57952 .50502 L 0 .027 .126 r
F
.57683 .50579 m .57544 .50421 L .57812 .50343 L F
.61467 .506 m .61602 .50373 L .61738 .50526 L 0 .028 .127 r
F
.61467 .506 m .61331 .50448 L .61602 .50373 L F
.53224 .50604 m .53347 .50378 L .53491 .5053 L F
.53224 .50604 m .53081 .50452 L .53347 .50378 L F
.70385 .50569 m .70532 .50338 L .7066 .50495 L 0 .027 .126 r
F
.70385 .50569 m .70257 .50413 L .70532 .50338 L F
.44981 .50608 m .45093 .50393 L .45243 .50535 L 0 .028 .128 r
F
.44981 .50608 m .44831 .50466 L .45093 .50393 L F
.41872 .50556 m .4198 .50314 L .42133 .50471 L 0 .026 .126 r
F
.41872 .50556 m .41719 .50399 L .4198 .50314 L F
.34304 .5052 m .34401 .50277 L .34561 .50428 L 0 .026 .125 r
F
.34304 .5052 m .34144 .50369 L .34401 .50277 L F
.4944 .50596 m .49558 .50362 L .49705 .50519 L 0 .027 .127 r
F
.4944 .50596 m .49294 .5044 L .49558 .50362 L F
.65927 .50597 m .66067 .50354 L .66199 .50509 L F
.65927 .50597 m .65795 .50444 L .66067 .50354 L F
.34979 .50488 m .35076 .50252 L .35236 .50406 L 0 .025 .124 r
F
.34979 .50488 m .34819 .50336 L .35076 .50252 L F
.38087 .50558 m .38189 .50338 L .38346 .50485 L 0 .027 .126 r
F
.38087 .50558 m .3793 .50411 L .38189 .50338 L F
.66603 .5058 m .66744 .50334 L .66875 .50494 L 0 .027 .127 r
F
.66603 .5058 m .66471 .50421 L .66744 .50334 L F
.42546 .50547 m .42654 .50317 L .42807 .50473 L 0 .027 .126 r
F
.42546 .50547 m .42393 .50391 L .42654 .50317 L F
.62143 .50606 m .62278 .50362 L .62414 .50516 L 0 .028 .127 r
F
.62143 .50606 m .62008 .50452 L .62278 .50362 L F
.58359 .50587 m .58489 .50345 L .58628 .50506 L 0 .027 .127 r
F
.58359 .50587 m .5822 .50426 L .58489 .50345 L F
.539 .50606 m .54023 .5038 L .54166 .50531 L 0 .028 .128 r
F
.539 .50606 m .53757 .50456 L .54023 .5038 L F
.45656 .50606 m .45768 .5039 L .45918 .50533 L F
.45656 .50606 m .45505 .50463 L .45768 .5039 L F
.35652 .50486 m .3575 .50256 L .35909 .50413 L 0 .026 .124 r
F
.35652 .50486 m .35493 .50331 L .3575 .50256 L F
.62819 .50582 m .62955 .50335 L .63089 .50492 L 0 .027 .127 r
F
.62819 .50582 m .62684 .50425 L .62955 .50335 L F
.50115 .50601 m .50234 .50371 L .5038 .50526 L 0 .028 .128 r
F
.50115 .50601 m .49969 .50445 L .50234 .50371 L F
.67279 .50566 m .67421 .50324 L .67552 .50483 L 0 .027 .127 r
F
.67279 .50566 m .67148 .50408 L .67421 .50324 L F
.4633 .50586 m .46444 .50353 L .46593 .50495 L 0 .028 .127 r
F
.4633 .50586 m .46181 .50443 L .46444 .50353 L F
.47005 .5055 m .47119 .50327 L .47268 .50466 L 0 .027 .126 r
F
.47005 .5055 m .46856 .50409 L .47119 .50327 L F
.59035 .50575 m .59165 .50331 L .59303 .50486 L 0 .027 .127 r
F
.59035 .50575 m .58896 .50419 L .59165 .50331 L F
.38761 .50557 m .38863 .50326 L .3902 .50471 L F
.38761 .50557 m .38604 .50411 L .38863 .50326 L F
.63494 .50558 m .63631 .50312 L .63765 .50468 L 0 .027 .126 r
F
.63494 .50558 m .6336 .50402 L .63631 .50312 L F
.67954 .50543 m .68098 .50317 L .68228 .50459 L F
.67954 .50543 m .67825 .504 L .68098 .50317 L F
.54575 .50601 m .547 .50377 L .54842 .50526 L 0 .028 .128 r
F
.54575 .50601 m .54433 .50454 L .547 .50377 L F
.5971 .50546 m .59842 .50314 L .59979 .50459 L 0 .027 .126 r
F
.5971 .50546 m .59572 .50399 L .59842 .50314 L F
.31866 .50492 m .31959 .5025 L .32122 .50405 L 0 .026 .125 r
F
.31866 .50492 m .31703 .50336 L .31959 .5025 L F
.4768 .50531 m .47795 .50301 L .47943 .50451 L 0 .027 .126 r
F
.4768 .50531 m .47532 .50382 L .47795 .50301 L F
.39435 .50532 m .39539 .50305 L .39695 .5045 L F
.39435 .50532 m .39279 .50385 L .39539 .50305 L F
.6863 .50515 m .68775 .5029 L .68903 .50429 L F
.6863 .50515 m .68501 .50375 L .68775 .5029 L F
.36325 .50481 m .36425 .50242 L .36583 .50397 L 0 .026 .125 r
F
.36325 .50481 m .36167 .50328 L .36425 .50242 L F
.60385 .50519 m .60518 .50298 L .60655 .50445 L 0 .027 .126 r
F
.60385 .50519 m .60248 .50374 L .60518 .50298 L F
.4322 .50558 m .43329 .50314 L .43481 .50474 L 0 .027 .127 r
F
.4322 .50558 m .43068 .504 L .43329 .50314 L F
.6417 .5054 m .64309 .50315 L .64442 .50466 L F
.6417 .5054 m .64037 .50389 L .64309 .50315 L F
.69306 .5049 m .69451 .50264 L .6958 .50412 L 0 .026 .125 r
F
.69306 .5049 m .69177 .50343 L .69451 .50264 L F
.5525 .50586 m .55376 .50347 L .55517 .50495 L 0 .028 .128 r
F
.5525 .50586 m .55109 .50437 L .55376 .50347 L F
.55925 .5055 m .56052 .50321 L .56193 .50463 L 0 .027 .127 r
F
.55925 .5055 m .55784 .50406 L .56052 .50321 L F
.32539 .50476 m .32634 .50243 L .32795 .50396 L 0 .026 .125 r
F
.32539 .50476 m .32378 .50322 L .32634 .50243 L F
.566 .50515 m .56728 .50296 L .56868 .50434 L 0 .027 .126 r
F
.566 .50515 m .5646 .50377 L .56728 .50296 L F
.5079 .5061 m .50909 .50391 L .51055 .50542 L 0 .029 .129 r
F
.5079 .5061 m .50644 .50459 L .50909 .50391 L F
.40109 .5052 m .40214 .50302 L .40369 .50444 L 0 .027 .126 r
F
.40109 .5052 m .39954 .50376 L .40214 .50302 L F
.36999 .50473 m .37099 .50244 L .37257 .50401 L 0 .026 .125 r
F
.36999 .50473 m .36841 .50316 L .37099 .50244 L F
.43894 .50549 m .44005 .50308 L .44156 .50469 L 0 .027 .127 r
F
.43894 .50549 m .43743 .50388 L .44005 .50308 L F
.48355 .5053 m .48471 .50292 L .48618 .50451 L 0 .027 .126 r
F
.48355 .5053 m .48207 .50373 L .48471 .50292 L F
.57276 .50497 m .57405 .50281 L .57544 .50421 L F
.57276 .50497 m .57136 .50358 L .57405 .50281 L F
.64846 .50535 m .64986 .50317 L .65118 .5046 L 0 .028 .127 r
F
.64846 .50535 m .64714 .50392 L .64986 .50317 L F
.40784 .50501 m .4089 .50269 L .41044 .50413 L 0 .027 .126 r
F
.40784 .50501 m .40629 .50358 L .4089 .50269 L F
.61061 .50522 m .61195 .50296 L .61331 .50448 L 0 .027 .127 r
F
.61061 .50522 m .60925 .50371 L .61195 .50296 L F
.33213 .50469 m .33308 .50233 L .33469 .50386 L 0 .026 .125 r
F
.33213 .50469 m .33052 .50315 L .33308 .50233 L F
.69983 .50489 m .70129 .50256 L .70257 .50413 L 0 .026 .126 r
F
.69983 .50489 m .69854 .50334 L .70129 .50256 L F
.51465 .50605 m .51585 .50376 L .5173 .50516 L 0 .029 .129 r
F
.51465 .50605 m .5132 .50465 L .51585 .50376 L F
.5214 .50568 m .52261 .50339 L .52406 .50479 L 0 .028 .128 r
F
.5214 .50568 m .51996 .50428 L .52261 .50339 L F
.52815 .50539 m .52938 .50302 L .53081 .50452 L 0 .028 .127 r
F
.52815 .50539 m .52671 .50389 L .52938 .50302 L F
.41458 .50484 m .41565 .50241 L .41719 .50399 L 0 .026 .125 r
F
.41458 .50484 m .41305 .50326 L .41565 .50241 L F
.44569 .50541 m .44679 .50322 L .44831 .50466 L 0 .028 .128 r
F
.44569 .50541 m .44417 .50396 L .44679 .50322 L F
.4903 .50525 m .49147 .5028 L .49294 .5044 L 0 .027 .127 r
F
.4903 .50525 m .48883 .50366 L .49147 .5028 L F
.65523 .50526 m .65663 .50302 L .65795 .50444 L 0 .028 .127 r
F
.65523 .50526 m .65391 .50385 L .65663 .50302 L F
.33887 .50455 m .33983 .50217 L .34144 .50369 L 0 .026 .125 r
F
.33887 .50455 m .33726 .50302 L .33983 .50217 L F
.57952 .50502 m .58081 .50265 L .5822 .50426 L 0 .027 .126 r
F
.57952 .50502 m .57812 .50343 L .58081 .50265 L F
.34561 .50428 m .34659 .50185 L .34819 .50336 L 0 .025 .124 r
F
.34561 .50428 m .34401 .50277 L .34659 .50185 L F
.37672 .50484 m .37773 .50257 L .3793 .50411 L 0 .027 .126 r
F
.37672 .50484 m .37515 .5033 L .37773 .50257 L F
.61738 .50526 m .61872 .50298 L .62008 .50452 L 0 .028 .127 r
F
.61738 .50526 m .61602 .50373 L .61872 .50298 L F
.42133 .50471 m .4224 .50235 L .42393 .50391 L 0 .026 .126 r
F
.42133 .50471 m .4198 .50314 L .4224 .50235 L F
.66199 .50509 m .66339 .50265 L .66471 .50421 L 0 .027 .127 r
F
.66199 .50509 m .66067 .50354 L .66339 .50265 L F
.53491 .5053 m .53614 .50304 L .53757 .50456 L 0 .028 .128 r
F
.53491 .5053 m .53347 .50378 L .53614 .50304 L F
.7066 .50495 m .70807 .50262 L .70935 .50421 L 0 .027 .126 r
F
.7066 .50495 m .70532 .50338 L .70807 .50262 L F
.45243 .50535 m .45355 .50321 L .45505 .50463 L 0 .028 .128 r
F
.45243 .50535 m .45093 .50393 L .45355 .50321 L F
.35236 .50406 m .35334 .50176 L .35493 .50331 L 0 .025 .124 r
F
.35236 .50406 m .35076 .50252 L .35334 .50176 L F
.49705 .50519 m .49823 .50288 L .49969 .50445 L 0 .028 .127 r
F
.49705 .50519 m .49558 .50362 L .49823 .50288 L F
.66875 .50494 m .67016 .50246 L .67148 .50408 L 0 .027 .126 r
F
.66875 .50494 m .66744 .50334 L .67016 .50246 L F
.62414 .50516 m .62549 .50273 L .62684 .50425 L 0 .028 .127 r
F
.62414 .50516 m .62278 .50362 L .62549 .50273 L F
.38346 .50485 m .38447 .50264 L .38604 .50411 L 0 .027 .127 r
F
.38346 .50485 m .38189 .50338 L .38447 .50264 L F
.58628 .50506 m .58758 .50258 L .58896 .50419 L F
.58628 .50506 m .58489 .50345 L .58758 .50258 L F
.63089 .50492 m .63226 .50245 L .6336 .50402 L F
.63089 .50492 m .62955 .50335 L .63226 .50245 L F
.42807 .50473 m .42915 .50242 L .43068 .504 L 0 .027 .126 r
F
.42807 .50473 m .42654 .50317 L .42915 .50242 L F
.54166 .50531 m .5429 .50302 L .54433 .50454 L 0 .028 .128 r
F
.54166 .50531 m .54023 .5038 L .5429 .50302 L F
.46593 .50495 m .46707 .50267 L .46856 .50409 L 0 .028 .127 r
F
.46593 .50495 m .46444 .50353 L .46707 .50267 L F
.45918 .50533 m .46031 .50299 L .46181 .50443 L 0 .028 .128 r
F
.45918 .50533 m .45768 .5039 L .46031 .50299 L F
.31448 .50421 m .31541 .5018 L .31703 .50336 L 0 .026 .125 r
F
.31448 .50421 m .31285 .50265 L .31541 .5018 L F
.67552 .50483 m .67694 .50243 L .67825 .504 L 0 .027 .127 r
F
.67552 .50483 m .67421 .50324 L .67694 .50243 L F
.47268 .50466 m .47383 .50245 L .47532 .50382 L 0 .027 .126 r
F
.47268 .50466 m .47119 .50327 L .47383 .50245 L F
.59303 .50486 m .59435 .50246 L .59572 .50399 L 0 .027 .127 r
F
.59303 .50486 m .59165 .50331 L .59435 .50246 L F
.63765 .50468 m .63903 .50233 L .64037 .50389 L 0 .027 .126 r
F
.63765 .50468 m .63631 .50312 L .63903 .50233 L F
.35909 .50413 m .36008 .5017 L .36167 .50328 L 0 .026 .125 r
F
.35909 .50413 m .3575 .50256 L .36008 .5017 L F
.5038 .50526 m .50499 .50302 L .50644 .50459 L 0 .029 .128 r
F
.5038 .50526 m .50234 .50371 L .50499 .50302 L F
.3902 .50471 m .39123 .50242 L .39279 .50385 L 0 .027 .127 r
F
.3902 .50471 m .38863 .50326 L .39123 .50242 L F
.59979 .50459 m .60111 .50229 L .60248 .50374 L 0 .027 .126 r
F
.59979 .50459 m .59842 .50314 L .60111 .50229 L F
.68228 .50459 m .68372 .50235 L .68501 .50375 L F
.68228 .50459 m .68098 .50317 L .68372 .50235 L F
.32122 .50405 m .32216 .50168 L .32378 .50322 L 0 .026 .125 r
F
.32122 .50405 m .31959 .5025 L .32216 .50168 L F
.68903 .50429 m .69049 .50206 L .69177 .50343 L 0 .027 .126 r
F
.68903 .50429 m .68775 .5029 L .69049 .50206 L F
.39695 .5045 m .39798 .50233 L .39954 .50376 L F
.39695 .5045 m .39539 .50305 L .39798 .50233 L F
.54842 .50526 m .54967 .50288 L .55109 .50437 L 0 .028 .128 r
F
.54842 .50526 m .547 .50377 L .54967 .50288 L F
.47943 .50451 m .48059 .50221 L .48207 .50373 L 0 .027 .126 r
F
.47943 .50451 m .47795 .50301 L .48059 .50221 L F
.36583 .50397 m .36683 .5016 L .36841 .50316 L 0 .026 .125 r
F
.36583 .50397 m .36425 .50242 L .36683 .5016 L F
.43481 .50474 m .43591 .50228 L .43743 .50388 L 0 .027 .127 r
F
.43481 .50474 m .43329 .50314 L .43591 .50228 L F
.55517 .50495 m .55643 .50258 L .55784 .50406 L 0 .028 .127 r
F
.55517 .50495 m .55376 .50347 L .55643 .50258 L F
.56193 .50463 m .5632 .50235 L .5646 .50377 L 0 .027 .127 r
F
.56193 .50463 m .56052 .50321 L .5632 .50235 L F
.60655 .50445 m .60788 .50222 L .60925 .50371 L 0 .027 .126 r
F
.60655 .50445 m .60518 .50298 L .60788 .50222 L F
.64442 .50466 m .64581 .50241 L .64714 .50392 L 0 .028 .127 r
F
.64442 .50466 m .64309 .50315 L .64581 .50241 L F
.6958 .50412 m .69726 .50184 L .69854 .50334 L 0 .026 .125 r
F
.6958 .50412 m .69451 .50264 L .69726 .50184 L F
.32795 .50396 m .3289 .50165 L .33052 .50315 L F
.32795 .50396 m .32634 .50243 L .3289 .50165 L F
.56868 .50434 m .56996 .50219 L .57136 .50358 L 0 .027 .126 r
F
.56868 .50434 m .56728 .50296 L .56996 .50219 L F
.40369 .50444 m .40474 .50216 L .40629 .50358 L 0 .027 .127 r
F
.40369 .50444 m .40214 .50302 L .40474 .50216 L F
.51055 .50542 m .51175 .50314 L .5132 .50465 L 0 .029 .129 r
F
.51055 .50542 m .50909 .50391 L .51175 .50314 L F
.44156 .50469 m .44266 .50235 L .44417 .50396 L 0 .028 .127 r
F
.44156 .50469 m .44005 .50308 L .44266 .50235 L F
.41044 .50413 m .4115 .50181 L .41305 .50326 L 0 .027 .126 r
F
.41044 .50413 m .4089 .50269 L .4115 .50181 L F
.48618 .50451 m .48735 .50206 L .48883 .50366 L F
.48618 .50451 m .48471 .50292 L .48735 .50206 L F
.37257 .50401 m .37357 .50172 L .37515 .5033 L 0 .026 .125 r
F
.37257 .50401 m .37099 .50244 L .37357 .50172 L F
.57544 .50421 m .57673 .50201 L .57812 .50343 L 0 .027 .126 r
F
.57544 .50421 m .57405 .50281 L .57673 .50201 L F
.52406 .50479 m .52528 .50251 L .52671 .50389 L 0 .028 .128 r
F
.52406 .50479 m .52261 .50339 L .52528 .50251 L F
.65118 .5046 m .65259 .50243 L .65391 .50385 L 0 .028 .127 r
F
.65118 .5046 m .64986 .50317 L .65259 .50243 L F
.5173 .50516 m .51851 .50287 L .51996 .50428 L 0 .029 .129 r
F
.5173 .50516 m .51585 .50376 L .51851 .50287 L F
.33469 .50386 m .33565 .50149 L .33726 .50302 L 0 .026 .125 r
F
.33469 .50386 m .33308 .50233 L .33565 .50149 L F
.61331 .50448 m .61466 .5022 L .61602 .50373 L 0 .028 .127 r
F
.61331 .50448 m .61195 .50296 L .61466 .5022 L F
.70257 .50413 m .70404 .50179 L .70532 .50338 L 0 .027 .126 r
F
.70257 .50413 m .70129 .50256 L .70404 .50179 L F
.53081 .50452 m .53204 .50229 L .53347 .50378 L 0 .028 .127 r
F
.53081 .50452 m .52938 .50302 L .53204 .50229 L F
.41719 .50399 m .41826 .50157 L .4198 .50314 L 0 .026 .125 r
F
.41719 .50399 m .41565 .50241 L .41826 .50157 L F
.49294 .5044 m .49411 .50202 L .49558 .50362 L 0 .027 .127 r
F
.49294 .5044 m .49147 .5028 L .49411 .50202 L F
.65795 .50444 m .65935 .50211 L .66067 .50354 L 0 .028 .127 r
F
.65795 .50444 m .65663 .50302 L .65935 .50211 L F
.34144 .50369 m .34241 .50127 L .34401 .50277 L 0 .026 .125 r
F
.34144 .50369 m .33983 .50217 L .34241 .50127 L F
.44831 .50466 m .44942 .50249 L .45093 .50393 L 0 .028 .128 r
F
.44831 .50466 m .44679 .50322 L .44942 .50249 L F
.34819 .50336 m .34916 .50101 L .35076 .50252 L 0 .025 .124 r
F
.34819 .50336 m .34659 .50185 L .34916 .50101 L F
.66471 .50421 m .66612 .50175 L .66744 .50334 L 0 .027 .126 r
F
.66471 .50421 m .66339 .50265 L .66612 .50175 L F
.5822 .50426 m .5835 .50183 L .58489 .50345 L 0 .027 .127 r
F
.5822 .50426 m .58081 .50265 L .5835 .50183 L F
.42393 .50391 m .42501 .5016 L .42654 .50317 L 0 .027 .126 r
F
.42393 .50391 m .4224 .50235 L .42501 .5016 L F
.3793 .50411 m .38032 .50182 L .38189 .50338 L F
.3793 .50411 m .37773 .50257 L .38032 .50182 L F
.62008 .50452 m .62143 .50209 L .62278 .50362 L 0 .028 .127 r
F
.62008 .50452 m .61872 .50298 L .62143 .50209 L F
.53757 .50456 m .53881 .50228 L .54023 .5038 L 0 .028 .128 r
F
.53757 .50456 m .53614 .50304 L .53881 .50228 L F
.70935 .50421 m .71082 .50174 L .7121 .50333 L 0 .027 .126 r
F
.70935 .50421 m .70807 .50262 L .71082 .50174 L F
.35493 .50331 m .35591 .501 L .3575 .50256 L 0 .026 .124 r
F
.35493 .50331 m .35334 .50176 L .35591 .501 L F
.62684 .50425 m .6282 .50183 L .62955 .50335 L 0 .027 .127 r
F
.62684 .50425 m .62549 .50273 L .6282 .50183 L F
.45505 .50463 m .45617 .50246 L .45768 .5039 L 0 .029 .128 r
F
.45505 .50463 m .45355 .50321 L .45617 .50246 L F
.49969 .50445 m .50087 .50215 L .50234 .50371 L 0 .028 .128 r
F
.49969 .50445 m .49823 .50288 L .50087 .50215 L F
.67148 .50408 m .67289 .50161 L .67421 .50324 L 0 .027 .126 r
F
.67148 .50408 m .67016 .50246 L .67289 .50161 L F
.58896 .50419 m .59027 .50172 L .59165 .50331 L 0 .027 .127 r
F
.58896 .50419 m .58758 .50258 L .59027 .50172 L F
.6336 .50402 m .63497 .50155 L .63631 .50312 L 0 .027 .126 r
F
.6336 .50402 m .63226 .50245 L .63497 .50155 L F
.46181 .50443 m .46294 .50209 L .46444 .50353 L 0 .028 .128 r
F
.46181 .50443 m .46031 .50299 L .46294 .50209 L F
.46856 .50409 m .4697 .50187 L .47119 .50327 L 0 .028 .127 r
F
.46856 .50409 m .46707 .50267 L .4697 .50187 L F
.38604 .50411 m .38707 .50181 L .38863 .50326 L F
.38604 .50411 m .38447 .50264 L .38707 .50181 L F
.31703 .50336 m .31797 .50096 L .31959 .5025 L 0 .026 .125 r
F
.31703 .50336 m .31541 .5018 L .31797 .50096 L F
.54433 .50454 m .54557 .50224 L .547 .50377 L 0 .029 .128 r
F
.54433 .50454 m .5429 .50302 L .54557 .50224 L F
.59572 .50399 m .59704 .50161 L .59842 .50314 L 0 .027 .127 r
F
.59572 .50399 m .59435 .50246 L .59704 .50161 L F
.43068 .504 m .43177 .50156 L .43329 .50314 L 0 .027 .126 r
F
.43068 .504 m .42915 .50242 L .43177 .50156 L F
.67825 .504 m .67968 .50162 L .68098 .50317 L 0 .027 .127 r
F
.67825 .504 m .67694 .50243 L .67968 .50162 L F
.47532 .50382 m .47647 .50163 L .47795 .50301 L F
.47532 .50382 m .47383 .50245 L .47647 .50163 L F
.36167 .50328 m .36267 .50082 L .36425 .50242 L 0 .026 .124 r
F
.36167 .50328 m .36008 .5017 L .36267 .50082 L F
.39279 .50385 m .39383 .50162 L .39539 .50305 L 0 .027 .127 r
F
.39279 .50385 m .39123 .50242 L .39383 .50162 L F
.64037 .50389 m .64175 .50158 L .64309 .50315 L F
.64037 .50389 m .63903 .50233 L .64175 .50158 L F
.60248 .50374 m .60381 .50151 L .60518 .50298 L 0 .027 .126 r
F
.60248 .50374 m .60111 .50229 L .60381 .50151 L F
.68501 .50375 m .68646 .50151 L .68775 .5029 L F
.68501 .50375 m .68372 .50235 L .68646 .50151 L F
.32378 .50322 m .32472 .50091 L .32634 .50243 L 0 .026 .125 r
F
.32378 .50322 m .32216 .50168 L .32472 .50091 L F
.69177 .50343 m .69323 .50125 L .69451 .50264 L 0 .027 .126 r
F
.69177 .50343 m .69049 .50206 L .69323 .50125 L F
.55109 .50437 m .55234 .50198 L .55376 .50347 L 0 .028 .128 r
F
.55109 .50437 m .54967 .50288 L .55234 .50198 L F
.50644 .50459 m .50764 .50232 L .50909 .50391 L 0 .029 .129 r
F
.50644 .50459 m .50499 .50302 L .50764 .50232 L F
.55784 .50406 m .55911 .50174 L .56052 .50321 L 0 .028 .127 r
F
.55784 .50406 m .55643 .50258 L .55911 .50174 L F
.43743 .50388 m .43853 .50147 L .44005 .50308 L 0 .027 .127 r
F
.43743 .50388 m .43591 .50228 L .43853 .50147 L F
.36841 .50316 m .36941 .50086 L .37099 .50244 L 0 .026 .125 r
F
.36841 .50316 m .36683 .5016 L .36941 .50086 L F
.48207 .50373 m .48323 .50139 L .48471 .50292 L 0 .027 .126 r
F
.48207 .50373 m .48059 .50221 L .48323 .50139 L F
.39954 .50376 m .40058 .5016 L .40214 .50302 L 0 .027 .127 r
F
.39954 .50376 m .39798 .50233 L .40058 .5016 L F
.5646 .50377 m .56588 .50154 L .56728 .50296 L F
.5646 .50377 m .5632 .50235 L .56588 .50154 L F
.60925 .50371 m .61059 .50145 L .61195 .50296 L F
.60925 .50371 m .60788 .50222 L .61059 .50145 L F
.69854 .50334 m .7 .50105 L .70129 .50256 L 0 .026 .126 r
F
.69854 .50334 m .69726 .50184 L .7 .50105 L F
.33052 .50315 m .33147 .50083 L .33308 .50233 L 0 .026 .125 r
F
.33052 .50315 m .3289 .50165 L .33147 .50083 L F
.64714 .50392 m .64853 .50167 L .64986 .50317 L 0 .028 .127 r
F
.64714 .50392 m .64581 .50241 L .64853 .50167 L F
.40629 .50358 m .40735 .50126 L .4089 .50269 L 0 .027 .126 r
F
.40629 .50358 m .40474 .50216 L .40735 .50126 L F
.57136 .50358 m .57265 .50141 L .57405 .50281 L 0 .027 .127 r
F
.57136 .50358 m .56996 .50219 L .57265 .50141 L F
.41305 .50326 m .41411 .50097 L .41565 .50241 L 0 .026 .126 r
F
.41305 .50326 m .4115 .50181 L .41411 .50097 L F
.48883 .50366 m .49 .50119 L .49147 .5028 L 0 .027 .126 r
F
.48883 .50366 m .48735 .50206 L .49 .50119 L F
.52671 .50389 m .52794 .50165 L .52938 .50302 L 0 .028 .128 r
F
.52671 .50389 m .52528 .50251 L .52794 .50165 L F
.51996 .50428 m .52117 .50199 L .52261 .50339 L 0 .029 .129 r
F
.51996 .50428 m .51851 .50287 L .52117 .50199 L F
.5132 .50465 m .5144 .50225 L .51585 .50376 L F
.5132 .50465 m .51175 .50314 L .5144 .50225 L F
.44417 .50396 m .44528 .50162 L .44679 .50322 L 0 .028 .128 r
F
.44417 .50396 m .44266 .50235 L .44528 .50162 L F
.33726 .50302 m .33822 .50065 L .33983 .50217 L 0 .026 .125 r
F
.33726 .50302 m .33565 .50149 L .33822 .50065 L F
.57812 .50343 m .57942 .5012 L .58081 .50265 L 0 .027 .126 r
F
.57812 .50343 m .57673 .50201 L .57942 .5012 L F
.65391 .50385 m .65531 .5016 L .65663 .50302 L 0 .028 .128 r
F
.65391 .50385 m .65259 .50243 L .65531 .5016 L F
.37515 .5033 m .37616 .50097 L .37773 .50257 L 0 .027 .126 r
F
.37515 .5033 m .37357 .50172 L .37616 .50097 L F
.4198 .50314 m .42087 .50077 L .4224 .50235 L 0 .026 .125 r
F
.4198 .50314 m .41826 .50157 L .42087 .50077 L F
.34401 .50277 m .34498 .50037 L .34659 .50185 L 0 .025 .124 r
F
.34401 .50277 m .34241 .50127 L .34498 .50037 L F
.61602 .50373 m .61737 .50144 L .61872 .50298 L 0 .028 .127 r
F
.61602 .50373 m .61466 .5022 L .61737 .50144 L F
.66067 .50354 m .66208 .50121 L .66339 .50265 L 0 .027 .127 r
F
.66067 .50354 m .65935 .50211 L .66208 .50121 L F
.70532 .50338 m .70679 .50103 L .70807 .50262 L 0 .027 .126 r
F
.70532 .50338 m .70404 .50179 L .70679 .50103 L F
.53347 .50378 m .53471 .50155 L .53614 .50304 L 0 .028 .128 r
F
.53347 .50378 m .53204 .50229 L .53471 .50155 L F
.49558 .50362 m .49676 .5013 L .49823 .50288 L 0 .028 .127 r
F
.49558 .50362 m .49411 .50202 L .49676 .5013 L F
.35076 .50252 m .35174 .50024 L .35334 .50176 L 0 .025 .124 r
F
.35076 .50252 m .34916 .50101 L .35174 .50024 L F
.66744 .50334 m .66885 .50086 L .67016 .50246 L 0 .027 .126 r
F
.66744 .50334 m .66612 .50175 L .66885 .50086 L F
.45093 .50393 m .45204 .50176 L .45355 .50321 L 0 .029 .128 r
F
.45093 .50393 m .44942 .50249 L .45204 .50176 L F
.62278 .50362 m .62414 .5012 L .62549 .50273 L 0 .028 .127 r
F
.62278 .50362 m .62143 .50209 L .62414 .5012 L F
.58489 .50345 m .58619 .50098 L .58758 .50258 L 0 .027 .126 r
F
.58489 .50345 m .5835 .50183 L .58619 .50098 L F
.7121 .50333 m .71357 .50083 L .71485 .50242 L F
.7121 .50333 m .71082 .50174 L .71357 .50083 L F
.62955 .50335 m .63091 .50095 L .63226 .50245 L F
.62955 .50335 m .6282 .50183 L .63091 .50095 L F
.42654 .50317 m .42763 .50085 L .42915 .50242 L F
.42654 .50317 m .42501 .5016 L .42763 .50085 L F
.38189 .50338 m .38291 .50107 L .38447 .50264 L 0 .027 .127 r
F
.38189 .50338 m .38032 .50182 L .38291 .50107 L F
.31285 .50265 m .31378 .50032 L .31541 .5018 L 0 .026 .125 r
F
.31285 .50265 m .31121 .50119 L .31378 .50032 L F
.54023 .5038 m .54148 .50149 L .5429 .50302 L 0 .028 .128 r
F
.54023 .5038 m .53881 .50228 L .54148 .50149 L F
.67421 .50324 m .67563 .50081 L .67694 .50243 L 0 .027 .126 r
F
.67421 .50324 m .67289 .50161 L .67563 .50081 L F
.63631 .50312 m .63769 .50076 L .63903 .50233 L F
.63631 .50312 m .63497 .50155 L .63769 .50076 L F
.59165 .50331 m .59296 .50088 L .59435 .50246 L 0 .027 .127 r
F
.59165 .50331 m .59027 .50172 L .59296 .50088 L F
.3575 .50256 m .3585 .50012 L .36008 .5017 L 0 .026 .124 r
F
.3575 .50256 m .35591 .501 L .3585 .50012 L F
.50234 .50371 m .50352 .50144 L .50499 .50302 L 0 .028 .128 r
F
.50234 .50371 m .50087 .50215 L .50352 .50144 L F
.45768 .5039 m .4588 .50156 L .46031 .50299 L 0 .029 .128 r
F
.45768 .5039 m .45617 .50246 L .4588 .50156 L F
.46444 .50353 m .46557 .50124 L .46707 .50267 L 0 .028 .128 r
F
.46444 .50353 m .46294 .50209 L .46557 .50124 L F
.31959 .5025 m .32053 .50014 L .32216 .50168 L 0 .026 .125 r
F
.31959 .5025 m .31797 .50096 L .32053 .50014 L F
.38863 .50326 m .38966 .50098 L .39123 .50242 L 0 .027 .127 r
F
.38863 .50326 m .38707 .50181 L .38966 .50098 L F
.47119 .50327 m .47234 .50107 L .47383 .50245 L 0 .028 .127 r
F
.47119 .50327 m .4697 .50187 L .47234 .50107 L F
.59842 .50314 m .59974 .50078 L .60111 .50229 L 0 .027 .126 r
F
.59842 .50314 m .59704 .50161 L .59974 .50078 L F
.43329 .50314 m .43439 .50069 L .43591 .50228 L F
.43329 .50314 m .43177 .50156 L .43439 .50069 L F
.36425 .50242 m .36525 .49999 L .36683 .5016 L 0 .026 .124 r
F
.36425 .50242 m .36267 .50082 L .36525 .49999 L F
.68098 .50317 m .68242 .50081 L .68372 .50235 L 0 .027 .127 r
F
.68098 .50317 m .67968 .50162 L .68242 .50081 L F
.47795 .50301 m .47911 .50081 L .48059 .50221 L F
.47795 .50301 m .47647 .50163 L .47911 .50081 L F
.547 .50377 m .54825 .50137 L .54967 .50288 L 0 .029 .128 r
F
.547 .50377 m .54557 .50224 L .54825 .50137 L F
.39539 .50305 m .39642 .50089 L .39798 .50233 L 0 .027 .127 r
F
.39539 .50305 m .39383 .50162 L .39642 .50089 L F
.68775 .5029 m .6892 .50068 L .69049 .50206 L 0 .027 .126 r
F
.68775 .5029 m .68646 .50151 L .6892 .50068 L F
.55376 .50347 m .55502 .5011 L .55643 .50258 L 0 .028 .128 r
F
.55376 .50347 m .55234 .50198 L .55502 .5011 L F
.64309 .50315 m .64447 .50083 L .64581 .50241 L 0 .027 .127 r
F
.64309 .50315 m .64175 .50158 L .64447 .50083 L F
.60518 .50298 m .60652 .50073 L .60788 .50222 L F
.60518 .50298 m .60381 .50151 L .60652 .50073 L F
.32634 .50243 m .32728 .50015 L .3289 .50165 L 0 .026 .125 r
F
.32634 .50243 m .32472 .50091 L .32728 .50015 L F
.69451 .50264 m .69597 .50043 L .69726 .50184 L 0 .027 .126 r
F
.69451 .50264 m .69323 .50125 L .69597 .50043 L F
.56052 .50321 m .56179 .50089 L .5632 .50235 L 0 .028 .127 r
F
.56052 .50321 m .55911 .50174 L .56179 .50089 L F
.44005 .50308 m .44115 .50074 L .44266 .50235 L 0 .027 .127 r
F
.44005 .50308 m .43853 .50147 L .44115 .50074 L F
.48471 .50292 m .48588 .50052 L .48735 .50206 L 0 .027 .126 r
F
.48471 .50292 m .48323 .50139 L .48588 .50052 L F
.56728 .50296 m .56856 .50074 L .56996 .50219 L 0 .027 .127 r
F
.56728 .50296 m .56588 .50154 L .56856 .50074 L F
.50909 .50391 m .51029 .50155 L .51175 .50314 L 0 .029 .129 r
F
.50909 .50391 m .50764 .50232 L .51029 .50155 L F
.37099 .50244 m .372 .50013 L .37357 .50172 L 0 .026 .125 r
F
.37099 .50244 m .36941 .50086 L .372 .50013 L F
.40214 .50302 m .40318 .50073 L .40474 .50216 L 0 .028 .127 r
F
.40214 .50302 m .40058 .5016 L .40318 .50073 L F
.4089 .50269 m .40995 .50038 L .4115 .50181 L 0 .027 .126 r
F
.4089 .50269 m .40735 .50126 L .40995 .50038 L F
.33308 .50233 m .33404 .5 L .33565 .50149 L 0 .026 .125 r
F
.33308 .50233 m .33147 .50083 L .33404 .5 L F
.70129 .50256 m .70276 .50027 L .70404 .50179 L 0 .027 .126 r
F
.70129 .50256 m .7 .50105 L .70276 .50027 L F
.61195 .50296 m .61329 .50066 L .61466 .5022 L 0 .028 .127 r
F
.61195 .50296 m .61059 .50145 L .61329 .50066 L F
.41565 .50241 m .41672 .50014 L .41826 .50157 L 0 .026 .125 r
F
.41565 .50241 m .41411 .50097 L .41672 .50014 L F
.49147 .5028 m .49264 .50042 L .49411 .50202 L 0 .027 .126 r
F
.49147 .5028 m .49 .50119 L .49264 .50042 L F
.64986 .50317 m .65126 .50092 L .65259 .50243 L 0 .028 .128 r
F
.64986 .50317 m .64853 .50167 L .65126 .50092 L F
.57405 .50281 m .57534 .50058 L .57673 .50201 L 0 .027 .127 r
F
.57405 .50281 m .57265 .50141 L .57534 .50058 L F
.51585 .50376 m .51706 .50136 L .51851 .50287 L 0 .029 .129 r
F
.51585 .50376 m .5144 .50225 L .51706 .50136 L F
.52261 .50339 m .52383 .50112 L .52528 .50251 L 0 .029 .128 r
F
.52261 .50339 m .52117 .50199 L .52383 .50112 L F
.52938 .50302 m .5306 .50091 L .53204 .50229 L 0 .028 .128 r
F
.52938 .50302 m .52794 .50165 L .5306 .50091 L F
.33983 .50217 m .3408 .49977 L .34241 .50127 L 0 .026 .125 r
F
.33983 .50217 m .33822 .50065 L .3408 .49977 L F
.34659 .50185 m .34756 .49954 L .34916 .50101 L 0 .025 .124 r
F
.34659 .50185 m .34498 .50037 L .34756 .49954 L F
.65663 .50302 m .65803 .50068 L .65935 .50211 L 0 .028 .127 r
F
.65663 .50302 m .65531 .5016 L .65803 .50068 L F
.58081 .50265 m .58211 .50039 L .5835 .50183 L 0 .027 .127 r
F
.58081 .50265 m .57942 .5012 L .58211 .50039 L F
.66339 .50265 m .66481 .5003 L .66612 .50175 L 0 .027 .126 r
F
.66339 .50265 m .66208 .50121 L .66481 .5003 L F
.44679 .50322 m .44791 .50089 L .44942 .50249 L 0 .028 .128 r
F
.44679 .50322 m .44528 .50162 L .44791 .50089 L F
.4224 .50235 m .42348 .50002 L .42501 .5016 L 0 .027 .126 r
F
.4224 .50235 m .42087 .50077 L .42348 .50002 L F
.37773 .50257 m .37875 .50021 L .38032 .50182 L F
.37773 .50257 m .37616 .50097 L .37875 .50021 L F
.61872 .50298 m .62007 .50056 L .62143 .50209 L 0 .028 .127 r
F
.61872 .50298 m .61737 .50144 L .62007 .50056 L F
.70807 .50262 m .70954 .50015 L .71082 .50174 L 0 .027 .126 r
F
.70807 .50262 m .70679 .50103 L .70954 .50015 L F
.67016 .50246 m .67158 .5 L .67289 .50161 L F
.67016 .50246 m .66885 .50086 L .67158 .5 L F
.53614 .50304 m .53738 .50078 L .53881 .50228 L 0 .028 .128 r
F
.53614 .50304 m .53471 .50155 L .53738 .50078 L F
.49823 .50288 m .49941 .50057 L .50087 .50215 L 0 .028 .127 r
F
.49823 .50288 m .49676 .5013 L .49941 .50057 L F
.35334 .50176 m .35432 .49947 L .35591 .501 L 0 .026 .124 r
F
.35334 .50176 m .35174 .50024 L .35432 .49947 L F
.62549 .50273 m .62685 .50032 L .6282 .50183 L 0 .027 .127 r
F
.62549 .50273 m .62414 .5012 L .62685 .50032 L F
.58758 .50258 m .58888 .50013 L .59027 .50172 L 0 .027 .126 r
F
.58758 .50258 m .58619 .50098 L .58888 .50013 L F
.71485 .50242 m .71632 .49993 L .71759 .50151 L F
.71485 .50242 m .71357 .50083 L .71632 .49993 L F
.63226 .50245 m .63362 .50006 L .63497 .50155 L F
.63226 .50245 m .63091 .50095 L .63362 .50006 L F
.45355 .50321 m .45467 .50101 L .45617 .50246 L 0 .029 .129 r
F
.45355 .50321 m .45204 .50176 L .45467 .50101 L F
.31541 .5018 m .31634 .49945 L .31797 .50096 L 0 .026 .125 r
F
.31541 .5018 m .31378 .50032 L .31634 .49945 L F
.42915 .50242 m .43024 .49999 L .43177 .50156 L 0 .027 .126 r
F
.42915 .50242 m .42763 .50085 L .43024 .49999 L F
.67694 .50243 m .67837 .50002 L .67968 .50162 L F
.67694 .50243 m .67563 .50081 L .67837 .50002 L F
.46031 .50299 m .46144 .50065 L .46294 .50209 L 0 .028 .128 r
F
.46031 .50299 m .4588 .50156 L .46144 .50065 L F
.38447 .50264 m .3855 .50025 L .38707 .50181 L 0 .028 .127 r
F
.38447 .50264 m .38291 .50107 L .3855 .50025 L F
.36008 .5017 m .36108 .49922 L .36267 .50082 L 0 .025 .124 r
F
.36008 .5017 m .3585 .50012 L .36108 .49922 L F
.59435 .50246 m .59566 .50006 L .59704 .50161 L 0 .027 .126 r
F
.59435 .50246 m .59296 .50088 L .59566 .50006 L F
.5429 .50302 m .54415 .5007 L .54557 .50224 L 0 .029 .128 r
F
.5429 .50302 m .54148 .50149 L .54415 .5007 L F
.46707 .50267 m .46821 .50045 L .4697 .50187 L 0 .028 .128 r
F
.46707 .50267 m .46557 .50124 L .46821 .50045 L F
.63903 .50233 m .64041 .5 L .64175 .50158 L 0 .027 .126 r
F
.63903 .50233 m .63769 .50076 L .64041 .5 L F
.39123 .50242 m .39226 .50019 L .39383 .50162 L 0 .028 .127 r
F
.39123 .50242 m .38966 .50098 L .39226 .50019 L F
.32216 .50168 m .32309 .49939 L .32472 .50091 L 0 .026 .125 r
F
.32216 .50168 m .32053 .50014 L .32309 .49939 L F
.47383 .50245 m .47498 .50024 L .47647 .50163 L 0 .028 .127 r
F
.47383 .50245 m .47234 .50107 L .47498 .50024 L F
.50499 .50302 m .50618 .50074 L .50764 .50232 L 0 .029 .129 r
F
.50499 .50302 m .50352 .50144 L .50618 .50074 L F
.43591 .50228 m .43701 .49988 L .43853 .50147 L 0 .027 .126 r
F
.43591 .50228 m .43439 .50069 L .43701 .49988 L F
.60111 .50229 m .60244 .49998 L .60381 .50151 L 0 .027 .127 r
F
.60111 .50229 m .59974 .50078 L .60244 .49998 L F
.54967 .50288 m .55092 .50049 L .55234 .50198 L 0 .028 .128 r
F
.54967 .50288 m .54825 .50137 L .55092 .50049 L F
.68372 .50235 m .68516 .49999 L .68646 .50151 L 0 .027 .127 r
F
.68372 .50235 m .68242 .50081 L .68516 .49999 L F
.36683 .5016 m .36783 .49926 L .36941 .50086 L 0 .026 .125 r
F
.36683 .5016 m .36525 .49999 L .36783 .49926 L F
.55643 .50258 m .5577 .50027 L .55911 .50174 L 0 .028 .127 r
F
.55643 .50258 m .55502 .5011 L .5577 .50027 L F
.48059 .50221 m .48175 .49997 L .48323 .50139 L 0 .027 .127 r
F
.48059 .50221 m .47911 .50081 L .48175 .49997 L F
.69049 .50206 m .69194 .49985 L .69323 .50125 L 0 .027 .126 r
F
.69049 .50206 m .6892 .50068 L .69194 .49985 L F
.39798 .50233 m .39902 .50016 L .40058 .5016 L 0 .028 .127 r
F
.39798 .50233 m .39642 .50089 L .39902 .50016 L F
.5632 .50235 m .56447 .50006 L .56588 .50154 L F
.5632 .50235 m .56179 .50089 L .56447 .50006 L F
.3289 .50165 m .32985 .49934 L .33147 .50083 L 0 .026 .125 r
F
.3289 .50165 m .32728 .50015 L .32985 .49934 L F
.69726 .50184 m .69872 .49962 L .7 .50105 L 0 .027 .126 r
F
.69726 .50184 m .69597 .50043 L .69872 .49962 L F
.64581 .50241 m .6472 .50008 L .64853 .50167 L 0 .028 .127 r
F
.64581 .50241 m .64447 .50083 L .6472 .50008 L F
.60788 .50222 m .60922 .49994 L .61059 .50145 L 0 .027 .127 r
F
.60788 .50222 m .60652 .50073 L .60922 .49994 L F
.48735 .50206 m .48852 .49964 L .49 .50119 L 0 .027 .126 r
F
.48735 .50206 m .48588 .50052 L .48852 .49964 L F
.40474 .50216 m .40579 .49983 L .40735 .50126 L 0 .027 .127 r
F
.40474 .50216 m .40318 .50073 L .40579 .49983 L F
.44266 .50235 m .44377 .50002 L .44528 .50162 L 0 .028 .127 r
F
.44266 .50235 m .44115 .50074 L .44377 .50002 L F
.56996 .50219 m .57125 .49995 L .57265 .50141 L F
.56996 .50219 m .56856 .50074 L .57125 .49995 L F
.4115 .50181 m .41256 .49955 L .41411 .50097 L 0 .027 .126 r
F
.4115 .50181 m .40995 .50038 L .41256 .49955 L F
.51175 .50314 m .51295 .50066 L .5144 .50225 L 0 .029 .129 r
F
.51175 .50314 m .51029 .50155 L .51295 .50066 L F
.33565 .50149 m .33661 .49917 L .33822 .50065 L 0 .026 .125 r
F
.33565 .50149 m .33404 .5 L .33661 .49917 L F
.37357 .50172 m .37459 .49937 L .37616 .50097 L 0 .027 .126 r
F
.37357 .50172 m .372 .50013 L .37459 .49937 L F
.51851 .50287 m .51972 .50049 L .52117 .50199 L 0 .029 .129 r
F
.51851 .50287 m .51706 .50136 L .51972 .50049 L F
.41826 .50157 m .41933 .49934 L .42087 .50077 L 0 .026 .126 r
F
.41826 .50157 m .41672 .50014 L .41933 .49934 L F
.52528 .50251 m .5265 .50027 L .52794 .50165 L 0 .028 .128 r
F
.52528 .50251 m .52383 .50112 L .5265 .50027 L F
.70404 .50179 m .70551 .49948 L .70679 .50103 L 0 .027 .126 r
F
.70404 .50179 m .70276 .50027 L .70551 .49948 L F
.57673 .50201 m .57803 .49976 L .57942 .5012 L 0 .027 .127 r
F
.57673 .50201 m .57534 .50058 L .57803 .49976 L F
.61466 .5022 m .616 .49988 L .61737 .50144 L 0 .028 .127 r
F
.61466 .5022 m .61329 .50066 L .616 .49988 L F
.34241 .50127 m .34338 .49888 L .34498 .50037 L 0 .026 .124 r
F
.34241 .50127 m .3408 .49977 L .34338 .49888 L F
.49411 .50202 m .49529 .49971 L .49676 .5013 L 0 .027 .127 r
F
.49411 .50202 m .49264 .50042 L .49529 .49971 L F
.65259 .50243 m .65398 .50009 L .65531 .5016 L 0 .028 .128 r
F
.65259 .50243 m .65126 .50092 L .65398 .50009 L F
.53204 .50229 m .53327 .50016 L .53471 .50155 L F
.53204 .50229 m .5306 .50091 L .53327 .50016 L F
.65935 .50211 m .66076 .49977 L .66208 .50121 L 0 .028 .127 r
F
.65935 .50211 m .65803 .50068 L .66076 .49977 L F
.66612 .50175 m .66754 .4994 L .66885 .50086 L 0 .027 .126 r
F
.66612 .50175 m .66481 .5003 L .66754 .4994 L F
.34916 .50101 m .35014 .49877 L .35174 .50024 L 0 .025 .124 r
F
.34916 .50101 m .34756 .49954 L .35014 .49877 L F
.5835 .50183 m .5848 .49955 L .58619 .50098 L 0 .027 .127 r
F
.5835 .50183 m .58211 .50039 L .5848 .49955 L F
.62143 .50209 m .62278 .49968 L .62414 .5012 L 0 .028 .127 r
F
.62143 .50209 m .62007 .50056 L .62278 .49968 L F
.44942 .50249 m .45053 .50015 L .45204 .50176 L 0 .029 .128 r
F
.44942 .50249 m .44791 .50089 L .45053 .50015 L F
.71082 .50174 m .71229 .49925 L .71357 .50083 L 0 .027 .126 r
F
.71082 .50174 m .70954 .50015 L .71229 .49925 L F
.42501 .5016 m .4261 .49927 L .42763 .50085 L F
.42501 .5016 m .42348 .50002 L .4261 .49927 L F
.67289 .50161 m .67432 .49922 L .67563 .50081 L F
.67289 .50161 m .67158 .5 L .67432 .49922 L F
.38032 .50182 m .38134 .49945 L .38291 .50107 L 0 .027 .127 r
F
.38032 .50182 m .37875 .50021 L .38134 .49945 L F
.6282 .50183 m .62956 .49945 L .63091 .50095 L F
.6282 .50183 m .62685 .50032 L .62956 .49945 L F
.71759 .50151 m .71908 .49902 L .72035 .5006 L 0 .026 .126 r
F
.71759 .50151 m .71632 .49993 L .71908 .49902 L F
.59027 .50172 m .59158 .49932 L .59296 .50088 L 0 .027 .126 r
F
.59027 .50172 m .58888 .50013 L .59158 .49932 L F
.53881 .50228 m .54005 .49998 L .54148 .50149 L 0 .028 .128 r
F
.53881 .50228 m .53738 .50078 L .54005 .49998 L F
.63497 .50155 m .63634 .49926 L .63769 .50076 L 0 .027 .126 r
F
.63497 .50155 m .63362 .50006 L .63634 .49926 L F
.35591 .501 m .3569 .49858 L .3585 .50012 L 0 .026 .124 r
F
.35591 .501 m .35432 .49947 L .3569 .49858 L F
.31121 .50119 m .31214 .49884 L .31378 .50032 L 0 .026 .125 r
F
.31121 .50119 m .30957 .49973 L .31214 .49884 L F
.50087 .50215 m .50206 .49986 L .50352 .50144 L 0 .028 .128 r
F
.50087 .50215 m .49941 .50057 L .50206 .49986 L F
.31797 .50096 m .3189 .49863 L .32053 .50014 L 0 .026 .125 r
F
.31797 .50096 m .31634 .49945 L .3189 .49863 L F
.45617 .50246 m .4573 .5001 L .4588 .50156 L 0 .029 .129 r
F
.45617 .50246 m .45467 .50101 L .4573 .5001 L F
.46294 .50209 m .46407 .4998 L .46557 .50124 L 0 .028 .128 r
F
.46294 .50209 m .46144 .50065 L .46407 .4998 L F
.43177 .50156 m .43287 .49913 L .43439 .50069 L 0 .027 .126 r
F
.43177 .50156 m .43024 .49999 L .43287 .49913 L F
.36267 .50082 m .36367 .49838 L .36525 .49999 L 0 .025 .124 r
F
.36267 .50082 m .36108 .49922 L .36367 .49838 L F
.59704 .50161 m .59836 .49923 L .59974 .50078 L 0 .027 .126 r
F
.59704 .50161 m .59566 .50006 L .59836 .49923 L F
.38707 .50181 m .3881 .49943 L .38966 .50098 L 0 .028 .127 r
F
.38707 .50181 m .3855 .50025 L .3881 .49943 L F
.67968 .50162 m .68111 .49922 L .68242 .50081 L 0 .027 .126 r
F
.67968 .50162 m .67837 .50002 L .68111 .49922 L F
.54557 .50224 m .54682 .49985 L .54825 .50137 L 0 .029 .128 r
F
.54557 .50224 m .54415 .5007 L .54682 .49985 L F
.4697 .50187 m .47085 .49966 L .47234 .50107 L 0 .028 .128 r
F
.4697 .50187 m .46821 .50045 L .47085 .49966 L F
.64175 .50158 m .64313 .49925 L .64447 .50083 L 0 .027 .127 r
F
.64175 .50158 m .64041 .5 L .64313 .49925 L F
.55234 .50198 m .5536 .49963 L .55502 .5011 L 0 .028 .128 r
F
.55234 .50198 m .55092 .50049 L .5536 .49963 L F
.39383 .50162 m .39486 .49946 L .39642 .50089 L 0 .028 .127 r
F
.39383 .50162 m .39226 .50019 L .39486 .49946 L F
.47647 .50163 m .47762 .49941 L .47911 .50081 L F
.47647 .50163 m .47498 .50024 L .47762 .49941 L F
.43853 .50147 m .43963 .49917 L .44115 .50074 L 0 .027 .127 r
F
.43853 .50147 m .43701 .49988 L .43963 .49917 L F
.32472 .50091 m .32566 .49864 L .32728 .50015 L 0 .026 .125 r
F
.32472 .50091 m .32309 .49939 L .32566 .49864 L F
.68646 .50151 m .6879 .49917 L .6892 .50068 L 0 .027 .127 r
F
.68646 .50151 m .68516 .49999 L .6879 .49917 L F
.60381 .50151 m .60515 .49918 L .60652 .50073 L F
.60381 .50151 m .60244 .49998 L .60515 .49918 L F
.55911 .50174 m .56038 .49943 L .56179 .50089 L 0 .028 .127 r
F
.55911 .50174 m .5577 .50027 L .56038 .49943 L F
.50764 .50232 m .50884 .49996 L .51029 .50155 L 0 .029 .129 r
F
.50764 .50232 m .50618 .50074 L .50884 .49996 L F
.48323 .50139 m .4844 .49909 L .48588 .50052 L 0 .027 .127 r
F
.48323 .50139 m .48175 .49997 L .4844 .49909 L F
.36941 .50086 m .37042 .49853 L .372 .50013 L 0 .026 .125 r
F
.36941 .50086 m .36783 .49926 L .37042 .49853 L F
.69323 .50125 m .69469 .49902 L .69597 .50043 L 0 .027 .126 r
F
.69323 .50125 m .69194 .49985 L .69469 .49902 L F
.56588 .50154 m .56716 .49924 L .56856 .50074 L 0 .028 .127 r
F
.56588 .50154 m .56447 .50006 L .56716 .49924 L F
.49 .50119 m .49117 .49887 L .49264 .50042 L 0 .027 .126 r
F
.49 .50119 m .48852 .49964 L .49117 .49887 L F
.33147 .50083 m .33242 .49852 L .33404 .5 L 0 .026 .125 r
F
.33147 .50083 m .32985 .49934 L .33242 .49852 L F
.40058 .5016 m .40163 .49928 L .40318 .50073 L 0 .028 .127 r
F
.40058 .5016 m .39902 .50016 L .40163 .49928 L F
.7 .50105 m .70148 .49882 L .70276 .50027 L 0 .027 .126 r
F
.7 .50105 m .69872 .49962 L .70148 .49882 L F
.61059 .50145 m .61193 .49913 L .61329 .50066 L 0 .028 .127 r
F
.61059 .50145 m .60922 .49994 L .61193 .49913 L F
.40735 .50126 m .4084 .49894 L .40995 .50038 L 0 .027 .127 r
F
.40735 .50126 m .40579 .49983 L .4084 .49894 L F
.64853 .50167 m .64992 .49933 L .65126 .50092 L 0 .028 .128 r
F
.64853 .50167 m .6472 .50008 L .64992 .49933 L F
.5144 .50225 m .51561 .49977 L .51706 .50136 L 0 .029 .129 r
F
.5144 .50225 m .51295 .50066 L .51561 .49977 L F
.41411 .50097 m .41518 .49873 L .41672 .50014 L 0 .027 .126 r
F
.41411 .50097 m .41256 .49955 L .41518 .49873 L F
.33822 .50065 m .33919 .4983 L .3408 .49977 L 0 .026 .125 r
F
.33822 .50065 m .33661 .49917 L .33919 .4983 L F
.57265 .50141 m .57394 .4991 L .57534 .50058 L 0 .028 .127 r
F
.57265 .50141 m .57125 .49995 L .57394 .4991 L F
.52117 .50199 m .52239 .49964 L .52383 .50112 L 0 .029 .129 r
F
.52117 .50199 m .51972 .50049 L .52239 .49964 L F
.44528 .50162 m .44639 .49928 L .44791 .50089 L 0 .028 .128 r
F
.44528 .50162 m .44377 .50002 L .44639 .49928 L F
.52794 .50165 m .52916 .49952 L .5306 .50091 L 0 .029 .128 r
F
.52794 .50165 m .5265 .50027 L .52916 .49952 L F
.34498 .50037 m .34595 .49806 L .34756 .49954 L 0 .026 .124 r
F
.34498 .50037 m .34338 .49888 L .34595 .49806 L F
.42087 .50077 m .42195 .49857 L .42348 .50002 L 0 .027 .126 r
F
.42087 .50077 m .41933 .49934 L .42195 .49857 L F
.37616 .50097 m .37718 .4986 L .37875 .50021 L F
.37616 .50097 m .37459 .49937 L .37718 .4986 L F
.57942 .5012 m .58072 .49894 L .58211 .50039 L 0 .027 .127 r
F
.57942 .5012 m .57803 .49976 L .58072 .49894 L F
.66208 .50121 m .66349 .49885 L .66481 .5003 L F
.66208 .50121 m .66076 .49977 L .66349 .49885 L F
.70679 .50103 m .70826 .49861 L .70954 .50015 L 0 .027 .126 r
F
.70679 .50103 m .70551 .49948 L .70826 .49861 L F
.65531 .5016 m .65671 .49917 L .65803 .50068 L 0 .028 .128 r
F
.65531 .5016 m .65398 .50009 L .65671 .49917 L F
.66885 .50086 m .67027 .49853 L .67158 .5 L 0 .027 .126 r
F
.66885 .50086 m .66754 .4994 L .67027 .49853 L F
.61737 .50144 m .61871 .49902 L .62007 .50056 L 0 .028 .127 r
F
.61737 .50144 m .616 .49988 L .61871 .49902 L F
.49676 .5013 m .49794 .49899 L .49941 .50057 L F
.49676 .5013 m .49529 .49971 L .49794 .49899 L F
.58619 .50098 m .5875 .49872 L .58888 .50013 L 0 .027 .126 r
F
.58619 .50098 m .5848 .49955 L .5875 .49872 L F
.53471 .50155 m .53594 .49938 L .53738 .50078 L 0 .029 .128 r
F
.53471 .50155 m .53327 .50016 L .53594 .49938 L F
.35174 .50024 m .35272 .498 L .35432 .49947 L 0 .026 .124 r
F
.35174 .50024 m .35014 .49877 L .35272 .498 L F
.62414 .5012 m .6255 .49881 L .62685 .50032 L 0 .027 .127 r
F
.62414 .5012 m .62278 .49968 L .6255 .49881 L F
.71357 .50083 m .71505 .49834 L .71632 .49993 L 0 .027 .126 r
F
.71357 .50083 m .71229 .49925 L .71505 .49834 L F
.63091 .50095 m .63228 .49857 L .63362 .50006 L F
.63091 .50095 m .62956 .49945 L .63228 .49857 L F
.72035 .5006 m .72183 .49811 L .7231 .4997 L 0 .026 .125 r
F
.72035 .5006 m .71908 .49902 L .72183 .49811 L F
.67563 .50081 m .67706 .49844 L .67837 .50002 L 0 .027 .126 r
F
.67563 .50081 m .67432 .49922 L .67706 .49844 L F
.45204 .50176 m .45316 .4994 L .45467 .50101 L 0 .029 .129 r
F
.45204 .50176 m .45053 .50015 L .45316 .4994 L F
.42763 .50085 m .42872 .49842 L .43024 .49999 L 0 .027 .126 r
F
.42763 .50085 m .4261 .49927 L .42872 .49842 L F
.3585 .50012 m .35949 .49768 L .36108 .49922 L 0 .025 .124 r
F
.3585 .50012 m .3569 .49858 L .35949 .49768 L F
.59296 .50088 m .59428 .4985 L .59566 .50006 L 0 .027 .126 r
F
.59296 .50088 m .59158 .49932 L .59428 .4985 L F
.38291 .50107 m .38394 .49863 L .3855 .50025 L 0 .027 .127 r
F
.38291 .50107 m .38134 .49945 L .38394 .49863 L F
.31378 .50032 m .31471 .49795 L .31634 .49945 L 0 .026 .125 r
F
.31378 .50032 m .31214 .49884 L .31471 .49795 L F
.54148 .50149 m .54272 .49918 L .54415 .5007 L 0 .029 .128 r
F
.54148 .50149 m .54005 .49998 L .54272 .49918 L F
.63769 .50076 m .63907 .49849 L .64041 .5 L 0 .027 .126 r
F
.63769 .50076 m .63634 .49926 L .63907 .49849 L F
.4588 .50156 m .45994 .49919 L .46144 .50065 L 0 .029 .129 r
F
.4588 .50156 m .4573 .5001 L .45994 .49919 L F
.46557 .50124 m .46671 .49901 L .46821 .50045 L 0 .028 .128 r
F
.46557 .50124 m .46407 .4998 L .46671 .49901 L F
.50352 .50144 m .50472 .49915 L .50618 .50074 L 0 .029 .128 r
F
.50352 .50144 m .50206 .49986 L .50472 .49915 L F
.43439 .50069 m .43549 .49833 L .43701 .49988 L 0 .027 .126 r
F
.43439 .50069 m .43287 .49913 L .43549 .49833 L F
.32053 .50014 m .32147 .49786 L .32309 .49939 L 0 .026 .125 r
F
.32053 .50014 m .3189 .49863 L .32147 .49786 L F
.36525 .49999 m .36625 .49765 L .36783 .49926 L 0 .025 .124 r
F
.36525 .49999 m .36367 .49838 L .36625 .49765 L F
.59974 .50078 m .60106 .49841 L .60244 .49998 L 0 .027 .127 r
F
.59974 .50078 m .59836 .49923 L .60106 .49841 L F
.38966 .50098 m .3907 .49865 L .39226 .50019 L 0 .028 .127 r
F
.38966 .50098 m .3881 .49943 L .3907 .49865 L F
.54825 .50137 m .5495 .49899 L .55092 .50049 L 0 .028 .128 r
F
.54825 .50137 m .54682 .49985 L .5495 .49899 L F
.68242 .50081 m .68386 .49842 L .68516 .49999 L 0 .027 .127 r
F
.68242 .50081 m .68111 .49922 L .68386 .49842 L F
.47234 .50107 m .47349 .4988 L .47498 .50024 L 0 .028 .128 r
F
.47234 .50107 m .47085 .49966 L .47349 .4988 L F
.55502 .5011 m .55628 .49882 L .5577 .50027 L F
.55502 .5011 m .5536 .49963 L .55628 .49882 L F
.47911 .50081 m .48026 .49856 L .48175 .49997 L 0 .028 .127 r
F
.47911 .50081 m .47762 .49941 L .48026 .49856 L F
.64447 .50083 m .64586 .49849 L .6472 .50008 L F
.64447 .50083 m .64313 .49925 L .64586 .49849 L F
.6892 .50068 m .69065 .49832 L .69194 .49985 L 0 .027 .127 r
F
.6892 .50068 m .6879 .49917 L .69065 .49832 L F
.48588 .50052 m .48704 .4982 L .48852 .49964 L 0 .027 .126 r
F
.48588 .50052 m .4844 .49909 L .48704 .4982 L F
.39642 .50089 m .39746 .49873 L .39902 .50016 L 0 .028 .128 r
F
.39642 .50089 m .39486 .49946 L .39746 .49873 L F
.56179 .50089 m .56306 .49859 L .56447 .50006 L 0 .028 .127 r
F
.56179 .50089 m .56038 .49943 L .56306 .49859 L F
.32728 .50015 m .32822 .49784 L .32985 .49934 L 0 .026 .125 r
F
.32728 .50015 m .32566 .49864 L .32822 .49784 L F
.60652 .50073 m .60785 .49837 L .60922 .49994 L 0 .027 .127 r
F
.60652 .50073 m .60515 .49918 L .60785 .49837 L F
.44115 .50074 m .44225 .49846 L .44377 .50002 L 0 .028 .127 r
F
.44115 .50074 m .43963 .49917 L .44225 .49846 L F
.51029 .50155 m .51149 .49907 L .51295 .50066 L 0 .029 .129 r
F
.51029 .50155 m .50884 .49996 L .51149 .49907 L F
.69597 .50043 m .69744 .4982 L .69872 .49962 L 0 .027 .126 r
F
.69597 .50043 m .69469 .49902 L .69744 .4982 L F
.372 .50013 m .37301 .49777 L .37459 .49937 L 0 .026 .125 r
F
.372 .50013 m .37042 .49853 L .37301 .49777 L F
.40318 .50073 m .40424 .49837 L .40579 .49983 L 0 .028 .127 r
F
.40318 .50073 m .40163 .49928 L .40424 .49837 L F
.56856 .50074 m .56985 .49841 L .57125 .49995 L F
.56856 .50074 m .56716 .49924 L .56985 .49841 L F
.33404 .5 m .33499 .49769 L .33661 .49917 L 0 .026 .125 r
F
.33404 .5 m .33242 .49852 L .33499 .49769 L F
.40995 .50038 m .41101 .49812 L .41256 .49955 L 0 .027 .126 r
F
.40995 .50038 m .4084 .49894 L .41101 .49812 L F
.51706 .50136 m .51827 .49892 L .51972 .50049 L 0 .029 .129 r
F
.51706 .50136 m .51561 .49977 L .51827 .49892 L F
.49264 .50042 m .49382 .49816 L .49529 .49971 L 0 .027 .127 r
F
.49264 .50042 m .49117 .49887 L .49382 .49816 L F
.70276 .50027 m .70423 .49802 L .70551 .49948 L 0 .027 .126 r
F
.70276 .50027 m .70148 .49882 L .70423 .49802 L F
.61329 .50066 m .61464 .49832 L .616 .49988 L 0 .028 .127 r
F
.61329 .50066 m .61193 .49913 L .61464 .49832 L F
.41672 .50014 m .41779 .49792 L .41933 .49934 L 0 .027 .126 r
F
.41672 .50014 m .41518 .49873 L .41779 .49792 L F
.3408 .49977 m .34176 .49743 L .34338 .49888 L 0 .026 .125 r
F
.3408 .49977 m .33919 .4983 L .34176 .49743 L F
.65126 .50092 m .65265 .49849 L .65398 .50009 L 0 .028 .128 r
F
.65126 .50092 m .64992 .49933 L .65265 .49849 L F
.52383 .50112 m .52505 .4988 L .5265 .50027 L 0 .029 .129 r
F
.52383 .50112 m .52239 .49964 L .52505 .4988 L F
.57534 .50058 m .57663 .49825 L .57803 .49976 L 0 .028 .127 r
F
.57534 .50058 m .57394 .4991 L .57663 .49825 L F
.34756 .49954 m .34853 .4973 L .35014 .49877 L 0 .026 .124 r
F
.34756 .49954 m .34595 .49806 L .34853 .4973 L F
.66481 .5003 m .66622 .49793 L .66754 .4994 L 0 .027 .126 r
F
.66481 .5003 m .66349 .49885 L .66622 .49793 L F
.65803 .50068 m .65944 .49825 L .66076 .49977 L 0 .028 .127 r
F
.65803 .50068 m .65671 .49917 L .65944 .49825 L F
.44791 .50089 m .44902 .49854 L .45053 .50015 L 0 .028 .128 r
F
.44791 .50089 m .44639 .49928 L .44902 .49854 L F
.70954 .50015 m .71102 .49771 L .71229 .49925 L 0 .027 .126 r
F
.70954 .50015 m .70826 .49861 L .71102 .49771 L F
.5306 .50091 m .53183 .49877 L .53327 .50016 L 0 .029 .129 r
F
.5306 .50091 m .52916 .49952 L .53183 .49877 L F
.67158 .5 m .67301 .49776 L .67432 .49922 L 0 .027 .126 r
F
.67158 .5 m .67027 .49853 L .67301 .49776 L F
.62007 .50056 m .62143 .49816 L .62278 .49968 L 0 .028 .127 r
F
.62007 .50056 m .61871 .49902 L .62143 .49816 L F
.58211 .50039 m .58341 .49812 L .5848 .49955 L F
.58211 .50039 m .58072 .49894 L .58341 .49812 L F
.42348 .50002 m .42456 .49779 L .4261 .49927 L 0 .027 .126 r
F
.42348 .50002 m .42195 .49857 L .42456 .49779 L F
.37875 .50021 m .37977 .49783 L .38134 .49945 L F
.37875 .50021 m .37718 .4986 L .37977 .49783 L F
.71632 .49993 m .7178 .49743 L .71908 .49902 L 0 .026 .125 r
F
.71632 .49993 m .71505 .49834 L .7178 .49743 L F
.58888 .50013 m .5902 .49792 L .59158 .49932 L 0 .027 .127 r
F
.58888 .50013 m .5875 .49872 L .5902 .49792 L F
.62685 .50032 m .62821 .49795 L .62956 .49945 L F
.62685 .50032 m .6255 .49881 L .62821 .49795 L F
.49941 .50057 m .5006 .49828 L .50206 .49986 L 0 .028 .128 r
F
.49941 .50057 m .49794 .49899 L .5006 .49828 L F
.53738 .50078 m .53862 .49856 L .54005 .49998 L 0 .029 .129 r
F
.53738 .50078 m .53594 .49938 L .53862 .49856 L F
.35432 .49947 m .3553 .49711 L .3569 .49858 L 0 .026 .124 r
F
.35432 .49947 m .35272 .498 L .3553 .49711 L F
.63362 .50006 m .635 .49777 L .63634 .49926 L 0 .027 .126 r
F
.63362 .50006 m .63228 .49857 L .635 .49777 L F
.7231 .4997 m .7246 .49728 L .72586 .49887 L 0 .026 .125 r
F
.7231 .4997 m .72183 .49811 L .7246 .49728 L F
.30957 .49973 m .3105 .49733 L .31214 .49884 L F
.30957 .49973 m .30793 .49824 L .3105 .49733 L F
.36108 .49922 m .36208 .49682 L .36367 .49838 L 0 .025 .124 r
F
.36108 .49922 m .35949 .49768 L .36208 .49682 L F
.43024 .49999 m .43134 .49756 L .43287 .49913 L 0 .027 .126 r
F
.43024 .49999 m .42872 .49842 L .43134 .49756 L F
.31634 .49945 m .31727 .49711 L .3189 .49863 L 0 .026 .125 r
F
.31634 .49945 m .31471 .49795 L .31727 .49711 L F
.67837 .50002 m .6798 .49766 L .68111 .49922 L 0 .027 .126 r
F
.67837 .50002 m .67706 .49844 L .6798 .49766 L F
.59566 .50006 m .59698 .49769 L .59836 .49923 L F
.59566 .50006 m .59428 .4985 L .59698 .49769 L F
.3855 .50025 m .38654 .49782 L .3881 .49943 L 0 .027 .127 r
F
.3855 .50025 m .38394 .49863 L .38654 .49782 L F
.45467 .50101 m .4558 .49851 L .4573 .5001 L 0 .029 .129 r
F
.45467 .50101 m .45316 .4994 L .4558 .49851 L F
.46144 .50065 m .46257 .49835 L .46407 .4998 L 0 .029 .128 r
F
.46144 .50065 m .45994 .49919 L .46257 .49835 L F
.54415 .5007 m .5454 .49835 L .54682 .49985 L F
.54415 .5007 m .54272 .49918 L .5454 .49835 L F
.64041 .5 m .64179 .49773 L .64313 .49925 L 0 .027 .127 r
F
.64041 .5 m .63907 .49849 L .64179 .49773 L F
.43701 .49988 m .43811 .49763 L .43963 .49917 L 0 .027 .126 r
F
.43701 .49988 m .43549 .49833 L .43811 .49763 L F
.46821 .50045 m .46935 .49823 L .47085 .49966 L 0 .028 .128 r
F
.46821 .50045 m .46671 .49901 L .46935 .49823 L F
.55092 .50049 m .55218 .49816 L .5536 .49963 L F
.55092 .50049 m .5495 .49899 L .55218 .49816 L F
.32309 .49939 m .32403 .4971 L .32566 .49864 L 0 .026 .125 r
F
.32309 .49939 m .32147 .49786 L .32403 .4971 L F
.60244 .49998 m .60377 .4976 L .60515 .49918 L 0 .027 .127 r
F
.60244 .49998 m .60106 .49841 L .60377 .4976 L F
.50618 .50074 m .50738 .49838 L .50884 .49996 L 0 .029 .129 r
F
.50618 .50074 m .50472 .49915 L .50738 .49838 L F
.68516 .49999 m .6866 .49762 L .6879 .49917 L 0 .027 .127 r
F
.68516 .49999 m .68386 .49842 L .6866 .49762 L F
.39226 .50019 m .3933 .49792 L .39486 .49946 L 0 .028 .128 r
F
.39226 .50019 m .3907 .49865 L .3933 .49792 L F
.36783 .49926 m .36884 .49692 L .37042 .49853 L 0 .026 .125 r
F
.36783 .49926 m .36625 .49765 L .36884 .49692 L F
.47498 .50024 m .47613 .49794 L .47762 .49941 L 0 .028 .128 r
F
.47498 .50024 m .47349 .4988 L .47613 .49794 L F
.5577 .50027 m .55897 .49801 L .56038 .49943 L F
.5577 .50027 m .55628 .49882 L .55897 .49801 L F
.48175 .49997 m .48291 .49766 L .4844 .49909 L 0 .028 .127 r
F
.48175 .49997 m .48026 .49856 L .48291 .49766 L F
.48852 .49964 m .48969 .49742 L .49117 .49887 L 0 .027 .126 r
F
.48852 .49964 m .48704 .4982 L .48969 .49742 L F
.69194 .49985 m .6934 .49747 L .69469 .49902 L 0 .027 .127 r
F
.69194 .49985 m .69065 .49832 L .6934 .49747 L F
.56447 .50006 m .56575 .49774 L .56716 .49924 L 0 .028 .127 r
F
.56447 .50006 m .56306 .49859 L .56575 .49774 L F
.6472 .50008 m .64859 .49773 L .64992 .49933 L F
.6472 .50008 m .64586 .49849 L .64859 .49773 L F
.32985 .49934 m .3308 .49702 L .33242 .49852 L 0 .026 .125 r
F
.32985 .49934 m .32822 .49784 L .3308 .49702 L F
.51295 .50066 m .51416 .49817 L .51561 .49977 L 0 .029 .129 r
F
.51295 .50066 m .51149 .49907 L .51416 .49817 L F
.60922 .49994 m .61056 .49754 L .61193 .49913 L 0 .028 .127 r
F
.60922 .49994 m .60785 .49837 L .61056 .49754 L F
.39902 .50016 m .40007 .49783 L .40163 .49928 L 0 .028 .128 r
F
.39902 .50016 m .39746 .49873 L .40007 .49783 L F
.69872 .49962 m .70019 .49738 L .70148 .49882 L 0 .027 .127 r
F
.69872 .49962 m .69744 .4982 L .70019 .49738 L F
.40579 .49983 m .40685 .49747 L .4084 .49894 L F
.40579 .49983 m .40424 .49837 L .40685 .49747 L F
.44377 .50002 m .44488 .49772 L .44639 .49928 L 0 .028 .128 r
F
.44377 .50002 m .44225 .49846 L .44488 .49772 L F
.33661 .49917 m .33757 .49684 L .33919 .4983 L 0 .026 .125 r
F
.33661 .49917 m .33499 .49769 L .33757 .49684 L F
.41256 .49955 m .41363 .4973 L .41518 .49873 L 0 .027 .126 r
F
.41256 .49955 m .41101 .49812 L .41363 .4973 L F
.51972 .50049 m .52094 .49808 L .52239 .49964 L 0 .029 .129 r
F
.51972 .50049 m .51827 .49892 L .52094 .49808 L F
.37459 .49937 m .3756 .49699 L .37718 .4986 L 0 .027 .126 r
F
.37459 .49937 m .37301 .49777 L .3756 .49699 L F
.57125 .49995 m .57254 .49754 L .57394 .4991 L 0 .028 .127 r
F
.57125 .49995 m .56985 .49841 L .57254 .49754 L F
.34338 .49888 m .34434 .49661 L .34595 .49806 L 0 .026 .125 r
F
.34338 .49888 m .34176 .49743 L .34434 .49661 L F
.70551 .49948 m .70699 .49716 L .70826 .49861 L 0 .027 .126 r
F
.70551 .49948 m .70423 .49802 L .70699 .49716 L F
.616 .49988 m .61735 .49748 L .61871 .49902 L 0 .028 .127 r
F
.616 .49988 m .61464 .49832 L .61735 .49748 L F
.5265 .50027 m .52772 .49803 L .52916 .49952 L 0 .029 .129 r
F
.5265 .50027 m .52505 .4988 L .52772 .49803 L F
.49529 .49971 m .49647 .49745 L .49794 .49899 L 0 .028 .127 r
F
.49529 .49971 m .49382 .49816 L .49647 .49745 L F
.41933 .49934 m .4204 .49712 L .42195 .49857 L 0 .027 .126 r
F
.41933 .49934 m .41779 .49792 L .4204 .49712 L F
.65398 .50009 m .65538 .49757 L .65671 .49917 L 0 .028 .128 r
F
.65398 .50009 m .65265 .49849 L .65538 .49757 L F
.57803 .49976 m .57932 .49742 L .58072 .49894 L 0 .028 .127 r
F
.57803 .49976 m .57663 .49825 L .57932 .49742 L F
.66076 .49977 m .66217 .49733 L .66349 .49885 L F
.66076 .49977 m .65944 .49825 L .66217 .49733 L F
.66754 .4994 m .66896 .49705 L .67027 .49853 L 0 .027 .126 r
F
.66754 .4994 m .66622 .49793 L .66896 .49705 L F
.71229 .49925 m .71377 .49681 L .71505 .49834 L 0 .026 .126 r
F
.71229 .49925 m .71102 .49771 L .71377 .49681 L F
.62278 .49968 m .62414 .4973 L .6255 .49881 L 0 .028 .127 r
F
.62278 .49968 m .62143 .49816 L .62414 .4973 L F
.35014 .49877 m .35111 .49653 L .35272 .498 L 0 .026 .125 r
F
.35014 .49877 m .34853 .4973 L .35111 .49653 L F
.5848 .49955 m .58611 .4973 L .5875 .49872 L 0 .028 .127 r
F
.5848 .49955 m .58341 .49812 L .58611 .4973 L F
.71908 .49902 m .72056 .49652 L .72183 .49811 L 0 .026 .125 r
F
.71908 .49902 m .7178 .49743 L .72056 .49652 L F
.45053 .50015 m .45165 .49778 L .45316 .4994 L 0 .029 .129 r
F
.45053 .50015 m .44902 .49854 L .45165 .49778 L F
.67432 .49922 m .67575 .49699 L .67706 .49844 L 0 .027 .126 r
F
.67432 .49922 m .67301 .49776 L .67575 .49699 L F
.53327 .50016 m .53451 .49797 L .53594 .49938 L 0 .029 .129 r
F
.53327 .50016 m .53183 .49877 L .53451 .49797 L F
.62956 .49945 m .63093 .49709 L .63228 .49857 L 0 .027 .127 r
F
.62956 .49945 m .62821 .49795 L .63093 .49709 L F
.38134 .49945 m .38237 .49701 L .38394 .49863 L 0 .027 .126 r
F
.38134 .49945 m .37977 .49783 L .38237 .49701 L F
.4261 .49927 m .42718 .49693 L .42872 .49842 L F
.4261 .49927 m .42456 .49779 L .42718 .49693 L F
.59158 .49932 m .5929 .49712 L .59428 .4985 L 0 .027 .127 r
F
.59158 .49932 m .5902 .49792 L .5929 .49712 L F
.3569 .49858 m .35789 .49621 L .35949 .49768 L 0 .025 .124 r
F
.3569 .49858 m .3553 .49711 L .35789 .49621 L F
.31214 .49884 m .31307 .49642 L .31471 .49795 L 0 .026 .125 r
F
.31214 .49884 m .3105 .49733 L .31307 .49642 L F
.54005 .49998 m .54129 .49774 L .54272 .49918 L 0 .029 .129 r
F
.54005 .49998 m .53862 .49856 L .54129 .49774 L F
.72586 .49887 m .72737 .49652 L .72863 .49811 L 0 .026 .125 r
F
.72586 .49887 m .7246 .49728 L .72737 .49652 L F
.63634 .49926 m .63772 .49699 L .63907 .49849 L 0 .027 .127 r
F
.63634 .49926 m .635 .49777 L .63772 .49699 L F
.50206 .49986 m .50325 .49756 L .50472 .49915 L 0 .029 .128 r
F
.50206 .49986 m .5006 .49828 L .50325 .49756 L F
.36367 .49838 m .36467 .4961 L .36625 .49765 L 0 .025 .124 r
F
.36367 .49838 m .36208 .49682 L .36467 .4961 L F
.43287 .49913 m .43396 .49677 L .43549 .49833 L 0 .027 .126 r
F
.43287 .49913 m .43134 .49756 L .43396 .49677 L F
.4573 .5001 m .45843 .49763 L .45994 .49919 L 0 .029 .129 r
F
.4573 .5001 m .4558 .49851 L .45843 .49763 L F
.3189 .49863 m .31984 .49633 L .32147 .49786 L 0 .026 .125 r
F
.3189 .49863 m .31727 .49711 L .31984 .49633 L F
.68111 .49922 m .68255 .49687 L .68386 .49842 L 0 .027 .126 r
F
.68111 .49922 m .6798 .49766 L .68255 .49687 L F
.59836 .49923 m .59969 .49685 L .60106 .49841 L F
.59836 .49923 m .59698 .49769 L .59969 .49685 L F
.46407 .4998 m .46521 .49757 L .46671 .49901 L 0 .029 .128 r
F
.46407 .4998 m .46257 .49835 L .46521 .49757 L F
.3881 .49943 m .38913 .49704 L .3907 .49865 L 0 .028 .127 r
F
.3881 .49943 m .38654 .49782 L .38913 .49704 L F
.54682 .49985 m .54808 .49752 L .5495 .49899 L 0 .029 .128 r
F
.54682 .49985 m .5454 .49835 L .54808 .49752 L F
.64313 .49925 m .64452 .49695 L .64586 .49849 L 0 .028 .127 r
F
.64313 .49925 m .64179 .49773 L .64452 .49695 L F
.5536 .49963 m .55487 .49737 L .55628 .49882 L 0 .028 .128 r
F
.5536 .49963 m .55218 .49816 L .55487 .49737 L F
.47085 .49966 m .47199 .49735 L .47349 .4988 L F
.47085 .49966 m .46935 .49823 L .47199 .49735 L F
.43963 .49917 m .44073 .49694 L .44225 .49846 L 0 .028 .127 r
F
.43963 .49917 m .43811 .49763 L .44073 .49694 L F
.6879 .49917 m .68935 .49675 L .69065 .49832 L 0 .027 .127 r
F
.6879 .49917 m .6866 .49762 L .68935 .49675 L F
.60515 .49918 m .60648 .49676 L .60785 .49837 L F
.60515 .49918 m .60377 .4976 L .60648 .49676 L F
.32566 .49864 m .3266 .49628 L .32822 .49784 L 0 .026 .125 r
F
.32566 .49864 m .32403 .4971 L .3266 .49628 L F
.50884 .49996 m .51004 .49751 L .51149 .49907 L 0 .029 .129 r
F
.50884 .49996 m .50738 .49838 L .51004 .49751 L F
.47762 .49941 m .47878 .49707 L .48026 .49856 L 0 .028 .128 r
F
.47762 .49941 m .47613 .49794 L .47878 .49707 L F
.56038 .49943 m .56165 .49716 L .56306 .49859 L F
.56038 .49943 m .55897 .49801 L .56165 .49716 L F
.39486 .49946 m .3959 .49719 L .39746 .49873 L F
.39486 .49946 m .3933 .49792 L .3959 .49719 L F
.4844 .49909 m .48556 .49675 L .48704 .4982 L 0 .027 .127 r
F
.4844 .49909 m .48291 .49766 L .48556 .49675 L F
.37042 .49853 m .37143 .49616 L .37301 .49777 L 0 .026 .125 r
F
.37042 .49853 m .36884 .49692 L .37143 .49616 L F
.51561 .49977 m .51682 .49734 L .51827 .49892 L 0 .029 .129 r
F
.51561 .49977 m .51416 .49817 L .51682 .49734 L F
.69469 .49902 m .69615 .49663 L .69744 .4982 L 0 .027 .127 r
F
.69469 .49902 m .6934 .49747 L .69615 .49663 L F
.56716 .49924 m .56844 .49688 L .56985 .49841 L 0 .028 .127 r
F
.56716 .49924 m .56575 .49774 L .56844 .49688 L F
.49117 .49887 m .49235 .49671 L .49382 .49816 L 0 .027 .127 r
F
.49117 .49887 m .48969 .49742 L .49235 .49671 L F
.33242 .49852 m .33337 .4962 L .33499 .49769 L 0 .026 .125 r
F
.33242 .49852 m .3308 .49702 L .33337 .4962 L F
.40163 .49928 m .40268 .4969 L .40424 .49837 L 0 .028 .128 r
F
.40163 .49928 m .40007 .49783 L .40268 .4969 L F
.4084 .49894 m .40946 .49664 L .41101 .49812 L 0 .027 .127 r
F
.4084 .49894 m .40685 .49747 L .40946 .49664 L F
.61193 .49913 m .61327 .49671 L .61464 .49832 L 0 .028 .127 r
F
.61193 .49913 m .61056 .49754 L .61327 .49671 L F
.64992 .49933 m .65132 .49689 L .65265 .49849 L 0 .028 .128 r
F
.64992 .49933 m .64859 .49773 L .65132 .49689 L F
.70148 .49882 m .70295 .49656 L .70423 .49802 L 0 .027 .127 r
F
.70148 .49882 m .70019 .49738 L .70295 .49656 L F
.33919 .4983 m .34015 .49598 L .34176 .49743 L 0 .026 .125 r
F
.33919 .4983 m .33757 .49684 L .34015 .49598 L F
.52239 .49964 m .52361 .49726 L .52505 .4988 L 0 .029 .129 r
F
.52239 .49964 m .52094 .49808 L .52361 .49726 L F
.44639 .49928 m .44751 .49698 L .44902 .49854 L 0 .028 .128 r
F
.44639 .49928 m .44488 .49772 L .44751 .49698 L F
.57394 .4991 m .57523 .49667 L .57663 .49825 L 0 .028 .127 r
F
.57394 .4991 m .57254 .49754 L .57523 .49667 L F
.41518 .49873 m .41624 .49648 L .41779 .49792 L 0 .027 .127 r
F
.41518 .49873 m .41363 .4973 L .41624 .49648 L F
.37718 .4986 m .3782 .49621 L .37977 .49783 L 0 .027 .126 r
F
.37718 .4986 m .3756 .49699 L .3782 .49621 L F
.65671 .49917 m .65811 .49666 L .65944 .49825 L 0 .028 .127 r
F
.65671 .49917 m .65538 .49757 L .65811 .49666 L F
.70826 .49861 m .70974 .49627 L .71102 .49771 L 0 .027 .126 r
F
.70826 .49861 m .70699 .49716 L .70974 .49627 L F
.34595 .49806 m .34692 .49584 L .34853 .4973 L 0 .026 .125 r
F
.34595 .49806 m .34434 .49661 L .34692 .49584 L F
.61871 .49902 m .62007 .49663 L .62143 .49816 L 0 .028 .127 r
F
.61871 .49902 m .61735 .49748 L .62007 .49663 L F
.66349 .49885 m .6649 .4964 L .66622 .49793 L 0 .027 .127 r
F
.66349 .49885 m .66217 .49733 L .6649 .4964 L F
.67027 .49853 m .6717 .49629 L .67301 .49776 L 0 .027 .126 r
F
.67027 .49853 m .66896 .49705 L .6717 .49629 L F
.71505 .49834 m .71653 .49591 L .7178 .49743 L 0 .026 .125 r
F
.71505 .49834 m .71377 .49681 L .71653 .49591 L F
.58072 .49894 m .58202 .49662 L .58341 .49812 L 0 .028 .127 r
F
.58072 .49894 m .57932 .49742 L .58202 .49662 L F
.42195 .49857 m .42302 .49633 L .42456 .49779 L 0 .027 .126 r
F
.42195 .49857 m .4204 .49712 L .42302 .49633 L F
.52916 .49952 m .53039 .49727 L .53183 .49877 L 0 .029 .129 r
F
.52916 .49952 m .52772 .49803 L .53039 .49727 L F
.49794 .49899 m .49913 .49673 L .5006 .49828 L 0 .028 .128 r
F
.49794 .49899 m .49647 .49745 L .49913 .49673 L F
.6255 .49881 m .62686 .49646 L .62821 .49795 L 0 .027 .127 r
F
.6255 .49881 m .62414 .4973 L .62686 .49646 L F
.72183 .49811 m .72333 .49569 L .7246 .49728 L 0 .026 .125 r
F
.72183 .49811 m .72056 .49652 L .72333 .49569 L F
.5875 .49872 m .58881 .49652 L .5902 .49792 L 0 .028 .127 r
F
.5875 .49872 m .58611 .4973 L .58881 .49652 L F
.35272 .498 m .3537 .49565 L .3553 .49711 L 0 .026 .125 r
F
.35272 .498 m .35111 .49653 L .3537 .49565 L F
.63228 .49857 m .63365 .49628 L .635 .49777 L 0 .027 .127 r
F
.63228 .49857 m .63093 .49709 L .63365 .49628 L F
.42872 .49842 m .42981 .49606 L .43134 .49756 L 0 .027 .126 r
F
.42872 .49842 m .42718 .49693 L .42981 .49606 L F
.30793 .49824 m .30886 .4958 L .3105 .49733 L 0 .026 .125 r
F
.30793 .49824 m .30629 .49673 L .30886 .4958 L F
.35949 .49768 m .36048 .49536 L .36208 .49682 L 0 .025 .124 r
F
.35949 .49768 m .35789 .49621 L .36048 .49536 L F
.67706 .49844 m .6785 .49621 L .6798 .49766 L 0 .027 .126 r
F
.67706 .49844 m .67575 .49699 L .6785 .49621 L F
.53594 .49938 m .53718 .49713 L .53862 .49856 L 0 .029 .129 r
F
.53594 .49938 m .53451 .49797 L .53718 .49713 L F
.38394 .49863 m .38497 .4962 L .38654 .49782 L 0 .027 .127 r
F
.38394 .49863 m .38237 .49701 L .38497 .4962 L F
.45316 .4994 m .45429 .49692 L .4558 .49851 L 0 .029 .129 r
F
.45316 .4994 m .45165 .49778 L .45429 .49692 L F
.59428 .4985 m .5956 .49632 L .59698 .49769 L 0 .027 .127 r
F
.59428 .4985 m .5929 .49712 L .5956 .49632 L F
.31471 .49795 m .31564 .49556 L .31727 .49711 L 0 .026 .125 r
F
.31471 .49795 m .31307 .49642 L .31564 .49556 L F
.54272 .49918 m .54397 .49692 L .5454 .49835 L 0 .029 .129 r
F
.54272 .49918 m .54129 .49774 L .54397 .49692 L F
.45994 .49919 m .46107 .49681 L .46257 .49835 L 0 .029 .128 r
F
.45994 .49919 m .45843 .49763 L .46107 .49681 L F
.72863 .49811 m .73014 .49575 L .7314 .49734 L 0 .026 .126 r
F
.72863 .49811 m .72737 .49652 L .73014 .49575 L F
.63907 .49849 m .64045 .49621 L .64179 .49773 L 0 .027 .127 r
F
.63907 .49849 m .63772 .49699 L .64045 .49621 L F
.43549 .49833 m .43658 .49609 L .43811 .49763 L 0 .027 .126 r
F
.43549 .49833 m .43396 .49677 L .43658 .49609 L F
.50472 .49915 m .50591 .4968 L .50738 .49838 L 0 .029 .129 r
F
.50472 .49915 m .50325 .49756 L .50591 .4968 L F
.36625 .49765 m .36725 .49537 L .36884 .49692 L 0 .026 .125 r
F
.36625 .49765 m .36467 .4961 L .36725 .49537 L F
.60106 .49841 m .60239 .49602 L .60377 .4976 L 0 .027 .127 r
F
.60106 .49841 m .59969 .49685 L .60239 .49602 L F
.68386 .49842 m .6853 .49609 L .6866 .49762 L F
.68386 .49842 m .68255 .49687 L .6853 .49609 L F
.32147 .49786 m .32241 .49556 L .32403 .4971 L 0 .026 .125 r
F
.32147 .49786 m .31984 .49633 L .32241 .49556 L F
.5495 .49899 m .55076 .4967 L .55218 .49816 L 0 .029 .128 r
F
.5495 .49899 m .54808 .49752 L .55076 .4967 L F
.46671 .49901 m .46785 .49679 L .46935 .49823 L 0 .029 .129 r
F
.46671 .49901 m .46521 .49757 L .46785 .49679 L F
.3907 .49865 m .39173 .49632 L .3933 .49792 L 0 .028 .127 r
F
.3907 .49865 m .38913 .49704 L .39173 .49632 L F
.47349 .4988 m .47464 .49645 L .47613 .49794 L 0 .028 .128 r
F
.47349 .4988 m .47199 .49735 L .47464 .49645 L F
.55628 .49882 m .55755 .49659 L .55897 .49801 L 0 .029 .128 r
F
.55628 .49882 m .55487 .49737 L .55755 .49659 L F
.64586 .49849 m .64725 .49618 L .64859 .49773 L 0 .028 .127 r
F
.64586 .49849 m .64452 .49695 L .64725 .49618 L F
.51149 .49907 m .5127 .49664 L .51416 .49817 L 0 .029 .129 r
F
.51149 .49907 m .51004 .49751 L .5127 .49664 L F
.69065 .49832 m .6921 .49588 L .6934 .49747 L 0 .027 .127 r
F
.69065 .49832 m .68935 .49675 L .6921 .49588 L F
.60785 .49837 m .60919 .49592 L .61056 .49754 L F
.60785 .49837 m .60648 .49676 L .60919 .49592 L F
.48026 .49856 m .48143 .49615 L .48291 .49766 L 0 .028 .127 r
F
.48026 .49856 m .47878 .49707 L .48143 .49615 L F
.48704 .4982 m .48821 .49597 L .48969 .49742 L 0 .027 .127 r
F
.48704 .4982 m .48556 .49675 L .48821 .49597 L F
.56306 .49859 m .56434 .49629 L .56575 .49774 L 0 .028 .128 r
F
.56306 .49859 m .56165 .49716 L .56434 .49629 L F
.32822 .49784 m .32918 .49545 L .3308 .49702 L 0 .026 .125 r
F
.32822 .49784 m .3266 .49628 L .32918 .49545 L F
.44225 .49846 m .44336 .49621 L .44488 .49772 L 0 .028 .128 r
F
.44225 .49846 m .44073 .49694 L .44336 .49621 L F
.37301 .49777 m .37402 .49538 L .3756 .49699 L 0 .026 .125 r
F
.37301 .49777 m .37143 .49616 L .37402 .49538 L F
.39746 .49873 m .39851 .4963 L .40007 .49783 L 0 .028 .128 r
F
.39746 .49873 m .3959 .49719 L .39851 .4963 L F
.51827 .49892 m .51949 .49653 L .52094 .49808 L 0 .029 .129 r
F
.51827 .49892 m .51682 .49734 L .51949 .49653 L F
.40424 .49837 m .4053 .49599 L .40685 .49747 L 0 .028 .127 r
F
.40424 .49837 m .40268 .4969 L .4053 .49599 L F
.69744 .4982 m .6989 .4958 L .70019 .49738 L 0 .027 .127 r
F
.69744 .4982 m .69615 .49663 L .6989 .4958 L F
.56985 .49841 m .57113 .49598 L .57254 .49754 L 0 .028 .127 r
F
.56985 .49841 m .56844 .49688 L .57113 .49598 L F
.33499 .49769 m .33595 .49536 L .33757 .49684 L 0 .026 .125 r
F
.33499 .49769 m .33337 .4962 L .33595 .49536 L F
.65265 .49849 m .65405 .49598 L .65538 .49757 L 0 .028 .127 r
F
.65265 .49849 m .65132 .49689 L .65405 .49598 L F
.41101 .49812 m .41208 .49581 L .41363 .4973 L 0 .027 .127 r
F
.41101 .49812 m .40946 .49664 L .41208 .49581 L F
.61464 .49832 m .61599 .49588 L .61735 .49748 L 0 .028 .127 r
F
.61464 .49832 m .61327 .49671 L .61599 .49588 L F
.49382 .49816 m .495 .496 L .49647 .49745 L F
.49382 .49816 m .49235 .49671 L .495 .496 L F
.34176 .49743 m .34273 .49517 L .34434 .49661 L 0 .026 .125 r
F
.34176 .49743 m .34015 .49598 L .34273 .49517 L F
.70423 .49802 m .70571 .4957 L .70699 .49716 L 0 .027 .127 r
F
.70423 .49802 m .70295 .49656 L .70571 .4957 L F
.52505 .4988 m .52628 .49647 L .52772 .49803 L 0 .029 .129 r
F
.52505 .4988 m .52361 .49726 L .52628 .49647 L F
.65944 .49825 m .66084 .49574 L .66217 .49733 L 0 .027 .127 r
F
.65944 .49825 m .65811 .49666 L .66084 .49574 L F
.57663 .49825 m .57792 .49583 L .57932 .49742 L 0 .028 .127 r
F
.57663 .49825 m .57523 .49667 L .57792 .49583 L F
.71102 .49771 m .7125 .49538 L .71377 .49681 L 0 .027 .126 r
F
.71102 .49771 m .70974 .49627 L .7125 .49538 L F
.41779 .49792 m .41886 .49566 L .4204 .49712 L 0 .027 .127 r
F
.41779 .49792 m .41624 .49648 L .41886 .49566 L F
.66622 .49793 m .66764 .49552 L .66896 .49705 L 0 .027 .126 r
F
.66622 .49793 m .6649 .4964 L .66764 .49552 L F
.62143 .49816 m .62278 .49579 L .62414 .4973 L 0 .028 .127 r
F
.62143 .49816 m .62007 .49663 L .62278 .49579 L F
.44902 .49854 m .45014 .49622 L .45165 .49778 L 0 .029 .128 r
F
.44902 .49854 m .44751 .49698 L .45014 .49622 L F
.7178 .49743 m .71929 .495 L .72056 .49652 L 0 .026 .125 r
F
.7178 .49743 m .71653 .49591 L .71929 .495 L F
.37977 .49783 m .38079 .49542 L .38237 .49701 L 0 .027 .126 r
F
.37977 .49783 m .3782 .49621 L .38079 .49542 L F
.34853 .4973 m .3495 .49507 L .35111 .49653 L 0 .026 .125 r
F
.34853 .4973 m .34692 .49584 L .3495 .49507 L F
.58341 .49812 m .58472 .49582 L .58611 .4973 L 0 .028 .127 r
F
.58341 .49812 m .58202 .49662 L .58472 .49582 L F
.67301 .49776 m .67445 .49553 L .67575 .49699 L 0 .027 .127 r
F
.67301 .49776 m .6717 .49629 L .67445 .49553 L F
.62821 .49795 m .62958 .49562 L .63093 .49709 L F
.62821 .49795 m .62686 .49646 L .62958 .49562 L F
.42456 .49779 m .42565 .49544 L .42718 .49693 L 0 .027 .126 r
F
.42456 .49779 m .42302 .49633 L .42565 .49544 L F
.53183 .49877 m .53307 .49645 L .53451 .49797 L 0 .029 .129 r
F
.53183 .49877 m .53039 .49727 L .53307 .49645 L F
.7246 .49728 m .7261 .49492 L .72737 .49652 L 0 .026 .125 r
F
.7246 .49728 m .72333 .49569 L .7261 .49492 L F
.3553 .49711 m .35629 .49475 L .35789 .49621 L F
.3553 .49711 m .3537 .49565 L .35629 .49475 L F
.3105 .49733 m .31143 .49487 L .31307 .49642 L F
.3105 .49733 m .30886 .4958 L .31143 .49487 L F
.5006 .49828 m .50179 .496 L .50325 .49756 L 0 .028 .128 r
F
.5006 .49828 m .49913 .49673 L .50179 .496 L F
.5902 .49792 m .59152 .49574 L .5929 .49712 L 0 .028 .127 r
F
.5902 .49792 m .58881 .49652 L .59152 .49574 L F
.43134 .49756 m .43243 .49525 L .43396 .49677 L 0 .027 .126 r
F
.43134 .49756 m .42981 .49606 L .43243 .49525 L F
.4558 .49851 m .45693 .49607 L .45843 .49763 L 0 .029 .128 r
F
.4558 .49851 m .45429 .49692 L .45693 .49607 L F
.36208 .49682 m .36307 .49463 L .36467 .4961 L 0 .025 .124 r
F
.36208 .49682 m .36048 .49536 L .36307 .49463 L F
.635 .49777 m .63638 .49548 L .63772 .49699 L 0 .027 .127 r
F
.635 .49777 m .63365 .49628 L .63638 .49548 L F
.53862 .49856 m .53986 .49629 L .54129 .49774 L 0 .029 .129 r
F
.53862 .49856 m .53718 .49713 L .53986 .49629 L F
.38654 .49782 m .38757 .49543 L .38913 .49704 L 0 .027 .127 r
F
.38654 .49782 m .38497 .4962 L .38757 .49543 L F
.6798 .49766 m .68125 .49544 L .68255 .49687 L F
.6798 .49766 m .6785 .49621 L .68125 .49544 L F
.31727 .49711 m .31821 .49478 L .31984 .49633 L 0 .026 .125 r
F
.31727 .49711 m .31564 .49556 L .31821 .49478 L F
.59698 .49769 m .59831 .49546 L .59969 .49685 L 0 .027 .127 r
F
.59698 .49769 m .5956 .49632 L .59831 .49546 L F
.46257 .49835 m .46371 .49605 L .46521 .49757 L 0 .029 .129 r
F
.46257 .49835 m .46107 .49681 L .46371 .49605 L F
.5454 .49835 m .54665 .4961 L .54808 .49752 L F
.5454 .49835 m .54397 .49692 L .54665 .4961 L F
.7314 .49734 m .73291 .49497 L .73418 .49655 L 0 .027 .126 r
F
.7314 .49734 m .73014 .49575 L .73291 .49497 L F
.64179 .49773 m .64318 .49542 L .64452 .49695 L 0 .028 .127 r
F
.64179 .49773 m .64045 .49621 L .64318 .49542 L F
.55218 .49816 m .55345 .49594 L .55487 .49737 L 0 .029 .129 r
F
.55218 .49816 m .55076 .4967 L .55345 .49594 L F
.60377 .4976 m .6051 .49517 L .60648 .49676 L 0 .027 .127 r
F
.60377 .4976 m .60239 .49602 L .6051 .49517 L F
.6866 .49762 m .68805 .4952 L .68935 .49675 L F
.6866 .49762 m .6853 .49609 L .68805 .4952 L F
.50738 .49838 m .50858 .49595 L .51004 .49751 L 0 .029 .129 r
F
.50738 .49838 m .50591 .4968 L .50858 .49595 L F
.43811 .49763 m .43921 .49542 L .44073 .49694 L 0 .028 .127 r
F
.43811 .49763 m .43658 .49609 L .43921 .49542 L F
.46935 .49823 m .4705 .49588 L .47199 .49735 L 0 .029 .129 r
F
.46935 .49823 m .46785 .49679 L .4705 .49588 L F
.32403 .4971 m .32498 .49473 L .3266 .49628 L 0 .026 .125 r
F
.32403 .4971 m .32241 .49556 L .32498 .49473 L F
.36884 .49692 m .36985 .4946 L .37143 .49616 L F
.36884 .49692 m .36725 .49537 L .36985 .4946 L F
.3933 .49792 m .39434 .49561 L .3959 .49719 L 0 .028 .128 r
F
.3933 .49792 m .39173 .49632 L .39434 .49561 L F
.47613 .49794 m .47729 .49555 L .47878 .49707 L F
.47613 .49794 m .47464 .49645 L .47729 .49555 L F
.51416 .49817 m .51537 .49584 L .51682 .49734 L 0 .029 .129 r
F
.51416 .49817 m .5127 .49664 L .51537 .49584 L F
.55897 .49801 m .56024 .49574 L .56165 .49716 L 0 .029 .128 r
F
.55897 .49801 m .55755 .49659 L .56024 .49574 L F
.48291 .49766 m .48408 .49524 L .48556 .49675 L 0 .028 .127 r
F
.48291 .49766 m .48143 .49615 L .48408 .49524 L F
.6934 .49747 m .69485 .49502 L .69615 .49663 L 0 .027 .126 r
F
.6934 .49747 m .6921 .49588 L .69485 .49502 L F
.61056 .49754 m .6119 .49507 L .61327 .49671 L 0 .027 .127 r
F
.61056 .49754 m .60919 .49592 L .6119 .49507 L F
.64859 .49773 m .64998 .49534 L .65132 .49689 L 0 .028 .127 r
F
.64859 .49773 m .64725 .49618 L .64998 .49534 L F
.56575 .49774 m .56703 .49542 L .56844 .49688 L 0 .028 .128 r
F
.56575 .49774 m .56434 .49629 L .56703 .49542 L F
.3308 .49702 m .33176 .49461 L .33337 .4962 L 0 .026 .125 r
F
.3308 .49702 m .32918 .49545 L .33176 .49461 L F
.48969 .49742 m .49087 .49526 L .49235 .49671 L 0 .028 .127 r
F
.48969 .49742 m .48821 .49597 L .49087 .49526 L F
.40007 .49783 m .40112 .49538 L .40268 .4969 L 0 .028 .128 r
F
.40007 .49783 m .39851 .4963 L .40112 .49538 L F
.40685 .49747 m .40791 .49516 L .40946 .49664 L 0 .028 .127 r
F
.40685 .49747 m .4053 .49599 L .40791 .49516 L F
.52094 .49808 m .52216 .49571 L .52361 .49726 L 0 .029 .129 r
F
.52094 .49808 m .51949 .49653 L .52216 .49571 L F
.44488 .49772 m .44599 .49547 L .44751 .49698 L 0 .028 .128 r
F
.44488 .49772 m .44336 .49621 L .44599 .49547 L F
.57254 .49754 m .57383 .49508 L .57523 .49667 L 0 .028 .127 r
F
.57254 .49754 m .57113 .49598 L .57383 .49508 L F
.3756 .49699 m .37662 .4946 L .3782 .49621 L 0 .027 .126 r
F
.3756 .49699 m .37402 .49538 L .37662 .4946 L F
.70019 .49738 m .70166 .49496 L .70295 .49656 L 0 .027 .127 r
F
.70019 .49738 m .6989 .4958 L .70166 .49496 L F
.65538 .49757 m .65678 .49507 L .65811 .49666 L 0 .028 .127 r
F
.65538 .49757 m .65405 .49598 L .65678 .49507 L F
.33757 .49684 m .33853 .49451 L .34015 .49598 L 0 .026 .125 r
F
.33757 .49684 m .33595 .49536 L .33853 .49451 L F
.61735 .49748 m .6187 .49505 L .62007 .49663 L 0 .028 .127 r
F
.61735 .49748 m .61599 .49588 L .6187 .49505 L F
.41363 .4973 m .4147 .49497 L .41624 .49648 L 0 .027 .127 r
F
.41363 .4973 m .41208 .49581 L .4147 .49497 L F
.66217 .49733 m .66358 .49482 L .6649 .4964 L F
.66217 .49733 m .66084 .49574 L .66358 .49482 L F
.70699 .49716 m .70846 .49482 L .70974 .49627 L 0 .027 .126 r
F
.70699 .49716 m .70571 .4957 L .70846 .49482 L F
.34434 .49661 m .34531 .4944 L .34692 .49584 L 0 .026 .125 r
F
.34434 .49661 m .34273 .49517 L .34531 .4944 L F
.71377 .49681 m .71526 .49448 L .71653 .49591 L 0 .026 .126 r
F
.71377 .49681 m .7125 .49538 L .71526 .49448 L F
.57932 .49742 m .58062 .49504 L .58202 .49662 L 0 .028 .127 r
F
.57932 .49742 m .57792 .49583 L .58062 .49504 L F
.66896 .49705 m .67039 .49477 L .6717 .49629 L 0 .027 .126 r
F
.66896 .49705 m .66764 .49552 L .67039 .49477 L F
.49647 .49745 m .49766 .49525 L .49913 .49673 L 0 .028 .128 r
F
.49647 .49745 m .495 .496 L .49766 .49525 L F
.72056 .49652 m .72206 .49417 L .72333 .49569 L 0 .026 .125 r
F
.72056 .49652 m .71929 .495 L .72206 .49417 L F
.52772 .49803 m .52895 .49568 L .53039 .49727 L 0 .029 .129 r
F
.52772 .49803 m .52628 .49647 L .52895 .49568 L F
.62414 .4973 m .62551 .49497 L .62686 .49646 L 0 .028 .127 r
F
.62414 .4973 m .62278 .49579 L .62551 .49497 L F
.4204 .49712 m .42148 .49483 L .42302 .49633 L 0 .027 .127 r
F
.4204 .49712 m .41886 .49566 L .42148 .49483 L F
.38237 .49701 m .3834 .49463 L .38497 .4962 L 0 .027 .126 r
F
.38237 .49701 m .38079 .49542 L .3834 .49463 L F
.45165 .49778 m .45278 .49539 L .45429 .49692 L 0 .029 .128 r
F
.45165 .49778 m .45014 .49622 L .45278 .49539 L F
.63093 .49709 m .63231 .49479 L .63365 .49628 L 0 .027 .127 r
F
.63093 .49709 m .62958 .49562 L .63231 .49479 L F
.35111 .49653 m .3521 .49418 L .3537 .49565 L 0 .026 .125 r
F
.35111 .49653 m .3495 .49507 L .3521 .49418 L F
.30629 .49673 m .30722 .49427 L .30886 .4958 L F
.30629 .49673 m .30465 .49522 L .30722 .49427 L F
.58611 .4973 m .58742 .49505 L .58881 .49652 L 0 .028 .128 r
F
.58611 .4973 m .58472 .49582 L .58742 .49505 L F
.42718 .49693 m .42827 .49455 L .42981 .49606 L 0 .027 .126 r
F
.42718 .49693 m .42565 .49544 L .42827 .49455 L F
.35789 .49621 m .35888 .4939 L .36048 .49536 L 0 .026 .124 r
F
.35789 .49621 m .35629 .49475 L .35888 .4939 L F
.31307 .49642 m .31401 .49399 L .31564 .49556 L 0 .026 .125 r
F
.31307 .49642 m .31143 .49487 L .31401 .49399 L F
.67575 .49699 m .6772 .49477 L .6785 .49621 L 0 .027 .127 r
F
.67575 .49699 m .67445 .49553 L .6772 .49477 L F
.53451 .49797 m .53575 .49559 L .53718 .49713 L 0 .029 .129 r
F
.53451 .49797 m .53307 .49645 L .53575 .49559 L F
.45843 .49763 m .45957 .49527 L .46107 .49681 L 0 .029 .128 r
F
.45843 .49763 m .45693 .49607 L .45957 .49527 L F
.72737 .49652 m .72887 .49415 L .73014 .49575 L 0 .026 .125 r
F
.72737 .49652 m .7261 .49492 L .72887 .49415 L F
.5929 .49712 m .59422 .49494 L .5956 .49632 L 0 .028 .127 r
F
.5929 .49712 m .59152 .49574 L .59422 .49494 L F
.43396 .49677 m .43506 .49456 L .43658 .49609 L 0 .027 .126 r
F
.43396 .49677 m .43243 .49525 L .43506 .49456 L F
.54129 .49774 m .54254 .49549 L .54397 .49692 L 0 .029 .129 r
F
.54129 .49774 m .53986 .49629 L .54254 .49549 L F
.63772 .49699 m .63911 .49469 L .64045 .49621 L 0 .028 .127 r
F
.63772 .49699 m .63638 .49548 L .63911 .49469 L F
.50325 .49756 m .50445 .49524 L .50591 .4968 L 0 .029 .129 r
F
.50325 .49756 m .50179 .496 L .50445 .49524 L F
.36467 .4961 m .36566 .4939 L .36725 .49537 L 0 .026 .125 r
F
.36467 .4961 m .36307 .49463 L .36566 .4939 L F
.38913 .49704 m .39017 .49473 L .39173 .49632 L 0 .028 .127 r
F
.38913 .49704 m .38757 .49543 L .39017 .49473 L F
.59969 .49685 m .60102 .4946 L .60239 .49602 L 0 .027 .127 r
F
.59969 .49685 m .59831 .49546 L .60102 .4946 L F
.68255 .49687 m .684 .49466 L .6853 .49609 L F
.68255 .49687 m .68125 .49544 L .684 .49466 L F
.31984 .49633 m .32078 .494 L .32241 .49556 L 0 .026 .125 r
F
.31984 .49633 m .31821 .49478 L .32078 .494 L F
.54808 .49752 m .54934 .4953 L .55076 .4967 L 0 .029 .129 r
F
.54808 .49752 m .54665 .4961 L .54934 .4953 L F
.46521 .49757 m .46635 .49529 L .46785 .49679 L F
.46521 .49757 m .46371 .49605 L .46635 .49529 L F
.73418 .49655 m .73569 .49419 L .73695 .49577 L 0 .027 .126 r
F
.73418 .49655 m .73291 .49497 L .73569 .49419 L F
.68935 .49675 m .6908 .49431 L .6921 .49588 L F
.68935 .49675 m .68805 .4952 L .6908 .49431 L F
.51004 .49751 m .51124 .49511 L .5127 .49664 L 0 .029 .129 r
F
.51004 .49751 m .50858 .49595 L .51124 .49511 L F
.60648 .49676 m .60781 .49431 L .60919 .49592 L 0 .027 .126 r
F
.60648 .49676 m .6051 .49517 L .60781 .49431 L F
.64452 .49695 m .64591 .49463 L .64725 .49618 L 0 .028 .127 r
F
.64452 .49695 m .64318 .49542 L .64591 .49463 L F
.47199 .49735 m .47315 .49496 L .47464 .49645 L 0 .029 .128 r
F
.47199 .49735 m .4705 .49588 L .47315 .49496 L F
.55487 .49737 m .55613 .49518 L .55755 .49659 L 0 .029 .129 r
F
.55487 .49737 m .55345 .49594 L .55613 .49518 L F
.3266 .49628 m .32756 .49387 L .32918 .49545 L 0 .026 .125 r
F
.3266 .49628 m .32498 .49473 L .32756 .49387 L F
.47878 .49707 m .47994 .49462 L .48143 .49615 L 0 .028 .128 r
F
.47878 .49707 m .47729 .49555 L .47994 .49462 L F
.37143 .49616 m .37244 .49381 L .37402 .49538 L 0 .026 .125 r
F
.37143 .49616 m .36985 .4946 L .37244 .49381 L F
.44073 .49694 m .44184 .4947 L .44336 .49621 L 0 .028 .128 r
F
.44073 .49694 m .43921 .49542 L .44184 .4947 L F
.48556 .49675 m .48673 .49444 L .48821 .49597 L 0 .028 .127 r
F
.48556 .49675 m .48408 .49524 L .48673 .49444 L F
.51682 .49734 m .51804 .49505 L .51949 .49653 L 0 .029 .129 r
F
.51682 .49734 m .51537 .49584 L .51804 .49505 L F
.56165 .49716 m .56293 .49486 L .56434 .49629 L 0 .029 .128 r
F
.56165 .49716 m .56024 .49574 L .56293 .49486 L F
.3959 .49719 m .39695 .49473 L .39851 .4963 L 0 .028 .128 r
F
.3959 .49719 m .39434 .49561 L .39695 .49473 L F
.69615 .49663 m .69761 .49416 L .6989 .4958 L 0 .027 .126 r
F
.69615 .49663 m .69485 .49502 L .69761 .49416 L F
.56844 .49688 m .56973 .49451 L .57113 .49598 L 0 .028 .127 r
F
.56844 .49688 m .56703 .49542 L .56973 .49451 L F
.65132 .49689 m .65272 .49444 L .65405 .49598 L F
.65132 .49689 m .64998 .49534 L .65272 .49444 L F
.61327 .49671 m .61462 .49426 L .61599 .49588 L 0 .027 .127 r
F
.61327 .49671 m .6119 .49507 L .61462 .49426 L F
.40268 .4969 m .40374 .49447 L .4053 .49599 L 0 .028 .127 r
F
.40268 .4969 m .40112 .49538 L .40374 .49447 L F
.33337 .4962 m .33434 .49376 L .33595 .49536 L 0 .026 .125 r
F
.33337 .4962 m .33176 .49461 L .33434 .49376 L F
.40946 .49664 m .41053 .49433 L .41208 .49581 L 0 .028 .127 r
F
.40946 .49664 m .40791 .49516 L .41053 .49433 L F
.65811 .49666 m .65952 .49415 L .66084 .49574 L 0 .027 .127 r
F
.65811 .49666 m .65678 .49507 L .65952 .49415 L F
.57523 .49667 m .57652 .49423 L .57792 .49583 L 0 .028 .127 r
F
.57523 .49667 m .57383 .49508 L .57652 .49423 L F
.52361 .49726 m .52483 .4949 L .52628 .49647 L 0 .029 .129 r
F
.52361 .49726 m .52216 .49571 L .52483 .4949 L F
.49235 .49671 m .49352 .49454 L .495 .496 L 0 .028 .128 r
F
.49235 .49671 m .49087 .49526 L .49352 .49454 L F
.34015 .49598 m .34111 .4937 L .34273 .49517 L 0 .026 .125 r
F
.34015 .49598 m .33853 .49451 L .34111 .4937 L F
.70295 .49656 m .70442 .4941 L .70571 .4957 L 0 .027 .127 r
F
.70295 .49656 m .70166 .49496 L .70442 .4941 L F
.3782 .49621 m .37922 .49383 L .38079 .49542 L 0 .027 .126 r
F
.3782 .49621 m .37662 .4946 L .37922 .49383 L F
.6649 .4964 m .66632 .49395 L .66764 .49552 L F
.6649 .4964 m .66358 .49482 L .66632 .49395 L F
.44751 .49698 m .44862 .49472 L .45014 .49622 L 0 .029 .128 r
F
.44751 .49698 m .44599 .49547 L .44862 .49472 L F
.62007 .49663 m .62142 .49423 L .62278 .49579 L 0 .028 .127 r
F
.62007 .49663 m .6187 .49505 L .62142 .49423 L F
.70974 .49627 m .71123 .49394 L .7125 .49538 L 0 .027 .126 r
F
.70974 .49627 m .70846 .49482 L .71123 .49394 L F
.71653 .49591 m .71802 .49358 L .71929 .495 L 0 .026 .125 r
F
.71653 .49591 m .71526 .49448 L .71802 .49358 L F
.41624 .49648 m .41732 .49412 L .41886 .49566 L 0 .027 .127 r
F
.41624 .49648 m .4147 .49497 L .41732 .49412 L F
.34692 .49584 m .34789 .49362 L .3495 .49507 L 0 .026 .125 r
F
.34692 .49584 m .34531 .4944 L .34789 .49362 L F
.58202 .49662 m .58333 .49425 L .58472 .49582 L 0 .028 .127 r
F
.58202 .49662 m .58062 .49504 L .58333 .49425 L F
.72333 .49569 m .72483 .49339 L .7261 .49492 L 0 .026 .125 r
F
.72333 .49569 m .72206 .49417 L .72483 .49339 L F
.62686 .49646 m .62823 .49415 L .62958 .49562 L 0 .028 .127 r
F
.62686 .49646 m .62551 .49497 L .62823 .49415 L F
.6717 .49629 m .67313 .49401 L .67445 .49553 L 0 .027 .127 r
F
.6717 .49629 m .67039 .49477 L .67313 .49401 L F
.42302 .49633 m .42411 .49394 L .42565 .49544 L F
.42302 .49633 m .42148 .49483 L .42411 .49394 L F
.53039 .49727 m .53163 .49484 L .53307 .49645 L 0 .029 .129 r
F
.53039 .49727 m .52895 .49568 L .53163 .49484 L F
.49913 .49673 m .50032 .4945 L .50179 .496 L 0 .028 .128 r
F
.49913 .49673 m .49766 .49525 L .50032 .4945 L F
.45429 .49692 m .45542 .49455 L .45693 .49607 L 0 .029 .128 r
F
.45429 .49692 m .45278 .49539 L .45542 .49455 L F
.30886 .4958 m .3098 .49331 L .31143 .49487 L 0 .026 .125 r
F
.30886 .4958 m .30722 .49427 L .3098 .49331 L F
.38497 .4962 m .386 .49388 L .38757 .49543 L 0 .027 .127 r
F
.38497 .4962 m .3834 .49463 L .386 .49388 L F
.3537 .49565 m .35469 .49328 L .35629 .49475 L 0 .026 .125 r
F
.3537 .49565 m .3521 .49418 L .35469 .49328 L F
.42981 .49606 m .4309 .49373 L .43243 .49525 L 0 .027 .126 r
F
.42981 .49606 m .42827 .49455 L .4309 .49373 L F
.63365 .49628 m .63503 .49398 L .63638 .49548 L 0 .028 .127 r
F
.63365 .49628 m .63231 .49479 L .63503 .49398 L F
.36048 .49536 m .36147 .49316 L .36307 .49463 L 0 .026 .125 r
F
.36048 .49536 m .35888 .4939 L .36147 .49316 L F
.31564 .49556 m .31657 .49321 L .31821 .49478 L F
.31564 .49556 m .31401 .49399 L .31657 .49321 L F
.58881 .49652 m .59013 .49429 L .59152 .49574 L 0 .028 .128 r
F
.58881 .49652 m .58742 .49505 L .59013 .49429 L F
.53718 .49713 m .53843 .49473 L .53986 .49629 L 0 .029 .129 r
F
.53718 .49713 m .53575 .49559 L .53843 .49473 L F
.6785 .49621 m .67995 .49401 L .68125 .49544 L 0 .028 .127 r
F
.6785 .49621 m .6772 .49477 L .67995 .49401 L F
.46107 .49681 m .46221 .49453 L .46371 .49605 L 0 .029 .129 r
F
.46107 .49681 m .45957 .49527 L .46221 .49453 L F
.73014 .49575 m .73165 .49338 L .73291 .49497 L 0 .026 .126 r
F
.73014 .49575 m .72887 .49415 L .73165 .49338 L F
.5956 .49632 m .59693 .49406 L .59831 .49546 L 0 .028 .127 r
F
.5956 .49632 m .59422 .49494 L .59693 .49406 L F
.54397 .49692 m .54522 .49468 L .54665 .4961 L 0 .029 .129 r
F
.54397 .49692 m .54254 .49549 L .54522 .49468 L F
.60239 .49602 m .60373 .49373 L .6051 .49517 L 0 .027 .127 r
F
.60239 .49602 m .60102 .4946 L .60373 .49373 L F
.64045 .49621 m .64184 .49388 L .64318 .49542 L 0 .028 .127 r
F
.64045 .49621 m .63911 .49469 L .64184 .49388 L F
.50591 .4968 m .50711 .49441 L .50858 .49595 L 0 .029 .129 r
F
.50591 .4968 m .50445 .49524 L .50711 .49441 L F
.6853 .49609 m .68675 .49375 L .68805 .4952 L 0 .027 .127 r
F
.6853 .49609 m .684 .49466 L .68675 .49375 L F
.43658 .49609 m .43768 .49388 L .43921 .49542 L 0 .028 .127 r
F
.43658 .49609 m .43506 .49456 L .43768 .49388 L F
.36725 .49537 m .36825 .49312 L .36985 .4946 L 0 .026 .125 r
F
.36725 .49537 m .36566 .4939 L .36825 .49312 L F
.32241 .49556 m .32335 .49315 L .32498 .49473 L F
.32241 .49556 m .32078 .494 L .32335 .49315 L F
.39173 .49632 m .39277 .49402 L .39434 .49561 L 0 .028 .128 r
F
.39173 .49632 m .39017 .49473 L .39277 .49402 L F
.55076 .4967 m .55202 .49455 L .55345 .49594 L 0 .029 .129 r
F
.55076 .4967 m .54934 .4953 L .55202 .49455 L F
.46785 .49679 m .469 .4944 L .4705 .49588 L F
.46785 .49679 m .46635 .49529 L .469 .4944 L F
.6921 .49588 m .69355 .49342 L .69485 .49502 L 0 .027 .126 r
F
.6921 .49588 m .6908 .49431 L .69355 .49342 L F
.47464 .49645 m .4758 .49403 L .47729 .49555 L 0 .028 .128 r
F
.47464 .49645 m .47315 .49496 L .4758 .49403 L F
.5127 .49664 m .51391 .49434 L .51537 .49584 L 0 .029 .129 r
F
.5127 .49664 m .51124 .49511 L .51391 .49434 L F
.60919 .49592 m .61053 .49344 L .6119 .49507 L 0 .027 .126 r
F
.60919 .49592 m .60781 .49431 L .61053 .49344 L F
.73695 .49577 m .73847 .49337 L .73973 .49495 L F
.73695 .49577 m .73569 .49419 L .73847 .49337 L F
.48143 .49615 m .48259 .4937 L .48408 .49524 L 0 .028 .127 r
F
.48143 .49615 m .47994 .49462 L .48259 .4937 L F
.64725 .49618 m .64865 .49379 L .64998 .49534 L F
.64725 .49618 m .64591 .49463 L .64865 .49379 L F
.32918 .49545 m .33014 .49302 L .33176 .49461 L 0 .026 .125 r
F
.32918 .49545 m .32756 .49387 L .33014 .49302 L F
.55755 .49659 m .55882 .49432 L .56024 .49574 L 0 .029 .129 r
F
.55755 .49659 m .55613 .49518 L .55882 .49432 L F
.56434 .49629 m .56562 .49398 L .56703 .49542 L 0 .028 .128 r
F
.56434 .49629 m .56293 .49486 L .56562 .49398 L F
.39851 .4963 m .39956 .49382 L .40112 .49538 L F
.39851 .4963 m .39695 .49473 L .39956 .49382 L F
.37402 .49538 m .37504 .49302 L .37662 .4946 L 0 .026 .125 r
F
.37402 .49538 m .37244 .49381 L .37504 .49302 L F
.51949 .49653 m .52071 .49426 L .52216 .49571 L 0 .029 .129 r
F
.51949 .49653 m .51804 .49505 L .52071 .49426 L F
.48821 .49597 m .48939 .49372 L .49087 .49526 L 0 .028 .127 r
F
.48821 .49597 m .48673 .49444 L .48939 .49372 L F
.65405 .49598 m .65545 .49353 L .65678 .49507 L F
.65405 .49598 m .65272 .49444 L .65545 .49353 L F
.57113 .49598 m .57242 .4936 L .57383 .49508 L F
.57113 .49598 m .56973 .49451 L .57242 .4936 L F
.6989 .4958 m .70036 .49331 L .70166 .49496 L 0 .027 .126 r
F
.6989 .4958 m .69761 .49416 L .70036 .49331 L F
.4053 .49599 m .40636 .49365 L .40791 .49516 L 0 .028 .127 r
F
.4053 .49599 m .40374 .49447 L .40636 .49365 L F
.44336 .49621 m .44447 .49396 L .44599 .49547 L 0 .028 .128 r
F
.44336 .49621 m .44184 .4947 L .44447 .49396 L F
.61599 .49588 m .61734 .49345 L .6187 .49505 L 0 .027 .127 r
F
.61599 .49588 m .61462 .49426 L .61734 .49345 L F
.33595 .49536 m .33692 .49292 L .33853 .49451 L 0 .026 .125 r
F
.33595 .49536 m .33434 .49376 L .33692 .49292 L F
.66084 .49574 m .66225 .49324 L .66358 .49482 L 0 .027 .126 r
F
.66084 .49574 m .65952 .49415 L .66225 .49324 L F
.41208 .49581 m .41315 .49347 L .4147 .49497 L 0 .028 .127 r
F
.41208 .49581 m .41053 .49433 L .41315 .49347 L F
.57792 .49583 m .57922 .49346 L .58062 .49504 L F
.57792 .49583 m .57652 .49423 L .57922 .49346 L F
.70571 .4957 m .70718 .49324 L .70846 .49482 L 0 .027 .127 r
F
.70571 .4957 m .70442 .4941 L .70718 .49324 L F
.66764 .49552 m .66907 .49318 L .67039 .49477 L 0 .027 .126 r
F
.66764 .49552 m .66632 .49395 L .66907 .49318 L F
.52628 .49647 m .52751 .49409 L .52895 .49568 L 0 .029 .129 r
F
.52628 .49647 m .52483 .4949 L .52751 .49409 L F
.34273 .49517 m .3437 .49292 L .34531 .4944 L 0 .026 .126 r
F
.34273 .49517 m .34111 .4937 L .3437 .49292 L F
.71929 .495 m .72079 .49274 L .72206 .49417 L 0 .026 .125 r
F
.71929 .495 m .71802 .49358 L .72079 .49274 L F
.7125 .49538 m .71399 .49305 L .71526 .49448 L 0 .027 .126 r
F
.7125 .49538 m .71123 .49394 L .71399 .49305 L F
.62278 .49579 m .62415 .49342 L .62551 .49497 L 0 .028 .127 r
F
.62278 .49579 m .62142 .49423 L .62415 .49342 L F
.38079 .49542 m .38182 .49306 L .3834 .49463 L 0 .027 .126 r
F
.38079 .49542 m .37922 .49383 L .38182 .49306 L F
.495 .496 m .49618 .49377 L .49766 .49525 L 0 .028 .128 r
F
.495 .496 m .49352 .49454 L .49618 .49377 L F
.41886 .49566 m .41994 .49327 L .42148 .49483 L 0 .027 .127 r
F
.41886 .49566 m .41732 .49412 L .41994 .49327 L F
.45014 .49622 m .45126 .49391 L .45278 .49539 L 0 .029 .129 r
F
.45014 .49622 m .44862 .49472 L .45126 .49391 L F
.30465 .49522 m .30557 .49273 L .30722 .49427 L 0 .026 .126 r
F
.30465 .49522 m .303 .49367 L .30557 .49273 L F
.62958 .49562 m .63095 .49331 L .63231 .49479 L 0 .028 .127 r
F
.62958 .49562 m .62823 .49415 L .63095 .49331 L F
.31143 .49487 m .31237 .49242 L .31401 .49399 L 0 .026 .125 r
F
.31143 .49487 m .3098 .49331 L .31237 .49242 L F
.58472 .49582 m .58603 .49349 L .58742 .49505 L 0 .028 .128 r
F
.58472 .49582 m .58333 .49425 L .58603 .49349 L F
.42565 .49544 m .42674 .49303 L .42827 .49455 L 0 .027 .126 r
F
.42565 .49544 m .42411 .49394 L .42674 .49303 L F
.3495 .49507 m .35049 .49272 L .3521 .49418 L 0 .026 .125 r
F
.3495 .49507 m .34789 .49362 L .35049 .49272 L F
.7261 .49492 m .72761 .49261 L .72887 .49415 L F
.7261 .49492 m .72483 .49339 L .72761 .49261 L F
.35629 .49475 m .35728 .49242 L .35888 .4939 L F
.35629 .49475 m .35469 .49328 L .35728 .49242 L F
.45693 .49607 m .45806 .49378 L .45957 .49527 L 0 .029 .129 r
F
.45693 .49607 m .45542 .49455 L .45806 .49378 L F
.53307 .49645 m .53431 .49397 L .53575 .49559 L F
.53307 .49645 m .53163 .49484 L .53431 .49397 L F
.67445 .49553 m .67588 .49325 L .6772 .49477 L 0 .028 .127 r
F
.67445 .49553 m .67313 .49401 L .67588 .49325 L F
.38757 .49543 m .3886 .49319 L .39017 .49473 L F
.38757 .49543 m .386 .49388 L .3886 .49319 L F
.43243 .49525 m .43353 .49303 L .43506 .49456 L 0 .027 .127 r
F
.43243 .49525 m .4309 .49373 L .43353 .49303 L F
.50179 .496 m .50298 .49372 L .50445 .49524 L 0 .029 .129 r
F
.50179 .496 m .50032 .4945 L .50298 .49372 L F
.63638 .49548 m .63776 .49316 L .63911 .49469 L 0 .028 .127 r
F
.63638 .49548 m .63503 .49398 L .63776 .49316 L F
.31821 .49478 m .31915 .49242 L .32078 .494 L 0 .026 .125 r
F
.31821 .49478 m .31657 .49321 L .31915 .49242 L F
.53986 .49629 m .54111 .49394 L .54254 .49549 L 0 .029 .129 r
F
.53986 .49629 m .53843 .49473 L .54111 .49394 L F
.59152 .49574 m .59284 .49349 L .59422 .49494 L 0 .028 .128 r
F
.59152 .49574 m .59013 .49429 L .59284 .49349 L F
.36307 .49463 m .36406 .49243 L .36566 .4939 L 0 .026 .125 r
F
.36307 .49463 m .36147 .49316 L .36406 .49243 L F
.68125 .49544 m .6827 .49324 L .684 .49466 L 0 .028 .127 r
F
.68125 .49544 m .67995 .49401 L .6827 .49324 L F
.59831 .49546 m .59964 .49318 L .60102 .4946 L F
.59831 .49546 m .59693 .49406 L .59964 .49318 L F
.46371 .49605 m .46485 .4938 L .46635 .49529 L 0 .029 .129 r
F
.46371 .49605 m .46221 .49453 L .46485 .4938 L F
.73291 .49497 m .73443 .49261 L .73569 .49419 L 0 .027 .126 r
F
.73291 .49497 m .73165 .49338 L .73443 .49261 L F
.54665 .4961 m .54791 .4939 L .54934 .4953 L 0 .029 .129 r
F
.54665 .4961 m .54522 .49468 L .54791 .4939 L F
.6051 .49517 m .60644 .49285 L .60781 .49431 L 0 .027 .127 r
F
.6051 .49517 m .60373 .49373 L .60644 .49285 L F
.68805 .4952 m .6895 .49284 L .6908 .49431 L F
.68805 .4952 m .68675 .49375 L .6895 .49284 L F
.50858 .49595 m .50978 .49359 L .51124 .49511 L 0 .029 .129 r
F
.50858 .49595 m .50711 .49441 L .50978 .49359 L F
.64318 .49542 m .64457 .49308 L .64591 .49463 L 0 .028 .127 r
F
.64318 .49542 m .64184 .49388 L .64457 .49308 L F
.32498 .49473 m .32593 .49228 L .32756 .49387 L 0 .026 .125 r
F
.32498 .49473 m .32335 .49315 L .32593 .49228 L F
.4705 .49588 m .47165 .49348 L .47315 .49496 L 0 .029 .129 r
F
.4705 .49588 m .469 .4944 L .47165 .49348 L F
.36985 .4946 m .37085 .49231 L .37244 .49381 L 0 .026 .125 r
F
.36985 .4946 m .36825 .49312 L .37085 .49231 L F
.47729 .49555 m .47845 .4931 L .47994 .49462 L 0 .028 .128 r
F
.47729 .49555 m .4758 .49403 L .47845 .4931 L F
.55345 .49594 m .55471 .4938 L .55613 .49518 L 0 .029 .129 r
F
.55345 .49594 m .55202 .49455 L .55471 .4938 L F
.69485 .49502 m .69631 .49255 L .69761 .49416 L 0 .027 .126 r
F
.69485 .49502 m .69355 .49342 L .69631 .49255 L F
.43921 .49542 m .44031 .49313 L .44184 .4947 L 0 .028 .128 r
F
.43921 .49542 m .43768 .49388 L .44031 .49313 L F
.39434 .49561 m .39539 .49316 L .39695 .49473 L F
.39434 .49561 m .39277 .49402 L .39539 .49316 L F
.48408 .49524 m .48525 .49289 L .48673 .49444 L 0 .028 .127 r
F
.48408 .49524 m .48259 .4937 L .48525 .49289 L F
.6119 .49507 m .61325 .49265 L .61462 .49426 L 0 .027 .126 r
F
.6119 .49507 m .61053 .49344 L .61325 .49265 L F
.51537 .49584 m .51658 .49358 L .51804 .49505 L 0 .029 .129 r
F
.51537 .49584 m .51391 .49434 L .51658 .49358 L F
.73973 .49495 m .74125 .49247 L .7425 .49406 L 0 .027 .126 r
F
.73973 .49495 m .73847 .49337 L .74125 .49247 L F
.64998 .49534 m .65138 .4929 L .65272 .49444 L 0 .028 .127 r
F
.64998 .49534 m .64865 .49379 L .65138 .4929 L F
.56024 .49574 m .56152 .49343 L .56293 .49486 L 0 .029 .129 r
F
.56024 .49574 m .55882 .49432 L .56152 .49343 L F
.33176 .49461 m .33272 .49217 L .33434 .49376 L 0 .026 .125 r
F
.33176 .49461 m .33014 .49302 L .33272 .49217 L F
.40112 .49538 m .40218 .49293 L .40374 .49447 L 0 .028 .127 r
F
.40112 .49538 m .39956 .49382 L .40218 .49293 L F
.56703 .49542 m .56832 .49306 L .56973 .49451 L 0 .028 .128 r
F
.56703 .49542 m .56562 .49398 L .56832 .49306 L F
.65678 .49507 m .65819 .49263 L .65952 .49415 L 0 .027 .127 r
F
.65678 .49507 m .65545 .49353 L .65819 .49263 L F
.57383 .49508 m .57512 .49275 L .57652 .49423 L 0 .028 .127 r
F
.57383 .49508 m .57242 .4936 L .57512 .49275 L F
.52216 .49571 m .52338 .49344 L .52483 .4949 L 0 .029 .129 r
F
.52216 .49571 m .52071 .49426 L .52338 .49344 L F
.70166 .49496 m .70312 .49246 L .70442 .4941 L 0 .027 .126 r
F
.70166 .49496 m .70036 .49331 L .70312 .49246 L F
.40791 .49516 m .40897 .49284 L .41053 .49433 L 0 .028 .127 r
F
.40791 .49516 m .40636 .49365 L .40897 .49284 L F
.37662 .4946 m .37764 .49226 L .37922 .49383 L 0 .027 .126 r
F
.37662 .4946 m .37504 .49302 L .37764 .49226 L F
.66358 .49482 m .66499 .49237 L .66632 .49395 L F
.66358 .49482 m .66225 .49324 L .66499 .49237 L F
.6187 .49505 m .62006 .49264 L .62142 .49423 L 0 .028 .127 r
F
.6187 .49505 m .61734 .49345 L .62006 .49264 L F
.49087 .49526 m .49205 .49299 L .49352 .49454 L 0 .028 .128 r
F
.49087 .49526 m .48939 .49372 L .49205 .49299 L F
.33853 .49451 m .3395 .4921 L .34111 .4937 L 0 .026 .125 r
F
.33853 .49451 m .33692 .49292 L .3395 .4921 L F
.44599 .49547 m .4471 .49321 L .44862 .49472 L 0 .029 .129 r
F
.44599 .49547 m .44447 .49396 L .4471 .49321 L F
.4147 .49497 m .41577 .49259 L .41732 .49412 L 0 .028 .127 r
F
.4147 .49497 m .41315 .49347 L .41577 .49259 L F
.70846 .49482 m .70994 .49237 L .71123 .49394 L 0 .027 .126 r
F
.70846 .49482 m .70718 .49324 L .70994 .49237 L F
.58062 .49504 m .58193 .49268 L .58333 .49425 L 0 .028 .127 r
F
.58062 .49504 m .57922 .49346 L .58193 .49268 L F
.71526 .49448 m .71675 .49215 L .71802 .49358 L 0 .027 .126 r
F
.71526 .49448 m .71399 .49305 L .71675 .49215 L F
.72206 .49417 m .72357 .49195 L .72483 .49339 L 0 .026 .125 r
F
.72206 .49417 m .72079 .49274 L .72357 .49195 L F
.52895 .49568 m .53018 .49323 L .53163 .49484 L 0 .029 .129 r
F
.52895 .49568 m .52751 .49409 L .53018 .49323 L F
.67039 .49477 m .67182 .49242 L .67313 .49401 L 0 .027 .127 r
F
.67039 .49477 m .66907 .49318 L .67182 .49242 L F
.34531 .4944 m .34628 .49214 L .34789 .49362 L 0 .027 .126 r
F
.34531 .4944 m .3437 .49292 L .34628 .49214 L F
.62551 .49497 m .62687 .49262 L .62823 .49415 L 0 .028 .127 r
F
.62551 .49497 m .62415 .49342 L .62687 .49262 L F
.3834 .49463 m .38442 .49233 L .386 .49388 L 0 .027 .126 r
F
.3834 .49463 m .38182 .49306 L .38442 .49233 L F
.45278 .49539 m .4539 .4931 L .45542 .49455 L 0 .029 .129 r
F
.45278 .49539 m .45126 .49391 L .4539 .4931 L F
.30722 .49427 m .30815 .4918 L .3098 .49331 L 0 .026 .125 r
F
.30722 .49427 m .30557 .49273 L .30815 .4918 L F
.42148 .49483 m .42257 .49237 L .42411 .49394 L 0 .027 .127 r
F
.42148 .49483 m .41994 .49327 L .42257 .49237 L F
.49766 .49525 m .49885 .493 L .50032 .4945 L 0 .029 .128 r
F
.49766 .49525 m .49618 .49377 L .49885 .493 L F
.42827 .49455 m .42937 .49219 L .4309 .49373 L 0 .027 .126 r
F
.42827 .49455 m .42674 .49303 L .42937 .49219 L F
.31401 .49399 m .31494 .49163 L .31657 .49321 L 0 .026 .125 r
F
.31401 .49399 m .31237 .49242 L .31494 .49163 L F
.3521 .49418 m .35308 .49181 L .35469 .49328 L F
.3521 .49418 m .35049 .49272 L .35308 .49181 L F
.63231 .49479 m .63368 .49247 L .63503 .49398 L 0 .028 .127 r
F
.63231 .49479 m .63095 .49331 L .63368 .49247 L F
.35888 .4939 m .35987 .49168 L .36147 .49316 L 0 .026 .125 r
F
.35888 .4939 m .35728 .49242 L .35987 .49168 L F
.53575 .49559 m .53699 .49309 L .53843 .49473 L 0 .029 .129 r
F
.53575 .49559 m .53431 .49397 L .53699 .49309 L F
.58742 .49505 m .58874 .49274 L .59013 .49429 L 0 .028 .128 r
F
.58742 .49505 m .58603 .49349 L .58874 .49274 L F
.45957 .49527 m .4607 .49307 L .46221 .49453 L 0 .029 .129 r
F
.45957 .49527 m .45806 .49378 L .4607 .49307 L F
.72887 .49415 m .73039 .49184 L .73165 .49338 L 0 .026 .126 r
F
.72887 .49415 m .72761 .49261 L .73039 .49184 L F
.6772 .49477 m .67864 .49249 L .67995 .49401 L 0 .028 .127 r
F
.6772 .49477 m .67588 .49325 L .67864 .49249 L F
.50445 .49524 m .50565 .4929 L .50711 .49441 L 0 .029 .129 r
F
.50445 .49524 m .50298 .49372 L .50565 .4929 L F
.63911 .49469 m .64049 .49233 L .64184 .49388 L 0 .028 .127 r
F
.63911 .49469 m .63776 .49316 L .64049 .49233 L F
.39017 .49473 m .3912 .4925 L .39277 .49402 L 0 .028 .128 r
F
.39017 .49473 m .3886 .49319 L .3912 .4925 L F
.54254 .49549 m .54379 .49316 L .54522 .49468 L 0 .03 .13 r
F
.54254 .49549 m .54111 .49394 L .54379 .49316 L F
.43506 .49456 m .43615 .49233 L .43768 .49388 L 0 .028 .127 r
F
.43506 .49456 m .43353 .49303 L .43615 .49233 L F
.32078 .494 m .32172 .49156 L .32335 .49315 L 0 .026 .125 r
F
.32078 .494 m .31915 .49242 L .32172 .49156 L F
.59422 .49494 m .59555 .49259 L .59693 .49406 L 0 .028 .128 r
F
.59422 .49494 m .59284 .49349 L .59555 .49259 L F
.60102 .4946 m .60235 .49229 L .60373 .49373 L 0 .028 .127 r
F
.60102 .4946 m .59964 .49318 L .60235 .49229 L F
.36566 .4939 m .36666 .49164 L .36825 .49312 L 0 .026 .125 r
F
.36566 .4939 m .36406 .49243 L .36666 .49164 L F
.684 .49466 m .68545 .49231 L .68675 .49375 L 0 .028 .127 r
F
.684 .49466 m .6827 .49324 L .68545 .49231 L F
.60781 .49431 m .60916 .49196 L .61053 .49344 L 0 .027 .126 r
F
.60781 .49431 m .60644 .49285 L .60916 .49196 L F
.6908 .49431 m .69226 .49194 L .69355 .49342 L F
.6908 .49431 m .6895 .49284 L .69226 .49194 L F
.46635 .49529 m .4675 .49291 L .469 .4944 L 0 .029 .129 r
F
.46635 .49529 m .46485 .4938 L .4675 .49291 L F
.51124 .49511 m .51245 .49283 L .51391 .49434 L F
.51124 .49511 m .50978 .49359 L .51245 .49283 L F
.54934 .4953 m .5506 .49316 L .55202 .49455 L 0 .03 .13 r
F
.54934 .4953 m .54791 .4939 L .5506 .49316 L F
.73569 .49419 m .73721 .49179 L .73847 .49337 L 0 .027 .126 r
F
.73569 .49419 m .73443 .49261 L .73721 .49179 L F
.47315 .49496 m .4743 .49257 L .4758 .49403 L 0 .029 .128 r
F
.47315 .49496 m .47165 .49348 L .4743 .49257 L F
.47994 .49462 m .48111 .49217 L .48259 .4937 L 0 .028 .127 r
F
.47994 .49462 m .47845 .4931 L .48111 .49217 L F
.32756 .49387 m .32851 .49141 L .33014 .49302 L 0 .026 .125 r
F
.32756 .49387 m .32593 .49228 L .32851 .49141 L F
.64591 .49463 m .64731 .49224 L .64865 .49379 L 0 .028 .127 r
F
.64591 .49463 m .64457 .49308 L .64731 .49224 L F
.69761 .49416 m .69907 .49167 L .70036 .49331 L 0 .027 .126 r
F
.69761 .49416 m .69631 .49255 L .69907 .49167 L F
.39695 .49473 m .398 .49226 L .39956 .49382 L 0 .028 .128 r
F
.39695 .49473 m .39539 .49316 L .398 .49226 L F
.37244 .49381 m .37345 .4915 L .37504 .49302 L 0 .026 .125 r
F
.37244 .49381 m .37085 .49231 L .37345 .4915 L F
.55613 .49518 m .55741 .49294 L .55882 .49432 L 0 .03 .13 r
F
.55613 .49518 m .55471 .4938 L .55741 .49294 L F
.65272 .49444 m .65412 .49201 L .65545 .49353 L 0 .028 .127 r
F
.65272 .49444 m .65138 .4929 L .65412 .49201 L F
.7425 .49406 m .74403 .49157 L .74528 .49318 L 0 .027 .126 r
F
.7425 .49406 m .74125 .49247 L .74403 .49157 L F
.48673 .49444 m .48791 .49215 L .48939 .49372 L 0 .028 .127 r
F
.48673 .49444 m .48525 .49289 L .48791 .49215 L F
.61462 .49426 m .61597 .49185 L .61734 .49345 L 0 .027 .127 r
F
.61462 .49426 m .61325 .49265 L .61597 .49185 L F
.40374 .49447 m .4048 .49214 L .40636 .49365 L 0 .028 .127 r
F
.40374 .49447 m .40218 .49293 L .4048 .49214 L F
.56293 .49486 m .56421 .49253 L .56562 .49398 L 0 .029 .129 r
F
.56293 .49486 m .56152 .49343 L .56421 .49253 L F
.51804 .49505 m .51925 .49282 L .52071 .49426 L F
.51804 .49505 m .51658 .49358 L .51925 .49282 L F
.44184 .4947 m .44295 .49237 L .44447 .49396 L 0 .028 .128 r
F
.44184 .4947 m .44031 .49313 L .44295 .49237 L F
.56973 .49451 m .57102 .49214 L .57242 .4936 L 0 .028 .127 r
F
.56973 .49451 m .56832 .49306 L .57102 .49214 L F
.33434 .49376 m .3353 .49132 L .33692 .49292 L 0 .026 .125 r
F
.33434 .49376 m .33272 .49217 L .3353 .49132 L F
.65952 .49415 m .66093 .49173 L .66225 .49324 L 0 .027 .126 r
F
.65952 .49415 m .65819 .49263 L .66093 .49173 L F
.57652 .49423 m .57782 .49199 L .57922 .49346 L 0 .028 .127 r
F
.57652 .49423 m .57512 .49275 L .57782 .49199 L F
.70442 .4941 m .70589 .49162 L .70718 .49324 L 0 .027 .126 r
F
.70442 .4941 m .70312 .49246 L .70589 .49162 L F
.66632 .49395 m .66774 .4916 L .66907 .49318 L F
.66632 .49395 m .66499 .49237 L .66774 .4916 L F
.41053 .49433 m .41159 .49198 L .41315 .49347 L 0 .028 .127 r
F
.41053 .49433 m .40897 .49284 L .41159 .49198 L F
.52483 .4949 m .52606 .49262 L .52751 .49409 L 0 .029 .129 r
F
.52483 .4949 m .52338 .49344 L .52606 .49262 L F
.37922 .49383 m .38024 .4915 L .38182 .49306 L 0 .027 .126 r
F
.37922 .49383 m .37764 .49226 L .38024 .4915 L F
.62142 .49423 m .62279 .49185 L .62415 .49342 L 0 .028 .127 r
F
.62142 .49423 m .62006 .49264 L .62279 .49185 L F
.34111 .4937 m .34209 .49132 L .3437 .49292 L 0 .027 .126 r
F
.34111 .4937 m .3395 .4921 L .34209 .49132 L F
.41732 .49412 m .4184 .49171 L .41994 .49327 L 0 .027 .127 r
F
.41732 .49412 m .41577 .49259 L .4184 .49171 L F
.71123 .49394 m .71271 .49149 L .71399 .49305 L 0 .027 .126 r
F
.71123 .49394 m .70994 .49237 L .71271 .49149 L F
.71802 .49358 m .71952 .49131 L .72079 .49274 L F
.71802 .49358 m .71675 .49215 L .71952 .49131 L F
.44862 .49472 m .44974 .49243 L .45126 .49391 L 0 .029 .129 r
F
.44862 .49472 m .4471 .49321 L .44974 .49243 L F
.49352 .49454 m .49471 .49219 L .49618 .49377 L 0 .029 .128 r
F
.49352 .49454 m .49205 .49299 L .49471 .49219 L F
.303 .49367 m .30393 .4912 L .30557 .49273 L 0 .026 .126 r
F
.303 .49367 m .30135 .49212 L .30393 .4912 L F
.58333 .49425 m .58463 .49193 L .58603 .49349 L 0 .028 .128 r
F
.58333 .49425 m .58193 .49268 L .58463 .49193 L F
.3098 .49331 m .31072 .49092 L .31237 .49242 L 0 .026 .125 r
F
.3098 .49331 m .30815 .4918 L .31072 .49092 L F
.53163 .49484 m .53286 .49234 L .53431 .49397 L 0 .029 .129 r
F
.53163 .49484 m .53018 .49323 L .53286 .49234 L F
.42411 .49394 m .4252 .49146 L .42674 .49303 L 0 .027 .126 r
F
.42411 .49394 m .42257 .49237 L .4252 .49146 L F
.72483 .49339 m .72634 .49117 L .72761 .49261 L 0 .026 .125 r
F
.72483 .49339 m .72357 .49195 L .72634 .49117 L F
.62823 .49415 m .6296 .49177 L .63095 .49331 L 0 .028 .127 r
F
.62823 .49415 m .62687 .49262 L .6296 .49177 L F
.45542 .49455 m .45654 .49235 L .45806 .49378 L 0 .029 .129 r
F
.45542 .49455 m .4539 .4931 L .45654 .49235 L F
.34789 .49362 m .34888 .49123 L .35049 .49272 L 0 .027 .126 r
F
.34789 .49362 m .34628 .49214 L .34888 .49123 L F
.67313 .49401 m .67457 .49165 L .67588 .49325 L 0 .028 .127 r
F
.67313 .49401 m .67182 .49242 L .67457 .49165 L F
.35469 .49328 m .35568 .49094 L .35728 .49242 L 0 .026 .125 r
F
.35469 .49328 m .35308 .49181 L .35568 .49094 L F
.386 .49388 m .38702 .49166 L .3886 .49319 L 0 .028 .127 r
F
.386 .49388 m .38442 .49233 L .38702 .49166 L F
.4309 .49373 m .43199 .49148 L .43353 .49303 L 0 .027 .127 r
F
.4309 .49373 m .42937 .49219 L .43199 .49148 L F
.50032 .4945 m .50151 .4922 L .50298 .49372 L 0 .029 .129 r
F
.50032 .4945 m .49885 .493 L .50151 .4922 L F
.31657 .49321 m .31751 .49084 L .31915 .49242 L 0 .026 .125 r
F
.31657 .49321 m .31494 .49163 L .31751 .49084 L F
.63503 .49398 m .63641 .49163 L .63776 .49316 L 0 .028 .127 r
F
.63503 .49398 m .63368 .49247 L .63641 .49163 L F
.53843 .49473 m .53967 .49232 L .54111 .49394 L 0 .029 .129 r
F
.53843 .49473 m .53699 .49309 L .53967 .49232 L F
.59013 .49429 m .59145 .49195 L .59284 .49349 L 0 .029 .128 r
F
.59013 .49429 m .58874 .49274 L .59145 .49195 L F
.36147 .49316 m .36247 .49093 L .36406 .49243 L 0 .026 .125 r
F
.36147 .49316 m .35987 .49168 L .36247 .49093 L F
.73165 .49338 m .73317 .49107 L .73443 .49261 L 0 .027 .126 r
F
.73165 .49338 m .73039 .49184 L .73317 .49107 L F
.46221 .49453 m .46334 .49235 L .46485 .4938 L 0 .029 .129 r
F
.46221 .49453 m .4607 .49307 L .46334 .49235 L F
.67995 .49401 m .6814 .49172 L .6827 .49324 L 0 .028 .128 r
F
.67995 .49401 m .67864 .49249 L .6814 .49172 L F
.50711 .49441 m .50832 .49207 L .50978 .49359 L 0 .029 .129 r
F
.50711 .49441 m .50565 .4929 L .50832 .49207 L F
.59693 .49406 m .59826 .49169 L .59964 .49318 L 0 .028 .128 r
F
.59693 .49406 m .59555 .49259 L .59826 .49169 L F
.64184 .49388 m .64323 .4915 L .64457 .49308 L 0 .028 .127 r
F
.64184 .49388 m .64049 .49233 L .64323 .4915 L F
.32335 .49315 m .32431 .49068 L .32593 .49228 L 0 .026 .125 r
F
.32335 .49315 m .32172 .49156 L .32431 .49068 L F
.60373 .49373 m .60507 .49138 L .60644 .49285 L 0 .028 .127 r
F
.60373 .49373 m .60235 .49229 L .60507 .49138 L F
.54522 .49468 m .54648 .49239 L .54791 .4939 L 0 .03 .13 r
F
.54522 .49468 m .54379 .49316 L .54648 .49239 L F
.68675 .49375 m .6882 .49138 L .6895 .49284 L 0 .028 .127 r
F
.68675 .49375 m .68545 .49231 L .6882 .49138 L F
.69355 .49342 m .69501 .49104 L .69631 .49255 L 0 .027 .126 r
F
.69355 .49342 m .69226 .49194 L .69501 .49104 L F
.61053 .49344 m .61188 .49118 L .61325 .49265 L F
.61053 .49344 m .60916 .49196 L .61188 .49118 L F
.39277 .49402 m .39382 .49166 L .39539 .49316 L 0 .028 .128 r
F
.39277 .49402 m .3912 .4925 L .39382 .49166 L F
.469 .4944 m .47015 .492 L .47165 .49348 L 0 .029 .129 r
F
.469 .4944 m .4675 .49291 L .47015 .492 L F
.4758 .49403 m .47696 .49166 L .47845 .4931 L 0 .028 .128 r
F
.4758 .49403 m .4743 .49257 L .47696 .49166 L F
.36825 .49312 m .36926 .49081 L .37085 .49231 L 0 .026 .126 r
F
.36825 .49312 m .36666 .49164 L .36926 .49081 L F
.43768 .49388 m .43879 .49156 L .44031 .49313 L 0 .028 .128 r
F
.43768 .49388 m .43615 .49233 L .43879 .49156 L F
.48259 .4937 m .48376 .49134 L .48525 .49289 L 0 .028 .127 r
F
.48259 .4937 m .48111 .49217 L .48376 .49134 L F
.73847 .49337 m .73999 .49087 L .74125 .49247 L 0 .027 .126 r
F
.73847 .49337 m .73721 .49179 L .73999 .49087 L F
.33014 .49302 m .3311 .49057 L .33272 .49217 L 0 .026 .125 r
F
.33014 .49302 m .32851 .49141 L .3311 .49057 L F
.51391 .49434 m .51512 .4921 L .51658 .49358 L 0 .029 .129 r
F
.51391 .49434 m .51245 .49283 L .51512 .4921 L F
.64865 .49379 m .65005 .49136 L .65138 .4929 L 0 .028 .127 r
F
.64865 .49379 m .64731 .49224 L .65005 .49136 L F
.55202 .49455 m .55329 .49242 L .55471 .4938 L 0 .03 .13 r
F
.55202 .49455 m .5506 .49316 L .55329 .49242 L F
.39956 .49382 m .40062 .49138 L .40218 .49293 L 0 .028 .127 r
F
.39956 .49382 m .398 .49226 L .40062 .49138 L F
.70036 .49331 m .70183 .49084 L .70312 .49246 L 0 .027 .126 r
F
.70036 .49331 m .69907 .49167 L .70183 .49084 L F
.65545 .49353 m .65686 .49111 L .65819 .49263 L 0 .027 .127 r
F
.65545 .49353 m .65412 .49201 L .65686 .49111 L F
.74528 .49318 m .74681 .4907 L .74806 .49232 L 0 .027 .126 r
F
.74528 .49318 m .74403 .49157 L .74681 .4907 L F
.55882 .49432 m .5601 .49202 L .56152 .49343 L 0 .029 .129 r
F
.55882 .49432 m .55741 .49294 L .5601 .49202 L F
.37504 .49302 m .37605 .49074 L .37764 .49226 L 0 .027 .126 r
F
.37504 .49302 m .37345 .4915 L .37605 .49074 L F
.57242 .4936 m .57372 .4913 L .57512 .49275 L 0 .028 .127 r
F
.57242 .4936 m .57102 .49214 L .57372 .4913 L F
.56562 .49398 m .56691 .49161 L .56832 .49306 L 0 .029 .128 r
F
.56562 .49398 m .56421 .49253 L .56691 .49161 L F
.66225 .49324 m .66367 .49086 L .66499 .49237 L 0 .027 .126 r
F
.66225 .49324 m .66093 .49173 L .66367 .49086 L F
.61734 .49345 m .61869 .49106 L .62006 .49264 L 0 .027 .127 r
F
.61734 .49345 m .61597 .49185 L .61869 .49106 L F
.40636 .49365 m .40742 .49135 L .40897 .49284 L 0 .028 .128 r
F
.40636 .49365 m .4048 .49214 L .40742 .49135 L F
.33692 .49292 m .33789 .4905 L .3395 .4921 L 0 .026 .125 r
F
.33692 .49292 m .3353 .49132 L .33789 .4905 L F
.52071 .49426 m .52193 .49199 L .52338 .49344 L 0 .029 .129 r
F
.52071 .49426 m .51925 .49282 L .52193 .49199 L F
.48939 .49372 m .49057 .4914 L .49205 .49299 L 0 .028 .128 r
F
.48939 .49372 m .48791 .49215 L .49057 .4914 L F
.44447 .49396 m .44559 .4916 L .4471 .49321 L 0 .029 .128 r
F
.44447 .49396 m .44295 .49237 L .44559 .4916 L F
.70718 .49324 m .70865 .49076 L .70994 .49237 L 0 .027 .126 r
F
.70718 .49324 m .70589 .49162 L .70865 .49076 L F
.57922 .49346 m .58053 .49123 L .58193 .49268 L 0 .028 .127 r
F
.57922 .49346 m .57782 .49199 L .58053 .49123 L F
.41315 .49347 m .41422 .49109 L .41577 .49259 L F
.41315 .49347 m .41159 .49198 L .41422 .49109 L F
.52751 .49409 m .52874 .49176 L .53018 .49323 L 0 .029 .129 r
F
.52751 .49409 m .52606 .49262 L .52874 .49176 L F
.66907 .49318 m .67049 .49083 L .67182 .49242 L 0 .027 .127 r
F
.66907 .49318 m .66774 .4916 L .67049 .49083 L F
.71399 .49305 m .71548 .49061 L .71675 .49215 L 0 .027 .126 r
F
.71399 .49305 m .71271 .49149 L .71548 .49061 L F
.62415 .49342 m .62551 .49106 L .62687 .49262 L 0 .028 .127 r
F
.62415 .49342 m .62279 .49185 L .62551 .49106 L F
.38182 .49306 m .38285 .49078 L .38442 .49233 L 0 .027 .126 r
F
.38182 .49306 m .38024 .4915 L .38285 .49078 L F
.41994 .49327 m .42103 .49079 L .42257 .49237 L 0 .027 .127 r
F
.41994 .49327 m .4184 .49171 L .42103 .49079 L F
.3437 .49292 m .34467 .49053 L .34628 .49214 L 0 .027 .126 r
F
.3437 .49292 m .34209 .49132 L .34467 .49053 L F
.30557 .49273 m .3065 .49028 L .30815 .4918 L 0 .026 .125 r
F
.30557 .49273 m .30393 .4912 L .3065 .49028 L F
.72079 .49274 m .7223 .49051 L .72357 .49195 L 0 .027 .126 r
F
.72079 .49274 m .71952 .49131 L .7223 .49051 L F
.45126 .49391 m .45238 .49164 L .4539 .4931 L 0 .029 .129 r
F
.45126 .49391 m .44974 .49243 L .45238 .49164 L F
.31237 .49242 m .3133 .49014 L .31494 .49163 L 0 .026 .125 r
F
.31237 .49242 m .31072 .49092 L .3133 .49014 L F
.49618 .49377 m .49737 .49139 L .49885 .493 L 0 .029 .128 r
F
.49618 .49377 m .49471 .49219 L .49737 .49139 L F
.53431 .49397 m .53555 .49144 L .53699 .49309 L 0 .029 .129 r
F
.53431 .49397 m .53286 .49234 L .53555 .49144 L F
.42674 .49303 m .42783 .49061 L .42937 .49219 L 0 .027 .126 r
F
.42674 .49303 m .4252 .49146 L .42783 .49061 L F
.35049 .49272 m .35147 .49032 L .35308 .49181 L 0 .026 .126 r
F
.35049 .49272 m .34888 .49123 L .35147 .49032 L F
.58603 .49349 m .58734 .49118 L .58874 .49274 L 0 .028 .128 r
F
.58603 .49349 m .58463 .49193 L .58734 .49118 L F
.63095 .49331 m .63233 .49091 L .63368 .49247 L 0 .028 .127 r
F
.63095 .49331 m .6296 .49177 L .63233 .49091 L F
.35728 .49242 m .35827 .49018 L .35987 .49168 L 0 .026 .125 r
F
.35728 .49242 m .35568 .49094 L .35827 .49018 L F
.72761 .49261 m .72913 .49039 L .73039 .49184 L 0 .027 .126 r
F
.72761 .49261 m .72634 .49117 L .72913 .49039 L F
.45806 .49378 m .45919 .49165 L .4607 .49307 L 0 .029 .129 r
F
.45806 .49378 m .45654 .49235 L .45919 .49165 L F
.67588 .49325 m .67732 .49089 L .67864 .49249 L 0 .028 .127 r
F
.67588 .49325 m .67457 .49165 L .67732 .49089 L F
.50298 .49372 m .50418 .49138 L .50565 .4929 L 0 .029 .129 r
F
.50298 .49372 m .50151 .4922 L .50418 .49138 L F
.63776 .49316 m .63915 .49077 L .64049 .49233 L 0 .028 .127 r
F
.63776 .49316 m .63641 .49163 L .63915 .49077 L F
.31915 .49242 m .32009 .48997 L .32172 .49156 L 0 .026 .125 r
F
.31915 .49242 m .31751 .49084 L .32009 .48997 L F
.54111 .49394 m .54236 .49156 L .54379 .49316 L 0 .029 .129 r
F
.54111 .49394 m .53967 .49232 L .54236 .49156 L F
.3886 .49319 m .38963 .49099 L .3912 .4925 L 0 .028 .128 r
F
.3886 .49319 m .38702 .49166 L .38963 .49099 L F
.43353 .49303 m .43462 .49076 L .43615 .49233 L 0 .028 .127 r
F
.43353 .49303 m .43199 .49148 L .43462 .49076 L F
.59284 .49349 m .59416 .49103 L .59555 .49259 L 0 .028 .128 r
F
.59284 .49349 m .59145 .49195 L .59416 .49103 L F
.73443 .49261 m .73595 .49025 L .73721 .49179 L 0 .027 .126 r
F
.73443 .49261 m .73317 .49107 L .73595 .49025 L F
.59964 .49318 m .60097 .49078 L .60235 .49229 L 0 .028 .128 r
F
.59964 .49318 m .59826 .49169 L .60097 .49078 L F
.36406 .49243 m .36506 .49012 L .36666 .49164 L 0 .027 .126 r
F
.36406 .49243 m .36247 .49093 L .36506 .49012 L F
.50978 .49359 m .51099 .49132 L .51245 .49283 L 0 .029 .129 r
F
.50978 .49359 m .50832 .49207 L .51099 .49132 L F
.6895 .49284 m .69096 .49045 L .69226 .49194 L 0 .027 .127 r
F
.6895 .49284 m .6882 .49138 L .69096 .49045 L F
.60644 .49285 m .60778 .49048 L .60916 .49196 L F
.60644 .49285 m .60507 .49138 L .60778 .49048 L F
.32593 .49228 m .32689 .4898 L .32851 .49141 L 0 .026 .125 r
F
.32593 .49228 m .32431 .49068 L .32689 .4898 L F
.46485 .4938 m .46599 .49147 L .4675 .49291 L 0 .03 .13 r
F
.46485 .4938 m .46334 .49235 L .46599 .49147 L F
.6827 .49324 m .68415 .49078 L .68545 .49231 L 0 .028 .128 r
F
.6827 .49324 m .6814 .49172 L .68415 .49078 L F
.64457 .49308 m .64597 .49066 L .64731 .49224 L 0 .028 .127 r
F
.64457 .49308 m .64323 .4915 L .64597 .49066 L F
.47845 .4931 m .47961 .49074 L .48111 .49217 L 0 .028 .128 r
F
.47845 .4931 m .47696 .49166 L .47961 .49074 L F
.47165 .49348 m .4728 .4911 L .4743 .49257 L 0 .029 .129 r
F
.47165 .49348 m .47015 .492 L .4728 .4911 L F
.69631 .49255 m .69777 .49015 L .69907 .49167 L 0 .027 .126 r
F
.69631 .49255 m .69501 .49104 L .69777 .49015 L F
.54791 .4939 m .54917 .49166 L .5506 .49316 L 0 .03 .13 r
F
.54791 .4939 m .54648 .49239 L .54917 .49166 L F
.39539 .49316 m .39643 .49077 L .398 .49226 L 0 .028 .128 r
F
.39539 .49316 m .39382 .49166 L .39643 .49077 L F
.61325 .49265 m .6146 .4904 L .61597 .49185 L 0 .027 .127 r
F
.61325 .49265 m .61188 .49118 L .6146 .4904 L F
.74125 .49247 m .74277 .48996 L .74403 .49157 L 0 .027 .126 r
F
.74125 .49247 m .73999 .49087 L .74277 .48996 L F
.37085 .49231 m .37186 .48998 L .37345 .4915 L F
.37085 .49231 m .36926 .49081 L .37186 .48998 L F
.48525 .49289 m .48642 .49059 L .48791 .49215 L 0 .028 .127 r
F
.48525 .49289 m .48376 .49134 L .48642 .49059 L F
.65138 .4929 m .65278 .49048 L .65412 .49201 L F
.65138 .4929 m .65005 .49136 L .65278 .49048 L F
.33272 .49217 m .33368 .48972 L .3353 .49132 L 0 .026 .125 r
F
.33272 .49217 m .3311 .49057 L .33368 .48972 L F
.40218 .49293 m .40324 .49062 L .4048 .49214 L 0 .028 .127 r
F
.40218 .49293 m .40062 .49138 L .40324 .49062 L F
.44031 .49313 m .44142 .49076 L .44295 .49237 L 0 .028 .128 r
F
.44031 .49313 m .43879 .49156 L .44142 .49076 L F
.65819 .49263 m .6596 .49022 L .66093 .49173 L 0 .027 .127 r
F
.65819 .49263 m .65686 .49111 L .6596 .49022 L F
.51658 .49358 m .5178 .49135 L .51925 .49282 L 0 .03 .13 r
F
.51658 .49358 m .51512 .4921 L .5178 .49135 L F
.70312 .49246 m .7046 .49001 L .70589 .49162 L 0 .027 .126 r
F
.70312 .49246 m .70183 .49084 L .7046 .49001 L F
.55471 .4938 m .55598 .49155 L .55741 .49294 L 0 .03 .13 r
F
.55471 .4938 m .55329 .49242 L .55598 .49155 L F
.56152 .49343 m .5628 .4911 L .56421 .49253 L 0 .029 .129 r
F
.56152 .49343 m .5601 .49202 L .5628 .4911 L F
.56832 .49306 m .56961 .49068 L .57102 .49214 L 0 .028 .128 r
F
.56832 .49306 m .56691 .49161 L .56961 .49068 L F
.74806 .49232 m .74959 .48983 L .75085 .49148 L 0 .026 .126 r
F
.74806 .49232 m .74681 .4907 L .74959 .48983 L F
.66499 .49237 m .66642 .49007 L .66774 .4916 L 0 .027 .126 r
F
.66499 .49237 m .66367 .49086 L .66642 .49007 L F
.57512 .49275 m .57642 .49055 L .57782 .49199 L 0 .028 .127 r
F
.57512 .49275 m .57372 .4913 L .57642 .49055 L F
.37764 .49226 m .37866 .48997 L .38024 .4915 L 0 .027 .126 r
F
.37764 .49226 m .37605 .49074 L .37866 .48997 L F
.62006 .49264 m .62142 .49028 L .62279 .49185 L 0 .028 .127 r
F
.62006 .49264 m .61869 .49106 L .62142 .49028 L F
.40897 .49284 m .41004 .4905 L .41159 .49198 L 0 .028 .128 r
F
.40897 .49284 m .40742 .49135 L .41004 .4905 L F
.3395 .4921 m .34047 .48971 L .34209 .49132 L 0 .026 .125 r
F
.3395 .4921 m .33789 .4905 L .34047 .48971 L F
.52338 .49344 m .52461 .49116 L .52606 .49262 L 0 .03 .129 r
F
.52338 .49344 m .52193 .49199 L .52461 .49116 L F
.70994 .49237 m .71142 .4899 L .71271 .49149 L 0 .027 .126 r
F
.70994 .49237 m .70865 .49076 L .71142 .4899 L F
.41577 .49259 m .41685 .4902 L .4184 .49171 L 0 .028 .127 r
F
.41577 .49259 m .41422 .49109 L .41685 .4902 L F
.49205 .49299 m .49323 .49057 L .49471 .49219 L 0 .028 .128 r
F
.49205 .49299 m .49057 .4914 L .49323 .49057 L F
.4471 .49321 m .44823 .49082 L .44974 .49243 L 0 .029 .129 r
F
.4471 .49321 m .44559 .4916 L .44823 .49082 L F
.53018 .49323 m .53142 .49087 L .53286 .49234 L F
.53018 .49323 m .52874 .49176 L .53142 .49087 L F
.58193 .49268 m .58324 .49048 L .58463 .49193 L 0 .028 .128 r
F
.58193 .49268 m .58053 .49123 L .58324 .49048 L F
.30135 .49212 m .30227 .48968 L .30393 .4912 L 0 .027 .126 r
F
.30135 .49212 m .2997 .49058 L .30227 .48968 L F
.71675 .49215 m .71825 .48976 L .71952 .49131 L F
.71675 .49215 m .71548 .49061 L .71825 .48976 L F
.30815 .4918 m .30908 .48942 L .31072 .49092 L 0 .026 .125 r
F
.30815 .4918 m .3065 .49028 L .30908 .48942 L F
.42257 .49237 m .42366 .48988 L .4252 .49146 L 0 .027 .126 r
F
.42257 .49237 m .42103 .49079 L .42366 .48988 L F
.67182 .49242 m .67325 .49006 L .67457 .49165 L 0 .027 .127 r
F
.67182 .49242 m .67049 .49083 L .67325 .49006 L F
.62687 .49262 m .62824 .4902 L .6296 .49177 L 0 .028 .127 r
F
.62687 .49262 m .62551 .49106 L .62824 .4902 L F
.34628 .49214 m .34727 .48963 L .34888 .49123 L 0 .027 .126 r
F
.34628 .49214 m .34467 .49053 L .34727 .48963 L F
.72357 .49195 m .72508 .48971 L .72634 .49117 L F
.72357 .49195 m .7223 .49051 L .72508 .48971 L F
.38442 .49233 m .38545 .49011 L .38702 .49166 L 0 .028 .127 r
F
.38442 .49233 m .38285 .49078 L .38545 .49011 L F
.53699 .49309 m .53823 .49069 L .53967 .49232 L 0 .029 .129 r
F
.53699 .49309 m .53555 .49144 L .53823 .49069 L F
.4539 .4931 m .45503 .49091 L .45654 .49235 L F
.4539 .4931 m .45238 .49164 L .45503 .49091 L F
.35308 .49181 m .35407 .48944 L .35568 .49094 L 0 .026 .125 r
F
.35308 .49181 m .35147 .49032 L .35407 .48944 L F
.42937 .49219 m .43046 .48988 L .43199 .49148 L 0 .027 .127 r
F
.42937 .49219 m .42783 .49061 L .43046 .48988 L F
.31494 .49163 m .31587 .48936 L .31751 .49084 L 0 .026 .125 r
F
.31494 .49163 m .3133 .49014 L .31587 .48936 L F
.49885 .493 m .50004 .49059 L .50151 .4922 L 0 .029 .129 r
F
.49885 .493 m .49737 .49139 L .50004 .49059 L F
.63368 .49247 m .63506 .49005 L .63641 .49163 L 0 .028 .127 r
F
.63368 .49247 m .63233 .49091 L .63506 .49005 L F
.58874 .49274 m .59006 .49039 L .59145 .49195 L 0 .029 .128 r
F
.58874 .49274 m .58734 .49118 L .59006 .49039 L F
.73039 .49184 m .73191 .4896 L .73317 .49107 L 0 .027 .126 r
F
.73039 .49184 m .72913 .49039 L .73191 .4896 L F
.35987 .49168 m .36087 .48942 L .36247 .49093 L 0 .026 .126 r
F
.35987 .49168 m .35827 .49018 L .36087 .48942 L F
.67864 .49249 m .68008 .49012 L .6814 .49172 L 0 .028 .128 r
F
.67864 .49249 m .67732 .49089 L .68008 .49012 L F
.4607 .49307 m .46183 .49095 L .46334 .49235 L 0 .03 .13 r
F
.4607 .49307 m .45919 .49165 L .46183 .49095 L F
.32172 .49156 m .32268 .48907 L .32431 .49068 L 0 .026 .125 r
F
.32172 .49156 m .32009 .48997 L .32268 .48907 L F
.64049 .49233 m .64188 .48992 L .64323 .4915 L 0 .028 .127 r
F
.64049 .49233 m .63915 .49077 L .64188 .48992 L F
.50565 .4929 m .50685 .49055 L .50832 .49207 L 0 .029 .129 r
F
.50565 .4929 m .50418 .49138 L .50685 .49055 L F
.54379 .49316 m .54505 .49081 L .54648 .49239 L 0 .03 .13 r
F
.54379 .49316 m .54236 .49156 L .54505 .49081 L F
.59555 .49259 m .59687 .49011 L .59826 .49169 L 0 .028 .128 r
F
.59555 .49259 m .59416 .49103 L .59687 .49011 L F
.60235 .49229 m .60369 .48986 L .60507 .49138 L 0 .028 .127 r
F
.60235 .49229 m .60097 .49078 L .60369 .48986 L F
.68545 .49231 m .6869 .48985 L .6882 .49138 L F
.68545 .49231 m .68415 .49078 L .6869 .48985 L F
.3912 .4925 m .39224 .49015 L .39382 .49166 L 0 .028 .128 r
F
.3912 .4925 m .38963 .49099 L .39224 .49015 L F
.69226 .49194 m .69372 .48953 L .69501 .49104 L 0 .027 .126 r
F
.69226 .49194 m .69096 .49045 L .69372 .48953 L F
.43615 .49233 m .43726 .48997 L .43879 .49156 L 0 .028 .128 r
F
.43615 .49233 m .43462 .49076 L .43726 .48997 L F
.60916 .49196 m .61051 .48971 L .61188 .49118 L 0 .027 .127 r
F
.60916 .49196 m .60778 .49048 L .61051 .48971 L F
.4675 .49291 m .46865 .49056 L .47015 .492 L 0 .029 .129 r
F
.4675 .49291 m .46599 .49147 L .46865 .49056 L F
.73721 .49179 m .73873 .48932 L .73999 .49087 L 0 .027 .126 r
F
.73721 .49179 m .73595 .49025 L .73873 .48932 L F
.48111 .49217 m .48227 .48993 L .48376 .49134 L 0 .028 .127 r
F
.48111 .49217 m .47961 .49074 L .48227 .48993 L F
.32851 .49141 m .32947 .48896 L .3311 .49057 L 0 .026 .125 r
F
.32851 .49141 m .32689 .4898 L .32947 .48896 L F
.4743 .49257 m .47546 .49021 L .47696 .49166 L 0 .029 .128 r
F
.4743 .49257 m .4728 .4911 L .47546 .49021 L F
.36666 .49164 m .36767 .48927 L .36926 .49081 L 0 .027 .126 r
F
.36666 .49164 m .36506 .49012 L .36767 .48927 L F
.64731 .49224 m .64871 .4898 L .65005 .49136 L 0 .028 .127 r
F
.64731 .49224 m .64597 .49066 L .64871 .4898 L F
.69907 .49167 m .70054 .48931 L .70183 .49084 L 0 .027 .126 r
F
.69907 .49167 m .69777 .49015 L .70054 .48931 L F
.398 .49226 m .39905 .48992 L .40062 .49138 L 0 .028 .128 r
F
.398 .49226 m .39643 .49077 L .39905 .48992 L F
.51245 .49283 m .51366 .4906 L .51512 .4921 L 0 .029 .129 r
F
.51245 .49283 m .51099 .49132 L .51366 .4906 L F
.74403 .49157 m .74555 .48907 L .74681 .4907 L 0 .026 .125 r
F
.74403 .49157 m .74277 .48996 L .74555 .48907 L F
.65412 .49201 m .65553 .4896 L .65686 .49111 L 0 .027 .127 r
F
.65412 .49201 m .65278 .49048 L .65553 .4896 L F
.5506 .49316 m .55187 .49093 L .55329 .49242 L 0 .03 .131 r
F
.5506 .49316 m .54917 .49166 L .55187 .49093 L F
.61597 .49185 m .61733 .48962 L .61869 .49106 L 0 .027 .127 r
F
.61597 .49185 m .6146 .4904 L .61733 .48962 L F
.37345 .4915 m .37447 .48921 L .37605 .49074 L 0 .027 .126 r
F
.37345 .4915 m .37186 .48998 L .37447 .48921 L F
.3353 .49132 m .33627 .4889 L .33789 .4905 L 0 .026 .125 r
F
.3353 .49132 m .33368 .48972 L .33627 .4889 L F
.66093 .49173 m .66235 .48935 L .66367 .49086 L 0 .027 .126 r
F
.66093 .49173 m .6596 .49022 L .66235 .48935 L F
.4048 .49214 m .40586 .48986 L .40742 .49135 L 0 .028 .128 r
F
.4048 .49214 m .40324 .49062 L .40586 .48986 L F
.57102 .49214 m .57231 .48984 L .57372 .4913 L F
.57102 .49214 m .56961 .49068 L .57231 .48984 L F
.48791 .49215 m .48908 .48983 L .49057 .4914 L F
.48791 .49215 m .48642 .49059 L .48908 .48983 L F
.56421 .49253 m .56549 .49016 L .56691 .49161 L 0 .029 .129 r
F
.56421 .49253 m .5628 .4911 L .56549 .49016 L F
.44295 .49237 m .44406 .48996 L .44559 .4916 L 0 .029 .128 r
F
.44295 .49237 m .44142 .49076 L .44406 .48996 L F
.55741 .49294 m .55868 .49061 L .5601 .49202 L 0 .03 .13 r
F
.55741 .49294 m .55598 .49155 L .55868 .49061 L F
.70589 .49162 m .70737 .48917 L .70865 .49076 L 0 .027 .126 r
F
.70589 .49162 m .7046 .49001 L .70737 .48917 L F
.75085 .49148 m .75238 .48897 L .75364 .49063 L 0 .026 .126 r
F
.75085 .49148 m .74959 .48983 L .75238 .48897 L F
.51925 .49282 m .52047 .49051 L .52193 .49199 L 0 .03 .13 r
F
.51925 .49282 m .5178 .49135 L .52047 .49051 L F
.66774 .4916 m .66917 .48929 L .67049 .49083 L 0 .027 .126 r
F
.66774 .4916 m .66642 .49007 L .66917 .48929 L F
.41159 .49198 m .41267 .48962 L .41422 .49109 L 0 .028 .127 r
F
.41159 .49198 m .41004 .4905 L .41267 .48962 L F
.57782 .49199 m .57913 .4898 L .58053 .49123 L 0 .028 .128 r
F
.57782 .49199 m .57642 .49055 L .57913 .4898 L F
.62279 .49185 m .62415 .4895 L .62551 .49106 L 0 .028 .127 r
F
.62279 .49185 m .62142 .49028 L .62415 .4895 L F
.52606 .49262 m .52729 .4903 L .52874 .49176 L 0 .029 .129 r
F
.52606 .49262 m .52461 .49116 L .52729 .4903 L F
.71271 .49149 m .71419 .48902 L .71548 .49061 L 0 .027 .126 r
F
.71271 .49149 m .71142 .4899 L .71419 .48902 L F
.38024 .4915 m .38126 .48923 L .38285 .49078 L F
.38024 .4915 m .37866 .48997 L .38126 .48923 L F
.34209 .49132 m .34306 .48892 L .34467 .49053 L F
.34209 .49132 m .34047 .48971 L .34306 .48892 L F
.4184 .49171 m .41948 .4893 L .42103 .49079 L 0 .027 .127 r
F
.4184 .49171 m .41685 .4902 L .41948 .4893 L F
.30393 .4912 m .30485 .48877 L .3065 .49028 L 0 .026 .125 r
F
.30393 .4912 m .30227 .48968 L .30485 .48877 L F
.53286 .49234 m .5341 .48998 L .53555 .49144 L 0 .029 .129 r
F
.53286 .49234 m .53142 .49087 L .5341 .48998 L F
.49471 .49219 m .49589 .48974 L .49737 .49139 L 0 .029 .128 r
F
.49471 .49219 m .49323 .49057 L .49589 .48974 L F
.4252 .49146 m .42629 .48902 L .42783 .49061 L 0 .027 .126 r
F
.4252 .49146 m .42366 .48988 L .42629 .48902 L F
.44974 .49243 m .45087 .49005 L .45238 .49164 L 0 .029 .129 r
F
.44974 .49243 m .44823 .49082 L .45087 .49005 L F
.31072 .49092 m .31165 .48865 L .3133 .49014 L 0 .026 .125 r
F
.31072 .49092 m .30908 .48942 L .31165 .48865 L F
.71952 .49131 m .72103 .48895 L .7223 .49051 L 0 .027 .126 r
F
.71952 .49131 m .71825 .48976 L .72103 .48895 L F
.58463 .49193 m .58595 .48974 L .58734 .49118 L 0 .028 .128 r
F
.58463 .49193 m .58324 .49048 L .58595 .48974 L F
.6296 .49177 m .63097 .48933 L .63233 .49091 L 0 .028 .127 r
F
.6296 .49177 m .62824 .4902 L .63097 .48933 L F
.34888 .49123 m .34987 .48872 L .35147 .49032 L 0 .026 .126 r
F
.34888 .49123 m .34727 .48963 L .34987 .48872 L F
.67457 .49165 m .67601 .48929 L .67732 .49089 L 0 .028 .127 r
F
.67457 .49165 m .67325 .49006 L .67601 .48929 L F
.35568 .49094 m .35667 .48867 L .35827 .49018 L 0 .026 .125 r
F
.35568 .49094 m .35407 .48944 L .35667 .48867 L F
.72634 .49117 m .72786 .48893 L .72913 .49039 L 0 .027 .126 r
F
.72634 .49117 m .72508 .48971 L .72786 .48893 L F
.53967 .49232 m .54092 .48996 L .54236 .49156 L 0 .029 .129 r
F
.53967 .49232 m .53823 .49069 L .54092 .48996 L F
.45654 .49235 m .45767 .49023 L .45919 .49165 L 0 .03 .13 r
F
.45654 .49235 m .45503 .49091 L .45767 .49023 L F
.31751 .49084 m .31845 .48849 L .32009 .48997 L 0 .026 .125 r
F
.31751 .49084 m .31587 .48936 L .31845 .48849 L F
.63641 .49163 m .6378 .48918 L .63915 .49077 L 0 .028 .127 r
F
.63641 .49163 m .63506 .49005 L .6378 .48918 L F
.50151 .4922 m .50271 .48977 L .50418 .49138 L 0 .029 .129 r
F
.50151 .4922 m .50004 .49059 L .50271 .48977 L F
.38702 .49166 m .38806 .48943 L .38963 .49099 L 0 .028 .128 r
F
.38702 .49166 m .38545 .49011 L .38806 .48943 L F
.43199 .49148 m .43309 .48914 L .43462 .49076 L 0 .028 .127 r
F
.43199 .49148 m .43046 .48988 L .43309 .48914 L F
.59145 .49195 m .59277 .48946 L .59416 .49103 L 0 .028 .128 r
F
.59145 .49195 m .59006 .49039 L .59277 .48946 L F
.32431 .49068 m .32526 .48818 L .32689 .4898 L 0 .026 .125 r
F
.32431 .49068 m .32268 .48907 L .32526 .48818 L F
.73317 .49107 m .73469 .48878 L .73595 .49025 L 0 .027 .126 r
F
.73317 .49107 m .73191 .4896 L .73469 .48878 L F
.36247 .49093 m .36347 .48858 L .36506 .49012 L F
.36247 .49093 m .36087 .48942 L .36347 .48858 L F
.64323 .4915 m .64462 .48908 L .64597 .49066 L 0 .028 .127 r
F
.64323 .4915 m .64188 .48992 L .64462 .48908 L F
.50832 .49207 m .50952 .48981 L .51099 .49132 L 0 .029 .129 r
F
.50832 .49207 m .50685 .49055 L .50952 .48981 L F
.59826 .49169 m .59959 .48919 L .60097 .49078 L 0 .028 .128 r
F
.59826 .49169 m .59687 .49011 L .59959 .48919 L F
.6814 .49172 m .68283 .48919 L .68415 .49078 L F
.6814 .49172 m .68008 .49012 L .68283 .48919 L F
.6882 .49138 m .68966 .48891 L .69096 .49045 L 0 .027 .127 r
F
.6882 .49138 m .6869 .48985 L .68966 .48891 L F
.60507 .49138 m .60641 .48894 L .60778 .49048 L 0 .028 .127 r
F
.60507 .49138 m .60369 .48986 L .60641 .48894 L F
.46334 .49235 m .46448 .49007 L .46599 .49147 L 0 .03 .13 r
F
.46334 .49235 m .46183 .49095 L .46448 .49007 L F
.69501 .49104 m .69648 .48861 L .69777 .49015 L 0 .027 .126 r
F
.69501 .49104 m .69372 .48953 L .69648 .48861 L F
.47015 .492 m .4713 .48966 L .4728 .4911 L 0 .029 .129 r
F
.47015 .492 m .46865 .49056 L .4713 .48966 L F
.73999 .49087 m .74151 .4884 L .74277 .48996 L 0 .026 .126 r
F
.73999 .49087 m .73873 .48932 L .74151 .4884 L F
.54648 .49239 m .54774 .49009 L .54917 .49166 L 0 .03 .13 r
F
.54648 .49239 m .54505 .49081 L .54774 .49009 L F
.47696 .49166 m .47812 .48932 L .47961 .49074 L 0 .028 .128 r
F
.47696 .49166 m .47546 .49021 L .47812 .48932 L F
.39382 .49166 m .39486 .48929 L .39643 .49077 L F
.39382 .49166 m .39224 .49015 L .39486 .48929 L F
.3311 .49057 m .33206 .48813 L .33368 .48972 L 0 .026 .125 r
F
.3311 .49057 m .32947 .48896 L .33206 .48813 L F
.48376 .49134 m .48493 .48916 L .48642 .49059 L 0 .028 .128 r
F
.48376 .49134 m .48227 .48993 L .48493 .48916 L F
.65005 .49136 m .65145 .48894 L .65278 .49048 L 0 .028 .127 r
F
.65005 .49136 m .64871 .4898 L .65145 .48894 L F
.43879 .49156 m .4399 .48914 L .44142 .49076 L 0 .028 .128 r
F
.43879 .49156 m .43726 .48997 L .4399 .48914 L F
.61188 .49118 m .61323 .48895 L .6146 .4904 L 0 .028 .127 r
F
.61188 .49118 m .61051 .48971 L .61323 .48895 L F
.36926 .49081 m .37027 .48842 L .37186 .48998 L 0 .027 .126 r
F
.36926 .49081 m .36767 .48927 L .37027 .48842 L F
.40062 .49138 m .40167 .48918 L .40324 .49062 L 0 .028 .128 r
F
.40062 .49138 m .39905 .48992 L .40167 .48918 L F
.70183 .49084 m .70331 .4885 L .7046 .49001 L 0 .027 .126 r
F
.70183 .49084 m .70054 .48931 L .70331 .4885 L F
.74681 .4907 m .74834 .48818 L .74959 .48983 L 0 .026 .125 r
F
.74681 .4907 m .74555 .48907 L .74834 .48818 L F
.65686 .49111 m .65827 .48872 L .6596 .49022 L 0 .027 .127 r
F
.65686 .49111 m .65553 .4896 L .65827 .48872 L F
.51512 .4921 m .51634 .48985 L .5178 .49135 L 0 .03 .13 r
F
.51512 .4921 m .51366 .4906 L .51634 .48985 L F
.56691 .49161 m .5682 .48923 L .56961 .49068 L 0 .029 .128 r
F
.56691 .49161 m .56549 .49016 L .5682 .48923 L F
.66367 .49086 m .6651 .48856 L .66642 .49007 L 0 .027 .126 r
F
.66367 .49086 m .66235 .48935 L .6651 .48856 L F
.61869 .49106 m .62006 .48886 L .62142 .49028 L 0 .028 .127 r
F
.61869 .49106 m .61733 .48962 L .62006 .48886 L F
.33789 .4905 m .33886 .48811 L .34047 .48971 L 0 .026 .125 r
F
.33789 .4905 m .33627 .4889 L .33886 .48811 L F
.5601 .49202 m .56138 .48967 L .5628 .4911 L 0 .03 .13 r
F
.5601 .49202 m .55868 .49061 L .56138 .48967 L F
.55329 .49242 m .55456 .49006 L .55598 .49155 L 0 .031 .131 r
F
.55329 .49242 m .55187 .49093 L .55456 .49006 L F
.57372 .4913 m .57502 .4891 L .57642 .49055 L 0 .028 .128 r
F
.57372 .4913 m .57231 .48984 L .57502 .4891 L F
.37605 .49074 m .37707 .48843 L .37866 .48997 L 0 .027 .126 r
F
.37605 .49074 m .37447 .48921 L .37707 .48843 L F
.70865 .49076 m .71014 .48831 L .71142 .4899 L F
.70865 .49076 m .70737 .48917 L .71014 .48831 L F
.40742 .49135 m .40848 .48903 L .41004 .4905 L 0 .028 .128 r
F
.40742 .49135 m .40586 .48986 L .40848 .48903 L F
.75364 .49063 m .75518 .48812 L .75643 .48976 L 0 .026 .125 r
F
.75364 .49063 m .75238 .48897 L .75518 .48812 L F
.49057 .4914 m .49175 .48897 L .49323 .49057 L 0 .028 .128 r
F
.49057 .4914 m .48908 .48983 L .49175 .48897 L F
.44559 .4916 m .4467 .48919 L .44823 .49082 L 0 .029 .129 r
F
.44559 .4916 m .44406 .48996 L .4467 .48919 L F
.52193 .49199 m .52315 .48967 L .52461 .49116 L 0 .03 .13 r
F
.52193 .49199 m .52047 .49051 L .52315 .48967 L F
.41422 .49109 m .41529 .48874 L .41685 .4902 L 0 .028 .127 r
F
.41422 .49109 m .41267 .48962 L .41529 .48874 L F
.2997 .49058 m .30062 .48817 L .30227 .48968 L 0 .027 .126 r
F
.2997 .49058 m .29804 .48906 L .30062 .48817 L F
.42103 .49079 m .42211 .48839 L .42366 .48988 L F
.42103 .49079 m .41948 .4893 L .42211 .48839 L F
.71548 .49061 m .71697 .48818 L .71825 .48976 L F
.71548 .49061 m .71419 .48902 L .71697 .48818 L F
.52874 .49176 m .52997 .48941 L .53142 .49087 L 0 .029 .129 r
F
.52874 .49176 m .52729 .4903 L .52997 .48941 L F
.67049 .49083 m .67193 .48851 L .67325 .49006 L 0 .027 .127 r
F
.67049 .49083 m .66917 .48929 L .67193 .48851 L F
.58053 .49123 m .58184 .48905 L .58324 .49048 L 0 .029 .128 r
F
.58053 .49123 m .57913 .4898 L .58184 .48905 L F
.3065 .49028 m .30743 .48792 L .30908 .48942 L 0 .026 .125 r
F
.3065 .49028 m .30485 .48877 L .30743 .48792 L F
.62551 .49106 m .62688 .48864 L .62824 .4902 L 0 .028 .127 r
F
.62551 .49106 m .62415 .4895 L .62688 .48864 L F
.53555 .49144 m .53679 .48924 L .53823 .49069 L 0 .029 .129 r
F
.53555 .49144 m .5341 .48998 L .53679 .48924 L F
.34467 .49053 m .34566 .48802 L .34727 .48963 L 0 .027 .126 r
F
.34467 .49053 m .34306 .48892 L .34566 .48802 L F
.38285 .49078 m .38387 .48853 L .38545 .49011 L 0 .028 .127 r
F
.38285 .49078 m .38126 .48923 L .38387 .48853 L F
.42783 .49061 m .42892 .48827 L .43046 .48988 L 0 .027 .126 r
F
.42783 .49061 m .42629 .48902 L .42892 .48827 L F
.49737 .49139 m .49856 .48893 L .50004 .49059 L 0 .029 .128 r
F
.49737 .49139 m .49589 .48974 L .49856 .48893 L F
.35147 .49032 m .35247 .48785 L .35407 .48944 L 0 .026 .125 r
F
.35147 .49032 m .34987 .48872 L .35247 .48785 L F
.45238 .49164 m .45351 .48931 L .45503 .49091 L 0 .029 .129 r
F
.45238 .49164 m .45087 .49005 L .45351 .48931 L F
.7223 .49051 m .72381 .48814 L .72508 .48971 L 0 .027 .126 r
F
.7223 .49051 m .72103 .48895 L .72381 .48814 L F
.3133 .49014 m .31422 .48788 L .31587 .48936 L 0 .026 .125 r
F
.3133 .49014 m .31165 .48865 L .31422 .48788 L F
.63233 .49091 m .63371 .48845 L .63506 .49005 L 0 .028 .127 r
F
.63233 .49091 m .63097 .48933 L .63371 .48845 L F
.58734 .49118 m .58866 .48895 L .59006 .49039 L 0 .029 .128 r
F
.58734 .49118 m .58595 .48974 L .58866 .48895 L F
.67732 .49089 m .67877 .48852 L .68008 .49012 L 0 .028 .127 r
F
.67732 .49089 m .67601 .48929 L .67877 .48852 L F
.32009 .48997 m .32104 .48759 L .32268 .48907 L 0 .026 .125 r
F
.32009 .48997 m .31845 .48849 L .32104 .48759 L F
.35827 .49018 m .35926 .4879 L .36087 .48942 L 0 .027 .126 r
F
.35827 .49018 m .35667 .48867 L .35926 .4879 L F
.72913 .49039 m .73065 .48814 L .73191 .4896 L F
.72913 .49039 m .72786 .48893 L .73065 .48814 L F
.63915 .49077 m .64053 .48831 L .64188 .48992 L 0 .028 .127 r
F
.63915 .49077 m .6378 .48918 L .64053 .48831 L F
.54236 .49156 m .54361 .48922 L .54505 .49081 L 0 .03 .13 r
F
.54236 .49156 m .54092 .48996 L .54361 .48922 L F
.50418 .49138 m .50538 .48896 L .50685 .49055 L 0 .029 .129 r
F
.50418 .49138 m .50271 .48977 L .50538 .48896 L F
.59416 .49103 m .59548 .48853 L .59687 .49011 L 0 .028 .128 r
F
.59416 .49103 m .59277 .48946 L .59548 .48853 L F
.45919 .49165 m .46032 .48955 L .46183 .49095 L 0 .03 .131 r
F
.45919 .49165 m .45767 .49023 L .46032 .48955 L F
.32689 .4898 m .32785 .48736 L .32947 .48896 L 0 .026 .125 r
F
.32689 .4898 m .32526 .48818 L .32785 .48736 L F
.43462 .49076 m .43573 .48833 L .43726 .48997 L 0 .028 .127 r
F
.43462 .49076 m .43309 .48914 L .43573 .48833 L F
.60097 .49078 m .6023 .48826 L .60369 .48986 L F
.60097 .49078 m .59959 .48919 L .6023 .48826 L F
.68415 .49078 m .68559 .48825 L .6869 .48985 L F
.68415 .49078 m .68283 .48919 L .68559 .48825 L F
.38963 .49099 m .39067 .48861 L .39224 .49015 L 0 .028 .128 r
F
.38963 .49099 m .38806 .48943 L .39067 .48861 L F
.73595 .49025 m .73747 .48785 L .73873 .48932 L 0 .027 .126 r
F
.73595 .49025 m .73469 .48878 L .73747 .48785 L F
.69096 .49045 m .69242 .48798 L .69372 .48953 L 0 .027 .127 r
F
.69096 .49045 m .68966 .48891 L .69242 .48798 L F
.64597 .49066 m .64736 .48824 L .64871 .4898 L 0 .028 .127 r
F
.64597 .49066 m .64462 .48908 L .64736 .48824 L F
.60778 .49048 m .60913 .48818 L .61051 .48971 L F
.60778 .49048 m .60641 .48894 L .60913 .48818 L F
.36506 .49012 m .36607 .48771 L .36767 .48927 L 0 .027 .126 r
F
.36506 .49012 m .36347 .48858 L .36607 .48771 L F
.46599 .49147 m .46714 .48915 L .46865 .49056 L 0 .03 .13 r
F
.46599 .49147 m .46448 .49007 L .46714 .48915 L F
.69777 .49015 m .69925 .48779 L .70054 .48931 L 0 .027 .126 r
F
.69777 .49015 m .69648 .48861 L .69925 .48779 L F
.74277 .48996 m .74429 .48749 L .74555 .48907 L 0 .026 .125 r
F
.74277 .48996 m .74151 .4884 L .74429 .48749 L F
.4728 .4911 m .47396 .48878 L .47546 .49021 L 0 .029 .129 r
F
.4728 .4911 m .4713 .48966 L .47396 .48878 L F
.47961 .49074 m .48078 .48851 L .48227 .48993 L 0 .028 .128 r
F
.47961 .49074 m .47812 .48932 L .48078 .48851 L F
.51099 .49132 m .5122 .48909 L .51366 .4906 L 0 .03 .13 r
F
.51099 .49132 m .50952 .48981 L .5122 .48909 L F
.39643 .49077 m .39748 .48845 L .39905 .48992 L 0 .028 .128 r
F
.39643 .49077 m .39486 .48929 L .39748 .48845 L F
.65278 .49048 m .65419 .48808 L .65553 .4896 L 0 .028 .127 r
F
.65278 .49048 m .65145 .48894 L .65419 .48808 L F
.33368 .48972 m .33465 .48732 L .33627 .4889 L 0 .026 .125 r
F
.33368 .48972 m .33206 .48813 L .33465 .48732 L F
.54917 .49166 m .55044 .48936 L .55187 .49093 L 0 .03 .131 r
F
.54917 .49166 m .54774 .49009 L .55044 .48936 L F
.37186 .48998 m .37288 .48764 L .37447 .48921 L 0 .027 .126 r
F
.37186 .48998 m .37027 .48842 L .37288 .48764 L F
.44142 .49076 m .44254 .48832 L .44406 .48996 L 0 .028 .128 r
F
.44142 .49076 m .4399 .48914 L .44254 .48832 L F
.7046 .49001 m .70608 .48768 L .70737 .48917 L 0 .027 .126 r
F
.7046 .49001 m .70331 .4885 L .70608 .48768 L F
.48642 .49059 m .4876 .4884 L .48908 .48983 L 0 .028 .128 r
F
.48642 .49059 m .48493 .48916 L .4876 .4884 L F
.74959 .48983 m .75113 .4873 L .75238 .48897 L 0 .026 .125 r
F
.74959 .48983 m .74834 .48818 L .75113 .4873 L F
.6146 .4904 m .61596 .48818 L .61733 .48962 L 0 .028 .127 r
F
.6146 .4904 m .61323 .48895 L .61596 .48818 L F
.6596 .49022 m .66102 .48785 L .66235 .48935 L 0 .027 .127 r
F
.6596 .49022 m .65827 .48872 L .66102 .48785 L F
.40324 .49062 m .40429 .48844 L .40586 .48986 L 0 .028 .128 r
F
.40324 .49062 m .40167 .48918 L .40429 .48844 L F
.56961 .49068 m .5709 .48838 L .57231 .48984 L F
.56961 .49068 m .5682 .48923 L .5709 .48838 L F
.5628 .4911 m .56408 .48872 L .56549 .49016 L 0 .029 .129 r
F
.5628 .4911 m .56138 .48967 L .56408 .48872 L F
.5178 .49135 m .51902 .48898 L .52047 .49051 L 0 .03 .13 r
F
.5178 .49135 m .51634 .48985 L .51902 .48898 L F
.55598 .49155 m .55726 .48911 L .55868 .49061 L F
.55598 .49155 m .55456 .49006 L .55726 .48911 L F
.66642 .49007 m .66785 .48776 L .66917 .48929 L 0 .027 .127 r
F
.66642 .49007 m .6651 .48856 L .66785 .48776 L F
.71142 .4899 m .71291 .48746 L .71419 .48902 L 0 .027 .126 r
F
.71142 .4899 m .71014 .48831 L .71291 .48746 L F
.34047 .48971 m .34145 .48732 L .34306 .48892 L 0 .026 .125 r
F
.34047 .48971 m .33886 .48811 L .34145 .48732 L F
.62142 .49028 m .62279 .48809 L .62415 .4895 L 0 .028 .127 r
F
.62142 .49028 m .62006 .48886 L .62279 .48809 L F
.41004 .4905 m .41111 .48815 L .41267 .48962 L 0 .028 .128 r
F
.41004 .4905 m .40848 .48903 L .41111 .48815 L F
.75643 .48976 m .75797 .48727 L .75922 .48889 L 0 .026 .125 r
F
.75643 .48976 m .75518 .48812 L .75797 .48727 L F
.37866 .48997 m .37968 .48768 L .38126 .48923 L 0 .027 .127 r
F
.37866 .48997 m .37707 .48843 L .37968 .48768 L F
.57642 .49055 m .57773 .48836 L .57913 .4898 L 0 .029 .128 r
F
.57642 .49055 m .57502 .4891 L .57773 .48836 L F
.49323 .49057 m .49442 .48811 L .49589 .48974 L 0 .028 .128 r
F
.49323 .49057 m .49175 .48897 L .49442 .48811 L F
.41685 .4902 m .41793 .48784 L .41948 .4893 L 0 .028 .127 r
F
.41685 .4902 m .41529 .48874 L .41793 .48784 L F
.52461 .49116 m .52584 .4888 L .52729 .4903 L 0 .03 .13 r
F
.52461 .49116 m .52315 .48967 L .52584 .4888 L F
.30227 .48968 m .30319 .48728 L .30485 .48877 L 0 .026 .126 r
F
.30227 .48968 m .30062 .48817 L .30319 .48728 L F
.44823 .49082 m .44935 .48842 L .45087 .49005 L 0 .029 .129 r
F
.44823 .49082 m .4467 .48919 L .44935 .48842 L F
.42366 .48988 m .42475 .48753 L .42629 .48902 L 0 .027 .126 r
F
.42366 .48988 m .42211 .48839 L .42475 .48753 L F
.53142 .49087 m .53266 .48852 L .5341 .48998 L 0 .029 .129 r
F
.53142 .49087 m .52997 .48941 L .53266 .48852 L F
.71825 .48976 m .71975 .48735 L .72103 .48895 L 0 .027 .126 r
F
.71825 .48976 m .71697 .48818 L .71975 .48735 L F
.30908 .48942 m .31 .48716 L .31165 .48865 L 0 .026 .125 r
F
.30908 .48942 m .30743 .48792 L .31 .48716 L F
.34727 .48963 m .34826 .48711 L .34987 .48872 L F
.34727 .48963 m .34566 .48802 L .34826 .48711 L F
.62824 .4902 m .62961 .48775 L .63097 .48933 L 0 .028 .127 r
F
.62824 .4902 m .62688 .48864 L .62961 .48775 L F
.67325 .49006 m .67469 .48773 L .67601 .48929 L F
.67325 .49006 m .67193 .48851 L .67469 .48773 L F
.58324 .49048 m .58455 .48831 L .58595 .48974 L 0 .029 .129 r
F
.58324 .49048 m .58184 .48905 L .58455 .48831 L F
.53823 .49069 m .53948 .48852 L .54092 .48996 L F
.53823 .49069 m .53679 .48924 L .53948 .48852 L F
.35407 .48944 m .35506 .48709 L .35667 .48867 L 0 .026 .125 r
F
.35407 .48944 m .35247 .48785 L .35506 .48709 L F
.50004 .49059 m .50123 .48813 L .50271 .48977 L 0 .029 .128 r
F
.50004 .49059 m .49856 .48893 L .50123 .48813 L F
.63506 .49005 m .63644 .48756 L .6378 .48918 L 0 .028 .127 r
F
.63506 .49005 m .63371 .48845 L .63644 .48756 L F
.43046 .48988 m .43156 .48752 L .43309 .48914 L 0 .027 .127 r
F
.43046 .48988 m .42892 .48827 L .43156 .48752 L F
.72508 .48971 m .72659 .48735 L .72786 .48893 L 0 .027 .126 r
F
.72508 .48971 m .72381 .48814 L .72659 .48735 L F
.38545 .49011 m .38648 .48783 L .38806 .48943 L 0 .028 .128 r
F
.38545 .49011 m .38387 .48853 L .38648 .48783 L F
.31587 .48936 m .31681 .48701 L .31845 .48849 L 0 .026 .125 r
F
.31587 .48936 m .31422 .48788 L .31681 .48701 L F
.45503 .49091 m .45616 .48863 L .45767 .49023 L 0 .03 .13 r
F
.45503 .49091 m .45351 .48931 L .45616 .48863 L F
.32268 .48907 m .32362 .4867 L .32526 .48818 L 0 .026 .125 r
F
.32268 .48907 m .32104 .48759 L .32362 .4867 L F
.59006 .49039 m .59138 .48801 L .59277 .48946 L 0 .029 .128 r
F
.59006 .49039 m .58866 .48895 L .59138 .48801 L F
.64188 .48992 m .64327 .48746 L .64462 .48908 L 0 .028 .127 r
F
.64188 .48992 m .64053 .48831 L .64327 .48746 L F
.59687 .49011 m .5982 .48759 L .59959 .48919 L F
.59687 .49011 m .59548 .48853 L .5982 .48759 L F
.68008 .49012 m .68152 .48759 L .68283 .48919 L F
.68008 .49012 m .67877 .48852 L .68152 .48759 L F
.73191 .4896 m .73343 .4873 L .73469 .48878 L 0 .027 .127 r
F
.73191 .4896 m .73065 .48814 L .73343 .4873 L F
.36087 .48942 m .36187 .48705 L .36347 .48858 L 0 .027 .126 r
F
.36087 .48942 m .35926 .4879 L .36187 .48705 L F
.50685 .49055 m .50805 .48822 L .50952 .48981 L 0 .029 .129 r
F
.50685 .49055 m .50538 .48896 L .50805 .48822 L F
.6869 .48985 m .68835 .48731 L .68966 .48891 L 0 .027 .127 r
F
.6869 .48985 m .68559 .48825 L .68835 .48731 L F
.60369 .48986 m .60502 .48734 L .60641 .48894 L F
.60369 .48986 m .6023 .48826 L .60502 .48734 L F
.54505 .49081 m .54631 .48851 L .54774 .49009 L 0 .03 .13 r
F
.54505 .49081 m .54361 .48922 L .54631 .48851 L F
.73873 .48932 m .74026 .48692 L .74151 .4884 L 0 .027 .126 r
F
.73873 .48932 m .73747 .48785 L .74026 .48692 L F
.32947 .48896 m .33043 .48654 L .33206 .48813 L 0 .026 .125 r
F
.32947 .48896 m .32785 .48736 L .33043 .48654 L F
.69372 .48953 m .69518 .48705 L .69648 .48861 L 0 .027 .126 r
F
.69372 .48953 m .69242 .48798 L .69518 .48705 L F
.43726 .48997 m .43837 .48749 L .4399 .48914 L 0 .028 .127 r
F
.43726 .48997 m .43573 .48833 L .43837 .48749 L F
.39224 .49015 m .39329 .48775 L .39486 .48929 L 0 .028 .128 r
F
.39224 .49015 m .39067 .48861 L .39329 .48775 L F
.64871 .4898 m .65011 .4874 L .65145 .48894 L 0 .028 .127 r
F
.64871 .4898 m .64736 .48824 L .65011 .4874 L F
.46865 .49056 m .4698 .48825 L .4713 .48966 L 0 .03 .13 r
F
.46865 .49056 m .46714 .48915 L .4698 .48825 L F
.46183 .49095 m .46297 .48866 L .46448 .49007 L 0 .03 .131 r
F
.46183 .49095 m .46032 .48955 L .46297 .48866 L F
.74555 .48907 m .74708 .48659 L .74834 .48818 L 0 .026 .125 r
F
.74555 .48907 m .74429 .48749 L .74708 .48659 L F
.47546 .49021 m .47662 .48791 L .47812 .48932 L 0 .029 .129 r
F
.47546 .49021 m .47396 .48878 L .47662 .48791 L F
.36767 .48927 m .36868 .48685 L .37027 .48842 L 0 .027 .126 r
F
.36767 .48927 m .36607 .48771 L .36868 .48685 L F
.70054 .48931 m .70202 .48699 L .70331 .4885 L F
.70054 .48931 m .69925 .48779 L .70202 .48699 L F
.61051 .48971 m .61186 .48743 L .61323 .48895 L 0 .028 .127 r
F
.61051 .48971 m .60913 .48818 L .61186 .48743 L F
.39905 .48992 m .4001 .48773 L .40167 .48918 L 0 .028 .128 r
F
.39905 .48992 m .39748 .48845 L .4001 .48773 L F
.48227 .48993 m .48344 .48774 L .48493 .48916 L F
.48227 .48993 m .48078 .48851 L .48344 .48774 L F
.65553 .4896 m .65694 .48722 L .65827 .48872 L 0 .027 .127 r
F
.65553 .4896 m .65419 .48808 L .65694 .48722 L F
.51366 .4906 m .51487 .48834 L .51634 .48985 L 0 .03 .13 r
F
.51366 .4906 m .5122 .48909 L .51487 .48834 L F
.33627 .4889 m .33724 .48653 L .33886 .48811 L 0 .026 .125 r
F
.33627 .4889 m .33465 .48732 L .33724 .48653 L F
.75238 .48897 m .75392 .48647 L .75518 .48812 L F
.75238 .48897 m .75113 .4873 L .75392 .48647 L F
.66235 .48935 m .66377 .48704 L .6651 .48856 L 0 .027 .127 r
F
.66235 .48935 m .66102 .48785 L .66377 .48704 L F
.70737 .48917 m .70885 .48684 L .71014 .48831 L 0 .027 .126 r
F
.70737 .48917 m .70608 .48768 L .70885 .48684 L F
.44406 .48996 m .44518 .48756 L .4467 .48919 L 0 .028 .128 r
F
.44406 .48996 m .44254 .48832 L .44518 .48756 L F
.37447 .48921 m .37549 .48685 L .37707 .48843 L 0 .027 .126 r
F
.37447 .48921 m .37288 .48764 L .37549 .48685 L F
.56549 .49016 m .56678 .48777 L .5682 .48923 L 0 .029 .129 r
F
.56549 .49016 m .56408 .48872 L .56678 .48777 L F
.55187 .49093 m .55313 .48849 L .55456 .49006 L 0 .031 .131 r
F
.55187 .49093 m .55044 .48936 L .55313 .48849 L F
.61733 .48962 m .61869 .48743 L .62006 .48886 L 0 .028 .128 r
F
.61733 .48962 m .61596 .48818 L .61869 .48743 L F
.48908 .48983 m .49026 .48753 L .49175 .48897 L F
.48908 .48983 m .4876 .4884 L .49026 .48753 L F
.57231 .48984 m .57361 .48763 L .57502 .4891 L 0 .029 .128 r
F
.57231 .48984 m .5709 .48838 L .57361 .48763 L F
.55868 .49061 m .55996 .48817 L .56138 .48967 L 0 .03 .13 r
F
.55868 .49061 m .55726 .48911 L .55996 .48817 L F
.40586 .48986 m .40692 .48761 L .40848 .48903 L 0 .029 .128 r
F
.40586 .48986 m .40429 .48844 L .40692 .48761 L F
.52047 .49051 m .5217 .48811 L .52315 .48967 L 0 .03 .13 r
F
.52047 .49051 m .51902 .48898 L .5217 .48811 L F
.71419 .48902 m .71569 .48661 L .71697 .48818 L 0 .027 .126 r
F
.71419 .48902 m .71291 .48746 L .71569 .48661 L F
.41267 .48962 m .41374 .48727 L .41529 .48874 L 0 .028 .128 r
F
.41267 .48962 m .41111 .48815 L .41374 .48727 L F
.29804 .48906 m .29896 .48667 L .30062 .48817 L 0 .027 .126 r
F
.29804 .48906 m .29638 .48755 L .29896 .48667 L F
.75922 .48889 m .76077 .48639 L .76201 .48801 L 0 .026 .125 r
F
.75922 .48889 m .75797 .48727 L .76077 .48639 L F
.66917 .48929 m .67061 .48697 L .67193 .48851 L 0 .027 .127 r
F
.66917 .48929 m .66785 .48776 L .67061 .48697 L F
.34306 .48892 m .34404 .48643 L .34566 .48802 L 0 .026 .125 r
F
.34306 .48892 m .34145 .48732 L .34404 .48643 L F
.41948 .4893 m .42056 .48694 L .42211 .48839 L 0 .027 .127 r
F
.41948 .4893 m .41793 .48784 L .42056 .48694 L F
.62415 .4895 m .62552 .48722 L .62688 .48864 L 0 .028 .128 r
F
.62415 .4895 m .62279 .48809 L .62552 .48722 L F
.30485 .48877 m .30577 .48644 L .30743 .48792 L 0 .026 .125 r
F
.30485 .48877 m .30319 .48728 L .30577 .48644 L F
.52729 .4903 m .52852 .48791 L .52997 .48941 L 0 .03 .13 r
F
.52729 .4903 m .52584 .4888 L .52852 .48791 L F
.49589 .48974 m .49709 .48729 L .49856 .48893 L 0 .028 .128 r
F
.49589 .48974 m .49442 .48811 L .49709 .48729 L F
.42629 .48902 m .42738 .48677 L .42892 .48827 L 0 .027 .126 r
F
.42629 .48902 m .42475 .48753 L .42738 .48677 L F
.5341 .48998 m .53535 .48779 L .53679 .48924 L 0 .029 .129 r
F
.5341 .48998 m .53266 .48852 L .53535 .48779 L F
.57913 .4898 m .58044 .48761 L .58184 .48905 L F
.57913 .4898 m .57773 .48836 L .58044 .48761 L F
.38126 .48923 m .38229 .48696 L .38387 .48853 L 0 .028 .127 r
F
.38126 .48923 m .37968 .48768 L .38229 .48696 L F
.34987 .48872 m .35086 .48625 L .35247 .48785 L 0 .026 .125 r
F
.34987 .48872 m .34826 .48711 L .35086 .48625 L F
.45087 .49005 m .45199 .48769 L .45351 .48931 L 0 .029 .129 r
F
.45087 .49005 m .44935 .48842 L .45199 .48769 L F
.63097 .48933 m .63235 .48685 L .63371 .48845 L 0 .028 .127 r
F
.63097 .48933 m .62961 .48775 L .63235 .48685 L F
.72103 .48895 m .72253 .48653 L .72381 .48814 L 0 .027 .126 r
F
.72103 .48895 m .71975 .48735 L .72253 .48653 L F
.31165 .48865 m .31257 .4864 L .31422 .48788 L F
.31165 .48865 m .31 .48716 L .31257 .4864 L F
.67601 .48929 m .67745 .48695 L .67877 .48852 L 0 .028 .127 r
F
.67601 .48929 m .67469 .48773 L .67745 .48695 L F
.58595 .48974 m .58727 .48753 L .58866 .48895 L 0 .029 .129 r
F
.58595 .48974 m .58455 .48831 L .58727 .48753 L F
.6378 .48918 m .63918 .48667 L .64053 .48831 L 0 .027 .127 r
F
.6378 .48918 m .63644 .48756 L .63918 .48667 L F
.54092 .48996 m .54218 .48779 L .54361 .48922 L 0 .03 .13 r
F
.54092 .48996 m .53948 .48852 L .54218 .48779 L F
.50271 .48977 m .50391 .48734 L .50538 .48896 L 0 .029 .129 r
F
.50271 .48977 m .50123 .48813 L .50391 .48734 L F
.35667 .48867 m .35766 .48633 L .35926 .4879 L 0 .027 .126 r
F
.35667 .48867 m .35506 .48709 L .35766 .48633 L F
.31845 .48849 m .31939 .48611 L .32104 .48759 L 0 .026 .125 r
F
.31845 .48849 m .31681 .48701 L .31939 .48611 L F
.59277 .48946 m .59409 .48708 L .59548 .48853 L 0 .028 .128 r
F
.59277 .48946 m .59138 .48801 L .59409 .48708 L F
.72786 .48893 m .72938 .48655 L .73065 .48814 L 0 .027 .127 r
F
.72786 .48893 m .72659 .48735 L .72938 .48655 L F
.32526 .48818 m .32621 .48587 L .32785 .48736 L 0 .026 .125 r
F
.32526 .48818 m .32362 .4867 L .32621 .48587 L F
.43309 .48914 m .4342 .4867 L .43573 .48833 L 0 .028 .127 r
F
.43309 .48914 m .43156 .48752 L .4342 .4867 L F
.68283 .48919 m .68428 .48665 L .68559 .48825 L F
.68283 .48919 m .68152 .48759 L .68428 .48665 L F
.59959 .48919 m .60092 .48666 L .6023 .48826 L F
.59959 .48919 m .5982 .48759 L .60092 .48666 L F
.38806 .48943 m .3891 .487 L .39067 .48861 L 0 .028 .128 r
F
.38806 .48943 m .38648 .48783 L .3891 .487 L F
.64462 .48908 m .64602 .48664 L .64736 .48824 L 0 .028 .127 r
F
.64462 .48908 m .64327 .48746 L .64602 .48664 L F
.45767 .49023 m .45881 .48795 L .46032 .48955 L 0 .03 .131 r
F
.45767 .49023 m .45616 .48863 L .45881 .48795 L F
.68966 .48891 m .69111 .48638 L .69242 .48798 L 0 .027 .126 r
F
.68966 .48891 m .68835 .48731 L .69111 .48638 L F
.60641 .48894 m .60775 .48658 L .60913 .48818 L 0 .028 .127 r
F
.60641 .48894 m .60502 .48734 L .60775 .48658 L F
.36347 .48858 m .36447 .48616 L .36607 .48771 L 0 .027 .126 r
F
.36347 .48858 m .36187 .48705 L .36447 .48616 L F
.73469 .48878 m .73622 .48637 L .73747 .48785 L F
.73469 .48878 m .73343 .4873 L .73622 .48637 L F
.74151 .4884 m .74304 .486 L .74429 .48749 L 0 .026 .125 r
F
.74151 .4884 m .74026 .48692 L .74304 .486 L F
.69648 .48861 m .69795 .48623 L .69925 .48779 L 0 .027 .126 r
F
.69648 .48861 m .69518 .48705 L .69795 .48623 L F
.50952 .48981 m .51073 .48751 L .5122 .48909 L 0 .03 .13 r
F
.50952 .48981 m .50805 .48822 L .51073 .48751 L F
.33206 .48813 m .33302 .48573 L .33465 .48732 L 0 .026 .125 r
F
.33206 .48813 m .33043 .48654 L .33302 .48573 L F
.4713 .48966 m .47246 .48738 L .47396 .48878 L 0 .029 .129 r
F
.4713 .48966 m .4698 .48825 L .47246 .48738 L F
.39486 .48929 m .39591 .48692 L .39748 .48845 L 0 .028 .128 r
F
.39486 .48929 m .39329 .48775 L .39591 .48692 L F
.46448 .49007 m .46563 .48774 L .46714 .48915 L 0 .03 .13 r
F
.46448 .49007 m .46297 .48866 L .46563 .48774 L F
.65145 .48894 m .65286 .48656 L .65419 .48808 L 0 .028 .127 r
F
.65145 .48894 m .65011 .4874 L .65286 .48656 L F
.74834 .48818 m .74987 .48569 L .75113 .4873 L 0 .026 .125 r
F
.74834 .48818 m .74708 .48659 L .74987 .48569 L F
.47812 .48932 m .47928 .48709 L .48078 .48851 L 0 .029 .129 r
F
.47812 .48932 m .47662 .48791 L .47928 .48709 L F
.4399 .48914 m .44101 .48667 L .44254 .48832 L 0 .028 .128 r
F
.4399 .48914 m .43837 .48749 L .44101 .48667 L F
.54774 .49009 m .549 .48779 L .55044 .48936 L 0 .03 .131 r
F
.54774 .49009 m .54631 .48851 L .549 .48779 L F
.37027 .48842 m .37129 .48605 L .37288 .48764 L 0 .027 .126 r
F
.37027 .48842 m .36868 .48685 L .37129 .48605 L F
.70331 .4885 m .70479 .48618 L .70608 .48768 L F
.70331 .4885 m .70202 .48699 L .70479 .48618 L F
.65827 .48872 m .65969 .48637 L .66102 .48785 L 0 .027 .127 r
F
.65827 .48872 m .65694 .48722 L .65969 .48637 L F
.61323 .48895 m .61459 .48667 L .61596 .48818 L 0 .028 .128 r
F
.61323 .48895 m .61186 .48743 L .61459 .48667 L F
.48493 .48916 m .48611 .48697 L .4876 .4884 L 0 .029 .129 r
F
.48493 .48916 m .48344 .48774 L .48611 .48697 L F
.40167 .48918 m .40272 .48702 L .40429 .48844 L F
.40167 .48918 m .4001 .48773 L .40272 .48702 L F
.5682 .48923 m .56949 .48691 L .5709 .48838 L F
.5682 .48923 m .56678 .48777 L .56949 .48691 L F
.33886 .48811 m .33983 .48574 L .34145 .48732 L 0 .026 .125 r
F
.33886 .48811 m .33724 .48653 L .33983 .48574 L F
.75518 .48812 m .75672 .48564 L .75797 .48727 L F
.75518 .48812 m .75392 .48647 L .75672 .48564 L F
.71014 .48831 m .71163 .486 L .71291 .48746 L 0 .027 .126 r
F
.71014 .48831 m .70885 .48684 L .71163 .486 L F
.51634 .48985 m .51756 .48744 L .51902 .48898 L 0 .03 .13 r
F
.51634 .48985 m .51487 .48834 L .51756 .48744 L F
.56138 .48967 m .56266 .48723 L .56408 .48872 L F
.56138 .48967 m .55996 .48817 L .56266 .48723 L F
.55456 .49006 m .55583 .48755 L .55726 .48911 L 0 .03 .131 r
F
.55456 .49006 m .55313 .48849 L .55583 .48755 L F
.6651 .48856 m .66653 .48623 L .66785 .48776 L 0 .027 .127 r
F
.6651 .48856 m .66377 .48704 L .66653 .48623 L F
.49175 .48897 m .49293 .48666 L .49442 .48811 L 0 .028 .128 r
F
.49175 .48897 m .49026 .48753 L .49293 .48666 L F
.37707 .48843 m .3781 .48608 L .37968 .48768 L 0 .027 .126 r
F
.37707 .48843 m .37549 .48685 L .3781 .48608 L F
.4467 .48919 m .44783 .4868 L .44935 .48842 L 0 .029 .129 r
F
.4467 .48919 m .44518 .48756 L .44783 .4868 L F
.40848 .48903 m .40955 .48672 L .41111 .48815 L 0 .029 .128 r
F
.40848 .48903 m .40692 .48761 L .40955 .48672 L F
.62006 .48886 m .62143 .48668 L .62279 .48809 L 0 .028 .128 r
F
.62006 .48886 m .61869 .48743 L .62143 .48668 L F
.57502 .4891 m .57632 .48689 L .57773 .48836 L 0 .029 .129 r
F
.57502 .4891 m .57361 .48763 L .57632 .48689 L F
.52315 .48967 m .52438 .48722 L .52584 .4888 L 0 .03 .13 r
F
.52315 .48967 m .5217 .48811 L .52438 .48722 L F
.41529 .48874 m .41637 .48638 L .41793 .48784 L 0 .028 .127 r
F
.41529 .48874 m .41374 .48727 L .41637 .48638 L F
.30062 .48817 m .30153 .48579 L .30319 .48728 L 0 .027 .126 r
F
.30062 .48817 m .29896 .48667 L .30153 .48579 L F
.71697 .48818 m .71847 .48577 L .71975 .48735 L F
.71697 .48818 m .71569 .48661 L .71847 .48577 L F
.76201 .48801 m .76357 .4855 L .76481 .48709 L 0 .026 .125 r
F
.76201 .48801 m .76077 .48639 L .76357 .4855 L F
.42211 .48839 m .4232 .48609 L .42475 .48753 L 0 .027 .127 r
F
.42211 .48839 m .42056 .48694 L .4232 .48609 L F
.34566 .48802 m .34664 .48554 L .34826 .48711 L 0 .026 .125 r
F
.34566 .48802 m .34404 .48643 L .34664 .48554 L F
.62688 .48864 m .62826 .48631 L .62961 .48775 L 0 .028 .127 r
F
.62688 .48864 m .62552 .48722 L .62826 .48631 L F
.52997 .48941 m .53121 .48701 L .53266 .48852 L 0 .029 .129 r
F
.52997 .48941 m .52852 .48791 L .53121 .48701 L F
.30743 .48792 m .30834 .48569 L .31 .48716 L 0 .027 .126 r
F
.30743 .48792 m .30577 .48644 L .30834 .48569 L F
.67193 .48851 m .67337 .48618 L .67469 .48773 L 0 .028 .127 r
F
.67193 .48851 m .67061 .48697 L .67337 .48618 L F
.49856 .48893 m .49976 .48651 L .50123 .48813 L 0 .028 .128 r
F
.49856 .48893 m .49709 .48729 L .49976 .48651 L F
.35247 .48785 m .35345 .48551 L .35506 .48709 L 0 .026 .125 r
F
.35247 .48785 m .35086 .48625 L .35345 .48551 L F
.63371 .48845 m .63509 .48595 L .63644 .48756 L 0 .027 .127 r
F
.63371 .48845 m .63235 .48685 L .63509 .48595 L F
.42892 .48827 m .43002 .48602 L .43156 .48752 L F
.42892 .48827 m .42738 .48677 L .43002 .48602 L F
.53679 .48924 m .53804 .48708 L .53948 .48852 L 0 .03 .13 r
F
.53679 .48924 m .53535 .48779 L .53804 .48708 L F
.58184 .48905 m .58315 .48687 L .58455 .48831 L 0 .029 .129 r
F
.58184 .48905 m .58044 .48761 L .58315 .48687 L F
.72381 .48814 m .72531 .48573 L .72659 .48735 L 0 .027 .126 r
F
.72381 .48814 m .72253 .48653 L .72531 .48573 L F
.38387 .48853 m .3849 .48623 L .38648 .48783 L 0 .028 .128 r
F
.38387 .48853 m .38229 .48696 L .3849 .48623 L F
.45351 .48931 m .45464 .487 L .45616 .48863 L 0 .03 .13 r
F
.45351 .48931 m .45199 .48769 L .45464 .487 L F
.31422 .48788 m .31516 .48554 L .31681 .48701 L 0 .027 .126 r
F
.31422 .48788 m .31257 .4864 L .31516 .48554 L F
.64053 .48831 m .64192 .48583 L .64327 .48746 L 0 .027 .127 r
F
.64053 .48831 m .63918 .48667 L .64192 .48583 L F
.67877 .48852 m .68021 .48602 L .68152 .48759 L 0 .028 .127 r
F
.67877 .48852 m .67745 .48695 L .68021 .48602 L F
.59548 .48853 m .59681 .48615 L .5982 .48759 L 0 .028 .128 r
F
.59548 .48853 m .59409 .48708 L .59681 .48615 L F
.32104 .48759 m .32198 .48522 L .32362 .4867 L 0 .026 .125 r
F
.32104 .48759 m .31939 .48611 L .32198 .48522 L F
.58866 .48895 m .58999 .48659 L .59138 .48801 L 0 .029 .129 r
F
.58866 .48895 m .58727 .48753 L .58999 .48659 L F
.50538 .48896 m .50658 .48661 L .50805 .48822 L F
.50538 .48896 m .50391 .48734 L .50658 .48661 L F
.68559 .48825 m .68704 .48572 L .68835 .48731 L 0 .027 .127 r
F
.68559 .48825 m .68428 .48665 L .68704 .48572 L F
.6023 .48826 m .60364 .48573 L .60502 .48734 L F
.6023 .48826 m .60092 .48666 L .60364 .48573 L F
.35926 .4879 m .36026 .48549 L .36187 .48705 L 0 .027 .126 r
F
.35926 .4879 m .35766 .48633 L .36026 .48549 L F
.54361 .48922 m .54487 .48707 L .54631 .48851 L 0 .03 .13 r
F
.54361 .48922 m .54218 .48779 L .54487 .48707 L F
.32785 .48736 m .3288 .48504 L .33043 .48654 L 0 .026 .125 r
F
.32785 .48736 m .32621 .48587 L .3288 .48504 L F
.73065 .48814 m .73216 .48571 L .73343 .4873 L 0 .027 .127 r
F
.73065 .48814 m .72938 .48655 L .73216 .48571 L F
.43573 .48833 m .43684 .48585 L .43837 .48749 L 0 .028 .127 r
F
.43573 .48833 m .4342 .4867 L .43684 .48585 L F
.69242 .48798 m .69387 .48545 L .69518 .48705 L 0 .027 .126 r
F
.69242 .48798 m .69111 .48638 L .69387 .48545 L F
.73747 .48785 m .739 .48543 L .74026 .48692 L F
.73747 .48785 m .73622 .48637 L .739 .48543 L F
.39067 .48861 m .39172 .48614 L .39329 .48775 L 0 .028 .128 r
F
.39067 .48861 m .3891 .487 L .39172 .48614 L F
.64736 .48824 m .64876 .48582 L .65011 .4874 L 0 .028 .127 r
F
.64736 .48824 m .64602 .48664 L .64876 .48582 L F
.74429 .48749 m .74583 .48508 L .74708 .48659 L 0 .026 .125 r
F
.74429 .48749 m .74304 .486 L .74583 .48508 L F
.36607 .48771 m .36709 .48527 L .36868 .48685 L 0 .027 .126 r
F
.36607 .48771 m .36447 .48616 L .36709 .48527 L F
.69925 .48779 m .70072 .48544 L .70202 .48699 L F
.69925 .48779 m .69795 .48623 L .70072 .48544 L F
.60913 .48818 m .61048 .48582 L .61186 .48743 L 0 .028 .127 r
F
.60913 .48818 m .60775 .48658 L .61048 .48582 L F
.46714 .48915 m .46829 .48684 L .4698 .48825 L 0 .03 .13 r
F
.46714 .48915 m .46563 .48774 L .46829 .48684 L F
.47396 .48878 m .47512 .48651 L .47662 .48791 L 0 .029 .129 r
F
.47396 .48878 m .47246 .48738 L .47512 .48651 L F
.46032 .48955 m .46146 .48706 L .46297 .48866 L 0 .031 .131 r
F
.46032 .48955 m .45881 .48795 L .46146 .48706 L F
.75113 .4873 m .75267 .48487 L .75392 .48647 L 0 .026 .125 r
F
.75113 .4873 m .74987 .48569 L .75267 .48487 L F
.39748 .48845 m .39853 .48622 L .4001 .48773 L 0 .029 .128 r
F
.39748 .48845 m .39591 .48692 L .39853 .48622 L F
.33465 .48732 m .33561 .48494 L .33724 .48653 L 0 .026 .125 r
F
.33465 .48732 m .33302 .48573 L .33561 .48494 L F
.65419 .48808 m .65561 .48572 L .65694 .48722 L 0 .028 .127 r
F
.65419 .48808 m .65286 .48656 L .65561 .48572 L F
.48078 .48851 m .48195 .48631 L .48344 .48774 L 0 .029 .129 r
F
.48078 .48851 m .47928 .48709 L .48195 .48631 L F
.44254 .48832 m .44366 .48593 L .44518 .48756 L 0 .028 .128 r
F
.44254 .48832 m .44101 .48667 L .44366 .48593 L F
.5122 .48909 m .51341 .48677 L .51487 .48834 L 0 .03 .13 r
F
.5122 .48909 m .51073 .48751 L .51341 .48677 L F
.37288 .48764 m .3739 .48525 L .37549 .48685 L 0 .027 .126 r
F
.37288 .48764 m .37129 .48605 L .3739 .48525 L F
.55044 .48936 m .5517 .48692 L .55313 .48849 L 0 .031 .131 r
F
.55044 .48936 m .549 .48779 L .5517 .48692 L F
.66102 .48785 m .66244 .48553 L .66377 .48704 L 0 .027 .127 r
F
.66102 .48785 m .65969 .48637 L .66244 .48553 L F
.70608 .48768 m .70757 .48536 L .70885 .48684 L 0 .027 .126 r
F
.70608 .48768 m .70479 .48618 L .70757 .48536 L F
.56408 .48872 m .56536 .48629 L .56678 .48777 L 0 .029 .129 r
F
.56408 .48872 m .56266 .48723 L .56536 .48629 L F
.55726 .48911 m .55853 .48662 L .55996 .48817 L 0 .03 .13 r
F
.55726 .48911 m .55583 .48755 L .55853 .48662 L F
.61596 .48818 m .61732 .48593 L .61869 .48743 L 0 .028 .128 r
F
.61596 .48818 m .61459 .48667 L .61732 .48593 L F
.5709 .48838 m .5722 .48616 L .57361 .48763 L 0 .029 .129 r
F
.5709 .48838 m .56949 .48691 L .5722 .48616 L F
.4876 .4884 m .48877 .48609 L .49026 .48753 L F
.4876 .4884 m .48611 .48697 L .48877 .48609 L F
.75797 .48727 m .75952 .48478 L .76077 .48639 L 0 .026 .125 r
F
.75797 .48727 m .75672 .48564 L .75952 .48478 L F
.71291 .48746 m .71441 .48514 L .71569 .48661 L 0 .027 .126 r
F
.71291 .48746 m .71163 .486 L .71441 .48514 L F
.51902 .48898 m .52024 .48655 L .5217 .48811 L 0 .03 .13 r
F
.51902 .48898 m .51756 .48744 L .52024 .48655 L F
.40429 .48844 m .40535 .4862 L .40692 .48761 L 0 .029 .129 r
F
.40429 .48844 m .40272 .48702 L .40535 .4862 L F
.34145 .48732 m .34243 .48486 L .34404 .48643 L 0 .026 .125 r
F
.34145 .48732 m .33983 .48574 L .34243 .48486 L F
.49442 .48811 m .4956 .48584 L .49709 .48729 L 0 .028 .128 r
F
.49442 .48811 m .49293 .48666 L .4956 .48584 L F
.29638 .48755 m .2973 .48509 L .29896 .48667 L 0 .027 .126 r
F
.29638 .48755 m .29472 .48597 L .2973 .48509 L F
.66785 .48776 m .66928 .48542 L .67061 .48697 L 0 .028 .127 r
F
.66785 .48776 m .66653 .48623 L .66928 .48542 L F
.41111 .48815 m .41218 .48583 L .41374 .48727 L 0 .028 .128 r
F
.41111 .48815 m .40955 .48672 L .41218 .48583 L F
.41793 .48784 m .41901 .4855 L .42056 .48694 L 0 .028 .127 r
F
.41793 .48784 m .41637 .48638 L .41901 .4855 L F
.52584 .4888 m .52707 .48632 L .52852 .48791 L 0 .03 .13 r
F
.52584 .4888 m .52438 .48722 L .52707 .48632 L F
.76481 .48709 m .76637 .48461 L .76761 .48618 L 0 .026 .125 r
F
.76481 .48709 m .76357 .4855 L .76637 .48461 L F
.30319 .48728 m .30411 .48496 L .30577 .48644 L 0 .027 .126 r
F
.30319 .48728 m .30153 .48579 L .30411 .48496 L F
.44935 .48842 m .45047 .48607 L .45199 .48769 L 0 .029 .129 r
F
.44935 .48842 m .44783 .4868 L .45047 .48607 L F
.34826 .48711 m .34925 .48469 L .35086 .48625 L 0 .026 .125 r
F
.34826 .48711 m .34664 .48554 L .34925 .48469 L F
.37968 .48768 m .38071 .48533 L .38229 .48696 L 0 .027 .127 r
F
.37968 .48768 m .3781 .48608 L .38071 .48533 L F
.62279 .48809 m .62416 .4858 L .62552 .48722 L 0 .028 .128 r
F
.62279 .48809 m .62143 .48668 L .62416 .4858 L F
.42475 .48753 m .42583 .48533 L .42738 .48677 L 0 .027 .127 r
F
.42475 .48753 m .4232 .48609 L .42583 .48533 L F
.71975 .48735 m .72125 .48493 L .72253 .48653 L 0 .027 .126 r
F
.71975 .48735 m .71847 .48577 L .72125 .48493 L F
.62961 .48775 m .63099 .4854 L .63235 .48685 L 0 .028 .127 r
F
.62961 .48775 m .62826 .48631 L .63099 .4854 L F
.53266 .48852 m .5339 .48629 L .53535 .48779 L 0 .03 .13 r
F
.53266 .48852 m .53121 .48701 L .5339 .48629 L F
.57773 .48836 m .57903 .48614 L .58044 .48761 L 0 .029 .129 r
F
.57773 .48836 m .57632 .48689 L .57903 .48614 L F
.31 .48716 m .31092 .48493 L .31257 .4864 L 0 .027 .126 r
F
.31 .48716 m .30834 .48569 L .31092 .48493 L F
.67469 .48773 m .67613 .48538 L .67745 .48695 L 0 .028 .127 r
F
.67469 .48773 m .67337 .48618 L .67613 .48538 L F
.63644 .48756 m .63783 .48505 L .63918 .48667 L 0 .027 .127 r
F
.63644 .48756 m .63509 .48595 L .63783 .48505 L F
.50123 .48813 m .50243 .48573 L .50391 .48734 L 0 .029 .128 r
F
.50123 .48813 m .49976 .48651 L .50243 .48573 L F
.35506 .48709 m .35605 .48477 L .35766 .48633 L 0 .027 .126 r
F
.35506 .48709 m .35345 .48551 L .35605 .48477 L F
.43156 .48752 m .43266 .48518 L .4342 .4867 L 0 .028 .127 r
F
.43156 .48752 m .43002 .48602 L .43266 .48518 L F
.72659 .48735 m .7281 .48493 L .72938 .48655 L 0 .027 .126 r
F
.72659 .48735 m .72531 .48573 L .7281 .48493 L F
.58455 .48831 m .58587 .48609 L .58727 .48753 L 0 .03 .13 r
F
.58455 .48831 m .58315 .48687 L .58587 .48609 L F
.53948 .48852 m .54074 .48637 L .54218 .48779 L F
.53948 .48852 m .53804 .48708 L .54074 .48637 L F
.31681 .48701 m .31775 .48464 L .31939 .48611 L 0 .026 .126 r
F
.31681 .48701 m .31516 .48554 L .31775 .48464 L F
.68152 .48759 m .68297 .48509 L .68428 .48665 L 0 .028 .127 r
F
.68152 .48759 m .68021 .48602 L .68297 .48509 L F
.5982 .48759 m .59953 .48522 L .60092 .48666 L F
.5982 .48759 m .59681 .48615 L .59953 .48522 L F
.59138 .48801 m .5927 .48566 L .59409 .48708 L 0 .029 .129 r
F
.59138 .48801 m .58999 .48659 L .5927 .48566 L F
.32362 .4867 m .32457 .48439 L .32621 .48587 L 0 .026 .125 r
F
.32362 .4867 m .32198 .48522 L .32457 .48439 L F
.38648 .48783 m .38752 .48539 L .3891 .487 L 0 .028 .128 r
F
.38648 .48783 m .3849 .48623 L .38752 .48539 L F
.64327 .48746 m .64467 .48502 L .64602 .48664 L 0 .027 .127 r
F
.64327 .48746 m .64192 .48583 L .64467 .48502 L F
.45616 .48863 m .45729 .48631 L .45881 .48795 L 0 .03 .13 r
F
.45616 .48863 m .45464 .487 L .45729 .48631 L F
.68835 .48731 m .6898 .48478 L .69111 .48638 L 0 .027 .126 r
F
.68835 .48731 m .68704 .48572 L .6898 .48478 L F
.60502 .48734 m .60637 .48497 L .60775 .48658 L 0 .027 .127 r
F
.60502 .48734 m .60364 .48573 L .60637 .48497 L F
.36187 .48705 m .36287 .48461 L .36447 .48616 L 0 .027 .126 r
F
.36187 .48705 m .36026 .48549 L .36287 .48461 L F
.69518 .48705 m .69665 .48463 L .69795 .48623 L F
.69518 .48705 m .69387 .48545 L .69665 .48463 L F
.50805 .48822 m .50926 .48591 L .51073 .48751 L 0 .03 .13 r
F
.50805 .48822 m .50658 .48661 L .50926 .48591 L F
.33043 .48654 m .33139 .48423 L .33302 .48573 L 0 .026 .125 r
F
.33043 .48654 m .3288 .48504 L .33139 .48423 L F
.74026 .48692 m .74179 .4845 L .74304 .486 L 0 .027 .126 r
F
.74026 .48692 m .739 .48543 L .74179 .4845 L F
.73343 .4873 m .73495 .48478 L .73622 .48637 L 0 .027 .127 r
F
.73343 .4873 m .73216 .48571 L .73495 .48478 L F
.43837 .48749 m .43948 .48501 L .44101 .48667 L 0 .028 .127 r
F
.43837 .48749 m .43684 .48585 L .43948 .48501 L F
.74708 .48659 m .74862 .48417 L .74987 .48569 L 0 .026 .125 r
F
.74708 .48659 m .74583 .48508 L .74862 .48417 L F
.39329 .48775 m .39434 .4853 L .39591 .48692 L 0 .028 .128 r
F
.39329 .48775 m .39172 .48614 L .39434 .4853 L F
.54631 .48851 m .54757 .48635 L .549 .48779 L 0 .031 .131 r
F
.54631 .48851 m .54487 .48707 L .54757 .48635 L F
.65011 .4874 m .65151 .48499 L .65286 .48656 L 0 .028 .127 r
F
.65011 .4874 m .64876 .48582 L .65151 .48499 L F
.36868 .48685 m .36969 .48447 L .37129 .48605 L 0 .027 .126 r
F
.36868 .48685 m .36709 .48527 L .36969 .48447 L F
.4698 .48825 m .47095 .48597 L .47246 .48738 L 0 .03 .13 r
F
.4698 .48825 m .46829 .48684 L .47095 .48597 L F
.46297 .48866 m .46412 .48615 L .46563 .48774 L 0 .03 .131 r
F
.46297 .48866 m .46146 .48706 L .46412 .48615 L F
.47662 .48791 m .47778 .48568 L .47928 .48709 L 0 .029 .129 r
F
.47662 .48791 m .47512 .48651 L .47778 .48568 L F
.70202 .48699 m .7035 .48464 L .70479 .48618 L 0 .027 .126 r
F
.70202 .48699 m .70072 .48544 L .7035 .48464 L F
.65694 .48722 m .65836 .48488 L .65969 .48637 L 0 .028 .127 r
F
.65694 .48722 m .65561 .48572 L .65836 .48488 L F
.75392 .48647 m .75547 .48405 L .75672 .48564 L 0 .026 .125 r
F
.75392 .48647 m .75267 .48487 L .75547 .48405 L F
.61186 .48743 m .61321 .48507 L .61459 .48667 L 0 .028 .128 r
F
.61186 .48743 m .61048 .48582 L .61321 .48507 L F
.33724 .48653 m .33821 .48415 L .33983 .48574 L 0 .026 .125 r
F
.33724 .48653 m .33561 .48494 L .33821 .48415 L F
.55313 .48849 m .5544 .48599 L .55583 .48755 L 0 .03 .131 r
F
.55313 .48849 m .5517 .48692 L .5544 .48599 L F
.4001 .48773 m .40115 .48552 L .40272 .48702 L 0 .029 .129 r
F
.4001 .48773 m .39853 .48622 L .40115 .48552 L F
.48344 .48774 m .48461 .48553 L .48611 .48697 L F
.48344 .48774 m .48195 .48631 L .48461 .48553 L F
.44518 .48756 m .4463 .48519 L .44783 .4868 L 0 .029 .128 r
F
.44518 .48756 m .44366 .48593 L .4463 .48519 L F
.56678 .48777 m .56807 .48543 L .56949 .48691 L 0 .029 .129 r
F
.56678 .48777 m .56536 .48629 L .56807 .48543 L F
.51487 .48834 m .51609 .48587 L .51756 .48744 L 0 .03 .13 r
F
.51487 .48834 m .51341 .48677 L .51609 .48587 L F
.70885 .48684 m .71035 .48454 L .71163 .486 L 0 .027 .126 r
F
.70885 .48684 m .70757 .48536 L .71035 .48454 L F
.55996 .48817 m .56124 .4857 L .56266 .48723 L 0 .03 .13 r
F
.55996 .48817 m .55853 .48662 L .56124 .4857 L F
.37549 .48685 m .37651 .48446 L .3781 .48608 L 0 .027 .126 r
F
.37549 .48685 m .3739 .48525 L .37651 .48446 L F
.66377 .48704 m .6652 .4847 L .66653 .48623 L 0 .028 .127 r
F
.66377 .48704 m .66244 .48553 L .6652 .4847 L F
.76077 .48639 m .76232 .4839 L .76357 .4855 L 0 .026 .125 r
F
.76077 .48639 m .75952 .48478 L .76232 .4839 L F
.49026 .48753 m .49145 .48521 L .49293 .48666 L 0 .029 .129 r
F
.49026 .48753 m .48877 .48609 L .49145 .48521 L F
.5217 .48811 m .52293 .48565 L .52438 .48722 L 0 .03 .13 r
F
.5217 .48811 m .52024 .48655 L .52293 .48565 L F
.71569 .48661 m .71719 .48427 L .71847 .48577 L 0 .027 .126 r
F
.71569 .48661 m .71441 .48514 L .71719 .48427 L F
.34404 .48643 m .34503 .48399 L .34664 .48554 L 0 .026 .125 r
F
.34404 .48643 m .34243 .48486 L .34503 .48399 L F
.40692 .48761 m .40798 .4853 L .40955 .48672 L 0 .029 .129 r
F
.40692 .48761 m .40535 .4862 L .40798 .4853 L F
.29896 .48667 m .29988 .48421 L .30153 .48579 L 0 .027 .126 r
F
.29896 .48667 m .2973 .48509 L .29988 .48421 L F
.61869 .48743 m .62006 .48518 L .62143 .48668 L 0 .029 .129 r
F
.61869 .48743 m .61732 .48593 L .62006 .48518 L F
.57361 .48763 m .57491 .48542 L .57632 .48689 L F
.57361 .48763 m .5722 .48616 L .57491 .48542 L F
.41374 .48727 m .41481 .48495 L .41637 .48638 L 0 .028 .128 r
F
.41374 .48727 m .41218 .48583 L .41481 .48495 L F
.49709 .48729 m .49828 .48507 L .49976 .48651 L 0 .029 .128 r
F
.49709 .48729 m .4956 .48584 L .49828 .48507 L F
.76761 .48618 m .76918 .48378 L .77041 .48536 L 0 .026 .125 r
F
.76761 .48618 m .76637 .48461 L .76918 .48378 L F
.42056 .48694 m .42164 .48465 L .4232 .48609 L 0 .028 .127 r
F
.42056 .48694 m .41901 .4855 L .42164 .48465 L F
.52852 .48791 m .52976 .48542 L .53121 .48701 L 0 .03 .13 r
F
.52852 .48791 m .52707 .48632 L .52976 .48542 L F
.67061 .48697 m .67205 .48461 L .67337 .48618 L 0 .028 .127 r
F
.67061 .48697 m .66928 .48542 L .67205 .48461 L F
.35086 .48625 m .35184 .48396 L .35345 .48551 L 0 .026 .125 r
F
.35086 .48625 m .34925 .48469 L .35184 .48396 L F
.30577 .48644 m .30669 .48421 L .30834 .48569 L 0 .027 .126 r
F
.30577 .48644 m .30411 .48496 L .30669 .48421 L F
.62552 .48722 m .6269 .48487 L .62826 .48631 L 0 .028 .128 r
F
.62552 .48722 m .62416 .4858 L .6269 .48487 L F
.63235 .48685 m .63373 .48448 L .63509 .48595 L 0 .027 .127 r
F
.63235 .48685 m .63099 .4854 L .63373 .48448 L F
.72253 .48653 m .72403 .48411 L .72531 .48573 L 0 .027 .126 r
F
.72253 .48653 m .72125 .48493 L .72403 .48411 L F
.45199 .48769 m .45312 .48538 L .45464 .487 L 0 .03 .13 r
F
.45199 .48769 m .45047 .48607 L .45312 .48538 L F
.38229 .48696 m .38332 .48459 L .3849 .48623 L 0 .028 .127 r
F
.38229 .48696 m .38071 .48533 L .38332 .48459 L F
.42738 .48677 m .42847 .48457 L .43002 .48602 L F
.42738 .48677 m .42583 .48533 L .42847 .48457 L F
.53535 .48779 m .5366 .48559 L .53804 .48708 L 0 .03 .13 r
F
.53535 .48779 m .5339 .48629 L .5366 .48559 L F
.58044 .48761 m .58175 .48538 L .58315 .48687 L F
.58044 .48761 m .57903 .48614 L .58175 .48538 L F
.63918 .48667 m .64057 .4842 L .64192 .48583 L 0 .027 .126 r
F
.63918 .48667 m .63783 .48505 L .64057 .4842 L F
.67745 .48695 m .67889 .48445 L .68021 .48602 L 0 .028 .127 r
F
.67745 .48695 m .67613 .48538 L .67889 .48445 L F
.50391 .48734 m .50511 .48502 L .50658 .48661 L 0 .029 .129 r
F
.50391 .48734 m .50243 .48573 L .50511 .48502 L F
.31257 .4864 m .31351 .48406 L .31516 .48554 L 0 .027 .126 r
F
.31257 .4864 m .31092 .48493 L .31351 .48406 L F
.68428 .48665 m .68573 .48415 L .68704 .48572 L 0 .027 .127 r
F
.68428 .48665 m .68297 .48509 L .68573 .48415 L F
.60092 .48666 m .60226 .48429 L .60364 .48573 L F
.60092 .48666 m .59953 .48522 L .60226 .48429 L F
.31939 .48611 m .32034 .48374 L .32198 .48522 L 0 .026 .125 r
F
.31939 .48611 m .31775 .48464 L .32034 .48374 L F
.4342 .4867 m .4353 .48431 L .43684 .48585 L 0 .028 .127 r
F
.4342 .4867 m .43266 .48518 L .4353 .48431 L F
.59409 .48708 m .59542 .48473 L .59681 .48615 L 0 .028 .128 r
F
.59409 .48708 m .5927 .48566 L .59542 .48473 L F
.35766 .48633 m .35866 .48393 L .36026 .48549 L 0 .027 .126 r
F
.35766 .48633 m .35605 .48477 L .35866 .48393 L F
.72938 .48655 m .73089 .48408 L .73216 .48571 L F
.72938 .48655 m .7281 .48493 L .73089 .48408 L F
.69111 .48638 m .69257 .48384 L .69387 .48545 L F
.69111 .48638 m .6898 .48478 L .69257 .48384 L F
.58727 .48753 m .58859 .48515 L .58999 .48659 L 0 .03 .13 r
F
.58727 .48753 m .58587 .48609 L .58859 .48515 L F
.3891 .487 m .39014 .48452 L .39172 .48614 L 0 .028 .128 r
F
.3891 .487 m .38752 .48539 L .39014 .48452 L F
.32621 .48587 m .32716 .48356 L .3288 .48504 L 0 .026 .125 r
F
.32621 .48587 m .32457 .48439 L .32716 .48356 L F
.64602 .48664 m .64742 .48421 L .64876 .48582 L 0 .028 .127 r
F
.64602 .48664 m .64467 .48502 L .64742 .48421 L F
.54218 .48779 m .54343 .48564 L .54487 .48707 L 0 .031 .131 r
F
.54218 .48779 m .54074 .48637 L .54343 .48564 L F
.36447 .48616 m .36549 .48373 L .36709 .48527 L 0 .027 .126 r
F
.36447 .48616 m .36287 .48461 L .36549 .48373 L F
.73622 .48637 m .73774 .48385 L .739 .48543 L F
.73622 .48637 m .73495 .48478 L .73774 .48385 L F
.74304 .486 m .74458 .48357 L .74583 .48508 L 0 .026 .125 r
F
.74304 .486 m .74179 .4845 L .74458 .48357 L F
.60775 .48658 m .6091 .48422 L .61048 .48582 L 0 .028 .127 r
F
.60775 .48658 m .60637 .48497 L .6091 .48422 L F
.69795 .48623 m .69942 .48385 L .70072 .48544 L 0 .027 .126 r
F
.69795 .48623 m .69665 .48463 L .69942 .48385 L F
.45881 .48795 m .45995 .48543 L .46146 .48706 L 0 .03 .131 r
F
.45881 .48795 m .45729 .48631 L .45995 .48543 L F
.74987 .48569 m .75142 .48335 L .75267 .48487 L 0 .026 .125 r
F
.74987 .48569 m .74862 .48417 L .75142 .48335 L F
.44101 .48667 m .44213 .48429 L .44366 .48593 L 0 .028 .127 r
F
.44101 .48667 m .43948 .48501 L .44213 .48429 L F
.33302 .48573 m .33398 .48342 L .33561 .48494 L 0 .026 .125 r
F
.33302 .48573 m .33139 .48423 L .33398 .48342 L F
.39591 .48692 m .39696 .4846 L .39853 .48622 L 0 .029 .128 r
F
.39591 .48692 m .39434 .4853 L .39696 .4846 L F
.65286 .48656 m .65427 .48417 L .65561 .48572 L 0 .028 .127 r
F
.65286 .48656 m .65151 .48499 L .65427 .48417 L F
.51073 .48751 m .51194 .48518 L .51341 .48677 L 0 .03 .13 r
F
.51073 .48751 m .50926 .48591 L .51194 .48518 L F
.46563 .48774 m .46678 .48525 L .46829 .48684 L F
.46563 .48774 m .46412 .48615 L .46678 .48525 L F
.37129 .48605 m .37231 .48366 L .3739 .48525 L 0 .027 .126 r
F
.37129 .48605 m .36969 .48447 L .37231 .48366 L F
.47246 .48738 m .47361 .48511 L .47512 .48651 L 0 .03 .13 r
F
.47246 .48738 m .47095 .48597 L .47361 .48511 L F
.549 .48779 m .55027 .48549 L .5517 .48692 L 0 .031 .131 r
F
.549 .48779 m .54757 .48635 L .55027 .48549 L F
.47928 .48709 m .48045 .48488 L .48195 .48631 L 0 .029 .129 r
F
.47928 .48709 m .47778 .48568 L .48045 .48488 L F
.65969 .48637 m .66111 .48402 L .66244 .48553 L 0 .028 .127 r
F
.65969 .48637 m .65836 .48488 L .66111 .48402 L F
.70479 .48618 m .70628 .48383 L .70757 .48536 L 0 .027 .127 r
F
.70479 .48618 m .7035 .48464 L .70628 .48383 L F
.75672 .48564 m .75828 .48321 L .75952 .48478 L 0 .026 .125 r
F
.75672 .48564 m .75547 .48405 L .75828 .48321 L F
.55583 .48755 m .55711 .48506 L .55853 .48662 L 0 .03 .13 r
F
.55583 .48755 m .5544 .48599 L .55711 .48506 L F
.56266 .48723 m .56394 .48478 L .56536 .48629 L 0 .029 .129 r
F
.56266 .48723 m .56124 .4857 L .56394 .48478 L F
.61459 .48667 m .61595 .48432 L .61732 .48593 L 0 .028 .128 r
F
.61459 .48667 m .61321 .48507 L .61595 .48432 L F
.33983 .48574 m .3408 .48329 L .34243 .48486 L 0 .026 .125 r
F
.33983 .48574 m .33821 .48415 L .3408 .48329 L F
.51756 .48744 m .51878 .48496 L .52024 .48655 L 0 .03 .13 r
F
.51756 .48744 m .51609 .48587 L .51878 .48496 L F
.56949 .48691 m .57078 .48467 L .5722 .48616 L 0 .029 .129 r
F
.56949 .48691 m .56807 .48543 L .57078 .48467 L F
.29472 .48597 m .29564 .48347 L .2973 .48509 L 0 .027 .126 r
F
.29472 .48597 m .29306 .48436 L .29564 .48347 L F
.71163 .486 m .71313 .48368 L .71441 .48514 L F
.71163 .486 m .71035 .48454 L .71313 .48368 L F
.48611 .48697 m .48728 .48463 L .48877 .48609 L 0 .029 .129 r
F
.48611 .48697 m .48461 .48553 L .48728 .48463 L F
.66653 .48623 m .66796 .48387 L .66928 .48542 L 0 .028 .127 r
F
.66653 .48623 m .6652 .4847 L .66796 .48387 L F
.44783 .4868 m .44895 .48447 L .45047 .48607 L 0 .029 .129 r
F
.44783 .4868 m .4463 .48519 L .44895 .48447 L F
.76357 .4855 m .76513 .48303 L .76637 .48461 L 0 .026 .125 r
F
.76357 .4855 m .76232 .4839 L .76513 .48303 L F
.40272 .48702 m .40378 .4847 L .40535 .4862 L 0 .029 .129 r
F
.40272 .48702 m .40115 .48552 L .40378 .4847 L F
.3781 .48608 m .37912 .4837 L .38071 .48533 L 0 .027 .127 r
F
.3781 .48608 m .37651 .48446 L .37912 .4837 L F
.52438 .48722 m .52562 .48474 L .52707 .48632 L 0 .03 .13 r
F
.52438 .48722 m .52293 .48565 L .52562 .48474 L F
.49293 .48666 m .49412 .48438 L .4956 .48584 L 0 .029 .129 r
F
.49293 .48666 m .49145 .48521 L .49412 .48438 L F
.34664 .48554 m .34763 .48315 L .34925 .48469 L 0 .026 .125 r
F
.34664 .48554 m .34503 .48399 L .34763 .48315 L F
.71847 .48577 m .71997 .4834 L .72125 .48493 L 0 .027 .126 r
F
.71847 .48577 m .71719 .48427 L .71997 .4834 L F
.40955 .48672 m .41061 .4844 L .41218 .48583 L 0 .029 .129 r
F
.40955 .48672 m .40798 .4853 L .41061 .4844 L F
.30153 .48579 m .30246 .48338 L .30411 .48496 L 0 .027 .126 r
F
.30153 .48579 m .29988 .48421 L .30246 .48338 L F
.41637 .48638 m .41745 .48406 L .41901 .4855 L 0 .028 .128 r
F
.41637 .48638 m .41481 .48495 L .41745 .48406 L F
.53121 .48701 m .53245 .4847 L .5339 .48629 L 0 .03 .13 r
F
.53121 .48701 m .52976 .48542 L .53245 .4847 L F
.4232 .48609 m .42428 .48389 L .42583 .48533 L 0 .028 .127 r
F
.4232 .48609 m .42164 .48465 L .42428 .48389 L F
.62143 .48668 m .6228 .48429 L .62416 .4858 L 0 .029 .129 r
F
.62143 .48668 m .62006 .48518 L .6228 .48429 L F
.62826 .48631 m .62964 .48394 L .63099 .4854 L 0 .028 .128 r
F
.62826 .48631 m .6269 .48487 L .62964 .48394 L F
.77041 .48536 m .77199 .48296 L .77322 .48456 L 0 .026 .125 r
F
.77041 .48536 m .76918 .48378 L .77199 .48296 L F
.57632 .48689 m .57763 .48465 L .57903 .48614 L 0 .03 .13 r
F
.57632 .48689 m .57491 .48542 L .57763 .48465 L F
.49976 .48651 m .50095 .48431 L .50243 .48573 L 0 .029 .129 r
F
.49976 .48651 m .49828 .48507 L .50095 .48431 L F
.63509 .48595 m .63647 .48356 L .63783 .48505 L 0 .027 .127 r
F
.63509 .48595 m .63373 .48448 L .63647 .48356 L F
.67337 .48618 m .67481 .48381 L .67613 .48538 L 0 .028 .127 r
F
.67337 .48618 m .67205 .48461 L .67481 .48381 L F
.30834 .48569 m .30926 .48346 L .31092 .48493 L 0 .027 .126 r
F
.30834 .48569 m .30669 .48421 L .30926 .48346 L F
.35345 .48551 m .35444 .48323 L .35605 .48477 L F
.35345 .48551 m .35184 .48396 L .35444 .48323 L F
.72531 .48573 m .72682 .4833 L .7281 .48493 L F
.72531 .48573 m .72403 .48411 L .72682 .4833 L F
.43002 .48602 m .43111 .48373 L .43266 .48518 L 0 .028 .127 r
F
.43002 .48602 m .42847 .48457 L .43111 .48373 L F
.64192 .48583 m .64332 .4834 L .64467 .48502 L 0 .027 .127 r
F
.64192 .48583 m .64057 .4842 L .64332 .4834 L F
.68021 .48602 m .68165 .48352 L .68297 .48509 L 0 .028 .127 r
F
.68021 .48602 m .67889 .48445 L .68165 .48352 L F
.3849 .48623 m .38594 .48374 L .38752 .48539 L 0 .028 .128 r
F
.3849 .48623 m .38332 .48459 L .38594 .48374 L F
.45464 .487 m .45578 .48468 L .45729 .48631 L 0 .03 .13 r
F
.45464 .487 m .45312 .48538 L .45578 .48468 L F
.68704 .48572 m .68849 .48321 L .6898 .48478 L 0 .027 .126 r
F
.68704 .48572 m .68573 .48415 L .68849 .48321 L F
.31516 .48554 m .3161 .48315 L .31775 .48464 L F
.31516 .48554 m .31351 .48406 L .3161 .48315 L F
.60364 .48573 m .60499 .48353 L .60637 .48497 L 0 .027 .127 r
F
.60364 .48573 m .60226 .48429 L .60499 .48353 L F
.58315 .48687 m .58447 .48459 L .58587 .48609 L 0 .03 .13 r
F
.58315 .48687 m .58175 .48538 L .58447 .48459 L F
.53804 .48708 m .53929 .48487 L .54074 .48637 L 0 .031 .131 r
F
.53804 .48708 m .5366 .48559 L .53929 .48487 L F
.59681 .48615 m .59815 .48381 L .59953 .48522 L 0 .028 .128 r
F
.59681 .48615 m .59542 .48473 L .59815 .48381 L F
.32198 .48522 m .32293 .4829 L .32457 .48439 L 0 .026 .125 r
F
.32198 .48522 m .32034 .48374 L .32293 .4829 L F
.69387 .48545 m .69534 .48303 L .69665 .48463 L 0 .027 .126 r
F
.69387 .48545 m .69257 .48384 L .69534 .48303 L F
.58999 .48659 m .59131 .48422 L .5927 .48566 L 0 .029 .129 r
F
.58999 .48659 m .58859 .48515 L .59131 .48422 L F
.43684 .48585 m .43795 .48346 L .43948 .48501 L 0 .028 .127 r
F
.43684 .48585 m .4353 .48431 L .43795 .48346 L F
.50658 .48661 m .50779 .48433 L .50926 .48591 L 0 .029 .129 r
F
.50658 .48661 m .50511 .48502 L .50779 .48433 L F
.36026 .48549 m .36127 .48305 L .36287 .48461 L 0 .027 .126 r
F
.36026 .48549 m .35866 .48393 L .36127 .48305 L F
.73216 .48571 m .73368 .48316 L .73495 .48478 L F
.73216 .48571 m .73089 .48408 L .73368 .48316 L F
.39172 .48614 m .39277 .48368 L .39434 .4853 L 0 .028 .128 r
F
.39172 .48614 m .39014 .48452 L .39277 .48368 L F
.3288 .48504 m .32975 .48273 L .33139 .48423 L 0 .026 .125 r
F
.3288 .48504 m .32716 .48356 L .32975 .48273 L F
.739 .48543 m .74052 .48291 L .74179 .4845 L 0 .027 .126 r
F
.739 .48543 m .73774 .48385 L .74052 .48291 L F
.64876 .48582 m .65017 .4834 L .65151 .48499 L 0 .028 .127 r
F
.64876 .48582 m .64742 .48421 L .65017 .4834 L F
.74583 .48508 m .74737 .48265 L .74862 .48417 L 0 .026 .125 r
F
.74583 .48508 m .74458 .48357 L .74737 .48265 L F
.36709 .48527 m .36809 .48294 L .36969 .48447 L 0 .027 .126 r
F
.36709 .48527 m .36549 .48373 L .36809 .48294 L F
.46146 .48706 m .46261 .48452 L .46412 .48615 L 0 .03 .131 r
F
.46146 .48706 m .45995 .48543 L .46261 .48452 L F
.54487 .48707 m .54613 .48491 L .54757 .48635 L 0 .031 .131 r
F
.54487 .48707 m .54343 .48564 L .54613 .48491 L F
.70072 .48544 m .7022 .48306 L .7035 .48464 L 0 .027 .126 r
F
.70072 .48544 m .69942 .48385 L .7022 .48306 L F
.75267 .48487 m .75423 .48253 L .75547 .48405 L 0 .026 .125 r
F
.75267 .48487 m .75142 .48335 L .75423 .48253 L F
.61048 .48582 m .61184 .48346 L .61321 .48507 L 0 .028 .128 r
F
.61048 .48582 m .6091 .48422 L .61184 .48346 L F
.33561 .48494 m .33658 .48262 L .33821 .48415 L 0 .026 .125 r
F
.33561 .48494 m .33398 .48342 L .33658 .48262 L F
.46829 .48684 m .46944 .48442 L .47095 .48597 L 0 .03 .13 r
F
.46829 .48684 m .46678 .48525 L .46944 .48442 L F
.65561 .48572 m .65702 .48333 L .65836 .48488 L 0 .028 .127 r
F
.65561 .48572 m .65427 .48417 L .65702 .48333 L F
.44366 .48593 m .44478 .48357 L .4463 .48519 L 0 .028 .128 r
F
.44366 .48593 m .44213 .48429 L .44478 .48357 L F
.47512 .48651 m .47628 .48427 L .47778 .48568 L 0 .03 .13 r
F
.47512 .48651 m .47361 .48511 L .47628 .48427 L F
.5517 .48692 m .55297 .48458 L .5544 .48599 L 0 .031 .131 r
F
.5517 .48692 m .55027 .48549 L .55297 .48458 L F
.3739 .48525 m .37492 .48286 L .37651 .48446 L 0 .027 .126 r
F
.3739 .48525 m .37231 .48366 L .37492 .48286 L F
.51341 .48677 m .51463 .48427 L .51609 .48587 L 0 .03 .13 r
F
.51341 .48677 m .51194 .48518 L .51463 .48427 L F
.39853 .48622 m .39958 .48389 L .40115 .48552 L 0 .029 .129 r
F
.39853 .48622 m .39696 .4846 L .39958 .48389 L F
.55853 .48662 m .55981 .48417 L .56124 .4857 L 0 .03 .13 r
F
.55853 .48662 m .55711 .48506 L .55981 .48417 L F
.56536 .48629 m .56665 .48393 L .56807 .48543 L 0 .029 .129 r
F
.56536 .48629 m .56394 .48478 L .56665 .48393 L F
.66244 .48553 m .66387 .48317 L .6652 .4847 L 0 .028 .127 r
F
.66244 .48553 m .66111 .48402 L .66387 .48317 L F
.75952 .48478 m .76108 .48234 L .76232 .4839 L 0 .026 .125 r
F
.75952 .48478 m .75828 .48321 L .76108 .48234 L F
.48195 .48631 m .48312 .48407 L .48461 .48553 L 0 .03 .13 r
F
.48195 .48631 m .48045 .48488 L .48312 .48407 L F
.70757 .48536 m .70906 .48302 L .71035 .48454 L 0 .027 .127 r
F
.70757 .48536 m .70628 .48383 L .70906 .48302 L F
.52024 .48655 m .52147 .48406 L .52293 .48565 L 0 .03 .13 r
F
.52024 .48655 m .51878 .48496 L .52147 .48406 L F
.34243 .48486 m .34341 .48243 L .34503 .48399 L 0 .026 .125 r
F
.34243 .48486 m .3408 .48329 L .34341 .48243 L F
.2973 .48509 m .29822 .48258 L .29988 .48421 L 0 .027 .126 r
F
.2973 .48509 m .29564 .48347 L .29822 .48258 L F
.48877 .48609 m .48996 .48373 L .49145 .48521 L 0 .029 .129 r
F
.48877 .48609 m .48728 .48463 L .48996 .48373 L F
.71441 .48514 m .71591 .48278 L .71719 .48427 L 0 .027 .126 r
F
.71441 .48514 m .71313 .48368 L .71591 .48278 L F
.61732 .48593 m .61869 .48356 L .62006 .48518 L 0 .029 .129 r
F
.61732 .48593 m .61595 .48432 L .61869 .48356 L F
.76637 .48461 m .76794 .48219 L .76918 .48378 L 0 .026 .125 r
F
.76637 .48461 m .76513 .48303 L .76794 .48219 L F
.52707 .48632 m .52831 .48383 L .52976 .48542 L 0 .029 .129 r
F
.52707 .48632 m .52562 .48474 L .52831 .48383 L F
.5722 .48616 m .5735 .48392 L .57491 .48542 L 0 .03 .13 r
F
.5722 .48616 m .57078 .48467 L .5735 .48392 L F
.66928 .48542 m .67072 .48305 L .67205 .48461 L 0 .028 .127 r
F
.66928 .48542 m .66796 .48387 L .67072 .48305 L F
.40535 .4862 m .40641 .48379 L .40798 .4853 L 0 .029 .129 r
F
.40535 .4862 m .40378 .4847 L .40641 .48379 L F
.34925 .48469 m .35023 .48244 L .35184 .48396 L 0 .026 .125 r
F
.34925 .48469 m .34763 .48315 L .35023 .48244 L F
.41218 .48583 m .41325 .48351 L .41481 .48495 L 0 .029 .128 r
F
.41218 .48583 m .41061 .4844 L .41325 .48351 L F
.4956 .48584 m .49679 .48363 L .49828 .48507 L 0 .029 .129 r
F
.4956 .48584 m .49412 .48438 L .49679 .48363 L F
.72125 .48493 m .72276 .48256 L .72403 .48411 L 0 .027 .126 r
F
.72125 .48493 m .71997 .4834 L .72276 .48256 L F
.41901 .4855 m .42009 .4832 L .42164 .48465 L 0 .028 .128 r
F
.41901 .4855 m .41745 .48406 L .42009 .4832 L F
.45047 .48607 m .4516 .48378 L .45312 .48538 L 0 .029 .129 r
F
.45047 .48607 m .44895 .48447 L .4516 .48378 L F
.38071 .48533 m .38174 .48293 L .38332 .48459 L 0 .028 .127 r
F
.38071 .48533 m .37912 .4837 L .38174 .48293 L F
.30411 .48496 m .30503 .48263 L .30669 .48421 L 0 .027 .126 r
F
.30411 .48496 m .30246 .48338 L .30503 .48263 L F
.63099 .4854 m .63238 .483 L .63373 .48448 L 0 .028 .127 r
F
.63099 .4854 m .62964 .48394 L .63238 .483 L F
.62416 .4858 m .62553 .48335 L .6269 .48487 L 0 .029 .128 r
F
.62416 .4858 m .6228 .48429 L .62553 .48335 L F
.63783 .48505 m .63922 .48271 L .64057 .4842 L 0 .027 .126 r
F
.63783 .48505 m .63647 .48356 L .63922 .48271 L F
.77322 .48456 m .7748 .48215 L .77604 .48377 L 0 .026 .125 r
F
.77322 .48456 m .77199 .48296 L .7748 .48215 L F
.42583 .48533 m .42692 .48313 L .42847 .48457 L 0 .028 .128 r
F
.42583 .48533 m .42428 .48389 L .42692 .48313 L F
.5339 .48629 m .53515 .48398 L .5366 .48559 L 0 .03 .13 r
F
.5339 .48629 m .53245 .4847 L .53515 .48398 L F
.50243 .48573 m .50363 .48359 L .50511 .48502 L 0 .029 .129 r
F
.50243 .48573 m .50095 .48431 L .50363 .48359 L F
.57903 .48614 m .58035 .48389 L .58175 .48538 L 0 .03 .13 r
F
.57903 .48614 m .57763 .48465 L .58035 .48389 L F
.67613 .48538 m .67757 .48288 L .67889 .48445 L 0 .028 .127 r
F
.67613 .48538 m .67481 .48381 L .67757 .48288 L F
.68297 .48509 m .68442 .48259 L .68573 .48415 L 0 .027 .127 r
F
.68297 .48509 m .68165 .48352 L .68442 .48259 L F
.7281 .48493 m .72962 .48246 L .73089 .48408 L 0 .027 .126 r
F
.7281 .48493 m .72682 .4833 L .72962 .48246 L F
.31092 .48493 m .31185 .48258 L .31351 .48406 L 0 .027 .127 r
F
.31092 .48493 m .30926 .48346 L .31185 .48258 L F
.35605 .48477 m .35705 .48241 L .35866 .48393 L 0 .027 .126 r
F
.35605 .48477 m .35444 .48323 L .35705 .48241 L F
.6898 .48478 m .69126 .48227 L .69257 .48384 L F
.6898 .48478 m .68849 .48321 L .69126 .48227 L F
.43266 .48518 m .43376 .48284 L .4353 .48431 L 0 .028 .127 r
F
.43266 .48518 m .43111 .48373 L .43376 .48284 L F
.38752 .48539 m .38857 .48288 L .39014 .48452 L 0 .028 .128 r
F
.38752 .48539 m .38594 .48374 L .38857 .48288 L F
.31775 .48464 m .31869 .48225 L .32034 .48374 L 0 .027 .126 r
F
.31775 .48464 m .3161 .48315 L .31869 .48225 L F
.64467 .48502 m .64607 .48261 L .64742 .48421 L 0 .027 .127 r
F
.64467 .48502 m .64332 .4834 L .64607 .48261 L F
.59953 .48522 m .60087 .48289 L .60226 .48429 L 0 .028 .127 r
F
.59953 .48522 m .59815 .48381 L .60087 .48289 L F
.5927 .48566 m .59403 .4833 L .59542 .48473 L 0 .029 .129 r
F
.5927 .48566 m .59131 .48422 L .59403 .4833 L F
.58587 .48609 m .58719 .48365 L .58859 .48515 L 0 .03 .13 r
F
.58587 .48609 m .58447 .48459 L .58719 .48365 L F
.32457 .48439 m .32552 .48206 L .32716 .48356 L 0 .026 .125 r
F
.32457 .48439 m .32293 .4829 L .32552 .48206 L F
.73495 .48478 m .73647 .48223 L .73774 .48385 L 0 .027 .126 r
F
.73495 .48478 m .73368 .48316 L .73647 .48223 L F
.60637 .48497 m .60772 .48277 L .6091 .48422 L 0 .028 .127 r
F
.60637 .48497 m .60499 .48353 L .60772 .48277 L F
.45729 .48631 m .45843 .48381 L .45995 .48543 L 0 .03 .13 r
F
.45729 .48631 m .45578 .48468 L .45843 .48381 L F
.36287 .48461 m .36388 .48218 L .36549 .48373 L 0 .027 .126 r
F
.36287 .48461 m .36127 .48305 L .36388 .48218 L F
.43948 .48501 m .44059 .48275 L .44213 .48429 L 0 .028 .127 r
F
.43948 .48501 m .43795 .48346 L .44059 .48275 L F
.69665 .48463 m .69812 .48225 L .69942 .48385 L 0 .027 .126 r
F
.69665 .48463 m .69534 .48303 L .69812 .48225 L F
.54074 .48637 m .54199 .48413 L .54343 .48564 L 0 .031 .131 r
F
.54074 .48637 m .53929 .48487 L .54199 .48413 L F
.74179 .4845 m .74332 .48198 L .74458 .48357 L 0 .026 .125 r
F
.74179 .4845 m .74052 .48291 L .74332 .48198 L F
.39434 .4853 m .39539 .48297 L .39696 .4846 L 0 .028 .128 r
F
.39434 .4853 m .39277 .48368 L .39539 .48297 L F
.74862 .48417 m .75017 .48183 L .75142 .48335 L 0 .026 .125 r
F
.74862 .48417 m .74737 .48265 L .75017 .48183 L F
.50926 .48591 m .51047 .4836 L .51194 .48518 L 0 .03 .13 r
F
.50926 .48591 m .50779 .48433 L .51047 .4836 L F
.33139 .48423 m .33235 .48191 L .33398 .48342 L 0 .026 .125 r
F
.33139 .48423 m .32975 .48273 L .33235 .48191 L F
.65151 .48499 m .65293 .48259 L .65427 .48417 L 0 .028 .127 r
F
.65151 .48499 m .65017 .4834 L .65293 .48259 L F
.46412 .48615 m .46527 .48364 L .46678 .48525 L 0 .03 .13 r
F
.46412 .48615 m .46261 .48452 L .46527 .48364 L F
.36969 .48447 m .37071 .48216 L .37231 .48366 L 0 .027 .126 r
F
.36969 .48447 m .36809 .48294 L .37071 .48216 L F
.75547 .48405 m .75703 .4817 L .75828 .48321 L 0 .026 .125 r
F
.75547 .48405 m .75423 .48253 L .75703 .4817 L F
.54757 .48635 m .54884 .48406 L .55027 .48549 L 0 .031 .132 r
F
.54757 .48635 m .54613 .48491 L .54884 .48406 L F
.7035 .48464 m .70498 .48226 L .70628 .48383 L 0 .027 .127 r
F
.7035 .48464 m .7022 .48306 L .70498 .48226 L F
.47095 .48597 m .47211 .48358 L .47361 .48511 L 0 .03 .13 r
F
.47095 .48597 m .46944 .48442 L .47211 .48358 L F
.5544 .48599 m .55568 .48366 L .55711 .48506 L 0 .03 .131 r
F
.5544 .48599 m .55297 .48458 L .55568 .48366 L F
.61321 .48507 m .61457 .4827 L .61595 .48432 L 0 .028 .128 r
F
.61321 .48507 m .61184 .48346 L .61457 .4827 L F
.65836 .48488 m .65978 .48246 L .66111 .48402 L 0 .028 .127 r
F
.65836 .48488 m .65702 .48333 L .65978 .48246 L F
.33821 .48415 m .33918 .48175 L .3408 .48329 L 0 .026 .125 r
F
.33821 .48415 m .33658 .48262 L .33918 .48175 L F
.51609 .48587 m .51732 .48336 L .51878 .48496 L 0 .03 .13 r
F
.51609 .48587 m .51463 .48427 L .51732 .48336 L F
.47778 .48568 m .47895 .48344 L .48045 .48488 L F
.47778 .48568 m .47628 .48427 L .47895 .48344 L F
.29306 .48436 m .29398 .48185 L .29564 .48347 L 0 .027 .126 r
F
.29306 .48436 m .2914 .48275 L .29398 .48185 L F
.56124 .4857 m .56252 .48327 L .56394 .48478 L 0 .03 .13 r
F
.56124 .4857 m .55981 .48417 L .56252 .48327 L F
.4463 .48519 m .44742 .48287 L .44895 .48447 L 0 .029 .129 r
F
.4463 .48519 m .44478 .48357 L .44742 .48287 L F
.37651 .48446 m .37754 .48208 L .37912 .4837 L 0 .027 .126 r
F
.37651 .48446 m .37492 .48286 L .37754 .48208 L F
.76232 .4839 m .76389 .48148 L .76513 .48303 L 0 .026 .125 r
F
.76232 .4839 m .76108 .48234 L .76389 .48148 L F
.56807 .48543 m .56937 .48316 L .57078 .48467 L 0 .029 .129 r
F
.56807 .48543 m .56665 .48393 L .56937 .48316 L F
.52293 .48565 m .52416 .48317 L .52562 .48474 L 0 .03 .13 r
F
.52293 .48565 m .52147 .48406 L .52416 .48317 L F
.6652 .4847 m .66663 .48232 L .66796 .48387 L 0 .028 .127 r
F
.6652 .4847 m .66387 .48317 L .66663 .48232 L F
.71035 .48454 m .71184 .48216 L .71313 .48368 L 0 .027 .127 r
F
.71035 .48454 m .70906 .48302 L .71184 .48216 L F
.34503 .48399 m .34601 .48161 L .34763 .48315 L 0 .026 .125 r
F
.34503 .48399 m .34341 .48243 L .34601 .48161 L F
.40115 .48552 m .40221 .48307 L .40378 .4847 L 0 .029 .129 r
F
.40115 .48552 m .39958 .48389 L .40221 .48307 L F
.48461 .48553 m .48579 .48315 L .48728 .48463 L 0 .03 .13 r
F
.48461 .48553 m .48312 .48407 L .48579 .48315 L F
.29988 .48421 m .3008 .48174 L .30246 .48338 L 0 .027 .126 r
F
.29988 .48421 m .29822 .48258 L .3008 .48174 L F
.49145 .48521 m .49263 .48289 L .49412 .48438 L 0 .029 .129 r
F
.49145 .48521 m .48996 .48373 L .49263 .48289 L F
.71719 .48427 m .71869 .48188 L .71997 .4834 L 0 .027 .126 r
F
.71719 .48427 m .71591 .48278 L .71869 .48188 L F
.52976 .48542 m .531 .48309 L .53245 .4847 L 0 .03 .13 r
F
.52976 .48542 m .52831 .48383 L .531 .48309 L F
.76918 .48378 m .77075 .48135 L .77199 .48296 L 0 .026 .125 r
F
.76918 .48378 m .76794 .48219 L .77075 .48135 L F
.40798 .4853 m .40905 .48288 L .41061 .4844 L 0 .029 .129 r
F
.40798 .4853 m .40641 .48379 L .40905 .48288 L F
.41481 .48495 m .41589 .48262 L .41745 .48406 L 0 .029 .128 r
F
.41481 .48495 m .41325 .48351 L .41589 .48262 L F
.62006 .48518 m .62143 .48267 L .6228 .48429 L 0 .029 .129 r
F
.62006 .48518 m .61869 .48356 L .62143 .48267 L F
.67205 .48461 m .67349 .48222 L .67481 .48381 L 0 .028 .127 r
F
.67205 .48461 m .67072 .48305 L .67349 .48222 L F
.42164 .48465 m .42273 .48242 L .42428 .48389 L 0 .028 .128 r
F
.42164 .48465 m .42009 .4832 L .42273 .48242 L F
.57491 .48542 m .57622 .48314 L .57763 .48465 L 0 .03 .13 r
F
.57491 .48542 m .5735 .48392 L .57622 .48314 L F
.63373 .48448 m .63512 .48207 L .63647 .48356 L 0 .028 .127 r
F
.63373 .48448 m .63238 .483 L .63512 .48207 L F
.6269 .48487 m .62827 .48241 L .62964 .48394 L 0 .028 .128 r
F
.6269 .48487 m .62553 .48335 L .62827 .48241 L F
.72403 .48411 m .72555 .48172 L .72682 .4833 L 0 .027 .126 r
F
.72403 .48411 m .72276 .48256 L .72555 .48172 L F
.49828 .48507 m .49947 .48288 L .50095 .48431 L 0 .029 .129 r
F
.49828 .48507 m .49679 .48363 L .49947 .48288 L F
.35184 .48396 m .35283 .48172 L .35444 .48323 L 0 .027 .126 r
F
.35184 .48396 m .35023 .48244 L .35283 .48172 L F
.64057 .4842 m .64197 .48193 L .64332 .4834 L 0 .027 .127 r
F
.64057 .4842 m .63922 .48271 L .64197 .48193 L F
.38332 .48459 m .38436 .48209 L .38594 .48374 L 0 .028 .127 r
F
.38332 .48459 m .38174 .48293 L .38436 .48209 L F
.30669 .48421 m .30761 .48188 L .30926 .48346 L 0 .027 .127 r
F
.30669 .48421 m .30503 .48263 L .30761 .48188 L F
.45312 .48538 m .45426 .48309 L .45578 .48468 L 0 .03 .13 r
F
.45312 .48538 m .4516 .48378 L .45426 .48309 L F
.67889 .48445 m .68034 .48196 L .68165 .48352 L 0 .028 .127 r
F
.67889 .48445 m .67757 .48288 L .68034 .48196 L F
.77604 .48377 m .77762 .48135 L .77886 .48297 L 0 .026 .125 r
F
.77604 .48377 m .7748 .48215 L .77762 .48135 L F
.68573 .48415 m .68718 .48165 L .68849 .48321 L 0 .027 .126 r
F
.68573 .48415 m .68442 .48259 L .68718 .48165 L F
.42847 .48457 m .42957 .48227 L .43111 .48373 L 0 .028 .128 r
F
.42847 .48457 m .42692 .48313 L .42957 .48227 L F
.69257 .48384 m .69404 .48146 L .69534 .48303 L 0 .027 .126 r
F
.69257 .48384 m .69126 .48227 L .69404 .48146 L F
.58175 .48538 m .58307 .48308 L .58447 .48459 L 0 .03 .13 r
F
.58175 .48538 m .58035 .48389 L .58307 .48308 L F
.31351 .48406 m .31444 .48167 L .3161 .48315 L 0 .027 .126 r
F
.31351 .48406 m .31185 .48258 L .31444 .48167 L F
.50511 .48502 m .50632 .48289 L .50779 .48433 L 0 .03 .13 r
F
.50511 .48502 m .50363 .48359 L .50632 .48289 L F
.5366 .48559 m .53785 .48325 L .53929 .48487 L 0 .031 .131 r
F
.5366 .48559 m .53515 .48398 L .53785 .48325 L F
.73089 .48408 m .7324 .48154 L .73368 .48316 L 0 .027 .126 r
F
.73089 .48408 m .72962 .48246 L .7324 .48154 L F
.60226 .48429 m .60361 .48212 L .60499 .48353 L 0 .028 .128 r
F
.60226 .48429 m .60087 .48289 L .60361 .48212 L F
.32034 .48374 m .32128 .4814 L .32293 .4829 L 0 .027 .126 r
F
.32034 .48374 m .31869 .48225 L .32128 .4814 L F
.4353 .48431 m .43641 .48198 L .43795 .48346 L 0 .028 .127 r
F
.4353 .48431 m .43376 .48284 L .43641 .48198 L F
.35866 .48393 m .35966 .48153 L .36127 .48305 L 0 .027 .126 r
F
.35866 .48393 m .35705 .48241 L .35966 .48153 L F
.39014 .48452 m .39119 .48205 L .39277 .48368 L 0 .028 .128 r
F
.39014 .48452 m .38857 .48288 L .39119 .48205 L F
.59542 .48473 m .59676 .48238 L .59815 .48381 L 0 .029 .128 r
F
.59542 .48473 m .59403 .4833 L .59676 .48238 L F
.58859 .48515 m .58991 .48272 L .59131 .48422 L 0 .03 .13 r
F
.58859 .48515 m .58719 .48365 L .58991 .48272 L F
.64742 .48421 m .64882 .48181 L .65017 .4834 L 0 .028 .127 r
F
.64742 .48421 m .64607 .48261 L .64882 .48181 L F
.73774 .48385 m .73926 .48129 L .74052 .48291 L 0 .026 .126 r
F
.73774 .48385 m .73647 .48223 L .73926 .48129 L F
.45995 .48543 m .4611 .48292 L .46261 .48452 L 0 .03 .13 r
F
.45995 .48543 m .45843 .48381 L .4611 .48292 L F
.36549 .48373 m .36649 .48142 L .36809 .48294 L 0 .027 .126 r
F
.36549 .48373 m .36388 .48218 L .36649 .48142 L F
.32716 .48356 m .32811 .48122 L .32975 .48273 L 0 .026 .125 r
F
.32716 .48356 m .32552 .48206 L .32811 .48122 L F
.74458 .48357 m .74611 .48105 L .74737 .48265 L F
.74458 .48357 m .74332 .48198 L .74611 .48105 L F
.6091 .48422 m .61046 .482 L .61184 .48346 L 0 .028 .128 r
F
.6091 .48422 m .60772 .48277 L .61046 .482 L F
.69942 .48385 m .7009 .48147 L .7022 .48306 L 0 .027 .126 r
F
.69942 .48385 m .69812 .48225 L .7009 .48147 L F
.44213 .48429 m .44324 .48204 L .44478 .48357 L 0 .028 .128 r
F
.44213 .48429 m .44059 .48275 L .44324 .48204 L F
.75142 .48335 m .75298 .48102 L .75423 .48253 L 0 .026 .125 r
F
.75142 .48335 m .75017 .48183 L .75298 .48102 L F
.46678 .48525 m .46794 .48284 L .46944 .48442 L 0 .03 .13 r
F
.46678 .48525 m .46527 .48364 L .46794 .48284 L F
.54343 .48564 m .54469 .48339 L .54613 .48491 L 0 .031 .132 r
F
.54343 .48564 m .54199 .48413 L .54469 .48339 L F
.65427 .48417 m .65568 .48176 L .65702 .48333 L 0 .028 .127 r
F
.65427 .48417 m .65293 .48259 L .65568 .48176 L F
.33398 .48342 m .33495 .48109 L .33658 .48262 L 0 .026 .125 r
F
.33398 .48342 m .33235 .48191 L .33495 .48109 L F
.39696 .4846 m .39802 .48226 L .39958 .48389 L 0 .029 .129 r
F
.39696 .4846 m .39539 .48297 L .39802 .48226 L F
.37231 .48366 m .37332 .48137 L .37492 .48286 L 0 .027 .126 r
F
.37231 .48366 m .37071 .48216 L .37332 .48137 L F
.51194 .48518 m .51316 .48269 L .51463 .48427 L 0 .03 .13 r
F
.51194 .48518 m .51047 .4836 L .51316 .48269 L F
.55711 .48506 m .55839 .48279 L .55981 .48417 L F
.55711 .48506 m .55568 .48366 L .55839 .48279 L F
.75828 .48321 m .75984 .48084 L .76108 .48234 L 0 .026 .125 r
F
.75828 .48321 m .75703 .4817 L .75984 .48084 L F
.47361 .48511 m .47478 .48274 L .47628 .48427 L 0 .03 .13 r
F
.47361 .48511 m .47211 .48358 L .47478 .48274 L F
.55027 .48549 m .55154 .48316 L .55297 .48458 L 0 .031 .131 r
F
.55027 .48549 m .54884 .48406 L .55154 .48316 L F
.51878 .48496 m .52 .48248 L .52147 .48406 L 0 .03 .13 r
F
.51878 .48496 m .51732 .48336 L .52 .48248 L F
.56394 .48478 m .56523 .48243 L .56665 .48393 L F
.56394 .48478 m .56252 .48327 L .56523 .48243 L F
.70628 .48383 m .70777 .48146 L .70906 .48302 L 0 .027 .127 r
F
.70628 .48383 m .70498 .48226 L .70777 .48146 L F
.66111 .48402 m .66254 .48158 L .66387 .48317 L 0 .028 .127 r
F
.66111 .48402 m .65978 .48246 L .66254 .48158 L F
.29564 .48347 m .29656 .48095 L .29822 .48258 L 0 .026 .125 r
F
.29564 .48347 m .29398 .48185 L .29656 .48095 L F
.3408 .48329 m .34178 .48087 L .34341 .48243 L F
.3408 .48329 m .33918 .48175 L .34178 .48087 L F
.48045 .48488 m .48162 .48261 L .48312 .48407 L 0 .03 .13 r
F
.48045 .48488 m .47895 .48344 L .48162 .48261 L F
.61595 .48432 m .61731 .48194 L .61869 .48356 L 0 .029 .128 r
F
.61595 .48432 m .61457 .4827 L .61731 .48194 L F
.76513 .48303 m .7667 .48062 L .76794 .48219 L 0 .026 .125 r
F
.76513 .48303 m .76389 .48148 L .7667 .48062 L F
.52562 .48474 m .52685 .48228 L .52831 .48383 L 0 .029 .129 r
F
.52562 .48474 m .52416 .48317 L .52685 .48228 L F
.71313 .48368 m .71462 .48124 L .71591 .48278 L 0 .027 .127 r
F
.71313 .48368 m .71184 .48216 L .71462 .48124 L F
.66796 .48387 m .66939 .48147 L .67072 .48305 L 0 .028 .127 r
F
.66796 .48387 m .66663 .48232 L .66939 .48147 L F
.48728 .48463 m .48847 .48222 L .48996 .48373 L 0 .029 .129 r
F
.48728 .48463 m .48579 .48315 L .48847 .48222 L F
.37912 .4837 m .38015 .4813 L .38174 .48293 L 0 .027 .127 r
F
.37912 .4837 m .37754 .48208 L .38015 .4813 L F
.44895 .48447 m .45008 .48218 L .4516 .48378 L 0 .029 .129 r
F
.44895 .48447 m .44742 .48287 L .45008 .48218 L F
.34763 .48315 m .34861 .48091 L .35023 .48244 L 0 .026 .126 r
F
.34763 .48315 m .34601 .48161 L .34861 .48091 L F
.57078 .48467 m .57209 .4824 L .5735 .48392 L 0 .03 .13 r
F
.57078 .48467 m .56937 .48316 L .57209 .4824 L F
.40378 .4847 m .40485 .48216 L .40641 .48379 L 0 .029 .129 r
F
.40378 .4847 m .40221 .48307 L .40485 .48216 L F
.30246 .48338 m .30338 .481 L .30503 .48263 L 0 .027 .126 r
F
.30246 .48338 m .3008 .48174 L .30338 .481 L F
.71997 .4834 m .72148 .48101 L .72276 .48256 L F
.71997 .4834 m .71869 .48188 L .72148 .48101 L F
.49412 .48438 m .49531 .48215 L .49679 .48363 L 0 .029 .129 r
F
.49412 .48438 m .49263 .48289 L .49531 .48215 L F
.41061 .4844 m .41169 .482 L .41325 .48351 L F
.41061 .4844 m .40905 .48288 L .41169 .482 L F
.41745 .48406 m .41853 .48175 L .42009 .4832 L 0 .028 .128 r
F
.41745 .48406 m .41589 .48262 L .41853 .48175 L F
.77199 .48296 m .77357 .48053 L .7748 .48215 L 0 .026 .125 r
F
.77199 .48296 m .77075 .48135 L .77357 .48053 L F
.6228 .48429 m .62416 .48173 L .62553 .48335 L 0 .029 .128 r
F
.6228 .48429 m .62143 .48267 L .62416 .48173 L F
.53245 .4847 m .5337 .48237 L .53515 .48398 L 0 .03 .13 r
F
.53245 .4847 m .531 .48309 L .5337 .48237 L F
.62964 .48394 m .63101 .48147 L .63238 .483 L 0 .028 .128 r
F
.62964 .48394 m .62827 .48241 L .63101 .48147 L F
.63647 .48356 m .63787 .48122 L .63922 .48271 L 0 .027 .127 r
F
.63647 .48356 m .63512 .48207 L .63787 .48122 L F
.67481 .48381 m .67625 .48132 L .67757 .48288 L 0 .028 .127 r
F
.67481 .48381 m .67349 .48222 L .67625 .48132 L F
.72682 .4833 m .72834 .48086 L .72962 .48246 L 0 .027 .126 r
F
.72682 .4833 m .72555 .48172 L .72834 .48086 L F
.42428 .48389 m .42537 .48164 L .42692 .48313 L 0 .028 .128 r
F
.42428 .48389 m .42273 .48242 L .42537 .48164 L F
.57763 .48465 m .57894 .48235 L .58035 .48389 L 0 .03 .13 r
F
.57763 .48465 m .57622 .48314 L .57894 .48235 L F
.68165 .48352 m .6831 .48103 L .68442 .48259 L 0 .027 .127 r
F
.68165 .48352 m .68034 .48196 L .6831 .48103 L F
.50095 .48431 m .50215 .48216 L .50363 .48359 L 0 .03 .13 r
F
.50095 .48431 m .49947 .48288 L .50215 .48216 L F
.38594 .48374 m .38699 .48124 L .38857 .48288 L 0 .028 .127 r
F
.38594 .48374 m .38436 .48209 L .38699 .48124 L F
.68849 .48321 m .68995 .4807 L .69126 .48227 L 0 .027 .126 r
F
.68849 .48321 m .68718 .48165 L .68995 .4807 L F
.64332 .4834 m .64472 .48115 L .64607 .48261 L 0 .027 .127 r
F
.64332 .4834 m .64197 .48193 L .64472 .48115 L F
.35444 .48323 m .35543 .4809 L .35705 .48241 L 0 .027 .126 r
F
.35444 .48323 m .35283 .48172 L .35543 .4809 L F
.30926 .48346 m .3102 .481 L .31185 .48258 L 0 .027 .127 r
F
.30926 .48346 m .30761 .48188 L .3102 .481 L F
.3161 .48315 m .31704 .48076 L .31869 .48225 L 0 .027 .126 r
F
.3161 .48315 m .31444 .48167 L .31704 .48076 L F
.73368 .48316 m .7352 .48061 L .73647 .48223 L F
.73368 .48316 m .7324 .48154 L .7352 .48061 L F
.43111 .48373 m .43222 .48137 L .43376 .48284 L 0 .028 .128 r
F
.43111 .48373 m .42957 .48227 L .43222 .48137 L F
.77886 .48297 m .78044 .48056 L .78168 .48218 L 0 .026 .126 r
F
.77886 .48297 m .77762 .48135 L .78044 .48056 L F
.45578 .48468 m .45691 .48224 L .45843 .48381 L 0 .03 .13 r
F
.45578 .48468 m .45426 .48309 L .45691 .48224 L F
.69534 .48303 m .69682 .48067 L .69812 .48225 L 0 .027 .126 r
F
.69534 .48303 m .69404 .48146 L .69682 .48067 L F
.59815 .48381 m .59949 .48147 L .60087 .48289 L 0 .028 .128 r
F
.59815 .48381 m .59676 .48238 L .59949 .48147 L F
.36127 .48305 m .36228 .48065 L .36388 .48218 L 0 .027 .126 r
F
.36127 .48305 m .35966 .48153 L .36228 .48065 L F
.58447 .48459 m .58579 .48215 L .58719 .48365 L 0 .03 .13 r
F
.58447 .48459 m .58307 .48308 L .58579 .48215 L F
.59131 .48422 m .59264 .4818 L .59403 .4833 L 0 .029 .129 r
F
.59131 .48422 m .58991 .48272 L .59264 .4818 L F
.43795 .48346 m .43906 .48126 L .44059 .48275 L 0 .028 .128 r
F
.43795 .48346 m .43641 .48198 L .43906 .48126 L F
.32293 .4829 m .32388 .48054 L .32552 .48206 L 0 .027 .126 r
F
.32293 .4829 m .32128 .4814 L .32388 .48054 L F
.74052 .48291 m .74205 .48036 L .74332 .48198 L 0 .026 .125 r
F
.74052 .48291 m .73926 .48129 L .74205 .48036 L F
.39277 .48368 m .39382 .48134 L .39539 .48297 L 0 .028 .128 r
F
.39277 .48368 m .39119 .48205 L .39382 .48134 L F
.60499 .48353 m .60634 .48135 L .60772 .48277 L F
.60499 .48353 m .60361 .48212 L .60634 .48135 L F
.53929 .48487 m .54055 .48249 L .54199 .48413 L 0 .031 .131 r
F
.53929 .48487 m .53785 .48325 L .54055 .48249 L F
.50779 .48433 m .509 .48216 L .51047 .4836 L 0 .03 .13 r
F
.50779 .48433 m .50632 .48289 L .509 .48216 L F
.46261 .48452 m .46376 .48205 L .46527 .48364 L F
.46261 .48452 m .4611 .48292 L .46376 .48205 L F
.65017 .4834 m .65158 .48101 L .65293 .48259 L 0 .028 .127 r
F
.65017 .4834 m .64882 .48181 L .65158 .48101 L F
.74737 .48265 m .74892 .48024 L .75017 .48183 L 0 .026 .125 r
F
.74737 .48265 m .74611 .48105 L .74892 .48024 L F
.32975 .48273 m .33071 .48038 L .33235 .48191 L F
.32975 .48273 m .32811 .48122 L .33071 .48038 L F
.36809 .48294 m .36911 .48066 L .37071 .48216 L 0 .027 .126 r
F
.36809 .48294 m .36649 .48142 L .36911 .48066 L F
.7022 .48306 m .70369 .48068 L .70498 .48226 L 0 .027 .127 r
F
.7022 .48306 m .7009 .48147 L .70369 .48068 L F
.61184 .48346 m .6132 .48124 L .61457 .4827 L 0 .028 .128 r
F
.61184 .48346 m .61046 .482 L .6132 .48124 L F
.46944 .48442 m .4706 .48203 L .47211 .48358 L 0 .03 .13 r
F
.46944 .48442 m .46794 .48284 L .4706 .48203 L F
.75423 .48253 m .75579 .48018 L .75703 .4817 L 0 .026 .125 r
F
.75423 .48253 m .75298 .48102 L .75579 .48018 L F
.51463 .48427 m .51585 .48178 L .51732 .48336 L 0 .03 .13 r
F
.51463 .48427 m .51316 .48269 L .51585 .48178 L F
.2914 .48275 m .29231 .48021 L .29398 .48185 L 0 .026 .125 r
F
.2914 .48275 m .28973 .48112 L .29231 .48021 L F
.65702 .48333 m .65844 .48086 L .65978 .48246 L 0 .028 .127 r
F
.65702 .48333 m .65568 .48176 L .65844 .48086 L F
.33658 .48262 m .33755 .4802 L .33918 .48175 L 0 .026 .125 r
F
.33658 .48262 m .33495 .48109 L .33755 .4802 L F
.44478 .48357 m .44589 .48133 L .44742 .48287 L 0 .029 .128 r
F
.44478 .48357 m .44324 .48204 L .44589 .48133 L F
.54613 .48491 m .5474 .48255 L .54884 .48406 L 0 .032 .132 r
F
.54613 .48491 m .54469 .48339 L .5474 .48255 L F
.55981 .48417 m .5611 .48192 L .56252 .48327 L 0 .03 .13 r
F
.55981 .48417 m .55839 .48279 L .5611 .48192 L F
.37492 .48286 m .37594 .48059 L .37754 .48208 L 0 .027 .126 r
F
.37492 .48286 m .37332 .48137 L .37594 .48059 L F
.55297 .48458 m .55425 .48227 L .55568 .48366 L 0 .031 .131 r
F
.55297 .48458 m .55154 .48316 L .55425 .48227 L F
.76108 .48234 m .76265 .47998 L .76389 .48148 L 0 .026 .125 r
F
.76108 .48234 m .75984 .48084 L .76265 .47998 L F
.52147 .48406 m .5227 .48161 L .52416 .48317 L 0 .03 .13 r
F
.52147 .48406 m .52 .48248 L .5227 .48161 L F
.47628 .48427 m .47745 .48191 L .47895 .48344 L F
.47628 .48427 m .47478 .48274 L .47745 .48191 L F
.39958 .48389 m .40065 .48143 L .40221 .48307 L 0 .029 .129 r
F
.39958 .48389 m .39802 .48226 L .40065 .48143 L F
.29822 .48258 m .29914 .48011 L .3008 .48174 L 0 .026 .125 r
F
.29822 .48258 m .29656 .48095 L .29914 .48011 L F
.66387 .48317 m .6653 .48071 L .66663 .48232 L 0 .028 .127 r
F
.66387 .48317 m .66254 .48158 L .6653 .48071 L F
.56665 .48393 m .56795 .48165 L .56937 .48316 L 0 .03 .13 r
F
.56665 .48393 m .56523 .48243 L .56795 .48165 L F
.34341 .48243 m .34439 .48004 L .34601 .48161 L 0 .026 .125 r
F
.34341 .48243 m .34178 .48087 L .34439 .48004 L F
.70906 .48302 m .71055 .48059 L .71184 .48216 L 0 .027 .127 r
F
.70906 .48302 m .70777 .48146 L .71055 .48059 L F
.52831 .48383 m .52955 .48154 L .531 .48309 L 0 .029 .129 r
F
.52831 .48383 m .52685 .48228 L .52955 .48154 L F
.48312 .48407 m .48429 .48166 L .48579 .48315 L 0 .03 .13 r
F
.48312 .48407 m .48162 .48261 L .48429 .48166 L F
.76794 .48219 m .76951 .47977 L .77075 .48135 L 0 .026 .125 r
F
.76794 .48219 m .7667 .48062 L .76951 .47977 L F
.71591 .48278 m .71741 .48032 L .71869 .48188 L 0 .027 .126 r
F
.71591 .48278 m .71462 .48124 L .71741 .48032 L F
.48996 .48373 m .49114 .48137 L .49263 .48289 L 0 .029 .129 r
F
.48996 .48373 m .48847 .48222 L .49114 .48137 L F
.61869 .48356 m .62005 .48105 L .62143 .48267 L 0 .029 .128 r
F
.61869 .48356 m .61731 .48194 L .62005 .48105 L F
.40641 .48379 m .40749 .48125 L .40905 .48288 L 0 .029 .129 r
F
.40641 .48379 m .40485 .48216 L .40749 .48125 L F
.67072 .48305 m .67216 .48063 L .67349 .48222 L 0 .028 .127 r
F
.67072 .48305 m .66939 .48147 L .67216 .48063 L F
.38174 .48293 m .38278 .48046 L .38436 .48209 L 0 .027 .127 r
F
.38174 .48293 m .38015 .4813 L .38278 .48046 L F
.41325 .48351 m .41433 .48112 L .41589 .48262 L 0 .029 .129 r
F
.41325 .48351 m .41169 .482 L .41433 .48112 L F
.72276 .48256 m .72427 .48014 L .72555 .48172 L 0 .027 .126 r
F
.72276 .48256 m .72148 .48101 L .72427 .48014 L F
.5735 .48392 m .5748 .48159 L .57622 .48314 L 0 .03 .13 r
F
.5735 .48392 m .57209 .4824 L .5748 .48159 L F
.62553 .48335 m .6269 .48079 L .62827 .48241 L 0 .028 .128 r
F
.62553 .48335 m .62416 .48173 L .6269 .48079 L F
.63238 .483 m .63376 .48053 L .63512 .48207 L 0 .028 .127 r
F
.63238 .483 m .63101 .48147 L .63376 .48053 L F
.30503 .48263 m .30596 .48025 L .30761 .48188 L 0 .027 .126 r
F
.30503 .48263 m .30338 .481 L .30596 .48025 L F
.35023 .48244 m .35121 .48021 L .35283 .48172 L F
.35023 .48244 m .34861 .48091 L .35121 .48021 L F
.42009 .4832 m .42117 .48095 L .42273 .48242 L 0 .029 .128 r
F
.42009 .4832 m .41853 .48175 L .42117 .48095 L F
.4516 .48378 m .45273 .48149 L .45426 .48309 L 0 .03 .13 r
F
.4516 .48378 m .45008 .48218 L .45273 .48149 L F
.49679 .48363 m .49799 .4814 L .49947 .48288 L F
.49679 .48363 m .49531 .48215 L .49799 .4814 L F
.67757 .48288 m .67902 .48041 L .68034 .48196 L 0 .028 .127 r
F
.67757 .48288 m .67625 .48132 L .67902 .48041 L F
.63922 .48271 m .64062 .48045 L .64197 .48193 L F
.63922 .48271 m .63787 .48122 L .64062 .48045 L F
.7748 .48215 m .77639 .47973 L .77762 .48135 L 0 .026 .125 r
F
.7748 .48215 m .77357 .48053 L .77639 .47973 L F
.68442 .48259 m .68587 .48009 L .68718 .48165 L 0 .027 .126 r
F
.68442 .48259 m .6831 .48103 L .68587 .48009 L F
.72962 .48246 m .73113 .47995 L .7324 .48154 L F
.72962 .48246 m .72834 .48086 L .73113 .47995 L F
.69126 .48227 m .69273 .47988 L .69404 .48146 L F
.69126 .48227 m .68995 .4807 L .69273 .47988 L F
.53515 .48398 m .5364 .48163 L .53785 .48325 L 0 .03 .131 r
F
.53515 .48398 m .5337 .48237 L .5364 .48163 L F
.38857 .48288 m .38961 .48041 L .39119 .48205 L 0 .028 .127 r
F
.38857 .48288 m .38699 .48124 L .38961 .48041 L F
.58035 .48389 m .58166 .48154 L .58307 .48308 L 0 .03 .13 r
F
.58035 .48389 m .57894 .48235 L .58166 .48154 L F
.42692 .48313 m .42802 .48075 L .42957 .48227 L 0 .029 .128 r
F
.42692 .48313 m .42537 .48164 L .42802 .48075 L F
.31185 .48258 m .31279 .48009 L .31444 .48167 L 0 .027 .126 r
F
.31185 .48258 m .3102 .481 L .31279 .48009 L F
.35705 .48241 m .35805 .48002 L .35966 .48153 L F
.35705 .48241 m .35543 .4809 L .35805 .48002 L F
.73647 .48223 m .73799 .47968 L .73926 .48129 L 0 .026 .125 r
F
.73647 .48223 m .7352 .48061 L .73799 .47968 L F
.64607 .48261 m .64748 .48036 L .64882 .48181 L 0 .028 .127 r
F
.64607 .48261 m .64472 .48115 L .64748 .48036 L F
.31869 .48225 m .31963 .47989 L .32128 .4814 L 0 .027 .126 r
F
.31869 .48225 m .31704 .48076 L .31963 .47989 L F
.50363 .48359 m .50484 .48145 L .50632 .48289 L 0 .03 .13 r
F
.50363 .48359 m .50215 .48216 L .50484 .48145 L F
.43376 .48284 m .43487 .48049 L .43641 .48198 L 0 .028 .128 r
F
.43376 .48284 m .43222 .48137 L .43487 .48049 L F
.45843 .48381 m .45958 .48138 L .4611 .48292 L 0 .03 .13 r
F
.45843 .48381 m .45691 .48224 L .45958 .48138 L F
.60087 .48289 m .60222 .48069 L .60361 .48212 L 0 .028 .128 r
F
.60087 .48289 m .59949 .48147 L .60222 .48069 L F
.58719 .48365 m .58851 .48122 L .58991 .48272 L 0 .03 .13 r
F
.58719 .48365 m .58579 .48215 L .58851 .48122 L F
.59403 .4833 m .59536 .4809 L .59676 .48238 L 0 .029 .129 r
F
.59403 .4833 m .59264 .4818 L .59536 .4809 L F
.74332 .48198 m .74485 .47943 L .74611 .48105 L 0 .026 .125 r
F
.74332 .48198 m .74205 .48036 L .74485 .47943 L F
.36388 .48218 m .36489 .47991 L .36649 .48142 L 0 .027 .126 r
F
.36388 .48218 m .36228 .48065 L .36489 .47991 L F
.78168 .48218 m .78326 .47967 L .78449 .48129 L 0 .026 .126 r
F
.78168 .48218 m .78044 .48056 L .78326 .47967 L F
.69812 .48225 m .6996 .47989 L .7009 .48147 L 0 .027 .126 r
F
.69812 .48225 m .69682 .48067 L .6996 .47989 L F
.32552 .48206 m .32647 .47969 L .32811 .48122 L F
.32552 .48206 m .32388 .48054 L .32647 .47969 L F
.46527 .48364 m .46642 .48128 L .46794 .48284 L 0 .03 .13 r
F
.46527 .48364 m .46376 .48205 L .46642 .48128 L F
.44059 .48275 m .44171 .48054 L .44324 .48204 L 0 .028 .128 r
F
.44059 .48275 m .43906 .48126 L .44171 .48054 L F
.60772 .48277 m .60908 .48058 L .61046 .482 L 0 .029 .128 r
F
.60772 .48277 m .60634 .48135 L .60908 .48058 L F
.65293 .48259 m .65434 .48019 L .65568 .48176 L 0 .028 .127 r
F
.65293 .48259 m .65158 .48101 L .65434 .48019 L F
.39539 .48297 m .39644 .48064 L .39802 .48226 L 0 .029 .129 r
F
.39539 .48297 m .39382 .48134 L .39644 .48064 L F
.75017 .48183 m .75173 .47943 L .75298 .48102 L 0 .026 .125 r
F
.75017 .48183 m .74892 .48024 L .75173 .47943 L F
.54199 .48413 m .54325 .48173 L .54469 .48339 L 0 .031 .132 r
F
.54199 .48413 m .54055 .48249 L .54325 .48173 L F
.51047 .4836 m .51169 .48124 L .51316 .48269 L 0 .03 .13 r
F
.51047 .4836 m .509 .48216 L .51169 .48124 L F
.33235 .48191 m .33331 .47954 L .33495 .48109 L 0 .026 .126 r
F
.33235 .48191 m .33071 .48038 L .33331 .47954 L F
.37071 .48216 m .37172 .47988 L .37332 .48137 L 0 .027 .127 r
F
.37071 .48216 m .36911 .48066 L .37172 .47988 L F
.51732 .48336 m .51854 .48091 L .52 .48248 L 0 .03 .13 r
F
.51732 .48336 m .51585 .48178 L .51854 .48091 L F
.29398 .48185 m .2949 .47931 L .29656 .48095 L 0 .026 .125 r
F
.29398 .48185 m .29231 .48021 L .2949 .47931 L F
.47211 .48358 m .47327 .4812 L .47478 .48274 L 0 .03 .13 r
F
.47211 .48358 m .4706 .48203 L .47327 .4812 L F
.70498 .48226 m .70647 .47989 L .70777 .48146 L 0 .027 .127 r
F
.70498 .48226 m .70369 .48068 L .70647 .47989 L F
.75703 .4817 m .7586 .47933 L .75984 .48084 L 0 .026 .125 r
F
.75703 .4817 m .75579 .48018 L .7586 .47933 L F
.65978 .48246 m .6612 .47997 L .66254 .48158 L 0 .028 .127 r
F
.65978 .48246 m .65844 .48086 L .6612 .47997 L F
.33918 .48175 m .34016 .47931 L .34178 .48087 L 0 .026 .125 r
F
.33918 .48175 m .33755 .4802 L .34016 .47931 L F
.61457 .4827 m .61594 .48047 L .61731 .48194 L 0 .029 .128 r
F
.61457 .4827 m .6132 .48124 L .61594 .48047 L F
.56252 .48327 m .56381 .48108 L .56523 .48243 L 0 .03 .13 r
F
.56252 .48327 m .5611 .48192 L .56381 .48108 L F
.55568 .48366 m .55696 .48142 L .55839 .48279 L 0 .031 .131 r
F
.55568 .48366 m .55425 .48227 L .55696 .48142 L F
.54884 .48406 m .55011 .48167 L .55154 .48316 L 0 .031 .132 r
F
.54884 .48406 m .5474 .48255 L .55011 .48167 L F
.52416 .48317 m .52539 .48074 L .52685 .48228 L 0 .029 .129 r
F
.52416 .48317 m .5227 .48161 L .52539 .48074 L F
.76389 .48148 m .76546 .47911 L .7667 .48062 L 0 .026 .125 r
F
.76389 .48148 m .76265 .47998 L .76546 .47911 L F
.37754 .48208 m .37856 .47981 L .38015 .4813 L 0 .027 .127 r
F
.37754 .48208 m .37594 .48059 L .37856 .47981 L F
.44742 .48287 m .44855 .48062 L .45008 .48218 L 0 .029 .129 r
F
.44742 .48287 m .44589 .48133 L .44855 .48062 L F
.47895 .48344 m .48012 .48107 L .48162 .48261 L 0 .03 .13 r
F
.47895 .48344 m .47745 .48191 L .48012 .48107 L F
.40221 .48307 m .40328 .48053 L .40485 .48216 L 0 .029 .129 r
F
.40221 .48307 m .40065 .48143 L .40328 .48053 L F
.3008 .48174 m .30172 .47936 L .30338 .481 L 0 .027 .126 r
F
.3008 .48174 m .29914 .48011 L .30172 .47936 L F
.66663 .48232 m .66806 .47985 L .66939 .48147 L 0 .028 .127 r
F
.66663 .48232 m .6653 .48071 L .66806 .47985 L F
.71184 .48216 m .71333 .47966 L .71462 .48124 L 0 .027 .127 r
F
.71184 .48216 m .71055 .48059 L .71333 .47966 L F
.34601 .48161 m .34699 .47932 L .34861 .48091 L 0 .026 .126 r
F
.34601 .48161 m .34439 .48004 L .34699 .47932 L F
.48579 .48315 m .48697 .48071 L .48847 .48222 L 0 .03 .13 r
F
.48579 .48315 m .48429 .48166 L .48697 .48071 L F
.56937 .48316 m .57067 .48087 L .57209 .4824 L F
.56937 .48316 m .56795 .48165 L .57067 .48087 L F
.71869 .48188 m .7202 .47943 L .72148 .48101 L 0 .027 .126 r
F
.71869 .48188 m .71741 .48032 L .7202 .47943 L F
.62143 .48267 m .62279 .48011 L .62416 .48173 L 0 .028 .128 r
F
.62143 .48267 m .62005 .48105 L .62279 .48011 L F
.77075 .48135 m .77233 .47893 L .77357 .48053 L 0 .026 .125 r
F
.77075 .48135 m .76951 .47977 L .77233 .47893 L F
.40905 .48288 m .41013 .4804 L .41169 .482 L 0 .029 .129 r
F
.40905 .48288 m .40749 .48125 L .41013 .4804 L F
.49263 .48289 m .49382 .48061 L .49531 .48215 L F
.49263 .48289 m .49114 .48137 L .49382 .48061 L F
.531 .48309 m .53225 .48081 L .5337 .48237 L 0 .03 .13 r
F
.531 .48309 m .52955 .48154 L .53225 .48081 L F
.67349 .48222 m .67493 .47975 L .67625 .48132 L 0 .028 .127 r
F
.67349 .48222 m .67216 .48063 L .67493 .47975 L F
.62827 .48241 m .62965 .47986 L .63101 .48147 L 0 .028 .128 r
F
.62827 .48241 m .6269 .48079 L .62965 .47986 L F
.41589 .48262 m .41697 .48026 L .41853 .48175 L 0 .029 .129 r
F
.41589 .48262 m .41433 .48112 L .41697 .48026 L F
.63512 .48207 m .63651 .47968 L .63787 .48122 L 0 .028 .127 r
F
.63512 .48207 m .63376 .48053 L .63651 .47968 L F
.38436 .48209 m .3854 .47961 L .38699 .48124 L F
.38436 .48209 m .38278 .48046 L .3854 .47961 L F
.72555 .48172 m .72706 .47927 L .72834 .48086 L 0 .027 .126 r
F
.72555 .48172 m .72427 .48014 L .72706 .47927 L F
.68034 .48196 m .68179 .4795 L .6831 .48103 L 0 .027 .127 r
F
.68034 .48196 m .67902 .48041 L .68179 .4795 L F
.57622 .48314 m .57753 .48079 L .57894 .48235 L 0 .03 .13 r
F
.57622 .48314 m .5748 .48159 L .57753 .48079 L F
.68718 .48165 m .68864 .47916 L .68995 .4807 L 0 .027 .126 r
F
.68718 .48165 m .68587 .48009 L .68864 .47916 L F
.42273 .48242 m .42382 .48014 L .42537 .48164 L 0 .029 .129 r
F
.42273 .48242 m .42117 .48095 L .42382 .48014 L F
.30761 .48188 m .30855 .47938 L .3102 .481 L 0 .027 .127 r
F
.30761 .48188 m .30596 .48025 L .30855 .47938 L F
.35283 .48172 m .35382 .47939 L .35543 .4809 L F
.35283 .48172 m .35121 .48021 L .35382 .47939 L F
.7324 .48154 m .73393 .47904 L .7352 .48061 L 0 .027 .126 r
F
.7324 .48154 m .73113 .47995 L .73393 .47904 L F
.77762 .48135 m .77921 .47893 L .78044 .48056 L 0 .026 .125 r
F
.77762 .48135 m .77639 .47973 L .77921 .47893 L F
.64197 .48193 m .64338 .47968 L .64472 .48115 L 0 .028 .127 r
F
.64197 .48193 m .64062 .48045 L .64338 .47968 L F
.49947 .48288 m .50067 .48067 L .50215 .48216 L 0 .03 .13 r
F
.49947 .48288 m .49799 .4814 L .50067 .48067 L F
.45426 .48309 m .45539 .48067 L .45691 .48224 L F
.45426 .48309 m .45273 .48149 L .45539 .48067 L F
.69404 .48146 m .69551 .47909 L .69682 .48067 L 0 .027 .126 r
F
.69404 .48146 m .69273 .47988 L .69551 .47909 L F
.31444 .48167 m .31539 .47918 L .31704 .48076 L F
.31444 .48167 m .31279 .48009 L .31539 .47918 L F
.39119 .48205 m .39224 .47971 L .39382 .48134 L 0 .028 .128 r
F
.39119 .48205 m .38961 .48041 L .39224 .47971 L F
.73926 .48129 m .74078 .47874 L .74205 .48036 L 0 .026 .125 r
F
.73926 .48129 m .73799 .47968 L .74078 .47874 L F
.42957 .48227 m .43067 .47982 L .43222 .48137 L 0 .028 .128 r
F
.42957 .48227 m .42802 .48075 L .43067 .47982 L F
.35966 .48153 m .36066 .47915 L .36228 .48065 L 0 .027 .126 r
F
.35966 .48153 m .35805 .48002 L .36066 .47915 L F
.53785 .48325 m .5391 .48085 L .54055 .48249 L 0 .031 .131 r
F
.53785 .48325 m .5364 .48163 L .5391 .48085 L F
.58307 .48308 m .58438 .48062 L .58579 .48215 L 0 .03 .13 r
F
.58307 .48308 m .58166 .48154 L .58438 .48062 L F
.58991 .48272 m .59124 .4803 L .59264 .4818 L F
.58991 .48272 m .58851 .48122 L .59124 .4803 L F
.32128 .4814 m .32223 .47902 L .32388 .48054 L 0 .027 .126 r
F
.32128 .4814 m .31963 .47989 L .32223 .47902 L F
.4611 .48292 m .46224 .48055 L .46376 .48205 L 0 .03 .13 r
F
.4611 .48292 m .45958 .48138 L .46224 .48055 L F
.43641 .48198 m .43752 .47977 L .43906 .48126 L 0 .028 .128 r
F
.43641 .48198 m .43487 .48049 L .43752 .47977 L F
.74611 .48105 m .74766 .47863 L .74892 .48024 L 0 .026 .125 r
F
.74611 .48105 m .74485 .47943 L .74766 .47863 L F
.64882 .48181 m .65024 .47958 L .65158 .48101 L 0 .028 .127 r
F
.64882 .48181 m .64748 .48036 L .65024 .47958 L F
.59676 .48238 m .5981 .47999 L .59949 .48147 L 0 .029 .129 r
F
.59676 .48238 m .59536 .4809 L .5981 .47999 L F
.78449 .48129 m .78608 .47872 L .7873 .48034 L 0 .026 .125 r
F
.78449 .48129 m .78326 .47967 L .78608 .47872 L F
.60361 .48212 m .60496 .47991 L .60634 .48135 L 0 .029 .129 r
F
.60361 .48212 m .60222 .48069 L .60496 .47991 L F
.50632 .48289 m .50752 .48071 L .509 .48216 L 0 .031 .131 r
F
.50632 .48289 m .50484 .48145 L .50752 .48071 L F
.32811 .48122 m .32907 .47883 L .33071 .48038 L 0 .027 .126 r
F
.32811 .48122 m .32647 .47969 L .32907 .47883 L F
.36649 .48142 m .3675 .47916 L .36911 .48066 L F
.36649 .48142 m .36489 .47991 L .3675 .47916 L F
.7009 .48147 m .70239 .4791 L .70369 .48068 L F
.7009 .48147 m .6996 .47989 L .70239 .4791 L F
.28973 .48112 m .29065 .47857 L .29231 .48021 L 0 .026 .125 r
F
.28973 .48112 m .28806 .47948 L .29065 .47857 L F
.46794 .48284 m .46909 .48052 L .4706 .48203 L 0 .03 .13 r
F
.46794 .48284 m .46642 .48128 L .46909 .48052 L F
.51316 .48269 m .51438 .48033 L .51585 .48178 L F
.51316 .48269 m .51169 .48124 L .51438 .48033 L F
.65568 .48176 m .6571 .47928 L .65844 .48086 L 0 .028 .127 r
F
.65568 .48176 m .65434 .48019 L .6571 .47928 L F
.75298 .48102 m .75454 .47861 L .75579 .48018 L 0 .026 .125 r
F
.75298 .48102 m .75173 .47943 L .75454 .47861 L F
.61046 .482 m .61182 .4798 L .6132 .48124 L 0 .029 .129 r
F
.61046 .482 m .60908 .48058 L .61182 .4798 L F
.33495 .48109 m .33592 .47864 L .33755 .4802 L 0 .026 .126 r
F
.33495 .48109 m .33331 .47954 L .33592 .47864 L F
.44324 .48204 m .44436 .47982 L .44589 .48133 L 0 .029 .129 r
F
.44324 .48204 m .44171 .48054 L .44436 .47982 L F
.54469 .48339 m .54596 .4809 L .5474 .48255 L 0 .031 .132 r
F
.54469 .48339 m .54325 .48173 L .54596 .4809 L F
.39802 .48226 m .39907 .47982 L .40065 .48143 L 0 .029 .129 r
F
.39802 .48226 m .39644 .48064 L .39907 .47982 L F
.29656 .48095 m .29748 .47847 L .29914 .48011 L 0 .026 .125 r
F
.29656 .48095 m .2949 .47931 L .29748 .47847 L F
.52 .48248 m .52123 .48006 L .5227 .48161 L 0 .03 .13 r
F
.52 .48248 m .51854 .48091 L .52123 .48006 L F
.37332 .48137 m .37434 .4791 L .37594 .48059 L 0 .027 .127 r
F
.37332 .48137 m .37172 .47988 L .37434 .4791 L F
.66254 .48158 m .66396 .47908 L .6653 .48071 L 0 .028 .127 r
F
.66254 .48158 m .6612 .47997 L .66396 .47908 L F
.75984 .48084 m .76141 .47848 L .76265 .47998 L 0 .026 .125 r
F
.75984 .48084 m .7586 .47933 L .76141 .47848 L F
.47478 .48274 m .47594 .48035 L .47745 .48191 L 0 .03 .131 r
F
.47478 .48274 m .47327 .4812 L .47594 .48035 L F
.34178 .48087 m .34276 .47847 L .34439 .48004 L 0 .026 .125 r
F
.34178 .48087 m .34016 .47931 L .34276 .47847 L F
.55154 .48316 m .55282 .48079 L .55425 .48227 L 0 .031 .132 r
F
.55154 .48316 m .55011 .48167 L .55282 .48079 L F
.70777 .48146 m .70926 .47902 L .71055 .48059 L 0 .027 .127 r
F
.70777 .48146 m .70647 .47989 L .70926 .47902 L F
.55839 .48279 m .55967 .48057 L .5611 .48192 L 0 .031 .131 r
F
.55839 .48279 m .55696 .48142 L .55967 .48057 L F
.56523 .48243 m .56653 .48028 L .56795 .48165 L 0 .03 .13 r
F
.56523 .48243 m .56381 .48108 L .56653 .48028 L F
.52685 .48228 m .52809 .48 L .52955 .48154 L F
.52685 .48228 m .52539 .48074 L .52809 .48 L F
.61731 .48194 m .61868 .47958 L .62005 .48105 L 0 .029 .129 r
F
.61731 .48194 m .61594 .48047 L .61868 .47958 L F
.7667 .48062 m .76827 .47824 L .76951 .47977 L 0 .026 .125 r
F
.7667 .48062 m .76546 .47911 L .76827 .47824 L F
.40485 .48216 m .40592 .47962 L .40749 .48125 L 0 .029 .129 r
F
.40485 .48216 m .40328 .48053 L .40592 .47962 L F
.71462 .48124 m .71612 .47874 L .71741 .48032 L 0 .027 .126 r
F
.71462 .48124 m .71333 .47966 L .71612 .47874 L F
.48847 .48222 m .48965 .47984 L .49114 .48137 L 0 .029 .129 r
F
.48847 .48222 m .48697 .48071 L .48965 .47984 L F
.66939 .48147 m .67083 .47898 L .67216 .48063 L 0 .028 .127 r
F
.66939 .48147 m .66806 .47985 L .67083 .47898 L F
.48162 .48261 m .4828 .48012 L .48429 .48166 L 0 .03 .13 r
F
.48162 .48261 m .48012 .48107 L .4828 .48012 L F
.38015 .4813 m .38118 .47898 L .38278 .48046 L 0 .028 .127 r
F
.38015 .4813 m .37856 .47981 L .38118 .47898 L F
.62416 .48173 m .62553 .47917 L .6269 .48079 L 0 .028 .128 r
F
.62416 .48173 m .62279 .48011 L .62553 .47917 L F
.30338 .481 m .3043 .47862 L .30596 .48025 L 0 .027 .126 r
F
.30338 .481 m .30172 .47936 L .3043 .47862 L F
.72148 .48101 m .72299 .47855 L .72427 .48014 L F
.72148 .48101 m .7202 .47943 L .72299 .47855 L F
.45008 .48218 m .45121 .47992 L .45273 .48149 L 0 .03 .13 r
F
.45008 .48218 m .44855 .48062 L .45121 .47992 L F
.41169 .482 m .41277 .47954 L .41433 .48112 L 0 .029 .129 r
F
.41169 .482 m .41013 .4804 L .41277 .47954 L F
.57209 .4824 m .57339 .48005 L .5748 .48159 L 0 .03 .13 r
F
.57209 .4824 m .57067 .48087 L .57339 .48005 L F
.63101 .48147 m .63239 .47892 L .63376 .48053 L 0 .028 .127 r
F
.63101 .48147 m .62965 .47986 L .63239 .47892 L F
.77357 .48053 m .77515 .47812 L .77639 .47973 L 0 .026 .125 r
F
.77357 .48053 m .77233 .47893 L .77515 .47812 L F
.34861 .48091 m .34959 .4786 L .35121 .48021 L 0 .027 .126 r
F
.34861 .48091 m .34699 .47932 L .34959 .4786 L F
.67625 .48132 m .6777 .47886 L .67902 .48041 L 0 .028 .127 r
F
.67625 .48132 m .67493 .47975 L .6777 .47886 L F
.41853 .48175 m .41962 .47944 L .42117 .48095 L 0 .029 .129 r
F
.41853 .48175 m .41697 .48026 L .41962 .47944 L F
.49531 .48215 m .4965 .47986 L .49799 .4814 L 0 .03 .13 r
F
.49531 .48215 m .49382 .48061 L .4965 .47986 L F
.6831 .48103 m .68456 .47858 L .68587 .48009 L 0 .027 .126 r
F
.6831 .48103 m .68179 .4795 L .68456 .47858 L F
.63787 .48122 m .63926 .47891 L .64062 .48045 L 0 .028 .127 r
F
.63787 .48122 m .63651 .47968 L .63926 .47891 L F
.5337 .48237 m .53495 .48006 L .5364 .48163 L 0 .03 .131 r
F
.5337 .48237 m .53225 .48081 L .53495 .48006 L F
.38699 .48124 m .38803 .47879 L .38961 .48041 L 0 .028 .127 r
F
.38699 .48124 m .3854 .47961 L .38803 .47879 L F
.72834 .48086 m .72986 .47837 L .73113 .47995 L 0 .027 .126 r
F
.72834 .48086 m .72706 .47927 L .72986 .47837 L F
.68995 .4807 m .69142 .47833 L .69273 .47988 L F
.68995 .4807 m .68864 .47916 L .69142 .47833 L F
.7352 .48061 m .73672 .47812 L .73799 .47968 L 0 .026 .125 r
F
.7352 .48061 m .73393 .47904 L .73672 .47812 L F
.3102 .481 m .31114 .47846 L .31279 .48009 L 0 .027 .126 r
F
.3102 .481 m .30855 .47938 L .31114 .47846 L F
.57894 .48235 m .58025 .47996 L .58166 .48154 L 0 .03 .131 r
F
.57894 .48235 m .57753 .48079 L .58025 .47996 L F
.42537 .48164 m .42647 .47923 L .42802 .48075 L 0 .029 .129 r
F
.42537 .48164 m .42382 .48014 L .42647 .47923 L F
.35543 .4809 m .35643 .47851 L .35805 .48002 L 0 .027 .127 r
F
.35543 .4809 m .35382 .47939 L .35643 .47851 L F
.45691 .48224 m .45806 .47984 L .45958 .48138 L 0 .03 .13 r
F
.45691 .48224 m .45539 .48067 L .45806 .47984 L F
.74205 .48036 m .74358 .47781 L .74485 .47943 L 0 .026 .125 r
F
.74205 .48036 m .74078 .47874 L .74358 .47781 L F
.78044 .48056 m .78203 .47804 L .78326 .47967 L F
.78044 .48056 m .77921 .47893 L .78203 .47804 L F
.31704 .48076 m .31799 .47832 L .31963 .47989 L 0 .027 .126 r
F
.31704 .48076 m .31539 .47918 L .31799 .47832 L F
.64472 .48115 m .64613 .47891 L .64748 .48036 L 0 .028 .128 r
F
.64472 .48115 m .64338 .47968 L .64613 .47891 L F
.43222 .48137 m .43332 .47892 L .43487 .48049 L F
.43222 .48137 m .43067 .47982 L .43332 .47892 L F
.58579 .48215 m .58711 .47971 L .58851 .48122 L 0 .03 .13 r
F
.58579 .48215 m .58438 .48062 L .58711 .47971 L F
.50215 .48216 m .50336 .47995 L .50484 .48145 L 0 .03 .131 r
F
.50215 .48216 m .50067 .48067 L .50336 .47995 L F
.36228 .48065 m .36328 .47842 L .36489 .47991 L 0 .027 .126 r
F
.36228 .48065 m .36066 .47915 L .36328 .47842 L F
.59264 .4818 m .59397 .47941 L .59536 .4809 L 0 .029 .129 r
F
.59264 .4818 m .59124 .4803 L .59397 .47941 L F
.69682 .48067 m .6983 .47831 L .6996 .47989 L 0 .027 .126 r
F
.69682 .48067 m .69551 .47909 L .6983 .47831 L F
.59949 .48147 m .60083 .4792 L .60222 .48069 L 0 .029 .129 r
F
.59949 .48147 m .5981 .47999 L .60083 .4792 L F
.7873 .48034 m .7889 .47777 L .79012 .47938 L 0 .026 .125 r
F
.7873 .48034 m .78608 .47872 L .7889 .47777 L F
.46376 .48205 m .46491 .47982 L .46642 .48128 L 0 .03 .13 r
F
.46376 .48205 m .46224 .48055 L .46491 .47982 L F
.32388 .48054 m .32483 .47814 L .32647 .47969 L 0 .027 .126 r
F
.32388 .48054 m .32223 .47902 L .32483 .47814 L F
.39382 .48134 m .39487 .47901 L .39644 .48064 L 0 .029 .128 r
F
.39382 .48134 m .39224 .47971 L .39487 .47901 L F
.54055 .48249 m .54181 .48006 L .54325 .48173 L 0 .031 .131 r
F
.54055 .48249 m .5391 .48085 L .54181 .48006 L F
.74892 .48024 m .75047 .47783 L .75173 .47943 L 0 .026 .125 r
F
.74892 .48024 m .74766 .47863 L .75047 .47783 L F
.65158 .48101 m .653 .47876 L .65434 .48019 L 0 .028 .128 r
F
.65158 .48101 m .65024 .47958 L .653 .47876 L F
.43906 .48126 m .44017 .47905 L .44171 .48054 L 0 .029 .128 r
F
.43906 .48126 m .43752 .47977 L .44017 .47905 L F
.33071 .48038 m .33168 .47797 L .33331 .47954 L 0 .027 .126 r
F
.33071 .48038 m .32907 .47883 L .33168 .47797 L F
.60634 .48135 m .6077 .47913 L .60908 .48058 L 0 .029 .129 r
F
.60634 .48135 m .60496 .47991 L .6077 .47913 L F
.29231 .48021 m .29323 .47767 L .2949 .47931 L 0 .026 .125 r
F
.29231 .48021 m .29065 .47857 L .29323 .47767 L F
.509 .48216 m .51021 .4798 L .51169 .48124 L 0 .031 .131 r
F
.509 .48216 m .50752 .48071 L .51021 .4798 L F
.51585 .48178 m .51707 .47946 L .51854 .48091 L 0 .03 .13 r
F
.51585 .48178 m .51438 .48033 L .51707 .47946 L F
.36911 .48066 m .37012 .4784 L .37172 .47988 L 0 .027 .127 r
F
.36911 .48066 m .3675 .47916 L .37012 .4784 L F
.65844 .48086 m .65986 .47836 L .6612 .47997 L 0 .028 .127 r
F
.65844 .48086 m .6571 .47928 L .65986 .47836 L F
.70369 .48068 m .70518 .47831 L .70647 .47989 L 0 .027 .127 r
F
.70369 .48068 m .70239 .4791 L .70518 .47831 L F
.4706 .48203 m .47176 .47969 L .47327 .4812 L 0 .03 .131 r
F
.4706 .48203 m .46909 .48052 L .47176 .47969 L F
.75579 .48018 m .75735 .47777 L .7586 .47933 L 0 .026 .125 r
F
.75579 .48018 m .75454 .47861 L .75735 .47777 L F
.33755 .4802 m .33853 .47774 L .34016 .47931 L F
.33755 .4802 m .33592 .47864 L .33853 .47774 L F
.5474 .48255 m .54867 .48003 L .55011 .48167 L 0 .031 .132 r
F
.5474 .48255 m .54596 .4809 L .54867 .48003 L F
.5227 .48161 m .52393 .47922 L .52539 .48074 L 0 .03 .13 r
F
.5227 .48161 m .52123 .48006 L .52393 .47922 L F
.6132 .48124 m .61456 .47902 L .61594 .48047 L 0 .029 .129 r
F
.6132 .48124 m .61182 .4798 L .61456 .47902 L F
.40065 .48143 m .40171 .47893 L .40328 .48053 L F
.40065 .48143 m .39907 .47982 L .40171 .47893 L F
.29914 .48011 m .30006 .47773 L .30172 .47936 L 0 .026 .125 r
F
.29914 .48011 m .29748 .47847 L .30006 .47773 L F
.6653 .48071 m .66673 .4782 L .66806 .47985 L 0 .027 .127 r
F
.6653 .48071 m .66396 .47908 L .66673 .4782 L F
.76265 .47998 m .76422 .47759 L .76546 .47911 L 0 .026 .125 r
F
.76265 .47998 m .76141 .47848 L .76422 .47759 L F
.55425 .48227 m .55553 .47997 L .55696 .48142 L 0 .031 .132 r
F
.55425 .48227 m .55282 .48079 L .55553 .47997 L F
.44589 .48133 m .44702 .47909 L .44855 .48062 L 0 .029 .129 r
F
.44589 .48133 m .44436 .47982 L .44702 .47909 L F
.47745 .48191 m .47862 .4795 L .48012 .48107 L 0 .03 .131 r
F
.47745 .48191 m .47594 .48035 L .47862 .4795 L F
.5611 .48192 m .56239 .47973 L .56381 .48108 L 0 .031 .131 r
F
.5611 .48192 m .55967 .48057 L .56239 .47973 L F
.71055 .48059 m .71204 .47809 L .71333 .47966 L 0 .027 .127 r
F
.71055 .48059 m .70926 .47902 L .71204 .47809 L F
.37594 .48059 m .37696 .47832 L .37856 .47981 L 0 .028 .127 r
F
.37594 .48059 m .37434 .4791 L .37696 .47832 L F
.34439 .48004 m .34537 .47773 L .34699 .47932 L 0 .026 .126 r
F
.34439 .48004 m .34276 .47847 L .34537 .47773 L F
.62005 .48105 m .62142 .47864 L .62279 .48011 L 0 .029 .128 r
F
.62005 .48105 m .61868 .47958 L .62142 .47864 L F
.40749 .48125 m .40856 .47879 L .41013 .4804 L 0 .029 .129 r
F
.40749 .48125 m .40592 .47962 L .40856 .47879 L F
.71741 .48032 m .71891 .47784 L .7202 .47943 L 0 .027 .126 r
F
.71741 .48032 m .71612 .47874 L .71891 .47784 L F
.56795 .48165 m .56925 .47948 L .57067 .48087 L 0 .03 .131 r
F
.56795 .48165 m .56653 .48028 L .56925 .47948 L F
.48429 .48166 m .48548 .47918 L .48697 .48071 L 0 .03 .13 r
F
.48429 .48166 m .4828 .48012 L .48548 .47918 L F
.76951 .47977 m .77109 .47737 L .77233 .47893 L 0 .026 .125 r
F
.76951 .47977 m .76827 .47824 L .77109 .47737 L F
.52955 .48154 m .53079 .47926 L .53225 .48081 L 0 .03 .13 r
F
.52955 .48154 m .52809 .48 L .53079 .47926 L F
.6269 .48079 m .62828 .47824 L .62965 .47986 L 0 .028 .127 r
F
.6269 .48079 m .62553 .47917 L .62828 .47824 L F
.49114 .48137 m .49233 .47908 L .49382 .48061 L 0 .03 .13 r
F
.49114 .48137 m .48965 .47984 L .49233 .47908 L F
.67216 .48063 m .6736 .47812 L .67493 .47975 L 0 .028 .127 r
F
.67216 .48063 m .67083 .47898 L .6736 .47812 L F
.38278 .48046 m .38381 .47813 L .3854 .47961 L F
.38278 .48046 m .38118 .47898 L .38381 .47813 L F
.72427 .48014 m .72578 .47767 L .72706 .47927 L 0 .027 .126 r
F
.72427 .48014 m .72299 .47855 L .72578 .47767 L F
.63376 .48053 m .63515 .47807 L .63651 .47968 L 0 .028 .127 r
F
.63376 .48053 m .63239 .47892 L .63515 .47807 L F
.41433 .48112 m .41541 .4787 L .41697 .48026 L 0 .029 .129 r
F
.41433 .48112 m .41277 .47954 L .41541 .4787 L F
.67902 .48041 m .68047 .47797 L .68179 .4795 L 0 .027 .127 r
F
.67902 .48041 m .6777 .47886 L .68047 .47797 L F
.30596 .48025 m .30689 .47775 L .30855 .47938 L 0 .027 .126 r
F
.30596 .48025 m .3043 .47862 L .30689 .47775 L F
.5748 .48159 m .57611 .47922 L .57753 .48079 L 0 .03 .13 r
F
.5748 .48159 m .57339 .48005 L .57611 .47922 L F
.68587 .48009 m .68733 .47767 L .68864 .47916 L 0 .027 .126 r
F
.68587 .48009 m .68456 .47858 L .68733 .47767 L F
.77639 .47973 m .77798 .47731 L .77921 .47893 L 0 .026 .125 r
F
.77639 .47973 m .77515 .47812 L .77798 .47731 L F
.73113 .47995 m .73265 .47747 L .73393 .47904 L 0 .027 .126 r
F
.73113 .47995 m .72986 .47837 L .73265 .47747 L F
.45273 .48149 m .45387 .47911 L .45539 .48067 L 0 .03 .13 r
F
.45273 .48149 m .45121 .47992 L .45387 .47911 L F
.42117 .48095 m .42226 .47862 L .42382 .48014 L 0 .029 .129 r
F
.42117 .48095 m .41962 .47944 L .42226 .47862 L F
.35121 .48021 m .3522 .47777 L .35382 .47939 L 0 .027 .127 r
F
.35121 .48021 m .34959 .4786 L .3522 .47777 L F
.38961 .48041 m .39066 .4781 L .39224 .47971 L 0 .028 .127 r
F
.38961 .48041 m .38803 .47879 L .39066 .4781 L F
.73799 .47968 m .73952 .47718 L .74078 .47874 L 0 .026 .125 r
F
.73799 .47968 m .73672 .47812 L .73952 .47718 L F
.49799 .4814 m .49919 .47911 L .50067 .48067 L 0 .03 .13 r
F
.49799 .4814 m .4965 .47986 L .49919 .47911 L F
.64062 .48045 m .64202 .47815 L .64338 .47968 L 0 .028 .128 r
F
.64062 .48045 m .63926 .47891 L .64202 .47815 L F
.69273 .47988 m .69421 .47753 L .69551 .47909 L 0 .027 .126 r
F
.69273 .47988 m .69142 .47833 L .69421 .47753 L F
.31279 .48009 m .31374 .47756 L .31539 .47918 L F
.31279 .48009 m .31114 .47846 L .31374 .47756 L F
.5364 .48163 m .53765 .47925 L .5391 .48085 L 0 .031 .131 r
F
.5364 .48163 m .53495 .48006 L .53765 .47925 L F
.42802 .48075 m .42912 .47827 L .43067 .47982 L 0 .029 .128 r
F
.42802 .48075 m .42647 .47923 L .42912 .47827 L F
.74485 .47943 m .74639 .47702 L .74766 .47863 L 0 .026 .125 r
F
.74485 .47943 m .74358 .47781 L .74639 .47702 L F
.58166 .48154 m .58298 .47908 L .58438 .48062 L 0 .03 .13 r
F
.58166 .48154 m .58025 .47996 L .58298 .47908 L F
.35805 .48002 m .35905 .47764 L .36066 .47915 L 0 .027 .126 r
F
.35805 .48002 m .35643 .47851 L .35905 .47764 L F
.78326 .47967 m .78485 .4771 L .78608 .47872 L 0 .026 .125 r
F
.78326 .47967 m .78203 .47804 L .78485 .4771 L F
.45958 .48138 m .46072 .47905 L .46224 .48055 L 0 .03 .13 r
F
.45958 .48138 m .45806 .47984 L .46072 .47905 L F
.58851 .48122 m .58984 .47882 L .59124 .4803 L F
.58851 .48122 m .58711 .47971 L .58984 .47882 L F
.31963 .47989 m .32058 .47746 L .32223 .47902 L 0 .027 .126 r
F
.31963 .47989 m .31799 .47832 L .32058 .47746 L F
.43487 .48049 m .43597 .47818 L .43752 .47977 L 0 .028 .128 r
F
.43487 .48049 m .43332 .47892 L .43597 .47818 L F
.59536 .4809 m .5967 .47851 L .5981 .47999 L 0 .029 .129 r
F
.59536 .4809 m .59397 .47941 L .5967 .47851 L F
.79012 .47938 m .79172 .47685 L .79294 .47847 L 0 .026 .124 r
F
.79012 .47938 m .7889 .47777 L .79172 .47685 L F
.64748 .48036 m .6489 .47814 L .65024 .47958 L 0 .028 .128 r
F
.64748 .48036 m .64613 .47891 L .6489 .47814 L F
.28806 .47948 m .28897 .47699 L .29065 .47857 L 0 .026 .125 r
F
.28806 .47948 m .28639 .4779 L .28897 .47699 L F
.32647 .47969 m .32743 .47727 L .32907 .47883 L 0 .027 .126 r
F
.32647 .47969 m .32483 .47814 L .32743 .47727 L F
.6996 .47989 m .70109 .47752 L .70239 .4791 L F
.6996 .47989 m .6983 .47831 L .70109 .47752 L F
.36489 .47991 m .36589 .47769 L .3675 .47916 L 0 .027 .127 r
F
.36489 .47991 m .36328 .47842 L .36589 .47769 L F
.60222 .48069 m .60357 .4784 L .60496 .47991 L 0 .029 .129 r
F
.60222 .48069 m .60083 .4792 L .60357 .4784 L F
.50484 .48145 m .50605 .47919 L .50752 .48071 L 0 .031 .131 r
F
.50484 .48145 m .50336 .47995 L .50605 .47919 L F
.46642 .48128 m .46757 .47908 L .46909 .48052 L F
.46642 .48128 m .46491 .47982 L .46757 .47908 L F
.65434 .48019 m .65576 .47783 L .6571 .47928 L 0 .028 .127 r
F
.65434 .48019 m .653 .47876 L .65576 .47783 L F
.75173 .47943 m .75328 .47702 L .75454 .47861 L 0 .026 .125 r
F
.75173 .47943 m .75047 .47783 L .75328 .47702 L F
.54325 .48173 m .54451 .47923 L .54596 .4809 L 0 .031 .132 r
F
.54325 .48173 m .54181 .48006 L .54451 .47923 L F
.39644 .48064 m .3975 .47821 L .39907 .47982 L 0 .029 .129 r
F
.39644 .48064 m .39487 .47901 L .3975 .47821 L F
.2949 .47931 m .29582 .47683 L .29748 .47847 L 0 .026 .125 r
F
.2949 .47931 m .29323 .47767 L .29582 .47683 L F
.51169 .48124 m .51291 .47888 L .51438 .48033 L 0 .03 .131 r
F
.51169 .48124 m .51021 .4798 L .51291 .47888 L F
.33331 .47954 m .33429 .47705 L .33592 .47864 L 0 .026 .126 r
F
.33331 .47954 m .33168 .47797 L .33429 .47705 L F
.51854 .48091 m .51977 .47863 L .52123 .48006 L 0 .03 .13 r
F
.51854 .48091 m .51707 .47946 L .51977 .47863 L F
.6612 .47997 m .66262 .47746 L .66396 .47908 L 0 .027 .127 r
F
.6612 .47997 m .65986 .47836 L .66262 .47746 L F
.44171 .48054 m .44282 .47831 L .44436 .47982 L 0 .029 .129 r
F
.44171 .48054 m .44017 .47905 L .44282 .47831 L F
.60908 .48058 m .61044 .47834 L .61182 .4798 L F
.60908 .48058 m .6077 .47913 L .61044 .47834 L F
.47327 .4812 m .47443 .47883 L .47594 .48035 L 0 .03 .131 r
F
.47327 .4812 m .47176 .47969 L .47443 .47883 L F
.34016 .47931 m .34114 .47687 L .34276 .47847 L 0 .026 .125 r
F
.34016 .47931 m .33853 .47774 L .34114 .47687 L F
.37172 .47988 m .37274 .47761 L .37434 .4791 L 0 .028 .127 r
F
.37172 .47988 m .37012 .4784 L .37274 .47761 L F
.70647 .47989 m .70796 .47744 L .70926 .47902 L 0 .027 .127 r
F
.70647 .47989 m .70518 .47831 L .70796 .47744 L F
.7586 .47933 m .76016 .47693 L .76141 .47848 L 0 .026 .125 r
F
.7586 .47933 m .75735 .47777 L .76016 .47693 L F
.40328 .48053 m .40435 .47804 L .40592 .47962 L 0 .029 .129 r
F
.40328 .48053 m .40171 .47893 L .40435 .47804 L F
.55011 .48167 m .55138 .47916 L .55282 .48079 L 0 .031 .132 r
F
.55011 .48167 m .54867 .48003 L .55138 .47916 L F
.52539 .48074 m .52663 .47847 L .52809 .48 L 0 .03 .13 r
F
.52539 .48074 m .52393 .47922 L .52663 .47847 L F
.66806 .47985 m .66949 .47731 L .67083 .47898 L 0 .027 .127 r
F
.66806 .47985 m .66673 .4782 L .66949 .47731 L F
.71333 .47966 m .71483 .47716 L .71612 .47874 L 0 .027 .126 r
F
.71333 .47966 m .71204 .47809 L .71483 .47716 L F
.76546 .47911 m .76704 .4767 L .76827 .47824 L 0 .026 .125 r
F
.76546 .47911 m .76422 .47759 L .76704 .4767 L F
.61594 .48047 m .61731 .47813 L .61868 .47958 L 0 .029 .129 r
F
.61594 .48047 m .61456 .47902 L .61731 .47813 L F
.55696 .48142 m .55824 .47914 L .55967 .48057 L 0 .031 .132 r
F
.55696 .48142 m .55553 .47997 L .55824 .47914 L F
.62279 .48011 m .62417 .47771 L .62553 .47917 L 0 .028 .128 r
F
.62279 .48011 m .62142 .47864 L .62417 .47771 L F
.48012 .48107 m .48129 .47857 L .4828 .48012 L 0 .03 .13 r
F
.48012 .48107 m .47862 .4795 L .48129 .47857 L F
.30172 .47936 m .30264 .477 L .3043 .47862 L 0 .027 .126 r
F
.30172 .47936 m .30006 .47773 L .30264 .477 L F
.56381 .48108 m .56511 .47891 L .56653 .48028 L 0 .031 .131 r
F
.56381 .48108 m .56239 .47973 L .56511 .47891 L F
.48697 .48071 m .48816 .47831 L .48965 .47984 L 0 .03 .13 r
F
.48697 .48071 m .48548 .47918 L .48816 .47831 L F
.37856 .47981 m .37959 .47749 L .38118 .47898 L 0 .028 .127 r
F
.37856 .47981 m .37696 .47832 L .37959 .47749 L F
.7202 .47943 m .7217 .47695 L .72299 .47855 L 0 .027 .126 r
F
.7202 .47943 m .71891 .47784 L .7217 .47695 L F
.41013 .4804 m .41121 .47796 L .41277 .47954 L 0 .029 .129 r
F
.41013 .4804 m .40856 .47879 L .41121 .47796 L F
.62965 .47986 m .63103 .4773 L .63239 .47892 L 0 .028 .127 r
F
.62965 .47986 m .62828 .47824 L .63103 .4773 L F
.44855 .48062 m .44968 .47836 L .45121 .47992 L 0 .03 .13 r
F
.44855 .48062 m .44702 .47909 L .44968 .47836 L F
.77233 .47893 m .77391 .47654 L .77515 .47812 L 0 .026 .125 r
F
.77233 .47893 m .77109 .47737 L .77391 .47654 L F
.34699 .47932 m .34797 .47698 L .34959 .4786 L 0 .027 .126 r
F
.34699 .47932 m .34537 .47773 L .34797 .47698 L F
.57067 .48087 m .57197 .47863 L .57339 .48005 L 0 .03 .131 r
F
.57067 .48087 m .56925 .47948 L .57197 .47863 L F
.67493 .47975 m .67637 .47725 L .6777 .47886 L 0 .028 .127 r
F
.67493 .47975 m .6736 .47812 L .67637 .47725 L F
.3854 .47961 m .38644 .47731 L .38803 .47879 L F
.3854 .47961 m .38381 .47813 L .38644 .47731 L F
.72706 .47927 m .72858 .47679 L .72986 .47837 L 0 .027 .126 r
F
.72706 .47927 m .72578 .47767 L .72858 .47679 L F
.49382 .48061 m .49501 .47832 L .4965 .47986 L 0 .03 .13 r
F
.49382 .48061 m .49233 .47908 L .49501 .47832 L F
.53225 .48081 m .53349 .4785 L .53495 .48006 L 0 .03 .131 r
F
.53225 .48081 m .53079 .47926 L .53349 .4785 L F
.63651 .47968 m .6379 .4773 L .63926 .47891 L 0 .028 .127 r
F
.63651 .47968 m .63515 .47807 L .6379 .4773 L F
.41697 .48026 m .41806 .47788 L .41962 .47944 L 0 .029 .129 r
F
.41697 .48026 m .41541 .4787 L .41806 .47788 L F
.68179 .4795 m .68324 .47707 L .68456 .47858 L 0 .027 .127 r
F
.68179 .4795 m .68047 .47797 L .68324 .47707 L F
.68864 .47916 m .69011 .47683 L .69142 .47833 L 0 .027 .126 r
F
.68864 .47916 m .68733 .47767 L .69011 .47683 L F
.30855 .47938 m .30949 .47684 L .31114 .47846 L F
.30855 .47938 m .30689 .47775 L .30949 .47684 L F
.73393 .47904 m .73545 .47655 L .73672 .47812 L 0 .026 .125 r
F
.73393 .47904 m .73265 .47747 L .73545 .47655 L F
.57753 .48079 m .57884 .47838 L .58025 .47996 L 0 .03 .131 r
F
.57753 .48079 m .57611 .47922 L .57884 .47838 L F
.77921 .47893 m .7808 .47642 L .78203 .47804 L 0 .026 .125 r
F
.77921 .47893 m .77798 .47731 L .7808 .47642 L F
.74078 .47874 m .74232 .47626 L .74358 .47781 L F
.74078 .47874 m .73952 .47718 L .74232 .47626 L F
.45539 .48067 m .45653 .47828 L .45806 .47984 L 0 .03 .13 r
F
.45539 .48067 m .45387 .47911 L .45653 .47828 L F
.31539 .47918 m .31634 .47673 L .31799 .47832 L 0 .027 .126 r
F
.31539 .47918 m .31374 .47756 L .31634 .47673 L F
.42382 .48014 m .42492 .4777 L .42647 .47923 L 0 .029 .129 r
F
.42382 .48014 m .42226 .47862 L .42492 .4777 L F
.35382 .47939 m .35482 .47688 L .35643 .47851 L 0 .027 .127 r
F
.35382 .47939 m .3522 .47777 L .35482 .47688 L F
.43067 .47982 m .43178 .47734 L .43332 .47892 L 0 .028 .128 r
F
.43067 .47982 m .42912 .47827 L .43178 .47734 L F
.69551 .47909 m .69699 .47674 L .6983 .47831 L 0 .027 .126 r
F
.69551 .47909 m .69421 .47753 L .69699 .47674 L F
.78608 .47872 m .78767 .47615 L .7889 .47777 L 0 .026 .125 r
F
.78608 .47872 m .78485 .4771 L .78767 .47615 L F
.58438 .48062 m .5857 .47819 L .58711 .47971 L 0 .03 .13 r
F
.58438 .48062 m .58298 .47908 L .5857 .47819 L F
.64338 .47968 m .64478 .47739 L .64613 .47891 L 0 .028 .128 r
F
.64338 .47968 m .64202 .47815 L .64478 .47739 L F
.5391 .48085 m .54036 .47845 L .54181 .48006 L 0 .031 .131 r
F
.5391 .48085 m .53765 .47925 L .54036 .47845 L F
.39224 .47971 m .39329 .47741 L .39487 .47901 L 0 .028 .128 r
F
.39224 .47971 m .39066 .4781 L .39329 .47741 L F
.36066 .47915 m .36166 .47692 L .36328 .47842 L 0 .027 .127 r
F
.36066 .47915 m .35905 .47764 L .36166 .47692 L F
.50067 .48067 m .50188 .47837 L .50336 .47995 L 0 .031 .131 r
F
.50067 .48067 m .49919 .47911 L .50188 .47837 L F
.59124 .4803 m .59257 .47794 L .59397 .47941 L 0 .03 .13 r
F
.59124 .4803 m .58984 .47882 L .59257 .47794 L F
.74766 .47863 m .74921 .47622 L .75047 .47783 L 0 .026 .125 r
F
.74766 .47863 m .74639 .47702 L .74921 .47622 L F
.32223 .47902 m .32319 .4766 L .32483 .47814 L 0 .027 .126 r
F
.32223 .47902 m .32058 .47746 L .32319 .4766 L F
.46224 .48055 m .46339 .47835 L .46491 .47982 L 0 .031 .131 r
F
.46224 .48055 m .46072 .47905 L .46339 .47835 L F
.79294 .47847 m .79455 .47593 L .79577 .47756 L 0 .025 .124 r
F
.79294 .47847 m .79172 .47685 L .79455 .47593 L F
.5981 .47999 m .59944 .4777 L .60083 .4792 L 0 .029 .129 r
F
.5981 .47999 m .5967 .47851 L .59944 .4777 L F
.29065 .47857 m .29156 .47608 L .29323 .47767 L 0 .026 .125 r
F
.29065 .47857 m .28897 .47699 L .29156 .47608 L F
.43752 .47977 m .43863 .47745 L .44017 .47905 L 0 .029 .129 r
F
.43752 .47977 m .43597 .47818 L .43863 .47745 L F
.65024 .47958 m .65166 .47733 L .653 .47876 L 0 .028 .128 r
F
.65024 .47958 m .6489 .47814 L .65166 .47733 L F
.32907 .47883 m .33004 .47639 L .33168 .47797 L 0 .027 .126 r
F
.32907 .47883 m .32743 .47727 L .33004 .47639 L F
.6571 .47928 m .65852 .4769 L .65986 .47836 L 0 .028 .127 r
F
.6571 .47928 m .65576 .47783 L .65852 .4769 L F
.70239 .4791 m .70388 .47673 L .70518 .47831 L 0 .027 .127 r
F
.70239 .4791 m .70109 .47752 L .70388 .47673 L F
.60496 .47991 m .60631 .4776 L .6077 .47913 L 0 .029 .129 r
F
.60496 .47991 m .60357 .4784 L .60631 .4776 L F
.3675 .47916 m .36851 .47692 L .37012 .4784 L 0 .028 .127 r
F
.3675 .47916 m .36589 .47769 L .36851 .47692 L F
.75454 .47861 m .7561 .4762 L .75735 .47777 L 0 .026 .125 r
F
.75454 .47861 m .75328 .47702 L .7561 .4762 L F
.54596 .4809 m .54722 .47838 L .54867 .48003 L 0 .031 .132 r
F
.54596 .4809 m .54451 .47923 L .54722 .47838 L F
.46909 .48052 m .47025 .47827 L .47176 .47969 L 0 .031 .131 r
F
.46909 .48052 m .46757 .47908 L .47025 .47827 L F
.51438 .48033 m .5156 .47801 L .51707 .47946 L 0 .03 .13 r
F
.51438 .48033 m .51291 .47888 L .5156 .47801 L F
.50752 .48071 m .50874 .47828 L .51021 .4798 L 0 .031 .131 r
F
.50752 .48071 m .50605 .47919 L .50874 .47828 L F
.33592 .47864 m .3369 .47613 L .33853 .47774 L 0 .026 .125 r
F
.33592 .47864 m .33429 .47705 L .3369 .47613 L F
.29748 .47847 m .2984 .4761 L .30006 .47773 L F
.29748 .47847 m .29582 .47683 L .2984 .4761 L F
.39907 .47982 m .40014 .47734 L .40171 .47893 L 0 .029 .129 r
F
.39907 .47982 m .3975 .47821 L .40014 .47734 L F
.66396 .47908 m .66539 .47655 L .66673 .4782 L 0 .027 .127 r
F
.66396 .47908 m .66262 .47746 L .66539 .47655 L F
.52123 .48006 m .52247 .47779 L .52393 .47922 L 0 .03 .13 r
F
.52123 .48006 m .51977 .47863 L .52247 .47779 L F
.70926 .47902 m .71075 .47649 L .71204 .47809 L 0 .027 .127 r
F
.70926 .47902 m .70796 .47744 L .71075 .47649 L F
.47594 .48035 m .47711 .47797 L .47862 .4795 L 0 .03 .131 r
F
.47594 .48035 m .47443 .47883 L .47711 .47797 L F
.34276 .47847 m .34374 .47611 L .34537 .47773 L 0 .026 .125 r
F
.34276 .47847 m .34114 .47687 L .34374 .47611 L F
.61182 .4798 m .61318 .47754 L .61456 .47902 L 0 .029 .129 r
F
.61182 .4798 m .61044 .47834 L .61318 .47754 L F
.40592 .47962 m .40699 .47723 L .40856 .47879 L F
.40592 .47962 m .40435 .47804 L .40699 .47723 L F
.76141 .47848 m .76298 .47604 L .76422 .47759 L 0 .026 .125 r
F
.76141 .47848 m .76016 .47693 L .76298 .47604 L F
.44436 .47982 m .44548 .47756 L .44702 .47909 L 0 .03 .13 r
F
.44436 .47982 m .44282 .47831 L .44548 .47756 L F
.55282 .48079 m .55409 .47836 L .55553 .47997 L 0 .031 .132 r
F
.55282 .48079 m .55138 .47916 L .55409 .47836 L F
.37434 .4791 m .37536 .47682 L .37696 .47832 L 0 .028 .127 r
F
.37434 .4791 m .37274 .47761 L .37536 .47682 L F
.71612 .47874 m .71762 .47625 L .71891 .47784 L 0 .027 .126 r
F
.71612 .47874 m .71483 .47716 L .71762 .47625 L F
.4828 .48012 m .48398 .47763 L .48548 .47918 L 0 .03 .13 r
F
.4828 .48012 m .48129 .47857 L .48398 .47763 L F
.62553 .47917 m .62691 .47679 L .62828 .47824 L 0 .028 .128 r
F
.62553 .47917 m .62417 .47771 L .62691 .47679 L F
.67083 .47898 m .67227 .47646 L .6736 .47812 L 0 .027 .127 r
F
.67083 .47898 m .66949 .47731 L .67227 .47646 L F
.76827 .47824 m .76985 .47581 L .77109 .47737 L 0 .026 .125 r
F
.76827 .47824 m .76704 .4767 L .76985 .47581 L F
.61868 .47958 m .62005 .47721 L .62142 .47864 L 0 .029 .129 r
F
.61868 .47958 m .61731 .47813 L .62005 .47721 L F
.55967 .48057 m .56096 .47831 L .56239 .47973 L 0 .031 .132 r
F
.55967 .48057 m .55824 .47914 L .56096 .47831 L F
.52809 .48 m .52933 .47772 L .53079 .47926 L 0 .03 .13 r
F
.52809 .48 m .52663 .47847 L .52933 .47772 L F
.48965 .47984 m .49084 .47757 L .49233 .47908 L F
.48965 .47984 m .48816 .47831 L .49084 .47757 L F
.63239 .47892 m .63378 .47645 L .63515 .47807 L 0 .027 .127 r
F
.63239 .47892 m .63103 .4773 L .63378 .47645 L F
.72299 .47855 m .7245 .47607 L .72578 .47767 L 0 .027 .126 r
F
.72299 .47855 m .7217 .47695 L .7245 .47607 L F
.56653 .48028 m .56783 .47808 L .56925 .47948 L 0 .031 .131 r
F
.56653 .48028 m .56511 .47891 L .56783 .47808 L F
.41277 .47954 m .41385 .47713 L .41541 .4787 L 0 .029 .129 r
F
.41277 .47954 m .41121 .47796 L .41385 .47713 L F
.38118 .47898 m .38222 .47664 L .38381 .47813 L 0 .028 .127 r
F
.38118 .47898 m .37959 .47749 L .38222 .47664 L F
.3043 .47862 m .30524 .47613 L .30689 .47775 L 0 .027 .126 r
F
.3043 .47862 m .30264 .477 L .30524 .47613 L F
.6777 .47886 m .67915 .47638 L .68047 .47797 L 0 .027 .127 r
F
.6777 .47886 m .67637 .47725 L .67915 .47638 L F
.77515 .47812 m .77674 .47571 L .77798 .47731 L 0 .026 .125 r
F
.77515 .47812 m .77391 .47654 L .77674 .47571 L F
.57339 .48005 m .5747 .47777 L .57611 .47922 L 0 .031 .131 r
F
.57339 .48005 m .57197 .47863 L .5747 .47777 L F
.72986 .47837 m .73138 .4759 L .73265 .47747 L 0 .026 .126 r
F
.72986 .47837 m .72858 .47679 L .73138 .4759 L F
.45121 .47992 m .45234 .47754 L .45387 .47911 L 0 .03 .13 r
F
.45121 .47992 m .44968 .47836 L .45234 .47754 L F
.68456 .47858 m .68602 .47617 L .68733 .47767 L 0 .027 .126 r
F
.68456 .47858 m .68324 .47707 L .68602 .47617 L F
.34959 .4786 m .35059 .47614 L .3522 .47777 L F
.34959 .4786 m .34797 .47698 L .35059 .47614 L F
.38803 .47879 m .38907 .47661 L .39066 .4781 L 0 .028 .128 r
F
.38803 .47879 m .38644 .47731 L .38907 .47661 L F
.31114 .47846 m .31209 .47594 L .31374 .47756 L 0 .027 .126 r
F
.31114 .47846 m .30949 .47684 L .31209 .47594 L F
.41962 .47944 m .42071 .47706 L .42226 .47862 L 0 .029 .129 r
F
.41962 .47944 m .41806 .47788 L .42071 .47706 L F
.73672 .47812 m .73825 .47562 L .73952 .47718 L 0 .026 .125 r
F
.73672 .47812 m .73545 .47655 L .73825 .47562 L F
.69142 .47833 m .6929 .47602 L .69421 .47753 L 0 .027 .126 r
F
.69142 .47833 m .69011 .47683 L .6929 .47602 L F
.4965 .47986 m .4977 .47755 L .49919 .47911 L 0 .03 .13 r
F
.4965 .47986 m .49501 .47832 L .4977 .47755 L F
.63926 .47891 m .64066 .47653 L .64202 .47815 L 0 .028 .128 r
F
.63926 .47891 m .6379 .4773 L .64066 .47653 L F
.53495 .48006 m .5362 .47768 L .53765 .47925 L 0 .031 .131 r
F
.53495 .48006 m .53349 .4785 L .5362 .47768 L F
.74358 .47781 m .74513 .47545 L .74639 .47702 L 0 .026 .125 r
F
.74358 .47781 m .74232 .47626 L .74513 .47545 L F
.78203 .47804 m .78362 .47548 L .78485 .4771 L F
.78203 .47804 m .7808 .47642 L .78362 .47548 L F
.58025 .47996 m .58157 .47753 L .58298 .47908 L 0 .03 .131 r
F
.58025 .47996 m .57884 .47838 L .58157 .47753 L F
.42647 .47923 m .42757 .47673 L .42912 .47827 L 0 .029 .128 r
F
.42647 .47923 m .42492 .4777 L .42757 .47673 L F
.45806 .47984 m .4592 .47749 L .46072 .47905 L 0 .03 .131 r
F
.45806 .47984 m .45653 .47828 L .4592 .47749 L F
.31799 .47832 m .31893 .47589 L .32058 .47746 L 0 .027 .126 r
F
.31799 .47832 m .31634 .47673 L .31893 .47589 L F
.35643 .47851 m .35744 .476 L .35905 .47764 L F
.35643 .47851 m .35482 .47688 L .35744 .476 L F
.7889 .47777 m .79049 .47523 L .79172 .47685 L 0 .026 .124 r
F
.7889 .47777 m .78767 .47615 L .79049 .47523 L F
.43332 .47892 m .43443 .4766 L .43597 .47818 L 0 .028 .128 r
F
.43332 .47892 m .43178 .47734 L .43443 .4766 L F
.58711 .47971 m .58844 .47734 L .58984 .47882 L 0 .03 .13 r
F
.58711 .47971 m .5857 .47819 L .58844 .47734 L F
.59397 .47941 m .59531 .47707 L .5967 .47851 L F
.59397 .47941 m .59257 .47794 L .59531 .47707 L F
.28639 .4779 m .28729 .47549 L .28897 .47699 L 0 .026 .125 r
F
.28639 .4779 m .2847 .47639 L .28729 .47549 L F
.6983 .47831 m .69978 .47595 L .70109 .47752 L 0 .027 .126 r
F
.6983 .47831 m .69699 .47674 L .69978 .47595 L F
.79577 .47756 m .79738 .47503 L .7986 .47666 L 0 .025 .124 r
F
.79577 .47756 m .79455 .47593 L .79738 .47503 L F
.32483 .47814 m .32579 .47572 L .32743 .47727 L 0 .027 .126 r
F
.32483 .47814 m .32319 .4766 L .32579 .47572 L F
.64613 .47891 m .64755 .47662 L .6489 .47814 L 0 .029 .128 r
F
.64613 .47891 m .64478 .47739 L .64755 .47662 L F
.54181 .48006 m .54307 .47763 L .54451 .47923 L 0 .031 .131 r
F
.54181 .48006 m .54036 .47845 L .54307 .47763 L F
.75047 .47783 m .75202 .47542 L .75328 .47702 L 0 .026 .125 r
F
.75047 .47783 m .74921 .47622 L .75202 .47542 L F
.36328 .47842 m .36428 .4762 L .36589 .47769 L 0 .028 .127 r
F
.36328 .47842 m .36166 .47692 L .36428 .4762 L F
.50336 .47995 m .50457 .47759 L .50605 .47919 L 0 .031 .131 r
F
.50336 .47995 m .50188 .47837 L .50457 .47759 L F
.29323 .47767 m .29415 .47524 L .29582 .47683 L 0 .026 .125 r
F
.29323 .47767 m .29156 .47608 L .29415 .47524 L F
.60083 .4792 m .60218 .47689 L .60357 .4784 L 0 .029 .129 r
F
.60083 .4792 m .59944 .4777 L .60218 .47689 L F
.39487 .47901 m .39592 .47662 L .3975 .47821 L F
.39487 .47901 m .39329 .47741 L .39592 .47662 L F
.46491 .47982 m .46606 .47765 L .46757 .47908 L 0 .031 .131 r
F
.46491 .47982 m .46339 .47835 L .46606 .47765 L F
.33168 .47797 m .33265 .47546 L .33429 .47705 L 0 .026 .126 r
F
.33168 .47797 m .33004 .47639 L .33265 .47546 L F
.65986 .47836 m .66129 .47598 L .66262 .47746 L 0 .028 .127 r
F
.65986 .47836 m .65852 .4769 L .66129 .47598 L F
.653 .47876 m .65442 .47638 L .65576 .47783 L 0 .028 .128 r
F
.653 .47876 m .65166 .47733 L .65442 .47638 L F
.51021 .4798 m .51143 .47736 L .51291 .47888 L 0 .031 .131 r
F
.51021 .4798 m .50874 .47828 L .51143 .47736 L F
.44017 .47905 m .44129 .4767 L .44282 .47831 L 0 .029 .129 r
F
.44017 .47905 m .43863 .47745 L .44129 .4767 L F
.33853 .47774 m .33951 .47525 L .34114 .47687 L 0 .026 .125 r
F
.33853 .47774 m .3369 .47613 L .33951 .47525 L F
.70518 .47831 m .70666 .47585 L .70796 .47744 L 0 .027 .127 r
F
.70518 .47831 m .70388 .47673 L .70666 .47585 L F
.54867 .48003 m .54994 .47753 L .55138 .47916 L 0 .031 .132 r
F
.54867 .48003 m .54722 .47838 L .54994 .47753 L F
.51707 .47946 m .5183 .47719 L .51977 .47863 L 0 .03 .13 r
F
.51707 .47946 m .5156 .47801 L .5183 .47719 L F
.75735 .47777 m .75891 .47537 L .76016 .47693 L 0 .026 .125 r
F
.75735 .47777 m .7561 .4762 L .75891 .47537 L F
.40171 .47893 m .40278 .47647 L .40435 .47804 L 0 .029 .129 r
F
.40171 .47893 m .40014 .47734 L .40278 .47647 L F
.47176 .47969 m .47292 .47741 L .47443 .47883 L 0 .031 .131 r
F
.47176 .47969 m .47025 .47827 L .47292 .47741 L F
.6077 .47913 m .60905 .47678 L .61044 .47834 L 0 .029 .129 r
F
.6077 .47913 m .60631 .4776 L .60905 .47678 L F
.66673 .4782 m .66816 .47565 L .66949 .47731 L 0 .027 .126 r
F
.66673 .4782 m .66539 .47655 L .66816 .47565 L F
.37012 .4784 m .37113 .47611 L .37274 .47761 L 0 .028 .128 r
F
.37012 .4784 m .36851 .47692 L .37113 .47611 L F
.52393 .47922 m .52517 .47701 L .52663 .47847 L 0 .03 .13 r
F
.52393 .47922 m .52247 .47779 L .52517 .47701 L F
.71204 .47809 m .71354 .47554 L .71483 .47716 L 0 .027 .126 r
F
.71204 .47809 m .71075 .47649 L .71354 .47554 L F
.30006 .47773 m .30098 .47537 L .30264 .477 L F
.30006 .47773 m .2984 .4761 L .30098 .47537 L F
.76422 .47759 m .76579 .47513 L .76704 .4767 L 0 .026 .125 r
F
.76422 .47759 m .76298 .47604 L .76579 .47513 L F
.47862 .4795 m .47979 .47705 L .48129 .47857 L 0 .03 .131 r
F
.47862 .4795 m .47711 .47797 L .47979 .47705 L F
.40856 .47879 m .40964 .47644 L .41121 .47796 L 0 .029 .129 r
F
.40856 .47879 m .40699 .47723 L .40964 .47644 L F
.48548 .47918 m .48666 .47678 L .48816 .47831 L 0 .03 .13 r
F
.48548 .47918 m .48398 .47763 L .48666 .47678 L F
.71891 .47784 m .72042 .47535 L .7217 .47695 L 0 .027 .126 r
F
.71891 .47784 m .71762 .47625 L .72042 .47535 L F
.62828 .47824 m .62967 .47586 L .63103 .4773 L 0 .028 .127 r
F
.62828 .47824 m .62691 .47679 L .62967 .47586 L F
.55553 .47997 m .55681 .47756 L .55824 .47914 L 0 .032 .132 r
F
.55553 .47997 m .55409 .47836 L .55681 .47756 L F
.61456 .47902 m .61593 .47666 L .61731 .47813 L 0 .03 .13 r
F
.61456 .47902 m .61318 .47754 L .61593 .47666 L F
.62142 .47864 m .6228 .47629 L .62417 .47771 L 0 .029 .128 r
F
.62142 .47864 m .62005 .47721 L .6228 .47629 L F
.34537 .47773 m .34635 .47535 L .34797 .47698 L 0 .027 .126 r
F
.34537 .47773 m .34374 .47611 L .34635 .47535 L F
.6736 .47812 m .67504 .47561 L .67637 .47725 L 0 .027 .127 r
F
.6736 .47812 m .67227 .47646 L .67504 .47561 L F
.37696 .47832 m .37799 .47598 L .37959 .47749 L 0 .028 .128 r
F
.37696 .47832 m .37536 .47682 L .37799 .47598 L F
.77109 .47737 m .77268 .47496 L .77391 .47654 L 0 .026 .125 r
F
.77109 .47737 m .76985 .47581 L .77268 .47496 L F
.44702 .47909 m .44814 .4768 L .44968 .47836 L 0 .03 .13 r
F
.44702 .47909 m .44548 .47756 L .44814 .4768 L F
.56239 .47973 m .56368 .47746 L .56511 .47891 L 0 .031 .132 r
F
.56239 .47973 m .56096 .47831 L .56368 .47746 L F
.72578 .47767 m .7273 .4752 L .72858 .47679 L 0 .027 .126 r
F
.72578 .47767 m .7245 .47607 L .7273 .4752 L F
.63515 .47807 m .63654 .47568 L .6379 .4773 L 0 .028 .127 r
F
.63515 .47807 m .63378 .47645 L .63654 .47568 L F
.53079 .47926 m .53204 .47694 L .53349 .4785 L 0 .03 .131 r
F
.53079 .47926 m .52933 .47772 L .53204 .47694 L F
.41541 .4787 m .4165 .47631 L .41806 .47788 L 0 .029 .129 r
F
.41541 .4787 m .41385 .47713 L .4165 .47631 L F
.49233 .47908 m .49352 .47682 L .49501 .47832 L 0 .03 .13 r
F
.49233 .47908 m .49084 .47757 L .49352 .47682 L F
.30689 .47775 m .30783 .47523 L .30949 .47684 L 0 .027 .126 r
F
.30689 .47775 m .30524 .47613 L .30783 .47523 L F
.38381 .47813 m .38485 .47583 L .38644 .47731 L 0 .028 .127 r
F
.38381 .47813 m .38222 .47664 L .38485 .47583 L F
.56925 .47948 m .57055 .47721 L .57197 .47863 L 0 .031 .131 r
F
.56925 .47948 m .56783 .47808 L .57055 .47721 L F
.68047 .47797 m .68192 .4755 L .68324 .47707 L 0 .027 .127 r
F
.68047 .47797 m .67915 .47638 L .68192 .4755 L F
.73265 .47747 m .73418 .47499 L .73545 .47655 L 0 .026 .125 r
F
.73265 .47747 m .73138 .4759 L .73418 .47499 L F
.68733 .47767 m .6888 .47533 L .69011 .47683 L 0 .027 .126 r
F
.68733 .47767 m .68602 .47617 L .6888 .47533 L F
.77798 .47731 m .77956 .47481 L .7808 .47642 L 0 .026 .125 r
F
.77798 .47731 m .77674 .47571 L .77956 .47481 L F
.57611 .47922 m .57742 .47692 L .57884 .47838 L 0 .031 .131 r
F
.57611 .47922 m .5747 .47777 L .57742 .47692 L F
.31374 .47756 m .31468 .47513 L .31634 .47673 L 0 .027 .126 r
F
.31374 .47756 m .31209 .47594 L .31468 .47513 L F
.73952 .47718 m .74105 .47469 L .74232 .47626 L 0 .026 .125 r
F
.73952 .47718 m .73825 .47562 L .74105 .47469 L F
.3522 .47777 m .3532 .47524 L .35482 .47688 L 0 .027 .126 r
F
.3522 .47777 m .35059 .47614 L .3532 .47524 L F
.45387 .47911 m .45501 .47671 L .45653 .47828 L 0 .03 .13 r
F
.45387 .47911 m .45234 .47754 L .45501 .47671 L F
.78485 .4771 m .78644 .47454 L .78767 .47615 L 0 .026 .124 r
F
.78485 .4771 m .78362 .47548 L .78644 .47454 L F
.42226 .47862 m .42336 .47615 L .42492 .4777 L 0 .029 .129 r
F
.42226 .47862 m .42071 .47706 L .42336 .47615 L F
.42912 .47827 m .43023 .47579 L .43178 .47734 L 0 .028 .128 r
F
.42912 .47827 m .42757 .47673 L .43023 .47579 L F
.39066 .4781 m .3917 .47591 L .39329 .47741 L F
.39066 .4781 m .38907 .47661 L .3917 .47591 L F
.69421 .47753 m .69569 .47522 L .69699 .47674 L 0 .027 .126 r
F
.69421 .47753 m .6929 .47602 L .69569 .47522 L F
.53765 .47925 m .53891 .47685 L .54036 .47845 L 0 .031 .131 r
F
.53765 .47925 m .5362 .47768 L .53891 .47685 L F
.58298 .47908 m .5843 .47668 L .5857 .47819 L 0 .03 .13 r
F
.58298 .47908 m .58157 .47753 L .5843 .47668 L F
.64202 .47815 m .64343 .47576 L .64478 .47739 L 0 .028 .128 r
F
.64202 .47815 m .64066 .47653 L .64343 .47576 L F
.74639 .47702 m .74795 .47464 L .74921 .47622 L 0 .026 .125 r
F
.74639 .47702 m .74513 .47545 L .74795 .47464 L F
.49919 .47911 m .50039 .47679 L .50188 .47837 L 0 .031 .131 r
F
.49919 .47911 m .4977 .47755 L .50039 .47679 L F
.79172 .47685 m .79332 .4743 L .79455 .47593 L 0 .025 .124 r
F
.79172 .47685 m .79049 .47523 L .79332 .4743 L F
.35905 .47764 m .36005 .47528 L .36166 .47692 L 0 .027 .127 r
F
.35905 .47764 m .35744 .476 L .36005 .47528 L F
.32058 .47746 m .32154 .47504 L .32319 .4766 L 0 .027 .126 r
F
.32058 .47746 m .31893 .47589 L .32154 .47504 L F
.58984 .47882 m .59117 .4765 L .59257 .47794 L 0 .03 .13 r
F
.58984 .47882 m .58844 .47734 L .59117 .4765 L F
.46072 .47905 m .46187 .47681 L .46339 .47835 L 0 .031 .131 r
F
.46072 .47905 m .4592 .47749 L .46187 .47681 L F
.5967 .47851 m .59804 .47623 L .59944 .4777 L 0 .03 .13 r
F
.5967 .47851 m .59531 .47707 L .59804 .47623 L F
.28897 .47699 m .28988 .47458 L .29156 .47608 L 0 .026 .125 r
F
.28897 .47699 m .28729 .47549 L .28988 .47458 L F
.7986 .47666 m .80021 .47419 L .80143 .4758 L 0 .025 .124 r
F
.7986 .47666 m .79738 .47503 L .80021 .47419 L F
.43597 .47818 m .43709 .47585 L .43863 .47745 L 0 .029 .129 r
F
.43597 .47818 m .43443 .4766 L .43709 .47585 L F
.32743 .47727 m .3284 .47484 L .33004 .47639 L 0 .027 .126 r
F
.32743 .47727 m .32579 .47572 L .3284 .47484 L F
.70109 .47752 m .70257 .47516 L .70388 .47673 L 0 .027 .127 r
F
.70109 .47752 m .69978 .47595 L .70257 .47516 L F
.54451 .47923 m .54578 .47682 L .54722 .47838 L 0 .031 .131 r
F
.54451 .47923 m .54307 .47763 L .54578 .47682 L F
.6489 .47814 m .65031 .47581 L .65166 .47733 L 0 .029 .129 r
F
.6489 .47814 m .64755 .47662 L .65031 .47581 L F
.29582 .47683 m .29673 .47452 L .2984 .4761 L 0 .026 .125 r
F
.29582 .47683 m .29415 .47524 L .29673 .47452 L F
.75328 .47702 m .75484 .47462 L .7561 .4762 L F
.75328 .47702 m .75202 .47542 L .75484 .47462 L F
.33429 .47705 m .33526 .47452 L .3369 .47613 L F
.33429 .47705 m .33265 .47546 L .33526 .47452 L F
.60357 .4784 m .60492 .47606 L .60631 .4776 L 0 .029 .129 r
F
.60357 .4784 m .60218 .47689 L .60492 .47606 L F
.65576 .47783 m .65718 .47544 L .65852 .4769 L 0 .028 .128 r
F
.65576 .47783 m .65442 .47638 L .65718 .47544 L F
.3975 .47821 m .39856 .47576 L .40014 .47734 L 0 .029 .129 r
F
.3975 .47821 m .39592 .47662 L .39856 .47576 L F
.66262 .47746 m .66406 .47506 L .66539 .47655 L 0 .027 .127 r
F
.66262 .47746 m .66129 .47598 L .66406 .47506 L F
.50605 .47919 m .50726 .47667 L .50874 .47828 L 0 .031 .131 r
F
.50605 .47919 m .50457 .47759 L .50726 .47667 L F
.36589 .47769 m .3669 .47544 L .36851 .47692 L 0 .028 .128 r
F
.36589 .47769 m .36428 .4762 L .3669 .47544 L F
.51291 .47888 m .51413 .47649 L .5156 .47801 L 0 .031 .131 r
F
.51291 .47888 m .51143 .47736 L .51413 .47649 L F
.46757 .47908 m .46873 .47685 L .47025 .47827 L 0 .031 .132 r
F
.46757 .47908 m .46606 .47765 L .46873 .47685 L F
.70796 .47744 m .70945 .47489 L .71075 .47649 L 0 .027 .127 r
F
.70796 .47744 m .70666 .47585 L .70945 .47489 L F
.34114 .47687 m .34212 .47448 L .34374 .47611 L 0 .026 .125 r
F
.34114 .47687 m .33951 .47525 L .34212 .47448 L F
.55138 .47916 m .55265 .47676 L .55409 .47836 L 0 .031 .132 r
F
.55138 .47916 m .54994 .47753 L .55265 .47676 L F
.40435 .47804 m .40542 .47569 L .40699 .47723 L 0 .029 .129 r
F
.40435 .47804 m .40278 .47647 L .40542 .47569 L F
.51977 .47863 m .521 .47636 L .52247 .47779 L 0 .03 .131 r
F
.51977 .47863 m .5183 .47719 L .521 .47636 L F
.47443 .47883 m .4756 .47654 L .47711 .47797 L 0 .031 .131 r
F
.47443 .47883 m .47292 .47741 L .4756 .47654 L F
.66949 .47731 m .67093 .47482 L .67227 .47646 L 0 .027 .126 r
F
.66949 .47731 m .66816 .47565 L .67093 .47482 L F
.76016 .47693 m .76173 .47447 L .76298 .47604 L 0 .026 .125 r
F
.76016 .47693 m .75891 .47537 L .76173 .47447 L F
.71483 .47716 m .71633 .47462 L .71762 .47625 L 0 .027 .126 r
F
.71483 .47716 m .71354 .47554 L .71633 .47462 L F
.44282 .47831 m .44395 .47591 L .44548 .47756 L 0 .03 .13 r
F
.44282 .47831 m .44129 .4767 L .44395 .47591 L F
.61044 .47834 m .6118 .47597 L .61318 .47754 L F
.61044 .47834 m .60905 .47678 L .6118 .47597 L F
.37274 .47761 m .37376 .4753 L .37536 .47682 L 0 .028 .128 r
F
.37274 .47761 m .37113 .47611 L .37376 .4753 L F
.48129 .47857 m .48247 .47612 L .48398 .47763 L 0 .03 .13 r
F
.48129 .47857 m .47979 .47705 L .48247 .47612 L F
.76704 .4767 m .76861 .47423 L .76985 .47581 L 0 .026 .125 r
F
.76704 .4767 m .76579 .47513 L .76861 .47423 L F
.63103 .4773 m .63242 .47501 L .63378 .47645 L 0 .028 .127 r
F
.63103 .4773 m .62967 .47586 L .63242 .47501 L F
.52663 .47847 m .52787 .47623 L .52933 .47772 L 0 .03 .131 r
F
.52663 .47847 m .52517 .47701 L .52787 .47623 L F
.62417 .47771 m .62555 .47537 L .62691 .47679 L 0 .028 .128 r
F
.62417 .47771 m .6228 .47629 L .62555 .47537 L F
.7217 .47695 m .72321 .47446 L .7245 .47607 L 0 .027 .126 r
F
.7217 .47695 m .72042 .47535 L .72321 .47446 L F
.48816 .47831 m .48934 .47605 L .49084 .47757 L 0 .03 .13 r
F
.48816 .47831 m .48666 .47678 L .48934 .47605 L F
.61731 .47813 m .61868 .47575 L .62005 .47721 L 0 .029 .129 r
F
.61731 .47813 m .61593 .47666 L .61868 .47575 L F
.30264 .477 m .30357 .47452 L .30524 .47613 L 0 .027 .126 r
F
.30264 .477 m .30098 .47537 L .30357 .47452 L F
.41121 .47796 m .41228 .47563 L .41385 .47713 L 0 .029 .129 r
F
.41121 .47796 m .40964 .47644 L .41228 .47563 L F
.55824 .47914 m .55953 .47673 L .56096 .47831 L 0 .032 .132 r
F
.55824 .47914 m .55681 .47756 L .55953 .47673 L F
.67637 .47725 m .67782 .47475 L .67915 .47638 L 0 .027 .127 r
F
.67637 .47725 m .67504 .47561 L .67782 .47475 L F
.37959 .47749 m .38062 .47513 L .38222 .47664 L 0 .028 .128 r
F
.37959 .47749 m .37799 .47598 L .38062 .47513 L F
.77391 .47654 m .7755 .47411 L .77674 .47571 L 0 .026 .125 r
F
.77391 .47654 m .77268 .47496 L .7755 .47411 L F
.72858 .47679 m .7301 .47433 L .73138 .4759 L 0 .027 .126 r
F
.72858 .47679 m .7273 .4752 L .7301 .47433 L F
.34797 .47698 m .34897 .4745 L .35059 .47614 L F
.34797 .47698 m .34635 .47535 L .34897 .4745 L F
.56511 .47891 m .56641 .47661 L .56783 .47808 L 0 .032 .132 r
F
.56511 .47891 m .56368 .47746 L .56641 .47661 L F
.30949 .47684 m .31043 .47435 L .31209 .47594 L 0 .027 .126 r
F
.30949 .47684 m .30783 .47523 L .31043 .47435 L F
.44968 .47836 m .45081 .47597 L .45234 .47754 L 0 .03 .13 r
F
.44968 .47836 m .44814 .4768 L .45081 .47597 L F
.68324 .47707 m .6847 .47461 L .68602 .47617 L 0 .027 .127 r
F
.68324 .47707 m .68192 .4755 L .6847 .47461 L F
.57197 .47863 m .57328 .47633 L .5747 .47777 L 0 .031 .131 r
F
.57197 .47863 m .57055 .47721 L .57328 .47633 L F
.6379 .4773 m .6393 .4749 L .64066 .47653 L 0 .028 .127 r
F
.6379 .4773 m .63654 .47568 L .6393 .4749 L F
.41806 .47788 m .41915 .47549 L .42071 .47706 L 0 .029 .129 r
F
.41806 .47788 m .4165 .47631 L .41915 .47549 L F
.38644 .47731 m .38748 .47512 L .38907 .47661 L 0 .028 .128 r
F
.38644 .47731 m .38485 .47583 L .38748 .47512 L F
.73545 .47655 m .73698 .47407 L .73825 .47562 L 0 .026 .125 r
F
.73545 .47655 m .73418 .47499 L .73698 .47407 L F
.53349 .4785 m .53475 .4761 L .5362 .47768 L 0 .031 .131 r
F
.53349 .4785 m .53204 .47694 L .53475 .4761 L F
.49501 .47832 m .49621 .47605 L .4977 .47755 L 0 .03 .131 r
F
.49501 .47832 m .49352 .47682 L .49621 .47605 L F
.7808 .47642 m .78239 .47388 L .78362 .47548 L 0 .026 .125 r
F
.7808 .47642 m .77956 .47481 L .78239 .47388 L F
.74232 .47626 m .74387 .47387 L .74513 .47545 L F
.74232 .47626 m .74105 .47469 L .74387 .47387 L F
.69011 .47683 m .69159 .47451 L .6929 .47602 L 0 .027 .126 r
F
.69011 .47683 m .6888 .47533 L .69159 .47451 L F
.57884 .47838 m .58016 .47609 L .58157 .47753 L 0 .031 .131 r
F
.57884 .47838 m .57742 .47692 L .58016 .47609 L F
.35482 .47688 m .35583 .47435 L .35744 .476 L 0 .027 .126 r
F
.35482 .47688 m .3532 .47524 L .35583 .47435 L F
.78767 .47615 m .78927 .47361 L .79049 .47523 L 0 .025 .124 r
F
.78767 .47615 m .78644 .47454 L .78927 .47361 L F
.31634 .47673 m .31728 .47432 L .31893 .47589 L 0 .027 .126 r
F
.31634 .47673 m .31468 .47513 L .31728 .47432 L F
.42492 .4777 m .42602 .4752 L .42757 .47673 L 0 .029 .129 r
F
.42492 .4777 m .42336 .47615 L .42602 .4752 L F
.45653 .47828 m .45767 .47591 L .4592 .47749 L 0 .03 .131 r
F
.45653 .47828 m .45501 .47671 L .45767 .47591 L F
.43178 .47734 m .43288 .47504 L .43443 .4766 L 0 .028 .128 r
F
.43178 .47734 m .43023 .47579 L .43288 .47504 L F
.5857 .47819 m .58703 .47585 L .58844 .47734 L 0 .03 .13 r
F
.5857 .47819 m .5843 .47668 L .58703 .47585 L F
.79455 .47593 m .79616 .4734 L .79738 .47503 L 0 .025 .124 r
F
.79455 .47593 m .79332 .4743 L .79616 .4734 L F
.54036 .47845 m .54162 .47606 L .54307 .47763 L 0 .031 .131 r
F
.54036 .47845 m .53891 .47685 L .54162 .47606 L F
.69699 .47674 m .69848 .47442 L .69978 .47595 L 0 .027 .127 r
F
.69699 .47674 m .69569 .47522 L .69848 .47442 L F
.2847 .47639 m .2856 .47398 L .28729 .47549 L 0 .026 .125 r
F
.2847 .47639 m .28301 .47489 L .2856 .47398 L F
.32319 .4766 m .32414 .47417 L .32579 .47572 L 0 .027 .126 r
F
.32319 .4766 m .32154 .47504 L .32414 .47417 L F
.74921 .47622 m .75076 .47383 L .75202 .47542 L 0 .026 .125 r
F
.74921 .47622 m .74795 .47464 L .75076 .47383 L F
.59257 .47794 m .59391 .47566 L .59531 .47707 L 0 .03 .13 r
F
.59257 .47794 m .59117 .4765 L .59391 .47566 L F
.64478 .47739 m .64619 .47499 L .64755 .47662 L 0 .029 .128 r
F
.64478 .47739 m .64343 .47576 L .64619 .47499 L F
.39329 .47741 m .39434 .4751 L .39592 .47662 L 0 .029 .129 r
F
.39329 .47741 m .3917 .47591 L .39434 .4751 L F
.50188 .47837 m .50308 .47599 L .50457 .47759 L 0 .031 .131 r
F
.50188 .47837 m .50039 .47679 L .50308 .47599 L F
.29156 .47608 m .29247 .47374 L .29415 .47524 L 0 .026 .125 r
F
.29156 .47608 m .28988 .47458 L .29247 .47374 L F
.36166 .47692 m .36267 .47456 L .36428 .4762 L 0 .028 .127 r
F
.36166 .47692 m .36005 .47528 L .36267 .47456 L F
.59944 .4777 m .60079 .4754 L .60218 .47689 L 0 .03 .13 r
F
.59944 .4777 m .59804 .47623 L .60079 .4754 L F
.80143 .4758 m .80306 .47334 L .80427 .47493 L 0 .025 .124 r
F
.80143 .4758 m .80021 .47419 L .80306 .47334 L F
.33004 .47639 m .33101 .47391 L .33265 .47546 L 0 .026 .126 r
F
.33004 .47639 m .3284 .47484 L .33101 .47391 L F
.46339 .47835 m .46454 .47612 L .46606 .47765 L 0 .031 .132 r
F
.46339 .47835 m .46187 .47681 L .46454 .47612 L F
.54722 .47838 m .5485 .476 L .54994 .47753 L F
.54722 .47838 m .54578 .47682 L .5485 .476 L F
.43863 .47745 m .43975 .47508 L .44129 .4767 L 0 .029 .129 r
F
.43863 .47745 m .43709 .47585 L .43975 .47508 L F
.3369 .47613 m .33788 .47363 L .33951 .47525 L 0 .026 .125 r
F
.3369 .47613 m .33526 .47452 L .33788 .47363 L F
.65852 .4769 m .65995 .4745 L .66129 .47598 L 0 .028 .127 r
F
.65852 .4769 m .65718 .47544 L .65995 .4745 L F
.70388 .47673 m .70537 .47427 L .70666 .47585 L 0 .027 .127 r
F
.70388 .47673 m .70257 .47516 L .70537 .47427 L F
.66539 .47655 m .66683 .47414 L .66816 .47565 L 0 .027 .126 r
F
.66539 .47655 m .66406 .47506 L .66683 .47414 L F
.50874 .47828 m .50996 .47575 L .51143 .47736 L 0 .031 .131 r
F
.50874 .47828 m .50726 .47667 L .50996 .47575 L F
.65166 .47733 m .65308 .47486 L .65442 .47638 L 0 .029 .129 r
F
.65166 .47733 m .65031 .47581 L .65308 .47486 L F
.7561 .4762 m .75766 .47381 L .75891 .47537 L 0 .026 .125 r
F
.7561 .4762 m .75484 .47462 L .75766 .47381 L F
.40014 .47734 m .4012 .47489 L .40278 .47647 L 0 .029 .129 r
F
.40014 .47734 m .39856 .47576 L .4012 .47489 L F
.60631 .4776 m .60766 .47523 L .60905 .47678 L 0 .03 .13 r
F
.60631 .4776 m .60492 .47606 L .60766 .47523 L F
.2984 .4761 m .29931 .47379 L .30098 .47537 L 0 .026 .126 r
F
.2984 .4761 m .29673 .47452 L .29931 .47379 L F
.71075 .47649 m .71224 .47392 L .71354 .47554 L 0 .027 .126 r
F
.71075 .47649 m .70945 .47489 L .71224 .47392 L F
.5156 .47801 m .51683 .47567 L .5183 .47719 L 0 .031 .131 r
F
.5156 .47801 m .51413 .47649 L .51683 .47567 L F
.36851 .47692 m .36952 .47461 L .37113 .47611 L 0 .028 .128 r
F
.36851 .47692 m .3669 .47544 L .36952 .47461 L F
.47025 .47827 m .47141 .47598 L .47292 .47741 L 0 .031 .132 r
F
.47025 .47827 m .46873 .47685 L .47141 .47598 L F
.76298 .47604 m .76455 .47355 L .76579 .47513 L 0 .026 .125 r
F
.76298 .47604 m .76173 .47447 L .76455 .47355 L F
.71762 .47625 m .71912 .4737 L .72042 .47535 L 0 .027 .126 r
F
.71762 .47625 m .71633 .47462 L .71912 .4737 L F
.47711 .47797 m .47828 .47563 L .47979 .47705 L 0 .031 .131 r
F
.47711 .47797 m .4756 .47654 L .47828 .47563 L F
.52247 .47779 m .5237 .47555 L .52517 .47701 L 0 .03 .131 r
F
.52247 .47779 m .521 .47636 L .5237 .47555 L F
.55409 .47836 m .55537 .47599 L .55681 .47756 L 0 .032 .132 r
F
.55409 .47836 m .55265 .47676 L .55537 .47599 L F
.67227 .47646 m .67371 .47398 L .67504 .47561 L 0 .027 .126 r
F
.67227 .47646 m .67093 .47482 L .67371 .47398 L F
.40699 .47723 m .40806 .47493 L .40964 .47644 L 0 .029 .129 r
F
.40699 .47723 m .40542 .47569 L .40806 .47493 L F
.48398 .47763 m .48516 .47528 L .48666 .47678 L 0 .03 .13 r
F
.48398 .47763 m .48247 .47612 L .48516 .47528 L F
.34374 .47611 m .34473 .47371 L .34635 .47535 L 0 .027 .126 r
F
.34374 .47611 m .34212 .47448 L .34473 .47371 L F
.76985 .47581 m .77144 .47337 L .77268 .47496 L 0 .026 .125 r
F
.76985 .47581 m .76861 .47423 L .77144 .47337 L F
.61318 .47754 m .61455 .47509 L .61593 .47666 L 0 .03 .13 r
F
.61318 .47754 m .6118 .47597 L .61455 .47509 L F
.62691 .47679 m .6283 .47446 L .62967 .47586 L 0 .028 .128 r
F
.62691 .47679 m .62555 .47537 L .6283 .47446 L F
.44548 .47756 m .44661 .47513 L .44814 .4768 L 0 .03 .13 r
F
.44548 .47756 m .44395 .47591 L .44661 .47513 L F
.37536 .47682 m .37639 .47446 L .37799 .47598 L 0 .028 .128 r
F
.37536 .47682 m .37376 .4753 L .37639 .47446 L F
.62005 .47721 m .62143 .47484 L .6228 .47629 L 0 .029 .129 r
F
.62005 .47721 m .61868 .47575 L .62143 .47484 L F
.7245 .47607 m .72602 .47361 L .7273 .4752 L 0 .027 .126 r
F
.7245 .47607 m .72321 .47446 L .72602 .47361 L F
.63378 .47645 m .63518 .47423 L .63654 .47568 L 0 .028 .127 r
F
.63378 .47645 m .63242 .47501 L .63518 .47423 L F
.30524 .47613 m .30617 .47363 L .30783 .47523 L 0 .027 .126 r
F
.30524 .47613 m .30357 .47452 L .30617 .47363 L F
.41385 .47713 m .41493 .47481 L .4165 .47631 L 0 .029 .129 r
F
.41385 .47713 m .41228 .47563 L .41493 .47481 L F
.67915 .47638 m .6806 .47388 L .68192 .4755 L 0 .027 .127 r
F
.67915 .47638 m .67782 .47475 L .6806 .47388 L F
.52933 .47772 m .53058 .47543 L .53204 .47694 L 0 .031 .131 r
F
.52933 .47772 m .52787 .47623 L .53058 .47543 L F
.56096 .47831 m .56225 .47586 L .56368 .47746 L 0 .032 .132 r
F
.56096 .47831 m .55953 .47673 L .56225 .47586 L F
.49084 .47757 m .49203 .47533 L .49352 .47682 L 0 .03 .131 r
F
.49084 .47757 m .48934 .47605 L .49203 .47533 L F
.38222 .47664 m .38325 .47431 L .38485 .47583 L 0 .028 .128 r
F
.38222 .47664 m .38062 .47513 L .38325 .47431 L F
.77674 .47571 m .77833 .47321 L .77956 .47481 L 0 .026 .125 r
F
.77674 .47571 m .7755 .47411 L .77833 .47321 L F
.73138 .4759 m .73291 .47344 L .73418 .47499 L F
.73138 .4759 m .7301 .47433 L .73291 .47344 L F
.31209 .47594 m .31303 .47357 L .31468 .47513 L 0 .027 .126 r
F
.31209 .47594 m .31043 .47435 L .31303 .47357 L F
.35059 .47614 m .35159 .47359 L .3532 .47524 L F
.35059 .47614 m .34897 .4745 L .35159 .47359 L F
.68602 .47617 m .68749 .47376 L .6888 .47533 L F
.68602 .47617 m .6847 .47461 L .68749 .47376 L F
.56783 .47808 m .56913 .47572 L .57055 .47721 L 0 .032 .132 r
F
.56783 .47808 m .56641 .47661 L .56913 .47572 L F
.73825 .47562 m .73979 .47315 L .74105 .47469 L 0 .026 .125 r
F
.73825 .47562 m .73698 .47407 L .73979 .47315 L F
.45234 .47754 m .45348 .47513 L .45501 .47671 L 0 .03 .13 r
F
.45234 .47754 m .45081 .47597 L .45348 .47513 L F
.78362 .47548 m .78521 .47294 L .78644 .47454 L 0 .026 .124 r
F
.78362 .47548 m .78239 .47388 L .78521 .47294 L F
.5747 .47777 m .57601 .47546 L .57742 .47692 L 0 .031 .131 r
F
.5747 .47777 m .57328 .47633 L .57601 .47546 L F
.42071 .47706 m .4218 .47459 L .42336 .47615 L 0 .029 .129 r
F
.42071 .47706 m .41915 .47549 L .4218 .47459 L F
.64066 .47653 m .64207 .47413 L .64343 .47576 L 0 .028 .128 r
F
.64066 .47653 m .6393 .4749 L .64207 .47413 L F
.5362 .47768 m .53746 .47525 L .53891 .47685 L 0 .031 .131 r
F
.5362 .47768 m .53475 .4761 L .53746 .47525 L F
.42757 .47673 m .42868 .47427 L .43023 .47579 L 0 .028 .128 r
F
.42757 .47673 m .42602 .4752 L .42868 .47427 L F
.79049 .47523 m .7921 .47267 L .79332 .4743 L 0 .025 .124 r
F
.79049 .47523 m .78927 .47361 L .7921 .47267 L F
.35744 .476 m .35844 .47363 L .36005 .47528 L 0 .027 .126 r
F
.35744 .476 m .35583 .47435 L .35844 .47363 L F
.58157 .47753 m .58289 .47526 L .5843 .47668 L 0 .031 .131 r
F
.58157 .47753 m .58016 .47609 L .58289 .47526 L F
.74513 .47545 m .74668 .47305 L .74795 .47464 L 0 .026 .125 r
F
.74513 .47545 m .74387 .47387 L .74668 .47305 L F
.6929 .47602 m .69438 .47369 L .69569 .47522 L 0 .027 .127 r
F
.6929 .47602 m .69159 .47451 L .69438 .47369 L F
.4977 .47755 m .4989 .47527 L .50039 .47679 L 0 .031 .131 r
F
.4977 .47755 m .49621 .47605 L .4989 .47527 L F
.38907 .47661 m .39011 .47441 L .3917 .47591 L 0 .029 .129 r
F
.38907 .47661 m .38748 .47512 L .39011 .47441 L F
.31893 .47589 m .31988 .47348 L .32154 .47504 L 0 .027 .126 r
F
.31893 .47589 m .31728 .47432 L .31988 .47348 L F
.4592 .47749 m .46034 .47522 L .46187 .47681 L 0 .031 .131 r
F
.4592 .47749 m .45767 .47591 L .46034 .47522 L F
.79738 .47503 m .799 .47257 L .80021 .47419 L 0 .025 .124 r
F
.79738 .47503 m .79616 .4734 L .799 .47257 L F
.58844 .47734 m .58977 .47505 L .59117 .4765 L 0 .03 .131 r
F
.58844 .47734 m .58703 .47585 L .58977 .47505 L F
.43443 .4766 m .43554 .4743 L .43709 .47585 L 0 .029 .129 r
F
.43443 .4766 m .43288 .47504 L .43554 .4743 L F
.28729 .47549 m .2882 .47307 L .28988 .47458 L 0 .026 .125 r
F
.28729 .47549 m .2856 .47398 L .2882 .47307 L F
.32579 .47572 m .32675 .47329 L .3284 .47484 L 0 .027 .126 r
F
.32579 .47572 m .32414 .47417 L .32675 .47329 L F
.54307 .47763 m .54433 .47528 L .54578 .47682 L 0 .031 .131 r
F
.54307 .47763 m .54162 .47606 L .54433 .47528 L F
.59531 .47707 m .59665 .47479 L .59804 .47623 L 0 .03 .13 r
F
.59531 .47707 m .59391 .47566 L .59665 .47479 L F
.69978 .47595 m .70127 .47363 L .70257 .47516 L 0 .027 .127 r
F
.69978 .47595 m .69848 .47442 L .70127 .47363 L F
.75202 .47542 m .75358 .47302 L .75484 .47462 L 0 .026 .125 r
F
.75202 .47542 m .75076 .47383 L .75358 .47302 L F
.29415 .47524 m .29505 .473 L .29673 .47452 L F
.29415 .47524 m .29247 .47374 L .29505 .473 L F
.33265 .47546 m .33362 .47298 L .33526 .47452 L F
.33265 .47546 m .33101 .47391 L .33362 .47298 L F
.39592 .47662 m .39698 .47422 L .39856 .47576 L 0 .029 .129 r
F
.39592 .47662 m .39434 .4751 L .39698 .47422 L F
.64755 .47662 m .64896 .47418 L .65031 .47581 L F
.64755 .47662 m .64619 .47499 L .64896 .47418 L F
.50457 .47759 m .50578 .47507 L .50726 .47667 L 0 .031 .131 r
F
.50457 .47759 m .50308 .47599 L .50578 .47507 L F
.80427 .47493 m .8059 .47244 L .8071 .47402 L 0 .025 .124 r
F
.80427 .47493 m .80306 .47334 L .8059 .47244 L F
.60218 .47689 m .60353 .47455 L .60492 .47606 L 0 .03 .13 r
F
.60218 .47689 m .60079 .4754 L .60353 .47455 L F
.66129 .47598 m .66272 .47356 L .66406 .47506 L 0 .028 .127 r
F
.66129 .47598 m .65995 .4745 L .66272 .47356 L F
.65442 .47638 m .65584 .4739 L .65718 .47544 L 0 .028 .128 r
F
.65442 .47638 m .65308 .47486 L .65584 .4739 L F
.54994 .47753 m .55121 .47526 L .55265 .47676 L 0 .031 .132 r
F
.54994 .47753 m .5485 .476 L .55121 .47526 L F
.36428 .4762 m .36529 .47379 L .3669 .47544 L 0 .028 .128 r
F
.36428 .4762 m .36267 .47456 L .36529 .47379 L F
.33951 .47525 m .34049 .47284 L .34212 .47448 L 0 .026 .125 r
F
.33951 .47525 m .33788 .47363 L .34049 .47284 L F
.51143 .47736 m .51265 .47489 L .51413 .47649 L 0 .031 .131 r
F
.51143 .47736 m .50996 .47575 L .51265 .47489 L F
.66816 .47565 m .6696 .47332 L .67093 .47482 L 0 .027 .126 r
F
.66816 .47565 m .66683 .47414 L .6696 .47332 L F
.70666 .47585 m .70815 .47331 L .70945 .47489 L 0 .027 .127 r
F
.70666 .47585 m .70537 .47427 L .70815 .47331 L F
.40278 .47647 m .40385 .47415 L .40542 .47569 L 0 .029 .129 r
F
.40278 .47647 m .4012 .47489 L .40385 .47415 L F
.71354 .47554 m .71503 .47298 L .71633 .47462 L 0 .027 .126 r
F
.71354 .47554 m .71224 .47392 L .71503 .47298 L F
.44129 .4767 m .44241 .47427 L .44395 .47591 L 0 .029 .129 r
F
.44129 .4767 m .43975 .47508 L .44241 .47427 L F
.46606 .47765 m .46721 .47531 L .46873 .47685 L 0 .032 .132 r
F
.46606 .47765 m .46454 .47612 L .46721 .47531 L F
.75891 .47537 m .76048 .4729 L .76173 .47447 L 0 .026 .125 r
F
.75891 .47537 m .75766 .47381 L .76048 .4729 L F
.60905 .47678 m .61041 .47439 L .6118 .47597 L 0 .03 .13 r
F
.60905 .47678 m .60766 .47523 L .61041 .47439 L F
.5183 .47719 m .51953 .47485 L .521 .47636 L 0 .031 .131 r
F
.5183 .47719 m .51683 .47567 L .51953 .47485 L F
.47292 .47741 m .47409 .47511 L .4756 .47654 L 0 .031 .132 r
F
.47292 .47741 m .47141 .47598 L .47409 .47511 L F
.76579 .47513 m .76737 .47264 L .76861 .47423 L 0 .026 .125 r
F
.76579 .47513 m .76455 .47355 L .76737 .47264 L F
.47979 .47705 m .48097 .47472 L .48247 .47612 L 0 .03 .131 r
F
.47979 .47705 m .47828 .47563 L .48097 .47472 L F
.72042 .47535 m .72192 .47281 L .72321 .47446 L 0 .026 .126 r
F
.72042 .47535 m .71912 .4737 L .72192 .47281 L F
.37113 .47611 m .37215 .47379 L .37376 .4753 L 0 .028 .128 r
F
.37113 .47611 m .36952 .47461 L .37215 .47379 L F
.30098 .47537 m .30191 .47293 L .30357 .47452 L 0 .027 .126 r
F
.30098 .47537 m .29931 .47379 L .30191 .47293 L F
.67504 .47561 m .67649 .47314 L .67782 .47475 L F
.67504 .47561 m .67371 .47398 L .67649 .47314 L F
.48666 .47678 m .48784 .47457 L .48934 .47605 L 0 .03 .13 r
F
.48666 .47678 m .48516 .47528 L .48784 .47457 L F
.55681 .47756 m .5581 .47516 L .55953 .47673 L 0 .032 .132 r
F
.55681 .47756 m .55537 .47599 L .5581 .47516 L F
.40964 .47644 m .41071 .47414 L .41228 .47563 L 0 .029 .129 r
F
.40964 .47644 m .40806 .47493 L .41071 .47414 L F
.62967 .47586 m .63106 .47361 L .63242 .47501 L 0 .028 .128 r
F
.62967 .47586 m .6283 .47446 L .63106 .47361 L F
.52517 .47701 m .52641 .47474 L .52787 .47623 L 0 .031 .131 r
F
.52517 .47701 m .5237 .47555 L .52641 .47474 L F
.61593 .47666 m .6173 .47419 L .61868 .47575 L 0 .03 .13 r
F
.61593 .47666 m .61455 .47509 L .6173 .47419 L F
.6228 .47629 m .62418 .47394 L .62555 .47537 L 0 .029 .129 r
F
.6228 .47629 m .62143 .47484 L .62418 .47394 L F
.77268 .47496 m .77426 .47251 L .7755 .47411 L 0 .026 .125 r
F
.77268 .47496 m .77144 .47337 L .77426 .47251 L F
.34635 .47535 m .34734 .47285 L .34897 .4745 L 0 .027 .126 r
F
.34635 .47535 m .34473 .47371 L .34734 .47285 L F
.7273 .4752 m .72882 .47276 L .7301 .47433 L F
.7273 .4752 m .72602 .47361 L .72882 .47276 L F
.37799 .47598 m .37902 .4736 L .38062 .47513 L 0 .028 .128 r
F
.37799 .47598 m .37639 .47446 L .37902 .4736 L F
.30783 .47523 m .30877 .47275 L .31043 .47435 L 0 .027 .126 r
F
.30783 .47523 m .30617 .47363 L .30877 .47275 L F
.44814 .4768 m .44928 .4743 L .45081 .47597 L 0 .03 .13 r
F
.44814 .4768 m .44661 .47513 L .44928 .4743 L F
.63654 .47568 m .63794 .47344 L .6393 .4749 L 0 .028 .128 r
F
.63654 .47568 m .63518 .47423 L .63794 .47344 L F
.68192 .4755 m .68338 .47301 L .6847 .47461 L 0 .027 .127 r
F
.68192 .4755 m .6806 .47388 L .68338 .47301 L F
.4165 .47631 m .41758 .474 L .41915 .47549 L 0 .029 .129 r
F
.4165 .47631 m .41493 .47481 L .41758 .474 L F
.56368 .47746 m .56498 .47499 L .56641 .47661 L 0 .032 .132 r
F
.56368 .47746 m .56225 .47586 L .56498 .47499 L F
.73418 .47499 m .73571 .47253 L .73698 .47407 L 0 .026 .125 r
F
.73418 .47499 m .73291 .47344 L .73571 .47253 L F
.77956 .47481 m .78115 .47227 L .78239 .47388 L F
.77956 .47481 m .77833 .47321 L .78115 .47227 L F
.53204 .47694 m .53329 .47456 L .53475 .4761 L 0 .031 .131 r
F
.53204 .47694 m .53058 .47543 L .53329 .47456 L F
.3532 .47524 m .35421 .4727 L .35583 .47435 L 0 .027 .126 r
F
.3532 .47524 m .35159 .47359 L .35421 .4727 L F
.38485 .47583 m .38588 .47359 L .38748 .47512 L 0 .029 .128 r
F
.38485 .47583 m .38325 .47431 L .38588 .47359 L F
.74105 .47469 m .7426 .47232 L .74387 .47387 L 0 .026 .125 r
F
.74105 .47469 m .73979 .47315 L .7426 .47232 L F
.49352 .47682 m .49472 .47456 L .49621 .47605 L 0 .031 .131 r
F
.49352 .47682 m .49203 .47533 L .49472 .47456 L F
.78644 .47454 m .78804 .472 L .78927 .47361 L 0 .025 .124 r
F
.78644 .47454 m .78521 .47294 L .78804 .472 L F
.57055 .47721 m .57186 .47481 L .57328 .47633 L 0 .031 .132 r
F
.57055 .47721 m .56913 .47572 L .57186 .47481 L F
.31468 .47513 m .31562 .47279 L .31728 .47432 L 0 .027 .126 r
F
.31468 .47513 m .31303 .47357 L .31562 .47279 L F
.6888 .47533 m .69028 .47292 L .69159 .47451 L 0 .027 .127 r
F
.6888 .47533 m .68749 .47376 L .69028 .47292 L F
.45501 .47671 m .45615 .47432 L .45767 .47591 L 0 .03 .131 r
F
.45501 .47671 m .45348 .47513 L .45615 .47432 L F
.42336 .47615 m .42446 .47366 L .42602 .4752 L 0 .029 .129 r
F
.42336 .47615 m .4218 .47459 L .42446 .47366 L F
.57742 .47692 m .57874 .47465 L .58016 .47609 L 0 .031 .131 r
F
.57742 .47692 m .57601 .47546 L .57874 .47465 L F
.43023 .47579 m .43133 .47354 L .43288 .47504 L 0 .029 .128 r
F
.43023 .47579 m .42868 .47427 L .43133 .47354 L F
.79332 .4743 m .79493 .47178 L .79616 .4734 L 0 .025 .124 r
F
.79332 .4743 m .7921 .47267 L .79493 .47178 L F
.53891 .47685 m .54017 .47448 L .54162 .47606 L 0 .031 .131 r
F
.53891 .47685 m .53746 .47525 L .54017 .47448 L F
.5843 .47668 m .58562 .47445 L .58703 .47585 L F
.5843 .47668 m .58289 .47526 L .58562 .47445 L F
.64343 .47576 m .64483 .47336 L .64619 .47499 L 0 .028 .128 r
F
.64343 .47576 m .64207 .47413 L .64483 .47336 L F
.74795 .47464 m .7495 .47223 L .75076 .47383 L 0 .026 .125 r
F
.74795 .47464 m .74668 .47305 L .7495 .47223 L F
.69569 .47522 m .69717 .47289 L .69848 .47442 L 0 .027 .127 r
F
.69569 .47522 m .69438 .47369 L .69717 .47289 L F
.32154 .47504 m .32249 .47262 L .32414 .47417 L 0 .027 .126 r
F
.32154 .47504 m .31988 .47348 L .32249 .47262 L F
.50039 .47679 m .5016 .47447 L .50308 .47599 L 0 .031 .131 r
F
.50039 .47679 m .4989 .47527 L .5016 .47447 L F
.28301 .47489 m .28391 .47247 L .2856 .47398 L 0 .027 .126 r
F
.28301 .47489 m .28132 .47339 L .28391 .47247 L F
.36005 .47528 m .36106 .4729 L .36267 .47456 L 0 .028 .127 r
F
.36005 .47528 m .35844 .47363 L .36106 .4729 L F
.80021 .47419 m .80184 .47174 L .80306 .47334 L 0 .025 .124 r
F
.80021 .47419 m .799 .47257 L .80184 .47174 L F
.3917 .47591 m .39275 .47359 L .39434 .4751 L 0 .029 .129 r
F
.3917 .47591 m .39011 .47441 L .39275 .47359 L F
.28988 .47458 m .29079 .47223 L .29247 .47374 L 0 .026 .125 r
F
.28988 .47458 m .2882 .47307 L .29079 .47223 L F
.59117 .4765 m .59251 .47424 L .59391 .47566 L 0 .03 .131 r
F
.59117 .4765 m .58977 .47505 L .59251 .47424 L F
.3284 .47484 m .32936 .47239 L .33101 .47391 L 0 .027 .126 r
F
.3284 .47484 m .32675 .47329 L .32936 .47239 L F
.43709 .47585 m .4382 .47351 L .43975 .47508 L 0 .029 .129 r
F
.43709 .47585 m .43554 .4743 L .4382 .47351 L F
.46187 .47681 m .46302 .47452 L .46454 .47612 L 0 .031 .132 r
F
.46187 .47681 m .46034 .47522 L .46302 .47452 L F
.59804 .47623 m .59939 .47393 L .60079 .4754 L 0 .03 .13 r
F
.59804 .47623 m .59665 .47479 L .59939 .47393 L F
.33526 .47452 m .33624 .47209 L .33788 .47363 L 0 .026 .125 r
F
.33526 .47452 m .33362 .47298 L .33624 .47209 L F
.54578 .47682 m .54705 .47451 L .5485 .476 L 0 .031 .132 r
F
.54578 .47682 m .54433 .47528 L .54705 .47451 L F
.50726 .47667 m .50848 .47414 L .50996 .47575 L 0 .031 .131 r
F
.50726 .47667 m .50578 .47507 L .50848 .47414 L F
.70257 .47516 m .70407 .47274 L .70537 .47427 L 0 .028 .127 r
F
.70257 .47516 m .70127 .47363 L .70407 .47274 L F
.8071 .47402 m .80874 .47154 L .80994 .4731 L 0 .025 .124 r
F
.8071 .47402 m .8059 .47244 L .80874 .47154 L F
.39856 .47576 m .39962 .47334 L .4012 .47489 L 0 .029 .129 r
F
.39856 .47576 m .39698 .47422 L .39962 .47334 L F
.75484 .47462 m .75641 .47221 L .75766 .47381 L 0 .026 .125 r
F
.75484 .47462 m .75358 .47302 L .75641 .47221 L F
.65031 .47581 m .65172 .47322 L .65308 .47486 L 0 .029 .129 r
F
.65031 .47581 m .64896 .47418 L .65172 .47322 L F
.65718 .47544 m .65861 .47295 L .65995 .4745 L 0 .028 .128 r
F
.65718 .47544 m .65584 .4739 L .65861 .47295 L F
.66406 .47506 m .66549 .47262 L .66683 .47414 L 0 .027 .127 r
F
.66406 .47506 m .66272 .47356 L .66549 .47262 L F
.70945 .47489 m .71094 .47234 L .71224 .47392 L 0 .027 .126 r
F
.70945 .47489 m .70815 .47331 L .71094 .47234 L F
.29673 .47452 m .29764 .47226 L .29931 .47379 L F
.29673 .47452 m .29505 .473 L .29764 .47226 L F
.60492 .47606 m .60627 .47369 L .60766 .47523 L 0 .03 .13 r
F
.60492 .47606 m .60353 .47455 L .60627 .47369 L F
.51413 .47649 m .51535 .47408 L .51683 .47567 L 0 .031 .131 r
F
.51413 .47649 m .51265 .47489 L .51535 .47408 L F
.71633 .47462 m .71783 .47205 L .71912 .4737 L 0 .026 .125 r
F
.71633 .47462 m .71503 .47298 L .71783 .47205 L F
.67093 .47482 m .67238 .4725 L .67371 .47398 L 0 .027 .127 r
F
.67093 .47482 m .6696 .47332 L .67238 .4725 L F
.76173 .47447 m .7633 .47196 L .76455 .47355 L 0 .026 .125 r
F
.76173 .47447 m .76048 .4729 L .7633 .47196 L F
.55265 .47676 m .55394 .47452 L .55537 .47599 L 0 .032 .132 r
F
.55265 .47676 m .55121 .47526 L .55394 .47452 L F
.34212 .47448 m .3431 .47206 L .34473 .47371 L 0 .026 .125 r
F
.34212 .47448 m .34049 .47284 L .3431 .47206 L F
.3669 .47544 m .36792 .47297 L .36952 .47461 L 0 .028 .128 r
F
.3669 .47544 m .36529 .47379 L .36792 .47297 L F
.40542 .47569 m .40649 .47341 L .40806 .47493 L 0 .029 .129 r
F
.40542 .47569 m .40385 .47415 L .40649 .47341 L F
.46873 .47685 m .46989 .47443 L .47141 .47598 L 0 .032 .132 r
F
.46873 .47685 m .46721 .47531 L .46989 .47443 L F
.44395 .47591 m .44507 .47346 L .44661 .47513 L 0 .03 .13 r
F
.44395 .47591 m .44241 .47427 L .44507 .47346 L F
.48247 .47612 m .48365 .47389 L .48516 .47528 L 0 .03 .131 r
F
.48247 .47612 m .48097 .47472 L .48365 .47389 L F
.76861 .47423 m .77019 .47178 L .77144 .47337 L 0 .026 .125 r
F
.76861 .47423 m .76737 .47264 L .77019 .47178 L F
.6118 .47597 m .61316 .47352 L .61455 .47509 L 0 .03 .13 r
F
.6118 .47597 m .61041 .47439 L .61316 .47352 L F
.4756 .47654 m .47677 .47422 L .47828 .47563 L 0 .031 .132 r
F
.4756 .47654 m .47409 .47511 L .47677 .47422 L F
.521 .47636 m .52224 .47402 L .5237 .47555 L 0 .031 .131 r
F
.521 .47636 m .51953 .47485 L .52224 .47402 L F
.72321 .47446 m .72473 .47197 L .72602 .47361 L 0 .026 .125 r
F
.72321 .47446 m .72192 .47281 L .72473 .47197 L F
.30357 .47452 m .30451 .47204 L .30617 .47363 L 0 .027 .126 r
F
.30357 .47452 m .30191 .47293 L .30451 .47204 L F
.37376 .4753 m .37478 .47293 L .37639 .47446 L 0 .029 .128 r
F
.37376 .4753 m .37215 .47379 L .37478 .47293 L F
.67782 .47475 m .67927 .47228 L .6806 .47388 L 0 .027 .126 r
F
.67782 .47475 m .67649 .47314 L .67927 .47228 L F
.61868 .47575 m .62005 .47329 L .62143 .47484 L 0 .029 .129 r
F
.61868 .47575 m .6173 .47419 L .62005 .47329 L F
.62555 .47537 m .62693 .47304 L .6283 .47446 L F
.62555 .47537 m .62418 .47394 L .62693 .47304 L F
.63242 .47501 m .63382 .47281 L .63518 .47423 L 0 .028 .128 r
F
.63242 .47501 m .63106 .47361 L .63382 .47281 L F
.55953 .47673 m .56082 .47427 L .56225 .47586 L 0 .032 .132 r
F
.55953 .47673 m .5581 .47516 L .56082 .47427 L F
.41228 .47563 m .41336 .47333 L .41493 .47481 L 0 .03 .13 r
F
.41228 .47563 m .41071 .47414 L .41336 .47333 L F
.7755 .47411 m .77709 .47161 L .77833 .47321 L 0 .026 .125 r
F
.7755 .47411 m .77426 .47251 L .77709 .47161 L F
.34897 .4745 m .34997 .47194 L .35159 .47359 L 0 .027 .126 r
F
.34897 .4745 m .34734 .47285 L .34997 .47194 L F
.52787 .47623 m .52912 .47391 L .53058 .47543 L 0 .031 .131 r
F
.52787 .47623 m .52641 .47474 L .52912 .47391 L F
.7301 .47433 m .73163 .47188 L .73291 .47344 L 0 .026 .126 r
F
.7301 .47433 m .72882 .47276 L .73163 .47188 L F
.48934 .47605 m .49053 .47386 L .49203 .47533 L 0 .031 .131 r
F
.48934 .47605 m .48784 .47457 L .49053 .47386 L F
.31043 .47435 m .31137 .472 L .31303 .47357 L 0 .027 .126 r
F
.31043 .47435 m .30877 .47275 L .31137 .472 L F
.38062 .47513 m .38166 .47277 L .38325 .47431 L 0 .028 .128 r
F
.38062 .47513 m .37902 .4736 L .38166 .47277 L F
.6847 .47461 m .68617 .47215 L .68749 .47376 L 0 .027 .126 r
F
.6847 .47461 m .68338 .47301 L .68617 .47215 L F
.45081 .47597 m .45195 .47347 L .45348 .47513 L 0 .03 .13 r
F
.45081 .47597 m .44928 .4743 L .45195 .47347 L F
.78239 .47388 m .78398 .47133 L .78521 .47294 L 0 .025 .124 r
F
.78239 .47388 m .78115 .47227 L .78398 .47133 L F
.73698 .47407 m .73852 .47162 L .73979 .47315 L 0 .026 .125 r
F
.73698 .47407 m .73571 .47253 L .73852 .47162 L F
.56641 .47661 m .5677 .47408 L .56913 .47572 L 0 .032 .132 r
F
.56641 .47661 m .56498 .47499 L .5677 .47408 L F
.6393 .4749 m .64071 .47266 L .64207 .47413 L 0 .028 .128 r
F
.6393 .4749 m .63794 .47344 L .64071 .47266 L F
.41915 .47549 m .42024 .47311 L .4218 .47459 L 0 .029 .129 r
F
.41915 .47549 m .41758 .474 L .42024 .47311 L F
.35583 .47435 m .35683 .47197 L .35844 .47363 L 0 .027 .126 r
F
.35583 .47435 m .35421 .4727 L .35683 .47197 L F
.78927 .47361 m .79087 .47106 L .7921 .47267 L 0 .025 .124 r
F
.78927 .47361 m .78804 .472 L .79087 .47106 L F
.53475 .4761 m .536 .47369 L .53746 .47525 L 0 .031 .131 r
F
.53475 .4761 m .53329 .47456 L .536 .47369 L F
.57328 .47633 m .57459 .47393 L .57601 .47546 L 0 .031 .132 r
F
.57328 .47633 m .57186 .47481 L .57459 .47393 L F
.42602 .4752 m .42712 .47276 L .42868 .47427 L 0 .029 .128 r
F
.42602 .4752 m .42446 .47366 L .42712 .47276 L F
.74387 .47387 m .74542 .47148 L .74668 .47305 L 0 .026 .125 r
F
.74387 .47387 m .7426 .47232 L .74542 .47148 L F
.69159 .47451 m .69307 .47208 L .69438 .47369 L 0 .027 .127 r
F
.69159 .47451 m .69028 .47292 L .69307 .47208 L F
.31728 .47432 m .31823 .47196 L .31988 .47348 L 0 .027 .126 r
F
.31728 .47432 m .31562 .47279 L .31823 .47196 L F
.49621 .47605 m .49741 .47377 L .4989 .47527 L 0 .031 .131 r
F
.49621 .47605 m .49472 .47456 L .49741 .47377 L F
.38748 .47512 m .38852 .47287 L .39011 .47441 L 0 .029 .129 r
F
.38748 .47512 m .38588 .47359 L .38852 .47287 L F
.79616 .4734 m .79778 .47095 L .799 .47257 L 0 .025 .124 r
F
.79616 .4734 m .79493 .47178 L .79778 .47095 L F
.58016 .47609 m .58148 .47384 L .58289 .47526 L 0 .031 .132 r
F
.58016 .47609 m .57874 .47465 L .58148 .47384 L F
.45767 .47591 m .45882 .47362 L .46034 .47522 L 0 .031 .131 r
F
.45767 .47591 m .45615 .47432 L .45882 .47362 L F
.43288 .47504 m .43399 .47281 L .43554 .4743 L 0 .029 .129 r
F
.43288 .47504 m .43133 .47354 L .43399 .47281 L F
.58703 .47585 m .58836 .47366 L .58977 .47505 L 0 .031 .131 r
F
.58703 .47585 m .58562 .47445 L .58836 .47366 L F
.54162 .47606 m .54289 .47374 L .54433 .47528 L 0 .031 .132 r
F
.54162 .47606 m .54017 .47448 L .54289 .47374 L F
.32414 .47417 m .3251 .47175 L .32675 .47329 L 0 .027 .126 r
F
.32414 .47417 m .32249 .47262 L .3251 .47175 L F
.2856 .47398 m .28651 .47156 L .2882 .47307 L 0 .026 .126 r
F
.2856 .47398 m .28391 .47247 L .28651 .47156 L F
.75076 .47383 m .75232 .47142 L .75358 .47302 L 0 .026 .125 r
F
.75076 .47383 m .7495 .47223 L .75232 .47142 L F
.69848 .47442 m .69997 .47209 L .70127 .47363 L 0 .028 .127 r
F
.69848 .47442 m .69717 .47289 L .69997 .47209 L F
.64619 .47499 m .6476 .47254 L .64896 .47418 L 0 .029 .128 r
F
.64619 .47499 m .64483 .47336 L .6476 .47254 L F
.50308 .47599 m .50429 .47358 L .50578 .47507 L 0 .031 .131 r
F
.50308 .47599 m .5016 .47447 L .50429 .47358 L F
.80306 .47334 m .80468 .47086 L .8059 .47244 L 0 .025 .124 r
F
.80306 .47334 m .80184 .47174 L .80468 .47086 L F
.33101 .47391 m .33198 .47147 L .33362 .47298 L 0 .026 .125 r
F
.33101 .47391 m .32936 .47239 L .33198 .47147 L F
.29247 .47374 m .29337 .47148 L .29505 .473 L F
.29247 .47374 m .29079 .47223 L .29337 .47148 L F
.59391 .47566 m .59525 .47335 L .59665 .47479 L 0 .031 .131 r
F
.59391 .47566 m .59251 .47424 L .59525 .47335 L F
.39434 .4751 m .39539 .47268 L .39698 .47422 L 0 .029 .129 r
F
.39434 .4751 m .39275 .47359 L .39539 .47268 L F
.36267 .47456 m .36368 .47213 L .36529 .47379 L 0 .028 .127 r
F
.36267 .47456 m .36106 .4729 L .36368 .47213 L F
.33788 .47363 m .33885 .4713 L .34049 .47284 L 0 .026 .125 r
F
.33788 .47363 m .33624 .47209 L .33885 .4713 L F
.50996 .47575 m .51118 .47329 L .51265 .47489 L 0 .031 .131 r
F
.50996 .47575 m .50848 .47414 L .51118 .47329 L F
.80994 .4731 m .81158 .47064 L .81278 .47218 L 0 .025 .123 r
F
.80994 .4731 m .80874 .47154 L .81158 .47064 L F
.60079 .4754 m .60214 .47305 L .60353 .47455 L 0 .03 .13 r
F
.60079 .4754 m .59939 .47393 L .60214 .47305 L F
.70537 .47427 m .70686 .47178 L .70815 .47331 L 0 .027 .127 r
F
.70537 .47427 m .70407 .47274 L .70686 .47178 L F
.65308 .47486 m .65449 .47227 L .65584 .4739 L 0 .028 .128 r
F
.65308 .47486 m .65172 .47322 L .65449 .47227 L F
.5485 .476 m .54977 .4738 L .55121 .47526 L 0 .032 .132 r
F
.5485 .476 m .54705 .47451 L .54977 .4738 L F
.71224 .47392 m .71374 .47138 L .71503 .47298 L 0 .027 .126 r
F
.71224 .47392 m .71094 .47234 L .71374 .47138 L F
.65995 .4745 m .66138 .472 L .66272 .47356 L 0 .028 .127 r
F
.65995 .4745 m .65861 .47295 L .66138 .472 L F
.43975 .47508 m .44087 .47268 L .44241 .47427 L 0 .029 .129 r
F
.43975 .47508 m .4382 .47351 L .44087 .47268 L F
.4012 .47489 m .40227 .47258 L .40385 .47415 L F
.4012 .47489 m .39962 .47334 L .40227 .47258 L F
.66683 .47414 m .66827 .47183 L .6696 .47332 L 0 .027 .127 r
F
.66683 .47414 m .66549 .47262 L .66827 .47183 L F
.75766 .47381 m .75922 .47128 L .76048 .4729 L 0 .026 .125 r
F
.75766 .47381 m .75641 .47221 L .75922 .47128 L F
.46454 .47612 m .46569 .4737 L .46721 .47531 L 0 .032 .132 r
F
.46454 .47612 m .46302 .47452 L .46569 .4737 L F
.60766 .47523 m .60902 .47282 L .61041 .47439 L 0 .03 .13 r
F
.60766 .47523 m .60627 .47369 L .60902 .47282 L F
.71912 .4737 m .72063 .47114 L .72192 .47281 L 0 .026 .125 r
F
.71912 .4737 m .71783 .47205 L .72063 .47114 L F
.76455 .47355 m .76612 .47105 L .76737 .47264 L F
.76455 .47355 m .7633 .47196 L .76612 .47105 L F
.51683 .47567 m .51806 .47327 L .51953 .47485 L 0 .031 .131 r
F
.51683 .47567 m .51535 .47408 L .51806 .47327 L F
.29931 .47379 m .30023 .47139 L .30191 .47293 L 0 .027 .126 r
F
.29931 .47379 m .29764 .47226 L .30023 .47139 L F
.67371 .47398 m .67517 .47168 L .67649 .47314 L 0 .027 .127 r
F
.67371 .47398 m .67238 .4725 L .67517 .47168 L F
.36952 .47461 m .37055 .47214 L .37215 .47379 L 0 .028 .128 r
F
.36952 .47461 m .36792 .47297 L .37055 .47214 L F
.47141 .47598 m .47257 .47355 L .47409 .47511 L 0 .032 .132 r
F
.47141 .47598 m .46989 .47443 L .47257 .47355 L F
.55537 .47599 m .55666 .4737 L .5581 .47516 L F
.55537 .47599 m .55394 .47452 L .55666 .4737 L F
.34473 .47371 m .34572 .47119 L .34734 .47285 L 0 .026 .126 r
F
.34473 .47371 m .3431 .47206 L .34572 .47119 L F
.47828 .47563 m .47946 .47332 L .48097 .47472 L 0 .031 .131 r
F
.47828 .47563 m .47677 .47422 L .47946 .47332 L F
.77144 .47337 m .77302 .47091 L .77426 .47251 L 0 .026 .125 r
F
.77144 .47337 m .77019 .47178 L .77302 .47091 L F
.48516 .47528 m .48634 .47317 L .48784 .47457 L 0 .031 .131 r
F
.48516 .47528 m .48365 .47389 L .48634 .47317 L F
.61455 .47509 m .61591 .47263 L .6173 .47419 L 0 .03 .13 r
F
.61455 .47509 m .61316 .47352 L .61591 .47263 L F
.40806 .47493 m .40914 .47264 L .41071 .47414 L F
.40806 .47493 m .40649 .47341 L .40914 .47264 L F
.44661 .47513 m .44774 .47263 L .44928 .4743 L F
.44661 .47513 m .44507 .47346 L .44774 .47263 L F
.72602 .47361 m .72754 .47113 L .72882 .47276 L 0 .026 .126 r
F
.72602 .47361 m .72473 .47197 L .72754 .47113 L F
.30617 .47363 m .30711 .47117 L .30877 .47275 L 0 .027 .126 r
F
.30617 .47363 m .30451 .47204 L .30711 .47117 L F
.5237 .47555 m .52494 .47319 L .52641 .47474 L 0 .031 .131 r
F
.5237 .47555 m .52224 .47402 L .52494 .47319 L F
.62143 .47484 m .6228 .47241 L .62418 .47394 L 0 .029 .129 r
F
.62143 .47484 m .62005 .47329 L .6228 .47241 L F
.6806 .47388 m .68206 .47142 L .68338 .47301 L 0 .027 .126 r
F
.6806 .47388 m .67927 .47228 L .68206 .47142 L F
.37639 .47446 m .37742 .47207 L .37902 .4736 L 0 .029 .128 r
F
.37639 .47446 m .37478 .47293 L .37742 .47207 L F
.6283 .47446 m .62969 .47218 L .63106 .47361 L F
.6283 .47446 m .62693 .47304 L .62969 .47218 L F
.56225 .47586 m .56355 .47337 L .56498 .47499 L 0 .032 .132 r
F
.56225 .47586 m .56082 .47427 L .56355 .47337 L F
.77833 .47321 m .77992 .47069 L .78115 .47227 L 0 .026 .125 r
F
.77833 .47321 m .77709 .47161 L .77992 .47069 L F
.35159 .47359 m .35259 .47105 L .35421 .4727 L 0 .026 .126 r
F
.35159 .47359 m .34997 .47194 L .35259 .47105 L F
.73291 .47344 m .73444 .47098 L .73571 .47253 L 0 .026 .125 r
F
.73291 .47344 m .73163 .47188 L .73444 .47098 L F
.63518 .47423 m .63659 .47201 L .63794 .47344 L 0 .028 .128 r
F
.63518 .47423 m .63382 .47281 L .63659 .47201 L F
.41493 .47481 m .41601 .47252 L .41758 .474 L 0 .03 .13 r
F
.41493 .47481 m .41336 .47333 L .41601 .47252 L F
.78521 .47294 m .78681 .47039 L .78804 .472 L 0 .025 .124 r
F
.78521 .47294 m .78398 .47133 L .78681 .47039 L F
.53058 .47543 m .53183 .47301 L .53329 .47456 L 0 .031 .131 r
F
.53058 .47543 m .52912 .47391 L .53183 .47301 L F
.73979 .47315 m .74134 .47078 L .7426 .47232 L 0 .026 .125 r
F
.73979 .47315 m .73852 .47162 L .74134 .47078 L F
.38325 .47431 m .38429 .47203 L .38588 .47359 L 0 .029 .128 r
F
.38325 .47431 m .38166 .47277 L .38429 .47203 L F
.31303 .47357 m .31396 .47124 L .31562 .47279 L 0 .027 .126 r
F
.31303 .47357 m .31137 .472 L .31396 .47124 L F
.68749 .47376 m .68896 .47129 L .69028 .47292 L 0 .027 .127 r
F
.68749 .47376 m .68617 .47215 L .68896 .47129 L F
.45348 .47513 m .45462 .47267 L .45615 .47432 L 0 .03 .13 r
F
.45348 .47513 m .45195 .47347 L .45462 .47267 L F
.49203 .47533 m .49322 .47307 L .49472 .47456 L 0 .031 .131 r
F
.49203 .47533 m .49053 .47386 L .49322 .47307 L F
.56913 .47572 m .57043 .47316 L .57186 .47481 L 0 .031 .132 r
F
.56913 .47572 m .5677 .47408 L .57043 .47316 L F
.7921 .47267 m .79371 .47016 L .79493 .47178 L 0 .025 .123 r
F
.7921 .47267 m .79087 .47106 L .79371 .47016 L F
.4218 .47459 m .4229 .4722 L .42446 .47366 L 0 .029 .129 r
F
.4218 .47459 m .42024 .47311 L .4229 .4722 L F
.42868 .47427 m .42978 .47204 L .43133 .47354 L F
.42868 .47427 m .42712 .47276 L .42978 .47204 L F
.53746 .47525 m .53872 .47291 L .54017 .47448 L 0 .031 .131 r
F
.53746 .47525 m .536 .47369 L .53872 .47291 L F
.57601 .47546 m .57732 .47314 L .57874 .47465 L 0 .031 .132 r
F
.57601 .47546 m .57459 .47393 L .57732 .47314 L F
.64207 .47413 m .64348 .47187 L .64483 .47336 L 0 .029 .128 r
F
.64207 .47413 m .64071 .47266 L .64348 .47187 L F
.74668 .47305 m .74824 .47066 L .7495 .47223 L 0 .026 .125 r
F
.74668 .47305 m .74542 .47148 L .74824 .47066 L F
.35844 .47363 m .35945 .47125 L .36106 .4729 L 0 .027 .127 r
F
.35844 .47363 m .35683 .47197 L .35945 .47125 L F
.31988 .47348 m .32084 .4711 L .32249 .47262 L 0 .027 .126 r
F
.31988 .47348 m .31823 .47196 L .32084 .4711 L F
.69438 .47369 m .69586 .47127 L .69717 .47289 L 0 .027 .127 r
F
.69438 .47369 m .69307 .47208 L .69586 .47127 L F
.799 .47257 m .80062 .47013 L .80184 .47174 L 0 .025 .124 r
F
.799 .47257 m .79778 .47095 L .80062 .47013 L F
.58289 .47526 m .58422 .47305 L .58562 .47445 L 0 .031 .132 r
F
.58289 .47526 m .58148 .47384 L .58422 .47305 L F
.4989 .47527 m .50011 .47297 L .5016 .47447 L F
.4989 .47527 m .49741 .47377 L .50011 .47297 L F
.28132 .47339 m .28222 .47096 L .28391 .47247 L 0 .027 .126 r
F
.28132 .47339 m .27963 .47188 L .28222 .47096 L F
.2882 .47307 m .2891 .47071 L .29079 .47223 L 0 .026 .125 r
F
.2882 .47307 m .28651 .47156 L .2891 .47071 L F
.39011 .47441 m .39116 .47203 L .39275 .47359 L 0 .029 .129 r
F
.39011 .47441 m .38852 .47287 L .39116 .47203 L F
.32675 .47329 m .32771 .47086 L .32936 .47239 L 0 .027 .126 r
F
.32675 .47329 m .3251 .47175 L .32771 .47086 L F
.46034 .47522 m .46149 .47293 L .46302 .47452 L 0 .031 .132 r
F
.46034 .47522 m .45882 .47362 L .46149 .47293 L F
.58977 .47505 m .59111 .47287 L .59251 .47424 L F
.58977 .47505 m .58836 .47366 L .59111 .47287 L F
.43554 .4743 m .43665 .47203 L .4382 .47351 L 0 .029 .129 r
F
.43554 .4743 m .43399 .47281 L .43665 .47203 L F
.50578 .47507 m .50699 .47268 L .50848 .47414 L 0 .031 .131 r
F
.50578 .47507 m .50429 .47358 L .50699 .47268 L F
.33362 .47298 m .33459 .4706 L .33624 .47209 L 0 .026 .125 r
F
.33362 .47298 m .33198 .47147 L .33459 .4706 L F
.54433 .47528 m .5456 .473 L .54705 .47451 L 0 .032 .132 r
F
.54433 .47528 m .54289 .47374 L .5456 .473 L F
.8059 .47244 m .80753 .46997 L .80874 .47154 L 0 .025 .124 r
F
.8059 .47244 m .80468 .47086 L .80753 .46997 L F
.75358 .47302 m .75515 .47061 L .75641 .47221 L 0 .026 .125 r
F
.75358 .47302 m .75232 .47142 L .75515 .47061 L F
.64896 .47418 m .65037 .47159 L .65172 .47322 L 0 .029 .128 r
F
.64896 .47418 m .6476 .47254 L .65037 .47159 L F
.70127 .47363 m .70276 .47121 L .70407 .47274 L 0 .028 .127 r
F
.70127 .47363 m .69997 .47209 L .70276 .47121 L F
.39698 .47422 m .39804 .47177 L .39962 .47334 L 0 .029 .129 r
F
.39698 .47422 m .39539 .47268 L .39804 .47177 L F
.59665 .47479 m .59799 .47245 L .59939 .47393 L 0 .03 .131 r
F
.59665 .47479 m .59525 .47335 L .59799 .47245 L F
.70815 .47331 m .70965 .47082 L .71094 .47234 L 0 .027 .126 r
F
.70815 .47331 m .70686 .47178 L .70965 .47082 L F
.81278 .47218 m .81443 .46979 L .81563 .47134 L 0 .025 .123 r
F
.81278 .47218 m .81158 .47064 L .81443 .46979 L F
.65584 .4739 m .65726 .47132 L .65861 .47295 L 0 .028 .128 r
F
.65584 .4739 m .65449 .47227 L .65726 .47132 L F
.51265 .47489 m .51388 .47249 L .51535 .47408 L 0 .031 .131 r
F
.51265 .47489 m .51118 .47329 L .51388 .47249 L F
.71503 .47298 m .71654 .47043 L .71783 .47205 L 0 .026 .125 r
F
.71503 .47298 m .71374 .47138 L .71654 .47043 L F
.66272 .47356 m .66415 .47106 L .66549 .47262 L 0 .028 .127 r
F
.66272 .47356 m .66138 .472 L .66415 .47106 L F
.29505 .473 m .29596 .47073 L .29764 .47226 L 0 .027 .126 r
F
.29505 .473 m .29337 .47148 L .29596 .47073 L F
.60353 .47455 m .60488 .47216 L .60627 .47369 L 0 .03 .13 r
F
.60353 .47455 m .60214 .47305 L .60488 .47216 L F
.36529 .47379 m .36631 .47131 L .36792 .47297 L 0 .028 .128 r
F
.36529 .47379 m .36368 .47213 L .36631 .47131 L F
.34049 .47284 m .34146 .47051 L .3431 .47206 L 0 .026 .125 r
F
.34049 .47284 m .33885 .4713 L .34146 .47051 L F
.76048 .4729 m .76204 .47034 L .7633 .47196 L F
.76048 .4729 m .75922 .47128 L .76204 .47034 L F
.44241 .47427 m .44353 .47185 L .44507 .47346 L 0 .029 .129 r
F
.44241 .47427 m .44087 .47268 L .44353 .47185 L F
.6696 .47332 m .67106 .47103 L .67238 .4725 L 0 .028 .127 r
F
.6696 .47332 m .66827 .47183 L .67106 .47103 L F
.55121 .47526 m .5525 .47309 L .55394 .47452 L 0 .032 .133 r
F
.55121 .47526 m .54977 .4738 L .5525 .47309 L F
.72192 .47281 m .72344 .47031 L .72473 .47197 L 0 .026 .125 r
F
.72192 .47281 m .72063 .47114 L .72344 .47031 L F
.40385 .47415 m .40491 .47183 L .40649 .47341 L 0 .029 .129 r
F
.40385 .47415 m .40227 .47258 L .40491 .47183 L F
.46721 .47531 m .46837 .47281 L .46989 .47443 L 0 .032 .132 r
F
.46721 .47531 m .46569 .4737 L .46837 .47281 L F
.76737 .47264 m .76895 .47017 L .77019 .47178 L 0 .026 .125 r
F
.76737 .47264 m .76612 .47105 L .76895 .47017 L F
.61041 .47439 m .61177 .47196 L .61316 .47352 L 0 .03 .13 r
F
.61041 .47439 m .60902 .47282 L .61177 .47196 L F
.30191 .47293 m .30284 .47049 L .30451 .47204 L 0 .027 .126 r
F
.30191 .47293 m .30023 .47139 L .30284 .47049 L F
.67649 .47314 m .67795 .47084 L .67927 .47228 L 0 .027 .127 r
F
.67649 .47314 m .67517 .47168 L .67795 .47084 L F
.51953 .47485 m .52077 .47242 L .52224 .47402 L 0 .031 .131 r
F
.51953 .47485 m .51806 .47327 L .52077 .47242 L F
.48097 .47472 m .48214 .47249 L .48365 .47389 L F
.48097 .47472 m .47946 .47332 L .48214 .47249 L F
.47409 .47511 m .47526 .47267 L .47677 .47422 L 0 .032 .132 r
F
.47409 .47511 m .47257 .47355 L .47526 .47267 L F
.37215 .47379 m .37318 .4713 L .37478 .47293 L 0 .029 .128 r
F
.37215 .47379 m .37055 .47214 L .37318 .4713 L F
.34734 .47285 m .34834 .47029 L .34997 .47194 L 0 .026 .125 r
F
.34734 .47285 m .34572 .47119 L .34834 .47029 L F
.6173 .47419 m .61867 .47175 L .62005 .47329 L 0 .03 .13 r
F
.6173 .47419 m .61591 .47263 L .61867 .47175 L F
.5581 .47516 m .55938 .47279 L .56082 .47427 L 0 .032 .132 r
F
.5581 .47516 m .55666 .4737 L .55938 .47279 L F
.77426 .47251 m .77585 .47001 L .77709 .47161 L 0 .026 .125 r
F
.77426 .47251 m .77302 .47091 L .77585 .47001 L F
.30877 .47275 m .3097 .47042 L .31137 .472 L 0 .027 .126 r
F
.30877 .47275 m .30711 .47117 L .3097 .47042 L F
.72882 .47276 m .73035 .47026 L .73163 .47188 L 0 .026 .126 r
F
.72882 .47276 m .72754 .47113 L .73035 .47026 L F
.44928 .4743 m .45041 .4718 L .45195 .47347 L 0 .03 .13 r
F
.44928 .4743 m .44774 .47263 L .45041 .4718 L F
.62418 .47394 m .62556 .47153 L .62693 .47304 L 0 .029 .129 r
F
.62418 .47394 m .6228 .47241 L .62556 .47153 L F
.41071 .47414 m .41179 .47183 L .41336 .47333 L 0 .03 .13 r
F
.41071 .47414 m .40914 .47264 L .41179 .47183 L F
.68338 .47301 m .68485 .47055 L .68617 .47215 L 0 .027 .126 r
F
.68338 .47301 m .68206 .47142 L .68485 .47055 L F
.52641 .47474 m .52765 .47233 L .52912 .47391 L 0 .031 .131 r
F
.52641 .47474 m .52494 .47319 L .52765 .47233 L F
.37902 .4736 m .38006 .47123 L .38166 .47277 L 0 .029 .128 r
F
.37902 .4736 m .37742 .47207 L .38006 .47123 L F
.78115 .47227 m .78275 .46976 L .78398 .47133 L 0 .025 .124 r
F
.78115 .47227 m .77992 .47069 L .78275 .46976 L F
.63106 .47361 m .63246 .47137 L .63382 .47281 L 0 .029 .129 r
F
.63106 .47361 m .62969 .47218 L .63246 .47137 L F
.48784 .47457 m .48903 .47245 L .49053 .47386 L 0 .031 .132 r
F
.48784 .47457 m .48634 .47317 L .48903 .47245 L F
.35421 .4727 m .35521 .47033 L .35683 .47197 L 0 .027 .126 r
F
.35421 .4727 m .35259 .47105 L .35521 .47033 L F
.56498 .47499 m .56627 .47244 L .5677 .47408 L 0 .031 .132 r
F
.56498 .47499 m .56355 .47337 L .56627 .47244 L F
.73571 .47253 m .73725 .47009 L .73852 .47162 L 0 .026 .125 r
F
.73571 .47253 m .73444 .47098 L .73725 .47009 L F
.78804 .472 m .78964 .46944 L .79087 .47106 L 0 .025 .124 r
F
.78804 .472 m .78681 .47039 L .78964 .46944 L F
.53329 .47456 m .53454 .47211 L .536 .47369 L 0 .031 .131 r
F
.53329 .47456 m .53183 .47301 L .53454 .47211 L F
.41758 .474 m .41867 .47165 L .42024 .47311 L 0 .03 .13 r
F
.41758 .474 m .41601 .47252 L .41867 .47165 L F
.63794 .47344 m .63935 .47121 L .64071 .47266 L 0 .029 .128 r
F
.63794 .47344 m .63659 .47201 L .63935 .47121 L F
.7426 .47232 m .74415 .46994 L .74542 .47148 L 0 .026 .125 r
F
.7426 .47232 m .74134 .47078 L .74415 .46994 L F
.42446 .47366 m .42556 .4713 L .42712 .47276 L 0 .029 .129 r
F
.42446 .47366 m .4229 .4722 L .42556 .4713 L F
.57186 .47481 m .57317 .47227 L .57459 .47393 L 0 .031 .132 r
F
.57186 .47481 m .57043 .47316 L .57317 .47227 L F
.69028 .47292 m .69175 .47044 L .69307 .47208 L 0 .027 .127 r
F
.69028 .47292 m .68896 .47129 L .69175 .47044 L F
.79493 .47178 m .79655 .46933 L .79778 .47095 L 0 .025 .123 r
F
.79493 .47178 m .79371 .47016 L .79655 .46933 L F
.31562 .47279 m .31657 .47043 L .31823 .47196 L 0 .027 .127 r
F
.31562 .47279 m .31396 .47124 L .31657 .47043 L F
.45615 .47432 m .45729 .47198 L .45882 .47362 L 0 .031 .131 r
F
.45615 .47432 m .45462 .47267 L .45729 .47198 L F
.38588 .47359 m .38693 .47129 L .38852 .47287 L 0 .029 .129 r
F
.38588 .47359 m .38429 .47203 L .38693 .47129 L F
.49472 .47456 m .49592 .47227 L .49741 .47377 L 0 .031 .132 r
F
.49472 .47456 m .49322 .47307 L .49592 .47227 L F
.57874 .47465 m .58006 .47235 L .58148 .47384 L 0 .032 .132 r
F
.57874 .47465 m .57732 .47314 L .58006 .47235 L F
.54017 .47448 m .54143 .47217 L .54289 .47374 L 0 .031 .132 r
F
.54017 .47448 m .53872 .47291 L .54143 .47217 L F
.43133 .47354 m .43244 .47132 L .43399 .47281 L 0 .029 .129 r
F
.43133 .47354 m .42978 .47204 L .43244 .47132 L F
.64483 .47336 m .64625 .47105 L .6476 .47254 L F
.64483 .47336 m .64348 .47187 L .64625 .47105 L F
.7495 .47223 m .75106 .46985 L .75232 .47142 L 0 .026 .125 r
F
.7495 .47223 m .74824 .47066 L .75106 .46985 L F
.32249 .47262 m .32345 .47023 L .3251 .47175 L 0 .027 .126 r
F
.32249 .47262 m .32084 .4711 L .32345 .47023 L F
.28391 .47247 m .28482 .47004 L .28651 .47156 L F
.28391 .47247 m .28222 .47096 L .28482 .47004 L F
.80184 .47174 m .80347 .46927 L .80468 .47086 L 0 .025 .124 r
F
.80184 .47174 m .80062 .47013 L .80347 .46927 L F
.69717 .47289 m .69866 .47046 L .69997 .47209 L 0 .028 .127 r
F
.69717 .47289 m .69586 .47127 L .69866 .47046 L F
.36106 .4729 m .36207 .47048 L .36368 .47213 L F
.36106 .4729 m .35945 .47125 L .36207 .47048 L F
.58562 .47445 m .58696 .47228 L .58836 .47366 L 0 .032 .132 r
F
.58562 .47445 m .58422 .47305 L .58696 .47228 L F
.5016 .47447 m .5028 .4721 L .50429 .47358 L 0 .031 .132 r
F
.5016 .47447 m .50011 .47297 L .5028 .4721 L F
.32936 .47239 m .33033 .46996 L .33198 .47147 L 0 .027 .126 r
F
.32936 .47239 m .32771 .47086 L .33033 .46996 L F
.29079 .47223 m .29169 .46995 L .29337 .47148 L F
.29079 .47223 m .2891 .47071 L .29169 .46995 L F
.50848 .47414 m .50969 .47185 L .51118 .47329 L 0 .031 .131 r
F
.50848 .47414 m .50699 .47268 L .50969 .47185 L F
.39275 .47359 m .39381 .4711 L .39539 .47268 L 0 .029 .129 r
F
.39275 .47359 m .39116 .47203 L .39381 .4711 L F
.65172 .47322 m .65314 .47064 L .65449 .47227 L 0 .028 .128 r
F
.65172 .47322 m .65037 .47159 L .65314 .47064 L F
.33624 .47209 m .33721 .46981 L .33885 .4713 L 0 .026 .125 r
F
.33624 .47209 m .33459 .4706 L .33721 .46981 L F
.80874 .47154 m .81038 .46909 L .81158 .47064 L 0 .025 .123 r
F
.80874 .47154 m .80753 .46997 L .81038 .46909 L F
.59251 .47424 m .59385 .47196 L .59525 .47335 L 0 .031 .132 r
F
.59251 .47424 m .59111 .47287 L .59385 .47196 L F
.71094 .47234 m .71245 .46986 L .71374 .47138 L 0 .027 .126 r
F
.71094 .47234 m .70965 .47082 L .71245 .46986 L F
.70407 .47274 m .70556 .47025 L .70686 .47178 L 0 .027 .127 r
F
.70407 .47274 m .70276 .47121 L .70556 .47025 L F
.4382 .47351 m .43932 .47119 L .44087 .47268 L 0 .029 .129 r
F
.4382 .47351 m .43665 .47203 L .43932 .47119 L F
.65861 .47295 m .66003 .47037 L .66138 .472 L 0 .028 .127 r
F
.65861 .47295 m .65726 .47132 L .66003 .47037 L F
.39962 .47334 m .40069 .47101 L .40227 .47258 L 0 .029 .129 r
F
.39962 .47334 m .39804 .47177 L .40069 .47101 L F
.75641 .47221 m .75797 .46967 L .75922 .47128 L 0 .026 .125 r
F
.75641 .47221 m .75515 .47061 L .75797 .46967 L F
.59939 .47393 m .60074 .47155 L .60214 .47305 L 0 .03 .131 r
F
.59939 .47393 m .59799 .47245 L .60074 .47155 L F
.54705 .47451 m .54833 .47232 L .54977 .4738 L 0 .032 .133 r
F
.54705 .47451 m .5456 .473 L .54833 .47232 L F
.46302 .47452 m .46417 .4721 L .46569 .4737 L 0 .032 .132 r
F
.46302 .47452 m .46149 .47293 L .46417 .4721 L F
.71783 .47205 m .71934 .46952 L .72063 .47114 L 0 .026 .125 r
F
.71783 .47205 m .71654 .47043 L .71934 .46952 L F
.66549 .47262 m .66694 .47027 L .66827 .47183 L 0 .028 .127 r
F
.66549 .47262 m .66415 .47106 L .66694 .47027 L F
.81563 .47134 m .81729 .46894 L .81849 .4705 L 0 .025 .123 r
F
.81563 .47134 m .81443 .46979 L .81729 .46894 L F
.7633 .47196 m .76487 .4694 L .76612 .47105 L 0 .026 .125 r
F
.7633 .47196 m .76204 .47034 L .76487 .4694 L F
.60627 .47369 m .60763 .47127 L .60902 .47282 L 0 .03 .13 r
F
.60627 .47369 m .60488 .47216 L .60763 .47127 L F
.51535 .47408 m .51658 .47169 L .51806 .47327 L 0 .031 .131 r
F
.51535 .47408 m .51388 .47249 L .51658 .47169 L F
.36792 .47297 m .36894 .47048 L .37055 .47214 L 0 .028 .128 r
F
.36792 .47297 m .36631 .47131 L .36894 .47048 L F
.3431 .47206 m .34408 .46964 L .34572 .47119 L 0 .026 .126 r
F
.3431 .47206 m .34146 .47051 L .34408 .46964 L F
.29764 .47226 m .29856 .46985 L .30023 .47139 L 0 .027 .126 r
F
.29764 .47226 m .29596 .47073 L .29856 .46985 L F
.67238 .4725 m .67384 .47022 L .67517 .47168 L 0 .028 .127 r
F
.67238 .4725 m .67106 .47103 L .67384 .47022 L F
.44507 .47346 m .4462 .47104 L .44774 .47263 L 0 .03 .13 r
F
.44507 .47346 m .44353 .47185 L .4462 .47104 L F
.46989 .47443 m .47106 .47191 L .47257 .47355 L 0 .032 .132 r
F
.46989 .47443 m .46837 .47281 L .47106 .47191 L F
.72473 .47197 m .72625 .46948 L .72754 .47113 L 0 .026 .125 r
F
.72473 .47197 m .72344 .47031 L .72625 .46948 L F
.77019 .47178 m .77178 .46929 L .77302 .47091 L F
.77019 .47178 m .76895 .47017 L .77178 .46929 L F
.61316 .47352 m .61453 .4711 L .61591 .47263 L 0 .03 .13 r
F
.61316 .47352 m .61177 .47196 L .61453 .4711 L F
.55394 .47452 m .55522 .47228 L .55666 .4737 L 0 .032 .133 r
F
.55394 .47452 m .5525 .47309 L .55522 .47228 L F
.30451 .47204 m .30544 .4696 L .30711 .47117 L 0 .027 .126 r
F
.30451 .47204 m .30284 .47049 L .30544 .4696 L F
.40649 .47341 m .40756 .47105 L .40914 .47264 L 0 .03 .13 r
F
.40649 .47341 m .40491 .47183 L .40756 .47105 L F
.67927 .47228 m .68074 .47001 L .68206 .47142 L 0 .027 .127 r
F
.67927 .47228 m .67795 .47084 L .68074 .47001 L F
.52224 .47402 m .52347 .47157 L .52494 .47319 L 0 .031 .131 r
F
.52224 .47402 m .52077 .47242 L .52347 .47157 L F
.47677 .47422 m .47795 .47178 L .47946 .47332 L 0 .031 .132 r
F
.47677 .47422 m .47526 .47267 L .47795 .47178 L F
.34997 .47194 m .35097 .46939 L .35259 .47105 L 0 .026 .125 r
F
.34997 .47194 m .34834 .47029 L .35097 .46939 L F
.62005 .47329 m .62142 .47088 L .6228 .47241 L 0 .029 .129 r
F
.62005 .47329 m .61867 .47175 L .62142 .47088 L F
.56082 .47427 m .56211 .47188 L .56355 .47337 L 0 .032 .132 r
F
.56082 .47427 m .55938 .47279 L .56211 .47188 L F
.37478 .47293 m .37582 .47047 L .37742 .47207 L 0 .029 .128 r
F
.37478 .47293 m .37318 .4713 L .37582 .47047 L F
.48365 .47389 m .48483 .47176 L .48634 .47317 L 0 .031 .132 r
F
.48365 .47389 m .48214 .47249 L .48483 .47176 L F
.77709 .47161 m .77868 .46911 L .77992 .47069 L 0 .026 .125 r
F
.77709 .47161 m .77585 .47001 L .77868 .46911 L F
.73163 .47188 m .73316 .46938 L .73444 .47098 L F
.73163 .47188 m .73035 .47026 L .73316 .46938 L F
.62693 .47304 m .62832 .47067 L .62969 .47218 L 0 .029 .129 r
F
.62693 .47304 m .62556 .47153 L .62832 .47067 L F
.78398 .47133 m .78558 .46881 L .78681 .47039 L 0 .025 .124 r
F
.78398 .47133 m .78275 .46976 L .78558 .46881 L F
.45195 .47347 m .45309 .47101 L .45462 .47267 L 0 .03 .13 r
F
.45195 .47347 m .45041 .4718 L .45309 .47101 L F
.68617 .47215 m .68763 .46967 L .68896 .47129 L 0 .027 .126 r
F
.68617 .47215 m .68485 .47055 L .68763 .46967 L F
.5677 .47408 m .569 .4715 L .57043 .47316 L 0 .031 .132 r
F
.5677 .47408 m .56627 .47244 L .569 .4715 L F
.41336 .47333 m .41444 .47102 L .41601 .47252 L 0 .03 .13 r
F
.41336 .47333 m .41179 .47183 L .41444 .47102 L F
.31137 .472 m .3123 .46967 L .31396 .47124 L 0 .027 .126 r
F
.31137 .472 m .3097 .47042 L .3123 .46967 L F
.52912 .47391 m .53037 .47142 L .53183 .47301 L 0 .031 .131 r
F
.52912 .47391 m .52765 .47233 L .53037 .47142 L F
.73852 .47162 m .74007 .46925 L .74134 .47078 L 0 .026 .125 r
F
.73852 .47162 m .73725 .47009 L .74007 .46925 L F
.38166 .47277 m .38269 .47047 L .38429 .47203 L 0 .029 .129 r
F
.38166 .47277 m .38006 .47123 L .38269 .47047 L F
.79087 .47106 m .79248 .46853 L .79371 .47016 L 0 .025 .123 r
F
.79087 .47106 m .78964 .46944 L .79248 .46853 L F
.63382 .47281 m .63522 .47055 L .63659 .47201 L 0 .029 .129 r
F
.63382 .47281 m .63246 .47137 L .63522 .47055 L F
.49053 .47386 m .49172 .47164 L .49322 .47307 L 0 .032 .132 r
F
.49053 .47386 m .48903 .47245 L .49172 .47164 L F
.42024 .47311 m .42133 .47075 L .4229 .4722 L 0 .03 .13 r
F
.42024 .47311 m .41867 .47165 L .42133 .47075 L F
.536 .47369 m .53726 .47133 L .53872 .47291 L 0 .031 .131 r
F
.536 .47369 m .53454 .47211 L .53726 .47133 L F
.35683 .47197 m .35783 .46961 L .35945 .47125 L 0 .027 .126 r
F
.35683 .47197 m .35521 .47033 L .35783 .46961 L F
.42712 .47276 m .42822 .47058 L .42978 .47204 L 0 .029 .129 r
F
.42712 .47276 m .42556 .4713 L .42822 .47058 L F
.57459 .47393 m .5759 .4715 L .57732 .47314 L 0 .031 .132 r
F
.57459 .47393 m .57317 .47227 L .5759 .4715 L F
.74542 .47148 m .74698 .46912 L .74824 .47066 L 0 .026 .125 r
F
.74542 .47148 m .74415 .46994 L .74698 .46912 L F
.64071 .47266 m .64212 .47041 L .64348 .47187 L 0 .029 .129 r
F
.64071 .47266 m .63935 .47121 L .64212 .47041 L F
.69307 .47208 m .69454 .46961 L .69586 .47127 L 0 .027 .127 r
F
.69307 .47208 m .69175 .47044 L .69454 .46961 L F
.79778 .47095 m .7994 .4685 L .80062 .47013 L 0 .025 .124 r
F
.79778 .47095 m .79655 .46933 L .7994 .4685 L F
.31823 .47196 m .31918 .46958 L .32084 .4711 L 0 .027 .127 r
F
.31823 .47196 m .31657 .47043 L .31918 .46958 L F
.49741 .47377 m .49861 .47146 L .50011 .47297 L 0 .032 .132 r
F
.49741 .47377 m .49592 .47227 L .49861 .47146 L F
.27963 .47188 m .28053 .46942 L .28222 .47096 L 0 .027 .126 r
F
.27963 .47188 m .27793 .47034 L .28053 .46942 L F
.45882 .47362 m .45997 .4713 L .46149 .47293 L 0 .031 .132 r
F
.45882 .47362 m .45729 .47198 L .45997 .4713 L F
.38852 .47287 m .38957 .47043 L .39116 .47203 L 0 .029 .129 r
F
.38852 .47287 m .38693 .47129 L .38957 .47043 L F
.58148 .47384 m .5828 .47158 L .58422 .47305 L 0 .032 .132 r
F
.58148 .47384 m .58006 .47235 L .5828 .47158 L F
.3251 .47175 m .32606 .46936 L .32771 .47086 L 0 .027 .126 r
F
.3251 .47175 m .32345 .47023 L .32606 .46936 L F
.28651 .47156 m .28741 .46918 L .2891 .47071 L F
.28651 .47156 m .28482 .47004 L .28741 .46918 L F
.6476 .47254 m .64902 .4701 L .65037 .47159 L 0 .029 .128 r
F
.6476 .47254 m .64625 .47105 L .64902 .4701 L F
.75232 .47142 m .75389 .46904 L .75515 .47061 L 0 .026 .125 r
F
.75232 .47142 m .75106 .46985 L .75389 .46904 L F
.80468 .47086 m .80632 .46839 L .80753 .46997 L 0 .025 .124 r
F
.80468 .47086 m .80347 .46927 L .80632 .46839 L F
.54289 .47374 m .54415 .47144 L .5456 .473 L 0 .032 .132 r
F
.54289 .47374 m .54143 .47217 L .54415 .47144 L F
.33198 .47147 m .33295 .4691 L .33459 .4706 L 0 .027 .126 r
F
.33198 .47147 m .33033 .46996 L .33295 .4691 L F
.43399 .47281 m .4351 .47054 L .43665 .47203 L 0 .03 .13 r
F
.43399 .47281 m .43244 .47132 L .4351 .47054 L F
.50429 .47358 m .50551 .47124 L .50699 .47268 L 0 .031 .132 r
F
.50429 .47358 m .5028 .4721 L .50551 .47124 L F
.65449 .47227 m .65591 .46968 L .65726 .47132 L 0 .028 .128 r
F
.65449 .47227 m .65314 .47064 L .65591 .46968 L F
.69997 .47209 m .70145 .46957 L .70276 .47121 L 0 .028 .127 r
F
.69997 .47209 m .69866 .47046 L .70145 .46957 L F
.39539 .47268 m .39646 .47017 L .39804 .47177 L 0 .029 .129 r
F
.39539 .47268 m .39381 .4711 L .39646 .47017 L F
.36368 .47213 m .3647 .46966 L .36631 .47131 L 0 .028 .127 r
F
.36368 .47213 m .36207 .47048 L .3647 .46966 L F
.58836 .47366 m .5897 .4715 L .59111 .47287 L 0 .032 .132 r
F
.58836 .47366 m .58696 .47228 L .5897 .4715 L F
.51118 .47329 m .5124 .47108 L .51388 .47249 L 0 .031 .131 r
F
.51118 .47329 m .50969 .47185 L .5124 .47108 L F
.71374 .47138 m .71525 .46891 L .71654 .47043 L 0 .026 .125 r
F
.71374 .47138 m .71245 .46986 L .71525 .46891 L F
.70686 .47178 m .70835 .4693 L .70965 .47082 L 0 .027 .126 r
F
.70686 .47178 m .70556 .47025 L .70835 .4693 L F
.81158 .47064 m .81323 .46823 L .81443 .46979 L 0 .025 .123 r
F
.81158 .47064 m .81038 .46909 L .81323 .46823 L F
.66138 .472 m .66281 .46942 L .66415 .47106 L 0 .028 .127 r
F
.66138 .472 m .66003 .47037 L .66281 .46942 L F
.59525 .47335 m .59659 .47104 L .59799 .47245 L 0 .031 .131 r
F
.59525 .47335 m .59385 .47196 L .59659 .47104 L F
.75922 .47128 m .76079 .46871 L .76204 .47034 L 0 .026 .125 r
F
.75922 .47128 m .75797 .46967 L .76079 .46871 L F
.29337 .47148 m .29428 .46919 L .29596 .47073 L 0 .027 .126 r
F
.29337 .47148 m .29169 .46995 L .29428 .46919 L F
.33885 .4713 m .33982 .46902 L .34146 .47051 L F
.33885 .4713 m .33721 .46981 L .33982 .46902 L F
.72063 .47114 m .72215 .4687 L .72344 .47031 L 0 .026 .125 r
F
.72063 .47114 m .71934 .46952 L .72215 .4687 L F
.60214 .47305 m .60349 .47063 L .60488 .47216 L 0 .03 .13 r
F
.60214 .47305 m .60074 .47155 L .60349 .47063 L F
.44087 .47268 m .44199 .47036 L .44353 .47185 L F
.44087 .47268 m .43932 .47119 L .44199 .47036 L F
.46569 .4737 m .46685 .47118 L .46837 .47281 L 0 .032 .132 r
F
.46569 .4737 m .46417 .4721 L .46685 .47118 L F
.76612 .47105 m .76769 .46851 L .76895 .47017 L 0 .026 .125 r
F
.76612 .47105 m .76487 .4694 L .76769 .46851 L F
.40227 .47258 m .40333 .47025 L .40491 .47183 L 0 .029 .129 r
F
.40227 .47258 m .40069 .47101 L .40333 .47025 L F
.66827 .47183 m .66972 .46948 L .67106 .47103 L 0 .028 .127 r
F
.66827 .47183 m .66694 .47027 L .66972 .46948 L F
.81849 .4705 m .82015 .4681 L .82134 .46967 L 0 .025 .123 r
F
.81849 .4705 m .81729 .46894 L .82015 .4681 L F
.60902 .47282 m .61039 .47042 L .61177 .47196 L 0 .03 .13 r
F
.60902 .47282 m .60763 .47127 L .61039 .47042 L F
.54977 .4738 m .55105 .47164 L .5525 .47309 L 0 .033 .133 r
F
.54977 .4738 m .54833 .47232 L .55105 .47164 L F
.51806 .47327 m .51929 .47082 L .52077 .47242 L 0 .031 .131 r
F
.51806 .47327 m .51658 .47169 L .51929 .47082 L F
.37055 .47214 m .37158 .46966 L .37318 .4713 L 0 .028 .128 r
F
.37055 .47214 m .36894 .47048 L .37158 .46966 L F
.34572 .47119 m .34671 .46873 L .34834 .47029 L 0 .026 .125 r
F
.34572 .47119 m .34408 .46964 L .34671 .46873 L F
.30023 .47139 m .30116 .46893 L .30284 .47049 L 0 .027 .126 r
F
.30023 .47139 m .29856 .46985 L .30116 .46893 L F
.47257 .47355 m .47375 .47103 L .47526 .47267 L 0 .032 .132 r
F
.47257 .47355 m .47106 .47191 L .47375 .47103 L F
.77302 .47091 m .77461 .46841 L .77585 .47001 L 0 .026 .125 r
F
.77302 .47091 m .77178 .46929 L .77461 .46841 L F
.61591 .47263 m .61729 .47024 L .61867 .47175 L 0 .03 .13 r
F
.61591 .47263 m .61453 .4711 L .61729 .47024 L F
.44774 .47263 m .44888 .47022 L .45041 .4718 L F
.44774 .47263 m .4462 .47104 L .44888 .47022 L F
.67517 .47168 m .67663 .4694 L .67795 .47084 L 0 .028 .127 r
F
.67517 .47168 m .67384 .47022 L .67663 .4694 L F
.72754 .47113 m .72906 .46863 L .73035 .47026 L 0 .026 .125 r
F
.72754 .47113 m .72625 .46948 L .72906 .46863 L F
.30711 .47117 m .30804 .46883 L .3097 .47042 L 0 .027 .126 r
F
.30711 .47117 m .30544 .4696 L .30804 .46883 L F
.55666 .4737 m .55795 .47136 L .55938 .47279 L 0 .032 .133 r
F
.55666 .4737 m .55522 .47228 L .55795 .47136 L F
.47946 .47332 m .48064 .47095 L .48214 .47249 L 0 .031 .132 r
F
.47946 .47332 m .47795 .47178 L .48064 .47095 L F
.68206 .47142 m .68353 .46912 L .68485 .47055 L 0 .027 .127 r
F
.68206 .47142 m .68074 .47001 L .68353 .46912 L F
.35259 .47105 m .35359 .46868 L .35521 .47033 L 0 .026 .126 r
F
.35259 .47105 m .35097 .46939 L .35359 .46868 L F
.77992 .47069 m .78152 .4682 L .78275 .46976 L 0 .026 .124 r
F
.77992 .47069 m .77868 .46911 L .78152 .4682 L F
.6228 .47241 m .62419 .47002 L .62556 .47153 L 0 .029 .129 r
F
.6228 .47241 m .62142 .47088 L .62419 .47002 L F
.56355 .47337 m .56484 .47094 L .56627 .47244 L 0 .032 .132 r
F
.56355 .47337 m .56211 .47188 L .56484 .47094 L F
.52494 .47319 m .52619 .47069 L .52765 .47233 L 0 .031 .131 r
F
.52494 .47319 m .52347 .47157 L .52619 .47069 L F
.40914 .47264 m .41022 .47021 L .41179 .47183 L 0 .03 .13 r
F
.40914 .47264 m .40756 .47105 L .41022 .47021 L F
.37742 .47207 m .37845 .46964 L .38006 .47123 L 0 .029 .128 r
F
.37742 .47207 m .37582 .47047 L .37845 .46964 L F
.78681 .47039 m .78842 .46787 L .78964 .46944 L 0 .025 .124 r
F
.78681 .47039 m .78558 .46881 L .78842 .46787 L F
.73444 .47098 m .73597 .46849 L .73725 .47009 L 0 .026 .125 r
F
.73444 .47098 m .73316 .46938 L .73597 .46849 L F
.62969 .47218 m .63109 .46984 L .63246 .47137 L 0 .029 .129 r
F
.62969 .47218 m .62832 .47067 L .63109 .46984 L F
.57043 .47316 m .57174 .4706 L .57317 .47227 L 0 .031 .131 r
F
.57043 .47316 m .569 .4715 L .57174 .4706 L F
.48634 .47317 m .48752 .47103 L .48903 .47245 L 0 .032 .132 r
F
.48634 .47317 m .48483 .47176 L .48752 .47103 L F
.68896 .47129 m .69043 .4688 L .69175 .47044 L 0 .027 .126 r
F
.68896 .47129 m .68763 .46967 L .69043 .4688 L F
.53183 .47301 m .53308 .4705 L .53454 .47211 L 0 .031 .131 r
F
.53183 .47301 m .53037 .47142 L .53308 .4705 L F
.79371 .47016 m .79533 .4677 L .79655 .46933 L 0 .025 .123 r
F
.79371 .47016 m .79248 .46853 L .79533 .4677 L F
.45462 .47267 m .45576 .47034 L .45729 .47198 L 0 .03 .131 r
F
.45462 .47267 m .45309 .47101 L .45576 .47034 L F
.74134 .47078 m .74289 .4684 L .74415 .46994 L 0 .026 .125 r
F
.74134 .47078 m .74007 .46925 L .74289 .4684 L F
.41601 .47252 m .4171 .47015 L .41867 .47165 L 0 .03 .13 r
F
.41601 .47252 m .41444 .47102 L .4171 .47015 L F
.4229 .4722 m .42399 .46987 L .42556 .4713 L 0 .029 .129 r
F
.4229 .4722 m .42133 .47075 L .42399 .46987 L F
.31396 .47124 m .31491 .46886 L .31657 .47043 L 0 .027 .127 r
F
.31396 .47124 m .3123 .46967 L .31491 .46886 L F
.63659 .47201 m .63799 .46974 L .63935 .47121 L 0 .029 .129 r
F
.63659 .47201 m .63522 .47055 L .63799 .46974 L F
.38429 .47203 m .38533 .4697 L .38693 .47129 L F
.38429 .47203 m .38269 .47047 L .38533 .4697 L F
.49322 .47307 m .49442 .47081 L .49592 .47227 L 0 .032 .132 r
F
.49322 .47307 m .49172 .47164 L .49442 .47081 L F
.53872 .47291 m .53998 .4706 L .54143 .47217 L 0 .031 .132 r
F
.53872 .47291 m .53726 .47133 L .53998 .4706 L F
.74824 .47066 m .7498 .46831 L .75106 .46985 L 0 .026 .125 r
F
.74824 .47066 m .74698 .46912 L .7498 .46831 L F
.57732 .47314 m .57864 .47073 L .58006 .47235 L 0 .032 .132 r
F
.57732 .47314 m .5759 .4715 L .57864 .47073 L F
.35945 .47125 m .36045 .46885 L .36207 .47048 L 0 .028 .127 r
F
.35945 .47125 m .35783 .46961 L .36045 .46885 L F
.69586 .47127 m .69734 .46878 L .69866 .47046 L 0 .027 .127 r
F
.69586 .47127 m .69454 .46961 L .69734 .46878 L F
.80062 .47013 m .80225 .46764 L .80347 .46927 L 0 .025 .124 r
F
.80062 .47013 m .7994 .4685 L .80225 .46764 L F
.42978 .47204 m .43088 .46986 L .43244 .47132 L 0 .03 .13 r
F
.42978 .47204 m .42822 .47058 L .43088 .46986 L F
.32084 .4711 m .32179 .46872 L .32345 .47023 L 0 .027 .127 r
F
.32084 .4711 m .31918 .46958 L .32179 .46872 L F
.64348 .47187 m .6449 .46958 L .64625 .47105 L 0 .029 .129 r
F
.64348 .47187 m .64212 .47041 L .6449 .46958 L F
.28222 .47096 m .28313 .4685 L .28482 .47004 L 0 .027 .126 r
F
.28222 .47096 m .28053 .46942 L .28313 .4685 L F
.65037 .47159 m .65179 .46915 L .65314 .47064 L 0 .028 .128 r
F
.65037 .47159 m .64902 .4701 L .65179 .46915 L F
.32771 .47086 m .32868 .46848 L .33033 .46996 L 0 .027 .126 r
F
.32771 .47086 m .32606 .46936 L .32868 .46848 L F
.50011 .47297 m .50131 .47063 L .5028 .4721 L 0 .032 .132 r
F
.50011 .47297 m .49861 .47146 L .50131 .47063 L F
.39116 .47203 m .39222 .46948 L .39381 .4711 L 0 .029 .129 r
F
.39116 .47203 m .38957 .47043 L .39222 .46948 L F
.2891 .47071 m .29 .46841 L .29169 .46995 L 0 .027 .126 r
F
.2891 .47071 m .28741 .46918 L .29 .46841 L F
.80753 .46997 m .80917 .46751 L .81038 .46909 L 0 .025 .124 r
F
.80753 .46997 m .80632 .46839 L .80917 .46751 L F
.65726 .47132 m .65868 .46873 L .66003 .47037 L 0 .028 .127 r
F
.65726 .47132 m .65591 .46968 L .65868 .46873 L F
.58422 .47305 m .58555 .47082 L .58696 .47228 L 0 .032 .133 r
F
.58422 .47305 m .5828 .47158 L .58555 .47082 L F
.50699 .47268 m .50821 .47044 L .50969 .47185 L 0 .031 .132 r
F
.50699 .47268 m .50551 .47124 L .50821 .47044 L F
.33459 .4706 m .33556 .46831 L .33721 .46981 L 0 .027 .126 r
F
.33459 .4706 m .33295 .4691 L .33556 .46831 L F
.75515 .47061 m .75671 .4681 L .75797 .46967 L 0 .026 .125 r
F
.75515 .47061 m .75389 .46904 L .75671 .4681 L F
.71654 .47043 m .71805 .468 L .71934 .46952 L F
.71654 .47043 m .71525 .46891 L .71805 .468 L F
.39804 .47177 m .3991 .4694 L .40069 .47101 L 0 .029 .129 r
F
.39804 .47177 m .39646 .47017 L .3991 .4694 L F
.70965 .47082 m .71115 .46834 L .71245 .46986 L 0 .027 .126 r
F
.70965 .47082 m .70835 .4693 L .71115 .46834 L F
.70276 .47121 m .70425 .46863 L .70556 .47025 L 0 .028 .127 r
F
.70276 .47121 m .70145 .46957 L .70425 .46863 L F
.46149 .47293 m .46265 .47047 L .46417 .4721 L 0 .032 .132 r
F
.46149 .47293 m .45997 .4713 L .46265 .47047 L F
.66415 .47106 m .66559 .46864 L .66694 .47027 L 0 .027 .127 r
F
.66415 .47106 m .66281 .46942 L .66559 .46864 L F
.43665 .47203 m .43777 .4697 L .43932 .47119 L 0 .03 .13 r
F
.43665 .47203 m .4351 .47054 L .43777 .4697 L F
.5456 .473 m .54688 .47075 L .54833 .47232 L 0 .032 .133 r
F
.5456 .473 m .54415 .47144 L .54688 .47075 L F
.76204 .47034 m .76361 .46776 L .76487 .4694 L 0 .026 .125 r
F
.76204 .47034 m .76079 .46871 L .76361 .46776 L F
.36631 .47131 m .36733 .46884 L .36894 .47048 L 0 .028 .128 r
F
.36631 .47131 m .3647 .46966 L .36733 .46884 L F
.59799 .47245 m .59934 .47012 L .60074 .47155 L 0 .031 .131 r
F
.59799 .47245 m .59659 .47104 L .59934 .47012 L F
.81443 .46979 m .81609 .46737 L .81729 .46894 L 0 .025 .123 r
F
.81443 .46979 m .81323 .46823 L .81609 .46737 L F
.59111 .47287 m .59245 .47057 L .59385 .47196 L 0 .032 .132 r
F
.59111 .47287 m .5897 .4715 L .59245 .47057 L F
.51388 .47249 m .51511 .47031 L .51658 .47169 L 0 .031 .132 r
F
.51388 .47249 m .5124 .47108 L .51511 .47031 L F
.60488 .47216 m .60624 .46971 L .60763 .47127 L 0 .03 .13 r
F
.60488 .47216 m .60349 .47063 L .60624 .46971 L F
.72344 .47031 m .72496 .46788 L .72625 .46948 L 0 .026 .125 r
F
.72344 .47031 m .72215 .4687 L .72496 .46788 L F
.34146 .47051 m .34244 .46814 L .34408 .46964 L 0 .027 .126 r
F
.34146 .47051 m .33982 .46902 L .34244 .46814 L F
.46837 .47281 m .46954 .47027 L .47106 .47191 L 0 .031 .132 r
F
.46837 .47281 m .46685 .47118 L .46954 .47027 L F
.44353 .47185 m .44466 .46955 L .4462 .47104 L 0 .03 .13 r
F
.44353 .47185 m .44199 .47036 L .44466 .46955 L F
.29596 .47073 m .29688 .46829 L .29856 .46985 L 0 .027 .126 r
F
.29596 .47073 m .29428 .46919 L .29688 .46829 L F
.76895 .47017 m .77052 .46761 L .77178 .46929 L 0 .026 .125 r
F
.76895 .47017 m .76769 .46851 L .77052 .46761 L F
.82134 .46967 m .82301 .46728 L .8242 .46884 L 0 .025 .124 r
F
.82134 .46967 m .82015 .4681 L .82301 .46728 L F
.61177 .47196 m .61314 .46959 L .61453 .4711 L 0 .03 .13 r
F
.61177 .47196 m .61039 .47042 L .61314 .46959 L F
.67106 .47103 m .67251 .46869 L .67384 .47022 L 0 .028 .128 r
F
.67106 .47103 m .66972 .46948 L .67251 .46869 L F
.34834 .47029 m .34934 .46783 L .35097 .46939 L 0 .026 .125 r
F
.34834 .47029 m .34671 .46873 L .34934 .46783 L F
.30284 .47049 m .30377 .46802 L .30544 .4696 L 0 .027 .126 r
F
.30284 .47049 m .30116 .46893 L .30377 .46802 L F
.40491 .47183 m .40599 .46946 L .40756 .47105 L 0 .03 .13 r
F
.40491 .47183 m .40333 .47025 L .40599 .46946 L F
.52077 .47242 m .522 .46995 L .52347 .47157 L 0 .031 .131 r
F
.52077 .47242 m .51929 .47082 L .522 .46995 L F
.37318 .4713 m .37421 .46885 L .37582 .47047 L 0 .028 .128 r
F
.37318 .4713 m .37158 .46966 L .37421 .46885 L F
.47526 .47267 m .47643 .47016 L .47795 .47178 L 0 .031 .132 r
F
.47526 .47267 m .47375 .47103 L .47643 .47016 L F
.77585 .47001 m .77744 .46751 L .77868 .46911 L 0 .026 .125 r
F
.77585 .47001 m .77461 .46841 L .77744 .46751 L F
.61867 .47175 m .62005 .4694 L .62142 .47088 L 0 .03 .13 r
F
.61867 .47175 m .61729 .47024 L .62005 .4694 L F
.5525 .47309 m .55378 .47084 L .55522 .47228 L 0 .033 .134 r
F
.5525 .47309 m .55105 .47164 L .55378 .47084 L F
.73035 .47026 m .73188 .46776 L .73316 .46938 L 0 .026 .125 r
F
.73035 .47026 m .72906 .46863 L .73188 .46776 L F
.67795 .47084 m .67942 .46859 L .68074 .47001 L 0 .028 .127 r
F
.67795 .47084 m .67663 .4694 L .67942 .46859 L F
.45041 .4718 m .45155 .46943 L .45309 .47101 L 0 .03 .13 r
F
.45041 .4718 m .44888 .47022 L .45155 .46943 L F
.55938 .47279 m .56068 .47043 L .56211 .47188 L 0 .032 .133 r
F
.55938 .47279 m .55795 .47136 L .56068 .47043 L F
.78275 .46976 m .78435 .46725 L .78558 .46881 L 0 .025 .124 r
F
.78275 .46976 m .78152 .4682 L .78435 .46725 L F
.56627 .47244 m .56758 .46999 L .569 .4715 L 0 .031 .132 r
F
.56627 .47244 m .56484 .47094 L .56758 .46999 L F
.68485 .47055 m .68632 .46822 L .68763 .46967 L 0 .027 .127 r
F
.68485 .47055 m .68353 .46912 L .68632 .46822 L F
.62556 .47153 m .62695 .46916 L .62832 .47067 L 0 .029 .129 r
F
.62556 .47153 m .62419 .47002 L .62695 .46916 L F
.48214 .47249 m .48333 .47022 L .48483 .47176 L 0 .032 .132 r
F
.48214 .47249 m .48064 .47095 L .48333 .47022 L F
.78964 .46944 m .79126 .46696 L .79248 .46853 L 0 .025 .123 r
F
.78964 .46944 m .78842 .46787 L .79126 .46696 L F
.3097 .47042 m .31064 .46806 L .3123 .46967 L 0 .027 .126 r
F
.3097 .47042 m .30804 .46883 L .31064 .46806 L F
.52765 .47233 m .5289 .46977 L .53037 .47142 L 0 .031 .131 r
F
.52765 .47233 m .52619 .47069 L .5289 .46977 L F
.38006 .47123 m .38109 .46889 L .38269 .47047 L 0 .029 .129 r
F
.38006 .47123 m .37845 .46964 L .38109 .46889 L F
.73725 .47009 m .73879 .46763 L .74007 .46925 L 0 .026 .125 r
F
.73725 .47009 m .73597 .46849 L .73879 .46763 L F
.41179 .47183 m .41287 .46938 L .41444 .47102 L 0 .03 .13 r
F
.41179 .47183 m .41022 .47021 L .41287 .46938 L F
.35521 .47033 m .35621 .46797 L .35783 .46961 L 0 .027 .126 r
F
.35521 .47033 m .35359 .46868 L .35621 .46797 L F
.57317 .47227 m .57448 .46985 L .5759 .4715 L 0 .031 .132 r
F
.57317 .47227 m .57174 .4706 L .57448 .46985 L F
.53454 .47211 m .5358 .46972 L .53726 .47133 L 0 .031 .131 r
F
.53454 .47211 m .53308 .4705 L .5358 .46972 L F
.63246 .47137 m .63385 .46901 L .63522 .47055 L 0 .029 .129 r
F
.63246 .47137 m .63109 .46984 L .63385 .46901 L F
.69175 .47044 m .69322 .46795 L .69454 .46961 L 0 .027 .126 r
F
.69175 .47044 m .69043 .4688 L .69322 .46795 L F
.79655 .46933 m .79818 .46687 L .7994 .4685 L 0 .025 .123 r
F
.79655 .46933 m .79533 .4677 L .79818 .46687 L F
.41867 .47165 m .41976 .46926 L .42133 .47075 L 0 .03 .13 r
F
.41867 .47165 m .4171 .47015 L .41976 .46926 L F
.74415 .46994 m .74571 .46758 L .74698 .46912 L 0 .026 .125 r
F
.74415 .46994 m .74289 .4684 L .74571 .46758 L F
.48903 .47245 m .49022 .4702 L .49172 .47164 L 0 .032 .133 r
F
.48903 .47245 m .48752 .47103 L .49022 .4702 L F
.42556 .4713 m .42665 .46914 L .42822 .47058 L 0 .03 .13 r
F
.42556 .4713 m .42399 .46987 L .42665 .46914 L F
.31657 .47043 m .31752 .468 L .31918 .46958 L 0 .027 .127 r
F
.31657 .47043 m .31491 .46886 L .31752 .468 L F
.63935 .47121 m .64076 .46893 L .64212 .47041 L 0 .029 .129 r
F
.63935 .47121 m .63799 .46974 L .64076 .46893 L F
.45729 .47198 m .45844 .46966 L .45997 .4713 L 0 .031 .131 r
F
.45729 .47198 m .45576 .47034 L .45844 .46966 L F
.38693 .47129 m .38798 .46882 L .38957 .47043 L 0 .029 .129 r
F
.38693 .47129 m .38533 .4697 L .38798 .46882 L F
.27793 .47034 m .27884 .46775 L .28053 .46942 L 0 .027 .126 r
F
.27793 .47034 m .27625 .46867 L .27884 .46775 L F
.49592 .47227 m .49712 .46998 L .49861 .47146 L 0 .032 .132 r
F
.49592 .47227 m .49442 .47081 L .49712 .46998 L F
.80347 .46927 m .8051 .46677 L .80632 .46839 L 0 .025 .124 r
F
.80347 .46927 m .80225 .46764 L .8051 .46677 L F
.75106 .46985 m .75263 .4675 L .75389 .46904 L 0 .026 .126 r
F
.75106 .46985 m .7498 .46831 L .75263 .4675 L F
.32345 .47023 m .3244 .46785 L .32606 .46936 L 0 .027 .127 r
F
.32345 .47023 m .32179 .46872 L .3244 .46785 L F
.28482 .47004 m .28572 .46763 L .28741 .46918 L 0 .027 .126 r
F
.28482 .47004 m .28313 .4685 L .28572 .46763 L F
.58006 .47235 m .58138 .46998 L .5828 .47158 L 0 .032 .133 r
F
.58006 .47235 m .57864 .47073 L .58138 .46998 L F
.65314 .47064 m .65456 .4682 L .65591 .46968 L 0 .028 .128 r
F
.65314 .47064 m .65179 .46915 L .65456 .4682 L F
.54143 .47217 m .5427 .46987 L .54415 .47144 L 0 .032 .132 r
F
.54143 .47217 m .53998 .4706 L .5427 .46987 L F
.69866 .47046 m .70014 .46789 L .70145 .46957 L 0 .027 .127 r
F
.69866 .47046 m .69734 .46878 L .70014 .46789 L F
.64625 .47105 m .64767 .46864 L .64902 .4701 L 0 .029 .129 r
F
.64625 .47105 m .6449 .46958 L .64767 .46864 L F
.36207 .47048 m .36309 .46804 L .3647 .46966 L 0 .028 .127 r
F
.36207 .47048 m .36045 .46885 L .36309 .46804 L F
.39381 .4711 m .39487 .46853 L .39646 .47017 L 0 .029 .129 r
F
.39381 .4711 m .39222 .46948 L .39487 .46853 L F
.33033 .46996 m .33129 .46762 L .33295 .4691 L 0 .027 .126 r
F
.33033 .46996 m .32868 .46848 L .33129 .46762 L F
.43244 .47132 m .43354 .46908 L .4351 .47054 L 0 .03 .13 r
F
.43244 .47132 m .43088 .46986 L .43354 .46908 L F
.66003 .47037 m .66146 .46778 L .66281 .46942 L 0 .027 .127 r
F
.66003 .47037 m .65868 .46873 L .66146 .46778 L F
.5028 .4721 m .50402 .46979 L .50551 .47124 L 0 .032 .132 r
F
.5028 .4721 m .50131 .47063 L .50402 .46979 L F
.81038 .46909 m .81202 .46665 L .81323 .46823 L 0 .025 .124 r
F
.81038 .46909 m .80917 .46751 L .81202 .46665 L F
.75797 .46967 m .75953 .46713 L .76079 .46871 L 0 .026 .125 r
F
.75797 .46967 m .75671 .4681 L .75953 .46713 L F
.71245 .46986 m .71395 .46738 L .71525 .46891 L 0 .027 .126 r
F
.71245 .46986 m .71115 .46834 L .71395 .46738 L F
.70556 .47025 m .70705 .46769 L .70835 .4693 L 0 .027 .127 r
F
.70556 .47025 m .70425 .46863 L .70705 .46769 L F
.71934 .46952 m .72086 .46719 L .72215 .4687 L 0 .026 .125 r
F
.71934 .46952 m .71805 .468 L .72086 .46719 L F
.50969 .47185 m .51092 .4697 L .5124 .47108 L 0 .032 .132 r
F
.50969 .47185 m .50821 .47044 L .51092 .4697 L F
.29169 .46995 m .29259 .46764 L .29428 .46919 L 0 .027 .126 r
F
.29169 .46995 m .29 .46841 L .29259 .46764 L F
.76487 .4694 m .76644 .46684 L .76769 .46851 L 0 .026 .124 r
F
.76487 .4694 m .76361 .46776 L .76644 .46684 L F
.58696 .47228 m .58829 .47006 L .5897 .4715 L 0 .032 .133 r
F
.58696 .47228 m .58555 .47082 L .58829 .47006 L F
.46417 .4721 m .46533 .46957 L .46685 .47118 L 0 .032 .132 r
F
.46417 .4721 m .46265 .47047 L .46533 .46957 L F
.33721 .46981 m .33818 .46752 L .33982 .46902 L 0 .027 .126 r
F
.33721 .46981 m .33556 .46831 L .33818 .46752 L F
.60074 .47155 m .60209 .46918 L .60349 .47063 L 0 .031 .131 r
F
.60074 .47155 m .59934 .47012 L .60209 .46918 L F
.43932 .47119 m .44044 .46885 L .44199 .47036 L 0 .03 .13 r
F
.43932 .47119 m .43777 .4697 L .44044 .46885 L F
.59385 .47196 m .59519 .46963 L .59659 .47104 L 0 .032 .132 r
F
.59385 .47196 m .59245 .47057 L .59519 .46963 L F
.40069 .47101 m .40175 .46864 L .40333 .47025 L 0 .029 .129 r
F
.40069 .47101 m .3991 .4694 L .40175 .46864 L F
.66694 .47027 m .66838 .46785 L .66972 .46948 L 0 .028 .127 r
F
.66694 .47027 m .66559 .46864 L .66838 .46785 L F
.81729 .46894 m .81895 .46654 L .82015 .4681 L 0 .025 .124 r
F
.81729 .46894 m .81609 .46737 L .81895 .46654 L F
.36894 .47048 m .36997 .46804 L .37158 .46966 L 0 .028 .128 r
F
.36894 .47048 m .36733 .46884 L .36997 .46804 L F
.60763 .47127 m .60899 .46888 L .61039 .47042 L 0 .03 .13 r
F
.60763 .47127 m .60624 .46971 L .60899 .46888 L F
.51658 .47169 m .51782 .46943 L .51929 .47082 L 0 .031 .132 r
F
.51658 .47169 m .51511 .47031 L .51782 .46943 L F
.47106 .47191 m .47223 .4694 L .47375 .47103 L F
.47106 .47191 m .46954 .47027 L .47223 .4694 L F
.34408 .46964 m .34507 .46722 L .34671 .46873 L 0 .027 .126 r
F
.34408 .46964 m .34244 .46814 L .34507 .46722 L F
.54833 .47232 m .54961 .47006 L .55105 .47164 L 0 .033 .134 r
F
.54833 .47232 m .54688 .47075 L .54961 .47006 L F
.29856 .46985 m .29949 .46735 L .30116 .46893 L 0 .027 .126 r
F
.29856 .46985 m .29688 .46829 L .29949 .46735 L F
.77178 .46929 m .77336 .46672 L .77461 .46841 L 0 .026 .124 r
F
.77178 .46929 m .77052 .46761 L .77336 .46672 L F
.72625 .46948 m .72778 .46704 L .72906 .46863 L 0 .026 .125 r
F
.72625 .46948 m .72496 .46788 L .72778 .46704 L F
.4462 .47104 m .44733 .46875 L .44888 .47022 L 0 .03 .13 r
F
.4462 .47104 m .44466 .46955 L .44733 .46875 L F
.61453 .4711 m .6159 .46876 L .61729 .47024 L F
.61453 .4711 m .61314 .46959 L .6159 .46876 L F
.35097 .46939 m .35196 .46711 L .35359 .46868 L 0 .026 .125 r
F
.35097 .46939 m .34934 .46783 L .35196 .46711 L F
.30544 .4696 m .30637 .46723 L .30804 .46883 L 0 .027 .126 r
F
.30544 .4696 m .30377 .46802 L .30637 .46723 L F
.8242 .46884 m .82588 .46646 L .82707 .46801 L 0 .025 .124 r
F
.8242 .46884 m .82301 .46728 L .82588 .46646 L F
.67384 .47022 m .6753 .46789 L .67663 .4694 L 0 .028 .128 r
F
.67384 .47022 m .67251 .46869 L .6753 .46789 L F
.52347 .47157 m .52472 .46905 L .52619 .47069 L 0 .031 .131 r
F
.52347 .47157 m .522 .46995 L .52472 .46905 L F
.77868 .46911 m .78028 .46661 L .78152 .4682 L 0 .026 .124 r
F
.77868 .46911 m .77744 .46751 L .78028 .46661 L F
.47795 .47178 m .47912 .46933 L .48064 .47095 L 0 .031 .132 r
F
.47795 .47178 m .47643 .47016 L .47912 .46933 L F
.37582 .47047 m .37685 .46805 L .37845 .46964 L 0 .029 .128 r
F
.37582 .47047 m .37421 .46885 L .37685 .46805 L F
.40756 .47105 m .40864 .4686 L .41022 .47021 L 0 .03 .13 r
F
.40756 .47105 m .40599 .46946 L .40864 .4686 L F
.62142 .47088 m .62281 .46856 L .62419 .47002 L F
.62142 .47088 m .62005 .4694 L .62281 .46856 L F
.73316 .46938 m .73469 .46689 L .73597 .46849 L 0 .026 .125 r
F
.73316 .46938 m .73188 .46776 L .73469 .46689 L F
.78558 .46881 m .78719 .46631 L .78842 .46787 L 0 .025 .124 r
F
.78558 .46881 m .78435 .46725 L .78719 .46631 L F
.56211 .47188 m .56341 .46949 L .56484 .47094 L 0 .032 .133 r
F
.56211 .47188 m .56068 .47043 L .56341 .46949 L F
.569 .4715 m .57031 .46909 L .57174 .4706 L 0 .031 .131 r
F
.569 .4715 m .56758 .46999 L .57031 .46909 L F
.55522 .47228 m .55651 .4699 L .55795 .47136 L 0 .033 .134 r
F
.55522 .47228 m .55378 .47084 L .55651 .4699 L F
.68074 .47001 m .68221 .46769 L .68353 .46912 L 0 .028 .127 r
F
.68074 .47001 m .67942 .46859 L .68221 .46769 L F
.68763 .46967 m .68911 .46733 L .69043 .4688 L 0 .027 .127 r
F
.68763 .46967 m .68632 .46822 L .68911 .46733 L F
.45309 .47101 m .45423 .46876 L .45576 .47034 L 0 .03 .131 r
F
.45309 .47101 m .45155 .46943 L .45423 .46876 L F
.79248 .46853 m .79411 .46614 L .79533 .4677 L 0 .025 .123 r
F
.79248 .46853 m .79126 .46696 L .79411 .46614 L F
.53037 .47142 m .53162 .46884 L .53308 .4705 L 0 .031 .131 r
F
.53037 .47142 m .5289 .46977 L .53162 .46884 L F
.62832 .47067 m .62971 .46831 L .63109 .46984 L 0 .029 .129 r
F
.62832 .47067 m .62695 .46916 L .62971 .46831 L F
.74007 .46925 m .74161 .46677 L .74289 .4684 L 0 .026 .125 r
F
.74007 .46925 m .73879 .46763 L .74161 .46677 L F
.48483 .47176 m .48602 .46948 L .48752 .47103 L 0 .032 .133 r
F
.48483 .47176 m .48333 .47022 L .48602 .46948 L F
.3123 .46967 m .31325 .46723 L .31491 .46886 L 0 .027 .127 r
F
.3123 .46967 m .31064 .46806 L .31325 .46723 L F
.41444 .47102 m .41553 .4685 L .4171 .47015 L 0 .03 .13 r
F
.41444 .47102 m .41287 .46938 L .41553 .4685 L F
.38269 .47047 m .38373 .46814 L .38533 .4697 L 0 .029 .129 r
F
.38269 .47047 m .38109 .46889 L .38373 .46814 L F
.5759 .4715 m .57722 .46911 L .57864 .47073 L 0 .032 .132 r
F
.5759 .4715 m .57448 .46985 L .57722 .46911 L F
.63522 .47055 m .63662 .46818 L .63799 .46974 L 0 .029 .129 r
F
.63522 .47055 m .63385 .46901 L .63662 .46818 L F
.42133 .47075 m .42243 .46839 L .42399 .46987 L 0 .03 .13 r
F
.42133 .47075 m .41976 .46926 L .42243 .46839 L F
.69454 .46961 m .69602 .4671 L .69734 .46878 L 0 .027 .127 r
F
.69454 .46961 m .69322 .46795 L .69602 .4671 L F
.35783 .46961 m .35884 .46722 L .36045 .46885 L F
.35783 .46961 m .35621 .46797 L .35884 .46722 L F
.53726 .47133 m .53852 .46899 L .53998 .4706 L 0 .031 .132 r
F
.53726 .47133 m .5358 .46972 L .53852 .46899 L F
.7994 .4685 m .80103 .46601 L .80225 .46764 L 0 .025 .123 r
F
.7994 .4685 m .79818 .46687 L .80103 .46601 L F
.74698 .46912 m .74854 .46677 L .7498 .46831 L 0 .026 .126 r
F
.74698 .46912 m .74571 .46758 L .74854 .46677 L F
.49172 .47164 m .49292 .46934 L .49442 .47081 L 0 .032 .133 r
F
.49172 .47164 m .49022 .4702 L .49292 .46934 L F
.31918 .46958 m .32013 .46714 L .32179 .46872 L 0 .027 .127 r
F
.31918 .46958 m .31752 .468 L .32013 .46714 L F
.28053 .46942 m .28144 .46684 L .28313 .4685 L 0 .027 .126 r
F
.28053 .46942 m .27884 .46775 L .28144 .46684 L F
.42822 .47058 m .42932 .46841 L .43088 .46986 L 0 .03 .13 r
F
.42822 .47058 m .42665 .46914 L .42932 .46841 L F
.64212 .47041 m .64354 .46809 L .6449 .46958 L F
.64212 .47041 m .64076 .46893 L .64354 .46809 L F
.38957 .47043 m .39063 .46786 L .39222 .46948 L 0 .029 .129 r
F
.38957 .47043 m .38798 .46882 L .39063 .46786 L F
.65591 .46968 m .65734 .46725 L .65868 .46873 L 0 .028 .127 r
F
.65591 .46968 m .65456 .4682 L .65734 .46725 L F
.64902 .4701 m .65044 .4677 L .65179 .46915 L 0 .029 .129 r
F
.64902 .4701 m .64767 .46864 L .65044 .4677 L F
.80632 .46839 m .80796 .4659 L .80917 .46751 L 0 .025 .124 r
F
.80632 .46839 m .8051 .46677 L .80796 .4659 L F
.32606 .46936 m .32702 .46698 L .32868 .46848 L 0 .027 .127 r
F
.32606 .46936 m .3244 .46785 L .32702 .46698 L F
.49861 .47146 m .49982 .46915 L .50131 .47063 L 0 .032 .133 r
F
.49861 .47146 m .49712 .46998 L .49982 .46915 L F
.28741 .46918 m .28831 .46685 L .29 .46841 L 0 .027 .126 r
F
.28741 .46918 m .28572 .46763 L .28831 .46685 L F
.70145 .46957 m .70294 .46696 L .70425 .46863 L 0 .027 .127 r
F
.70145 .46957 m .70014 .46789 L .70294 .46696 L F
.45997 .4713 m .46112 .46885 L .46265 .47047 L 0 .031 .132 r
F
.45997 .4713 m .45844 .46966 L .46112 .46885 L F
.39646 .47017 m .39752 .46776 L .3991 .4694 L 0 .029 .129 r
F
.39646 .47017 m .39487 .46853 L .39752 .46776 L F
.66281 .46942 m .66425 .467 L .66559 .46864 L 0 .027 .127 r
F
.66281 .46942 m .66146 .46778 L .66425 .467 L F
.75389 .46904 m .75546 .46656 L .75671 .4681 L 0 .026 .126 r
F
.75389 .46904 m .75263 .4675 L .75546 .46656 L F
.3647 .46966 m .36572 .46723 L .36733 .46884 L 0 .028 .127 r
F
.3647 .46966 m .36309 .46804 L .36572 .46723 L F
.76079 .46871 m .76236 .46618 L .76361 .46776 L 0 .026 .125 r
F
.76079 .46871 m .75953 .46713 L .76236 .46618 L F
.5828 .47158 m .58413 .46923 L .58555 .47082 L 0 .032 .133 r
F
.5828 .47158 m .58138 .46998 L .58413 .46923 L F
.71525 .46891 m .71676 .46648 L .71805 .468 L 0 .026 .125 r
F
.71525 .46891 m .71395 .46738 L .71676 .46648 L F
.33295 .4691 m .33391 .46682 L .33556 .46831 L 0 .027 .126 r
F
.33295 .4691 m .33129 .46762 L .33391 .46682 L F
.70835 .4693 m .70985 .46674 L .71115 .46834 L F
.70835 .4693 m .70705 .46769 L .70985 .46674 L F
.50551 .47124 m .50672 .46902 L .50821 .47044 L 0 .032 .132 r
F
.50551 .47124 m .50402 .46979 L .50672 .46902 L F
.54415 .47144 m .54543 .46917 L .54688 .47075 L 0 .032 .133 r
F
.54415 .47144 m .5427 .46987 L .54543 .46917 L F
.81323 .46823 m .81488 .46578 L .81609 .46737 L 0 .025 .124 r
F
.81323 .46823 m .81202 .46665 L .81488 .46578 L F
.4351 .47054 m .43622 .46821 L .43777 .4697 L 0 .03 .13 r
F
.4351 .47054 m .43354 .46908 L .43622 .46821 L F
.46685 .47118 m .46802 .46866 L .46954 .47027 L 0 .031 .132 r
F
.46685 .47118 m .46533 .46957 L .46802 .46866 L F
.76769 .46851 m .76927 .46592 L .77052 .46761 L 0 .025 .124 r
F
.76769 .46851 m .76644 .46684 L .76927 .46592 L F
.72215 .4687 m .72368 .46638 L .72496 .46788 L 0 .026 .125 r
F
.72215 .4687 m .72086 .46719 L .72368 .46638 L F
.60349 .47063 m .60484 .46825 L .60624 .46971 L 0 .03 .131 r
F
.60349 .47063 m .60209 .46918 L .60484 .46825 L F
.59659 .47104 m .59794 .46869 L .59934 .47012 L 0 .031 .132 r
F
.59659 .47104 m .59519 .46963 L .59794 .46869 L F
.5124 .47108 m .51362 .46896 L .51511 .47031 L 0 .032 .133 r
F
.5124 .47108 m .51092 .4697 L .51362 .46896 L F
.29428 .46919 m .2952 .46673 L .29688 .46829 L 0 .027 .127 r
F
.29428 .46919 m .29259 .46764 L .2952 .46673 L F
.5897 .4715 m .59104 .46911 L .59245 .47057 L 0 .032 .133 r
F
.5897 .4715 m .58829 .47006 L .59104 .46911 L F
.33982 .46902 m .3408 .46663 L .34244 .46814 L 0 .027 .126 r
F
.33982 .46902 m .33818 .46752 L .3408 .46663 L F
.44199 .47036 m .44311 .46807 L .44466 .46955 L 0 .03 .13 r
F
.44199 .47036 m .44044 .46885 L .44311 .46807 L F
.82015 .4681 m .82181 .46572 L .82301 .46728 L 0 .025 .124 r
F
.82015 .4681 m .81895 .46654 L .82181 .46572 L F
.61039 .47042 m .61175 .46808 L .61314 .46959 L 0 .03 .13 r
F
.61039 .47042 m .60899 .46888 L .61175 .46808 L F
.37158 .46966 m .3726 .46725 L .37421 .46885 L 0 .028 .128 r
F
.37158 .46966 m .36997 .46804 L .3726 .46725 L F
.66972 .46948 m .67117 .46707 L .67251 .46869 L F
.66972 .46948 m .66838 .46785 L .67117 .46707 L F
.51929 .47082 m .52053 .46853 L .522 .46995 L 0 .031 .132 r
F
.51929 .47082 m .51782 .46943 L .52053 .46853 L F
.40333 .47025 m .40441 .46784 L .40599 .46946 L 0 .03 .13 r
F
.40333 .47025 m .40175 .46864 L .40441 .46784 L F
.34671 .46873 m .3477 .46631 L .34934 .46783 L 0 .026 .125 r
F
.34671 .46873 m .34507 .46722 L .3477 .46631 L F
.30116 .46893 m .3021 .46643 L .30377 .46802 L 0 .027 .126 r
F
.30116 .46893 m .29949 .46735 L .3021 .46643 L F
.47375 .47103 m .47492 .46853 L .47643 .47016 L 0 .031 .132 r
F
.47375 .47103 m .47223 .4694 L .47492 .46853 L F
.77461 .46841 m .7762 .46584 L .77744 .46751 L 0 .026 .124 r
F
.77461 .46841 m .77336 .46672 L .7762 .46584 L F
.72906 .46863 m .7306 .46618 L .73188 .46776 L 0 .026 .125 r
F
.72906 .46863 m .72778 .46704 L .7306 .46618 L F
.44888 .47022 m .45001 .46799 L .45155 .46943 L 0 .03 .13 r
F
.44888 .47022 m .44733 .46875 L .45001 .46799 L F
.61729 .47024 m .61867 .46795 L .62005 .4694 L F
.61729 .47024 m .6159 .46876 L .61867 .46795 L F
.78152 .4682 m .78312 .46568 L .78435 .46725 L 0 .025 .124 r
F
.78152 .4682 m .78028 .46661 L .78312 .46568 L F
.55105 .47164 m .55234 .46925 L .55378 .47084 L 0 .033 .134 r
F
.55105 .47164 m .54961 .47006 L .55234 .46925 L F
.82707 .46801 m .82874 .46552 L .82992 .46707 L 0 .025 .124 r
F
.82707 .46801 m .82588 .46646 L .82874 .46552 L F
.52619 .47069 m .52743 .46812 L .5289 .46977 L 0 .031 .131 r
F
.52619 .47069 m .52472 .46905 L .52743 .46812 L F
.78842 .46787 m .79003 .46541 L .79126 .46696 L 0 .025 .123 r
F
.78842 .46787 m .78719 .46631 L .79003 .46541 L F
.30804 .46883 m .30897 .46644 L .31064 .46806 L 0 .027 .126 r
F
.30804 .46883 m .30637 .46723 L .30897 .46644 L F
.67663 .4694 m .6781 .46709 L .67942 .46859 L 0 .028 .128 r
F
.67663 .4694 m .6753 .46789 L .6781 .46709 L F
.56484 .47094 m .56615 .46854 L .56758 .46999 L 0 .032 .132 r
F
.56484 .47094 m .56341 .46949 L .56615 .46854 L F
.48064 .47095 m .48182 .46859 L .48333 .47022 L F
.48064 .47095 m .47912 .46933 L .48182 .46859 L F
.55795 .47136 m .55924 .46896 L .56068 .47043 L 0 .033 .133 r
F
.55795 .47136 m .55651 .4699 L .55924 .46896 L F
.62419 .47002 m .62557 .4677 L .62695 .46916 L 0 .03 .13 r
F
.62419 .47002 m .62281 .46856 L .62557 .4677 L F
.35359 .46868 m .35458 .4664 L .35621 .46797 L 0 .027 .126 r
F
.35359 .46868 m .35196 .46711 L .35458 .4664 L F
.41022 .47021 m .4113 .46773 L .41287 .46938 L 0 .03 .13 r
F
.41022 .47021 m .40864 .4686 L .4113 .46773 L F
.73597 .46849 m .73751 .46601 L .73879 .46763 L 0 .026 .125 r
F
.73597 .46849 m .73469 .46689 L .73751 .46601 L F
.37845 .46964 m .37949 .46731 L .38109 .46889 L 0 .029 .129 r
F
.37845 .46964 m .37685 .46805 L .37949 .46731 L F
.57174 .4706 m .57305 .46836 L .57448 .46985 L 0 .031 .132 r
F
.57174 .4706 m .57031 .46909 L .57305 .46836 L F
.68353 .46912 m .685 .46677 L .68632 .46822 L 0 .028 .127 r
F
.68353 .46912 m .68221 .46769 L .685 .46677 L F
.53308 .4705 m .53434 .46806 L .5358 .46972 L 0 .031 .131 r
F
.53308 .4705 m .53162 .46884 L .53434 .46806 L F
.69043 .4688 m .69191 .46646 L .69322 .46795 L 0 .027 .127 r
F
.69043 .4688 m .68911 .46733 L .69191 .46646 L F
.79533 .4677 m .79696 .46531 L .79818 .46687 L 0 .025 .123 r
F
.79533 .4677 m .79411 .46614 L .79696 .46531 L F
.63109 .46984 m .63248 .46745 L .63385 .46901 L 0 .029 .129 r
F
.63109 .46984 m .62971 .46831 L .63248 .46745 L F
.74289 .4684 m .74444 .46593 L .74571 .46758 L 0 .026 .125 r
F
.74289 .4684 m .74161 .46677 L .74444 .46593 L F
.45576 .47034 m .45691 .46809 L .45844 .46966 L 0 .031 .131 r
F
.45576 .47034 m .45423 .46876 L .45691 .46809 L F
.4171 .47015 m .4182 .46761 L .41976 .46926 L 0 .03 .13 r
F
.4171 .47015 m .41553 .4685 L .4182 .46761 L F
.27625 .46867 m .27715 .46608 L .27884 .46775 L 0 .027 .126 r
F
.27625 .46867 m .27456 .46698 L .27715 .46608 L F
.31491 .46886 m .31586 .46636 L .31752 .468 L 0 .027 .127 r
F
.31491 .46886 m .31325 .46723 L .31586 .46636 L F
.42399 .46987 m .42509 .46766 L .42665 .46914 L 0 .03 .13 r
F
.42399 .46987 m .42243 .46839 L .42509 .46766 L F
.48752 .47103 m .48872 .46863 L .49022 .4702 L 0 .032 .133 r
F
.48752 .47103 m .48602 .46948 L .48872 .46863 L F
.38533 .4697 m .38638 .46728 L .38798 .46882 L 0 .029 .129 r
F
.38533 .4697 m .38373 .46814 L .38638 .46728 L F
.69734 .46878 m .69882 .46621 L .70014 .46789 L 0 .027 .127 r
F
.69734 .46878 m .69602 .4671 L .69882 .46621 L F
.63799 .46974 m .6394 .46735 L .64076 .46893 L 0 .03 .13 r
F
.63799 .46974 m .63662 .46818 L .6394 .46735 L F
.80225 .46764 m .80388 .46515 L .8051 .46677 L 0 .025 .123 r
F
.80225 .46764 m .80103 .46601 L .80388 .46515 L F
.57864 .47073 m .57996 .46837 L .58138 .46998 L 0 .032 .132 r
F
.57864 .47073 m .57722 .46911 L .57996 .46837 L F
.36045 .46885 m .36147 .46642 L .36309 .46804 L 0 .028 .127 r
F
.36045 .46885 m .35884 .46722 L .36147 .46642 L F
.53998 .4706 m .54125 .46827 L .5427 .46987 L 0 .032 .132 r
F
.53998 .4706 m .53852 .46899 L .54125 .46827 L F
.28313 .4685 m .28404 .46598 L .28572 .46763 L 0 .027 .126 r
F
.28313 .4685 m .28144 .46684 L .28404 .46598 L F
.7498 .46831 m .75137 .46596 L .75263 .4675 L F
.7498 .46831 m .74854 .46677 L .75137 .46596 L F
.49442 .47081 m .49562 .46849 L .49712 .46998 L 0 .032 .133 r
F
.49442 .47081 m .49292 .46934 L .49562 .46849 L F
.39222 .46948 m .39328 .46689 L .39487 .46853 L 0 .029 .129 r
F
.39222 .46948 m .39063 .46786 L .39328 .46689 L F
.32179 .46872 m .32275 .46628 L .3244 .46785 L 0 .027 .127 r
F
.32179 .46872 m .32013 .46714 L .32275 .46628 L F
.65868 .46873 m .66012 .46631 L .66146 .46778 L F
.65868 .46873 m .65734 .46725 L .66012 .46631 L F
.65179 .46915 m .65322 .46676 L .65456 .4682 L 0 .028 .128 r
F
.65179 .46915 m .65044 .4677 L .65322 .46676 L F
.6449 .46958 m .64631 .46716 L .64767 .46864 L 0 .029 .129 r
F
.6449 .46958 m .64354 .46809 L .64631 .46716 L F
.70425 .46863 m .70574 .46603 L .70705 .46769 L 0 .027 .126 r
F
.70425 .46863 m .70294 .46696 L .70574 .46603 L F
.80917 .46751 m .81081 .46502 L .81202 .46665 L 0 .025 .124 r
F
.80917 .46751 m .80796 .4659 L .81081 .46502 L F
.32868 .46848 m .32964 .46613 L .33129 .46762 L 0 .027 .127 r
F
.32868 .46848 m .32702 .46698 L .32964 .46613 L F
.75671 .4681 m .75828 .4656 L .75953 .46713 L 0 .026 .125 r
F
.75671 .4681 m .75546 .46656 L .75828 .4656 L F
.50131 .47063 m .50253 .46833 L .50402 .46979 L 0 .032 .133 r
F
.50131 .47063 m .49982 .46915 L .50253 .46833 L F
.43088 .46986 m .43199 .46761 L .43354 .46908 L 0 .03 .131 r
F
.43088 .46986 m .42932 .46841 L .43199 .46761 L F
.76361 .46776 m .76519 .46524 L .76644 .46684 L 0 .025 .124 r
F
.76361 .46776 m .76236 .46618 L .76519 .46524 L F
.71115 .46834 m .71265 .46578 L .71395 .46738 L 0 .027 .126 r
F
.71115 .46834 m .70985 .46674 L .71265 .46578 L F
.46265 .47047 m .46381 .46795 L .46533 .46957 L 0 .031 .132 r
F
.46265 .47047 m .46112 .46885 L .46381 .46795 L F
.71805 .468 m .71958 .46568 L .72086 .46719 L 0 .026 .125 r
F
.71805 .468 m .71676 .46648 L .71958 .46568 L F
.29 .46841 m .29091 .46608 L .29259 .46764 L 0 .027 .127 r
F
.29 .46841 m .28831 .46685 L .29091 .46608 L F
.66559 .46864 m .66704 .46622 L .66838 .46785 L 0 .028 .127 r
F
.66559 .46864 m .66425 .467 L .66704 .46622 L F
.3991 .4694 m .40017 .467 L .40175 .46864 L 0 .029 .129 r
F
.3991 .4694 m .39752 .46776 L .40017 .467 L F
.36733 .46884 m .36835 .46646 L .36997 .46804 L 0 .028 .128 r
F
.36733 .46884 m .36572 .46723 L .36835 .46646 L F
.33556 .46831 m .33653 .46602 L .33818 .46752 L 0 .027 .127 r
F
.33556 .46831 m .33391 .46682 L .33653 .46602 L F
.81609 .46737 m .81774 .46494 L .81895 .46654 L 0 .025 .124 r
F
.81609 .46737 m .81488 .46578 L .81774 .46494 L F
.58555 .47082 m .58688 .46849 L .58829 .47006 L 0 .033 .134 r
F
.58555 .47082 m .58413 .46923 L .58688 .46849 L F
.50821 .47044 m .50943 .4683 L .51092 .4697 L 0 .032 .133 r
F
.50821 .47044 m .50672 .46902 L .50943 .4683 L F
.46954 .47027 m .47071 .46783 L .47223 .4694 L 0 .031 .132 r
F
.46954 .47027 m .46802 .46866 L .47071 .46783 L F
.43777 .4697 m .43889 .46735 L .44044 .46885 L 0 .03 .13 r
F
.43777 .4697 m .43622 .46821 L .43889 .46735 L F
.60624 .46971 m .6076 .46742 L .60899 .46888 L 0 .03 .131 r
F
.60624 .46971 m .60484 .46825 L .6076 .46742 L F
.77052 .46761 m .77211 .46503 L .77336 .46672 L 0 .025 .124 r
F
.77052 .46761 m .76927 .46592 L .77211 .46503 L F
.59934 .47012 m .60069 .46774 L .60209 .46918 L 0 .031 .132 r
F
.59934 .47012 m .59794 .46869 L .60069 .46774 L F
.54688 .47075 m .54816 .46847 L .54961 .47006 L 0 .033 .134 r
F
.54688 .47075 m .54543 .46917 L .54816 .46847 L F
.72496 .46788 m .7265 .46555 L .72778 .46704 L 0 .026 .125 r
F
.72496 .46788 m .72368 .46638 L .7265 .46555 L F
.59245 .47057 m .59379 .46816 L .59519 .46963 L 0 .032 .133 r
F
.59245 .47057 m .59104 .46911 L .59379 .46816 L F
.29688 .46829 m .29781 .46577 L .29949 .46735 L 0 .027 .126 r
F
.29688 .46829 m .2952 .46673 L .29781 .46577 L F
.34244 .46814 m .34343 .4657 L .34507 .46722 L F
.34244 .46814 m .3408 .46663 L .34343 .4657 L F
.51511 .47031 m .51634 .46806 L .51782 .46943 L 0 .032 .133 r
F
.51511 .47031 m .51362 .46896 L .51634 .46806 L F
.34934 .46783 m .35033 .46558 L .35196 .46711 L 0 .027 .126 r
F
.34934 .46783 m .3477 .46631 L .35033 .46558 L F
.30377 .46802 m .3047 .46562 L .30637 .46723 L F
.30377 .46802 m .3021 .46643 L .3047 .46562 L F
.44466 .46955 m .44579 .46729 L .44733 .46875 L 0 .03 .13 r
F
.44466 .46955 m .44311 .46807 L .44579 .46729 L F
.522 .46995 m .52324 .46762 L .52472 .46905 L 0 .031 .132 r
F
.522 .46995 m .52053 .46853 L .52324 .46762 L F
.82301 .46728 m .82468 .4649 L .82588 .46646 L 0 .025 .124 r
F
.82301 .46728 m .82181 .46572 L .82468 .4649 L F
.47643 .47016 m .47761 .46771 L .47912 .46933 L 0 .031 .132 r
F
.47643 .47016 m .47492 .46853 L .47761 .46771 L F
.61314 .46959 m .61452 .46728 L .6159 .46876 L 0 .03 .131 r
F
.61314 .46959 m .61175 .46808 L .61452 .46728 L F
.77744 .46751 m .77904 .46496 L .78028 .46661 L 0 .025 .124 r
F
.77744 .46751 m .7762 .46584 L .77904 .46496 L F
.37421 .46885 m .37524 .46647 L .37685 .46805 L 0 .029 .128 r
F
.37421 .46885 m .3726 .46725 L .37524 .46647 L F
.67251 .46869 m .67397 .46628 L .6753 .46789 L 0 .028 .128 r
F
.67251 .46869 m .67117 .46707 L .67397 .46628 L F
.40599 .46946 m .40707 .46696 L .40864 .4686 L 0 .03 .13 r
F
.40599 .46946 m .40441 .46784 L .40707 .46696 L F
.73188 .46776 m .73342 .46532 L .73469 .46689 L 0 .026 .125 r
F
.73188 .46776 m .7306 .46618 L .73342 .46532 L F
.78435 .46725 m .78596 .46474 L .78719 .46631 L 0 .025 .124 r
F
.78435 .46725 m .78312 .46568 L .78596 .46474 L F
.82992 .46707 m .83159 .46457 L .83278 .46612 L 0 .025 .123 r
F
.82992 .46707 m .82874 .46552 L .83159 .46457 L F
.5289 .46977 m .53015 .46718 L .53162 .46884 L 0 .03 .131 r
F
.5289 .46977 m .52743 .46812 L .53015 .46718 L F
.62005 .4694 m .62143 .46713 L .62281 .46856 L 0 .03 .13 r
F
.62005 .4694 m .61867 .46795 L .62143 .46713 L F
.56758 .46999 m .56888 .46764 L .57031 .46909 L 0 .031 .132 r
F
.56758 .46999 m .56615 .46854 L .56888 .46764 L F
.45155 .46943 m .45269 .4673 L .45423 .46876 L 0 .031 .131 r
F
.45155 .46943 m .45001 .46799 L .45269 .4673 L F
.79126 .46696 m .79288 .46459 L .79411 .46614 L 0 .025 .123 r
F
.79126 .46696 m .79003 .46541 L .79288 .46459 L F
.56068 .47043 m .56197 .46802 L .56341 .46949 L 0 .032 .133 r
F
.56068 .47043 m .55924 .46896 L .56197 .46802 L F
.55378 .47084 m .55507 .46831 L .55651 .4699 L 0 .033 .134 r
F
.55378 .47084 m .55234 .46925 L .55507 .46831 L F
.62695 .46916 m .62834 .46682 L .62971 .46831 L 0 .03 .13 r
F
.62695 .46916 m .62557 .4677 L .62834 .46682 L F
.67942 .46859 m .68089 .46618 L .68221 .46769 L 0 .028 .128 r
F
.67942 .46859 m .6781 .46709 L .68089 .46618 L F
.73879 .46763 m .74034 .46512 L .74161 .46677 L 0 .026 .125 r
F
.73879 .46763 m .73751 .46601 L .74034 .46512 L F
.68632 .46822 m .6878 .46585 L .68911 .46733 L 0 .028 .127 r
F
.68632 .46822 m .685 .46677 L .6878 .46585 L F
.41287 .46938 m .41396 .46685 L .41553 .4685 L 0 .03 .13 r
F
.41287 .46938 m .4113 .46773 L .41396 .46685 L F
.31064 .46806 m .31158 .4656 L .31325 .46723 L 0 .027 .127 r
F
.31064 .46806 m .30897 .46644 L .31158 .4656 L F
.48333 .47022 m .48451 .46784 L .48602 .46948 L 0 .032 .133 r
F
.48333 .47022 m .48182 .46859 L .48451 .46784 L F
.38109 .46889 m .38213 .46658 L .38373 .46814 L 0 .029 .129 r
F
.38109 .46889 m .37949 .46731 L .38213 .46658 L F
.57448 .46985 m .5758 .46763 L .57722 .46911 L 0 .032 .132 r
F
.57448 .46985 m .57305 .46836 L .5758 .46763 L F
.69322 .46795 m .69471 .46559 L .69602 .4671 L 0 .027 .127 r
F
.69322 .46795 m .69191 .46646 L .69471 .46559 L F
.35621 .46797 m .35721 .46564 L .35884 .46722 L F
.35621 .46797 m .35458 .4664 L .35721 .46564 L F
.5358 .46972 m .53706 .46735 L .53852 .46899 L 0 .031 .132 r
F
.5358 .46972 m .53434 .46806 L .53706 .46735 L F
.79818 .46687 m .79981 .46446 L .80103 .46601 L 0 .025 .123 r
F
.79818 .46687 m .79696 .46531 L .79981 .46446 L F
.63385 .46901 m .63526 .46661 L .63662 .46818 L 0 .03 .13 r
F
.63385 .46901 m .63248 .46745 L .63526 .46661 L F
.41976 .46926 m .42086 .46674 L .42243 .46839 L F
.41976 .46926 m .4182 .46761 L .42086 .46674 L F
.27884 .46775 m .27975 .46517 L .28144 .46684 L 0 .027 .126 r
F
.27884 .46775 m .27715 .46608 L .27975 .46517 L F
.74571 .46758 m .74727 .46511 L .74854 .46677 L 0 .026 .126 r
F
.74571 .46758 m .74444 .46593 L .74727 .46511 L F
.31752 .468 m .31848 .46548 L .32013 .46714 L 0 .027 .127 r
F
.31752 .468 m .31586 .46636 L .31848 .46548 L F
.38798 .46882 m .38903 .46633 L .39063 .46786 L 0 .029 .129 r
F
.38798 .46882 m .38638 .46728 L .38903 .46633 L F
.70014 .46789 m .70163 .4653 L .70294 .46696 L 0 .027 .126 r
F
.70014 .46789 m .69882 .46621 L .70163 .4653 L F
.49022 .4702 m .49142 .46775 L .49292 .46934 L 0 .032 .133 r
F
.49022 .4702 m .48872 .46863 L .49142 .46775 L F
.8051 .46677 m .80674 .46428 L .80796 .4659 L 0 .025 .123 r
F
.8051 .46677 m .80388 .46515 L .80674 .46428 L F
.45844 .46966 m .45959 .46728 L .46112 .46885 L 0 .031 .132 r
F
.45844 .46966 m .45691 .46809 L .45959 .46728 L F
.39487 .46853 m .39593 .46612 L .39752 .46776 L 0 .029 .129 r
F
.39487 .46853 m .39328 .46689 L .39593 .46612 L F
.66146 .46778 m .66291 .46552 L .66425 .467 L 0 .027 .127 r
F
.66146 .46778 m .66012 .46631 L .66291 .46552 L F
.64076 .46893 m .64217 .46649 L .64354 .46809 L 0 .03 .13 r
F
.64076 .46893 m .6394 .46735 L .64217 .46649 L F
.42665 .46914 m .42775 .46693 L .42932 .46841 L 0 .031 .131 r
F
.42665 .46914 m .42509 .46766 L .42775 .46693 L F
.28572 .46763 m .28663 .46522 L .28831 .46685 L 0 .027 .126 r
F
.28572 .46763 m .28404 .46598 L .28663 .46522 L F
.65456 .4682 m .656 .46581 L .65734 .46725 L 0 .028 .128 r
F
.65456 .4682 m .65322 .46676 L .656 .46581 L F
.36309 .46804 m .3641 .46562 L .36572 .46723 L 0 .028 .127 r
F
.36309 .46804 m .36147 .46642 L .3641 .46562 L F
.3244 .46785 m .32536 .46541 L .32702 .46698 L 0 .027 .127 r
F
.3244 .46785 m .32275 .46628 L .32536 .46541 L F
.49712 .46998 m .49832 .46768 L .49982 .46915 L 0 .032 .133 r
F
.49712 .46998 m .49562 .46849 L .49832 .46768 L F
.58138 .46998 m .58271 .46764 L .58413 .46923 L F
.58138 .46998 m .57996 .46837 L .58271 .46764 L F
.64767 .46864 m .64909 .46623 L .65044 .4677 L 0 .029 .129 r
F
.64767 .46864 m .64631 .46716 L .64909 .46623 L F
.70705 .46769 m .70854 .46509 L .70985 .46674 L 0 .027 .126 r
F
.70705 .46769 m .70574 .46603 L .70854 .46509 L F
.75263 .4675 m .7542 .46502 L .75546 .46656 L F
.75263 .4675 m .75137 .46596 L .7542 .46502 L F
.75953 .46713 m .76111 .46464 L .76236 .46618 L 0 .026 .125 r
F
.75953 .46713 m .75828 .4656 L .76111 .46464 L F
.5427 .46987 m .54397 .46756 L .54543 .46917 L 0 .032 .133 r
F
.5427 .46987 m .54125 .46827 L .54397 .46756 L F
.71395 .46738 m .71546 .46488 L .71676 .46648 L 0 .026 .126 r
F
.71395 .46738 m .71265 .46578 L .71546 .46488 L F
.81202 .46665 m .81367 .46413 L .81488 .46578 L 0 .025 .123 r
F
.81202 .46665 m .81081 .46502 L .81367 .46413 L F
.76644 .46684 m .76802 .46431 L .76927 .46592 L 0 .025 .124 r
F
.76644 .46684 m .76519 .46524 L .76802 .46431 L F
.33129 .46762 m .33226 .46532 L .33391 .46682 L 0 .027 .127 r
F
.33129 .46762 m .32964 .46613 L .33226 .46532 L F
.46533 .46957 m .4665 .46705 L .46802 .46866 L 0 .031 .132 r
F
.46533 .46957 m .46381 .46795 L .4665 .46705 L F
.50402 .46979 m .50523 .46756 L .50672 .46902 L 0 .032 .133 r
F
.50402 .46979 m .50253 .46833 L .50523 .46756 L F
.43354 .46908 m .43466 .46673 L .43622 .46821 L 0 .031 .131 r
F
.43354 .46908 m .43199 .46761 L .43466 .46673 L F
.72086 .46719 m .7224 .46488 L .72368 .46638 L 0 .027 .126 r
F
.72086 .46719 m .71958 .46568 L .7224 .46488 L F
.29259 .46764 m .29351 .46515 L .2952 .46673 L 0 .027 .127 r
F
.29259 .46764 m .29091 .46608 L .29351 .46515 L F
.60209 .46918 m .60345 .46678 L .60484 .46825 L 0 .031 .131 r
F
.60209 .46918 m .60069 .46774 L .60345 .46678 L F
.36997 .46804 m .37099 .46569 L .3726 .46725 L 0 .028 .128 r
F
.36997 .46804 m .36835 .46646 L .37099 .46569 L F
.66838 .46785 m .66983 .46545 L .67117 .46707 L 0 .028 .127 r
F
.66838 .46785 m .66704 .46622 L .66983 .46545 L F
.77336 .46672 m .77495 .46417 L .7762 .46584 L 0 .025 .124 r
F
.77336 .46672 m .77211 .46503 L .77495 .46417 L F
.47223 .4694 m .4734 .467 L .47492 .46853 L 0 .031 .132 r
F
.47223 .4694 m .47071 .46783 L .4734 .467 L F
.40175 .46864 m .40283 .4662 L .40441 .46784 L 0 .03 .13 r
F
.40175 .46864 m .40017 .467 L .40283 .4662 L F
.81895 .46654 m .82061 .46412 L .82181 .46572 L 0 .025 .124 r
F
.81895 .46654 m .81774 .46494 L .82061 .46412 L F
.44044 .46885 m .44156 .46656 L .44311 .46807 L 0 .03 .131 r
F
.44044 .46885 m .43889 .46735 L .44156 .46656 L F
.33818 .46752 m .33916 .46512 L .3408 .46663 L 0 .027 .127 r
F
.33818 .46752 m .33653 .46602 L .33916 .46512 L F
.59519 .46963 m .59654 .4672 L .59794 .46869 L 0 .032 .133 r
F
.59519 .46963 m .59379 .46816 L .59654 .4672 L F
.60899 .46888 m .61036 .46663 L .61175 .46808 L 0 .031 .131 r
F
.60899 .46888 m .6076 .46742 L .61036 .46663 L F
.29949 .46735 m .30042 .46482 L .3021 .46643 L 0 .027 .126 r
F
.29949 .46735 m .29781 .46577 L .30042 .46482 L F
.58829 .47006 m .58963 .46753 L .59104 .46911 L 0 .033 .134 r
F
.58829 .47006 m .58688 .46849 L .58963 .46753 L F
.51092 .4697 m .51214 .46758 L .51362 .46896 L 0 .033 .133 r
F
.51092 .4697 m .50943 .4683 L .51214 .46758 L F
.34507 .46722 m .34606 .46478 L .3477 .46631 L 0 .027 .126 r
F
.34507 .46722 m .34343 .4657 L .34606 .46478 L F
.72778 .46704 m .72932 .46471 L .7306 .46618 L 0 .026 .126 r
F
.72778 .46704 m .7265 .46555 L .72932 .46471 L F
.51782 .46943 m .51905 .46714 L .52053 .46853 L 0 .032 .133 r
F
.51782 .46943 m .51634 .46806 L .51905 .46714 L F
.52472 .46905 m .52596 .46668 L .52743 .46812 L 0 .031 .131 r
F
.52472 .46905 m .52324 .46762 L .52596 .46668 L F
.54961 .47006 m .55089 .46766 L .55234 .46925 L 0 .033 .134 r
F
.54961 .47006 m .54816 .46847 L .55089 .46766 L F
.78028 .46661 m .78188 .46403 L .78312 .46568 L 0 .025 .124 r
F
.78028 .46661 m .77904 .46496 L .78188 .46403 L F
.44733 .46875 m .44847 .46653 L .45001 .46799 L 0 .031 .131 r
F
.44733 .46875 m .44579 .46729 L .44847 .46653 L F
.82588 .46646 m .82754 .46397 L .82874 .46552 L 0 .025 .124 r
F
.82588 .46646 m .82468 .4649 L .82754 .46397 L F
.47912 .46933 m .48031 .46695 L .48182 .46859 L 0 .032 .132 r
F
.47912 .46933 m .47761 .46771 L .48031 .46695 L F
.6159 .46876 m .61728 .46649 L .61867 .46795 L 0 .031 .131 r
F
.6159 .46876 m .61452 .46728 L .61728 .46649 L F
.30637 .46723 m .30731 .46481 L .30897 .46644 L 0 .027 .126 r
F
.30637 .46723 m .3047 .46562 L .30731 .46481 L F
.40864 .4686 m .40973 .46608 L .4113 .46773 L 0 .03 .13 r
F
.40864 .4686 m .40707 .46696 L .40973 .46608 L F
.78719 .46631 m .7888 .46384 L .79003 .46541 L 0 .025 .124 r
F
.78719 .46631 m .78596 .46474 L .7888 .46384 L F
.83278 .46612 m .83446 .46363 L .83564 .46518 L 0 .025 .123 r
F
.83278 .46612 m .83159 .46457 L .83446 .46363 L F
.73469 .46689 m .73624 .46442 L .73751 .46601 L 0 .026 .125 r
F
.73469 .46689 m .73342 .46532 L .73624 .46442 L F
.37685 .46805 m .37788 .46575 L .37949 .46731 L 0 .029 .129 r
F
.37685 .46805 m .37524 .46647 L .37788 .46575 L F
.35196 .46711 m .35295 .46485 L .35458 .4664 L 0 .027 .126 r
F
.35196 .46711 m .35033 .46558 L .35295 .46485 L F
.53162 .46884 m .53287 .46641 L .53434 .46806 L 0 .031 .131 r
F
.53162 .46884 m .53015 .46718 L .53287 .46641 L F
.6753 .46789 m .67676 .4655 L .6781 .46709 L 0 .028 .128 r
F
.6753 .46789 m .67397 .46628 L .67676 .4655 L F
.57031 .46909 m .57163 .46692 L .57305 .46836 L 0 .032 .132 r
F
.57031 .46909 m .56888 .46764 L .57163 .46692 L F
.56341 .46949 m .56471 .46707 L .56615 .46854 L 0 .032 .133 r
F
.56341 .46949 m .56197 .46802 L .56471 .46707 L F
.62281 .46856 m .6242 .46627 L .62557 .4677 L 0 .03 .13 r
F
.62281 .46856 m .62143 .46713 L .6242 .46627 L F
.55651 .4699 m .5578 .46736 L .55924 .46896 L 0 .033 .134 r
F
.55651 .4699 m .55507 .46831 L .5578 .46736 L F
.79411 .46614 m .79574 .46377 L .79696 .46531 L 0 .025 .124 r
F
.79411 .46614 m .79288 .46459 L .79574 .46377 L F
.68221 .46769 m .68368 .46525 L .685 .46677 L 0 .028 .128 r
F
.68221 .46769 m .68089 .46618 L .68368 .46525 L F
.68911 .46733 m .6906 .46497 L .69191 .46646 L 0 .028 .127 r
F
.68911 .46733 m .6878 .46585 L .6906 .46497 L F
.74161 .46677 m .74316 .46427 L .74444 .46593 L 0 .026 .125 r
F
.74161 .46677 m .74034 .46512 L .74316 .46427 L F
.62971 .46831 m .63111 .46594 L .63248 .46745 L 0 .03 .13 r
F
.62971 .46831 m .62834 .46682 L .63111 .46594 L F
.41553 .4685 m .41663 .46596 L .4182 .46761 L F
.41553 .4685 m .41396 .46685 L .41663 .46596 L F
.27456 .46698 m .27546 .46441 L .27715 .46608 L 0 .027 .126 r
F
.27456 .46698 m .27286 .4653 L .27546 .46441 L F
.31325 .46723 m .3142 .46471 L .31586 .46636 L 0 .027 .127 r
F
.31325 .46723 m .31158 .4656 L .3142 .46471 L F
.45423 .46876 m .45537 .46662 L .45691 .46809 L 0 .031 .132 r
F
.45423 .46876 m .45269 .4673 L .45537 .46662 L F
.69602 .4671 m .69751 .46471 L .69882 .46621 L 0 .027 .127 r
F
.69602 .4671 m .69471 .46559 L .69751 .46471 L F
.80103 .46601 m .80267 .46361 L .80388 .46515 L 0 .025 .124 r
F
.80103 .46601 m .79981 .46446 L .80267 .46361 L F
.48602 .46948 m .48721 .46698 L .48872 .46863 L 0 .032 .133 r
F
.48602 .46948 m .48451 .46784 L .48721 .46698 L F
.38373 .46814 m .38478 .46573 L .38638 .46728 L 0 .03 .13 r
F
.38373 .46814 m .38213 .46658 L .38478 .46573 L F
.57722 .46911 m .57854 .4669 L .57996 .46837 L 0 .032 .133 r
F
.57722 .46911 m .5758 .46763 L .57854 .4669 L F
.63662 .46818 m .63803 .46576 L .6394 .46735 L 0 .03 .13 r
F
.63662 .46818 m .63526 .46661 L .63803 .46576 L F
.28144 .46684 m .28235 .46433 L .28404 .46598 L 0 .027 .126 r
F
.28144 .46684 m .27975 .46517 L .28235 .46433 L F
.35884 .46722 m .35985 .46482 L .36147 .46642 L 0 .028 .127 r
F
.35884 .46722 m .35721 .46564 L .35985 .46482 L F
.42243 .46839 m .42353 .46601 L .42509 .46766 L 0 .03 .13 r
F
.42243 .46839 m .42086 .46674 L .42353 .46601 L F
.53852 .46899 m .53979 .46663 L .54125 .46827 L 0 .032 .132 r
F
.53852 .46899 m .53706 .46735 L .53979 .46663 L F
.39063 .46786 m .39169 .46538 L .39328 .46689 L 0 .029 .129 r
F
.39063 .46786 m .38903 .46633 L .39169 .46538 L F
.32013 .46714 m .32109 .46461 L .32275 .46628 L 0 .027 .127 r
F
.32013 .46714 m .31848 .46548 L .32109 .46461 L F
.74854 .46677 m .7501 .4643 L .75137 .46596 L 0 .027 .126 r
F
.74854 .46677 m .74727 .46511 L .7501 .4643 L F
.70294 .46696 m .70443 .46438 L .70574 .46603 L F
.70294 .46696 m .70163 .4653 L .70443 .46438 L F
.49292 .46934 m .49412 .46689 L .49562 .46849 L 0 .032 .133 r
F
.49292 .46934 m .49142 .46775 L .49412 .46689 L F
.80796 .4659 m .8096 .46338 L .81081 .46502 L 0 .025 .123 r
F
.80796 .4659 m .80674 .46428 L .8096 .46338 L F
.65734 .46725 m .65878 .46487 L .66012 .46631 L 0 .028 .128 r
F
.65734 .46725 m .656 .46581 L .65878 .46487 L F
.70985 .46674 m .71135 .46414 L .71265 .46578 L 0 .027 .126 r
F
.70985 .46674 m .70854 .46509 L .71135 .46414 L F
.46112 .46885 m .46228 .46638 L .46381 .46795 L 0 .031 .132 r
F
.46112 .46885 m .45959 .46728 L .46228 .46638 L F
.65044 .4677 m .65187 .46529 L .65322 .46676 L 0 .029 .129 r
F
.65044 .4677 m .64909 .46623 L .65187 .46529 L F
.64354 .46809 m .64495 .46558 L .64631 .46716 L 0 .03 .13 r
F
.64354 .46809 m .64217 .46649 L .64495 .46558 L F
.76236 .46618 m .76394 .46371 L .76519 .46524 L 0 .026 .124 r
F
.76236 .46618 m .76111 .46464 L .76394 .46371 L F
.75546 .46656 m .75702 .46407 L .75828 .4656 L 0 .026 .125 r
F
.75546 .46656 m .7542 .46502 L .75702 .46407 L F
.32702 .46698 m .32798 .46457 L .32964 .46613 L 0 .027 .127 r
F
.32702 .46698 m .32536 .46541 L .32798 .46457 L F
.39752 .46776 m .39859 .46536 L .40017 .467 L 0 .029 .129 r
F
.39752 .46776 m .39593 .46612 L .39859 .46536 L F
.66425 .467 m .6657 .46474 L .66704 .46622 L 0 .028 .127 r
F
.66425 .467 m .66291 .46552 L .6657 .46474 L F
.36572 .46723 m .36674 .46487 L .36835 .46646 L 0 .028 .128 r
F
.36572 .46723 m .3641 .46562 L .36674 .46487 L F
.28831 .46685 m .28922 .46446 L .29091 .46608 L 0 .027 .127 r
F
.28831 .46685 m .28663 .46522 L .28922 .46446 L F
.49982 .46915 m .50103 .46687 L .50253 .46833 L 0 .033 .133 r
F
.49982 .46915 m .49832 .46768 L .50103 .46687 L F
.71676 .46648 m .71828 .46408 L .71958 .46568 L 0 .026 .126 r
F
.71676 .46648 m .71546 .46488 L .71828 .46408 L F
.76927 .46592 m .77086 .46342 L .77211 .46503 L 0 .025 .124 r
F
.76927 .46592 m .76802 .46431 L .77086 .46342 L F
.42932 .46841 m .43042 .46612 L .43199 .46761 L 0 .031 .131 r
F
.42932 .46841 m .42775 .46693 L .43042 .46612 L F
.81488 .46578 m .81653 .46328 L .81774 .46494 L 0 .025 .123 r
F
.81488 .46578 m .81367 .46413 L .81653 .46328 L F
.58413 .46923 m .58546 .46691 L .58688 .46849 L 0 .033 .134 r
F
.58413 .46923 m .58271 .46764 L .58546 .46691 L F
.46802 .46866 m .46919 .46625 L .47071 .46783 L 0 .031 .132 r
F
.46802 .46866 m .4665 .46705 L .46919 .46625 L F
.33391 .46682 m .33488 .46451 L .33653 .46602 L 0 .028 .127 r
F
.33391 .46682 m .33226 .46532 L .33488 .46451 L F
.54543 .46917 m .5467 .46686 L .54816 .46847 L 0 .033 .134 r
F
.54543 .46917 m .54397 .46756 L .5467 .46686 L F
.43622 .46821 m .43733 .46585 L .43889 .46735 L 0 .031 .131 r
F
.43622 .46821 m .43466 .46673 L .43733 .46585 L F
.60484 .46825 m .60621 .46596 L .6076 .46742 L F
.60484 .46825 m .60345 .46678 L .60621 .46596 L F
.50672 .46902 m .50794 .46684 L .50943 .4683 L 0 .033 .134 r
F
.50672 .46902 m .50523 .46756 L .50794 .46684 L F
.2952 .46673 m .29613 .46418 L .29781 .46577 L 0 .027 .126 r
F
.2952 .46673 m .29351 .46515 L .29613 .46418 L F
.72368 .46638 m .72522 .46406 L .7265 .46555 L F
.72368 .46638 m .7224 .46488 L .72522 .46406 L F
.59794 .46869 m .59929 .46623 L .60069 .46774 L 0 .032 .132 r
F
.59794 .46869 m .59654 .4672 L .59929 .46623 L F
.7762 .46584 m .77779 .4633 L .77904 .46496 L 0 .025 .124 r
F
.7762 .46584 m .77495 .46417 L .77779 .4633 L F
.3021 .46643 m .30303 .46399 L .3047 .46562 L 0 .027 .126 r
F
.3021 .46643 m .30042 .46482 L .30303 .46399 L F
.47492 .46853 m .47609 .4662 L .47761 .46771 L 0 .031 .132 r
F
.47492 .46853 m .4734 .467 L .47609 .4662 L F
.59104 .46911 m .59238 .46656 L .59379 .46816 L 0 .032 .133 r
F
.59104 .46911 m .58963 .46753 L .59238 .46656 L F
.3408 .46663 m .34179 .46417 L .34343 .4657 L 0 .027 .126 r
F
.3408 .46663 m .33916 .46512 L .34179 .46417 L F
.3726 .46725 m .37363 .46494 L .37524 .46647 L 0 .029 .128 r
F
.3726 .46725 m .37099 .46569 L .37363 .46494 L F
.82181 .46572 m .82348 .4633 L .82468 .4649 L 0 .025 .124 r
F
.82181 .46572 m .82061 .46412 L .82348 .4633 L F
.67117 .46707 m .67263 .46467 L .67397 .46628 L 0 .028 .128 r
F
.67117 .46707 m .66983 .46545 L .67263 .46467 L F
.40441 .46784 m .40549 .4653 L .40707 .46696 L 0 .03 .13 r
F
.40441 .46784 m .40283 .4662 L .40549 .4653 L F
.3477 .46631 m .34869 .46404 L .35033 .46558 L 0 .027 .126 r
F
.3477 .46631 m .34606 .46478 L .34869 .46404 L F
.44311 .46807 m .44424 .46578 L .44579 .46729 L 0 .031 .131 r
F
.44311 .46807 m .44156 .46656 L .44424 .46578 L F
.61175 .46808 m .61313 .46584 L .61452 .46728 L F
.61175 .46808 m .61036 .46663 L .61313 .46584 L F
.7306 .46618 m .73214 .46387 L .73342 .46532 L 0 .026 .126 r
F
.7306 .46618 m .72932 .46471 L .73214 .46387 L F
.52743 .46812 m .52868 .46574 L .53015 .46718 L 0 .031 .131 r
F
.52743 .46812 m .52596 .46668 L .52868 .46574 L F
.52053 .46853 m .52177 .46621 L .52324 .46762 L 0 .032 .132 r
F
.52053 .46853 m .51905 .46714 L .52177 .46621 L F
.78312 .46568 m .78472 .4631 L .78596 .46474 L 0 .025 .124 r
F
.78312 .46568 m .78188 .46403 L .78472 .4631 L F
.51362 .46896 m .51486 .46666 L .51634 .46806 L 0 .033 .134 r
F
.51362 .46896 m .51214 .46758 L .51486 .46666 L F
.82874 .46552 m .83041 .46301 L .83159 .46457 L 0 .025 .124 r
F
.82874 .46552 m .82754 .46397 L .83041 .46301 L F
.83564 .46518 m .83733 .46273 L .83851 .4643 L 0 .024 .123 r
F
.83564 .46518 m .83446 .46363 L .83733 .46273 L F
.79003 .46541 m .79166 .46303 L .79288 .46459 L 0 .025 .124 r
F
.79003 .46541 m .7888 .46384 L .79166 .46303 L F
.55234 .46925 m .55362 .46671 L .55507 .46831 L 0 .033 .134 r
F
.55234 .46925 m .55089 .46766 L .55362 .46671 L F
.73751 .46601 m .73906 .46352 L .74034 .46512 L 0 .026 .125 r
F
.73751 .46601 m .73624 .46442 L .73906 .46352 L F
.4113 .46773 m .41239 .4652 L .41396 .46685 L 0 .03 .13 r
F
.4113 .46773 m .40973 .46608 L .41239 .4652 L F
.61867 .46795 m .62005 .4657 L .62143 .46713 L 0 .031 .131 r
F
.61867 .46795 m .61728 .46649 L .62005 .4657 L F
.56615 .46854 m .56745 .46617 L .56888 .46764 L 0 .032 .133 r
F
.56615 .46854 m .56471 .46707 L .56745 .46617 L F
.30897 .46644 m .30992 .46395 L .31158 .4656 L 0 .027 .126 r
F
.30897 .46644 m .30731 .46481 L .30992 .46395 L F
.45001 .46799 m .45114 .46584 L .45269 .4673 L 0 .031 .131 r
F
.45001 .46799 m .44847 .46653 L .45114 .46584 L F
.55924 .46896 m .56054 .46642 L .56197 .46802 L 0 .033 .133 r
F
.55924 .46896 m .5578 .46736 L .56054 .46642 L F
.48182 .46859 m .483 .4662 L .48451 .46784 L 0 .032 .133 r
F
.48182 .46859 m .48031 .46695 L .483 .4662 L F
.6781 .46709 m .67956 .46458 L .68089 .46618 L 0 .029 .128 r
F
.6781 .46709 m .67676 .4655 L .67956 .46458 L F
.53434 .46806 m .5356 .4657 L .53706 .46735 L 0 .031 .131 r
F
.53434 .46806 m .53287 .46641 L .5356 .4657 L F
.62557 .4677 m .62697 .46536 L .62834 .46682 L 0 .03 .13 r
F
.62557 .4677 m .6242 .46627 L .62697 .46536 L F
.37949 .46731 m .38052 .46503 L .38213 .46658 L 0 .029 .129 r
F
.37949 .46731 m .37788 .46575 L .38052 .46503 L F
.685 .46677 m .68648 .46431 L .6878 .46585 L 0 .028 .128 r
F
.685 .46677 m .68368 .46525 L .68648 .46431 L F
.35458 .4664 m .35558 .46408 L .35721 .46564 L 0 .027 .127 r
F
.35458 .4664 m .35295 .46485 L .35558 .46408 L F
.57305 .46836 m .57437 .4662 L .5758 .46763 L 0 .032 .133 r
F
.57305 .46836 m .57163 .46692 L .57437 .4662 L F
.79696 .46531 m .7986 .46294 L .79981 .46446 L 0 .025 .124 r
F
.79696 .46531 m .79574 .46377 L .7986 .46294 L F
.69191 .46646 m .6934 .46408 L .69471 .46559 L 0 .028 .127 r
F
.69191 .46646 m .6906 .46497 L .6934 .46408 L F
.27715 .46608 m .27806 .46352 L .27975 .46517 L 0 .026 .125 r
F
.27715 .46608 m .27546 .46441 L .27806 .46352 L F
.4182 .46761 m .4193 .46508 L .42086 .46674 L 0 .03 .13 r
F
.4182 .46761 m .41663 .46596 L .4193 .46508 L F
.63248 .46745 m .63388 .46506 L .63526 .46661 L F
.63248 .46745 m .63111 .46594 L .63388 .46506 L F
.74444 .46593 m .74599 .46344 L .74727 .46511 L 0 .026 .125 r
F
.74444 .46593 m .74316 .46427 L .74599 .46344 L F
.31586 .46636 m .31682 .46382 L .31848 .46548 L 0 .027 .126 r
F
.31586 .46636 m .3142 .46471 L .31682 .46382 L F
.69882 .46621 m .70032 .46381 L .70163 .4653 L F
.69882 .46621 m .69751 .46471 L .70032 .46381 L F
.80388 .46515 m .80553 .46275 L .80674 .46428 L 0 .025 .124 r
F
.80388 .46515 m .80267 .46361 L .80553 .46275 L F
.39328 .46689 m .39434 .46463 L .39593 .46612 L 0 .029 .129 r
F
.39328 .46689 m .39169 .46538 L .39434 .46463 L F
.38638 .46728 m .38743 .46481 L .38903 .46633 L F
.38638 .46728 m .38478 .46573 L .38743 .46481 L F
.48872 .46863 m .48991 .4661 L .49142 .46775 L 0 .032 .133 r
F
.48872 .46863 m .48721 .46698 L .48991 .4661 L F
.28404 .46598 m .28494 .46358 L .28663 .46522 L 0 .027 .126 r
F
.28404 .46598 m .28235 .46433 L .28494 .46358 L F
.45691 .46809 m .45805 .4658 L .45959 .46728 L 0 .032 .132 r
F
.45691 .46809 m .45537 .46662 L .45805 .4658 L F
.6394 .46735 m .64081 .4649 L .64217 .46649 L 0 .03 .13 r
F
.6394 .46735 m .63803 .46576 L .64081 .4649 L F
.70574 .46603 m .70724 .46345 L .70854 .46509 L 0 .027 .126 r
F
.70574 .46603 m .70443 .46438 L .70724 .46345 L F
.36147 .46642 m .36248 .46401 L .3641 .46562 L 0 .028 .127 r
F
.36147 .46642 m .35985 .46482 L .36248 .46401 L F
.57996 .46837 m .58129 .46617 L .58271 .46764 L 0 .033 .133 r
F
.57996 .46837 m .57854 .4669 L .58129 .46617 L F
.32275 .46628 m .32371 .46375 L .32536 .46541 L 0 .027 .127 r
F
.32275 .46628 m .32109 .46461 L .32371 .46375 L F
.66012 .46631 m .66157 .46408 L .66291 .46552 L 0 .028 .128 r
F
.66012 .46631 m .65878 .46487 L .66157 .46408 L F
.42509 .46766 m .42619 .46527 L .42775 .46693 L 0 .031 .131 r
F
.42509 .46766 m .42353 .46601 L .42619 .46527 L F
.75137 .46596 m .75293 .46337 L .7542 .46502 L 0 .027 .126 r
F
.75137 .46596 m .7501 .4643 L .75293 .46337 L F
.54125 .46827 m .54252 .46593 L .54397 .46756 L 0 .032 .133 r
F
.54125 .46827 m .53979 .46663 L .54252 .46593 L F
.81081 .46502 m .81246 .46248 L .81367 .46413 L 0 .025 .123 r
F
.81081 .46502 m .8096 .46338 L .81246 .46248 L F
.71265 .46578 m .71416 .46324 L .71546 .46488 L 0 .026 .125 r
F
.71265 .46578 m .71135 .46414 L .71416 .46324 L F
.75828 .4656 m .75985 .46311 L .76111 .46464 L F
.75828 .4656 m .75702 .46407 L .75985 .46311 L F
.65322 .46676 m .65465 .46436 L .656 .46581 L 0 .029 .128 r
F
.65322 .46676 m .65187 .46529 L .65465 .46436 L F
.49562 .46849 m .49683 .46611 L .49832 .46768 L 0 .033 .133 r
F
.49562 .46849 m .49412 .46689 L .49683 .46611 L F
.76519 .46524 m .76677 .46277 L .76802 .46431 L 0 .025 .124 r
F
.76519 .46524 m .76394 .46371 L .76677 .46277 L F
.64631 .46716 m .64773 .46467 L .64909 .46623 L 0 .029 .129 r
F
.64631 .46716 m .64495 .46558 L .64773 .46467 L F
.46381 .46795 m .46497 .46548 L .4665 .46705 L 0 .031 .132 r
F
.46381 .46795 m .46228 .46638 L .46497 .46548 L F
.32964 .46613 m .33061 .46375 L .33226 .46532 L 0 .028 .127 r
F
.32964 .46613 m .32798 .46457 L .33061 .46375 L F
.77211 .46503 m .7737 .46257 L .77495 .46417 L 0 .025 .124 r
F
.77211 .46503 m .77086 .46342 L .7737 .46257 L F
.66704 .46622 m .6685 .46396 L .66983 .46545 L 0 .028 .128 r
F
.66704 .46622 m .6657 .46474 L .6685 .46396 L F
.50253 .46833 m .50374 .4661 L .50523 .46756 L 0 .033 .134 r
F
.50253 .46833 m .50103 .46687 L .50374 .4661 L F
.40017 .467 m .40124 .46455 L .40283 .4662 L 0 .029 .129 r
F
.40017 .467 m .39859 .46536 L .40124 .46455 L F
.71958 .46568 m .7211 .46328 L .7224 .46488 L 0 .027 .126 r
F
.71958 .46568 m .71828 .46408 L .7211 .46328 L F
.36835 .46646 m .36937 .46413 L .37099 .46569 L 0 .028 .128 r
F
.36835 .46646 m .36674 .46487 L .36937 .46413 L F
.29091 .46608 m .29183 .46354 L .29351 .46515 L 0 .027 .127 r
F
.29091 .46608 m .28922 .46446 L .29183 .46354 L F
.43199 .46761 m .4331 .46522 L .43466 .46673 L 0 .031 .131 r
F
.43199 .46761 m .43042 .46612 L .4331 .46522 L F
.81774 .46494 m .8194 .46245 L .82061 .46412 L 0 .025 .124 r
F
.81774 .46494 m .81653 .46328 L .8194 .46245 L F
.47071 .46783 m .47188 .46546 L .4734 .467 L 0 .031 .132 r
F
.47071 .46783 m .46919 .46625 L .47188 .46546 L F
.29781 .46577 m .29874 .46322 L .30042 .46482 L 0 .027 .126 r
F
.29781 .46577 m .29613 .46418 L .29874 .46322 L F
.58688 .46849 m .58821 .46594 L .58963 .46753 L 0 .033 .134 r
F
.58688 .46849 m .58546 .46691 L .58821 .46594 L F
.43889 .46735 m .44001 .46505 L .44156 .46656 L 0 .031 .131 r
F
.43889 .46735 m .43733 .46585 L .44001 .46505 L F
.60069 .46774 m .60205 .46527 L .60345 .46678 L 0 .031 .132 r
F
.60069 .46774 m .59929 .46623 L .60205 .46527 L F
.33653 .46602 m .33751 .4636 L .33916 .46512 L 0 .028 .127 r
F
.33653 .46602 m .33488 .46451 L .33751 .4636 L F
.59379 .46816 m .59513 .4656 L .59654 .4672 L 0 .032 .133 r
F
.59379 .46816 m .59238 .46656 L .59513 .4656 L F
.6076 .46742 m .60897 .46518 L .61036 .46663 L 0 .031 .131 r
F
.6076 .46742 m .60621 .46596 L .60897 .46518 L F
.34343 .4657 m .34442 .46324 L .34606 .46478 L 0 .027 .126 r
F
.34343 .4657 m .34179 .46417 L .34442 .46324 L F
.77904 .46496 m .78063 .46238 L .78188 .46403 L 0 .025 .124 r
F
.77904 .46496 m .77779 .4633 L .78063 .46238 L F
.7265 .46555 m .72804 .46324 L .72932 .46471 L 0 .027 .126 r
F
.7265 .46555 m .72522 .46406 L .72804 .46324 L F
.54816 .46847 m .54944 .46605 L .55089 .46766 L 0 .033 .134 r
F
.54816 .46847 m .5467 .46686 L .54944 .46605 L F
.47761 .46771 m .47879 .46544 L .48031 .46695 L 0 .032 .132 r
F
.47761 .46771 m .47609 .4662 L .47879 .46544 L F
.3047 .46562 m .30564 .46316 L .30731 .46481 L 0 .027 .126 r
F
.3047 .46562 m .30303 .46399 L .30564 .46316 L F
.40707 .46696 m .40815 .46441 L .40973 .46608 L 0 .03 .13 r
F
.40707 .46696 m .40549 .4653 L .40815 .46441 L F
.50943 .4683 m .51065 .46611 L .51214 .46758 L 0 .033 .134 r
F
.50943 .4683 m .50794 .46684 L .51065 .46611 L F
.53015 .46718 m .53141 .46496 L .53287 .46641 L 0 .031 .131 r
F
.53015 .46718 m .52868 .46574 L .53141 .46496 L F
.82468 .4649 m .82635 .46236 L .82754 .46397 L 0 .025 .124 r
F
.82468 .4649 m .82348 .4633 L .82635 .46236 L F
.78596 .46474 m .78757 .46221 L .7888 .46384 L F
.78596 .46474 m .78472 .4631 L .78757 .46221 L F
.52324 .46762 m .52449 .46527 L .52596 .46668 L 0 .032 .132 r
F
.52324 .46762 m .52177 .46621 L .52449 .46527 L F
.73342 .46532 m .73496 .46295 L .73624 .46442 L 0 .026 .126 r
F
.73342 .46532 m .73214 .46387 L .73496 .46295 L F
.37524 .46647 m .37627 .46423 L .37788 .46575 L 0 .029 .129 r
F
.37524 .46647 m .37363 .46494 L .37627 .46423 L F
.67397 .46628 m .67543 .4639 L .67676 .4655 L 0 .028 .128 r
F
.67397 .46628 m .67263 .46467 L .67543 .4639 L F
.83159 .46457 m .83327 .46208 L .83446 .46363 L 0 .025 .123 r
F
.83159 .46457 m .83041 .46301 L .83327 .46208 L F
.61452 .46728 m .6159 .46507 L .61728 .46649 L 0 .031 .131 r
F
.61452 .46728 m .61313 .46584 L .6159 .46507 L F
.44579 .46729 m .44692 .46502 L .44847 .46653 L F
.44579 .46729 m .44424 .46578 L .44692 .46502 L F
.51634 .46806 m .51757 .46572 L .51905 .46714 L 0 .033 .133 r
F
.51634 .46806 m .51486 .46666 L .51757 .46572 L F
.35033 .46558 m .35132 .46331 L .35295 .46485 L 0 .027 .127 r
F
.35033 .46558 m .34869 .46404 L .35132 .46331 L F
.55507 .46831 m .55636 .46576 L .5578 .46736 L 0 .033 .134 r
F
.55507 .46831 m .55362 .46671 L .55636 .46576 L F
.83851 .4643 m .8402 .46184 L .84139 .46341 L 0 .024 .123 r
F
.83851 .4643 m .83733 .46273 L .8402 .46184 L F
.27286 .4653 m .27376 .46274 L .27546 .46441 L 0 .026 .125 r
F
.27286 .4653 m .27116 .46362 L .27376 .46274 L F
.74034 .46512 m .74189 .46265 L .74316 .46427 L F
.74034 .46512 m .73906 .46352 L .74189 .46265 L F
.41396 .46685 m .41506 .46432 L .41663 .46596 L 0 .03 .13 r
F
.41396 .46685 m .41239 .4652 L .41506 .46432 L F
.56197 .46802 m .56327 .46548 L .56471 .46707 L 0 .032 .133 r
F
.56197 .46802 m .56054 .46642 L .56327 .46548 L F
.56888 .46764 m .5702 .46546 L .57163 .46692 L F
.56888 .46764 m .56745 .46617 L .5702 .46546 L F
.79288 .46459 m .79452 .46221 L .79574 .46377 L 0 .025 .124 r
F
.79288 .46459 m .79166 .46303 L .79452 .46221 L F
.62143 .46713 m .62282 .46484 L .6242 .46627 L 0 .031 .131 r
F
.62143 .46713 m .62005 .4657 L .62282 .46484 L F
.31158 .4656 m .31254 .46305 L .3142 .46471 L 0 .027 .126 r
F
.31158 .4656 m .30992 .46395 L .31254 .46305 L F
.68089 .46618 m .68235 .46363 L .68368 .46525 L 0 .028 .128 r
F
.68089 .46618 m .67956 .46458 L .68235 .46363 L F
.6878 .46585 m .68928 .46341 L .6906 .46497 L 0 .028 .127 r
F
.6878 .46585 m .68648 .46431 L .68928 .46341 L F
.62834 .46682 m .62974 .46445 L .63111 .46594 L 0 .03 .13 r
F
.62834 .46682 m .62697 .46536 L .62974 .46445 L F
.48451 .46784 m .4857 .46533 L .48721 .46698 L 0 .032 .133 r
F
.48451 .46784 m .483 .4662 L .4857 .46533 L F
.27975 .46517 m .28065 .46268 L .28235 .46433 L 0 .026 .125 r
F
.27975 .46517 m .27806 .46352 L .28065 .46268 L F
.45269 .4673 m .45383 .46515 L .45537 .46662 L 0 .032 .132 r
F
.45269 .4673 m .45114 .46584 L .45383 .46515 L F
.42086 .46674 m .42196 .46435 L .42353 .46601 L 0 .03 .13 r
F
.42086 .46674 m .4193 .46508 L .42196 .46435 L F
.69471 .46559 m .6962 .46319 L .69751 .46471 L 0 .027 .127 r
F
.69471 .46559 m .6934 .46408 L .6962 .46319 L F
.79981 .46446 m .80146 .4621 L .80267 .46361 L 0 .025 .124 r
F
.79981 .46446 m .7986 .46294 L .80146 .4621 L F
.38213 .46658 m .38317 .4642 L .38478 .46573 L 0 .03 .13 r
F
.38213 .46658 m .38052 .46503 L .38317 .4642 L F
.53706 .46735 m .53833 .465 L .53979 .46663 L 0 .031 .132 r
F
.53706 .46735 m .5356 .4657 L .53833 .465 L F
.35721 .46564 m .35822 .46323 L .35985 .46482 L 0 .028 .127 r
F
.35721 .46564 m .35558 .46408 L .35822 .46323 L F
.63526 .46661 m .63666 .46419 L .63803 .46576 L 0 .03 .13 r
F
.63526 .46661 m .63388 .46506 L .63666 .46419 L F
.31848 .46548 m .31944 .46295 L .32109 .46461 L 0 .027 .126 r
F
.31848 .46548 m .31682 .46382 L .31944 .46295 L F
.70163 .4653 m .70313 .46291 L .70443 .46438 L F
.70163 .4653 m .70032 .46381 L .70313 .46291 L F
.74727 .46511 m .74883 .46262 L .7501 .4643 L 0 .026 .126 r
F
.74727 .46511 m .74599 .46344 L .74883 .46262 L F
.5758 .46763 m .57712 .46548 L .57854 .4669 L 0 .033 .133 r
F
.5758 .46763 m .57437 .4662 L .57712 .46548 L F
.38903 .46633 m .39009 .46388 L .39169 .46538 L 0 .029 .129 r
F
.38903 .46633 m .38743 .46481 L .39009 .46388 L F
.80674 .46428 m .80839 .46184 L .8096 .46338 L 0 .025 .123 r
F
.80674 .46428 m .80553 .46275 L .80839 .46184 L F
.49142 .46775 m .49262 .46523 L .49412 .46689 L 0 .032 .133 r
F
.49142 .46775 m .48991 .4661 L .49262 .46523 L F
.70854 .46509 m .71004 .46251 L .71135 .46414 L 0 .026 .126 r
F
.70854 .46509 m .70724 .46345 L .71004 .46251 L F
.64217 .46649 m .64359 .464 L .64495 .46558 L 0 .03 .13 r
F
.64217 .46649 m .64081 .4649 L .64359 .464 L F
.39593 .46612 m .39699 .46388 L .39859 .46536 L 0 .029 .129 r
F
.39593 .46612 m .39434 .46463 L .39699 .46388 L F
.45959 .46728 m .46074 .46489 L .46228 .46638 L 0 .032 .132 r
F
.45959 .46728 m .45805 .4658 L .46074 .46489 L F
.7542 .46502 m .75576 .46241 L .75702 .46407 L 0 .026 .125 r
F
.7542 .46502 m .75293 .46337 L .75576 .46241 L F
.28663 .46522 m .28753 .46283 L .28922 .46446 L 0 .027 .126 r
F
.28663 .46522 m .28494 .46358 L .28753 .46283 L F
.76111 .46464 m .76269 .46217 L .76394 .46371 L 0 .026 .125 r
F
.76111 .46464 m .75985 .46311 L .76269 .46217 L F
.32536 .46541 m .32633 .46289 L .32798 .46457 L 0 .027 .127 r
F
.32536 .46541 m .32371 .46375 L .32633 .46289 L F
.656 .46581 m .65743 .46342 L .65878 .46487 L 0 .028 .128 r
F
.656 .46581 m .65465 .46436 L .65743 .46342 L F
.3641 .46562 m .36512 .46326 L .36674 .46487 L F
.3641 .46562 m .36248 .46401 L .36512 .46326 L F
.71546 .46488 m .71698 .46244 L .71828 .46408 L 0 .026 .125 r
F
.71546 .46488 m .71416 .46324 L .71698 .46244 L F
.76802 .46431 m .76961 .46189 L .77086 .46342 L 0 .025 .124 r
F
.76802 .46431 m .76677 .46277 L .76961 .46189 L F
.64909 .46623 m .65051 .46375 L .65187 .46529 L 0 .029 .129 r
F
.64909 .46623 m .64773 .46467 L .65051 .46375 L F
.81367 .46413 m .81532 .46162 L .81653 .46328 L 0 .025 .123 r
F
.81367 .46413 m .81246 .46248 L .81532 .46162 L F
.4665 .46705 m .46766 .46471 L .46919 .46625 L 0 .031 .132 r
F
.4665 .46705 m .46497 .46548 L .46766 .46471 L F
.66291 .46552 m .66436 .46329 L .6657 .46474 L 0 .028 .128 r
F
.66291 .46552 m .66157 .46408 L .66436 .46329 L F
.58271 .46764 m .58405 .46544 L .58546 .46691 L 0 .033 .134 r
F
.58271 .46764 m .58129 .46617 L .58405 .46544 L F
.49832 .46768 m .49953 .46533 L .50103 .46687 L F
.49832 .46768 m .49683 .46611 L .49953 .46533 L F
.42775 .46693 m .42887 .46445 L .43042 .46612 L 0 .031 .131 r
F
.42775 .46693 m .42619 .46527 L .42887 .46445 L F
.54397 .46756 m .54525 .46522 L .5467 .46686 L 0 .033 .134 r
F
.54397 .46756 m .54252 .46593 L .54525 .46522 L F
.77495 .46417 m .77655 .46172 L .77779 .4633 L 0 .025 .124 r
F
.77495 .46417 m .7737 .46257 L .77655 .46172 L F
.33226 .46532 m .33323 .46293 L .33488 .46451 L 0 .028 .127 r
F
.33226 .46532 m .33061 .46375 L .33323 .46293 L F
.29351 .46515 m .29444 .46258 L .29613 .46418 L 0 .027 .126 r
F
.29351 .46515 m .29183 .46354 L .29444 .46258 L F
.43466 .46673 m .43578 .46432 L .43733 .46585 L 0 .031 .131 r
F
.43466 .46673 m .4331 .46522 L .43578 .46432 L F
.30042 .46482 m .30135 .46238 L .30303 .46399 L 0 .027 .126 r
F
.30042 .46482 m .29874 .46322 L .30135 .46238 L F
.58963 .46753 m .59096 .46496 L .59238 .46656 L 0 .032 .133 r
F
.58963 .46753 m .58821 .46594 L .59096 .46496 L F
.40283 .4662 m .4039 .46365 L .40549 .4653 L 0 .029 .129 r
F
.40283 .4662 m .40124 .46455 L .4039 .46365 L F
.60345 .46678 m .60481 .46445 L .60621 .46596 L 0 .031 .132 r
F
.60345 .46678 m .60205 .46527 L .60481 .46445 L F
.66983 .46545 m .67129 .46318 L .67263 .46467 L 0 .028 .128 r
F
.66983 .46545 m .6685 .46396 L .67129 .46318 L F
.7224 .46488 m .72393 .46247 L .72522 .46406 L 0 .027 .126 r
F
.7224 .46488 m .7211 .46328 L .72393 .46247 L F
.50523 .46756 m .50645 .46537 L .50794 .46684 L 0 .033 .134 r
F
.50523 .46756 m .50374 .4661 L .50645 .46537 L F
.82061 .46412 m .82227 .46162 L .82348 .4633 L 0 .025 .124 r
F
.82061 .46412 m .8194 .46245 L .82227 .46162 L F
.4734 .467 m .47457 .46469 L .47609 .4662 L 0 .032 .132 r
F
.4734 .467 m .47188 .46546 L .47457 .46469 L F
.59654 .4672 m .59789 .46463 L .59929 .46623 L F
.59654 .4672 m .59513 .4656 L .59789 .46463 L F
.37099 .46569 m .37201 .4634 L .37363 .46494 L 0 .029 .129 r
F
.37099 .46569 m .36937 .46413 L .37201 .4634 L F
.33916 .46512 m .34014 .46264 L .34179 .46417 L 0 .027 .127 r
F
.33916 .46512 m .33751 .4636 L .34014 .46264 L F
.34606 .46478 m .34705 .46248 L .34869 .46404 L 0 .027 .126 r
F
.34606 .46478 m .34442 .46324 L .34705 .46248 L F
.78188 .46403 m .78348 .46147 L .78472 .4631 L 0 .025 .124 r
F
.78188 .46403 m .78063 .46238 L .78348 .46147 L F
.44156 .46656 m .44269 .46427 L .44424 .46578 L 0 .031 .131 r
F
.44156 .46656 m .44001 .46505 L .44269 .46427 L F
.72932 .46471 m .73087 .46241 L .73214 .46387 L 0 .027 .126 r
F
.72932 .46471 m .72804 .46324 L .73087 .46241 L F
.61036 .46663 m .61174 .46441 L .61313 .46584 L 0 .031 .132 r
F
.61036 .46663 m .60897 .46518 L .61174 .46441 L F
.82754 .46397 m .82921 .46142 L .83041 .46301 L 0 .025 .124 r
F
.82754 .46397 m .82635 .46236 L .82921 .46142 L F
.40973 .46608 m .41081 .46355 L .41239 .4652 L 0 .03 .13 r
F
.40973 .46608 m .40815 .46441 L .41081 .46355 L F
.52596 .46668 m .52721 .46433 L .52868 .46574 L 0 .031 .132 r
F
.52596 .46668 m .52449 .46527 L .52721 .46433 L F
.83446 .46363 m .83614 .46117 L .83733 .46273 L 0 .025 .123 r
F
.83446 .46363 m .83327 .46208 L .83614 .46117 L F
.55089 .46766 m .55217 .4651 L .55362 .46671 L 0 .033 .134 r
F
.55089 .46766 m .54944 .46605 L .55217 .4651 L F
.7888 .46384 m .79042 .46139 L .79166 .46303 L 0 .025 .124 r
F
.7888 .46384 m .78757 .46221 L .79042 .46139 L F
.30731 .46481 m .30825 .46229 L .30992 .46395 L 0 .027 .126 r
F
.30731 .46481 m .30564 .46316 L .30825 .46229 L F
.73624 .46442 m .73779 .46204 L .73906 .46352 L 0 .026 .125 r
F
.73624 .46442 m .73496 .46295 L .73779 .46204 L F
.51905 .46714 m .52029 .46477 L .52177 .46621 L 0 .032 .133 r
F
.51905 .46714 m .51757 .46572 L .52029 .46477 L F
.48031 .46695 m .48149 .46469 L .483 .4662 L F
.48031 .46695 m .47879 .46544 L .48149 .46469 L F
.5578 .46736 m .55909 .46482 L .56054 .46642 L 0 .033 .133 r
F
.5578 .46736 m .55636 .46576 L .55909 .46482 L F
.53287 .46641 m .53413 .46425 L .5356 .4657 L 0 .031 .132 r
F
.53287 .46641 m .53141 .46496 L .53413 .46425 L F
.51214 .46758 m .51337 .46517 L .51486 .46666 L 0 .033 .134 r
F
.51214 .46758 m .51065 .46611 L .51337 .46517 L F
.67676 .4655 m .67822 .46298 L .67956 .46458 L 0 .029 .128 r
F
.67676 .4655 m .67543 .4639 L .67822 .46298 L F
.84139 .46341 m .84308 .46095 L .84426 .46251 L 0 .024 .123 r
F
.84139 .46341 m .8402 .46184 L .84308 .46095 L F
.61728 .46649 m .61867 .46429 L .62005 .4657 L 0 .031 .132 r
F
.61728 .46649 m .6159 .46507 L .61867 .46429 L F
.56471 .46707 m .56602 .46459 L .56745 .46617 L 0 .032 .133 r
F
.56471 .46707 m .56327 .46548 L .56602 .46459 L F
.37788 .46575 m .37891 .46352 L .38052 .46503 L 0 .03 .13 r
F
.37788 .46575 m .37627 .46423 L .37891 .46352 L F
.27546 .46441 m .27636 .46186 L .27806 .46352 L 0 .026 .125 r
F
.27546 .46441 m .27376 .46274 L .27636 .46186 L F
.44847 .46653 m .4496 .4643 L .45114 .46584 L 0 .031 .132 r
F
.44847 .46653 m .44692 .46502 L .4496 .4643 L F
.41663 .46596 m .41773 .46346 L .4193 .46508 L 0 .03 .13 r
F
.41663 .46596 m .41506 .46432 L .41773 .46346 L F
.74316 .46427 m .74472 .46182 L .74599 .46344 L 0 .026 .125 r
F
.74316 .46427 m .74189 .46265 L .74472 .46182 L F
.35295 .46485 m .35395 .46251 L .35558 .46408 L 0 .028 .127 r
F
.35295 .46485 m .35132 .46331 L .35395 .46251 L F
.68368 .46525 m .68515 .46269 L .68648 .46431 L 0 .028 .128 r
F
.68368 .46525 m .68235 .46363 L .68515 .46269 L F
.3142 .46471 m .31516 .46215 L .31682 .46382 L 0 .027 .126 r
F
.3142 .46471 m .31254 .46305 L .31516 .46215 L F
.79574 .46377 m .79738 .46139 L .7986 .46294 L 0 .025 .124 r
F
.79574 .46377 m .79452 .46221 L .79738 .46139 L F
.6242 .46627 m .62559 .4639 L .62697 .46536 L 0 .031 .131 r
F
.6242 .46627 m .62282 .46484 L .62559 .4639 L F
.6906 .46497 m .69208 .4625 L .6934 .46408 L 0 .028 .127 r
F
.6906 .46497 m .68928 .46341 L .69208 .4625 L F
.63111 .46594 m .63251 .46354 L .63388 .46506 L 0 .03 .13 r
F
.63111 .46594 m .62974 .46445 L .63251 .46354 L F
.57163 .46692 m .57294 .46475 L .57437 .4662 L 0 .033 .133 r
F
.57163 .46692 m .5702 .46546 L .57294 .46475 L F
.48721 .46698 m .48841 .46444 L .48991 .4661 L 0 .032 .133 r
F
.48721 .46698 m .4857 .46533 L .48841 .46444 L F
.69751 .46471 m .69901 .46231 L .70032 .46381 L 0 .027 .127 r
F
.69751 .46471 m .6962 .46319 L .69901 .46231 L F
.28235 .46433 m .28325 .46194 L .28494 .46358 L 0 .027 .126 r
F
.28235 .46433 m .28065 .46268 L .28325 .46194 L F
.80267 .46361 m .80432 .46125 L .80553 .46275 L 0 .025 .124 r
F
.80267 .46361 m .80146 .4621 L .80432 .46125 L F
.70443 .46438 m .70593 .46198 L .70724 .46345 L 0 .027 .126 r
F
.70443 .46438 m .70313 .46291 L .70593 .46198 L F
.38478 .46573 m .38583 .4633 L .38743 .46481 L 0 .03 .13 r
F
.38478 .46573 m .38317 .4642 L .38583 .4633 L F
.63803 .46576 m .63944 .46332 L .64081 .4649 L F
.63803 .46576 m .63666 .46419 L .63944 .46332 L F
.32109 .46461 m .32206 .46208 L .32371 .46375 L 0 .027 .126 r
F
.32109 .46461 m .31944 .46295 L .32206 .46208 L F
.39169 .46538 m .39274 .46314 L .39434 .46463 L 0 .029 .129 r
F
.39169 .46538 m .39009 .46388 L .39274 .46314 L F
.35985 .46482 m .36086 .46239 L .36248 .46401 L 0 .028 .127 r
F
.35985 .46482 m .35822 .46323 L .36086 .46239 L F
.42353 .46601 m .42463 .46361 L .42619 .46527 L 0 .03 .131 r
F
.42353 .46601 m .42196 .46435 L .42463 .46361 L F
.7501 .4643 m .75166 .46169 L .75293 .46337 L 0 .026 .125 r
F
.7501 .4643 m .74883 .46262 L .75166 .46169 L F
.45537 .46662 m .45651 .46432 L .45805 .4658 L 0 .032 .133 r
F
.45537 .46662 m .45383 .46515 L .45651 .46432 L F
.53979 .46663 m .54106 .46429 L .54252 .46593 L F
.53979 .46663 m .53833 .465 L .54106 .46429 L F
.71135 .46414 m .71286 .46161 L .71416 .46324 L 0 .026 .125 r
F
.71135 .46414 m .71004 .46251 L .71286 .46161 L F
.8096 .46338 m .81125 .46093 L .81246 .46248 L 0 .025 .123 r
F
.8096 .46338 m .80839 .46184 L .81125 .46093 L F
.49412 .46689 m .49533 .46448 L .49683 .46611 L 0 .033 .133 r
F
.49412 .46689 m .49262 .46523 L .49533 .46448 L F
.57854 .4669 m .57987 .46474 L .58129 .46617 L 0 .033 .134 r
F
.57854 .4669 m .57712 .46548 L .57987 .46474 L F
.64495 .46558 m .64637 .46311 L .64773 .46467 L 0 .03 .13 r
F
.64495 .46558 m .64359 .464 L .64637 .46311 L F
.75702 .46407 m .75859 .46146 L .75985 .46311 L 0 .026 .125 r
F
.75702 .46407 m .75576 .46241 L .75859 .46146 L F
.46228 .46638 m .46344 .46398 L .46497 .46548 L 0 .032 .132 r
F
.46228 .46638 m .46074 .46489 L .46344 .46398 L F
.76394 .46371 m .76552 .46122 L .76677 .46277 L 0 .026 .124 r
F
.76394 .46371 m .76269 .46217 L .76552 .46122 L F
.65878 .46487 m .66022 .46262 L .66157 .46408 L 0 .028 .128 r
F
.65878 .46487 m .65743 .46342 L .66022 .46262 L F
.65187 .46529 m .65329 .46283 L .65465 .46436 L 0 .029 .129 r
F
.65187 .46529 m .65051 .46375 L .65329 .46283 L F
.32798 .46457 m .32896 .46208 L .33061 .46375 L 0 .027 .127 r
F
.32798 .46457 m .32633 .46289 L .32896 .46208 L F
.77086 .46342 m .77246 .46105 L .7737 .46257 L 0 .025 .124 r
F
.77086 .46342 m .76961 .46189 L .77246 .46105 L F
.39859 .46536 m .39965 .46307 L .40124 .46455 L 0 .03 .13 r
F
.39859 .46536 m .39699 .46388 L .39965 .46307 L F
.81653 .46328 m .81819 .46078 L .8194 .46245 L 0 .025 .123 r
F
.81653 .46328 m .81532 .46162 L .81819 .46078 L F
.28922 .46446 m .29014 .46193 L .29183 .46354 L 0 .027 .127 r
F
.28922 .46446 m .28753 .46283 L .29014 .46193 L F
.71828 .46408 m .7198 .46164 L .7211 .46328 L 0 .027 .126 r
F
.71828 .46408 m .71698 .46244 L .7198 .46164 L F
.36674 .46487 m .36776 .46251 L .36937 .46413 L 0 .029 .128 r
F
.36674 .46487 m .36512 .46326 L .36776 .46251 L F
.46919 .46625 m .47035 .46394 L .47188 .46546 L 0 .032 .132 r
F
.46919 .46625 m .46766 .46471 L .47035 .46394 L F
.6657 .46474 m .66716 .4625 L .6685 .46396 L 0 .028 .128 r
F
.6657 .46474 m .66436 .46329 L .66716 .4625 L F
.29613 .46418 m .29706 .46165 L .29874 .46322 L 0 .027 .126 r
F
.29613 .46418 m .29444 .46258 L .29706 .46165 L F
.50103 .46687 m .50224 .46457 L .50374 .4661 L 0 .033 .134 r
F
.50103 .46687 m .49953 .46533 L .50224 .46457 L F
.43042 .46612 m .43154 .46355 L .4331 .46522 L 0 .031 .131 r
F
.43042 .46612 m .42887 .46445 L .43154 .46355 L F
.58546 .46691 m .5868 .46447 L .58821 .46594 L 0 .033 .134 r
F
.58546 .46691 m .58405 .46544 L .5868 .46447 L F
.77779 .4633 m .7794 .46081 L .78063 .46238 L 0 .025 .124 r
F
.77779 .4633 m .77655 .46172 L .7794 .46081 L F
.59238 .46656 m .59372 .46399 L .59513 .4656 L 0 .032 .133 r
F
.59238 .46656 m .59096 .46496 L .59372 .46399 L F
.43733 .46585 m .43846 .46352 L .44001 .46505 L 0 .031 .131 r
F
.43733 .46585 m .43578 .46432 L .43846 .46352 L F
.59929 .46623 m .60064 .46366 L .60205 .46527 L 0 .031 .132 r
F
.59929 .46623 m .59789 .46463 L .60064 .46366 L F
.33488 .46451 m .33586 .46202 L .33751 .4636 L 0 .028 .127 r
F
.33488 .46451 m .33323 .46293 L .33586 .46202 L F
.40549 .4653 m .40657 .46274 L .40815 .46441 L 0 .029 .129 r
F
.40549 .4653 m .4039 .46365 L .40657 .46274 L F
.34179 .46417 m .34278 .46169 L .34442 .46324 L 0 .027 .126 r
F
.34179 .46417 m .34014 .46264 L .34278 .46169 L F
.5467 .46686 m .54798 .46441 L .54944 .46605 L 0 .033 .134 r
F
.5467 .46686 m .54525 .46522 L .54798 .46441 L F
.30303 .46399 m .30396 .46154 L .30564 .46316 L 0 .027 .126 r
F
.30303 .46399 m .30135 .46238 L .30396 .46154 L F
.60621 .46596 m .60758 .46368 L .60897 .46518 L 0 .031 .132 r
F
.60621 .46596 m .60481 .46445 L .60758 .46368 L F
.78472 .4631 m .78633 .46058 L .78757 .46221 L 0 .025 .123 r
F
.78472 .4631 m .78348 .46147 L .78633 .46058 L F
.72522 .46406 m .72675 .46166 L .72804 .46324 L 0 .027 .126 r
F
.72522 .46406 m .72393 .46247 L .72675 .46166 L F
.82348 .4633 m .82514 .46069 L .82635 .46236 L 0 .025 .124 r
F
.82348 .4633 m .82227 .46162 L .82514 .46069 L F
.47609 .4662 m .47727 .46393 L .47879 .46544 L 0 .032 .133 r
F
.47609 .4662 m .47457 .46469 L .47727 .46393 L F
.67263 .46467 m .67409 .46241 L .67543 .4639 L 0 .029 .128 r
F
.67263 .46467 m .67129 .46318 L .67409 .46241 L F
.50794 .46684 m .50917 .46464 L .51065 .46611 L 0 .034 .135 r
F
.50794 .46684 m .50645 .46537 L .50917 .46464 L F
.83041 .46301 m .83208 .46048 L .83327 .46208 L 0 .025 .123 r
F
.83041 .46301 m .82921 .46142 L .83208 .46048 L F
.37363 .46494 m .37465 .4627 L .37627 .46423 L 0 .029 .129 r
F
.37363 .46494 m .37201 .4634 L .37465 .4627 L F
.27116 .46362 m .27206 .46107 L .27376 .46274 L 0 .026 .125 r
F
.27116 .46362 m .26946 .46193 L .27206 .46107 L F
.52868 .46574 m .52994 .46355 L .53141 .46496 L 0 .031 .132 r
F
.52868 .46574 m .52721 .46433 L .52994 .46355 L F
.55362 .46671 m .55491 .46415 L .55636 .46576 L 0 .033 .134 r
F
.55362 .46671 m .55217 .4651 L .55491 .46415 L F
.34869 .46404 m .34968 .46172 L .35132 .46331 L 0 .027 .127 r
F
.34869 .46404 m .34705 .46248 L .34968 .46172 L F
.41239 .4652 m .41348 .46269 L .41506 .46432 L 0 .03 .13 r
F
.41239 .4652 m .41081 .46355 L .41348 .46269 L F
.44424 .46578 m .44537 .46349 L .44692 .46502 L 0 .031 .132 r
F
.44424 .46578 m .44269 .46427 L .44537 .46349 L F
.73214 .46387 m .73369 .46148 L .73496 .46295 L 0 .027 .126 r
F
.73214 .46387 m .73087 .46241 L .73369 .46148 L F
.83733 .46273 m .83902 .46026 L .8402 .46184 L 0 .024 .123 r
F
.83733 .46273 m .83614 .46117 L .83902 .46026 L F
.73906 .46352 m .74062 .46115 L .74189 .46265 L 0 .026 .125 r
F
.73906 .46352 m .73779 .46204 L .74062 .46115 L F
.52177 .46621 m .52301 .46383 L .52449 .46527 L 0 .032 .133 r
F
.52177 .46621 m .52029 .46477 L .52301 .46383 L F
.61313 .46584 m .61451 .46364 L .6159 .46507 L 0 .032 .132 r
F
.61313 .46584 m .61174 .46441 L .61451 .46364 L F
.56054 .46642 m .56183 .4639 L .56327 .46548 L 0 .032 .133 r
F
.56054 .46642 m .55909 .46482 L .56183 .4639 L F
.30992 .46395 m .31087 .46139 L .31254 .46305 L 0 .027 .126 r
F
.30992 .46395 m .30825 .46229 L .31087 .46139 L F
.51486 .46666 m .51609 .4642 L .51757 .46572 L 0 .033 .134 r
F
.51486 .46666 m .51337 .46517 L .51609 .4642 L F
.79166 .46303 m .79328 .46056 L .79452 .46221 L 0 .025 .124 r
F
.79166 .46303 m .79042 .46139 L .79328 .46056 L F
.67956 .46458 m .68102 .46202 L .68235 .46363 L 0 .028 .128 r
F
.67956 .46458 m .67822 .46298 L .68102 .46202 L F
.84426 .46251 m .84596 .46006 L .84714 .46161 L 0 .024 .122 r
F
.84426 .46251 m .84308 .46095 L .84596 .46006 L F
.56745 .46617 m .56876 .46386 L .5702 .46546 L 0 .032 .133 r
F
.56745 .46617 m .56602 .46459 L .56876 .46386 L F
.483 .4662 m .48419 .46383 L .4857 .46533 L F
.483 .4662 m .48149 .46469 L .48419 .46383 L F
.27806 .46352 m .27896 .46104 L .28065 .46268 L 0 .026 .125 r
F
.27806 .46352 m .27636 .46186 L .27896 .46104 L F
.68648 .46431 m .68795 .46177 L .68928 .46341 L 0 .028 .127 r
F
.68648 .46431 m .68515 .46269 L .68795 .46177 L F
.4193 .46508 m .42039 .46272 L .42196 .46435 L 0 .03 .13 r
F
.4193 .46508 m .41773 .46346 L .42039 .46272 L F
.62005 .4657 m .62144 .46342 L .62282 .46484 L 0 .031 .132 r
F
.62005 .4657 m .61867 .46429 L .62144 .46342 L F
.5356 .4657 m .53686 .46355 L .53833 .465 L 0 .032 .132 r
F
.5356 .4657 m .53413 .46425 L .53686 .46355 L F
.31682 .46382 m .31778 .46128 L .31944 .46295 L 0 .027 .126 r
F
.31682 .46382 m .31516 .46215 L .31778 .46128 L F
.62697 .46536 m .62836 .46295 L .62974 .46445 L 0 .031 .131 r
F
.62697 .46536 m .62559 .4639 L .62836 .46295 L F
.74599 .46344 m .74755 .46098 L .74883 .46262 L 0 .026 .125 r
F
.74599 .46344 m .74472 .46182 L .74755 .46098 L F
.38052 .46503 m .38156 .4627 L .38317 .4642 L 0 .03 .13 r
F
.38052 .46503 m .37891 .46352 L .38156 .4627 L F
.35558 .46408 m .35659 .46164 L .35822 .46323 L 0 .028 .127 r
F
.35558 .46408 m .35395 .46251 L .35659 .46164 L F
.6934 .46408 m .69489 .46162 L .6962 .46319 L F
.6934 .46408 m .69208 .4625 L .69489 .46162 L F
.7986 .46294 m .80024 .46057 L .80146 .4621 L 0 .025 .124 r
F
.7986 .46294 m .79738 .46139 L .80024 .46057 L F
.63388 .46506 m .63529 .46264 L .63666 .46419 L 0 .03 .13 r
F
.63388 .46506 m .63251 .46354 L .63529 .46264 L F
.45114 .46584 m .45228 .46359 L .45383 .46515 L 0 .032 .133 r
F
.45114 .46584 m .4496 .4643 L .45228 .46359 L F
.48991 .4661 m .49111 .46357 L .49262 .46523 L F
.48991 .4661 m .48841 .46444 L .49111 .46357 L F
.70032 .46381 m .70182 .46143 L .70313 .46291 L 0 .027 .127 r
F
.70032 .46381 m .69901 .46231 L .70182 .46143 L F
.70724 .46345 m .70875 .46105 L .71004 .46251 L 0 .027 .126 r
F
.70724 .46345 m .70593 .46198 L .70875 .46105 L F
.38743 .46481 m .38848 .46239 L .39009 .46388 L 0 .03 .13 r
F
.38743 .46481 m .38583 .4633 L .38848 .46239 L F
.80553 .46275 m .80718 .46033 L .80839 .46184 L 0 .025 .124 r
F
.80553 .46275 m .80432 .46125 L .80718 .46033 L F
.57437 .4662 m .5757 .46403 L .57712 .46548 L 0 .033 .134 r
F
.57437 .4662 m .57294 .46475 L .5757 .46403 L F
.32371 .46375 m .32468 .46122 L .32633 .46289 L 0 .027 .126 r
F
.32371 .46375 m .32206 .46208 L .32468 .46122 L F
.64081 .4649 m .64222 .46245 L .64359 .464 L 0 .03 .13 r
F
.64081 .4649 m .63944 .46332 L .64222 .46245 L F
.75293 .46337 m .75449 .46075 L .75576 .46241 L 0 .026 .125 r
F
.75293 .46337 m .75166 .46169 L .75449 .46075 L F
.28494 .46358 m .28584 .46121 L .28753 .46283 L 0 .027 .126 r
F
.28494 .46358 m .28325 .46194 L .28584 .46121 L F
.71416 .46324 m .71568 .46081 L .71698 .46244 L 0 .026 .125 r
F
.71416 .46324 m .71286 .46161 L .71568 .46081 L F
.36248 .46401 m .3635 .46162 L .36512 .46326 L 0 .028 .128 r
F
.36248 .46401 m .36086 .46239 L .3635 .46162 L F
.81246 .46248 m .81411 .46006 L .81532 .46162 L 0 .025 .123 r
F
.81246 .46248 m .81125 .46093 L .81411 .46006 L F
.39434 .46463 m .39539 .4624 L .39699 .46388 L 0 .03 .13 r
F
.39434 .46463 m .39274 .46314 L .39539 .4624 L F
.75985 .46311 m .76143 .46051 L .76269 .46217 L 0 .026 .125 r
F
.75985 .46311 m .75859 .46146 L .76143 .46051 L F
.45805 .4658 m .45921 .4634 L .46074 .46489 L 0 .032 .133 r
F
.45805 .4658 m .45651 .46432 L .45921 .4634 L F
.64773 .46467 m .64915 .46221 L .65051 .46375 L 0 .029 .129 r
F
.64773 .46467 m .64637 .46311 L .64915 .46221 L F
.76677 .46277 m .76837 .46035 L .76961 .46189 L 0 .025 .124 r
F
.76677 .46277 m .76552 .46122 L .76837 .46035 L F
.42619 .46527 m .4273 .46279 L .42887 .46445 L 0 .031 .131 r
F
.42619 .46527 m .42463 .46361 L .4273 .46279 L F
.46497 .46548 m .46613 .46322 L .46766 .46471 L 0 .032 .132 r
F
.46497 .46548 m .46344 .46398 L .46613 .46322 L F
.65465 .46436 m .65608 .46191 L .65743 .46342 L 0 .029 .129 r
F
.65465 .46436 m .65329 .46283 L .65608 .46191 L F
.49683 .46611 m .49803 .46373 L .49953 .46533 L 0 .033 .134 r
F
.49683 .46611 m .49533 .46448 L .49803 .46373 L F
.54252 .46593 m .54379 .46358 L .54525 .46522 L 0 .033 .133 r
F
.54252 .46593 m .54106 .46429 L .54379 .46358 L F
.58129 .46617 m .58263 .46401 L .58405 .46544 L 0 .034 .135 r
F
.58129 .46617 m .57987 .46474 L .58263 .46401 L F
.66157 .46408 m .66302 .46182 L .66436 .46329 L 0 .029 .128 r
F
.66157 .46408 m .66022 .46262 L .66302 .46182 L F
.7737 .46257 m .77531 .4602 L .77655 .46172 L 0 .025 .124 r
F
.7737 .46257 m .77246 .46105 L .77531 .4602 L F
.29183 .46354 m .29276 .46099 L .29444 .46258 L 0 .027 .126 r
F
.29183 .46354 m .29014 .46193 L .29276 .46099 L F
.33061 .46375 m .33158 .46127 L .33323 .46293 L 0 .028 .127 r
F
.33061 .46375 m .32896 .46208 L .33158 .46127 L F
.40124 .46455 m .40231 .46216 L .4039 .46365 L 0 .03 .13 r
F
.40124 .46455 m .39965 .46307 L .40231 .46216 L F
.8194 .46245 m .82106 .45994 L .82227 .46162 L 0 .025 .124 r
F
.8194 .46245 m .81819 .46078 L .82106 .45994 L F
.29874 .46322 m .29967 .46083 L .30135 .46238 L 0 .027 .126 r
F
.29874 .46322 m .29706 .46165 L .29967 .46083 L F
.58821 .46594 m .58955 .4635 L .59096 .46496 L 0 .033 .133 r
F
.58821 .46594 m .5868 .46447 L .58955 .4635 L F
.7211 .46328 m .72263 .46083 L .72393 .46247 L 0 .027 .126 r
F
.7211 .46328 m .7198 .46164 L .72263 .46083 L F
.59513 .4656 m .59648 .46301 L .59789 .46463 L 0 .032 .132 r
F
.59513 .4656 m .59372 .46399 L .59648 .46301 L F
.4331 .46522 m .43422 .46265 L .43578 .46432 L 0 .031 .131 r
F
.4331 .46522 m .43154 .46355 L .43422 .46265 L F
.78063 .46238 m .78224 .4599 L .78348 .46147 L 0 .025 .124 r
F
.78063 .46238 m .7794 .46081 L .78224 .4599 L F
.60205 .46527 m .60341 .46284 L .60481 .46445 L 0 .031 .132 r
F
.60205 .46527 m .60064 .46366 L .60341 .46284 L F
.47188 .46546 m .47305 .46318 L .47457 .46469 L 0 .032 .133 r
F
.47188 .46546 m .47035 .46394 L .47305 .46318 L F
.36937 .46413 m .3704 .46178 L .37201 .4634 L 0 .029 .129 r
F
.36937 .46413 m .36776 .46251 L .3704 .46178 L F
.6685 .46396 m .66996 .46172 L .67129 .46318 L F
.6685 .46396 m .66716 .4625 L .66996 .46172 L F
.33751 .4636 m .3385 .46106 L .34014 .46264 L 0 .028 .127 r
F
.33751 .4636 m .33586 .46202 L .3385 .46106 L F
.50374 .4661 m .50496 .46385 L .50645 .46537 L 0 .034 .135 r
F
.50374 .4661 m .50224 .46457 L .50496 .46385 L F
.34442 .46324 m .34541 .46091 L .34705 .46248 L 0 .027 .126 r
F
.34442 .46324 m .34278 .46169 L .34541 .46091 L F
.40815 .46441 m .40924 .46189 L .41081 .46355 L 0 .029 .129 r
F
.40815 .46441 m .40657 .46274 L .40924 .46189 L F
.82635 .46236 m .82801 .45975 L .82921 .46142 L 0 .025 .123 r
F
.82635 .46236 m .82514 .46069 L .82801 .45975 L F
.44001 .46505 m .44114 .46273 L .44269 .46427 L 0 .031 .132 r
F
.44001 .46505 m .43846 .46352 L .44114 .46273 L F
.30564 .46316 m .30658 .46066 L .30825 .46229 L 0 .027 .126 r
F
.30564 .46316 m .30396 .46154 L .30658 .46066 L F
.54944 .46605 m .55072 .46349 L .55217 .4651 L 0 .033 .134 r
F
.54944 .46605 m .54798 .46441 L .55072 .46349 L F
.78757 .46221 m .78919 .45974 L .79042 .46139 L 0 .025 .123 r
F
.78757 .46221 m .78633 .46058 L .78919 .45974 L F
.83327 .46208 m .83495 .45957 L .83614 .46117 L F
.83327 .46208 m .83208 .46048 L .83495 .45957 L F
.72804 .46324 m .72958 .46084 L .73087 .46241 L 0 .027 .127 r
F
.72804 .46324 m .72675 .46166 L .72958 .46084 L F
.55636 .46576 m .55765 .46324 L .55909 .46482 L 0 .033 .133 r
F
.55636 .46576 m .55491 .46415 L .55765 .46324 L F
.60897 .46518 m .61035 .46292 L .61174 .46441 L 0 .032 .132 r
F
.60897 .46518 m .60758 .46368 L .61035 .46292 L F
.27376 .46274 m .27466 .4602 L .27636 .46186 L 0 .026 .125 r
F
.27376 .46274 m .27206 .46107 L .27466 .4602 L F
.67543 .4639 m .67689 .46148 L .67822 .46298 L 0 .029 .128 r
F
.67543 .4639 m .67409 .46241 L .67689 .46148 L F
.47879 .46544 m .47997 .46318 L .48149 .46469 L 0 .032 .133 r
F
.47879 .46544 m .47727 .46393 L .47997 .46318 L F
.73496 .46295 m .73651 .46055 L .73779 .46204 L 0 .027 .126 r
F
.73496 .46295 m .73369 .46148 L .73651 .46055 L F
.52449 .46527 m .52574 .46289 L .52721 .46433 L 0 .032 .132 r
F
.52449 .46527 m .52301 .46383 L .52574 .46289 L F
.41506 .46432 m .41615 .46185 L .41773 .46346 L 0 .03 .13 r
F
.41506 .46432 m .41348 .46269 L .41615 .46185 L F
.8402 .46184 m .8419 .45938 L .84308 .46095 L 0 .024 .123 r
F
.8402 .46184 m .83902 .46026 L .8419 .45938 L F
.56327 .46548 m .56458 .463 L .56602 .46459 L 0 .032 .133 r
F
.56327 .46548 m .56183 .4639 L .56458 .463 L F
.51757 .46572 m .51881 .46325 L .52029 .46477 L 0 .033 .134 r
F
.51757 .46572 m .51609 .4642 L .51881 .46325 L F
.74189 .46265 m .74345 .46029 L .74472 .46182 L 0 .026 .125 r
F
.74189 .46265 m .74062 .46115 L .74345 .46029 L F
.51065 .46611 m .51188 .46367 L .51337 .46517 L 0 .034 .135 r
F
.51065 .46611 m .50917 .46464 L .51188 .46367 L F
.53141 .46496 m .53267 .46283 L .53413 .46425 L 0 .032 .132 r
F
.53141 .46496 m .52994 .46355 L .53267 .46283 L F
.31254 .46305 m .31349 .46048 L .31516 .46215 L 0 .027 .126 r
F
.31254 .46305 m .31087 .46139 L .31349 .46048 L F
.68235 .46363 m .68382 .46106 L .68515 .46269 L 0 .028 .128 r
F
.68235 .46363 m .68102 .46202 L .68382 .46106 L F
.37627 .46423 m .3773 .462 L .37891 .46352 L 0 .03 .13 r
F
.37627 .46423 m .37465 .4627 L .3773 .462 L F
.44692 .46502 m .44805 .46274 L .4496 .4643 L 0 .032 .132 r
F
.44692 .46502 m .44537 .46349 L .44805 .46274 L F
.35132 .46331 m .35232 .4609 L .35395 .46251 L 0 .028 .127 r
F
.35132 .46331 m .34968 .46172 L .35232 .4609 L F
.84714 .46161 m .84884 .45917 L .85002 .4607 L 0 .024 .122 r
F
.84714 .46161 m .84596 .46006 L .84884 .45917 L F
.6159 .46507 m .61728 .46287 L .61867 .46429 L 0 .032 .133 r
F
.6159 .46507 m .61451 .46364 L .61728 .46287 L F
.79452 .46221 m .79615 .45974 L .79738 .46139 L 0 .025 .124 r
F
.79452 .46221 m .79328 .46056 L .79615 .45974 L F
.68928 .46341 m .69075 .46084 L .69208 .4625 L 0 .028 .127 r
F
.68928 .46341 m .68795 .46177 L .69075 .46084 L F
.4857 .46533 m .4869 .46293 L .48841 .46444 L 0 .032 .133 r
F
.4857 .46533 m .48419 .46383 L .4869 .46293 L F
.28065 .46268 m .28155 .46031 L .28325 .46194 L 0 .027 .126 r
F
.28065 .46268 m .27896 .46104 L .28155 .46031 L F
.62974 .46445 m .63114 .46202 L .63251 .46354 L 0 .03 .131 r
F
.62974 .46445 m .62836 .46295 L .63114 .46202 L F
.62282 .46484 m .62421 .46247 L .62559 .4639 L 0 .031 .132 r
F
.62282 .46484 m .62144 .46342 L .62421 .46247 L F
.31944 .46295 m .3204 .4604 L .32206 .46208 L 0 .027 .126 r
F
.31944 .46295 m .31778 .46128 L .3204 .4604 L F
.5702 .46546 m .57151 .46313 L .57294 .46475 L 0 .033 .134 r
F
.5702 .46546 m .56876 .46386 L .57151 .46313 L F
.6962 .46319 m .6977 .46076 L .69901 .46231 L 0 .028 .127 r
F
.6962 .46319 m .69489 .46162 L .6977 .46076 L F
.74883 .46262 m .75039 .46006 L .75166 .46169 L 0 .026 .125 r
F
.74883 .46262 m .74755 .46098 L .75039 .46006 L F
.42196 .46435 m .42306 .46198 L .42463 .46361 L 0 .03 .131 r
F
.42196 .46435 m .42039 .46272 L .42306 .46198 L F
.63666 .46419 m .63807 .46174 L .63944 .46332 L 0 .03 .13 r
F
.63666 .46419 m .63529 .46264 L .63807 .46174 L F
.35822 .46323 m .35923 .46076 L .36086 .46239 L 0 .028 .127 r
F
.35822 .46323 m .35659 .46164 L .35923 .46076 L F
.38317 .4642 m .38422 .46181 L .38583 .4633 L 0 .03 .13 r
F
.38317 .4642 m .38156 .4627 L .38422 .46181 L F
.80146 .4621 m .80311 .45973 L .80432 .46125 L 0 .026 .124 r
F
.80146 .4621 m .80024 .46057 L .80311 .45973 L F
.53833 .465 m .5396 .46281 L .54106 .46429 L 0 .032 .133 r
F
.53833 .465 m .53686 .46355 L .5396 .46281 L F
.71004 .46251 m .71156 .46016 L .71286 .46161 L 0 .026 .126 r
F
.71004 .46251 m .70875 .46105 L .71156 .46016 L F
.70313 .46291 m .70463 .46051 L .70593 .46198 L 0 .027 .127 r
F
.70313 .46291 m .70182 .46143 L .70463 .46051 L F
.39009 .46388 m .39114 .46166 L .39274 .46314 L 0 .03 .13 r
F
.39009 .46388 m .38848 .46239 L .39114 .46166 L F
.49262 .46523 m .49382 .46285 L .49533 .46448 L 0 .032 .133 r
F
.49262 .46523 m .49111 .46357 L .49382 .46285 L F
.75576 .46241 m .75732 .4598 L .75859 .46146 L 0 .026 .125 r
F
.75576 .46241 m .75449 .46075 L .75732 .4598 L F
.80839 .46184 m .81004 .45941 L .81125 .46093 L 0 .025 .124 r
F
.80839 .46184 m .80718 .46033 L .81004 .45941 L F
.45383 .46515 m .45497 .46274 L .45651 .46432 L 0 .032 .133 r
F
.45383 .46515 m .45228 .46359 L .45497 .46274 L F
.64359 .464 m .645 .46157 L .64637 .46311 L 0 .03 .13 r
F
.64359 .464 m .64222 .46245 L .645 .46157 L F
.32633 .46289 m .3273 .46041 L .32896 .46208 L 0 .027 .127 r
F
.32633 .46289 m .32468 .46122 L .3273 .46041 L F
.76269 .46217 m .76426 .45957 L .76552 .46122 L 0 .026 .124 r
F
.76269 .46217 m .76143 .46051 L .76426 .45957 L F
.81532 .46162 m .81699 .45921 L .81819 .46078 L 0 .025 .123 r
F
.81532 .46162 m .81411 .46006 L .81699 .45921 L F
.46074 .46489 m .4619 .46248 L .46344 .46398 L 0 .032 .133 r
F
.46074 .46489 m .45921 .4634 L .4619 .46248 L F
.57712 .46548 m .57845 .46329 L .57987 .46474 L 0 .034 .135 r
F
.57712 .46548 m .5757 .46403 L .57845 .46329 L F
.65051 .46375 m .65194 .46131 L .65329 .46283 L 0 .029 .129 r
F
.65051 .46375 m .64915 .46221 L .65194 .46131 L F
.71698 .46244 m .7185 .46 L .7198 .46164 L 0 .027 .126 r
F
.71698 .46244 m .71568 .46081 L .7185 .46 L F
.28753 .46283 m .28845 .46033 L .29014 .46193 L 0 .027 .127 r
F
.28753 .46283 m .28584 .46121 L .28845 .46033 L F
.65743 .46342 m .65887 .4611 L .66022 .46262 L 0 .029 .129 r
F
.65743 .46342 m .65608 .46191 L .65887 .4611 L F
.76961 .46189 m .77122 .45952 L .77246 .46105 L 0 .025 .124 r
F
.76961 .46189 m .76837 .46035 L .77122 .45952 L F
.36512 .46326 m .36614 .46087 L .36776 .46251 L 0 .028 .128 r
F
.36512 .46326 m .3635 .46162 L .36614 .46087 L F
.39699 .46388 m .39805 .46161 L .39965 .46307 L 0 .03 .13 r
F
.39699 .46388 m .39539 .4624 L .39805 .46161 L F
.42887 .46445 m .42998 .46189 L .43154 .46355 L 0 .031 .131 r
F
.42887 .46445 m .4273 .46279 L .42998 .46189 L F
.29444 .46258 m .29537 .46007 L .29706 .46165 L 0 .027 .126 r
F
.29444 .46258 m .29276 .46099 L .29537 .46007 L F
.46766 .46471 m .46882 .46245 L .47035 .46394 L 0 .032 .133 r
F
.46766 .46471 m .46613 .46322 L .46882 .46245 L F
.49953 .46533 m .50075 .463 L .50224 .46457 L 0 .033 .134 r
F
.49953 .46533 m .49803 .46373 L .50075 .463 L F
.59096 .46496 m .59231 .46253 L .59372 .46399 L 0 .032 .133 r
F
.59096 .46496 m .58955 .4635 L .59231 .46253 L F
.77655 .46172 m .77816 .45931 L .7794 .46081 L 0 .025 .124 r
F
.77655 .46172 m .77531 .4602 L .77816 .45931 L F
.4039 .46365 m .40498 .46125 L .40657 .46274 L 0 .029 .129 r
F
.4039 .46365 m .40231 .46216 L .40498 .46125 L F
.59789 .46463 m .59924 .46204 L .60064 .46366 L 0 .031 .132 r
F
.59789 .46463 m .59648 .46301 L .59924 .46204 L F
.66436 .46329 m .66582 .46102 L .66716 .4625 L 0 .029 .129 r
F
.66436 .46329 m .66302 .46182 L .66582 .46102 L F
.54525 .46522 m .54653 .46278 L .54798 .46441 L 0 .033 .134 r
F
.54525 .46522 m .54379 .46358 L .54653 .46278 L F
.33323 .46293 m .33421 .46036 L .33586 .46202 L 0 .028 .127 r
F
.33323 .46293 m .33158 .46127 L .33421 .46036 L F
.58405 .46544 m .58538 .46305 L .5868 .46447 L 0 .034 .135 r
F
.58405 .46544 m .58263 .46401 L .58538 .46305 L F
.30135 .46238 m .30228 .46001 L .30396 .46154 L 0 .027 .126 r
F
.30135 .46238 m .29967 .46083 L .30228 .46001 L F
.82227 .46162 m .82393 .45902 L .82514 .46069 L 0 .025 .123 r
F
.82227 .46162 m .82106 .45994 L .82393 .45902 L F
.43578 .46432 m .4369 .46188 L .43846 .46352 L 0 .031 .131 r
F
.43578 .46432 m .43422 .46265 L .4369 .46188 L F
.78348 .46147 m .7851 .45902 L .78633 .46058 L 0 .025 .123 r
F
.78348 .46147 m .78224 .4599 L .7851 .45902 L F
.34014 .46264 m .34114 .4601 L .34278 .46169 L 0 .027 .127 r
F
.34014 .46264 m .3385 .46106 L .34114 .4601 L F
.72393 .46247 m .72546 .46003 L .72675 .46166 L 0 .027 .126 r
F
.72393 .46247 m .72263 .46083 L .72546 .46003 L F
.26946 .46193 m .27035 .45952 L .27206 .46107 L 0 .026 .125 r
F
.26946 .46193 m .26775 .4604 L .27035 .45952 L F
.60481 .46445 m .60618 .46208 L .60758 .46368 L 0 .032 .132 r
F
.60481 .46445 m .60341 .46284 L .60618 .46208 L F
.82921 .46142 m .83088 .45882 L .83208 .46048 L 0 .025 .123 r
F
.82921 .46142 m .82801 .45975 L .83088 .45882 L F
.47457 .46469 m .47575 .46241 L .47727 .46393 L 0 .032 .133 r
F
.47457 .46469 m .47305 .46318 L .47575 .46241 L F
.41081 .46355 m .4119 .46106 L .41348 .46269 L 0 .029 .129 r
F
.41081 .46355 m .40924 .46189 L .4119 .46106 L F
.55217 .4651 m .55346 .46256 L .55491 .46415 L 0 .033 .134 r
F
.55217 .4651 m .55072 .46349 L .55346 .46256 L F
.67129 .46318 m .67276 .46094 L .67409 .46241 L 0 .029 .129 r
F
.67129 .46318 m .66996 .46172 L .67276 .46094 L F
.37201 .4634 m .37304 .46107 L .37465 .4627 L F
.37201 .4634 m .3704 .46178 L .37304 .46107 L F
.34705 .46248 m .34804 .46014 L .34968 .46172 L 0 .027 .127 r
F
.34705 .46248 m .34541 .46091 L .34804 .46014 L F
.30825 .46229 m .3092 .45975 L .31087 .46139 L 0 .027 .126 r
F
.30825 .46229 m .30658 .46066 L .3092 .45975 L F
.50645 .46537 m .50767 .46312 L .50917 .46464 L 0 .034 .135 r
F
.50645 .46537 m .50496 .46385 L .50767 .46312 L F
.83614 .46117 m .83783 .45865 L .83902 .46026 L 0 .024 .123 r
F
.83614 .46117 m .83495 .45957 L .83783 .45865 L F
.55909 .46482 m .56039 .46233 L .56183 .4639 L 0 .032 .133 r
F
.55909 .46482 m .55765 .46324 L .56039 .46233 L F
.44269 .46427 m .44382 .46195 L .44537 .46349 L 0 .032 .132 r
F
.44269 .46427 m .44114 .46273 L .44382 .46195 L F
.79042 .46139 m .79205 .45891 L .79328 .46056 L 0 .025 .124 r
F
.79042 .46139 m .78919 .45974 L .79205 .45891 L F
.67822 .46298 m .67969 .46051 L .68102 .46202 L 0 .028 .128 r
F
.67822 .46298 m .67689 .46148 L .67969 .46051 L F
.73087 .46241 m .7324 .4599 L .73369 .46148 L 0 .027 .127 r
F
.73087 .46241 m .72958 .46084 L .7324 .4599 L F
.52721 .46433 m .52847 .4621 L .52994 .46355 L 0 .032 .132 r
F
.52721 .46433 m .52574 .46289 L .52847 .4621 L F
.73779 .46204 m .73934 .45964 L .74062 .46115 L 0 .027 .126 r
F
.73779 .46204 m .73651 .46055 L .73934 .45964 L F
.27636 .46186 m .27726 .45939 L .27896 .46104 L 0 .026 .125 r
F
.27636 .46186 m .27466 .4602 L .27726 .45939 L F
.52029 .46477 m .52154 .46231 L .52301 .46383 L 0 .033 .133 r
F
.52029 .46477 m .51881 .46325 L .52154 .46231 L F
.56602 .46459 m .56733 .46225 L .56876 .46386 L 0 .032 .133 r
F
.56602 .46459 m .56458 .463 L .56733 .46225 L F
.51337 .46517 m .5146 .46269 L .51609 .4642 L 0 .033 .134 r
F
.51337 .46517 m .51188 .46367 L .5146 .46269 L F
.84308 .46095 m .84478 .4585 L .84596 .46006 L 0 .024 .123 r
F
.84308 .46095 m .8419 .45938 L .84478 .4585 L F
.61174 .46441 m .61312 .46216 L .61451 .46364 L 0 .032 .133 r
F
.61174 .46441 m .61035 .46292 L .61312 .46216 L F
.68515 .46269 m .68662 .46012 L .68795 .46177 L 0 .028 .127 r
F
.68515 .46269 m .68382 .46106 L .68662 .46012 L F
.41773 .46346 m .41882 .46112 L .42039 .46272 L 0 .03 .13 r
F
.41773 .46346 m .41615 .46185 L .41882 .46112 L F
.31516 .46215 m .31611 .4596 L .31778 .46128 L 0 .027 .126 r
F
.31516 .46215 m .31349 .46048 L .31611 .4596 L F
.48149 .46469 m .48268 .46231 L .48419 .46383 L 0 .033 .133 r
F
.48149 .46469 m .47997 .46318 L .48268 .46231 L F
.74472 .46182 m .74629 .45944 L .74755 .46098 L 0 .026 .125 r
F
.74472 .46182 m .74345 .46029 L .74629 .45944 L F
.85002 .4607 m .85172 .45823 L .85289 .45976 L 0 .024 .122 r
F
.85002 .4607 m .84884 .45917 L .85172 .45823 L F
.69208 .4625 m .69356 .45997 L .69489 .46162 L 0 .028 .127 r
F
.69208 .4625 m .69075 .46084 L .69356 .45997 L F
.35395 .46251 m .35496 .46 L .35659 .46164 L F
.35395 .46251 m .35232 .4609 L .35496 .46 L F
.48841 .46444 m .4896 .46207 L .49111 .46357 L 0 .032 .133 r
F
.48841 .46444 m .4869 .46293 L .4896 .46207 L F
.53413 .46425 m .5354 .46212 L .53686 .46355 L F
.53413 .46425 m .53267 .46283 L .5354 .46212 L F
.79738 .46139 m .79901 .45893 L .80024 .46057 L 0 .025 .124 r
F
.79738 .46139 m .79615 .45974 L .79901 .45893 L F
.62559 .4639 m .62698 .46151 L .62836 .46295 L 0 .031 .131 r
F
.62559 .4639 m .62421 .46247 L .62698 .46151 L F
.37891 .46352 m .37995 .4612 L .38156 .4627 L 0 .03 .131 r
F
.37891 .46352 m .3773 .462 L .37995 .4612 L F
.61867 .46429 m .62006 .462 L .62144 .46342 L 0 .032 .133 r
F
.61867 .46429 m .61728 .46287 L .62006 .462 L F
.4496 .4643 m .45074 .46199 L .45228 .46359 L F
.4496 .4643 m .44805 .46274 L .45074 .46199 L F
.63251 .46354 m .63391 .46108 L .63529 .46264 L 0 .03 .13 r
F
.63251 .46354 m .63114 .46202 L .63391 .46108 L F
.32206 .46208 m .32302 .45955 L .32468 .46122 L 0 .027 .126 r
F
.32206 .46208 m .3204 .4604 L .32302 .45955 L F
.75166 .46169 m .75322 .45912 L .75449 .46075 L 0 .026 .125 r
F
.75166 .46169 m .75039 .46006 L .75322 .45912 L F
.69901 .46231 m .70051 .4599 L .70182 .46143 L 0 .028 .127 r
F
.69901 .46231 m .6977 .46076 L .70051 .4599 L F
.28325 .46194 m .28415 .45959 L .28584 .46121 L 0 .027 .126 r
F
.28325 .46194 m .28155 .46031 L .28415 .45959 L F
.38583 .4633 m .38688 .46091 L .38848 .46239 L 0 .03 .13 r
F
.38583 .4633 m .38422 .46181 L .38688 .46091 L F
.63944 .46332 m .64085 .4609 L .64222 .46245 L F
.63944 .46332 m .63807 .46174 L .64085 .4609 L F
.70593 .46198 m .70745 .45959 L .70875 .46105 L 0 .027 .126 r
F
.70593 .46198 m .70463 .46051 L .70745 .45959 L F
.71286 .46161 m .71438 .45934 L .71568 .46081 L 0 .026 .126 r
F
.71286 .46161 m .71156 .46016 L .71438 .45934 L F
.36086 .46239 m .36187 .45998 L .3635 .46162 L 0 .028 .128 r
F
.36086 .46239 m .35923 .46076 L .36187 .45998 L F
.80432 .46125 m .80597 .4588 L .80718 .46033 L 0 .025 .124 r
F
.80432 .46125 m .80311 .45973 L .80597 .4588 L F
.75859 .46146 m .76016 .45885 L .76143 .46051 L 0 .026 .125 r
F
.75859 .46146 m .75732 .4598 L .76016 .45885 L F
.57294 .46475 m .57426 .46238 L .5757 .46403 L 0 .033 .134 r
F
.57294 .46475 m .57151 .46313 L .57426 .46238 L F
.42463 .46361 m .42574 .46117 L .4273 .46279 L 0 .031 .131 r
F
.42463 .46361 m .42306 .46198 L .42574 .46117 L F
.81125 .46093 m .81291 .45853 L .81411 .46006 L 0 .025 .124 r
F
.81125 .46093 m .81004 .45941 L .81291 .45853 L F
.64637 .46311 m .64779 .46069 L .64915 .46221 L 0 .03 .13 r
F
.64637 .46311 m .645 .46157 L .64779 .46069 L F
.49533 .46448 m .49653 .46213 L .49803 .46373 L 0 .033 .134 r
F
.49533 .46448 m .49382 .46285 L .49653 .46213 L F
.54106 .46429 m .54233 .46207 L .54379 .46358 L F
.54106 .46429 m .5396 .46281 L .54233 .46207 L F
.39274 .46314 m .39379 .46093 L .39539 .4624 L 0 .03 .13 r
F
.39274 .46314 m .39114 .46166 L .39379 .46093 L F
.76552 .46122 m .76711 .4587 L .76837 .46035 L 0 .025 .124 r
F
.76552 .46122 m .76426 .45957 L .76711 .4587 L F
.45651 .46432 m .45767 .46181 L .45921 .4634 L 0 .032 .133 r
F
.45651 .46432 m .45497 .46274 L .45767 .46181 L F
.46344 .46398 m .4646 .46172 L .46613 .46322 L F
.46344 .46398 m .4619 .46248 L .4646 .46172 L F
.65329 .46283 m .65473 .4604 L .65608 .46191 L 0 .029 .129 r
F
.65329 .46283 m .65194 .46131 L .65473 .4604 L F
.32896 .46208 m .32993 .45959 L .33158 .46127 L 0 .027 .127 r
F
.32896 .46208 m .3273 .46041 L .32993 .45959 L F
.29014 .46193 m .29106 .4594 L .29276 .46099 L 0 .027 .126 r
F
.29014 .46193 m .28845 .46033 L .29106 .4594 L F
.81819 .46078 m .81986 .45837 L .82106 .45994 L 0 .025 .123 r
F
.81819 .46078 m .81699 .45921 L .81986 .45837 L F
.77246 .46105 m .77407 .45868 L .77531 .4602 L 0 .026 .124 r
F
.77246 .46105 m .77122 .45952 L .77407 .45868 L F
.43154 .46355 m .43266 .46098 L .43422 .46265 L 0 .031 .131 r
F
.43154 .46355 m .42998 .46189 L .43266 .46098 L F
.7198 .46164 m .72133 .4592 L .72263 .46083 L 0 .027 .126 r
F
.7198 .46164 m .7185 .46 L .72133 .4592 L F
.29706 .46165 m .29798 .45927 L .29967 .46083 L F
.29706 .46165 m .29537 .46007 L .29798 .45927 L F
.66022 .46262 m .66167 .46029 L .66302 .46182 L 0 .029 .129 r
F
.66022 .46262 m .65887 .4611 L .66167 .46029 L F
.57987 .46474 m .58121 .46255 L .58263 .46401 L 0 .034 .135 r
F
.57987 .46474 m .57845 .46329 L .58121 .46255 L F
.59372 .46399 m .59507 .46157 L .59648 .46301 L 0 .032 .133 r
F
.59372 .46399 m .59231 .46253 L .59507 .46157 L F
.39965 .46307 m .40072 .46068 L .40231 .46216 L 0 .03 .13 r
F
.39965 .46307 m .39805 .46161 L .40072 .46068 L F
.60064 .46366 m .602 .46123 L .60341 .46284 L 0 .031 .132 r
F
.60064 .46366 m .59924 .46204 L .602 .46123 L F
.36776 .46251 m .36878 .46012 L .3704 .46178 L 0 .029 .129 r
F
.36776 .46251 m .36614 .46087 L .36878 .46012 L F
.7794 .46081 m .78101 .45841 L .78224 .4599 L 0 .025 .124 r
F
.7794 .46081 m .77816 .45931 L .78101 .45841 L F
.40657 .46274 m .40765 .46039 L .40924 .46189 L 0 .029 .129 r
F
.40657 .46274 m .40498 .46125 L .40765 .46039 L F
.5868 .46447 m .58814 .46208 L .58955 .4635 L 0 .033 .134 r
F
.5868 .46447 m .58538 .46305 L .58814 .46208 L F
.33586 .46202 m .33685 .45941 L .3385 .46106 L 0 .027 .127 r
F
.33586 .46202 m .33421 .46036 L .33685 .45941 L F
.47035 .46394 m .47152 .46167 L .47305 .46318 L 0 .032 .133 r
F
.47035 .46394 m .46882 .46245 L .47152 .46167 L F
.82514 .46069 m .8268 .45808 L .82801 .45975 L 0 .025 .123 r
F
.82514 .46069 m .82393 .45902 L .8268 .45808 L F
.34278 .46169 m .34377 .45932 L .34541 .46091 L 0 .027 .127 r
F
.34278 .46169 m .34114 .4601 L .34377 .45932 L F
.50224 .46457 m .50346 .46229 L .50496 .46385 L 0 .034 .135 r
F
.50224 .46457 m .50075 .463 L .50346 .46229 L F
.54798 .46441 m .54927 .46187 L .55072 .46349 L 0 .033 .134 r
F
.54798 .46441 m .54653 .46278 L .54927 .46187 L F
.78633 .46058 m .78796 .45817 L .78919 .45974 L 0 .025 .123 r
F
.78633 .46058 m .7851 .45902 L .78796 .45817 L F
.66716 .4625 m .66862 .46024 L .66996 .46172 L 0 .029 .129 r
F
.66716 .4625 m .66582 .46102 L .66862 .46024 L F
.30396 .46154 m .30489 .45914 L .30658 .46066 L 0 .027 .126 r
F
.30396 .46154 m .30228 .46001 L .30489 .45914 L F
.43846 .46352 m .43958 .46112 L .44114 .46273 L 0 .031 .132 r
F
.43846 .46352 m .4369 .46188 L .43958 .46112 L F
.83208 .46048 m .83375 .4579 L .83495 .45957 L 0 .025 .123 r
F
.83208 .46048 m .83088 .45882 L .83375 .4579 L F
.27206 .46107 m .27295 .45864 L .27466 .4602 L 0 .026 .125 r
F
.27206 .46107 m .27035 .45952 L .27295 .45864 L F
.55491 .46415 m .5562 .46167 L .55765 .46324 L 0 .033 .133 r
F
.55491 .46415 m .55346 .46256 L .5562 .46167 L F
.72675 .46166 m .72829 .45921 L .72958 .46084 L 0 .027 .127 r
F
.72675 .46166 m .72546 .46003 L .72829 .45921 L F
.41348 .46269 m .41457 .46024 L .41615 .46185 L 0 .03 .13 r
F
.41348 .46269 m .4119 .46106 L .41457 .46024 L F
.60758 .46368 m .60895 .46132 L .61035 .46292 L 0 .032 .133 r
F
.60758 .46368 m .60618 .46208 L .60895 .46132 L F
.31087 .46139 m .31182 .45883 L .31349 .46048 L 0 .027 .126 r
F
.31087 .46139 m .3092 .45975 L .31182 .45883 L F
.56183 .4639 m .56314 .46145 L .56458 .463 L 0 .032 .133 r
F
.56183 .4639 m .56039 .46233 L .56314 .46145 L F
.83902 .46026 m .84071 .45778 L .8419 .45938 L 0 .024 .123 r
F
.83902 .46026 m .83783 .45865 L .84071 .45778 L F
.47727 .46393 m .47845 .46164 L .47997 .46318 L 0 .033 .134 r
F
.47727 .46393 m .47575 .46241 L .47845 .46164 L F
.68102 .46202 m .68249 .45954 L .68382 .46106 L 0 .028 .128 r
F
.68102 .46202 m .67969 .46051 L .68249 .45954 L F
.67409 .46241 m .67556 .46 L .67689 .46148 L 0 .029 .129 r
F
.67409 .46241 m .67276 .46094 L .67556 .46 L F
.73369 .46148 m .73523 .45896 L .73651 .46055 L 0 .027 .126 r
F
.73369 .46148 m .7324 .4599 L .73523 .45896 L F
.51609 .4642 m .51733 .46172 L .51881 .46325 L 0 .033 .134 r
F
.51609 .4642 m .5146 .46269 L .51733 .46172 L F
.79328 .46056 m .79491 .45809 L .79615 .45974 L 0 .025 .124 r
F
.79328 .46056 m .79205 .45891 L .79491 .45809 L F
.52301 .46383 m .52426 .46138 L .52574 .46289 L 0 .032 .133 r
F
.52301 .46383 m .52154 .46231 L .52426 .46138 L F
.34968 .46172 m .35068 .45929 L .35232 .4609 L 0 .028 .127 r
F
.34968 .46172 m .34804 .46014 L .35068 .45929 L F
.74062 .46115 m .74218 .45877 L .74345 .46029 L 0 .027 .126 r
F
.74062 .46115 m .73934 .45964 L .74218 .45877 L F
.37465 .4627 m .37569 .46036 L .3773 .462 L 0 .03 .13 r
F
.37465 .4627 m .37304 .46107 L .37569 .46036 L F
.50917 .46464 m .51039 .46216 L .51188 .46367 L 0 .034 .135 r
F
.50917 .46464 m .50767 .46312 L .51039 .46216 L F
.44537 .46349 m .44651 .46118 L .44805 .46274 L 0 .032 .132 r
F
.44537 .46349 m .44382 .46195 L .44651 .46118 L F
.68795 .46177 m .68942 .45918 L .69075 .46084 L 0 .028 .127 r
F
.68795 .46177 m .68662 .46012 L .68942 .45918 L F
.84596 .46006 m .84767 .45763 L .84884 .45917 L 0 .024 .123 r
F
.84596 .46006 m .84478 .4585 L .84767 .45763 L F
.27896 .46104 m .27985 .45868 L .28155 .46031 L 0 .026 .126 r
F
.27896 .46104 m .27726 .45939 L .27985 .45868 L F
.52994 .46355 m .5312 .46137 L .53267 .46283 L 0 .032 .133 r
F
.52994 .46355 m .52847 .4621 L .5312 .46137 L F
.31778 .46128 m .31874 .45873 L .3204 .4604 L 0 .027 .126 r
F
.31778 .46128 m .31611 .4596 L .31874 .45873 L F
.85289 .45976 m .85461 .45729 L .85578 .45882 L 0 .024 .122 r
F
.85289 .45976 m .85172 .45823 L .85461 .45729 L F
.48419 .46383 m .48538 .46142 L .4869 .46293 L 0 .033 .133 r
F
.48419 .46383 m .48268 .46231 L .48538 .46142 L F
.61451 .46364 m .61589 .4614 L .61728 .46287 L 0 .032 .133 r
F
.61451 .46364 m .61312 .46216 L .61589 .4614 L F
.56876 .46386 m .57008 .46151 L .57151 .46313 L 0 .033 .134 r
F
.56876 .46386 m .56733 .46225 L .57008 .46151 L F
.74755 .46098 m .74912 .45853 L .75039 .46006 L 0 .026 .125 r
F
.74755 .46098 m .74629 .45944 L .74912 .45853 L F
.42039 .46272 m .42149 .46039 L .42306 .46198 L 0 .03 .131 r
F
.42039 .46272 m .41882 .46112 L .42149 .46039 L F
.62836 .46295 m .62976 .46056 L .63114 .46202 L 0 .031 .131 r
F
.62836 .46295 m .62698 .46151 L .62976 .46056 L F
.69489 .46162 m .69638 .45913 L .6977 .46076 L 0 .028 .127 r
F
.69489 .46162 m .69356 .45997 L .69638 .45913 L F
.35659 .46164 m .35761 .4591 L .35923 .46076 L F
.35659 .46164 m .35496 .46 L .35761 .4591 L F
.49111 .46357 m .49231 .46138 L .49382 .46285 L 0 .033 .133 r
F
.49111 .46357 m .4896 .46207 L .49231 .46138 L F
.63529 .46264 m .63669 .46017 L .63807 .46174 L 0 .03 .13 r
F
.63529 .46264 m .63391 .46108 L .63669 .46017 L F
.62144 .46342 m .62283 .46104 L .62421 .46247 L 0 .032 .133 r
F
.62144 .46342 m .62006 .462 L .62283 .46104 L F
.75449 .46075 m .75606 .45818 L .75732 .4598 L 0 .026 .125 r
F
.75449 .46075 m .75322 .45912 L .75606 .45818 L F
.80024 .46057 m .80188 .4581 L .80311 .45973 L 0 .026 .124 r
F
.80024 .46057 m .79901 .45893 L .80188 .4581 L F
.38156 .4627 m .38261 .46031 L .38422 .46181 L 0 .03 .131 r
F
.38156 .4627 m .37995 .4612 L .38261 .46031 L F
.32468 .46122 m .32565 .45874 L .3273 .46041 L 0 .027 .126 r
F
.32468 .46122 m .32302 .45955 L .32565 .45874 L F
.70182 .46143 m .70332 .45899 L .70463 .46051 L 0 .028 .127 r
F
.70182 .46143 m .70051 .4599 L .70332 .45899 L F
.38848 .46239 m .38953 .46017 L .39114 .46166 L 0 .03 .13 r
F
.38848 .46239 m .38688 .46091 L .38953 .46017 L F
.53686 .46355 m .53813 .46135 L .5396 .46281 L 0 .033 .134 r
F
.53686 .46355 m .5354 .46212 L .53813 .46135 L F
.70875 .46105 m .71026 .4587 L .71156 .46016 L 0 .027 .126 r
F
.70875 .46105 m .70745 .45959 L .71026 .4587 L F
.45228 .46359 m .45343 .46113 L .45497 .46274 L 0 .032 .133 r
F
.45228 .46359 m .45074 .46199 L .45343 .46113 L F
.76143 .46051 m .763 .4579 L .76426 .45957 L 0 .025 .124 r
F
.76143 .46051 m .76016 .45885 L .763 .4579 L F
.80718 .46033 m .80883 .45787 L .81004 .45941 L F
.80718 .46033 m .80597 .4588 L .80883 .45787 L F
.64222 .46245 m .64364 .46005 L .645 .46157 L 0 .03 .13 r
F
.64222 .46245 m .64085 .4609 L .64364 .46005 L F
.71568 .46081 m .71721 .45852 L .7185 .46 L 0 .027 .126 r
F
.71568 .46081 m .71438 .45934 L .71721 .45852 L F
.28584 .46121 m .28676 .45873 L .28845 .46033 L 0 .027 .127 r
F
.28584 .46121 m .28415 .45959 L .28676 .45873 L F
.81411 .46006 m .81578 .45768 L .81699 .45921 L 0 .025 .124 r
F
.81411 .46006 m .81291 .45853 L .81578 .45768 L F
.3635 .46162 m .36452 .45921 L .36614 .46087 L 0 .028 .128 r
F
.3635 .46162 m .36187 .45998 L .36452 .45921 L F
.64915 .46221 m .65058 .45981 L .65194 .46131 L 0 .03 .13 r
F
.64915 .46221 m .64779 .46069 L .65058 .45981 L F
.4273 .46279 m .42842 .46027 L .42998 .46189 L 0 .031 .131 r
F
.4273 .46279 m .42574 .46117 L .42842 .46027 L F
.45921 .4634 m .46036 .46089 L .4619 .46248 L 0 .032 .133 r
F
.45921 .4634 m .45767 .46181 L .46036 .46089 L F
.76837 .46035 m .76996 .45788 L .77122 .45952 L 0 .026 .124 r
F
.76837 .46035 m .76711 .4587 L .76996 .45788 L F
.65608 .46191 m .65752 .45958 L .65887 .4611 L 0 .029 .129 r
F
.65608 .46191 m .65473 .4604 L .65752 .45958 L F
.5757 .46403 m .57702 .46161 L .57845 .46329 L 0 .034 .135 r
F
.5757 .46403 m .57426 .46238 L .57702 .46161 L F
.29276 .46099 m .29368 .4585 L .29537 .46007 L 0 .027 .126 r
F
.29276 .46099 m .29106 .4594 L .29368 .4585 L F
.49803 .46373 m .49925 .46143 L .50075 .463 L 0 .033 .134 r
F
.49803 .46373 m .49653 .46213 L .49925 .46143 L F
.39539 .4624 m .39645 .46013 L .39805 .46161 L 0 .03 .131 r
F
.39539 .4624 m .39379 .46093 L .39645 .46013 L F
.33158 .46127 m .33256 .4587 L .33421 .46036 L 0 .027 .127 r
F
.33158 .46127 m .32993 .45959 L .33256 .4587 L F
.54379 .46358 m .54507 .46126 L .54653 .46278 L 0 .033 .134 r
F
.54379 .46358 m .54233 .46207 L .54507 .46126 L F
.82106 .45994 m .82273 .45745 L .82393 .45902 L 0 .025 .123 r
F
.82106 .45994 m .81986 .45837 L .82273 .45745 L F
.59648 .46301 m .59783 .4606 L .59924 .46204 L 0 .032 .132 r
F
.59648 .46301 m .59507 .46157 L .59783 .4606 L F
.46613 .46322 m .46729 .46096 L .46882 .46245 L 0 .032 .133 r
F
.46613 .46322 m .4646 .46172 L .46729 .46096 L F
.43422 .46265 m .43534 .46024 L .4369 .46188 L 0 .031 .131 r
F
.43422 .46265 m .43266 .46098 L .43534 .46024 L F
.77531 .4602 m .77692 .4578 L .77816 .45931 L 0 .026 .124 r
F
.77531 .4602 m .77407 .45868 L .77692 .4578 L F
.58955 .4635 m .5909 .46112 L .59231 .46253 L 0 .033 .134 r
F
.58955 .4635 m .58814 .46208 L .5909 .46112 L F
.40231 .46216 m .40339 .45976 L .40498 .46125 L 0 .03 .13 r
F
.40231 .46216 m .40072 .46068 L .40339 .45976 L F
.29967 .46083 m .30059 .45847 L .30228 .46001 L 0 .027 .126 r
F
.29967 .46083 m .29798 .45927 L .30059 .45847 L F
.72263 .46083 m .72416 .4584 L .72546 .46003 L F
.72263 .46083 m .72133 .4592 L .72416 .4584 L F
.66302 .46182 m .66447 .45948 L .66582 .46102 L 0 .029 .129 r
F
.66302 .46182 m .66167 .46029 L .66447 .45948 L F
.3385 .46106 m .33949 .45847 L .34114 .4601 L 0 .027 .127 r
F
.3385 .46106 m .33685 .45941 L .33949 .45847 L F
.78224 .4599 m .78387 .45753 L .7851 .45902 L 0 .025 .124 r
F
.78224 .4599 m .78101 .45841 L .78387 .45753 L F
.82801 .45975 m .82968 .45715 L .83088 .45882 L 0 .025 .123 r
F
.82801 .45975 m .8268 .45808 L .82968 .45715 L F
.60341 .46284 m .60477 .46047 L .60618 .46208 L 0 .032 .132 r
F
.60341 .46284 m .602 .46123 L .60477 .46047 L F
.40924 .46189 m .41032 .45956 L .4119 .46106 L 0 .03 .13 r
F
.40924 .46189 m .40765 .46039 L .41032 .45956 L F
.58263 .46401 m .58396 .4616 L .58538 .46305 L 0 .034 .135 r
F
.58263 .46401 m .58121 .46255 L .58396 .4616 L F
.26775 .4604 m .26863 .45797 L .27035 .45952 L 0 .026 .125 r
F
.26775 .4604 m .26603 .45887 L .26863 .45797 L F
.55072 .46349 m .55201 .46095 L .55346 .46256 L 0 .033 .134 r
F
.55072 .46349 m .54927 .46187 L .55201 .46095 L F
.3704 .46178 m .37143 .45939 L .37304 .46107 L 0 .029 .129 r
F
.3704 .46178 m .36878 .46012 L .37143 .45939 L F
.30658 .46066 m .30752 .45822 L .3092 .45975 L 0 .027 .126 r
F
.30658 .46066 m .30489 .45914 L .30752 .45822 L F
.47305 .46318 m .47422 .46086 L .47575 .46241 L 0 .033 .133 r
F
.47305 .46318 m .47152 .46167 L .47422 .46086 L F
.78919 .45974 m .79082 .45733 L .79205 .45891 L 0 .025 .124 r
F
.78919 .45974 m .78796 .45817 L .79082 .45733 L F
.34541 .46091 m .3464 .45854 L .34804 .46014 L 0 .028 .127 r
F
.34541 .46091 m .34377 .45932 L .3464 .45854 L F
.83495 .45957 m .83663 .45699 L .83783 .45865 L 0 .024 .123 r
F
.83495 .45957 m .83375 .4579 L .83663 .45699 L F
.55765 .46324 m .55895 .46079 L .56039 .46233 L 0 .033 .133 r
F
.55765 .46324 m .5562 .46167 L .55895 .46079 L F
.66996 .46172 m .67142 .45945 L .67276 .46094 L 0 .03 .13 r
F
.66996 .46172 m .66862 .46024 L .67142 .45945 L F
.50496 .46385 m .50618 .46158 L .50767 .46312 L 0 .034 .135 r
F
.50496 .46385 m .50346 .46229 L .50618 .46158 L F
.27466 .4602 m .27555 .45782 L .27726 .45939 L 0 .026 .125 r
F
.27466 .4602 m .27295 .45864 L .27555 .45782 L F
.44114 .46273 m .44227 .46037 L .44382 .46195 L 0 .032 .132 r
F
.44114 .46273 m .43958 .46112 L .44227 .46037 L F
.72958 .46084 m .73111 .45827 L .7324 .4599 L 0 .027 .127 r
F
.72958 .46084 m .72829 .45921 L .73111 .45827 L F
.31349 .46048 m .31445 .45796 L .31611 .4596 L 0 .027 .126 r
F
.31349 .46048 m .31182 .45883 L .31445 .45796 L F
.68382 .46106 m .68529 .45859 L .68662 .46012 L 0 .028 .127 r
F
.68382 .46106 m .68249 .45954 L .68529 .45859 L F
.41615 .46185 m .41724 .45952 L .41882 .46112 L 0 .03 .13 r
F
.41615 .46185 m .41457 .46024 L .41724 .45952 L F
.56458 .463 m .56589 .46068 L .56733 .46225 L 0 .033 .133 r
F
.56458 .463 m .56314 .46145 L .56589 .46068 L F
.67689 .46148 m .67836 .45903 L .67969 .46051 L 0 .029 .129 r
F
.67689 .46148 m .67556 .46 L .67836 .45903 L F
.8419 .45938 m .8436 .45691 L .84478 .4585 L 0 .024 .123 r
F
.8419 .45938 m .84071 .45778 L .8436 .45691 L F
.73651 .46055 m .73806 .45805 L .73934 .45964 L 0 .027 .126 r
F
.73651 .46055 m .73523 .45896 L .73806 .45805 L F
.51881 .46325 m .52005 .46079 L .52154 .46231 L 0 .033 .134 r
F
.51881 .46325 m .51733 .46172 L .52005 .46079 L F
.52574 .46289 m .52699 .46056 L .52847 .4621 L 0 .032 .133 r
F
.52574 .46289 m .52426 .46138 L .52699 .46056 L F
.51188 .46367 m .51312 .46119 L .5146 .46269 L 0 .034 .135 r
F
.51188 .46367 m .51039 .46216 L .51312 .46119 L F
.61035 .46292 m .61172 .46056 L .61312 .46216 L 0 .032 .133 r
F
.61035 .46292 m .60895 .46132 L .61172 .46056 L F
.69075 .46084 m .69224 .45831 L .69356 .45997 L 0 .028 .127 r
F
.69075 .46084 m .68942 .45918 L .69224 .45831 L F
.74345 .46029 m .74501 .4579 L .74629 .45944 L 0 .027 .126 r
F
.74345 .46029 m .74218 .45877 L .74501 .4579 L F
.47997 .46318 m .48116 .46077 L .48268 .46231 L 0 .033 .134 r
F
.47997 .46318 m .47845 .46164 L .48116 .46077 L F
.84884 .45917 m .85055 .45669 L .85172 .45823 L 0 .024 .122 r
F
.84884 .45917 m .84767 .45763 L .85055 .45669 L F
.79615 .45974 m .79778 .45728 L .79901 .45893 L 0 .025 .124 r
F
.79615 .45974 m .79491 .45809 L .79778 .45728 L F
.35232 .4609 m .35333 .45836 L .35496 .46 L 0 .028 .127 r
F
.35232 .4609 m .35068 .45929 L .35333 .45836 L F
.85578 .45882 m .8575 .45641 L .85866 .45794 L 0 .024 .122 r
F
.85578 .45882 m .85461 .45729 L .8575 .45641 L F
.3204 .4604 m .32137 .45788 L .32302 .45955 L 0 .027 .126 r
F
.3204 .4604 m .31874 .45873 L .32137 .45788 L F
.4869 .46293 m .48809 .46056 L .4896 .46207 L 0 .033 .133 r
F
.4869 .46293 m .48538 .46142 L .48809 .46056 L F
.44805 .46274 m .44919 .46041 L .45074 .46199 L 0 .032 .133 r
F
.44805 .46274 m .44651 .46118 L .44919 .46041 L F
.75039 .46006 m .75196 .4576 L .75322 .45912 L 0 .026 .125 r
F
.75039 .46006 m .74912 .45853 L .75196 .4576 L F
.3773 .462 m .37834 .45955 L .37995 .4612 L 0 .03 .131 r
F
.3773 .462 m .37569 .46036 L .37834 .45955 L F
.63114 .46202 m .63254 .4596 L .63391 .46108 L 0 .031 .131 r
F
.63114 .46202 m .62976 .46056 L .63254 .4596 L F
.28155 .46031 m .28245 .45797 L .28415 .45959 L 0 .027 .126 r
F
.28155 .46031 m .27985 .45868 L .28245 .45797 L F
.53267 .46283 m .53393 .46064 L .5354 .46212 L 0 .033 .134 r
F
.53267 .46283 m .5312 .46137 L .53393 .46064 L F
.62421 .46247 m .6256 .46007 L .62698 .46151 L 0 .032 .132 r
F
.62421 .46247 m .62283 .46104 L .6256 .46007 L F
.75732 .4598 m .7589 .45723 L .76016 .45885 L 0 .026 .124 r
F
.75732 .4598 m .75606 .45818 L .7589 .45723 L F
.61728 .46287 m .61867 .46052 L .62006 .462 L 0 .033 .133 r
F
.61728 .46287 m .61589 .4614 L .61867 .46052 L F
.6977 .46076 m .69919 .45829 L .70051 .4599 L 0 .028 .127 r
F
.6977 .46076 m .69638 .45913 L .69919 .45829 L F
.35923 .46076 m .36025 .4583 L .36187 .45998 L F
.35923 .46076 m .35761 .4591 L .36025 .4583 L F
.63807 .46174 m .63948 .45935 L .64085 .4609 L 0 .03 .13 r
F
.63807 .46174 m .63669 .46017 L .63948 .45935 L F
.57151 .46313 m .57283 .46073 L .57426 .46238 L 0 .033 .134 r
F
.57151 .46313 m .57008 .46151 L .57283 .46073 L F
.42306 .46198 m .42417 .45958 L .42574 .46117 L 0 .031 .131 r
F
.42306 .46198 m .42149 .46039 L .42417 .45958 L F
.38422 .46181 m .38527 .45943 L .38688 .46091 L 0 .03 .131 r
F
.38422 .46181 m .38261 .46031 L .38527 .45943 L F
.80311 .45973 m .80474 .45716 L .80597 .4588 L 0 .026 .124 r
F
.80311 .45973 m .80188 .4581 L .80474 .45716 L F
.70463 .46051 m .70614 .45809 L .70745 .45959 L 0 .027 .127 r
F
.70463 .46051 m .70332 .45899 L .70614 .45809 L F
.76426 .45957 m .76585 .45703 L .76711 .4587 L 0 .025 .124 r
F
.76426 .45957 m .763 .4579 L .76585 .45703 L F
.71156 .46016 m .71309 .45787 L .71438 .45934 L 0 .027 .126 r
F
.71156 .46016 m .71026 .4587 L .71309 .45787 L F
.49382 .46285 m .49503 .46069 L .49653 .46213 L 0 .033 .134 r
F
.49382 .46285 m .49231 .46138 L .49503 .46069 L F
.81004 .45941 m .8117 .45698 L .81291 .45853 L 0 .025 .124 r
F
.81004 .45941 m .80883 .45787 L .8117 .45698 L F
.3273 .46041 m .32828 .45794 L .32993 .45959 L 0 .027 .127 r
F
.3273 .46041 m .32565 .45874 L .32828 .45794 L F
.645 .46157 m .64643 .4592 L .64779 .46069 L 0 .03 .13 r
F
.645 .46157 m .64364 .46005 L .64643 .4592 L F
.45497 .46274 m .45613 .46019 L .45767 .46181 L 0 .032 .133 r
F
.45497 .46274 m .45343 .46113 L .45613 .46019 L F
.39114 .46166 m .39219 .45944 L .39379 .46093 L 0 .031 .131 r
F
.39114 .46166 m .38953 .46017 L .39219 .45944 L F
.5396 .46281 m .54087 .46058 L .54233 .46207 L 0 .033 .134 r
F
.5396 .46281 m .53813 .46135 L .54087 .46058 L F
.28845 .46033 m .28937 .45782 L .29106 .4594 L 0 .027 .126 r
F
.28845 .46033 m .28676 .45873 L .28937 .45782 L F
.65194 .46131 m .65337 .45893 L .65473 .4604 L 0 .03 .13 r
F
.65194 .46131 m .65058 .45981 L .65337 .45893 L F
.42998 .46189 m .4311 .45937 L .43266 .46098 L 0 .031 .131 r
F
.42998 .46189 m .42842 .46027 L .4311 .45937 L F
.81699 .45921 m .81866 .45683 L .81986 .45837 L 0 .025 .124 r
F
.81699 .45921 m .81578 .45768 L .81866 .45683 L F
.4619 .46248 m .46306 .46012 L .4646 .46172 L 0 .032 .133 r
F
.4619 .46248 m .46036 .46089 L .46306 .46012 L F
.7185 .46 m .72004 .45771 L .72133 .4592 L 0 .027 .126 r
F
.7185 .46 m .71721 .45852 L .72004 .45771 L F
.29537 .46007 m .29629 .45772 L .29798 .45927 L F
.29537 .46007 m .29368 .4585 L .29629 .45772 L F
.77122 .45952 m .77282 .45706 L .77407 .45868 L 0 .026 .125 r
F
.77122 .45952 m .76996 .45788 L .77282 .45706 L F
.36614 .46087 m .36716 .45845 L .36878 .46012 L 0 .029 .128 r
F
.36614 .46087 m .36452 .45921 L .36716 .45845 L F
.59924 .46204 m .6006 .45979 L .602 .46123 L 0 .032 .132 r
F
.59924 .46204 m .59783 .4606 L .6006 .45979 L F
.65887 .4611 m .66032 .45875 L .66167 .46029 L 0 .029 .129 r
F
.65887 .4611 m .65752 .45958 L .66032 .45875 L F
.33421 .46036 m .3352 .45776 L .33685 .45941 L 0 .027 .127 r
F
.33421 .46036 m .33256 .4587 L .3352 .45776 L F
.82393 .45902 m .8256 .45651 L .8268 .45808 L 0 .025 .123 r
F
.82393 .45902 m .82273 .45745 L .8256 .45651 L F
.57845 .46329 m .57978 .46084 L .58121 .46255 L 0 .034 .135 r
F
.57845 .46329 m .57702 .46161 L .57978 .46084 L F
.59231 .46253 m .59366 .46018 L .59507 .46157 L 0 .033 .133 r
F
.59231 .46253 m .5909 .46112 L .59366 .46018 L F
.39805 .46161 m .39912 .4592 L .40072 .46068 L 0 .031 .131 r
F
.39805 .46161 m .39645 .46013 L .39912 .4592 L F
.77816 .45931 m .77978 .45691 L .78101 .45841 L 0 .026 .124 r
F
.77816 .45931 m .77692 .4578 L .77978 .45691 L F
.54653 .46278 m .54781 .46037 L .54927 .46187 L 0 .033 .134 r
F
.54653 .46278 m .54507 .46126 L .54781 .46037 L F
.40498 .46125 m .40606 .4589 L .40765 .46039 L 0 .03 .13 r
F
.40498 .46125 m .40339 .45976 L .40606 .4589 L F
.34114 .4601 m .34212 .45771 L .34377 .45932 L 0 .027 .127 r
F
.34114 .4601 m .33949 .45847 L .34212 .45771 L F
.50075 .463 m .50196 .46073 L .50346 .46229 L 0 .034 .135 r
F
.50075 .463 m .49925 .46143 L .50196 .46073 L F
.46882 .46245 m .46999 .46016 L .47152 .46167 L 0 .033 .133 r
F
.46882 .46245 m .46729 .46096 L .46999 .46016 L F
.4369 .46188 m .43803 .45952 L .43958 .46112 L 0 .031 .132 r
F
.4369 .46188 m .43534 .46024 L .43803 .45952 L F
.83088 .45882 m .83255 .45624 L .83375 .4579 L 0 .024 .123 r
F
.83088 .45882 m .82968 .45715 L .83255 .45624 L F
.58538 .46305 m .58672 .46064 L .58814 .46208 L 0 .034 .135 r
F
.58538 .46305 m .58396 .4616 L .58672 .46064 L F
.7851 .45902 m .78673 .45667 L .78796 .45817 L 0 .025 .124 r
F
.7851 .45902 m .78387 .45753 L .78673 .45667 L F
.30228 .46001 m .30321 .45761 L .30489 .45914 L 0 .027 .127 r
F
.30228 .46001 m .30059 .45847 L .30321 .45761 L F
.72546 .46003 m .727 .45759 L .72829 .45921 L 0 .027 .126 r
F
.72546 .46003 m .72416 .4584 L .727 .45759 L F
.55346 .46256 m .55475 .46009 L .5562 .46167 L 0 .033 .134 r
F
.55346 .46256 m .55201 .46095 L .55475 .46009 L F
.66582 .46102 m .66727 .45869 L .66862 .46024 L 0 .03 .13 r
F
.66582 .46102 m .66447 .45948 L .66727 .45869 L F
.27035 .45952 m .27124 .45708 L .27295 .45864 L 0 .026 .125 r
F
.27035 .45952 m .26863 .45797 L .27124 .45708 L F
.4119 .46106 m .41299 .45873 L .41457 .46024 L 0 .03 .13 r
F
.4119 .46106 m .41032 .45956 L .41299 .45873 L F
.3092 .45975 m .31014 .45731 L .31182 .45883 L 0 .027 .126 r
F
.3092 .45975 m .30752 .45822 L .31014 .45731 L F
.60618 .46208 m .60754 .45972 L .60895 .46132 L 0 .032 .133 r
F
.60618 .46208 m .60477 .46047 L .60754 .45972 L F
.83783 .45865 m .83952 .45612 L .84071 .45778 L 0 .024 .123 r
F
.83783 .45865 m .83663 .45699 L .83952 .45612 L F
.56039 .46233 m .56169 .45993 L .56314 .46145 L 0 .033 .133 r
F
.56039 .46233 m .55895 .46079 L .56169 .45993 L F
.79205 .45891 m .79369 .45651 L .79491 .45809 L 0 .025 .124 r
F
.79205 .45891 m .79082 .45733 L .79369 .45651 L F
.7324 .4599 m .73394 .45733 L .73523 .45896 L 0 .027 .126 r
F
.7324 .4599 m .73111 .45827 L .73394 .45733 L F
.47575 .46241 m .47693 .46005 L .47845 .46164 L 0 .033 .134 r
F
.47575 .46241 m .47422 .46086 L .47693 .46005 L F
.37304 .46107 m .37407 .45865 L .37569 .46036 L 0 .03 .13 r
F
.37304 .46107 m .37143 .45939 L .37407 .45865 L F
.68662 .46012 m .6881 .45764 L .68942 .45918 L 0 .028 .127 r
F
.68662 .46012 m .68529 .45859 L .6881 .45764 L F
.67969 .46051 m .68116 .45805 L .68249 .45954 L 0 .029 .128 r
F
.67969 .46051 m .67836 .45903 L .68116 .45805 L F
.34804 .46014 m .34904 .45769 L .35068 .45929 L 0 .028 .127 r
F
.34804 .46014 m .3464 .45854 L .34904 .45769 L F
.27726 .45939 m .27815 .45709 L .27985 .45868 L 0 .026 .126 r
F
.27726 .45939 m .27555 .45782 L .27815 .45709 L F
.67276 .46094 m .67422 .45851 L .67556 .46 L 0 .03 .13 r
F
.67276 .46094 m .67142 .45945 L .67422 .45851 L F
.31611 .4596 m .31707 .45708 L .31874 .45873 L 0 .027 .126 r
F
.31611 .4596 m .31445 .45796 L .31707 .45708 L F
.5146 .46269 m .51584 .46023 L .51733 .46172 L 0 .033 .134 r
F
.5146 .46269 m .51312 .46119 L .51584 .46023 L F
.52154 .46231 m .52278 .45986 L .52426 .46138 L 0 .033 .133 r
F
.52154 .46231 m .52005 .46079 L .52278 .45986 L F
.44382 .46195 m .44495 .45961 L .44651 .46118 L 0 .032 .133 r
F
.44382 .46195 m .44227 .46037 L .44495 .45961 L F
.73934 .45964 m .7409 .45717 L .74218 .45877 L 0 .027 .126 r
F
.73934 .45964 m .73806 .45805 L .7409 .45717 L F
.84478 .4585 m .84649 .45605 L .84767 .45763 L 0 .024 .123 r
F
.84478 .4585 m .8436 .45691 L .84649 .45605 L F
.50767 .46312 m .5089 .46065 L .51039 .46216 L 0 .035 .136 r
F
.50767 .46312 m .50618 .46158 L .5089 .46065 L F
.56733 .46225 m .56864 .45992 L .57008 .46151 L 0 .033 .134 r
F
.56733 .46225 m .56589 .46068 L .56864 .45992 L F
.85172 .45823 m .85344 .45576 L .85461 .45729 L 0 .024 .122 r
F
.85172 .45823 m .85055 .45669 L .85344 .45576 L F
.41882 .46112 m .41992 .45879 L .42149 .46039 L 0 .03 .131 r
F
.41882 .46112 m .41724 .45952 L .41992 .45879 L F
.69356 .45997 m .69505 .4575 L .69638 .45913 L 0 .028 .127 r
F
.69356 .45997 m .69224 .45831 L .69505 .4575 L F
.52847 .4621 m .52972 .45981 L .5312 .46137 L 0 .033 .133 r
F
.52847 .4621 m .52699 .46056 L .52972 .45981 L F
.35496 .46 m .35598 .45743 L .35761 .4591 L 0 .028 .127 r
F
.35496 .46 m .35333 .45836 L .35598 .45743 L F
.48268 .46231 m .48387 .45987 L .48538 .46142 L 0 .033 .134 r
F
.48268 .46231 m .48116 .46077 L .48387 .45987 L F
.74629 .45944 m .74785 .45699 L .74912 .45853 L 0 .027 .126 r
F
.74629 .45944 m .74501 .4579 L .74785 .45699 L F
.61312 .46216 m .6145 .4598 L .61589 .4614 L 0 .033 .134 r
F
.61312 .46216 m .61172 .46056 L .6145 .4598 L F
.85866 .45794 m .8604 .45559 L .86156 .45712 L 0 .024 .122 r
F
.85866 .45794 m .8575 .45641 L .8604 .45559 L F
.79901 .45893 m .80065 .45646 L .80188 .4581 L 0 .026 .124 r
F
.79901 .45893 m .79778 .45728 L .80065 .45646 L F
.75322 .45912 m .7548 .45667 L .75606 .45818 L 0 .026 .125 r
F
.75322 .45912 m .75196 .4576 L .7548 .45667 L F
.63391 .46108 m .63532 .45869 L .63669 .46017 L 0 .03 .131 r
F
.63391 .46108 m .63254 .4596 L .63532 .45869 L F
.32302 .45955 m .32399 .45708 L .32565 .45874 L 0 .027 .126 r
F
.32302 .45955 m .32137 .45788 L .32399 .45708 L F
.4896 .46207 m .4908 .45991 L .49231 .46138 L 0 .033 .134 r
F
.4896 .46207 m .48809 .46056 L .4908 .45991 L F
.62698 .46151 m .62838 .4591 L .62976 .46056 L 0 .031 .132 r
F
.62698 .46151 m .6256 .46007 L .62838 .4591 L F
.76016 .45885 m .76174 .45627 L .763 .4579 L 0 .025 .124 r
F
.76016 .45885 m .7589 .45723 L .76174 .45627 L F
.37995 .4612 m .381 .45867 L .38261 .46031 L 0 .031 .131 r
F
.37995 .4612 m .37834 .45955 L .381 .45867 L F
.45074 .46199 m .45189 .45953 L .45343 .46113 L 0 .032 .133 r
F
.45074 .46199 m .44919 .46041 L .45189 .45953 L F
.62006 .462 m .62144 .45954 L .62283 .46104 L 0 .033 .133 r
F
.62006 .462 m .61867 .46052 L .62144 .45954 L F
.70051 .4599 m .70201 .45742 L .70332 .45899 L 0 .028 .127 r
F
.70051 .4599 m .69919 .45829 L .70201 .45742 L F
.64085 .4609 m .64227 .45853 L .64364 .46005 L 0 .03 .13 r
F
.64085 .4609 m .63948 .45935 L .64227 .45853 L F
.38688 .46091 m .38792 .45869 L .38953 .46017 L 0 .031 .131 r
F
.38688 .46091 m .38527 .45943 L .38792 .45869 L F
.80597 .4588 m .80761 .45623 L .80883 .45787 L 0 .025 .124 r
F
.80597 .4588 m .80474 .45716 L .80761 .45623 L F
.70745 .45959 m .70896 .4572 L .71026 .4587 L 0 .027 .127 r
F
.70745 .45959 m .70614 .45809 L .70896 .4572 L F
.28415 .45959 m .28506 .45712 L .28676 .45873 L F
.28415 .45959 m .28245 .45797 L .28506 .45712 L F
.36187 .45998 m .36289 .45753 L .36452 .45921 L 0 .028 .128 r
F
.36187 .45998 m .36025 .4583 L .36289 .45753 L F
.5354 .46212 m .53667 .45985 L .53813 .46135 L 0 .033 .134 r
F
.5354 .46212 m .53393 .46064 L .53667 .45985 L F
.42574 .46117 m .42685 .4587 L .42842 .46027 L 0 .031 .131 r
F
.42574 .46117 m .42417 .45958 L .42685 .4587 L F
.76711 .4587 m .76871 .45623 L .76996 .45788 L 0 .025 .124 r
F
.76711 .4587 m .76585 .45703 L .76871 .45623 L F
.81291 .45853 m .81457 .45612 L .81578 .45768 L F
.81291 .45853 m .8117 .45698 L .81457 .45612 L F
.57426 .46238 m .57559 .45993 L .57702 .46161 L 0 .034 .135 r
F
.57426 .46238 m .57283 .46073 L .57559 .45993 L F
.45767 .46181 m .45883 .45926 L .46036 .46089 L 0 .032 .133 r
F
.45767 .46181 m .45613 .46019 L .45883 .45926 L F
.71438 .45934 m .71591 .45704 L .71721 .45852 L 0 .027 .126 r
F
.71438 .45934 m .71309 .45787 L .71591 .45704 L F
.64779 .46069 m .64922 .45834 L .65058 .45981 L 0 .03 .13 r
F
.64779 .46069 m .64643 .4592 L .64922 .45834 L F
.29106 .4594 m .29198 .45693 L .29368 .4585 L 0 .027 .126 r
F
.29106 .4594 m .28937 .45782 L .29198 .45693 L F
.32993 .45959 m .33091 .45706 L .33256 .4587 L 0 .027 .127 r
F
.32993 .45959 m .32828 .45794 L .33091 .45706 L F
.49653 .46213 m .49774 .46 L .49925 .46143 L 0 .034 .135 r
F
.49653 .46213 m .49503 .46069 L .49774 .46 L F
.65473 .4604 m .65617 .45808 L .65752 .45958 L 0 .03 .13 r
F
.65473 .4604 m .65337 .45893 L .65617 .45808 L F
.43266 .46098 m .43378 .45865 L .43534 .46024 L 0 .031 .131 r
F
.43266 .46098 m .4311 .45937 L .43378 .45865 L F
.81986 .45837 m .82153 .4559 L .82273 .45745 L 0 .025 .124 r
F
.81986 .45837 m .81866 .45683 L .82153 .4559 L F
.54233 .46207 m .54361 .45977 L .54507 .46126 L 0 .033 .134 r
F
.54233 .46207 m .54087 .46058 L .54361 .45977 L F
.39379 .46093 m .39485 .45863 L .39645 .46013 L 0 .031 .131 r
F
.39379 .46093 m .39219 .45944 L .39485 .45863 L F
.72133 .4592 m .72287 .45692 L .72416 .4584 L 0 .027 .126 r
F
.72133 .4592 m .72004 .45771 L .72287 .45692 L F
.33685 .45941 m .33784 .45684 L .33949 .45847 L F
.33685 .45941 m .3352 .45776 L .33784 .45684 L F
.4646 .46172 m .46576 .45936 L .46729 .46096 L 0 .033 .133 r
F
.4646 .46172 m .46306 .46012 L .46576 .45936 L F
.8268 .45808 m .82848 .45558 L .82968 .45715 L 0 .024 .123 r
F
.8268 .45808 m .8256 .45651 L .82848 .45558 L F
.59507 .46157 m .59642 .45923 L .59783 .4606 L 0 .032 .133 r
F
.59507 .46157 m .59366 .46018 L .59642 .45923 L F
.77407 .45868 m .77567 .45619 L .77692 .4578 L 0 .026 .125 r
F
.77407 .45868 m .77282 .45706 L .77567 .45619 L F
.29798 .45927 m .2989 .45694 L .30059 .45847 L 0 .027 .127 r
F
.29798 .45927 m .29629 .45772 L .2989 .45694 L F
.602 .46123 m .60337 .45902 L .60477 .46047 L 0 .032 .132 r
F
.602 .46123 m .6006 .45979 L .60337 .45902 L F
.66167 .46029 m .66312 .45794 L .66447 .45948 L 0 .03 .13 r
F
.66167 .46029 m .66032 .45875 L .66312 .45794 L F
.40072 .46068 m .40179 .45826 L .40339 .45976 L 0 .03 .131 r
F
.40072 .46068 m .39912 .4592 L .40179 .45826 L F
.36878 .46012 m .36981 .4577 L .37143 .45939 L 0 .029 .129 r
F
.36878 .46012 m .36716 .45845 L .36981 .4577 L F
.54927 .46187 m .55055 .45947 L .55201 .46095 L 0 .033 .134 r
F
.54927 .46187 m .54781 .46037 L .55055 .45947 L F
.78101 .45841 m .78263 .45603 L .78387 .45753 L 0 .026 .124 r
F
.78101 .45841 m .77978 .45691 L .78263 .45603 L F
.58814 .46208 m .58948 .45969 L .5909 .46112 L 0 .034 .135 r
F
.58814 .46208 m .58672 .46064 L .58948 .45969 L F
.40765 .46039 m .40873 .45806 L .41032 .45956 L 0 .03 .13 r
F
.40765 .46039 m .40606 .4589 L .40873 .45806 L F
.83375 .4579 m .83543 .45532 L .83663 .45699 L 0 .024 .123 r
F
.83375 .4579 m .83255 .45624 L .83543 .45532 L F
.26603 .45887 m .26691 .45642 L .26863 .45797 L 0 .026 .126 r
F
.26603 .45887 m .26431 .45734 L .26691 .45642 L F
.58121 .46255 m .58253 .45992 L .58396 .4616 L 0 .034 .135 r
F
.58121 .46255 m .57978 .46084 L .58253 .45992 L F
.34377 .45932 m .34476 .45694 L .3464 .45854 L 0 .028 .127 r
F
.34377 .45932 m .34212 .45771 L .34476 .45694 L F
.78796 .45817 m .78959 .45582 L .79082 .45733 L 0 .025 .124 r
F
.78796 .45817 m .78673 .45667 L .78959 .45582 L F
.30489 .45914 m .30583 .4567 L .30752 .45822 L 0 .027 .126 r
F
.30489 .45914 m .30321 .45761 L .30583 .4567 L F
.5562 .46167 m .5575 .45925 L .55895 .46079 L 0 .033 .134 r
F
.5562 .46167 m .55475 .46009 L .5575 .45925 L F
.47152 .46167 m .4727 .45931 L .47422 .46086 L F
.47152 .46167 m .46999 .46016 L .4727 .45931 L F
.43958 .46112 m .44071 .45879 L .44227 .46037 L 0 .032 .132 r
F
.43958 .46112 m .43803 .45952 L .44071 .45879 L F
.72829 .45921 m .72982 .45665 L .73111 .45827 L 0 .027 .126 r
F
.72829 .45921 m .727 .45759 L .72982 .45665 L F
.27295 .45864 m .27384 .45624 L .27555 .45782 L 0 .026 .125 r
F
.27295 .45864 m .27124 .45708 L .27384 .45624 L F
.50346 .46229 m .50468 .46004 L .50618 .46158 L 0 .035 .136 r
F
.50346 .46229 m .50196 .46073 L .50468 .46004 L F
.31182 .45883 m .31277 .45643 L .31445 .45796 L 0 .027 .126 r
F
.31182 .45883 m .31014 .45731 L .31277 .45643 L F
.66862 .46024 m .67008 .4579 L .67142 .45945 L 0 .03 .13 r
F
.66862 .46024 m .66727 .45869 L .67008 .4579 L F
.41457 .46024 m .41566 .45798 L .41724 .45952 L F
.41457 .46024 m .41299 .45873 L .41566 .45798 L F
.84071 .45778 m .84241 .45526 L .8436 .45691 L 0 .024 .123 r
F
.84071 .45778 m .83952 .45612 L .84241 .45526 L F
.56314 .46145 m .56444 .45915 L .56589 .46068 L 0 .033 .133 r
F
.56314 .46145 m .56169 .45993 L .56444 .45915 L F
.73523 .45896 m .73678 .45641 L .73806 .45805 L 0 .027 .126 r
F
.73523 .45896 m .73394 .45733 L .73678 .45641 L F
.68249 .45954 m .68397 .45709 L .68529 .45859 L 0 .028 .128 r
F
.68249 .45954 m .68116 .45805 L .68397 .45709 L F
.68942 .45918 m .69091 .45677 L .69224 .45831 L 0 .028 .127 r
F
.68942 .45918 m .6881 .45764 L .69091 .45677 L F
.60895 .46132 m .61032 .45896 L .61172 .46056 L 0 .032 .133 r
F
.60895 .46132 m .60754 .45972 L .61032 .45896 L F
.51733 .46172 m .51857 .45932 L .52005 .46079 L 0 .033 .134 r
F
.51733 .46172 m .51584 .46023 L .51857 .45932 L F
.67556 .46 m .67702 .45753 L .67836 .45903 L 0 .029 .129 r
F
.67556 .46 m .67422 .45851 L .67702 .45753 L F
.79491 .45809 m .79656 .45571 L .79778 .45728 L 0 .025 .124 r
F
.79491 .45809 m .79369 .45651 L .79656 .45571 L F
.52426 .46138 m .52551 .45902 L .52699 .46056 L 0 .033 .133 r
F
.52426 .46138 m .52278 .45986 L .52551 .45902 L F
.51039 .46216 m .51163 .45969 L .51312 .46119 L 0 .034 .135 r
F
.51039 .46216 m .5089 .46065 L .51163 .45969 L F
.35068 .45929 m .35169 .45676 L .35333 .45836 L 0 .028 .127 r
F
.35068 .45929 m .34904 .45769 L .35169 .45676 L F
.31874 .45873 m .3197 .45623 L .32137 .45788 L 0 .027 .126 r
F
.31874 .45873 m .31707 .45708 L .3197 .45623 L F
.47845 .46164 m .47964 .45916 L .48116 .46077 L 0 .033 .134 r
F
.47845 .46164 m .47693 .46005 L .47964 .45916 L F
.74218 .45877 m .74374 .45628 L .74501 .4579 L 0 .027 .126 r
F
.74218 .45877 m .7409 .45717 L .74374 .45628 L F
.84767 .45763 m .84938 .45512 L .85055 .45669 L 0 .024 .123 r
F
.84767 .45763 m .84649 .45605 L .84938 .45512 L F
.37569 .46036 m .37673 .45784 L .37834 .45955 L 0 .03 .13 r
F
.37569 .46036 m .37407 .45865 L .37673 .45784 L F
.85461 .45729 m .85633 .45488 L .8575 .45641 L 0 .024 .122 r
F
.85461 .45729 m .85344 .45576 L .85633 .45488 L F
.44651 .46118 m .44764 .45885 L .44919 .46041 L 0 .032 .133 r
F
.44651 .46118 m .44495 .45961 L .44764 .45885 L F
.27985 .45868 m .28075 .45636 L .28245 .45797 L 0 .027 .126 r
F
.27985 .45868 m .27815 .45709 L .28075 .45636 L F
.35761 .4591 m .35862 .45663 L .36025 .4583 L 0 .028 .127 r
F
.35761 .4591 m .35598 .45743 L .35862 .45663 L F
.74912 .45853 m .75069 .45608 L .75196 .4576 L 0 .026 .125 r
F
.74912 .45853 m .74785 .45699 L .75069 .45608 L F
.48538 .46142 m .48658 .45901 L .48809 .46056 L 0 .033 .134 r
F
.48538 .46142 m .48387 .45987 L .48658 .45901 L F
.69638 .45913 m .69787 .45669 L .69919 .45829 L 0 .028 .127 r
F
.69638 .45913 m .69505 .4575 L .69787 .45669 L F
.75606 .45818 m .75764 .45572 L .7589 .45723 L 0 .026 .125 r
F
.75606 .45818 m .7548 .45667 L .75764 .45572 L F
.57008 .46151 m .57139 .45912 L .57283 .46073 L 0 .033 .134 r
F
.57008 .46151 m .56864 .45992 L .57139 .45912 L F
.63669 .46017 m .63811 .45788 L .63948 .45935 L 0 .03 .131 r
F
.63669 .46017 m .63532 .45869 L .63811 .45788 L F
.62976 .46056 m .63116 .45813 L .63254 .4596 L 0 .031 .131 r
F
.62976 .46056 m .62838 .4591 L .63116 .45813 L F
.86156 .45712 m .86331 .45477 L .86447 .45631 L 0 .024 .122 r
F
.86156 .45712 m .8604 .45559 L .86331 .45477 L F
.42149 .46039 m .42259 .458 L .42417 .45958 L 0 .031 .131 r
F
.42149 .46039 m .41992 .45879 L .42259 .458 L F
.763 .4579 m .76459 .45541 L .76585 .45703 L 0 .025 .124 r
F
.763 .4579 m .76174 .45627 L .76459 .45541 L F
.80188 .4581 m .80352 .45552 L .80474 .45716 L F
.80188 .4581 m .80065 .45646 L .80352 .45552 L F
.5312 .46137 m .53246 .45904 L .53393 .46064 L 0 .033 .134 r
F
.5312 .46137 m .52972 .45981 L .53246 .45904 L F
.61589 .4614 m .61727 .45893 L .61867 .46052 L F
.61589 .4614 m .6145 .4598 L .61727 .45893 L F
.62283 .46104 m .62422 .45856 L .6256 .46007 L 0 .032 .133 r
F
.62283 .46104 m .62144 .45954 L .62422 .45856 L F
.32565 .45874 m .32662 .45629 L .32828 .45794 L 0 .027 .126 r
F
.32565 .45874 m .32399 .45708 L .32662 .45629 L F
.38261 .46031 m .38366 .4578 L .38527 .45943 L 0 .03 .131 r
F
.38261 .46031 m .381 .45867 L .38366 .4578 L F
.70332 .45899 m .70483 .45654 L .70614 .45809 L 0 .028 .127 r
F
.70332 .45899 m .70201 .45742 L .70483 .45654 L F
.45343 .46113 m .45458 .45859 L .45613 .46019 L 0 .032 .133 r
F
.45343 .46113 m .45189 .45953 L .45458 .45859 L F
.80883 .45787 m .81048 .45533 L .8117 .45698 L 0 .025 .124 r
F
.80883 .45787 m .80761 .45623 L .81048 .45533 L F
.49231 .46138 m .49352 .45925 L .49503 .46069 L 0 .034 .135 r
F
.49231 .46138 m .4908 .45991 L .49352 .45925 L F
.71026 .4587 m .71179 .45636 L .71309 .45787 L 0 .027 .127 r
F
.71026 .4587 m .70896 .4572 L .71179 .45636 L F
.64364 .46005 m .64506 .4577 L .64643 .4592 L 0 .03 .131 r
F
.64364 .46005 m .64227 .45853 L .64506 .4577 L F
.28676 .45873 m .28767 .45623 L .28937 .45782 L 0 .027 .127 r
F
.28676 .45873 m .28506 .45712 L .28767 .45623 L F
.42842 .46027 m .42953 .45781 L .4311 .45937 L 0 .031 .131 r
F
.42842 .46027 m .42685 .4587 L .42953 .45781 L F
.46036 .46089 m .46152 .45849 L .46306 .46012 L 0 .032 .133 r
F
.46036 .46089 m .45883 .45926 L .46152 .45849 L F
.38953 .46017 m .39058 .45795 L .39219 .45944 L 0 .031 .131 r
F
.38953 .46017 m .38792 .45869 L .39058 .45795 L F
.36452 .45921 m .36554 .45676 L .36716 .45845 L 0 .028 .128 r
F
.36452 .45921 m .36289 .45753 L .36554 .45676 L F
.81578 .45768 m .81745 .45526 L .81866 .45683 L 0 .025 .124 r
F
.81578 .45768 m .81457 .45612 L .81745 .45526 L F
.76996 .45788 m .77156 .45542 L .77282 .45706 L 0 .026 .124 r
F
.76996 .45788 m .76871 .45623 L .77156 .45542 L F
.65058 .45981 m .65202 .45748 L .65337 .45893 L 0 .03 .13 r
F
.65058 .45981 m .64922 .45834 L .65202 .45748 L F
.53813 .46135 m .5394 .45905 L .54087 .46058 L 0 .034 .135 r
F
.53813 .46135 m .53667 .45985 L .5394 .45905 L F
.29368 .4585 m .29459 .45617 L .29629 .45772 L 0 .027 .126 r
F
.29368 .4585 m .29198 .45693 L .29459 .45617 L F
.33256 .4587 m .33355 .45614 L .3352 .45776 L 0 .027 .127 r
F
.33256 .4587 m .33091 .45706 L .33355 .45614 L F
.71721 .45852 m .71875 .45623 L .72004 .45771 L F
.71721 .45852 m .71591 .45704 L .71875 .45623 L F
.57702 .46161 m .57834 .45914 L .57978 .46084 L 0 .034 .135 r
F
.57702 .46161 m .57559 .45993 L .57834 .45914 L F
.82273 .45745 m .82441 .45498 L .8256 .45651 L 0 .025 .123 r
F
.82273 .45745 m .82153 .4559 L .82441 .45498 L F
.65752 .45958 m .65897 .45723 L .66032 .45875 L 0 .03 .13 r
F
.65752 .45958 m .65617 .45808 L .65897 .45723 L F
.33949 .45847 m .34048 .45609 L .34212 .45771 L 0 .027 .127 r
F
.33949 .45847 m .33784 .45684 L .34048 .45609 L F
.59783 .4606 m .59919 .45841 L .6006 .45979 L 0 .032 .133 r
F
.59783 .4606 m .59642 .45923 L .59919 .45841 L F
.82968 .45715 m .83136 .45466 L .83255 .45624 L 0 .024 .123 r
F
.82968 .45715 m .82848 .45558 L .83136 .45466 L F
.43534 .46024 m .43646 .45796 L .43803 .45952 L 0 .031 .132 r
F
.43534 .46024 m .43378 .45865 L .43646 .45796 L F
.49925 .46143 m .50046 .45931 L .50196 .46073 L 0 .034 .136 r
F
.49925 .46143 m .49774 .46 L .50046 .45931 L F
.77692 .4578 m .77853 .45532 L .77978 .45691 L 0 .026 .125 r
F
.77692 .4578 m .77567 .45619 L .77853 .45532 L F
.54507 .46126 m .54635 .45888 L .54781 .46037 L 0 .034 .135 r
F
.54507 .46126 m .54361 .45977 L .54635 .45888 L F
.39645 .46013 m .39752 .45768 L .39912 .4592 L 0 .031 .131 r
F
.39645 .46013 m .39485 .45863 L .39752 .45768 L F
.72416 .4584 m .72571 .4561 L .727 .45759 L 0 .027 .127 r
F
.72416 .4584 m .72287 .45692 L .72571 .4561 L F
.40339 .45976 m .40446 .45739 L .40606 .4589 L 0 .03 .13 r
F
.40339 .45976 m .40179 .45826 L .40446 .45739 L F
.5909 .46112 m .59224 .45877 L .59366 .46018 L 0 .033 .134 r
F
.5909 .46112 m .58948 .45969 L .59224 .45877 L F
.55201 .46095 m .5533 .45863 L .55475 .46009 L F
.55201 .46095 m .55055 .45947 L .5533 .45863 L F
.46729 .46096 m .46846 .45855 L .46999 .46016 L F
.46729 .46096 m .46576 .45936 L .46846 .45855 L F
.30059 .45847 m .30152 .45609 L .30321 .45761 L 0 .027 .127 r
F
.30059 .45847 m .2989 .45694 L .30152 .45609 L F
.78387 .45753 m .7855 .45517 L .78673 .45667 L 0 .026 .124 r
F
.78387 .45753 m .78263 .45603 L .7855 .45517 L F
.58396 .4616 m .58529 .45898 L .58672 .46064 L 0 .034 .135 r
F
.58396 .4616 m .58253 .45992 L .58529 .45898 L F
.66447 .45948 m .66593 .45714 L .66727 .45869 L 0 .03 .13 r
F
.66447 .45948 m .66312 .45794 L .66593 .45714 L F
.83663 .45699 m .83832 .45445 L .83952 .45612 L 0 .024 .122 r
F
.83663 .45699 m .83543 .45532 L .83832 .45445 L F
.60477 .46047 m .60614 .45826 L .60754 .45972 L 0 .032 .133 r
F
.60477 .46047 m .60337 .45902 L .60614 .45826 L F
.26863 .45797 m .26952 .45551 L .27124 .45708 L 0 .026 .125 r
F
.26863 .45797 m .26691 .45642 L .26952 .45551 L F
.41032 .45956 m .4114 .45722 L .41299 .45873 L 0 .03 .13 r
F
.41032 .45956 m .40873 .45806 L .4114 .45722 L F
.30752 .45822 m .30846 .45578 L .31014 .45731 L 0 .027 .126 r
F
.30752 .45822 m .30583 .4567 L .30846 .45578 L F
.37143 .45939 m .37246 .45694 L .37407 .45865 L 0 .03 .13 r
F
.37143 .45939 m .36981 .4577 L .37246 .45694 L F
.73111 .45827 m .73265 .4557 L .73394 .45733 L 0 .027 .126 r
F
.73111 .45827 m .72982 .45665 L .73265 .4557 L F
.55895 .46079 m .56025 .45841 L .56169 .45993 L 0 .033 .134 r
F
.55895 .46079 m .5575 .45925 L .56025 .45841 L F
.79082 .45733 m .79246 .455 L .79369 .45651 L 0 .025 .124 r
F
.79082 .45733 m .78959 .45582 L .79246 .455 L F
.31445 .45796 m .3154 .45556 L .31707 .45708 L 0 .027 .126 r
F
.31445 .45796 m .31277 .45643 L .3154 .45556 L F
.3464 .45854 m .3474 .45611 L .34904 .45769 L 0 .028 .127 r
F
.3464 .45854 m .34476 .45694 L .3474 .45611 L F
.47422 .46086 m .4754 .45847 L .47693 .46005 L 0 .033 .134 r
F
.47422 .46086 m .4727 .45931 L .4754 .45847 L F
.27555 .45782 m .27644 .4555 L .27815 .45709 L 0 .027 .126 r
F
.27555 .45782 m .27384 .45624 L .27644 .4555 L F
.68529 .45859 m .68677 .45612 L .6881 .45764 L 0 .028 .127 r
F
.68529 .45859 m .68397 .45709 L .68677 .45612 L F
.73806 .45805 m .73961 .45552 L .7409 .45717 L 0 .027 .126 r
F
.73806 .45805 m .73678 .45641 L .73961 .45552 L F
.44227 .46037 m .4434 .45804 L .44495 .45961 L 0 .032 .133 r
F
.44227 .46037 m .44071 .45879 L .4434 .45804 L F
.67836 .45903 m .67983 .45655 L .68116 .45805 L 0 .029 .129 r
F
.67836 .45903 m .67702 .45753 L .67983 .45655 L F
.8436 .45691 m .8453 .45441 L .84649 .45605 L 0 .024 .123 r
F
.8436 .45691 m .84241 .45526 L .8453 .45441 L F
.52005 .46079 m .5213 .45841 L .52278 .45986 L 0 .033 .134 r
F
.52005 .46079 m .51857 .45932 L .5213 .45841 L F
.67142 .45945 m .67288 .45697 L .67422 .45851 L 0 .03 .13 r
F
.67142 .45945 m .67008 .4579 L .67288 .45697 L F
.51312 .46119 m .51435 .45875 L .51584 .46023 L 0 .034 .135 r
F
.51312 .46119 m .51163 .45969 L .51435 .45875 L F
.50618 .46158 m .50741 .45912 L .5089 .46065 L 0 .035 .136 r
F
.50618 .46158 m .50468 .46004 L .50741 .45912 L F
.69224 .45831 m .69373 .45596 L .69505 .4575 L 0 .028 .127 r
F
.69224 .45831 m .69091 .45677 L .69373 .45596 L F
.35333 .45836 m .35434 .45582 L .35598 .45743 L F
.35333 .45836 m .35169 .45676 L .35434 .45582 L F
.41724 .45952 m .41834 .45723 L .41992 .45879 L 0 .03 .131 r
F
.41724 .45952 m .41566 .45798 L .41834 .45723 L F
.56589 .46068 m .5672 .45837 L .56864 .45992 L 0 .033 .134 r
F
.56589 .46068 m .56444 .45915 L .5672 .45837 L F
.85055 .45669 m .85227 .4542 L .85344 .45576 L 0 .024 .122 r
F
.85055 .45669 m .84938 .45512 L .85227 .4542 L F
.79778 .45728 m .79943 .45488 L .80065 .45646 L 0 .026 .124 r
F
.79778 .45728 m .79656 .45571 L .79943 .45488 L F
.61172 .46056 m .6131 .4582 L .6145 .4598 L 0 .033 .134 r
F
.61172 .46056 m .61032 .45896 L .6131 .4582 L F
.52699 .46056 m .52825 .45823 L .52972 .45981 L F
.52699 .46056 m .52551 .45902 L .52825 .45823 L F
.32137 .45788 m .32233 .45544 L .32399 .45708 L 0 .027 .126 r
F
.32137 .45788 m .3197 .45623 L .32233 .45544 L F
.48116 .46077 m .48235 .45825 L .48387 .45987 L 0 .033 .134 r
F
.48116 .46077 m .47964 .45916 L .48235 .45825 L F
.74501 .4579 m .74658 .45539 L .74785 .45699 L 0 .027 .126 r
F
.74501 .4579 m .74374 .45628 L .74658 .45539 L F
.8575 .45641 m .85924 .45405 L .8604 .45559 L 0 .024 .122 r
F
.8575 .45641 m .85633 .45488 L .85924 .45405 L F
.75196 .4576 m .75354 .45516 L .7548 .45667 L 0 .026 .125 r
F
.75196 .4576 m .75069 .45608 L .75354 .45516 L F
.7589 .45723 m .76048 .45476 L .76174 .45627 L 0 .025 .124 r
F
.7589 .45723 m .75764 .45572 L .76048 .45476 L F
.37834 .45955 m .37939 .45697 L .381 .45867 L 0 .03 .13 r
F
.37834 .45955 m .37673 .45784 L .37939 .45697 L F
.48809 .46056 m .48929 .45837 L .4908 .45991 L 0 .033 .134 r
F
.48809 .46056 m .48658 .45901 L .48929 .45837 L F
.63254 .4596 m .63395 .45721 L .63532 .45869 L 0 .031 .131 r
F
.63254 .4596 m .63116 .45813 L .63395 .45721 L F
.44919 .46041 m .45034 .458 L .45189 .45953 L 0 .033 .133 r
F
.44919 .46041 m .44764 .45885 L .45034 .458 L F
.69919 .45829 m .70069 .45584 L .70201 .45742 L 0 .028 .127 r
F
.69919 .45829 m .69787 .45669 L .70069 .45584 L F
.36025 .4583 m .36127 .45584 L .36289 .45753 L F
.36025 .4583 m .35862 .45663 L .36127 .45584 L F
.80474 .45716 m .80638 .45458 L .80761 .45623 L 0 .025 .124 r
F
.80474 .45716 m .80352 .45552 L .80638 .45458 L F
.6256 .46007 m .627 .45758 L .62838 .4591 L 0 .032 .132 r
F
.6256 .46007 m .62422 .45856 L .627 .45758 L F
.28245 .45797 m .28336 .4555 L .28506 .45712 L 0 .027 .127 r
F
.28245 .45797 m .28075 .45636 L .28336 .4555 L F
.76585 .45703 m .76745 .45461 L .76871 .45623 L 0 .025 .124 r
F
.76585 .45703 m .76459 .45541 L .76745 .45461 L F
.63948 .45935 m .6409 .45708 L .64227 .45853 L 0 .031 .131 r
F
.63948 .45935 m .63811 .45788 L .6409 .45708 L F
.61867 .46052 m .62005 .45794 L .62144 .45954 L 0 .033 .134 r
F
.61867 .46052 m .61727 .45893 L .62005 .45794 L F
.57283 .46073 m .57415 .4583 L .57559 .45993 L 0 .034 .134 r
F
.57283 .46073 m .57139 .45912 L .57415 .4583 L F
.86447 .45631 m .86621 .45392 L .86737 .45545 L 0 .024 .122 r
F
.86447 .45631 m .86331 .45477 L .86621 .45392 L F
.42417 .45958 m .42528 .45712 L .42685 .4587 L 0 .031 .131 r
F
.42417 .45958 m .42259 .458 L .42528 .45712 L F
.45613 .46019 m .45728 .45766 L .45883 .45926 L 0 .032 .133 r
F
.45613 .46019 m .45458 .45859 L .45728 .45766 L F
.38527 .45943 m .38632 .45706 L .38792 .45869 L 0 .031 .131 r
F
.38527 .45943 m .38366 .4578 L .38632 .45706 L F
.70614 .45809 m .70765 .45567 L .70896 .4572 L 0 .028 .127 r
F
.70614 .45809 m .70483 .45654 L .70765 .45567 L F
.8117 .45698 m .81336 .45446 L .81457 .45612 L 0 .025 .124 r
F
.8117 .45698 m .81048 .45533 L .81336 .45446 L F
.32828 .45794 m .32925 .45542 L .33091 .45706 L 0 .027 .127 r
F
.32828 .45794 m .32662 .45629 L .32925 .45542 L F
.53393 .46064 m .5352 .45821 L .53667 .45985 L 0 .033 .134 r
F
.53393 .46064 m .53246 .45904 L .5352 .45821 L F
.28937 .45782 m .29029 .45536 L .29198 .45693 L 0 .027 .126 r
F
.28937 .45782 m .28767 .45623 L .29029 .45536 L F
.4311 .45937 m .43221 .45712 L .43378 .45865 L 0 .031 .131 r
F
.4311 .45937 m .42953 .45781 L .43221 .45712 L F
.64643 .4592 m .64786 .45687 L .64922 .45834 L 0 .03 .131 r
F
.64643 .4592 m .64506 .4577 L .64786 .45687 L F
.71309 .45787 m .71461 .45552 L .71591 .45704 L 0 .028 .127 r
F
.71309 .45787 m .71179 .45636 L .71461 .45552 L F
.3352 .45776 m .33619 .45523 L .33784 .45684 L 0 .027 .126 r
F
.3352 .45776 m .33355 .45614 L .33619 .45523 L F
.65337 .45893 m .65481 .45659 L .65617 .45808 L 0 .03 .13 r
F
.65337 .45893 m .65202 .45748 L .65481 .45659 L F
.81866 .45683 m .82033 .45435 L .82153 .4559 L 0 .025 .124 r
F
.81866 .45683 m .81745 .45526 L .82033 .45435 L F
.49503 .46069 m .49623 .45858 L .49774 .46 L 0 .034 .136 r
F
.49503 .46069 m .49352 .45925 L .49623 .45858 L F
.46306 .46012 m .46422 .45773 L .46576 .45936 L 0 .033 .133 r
F
.46306 .46012 m .46152 .45849 L .46422 .45773 L F
.77282 .45706 m .77442 .45457 L .77567 .45619 L 0 .026 .125 r
F
.77282 .45706 m .77156 .45542 L .77442 .45457 L F
.8256 .45651 m .82728 .45404 L .82848 .45558 L 0 .025 .123 r
F
.8256 .45651 m .82441 .45498 L .82728 .45404 L F
.36716 .45845 m .36819 .45599 L .36981 .4577 L 0 .029 .129 r
F
.36716 .45845 m .36554 .45676 L .36819 .45599 L F
.54087 .46058 m .54215 .45822 L .54361 .45977 L 0 .034 .135 r
F
.54087 .46058 m .5394 .45905 L .54215 .45822 L F
.39219 .45944 m .39325 .45713 L .39485 .45863 L 0 .031 .132 r
F
.39219 .45944 m .39058 .45795 L .39325 .45713 L F
.72004 .45771 m .72158 .45543 L .72287 .45692 L 0 .028 .127 r
F
.72004 .45771 m .71875 .45623 L .72158 .45543 L F
.29629 .45772 m .29721 .45541 L .2989 .45694 L F
.29629 .45772 m .29459 .45617 L .29721 .45541 L F
.57978 .46084 m .5811 .45823 L .58253 .45992 L 0 .034 .135 r
F
.57978 .46084 m .57834 .45914 L .5811 .45823 L F
.83255 .45624 m .83424 .45373 L .83543 .45532 L 0 .024 .123 r
F
.83255 .45624 m .83136 .45466 L .83424 .45373 L F
.66032 .45875 m .66177 .45639 L .66312 .45794 L 0 .03 .13 r
F
.66032 .45875 m .65897 .45723 L .66177 .45639 L F
.39912 .4592 m .4002 .45673 L .40179 .45826 L 0 .031 .131 r
F
.39912 .4592 m .39752 .45768 L .4002 .45673 L F
.6006 .45979 m .60196 .45763 L .60337 .45902 L 0 .033 .133 r
F
.6006 .45979 m .59919 .45841 L .60196 .45763 L F
.54781 .46037 m .5491 .458 L .55055 .45947 L 0 .034 .134 r
F
.54781 .46037 m .54635 .45888 L .5491 .458 L F
.59366 .46018 m .59501 .45784 L .59642 .45923 L 0 .033 .134 r
F
.59366 .46018 m .59224 .45877 L .59501 .45784 L F
.77978 .45691 m .78139 .45445 L .78263 .45603 L 0 .026 .125 r
F
.77978 .45691 m .77853 .45532 L .78139 .45445 L F
.34212 .45771 m .34311 .45534 L .34476 .45694 L 0 .028 .127 r
F
.34212 .45771 m .34048 .45609 L .34311 .45534 L F
.26431 .45734 m .26519 .45487 L .26691 .45642 L 0 .027 .126 r
F
.26431 .45734 m .26258 .4558 L .26519 .45487 L F
.40606 .4589 m .40714 .45654 L .40873 .45806 L 0 .03 .13 r
F
.40606 .4589 m .40446 .45739 L .40714 .45654 L F
.58672 .46064 m .58806 .45806 L .58948 .45969 L 0 .034 .135 r
F
.58672 .46064 m .58529 .45898 L .58806 .45806 L F
.727 .45759 m .72854 .45515 L .72982 .45665 L 0 .027 .127 r
F
.727 .45759 m .72571 .4561 L .72854 .45515 L F
.43803 .45952 m .43915 .45726 L .44071 .45879 L 0 .032 .132 r
F
.43803 .45952 m .43646 .45796 L .43915 .45726 L F
.55475 .46009 m .55605 .45781 L .5575 .45925 L 0 .033 .134 r
F
.55475 .46009 m .5533 .45863 L .55605 .45781 L F
.30321 .45761 m .30414 .45517 L .30583 .4567 L 0 .027 .127 r
F
.30321 .45761 m .30152 .45609 L .30414 .45517 L F
.78673 .45667 m .78836 .4543 L .78959 .45582 L 0 .026 .124 r
F
.78673 .45667 m .7855 .45517 L .78836 .4543 L F
.27124 .45708 m .27213 .45466 L .27384 .45624 L 0 .026 .125 r
F
.27124 .45708 m .26952 .45551 L .27213 .45466 L F
.50196 .46073 m .50318 .45862 L .50468 .46004 L 0 .035 .136 r
F
.50196 .46073 m .50046 .45931 L .50318 .45862 L F
.83952 .45612 m .84122 .45361 L .84241 .45526 L 0 .024 .123 r
F
.83952 .45612 m .83832 .45445 L .84122 .45361 L F
.46999 .46016 m .47117 .45769 L .4727 .45931 L 0 .033 .134 r
F
.46999 .46016 m .46846 .45855 L .47117 .45769 L F
.31014 .45731 m .31109 .45491 L .31277 .45643 L 0 .027 .126 r
F
.31014 .45731 m .30846 .45578 L .31109 .45491 L F
.73394 .45733 m .73549 .45478 L .73678 .45641 L F
.73394 .45733 m .73265 .4557 L .73549 .45478 L F
.66727 .45869 m .66873 .45635 L .67008 .4579 L 0 .03 .13 r
F
.66727 .45869 m .66593 .45714 L .66873 .45635 L F
.41299 .45873 m .41408 .45644 L .41566 .45798 L 0 .03 .131 r
F
.41299 .45873 m .4114 .45722 L .41408 .45644 L F
.60754 .45972 m .60892 .45749 L .61032 .45896 L 0 .033 .133 r
F
.60754 .45972 m .60614 .45826 L .60892 .45749 L F
.56169 .45993 m .563 .45761 L .56444 .45915 L 0 .033 .134 r
F
.56169 .45993 m .56025 .45841 L .563 .45761 L F
.6881 .45764 m .68959 .45524 L .69091 .45677 L 0 .028 .127 r
F
.6881 .45764 m .68677 .45612 L .68959 .45524 L F
.31707 .45708 m .31803 .45471 L .3197 .45623 L 0 .027 .126 r
F
.31707 .45708 m .3154 .45556 L .31803 .45471 L F
.79369 .45651 m .79533 .45418 L .79656 .45571 L 0 .026 .124 r
F
.79369 .45651 m .79246 .455 L .79533 .45418 L F
.68116 .45805 m .68264 .45558 L .68397 .45709 L 0 .029 .128 r
F
.68116 .45805 m .67983 .45655 L .68264 .45558 L F
.37407 .45865 m .37512 .45612 L .37673 .45784 L 0 .03 .13 r
F
.37407 .45865 m .37246 .45694 L .37512 .45612 L F
.34904 .45769 m .35005 .45519 L .35169 .45676 L 0 .028 .127 r
F
.34904 .45769 m .3474 .45611 L .35005 .45519 L F
.51584 .46023 m .51708 .45788 L .51857 .45932 L 0 .034 .135 r
F
.51584 .46023 m .51435 .45875 L .51708 .45788 L F
.52278 .45986 m .52403 .45758 L .52551 .45902 L 0 .033 .134 r
F
.52278 .45986 m .5213 .45841 L .52403 .45758 L F
.67422 .45851 m .67569 .456 L .67702 .45753 L 0 .03 .13 r
F
.67422 .45851 m .67288 .45697 L .67569 .456 L F
.7409 .45717 m .74245 .45463 L .74374 .45628 L 0 .027 .126 r
F
.7409 .45717 m .73961 .45552 L .74245 .45463 L F
.47693 .46005 m .47811 .45756 L .47964 .45916 L 0 .033 .134 r
F
.47693 .46005 m .4754 .45847 L .47811 .45756 L F
.5089 .46065 m .51013 .45818 L .51163 .45969 L 0 .035 .136 r
F
.5089 .46065 m .50741 .45912 L .51013 .45818 L F
.84649 .45605 m .84819 .4535 L .84938 .45512 L 0 .024 .123 r
F
.84649 .45605 m .8453 .45441 L .84819 .4535 L F
.35598 .45743 m .35699 .45501 L .35862 .45663 L 0 .028 .127 r
F
.35598 .45743 m .35434 .45582 L .35699 .45501 L F
.27815 .45709 m .27904 .45475 L .28075 .45636 L 0 .027 .126 r
F
.27815 .45709 m .27644 .4555 L .27904 .45475 L F
.44495 .45961 m .44609 .45729 L .44764 .45885 L 0 .033 .133 r
F
.44495 .45961 m .4434 .45804 L .44609 .45729 L F
.85344 .45576 m .85516 .45332 L .85633 .45488 L 0 .024 .122 r
F
.85344 .45576 m .85227 .4542 L .85516 .45332 L F
.69505 .4575 m .69655 .45516 L .69787 .45669 L 0 .028 .127 r
F
.69505 .4575 m .69373 .45596 L .69655 .45516 L F
.48387 .45987 m .48506 .45738 L .48658 .45901 L 0 .033 .134 r
F
.48387 .45987 m .48235 .45825 L .48506 .45738 L F
.74785 .45699 m .74942 .4545 L .75069 .45608 L 0 .027 .126 r
F
.74785 .45699 m .74658 .45539 L .74942 .4545 L F
.56864 .45992 m .56996 .45755 L .57139 .45912 L 0 .033 .134 r
F
.56864 .45992 m .5672 .45837 L .56996 .45755 L F
.80065 .45646 m .8023 .45394 L .80352 .45552 L 0 .026 .124 r
F
.80065 .45646 m .79943 .45488 L .8023 .45394 L F
.76174 .45627 m .76334 .4539 L .76459 .45541 L 0 .025 .124 r
F
.76174 .45627 m .76048 .45476 L .76334 .4539 L F
.7548 .45667 m .75638 .45421 L .75764 .45572 L 0 .026 .125 r
F
.7548 .45667 m .75354 .45516 L .75638 .45421 L F
.41992 .45879 m .42102 .45641 L .42259 .458 L 0 .031 .131 r
F
.41992 .45879 m .41834 .45723 L .42102 .45641 L F
.32399 .45708 m .32496 .45465 L .32662 .45629 L 0 .027 .126 r
F
.32399 .45708 m .32233 .45544 L .32496 .45465 L F
.6145 .4598 m .61588 .45733 L .61727 .45893 L 0 .033 .134 r
F
.6145 .4598 m .6131 .4582 L .61588 .45733 L F
.52972 .45981 m .53098 .45744 L .53246 .45904 L F
.52972 .45981 m .52825 .45823 L .53098 .45744 L F
.8604 .45559 m .86214 .45323 L .86331 .45477 L 0 .024 .122 r
F
.8604 .45559 m .85924 .45405 L .86214 .45323 L F
.381 .45867 m .38205 .45609 L .38366 .4578 L 0 .03 .13 r
F
.381 .45867 m .37939 .45697 L .38205 .45609 L F
.63532 .45869 m .63674 .45642 L .63811 .45788 L 0 .031 .131 r
F
.63532 .45869 m .63395 .45721 L .63674 .45642 L F
.62838 .4591 m .62978 .4566 L .63116 .45813 L 0 .031 .132 r
F
.62838 .4591 m .627 .45758 L .62978 .4566 L F
.80761 .45623 m .80926 .45368 L .81048 .45533 L 0 .025 .124 r
F
.80761 .45623 m .80638 .45458 L .80926 .45368 L F
.45189 .45953 m .45304 .45709 L .45458 .45859 L 0 .033 .133 r
F
.45189 .45953 m .45034 .458 L .45304 .45709 L F
.70201 .45742 m .70352 .45498 L .70483 .45654 L 0 .028 .127 r
F
.70201 .45742 m .70069 .45584 L .70352 .45498 L F
.62144 .45954 m .62283 .45695 L .62422 .45856 L 0 .032 .133 r
F
.62144 .45954 m .62005 .45794 L .62283 .45695 L F
.28506 .45712 m .28597 .45459 L .28767 .45623 L 0 .027 .127 r
F
.28506 .45712 m .28336 .4555 L .28597 .45459 L F
.45883 .45926 m .45998 .45689 L .46152 .45849 L 0 .032 .133 r
F
.45883 .45926 m .45728 .45766 L .45998 .45689 L F
.36289 .45753 m .36392 .45506 L .36554 .45676 L 0 .028 .128 r
F
.36289 .45753 m .36127 .45584 L .36392 .45506 L F
.42685 .4587 m .42796 .45624 L .42953 .45781 L 0 .031 .131 r
F
.42685 .4587 m .42528 .45712 L .42796 .45624 L F
.64227 .45853 m .6437 .45627 L .64506 .4577 L F
.64227 .45853 m .6409 .45708 L .6437 .45627 L F
.86737 .45545 m .86912 .45307 L .87027 .45459 L 0 .024 .122 r
F
.86737 .45545 m .86621 .45392 L .86912 .45307 L F
.76871 .45623 m .77031 .45381 L .77156 .45542 L 0 .026 .124 r
F
.76871 .45623 m .76745 .45461 L .77031 .45381 L F
.70896 .4572 m .71048 .45481 L .71179 .45636 L 0 .028 .127 r
F
.70896 .4572 m .70765 .45567 L .71048 .45481 L F
.4908 .45991 m .49201 .45773 L .49352 .45925 L 0 .034 .135 r
F
.4908 .45991 m .48929 .45837 L .49201 .45773 L F
.57559 .45993 m .57691 .45748 L .57834 .45914 L F
.57559 .45993 m .57415 .4583 L .57691 .45748 L F
.33091 .45706 m .33189 .45452 L .33355 .45614 L 0 .027 .127 r
F
.33091 .45706 m .32925 .45542 L .33189 .45452 L F
.81457 .45612 m .81624 .4536 L .81745 .45526 L 0 .025 .124 r
F
.81457 .45612 m .81336 .45446 L .81624 .4536 L F
.29198 .45693 m .2929 .45462 L .29459 .45617 L 0 .027 .127 r
F
.29198 .45693 m .29029 .45536 L .2929 .45462 L F
.38792 .45869 m .38898 .45634 L .39058 .45795 L 0 .031 .132 r
F
.38792 .45869 m .38632 .45706 L .38898 .45634 L F
.53667 .45985 m .53794 .45737 L .5394 .45905 L 0 .034 .135 r
F
.53667 .45985 m .5352 .45821 L .53794 .45737 L F
.64922 .45834 m .65066 .45603 L .65202 .45748 L 0 .031 .131 r
F
.64922 .45834 m .64786 .45687 L .65066 .45603 L F
.33784 .45684 m .33882 .4545 L .34048 .45609 L 0 .027 .127 r
F
.33784 .45684 m .33619 .45523 L .33882 .4545 L F
.71591 .45704 m .71745 .4547 L .71875 .45623 L 0 .028 .127 r
F
.71591 .45704 m .71461 .45552 L .71745 .4547 L F
.82153 .4559 m .82321 .45342 L .82441 .45498 L 0 .025 .124 r
F
.82153 .4559 m .82033 .45435 L .82321 .45342 L F
.43378 .45865 m .4349 .45646 L .43646 .45796 L 0 .032 .132 r
F
.43378 .45865 m .43221 .45712 L .4349 .45646 L F
.65617 .45808 m .65761 .45571 L .65897 .45723 L 0 .03 .13 r
F
.65617 .45808 m .65481 .45659 L .65761 .45571 L F
.82848 .45558 m .83016 .4531 L .83136 .45466 L 0 .025 .123 r
F
.82848 .45558 m .82728 .45404 L .83016 .4531 L F
.77567 .45619 m .77728 .45372 L .77853 .45532 L 0 .026 .125 r
F
.77567 .45619 m .77442 .45457 L .77728 .45372 L F
.58253 .45992 m .58387 .45732 L .58529 .45898 L 0 .034 .135 r
F
.58253 .45992 m .5811 .45823 L .58387 .45732 L F
.46576 .45936 m .46693 .45691 L .46846 .45855 L 0 .033 .134 r
F
.46576 .45936 m .46422 .45773 L .46693 .45691 L F
.83543 .45532 m .83713 .45287 L .83832 .45445 L 0 .024 .122 r
F
.83543 .45532 m .83424 .45373 L .83713 .45287 L F
.54361 .45977 m .54489 .45735 L .54635 .45888 L 0 .034 .135 r
F
.54361 .45977 m .54215 .45822 L .54489 .45735 L F
.39485 .45863 m .39592 .45616 L .39752 .45768 L 0 .031 .132 r
F
.39485 .45863 m .39325 .45713 L .39592 .45616 L F
.72287 .45692 m .72442 .45461 L .72571 .4561 L 0 .028 .127 r
F
.72287 .45692 m .72158 .45543 L .72442 .45461 L F
.40179 .45826 m .40287 .45583 L .40446 .45739 L 0 .031 .131 r
F
.40179 .45826 m .4002 .45673 L .40287 .45583 L F
.59642 .45923 m .59778 .45701 L .59919 .45841 L 0 .033 .134 r
F
.59642 .45923 m .59501 .45784 L .59778 .45701 L F
.49774 .46 m .49895 .45789 L .50046 .45931 L 0 .035 .136 r
F
.49774 .46 m .49623 .45858 L .49895 .45789 L F
.36981 .4577 m .37084 .45522 L .37246 .45694 L 0 .029 .129 r
F
.36981 .4577 m .36819 .45599 L .37084 .45522 L F
.2989 .45694 m .29983 .45457 L .30152 .45609 L 0 .028 .127 r
F
.2989 .45694 m .29721 .45541 L .29983 .45457 L F
.55055 .45947 m .55185 .45719 L .5533 .45863 L 0 .034 .135 r
F
.55055 .45947 m .5491 .458 L .55185 .45719 L F
.66312 .45794 m .66458 .45557 L .66593 .45714 L 0 .03 .13 r
F
.66312 .45794 m .66177 .45639 L .66458 .45557 L F
.78263 .45603 m .78426 .45358 L .7855 .45517 L 0 .026 .125 r
F
.78263 .45603 m .78139 .45445 L .78426 .45358 L F
.58948 .45969 m .59082 .45716 L .59224 .45877 L 0 .034 .135 r
F
.58948 .45969 m .58806 .45806 L .59082 .45716 L F
.26691 .45642 m .2678 .45394 L .26952 .45551 L 0 .027 .126 r
F
.26691 .45642 m .26519 .45487 L .2678 .45394 L F
.72982 .45665 m .73137 .45419 L .73265 .4557 L F
.72982 .45665 m .72854 .45515 L .73137 .45419 L F
.30583 .4567 m .30677 .45425 L .30846 .45578 L 0 .027 .127 r
F
.30583 .4567 m .30414 .45517 L .30677 .45425 L F
.40873 .45806 m .40981 .45569 L .4114 .45722 L 0 .03 .131 r
F
.40873 .45806 m .40714 .45654 L .40981 .45569 L F
.60337 .45902 m .60474 .45685 L .60614 .45826 L 0 .033 .134 r
F
.60337 .45902 m .60196 .45763 L .60474 .45685 L F
.5575 .45925 m .5588 .45698 L .56025 .45841 L F
.5575 .45925 m .55605 .45781 L .5588 .45698 L F
.34476 .45694 m .34575 .45452 L .3474 .45611 L 0 .028 .127 r
F
.34476 .45694 m .34311 .45534 L .34575 .45452 L F
.78959 .45582 m .79123 .45348 L .79246 .455 L 0 .026 .125 r
F
.78959 .45582 m .78836 .4543 L .79123 .45348 L F
.73678 .45641 m .73833 .45388 L .73961 .45552 L 0 .027 .126 r
F
.73678 .45641 m .73549 .45478 L .73833 .45388 L F
.84241 .45526 m .84411 .45276 L .8453 .45441 L 0 .024 .123 r
F
.84241 .45526 m .84122 .45361 L .84411 .45276 L F
.4727 .45931 m .47388 .45682 L .4754 .45847 L 0 .033 .134 r
F
.4727 .45931 m .47117 .45769 L .47388 .45682 L F
.27384 .45624 m .27473 .4539 L .27644 .4555 L 0 .027 .126 r
F
.27384 .45624 m .27213 .45466 L .27473 .4539 L F
.31277 .45643 m .31372 .45404 L .3154 .45556 L F
.31277 .45643 m .31109 .45491 L .31372 .45404 L F
.44071 .45879 m .44184 .45651 L .4434 .45804 L 0 .032 .133 r
F
.44071 .45879 m .43915 .45726 L .44184 .45651 L F
.68397 .45709 m .68544 .4546 L .68677 .45612 L 0 .028 .128 r
F
.68397 .45709 m .68264 .45558 L .68544 .4546 L F
.67008 .4579 m .67154 .45542 L .67288 .45697 L 0 .03 .13 r
F
.67008 .4579 m .66873 .45635 L .67154 .45542 L F
.35169 .45676 m .3527 .45426 L .35434 .45582 L 0 .028 .127 r
F
.35169 .45676 m .35005 .45519 L .3527 .45426 L F
.67702 .45753 m .67849 .45503 L .67983 .45655 L 0 .029 .129 r
F
.67702 .45753 m .67569 .456 L .67849 .45503 L F
.69091 .45677 m .69241 .45444 L .69373 .45596 L 0 .028 .127 r
F
.69091 .45677 m .68959 .45524 L .69241 .45444 L F
.50468 .46004 m .50591 .45772 L .50741 .45912 L 0 .035 .137 r
F
.50468 .46004 m .50318 .45862 L .50591 .45772 L F
.51163 .45969 m .51286 .45728 L .51435 .45875 L 0 .034 .135 r
F
.51163 .45969 m .51013 .45818 L .51286 .45728 L F
.3197 .45623 m .32065 .45389 L .32233 .45544 L 0 .027 .126 r
F
.3197 .45623 m .31803 .45471 L .32065 .45389 L F
.51857 .45932 m .51981 .45701 L .5213 .45841 L 0 .034 .135 r
F
.51857 .45932 m .51708 .45788 L .51981 .45701 L F
.41566 .45798 m .41676 .45566 L .41834 .45723 L 0 .031 .131 r
F
.41566 .45798 m .41408 .45644 L .41676 .45566 L F
.56444 .45915 m .56576 .45681 L .5672 .45837 L 0 .033 .134 r
F
.56444 .45915 m .563 .45761 L .56576 .45681 L F
.61032 .45896 m .6117 .45671 L .6131 .4582 L F
.61032 .45896 m .60892 .45749 L .6117 .45671 L F
.47964 .45916 m .48083 .45663 L .48235 .45825 L F
.47964 .45916 m .47811 .45756 L .48083 .45663 L F
.84938 .45512 m .85109 .45259 L .85227 .4542 L 0 .024 .123 r
F
.84938 .45512 m .84819 .4535 L .85109 .45259 L F
.74374 .45628 m .7453 .45375 L .74658 .45539 L 0 .027 .126 r
F
.74374 .45628 m .74245 .45463 L .7453 .45375 L F
.79656 .45571 m .79821 .45335 L .79943 .45488 L 0 .026 .125 r
F
.79656 .45571 m .79533 .45418 L .79821 .45335 L F
.37673 .45784 m .37778 .45526 L .37939 .45697 L 0 .03 .13 r
F
.37673 .45784 m .37512 .45612 L .37778 .45526 L F
.52551 .45902 m .52677 .45677 L .52825 .45823 L 0 .033 .134 r
F
.52551 .45902 m .52403 .45758 L .52677 .45677 L F
.85633 .45488 m .85807 .45249 L .85924 .45405 L 0 .024 .122 r
F
.85633 .45488 m .85516 .45332 L .85807 .45249 L F
.35862 .45663 m .35964 .45423 L .36127 .45584 L 0 .028 .127 r
F
.35862 .45663 m .35699 .45501 L .35964 .45423 L F
.75069 .45608 m .75227 .45359 L .75354 .45516 L 0 .026 .126 r
F
.75069 .45608 m .74942 .4545 L .75227 .45359 L F
.80352 .45552 m .80516 .45299 L .80638 .45458 L 0 .025 .124 r
F
.80352 .45552 m .8023 .45394 L .80516 .45299 L F
.75764 .45572 m .75923 .45325 L .76048 .45476 L 0 .026 .125 r
F
.75764 .45572 m .75638 .45421 L .75923 .45325 L F
.69787 .45669 m .69938 .45432 L .70069 .45584 L 0 .028 .128 r
F
.69787 .45669 m .69655 .45516 L .69938 .45432 L F
.48658 .45901 m .48778 .45673 L .48929 .45837 L 0 .033 .134 r
F
.48658 .45901 m .48506 .45738 L .48778 .45673 L F
.44764 .45885 m .44879 .45646 L .45034 .458 L F
.44764 .45885 m .44609 .45729 L .44879 .45646 L F
.28075 .45636 m .28165 .45387 L .28336 .4555 L 0 .027 .127 r
F
.28075 .45636 m .27904 .45475 L .28165 .45387 L F
.76459 .45541 m .7662 .4531 L .76745 .45461 L 0 .026 .124 r
F
.76459 .45541 m .76334 .4539 L .7662 .4531 L F
.63116 .45813 m .63257 .45568 L .63395 .45721 L 0 .031 .132 r
F
.63116 .45813 m .62978 .4566 L .63257 .45568 L F
.57139 .45912 m .57271 .45671 L .57415 .4583 L 0 .034 .135 r
F
.57139 .45912 m .56996 .45755 L .57271 .45671 L F
.61727 .45893 m .61866 .45633 L .62005 .45794 L 0 .033 .134 r
F
.61727 .45893 m .61588 .45733 L .61866 .45633 L F
.62422 .45856 m .62561 .45597 L .627 .45758 L 0 .032 .133 r
F
.62422 .45856 m .62283 .45695 L .62561 .45597 L F
.38366 .4578 m .38471 .45538 L .38632 .45706 L 0 .031 .131 r
F
.38366 .4578 m .38205 .45609 L .38471 .45538 L F
.42259 .458 m .4237 .45551 L .42528 .45712 L F
.42259 .458 m .42102 .45641 L .4237 .45551 L F
.45458 .45859 m .45574 .45619 L .45728 .45766 L 0 .032 .133 r
F
.45458 .45859 m .45304 .45709 L .45574 .45619 L F
.32662 .45629 m .32759 .45379 L .32925 .45542 L 0 .027 .126 r
F
.32662 .45629 m .32496 .45465 L .32759 .45379 L F
.81048 .45533 m .81214 .45281 L .81336 .45446 L 0 .025 .124 r
F
.81048 .45533 m .80926 .45368 L .81214 .45281 L F
.86331 .45477 m .86505 .45239 L .86621 .45392 L 0 .024 .123 r
F
.86331 .45477 m .86214 .45323 L .86505 .45239 L F
.63811 .45788 m .63953 .45563 L .6409 .45708 L 0 .031 .132 r
F
.63811 .45788 m .63674 .45642 L .63953 .45563 L F
.70483 .45654 m .70634 .45412 L .70765 .45567 L 0 .028 .127 r
F
.70483 .45654 m .70352 .45498 L .70634 .45412 L F
.53246 .45904 m .53372 .45656 L .5352 .45821 L 0 .033 .134 r
F
.53246 .45904 m .53098 .45744 L .53372 .45656 L F
.28767 .45623 m .28859 .4537 L .29029 .45536 L 0 .027 .126 r
F
.28767 .45623 m .28597 .45459 L .28859 .4537 L F
.42953 .45781 m .43064 .45558 L .43221 .45712 L 0 .031 .132 r
F
.42953 .45781 m .42796 .45624 L .43064 .45558 L F
.87027 .45459 m .87203 .45221 L .87318 .45373 L 0 .024 .122 r
F
.87027 .45459 m .86912 .45307 L .87203 .45221 L F
.33355 .45614 m .33453 .45362 L .33619 .45523 L 0 .027 .126 r
F
.33355 .45614 m .33189 .45452 L .33453 .45362 L F
.64506 .4577 m .6465 .45545 L .64786 .45687 L 0 .031 .131 r
F
.64506 .4577 m .6437 .45627 L .6465 .45545 L F
.71179 .45636 m .71331 .45395 L .71461 .45552 L 0 .028 .127 r
F
.71179 .45636 m .71048 .45481 L .71331 .45395 L F
.36554 .45676 m .36657 .45428 L .36819 .45599 L 0 .029 .128 r
F
.36554 .45676 m .36392 .45506 L .36657 .45428 L F
.46152 .45849 m .46269 .45613 L .46422 .45773 L 0 .033 .133 r
F
.46152 .45849 m .45998 .45689 L .46269 .45613 L F
.77156 .45542 m .77317 .45298 L .77442 .45457 L 0 .026 .125 r
F
.77156 .45542 m .77031 .45381 L .77317 .45298 L F
.81745 .45526 m .81911 .4527 L .82033 .45435 L 0 .025 .124 r
F
.81745 .45526 m .81624 .4536 L .81911 .4527 L F
.57834 .45914 m .57967 .4566 L .5811 .45823 L 0 .034 .135 r
F
.57834 .45914 m .57691 .45748 L .57967 .4566 L F
.82441 .45498 m .82609 .45249 L .82728 .45404 L 0 .025 .123 r
F
.82441 .45498 m .82321 .45342 L .82609 .45249 L F
.65202 .45748 m .65346 .45511 L .65481 .45659 L 0 .031 .131 r
F
.65202 .45748 m .65066 .45603 L .65346 .45511 L F
.5394 .45905 m .54068 .45653 L .54215 .45822 L 0 .034 .135 r
F
.5394 .45905 m .53794 .45737 L .54068 .45653 L F
.49352 .45925 m .49472 .45706 L .49623 .45858 L 0 .035 .136 r
F
.49352 .45925 m .49201 .45773 L .49472 .45706 L F
.29459 .45617 m .29551 .45388 L .29721 .45541 L 0 .028 .127 r
F
.29459 .45617 m .2929 .45462 L .29551 .45388 L F
.83136 .45466 m .83305 .45217 L .83424 .45373 L 0 .024 .123 r
F
.83136 .45466 m .83016 .4531 L .83305 .45217 L F
.39058 .45795 m .39164 .45553 L .39325 .45713 L 0 .032 .132 r
F
.39058 .45795 m .38898 .45634 L .39164 .45553 L F
.71875 .45623 m .72029 .4539 L .72158 .45543 L 0 .028 .127 r
F
.71875 .45623 m .71745 .4547 L .72029 .4539 L F
.65897 .45723 m .66042 .45484 L .66177 .45639 L 0 .03 .13 r
F
.65897 .45723 m .65761 .45571 L .66042 .45484 L F
.77853 .45532 m .78015 .45285 L .78139 .45445 L 0 .026 .125 r
F
.77853 .45532 m .77728 .45372 L .78015 .45285 L F
.34048 .45609 m .34146 .45377 L .34311 .45534 L 0 .028 .127 r
F
.34048 .45609 m .33882 .4545 L .34146 .45377 L F
.58529 .45898 m .58663 .45642 L .58806 .45806 L 0 .034 .135 r
F
.58529 .45898 m .58387 .45732 L .58663 .45642 L F
.39752 .45768 m .3986 .45519 L .4002 .45673 L 0 .031 .131 r
F
.39752 .45768 m .39592 .45616 L .3986 .45519 L F
.26258 .4558 m .26346 .45332 L .26519 .45487 L 0 .027 .126 r
F
.26258 .4558 m .26085 .45426 L .26346 .45332 L F
.54635 .45888 m .54764 .45649 L .5491 .458 L 0 .034 .135 r
F
.54635 .45888 m .54489 .45735 L .54764 .45649 L F
.83832 .45445 m .84003 .45203 L .84122 .45361 L 0 .024 .123 r
F
.83832 .45445 m .83713 .45287 L .84003 .45203 L F
.43646 .45796 m .43758 .45578 L .43915 .45726 L 0 .032 .133 r
F
.43646 .45796 m .4349 .45646 L .43758 .45578 L F
.40446 .45739 m .40555 .45496 L .40714 .45654 L 0 .031 .131 r
F
.40446 .45739 m .40287 .45583 L .40555 .45496 L F
.46846 .45855 m .46964 .45603 L .47117 .45769 L 0 .033 .134 r
F
.46846 .45855 m .46693 .45691 L .46964 .45603 L F
.59224 .45877 m .59359 .45625 L .59501 .45784 L 0 .034 .134 r
F
.59224 .45877 m .59082 .45716 L .59359 .45625 L F
.73265 .4557 m .7342 .45324 L .73549 .45478 L 0 .027 .126 r
F
.73265 .4557 m .73137 .45419 L .7342 .45324 L F
.26952 .45551 m .27041 .45307 L .27213 .45466 L 0 .026 .126 r
F
.26952 .45551 m .2678 .45394 L .27041 .45307 L F
.30152 .45609 m .30245 .45365 L .30414 .45517 L 0 .028 .127 r
F
.30152 .45609 m .29983 .45457 L .30245 .45365 L F
.59919 .45841 m .60056 .45621 L .60196 .45763 L 0 .033 .134 r
F
.59919 .45841 m .59778 .45701 L .60056 .45621 L F
.72571 .4561 m .72725 .45364 L .72854 .45515 L 0 .028 .127 r
F
.72571 .4561 m .72442 .45461 L .72725 .45364 L F
.5533 .45863 m .5546 .45639 L .55605 .45781 L 0 .034 .135 r
F
.5533 .45863 m .55185 .45719 L .5546 .45639 L F
.7855 .45517 m .78712 .45271 L .78836 .4543 L 0 .026 .125 r
F
.7855 .45517 m .78426 .45358 L .78712 .45271 L F
.30846 .45578 m .3094 .45338 L .31109 .45491 L 0 .027 .127 r
F
.30846 .45578 m .30677 .45425 L .3094 .45338 L F
.37246 .45694 m .3735 .45441 L .37512 .45612 L 0 .03 .129 r
F
.37246 .45694 m .37084 .45522 L .3735 .45441 L F
.66593 .45714 m .66739 .45475 L .66873 .45635 L 0 .03 .13 r
F
.66593 .45714 m .66458 .45557 L .66739 .45475 L F
.50046 .45931 m .50168 .4572 L .50318 .45862 L 0 .036 .137 r
F
.50046 .45931 m .49895 .45789 L .50168 .4572 L F
.4114 .45722 m .41249 .45488 L .41408 .45644 L 0 .031 .131 r
F
.4114 .45722 m .40981 .45569 L .41249 .45488 L F
.56025 .45841 m .56155 .45615 L .563 .45761 L 0 .033 .134 r
F
.56025 .45841 m .5588 .45698 L .56155 .45615 L F
.73961 .45552 m .74117 .45298 L .74245 .45463 L 0 .027 .126 r
F
.73961 .45552 m .73833 .45388 L .74117 .45298 L F
.3474 .45611 m .3484 .45361 L .35005 .45519 L 0 .028 .127 r
F
.3474 .45611 m .34575 .45452 L .3484 .45361 L F
.68677 .45612 m .68826 .45372 L .68959 .45524 L 0 .028 .128 r
F
.68677 .45612 m .68544 .4546 L .68826 .45372 L F
.60614 .45826 m .60752 .45606 L .60892 .45749 L 0 .033 .134 r
F
.60614 .45826 m .60474 .45685 L .60752 .45606 L F
.3154 .45556 m .31635 .45318 L .31803 .45471 L 0 .027 .126 r
F
.3154 .45556 m .31372 .45404 L .31635 .45318 L F
.8453 .45441 m .84701 .45187 L .84819 .4535 L 0 .024 .123 r
F
.8453 .45441 m .84411 .45276 L .84701 .45187 L F
.79246 .455 m .79411 .45266 L .79533 .45418 L 0 .026 .125 r
F
.79246 .455 m .79123 .45348 L .79411 .45266 L F
.4754 .45847 m .47659 .45591 L .47811 .45756 L 0 .033 .134 r
F
.4754 .45847 m .47388 .45682 L .47659 .45591 L F
.67983 .45655 m .6813 .45405 L .68264 .45558 L 0 .029 .129 r
F
.67983 .45655 m .67849 .45503 L .6813 .45405 L F
.67288 .45697 m .67435 .45446 L .67569 .456 L 0 .03 .13 r
F
.67288 .45697 m .67154 .45542 L .67435 .45446 L F
.35434 .45582 m .35535 .45347 L .35699 .45501 L 0 .028 .127 r
F
.35434 .45582 m .3527 .45426 L .35535 .45347 L F
.50741 .45912 m .50863 .45679 L .51013 .45818 L 0 .035 .136 r
F
.50741 .45912 m .50591 .45772 L .50863 .45679 L F
.51435 .45875 m .51559 .45644 L .51708 .45788 L 0 .034 .135 r
F
.51435 .45875 m .51286 .45728 L .51559 .45644 L F
.27644 .4555 m .27733 .45314 L .27904 .45475 L 0 .027 .126 r
F
.27644 .4555 m .27473 .4539 L .27733 .45314 L F
.5213 .45841 m .52255 .45618 L .52403 .45758 L 0 .034 .135 r
F
.5213 .45841 m .51981 .45701 L .52255 .45618 L F
.4434 .45804 m .44453 .45577 L .44609 .45729 L 0 .033 .134 r
F
.4434 .45804 m .44184 .45651 L .44453 .45577 L F
.85227 .4542 m .85399 .45171 L .85516 .45332 L 0 .024 .122 r
F
.85227 .4542 m .85109 .45259 L .85399 .45171 L F
.48235 .45825 m .48354 .45575 L .48506 .45738 L 0 .033 .134 r
F
.48235 .45825 m .48083 .45663 L .48354 .45575 L F
.69373 .45596 m .69523 .45364 L .69655 .45516 L 0 .028 .128 r
F
.69373 .45596 m .69241 .45444 L .69523 .45364 L F
.74658 .45539 m .74815 .45288 L .74942 .4545 L 0 .027 .126 r
F
.74658 .45539 m .7453 .45375 L .74815 .45288 L F
.37939 .45697 m .38044 .45439 L .38205 .45609 L 0 .03 .13 r
F
.37939 .45697 m .37778 .45526 L .38044 .45439 L F
.32233 .45544 m .32329 .45308 L .32496 .45465 L 0 .027 .126 r
F
.32233 .45544 m .32065 .45389 L .32329 .45308 L F
.79943 .45488 m .80107 .4524 L .8023 .45394 L 0 .026 .125 r
F
.79943 .45488 m .79821 .45335 L .80107 .4524 L F
.5672 .45837 m .56851 .45598 L .56996 .45755 L 0 .034 .135 r
F
.5672 .45837 m .56576 .45681 L .56851 .45598 L F
.41834 .45723 m .41944 .45481 L .42102 .45641 L 0 .031 .131 r
F
.41834 .45723 m .41676 .45566 L .41944 .45481 L F
.6131 .4582 m .61448 .45584 L .61588 .45733 L 0 .033 .134 r
F
.6131 .4582 m .6117 .45671 L .61448 .45584 L F
.76048 .45476 m .76208 .45238 L .76334 .4539 L 0 .026 .125 r
F
.76048 .45476 m .75923 .45325 L .76208 .45238 L F
.52825 .45823 m .52951 .45596 L .53098 .45744 L 0 .034 .134 r
F
.52825 .45823 m .52677 .45677 L .52951 .45596 L F
.75354 .45516 m .75511 .45265 L .75638 .45421 L 0 .026 .125 r
F
.75354 .45516 m .75227 .45359 L .75511 .45265 L F
.80638 .45458 m .80804 .45208 L .80926 .45368 L 0 .025 .124 r
F
.80638 .45458 m .80516 .45299 L .80804 .45208 L F
.85924 .45405 m .86098 .45166 L .86214 .45323 L 0 .024 .123 r
F
.85924 .45405 m .85807 .45249 L .86098 .45166 L F
.62005 .45794 m .62144 .45534 L .62283 .45695 L 0 .032 .133 r
F
.62005 .45794 m .61866 .45633 L .62144 .45534 L F
.70069 .45584 m .7022 .45348 L .70352 .45498 L 0 .028 .128 r
F
.70069 .45584 m .69938 .45432 L .7022 .45348 L F
.36127 .45584 m .36229 .45344 L .36392 .45506 L F
.36127 .45584 m .35964 .45423 L .36229 .45344 L F
.627 .45758 m .6284 .45498 L .62978 .4566 L 0 .032 .132 r
F
.627 .45758 m .62561 .45597 L .6284 .45498 L F
.63395 .45721 m .63536 .4549 L .63674 .45642 L 0 .031 .132 r
F
.63395 .45721 m .63257 .45568 L .63536 .4549 L F
.45034 .458 m .45149 .45559 L .45304 .45709 L 0 .033 .134 r
F
.45034 .458 m .44879 .45646 L .45149 .45559 L F
.28336 .4555 m .28427 .45294 L .28597 .45459 L 0 .027 .126 r
F
.28336 .4555 m .28165 .45387 L .28427 .45294 L F
.45728 .45766 m .45844 .45546 L .45998 .45689 L 0 .033 .133 r
F
.45728 .45766 m .45574 .45619 L .45844 .45546 L F
.76745 .45461 m .76906 .45229 L .77031 .45381 L 0 .026 .125 r
F
.76745 .45461 m .7662 .4531 L .76906 .45229 L F
.42528 .45712 m .42639 .45462 L .42796 .45624 L 0 .031 .131 r
F
.42528 .45712 m .4237 .45551 L .42639 .45462 L F
.57415 .4583 m .57548 .45586 L .57691 .45748 L 0 .034 .135 r
F
.57415 .4583 m .57271 .45671 L .57548 .45586 L F
.32925 .45542 m .33023 .4529 L .33189 .45452 L 0 .027 .126 r
F
.32925 .45542 m .32759 .45379 L .33023 .4529 L F
.81336 .45446 m .81502 .45193 L .81624 .4536 L 0 .025 .124 r
F
.81336 .45446 m .81214 .45281 L .81502 .45193 L F
.86621 .45392 m .86796 .45154 L .86912 .45307 L 0 .024 .123 r
F
.86621 .45392 m .86505 .45239 L .86796 .45154 L F
.70765 .45567 m .70917 .45325 L .71048 .45481 L 0 .028 .127 r
F
.70765 .45567 m .70634 .45412 L .70917 .45325 L F
.48929 .45837 m .49049 .45607 L .49201 .45773 L 0 .034 .135 r
F
.48929 .45837 m .48778 .45673 L .49049 .45607 L F
.5352 .45821 m .53646 .45569 L .53794 .45737 L 0 .033 .134 r
F
.5352 .45821 m .53372 .45656 L .53646 .45569 L F
.38632 .45706 m .38737 .45467 L .38898 .45634 L 0 .031 .131 r
F
.38632 .45706 m .38471 .45538 L .38737 .45467 L F
.6409 .45708 m .64233 .45483 L .6437 .45627 L 0 .031 .132 r
F
.6409 .45708 m .63953 .45563 L .64233 .45483 L F
.29029 .45536 m .2912 .45295 L .2929 .45462 L 0 .027 .127 r
F
.29029 .45536 m .28859 .4537 L .2912 .45295 L F
.33619 .45523 m .33717 .45291 L .33882 .4545 L F
.33619 .45523 m .33453 .45362 L .33717 .45291 L F
.87318 .45373 m .87494 .45132 L .87609 .45286 L 0 .024 .122 r
F
.87318 .45373 m .87203 .45221 L .87494 .45132 L F
.82033 .45435 m .822 .45179 L .82321 .45342 L 0 .025 .124 r
F
.82033 .45435 m .81911 .4527 L .822 .45179 L F
.71461 .45552 m .71614 .45313 L .71745 .4547 L 0 .028 .127 r
F
.71461 .45552 m .71331 .45395 L .71614 .45313 L F
.64786 .45687 m .6493 .45463 L .65066 .45603 L 0 .031 .132 r
F
.64786 .45687 m .6465 .45545 L .6493 .45463 L F
.5811 .45823 m .58244 .45571 L .58387 .45732 L 0 .034 .135 r
F
.5811 .45823 m .57967 .4566 L .58244 .45571 L F
.77442 .45457 m .77604 .45214 L .77728 .45372 L 0 .026 .125 r
F
.77442 .45457 m .77317 .45298 L .77604 .45214 L F
.43221 .45712 m .43333 .45496 L .4349 .45646 L 0 .032 .132 r
F
.43221 .45712 m .43064 .45558 L .43333 .45496 L F
.82728 .45404 m .82897 .45154 L .83016 .4531 L 0 .025 .123 r
F
.82728 .45404 m .82609 .45249 L .82897 .45154 L F
.36819 .45599 m .36922 .45349 L .37084 .45522 L 0 .029 .129 r
F
.36819 .45599 m .36657 .45428 L .36922 .45349 L F
.46422 .45773 m .46539 .45531 L .46693 .45691 L 0 .033 .134 r
F
.46422 .45773 m .46269 .45613 L .46539 .45531 L F
.65481 .45659 m .65626 .45419 L .65761 .45571 L 0 .03 .131 r
F
.65481 .45659 m .65346 .45511 L .65626 .45419 L F
.83424 .45373 m .83594 .4513 L .83713 .45287 L 0 .024 .123 r
F
.83424 .45373 m .83305 .45217 L .83594 .4513 L F
.54215 .45822 m .54343 .45569 L .54489 .45735 L 0 .034 .135 r
F
.54215 .45822 m .54068 .45653 L .54343 .45569 L F
.58806 .45806 m .5894 .45554 L .59082 .45716 L F
.58806 .45806 m .58663 .45642 L .5894 .45554 L F
.4002 .45673 m .40127 .45427 L .40287 .45583 L 0 .031 .131 r
F
.4002 .45673 m .3986 .45519 L .40127 .45427 L F
.39325 .45713 m .39432 .45456 L .39592 .45616 L 0 .031 .132 r
F
.39325 .45713 m .39164 .45553 L .39432 .45456 L F
.78139 .45445 m .78301 .45198 L .78426 .45358 L 0 .026 .125 r
F
.78139 .45445 m .78015 .45285 L .78301 .45198 L F
.29721 .45541 m .29813 .45304 L .29983 .45457 L 0 .028 .128 r
F
.29721 .45541 m .29551 .45388 L .29813 .45304 L F
.66177 .45639 m .66322 .45398 L .66458 .45557 L 0 .03 .13 r
F
.66177 .45639 m .66042 .45484 L .66322 .45398 L F
.72158 .45543 m .72312 .45308 L .72442 .45461 L 0 .028 .128 r
F
.72158 .45543 m .72029 .4539 L .72312 .45308 L F
.26519 .45487 m .26608 .45237 L .2678 .45394 L 0 .027 .126 r
F
.26519 .45487 m .26346 .45332 L .26608 .45237 L F
.5491 .458 m .55039 .4557 L .55185 .45719 L 0 .034 .135 r
F
.5491 .458 m .54764 .45649 L .55039 .4557 L F
.49623 .45858 m .49745 .45635 L .49895 .45789 L 0 .036 .137 r
F
.49623 .45858 m .49472 .45706 L .49745 .45635 L F
.59501 .45784 m .59637 .45541 L .59778 .45701 L 0 .034 .134 r
F
.59501 .45784 m .59359 .45625 L .59637 .45541 L F
.72854 .45515 m .73008 .45267 L .73137 .45419 L 0 .027 .127 r
F
.72854 .45515 m .72725 .45364 L .73008 .45267 L F
.34311 .45534 m .3441 .45297 L .34575 .45452 L 0 .028 .128 r
F
.34311 .45534 m .34146 .45377 L .3441 .45297 L F
.84122 .45361 m .84293 .45119 L .84411 .45276 L 0 .024 .123 r
F
.84122 .45361 m .84003 .45203 L .84293 .45119 L F
.73549 .45478 m .73704 .45232 L .73833 .45388 L 0 .027 .126 r
F
.73549 .45478 m .7342 .45324 L .73704 .45232 L F
.30414 .45517 m .30508 .45272 L .30677 .45425 L 0 .028 .127 r
F
.30414 .45517 m .30245 .45365 L .30508 .45272 L F
.47117 .45769 m .47235 .45515 L .47388 .45682 L 0 .033 .134 r
F
.47117 .45769 m .46964 .45603 L .47235 .45515 L F
.40714 .45654 m .40822 .4541 L .40981 .45569 L 0 .031 .131 r
F
.40714 .45654 m .40555 .45496 L .40822 .4541 L F
.27213 .45466 m .27301 .45229 L .27473 .4539 L 0 .027 .126 r
F
.27213 .45466 m .27041 .45307 L .27301 .45229 L F
.78836 .4543 m .79 .45188 L .79123 .45348 L 0 .026 .125 r
F
.78836 .4543 m .78712 .45271 L .79 .45188 L F
.31109 .45491 m .31203 .45251 L .31372 .45404 L 0 .027 .127 r
F
.31109 .45491 m .3094 .45338 L .31203 .45251 L F
.55605 .45781 m .55735 .45557 L .5588 .45698 L 0 .034 .135 r
F
.55605 .45781 m .5546 .45639 L .55735 .45557 L F
.60196 .45763 m .60334 .45541 L .60474 .45685 L F
.60196 .45763 m .60056 .45621 L .60334 .45541 L F
.43915 .45726 m .44028 .45503 L .44184 .45651 L 0 .033 .134 r
F
.43915 .45726 m .43758 .45578 L .44028 .45503 L F
.37512 .45612 m .37616 .45356 L .37778 .45526 L 0 .03 .13 r
F
.37512 .45612 m .3735 .45441 L .37616 .45356 L F
.35005 .45519 m .35105 .4527 L .3527 .45426 L 0 .028 .127 r
F
.35005 .45519 m .3484 .45361 L .35105 .4527 L F
.68264 .45558 m .68411 .45307 L .68544 .4546 L 0 .029 .128 r
F
.68264 .45558 m .6813 .45405 L .68411 .45307 L F
.66873 .45635 m .67019 .45383 L .67154 .45542 L 0 .03 .13 r
F
.66873 .45635 m .66739 .45475 L .67019 .45383 L F
.74245 .45463 m .74402 .45212 L .7453 .45375 L 0 .027 .126 r
F
.74245 .45463 m .74117 .45298 L .74402 .45212 L F
.67569 .456 m .67716 .4535 L .67849 .45503 L 0 .03 .13 r
F
.67569 .456 m .67435 .45446 L .67716 .4535 L F
.84819 .4535 m .8499 .45097 L .85109 .45259 L 0 .024 .123 r
F
.84819 .4535 m .84701 .45187 L .8499 .45097 L F
.68959 .45524 m .69109 .45292 L .69241 .45444 L 0 .028 .128 r
F
.68959 .45524 m .68826 .45372 L .69109 .45292 L F
.47811 .45756 m .4793 .455 L .48083 .45663 L 0 .033 .134 r
F
.47811 .45756 m .47659 .45591 L .4793 .455 L F
.31803 .45471 m .31898 .45234 L .32065 .45389 L 0 .027 .126 r
F
.31803 .45471 m .31635 .45318 L .31898 .45234 L F
.41408 .45644 m .41517 .45407 L .41676 .45566 L 0 .031 .131 r
F
.41408 .45644 m .41249 .45488 L .41517 .45407 L F
.51013 .45818 m .51136 .4559 L .51286 .45728 L 0 .035 .136 r
F
.51013 .45818 m .50863 .45679 L .51136 .4559 L F
.563 .45761 m .56431 .45532 L .56576 .45681 L 0 .034 .135 r
F
.563 .45761 m .56155 .45615 L .56431 .45532 L F
.79533 .45418 m .79698 .45183 L .79821 .45335 L 0 .026 .125 r
F
.79533 .45418 m .79411 .45266 L .79698 .45183 L F
.50318 .45862 m .5044 .45631 L .50591 .45772 L 0 .036 .137 r
F
.50318 .45862 m .50168 .4572 L .5044 .45631 L F
.60892 .45749 m .6103 .45527 L .6117 .45671 L 0 .034 .135 r
F
.60892 .45749 m .60752 .45606 L .6103 .45527 L F
.51708 .45788 m .51833 .45561 L .51981 .45701 L 0 .034 .136 r
F
.51708 .45788 m .51559 .45644 L .51833 .45561 L F
.35699 .45501 m .358 .4527 L .35964 .45423 L 0 .028 .127 r
F
.35699 .45501 m .35535 .45347 L .358 .4527 L F
.85516 .45332 m .85689 .45088 L .85807 .45249 L 0 .024 .123 r
F
.85516 .45332 m .85399 .45171 L .85689 .45088 L F
.48506 .45738 m .48626 .45508 L .48778 .45673 L 0 .033 .134 r
F
.48506 .45738 m .48354 .45575 L .48626 .45508 L F
.52403 .45758 m .52529 .45536 L .52677 .45677 L 0 .034 .135 r
F
.52403 .45758 m .52255 .45618 L .52529 .45536 L F
.74942 .4545 m .75099 .45199 L .75227 .45359 L 0 .027 .126 r
F
.74942 .4545 m .74815 .45288 L .75099 .45199 L F
.8023 .45394 m .80394 .45145 L .80516 .45299 L 0 .025 .124 r
F
.8023 .45394 m .80107 .4524 L .80394 .45145 L F
.38205 .45609 m .3831 .45369 L .38471 .45538 L 0 .03 .13 r
F
.38205 .45609 m .38044 .45439 L .3831 .45369 L F
.27904 .45475 m .27995 .45224 L .28165 .45387 L 0 .027 .127 r
F
.27904 .45475 m .27733 .45314 L .27995 .45224 L F
.69655 .45516 m .69806 .45281 L .69938 .45432 L 0 .028 .128 r
F
.69655 .45516 m .69523 .45364 L .69806 .45281 L F
.44609 .45729 m .44723 .45496 L .44879 .45646 L 0 .033 .134 r
F
.44609 .45729 m .44453 .45577 L .44723 .45496 L F
.75638 .45421 m .75796 .4517 L .75923 .45325 L 0 .026 .125 r
F
.75638 .45421 m .75511 .45265 L .75796 .4517 L F
.61588 .45733 m .61726 .45485 L .61866 .45633 L 0 .033 .134 r
F
.61588 .45733 m .61448 .45584 L .61726 .45485 L F
.62283 .45695 m .62422 .45435 L .62561 .45597 L 0 .032 .133 r
F
.62283 .45695 m .62144 .45534 L .62422 .45435 L F
.80926 .45368 m .81092 .45119 L .81214 .45281 L 0 .025 .124 r
F
.80926 .45368 m .80804 .45208 L .81092 .45119 L F
.32496 .45465 m .32592 .4522 L .32759 .45379 L 0 .027 .127 r
F
.32496 .45465 m .32329 .45308 L .32592 .4522 L F
.56996 .45755 m .57128 .45511 L .57271 .45671 L 0 .034 .135 r
F
.56996 .45755 m .56851 .45598 L .57128 .45511 L F
.76334 .4539 m .76494 .45157 L .7662 .4531 L 0 .026 .125 r
F
.76334 .4539 m .76208 .45238 L .76494 .45157 L F
.42102 .45641 m .42213 .4539 L .4237 .45551 L 0 .031 .131 r
F
.42102 .45641 m .41944 .45481 L .42213 .4539 L F
.62978 .4566 m .63118 .45405 L .63257 .45568 L 0 .031 .132 r
F
.62978 .4566 m .6284 .45498 L .63118 .45405 L F
.53098 .45744 m .53225 .45505 L .53372 .45656 L 0 .034 .135 r
F
.53098 .45744 m .52951 .45596 L .53225 .45505 L F
.86214 .45323 m .86389 .45083 L .86505 .45239 L 0 .024 .123 r
F
.86214 .45323 m .86098 .45166 L .86389 .45083 L F
.45304 .45709 m .45419 .45471 L .45574 .45619 L 0 .033 .134 r
F
.45304 .45709 m .45149 .45559 L .45419 .45471 L F
.28597 .45459 m .28689 .45203 L .28859 .4537 L 0 .027 .126 r
F
.28597 .45459 m .28427 .45294 L .28689 .45203 L F
.70352 .45498 m .70503 .45262 L .70634 .45412 L 0 .028 .128 r
F
.70352 .45498 m .7022 .45348 L .70503 .45262 L F
.36392 .45506 m .36494 .45265 L .36657 .45428 L F
.36392 .45506 m .36229 .45344 L .36494 .45265 L F
.63674 .45642 m .63816 .45412 L .63953 .45563 L 0 .032 .132 r
F
.63674 .45642 m .63536 .4549 L .63816 .45412 L F
.42796 .45624 m .42907 .45394 L .43064 .45558 L 0 .031 .132 r
F
.42796 .45624 m .42639 .45462 L .42907 .45394 L F
.33189 .45452 m .33287 .45201 L .33453 .45362 L 0 .027 .126 r
F
.33189 .45452 m .33023 .4529 L .33287 .45201 L F
.81624 .4536 m .8179 .45105 L .81911 .4527 L 0 .025 .124 r
F
.81624 .4536 m .81502 .45193 L .8179 .45105 L F
.45998 .45689 m .46114 .45472 L .46269 .45613 L 0 .033 .134 r
F
.45998 .45689 m .45844 .45546 L .46114 .45472 L F
.57691 .45748 m .57824 .45501 L .57967 .4566 L 0 .034 .135 r
F
.57691 .45748 m .57548 .45586 L .57824 .45501 L F
.77031 .45381 m .77192 .45146 L .77317 .45298 L 0 .026 .125 r
F
.77031 .45381 m .76906 .45229 L .77192 .45146 L F
.86912 .45307 m .87088 .45069 L .87203 .45221 L 0 .024 .123 r
F
.86912 .45307 m .86796 .45154 L .87088 .45069 L F
.71048 .45481 m .712 .45238 L .71331 .45395 L 0 .028 .128 r
F
.71048 .45481 m .70917 .45325 L .712 .45238 L F
.53794 .45737 m .53921 .45484 L .54068 .45653 L 0 .034 .135 r
F
.53794 .45737 m .53646 .45569 L .53921 .45484 L F
.6437 .45627 m .64513 .45403 L .6465 .45545 L 0 .032 .132 r
F
.6437 .45627 m .64233 .45483 L .64513 .45403 L F
.82321 .45342 m .82488 .45088 L .82609 .45249 L 0 .025 .124 r
F
.82321 .45342 m .822 .45179 L .82488 .45088 L F
.87609 .45286 m .87785 .45044 L .879 .452 L 0 .024 .122 r
F
.87609 .45286 m .87494 .45132 L .87785 .45044 L F
.38898 .45634 m .39004 .45387 L .39164 .45553 L 0 .031 .132 r
F
.38898 .45634 m .38737 .45467 L .39004 .45387 L F
.58387 .45732 m .58521 .45484 L .58663 .45642 L 0 .034 .135 r
F
.58387 .45732 m .58244 .45571 L .58521 .45484 L F
.2929 .45462 m .29382 .45219 L .29551 .45388 L 0 .028 .127 r
F
.2929 .45462 m .2912 .45295 L .29382 .45219 L F
.49201 .45773 m .49321 .45538 L .49472 .45706 L 0 .035 .136 r
F
.49201 .45773 m .49049 .45607 L .49321 .45538 L F
.83016 .4531 m .83185 .45059 L .83305 .45217 L 0 .025 .123 r
F
.83016 .4531 m .82897 .45154 L .83185 .45059 L F
.77728 .45372 m .7789 .45128 L .78015 .45285 L 0 .026 .125 r
F
.77728 .45372 m .77604 .45214 L .7789 .45128 L F
.65066 .45603 m .6521 .45369 L .65346 .45511 L 0 .031 .132 r
F
.65066 .45603 m .6493 .45463 L .6521 .45369 L F
.33882 .4545 m .3398 .4522 L .34146 .45377 L 0 .028 .127 r
F
.33882 .4545 m .33717 .45291 L .3398 .4522 L F
.71745 .4547 m .71898 .45232 L .72029 .4539 L 0 .028 .128 r
F
.71745 .4547 m .71614 .45313 L .71898 .45232 L F
.65761 .45571 m .65906 .45328 L .66042 .45484 L 0 .03 .131 r
F
.65761 .45571 m .65626 .45419 L .65906 .45328 L F
.46693 .45691 m .4681 .45442 L .46964 .45603 L 0 .033 .134 r
F
.46693 .45691 m .46539 .45531 L .4681 .45442 L F
.83713 .45287 m .83884 .45047 L .84003 .45203 L 0 .024 .123 r
F
.83713 .45287 m .83594 .4513 L .83884 .45047 L F
.39592 .45616 m .397 .45359 L .3986 .45519 L 0 .031 .132 r
F
.39592 .45616 m .39432 .45456 L .397 .45359 L F
.37084 .45522 m .37188 .45268 L .3735 .45441 L 0 .029 .129 r
F
.37084 .45522 m .36922 .45349 L .37188 .45268 L F
.59082 .45716 m .59217 .45466 L .59359 .45625 L 0 .034 .135 r
F
.59082 .45716 m .5894 .45554 L .59217 .45466 L F
.26085 .45426 m .26174 .45167 L .26346 .45332 L 0 .027 .126 r
F
.26085 .45426 m .25913 .45261 L .26174 .45167 L F
.54489 .45735 m .54617 .45485 L .54764 .45649 L 0 .034 .135 r
F
.54489 .45735 m .54343 .45569 L .54617 .45485 L F
.40287 .45583 m .40395 .45339 L .40555 .45496 L 0 .031 .131 r
F
.40287 .45583 m .40127 .45427 L .40395 .45339 L F
.2678 .45394 m .26869 .45148 L .27041 .45307 L 0 .027 .126 r
F
.2678 .45394 m .26608 .45237 L .26869 .45148 L F
.4349 .45646 m .43602 .4543 L .43758 .45578 L 0 .033 .133 r
F
.4349 .45646 m .43333 .45496 L .43602 .4543 L F
.78426 .45358 m .78588 .4511 L .78712 .45271 L 0 .026 .125 r
F
.78426 .45358 m .78301 .45198 L .78588 .4511 L F
.29983 .45457 m .30076 .45212 L .30245 .45365 L 0 .028 .128 r
F
.29983 .45457 m .29813 .45304 L .30076 .45212 L F
.73137 .45419 m .73292 .45171 L .7342 .45324 L 0 .027 .127 r
F
.73137 .45419 m .73008 .45267 L .73292 .45171 L F
.66458 .45557 m .66603 .45313 L .66739 .45475 L 0 .03 .131 r
F
.66458 .45557 m .66322 .45398 L .66603 .45313 L F
.72442 .45461 m .72596 .45211 L .72725 .45364 L 0 .028 .128 r
F
.72442 .45461 m .72312 .45308 L .72596 .45211 L F
.30677 .45425 m .30771 .45184 L .3094 .45338 L 0 .028 .127 r
F
.30677 .45425 m .30508 .45272 L .30771 .45184 L F
.73833 .45388 m .73989 .4514 L .74117 .45298 L 0 .027 .126 r
F
.73833 .45388 m .73704 .45232 L .73989 .4514 L F
.55185 .45719 m .55314 .45492 L .5546 .45639 L 0 .034 .135 r
F
.55185 .45719 m .55039 .4557 L .55314 .45492 L F
.59778 .45701 m .59914 .45458 L .60056 .45621 L F
.59778 .45701 m .59637 .45541 L .59914 .45458 L F
.84411 .45276 m .84582 .4503 L .84701 .45187 L 0 .024 .123 r
F
.84411 .45276 m .84293 .45119 L .84582 .4503 L F
.47388 .45682 m .47506 .45425 L .47659 .45591 L 0 .033 .134 r
F
.47388 .45682 m .47235 .45515 L .47506 .45425 L F
.34575 .45452 m .34675 .45207 L .3484 .45361 L 0 .028 .128 r
F
.34575 .45452 m .3441 .45297 L .34675 .45207 L F
.40981 .45569 m .4109 .45326 L .41249 .45488 L 0 .031 .131 r
F
.40981 .45569 m .40822 .4541 L .4109 .45326 L F
.68544 .4546 m .68693 .4522 L .68826 .45372 L 0 .028 .128 r
F
.68544 .4546 m .68411 .45307 L .68693 .4522 L F
.49895 .45789 m .50017 .45565 L .50168 .4572 L 0 .036 .138 r
F
.49895 .45789 m .49745 .45635 L .50017 .45565 L F
.31372 .45404 m .31467 .45164 L .31635 .45318 L 0 .027 .127 r
F
.31372 .45404 m .31203 .45251 L .31467 .45164 L F
.79123 .45348 m .79287 .45107 L .79411 .45266 L 0 .026 .125 r
F
.79123 .45348 m .79 .45188 L .79287 .45107 L F
.67849 .45503 m .67997 .45252 L .6813 .45405 L 0 .029 .129 r
F
.67849 .45503 m .67716 .4535 L .67997 .45252 L F
.3527 .45426 m .3537 .45192 L .35535 .45347 L 0 .028 .127 r
F
.3527 .45426 m .35105 .4527 L .3537 .45192 L F
.67154 .45542 m .673 .45289 L .67435 .45446 L 0 .03 .13 r
F
.67154 .45542 m .67019 .45383 L .673 .45289 L F
.5588 .45698 m .56011 .4547 L .56155 .45615 L 0 .034 .135 r
F
.5588 .45698 m .55735 .45557 L .56011 .4547 L F
.27473 .4539 m .27562 .45152 L .27733 .45314 L 0 .027 .126 r
F
.27473 .4539 m .27301 .45229 L .27562 .45152 L F
.37778 .45526 m .37883 .45272 L .38044 .45439 L 0 .03 .13 r
F
.37778 .45526 m .37616 .45356 L .37883 .45272 L F
.48083 .45663 m .48202 .45412 L .48354 .45575 L 0 .033 .134 r
F
.48083 .45663 m .4793 .455 L .48202 .45412 L F
.85109 .45259 m .85281 .4501 L .85399 .45171 L 0 .024 .122 r
F
.85109 .45259 m .8499 .45097 L .85281 .4501 L F
.7453 .45375 m .74687 .45126 L .74815 .45288 L 0 .027 .126 r
F
.7453 .45375 m .74402 .45212 L .74687 .45126 L F
.60474 .45685 m .60612 .4546 L .60752 .45606 L 0 .034 .135 r
F
.60474 .45685 m .60334 .45541 L .60612 .4546 L F
.51286 .45728 m .5141 .4551 L .51559 .45644 L 0 .035 .136 r
F
.51286 .45728 m .51136 .4559 L .5141 .4551 L F
.44184 .45651 m .44297 .45427 L .44453 .45577 L 0 .033 .134 r
F
.44184 .45651 m .44028 .45503 L .44297 .45427 L F
.50591 .45772 m .50713 .4554 L .50863 .45679 L 0 .036 .137 r
F
.50591 .45772 m .5044 .45631 L .50713 .4554 L F
.69241 .45444 m .69391 .45213 L .69523 .45364 L 0 .029 .128 r
F
.69241 .45444 m .69109 .45292 L .69391 .45213 L F
.32065 .45389 m .32161 .45151 L .32329 .45308 L 0 .027 .127 r
F
.32065 .45389 m .31898 .45234 L .32161 .45151 L F
.56576 .45681 m .56707 .45445 L .56851 .45598 L 0 .034 .135 r
F
.56576 .45681 m .56431 .45532 L .56707 .45445 L F
.41676 .45566 m .41786 .4532 L .41944 .45481 L 0 .031 .131 r
F
.41676 .45566 m .41517 .45407 L .41786 .4532 L F
.51981 .45701 m .52106 .45478 L .52255 .45618 L 0 .035 .136 r
F
.51981 .45701 m .51833 .45561 L .52106 .45478 L F
.79821 .45335 m .79985 .45086 L .80107 .4524 L 0 .026 .125 r
F
.79821 .45335 m .79698 .45183 L .79985 .45086 L F
.80516 .45299 m .80682 .45052 L .80804 .45208 L 0 .025 .124 r
F
.80516 .45299 m .80394 .45145 L .80682 .45052 L F
.75227 .45359 m .75384 .45107 L .75511 .45265 L 0 .026 .126 r
F
.75227 .45359 m .75099 .45199 L .75384 .45107 L F
.6117 .45671 m .61309 .45439 L .61448 .45584 L 0 .034 .135 r
F
.6117 .45671 m .6103 .45527 L .61309 .45439 L F
.61866 .45633 m .62005 .45387 L .62144 .45534 L 0 .033 .133 r
F
.61866 .45633 m .61726 .45485 L .62005 .45387 L F
.75923 .45325 m .76082 .45084 L .76208 .45238 L 0 .026 .125 r
F
.75923 .45325 m .75796 .4517 L .76082 .45084 L F
.85807 .45249 m .8598 .45006 L .86098 .45166 L 0 .024 .123 r
F
.85807 .45249 m .85689 .45088 L .8598 .45006 L F
.35964 .45423 m .36065 .45192 L .36229 .45344 L 0 .028 .128 r
F
.35964 .45423 m .358 .4527 L .36065 .45192 L F
.62561 .45597 m .62701 .45335 L .6284 .45498 L 0 .032 .132 r
F
.62561 .45597 m .62422 .45435 L .62701 .45335 L F
.28165 .45387 m .28257 .45129 L .28427 .45294 L 0 .027 .126 r
F
.28165 .45387 m .27995 .45224 L .28257 .45129 L F
.52677 .45677 m .52803 .45454 L .52951 .45596 L 0 .034 .135 r
F
.52677 .45677 m .52529 .45536 L .52803 .45454 L F
.69938 .45432 m .70089 .45198 L .7022 .45348 L 0 .029 .128 r
F
.69938 .45432 m .69806 .45281 L .70089 .45198 L F
.63257 .45568 m .63398 .45327 L .63536 .4549 L 0 .031 .132 r
F
.63257 .45568 m .63118 .45405 L .63398 .45327 L F
.44879 .45646 m .44993 .45411 L .45149 .45559 L 0 .033 .134 r
F
.44879 .45646 m .44723 .45496 L .44993 .45411 L F
.81214 .45281 m .8138 .4503 L .81502 .45193 L 0 .025 .124 r
F
.81214 .45281 m .81092 .45119 L .8138 .4503 L F
.4237 .45551 m .42482 .45298 L .42639 .45462 L 0 .031 .131 r
F
.4237 .45551 m .42213 .4539 L .42482 .45298 L F
.32759 .45379 m .32857 .45129 L .33023 .4529 L 0 .027 .127 r
F
.32759 .45379 m .32592 .4522 L .32857 .45129 L F
.57271 .45671 m .57404 .45425 L .57548 .45586 L 0 .034 .135 r
F
.57271 .45671 m .57128 .45511 L .57404 .45425 L F
.48778 .45673 m .48898 .45441 L .49049 .45607 L F
.48778 .45673 m .48626 .45508 L .48898 .45441 L F
.38471 .45538 m .38576 .45299 L .38737 .45467 L 0 .031 .131 r
F
.38471 .45538 m .3831 .45369 L .38576 .45299 L F
.53372 .45656 m .53499 .45415 L .53646 .45569 L 0 .034 .135 r
F
.53372 .45656 m .53225 .45505 L .53499 .45415 L F
.7662 .4531 m .76781 .45076 L .76906 .45229 L 0 .026 .125 r
F
.7662 .4531 m .76494 .45157 L .76781 .45076 L F
.45574 .45619 m .45689 .45401 L .45844 .45546 L 0 .033 .134 r
F
.45574 .45619 m .45419 .45471 L .45689 .45401 L F
.28859 .4537 m .28951 .45126 L .2912 .45295 L 0 .027 .127 r
F
.28859 .4537 m .28689 .45203 L .28951 .45126 L F
.86505 .45239 m .8668 .44999 L .86796 .45154 L 0 .025 .123 r
F
.86505 .45239 m .86389 .45083 L .8668 .44999 L F
.70634 .45412 m .70786 .45172 L .70917 .45325 L 0 .028 .128 r
F
.70634 .45412 m .70503 .45262 L .70786 .45172 L F
.33453 .45362 m .33551 .45131 L .33717 .45291 L 0 .027 .127 r
F
.33453 .45362 m .33287 .45201 L .33551 .45131 L F
.81911 .4527 m .82079 .45016 L .822 .45179 L 0 .025 .124 r
F
.81911 .4527 m .8179 .45105 L .82079 .45016 L F
.36657 .45428 m .3676 .45185 L .36922 .45349 L 0 .029 .128 r
F
.36657 .45428 m .36494 .45265 L .3676 .45185 L F
.63953 .45563 m .64096 .45333 L .64233 .45483 L 0 .032 .132 r
F
.63953 .45563 m .63816 .45412 L .64096 .45333 L F
.57967 .4566 m .58101 .45416 L .58244 .45571 L 0 .034 .135 r
F
.57967 .4566 m .57824 .45501 L .58101 .45416 L F
.77317 .45298 m .77479 .45063 L .77604 .45214 L 0 .026 .125 r
F
.77317 .45298 m .77192 .45146 L .77479 .45063 L F
.87203 .45221 m .87379 .44978 L .87494 .45132 L 0 .024 .123 r
F
.87203 .45221 m .87088 .45069 L .87379 .44978 L F
.71331 .45395 m .71484 .45155 L .71614 .45313 L 0 .028 .128 r
F
.71331 .45395 m .712 .45238 L .71484 .45155 L F
.46269 .45613 m .46385 .45392 L .46539 .45531 L 0 .033 .134 r
F
.46269 .45613 m .46114 .45472 L .46385 .45392 L F
.54068 .45653 m .54196 .45402 L .54343 .45569 L 0 .034 .135 r
F
.54068 .45653 m .53921 .45484 L .54196 .45402 L F
.82609 .45249 m .82776 .44994 L .82897 .45154 L 0 .025 .123 r
F
.82609 .45249 m .82488 .45088 L .82776 .44994 L F
.43064 .45558 m .43176 .4533 L .43333 .45496 L 0 .032 .133 r
F
.43064 .45558 m .42907 .45394 L .43176 .4533 L F
.83305 .45217 m .83475 .44973 L .83594 .4513 L 0 .024 .123 r
F
.83305 .45217 m .83185 .45059 L .83475 .44973 L F
.6465 .45545 m .64794 .45323 L .6493 .45463 L 0 .032 .132 r
F
.6465 .45545 m .64513 .45403 L .64794 .45323 L F
.58663 .45642 m .58798 .45399 L .5894 .45554 L 0 .034 .135 r
F
.58663 .45642 m .58521 .45484 L .58798 .45399 L F
.879 .452 m .88077 .44959 L .88192 .45117 L 0 .024 .122 r
F
.879 .452 m .87785 .45044 L .88077 .44959 L F
.65346 .45511 m .6549 .45275 L .65626 .45419 L 0 .031 .131 r
F
.65346 .45511 m .6521 .45369 L .6549 .45275 L F
.39164 .45553 m .39271 .45292 L .39432 .45456 L 0 .031 .132 r
F
.39164 .45553 m .39004 .45387 L .39271 .45292 L F
.78015 .45285 m .78177 .45039 L .78301 .45198 L 0 .026 .125 r
F
.78015 .45285 m .7789 .45128 L .78177 .45039 L F
.3986 .45519 m .39967 .4527 L .40127 .45427 L 0 .031 .131 r
F
.3986 .45519 m .397 .45359 L .39967 .4527 L F
.66042 .45484 m .66187 .45239 L .66322 .45398 L 0 .03 .131 r
F
.66042 .45484 m .65906 .45328 L .66187 .45239 L F
.29551 .45388 m .29644 .45134 L .29813 .45304 L 0 .028 .128 r
F
.29551 .45388 m .29382 .45219 L .29644 .45134 L F
.26346 .45332 m .26436 .45072 L .26608 .45237 L 0 .027 .126 r
F
.26346 .45332 m .26174 .45167 L .26436 .45072 L F
.72029 .4539 m .72182 .4515 L .72312 .45308 L 0 .028 .128 r
F
.72029 .4539 m .71898 .45232 L .72182 .4515 L F
.46964 .45603 m .47081 .45352 L .47235 .45515 L 0 .033 .134 r
F
.46964 .45603 m .4681 .45442 L .47081 .45352 L F
.59359 .45625 m .59495 .45381 L .59637 .45541 L 0 .034 .135 r
F
.59359 .45625 m .59217 .45466 L .59495 .45381 L F
.84003 .45203 m .84174 .44964 L .84293 .45119 L 0 .025 .123 r
F
.84003 .45203 m .83884 .45047 L .84174 .44964 L F
.34146 .45377 m .34245 .45141 L .3441 .45297 L 0 .028 .128 r
F
.34146 .45377 m .3398 .4522 L .34245 .45141 L F
.49472 .45706 m .49594 .45464 L .49745 .45635 L 0 .036 .137 r
F
.49472 .45706 m .49321 .45538 L .49594 .45464 L F
.54764 .45649 m .54893 .45408 L .55039 .4557 L 0 .034 .135 r
F
.54764 .45649 m .54617 .45485 L .54893 .45408 L F
.40555 .45496 m .40663 .4525 L .40822 .4541 L 0 .031 .131 r
F
.40555 .45496 m .40395 .45339 L .40663 .4525 L F
.7342 .45324 m .73576 .45076 L .73704 .45232 L 0 .027 .126 r
F
.7342 .45324 m .73292 .45171 L .73576 .45076 L F
.3735 .45441 m .37454 .45186 L .37616 .45356 L 0 .029 .129 r
F
.3735 .45441 m .37188 .45268 L .37454 .45186 L F
.72725 .45364 m .72879 .45113 L .73008 .45267 L 0 .028 .127 r
F
.72725 .45364 m .72596 .45211 L .72879 .45113 L F
.30245 .45365 m .30339 .45119 L .30508 .45272 L F
.30245 .45365 m .30076 .45212 L .30339 .45119 L F
.27041 .45307 m .27129 .45069 L .27301 .45229 L 0 .027 .126 r
F
.27041 .45307 m .26869 .45148 L .27129 .45069 L F
.78712 .45271 m .78876 .45027 L .79 .45188 L 0 .026 .125 r
F
.78712 .45271 m .78588 .4511 L .78876 .45027 L F
.74117 .45298 m .74274 .45054 L .74402 .45212 L 0 .027 .126 r
F
.74117 .45298 m .73989 .4514 L .74274 .45054 L F
.3094 .45338 m .31035 .45097 L .31203 .45251 L 0 .028 .127 r
F
.3094 .45338 m .30771 .45184 L .31035 .45097 L F
.66739 .45475 m .66884 .45222 L .67019 .45383 L 0 .03 .131 r
F
.66739 .45475 m .66603 .45313 L .66884 .45222 L F
.47659 .45591 m .47778 .45335 L .4793 .455 L 0 .033 .134 r
F
.47659 .45591 m .47506 .45425 L .47778 .45335 L F
.84701 .45187 m .84872 .4494 L .8499 .45097 L 0 .024 .123 r
F
.84701 .45187 m .84582 .4503 L .84872 .4494 L F
.3484 .45361 m .34941 .45116 L .35105 .4527 L 0 .028 .128 r
F
.3484 .45361 m .34675 .45207 L .34941 .45116 L F
.43758 .45578 m .43871 .45354 L .44028 .45503 L 0 .033 .134 r
F
.43758 .45578 m .43602 .4543 L .43871 .45354 L F
.6813 .45405 m .68278 .45154 L .68411 .45307 L 0 .029 .129 r
F
.6813 .45405 m .67997 .45252 L .68278 .45154 L F
.5546 .45639 m .5559 .45412 L .55735 .45557 L 0 .035 .136 r
F
.5546 .45639 m .55314 .45492 L .5559 .45412 L F
.67435 .45446 m .67581 .45194 L .67716 .4535 L 0 .03 .13 r
F
.67435 .45446 m .673 .45289 L .67581 .45194 L F
.60056 .45621 m .60192 .45376 L .60334 .45541 L 0 .034 .135 r
F
.60056 .45621 m .59914 .45458 L .60192 .45376 L F
.68826 .45372 m .68976 .45141 L .69109 .45292 L 0 .029 .128 r
F
.68826 .45372 m .68693 .4522 L .68976 .45141 L F
.41249 .45488 m .41359 .45242 L .41517 .45407 L 0 .031 .131 r
F
.41249 .45488 m .4109 .45326 L .41359 .45242 L F
.31635 .45318 m .3173 .45078 L .31898 .45234 L 0 .027 .127 r
F
.31635 .45318 m .31467 .45164 L .3173 .45078 L F
.38044 .45439 m .38149 .45203 L .3831 .45369 L 0 .03 .13 r
F
.38044 .45439 m .37883 .45272 L .38149 .45203 L F
.48354 .45575 m .48474 .45345 L .48626 .45508 L 0 .033 .134 r
F
.48354 .45575 m .48202 .45412 L .48474 .45345 L F
.79411 .45266 m .79575 .45024 L .79698 .45183 L 0 .026 .125 r
F
.79411 .45266 m .79287 .45107 L .79575 .45024 L F
.85399 .45171 m .85572 .44928 L .85689 .45088 L 0 .024 .123 r
F
.85399 .45171 m .85281 .4501 L .85572 .44928 L F
.56155 .45615 m .56287 .45383 L .56431 .45532 L 0 .034 .135 r
F
.56155 .45615 m .56011 .4547 L .56287 .45383 L F
.74815 .45288 m .74972 .45039 L .75099 .45199 L 0 .027 .126 r
F
.74815 .45288 m .74687 .45126 L .74972 .45039 L F
.35535 .45347 m .35635 .45116 L .358 .4527 L 0 .028 .128 r
F
.35535 .45347 m .3537 .45192 L .35635 .45116 L F
.50863 .45679 m .50987 .45453 L .51136 .4559 L 0 .036 .137 r
F
.50863 .45679 m .50713 .4554 L .50987 .45453 L F
.27733 .45314 m .27824 .4506 L .27995 .45224 L 0 .027 .127 r
F
.27733 .45314 m .27562 .45152 L .27824 .4506 L F
.50168 .4572 m .5029 .45478 L .5044 .45631 L 0 .037 .138 r
F
.50168 .4572 m .50017 .45565 L .5029 .45478 L F
.51559 .45644 m .51683 .45429 L .51833 .45561 L 0 .035 .137 r
F
.51559 .45644 m .5141 .4551 L .51683 .45429 L F
.60752 .45606 m .6089 .45379 L .6103 .45527 L 0 .034 .135 r
F
.60752 .45606 m .60612 .4546 L .6089 .45379 L F
.80107 .4524 m .80272 .4499 L .80394 .45145 L 0 .026 .125 r
F
.80107 .4524 m .79985 .45086 L .80272 .4499 L F
.62144 .45534 m .62283 .45288 L .62422 .45435 L 0 .032 .133 r
F
.62144 .45534 m .62005 .45387 L .62283 .45288 L F
.75511 .45265 m .7567 .45014 L .75796 .4517 L 0 .026 .125 r
F
.75511 .45265 m .75384 .45107 L .7567 .45014 L F
.80804 .45208 m .8097 .44962 L .81092 .45119 L 0 .025 .124 r
F
.80804 .45208 m .80682 .45052 L .8097 .44962 L F
.6284 .45498 m .6298 .45241 L .63118 .45405 L 0 .031 .132 r
F
.6284 .45498 m .62701 .45335 L .6298 .45241 L F
.69523 .45364 m .69674 .45131 L .69806 .45281 L 0 .029 .129 r
F
.69523 .45364 m .69391 .45213 L .69674 .45131 L F
.44453 .45577 m .44567 .45347 L .44723 .45496 L 0 .034 .135 r
F
.44453 .45577 m .44297 .45427 L .44567 .45347 L F
.41944 .45481 m .42055 .45226 L .42213 .4539 L 0 .031 .131 r
F
.41944 .45481 m .41786 .4532 L .42055 .45226 L F
.32329 .45308 m .32425 .45061 L .32592 .4522 L 0 .027 .127 r
F
.32329 .45308 m .32161 .45151 L .32425 .45061 L F
.56851 .45598 m .56983 .45355 L .57128 .45511 L 0 .034 .135 r
F
.56851 .45598 m .56707 .45445 L .56983 .45355 L F
.52255 .45618 m .5238 .45396 L .52529 .45536 L 0 .035 .136 r
F
.52255 .45618 m .52106 .45478 L .5238 .45396 L F
.28427 .45294 m .28519 .45036 L .28689 .45203 L 0 .027 .126 r
F
.28427 .45294 m .28257 .45129 L .28519 .45036 L F
.61448 .45584 m .61587 .45342 L .61726 .45485 L 0 .034 .135 r
F
.61448 .45584 m .61309 .45439 L .61587 .45342 L F
.76208 .45238 m .76368 .45003 L .76494 .45157 L 0 .026 .125 r
F
.76208 .45238 m .76082 .45084 L .76368 .45003 L F
.86098 .45166 m .86272 .44923 L .86389 .45083 L 0 .025 .123 r
F
.86098 .45166 m .8598 .45006 L .86272 .44923 L F
.36229 .45344 m .3633 .45113 L .36494 .45265 L 0 .029 .128 r
F
.36229 .45344 m .36065 .45192 L .3633 .45113 L F
.52951 .45596 m .53077 .45362 L .53225 .45505 L 0 .034 .135 r
F
.52951 .45596 m .52803 .45454 L .53077 .45362 L F
.42639 .45462 m .4275 .45229 L .42907 .45394 L 0 .031 .132 r
F
.42639 .45462 m .42482 .45298 L .4275 .45229 L F
.45149 .45559 m .45263 .45326 L .45419 .45471 L 0 .033 .134 r
F
.45149 .45559 m .44993 .45411 L .45263 .45326 L F
.33023 .4529 m .33121 .45039 L .33287 .45201 L 0 .027 .126 r
F
.33023 .4529 m .32857 .45129 L .33121 .45039 L F
.81502 .45193 m .81668 .44943 L .8179 .45105 L 0 .025 .124 r
F
.81502 .45193 m .8138 .4503 L .81668 .44943 L F
.7022 .45348 m .70372 .45112 L .70503 .45262 L 0 .029 .128 r
F
.7022 .45348 m .70089 .45198 L .70372 .45112 L F
.63536 .4549 m .63678 .45249 L .63816 .45412 L 0 .032 .132 r
F
.63536 .4549 m .63398 .45327 L .63678 .45249 L F
.57548 .45586 m .57681 .45343 L .57824 .45501 L 0 .034 .135 r
F
.57548 .45586 m .57404 .45425 L .57681 .45343 L F
.53646 .45569 m .53774 .4533 L .53921 .45484 L F
.53646 .45569 m .53499 .45415 L .53774 .4533 L F
.70917 .45325 m .71069 .45082 L .712 .45238 L 0 .028 .128 r
F
.70917 .45325 m .70786 .45172 L .71069 .45082 L F
.76906 .45229 m .77067 .44994 L .77192 .45146 L 0 .026 .125 r
F
.76906 .45229 m .76781 .45076 L .77067 .44994 L F
.86796 .45154 m .86972 .44914 L .87088 .45069 L 0 .025 .123 r
F
.86796 .45154 m .8668 .44999 L .86972 .44914 L F
.38737 .45467 m .38843 .45222 L .39004 .45387 L 0 .031 .132 r
F
.38737 .45467 m .38576 .45299 L .38843 .45222 L F
.2912 .45295 m .29213 .45049 L .29382 .45219 L 0 .028 .127 r
F
.2912 .45295 m .28951 .45126 L .29213 .45049 L F
.45844 .45546 m .45959 .45332 L .46114 .45472 L 0 .034 .135 r
F
.45844 .45546 m .45689 .45401 L .45959 .45332 L F
.822 .45179 m .82367 .44926 L .82488 .45088 L 0 .025 .124 r
F
.822 .45179 m .82079 .45016 L .82367 .44926 L F
.49049 .45607 m .4917 .4537 L .49321 .45538 L 0 .035 .136 r
F
.49049 .45607 m .48898 .45441 L .4917 .4537 L F
.58244 .45571 m .58378 .45332 L .58521 .45484 L 0 .034 .135 r
F
.58244 .45571 m .58101 .45416 L .58378 .45332 L F
.87494 .45132 m .8767 .44888 L .87785 .45044 L 0 .024 .123 r
F
.87494 .45132 m .87379 .44978 L .8767 .44888 L F
.82897 .45154 m .83065 .44899 L .83185 .45059 L 0 .025 .123 r
F
.82897 .45154 m .82776 .44994 L .83065 .44899 L F
.64233 .45483 m .64376 .45255 L .64513 .45403 L 0 .032 .133 r
F
.64233 .45483 m .64096 .45333 L .64376 .45255 L F
.77604 .45214 m .77766 .44976 L .7789 .45128 L 0 .026 .125 r
F
.77604 .45214 m .77479 .45063 L .77766 .44976 L F
.36922 .45349 m .37026 .45105 L .37188 .45268 L 0 .029 .129 r
F
.36922 .45349 m .3676 .45185 L .37026 .45105 L F
.33717 .45291 m .33815 .45061 L .3398 .4522 L 0 .028 .127 r
F
.33717 .45291 m .33551 .45131 L .33815 .45061 L F
.71614 .45313 m .71768 .45073 L .71898 .45232 L 0 .028 .128 r
F
.71614 .45313 m .71484 .45155 L .71768 .45073 L F
.54343 .45569 m .54471 .4532 L .54617 .45485 L 0 .034 .135 r
F
.54343 .45569 m .54196 .45402 L .54471 .4532 L F
.25913 .45261 m .26002 .44998 L .26174 .45167 L 0 .027 .126 r
F
.25913 .45261 m .25741 .4509 L .26002 .44998 L F
.46539 .45531 m .46656 .45301 L .4681 .45442 L 0 .033 .134 r
F
.46539 .45531 m .46385 .45392 L .46656 .45301 L F
.39432 .45456 m .39539 .45197 L .397 .45359 L 0 .031 .132 r
F
.39432 .45456 m .39271 .45292 L .39539 .45197 L F
.65626 .45419 m .6577 .45182 L .65906 .45328 L 0 .031 .131 r
F
.65626 .45419 m .6549 .45275 L .6577 .45182 L F
.5894 .45554 m .59075 .45314 L .59217 .45466 L 0 .034 .135 r
F
.5894 .45554 m .58798 .45399 L .59075 .45314 L F
.83594 .4513 m .83765 .4489 L .83884 .45047 L 0 .025 .123 r
F
.83594 .4513 m .83475 .44973 L .83765 .4489 L F
.6493 .45463 m .65074 .45227 L .6521 .45369 L 0 .032 .132 r
F
.6493 .45463 m .64794 .45323 L .65074 .45227 L F
.88192 .45117 m .8837 .44878 L .88485 .45037 L 0 .024 .123 r
F
.88192 .45117 m .88077 .44959 L .8837 .44878 L F
.40127 .45427 m .40235 .45183 L .40395 .45339 L 0 .031 .131 r
F
.40127 .45427 m .39967 .4527 L .40235 .45183 L F
.78301 .45198 m .78464 .4495 L .78588 .4511 L 0 .026 .125 r
F
.78301 .45198 m .78177 .45039 L .78464 .4495 L F
.26608 .45237 m .26697 .44984 L .26869 .45148 L 0 .027 .126 r
F
.26608 .45237 m .26436 .45072 L .26697 .44984 L F
.66322 .45398 m .66468 .4515 L .66603 .45313 L 0 .03 .131 r
F
.66322 .45398 m .66187 .45239 L .66468 .4515 L F
.47235 .45515 m .47353 .45263 L .47506 .45425 L 0 .033 .134 r
F
.47235 .45515 m .47081 .45352 L .47353 .45263 L F
.43333 .45496 m .43445 .45262 L .43602 .4543 L F
.43333 .45496 m .43176 .4533 L .43445 .45262 L F
.29813 .45304 m .29907 .45042 L .30076 .45212 L 0 .028 .128 r
F
.29813 .45304 m .29644 .45134 L .29907 .45042 L F
.73008 .45267 m .73163 .45016 L .73292 .45171 L 0 .027 .127 r
F
.73008 .45267 m .72879 .45113 L .73163 .45016 L F
.72312 .45308 m .72466 .45054 L .72596 .45211 L 0 .028 .128 r
F
.72312 .45308 m .72182 .4515 L .72466 .45054 L F
.59637 .45541 m .59773 .45295 L .59914 .45458 L 0 .034 .135 r
F
.59637 .45541 m .59495 .45381 L .59773 .45295 L F
.73704 .45232 m .7386 .44981 L .73989 .4514 L 0 .027 .126 r
F
.73704 .45232 m .73576 .45076 L .7386 .44981 L F
.30508 .45272 m .30602 .45031 L .30771 .45184 L 0 .028 .127 r
F
.30508 .45272 m .30339 .45119 L .30602 .45031 L F
.84293 .45119 m .84464 .44874 L .84582 .4503 L 0 .025 .123 r
F
.84293 .45119 m .84174 .44964 L .84464 .44874 L F
.40822 .4541 m .40931 .45163 L .4109 .45326 L 0 .031 .131 r
F
.40822 .4541 m .40663 .4525 L .40931 .45163 L F
.3441 .45297 m .3451 .45052 L .34675 .45207 L 0 .028 .128 r
F
.3441 .45297 m .34245 .45141 L .3451 .45052 L F
.37616 .45356 m .37721 .45104 L .37883 .45272 L 0 .029 .129 r
F
.37616 .45356 m .37454 .45186 L .37721 .45104 L F
.55039 .4557 m .55168 .45332 L .55314 .45492 L 0 .035 .136 r
F
.55039 .4557 m .54893 .45408 L .55168 .45332 L F
.79 .45188 m .79164 .44947 L .79287 .45107 L 0 .026 .125 r
F
.79 .45188 m .78876 .45027 L .79164 .44947 L F
.67019 .45383 m .67165 .45129 L .673 .45289 L 0 .03 .13 r
F
.67019 .45383 m .66884 .45222 L .67165 .45129 L F
.4793 .455 m .4805 .45249 L .48202 .45412 L 0 .033 .134 r
F
.4793 .455 m .47778 .45335 L .4805 .45249 L F
.27301 .45229 m .2739 .4499 L .27562 .45152 L 0 .027 .126 r
F
.27301 .45229 m .27129 .45069 L .2739 .4499 L F
.49745 .45635 m .49866 .45391 L .50017 .45565 L 0 .036 .138 r
F
.49745 .45635 m .49594 .45464 L .49866 .45391 L F
.68411 .45307 m .6856 .45068 L .68693 .4522 L 0 .029 .129 r
F
.68411 .45307 m .68278 .45154 L .6856 .45068 L F
.74402 .45212 m .74559 .44969 L .74687 .45126 L 0 .027 .126 r
F
.74402 .45212 m .74274 .45054 L .74559 .44969 L F
.31203 .45251 m .31298 .45009 L .31467 .45164 L 0 .028 .127 r
F
.31203 .45251 m .31035 .45097 L .31298 .45009 L F
.35105 .4527 m .35205 .45039 L .3537 .45192 L 0 .028 .128 r
F
.35105 .4527 m .34941 .45116 L .35205 .45039 L F
.8499 .45097 m .85163 .44853 L .85281 .4501 L 0 .024 .123 r
F
.8499 .45097 m .84872 .4494 L .85163 .44853 L F
.67716 .4535 m .67863 .45097 L .67997 .45252 L 0 .03 .13 r
F
.67716 .4535 m .67581 .45194 L .67863 .45097 L F
.55735 .45557 m .55865 .45321 L .56011 .4547 L 0 .035 .136 r
F
.55735 .45557 m .5559 .45412 L .55865 .45321 L F
.60334 .45541 m .6047 .45291 L .60612 .4546 L 0 .034 .135 r
F
.60334 .45541 m .60192 .45376 L .6047 .45291 L F
.44028 .45503 m .44141 .45278 L .44297 .45427 L F
.44028 .45503 m .43871 .45354 L .44141 .45278 L F
.41517 .45407 m .41627 .45153 L .41786 .4532 L 0 .031 .131 r
F
.41517 .45407 m .41359 .45242 L .41627 .45153 L F
.31898 .45234 m .31994 .44992 L .32161 .45151 L 0 .027 .127 r
F
.31898 .45234 m .3173 .45078 L .31994 .44992 L F
.69109 .45292 m .69259 .45063 L .69391 .45213 L 0 .029 .129 r
F
.69109 .45292 m .68976 .45141 L .69259 .45063 L F
.75099 .45199 m .75257 .44948 L .75384 .45107 L 0 .027 .126 r
F
.75099 .45199 m .74972 .45039 L .75257 .44948 L F
.79698 .45183 m .79862 .44928 L .79985 .45086 L 0 .026 .125 r
F
.79698 .45183 m .79575 .45024 L .79862 .44928 L F
.62422 .45435 m .62562 .45189 L .62701 .45335 L 0 .032 .132 r
F
.62422 .45435 m .62283 .45288 L .62562 .45189 L F
.80394 .45145 m .8056 .44896 L .80682 .45052 L 0 .026 .124 r
F
.80394 .45145 m .80272 .4499 L .8056 .44896 L F
.56431 .45532 m .56563 .45292 L .56707 .45445 L 0 .034 .135 r
F
.56431 .45532 m .56287 .45383 L .56563 .45292 L F
.51136 .4559 m .5126 .45375 L .5141 .4551 L 0 .036 .137 r
F
.51136 .4559 m .50987 .45453 L .5126 .45375 L F
.27995 .45224 m .28086 .44963 L .28257 .45129 L 0 .027 .126 r
F
.27995 .45224 m .27824 .4506 L .28086 .44963 L F
.85689 .45088 m .85863 .44845 L .8598 .45006 L 0 .024 .123 r
F
.85689 .45088 m .85572 .44928 L .85863 .44845 L F
.5044 .45631 m .50563 .45389 L .50713 .4554 L 0 .037 .138 r
F
.5044 .45631 m .5029 .45478 L .50563 .45389 L F
.75796 .4517 m .75956 .44928 L .76082 .45084 L 0 .026 .125 r
F
.75796 .4517 m .7567 .45014 L .75956 .44928 L F
.63118 .45405 m .63259 .45164 L .63398 .45327 L 0 .031 .132 r
F
.63118 .45405 m .6298 .45241 L .63259 .45164 L F
.358 .4527 m .35901 .4504 L .36065 .45192 L 0 .029 .128 r
F
.358 .4527 m .35635 .45116 L .35901 .4504 L F
.51833 .45561 m .51957 .45345 L .52106 .45478 L 0 .035 .137 r
F
.51833 .45561 m .51683 .45429 L .51957 .45345 L F
.3831 .45369 m .38415 .45136 L .38576 .45299 L 0 .031 .131 r
F
.3831 .45369 m .38149 .45203 L .38415 .45136 L F
.61726 .45485 m .61865 .45245 L .62005 .45387 L 0 .033 .134 r
F
.61726 .45485 m .61587 .45342 L .61865 .45245 L F
.81092 .45119 m .81258 .44871 L .8138 .4503 L 0 .025 .124 r
F
.81092 .45119 m .8097 .44962 L .81258 .44871 L F
.42213 .4539 m .42324 .45133 L .42482 .45298 L 0 .031 .131 r
F
.42213 .4539 m .42055 .45226 L .42324 .45133 L F
.6103 .45527 m .61168 .4529 L .61309 .45439 L 0 .034 .135 r
F
.6103 .45527 m .6089 .45379 L .61168 .4529 L F
.48626 .45508 m .48746 .45278 L .48898 .45441 L F
.48626 .45508 m .48474 .45345 L .48746 .45278 L F
.32592 .4522 m .3269 .44968 L .32857 .45129 L 0 .027 .127 r
F
.32592 .4522 m .32425 .45061 L .3269 .44968 L F
.57128 .45511 m .5726 .45265 L .57404 .45425 L 0 .034 .135 r
F
.57128 .45511 m .56983 .45355 L .5726 .45265 L F
.28689 .45203 m .28781 .44957 L .28951 .45126 L 0 .027 .126 r
F
.28689 .45203 m .28519 .45036 L .28781 .44957 L F
.69806 .45281 m .69957 .45049 L .70089 .45198 L 0 .029 .129 r
F
.69806 .45281 m .69674 .45131 L .69957 .45049 L F
.44723 .45496 m .44837 .45264 L .44993 .45411 L 0 .034 .135 r
F
.44723 .45496 m .44567 .45347 L .44837 .45264 L F
.52529 .45536 m .52654 .45312 L .52803 .45454 L 0 .035 .136 r
F
.52529 .45536 m .5238 .45396 L .52654 .45312 L F
.76494 .45157 m .76655 .44921 L .76781 .45076 L 0 .026 .125 r
F
.76494 .45157 m .76368 .45003 L .76655 .44921 L F
.53225 .45505 m .53352 .45271 L .53499 .45415 L 0 .034 .135 r
F
.53225 .45505 m .53077 .45362 L .53352 .45271 L F
.86389 .45083 m .86564 .4484 L .8668 .44999 L 0 .025 .123 r
F
.86389 .45083 m .86272 .44923 L .86564 .4484 L F
.45419 .45471 m .45534 .45257 L .45689 .45401 L 0 .034 .135 r
F
.45419 .45471 m .45263 .45326 L .45534 .45257 L F
.33287 .45201 m .33385 .44966 L .33551 .45131 L 0 .027 .127 r
F
.33287 .45201 m .33121 .45039 L .33385 .44966 L F
.8179 .45105 m .81957 .44855 L .82079 .45016 L 0 .025 .124 r
F
.8179 .45105 m .81668 .44943 L .81957 .44855 L F
.70503 .45262 m .70655 .45019 L .70786 .45172 L 0 .029 .128 r
F
.70503 .45262 m .70372 .45112 L .70655 .45019 L F
.36494 .45265 m .36596 .45033 L .3676 .45185 L 0 .029 .129 r
F
.36494 .45265 m .3633 .45113 L .36596 .45033 L F
.57824 .45501 m .57958 .45261 L .58101 .45416 L 0 .034 .135 r
F
.57824 .45501 m .57681 .45343 L .57958 .45261 L F
.53921 .45484 m .54049 .45251 L .54196 .45402 L F
.53921 .45484 m .53774 .4533 L .54049 .45251 L F
.712 .45238 m .71353 .44997 L .71484 .45155 L 0 .028 .128 r
F
.712 .45238 m .71069 .45082 L .71353 .44997 L F
.63816 .45412 m .63958 .45171 L .64096 .45333 L 0 .032 .133 r
F
.63816 .45412 m .63678 .45249 L .63958 .45171 L F
.42907 .45394 m .43019 .45162 L .43176 .4533 L 0 .032 .132 r
F
.42907 .45394 m .4275 .45229 L .43019 .45162 L F
.87088 .45069 m .87263 .44823 L .87379 .44978 L 0 .025 .123 r
F
.87088 .45069 m .86972 .44914 L .87263 .44823 L F
.82488 .45088 m .82656 .44833 L .82776 .44994 L F
.82488 .45088 m .82367 .44926 L .82656 .44833 L F
.77192 .45146 m .77354 .44911 L .77479 .45063 L 0 .026 .126 r
F
.77192 .45146 m .77067 .44994 L .77354 .44911 L F
.39004 .45387 m .39111 .45128 L .39271 .45292 L 0 .031 .132 r
F
.39004 .45387 m .38843 .45222 L .39111 .45128 L F
.58521 .45484 m .58655 .45251 L .58798 .45399 L 0 .034 .135 r
F
.58521 .45484 m .58378 .45332 L .58655 .45251 L F
.83185 .45059 m .83355 .44813 L .83475 .44973 L 0 .025 .123 r
F
.83185 .45059 m .83065 .44899 L .83355 .44813 L F
.87785 .45044 m .87962 .44802 L .88077 .44959 L 0 .024 .123 r
F
.87785 .45044 m .8767 .44888 L .87962 .44802 L F
.29382 .45219 m .29475 .44964 L .29644 .45134 L 0 .028 .127 r
F
.29382 .45219 m .29213 .45049 L .29475 .44964 L F
.46114 .45472 m .4623 .45253 L .46385 .45392 L 0 .034 .135 r
F
.46114 .45472 m .45959 .45332 L .4623 .45253 L F
.397 .45359 m .39807 .45111 L .39967 .4527 L 0 .031 .131 r
F
.397 .45359 m .39539 .45197 L .39807 .45111 L F
.26174 .45167 m .26263 .44906 L .26436 .45072 L 0 .027 .126 r
F
.26174 .45167 m .26002 .44998 L .26263 .44906 L F
.7789 .45128 m .78053 .44885 L .78177 .45039 L 0 .026 .125 r
F
.7789 .45128 m .77766 .44976 L .78053 .44885 L F
.49321 .45538 m .49442 .45293 L .49594 .45464 L 0 .035 .137 r
F
.49321 .45538 m .4917 .4537 L .49442 .45293 L F
.4681 .45442 m .46928 .4521 L .47081 .45352 L 0 .033 .134 r
F
.4681 .45442 m .46656 .45301 L .46928 .4521 L F
.64513 .45403 m .64657 .45176 L .64794 .45323 L 0 .032 .133 r
F
.64513 .45403 m .64376 .45255 L .64657 .45176 L F
.37188 .45268 m .37292 .45023 L .37454 .45186 L 0 .029 .129 r
F
.37188 .45268 m .37026 .45105 L .37292 .45023 L F
.65906 .45328 m .66051 .4509 L .66187 .45239 L 0 .031 .131 r
F
.65906 .45328 m .6577 .45182 L .66051 .4509 L F
.71898 .45232 m .72052 .44991 L .72182 .4515 L 0 .028 .128 r
F
.71898 .45232 m .71768 .45073 L .72052 .44991 L F
.6521 .45369 m .65354 .45131 L .6549 .45275 L 0 .032 .132 r
F
.6521 .45369 m .65074 .45227 L .65354 .45131 L F
.54617 .45485 m .54746 .45245 L .54893 .45408 L 0 .034 .135 r
F
.54617 .45485 m .54471 .4532 L .54746 .45245 L F
.59217 .45466 m .59353 .45227 L .59495 .45381 L F
.59217 .45466 m .59075 .45314 L .59353 .45227 L F
.3398 .4522 m .34079 .44983 L .34245 .45141 L 0 .028 .128 r
F
.3398 .4522 m .33815 .45061 L .34079 .44983 L F
.83884 .45047 m .84055 .44808 L .84174 .44964 L 0 .025 .123 r
F
.83884 .45047 m .83765 .4489 L .84055 .44808 L F
.40395 .45339 m .40503 .45096 L .40663 .4525 L 0 .031 .131 r
F
.40395 .45339 m .40235 .45183 L .40503 .45096 L F
.26869 .45148 m .26957 .44906 L .27129 .45069 L 0 .027 .126 r
F
.26869 .45148 m .26697 .44984 L .26957 .44906 L F
.78588 .4511 m .78752 .44867 L .78876 .45027 L 0 .026 .125 r
F
.78588 .4511 m .78464 .4495 L .78752 .44867 L F
.73292 .45171 m .73447 .4492 L .73576 .45076 L 0 .027 .127 r
F
.73292 .45171 m .73163 .45016 L .73447 .4492 L F
.88485 .45037 m .88663 .44796 L .88778 .44956 L 0 .025 .123 r
F
.88485 .45037 m .8837 .44878 L .88663 .44796 L F
.72596 .45211 m .7275 .44958 L .72879 .45113 L 0 .028 .128 r
F
.72596 .45211 m .72466 .45054 L .7275 .44958 L F
.30076 .45212 m .30171 .44949 L .30339 .45119 L 0 .028 .127 r
F
.30076 .45212 m .29907 .45042 L .30171 .44949 L F
.47506 .45425 m .47625 .45174 L .47778 .45335 L 0 .033 .134 r
F
.47506 .45425 m .47353 .45263 L .47625 .45174 L F
.66603 .45313 m .66749 .45059 L .66884 .45222 L 0 .03 .131 r
F
.66603 .45313 m .66468 .4515 L .66749 .45059 L F
.73989 .4514 m .74145 .44895 L .74274 .45054 L 0 .027 .126 r
F
.73989 .4514 m .7386 .44981 L .74145 .44895 L F
.84582 .4503 m .84754 .44785 L .84872 .4494 L 0 .025 .123 r
F
.84582 .4503 m .84464 .44874 L .84754 .44785 L F
.30771 .45184 m .30866 .44943 L .31035 .45097 L 0 .028 .127 r
F
.30771 .45184 m .30602 .45031 L .30866 .44943 L F
.34675 .45207 m .34775 .44963 L .34941 .45116 L 0 .028 .128 r
F
.34675 .45207 m .3451 .45052 L .34775 .44963 L F
.59914 .45458 m .60051 .4521 L .60192 .45376 L 0 .034 .135 r
F
.59914 .45458 m .59773 .45295 L .60051 .4521 L F
.4109 .45326 m .412 .45076 L .41359 .45242 L 0 .031 .131 r
F
.4109 .45326 m .40931 .45163 L .412 .45076 L F
.673 .45289 m .67447 .45035 L .67581 .45194 L 0 .03 .13 r
F
.673 .45289 m .67165 .45129 L .67447 .45035 L F
.67997 .45252 m .68144 .44999 L .68278 .45154 L 0 .029 .129 r
F
.67997 .45252 m .67863 .45097 L .68144 .44999 L F
.37883 .45272 m .37987 .45038 L .38149 .45203 L 0 .03 .13 r
F
.37883 .45272 m .37721 .45104 L .37987 .45038 L F
.43602 .4543 m .43715 .45184 L .43871 .45354 L 0 .033 .134 r
F
.43602 .4543 m .43445 .45262 L .43715 .45184 L F
.48202 .45412 m .48322 .45182 L .48474 .45345 L F
.48202 .45412 m .4805 .45249 L .48322 .45182 L F
.68693 .4522 m .68843 .4499 L .68976 .45141 L 0 .029 .129 r
F
.68693 .4522 m .6856 .45068 L .68843 .4499 L F
.55314 .45492 m .55444 .45252 L .5559 .45412 L 0 .035 .136 r
F
.55314 .45492 m .55168 .45332 L .55444 .45252 L F
.31467 .45164 m .31562 .44921 L .3173 .45078 L 0 .028 .127 r
F
.31467 .45164 m .31298 .45009 L .31562 .44921 L F
.74687 .45126 m .74845 .44883 L .74972 .45039 L 0 .027 .126 r
F
.74687 .45126 m .74559 .44969 L .74845 .44883 L F
.85281 .4501 m .85454 .4477 L .85572 .44928 L 0 .024 .123 r
F
.85281 .4501 m .85163 .44853 L .85454 .4477 L F
.79287 .45107 m .79452 .44864 L .79575 .45024 L 0 .026 .125 r
F
.79287 .45107 m .79164 .44947 L .79452 .44864 L F
.27562 .45152 m .27653 .44895 L .27824 .4506 L 0 .027 .126 r
F
.27562 .45152 m .2739 .4499 L .27653 .44895 L F
.3537 .45192 m .35471 .44964 L .35635 .45116 L 0 .028 .128 r
F
.3537 .45192 m .35205 .45039 L .35471 .44964 L F
.50017 .45565 m .50139 .45306 L .5029 .45478 L 0 .037 .138 r
F
.50017 .45565 m .49866 .45391 L .50139 .45306 L F
.56011 .4547 m .56142 .4523 L .56287 .45383 L 0 .035 .136 r
F
.56011 .4547 m .55865 .45321 L .56142 .4523 L F
.62701 .45335 m .62841 .45096 L .6298 .45241 L 0 .032 .132 r
F
.62701 .45335 m .62562 .45189 L .62841 .45096 L F
.79985 .45086 m .8015 .44832 L .80272 .4499 L 0 .026 .125 r
F
.79985 .45086 m .79862 .44928 L .8015 .44832 L F
.75384 .45107 m .75543 .44857 L .7567 .45014 L 0 .026 .126 r
F
.75384 .45107 m .75257 .44948 L .75543 .44857 L F
.41786 .4532 m .41897 .45058 L .42055 .45226 L 0 .031 .131 r
F
.41786 .4532 m .41627 .45153 L .41897 .45058 L F
.28257 .45129 m .28349 .44868 L .28519 .45036 L 0 .027 .126 r
F
.28257 .45129 m .28086 .44963 L .28349 .44868 L F
.80682 .45052 m .80848 .44804 L .8097 .44962 L 0 .025 .124 r
F
.80682 .45052 m .8056 .44896 L .80848 .44804 L F
.32161 .45151 m .32258 .44901 L .32425 .45061 L 0 .027 .127 r
F
.32161 .45151 m .31994 .44992 L .32258 .44901 L F
.60612 .4546 m .60749 .45207 L .6089 .45379 L 0 .034 .135 r
F
.60612 .4546 m .6047 .45291 L .60749 .45207 L F
.50713 .4554 m .50837 .45304 L .50987 .45453 L 0 .037 .138 r
F
.50713 .4554 m .50563 .45389 L .50837 .45304 L F
.56707 .45445 m .56839 .45199 L .56983 .45355 L 0 .034 .135 r
F
.56707 .45445 m .56563 .45292 L .56839 .45199 L F
.62005 .45387 m .62144 .45147 L .62283 .45288 L 0 .033 .134 r
F
.62005 .45387 m .61865 .45245 L .62144 .45147 L F
.69391 .45213 m .69542 .44983 L .69674 .45131 L 0 .029 .129 r
F
.69391 .45213 m .69259 .45063 L .69542 .44983 L F
.44297 .45427 m .44411 .45199 L .44567 .45347 L 0 .034 .135 r
F
.44297 .45427 m .44141 .45278 L .44411 .45199 L F
.8598 .45006 m .86155 .44763 L .86272 .44923 L 0 .025 .123 r
F
.8598 .45006 m .85863 .44845 L .86155 .44763 L F
.76082 .45084 m .76242 .44847 L .76368 .45003 L 0 .026 .125 r
F
.76082 .45084 m .75956 .44928 L .76242 .44847 L F
.5141 .4551 m .51534 .45297 L .51683 .45429 L 0 .036 .138 r
F
.5141 .4551 m .5126 .45375 L .51534 .45297 L F
.42482 .45298 m .42593 .45062 L .4275 .45229 L 0 .031 .131 r
F
.42482 .45298 m .42324 .45133 L .42593 .45062 L F
.8138 .4503 m .81547 .44783 L .81668 .44943 L 0 .025 .124 r
F
.8138 .4503 m .81258 .44871 L .81547 .44783 L F
.32857 .45129 m .32955 .44876 L .33121 .45039 L 0 .027 .126 r
F
.32857 .45129 m .3269 .44968 L .32955 .44876 L F
.61309 .45439 m .61447 .45195 L .61587 .45342 L 0 .034 .135 r
F
.61309 .45439 m .61168 .4529 L .61447 .45195 L F
.52106 .45478 m .52231 .45258 L .5238 .45396 L 0 .036 .137 r
F
.52106 .45478 m .51957 .45345 L .52231 .45258 L F
.63398 .45327 m .6354 .45086 L .63678 .45249 L 0 .032 .132 r
F
.63398 .45327 m .63259 .45164 L .6354 .45086 L F
.36065 .45192 m .36166 .4496 L .3633 .45113 L 0 .029 .129 r
F
.36065 .45192 m .35901 .4504 L .36166 .4496 L F
.57404 .45425 m .57537 .45185 L .57681 .45343 L 0 .034 .135 r
F
.57404 .45425 m .5726 .45265 L .57537 .45185 L F
.70089 .45198 m .70241 .44963 L .70372 .45112 L 0 .029 .129 r
F
.70089 .45198 m .69957 .45049 L .70241 .44963 L F
.44993 .45411 m .45108 .45182 L .45263 .45326 L 0 .034 .135 r
F
.44993 .45411 m .44837 .45264 L .45108 .45182 L F
.52803 .45454 m .52929 .45219 L .53077 .45362 L 0 .035 .136 r
F
.52803 .45454 m .52654 .45312 L .52929 .45219 L F
.38576 .45299 m .38682 .4506 L .38843 .45222 L 0 .031 .132 r
F
.38576 .45299 m .38415 .45136 L .38682 .4506 L F
.53499 .45415 m .53626 .45186 L .53774 .4533 L 0 .034 .135 r
F
.53499 .45415 m .53352 .45271 L .53626 .45186 L F
.28951 .45126 m .29043 .44879 L .29213 .45049 L 0 .027 .127 r
F
.28951 .45126 m .28781 .44957 L .29043 .44879 L F
.82079 .45016 m .82246 .44766 L .82367 .44926 L 0 .025 .124 r
F
.82079 .45016 m .81957 .44855 L .82246 .44766 L F
.48898 .45441 m .49018 .45206 L .4917 .4537 L 0 .035 .136 r
F
.48898 .45441 m .48746 .45278 L .49018 .45206 L F
.70786 .45172 m .70938 .44927 L .71069 .45082 L 0 .028 .128 r
F
.70786 .45172 m .70655 .45019 L .70938 .44927 L F
.76781 .45076 m .76942 .4484 L .77067 .44994 L 0 .027 .126 r
F
.76781 .45076 m .76655 .44921 L .76942 .4484 L F
.8668 .44999 m .86855 .44756 L .86972 .44914 L 0 .025 .123 r
F
.8668 .44999 m .86564 .4484 L .86855 .44756 L F
.58101 .45416 m .58235 .4518 L .58378 .45332 L 0 .034 .135 r
F
.58101 .45416 m .57958 .45261 L .58235 .4518 L F
.3676 .45185 m .36862 .44951 L .37026 .45105 L 0 .029 .129 r
F
.3676 .45185 m .36596 .45033 L .36862 .44951 L F
.25741 .4509 m .25829 .44829 L .26002 .44998 L 0 .027 .126 r
F
.25741 .4509 m .25568 .4492 L .25829 .44829 L F
.82776 .44994 m .82945 .44739 L .83065 .44899 L 0 .025 .123 r
F
.82776 .44994 m .82656 .44833 L .82945 .44739 L F
.45689 .45401 m .45804 .45189 L .45959 .45332 L 0 .034 .135 r
F
.45689 .45401 m .45534 .45257 L .45804 .45189 L F
.33551 .45131 m .33649 .44894 L .33815 .45061 L 0 .028 .127 r
F
.33551 .45131 m .33385 .44966 L .33649 .44894 L F
.54196 .45402 m .54324 .45172 L .54471 .4532 L 0 .034 .135 r
F
.54196 .45402 m .54049 .45251 L .54324 .45172 L F
.87379 .44978 m .87554 .44731 L .8767 .44888 L 0 .025 .123 r
F
.87379 .44978 m .87263 .44823 L .87554 .44731 L F
.71484 .45155 m .71637 .44913 L .71768 .45073 L 0 .028 .128 r
F
.71484 .45155 m .71353 .44997 L .71637 .44913 L F
.39271 .45292 m .39379 .45034 L .39539 .45197 L 0 .031 .132 r
F
.39271 .45292 m .39111 .45128 L .39379 .45034 L F
.77479 .45063 m .77641 .44825 L .77766 .44976 L 0 .027 .126 r
F
.77479 .45063 m .77354 .44911 L .77641 .44825 L F
.64096 .45333 m .64239 .45093 L .64376 .45255 L 0 .032 .133 r
F
.64096 .45333 m .63958 .45171 L .64239 .45093 L F
.83475 .44973 m .83645 .44732 L .83765 .4489 L 0 .025 .123 r
F
.83475 .44973 m .83355 .44813 L .83645 .44732 L F
.58798 .45399 m .58933 .45169 L .59075 .45314 L 0 .034 .135 r
F
.58798 .45399 m .58655 .45251 L .58933 .45169 L F
.26436 .45072 m .26525 .44819 L .26697 .44984 L 0 .027 .126 r
F
.26436 .45072 m .26263 .44906 L .26525 .44819 L F
.88077 .44959 m .88255 .44719 L .8837 .44878 L 0 .025 .123 r
F
.88077 .44959 m .87962 .44802 L .88255 .44719 L F
.39967 .4527 m .40075 .45028 L .40235 .45183 L 0 .031 .132 r
F
.39967 .4527 m .39807 .45111 L .40075 .45028 L F
.29644 .45134 m .29738 .44871 L .29907 .45042 L 0 .028 .127 r
F
.29644 .45134 m .29475 .44964 L .29738 .44871 L F
.78177 .45039 m .7834 .44794 L .78464 .4495 L 0 .026 .125 r
F
.78177 .45039 m .78053 .44885 L .7834 .44794 L F
.43176 .4533 m .43288 .45092 L .43445 .45262 L 0 .033 .133 r
F
.43176 .4533 m .43019 .45162 L .43288 .45092 L F
.47081 .45352 m .47199 .45121 L .47353 .45263 L 0 .033 .134 r
F
.47081 .45352 m .46928 .4521 L .47199 .45121 L F
.6549 .45275 m .65635 .45036 L .6577 .45182 L 0 .031 .132 r
F
.6549 .45275 m .65354 .45131 L .65635 .45036 L F
.46385 .45392 m .46502 .4516 L .46656 .45301 L 0 .034 .135 r
F
.46385 .45392 m .4623 .45253 L .46502 .4516 L F
.66187 .45239 m .66332 .44999 L .66468 .4515 L 0 .031 .131 r
F
.66187 .45239 m .66051 .4509 L .66332 .44999 L F
.37454 .45186 m .37559 .44941 L .37721 .45104 L 0 .029 .129 r
F
.37454 .45186 m .37292 .45023 L .37559 .44941 L F
.59495 .45381 m .59631 .45139 L .59773 .45295 L 0 .034 .135 r
F
.59495 .45381 m .59353 .45227 L .59631 .45139 L F
.64794 .45323 m .64937 .45078 L .65074 .45227 L 0 .032 .133 r
F
.64794 .45323 m .64657 .45176 L .64937 .45078 L F
.72182 .4515 m .72336 .44896 L .72466 .45054 L 0 .028 .128 r
F
.72182 .4515 m .72052 .44991 L .72336 .44896 L F
.72879 .45113 m .73034 .44861 L .73163 .45016 L 0 .028 .127 r
F
.72879 .45113 m .7275 .44958 L .73034 .44861 L F
.73576 .45076 m .73732 .44823 L .7386 .44981 L 0 .027 .126 r
F
.73576 .45076 m .73447 .4492 L .73732 .44823 L F
.40663 .4525 m .40772 .45009 L .40931 .45163 L 0 .031 .131 r
F
.40663 .4525 m .40503 .45096 L .40772 .45009 L F
.49594 .45464 m .49715 .45216 L .49866 .45391 L 0 .036 .137 r
F
.49594 .45464 m .49442 .45293 L .49715 .45216 L F
.54893 .45408 m .55022 .45171 L .55168 .45332 L 0 .035 .136 r
F
.54893 .45408 m .54746 .45245 L .55022 .45171 L F
.84174 .44964 m .84346 .44719 L .84464 .44874 L 0 .025 .123 r
F
.84174 .44964 m .84055 .44808 L .84346 .44719 L F
.30339 .45119 m .30434 .44861 L .30602 .45031 L 0 .028 .127 r
F
.30339 .45119 m .30171 .44949 L .30434 .44861 L F
.34245 .45141 m .34344 .44894 L .3451 .45052 L 0 .029 .128 r
F
.34245 .45141 m .34079 .44983 L .34344 .44894 L F
.47778 .45335 m .47897 .45089 L .4805 .45249 L 0 .033 .134 r
F
.47778 .45335 m .47625 .45174 L .47897 .45089 L F
.78876 .45027 m .7904 .44786 L .79164 .44947 L 0 .026 .125 r
F
.78876 .45027 m .78752 .44867 L .7904 .44786 L F
.66884 .45222 m .6703 .44969 L .67165 .45129 L 0 .03 .13 r
F
.66884 .45222 m .66749 .45059 L .6703 .44969 L F
.27129 .45069 m .27218 .44827 L .2739 .4499 L 0 .027 .126 r
F
.27129 .45069 m .26957 .44906 L .27218 .44827 L F
.88778 .44956 m .88955 .44703 L .8907 .44864 L 0 .025 .123 r
F
.88778 .44956 m .88663 .44796 L .88955 .44703 L F
.74274 .45054 m .74431 .44812 L .74559 .44969 L 0 .027 .126 r
F
.74274 .45054 m .74145 .44895 L .74431 .44812 L F
.84872 .4494 m .85045 .44698 L .85163 .44853 L 0 .025 .123 r
F
.84872 .4494 m .84754 .44785 L .85045 .44698 L F
.68278 .45154 m .68427 .44913 L .6856 .45068 L 0 .029 .129 r
F
.68278 .45154 m .68144 .44999 L .68427 .44913 L F
.31035 .45097 m .31129 .44854 L .31298 .45009 L 0 .028 .127 r
F
.31035 .45097 m .30866 .44943 L .31129 .44854 L F
.67581 .45194 m .67728 .44939 L .67863 .45097 L 0 .03 .13 r
F
.67581 .45194 m .67447 .45035 L .67728 .44939 L F
.34941 .45116 m .3504 .44886 L .35205 .45039 L 0 .028 .128 r
F
.34941 .45116 m .34775 .44963 L .3504 .44886 L F
.60192 .45376 m .60329 .45122 L .6047 .45291 L 0 .034 .135 r
F
.60192 .45376 m .60051 .4521 L .60329 .45122 L F
.41359 .45242 m .41469 .44985 L .41627 .45153 L 0 .031 .131 r
F
.41359 .45242 m .412 .45076 L .41469 .44985 L F
.74972 .45039 m .7513 .44793 L .75257 .44948 L 0 .027 .126 r
F
.74972 .45039 m .74845 .44883 L .7513 .44793 L F
.3173 .45078 m .31826 .44833 L .31994 .44992 L 0 .028 .127 r
F
.3173 .45078 m .31562 .44921 L .31826 .44833 L F
.27824 .4506 m .27916 .44796 L .28086 .44963 L 0 .027 .126 r
F
.27824 .4506 m .27653 .44895 L .27916 .44796 L F
.79575 .45024 m .79739 .44769 L .79862 .44928 L 0 .026 .125 r
F
.79575 .45024 m .79452 .44864 L .79739 .44769 L F
.85572 .44928 m .85745 .44686 L .85863 .44845 L 0 .025 .123 r
F
.85572 .44928 m .85454 .4477 L .85745 .44686 L F
.5559 .45412 m .5572 .45159 L .55865 .45321 L 0 .035 .136 r
F
.5559 .45412 m .55444 .45252 L .5572 .45159 L F
.43871 .45354 m .43985 .45106 L .44141 .45278 L 0 .034 .135 r
F
.43871 .45354 m .43715 .45184 L .43985 .45106 L F
.68976 .45141 m .69126 .44912 L .69259 .45063 L 0 .029 .129 r
F
.68976 .45141 m .68843 .4499 L .69126 .44912 L F
.6298 .45241 m .63121 .45017 L .63259 .45164 L 0 .032 .132 r
F
.6298 .45241 m .62841 .45096 L .63121 .45017 L F
.80272 .4499 m .80438 .44738 L .8056 .44896 L 0 .026 .125 r
F
.80272 .4499 m .8015 .44832 L .80438 .44738 L F
.38149 .45203 m .38253 .44972 L .38415 .45136 L 0 .031 .131 r
F
.38149 .45203 m .37987 .45038 L .38253 .44972 L F
.7567 .45014 m .75829 .44772 L .75956 .44928 L 0 .026 .126 r
F
.7567 .45014 m .75543 .44857 L .75829 .44772 L F
.5029 .45478 m .50413 .45221 L .50563 .45389 L 0 .037 .138 r
F
.5029 .45478 m .50139 .45306 L .50413 .45221 L F
.42055 .45226 m .42166 .44964 L .42324 .45133 L 0 .031 .131 r
F
.42055 .45226 m .41897 .45058 L .42166 .44964 L F
.56287 .45383 m .56418 .45136 L .56563 .45292 L 0 .035 .136 r
F
.56287 .45383 m .56142 .4523 L .56418 .45136 L F
.48474 .45345 m .48594 .45116 L .48746 .45278 L 0 .034 .135 r
F
.48474 .45345 m .48322 .45182 L .48594 .45116 L F
.28519 .45036 m .28611 .44788 L .28781 .44957 L 0 .027 .126 r
F
.28519 .45036 m .28349 .44868 L .28611 .44788 L F
.62283 .45288 m .62423 .4505 L .62562 .45189 L 0 .033 .133 r
F
.62283 .45288 m .62144 .45147 L .62423 .4505 L F
.8097 .44962 m .81136 .44711 L .81258 .44871 L 0 .025 .124 r
F
.8097 .44962 m .80848 .44804 L .81136 .44711 L F
.35635 .45116 m .35736 .44888 L .35901 .4504 L 0 .029 .129 r
F
.35635 .45116 m .35471 .44964 L .35736 .44888 L F
.32425 .45061 m .32523 .44806 L .3269 .44968 L 0 .027 .127 r
F
.32425 .45061 m .32258 .44901 L .32523 .44806 L F
.56983 .45355 m .57116 .45105 L .5726 .45265 L 0 .034 .135 r
F
.56983 .45355 m .56839 .45199 L .57116 .45105 L F
.50987 .45453 m .5111 .4523 L .5126 .45375 L 0 .037 .138 r
F
.50987 .45453 m .50837 .45304 L .5111 .4523 L F
.6089 .45379 m .61028 .45119 L .61168 .4529 L 0 .034 .136 r
F
.6089 .45379 m .60749 .45207 L .61028 .45119 L F
.61587 .45342 m .61726 .451 L .61865 .45245 L 0 .034 .135 r
F
.61587 .45342 m .61447 .45195 L .61726 .451 L F
.69674 .45131 m .69826 .44902 L .69957 .45049 L 0 .029 .129 r
F
.69674 .45131 m .69542 .44983 L .69826 .44902 L F
.44567 .45347 m .44681 .45118 L .44837 .45264 L 0 .034 .135 r
F
.44567 .45347 m .44411 .45199 L .44681 .45118 L F
.33121 .45039 m .33219 .44801 L .33385 .44966 L 0 .027 .127 r
F
.33121 .45039 m .32955 .44876 L .33219 .44801 L F
.86272 .44923 m .86447 .44681 L .86564 .4484 L 0 .025 .123 r
F
.86272 .44923 m .86155 .44763 L .86447 .44681 L F
.81668 .44943 m .81836 .44696 L .81957 .44855 L 0 .025 .124 r
F
.81668 .44943 m .81547 .44783 L .81836 .44696 L F
.76368 .45003 m .76529 .44765 L .76655 .44921 L 0 .027 .126 r
F
.76368 .45003 m .76242 .44847 L .76529 .44765 L F
.51683 .45429 m .51808 .45211 L .51957 .45345 L 0 .037 .138 r
F
.51683 .45429 m .51534 .45297 L .51808 .45211 L F
.5238 .45396 m .52506 .45171 L .52654 .45312 L 0 .036 .137 r
F
.5238 .45396 m .52231 .45258 L .52506 .45171 L F
.57681 .45343 m .57814 .45106 L .57958 .45261 L 0 .034 .135 r
F
.57681 .45343 m .57537 .45185 L .57814 .45106 L F
.53077 .45362 m .53204 .45125 L .53352 .45271 L 0 .035 .136 r
F
.53077 .45362 m .52929 .45219 L .53204 .45125 L F
.70372 .45112 m .70524 .44867 L .70655 .45019 L 0 .029 .129 r
F
.70372 .45112 m .70241 .44963 L .70524 .44867 L F
.3633 .45113 m .36432 .4488 L .36596 .45033 L F
.3633 .45113 m .36166 .4496 L .36432 .4488 L F
.4275 .45229 m .42862 .44993 L .43019 .45162 L 0 .032 .132 r
F
.4275 .45229 m .42593 .45062 L .42862 .44993 L F
.45263 .45326 m .45378 .45113 L .45534 .45257 L 0 .034 .135 r
F
.45263 .45326 m .45108 .45182 L .45378 .45113 L F
.63678 .45249 m .6382 .45009 L .63958 .45171 L 0 .032 .133 r
F
.63678 .45249 m .6354 .45086 L .6382 .45009 L F
.53774 .4533 m .53902 .4511 L .54049 .45251 L 0 .034 .135 r
F
.53774 .4533 m .53626 .45186 L .53902 .4511 L F
.82367 .44926 m .82535 .44673 L .82656 .44833 L 0 .025 .124 r
F
.82367 .44926 m .82246 .44766 L .82535 .44673 L F
.71069 .45082 m .71222 .44838 L .71353 .44997 L 0 .028 .128 r
F
.71069 .45082 m .70938 .44927 L .71222 .44838 L F
.38843 .45222 m .38949 .44969 L .39111 .45128 L 0 .031 .132 r
F
.38843 .45222 m .38682 .4506 L .38949 .44969 L F
.29213 .45049 m .29306 .44793 L .29475 .44964 L 0 .028 .127 r
F
.29213 .45049 m .29043 .44879 L .29306 .44793 L F
.86972 .44914 m .87147 .44665 L .87263 .44823 L 0 .025 .123 r
F
.86972 .44914 m .86855 .44756 L .87147 .44665 L F
.77067 .44994 m .77229 .44758 L .77354 .44911 L 0 .027 .126 r
F
.77067 .44994 m .76942 .4484 L .77229 .44758 L F
.83065 .44899 m .83235 .44654 L .83355 .44813 L 0 .025 .123 r
F
.83065 .44899 m .82945 .44739 L .83235 .44654 L F
.26002 .44998 m .26091 .44738 L .26263 .44906 L 0 .026 .126 r
F
.26002 .44998 m .25829 .44829 L .26091 .44738 L F
.4917 .4537 m .49291 .45128 L .49442 .45293 L 0 .035 .136 r
F
.4917 .4537 m .49018 .45206 L .49291 .45128 L F
.39539 .45197 m .39646 .44952 L .39807 .45111 L 0 .031 .132 r
F
.39539 .45197 m .39379 .45034 L .39646 .44952 L F
.58378 .45332 m .58513 .45102 L .58655 .45251 L 0 .034 .136 r
F
.58378 .45332 m .58235 .4518 L .58513 .45102 L F
.8767 .44888 m .87847 .44644 L .87962 .44802 L 0 .025 .123 r
F
.8767 .44888 m .87554 .44731 L .87847 .44644 L F
.37026 .45105 m .37129 .44868 L .37292 .45023 L 0 .029 .129 r
F
.37026 .45105 m .36862 .44951 L .37129 .44868 L F
.54471 .4532 m .546 .45099 L .54746 .45245 L 0 .034 .136 r
F
.54471 .4532 m .54324 .45172 L .546 .45099 L F
.77766 .44976 m .77928 .44731 L .78053 .44885 L 0 .026 .126 r
F
.77766 .44976 m .77641 .44825 L .77928 .44731 L F
.71768 .45073 m .71922 .44828 L .72052 .44991 L 0 .029 .128 r
F
.71768 .45073 m .71637 .44913 L .71922 .44828 L F
.33815 .45061 m .33914 .44813 L .34079 .44983 L 0 .028 .128 r
F
.33815 .45061 m .33649 .44894 L .33914 .44813 L F
.45959 .45332 m .46075 .4511 L .4623 .45253 L 0 .035 .136 r
F
.45959 .45332 m .45804 .45189 L .46075 .4511 L F
.29907 .45042 m .30002 .44778 L .30171 .44949 L 0 .028 .127 r
F
.29907 .45042 m .29738 .44871 L .30002 .44778 L F
.64376 .45255 m .6452 .45015 L .64657 .45176 L 0 .033 .134 r
F
.64376 .45255 m .64239 .45093 L .6452 .45015 L F
.26697 .44984 m .26785 .44742 L .26957 .44906 L 0 .027 .126 r
F
.26697 .44984 m .26525 .44819 L .26785 .44742 L F
.59075 .45314 m .59211 .4508 L .59353 .45227 L 0 .034 .135 r
F
.59075 .45314 m .58933 .45169 L .59211 .4508 L F
.83765 .4489 m .83936 .4465 L .84055 .44808 L 0 .025 .123 r
F
.83765 .4489 m .83645 .44732 L .83936 .4465 L F
.6577 .45182 m .65916 .44942 L .66051 .4509 L 0 .031 .132 r
F
.6577 .45182 m .65635 .45036 L .65916 .44942 L F
.78464 .4495 m .78627 .44708 L .78752 .44867 L 0 .026 .125 r
F
.78464 .4495 m .7834 .44794 L .78627 .44708 L F
.40235 .45183 m .40343 .44945 L .40503 .45096 L 0 .031 .132 r
F
.40235 .45183 m .40075 .45028 L .40343 .44945 L F
.46656 .45301 m .46773 .45067 L .46928 .4521 L 0 .034 .135 r
F
.46656 .45301 m .46502 .4516 L .46773 .45067 L F
.47353 .45263 m .47471 .45033 L .47625 .45174 L 0 .033 .134 r
F
.47353 .45263 m .47199 .45121 L .47471 .45033 L F
.8837 .44878 m .88548 .44636 L .88663 .44796 L 0 .025 .123 r
F
.8837 .44878 m .88255 .44719 L .88548 .44636 L F
.65074 .45227 m .65218 .4498 L .65354 .45131 L 0 .032 .133 r
F
.65074 .45227 m .64937 .45078 L .65218 .4498 L F
.66468 .4515 m .66614 .4491 L .66749 .45059 L 0 .031 .131 r
F
.66468 .4515 m .66332 .44999 L .66614 .4491 L F
.72466 .45054 m .7262 .44802 L .7275 .44958 L 0 .028 .128 r
F
.72466 .45054 m .72336 .44896 L .7262 .44802 L F
.73163 .45016 m .73318 .44765 L .73447 .4492 L 0 .027 .127 r
F
.73163 .45016 m .73034 .44861 L .73318 .44765 L F
.7386 .44981 m .74017 .44739 L .74145 .44895 L 0 .027 .126 r
F
.7386 .44981 m .73732 .44823 L .74017 .44739 L F
.59773 .45295 m .59909 .4505 L .60051 .4521 L 0 .034 .135 r
F
.59773 .45295 m .59631 .45139 L .59909 .4505 L F
.37721 .45104 m .37825 .44875 L .37987 .45038 L 0 .03 .13 r
F
.37721 .45104 m .37559 .44941 L .37825 .44875 L F
.40931 .45163 m .41041 .44921 L .412 .45076 L 0 .031 .131 r
F
.40931 .45163 m .40772 .45009 L .41041 .44921 L F
.84464 .44874 m .84636 .4463 L .84754 .44785 L 0 .025 .123 r
F
.84464 .44874 m .84346 .44719 L .84636 .4463 L F
.43445 .45262 m .43558 .45012 L .43715 .45184 L 0 .033 .134 r
F
.43445 .45262 m .43288 .45092 L .43558 .45012 L F
.30602 .45031 m .30697 .44774 L .30866 .44943 L 0 .028 .127 r
F
.30602 .45031 m .30434 .44861 L .30697 .44774 L F
.67165 .45129 m .67312 .44877 L .67447 .45035 L 0 .03 .13 r
F
.67165 .45129 m .6703 .44969 L .67312 .44877 L F
.3451 .45052 m .3461 .44805 L .34775 .44963 L 0 .028 .128 r
F
.3451 .45052 m .34344 .44894 L .3461 .44805 L F
.4805 .45249 m .48169 .45022 L .48322 .45182 L 0 .033 .134 r
F
.4805 .45249 m .47897 .45089 L .48169 .45022 L F
.8907 .44864 m .89247 .44609 L .89362 .4477 L 0 .024 .123 r
F
.8907 .44864 m .88955 .44703 L .89247 .44609 L F
.67863 .45097 m .6801 .44843 L .68144 .44999 L 0 .029 .129 r
F
.67863 .45097 m .67728 .44939 L .6801 .44843 L F
.55168 .45332 m .55298 .45093 L .55444 .45252 L 0 .035 .136 r
F
.55168 .45332 m .55022 .45171 L .55298 .45093 L F
.49866 .45391 m .49989 .45135 L .50139 .45306 L 0 .036 .138 r
F
.49866 .45391 m .49715 .45216 L .49989 .45135 L F
.79164 .44947 m .79328 .44704 L .79452 .44864 L 0 .026 .126 r
F
.79164 .44947 m .7904 .44786 L .79328 .44704 L F
.74559 .44969 m .74717 .44727 L .74845 .44883 L 0 .027 .126 r
F
.74559 .44969 m .74431 .44812 L .74717 .44727 L F
.85163 .44853 m .85336 .44612 L .85454 .4477 L 0 .025 .123 r
F
.85163 .44853 m .85045 .44698 L .85336 .44612 L F
.2739 .4499 m .27481 .44734 L .27653 .44895 L 0 .027 .127 r
F
.2739 .4499 m .27218 .44827 L .27481 .44734 L F
.31298 .45009 m .31394 .44764 L .31562 .44921 L 0 .028 .127 r
F
.31298 .45009 m .31129 .44854 L .31394 .44764 L F
.6856 .45068 m .6871 .44834 L .68843 .4499 L 0 .029 .129 r
F
.6856 .45068 m .68427 .44913 L .6871 .44834 L F
.41627 .45153 m .41738 .4489 L .41897 .45058 L 0 .031 .131 r
F
.41627 .45153 m .41469 .44985 L .41738 .4489 L F
.35205 .45039 m .35306 .44811 L .35471 .44964 L 0 .029 .129 r
F
.35205 .45039 m .3504 .44886 L .35306 .44811 L F
.28086 .44963 m .28178 .447 L .28349 .44868 L 0 .027 .126 r
F
.28086 .44963 m .27916 .44796 L .28178 .447 L F
.6047 .45291 m .60607 .45035 L .60749 .45207 L 0 .034 .135 r
F
.6047 .45291 m .60329 .45122 L .60607 .45035 L F
.79862 .44928 m .80027 .44674 L .8015 .44832 L 0 .026 .125 r
F
.79862 .44928 m .79739 .44769 L .80027 .44674 L F
.75257 .44948 m .75416 .44702 L .75543 .44857 L 0 .027 .126 r
F
.75257 .44948 m .7513 .44793 L .75416 .44702 L F
.55865 .45321 m .55996 .45066 L .56142 .4523 L 0 .035 .136 r
F
.55865 .45321 m .5572 .45159 L .55996 .45066 L F
.31994 .44992 m .32091 .44739 L .32258 .44901 L 0 .028 .127 r
F
.31994 .44992 m .31826 .44833 L .32091 .44739 L F
.8056 .44896 m .80726 .44645 L .80848 .44804 L 0 .026 .124 r
F
.8056 .44896 m .80438 .44738 L .80726 .44645 L F
.62562 .45189 m .62703 .44957 L .62841 .45096 L 0 .032 .133 r
F
.62562 .45189 m .62423 .4505 L .62703 .44957 L F
.42324 .45133 m .42435 .44892 L .42593 .45062 L 0 .031 .131 r
F
.42324 .45133 m .42166 .44964 L .42435 .44892 L F
.85863 .44845 m .86037 .44604 L .86155 .44763 L 0 .025 .123 r
F
.85863 .44845 m .85745 .44686 L .86037 .44604 L F
.56563 .45292 m .56694 .4504 L .56839 .45199 L 0 .034 .136 r
F
.56563 .45292 m .56418 .45136 L .56694 .4504 L F
.50563 .45389 m .50686 .4514 L .50837 .45304 L 0 .037 .138 r
F
.50563 .45389 m .50413 .45221 L .50686 .4514 L F
.69259 .45063 m .6941 .44834 L .69542 .44983 L 0 .03 .13 r
F
.69259 .45063 m .69126 .44912 L .6941 .44834 L F
.75956 .44928 m .76116 .4469 L .76242 .44847 L 0 .027 .126 r
F
.75956 .44928 m .75829 .44772 L .76116 .4469 L F
.81258 .44871 m .81425 .44624 L .81547 .44783 L 0 .025 .124 r
F
.81258 .44871 m .81136 .44711 L .81425 .44624 L F
.3269 .44968 m .32788 .44712 L .32955 .44876 L 0 .027 .126 r
F
.3269 .44968 m .32523 .44806 L .32788 .44712 L F
.44141 .45278 m .44255 .45027 L .44411 .45199 L 0 .034 .135 r
F
.44141 .45278 m .43985 .45106 L .44255 .45027 L F
.63259 .45164 m .63402 .44939 L .6354 .45086 L 0 .032 .133 r
F
.63259 .45164 m .63121 .45017 L .63402 .44939 L F
.61865 .45245 m .62005 .45004 L .62144 .45147 L 0 .034 .135 r
F
.61865 .45245 m .61726 .451 L .62005 .45004 L F
.5726 .45265 m .57393 .45028 L .57537 .45185 L F
.5726 .45265 m .57116 .45105 L .57393 .45028 L F
.28781 .44957 m .28873 .44708 L .29043 .44879 L 0 .027 .126 r
F
.28781 .44957 m .28611 .44788 L .28873 .44708 L F
.61168 .4529 m .61306 .45026 L .61447 .45195 L 0 .034 .135 r
F
.61168 .4529 m .61028 .45119 L .61306 .45026 L F
.38415 .45136 m .3852 .44899 L .38682 .4506 L 0 .031 .132 r
F
.38415 .45136 m .38253 .44972 L .3852 .44899 L F
.35901 .4504 m .36002 .44807 L .36166 .4496 L 0 .029 .129 r
F
.35901 .4504 m .35736 .44888 L .36002 .44807 L F
.5126 .45375 m .51384 .45155 L .51534 .45297 L 0 .037 .139 r
F
.5126 .45375 m .5111 .4523 L .51384 .45155 L F
.48746 .45278 m .48866 .45043 L .49018 .45206 L 0 .035 .136 r
F
.48746 .45278 m .48594 .45116 L .48866 .45043 L F
.81957 .44855 m .82125 .44607 L .82246 .44766 L 0 .025 .124 r
F
.81957 .44855 m .81836 .44696 L .82125 .44607 L F
.69957 .45049 m .70109 .44817 L .70241 .44963 L 0 .03 .13 r
F
.69957 .45049 m .69826 .44902 L .70109 .44817 L F
.44837 .45264 m .44952 .45037 L .45108 .45182 L 0 .035 .136 r
F
.44837 .45264 m .44681 .45118 L .44952 .45037 L F
.86564 .4484 m .86739 .44598 L .86855 .44756 L 0 .025 .124 r
F
.86564 .4484 m .86447 .44681 L .86739 .44598 L F
.51957 .45345 m .52082 .45121 L .52231 .45258 L 0 .037 .138 r
F
.51957 .45345 m .51808 .45211 L .52082 .45121 L F
.25568 .4492 m .25656 .4466 L .25829 .44829 L 0 .026 .125 r
F
.25568 .4492 m .25395 .44749 L .25656 .4466 L F
.76655 .44921 m .76816 .44685 L .76942 .4484 L 0 .027 .126 r
F
.76655 .44921 m .76529 .44765 L .76816 .44685 L F
.53352 .45271 m .53479 .45041 L .53626 .45186 L 0 .035 .136 r
F
.53352 .45271 m .53204 .45125 L .53479 .45041 L F
.70655 .45019 m .70807 .44772 L .70938 .44927 L 0 .029 .129 r
F
.70655 .45019 m .70524 .44867 L .70807 .44772 L F
.52654 .45312 m .52781 .45075 L .52929 .45219 L 0 .036 .137 r
F
.52654 .45312 m .52506 .45171 L .52781 .45075 L F
.33385 .44966 m .33483 .44726 L .33649 .44894 L 0 .028 .127 r
F
.33385 .44966 m .33219 .44801 L .33483 .44726 L F
.82656 .44833 m .82825 .44579 L .82945 .44739 L 0 .025 .123 r
F
.82656 .44833 m .82535 .44673 L .82825 .44579 L F
.57958 .45261 m .58092 .45027 L .58235 .4518 L 0 .035 .136 r
F
.57958 .45261 m .57814 .45106 L .58092 .45027 L F
.39111 .45128 m .39217 .44878 L .39379 .45034 L 0 .031 .132 r
F
.39111 .45128 m .38949 .44969 L .39217 .44878 L F
.36596 .45033 m .36699 .44797 L .36862 .44951 L 0 .029 .129 r
F
.36596 .45033 m .36432 .4488 L .36699 .44797 L F
.71353 .44997 m .71506 .44752 L .71637 .44913 L 0 .029 .128 r
F
.71353 .44997 m .71222 .44838 L .71506 .44752 L F
.87263 .44823 m .87438 .44573 L .87554 .44731 L 0 .025 .123 r
F
.87263 .44823 m .87147 .44665 L .87438 .44573 L F
.63958 .45171 m .64101 .44932 L .64239 .45093 L 0 .032 .133 r
F
.63958 .45171 m .6382 .45009 L .64101 .44932 L F
.54049 .45251 m .54177 .45034 L .54324 .45172 L 0 .035 .136 r
F
.54049 .45251 m .53902 .4511 L .54177 .45034 L F
.26263 .44906 m .26352 .44653 L .26525 .44819 L 0 .026 .126 r
F
.26263 .44906 m .26091 .44738 L .26352 .44653 L F
.29475 .44964 m .29569 .447 L .29738 .44871 L 0 .028 .127 r
F
.29475 .44964 m .29306 .44793 L .29569 .447 L F
.45534 .45257 m .45649 .45045 L .45804 .45189 L 0 .035 .136 r
F
.45534 .45257 m .45378 .45113 L .45649 .45045 L F
.83355 .44813 m .83526 .44573 L .83645 .44732 L 0 .025 .123 r
F
.83355 .44813 m .83235 .44654 L .83526 .44573 L F
.43019 .45162 m .43131 .44922 L .43288 .45092 L 0 .032 .133 r
F
.43019 .45162 m .42862 .44993 L .43131 .44922 L F
.77354 .44911 m .77517 .44672 L .77641 .44825 L 0 .027 .126 r
F
.77354 .44911 m .77229 .44758 L .77517 .44672 L F
.39807 .45111 m .39914 .44873 L .40075 .45028 L 0 .031 .132 r
F
.39807 .45111 m .39646 .44952 L .39914 .44873 L F
.87962 .44802 m .88139 .4456 L .88255 .44719 L 0 .025 .123 r
F
.87962 .44802 m .87847 .44644 L .88139 .4456 L F
.58655 .45251 m .5879 .45023 L .58933 .45169 L 0 .035 .136 r
F
.58655 .45251 m .58513 .45102 L .5879 .45023 L F
.78053 .44885 m .78215 .44637 L .7834 .44794 L 0 .026 .125 r
F
.78053 .44885 m .77928 .44731 L .78215 .44637 L F
.49442 .45293 m .49564 .45051 L .49715 .45216 L 0 .036 .137 r
F
.49442 .45293 m .49291 .45128 L .49564 .45051 L F
.37292 .45023 m .37396 .44785 L .37559 .44941 L 0 .03 .13 r
F
.37292 .45023 m .37129 .44868 L .37396 .44785 L F
.30171 .44949 m .30265 .44691 L .30434 .44861 L 0 .028 .127 r
F
.30171 .44949 m .30002 .44778 L .30265 .44691 L F
.72052 .44991 m .72206 .44735 L .72336 .44896 L 0 .029 .128 r
F
.72052 .44991 m .71922 .44828 L .72206 .44735 L F
.66051 .4509 m .66197 .44848 L .66332 .44999 L 0 .031 .131 r
F
.66051 .4509 m .65916 .44942 L .66197 .44848 L F
.54746 .45245 m .54876 .45027 L .55022 .45171 L 0 .035 .136 r
F
.54746 .45245 m .546 .45099 L .54876 .45027 L F
.59353 .45227 m .59489 .4499 L .59631 .45139 L 0 .034 .135 r
F
.59353 .45227 m .59211 .4508 L .59489 .4499 L F
.65354 .45131 m .65498 .44882 L .65635 .45036 L 0 .032 .132 r
F
.65354 .45131 m .65218 .4498 L .65498 .44882 L F
.7275 .44958 m .72905 .44706 L .73034 .44861 L 0 .028 .128 r
F
.7275 .44958 m .7262 .44802 L .72905 .44706 L F
.46928 .4521 m .47045 .44979 L .47199 .45121 L 0 .034 .135 r
F
.46928 .4521 m .46773 .45067 L .47045 .44979 L F
.73447 .4492 m .73603 .44668 L .73732 .44823 L 0 .027 .127 r
F
.73447 .4492 m .73318 .44765 L .73603 .44668 L F
.40503 .45096 m .40612 .44858 L .40772 .45009 L 0 .031 .132 r
F
.40503 .45096 m .40343 .44945 L .40612 .44858 L F
.47625 .45174 m .47743 .44947 L .47897 .45089 L 0 .033 .134 r
F
.47625 .45174 m .47471 .45033 L .47743 .44947 L F
.84055 .44808 m .84227 .44563 L .84346 .44719 L 0 .025 .124 r
F
.84055 .44808 m .83936 .4465 L .84227 .44563 L F
.4623 .45253 m .46347 .45015 L .46502 .4516 L 0 .035 .136 r
F
.4623 .45253 m .46075 .4511 L .46347 .45015 L F
.66749 .45059 m .66896 .44821 L .6703 .44969 L 0 .03 .131 r
F
.66749 .45059 m .66614 .4491 L .66896 .44821 L F
.64657 .45176 m .648 .44915 L .64937 .45078 L 0 .033 .134 r
F
.64657 .45176 m .6452 .45015 L .648 .44915 L F
.34079 .44983 m .34179 .44723 L .34344 .44894 L 0 .028 .128 r
F
.34079 .44983 m .33914 .44813 L .34179 .44723 L F
.26957 .44906 m .27046 .44665 L .27218 .44827 L 0 .027 .126 r
F
.26957 .44906 m .26785 .44742 L .27046 .44665 L F
.78752 .44867 m .78915 .44624 L .7904 .44786 L 0 .026 .125 r
F
.78752 .44867 m .78627 .44708 L .78915 .44624 L F
.88663 .44796 m .8884 .44542 L .88955 .44703 L 0 .025 .123 r
F
.88663 .44796 m .88548 .44636 L .8884 .44542 L F
.74145 .44895 m .74303 .44656 L .74431 .44812 L 0 .027 .126 r
F
.74145 .44895 m .74017 .44739 L .74303 .44656 L F
.67447 .45035 m .67594 .44782 L .67728 .44939 L 0 .03 .13 r
F
.67447 .45035 m .67312 .44877 L .67594 .44782 L F
.60051 .4521 m .60187 .4496 L .60329 .45122 L 0 .034 .135 r
F
.60051 .4521 m .59909 .4505 L .60187 .4496 L F
.84754 .44785 m .84927 .44542 L .85045 .44698 L 0 .025 .123 r
F
.84754 .44785 m .84636 .4463 L .84927 .44542 L F
.412 .45076 m .4131 .4483 L .41469 .44985 L 0 .031 .131 r
F
.412 .45076 m .41041 .44921 L .4131 .4483 L F
.68144 .44999 m .68293 .44755 L .68427 .44913 L 0 .029 .129 r
F
.68144 .44999 m .6801 .44843 L .68293 .44755 L F
.30866 .44943 m .30961 .44687 L .31129 .44854 L 0 .028 .127 r
F
.30866 .44943 m .30697 .44774 L .30961 .44687 L F
.34775 .44963 m .34875 .44728 L .3504 .44886 L 0 .029 .128 r
F
.34775 .44963 m .3461 .44805 L .34875 .44728 L F
.89362 .4477 m .8954 .44516 L .89654 .44679 L 0 .024 .123 r
F
.89362 .4477 m .89247 .44609 L .8954 .44516 L F
.43715 .45184 m .43828 .44932 L .43985 .45106 L 0 .033 .134 r
F
.43715 .45184 m .43558 .45012 L .43828 .44932 L F
.27653 .44895 m .27744 .44635 L .27916 .44796 L 0 .027 .126 r
F
.27653 .44895 m .27481 .44734 L .27744 .44635 L F
.50139 .45306 m .50262 .45053 L .50413 .45221 L 0 .036 .138 r
F
.50139 .45306 m .49989 .45135 L .50262 .45053 L F
.31562 .44921 m .31658 .44673 L .31826 .44833 L 0 .028 .127 r
F
.31562 .44921 m .31394 .44764 L .31658 .44673 L F
.37987 .45038 m .38091 .4481 L .38253 .44972 L 0 .031 .131 r
F
.37987 .45038 m .37825 .44875 L .38091 .4481 L F
.74845 .44883 m .75003 .44637 L .7513 .44793 L 0 .027 .126 r
F
.74845 .44883 m .74717 .44727 L .75003 .44637 L F
.79452 .44864 m .79616 .44609 L .79739 .44769 L 0 .026 .126 r
F
.79452 .44864 m .79328 .44704 L .79616 .44609 L F
.41897 .45058 m .42008 .44794 L .42166 .44964 L 0 .03 .131 r
F
.41897 .45058 m .41738 .4489 L .42008 .44794 L F
.55444 .45252 m .55574 .44997 L .5572 .45159 L 0 .035 .136 r
F
.55444 .45252 m .55298 .45093 L .55574 .44997 L F
.85454 .4477 m .85628 .44527 L .85745 .44686 L 0 .025 .123 r
F
.85454 .4477 m .85336 .44612 L .85628 .44527 L F
.28349 .44868 m .28441 .44619 L .28611 .44788 L 0 .027 .126 r
F
.28349 .44868 m .28178 .447 L .28441 .44619 L F
.8015 .44832 m .80315 .4458 L .80438 .44738 L 0 .026 .125 r
F
.8015 .44832 m .80027 .44674 L .80315 .4458 L F
.48322 .45182 m .48441 .44955 L .48594 .45116 L 0 .034 .135 r
F
.48322 .45182 m .48169 .45022 L .48441 .44955 L F
.68843 .4499 m .68993 .44755 L .69126 .44912 L 0 .03 .13 r
F
.68843 .4499 m .6871 .44834 L .68993 .44755 L F
.75543 .44857 m .75702 .44616 L .75829 .44772 L 0 .027 .126 r
F
.75543 .44857 m .75416 .44702 L .75702 .44616 L F
.60749 .45207 m .60886 .44946 L .61028 .45119 L 0 .034 .135 r
F
.60749 .45207 m .60607 .45035 L .60886 .44946 L F
.80848 .44804 m .81014 .44552 L .81136 .44711 L 0 .025 .124 r
F
.80848 .44804 m .80726 .44645 L .81014 .44552 L F
.32258 .44901 m .32356 .44643 L .32523 .44806 L 0 .027 .127 r
F
.32258 .44901 m .32091 .44739 L .32356 .44643 L F
.56142 .4523 m .56273 .4497 L .56418 .45136 L 0 .035 .136 r
F
.56142 .4523 m .55996 .45066 L .56273 .4497 L F
.62841 .45096 m .62983 .44877 L .63121 .45017 L 0 .032 .133 r
F
.62841 .45096 m .62703 .44957 L .62983 .44877 L F
.35471 .44964 m .35571 .44735 L .35736 .44888 L 0 .029 .129 r
F
.35471 .44964 m .35306 .44811 L .35571 .44735 L F
.56839 .45199 m .56971 .44944 L .57116 .45105 L 0 .034 .135 r
F
.56839 .45199 m .56694 .4504 L .56971 .44944 L F
.32955 .44876 m .33052 .44635 L .33219 .44801 L 0 .027 .127 r
F
.32955 .44876 m .32788 .44712 L .33052 .44635 L F
.62144 .45147 m .62284 .44908 L .62423 .4505 L 0 .033 .134 r
F
.62144 .45147 m .62005 .45004 L .62284 .44908 L F
.50837 .45304 m .5096 .45068 L .5111 .4523 L 0 .037 .139 r
F
.50837 .45304 m .50686 .4514 L .5096 .45068 L F
.86155 .44763 m .86329 .44522 L .86447 .44681 L 0 .025 .124 r
F
.86155 .44763 m .86037 .44604 L .86329 .44522 L F
.81547 .44783 m .81715 .44537 L .81836 .44696 L F
.81547 .44783 m .81425 .44624 L .81715 .44537 L F
.76242 .44847 m .76403 .44609 L .76529 .44765 L 0 .027 .126 r
F
.76242 .44847 m .76116 .4469 L .76403 .44609 L F
.61447 .45195 m .61585 .44933 L .61726 .451 L 0 .034 .135 r
F
.61447 .45195 m .61306 .45026 L .61585 .44933 L F
.69542 .44983 m .69694 .44756 L .69826 .44902 L 0 .03 .13 r
F
.69542 .44983 m .6941 .44834 L .69694 .44756 L F
.42593 .45062 m .42704 .44823 L .42862 .44993 L 0 .032 .132 r
F
.42593 .45062 m .42435 .44892 L .42704 .44823 L F
.44411 .45199 m .44525 .44949 L .44681 .45118 L 0 .034 .136 r
F
.44411 .45199 m .44255 .45027 L .44525 .44949 L F
.6354 .45086 m .63682 .4486 L .6382 .45009 L 0 .032 .133 r
F
.6354 .45086 m .63402 .44939 L .63682 .4486 L F
.57537 .45185 m .5767 .44951 L .57814 .45106 L 0 .034 .136 r
F
.57537 .45185 m .57393 .45028 L .5767 .44951 L F
.29043 .44879 m .29136 .44622 L .29306 .44793 L 0 .027 .127 r
F
.29043 .44879 m .28873 .44708 L .29136 .44622 L F
.82246 .44766 m .82415 .44513 L .82535 .44673 L 0 .025 .124 r
F
.82246 .44766 m .82125 .44607 L .82415 .44513 L F
.36166 .4496 m .36268 .44726 L .36432 .4488 L 0 .03 .129 r
F
.36166 .4496 m .36002 .44807 L .36268 .44726 L F
.70241 .44963 m .70392 .4472 L .70524 .44867 L 0 .029 .129 r
F
.70241 .44963 m .70109 .44817 L .70392 .4472 L F
.38682 .4506 m .38788 .4481 L .38949 .44969 L 0 .031 .132 r
F
.38682 .4506 m .3852 .44899 L .38788 .4481 L F
.25829 .44829 m .25918 .44571 L .26091 .44738 L 0 .026 .125 r
F
.25829 .44829 m .25656 .4466 L .25918 .44571 L F
.70938 .44927 m .71091 .44681 L .71222 .44838 L 0 .029 .128 r
F
.70938 .44927 m .70807 .44772 L .71091 .44681 L F
.52929 .45219 m .53056 .44979 L .53204 .45125 L 0 .035 .137 r
F
.52929 .45219 m .52781 .45075 L .53056 .44979 L F
.51534 .45297 m .51658 .45068 L .51808 .45211 L 0 .037 .139 r
F
.51534 .45297 m .51384 .45155 L .51658 .45068 L F
.52231 .45258 m .52357 .45031 L .52506 .45171 L 0 .037 .138 r
F
.52231 .45258 m .52082 .45121 L .52357 .45031 L F
.45108 .45182 m .45222 .44969 L .45378 .45113 L 0 .035 .136 r
F
.45108 .45182 m .44952 .45037 L .45222 .44969 L F
.86855 .44756 m .8703 .44507 L .87147 .44665 L 0 .025 .124 r
F
.86855 .44756 m .86739 .44598 L .8703 .44507 L F
.82945 .44739 m .83115 .44494 L .83235 .44654 L 0 .025 .123 r
F
.82945 .44739 m .82825 .44579 L .83115 .44494 L F
.53626 .45186 m .53754 .44968 L .53902 .4511 L 0 .035 .136 r
F
.53626 .45186 m .53479 .45041 L .53754 .44968 L F
.49018 .45206 m .49139 .44965 L .49291 .45128 L F
.49018 .45206 m .48866 .45043 L .49139 .44965 L F
.76942 .4484 m .77104 .44604 L .77229 .44758 L 0 .027 .126 r
F
.76942 .4484 m .76816 .44685 L .77104 .44604 L F
.39379 .45034 m .39485 .44799 L .39646 .44952 L 0 .031 .132 r
F
.39379 .45034 m .39217 .44878 L .39485 .44799 L F
.87554 .44731 m .87731 .44486 L .87847 .44644 L 0 .025 .123 r
F
.87554 .44731 m .87438 .44573 L .87731 .44486 L F
.58235 .4518 m .58369 .44951 L .58513 .45102 L 0 .035 .136 r
F
.58235 .4518 m .58092 .45027 L .58369 .44951 L F
.29738 .44871 m .29833 .44607 L .30002 .44778 L 0 .027 .127 r
F
.29738 .44871 m .29569 .447 L .29833 .44607 L F
.36862 .44951 m .36965 .44713 L .37129 .44868 L 0 .03 .13 r
F
.36862 .44951 m .36699 .44797 L .36965 .44713 L F
.71637 .44913 m .71791 .44665 L .71922 .44828 L 0 .029 .128 r
F
.71637 .44913 m .71506 .44752 L .71791 .44665 L F
.33649 .44894 m .33748 .44644 L .33914 .44813 L 0 .028 .128 r
F
.33649 .44894 m .33483 .44726 L .33748 .44644 L F
.26525 .44819 m .26613 .44578 L .26785 .44742 L 0 .027 .126 r
F
.26525 .44819 m .26352 .44653 L .26613 .44578 L F
.64239 .45093 m .64382 .44853 L .6452 .45015 L 0 .033 .134 r
F
.64239 .45093 m .64101 .44932 L .64382 .44853 L F
.54324 .45172 m .54453 .44963 L .546 .45099 L 0 .035 .136 r
F
.54324 .45172 m .54177 .45034 L .54453 .44963 L F
.77641 .44825 m .77803 .44577 L .77928 .44731 L 0 .027 .126 r
F
.77641 .44825 m .77517 .44672 L .77803 .44577 L F
.83645 .44732 m .83817 .44492 L .83936 .4465 L 0 .025 .124 r
F
.83645 .44732 m .83526 .44573 L .83817 .44492 L F
.7834 .44794 m .78503 .44548 L .78627 .44708 L 0 .026 .125 r
F
.7834 .44794 m .78215 .44637 L .78503 .44548 L F
.40075 .45028 m .40183 .44794 L .40343 .44945 L 0 .032 .132 r
F
.40075 .45028 m .39914 .44873 L .40183 .44794 L F
.88255 .44719 m .88433 .44476 L .88548 .44636 L 0 .025 .123 r
F
.88255 .44719 m .88139 .4456 L .88433 .44476 L F
.72336 .44896 m .7249 .44641 L .7262 .44802 L 0 .028 .128 r
F
.72336 .44896 m .72206 .44735 L .7249 .44641 L F
.58933 .45169 m .59068 .44933 L .59211 .4508 L 0 .035 .136 r
F
.58933 .45169 m .5879 .45023 L .59068 .44933 L F
.43288 .45092 m .43401 .4484 L .43558 .45012 L 0 .033 .134 r
F
.43288 .45092 m .43131 .44922 L .43401 .4484 L F
.45804 .45189 m .4592 .44965 L .46075 .4511 L 0 .036 .137 r
F
.45804 .45189 m .45649 .45045 L .4592 .44965 L F
.73034 .44861 m .73189 .44609 L .73318 .44765 L 0 .028 .127 r
F
.73034 .44861 m .72905 .44706 L .73189 .44609 L F
.65635 .45036 m .65779 .44787 L .65916 .44942 L 0 .032 .132 r
F
.65635 .45036 m .65498 .44882 L .65779 .44787 L F
.30434 .44861 m .30529 .44605 L .30697 .44774 L 0 .028 .127 r
F
.30434 .44861 m .30265 .44691 L .30529 .44605 L F
.73732 .44823 m .73889 .44584 L .74017 .44739 L 0 .027 .126 r
F
.73732 .44823 m .73603 .44668 L .73889 .44584 L F
.66332 .44999 m .66479 .4476 L .66614 .4491 L 0 .031 .131 r
F
.66332 .44999 m .66197 .44848 L .66479 .4476 L F
.37559 .44941 m .37662 .44717 L .37825 .44875 L 0 .03 .13 r
F
.37559 .44941 m .37396 .44785 L .37662 .44717 L F
.64937 .45078 m .6508 .44815 L .65218 .4498 L 0 .032 .133 r
F
.64937 .45078 m .648 .44915 L .6508 .44815 L F
.59631 .45139 m .59767 .44898 L .59909 .4505 L 0 .034 .135 r
F
.59631 .45139 m .59489 .4499 L .59767 .44898 L F
.49715 .45216 m .49837 .44973 L .49989 .45135 L 0 .036 .137 r
F
.49715 .45216 m .49564 .45051 L .49837 .44973 L F
.47199 .45121 m .47317 .44891 L .47471 .45033 L 0 .034 .135 r
F
.47199 .45121 m .47045 .44979 L .47317 .44891 L F
.46502 .4516 m .46619 .4492 L .46773 .45067 L 0 .035 .136 r
F
.46502 .4516 m .46347 .45015 L .46619 .4492 L F
.6703 .44969 m .67178 .44732 L .67312 .44877 L 0 .03 .131 r
F
.6703 .44969 m .66896 .44821 L .67178 .44732 L F
.40772 .45009 m .40881 .44771 L .41041 .44921 L 0 .031 .132 r
F
.40772 .45009 m .40612 .44858 L .40881 .44771 L F
.84346 .44719 m .84518 .44477 L .84636 .4463 L 0 .025 .124 r
F
.84346 .44719 m .84227 .44563 L .84518 .44477 L F
.34344 .44894 m .34445 .44633 L .3461 .44805 L 0 .028 .128 r
F
.34344 .44894 m .34179 .44723 L .34445 .44633 L F
.47897 .45089 m .48016 .44878 L .48169 .45022 L 0 .034 .135 r
F
.47897 .45089 m .47743 .44947 L .48016 .44878 L F
.88955 .44703 m .89132 .44447 L .89247 .44609 L 0 .025 .123 r
F
.88955 .44703 m .8884 .44542 L .89132 .44447 L F
.55022 .45171 m .55152 .44949 L .55298 .45093 L 0 .035 .137 r
F
.55022 .45171 m .54876 .45027 L .55152 .44949 L F
.67728 .44939 m .67876 .44687 L .6801 .44843 L 0 .03 .13 r
F
.67728 .44939 m .67594 .44782 L .67876 .44687 L F
.7904 .44786 m .79204 .44539 L .79328 .44704 L 0 .026 .126 r
F
.7904 .44786 m .78915 .44624 L .79204 .44539 L F
.27218 .44827 m .27309 .44573 L .27481 .44734 L 0 .027 .127 r
F
.27218 .44827 m .27046 .44665 L .27309 .44573 L F
.41469 .44985 m .41579 .44735 L .41738 .4489 L 0 .031 .131 r
F
.41469 .44985 m .4131 .4483 L .41579 .44735 L F
.74431 .44812 m .74589 .44573 L .74717 .44727 L 0 .027 .127 r
F
.74431 .44812 m .74303 .44656 L .74589 .44573 L F
.60329 .45122 m .60466 .4487 L .60607 .45035 L 0 .034 .135 r
F
.60329 .45122 m .60187 .4496 L .60466 .4487 L F
.85045 .44698 m .85218 .44455 L .85336 .44612 L 0 .025 .123 r
F
.85045 .44698 m .84927 .44542 L .85218 .44455 L F
.89654 .44679 m .89833 .44427 L .89948 .44592 L 0 .024 .123 r
F
.89654 .44679 m .8954 .44516 L .89833 .44427 L F
.31129 .44854 m .31225 .44598 L .31394 .44764 L 0 .028 .127 r
F
.31129 .44854 m .30961 .44687 L .31225 .44598 L F
.27916 .44796 m .28007 .4454 L .28178 .447 L 0 .027 .126 r
F
.27916 .44796 m .27744 .44635 L .28007 .4454 L F
.68427 .44913 m .68576 .44674 L .6871 .44834 L 0 .029 .129 r
F
.68427 .44913 m .68293 .44755 L .68576 .44674 L F
.79739 .44769 m .79904 .44514 L .80027 .44674 L 0 .026 .125 r
F
.79739 .44769 m .79616 .44609 L .79904 .44514 L F
.3504 .44886 m .3514 .44654 L .35306 .44811 L 0 .029 .129 r
F
.3504 .44886 m .34875 .44728 L .3514 .44654 L F
.42166 .44964 m .42277 .44722 L .42435 .44892 L 0 .031 .131 r
F
.42166 .44964 m .42008 .44794 L .42277 .44722 L F
.5572 .45159 m .5585 .44902 L .55996 .45066 L 0 .035 .136 r
F
.5572 .45159 m .55574 .44997 L .5585 .44902 L F
.7513 .44793 m .75289 .44547 L .75416 .44702 L 0 .027 .126 r
F
.7513 .44793 m .75003 .44637 L .75289 .44547 L F
.31826 .44833 m .31923 .44578 L .32091 .44739 L 0 .028 .127 r
F
.31826 .44833 m .31658 .44673 L .31923 .44578 L F
.50413 .45221 m .50536 .44975 L .50686 .4514 L 0 .037 .138 r
F
.50413 .45221 m .50262 .45053 L .50536 .44975 L F
.80438 .44738 m .80603 .44486 L .80726 .44645 L 0 .026 .125 r
F
.80438 .44738 m .80315 .4458 L .80603 .44486 L F
.43985 .45106 m .44098 .44854 L .44255 .45027 L 0 .034 .135 r
F
.43985 .45106 m .43828 .44932 L .44098 .44854 L F
.85745 .44686 m .8592 .44444 L .86037 .44604 L 0 .025 .123 r
F
.85745 .44686 m .85628 .44527 L .8592 .44444 L F
.32523 .44806 m .32621 .44547 L .32788 .44712 L 0 .027 .126 r
F
.32523 .44806 m .32356 .44643 L .32621 .44547 L F
.56418 .45136 m .56549 .44873 L .56694 .4504 L 0 .034 .136 r
F
.56418 .45136 m .56273 .4497 L .56549 .44873 L F
.28611 .44788 m .28703 .44537 L .28873 .44708 L 0 .027 .126 r
F
.28611 .44788 m .28441 .44619 L .28703 .44537 L F
.81136 .44711 m .81304 .44466 L .81425 .44624 L 0 .025 .124 r
F
.81136 .44711 m .81014 .44552 L .81304 .44466 L F
.61028 .45119 m .61165 .44856 L .61306 .45026 L 0 .034 .135 r
F
.61028 .45119 m .60886 .44946 L .61165 .44856 L F
.75829 .44772 m .75989 .44532 L .76116 .4469 L 0 .027 .126 r
F
.75829 .44772 m .75702 .44616 L .75989 .44532 L F
.57116 .45105 m .57248 .44868 L .57393 .45028 L 0 .034 .135 r
F
.57116 .45105 m .56971 .44944 L .57248 .44868 L F
.69126 .44912 m .69277 .44677 L .6941 .44834 L 0 .03 .13 r
F
.69126 .44912 m .68993 .44755 L .69277 .44677 L F
.38253 .44972 m .38358 .44736 L .3852 .44899 L 0 .031 .132 r
F
.38253 .44972 m .38091 .4481 L .38358 .44736 L F
.62423 .4505 m .62564 .44816 L .62703 .44957 L 0 .033 .134 r
F
.62423 .4505 m .62284 .44908 L .62564 .44816 L F
.63121 .45017 m .63263 .44796 L .63402 .44939 L 0 .033 .133 r
F
.63121 .45017 m .62983 .44877 L .63263 .44796 L F
.48594 .45116 m .48714 .44882 L .48866 .45043 L 0 .035 .136 r
F
.48594 .45116 m .48441 .44955 L .48714 .44882 L F
.25395 .44749 m .25483 .44491 L .25656 .4466 L 0 .026 .125 r
F
.25395 .44749 m .25222 .44578 L .25483 .44491 L F
.61726 .451 m .61865 .4484 L .62005 .45004 L 0 .034 .135 r
F
.61726 .451 m .61585 .44933 L .61865 .4484 L F
.35736 .44888 m .35837 .44653 L .36002 .44807 L 0 .03 .13 r
F
.35736 .44888 m .35571 .44735 L .35837 .44653 L F
.81836 .44696 m .82004 .44448 L .82125 .44607 L 0 .025 .124 r
F
.81836 .44696 m .81715 .44537 L .82004 .44448 L F
.86447 .44681 m .86622 .44438 L .86739 .44598 L F
.86447 .44681 m .86329 .44522 L .86622 .44438 L F
.33219 .44801 m .33317 .44558 L .33483 .44726 L 0 .028 .127 r
F
.33219 .44801 m .33052 .44635 L .33317 .44558 L F
.5111 .4523 m .51234 .44997 L .51384 .45155 L 0 .038 .139 r
F
.5111 .4523 m .5096 .45068 L .51234 .44997 L F
.76529 .44765 m .7669 .44529 L .76816 .44685 L 0 .027 .126 r
F
.76529 .44765 m .76403 .44609 L .7669 .44529 L F
.69826 .44902 m .69977 .44671 L .70109 .44817 L 0 .03 .13 r
F
.69826 .44902 m .69694 .44756 L .69977 .44671 L F
.82535 .44673 m .82704 .44419 L .82825 .44579 L 0 .025 .123 r
F
.82535 .44673 m .82415 .44513 L .82704 .44419 L F
.44681 .45118 m .44796 .4487 L .44952 .45037 L 0 .035 .136 r
F
.44681 .45118 m .44525 .44949 L .44796 .4487 L F
.70524 .44867 m .70676 .44623 L .70807 .44772 L 0 .029 .129 r
F
.70524 .44867 m .70392 .4472 L .70676 .44623 L F
.29306 .44793 m .294 .44529 L .29569 .447 L 0 .027 .127 r
F
.29306 .44793 m .29136 .44622 L .294 .44529 L F
.38949 .44969 m .39056 .44721 L .39217 .44878 L 0 .031 .132 r
F
.38949 .44969 m .38788 .4481 L .39056 .44721 L F
.6382 .45009 m .63963 .44782 L .64101 .44932 L 0 .033 .133 r
F
.6382 .45009 m .63682 .4486 L .63963 .44782 L F
.57814 .45106 m .57948 .44874 L .58092 .45027 L 0 .035 .136 r
F
.57814 .45106 m .5767 .44951 L .57948 .44874 L F
.53204 .45125 m .53331 .44893 L .53479 .45041 L 0 .035 .137 r
F
.53204 .45125 m .53056 .44979 L .53331 .44893 L F
.26091 .44738 m .26179 .44488 L .26352 .44653 L 0 .026 .125 r
F
.26091 .44738 m .25918 .44571 L .26179 .44488 L F
.71222 .44838 m .71375 .44592 L .71506 .44752 L 0 .029 .128 r
F
.71222 .44838 m .71091 .44681 L .71375 .44592 L F
.42862 .44993 m .42974 .44751 L .43131 .44922 L 0 .032 .133 r
F
.42862 .44993 m .42704 .44823 L .42974 .44751 L F
.87147 .44665 m .87322 .44415 L .87438 .44573 L 0 .025 .124 r
F
.87147 .44665 m .8703 .44507 L .87322 .44415 L F
.36432 .4488 m .36535 .44642 L .36699 .44797 L 0 .03 .13 r
F
.36432 .4488 m .36268 .44726 L .36535 .44642 L F
.52506 .45171 m .52632 .44931 L .52781 .45075 L 0 .036 .138 r
F
.52506 .45171 m .52357 .45031 L .52632 .44931 L F
.51808 .45211 m .51933 .44976 L .52082 .45121 L 0 .037 .139 r
F
.51808 .45211 m .51658 .45068 L .51933 .44976 L F
.83235 .44654 m .83406 .44413 L .83526 .44573 L 0 .025 .124 r
F
.83235 .44654 m .83115 .44494 L .83406 .44413 L F
.39646 .44952 m .39753 .44724 L .39914 .44873 L 0 .032 .132 r
F
.39646 .44952 m .39485 .44799 L .39753 .44724 L F
.77229 .44758 m .77391 .44518 L .77517 .44672 L 0 .027 .127 r
F
.77229 .44758 m .77104 .44604 L .77391 .44518 L F
.30002 .44778 m .30096 .44521 L .30265 .44691 L F
.30002 .44778 m .29833 .44607 L .30096 .44521 L F
.87847 .44644 m .88024 .44402 L .88139 .4456 L 0 .025 .123 r
F
.87847 .44644 m .87731 .44486 L .88024 .44402 L F
.49291 .45128 m .49412 .44887 L .49564 .45051 L 0 .036 .137 r
F
.49291 .45128 m .49139 .44965 L .49412 .44887 L F
.53902 .4511 m .5403 .44895 L .54177 .45034 L F
.53902 .4511 m .53754 .44968 L .5403 .44895 L F
.45378 .45113 m .45493 .44901 L .45649 .45045 L F
.45378 .45113 m .45222 .44969 L .45493 .44901 L F
.77928 .44731 m .78091 .44482 L .78215 .44637 L 0 .027 .126 r
F
.77928 .44731 m .77803 .44577 L .78091 .44482 L F
.71922 .44828 m .72075 .44571 L .72206 .44735 L 0 .029 .128 r
F
.71922 .44828 m .71791 .44665 L .72075 .44571 L F
.37129 .44868 m .37232 .44629 L .37396 .44785 L 0 .03 .13 r
F
.37129 .44868 m .36965 .44713 L .37232 .44629 L F
.58513 .45102 m .58648 .44875 L .5879 .45023 L 0 .035 .137 r
F
.58513 .45102 m .58369 .44951 L .58648 .44875 L F
.33914 .44813 m .34014 .44552 L .34179 .44723 L 0 .028 .128 r
F
.33914 .44813 m .33748 .44644 L .34014 .44552 L F
.26785 .44742 m .26874 .44502 L .27046 .44665 L 0 .027 .126 r
F
.26785 .44742 m .26613 .44578 L .26874 .44502 L F
.6452 .45015 m .64662 .44752 L .648 .44915 L 0 .033 .134 r
F
.6452 .45015 m .64382 .44853 L .64662 .44752 L F
.7262 .44802 m .72775 .44545 L .72905 .44706 L 0 .028 .128 r
F
.7262 .44802 m .7249 .44641 L .72775 .44545 L F
.73318 .44765 m .73474 .44512 L .73603 .44668 L 0 .027 .127 r
F
.73318 .44765 m .73189 .44609 L .73474 .44512 L F
.78627 .44708 m .78791 .44462 L .78915 .44624 L 0 .026 .125 r
F
.78627 .44708 m .78503 .44548 L .78791 .44462 L F
.83936 .4465 m .84108 .44408 L .84227 .44563 L 0 .025 .124 r
F
.83936 .4465 m .83817 .44492 L .84108 .44408 L F
.65218 .4498 m .65361 .44716 L .65498 .44882 L 0 .032 .133 r
F
.65218 .4498 m .6508 .44815 L .65361 .44716 L F
.65916 .44942 m .66061 .44691 L .66197 .44848 L 0 .031 .132 r
F
.65916 .44942 m .65779 .44787 L .66061 .44691 L F
.546 .45099 m .54729 .44892 L .54876 .45027 L 0 .036 .137 r
F
.546 .45099 m .54453 .44963 L .54729 .44892 L F
.59211 .4508 m .59347 .4484 L .59489 .4499 L 0 .035 .136 r
F
.59211 .4508 m .59068 .44933 L .59347 .4484 L F
.40343 .44945 m .40451 .44707 L .40612 .44858 L 0 .032 .132 r
F
.40343 .44945 m .40183 .44794 L .40451 .44707 L F
.88548 .44636 m .88725 .44382 L .8884 .44542 L 0 .025 .123 r
F
.88548 .44636 m .88433 .44476 L .88725 .44382 L F
.66614 .4491 m .66761 .44674 L .66896 .44821 L 0 .031 .131 r
F
.66614 .4491 m .66479 .4476 L .66761 .44674 L F
.30697 .44774 m .30793 .44518 L .30961 .44687 L 0 .028 .127 r
F
.30697 .44774 m .30529 .44605 L .30793 .44518 L F
.46773 .45067 m .46891 .44831 L .47045 .44979 L 0 .035 .136 r
F
.46773 .45067 m .46619 .4492 L .46891 .44831 L F
.74017 .44739 m .74175 .44503 L .74303 .44656 L 0 .027 .127 r
F
.74017 .44739 m .73889 .44584 L .74175 .44503 L F
.59909 .4505 m .60046 .44805 L .60187 .4496 L 0 .034 .135 r
F
.59909 .4505 m .59767 .44898 L .60046 .44805 L F
.43558 .45012 m .43671 .44759 L .43828 .44932 L 0 .033 .134 r
F
.43558 .45012 m .43401 .4484 L .43671 .44759 L F
.67312 .44877 m .6746 .44638 L .67594 .44782 L 0 .03 .13 r
F
.67312 .44877 m .67178 .44732 L .6746 .44638 L F
.47471 .45033 m .4759 .44805 L .47743 .44947 L 0 .034 .135 r
F
.47471 .45033 m .47317 .44891 L .4759 .44805 L F
.46075 .4511 m .46192 .44868 L .46347 .45015 L 0 .036 .137 r
F
.46075 .4511 m .4592 .44965 L .46192 .44868 L F
.89247 .44609 m .89425 .44354 L .8954 .44516 L 0 .024 .123 r
F
.89247 .44609 m .89132 .44447 L .89425 .44354 L F
.84636 .4463 m .84809 .44389 L .84927 .44542 L 0 .025 .124 r
F
.84636 .4463 m .84518 .44477 L .84809 .44389 L F
.6801 .44843 m .68159 .44598 L .68293 .44755 L 0 .03 .13 r
F
.6801 .44843 m .67876 .44687 L .68159 .44598 L F
.3461 .44805 m .3471 .44556 L .34875 .44728 L 0 .029 .128 r
F
.3461 .44805 m .34445 .44633 L .3471 .44556 L F
.41041 .44921 m .4115 .4468 L .4131 .4483 L 0 .031 .132 r
F
.41041 .44921 m .40881 .44771 L .4115 .4468 L F
.49989 .45135 m .50111 .44896 L .50262 .45053 L 0 .036 .138 r
F
.49989 .45135 m .49837 .44973 L .50111 .44896 L F
.27481 .44734 m .27572 .44476 L .27744 .44635 L 0 .027 .126 r
F
.27481 .44734 m .27309 .44573 L .27572 .44476 L F
.41738 .4489 m .41849 .4464 L .42008 .44794 L 0 .031 .131 r
F
.41738 .4489 m .41579 .44735 L .41849 .4464 L F
.28178 .447 m .28269 .44459 L .28441 .44619 L 0 .027 .126 r
F
.28178 .447 m .28007 .4454 L .28269 .44459 L F
.37825 .44875 m .37929 .44649 L .38091 .4481 L 0 .031 .131 r
F
.37825 .44875 m .37662 .44717 L .37929 .44649 L F
.79328 .44704 m .79492 .44445 L .79616 .44609 L 0 .026 .126 r
F
.79328 .44704 m .79204 .44539 L .79492 .44445 L F
.55298 .45093 m .55428 .44852 L .55574 .44997 L 0 .036 .137 r
F
.55298 .45093 m .55152 .44949 L .55428 .44852 L F
.60607 .45035 m .60745 .44781 L .60886 .44946 L 0 .034 .135 r
F
.60607 .45035 m .60466 .4487 L .60745 .44781 L F
.31394 .44764 m .3149 .44509 L .31658 .44673 L 0 .028 .127 r
F
.31394 .44764 m .31225 .44598 L .3149 .44509 L F
.74717 .44727 m .74875 .44484 L .75003 .44637 L 0 .027 .127 r
F
.74717 .44727 m .74589 .44573 L .74875 .44484 L F
.89948 .44592 m .90127 .44338 L .90241 .44505 L 0 .024 .123 r
F
.89948 .44592 m .89833 .44427 L .90127 .44338 L F
.85336 .44612 m .8551 .44368 L .85628 .44527 L 0 .025 .123 r
F
.85336 .44612 m .85218 .44455 L .8551 .44368 L F
.48169 .45022 m .48288 .44809 L .48441 .44955 L 0 .034 .136 r
F
.48169 .45022 m .48016 .44878 L .48288 .44809 L F
.80027 .44674 m .80192 .4442 L .80315 .4458 L 0 .026 .125 r
F
.80027 .44674 m .79904 .44514 L .80192 .4442 L F
.55996 .45066 m .56127 .44805 L .56273 .4497 L 0 .035 .136 r
F
.55996 .45066 m .5585 .44902 L .56127 .44805 L F
.6871 .44834 m .68859 .44593 L .68993 .44755 L 0 .03 .13 r
F
.6871 .44834 m .68576 .44674 L .68859 .44593 L F
.32091 .44739 m .32188 .4448 L .32356 .44643 L 0 .027 .127 r
F
.32091 .44739 m .31923 .44578 L .32188 .4448 L F
.75416 .44702 m .75575 .44459 L .75702 .44616 L 0 .027 .126 r
F
.75416 .44702 m .75289 .44547 L .75575 .44459 L F
.80726 .44645 m .80892 .44393 L .81014 .44552 L 0 .026 .124 r
F
.80726 .44645 m .80603 .44486 L .80892 .44393 L F
.56694 .4504 m .56826 .44776 L .56971 .44944 L 0 .034 .135 r
F
.56694 .4504 m .56549 .44873 L .56826 .44776 L F
.32788 .44712 m .32886 .44468 L .33052 .44635 L 0 .027 .127 r
F
.32788 .44712 m .32621 .44547 L .32886 .44468 L F
.50686 .4514 m .5081 .44907 L .5096 .45068 L 0 .037 .139 r
F
.50686 .4514 m .50536 .44975 L .5081 .44907 L F
.35306 .44811 m .35406 .44578 L .35571 .44735 L 0 .03 .13 r
F
.35306 .44811 m .3514 .44654 L .35406 .44578 L F
.61306 .45026 m .61445 .44766 L .61585 .44933 L 0 .034 .135 r
F
.61306 .45026 m .61165 .44856 L .61445 .44766 L F
.42435 .44892 m .42546 .44652 L .42704 .44823 L 0 .031 .132 r
F
.42435 .44892 m .42277 .44722 L .42546 .44652 L F
.44255 .45027 m .44369 .44777 L .44525 .44949 L 0 .034 .135 r
F
.44255 .45027 m .44098 .44854 L .44369 .44777 L F
.86037 .44604 m .86212 .44362 L .86329 .44522 L 0 .025 .124 r
F
.86037 .44604 m .8592 .44444 L .86212 .44362 L F
.81425 .44624 m .81593 .4438 L .81715 .44537 L F
.81425 .44624 m .81304 .44466 L .81593 .4438 L F
.62703 .44957 m .62844 .44734 L .62983 .44877 L 0 .033 .134 r
F
.62703 .44957 m .62564 .44816 L .62844 .44734 L F
.28873 .44708 m .28966 .4445 L .29136 .44622 L 0 .027 .126 r
F
.28873 .44708 m .28703 .44537 L .28966 .4445 L F
.76116 .4469 m .76276 .44447 L .76403 .44609 L F
.76116 .4469 m .75989 .44532 L .76276 .44447 L F
.62005 .45004 m .62144 .44747 L .62284 .44908 L 0 .034 .135 r
F
.62005 .45004 m .61865 .4484 L .62144 .44747 L F
.6941 .44834 m .69561 .44599 L .69694 .44756 L 0 .03 .13 r
F
.6941 .44834 m .69277 .44677 L .69561 .44599 L F
.57393 .45028 m .57526 .44793 L .5767 .44951 L 0 .035 .136 r
F
.57393 .45028 m .57248 .44868 L .57526 .44793 L F
.25656 .4466 m .25745 .44404 L .25918 .44571 L 0 .026 .125 r
F
.25656 .4466 m .25483 .44491 L .25745 .44404 L F
.82125 .44607 m .82294 .44353 L .82415 .44513 L 0 .025 .124 r
F
.82125 .44607 m .82004 .44448 L .82294 .44353 L F
.3852 .44899 m .38626 .44648 L .38788 .4481 L 0 .032 .132 r
F
.3852 .44899 m .38358 .44736 L .38626 .44648 L F
.63402 .44939 m .63544 .44716 L .63682 .4486 L 0 .033 .134 r
F
.63402 .44939 m .63263 .44796 L .63544 .44716 L F
.36002 .44807 m .36104 .44571 L .36268 .44726 L 0 .03 .13 r
F
.36002 .44807 m .35837 .44653 L .36104 .44571 L F
.48866 .45043 m .48987 .44803 L .49139 .44965 L 0 .035 .136 r
F
.48866 .45043 m .48714 .44882 L .48987 .44803 L F
.86739 .44598 m .86914 .44345 L .8703 .44507 L 0 .025 .124 r
F
.86739 .44598 m .86622 .44438 L .86914 .44345 L F
.70807 .44772 m .7096 .44531 L .71091 .44681 L 0 .029 .129 r
F
.70807 .44772 m .70676 .44623 L .7096 .44531 L F
.82825 .44579 m .82994 .44333 L .83115 .44494 L 0 .025 .123 r
F
.82825 .44579 m .82704 .44419 L .82994 .44333 L F
.29569 .447 m .29663 .44436 L .29833 .44607 L 0 .027 .126 r
F
.29569 .447 m .294 .44529 L .29663 .44436 L F
.70109 .44817 m .70261 .44572 L .70392 .4472 L 0 .03 .13 r
F
.70109 .44817 m .69977 .44671 L .70261 .44572 L F
.39217 .44878 m .39324 .44645 L .39485 .44799 L 0 .032 .132 r
F
.39217 .44878 m .39056 .44721 L .39324 .44645 L F
.76816 .44685 m .76978 .44449 L .77104 .44604 L 0 .027 .127 r
F
.76816 .44685 m .7669 .44529 L .76978 .44449 L F
.33483 .44726 m .33582 .44474 L .33748 .44644 L 0 .028 .128 r
F
.33483 .44726 m .33317 .44558 L .33582 .44474 L F
.52781 .45075 m .52907 .44831 L .53056 .44979 L 0 .036 .137 r
F
.52781 .45075 m .52632 .44931 L .52907 .44831 L F
.44952 .45037 m .45067 .44803 L .45222 .44969 L 0 .035 .137 r
F
.44952 .45037 m .44796 .4487 L .45067 .44803 L F
.87438 .44573 m .87615 .44328 L .87731 .44486 L 0 .025 .123 r
F
.87438 .44573 m .87322 .44415 L .87615 .44328 L F
.51384 .45155 m .51509 .44911 L .51658 .45068 L 0 .038 .14 r
F
.51384 .45155 m .51234 .44997 L .51509 .44911 L F
.26352 .44653 m .2644 .44413 L .26613 .44578 L 0 .027 .126 r
F
.26352 .44653 m .26179 .44488 L .2644 .44413 L F
.53479 .45041 m .53606 .44821 L .53754 .44968 L 0 .036 .137 r
F
.53479 .45041 m .53331 .44893 L .53606 .44821 L F
.71506 .44752 m .71659 .44503 L .71791 .44665 L 0 .029 .128 r
F
.71506 .44752 m .71375 .44592 L .71659 .44503 L F
.52082 .45121 m .52208 .44883 L .52357 .45031 L 0 .037 .139 r
F
.52082 .45121 m .51933 .44976 L .52208 .44883 L F
.58092 .45027 m .58226 .448 L .58369 .44951 L 0 .035 .137 r
F
.58092 .45027 m .57948 .44874 L .58226 .448 L F
.64101 .44932 m .64244 .44703 L .64382 .44853 L 0 .033 .134 r
F
.64101 .44932 m .63963 .44782 L .64244 .44703 L F
.36699 .44797 m .36802 .44556 L .36965 .44713 L 0 .03 .13 r
F
.36699 .44797 m .36535 .44642 L .36802 .44556 L F
.43131 .44922 m .43244 .4467 L .43401 .4484 L 0 .033 .133 r
F
.43131 .44922 m .42974 .44751 L .43244 .4467 L F
.83526 .44573 m .83697 .44332 L .83817 .44492 L 0 .025 .124 r
F
.83526 .44573 m .83406 .44413 L .83697 .44332 L F
.77517 .44672 m .77679 .44423 L .77803 .44577 L 0 .027 .126 r
F
.77517 .44672 m .77391 .44518 L .77679 .44423 L F
.30265 .44691 m .3036 .44436 L .30529 .44605 L 0 .027 .127 r
F
.30265 .44691 m .30096 .44521 L .3036 .44436 L F
.78215 .44637 m .78378 .44392 L .78503 .44548 L 0 .027 .126 r
F
.78215 .44637 m .78091 .44482 L .78378 .44392 L F
.88139 .4456 m .88317 .44317 L .88433 .44476 L 0 .025 .124 r
F
.88139 .4456 m .88024 .44402 L .88317 .44317 L F
.72206 .44735 m .7236 .44478 L .7249 .44641 L 0 .028 .128 r
F
.72206 .44735 m .72075 .44571 L .7236 .44478 L F
.39914 .44873 m .40022 .44647 L .40183 .44794 L 0 .032 .133 r
F
.39914 .44873 m .39753 .44724 L .40022 .44647 L F
.648 .44915 m .64943 .4465 L .6508 .44815 L F
.648 .44915 m .64662 .44752 L .64943 .4465 L F
.49564 .45051 m .49686 .44814 L .49837 .44973 L 0 .036 .137 r
F
.49564 .45051 m .49412 .44887 L .49686 .44814 L F
.34179 .44723 m .3428 .4446 L .34445 .44633 L 0 .028 .128 r
F
.34179 .44723 m .34014 .44552 L .3428 .4446 L F
.54177 .45034 m .54306 .44826 L .54453 .44963 L 0 .036 .138 r
F
.54177 .45034 m .5403 .44895 L .54306 .44826 L F
.72905 .44706 m .73059 .44448 L .73189 .44609 L 0 .028 .127 r
F
.72905 .44706 m .72775 .44545 L .73059 .44448 L F
.73603 .44668 m .7376 .4443 L .73889 .44584 L 0 .027 .127 r
F
.73603 .44668 m .73474 .44512 L .7376 .4443 L F
.37396 .44785 m .37499 .44559 L .37662 .44717 L 0 .03 .13 r
F
.37396 .44785 m .37232 .44629 L .37499 .44559 L F
.65498 .44882 m .65642 .44617 L .65779 .44787 L 0 .032 .132 r
F
.65498 .44882 m .65361 .44716 L .65642 .44617 L F
.66197 .44848 m .66343 .44604 L .66479 .4476 L 0 .031 .132 r
F
.66197 .44848 m .66061 .44691 L .66343 .44604 L F
.5879 .45023 m .58926 .44783 L .59068 .44933 L 0 .035 .137 r
F
.5879 .45023 m .58648 .44875 L .58926 .44783 L F
.45649 .45045 m .45765 .4482 L .4592 .44965 L 0 .036 .138 r
F
.45649 .45045 m .45493 .44901 L .45765 .4482 L F
.8884 .44542 m .89018 .44287 L .89132 .44447 L 0 .025 .123 r
F
.8884 .44542 m .88725 .44382 L .89018 .44287 L F
.59489 .4499 m .59625 .44746 L .59767 .44898 L 0 .035 .136 r
F
.59489 .4499 m .59347 .4484 L .59625 .44746 L F
.84227 .44563 m .84399 .44323 L .84518 .44477 L 0 .025 .124 r
F
.84227 .44563 m .84108 .44408 L .84399 .44323 L F
.78915 .44624 m .79079 .44375 L .79204 .44539 L 0 .026 .126 r
F
.78915 .44624 m .78791 .44462 L .79079 .44375 L F
.40612 .44858 m .4072 .4462 L .40881 .44771 L 0 .032 .132 r
F
.40612 .44858 m .40451 .44707 L .4072 .4462 L F
.27046 .44665 m .27136 .44412 L .27309 .44573 L 0 .027 .127 r
F
.27046 .44665 m .26874 .44502 L .27136 .44412 L F
.67594 .44782 m .67742 .44545 L .67876 .44687 L 0 .03 .13 r
F
.67594 .44782 m .6746 .44638 L .67742 .44545 L F
.66896 .44821 m .67043 .44586 L .67178 .44732 L 0 .031 .131 r
F
.66896 .44821 m .66761 .44674 L .67043 .44586 L F
.46347 .45015 m .46464 .4477 L .46619 .4492 L 0 .035 .137 r
F
.46347 .45015 m .46192 .44868 L .46464 .4477 L F
.30961 .44687 m .31057 .44431 L .31225 .44598 L 0 .028 .127 r
F
.30961 .44687 m .30793 .44518 L .31057 .44431 L F
.47045 .44979 m .47163 .44744 L .47317 .44891 L 0 .035 .136 r
F
.47045 .44979 m .46891 .44831 L .47163 .44744 L F
.60187 .4496 m .60325 .44712 L .60466 .4487 L 0 .034 .135 r
F
.60187 .4496 m .60046 .44805 L .60325 .44712 L F
.8954 .44516 m .89718 .44262 L .89833 .44427 L 0 .024 .123 r
F
.8954 .44516 m .89425 .44354 L .89718 .44262 L F
.27744 .44635 m .27835 .44382 L .28007 .4454 L 0 .027 .126 r
F
.27744 .44635 m .27572 .44476 L .27835 .44382 L F
.4131 .4483 m .4142 .44587 L .41579 .44735 L 0 .031 .132 r
F
.4131 .4483 m .4115 .4468 L .4142 .44587 L F
.74303 .44656 m .74461 .44421 L .74589 .44573 L 0 .028 .127 r
F
.74303 .44656 m .74175 .44503 L .74461 .44421 L F
.47743 .44947 m .47862 .44734 L .48016 .44878 L 0 .034 .136 r
F
.47743 .44947 m .4759 .44805 L .47862 .44734 L F
.84927 .44542 m .851 .44301 L .85218 .44455 L 0 .025 .124 r
F
.84927 .44542 m .84809 .44389 L .851 .44301 L F
.68293 .44755 m .68442 .44514 L .68576 .44674 L 0 .03 .13 r
F
.68293 .44755 m .68159 .44598 L .68442 .44514 L F
.42008 .44794 m .42118 .44567 L .42277 .44722 L 0 .031 .131 r
F
.42008 .44794 m .41849 .4464 L .42118 .44567 L F
.54876 .45027 m .55005 .44816 L .55152 .44949 L 0 .036 .138 r
F
.54876 .45027 m .54729 .44892 L .55005 .44816 L F
.43828 .44932 m .43942 .44682 L .44098 .44854 L 0 .033 .134 r
F
.43828 .44932 m .43671 .44759 L .43942 .44682 L F
.50262 .45053 m .50385 .44822 L .50536 .44975 L 0 .037 .138 r
F
.50262 .45053 m .50111 .44896 L .50385 .44822 L F
.79616 .44609 m .7978 .44351 L .79904 .44514 L 0 .026 .125 r
F
.79616 .44609 m .79492 .44445 L .7978 .44351 L F
.55574 .44997 m .55705 .44755 L .5585 .44902 L 0 .035 .136 r
F
.55574 .44997 m .55428 .44852 L .55705 .44755 L F
.34875 .44728 m .34976 .44482 L .3514 .44654 L 0 .029 .129 r
F
.34875 .44728 m .3471 .44556 L .34976 .44482 L F
.31658 .44673 m .31755 .44415 L .31923 .44578 L 0 .028 .127 r
F
.31658 .44673 m .3149 .44509 L .31755 .44415 L F
.60886 .44946 m .61024 .44694 L .61165 .44856 L 0 .034 .135 r
F
.60886 .44946 m .60745 .44781 L .61024 .44694 L F
.75003 .44637 m .75162 .44395 L .75289 .44547 L 0 .027 .127 r
F
.75003 .44637 m .74875 .44484 L .75162 .44395 L F
.80315 .4458 m .8048 .44325 L .80603 .44486 L 0 .026 .125 r
F
.80315 .4458 m .80192 .4442 L .8048 .44325 L F
.28441 .44619 m .28532 .44378 L .28703 .44537 L 0 .027 .126 r
F
.28441 .44619 m .28269 .44459 L .28532 .44378 L F
.90241 .44505 m .90421 .4425 L .90535 .44417 L 0 .024 .123 r
F
.90241 .44505 m .90127 .44338 L .90421 .4425 L F
.56273 .4497 m .56404 .44707 L .56549 .44873 L 0 .034 .135 r
F
.56273 .4497 m .56127 .44805 L .56404 .44707 L F
.85628 .44527 m .85802 .44284 L .8592 .44444 L 0 .025 .124 r
F
.85628 .44527 m .8551 .44368 L .85802 .44284 L F
.32356 .44643 m .32454 .44382 L .32621 .44547 L 0 .027 .126 r
F
.32356 .44643 m .32188 .4448 L .32454 .44382 L F
.81014 .44552 m .81182 .44308 L .81304 .44466 L 0 .026 .124 r
F
.81014 .44552 m .80892 .44393 L .81182 .44308 L F
.56971 .44944 m .57104 .44702 L .57248 .44868 L 0 .034 .135 r
F
.56971 .44944 m .56826 .44776 L .57104 .44702 L F
.75702 .44616 m .75862 .44372 L .75989 .44532 L 0 .027 .126 r
F
.75702 .44616 m .75575 .44459 L .75862 .44372 L F
.38091 .4481 m .38196 .44574 L .38358 .44736 L 0 .031 .132 r
F
.38091 .4481 m .37929 .44649 L .38196 .44574 L F
.25222 .44578 m .25309 .44327 L .25483 .44491 L 0 .026 .125 r
F
.25222 .44578 m .25048 .44415 L .25309 .44327 L F
.68993 .44755 m .69143 .44514 L .69277 .44677 L 0 .03 .13 r
F
.68993 .44755 m .68859 .44593 L .69143 .44514 L F
.61585 .44933 m .61724 .44676 L .61865 .4484 L 0 .034 .135 r
F
.61585 .44933 m .61445 .44766 L .61724 .44676 L F
.48441 .44955 m .48561 .44732 L .48714 .44882 L 0 .035 .136 r
F
.48441 .44955 m .48288 .44809 L .48561 .44732 L F
.81715 .44537 m .81883 .44293 L .82004 .44448 L 0 .025 .124 r
F
.81715 .44537 m .81593 .4438 L .81883 .44293 L F
.33052 .44635 m .3315 .44388 L .33317 .44558 L 0 .028 .127 r
F
.33052 .44635 m .32886 .44468 L .3315 .44388 L F
.62284 .44908 m .62424 .44656 L .62564 .44816 L 0 .034 .134 r
F
.62284 .44908 m .62144 .44747 L .62424 .44656 L F
.86329 .44522 m .86505 .44277 L .86622 .44438 L 0 .025 .124 r
F
.86329 .44522 m .86212 .44362 L .86505 .44277 L F
.35571 .44735 m .35673 .44496 L .35837 .44653 L 0 .03 .13 r
F
.35571 .44735 m .35406 .44578 L .35673 .44496 L F
.44525 .44949 m .4464 .447 L .44796 .4487 L 0 .035 .136 r
F
.44525 .44949 m .44369 .44777 L .4464 .447 L F
.29136 .44622 m .2923 .44358 L .294 .44529 L 0 .027 .126 r
F
.29136 .44622 m .28966 .4445 L .2923 .44358 L F
.5096 .45068 m .51084 .44839 L .51234 .44997 L 0 .038 .139 r
F
.5096 .45068 m .5081 .44907 L .51084 .44839 L F
.62983 .44877 m .63125 .44651 L .63263 .44796 L 0 .033 .134 r
F
.62983 .44877 m .62844 .44734 L .63125 .44651 L F
.76403 .44609 m .76564 .44367 L .7669 .44529 L 0 .027 .127 r
F
.76403 .44609 m .76276 .44447 L .76564 .44367 L F
.25918 .44571 m .26006 .44322 L .26179 .44488 L 0 .026 .125 r
F
.25918 .44571 m .25745 .44404 L .26006 .44322 L F
.42704 .44823 m .42816 .4458 L .42974 .44751 L 0 .032 .132 r
F
.42704 .44823 m .42546 .44652 L .42816 .4458 L F
.82415 .44513 m .82583 .44259 L .82704 .44419 L 0 .025 .124 r
F
.82415 .44513 m .82294 .44353 L .82583 .44259 L F
.38788 .4481 m .38894 .4456 L .39056 .44721 L 0 .032 .132 r
F
.38788 .4481 m .38626 .44648 L .38894 .4456 L F
.69694 .44756 m .69845 .44514 L .69977 .44671 L 0 .031 .131 r
F
.69694 .44756 m .69561 .44599 L .69845 .44514 L F
.5767 .44951 m .57804 .44718 L .57948 .44874 L 0 .035 .136 r
F
.5767 .44951 m .57526 .44793 L .57804 .44718 L F
.8703 .44507 m .87206 .44252 L .87322 .44415 L 0 .025 .124 r
F
.8703 .44507 m .86914 .44345 L .87206 .44252 L F
.71091 .44681 m .71244 .4444 L .71375 .44592 L 0 .029 .129 r
F
.71091 .44681 m .7096 .44531 L .71244 .4444 L F
.70392 .4472 m .70544 .44474 L .70676 .44623 L 0 .03 .13 r
F
.70392 .4472 m .70261 .44572 L .70544 .44474 L F
.29833 .44607 m .29927 .44351 L .30096 .44521 L 0 .027 .126 r
F
.29833 .44607 m .29663 .44436 L .29927 .44351 L F
.63682 .4486 m .63825 .44637 L .63963 .44782 L 0 .033 .134 r
F
.63682 .4486 m .63544 .44716 L .63825 .44637 L F
.36268 .44726 m .36371 .44485 L .36535 .44642 L 0 .03 .13 r
F
.36268 .44726 m .36104 .44571 L .36371 .44485 L F
.83115 .44494 m .83286 .44251 L .83406 .44413 L 0 .025 .124 r
F
.83115 .44494 m .82994 .44333 L .83286 .44251 L F
.53056 .44979 m .53183 .44744 L .53331 .44893 L 0 .036 .137 r
F
.53056 .44979 m .52907 .44831 L .53183 .44744 L F
.49139 .44965 m .4926 .44724 L .49412 .44887 L F
.49139 .44965 m .48987 .44803 L .4926 .44724 L F
.87731 .44486 m .87908 .44243 L .88024 .44402 L 0 .025 .124 r
F
.87731 .44486 m .87615 .44328 L .87908 .44243 L F
.51658 .45068 m .51783 .44818 L .51933 .44976 L 0 .038 .14 r
F
.51658 .45068 m .51509 .44911 L .51783 .44818 L F
.77104 .44604 m .77266 .44363 L .77391 .44518 L 0 .028 .127 r
F
.77104 .44604 m .76978 .44449 L .77266 .44363 L F
.52357 .45031 m .52483 .44782 L .52632 .44931 L 0 .037 .139 r
F
.52357 .45031 m .52208 .44883 L .52483 .44782 L F
.39485 .44799 m .39592 .44574 L .39753 .44724 L 0 .032 .133 r
F
.39485 .44799 m .39324 .44645 L .39592 .44574 L F
.33748 .44644 m .33848 .4438 L .34014 .44552 L 0 .028 .128 r
F
.33748 .44644 m .33582 .44474 L .33848 .4438 L F
.71791 .44665 m .71944 .4441 L .72075 .44571 L 0 .029 .128 r
F
.71791 .44665 m .71659 .44503 L .71944 .4441 L F
.77803 .44577 m .77966 .44328 L .78091 .44482 L 0 .027 .126 r
F
.77803 .44577 m .77679 .44423 L .77966 .44328 L F
.26613 .44578 m .26701 .44339 L .26874 .44502 L F
.26613 .44578 m .2644 .44413 L .26701 .44339 L F
.36965 .44713 m .37069 .44469 L .37232 .44629 L 0 .03 .13 r
F
.36965 .44713 m .36802 .44556 L .37069 .44469 L F
.53754 .44968 m .53882 .44749 L .5403 .44895 L 0 .036 .138 r
F
.53754 .44968 m .53606 .44821 L .53882 .44749 L F
.45222 .44969 m .45338 .44736 L .45493 .44901 L 0 .036 .137 r
F
.45222 .44969 m .45067 .44803 L .45338 .44736 L F
.64382 .44853 m .64525 .44601 L .64662 .44752 L 0 .033 .134 r
F
.64382 .44853 m .64244 .44703 L .64525 .44601 L F
.6508 .44815 m .65224 .44549 L .65361 .44716 L 0 .032 .133 r
F
.6508 .44815 m .64943 .4465 L .65224 .44549 L F
.7249 .44641 m .72644 .44383 L .72775 .44545 L 0 .028 .128 r
F
.7249 .44641 m .7236 .44478 L .72644 .44383 L F
.58369 .44951 m .58504 .44725 L .58648 .44875 L 0 .036 .137 r
F
.58369 .44951 m .58226 .448 L .58504 .44725 L F
.30529 .44605 m .30624 .4435 L .30793 .44518 L 0 .028 .127 r
F
.30529 .44605 m .3036 .44436 L .30624 .4435 L F
.78503 .44548 m .78667 .44304 L .78791 .44462 L 0 .027 .126 r
F
.78503 .44548 m .78378 .44392 L .78667 .44304 L F
.43401 .4484 m .43514 .44589 L .43671 .44759 L 0 .033 .134 r
F
.43401 .4484 m .43244 .4467 L .43514 .44589 L F
.83817 .44492 m .83988 .44248 L .84108 .44408 L 0 .025 .124 r
F
.83817 .44492 m .83697 .44332 L .83988 .44248 L F
.73189 .44609 m .73344 .4435 L .73474 .44512 L 0 .028 .127 r
F
.73189 .44609 m .73059 .44448 L .73344 .4435 L F
.88433 .44476 m .8861 .44224 L .88725 .44382 L 0 .025 .124 r
F
.88433 .44476 m .88317 .44317 L .8861 .44224 L F
.65779 .44787 m .65924 .44519 L .66061 .44691 L 0 .031 .132 r
F
.65779 .44787 m .65642 .44617 L .65924 .44519 L F
.34445 .44633 m .34545 .44383 L .3471 .44556 L 0 .028 .128 r
F
.34445 .44633 m .3428 .4446 L .34545 .44383 L F
.40183 .44794 m .40291 .4456 L .40451 .44707 L 0 .032 .133 r
F
.40183 .44794 m .40022 .44647 L .40291 .4456 L F
.89132 .44447 m .89311 .44193 L .89425 .44354 L 0 .024 .123 r
F
.89132 .44447 m .89018 .44287 L .89311 .44193 L F
.73889 .44584 m .74046 .4435 L .74175 .44503 L 0 .028 .127 r
F
.73889 .44584 m .7376 .4443 L .74046 .4435 L F
.59068 .44933 m .59204 .44687 L .59347 .4484 L 0 .035 .137 r
F
.59068 .44933 m .58926 .44783 L .59204 .44687 L F
.49837 .44973 m .4996 .44742 L .50111 .44896 L 0 .036 .138 r
F
.49837 .44973 m .49686 .44814 L .4996 .44742 L F
.66479 .4476 m .66625 .44519 L .66761 .44674 L 0 .031 .132 r
F
.66479 .4476 m .66343 .44604 L .66625 .44519 L F
.59767 .44898 m .59904 .4465 L .60046 .44805 L 0 .034 .136 r
F
.59767 .44898 m .59625 .44746 L .59904 .4465 L F
.67876 .44687 m .68025 .44456 L .68159 .44598 L 0 .03 .13 r
F
.67876 .44687 m .67742 .44545 L .68025 .44456 L F
.46619 .4492 m .46737 .4468 L .46891 .44831 L 0 .035 .136 r
F
.46619 .4492 m .46464 .4477 L .46737 .4468 L F
.27309 .44573 m .27399 .44317 L .27572 .44476 L 0 .027 .126 r
F
.27309 .44573 m .27136 .44412 L .27399 .44317 L F
.84518 .44477 m .84691 .44236 L .84809 .44389 L 0 .025 .124 r
F
.84518 .44477 m .84399 .44323 L .84691 .44236 L F
.54453 .44963 m .54582 .44757 L .54729 .44892 L 0 .037 .138 r
F
.54453 .44963 m .54306 .44826 L .54582 .44757 L F
.67178 .44732 m .67325 .44495 L .6746 .44638 L 0 .031 .131 r
F
.67178 .44732 m .67043 .44586 L .67325 .44495 L F
.40881 .44771 m .4099 .44531 L .4115 .4468 L 0 .032 .132 r
F
.40881 .44771 m .4072 .4462 L .4099 .44531 L F
.4592 .44965 m .46037 .44719 L .46192 .44868 L 0 .036 .138 r
F
.4592 .44965 m .45765 .4482 L .46037 .44719 L F
.79204 .44539 m .79368 .44281 L .79492 .44445 L 0 .026 .126 r
F
.79204 .44539 m .79079 .44375 L .79368 .44281 L F
.28007 .4454 m .28097 .44302 L .28269 .44459 L 0 .027 .126 r
F
.28007 .4454 m .27835 .44382 L .28097 .44302 L F
.31225 .44598 m .31321 .44344 L .3149 .44509 L 0 .028 .127 r
F
.31225 .44598 m .31057 .44431 L .31321 .44344 L F
.60466 .4487 m .60604 .44623 L .60745 .44781 L 0 .034 .135 r
F
.60466 .4487 m .60325 .44712 L .60604 .44623 L F
.41579 .44735 m .4169 .44493 L .41849 .4464 L 0 .031 .131 r
F
.41579 .44735 m .4142 .44587 L .4169 .44493 L F
.47317 .44891 m .47436 .44658 L .4759 .44805 L 0 .035 .136 r
F
.47317 .44891 m .47163 .44744 L .47436 .44658 L F
.37662 .44717 m .37766 .44488 L .37929 .44649 L 0 .031 .131 r
F
.37662 .44717 m .37499 .44559 L .37766 .44488 L F
.89833 .44427 m .90012 .44171 L .90127 .44338 L 0 .024 .123 r
F
.89833 .44427 m .89718 .44262 L .90012 .44171 L F
.85218 .44455 m .85392 .44213 L .8551 .44368 L 0 .025 .124 r
F
.85218 .44455 m .851 .44301 L .85392 .44213 L F
.5585 .44902 m .55981 .44658 L .56127 .44805 L 0 .035 .136 r
F
.5585 .44902 m .55705 .44755 L .55981 .44658 L F
.79904 .44514 m .80068 .44256 L .80192 .4442 L 0 .026 .125 r
F
.79904 .44514 m .7978 .44351 L .80068 .44256 L F
.74589 .44573 m .74748 .44335 L .74875 .44484 L 0 .028 .127 r
F
.74589 .44573 m .74461 .44421 L .74748 .44335 L F
.68576 .44674 m .68725 .44431 L .68859 .44593 L 0 .03 .13 r
F
.68576 .44674 m .68442 .44514 L .68725 .44431 L F
.31923 .44578 m .3202 .44318 L .32188 .4448 L 0 .027 .127 r
F
.31923 .44578 m .31755 .44415 L .3202 .44318 L F
.55152 .44949 m .55282 .44718 L .55428 .44852 L 0 .036 .138 r
F
.55152 .44949 m .55005 .44816 L .55282 .44718 L F
.44098 .44854 m .44213 .44608 L .44369 .44777 L 0 .034 .135 r
F
.44098 .44854 m .43942 .44682 L .44213 .44608 L F
.56549 .44873 m .56681 .44609 L .56826 .44776 L F
.56549 .44873 m .56404 .44707 L .56681 .44609 L F
.80603 .44486 m .80769 .44231 L .80892 .44393 L 0 .026 .125 r
F
.80603 .44486 m .8048 .44325 L .80769 .44231 L F
.61165 .44856 m .61304 .44606 L .61445 .44766 L 0 .034 .135 r
F
.61165 .44856 m .61024 .44694 L .61304 .44606 L F
.75289 .44547 m .75448 .44306 L .75575 .44459 L 0 .027 .127 r
F
.75289 .44547 m .75162 .44395 L .75448 .44306 L F
.42277 .44722 m .42388 .44497 L .42546 .44652 L 0 .031 .132 r
F
.42277 .44722 m .42118 .44567 L .42388 .44497 L F
.32621 .44547 m .32719 .443 L .32886 .44468 L 0 .027 .126 r
F
.32621 .44547 m .32454 .44382 L .32719 .443 L F
.48016 .44878 m .48135 .44662 L .48288 .44809 L 0 .035 .136 r
F
.48016 .44878 m .47862 .44734 L .48135 .44662 L F
.50536 .44975 m .50659 .44757 L .5081 .44907 L 0 .037 .139 r
F
.50536 .44975 m .50385 .44822 L .50659 .44757 L F
.90535 .44417 m .90715 .44161 L .90829 .44327 L 0 .024 .123 r
F
.90535 .44417 m .90421 .4425 L .90715 .44161 L F
.28703 .44537 m .28795 .44291 L .28966 .4445 L 0 .027 .126 r
F
.28703 .44537 m .28532 .44378 L .28795 .44291 L F
.3514 .44654 m .35242 .44406 L .35406 .44578 L 0 .03 .13 r
F
.3514 .44654 m .34976 .44482 L .35242 .44406 L F
.8592 .44444 m .86095 .44202 L .86212 .44362 L 0 .025 .124 r
F
.8592 .44444 m .85802 .44284 L .86095 .44202 L F
.81304 .44466 m .81472 .44224 L .81593 .4438 L 0 .026 .124 r
F
.81304 .44466 m .81182 .44308 L .81472 .44224 L F
.25483 .44491 m .25571 .44239 L .25745 .44404 L 0 .026 .125 r
F
.25483 .44491 m .25309 .44327 L .25571 .44239 L F
.61865 .4484 m .62004 .44585 L .62144 .44747 L 0 .034 .135 r
F
.61865 .4484 m .61724 .44676 L .62004 .44585 L F
.75989 .44532 m .76149 .44286 L .76276 .44447 L 0 .027 .126 r
F
.75989 .44532 m .75862 .44372 L .76149 .44286 L F
.57248 .44868 m .57382 .44628 L .57526 .44793 L 0 .035 .136 r
F
.57248 .44868 m .57104 .44702 L .57382 .44628 L F
.69277 .44677 m .69427 .44434 L .69561 .44599 L 0 .03 .131 r
F
.69277 .44677 m .69143 .44514 L .69427 .44434 L F
.38358 .44736 m .38464 .44483 L .38626 .44648 L 0 .032 .132 r
F
.38358 .44736 m .38196 .44574 L .38464 .44483 L F
.82004 .44448 m .82173 .44199 L .82294 .44353 L 0 .025 .124 r
F
.82004 .44448 m .81883 .44293 L .82173 .44199 L F
.62564 .44816 m .62705 .44571 L .62844 .44734 L 0 .034 .134 r
F
.62564 .44816 m .62424 .44656 L .62705 .44571 L F
.294 .44529 m .29494 .44265 L .29663 .44436 L 0 .027 .126 r
F
.294 .44529 m .2923 .44358 L .29494 .44265 L F
.48714 .44882 m .48835 .44649 L .48987 .44803 L 0 .035 .137 r
F
.48714 .44882 m .48561 .44732 L .48835 .44649 L F
.86622 .44438 m .86796 .44182 L .86914 .44345 L 0 .025 .124 r
F
.86622 .44438 m .86505 .44277 L .86796 .44182 L F
.82704 .44419 m .82874 .44172 L .82994 .44333 L F
.82704 .44419 m .82583 .44259 L .82874 .44172 L F
.35837 .44653 m .35939 .44413 L .36104 .44571 L 0 .03 .13 r
F
.35837 .44653 m .35673 .44496 L .35939 .44413 L F
.33317 .44558 m .33416 .44303 L .33582 .44474 L 0 .028 .127 r
F
.33317 .44558 m .3315 .44388 L .33416 .44303 L F
.44796 .4487 m .44911 .44635 L .45067 .44803 L 0 .035 .136 r
F
.44796 .4487 m .4464 .447 L .44911 .44635 L F
.63263 .44796 m .63406 .4457 L .63544 .44716 L 0 .034 .135 r
F
.63263 .44796 m .63125 .44651 L .63406 .4457 L F
.26179 .44488 m .26267 .44249 L .2644 .44413 L 0 .027 .126 r
F
.26179 .44488 m .26006 .44322 L .26267 .44249 L F
.70676 .44623 m .70828 .4438 L .7096 .44531 L 0 .029 .129 r
F
.70676 .44623 m .70544 .44474 L .70828 .4438 L F
.39056 .44721 m .39162 .44485 L .39324 .44645 L 0 .032 .132 r
F
.39056 .44721 m .38894 .4456 L .39162 .44485 L F
.7669 .44529 m .76852 .44286 L .76978 .44449 L 0 .027 .127 r
F
.7669 .44529 m .76564 .44367 L .76852 .44286 L F
.87322 .44415 m .87498 .44163 L .87615 .44328 L 0 .025 .124 r
F
.87322 .44415 m .87206 .44252 L .87498 .44163 L F
.51234 .44997 m .51359 .44753 L .51509 .44911 L 0 .038 .14 r
F
.51234 .44997 m .51084 .44839 L .51359 .44753 L F
.71375 .44592 m .71529 .44349 L .71659 .44503 L 0 .029 .129 r
F
.71375 .44592 m .71244 .4444 L .71529 .44349 L F
.69977 .44671 m .70128 .44414 L .70261 .44572 L 0 .03 .131 r
F
.69977 .44671 m .69845 .44514 L .70128 .44414 L F
.42974 .44751 m .43086 .44499 L .43244 .4467 L 0 .032 .133 r
F
.42974 .44751 m .42816 .4458 L .43086 .44499 L F
.30096 .44521 m .30191 .44266 L .3036 .44436 L 0 .027 .127 r
F
.30096 .44521 m .29927 .44351 L .30191 .44266 L F
.52632 .44931 m .52758 .44681 L .52907 .44831 L 0 .037 .138 r
F
.52632 .44931 m .52483 .44782 L .52758 .44681 L F
.53331 .44893 m .53458 .44673 L .53606 .44821 L 0 .036 .138 r
F
.53331 .44893 m .53183 .44744 L .53458 .44673 L F
.36535 .44642 m .36638 .44397 L .36802 .44556 L 0 .03 .13 r
F
.36535 .44642 m .36371 .44485 L .36638 .44397 L F
.57948 .44874 m .58082 .44645 L .58226 .448 L 0 .036 .137 r
F
.57948 .44874 m .57804 .44718 L .58082 .44645 L F
.83406 .44413 m .83577 .44169 L .83697 .44332 L 0 .025 .124 r
F
.83406 .44413 m .83286 .44251 L .83577 .44169 L F
.51933 .44976 m .52058 .44724 L .52208 .44883 L 0 .038 .139 r
F
.51933 .44976 m .51783 .44818 L .52058 .44724 L F
.63963 .44782 m .64107 .44557 L .64244 .44703 L 0 .034 .135 r
F
.63963 .44782 m .63825 .44637 L .64107 .44557 L F
.72075 .44571 m .72229 .44318 L .7236 .44478 L 0 .028 .128 r
F
.72075 .44571 m .71944 .4441 L .72229 .44318 L F
.34014 .44552 m .34114 .44287 L .3428 .4446 L 0 .028 .127 r
F
.34014 .44552 m .33848 .4438 L .34114 .44287 L F
.77391 .44518 m .77553 .44268 L .77679 .44423 L 0 .027 .127 r
F
.77391 .44518 m .77266 .44363 L .77553 .44268 L F
.88024 .44402 m .88202 .44158 L .88317 .44317 L 0 .025 .124 r
F
.88024 .44402 m .87908 .44243 L .88202 .44158 L F
.49412 .44887 m .49534 .44655 L .49686 .44814 L 0 .036 .137 r
F
.49412 .44887 m .4926 .44724 L .49534 .44655 L F
.64662 .44752 m .64806 .44498 L .64943 .4465 L 0 .033 .133 r
F
.64662 .44752 m .64525 .44601 L .64806 .44498 L F
.78091 .44482 m .78254 .44237 L .78378 .44392 L 0 .027 .126 r
F
.78091 .44482 m .77966 .44328 L .78254 .44237 L F
.65361 .44716 m .65505 .44448 L .65642 .44617 L 0 .032 .132 r
F
.65361 .44716 m .65224 .44549 L .65505 .44448 L F
.72775 .44545 m .72929 .44285 L .73059 .44448 L 0 .028 .127 r
F
.72775 .44545 m .72644 .44383 L .72929 .44285 L F
.39753 .44724 m .3986 .44501 L .40022 .44647 L 0 .033 .133 r
F
.39753 .44724 m .39592 .44574 L .3986 .44501 L F
.73474 .44512 m .73631 .44267 L .7376 .4443 L 0 .028 .127 r
F
.73474 .44512 m .73344 .4435 L .73631 .44267 L F
.37232 .44629 m .37336 .44396 L .37499 .44559 L 0 .03 .131 r
F
.37232 .44629 m .37069 .44469 L .37336 .44396 L F
.66061 .44691 m .66206 .44433 L .66343 .44604 L 0 .031 .132 r
F
.66061 .44691 m .65924 .44519 L .66206 .44433 L F
.88725 .44382 m .88903 .4413 L .89018 .44287 L 0 .025 .123 r
F
.88725 .44382 m .8861 .44224 L .88903 .4413 L F
.30793 .44518 m .30888 .44265 L .31057 .44431 L 0 .028 .127 r
F
.30793 .44518 m .30624 .4435 L .30888 .44265 L F
.78791 .44462 m .78955 .44215 L .79079 .44375 L 0 .027 .126 r
F
.78791 .44462 m .78667 .44304 L .78955 .44215 L F
.26874 .44502 m .26963 .4425 L .27136 .44412 L 0 .027 .127 r
F
.26874 .44502 m .26701 .44339 L .26963 .4425 L F
.84108 .44408 m .8428 .44164 L .84399 .44323 L 0 .026 .124 r
F
.84108 .44408 m .83988 .44248 L .8428 .44164 L F
.58648 .44875 m .58783 .44633 L .58926 .44783 L 0 .036 .137 r
F
.58648 .44875 m .58504 .44725 L .58783 .44633 L F
.43671 .44759 m .43785 .44514 L .43942 .44682 L 0 .033 .134 r
F
.43671 .44759 m .43514 .44589 L .43785 .44514 L F
.5403 .44895 m .54158 .44678 L .54306 .44826 L 0 .037 .138 r
F
.5403 .44895 m .53882 .44749 L .54158 .44678 L F
.89425 .44354 m .89604 .441 L .89718 .44262 L 0 .024 .123 r
F
.89425 .44354 m .89311 .44193 L .89604 .441 L F
.59347 .4484 m .59483 .4459 L .59625 .44746 L 0 .035 .136 r
F
.59347 .4484 m .59204 .44687 L .59483 .4459 L F
.40451 .44707 m .4056 .44473 L .4072 .4462 L 0 .032 .133 r
F
.40451 .44707 m .40291 .4456 L .4056 .44473 L F
.45493 .44901 m .45609 .44657 L .45765 .4482 L 0 .037 .138 r
F
.45493 .44901 m .45338 .44736 L .45609 .44657 L F
.60046 .44805 m .60183 .44554 L .60325 .44712 L 0 .034 .135 r
F
.60046 .44805 m .59904 .4465 L .60183 .44554 L F
.27572 .44476 m .27662 .44224 L .27835 .44382 L 0 .027 .126 r
F
.27572 .44476 m .27399 .44317 L .27662 .44224 L F
.3471 .44556 m .34811 .44309 L .34976 .44482 L 0 .029 .129 r
F
.3471 .44556 m .34545 .44383 L .34811 .44309 L F
.46192 .44868 m .46309 .44618 L .46464 .4477 L 0 .036 .137 r
F
.46192 .44868 m .46037 .44719 L .46309 .44618 L F
.66761 .44674 m .66908 .44434 L .67043 .44586 L 0 .031 .132 r
F
.66761 .44674 m .66625 .44519 L .66908 .44434 L F
.68159 .44598 m .68308 .4437 L .68442 .44514 L 0 .03 .13 r
F
.68159 .44598 m .68025 .44456 L .68308 .4437 L F
.46891 .44831 m .47009 .44592 L .47163 .44744 L 0 .035 .136 r
F
.46891 .44831 m .46737 .4468 L .47009 .44592 L F
.6746 .44638 m .67608 .44404 L .67742 .44545 L 0 .031 .131 r
F
.6746 .44638 m .67325 .44495 L .67608 .44404 L F
.79492 .44445 m .79656 .44187 L .7978 .44351 L 0 .026 .125 r
F
.79492 .44445 m .79368 .44281 L .79656 .44187 L F
.74175 .44503 m .74333 .4427 L .74461 .44421 L 0 .028 .127 r
F
.74175 .44503 m .74046 .4435 L .74333 .4427 L F
.41849 .4464 m .41959 .44419 L .42118 .44567 L 0 .031 .132 r
F
.41849 .4464 m .4169 .44493 L .41959 .44419 L F
.84809 .44389 m .84982 .44147 L .851 .44301 L 0 .025 .124 r
F
.84809 .44389 m .84691 .44236 L .84982 .44147 L F
.4115 .4468 m .4126 .44438 L .4142 .44587 L 0 .032 .132 r
F
.4115 .4468 m .4099 .44531 L .4126 .44438 L F
.50111 .44896 m .50234 .44673 L .50385 .44822 L 0 .037 .139 r
F
.50111 .44896 m .4996 .44742 L .50234 .44673 L F
.3149 .44509 m .31586 .44252 L .31755 .44415 L 0 .028 .127 r
F
.3149 .44509 m .31321 .44344 L .31586 .44252 L F
.60745 .44781 m .60883 .44538 L .61024 .44694 L 0 .034 .135 r
F
.60745 .44781 m .60604 .44623 L .60883 .44538 L F
.90127 .44338 m .90306 .44082 L .90421 .4425 L 0 .024 .123 r
F
.90127 .44338 m .90012 .44171 L .90306 .44082 L F
.56127 .44805 m .56259 .44559 L .56404 .44707 L 0 .035 .136 r
F
.56127 .44805 m .55981 .44658 L .56259 .44559 L F
.4759 .44805 m .47709 .44583 L .47862 .44734 L F
.4759 .44805 m .47436 .44658 L .47709 .44583 L F
.80192 .4442 m .80357 .4416 L .8048 .44325 L 0 .026 .125 r
F
.80192 .4442 m .80068 .44256 L .80357 .4416 L F
.28269 .44459 m .2836 .44222 L .28532 .44378 L 0 .027 .126 r
F
.28269 .44459 m .28097 .44302 L .2836 .44222 L F
.32188 .4448 m .32286 .44222 L .32454 .44382 L F
.32188 .4448 m .3202 .44318 L .32286 .44222 L F
.74875 .44484 m .75034 .44249 L .75162 .44395 L 0 .028 .127 r
F
.74875 .44484 m .74748 .44335 L .75034 .44249 L F
.55428 .44852 m .55559 .44619 L .55705 .44755 L 0 .036 .137 r
F
.55428 .44852 m .55282 .44718 L .55559 .44619 L F
.8551 .44368 m .85684 .44129 L .85802 .44284 L 0 .025 .124 r
F
.8551 .44368 m .85392 .44213 L .85684 .44129 L F
.54729 .44892 m .54859 .44682 L .55005 .44816 L 0 .037 .139 r
F
.54729 .44892 m .54582 .44757 L .54859 .44682 L F
.56826 .44776 m .56959 .44535 L .57104 .44702 L 0 .034 .135 r
F
.56826 .44776 m .56681 .44609 L .56959 .44535 L F
.80892 .44393 m .81059 .44147 L .81182 .44308 L 0 .026 .124 r
F
.80892 .44393 m .80769 .44231 L .81059 .44147 L F
.25048 .44415 m .25134 .44168 L .25309 .44327 L 0 .026 .125 r
F
.25048 .44415 m .24873 .44258 L .25134 .44168 L F
.37929 .44649 m .38034 .44411 L .38196 .44574 L 0 .031 .132 r
F
.37929 .44649 m .37766 .44488 L .38034 .44411 L F
.61445 .44766 m .61584 .44518 L .61724 .44676 L 0 .034 .135 r
F
.61445 .44766 m .61304 .44606 L .61584 .44518 L F
.68859 .44593 m .69009 .4435 L .69143 .44514 L 0 .03 .13 r
F
.68859 .44593 m .68725 .44431 L .69009 .4435 L F
.75575 .44459 m .75735 .44217 L .75862 .44372 L 0 .027 .127 r
F
.75575 .44459 m .75448 .44306 L .75735 .44217 L F
.90829 .44327 m .9101 .44071 L .91123 .44238 L 0 .024 .123 r
F
.90829 .44327 m .90715 .44161 L .9101 .44071 L F
.44369 .44777 m .44483 .44533 L .4464 .447 L 0 .034 .135 r
F
.44369 .44777 m .44213 .44608 L .44483 .44533 L F
.32886 .44468 m .32984 .44219 L .3315 .44388 L 0 .027 .127 r
F
.32886 .44468 m .32719 .443 L .32984 .44219 L F
.28966 .4445 m .29059 .44198 L .2923 .44358 L 0 .027 .126 r
F
.28966 .4445 m .28795 .44291 L .29059 .44198 L F
.62144 .44747 m .62284 .44495 L .62424 .44656 L 0 .034 .135 r
F
.62144 .44747 m .62004 .44585 L .62284 .44495 L F
.81593 .4438 m .81762 .44138 L .81883 .44293 L 0 .026 .125 r
F
.81593 .4438 m .81472 .44224 L .81762 .44138 L F
.42546 .44652 m .42658 .44424 L .42816 .4458 L 0 .032 .132 r
F
.42546 .44652 m .42388 .44497 L .42658 .44424 L F
.86212 .44362 m .86387 .44117 L .86505 .44277 L 0 .025 .124 r
F
.86212 .44362 m .86095 .44202 L .86387 .44117 L F
.48288 .44809 m .48408 .44582 L .48561 .44732 L 0 .036 .137 r
F
.48288 .44809 m .48135 .44662 L .48408 .44582 L F
.5081 .44907 m .50933 .44693 L .51084 .44839 L 0 .038 .14 r
F
.5081 .44907 m .50659 .44757 L .50933 .44693 L F
.25745 .44404 m .25832 .44157 L .26006 .44322 L 0 .026 .125 r
F
.25745 .44404 m .25571 .44239 L .25832 .44157 L F
.35406 .44578 m .35508 .44323 L .35673 .44496 L 0 .03 .13 r
F
.35406 .44578 m .35242 .44406 L .35508 .44323 L F
.76276 .44447 m .76437 .44204 L .76564 .44367 L 0 .027 .127 r
F
.76276 .44447 m .76149 .44286 L .76437 .44204 L F
.82294 .44353 m .82463 .44105 L .82583 .44259 L 0 .025 .124 r
F
.82294 .44353 m .82173 .44199 L .82463 .44105 L F
.38626 .44648 m .38733 .44393 L .38894 .4456 L 0 .032 .132 r
F
.38626 .44648 m .38464 .44483 L .38733 .44393 L F
.29663 .44436 m .29757 .44181 L .29927 .44351 L 0 .027 .126 r
F
.29663 .44436 m .29494 .44265 L .29757 .44181 L F
.86914 .44345 m .87088 .44088 L .87206 .44252 L 0 .025 .124 r
F
.86914 .44345 m .86796 .44182 L .87088 .44088 L F
.62844 .44734 m .62985 .44485 L .63125 .44651 L 0 .034 .135 r
F
.62844 .44734 m .62705 .44571 L .62985 .44485 L F
.69561 .44599 m .69712 .44348 L .69845 .44514 L 0 .031 .131 r
F
.69561 .44599 m .69427 .44434 L .69712 .44348 L F
.57526 .44793 m .5766 .44554 L .57804 .44718 L 0 .035 .137 r
F
.57526 .44793 m .57382 .44628 L .5766 .44554 L F
.82994 .44333 m .83165 .44089 L .83286 .44251 L 0 .025 .124 r
F
.82994 .44333 m .82874 .44172 L .83165 .44089 L F
.7096 .44531 m .71113 .44287 L .71244 .4444 L 0 .029 .129 r
F
.7096 .44531 m .70828 .4438 L .71113 .44287 L F
.48987 .44803 m .49108 .44566 L .4926 .44724 L 0 .036 .137 r
F
.48987 .44803 m .48835 .44649 L .49108 .44566 L F
.33582 .44474 m .33682 .44208 L .33848 .4438 L 0 .028 .127 r
F
.33582 .44474 m .33416 .44303 L .33682 .44208 L F
.36104 .44571 m .36206 .44326 L .36371 .44485 L 0 .03 .13 r
F
.36104 .44571 m .35939 .44413 L .36206 .44326 L F
.70261 .44572 m .70412 .44314 L .70544 .44474 L F
.70261 .44572 m .70128 .44414 L .70412 .44314 L F
.52907 .44831 m .53034 .44594 L .53183 .44744 L 0 .036 .138 r
F
.52907 .44831 m .52758 .44681 L .53034 .44594 L F
.87615 .44328 m .87792 .44077 L .87908 .44243 L 0 .025 .124 r
F
.87615 .44328 m .87498 .44163 L .87792 .44077 L F
.71659 .44503 m .71814 .44258 L .71944 .4441 L 0 .029 .129 r
F
.71659 .44503 m .71529 .44349 L .71814 .44258 L F
.63544 .44716 m .63687 .44489 L .63825 .44637 L 0 .034 .135 r
F
.63544 .44716 m .63406 .4457 L .63687 .44489 L F
.51509 .44911 m .51634 .44659 L .51783 .44818 L 0 .038 .14 r
F
.51509 .44911 m .51359 .44753 L .51634 .44659 L F
.76978 .44449 m .7714 .44199 L .77266 .44363 L 0 .028 .127 r
F
.76978 .44449 m .76852 .44286 L .7714 .44199 L F
.39324 .44645 m .39431 .44415 L .39592 .44574 L 0 .032 .133 r
F
.39324 .44645 m .39162 .44485 L .39431 .44415 L F
.2644 .44413 m .26528 .44176 L .26701 .44339 L 0 .027 .126 r
F
.2644 .44413 m .26267 .44249 L .26528 .44176 L F
.45067 .44803 m .45182 .44569 L .45338 .44736 L 0 .036 .137 r
F
.45067 .44803 m .44911 .44635 L .45182 .44569 L F
.3036 .44436 m .30455 .44182 L .30624 .4435 L 0 .027 .127 r
F
.3036 .44436 m .30191 .44266 L .30455 .44182 L F
.52208 .44883 m .52334 .44626 L .52483 .44782 L 0 .037 .139 r
F
.52208 .44883 m .52058 .44724 L .52334 .44626 L F
.64943 .4465 m .65087 .44396 L .65224 .44549 L 0 .032 .133 r
F
.64943 .4465 m .64806 .44498 L .65087 .44396 L F
.43244 .4467 m .43357 .44418 L .43514 .44589 L 0 .033 .133 r
F
.43244 .4467 m .43086 .44499 L .43357 .44418 L F
.7236 .44478 m .72514 .44222 L .72644 .44383 L 0 .028 .128 r
F
.7236 .44478 m .72229 .44318 L .72514 .44222 L F
.36802 .44556 m .36905 .44309 L .37069 .44469 L 0 .03 .13 r
F
.36802 .44556 m .36638 .44397 L .36905 .44309 L F
.3428 .4446 m .3438 .4421 L .34545 .44383 L 0 .028 .128 r
F
.3428 .4446 m .34114 .44287 L .3438 .4421 L F
.77679 .44423 m .77841 .44173 L .77966 .44328 L 0 .027 .127 r
F
.77679 .44423 m .77553 .44268 L .77841 .44173 L F
.65642 .44617 m .65787 .44347 L .65924 .44519 L 0 .031 .132 r
F
.65642 .44617 m .65505 .44448 L .65787 .44347 L F
.73059 .44448 m .73214 .44187 L .73344 .4435 L 0 .028 .127 r
F
.73059 .44448 m .72929 .44285 L .73214 .44187 L F
.83697 .44332 m .83868 .44084 L .83988 .44248 L 0 .025 .124 r
F
.83697 .44332 m .83577 .44169 L .83868 .44084 L F
.78378 .44392 m .78542 .44148 L .78667 .44304 L 0 .027 .126 r
F
.78378 .44392 m .78254 .44237 L .78542 .44148 L F
.58226 .448 m .58361 .44572 L .58504 .44725 L 0 .036 .138 r
F
.58226 .448 m .58082 .44645 L .58361 .44572 L F
.64244 .44703 m .64387 .44454 L .64525 .44601 L 0 .034 .135 r
F
.64244 .44703 m .64107 .44557 L .64387 .44454 L F
.53606 .44821 m .53734 .44602 L .53882 .44749 L 0 .037 .138 r
F
.53606 .44821 m .53458 .44673 L .53734 .44602 L F
.88317 .44317 m .88495 .44065 L .8861 .44224 L 0 .025 .124 r
F
.88317 .44317 m .88202 .44158 L .88495 .44065 L F
.89018 .44287 m .89196 .44036 L .89311 .44193 L 0 .025 .123 r
F
.89018 .44287 m .88903 .4413 L .89196 .44036 L F
.49686 .44814 m .49808 .44587 L .4996 .44742 L 0 .037 .138 r
F
.49686 .44814 m .49534 .44655 L .49808 .44587 L F
.66343 .44604 m .66489 .4435 L .66625 .44519 L 0 .031 .132 r
F
.66343 .44604 m .66206 .44433 L .66489 .4435 L F
.7376 .4443 m .73917 .44187 L .74046 .4435 L 0 .028 .127 r
F
.7376 .4443 m .73631 .44267 L .73917 .44187 L F
.27136 .44412 m .27226 .44157 L .27399 .44317 L 0 .027 .127 r
F
.27136 .44412 m .26963 .4425 L .27226 .44157 L F
.31057 .44431 m .31153 .44179 L .31321 .44344 L 0 .028 .127 r
F
.31057 .44431 m .30888 .44265 L .31153 .44179 L F
.79079 .44375 m .79244 .44122 L .79368 .44281 L 0 .027 .126 r
F
.79079 .44375 m .78955 .44215 L .79244 .44122 L F
.40022 .44647 m .40129 .44413 L .40291 .4456 L 0 .033 .134 r
F
.40022 .44647 m .3986 .44501 L .40129 .44413 L F
.58926 .44783 m .59061 .44534 L .59204 .44687 L 0 .036 .137 r
F
.58926 .44783 m .58783 .44633 L .59061 .44534 L F
.59625 .44746 m .59762 .44492 L .59904 .4465 L 0 .035 .136 r
F
.59625 .44746 m .59483 .4459 L .59762 .44492 L F
.89718 .44262 m .89898 .44007 L .90012 .44171 L 0 .024 .123 r
F
.89718 .44262 m .89604 .441 L .89898 .44007 L F
.84399 .44323 m .84572 .44077 L .84691 .44236 L 0 .026 .124 r
F
.84399 .44323 m .8428 .44164 L .84572 .44077 L F
.46464 .4477 m .46582 .44528 L .46737 .4468 L 0 .036 .137 r
F
.46464 .4477 m .46309 .44618 L .46582 .44528 L F
.27835 .44382 m .27925 .44145 L .28097 .44302 L 0 .027 .126 r
F
.27835 .44382 m .27662 .44224 L .27925 .44145 L F
.60325 .44712 m .60462 .44465 L .60604 .44623 L 0 .034 .135 r
F
.60325 .44712 m .60183 .44554 L .60462 .44465 L F
.37499 .44559 m .37603 .44324 L .37766 .44488 L 0 .031 .131 r
F
.37499 .44559 m .37336 .44396 L .37603 .44324 L F
.4072 .4462 m .40829 .44383 L .4099 .44531 L 0 .032 .133 r
F
.4072 .4462 m .4056 .44473 L .40829 .44383 L F
.7978 .44351 m .79945 .44091 L .80068 .44256 L 0 .026 .125 r
F
.7978 .44351 m .79656 .44187 L .79945 .44091 L F
.67742 .44545 m .67891 .44315 L .68025 .44456 L 0 .031 .131 r
F
.67742 .44545 m .67608 .44404 L .67891 .44315 L F
.43942 .44682 m .44056 .44443 L .44213 .44608 L 0 .034 .135 r
F
.43942 .44682 m .43785 .44514 L .44056 .44443 L F
.67043 .44586 m .67191 .44344 L .67325 .44495 L 0 .031 .132 r
F
.67043 .44586 m .66908 .44434 L .67191 .44344 L F
.4142 .44587 m .4153 .44345 L .4169 .44493 L 0 .032 .132 r
F
.4142 .44587 m .4126 .44438 L .4153 .44345 L F
.45765 .4482 m .45882 .44559 L .46037 .44719 L 0 .037 .138 r
F
.45765 .4482 m .45609 .44657 L .45882 .44559 L F
.47163 .44744 m .47282 .44505 L .47436 .44658 L 0 .035 .136 r
F
.47163 .44744 m .47009 .44592 L .47282 .44505 L F
.31755 .44415 m .31852 .44157 L .3202 .44318 L 0 .027 .127 r
F
.31755 .44415 m .31586 .44252 L .31852 .44157 L F
.56404 .44707 m .56536 .44461 L .56681 .44609 L 0 .034 .135 r
F
.56404 .44707 m .56259 .44559 L .56536 .44461 L F
.851 .44301 m .85274 .44057 L .85392 .44213 L 0 .025 .124 r
F
.851 .44301 m .84982 .44147 L .85274 .44057 L F
.68442 .44514 m .68592 .44284 L .68725 .44431 L 0 .03 .13 r
F
.68442 .44514 m .68308 .4437 L .68592 .44284 L F
.54306 .44826 m .54435 .44608 L .54582 .44757 L 0 .038 .139 r
F
.54306 .44826 m .54158 .44678 L .54435 .44608 L F
.32454 .44382 m .32551 .44142 L .32719 .443 L 0 .027 .126 r
F
.32454 .44382 m .32286 .44222 L .32551 .44142 L F
.74461 .44421 m .7462 .44186 L .74748 .44335 L 0 .028 .128 r
F
.74461 .44421 m .74333 .4427 L .7462 .44186 L F
.61024 .44694 m .61163 .44453 L .61304 .44606 L 0 .034 .135 r
F
.61024 .44694 m .60883 .44538 L .61163 .44453 L F
.8048 .44325 m .80646 .44064 L .80769 .44231 L 0 .026 .125 r
F
.8048 .44325 m .80357 .4416 L .80646 .44064 L F
.34976 .44482 m .35077 .44233 L .35242 .44406 L 0 .029 .129 r
F
.34976 .44482 m .34811 .44309 L .35077 .44233 L F
.90421 .4425 m .90601 .43994 L .90715 .44161 L 0 .024 .123 r
F
.90421 .4425 m .90306 .44082 L .90601 .43994 L F
.55705 .44755 m .55836 .44521 L .55981 .44658 L 0 .036 .137 r
F
.55705 .44755 m .55559 .44619 L .55836 .44521 L F
.42118 .44567 m .42229 .44349 L .42388 .44497 L 0 .032 .132 r
F
.42118 .44567 m .41959 .44419 L .42229 .44349 L F
.75162 .44395 m .75321 .44159 L .75448 .44306 L 0 .028 .127 r
F
.75162 .44395 m .75034 .44249 L .75321 .44159 L F
.50385 .44822 m .50508 .44611 L .50659 .44757 L 0 .038 .139 r
F
.50385 .44822 m .50234 .44673 L .50508 .44611 L F
.28532 .44378 m .28623 .44135 L .28795 .44291 L 0 .027 .127 r
F
.28532 .44378 m .2836 .44222 L .28623 .44135 L F
.85802 .44284 m .85977 .44047 L .86095 .44202 L 0 .025 .124 r
F
.85802 .44284 m .85684 .44129 L .85977 .44047 L F
.47862 .44734 m .47982 .44507 L .48135 .44662 L 0 .036 .137 r
F
.47862 .44734 m .47709 .44583 L .47982 .44507 L F
.61724 .44676 m .61864 .4443 L .62004 .44585 L 0 .034 .135 r
F
.61724 .44676 m .61584 .44518 L .61864 .4443 L F
.25309 .44327 m .25396 .44079 L .25571 .44239 L 0 .026 .125 r
F
.25309 .44327 m .25134 .44168 L .25396 .44079 L F
.81182 .44308 m .8135 .44064 L .81472 .44224 L F
.81182 .44308 m .81059 .44147 L .8135 .44064 L F
.55005 .44816 m .55135 .44582 L .55282 .44718 L 0 .037 .139 r
F
.55005 .44816 m .54859 .44682 L .55135 .44582 L F
.57104 .44702 m .57237 .44462 L .57382 .44628 L 0 .035 .136 r
F
.57104 .44702 m .56959 .44535 L .57237 .44462 L F
.75862 .44372 m .76022 .44128 L .76149 .44286 L 0 .027 .127 r
F
.75862 .44372 m .75735 .44217 L .76022 .44128 L F
.91123 .44238 m .91304 .43977 L .91417 .44143 L 0 .024 .123 r
F
.91123 .44238 m .9101 .44071 L .91304 .43977 L F
.2923 .44358 m .29323 .44104 L .29494 .44265 L 0 .027 .126 r
F
.2923 .44358 m .29059 .44198 L .29323 .44104 L F
.69143 .44514 m .69294 .4427 L .69427 .44434 L 0 .03 .131 r
F
.69143 .44514 m .69009 .4435 L .69294 .4427 L F
.38196 .44574 m .38302 .44318 L .38464 .44483 L 0 .032 .132 r
F
.38196 .44574 m .38034 .44411 L .38302 .44318 L F
.62424 .44656 m .62565 .44407 L .62705 .44571 L 0 .034 .135 r
F
.62424 .44656 m .62284 .44495 L .62565 .44407 L F
.3315 .44388 m .33249 .44131 L .33416 .44303 L 0 .028 .127 r
F
.3315 .44388 m .32984 .44219 L .33249 .44131 L F
.81883 .44293 m .82052 .44045 L .82173 .44199 L 0 .026 .125 r
F
.81883 .44293 m .81762 .44138 L .82052 .44045 L F
.4464 .447 m .44754 .44469 L .44911 .44635 L 0 .035 .136 r
F
.4464 .447 m .44483 .44533 L .44754 .44469 L F
.86505 .44277 m .86679 .4402 L .86796 .44182 L 0 .025 .124 r
F
.86505 .44277 m .86387 .44117 L .86679 .4402 L F
.82583 .44259 m .82754 .44018 L .82874 .44172 L F
.82583 .44259 m .82463 .44105 L .82754 .44018 L F
.35673 .44496 m .35775 .4424 L .35939 .44413 L 0 .03 .13 r
F
.35673 .44496 m .35508 .44323 L .35775 .4424 L F
.26006 .44322 m .26093 .44084 L .26267 .44249 L 0 .027 .126 r
F
.26006 .44322 m .25832 .44157 L .26093 .44084 L F
.48561 .44732 m .48682 .44495 L .48835 .44649 L 0 .036 .137 r
F
.48561 .44732 m .48408 .44582 L .48682 .44495 L F
.38894 .4456 m .39001 .44316 L .39162 .44485 L 0 .032 .132 r
F
.38894 .4456 m .38733 .44393 L .39001 .44316 L F
.76564 .44367 m .76725 .44122 L .76852 .44286 L 0 .028 .127 r
F
.76564 .44367 m .76437 .44204 L .76725 .44122 L F
.42816 .4458 m .42928 .44341 L .43086 .44499 L 0 .032 .133 r
F
.42816 .4458 m .42658 .44424 L .42928 .44341 L F
.87206 .44252 m .87381 .43997 L .87498 .44163 L 0 .025 .124 r
F
.87206 .44252 m .87088 .44088 L .87381 .43997 L F
.29927 .44351 m .30021 .44097 L .30191 .44266 L 0 .027 .126 r
F
.29927 .44351 m .29757 .44181 L .30021 .44097 L F
.51084 .44839 m .51208 .44609 L .51359 .44753 L 0 .039 .14 r
F
.51084 .44839 m .50933 .44693 L .51208 .44609 L F
.70544 .44474 m .70696 .44218 L .70828 .4438 L 0 .03 .13 r
F
.70544 .44474 m .70412 .44314 L .70696 .44218 L F
.69845 .44514 m .69995 .44247 L .70128 .44414 L 0 .03 .131 r
F
.69845 .44514 m .69712 .44348 L .69995 .44247 L F
.63125 .44651 m .63266 .44401 L .63406 .4457 L 0 .034 .135 r
F
.63125 .44651 m .62985 .44485 L .63266 .44401 L F
.33848 .4438 m .33949 .44114 L .34114 .44287 L 0 .028 .127 r
F
.33848 .4438 m .33682 .44208 L .33949 .44114 L F
.71244 .4444 m .71398 .44194 L .71529 .44349 L 0 .029 .129 r
F
.71244 .4444 m .71113 .44287 L .71398 .44194 L F
.83286 .44251 m .83456 .44005 L .83577 .44169 L 0 .025 .124 r
F
.83286 .44251 m .83165 .44089 L .83456 .44005 L F
.36371 .44485 m .36474 .44237 L .36638 .44397 L 0 .03 .13 r
F
.36371 .44485 m .36206 .44326 L .36474 .44237 L F
.57804 .44718 m .57938 .4448 L .58082 .44645 L 0 .036 .137 r
F
.57804 .44718 m .5766 .44554 L .57938 .4448 L F
.51783 .44818 m .51909 .44565 L .52058 .44724 L 0 .038 .14 r
F
.51783 .44818 m .51634 .44659 L .51909 .44565 L F
.71944 .4441 m .72099 .44167 L .72229 .44318 L 0 .029 .129 r
F
.71944 .4441 m .71814 .44258 L .72099 .44167 L F
.65224 .44549 m .65368 .44294 L .65505 .44448 L 0 .032 .132 r
F
.65224 .44549 m .65087 .44396 L .65368 .44294 L F
.52483 .44782 m .52609 .44527 L .52758 .44681 L 0 .037 .139 r
F
.52483 .44782 m .52334 .44626 L .52609 .44527 L F
.4926 .44724 m .49382 .44497 L .49534 .44655 L 0 .036 .138 r
F
.4926 .44724 m .49108 .44566 L .49382 .44497 L F
.53183 .44744 m .5331 .44524 L .53458 .44673 L 0 .037 .138 r
F
.53183 .44744 m .53034 .44594 L .5331 .44524 L F
.87908 .44243 m .88085 .43991 L .88202 .44158 L 0 .025 .124 r
F
.87908 .44243 m .87792 .44077 L .88085 .43991 L F
.72644 .44383 m .72799 .44124 L .72929 .44285 L 0 .028 .128 r
F
.72644 .44383 m .72514 .44222 L .72799 .44124 L F
.77266 .44363 m .77427 .44102 L .77553 .44268 L 0 .028 .127 r
F
.77266 .44363 m .7714 .44199 L .77427 .44102 L F
.65924 .44519 m .66069 .44262 L .66206 .44433 L 0 .031 .131 r
F
.65924 .44519 m .65787 .44347 L .66069 .44262 L F
.63825 .44637 m .63969 .44407 L .64107 .44557 L 0 .034 .135 r
F
.63825 .44637 m .63687 .44489 L .63969 .44407 L F
.77966 .44328 m .78129 .44081 L .78254 .44237 L 0 .027 .126 r
F
.77966 .44328 m .77841 .44173 L .78129 .44081 L F
.64525 .44601 m .64669 .44352 L .64806 .44498 L 0 .033 .134 r
F
.64525 .44601 m .64387 .44454 L .64669 .44352 L F
.30624 .4435 m .30719 .44099 L .30888 .44265 L 0 .028 .127 r
F
.30624 .4435 m .30455 .44182 L .30719 .44099 L F
.73344 .4435 m .73501 .44103 L .73631 .44267 L F
.73344 .4435 m .73214 .44187 L .73501 .44103 L F
.37069 .44469 m .37173 .44233 L .37336 .44396 L 0 .03 .131 r
F
.37069 .44469 m .36905 .44309 L .37173 .44233 L F
.43514 .44589 m .43628 .44345 L .43785 .44514 L 0 .033 .134 r
F
.43514 .44589 m .43357 .44418 L .43628 .44345 L F
.26701 .44339 m .2679 .44089 L .26963 .4425 L 0 .027 .127 r
F
.26701 .44339 m .26528 .44176 L .2679 .44089 L F
.8861 .44224 m .88788 .43972 L .88903 .4413 L 0 .025 .124 r
F
.8861 .44224 m .88495 .44065 L .88788 .43972 L F
.39592 .44574 m .39699 .44343 L .3986 .44501 L 0 .033 .134 r
F
.39592 .44574 m .39431 .44415 L .39699 .44343 L F
.78667 .44304 m .78831 .44059 L .78955 .44215 L 0 .027 .126 r
F
.78667 .44304 m .78542 .44148 L .78831 .44059 L F
.34545 .44383 m .34646 .44136 L .34811 .44309 L 0 .028 .128 r
F
.34545 .44383 m .3438 .4421 L .34646 .44136 L F
.83988 .44248 m .8416 .44 L .8428 .44164 L 0 .026 .124 r
F
.83988 .44248 m .83868 .44084 L .8416 .44 L F
.45338 .44736 m .45454 .44492 L .45609 .44657 L 0 .037 .138 r
F
.45338 .44736 m .45182 .44569 L .45454 .44492 L F
.89311 .44193 m .8949 .43942 L .89604 .441 L 0 .024 .123 r
F
.89311 .44193 m .89196 .44036 L .8949 .43942 L F
.27399 .44317 m .2749 .44066 L .27662 .44224 L 0 .027 .126 r
F
.27399 .44317 m .27226 .44157 L .2749 .44066 L F
.58504 .44725 m .58639 .44478 L .58783 .44633 L 0 .036 .138 r
F
.58504 .44725 m .58361 .44572 L .58639 .44478 L F
.59204 .44687 m .5934 .44434 L .59483 .4459 L 0 .035 .137 r
F
.59204 .44687 m .59061 .44534 L .5934 .44434 L F
.79368 .44281 m .79532 .44029 L .79656 .44187 L 0 .026 .125 r
F
.79368 .44281 m .79244 .44122 L .79532 .44029 L F
.59904 .4465 m .60041 .44394 L .60183 .44554 L 0 .034 .136 r
F
.59904 .4465 m .59762 .44492 L .60041 .44394 L F
.53882 .44749 m .54011 .44531 L .54158 .44678 L 0 .038 .139 r
F
.53882 .44749 m .53734 .44602 L .54011 .44531 L F
.31321 .44344 m .31418 .44089 L .31586 .44252 L 0 .028 .127 r
F
.31321 .44344 m .31153 .44179 L .31418 .44089 L F
.66625 .44519 m .66772 .44266 L .66908 .44434 L 0 .032 .132 r
F
.66625 .44519 m .66489 .4435 L .66772 .44266 L F
.90012 .44171 m .90192 .43918 L .90306 .44082 L 0 .024 .122 r
F
.90012 .44171 m .89898 .44007 L .90192 .43918 L F
.40291 .4456 m .40399 .44325 L .4056 .44473 L 0 .033 .134 r
F
.40291 .4456 m .40129 .44413 L .40399 .44325 L F
.46737 .4468 m .46854 .4444 L .47009 .44592 L 0 .036 .137 r
F
.46737 .4468 m .46582 .44528 L .46854 .4444 L F
.74046 .4435 m .74204 .44106 L .74333 .4427 L 0 .028 .128 r
F
.74046 .4435 m .73917 .44187 L .74204 .44106 L F
.46037 .44719 m .46154 .44461 L .46309 .44618 L 0 .036 .138 r
F
.46037 .44719 m .45882 .44559 L .46154 .44461 L F
.60604 .44623 m .60742 .44383 L .60883 .44538 L 0 .034 .135 r
F
.60604 .44623 m .60462 .44465 L .60742 .44383 L F
.84691 .44236 m .84863 .43986 L .84982 .44147 L 0 .026 .124 r
F
.84691 .44236 m .84572 .44077 L .84863 .43986 L F
.80068 .44256 m .80233 .43994 L .80357 .4416 L 0 .026 .125 r
F
.80068 .44256 m .79945 .44091 L .80233 .43994 L F
.4996 .44742 m .50082 .44522 L .50234 .44673 L 0 .037 .139 r
F
.4996 .44742 m .49808 .44587 L .50082 .44522 L F
.4099 .44531 m .41099 .4429 L .4126 .44438 L 0 .032 .133 r
F
.4099 .44531 m .40829 .44383 L .41099 .4429 L F
.56681 .44609 m .56814 .44388 L .56959 .44535 L 0 .034 .135 r
F
.56681 .44609 m .56536 .44461 L .56814 .44388 L F
.4169 .44493 m .41799 .44271 L .41959 .44419 L 0 .032 .132 r
F
.4169 .44493 m .4153 .44345 L .41799 .44271 L F
.3202 .44318 m .32117 .44063 L .32286 .44222 L 0 .027 .127 r
F
.3202 .44318 m .31852 .44157 L .32117 .44063 L F
.68025 .44456 m .68175 .44226 L .68308 .4437 L 0 .031 .131 r
F
.68025 .44456 m .67891 .44315 L .68175 .44226 L F
.67325 .44495 m .67474 .44255 L .67608 .44404 L 0 .031 .132 r
F
.67325 .44495 m .67191 .44344 L .67474 .44255 L F
.28097 .44302 m .28187 .44067 L .2836 .44222 L 0 .027 .127 r
F
.28097 .44302 m .27925 .44145 L .28187 .44067 L F
.55981 .44658 m .56113 .44423 L .56259 .44559 L 0 .035 .137 r
F
.55981 .44658 m .55836 .44521 L .56113 .44423 L F
.47436 .44658 m .47555 .44426 L .47709 .44583 L F
.47436 .44658 m .47282 .44505 L .47555 .44426 L F
.80769 .44231 m .80936 .4398 L .81059 .44147 L 0 .026 .124 r
F
.80769 .44231 m .80646 .44064 L .80936 .4398 L F
.85392 .44213 m .85567 .43973 L .85684 .44129 L 0 .025 .124 r
F
.85392 .44213 m .85274 .44057 L .85567 .43973 L F
.37766 .44488 m .37871 .44244 L .38034 .44411 L 0 .031 .132 r
F
.37766 .44488 m .37603 .44324 L .37871 .44244 L F
.68725 .44431 m .68876 .44201 L .69009 .4435 L 0 .03 .131 r
F
.68725 .44431 m .68592 .44284 L .68876 .44201 L F
.61304 .44606 m .61443 .44368 L .61584 .44518 L 0 .034 .135 r
F
.61304 .44606 m .61163 .44453 L .61443 .44368 L F
.74748 .44335 m .74907 .44101 L .75034 .44249 L 0 .028 .128 r
F
.74748 .44335 m .7462 .44186 L .74907 .44101 L F
.90715 .44161 m .90896 .43905 L .9101 .44071 L 0 .024 .123 r
F
.90715 .44161 m .90601 .43994 L .90896 .43905 L F
.24873 .44258 m .24959 .4401 L .25134 .44168 L 0 .026 .125 r
F
.24873 .44258 m .24697 .44101 L .24959 .4401 L F
.44213 .44608 m .44327 .44372 L .44483 .44533 L 0 .034 .135 r
F
.44213 .44608 m .44056 .44443 L .44327 .44372 L F
.32719 .443 m .32816 .44062 L .32984 .44219 L 0 .027 .127 r
F
.32719 .443 m .32551 .44142 L .32816 .44062 L F
.75448 .44306 m .75608 .44068 L .75735 .44217 L 0 .028 .127 r
F
.75448 .44306 m .75321 .44159 L .75608 .44068 L F
.35242 .44406 m .35344 .4415 L .35508 .44323 L 0 .03 .13 r
F
.35242 .44406 m .35077 .44233 L .35344 .4415 L F
.55282 .44718 m .55412 .44483 L .55559 .44619 L 0 .037 .139 r
F
.55282 .44718 m .55135 .44582 L .55412 .44483 L F
.28795 .44291 m .28887 .44042 L .29059 .44198 L 0 .027 .127 r
F
.28795 .44291 m .28623 .44135 L .28887 .44042 L F
.54582 .44757 m .54712 .44532 L .54859 .44682 L 0 .038 .14 r
F
.54582 .44757 m .54435 .44608 L .54712 .44532 L F
.62004 .44585 m .62144 .44341 L .62284 .44495 L 0 .034 .135 r
F
.62004 .44585 m .61864 .4443 L .62144 .44341 L F
.25571 .44239 m .25658 .43995 L .25832 .44157 L 0 .026 .125 r
F
.25571 .44239 m .25396 .44079 L .25658 .43995 L F
.91417 .44143 m .91598 .43882 L .91712 .44049 L 0 .024 .122 r
F
.91417 .44143 m .91304 .43977 L .91598 .43882 L F
.86095 .44202 m .8627 .43961 L .86387 .44117 L 0 .026 .124 r
F
.86095 .44202 m .85977 .44047 L .8627 .43961 L F
.81472 .44224 m .8164 .43979 L .81762 .44138 L 0 .026 .125 r
F
.81472 .44224 m .8135 .44064 L .8164 .43979 L F
.42388 .44497 m .42499 .44274 L .42658 .44424 L 0 .032 .133 r
F
.42388 .44497 m .42229 .44349 L .42499 .44274 L F
.29494 .44265 m .29587 .4402 L .29757 .44181 L 0 .027 .126 r
F
.29494 .44265 m .29323 .44104 L .29587 .4402 L F
.76149 .44286 m .7631 .44046 L .76437 .44204 L 0 .027 .127 r
F
.76149 .44286 m .76022 .44128 L .7631 .44046 L F
.38464 .44483 m .38571 .44225 L .38733 .44393 L 0 .031 .132 r
F
.38464 .44483 m .38302 .44318 L .38571 .44225 L F
.50659 .44757 m .50782 .44549 L .50933 .44693 L 0 .039 .141 r
F
.50659 .44757 m .50508 .44611 L .50782 .44549 L F
.48135 .44662 m .48255 .44424 L .48408 .44582 L 0 .036 .137 r
F
.48135 .44662 m .47982 .44507 L .48255 .44424 L F
.82173 .44199 m .82342 .43952 L .82463 .44105 L 0 .026 .124 r
F
.82173 .44199 m .82052 .44045 L .82342 .43952 L F
.57382 .44628 m .57515 .44389 L .5766 .44554 L 0 .035 .136 r
F
.57382 .44628 m .57237 .44462 L .57515 .44389 L F
.69427 .44434 m .69578 .44182 L .69712 .44348 L 0 .031 .131 r
F
.69427 .44434 m .69294 .4427 L .69578 .44182 L F
.86796 .44182 m .86971 .43924 L .87088 .44088 L 0 .025 .124 r
F
.86796 .44182 m .86679 .4402 L .86971 .43924 L F
.62705 .44571 m .62846 .44319 L .62985 .44485 L 0 .034 .135 r
F
.62705 .44571 m .62565 .44407 L .62846 .44319 L F
.33416 .44303 m .33516 .44036 L .33682 .44208 L 0 .028 .127 r
F
.33416 .44303 m .33249 .44131 L .33516 .44036 L F
.82874 .44172 m .83045 .43934 L .83165 .44089 L 0 .025 .124 r
F
.82874 .44172 m .82754 .44018 L .83045 .43934 L F
.35939 .44413 m .36042 .44155 L .36206 .44326 L 0 .03 .13 r
F
.35939 .44413 m .35775 .4424 L .36042 .44155 L F
.70128 .44414 m .70279 .44147 L .70412 .44314 L F
.70128 .44414 m .69995 .44247 L .70279 .44147 L F
.87498 .44163 m .87675 .43909 L .87792 .44077 L 0 .025 .124 r
F
.87498 .44163 m .87381 .43997 L .87675 .43909 L F
.48835 .44649 m .48956 .44407 L .49108 .44566 L 0 .036 .137 r
F
.48835 .44649 m .48682 .44495 L .48956 .44407 L F
.70828 .4438 m .70981 .44123 L .71113 .44287 L 0 .03 .13 r
F
.70828 .4438 m .70696 .44218 L .70981 .44123 L F
.44911 .44635 m .45026 .44405 L .45182 .44569 L 0 .036 .137 r
F
.44911 .44635 m .44754 .44469 L .45026 .44405 L F
.43086 .44499 m .43199 .44257 L .43357 .44418 L 0 .033 .133 r
F
.43086 .44499 m .42928 .44341 L .43199 .44257 L F
.30191 .44266 m .30285 .44014 L .30455 .44182 L 0 .027 .127 r
F
.30191 .44266 m .30021 .44097 L .30285 .44014 L F
.76852 .44286 m .77013 .44035 L .7714 .44199 L 0 .028 .127 r
F
.76852 .44286 m .76725 .44122 L .77013 .44035 L F
.34114 .44287 m .34214 .44037 L .3438 .4421 L F
.34114 .44287 m .33949 .44114 L .34214 .44037 L F
.51359 .44753 m .51483 .44516 L .51634 .44659 L 0 .039 .14 r
F
.51359 .44753 m .51208 .44609 L .51483 .44516 L F
.26267 .44249 m .26354 .44011 L .26528 .44176 L 0 .027 .126 r
F
.26267 .44249 m .26093 .44084 L .26354 .44011 L F
.71529 .44349 m .71683 .44105 L .71814 .44258 L 0 .029 .129 r
F
.71529 .44349 m .71398 .44194 L .71683 .44105 L F
.39162 .44485 m .39269 .44244 L .39431 .44415 L 0 .032 .133 r
F
.39162 .44485 m .39001 .44316 L .39269 .44244 L F
.65505 .44448 m .6565 .44191 L .65787 .44347 L 0 .031 .132 r
F
.65505 .44448 m .65368 .44294 L .6565 .44191 L F
.52758 .44681 m .52885 .44442 L .53034 .44594 L 0 .037 .138 r
F
.52758 .44681 m .52609 .44527 L .52885 .44442 L F
.52058 .44724 m .52184 .44469 L .52334 .44626 L 0 .038 .139 r
F
.52058 .44724 m .51909 .44565 L .52184 .44469 L F
.63406 .4457 m .63548 .44318 L .63687 .44489 L 0 .034 .135 r
F
.63406 .4457 m .63266 .44401 L .63548 .44318 L F
.72229 .44318 m .72384 .44073 L .72514 .44222 L 0 .029 .128 r
F
.72229 .44318 m .72099 .44167 L .72384 .44073 L F
.36638 .44397 m .36741 .44147 L .36905 .44309 L 0 .03 .13 r
F
.36638 .44397 m .36474 .44237 L .36741 .44147 L F
.72929 .44285 m .73084 .44026 L .73214 .44187 L 0 .028 .127 r
F
.72929 .44285 m .72799 .44124 L .73084 .44026 L F
.64806 .44498 m .6495 .44249 L .65087 .44396 L 0 .033 .133 r
F
.64806 .44498 m .64669 .44352 L .6495 .44249 L F
.83577 .44169 m .83748 .4392 L .83868 .44084 L 0 .025 .124 r
F
.83577 .44169 m .83456 .44005 L .83748 .4392 L F
.77553 .44268 m .77715 .44005 L .77841 .44173 L 0 .027 .127 r
F
.77553 .44268 m .77427 .44102 L .77715 .44005 L F
.88202 .44158 m .88378 .43898 L .88495 .44065 L 0 .025 .124 r
F
.88202 .44158 m .88085 .43991 L .88378 .43898 L F
.78254 .44237 m .78418 .43991 L .78542 .44148 L 0 .027 .126 r
F
.78254 .44237 m .78129 .44081 L .78418 .43991 L F
.58082 .44645 m .58217 .44407 L .58361 .44572 L 0 .036 .138 r
F
.58082 .44645 m .57938 .4448 L .58217 .44407 L F
.66206 .44433 m .66352 .4418 L .66489 .4435 L 0 .031 .132 r
F
.66206 .44433 m .66069 .44262 L .66352 .4418 L F
.30888 .44265 m .30983 .44015 L .31153 .44179 L 0 .028 .127 r
F
.30888 .44265 m .30719 .44099 L .30983 .44015 L F
.88903 .4413 m .89081 .43878 L .89196 .44036 L 0 .025 .123 r
F
.88903 .4413 m .88788 .43972 L .89081 .43878 L F
.64107 .44557 m .6425 .44305 L .64387 .44454 L 0 .034 .135 r
F
.64107 .44557 m .63969 .44407 L .6425 .44305 L F
.53458 .44673 m .53586 .44454 L .53734 .44602 L 0 .037 .139 r
F
.53458 .44673 m .5331 .44524 L .53586 .44454 L F
.49534 .44655 m .49656 .44429 L .49808 .44587 L 0 .037 .138 r
F
.49534 .44655 m .49382 .44497 L .49656 .44429 L F
.73631 .44267 m .73788 .44021 L .73917 .44187 L 0 .028 .127 r
F
.73631 .44267 m .73501 .44103 L .73788 .44021 L F
.26963 .4425 m .27053 .43997 L .27226 .44157 L 0 .027 .127 r
F
.26963 .4425 m .2679 .44089 L .27053 .43997 L F
.78955 .44215 m .7912 .43966 L .79244 .44122 L 0 .027 .126 r
F
.78955 .44215 m .78831 .44059 L .7912 .43966 L F
.89604 .441 m .89784 .43849 L .89898 .44007 L 0 .024 .123 r
F
.89604 .441 m .8949 .43942 L .89784 .43849 L F
.59483 .4459 m .59619 .44334 L .59762 .44492 L 0 .035 .136 r
F
.59483 .4459 m .5934 .44434 L .59619 .44334 L F
.37336 .44396 m .3744 .44158 L .37603 .44324 L 0 .031 .131 r
F
.37336 .44396 m .37173 .44233 L .3744 .44158 L F
.8428 .44164 m .84452 .43912 L .84572 .44077 L 0 .026 .125 r
F
.8428 .44164 m .8416 .44 L .84452 .43912 L F
.43785 .44514 m .43898 .44278 L .44056 .44443 L 0 .034 .135 r
F
.43785 .44514 m .43628 .44345 L .43898 .44278 L F
.60183 .44554 m .6032 .44305 L .60462 .44465 L F
.60183 .44554 m .60041 .44394 L .6032 .44305 L F
.27662 .44224 m .27752 .43988 L .27925 .44145 L 0 .027 .127 r
F
.27662 .44224 m .2749 .44066 L .27752 .43988 L F
.58783 .44633 m .58918 .44377 L .59061 .44534 L 0 .036 .138 r
F
.58783 .44633 m .58639 .44478 L .58918 .44377 L F
.79656 .44187 m .79821 .43934 L .79945 .44091 L 0 .026 .125 r
F
.79656 .44187 m .79532 .44029 L .79821 .43934 L F
.3986 .44501 m .39968 .44254 L .40129 .44413 L 0 .033 .134 r
F
.3986 .44501 m .39699 .44343 L .39968 .44254 L F
.45609 .44657 m .45726 .44398 L .45882 .44559 L 0 .037 .138 r
F
.45609 .44657 m .45454 .44492 L .45726 .44398 L F
.46309 .44618 m .46427 .44374 L .46582 .44528 L 0 .036 .137 r
F
.46309 .44618 m .46154 .44461 L .46427 .44374 L F
.34811 .44309 m .34912 .44061 L .35077 .44233 L 0 .029 .129 r
F
.34811 .44309 m .34646 .44136 L .34912 .44061 L F
.31586 .44252 m .31683 .43995 L .31852 .44157 L 0 .028 .127 r
F
.31586 .44252 m .31418 .44089 L .31683 .43995 L F
.90306 .44082 m .90487 .4383 L .90601 .43994 L 0 .024 .122 r
F
.90306 .44082 m .90192 .43918 L .90487 .4383 L F
.80357 .4416 m .80522 .43897 L .80646 .44064 L 0 .026 .124 r
F
.80357 .4416 m .80233 .43994 L .80522 .43897 L F
.66908 .44434 m .67055 .44179 L .67191 .44344 L 0 .032 .132 r
F
.66908 .44434 m .66772 .44266 L .67055 .44179 L F
.4056 .44473 m .40669 .44234 L .40829 .44383 L 0 .033 .134 r
F
.4056 .44473 m .40399 .44325 L .40669 .44234 L F
.32286 .44222 m .32382 .43984 L .32551 .44142 L 0 .027 .127 r
F
.32286 .44222 m .32117 .44063 L .32382 .43984 L F
.47009 .44592 m .47127 .44352 L .47282 .44505 L 0 .036 .137 r
F
.47009 .44592 m .46854 .4444 L .47127 .44352 L F
.84982 .44147 m .85155 .43895 L .85274 .44057 L 0 .026 .124 r
F
.84982 .44147 m .84863 .43986 L .85155 .43895 L F
.4126 .44438 m .4137 .44198 L .4153 .44345 L 0 .032 .133 r
F
.4126 .44438 m .41099 .4429 L .4137 .44198 L F
.60883 .44538 m .61022 .443 L .61163 .44453 L 0 .034 .136 r
F
.60883 .44538 m .60742 .44383 L .61022 .443 L F
.56259 .44559 m .56391 .44325 L .56536 .44461 L 0 .035 .136 r
F
.56259 .44559 m .56113 .44423 L .56391 .44325 L F
.67608 .44404 m .67757 .44165 L .67891 .44315 L 0 .031 .132 r
F
.67608 .44404 m .67474 .44255 L .67757 .44165 L F
.74333 .4427 m .74491 .44022 L .7462 .44186 L 0 .028 .128 r
F
.74333 .4427 m .74204 .44106 L .74491 .44022 L F
.54158 .44678 m .54287 .44459 L .54435 .44608 L 0 .038 .14 r
F
.54158 .44678 m .54011 .44531 L .54287 .44459 L F
.68308 .4437 m .68458 .44137 L .68592 .44284 L 0 .031 .131 r
F
.68308 .4437 m .68175 .44226 L .68458 .44137 L F
.2836 .44222 m .28451 .4398 L .28623 .44135 L 0 .028 .127 r
F
.2836 .44222 m .28187 .44067 L .28451 .4398 L F
.56959 .44535 m .57092 .44315 L .57237 .44462 L 0 .035 .136 r
F
.56959 .44535 m .56814 .44388 L .57092 .44315 L F
.81059 .44147 m .81227 .43897 L .8135 .44064 L 0 .026 .125 r
F
.81059 .44147 m .80936 .4398 L .81227 .43897 L F
.41959 .44419 m .42069 .442 L .42229 .44349 L 0 .032 .133 r
F
.41959 .44419 m .41799 .44271 L .42069 .442 L F
.85684 .44129 m .8586 .43891 L .85977 .44047 L 0 .026 .125 r
F
.85684 .44129 m .85567 .43973 L .8586 .43891 L F
.50234 .44673 m .50356 .44463 L .50508 .44611 L 0 .038 .14 r
F
.50234 .44673 m .50082 .44522 L .50356 .44463 L F
.9101 .44071 m .9119 .4381 L .91304 .43977 L 0 .024 .122 r
F
.9101 .44071 m .90896 .43905 L .9119 .4381 L F
.25134 .44168 m .25222 .43918 L .25396 .44079 L 0 .026 .125 r
F
.25134 .44168 m .24959 .4401 L .25222 .43918 L F
.61584 .44518 m .61724 .44282 L .61864 .4443 L 0 .034 .135 r
F
.61584 .44518 m .61443 .44368 L .61724 .44282 L F
.75034 .44249 m .75194 .44012 L .75321 .44159 L 0 .028 .128 r
F
.75034 .44249 m .74907 .44101 L .75194 .44012 L F
.55559 .44619 m .5569 .44384 L .55836 .44521 L 0 .037 .138 r
F
.55559 .44619 m .55412 .44483 L .5569 .44384 L F
.47709 .44583 m .47828 .44346 L .47982 .44507 L 0 .036 .137 r
F
.47709 .44583 m .47555 .44426 L .47828 .44346 L F
.69009 .4435 m .69161 .44119 L .69294 .4427 L 0 .031 .131 r
F
.69009 .4435 m .68876 .44201 L .69161 .44119 L F
.38034 .44411 m .3814 .44149 L .38302 .44318 L 0 .031 .132 r
F
.38034 .44411 m .37871 .44244 L .3814 .44149 L F
.29059 .44198 m .29151 .43948 L .29323 .44104 L 0 .027 .126 r
F
.29059 .44198 m .28887 .44042 L .29151 .43948 L F
.75735 .44217 m .75896 .43977 L .76022 .44128 L 0 .028 .127 r
F
.75735 .44217 m .75608 .44068 L .75896 .43977 L F
.32984 .44219 m .33082 .43975 L .33249 .44131 L F
.32984 .44219 m .32816 .44062 L .33082 .43975 L F
.44483 .44533 m .44598 .44311 L .44754 .44469 L 0 .035 .136 r
F
.44483 .44533 m .44327 .44372 L .44598 .44311 L F
.62284 .44495 m .62425 .4425 L .62565 .44407 L 0 .034 .135 r
F
.62284 .44495 m .62144 .44341 L .62425 .4425 L F
.91712 .44049 m .91894 .43792 L .92007 .4396 L 0 .024 .122 r
F
.91712 .44049 m .91598 .43882 L .91894 .43792 L F
.35508 .44323 m .35611 .44067 L .35775 .4424 L 0 .03 .13 r
F
.35508 .44323 m .35344 .4415 L .35611 .44067 L F
.86387 .44117 m .86562 .43864 L .86679 .4402 L 0 .025 .124 r
F
.86387 .44117 m .8627 .43961 L .86562 .43864 L F
.81762 .44138 m .8193 .43887 L .82052 .44045 L 0 .026 .125 r
F
.81762 .44138 m .8164 .43979 L .8193 .43887 L F
.54859 .44682 m .54989 .44431 L .55135 .44582 L 0 .038 .14 r
F
.54859 .44682 m .54712 .44532 L .54989 .44431 L F
.25832 .44157 m .25919 .4392 L .26093 .44084 L 0 .027 .126 r
F
.25832 .44157 m .25658 .43995 L .25919 .4392 L F
.38733 .44393 m .38839 .44146 L .39001 .44316 L 0 .032 .132 r
F
.38733 .44393 m .38571 .44225 L .38839 .44146 L F
.29757 .44181 m .29851 .43935 L .30021 .44097 L 0 .027 .126 r
F
.29757 .44181 m .29587 .4402 L .29851 .43935 L F
.82463 .44105 m .82633 .43864 L .82754 .44018 L 0 .026 .124 r
F
.82463 .44105 m .82342 .43952 L .82633 .43864 L F
.76437 .44204 m .76599 .43963 L .76725 .44122 L 0 .028 .127 r
F
.76437 .44204 m .7631 .44046 L .76599 .43963 L F
.87088 .44088 m .87264 .43831 L .87381 .43997 L 0 .025 .124 r
F
.87088 .44088 m .86971 .43924 L .87264 .43831 L F
.33682 .44208 m .33783 .43941 L .33949 .44114 L 0 .027 .127 r
F
.33682 .44208 m .33516 .44036 L .33783 .43941 L F
.42658 .44424 m .4277 .44188 L .42928 .44341 L 0 .033 .133 r
F
.42658 .44424 m .42499 .44274 L .4277 .44188 L F
.69712 .44348 m .69862 .44081 L .69995 .44247 L 0 .03 .131 r
F
.69712 .44348 m .69578 .44182 L .69862 .44081 L F
.48408 .44582 m .48529 .44333 L .48682 .44495 L 0 .036 .138 r
F
.48408 .44582 m .48255 .44424 L .48529 .44333 L F
.62985 .44485 m .63127 .44232 L .63266 .44401 L 0 .034 .135 r
F
.62985 .44485 m .62846 .44319 L .63127 .44232 L F
.70412 .44314 m .70563 .44048 L .70696 .44218 L 0 .03 .13 r
F
.70412 .44314 m .70279 .44147 L .70563 .44048 L F
.5766 .44554 m .57794 .44315 L .57938 .4448 L 0 .036 .137 r
F
.5766 .44554 m .57515 .44389 L .57794 .44315 L F
.83165 .44089 m .83337 .4385 L .83456 .44005 L 0 .025 .124 r
F
.83165 .44089 m .83045 .43934 L .83337 .4385 L F
.50933 .44693 m .51057 .44467 L .51208 .44609 L 0 .039 .141 r
F
.50933 .44693 m .50782 .44549 L .51057 .44467 L F
.71113 .44287 m .71266 .44028 L .71398 .44194 L 0 .029 .129 r
F
.71113 .44287 m .70981 .44123 L .71266 .44028 L F
.36206 .44326 m .3631 .44069 L .36474 .44237 L 0 .03 .13 r
F
.36206 .44326 m .36042 .44155 L .3631 .44069 L F
.65787 .44347 m .65933 .44106 L .66069 .44262 L 0 .031 .131 r
F
.65787 .44347 m .6565 .44191 L .65933 .44106 L F
.51634 .44659 m .51759 .44423 L .51909 .44565 L 0 .038 .14 r
F
.51634 .44659 m .51483 .44516 L .51759 .44423 L F
.87792 .44077 m .87968 .43821 L .88085 .43991 L 0 .025 .124 r
F
.87792 .44077 m .87675 .43909 L .87968 .43821 L F
.49108 .44566 m .4923 .44339 L .49382 .44497 L 0 .036 .138 r
F
.49108 .44566 m .48956 .44407 L .4923 .44339 L F
.52334 .44626 m .5246 .44373 L .52609 .44527 L 0 .037 .139 r
F
.52334 .44626 m .52184 .44469 L .5246 .44373 L F
.7714 .44199 m .77301 .43936 L .77427 .44102 L 0 .028 .127 r
F
.7714 .44199 m .77013 .44035 L .77301 .43936 L F
.71814 .44258 m .71968 .44016 L .72099 .44167 L 0 .029 .129 r
F
.71814 .44258 m .71683 .44105 L .71968 .44016 L F
.30455 .44182 m .30549 .43932 L .30719 .44099 L 0 .027 .127 r
F
.30455 .44182 m .30285 .44014 L .30549 .43932 L F
.65087 .44396 m .65231 .44145 L .65368 .44294 L 0 .032 .133 r
F
.65087 .44396 m .6495 .44249 L .65231 .44145 L F
.72514 .44222 m .72669 .43975 L .72799 .44124 L 0 .028 .128 r
F
.72514 .44222 m .72384 .44073 L .72669 .43975 L F
.43357 .44418 m .4347 .44185 L .43628 .44345 L 0 .033 .134 r
F
.43357 .44418 m .43199 .44257 L .4347 .44185 L F
.53034 .44594 m .53161 .44373 L .5331 .44524 L 0 .037 .139 r
F
.53034 .44594 m .52885 .44442 L .53161 .44373 L F
.73214 .44187 m .73371 .43941 L .73501 .44103 L 0 .028 .127 r
F
.73214 .44187 m .73084 .44026 L .73371 .43941 L F
.3438 .4421 m .3448 .43964 L .34646 .44136 L 0 .028 .128 r
F
.3438 .4421 m .34214 .44037 L .3448 .43964 L F
.77841 .44173 m .78003 .43911 L .78129 .44081 L 0 .027 .126 r
F
.77841 .44173 m .77715 .44005 L .78003 .43911 L F
.36905 .44309 m .37009 .4407 L .37173 .44233 L 0 .03 .131 r
F
.36905 .44309 m .36741 .44147 L .37009 .4407 L F
.26528 .44176 m .26617 .43924 L .2679 .44089 L 0 .027 .127 r
F
.26528 .44176 m .26354 .44011 L .26617 .43924 L F
.63687 .44489 m .63829 .44234 L .63969 .44407 L 0 .034 .135 r
F
.63687 .44489 m .63548 .44318 L .63829 .44234 L F
.45182 .44569 m .45298 .44331 L .45454 .44492 L 0 .037 .138 r
F
.45182 .44569 m .45026 .44405 L .45298 .44331 L F
.83868 .44084 m .8404 .43836 L .8416 .44 L 0 .026 .124 r
F
.83868 .44084 m .83748 .4392 L .8404 .43836 L F
.39431 .44415 m .39538 .44171 L .39699 .44343 L 0 .033 .134 r
F
.39431 .44415 m .39269 .44244 L .39538 .44171 L F
.88495 .44065 m .88672 .43805 L .88788 .43972 L 0 .025 .124 r
F
.88495 .44065 m .88378 .43898 L .88672 .43805 L F
.64387 .44454 m .64531 .44202 L .64669 .44352 L 0 .034 .135 r
F
.64387 .44454 m .6425 .44305 L .64531 .44202 L F
.78542 .44148 m .78706 .43901 L .78831 .44059 L 0 .027 .126 r
F
.78542 .44148 m .78418 .43991 L .78706 .43901 L F
.89196 .44036 m .89375 .43784 L .8949 .43942 L 0 .025 .123 r
F
.89196 .44036 m .89081 .43878 L .89375 .43784 L F
.66489 .4435 m .66635 .44098 L .66772 .44266 L 0 .031 .132 r
F
.66489 .4435 m .66352 .4418 L .66635 .44098 L F
.27226 .44157 m .27317 .43908 L .2749 .44066 L 0 .027 .127 r
F
.27226 .44157 m .27053 .43997 L .27317 .43908 L F
.31153 .44179 m .31249 .43926 L .31418 .44089 L 0 .028 .127 r
F
.31153 .44179 m .30983 .44015 L .31249 .43926 L F
.79244 .44122 m .79409 .43874 L .79532 .44029 L 0 .027 .126 r
F
.79244 .44122 m .7912 .43966 L .79409 .43874 L F
.59762 .44492 m .59898 .44233 L .60041 .44394 L 0 .035 .136 r
F
.59762 .44492 m .59619 .44334 L .59898 .44233 L F
.89898 .44007 m .90078 .43759 L .90192 .43918 L 0 .024 .123 r
F
.89898 .44007 m .89784 .43849 L .90078 .43759 L F
.58361 .44572 m .58496 .44313 L .58639 .44478 L 0 .037 .138 r
F
.58361 .44572 m .58217 .44407 L .58496 .44313 L F
.59061 .44534 m .59197 .44276 L .5934 .44434 L 0 .036 .137 r
F
.59061 .44534 m .58918 .44377 L .59197 .44276 L F
.73917 .44187 m .74075 .43939 L .74204 .44106 L 0 .028 .128 r
F
.73917 .44187 m .73788 .44021 L .74075 .43939 L F
.79945 .44091 m .8011 .43836 L .80233 .43994 L 0 .026 .125 r
F
.79945 .44091 m .79821 .43934 L .8011 .43836 L F
.45882 .44559 m .45999 .44303 L .46154 .44461 L 0 .036 .138 r
F
.45882 .44559 m .45726 .44398 L .45999 .44303 L F
.60462 .44465 m .606 .44224 L .60742 .44383 L 0 .034 .136 r
F
.60462 .44465 m .6032 .44305 L .606 .44224 L F
.84572 .44077 m .84744 .43819 L .84863 .43986 L 0 .026 .125 r
F
.84572 .44077 m .84452 .43912 L .84744 .43819 L F
.53734 .44602 m .53863 .44381 L .54011 .44531 L 0 .038 .14 r
F
.53734 .44602 m .53586 .44454 L .53863 .44381 L F
.31852 .44157 m .31949 .43903 L .32117 .44063 L 0 .027 .127 r
F
.31852 .44157 m .31683 .43995 L .31949 .43903 L F
.46582 .44528 m .46699 .44291 L .46854 .4444 L 0 .036 .137 r
F
.46582 .44528 m .46427 .44374 L .46699 .44291 L F
.49808 .44587 m .4993 .44364 L .50082 .44522 L 0 .038 .139 r
F
.49808 .44587 m .49656 .44429 L .4993 .44364 L F
.40129 .44413 m .40238 .44165 L .40399 .44325 L 0 .033 .134 r
F
.40129 .44413 m .39968 .44254 L .40238 .44165 L F
.80646 .44064 m .80813 .43812 L .80936 .4398 L 0 .026 .124 r
F
.80646 .44064 m .80522 .43897 L .80813 .43812 L F
.27925 .44145 m .28015 .43911 L .28187 .44067 L 0 .028 .127 r
F
.27925 .44145 m .27752 .43988 L .28015 .43911 L F
.37603 .44324 m .37708 .44076 L .37871 .44244 L 0 .031 .132 r
F
.37603 .44324 m .3744 .44158 L .37708 .44076 L F
.90601 .43994 m .90782 .43741 L .90896 .43905 L 0 .024 .123 r
F
.90601 .43994 m .90487 .4383 L .90782 .43741 L F
.40829 .44383 m .40939 .44142 L .41099 .4429 L 0 .033 .134 r
F
.40829 .44383 m .40669 .44234 L .40939 .44142 L F
.67191 .44344 m .67338 .44092 L .67474 .44255 L 0 .032 .132 r
F
.67191 .44344 m .67055 .44179 L .67338 .44092 L F
.56536 .44461 m .56669 .44251 L .56814 .44388 L 0 .035 .136 r
F
.56536 .44461 m .56391 .44325 L .56669 .44251 L F
.4153 .44345 m .4164 .44121 L .41799 .44271 L 0 .032 .133 r
F
.4153 .44345 m .4137 .44198 L .4164 .44121 L F
.44056 .44443 m .4417 .44211 L .44327 .44372 L 0 .034 .135 r
F
.44056 .44443 m .43898 .44278 L .4417 .44211 L F
.85274 .44057 m .85448 .4381 L .85567 .43973 L 0 .026 .124 r
F
.85274 .44057 m .85155 .43895 L .85448 .4381 L F
.35077 .44233 m .35179 .43979 L .35344 .4415 L 0 .029 .129 r
F
.35077 .44233 m .34912 .44061 L .35179 .43979 L F
.47282 .44505 m .47401 .44269 L .47555 .44426 L 0 .036 .137 r
F
.47282 .44505 m .47127 .44352 L .47401 .44269 L F
.67891 .44315 m .6804 .44074 L .68175 .44226 L 0 .031 .132 r
F
.67891 .44315 m .67757 .44165 L .6804 .44074 L F
.24697 .44101 m .24784 .43851 L .24959 .4401 L 0 .027 .126 r
F
.24697 .44101 m .24522 .43945 L .24784 .43851 L F
.32551 .44142 m .32648 .43905 L .32816 .44062 L 0 .028 .127 r
F
.32551 .44142 m .32382 .43984 L .32648 .43905 L F
.61163 .44453 m .61302 .44217 L .61443 .44368 L 0 .035 .136 r
F
.61163 .44453 m .61022 .443 L .61302 .44217 L F
.7462 .44186 m .74779 .43939 L .74907 .44101 L 0 .028 .128 r
F
.7462 .44186 m .74491 .44022 L .74779 .43939 L F
.68592 .44284 m .68743 .44052 L .68876 .44201 L 0 .031 .131 r
F
.68592 .44284 m .68458 .44137 L .68743 .44052 L F
.91304 .43977 m .91485 .43715 L .91598 .43882 L 0 .024 .122 r
F
.91304 .43977 m .9119 .4381 L .91485 .43715 L F
.55836 .44521 m .55967 .44286 L .56113 .44423 L 0 .036 .138 r
F
.55836 .44521 m .5569 .44384 L .55967 .44286 L F
.28623 .44135 m .28715 .43885 L .28887 .44042 L 0 .027 .127 r
F
.28623 .44135 m .28451 .4398 L .28715 .43885 L F
.25396 .44079 m .25484 .43832 L .25658 .43995 L 0 .026 .125 r
F
.25396 .44079 m .25222 .43918 L .25484 .43832 L F
.61864 .4443 m .62004 .44194 L .62144 .44341 L 0 .034 .135 r
F
.61864 .4443 m .61724 .44282 L .62004 .44194 L F
.75321 .44159 m .75481 .43918 L .75608 .44068 L 0 .028 .128 r
F
.75321 .44159 m .75194 .44012 L .75481 .43918 L F
.54435 .44608 m .54564 .44382 L .54712 .44532 L 0 .039 .141 r
F
.54435 .44608 m .54287 .44459 L .54564 .44382 L F
.8135 .44064 m .81518 .43811 L .8164 .43979 L 0 .026 .125 r
F
.8135 .44064 m .81227 .43897 L .81518 .43811 L F
.38302 .44318 m .38409 .44054 L .38571 .44225 L 0 .031 .132 r
F
.38302 .44318 m .3814 .44149 L .38409 .44054 L F
.29323 .44104 m .29415 .43862 L .29587 .4402 L 0 .027 .126 r
F
.29323 .44104 m .29151 .43948 L .29415 .43862 L F
.85977 .44047 m .86153 .43805 L .8627 .43961 L 0 .026 .125 r
F
.85977 .44047 m .8586 .43891 L .86153 .43805 L F
.76022 .44128 m .76184 .43893 L .7631 .44046 L 0 .028 .127 r
F
.76022 .44128 m .75896 .43977 L .76184 .43893 L F
.33249 .44131 m .33348 .4388 L .33516 .44036 L F
.33249 .44131 m .33082 .43975 L .33348 .4388 L F
.57237 .44462 m .57371 .44241 L .57515 .44389 L 0 .035 .137 r
F
.57237 .44462 m .57092 .44315 L .57371 .44241 L F
.69294 .4427 m .69445 .4403 L .69578 .44182 L 0 .031 .131 r
F
.69294 .4427 m .69161 .44119 L .69445 .4403 L F
.92007 .4396 m .9219 .43709 L .92303 .43878 L 0 .024 .122 r
F
.92007 .4396 m .91894 .43792 L .9219 .43709 L F
.42229 .44349 m .4234 .44124 L .42499 .44274 L 0 .033 .134 r
F
.42229 .44349 m .42069 .442 L .4234 .44124 L F
.55135 .44582 m .55266 .44331 L .55412 .44483 L 0 .038 .14 r
F
.55135 .44582 m .54989 .44431 L .55266 .44331 L F
.62565 .44407 m .62706 .44159 L .62846 .44319 L 0 .034 .135 r
F
.62565 .44407 m .62425 .4425 L .62706 .44159 L F
.86679 .4402 m .86854 .43767 L .86971 .43924 L 0 .025 .124 r
F
.86679 .4402 m .86562 .43864 L .86854 .43767 L F
.47982 .44507 m .48102 .44259 L .48255 .44424 L 0 .036 .138 r
F
.47982 .44507 m .47828 .44346 L .48102 .44259 L F
.82052 .44045 m .82221 .43795 L .82342 .43952 L 0 .026 .125 r
F
.82052 .44045 m .8193 .43887 L .82221 .43795 L F
.35775 .4424 m .35878 .43984 L .36042 .44155 L 0 .03 .13 r
F
.35775 .4424 m .35611 .44067 L .35878 .43984 L F
.50508 .44611 m .50631 .44403 L .50782 .44549 L 0 .039 .141 r
F
.50508 .44611 m .50356 .44463 L .50631 .44403 L F
.69995 .44247 m .70146 .43979 L .70279 .44147 L 0 .03 .13 r
F
.69995 .44247 m .69862 .44081 L .70146 .43979 L F
.87381 .43997 m .87557 .43742 L .87675 .43909 L 0 .025 .123 r
F
.87381 .43997 m .87264 .43831 L .87557 .43742 L F
.33949 .44114 m .34048 .43864 L .34214 .44037 L 0 .027 .127 r
F
.33949 .44114 m .33783 .43941 L .34048 .43864 L F
.82754 .44018 m .82925 .4378 L .83045 .43934 L 0 .026 .124 r
F
.82754 .44018 m .82633 .43864 L .82925 .4378 L F
.30021 .44097 m .30115 .43852 L .30285 .44014 L 0 .027 .127 r
F
.30021 .44097 m .29851 .43935 L .30115 .43852 L F
.44754 .44469 m .44869 .44249 L .45026 .44405 L 0 .036 .137 r
F
.44754 .44469 m .44598 .44311 L .44869 .44249 L F
.70696 .44218 m .70848 .43951 L .70981 .44123 L 0 .029 .129 r
F
.70696 .44218 m .70563 .44048 L .70848 .43951 L F
.39001 .44316 m .39108 .44073 L .39269 .44244 L 0 .032 .133 r
F
.39001 .44316 m .38839 .44146 L .39108 .44073 L F
.76725 .44122 m .76887 .43874 L .77013 .44035 L 0 .028 .127 r
F
.76725 .44122 m .76599 .43963 L .76887 .43874 L F
.26093 .44084 m .26181 .43845 L .26354 .44011 L 0 .027 .126 r
F
.26093 .44084 m .25919 .4392 L .26181 .43845 L F
.48682 .44495 m .48803 .44242 L .48956 .44407 L 0 .036 .138 r
F
.48682 .44495 m .48529 .44333 L .48803 .44242 L F
.42928 .44341 m .43041 .44101 L .43199 .44257 L 0 .033 .134 r
F
.42928 .44341 m .4277 .44188 L .43041 .44101 L F
.63266 .44401 m .63408 .44146 L .63548 .44318 L 0 .034 .135 r
F
.63266 .44401 m .63127 .44232 L .63408 .44146 L F
.71398 .44194 m .71551 .43941 L .71683 .44105 L 0 .029 .129 r
F
.71398 .44194 m .71266 .44028 L .71551 .43941 L F
.51909 .44565 m .52034 .4433 L .52184 .44469 L 0 .038 .14 r
F
.51909 .44565 m .51759 .44423 L .52034 .4433 L F
.65368 .44294 m .65513 .44041 L .6565 .44191 L 0 .032 .132 r
F
.65368 .44294 m .65231 .44145 L .65513 .44041 L F
.52609 .44527 m .52736 .44289 L .52885 .44442 L 0 .037 .139 r
F
.52609 .44527 m .5246 .44373 L .52736 .44289 L F
.36474 .44237 m .36577 .43983 L .36741 .44147 L 0 .03 .131 r
F
.36474 .44237 m .3631 .44069 L .36577 .43983 L F
.77427 .44102 m .77588 .43837 L .77715 .44005 L 0 .027 .127 r
F
.77427 .44102 m .77301 .43936 L .77588 .43837 L F
.83456 .44005 m .83629 .43766 L .83748 .4392 L 0 .026 .124 r
F
.83456 .44005 m .83337 .4385 L .83629 .43766 L F
.51208 .44609 m .51333 .44376 L .51483 .44516 L 0 .039 .141 r
F
.51208 .44609 m .51057 .44467 L .51333 .44376 L F
.72799 .44124 m .72955 .43877 L .73084 .44026 L 0 .028 .128 r
F
.72799 .44124 m .72669 .43975 L .72955 .43877 L F
.66069 .44262 m .66216 .44025 L .66352 .4418 L 0 .031 .132 r
F
.66069 .44262 m .65933 .44106 L .66216 .44025 L F
.88085 .43991 m .88262 .43728 L .88378 .43898 L 0 .025 .124 r
F
.88085 .43991 m .87968 .43821 L .88262 .43728 L F
.72099 .44167 m .72254 .43923 L .72384 .44073 L 0 .029 .129 r
F
.72099 .44167 m .71968 .44016 L .72254 .43923 L F
.57938 .4448 m .58073 .44242 L .58217 .44407 L 0 .036 .138 r
F
.57938 .4448 m .57794 .44315 L .58073 .44242 L F
.30719 .44099 m .30814 .4385 L .30983 .44015 L 0 .028 .127 r
F
.30719 .44099 m .30549 .43932 L .30814 .4385 L F
.64669 .44352 m .64812 .44099 L .6495 .44249 L 0 .033 .134 r
F
.64669 .44352 m .64531 .44202 L .64812 .44099 L F
.78129 .44081 m .78292 .43819 L .78418 .43991 L 0 .027 .126 r
F
.78129 .44081 m .78003 .43911 L .78292 .43819 L F
.73501 .44103 m .73658 .43858 L .73788 .44021 L 0 .028 .127 r
F
.73501 .44103 m .73371 .43941 L .73658 .43858 L F
.88788 .43972 m .88966 .43711 L .89081 .43878 L 0 .025 .123 r
F
.88788 .43972 m .88672 .43805 L .88966 .43711 L F
.2679 .44089 m .2688 .43832 L .27053 .43997 L 0 .027 .127 r
F
.2679 .44089 m .26617 .43924 L .2688 .43832 L F
.49382 .44497 m .49504 .44271 L .49656 .44429 L 0 .037 .139 r
F
.49382 .44497 m .4923 .44339 L .49504 .44271 L F
.43628 .44345 m .43741 .44118 L .43898 .44278 L 0 .034 .135 r
F
.43628 .44345 m .4347 .44185 L .43741 .44118 L F
.63969 .44407 m .64111 .44134 L .6425 .44305 L F
.63969 .44407 m .63829 .44234 L .64111 .44134 L F
.5331 .44524 m .53438 .44303 L .53586 .44454 L 0 .038 .14 r
F
.5331 .44524 m .53161 .44373 L .53438 .44303 L F
.8416 .44 m .84332 .43747 L .84452 .43912 L 0 .026 .125 r
F
.8416 .44 m .8404 .43836 L .84332 .43747 L F
.37173 .44233 m .37277 .43994 L .3744 .44158 L 0 .031 .131 r
F
.37173 .44233 m .37009 .4407 L .37277 .43994 L F
.78831 .44059 m .78996 .43809 L .7912 .43966 L 0 .027 .126 r
F
.78831 .44059 m .78706 .43901 L .78996 .43809 L F
.34646 .44136 m .34746 .43889 L .34912 .44061 L 0 .029 .128 r
F
.34646 .44136 m .3448 .43964 L .34746 .43889 L F
.8949 .43942 m .89669 .4369 L .89784 .43849 L 0 .025 .123 r
F
.8949 .43942 m .89375 .43784 L .89669 .4369 L F
.60041 .44394 m .60178 .44144 L .6032 .44305 L 0 .034 .136 r
F
.60041 .44394 m .59898 .44233 L .60178 .44144 L F
.45454 .44492 m .4557 .44239 L .45726 .44398 L 0 .037 .138 r
F
.45454 .44492 m .45298 .44331 L .4557 .44239 L F
.5934 .44434 m .59476 .44174 L .59619 .44334 L 0 .035 .137 r
F
.5934 .44434 m .59197 .44276 L .59476 .44174 L F
.2749 .44066 m .27579 .43831 L .27752 .43988 L 0 .027 .127 r
F
.2749 .44066 m .27317 .43908 L .27579 .43831 L F
.79532 .44029 m .79698 .43779 L .79821 .43934 L 0 .026 .126 r
F
.79532 .44029 m .79409 .43874 L .79698 .43779 L F
.31418 .44089 m .31514 .43834 L .31683 .43995 L 0 .028 .127 r
F
.31418 .44089 m .31249 .43926 L .31514 .43834 L F
.58639 .44478 m .58775 .44212 L .58918 .44377 L 0 .036 .138 r
F
.58639 .44478 m .58496 .44313 L .58775 .44212 L F
.39699 .44343 m .39808 .44081 L .39968 .44254 L 0 .033 .134 r
F
.39699 .44343 m .39538 .44171 L .39808 .44081 L F
.66772 .44266 m .66919 .44013 L .67055 .44179 L 0 .032 .132 r
F
.66772 .44266 m .66635 .44098 L .66919 .44013 L F
.80233 .43994 m .80399 .43738 L .80522 .43897 L 0 .026 .125 r
F
.80233 .43994 m .8011 .43836 L .80399 .43738 L F
.46154 .44461 m .46271 .44221 L .46427 .44374 L 0 .036 .138 r
F
.46154 .44461 m .45999 .44303 L .46271 .44221 L F
.90192 .43918 m .90373 .43672 L .90487 .4383 L 0 .024 .123 r
F
.90192 .43918 m .90078 .43759 L .90373 .43672 L F
.32117 .44063 m .32214 .43826 L .32382 .43984 L 0 .028 .127 r
F
.32117 .44063 m .31949 .43903 L .32214 .43826 L F
.84863 .43986 m .85036 .43727 L .85155 .43895 L 0 .026 .124 r
F
.84863 .43986 m .84744 .43819 L .85036 .43727 L F
.74204 .44106 m .74362 .43856 L .74491 .44022 L 0 .028 .128 r
F
.74204 .44106 m .74075 .43939 L .74362 .43856 L F
.46854 .4444 m .46973 .44208 L .47127 .44352 L 0 .036 .138 r
F
.46854 .4444 m .46699 .44291 L .46973 .44208 L F
.60742 .44383 m .60881 .44144 L .61022 .443 L 0 .035 .136 r
F
.60742 .44383 m .606 .44224 L .60881 .44144 L F
.40399 .44325 m .40508 .44075 L .40669 .44234 L 0 .033 .134 r
F
.40399 .44325 m .40238 .44165 L .40508 .44075 L F
.41099 .4429 m .41209 .4405 L .4137 .44198 L 0 .033 .133 r
F
.41099 .4429 m .40939 .44142 L .41209 .4405 L F
.80936 .4398 m .81104 .43729 L .81227 .43897 L 0 .026 .125 r
F
.80936 .4398 m .80813 .43812 L .81104 .43729 L F
.90896 .43905 m .91077 .43646 L .9119 .4381 L 0 .024 .122 r
F
.90896 .43905 m .90782 .43741 L .91077 .43646 L F
.67474 .44255 m .67621 .44001 L .67757 .44165 L 0 .032 .132 r
F
.67474 .44255 m .67338 .44092 L .67621 .44001 L F
.54011 .44531 m .5414 .44309 L .54287 .44459 L 0 .039 .141 r
F
.54011 .44531 m .53863 .44381 L .5414 .44309 L F
.28187 .44067 m .28278 .43824 L .28451 .4398 L 0 .028 .127 r
F
.28187 .44067 m .28015 .43911 L .28278 .43824 L F
.24959 .4401 m .25046 .43757 L .25222 .43918 L 0 .026 .126 r
F
.24959 .4401 m .24784 .43851 L .25046 .43757 L F
.37871 .44244 m .37977 .43979 L .3814 .44149 L 0 .031 .132 r
F
.37871 .44244 m .37708 .44076 L .37977 .43979 L F
.68175 .44226 m .68324 .43982 L .68458 .44137 L F
.68175 .44226 m .6804 .44074 L .68324 .43982 L F
.85567 .43973 m .85741 .43727 L .8586 .43891 L 0 .026 .125 r
F
.85567 .43973 m .85448 .4381 L .85741 .43727 L F
.35344 .4415 m .35446 .43896 L .35611 .44067 L 0 .029 .129 r
F
.35344 .4415 m .35179 .43979 L .35446 .43896 L F
.56113 .44423 m .56245 .44188 L .56391 .44325 L 0 .036 .137 r
F
.56113 .44423 m .55967 .44286 L .56245 .44188 L F
.50082 .44522 m .50205 .44303 L .50356 .44463 L 0 .039 .141 r
F
.50082 .44522 m .4993 .44364 L .50205 .44303 L F
.47555 .44426 m .47674 .44185 L .47828 .44346 L 0 .036 .137 r
F
.47555 .44426 m .47401 .44269 L .47674 .44185 L F
.91598 .43882 m .9178 .43625 L .91894 .43792 L 0 .024 .122 r
F
.91598 .43882 m .91485 .43715 L .9178 .43625 L F
.61443 .44368 m .61583 .44134 L .61724 .44282 L 0 .035 .136 r
F
.61443 .44368 m .61302 .44217 L .61583 .44134 L F
.56814 .44388 m .56947 .44178 L .57092 .44315 L 0 .036 .137 r
F
.56814 .44388 m .56669 .44251 L .56947 .44178 L F
.41799 .44271 m .4191 .44047 L .42069 .442 L 0 .033 .134 r
F
.41799 .44271 m .4164 .44121 L .4191 .44047 L F
.28887 .44042 m .2898 .43791 L .29151 .43948 L 0 .027 .127 r
F
.28887 .44042 m .28715 .43885 L .2898 .43791 L F
.44327 .44372 m .44441 .44152 L .44598 .44311 L 0 .035 .136 r
F
.44327 .44372 m .4417 .44211 L .44441 .44152 L F
.32816 .44062 m .32914 .43819 L .33082 .43975 L 0 .028 .127 r
F
.32816 .44062 m .32648 .43905 L .32914 .43819 L F
.74907 .44101 m .75066 .43848 L .75194 .44012 L 0 .029 .128 r
F
.74907 .44101 m .74779 .43939 L .75066 .43848 L F
.68876 .44201 m .69027 .43968 L .69161 .44119 L 0 .031 .132 r
F
.68876 .44201 m .68743 .44052 L .69027 .43968 L F
.75608 .44068 m .75769 .43825 L .75896 .43977 L 0 .028 .128 r
F
.75608 .44068 m .75481 .43918 L .75769 .43825 L F
.62144 .44341 m .62285 .44099 L .62425 .4425 L 0 .034 .135 r
F
.62144 .44341 m .62004 .44194 L .62285 .44099 L F
.38571 .44225 m .38677 .43974 L .38839 .44146 L 0 .031 .132 r
F
.38571 .44225 m .38409 .44054 L .38677 .43974 L F
.25658 .43995 m .25745 .43755 L .25919 .4392 L 0 .027 .126 r
F
.25658 .43995 m .25484 .43832 L .25745 .43755 L F
.55412 .44483 m .55543 .44233 L .5569 .44384 L 0 .037 .139 r
F
.55412 .44483 m .55266 .44331 L .55543 .44233 L F
.33516 .44036 m .33615 .43785 L .33783 .43941 L 0 .027 .127 r
F
.33516 .44036 m .33348 .4388 L .33615 .43785 L F
.8164 .43979 m .81808 .4372 L .8193 .43887 L 0 .026 .125 r
F
.8164 .43979 m .81518 .43811 L .81808 .4372 L F
.29587 .4402 m .2968 .43776 L .29851 .43935 L 0 .027 .126 r
F
.29587 .4402 m .29415 .43862 L .2968 .43776 L F
.8627 .43961 m .86445 .43708 L .86562 .43864 L 0 .026 .125 r
F
.8627 .43961 m .86153 .43805 L .86445 .43708 L F
.86971 .43924 m .87147 .43673 L .87264 .43831 L 0 .025 .124 r
F
.86971 .43924 m .86854 .43767 L .87147 .43673 L F
.7631 .44046 m .76472 .43808 L .76599 .43963 L 0 .028 .127 r
F
.7631 .44046 m .76184 .43893 L .76472 .43808 L F
.54712 .44532 m .54841 .4428 L .54989 .44431 L 0 .039 .141 r
F
.54712 .44532 m .54564 .44382 L .54841 .4428 L F
.69578 .44182 m .69729 .43928 L .69862 .44081 L 0 .031 .131 r
F
.69578 .44182 m .69445 .4403 L .69729 .43928 L F
.62846 .44319 m .62987 .44069 L .63127 .44232 L 0 .034 .135 r
F
.62846 .44319 m .62706 .44159 L .62987 .44069 L F
.82342 .43952 m .82512 .43707 L .82633 .43864 L 0 .026 .125 r
F
.82342 .43952 m .82221 .43795 L .82512 .43707 L F
.70279 .44147 m .7043 .43878 L .70563 .44048 L 0 .03 .13 r
F
.70279 .44147 m .70146 .43979 L .7043 .43878 L F
.92303 .43878 m .92487 .43626 L .926 .43795 L 0 .024 .123 r
F
.92303 .43878 m .9219 .43709 L .92487 .43626 L F
.48255 .44424 m .48376 .44165 L .48529 .44333 L 0 .036 .138 r
F
.48255 .44424 m .48102 .44259 L .48376 .44165 L F
.36042 .44155 m .36145 .43902 L .3631 .44069 L 0 .03 .13 r
F
.36042 .44155 m .35878 .43984 L .36145 .43902 L F
.57515 .44389 m .57649 .44167 L .57794 .44315 L 0 .036 .137 r
F
.57515 .44389 m .57371 .44241 L .57649 .44167 L F
.42499 .44274 m .42611 .44034 L .4277 .44188 L 0 .033 .134 r
F
.42499 .44274 m .4234 .44124 L .42611 .44034 L F
.87675 .43909 m .87851 .43652 L .87968 .43821 L 0 .025 .124 r
F
.87675 .43909 m .87557 .43742 L .87851 .43652 L F
.70981 .44123 m .71133 .43854 L .71266 .44028 L 0 .029 .129 r
F
.70981 .44123 m .70848 .43951 L .71133 .43854 L F
.83045 .43934 m .83217 .43695 L .83337 .4385 L 0 .026 .125 r
F
.83045 .43934 m .82925 .4378 L .83217 .43695 L F
.30285 .44014 m .30379 .43769 L .30549 .43932 L 0 .027 .127 r
F
.30285 .44014 m .30115 .43852 L .30379 .43769 L F
.77013 .44035 m .77174 .43774 L .77301 .43936 L 0 .028 .127 r
F
.77013 .44035 m .76887 .43874 L .77174 .43774 L F
.6565 .44191 m .65796 .43955 L .65933 .44106 L 0 .031 .132 r
F
.6565 .44191 m .65513 .44041 L .65796 .43955 L F
.34214 .44037 m .34314 .43791 L .3448 .43964 L 0 .028 .127 r
F
.34214 .44037 m .34048 .43864 L .34314 .43791 L F
.48956 .44407 m .49077 .44174 L .4923 .44339 L 0 .036 .138 r
F
.48956 .44407 m .48803 .44242 L .49077 .44174 L F
.52184 .44469 m .5231 .44237 L .5246 .44373 L 0 .038 .14 r
F
.52184 .44469 m .52034 .4433 L .5231 .44237 L F
.43199 .44257 m .43312 .44027 L .4347 .44185 L 0 .033 .134 r
F
.43199 .44257 m .43041 .44101 L .43312 .44027 L F
.77715 .44005 m .77877 .43741 L .78003 .43911 L 0 .027 .126 r
F
.77715 .44005 m .77588 .43837 L .77877 .43741 L F
.50782 .44549 m .50906 .44323 L .51057 .44467 L 0 .04 .142 r
F
.50782 .44549 m .50631 .44403 L .50906 .44323 L F
.73084 .44026 m .73242 .43791 L .73371 .43941 L 0 .028 .128 r
F
.73084 .44026 m .72955 .43877 L .73242 .43791 L F
.63548 .44318 m .6369 .4406 L .63829 .44234 L 0 .034 .135 r
F
.63548 .44318 m .63408 .44146 L .6369 .4406 L F
.71683 .44105 m .71837 .43853 L .71968 .44016 L 0 .029 .129 r
F
.71683 .44105 m .71551 .43941 L .71837 .43853 L F
.51483 .44516 m .51608 .44285 L .51759 .44423 L 0 .039 .141 r
F
.51483 .44516 m .51333 .44376 L .51608 .44285 L F
.39269 .44244 m .39377 .43998 L .39538 .44171 L 0 .033 .133 r
F
.39269 .44244 m .39108 .44073 L .39377 .43998 L F
.26354 .44011 m .26444 .43756 L .26617 .43924 L 0 .027 .127 r
F
.26354 .44011 m .26181 .43845 L .26444 .43756 L F
.36741 .44147 m .36845 .43908 L .37009 .4407 L 0 .031 .131 r
F
.36741 .44147 m .36577 .43983 L .36845 .43908 L F
.52885 .44442 m .53012 .44221 L .53161 .44373 L 0 .038 .139 r
F
.52885 .44442 m .52736 .44289 L .53012 .44221 L F
.72384 .44073 m .72539 .43826 L .72669 .43975 L 0 .029 .129 r
F
.72384 .44073 m .72254 .43923 L .72539 .43826 L F
.88378 .43898 m .88555 .43635 L .88672 .43805 L 0 .025 .123 r
F
.88378 .43898 m .88262 .43728 L .88555 .43635 L F
.6495 .44249 m .65094 .43994 L .65231 .44145 L 0 .033 .133 r
F
.6495 .44249 m .64812 .44099 L .65094 .43994 L F
.45026 .44405 m .45141 .44178 L .45298 .44331 L 0 .037 .138 r
F
.45026 .44405 m .44869 .44249 L .45141 .44178 L F
.83748 .4392 m .83921 .43681 L .8404 .43836 L 0 .026 .125 r
F
.83748 .4392 m .83629 .43766 L .83921 .43681 L F
.66352 .4418 m .66499 .43943 L .66635 .44098 L 0 .031 .132 r
F
.66352 .4418 m .66216 .44025 L .66499 .43943 L F
.78418 .43991 m .7858 .43727 L .78706 .43901 L 0 .027 .126 r
F
.78418 .43991 m .78292 .43819 L .7858 .43727 L F
.6425 .44305 m .64392 .44033 L .64531 .44202 L 0 .034 .135 r
F
.6425 .44305 m .64111 .44134 L .64392 .44033 L F
.89081 .43878 m .89259 .43616 L .89375 .43784 L 0 .025 .123 r
F
.89081 .43878 m .88966 .43711 L .89259 .43616 L F
.30983 .44015 m .31079 .43763 L .31249 .43926 L 0 .028 .127 r
F
.30983 .44015 m .30814 .4385 L .31079 .43763 L F
.27053 .43997 m .27144 .43743 L .27317 .43908 L 0 .027 .127 r
F
.27053 .43997 m .2688 .43832 L .27144 .43743 L F
.58217 .44407 m .58352 .44148 L .58496 .44313 L 0 .037 .138 r
F
.58217 .44407 m .58073 .44242 L .58352 .44148 L F
.73788 .44021 m .73945 .43776 L .74075 .43939 L 0 .028 .128 r
F
.73788 .44021 m .73658 .43858 L .73945 .43776 L F
.59619 .44334 m .59756 .44071 L .59898 .44233 L 0 .035 .136 r
F
.59619 .44334 m .59476 .44174 L .59756 .44071 L F
.89784 .43849 m .89964 .43601 L .90078 .43759 L 0 .024 .123 r
F
.89784 .43849 m .89669 .4369 L .89964 .43601 L F
.7912 .43966 m .79285 .43718 L .79409 .43874 L 0 .027 .126 r
F
.7912 .43966 m .78996 .43809 L .79285 .43718 L F
.58918 .44377 m .59054 .44111 L .59197 .44276 L 0 .036 .137 r
F
.58918 .44377 m .58775 .44212 L .59054 .44111 L F
.45726 .44398 m .45843 .44148 L .45999 .44303 L 0 .037 .138 r
F
.45726 .44398 m .4557 .44239 L .45843 .44148 L F
.84452 .43912 m .84624 .43653 L .84744 .43819 L 0 .026 .124 r
F
.84452 .43912 m .84332 .43747 L .84624 .43653 L F
.79821 .43934 m .79987 .43681 L .8011 .43836 L 0 .026 .125 r
F
.79821 .43934 m .79698 .43779 L .79987 .43681 L F
.6032 .44305 m .60458 .44066 L .606 .44224 L 0 .035 .136 r
F
.6032 .44305 m .60178 .44144 L .60458 .44066 L F
.80522 .43897 m .8069 .43653 L .80813 .43812 L 0 .026 .124 r
F
.80522 .43897 m .80399 .43738 L .8069 .43653 L F
.31683 .43995 m .3178 .43743 L .31949 .43903 L 0 .028 .127 r
F
.31683 .43995 m .31514 .43834 L .3178 .43743 L F
.39968 .44254 m .40077 .43992 L .40238 .44165 L 0 .033 .134 r
F
.39968 .44254 m .39808 .44081 L .40077 .43992 L F
.49656 .44429 m .49778 .44206 L .4993 .44364 L 0 .038 .14 r
F
.49656 .44429 m .49504 .44271 L .49778 .44206 L F
.34912 .44061 m .35013 .43807 L .35179 .43979 L 0 .029 .129 r
F
.34912 .44061 m .34746 .43889 L .35013 .43807 L F
.3744 .44158 m .37545 .4391 L .37708 .44076 L 0 .031 .132 r
F
.3744 .44158 m .37277 .43994 L .37545 .4391 L F
.67055 .44179 m .67202 .43928 L .67338 .44092 L 0 .032 .132 r
F
.67055 .44179 m .66919 .44013 L .67202 .43928 L F
.90487 .4383 m .90669 .43583 L .90782 .43741 L 0 .024 .123 r
F
.90487 .4383 m .90373 .43672 L .90669 .43583 L F
.46427 .44374 m .46544 .44142 L .46699 .44291 L 0 .037 .138 r
F
.46427 .44374 m .46271 .44221 L .46544 .44142 L F
.43898 .44278 m .44012 .44051 L .4417 .44211 L 0 .034 .136 r
F
.43898 .44278 m .43741 .44118 L .44012 .44051 L F
.53586 .44454 m .53714 .4423 L .53863 .44381 L 0 .039 .14 r
F
.53586 .44454 m .53438 .44303 L .53714 .4423 L F
.27752 .43988 m .27842 .43754 L .28015 .43911 L 0 .028 .127 r
F
.27752 .43988 m .27579 .43831 L .27842 .43754 L F
.85155 .43895 m .85329 .4364 L .85448 .4381 L 0 .026 .124 r
F
.85155 .43895 m .85036 .43727 L .85329 .4364 L F
.40669 .44234 m .40778 .43984 L .40939 .44142 L 0 .033 .134 r
F
.40669 .44234 m .40508 .44075 L .40778 .43984 L F
.47127 .44352 m .47246 .44124 L .47401 .44269 L 0 .036 .138 r
F
.47127 .44352 m .46973 .44208 L .47246 .44124 L F
.74491 .44022 m .7465 .43772 L .74779 .43939 L 0 .028 .128 r
F
.74491 .44022 m .74362 .43856 L .7465 .43772 L F
.24522 .43945 m .24608 .43693 L .24784 .43851 L 0 .027 .126 r
F
.24522 .43945 m .24345 .43788 L .24608 .43693 L F
.4137 .44198 m .41479 .43971 L .4164 .44121 L 0 .033 .134 r
F
.4137 .44198 m .41209 .4405 L .41479 .43971 L F
.32382 .43984 m .32479 .43748 L .32648 .43905 L 0 .028 .127 r
F
.32382 .43984 m .32214 .43826 L .32479 .43748 L F
.9119 .4381 m .91371 .43551 L .91485 .43715 L 0 .024 .122 r
F
.9119 .4381 m .91077 .43646 L .91371 .43551 L F
.61022 .443 m .61161 .44064 L .61302 .44217 L 0 .035 .136 r
F
.61022 .443 m .60881 .44144 L .61161 .44064 L F
.67757 .44165 m .67905 .43906 L .6804 .44074 L 0 .032 .132 r
F
.67757 .44165 m .67621 .44001 L .67905 .43906 L F
.3814 .44149 m .38246 .43882 L .38409 .44054 L 0 .031 .132 r
F
.3814 .44149 m .37977 .43979 L .38246 .43882 L F
.81227 .43897 m .81395 .43644 L .81518 .43811 L 0 .026 .125 r
F
.81227 .43897 m .81104 .43729 L .81395 .43644 L F
.56391 .44325 m .56523 .44114 L .56669 .44251 L 0 .036 .138 r
F
.56391 .44325 m .56245 .44188 L .56523 .44114 L F
.25222 .43918 m .25309 .4367 L .25484 .43832 L 0 .026 .126 r
F
.25222 .43918 m .25046 .43757 L .25309 .4367 L F
.28451 .4398 m .28543 .43729 L .28715 .43885 L 0 .028 .127 r
F
.28451 .4398 m .28278 .43824 L .28543 .43729 L F
.68458 .44137 m .68609 .43896 L .68743 .44052 L 0 .031 .132 r
F
.68458 .44137 m .68324 .43982 L .68609 .43896 L F
.29151 .43948 m .29244 .43704 L .29415 .43862 L 0 .027 .127 r
F
.29151 .43948 m .2898 .43791 L .29244 .43704 L F
.91894 .43792 m .92077 .4354 L .9219 .43709 L 0 .024 .122 r
F
.91894 .43792 m .9178 .43625 L .92077 .4354 L F
.8586 .43891 m .86035 .43641 L .86153 .43805 L 0 .026 .125 r
F
.8586 .43891 m .85741 .43727 L .86035 .43641 L F
.35611 .44067 m .35713 .43815 L .35878 .43984 L 0 .03 .13 r
F
.35611 .44067 m .35446 .43896 L .35713 .43815 L F
.61724 .44282 m .61864 .44047 L .62004 .44194 L 0 .035 .136 r
F
.61724 .44282 m .61583 .44134 L .61864 .44047 L F
.75194 .44012 m .75353 .43753 L .75481 .43918 L 0 .028 .128 r
F
.75194 .44012 m .75066 .43848 L .75353 .43753 L F
.54287 .44459 m .54417 .4423 L .54564 .44382 L 0 .039 .141 r
F
.54287 .44459 m .5414 .44309 L .54417 .4423 L F
.33082 .43975 m .3318 .43724 L .33348 .4388 L 0 .028 .127 r
F
.33082 .43975 m .32914 .43819 L .3318 .43724 L F
.5569 .44384 m .55821 .44136 L .55967 .44286 L 0 .037 .139 r
F
.5569 .44384 m .55543 .44233 L .55821 .44136 L F
.75896 .43977 m .76057 .43739 L .76184 .43893 L 0 .028 .128 r
F
.75896 .43977 m .75769 .43825 L .76057 .43739 L F
.47828 .44346 m .47948 .44094 L .48102 .44259 L 0 .036 .138 r
F
.47828 .44346 m .47674 .44185 L .47948 .44094 L F
.62425 .4425 m .62566 .44005 L .62706 .44159 L 0 .034 .135 r
F
.62425 .4425 m .62285 .44099 L .62566 .44005 L F
.33783 .43941 m .33881 .43708 L .34048 .43864 L 0 .027 .127 r
F
.33783 .43941 m .33615 .43785 L .33881 .43708 L F
.86562 .43864 m .86738 .4361 L .86854 .43767 L 0 .026 .124 r
F
.86562 .43864 m .86445 .43708 L .86738 .4361 L F
.69161 .44119 m .69312 .43878 L .69445 .4403 L 0 .031 .132 r
F
.69161 .44119 m .69027 .43968 L .69312 .43878 L F
.69862 .44081 m .70013 .43827 L .70146 .43979 L 0 .03 .13 r
F
.69862 .44081 m .69729 .43928 L .70013 .43827 L F
.8193 .43887 m .82099 .43629 L .82221 .43795 L 0 .026 .125 r
F
.8193 .43887 m .81808 .4372 L .82099 .43629 L F
.54989 .44431 m .55119 .44179 L .55266 .44331 L 0 .038 .14 r
F
.54989 .44431 m .54841 .4428 L .55119 .44179 L F
.57092 .44315 m .57226 .44104 L .57371 .44241 L 0 .036 .138 r
F
.57092 .44315 m .56947 .44178 L .57226 .44104 L F
.42069 .442 m .4218 .43968 L .4234 .44124 L 0 .033 .134 r
F
.42069 .442 m .4191 .44047 L .4218 .43968 L F
.87264 .43831 m .87441 .43582 L .87557 .43742 L 0 .025 .124 r
F
.87264 .43831 m .87147 .43673 L .87441 .43582 L F
.70563 .44048 m .70715 .43778 L .70848 .43951 L 0 .029 .129 r
F
.70563 .44048 m .7043 .43878 L .70715 .43778 L F
.38839 .44146 m .38946 .43901 L .39108 .44073 L 0 .032 .132 r
F
.38839 .44146 m .38677 .43974 L .38946 .43901 L F
.29851 .43935 m .29944 .43691 L .30115 .43852 L 0 .027 .127 r
F
.29851 .43935 m .2968 .43776 L .29944 .43691 L F
.50356 .44463 m .5048 .44243 L .50631 .44403 L 0 .04 .142 r
F
.50356 .44463 m .50205 .44303 L .5048 .44243 L F
.25919 .4392 m .26007 .43679 L .26181 .43845 L 0 .027 .126 r
F
.25919 .4392 m .25745 .43755 L .26007 .43679 L F
.63127 .44232 m .63269 .4398 L .63408 .44146 L 0 .034 .135 r
F
.63127 .44232 m .62987 .44069 L .63269 .4398 L F
.44598 .44311 m .44712 .44093 L .44869 .44249 L 0 .036 .138 r
F
.44598 .44311 m .44441 .44152 L .44712 .44093 L F
.82633 .43864 m .82804 .43621 L .82925 .4378 L 0 .026 .125 r
F
.82633 .43864 m .82512 .43707 L .82804 .43621 L F
.76599 .43963 m .7676 .43718 L .76887 .43874 L 0 .028 .128 r
F
.76599 .43963 m .76472 .43808 L .7676 .43718 L F
.48529 .44333 m .4865 .44071 L .48803 .44242 L 0 .036 .137 r
F
.48529 .44333 m .48376 .44165 L .4865 .44071 L F
.926 .43795 m .92783 .43536 L .92896 .43705 L 0 .024 .123 r
F
.926 .43795 m .92487 .43626 L .92783 .43536 L F
.71266 .44028 m .71419 .43768 L .71551 .43941 L 0 .029 .129 r
F
.71266 .44028 m .71133 .43854 L .71419 .43768 L F
.3631 .44069 m .36413 .43819 L .36577 .43983 L 0 .03 .13 r
F
.3631 .44069 m .36145 .43902 L .36413 .43819 L F
.4277 .44188 m .42882 .43945 L .43041 .44101 L 0 .033 .134 r
F
.4277 .44188 m .42611 .44034 L .42882 .43945 L F
.77301 .43936 m .77462 .43675 L .77588 .43837 L 0 .027 .127 r
F
.77301 .43936 m .77174 .43774 L .77462 .43675 L F
.87968 .43821 m .88145 .43559 L .88262 .43728 L 0 .025 .123 r
F
.87968 .43821 m .87851 .43652 L .88145 .43559 L F
.5246 .44373 m .52587 .44155 L .52736 .44289 L 0 .038 .14 r
F
.5246 .44373 m .5231 .44237 L .52587 .44155 L F
.57794 .44315 m .57929 .44092 L .58073 .44242 L 0 .037 .138 r
F
.57794 .44315 m .57649 .44167 L .57929 .44092 L F
.83337 .4385 m .83509 .43611 L .83629 .43766 L 0 .026 .125 r
F
.83337 .4385 m .83217 .43695 L .83509 .43611 L F
.65933 .44106 m .66079 .43874 L .66216 .44025 L 0 .032 .132 r
F
.65933 .44106 m .65796 .43955 L .66079 .43874 L F
.78003 .43911 m .78165 .43646 L .78292 .43819 L 0 .027 .126 r
F
.78003 .43911 m .77877 .43741 L .78165 .43646 L F
.65231 .44145 m .65376 .4389 L .65513 .44041 L 0 .032 .133 r
F
.65231 .44145 m .65094 .43994 L .65376 .4389 L F
.30549 .43932 m .30644 .43685 L .30814 .4385 L 0 .028 .127 r
F
.30549 .43932 m .30379 .43769 L .30644 .43685 L F
.72669 .43975 m .72825 .43728 L .72955 .43877 L 0 .029 .128 r
F
.72669 .43975 m .72539 .43826 L .72825 .43728 L F
.51759 .44423 m .51884 .44195 L .52034 .4433 L 0 .039 .141 r
F
.51759 .44423 m .51608 .44285 L .51884 .44195 L F
.71968 .44016 m .72123 .43762 L .72254 .43923 L 0 .029 .129 r
F
.71968 .44016 m .71837 .43853 L .72123 .43762 L F
.88672 .43805 m .88849 .43541 L .88966 .43711 L 0 .025 .123 r
F
.88672 .43805 m .88555 .43635 L .88849 .43541 L F
.73371 .43941 m .73529 .43707 L .73658 .43858 L 0 .028 .128 r
F
.73371 .43941 m .73242 .43791 L .73529 .43707 L F
.63829 .44234 m .63972 .43962 L .64111 .44134 L 0 .034 .135 r
F
.63829 .44234 m .6369 .4406 L .63972 .43962 L F
.51057 .44467 m .51182 .44233 L .51333 .44376 L 0 .04 .142 r
F
.51057 .44467 m .50906 .44323 L .51182 .44233 L F
.26617 .43924 m .26707 .43662 L .2688 .43832 L 0 .027 .127 r
F
.26617 .43924 m .26444 .43756 L .26707 .43662 L F
.3448 .43964 m .34581 .43717 L .34746 .43889 L 0 .028 .128 r
F
.3448 .43964 m .34314 .43791 L .34581 .43717 L F
.64531 .44202 m .64674 .43932 L .64812 .44099 L 0 .033 .134 r
F
.64531 .44202 m .64392 .44033 L .64674 .43932 L F
.4923 .44339 m .49351 .44108 L .49504 .44271 L 0 .037 .139 r
F
.4923 .44339 m .49077 .44174 L .49351 .44108 L F
.4347 .44185 m .43583 .43959 L .43741 .44118 L 0 .034 .135 r
F
.4347 .44185 m .43312 .44027 L .43583 .43959 L F
.8404 .43836 m .84213 .43592 L .84332 .43747 L 0 .026 .125 r
F
.8404 .43836 m .83921 .43681 L .84213 .43592 L F
.37009 .4407 m .37113 .43833 L .37277 .43994 L 0 .031 .131 r
F
.37009 .4407 m .36845 .43908 L .37113 .43833 L F
.39538 .44171 m .39646 .43908 L .39808 .44081 L 0 .033 .134 r
F
.39538 .44171 m .39377 .43998 L .39646 .43908 L F
.78706 .43901 m .7887 .43637 L .78996 .43809 L 0 .027 .126 r
F
.78706 .43901 m .7858 .43727 L .7887 .43637 L F
.89375 .43784 m .89554 .43521 L .89669 .4369 L 0 .025 .123 r
F
.89375 .43784 m .89259 .43616 L .89554 .43521 L F
.59898 .44233 m .60036 .43982 L .60178 .44144 L 0 .035 .136 r
F
.59898 .44233 m .59756 .44071 L .60036 .43982 L F
.45298 .44331 m .45414 .4409 L .4557 .44239 L 0 .037 .139 r
F
.45298 .44331 m .45141 .44178 L .45414 .4409 L F
.66635 .44098 m .66783 .43859 L .66919 .44013 L 0 .032 .132 r
F
.66635 .44098 m .66499 .43943 L .66783 .43859 L F
.58496 .44313 m .58631 .44047 L .58775 .44212 L 0 .036 .138 r
F
.58496 .44313 m .58352 .44148 L .58631 .44047 L F
.53161 .44373 m .53289 .44153 L .53438 .44303 L 0 .039 .14 r
F
.53161 .44373 m .53012 .44221 L .53289 .44153 L F
.59197 .44276 m .59333 .44009 L .59476 .44174 L 0 .035 .137 r
F
.59197 .44276 m .59054 .44111 L .59333 .44009 L F
.31249 .43926 m .31345 .43673 L .31514 .43834 L 0 .028 .127 r
F
.31249 .43926 m .31079 .43763 L .31345 .43673 L F
.27317 .43908 m .27406 .43666 L .27579 .43831 L F
.27317 .43908 m .27144 .43743 L .27406 .43666 L F
.79409 .43874 m .79574 .43624 L .79698 .43779 L 0 .027 .126 r
F
.79409 .43874 m .79285 .43718 L .79574 .43624 L F
.8011 .43836 m .80276 .43584 L .80399 .43738 L 0 .026 .125 r
F
.8011 .43836 m .79987 .43681 L .80276 .43584 L F
.45999 .44303 m .46116 .4407 L .46271 .44221 L 0 .037 .138 r
F
.45999 .44303 m .45843 .44148 L .46116 .4407 L F
.90078 .43759 m .9026 .43513 L .90373 .43672 L 0 .024 .123 r
F
.90078 .43759 m .89964 .43601 L .9026 .43513 L F
.84744 .43819 m .84916 .43558 L .85036 .43727 L 0 .026 .124 r
F
.84744 .43819 m .84624 .43653 L .84916 .43558 L F
.74075 .43939 m .74233 .43692 L .74362 .43856 L 0 .028 .128 r
F
.74075 .43939 m .73945 .43776 L .74233 .43692 L F
.31949 .43903 m .32045 .43668 L .32214 .43826 L 0 .028 .127 r
F
.31949 .43903 m .3178 .43743 L .32045 .43668 L F
.80813 .43812 m .80981 .43569 L .81104 .43729 L 0 .026 .125 r
F
.80813 .43812 m .8069 .43653 L .80981 .43569 L F
.40238 .44165 m .40347 .43902 L .40508 .44075 L 0 .033 .134 r
F
.40238 .44165 m .40077 .43992 L .40347 .43902 L F
.606 .44224 m .60739 .43988 L .60881 .44144 L 0 .035 .136 r
F
.606 .44224 m .60458 .44066 L .60739 .43988 L F
.90782 .43741 m .90963 .43488 L .91077 .43646 L 0 .024 .123 r
F
.90782 .43741 m .90669 .43583 L .90963 .43488 L F
.67338 .44092 m .67486 .43836 L .67621 .44001 L 0 .032 .132 r
F
.67338 .44092 m .67202 .43928 L .67486 .43836 L F
.37708 .44076 m .37814 .43812 L .37977 .43979 L 0 .031 .132 r
F
.37708 .44076 m .37545 .4391 L .37814 .43812 L F
.35179 .43979 m .3528 .43726 L .35446 .43896 L 0 .029 .129 r
F
.35179 .43979 m .35013 .43807 L .3528 .43726 L F
.46699 .44291 m .46817 .44063 L .46973 .44208 L 0 .037 .138 r
F
.46699 .44291 m .46544 .44142 L .46817 .44063 L F
.85448 .4381 m .85622 .43556 L .85741 .43727 L 0 .026 .125 r
F
.85448 .4381 m .85329 .4364 L .85622 .43556 L F
.40939 .44142 m .41049 .43892 L .41209 .4405 L 0 .033 .134 r
F
.40939 .44142 m .40778 .43984 L .41049 .43892 L F
.91485 .43715 m .91667 .4346 L .9178 .43625 L 0 .024 .122 r
F
.91485 .43715 m .91371 .43551 L .91667 .4346 L F
.24784 .43851 m .24871 .43597 L .25046 .43757 L 0 .027 .126 r
F
.24784 .43851 m .24608 .43693 L .24871 .43597 L F
.28015 .43911 m .28106 .43668 L .28278 .43824 L 0 .028 .128 r
F
.28015 .43911 m .27842 .43754 L .28106 .43668 L F
.53863 .44381 m .53992 .44156 L .5414 .44309 L 0 .039 .141 r
F
.53863 .44381 m .53714 .4423 L .53992 .44156 L F
.4993 .44364 m .50053 .44144 L .50205 .44303 L F
.4993 .44364 m .49778 .44206 L .50053 .44144 L F
.38409 .44054 m .38515 .43801 L .38677 .43974 L 0 .031 .132 r
F
.38409 .44054 m .38246 .43882 L .38515 .43801 L F
.6804 .44074 m .68189 .43812 L .68324 .43982 L F
.6804 .44074 m .67905 .43906 L .68189 .43812 L F
.47401 .44269 m .4752 .4404 L .47674 .44185 L 0 .037 .138 r
F
.47401 .44269 m .47246 .44124 L .4752 .4404 L F
.4417 .44211 m .44283 .4399 L .44441 .44152 L 0 .035 .137 r
F
.4417 .44211 m .44012 .44051 L .44283 .4399 L F
.74779 .43939 m .74937 .43681 L .75066 .43848 L 0 .029 .128 r
F
.74779 .43939 m .7465 .43772 L .74937 .43681 L F
.28715 .43885 m .28808 .43634 L .2898 .43791 L 0 .028 .127 r
F
.28715 .43885 m .28543 .43729 L .28808 .43634 L F
.32648 .43905 m .32745 .43663 L .32914 .43819 L 0 .028 .128 r
F
.32648 .43905 m .32479 .43748 L .32745 .43663 L F
.61302 .44217 m .61442 .43983 L .61583 .44134 L 0 .035 .137 r
F
.61302 .44217 m .61161 .44064 L .61442 .43983 L F
.4164 .44121 m .4175 .43894 L .4191 .44047 L 0 .033 .134 r
F
.4164 .44121 m .41479 .43971 L .4175 .43894 L F
.81518 .43811 m .81685 .43553 L .81808 .4372 L 0 .026 .125 r
F
.81518 .43811 m .81395 .43644 L .81685 .43553 L F
.25484 .43832 m .2557 .43591 L .25745 .43755 L 0 .027 .126 r
F
.25484 .43832 m .25309 .4367 L .2557 .43591 L F
.68743 .44052 m .68893 .43809 L .69027 .43968 L 0 .031 .132 r
F
.68743 .44052 m .68609 .43896 L .68893 .43809 L F
.55967 .44286 m .56099 .44039 L .56245 .44188 L 0 .037 .138 r
F
.55967 .44286 m .55821 .44136 L .56099 .44039 L F
.75481 .43918 m .7564 .43657 L .75769 .43825 L 0 .028 .128 r
F
.75481 .43918 m .75353 .43753 L .7564 .43657 L F
.33348 .4388 m .33447 .43629 L .33615 .43785 L 0 .028 .127 r
F
.33348 .4388 m .3318 .43724 L .33447 .43629 L F
.29415 .43862 m .29508 .43617 L .2968 .43776 L 0 .027 .127 r
F
.29415 .43862 m .29244 .43704 L .29508 .43617 L F
.56669 .44251 m .56802 .4404 L .56947 .44178 L 0 .037 .138 r
F
.56669 .44251 m .56523 .44114 L .56802 .4404 L F
.70146 .43979 m .70298 .43725 L .7043 .43878 L 0 .03 .13 r
F
.70146 .43979 m .70013 .43827 L .70298 .43725 L F
.62004 .44194 m .62145 .43948 L .62285 .44099 L 0 .035 .136 r
F
.62004 .44194 m .61864 .44047 L .62145 .43948 L F
.86153 .43805 m .86327 .43543 L .86445 .43708 L 0 .026 .125 r
F
.86153 .43805 m .86035 .43641 L .86327 .43543 L F
.55266 .44331 m .55396 .44081 L .55543 .44233 L 0 .038 .14 r
F
.55266 .44331 m .55119 .44179 L .55396 .44081 L F
.86854 .43767 m .87031 .43515 L .87147 .43673 L 0 .025 .124 r
F
.86854 .43767 m .86738 .4361 L .87031 .43515 L F
.9219 .43709 m .92374 .43456 L .92487 .43626 L 0 .024 .122 r
F
.9219 .43709 m .92077 .4354 L .92374 .43456 L F
.62706 .44159 m .62847 .43911 L .62987 .44069 L 0 .034 .135 r
F
.62706 .44159 m .62566 .44005 L .62847 .43911 L F
.35878 .43984 m .3598 .43736 L .36145 .43902 L 0 .03 .13 r
F
.35878 .43984 m .35713 .43815 L .3598 .43736 L F
.48102 .44259 m .48222 .43997 L .48376 .44165 L 0 .036 .138 r
F
.48102 .44259 m .47948 .44094 L .48222 .43997 L F
.82221 .43795 m .8239 .4354 L .82512 .43707 L 0 .026 .125 r
F
.82221 .43795 m .82099 .43629 L .8239 .4354 L F
.70848 .43951 m .71 .43679 L .71133 .43854 L 0 .029 .129 r
F
.70848 .43951 m .70715 .43778 L .71 .43679 L F
.76184 .43893 m .76345 .43653 L .76472 .43808 L 0 .028 .128 r
F
.76184 .43893 m .76057 .43739 L .76345 .43653 L F
.69445 .4403 m .69596 .43776 L .69729 .43928 L 0 .031 .131 r
F
.69445 .4403 m .69312 .43878 L .69596 .43776 L F
.54564 .44382 m .54694 .4413 L .54841 .4428 L 0 .039 .141 r
F
.54564 .44382 m .54417 .4423 L .54694 .4413 L F
.87557 .43742 m .87735 .4349 L .87851 .43652 L 0 .025 .124 r
F
.87557 .43742 m .87441 .43582 L .87735 .4349 L F
.34048 .43864 m .34147 .43634 L .34314 .43791 L 0 .028 .127 r
F
.34048 .43864 m .33881 .43708 L .34147 .43634 L F
.30115 .43852 m .30209 .43605 L .30379 .43769 L 0 .027 .127 r
F
.30115 .43852 m .29944 .43691 L .30209 .43605 L F
.4234 .44124 m .42452 .43875 L .42611 .44034 L 0 .033 .134 r
F
.4234 .44124 m .4218 .43968 L .42452 .43875 L F
.57371 .44241 m .57505 .44028 L .57649 .44167 L 0 .037 .138 r
F
.57371 .44241 m .57226 .44104 L .57505 .44028 L F
.48803 .44242 m .48924 .44004 L .49077 .44174 L 0 .036 .138 r
F
.48803 .44242 m .4865 .44071 L .48924 .44004 L F
.63408 .44146 m .63551 .4389 L .6369 .4406 L 0 .034 .135 r
F
.63408 .44146 m .63269 .4398 L .63551 .4389 L F
.76887 .43874 m .77048 .43619 L .77174 .43774 L 0 .028 .127 r
F
.76887 .43874 m .7676 .43718 L .77048 .43619 L F
.77588 .43837 m .77751 .43577 L .77877 .43741 L 0 .027 .126 r
F
.77588 .43837 m .77462 .43675 L .77751 .43577 L F
.82925 .4378 m .83096 .43536 L .83217 .43695 L 0 .026 .125 r
F
.82925 .4378 m .82804 .43621 L .83096 .43536 L F
.39108 .44073 m .39215 .43825 L .39377 .43998 L 0 .032 .133 r
F
.39108 .44073 m .38946 .43901 L .39215 .43825 L F
.92896 .43705 m .9308 .43445 L .93192 .43613 L 0 .024 .123 r
F
.92896 .43705 m .92783 .43536 L .9308 .43445 L F
.71551 .43941 m .71705 .43682 L .71837 .43853 L 0 .029 .129 r
F
.71551 .43941 m .71419 .43768 L .71705 .43682 L F
.88262 .43728 m .88439 .43466 L .88555 .43635 L 0 .025 .123 r
F
.88262 .43728 m .88145 .43559 L .88439 .43466 L F
.26181 .43845 m .2627 .43588 L .26444 .43756 L 0 .027 .127 r
F
.26181 .43845 m .26007 .43679 L .2627 .43588 L F
.65513 .44041 m .65659 .43803 L .65796 .43955 L 0 .032 .132 r
F
.65513 .44041 m .65376 .4389 L .65659 .43803 L F
.36577 .43983 m .3668 .43746 L .36845 .43908 L 0 .031 .131 r
F
.36577 .43983 m .36413 .43819 L .3668 .43746 L F
.43041 .44101 m .43153 .43868 L .43312 .44027 L 0 .033 .134 r
F
.43041 .44101 m .42882 .43945 L .43153 .43868 L F
.78292 .43819 m .78454 .43552 L .7858 .43727 L 0 .027 .126 r
F
.78292 .43819 m .78165 .43646 L .78454 .43552 L F
.72955 .43877 m .73112 .43641 L .73242 .43791 L 0 .028 .128 r
F
.72955 .43877 m .72825 .43728 L .73112 .43641 L F
.50631 .44403 m .50755 .44161 L .50906 .44323 L 0 .041 .143 r
F
.50631 .44403 m .5048 .44243 L .50755 .44161 L F
.44869 .44249 m .44984 .44024 L .45141 .44178 L 0 .037 .139 r
F
.44869 .44249 m .44712 .44093 L .44984 .44024 L F
.64111 .44134 m .64254 .43864 L .64392 .44033 L 0 .034 .135 r
F
.64111 .44134 m .63972 .43962 L .64254 .43864 L F
.52736 .44289 m .52863 .44086 L .53012 .44221 L 0 .039 .14 r
F
.52736 .44289 m .52587 .44155 L .52863 .44086 L F
.52034 .4433 m .5216 .44106 L .5231 .44237 L 0 .039 .141 r
F
.52034 .4433 m .51884 .44195 L .5216 .44106 L F
.83629 .43766 m .83801 .43528 L .83921 .43681 L 0 .026 .125 r
F
.83629 .43766 m .83509 .43611 L .83801 .43528 L F
.72254 .43923 m .72409 .43666 L .72539 .43826 L 0 .029 .129 r
F
.72254 .43923 m .72123 .43762 L .72409 .43666 L F
.64812 .44099 m .64956 .43829 L .65094 .43994 L 0 .033 .134 r
F
.64812 .44099 m .64674 .43932 L .64956 .43829 L F
.88966 .43711 m .89143 .43445 L .89259 .43616 L 0 .025 .123 r
F
.88966 .43711 m .88849 .43541 L .89143 .43445 L F
.66216 .44025 m .66363 .43793 L .66499 .43943 L 0 .032 .133 r
F
.66216 .44025 m .66079 .43874 L .66363 .43793 L F
.30814 .4385 m .3091 .43597 L .31079 .43763 L 0 .028 .127 r
F
.30814 .4385 m .30644 .43685 L .3091 .43597 L F
.51333 .44376 m .51458 .44143 L .51608 .44285 L 0 .04 .142 r
F
.51333 .44376 m .51182 .44233 L .51458 .44143 L F
.2688 .43832 m .26971 .43571 L .27144 .43743 L 0 .027 .127 r
F
.2688 .43832 m .26707 .43662 L .26971 .43571 L F
.58073 .44242 m .58208 .43999 L .58352 .44148 L 0 .037 .138 r
F
.58073 .44242 m .57929 .44092 L .58208 .43999 L F
.73658 .43858 m .73816 .43624 L .73945 .43776 L 0 .028 .128 r
F
.73658 .43858 m .73529 .43707 L .73816 .43624 L F
.58775 .44212 m .5891 .43946 L .59054 .44111 L 0 .036 .137 r
F
.58775 .44212 m .58631 .44047 L .5891 .43946 L F
.59476 .44174 m .59613 .43908 L .59756 .44071 L 0 .035 .136 r
F
.59476 .44174 m .59333 .44009 L .59613 .43908 L F
.84332 .43747 m .84505 .43495 L .84624 .43653 L 0 .026 .125 r
F
.84332 .43747 m .84213 .43592 L .84505 .43495 L F
.89669 .4369 m .89849 .43432 L .89964 .43601 L 0 .025 .123 r
F
.89669 .4369 m .89554 .43521 L .89849 .43432 L F
.39808 .44081 m .39916 .43818 L .40077 .43992 L 0 .033 .134 r
F
.39808 .44081 m .39646 .43908 L .39916 .43818 L F
.78996 .43809 m .79159 .43546 L .79285 .43718 L 0 .027 .126 r
F
.78996 .43809 m .7887 .43637 L .79159 .43546 L F
.4557 .44239 m .45687 .44002 L .45843 .44148 L 0 .037 .139 r
F
.4557 .44239 m .45414 .4409 L .45687 .44002 L F
.34746 .43889 m .34848 .43636 L .35013 .43807 L 0 .029 .129 r
F
.34746 .43889 m .34581 .43717 L .34848 .43636 L F
.60178 .44144 m .60316 .43905 L .60458 .44066 L 0 .035 .136 r
F
.60178 .44144 m .60036 .43982 L .60316 .43905 L F
.31514 .43834 m .31611 .43584 L .3178 .43743 L 0 .028 .127 r
F
.31514 .43834 m .31345 .43673 L .31611 .43584 L F
.80399 .43738 m .80567 .43498 L .8069 .43653 L 0 .026 .125 r
F
.80399 .43738 m .80276 .43584 L .80567 .43498 L F
.79698 .43779 m .79864 .43526 L .79987 .43681 L 0 .027 .126 r
F
.79698 .43779 m .79574 .43624 L .79864 .43526 L F
.66919 .44013 m .67067 .43775 L .67202 .43928 L 0 .032 .132 r
F
.66919 .44013 m .66783 .43859 L .67067 .43775 L F
.37277 .43994 m .37381 .43751 L .37545 .4391 L 0 .031 .132 r
F
.37277 .43994 m .37113 .43833 L .37381 .43751 L F
.49504 .44271 m .49626 .44042 L .49778 .44206 L 0 .038 .14 r
F
.49504 .44271 m .49351 .44108 L .49626 .44042 L F
.85036 .43727 m .85209 .4347 L .85329 .4364 L 0 .025 .124 r
F
.85036 .43727 m .84916 .43558 L .85209 .4347 L F
.43741 .44118 m .43854 .43892 L .44012 .44051 L 0 .035 .136 r
F
.43741 .44118 m .43583 .43959 L .43854 .43892 L F
.90373 .43672 m .90555 .43425 L .90669 .43583 L 0 .025 .123 r
F
.90373 .43672 m .9026 .43513 L .90555 .43425 L F
.27579 .43831 m .27669 .43589 L .27842 .43754 L 0 .028 .128 r
F
.27579 .43831 m .27406 .43666 L .27669 .43589 L F
.46271 .44221 m .46389 .43997 L .46544 .44142 L 0 .037 .139 r
F
.46271 .44221 m .46116 .4407 L .46389 .43997 L F
.53438 .44303 m .53566 .44079 L .53714 .4423 L 0 .039 .141 r
F
.53438 .44303 m .53289 .44153 L .53566 .44079 L F
.74362 .43856 m .7452 .43609 L .7465 .43772 L 0 .028 .128 r
F
.74362 .43856 m .74233 .43692 L .7452 .43609 L F
.91077 .43646 m .91259 .43393 L .91371 .43551 L 0 .024 .122 r
F
.91077 .43646 m .90963 .43488 L .91259 .43393 L F
.40508 .44075 m .40618 .43813 L .40778 .43984 L 0 .033 .134 r
F
.40508 .44075 m .40347 .43902 L .40618 .43813 L F
.37977 .43979 m .38084 .43714 L .38246 .43882 L 0 .031 .131 r
F
.37977 .43979 m .37814 .43812 L .38084 .43714 L F
.67621 .44001 m .6777 .43739 L .67905 .43906 L 0 .032 .132 r
F
.67621 .44001 m .67486 .43836 L .6777 .43739 L F
.32214 .43826 m .3231 .43592 L .32479 .43748 L 0 .028 .128 r
F
.32214 .43826 m .32045 .43668 L .3231 .43592 L F
.81104 .43729 m .81272 .43484 L .81395 .43644 L 0 .026 .125 r
F
.81104 .43729 m .80981 .43569 L .81272 .43484 L F
.24345 .43788 m .24432 .4353 L .24608 .43693 L 0 .027 .126 r
F
.24345 .43788 m .24169 .43627 L .24432 .4353 L F
.60881 .44144 m .6102 .43909 L .61161 .44064 L 0 .035 .137 r
F
.60881 .44144 m .60739 .43988 L .6102 .43909 L F
.25046 .43757 m .25133 .43507 L .25309 .4367 L 0 .027 .126 r
F
.25046 .43757 m .24871 .43597 L .25133 .43507 L F
.41209 .4405 m .41319 .43813 L .41479 .43971 L 0 .033 .134 r
F
.41209 .4405 m .41049 .43892 L .41319 .43813 L F
.35446 .43896 m .35548 .43647 L .35713 .43815 L 0 .03 .13 r
F
.35446 .43896 m .3528 .43726 L .35548 .43647 L F
.46973 .44208 m .47091 .4398 L .47246 .44124 L 0 .037 .139 r
F
.46973 .44208 m .46817 .44063 L .47091 .4398 L F
.9178 .43625 m .91964 .43375 L .92077 .4354 L 0 .024 .122 r
F
.9178 .43625 m .91667 .4346 L .91964 .43375 L F
.28278 .43824 m .2837 .43572 L .28543 .43729 L 0 .028 .128 r
F
.28278 .43824 m .28106 .43668 L .2837 .43572 L F
.85741 .43727 m .85915 .43469 L .86035 .43641 L 0 .026 .125 r
F
.85741 .43727 m .85622 .43556 L .85915 .43469 L F
.68324 .43982 m .68473 .43723 L .68609 .43896 L 0 .031 .132 r
F
.68324 .43982 m .68189 .43812 L .68473 .43723 L F
.75066 .43848 m .75224 .43584 L .75353 .43753 L 0 .028 .128 r
F
.75066 .43848 m .74937 .43681 L .75224 .43584 L F
.2898 .43791 m .29072 .43545 L .29244 .43704 L 0 .028 .127 r
F
.2898 .43791 m .28808 .43634 L .29072 .43545 L F
.47674 .44185 m .47794 .4395 L .47948 .44094 L 0 .037 .138 r
F
.47674 .44185 m .4752 .4404 L .47794 .4395 L F
.81808 .4372 m .81977 .43463 L .82099 .43629 L 0 .026 .125 r
F
.81808 .4372 m .81685 .43553 L .81977 .43463 L F
.56245 .44188 m .56377 .43962 L .56523 .44114 L 0 .037 .138 r
F
.56245 .44188 m .56099 .44039 L .56377 .43962 L F
.38677 .43974 m .38784 .43727 L .38946 .43901 L 0 .032 .132 r
F
.38677 .43974 m .38515 .43801 L .38784 .43727 L F
.32914 .43819 m .33012 .43568 L .3318 .43724 L 0 .028 .128 r
F
.32914 .43819 m .32745 .43663 L .33012 .43568 L F
.7043 .43878 m .70583 .43623 L .70715 .43778 L 0 .029 .129 r
F
.7043 .43878 m .70298 .43725 L .70583 .43623 L F
.5414 .44309 m .54269 .44078 L .54417 .4423 L 0 .04 .142 r
F
.5414 .44309 m .53992 .44156 L .54269 .44078 L F
.61583 .44134 m .61723 .43896 L .61864 .44047 L 0 .035 .137 r
F
.61583 .44134 m .61442 .43983 L .61723 .43896 L F
.33615 .43785 m .33714 .43551 L .33881 .43708 L 0 .028 .127 r
F
.33615 .43785 m .33447 .43629 L .33714 .43551 L F
.55543 .44233 m .55674 .43985 L .55821 .44136 L 0 .038 .139 r
F
.55543 .44233 m .55396 .44081 L .55674 .43985 L F
.86445 .43708 m .8662 .43446 L .86738 .4361 L 0 .026 .124 r
F
.86445 .43708 m .86327 .43543 L .8662 .43446 L F
.75769 .43825 m .75929 .4357 L .76057 .43739 L 0 .028 .128 r
F
.75769 .43825 m .7564 .43657 L .75929 .4357 L F
.62285 .44099 m .62426 .4385 L .62566 .44005 L 0 .035 .136 r
F
.62285 .44099 m .62145 .43948 L .62426 .4385 L F
.87147 .43673 m .87324 .43421 L .87441 .43582 L 0 .025 .124 r
F
.87147 .43673 m .87031 .43515 L .87324 .43421 L F
.69729 .43928 m .6988 .43675 L .70013 .43827 L 0 .031 .131 r
F
.69729 .43928 m .69596 .43776 L .6988 .43675 L F
.69027 .43968 m .69178 .43718 L .69312 .43878 L 0 .032 .132 r
F
.69027 .43968 m .68893 .43809 L .69178 .43718 L F
.54841 .4428 m .54972 .4403 L .55119 .44179 L 0 .039 .141 r
F
.54841 .4428 m .54694 .4413 L .54972 .4403 L F
.4191 .44047 m .42021 .43812 L .4218 .43968 L 0 .034 .135 r
F
.4191 .44047 m .4175 .43894 L .42021 .43812 L F
.25745 .43755 m .25833 .43513 L .26007 .43679 L 0 .027 .126 r
F
.25745 .43755 m .2557 .43591 L .25833 .43513 L F
.48376 .44165 m .48497 .439 L .4865 .44071 L 0 .036 .137 r
F
.48376 .44165 m .48222 .43997 L .48497 .439 L F
.71133 .43854 m .71286 .43594 L .71419 .43768 L 0 .029 .129 r
F
.71133 .43854 m .71 .43679 L .71286 .43594 L F
.2968 .43776 m .29773 .4353 L .29944 .43691 L 0 .027 .127 r
F
.2968 .43776 m .29508 .43617 L .29773 .4353 L F
.62987 .44069 m .63129 .43818 L .63269 .4398 L 0 .034 .135 r
F
.62987 .44069 m .62847 .43911 L .63129 .43818 L F
.50205 .44303 m .50328 .44082 L .5048 .44243 L 0 .04 .142 r
F
.50205 .44303 m .50053 .44144 L .50328 .44082 L F
.92487 .43626 m .92671 .43367 L .92783 .43536 L 0 .024 .123 r
F
.92487 .43626 m .92374 .43456 L .92671 .43367 L F
.44441 .44152 m .44555 .43929 L .44712 .44093 L 0 .036 .138 r
F
.44441 .44152 m .44283 .4399 L .44555 .43929 L F
.82512 .43707 m .82682 .43452 L .82804 .43621 L 0 .026 .125 r
F
.82512 .43707 m .8239 .4354 L .82682 .43452 L F
.36145 .43902 m .36248 .43656 L .36413 .43819 L 0 .03 .13 r
F
.36145 .43902 m .3598 .43736 L .36248 .43656 L F
.87851 .43652 m .88028 .43397 L .88145 .43559 L 0 .025 .123 r
F
.87851 .43652 m .87735 .4349 L .88028 .43397 L F
.56947 .44178 m .57081 .43965 L .57226 .44104 L 0 .037 .139 r
F
.56947 .44178 m .56802 .4404 L .57081 .43965 L F
.76472 .43808 m .76634 .43563 L .7676 .43718 L 0 .028 .128 r
F
.76472 .43808 m .76345 .43653 L .76634 .43563 L F
.77174 .43774 m .77336 .43519 L .77462 .43675 L 0 .027 .127 r
F
.77174 .43774 m .77048 .43619 L .77336 .43519 L F
.77877 .43741 m .78039 .4348 L .78165 .43646 L 0 .027 .126 r
F
.77877 .43741 m .77751 .43577 L .78039 .4348 L F
.42611 .44034 m .42723 .43781 L .42882 .43945 L 0 .033 .134 r
F
.42611 .44034 m .42452 .43875 L .42723 .43781 L F
.6369 .4406 m .63832 .43794 L .63972 .43962 L 0 .034 .135 r
F
.6369 .4406 m .63551 .4389 L .63832 .43794 L F
.30379 .43769 m .30474 .4352 L .30644 .43685 L 0 .028 .127 r
F
.30379 .43769 m .30209 .43605 L .30474 .4352 L F
.93192 .43613 m .93377 .43355 L .93489 .43522 L 0 .024 .123 r
F
.93192 .43613 m .9308 .43445 L .93377 .43355 L F
.88555 .43635 m .88733 .43372 L .88849 .43541 L 0 .025 .123 r
F
.88555 .43635 m .88439 .43466 L .88733 .43372 L F
.34314 .43791 m .34414 .43559 L .34581 .43717 L 0 .028 .128 r
F
.34314 .43791 m .34147 .43634 L .34414 .43559 L F
.83217 .43695 m .83388 .43452 L .83509 .43611 L 0 .026 .125 r
F
.83217 .43695 m .83096 .43536 L .83388 .43452 L F
.71837 .43853 m .71991 .43592 L .72123 .43762 L 0 .029 .129 r
F
.71837 .43853 m .71705 .43682 L .71991 .43592 L F
.26444 .43756 m .26534 .43492 L .26707 .43662 L 0 .027 .127 r
F
.26444 .43756 m .2627 .43588 L .26534 .43492 L F
.57649 .44167 m .57784 .43952 L .57929 .44092 L 0 .037 .139 r
F
.57649 .44167 m .57505 .44028 L .57784 .43952 L F
.65094 .43994 m .65239 .43726 L .65376 .4389 L 0 .032 .133 r
F
.65094 .43994 m .64956 .43829 L .65239 .43726 L F
.65796 .43955 m .65943 .43722 L .66079 .43874 L F
.65796 .43955 m .65659 .43803 L .65943 .43722 L F
.64392 .44033 m .64536 .43765 L .64674 .43932 L 0 .033 .134 r
F
.64392 .44033 m .64254 .43864 L .64536 .43765 L F
.39377 .43998 m .39485 .43736 L .39646 .43908 L 0 .033 .133 r
F
.39377 .43998 m .39215 .43825 L .39485 .43736 L F
.49077 .44174 m .49199 .43939 L .49351 .44108 L 0 .037 .139 r
F
.49077 .44174 m .48924 .44004 L .49199 .43939 L F
.7858 .43727 m .78744 .43463 L .7887 .43637 L 0 .027 .126 r
F
.7858 .43727 m .78454 .43552 L .78744 .43463 L F
.72539 .43826 m .72695 .4357 L .72825 .43728 L 0 .029 .129 r
F
.72539 .43826 m .72409 .43666 L .72695 .4357 L F
.5231 .44237 m .52437 .44025 L .52587 .44155 L 0 .039 .141 r
F
.5231 .44237 m .5216 .44106 L .52437 .44025 L F
.89259 .43616 m .89437 .43348 L .89554 .43521 L 0 .024 .123 r
F
.89259 .43616 m .89143 .43445 L .89437 .43348 L F
.36845 .43908 m .36948 .43673 L .37113 .43833 L 0 .031 .132 r
F
.36845 .43908 m .3668 .43746 L .36948 .43673 L F
.73242 .43791 m .73399 .43556 L .73529 .43707 L 0 .029 .128 r
F
.73242 .43791 m .73112 .43641 L .73399 .43556 L F
.43312 .44027 m .43425 .438 L .43583 .43959 L 0 .034 .135 r
F
.43312 .44027 m .43153 .43868 L .43425 .438 L F
.50906 .44323 m .51031 .4407 L .51182 .44233 L 0 .041 .143 r
F
.50906 .44323 m .50755 .44161 L .51031 .4407 L F
.58352 .44148 m .58487 .43898 L .58631 .44047 L 0 .037 .138 r
F
.58352 .44148 m .58208 .43999 L .58487 .43898 L F
.83921 .43681 m .84094 .43438 L .84213 .43592 L 0 .026 .125 r
F
.83921 .43681 m .83801 .43528 L .84094 .43438 L F
.51608 .44285 m .51734 .44056 L .51884 .44195 L 0 .04 .142 r
F
.51608 .44285 m .51458 .44143 L .51734 .44056 L F
.59756 .44071 m .59893 .43818 L .60036 .43982 L 0 .035 .136 r
F
.59756 .44071 m .59613 .43908 L .59893 .43818 L F
.59054 .44111 m .5919 .43845 L .59333 .44009 L 0 .035 .137 r
F
.59054 .44111 m .5891 .43946 L .5919 .43845 L F
.27144 .43743 m .27234 .43493 L .27406 .43666 L 0 .027 .127 r
F
.27144 .43743 m .26971 .43571 L .27234 .43493 L F
.31079 .43763 m .31175 .43506 L .31345 .43673 L 0 .028 .127 r
F
.31079 .43763 m .3091 .43597 L .31175 .43506 L F
.66499 .43943 m .66647 .4371 L .66783 .43859 L 0 .032 .133 r
F
.66499 .43943 m .66363 .43793 L .66647 .4371 L F
.45141 .44178 m .45257 .4394 L .45414 .4409 L 0 .038 .139 r
F
.45141 .44178 m .44984 .44024 L .45257 .4394 L F
.84624 .43653 m .84797 .43399 L .84916 .43558 L 0 .026 .124 r
F
.84624 .43653 m .84505 .43495 L .84797 .43399 L F
.53012 .44221 m .5314 .44017 L .53289 .44153 L 0 .039 .141 r
F
.53012 .44221 m .52863 .44086 L .5314 .44017 L F
.73945 .43776 m .74104 .4354 L .74233 .43692 L 0 .029 .128 r
F
.73945 .43776 m .73816 .43624 L .74104 .4354 L F
.89964 .43601 m .90144 .43345 L .9026 .43513 L 0 .025 .123 r
F
.89964 .43601 m .89849 .43432 L .90144 .43345 L F
.79285 .43718 m .79449 .43453 L .79574 .43624 L 0 .027 .126 r
F
.79285 .43718 m .79159 .43546 L .79449 .43453 L F
.40077 .43992 m .40187 .43729 L .40347 .43902 L 0 .033 .134 r
F
.40077 .43992 m .39916 .43818 L .40187 .43729 L F
.45843 .44148 m .45959 .43928 L .46116 .4407 L 0 .037 .139 r
F
.45843 .44148 m .45687 .44002 L .45959 .43928 L F
.79987 .43681 m .80153 .43428 L .80276 .43584 L 0 .026 .125 r
F
.79987 .43681 m .79864 .43526 L .80153 .43428 L F
.3178 .43743 m .31876 .4351 L .32045 .43668 L 0 .028 .127 r
F
.3178 .43743 m .31611 .43584 L .31876 .4351 L F
.35013 .43807 m .35115 .43555 L .3528 .43726 L 0 .029 .129 r
F
.35013 .43807 m .34848 .43636 L .35115 .43555 L F
.8069 .43653 m .80858 .43413 L .80981 .43569 L 0 .026 .125 r
F
.8069 .43653 m .80567 .43498 L .80858 .43413 L F
.67202 .43928 m .6735 .43682 L .67486 .43836 L 0 .032 .132 r
F
.67202 .43928 m .67067 .43775 L .6735 .43682 L F
.37545 .4391 m .3765 .43656 L .37814 .43812 L 0 .031 .132 r
F
.37545 .4391 m .37381 .43751 L .3765 .43656 L F
.60458 .44066 m .60597 .43829 L .60739 .43988 L 0 .035 .136 r
F
.60458 .44066 m .60316 .43905 L .60597 .43829 L F
.85329 .4364 m .85502 .43384 L .85622 .43556 L 0 .026 .124 r
F
.85329 .4364 m .85209 .4347 L .85502 .43384 L F
.90669 .43583 m .9085 .43329 L .90963 .43488 L 0 .024 .123 r
F
.90669 .43583 m .90555 .43425 L .9085 .43329 L F
.91371 .43551 m .91555 .43302 L .91667 .4346 L 0 .024 .122 r
F
.91371 .43551 m .91259 .43393 L .91555 .43302 L F
.38246 .43882 m .38353 .43633 L .38515 .43801 L 0 .031 .131 r
F
.38246 .43882 m .38084 .43714 L .38353 .43633 L F
.40778 .43984 m .40888 .43723 L .41049 .43892 L 0 .033 .134 r
F
.40778 .43984 m .40618 .43813 L .40888 .43723 L F
.67905 .43906 m .68053 .43642 L .68189 .43812 L 0 .031 .132 r
F
.67905 .43906 m .6777 .43739 L .68053 .43642 L F
.24608 .43693 m .24695 .43434 L .24871 .43597 L 0 .027 .126 r
F
.24608 .43693 m .24432 .4353 L .24695 .43434 L F
.7465 .43772 m .74808 .43516 L .74937 .43681 L 0 .029 .128 r
F
.7465 .43772 m .7452 .43609 L .74808 .43516 L F
.46544 .44142 m .46662 .43921 L .46817 .44063 L 0 .038 .139 r
F
.46544 .44142 m .46389 .43997 L .46662 .43921 L F
.27842 .43754 m .27933 .43502 L .28106 .43668 L 0 .028 .128 r
F
.27842 .43754 m .27669 .43589 L .27933 .43502 L F
.49778 .44206 m .49901 .43979 L .50053 .44144 L 0 .039 .141 r
F
.49778 .44206 m .49626 .44042 L .49901 .43979 L F
.44012 .44051 m .44126 .43827 L .44283 .4399 L 0 .035 .137 r
F
.44012 .44051 m .43854 .43892 L .44126 .43827 L F
.81395 .43644 m .81563 .43394 L .81685 .43553 L 0 .026 .125 r
F
.81395 .43644 m .81272 .43484 L .81563 .43394 L F
.53714 .4423 m .53843 .44003 L .53992 .44156 L 0 .04 .142 r
F
.53714 .4423 m .53566 .44079 L .53843 .44003 L F
.25309 .4367 m .25395 .43427 L .2557 .43591 L 0 .027 .126 r
F
.25309 .4367 m .25133 .43507 L .25395 .43427 L F
.28543 .43729 m .28635 .43476 L .28808 .43634 L 0 .028 .127 r
F
.28543 .43729 m .2837 .43572 L .28635 .43476 L F
.32479 .43748 m .32576 .43508 L .32745 .43663 L 0 .028 .128 r
F
.32479 .43748 m .3231 .43592 L .32576 .43508 L F
.61161 .44064 m .61301 .4383 L .61442 .43983 L 0 .036 .137 r
F
.61161 .44064 m .6102 .43909 L .61301 .4383 L F
.75353 .43753 m .75512 .43486 L .7564 .43657 L 0 .028 .128 r
F
.75353 .43753 m .75224 .43584 L .75512 .43486 L F
.47246 .44124 m .47365 .43896 L .4752 .4404 L 0 .037 .139 r
F
.47246 .44124 m .47091 .4398 L .47365 .43896 L F
.92077 .4354 m .92261 .4329 L .92374 .43456 L 0 .024 .122 r
F
.92077 .4354 m .91964 .43375 L .92261 .4329 L F
.35713 .43815 m .35815 .43571 L .3598 .43736 L 0 .03 .13 r
F
.35713 .43815 m .35548 .43647 L .35815 .43571 L F
.41479 .43971 m .4159 .43735 L .4175 .43894 L 0 .034 .135 r
F
.41479 .43971 m .41319 .43813 L .4159 .43735 L F
.86035 .43641 m .86208 .43371 L .86327 .43543 L 0 .026 .125 r
F
.86035 .43641 m .85915 .43469 L .86208 .43371 L F
.70715 .43778 m .70868 .43523 L .71 .43679 L 0 .029 .129 r
F
.70715 .43778 m .70583 .43623 L .70868 .43523 L F
.68609 .43896 m .68758 .43635 L .68893 .43809 L 0 .031 .132 r
F
.68609 .43896 m .68473 .43723 L .68758 .43635 L F
.29244 .43704 m .29337 .43458 L .29508 .43617 L 0 .028 .127 r
F
.29244 .43704 m .29072 .43545 L .29337 .43458 L F
.47948 .44094 m .48068 .43854 L .48222 .43997 L 0 .036 .138 r
F
.47948 .44094 m .47794 .4395 L .48068 .43854 L F
.3318 .43724 m .33279 .43473 L .33447 .43629 L 0 .028 .127 r
F
.3318 .43724 m .33012 .43568 L .33279 .43473 L F
.82099 .43629 m .82268 .43373 L .8239 .4354 L 0 .026 .125 r
F
.82099 .43629 m .81977 .43463 L .82268 .43373 L F
.55821 .44136 m .55953 .4389 L .56099 .44039 L 0 .037 .139 r
F
.55821 .44136 m .55674 .43985 L .55953 .4389 L F
.86738 .4361 m .86913 .43349 L .87031 .43515 L 0 .025 .124 r
F
.86738 .4361 m .8662 .43446 L .86913 .43349 L F
.70013 .43827 m .70165 .43572 L .70298 .43725 L 0 .03 .13 r
F
.70013 .43827 m .6988 .43675 L .70165 .43572 L F
.55119 .44179 m .55249 .43935 L .55396 .44081 L 0 .039 .14 r
F
.55119 .44179 m .54972 .4403 L .55249 .43935 L F
.62566 .44005 m .62707 .43753 L .62847 .43911 L 0 .034 .135 r
F
.62566 .44005 m .62426 .4385 L .62707 .43753 L F
.61864 .44047 m .62004 .43796 L .62145 .43948 L 0 .035 .137 r
F
.61864 .44047 m .61723 .43896 L .62004 .43796 L F
.87441 .43582 m .87618 .43327 L .87735 .4349 L 0 .025 .124 r
F
.87441 .43582 m .87324 .43421 L .87618 .43327 L F
.76057 .43739 m .76217 .43483 L .76345 .43653 L 0 .028 .128 r
F
.76057 .43739 m .75929 .4357 L .76217 .43483 L F
.4865 .44071 m .48771 .43834 L .48924 .44004 L 0 .036 .138 r
F
.4865 .44071 m .48497 .439 L .48771 .43834 L F
.69312 .43878 m .69462 .43617 L .69596 .43776 L 0 .031 .132 r
F
.69312 .43878 m .69178 .43718 L .69462 .43617 L F
.54417 .4423 m .54546 .43982 L .54694 .4413 L 0 .04 .142 r
F
.54417 .4423 m .54269 .44078 L .54546 .43982 L F
.56523 .44114 m .56656 .43886 L .56802 .4404 L 0 .037 .139 r
F
.56523 .44114 m .56377 .43962 L .56656 .43886 L F
.38946 .43901 m .39053 .43651 L .39215 .43825 L 0 .032 .133 r
F
.38946 .43901 m .38784 .43727 L .39053 .43651 L F
.63269 .4398 m .63411 .43725 L .63551 .4389 L 0 .034 .135 r
F
.63269 .4398 m .63129 .43818 L .63411 .43725 L F
.33881 .43708 m .3398 .43477 L .34147 .43634 L 0 .028 .128 r
F
.33881 .43708 m .33714 .43551 L .3398 .43477 L F
.71419 .43768 m .71572 .4351 L .71705 .43682 L 0 .029 .129 r
F
.71419 .43768 m .71286 .43594 L .71572 .4351 L F
.29944 .43691 m .30038 .43442 L .30209 .43605 L 0 .028 .127 r
F
.29944 .43691 m .29773 .4353 L .30038 .43442 L F
.92783 .43536 m .92967 .43277 L .9308 .43445 L 0 .024 .123 r
F
.92783 .43536 m .92671 .43367 L .92967 .43277 L F
.77462 .43675 m .77625 .4342 L .77751 .43577 L 0 .027 .126 r
F
.77462 .43675 m .77336 .43519 L .77625 .4342 L F
.88145 .43559 m .88323 .43305 L .88439 .43466 L 0 .025 .123 r
F
.88145 .43559 m .88028 .43397 L .88323 .43305 L F
.4218 .43968 m .42292 .43715 L .42452 .43875 L 0 .034 .135 r
F
.4218 .43968 m .42021 .43812 L .42292 .43715 L F
.26007 .43679 m .26096 .4342 L .2627 .43588 L 0 .027 .127 r
F
.26007 .43679 m .25833 .43513 L .26096 .4342 L F
.7676 .43718 m .76922 .43463 L .77048 .43619 L 0 .028 .128 r
F
.7676 .43718 m .76634 .43563 L .76922 .43463 L F
.82804 .43621 m .82974 .43365 L .83096 .43536 L 0 .026 .125 r
F
.82804 .43621 m .82682 .43452 L .82974 .43365 L F
.36413 .43819 m .36516 .43585 L .3668 .43746 L 0 .031 .131 r
F
.36413 .43819 m .36248 .43656 L .36516 .43585 L F
.78165 .43646 m .78328 .43383 L .78454 .43552 L 0 .027 .126 r
F
.78165 .43646 m .78039 .4348 L .78328 .43383 L F
.63972 .43962 m .64115 .43699 L .64254 .43864 L 0 .033 .134 r
F
.63972 .43962 m .63832 .43794 L .64115 .43699 L F
.42882 .43945 m .42995 .43703 L .43153 .43868 L 0 .034 .134 r
F
.42882 .43945 m .42723 .43781 L .42995 .43703 L F
.57226 .44104 m .5736 .43888 L .57505 .44028 L 0 .038 .139 r
F
.57226 .44104 m .57081 .43965 L .5736 .43888 L F
.65376 .4389 m .65522 .4364 L .65659 .43803 L 0 .032 .133 r
F
.65376 .4389 m .65239 .43726 L .65522 .4364 L F
.88849 .43541 m .89027 .43274 L .89143 .43445 L 0 .024 .123 r
F
.88849 .43541 m .88733 .43372 L .89027 .43274 L F
.93489 .43522 m .93674 .43266 L .93786 .43435 L F
.93489 .43522 m .93377 .43355 L .93674 .43266 L F
.5048 .44243 m .50604 .44 L .50755 .44161 L 0 .041 .143 r
F
.5048 .44243 m .50328 .44082 L .50604 .44 L F
.64674 .43932 m .64818 .43664 L .64956 .43829 L 0 .033 .134 r
F
.64674 .43932 m .64536 .43765 L .64818 .43664 L F
.26707 .43662 m .26798 .43399 L .26971 .43571 L 0 .027 .126 r
F
.26707 .43662 m .26534 .43492 L .26798 .43399 L F
.72123 .43762 m .72277 .43498 L .72409 .43666 L 0 .029 .129 r
F
.72123 .43762 m .71991 .43592 L .72277 .43498 L F
.44712 .44093 m .44827 .4386 L .44984 .44024 L 0 .037 .139 r
F
.44712 .44093 m .44555 .43929 L .44827 .4386 L F
.30644 .43685 m .3074 .4343 L .3091 .43597 L 0 .028 .127 r
F
.30644 .43685 m .30474 .4352 L .3074 .4343 L F
.83509 .43611 m .83681 .43369 L .83801 .43528 L 0 .026 .125 r
F
.83509 .43611 m .83388 .43452 L .83681 .43369 L F
.72825 .43728 m .72982 .43481 L .73112 .43641 L 0 .029 .129 r
F
.72825 .43728 m .72695 .4357 L .72982 .43481 L F
.39646 .43908 m .39755 .43646 L .39916 .43818 L 0 .033 .133 r
F
.39646 .43908 m .39485 .43736 L .39755 .43646 L F
.7887 .43637 m .79034 .43374 L .79159 .43546 L 0 .027 .126 r
F
.7887 .43637 m .78744 .43463 L .79034 .43374 L F
.89554 .43521 m .89733 .43259 L .89849 .43432 L 0 .024 .123 r
F
.89554 .43521 m .89437 .43348 L .89733 .43259 L F
.58631 .44047 m .58766 .43798 L .5891 .43946 L 0 .036 .137 r
F
.58631 .44047 m .58487 .43898 L .58766 .43798 L F
.34581 .43717 m .34681 .43476 L .34848 .43636 L 0 .029 .129 r
F
.34581 .43717 m .34414 .43559 L .34681 .43476 L F
.59333 .44009 m .59469 .43744 L .59613 .43908 L 0 .035 .136 r
F
.59333 .44009 m .5919 .43845 L .59469 .43744 L F
.66079 .43874 m .66227 .43641 L .66363 .43793 L 0 .032 .133 r
F
.66079 .43874 m .65943 .43722 L .66227 .43641 L F
.57929 .44092 m .58063 .43859 L .58208 .43999 L 0 .038 .139 r
F
.57929 .44092 m .57784 .43952 L .58063 .43859 L F
.52587 .44155 m .52714 .43955 L .52863 .44086 L 0 .04 .142 r
F
.52587 .44155 m .52437 .44025 L .52714 .43955 L F
.51182 .44233 m .51307 .4398 L .51458 .44143 L 0 .041 .143 r
F
.51182 .44233 m .51031 .4407 L .51307 .4398 L F
.73529 .43707 m .73687 .43471 L .73816 .43624 L 0 .029 .129 r
F
.73529 .43707 m .73399 .43556 L .73687 .43471 L F
.51884 .44195 m .5201 .4397 L .5216 .44106 L 0 .04 .142 r
F
.51884 .44195 m .51734 .44056 L .5201 .4397 L F
.84213 .43592 m .84385 .43339 L .84505 .43495 L 0 .026 .125 r
F
.84213 .43592 m .84094 .43438 L .84385 .43339 L F
.60036 .43982 m .60173 .43741 L .60316 .43905 L 0 .035 .136 r
F
.60036 .43982 m .59893 .43818 L .60173 .43741 L F
.31345 .43673 m .31441 .43416 L .31611 .43584 L 0 .028 .127 r
F
.31345 .43673 m .31175 .43506 L .31441 .43416 L F
.84916 .43558 m .8509 .4331 L .85209 .4347 L 0 .026 .124 r
F
.84916 .43558 m .84797 .43399 L .8509 .4331 L F
.37113 .43833 m .37217 .43593 L .37381 .43751 L 0 .032 .132 r
F
.37113 .43833 m .36948 .43673 L .37217 .43593 L F
.49351 .44108 m .49473 .43874 L .49626 .44042 L 0 .038 .14 r
F
.49351 .44108 m .49199 .43939 L .49473 .43874 L F
.45414 .4409 m .4553 .43856 L .45687 .44002 L 0 .038 .139 r
F
.45414 .4409 m .45257 .4394 L .4553 .43856 L F
.80276 .43584 m .80444 .43342 L .80567 .43498 L 0 .026 .125 r
F
.80276 .43584 m .80153 .43428 L .80444 .43342 L F
.79574 .43624 m .79739 .43355 L .79864 .43526 L 0 .027 .126 r
F
.79574 .43624 m .79449 .43453 L .79739 .43355 L F
.66783 .43859 m .66931 .43627 L .67067 .43775 L 0 .032 .133 r
F
.66783 .43859 m .66647 .4371 L .66931 .43627 L F
.27406 .43666 m .27497 .43415 L .27669 .43589 L 0 .028 .127 r
F
.27406 .43666 m .27234 .43493 L .27497 .43415 L F
.43583 .43959 m .43696 .43731 L .43854 .43892 L 0 .035 .136 r
F
.43583 .43959 m .43425 .438 L .43696 .43731 L F
.40347 .43902 m .40457 .43642 L .40618 .43813 L 0 .033 .134 r
F
.40347 .43902 m .40187 .43729 L .40457 .43642 L F
.9026 .43513 m .9044 .43257 L .90555 .43425 L 0 .025 .123 r
F
.9026 .43513 m .90144 .43345 L .9044 .43257 L F
.74233 .43692 m .74392 .43457 L .7452 .43609 L 0 .029 .129 r
F
.74233 .43692 m .74104 .4354 L .74392 .43457 L F
.37814 .43812 m .3792 .4356 L .38084 .43714 L 0 .031 .131 r
F
.37814 .43812 m .3765 .43656 L .3792 .4356 L F
.67486 .43836 m .67634 .43582 L .6777 .43739 L 0 .032 .132 r
F
.67486 .43836 m .6735 .43682 L .67634 .43582 L F
.46116 .4407 m .46233 .43858 L .46389 .43997 L 0 .038 .14 r
F
.46116 .4407 m .45959 .43928 L .46233 .43858 L F
.90963 .43488 m .91146 .43234 L .91259 .43393 L 0 .024 .123 r
F
.90963 .43488 m .9085 .43329 L .91146 .43234 L F
.24169 .43627 m .24257 .43359 L .24432 .4353 L 0 .027 .126 r
F
.24169 .43627 m .23994 .43454 L .24257 .43359 L F
.53289 .44153 m .53417 .43941 L .53566 .44079 L 0 .04 .142 r
F
.53289 .44153 m .5314 .44017 L .53417 .43941 L F
.80981 .43569 m .8115 .43327 L .81272 .43484 L 0 .026 .125 r
F
.80981 .43569 m .80858 .43413 L .8115 .43327 L F
.3528 .43726 m .35382 .43478 L .35548 .43647 L 0 .029 .129 r
F
.3528 .43726 m .35115 .43555 L .35382 .43478 L F
.32045 .43668 m .32141 .43435 L .3231 .43592 L 0 .028 .128 r
F
.32045 .43668 m .31876 .4351 L .32141 .43435 L F
.85622 .43556 m .85796 .43296 L .85915 .43469 L 0 .026 .125 r
F
.85622 .43556 m .85502 .43384 L .85796 .43296 L F
.91667 .4346 m .91851 .43215 L .91964 .43375 L 0 .024 .122 r
F
.91667 .4346 m .91555 .43302 L .91851 .43215 L F
.24871 .43597 m .24958 .43343 L .25133 .43507 L 0 .027 .126 r
F
.24871 .43597 m .24695 .43434 L .24958 .43343 L F
.68189 .43812 m .68338 .43551 L .68473 .43723 L 0 .031 .132 r
F
.68189 .43812 m .68053 .43642 L .68338 .43551 L F
.60739 .43988 m .60878 .43752 L .6102 .43909 L 0 .036 .137 r
F
.60739 .43988 m .60597 .43829 L .60878 .43752 L F
.41049 .43892 m .41159 .43645 L .41319 .43813 L 0 .033 .134 r
F
.41049 .43892 m .40888 .43723 L .41159 .43645 L F
.74937 .43681 m .75095 .43417 L .75224 .43584 L 0 .028 .128 r
F
.74937 .43681 m .74808 .43516 L .75095 .43417 L F
.38515 .43801 m .38622 .43558 L .38784 .43727 L 0 .031 .132 r
F
.38515 .43801 m .38353 .43633 L .38622 .43558 L F
.28106 .43668 m .28198 .43407 L .2837 .43572 L 0 .028 .128 r
F
.28106 .43668 m .27933 .43502 L .28198 .43407 L F
.81685 .43553 m .81855 .43304 L .81977 .43463 L 0 .026 .125 r
F
.81685 .43553 m .81563 .43394 L .81855 .43304 L F
.28808 .43634 m .289 .43387 L .29072 .43545 L 0 .028 .127 r
F
.28808 .43634 m .28635 .43476 L .289 .43387 L F
.46817 .44063 m .46936 .43838 L .47091 .4398 L 0 .038 .14 r
F
.46817 .44063 m .46662 .43921 L .46936 .43838 L F
.7564 .43657 m .758 .43397 L .75929 .4357 L 0 .028 .128 r
F
.7564 .43657 m .75512 .43486 L .758 .43397 L F
.71 .43679 m .71154 .43438 L .71286 .43594 L 0 .029 .129 r
F
.71 .43679 m .70868 .43523 L .71154 .43438 L F
.86327 .43543 m .86501 .43273 L .8662 .43446 L 0 .026 .124 r
F
.86327 .43543 m .86208 .43371 L .86501 .43273 L F
.32745 .43663 m .32843 .43412 L .33012 .43568 L 0 .028 .128 r
F
.32745 .43663 m .32576 .43508 L .32843 .43412 L F
.48222 .43997 m .48343 .43758 L .48497 .439 L 0 .036 .138 r
F
.48222 .43997 m .48068 .43854 L .48343 .43758 L F
.70298 .43725 m .7045 .43469 L .70583 .43623 L 0 .03 .13 r
F
.70298 .43725 m .70165 .43572 L .7045 .43469 L F
.33447 .43629 m .33546 .43395 L .33714 .43551 L 0 .028 .128 r
F
.33447 .43629 m .33279 .43473 L .33546 .43395 L F
.56099 .44039 m .56231 .43811 L .56377 .43962 L 0 .037 .139 r
F
.56099 .44039 m .55953 .4389 L .56231 .43811 L F
.53992 .44156 m .54121 .43925 L .54269 .44078 L 0 .04 .142 r
F
.53992 .44156 m .53843 .44003 L .54121 .43925 L F
.2557 .43591 m .25658 .43347 L .25833 .43513 L 0 .027 .126 r
F
.2557 .43591 m .25395 .43427 L .25658 .43347 L F
.4752 .4404 m .47639 .43807 L .47794 .4395 L 0 .037 .139 r
F
.4752 .4404 m .47365 .43896 L .47639 .43807 L F
.92374 .43456 m .92558 .43201 L .92671 .43367 L 0 .024 .122 r
F
.92374 .43456 m .92261 .4329 L .92558 .43201 L F
.61442 .43983 m .61582 .43745 L .61723 .43896 L 0 .036 .137 r
F
.61442 .43983 m .61301 .4383 L .61582 .43745 L F
.87031 .43515 m .87206 .43254 L .87324 .43421 L 0 .025 .124 r
F
.87031 .43515 m .86913 .43349 L .87206 .43254 L F
.55396 .44081 m .55528 .43842 L .55674 .43985 L 0 .038 .14 r
F
.55396 .44081 m .55249 .43935 L .55528 .43842 L F
.68893 .43809 m .69043 .43543 L .69178 .43718 L 0 .031 .132 r
F
.68893 .43809 m .68758 .43635 L .69043 .43543 L F
.29508 .43617 m .29602 .43369 L .29773 .4353 L 0 .028 .127 r
F
.29508 .43617 m .29337 .43458 L .29602 .43369 L F
.62145 .43948 m .62286 .43695 L .62426 .4385 L 0 .035 .136 r
F
.62145 .43948 m .62004 .43796 L .62286 .43695 L F
.50053 .44144 m .50176 .43916 L .50328 .44082 L 0 .04 .142 r
F
.50053 .44144 m .49901 .43979 L .50176 .43916 L F
.8239 .4354 m .8256 .43283 L .82682 .43452 L 0 .026 .125 r
F
.8239 .4354 m .82268 .43373 L .8256 .43283 L F
.3598 .43736 m .36083 .43494 L .36248 .43656 L 0 .03 .131 r
F
.3598 .43736 m .35815 .43571 L .36083 .43494 L F
.62847 .43911 m .62989 .43657 L .63129 .43818 L 0 .034 .135 r
F
.62847 .43911 m .62707 .43753 L .62989 .43657 L F
.44283 .4399 m .44398 .43763 L .44555 .43929 L 0 .036 .138 r
F
.44283 .4399 m .44126 .43827 L .44398 .43763 L F
.69596 .43776 m .69747 .43516 L .6988 .43675 L 0 .031 .131 r
F
.69596 .43776 m .69462 .43617 L .69747 .43516 L F
.4175 .43894 m .41861 .43652 L .42021 .43812 L 0 .034 .135 r
F
.4175 .43894 m .4159 .43735 L .41861 .43652 L F
.54694 .4413 m .54824 .43887 L .54972 .4403 L 0 .04 .141 r
F
.54694 .4413 m .54546 .43982 L .54824 .43887 L F
.87735 .4349 m .87912 .43236 L .88028 .43397 L 0 .025 .124 r
F
.87735 .4349 m .87618 .43327 L .87912 .43236 L F
.76345 .43653 m .76506 .43391 L .76634 .43563 L 0 .028 .128 r
F
.76345 .43653 m .76217 .43483 L .76506 .43391 L F
.77751 .43577 m .77913 .4332 L .78039 .4348 L 0 .027 .126 r
F
.77751 .43577 m .77625 .4342 L .77913 .4332 L F
.63551 .4389 m .63693 .43631 L .63832 .43794 L 0 .034 .135 r
F
.63551 .4389 m .63411 .43725 L .63693 .43631 L F
.77048 .43619 m .7721 .43364 L .77336 .43519 L 0 .028 .127 r
F
.77048 .43619 m .76922 .43463 L .7721 .43364 L F
.9308 .43445 m .93265 .43187 L .93377 .43355 L 0 .024 .122 r
F
.9308 .43445 m .92967 .43277 L .93265 .43187 L F
.42452 .43875 m .42564 .43618 L .42723 .43781 L 0 .033 .134 r
F
.42452 .43875 m .42292 .43715 L .42564 .43618 L F
.88439 .43466 m .88617 .43211 L .88733 .43372 L 0 .025 .123 r
F
.88439 .43466 m .88323 .43305 L .88617 .43211 L F
.71705 .43682 m .71859 .43422 L .71991 .43592 L 0 .029 .129 r
F
.71705 .43682 m .71572 .4351 L .71859 .43422 L F
.30209 .43605 m .30304 .43354 L .30474 .4352 L 0 .028 .127 r
F
.30209 .43605 m .30038 .43442 L .30304 .43354 L F
.2627 .43588 m .2636 .43322 L .26534 .43492 L 0 .027 .126 r
F
.2627 .43588 m .26096 .4342 L .2636 .43322 L F
.78454 .43552 m .78618 .43295 L .78744 .43463 L 0 .026 .126 r
F
.78454 .43552 m .78328 .43383 L .78618 .43295 L F
.39215 .43825 m .39323 .43562 L .39485 .43736 L 0 .032 .133 r
F
.39215 .43825 m .39053 .43651 L .39323 .43562 L F
.64254 .43864 m .64397 .43601 L .64536 .43765 L 0 .033 .134 r
F
.64254 .43864 m .64115 .43699 L .64397 .43601 L F
.56802 .4404 m .56935 .43809 L .57081 .43965 L 0 .038 .14 r
F
.56802 .4404 m .56656 .43886 L .56935 .43809 L F
.83096 .43536 m .83267 .43281 L .83388 .43452 L 0 .026 .125 r
F
.83096 .43536 m .82974 .43365 L .83267 .43281 L F
.48924 .44004 m .49046 .4377 L .49199 .43939 L 0 .037 .139 r
F
.48924 .44004 m .48771 .43834 L .49046 .4377 L F
.64956 .43829 m .651 .43562 L .65239 .43726 L 0 .032 .133 r
F
.64956 .43829 m .64818 .43664 L .651 .43562 L F
.34147 .43634 m .34247 .43401 L .34414 .43559 L 0 .029 .128 r
F
.34147 .43634 m .3398 .43477 L .34247 .43401 L F
.89143 .43445 m .89321 .43177 L .89437 .43348 L 0 .024 .123 r
F
.89143 .43445 m .89027 .43274 L .89321 .43177 L F
.72409 .43666 m .72564 .43404 L .72695 .4357 L 0 .029 .129 r
F
.72409 .43666 m .72277 .43498 L .72564 .43404 L F
.65659 .43803 m .65805 .43557 L .65943 .43722 L 0 .032 .133 r
F
.65659 .43803 m .65522 .4364 L .65805 .43557 L F
.3668 .43746 m .36784 .43514 L .36948 .43673 L 0 .031 .132 r
F
.3668 .43746 m .36516 .43585 L .36784 .43514 L F
.26971 .43571 m .27061 .43319 L .27234 .43493 L 0 .027 .127 r
F
.26971 .43571 m .26798 .43399 L .27061 .43319 L F
.93786 .43435 m .93972 .43177 L .94084 .43347 L 0 .024 .123 r
F
.93786 .43435 m .93674 .43266 L .93972 .43177 L F
.5891 .43946 m .59046 .43698 L .5919 .43845 L 0 .036 .137 r
F
.5891 .43946 m .58766 .43798 L .59046 .43698 L F
.43153 .43868 m .43266 .43632 L .43425 .438 L 0 .034 .135 r
F
.43153 .43868 m .42995 .43703 L .43266 .43632 L F
.59613 .43908 m .5975 .43654 L .59893 .43818 L 0 .035 .136 r
F
.59613 .43908 m .59469 .43744 L .5975 .43654 L F
.50755 .44161 m .5088 .43908 L .51031 .4407 L 0 .041 .143 r
F
.50755 .44161 m .50604 .44 L .5088 .43908 L F
.3091 .43597 m .31006 .43337 L .31175 .43506 L 0 .028 .127 r
F
.3091 .43597 m .3074 .4343 L .31006 .43337 L F
.57505 .44028 m .5764 .43811 L .57784 .43952 L 0 .038 .14 r
F
.57505 .44028 m .5736 .43888 L .5764 .43811 L F
.73112 .43641 m .73269 .43394 L .73399 .43556 L 0 .029 .129 r
F
.73112 .43641 m .72982 .43481 L .73269 .43394 L F
.39916 .43818 m .40025 .43558 L .40187 .43729 L 0 .033 .133 r
F
.39916 .43818 m .39755 .43646 L .40025 .43558 L F
.79159 .43546 m .79324 .43281 L .79449 .43453 L 0 .027 .126 r
F
.79159 .43546 m .79034 .43374 L .79324 .43281 L F
.83801 .43528 m .83974 .43278 L .84094 .43438 L 0 .026 .126 r
F
.83801 .43528 m .83681 .43369 L .83974 .43278 L F
.89849 .43432 m .90029 .43173 L .90144 .43345 L 0 .024 .123 r
F
.89849 .43432 m .89733 .43259 L .90029 .43173 L F
.58208 .43999 m .58343 .43759 L .58487 .43898 L 0 .037 .139 r
F
.58208 .43999 m .58063 .43859 L .58343 .43759 L F
.84505 .43495 m .84678 .43241 L .84797 .43399 L 0 .026 .125 r
F
.84505 .43495 m .84385 .43339 L .84678 .43241 L F
.44984 .44024 m .451 .43776 L .45257 .4394 L 0 .038 .139 r
F
.44984 .44024 m .44827 .4386 L .451 .43776 L F
.51458 .44143 m .51583 .43896 L .51734 .44056 L 0 .041 .143 r
F
.51458 .44143 m .51307 .4398 L .51583 .43896 L F
.34848 .43636 m .34949 .43393 L .35115 .43555 L 0 .029 .129 r
F
.34848 .43636 m .34681 .43476 L .34949 .43393 L F
.66363 .43793 m .66511 .43559 L .66647 .4371 L 0 .033 .133 r
F
.66363 .43793 m .66227 .43641 L .66511 .43559 L F
.5216 .44106 m .52287 .43891 L .52437 .44025 L 0 .04 .142 r
F
.5216 .44106 m .5201 .4397 L .52287 .43891 L F
.31611 .43584 m .31707 .43341 L .31876 .4351 L 0 .028 .128 r
F
.31611 .43584 m .31441 .43416 L .31707 .43341 L F
.79864 .43526 m .80029 .43258 L .80153 .43428 L 0 .026 .125 r
F
.79864 .43526 m .79739 .43355 L .80029 .43258 L F
.73816 .43624 m .73975 .43388 L .74104 .4354 L 0 .029 .129 r
F
.73816 .43624 m .73687 .43471 L .73975 .43388 L F
.85209 .4347 m .85383 .43222 L .85502 .43384 L 0 .026 .124 r
F
.85209 .4347 m .8509 .4331 L .85383 .43222 L F
.45687 .44002 m .45803 .43785 L .45959 .43928 L 0 .038 .14 r
F
.45687 .44002 m .4553 .43856 L .45803 .43785 L F
.60316 .43905 m .60455 .43664 L .60597 .43829 L 0 .035 .137 r
F
.60316 .43905 m .60173 .43741 L .60455 .43664 L F
.80567 .43498 m .80736 .43257 L .80858 .43413 L 0 .026 .125 r
F
.80567 .43498 m .80444 .43342 L .80736 .43257 L F
.37381 .43751 m .37486 .43499 L .3765 .43656 L 0 .032 .132 r
F
.37381 .43751 m .37217 .43593 L .37486 .43499 L F
.38084 .43714 m .38189 .4348 L .38353 .43633 L 0 .031 .132 r
F
.38084 .43714 m .3792 .4356 L .38189 .4348 L F
.40618 .43813 m .40728 .43554 L .40888 .43723 L 0 .033 .134 r
F
.40618 .43813 m .40457 .43642 L .40728 .43554 L F
.52863 .44086 m .52991 .43886 L .5314 .44017 L 0 .041 .143 r
F
.52863 .44086 m .52714 .43955 L .52991 .43886 L F
.67067 .43775 m .67215 .43533 L .6735 .43682 L 0 .032 .133 r
F
.67067 .43775 m .66931 .43627 L .67215 .43533 L F
.90555 .43425 m .90736 .43162 L .9085 .43329 L 0 .025 .123 r
F
.90555 .43425 m .9044 .43257 L .90736 .43162 L F
.6777 .43739 m .67918 .43481 L .68053 .43642 L 0 .031 .132 r
F
.6777 .43739 m .67634 .43582 L .67918 .43481 L F
.91259 .43393 m .91442 .43143 L .91555 .43302 L 0 .024 .122 r
F
.91259 .43393 m .91146 .43234 L .91442 .43143 L F
.24432 .4353 m .2452 .43264 L .24695 .43434 L 0 .027 .126 r
F
.24432 .4353 m .24257 .43359 L .2452 .43264 L F
.7452 .43609 m .7468 .43362 L .74808 .43516 L 0 .029 .129 r
F
.7452 .43609 m .74392 .43457 L .7468 .43362 L F
.27669 .43589 m .27761 .43328 L .27933 .43502 L 0 .028 .128 r
F
.27669 .43589 m .27497 .43415 L .27761 .43328 L F
.49626 .44042 m .49749 .4381 L .49901 .43979 L 0 .039 .141 r
F
.49626 .44042 m .49473 .43874 L .49749 .4381 L F
.43854 .43892 m .43968 .43663 L .44126 .43827 L 0 .036 .137 r
F
.43854 .43892 m .43696 .43731 L .43968 .43663 L F
.81272 .43484 m .81441 .43238 L .81563 .43394 L 0 .026 .125 r
F
.81272 .43484 m .8115 .43327 L .81441 .43238 L F
.75224 .43584 m .75383 .43317 L .75512 .43486 L 0 .028 .128 r
F
.75224 .43584 m .75095 .43417 L .75383 .43317 L F
.25133 .43507 m .2522 .43262 L .25395 .43427 L 0 .027 .126 r
F
.25133 .43507 m .24958 .43343 L .2522 .43262 L F
.85915 .43469 m .86089 .43198 L .86208 .43371 L 0 .026 .124 r
F
.85915 .43469 m .85796 .43296 L .86089 .43198 L F
.68473 .43723 m .68623 .4346 L .68758 .43635 L 0 .031 .132 r
F
.68473 .43723 m .68338 .43551 L .68623 .4346 L F
.46389 .43997 m .46506 .43785 L .46662 .43921 L 0 .038 .14 r
F
.46389 .43997 m .46233 .43858 L .46506 .43785 L F
.35548 .43647 m .3565 .43406 L .35815 .43571 L 0 .03 .13 r
F
.35548 .43647 m .35382 .43478 L .3565 .43406 L F
.91964 .43375 m .92149 .43129 L .92261 .4329 L 0 .024 .122 r
F
.91964 .43375 m .91851 .43215 L .92149 .43129 L F
.53566 .44079 m .53694 .43863 L .53843 .44003 L 0 .041 .143 r
F
.53566 .44079 m .53417 .43941 L .53694 .43863 L F
.2837 .43572 m .28463 .43311 L .28635 .43476 L 0 .028 .128 r
F
.2837 .43572 m .28198 .43407 L .28463 .43311 L F
.3231 .43592 m .32407 .43352 L .32576 .43508 L 0 .029 .129 r
F
.3231 .43592 m .32141 .43435 L .32407 .43352 L F
.6102 .43909 m .6116 .43675 L .61301 .4383 L 0 .036 .137 r
F
.6102 .43909 m .60878 .43752 L .6116 .43675 L F
.41319 .43813 m .4143 .43569 L .4159 .43735 L 0 .034 .135 r
F
.41319 .43813 m .41159 .43645 L .4143 .43569 L F
.81977 .43463 m .82146 .43213 L .82268 .43373 L 0 .026 .125 r
F
.81977 .43463 m .81855 .43304 L .82146 .43213 L F
.8662 .43446 m .86794 .43177 L .86913 .43349 L 0 .025 .124 r
F
.8662 .43446 m .86501 .43273 L .86794 .43177 L F
.70583 .43623 m .70735 .43367 L .70868 .43523 L 0 .029 .129 r
F
.70583 .43623 m .7045 .43469 L .70735 .43367 L F
.29072 .43545 m .29165 .43298 L .29337 .43458 L 0 .028 .127 r
F
.29072 .43545 m .289 .43387 L .29165 .43298 L F
.33012 .43568 m .33111 .43317 L .33279 .43473 L 0 .028 .128 r
F
.33012 .43568 m .32843 .43412 L .33111 .43317 L F
.48497 .439 m .48617 .43692 L .48771 .43834 L 0 .036 .138 r
F
.48497 .439 m .48343 .43758 L .48617 .43692 L F
.75929 .4357 m .76089 .43308 L .76217 .43483 L 0 .028 .128 r
F
.75929 .4357 m .758 .43397 L .76089 .43308 L F
.47091 .4398 m .4721 .43754 L .47365 .43896 L 0 .038 .14 r
F
.47091 .4398 m .46936 .43838 L .4721 .43754 L F
.38784 .43727 m .38891 .43482 L .39053 .43651 L 0 .032 .132 r
F
.38784 .43727 m .38622 .43558 L .38891 .43482 L F
.71286 .43594 m .71441 .43353 L .71572 .4351 L 0 .029 .129 r
F
.71286 .43594 m .71154 .43438 L .71441 .43353 L F
.55674 .43985 m .55806 .43749 L .55953 .4389 L 0 .038 .14 r
F
.55674 .43985 m .55528 .43842 L .55806 .43749 L F
.6988 .43675 m .70032 .43413 L .70165 .43572 L 0 .03 .131 r
F
.6988 .43675 m .69747 .43516 L .70032 .43413 L F
.87324 .43421 m .875 .43159 L .87618 .43327 L 0 .025 .124 r
F
.87324 .43421 m .87206 .43254 L .875 .43159 L F
.62426 .4385 m .62567 .43595 L .62707 .43753 L 0 .035 .136 r
F
.62426 .4385 m .62286 .43695 L .62567 .43595 L F
.47794 .4395 m .47914 .43712 L .48068 .43854 L 0 .037 .139 r
F
.47794 .4395 m .47639 .43807 L .47914 .43712 L F
.69178 .43718 m .69328 .43444 L .69462 .43617 L 0 .031 .132 r
F
.69178 .43718 m .69043 .43543 L .69328 .43444 L F
.92671 .43367 m .92855 .43112 L .92967 .43277 L 0 .024 .122 r
F
.92671 .43367 m .92558 .43201 L .92855 .43112 L F
.54972 .4403 m .55102 .43796 L .55249 .43935 L 0 .039 .141 r
F
.54972 .4403 m .54824 .43887 L .55102 .43796 L F
.63129 .43818 m .63271 .4356 L .63411 .43725 L 0 .034 .135 r
F
.63129 .43818 m .62989 .43657 L .63271 .4356 L F
.61723 .43896 m .61864 .43642 L .62004 .43796 L 0 .036 .137 r
F
.61723 .43896 m .61582 .43745 L .61864 .43642 L F
.29773 .4353 m .29867 .43279 L .30038 .43442 L 0 .028 .127 r
F
.29773 .4353 m .29602 .43369 L .29867 .43279 L F
.82682 .43452 m .82852 .43193 L .82974 .43365 L 0 .026 .125 r
F
.82682 .43452 m .8256 .43283 L .82852 .43193 L F
.54269 .44078 m .54398 .43834 L .54546 .43982 L 0 .04 .142 r
F
.54269 .44078 m .54121 .43925 L .54398 .43834 L F
.33714 .43551 m .33812 .4332 L .3398 .43477 L 0 .028 .128 r
F
.33714 .43551 m .33546 .43395 L .33812 .4332 L F
.25833 .43513 m .25922 .43252 L .26096 .4342 L 0 .027 .127 r
F
.25833 .43513 m .25658 .43347 L .25922 .43252 L F
.56377 .43962 m .5651 .43732 L .56656 .43886 L 0 .038 .14 r
F
.56377 .43962 m .56231 .43811 L .5651 .43732 L F
.88028 .43397 m .88207 .43144 L .88323 .43305 L 0 .025 .123 r
F
.88028 .43397 m .87912 .43236 L .88207 .43144 L F
.78039 .4348 m .78203 .43222 L .78328 .43383 L 0 .027 .126 r
F
.78039 .4348 m .77913 .4332 L .78203 .43222 L F
.77336 .43519 m .77499 .43262 L .77625 .4342 L 0 .027 .127 r
F
.77336 .43519 m .7721 .43364 L .77499 .43262 L F
.36248 .43656 m .36351 .43425 L .36516 .43585 L 0 .031 .131 r
F
.36248 .43656 m .36083 .43494 L .36351 .43425 L F
.42021 .43812 m .42133 .43554 L .42292 .43715 L 0 .034 .135 r
F
.42021 .43812 m .41861 .43652 L .42133 .43554 L F
.63832 .43794 m .63976 .43538 L .64115 .43699 L 0 .034 .134 r
F
.63832 .43794 m .63693 .43631 L .63976 .43538 L F
.76634 .43563 m .76794 .43293 L .76922 .43463 L 0 .028 .128 r
F
.76634 .43563 m .76506 .43391 L .76794 .43293 L F
.88733 .43372 m .88911 .43112 L .89027 .43274 L 0 .024 .123 r
F
.88733 .43372 m .88617 .43211 L .88911 .43112 L F
.42723 .43781 m .42836 .43536 L .42995 .43703 L 0 .034 .134 r
F
.42723 .43781 m .42564 .43618 L .42836 .43536 L F
.93377 .43355 m .93562 .43097 L .93674 .43266 L 0 .024 .122 r
F
.93377 .43355 m .93265 .43187 L .93562 .43097 L F
.64536 .43765 m .6468 .43502 L .64818 .43664 L 0 .033 .134 r
F
.64536 .43765 m .64397 .43601 L .6468 .43502 L F
.26534 .43492 m .26624 .43227 L .26798 .43399 L 0 .027 .126 r
F
.26534 .43492 m .2636 .43322 L .26624 .43227 L F
.65239 .43726 m .65384 .43475 L .65522 .4364 L 0 .032 .133 r
F
.65239 .43726 m .651 .43562 L .65384 .43475 L F
.71991 .43592 m .72145 .4333 L .72277 .43498 L 0 .029 .129 r
F
.71991 .43592 m .71859 .43422 L .72145 .4333 L F
.50328 .44082 m .50452 .43834 L .50604 .44 L 0 .041 .143 r
F
.50328 .44082 m .50176 .43916 L .50452 .43834 L F
.30474 .4352 m .3057 .43262 L .3074 .4343 L 0 .028 .127 r
F
.30474 .4352 m .30304 .43354 L .3057 .43262 L F
.44555 .43929 m .4467 .4369 L .44827 .4386 L 0 .037 .139 r
F
.44555 .43929 m .44398 .43763 L .4467 .4369 L F
.39485 .43736 m .39594 .43473 L .39755 .43646 L 0 .032 .133 r
F
.39485 .43736 m .39323 .43562 L .39594 .43473 L F
.78744 .43463 m .78908 .43207 L .79034 .43374 L 0 .027 .126 r
F
.78744 .43463 m .78618 .43295 L .78908 .43207 L F
.89437 .43348 m .89617 .43088 L .89733 .43259 L 0 .024 .122 r
F
.89437 .43348 m .89321 .43177 L .89617 .43088 L F
.83388 .43452 m .8356 .43197 L .83681 .43369 L 0 .026 .126 r
F
.83388 .43452 m .83267 .43281 L .8356 .43197 L F
.72695 .4357 m .72851 .43314 L .72982 .43481 L 0 .029 .129 r
F
.72695 .4357 m .72564 .43404 L .72851 .43314 L F
.5919 .43845 m .59326 .43598 L .59469 .43744 L 0 .035 .137 r
F
.5919 .43845 m .59046 .43698 L .59326 .43598 L F
.57081 .43965 m .57215 .43728 L .5736 .43888 L 0 .038 .14 r
F
.57081 .43965 m .56935 .43809 L .57215 .43728 L F
.34414 .43559 m .34514 .43316 L .34681 .43476 L 0 .029 .129 r
F
.34414 .43559 m .34247 .43401 L .34514 .43316 L F
.94084 .43347 m .9427 .4309 L .94382 .43261 L 0 .024 .123 r
F
.94084 .43347 m .93972 .43177 L .9427 .4309 L F
.51031 .4407 m .51156 .43816 L .51307 .4398 L 0 .041 .143 r
F
.51031 .4407 m .5088 .43908 L .51156 .43816 L F
.31175 .43506 m .31272 .43245 L .31441 .43416 L 0 .028 .127 r
F
.31175 .43506 m .31006 .43337 L .31272 .43245 L F
.59893 .43818 m .60031 .43576 L .60173 .43741 L 0 .035 .136 r
F
.59893 .43818 m .5975 .43654 L .60031 .43576 L F
.65943 .43722 m .66089 .43475 L .66227 .43641 L 0 .033 .133 r
F
.65943 .43722 m .65805 .43557 L .66089 .43475 L F
.58487 .43898 m .58623 .4366 L .58766 .43798 L 0 .037 .138 r
F
.58487 .43898 m .58343 .43759 L .58623 .4366 L F
.49199 .43939 m .49321 .43705 L .49473 .43874 L 0 .038 .14 r
F
.49199 .43939 m .49046 .4377 L .49321 .43705 L F
.79449 .43453 m .79614 .43184 L .79739 .43355 L 0 .026 .126 r
F
.79449 .43453 m .79324 .43281 L .79614 .43184 L F
.27234 .43493 m .27324 .4324 L .27497 .43415 L 0 .028 .127 r
F
.27234 .43493 m .27061 .43319 L .27324 .4324 L F
.40187 .43729 m .40296 .43473 L .40457 .43642 L 0 .033 .133 r
F
.40187 .43729 m .40025 .43558 L .40296 .43473 L F
.84094 .43438 m .84266 .43178 L .84385 .43339 L 0 .026 .125 r
F
.84094 .43438 m .83974 .43278 L .84266 .43178 L F
.84797 .43399 m .84971 .43149 L .8509 .4331 L F
.84797 .43399 m .84678 .43241 L .84971 .43149 L F
.36948 .43673 m .37052 .43436 L .37217 .43593 L 0 .032 .132 r
F
.36948 .43673 m .36784 .43514 L .37052 .43436 L F
.73399 .43556 m .73557 .43308 L .73687 .43471 L 0 .029 .129 r
F
.73399 .43556 m .73269 .43394 L .73557 .43308 L F
.90144 .43345 m .90325 .43086 L .9044 .43257 L 0 .024 .123 r
F
.90144 .43345 m .90029 .43173 L .90325 .43086 L F
.57784 .43952 m .57919 .43718 L .58063 .43859 L 0 .038 .14 r
F
.57784 .43952 m .5764 .43811 L .57919 .43718 L F
.80153 .43428 m .8032 .43171 L .80444 .43342 L 0 .026 .125 r
F
.80153 .43428 m .80029 .43258 L .8032 .43171 L F
.43425 .438 m .43538 .43562 L .43696 .43731 L 0 .035 .136 r
F
.43425 .438 m .43266 .43632 L .43538 .43562 L F
.51734 .44056 m .5186 .43812 L .5201 .4397 L 0 .041 .143 r
F
.51734 .44056 m .51583 .43896 L .5186 .43812 L F
.45257 .4394 m .45373 .43693 L .4553 .43856 L 0 .038 .14 r
F
.45257 .4394 m .451 .43776 L .45373 .43693 L F
.23994 .43454 m .24081 .43187 L .24257 .43359 L 0 .027 .126 r
F
.23994 .43454 m .23818 .4328 L .24081 .43187 L F
.66647 .4371 m .66795 .43477 L .66931 .43627 L 0 .033 .134 r
F
.66647 .4371 m .66511 .43559 L .66795 .43477 L F
.35115 .43555 m .35216 .43314 L .35382 .43478 L 0 .029 .129 r
F
.35115 .43555 m .34949 .43393 L .35216 .43314 L F
.52437 .44025 m .52564 .4382 L .52714 .43955 L 0 .041 .143 r
F
.52437 .44025 m .52287 .43891 L .52564 .4382 L F
.3765 .43656 m .37756 .43406 L .3792 .4356 L 0 .031 .132 r
F
.3765 .43656 m .37486 .43499 L .37756 .43406 L F
.74104 .4354 m .74263 .43304 L .74392 .43457 L 0 .029 .129 r
F
.74104 .4354 m .73975 .43388 L .74263 .43304 L F
.85502 .43384 m .85677 .43132 L .85796 .43296 L 0 .026 .124 r
F
.85502 .43384 m .85383 .43222 L .85677 .43132 L F
.9085 .43329 m .91031 .43067 L .91146 .43234 L 0 .024 .123 r
F
.9085 .43329 m .90736 .43162 L .91031 .43067 L F
.68053 .43642 m .68203 .43386 L .68338 .43551 L 0 .031 .132 r
F
.68053 .43642 m .67918 .43481 L .68203 .43386 L F
.6735 .43682 m .67499 .43428 L .67634 .43582 L 0 .032 .133 r
F
.6735 .43682 m .67215 .43533 L .67499 .43428 L F
.40888 .43723 m .40998 .43477 L .41159 .43645 L 0 .033 .134 r
F
.40888 .43723 m .40728 .43554 L .40998 .43477 L F
.31876 .4351 m .31972 .43266 L .32141 .43435 L 0 .028 .128 r
F
.31876 .4351 m .31707 .43341 L .31972 .43266 L F
.80858 .43413 m .81027 .4317 L .8115 .43327 L 0 .026 .126 r
F
.80858 .43413 m .80736 .43257 L .81027 .4317 L F
.24695 .43434 m .24783 .43174 L .24958 .43343 L 0 .027 .126 r
F
.24695 .43434 m .2452 .43264 L .24783 .43174 L F
.38353 .43633 m .38458 .43407 L .38622 .43558 L 0 .032 .132 r
F
.38353 .43633 m .38189 .4348 L .38458 .43407 L F
.74808 .43516 m .74967 .4326 L .75095 .43417 L 0 .029 .128 r
F
.74808 .43516 m .7468 .43362 L .74967 .4326 L F
.91555 .43302 m .91739 .43055 L .91851 .43215 L 0 .024 .123 r
F
.91555 .43302 m .91442 .43143 L .91739 .43055 L F
.60597 .43829 m .60736 .43586 L .60878 .43752 L 0 .036 .137 r
F
.60597 .43829 m .60455 .43664 L .60736 .43586 L F
.45959 .43928 m .46076 .43718 L .46233 .43858 L 0 .039 .141 r
F
.45959 .43928 m .45803 .43785 L .46076 .43718 L F
.27933 .43502 m .28026 .43232 L .28198 .43407 L 0 .028 .128 r
F
.27933 .43502 m .27761 .43328 L .28026 .43232 L F
.75512 .43486 m .75671 .43226 L .758 .43397 L 0 .028 .127 r
F
.75512 .43486 m .75383 .43317 L .75671 .43226 L F
.86208 .43371 m .86382 .43101 L .86501 .43273 L 0 .025 .124 r
F
.86208 .43371 m .86089 .43198 L .86382 .43101 L F
.5314 .44017 m .53268 .43807 L .53417 .43941 L 0 .041 .143 r
F
.5314 .44017 m .52991 .43886 L .53268 .43807 L F
.81563 .43394 m .81733 .43148 L .81855 .43304 L 0 .026 .125 r
F
.81563 .43394 m .81441 .43238 L .81733 .43148 L F
.28635 .43476 m .28728 .43221 L .289 .43387 L 0 .028 .127 r
F
.28635 .43476 m .28463 .43311 L .28728 .43221 L F
.68758 .43635 m .68908 .43368 L .69043 .43543 L 0 .031 .132 r
F
.68758 .43635 m .68623 .4346 L .68908 .43368 L F
.70868 .43523 m .71022 .43281 L .71154 .43438 L 0 .029 .129 r
F
.70868 .43523 m .70735 .43367 L .71022 .43281 L F
.92261 .4329 m .92446 .4304 L .92558 .43201 L 0 .024 .123 r
F
.92261 .4329 m .92149 .43129 L .92446 .4304 L F
.25395 .43427 m .25483 .43181 L .25658 .43347 L 0 .027 .126 r
F
.25395 .43427 m .2522 .43262 L .25483 .43181 L F
.86913 .43349 m .87088 .43081 L .87206 .43254 L 0 .025 .124 r
F
.86913 .43349 m .86794 .43177 L .87088 .43081 L F
.32576 .43508 m .32675 .43256 L .32843 .43412 L 0 .029 .129 r
F
.32576 .43508 m .32407 .43352 L .32675 .43256 L F
.82268 .43373 m .82438 .43121 L .8256 .43283 L 0 .026 .125 r
F
.82268 .43373 m .82146 .43213 L .82438 .43121 L F
.49901 .43979 m .50024 .43745 L .50176 .43916 L 0 .04 .142 r
F
.49901 .43979 m .49749 .4381 L .50024 .43745 L F
.46662 .43921 m .4678 .437 L .46936 .43838 L 0 .039 .141 r
F
.46662 .43921 m .46506 .43785 L .4678 .437 L F
.35815 .43571 m .35917 .43333 L .36083 .43494 L 0 .03 .131 r
F
.35815 .43571 m .3565 .43406 L .35917 .43333 L F
.33279 .43473 m .33378 .43238 L .33546 .43395 L 0 .028 .128 r
F
.33279 .43473 m .33111 .43317 L .33378 .43238 L F
.70165 .43572 m .70317 .43309 L .7045 .43469 L 0 .03 .13 r
F
.70165 .43572 m .70032 .43413 L .70317 .43309 L F
.44126 .43827 m .4424 .43595 L .44398 .43763 L 0 .036 .138 r
F
.44126 .43827 m .43968 .43663 L .4424 .43595 L F
.53843 .44003 m .53972 .43783 L .54121 .43925 L 0 .041 .143 r
F
.53843 .44003 m .53694 .43863 L .53972 .43783 L F
.29337 .43458 m .2943 .43208 L .29602 .43369 L 0 .028 .127 r
F
.29337 .43458 m .29165 .43298 L .2943 .43208 L F
.61301 .4383 m .61441 .4359 L .61582 .43745 L 0 .036 .138 r
F
.61301 .4383 m .6116 .43675 L .61441 .4359 L F
.62707 .43753 m .62849 .43496 L .62989 .43657 L 0 .034 .135 r
F
.62707 .43753 m .62567 .43595 L .62849 .43496 L F
.55953 .4389 m .56085 .43667 L .56231 .43811 L 0 .038 .14 r
F
.55953 .4389 m .55806 .43749 L .56085 .43667 L F
.69462 .43617 m .69613 .43345 L .69747 .43516 L 0 .031 .131 r
F
.69462 .43617 m .69328 .43444 L .69613 .43345 L F
.4159 .43735 m .41701 .43488 L .41861 .43652 L 0 .034 .135 r
F
.4159 .43735 m .4143 .43569 L .41701 .43488 L F
.76217 .43483 m .76377 .43216 L .76506 .43391 L 0 .028 .128 r
F
.76217 .43483 m .76089 .43308 L .76377 .43216 L F
.48068 .43854 m .48188 .43618 L .48343 .43758 L 0 .037 .139 r
F
.48068 .43854 m .47914 .43712 L .48188 .43618 L F
.87618 .43327 m .87795 .43068 L .87912 .43236 L 0 .025 .124 r
F
.87618 .43327 m .875 .43159 L .87795 .43068 L F
.62004 .43796 m .62145 .43539 L .62286 .43695 L 0 .035 .137 r
F
.62004 .43796 m .61864 .43642 L .62145 .43539 L F
.55249 .43935 m .55381 .43708 L .55528 .43842 L 0 .039 .141 r
F
.55249 .43935 m .55102 .43796 L .55381 .43708 L F
.47365 .43896 m .47484 .43665 L .47639 .43807 L 0 .038 .14 r
F
.47365 .43896 m .4721 .43754 L .47484 .43665 L F
.71572 .4351 m .71727 .43265 L .71859 .43422 L 0 .029 .129 r
F
.71572 .4351 m .71441 .43353 L .71727 .43265 L F
.63411 .43725 m .63554 .43468 L .63693 .43631 L 0 .034 .135 r
F
.63411 .43725 m .63271 .4356 L .63554 .43468 L F
.92967 .43277 m .93152 .43022 L .93265 .43187 L 0 .024 .122 r
F
.92967 .43277 m .92855 .43112 L .93152 .43022 L F
.54546 .43982 m .54676 .43743 L .54824 .43887 L 0 .04 .142 r
F
.54546 .43982 m .54398 .43834 L .54676 .43743 L F
.39053 .43651 m .39161 .43393 L .39323 .43562 L 0 .032 .133 r
F
.39053 .43651 m .38891 .43482 L .39161 .43393 L F
.77625 .4342 m .77788 .4316 L .77913 .4332 L 0 .027 .126 r
F
.77625 .4342 m .77499 .43262 L .77788 .4316 L F
.26096 .4342 m .26186 .43153 L .2636 .43322 L F
.26096 .4342 m .25922 .43252 L .26186 .43153 L F
.88323 .43305 m .88501 .4305 L .88617 .43211 L 0 .025 .123 r
F
.88323 .43305 m .88207 .43144 L .88501 .4305 L F
.42292 .43715 m .42405 .43456 L .42564 .43618 L 0 .034 .135 r
F
.42292 .43715 m .42133 .43554 L .42405 .43456 L F
.78328 .43383 m .78493 .43134 L .78618 .43295 L 0 .027 .126 r
F
.78328 .43383 m .78203 .43222 L .78493 .43134 L F
.30038 .43442 m .30133 .43188 L .30304 .43354 L 0 .028 .127 r
F
.30038 .43442 m .29867 .43279 L .30133 .43188 L F
.82974 .43365 m .83145 .43109 L .83267 .43281 L 0 .026 .125 r
F
.82974 .43365 m .82852 .43193 L .83145 .43109 L F
.48771 .43834 m .48892 .4363 L .49046 .4377 L 0 .037 .139 r
F
.48771 .43834 m .48617 .43692 L .48892 .4363 L F
.76922 .43463 m .77083 .43194 L .7721 .43364 L 0 .028 .127 r
F
.76922 .43463 m .76794 .43293 L .77083 .43194 L F
.64115 .43699 m .64258 .43442 L .64397 .43601 L 0 .033 .134 r
F
.64115 .43699 m .63976 .43538 L .64258 .43442 L F
.64818 .43664 m .64962 .43402 L .651 .43562 L 0 .032 .133 r
F
.64818 .43664 m .6468 .43502 L .64962 .43402 L F
.89027 .43274 m .89206 .43014 L .89321 .43177 L 0 .024 .123 r
F
.89027 .43274 m .88911 .43112 L .89206 .43014 L F
.26798 .43399 m .26888 .43146 L .27061 .43319 L 0 .027 .126 r
F
.26798 .43399 m .26624 .43227 L .26888 .43146 L F
.56656 .43886 m .56789 .43652 L .56935 .43809 L 0 .038 .14 r
F
.56656 .43886 m .5651 .43732 L .56789 .43652 L F
.3398 .43477 m .34079 .43243 L .34247 .43401 L 0 .029 .129 r
F
.3398 .43477 m .33812 .4332 L .34079 .43243 L F
.72277 .43498 m .72432 .43238 L .72564 .43404 L F
.72277 .43498 m .72145 .4333 L .72432 .43238 L F
.93674 .43266 m .9386 .43007 L .93972 .43177 L 0 .024 .123 r
F
.93674 .43266 m .93562 .43097 L .9386 .43007 L F
.65522 .4364 m .65668 .43392 L .65805 .43557 L 0 .032 .133 r
F
.65522 .4364 m .65384 .43475 L .65668 .43392 L F
.36516 .43585 m .36619 .43355 L .36784 .43514 L 0 .031 .132 r
F
.36516 .43585 m .36351 .43425 L .36619 .43355 L F
.42995 .43703 m .43108 .43465 L .43266 .43632 L 0 .034 .135 r
F
.42995 .43703 m .42836 .43536 L .43108 .43465 L F
.3074 .4343 m .30836 .43168 L .31006 .43337 L 0 .028 .127 r
F
.3074 .4343 m .3057 .43262 L .30836 .43168 L F
.39755 .43646 m .39864 .43388 L .40025 .43558 L 0 .032 .133 r
F
.39755 .43646 m .39594 .43473 L .39864 .43388 L F
.59469 .43744 m .59607 .43508 L .5975 .43654 L 0 .035 .136 r
F
.59469 .43744 m .59326 .43598 L .59607 .43508 L F
.79034 .43374 m .79199 .43115 L .79324 .43281 L 0 .027 .126 r
F
.79034 .43374 m .78908 .43207 L .79199 .43115 L F
.50604 .44 m .50728 .43744 L .5088 .43908 L 0 .041 .143 r
F
.50604 .44 m .50452 .43834 L .50728 .43744 L F
.89733 .43259 m .89913 .43002 L .90029 .43173 L 0 .024 .123 r
F
.89733 .43259 m .89617 .43088 L .89913 .43002 L F
.72982 .43481 m .73138 .43225 L .73269 .43394 L 0 .029 .129 r
F
.72982 .43481 m .72851 .43314 L .73138 .43225 L F
.83681 .43369 m .83852 .43106 L .83974 .43278 L 0 .027 .126 r
F
.83681 .43369 m .8356 .43197 L .83852 .43106 L F
.58766 .43798 m .58903 .43561 L .59046 .43698 L 0 .037 .138 r
F
.58766 .43798 m .58623 .4366 L .58903 .43561 L F
.44827 .4386 m .44943 .43606 L .451 .43776 L 0 .038 .139 r
F
.44827 .4386 m .4467 .4369 L .44943 .43606 L F
.79739 .43355 m .79904 .43087 L .80029 .43258 L 0 .026 .125 r
F
.79739 .43355 m .79614 .43184 L .79904 .43087 L F
.51307 .4398 m .51432 .43735 L .51583 .43896 L 0 .041 .143 r
F
.51307 .4398 m .51156 .43816 L .51432 .43735 L F
.31441 .43416 m .31538 .43168 L .31707 .43341 L 0 .028 .127 r
F
.31441 .43416 m .31272 .43245 L .31538 .43168 L F
.94382 .43261 m .94569 .43004 L .9468 .43174 L 0 .024 .123 r
F
.94382 .43261 m .9427 .4309 L .94569 .43004 L F
.84385 .43339 m .84558 .43078 L .84678 .43241 L 0 .026 .125 r
F
.84385 .43339 m .84266 .43178 L .84558 .43078 L F
.34681 .43476 m .34782 .43231 L .34949 .43393 L 0 .029 .129 r
F
.34681 .43476 m .34514 .43316 L .34782 .43231 L F
.5736 .43888 m .57494 .43648 L .5764 .43811 L 0 .039 .141 r
F
.5736 .43888 m .57215 .43728 L .57494 .43648 L F
.66227 .43641 m .66374 .43393 L .66511 .43559 L 0 .033 .134 r
F
.66227 .43641 m .66089 .43475 L .66374 .43393 L F
.8509 .4331 m .85264 .4306 L .85383 .43222 L 0 .026 .125 r
F
.8509 .4331 m .84971 .43149 L .85264 .4306 L F
.40457 .43642 m .40567 .43388 L .40728 .43554 L 0 .033 .134 r
F
.40457 .43642 m .40296 .43473 L .40567 .43388 L F
.60173 .43741 m .60312 .43499 L .60455 .43664 L 0 .035 .137 r
F
.60173 .43741 m .60031 .43576 L .60312 .43499 L F
.58063 .43859 m .58199 .43619 L .58343 .43759 L 0 .038 .14 r
F
.58063 .43859 m .57919 .43718 L .58199 .43619 L F
.73687 .43471 m .73845 .43224 L .73975 .43388 L 0 .029 .129 r
F
.73687 .43471 m .73557 .43308 L .73845 .43224 L F
.9044 .43257 m .90621 .42992 L .90736 .43162 L 0 .024 .123 r
F
.9044 .43257 m .90325 .43086 L .90621 .42992 L F
.27497 .43415 m .27588 .43153 L .27761 .43328 L 0 .028 .127 r
F
.27497 .43415 m .27324 .4324 L .27588 .43153 L F
.24257 .43359 m .24344 .43093 L .2452 .43264 L 0 .027 .126 r
F
.24257 .43359 m .24081 .43187 L .24344 .43093 L F
.37217 .43593 m .37322 .43344 L .37486 .43499 L 0 .032 .133 r
F
.37217 .43593 m .37052 .43436 L .37322 .43344 L F
.80444 .43342 m .80611 .43086 L .80736 .43257 L 0 .026 .125 r
F
.80444 .43342 m .8032 .43171 L .80611 .43086 L F
.3792 .4356 m .38025 .43328 L .38189 .4348 L 0 .032 .132 r
F
.3792 .4356 m .37756 .43406 L .38025 .43328 L F
.5201 .4397 m .52136 .43733 L .52287 .43891 L 0 .041 .143 r
F
.5201 .4397 m .5186 .43812 L .52136 .43733 L F
.49473 .43874 m .49596 .4364 L .49749 .4381 L 0 .039 .141 r
F
.49473 .43874 m .49321 .43705 L .49596 .4364 L F
.67634 .43582 m .67783 .43324 L .67918 .43481 L 0 .032 .132 r
F
.67634 .43582 m .67499 .43428 L .67783 .43324 L F
.4553 .43856 m .45646 .43624 L .45803 .43785 L 0 .038 .14 r
F
.4553 .43856 m .45373 .43693 L .45646 .43624 L F
.91146 .43234 m .91328 .42976 L .91442 .43143 L 0 .024 .123 r
F
.91146 .43234 m .91031 .43067 L .91328 .42976 L F
.66931 .43627 m .67079 .43381 L .67215 .43533 L 0 .033 .134 r
F
.66931 .43627 m .66795 .43477 L .67079 .43381 L F
.85796 .43296 m .8597 .43034 L .86089 .43198 L 0 .026 .124 r
F
.85796 .43296 m .85677 .43132 L .8597 .43034 L F
.68338 .43551 m .68488 .43292 L .68623 .4346 L 0 .031 .131 r
F
.68338 .43551 m .68203 .43386 L .68488 .43292 L F
.75095 .43417 m .75255 .43158 L .75383 .43317 L 0 .028 .128 r
F
.75095 .43417 m .74967 .4326 L .75255 .43158 L F
.74392 .43457 m .74551 .43208 L .7468 .43362 L 0 .029 .129 r
F
.74392 .43457 m .74263 .43304 L .74551 .43208 L F
.43696 .43731 m .4381 .4349 L .43968 .43663 L 0 .036 .137 r
F
.43696 .43731 m .43538 .43562 L .4381 .4349 L F
.35382 .43478 m .35484 .43239 L .3565 .43406 L 0 .03 .13 r
F
.35382 .43478 m .35216 .43314 L .35484 .43239 L F
.24958 .43343 m .25045 .43095 L .2522 .43262 L 0 .027 .126 r
F
.24958 .43343 m .24783 .43174 L .25045 .43095 L F
.8115 .43327 m .81319 .43081 L .81441 .43238 L F
.8115 .43327 m .81027 .4317 L .81319 .43081 L F
.28198 .43407 m .28291 .43137 L .28463 .43311 L 0 .028 .127 r
F
.28198 .43407 m .28026 .43232 L .28291 .43137 L F
.52714 .43955 m .52841 .43749 L .52991 .43886 L 0 .042 .144 r
F
.52714 .43955 m .52564 .4382 L .52841 .43749 L F
.86501 .43273 m .86675 .43004 L .86794 .43177 L 0 .025 .124 r
F
.86501 .43273 m .86382 .43101 L .86675 .43004 L F
.91851 .43215 m .92036 .42968 L .92149 .43129 L 0 .024 .123 r
F
.91851 .43215 m .91739 .43055 L .92036 .42968 L F
.41159 .43645 m .41269 .43402 L .4143 .43569 L 0 .034 .135 r
F
.41159 .43645 m .40998 .43477 L .41269 .43402 L F
.32141 .43435 m .32239 .43182 L .32407 .43352 L 0 .029 .129 r
F
.32141 .43435 m .31972 .43266 L .32239 .43182 L F
.758 .43397 m .7596 .43135 L .76089 .43308 L 0 .028 .127 r
F
.758 .43397 m .75671 .43226 L .7596 .43135 L F
.60878 .43752 m .61017 .43508 L .6116 .43675 L 0 .036 .138 r
F
.60878 .43752 m .60736 .43586 L .61017 .43508 L F
.81855 .43304 m .82024 .43055 L .82146 .43213 L 0 .026 .125 r
F
.81855 .43304 m .81733 .43148 L .82024 .43055 L F
.38622 .43558 m .38727 .43332 L .38891 .43482 L 0 .032 .133 r
F
.38622 .43558 m .38458 .43407 L .38727 .43332 L F
.69043 .43543 m .69193 .4327 L .69328 .43444 L 0 .031 .131 r
F
.69043 .43543 m .68908 .43368 L .69193 .4327 L F
.289 .43387 m .28993 .43132 L .29165 .43298 L 0 .028 .127 r
F
.289 .43387 m .28728 .43221 L .28993 .43132 L F
.46233 .43858 m .4635 .43649 L .46506 .43785 L 0 .04 .141 r
F
.46233 .43858 m .46076 .43718 L .4635 .43649 L F
.7045 .43469 m .70602 .43206 L .70735 .43367 L 0 .03 .13 r
F
.7045 .43469 m .70317 .43309 L .70602 .43206 L F
.87206 .43254 m .87382 .42986 L .875 .43159 L 0 .025 .124 r
F
.87206 .43254 m .87088 .43081 L .87382 .42986 L F
.32843 .43412 m .32942 .43161 L .33111 .43317 L 0 .029 .128 r
F
.32843 .43412 m .32675 .43256 L .32942 .43161 L F
.53417 .43941 m .53546 .43726 L .53694 .43863 L 0 .042 .144 r
F
.53417 .43941 m .53268 .43807 L .53546 .43726 L F
.92558 .43201 m .92743 .4295 L .92855 .43112 L 0 .024 .123 r
F
.92558 .43201 m .92446 .4304 L .92743 .4295 L F
.71154 .43438 m .71309 .43196 L .71441 .43353 L 0 .029 .129 r
F
.71154 .43438 m .71022 .43281 L .71309 .43196 L F
.69747 .43516 m .69898 .43243 L .70032 .43413 L 0 .031 .131 r
F
.69747 .43516 m .69613 .43345 L .69898 .43243 L F
.8256 .43283 m .8273 .43029 L .82852 .43193 L 0 .026 .125 r
F
.8256 .43283 m .82438 .43121 L .8273 .43029 L F
.62286 .43695 m .62427 .43437 L .62567 .43595 L 0 .035 .136 r
F
.62286 .43695 m .62145 .43539 L .62427 .43437 L F
.62989 .43657 m .63131 .43397 L .63271 .4356 L 0 .034 .135 r
F
.62989 .43657 m .62849 .43496 L .63131 .43397 L F
.25658 .43347 m .25747 .43085 L .25922 .43252 L 0 .027 .127 r
F
.25658 .43347 m .25483 .43181 L .25747 .43085 L F
.48343 .43758 m .48463 .43554 L .48617 .43692 L 0 .037 .139 r
F
.48343 .43758 m .48188 .43618 L .48463 .43554 L F
.29602 .43369 m .29696 .43115 L .29867 .43279 L 0 .028 .127 r
F
.29602 .43369 m .2943 .43208 L .29696 .43115 L F
.46936 .43838 m .47054 .43616 L .4721 .43754 L 0 .039 .141 r
F
.46936 .43838 m .4678 .437 L .47054 .43616 L F
.76506 .43391 m .76666 .43118 L .76794 .43293 L 0 .028 .128 r
F
.76506 .43391 m .76377 .43216 L .76666 .43118 L F
.87912 .43236 m .8809 .42977 L .88207 .43144 L 0 .025 .124 r
F
.87912 .43236 m .87795 .43068 L .8809 .42977 L F
.55528 .43842 m .55659 .4362 L .55806 .43749 L 0 .039 .141 r
F
.55528 .43842 m .55381 .43708 L .55659 .4362 L F
.61582 .43745 m .61722 .43485 L .61864 .43642 L 0 .036 .138 r
F
.61582 .43745 m .61441 .4359 L .61722 .43485 L F
.33546 .43395 m .33644 .43162 L .33812 .4332 L 0 .029 .129 r
F
.33546 .43395 m .33378 .43238 L .33644 .43162 L F
.36083 .43494 m .36185 .43265 L .36351 .43425 L 0 .031 .131 r
F
.36083 .43494 m .35917 .43333 L .36185 .43265 L F
.47639 .43807 m .47759 .43571 L .47914 .43712 L 0 .038 .14 r
F
.47639 .43807 m .47484 .43665 L .47759 .43571 L F
.63693 .43631 m .63836 .43376 L .63976 .43538 L 0 .034 .135 r
F
.63693 .43631 m .63554 .43468 L .63836 .43376 L F
.54121 .43925 m .5425 .43696 L .54398 .43834 L 0 .041 .143 r
F
.54121 .43925 m .53972 .43783 L .5425 .43696 L F
.77913 .4332 m .78077 .4306 L .78203 .43222 L 0 .027 .126 r
F
.77913 .4332 m .77788 .4316 L .78077 .4306 L F
.41861 .43652 m .41973 .43392 L .42133 .43554 L 0 .034 .135 r
F
.41861 .43652 m .41701 .43488 L .41973 .43392 L F
.54824 .43887 m .54955 .43657 L .55102 .43796 L 0 .04 .142 r
F
.54824 .43887 m .54676 .43743 L .54955 .43657 L F
.2636 .43322 m .26451 .43055 L .26624 .43227 L 0 .027 .126 r
F
.2636 .43322 m .26186 .43153 L .26451 .43055 L F
.56231 .43811 m .56364 .43585 L .5651 .43732 L 0 .039 .14 r
F
.56231 .43811 m .56085 .43667 L .56364 .43585 L F
.93265 .43187 m .9345 .4293 L .93562 .43097 L 0 .024 .122 r
F
.93265 .43187 m .93152 .43022 L .9345 .4293 L F
.71859 .43422 m .72014 .43173 L .72145 .4333 L 0 .029 .129 r
F
.71859 .43422 m .71727 .43265 L .72014 .43173 L F
.7721 .43364 m .77372 .43093 L .77499 .43262 L 0 .028 .127 r
F
.7721 .43364 m .77083 .43194 L .77372 .43093 L F
.42564 .43618 m .42677 .43374 L .42836 .43536 L 0 .034 .135 r
F
.42564 .43618 m .42405 .43456 L .42677 .43374 L F
.88617 .43211 m .88795 .4295 L .88911 .43112 L 0 .025 .123 r
F
.88617 .43211 m .88501 .4305 L .88795 .4295 L F
.39323 .43562 m .39432 .43304 L .39594 .43473 L 0 .032 .133 r
F
.39323 .43562 m .39161 .43393 L .39432 .43304 L F
.64397 .43601 m .64541 .43343 L .6468 .43502 L 0 .033 .134 r
F
.64397 .43601 m .64258 .43442 L .64541 .43343 L F
.651 .43562 m .65246 .43314 L .65384 .43475 L 0 .032 .133 r
F
.651 .43562 m .64962 .43402 L .65246 .43314 L F
.50176 .43916 m .503 .43666 L .50452 .43834 L 0 .041 .143 r
F
.50176 .43916 m .50024 .43745 L .503 .43666 L F
.44398 .43763 m .44513 .4352 L .4467 .4369 L 0 .037 .139 r
F
.44398 .43763 m .4424 .43595 L .44513 .4352 L F
.89321 .43177 m .89501 .42924 L .89617 .43088 L 0 .024 .122 r
F
.89321 .43177 m .89206 .43014 L .89501 .42924 L F
.78618 .43295 m .78783 .43047 L .78908 .43207 L 0 .027 .126 r
F
.78618 .43295 m .78493 .43134 L .78783 .43047 L F
.30304 .43354 m .30399 .43094 L .3057 .43262 L 0 .028 .127 r
F
.30304 .43354 m .30133 .43188 L .30399 .43094 L F
.83267 .43281 m .83438 .43025 L .8356 .43197 L 0 .026 .125 r
F
.83267 .43281 m .83145 .43109 L .83438 .43025 L F
.72564 .43404 m .72719 .43146 L .72851 .43314 L 0 .029 .129 r
F
.72564 .43404 m .72432 .43238 L .72719 .43146 L F
.93972 .43177 m .94158 .4292 L .9427 .4309 L 0 .024 .123 r
F
.93972 .43177 m .9386 .43007 L .94158 .4292 L F
.31006 .43337 m .31103 .43074 L .31272 .43245 L 0 .028 .127 r
F
.31006 .43337 m .30836 .43168 L .31103 .43074 L F
.27061 .43319 m .27151 .43066 L .27324 .4324 L 0 .027 .127 r
F
.27061 .43319 m .26888 .43146 L .27151 .43066 L F
.79324 .43281 m .79489 .43018 L .79614 .43184 L 0 .026 .125 r
F
.79324 .43281 m .79199 .43115 L .79489 .43018 L F
.56935 .43809 m .57069 .43568 L .57215 .43728 L 0 .039 .14 r
F
.56935 .43809 m .56789 .43652 L .57069 .43568 L F
.49046 .4377 m .49167 .43565 L .49321 .43705 L 0 .038 .14 r
F
.49046 .4377 m .48892 .4363 L .49167 .43565 L F
.5088 .43908 m .51004 .43654 L .51156 .43816 L 0 .041 .143 r
F
.5088 .43908 m .50728 .43744 L .51004 .43654 L F
.5975 .43654 m .59888 .43429 L .60031 .43576 L 0 .035 .137 r
F
.5975 .43654 m .59607 .43508 L .59888 .43429 L F
.34247 .43401 m .34347 .43156 L .34514 .43316 L 0 .029 .129 r
F
.34247 .43401 m .34079 .43243 L .34347 .43156 L F
.65805 .43557 m .65952 .43309 L .66089 .43475 L 0 .033 .133 r
F
.65805 .43557 m .65668 .43392 L .65952 .43309 L F
.40025 .43558 m .40135 .43305 L .40296 .43473 L F
.40025 .43558 m .39864 .43388 L .40135 .43305 L F
.59046 .43698 m .59183 .43462 L .59326 .43598 L 0 .036 .138 r
F
.59046 .43698 m .58903 .43561 L .59183 .43462 L F
.90029 .43173 m .9021 .42916 L .90325 .43086 L 0 .024 .123 r
F
.90029 .43173 m .89913 .43002 L .9021 .42916 L F
.73269 .43394 m .73426 .43136 L .73557 .43308 L 0 .029 .129 r
F
.73269 .43394 m .73138 .43225 L .73426 .43136 L F
.80029 .43258 m .80195 .43 L .8032 .43171 L 0 .026 .125 r
F
.80029 .43258 m .79904 .43087 L .80195 .43 L F
.83974 .43278 m .84144 .43006 L .84266 .43178 L F
.83974 .43278 m .83852 .43106 L .84144 .43006 L F
.36784 .43514 m .36887 .43279 L .37052 .43436 L 0 .032 .133 r
F
.36784 .43514 m .36619 .43355 L .36887 .43279 L F
.84678 .43241 m .84851 .42985 L .84971 .43149 L 0 .026 .125 r
F
.84678 .43241 m .84558 .43078 L .84851 .42985 L F
.23818 .4328 m .23905 .43014 L .24081 .43187 L 0 .026 .126 r
F
.23818 .4328 m .23642 .43106 L .23905 .43014 L F
.43266 .43632 m .4338 .43393 L .43538 .43562 L 0 .035 .136 r
F
.43266 .43632 m .43108 .43465 L .4338 .43393 L F
.451 .43776 m .45217 .43522 L .45373 .43693 L 0 .038 .14 r
F
.451 .43776 m .44943 .43606 L .45217 .43522 L F
.58343 .43759 m .58479 .43521 L .58623 .4366 L F
.58343 .43759 m .58199 .43619 L .58479 .43521 L F
.51583 .43896 m .51709 .43654 L .5186 .43812 L 0 .041 .143 r
F
.51583 .43896 m .51432 .43735 L .51709 .43654 L F
.9468 .43174 m .94868 .42918 L .94979 .43088 L 0 .025 .123 r
F
.9468 .43174 m .94569 .43004 L .94868 .42918 L F
.34949 .43393 m .3505 .4315 L .35216 .43314 L 0 .029 .129 r
F
.34949 .43393 m .34782 .43231 L .3505 .4315 L F
.90736 .43162 m .90917 .42897 L .91031 .43067 L 0 .024 .123 r
F
.90736 .43162 m .90621 .42992 L .90917 .42897 L F
.40728 .43554 m .40838 .43314 L .40998 .43477 L 0 .033 .134 r
F
.40728 .43554 m .40567 .43388 L .40838 .43314 L F
.85383 .43222 m .85558 .42969 L .85677 .43132 L 0 .026 .125 r
F
.85383 .43222 m .85264 .4306 L .85558 .42969 L F
.31707 .43341 m .31804 .43091 L .31972 .43266 L 0 .028 .128 r
F
.31707 .43341 m .31538 .43168 L .31804 .43091 L F
.2452 .43264 m .24607 .43005 L .24783 .43174 L 0 .027 .126 r
F
.2452 .43264 m .24344 .43093 L .24607 .43005 L F
.5764 .43811 m .57774 .43556 L .57919 .43718 L 0 .039 .141 r
F
.5764 .43811 m .57494 .43648 L .57774 .43556 L F
.37486 .43499 m .37591 .43252 L .37756 .43406 L 0 .032 .132 r
F
.37486 .43499 m .37322 .43344 L .37591 .43252 L F
.66511 .43559 m .66658 .43311 L .66795 .43477 L 0 .033 .134 r
F
.66511 .43559 m .66374 .43393 L .66658 .43311 L F
.67918 .43481 m .68067 .43225 L .68203 .43386 L 0 .031 .132 r
F
.67918 .43481 m .67783 .43324 L .68067 .43225 L F
.27761 .43328 m .27854 .43058 L .28026 .43232 L 0 .028 .127 r
F
.27761 .43328 m .27588 .43153 L .27854 .43058 L F
.73975 .43388 m .74133 .4314 L .74263 .43304 L 0 .029 .129 r
F
.73975 .43388 m .73845 .43224 L .74133 .4314 L F
.60455 .43664 m .60593 .4342 L .60736 .43586 L 0 .036 .137 r
F
.60455 .43664 m .60312 .43499 L .60593 .4342 L F
.80736 .43257 m .80903 .42999 L .81027 .4317 L 0 .027 .126 r
F
.80736 .43257 m .80611 .43086 L .80903 .42999 L F
.86089 .43198 m .86263 .42936 L .86382 .43101 L 0 .025 .124 r
F
.86089 .43198 m .8597 .43034 L .86263 .42936 L F
.75383 .43317 m .75543 .43064 L .75671 .43226 L 0 .028 .127 r
F
.75383 .43317 m .75255 .43158 L .75543 .43064 L F
.67215 .43533 m .67363 .43273 L .67499 .43428 L 0 .033 .133 r
F
.67215 .43533 m .67079 .43381 L .67363 .43273 L F
.91442 .43143 m .91625 .42888 L .91739 .43055 L 0 .024 .123 r
F
.91442 .43143 m .91328 .42976 L .91625 .42888 L F
.7468 .43362 m .74838 .43103 L .74967 .4326 L 0 .029 .129 r
F
.7468 .43362 m .74551 .43208 L .74838 .43103 L F
.68623 .4346 m .68773 .43197 L .68908 .43368 L 0 .031 .131 r
F
.68623 .4346 m .68488 .43292 L .68773 .43197 L F
.38189 .4348 m .38294 .43256 L .38458 .43407 L 0 .032 .133 r
F
.38189 .4348 m .38025 .43328 L .38294 .43256 L F
.52287 .43891 m .52414 .4366 L .52564 .4382 L 0 .042 .144 r
F
.52287 .43891 m .52136 .43733 L .52414 .4366 L F
.28463 .43311 m .28556 .43048 L .28728 .43221 L 0 .028 .127 r
F
.28463 .43311 m .28291 .43137 L .28556 .43048 L F
.86794 .43177 m .86969 .42908 L .87088 .43081 L 0 .025 .124 r
F
.86794 .43177 m .86675 .43004 L .86969 .42908 L F
.81441 .43238 m .81611 .42991 L .81733 .43148 L 0 .027 .126 r
F
.81441 .43238 m .81319 .43081 L .81611 .42991 L F
.45803 .43785 m .4592 .43559 L .46076 .43718 L 0 .039 .141 r
F
.45803 .43785 m .45646 .43624 L .4592 .43559 L F
.2522 .43262 m .25307 .43015 L .25483 .43181 L 0 .027 .126 r
F
.2522 .43262 m .25045 .43095 L .25307 .43015 L F
.49749 .4381 m .49872 .43575 L .50024 .43745 L 0 .04 .142 r
F
.49749 .4381 m .49596 .4364 L .49872 .43575 L F
.92149 .43129 m .92333 .42878 L .92446 .4304 L 0 .024 .123 r
F
.92149 .43129 m .92036 .42968 L .92333 .42878 L F
.69328 .43444 m .69478 .43173 L .69613 .43345 L 0 .031 .131 r
F
.69328 .43444 m .69193 .4327 L .69478 .43173 L F
.76089 .43308 m .76249 .43042 L .76377 .43216 L 0 .028 .127 r
F
.76089 .43308 m .7596 .43135 L .76249 .43042 L F
.3565 .43406 m .35752 .43163 L .35917 .43333 L 0 .03 .131 r
F
.3565 .43406 m .35484 .43239 L .35752 .43163 L F
.70735 .43367 m .70889 .43121 L .71022 .43281 L 0 .029 .129 r
F
.70735 .43367 m .70602 .43206 L .70889 .43121 L F
.82146 .43213 m .82316 .42961 L .82438 .43121 L 0 .026 .125 r
F
.82146 .43213 m .82024 .43055 L .82316 .42961 L F
.43968 .43663 m .44083 .43419 L .4424 .43595 L 0 .036 .138 r
F
.43968 .43663 m .4381 .4349 L .44083 .43419 L F
.32407 .43352 m .32506 .43086 L .32675 .43256 L 0 .029 .129 r
F
.32407 .43352 m .32239 .43182 L .32506 .43086 L F
.4143 .43569 m .41541 .43323 L .41701 .43488 L 0 .034 .135 r
F
.4143 .43569 m .41269 .43402 L .41541 .43323 L F
.875 .43159 m .87677 .42895 L .87795 .43068 L 0 .025 .123 r
F
.875 .43159 m .87382 .42986 L .87677 .42895 L F
.70032 .43413 m .70183 .43139 L .70317 .43309 L 0 .03 .13 r
F
.70032 .43413 m .69898 .43243 L .70183 .43139 L F
.33111 .43317 m .33209 .4308 L .33378 .43238 L 0 .029 .128 r
F
.33111 .43317 m .32942 .43161 L .33209 .4308 L F
.29165 .43298 m .29259 .43042 L .2943 .43208 L 0 .028 .127 r
F
.29165 .43298 m .28993 .43132 L .29259 .43042 L F
.52991 .43886 m .53118 .43668 L .53268 .43807 L 0 .042 .145 r
F
.52991 .43886 m .52841 .43749 L .53118 .43668 L F
.62567 .43595 m .62709 .43335 L .62849 .43496 L 0 .035 .136 r
F
.62567 .43595 m .62427 .43437 L .62709 .43335 L F
.6116 .43675 m .61299 .43423 L .61441 .4359 L 0 .037 .138 r
F
.6116 .43675 m .61017 .43508 L .61299 .43423 L F
.38891 .43482 m .38998 .43241 L .39161 .43393 L 0 .032 .133 r
F
.38891 .43482 m .38727 .43332 L .38998 .43241 L F
.63271 .4356 m .63414 .43308 L .63554 .43468 L 0 .034 .135 r
F
.63271 .4356 m .63131 .43397 L .63414 .43308 L F
.92855 .43112 m .93041 .42859 L .93152 .43022 L 0 .024 .123 r
F
.92855 .43112 m .92743 .4295 L .93041 .42859 L F
.61864 .43642 m .62004 .4338 L .62145 .43539 L 0 .036 .137 r
F
.61864 .43642 m .61722 .43485 L .62004 .4338 L F
.82852 .43193 m .83023 .42943 L .83145 .43109 L 0 .026 .125 r
F
.82852 .43193 m .8273 .43029 L .83023 .42943 L F
.25922 .43252 m .26012 .42984 L .26186 .43153 L 0 .027 .126 r
F
.25922 .43252 m .25747 .43085 L .26012 .42984 L F
.76794 .43293 m .76955 .43021 L .77083 .43194 L 0 .028 .127 r
F
.76794 .43293 m .76666 .43118 L .76955 .43021 L F
.71441 .43353 m .71596 .43108 L .71727 .43265 L 0 .029 .129 r
F
.71441 .43353 m .71309 .43196 L .71596 .43108 L F
.46506 .43785 m .46624 .43563 L .4678 .437 L 0 .04 .142 r
F
.46506 .43785 m .4635 .43649 L .46624 .43563 L F
.53694 .43863 m .53823 .43645 L .53972 .43783 L 0 .042 .144 r
F
.53694 .43863 m .53546 .43726 L .53823 .43645 L F
.29867 .43279 m .29962 .43022 L .30133 .43188 L 0 .028 .127 r
F
.29867 .43279 m .29696 .43115 L .29962 .43022 L F
.55806 .43749 m .55938 .43535 L .56085 .43667 L 0 .039 .141 r
F
.55806 .43749 m .55659 .4362 L .55938 .43535 L F
.88207 .43144 m .88384 .42883 L .88501 .4305 L 0 .025 .123 r
F
.88207 .43144 m .8809 .42977 L .88384 .42883 L F
.78203 .43222 m .78367 .42973 L .78493 .43134 L 0 .027 .126 r
F
.78203 .43222 m .78077 .4306 L .78367 .42973 L F
.42133 .43554 m .42245 .43296 L .42405 .43456 L 0 .034 .135 r
F
.42133 .43554 m .41973 .43392 L .42245 .43296 L F
.77499 .43262 m .77661 .42991 L .77788 .4316 L 0 .027 .126 r
F
.77499 .43262 m .77372 .43093 L .77661 .42991 L F
.47914 .43712 m .48034 .43478 L .48188 .43618 L 0 .038 .14 r
F
.47914 .43712 m .47759 .43571 L .48034 .43478 L F
.63976 .43538 m .64119 .43282 L .64258 .43442 L 0 .033 .134 r
F
.63976 .43538 m .63836 .43376 L .64119 .43282 L F
.26624 .43227 m .26714 .42973 L .26888 .43146 L 0 .027 .126 r
F
.26624 .43227 m .26451 .43055 L .26714 .42973 L F
.4721 .43754 m .47329 .43526 L .47484 .43665 L 0 .039 .141 r
F
.4721 .43754 m .47054 .43616 L .47329 .43526 L F
.6468 .43502 m .64824 .43245 L .64962 .43402 L 0 .033 .133 r
F
.6468 .43502 m .64541 .43343 L .64824 .43245 L F
.54398 .43834 m .54528 .43609 L .54676 .43743 L 0 .041 .143 r
F
.54398 .43834 m .5425 .43696 L .54528 .43609 L F
.55102 .43796 m .55233 .43574 L .55381 .43708 L 0 .04 .142 r
F
.55102 .43796 m .54955 .43657 L .55233 .43574 L F
.88911 .43112 m .8909 .42851 L .89206 .43014 L 0 .024 .123 r
F
.88911 .43112 m .88795 .4295 L .8909 .42851 L F
.72145 .4333 m .72301 .43082 L .72432 .43238 L 0 .029 .129 r
F
.72145 .4333 m .72014 .43173 L .72301 .43082 L F
.93562 .43097 m .93748 .42838 L .9386 .43007 L 0 .024 .122 r
F
.93562 .43097 m .9345 .4293 L .93748 .42838 L F
.39594 .43473 m .39702 .4322 L .39864 .43388 L 0 .032 .133 r
F
.39594 .43473 m .39432 .43304 L .39702 .4322 L F
.65384 .43475 m .6553 .43228 L .65668 .43392 L F
.65384 .43475 m .65246 .43314 L .6553 .43228 L F
.33812 .4332 m .33911 .43083 L .34079 .43243 L 0 .029 .129 r
F
.33812 .4332 m .33644 .43162 L .33911 .43083 L F
.3057 .43262 m .30666 .42998 L .30836 .43168 L 0 .028 .127 r
F
.3057 .43262 m .30399 .43094 L .30666 .42998 L F
.48617 .43692 m .48738 .43492 L .48892 .4363 L 0 .038 .14 r
F
.48617 .43692 m .48463 .43554 L .48738 .43492 L F
.42836 .43536 m .42949 .43303 L .43108 .43465 L 0 .034 .135 r
F
.42836 .43536 m .42677 .43374 L .42949 .43303 L F
.5651 .43732 m .56643 .43502 L .56789 .43652 L 0 .039 .141 r
F
.5651 .43732 m .56364 .43585 L .56643 .43502 L F
.89617 .43088 m .89798 .42838 L .89913 .43002 L 0 .024 .122 r
F
.89617 .43088 m .89501 .42924 L .89798 .42838 L F
.78908 .43207 m .79074 .42955 L .79199 .43115 L 0 .027 .126 r
F
.78908 .43207 m .78783 .43047 L .79074 .42955 L F
.50452 .43834 m .50576 .43579 L .50728 .43744 L 0 .041 .143 r
F
.50452 .43834 m .503 .43666 L .50576 .43579 L F
.36351 .43425 m .36453 .43197 L .36619 .43355 L 0 .032 .132 r
F
.36351 .43425 m .36185 .43265 L .36453 .43197 L F
.72851 .43314 m .73007 .43055 L .73138 .43225 L 0 .029 .129 r
F
.72851 .43314 m .72719 .43146 L .73007 .43055 L F
.8356 .43197 m .83731 .42934 L .83852 .43106 L 0 .026 .125 r
F
.8356 .43197 m .83438 .43025 L .83731 .42934 L F
.4467 .4369 m .44786 .43435 L .44943 .43606 L 0 .038 .139 r
F
.4467 .4369 m .44513 .4352 L .44786 .43435 L F
.79614 .43184 m .79779 .42921 L .79904 .43087 L 0 .026 .125 r
F
.79614 .43184 m .79489 .43018 L .79779 .42921 L F
.31272 .43245 m .31368 .42995 L .31538 .43168 L 0 .028 .127 r
F
.31272 .43245 m .31103 .43074 L .31368 .42995 L F
.59326 .43598 m .59464 .43372 L .59607 .43508 L 0 .036 .137 r
F
.59326 .43598 m .59183 .43462 L .59464 .43372 L F
.9427 .4309 m .94457 .42834 L .94569 .43004 L 0 .024 .123 r
F
.9427 .4309 m .94158 .4292 L .94457 .42834 L F
.51156 .43816 m .51281 .43578 L .51432 .43735 L 0 .041 .143 r
F
.51156 .43816 m .51004 .43654 L .51281 .43578 L F
.84266 .43178 m .84437 .42906 L .84558 .43078 L 0 .026 .125 r
F
.84266 .43178 m .84144 .43006 L .84437 .42906 L F
.34514 .43316 m .34615 .43069 L .34782 .43231 L 0 .029 .129 r
F
.34514 .43316 m .34347 .43156 L .34615 .43069 L F
.40296 .43473 m .40405 .43223 L .40567 .43388 L 0 .033 .134 r
F
.40296 .43473 m .40135 .43305 L .40405 .43223 L F
.57215 .43728 m .57349 .43484 L .57494 .43648 L 0 .039 .141 r
F
.57215 .43728 m .57069 .43568 L .57349 .43484 L F
.27324 .4324 m .27416 .42978 L .27588 .43153 L 0 .028 .127 r
F
.27324 .4324 m .27151 .43066 L .27416 .42978 L F
.66089 .43475 m .66236 .43227 L .66374 .43393 L 0 .033 .134 r
F
.66089 .43475 m .65952 .43309 L .66236 .43227 L F
.90325 .43086 m .90506 .42822 L .90621 .42992 L 0 .024 .123 r
F
.90325 .43086 m .9021 .42916 L .90506 .42822 L F
.60031 .43576 m .60169 .4335 L .60312 .43499 L 0 .036 .137 r
F
.60031 .43576 m .59888 .43429 L .60169 .4335 L F
.24081 .43187 m .24168 .42922 L .24344 .43093 L 0 .026 .125 r
F
.24081 .43187 m .23905 .43014 L .24168 .42922 L F
.84971 .43149 m .85144 .42894 L .85264 .4306 L F
.84971 .43149 m .84851 .42985 L .85144 .42894 L F
.8032 .43171 m .80487 .42914 L .80611 .43086 L F
.8032 .43171 m .80195 .43 L .80487 .42914 L F
.73557 .43308 m .73714 .43052 L .73845 .43224 L 0 .029 .129 r
F
.73557 .43308 m .73426 .43136 L .73714 .43052 L F
.58623 .4366 m .58759 .43423 L .58903 .43561 L 0 .038 .139 r
F
.58623 .4366 m .58479 .43521 L .58759 .43423 L F
.49321 .43705 m .49443 .43498 L .49596 .4364 L 0 .039 .141 r
F
.49321 .43705 m .49167 .43565 L .49443 .43498 L F
.37052 .43436 m .37157 .43189 L .37322 .43344 L 0 .032 .133 r
F
.37052 .43436 m .36887 .43279 L .37157 .43189 L F
.91031 .43067 m .91213 .42806 L .91328 .42976 L 0 .024 .123 r
F
.91031 .43067 m .90917 .42897 L .91213 .42806 L F
.45373 .43693 m .4549 .43454 L .45646 .43624 L 0 .038 .14 r
F
.45373 .43693 m .45217 .43522 L .4549 .43454 L F
.5186 .43812 m .51986 .43575 L .52136 .43733 L 0 .041 .144 r
F
.5186 .43812 m .51709 .43654 L .51986 .43575 L F
.85677 .43132 m .85851 .4287 L .8597 .43034 L 0 .026 .124 r
F
.85677 .43132 m .85558 .42969 L .85851 .4287 L F
.37756 .43406 m .37861 .43175 L .38025 .43328 L 0 .032 .133 r
F
.37756 .43406 m .37591 .43252 L .37861 .43175 L F
.43538 .43562 m .43652 .43317 L .4381 .4349 L 0 .035 .137 r
F
.43538 .43562 m .4338 .43393 L .43652 .43317 L F
.57919 .43718 m .58054 .43459 L .58199 .43619 L 0 .039 .141 r
F
.57919 .43718 m .57774 .43556 L .58054 .43459 L F
.68203 .43386 m .68352 .43126 L .68488 .43292 L 0 .031 .131 r
F
.68203 .43386 m .68067 .43225 L .68352 .43126 L F
.28026 .43232 m .28119 .42963 L .28291 .43137 L 0 .028 .127 r
F
.28026 .43232 m .27854 .43058 L .28119 .42963 L F
.24783 .43174 m .24869 .42927 L .25045 .43095 L 0 .027 .126 r
F
.24783 .43174 m .24607 .43005 L .24869 .42927 L F
.67499 .43428 m .67647 .43166 L .67783 .43324 L 0 .032 .133 r
F
.67499 .43428 m .67363 .43273 L .67647 .43166 L F
.35216 .43314 m .35318 .43072 L .35484 .43239 L 0 .03 .13 r
F
.35216 .43314 m .3505 .4315 L .35318 .43072 L F
.86382 .43101 m .86557 .42838 L .86675 .43004 L 0 .025 .124 r
F
.86382 .43101 m .86263 .42936 L .86557 .42838 L F
.74967 .4326 m .75126 .42999 L .75255 .43158 L 0 .028 .128 r
F
.74967 .4326 m .74838 .43103 L .75126 .42999 L F
.66795 .43477 m .66943 .43216 L .67079 .43381 L 0 .033 .134 r
F
.66795 .43477 m .66658 .43311 L .66943 .43216 L F
.40998 .43477 m .41108 .43241 L .41269 .43402 L 0 .034 .135 r
F
.40998 .43477 m .40838 .43314 L .41108 .43241 L F
.74263 .43304 m .74421 .43043 L .74551 .43208 L 0 .029 .129 r
F
.74263 .43304 m .74133 .4314 L .74421 .43043 L F
.75671 .43226 m .75832 .4297 L .7596 .43135 L 0 .028 .127 r
F
.75671 .43226 m .75543 .43064 L .75832 .4297 L F
.31972 .43266 m .3207 .43006 L .32239 .43182 L 0 .029 .128 r
F
.31972 .43266 m .31804 .43091 L .3207 .43006 L F
.81027 .4317 m .81195 .42911 L .81319 .43081 L 0 .027 .126 r
F
.81027 .4317 m .80903 .42999 L .81195 .42911 L F
.68908 .43368 m .69058 .43102 L .69193 .4327 L 0 .031 .131 r
F
.68908 .43368 m .68773 .43197 L .69058 .43102 L F
.91739 .43055 m .91922 .428 L .92036 .42968 L 0 .024 .123 r
F
.91739 .43055 m .91625 .42888 L .91922 .428 L F
.60736 .43586 m .60875 .43342 L .61017 .43508 L 0 .036 .138 r
F
.60736 .43586 m .60593 .4342 L .60875 .43342 L F
.87088 .43081 m .87263 .42812 L .87382 .42986 L 0 .025 .123 r
F
.87088 .43081 m .86969 .42908 L .87263 .42812 L F
.28728 .43221 m .28821 .4296 L .28993 .43132 L 0 .028 .127 r
F
.28728 .43221 m .28556 .43048 L .28821 .4296 L F
.81733 .43148 m .81902 .42897 L .82024 .43055 L 0 .027 .126 r
F
.81733 .43148 m .81611 .42991 L .81902 .42897 L F
.69613 .43345 m .69764 .43072 L .69898 .43243 L 0 .03 .131 r
F
.69613 .43345 m .69478 .43173 L .69764 .43072 L F
.70317 .43309 m .70469 .43037 L .70602 .43206 L 0 .03 .13 r
F
.70317 .43309 m .70183 .43139 L .70469 .43037 L F
.38458 .43407 m .38564 .43181 L .38727 .43332 L 0 .033 .133 r
F
.38458 .43407 m .38294 .43256 L .38564 .43181 L F
.52564 .4382 m .52691 .43586 L .52841 .43749 L 0 .042 .145 r
F
.52564 .4382 m .52414 .4366 L .52691 .43586 L F
.92446 .4304 m .92631 .42788 L .92743 .4295 L 0 .024 .123 r
F
.92446 .4304 m .92333 .42878 L .92631 .42788 L F
.76377 .43216 m .76538 .42945 L .76666 .43118 L 0 .028 .127 r
F
.76377 .43216 m .76249 .43042 L .76538 .42945 L F
.32675 .43256 m .32774 .4299 L .32942 .43161 L 0 .029 .128 r
F
.32675 .43256 m .32506 .43086 L .32774 .4299 L F
.82438 .43121 m .82608 .42866 L .8273 .43029 L 0 .026 .125 r
F
.82438 .43121 m .82316 .42961 L .82608 .42866 L F
.25483 .43181 m .25572 .42921 L .25747 .43085 L 0 .027 .127 r
F
.25483 .43181 m .25307 .43015 L .25572 .42921 L F
.62849 .43496 m .62991 .43234 L .63131 .43397 L 0 .034 .135 r
F
.62849 .43496 m .62709 .43335 L .62991 .43234 L F
.71022 .43281 m .71176 .43035 L .71309 .43196 L 0 .03 .13 r
F
.71022 .43281 m .70889 .43121 L .71176 .43035 L F
.87795 .43068 m .87972 .42805 L .8809 .42977 L 0 .025 .123 r
F
.87795 .43068 m .87677 .42895 L .87972 .42805 L F
.62145 .43539 m .62286 .43276 L .62427 .43437 L 0 .035 .136 r
F
.62145 .43539 m .62004 .4338 L .62286 .43276 L F
.2943 .43208 m .29524 .42949 L .29696 .43115 L 0 .028 .127 r
F
.2943 .43208 m .29259 .43042 L .29524 .42949 L F
.46076 .43718 m .46194 .43491 L .4635 .43649 L 0 .04 .142 r
F
.46076 .43718 m .4592 .43559 L .46194 .43491 L F
.26186 .43153 m .26276 .42886 L .26451 .43055 L 0 .027 .126 r
F
.26186 .43153 m .26012 .42984 L .26276 .42886 L F
.77083 .43194 m .77244 .4292 L .77372 .43093 L 0 .027 .127 r
F
.77083 .43194 m .76955 .43021 L .77244 .4292 L F
.41701 .43488 m .41813 .43229 L .41973 .43392 L 0 .034 .135 r
F
.41701 .43488 m .41541 .43323 L .41813 .43229 L F
.63554 .43468 m .63697 .43219 L .63836 .43376 L F
.63554 .43468 m .63414 .43308 L .63697 .43219 L F
.35917 .43333 m .3602 .43093 L .36185 .43265 L 0 .031 .131 r
F
.35917 .43333 m .35752 .43163 L .3602 .43093 L F
.93152 .43022 m .93338 .42766 L .9345 .4293 L 0 .024 .122 r
F
.93152 .43022 m .93041 .42859 L .93338 .42766 L F
.39161 .43393 m .39269 .4315 L .39432 .43304 L 0 .032 .133 r
F
.39161 .43393 m .38998 .43241 L .39269 .4315 L F
.50024 .43745 m .50148 .43497 L .503 .43666 L 0 .041 .143 r
F
.50024 .43745 m .49872 .43575 L .50148 .43497 L F
.33378 .43238 m .33476 .43004 L .33644 .43162 L 0 .029 .129 r
F
.33378 .43238 m .33209 .4308 L .33476 .43004 L F
.77788 .4316 m .7795 .42891 L .78077 .4306 L 0 .027 .126 r
F
.77788 .4316 m .77661 .42991 L .7795 .42891 L F
.61441 .4359 m .61581 .43318 L .61722 .43485 L 0 .036 .138 r
F
.61441 .4359 m .61299 .43423 L .61581 .43318 L F
.53268 .43807 m .53396 .43585 L .53546 .43726 L 0 .043 .145 r
F
.53268 .43807 m .53118 .43668 L .53396 .43585 L F
.42405 .43456 m .42517 .43217 L .42677 .43374 L 0 .034 .135 r
F
.42405 .43456 m .42245 .43296 L .42517 .43217 L F
.4424 .43595 m .44356 .43343 L .44513 .4352 L 0 .037 .138 r
F
.4424 .43595 m .44083 .43419 L .44356 .43343 L F
.88501 .4305 m .88679 .42784 L .88795 .4295 L 0 .025 .123 r
F
.88501 .4305 m .88384 .42883 L .88679 .42784 L F
.71727 .43265 m .71883 .43017 L .72014 .43173 L 0 .029 .129 r
F
.71727 .43265 m .71596 .43108 L .71883 .43017 L F
.64962 .43402 m .65108 .43154 L .65246 .43314 L 0 .033 .133 r
F
.64962 .43402 m .64824 .43245 L .65108 .43154 L F
.83145 .43109 m .83316 .42857 L .83438 .43025 L 0 .026 .125 r
F
.83145 .43109 m .83023 .42943 L .83316 .42857 L F
.64258 .43442 m .64402 .43185 L .64541 .43343 L 0 .033 .134 r
F
.64258 .43442 m .64119 .43282 L .64402 .43185 L F
.48188 .43618 m .48309 .43413 L .48463 .43554 L 0 .038 .14 r
F
.48188 .43618 m .48034 .43478 L .48309 .43413 L F
.30133 .43188 m .30228 .42926 L .30399 .43094 L 0 .028 .127 r
F
.30133 .43188 m .29962 .43022 L .30228 .42926 L F
.89206 .43014 m .89386 .4276 L .89501 .42924 L 0 .024 .123 r
F
.89206 .43014 m .8909 .42851 L .89386 .4276 L F
.4678 .437 m .46898 .43477 L .47054 .43616 L 0 .04 .142 r
F
.4678 .437 m .46624 .43563 L .46898 .43477 L F
.78493 .43134 m .78658 .42886 L .78783 .43047 L 0 .027 .126 r
F
.78493 .43134 m .78367 .42973 L .78658 .42886 L F
.54676 .43743 m .54807 .43526 L .54955 .43657 L 0 .041 .143 r
F
.54676 .43743 m .54528 .43609 L .54807 .43526 L F
.47484 .43665 m .47604 .43432 L .47759 .43571 L 0 .039 .141 r
F
.47484 .43665 m .47329 .43526 L .47604 .43432 L F
.53972 .43783 m .54102 .43561 L .5425 .43696 L 0 .042 .144 r
F
.53972 .43783 m .53823 .43645 L .54102 .43561 L F
.56085 .43667 m .56218 .43451 L .56364 .43585 L 0 .04 .141 r
F
.56085 .43667 m .55938 .43535 L .56218 .43451 L F
.72432 .43238 m .72588 .42988 L .72719 .43146 L 0 .029 .129 r
F
.72432 .43238 m .72301 .43082 L .72588 .42988 L F
.55381 .43708 m .55512 .43491 L .55659 .4362 L 0 .04 .142 r
F
.55381 .43708 m .55233 .43574 L .55512 .43491 L F
.9386 .43007 m .94046 .4275 L .94158 .4292 L 0 .024 .122 r
F
.9386 .43007 m .93748 .42838 L .94046 .4275 L F
.26888 .43146 m .26978 .42891 L .27151 .43066 L 0 .027 .126 r
F
.26888 .43146 m .26714 .42973 L .26978 .42891 L F
.30836 .43168 m .30933 .42903 L .31103 .43074 L 0 .027 .127 r
F
.30836 .43168 m .30666 .42998 L .30933 .42903 L F
.39864 .43388 m .39973 .43139 L .40135 .43305 L 0 .032 .133 r
F
.39864 .43388 m .39702 .4322 L .39973 .43139 L F
.79199 .43115 m .79364 .42858 L .79489 .43018 L 0 .026 .126 r
F
.79199 .43115 m .79074 .42955 L .79364 .42858 L F
.65668 .43392 m .65814 .43143 L .65952 .43309 L 0 .033 .133 r
F
.65668 .43392 m .6553 .43228 L .65814 .43143 L F
.50728 .43744 m .50853 .43494 L .51004 .43654 L 0 .041 .143 r
F
.50728 .43744 m .50576 .43579 L .50853 .43494 L F
.89913 .43002 m .90095 .4275 L .9021 .42916 L 0 .024 .123 r
F
.89913 .43002 m .89798 .42838 L .90095 .4275 L F
.56789 .43652 m .56923 .43415 L .57069 .43568 L 0 .039 .141 r
F
.56789 .43652 m .56643 .43502 L .56923 .43415 L F
.34079 .43243 m .34179 .42995 L .34347 .43156 L 0 .029 .129 r
F
.34079 .43243 m .33911 .43083 L .34179 .42995 L F
.23642 .43106 m .23729 .42841 L .23905 .43014 L 0 .026 .125 r
F
.23642 .43106 m .23466 .42932 L .23729 .42841 L F
.83852 .43106 m .84023 .42834 L .84144 .43006 L F
.83852 .43106 m .83731 .42934 L .84023 .42834 L F
.79904 .43087 m .80071 .42833 L .80195 .43 L F
.79904 .43087 m .79779 .42921 L .80071 .42833 L F
.73138 .43225 m .73295 .42965 L .73426 .43136 L 0 .029 .129 r
F
.73138 .43225 m .73007 .43055 L .73295 .42965 L F
.43108 .43465 m .43221 .43231 L .4338 .43393 L 0 .035 .136 r
F
.43108 .43465 m .42949 .43303 L .43221 .43231 L F
.84558 .43078 m .8473 .42813 L .84851 .42985 L 0 .026 .125 r
F
.84558 .43078 m .84437 .42906 L .8473 .42813 L F
.59607 .43508 m .59745 .43292 L .59888 .43429 L 0 .036 .138 r
F
.59607 .43508 m .59464 .43372 L .59745 .43292 L F
.44943 .43606 m .4506 .43351 L .45217 .43522 L 0 .038 .139 r
F
.44943 .43606 m .44786 .43435 L .4506 .43351 L F
.36619 .43355 m .36722 .43122 L .36887 .43279 L 0 .032 .133 r
F
.36619 .43355 m .36453 .43197 L .36722 .43122 L F
.94569 .43004 m .94756 .42748 L .94868 .42918 L 0 .024 .123 r
F
.94569 .43004 m .94457 .42834 L .94756 .42748 L F
.48892 .4363 m .49014 .43428 L .49167 .43565 L 0 .039 .141 r
F
.48892 .4363 m .48738 .43492 L .49014 .43428 L F
.90621 .42992 m .90802 .42728 L .90917 .42897 L 0 .024 .122 r
F
.90621 .42992 m .90506 .42822 L .90802 .42728 L F
.31538 .43168 m .31634 .42916 L .31804 .43091 L 0 .028 .128 r
F
.31538 .43168 m .31368 .42995 L .31634 .42916 L F
.51432 .43735 m .51558 .43502 L .51709 .43654 L 0 .041 .144 r
F
.51432 .43735 m .51281 .43578 L .51558 .43502 L F
.58903 .43561 m .5904 .43326 L .59183 .43462 L 0 .037 .139 r
F
.58903 .43561 m .58759 .43423 L .5904 .43326 L F
.24344 .43093 m .24431 .42835 L .24607 .43005 L 0 .026 .125 r
F
.24344 .43093 m .24168 .42922 L .24431 .42835 L F
.27588 .43153 m .27681 .42883 L .27854 .43058 L 0 .027 .127 r
F
.27588 .43153 m .27416 .42978 L .27681 .42883 L F
.34782 .43231 m .34883 .42985 L .3505 .4315 L 0 .03 .13 r
F
.34782 .43231 m .34615 .43069 L .34883 .42985 L F
.40567 .43388 m .40676 .43151 L .40838 .43314 L 0 .033 .134 r
F
.40567 .43388 m .40405 .43223 L .40676 .43151 L F
.85264 .4306 m .85438 .42802 L .85558 .42969 L 0 .026 .125 r
F
.85264 .4306 m .85144 .42894 L .85438 .42802 L F
.66374 .43393 m .66521 .43145 L .66658 .43311 L 0 .033 .134 r
F
.66374 .43393 m .66236 .43227 L .66521 .43145 L F
.57494 .43648 m .57629 .43393 L .57774 .43556 L 0 .039 .141 r
F
.57494 .43648 m .57349 .43484 L .57629 .43393 L F
.80611 .43086 m .80779 .42828 L .80903 .42999 L 0 .026 .125 r
F
.80611 .43086 m .80487 .42914 L .80779 .42828 L F
.73845 .43224 m .74003 .42968 L .74133 .4314 L 0 .029 .129 r
F
.73845 .43224 m .73714 .43052 L .74003 .42968 L F
.60312 .43499 m .60451 .43271 L .60593 .4342 L 0 .036 .138 r
F
.60312 .43499 m .60169 .4335 L .60451 .43271 L F
.67783 .43324 m .67932 .43063 L .68067 .43225 L 0 .032 .132 r
F
.67783 .43324 m .67647 .43166 L .67932 .43063 L F
.37322 .43344 m .37426 .43099 L .37591 .43252 L 0 .032 .133 r
F
.37322 .43344 m .37157 .43189 L .37426 .43099 L F
.58199 .43619 m .58334 .43363 L .58479 .43521 L 0 .038 .14 r
F
.58199 .43619 m .58054 .43459 L .58334 .43363 L F
.8597 .43034 m .86144 .42771 L .86263 .42936 L 0 .025 .124 r
F
.8597 .43034 m .85851 .4287 L .86144 .42771 L F
.91328 .42976 m .91511 .42718 L .91625 .42888 L 0 .024 .123 r
F
.91328 .42976 m .91213 .42806 L .91511 .42718 L F
.68488 .43292 m .68637 .43029 L .68773 .43197 L 0 .031 .131 r
F
.68488 .43292 m .68352 .43126 L .68637 .43029 L F
.28291 .43137 m .28384 .42875 L .28556 .43048 L 0 .028 .127 r
F
.28291 .43137 m .28119 .42963 L .28384 .42875 L F
.75255 .43158 m .75414 .42901 L .75543 .43064 L 0 .028 .128 r
F
.75255 .43158 m .75126 .42999 L .75414 .42901 L F
.86675 .43004 m .86851 .4274 L .86969 .42908 L 0 .025 .123 r
F
.86675 .43004 m .86557 .42838 L .86851 .4274 L F
.67079 .43381 m .67227 .43108 L .67363 .43273 L 0 .033 .134 r
F
.67079 .43381 m .66943 .43216 L .67227 .43108 L F
.52136 .43733 m .52263 .435 L .52414 .4366 L 0 .042 .144 r
F
.52136 .43733 m .51986 .43575 L .52263 .435 L F
.74551 .43208 m .74709 .42938 L .74838 .43103 L 0 .029 .129 r
F
.74551 .43208 m .74421 .43043 L .74709 .42938 L F
.49596 .4364 m .49719 .4343 L .49872 .43575 L 0 .04 .142 r
F
.49596 .4364 m .49443 .43498 L .49719 .4343 L F
.38025 .43328 m .3813 .43103 L .38294 .43256 L 0 .033 .133 r
F
.38025 .43328 m .37861 .43175 L .3813 .43103 L F
.69193 .4327 m .69344 .43006 L .69478 .43173 L 0 .031 .131 r
F
.69193 .4327 m .69058 .43102 L .69344 .43006 L F
.25045 .43095 m .25132 .42849 L .25307 .43015 L 0 .027 .126 r
F
.25045 .43095 m .24869 .42927 L .25132 .42849 L F
.7596 .43135 m .76121 .42875 L .76249 .43042 L 0 .028 .127 r
F
.7596 .43135 m .75832 .4297 L .76121 .42875 L F
.45646 .43624 m .45763 .43391 L .4592 .43559 L 0 .039 .141 r
F
.45646 .43624 m .4549 .43454 L .45763 .43391 L F
.4381 .4349 m .43925 .43242 L .44083 .43419 L 0 .036 .137 r
F
.4381 .4349 m .43652 .43317 L .43925 .43242 L F
.81319 .43081 m .81487 .42823 L .81611 .42991 L 0 .027 .126 r
F
.81319 .43081 m .81195 .42911 L .81487 .42823 L F
.35484 .43239 m .35586 .42993 L .35752 .43163 L 0 .03 .131 r
F
.35484 .43239 m .35318 .43072 L .35586 .42993 L F
.87382 .42986 m .87558 .42722 L .87677 .42895 L 0 .025 .123 r
F
.87382 .42986 m .87263 .42812 L .87558 .42722 L F
.32239 .43182 m .32338 .4291 L .32506 .43086 L 0 .029 .128 r
F
.32239 .43182 m .3207 .43006 L .32338 .4291 L F
.92036 .42968 m .9222 .42711 L .92333 .42878 L 0 .024 .123 r
F
.92036 .42968 m .91922 .428 L .9222 .42711 L F
.69898 .43243 m .70049 .42969 L .70183 .43139 L 0 .03 .13 r
F
.69898 .43243 m .69764 .43072 L .70049 .42969 L F
.70602 .43206 m .70756 .42952 L .70889 .43121 L F
.70602 .43206 m .70469 .43037 L .70756 .42952 L F
.41269 .43402 m .4138 .43164 L .41541 .43323 L 0 .034 .135 r
F
.41269 .43402 m .41108 .43241 L .4138 .43164 L F
.28993 .43132 m .29087 .42871 L .29259 .43042 L 0 .028 .127 r
F
.28993 .43132 m .28821 .4296 L .29087 .42871 L F
.82024 .43055 m .82194 .428 L .82316 .42961 L 0 .026 .125 r
F
.82024 .43055 m .81902 .42897 L .82194 .428 L F
.61017 .43508 m .61157 .43256 L .61299 .43423 L 0 .037 .138 r
F
.61017 .43508 m .60875 .43342 L .61157 .43256 L F
.76666 .43118 m .76827 .42849 L .76955 .43021 L 0 .027 .127 r
F
.76666 .43118 m .76538 .42945 L .76827 .42849 L F
.32942 .43161 m .33041 .4291 L .33209 .4308 L 0 .029 .129 r
F
.32942 .43161 m .32774 .4299 L .33041 .4291 L F
.63131 .43397 m .63274 .43148 L .63414 .43308 L 0 .034 .135 r
F
.63131 .43397 m .62991 .43234 L .63274 .43148 L F
.62427 .43437 m .62568 .43172 L .62709 .43335 L 0 .035 .136 r
F
.62427 .43437 m .62286 .43276 L .62568 .43172 L F
.25747 .43085 m .25836 .42822 L .26012 .42984 L 0 .027 .126 r
F
.25747 .43085 m .25572 .42921 L .25836 .42822 L F
.92743 .4295 m .92928 .42696 L .93041 .42859 L 0 .024 .123 r
F
.92743 .4295 m .92631 .42788 L .92928 .42696 L F
.8273 .43029 m .82901 .42779 L .83023 .42943 L 0 .026 .125 r
F
.8273 .43029 m .82608 .42866 L .82901 .42779 L F
.77372 .43093 m .77533 .42819 L .77661 .42991 L 0 .027 .126 r
F
.77372 .43093 m .77244 .4292 L .77533 .42819 L F
.8809 .42977 m .88267 .42712 L .88384 .42883 L 0 .025 .123 r
F
.8809 .42977 m .87972 .42805 L .88267 .42712 L F
.26451 .43055 m .2654 .42803 L .26714 .42973 L 0 .027 .126 r
F
.26451 .43055 m .26276 .42886 L .2654 .42803 L F
.61722 .43485 m .61862 .43213 L .62004 .4338 L 0 .036 .137 r
F
.61722 .43485 m .61581 .43318 L .61862 .43213 L F
.29696 .43115 m .29791 .42856 L .29962 .43022 L 0 .028 .127 r
F
.29696 .43115 m .29524 .42949 L .29791 .42856 L F
.38727 .43332 m .38834 .43088 L .38998 .43241 L 0 .033 .134 r
F
.38727 .43332 m .38564 .43181 L .38834 .43088 L F
.71309 .43196 m .71463 .42948 L .71596 .43108 L 0 .03 .13 r
F
.71309 .43196 m .71176 .43035 L .71463 .42948 L F
.41973 .43392 m .42085 .43136 L .42245 .43296 L 0 .034 .135 r
F
.41973 .43392 m .41813 .43229 L .42085 .43136 L F
.78077 .4306 m .78241 .42804 L .78367 .42973 L 0 .027 .126 r
F
.78077 .4306 m .7795 .42891 L .78241 .42804 L F
.63836 .43376 m .6398 .43128 L .64119 .43282 L 0 .034 .135 r
F
.63836 .43376 m .63697 .43219 L .6398 .43128 L F
.52841 .43749 m .52969 .43502 L .53118 .43668 L 0 .043 .145 r
F
.52841 .43749 m .52691 .43586 L .52969 .43502 L F
.9345 .4293 m .93636 .42673 L .93748 .42838 L 0 .024 .122 r
F
.9345 .4293 m .93338 .42766 L .93636 .42673 L F
.88795 .4295 m .88974 .42685 L .8909 .42851 L 0 .024 .123 r
F
.88795 .4295 m .88679 .42784 L .88974 .42685 L F
.64541 .43343 m .64686 .43088 L .64824 .43245 L 0 .033 .134 r
F
.64541 .43343 m .64402 .43185 L .64686 .43088 L F
.39432 .43304 m .39539 .43064 L .39702 .4322 L 0 .032 .133 r
F
.39432 .43304 m .39269 .4315 L .39539 .43064 L F
.30399 .43094 m .30495 .42828 L .30666 .42998 L 0 .027 .127 r
F
.30399 .43094 m .30228 .42926 L .30495 .42828 L F
.72014 .43173 m .7217 .42926 L .72301 .43082 L 0 .029 .129 r
F
.72014 .43173 m .71883 .43017 L .7217 .42926 L F
.65246 .43314 m .65392 .43065 L .6553 .43228 L 0 .033 .133 r
F
.65246 .43314 m .65108 .43154 L .65392 .43065 L F
.503 .43666 m .50424 .43414 L .50576 .43579 L 0 .041 .143 r
F
.503 .43666 m .50148 .43497 L .50424 .43414 L F
.89501 .42924 m .89683 .42673 L .89798 .42838 L 0 .024 .123 r
F
.89501 .42924 m .89386 .4276 L .89683 .42673 L F
.42677 .43374 m .42789 .43149 L .42949 .43303 L 0 .034 .135 r
F
.42677 .43374 m .42517 .43217 L .42789 .43149 L F
.53546 .43726 m .53674 .43502 L .53823 .43645 L 0 .043 .145 r
F
.53546 .43726 m .53396 .43585 L .53674 .43502 L F
.4635 .43649 m .46468 .43404 L .46624 .43563 L 0 .041 .143 r
F
.4635 .43649 m .46194 .43491 L .46468 .43404 L F
.47759 .43571 m .47879 .43337 L .48034 .43478 L 0 .039 .141 r
F
.47759 .43571 m .47604 .43432 L .47879 .43337 L F
.83438 .43025 m .83609 .42765 L .83731 .42934 L 0 .026 .125 r
F
.83438 .43025 m .83316 .42857 L .83609 .42765 L F
.33644 .43162 m .33743 .42924 L .33911 .43083 L 0 .029 .129 r
F
.33644 .43162 m .33476 .43004 L .33743 .42924 L F
.78783 .43047 m .78949 .42794 L .79074 .42955 L 0 .027 .126 r
F
.78783 .43047 m .78658 .42886 L .78949 .42794 L F
.72719 .43146 m .72876 .42893 L .73007 .43055 L 0 .029 .129 r
F
.72719 .43146 m .72588 .42988 L .72876 .42893 L F
.47054 .43616 m .47173 .43386 L .47329 .43526 L 0 .04 .142 r
F
.47054 .43616 m .46898 .43477 L .47173 .43386 L F
.36185 .43265 m .36288 .43023 L .36453 .43197 L 0 .032 .132 r
F
.36185 .43265 m .3602 .43093 L .36288 .43023 L F
.54955 .43657 m .55086 .43447 L .55233 .43574 L 0 .042 .144 r
F
.54955 .43657 m .54807 .43526 L .55086 .43447 L F
.44513 .4352 m .44629 .4326 L .44786 .43435 L 0 .037 .139 r
F
.44513 .4352 m .44356 .43343 L .44629 .4326 L F
.5425 .43696 m .5438 .43478 L .54528 .43609 L 0 .042 .145 r
F
.5425 .43696 m .54102 .43561 L .5438 .43478 L F
.55659 .4362 m .55792 .43404 L .55938 .43535 L 0 .041 .143 r
F
.55659 .4362 m .55512 .43491 L .55792 .43404 L F
.31103 .43074 m .31199 .42822 L .31368 .42995 L 0 .027 .127 r
F
.31103 .43074 m .30933 .42903 L .31199 .42822 L F
.94158 .4292 m .94345 .42664 L .94457 .42834 L 0 .024 .123 r
F
.94158 .4292 m .94046 .4275 L .94345 .42664 L F
.79489 .43018 m .79655 .42762 L .79779 .42921 L 0 .026 .125 r
F
.79489 .43018 m .79364 .42858 L .79655 .42762 L F
.56364 .43585 m .56497 .43364 L .56643 .43502 L 0 .04 .142 r
F
.56364 .43585 m .56218 .43451 L .56497 .43364 L F
.84144 .43006 m .84316 .42734 L .84437 .42906 L 0 .026 .125 r
F
.84144 .43006 m .84023 .42834 L .84316 .42734 L F
.48463 .43554 m .48584 .43352 L .48738 .43492 L 0 .039 .141 r
F
.48463 .43554 m .48309 .43413 L .48584 .43352 L F
.27151 .43066 m .27243 .42802 L .27416 .42978 L 0 .027 .127 r
F
.27151 .43066 m .26978 .42891 L .27243 .42802 L F
.51004 .43654 m .51129 .43424 L .51281 .43578 L 0 .041 .143 r
F
.51004 .43654 m .50853 .43494 L .51129 .43424 L F
.40135 .43305 m .40244 .43059 L .40405 .43223 L 0 .033 .134 r
F
.40135 .43305 m .39973 .43139 L .40244 .43059 L F
.9021 .42916 m .90391 .42657 L .90506 .42822 L 0 .024 .123 r
F
.9021 .42916 m .90095 .4275 L .90391 .42657 L F
.23905 .43014 m .23992 .42749 L .24168 .42922 L 0 .026 .125 r
F
.23905 .43014 m .23729 .42841 L .23992 .42749 L F
.65952 .43309 m .66099 .4306 L .66236 .43227 L 0 .033 .134 r
F
.65952 .43309 m .65814 .43143 L .66099 .4306 L F
.34347 .43156 m .34448 .42906 L .34615 .43069 L 0 .03 .13 r
F
.34347 .43156 m .34179 .42995 L .34448 .42906 L F
.73426 .43136 m .73583 .4288 L .73714 .43052 L 0 .029 .129 r
F
.73426 .43136 m .73295 .42965 L .73583 .4288 L F
.80195 .43 m .80362 .42746 L .80487 .42914 L 0 .026 .125 r
F
.80195 .43 m .80071 .42833 L .80362 .42746 L F
.57069 .43568 m .57203 .43327 L .57349 .43484 L 0 .039 .141 r
F
.57069 .43568 m .56923 .43415 L .57203 .43327 L F
.84851 .42985 m .85024 .42721 L .85144 .42894 L 0 .026 .125 r
F
.84851 .42985 m .8473 .42813 L .85024 .42721 L F
.59183 .43462 m .59321 .43236 L .59464 .43372 L 0 .037 .139 r
F
.59183 .43462 m .5904 .43326 L .59321 .43236 L F
.45217 .43522 m .45333 .43284 L .4549 .43454 L 0 .038 .14 r
F
.45217 .43522 m .4506 .43351 L .45333 .43284 L F
.90917 .42897 m .91099 .42637 L .91213 .42806 L 0 .024 .122 r
F
.90917 .42897 m .90802 .42728 L .91099 .42637 L F
.27854 .43058 m .27946 .42788 L .28119 .42963 L 0 .027 .127 r
F
.27854 .43058 m .27681 .42883 L .27946 .42788 L F
.59888 .43429 m .60027 .43211 L .60169 .4335 L 0 .037 .138 r
F
.59888 .43429 m .59745 .43292 L .60027 .43211 L F
.4338 .43393 m .43493 .43155 L .43652 .43317 L 0 .035 .137 r
F
.4338 .43393 m .43221 .43231 L .43493 .43155 L F
.36887 .43279 m .36991 .43034 L .37157 .43189 L 0 .033 .133 r
F
.36887 .43279 m .36722 .43122 L .36991 .43034 L F
.24607 .43005 m .24693 .42758 L .24869 .42927 L 0 .027 .126 r
F
.24607 .43005 m .24431 .42835 L .24693 .42758 L F
.85558 .42969 m .85732 .42703 L .85851 .4287 L 0 .026 .124 r
F
.85558 .42969 m .85438 .42802 L .85732 .42703 L F
.57774 .43556 m .57909 .43299 L .58054 .43459 L 0 .039 .141 r
F
.57774 .43556 m .57629 .43393 L .57909 .43299 L F
.51709 .43654 m .51835 .43425 L .51986 .43575 L 0 .042 .144 r
F
.51709 .43654 m .51558 .43502 L .51835 .43425 L F
.68067 .43225 m .68217 .4296 L .68352 .43126 L 0 .031 .132 r
F
.68067 .43225 m .67932 .43063 L .68217 .4296 L F
.58479 .43521 m .58615 .43268 L .58759 .43423 L 0 .038 .14 r
F
.58479 .43521 m .58334 .43363 L .58615 .43268 L F
.31804 .43091 m .31901 .4283 L .3207 .43006 L 0 .028 .128 r
F
.31804 .43091 m .31634 .42916 L .31901 .4283 L F
.3505 .4315 m .35151 .42904 L .35318 .43072 L 0 .03 .13 r
F
.3505 .4315 m .34883 .42985 L .35151 .42904 L F
.86263 .42936 m .86438 .42672 L .86557 .42838 L 0 .025 .124 r
F
.86263 .42936 m .86144 .42771 L .86438 .42672 L F
.37591 .43252 m .37696 .43022 L .37861 .43175 L 0 .032 .133 r
F
.37591 .43252 m .37426 .43099 L .37696 .43022 L F
.49167 .43565 m .49289 .43358 L .49443 .43498 L 0 .04 .142 r
F
.49167 .43565 m .49014 .43428 L .49289 .43358 L F
.66658 .43311 m .66806 .4305 L .66943 .43216 L 0 .033 .134 r
F
.66658 .43311 m .66521 .43145 L .66806 .4305 L F
.80903 .42999 m .81071 .42741 L .81195 .42911 L 0 .026 .126 r
F
.80903 .42999 m .80779 .42828 L .81071 .42741 L F
.67363 .43273 m .67511 .43001 L .67647 .43166 L 0 .032 .133 r
F
.67363 .43273 m .67227 .43108 L .67511 .43001 L F
.40838 .43314 m .40947 .43081 L .41108 .43241 L 0 .034 .135 r
F
.40838 .43314 m .40676 .43151 L .40947 .43081 L F
.68773 .43197 m .68923 .42935 L .69058 .43102 L 0 .031 .131 r
F
.68773 .43197 m .68637 .43029 L .68923 .42935 L F
.74133 .4314 m .74291 .42871 L .74421 .43043 L 0 .029 .129 r
F
.74133 .4314 m .74003 .42968 L .74291 .42871 L F
.91625 .42888 m .91808 .4263 L .91922 .428 L 0 .024 .123 r
F
.91625 .42888 m .91511 .42718 L .91808 .4263 L F
.75543 .43064 m .75703 .42804 L .75832 .4297 L 0 .028 .127 r
F
.75543 .43064 m .75414 .42901 L .75703 .42804 L F
.74838 .43103 m .74997 .42833 L .75126 .42999 L 0 .029 .128 r
F
.74838 .43103 m .74709 .42938 L .74997 .42833 L F
.86969 .42908 m .87145 .42642 L .87263 .42812 L 0 .025 .123 r
F
.86969 .42908 m .86851 .4274 L .87145 .42642 L F
.28556 .43048 m .28649 .42788 L .28821 .4296 L 0 .028 .127 r
F
.28556 .43048 m .28384 .42875 L .28649 .42788 L F
.60593 .4342 m .60733 .43191 L .60875 .43342 L 0 .037 .138 r
F
.60593 .4342 m .60451 .43271 L .60733 .43191 L F
.69478 .43173 m .69629 .42906 L .69764 .43072 L 0 .03 .13 r
F
.69478 .43173 m .69344 .43006 L .69629 .42906 L F
.70183 .43139 m .70335 .42868 L .70469 .43037 L F
.70183 .43139 m .70049 .42969 L .70335 .42868 L F
.76249 .43042 m .7641 .42779 L .76538 .42945 L 0 .028 .127 r
F
.76249 .43042 m .76121 .42875 L .7641 .42779 L F
.32506 .43086 m .32606 .42815 L .32774 .4299 L 0 .028 .128 r
F
.32506 .43086 m .32338 .4291 L .32606 .42815 L F
.81611 .42991 m .81779 .42729 L .81902 .42897 L 0 .027 .126 r
F
.81611 .42991 m .81487 .42823 L .81779 .42729 L F
.87677 .42895 m .87854 .42633 L .87972 .42805 L 0 .025 .123 r
F
.87677 .42895 m .87558 .42722 L .87854 .42633 L F
.52414 .4366 m .52541 .43424 L .52691 .43586 L 0 .043 .145 r
F
.52414 .4366 m .52263 .435 L .52541 .43424 L F
.92333 .42878 m .92518 .42621 L .92631 .42788 L 0 .024 .123 r
F
.92333 .42878 m .9222 .42711 L .92518 .42621 L F
.25307 .43015 m .25396 .42756 L .25572 .42921 L 0 .027 .127 r
F
.25307 .43015 m .25132 .42849 L .25396 .42756 L F
.82316 .42961 m .82486 .42704 L .82608 .42866 L 0 .026 .125 r
F
.82316 .42961 m .82194 .428 L .82486 .42704 L F
.76955 .43021 m .77116 .42748 L .77244 .4292 L 0 .027 .127 r
F
.76955 .43021 m .76827 .42849 L .77116 .42748 L F
.38294 .43256 m .384 .43029 L .38564 .43181 L 0 .033 .134 r
F
.38294 .43256 m .3813 .43103 L .384 .43029 L F
.29259 .43042 m .29353 .4278 L .29524 .42949 L 0 .028 .127 r
F
.29259 .43042 m .29087 .42871 L .29353 .4278 L F
.62709 .43335 m .6285 .43069 L .62991 .43234 L 0 .034 .135 r
F
.62709 .43335 m .62568 .43172 L .6285 .43069 L F
.70889 .43121 m .71043 .42867 L .71176 .43035 L 0 .03 .13 r
F
.70889 .43121 m .70756 .42952 L .71043 .42867 L F
.26012 .42984 m .26101 .42725 L .26276 .42886 L 0 .027 .126 r
F
.26012 .42984 m .25836 .42822 L .26101 .42725 L F
.35752 .43163 m .35854 .42921 L .3602 .43093 L 0 .031 .131 r
F
.35752 .43163 m .35586 .42993 L .35854 .42921 L F
.49872 .43575 m .49995 .43353 L .50148 .43497 L 0 .041 .143 r
F
.49872 .43575 m .49719 .4343 L .49995 .43353 L F
.44083 .43419 m .44198 .43165 L .44356 .43343 L 0 .037 .138 r
F
.44083 .43419 m .43925 .43242 L .44198 .43165 L F
.62004 .4338 m .62144 .43107 L .62286 .43276 L 0 .035 .137 r
F
.62004 .4338 m .61862 .43213 L .62144 .43107 L F
.41541 .43323 m .41652 .43073 L .41813 .43229 L 0 .034 .135 r
F
.41541 .43323 m .4138 .43164 L .41652 .43073 L F
.77661 .42991 m .77823 .42719 L .7795 .42891 L 0 .027 .126 r
F
.77661 .42991 m .77533 .42819 L .77823 .42719 L F
.4592 .43559 m .46037 .43324 L .46194 .43491 L 0 .04 .142 r
F
.4592 .43559 m .45763 .43391 L .46037 .43324 L F
.61299 .43423 m .61439 .43151 L .61581 .43318 L 0 .036 .138 r
F
.61299 .43423 m .61157 .43256 L .61439 .43151 L F
.63414 .43308 m .63557 .43062 L .63697 .43219 L 0 .034 .135 r
F
.63414 .43308 m .63274 .43148 L .63557 .43062 L F
.93041 .42859 m .93226 .42602 L .93338 .42766 L 0 .024 .123 r
F
.93041 .42859 m .92928 .42696 L .93226 .42602 L F
.88384 .42883 m .88562 .42614 L .88679 .42784 L 0 .025 .123 r
F
.88384 .42883 m .88267 .42712 L .88562 .42614 L F
.83023 .42943 m .83195 .42691 L .83316 .42857 L 0 .026 .125 r
F
.83023 .42943 m .82901 .42779 L .83195 .42691 L F
.33209 .4308 m .33308 .42834 L .33476 .43004 L 0 .029 .129 r
F
.33209 .4308 m .33041 .4291 L .33308 .42834 L F
.29962 .43022 m .30057 .4276 L .30228 .42926 L 0 .028 .127 r
F
.29962 .43022 m .29791 .42856 L .30057 .4276 L F
.42245 .43296 m .42357 .4306 L .42517 .43217 L 0 .034 .135 r
F
.42245 .43296 m .42085 .43136 L .42357 .4306 L F
.38998 .43241 m .39105 .42996 L .39269 .4315 L 0 .033 .134 r
F
.38998 .43241 m .38834 .43088 L .39105 .42996 L F
.8909 .42851 m .8927 .42594 L .89386 .4276 L 0 .024 .123 r
F
.8909 .42851 m .88974 .42685 L .8927 .42594 L F
.64119 .43282 m .64263 .43034 L .64402 .43185 L 0 .034 .135 r
F
.64119 .43282 m .6398 .43128 L .64263 .43034 L F
.71596 .43108 m .71751 .42858 L .71883 .43017 L 0 .03 .13 r
F
.71596 .43108 m .71463 .42948 L .71751 .42858 L F
.64824 .43245 m .64969 .42995 L .65108 .43154 L 0 .033 .134 r
F
.64824 .43245 m .64686 .43088 L .64969 .42995 L F
.78367 .42973 m .78532 .42718 L .78658 .42886 L 0 .027 .126 r
F
.78367 .42973 m .78241 .42804 L .78532 .42718 L F
.26714 .42973 m .26804 .4272 L .26978 .42891 L F
.26714 .42973 m .2654 .42803 L .26804 .4272 L F
.93748 .42838 m .93935 .42583 L .94046 .4275 L 0 .024 .122 r
F
.93748 .42838 m .93636 .42673 L .93935 .42583 L F
.30666 .42998 m .30762 .42731 L .30933 .42903 L 0 .027 .127 r
F
.30666 .42998 m .30495 .42828 L .30762 .42731 L F
.53118 .43668 m .53247 .43416 L .53396 .43585 L 0 .043 .145 r
F
.53118 .43668 m .52969 .43502 L .53247 .43416 L F
.72301 .43082 m .72457 .42829 L .72588 .42988 L 0 .029 .129 r
F
.72301 .43082 m .7217 .42926 L .72457 .42829 L F
.39702 .4322 m .3981 .42982 L .39973 .43139 L 0 .033 .133 r
F
.39702 .4322 m .39539 .43064 L .3981 .42982 L F
.48034 .43478 m .48154 .43271 L .48309 .43413 L 0 .039 .141 r
F
.48034 .43478 m .47879 .43337 L .48154 .43271 L F
.23466 .42932 m .23552 .42668 L .23729 .42841 L 0 .026 .125 r
F
.23466 .42932 m .23289 .42758 L .23552 .42668 L F
.83731 .42934 m .83902 .42664 L .84023 .42834 L F
.83731 .42934 m .83609 .42765 L .83902 .42664 L F
.50576 .43579 m .50701 .43333 L .50853 .43494 L 0 .041 .143 r
F
.50576 .43579 m .50424 .43414 L .50701 .43333 L F
.6553 .43228 m .65676 .42977 L .65814 .43143 L 0 .033 .133 r
F
.6553 .43228 m .65392 .43065 L .65676 .42977 L F
.79074 .42955 m .79239 .42698 L .79364 .42858 L 0 .027 .126 r
F
.79074 .42955 m .78949 .42794 L .79239 .42698 L F
.89798 .42838 m .89979 .42585 L .90095 .4275 L 0 .024 .123 r
F
.89798 .42838 m .89683 .42673 L .89979 .42585 L F
.46624 .43563 m .46743 .43318 L .46898 .43477 L 0 .041 .143 r
F
.46624 .43563 m .46468 .43404 L .46743 .43318 L F
.73007 .43055 m .73164 .42799 L .73295 .42965 L 0 .029 .129 r
F
.73007 .43055 m .72876 .42893 L .73164 .42799 L F
.47329 .43526 m .47448 .43292 L .47604 .43432 L 0 .04 .142 r
F
.47329 .43526 m .47173 .43386 L .47448 .43292 L F
.79779 .42921 m .79946 .42671 L .80071 .42833 L 0 .026 .125 r
F
.79779 .42921 m .79655 .42762 L .79946 .42671 L F
.53823 .43645 m .53953 .43422 L .54102 .43561 L 0 .043 .146 r
F
.53823 .43645 m .53674 .43502 L .53953 .43422 L F
.54528 .43609 m .54659 .43399 L .54807 .43526 L 0 .043 .145 r
F
.54528 .43609 m .5438 .43478 L .54659 .43399 L F
.84437 .42906 m .84609 .4264 L .8473 .42813 L 0 .026 .124 r
F
.84437 .42906 m .84316 .42734 L .84609 .4264 L F
.44786 .43435 m .44902 .43177 L .4506 .43351 L 0 .038 .139 r
F
.44786 .43435 m .44629 .4326 L .44902 .43177 L F
.33911 .43083 m .34012 .42833 L .34179 .42995 L 0 .03 .13 r
F
.33911 .43083 m .33743 .42924 L .34012 .42833 L F
.55233 .43574 m .55365 .43368 L .55512 .43491 L 0 .042 .144 r
F
.55233 .43574 m .55086 .43447 L .55365 .43368 L F
.55938 .43535 m .56071 .43316 L .56218 .43451 L 0 .041 .143 r
F
.55938 .43535 m .55792 .43404 L .56071 .43316 L F
.42949 .43303 m .43061 .4308 L .43221 .43231 L 0 .035 .136 r
F
.42949 .43303 m .42789 .43149 L .43061 .4308 L F
.94457 .42834 m .94645 .42578 L .94756 .42748 L 0 .024 .123 r
F
.94457 .42834 m .94345 .42664 L .94645 .42578 L F
.56643 .43502 m .56777 .43273 L .56923 .43415 L 0 .04 .142 r
F
.56643 .43502 m .56497 .43364 L .56777 .43273 L F
.31368 .42995 m .31465 .42741 L .31634 .42916 L 0 .028 .127 r
F
.31368 .42995 m .31199 .42822 L .31465 .42741 L F
.27416 .42978 m .27508 .42708 L .27681 .42883 L 0 .027 .127 r
F
.27416 .42978 m .27243 .42802 L .27508 .42708 L F
.90506 .42822 m .90687 .42563 L .90802 .42728 L 0 .024 .122 r
F
.90506 .42822 m .90391 .42657 L .90687 .42563 L F
.24168 .42922 m .24255 .42664 L .24431 .42835 L 0 .026 .125 r
F
.24168 .42922 m .23992 .42749 L .24255 .42664 L F
.36453 .43197 m .36557 .42947 L .36722 .43122 L 0 .032 .133 r
F
.36453 .43197 m .36288 .43023 L .36557 .42947 L F
.40405 .43223 m .40515 .42988 L .40676 .43151 L 0 .033 .134 r
F
.40405 .43223 m .40244 .43059 L .40515 .42988 L F
.34615 .43069 m .34716 .42819 L .34883 .42985 L 0 .03 .13 r
F
.34615 .43069 m .34448 .42906 L .34716 .42819 L F
.51281 .43578 m .51406 .43354 L .51558 .43502 L 0 .042 .144 r
F
.51281 .43578 m .51129 .43424 L .51406 .43354 L F
.85144 .42894 m .85318 .42628 L .85438 .42802 L 0 .026 .125 r
F
.85144 .42894 m .85024 .42721 L .85318 .42628 L F
.66236 .43227 m .66384 .42977 L .66521 .43145 L 0 .033 .134 r
F
.66236 .43227 m .66099 .4306 L .66384 .42977 L F
.80487 .42914 m .80655 .42659 L .80779 .42828 L 0 .026 .125 r
F
.80487 .42914 m .80362 .42746 L .80655 .42659 L F
.73714 .43052 m .73872 .42795 L .74003 .42968 L 0 .029 .129 r
F
.73714 .43052 m .73583 .4288 L .73872 .42795 L F
.57349 .43484 m .57483 .43237 L .57629 .43393 L 0 .039 .141 r
F
.57349 .43484 m .57203 .43327 L .57483 .43237 L F
.59464 .43372 m .59602 .43154 L .59745 .43292 L 0 .037 .139 r
F
.59464 .43372 m .59321 .43236 L .59602 .43154 L F
.91213 .42806 m .91396 .42548 L .91511 .42718 L 0 .024 .122 r
F
.91213 .42806 m .91099 .42637 L .91396 .42548 L F
.28119 .42963 m .28212 .42701 L .28384 .42875 L 0 .027 .127 r
F
.28119 .42963 m .27946 .42788 L .28212 .42701 L F
.48738 .43492 m .4886 .43287 L .49014 .43428 L 0 .04 .142 r
F
.48738 .43492 m .48584 .43352 L .4886 .43287 L F
.85851 .4287 m .86025 .42605 L .86144 .42771 L 0 .025 .124 r
F
.85851 .4287 m .85732 .42703 L .86025 .42605 L F
.68352 .43126 m .68502 .42861 L .68637 .43029 L 0 .031 .131 r
F
.68352 .43126 m .68217 .4296 L .68502 .42861 L F
.67647 .43166 m .67796 .42898 L .67932 .43063 L 0 .032 .132 r
F
.67647 .43166 m .67511 .43001 L .67796 .42898 L F
.58054 .43459 m .58189 .43205 L .58334 .43363 L 0 .039 .141 r
F
.58054 .43459 m .57909 .43299 L .58189 .43205 L F
.58759 .43423 m .58896 .43174 L .5904 .43326 L 0 .038 .14 r
F
.58759 .43423 m .58615 .43268 L .58896 .43174 L F
.37157 .43189 m .37261 .42945 L .37426 .43099 L 0 .033 .133 r
F
.37157 .43189 m .36991 .43034 L .37261 .42945 L F
.86557 .42838 m .86732 .42572 L .86851 .4274 L 0 .025 .123 r
F
.86557 .42838 m .86438 .42672 L .86732 .42572 L F
.60169 .4335 m .60309 .43131 L .60451 .43271 L 0 .037 .138 r
F
.60169 .4335 m .60027 .43211 L .60309 .43131 L F
.75126 .42999 m .75285 .42734 L .75414 .42901 L 0 .028 .128 r
F
.75126 .42999 m .74997 .42833 L .75285 .42734 L F
.66943 .43216 m .6709 .42943 L .67227 .43108 L 0 .033 .134 r
F
.66943 .43216 m .66806 .4305 L .6709 .42943 L F
.69058 .43102 m .69209 .42841 L .69344 .43006 L 0 .031 .131 r
F
.69058 .43102 m .68923 .42935 L .69209 .42841 L F
.4549 .43454 m .45607 .43222 L .45763 .43391 L 0 .039 .141 r
F
.4549 .43454 m .45333 .43284 L .45607 .43222 L F
.74421 .43043 m .74579 .42767 L .74709 .42938 L 0 .029 .129 r
F
.74421 .43043 m .74291 .42871 L .74579 .42767 L F
.43652 .43317 m .43766 .43078 L .43925 .43242 L 0 .036 .137 r
F
.43652 .43317 m .43493 .43155 L .43766 .43078 L F
.24869 .42927 m .24956 .42681 L .25132 .42849 L 0 .027 .126 r
F
.24869 .42927 m .24693 .42758 L .24956 .42681 L F
.3207 .43006 m .32169 .42734 L .32338 .4291 L 0 .028 .128 r
F
.3207 .43006 m .31901 .4283 L .32169 .42734 L F
.87263 .42812 m .8744 .42552 L .87558 .42722 L 0 .025 .123 r
F
.87263 .42812 m .87145 .42642 L .8744 .42552 L F
.51986 .43575 m .52112 .43347 L .52263 .435 L 0 .042 .145 r
F
.51986 .43575 m .51835 .43425 L .52112 .43347 L F
.75832 .4297 m .75992 .42707 L .76121 .42875 L 0 .028 .127 r
F
.75832 .4297 m .75703 .42804 L .75992 .42707 L F
.81195 .42911 m .81364 .42655 L .81487 .42823 L 0 .027 .126 r
F
.81195 .42911 m .81071 .42741 L .81364 .42655 L F
.35318 .43072 m .3542 .42823 L .35586 .42993 L 0 .03 .13 r
F
.35318 .43072 m .35151 .42904 L .3542 .42823 L F
.69764 .43072 m .69915 .42804 L .70049 .42969 L F
.69764 .43072 m .69629 .42906 L .69915 .42804 L F
.91922 .428 m .92106 .42542 L .9222 .42711 L 0 .024 .123 r
F
.91922 .428 m .91808 .4263 L .92106 .42542 L F
.70469 .43037 m .70622 .42783 L .70756 .42952 L 0 .029 .129 r
F
.70469 .43037 m .70335 .42868 L .70622 .42783 L F
.37861 .43175 m .37965 .42951 L .3813 .43103 L 0 .033 .134 r
F
.37861 .43175 m .37696 .43022 L .37965 .42951 L F
.28821 .4296 m .28915 .427 L .29087 .42871 L 0 .028 .127 r
F
.28821 .4296 m .28649 .42788 L .28915 .427 L F
.76538 .42945 m .76699 .42682 L .76827 .42849 L 0 .027 .127 r
F
.76538 .42945 m .7641 .42779 L .76699 .42682 L F
.41108 .43241 m .41219 .43006 L .4138 .43164 L 0 .034 .136 r
F
.41108 .43241 m .40947 .43081 L .41219 .43006 L F
.49443 .43498 m .49565 .43288 L .49719 .4343 L 0 .041 .143 r
F
.49443 .43498 m .49289 .43358 L .49565 .43288 L F
.60875 .43342 m .61015 .43105 L .61157 .43256 L 0 .037 .138 r
F
.60875 .43342 m .60733 .43191 L .61015 .43105 L F
.32774 .4299 m .32873 .42736 L .33041 .4291 L 0 .029 .128 r
F
.32774 .4299 m .32606 .42815 L .32873 .42736 L F
.81902 .42897 m .82071 .42631 L .82194 .428 L 0 .026 .126 r
F
.81902 .42897 m .81779 .42729 L .82071 .42631 L F
.77244 .4292 m .77406 .42647 L .77533 .42819 L 0 .027 .126 r
F
.77244 .4292 m .77116 .42748 L .77406 .42647 L F
.62991 .43234 m .63134 .42986 L .63274 .43148 L 0 .034 .135 r
F
.62991 .43234 m .6285 .43069 L .63134 .42986 L F
.25572 .42921 m .25661 .42659 L .25836 .42822 L 0 .027 .126 r
F
.25572 .42921 m .25396 .42756 L .25661 .42659 L F
.87972 .42805 m .88149 .42541 L .88267 .42712 L 0 .025 .123 r
F
.87972 .42805 m .87854 .42633 L .88149 .42541 L F
.62286 .43276 m .62427 .43002 L .62568 .43172 L 0 .035 .136 r
F
.62286 .43276 m .62144 .43107 L .62427 .43002 L F
.92631 .42788 m .92816 .4253 L .92928 .42696 L 0 .024 .123 r
F
.92631 .42788 m .92518 .42621 L .92816 .4253 L F
.82608 .42866 m .82779 .42614 L .82901 .42779 L 0 .026 .125 r
F
.82608 .42866 m .82486 .42704 L .82779 .42614 L F
.26276 .42886 m .26365 .42643 L .2654 .42803 L 0 .027 .126 r
F
.26276 .42886 m .26101 .42725 L .26365 .42643 L F
.61581 .43318 m .61721 .43045 L .61862 .43213 L 0 .036 .137 r
F
.61581 .43318 m .61439 .43151 L .61721 .43045 L F
.29524 .42949 m .29619 .42689 L .29791 .42856 L 0 .028 .127 r
F
.29524 .42949 m .29353 .4278 L .29619 .42689 L F
.7795 .42891 m .78114 .42633 L .78241 .42804 L 0 .027 .126 r
F
.7795 .42891 m .77823 .42719 L .78114 .42633 L F
.41813 .43229 m .41924 .42981 L .42085 .43136 L 0 .034 .135 r
F
.41813 .43229 m .41652 .43073 L .41924 .42981 L F
.71176 .43035 m .71331 .42781 L .71463 .42948 L 0 .03 .13 r
F
.71176 .43035 m .71043 .42867 L .71331 .42781 L F
.88679 .42784 m .88857 .42515 L .88974 .42685 L 0 .024 .123 r
F
.88679 .42784 m .88562 .42614 L .88857 .42515 L F
.52691 .43586 m .52819 .43337 L .52969 .43502 L 0 .043 .145 r
F
.52691 .43586 m .52541 .43424 L .52819 .43337 L F
.93338 .42766 m .93524 .42507 L .93636 .42673 L 0 .024 .122 r
F
.93338 .42766 m .93226 .42602 L .93524 .42507 L F
.63697 .43219 m .63841 .42975 L .6398 .43128 L 0 .034 .135 r
F
.63697 .43219 m .63557 .43062 L .63841 .42975 L F
.30228 .42926 m .30324 .42662 L .30495 .42828 L 0 .027 .127 r
F
.30228 .42926 m .30057 .4276 L .30324 .42662 L F
.38564 .43181 m .38671 .42934 L .38834 .43088 L 0 .033 .134 r
F
.38564 .43181 m .384 .43029 L .38671 .42934 L F
.50148 .43497 m .50271 .43272 L .50424 .43414 L 0 .041 .143 r
F
.50148 .43497 m .49995 .43353 L .50271 .43272 L F
.64402 .43185 m .64547 .4294 L .64686 .43088 L 0 .033 .134 r
F
.64402 .43185 m .64263 .43034 L .64547 .4294 L F
.44356 .43343 m .44471 .43084 L .44629 .4326 L 0 .037 .138 r
F
.44356 .43343 m .44198 .43165 L .44471 .43084 L F
.39269 .4315 m .39376 .42907 L .39539 .43064 L 0 .033 .134 r
F
.39269 .4315 m .39105 .42996 L .39376 .42907 L F
.83316 .42857 m .83488 .42597 L .83609 .42765 L 0 .026 .125 r
F
.83316 .42857 m .83195 .42691 L .83488 .42597 L F
.89386 .4276 m .89567 .42506 L .89683 .42673 L 0 .024 .123 r
F
.89386 .4276 m .8927 .42594 L .89567 .42506 L F
.3602 .43093 m .36123 .42849 L .36288 .43023 L 0 .032 .132 r
F
.3602 .43093 m .35854 .42921 L .36123 .42849 L F
.71883 .43017 m .72038 .42768 L .7217 .42926 L 0 .03 .13 r
F
.71883 .43017 m .71751 .42858 L .72038 .42768 L F
.65108 .43154 m .65253 .42903 L .65392 .43065 L 0 .033 .134 r
F
.65108 .43154 m .64969 .42995 L .65253 .42903 L F
.30933 .42903 m .31029 .42649 L .31199 .42822 L 0 .027 .127 r
F
.30933 .42903 m .30762 .42731 L .31029 .42649 L F
.46194 .43491 m .46312 .43236 L .46468 .43404 L 0 .041 .143 r
F
.46194 .43491 m .46037 .43324 L .46312 .43236 L F
.42517 .43217 m .42629 .42995 L .42789 .43149 L 0 .035 .136 r
F
.42517 .43217 m .42357 .4306 L .42629 .42995 L F
.78658 .42886 m .78823 .42627 L .78949 .42794 L 0 .027 .126 r
F
.78658 .42886 m .78532 .42718 L .78823 .42627 L F
.33476 .43004 m .33575 .42755 L .33743 .42924 L 0 .03 .13 r
F
.33476 .43004 m .33308 .42834 L .33575 .42755 L F
.94046 .4275 m .94234 .42495 L .94345 .42664 L 0 .024 .122 r
F
.94046 .4275 m .93935 .42583 L .94234 .42495 L F
.72588 .42988 m .72745 .4273 L .72876 .42893 L 0 .029 .129 r
F
.72588 .42988 m .72457 .42829 L .72745 .4273 L F
.26978 .42891 m .27069 .42631 L .27243 .42802 L 0 .027 .126 r
F
.26978 .42891 m .26804 .4272 L .27069 .42631 L F
.84023 .42834 m .84195 .42564 L .84316 .42734 L 0 .026 .125 r
F
.84023 .42834 m .83902 .42664 L .84195 .42564 L F
.79364 .42858 m .7953 .42602 L .79655 .42762 L 0 .026 .126 r
F
.79364 .42858 m .79239 .42698 L .7953 .42602 L F
.23729 .42841 m .23815 .42577 L .23992 .42749 L 0 .026 .125 r
F
.23729 .42841 m .23552 .42668 L .23815 .42577 L F
.53396 .43585 m .53525 .43332 L .53674 .43502 L 0 .043 .146 r
F
.53396 .43585 m .53247 .43416 L .53525 .43332 L F
.47604 .43432 m .47724 .43197 L .47879 .43337 L 0 .04 .142 r
F
.47604 .43432 m .47448 .43292 L .47724 .43197 L F
.39973 .43139 m .40081 .429 L .40244 .43059 L 0 .033 .134 r
F
.39973 .43139 m .3981 .42982 L .40081 .429 L F
.73295 .42965 m .73452 .42712 L .73583 .4288 L 0 .029 .129 r
F
.73295 .42965 m .73164 .42799 L .73452 .42712 L F
.50853 .43494 m .50978 .43269 L .51129 .43424 L 0 .042 .144 r
F
.50853 .43494 m .50701 .43333 L .50978 .43269 L F
.90095 .4275 m .90276 .42492 L .90391 .42657 L 0 .024 .123 r
F
.90095 .4275 m .89979 .42585 L .90276 .42492 L F
.65814 .43143 m .65961 .42892 L .66099 .4306 L 0 .033 .134 r
F
.65814 .43143 m .65676 .42977 L .65961 .42892 L F
.46898 .43477 m .47018 .43228 L .47173 .43386 L 0 .041 .143 r
F
.46898 .43477 m .46743 .43318 L .47018 .43228 L F
.8473 .42813 m .84903 .42547 L .85024 .42721 L 0 .026 .124 r
F
.8473 .42813 m .84609 .4264 L .84903 .42547 L F
.80071 .42833 m .80238 .42581 L .80362 .42746 L 0 .026 .125 r
F
.80071 .42833 m .79946 .42671 L .80238 .42581 L F
.54102 .43561 m .54232 .43342 L .5438 .43478 L 0 .044 .146 r
F
.54102 .43561 m .53953 .43422 L .54232 .43342 L F
.34179 .42995 m .3428 .42742 L .34448 .42906 L 0 .03 .13 r
F
.34179 .42995 m .34012 .42833 L .3428 .42742 L F
.54807 .43526 m .54938 .43323 L .55086 .43447 L 0 .043 .145 r
F
.54807 .43526 m .54659 .43399 L .54938 .43323 L F
.4506 .43351 m .45176 .43113 L .45333 .43284 L 0 .038 .14 r
F
.4506 .43351 m .44902 .43177 L .45176 .43113 L F
.27681 .42883 m .27774 .42613 L .27946 .42788 L 0 .027 .126 r
F
.27681 .42883 m .27508 .42708 L .27774 .42613 L F
.56218 .43451 m .56351 .43225 L .56497 .43364 L 0 .041 .143 r
F
.56218 .43451 m .56071 .43316 L .56351 .43225 L F
.90802 .42728 m .90984 .42471 L .91099 .42637 L 0 .024 .122 r
F
.90802 .42728 m .90687 .42563 L .90984 .42471 L F
.55512 .43491 m .55644 .43277 L .55792 .43404 L 0 .042 .144 r
F
.55512 .43491 m .55365 .43368 L .55644 .43277 L F
.48309 .43413 m .48429 .43207 L .48584 .43352 L 0 .04 .142 r
F
.48309 .43413 m .48154 .43271 L .48429 .43207 L F
.56923 .43415 m .57057 .43182 L .57203 .43327 L F
.56923 .43415 m .56777 .43273 L .57057 .43182 L F
.24431 .42835 m .24517 .42589 L .24693 .42758 L 0 .027 .126 r
F
.24431 .42835 m .24255 .42664 L .24517 .42589 L F
.31634 .42916 m .31732 .42654 L .31901 .4283 L 0 .028 .128 r
F
.31634 .42916 m .31465 .42741 L .31732 .42654 L F
.43221 .43231 m .43334 .43004 L .43493 .43155 L 0 .036 .137 r
F
.43221 .43231 m .43061 .4308 L .43334 .43004 L F
.85438 .42802 m .85612 .42531 L .85732 .42703 L 0 .026 .124 r
F
.85438 .42802 m .85318 .42628 L .85612 .42531 L F
.57629 .43393 m .57764 .43147 L .57909 .43299 L 0 .039 .141 r
F
.57629 .43393 m .57483 .43237 L .57764 .43147 L F
.67932 .43063 m .68081 .42794 L .68217 .4296 L 0 .031 .132 r
F
.67932 .43063 m .67796 .42898 L .68081 .42794 L F
.80779 .42828 m .80947 .42572 L .81071 .42741 L 0 .026 .125 r
F
.80779 .42828 m .80655 .42659 L .80947 .42572 L F
.36722 .43122 m .36827 .42858 L .36991 .43034 L 0 .033 .133 r
F
.36722 .43122 m .36557 .42947 L .36827 .42858 L F
.34883 .42985 m .34985 .42735 L .35151 .42904 L 0 .03 .13 r
F
.34883 .42985 m .34716 .42819 L .34985 .42735 L F
.86144 .42771 m .86319 .42505 L .86438 .42672 L 0 .025 .124 r
F
.86144 .42771 m .86025 .42605 L .86319 .42505 L F
.74003 .42968 m .7416 .42699 L .74291 .42871 L 0 .029 .129 r
F
.74003 .42968 m .73872 .42795 L .7416 .42699 L F
.66521 .43145 m .66668 .42882 L .66806 .4305 L 0 .033 .134 r
F
.66521 .43145 m .66384 .42977 L .66668 .42882 L F
.68637 .43029 m .68788 .42768 L .68923 .42935 L 0 .031 .131 r
F
.68637 .43029 m .68502 .42861 L .68788 .42768 L F
.67227 .43108 m .67375 .42836 L .67511 .43001 L 0 .032 .133 r
F
.67227 .43108 m .6709 .42943 L .67375 .42836 L F
.58334 .43363 m .5847 .43113 L .58615 .43268 L 0 .039 .14 r
F
.58334 .43363 m .58189 .43205 L .5847 .43113 L F
.91511 .42718 m .91694 .4246 L .91808 .4263 L 0 .024 .123 r
F
.91511 .42718 m .91396 .42548 L .91694 .4246 L F
.28384 .42875 m .28477 .42615 L .28649 .42788 L 0 .027 .127 r
F
.28384 .42875 m .28212 .42701 L .28477 .42615 L F
.5904 .43326 m .59177 .43084 L .59321 .43236 L 0 .038 .14 r
F
.5904 .43326 m .58896 .43174 L .59177 .43084 L F
.51558 .43502 m .51684 .4328 L .51835 .43425 L 0 .043 .145 r
F
.51558 .43502 m .51406 .43354 L .51684 .4328 L F
.86851 .4274 m .87026 .42472 L .87145 .42642 L 0 .025 .123 r
F
.86851 .4274 m .86732 .42572 L .87026 .42472 L F
.40676 .43151 m .40786 .42919 L .40947 .43081 L 0 .034 .135 r
F
.40676 .43151 m .40515 .42988 L .40786 .42919 L F
.74709 .42938 m .74867 .42663 L .74997 .42833 L 0 .029 .128 r
F
.74709 .42938 m .74579 .42767 L .74867 .42663 L F
.59745 .43292 m .59884 .43072 L .60027 .43211 L 0 .038 .139 r
F
.59745 .43292 m .59602 .43154 L .59884 .43072 L F
.75414 .42901 m .75574 .42635 L .75703 .42804 L 0 .028 .128 r
F
.75414 .42901 m .75285 .42734 L .75574 .42635 L F
.37426 .43099 m .37531 .42869 L .37696 .43022 L 0 .033 .134 r
F
.37426 .43099 m .37261 .42945 L .37531 .42869 L F
.69344 .43006 m .69495 .42742 L .69629 .42906 L 0 .03 .131 r
F
.69344 .43006 m .69209 .42841 L .69495 .42742 L F
.70049 .42969 m .70201 .42703 L .70335 .42868 L 0 .029 .129 r
F
.70049 .42969 m .69915 .42804 L .70201 .42703 L F
.32338 .4291 m .32437 .42639 L .32606 .42815 L 0 .028 .128 r
F
.32338 .4291 m .32169 .42734 L .32437 .42639 L F
.76121 .42875 m .76282 .42611 L .7641 .42779 L 0 .028 .127 r
F
.76121 .42875 m .75992 .42707 L .76282 .42611 L F
.87558 .42722 m .87736 .42463 L .87854 .42633 L 0 .025 .123 r
F
.87558 .42722 m .8744 .42552 L .87736 .42463 L F
.60451 .43271 m .60591 .4305 L .60733 .43191 L 0 .037 .139 r
F
.60451 .43271 m .60309 .43131 L .60591 .4305 L F
.49014 .43428 m .49135 .43214 L .49289 .43358 L 0 .041 .143 r
F
.49014 .43428 m .4886 .43287 L .49135 .43214 L F
.81487 .42823 m .81656 .4256 L .81779 .42729 L 0 .027 .126 r
F
.81487 .42823 m .81364 .42655 L .81656 .4256 L F
.9222 .42711 m .92405 .42454 L .92518 .42621 L 0 .024 .123 r
F
.9222 .42711 m .92106 .42542 L .92405 .42454 L F
.76827 .42849 m .76989 .42581 L .77116 .42748 L 0 .027 .126 r
F
.76827 .42849 m .76699 .42682 L .76989 .42581 L F
.25132 .42849 m .2522 .4259 L .25396 .42756 L 0 .027 .127 r
F
.25132 .42849 m .24956 .42681 L .2522 .4259 L F
.43925 .43242 m .44039 .43 L .44198 .43165 L 0 .036 .138 r
F
.43925 .43242 m .43766 .43078 L .44039 .43 L F
.29087 .42871 m .29181 .42612 L .29353 .4278 L 0 .028 .127 r
F
.29087 .42871 m .28915 .427 L .29181 .42612 L F
.52263 .435 m .5239 .43269 L .52541 .43424 L 0 .043 .145 r
F
.52263 .435 m .52112 .43347 L .5239 .43269 L F
.70756 .42952 m .7091 .42699 L .71043 .42867 L 0 .03 .13 r
F
.70756 .42952 m .70622 .42783 L .7091 .42699 L F
.35586 .42993 m .35689 .42748 L .35854 .42921 L 0 .031 .131 r
F
.35586 .42993 m .3542 .42823 L .35689 .42748 L F
.77533 .42819 m .77696 .42548 L .77823 .42719 L 0 .027 .126 r
F
.77533 .42819 m .77406 .42647 L .77696 .42548 L F
.82194 .428 m .82364 .42534 L .82486 .42704 L 0 .026 .125 r
F
.82194 .428 m .82071 .42631 L .82364 .42534 L F
.62568 .43172 m .62709 .42898 L .6285 .43069 L 0 .034 .135 r
F
.62568 .43172 m .62427 .43002 L .62709 .42898 L F
.61862 .43213 m .62003 .42939 L .62144 .43107 L 0 .035 .136 r
F
.61862 .43213 m .61721 .43045 L .62003 .42939 L F
.25836 .42822 m .25925 .42563 L .26101 .42725 L 0 .027 .126 r
F
.25836 .42822 m .25661 .42659 L .25925 .42563 L F
.45763 .43391 m .45881 .43156 L .46037 .43324 L 0 .04 .142 r
F
.45763 .43391 m .45607 .43222 L .45881 .43156 L F
.61157 .43256 m .61297 .43 L .61439 .43151 L 0 .037 .138 r
F
.61157 .43256 m .61015 .43105 L .61297 .43 L F
.88267 .42712 m .88445 .42443 L .88562 .42614 L 0 .024 .123 r
F
.88267 .42712 m .88149 .42541 L .88445 .42443 L F
.3813 .43103 m .38235 .42876 L .384 .43029 L 0 .034 .135 r
F
.3813 .43103 m .37965 .42951 L .38235 .42876 L F
.4138 .43164 m .41491 .42917 L .41652 .43073 L 0 .035 .136 r
F
.4138 .43164 m .41219 .43006 L .41491 .42917 L F
.33041 .4291 m .3314 .4266 L .33308 .42834 L 0 .029 .129 r
F
.33041 .4291 m .32873 .42736 L .3314 .4266 L F
.92928 .42696 m .93114 .42435 L .93226 .42602 L 0 .024 .123 r
F
.92928 .42696 m .92816 .4253 L .93114 .42435 L F
.63274 .43148 m .63417 .42903 L .63557 .43062 L 0 .034 .135 r
F
.63274 .43148 m .63134 .42986 L .63417 .42903 L F
.29791 .42856 m .29886 .42595 L .30057 .4276 L 0 .028 .127 r
F
.29791 .42856 m .29619 .42689 L .29886 .42595 L F
.82901 .42779 m .83073 .42525 L .83195 .42691 L 0 .026 .125 r
F
.82901 .42779 m .82779 .42614 L .83073 .42525 L F
.88974 .42685 m .89154 .42425 L .8927 .42594 L 0 .024 .123 r
F
.88974 .42685 m .88857 .42515 L .89154 .42425 L F
.2654 .42803 m .26629 .4256 L .26804 .4272 L 0 .027 .126 r
F
.2654 .42803 m .26365 .42643 L .26629 .4256 L F
.42085 .43136 m .42196 .42908 L .42357 .4306 L 0 .034 .136 r
F
.42085 .43136 m .41924 .42981 L .42196 .42908 L F
.49719 .4343 m .49842 .43211 L .49995 .43353 L 0 .042 .144 r
F
.49719 .4343 m .49565 .43288 L .49842 .43211 L F
.78241 .42804 m .78405 .42547 L .78532 .42718 L 0 .027 .126 r
F
.78241 .42804 m .78114 .42633 L .78405 .42547 L F
.30495 .42828 m .30592 .42564 L .30762 .42731 L F
.30495 .42828 m .30324 .42662 L .30592 .42564 L F
.93636 .42673 m .93823 .42416 L .93935 .42583 L 0 .024 .122 r
F
.93636 .42673 m .93524 .42507 L .93823 .42416 L F
.71463 .42948 m .71618 .42693 L .71751 .42858 L 0 .03 .13 r
F
.71463 .42948 m .71331 .42781 L .71618 .42693 L F
.64686 .43088 m .64831 .42846 L .64969 .42995 L 0 .033 .134 r
F
.64686 .43088 m .64547 .4294 L .64831 .42846 L F
.38834 .43088 m .38942 .42839 L .39105 .42996 L F
.38834 .43088 m .38671 .42934 L .38942 .42839 L F
.6398 .43128 m .64124 .42885 L .64263 .43034 L 0 .034 .135 r
F
.6398 .43128 m .63841 .42975 L .64124 .42885 L F
.23289 .42758 m .23374 .42507 L .23552 .42668 L 0 .026 .125 r
F
.23289 .42758 m .2311 .42599 L .23374 .42507 L F
.52969 .43502 m .53097 .43247 L .53247 .43416 L 0 .043 .145 r
F
.52969 .43502 m .52819 .43337 L .53097 .43247 L F
.83609 .42765 m .8378 .42496 L .83902 .42664 L 0 .026 .125 r
F
.83609 .42765 m .83488 .42597 L .8378 .42496 L F
.50424 .43414 m .50548 .43193 L .50701 .43333 L 0 .042 .144 r
F
.50424 .43414 m .50271 .43272 L .50548 .43193 L F
.7217 .42926 m .72326 .42669 L .72457 .42829 L 0 .03 .13 r
F
.7217 .42926 m .72038 .42768 L .72326 .42669 L F
.39539 .43064 m .39648 .42824 L .3981 .42982 L 0 .033 .134 r
F
.39539 .43064 m .39376 .42907 L .39648 .42824 L F
.44629 .4326 m .44745 .43003 L .44902 .43177 L 0 .037 .139 r
F
.44629 .4326 m .44471 .43084 L .44745 .43003 L F
.89683 .42673 m .89864 .42418 L .89979 .42585 L 0 .024 .123 r
F
.89683 .42673 m .89567 .42506 L .89864 .42418 L F
.65392 .43065 m .65538 .42811 L .65676 .42977 L 0 .033 .134 r
F
.65392 .43065 m .65253 .42903 L .65538 .42811 L F
.84316 .42734 m .84488 .42468 L .84609 .4264 L 0 .025 .124 r
F
.84316 .42734 m .84195 .42564 L .84488 .42468 L F
.78949 .42794 m .79114 .42532 L .79239 .42698 L 0 .027 .126 r
F
.78949 .42794 m .78823 .42627 L .79114 .42532 L F
.72876 .42893 m .73033 .42634 L .73164 .42799 L 0 .029 .129 r
F
.72876 .42893 m .72745 .4273 L .73033 .42634 L F
.46468 .43404 m .46587 .43148 L .46743 .43318 L 0 .041 .143 r
F
.46468 .43404 m .46312 .43236 L .46587 .43148 L F
.94345 .42664 m .94533 .42408 L .94645 .42578 L 0 .024 .123 r
F
.94345 .42664 m .94234 .42495 L .94533 .42408 L F
.79655 .42762 m .79822 .42509 L .79946 .42671 L 0 .026 .125 r
F
.79655 .42762 m .7953 .42602 L .79822 .42509 L F
.27243 .42802 m .27334 .42536 L .27508 .42708 L 0 .027 .126 r
F
.27243 .42802 m .27069 .42631 L .27334 .42536 L F
.31199 .42822 m .31295 .42566 L .31465 .42741 L 0 .028 .127 r
F
.31199 .42822 m .31029 .42649 L .31295 .42566 L F
.33743 .42924 m .33844 .42664 L .34012 .42833 L 0 .03 .13 r
F
.33743 .42924 m .33575 .42755 L .33844 .42664 L F
.36288 .43023 m .36392 .42771 L .36557 .42947 L 0 .032 .133 r
F
.36288 .43023 m .36123 .42849 L .36392 .42771 L F
.23992 .42749 m .24078 .42493 L .24255 .42664 L 0 .026 .125 r
F
.23992 .42749 m .23815 .42577 L .24078 .42493 L F
.47879 .43337 m .47999 .43128 L .48154 .43271 L 0 .04 .142 r
F
.47879 .43337 m .47724 .43197 L .47999 .43128 L F
.90391 .42657 m .90573 .42398 L .90687 .42563 L 0 .024 .123 r
F
.90391 .42657 m .90276 .42492 L .90573 .42398 L F
.42789 .43149 m .42901 .42929 L .43061 .4308 L 0 .036 .137 r
F
.42789 .43149 m .42629 .42995 L .42901 .42929 L F
.53674 .43502 m .53804 .43257 L .53953 .43422 L 0 .044 .146 r
F
.53674 .43502 m .53525 .43332 L .53804 .43257 L F
.85024 .42721 m .85197 .42453 L .85318 .42628 L 0 .025 .124 r
F
.85024 .42721 m .84903 .42547 L .85197 .42453 L F
.47173 .43386 m .47293 .43136 L .47448 .43292 L 0 .041 .143 r
F
.47173 .43386 m .47018 .43228 L .47293 .43136 L F
.73583 .4288 m .73741 .42624 L .73872 .42795 L 0 .029 .129 r
F
.73583 .4288 m .73452 .42712 L .73741 .42624 L F
.40244 .43059 m .40353 .42825 L .40515 .42988 L 0 .033 .134 r
F
.40244 .43059 m .40081 .429 L .40353 .42825 L F
.80362 .42746 m .8053 .42492 L .80655 .42659 L 0 .026 .125 r
F
.80362 .42746 m .80238 .42581 L .8053 .42492 L F
.66099 .4306 m .66246 .42808 L .66384 .42977 L 0 .033 .134 r
F
.66099 .4306 m .65961 .42892 L .66246 .42808 L F
.27946 .42788 m .28039 .42527 L .28212 .42701 L 0 .027 .126 r
F
.27946 .42788 m .27774 .42613 L .28039 .42527 L F
.34448 .42906 m .34549 .42653 L .34716 .42819 L 0 .03 .13 r
F
.34448 .42906 m .3428 .42742 L .34549 .42653 L F
.5438 .43478 m .54511 .43266 L .54659 .43399 L 0 .044 .146 r
F
.5438 .43478 m .54232 .43342 L .54511 .43266 L F
.91099 .42637 m .91282 .42381 L .91396 .42548 L 0 .024 .122 r
F
.91099 .42637 m .90984 .42471 L .91282 .42381 L F
.56497 .43364 m .56631 .43131 L .56777 .43273 L 0 .041 .143 r
F
.56497 .43364 m .56351 .43225 L .56631 .43131 L F
.55792 .43404 m .55924 .43186 L .56071 .43316 L 0 .042 .144 r
F
.55792 .43404 m .55644 .43277 L .55924 .43186 L F
.51129 .43424 m .51255 .43206 L .51406 .43354 L 0 .043 .145 r
F
.51129 .43424 m .50978 .43269 L .51255 .43206 L F
.57203 .43327 m .57338 .43094 L .57483 .43237 L 0 .04 .142 r
F
.57203 .43327 m .57057 .43182 L .57338 .43094 L F
.85732 .42703 m .85906 .42434 L .86025 .42605 L 0 .025 .124 r
F
.85732 .42703 m .85612 .42531 L .85906 .42434 L F
.55086 .43447 m .55218 .43247 L .55365 .43368 L 0 .044 .146 r
F
.55086 .43447 m .54938 .43323 L .55218 .43247 L F
.68217 .4296 m .68366 .42695 L .68502 .42861 L 0 .031 .131 r
F
.68217 .4296 m .68081 .42794 L .68366 .42695 L F
.67511 .43001 m .6766 .42732 L .67796 .42898 L 0 .032 .132 r
F
.67511 .43001 m .67375 .42836 L .6766 .42732 L F
.86438 .42672 m .86613 .42404 L .86732 .42572 L 0 .025 .123 r
F
.86438 .42672 m .86319 .42505 L .86613 .42404 L F
.57909 .43299 m .58044 .43056 L .58189 .43205 L 0 .039 .141 r
F
.57909 .43299 m .57764 .43147 L .58044 .43056 L F
.31901 .4283 m .32 .42559 L .32169 .42734 L 0 .028 .128 r
F
.31901 .4283 m .31732 .42654 L .32 .42559 L F
.74291 .42871 m .74449 .42596 L .74579 .42767 L 0 .029 .129 r
F
.74291 .42871 m .7416 .42699 L .74449 .42596 L F
.74997 .42833 m .75156 .42563 L .75285 .42734 L 0 .028 .128 r
F
.74997 .42833 m .74867 .42663 L .75156 .42563 L F
.45333 .43284 m .4545 .43054 L .45607 .43222 L 0 .039 .141 r
F
.45333 .43284 m .45176 .43113 L .4545 .43054 L F
.66806 .4305 m .66953 .42775 L .6709 .42943 L 0 .033 .134 r
F
.66806 .4305 m .66668 .42882 L .66953 .42775 L F
.24693 .42758 m .2478 .42513 L .24956 .42681 L 0 .027 .126 r
F
.24693 .42758 m .24517 .42589 L .2478 .42513 L F
.68923 .42935 m .69074 .42676 L .69209 .42841 L 0 .031 .131 r
F
.68923 .42935 m .68788 .42768 L .69074 .42676 L F
.58615 .43268 m .58751 .43022 L .58896 .43174 L 0 .038 .14 r
F
.58615 .43268 m .5847 .43113 L .58751 .43022 L F
.87145 .42642 m .87322 .42382 L .8744 .42552 L 0 .024 .123 r
F
.87145 .42642 m .87026 .42472 L .87322 .42382 L F
.36991 .43034 m .37097 .42768 L .37261 .42945 L 0 .033 .133 r
F
.36991 .43034 m .36827 .42858 L .37097 .42768 L F
.81071 .42741 m .8124 .42486 L .81364 .42655 L 0 .027 .126 r
F
.81071 .42741 m .80947 .42572 L .8124 .42486 L F
.43493 .43155 m .43607 .42928 L .43766 .43078 L 0 .036 .138 r
F
.43493 .43155 m .43334 .43004 L .43607 .42928 L F
.48584 .43352 m .48705 .43139 L .4886 .43287 L 0 .041 .143 r
F
.48584 .43352 m .48429 .43207 L .48705 .43139 L F
.75703 .42804 m .75863 .42538 L .75992 .42707 L 0 .028 .127 r
F
.75703 .42804 m .75574 .42635 L .75863 .42538 L F
.59321 .43236 m .59458 .42999 L .59602 .43154 L 0 .038 .14 r
F
.59321 .43236 m .59177 .43084 L .59458 .42999 L F
.35151 .42904 m .35254 .42651 L .3542 .42823 L 0 .03 .13 r
F
.35151 .42904 m .34985 .42735 L .35254 .42651 L F
.91808 .4263 m .91992 .42372 L .92106 .42542 L 0 .024 .123 r
F
.91808 .4263 m .91694 .4246 L .91992 .42372 L F
.28649 .42788 m .28743 .42528 L .28915 .427 L 0 .028 .127 r
F
.28649 .42788 m .28477 .42615 L .28743 .42528 L F
.69629 .42906 m .69781 .4264 L .69915 .42804 L 0 .03 .13 r
F
.69629 .42906 m .69495 .42742 L .69781 .4264 L F
.70335 .42868 m .70489 .42617 L .70622 .42783 L 0 .029 .129 r
F
.70335 .42868 m .70201 .42703 L .70489 .42617 L F
.32606 .42815 m .32704 .4256 L .32873 .42736 L 0 .028 .128 r
F
.32606 .42815 m .32437 .42639 L .32704 .4256 L F
.7641 .42779 m .76571 .42515 L .76699 .42682 L 0 .027 .127 r
F
.7641 .42779 m .76282 .42611 L .76571 .42515 L F
.51835 .43425 m .51961 .43201 L .52112 .43347 L 0 .043 .145 r
F
.51835 .43425 m .51684 .4328 L .51961 .43201 L F
.60027 .43211 m .60166 .4299 L .60309 .43131 L 0 .038 .14 r
F
.60027 .43211 m .59884 .43072 L .60166 .4299 L F
.40947 .43081 m .41057 .42845 L .41219 .43006 L 0 .035 .136 r
F
.40947 .43081 m .40786 .42919 L .41057 .42845 L F
.81779 .42729 m .81948 .42462 L .82071 .42631 L 0 .026 .125 r
F
.81779 .42729 m .81656 .4256 L .81948 .42462 L F
.37696 .43022 m .37801 .42798 L .37965 .42951 L 0 .033 .134 r
F
.37696 .43022 m .37531 .42869 L .37801 .42798 L F
.77116 .42748 m .77278 .42479 L .77406 .42647 L 0 .027 .126 r
F
.77116 .42748 m .76989 .42581 L .77278 .42479 L F
.87854 .42633 m .88032 .42371 L .88149 .42541 L 0 .025 .123 r
F
.87854 .42633 m .87736 .42463 L .88032 .42371 L F
.62144 .43107 m .62285 .42833 L .62427 .43002 L 0 .035 .136 r
F
.62144 .43107 m .62003 .42939 L .62285 .42833 L F
.6285 .43069 m .62993 .42816 L .63134 .42986 L 0 .034 .135 r
F
.6285 .43069 m .62709 .42898 L .62993 .42816 L F
.25396 .42756 m .25485 .42494 L .25661 .42659 L 0 .027 .126 r
F
.25396 .42756 m .2522 .4259 L .25485 .42494 L F
.77823 .42719 m .77987 .42462 L .78114 .42633 L 0 .026 .126 r
F
.77823 .42719 m .77696 .42548 L .77987 .42462 L F
.92518 .42621 m .92703 .42363 L .92816 .4253 L 0 .024 .123 r
F
.92518 .42621 m .92405 .42454 L .92703 .42363 L F
.61439 .43151 m .61579 .42894 L .61721 .43045 L 0 .036 .137 r
F
.61439 .43151 m .61297 .43 L .61579 .42894 L F
.60733 .43191 m .60873 .42963 L .61015 .43105 L 0 .038 .139 r
F
.60733 .43191 m .60591 .4305 L .60873 .42963 L F
.29353 .4278 m .29447 .42523 L .29619 .42689 L 0 .028 .127 r
F
.29353 .4278 m .29181 .42612 L .29447 .42523 L F
.82486 .42704 m .82657 .42445 L .82779 .42614 L 0 .026 .125 r
F
.82486 .42704 m .82364 .42534 L .82657 .42445 L F
.26101 .42725 m .26189 .42482 L .26365 .42643 L 0 .027 .126 r
F
.26101 .42725 m .25925 .42563 L .26189 .42482 L F
.71043 .42867 m .71198 .42614 L .71331 .42781 L 0 .03 .13 r
F
.71043 .42867 m .7091 .42699 L .71198 .42614 L F
.88562 .42614 m .8874 .42346 L .88857 .42515 L 0 .024 .123 r
F
.88562 .42614 m .88445 .42443 L .8874 .42346 L F
.49289 .43358 m .49412 .43141 L .49565 .43288 L 0 .042 .144 r
F
.49289 .43358 m .49135 .43214 L .49412 .43141 L F
.44198 .43165 m .44313 .42921 L .44471 .43084 L 0 .037 .138 r
F
.44198 .43165 m .44039 .43 L .44313 .42921 L F
.52541 .43424 m .52668 .43181 L .52819 .43337 L 0 .043 .146 r
F
.52541 .43424 m .5239 .43269 L .52668 .43181 L F
.93226 .42602 m .93412 .4234 L .93524 .42507 L 0 .024 .123 r
F
.93226 .42602 m .93114 .42435 L .93412 .4234 L F
.41652 .43073 m .41763 .42828 L .41924 .42981 L 0 .035 .136 r
F
.41652 .43073 m .41491 .42917 L .41763 .42828 L F
.30057 .4276 m .30153 .42498 L .30324 .42662 L 0 .027 .127 r
F
.30057 .4276 m .29886 .42595 L .30153 .42498 L F
.35854 .42921 m .35957 .42674 L .36123 .42849 L 0 .031 .132 r
F
.35854 .42921 m .35689 .42748 L .35957 .42674 L F
.63557 .43062 m .63701 .42818 L .63841 .42975 L 0 .035 .136 r
F
.63557 .43062 m .63417 .42903 L .63701 .42818 L F
.83195 .42691 m .83366 .4243 L .83488 .42597 L 0 .026 .125 r
F
.83195 .42691 m .83073 .42525 L .83366 .4243 L F
.8927 .42594 m .89451 .42338 L .89567 .42506 L 0 .024 .123 r
F
.8927 .42594 m .89154 .42425 L .89451 .42338 L F
.30762 .42731 m .30858 .42482 L .31029 .42649 L 0 .027 .127 r
F
.30762 .42731 m .30592 .42564 L .30858 .42482 L F
.384 .43029 m .38507 .42779 L .38671 .42934 L 0 .034 .135 r
F
.384 .43029 m .38235 .42876 L .38507 .42779 L F
.33308 .42834 m .33408 .42582 L .33575 .42755 L 0 .029 .129 r
F
.33308 .42834 m .3314 .4266 L .33408 .42582 L F
.46037 .43324 m .46155 .43068 L .46312 .43236 L 0 .041 .143 r
F
.46037 .43324 m .45881 .43156 L .46155 .43068 L F
.78532 .42718 m .78697 .42458 L .78823 .42627 L 0 .027 .126 r
F
.78532 .42718 m .78405 .42547 L .78697 .42458 L F
.26804 .4272 m .26894 .42472 L .27069 .42631 L F
.26804 .4272 m .26629 .4256 L .26894 .42472 L F
.93935 .42583 m .94122 .42327 L .94234 .42495 L 0 .024 .122 r
F
.93935 .42583 m .93823 .42416 L .94122 .42327 L F
.64969 .42995 m .65115 .42751 L .65253 .42903 L 0 .033 .134 r
F
.64969 .42995 m .64831 .42846 L .65115 .42751 L F
.71751 .42858 m .71906 .42606 L .72038 .42768 L 0 .03 .13 r
F
.71751 .42858 m .71618 .42693 L .71906 .42606 L F
.64263 .43034 m .64409 .42794 L .64547 .4294 L 0 .034 .135 r
F
.64263 .43034 m .64124 .42885 L .64409 .42794 L F
.39105 .42996 m .39213 .42749 L .39376 .42907 L 0 .033 .134 r
F
.39105 .42996 m .38942 .42839 L .39213 .42749 L F
.83902 .42664 m .84073 .42394 L .84195 .42564 L 0 .026 .124 r
F
.83902 .42664 m .8378 .42496 L .84073 .42394 L F
.23552 .42668 m .23637 .42415 L .23815 .42577 L 0 .026 .125 r
F
.23552 .42668 m .23374 .42507 L .23637 .42415 L F
.49995 .43353 m .50118 .43132 L .50271 .43272 L 0 .042 .144 r
F
.49995 .43353 m .49842 .43211 L .50118 .43132 L F
.42357 .4306 m .42469 .42844 L .42629 .42995 L 0 .035 .136 r
F
.42357 .4306 m .42196 .42908 L .42469 .42844 L F
.53247 .43416 m .53375 .43162 L .53525 .43332 L 0 .043 .146 r
F
.53247 .43416 m .53097 .43247 L .53375 .43162 L F
.72457 .42829 m .72613 .42568 L .72745 .4273 L 0 .029 .129 r
F
.72457 .42829 m .72326 .42669 L .72613 .42568 L F
.79239 .42698 m .79405 .42438 L .7953 .42602 L 0 .027 .126 r
F
.79239 .42698 m .79114 .42532 L .79405 .42438 L F
.84609 .4264 m .84782 .42374 L .84903 .42547 L 0 .025 .124 r
F
.84609 .4264 m .84488 .42468 L .84782 .42374 L F
.73164 .42799 m .73321 .42543 L .73452 .42712 L 0 .029 .129 r
F
.73164 .42799 m .73033 .42634 L .73321 .42543 L F
.89979 .42585 m .90161 .42326 L .90276 .42492 L 0 .024 .123 r
F
.89979 .42585 m .89864 .42418 L .90161 .42326 L F
.65676 .42977 m .65823 .42724 L .65961 .42892 L 0 .033 .134 r
F
.65676 .42977 m .65538 .42811 L .65823 .42724 L F
.50701 .43333 m .50825 .43131 L .50978 .43269 L 0 .042 .145 r
F
.50701 .43333 m .50548 .43193 L .50825 .43131 L F
.44902 .43177 m .45019 .42941 L .45176 .43113 L 0 .038 .14 r
F
.44902 .43177 m .44745 .43003 L .45019 .42941 L F
.3981 .42982 m .39919 .42741 L .40081 .429 L 0 .033 .134 r
F
.3981 .42982 m .39648 .42824 L .39919 .42741 L F
.27508 .42708 m .276 .42442 L .27774 .42613 L 0 .027 .126 r
F
.27508 .42708 m .27334 .42536 L .276 .42442 L F
.79946 .42671 m .80113 .42416 L .80238 .42581 L 0 .026 .125 r
F
.79946 .42671 m .79822 .42509 L .80113 .42416 L F
.46743 .43318 m .46862 .4306 L .47018 .43228 L 0 .041 .143 r
F
.46743 .43318 m .46587 .43148 L .46862 .4306 L F
.34012 .42833 m .34113 .42574 L .3428 .42742 L 0 .03 .13 r
F
.34012 .42833 m .33844 .42664 L .34113 .42574 L F
.90687 .42563 m .9087 .42305 L .90984 .42471 L 0 .024 .122 r
F
.90687 .42563 m .90573 .42398 L .9087 .42305 L F
.31465 .42741 m .31563 .42478 L .31732 .42654 L 0 .028 .127 r
F
.31465 .42741 m .31295 .42566 L .31563 .42478 L F
.24255 .42664 m .2434 .42419 L .24517 .42589 L 0 .026 .126 r
F
.24255 .42664 m .24078 .42493 L .2434 .42419 L F
.47448 .43292 m .47568 .43043 L .47724 .43197 L 0 .041 .143 r
F
.47448 .43292 m .47293 .43136 L .47568 .43043 L F
.85318 .42628 m .85491 .42359 L .85612 .42531 L 0 .025 .124 r
F
.85318 .42628 m .85197 .42453 L .85491 .42359 L F
.36557 .42947 m .36662 .4268 L .36827 .42858 L 0 .032 .133 r
F
.36557 .42947 m .36392 .42771 L .36662 .4268 L F
.53953 .43422 m .54083 .43181 L .54232 .43342 L 0 .044 .147 r
F
.53953 .43422 m .53804 .43257 L .54083 .43181 L F
.73872 .42795 m .7403 .42527 L .7416 .42699 L 0 .029 .129 r
F
.73872 .42795 m .73741 .42624 L .7403 .42527 L F
.80655 .42659 m .80823 .42405 L .80947 .42572 L 0 .026 .125 r
F
.80655 .42659 m .8053 .42492 L .80823 .42405 L F
.28212 .42701 m .28304 .42441 L .28477 .42615 L 0 .027 .126 r
F
.28212 .42701 m .28039 .42527 L .28304 .42441 L F
.67796 .42898 m .67945 .42628 L .68081 .42794 L 0 .031 .132 r
F
.67796 .42898 m .6766 .42732 L .67945 .42628 L F
.34716 .42819 m .34818 .42566 L .34985 .42735 L 0 .03 .13 r
F
.34716 .42819 m .34549 .42653 L .34818 .42566 L F
.86025 .42605 m .862 .42336 L .86319 .42505 L 0 .025 .124 r
F
.86025 .42605 m .85906 .42434 L .862 .42336 L F
.48154 .43271 m .48275 .43062 L .48429 .43207 L 0 .041 .143 r
F
.48154 .43271 m .47999 .43128 L .48275 .43062 L F
.66384 .42977 m .66531 .42711 L .66668 .42882 L 0 .033 .134 r
F
.66384 .42977 m .66246 .42808 L .66531 .42711 L F
.68502 .42861 m .68653 .42605 L .68788 .42768 L 0 .031 .131 r
F
.68502 .42861 m .68366 .42695 L .68653 .42605 L F
.91396 .42548 m .9158 .4229 L .91694 .4246 L 0 .024 .122 r
F
.91396 .42548 m .91282 .42381 L .9158 .4229 L F
.56777 .43273 m .56911 .43036 L .57057 .43182 L 0 .041 .143 r
F
.56777 .43273 m .56631 .43131 L .56911 .43036 L F
.6709 .42943 m .67238 .42668 L .67375 .42836 L 0 .032 .133 r
F
.6709 .42943 m .66953 .42775 L .67238 .42668 L F
.43061 .4308 m .43174 .42854 L .43334 .43004 L 0 .036 .138 r
F
.43061 .4308 m .42901 .42929 L .43174 .42854 L F
.74579 .42767 m .74737 .42492 L .74867 .42663 L 0 .028 .128 r
F
.74579 .42767 m .74449 .42596 L .74737 .42492 L F
.56071 .43316 m .56204 .43093 L .56351 .43225 L 0 .042 .144 r
F
.56071 .43316 m .55924 .43186 L .56204 .43093 L F
.57483 .43237 m .57618 .43008 L .57764 .43147 L 0 .04 .142 r
F
.57483 .43237 m .57338 .43094 L .57618 .43008 L F
.86732 .42572 m .86908 .42303 L .87026 .42472 L 0 .024 .123 r
F
.86732 .42572 m .86613 .42404 L .86908 .42303 L F
.54659 .43399 m .5479 .43193 L .54938 .43323 L 0 .045 .147 r
F
.54659 .43399 m .54511 .43266 L .5479 .43193 L F
.40515 .42988 m .40624 .42752 L .40786 .42919 L 0 .034 .135 r
F
.40515 .42988 m .40353 .42825 L .40624 .42752 L F
.75285 .42734 m .75445 .42463 L .75574 .42635 L 0 .028 .127 r
F
.75285 .42734 m .75156 .42563 L .75445 .42463 L F
.32169 .42734 m .32268 .42463 L .32437 .42639 L F
.32169 .42734 m .32 .42559 L .32268 .42463 L F
.58189 .43205 m .58325 .42968 L .5847 .43113 L 0 .039 .141 r
F
.58189 .43205 m .58044 .43056 L .58325 .42968 L F
.55365 .43368 m .55497 .43153 L .55644 .43277 L 0 .044 .146 r
F
.55365 .43368 m .55218 .43247 L .55497 .43153 L F
.69209 .42841 m .6936 .42578 L .69495 .42742 L 0 .03 .131 r
F
.69209 .42841 m .69074 .42676 L .6936 .42578 L F
.58896 .43174 m .59033 .42932 L .59177 .43084 L 0 .038 .14 r
F
.58896 .43174 m .58751 .43022 L .59033 .42932 L F
.69915 .42804 m .70067 .42539 L .70201 .42703 L 0 .03 .13 r
F
.69915 .42804 m .69781 .4264 L .70067 .42539 L F
.75992 .42707 m .76153 .42444 L .76282 .42611 L 0 .028 .127 r
F
.75992 .42707 m .75863 .42538 L .76153 .42444 L F
.51406 .43354 m .51532 .43135 L .51684 .4328 L 0 .043 .146 r
F
.51406 .43354 m .51255 .43206 L .51532 .43135 L F
.8744 .42552 m .87618 .42293 L .87736 .42463 L 0 .024 .123 r
F
.8744 .42552 m .87322 .42382 L .87618 .42293 L F
.37261 .42945 m .37367 .42692 L .37531 .42869 L 0 .033 .134 r
F
.37261 .42945 m .37097 .42768 L .37367 .42692 L F
.81364 .42655 m .81532 .42391 L .81656 .4256 L 0 .027 .126 r
F
.81364 .42655 m .8124 .42486 L .81532 .42391 L F
.92106 .42542 m .92291 .42285 L .92405 .42454 L 0 .024 .123 r
F
.92106 .42542 m .91992 .42372 L .92291 .42285 L F
.28915 .427 m .29008 .42442 L .29181 .42612 L 0 .028 .127 r
F
.28915 .427 m .28743 .42528 L .29008 .42442 L F
.24956 .42681 m .25044 .42423 L .2522 .4259 L 0 .027 .127 r
F
.24956 .42681 m .2478 .42513 L .25044 .42423 L F
.76699 .42682 m .76861 .42414 L .76989 .42581 L 0 .027 .126 r
F
.76699 .42682 m .76571 .42515 L .76861 .42414 L F
.59602 .43154 m .5974 .42914 L .59884 .43072 L 0 .038 .14 r
F
.59602 .43154 m .59458 .42999 L .5974 .42914 L F
.70622 .42783 m .70776 .4253 L .7091 .42699 L 0 .03 .13 r
F
.70622 .42783 m .70489 .42617 L .70776 .4253 L F
.3542 .42823 m .35523 .42575 L .35689 .42748 L 0 .031 .131 r
F
.3542 .42823 m .35254 .42651 L .35523 .42575 L F
.43766 .43078 m .4388 .42851 L .44039 .43 L 0 .037 .138 r
F
.43766 .43078 m .43607 .42928 L .4388 .42851 L F
.77406 .42647 m .77568 .42378 L .77696 .42548 L 0 .026 .126 r
F
.77406 .42647 m .77278 .42479 L .77568 .42378 L F
.62427 .43002 m .62568 .42727 L .62709 .42898 L 0 .034 .135 r
F
.62427 .43002 m .62285 .42833 L .62568 .42727 L F
.82071 .42631 m .8224 .42364 L .82364 .42534 L 0 .026 .125 r
F
.82071 .42631 m .81948 .42462 L .8224 .42364 L F
.61721 .43045 m .61861 .42788 L .62003 .42939 L 0 .035 .137 r
F
.61721 .43045 m .61579 .42894 L .61861 .42788 L F
.45607 .43222 m .45724 .42991 L .45881 .43156 L 0 .04 .142 r
F
.45607 .43222 m .4545 .43054 L .45724 .42991 L F
.32873 .42736 m .32972 .42486 L .3314 .4266 L 0 .029 .128 r
F
.32873 .42736 m .32704 .4256 L .32972 .42486 L F
.88149 .42541 m .88327 .42273 L .88445 .42443 L 0 .024 .123 r
F
.88149 .42541 m .88032 .42371 L .88327 .42273 L F
.25661 .42659 m .2575 .42401 L .25925 .42563 L 0 .027 .126 r
F
.25661 .42659 m .25485 .42494 L .2575 .42401 L F
.4886 .43287 m .48981 .43062 L .49135 .43214 L 0 .042 .144 r
F
.4886 .43287 m .48705 .43139 L .48981 .43062 L F
.60309 .43131 m .60448 .42908 L .60591 .4305 L 0 .038 .14 r
F
.60309 .43131 m .60166 .4299 L .60448 .42908 L F
.52112 .43347 m .52239 .43122 L .5239 .43269 L 0 .044 .146 r
F
.52112 .43347 m .51961 .43201 L .52239 .43122 L F
.92816 .4253 m .93001 .42268 L .93114 .42435 L 0 .024 .123 r
F
.92816 .4253 m .92703 .42363 L .93001 .42268 L F
.29619 .42689 m .29714 .4243 L .29886 .42595 L 0 .028 .127 r
F
.29619 .42689 m .29447 .42523 L .29714 .4243 L F
.88857 .42515 m .89037 .42256 L .89154 .42425 L 0 .024 .122 r
F
.88857 .42515 m .8874 .42346 L .89037 .42256 L F
.63134 .42986 m .63277 .42733 L .63417 .42903 L 0 .034 .136 r
F
.63134 .42986 m .62993 .42816 L .63277 .42733 L F
.78114 .42633 m .78278 .42377 L .78405 .42547 L 0 .027 .126 r
F
.78114 .42633 m .77987 .42462 L .78278 .42377 L F
.41219 .43006 m .4133 .42757 L .41491 .42917 L 0 .035 .136 r
F
.41219 .43006 m .41057 .42845 L .4133 .42757 L F
.82779 .42614 m .82951 .42356 L .83073 .42525 L 0 .026 .125 r
F
.82779 .42614 m .82657 .42445 L .82951 .42356 L F
.61015 .43105 m .61155 .42858 L .61297 .43 L 0 .037 .139 r
F
.61015 .43105 m .60873 .42963 L .61155 .42858 L F
.37965 .42951 m .38071 .42723 L .38235 .42876 L 0 .034 .135 r
F
.37965 .42951 m .37801 .42798 L .38071 .42723 L F
.30324 .42662 m .3042 .42402 L .30592 .42564 L 0 .027 .127 r
F
.30324 .42662 m .30153 .42498 L .3042 .42402 L F
.26365 .42643 m .26454 .42401 L .26629 .4256 L 0 .027 .126 r
F
.26365 .42643 m .26189 .42482 L .26454 .42401 L F
.93524 .42507 m .93711 .42248 L .93823 .42416 L 0 .024 .122 r
F
.93524 .42507 m .93412 .4234 L .93711 .42248 L F
.71331 .42781 m .71486 .42529 L .71618 .42693 L 0 .03 .13 r
F
.71331 .42781 m .71198 .42614 L .71486 .42529 L F
.41924 .42981 m .42036 .42756 L .42196 .42908 L 0 .035 .136 r
F
.41924 .42981 m .41763 .42828 L .42036 .42756 L F
.52819 .43337 m .52947 .4309 L .53097 .43247 L 0 .043 .146 r
F
.52819 .43337 m .52668 .43181 L .52947 .4309 L F
.44471 .43084 m .44587 .42841 L .44745 .43003 L 0 .037 .139 r
F
.44471 .43084 m .44313 .42921 L .44587 .42841 L F
.83488 .42597 m .83659 .42327 L .8378 .42496 L 0 .026 .125 r
F
.83488 .42597 m .83366 .4243 L .83659 .42327 L F
.2311 .42599 m .23195 .42346 L .23374 .42507 L F
.2311 .42599 m .22932 .4244 L .23195 .42346 L F
.38671 .42934 m .38778 .42681 L .38942 .42839 L 0 .034 .135 r
F
.38671 .42934 m .38507 .42779 L .38778 .42681 L F
.49565 .43288 m .49688 .43065 L .49842 .43211 L 0 .043 .145 r
F
.49565 .43288 m .49412 .43141 L .49688 .43065 L F
.63841 .42975 m .63985 .42731 L .64124 .42885 L 0 .035 .136 r
F
.63841 .42975 m .63701 .42818 L .63985 .42731 L F
.84195 .42564 m .84367 .42297 L .84488 .42468 L 0 .025 .124 r
F
.84195 .42564 m .84073 .42394 L .84367 .42297 L F
.89567 .42506 m .89748 .4225 L .89864 .42418 L 0 .024 .123 r
F
.89567 .42506 m .89451 .42338 L .89748 .4225 L F
.78823 .42627 m .78988 .42365 L .79114 .42532 L 0 .027 .126 r
F
.78823 .42627 m .78697 .42458 L .78988 .42365 L F
.64547 .4294 m .64693 .42698 L .64831 .42846 L 0 .034 .135 r
F
.64547 .4294 m .64409 .42794 L .64693 .42698 L F
.65253 .42903 m .654 .42657 L .65538 .42811 L 0 .033 .134 r
F
.65253 .42903 m .65115 .42751 L .654 .42657 L F
.46312 .43236 m .4643 .42979 L .46587 .43148 L 0 .041 .143 r
F
.46312 .43236 m .46155 .43068 L .4643 .42979 L F
.31029 .42649 m .31125 .42399 L .31295 .42566 L 0 .027 .127 r
F
.31029 .42649 m .30858 .42482 L .31125 .42399 L F
.72038 .42768 m .72194 .42506 L .72326 .42669 L 0 .03 .13 r
F
.72038 .42768 m .71906 .42606 L .72194 .42506 L F
.27069 .42631 m .2716 .42377 L .27334 .42536 L 0 .027 .126 r
F
.27069 .42631 m .26894 .42472 L .2716 .42377 L F
.72745 .4273 m .72901 .42469 L .73033 .42634 L 0 .029 .129 r
F
.72745 .4273 m .72613 .42568 L .72901 .42469 L F
.94234 .42495 m .94421 .42237 L .94533 .42408 L 0 .024 .123 r
F
.94234 .42495 m .94122 .42327 L .94421 .42237 L F
.39376 .42907 m .39485 .42663 L .39648 .42824 L 0 .033 .134 r
F
.39376 .42907 m .39213 .42749 L .39485 .42663 L F
.36123 .42849 m .36227 .42594 L .36392 .42771 L 0 .032 .132 r
F
.36123 .42849 m .35957 .42674 L .36227 .42594 L F
.23815 .42577 m .239 .42329 L .24078 .42493 L 0 .026 .125 r
F
.23815 .42577 m .23637 .42415 L .239 .42329 L F
.33575 .42755 m .33676 .42493 L .33844 .42664 L 0 .03 .13 r
F
.33575 .42755 m .33408 .42582 L .33676 .42493 L F
.7953 .42602 m .79697 .42344 L .79822 .42509 L 0 .026 .126 r
F
.7953 .42602 m .79405 .42438 L .79697 .42344 L F
.84903 .42547 m .85076 .42279 L .85197 .42453 L 0 .025 .124 r
F
.84903 .42547 m .84782 .42374 L .85076 .42279 L F
.50271 .43272 m .50395 .43054 L .50548 .43193 L 0 .043 .145 r
F
.50271 .43272 m .50118 .43132 L .50395 .43054 L F
.53525 .43332 m .53654 .43091 L .53804 .43257 L 0 .044 .146 r
F
.53525 .43332 m .53375 .43162 L .53654 .43091 L F
.90276 .42492 m .90458 .42233 L .90573 .42398 L 0 .024 .123 r
F
.90276 .42492 m .90161 .42326 L .90458 .42233 L F
.27774 .42613 m .27866 .42356 L .28039 .42527 L 0 .027 .126 r
F
.27774 .42613 m .276 .42442 L .27866 .42356 L F
.73452 .42712 m .7361 .42453 L .73741 .42624 L 0 .029 .129 r
F
.73452 .42712 m .73321 .42543 L .7361 .42453 L F
.65961 .42892 m .66108 .42637 L .66246 .42808 L 0 .033 .134 r
F
.65961 .42892 m .65823 .42724 L .66108 .42637 L F
.80238 .42581 m .80406 .42324 L .8053 .42492 L 0 .026 .125 r
F
.80238 .42581 m .80113 .42416 L .80406 .42324 L F
.47018 .43228 m .47137 .42972 L .47293 .43136 L 0 .041 .143 r
F
.47018 .43228 m .46862 .4306 L .47137 .42972 L F
.42629 .42995 m .42741 .42781 L .42901 .42929 L 0 .036 .138 r
F
.42629 .42995 m .42469 .42844 L .42741 .42781 L F
.3428 .42742 m .34381 .42486 L .34549 .42653 L 0 .03 .13 r
F
.3428 .42742 m .34113 .42574 L .34381 .42486 L F
.40081 .429 m .4019 .42663 L .40353 .42825 L 0 .034 .135 r
F
.40081 .429 m .39919 .42741 L .4019 .42663 L F
.90984 .42471 m .91167 .42213 L .91282 .42381 L 0 .024 .122 r
F
.90984 .42471 m .9087 .42305 L .91167 .42213 L F
.47724 .43197 m .47844 .42976 L .47999 .43128 L 0 .041 .143 r
F
.47724 .43197 m .47568 .43043 L .47844 .42976 L F
.85612 .42531 m .85786 .42264 L .85906 .42434 L 0 .025 .124 r
F
.85612 .42531 m .85491 .42359 L .85786 .42264 L F
.31732 .42654 m .31831 .42382 L .32 .42559 L 0 .028 .127 r
F
.31732 .42654 m .31563 .42478 L .31831 .42382 L F
.68081 .42794 m .6823 .4253 L .68366 .42695 L 0 .031 .131 r
F
.68081 .42794 m .67945 .42628 L .6823 .4253 L F
.67375 .42836 m .67523 .42563 L .6766 .42732 L 0 .032 .132 r
F
.67375 .42836 m .67238 .42668 L .67523 .42563 L F
.7416 .42699 m .74318 .42424 L .74449 .42596 L 0 .029 .128 r
F
.7416 .42699 m .7403 .42527 L .74318 .42424 L F
.86319 .42505 m .86494 .42235 L .86613 .42404 L 0 .025 .123 r
F
.86319 .42505 m .862 .42336 L .86494 .42235 L F
.36827 .42858 m .36932 .4259 L .37097 .42768 L 0 .032 .133 r
F
.36827 .42858 m .36662 .4268 L .36932 .4259 L F
.50978 .43269 m .51103 .43069 L .51255 .43206 L 0 .043 .146 r
F
.50978 .43269 m .50825 .43131 L .51103 .43069 L F
.45176 .43113 m .45292 .42885 L .4545 .43054 L 0 .039 .141 r
F
.45176 .43113 m .45019 .42941 L .45292 .42885 L F
.74867 .42663 m .75026 .42392 L .75156 .42563 L 0 .028 .128 r
F
.74867 .42663 m .74737 .42492 L .75026 .42392 L F
.66668 .42882 m .66816 .42604 L .66953 .42775 L 0 .033 .134 r
F
.66668 .42882 m .66531 .42711 L .66816 .42604 L F
.24517 .42589 m .24603 .42344 L .2478 .42513 L 0 .027 .126 r
F
.24517 .42589 m .2434 .42419 L .24603 .42344 L F
.87026 .42472 m .87204 .42213 L .87322 .42382 L 0 .024 .123 r
F
.87026 .42472 m .86908 .42303 L .87204 .42213 L F
.80947 .42572 m .81116 .42318 L .8124 .42486 L 0 .026 .126 r
F
.80947 .42572 m .80823 .42405 L .81116 .42318 L F
.68788 .42768 m .68939 .42515 L .69074 .42676 L 0 .031 .131 r
F
.68788 .42768 m .68653 .42605 L .68939 .42515 L F
.57057 .43182 m .57192 .42951 L .57338 .43094 L 0 .041 .143 r
F
.57057 .43182 m .56911 .43036 L .57192 .42951 L F
.28477 .42615 m .2857 .42356 L .28743 .42528 L 0 .027 .127 r
F
.28477 .42615 m .28304 .42441 L .2857 .42356 L F
.75574 .42635 m .75734 .42367 L .75863 .42538 L 0 .028 .127 r
F
.75574 .42635 m .75445 .42463 L .75734 .42367 L F
.91694 .4246 m .91878 .42202 L .91992 .42372 L 0 .024 .123 r
F
.91694 .4246 m .9158 .4229 L .91878 .42202 L F
.54232 .43342 m .54362 .4311 L .54511 .43266 L 0 .045 .147 r
F
.54232 .43342 m .54083 .43181 L .54362 .4311 L F
.34985 .42735 m .35087 .42479 L .35254 .42651 L 0 .03 .13 r
F
.34985 .42735 m .34818 .42566 L .35087 .42479 L F
.57764 .43147 m .57899 .42922 L .58044 .43056 L 0 .04 .142 r
F
.57764 .43147 m .57618 .43008 L .57899 .42922 L F
.56351 .43225 m .56484 .42995 L .56631 .43131 L 0 .042 .144 r
F
.56351 .43225 m .56204 .43093 L .56484 .42995 L F
.32437 .42639 m .32535 .42385 L .32704 .4256 L 0 .028 .128 r
F
.32437 .42639 m .32268 .42463 L .32535 .42385 L F
.5847 .43113 m .58607 .4288 L .58751 .43022 L 0 .039 .141 r
F
.5847 .43113 m .58325 .42968 L .58607 .4288 L F
.69495 .42742 m .69647 .42477 L .69781 .4264 L 0 .03 .13 r
F
.69495 .42742 m .6936 .42578 L .69647 .42477 L F
.70201 .42703 m .70355 .4245 L .70489 .42617 L 0 .029 .129 r
F
.70201 .42703 m .70067 .42539 L .70355 .4245 L F
.55644 .43277 m .55777 .43058 L .55924 .43186 L 0 .044 .146 r
F
.55644 .43277 m .55497 .43153 L .55777 .43058 L F
.76282 .42611 m .76443 .42349 L .76571 .42515 L 0 .027 .127 r
F
.76282 .42611 m .76153 .42444 L .76443 .42349 L F
.43334 .43004 m .43447 .42778 L .43607 .42928 L 0 .037 .138 r
F
.43334 .43004 m .43174 .42854 L .43447 .42778 L F
.59177 .43084 m .59314 .42844 L .59458 .42999 L 0 .039 .14 r
F
.59177 .43084 m .59033 .42932 L .59314 .42844 L F
.54938 .43323 m .5507 .43121 L .55218 .43247 L 0 .045 .148 r
F
.54938 .43323 m .5479 .43193 L .5507 .43121 L F
.81656 .4256 m .81825 .42292 L .81948 .42462 L 0 .026 .125 r
F
.81656 .4256 m .81532 .42391 L .81825 .42292 L F
.48429 .43207 m .48551 .42992 L .48705 .43139 L 0 .042 .144 r
F
.48429 .43207 m .48275 .43062 L .48551 .42992 L F
.87736 .42463 m .87914 .42201 L .88032 .42371 L 0 .024 .123 r
F
.87736 .42463 m .87618 .42293 L .87914 .42201 L F
.76989 .42581 m .77151 .4231 L .77278 .42479 L 0 .027 .126 r
F
.76989 .42581 m .76861 .42414 L .77151 .4231 L F
.62709 .42898 m .62852 .42645 L .62993 .42816 L 0 .034 .135 r
F
.62709 .42898 m .62568 .42727 L .62852 .42645 L F
.40786 .42919 m .40896 .42675 L .41057 .42845 L 0 .035 .136 r
F
.40786 .42919 m .40624 .42752 L .40896 .42675 L F
.62003 .42939 m .62144 .42682 L .62285 .42833 L F
.62003 .42939 m .61861 .42788 L .62144 .42682 L F
.77696 .42548 m .7786 .42292 L .77987 .42462 L 0 .026 .125 r
F
.77696 .42548 m .77568 .42378 L .7786 .42292 L F
.2522 .4259 m .25308 .42329 L .25485 .42494 L 0 .027 .126 r
F
.2522 .4259 m .25044 .42423 L .25308 .42329 L F
.92405 .42454 m .9259 .42196 L .92703 .42363 L 0 .024 .123 r
F
.92405 .42454 m .92291 .42285 L .9259 .42196 L F
.29181 .42612 m .29275 .42355 L .29447 .42523 L 0 .028 .127 r
F
.29181 .42612 m .29008 .42442 L .29275 .42355 L F
.82364 .42534 m .82534 .42275 L .82657 .42445 L 0 .026 .125 r
F
.82364 .42534 m .8224 .42364 L .82534 .42275 L F
.51684 .4328 m .5181 .43055 L .51961 .43201 L 0 .044 .146 r
F
.51684 .4328 m .51532 .43135 L .5181 .43055 L F
.37531 .42869 m .37636 .42622 L .37801 .42798 L 0 .034 .135 r
F
.37531 .42869 m .37367 .42692 L .37636 .42622 L F
.88445 .42443 m .88623 .42175 L .8874 .42346 L 0 .024 .122 r
F
.88445 .42443 m .88327 .42273 L .88623 .42175 L F
.7091 .42699 m .71064 .42445 L .71198 .42614 L 0 .03 .13 r
F
.7091 .42699 m .70776 .4253 L .71064 .42445 L F
.59884 .43072 m .60022 .42829 L .60166 .4299 L 0 .039 .14 r
F
.59884 .43072 m .5974 .42914 L .60022 .42829 L F
.25925 .42563 m .26013 .42321 L .26189 .42482 L 0 .027 .126 r
F
.25925 .42563 m .2575 .42401 L .26013 .42321 L F
.61297 .43 m .61438 .42754 L .61579 .42894 L 0 .037 .138 r
F
.61297 .43 m .61155 .42858 L .61438 .42754 L F
.44039 .43 m .44154 .42773 L .44313 .42921 L 0 .037 .139 r
F
.44039 .43 m .4388 .42851 L .44154 .42773 L F
.35689 .42748 m .35792 .42499 L .35957 .42674 L 0 .031 .131 r
F
.35689 .42748 m .35523 .42575 L .35792 .42499 L F
.93114 .42435 m .93299 .42172 L .93412 .4234 L 0 .024 .123 r
F
.93114 .42435 m .93001 .42268 L .93299 .42172 L F
.29886 .42595 m .29981 .42334 L .30153 .42498 L 0 .028 .127 r
F
.29886 .42595 m .29714 .4243 L .29981 .42334 L F
.60591 .4305 m .60731 .4282 L .60873 .42963 L 0 .038 .14 r
F
.60591 .4305 m .60448 .42908 L .60731 .4282 L F
.3314 .4266 m .33239 .42409 L .33408 .42582 L 0 .029 .129 r
F
.3314 .4266 m .32972 .42486 L .33239 .42409 L F
.89154 .42425 m .89334 .42169 L .89451 .42338 L 0 .024 .123 r
F
.89154 .42425 m .89037 .42256 L .89334 .42169 L F
.83073 .42525 m .83244 .42261 L .83366 .4243 L 0 .026 .125 r
F
.83073 .42525 m .82951 .42356 L .83244 .42261 L F
.5239 .43269 m .52518 .43033 L .52668 .43181 L 0 .044 .146 r
F
.5239 .43269 m .52239 .43122 L .52518 .43033 L F
.41491 .42917 m .41602 .42669 L .41763 .42828 L 0 .035 .136 r
F
.41491 .42917 m .4133 .42757 L .41602 .42669 L F
.30592 .42564 m .30687 .42321 L .30858 .42482 L 0 .027 .127 r
F
.30592 .42564 m .3042 .42402 L .30687 .42321 L F
.78405 .42547 m .7857 .42289 L .78697 .42458 L 0 .027 .126 r
F
.78405 .42547 m .78278 .42377 L .7857 .42289 L F
.49135 .43214 m .49258 .42985 L .49412 .43141 L 0 .043 .145 r
F
.49135 .43214 m .48981 .43062 L .49258 .42985 L F
.45881 .43156 m .45999 .42905 L .46155 .43068 L 0 .041 .143 r
F
.45881 .43156 m .45724 .42991 L .45999 .42905 L F
.63417 .42903 m .63561 .4265 L .63701 .42818 L 0 .035 .136 r
F
.63417 .42903 m .63277 .42733 L .63561 .4265 L F
.93823 .42416 m .9401 .4216 L .94122 .42327 L 0 .024 .122 r
F
.93823 .42416 m .93711 .42248 L .9401 .4216 L F
.8378 .42496 m .83952 .42225 L .84073 .42394 L 0 .026 .124 r
F
.8378 .42496 m .83659 .42327 L .83952 .42225 L F
.71618 .42693 m .71774 .42443 L .71906 .42606 L 0 .03 .13 r
F
.71618 .42693 m .71486 .42529 L .71774 .42443 L F
.26629 .4256 m .26719 .42312 L .26894 .42472 L 0 .027 .127 r
F
.26629 .4256 m .26454 .42401 L .26719 .42312 L F
.53097 .43247 m .53225 .43004 L .53375 .43162 L 0 .043 .146 r
F
.53097 .43247 m .52947 .4309 L .53225 .43004 L F
.38235 .42876 m .38342 .42623 L .38507 .42779 L 0 .034 .135 r
F
.38235 .42876 m .38071 .42723 L .38342 .42623 L F
.38942 .42839 m .3905 .42588 L .39213 .42749 L 0 .033 .134 r
F
.38942 .42839 m .38778 .42681 L .3905 .42588 L F
.23374 .42507 m .23459 .42253 L .23637 .42415 L 0 .026 .125 r
F
.23374 .42507 m .23195 .42346 L .23459 .42253 L F
.84488 .42468 m .84661 .42201 L .84782 .42374 L 0 .025 .124 r
F
.84488 .42468 m .84367 .42297 L .84661 .42201 L F
.72326 .42669 m .72481 .42404 L .72613 .42568 L 0 .03 .129 r
F
.72326 .42669 m .72194 .42506 L .72481 .42404 L F
.64124 .42885 m .64269 .42644 L .64409 .42794 L 0 .035 .136 r
F
.64124 .42885 m .63985 .42731 L .64269 .42644 L F
.64831 .42846 m .64977 .42601 L .65115 .42751 L 0 .034 .135 r
F
.64831 .42846 m .64693 .42698 L .64977 .42601 L F
.79114 .42532 m .7928 .42273 L .79405 .42438 L 0 .027 .126 r
F
.79114 .42532 m .78988 .42365 L .7928 .42273 L F
.44745 .43003 m .44861 .42781 L .45019 .42941 L 0 .038 .14 r
F
.44745 .43003 m .44587 .42841 L .44861 .42781 L F
.42196 .42908 m .42308 .42695 L .42469 .42844 L 0 .036 .137 r
F
.42196 .42908 m .42036 .42756 L .42308 .42695 L F
.73033 .42634 m .7319 .42376 L .73321 .42543 L 0 .029 .129 r
F
.73033 .42634 m .72901 .42469 L .7319 .42376 L F
.89864 .42418 m .90045 .42159 L .90161 .42326 L 0 .024 .123 r
F
.89864 .42418 m .89748 .4225 L .90045 .42159 L F
.27334 .42536 m .27426 .42282 L .276 .42442 L 0 .027 .126 r
F
.27334 .42536 m .2716 .42377 L .27426 .42282 L F
.65538 .42811 m .65685 .42568 L .65823 .42724 L 0 .033 .134 r
F
.65538 .42811 m .654 .42657 L .65685 .42568 L F
.46587 .43148 m .46706 .42893 L .46862 .4306 L 0 .041 .143 r
F
.46587 .43148 m .4643 .42979 L .46706 .42893 L F
.49842 .43211 m .49965 .42987 L .50118 .43132 L 0 .043 .145 r
F
.49842 .43211 m .49688 .43065 L .49965 .42987 L F
.31295 .42566 m .31392 .4231 L .31563 .42478 L 0 .028 .127 r
F
.31295 .42566 m .31125 .42399 L .31392 .4231 L F
.33844 .42664 m .33945 .42404 L .34113 .42574 L 0 .03 .13 r
F
.33844 .42664 m .33676 .42493 L .33945 .42404 L F
.79822 .42509 m .79989 .42251 L .80113 .42416 L 0 .026 .125 r
F
.79822 .42509 m .79697 .42344 L .79989 .42251 L F
.39648 .42824 m .39756 .42578 L .39919 .42741 L 0 .034 .134 r
F
.39648 .42824 m .39485 .42663 L .39756 .42578 L F
.85197 .42453 m .85371 .42185 L .85491 .42359 L 0 .025 .124 r
F
.85197 .42453 m .85076 .42279 L .85371 .42185 L F
.24078 .42493 m .24163 .42253 L .2434 .42419 L 0 .026 .126 r
F
.24078 .42493 m .239 .42329 L .24163 .42253 L F
.90573 .42398 m .90755 .4214 L .9087 .42305 L 0 .024 .123 r
F
.90573 .42398 m .90458 .42233 L .90755 .4214 L F
.36392 .42771 m .36497 .42503 L .36662 .4268 L 0 .032 .133 r
F
.36392 .42771 m .36227 .42594 L .36497 .42503 L F
.73741 .42624 m .73899 .42354 L .7403 .42527 L 0 .029 .129 r
F
.73741 .42624 m .7361 .42453 L .73899 .42354 L F
.50548 .43193 m .50673 .42994 L .50825 .43131 L 0 .043 .146 r
F
.50548 .43193 m .50395 .43054 L .50673 .42994 L F
.28039 .42527 m .28131 .4227 L .28304 .42441 L 0 .027 .126 r
F
.28039 .42527 m .27866 .42356 L .28131 .4227 L F
.47293 .43136 m .47413 .42884 L .47568 .43043 L 0 .041 .143 r
F
.47293 .43136 m .47137 .42972 L .47413 .42884 L F
.8053 .42492 m .80699 .42237 L .80823 .42405 L 0 .026 .125 r
F
.8053 .42492 m .80406 .42324 L .80699 .42237 L F
.53804 .43257 m .53933 .4302 L .54083 .43181 L 0 .044 .147 r
F
.53804 .43257 m .53654 .43091 L .53933 .4302 L F
.85906 .42434 m .86081 .42166 L .862 .42336 L 0 .025 .124 r
F
.85906 .42434 m .85786 .42264 L .86081 .42166 L F
.66246 .42808 m .66393 .42539 L .66531 .42711 L 0 .033 .134 r
F
.66246 .42808 m .66108 .42637 L .66393 .42539 L F
.34549 .42653 m .34651 .424 L .34818 .42566 L 0 .03 .13 r
F
.34549 .42653 m .34381 .42486 L .34651 .424 L F
.6766 .42732 m .67808 .42458 L .67945 .42628 L 0 .031 .132 r
F
.6766 .42732 m .67523 .42563 L .67808 .42458 L F
.74449 .42596 m .74607 .4232 L .74737 .42492 L 0 .028 .128 r
F
.74449 .42596 m .74318 .42424 L .74607 .4232 L F
.91282 .42381 m .91465 .4212 L .9158 .4229 L 0 .024 .122 r
F
.91282 .42381 m .91167 .42213 L .91465 .4212 L F
.68366 .42695 m .68517 .42442 L .68653 .42605 L 0 .031 .131 r
F
.68366 .42695 m .6823 .4253 L .68517 .42442 L F
.32 .42559 m .32099 .42287 L .32268 .42463 L 0 .028 .127 r
F
.32 .42559 m .31831 .42382 L .32099 .42287 L F
.66953 .42775 m .67101 .42497 L .67238 .42668 L 0 .032 .133 r
F
.66953 .42775 m .66816 .42604 L .67101 .42497 L F
.86613 .42404 m .86789 .42135 L .86908 .42303 L 0 .024 .123 r
F
.86613 .42404 m .86494 .42235 L .86789 .42135 L F
.75156 .42563 m .75315 .42291 L .75445 .42463 L 0 .028 .127 r
F
.75156 .42563 m .75026 .42392 L .75315 .42291 L F
.40353 .42825 m .40462 .42585 L .40624 .42752 L 0 .034 .135 r
F
.40353 .42825 m .4019 .42663 L .40462 .42585 L F
.37097 .42768 m .37202 .42515 L .37367 .42692 L 0 .033 .133 r
F
.37097 .42768 m .36932 .4259 L .37202 .42515 L F
.42901 .42929 m .43014 .42705 L .43174 .42854 L 0 .037 .138 r
F
.42901 .42929 m .42741 .42781 L .43014 .42705 L F
.75863 .42538 m .76024 .42275 L .76153 .42444 L 0 .027 .127 r
F
.75863 .42538 m .75734 .42367 L .76024 .42275 L F
.69074 .42676 m .69226 .4242 L .6936 .42578 L 0 .031 .131 r
F
.69074 .42676 m .68939 .42515 L .69226 .4242 L F
.87322 .42382 m .875 .42124 L .87618 .42293 L 0 .024 .123 r
F
.87322 .42382 m .87204 .42213 L .875 .42124 L F
.47999 .43128 m .4812 .4291 L .48275 .43062 L 0 .042 .144 r
F
.47999 .43128 m .47844 .42976 L .4812 .4291 L F
.69781 .4264 m .69933 .42376 L .70067 .42539 L 0 .03 .13 r
F
.69781 .4264 m .69647 .42477 L .69933 .42376 L F
.56631 .43131 m .56765 .42897 L .56911 .43036 L 0 .042 .144 r
F
.56631 .43131 m .56484 .42995 L .56765 .42897 L F
.8124 .42486 m .81408 .42221 L .81532 .42391 L 0 .026 .126 r
F
.8124 .42486 m .81116 .42318 L .81408 .42221 L F
.57338 .43094 m .57473 .42869 L .57618 .43008 L 0 .041 .143 r
F
.57338 .43094 m .57192 .42951 L .57473 .42869 L F
.58044 .43056 m .58181 .42838 L .58325 .42968 L 0 .04 .142 r
F
.58044 .43056 m .57899 .42922 L .58181 .42838 L F
.28743 .42528 m .28836 .42271 L .29008 .42442 L 0 .027 .127 r
F
.28743 .42528 m .2857 .42356 L .28836 .42271 L F
.91992 .42372 m .92177 .42115 L .92291 .42285 L 0 .024 .123 r
F
.91992 .42372 m .91878 .42202 L .92177 .42115 L F
.58751 .43022 m .58888 .4279 L .59033 .42932 L 0 .039 .141 r
F
.58751 .43022 m .58607 .4288 L .58888 .4279 L F
.2478 .42513 m .24867 .42256 L .25044 .42423 L 0 .027 .127 r
F
.2478 .42513 m .24603 .42344 L .24867 .42256 L F
.35254 .42651 m .35356 .42401 L .35523 .42575 L 0 .03 .131 r
F
.35254 .42651 m .35087 .42479 L .35356 .42401 L F
.76571 .42515 m .76733 .42248 L .76861 .42414 L 0 .027 .126 r
F
.76571 .42515 m .76443 .42349 L .76733 .42248 L F
.77278 .42479 m .77441 .42209 L .77568 .42378 L 0 .026 .125 r
F
.77278 .42479 m .77151 .4231 L .77441 .42209 L F
.70489 .42617 m .70642 .42361 L .70776 .4253 L 0 .03 .13 r
F
.70489 .42617 m .70355 .4245 L .70642 .42361 L F
.62285 .42833 m .62427 .42576 L .62568 .42727 L 0 .034 .135 r
F
.62285 .42833 m .62144 .42682 L .62427 .42576 L F
.55924 .43186 m .56057 .42961 L .56204 .43093 L 0 .044 .146 r
F
.55924 .43186 m .55777 .43058 L .56057 .42961 L F
.51255 .43206 m .5138 .42998 L .51532 .43135 L 0 .044 .147 r
F
.51255 .43206 m .51103 .43069 L .5138 .42998 L F
.81948 .42462 m .82117 .42193 L .8224 .42364 L 0 .026 .125 r
F
.81948 .42462 m .81825 .42292 L .82117 .42193 L F
.54511 .43266 m .54641 .43041 L .5479 .43193 L 0 .046 .148 r
F
.54511 .43266 m .54362 .4311 L .54641 .43041 L F
.32704 .4256 m .32803 .42312 L .32972 .42486 L 0 .028 .128 r
F
.32704 .4256 m .32535 .42385 L .32803 .42312 L F
.4545 .43054 m .45567 .42825 L .45724 .42991 L 0 .04 .142 r
F
.4545 .43054 m .45292 .42885 L .45567 .42825 L F
.88032 .42371 m .8821 .42103 L .88327 .42273 L 0 .024 .123 r
F
.88032 .42371 m .87914 .42201 L .8821 .42103 L F
.59458 .42999 m .59596 .42755 L .5974 .42914 L 0 .039 .14 r
F
.59458 .42999 m .59314 .42844 L .59596 .42755 L F
.25485 .42494 m .25573 .42237 L .2575 .42401 L 0 .027 .126 r
F
.25485 .42494 m .25308 .42329 L .25573 .42237 L F
.43607 .42928 m .43721 .42702 L .4388 .42851 L 0 .037 .139 r
F
.43607 .42928 m .43447 .42778 L .43721 .42702 L F
.92703 .42363 m .92888 .42099 L .93001 .42268 L 0 .024 .123 r
F
.92703 .42363 m .9259 .42196 L .92888 .42099 L F
.77987 .42462 m .78151 .42206 L .78278 .42377 L 0 .027 .126 r
F
.77987 .42462 m .7786 .42292 L .78151 .42206 L F
.55218 .43247 m .55349 .43024 L .55497 .43153 L 0 .045 .148 r
F
.55218 .43247 m .5507 .43121 L .55349 .43024 L F
.62993 .42816 m .63136 .42564 L .63277 .42733 L 0 .034 .135 r
F
.62993 .42816 m .62852 .42645 L .63136 .42564 L F
.61579 .42894 m .6172 .42648 L .61861 .42788 L 0 .036 .138 r
F
.61579 .42894 m .61438 .42754 L .6172 .42648 L F
.8874 .42346 m .8892 .42085 L .89037 .42256 L 0 .024 .122 r
F
.8874 .42346 m .88623 .42175 L .8892 .42085 L F
.29447 .42523 m .29541 .42264 L .29714 .4243 L 0 .028 .127 r
F
.29447 .42523 m .29275 .42355 L .29541 .42264 L F
.82657 .42445 m .82828 .42186 L .82951 .42356 L 0 .026 .125 r
F
.82657 .42445 m .82534 .42275 L .82828 .42186 L F
.41057 .42845 m .41169 .42585 L .4133 .42757 L 0 .035 .136 r
F
.41057 .42845 m .40896 .42675 L .41169 .42585 L F
.48705 .43139 m .48827 .4291 L .48981 .43062 L 0 .043 .145 r
F
.48705 .43139 m .48551 .42992 L .48827 .4291 L F
.51961 .43201 m .52088 .42975 L .52239 .43122 L 0 .044 .147 r
F
.51961 .43201 m .5181 .43055 L .52088 .42975 L F
.93412 .4234 m .93598 .42081 L .93711 .42248 L 0 .024 .122 r
F
.93412 .4234 m .93299 .42172 L .93598 .42081 L F
.71198 .42614 m .71352 .4236 L .71486 .42529 L 0 .03 .13 r
F
.71198 .42614 m .71064 .42445 L .71352 .4236 L F
.30153 .42498 m .30248 .4224 L .3042 .42402 L 0 .027 .127 r
F
.30153 .42498 m .29981 .42334 L .30248 .4224 L F
.60166 .4299 m .60305 .42744 L .60448 .42908 L 0 .039 .141 r
F
.60166 .4299 m .60022 .42829 L .60305 .42744 L F
.26189 .42482 m .26278 .4224 L .26454 .42401 L 0 .027 .127 r
F
.26189 .42482 m .26013 .42321 L .26278 .4224 L F
.37801 .42798 m .37907 .42548 L .38071 .42723 L 0 .034 .135 r
F
.37801 .42798 m .37636 .42622 L .37907 .42548 L F
.83366 .4243 m .83537 .4216 L .83659 .42327 L 0 .026 .125 r
F
.83366 .4243 m .83244 .42261 L .83537 .4216 L F
.44313 .42921 m .44428 .42695 L .44587 .42841 L 0 .038 .139 r
F
.44313 .42921 m .44154 .42773 L .44428 .42695 L F
.60873 .42963 m .61013 .42717 L .61155 .42858 L 0 .038 .14 r
F
.60873 .42963 m .60731 .4282 L .61013 .42717 L F
.84073 .42394 m .84245 .42126 L .84367 .42297 L 0 .025 .124 r
F
.84073 .42394 m .83952 .42225 L .84245 .42126 L F
.41763 .42828 m .41875 .42599 L .42036 .42756 L 0 .035 .137 r
F
.41763 .42828 m .41602 .42669 L .41875 .42599 L F
.52668 .43181 m .52796 .42942 L .52947 .4309 L 0 .044 .146 r
F
.52668 .43181 m .52518 .43033 L .52796 .42942 L F
.89451 .42338 m .89632 .42082 L .89748 .4225 L 0 .024 .123 r
F
.89451 .42338 m .89334 .42169 L .89632 .42082 L F
.78697 .42458 m .78862 .42197 L .78988 .42365 L 0 .027 .126 r
F
.78697 .42458 m .7857 .42289 L .78862 .42197 L F
.35957 .42674 m .36061 .42417 L .36227 .42594 L 0 .031 .132 r
F
.35957 .42674 m .35792 .42499 L .36061 .42417 L F
.22932 .4244 m .23016 .42186 L .23195 .42346 L 0 .027 .126 r
F
.22932 .4244 m .22752 .42281 L .23016 .42186 L F
.46155 .43068 m .46274 .42819 L .4643 .42979 L 0 .041 .143 r
F
.46155 .43068 m .45999 .42905 L .46274 .42819 L F
.30858 .42482 m .30953 .42239 L .31125 .42399 L 0 .028 .127 r
F
.30858 .42482 m .30687 .42321 L .30953 .42239 L F
.94122 .42327 m .9431 .42071 L .94421 .42237 L 0 .024 .123 r
F
.94122 .42327 m .9401 .4216 L .9431 .42071 L F
.33408 .42582 m .33508 .42321 L .33676 .42493 L 0 .029 .129 r
F
.33408 .42582 m .33239 .42409 L .33508 .42321 L F
.63701 .42818 m .63845 .42565 L .63985 .42731 L 0 .035 .136 r
F
.63701 .42818 m .63561 .4265 L .63845 .42565 L F
.38507 .42779 m .38614 .42522 L .38778 .42681 L 0 .034 .135 r
F
.38507 .42779 m .38342 .42623 L .38614 .42522 L F
.71906 .42606 m .72062 .42343 L .72194 .42506 L 0 .03 .13 r
F
.71906 .42606 m .71774 .42443 L .72062 .42343 L F
.72613 .42568 m .7277 .42304 L .72901 .42469 L 0 .029 .129 r
F
.72613 .42568 m .72481 .42404 L .7277 .42304 L F
.26894 .42472 m .26984 .42217 L .2716 .42377 L 0 .027 .127 r
F
.26894 .42472 m .26719 .42312 L .26984 .42217 L F
.84782 .42374 m .84955 .42105 L .85076 .42279 L 0 .025 .124 r
F
.84782 .42374 m .84661 .42201 L .84955 .42105 L F
.23637 .42415 m .23723 .42165 L .239 .42329 L 0 .026 .125 r
F
.23637 .42415 m .23459 .42253 L .23723 .42165 L F
.39213 .42749 m .39321 .42501 L .39485 .42663 L 0 .034 .134 r
F
.39213 .42749 m .3905 .42588 L .39321 .42501 L F
.49412 .43141 m .49535 .42908 L .49688 .43065 L 0 .043 .146 r
F
.49412 .43141 m .49258 .42985 L .49535 .42908 L F
.53375 .43162 m .53504 .42939 L .53654 .43091 L 0 .044 .146 r
F
.53375 .43162 m .53225 .43004 L .53504 .42939 L F
.65115 .42751 m .65262 .42505 L .654 .42657 L 0 .034 .135 r
F
.65115 .42751 m .64977 .42601 L .65262 .42505 L F
.79405 .42438 m .79572 .42179 L .79697 .42344 L 0 .027 .126 r
F
.79405 .42438 m .7928 .42273 L .79572 .42179 L F
.64409 .42794 m .64554 .42546 L .64693 .42698 L 0 .035 .136 r
F
.64409 .42794 m .64269 .42644 L .64554 .42546 L F
.276 .42442 m .27691 .42194 L .27866 .42356 L 0 .027 .126 r
F
.276 .42442 m .27426 .42282 L .27691 .42194 L F
.90161 .42326 m .90343 .42067 L .90458 .42233 L 0 .024 .123 r
F
.90161 .42326 m .90045 .42159 L .90343 .42067 L F
.73321 .42543 m .73479 .42283 L .7361 .42453 L 0 .029 .129 r
F
.73321 .42543 m .7319 .42376 L .73479 .42283 L F
.65823 .42724 m .6597 .42479 L .66108 .42637 L 0 .033 .134 r
F
.65823 .42724 m .65685 .42568 L .6597 .42479 L F
.46862 .4306 m .46981 .42809 L .47137 .42972 L 0 .041 .143 r
F
.46862 .4306 m .46706 .42893 L .46981 .42809 L F
.80113 .42416 m .80281 .42159 L .80406 .42324 L 0 .026 .125 r
F
.80113 .42416 m .79989 .42251 L .80281 .42159 L F
.34113 .42574 m .34214 .42319 L .34381 .42486 L 0 .03 .13 r
F
.34113 .42574 m .33945 .42404 L .34214 .42319 L F
.85491 .42359 m .85666 .42091 L .85786 .42264 L 0 .025 .124 r
F
.85491 .42359 m .85371 .42185 L .85666 .42091 L F
.31563 .42478 m .31661 .42215 L .31831 .42382 L 0 .028 .127 r
F
.31563 .42478 m .31392 .4231 L .31661 .42215 L F
.9087 .42305 m .91053 .42046 L .91167 .42213 L 0 .024 .122 r
F
.9087 .42305 m .90755 .4214 L .91053 .42046 L F
.36662 .4268 m .36767 .42412 L .36932 .4259 L 0 .032 .133 r
F
.36662 .4268 m .36497 .42503 L .36767 .42412 L F
.50118 .43132 m .50242 .4291 L .50395 .43054 L 0 .044 .146 r
F
.50118 .43132 m .49965 .42987 L .50242 .4291 L F
.39919 .42741 m .40028 .42497 L .4019 .42663 L 0 .034 .135 r
F
.39919 .42741 m .39756 .42578 L .40028 .42497 L F
.7403 .42527 m .74187 .42251 L .74318 .42424 L 0 .029 .128 r
F
.7403 .42527 m .73899 .42354 L .74187 .42251 L F
.45019 .42941 m .45135 .42726 L .45292 .42885 L 0 .039 .141 r
F
.45019 .42941 m .44861 .42781 L .45135 .42726 L F
.67945 .42628 m .68094 .4236 L .6823 .4253 L 0 .031 .131 r
F
.67945 .42628 m .67808 .42458 L .68094 .4236 L F
.42469 .42844 m .4258 .42633 L .42741 .42781 L 0 .037 .138 r
F
.42469 .42844 m .42308 .42695 L .4258 .42633 L F
.67238 .42668 m .67386 .42391 L .67523 .42563 L 0 .032 .132 r
F
.67238 .42668 m .67101 .42497 L .67386 .42391 L F
.74737 .42492 m .74896 .42219 L .75026 .42392 L 0 .028 .127 r
F
.74737 .42492 m .74607 .4232 L .74896 .42219 L F
.862 .42336 m .86375 .42067 L .86494 .42235 L 0 .025 .123 r
F
.862 .42336 m .86081 .42166 L .86375 .42067 L F
.47568 .43043 m .47689 .42818 L .47844 .42976 L 0 .041 .144 r
F
.47568 .43043 m .47413 .42884 L .47689 .42818 L F
.66531 .42711 m .66678 .42432 L .66816 .42604 L 0 .033 .133 r
F
.66531 .42711 m .66393 .42539 L .66678 .42432 L F
.2434 .42419 m .24426 .42177 L .24603 .42344 L 0 .027 .126 r
F
.2434 .42419 m .24163 .42253 L .24426 .42177 L F
.86908 .42303 m .87085 .42046 L .87204 .42213 L 0 .024 .123 r
F
.86908 .42303 m .86789 .42135 L .87085 .42046 L F
.28304 .42441 m .28397 .42185 L .2857 .42356 L 0 .027 .127 r
F
.28304 .42441 m .28131 .4227 L .28397 .42185 L F
.32268 .42463 m .32366 .4221 L .32535 .42385 L 0 .028 .127 r
F
.32268 .42463 m .32099 .42287 L .32366 .4221 L F
.75445 .42463 m .75605 .42195 L .75734 .42367 L 0 .027 .127 r
F
.75445 .42463 m .75315 .42291 L .75605 .42195 L F
.80823 .42405 m .80992 .42149 L .81116 .42318 L 0 .026 .126 r
F
.80823 .42405 m .80699 .42237 L .80992 .42149 L F
.9158 .4229 m .91764 .42031 L .91878 .42202 L 0 .024 .122 r
F
.9158 .4229 m .91465 .4212 L .91764 .42031 L F
.34818 .42566 m .3492 .42315 L .35087 .42479 L 0 .03 .13 r
F
.34818 .42566 m .34651 .424 L .3492 .42315 L F
.68653 .42605 m .68804 .42354 L .68939 .42515 L 0 .031 .131 r
F
.68653 .42605 m .68517 .42442 L .68804 .42354 L F
.54083 .43181 m .54213 .42953 L .54362 .4311 L 0 .045 .148 r
F
.54083 .43181 m .53933 .4302 L .54213 .42953 L F
.6936 .42578 m .69512 .42321 L .69647 .42477 L 0 .03 .131 r
F
.6936 .42578 m .69226 .4242 L .69512 .42321 L F
.70067 .42539 m .70221 .42285 L .70355 .4245 L 0 .03 .13 r
F
.70067 .42539 m .69933 .42376 L .70221 .42285 L F
.76153 .42444 m .76315 .42183 L .76443 .42349 L 0 .027 .127 r
F
.76153 .42444 m .76024 .42275 L .76315 .42183 L F
.50825 .43131 m .5095 .42933 L .51103 .43069 L 0 .045 .147 r
F
.50825 .43131 m .50673 .42994 L .5095 .42933 L F
.56911 .43036 m .57046 .42814 L .57192 .42951 L 0 .042 .144 r
F
.56911 .43036 m .56765 .42897 L .57046 .42814 L F
.87618 .42293 m .87796 .42032 L .87914 .42201 L 0 .024 .123 r
F
.87618 .42293 m .875 .42124 L .87796 .42032 L F
.81532 .42391 m .81701 .4212 L .81825 .42292 L 0 .026 .125 r
F
.81532 .42391 m .81408 .42221 L .81701 .4212 L F
.62568 .42727 m .62711 .42494 L .62852 .42645 L 0 .034 .135 r
F
.62568 .42727 m .62427 .42576 L .62711 .42494 L F
.76861 .42414 m .77023 .42146 L .77151 .4231 L 0 .027 .126 r
F
.76861 .42414 m .76733 .42248 L .77023 .42146 L F
.77568 .42378 m .77732 .42122 L .7786 .42292 L 0 .026 .125 r
F
.77568 .42378 m .77441 .42209 L .77732 .42122 L F
.37367 .42692 m .37472 .42444 L .37636 .42622 L 0 .033 .134 r
F
.37367 .42692 m .37202 .42515 L .37472 .42444 L F
.40624 .42752 m .40734 .42504 L .40896 .42675 L 0 .035 .136 r
F
.40624 .42752 m .40462 .42585 L .40734 .42504 L F
.58325 .42968 m .58462 .42754 L .58607 .4288 L 0 .04 .142 r
F
.58325 .42968 m .58181 .42838 L .58462 .42754 L F
.57618 .43008 m .57754 .42788 L .57899 .42922 L 0 .041 .143 r
F
.57618 .43008 m .57473 .42869 L .57754 .42788 L F
.59033 .42932 m .5917 .42698 L .59314 .42844 L 0 .039 .141 r
F
.59033 .42932 m .58888 .4279 L .5917 .42698 L F
.29008 .42442 m .29102 .42187 L .29275 .42355 L 0 .028 .127 r
F
.29008 .42442 m .28836 .42271 L .29102 .42187 L F
.43174 .42854 m .43288 .42629 L .43447 .42778 L 0 .037 .139 r
F
.43174 .42854 m .43014 .42705 L .43288 .42629 L F
.92291 .42285 m .92476 .42025 L .9259 .42196 L 0 .024 .123 r
F
.92291 .42285 m .92177 .42115 L .92476 .42025 L F
.8224 .42364 m .82411 .42103 L .82534 .42275 L 0 .026 .125 r
F
.8224 .42364 m .82117 .42193 L .82411 .42103 L F
.25044 .42423 m .25132 .42164 L .25308 .42329 L 0 .027 .127 r
F
.25044 .42423 m .24867 .42256 L .25132 .42164 L F
.56204 .43093 m .56337 .42861 L .56484 .42995 L 0 .043 .146 r
F
.56204 .43093 m .56057 .42961 L .56337 .42861 L F
.88327 .42273 m .88506 .42004 L .88623 .42175 L 0 .024 .122 r
F
.88327 .42273 m .8821 .42103 L .88506 .42004 L F
.70776 .4253 m .7093 .42274 L .71064 .42445 L 0 .03 .13 r
F
.70776 .4253 m .70642 .42361 L .7093 .42274 L F
.48275 .43062 m .48396 .42839 L .48551 .42992 L 0 .043 .145 r
F
.48275 .43062 m .4812 .4291 L .48396 .42839 L F
.61861 .42788 m .62003 .42542 L .62144 .42682 L 0 .036 .137 r
F
.61861 .42788 m .6172 .42648 L .62003 .42542 L F
.35523 .42575 m .35625 .42323 L .35792 .42499 L 0 .031 .131 r
F
.35523 .42575 m .35356 .42401 L .35625 .42323 L F
.2575 .42401 m .25837 .42159 L .26013 .42321 L 0 .027 .127 r
F
.2575 .42401 m .25573 .42237 L .25837 .42159 L F
.5974 .42914 m .59879 .42668 L .60022 .42829 L 0 .039 .141 r
F
.5974 .42914 m .59596 .42755 L .59879 .42668 L F
.93001 .42268 m .93186 .42003 L .93299 .42172 L 0 .024 .123 r
F
.93001 .42268 m .92888 .42099 L .93186 .42003 L F
.55497 .43153 m .55629 .42926 L .55777 .43058 L 0 .045 .148 r
F
.55497 .43153 m .55349 .43024 L .55629 .42926 L F
.32972 .42486 m .33071 .42236 L .33239 .42409 L 0 .029 .129 r
F
.32972 .42486 m .32803 .42312 L .33071 .42236 L F
.5479 .43193 m .54921 .42972 L .5507 .43121 L 0 .046 .149 r
F
.5479 .43193 m .54641 .43041 L .54921 .42972 L F
.51532 .43135 m .51658 .42914 L .5181 .43055 L 0 .045 .147 r
F
.51532 .43135 m .5138 .42998 L .51658 .42914 L F
.29714 .4243 m .29809 .4217 L .29981 .42334 L 0 .028 .127 r
F
.29714 .4243 m .29541 .42264 L .29809 .4217 L F
.89037 .42256 m .89217 .41998 L .89334 .42169 L 0 .024 .122 r
F
.89037 .42256 m .8892 .42085 L .89217 .41998 L F
.82951 .42356 m .83122 .42093 L .83244 .42261 L 0 .026 .125 r
F
.82951 .42356 m .82828 .42186 L .83122 .42093 L F
.78278 .42377 m .78443 .42117 L .7857 .42289 L 0 .027 .126 r
F
.78278 .42377 m .78151 .42206 L .78443 .42117 L F
.63277 .42733 m .6342 .42481 L .63561 .4265 L 0 .035 .136 r
F
.63277 .42733 m .63136 .42564 L .6342 .42481 L F
.4388 .42851 m .43995 .42625 L .44154 .42773 L 0 .038 .14 r
F
.4388 .42851 m .43721 .42702 L .43995 .42625 L F
.3042 .42402 m .30515 .4216 L .30687 .42321 L 0 .027 .127 r
F
.3042 .42402 m .30248 .4224 L .30515 .4216 L F
.45724 .42991 m .45842 .42741 L .45999 .42905 L 0 .041 .143 r
F
.45724 .42991 m .45567 .42825 L .45842 .42741 L F
.4133 .42757 m .41441 .42495 L .41602 .42669 L 0 .035 .136 r
F
.4133 .42757 m .41169 .42585 L .41441 .42495 L F
.93711 .42248 m .93898 .41993 L .9401 .4216 L 0 .024 .122 r
F
.93711 .42248 m .93598 .42081 L .93898 .41993 L F
.83659 .42327 m .8383 .42059 L .83952 .42225 L 0 .026 .124 r
F
.83659 .42327 m .83537 .4216 L .8383 .42059 L F
.61155 .42858 m .61296 .42613 L .61438 .42754 L 0 .038 .139 r
F
.61155 .42858 m .61013 .42717 L .61296 .42613 L F
.71486 .42529 m .71641 .42275 L .71774 .42443 L 0 .03 .13 r
F
.71486 .42529 m .71352 .4236 L .71641 .42275 L F
.84367 .42297 m .8454 .42028 L .84661 .42201 L 0 .025 .124 r
F
.84367 .42297 m .84245 .42126 L .8454 .42028 L F
.48981 .43062 m .49104 .42829 L .49258 .42985 L 0 .043 .145 r
F
.48981 .43062 m .48827 .4291 L .49104 .42829 L F
.52239 .43122 m .52367 .42885 L .52518 .43033 L 0 .045 .147 r
F
.52239 .43122 m .52088 .42975 L .52367 .42885 L F
.60448 .42908 m .60587 .42655 L .60731 .4282 L 0 .039 .141 r
F
.60448 .42908 m .60305 .42744 L .60587 .42655 L F
.26454 .42401 m .26543 .42152 L .26719 .42312 L 0 .028 .127 r
F
.26454 .42401 m .26278 .4224 L .26543 .42152 L F
.52947 .4309 m .53075 .42857 L .53225 .43004 L 0 .044 .146 r
F
.52947 .4309 m .52796 .42942 L .53075 .42857 L F
.78988 .42365 m .79154 .42106 L .7928 .42273 L 0 .027 .126 r
F
.78988 .42365 m .78862 .42197 L .79154 .42106 L F
.23195 .42346 m .2328 .4209 L .23459 .42253 L 0 .026 .125 r
F
.23195 .42346 m .23016 .42186 L .2328 .4209 L F
.38778 .42681 m .38886 .42427 L .3905 .42588 L 0 .034 .135 r
F
.38778 .42681 m .38614 .42522 L .38886 .42427 L F
.89748 .4225 m .89929 .41992 L .90045 .42159 L 0 .024 .123 r
F
.89748 .4225 m .89632 .42082 L .89929 .41992 L F
.72194 .42506 m .72349 .42241 L .72481 .42404 L 0 .03 .13 r
F
.72194 .42506 m .72062 .42343 L .72349 .42241 L F
.38071 .42723 m .38178 .4245 L .38342 .42623 L 0 .034 .135 r
F
.38071 .42723 m .37907 .42548 L .38178 .4245 L F
.44587 .42841 m .44702 .42634 L .44861 .42781 L 0 .038 .14 r
F
.44587 .42841 m .44428 .42695 L .44702 .42634 L F
.72901 .42469 m .73058 .42212 L .7319 .42376 L 0 .029 .129 r
F
.72901 .42469 m .7277 .42304 L .73058 .42212 L F
.4643 .42979 m .46549 .42737 L .46706 .42893 L 0 .041 .143 r
F
.4643 .42979 m .46274 .42819 L .46549 .42737 L F
.33676 .42493 m .33777 .42234 L .33945 .42404 L 0 .03 .13 r
F
.33676 .42493 m .33508 .42321 L .33777 .42234 L F
.2716 .42377 m .27251 .42121 L .27426 .42282 L 0 .027 .126 r
F
.2716 .42377 m .26984 .42217 L .27251 .42121 L F
.85076 .42279 m .8525 .42011 L .85371 .42185 L 0 .025 .124 r
F
.85076 .42279 m .84955 .42105 L .8525 .42011 L F
.63985 .42731 m .6413 .42479 L .64269 .42644 L 0 .035 .136 r
F
.63985 .42731 m .63845 .42565 L .6413 .42479 L F
.36227 .42594 m .36332 .42325 L .36497 .42503 L 0 .032 .132 r
F
.36227 .42594 m .36061 .42417 L .36332 .42325 L F
.31125 .42399 m .31221 .42152 L .31392 .4231 L 0 .028 .127 r
F
.31125 .42399 m .30953 .42239 L .31221 .42152 L F
.654 .42657 m .65547 .42414 L .65685 .42568 L 0 .034 .135 r
F
.654 .42657 m .65262 .42505 L .65547 .42414 L F
.42036 .42756 m .42147 .42539 L .42308 .42695 L 0 .036 .138 r
F
.42036 .42756 m .41875 .42599 L .42147 .42539 L F
.79697 .42344 m .79864 .42085 L .79989 .42251 L 0 .026 .126 r
F
.79697 .42344 m .79572 .42179 L .79864 .42085 L F
.64693 .42698 m .64838 .42446 L .64977 .42601 L 0 .034 .135 r
F
.64693 .42698 m .64554 .42546 L .64838 .42446 L F
.239 .42329 m .23985 .42087 L .24163 .42253 L 0 .027 .126 r
F
.239 .42329 m .23723 .42165 L .23985 .42087 L F
.39485 .42663 m .39593 .42414 L .39756 .42578 L 0 .034 .135 r
F
.39485 .42663 m .39321 .42501 L .39593 .42414 L F
.90458 .42233 m .9064 .41975 L .90755 .4214 L 0 .024 .123 r
F
.90458 .42233 m .90343 .42067 L .9064 .41975 L F
.7361 .42453 m .73768 .42185 L .73899 .42354 L 0 .029 .129 r
F
.7361 .42453 m .73479 .42283 L .73768 .42185 L F
.27866 .42356 m .27957 .42107 L .28131 .4227 L 0 .027 .126 r
F
.27866 .42356 m .27691 .42194 L .27957 .42107 L F
.49688 .43065 m .49812 .4283 L .49965 .42987 L 0 .044 .146 r
F
.49688 .43065 m .49535 .42908 L .49812 .4283 L F
.85786 .42264 m .85961 .41994 L .86081 .42166 L 0 .025 .123 r
F
.85786 .42264 m .85666 .42091 L .85961 .41994 L F
.66108 .42637 m .66255 .42382 L .66393 .42539 L 0 .033 .134 r
F
.66108 .42637 m .6597 .42479 L .66255 .42382 L F
.31831 .42382 m .31929 .42119 L .32099 .42287 L 0 .027 .127 r
F
.31831 .42382 m .31661 .42215 L .31929 .42119 L F
.80406 .42324 m .80574 .42072 L .80699 .42237 L 0 .026 .125 r
F
.80406 .42324 m .80281 .42159 L .80574 .42072 L F
.47137 .42972 m .47257 .42725 L .47413 .42884 L 0 .041 .143 r
F
.47137 .42972 m .46981 .42809 L .47257 .42725 L F
.74318 .42424 m .74476 .42148 L .74607 .4232 L 0 .028 .128 r
F
.74318 .42424 m .74187 .42251 L .74476 .42148 L F
.53654 .43091 m .53784 .42873 L .53933 .4302 L 0 .045 .147 r
F
.53654 .43091 m .53504 .42939 L .53784 .42873 L F
.67523 .42563 m .67671 .42285 L .67808 .42458 L 0 .031 .132 r
F
.67523 .42563 m .67386 .42391 L .67671 .42285 L F
.66816 .42604 m .66963 .42325 L .67101 .42497 L 0 .032 .133 r
F
.66816 .42604 m .66678 .42432 L .66963 .42325 L F
.34381 .42486 m .34483 .42236 L .34651 .424 L 0 .03 .13 r
F
.34381 .42486 m .34214 .42319 L .34483 .42236 L F
.91167 .42213 m .91351 .41953 L .91465 .4212 L 0 .024 .122 r
F
.91167 .42213 m .91053 .42046 L .91351 .41953 L F
.75026 .42392 m .75185 .42117 L .75315 .42291 L 0 .028 .127 r
F
.75026 .42392 m .74896 .42219 L .75185 .42117 L F
.6823 .4253 m .68381 .42274 L .68517 .42442 L 0 .031 .131 r
F
.6823 .4253 m .68094 .4236 L .68381 .42274 L F
.86494 .42235 m .8667 .41967 L .86789 .42135 L 0 .024 .123 r
F
.86494 .42235 m .86375 .42067 L .8667 .41967 L F
.36932 .4259 m .37037 .42336 L .37202 .42515 L 0 .032 .133 r
F
.36932 .4259 m .36767 .42412 L .37037 .42336 L F
.75734 .42367 m .75895 .42106 L .76024 .42275 L 0 .027 .127 r
F
.75734 .42367 m .75605 .42195 L .75895 .42106 L F
.50395 .43054 m .5052 .42851 L .50673 .42994 L 0 .045 .147 r
F
.50395 .43054 m .50242 .4291 L .5052 .42851 L F
.4019 .42663 m .403 .42416 L .40462 .42585 L 0 .034 .135 r
F
.4019 .42663 m .40028 .42497 L .403 .42416 L F
.87204 .42213 m .87382 .41958 L .875 .42124 L 0 .024 .123 r
F
.87204 .42213 m .87085 .42046 L .87382 .41958 L F
.2857 .42356 m .28663 .42102 L .28836 .42271 L 0 .027 .127 r
F
.2857 .42356 m .28397 .42185 L .28663 .42102 L F
.81116 .42318 m .81284 .42051 L .81408 .42221 L 0 .026 .126 r
F
.81116 .42318 m .80992 .42149 L .81284 .42051 L F
.68939 .42515 m .69091 .42261 L .69226 .4242 L 0 .031 .131 r
F
.68939 .42515 m .68804 .42354 L .69091 .42261 L F
.91878 .42202 m .92063 .41944 L .92177 .42115 L 0 .024 .123 r
F
.91878 .42202 m .91764 .42031 L .92063 .41944 L F
.69647 .42477 m .69799 .42224 L .69933 .42376 L 0 .03 .13 r
F
.69647 .42477 m .69512 .42321 L .69799 .42224 L F
.35087 .42479 m .35189 .42237 L .35356 .42401 L F
.35087 .42479 m .3492 .42315 L .35189 .42237 L F
.24603 .42344 m .2469 .42087 L .24867 .42256 L 0 .027 .127 r
F
.24603 .42344 m .24426 .42177 L .2469 .42087 L F
.32535 .42385 m .32634 .42137 L .32803 .42312 L 0 .028 .128 r
F
.32535 .42385 m .32366 .4221 L .32634 .42137 L F
.47844 .42976 m .47964 .42754 L .4812 .4291 L 0 .042 .145 r
F
.47844 .42976 m .47689 .42818 L .47964 .42754 L F
.76443 .42349 m .76605 .42085 L .76733 .42248 L 0 .027 .127 r
F
.76443 .42349 m .76315 .42183 L .76605 .42085 L F
.42741 .42781 m .42854 .42556 L .43014 .42705 L 0 .038 .139 r
F
.42741 .42781 m .4258 .42633 L .42854 .42556 L F
.77151 .4231 m .77313 .42045 L .77441 .42209 L 0 .026 .125 r
F
.77151 .4231 m .77023 .42146 L .77313 .42045 L F
.81825 .42292 m .81993 .42019 L .82117 .42193 L F
.81825 .42292 m .81701 .4212 L .81993 .42019 L F
.70355 .4245 m .70508 .42194 L .70642 .42361 L 0 .03 .13 r
F
.70355 .4245 m .70221 .42285 L .70508 .42194 L F
.45292 .42885 m .45409 .42667 L .45567 .42825 L 0 .04 .142 r
F
.45292 .42885 m .45135 .42726 L .45409 .42667 L F
.87914 .42201 m .88092 .41934 L .8821 .42103 L 0 .024 .123 r
F
.87914 .42201 m .87796 .42032 L .88092 .41934 L F
.57192 .42951 m .57327 .42735 L .57473 .42869 L 0 .042 .144 r
F
.57192 .42951 m .57046 .42814 L .57327 .42735 L F
.54362 .4311 m .54492 .42888 L .54641 .43041 L 0 .046 .149 r
F
.54362 .4311 m .54213 .42953 L .54492 .42888 L F
.56484 .42995 m .56618 .4276 L .56765 .42897 L 0 .043 .145 r
F
.56484 .42995 m .56337 .42861 L .56618 .4276 L F
.62144 .42682 m .62286 .42436 L .62427 .42576 L 0 .035 .136 r
F
.62144 .42682 m .62003 .42542 L .62286 .42436 L F
.25308 .42329 m .25397 .42073 L .25573 .42237 L 0 .027 .126 r
F
.25308 .42329 m .25132 .42164 L .25397 .42073 L F
.58607 .4288 m .58744 .42664 L .58888 .4279 L 0 .04 .142 r
F
.58607 .4288 m .58462 .42754 L .58744 .42664 L F
.62852 .42645 m .62995 .42413 L .63136 .42564 L 0 .035 .136 r
F
.62852 .42645 m .62711 .42494 L .62995 .42413 L F
.7786 .42292 m .78024 .42035 L .78151 .42206 L 0 .026 .126 r
F
.7786 .42292 m .77732 .42122 L .78024 .42035 L F
.88623 .42175 m .88803 .41914 L .8892 .42085 L 0 .024 .122 r
F
.88623 .42175 m .88506 .42004 L .88803 .41914 L F
.9259 .42196 m .92774 .41927 L .92888 .42099 L 0 .024 .123 r
F
.9259 .42196 m .92476 .42025 L .92774 .41927 L F
.59314 .42844 m .59452 .42606 L .59596 .42755 L 0 .039 .141 r
F
.59314 .42844 m .5917 .42698 L .59452 .42606 L F
.57899 .42922 m .58036 .42708 L .58181 .42838 L 0 .042 .144 r
F
.57899 .42922 m .57754 .42788 L .58036 .42708 L F
.82534 .42275 m .82705 .42014 L .82828 .42186 L 0 .026 .125 r
F
.82534 .42275 m .82411 .42103 L .82705 .42014 L F
.29275 .42355 m .29369 .42097 L .29541 .42264 L 0 .028 .127 r
F
.29275 .42355 m .29102 .42187 L .29369 .42097 L F
.40896 .42675 m .41007 .42412 L .41169 .42585 L 0 .035 .136 r
F
.40896 .42675 m .40734 .42504 L .41007 .42412 L F
.51103 .43069 m .51228 .42861 L .5138 .42998 L 0 .046 .148 r
F
.51103 .43069 m .5095 .42933 L .51228 .42861 L F
.43447 .42778 m .43561 .42552 L .43721 .42702 L 0 .038 .14 r
F
.43447 .42778 m .43288 .42629 L .43561 .42552 L F
.71064 .42445 m .71219 .42189 L .71352 .4236 L 0 .03 .13 r
F
.71064 .42445 m .7093 .42274 L .71219 .42189 L F
.37636 .42622 m .37742 .42372 L .37907 .42548 L 0 .034 .135 r
F
.37636 .42622 m .37472 .42444 L .37742 .42372 L F
.93299 .42172 m .93486 .41912 L .93598 .42081 L 0 .024 .122 r
F
.93299 .42172 m .93186 .42003 L .93486 .41912 L F
.55777 .43058 m .5591 .42826 L .56057 .42961 L 0 .045 .147 r
F
.55777 .43058 m .55629 .42926 L .5591 .42826 L F
.29981 .42334 m .30076 .42077 L .30248 .4224 L 0 .028 .127 r
F
.29981 .42334 m .29809 .4217 L .30076 .42077 L F
.60022 .42829 m .60161 .4258 L .60305 .42744 L 0 .039 .141 r
F
.60022 .42829 m .59879 .42668 L .60161 .4258 L F
.83244 .42261 m .83415 .41993 L .83537 .4216 L 0 .026 .125 r
F
.83244 .42261 m .83122 .42093 L .83415 .41993 L F
.26013 .42321 m .26102 .4208 L .26278 .4224 L 0 .028 .127 r
F
.26013 .42321 m .25837 .42159 L .26102 .4208 L F
.61438 .42754 m .61579 .42507 L .6172 .42648 L 0 .037 .139 r
F
.61438 .42754 m .61296 .42613 L .61579 .42507 L F
.35792 .42499 m .35895 .4224 L .36061 .42417 L 0 .031 .132 r
F
.35792 .42499 m .35625 .42323 L .35895 .4224 L F
.83952 .42225 m .84124 .4196 L .84245 .42126 L 0 .025 .124 r
F
.83952 .42225 m .8383 .42059 L .84124 .4196 L F
.48551 .42992 m .48673 .42757 L .48827 .4291 L 0 .043 .146 r
F
.48551 .42992 m .48396 .42839 L .48673 .42757 L F
.89334 .42169 m .89515 .4191 L .89632 .42082 L 0 .024 .123 r
F
.89334 .42169 m .89217 .41998 L .89515 .4191 L F
.7857 .42289 m .78735 .42027 L .78862 .42197 L 0 .027 .126 r
F
.7857 .42289 m .78443 .42117 L .78735 .42027 L F
.5181 .43055 m .51937 .42831 L .52088 .42975 L 0 .045 .148 r
F
.5181 .43055 m .51658 .42914 L .51937 .42831 L F
.33239 .42409 m .33339 .4215 L .33508 .42321 L 0 .029 .129 r
F
.33239 .42409 m .33071 .42236 L .33339 .4215 L F
.41602 .42669 m .41714 .42423 L .41875 .42599 L 0 .035 .137 r
F
.41602 .42669 m .41441 .42495 L .41714 .42423 L F
.45999 .42905 m .46117 .42658 L .46274 .42819 L 0 .041 .143 r
F
.45999 .42905 m .45842 .42741 L .46117 .42658 L F
.5507 .43121 m .55201 .42873 L .55349 .43024 L 0 .047 .149 r
F
.5507 .43121 m .54921 .42972 L .55201 .42873 L F
.63561 .4265 m .63705 .42398 L .63845 .42565 L 0 .035 .136 r
F
.63561 .4265 m .6342 .42481 L .63705 .42398 L F
.9401 .4216 m .94198 .41905 L .9431 .42071 L 0 .024 .123 r
F
.9401 .4216 m .93898 .41993 L .94198 .41905 L F
.84661 .42201 m .84834 .41931 L .84955 .42105 L 0 .025 .123 r
F
.84661 .42201 m .8454 .42028 L .84834 .41931 L F
.22752 .42281 m .22837 .42025 L .23016 .42186 L 0 .027 .126 r
F
.22752 .42281 m .22573 .42122 L .22837 .42025 L F
.30687 .42321 m .30782 .4208 L .30953 .42239 L 0 .028 .127 r
F
.30687 .42321 m .30515 .4216 L .30782 .4208 L F
.44154 .42773 m .44269 .42548 L .44428 .42695 L 0 .038 .14 r
F
.44154 .42773 m .43995 .42625 L .44269 .42548 L F
.71774 .42443 m .71929 .42174 L .72062 .42343 L 0 .03 .13 r
F
.71774 .42443 m .71641 .42275 L .71929 .42174 L F
.72481 .42404 m .72638 .4214 L .7277 .42304 L 0 .029 .129 r
F
.72481 .42404 m .72349 .42241 L .72638 .4214 L F
.52518 .43033 m .52646 .42794 L .52796 .42942 L 0 .045 .147 r
F
.52518 .43033 m .52367 .42885 L .52646 .42794 L F
.38342 .42623 m .3845 .42351 L .38614 .42522 L 0 .034 .135 r
F
.38342 .42623 m .38178 .4245 L .3845 .42351 L F
.60731 .4282 m .6087 .42554 L .61013 .42717 L 0 .039 .141 r
F
.60731 .4282 m .60587 .42655 L .6087 .42554 L F
.23459 .42253 m .23544 .42001 L .23723 .42165 L 0 .026 .125 r
F
.23459 .42253 m .2328 .4209 L .23544 .42001 L F
.7928 .42273 m .79446 .42012 L .79572 .42179 L 0 .027 .126 r
F
.7928 .42273 m .79154 .42106 L .79446 .42012 L F
.26719 .42312 m .26809 .42056 L .26984 .42217 L 0 .028 .127 r
F
.26719 .42312 m .26543 .42152 L .26809 .42056 L F
.3905 .42588 m .39158 .42338 L .39321 .42501 L 0 .034 .135 r
F
.3905 .42588 m .38886 .42427 L .39158 .42338 L F
.90045 .42159 m .90227 .41901 L .90343 .42067 L 0 .024 .123 r
F
.90045 .42159 m .89929 .41992 L .90227 .41901 L F
.7319 .42376 m .73348 .42119 L .73479 .42283 L 0 .029 .129 r
F
.7319 .42376 m .73058 .42212 L .73348 .42119 L F
.53225 .43004 m .53354 .42797 L .53504 .42939 L 0 .045 .147 r
F
.53225 .43004 m .53075 .42857 L .53354 .42797 L F
.49258 .42985 m .49381 .4275 L .49535 .42908 L 0 .044 .146 r
F
.49258 .42985 m .49104 .42829 L .49381 .4275 L F
.27426 .42282 m .27516 .42032 L .27691 .42194 L 0 .027 .126 r
F
.27426 .42282 m .27251 .42121 L .27516 .42032 L F
.85371 .42185 m .85545 .41917 L .85666 .42091 L 0 .025 .123 r
F
.85371 .42185 m .8525 .42011 L .85545 .41917 L F
.46706 .42893 m .46825 .4266 L .46981 .42809 L 0 .041 .143 r
F
.46706 .42893 m .46549 .42737 L .46825 .4266 L F
.33945 .42404 m .34046 .42151 L .34214 .42319 L 0 .03 .13 r
F
.33945 .42404 m .33777 .42234 L .34046 .42151 L F
.64977 .42601 m .65123 .42347 L .65262 .42505 L 0 .034 .135 r
F
.64977 .42601 m .64838 .42446 L .65123 .42347 L F
.36497 .42503 m .36602 .42233 L .36767 .42412 L 0 .032 .132 r
F
.36497 .42503 m .36332 .42325 L .36602 .42233 L F
.79989 .42251 m .80156 .41994 L .80281 .42159 L 0 .026 .126 r
F
.79989 .42251 m .79864 .42085 L .80156 .41994 L F
.64269 .42644 m .64414 .42381 L .64554 .42546 L 0 .035 .136 r
F
.64269 .42644 m .6413 .42479 L .64414 .42381 L F
.31392 .4231 m .31489 .42055 L .31661 .42215 L 0 .028 .127 r
F
.31392 .4231 m .31221 .42152 L .31489 .42055 L F
.65685 .42568 m .65832 .42323 L .6597 .42479 L 0 .034 .135 r
F
.65685 .42568 m .65547 .42414 L .65832 .42323 L F
.73899 .42354 m .74056 .42082 L .74187 .42251 L 0 .028 .128 r
F
.73899 .42354 m .73768 .42185 L .74056 .42082 L F
.90755 .4214 m .90938 .41882 L .91053 .42046 L 0 .024 .123 r
F
.90755 .4214 m .9064 .41975 L .90938 .41882 L F
.74607 .4232 m .74765 .42045 L .74896 .42219 L 0 .028 .127 r
F
.74607 .4232 m .74476 .42148 L .74765 .42045 L F
.67101 .42497 m .67248 .42218 L .67386 .42391 L 0 .031 .132 r
F
.67101 .42497 m .66963 .42325 L .67248 .42218 L F
.67808 .42458 m .67957 .42185 L .68094 .4236 L 0 .031 .131 r
F
.67808 .42458 m .67671 .42285 L .67957 .42185 L F
.39756 .42578 m .39865 .42328 L .40028 .42497 L 0 .034 .135 r
F
.39756 .42578 m .39593 .42414 L .39865 .42328 L F
.86081 .42166 m .86256 .41895 L .86375 .42067 L 0 .025 .123 r
F
.86081 .42166 m .85961 .41994 L .86256 .41895 L F
.66393 .42539 m .66541 .42277 L .66678 .42432 L 0 .033 .134 r
F
.66393 .42539 m .66255 .42382 L .66541 .42277 L F
.32099 .42287 m .32197 .42042 L .32366 .4221 L 0 .028 .127 r
F
.32099 .42287 m .31929 .42119 L .32197 .42042 L F
.28131 .4227 m .28223 .42021 L .28397 .42185 L 0 .027 .127 r
F
.28131 .4227 m .27957 .42107 L .28223 .42021 L F
.44861 .42781 m .44976 .42578 L .45135 .42726 L 0 .04 .142 r
F
.44861 .42781 m .44702 .42634 L .44976 .42578 L F
.75315 .42291 m .75475 .4202 L .75605 .42195 L 0 .027 .127 r
F
.75315 .42291 m .75185 .42117 L .75475 .4202 L F
.86789 .42135 m .86967 .41879 L .87085 .42046 L 0 .024 .123 r
F
.86789 .42135 m .8667 .41967 L .86967 .41879 L F
.24163 .42253 m .24249 .42009 L .24426 .42177 L 0 .027 .126 r
F
.24163 .42253 m .23985 .42087 L .24249 .42009 L F
.47413 .42884 m .47533 .42661 L .47689 .42818 L 0 .042 .144 r
F
.47413 .42884 m .47257 .42725 L .47533 .42661 L F
.80699 .42237 m .80868 .41985 L .80992 .42149 L 0 .027 .126 r
F
.80699 .42237 m .80574 .42072 L .80868 .41985 L F
.91465 .4212 m .9165 .41864 L .91764 .42031 L 0 .024 .122 r
F
.91465 .4212 m .91351 .41953 L .9165 .41864 L F
.49965 .42987 m .50089 .42754 L .50242 .4291 L 0 .044 .147 r
F
.49965 .42987 m .49812 .4283 L .50089 .42754 L F
.42308 .42695 m .4242 .42479 L .4258 .42633 L 0 .037 .139 r
F
.42308 .42695 m .42147 .42539 L .4242 .42479 L F
.34651 .424 m .34752 .42153 L .3492 .42315 L 0 .03 .13 r
F
.34651 .424 m .34483 .42236 L .34752 .42153 L F
.68517 .42442 m .68668 .42187 L .68804 .42354 L 0 .031 .131 r
F
.68517 .42442 m .68381 .42274 L .68668 .42187 L F
.53933 .4302 m .54063 .42809 L .54213 .42953 L 0 .046 .148 r
F
.53933 .4302 m .53784 .42873 L .54063 .42809 L F
.76024 .42275 m .76186 .42016 L .76315 .42183 L 0 .027 .127 r
F
.76024 .42275 m .75895 .42106 L .76186 .42016 L F
.69933 .42376 m .70087 .42131 L .70221 .42285 L 0 .03 .13 r
F
.69933 .42376 m .69799 .42224 L .70087 .42131 L F
.37202 .42515 m .37307 .42267 L .37472 .42444 L 0 .033 .134 r
F
.37202 .42515 m .37037 .42336 L .37307 .42267 L F
.81408 .42221 m .81577 .41949 L .81701 .4212 L 0 .026 .125 r
F
.81408 .42221 m .81284 .42051 L .81577 .41949 L F
.875 .42124 m .87679 .41868 L .87796 .42032 L 0 .024 .123 r
F
.875 .42124 m .87382 .41958 L .87679 .41868 L F
.69226 .4242 m .69378 .42166 L .69512 .42321 L 0 .031 .131 r
F
.69226 .4242 m .69091 .42261 L .69378 .42166 L F
.77441 .42209 m .77605 .41957 L .77732 .42122 L 0 .026 .125 r
F
.77441 .42209 m .77313 .42045 L .77605 .41957 L F
.76733 .42248 m .76895 .41984 L .77023 .42146 L 0 .027 .126 r
F
.76733 .42248 m .76605 .42085 L .76895 .41984 L F
.82117 .42193 m .82287 .41928 L .82411 .42103 L 0 .026 .125 r
F
.82117 .42193 m .81993 .42019 L .82287 .41928 L F
.40462 .42585 m .40572 .42331 L .40734 .42504 L 0 .035 .136 r
F
.40462 .42585 m .403 .42416 L .40572 .42331 L F
.28836 .42271 m .28929 .42018 L .29102 .42187 L 0 .028 .127 r
F
.28836 .42271 m .28663 .42102 L .28929 .42018 L F
.92177 .42115 m .92362 .41853 L .92476 .42025 L 0 .024 .123 r
F
.92177 .42115 m .92063 .41944 L .92362 .41853 L F
.24867 .42256 m .24956 .41992 L .25132 .42164 L 0 .027 .127 r
F
.24867 .42256 m .2469 .42087 L .24956 .41992 L F
.8821 .42103 m .88388 .41836 L .88506 .42004 L 0 .024 .122 r
F
.8821 .42103 m .88092 .41934 L .88388 .41836 L F
.62427 .42576 m .6257 .42354 L .62711 .42494 L 0 .035 .136 r
F
.62427 .42576 m .62286 .42436 L .6257 .42354 L F
.35356 .42401 m .35458 .42159 L .35625 .42323 L 0 .031 .131 r
F
.35356 .42401 m .35189 .42237 L .35458 .42159 L F
.70642 .42361 m .70796 .42105 L .7093 .42274 L 0 .03 .13 r
F
.70642 .42361 m .70508 .42194 L .70796 .42105 L F
.50673 .42994 m .50798 .42791 L .5095 .42933 L 0 .046 .148 r
F
.50673 .42994 m .5052 .42851 L .50798 .42791 L F
.56765 .42897 m .56899 .42677 L .57046 .42814 L 0 .043 .145 r
F
.56765 .42897 m .56618 .4276 L .56899 .42677 L F
.32803 .42312 m .32902 .42062 L .33071 .42236 L 0 .029 .129 r
F
.32803 .42312 m .32634 .42137 L .32902 .42062 L F
.43014 .42705 m .43127 .42479 L .43288 .42629 L 0 .038 .14 r
F
.43014 .42705 m .42854 .42556 L .43127 .42479 L F
.92888 .42099 m .93073 .4183 L .93186 .42003 L 0 .024 .122 r
F
.92888 .42099 m .92774 .41927 L .93073 .4183 L F
.25573 .42237 m .25661 .41996 L .25837 .42159 L 0 .027 .127 r
F
.25573 .42237 m .25397 .42073 L .25661 .41996 L F
.58888 .4279 m .59026 .42567 L .5917 .42698 L 0 .04 .142 r
F
.58888 .4279 m .58744 .42664 L .59026 .42567 L F
.57473 .42869 m .57608 .42656 L .57754 .42788 L 0 .043 .145 r
F
.57473 .42869 m .57327 .42735 L .57608 .42656 L F
.8892 .42085 m .891 .41825 L .89217 .41998 L 0 .024 .122 r
F
.8892 .42085 m .88803 .41914 L .891 .41825 L F
.4812 .4291 m .48241 .42685 L .48396 .42839 L 0 .043 .146 r
F
.4812 .4291 m .47964 .42754 L .48241 .42685 L F
.29541 .42264 m .29636 .42005 L .29809 .4217 L 0 .028 .127 r
F
.29541 .42264 m .29369 .42097 L .29636 .42005 L F
.59596 .42755 m .59735 .42514 L .59879 .42668 L 0 .039 .141 r
F
.59596 .42755 m .59452 .42606 L .59735 .42514 L F
.82828 .42186 m .82999 .4192 L .83122 .42093 L 0 .026 .125 r
F
.82828 .42186 m .82705 .42014 L .82999 .4192 L F
.78151 .42206 m .78316 .41946 L .78443 .42117 L 0 .027 .126 r
F
.78151 .42206 m .78024 .42035 L .78316 .41946 L F
.58181 .42838 m .58318 .42628 L .58462 .42754 L 0 .042 .144 r
F
.58181 .42838 m .58036 .42708 L .58318 .42628 L F
.63136 .42564 m .6328 .42331 L .6342 .42481 L 0 .035 .136 r
F
.63136 .42564 m .62995 .42413 L .6328 .42331 L F
.41169 .42585 m .4128 .4232 L .41441 .42495 L F
.41169 .42585 m .41007 .42412 L .4128 .4232 L F
.56057 .42961 m .5619 .42723 L .56337 .42861 L 0 .045 .147 r
F
.56057 .42961 m .5591 .42826 L .5619 .42723 L F
.6172 .42648 m .61862 .42401 L .62003 .42542 L 0 .037 .138 r
F
.6172 .42648 m .61579 .42507 L .61862 .42401 L F
.54641 .43041 m .54773 .42823 L .54921 .42972 L 0 .047 .15 r
F
.54641 .43041 m .54492 .42888 L .54773 .42823 L F
.45567 .42825 m .45684 .42583 L .45842 .42741 L 0 .041 .143 r
F
.45567 .42825 m .45409 .42667 L .45684 .42583 L F
.93598 .42081 m .93786 .41825 L .93898 .41993 L 0 .024 .122 r
F
.93598 .42081 m .93486 .41912 L .93786 .41825 L F
.83537 .4216 m .83709 .41892 L .8383 .42059 L 0 .026 .124 r
F
.83537 .4216 m .83415 .41993 L .83709 .41892 L F
.30248 .4224 m .30343 .41998 L .30515 .4216 L 0 .028 .127 r
F
.30248 .4224 m .30076 .42077 L .30343 .41998 L F
.71352 .4236 m .71508 .42104 L .71641 .42275 L 0 .03 .13 r
F
.71352 .4236 m .71219 .42189 L .71508 .42104 L F
.84245 .42126 m .84419 .41862 L .8454 .42028 L 0 .025 .124 r
F
.84245 .42126 m .84124 .4196 L .84419 .41862 L F
.43721 .42702 m .43835 .42474 L .43995 .42625 L 0 .039 .14 r
F
.43721 .42702 m .43561 .42552 L .43835 .42474 L F
.5138 .42998 m .51507 .42774 L .51658 .42914 L 0 .046 .149 r
F
.5138 .42998 m .51228 .42861 L .51507 .42774 L F
.60305 .42744 m .60444 .42489 L .60587 .42655 L 0 .039 .141 r
F
.60305 .42744 m .60161 .4258 L .60444 .42489 L F
.37907 .42548 m .38014 .42276 L .38178 .4245 L 0 .034 .135 r
F
.37907 .42548 m .37742 .42372 L .38014 .42276 L F
.78862 .42197 m .79028 .41936 L .79154 .42106 L 0 .027 .126 r
F
.78862 .42197 m .78735 .42027 L .79028 .41936 L F
.55349 .43024 m .55481 .42774 L .55629 .42926 L 0 .046 .149 r
F
.55349 .43024 m .55201 .42873 L .55481 .42774 L F
.89632 .42082 m .89813 .4182 L .89929 .41992 L 0 .024 .123 r
F
.89632 .42082 m .89515 .4191 L .89813 .4182 L F
.26278 .4224 m .26367 .41992 L .26543 .42152 L 0 .028 .127 r
F
.26278 .4224 m .26102 .4208 L .26367 .41992 L F
.36061 .42417 m .36166 .42147 L .36332 .42325 L 0 .031 .132 r
F
.36061 .42417 m .35895 .4224 L .36166 .42147 L F
.84955 .42105 m .85129 .41837 L .8525 .42011 L 0 .025 .123 r
F
.84955 .42105 m .84834 .41931 L .85129 .41837 L F
.48827 .4291 m .48949 .42674 L .49104 .42829 L 0 .044 .146 r
F
.48827 .4291 m .48673 .42757 L .48949 .42674 L F
.33508 .42321 m .33608 .42064 L .33777 .42234 L 0 .029 .129 r
F
.33508 .42321 m .33339 .4215 L .33608 .42064 L F
.23016 .42186 m .23101 .41929 L .2328 .4209 L 0 .027 .126 r
F
.23016 .42186 m .22837 .42025 L .23101 .41929 L F
.72062 .42343 m .72217 .4207 L .72349 .42241 L 0 .03 .13 r
F
.72062 .42343 m .71929 .42174 L .72217 .4207 L F
.61013 .42717 m .61153 .42453 L .61296 .42613 L 0 .038 .14 r
F
.61013 .42717 m .6087 .42554 L .61153 .42453 L F
.7277 .42304 m .72927 .42047 L .73058 .42212 L 0 .029 .129 r
F
.7277 .42304 m .72638 .4214 L .72927 .42047 L F
.38614 .42522 m .38722 .42259 L .38886 .42427 L 0 .034 .135 r
F
.38614 .42522 m .3845 .42351 L .38722 .42259 L F
.52088 .42975 m .52216 .4274 L .52367 .42885 L 0 .045 .148 r
F
.52088 .42975 m .51937 .42831 L .52216 .4274 L F
.46274 .42819 m .46392 .42581 L .46549 .42737 L 0 .041 .144 r
F
.46274 .42819 m .46117 .42658 L .46392 .42581 L F
.63845 .42565 m .6399 .42315 L .6413 .42479 L 0 .035 .136 r
F
.63845 .42565 m .63705 .42398 L .6399 .42315 L F
.52796 .42942 m .52925 .4271 L .53075 .42857 L 0 .045 .147 r
F
.52796 .42942 m .52646 .42794 L .52925 .4271 L F
.26984 .42217 m .27075 .41961 L .27251 .42121 L 0 .027 .127 r
F
.26984 .42217 m .26809 .42056 L .27075 .41961 L F
.79572 .42179 m .79738 .41918 L .79864 .42085 L 0 .027 .126 r
F
.79572 .42179 m .79446 .42012 L .79738 .41918 L F
.30953 .42239 m .31049 .41993 L .31221 .42152 L 0 .028 .128 r
F
.30953 .42239 m .30782 .4208 L .31049 .41993 L F
.44428 .42695 m .44543 .42487 L .44702 .42634 L 0 .039 .141 r
F
.44428 .42695 m .44269 .42548 L .44543 .42487 L F
.23723 .42165 m .23807 .41922 L .23985 .42087 L 0 .027 .126 r
F
.23723 .42165 m .23544 .42001 L .23807 .41922 L F
.73479 .42283 m .73637 .42021 L .73768 .42185 L 0 .029 .129 r
F
.73479 .42283 m .73348 .42119 L .73637 .42021 L F
.90343 .42067 m .90525 .41809 L .9064 .41975 L 0 .024 .123 r
F
.90343 .42067 m .90227 .41901 L .90525 .41809 L F
.41875 .42599 m .41987 .42362 L .42147 .42539 L 0 .036 .138 r
F
.41875 .42599 m .41714 .42423 L .41987 .42362 L F
.39321 .42501 m .3943 .42249 L .39593 .42414 L 0 .034 .135 r
F
.39321 .42501 m .39158 .42338 L .3943 .42249 L F
.85666 .42091 m .8584 .4182 L .85961 .41994 L 0 .025 .123 r
F
.85666 .42091 m .85545 .41917 L .8584 .4182 L F
.65262 .42505 m .65408 .42254 L .65547 .42414 L 0 .034 .135 r
F
.65262 .42505 m .65123 .42347 L .65408 .42254 L F
.74187 .42251 m .74345 .41979 L .74476 .42148 L 0 .028 .128 r
F
.74187 .42251 m .74056 .42082 L .74345 .41979 L F
.64554 .42546 m .64699 .42278 L .64838 .42446 L 0 .035 .136 r
F
.64554 .42546 m .64414 .42381 L .64699 .42278 L F
.27691 .42194 m .27783 .41944 L .27957 .42107 L 0 .027 .127 r
F
.27691 .42194 m .27516 .42032 L .27783 .41944 L F
.67386 .42391 m .67534 .4211 L .67671 .42285 L 0 .031 .131 r
F
.67386 .42391 m .67248 .42218 L .67534 .4211 L F
.31661 .42215 m .31758 .41959 L .31929 .42119 L 0 .028 .127 r
F
.31661 .42215 m .31489 .42055 L .31758 .41959 L F
.36767 .42412 m .36872 .42159 L .37037 .42336 L 0 .032 .132 r
F
.36767 .42412 m .36602 .42233 L .36872 .42159 L F
.66678 .42432 m .66826 .42172 L .66963 .42325 L 0 .032 .133 r
F
.66678 .42432 m .66541 .42277 L .66826 .42172 L F
.80281 .42159 m .8045 .41907 L .80574 .42072 L 0 .026 .126 r
F
.80281 .42159 m .80156 .41994 L .8045 .41907 L F
.74896 .42219 m .75055 .41942 L .75185 .42117 L 0 .027 .127 r
F
.74896 .42219 m .74765 .42045 L .75055 .41942 L F
.46981 .42809 m .47101 .42582 L .47257 .42725 L 0 .042 .144 r
F
.46981 .42809 m .46825 .4266 L .47101 .42582 L F
.49535 .42908 m .49658 .42673 L .49812 .4283 L 0 .044 .147 r
F
.49535 .42908 m .49381 .4275 L .49658 .42673 L F
.34214 .42319 m .34315 .42071 L .34483 .42236 L 0 .03 .13 r
F
.34214 .42319 m .34046 .42151 L .34315 .42071 L F
.68094 .4236 m .68245 .421 L .68381 .42274 L 0 .031 .131 r
F
.68094 .4236 m .67957 .42185 L .68245 .421 L F
.91053 .42046 m .91237 .41788 L .91351 .41953 L 0 .024 .122 r
F
.91053 .42046 m .90938 .41882 L .91237 .41788 L F
.86375 .42067 m .86551 .41795 L .8667 .41967 L 0 .024 .123 r
F
.86375 .42067 m .86256 .41895 L .86551 .41795 L F
.6597 .42479 m .66118 .42226 L .66255 .42382 L 0 .033 .134 r
F
.6597 .42479 m .65832 .42323 L .66118 .42226 L F
.53504 .42939 m .53634 .42737 L .53784 .42873 L 0 .046 .148 r
F
.53504 .42939 m .53354 .42797 L .53634 .42737 L F
.75605 .42195 m .75766 .41931 L .75895 .42106 L 0 .027 .127 r
F
.75605 .42195 m .75475 .4202 L .75766 .41931 L F
.40028 .42497 m .40138 .42244 L .403 .42416 L 0 .034 .135 r
F
.40028 .42497 m .39865 .42328 L .40138 .42244 L F
.87085 .42046 m .87264 .41792 L .87382 .41958 L 0 .024 .123 r
F
.87085 .42046 m .86967 .41879 L .87264 .41792 L F
.28397 .42185 m .28489 .41935 L .28663 .42102 L 0 .027 .127 r
F
.28397 .42185 m .28223 .42021 L .28489 .41935 L F
.80992 .42149 m .81161 .41887 L .81284 .42051 L 0 .026 .126 r
F
.80992 .42149 m .80868 .41985 L .81161 .41887 L F
.91764 .42031 m .91949 .41777 L .92063 .41944 L 0 .024 .123 r
F
.91764 .42031 m .9165 .41864 L .91949 .41777 L F
.32366 .4221 m .32464 .41969 L .32634 .42137 L 0 .028 .128 r
F
.32366 .4221 m .32197 .42042 L .32464 .41969 L F
.24426 .42177 m .24513 .41917 L .2469 .42087 L 0 .027 .127 r
F
.24426 .42177 m .24249 .42009 L .24513 .41917 L F
.3492 .42315 m .35021 .42077 L .35189 .42237 L 0 .03 .131 r
F
.3492 .42315 m .34752 .42153 L .35021 .42077 L F
.68804 .42354 m .68955 .42096 L .69091 .42261 L 0 .031 .131 r
F
.68804 .42354 m .68668 .42187 L .68955 .42096 L F
.81701 .4212 m .81869 .41846 L .81993 .42019 L 0 .026 .125 r
F
.81701 .4212 m .81577 .41949 L .81869 .41846 L F
.76315 .42183 m .76477 .4192 L .76605 .42085 L 0 .027 .127 r
F
.76315 .42183 m .76186 .42016 L .76477 .4192 L F
.50242 .4291 m .50367 .42694 L .5052 .42851 L 0 .045 .148 r
F
.50242 .4291 m .50089 .42754 L .50367 .42694 L F
.69512 .42321 m .69665 .4207 L .69799 .42224 L 0 .03 .131 r
F
.69512 .42321 m .69378 .42166 L .69665 .4207 L F
.77023 .42146 m .77186 .41885 L .77313 .42045 L 0 .027 .126 r
F
.77023 .42146 m .76895 .41984 L .77186 .41885 L F
.70221 .42285 m .70375 .42039 L .70508 .42194 L 0 .03 .13 r
F
.70221 .42285 m .70087 .42131 L .70375 .42039 L F
.87796 .42032 m .87975 .41771 L .88092 .41934 L 0 .024 .123 r
F
.87796 .42032 m .87679 .41868 L .87975 .41771 L F
.47689 .42818 m .47809 .42599 L .47964 .42754 L 0 .043 .145 r
F
.47689 .42818 m .47533 .42661 L .47809 .42599 L F
.45135 .42726 m .45251 .42517 L .45409 .42667 L 0 .041 .143 r
F
.45135 .42726 m .44976 .42578 L .45251 .42517 L F
.77732 .42122 m .77897 .4187 L .78024 .42035 L 0 .026 .126 r
F
.77732 .42122 m .77605 .41957 L .77897 .4187 L F
.88506 .42004 m .88685 .41745 L .88803 .41914 L 0 .024 .122 r
F
.88506 .42004 m .88388 .41836 L .88685 .41745 L F
.4258 .42633 m .42693 .42401 L .42854 .42556 L 0 .038 .14 r
F
.4258 .42633 m .4242 .42479 L .42693 .42401 L F
.82411 .42103 m .82581 .41836 L .82705 .42014 L 0 .026 .125 r
F
.82411 .42103 m .82287 .41928 L .82581 .41836 L F
.92476 .42025 m .9266 .41755 L .92774 .41927 L 0 .024 .123 r
F
.92476 .42025 m .92362 .41853 L .9266 .41755 L F
.25132 .42164 m .25221 .419 L .25397 .42073 L 0 .027 .126 r
F
.25132 .42164 m .24956 .41992 L .25221 .419 L F
.29102 .42187 m .29196 .41929 L .29369 .42097 L 0 .028 .127 r
F
.29102 .42187 m .28929 .42018 L .29196 .41929 L F
.54213 .42953 m .54343 .42748 L .54492 .42888 L 0 .047 .149 r
F
.54213 .42953 m .54063 .42809 L .54343 .42748 L F
.37472 .42444 m .37578 .42196 L .37742 .42372 L 0 .034 .135 r
F
.37472 .42444 m .37307 .42267 L .37578 .42196 L F
.40734 .42504 m .40845 .42237 L .41007 .42412 L 0 .035 .136 r
F
.40734 .42504 m .40572 .42331 L .40845 .42237 L F
.7093 .42274 m .71085 .4202 L .71219 .42189 L 0 .03 .13 r
F
.7093 .42274 m .70796 .42105 L .71085 .4202 L F
.93186 .42003 m .93372 .41739 L .93486 .41912 L 0 .024 .122 r
F
.93186 .42003 m .93073 .4183 L .93372 .41739 L F
.62711 .42494 m .62855 .42273 L .62995 .42413 L 0 .035 .137 r
F
.62711 .42494 m .6257 .42354 L .62855 .42273 L F
.57046 .42814 m .57181 .42601 L .57327 .42735 L 0 .043 .146 r
F
.57046 .42814 m .56899 .42677 L .57181 .42601 L F
.35625 .42323 m .35728 .42077 L .35895 .4224 L 0 .031 .132 r
F
.35625 .42323 m .35458 .42159 L .35728 .42077 L F
.5917 .42698 m .59308 .42471 L .59452 .42606 L 0 .04 .142 r
F
.5917 .42698 m .59026 .42567 L .59308 .42471 L F
.62003 .42542 m .62145 .42296 L .62286 .42436 L 0 .036 .138 r
F
.62003 .42542 m .61862 .42401 L .62145 .42296 L F
.29809 .4217 m .29904 .41913 L .30076 .42077 L 0 .028 .127 r
F
.29809 .4217 m .29636 .42005 L .29904 .41913 L F
.83122 .42093 m .83293 .41821 L .83415 .41993 L 0 .026 .125 r
F
.83122 .42093 m .82999 .4192 L .83293 .41821 L F
.56337 .42861 m .56471 .4262 L .56618 .4276 L 0 .044 .146 r
F
.56337 .42861 m .5619 .42723 L .56471 .4262 L F
.89217 .41998 m .89398 .41737 L .89515 .4191 L 0 .024 .122 r
F
.89217 .41998 m .891 .41825 L .89398 .41737 L F
.78443 .42117 m .78608 .41855 L .78735 .42027 L 0 .027 .126 r
F
.78443 .42117 m .78316 .41946 L .78608 .41855 L F
.59879 .42668 m .60017 .42423 L .60161 .4258 L 0 .039 .141 r
F
.59879 .42668 m .59735 .42514 L .60017 .42423 L F
.8383 .42059 m .84003 .41794 L .84124 .4196 L 0 .025 .124 r
F
.8383 .42059 m .83709 .41892 L .84003 .41794 L F
.33071 .42236 m .3317 .41978 L .33339 .4215 L 0 .029 .129 r
F
.33071 .42236 m .32902 .42062 L .3317 .41978 L F
.43288 .42629 m .43401 .42401 L .43561 .42552 L 0 .039 .14 r
F
.43288 .42629 m .43127 .42479 L .43401 .42401 L F
.25837 .42159 m .25925 .41918 L .26102 .4208 L 0 .028 .127 r
F
.25837 .42159 m .25661 .41996 L .25925 .41918 L F
.57754 .42788 m .5789 .42578 L .58036 .42708 L 0 .043 .145 r
F
.57754 .42788 m .57608 .42656 L .5789 .42578 L F
.41441 .42495 m .41553 .42246 L .41714 .42423 L 0 .035 .136 r
F
.41441 .42495 m .4128 .4232 L .41553 .42246 L F
.58462 .42754 m .586 .42537 L .58744 .42664 L 0 .042 .144 r
F
.58462 .42754 m .58318 .42628 L .586 .42537 L F
.8454 .42028 m .84713 .41764 L .84834 .41931 L 0 .025 .123 r
F
.8454 .42028 m .84419 .41862 L .84713 .41764 L F
.6342 .42481 m .63565 .42249 L .63705 .42398 L 0 .035 .136 r
F
.6342 .42481 m .6328 .42331 L .63565 .42249 L F
.5095 .42933 m .51076 .42718 L .51228 .42861 L 0 .047 .149 r
F
.5095 .42933 m .50798 .42791 L .51076 .42718 L F
.93898 .41993 m .94086 .41738 L .94198 .41905 L 0 .024 .123 r
F
.93898 .41993 m .93786 .41825 L .94086 .41738 L F
.48396 .42839 m .48518 .42602 L .48673 .42757 L 0 .044 .146 r
F
.48396 .42839 m .48241 .42685 L .48518 .42602 L F
.45842 .42741 m .4596 .425 L .46117 .42658 L 0 .041 .143 r
F
.45842 .42741 m .45684 .42583 L .4596 .425 L F
.38178 .4245 m .38286 .42179 L .3845 .42351 L 0 .034 .135 r
F
.38178 .4245 m .38014 .42276 L .38286 .42179 L F
.71641 .42275 m .71796 .42001 L .71929 .42174 L 0 .03 .13 r
F
.71641 .42275 m .71508 .42104 L .71796 .42001 L F
.55629 .42926 m .55762 .42673 L .5591 .42826 L 0 .046 .148 r
F
.55629 .42926 m .55481 .42774 L .55762 .42673 L F
.30515 .4216 m .3061 .4192 L .30782 .4208 L 0 .028 .128 r
F
.30515 .4216 m .30343 .41998 L .3061 .4192 L F
.61296 .42613 m .61436 .4235 L .61579 .42507 L 0 .038 .14 r
F
.61296 .42613 m .61153 .42453 L .61436 .4235 L F
.22573 .42122 m .22657 .41865 L .22837 .42025 L 0 .027 .126 r
F
.22573 .42122 m .22393 .41962 L .22657 .41865 L F
.72349 .42241 m .72505 .41968 L .72638 .4214 L 0 .029 .129 r
F
.72349 .42241 m .72217 .4207 L .72505 .41968 L F
.60587 .42655 m .60727 .42391 L .6087 .42554 L 0 .039 .141 r
F
.60587 .42655 m .60444 .42489 L .60727 .42391 L F
.79154 .42106 m .7932 .41841 L .79446 .42012 L 0 .027 .126 r
F
.79154 .42106 m .79028 .41936 L .7932 .41841 L F
.54921 .42972 m .55053 .42723 L .55201 .42873 L 0 .047 .15 r
F
.54921 .42972 m .54773 .42823 L .55053 .42723 L F
.51658 .42914 m .51785 .42687 L .51937 .42831 L 0 .046 .149 r
F
.51658 .42914 m .51507 .42774 L .51785 .42687 L F
.36332 .42325 m .36437 .42054 L .36602 .42233 L 0 .031 .132 r
F
.36332 .42325 m .36166 .42147 L .36437 .42054 L F
.8525 .42011 m .85424 .41744 L .85545 .41917 L 0 .025 .123 r
F
.8525 .42011 m .85129 .41837 L .85424 .41744 L F
.89929 .41992 m .90111 .4173 L .90227 .41901 L 0 .024 .123 r
F
.89929 .41992 m .89813 .4182 L .90111 .4173 L F
.2328 .4209 m .23365 .41839 L .23544 .42001 L 0 .027 .126 r
F
.2328 .4209 m .23101 .41929 L .23365 .41839 L F
.26543 .42152 m .26633 .41896 L .26809 .42056 L 0 .028 .127 r
F
.26543 .42152 m .26367 .41992 L .26633 .41896 L F
.38886 .42427 m .38994 .42173 L .39158 .42338 L 0 .034 .135 r
F
.38886 .42427 m .38722 .42259 L .38994 .42173 L F
.73058 .42212 m .73216 .41953 L .73348 .42119 L 0 .029 .129 r
F
.73058 .42212 m .72927 .42047 L .73216 .41953 L F
.43995 .42625 m .4411 .42396 L .44269 .42548 L 0 .039 .141 r
F
.43995 .42625 m .43835 .42474 L .4411 .42396 L F
.33777 .42234 m .33877 .41983 L .34046 .42151 L 0 .03 .13 r
F
.33777 .42234 m .33608 .42064 L .33877 .41983 L F
.52367 .42885 m .52495 .42648 L .52646 .42794 L 0 .045 .148 r
F
.52367 .42885 m .52216 .4274 L .52495 .42648 L F
.27251 .42121 m .27341 .41871 L .27516 .42032 L 0 .027 .127 r
F
.27251 .42121 m .27075 .41961 L .27341 .41871 L F
.49104 .42829 m .49227 .42599 L .49381 .4275 L 0 .044 .146 r
F
.49104 .42829 m .48949 .42674 L .49227 .42599 L F
.79864 .42085 m .80031 .41827 L .80156 .41994 L 0 .027 .126 r
F
.79864 .42085 m .79738 .41918 L .80031 .41827 L F
.73768 .42185 m .73926 .4192 L .74056 .42082 L 0 .028 .128 r
F
.73768 .42185 m .73637 .42021 L .73926 .4192 L F
.6413 .42479 m .64274 .42214 L .64414 .42381 L 0 .035 .136 r
F
.6413 .42479 m .6399 .42315 L .64274 .42214 L F
.67671 .42285 m .6782 .4201 L .67957 .42185 L 0 .031 .131 r
F
.67671 .42285 m .67534 .4211 L .6782 .4201 L F
.74476 .42148 m .74635 .41876 L .74765 .42045 L 0 .028 .127 r
F
.74476 .42148 m .74345 .41979 L .74635 .41876 L F
.46549 .42737 m .46668 .4251 L .46825 .4266 L 0 .042 .144 r
F
.46549 .42737 m .46392 .42581 L .46668 .4251 L F
.66963 .42325 m .67112 .42065 L .67248 .42218 L 0 .032 .132 r
F
.66963 .42325 m .66826 .42172 L .67112 .42065 L F
.53075 .42857 m .53204 .42656 L .53354 .42797 L 0 .046 .148 r
F
.53075 .42857 m .52925 .4271 L .53204 .42656 L F
.85961 .41994 m .86136 .41721 L .86256 .41895 L 0 .024 .123 r
F
.85961 .41994 m .8584 .4182 L .86136 .41721 L F
.64838 .42446 m .64984 .42177 L .65123 .42347 L 0 .034 .135 r
F
.64838 .42446 m .64699 .42278 L .64984 .42177 L F
.31221 .42152 m .31318 .41896 L .31489 .42055 L 0 .028 .128 r
F
.31221 .42152 m .31049 .41993 L .31318 .41896 L F
.9064 .41975 m .90824 .41716 L .90938 .41882 L 0 .024 .123 r
F
.9064 .41975 m .90525 .41809 L .90824 .41716 L F
.75185 .42117 m .75345 .41844 L .75475 .4202 L 0 .027 .126 r
F
.75185 .42117 m .75055 .41942 L .75345 .41844 L F
.31929 .42119 m .32026 .41881 L .32197 .42042 L 0 .028 .127 r
F
.31929 .42119 m .31758 .41959 L .32026 .41881 L F
.39593 .42414 m .39702 .4216 L .39865 .42328 L 0 .034 .135 r
F
.39593 .42414 m .3943 .42249 L .39702 .4216 L F
.65547 .42414 m .65694 .42161 L .65832 .42323 L F
.65547 .42414 m .65408 .42254 L .65694 .42161 L F
.8667 .41967 m .86848 .41708 L .86967 .41879 L 0 .024 .123 r
F
.8667 .41967 m .86551 .41795 L .86848 .41708 L F
.66255 .42382 m .66403 .42123 L .66541 .42277 L 0 .033 .134 r
F
.66255 .42382 m .66118 .42226 L .66403 .42123 L F
.23985 .42087 m .24071 .41842 L .24249 .42009 L 0 .027 .126 r
F
.23985 .42087 m .23807 .41922 L .24071 .41842 L F
.27957 .42107 m .28049 .41856 L .28223 .42021 L 0 .027 .127 r
F
.27957 .42107 m .27783 .41944 L .28049 .41856 L F
.91351 .41953 m .91536 .417 L .9165 .41864 L 0 .024 .122 r
F
.91351 .41953 m .91237 .41788 L .91536 .417 L F
.80574 .42072 m .80743 .41821 L .80868 .41985 L 0 .027 .126 r
F
.80574 .42072 m .8045 .41907 L .80743 .41821 L F
.47257 .42725 m .47377 .4252 L .47533 .42661 L 0 .043 .145 r
F
.47257 .42725 m .47101 .42582 L .47377 .4252 L F
.68381 .42274 m .68532 .42014 L .68668 .42187 L 0 .031 .131 r
F
.68381 .42274 m .68245 .421 L .68532 .42014 L F
.34483 .42236 m .34584 .41991 L .34752 .42153 L 0 .03 .13 r
F
.34483 .42236 m .34315 .42071 L .34584 .41991 L F
.37037 .42336 m .37142 .42091 L .37307 .42267 L 0 .033 .133 r
F
.37037 .42336 m .36872 .42159 L .37142 .42091 L F
.49812 .4283 m .49936 .42597 L .50089 .42754 L 0 .045 .147 r
F
.49812 .4283 m .49658 .42673 L .49936 .42597 L F
.44702 .42634 m .44817 .4243 L .44976 .42578 L 0 .04 .142 r
F
.44702 .42634 m .44543 .42487 L .44817 .4243 L F
.75895 .42106 m .76057 .41842 L .76186 .42016 L 0 .027 .127 r
F
.75895 .42106 m .75766 .41931 L .76057 .41842 L F
.42147 .42539 m .42259 .423 L .4242 .42479 L 0 .037 .139 r
F
.42147 .42539 m .41987 .42362 L .42259 .423 L F
.81284 .42051 m .81453 .41784 L .81577 .41949 L 0 .026 .125 r
F
.81284 .42051 m .81161 .41887 L .81453 .41784 L F
.87382 .41958 m .87561 .41703 L .87679 .41868 L 0 .025 .123 r
F
.87382 .41958 m .87264 .41792 L .87561 .41703 L F
.81993 .42019 m .82163 .41752 L .82287 .41928 L 0 .026 .124 r
F
.81993 .42019 m .81869 .41846 L .82163 .41752 L F
.92063 .41944 m .92248 .41686 L .92362 .41853 L 0 .024 .123 r
F
.92063 .41944 m .91949 .41777 L .92248 .41686 L F
.403 .42416 m .4041 .42156 L .40572 .42331 L 0 .034 .136 r
F
.403 .42416 m .40138 .42244 L .4041 .42156 L F
.28663 .42102 m .28756 .41849 L .28929 .42018 L 0 .028 .127 r
F
.28663 .42102 m .28489 .41935 L .28756 .41849 L F
.77313 .42045 m .77478 .41797 L .77605 .41957 L 0 .027 .126 r
F
.77313 .42045 m .77186 .41885 L .77478 .41797 L F
.69091 .42261 m .69243 .42003 L .69378 .42166 L 0 .031 .131 r
F
.69091 .42261 m .68955 .42096 L .69243 .42003 L F
.76605 .42085 m .76768 .41822 L .76895 .41984 L 0 .027 .126 r
F
.76605 .42085 m .76477 .4192 L .76768 .41822 L F
.69799 .42224 m .69953 .41977 L .70087 .42131 L 0 .03 .131 r
F
.69799 .42224 m .69665 .4207 L .69953 .41977 L F
.2469 .42087 m .24779 .4182 L .24956 .41992 L 0 .027 .126 r
F
.2469 .42087 m .24513 .41917 L .24779 .4182 L F
.53784 .42873 m .53914 .42677 L .54063 .42809 L 0 .047 .149 r
F
.53784 .42873 m .53634 .42737 L .53914 .42677 L F
.88092 .41934 m .88271 .41675 L .88388 .41836 L 0 .024 .122 r
F
.88092 .41934 m .87975 .41771 L .88271 .41675 L F
.70508 .42194 m .70663 .41949 L .70796 .42105 L 0 .03 .13 r
F
.70508 .42194 m .70375 .42039 L .70663 .41949 L F
.32634 .42137 m .32732 .41894 L .32902 .42062 L 0 .029 .128 r
F
.32634 .42137 m .32464 .41969 L .32732 .41894 L F
.35189 .42237 m .35291 .42 L .35458 .42159 L 0 .031 .131 r
F
.35189 .42237 m .35021 .42077 L .35291 .42 L F
.92774 .41927 m .92959 .41657 L .93073 .4183 L 0 .024 .122 r
F
.92774 .41927 m .9266 .41755 L .92959 .41657 L F
.88803 .41914 m .88983 .41656 L .891 .41825 L F
.88803 .41914 m .88685 .41745 L .88983 .41656 L F
.82705 .42014 m .82875 .41742 L .82999 .4192 L 0 .026 .125 r
F
.82705 .42014 m .82581 .41836 L .82875 .41742 L F
.25397 .42073 m .25485 .4182 L .25661 .41996 L 0 .027 .127 r
F
.25397 .42073 m .25221 .419 L .25485 .4182 L F
.78024 .42035 m .7819 .41781 L .78316 .41946 L 0 .027 .126 r
F
.78024 .42035 m .77897 .4187 L .7819 .41781 L F
.29369 .42097 m .29463 .41837 L .29636 .42005 L 0 .028 .127 r
F
.29369 .42097 m .29196 .41929 L .29463 .41837 L F
.41007 .42412 m .41119 .42144 L .4128 .4232 L 0 .035 .136 r
F
.41007 .42412 m .40845 .42237 L .41119 .42144 L F
.62286 .42436 m .62429 .42214 L .6257 .42354 L 0 .036 .137 r
F
.62286 .42436 m .62145 .42296 L .62429 .42214 L F
.5052 .42851 m .50645 .42635 L .50798 .42791 L 0 .046 .149 r
F
.5052 .42851 m .50367 .42694 L .50645 .42635 L F
.42854 .42556 m .42967 .42323 L .43127 .42479 L 0 .039 .141 r
F
.42854 .42556 m .42693 .42401 L .42967 .42323 L F
.47964 .42754 m .48085 .42531 L .48241 .42685 L 0 .044 .146 r
F
.47964 .42754 m .47809 .42599 L .48085 .42531 L F
.93486 .41912 m .93673 .41651 L .93786 .41825 L 0 .024 .122 r
F
.93486 .41912 m .93372 .41739 L .93673 .41651 L F
.71219 .42189 m .71374 .41934 L .71508 .42104 L 0 .03 .13 r
F
.71219 .42189 m .71085 .4202 L .71374 .41934 L F
.83415 .41993 m .83587 .41722 L .83709 .41892 L 0 .026 .124 r
F
.83415 .41993 m .83293 .41821 L .83587 .41722 L F
.56618 .4276 m .56752 .42538 L .56899 .42677 L 0 .044 .146 r
F
.56618 .4276 m .56471 .4262 L .56752 .42538 L F
.59452 .42606 m .59591 .42375 L .59735 .42514 L 0 .04 .142 r
F
.59452 .42606 m .59308 .42471 L .59591 .42375 L F
.30076 .42077 m .3017 .41836 L .30343 .41998 L 0 .028 .127 r
F
.30076 .42077 m .29904 .41913 L .3017 .41836 L F
.37742 .42372 m .3785 .42102 L .38014 .42276 L 0 .034 .135 r
F
.37742 .42372 m .37578 .42196 L .3785 .42102 L F
.45409 .42667 m .45526 .42431 L .45684 .42583 L 0 .042 .144 r
F
.45409 .42667 m .45251 .42517 L .45526 .42431 L F
.84124 .4196 m .84298 .41695 L .84419 .41862 L 0 .025 .124 r
F
.84124 .4196 m .84003 .41794 L .84298 .41695 L F
.62995 .42413 m .6314 .42191 L .6328 .42331 L 0 .036 .137 r
F
.62995 .42413 m .62855 .42273 L .6314 .42191 L F
.54492 .42888 m .54624 .42686 L .54773 .42823 L 0 .048 .15 r
F
.54492 .42888 m .54343 .42748 L .54624 .42686 L F
.35895 .4224 m .35999 .41984 L .36166 .42147 L 0 .031 .132 r
F
.35895 .4224 m .35728 .42077 L .35999 .41984 L F
.78735 .42027 m .78901 .41765 L .79028 .41936 L 0 .027 .126 r
F
.78735 .42027 m .78608 .41855 L .78901 .41765 L F
.57327 .42735 m .57462 .42524 L .57608 .42656 L 0 .044 .146 r
F
.57327 .42735 m .57181 .42601 L .57462 .42524 L F
.89515 .4191 m .89696 .41648 L .89813 .4182 L 0 .024 .123 r
F
.89515 .4191 m .89398 .41737 L .89696 .41648 L F
.84834 .41931 m .85009 .41673 L .85129 .41837 L 0 .025 .123 r
F
.84834 .41931 m .84713 .41764 L .85009 .41673 L F
.60161 .4258 m .603 .4233 L .60444 .42489 L 0 .039 .141 r
F
.60161 .4258 m .60017 .42423 L .603 .4233 L F
.33339 .4215 m .33439 .41894 L .33608 .42064 L 0 .029 .129 r
F
.33339 .4215 m .3317 .41978 L .33439 .41894 L F
.58744 .42664 m .58882 .42436 L .59026 .42567 L 0 .042 .144 r
F
.58744 .42664 m .586 .42537 L .58882 .42436 L F
.61579 .42507 m .6172 .42247 L .61862 .42401 L 0 .037 .139 r
F
.61579 .42507 m .61436 .4235 L .6172 .42247 L F
.71929 .42174 m .72084 .41896 L .72217 .4207 L 0 .03 .13 r
F
.71929 .42174 m .71796 .42001 L .72084 .41896 L F
.3845 .42351 m .38558 .4209 L .38722 .42259 L 0 .034 .135 r
F
.3845 .42351 m .38286 .42179 L .38558 .4209 L F
.58036 .42708 m .58172 .425 L .58318 .42628 L 0 .043 .146 r
F
.58036 .42708 m .5789 .42578 L .58172 .425 L F
.5591 .42826 m .56043 .42569 L .5619 .42723 L 0 .046 .148 r
F
.5591 .42826 m .55762 .42673 L .56043 .42569 L F
.26102 .4208 m .26191 .41831 L .26367 .41992 L 0 .028 .128 r
F
.26102 .4208 m .25925 .41918 L .26191 .41831 L F
.43561 .42552 m .43676 .42322 L .43835 .42474 L 0 .039 .141 r
F
.43561 .42552 m .43401 .42401 L .43676 .42322 L F
.72638 .4214 m .72794 .41873 L .72927 .42047 L 0 .029 .129 r
F
.72638 .4214 m .72505 .41968 L .72794 .41873 L F
.6087 .42554 m .6101 .42293 L .61153 .42453 L 0 .039 .14 r
F
.6087 .42554 m .60727 .42391 L .6101 .42293 L F
.63705 .42398 m .6385 .42167 L .6399 .42315 L 0 .035 .137 r
F
.63705 .42398 m .63565 .42249 L .6385 .42167 L F
.22837 .42025 m .22922 .41767 L .23101 .41929 L 0 .027 .126 r
F
.22837 .42025 m .22657 .41865 L .22922 .41767 L F
.55201 .42873 m .55333 .42621 L .55481 .42774 L 0 .047 .149 r
F
.55201 .42873 m .55053 .42723 L .55333 .42621 L F
.46117 .42658 m .46235 .42425 L .46392 .42581 L 0 .042 .144 r
F
.46117 .42658 m .4596 .425 L .46235 .42425 L F
.48673 .42757 m .48795 .4252 L .48949 .42674 L 0 .044 .147 r
F
.48673 .42757 m .48518 .42602 L .48795 .4252 L F
.41714 .42423 m .41826 .42184 L .41987 .42362 L 0 .036 .137 r
F
.41714 .42423 m .41553 .42246 L .41826 .42184 L F
.79446 .42012 m .79612 .41745 L .79738 .41918 L 0 .027 .126 r
F
.79446 .42012 m .7932 .41841 L .79612 .41745 L F
.85545 .41917 m .8572 .41647 L .8584 .4182 L 0 .025 .123 r
F
.85545 .41917 m .85424 .41744 L .8572 .41647 L F
.51228 .42861 m .51354 .42628 L .51507 .42774 L 0 .047 .15 r
F
.51228 .42861 m .51076 .42718 L .51354 .42628 L F
.36602 .42233 m .36707 .4198 L .36872 .42159 L 0 .032 .132 r
F
.36602 .42233 m .36437 .42054 L .36707 .4198 L F
.26809 .42056 m .269 .418 L .27075 .41961 L 0 .028 .127 r
F
.26809 .42056 m .26633 .41896 L .269 .418 L F
.90227 .41901 m .90409 .41638 L .90525 .41809 L 0 .024 .123 r
F
.90227 .41901 m .90111 .4173 L .90409 .41638 L F
.73348 .42119 m .73506 .41857 L .73637 .42021 L 0 .029 .129 r
F
.73348 .42119 m .73216 .41953 L .73506 .41857 L F
.23544 .42001 m .23629 .41758 L .23807 .41922 L 0 .027 .126 r
F
.23544 .42001 m .23365 .41839 L .23629 .41758 L F
.30782 .4208 m .30877 .41833 L .31049 .41993 L 0 .028 .128 r
F
.30782 .4208 m .3061 .4192 L .30877 .41833 L F
.67248 .42218 m .67398 .41958 L .67534 .4211 L 0 .031 .132 r
F
.67248 .42218 m .67112 .42065 L .67398 .41958 L F
.74056 .42082 m .74215 .4182 L .74345 .41979 L 0 .028 .128 r
F
.74056 .42082 m .73926 .4192 L .74215 .4182 L F
.39158 .42338 m .39266 .42086 L .3943 .42249 L 0 .034 .135 r
F
.39158 .42338 m .38994 .42173 L .39266 .42086 L F
.51937 .42831 m .52064 .42595 L .52216 .4274 L 0 .046 .149 r
F
.51937 .42831 m .51785 .42687 L .52064 .42595 L F
.74765 .42045 m .74924 .41772 L .75055 .41942 L 0 .027 .127 r
F
.74765 .42045 m .74635 .41876 L .74924 .41772 L F
.64414 .42381 m .64559 .4211 L .64699 .42278 L 0 .035 .136 r
F
.64414 .42381 m .64274 .42214 L .64559 .4211 L F
.52646 .42794 m .52774 .42564 L .52925 .4271 L 0 .046 .148 r
F
.52646 .42794 m .52495 .42648 L .52774 .42564 L F
.67957 .42185 m .68108 .41926 L .68245 .421 L 0 .03 .131 r
F
.67957 .42185 m .6782 .4201 L .68108 .41926 L F
.27516 .42032 m .27608 .41781 L .27783 .41944 L 0 .027 .127 r
F
.27516 .42032 m .27341 .41871 L .27608 .41781 L F
.86256 .41895 m .86431 .41622 L .86551 .41795 L 0 .024 .123 r
F
.86256 .41895 m .86136 .41721 L .86431 .41622 L F
.65123 .42347 m .65269 .42081 L .65408 .42254 L 0 .034 .135 r
F
.65123 .42347 m .64984 .42177 L .65269 .42081 L F
.34046 .42151 m .34146 .41906 L .34315 .42071 L 0 .03 .13 r
F
.34046 .42151 m .33877 .41983 L .34146 .41906 L F
.80156 .41994 m .80325 .41741 L .8045 .41907 L 0 .027 .126 r
F
.80156 .41994 m .80031 .41827 L .80325 .41741 L F
.31489 .42055 m .31587 .41799 L .31758 .41959 L 0 .028 .127 r
F
.31489 .42055 m .31318 .41896 L .31587 .41799 L F
.44269 .42548 m .44384 .42333 L .44543 .42487 L 0 .04 .142 r
F
.44269 .42548 m .4411 .42396 L .44384 .42333 L F
.90938 .41882 m .91122 .41623 L .91237 .41788 L 0 .024 .123 r
F
.90938 .41882 m .90824 .41716 L .91122 .41623 L F
.75475 .4202 m .75636 .41756 L .75766 .41931 L 0 .027 .126 r
F
.75475 .4202 m .75345 .41844 L .75636 .41756 L F
.66541 .42277 m .66689 .42021 L .66826 .42172 L 0 .033 .133 r
F
.66541 .42277 m .66403 .42123 L .66689 .42021 L F
.49381 .4275 m .49504 .42526 L .49658 .42673 L 0 .045 .147 r
F
.49381 .4275 m .49227 .42599 L .49504 .42526 L F
.65832 .42323 m .6598 .42065 L .66118 .42226 L 0 .034 .135 r
F
.65832 .42323 m .65694 .42161 L .6598 .42065 L F
.46825 .4266 m .46944 .42439 L .47101 .42582 L 0 .043 .145 r
F
.46825 .4266 m .46668 .4251 L .46944 .42439 L F
.39865 .42328 m .39975 .42071 L .40138 .42244 L 0 .034 .135 r
F
.39865 .42328 m .39702 .4216 L .39975 .42071 L F
.86967 .41879 m .87145 .41621 L .87264 .41792 L 0 .024 .123 r
F
.86967 .41879 m .86848 .41708 L .87145 .41621 L F
.28223 .42021 m .28315 .41768 L .28489 .41935 L 0 .027 .127 r
F
.28223 .42021 m .28049 .41856 L .28315 .41768 L F
.9165 .41864 m .91835 .41613 L .91949 .41777 L 0 .024 .123 r
F
.9165 .41864 m .91536 .417 L .91835 .41613 L F
.32197 .42042 m .32294 .41806 L .32464 .41969 L 0 .028 .128 r
F
.32197 .42042 m .32026 .41881 L .32294 .41806 L F
.80868 .41985 m .81037 .41724 L .81161 .41887 L 0 .027 .126 r
F
.80868 .41985 m .80743 .41821 L .81037 .41724 L F
.81577 .41949 m .81746 .41682 L .81869 .41846 L 0 .026 .125 r
F
.81577 .41949 m .81453 .41784 L .81746 .41682 L F
.24249 .42009 m .24336 .41748 L .24513 .41917 L 0 .027 .127 r
F
.24249 .42009 m .24071 .41842 L .24336 .41748 L F
.68668 .42187 m .68819 .41925 L .68955 .42096 L 0 .031 .131 r
F
.68668 .42187 m .68532 .42014 L .68819 .41925 L F
.53354 .42797 m .53484 .42601 L .53634 .42737 L 0 .047 .149 r
F
.53354 .42797 m .53204 .42656 L .53484 .42601 L F
.34752 .42153 m .34853 .41916 L .35021 .42077 L 0 .031 .131 r
F
.34752 .42153 m .34584 .41991 L .34853 .41916 L F
.76186 .42016 m .76348 .41747 L .76477 .4192 L 0 .027 .127 r
F
.76186 .42016 m .76057 .41842 L .76348 .41747 L F
.76895 .41984 m .77059 .41725 L .77186 .41885 L 0 .027 .126 r
F
.76895 .41984 m .76768 .41822 L .77059 .41725 L F
.87679 .41868 m .87857 .41608 L .87975 .41771 L 0 .024 .123 r
F
.87679 .41868 m .87561 .41703 L .87857 .41608 L F
.50089 .42754 m .50213 .42537 L .50367 .42694 L 0 .046 .148 r
F
.50089 .42754 m .49936 .42597 L .50213 .42537 L F
.82287 .41928 m .82457 .41659 L .82581 .41836 L 0 .026 .124 r
F
.82287 .41928 m .82163 .41752 L .82457 .41659 L F
.69378 .42166 m .6953 .4191 L .69665 .4207 L 0 .031 .131 r
F
.69378 .42166 m .69243 .42003 L .6953 .4191 L F
.92362 .41853 m .92547 .41588 L .9266 .41755 L 0 .024 .122 r
F
.92362 .41853 m .92248 .41686 L .92547 .41588 L F
.37307 .42267 m .37413 .4202 L .37578 .42196 L 0 .033 .134 r
F
.37307 .42267 m .37142 .42091 L .37413 .4202 L F
.24956 .41992 m .25044 .41726 L .25221 .419 L 0 .027 .126 r
F
.24956 .41992 m .24779 .4182 L .25044 .41726 L F
.47533 .42661 m .47653 .42459 L .47809 .42599 L 0 .044 .146 r
F
.47533 .42661 m .47377 .4252 L .47653 .42459 L F
.88388 .41836 m .88569 .41584 L .88685 .41745 L 0 .024 .122 r
F
.88388 .41836 m .88271 .41675 L .88569 .41584 L F
.70087 .42131 m .70241 .41883 L .70375 .42039 L 0 .03 .13 r
F
.70087 .42131 m .69953 .41977 L .70241 .41883 L F
.77605 .41957 m .7777 .41709 L .77897 .4187 L 0 .027 .126 r
F
.77605 .41957 m .77478 .41797 L .7777 .41709 L F
.40572 .42331 m .40684 .42061 L .40845 .42237 L 0 .034 .136 r
F
.40572 .42331 m .4041 .42156 L .40684 .42061 L F
.28929 .42018 m .29023 .41758 L .29196 .41929 L 0 .028 .127 r
F
.28929 .42018 m .28756 .41849 L .29023 .41758 L F
.70796 .42105 m .70952 .41864 L .71085 .4202 L 0 .03 .13 r
F
.70796 .42105 m .70663 .41949 L .70952 .41864 L F
.4242 .42479 m .42533 .42221 L .42693 .42401 L 0 .038 .14 r
F
.4242 .42479 m .42259 .423 L .42533 .42221 L F
.93073 .4183 m .93259 .41564 L .93372 .41739 L 0 .024 .122 r
F
.93073 .4183 m .92959 .41657 L .93259 .41564 L F
.44976 .42578 m .45092 .42368 L .45251 .42517 L 0 .042 .144 r
F
.44976 .42578 m .44817 .4243 L .45092 .42368 L F
.82999 .4192 m .8317 .41645 L .83293 .41821 L 0 .026 .124 r
F
.82999 .4192 m .82875 .41742 L .8317 .41645 L F
.35458 .42159 m .35561 .41919 L .35728 .42077 L 0 .031 .132 r
F
.35458 .42159 m .35291 .42 L .35561 .41919 L F
.891 .41825 m .89281 .41567 L .89398 .41737 L 0 .024 .122 r
F
.891 .41825 m .88983 .41656 L .89281 .41567 L F
.32902 .42062 m .33001 .41809 L .3317 .41978 L 0 .029 .129 r
F
.32902 .42062 m .32732 .41894 L .33001 .41809 L F
.54063 .42809 m .54194 .42618 L .54343 .42748 L 0 .048 .151 r
F
.54063 .42809 m .53914 .42677 L .54194 .42618 L F
.29636 .42005 m .29731 .41746 L .29904 .41913 L 0 .028 .127 r
F
.29636 .42005 m .29463 .41837 L .29731 .41746 L F
.78316 .41946 m .78482 .41692 L .78608 .41855 L 0 .027 .126 r
F
.78316 .41946 m .7819 .41781 L .78482 .41692 L F
.4128 .4232 m .41392 .42069 L .41553 .42246 L 0 .035 .136 r
F
.4128 .4232 m .41119 .42144 L .41392 .42069 L F
.83709 .41892 m .83881 .41623 L .84003 .41794 L 0 .025 .124 r
F
.83709 .41892 m .83587 .41722 L .83881 .41623 L F
.25661 .41996 m .2575 .41741 L .25925 .41918 L 0 .028 .127 r
F
.25661 .41996 m .25485 .4182 L .2575 .41741 L F
.84419 .41862 m .84592 .41598 L .84713 .41764 L 0 .025 .123 r
F
.84419 .41862 m .84298 .41695 L .84592 .41598 L F
.38014 .42276 m .38122 .42008 L .38286 .42179 L 0 .034 .135 r
F
.38014 .42276 m .3785 .42102 L .38122 .42008 L F
.6257 .42354 m .62714 .42132 L .62855 .42273 L 0 .036 .138 r
F
.6257 .42354 m .62429 .42214 L .62714 .42132 L F
.93786 .41825 m .93973 .41563 L .94086 .41738 L 0 .024 .123 r
F
.93786 .41825 m .93673 .41651 L .93973 .41563 L F
.59735 .42514 m .59874 .42278 L .60017 .42423 L 0 .04 .142 r
F
.59735 .42514 m .59591 .42375 L .59874 .42278 L F
.71508 .42104 m .71662 .41831 L .71796 .42001 L 0 .03 .13 r
F
.71508 .42104 m .71374 .41934 L .71662 .41831 L F
.43127 .42479 m .43241 .42244 L .43401 .42401 L 0 .039 .141 r
F
.43127 .42479 m .42967 .42323 L .43241 .42244 L F
.61862 .42401 m .62003 .42143 L .62145 .42296 L 0 .037 .138 r
F
.61862 .42401 m .6172 .42247 L .62003 .42143 L F
.56899 .42677 m .57034 .42464 L .57181 .42601 L 0 .045 .147 r
F
.56899 .42677 m .56752 .42538 L .57034 .42464 L F
.36166 .42147 m .3627 .41891 L .36437 .42054 L 0 .031 .132 r
F
.36166 .42147 m .35999 .41984 L .3627 .41891 L F
.72217 .4207 m .72372 .41792 L .72505 .41968 L 0 .029 .129 r
F
.72217 .4207 m .72084 .41896 L .72372 .41792 L F
.45684 .42583 m .45802 .42345 L .4596 .425 L 0 .042 .144 r
F
.45684 .42583 m .45526 .42431 L .45802 .42345 L F
.85129 .41837 m .85305 .41581 L .85424 .41744 L 0 .025 .123 r
F
.85129 .41837 m .85009 .41673 L .85305 .41581 L F
.79028 .41936 m .79193 .41668 L .7932 .41841 L 0 .027 .126 r
F
.79028 .41936 m .78901 .41765 L .79193 .41668 L F
.5619 .42723 m .56324 .42466 L .56471 .4262 L 0 .045 .147 r
F
.5619 .42723 m .56043 .42569 L .56324 .42466 L F
.48241 .42685 m .48362 .42449 L .48518 .42602 L 0 .044 .147 r
F
.48241 .42685 m .48085 .42531 L .48362 .42449 L F
.6328 .42331 m .63425 .4211 L .63565 .42249 L 0 .036 .137 r
F
.6328 .42331 m .6314 .42191 L .63425 .4211 L F
.59026 .42567 m .59164 .42336 L .59308 .42471 L 0 .042 .144 r
F
.59026 .42567 m .58882 .42436 L .59164 .42336 L F
.89813 .4182 m .89995 .41558 L .90111 .4173 L 0 .024 .123 r
F
.89813 .4182 m .89696 .41648 L .89995 .41558 L F
.60444 .42489 m .60584 .42236 L .60727 .42391 L 0 .039 .141 r
F
.60444 .42489 m .603 .4233 L .60584 .42236 L F
.30343 .41998 m .30437 .41759 L .3061 .4192 L 0 .028 .128 r
F
.30343 .41998 m .3017 .41836 L .30437 .41759 L F
.61153 .42453 m .61294 .42193 L .61436 .4235 L 0 .038 .14 r
F
.61153 .42453 m .6101 .42293 L .61294 .42193 L F
.22393 .41962 m .22478 .41692 L .22657 .41865 L 0 .027 .126 r
F
.22393 .41962 m .22214 .41789 L .22478 .41692 L F
.38722 .42259 m .3883 .42007 L .38994 .42173 L 0 .034 .135 r
F
.38722 .42259 m .38558 .4209 L .3883 .42007 L F
.50798 .42791 m .50923 .42561 L .51076 .42718 L 0 .047 .15 r
F
.50798 .42791 m .50645 .42635 L .50923 .42561 L F
.33608 .42064 m .33708 .41815 L .33877 .41983 L 0 .03 .13 r
F
.33608 .42064 m .33439 .41894 L .33708 .41815 L F
.55481 .42774 m .55614 .42519 L .55762 .42673 L 0 .047 .149 r
F
.55481 .42774 m .55333 .42621 L .55614 .42519 L F
.57608 .42656 m .57745 .42449 L .5789 .42578 L 0 .044 .147 r
F
.57608 .42656 m .57462 .42524 L .57745 .42449 L F
.72927 .42047 m .73084 .41778 L .73216 .41953 L 0 .029 .129 r
F
.72927 .42047 m .72794 .41873 L .73084 .41778 L F
.23101 .41929 m .23186 .41675 L .23365 .41839 L 0 .027 .126 r
F
.23101 .41929 m .22922 .41767 L .23186 .41675 L F
.26367 .41992 m .26457 .41735 L .26633 .41896 L 0 .028 .128 r
F
.26367 .41992 m .26191 .41831 L .26457 .41735 L F
.67534 .4211 m .67684 .41858 L .6782 .4201 L 0 .031 .131 r
F
.67534 .4211 m .67398 .41958 L .67684 .41858 L F
.79738 .41918 m .79905 .41652 L .80031 .41827 L 0 .026 .126 r
F
.79738 .41918 m .79612 .41745 L .79905 .41652 L F
.54773 .42823 m .54904 .42586 L .55053 .42723 L 0 .048 .151 r
F
.54773 .42823 m .54624 .42686 L .54904 .42586 L F
.8584 .4182 m .86015 .41548 L .86136 .41721 L 0 .024 .123 r
F
.8584 .4182 m .8572 .41647 L .86015 .41548 L F
.58318 .42628 m .58455 .4241 L .586 .42537 L 0 .044 .146 r
F
.58318 .42628 m .58172 .425 L .58455 .4241 L F
.74345 .41979 m .74505 .41716 L .74635 .41876 L 0 .028 .127 r
F
.74345 .41979 m .74215 .4182 L .74505 .41716 L F
.27075 .41961 m .27166 .41709 L .27341 .41871 L F
.27075 .41961 m .269 .418 L .27166 .41709 L F
.6399 .42315 m .64135 .42065 L .64274 .42214 L 0 .035 .137 r
F
.6399 .42315 m .6385 .42167 L .64135 .42065 L F
.75055 .41942 m .75215 .41674 L .75345 .41844 L 0 .027 .126 r
F
.75055 .41942 m .74924 .41772 L .75215 .41674 L F
.73637 .42021 m .73795 .41758 L .73926 .4192 L 0 .029 .128 r
F
.73637 .42021 m .73506 .41857 L .73795 .41758 L F
.43835 .42474 m .4395 .42244 L .4411 .42396 L 0 .04 .142 r
F
.43835 .42474 m .43676 .42322 L .4395 .42244 L F
.64699 .42278 m .64844 .42006 L .64984 .42177 L 0 .034 .135 r
F
.64699 .42278 m .64559 .4211 L .64844 .42006 L F
.48949 .42674 m .49072 .42449 L .49227 .42599 L 0 .045 .147 r
F
.48949 .42674 m .48795 .4252 L .49072 .42449 L F
.90525 .41809 m .90708 .41545 L .90824 .41716 L 0 .024 .123 r
F
.90525 .41809 m .90409 .41638 L .90708 .41545 L F
.51507 .42774 m .51633 .42538 L .51785 .42687 L 0 .047 .15 r
F
.51507 .42774 m .51354 .42628 L .51633 .42538 L F
.46392 .42581 m .46511 .42357 L .46668 .4251 L 0 .043 .145 r
F
.46392 .42581 m .46235 .42425 L .46511 .42357 L F
.86551 .41795 m .86728 .41534 L .86848 .41708 L 0 .024 .122 r
F
.86551 .41795 m .86431 .41622 L .86728 .41534 L F
.31049 .41993 m .31146 .41736 L .31318 .41896 L 0 .028 .128 r
F
.31049 .41993 m .30877 .41833 L .31146 .41736 L F
.52216 .4274 m .52343 .42502 L .52495 .42648 L 0 .046 .149 r
F
.52216 .4274 m .52064 .42595 L .52343 .42502 L F
.3943 .42249 m .39539 .42 L .39702 .4216 L 0 .034 .135 r
F
.3943 .42249 m .39266 .42086 L .39539 .42 L F
.66826 .42172 m .66975 .41915 L .67112 .42065 L 0 .032 .133 r
F
.66826 .42172 m .66689 .42021 L .66975 .41915 L F
.31758 .41959 m .31855 .41719 L .32026 .41881 L 0 .028 .128 r
F
.31758 .41959 m .31587 .41799 L .31855 .41719 L F
.65408 .42254 m .65555 .41985 L .65694 .42161 L 0 .034 .135 r
F
.65408 .42254 m .65269 .42081 L .65555 .41985 L F
.23807 .41922 m .23893 .41677 L .24071 .41842 L 0 .027 .126 r
F
.23807 .41922 m .23629 .41758 L .23893 .41677 L F
.36872 .42159 m .36977 .41914 L .37142 .42091 L 0 .032 .133 r
F
.36872 .42159 m .36707 .4198 L .36977 .41914 L F
.68245 .421 m .68395 .41841 L .68532 .42014 L 0 .031 .131 r
F
.68245 .421 m .68108 .41926 L .68395 .41841 L F
.52925 .4271 m .53053 .42509 L .53204 .42656 L 0 .046 .149 r
F
.52925 .4271 m .52774 .42564 L .53053 .42509 L F
.27783 .41944 m .27874 .41691 L .28049 .41856 L 0 .027 .127 r
F
.27783 .41944 m .27608 .41781 L .27874 .41691 L F
.91237 .41788 m .91422 .41536 L .91536 .417 L 0 .024 .123 r
F
.91237 .41788 m .91122 .41623 L .91422 .41536 L F
.8045 .41907 m .80619 .41655 L .80743 .41821 L 0 .027 .126 r
F
.8045 .41907 m .80325 .41741 L .80619 .41655 L F
.41987 .42362 m .42099 .42121 L .42259 .423 L 0 .037 .139 r
F
.41987 .42362 m .41826 .42184 L .42099 .42121 L F
.66118 .42226 m .66265 .41965 L .66403 .42123 L 0 .034 .134 r
F
.66118 .42226 m .6598 .42065 L .66265 .41965 L F
.75766 .41931 m .75927 .41667 L .76057 .41842 L 0 .027 .126 r
F
.75766 .41931 m .75636 .41756 L .75927 .41667 L F
.34315 .42071 m .34415 .41829 L .34584 .41991 L 0 .03 .131 r
F
.34315 .42071 m .34146 .41906 L .34415 .41829 L F
.81869 .41846 m .8204 .41588 L .82163 .41752 L 0 .026 .124 r
F
.81869 .41846 m .81746 .41682 L .8204 .41588 L F
.49658 .42673 m .49782 .42455 L .49936 .42597 L 0 .045 .148 r
F
.49658 .42673 m .49504 .42526 L .49782 .42455 L F
.81161 .41887 m .8133 .41622 L .81453 .41784 L 0 .026 .125 r
F
.81161 .41887 m .81037 .41724 L .8133 .41622 L F
.40138 .42244 m .40248 .41981 L .4041 .42156 L 0 .034 .135 r
F
.40138 .42244 m .39975 .42071 L .40248 .41981 L F
.87264 .41792 m .87442 .41532 L .87561 .41703 L 0 .025 .123 r
F
.87264 .41792 m .87145 .41621 L .87442 .41532 L F
.47101 .42582 m .4722 .42379 L .47377 .4252 L 0 .044 .146 r
F
.47101 .42582 m .46944 .42439 L .4722 .42379 L F
.91949 .41777 m .92135 .41523 L .92248 .41686 L 0 .024 .123 r
F
.91949 .41777 m .91835 .41613 L .92135 .41523 L F
.28489 .41935 m .28582 .4168 L .28756 .41849 L 0 .028 .127 r
F
.28489 .41935 m .28315 .41768 L .28582 .4168 L F
.44543 .42487 m .44659 .42274 L .44817 .4243 L 0 .041 .143 r
F
.44543 .42487 m .44384 .42333 L .44659 .42274 L F
.24513 .41917 m .24602 .41649 L .24779 .4182 L 0 .027 .126 r
F
.24513 .41917 m .24336 .41748 L .24602 .41649 L F
.68955 .42096 m .69107 .41833 L .69243 .42003 L 0 .031 .131 r
F
.68955 .42096 m .68819 .41925 L .69107 .41833 L F
.76477 .4192 m .76639 .4165 L .76768 .41822 L 0 .027 .126 r
F
.76477 .4192 m .76348 .41747 L .76639 .4165 L F
.77186 .41885 m .77351 .41637 L .77478 .41797 L F
.77186 .41885 m .77059 .41725 L .77351 .41637 L F
.87975 .41771 m .88154 .41513 L .88271 .41675 L 0 .024 .123 r
F
.87975 .41771 m .87857 .41608 L .88154 .41513 L F
.32464 .41969 m .32562 .4173 L .32732 .41894 L 0 .029 .129 r
F
.32464 .41969 m .32294 .41806 L .32562 .4173 L F
.9266 .41755 m .92846 .41489 L .92959 .41657 L 0 .024 .122 r
F
.9266 .41755 m .92547 .41588 L .92846 .41489 L F
.69665 .4207 m .69818 .41815 L .69953 .41977 L 0 .031 .131 r
F
.69665 .4207 m .6953 .4191 L .69818 .41815 L F
.82581 .41836 m .82752 .41564 L .82875 .41742 L 0 .026 .124 r
F
.82581 .41836 m .82457 .41659 L .82752 .41564 L F
.35021 .42077 m .35123 .41841 L .35291 .42 L 0 .031 .132 r
F
.35021 .42077 m .34853 .41916 L .35123 .41841 L F
.25221 .419 m .25309 .41644 L .25485 .4182 L 0 .027 .126 r
F
.25221 .419 m .25044 .41726 L .25309 .41644 L F
.70375 .42039 m .7053 .41794 L .70663 .41949 L 0 .03 .13 r
F
.70375 .42039 m .70241 .41883 L .7053 .41794 L F
.88685 .41745 m .88867 .41494 L .88983 .41656 L 0 .024 .122 r
F
.88685 .41745 m .88569 .41584 L .88867 .41494 L F
.40845 .42237 m .40957 .41966 L .41119 .42144 L 0 .034 .135 r
F
.40845 .42237 m .40684 .42061 L .40957 .41966 L F
.77897 .4187 m .78063 .41622 L .7819 .41781 L 0 .027 .126 r
F
.77897 .4187 m .7777 .41709 L .78063 .41622 L F
.29196 .41929 m .29291 .41664 L .29463 .41837 L 0 .028 .127 r
F
.29196 .41929 m .29023 .41758 L .29291 .41664 L F
.53634 .42737 m .53764 .42545 L .53914 .42677 L 0 .048 .151 r
F
.53634 .42737 m .53484 .42601 L .53764 .42545 L F
.93372 .41739 m .93559 .41476 L .93673 .41651 L 0 .024 .122 r
F
.93372 .41739 m .93259 .41564 L .93559 .41476 L F
.83293 .41821 m .83464 .41547 L .83587 .41722 L 0 .025 .124 r
F
.83293 .41821 m .8317 .41645 L .83464 .41547 L F
.37578 .42196 m .37685 .41929 L .3785 .42102 L 0 .034 .135 r
F
.37578 .42196 m .37413 .4202 L .37685 .41929 L F
.71085 .4202 m .71241 .41778 L .71374 .41934 L 0 .03 .13 r
F
.71085 .4202 m .70952 .41864 L .71241 .41778 L F
.50367 .42694 m .50492 .42478 L .50645 .42635 L 0 .047 .149 r
F
.50367 .42694 m .50213 .42537 L .50492 .42478 L F
.42693 .42401 m .42807 .42142 L .42967 .42323 L 0 .039 .141 r
F
.42693 .42401 m .42533 .42221 L .42807 .42142 L F
.47809 .42599 m .4793 .42392 L .48085 .42531 L 0 .045 .147 r
F
.47809 .42599 m .47653 .42459 L .4793 .42392 L F
.84003 .41794 m .84176 .41524 L .84298 .41695 L 0 .025 .124 r
F
.84003 .41794 m .83881 .41623 L .84176 .41524 L F
.29904 .41913 m .29998 .4167 L .3017 .41836 L 0 .028 .128 r
F
.29904 .41913 m .29731 .41746 L .29998 .4167 L F
.89398 .41737 m .8958 .41478 L .89696 .41648 L 0 .024 .122 r
F
.89398 .41737 m .89281 .41567 L .8958 .41478 L F
.78608 .41855 m .78775 .41603 L .78901 .41765 L 0 .027 .126 r
F
.78608 .41855 m .78482 .41692 L .78775 .41603 L F
.3317 .41978 m .3327 .41725 L .33439 .41894 L 0 .029 .129 r
F
.3317 .41978 m .33001 .41809 L .3327 .41725 L F
.35728 .42077 m .35832 .41827 L .35999 .41984 L 0 .031 .132 r
F
.35728 .42077 m .35561 .41919 L .35832 .41827 L F
.62145 .42296 m .62288 .4206 L .62429 .42214 L 0 .037 .138 r
F
.62145 .42296 m .62003 .42143 L .62288 .4206 L F
.84713 .41764 m .84888 .41508 L .85009 .41673 L 0 .025 .123 r
F
.84713 .41764 m .84592 .41598 L .84888 .41508 L F
.71796 .42001 m .71951 .41724 L .72084 .41896 L 0 .029 .129 r
F
.71796 .42001 m .71662 .41831 L .71951 .41724 L F
.38286 .42179 m .38394 .41921 L .38558 .4209 L 0 .034 .135 r
F
.38286 .42179 m .38122 .42008 L .38394 .41921 L F
.45251 .42517 m .45368 .42279 L .45526 .42431 L 0 .042 .144 r
F
.45251 .42517 m .45092 .42368 L .45368 .42279 L F
.72505 .41968 m .72662 .41695 L .72794 .41873 L 0 .029 .129 r
F
.72505 .41968 m .72372 .41792 L .72662 .41695 L F
.60017 .42423 m .60157 .42183 L .603 .4233 L 0 .04 .142 r
F
.60017 .42423 m .59874 .42278 L .60157 .42183 L F
.56471 .4262 m .56605 .42385 L .56752 .42538 L 0 .045 .147 r
F
.56471 .4262 m .56324 .42466 L .56605 .42385 L F
.41553 .42246 m .41665 .42006 L .41826 .42184 L 0 .036 .137 r
F
.41553 .42246 m .41392 .42069 L .41665 .42006 L F
.36437 .42054 m .3654 .41817 L .36707 .4198 L 0 .031 .132 r
F
.36437 .42054 m .3627 .41891 L .3654 .41817 L F
.61436 .4235 m .61577 .42092 L .6172 .42247 L 0 .038 .14 r
F
.61436 .4235 m .61294 .42193 L .61577 .42092 L F
.25925 .41918 m .26015 .41652 L .26191 .41831 L 0 .028 .128 r
F
.25925 .41918 m .2575 .41741 L .26015 .41652 L F
.62855 .42273 m .62999 .4205 L .6314 .42191 L 0 .037 .138 r
F
.62855 .42273 m .62714 .42132 L .62999 .4205 L F
.60727 .42391 m .60867 .42141 L .6101 .42293 L 0 .039 .141 r
F
.60727 .42391 m .60584 .42236 L .60867 .42141 L F
.7932 .41841 m .79486 .41571 L .79612 .41745 L 0 .026 .125 r
F
.7932 .41841 m .79193 .41668 L .79486 .41571 L F
.59308 .42471 m .59447 .42235 L .59591 .42375 L 0 .041 .143 r
F
.59308 .42471 m .59164 .42336 L .59447 .42235 L F
.85424 .41744 m .856 .41485 L .8572 .41647 L 0 .025 .123 r
F
.85424 .41744 m .85305 .41581 L .856 .41485 L F
.54343 .42748 m .54475 .42559 L .54624 .42686 L 0 .049 .152 r
F
.54343 .42748 m .54194 .42618 L .54475 .42559 L F
.22657 .41865 m .22743 .41594 L .22922 .41767 L 0 .027 .126 r
F
.22657 .41865 m .22478 .41692 L .22743 .41594 L F
.55762 .42673 m .55895 .42415 L .56043 .42569 L 0 .046 .149 r
F
.55762 .42673 m .55614 .42519 L .55895 .42415 L F
.90111 .4173 m .90293 .41466 L .90409 .41638 L 0 .024 .123 r
F
.90111 .4173 m .89995 .41558 L .90293 .41466 L F
.4596 .425 m .46078 .42269 L .46235 .42425 L 0 .042 .144 r
F
.4596 .425 m .45802 .42345 L .46078 .42269 L F
.43401 .42401 m .43516 .42166 L .43676 .42322 L 0 .04 .142 r
F
.43401 .42401 m .43241 .42244 L .43516 .42166 L F
.6782 .4201 m .67972 .41773 L .68108 .41926 L 0 .031 .131 r
F
.6782 .4201 m .67684 .41858 L .67972 .41773 L F
.57181 .42601 m .57316 .4239 L .57462 .42524 L 0 .045 .148 r
F
.57181 .42601 m .57034 .42464 L .57316 .4239 L F
.48518 .42602 m .4864 .42366 L .48795 .4252 L 0 .045 .147 r
F
.48518 .42602 m .48362 .42449 L .4864 .42366 L F
.73216 .41953 m .73373 .41682 L .73506 .41857 L 0 .029 .129 r
F
.73216 .41953 m .73084 .41778 L .73373 .41682 L F
.63565 .42249 m .6371 .42028 L .6385 .42167 L 0 .036 .138 r
F
.63565 .42249 m .63425 .4211 L .6371 .42028 L F
.74635 .41876 m .74795 .41612 L .74924 .41772 L 0 .027 .127 r
F
.74635 .41876 m .74505 .41716 L .74795 .41612 L F
.26633 .41896 m .26724 .41639 L .269 .418 L 0 .028 .127 r
F
.26633 .41896 m .26457 .41735 L .26724 .41639 L F
.55053 .42723 m .55185 .42484 L .55333 .42621 L 0 .048 .15 r
F
.55053 .42723 m .54904 .42586 L .55185 .42484 L F
.38994 .42173 m .39102 .41924 L .39266 .42086 L 0 .034 .135 r
F
.38994 .42173 m .3883 .42007 L .39102 .41924 L F
.23365 .41839 m .2345 .41593 L .23629 .41758 L 0 .027 .126 r
F
.23365 .41839 m .23186 .41675 L .2345 .41593 L F
.86136 .41721 m .86311 .41449 L .86431 .41622 L 0 .024 .122 r
F
.86136 .41721 m .86015 .41548 L .86311 .41449 L F
.64274 .42214 m .64419 .41958 L .64559 .4211 L 0 .035 .136 r
F
.64274 .42214 m .64135 .42065 L .64419 .41958 L F
.3061 .4192 m .30705 .41674 L .30877 .41833 L 0 .029 .128 r
F
.3061 .4192 m .30437 .41759 L .30705 .41674 L F
.73926 .4192 m .74085 .41659 L .74215 .4182 L 0 .028 .128 r
F
.73926 .4192 m .73795 .41758 L .74085 .41659 L F
.64984 .42177 m .65129 .41908 L .65269 .42081 L 0 .034 .135 r
F
.64984 .42177 m .64844 .42006 L .65129 .41908 L F
.75345 .41844 m .75506 .41586 L .75636 .41756 L 0 .027 .126 r
F
.75345 .41844 m .75215 .41674 L .75506 .41586 L F
.33877 .41983 m .33977 .41741 L .34146 .41906 L 0 .03 .13 r
F
.33877 .41983 m .33708 .41815 L .33977 .41741 L F
.80031 .41827 m .80199 .41566 L .80325 .41741 L 0 .027 .126 r
F
.80031 .41827 m .79905 .41652 L .80199 .41566 L F
.67112 .42065 m .67261 .41808 L .67398 .41958 L 0 .032 .132 r
F
.67112 .42065 m .66975 .41915 L .67261 .41808 L F
.586 .42537 m .58737 .42306 L .58882 .42436 L 0 .043 .146 r
F
.586 .42537 m .58455 .4241 L .58737 .42306 L F
.5789 .42578 m .58027 .42373 L .58172 .425 L 0 .045 .147 r
F
.5789 .42578 m .57745 .42449 L .58027 .42373 L F
.27341 .41871 m .27432 .41619 L .27608 .41781 L 0 .028 .127 r
F
.27341 .41871 m .27166 .41709 L .27432 .41619 L F
.51076 .42718 m .51202 .4247 L .51354 .42628 L 0 .048 .15 r
F
.51076 .42718 m .50923 .42561 L .51202 .4247 L F
.90824 .41716 m .91006 .41451 L .91122 .41623 L 0 .024 .123 r
F
.90824 .41716 m .90708 .41545 L .91006 .41451 L F
.31318 .41896 m .31415 .41639 L .31587 .41799 L 0 .028 .128 r
F
.31318 .41896 m .31146 .41736 L .31415 .41639 L F
.51785 .42687 m .51912 .42446 L .52064 .42595 L 0 .047 .15 r
F
.51785 .42687 m .51633 .42538 L .51912 .42446 L F
.52495 .42648 m .52623 .42417 L .52774 .42564 L 0 .046 .149 r
F
.52495 .42648 m .52343 .42502 L .52623 .42417 L F
.39702 .4216 m .39811 .41914 L .39975 .42071 L 0 .034 .135 r
F
.39702 .4216 m .39539 .42 L .39811 .41914 L F
.4411 .42396 m .44225 .42178 L .44384 .42333 L 0 .04 .142 r
F
.4411 .42396 m .4395 .42244 L .44225 .42178 L F
.86848 .41708 m .87025 .41448 L .87145 .41621 L 0 .024 .123 r
F
.86848 .41708 m .86728 .41534 L .87025 .41448 L F
.65694 .42161 m .65841 .4189 L .6598 .42065 L 0 .034 .135 r
F
.65694 .42161 m .65555 .41985 L .65841 .4189 L F
.66403 .42123 m .66552 .41866 L .66689 .42021 L 0 .033 .134 r
F
.66403 .42123 m .66265 .41965 L .66552 .41866 L F
.49227 .42599 m .4935 .42384 L .49504 .42526 L 0 .046 .148 r
F
.49227 .42599 m .49072 .42449 L .4935 .42384 L F
.28049 .41856 m .28141 .41601 L .28315 .41768 L 0 .028 .127 r
F
.28049 .41856 m .27874 .41691 L .28141 .41601 L F
.68532 .42014 m .68683 .41753 L .68819 .41925 L 0 .031 .131 r
F
.68532 .42014 m .68395 .41841 L .68683 .41753 L F
.91536 .417 m .91721 .41449 L .91835 .41613 L 0 .024 .123 r
F
.91536 .417 m .91422 .41536 L .91721 .41449 L F
.80743 .41821 m .80912 .41558 L .81037 .41724 L 0 .027 .126 r
F
.80743 .41821 m .80619 .41655 L .80912 .41558 L F
.46668 .4251 m .46787 .4229 L .46944 .42439 L 0 .043 .146 r
F
.46668 .4251 m .46511 .42357 L .46787 .4229 L F
.32026 .41881 m .32123 .41644 L .32294 .41806 L 0 .028 .128 r
F
.32026 .41881 m .31855 .41719 L .32123 .41644 L F
.76057 .41842 m .76218 .41574 L .76348 .41747 L 0 .027 .126 r
F
.76057 .41842 m .75927 .41667 L .76218 .41574 L F
.24071 .41842 m .24158 .41581 L .24336 .41748 L 0 .027 .127 r
F
.24071 .41842 m .23893 .41677 L .24158 .41581 L F
.81453 .41784 m .81623 .4152 L .81746 .41682 L 0 .026 .125 r
F
.81453 .41784 m .8133 .41622 L .81623 .4152 L F
.82163 .41752 m .82334 .41493 L .82457 .41659 L 0 .026 .124 r
F
.82163 .41752 m .8204 .41588 L .82334 .41493 L F
.34584 .41991 m .34685 .41755 L .34853 .41916 L 0 .031 .131 r
F
.34584 .41991 m .34415 .41829 L .34685 .41755 L F
.37142 .42091 m .37248 .41845 L .37413 .4202 L 0 .033 .134 r
F
.37142 .42091 m .36977 .41914 L .37248 .41845 L F
.24779 .4182 m .24868 .41553 L .25044 .41726 L 0 .027 .126 r
F
.24779 .4182 m .24602 .41649 L .24868 .41553 L F
.87561 .41703 m .87739 .41439 L .87857 .41608 L 0 .025 .123 r
F
.87561 .41703 m .87442 .41532 L .87739 .41439 L F
.4041 .42156 m .40521 .41885 L .40684 .42061 L 0 .034 .135 r
F
.4041 .42156 m .40248 .41981 L .40521 .41885 L F
.76768 .41822 m .7693 .41554 L .77059 .41725 L 0 .027 .126 r
F
.76768 .41822 m .76639 .4165 L .7693 .41554 L F
.92248 .41686 m .92434 .41424 L .92547 .41588 L 0 .024 .123 r
F
.92248 .41686 m .92135 .41523 L .92434 .41424 L F
.69243 .42003 m .69395 .41742 L .6953 .4191 L 0 .031 .131 r
F
.69243 .42003 m .69107 .41833 L .69395 .41742 L F
.42259 .423 m .42373 .42042 L .42533 .42221 L 0 .038 .14 r
F
.42259 .423 m .42099 .42121 L .42373 .42042 L F
.53204 .42656 m .53333 .42453 L .53484 .42601 L 0 .048 .15 r
F
.53204 .42656 m .53053 .42509 L .53333 .42453 L F
.49936 .42597 m .5006 .42398 L .50213 .42537 L 0 .046 .149 r
F
.49936 .42597 m .49782 .42455 L .5006 .42398 L F
.28756 .41849 m .2885 .41586 L .29023 .41758 L 0 .028 .127 r
F
.28756 .41849 m .28582 .4168 L .2885 .41586 L F
.88271 .41675 m .88452 .41422 L .88569 .41584 L 0 .024 .123 r
F
.88271 .41675 m .88154 .41513 L .88452 .41422 L F
.92959 .41657 m .93146 .41396 L .93259 .41564 L 0 .024 .122 r
F
.92959 .41657 m .92846 .41489 L .93146 .41396 L F
.77478 .41797 m .77643 .41549 L .7777 .41709 L 0 .027 .126 r
F
.77478 .41797 m .77351 .41637 L .77643 .41549 L F
.69953 .41977 m .70107 .41721 L .70241 .41883 L 0 .031 .131 r
F
.69953 .41977 m .69818 .41815 L .70107 .41721 L F
.82875 .41742 m .83046 .41468 L .8317 .41645 L 0 .025 .124 r
F
.82875 .41742 m .82752 .41564 L .83046 .41468 L F
.41119 .42144 m .4123 .41891 L .41392 .42069 L 0 .035 .136 r
F
.41119 .42144 m .40957 .41966 L .4123 .41891 L F
.70663 .41949 m .70819 .41708 L .70952 .41864 L 0 .03 .131 r
F
.70663 .41949 m .7053 .41794 L .70819 .41708 L F
.47377 .4252 m .47496 .42319 L .47653 .42459 L 0 .045 .147 r
F
.47377 .4252 m .4722 .42379 L .47496 .42319 L F
.88983 .41656 m .89165 .41405 L .89281 .41567 L 0 .024 .122 r
F
.88983 .41656 m .88867 .41494 L .89165 .41405 L F
.32732 .41894 m .32831 .41643 L .33001 .41809 L 0 .029 .129 r
F
.32732 .41894 m .32562 .4173 L .32831 .41643 L F
.29463 .41837 m .29559 .41571 L .29731 .41746 L 0 .028 .127 r
F
.29463 .41837 m .29291 .41664 L .29559 .41571 L F
.44817 .4243 m .44934 .42209 L .45092 .42368 L 0 .042 .144 r
F
.44817 .4243 m .44659 .42274 L .44934 .42209 L F
.25485 .4182 m .25574 .41563 L .2575 .41741 L 0 .028 .127 r
F
.25485 .4182 m .25309 .41644 L .25574 .41563 L F
.83587 .41722 m .83759 .41448 L .83881 .41623 L 0 .025 .124 r
F
.83587 .41722 m .83464 .41547 L .83759 .41448 L F
.7819 .41781 m .78356 .41534 L .78482 .41692 L 0 .027 .126 r
F
.7819 .41781 m .78063 .41622 L .78356 .41534 L F
.35291 .42 m .35393 .4176 L .35561 .41919 L 0 .032 .132 r
F
.35291 .42 m .35123 .41841 L .35393 .4176 L F
.3785 .42102 m .37957 .41838 L .38122 .42008 L 0 .034 .135 r
F
.3785 .42102 m .37685 .41929 L .37957 .41838 L F
.93673 .41651 m .9386 .41387 L .93973 .41563 L 0 .024 .122 r
F
.93673 .41651 m .93559 .41476 L .9386 .41387 L F
.84298 .41695 m .84471 .41427 L .84592 .41598 L 0 .025 .123 r
F
.84298 .41695 m .84176 .41524 L .84471 .41427 L F
.71374 .41934 m .7153 .41675 L .71662 .41831 L 0 .03 .13 r
F
.71374 .41934 m .71241 .41778 L .7153 .41675 L F
.72084 .41896 m .72239 .41619 L .72372 .41792 L 0 .029 .129 r
F
.72084 .41896 m .71951 .41724 L .72239 .41619 L F
.78901 .41765 m .79067 .41505 L .79193 .41668 L 0 .027 .126 r
F
.78901 .41765 m .78775 .41603 L .79067 .41505 L F
.89696 .41648 m .89879 .41389 L .89995 .41558 L 0 .024 .123 r
F
.89696 .41648 m .8958 .41478 L .89879 .41389 L F
.35999 .41984 m .36103 .41734 L .3627 .41891 L 0 .031 .132 r
F
.35999 .41984 m .35832 .41827 L .36103 .41734 L F
.22214 .41789 m .223 .41515 L .22478 .41692 L 0 .027 .126 r
F
.22214 .41789 m .22035 .41611 L .223 .41515 L F
.85009 .41673 m .85185 .41417 L .85305 .41581 L 0 .025 .123 r
F
.85009 .41673 m .84888 .41508 L .85185 .41417 L F
.42967 .42323 m .43081 .42065 L .43241 .42244 L 0 .039 .141 r
F
.42967 .42323 m .42807 .42142 L .43081 .42065 L F
.53914 .42677 m .54044 .42488 L .54194 .42618 L 0 .05 .152 r
F
.53914 .42677 m .53764 .42545 L .54044 .42488 L F
.6172 .42247 m .61861 .41991 L .62003 .42143 L 0 .037 .139 r
F
.6172 .42247 m .61577 .42092 L .61861 .41991 L F
.72794 .41873 m .72951 .41599 L .73084 .41778 L 0 .029 .129 r
F
.72794 .41873 m .72662 .41695 L .72951 .41599 L F
.38558 .4209 m .38665 .41841 L .3883 .42007 L 0 .034 .135 r
F
.38558 .4209 m .38394 .41921 L .38665 .41841 L F
.33439 .41894 m .33539 .41646 L .33708 .41815 L 0 .03 .13 r
F
.33439 .41894 m .3327 .41725 L .33539 .41646 L F
.3017 .41836 m .30265 .41594 L .30437 .41759 L 0 .028 .128 r
F
.3017 .41836 m .29998 .4167 L .30265 .41594 L F
.603 .4233 m .6044 .42092 L .60584 .42236 L 0 .04 .142 r
F
.603 .4233 m .60157 .42183 L .6044 .42092 L F
.62429 .42214 m .62573 .41977 L .62714 .42132 L 0 .037 .139 r
F
.62429 .42214 m .62288 .4206 L .62573 .41977 L F
.6101 .42293 m .61151 .42043 L .61294 .42193 L 0 .039 .141 r
F
.6101 .42293 m .60867 .42141 L .61151 .42043 L F
.45526 .42431 m .45644 .42191 L .45802 .42345 L 0 .042 .145 r
F
.45526 .42431 m .45368 .42279 L .45644 .42191 L F
.56043 .42569 m .56176 .42311 L .56324 .42466 L 0 .046 .148 r
F
.56043 .42569 m .55895 .42415 L .56176 .42311 L F
.48085 .42531 m .48207 .4231 L .48362 .42449 L 0 .045 .148 r
F
.48085 .42531 m .4793 .42392 L .48207 .4231 L F
.59591 .42375 m .5973 .42134 L .59874 .42278 L 0 .041 .143 r
F
.59591 .42375 m .59447 .42235 L .5973 .42134 L F
.79612 .41745 m .79779 .41477 L .79905 .41652 L 0 .026 .125 r
F
.79612 .41745 m .79486 .41571 L .79779 .41477 L F
.8572 .41647 m .85896 .41386 L .86015 .41548 L 0 .024 .123 r
F
.8572 .41647 m .856 .41485 L .85896 .41386 L F
.22922 .41767 m .23008 .41503 L .23186 .41675 L 0 .027 .126 r
F
.22922 .41767 m .22743 .41594 L .23008 .41503 L F
.50645 .42635 m .5077 .42404 L .50923 .42561 L 0 .048 .15 r
F
.50645 .42635 m .50492 .42478 L .5077 .42404 L F
.56752 .42538 m .56887 .42313 L .57034 .42464 L 0 .046 .148 r
F
.56752 .42538 m .56605 .42385 L .56887 .42313 L F
.74924 .41772 m .75085 .41514 L .75215 .41674 L 0 .027 .126 r
F
.74924 .41772 m .74795 .41612 L .75085 .41514 L F
.26191 .41831 m .26282 .41556 L .26457 .41735 L 0 .028 .128 r
F
.26191 .41831 m .26015 .41652 L .26282 .41556 L F
.55333 .42621 m .55466 .42382 L .55614 .42519 L 0 .047 .15 r
F
.55333 .42621 m .55185 .42484 L .55466 .42382 L F
.64559 .4211 m .64705 .41852 L .64844 .42006 L 0 .035 .136 r
F
.64559 .4211 m .64419 .41958 L .64705 .41852 L F
.90409 .41638 m .90592 .41372 L .90708 .41545 L 0 .024 .123 r
F
.90409 .41638 m .90293 .41466 L .90592 .41372 L F
.6314 .42191 m .63284 .4197 L .63425 .4211 L 0 .037 .139 r
F
.6314 .42191 m .62999 .4205 L .63284 .4197 L F
.73506 .41857 m .73663 .41586 L .73795 .41758 L 0 .029 .128 r
F
.73506 .41857 m .73373 .41682 L .73663 .41586 L F
.86431 .41622 m .86608 .41361 L .86728 .41534 L 0 .024 .122 r
F
.86431 .41622 m .86311 .41449 L .86608 .41361 L F
.74215 .4182 m .74375 .41556 L .74505 .41716 L 0 .028 .128 r
F
.74215 .4182 m .74085 .41659 L .74375 .41556 L F
.269 .418 m .2699 .41547 L .27166 .41709 L 0 .028 .127 r
F
.269 .418 m .26724 .41639 L .2699 .41547 L F
.67398 .41958 m .67548 .41708 L .67684 .41858 L 0 .031 .132 r
F
.67398 .41958 m .67261 .41808 L .67548 .41708 L F
.36707 .4198 m .36811 .4175 L .36977 .41914 L 0 .032 .133 r
F
.36707 .4198 m .3654 .41817 L .36811 .4175 L F
.65269 .42081 m .65415 .41809 L .65555 .41985 L 0 .034 .135 r
F
.65269 .42081 m .65129 .41908 L .65415 .41809 L F
.58882 .42436 m .5902 .42202 L .59164 .42336 L 0 .043 .145 r
F
.58882 .42436 m .58737 .42306 L .5902 .42202 L F
.68108 .41926 m .6826 .41689 L .68395 .41841 L 0 .031 .131 r
F
.68108 .41926 m .67972 .41773 L .6826 .41689 L F
.41826 .42184 m .41938 .41943 L .42099 .42121 L 0 .037 .138 r
F
.41826 .42184 m .41665 .42006 L .41938 .41943 L F
.43676 .42322 m .4379 .42087 L .4395 .42244 L 0 .04 .142 r
F
.43676 .42322 m .43516 .42166 L .4379 .42087 L F
.39266 .42086 m .39375 .4184 L .39539 .42 L 0 .034 .135 r
F
.39266 .42086 m .39102 .41924 L .39375 .4184 L F
.48795 .4252 m .48917 .42301 L .49072 .42449 L 0 .045 .148 r
F
.48795 .4252 m .4864 .42366 L .48917 .42301 L F
.6385 .42167 m .63995 .41925 L .64135 .42065 L 0 .036 .138 r
F
.6385 .42167 m .6371 .42028 L .63995 .41925 L F
.30877 .41833 m .30974 .41576 L .31146 .41736 L 0 .029 .128 r
F
.30877 .41833 m .30705 .41674 L .30974 .41576 L F
.46235 .42425 m .46354 .422 L .46511 .42357 L 0 .043 .145 r
F
.46235 .42425 m .46078 .42269 L .46354 .422 L F
.75636 .41756 m .75798 .41498 L .75927 .41667 L 0 .027 .126 r
F
.75636 .41756 m .75506 .41586 L .75798 .41498 L F
.57462 .42524 m .57599 .42316 L .57745 .42449 L 0 .046 .148 r
F
.57462 .42524 m .57316 .4239 L .57599 .42316 L F
.23629 .41758 m .23714 .41511 L .23893 .41677 L 0 .027 .127 r
F
.23629 .41758 m .2345 .41593 L .23714 .41511 L F
.31587 .41799 m .31684 .41559 L .31855 .41719 L 0 .028 .128 r
F
.31587 .41799 m .31415 .41639 L .31684 .41559 L F
.80325 .41741 m .80493 .4148 L .80619 .41655 L 0 .027 .126 r
F
.80325 .41741 m .80199 .41566 L .80493 .4148 L F
.54624 .42686 m .54755 .4246 L .54904 .42586 L 0 .05 .152 r
F
.54624 .42686 m .54475 .42559 L .54755 .4246 L F
.91122 .41623 m .91306 .41364 L .91422 .41536 L 0 .024 .123 r
F
.91122 .41623 m .91006 .41451 L .91306 .41364 L F
.27608 .41781 m .27699 .41528 L .27874 .41691 L 0 .028 .127 r
F
.27608 .41781 m .27432 .41619 L .27699 .41528 L F
.51354 .42628 m .51481 .42379 L .51633 .42538 L 0 .048 .15 r
F
.51354 .42628 m .51202 .4247 L .51481 .42379 L F
.66689 .42021 m .66838 .4176 L .66975 .41915 L 0 .033 .134 r
F
.66689 .42021 m .66552 .41866 L .66838 .4176 L F
.52064 .42595 m .52192 .42353 L .52343 .42502 L 0 .047 .15 r
F
.52064 .42595 m .51912 .42446 L .52192 .42353 L F
.34146 .41906 m .34246 .41667 L .34415 .41829 L 0 .031 .131 r
F
.34146 .41906 m .33977 .41741 L .34246 .41667 L F
.6598 .42065 m .66127 .41794 L .66265 .41965 L 0 .034 .135 r
F
.6598 .42065 m .65841 .4189 L .66127 .41794 L F
.58172 .425 m .5831 .42282 L .58455 .4241 L 0 .045 .148 r
F
.58172 .425 m .58027 .42373 L .5831 .42282 L F
.39975 .42071 m .40084 .41825 L .40248 .41981 L 0 .034 .135 r
F
.39975 .42071 m .39811 .41914 L .40084 .41825 L F
.52774 .42564 m .52902 .42361 L .53053 .42509 L 0 .047 .15 r
F
.52774 .42564 m .52623 .42417 L .52902 .42361 L F
.87145 .41621 m .87323 .41359 L .87442 .41532 L 0 .024 .123 r
F
.87145 .41621 m .87025 .41448 L .87323 .41359 L F
.81746 .41682 m .81917 .41425 L .8204 .41588 L 0 .026 .125 r
F
.81746 .41682 m .81623 .4152 L .81917 .41425 L F
.81037 .41724 m .81205 .41457 L .8133 .41622 L 0 .026 .126 r
F
.81037 .41724 m .80912 .41558 L .81205 .41457 L F
.76348 .41747 m .7651 .41478 L .76639 .4165 L 0 .027 .126 r
F
.76348 .41747 m .76218 .41574 L .7651 .41478 L F
.68819 .41925 m .68971 .41663 L .69107 .41833 L 0 .031 .131 r
F
.68819 .41925 m .68683 .41753 L .68971 .41663 L F
.28315 .41768 m .28408 .41511 L .28582 .4168 L 0 .028 .127 r
F
.28315 .41768 m .28141 .41601 L .28408 .41511 L F
.24336 .41748 m .24424 .4148 L .24602 .41649 L 0 .027 .126 r
F
.24336 .41748 m .24158 .41581 L .24424 .4148 L F
.91835 .41613 m .92021 .4136 L .92135 .41523 L 0 .025 .123 r
F
.91835 .41613 m .91721 .41449 L .92021 .4136 L F
.82457 .41659 m .82629 .41398 L .82752 .41564 L 0 .025 .124 r
F
.82457 .41659 m .82334 .41493 L .82629 .41398 L F
.49504 .42526 m .49627 .4232 L .49782 .42455 L 0 .047 .149 r
F
.49504 .42526 m .4935 .42384 L .49627 .4232 L F
.44384 .42333 m .44499 .42116 L .44659 .42274 L 0 .042 .144 r
F
.44384 .42333 m .44225 .42178 L .44499 .42116 L F
.77059 .41725 m .77223 .41466 L .77351 .41637 L 0 .027 .126 r
F
.77059 .41725 m .7693 .41554 L .77223 .41466 L F
.92547 .41588 m .92733 .41326 L .92846 .41489 L 0 .024 .122 r
F
.92547 .41588 m .92434 .41424 L .92733 .41326 L F
.25044 .41726 m .25132 .41469 L .25309 .41644 L 0 .027 .126 r
F
.25044 .41726 m .24868 .41553 L .25132 .41469 L F
.87857 .41608 m .88037 .41345 L .88154 .41513 L 0 .024 .123 r
F
.87857 .41608 m .87739 .41439 L .88037 .41345 L F
.40684 .42061 m .40795 .41788 L .40957 .41966 L 0 .034 .135 r
F
.40684 .42061 m .40521 .41885 L .40795 .41788 L F
.32294 .41806 m .32391 .41566 L .32562 .4173 L 0 .029 .129 r
F
.32294 .41806 m .32123 .41644 L .32391 .41566 L F
.46944 .42439 m .47063 .42229 L .4722 .42379 L 0 .044 .147 r
F
.46944 .42439 m .46787 .4229 L .47063 .42229 L F
.6953 .4191 m .69683 .41646 L .69818 .41815 L 0 .031 .131 r
F
.6953 .4191 m .69395 .41742 L .69683 .41646 L F
.29023 .41758 m .29118 .41491 L .29291 .41664 L 0 .028 .127 r
F
.29023 .41758 m .2885 .41586 L .29118 .41491 L F
.34853 .41916 m .34954 .41681 L .35123 .41841 L 0 .032 .132 r
F
.34853 .41916 m .34685 .41755 L .34954 .41681 L F
.88569 .41584 m .8875 .41332 L .88867 .41494 L 0 .024 .123 r
F
.88569 .41584 m .88452 .41422 L .8875 .41332 L F
.93259 .41564 m .93446 .41306 L .93559 .41476 L 0 .024 .122 r
F
.93259 .41564 m .93146 .41396 L .93446 .41306 L F
.8317 .41645 m .83341 .41371 L .83464 .41547 L 0 .025 .124 r
F
.8317 .41645 m .83046 .41468 L .83341 .41371 L F
.37413 .4202 m .37519 .41756 L .37685 .41929 L 0 .033 .134 r
F
.37413 .4202 m .37248 .41845 L .37519 .41756 L F
.70241 .41883 m .70395 .4163 L .7053 .41794 L 0 .031 .131 r
F
.70241 .41883 m .70107 .41721 L .70395 .4163 L F
.7777 .41709 m .77936 .41462 L .78063 .41622 L 0 .027 .126 r
F
.7777 .41709 m .77643 .41549 L .77936 .41462 L F
.42533 .42221 m .42647 .41962 L .42807 .42142 L 0 .038 .14 r
F
.42533 .42221 m .42373 .42042 L .42647 .41962 L F
.83881 .41623 m .84054 .41349 L .84176 .41524 L 0 .025 .124 r
F
.83881 .41623 m .83759 .41448 L .84054 .41349 L F
.89281 .41567 m .89464 .41317 L .8958 .41478 L 0 .024 .123 r
F
.89281 .41567 m .89165 .41405 L .89464 .41317 L F
.70952 .41864 m .71108 .41622 L .71241 .41778 L 0 .031 .131 r
F
.70952 .41864 m .70819 .41708 L .71108 .41622 L F
.29731 .41746 m .29826 .41493 L .29998 .4167 L 0 .028 .127 r
F
.29731 .41746 m .29559 .41571 L .29826 .41493 L F
.50213 .42537 m .50338 .42342 L .50492 .42478 L 0 .048 .15 r
F
.50213 .42537 m .5006 .42398 L .50338 .42342 L F
.33001 .41809 m .331 .41557 L .3327 .41725 L 0 .029 .129 r
F
.33001 .41809 m .32831 .41643 L .331 .41557 L F
.78482 .41692 m .78649 .41446 L .78775 .41603 L 0 .027 .126 r
F
.78482 .41692 m .78356 .41534 L .78649 .41446 L F
.71662 .41831 m .71818 .41569 L .71951 .41724 L 0 .03 .13 r
F
.71662 .41831 m .7153 .41675 L .71818 .41569 L F
.38122 .42008 m .38229 .41754 L .38394 .41921 L 0 .034 .135 r
F
.38122 .42008 m .37957 .41838 L .38229 .41754 L F
.72372 .41792 m .72529 .4152 L .72662 .41695 L 0 .029 .128 r
F
.72372 .41792 m .72239 .41619 L .72529 .4152 L F
.41392 .42069 m .41503 .41828 L .41665 .42006 L 0 .035 .137 r
F
.41392 .42069 m .4123 .41891 L .41503 .41828 L F
.53484 .42601 m .53614 .42396 L .53764 .42545 L 0 .049 .152 r
F
.53484 .42601 m .53333 .42453 L .53614 .42396 L F
.84592 .41598 m .84767 .41339 L .84888 .41508 L 0 .025 .123 r
F
.84592 .41598 m .84471 .41427 L .84767 .41339 L F
.2575 .41741 m .2584 .41474 L .26015 .41652 L 0 .028 .127 r
F
.2575 .41741 m .25574 .41563 L .2584 .41474 L F
.35561 .41919 m .35664 .41669 L .35832 .41827 L 0 .032 .132 r
F
.35561 .41919 m .35393 .4176 L .35664 .41669 L F
.79193 .41668 m .7936 .41406 L .79486 .41571 L 0 .026 .125 r
F
.79193 .41668 m .79067 .41505 L .7936 .41406 L F
.62003 .42143 m .62146 .41906 L .62288 .4206 L 0 .037 .139 r
F
.62003 .42143 m .61861 .41991 L .62146 .41906 L F
.47653 .42459 m .47773 .42253 L .4793 .42392 L 0 .046 .148 r
F
.47653 .42459 m .47496 .42319 L .47773 .42253 L F
.22478 .41692 m .22564 .41418 L .22743 .41594 L 0 .027 .126 r
F
.22478 .41692 m .223 .41515 L .22564 .41418 L F
.3627 .41891 m .36373 .41659 L .3654 .41817 L 0 .032 .132 r
F
.3627 .41891 m .36103 .41734 L .36373 .41659 L F
.89995 .41558 m .90177 .41298 L .90293 .41466 L 0 .024 .123 r
F
.89995 .41558 m .89879 .41389 L .90177 .41298 L F
.56324 .42466 m .56458 .42232 L .56605 .42385 L 0 .046 .148 r
F
.56324 .42466 m .56176 .42311 L .56458 .42232 L F
.45092 .42368 m .45209 .42118 L .45368 .42279 L 0 .043 .145 r
F
.45092 .42368 m .44934 .42209 L .45209 .42118 L F
.85305 .41581 m .85481 .41323 L .856 .41485 L 0 .025 .123 r
F
.85305 .41581 m .85185 .41417 L .85481 .41323 L F
.73084 .41778 m .73241 .41504 L .73373 .41682 L 0 .029 .128 r
F
.73084 .41778 m .72951 .41599 L .73241 .41504 L F
.61294 .42193 m .61435 .41945 L .61577 .42092 L 0 .038 .14 r
F
.61294 .42193 m .61151 .42043 L .61435 .41945 L F
.60584 .42236 m .60724 .42 L .60867 .42141 L 0 .04 .142 r
F
.60584 .42236 m .6044 .42092 L .60724 .42 L F
.86015 .41548 m .86192 .41287 L .86311 .41449 L 0 .024 .122 r
F
.86015 .41548 m .85896 .41386 L .86192 .41287 L F
.59874 .42278 m .60013 .42036 L .60157 .42183 L 0 .041 .143 r
F
.59874 .42278 m .5973 .42134 L .60013 .42036 L F
.64844 .42006 m .6499 .4175 L .65129 .41908 L 0 .034 .135 r
F
.64844 .42006 m .64705 .41852 L .6499 .4175 L F
.79905 .41652 m .80073 .41391 L .80199 .41566 L 0 .026 .125 r
F
.79905 .41652 m .79779 .41477 L .80073 .41391 L F
.3883 .42007 m .38938 .41762 L .39102 .41924 L 0 .034 .135 r
F
.3883 .42007 m .38665 .41841 L .38938 .41762 L F
.55614 .42519 m .55747 .42279 L .55895 .42415 L 0 .047 .149 r
F
.55614 .42519 m .55466 .42382 L .55747 .42279 L F
.43241 .42244 m .43356 .41991 L .43516 .42166 L 0 .04 .142 r
F
.43241 .42244 m .43081 .42065 L .43356 .41991 L F
.75215 .41674 m .75377 .41428 L .75506 .41586 L 0 .027 .126 r
F
.75215 .41674 m .75085 .41514 L .75377 .41428 L F
.23186 .41675 m .23272 .41421 L .2345 .41593 L F
.23186 .41675 m .23008 .41503 L .23272 .41421 L F
.45802 .42345 m .4592 .42112 L .46078 .42269 L 0 .043 .145 r
F
.45802 .42345 m .45644 .42191 L .4592 .42112 L F
.26457 .41735 m .26549 .4146 L .26724 .41639 L 0 .028 .127 r
F
.26457 .41735 m .26282 .41556 L .26549 .4146 L F
.74505 .41716 m .74665 .41452 L .74795 .41612 L F
.74505 .41716 m .74375 .41556 L .74665 .41452 L F
.33708 .41815 m .33808 .41572 L .33977 .41741 L 0 .03 .13 r
F
.33708 .41815 m .33539 .41646 L .33808 .41572 L F
.62714 .42132 m .62858 .41895 L .62999 .4205 L 0 .037 .139 r
F
.62714 .42132 m .62573 .41977 L .62858 .41895 L F
.73795 .41758 m .73954 .4149 L .74085 .41659 L 0 .028 .128 r
F
.73795 .41758 m .73663 .41586 L .73954 .4149 L F
.67684 .41858 m .67836 .41624 L .67972 .41773 L 0 .031 .132 r
F
.67684 .41858 m .67548 .41708 L .67836 .41624 L F
.30437 .41759 m .30533 .41509 L .30705 .41674 L 0 .029 .129 r
F
.30437 .41759 m .30265 .41594 L .30533 .41509 L F
.48362 .42449 m .48484 .42229 L .4864 .42366 L 0 .046 .148 r
F
.48362 .42449 m .48207 .4231 L .48484 .42229 L F
.90708 .41545 m .90891 .41278 L .91006 .41451 L 0 .024 .122 r
F
.90708 .41545 m .90592 .41372 L .90891 .41278 L F
.59164 .42336 m .59303 .42098 L .59447 .42235 L 0 .043 .145 r
F
.59164 .42336 m .5902 .42202 L .59303 .42098 L F
.27166 .41709 m .27257 .41456 L .27432 .41619 L 0 .028 .127 r
F
.27166 .41709 m .2699 .41547 L .27257 .41456 L F
.65555 .41985 m .65701 .41714 L .65841 .4189 L 0 .034 .135 r
F
.65555 .41985 m .65415 .41809 L .65701 .41714 L F
.64135 .42065 m .6428 .41816 L .64419 .41958 L 0 .036 .137 r
F
.64135 .42065 m .63995 .41925 L .6428 .41816 L F
.86728 .41534 m .86906 .41274 L .87025 .41448 L 0 .024 .122 r
F
.86728 .41534 m .86608 .41361 L .86906 .41274 L F
.54194 .42618 m .54325 .42431 L .54475 .42559 L 0 .051 .154 r
F
.54194 .42618 m .54044 .42488 L .54325 .42431 L F
.50923 .42561 m .51049 .42311 L .51202 .4247 L 0 .048 .151 r
F
.50923 .42561 m .5077 .42404 L .51049 .42311 L F
.63425 .4211 m .6357 .41889 L .6371 .42028 L 0 .037 .139 r
F
.63425 .4211 m .63284 .4197 L .6357 .41889 L F
.57034 .42464 m .5717 .42241 L .57316 .4239 L 0 .046 .149 r
F
.57034 .42464 m .56887 .42313 L .5717 .42241 L F
.31146 .41736 m .31243 .41479 L .31415 .41639 L 0 .028 .128 r
F
.31146 .41736 m .30974 .41576 L .31243 .41479 L F
.66975 .41915 m .67124 .41655 L .67261 .41808 L 0 .032 .133 r
F
.66975 .41915 m .66838 .4176 L .67124 .41655 L F
.54904 .42586 m .55036 .42359 L .55185 .42484 L 0 .049 .152 r
F
.54904 .42586 m .54755 .4246 L .55036 .42359 L F
.68395 .41841 m .68548 .41602 L .68683 .41753 L 0 .031 .131 r
F
.68395 .41841 m .6826 .41689 L .68548 .41602 L F
.39539 .42 m .39647 .41756 L .39811 .41914 L 0 .035 .136 r
F
.39539 .42 m .39375 .4184 L .39647 .41756 L F
.75927 .41667 m .76089 .41406 L .76218 .41574 L 0 .027 .126 r
F
.75927 .41667 m .75798 .41498 L .76089 .41406 L F
.66265 .41965 m .66413 .41698 L .66552 .41866 L 0 .033 .134 r
F
.66265 .41965 m .66127 .41794 L .66413 .41698 L F
.51633 .42538 m .5176 .42289 L .51912 .42446 L 0 .048 .15 r
F
.51633 .42538 m .51481 .42379 L .5176 .42289 L F
.27874 .41691 m .27966 .41436 L .28141 .41601 L 0 .028 .127 r
F
.27874 .41691 m .27699 .41528 L .27966 .41436 L F
.4395 .42244 m .44065 .4202 L .44225 .42178 L 0 .041 .143 r
F
.4395 .42244 m .4379 .42087 L .44065 .4202 L F
.91422 .41536 m .91607 .41278 L .91721 .41449 L 0 .024 .123 r
F
.91422 .41536 m .91306 .41364 L .91607 .41278 L F
.80619 .41655 m .80787 .41384 L .80912 .41558 L 0 .027 .126 r
F
.80619 .41655 m .80493 .4148 L .80787 .41384 L F
.52343 .42502 m .52471 .42268 L .52623 .42417 L 0 .047 .15 r
F
.52343 .42502 m .52192 .42353 L .52471 .42268 L F
.23893 .41677 m .2398 .41413 L .24158 .41581 L 0 .027 .127 r
F
.23893 .41677 m .23714 .41511 L .2398 .41413 L F
.36977 .41914 m .37082 .4168 L .37248 .41845 L 0 .033 .134 r
F
.36977 .41914 m .36811 .4175 L .37082 .4168 L F
.31855 .41719 m .31952 .41482 L .32123 .41644 L 0 .029 .128 r
F
.31855 .41719 m .31684 .41559 L .31952 .41482 L F
.57745 .42449 m .57881 .42242 L .58027 .42373 L 0 .047 .149 r
F
.57745 .42449 m .57599 .42316 L .57881 .42242 L F
.8133 .41622 m .81499 .41355 L .81623 .4152 L 0 .026 .125 r
F
.8133 .41622 m .81205 .41457 L .81499 .41355 L F
.58455 .4241 m .58592 .42176 L .58737 .42306 L 0 .045 .147 r
F
.58455 .4241 m .5831 .42282 L .58592 .42176 L F
.49072 .42449 m .49195 .42243 L .4935 .42384 L 0 .047 .149 r
F
.49072 .42449 m .48917 .42301 L .49195 .42243 L F
.40248 .41981 m .40358 .4173 L .40521 .41885 L 0 .034 .135 r
F
.40248 .41981 m .40084 .41825 L .40358 .4173 L F
.8204 .41588 m .82211 .4133 L .82334 .41493 L 0 .026 .125 r
F
.8204 .41588 m .81917 .41425 L .82211 .4133 L F
.46511 .42357 m .4663 .42131 L .46787 .4229 L 0 .044 .146 r
F
.46511 .42357 m .46354 .422 L .4663 .42131 L F
.42099 .42121 m .42212 .41863 L .42373 .42042 L 0 .037 .139 r
F
.42099 .42121 m .41938 .41943 L .42212 .41863 L F
.24602 .41649 m .2469 .41381 L .24868 .41553 L 0 .027 .126 r
F
.24602 .41649 m .24424 .4148 L .2469 .41381 L F
.76639 .4165 m .76802 .41383 L .7693 .41554 L F
.76639 .4165 m .7651 .41478 L .76802 .41383 L F
.87442 .41532 m .8762 .41266 L .87739 .41439 L 0 .024 .123 r
F
.87442 .41532 m .87323 .41359 L .8762 .41266 L F
.34415 .41829 m .34516 .41594 L .34685 .41755 L 0 .031 .132 r
F
.34415 .41829 m .34246 .41667 L .34516 .41594 L F
.69107 .41833 m .69259 .41573 L .69395 .41742 L 0 .031 .131 r
F
.69107 .41833 m .68971 .41663 L .69259 .41573 L F
.28582 .4168 m .28676 .41416 L .2885 .41586 L 0 .028 .127 r
F
.28582 .4168 m .28408 .41511 L .28676 .41416 L F
.92135 .41523 m .9232 .41261 L .92434 .41424 L 0 .024 .123 r
F
.92135 .41523 m .92021 .4136 L .9232 .41261 L F
.82752 .41564 m .82924 .41303 L .83046 .41468 L 0 .025 .124 r
F
.82752 .41564 m .82629 .41398 L .82924 .41303 L F
.92846 .41489 m .93033 .41232 L .93146 .41396 L 0 .024 .122 r
F
.92846 .41489 m .92733 .41326 L .93033 .41232 L F
.40957 .41966 m .41068 .41713 L .4123 .41891 L 0 .034 .135 r
F
.40957 .41966 m .40795 .41788 L .41068 .41713 L F
.88154 .41513 m .88335 .41254 L .88452 .41422 L 0 .024 .123 r
F
.88154 .41513 m .88037 .41345 L .88335 .41254 L F
.77351 .41637 m .77515 .41377 L .77643 .41549 L 0 .027 .126 r
F
.77351 .41637 m .77223 .41466 L .77515 .41377 L F
.69818 .41815 m .69971 .4155 L .70107 .41721 L 0 .031 .131 r
F
.69818 .41815 m .69683 .41646 L .69971 .4155 L F
.53053 .42509 m .53183 .42305 L .53333 .42453 L 0 .049 .151 r
F
.53053 .42509 m .52902 .42361 L .53183 .42305 L F
.25309 .41644 m .25398 .41385 L .25574 .41563 L 0 .027 .127 r
F
.25309 .41644 m .25132 .41469 L .25398 .41385 L F
.29291 .41664 m .29386 .41396 L .29559 .41571 L 0 .028 .127 r
F
.29291 .41664 m .29118 .41491 L .29386 .41396 L F
.83464 .41547 m .83636 .41273 L .83759 .41448 L 0 .025 .124 r
F
.83464 .41547 m .83341 .41371 L .83636 .41273 L F
.49782 .42455 m .49906 .42268 L .5006 .42398 L 0 .048 .15 r
F
.49782 .42455 m .49627 .4232 L .49906 .42268 L F
.32562 .4173 m .32661 .41477 L .32831 .41643 L 0 .029 .129 r
F
.32562 .4173 m .32391 .41566 L .32661 .41477 L F
.88867 .41494 m .89049 .41243 L .89165 .41405 L 0 .024 .123 r
F
.88867 .41494 m .8875 .41332 L .89049 .41243 L F
.93559 .41476 m .93747 .41217 L .9386 .41387 L 0 .024 .122 r
F
.93559 .41476 m .93446 .41306 L .93747 .41217 L F
.37685 .41929 m .37792 .41667 L .37957 .41838 L 0 .033 .134 r
F
.37685 .41929 m .37519 .41756 L .37792 .41667 L F
.7053 .41794 m .70685 .41544 L .70819 .41708 L 0 .031 .131 r
F
.7053 .41794 m .70395 .4163 L .70685 .41544 L F
.78063 .41622 m .7823 .41376 L .78356 .41534 L 0 .027 .126 r
F
.78063 .41622 m .77936 .41462 L .7823 .41376 L F
.84176 .41524 m .84349 .41252 L .84471 .41427 L 0 .025 .123 r
F
.84176 .41524 m .84054 .41349 L .84349 .41252 L F
.44659 .42274 m .44775 .42049 L .44934 .42209 L 0 .043 .145 r
F
.44659 .42274 m .44499 .42116 L .44775 .42049 L F
.35123 .41841 m .35225 .41602 L .35393 .4176 L 0 .032 .133 r
F
.35123 .41841 m .34954 .41681 L .35225 .41602 L F
.71951 .41724 m .72107 .41464 L .72239 .41619 L 0 .029 .129 r
F
.71951 .41724 m .71818 .41569 L .72107 .41464 L F
.42807 .42142 m .42921 .41886 L .43081 .42065 L 0 .039 .141 r
F
.42807 .42142 m .42647 .41962 L .42921 .41886 L F
.4722 .42379 m .4734 .42168 L .47496 .42319 L 0 .046 .148 r
F
.4722 .42379 m .47063 .42229 L .4734 .42168 L F
.22035 .41611 m .2212 .41337 L .223 .41515 L 0 .027 .126 r
F
.22035 .41611 m .21856 .41434 L .2212 .41337 L F
.8958 .41478 m .89763 .41229 L .89879 .41389 L 0 .024 .123 r
F
.8958 .41478 m .89464 .41317 L .89763 .41229 L F
.72662 .41695 m .72818 .41421 L .72951 .41599 L 0 .028 .128 r
F
.72662 .41695 m .72529 .4152 L .72818 .41421 L F
.71241 .41778 m .71397 .41519 L .7153 .41675 L 0 .031 .131 r
F
.71241 .41778 m .71108 .41622 L .71397 .41519 L F
.78775 .41603 m .78942 .41348 L .79067 .41505 L 0 .027 .126 r
F
.78775 .41603 m .78649 .41446 L .78942 .41348 L F
.38394 .41921 m .38501 .41677 L .38665 .41841 L 0 .034 .135 r
F
.38394 .41921 m .38229 .41754 L .38501 .41677 L F
.84888 .41508 m .85064 .4125 L .85185 .41417 L 0 .025 .123 r
F
.84888 .41508 m .84767 .41339 L .85064 .4125 L F
.3327 .41725 m .3337 .41476 L .33539 .41646 L 0 .03 .13 r
F
.3327 .41725 m .331 .41557 L .3337 .41476 L F
.35832 .41827 m .35935 .41577 L .36103 .41734 L 0 .032 .132 r
F
.35832 .41827 m .35664 .41669 L .35935 .41577 L F
.79486 .41571 m .79653 .41311 L .79779 .41477 L 0 .026 .125 r
F
.79486 .41571 m .7936 .41406 L .79653 .41311 L F
.29998 .4167 m .30093 .41415 L .30265 .41594 L 0 .028 .128 r
F
.29998 .4167 m .29826 .41493 L .30093 .41415 L F
.26015 .41652 m .26106 .41378 L .26282 .41556 L 0 .028 .127 r
F
.26015 .41652 m .2584 .41474 L .26106 .41378 L F
.22743 .41594 m .22829 .41327 L .23008 .41503 L 0 .027 .126 r
F
.22743 .41594 m .22564 .41418 L .22829 .41327 L F
.61577 .42092 m .61719 .41846 L .61861 .41991 L 0 .038 .14 r
F
.61577 .42092 m .61435 .41945 L .61719 .41846 L F
.856 .41485 m .85777 .41224 L .85896 .41386 L 0 .025 .123 r
F
.856 .41485 m .85481 .41323 L .85777 .41224 L F
.73373 .41682 m .73531 .4141 L .73663 .41586 L 0 .028 .128 r
F
.73373 .41682 m .73241 .41504 L .73531 .4141 L F
.90293 .41466 m .90476 .41202 L .90592 .41372 L 0 .024 .123 r
F
.90293 .41466 m .90177 .41298 L .90476 .41202 L F
.86311 .41449 m .8649 .412 L .86608 .41361 L 0 .024 .122 r
F
.86311 .41449 m .86192 .41287 L .8649 .412 L F
.62288 .4206 m .62431 .41822 L .62573 .41977 L 0 .038 .139 r
F
.62288 .4206 m .62146 .41906 L .62431 .41822 L F
.55895 .42415 m .56028 .42176 L .56176 .42311 L 0 .047 .149 r
F
.55895 .42415 m .55747 .42279 L .56028 .42176 L F
.60867 .42141 m .61008 .41906 L .61151 .42043 L 0 .04 .142 r
F
.60867 .42141 m .60724 .42 L .61008 .41906 L F
.45368 .42279 m .45486 .42026 L .45644 .42191 L 0 .043 .145 r
F
.45368 .42279 m .45209 .42118 L .45486 .42026 L F
.50492 .42478 m .50617 .4227 L .5077 .42404 L 0 .049 .151 r
F
.50492 .42478 m .50338 .42342 L .50617 .4227 L F
.41665 .42006 m .41777 .41764 L .41938 .41943 L 0 .036 .138 r
F
.41665 .42006 m .41503 .41828 L .41777 .41764 L F
.60157 .42183 m .60297 .41948 L .6044 .42092 L 0 .041 .143 r
F
.60157 .42183 m .60013 .42036 L .60297 .41948 L F
.74795 .41612 m .74956 .41355 L .75085 .41514 L 0 .027 .127 r
F
.74795 .41612 m .74665 .41452 L .74956 .41355 L F
.65129 .41908 m .65276 .41649 L .65415 .41809 L 0 .034 .135 r
F
.65129 .41908 m .6499 .4175 L .65276 .41649 L F
.56605 .42385 m .5674 .42161 L .56887 .42313 L 0 .046 .149 r
F
.56605 .42385 m .56458 .42232 L .5674 .42161 L F
.53764 .42545 m .53894 .42337 L .54044 .42488 L 0 .051 .153 r
F
.53764 .42545 m .53614 .42396 L .53894 .42337 L F
.26724 .41639 m .26815 .41369 L .2699 .41547 L 0 .028 .127 r
F
.26724 .41639 m .26549 .4146 L .26815 .41369 L F
.74085 .41659 m .74244 .41387 L .74375 .41556 L 0 .028 .128 r
F
.74085 .41659 m .73954 .4149 L .74244 .41387 L F
.3654 .41817 m .36644 .4159 L .36811 .4175 L 0 .032 .133 r
F
.3654 .41817 m .36373 .41659 L .36644 .4159 L F
.64419 .41958 m .64565 .41707 L .64705 .41852 L 0 .035 .137 r
F
.64419 .41958 m .6428 .41816 L .64565 .41707 L F
.4793 .42392 m .48051 .42172 L .48207 .4231 L 0 .047 .149 r
F
.4793 .42392 m .47773 .42253 L .48051 .42172 L F
.59447 .42235 m .59586 .41994 L .5973 .42134 L 0 .042 .144 r
F
.59447 .42235 m .59303 .42098 L .59586 .41994 L F
.80199 .41566 m .80368 .41305 L .80493 .4148 L 0 .027 .126 r
F
.80199 .41566 m .80073 .41391 L .80368 .41305 L F
.75506 .41586 m .75669 .41341 L .75798 .41498 L 0 .027 .127 r
F
.75506 .41586 m .75377 .41428 L .75669 .41341 L F
.39102 .41924 m .3921 .4168 L .39375 .4184 L 0 .035 .136 r
F
.39102 .41924 m .38938 .41762 L .3921 .4168 L F
.91006 .41451 m .91191 .41191 L .91306 .41364 L 0 .024 .123 r
F
.91006 .41451 m .90891 .41278 L .91191 .41191 L F
.67261 .41808 m .67411 .41556 L .67548 .41708 L 0 .032 .132 r
F
.67261 .41808 m .67124 .41655 L .67411 .41556 L F
.2345 .41593 m .23536 .41338 L .23714 .41511 L 0 .027 .127 r
F
.2345 .41593 m .23272 .41421 L .23536 .41338 L F
.65841 .4189 m .65988 .41622 L .66127 .41794 L 0 .033 .134 r
F
.65841 .4189 m .65701 .41714 L .65988 .41622 L F
.43516 .42166 m .43631 .41917 L .4379 .42087 L 0 .04 .142 r
F
.43516 .42166 m .43356 .41991 L .43631 .41917 L F
.30705 .41674 m .30802 .41411 L .30974 .41576 L 0 .029 .129 r
F
.30705 .41674 m .30533 .41509 L .30802 .41411 L F
.67972 .41773 m .68124 .41539 L .6826 .41689 L 0 .032 .132 r
F
.67972 .41773 m .67836 .41624 L .68124 .41539 L F
.62999 .4205 m .63143 .41814 L .63284 .4197 L 0 .038 .14 r
F
.62999 .4205 m .62858 .41895 L .63143 .41814 L F
.55185 .42484 m .55317 .42259 L .55466 .42382 L 0 .049 .152 r
F
.55185 .42484 m .55036 .42359 L .55317 .42259 L F
.4864 .42366 m .48762 .42166 L .48917 .42301 L 0 .046 .149 r
F
.4864 .42366 m .48484 .42229 L .48762 .42166 L F
.46078 .42269 m .46196 .42042 L .46354 .422 L 0 .043 .146 r
F
.46078 .42269 m .4592 .42112 L .46196 .42042 L F
.27432 .41619 m .27524 .41363 L .27699 .41528 L 0 .028 .127 r
F
.27432 .41619 m .27257 .41456 L .27524 .41363 L F
.31415 .41639 m .31512 .41398 L .31684 .41559 L 0 .029 .128 r
F
.31415 .41639 m .31243 .41479 L .31512 .41398 L F
.51202 .4247 m .51328 .42219 L .51481 .42379 L 0 .048 .151 r
F
.51202 .4247 m .51049 .42311 L .51328 .42219 L F
.33977 .41741 m .34078 .41498 L .34246 .41667 L 0 .031 .131 r
F
.33977 .41741 m .33808 .41572 L .34078 .41498 L F
.87025 .41448 m .87204 .41186 L .87323 .41359 L 0 .024 .123 r
F
.87025 .41448 m .86906 .41274 L .87204 .41186 L F
.66552 .41866 m .667 .41595 L .66838 .4176 L 0 .033 .134 r
F
.66552 .41866 m .66413 .41698 L .667 .41595 L F
.76218 .41574 m .76381 .41312 L .7651 .41478 L 0 .027 .126 r
F
.76218 .41574 m .76089 .41406 L .76381 .41312 L F
.6371 .42028 m .63855 .41784 L .63995 .41925 L 0 .037 .139 r
F
.6371 .42028 m .6357 .41889 L .63855 .41784 L F
.68683 .41753 m .68836 .41514 L .68971 .41663 L 0 .031 .132 r
F
.68683 .41753 m .68548 .41602 L .68836 .41514 L F
.58737 .42306 m .58875 .4207 L .5902 .42202 L 0 .044 .147 r
F
.58737 .42306 m .58592 .42176 L .58875 .4207 L F
.80912 .41558 m .8108 .41283 L .81205 .41457 L 0 .026 .126 r
F
.80912 .41558 m .80787 .41384 L .8108 .41283 L F
.39811 .41914 m .39921 .41669 L .40084 .41825 L 0 .035 .136 r
F
.39811 .41914 m .39647 .41756 L .39921 .41669 L F
.81623 .4152 m .81793 .4126 L .81917 .41425 L 0 .026 .125 r
F
.81623 .4152 m .81499 .41355 L .81793 .4126 L F
.51912 .42446 m .5204 .42198 L .52192 .42353 L 0 .048 .15 r
F
.51912 .42446 m .5176 .42289 L .5204 .42198 L F
.24158 .41581 m .24246 .4131 L .24424 .4148 L 0 .027 .126 r
F
.24158 .41581 m .2398 .41413 L .24246 .4131 L F
.28141 .41601 m .28234 .41344 L .28408 .41511 L 0 .028 .127 r
F
.28141 .41601 m .27966 .41436 L .28234 .41344 L F
.57316 .4239 m .57452 .42168 L .57599 .42316 L 0 .047 .149 r
F
.57316 .4239 m .5717 .42241 L .57452 .42168 L F
.91721 .41449 m .91907 .41189 L .92021 .4136 L 0 .025 .123 r
F
.91721 .41449 m .91607 .41278 L .91907 .41189 L F
.40521 .41885 m .40632 .41634 L .40795 .41788 L 0 .034 .135 r
F
.40521 .41885 m .40358 .4173 L .40632 .41634 L F
.52623 .42417 m .52751 .42212 L .52902 .42361 L 0 .048 .151 r
F
.52623 .42417 m .52471 .42268 L .52751 .42212 L F
.82334 .41493 m .82506 .41235 L .82629 .41398 L 0 .026 .124 r
F
.82334 .41493 m .82211 .4133 L .82506 .41235 L F
.24868 .41553 m .24956 .41295 L .25132 .41469 L 0 .027 .126 r
F
.24868 .41553 m .2469 .41381 L .24956 .41295 L F
.54475 .42559 m .54606 .42333 L .54755 .4246 L 0 .052 .154 r
F
.54475 .42559 m .54325 .42431 L .54606 .42333 L F
.7693 .41554 m .77094 .41294 L .77223 .41466 L 0 .027 .126 r
F
.7693 .41554 m .76802 .41383 L .77094 .41294 L F
.87739 .41439 m .87918 .41174 L .88037 .41345 L 0 .024 .123 r
F
.87739 .41439 m .8762 .41266 L .87918 .41174 L F
.92434 .41424 m .9262 .41162 L .92733 .41326 L F
.92434 .41424 m .9232 .41261 L .9262 .41162 L F
.69395 .41742 m .69548 .41476 L .69683 .41646 L 0 .031 .131 r
F
.69395 .41742 m .69259 .41573 L .69548 .41476 L F
.32123 .41644 m .32221 .41402 L .32391 .41566 L 0 .029 .129 r
F
.32123 .41644 m .31952 .41482 L .32221 .41402 L F
.58027 .42373 m .58164 .42151 L .5831 .42282 L 0 .047 .149 r
F
.58027 .42373 m .57881 .42242 L .58164 .42151 L F
.83046 .41468 m .83219 .41207 L .83341 .41371 L 0 .025 .124 r
F
.83046 .41468 m .82924 .41303 L .83219 .41207 L F
.2885 .41586 m .28944 .41318 L .29118 .41491 L 0 .028 .127 r
F
.2885 .41586 m .28676 .41416 L .28944 .41318 L F
.44225 .42178 m .4434 .41957 L .44499 .42116 L 0 .042 .144 r
F
.44225 .42178 m .44065 .4202 L .4434 .41957 L F
.42373 .42042 m .42486 .41783 L .42647 .41962 L 0 .038 .14 r
F
.42373 .42042 m .42212 .41863 L .42486 .41783 L F
.37248 .41845 m .37354 .4159 L .37519 .41756 L 0 .033 .134 r
F
.37248 .41845 m .37082 .4168 L .37354 .4159 L F
.93146 .41396 m .93334 .41143 L .93446 .41306 L 0 .024 .122 r
F
.93146 .41396 m .93033 .41232 L .93334 .41143 L F
.4935 .42384 m .49473 .42185 L .49627 .4232 L 0 .048 .15 r
F
.4935 .42384 m .49195 .42243 L .49473 .42185 L F
.34685 .41755 m .34786 .41522 L .34954 .41681 L 0 .032 .132 r
F
.34685 .41755 m .34516 .41594 L .34786 .41522 L F
.88452 .41422 m .88633 .41165 L .8875 .41332 L 0 .024 .123 r
F
.88452 .41422 m .88335 .41254 L .88633 .41165 L F
.46787 .4229 m .46906 .42067 L .47063 .42229 L 0 .045 .147 r
F
.46787 .4229 m .4663 .42131 L .46906 .42067 L F
.70107 .41721 m .7026 .41458 L .70395 .4163 L 0 .031 .131 r
F
.70107 .41721 m .69971 .4155 L .7026 .41458 L F
.83759 .41448 m .83931 .41173 L .84054 .41349 L 0 .025 .123 r
F
.83759 .41448 m .83636 .41273 L .83931 .41173 L F
.77643 .41549 m .77808 .4129 L .77936 .41462 L 0 .027 .126 r
F
.77643 .41549 m .77515 .41377 L .77808 .4129 L F
.29559 .41571 m .29653 .41316 L .29826 .41493 L 0 .028 .127 r
F
.29559 .41571 m .29386 .41396 L .29653 .41316 L F
.4123 .41891 m .41342 .41649 L .41503 .41828 L 0 .035 .136 r
F
.4123 .41891 m .41068 .41713 L .41342 .41649 L F
.72239 .41619 m .72396 .41363 L .72529 .4152 L 0 .029 .129 r
F
.72239 .41619 m .72107 .41464 L .72396 .41363 L F
.37957 .41838 m .38064 .41586 L .38229 .41754 L 0 .034 .135 r
F
.37957 .41838 m .37792 .41667 L .38064 .41586 L F
.25574 .41563 m .25664 .41295 L .2584 .41474 L 0 .027 .127 r
F
.25574 .41563 m .25398 .41385 L .25664 .41295 L F
.89165 .41405 m .89348 .41156 L .89464 .41317 L 0 .025 .123 r
F
.89165 .41405 m .89049 .41243 L .89348 .41156 L F
.32831 .41643 m .32931 .41388 L .331 .41557 L 0 .029 .129 r
F
.32831 .41643 m .32661 .41477 L .32931 .41388 L F
.84471 .41427 m .84646 .41165 L .84767 .41339 L 0 .025 .123 r
F
.84471 .41427 m .84349 .41252 L .84646 .41165 L F
.70819 .41708 m .70974 .41458 L .71108 .41622 L 0 .031 .131 r
F
.70819 .41708 m .70685 .41544 L .70974 .41458 L F
.78356 .41534 m .78523 .4129 L .78649 .41446 L 0 .027 .127 r
F
.78356 .41534 m .7823 .41376 L .78523 .4129 L F
.223 .41515 m .22385 .41241 L .22564 .41418 L 0 .026 .126 r
F
.223 .41515 m .2212 .41337 L .22385 .41241 L F
.7153 .41675 m .71686 .41413 L .71818 .41569 L 0 .03 .13 r
F
.7153 .41675 m .71397 .41519 L .71686 .41413 L F
.72951 .41599 m .73108 .41327 L .73241 .41504 L 0 .028 .128 r
F
.72951 .41599 m .72818 .41421 L .73108 .41327 L F
.35393 .4176 m .35496 .41511 L .35664 .41669 L 0 .032 .133 r
F
.35393 .4176 m .35225 .41602 L .35496 .41511 L F
.79067 .41505 m .79235 .41248 L .7936 .41406 L 0 .027 .126 r
F
.79067 .41505 m .78942 .41348 L .79235 .41248 L F
.53333 .42453 m .53463 .42246 L .53614 .42396 L 0 .05 .153 r
F
.53333 .42453 m .53183 .42305 L .53463 .42246 L F
.89879 .41389 m .90062 .41137 L .90177 .41298 L 0 .024 .123 r
F
.89879 .41389 m .89763 .41229 L .90062 .41137 L F
.5006 .42398 m .50184 .42215 L .50338 .42342 L 0 .049 .152 r
F
.5006 .42398 m .49906 .42268 L .50184 .42215 L F
.43081 .42065 m .43196 .41816 L .43356 .41991 L 0 .039 .141 r
F
.43081 .42065 m .42921 .41886 L .43196 .41816 L F
.85185 .41417 m .8536 .41156 L .85481 .41323 L 0 .025 .123 r
F
.85185 .41417 m .85064 .4125 L .8536 .41156 L F
.79779 .41477 m .79948 .41224 L .80073 .41391 L 0 .026 .125 r
F
.79779 .41477 m .79653 .41311 L .79948 .41224 L F
.26282 .41556 m .26373 .41282 L .26549 .4146 L 0 .028 .127 r
F
.26282 .41556 m .26106 .41378 L .26373 .41282 L F
.61861 .41991 m .62004 .41759 L .62146 .41906 L 0 .038 .14 r
F
.61861 .41991 m .61719 .41846 L .62004 .41759 L F
.36103 .41734 m .36206 .41501 L .36373 .41659 L 0 .032 .133 r
F
.36103 .41734 m .35935 .41577 L .36206 .41501 L F
.44934 .42209 m .45051 .41954 L .45209 .42118 L 0 .043 .145 r
F
.44934 .42209 m .44775 .42049 L .45051 .41954 L F
.23008 .41503 m .23093 .41246 L .23272 .41421 L 0 .027 .126 r
F
.23008 .41503 m .22829 .41327 L .23093 .41246 L F
.56176 .42311 m .5631 .42098 L .56458 .42232 L 0 .047 .149 r
F
.56176 .42311 m .56028 .42176 L .5631 .42098 L F
.85896 .41386 m .86073 .41125 L .86192 .41287 L 0 .024 .123 r
F
.85896 .41386 m .85777 .41224 L .86073 .41125 L F
.38665 .41841 m .38773 .41601 L .38938 .41762 L 0 .034 .136 r
F
.38665 .41841 m .38501 .41677 L .38773 .41601 L F
.73663 .41586 m .73822 .41316 L .73954 .4149 L 0 .028 .128 r
F
.73663 .41586 m .73531 .4141 L .73822 .41316 L F
.33539 .41646 m .33639 .41398 L .33808 .41572 L 0 .03 .13 r
F
.33539 .41646 m .3337 .41476 L .33639 .41398 L F
.90592 .41372 m .90775 .41107 L .90891 .41278 L 0 .024 .122 r
F
.90592 .41372 m .90476 .41202 L .90775 .41107 L F
.61151 .42043 m .61293 .4181 L .61435 .41945 L 0 .039 .141 r
F
.61151 .42043 m .61008 .41906 L .61293 .4181 L F
.47496 .42319 m .47617 .42101 L .47773 .42253 L 0 .047 .149 r
F
.47496 .42319 m .4734 .42168 L .47617 .42101 L F
.65415 .41809 m .65562 .41554 L .65701 .41714 L 0 .034 .135 r
F
.65415 .41809 m .65276 .41649 L .65562 .41554 L F
.75085 .41514 m .75247 .41269 L .75377 .41428 L 0 .027 .127 r
F
.75085 .41514 m .74956 .41355 L .75247 .41269 L F
.30265 .41594 m .30361 .41329 L .30533 .41509 L 0 .029 .129 r
F
.30265 .41594 m .30093 .41415 L .30361 .41329 L F
.74375 .41556 m .74534 .41284 L .74665 .41452 L 0 .028 .127 r
F
.74375 .41556 m .74244 .41387 L .74534 .41284 L F
.64705 .41852 m .64851 .41603 L .6499 .4175 L 0 .035 .136 r
F
.64705 .41852 m .64565 .41707 L .64851 .41603 L F
.86608 .41361 m .86787 .41113 L .86906 .41274 L 0 .024 .123 r
F
.86608 .41361 m .8649 .412 L .86787 .41113 L F
.6044 .42092 m .60581 .41859 L .60724 .42 L 0 .041 .143 r
F
.6044 .42092 m .60297 .41948 L .60581 .41859 L F
.45644 .42191 m .45762 .41946 L .4592 .42112 L 0 .043 .145 r
F
.45644 .42191 m .45486 .42026 L .45762 .41946 L F
.5973 .42134 m .59869 .41895 L .60013 .42036 L 0 .042 .144 r
F
.5973 .42134 m .59586 .41994 L .59869 .41895 L F
.62573 .41977 m .62716 .41739 L .62858 .41895 L 0 .038 .14 r
F
.62573 .41977 m .62431 .41822 L .62716 .41739 L F
.2699 .41547 m .27082 .41278 L .27257 .41456 L 0 .028 .127 r
F
.2699 .41547 m .26815 .41369 L .27082 .41278 L F
.67548 .41708 m .67699 .41471 L .67836 .41624 L 0 .032 .132 r
F
.67548 .41708 m .67411 .41556 L .67699 .41471 L F
.55466 .42382 m .55599 .42159 L .55747 .42279 L 0 .049 .151 r
F
.55466 .42382 m .55317 .42259 L .55599 .42159 L F
.5077 .42404 m .50896 .42179 L .51049 .42311 L 0 .049 .152 r
F
.5077 .42404 m .50617 .4227 L .50896 .42179 L F
.30974 .41576 m .31071 .41314 L .31243 .41479 L 0 .029 .128 r
F
.30974 .41576 m .30802 .41411 L .31071 .41314 L F
.66127 .41794 m .66275 .41529 L .66413 .41698 L 0 .033 .134 r
F
.66127 .41794 m .65988 .41622 L .66275 .41529 L F
.75798 .41498 m .75961 .4125 L .76089 .41406 L 0 .027 .127 r
F
.75798 .41498 m .75669 .41341 L .75961 .4125 L F
.80493 .4148 m .80661 .41209 L .80787 .41384 L 0 .027 .126 r
F
.80493 .4148 m .80368 .41305 L .80661 .41209 L F
.91306 .41364 m .91491 .41106 L .91607 .41278 L 0 .024 .123 r
F
.91306 .41364 m .91191 .41191 L .91491 .41106 L F
.48207 .4231 m .48328 .4209 L .48484 .42229 L 0 .047 .149 r
F
.48207 .4231 m .48051 .42172 L .48328 .4209 L F
.66838 .4176 m .66987 .41493 L .67124 .41655 L 0 .033 .133 r
F
.66838 .4176 m .667 .41595 L .66987 .41493 L F
.56887 .42313 m .57022 .42091 L .5717 .42241 L 0 .047 .149 r
F
.56887 .42313 m .5674 .42161 L .57022 .42091 L F
.39375 .4184 m .39483 .41598 L .39647 .41756 L 0 .035 .136 r
F
.39375 .4184 m .3921 .4168 L .39483 .41598 L F
.27699 .41528 m .27791 .4127 L .27966 .41436 L 0 .028 .127 r
F
.27699 .41528 m .27524 .41363 L .27791 .4127 L F
.41938 .41943 m .42051 .41685 L .42212 .41863 L 0 .037 .139 r
F
.41938 .41943 m .41777 .41764 L .42051 .41685 L F
.23714 .41511 m .23801 .41241 L .2398 .41413 L 0 .027 .127 r
F
.23714 .41511 m .23536 .41338 L .23801 .41241 L F
.63995 .41925 m .6414 .41673 L .6428 .41816 L 0 .037 .138 r
F
.63995 .41925 m .63855 .41784 L .6414 .41673 L F
.6826 .41689 m .68412 .41454 L .68548 .41602 L 0 .032 .132 r
F
.6826 .41689 m .68124 .41539 L .68412 .41454 L F
.51481 .42379 m .51608 .42131 L .5176 .42289 L 0 .048 .151 r
F
.51481 .42379 m .51328 .42219 L .51608 .42131 L F
.5902 .42202 m .59158 .41963 L .59303 .42098 L 0 .044 .146 r
F
.5902 .42202 m .58875 .4207 L .59158 .41963 L F
.36811 .4175 m .36915 .41519 L .37082 .4168 L 0 .033 .134 r
F
.36811 .4175 m .36644 .4159 L .36915 .41519 L F
.4379 .42087 m .43905 .41854 L .44065 .4202 L 0 .041 .143 r
F
.4379 .42087 m .43631 .41917 L .43905 .41854 L F
.81205 .41457 m .81374 .41182 L .81499 .41355 L 0 .026 .125 r
F
.81205 .41457 m .8108 .41283 L .81374 .41182 L F
.63284 .4197 m .63429 .41734 L .6357 .41889 L 0 .038 .14 r
F
.63284 .4197 m .63143 .41814 L .63429 .41734 L F
.87323 .41359 m .87501 .41094 L .8762 .41266 L 0 .024 .123 r
F
.87323 .41359 m .87204 .41186 L .87501 .41094 L F
.7651 .41478 m .76673 .41218 L .76802 .41383 L 0 .027 .126 r
F
.7651 .41478 m .76381 .41312 L .76673 .41218 L F
.31684 .41559 m .3178 .4132 L .31952 .41482 L 0 .029 .129 r
F
.31684 .41559 m .31512 .41398 L .3178 .4132 L F
.24424 .4148 m .24513 .41209 L .2469 .41381 L 0 .027 .126 r
F
.24424 .4148 m .24246 .4131 L .24513 .41209 L F
.54044 .42488 m .54175 .42278 L .54325 .42431 L 0 .052 .155 r
F
.54044 .42488 m .53894 .42337 L .54175 .42278 L F
.81917 .41425 m .82088 .41165 L .82211 .4133 L 0 .026 .125 r
F
.81917 .41425 m .81793 .4126 L .82088 .41165 L F
.52192 .42353 m .52319 .42115 L .52471 .42268 L 0 .048 .151 r
F
.52192 .42353 m .5204 .42198 L .52319 .42115 L F
.68971 .41663 m .69125 .41425 L .69259 .41573 L 0 .031 .132 r
F
.68971 .41663 m .68836 .41514 L .69125 .41425 L F
.40084 .41825 m .40194 .41575 L .40358 .4173 L 0 .035 .136 r
F
.40084 .41825 m .39921 .41669 L .40194 .41575 L F
.34246 .41667 m .34347 .41425 L .34516 .41594 L 0 .031 .132 r
F
.34246 .41667 m .34078 .41498 L .34347 .41425 L F
.46354 .422 m .46472 .41973 L .4663 .42131 L 0 .044 .147 r
F
.46354 .422 m .46196 .42042 L .46472 .41973 L F
.28408 .41511 m .28502 .41246 L .28676 .41416 L 0 .028 .127 r
F
.28408 .41511 m .28234 .41344 L .28502 .41246 L F
.48917 .42301 m .4904 .42113 L .49195 .42243 L 0 .048 .15 r
F
.48917 .42301 m .48762 .42166 L .4904 .42113 L F
.40795 .41788 m .40905 .41559 L .41068 .41713 L 0 .034 .135 r
F
.40795 .41788 m .40632 .41634 L .40905 .41559 L F
.54755 .4246 m .54887 .42234 L .55036 .42359 L 0 .051 .154 r
F
.54755 .4246 m .54606 .42333 L .54887 .42234 L F
.82629 .41398 m .82801 .41141 L .82924 .41303 L 0 .025 .124 r
F
.82629 .41398 m .82506 .41235 L .82801 .41141 L F
.92021 .4136 m .92206 .4109 L .9232 .41261 L 0 .025 .123 r
F
.92021 .4136 m .91907 .41189 L .92206 .4109 L F
.88037 .41345 m .88216 .41084 L .88335 .41254 L 0 .024 .123 r
F
.88037 .41345 m .87918 .41174 L .88216 .41084 L F
.92733 .41326 m .9292 .41069 L .93033 .41232 L 0 .024 .122 r
F
.92733 .41326 m .9262 .41162 L .9292 .41069 L F
.77223 .41466 m .77387 .41205 L .77515 .41377 L 0 .027 .126 r
F
.77223 .41466 m .77094 .41294 L .77387 .41205 L F
.57599 .42316 m .57735 .42094 L .57881 .42242 L 0 .048 .15 r
F
.57599 .42316 m .57452 .42168 L .57735 .42094 L F
.69683 .41646 m .69836 .41378 L .69971 .4155 L 0 .031 .131 r
F
.69683 .41646 m .69548 .41476 L .69836 .41378 L F
.25132 .41469 m .25221 .41208 L .25398 .41385 L 0 .027 .126 r
F
.25132 .41469 m .24956 .41295 L .25221 .41208 L F
.83341 .41371 m .83514 .41108 L .83636 .41273 L 0 .025 .124 r
F
.83341 .41371 m .83219 .41207 L .83514 .41108 L F
.29118 .41491 m .29213 .41221 L .29386 .41396 L 0 .027 .127 r
F
.29118 .41491 m .28944 .41318 L .29213 .41221 L F
.5831 .42282 m .58447 .42042 L .58592 .42176 L 0 .047 .149 r
F
.5831 .42282 m .58164 .42151 L .58447 .42042 L F
.37519 .41756 m .37626 .41499 L .37792 .41667 L 0 .033 .134 r
F
.37519 .41756 m .37354 .4159 L .37626 .41499 L F
.93446 .41306 m .93635 .41053 L .93747 .41217 L 0 .024 .122 r
F
.93446 .41306 m .93334 .41143 L .93635 .41053 L F
.32391 .41566 m .3249 .41312 L .32661 .41477 L 0 .029 .129 r
F
.32391 .41566 m .32221 .41402 L .3249 .41312 L F
.84054 .41349 m .84227 .41076 L .84349 .41252 L 0 .025 .123 r
F
.84054 .41349 m .83931 .41173 L .84227 .41076 L F
.42647 .41962 m .42761 .4171 L .42921 .41886 L 0 .038 .14 r
F
.42647 .41962 m .42486 .41783 L .42761 .4171 L F
.8875 .41332 m .88932 .41075 L .89049 .41243 L 0 .025 .123 r
F
.8875 .41332 m .88633 .41165 L .88932 .41075 L F
.70395 .4163 m .7055 .41373 L .70685 .41544 L 0 .031 .131 r
F
.70395 .4163 m .7026 .41458 L .7055 .41373 L F
.21856 .41434 m .21941 .4116 L .2212 .41337 L 0 .026 .125 r
F
.21856 .41434 m .21676 .41257 L .21941 .4116 L F
.52902 .42361 m .53031 .42156 L .53183 .42305 L 0 .05 .152 r
F
.52902 .42361 m .52751 .42212 L .53031 .42156 L F
.72529 .4152 m .72686 .41262 L .72818 .41421 L 0 .029 .128 r
F
.72529 .4152 m .72396 .41363 L .72686 .41262 L F
.77936 .41462 m .78102 .41205 L .7823 .41376 L 0 .027 .127 r
F
.77936 .41462 m .77808 .4129 L .78102 .41205 L F
.34954 .41681 m .35056 .41443 L .35225 .41602 L 0 .032 .133 r
F
.34954 .41681 m .34786 .41522 L .35056 .41443 L F
.44499 .42116 m .44615 .41889 L .44775 .42049 L 0 .043 .145 r
F
.44499 .42116 m .4434 .41957 L .44615 .41889 L F
.71818 .41569 m .71975 .41308 L .72107 .41464 L 0 .03 .13 r
F
.71818 .41569 m .71686 .41413 L .71975 .41308 L F
.49627 .4232 m .49751 .42137 L .49906 .42268 L 0 .049 .152 r
F
.49627 .4232 m .49473 .42185 L .49751 .42137 L F
.2584 .41474 m .25931 .41199 L .26106 .41378 L 0 .027 .127 r
F
.2584 .41474 m .25664 .41295 L .25931 .41199 L F
.29826 .41493 m .29921 .41237 L .30093 .41415 L 0 .028 .128 r
F
.29826 .41493 m .29653 .41316 L .29921 .41237 L F
.89464 .41317 m .89648 .41068 L .89763 .41229 L 0 .025 .123 r
F
.89464 .41317 m .89348 .41156 L .89648 .41068 L F
.22564 .41418 m .2265 .4115 L .22829 .41327 L 0 .026 .125 r
F
.22564 .41418 m .22385 .41241 L .2265 .4115 L F
.84767 .41339 m .84943 .41078 L .85064 .4125 L 0 .025 .123 r
F
.84767 .41339 m .84646 .41165 L .84943 .41078 L F
.38229 .41754 m .38336 .41513 L .38501 .41677 L 0 .034 .135 r
F
.38229 .41754 m .38064 .41586 L .38336 .41513 L F
.331 .41557 m .332 .41305 L .3337 .41476 L 0 .03 .13 r
F
.331 .41557 m .32931 .41388 L .332 .41305 L F
.47063 .42229 m .47183 .42003 L .4734 .42168 L 0 .046 .149 r
F
.47063 .42229 m .46906 .42067 L .47183 .42003 L F
.73241 .41504 m .73399 .41236 L .73531 .4141 L 0 .028 .128 r
F
.73241 .41504 m .73108 .41327 L .73399 .41236 L F
.71108 .41622 m .71263 .41357 L .71397 .41519 L 0 .031 .131 r
F
.71108 .41622 m .70974 .41458 L .71263 .41357 L F
.7936 .41406 m .79528 .41151 L .79653 .41311 L 0 .026 .126 r
F
.7936 .41406 m .79235 .41248 L .79528 .41151 L F
.78649 .41446 m .78816 .4119 L .78942 .41348 L 0 .027 .127 r
F
.78649 .41446 m .78523 .4129 L .78816 .4119 L F
.35664 .41669 m .35767 .4142 L .35935 .41577 L 0 .032 .133 r
F
.35664 .41669 m .35496 .41511 L .35767 .4142 L F
.41503 .41828 m .41615 .41585 L .41777 .41764 L 0 .036 .137 r
F
.41503 .41828 m .41342 .41649 L .41615 .41585 L F
.90177 .41298 m .90361 .41041 L .90476 .41202 L 0 .024 .123 r
F
.90177 .41298 m .90062 .41137 L .90361 .41041 L F
.26549 .4146 m .2664 .4119 L .26815 .41369 L 0 .028 .127 r
F
.26549 .4146 m .26373 .41282 L .2664 .4119 L F
.85481 .41323 m .85657 .41059 L .85777 .41224 L 0 .025 .123 r
F
.85481 .41323 m .8536 .41156 L .85657 .41059 L F
.86192 .41287 m .86371 .41038 L .8649 .412 L 0 .024 .123 r
F
.86192 .41287 m .86073 .41125 L .86371 .41038 L F
.45209 .42118 m .45327 .4186 L .45486 .42026 L 0 .043 .145 r
F
.45209 .42118 m .45051 .41954 L .45327 .4186 L F
.80073 .41391 m .80242 .41137 L .80368 .41305 L 0 .026 .126 r
F
.80073 .41391 m .79948 .41224 L .80242 .41137 L F
.73954 .4149 m .74112 .41215 L .74244 .41387 L 0 .028 .128 r
F
.73954 .4149 m .73822 .41316 L .74112 .41215 L F
.61435 .41945 m .61577 .41714 L .61719 .41846 L 0 .039 .141 r
F
.61435 .41945 m .61293 .4181 L .61577 .41714 L F
.74665 .41452 m .74825 .41188 L .74956 .41355 L 0 .028 .127 r
F
.74665 .41452 m .74534 .41284 L .74825 .41188 L F
.62146 .41906 m .62289 .41671 L .62431 .41822 L 0 .038 .14 r
F
.62146 .41906 m .62004 .41759 L .62289 .41671 L F
.6499 .4175 m .65137 .41498 L .65276 .41649 L 0 .034 .135 r
F
.6499 .4175 m .64851 .41603 L .65137 .41498 L F
.90891 .41278 m .91075 .41021 L .91191 .41191 L 0 .024 .122 r
F
.90891 .41278 m .90775 .41107 L .91075 .41021 L F
.65701 .41714 m .65849 .41464 L .65988 .41622 L 0 .034 .135 r
F
.65701 .41714 m .65562 .41554 L .65849 .41464 L F
.43356 .41991 m .43471 .41747 L .43631 .41917 L 0 .04 .142 r
F
.43356 .41991 m .43196 .41816 L .43471 .41747 L F
.23272 .41421 m .23357 .41164 L .23536 .41338 L 0 .027 .126 r
F
.23272 .41421 m .23093 .41246 L .23357 .41164 L F
.36373 .41659 m .36477 .41431 L .36644 .4159 L 0 .033 .134 r
F
.36373 .41659 m .36206 .41501 L .36477 .41431 L F
.56458 .42232 m .56593 .42028 L .5674 .42161 L 0 .047 .15 r
F
.56458 .42232 m .5631 .42098 L .56593 .42028 L F
.60013 .42036 m .60153 .4181 L .60297 .41948 L 0 .042 .144 r
F
.60013 .42036 m .59869 .41895 L .60153 .4181 L F
.38938 .41762 m .39046 .41522 L .3921 .4168 L 0 .035 .136 r
F
.38938 .41762 m .38773 .41601 L .39046 .41522 L F
.75377 .41428 m .7554 .41184 L .75669 .41341 L 0 .028 .127 r
F
.75377 .41428 m .75247 .41269 L .7554 .41184 L F
.60724 .42 m .60865 .41768 L .61008 .41906 L 0 .041 .143 r
F
.60724 .42 m .60581 .41859 L .60865 .41768 L F
.53614 .42396 m .53744 .42184 L .53894 .42337 L 0 .052 .154 r
F
.53614 .42396 m .53463 .42246 L .53744 .42184 L F
.30533 .41509 m .30631 .41232 L .30802 .41411 L 0 .029 .129 r
F
.30533 .41509 m .30361 .41329 L .30631 .41232 L F
.55747 .42279 m .5588 .42059 L .56028 .42176 L 0 .048 .151 r
F
.55747 .42279 m .55599 .42159 L .5588 .42059 L F
.86906 .41274 m .87086 .41025 L .87204 .41186 L 0 .024 .123 r
F
.86906 .41274 m .86787 .41113 L .87086 .41025 L F
.33808 .41572 m .33909 .41321 L .34078 .41498 L 0 .031 .131 r
F
.33808 .41572 m .33639 .41398 L .33909 .41321 L F
.50338 .42342 m .50463 .42146 L .50617 .4227 L 0 .05 .153 r
F
.50338 .42342 m .50184 .42215 L .50463 .42146 L F
.27257 .41456 m .27349 .41186 L .27524 .41363 L 0 .028 .127 r
F
.27257 .41456 m .27082 .41278 L .27349 .41186 L F
.67124 .41655 m .67274 .41395 L .67411 .41556 L 0 .032 .133 r
F
.67124 .41655 m .66987 .41493 L .67274 .41395 L F
.31243 .41479 m .3134 .41232 L .31512 .41398 L 0 .029 .129 r
F
.31243 .41479 m .31071 .41314 L .3134 .41232 L F
.6428 .41816 m .64426 .41562 L .64565 .41707 L 0 .036 .138 r
F
.6428 .41816 m .6414 .41673 L .64426 .41562 L F
.62858 .41895 m .63002 .41659 L .63143 .41814 L 0 .038 .14 r
F
.62858 .41895 m .62716 .41739 L .63002 .41659 L F
.66413 .41698 m .66562 .4143 L .667 .41595 L 0 .033 .134 r
F
.66413 .41698 m .66275 .41529 L .66562 .4143 L F
.4592 .42112 m .46038 .41876 L .46196 .42042 L 0 .044 .146 r
F
.4592 .42112 m .45762 .41946 L .46038 .41876 L F
.80787 .41384 m .80955 .41109 L .8108 .41283 L 0 .026 .125 r
F
.80787 .41384 m .80661 .41209 L .80955 .41109 L F
.51049 .42311 m .51175 .42088 L .51328 .42219 L 0 .049 .152 r
F
.51049 .42311 m .50896 .42179 L .51175 .42088 L F
.47773 .42253 m .47894 .4202 L .48051 .42172 L 0 .047 .15 r
F
.47773 .42253 m .47617 .42101 L .47894 .4202 L F
.76089 .41406 m .76253 .41157 L .76381 .41312 L 0 .027 .127 r
F
.76089 .41406 m .75961 .4125 L .76253 .41157 L F
.67836 .41624 m .67988 .41387 L .68124 .41539 L 0 .032 .133 r
F
.67836 .41624 m .67699 .41471 L .67988 .41387 L F
.59303 .42098 m .59441 .41857 L .59586 .41994 L 0 .043 .146 r
F
.59303 .42098 m .59158 .41963 L .59441 .41857 L F
.2398 .41413 m .24068 .41139 L .24246 .4131 L 0 .027 .126 r
F
.2398 .41413 m .23801 .41241 L .24068 .41139 L F
.81499 .41355 m .81669 .41087 L .81793 .4126 L 0 .026 .125 r
F
.81499 .41355 m .81374 .41182 L .81669 .41087 L F
.27966 .41436 m .28059 .41176 L .28234 .41344 L 0 .028 .127 r
F
.27966 .41436 m .27791 .4127 L .28059 .41176 L F
.91607 .41278 m .91792 .41017 L .91907 .41189 L 0 .025 .123 r
F
.91607 .41278 m .91491 .41106 L .91792 .41017 L F
.48484 .42229 m .48606 .42031 L .48762 .42166 L 0 .048 .15 r
F
.48484 .42229 m .48328 .4209 L .48606 .42031 L F
.2469 .41381 m .24778 .4112 L .24956 .41295 L 0 .027 .126 r
F
.2469 .41381 m .24513 .41209 L .24778 .4112 L F
.39647 .41756 m .39756 .41514 L .39921 .41669 L 0 .035 .136 r
F
.39647 .41756 m .39483 .41598 L .39756 .41514 L F
.5176 .42289 m .51887 .42043 L .5204 .42198 L 0 .048 .151 r
F
.5176 .42289 m .51608 .42131 L .51887 .42043 L F
.76802 .41383 m .76966 .41128 L .77094 .41294 L 0 .027 .126 r
F
.76802 .41383 m .76673 .41218 L .76966 .41128 L F
.8762 .41266 m .878 .41003 L .87918 .41174 L 0 .024 .123 r
F
.8762 .41266 m .87501 .41094 L .878 .41003 L F
.68548 .41602 m .68701 .41368 L .68836 .41514 L 0 .032 .132 r
F
.68548 .41602 m .68412 .41454 L .68701 .41368 L F
.82211 .4133 m .82383 .4107 L .82506 .41235 L 0 .026 .125 r
F
.82211 .4133 m .82088 .41165 L .82383 .4107 L F
.42212 .41863 m .42325 .41606 L .42486 .41783 L 0 .038 .139 r
F
.42212 .41863 m .42051 .41685 L .42325 .41606 L F
.5717 .42241 m .57305 .42019 L .57452 .42168 L 0 .048 .15 r
F
.5717 .42241 m .57022 .42091 L .57305 .42019 L F
.55036 .42359 m .55168 .42135 L .55317 .42259 L 0 .051 .153 r
F
.55036 .42359 m .54887 .42234 L .55168 .42135 L F
.40358 .4173 m .40468 .41481 L .40632 .41634 L 0 .035 .136 r
F
.40358 .4173 m .40194 .41575 L .40468 .41481 L F
.69259 .41573 m .69413 .41325 L .69548 .41476 L 0 .031 .132 r
F
.69259 .41573 m .69125 .41425 L .69413 .41325 L F
.6357 .41889 m .63715 .4163 L .63855 .41784 L 0 .038 .14 r
F
.6357 .41889 m .63429 .41734 L .63715 .4163 L F
.28676 .41416 m .28771 .41147 L .28944 .41318 L 0 .027 .127 r
F
.28676 .41416 m .28502 .41246 L .28771 .41147 L F
.9232 .41261 m .92506 .40992 L .9262 .41162 L 0 .024 .123 r
F
.9232 .41261 m .92206 .4109 L .92506 .40992 L F
.52471 .42268 m .526 .4206 L .52751 .42212 L 0 .049 .151 r
F
.52471 .42268 m .52319 .42115 L .526 .4206 L F
.82924 .41303 m .83097 .41046 L .83219 .41207 L 0 .025 .124 r
F
.82924 .41303 m .82801 .41141 L .83097 .41046 L F
.31952 .41482 m .32049 .41239 L .32221 .41402 L 0 .029 .129 r
F
.31952 .41482 m .3178 .4132 L .32049 .41239 L F
.37082 .4168 m .37187 .41426 L .37354 .4159 L 0 .034 .135 r
F
.37082 .4168 m .36915 .41519 L .37187 .41426 L F
.58592 .42176 m .5873 .41934 L .58875 .4207 L 0 .046 .148 r
F
.58592 .42176 m .58447 .42042 L .5873 .41934 L F
.44065 .4202 m .4418 .41794 L .4434 .41957 L 0 .042 .144 r
F
.44065 .4202 m .43905 .41854 L .4418 .41794 L F
.93033 .41232 m .93221 .40978 L .93334 .41143 L 0 .024 .122 r
F
.93033 .41232 m .9292 .41069 L .93221 .40978 L F
.83636 .41273 m .83809 .41009 L .83931 .41173 L 0 .025 .123 r
F
.83636 .41273 m .83514 .41108 L .83809 .41009 L F
.69971 .4155 m .70125 .41286 L .7026 .41458 L 0 .031 .131 r
F
.69971 .4155 m .69836 .41378 L .70125 .41286 L F
.88335 .41254 m .88515 .40994 L .88633 .41165 L 0 .024 .123 r
F
.88335 .41254 m .88216 .41084 L .88515 .40994 L F
.29386 .41396 m .2948 .4114 L .29653 .41316 L 0 .027 .127 r
F
.29386 .41396 m .29213 .41221 L .2948 .4114 L F
.77515 .41377 m .7768 .41118 L .77808 .4129 L 0 .027 .126 r
F
.77515 .41377 m .77387 .41205 L .7768 .41118 L F
.41068 .41713 m .41179 .41495 L .41342 .41649 L 0 .035 .136 r
F
.41068 .41713 m .40905 .41559 L .41179 .41495 L F
.34516 .41594 m .34617 .41352 L .34786 .41522 L 0 .032 .133 r
F
.34516 .41594 m .34347 .41425 L .34617 .41352 L F
.4663 .42131 m .46749 .41905 L .46906 .42067 L 0 .045 .148 r
F
.4663 .42131 m .46472 .41973 L .46749 .41905 L F
.25398 .41385 m .25487 .41117 L .25664 .41295 L 0 .027 .126 r
F
.25398 .41385 m .25221 .41208 L .25487 .41117 L F
.54325 .42431 m .54456 .42182 L .54606 .42333 L 0 .053 .155 r
F
.54325 .42431 m .54175 .42278 L .54456 .42182 L F
.84349 .41252 m .84524 .40991 L .84646 .41165 L 0 .025 .123 r
F
.84349 .41252 m .84227 .41076 L .84524 .40991 L F
.37792 .41667 m .37898 .41417 L .38064 .41586 L 0 .034 .135 r
F
.37792 .41667 m .37626 .41499 L .37898 .41417 L F
.57881 .42242 m .58018 .42003 L .58164 .42151 L 0 .048 .151 r
F
.57881 .42242 m .57735 .42094 L .58018 .42003 L F
.49195 .42243 m .49318 .4206 L .49473 .42185 L 0 .049 .152 r
F
.49195 .42243 m .4904 .42113 L .49318 .4206 L F
.2212 .41337 m .22206 .41063 L .22385 .41241 L 0 .026 .125 r
F
.2212 .41337 m .21941 .4116 L .22206 .41063 L F
.32661 .41477 m .3276 .41222 L .32931 .41388 L 0 .029 .129 r
F
.32661 .41477 m .3249 .41312 L .3276 .41222 L F
.89049 .41243 m .89231 .40989 L .89348 .41156 L 0 .025 .123 r
F
.89049 .41243 m .88932 .41075 L .89231 .40989 L F
.72818 .41421 m .72977 .41168 L .73108 .41327 L 0 .028 .128 r
F
.72818 .41421 m .72686 .41262 L .72977 .41168 L F
.72107 .41464 m .72264 .41206 L .72396 .41363 L 0 .029 .129 r
F
.72107 .41464 m .71975 .41308 L .72264 .41206 L F
.70685 .41544 m .7084 .41287 L .70974 .41458 L 0 .031 .131 r
F
.70685 .41544 m .7055 .41373 L .7084 .41287 L F
.42921 .41886 m .43035 .41645 L .43196 .41816 L 0 .039 .141 r
F
.42921 .41886 m .42761 .4171 L .43035 .41645 L F
.7823 .41376 m .78396 .4112 L .78523 .4129 L 0 .028 .127 r
F
.7823 .41376 m .78102 .41205 L .78396 .4112 L F
.26106 .41378 m .26198 .41103 L .26373 .41282 L 0 .027 .127 r
F
.26106 .41378 m .25931 .41199 L .26198 .41103 L F
.71397 .41519 m .71552 .41252 L .71686 .41413 L 0 .03 .131 r
F
.71397 .41519 m .71263 .41357 L .71552 .41252 L F
.35225 .41602 m .35327 .41353 L .35496 .41511 L 0 .033 .133 r
F
.35225 .41602 m .35056 .41443 L .35327 .41353 L F
.22829 .41327 m .22914 .4107 L .23093 .41246 L 0 .027 .126 r
F
.22829 .41327 m .2265 .4115 L .22914 .4107 L F
.89763 .41229 m .89947 .40976 L .90062 .41137 L 0 .025 .123 r
F
.89763 .41229 m .89648 .41068 L .89947 .40976 L F
.78942 .41348 m .79109 .4109 L .79235 .41248 L 0 .027 .126 r
F
.78942 .41348 m .78816 .4119 L .79109 .4109 L F
.85064 .4125 m .85239 .40986 L .8536 .41156 L 0 .025 .124 r
F
.85064 .4125 m .84943 .41078 L .85239 .40986 L F
.79653 .41311 m .79822 .41063 L .79948 .41224 L 0 .026 .126 r
F
.79653 .41311 m .79528 .41151 L .79822 .41063 L F
.73531 .4141 m .7369 .41144 L .73822 .41316 L 0 .028 .128 r
F
.73531 .4141 m .73399 .41236 L .7369 .41144 L F
.30093 .41415 m .30189 .41149 L .30361 .41329 L F
.30093 .41415 m .29921 .41237 L .30189 .41149 L F
.3337 .41476 m .3347 .41224 L .33639 .41398 L 0 .03 .13 r
F
.3337 .41476 m .332 .41305 L .3347 .41224 L F
.53183 .42305 m .53312 .42095 L .53463 .42246 L 0 .051 .154 r
F
.53183 .42305 m .53031 .42156 L .53312 .42095 L F
.44775 .42049 m .44892 .41793 L .45051 .41954 L 0 .043 .146 r
F
.44775 .42049 m .44615 .41889 L .44892 .41793 L F
.90476 .41202 m .9066 .40944 L .90775 .41107 L 0 .024 .123 r
F
.90476 .41202 m .90361 .41041 L .9066 .40944 L F
.35935 .41577 m .36038 .41343 L .36206 .41501 L 0 .033 .133 r
F
.35935 .41577 m .35767 .4142 L .36038 .41343 L F
.38501 .41677 m .38608 .41439 L .38773 .41601 L 0 .035 .136 r
F
.38501 .41677 m .38336 .41513 L .38608 .41439 L F
.85777 .41224 m .85953 .40961 L .86073 .41125 L 0 .025 .123 r
F
.85777 .41224 m .85657 .41059 L .85953 .40961 L F
.74244 .41387 m .74403 .41114 L .74534 .41284 L 0 .028 .127 r
F
.74244 .41387 m .74112 .41215 L .74403 .41114 L F
.26815 .41369 m .26907 .41099 L .27082 .41278 L F
.26815 .41369 m .2664 .4119 L .26907 .41099 L F
.61719 .41846 m .61862 .41621 L .62004 .41759 L 0 .039 .141 r
F
.61719 .41846 m .61577 .41714 L .61862 .41621 L F
.65276 .41649 m .65424 .41402 L .65562 .41554 L 0 .034 .135 r
F
.65276 .41649 m .65137 .41498 L .65424 .41402 L F
.74956 .41355 m .75117 .41104 L .75247 .41269 L 0 .028 .127 r
F
.74956 .41355 m .74825 .41188 L .75117 .41104 L F
.45486 .42026 m .45604 .41778 L .45762 .41946 L 0 .043 .145 r
F
.45486 .42026 m .45327 .4186 L .45604 .41778 L F
.8649 .412 m .86669 .40951 L .86787 .41113 L 0 .025 .123 r
F
.8649 .412 m .86371 .41038 L .86669 .40951 L F
.4734 .42168 m .4746 .41933 L .47617 .42101 L 0 .047 .15 r
F
.4734 .42168 m .47183 .42003 L .4746 .41933 L F
.49906 .42268 m .5003 .42088 L .50184 .42215 L 0 .051 .153 r
F
.49906 .42268 m .49751 .42137 L .5003 .42088 L F
.80368 .41305 m .80536 .41041 L .80661 .41209 L 0 .026 .126 r
F
.80368 .41305 m .80242 .41137 L .80536 .41041 L F
.65988 .41622 m .66136 .41373 L .66275 .41529 L 0 .034 .135 r
F
.65988 .41622 m .65849 .41464 L .66136 .41373 L F
.56028 .42176 m .56163 .4198 L .5631 .42098 L 0 .048 .151 r
F
.56028 .42176 m .5588 .42059 L .56163 .4198 L F
.62431 .41822 m .62575 .41586 L .62716 .41739 L 0 .039 .14 r
F
.62431 .41822 m .62289 .41671 L .62575 .41586 L F
.91191 .41191 m .91376 .40936 L .91491 .41106 L 0 .024 .123 r
F
.91191 .41191 m .91075 .41021 L .91376 .40936 L F
.41777 .41764 m .41889 .41507 L .42051 .41685 L 0 .037 .138 r
F
.41777 .41764 m .41615 .41585 L .41889 .41507 L F
.64565 .41707 m .64712 .41454 L .64851 .41603 L 0 .036 .137 r
F
.64565 .41707 m .64426 .41562 L .64712 .41454 L F
.30802 .41411 m .309 .41134 L .31071 .41314 L 0 .029 .128 r
F
.30802 .41411 m .30631 .41232 L .309 .41134 L F
.61008 .41906 m .6115 .41675 L .61293 .4181 L 0 .041 .143 r
F
.61008 .41906 m .60865 .41768 L .6115 .41675 L F
.60297 .41948 m .60438 .41724 L .60581 .41859 L 0 .042 .144 r
F
.60297 .41948 m .60153 .4181 L .60438 .41724 L F
.23536 .41338 m .23623 .41069 L .23801 .41241 L 0 .027 .127 r
F
.23536 .41338 m .23357 .41164 L .23623 .41069 L F
.67411 .41556 m .67562 .4131 L .67699 .41471 L 0 .032 .133 r
F
.67411 .41556 m .67274 .41395 L .67562 .4131 L F
.667 .41595 m .66849 .4133 L .66987 .41493 L 0 .033 .134 r
F
.667 .41595 m .66562 .4143 L .66849 .4133 L F
.75669 .41341 m .75832 .41094 L .75961 .4125 L 0 .028 .127 r
F
.75669 .41341 m .7554 .41184 L .75832 .41094 L F
.8108 .41283 m .81249 .41008 L .81374 .41182 L 0 .026 .125 r
F
.8108 .41283 m .80955 .41109 L .81249 .41008 L F
.59586 .41994 m .59725 .41756 L .59869 .41895 L 0 .043 .145 r
F
.59586 .41994 m .59441 .41857 L .59725 .41756 L F
.87204 .41186 m .87384 .40934 L .87501 .41094 L 0 .024 .123 r
F
.87204 .41186 m .87086 .41025 L .87384 .40934 L F
.27524 .41363 m .27617 .41094 L .27791 .4127 L 0 .028 .127 r
F
.27524 .41363 m .27349 .41186 L .27617 .41094 L F
.3921 .4168 m .39319 .41442 L .39483 .41598 L 0 .035 .137 r
F
.3921 .4168 m .39046 .41522 L .39319 .41442 L F
.43631 .41917 m .43745 .41687 L .43905 .41854 L 0 .041 .143 r
F
.43631 .41917 m .43471 .41747 L .43745 .41687 L F
.24246 .4131 m .24334 .4104 L .24513 .41209 L 0 .027 .126 r
F
.24246 .4131 m .24068 .41139 L .24334 .4104 L F
.51328 .42219 m .51455 .42004 L .51608 .42131 L 0 .049 .152 r
F
.51328 .42219 m .51175 .42088 L .51455 .42004 L F
.76381 .41312 m .76545 .41065 L .76673 .41218 L 0 .027 .127 r
F
.76381 .41312 m .76253 .41157 L .76545 .41065 L F
.5674 .42161 m .56875 .41958 L .57022 .42091 L 0 .048 .151 r
F
.5674 .42161 m .56593 .42028 L .56875 .41958 L F
.36644 .4159 m .36748 .41357 L .36915 .41519 L 0 .034 .134 r
F
.36644 .4159 m .36477 .41431 L .36748 .41357 L F
.31512 .41398 m .31609 .41153 L .3178 .4132 L 0 .029 .129 r
F
.31512 .41398 m .3134 .41232 L .31609 .41153 L F
.81793 .4126 m .81964 .40992 L .82088 .41165 L 0 .026 .125 r
F
.81793 .4126 m .81669 .41087 L .81964 .40992 L F
.34078 .41498 m .34179 .41246 L .34347 .41425 L 0 .031 .132 r
F
.34078 .41498 m .33909 .41321 L .34179 .41246 L F
.63143 .41814 m .63288 .41579 L .63429 .41734 L 0 .039 .141 r
F
.63143 .41814 m .63002 .41659 L .63288 .41579 L F
.68124 .41539 m .68276 .41302 L .68412 .41454 L 0 .032 .133 r
F
.68124 .41539 m .67988 .41387 L .68276 .41302 L F
.50617 .4227 m .50742 .42058 L .50896 .42179 L 0 .051 .154 r
F
.50617 .4227 m .50463 .42146 L .50742 .42058 L F
.48051 .42172 m .48172 .41938 L .48328 .4209 L 0 .048 .15 r
F
.48051 .42172 m .47894 .4202 L .48172 .41938 L F
.28234 .41344 m .28328 .41076 L .28502 .41246 L 0 .028 .127 r
F
.28234 .41344 m .28059 .41176 L .28328 .41076 L F
.91907 .41189 m .92091 .40919 L .92206 .4109 L 0 .025 .123 r
F
.91907 .41189 m .91792 .41017 L .92091 .40919 L F
.5204 .42198 m .52167 .41962 L .52319 .42115 L 0 .049 .151 r
F
.5204 .42198 m .51887 .42043 L .52167 .41962 L F
.63855 .41784 m .64 .41519 L .6414 .41673 L 0 .038 .139 r
F
.63855 .41784 m .63715 .4163 L .64 .41519 L F
.53894 .42337 m .54025 .42122 L .54175 .42278 L 0 .053 .155 r
F
.53894 .42337 m .53744 .42184 L .54025 .42122 L F
.55317 .42259 m .5545 .42038 L .55599 .42159 L 0 .051 .153 r
F
.55317 .42259 m .55168 .42135 L .5545 .42038 L F
.87918 .41174 m .88098 .40913 L .88216 .41084 L 0 .024 .123 r
F
.87918 .41174 m .878 .41003 L .88098 .40913 L F
.46196 .42042 m .46315 .41805 L .46472 .41973 L 0 .045 .147 r
F
.46196 .42042 m .46038 .41876 L .46315 .41805 L F
.77094 .41294 m .77259 .41037 L .77387 .41205 L 0 .027 .126 r
F
.77094 .41294 m .76966 .41128 L .77259 .41037 L F
.39921 .41669 m .4003 .4142 L .40194 .41575 L 0 .035 .137 r
F
.39921 .41669 m .39756 .41514 L .4003 .4142 L F
.82506 .41235 m .82679 .40977 L .82801 .41141 L 0 .026 .125 r
F
.82506 .41235 m .82383 .4107 L .82679 .40977 L F
.24956 .41295 m .25044 .41031 L .25221 .41208 L 0 .027 .126 r
F
.24956 .41295 m .24778 .4112 L .25044 .41031 L F
.68836 .41514 m .6899 .4128 L .69125 .41425 L 0 .032 .133 r
F
.68836 .41514 m .68701 .41368 L .6899 .4128 L F
.69548 .41476 m .69701 .41224 L .69836 .41378 L 0 .031 .131 r
F
.69548 .41476 m .69413 .41325 L .69701 .41224 L F
.28944 .41318 m .29039 .41047 L .29213 .41221 L 0 .027 .127 r
F
.28944 .41318 m .28771 .41147 L .29039 .41047 L F
.40632 .41634 m .40742 .41405 L .40905 .41559 L 0 .035 .136 r
F
.40632 .41634 m .40468 .41481 L .40742 .41405 L F
.58875 .4207 m .59013 .41825 L .59158 .41963 L 0 .045 .148 r
F
.58875 .4207 m .5873 .41934 L .59013 .41825 L F
.9262 .41162 m .92806 .40899 L .9292 .41069 L 0 .024 .123 r
F
.9262 .41162 m .92506 .40992 L .92806 .40899 L F
.83219 .41207 m .83392 .40946 L .83514 .41108 L 0 .025 .124 r
F
.83219 .41207 m .83097 .41046 L .83392 .40946 L F
.42486 .41783 m .426 .41535 L .42761 .4171 L 0 .038 .14 r
F
.42486 .41783 m .42325 .41606 L .426 .41535 L F
.83931 .41173 m .84105 .40911 L .84227 .41076 L 0 .025 .123 r
F
.83931 .41173 m .83809 .41009 L .84105 .40911 L F
.37354 .4159 m .3746 .41332 L .37626 .41499 L 0 .034 .135 r
F
.37354 .4159 m .37187 .41426 L .3746 .41332 L F
.21676 .41257 m .21761 .40983 L .21941 .4116 L 0 .026 .125 r
F
.21676 .41257 m .21496 .4108 L .21761 .40983 L F
.48762 .42166 m .48884 .41983 L .4904 .42113 L 0 .049 .152 r
F
.48762 .42166 m .48606 .42031 L .48884 .41983 L F
.57452 .42168 m .57588 .41947 L .57735 .42094 L 0 .049 .151 r
F
.57452 .42168 m .57305 .42019 L .57588 .41947 L F
.7026 .41458 m .70415 .412 L .7055 .41373 L 0 .031 .131 r
F
.7026 .41458 m .70125 .41286 L .70415 .412 L F
.93334 .41143 m .93523 .40888 L .93635 .41053 L 0 .024 .122 r
F
.93334 .41143 m .93221 .40978 L .93523 .40888 L F
.88633 .41165 m .88814 .40905 L .88932 .41075 L 0 .025 .123 r
F
.88633 .41165 m .88515 .40994 L .88814 .40905 L F
.32221 .41402 m .32319 .41147 L .3249 .41312 L 0 .03 .13 r
F
.32221 .41402 m .32049 .41239 L .32319 .41147 L F
.54606 .42333 m .54738 .42086 L .54887 .42234 L 0 .053 .155 r
F
.54606 .42333 m .54456 .42182 L .54738 .42086 L F
.77808 .4129 m .77974 .41034 L .78102 .41205 L 0 .027 .127 r
F
.77808 .4129 m .7768 .41118 L .77974 .41034 L F
.25664 .41295 m .25754 .4102 L .25931 .41199 L 0 .027 .126 r
F
.25664 .41295 m .25487 .41117 L .25754 .4102 L F
.29653 .41316 m .29748 .41059 L .29921 .41237 L 0 .028 .127 r
F
.29653 .41316 m .2948 .4114 L .29748 .41059 L F
.22385 .41241 m .22471 .40973 L .2265 .4115 L 0 .026 .125 r
F
.22385 .41241 m .22206 .41063 L .22471 .40973 L F
.58164 .42151 m .58301 .41893 L .58447 .42042 L 0 .048 .15 r
F
.58164 .42151 m .58018 .42003 L .58301 .41893 L F
.84646 .41165 m .84821 .40905 L .84943 .41078 L 0 .025 .123 r
F
.84646 .41165 m .84524 .40991 L .84821 .40905 L F
.72396 .41363 m .72554 .41104 L .72686 .41262 L 0 .029 .129 r
F
.72396 .41363 m .72264 .41206 L .72554 .41104 L F
.52751 .42212 m .5288 .42004 L .53031 .42156 L 0 .05 .153 r
F
.52751 .42212 m .526 .4206 L .5288 .42004 L F
.34786 .41522 m .34888 .41273 L .35056 .41443 L 0 .033 .133 r
F
.34786 .41522 m .34617 .41352 L .34888 .41273 L F
.4434 .41957 m .44456 .41729 L .44615 .41889 L 0 .043 .146 r
F
.4434 .41957 m .4418 .41794 L .44456 .41729 L F
.73108 .41327 m .73268 .41078 L .73399 .41236 L 0 .028 .128 r
F
.73108 .41327 m .72977 .41168 L .73268 .41078 L F
.38064 .41586 m .3817 .41342 L .38336 .41513 L 0 .034 .135 r
F
.38064 .41586 m .37898 .41417 L .3817 .41342 L F
.32931 .41388 m .3303 .41135 L .332 .41305 L 0 .03 .13 r
F
.32931 .41388 m .3276 .41222 L .3303 .41135 L F
.41342 .41649 m .41453 .4143 L .41615 .41585 L 0 .036 .138 r
F
.41342 .41649 m .41179 .41495 L .41453 .4143 L F
.89348 .41156 m .89531 .40902 L .89648 .41068 L 0 .025 .123 r
F
.89348 .41156 m .89231 .40989 L .89531 .40902 L F
.71686 .41413 m .71842 .41147 L .71975 .41308 L 0 .03 .13 r
F
.71686 .41413 m .71552 .41252 L .71842 .41147 L F
.46906 .42067 m .47026 .41838 L .47183 .42003 L 0 .046 .149 r
F
.46906 .42067 m .46749 .41905 L .47026 .41838 L F
.70974 .41458 m .71129 .41186 L .71263 .41357 L 0 .031 .131 r
F
.70974 .41458 m .7084 .41287 L .71129 .41186 L F
.26373 .41282 m .26465 .41011 L .2664 .4119 L 0 .027 .127 r
F
.26373 .41282 m .26198 .41103 L .26465 .41011 L F
.79235 .41248 m .79402 .40992 L .79528 .41151 L 0 .027 .126 r
F
.79235 .41248 m .79109 .4109 L .79402 .40992 L F
.78523 .4129 m .78689 .41022 L .78816 .4119 L 0 .028 .127 r
F
.78523 .4129 m .78396 .4112 L .78689 .41022 L F
.35496 .41511 m .35599 .41262 L .35767 .4142 L 0 .033 .133 r
F
.35496 .41511 m .35327 .41353 L .35599 .41262 L F
.8536 .41156 m .85536 .4089 L .85657 .41059 L 0 .025 .123 r
F
.8536 .41156 m .85239 .40986 L .85536 .4089 L F
.90062 .41137 m .90246 .40879 L .90361 .41041 L F
.90062 .41137 m .89947 .40976 L .90246 .40879 L F
.73822 .41316 m .73981 .41044 L .74112 .41215 L 0 .028 .128 r
F
.73822 .41316 m .7369 .41144 L .73981 .41044 L F
.49473 .42185 m .49596 .42011 L .49751 .42137 L 0 .051 .153 r
F
.49473 .42185 m .49318 .4206 L .49596 .42011 L F
.45051 .41954 m .45168 .41696 L .45327 .4186 L 0 .043 .145 r
F
.45051 .41954 m .44892 .41793 L .45168 .41696 L F
.79948 .41224 m .80117 .40975 L .80242 .41137 L 0 .027 .126 r
F
.79948 .41224 m .79822 .41063 L .80117 .40975 L F
.86073 .41125 m .86251 .40874 L .86371 .41038 L 0 .025 .123 r
F
.86073 .41125 m .85953 .40961 L .86251 .40874 L F
.43196 .41816 m .4331 .4158 L .43471 .41747 L 0 .04 .142 r
F
.43196 .41816 m .43035 .41645 L .4331 .4158 L F
.74534 .41284 m .74694 .41019 L .74825 .41188 L 0 .028 .127 r
F
.74534 .41284 m .74403 .41114 L .74694 .41019 L F
.90775 .41107 m .9096 .40857 L .91075 .41021 L 0 .024 .123 r
F
.90775 .41107 m .9066 .40944 L .9096 .40857 L F
.23093 .41246 m .23178 .4099 L .23357 .41164 L 0 .027 .126 r
F
.23093 .41246 m .22914 .4107 L .23178 .4099 L F
.30361 .41329 m .30459 .41052 L .30631 .41232 L 0 .028 .128 r
F
.30361 .41329 m .30189 .41149 L .30459 .41052 L F
.65562 .41554 m .65711 .41313 L .65849 .41464 L 0 .034 .135 r
F
.65562 .41554 m .65424 .41402 L .65711 .41313 L F
.27082 .41278 m .27174 .41008 L .27349 .41186 L 0 .028 .127 r
F
.27082 .41278 m .26907 .41099 L .27174 .41008 L F
.33639 .41398 m .3374 .41144 L .33909 .41321 L 0 .03 .131 r
F
.33639 .41398 m .3347 .41224 L .3374 .41144 L F
.36206 .41501 m .36309 .41271 L .36477 .41431 L 0 .033 .134 r
F
.36206 .41501 m .36038 .41343 L .36309 .41271 L F
.38773 .41601 m .38881 .41363 L .39046 .41522 L 0 .035 .137 r
F
.38773 .41601 m .38608 .41439 L .38881 .41363 L F
.62004 .41759 m .62147 .41529 L .62289 .41671 L 0 .039 .141 r
F
.62004 .41759 m .61862 .41621 L .62147 .41529 L F
.64851 .41603 m .64998 .41346 L .65137 .41498 L 0 .035 .136 r
F
.64851 .41603 m .64712 .41454 L .64998 .41346 L F
.80661 .41209 m .8083 .40941 L .80955 .41109 L 0 .026 .125 r
F
.80661 .41209 m .80536 .41041 L .8083 .40941 L F
.75247 .41269 m .7541 .4102 L .7554 .41184 L 0 .028 .127 r
F
.75247 .41269 m .75117 .41104 L .7541 .4102 L F
.86787 .41113 m .86967 .40863 L .87086 .41025 L 0 .025 .123 r
F
.86787 .41113 m .86669 .40951 L .86967 .40863 L F
.66275 .41529 m .66424 .41275 L .66562 .4143 L 0 .033 .134 r
F
.66275 .41529 m .66136 .41373 L .66424 .41275 L F
.31071 .41314 m .31169 .41053 L .3134 .41232 L 0 .029 .128 r
F
.31071 .41314 m .309 .41134 L .31169 .41053 L F
.45762 .41946 m .4588 .41707 L .46038 .41876 L 0 .044 .146 r
F
.45762 .41946 m .45604 .41778 L .4588 .41707 L F
.66987 .41493 m .67136 .41235 L .67274 .41395 L 0 .033 .133 r
F
.66987 .41493 m .66849 .4133 L .67136 .41235 L F
.61293 .4181 m .61435 .41582 L .61577 .41714 L 0 .041 .143 r
F
.61293 .4181 m .6115 .41675 L .61435 .41582 L F
.53463 .42246 m .53593 .42031 L .53744 .42184 L 0 .052 .155 r
F
.53463 .42246 m .53312 .42095 L .53593 .42031 L F
.81374 .41182 m .81544 .40913 L .81669 .41087 L 0 .026 .125 r
F
.81374 .41182 m .81249 .41008 L .81544 .40913 L F
.23801 .41241 m .23889 .40969 L .24068 .41139 L 0 .027 .126 r
F
.23801 .41241 m .23623 .41069 L .23889 .40969 L F
.59869 .41895 m .60009 .41673 L .60153 .4181 L 0 .043 .145 r
F
.59869 .41895 m .59725 .41756 L .60009 .41673 L F
.91491 .41106 m .91677 .40847 L .91792 .41017 L 0 .025 .123 r
F
.91491 .41106 m .91376 .40936 L .91677 .40847 L F
.62716 .41739 m .62861 .41504 L .63002 .41659 L 0 .039 .141 r
F
.62716 .41739 m .62575 .41586 L .62861 .41504 L F
.60581 .41859 m .60722 .41636 L .60865 .41768 L 0 .042 .144 r
F
.60581 .41859 m .60438 .41724 L .60722 .41636 L F
.24513 .41209 m .246 .40951 L .24778 .4112 L 0 .027 .126 r
F
.24513 .41209 m .24334 .4104 L .246 .40951 L F
.5631 .42098 m .56445 .4191 L .56593 .42028 L 0 .049 .152 r
F
.5631 .42098 m .56163 .4198 L .56445 .4191 L F
.27791 .4127 m .27885 .41002 L .28059 .41176 L 0 .028 .127 r
F
.27791 .4127 m .27617 .41094 L .27885 .41002 L F
.75961 .4125 m .76124 .41003 L .76253 .41157 L F
.75961 .4125 m .75832 .41094 L .76124 .41003 L F
.42051 .41685 m .42164 .41429 L .42325 .41606 L 0 .037 .139 r
F
.42051 .41685 m .41889 .41507 L .42164 .41429 L F
.47617 .42101 m .47738 .41851 L .47894 .4202 L 0 .048 .15 r
F
.47617 .42101 m .4746 .41933 L .47738 .41851 L F
.87501 .41094 m .87682 .40843 L .878 .41003 L 0 .024 .123 r
F
.87501 .41094 m .87384 .40934 L .87682 .40843 L F
.67699 .41471 m .67851 .41225 L .67988 .41387 L 0 .033 .133 r
F
.67699 .41471 m .67562 .4131 L .67851 .41225 L F
.76673 .41218 m .76838 .40972 L .76966 .41128 L 0 .027 .126 r
F
.76673 .41218 m .76545 .41065 L .76838 .40972 L F
.6414 .41673 m .64286 .41409 L .64426 .41562 L 0 .037 .138 r
F
.6414 .41673 m .64 .41519 L .64286 .41409 L F
.51608 .42131 m .51735 .41921 L .51887 .42043 L 0 .05 .152 r
F
.51608 .42131 m .51455 .42004 L .51735 .41921 L F
.39483 .41598 m .39592 .41359 L .39756 .41514 L 0 .036 .137 r
F
.39483 .41598 m .39319 .41442 L .39592 .41359 L F
.82088 .41165 m .82259 .40898 L .82383 .4107 L 0 .026 .125 r
F
.82088 .41165 m .81964 .40992 L .82259 .40898 L F
.28502 .41246 m .28597 .40974 L .28771 .41147 L 0 .027 .127 r
F
.28502 .41246 m .28328 .41076 L .28597 .40974 L F
.50184 .42215 m .50309 .42023 L .50463 .42146 L 0 .052 .155 r
F
.50184 .42215 m .5003 .42088 L .50309 .42023 L F
.92206 .4109 m .92391 .40821 L .92506 .40992 L 0 .024 .123 r
F
.92206 .4109 m .92091 .40919 L .92391 .40821 L F
.55599 .42159 m .55732 .41941 L .5588 .42059 L 0 .05 .153 r
F
.55599 .42159 m .5545 .42038 L .55732 .41941 L F
.50896 .42179 m .51022 .41969 L .51175 .42088 L 0 .051 .154 r
F
.50896 .42179 m .50742 .42058 L .51022 .41969 L F
.59158 .41963 m .59296 .41716 L .59441 .41857 L 0 .045 .147 r
F
.59158 .41963 m .59013 .41825 L .59296 .41716 L F
.68412 .41454 m .68565 .41218 L .68701 .41368 L 0 .033 .133 r
F
.68412 .41454 m .68276 .41302 L .68565 .41218 L F
.82801 .41141 m .82974 .40883 L .83097 .41046 L 0 .026 .124 r
F
.82801 .41141 m .82679 .40977 L .82974 .40883 L F
.40194 .41575 m .40305 .41327 L .40468 .41481 L 0 .035 .136 r
F
.40194 .41575 m .4003 .4142 L .40305 .41327 L F
.69836 .41378 m .69991 .41129 L .70125 .41286 L 0 .031 .131 r
F
.69836 .41378 m .69701 .41224 L .69991 .41129 L F
.63429 .41734 m .63574 .41475 L .63715 .4163 L 0 .039 .141 r
F
.63429 .41734 m .63288 .41579 L .63574 .41475 L F
.3178 .4132 m .31878 .41072 L .32049 .41239 L 0 .03 .13 r
F
.3178 .4132 m .31609 .41153 L .31878 .41072 L F
.29213 .41221 m .29307 .40964 L .2948 .4114 L 0 .027 .127 r
F
.29213 .41221 m .29039 .41047 L .29307 .40964 L F
.48328 .4209 m .4845 .41881 L .48606 .42031 L 0 .049 .151 r
F
.48328 .4209 m .48172 .41938 L .4845 .41881 L F
.88216 .41084 m .88397 .40823 L .88515 .40994 L 0 .024 .123 r
F
.88216 .41084 m .88098 .40913 L .88397 .40823 L F
.57022 .42091 m .57158 .41885 L .57305 .42019 L 0 .049 .151 r
F
.57022 .42091 m .56875 .41958 L .57158 .41885 L F
.43905 .41854 m .4402 .41631 L .4418 .41794 L 0 .042 .145 r
F
.43905 .41854 m .43745 .41687 L .4402 .41631 L F
.36915 .41519 m .37021 .41261 L .37187 .41426 L 0 .034 .135 r
F
.36915 .41519 m .36748 .41357 L .37021 .41261 L F
.77387 .41205 m .77552 .4095 L .7768 .41118 L 0 .027 .126 r
F
.77387 .41205 m .77259 .41037 L .77552 .4095 L F
.9292 .41069 m .93108 .40809 L .93221 .40978 L 0 .024 .123 r
F
.9292 .41069 m .92806 .40899 L .93108 .40809 L F
.83514 .41108 m .83688 .40846 L .83809 .41009 L 0 .025 .124 r
F
.83514 .41108 m .83392 .40946 L .83688 .40846 L F
.52319 .42115 m .52448 .41907 L .526 .4206 L 0 .05 .152 r
F
.52319 .42115 m .52167 .41962 L .52448 .41907 L F
.34347 .41425 m .34449 .41172 L .34617 .41352 L 0 .032 .132 r
F
.34347 .41425 m .34179 .41246 L .34449 .41172 L F
.69125 .41425 m .69278 .41176 L .69413 .41325 L 0 .032 .133 r
F
.69125 .41425 m .6899 .4128 L .69278 .41176 L F
.25221 .41208 m .25311 .40938 L .25487 .41117 L 0 .027 .126 r
F
.25221 .41208 m .25044 .41031 L .25311 .40938 L F
.84227 .41076 m .84402 .40826 L .84524 .40991 L 0 .025 .123 r
F
.84227 .41076 m .84105 .40911 L .84402 .40826 L F
.21941 .4116 m .22026 .40885 L .22206 .41063 L 0 .026 .125 r
F
.21941 .4116 m .21761 .40983 L .22026 .40885 L F
.46472 .41973 m .46592 .41736 L .46749 .41905 L 0 .045 .148 r
F
.46472 .41973 m .46315 .41805 L .46592 .41736 L F
.37626 .41499 m .37733 .41247 L .37898 .41417 L 0 .034 .135 r
F
.37626 .41499 m .3746 .41332 L .37733 .41247 L F
.40905 .41559 m .41016 .41341 L .41179 .41495 L 0 .036 .137 r
F
.40905 .41559 m .40742 .41405 L .41016 .41341 L F
.54887 .42234 m .55019 .41991 L .55168 .42135 L 0 .052 .155 r
F
.54887 .42234 m .54738 .42086 L .55019 .41991 L F
.54175 .42278 m .54306 .42029 L .54456 .42182 L 0 .054 .156 r
F
.54175 .42278 m .54025 .42122 L .54306 .42029 L F
.58447 .42042 m .58584 .41783 L .5873 .41934 L 0 .047 .149 r
F
.58447 .42042 m .58301 .41893 L .58584 .41783 L F
.3249 .41312 m .32589 .41055 L .3276 .41222 L 0 .03 .13 r
F
.3249 .41312 m .32319 .41147 L .32589 .41055 L F
.88932 .41075 m .89114 .40819 L .89231 .40989 L 0 .025 .123 r
F
.88932 .41075 m .88814 .40905 L .89114 .40819 L F
.7055 .41373 m .70705 .41114 L .7084 .41287 L 0 .031 .131 r
F
.7055 .41373 m .70415 .412 L .70705 .41114 L F
.42761 .4171 m .42874 .41476 L .43035 .41645 L 0 .039 .141 r
F
.42761 .4171 m .426 .41535 L .42874 .41476 L F
.25931 .41199 m .26022 .40924 L .26198 .41103 L 0 .027 .126 r
F
.25931 .41199 m .25754 .4102 L .26022 .40924 L F
.72686 .41262 m .72845 .41009 L .72977 .41168 L 0 .029 .129 r
F
.72686 .41262 m .72554 .41104 L .72845 .41009 L F
.78102 .41205 m .78268 .40949 L .78396 .4112 L 0 .027 .127 r
F
.78102 .41205 m .77974 .41034 L .78268 .40949 L F
.57735 .42094 m .57872 .41855 L .58018 .42003 L 0 .049 .151 r
F
.57735 .42094 m .57588 .41947 L .57872 .41855 L F
.71975 .41308 m .72131 .41044 L .72264 .41206 L 0 .03 .13 r
F
.71975 .41308 m .71842 .41147 L .72131 .41044 L F
.2265 .4115 m .22735 .40893 L .22914 .4107 L 0 .026 .125 r
F
.2265 .4115 m .22471 .40973 L .22735 .40893 L F
.73399 .41236 m .73559 .40987 L .7369 .41144 L 0 .028 .128 r
F
.73399 .41236 m .73268 .41078 L .73559 .40987 L F
.84943 .41078 m .85118 .40814 L .85239 .40986 L 0 .025 .123 r
F
.84943 .41078 m .84821 .40905 L .85118 .40814 L F
.29921 .41237 m .30017 .4097 L .30189 .41149 L 0 .028 .128 r
F
.29921 .41237 m .29748 .41059 L .30017 .4097 L F
.71263 .41357 m .71418 .41083 L .71552 .41252 L 0 .031 .131 r
F
.71263 .41357 m .71129 .41186 L .71418 .41083 L F
.4904 .42113 m .49162 .41934 L .49318 .4206 L 0 .051 .154 r
F
.4904 .42113 m .48884 .41983 L .49162 .41934 L F
.332 .41305 m .333 .41051 L .3347 .41224 L 0 .03 .13 r
F
.332 .41305 m .3303 .41135 L .333 .41051 L F
.35056 .41443 m .35159 .41183 L .35327 .41353 L 0 .033 .134 r
F
.35056 .41443 m .34888 .41273 L .35159 .41183 L F
.89648 .41068 m .89831 .40811 L .89947 .40976 L 0 .025 .123 r
F
.89648 .41068 m .89531 .40902 L .89831 .40811 L F
.2664 .4119 m .26732 .4092 L .26907 .41099 L 0 .027 .127 r
F
.2664 .4119 m .26465 .41011 L .26732 .4092 L F
.78816 .4119 m .78982 .40921 L .79109 .4109 L F
.78816 .4119 m .78689 .41022 L .78982 .40921 L F
.79528 .41151 m .79697 .40902 L .79822 .41063 L 0 .027 .126 r
F
.79528 .41151 m .79402 .40992 L .79697 .40902 L F
.74112 .41215 m .74272 .40944 L .74403 .41114 L 0 .028 .127 r
F
.74112 .41215 m .73981 .41044 L .74272 .40944 L F
.38336 .41513 m .38443 .41268 L .38608 .41439 L 0 .035 .136 r
F
.38336 .41513 m .3817 .41342 L .38443 .41268 L F
.85657 .41059 m .85833 .40794 L .85953 .40961 L 0 .025 .123 r
F
.85657 .41059 m .85536 .4089 L .85833 .40794 L F
.44615 .41889 m .44732 .41638 L .44892 .41793 L 0 .044 .146 r
F
.44615 .41889 m .44456 .41729 L .44732 .41638 L F
.90361 .41041 m .90545 .40782 L .9066 .40944 L 0 .024 .123 r
F
.90361 .41041 m .90246 .40879 L .90545 .40782 L F
.35767 .4142 m .3587 .41184 L .36038 .41343 L 0 .033 .134 r
F
.35767 .4142 m .35599 .41262 L .3587 .41184 L F
.53031 .42156 m .53161 .41942 L .53312 .42095 L 0 .052 .154 r
F
.53031 .42156 m .5288 .42004 L .53161 .41942 L F
.74825 .41188 m .74987 .40935 L .75117 .41104 L 0 .028 .127 r
F
.74825 .41188 m .74694 .41019 L .74987 .40935 L F
.45327 .4186 m .45445 .41614 L .45604 .41778 L 0 .043 .146 r
F
.45327 .4186 m .45168 .41696 L .45445 .41614 L F
.41615 .41585 m .41727 .4135 L .41889 .41507 L 0 .037 .138 r
F
.41615 .41585 m .41453 .4143 L .41727 .4135 L F
.30631 .41232 m .30728 .40955 L .309 .41134 L 0 .028 .128 r
F
.30631 .41232 m .30459 .41052 L .30728 .40955 L F
.47183 .42003 m .47304 .41765 L .4746 .41933 L 0 .047 .15 r
F
.47183 .42003 m .47026 .41838 L .47304 .41765 L F
.86371 .41038 m .8655 .40787 L .86669 .40951 L 0 .025 .123 r
F
.86371 .41038 m .86251 .40874 L .8655 .40787 L F
.80242 .41137 m .80411 .40878 L .80536 .41041 L 0 .027 .126 r
F
.80242 .41137 m .80117 .40975 L .80411 .40878 L F
.91075 .41021 m .91261 .40771 L .91376 .40936 L 0 .024 .123 r
F
.91075 .41021 m .9096 .40857 L .91261 .40771 L F
.65137 .41498 m .65285 .4125 L .65424 .41402 L 0 .035 .136 r
F
.65137 .41498 m .64998 .41346 L .65285 .4125 L F
.23357 .41164 m .23444 .40896 L .23623 .41069 L 0 .027 .126 r
F
.23357 .41164 m .23178 .4099 L .23444 .40896 L F
.27349 .41186 m .27442 .40919 L .27617 .41094 L 0 .028 .127 r
F
.27349 .41186 m .27174 .41008 L .27442 .40919 L F
.65849 .41464 m .65998 .41224 L .66136 .41373 L 0 .034 .135 r
F
.65849 .41464 m .65711 .41313 L .65998 .41224 L F
.80955 .41109 m .81125 .40841 L .81249 .41008 L 0 .026 .125 r
F
.80955 .41109 m .8083 .40941 L .81125 .40841 L F
.66562 .4143 m .66711 .41177 L .66849 .4133 L 0 .033 .134 r
F
.66562 .4143 m .66424 .41275 L .66711 .41177 L F
.43471 .41747 m .43585 .41524 L .43745 .41687 L 0 .041 .143 r
F
.43471 .41747 m .4331 .4158 L .43585 .41524 L F
.62289 .41671 m .62433 .41438 L .62575 .41586 L 0 .039 .141 r
F
.62289 .41671 m .62147 .41529 L .62433 .41438 L F
.67274 .41395 m .67425 .41149 L .67562 .4131 L 0 .033 .133 r
F
.67274 .41395 m .67136 .41235 L .67425 .41149 L F
.24068 .41139 m .24156 .4087 L .24334 .4104 L 0 .027 .126 r
F
.24068 .41139 m .23889 .40969 L .24156 .4087 L F
.61577 .41714 m .6172 .41484 L .61862 .41621 L 0 .041 .143 r
F
.61577 .41714 m .61435 .41582 L .6172 .41484 L F
.33909 .41321 m .3401 .41068 L .34179 .41246 L 0 .031 .131 r
F
.33909 .41321 m .3374 .41144 L .3401 .41068 L F
.87086 .41025 m .87266 .40773 L .87384 .40934 L 0 .025 .123 r
F
.87086 .41025 m .86967 .40863 L .87266 .40773 L F
.7554 .41184 m .75703 .40932 L .75832 .41094 L 0 .028 .128 r
F
.7554 .41184 m .7541 .4102 L .75703 .40932 L F
.81669 .41087 m .81839 .40819 L .81964 .40992 L 0 .026 .125 r
F
.81669 .41087 m .81544 .40913 L .81839 .40819 L F
.39046 .41522 m .39154 .41285 L .39319 .41442 L 0 .036 .137 r
F
.39046 .41522 m .38881 .41363 L .39154 .41285 L F
.64426 .41562 m .64572 .413 L .64712 .41454 L 0 .036 .138 r
F
.64426 .41562 m .64286 .41409 L .64572 .413 L F
.49751 .42137 m .49875 .41962 L .5003 .42088 L 0 .053 .155 r
F
.49751 .42137 m .49596 .42011 L .49875 .41962 L F
.3134 .41232 m .31438 .40975 L .31609 .41153 L 0 .029 .129 r
F
.3134 .41232 m .31169 .41053 L .31438 .40975 L F
.36477 .41431 m .36581 .41196 L .36748 .41357 L 0 .034 .135 r
F
.36477 .41431 m .36309 .41271 L .36581 .41196 L F
.91792 .41017 m .91977 .40749 L .92091 .40919 L 0 .024 .123 r
F
.91792 .41017 m .91677 .40847 L .91977 .40749 L F
.28059 .41176 m .28153 .40905 L .28328 .41076 L 0 .028 .127 r
F
.28059 .41176 m .27885 .41002 L .28153 .40905 L F
.60865 .41768 m .61007 .41546 L .6115 .41675 L 0 .042 .144 r
F
.60865 .41768 m .60722 .41636 L .61007 .41546 L F
.76253 .41157 m .76417 .4091 L .76545 .41065 L 0 .028 .127 r
F
.76253 .41157 m .76124 .41003 L .76417 .4091 L F
.60153 .4181 m .60294 .41591 L .60438 .41724 L 0 .043 .146 r
F
.60153 .4181 m .60009 .41673 L .60294 .41591 L F
.24778 .4112 m .24866 .40863 L .25044 .41031 L 0 .027 .126 r
F
.24778 .4112 m .246 .40951 L .24866 .40863 L F
.878 .41003 m .87981 .40752 L .88098 .40913 L 0 .025 .123 r
F
.878 .41003 m .87682 .40843 L .87981 .40752 L F
.46038 .41876 m .46157 .41636 L .46315 .41805 L 0 .045 .147 r
F
.46038 .41876 m .4588 .41707 L .46157 .41636 L F
.63002 .41659 m .63147 .41422 L .63288 .41579 L 0 .039 .141 r
F
.63002 .41659 m .62861 .41504 L .63147 .41422 L F
.59441 .41857 m .5958 .41614 L .59725 .41756 L 0 .044 .146 r
F
.59441 .41857 m .59296 .41716 L .5958 .41614 L F
.28771 .41147 m .28866 .40873 L .29039 .41047 L 0 .027 .126 r
F
.28771 .41147 m .28597 .40974 L .28866 .40873 L F
.76966 .41128 m .77131 .40879 L .77259 .41037 L 0 .027 .127 r
F
.76966 .41128 m .76838 .40972 L .77131 .40879 L F
.82383 .4107 m .82555 .40806 L .82679 .40977 L 0 .026 .125 r
F
.82383 .4107 m .82259 .40898 L .82555 .40806 L F
.67988 .41387 m .6814 .41142 L .68276 .41302 L 0 .033 .134 r
F
.67988 .41387 m .67851 .41225 L .6814 .41142 L F
.92506 .40992 m .92692 .40728 L .92806 .40899 L 0 .024 .122 r
F
.92506 .40992 m .92391 .40821 L .92692 .40728 L F
.5588 .42059 m .56015 .41863 L .56163 .4198 L 0 .05 .153 r
F
.5588 .42059 m .55732 .41941 L .56015 .41863 L F
.47894 .4202 m .48016 .41768 L .48172 .41938 L 0 .048 .151 r
F
.47894 .4202 m .47738 .41851 L .48016 .41768 L F
.42325 .41606 m .42439 .4136 L .426 .41535 L 0 .038 .14 r
F
.42325 .41606 m .42164 .41429 L .42439 .4136 L F
.51887 .42043 m .52015 .41844 L .52167 .41962 L 0 .05 .153 r
F
.51887 .42043 m .51735 .41921 L .52015 .41844 L F
.63715 .4163 m .63859 .41365 L .64 .41519 L 0 .038 .14 r
F
.63715 .4163 m .63574 .41475 L .63859 .41365 L F
.53744 .42184 m .53874 .41966 L .54025 .42122 L 0 .054 .156 r
F
.53744 .42184 m .53593 .42031 L .53874 .41966 L F
.39756 .41514 m .39866 .41266 L .4003 .4142 L 0 .036 .137 r
F
.39756 .41514 m .39592 .41359 L .39866 .41266 L F
.56593 .42028 m .56728 .41839 L .56875 .41958 L 0 .05 .152 r
F
.56593 .42028 m .56445 .4191 L .56728 .41839 L F
.51175 .42088 m .51302 .4189 L .51455 .42004 L 0 .051 .154 r
F
.51175 .42088 m .51022 .41969 L .51302 .4189 L F
.21496 .4108 m .2158 .40813 L .21761 .40983 L 0 .026 .125 r
F
.21496 .4108 m .21315 .40911 L .2158 .40813 L F
.83097 .41046 m .8327 .40783 L .83392 .40946 L 0 .025 .124 r
F
.83097 .41046 m .82974 .40883 L .8327 .40783 L F
.40468 .41481 m .40578 .41251 L .40742 .41405 L 0 .035 .137 r
F
.40468 .41481 m .40305 .41327 L .40578 .41251 L F
.83809 .41009 m .83984 .40748 L .84105 .40911 L 0 .025 .123 r
F
.83809 .41009 m .83688 .40846 L .83984 .40748 L F
.69413 .41325 m .69567 .41072 L .69701 .41224 L 0 .032 .132 r
F
.69413 .41325 m .69278 .41176 L .69567 .41072 L F
.70125 .41286 m .7028 .4104 L .70415 .412 L 0 .031 .131 r
F
.70125 .41286 m .69991 .41129 L .7028 .4104 L F
.37187 .41426 m .37294 .41165 L .3746 .41332 L 0 .034 .135 r
F
.37187 .41426 m .37021 .41261 L .37294 .41165 L F
.68701 .41368 m .68854 .41132 L .6899 .4128 L 0 .033 .134 r
F
.68701 .41368 m .68565 .41218 L .68854 .41132 L F
.88515 .40994 m .88696 .40734 L .88814 .40905 L 0 .025 .123 r
F
.88515 .40994 m .88397 .40823 L .88696 .40734 L F
.25487 .41117 m .25578 .40841 L .25754 .4102 L 0 .027 .126 r
F
.25487 .41117 m .25311 .40938 L .25578 .40841 L F
.93221 .40978 m .93409 .40719 L .93523 .40888 L 0 .024 .123 r
F
.93221 .40978 m .93108 .40809 L .93409 .40719 L F
.7768 .41118 m .77846 .40866 L .77974 .41034 L 0 .027 .127 r
F
.7768 .41118 m .77552 .4095 L .77846 .40866 L F
.50463 .42146 m .50588 .41936 L .50742 .42058 L 0 .053 .155 r
F
.50463 .42146 m .50309 .42023 L .50588 .41936 L F
.32049 .41239 m .32148 .40979 L .32319 .41147 L 0 .03 .13 r
F
.32049 .41239 m .31878 .41072 L .32148 .40979 L F
.2948 .4114 m .29575 .40881 L .29748 .41059 L 0 .028 .127 r
F
.2948 .4114 m .29307 .40964 L .29575 .40881 L F
.22206 .41063 m .22291 .40795 L .22471 .40973 L 0 .026 .125 r
F
.22206 .41063 m .22026 .40885 L .22291 .40795 L F
.5873 .41934 m .58867 .41672 L .59013 .41825 L 0 .046 .149 r
F
.5873 .41934 m .58584 .41783 L .58867 .41672 L F
.55168 .42135 m .55301 .41898 L .5545 .42038 L 0 .052 .155 r
F
.55168 .42135 m .55019 .41991 L .55301 .41898 L F
.84524 .40991 m .847 .4074 L .84821 .40905 L 0 .025 .123 r
F
.84524 .40991 m .84402 .40826 L .847 .4074 L F
.57305 .42019 m .57442 .41812 L .57588 .41947 L 0 .05 .152 r
F
.57305 .42019 m .57158 .41885 L .57442 .41812 L F
.34617 .41352 m .3472 .41092 L .34888 .41273 L 0 .032 .133 r
F
.34617 .41352 m .34449 .41172 L .3472 .41092 L F
.54456 .42182 m .54588 .41936 L .54738 .42086 L 0 .053 .156 r
F
.54456 .42182 m .54306 .42029 L .54588 .41936 L F
.37898 .41417 m .38005 .4117 L .3817 .41342 L 0 .034 .135 r
F
.37898 .41417 m .37733 .41247 L .38005 .4117 L F
.4418 .41794 m .44296 .41569 L .44456 .41729 L 0 .044 .146 r
F
.4418 .41794 m .4402 .41631 L .44296 .41569 L F
.26198 .41103 m .26289 .40832 L .26465 .41011 L 0 .027 .126 r
F
.26198 .41103 m .26022 .40924 L .26289 .40832 L F
.48606 .42031 m .48728 .41836 L .48884 .41983 L 0 .05 .153 r
F
.48606 .42031 m .4845 .41881 L .48728 .41836 L F
.3276 .41222 m .3286 .40966 L .3303 .41135 L 0 .03 .13 r
F
.3276 .41222 m .32589 .41055 L .3286 .40966 L F
.72264 .41206 m .72421 .40941 L .72554 .41104 L 0 .029 .129 r
F
.72264 .41206 m .72131 .41044 L .72421 .40941 L F
.89231 .40989 m .89414 .40733 L .89531 .40902 L 0 .025 .123 r
F
.89231 .40989 m .89114 .40819 L .89414 .40733 L F
.72977 .41168 m .73136 .4092 L .73268 .41078 L 0 .029 .128 r
F
.72977 .41168 m .72845 .41009 L .73136 .4092 L F
.7084 .41287 m .70994 .41016 L .71129 .41186 L 0 .031 .131 r
F
.7084 .41287 m .70705 .41114 L .70994 .41016 L F
.526 .4206 m .52728 .41852 L .5288 .42004 L 0 .051 .154 r
F
.526 .4206 m .52448 .41907 L .52728 .41852 L F
.71552 .41252 m .71708 .4098 L .71842 .41147 L 0 .03 .13 r
F
.71552 .41252 m .71418 .41083 L .71708 .4098 L F
.58018 .42003 m .58155 .41743 L .58301 .41893 L 0 .049 .151 r
F
.58018 .42003 m .57872 .41855 L .58155 .41743 L F
.46749 .41905 m .46869 .41667 L .47026 .41838 L 0 .046 .149 r
F
.46749 .41905 m .46592 .41736 L .46869 .41667 L F
.41179 .41495 m .4129 .41276 L .41453 .4143 L 0 .037 .138 r
F
.41179 .41495 m .41016 .41341 L .4129 .41276 L F
.78396 .4112 m .78562 .40852 L .78689 .41022 L 0 .028 .127 r
F
.78396 .4112 m .78268 .40949 L .78562 .40852 L F
.85239 .40986 m .85415 .4072 L .85536 .4089 L 0 .025 .123 r
F
.85239 .40986 m .85118 .40814 L .85415 .4072 L F
.7369 .41144 m .7385 .40888 L .73981 .41044 L 0 .028 .128 r
F
.7369 .41144 m .73559 .40987 L .7385 .40888 L F
.79109 .4109 m .79276 .40824 L .79402 .40992 L 0 .027 .126 r
F
.79109 .4109 m .78982 .40921 L .79276 .40824 L F
.22914 .4107 m .22999 .40813 L .23178 .4099 L F
.22914 .4107 m .22735 .40893 L .22999 .40813 L F
.30189 .41149 m .30287 .40873 L .30459 .41052 L 0 .028 .128 r
F
.30189 .41149 m .30017 .4097 L .30287 .40873 L F
.43035 .41645 m .43149 .41416 L .4331 .4158 L 0 .04 .142 r
F
.43035 .41645 m .42874 .41476 L .43149 .41416 L F
.74403 .41114 m .74563 .4085 L .74694 .41019 L 0 .028 .127 r
F
.74403 .41114 m .74272 .40944 L .74563 .4085 L F
.89947 .40976 m .9013 .40713 L .90246 .40879 L 0 .025 .123 r
F
.89947 .40976 m .89831 .40811 L .9013 .40713 L F
.35327 .41353 m .35431 .41092 L .35599 .41262 L 0 .033 .134 r
F
.35327 .41353 m .35159 .41183 L .35431 .41092 L F
.26907 .41099 m .26999 .4083 L .27174 .41008 L 0 .027 .127 r
F
.26907 .41099 m .26732 .4092 L .26999 .4083 L F
.85953 .40961 m .86131 .40707 L .86251 .40874 L 0 .025 .123 r
F
.85953 .40961 m .85833 .40794 L .86131 .40707 L F
.44892 .41793 m .45009 .41546 L .45168 .41696 L 0 .044 .146 r
F
.44892 .41793 m .44732 .41638 L .45009 .41546 L F
.9066 .40944 m .90845 .40693 L .9096 .40857 L 0 .024 .123 r
F
.9066 .40944 m .90545 .40782 L .90845 .40693 L F
.79822 .41063 m .79992 .40812 L .80117 .40975 L 0 .027 .126 r
F
.79822 .41063 m .79697 .40902 L .79992 .40812 L F
.3347 .41224 m .33571 .40967 L .3374 .41144 L 0 .03 .13 r
F
.3347 .41224 m .333 .41051 L .33571 .40967 L F
.309 .41134 m .30997 .40874 L .31169 .41053 L 0 .028 .128 r
F
.309 .41134 m .30728 .40955 L .30997 .40874 L F
.80536 .41041 m .80706 .40778 L .8083 .40941 L 0 .026 .126 r
F
.80536 .41041 m .80411 .40878 L .80706 .40778 L F
.38608 .41439 m .38716 .4119 L .38881 .41363 L 0 .035 .137 r
F
.38608 .41439 m .38443 .41268 L .38716 .4119 L F
.75117 .41104 m .7528 .40852 L .7541 .4102 L 0 .028 .128 r
F
.75117 .41104 m .74987 .40935 L .7528 .40852 L F
.36038 .41343 m .36142 .4111 L .36309 .41271 L 0 .034 .134 r
F
.36038 .41343 m .3587 .41184 L .36142 .4111 L F
.65424 .41402 m .65572 .41162 L .65711 .41313 L 0 .035 .136 r
F
.65424 .41402 m .65285 .4125 L .65572 .41162 L F
.45604 .41778 m .45722 .41544 L .4588 .41707 L 0 .044 .146 r
F
.45604 .41778 m .45445 .41614 L .45722 .41544 L F
.81249 .41008 m .8142 .40745 L .81544 .40913 L 0 .026 .125 r
F
.81249 .41008 m .81125 .40841 L .8142 .40745 L F
.23623 .41069 m .2371 .40797 L .23889 .40969 L 0 .027 .126 r
F
.23623 .41069 m .23444 .40896 L .2371 .40797 L F
.86669 .40951 m .86848 .407 L .86967 .40863 L 0 .025 .123 r
F
.86669 .40951 m .8655 .40787 L .86848 .407 L F
.49318 .4206 m .49441 .41885 L .49596 .42011 L 0 .053 .155 r
F
.49318 .4206 m .49162 .41934 L .49441 .41885 L F
.41889 .41507 m .42002 .4127 L .42164 .41429 L 0 .037 .139 r
F
.41889 .41507 m .41727 .4135 L .42002 .4127 L F
.66849 .4133 m .66999 .41082 L .67136 .41235 L 0 .033 .134 r
F
.66849 .4133 m .66711 .41177 L .66999 .41082 L F
.91376 .40936 m .91562 .40681 L .91677 .40847 L 0 .025 .123 r
F
.91376 .40936 m .91261 .40771 L .91562 .40681 L F
.27617 .41094 m .2771 .40829 L .27885 .41002 L 0 .028 .127 r
F
.27617 .41094 m .27442 .40919 L .2771 .40829 L F
.66136 .41373 m .66286 .41127 L .66424 .41275 L 0 .034 .135 r
F
.66136 .41373 m .65998 .41224 L .66286 .41127 L F
.64712 .41454 m .64858 .41191 L .64998 .41346 L 0 .036 .137 r
F
.64712 .41454 m .64572 .413 L .64858 .41191 L F
.24334 .4104 m .24422 .40784 L .246 .40951 L 0 .027 .126 r
F
.24334 .4104 m .24156 .4087 L .24422 .40784 L F
.4746 .41933 m .47582 .41682 L .47738 .41851 L 0 .048 .15 r
F
.4746 .41933 m .47304 .41765 L .47582 .41682 L F
.53312 .42095 m .53442 .41877 L .53593 .42031 L 0 .053 .156 r
F
.53312 .42095 m .53161 .41942 L .53442 .41877 L F
.61862 .41621 m .62005 .41386 L .62147 .41529 L 0 .04 .142 r
F
.61862 .41621 m .6172 .41484 L .62005 .41386 L F
.81964 .40992 m .82135 .40726 L .82259 .40898 L 0 .026 .125 r
F
.81964 .40992 m .81839 .40819 L .82135 .40726 L F
.87384 .40934 m .87564 .40683 L .87682 .40843 L 0 .025 .123 r
F
.87384 .40934 m .87266 .40773 L .87564 .40683 L F
.62575 .41586 m .62719 .41351 L .62861 .41504 L 0 .04 .141 r
F
.62575 .41586 m .62433 .41438 L .62719 .41351 L F
.67562 .4131 m .67713 .41064 L .67851 .41225 L 0 .033 .134 r
F
.67562 .4131 m .67425 .41149 L .67713 .41064 L F
.75832 .41094 m .75995 .40843 L .76124 .41003 L 0 .028 .128 r
F
.75832 .41094 m .75703 .40932 L .75995 .40843 L F
.28328 .41076 m .28422 .40805 L .28597 .40974 L 0 .027 .127 r
F
.28328 .41076 m .28153 .40905 L .28422 .40805 L F
.92091 .40919 m .92277 .4065 L .92391 .40821 L 0 .024 .123 r
F
.92091 .40919 m .91977 .40749 L .92277 .4065 L F
.6115 .41675 m .61292 .41456 L .61435 .41582 L 0 .042 .144 r
F
.6115 .41675 m .61007 .41546 L .61292 .41456 L F
.76545 .41065 m .7671 .40816 L .76838 .40972 L 0 .028 .127 r
F
.76545 .41065 m .76417 .4091 L .7671 .40816 L F
.59725 .41756 m .59865 .41534 L .60009 .41673 L 0 .044 .146 r
F
.59725 .41756 m .5958 .41614 L .59865 .41534 L F
.64 .41519 m .64145 .41256 L .64286 .41409 L 0 .038 .139 r
F
.64 .41519 m .63859 .41365 L .64145 .41256 L F
.39319 .41442 m .39427 .41204 L .39592 .41359 L 0 .036 .138 r
F
.39319 .41442 m .39154 .41285 L .39427 .41204 L F
.29039 .41047 m .29134 .40788 L .29307 .40964 L 0 .027 .126 r
F
.29039 .41047 m .28866 .40873 L .29134 .40788 L F
.34179 .41246 m .34281 .40992 L .34449 .41172 L 0 .032 .132 r
F
.34179 .41246 m .3401 .41068 L .34281 .40992 L F
.25044 .41031 m .25133 .4077 L .25311 .40938 L 0 .027 .126 r
F
.25044 .41031 m .24866 .40863 L .25133 .4077 L F
.88098 .40913 m .8828 .4066 L .88397 .40823 L 0 .025 .123 r
F
.88098 .40913 m .87981 .40752 L .8828 .4066 L F
.60438 .41724 m .60579 .41505 L .60722 .41636 L 0 .043 .146 r
F
.60438 .41724 m .60294 .41591 L .60579 .41505 L F
.31609 .41153 m .31707 .40895 L .31878 .41072 L 0 .029 .129 r
F
.31609 .41153 m .31438 .40975 L .31707 .40895 L F
.43745 .41687 m .4386 .41471 L .4402 .41631 L 0 .043 .145 r
F
.43745 .41687 m .43585 .41524 L .4386 .41471 L F
.82679 .40977 m .82851 .40714 L .82974 .40883 L 0 .026 .125 r
F
.82679 .40977 m .82555 .40806 L .82851 .40714 L F
.92806 .40899 m .92994 .40639 L .93108 .40809 L 0 .024 .123 r
F
.92806 .40899 m .92692 .40728 L .92994 .40639 L F
.77259 .41037 m .77425 .4079 L .77552 .4095 L 0 .027 .127 r
F
.77259 .41037 m .77131 .40879 L .77425 .4079 L F
.36748 .41357 m .36854 .41096 L .37021 .41261 L 0 .034 .135 r
F
.36748 .41357 m .36581 .41196 L .36854 .41096 L F
.21761 .40983 m .21845 .40715 L .22026 .40885 L 0 .026 .125 r
F
.21761 .40983 m .2158 .40813 L .21845 .40715 L F
.4003 .4142 m .4014 .41173 L .40305 .41327 L 0 .036 .137 r
F
.4003 .4142 m .39866 .41266 L .4014 .41173 L F
.63288 .41579 m .63433 .41319 L .63574 .41475 L 0 .039 .141 r
F
.63288 .41579 m .63147 .41422 L .63433 .41319 L F
.83392 .40946 m .83566 .40683 L .83688 .40846 L 0 .025 .124 r
F
.83392 .40946 m .8327 .40783 L .83566 .40683 L F
.68276 .41302 m .68429 .41059 L .68565 .41218 L 0 .033 .134 r
F
.68276 .41302 m .6814 .41142 L .68429 .41059 L F
.69701 .41224 m .69856 .40974 L .69991 .41129 L 0 .031 .132 r
F
.69701 .41224 m .69567 .41072 L .69856 .40974 L F
.48172 .41938 m .48294 .41713 L .4845 .41881 L 0 .049 .152 r
F
.48172 .41938 m .48016 .41768 L .48294 .41713 L F
.84105 .40911 m .84281 .40662 L .84402 .40826 L 0 .025 .123 r
F
.84105 .40911 m .83984 .40748 L .84281 .40662 L F
.56163 .4198 m .56297 .41791 L .56445 .4191 L 0 .051 .154 r
F
.56163 .4198 m .56015 .41863 L .56297 .41791 L F
.52167 .41962 m .52296 .41788 L .52448 .41907 L F
.52167 .41962 m .52015 .41844 L .52296 .41788 L F
.59013 .41825 m .59151 .41561 L .59296 .41716 L 0 .046 .148 r
F
.59013 .41825 m .58867 .41672 L .59151 .41561 L F
.46315 .41805 m .46434 .41566 L .46592 .41736 L F
.46315 .41805 m .46157 .41636 L .46434 .41566 L F
.51455 .42004 m .51582 .41813 L .51735 .41921 L 0 .052 .154 r
F
.51455 .42004 m .51302 .4189 L .51582 .41813 L F
.3746 .41332 m .37567 .41076 L .37733 .41247 L 0 .034 .135 r
F
.3746 .41332 m .37294 .41165 L .37567 .41076 L F
.25754 .4102 m .25845 .40745 L .26022 .40924 L 0 .027 .126 r
F
.25754 .4102 m .25578 .40841 L .25845 .40745 L F
.5003 .42088 m .50154 .41898 L .50309 .42023 L 0 .054 .157 r
F
.5003 .42088 m .49875 .41962 L .50154 .41898 L F
.426 .41535 m .42713 .41306 L .42874 .41476 L 0 .039 .141 r
F
.426 .41535 m .42439 .4136 L .42713 .41306 L F
.70415 .412 m .7057 .40951 L .70705 .41114 L 0 .031 .131 r
F
.70415 .412 m .7028 .4104 L .7057 .40951 L F
.6899 .4128 m .69143 .41026 L .69278 .41176 L 0 .033 .133 r
F
.6899 .4128 m .68854 .41132 L .69143 .41026 L F
.88814 .40905 m .88997 .40649 L .89114 .40819 L 0 .025 .123 r
F
.88814 .40905 m .88696 .40734 L .88997 .40649 L F
.32319 .41147 m .32418 .40886 L .32589 .41055 L 0 .03 .13 r
F
.32319 .41147 m .32148 .40979 L .32418 .40886 L F
.56875 .41958 m .57011 .41763 L .57158 .41885 L 0 .051 .153 r
F
.56875 .41958 m .56728 .41839 L .57011 .41763 L F
.50742 .42058 m .50868 .4185 L .51022 .41969 L 0 .053 .156 r
F
.50742 .42058 m .50588 .41936 L .50868 .4185 L F
.40742 .41405 m .40852 .41187 L .41016 .41341 L 0 .036 .138 r
F
.40742 .41405 m .40578 .41251 L .40852 .41187 L F
.5545 .42038 m .55583 .41805 L .55732 .41941 L 0 .052 .155 r
F
.5545 .42038 m .55301 .41898 L .55583 .41805 L F
.22471 .40973 m .22555 .40715 L .22735 .40893 L 0 .026 .125 r
F
.22471 .40973 m .22291 .40795 L .22555 .40715 L F
.77974 .41034 m .78141 .40782 L .78268 .40949 L 0 .028 .127 r
F
.77974 .41034 m .77846 .40866 L .78141 .40782 L F
.54025 .42122 m .54156 .41878 L .54306 .42029 L 0 .054 .157 r
F
.54025 .42122 m .53874 .41966 L .54156 .41878 L F
.54738 .42086 m .5487 .41844 L .55019 .41991 L 0 .053 .156 r
F
.54738 .42086 m .54588 .41936 L .5487 .41844 L F
.29748 .41059 m .29844 .40791 L .30017 .4097 L 0 .028 .127 r
F
.29748 .41059 m .29575 .40881 L .29844 .40791 L F
.58301 .41893 m .58438 .41632 L .58584 .41783 L 0 .048 .15 r
F
.58301 .41893 m .58155 .41743 L .58438 .41632 L F
.84821 .40905 m .84997 .40649 L .85118 .40814 L 0 .025 .124 r
F
.84821 .40905 m .847 .4074 L .84997 .40649 L F
.72554 .41104 m .72712 .40847 L .72845 .41009 L 0 .029 .129 r
F
.72554 .41104 m .72421 .40941 L .72712 .40847 L F
.71129 .41186 m .71284 .40914 L .71418 .41083 L 0 .031 .131 r
F
.71129 .41186 m .70994 .41016 L .71284 .40914 L F
.71842 .41147 m .71998 .40878 L .72131 .41044 L 0 .03 .13 r
F
.71842 .41147 m .71708 .4098 L .71998 .40878 L F
.26465 .41011 m .26556 .4074 L .26732 .4092 L 0 .027 .126 r
F
.26465 .41011 m .26289 .40832 L .26556 .4074 L F
.34888 .41273 m .34991 .41001 L .35159 .41183 L 0 .033 .133 r
F
.34888 .41273 m .3472 .41092 L .34991 .41001 L F
.3303 .41135 m .3313 .40878 L .333 .41051 L 0 .03 .13 r
F
.3303 .41135 m .3286 .40966 L .3313 .40878 L F
.57588 .41947 m .57725 .4172 L .57872 .41855 L 0 .05 .153 r
F
.57588 .41947 m .57442 .41812 L .57725 .4172 L F
.73268 .41078 m .73427 .4083 L .73559 .40987 L 0 .029 .129 r
F
.73268 .41078 m .73136 .4092 L .73427 .4083 L F
.89531 .40902 m .89714 .40642 L .89831 .40811 L 0 .025 .124 r
F
.89531 .40902 m .89414 .40733 L .89714 .40642 L F
.78689 .41022 m .78855 .40753 L .78982 .40921 L 0 .027 .127 r
F
.78689 .41022 m .78562 .40852 L .78855 .40753 L F
.73981 .41044 m .74141 .40788 L .74272 .40944 L 0 .028 .128 r
F
.73981 .41044 m .7385 .40888 L .74141 .40788 L F
.3817 .41342 m .38278 .41092 L .38443 .41268 L 0 .035 .136 r
F
.3817 .41342 m .38005 .4117 L .38278 .41092 L F
.85536 .4089 m .85713 .40626 L .85833 .40794 L 0 .025 .123 r
F
.85536 .4089 m .85415 .4072 L .85713 .40626 L F
.79402 .40992 m .79571 .40734 L .79697 .40902 L 0 .027 .126 r
F
.79402 .40992 m .79276 .40824 L .79571 .40734 L F
.30459 .41052 m .30556 .40775 L .30728 .40955 L 0 .028 .127 r
F
.30459 .41052 m .30287 .40873 L .30556 .40775 L F
.44456 .41729 m .44573 .41482 L .44732 .41638 L 0 .044 .147 r
F
.44456 .41729 m .44296 .41569 L .44573 .41482 L F
.90246 .40879 m .90429 .40616 L .90545 .40782 L 0 .025 .123 r
F
.90246 .40879 m .9013 .40713 L .90429 .40616 L F
.74694 .41019 m .74856 .40768 L .74987 .40935 L 0 .028 .127 r
F
.74694 .41019 m .74563 .4085 L .74856 .40768 L F
.45168 .41696 m .45286 .41469 L .45445 .41614 L 0 .044 .146 r
F
.45168 .41696 m .45009 .41546 L .45286 .41469 L F
.35599 .41262 m .35702 .41014 L .3587 .41184 L 0 .033 .134 r
F
.35599 .41262 m .35431 .41092 L .35702 .41014 L F
.47026 .41838 m .47147 .41594 L .47304 .41765 L 0 .047 .15 r
F
.47026 .41838 m .46869 .41667 L .47147 .41594 L F
.27174 .41008 m .27267 .40742 L .27442 .40919 L 0 .027 .127 r
F
.27174 .41008 m .26999 .4083 L .27267 .40742 L F
.23178 .4099 m .23265 .4072 L .23444 .40896 L 0 .027 .126 r
F
.23178 .4099 m .22999 .40813 L .23265 .4072 L F
.86251 .40874 m .8643 .4062 L .8655 .40787 L 0 .025 .123 r
F
.86251 .40874 m .86131 .40707 L .8643 .4062 L F
.48884 .41983 m .49007 .41791 L .49162 .41934 L 0 .052 .155 r
F
.48884 .41983 m .48728 .41836 L .49007 .41791 L F
.80117 .40975 m .80286 .40715 L .80411 .40878 L 0 .027 .126 r
F
.80117 .40975 m .79992 .40812 L .80286 .40715 L F
.9096 .40857 m .91146 .40605 L .91261 .40771 L 0 .025 .123 r
F
.9096 .40857 m .90845 .40693 L .91146 .40605 L F
.5288 .42004 m .53009 .4179 L .53161 .41942 L 0 .053 .155 r
F
.5288 .42004 m .52728 .41852 L .53009 .4179 L F
.41453 .4143 m .41564 .41193 L .41727 .4135 L 0 .037 .139 r
F
.41453 .4143 m .4129 .41276 L .41564 .41193 L F
.8083 .40941 m .81 .40678 L .81125 .40841 L 0 .026 .125 r
F
.8083 .40941 m .80706 .40778 L .81 .40678 L F
.3374 .41144 m .33841 .4089 L .3401 .41068 L 0 .031 .131 r
F
.3374 .41144 m .33571 .40967 L .33841 .4089 L F
.4331 .4158 m .43424 .41363 L .43585 .41524 L 0 .042 .144 r
F
.4331 .4158 m .43149 .41416 L .43424 .41363 L F
.23889 .40969 m .23977 .407 L .24156 .4087 L 0 .027 .126 r
F
.23889 .40969 m .2371 .40797 L .23977 .407 L F
.64998 .41346 m .65145 .41096 L .65285 .4125 L 0 .035 .137 r
F
.64998 .41346 m .64858 .41191 L .65145 .41096 L F
.81544 .40913 m .81715 .40649 L .81839 .40819 L 0 .026 .125 r
F
.81544 .40913 m .8142 .40745 L .81715 .40649 L F
.31169 .41053 m .31266 .40797 L .31438 .40975 L 0 .029 .129 r
F
.31169 .41053 m .30997 .40874 L .31266 .40797 L F
.65711 .41313 m .6586 .41074 L .65998 .41224 L 0 .035 .136 r
F
.65711 .41313 m .65572 .41162 L .6586 .41074 L F
.67136 .41235 m .67287 .40994 L .67425 .41149 L 0 .033 .134 r
F
.67136 .41235 m .66999 .41082 L .67287 .40994 L F
.66424 .41275 m .66573 .41029 L .66711 .41177 L 0 .034 .135 r
F
.66424 .41275 m .66286 .41127 L .66573 .41029 L F
.7541 .4102 m .75573 .40767 L .75703 .40932 L 0 .028 .128 r
F
.7541 .4102 m .7528 .40852 L .75573 .40767 L F
.86967 .40863 m .87147 .40611 L .87266 .40773 L 0 .025 .124 r
F
.86967 .40863 m .86848 .407 L .87147 .40611 L F
.27885 .41002 m .27978 .40733 L .28153 .40905 L 0 .028 .127 r
F
.27885 .41002 m .2771 .40829 L .27978 .40733 L F
.91677 .40847 m .91862 .40582 L .91977 .40749 L 0 .025 .123 r
F
.91677 .40847 m .91562 .40681 L .91862 .40582 L F
.38881 .41363 m .38989 .41111 L .39154 .41285 L 0 .036 .137 r
F
.38881 .41363 m .38716 .4119 L .38989 .41111 L F
.246 .40951 m .24688 .40697 L .24866 .40863 L 0 .027 .126 r
F
.246 .40951 m .24422 .40784 L .24688 .40697 L F
.36309 .41271 m .36413 .41033 L .36581 .41196 L 0 .034 .135 r
F
.36309 .41271 m .36142 .4111 L .36413 .41033 L F
.64286 .41409 m .64432 .41146 L .64572 .413 L 0 .037 .138 r
F
.64286 .41409 m .64145 .41256 L .64432 .41146 L F
.42164 .41429 m .42277 .41198 L .42439 .4136 L 0 .038 .14 r
F
.42164 .41429 m .42002 .4127 L .42277 .41198 L F
.28597 .40974 m .28691 .40705 L .28866 .40873 L 0 .027 .126 r
F
.28597 .40974 m .28422 .40805 L .28691 .40705 L F
.62147 .41529 m .62291 .4129 L .62433 .41438 L 0 .04 .142 r
F
.62147 .41529 m .62005 .41386 L .62291 .4129 L F
.4588 .41707 m .45999 .41474 L .46157 .41636 L 0 .045 .147 r
F
.4588 .41707 m .45722 .41544 L .45999 .41474 L F
.82259 .40898 m .82431 .40636 L .82555 .40806 L 0 .026 .125 r
F
.82259 .40898 m .82135 .40726 L .82431 .40636 L F
.92391 .40821 m .92578 .40557 L .92692 .40728 L 0 .024 .122 r
F
.92391 .40821 m .92277 .4065 L .92578 .40557 L F
.47738 .41851 m .4786 .41598 L .48016 .41768 L 0 .048 .151 r
F
.47738 .41851 m .47582 .41682 L .4786 .41598 L F
.87682 .40843 m .87863 .4059 L .87981 .40752 L 0 .025 .123 r
F
.87682 .40843 m .87564 .40683 L .87863 .4059 L F
.76124 .41003 m .76288 .40752 L .76417 .4091 L 0 .028 .128 r
F
.76124 .41003 m .75995 .40843 L .76288 .40752 L F
.67851 .41225 m .68003 .40981 L .6814 .41142 L 0 .033 .134 r
F
.67851 .41225 m .67713 .41064 L .68003 .40981 L F
.61435 .41582 m .61577 .41354 L .6172 .41484 L 0 .042 .144 r
F
.61435 .41582 m .61292 .41456 L .61577 .41354 L F
.21315 .40911 m .21398 .4065 L .2158 .40813 L 0 .026 .125 r
F
.21315 .40911 m .21132 .40748 L .21398 .4065 L F
.62861 .41504 m .63005 .41264 L .63147 .41422 L 0 .04 .142 r
F
.62861 .41504 m .62719 .41351 L .63005 .41264 L F
.76838 .40972 m .77003 .40721 L .77131 .40879 L 0 .028 .127 r
F
.76838 .40972 m .7671 .40816 L .77003 .40721 L F
.25311 .40938 m .254 .40674 L .25578 .40841 L 0 .027 .126 r
F
.25311 .40938 m .25133 .4077 L .254 .40674 L F
.63574 .41475 m .63719 .4121 L .63859 .41365 L 0 .039 .141 r
F
.63574 .41475 m .63433 .41319 L .63719 .4121 L F
.82974 .40883 m .83147 .40616 L .8327 .40783 L 0 .026 .124 r
F
.82974 .40883 m .82851 .40714 L .83147 .40616 L F
.60009 .41673 m .6015 .41453 L .60294 .41591 L 0 .045 .147 r
F
.60009 .41673 m .59865 .41534 L .6015 .41453 L F
.88397 .40823 m .88579 .40569 L .88696 .40734 L 0 .025 .123 r
F
.88397 .40823 m .8828 .4066 L .88579 .40569 L F
.53593 .42031 m .53724 .41812 L .53874 .41966 L 0 .054 .157 r
F
.53593 .42031 m .53442 .41877 L .53724 .41812 L F
.49596 .42011 m .4972 .41836 L .49875 .41962 L 0 .055 .157 r
F
.49596 .42011 m .49441 .41885 L .4972 .41836 L F
.39592 .41359 m .39701 .41111 L .39866 .41266 L 0 .036 .138 r
F
.39592 .41359 m .39427 .41204 L .39701 .41111 L F
.60722 .41636 m .60864 .41418 L .61007 .41546 L 0 .044 .146 r
F
.60722 .41636 m .60579 .41505 L .60864 .41418 L F
.29307 .40964 m .29402 .40703 L .29575 .40881 L 0 .027 .127 r
F
.29307 .40964 m .29134 .40788 L .29402 .40703 L F
.22026 .40885 m .2211 .40624 L .22291 .40795 L 0 .026 .125 r
F
.22026 .40885 m .21845 .40715 L .2211 .40624 L F
.37021 .41261 m .37127 .40997 L .37294 .41165 L 0 .034 .135 r
F
.37021 .41261 m .36854 .41096 L .37127 .40997 L F
.59296 .41716 m .59435 .41458 L .5958 .41614 L 0 .045 .147 r
F
.59296 .41716 m .59151 .41561 L .59435 .41458 L F
.83688 .40846 m .83862 .40585 L .83984 .40748 L 0 .025 .124 r
F
.83688 .40846 m .83566 .40683 L .83862 .40585 L F
.93108 .40809 m .93296 .40549 L .93409 .40719 L 0 .024 .123 r
F
.93108 .40809 m .92994 .40639 L .93296 .40549 L F
.77552 .4095 m .77719 .40706 L .77846 .40866 L 0 .027 .127 r
F
.77552 .4095 m .77425 .4079 L .77719 .40706 L F
.69991 .41129 m .70145 .40881 L .7028 .4104 L 0 .031 .132 r
F
.69991 .41129 m .69856 .40974 L .70145 .40881 L F
.40305 .41327 m .40414 .41097 L .40578 .41251 L 0 .036 .137 r
F
.40305 .41327 m .4014 .41173 L .40414 .41097 L F
.31878 .41072 m .31977 .40804 L .32148 .40979 L 0 .03 .13 r
F
.31878 .41072 m .31707 .40895 L .31977 .40804 L F
.34449 .41172 m .34551 .40911 L .3472 .41092 L 0 .032 .133 r
F
.34449 .41172 m .34281 .40992 L .34551 .40911 L F
.69278 .41176 m .69431 .40919 L .69567 .41072 L F
.69278 .41176 m .69143 .41026 L .69431 .40919 L F
.68565 .41218 m .68718 .40975 L .68854 .41132 L 0 .033 .134 r
F
.68565 .41218 m .68429 .41059 L .68718 .40975 L F
.26022 .40924 m .26113 .40652 L .26289 .40832 L 0 .027 .126 r
F
.26022 .40924 m .25845 .40745 L .26113 .40652 L F
.84402 .40826 m .84579 .40576 L .847 .4074 L 0 .025 .124 r
F
.84402 .40826 m .84281 .40662 L .84579 .40576 L F
.37733 .41247 m .37839 .40997 L .38005 .4117 L 0 .034 .135 r
F
.37733 .41247 m .37567 .41076 L .37839 .40997 L F
.51735 .41921 m .51862 .41741 L .52015 .41844 L 0 .052 .155 r
F
.51735 .41921 m .51582 .41813 L .51862 .41741 L F
.55732 .41941 m .55866 .41725 L .56015 .41863 L F
.55732 .41941 m .55583 .41805 L .55866 .41725 L F
.58584 .41783 m .58722 .41519 L .58867 .41672 L 0 .047 .149 r
F
.58584 .41783 m .58438 .41632 L .58722 .41519 L F
.32589 .41055 m .32689 .40795 L .3286 .40966 L 0 .03 .13 r
F
.32589 .41055 m .32418 .40886 L .32689 .40795 L F
.70705 .41114 m .7086 .40852 L .70994 .41016 L 0 .031 .131 r
F
.70705 .41114 m .7057 .40951 L .7086 .40852 L F
.89114 .40819 m .89297 .40564 L .89414 .40733 L 0 .025 .123 r
F
.89114 .40819 m .88997 .40649 L .89297 .40564 L F
.4402 .41631 m .44136 .41412 L .44296 .41569 L 0 .044 .146 r
F
.4402 .41631 m .4386 .41471 L .44136 .41412 L F
.51022 .41969 m .51148 .41776 L .51302 .4189 L 0 .054 .156 r
F
.51022 .41969 m .50868 .4185 L .51148 .41776 L F
.56445 .4191 m .56581 .41719 L .56728 .41839 L 0 .052 .155 r
F
.56445 .4191 m .56297 .41791 L .56581 .41719 L F
.54306 .42029 m .54438 .41788 L .54588 .41936 L 0 .054 .157 r
F
.54306 .42029 m .54156 .41878 L .54438 .41788 L F
.55019 .41991 m .55152 .41755 L .55301 .41898 L 0 .053 .156 r
F
.55019 .41991 m .5487 .41844 L .55152 .41755 L F
.71418 .41083 m .71574 .40813 L .71708 .4098 L 0 .03 .13 r
F
.71418 .41083 m .71284 .40914 L .71574 .40813 L F
.46592 .41736 m .46712 .41495 L .46869 .41667 L 0 .046 .149 r
F
.46592 .41736 m .46434 .41566 L .46712 .41495 L F
.72131 .41044 m .72288 .40775 L .72421 .40941 L 0 .029 .129 r
F
.72131 .41044 m .71998 .40878 L .72288 .40775 L F
.78268 .40949 m .78434 .40684 L .78562 .40852 L 0 .028 .127 r
F
.78268 .40949 m .78141 .40782 L .78434 .40684 L F
.72845 .41009 m .73004 .40759 L .73136 .4092 L 0 .029 .129 r
F
.72845 .41009 m .72712 .40847 L .73004 .40759 L F
.30017 .4097 m .30114 .40693 L .30287 .40873 L 0 .028 .127 r
F
.30017 .4097 m .29844 .40791 L .30114 .40693 L F
.4845 .41881 m .48572 .4167 L .48728 .41836 L 0 .051 .154 r
F
.4845 .41881 m .48294 .41713 L .48572 .4167 L F
.22735 .40893 m .2282 .40636 L .22999 .40813 L 0 .027 .126 r
F
.22735 .40893 m .22555 .40715 L .2282 .40636 L F
.85118 .40814 m .85295 .40555 L .85415 .4072 L 0 .025 .124 r
F
.85118 .40814 m .84997 .40649 L .85295 .40555 L F
.50309 .42023 m .50434 .41814 L .50588 .41936 L 0 .055 .157 r
F
.50309 .42023 m .50154 .41898 L .50434 .41814 L F
.57158 .41885 m .57295 .41688 L .57442 .41812 L 0 .051 .154 r
F
.57158 .41885 m .57011 .41763 L .57295 .41688 L F
.52448 .41907 m .52577 .41732 L .52728 .41852 L 0 .053 .155 r
F
.52448 .41907 m .52296 .41788 L .52577 .41732 L F
.26732 .4092 m .26824 .4065 L .26999 .4083 L 0 .027 .126 r
F
.26732 .4092 m .26556 .4074 L .26824 .4065 L F
.78982 .40921 m .79149 .40656 L .79276 .40824 L F
.78982 .40921 m .78855 .40753 L .79149 .40656 L F
.42874 .41476 m .42988 .41251 L .43149 .41416 L 0 .04 .142 r
F
.42874 .41476 m .42713 .41306 L .42988 .41251 L F
.74272 .40944 m .74433 .40693 L .74563 .4085 L 0 .028 .127 r
F
.74272 .40944 m .74141 .40788 L .74433 .40693 L F
.57872 .41855 m .58008 .41608 L .58155 .41743 L 0 .05 .152 r
F
.57872 .41855 m .57725 .4172 L .58008 .41608 L F
.35159 .41183 m .35263 .4091 L .35431 .41092 L 0 .033 .133 r
F
.35159 .41183 m .34991 .41001 L .35263 .4091 L F
.41016 .41341 m .41126 .41121 L .4129 .41276 L 0 .037 .139 r
F
.41016 .41341 m .40852 .41187 L .41126 .41121 L F
.73559 .40987 m .73719 .4073 L .7385 .40888 L 0 .029 .128 r
F
.73559 .40987 m .73427 .4083 L .73719 .4073 L F
.89831 .40811 m .90013 .40546 L .9013 .40713 L 0 .025 .124 r
F
.89831 .40811 m .89714 .40642 L .90013 .40546 L F
.85833 .40794 m .86011 .40539 L .86131 .40707 L 0 .025 .123 r
F
.85833 .40794 m .85713 .40626 L .86011 .40539 L F
.333 .41051 m .33401 .40791 L .33571 .40967 L 0 .03 .13 r
F
.333 .41051 m .3313 .40878 L .33401 .40791 L F
.30728 .40955 m .30825 .40694 L .30997 .40874 L 0 .028 .128 r
F
.30728 .40955 m .30556 .40775 L .30825 .40694 L F
.90545 .40782 m .9073 .40527 L .90845 .40693 L 0 .025 .123 r
F
.90545 .40782 m .90429 .40616 L .9073 .40527 L F
.79697 .40902 m .79866 .40644 L .79992 .40812 L 0 .027 .126 r
F
.79697 .40902 m .79571 .40734 L .79866 .40644 L F
.44732 .41638 m .44849 .41395 L .45009 .41546 L 0 .044 .147 r
F
.44732 .41638 m .44573 .41482 L .44849 .41395 L F
.38443 .41268 m .38551 .41011 L .38716 .4119 L 0 .035 .137 r
F
.38443 .41268 m .38278 .41092 L .38551 .41011 L F
.23444 .40896 m .23531 .40623 L .2371 .40797 L 0 .027 .126 r
F
.23444 .40896 m .23265 .4072 L .23531 .40623 L F
.74987 .40935 m .75149 .40685 L .7528 .40852 L 0 .028 .128 r
F
.74987 .40935 m .74856 .40768 L .75149 .40685 L F
.80411 .40878 m .80581 .40615 L .80706 .40778 L 0 .027 .126 r
F
.80411 .40878 m .80286 .40715 L .80581 .40615 L F
.27442 .40919 m .27534 .40654 L .2771 .40829 L 0 .027 .127 r
F
.27442 .40919 m .27267 .40742 L .27534 .40654 L F
.81125 .40841 m .81295 .4058 L .8142 .40745 L 0 .026 .125 r
F
.81125 .40841 m .81 .40678 L .81295 .4058 L F
.45445 .41614 m .45563 .41404 L .45722 .41544 L 0 .045 .147 r
F
.45445 .41614 m .45286 .41469 L .45563 .41404 L F
.8655 .40787 m .86729 .40533 L .86848 .407 L 0 .025 .124 r
F
.8655 .40787 m .8643 .4062 L .86729 .40533 L F
.3587 .41184 m .35974 .4094 L .36142 .4111 L 0 .034 .135 r
F
.3587 .41184 m .35702 .41014 L .35974 .4094 L F
.91261 .40771 m .91447 .40515 L .91562 .40681 L 0 .025 .123 r
F
.91261 .40771 m .91146 .40605 L .91447 .40515 L F
.24156 .4087 m .24243 .40615 L .24422 .40784 L 0 .027 .126 r
F
.24156 .4087 m .23977 .407 L .24243 .40615 L F
.65285 .4125 m .65433 .41011 L .65572 .41162 L 0 .035 .137 r
F
.65285 .4125 m .65145 .41096 L .65433 .41011 L F
.47304 .41765 m .47425 .41512 L .47582 .41682 L 0 .048 .15 r
F
.47304 .41765 m .47147 .41594 L .47425 .41512 L F
.41727 .4135 m .41839 .4111 L .42002 .4127 L 0 .038 .139 r
F
.41727 .4135 m .41564 .41193 L .41839 .4111 L F
.81839 .40819 m .82011 .40555 L .82135 .40726 L 0 .026 .125 r
F
.81839 .40819 m .81715 .40649 L .82011 .40555 L F
.66711 .41177 m .66861 .40933 L .66999 .41082 L 0 .034 .135 r
F
.66711 .41177 m .66573 .41029 L .66861 .40933 L F
.64572 .413 m .64718 .41036 L .64858 .41191 L 0 .036 .138 r
F
.64572 .413 m .64432 .41146 L .64718 .41036 L F
.28153 .40905 m .28247 .40634 L .28422 .40805 L 0 .027 .127 r
F
.28153 .40905 m .27978 .40733 L .28247 .40634 L F
.91977 .40749 m .92163 .40483 L .92277 .4065 L 0 .024 .123 r
F
.91977 .40749 m .91862 .40582 L .92163 .40483 L F
.65998 .41224 m .66147 .40978 L .66286 .41127 L 0 .035 .136 r
F
.65998 .41224 m .6586 .41074 L .66147 .40978 L F
.3401 .41068 m .34112 .40813 L .34281 .40992 L 0 .031 .132 r
F
.3401 .41068 m .33841 .4089 L .34112 .40813 L F
.87266 .40773 m .87446 .40521 L .87564 .40683 L 0 .025 .124 r
F
.87266 .40773 m .87147 .40611 L .87446 .40521 L F
.75703 .40932 m .75866 .4068 L .75995 .40843 L 0 .028 .128 r
F
.75703 .40932 m .75573 .40767 L .75866 .4068 L F
.67425 .41149 m .67576 .40905 L .67713 .41064 L 0 .033 .134 r
F
.67425 .41149 m .67287 .40994 L .67576 .40905 L F
.28866 .40873 m .28959 .40622 L .29134 .40788 L 0 .027 .126 r
F
.28866 .40873 m .28691 .40705 L .28959 .40622 L F
.53161 .41942 m .53291 .41724 L .53442 .41877 L 0 .054 .156 r
F
.53161 .41942 m .53009 .4179 L .53291 .41724 L F
.31438 .40975 m .31535 .40718 L .31707 .40895 L 0 .029 .129 r
F
.31438 .40975 m .31266 .40797 L .31535 .40718 L F
.24866 .40863 m .24954 .40605 L .25133 .4077 L 0 .027 .126 r
F
.24866 .40863 m .24688 .40697 L .24954 .40605 L F
.62433 .41438 m .62577 .41198 L .62719 .41351 L 0 .04 .142 r
F
.62433 .41438 m .62291 .4129 L .62577 .41198 L F
.49162 .41934 m .49286 .41743 L .49441 .41885 L 0 .054 .157 r
F
.49162 .41934 m .49007 .41791 L .49286 .41743 L F
.82555 .40806 m .82728 .40546 L .82851 .40714 L 0 .026 .125 r
F
.82555 .40806 m .82431 .40636 L .82728 .40546 L F
.92692 .40728 m .9288 .40468 L .92994 .40639 L 0 .024 .123 r
F
.92692 .40728 m .92578 .40557 L .9288 .40468 L F
.39154 .41285 m .39263 .41028 L .39427 .41204 L 0 .036 .138 r
F
.39154 .41285 m .38989 .41111 L .39263 .41028 L F
.87981 .40752 m .88162 .40496 L .8828 .4066 L 0 .025 .123 r
F
.87981 .40752 m .87863 .4059 L .88162 .40496 L F
.6172 .41484 m .61863 .41251 L .62005 .41386 L 0 .042 .144 r
F
.6172 .41484 m .61577 .41354 L .61863 .41251 L F
.63859 .41365 m .64005 .41101 L .64145 .41256 L 0 .038 .14 r
F
.63859 .41365 m .63719 .4121 L .64005 .41101 L F
.76417 .4091 m .76581 .40656 L .7671 .40816 L 0 .028 .128 r
F
.76417 .4091 m .76288 .40752 L .76581 .40656 L F
.43585 .41524 m .43699 .41313 L .4386 .41471 L 0 .043 .145 r
F
.43585 .41524 m .43424 .41363 L .43699 .41313 L F
.2158 .40813 m .21664 .40552 L .21845 .40715 L 0 .026 .125 r
F
.2158 .40813 m .21398 .4065 L .21664 .40552 L F
.48016 .41768 m .48138 .41544 L .48294 .41713 L 0 .049 .152 r
F
.48016 .41768 m .4786 .41598 L .48138 .41544 L F
.36581 .41196 m .36687 .40931 L .36854 .41096 L 0 .034 .135 r
F
.36581 .41196 m .36413 .41033 L .36687 .40931 L F
.77131 .40879 m .77297 .40631 L .77425 .4079 L 0 .028 .127 r
F
.77131 .40879 m .77003 .40721 L .77297 .40631 L F
.25578 .40841 m .25668 .40578 L .25845 .40745 L 0 .027 .126 r
F
.25578 .40841 m .254 .40674 L .25668 .40578 L F
.8327 .40783 m .83443 .40516 L .83566 .40683 L 0 .025 .124 r
F
.8327 .40783 m .83147 .40616 L .83443 .40516 L F
.5958 .41614 m .5972 .41378 L .59865 .41534 L 0 .045 .147 r
F
.5958 .41614 m .59435 .41458 L .5972 .41378 L F
.46157 .41636 m .46276 .41403 L .46434 .41566 L 0 .046 .148 r
F
.46157 .41636 m .45999 .41474 L .46276 .41403 L F
.6814 .41142 m .68292 .409 L .68429 .41059 L 0 .034 .134 r
F
.6814 .41142 m .68003 .40981 L .68292 .409 L F
.42439 .4136 m .42552 .41141 L .42713 .41306 L 0 .039 .141 r
F
.42439 .4136 m .42277 .41198 L .42552 .41141 L F
.83984 .40748 m .84159 .40499 L .84281 .40662 L 0 .025 .124 r
F
.83984 .40748 m .83862 .40585 L .84159 .40499 L F
.37294 .41165 m .374 .40906 L .37567 .41076 L 0 .034 .135 r
F
.37294 .41165 m .37127 .40997 L .374 .40906 L F
.63147 .41422 m .63291 .41161 L .63433 .41319 L 0 .04 .142 r
F
.63147 .41422 m .63005 .41264 L .63291 .41161 L F
.39866 .41266 m .39976 .41018 L .4014 .41173 L 0 .036 .138 r
F
.39866 .41266 m .39701 .41111 L .39976 .41018 L F
.88696 .40734 m .88879 .40483 L .88997 .40649 L 0 .025 .123 r
F
.88696 .40734 m .88579 .40569 L .88879 .40483 L F
.61007 .41546 m .6115 .41331 L .61292 .41456 L 0 .044 .146 r
F
.61007 .41546 m .60864 .41418 L .6115 .41331 L F
.22291 .40795 m .22375 .40544 L .22555 .40715 L 0 .026 .125 r
F
.22291 .40795 m .2211 .40624 L .22375 .40544 L F
.69567 .41072 m .69721 .40818 L .69856 .40974 L 0 .032 .132 r
F
.69567 .41072 m .69431 .40919 L .69721 .40818 L F
.60294 .41591 m .60435 .4137 L .60579 .41505 L 0 .045 .147 r
F
.60294 .41591 m .6015 .41453 L .60435 .4137 L F
.32148 .40979 m .32247 .40713 L .32418 .40886 L 0 .03 .13 r
F
.32148 .40979 m .31977 .40804 L .32247 .40713 L F
.29575 .40881 m .29671 .40612 L .29844 .40791 L 0 .028 .127 r
F
.29575 .40881 m .29402 .40703 L .29671 .40612 L F
.58867 .41672 m .59005 .41406 L .59151 .41561 L 0 .046 .149 r
F
.58867 .41672 m .58722 .41519 L .59005 .41406 L F
.7028 .4104 m .70436 .40788 L .7057 .40951 L 0 .031 .132 r
F
.7028 .4104 m .70145 .40881 L .70436 .40788 L F
.77846 .40866 m .78013 .40621 L .78141 .40782 L 0 .028 .127 r
F
.77846 .40866 m .77719 .40706 L .78013 .40621 L F
.26289 .40832 m .2638 .40559 L .26556 .4074 L 0 .027 .126 r
F
.26289 .40832 m .26113 .40652 L .2638 .40559 L F
.3472 .41092 m .34823 .40819 L .34991 .41001 L 0 .032 .133 r
F
.3472 .41092 m .34551 .40911 L .34823 .40819 L F
.68854 .41132 m .69007 .40869 L .69143 .41026 L 0 .033 .134 r
F
.68854 .41132 m .68718 .40975 L .69007 .40869 L F
.40578 .41251 m .40688 .41031 L .40852 .41187 L 0 .037 .138 r
F
.40578 .41251 m .40414 .41097 L .40688 .41031 L F
.70994 .41016 m .7115 .40751 L .71284 .40914 L 0 .031 .131 r
F
.70994 .41016 m .7086 .40852 L .7115 .40751 L F
.53874 .41966 m .54005 .4173 L .54156 .41878 L 0 .055 .157 r
F
.53874 .41966 m .53724 .41812 L .54005 .4173 L F
.847 .4074 m .84876 .40485 L .84997 .40649 L 0 .025 .124 r
F
.847 .4074 m .84579 .40576 L .84876 .40485 L F
.71708 .4098 m .71864 .40711 L .71998 .40878 L 0 .03 .13 r
F
.71708 .4098 m .71574 .40813 L .71864 .40711 L F
.72421 .40941 m .72579 .40683 L .72712 .40847 L 0 .029 .129 r
F
.72421 .40941 m .72288 .40775 L .72579 .40683 L F
.3286 .40966 m .3296 .40706 L .3313 .40878 L 0 .03 .13 r
F
.3286 .40966 m .32689 .40795 L .3296 .40706 L F
.54588 .41936 m .5472 .41701 L .5487 .41844 L 0 .054 .157 r
F
.54588 .41936 m .54438 .41788 L .5472 .41701 L F
.55301 .41898 m .55434 .41667 L .55583 .41805 L 0 .053 .156 r
F
.55301 .41898 m .55152 .41755 L .55434 .41667 L F
.89414 .40733 m .89597 .40474 L .89714 .40642 L 0 .025 .124 r
F
.89414 .40733 m .89297 .40564 L .89597 .40474 L F
.78562 .40852 m .78728 .40585 L .78855 .40753 L 0 .027 .127 r
F
.78562 .40852 m .78434 .40684 L .78728 .40585 L F
.30287 .40873 m .30384 .40595 L .30556 .40775 L 0 .028 .127 r
F
.30287 .40873 m .30114 .40693 L .30384 .40595 L F
.58155 .41743 m .58292 .41497 L .58438 .41632 L 0 .049 .151 r
F
.58155 .41743 m .58008 .41608 L .58292 .41497 L F
.38005 .4117 m .38112 .40917 L .38278 .41092 L 0 .035 .136 r
F
.38005 .4117 m .37839 .40997 L .38112 .40917 L F
.56015 .41863 m .56149 .4165 L .56297 .41791 L 0 .053 .155 r
F
.56015 .41863 m .55866 .41725 L .56149 .4165 L F
.49875 .41962 m .49999 .41773 L .50154 .41898 L 0 .056 .159 r
F
.49875 .41962 m .4972 .41836 L .49999 .41773 L F
.52015 .41844 m .52143 .41684 L .52296 .41788 L 0 .053 .156 r
F
.52015 .41844 m .51862 .41741 L .52143 .41684 L F
.85415 .4072 m .85592 .40461 L .85713 .40626 L 0 .025 .123 r
F
.85415 .4072 m .85295 .40555 L .85592 .40461 L F
.73136 .4092 m .73296 .40671 L .73427 .4083 L 0 .029 .129 r
F
.73136 .4092 m .73004 .40759 L .73296 .40671 L F
.51302 .4189 m .51429 .41706 L .51582 .41813 L 0 .054 .157 r
F
.51302 .4189 m .51148 .41776 L .51429 .41706 L F
.79276 .40824 m .79444 .40566 L .79571 .40734 L 0 .027 .126 r
F
.79276 .40824 m .79149 .40656 L .79444 .40566 L F
.50588 .41936 m .50714 .41729 L .50868 .4185 L 0 .055 .158 r
F
.50588 .41936 m .50434 .41814 L .50714 .41729 L F
.7385 .40888 m .7401 .40631 L .74141 .40788 L 0 .028 .128 r
F
.7385 .40888 m .73719 .4073 L .7401 .40631 L F
.56728 .41839 m .56864 .41642 L .57011 .41763 L 0 .053 .155 r
F
.56728 .41839 m .56581 .41719 L .56864 .41642 L F
.26999 .4083 m .27091 .40564 L .27267 .40742 L 0 .027 .126 r
F
.26999 .4083 m .26824 .4065 L .27091 .40564 L F
.74563 .4085 m .74726 .40608 L .74856 .40768 L 0 .028 .128 r
F
.74563 .4085 m .74433 .40693 L .74726 .40608 L F
.9013 .40713 m .90313 .40449 L .90429 .40616 L 0 .025 .123 r
F
.9013 .40713 m .90013 .40546 L .90313 .40449 L F
.22999 .40813 m .23086 .40544 L .23265 .4072 L 0 .027 .126 r
F
.22999 .40813 m .2282 .40636 L .23086 .40544 L F
.35431 .41092 m .35535 .40832 L .35702 .41014 L 0 .033 .134 r
F
.35431 .41092 m .35263 .4091 L .35535 .40832 L F
.46869 .41667 m .46989 .41422 L .47147 .41594 L 0 .047 .15 r
F
.46869 .41667 m .46712 .41495 L .46989 .41422 L F
.44296 .41569 m .44412 .4133 L .44573 .41482 L 0 .045 .147 r
F
.44296 .41569 m .44136 .41412 L .44412 .4133 L F
.57442 .41812 m .57579 .41596 L .57725 .4172 L 0 .052 .154 r
F
.57442 .41812 m .57295 .41688 L .57579 .41596 L F
.86131 .40707 m .8631 .40453 L .8643 .4062 L 0 .025 .124 r
F
.86131 .40707 m .86011 .40539 L .8631 .40453 L F
.33571 .40967 m .33672 .40712 L .33841 .4089 L 0 .03 .131 r
F
.33571 .40967 m .33401 .40791 L .33672 .40712 L F
.90845 .40693 m .91031 .40439 L .91146 .40605 L 0 .025 .123 r
F
.90845 .40693 m .9073 .40527 L .91031 .40439 L F
.79992 .40812 m .8016 .40548 L .80286 .40715 L 0 .027 .126 r
F
.79992 .40812 m .79866 .40644 L .8016 .40548 L F
.45009 .41546 m .45126 .41323 L .45286 .41469 L 0 .045 .147 r
F
.45009 .41546 m .44849 .41395 L .45126 .41323 L F
.30997 .40874 m .31094 .40618 L .31266 .40797 L 0 .028 .128 r
F
.30997 .40874 m .30825 .40694 L .31094 .40618 L F
.2371 .40797 m .23798 .40527 L .23977 .407 L 0 .027 .126 r
F
.2371 .40797 m .23531 .40623 L .23798 .40527 L F
.80706 .40778 m .80876 .40515 L .81 .40678 L 0 .026 .126 r
F
.80706 .40778 m .80581 .40615 L .80876 .40515 L F
.4129 .41276 m .41401 .41036 L .41564 .41193 L 0 .038 .14 r
F
.4129 .41276 m .41126 .41121 L .41401 .41036 L F
.43149 .41416 m .43263 .41202 L .43424 .41363 L 0 .042 .144 r
F
.43149 .41416 m .42988 .41251 L .43263 .41202 L F
.52728 .41852 m .52858 .41669 L .53009 .4179 L 0 .054 .156 r
F
.52728 .41852 m .52577 .41732 L .52858 .41669 L F
.8142 .40745 m .81591 .40481 L .81715 .40649 L 0 .026 .125 r
F
.8142 .40745 m .81295 .4058 L .81591 .40481 L F
.48728 .41836 m .48851 .41627 L .49007 .41791 L 0 .053 .156 r
F
.48728 .41836 m .48572 .4167 L .48851 .41627 L F
.2771 .40829 m .27803 .4056 L .27978 .40733 L 0 .028 .127 r
F
.2771 .40829 m .27534 .40654 L .27803 .4056 L F
.7528 .40852 m .75443 .40601 L .75573 .40767 L 0 .028 .128 r
F
.7528 .40852 m .75149 .40685 L .75443 .40601 L F
.38716 .4119 m .38825 .4093 L .38989 .41111 L 0 .036 .137 r
F
.38716 .4119 m .38551 .41011 L .38825 .4093 L F
.64858 .41191 m .65005 .40942 L .65145 .41096 L F
.64858 .41191 m .64718 .41036 L .65005 .40942 L F
.86848 .407 m .87028 .40446 L .87147 .40611 L 0 .025 .124 r
F
.86848 .407 m .86729 .40533 L .87028 .40446 L F
.91562 .40681 m .91748 .40415 L .91862 .40582 L 0 .025 .123 r
F
.91562 .40681 m .91447 .40515 L .91748 .40415 L F
.24422 .40784 m .24509 .4053 L .24688 .40697 L 0 .027 .126 r
F
.24422 .40784 m .24243 .40615 L .24509 .4053 L F
.28422 .40805 m .28516 .40536 L .28691 .40705 L 0 .027 .127 r
F
.28422 .40805 m .28247 .40634 L .28516 .40536 L F
.66999 .41082 m .6715 .40841 L .67287 .40994 L 0 .034 .135 r
F
.66999 .41082 m .66861 .40933 L .6715 .40841 L F
.82135 .40726 m .82307 .40466 L .82431 .40636 L 0 .026 .125 r
F
.82135 .40726 m .82011 .40555 L .82307 .40466 L F
.65572 .41162 m .65721 .40926 L .6586 .41074 L 0 .036 .137 r
F
.65572 .41162 m .65433 .41011 L .65721 .40926 L F
.92277 .4065 m .92464 .40389 L .92578 .40557 L 0 .024 .123 r
F
.92277 .4065 m .92163 .40483 L .92464 .40389 L F
.66286 .41127 m .66435 .40881 L .66573 .41029 L 0 .035 .136 r
F
.66286 .41127 m .66147 .40978 L .66435 .40881 L F
.47582 .41682 m .47703 .41431 L .4786 .41598 L 0 .048 .151 r
F
.47582 .41682 m .47425 .41512 L .47703 .41431 L F
.45722 .41544 m .4584 .4134 L .45999 .41474 L 0 .046 .148 r
F
.45722 .41544 m .45563 .41404 L .4584 .4134 L F
.36142 .4111 m .36246 .40863 L .36413 .41033 L 0 .034 .135 r
F
.36142 .4111 m .35974 .4094 L .36246 .40863 L F
.42002 .4127 m .42115 .41036 L .42277 .41198 L 0 .038 .14 r
F
.42002 .4127 m .41839 .4111 L .42115 .41036 L F
.64145 .41256 m .64291 .4099 L .64432 .41146 L 0 .037 .139 r
F
.64145 .41256 m .64005 .41101 L .64291 .4099 L F
.87564 .40683 m .87745 .40428 L .87863 .4059 L 0 .025 .124 r
F
.87564 .40683 m .87446 .40521 L .87745 .40428 L F
.75995 .40843 m .76159 .40593 L .76288 .40752 L 0 .028 .128 r
F
.75995 .40843 m .75866 .4068 L .76159 .40593 L F
.67713 .41064 m .67865 .40821 L .68003 .40981 L 0 .034 .134 r
F
.67713 .41064 m .67576 .40905 L .67865 .40821 L F
.21132 .40748 m .21216 .40486 L .21398 .4065 L 0 .026 .125 r
F
.21132 .40748 m .2095 .40584 L .21216 .40486 L F
.29134 .40788 m .29228 .40538 L .29402 .40703 L 0 .027 .127 r
F
.29134 .40788 m .28959 .40622 L .29228 .40538 L F
.25133 .4077 m .25222 .4051 L .254 .40674 L 0 .027 .126 r
F
.25133 .4077 m .24954 .40605 L .25222 .4051 L F
.62005 .41386 m .62149 .41152 L .62291 .4129 L 0 .041 .143 r
F
.62005 .41386 m .61863 .41251 L .62149 .41152 L F
.82851 .40714 m .83024 .40449 L .83147 .40616 L 0 .026 .125 r
F
.82851 .40714 m .82728 .40546 L .83024 .40449 L F
.34281 .40992 m .34383 .4073 L .34551 .40911 L 0 .032 .132 r
F
.34281 .40992 m .34112 .40813 L .34383 .4073 L F
.21845 .40715 m .21929 .4046 L .2211 .40624 L 0 .026 .125 r
F
.21845 .40715 m .21664 .40552 L .21929 .4046 L F
.31707 .40895 m .31806 .40628 L .31977 .40804 L 0 .029 .129 r
F
.31707 .40895 m .31535 .40718 L .31806 .40628 L F
.7671 .40816 m .76875 .4056 L .77003 .40721 L 0 .028 .128 r
F
.7671 .40816 m .76581 .40656 L .76875 .4056 L F
.92994 .40639 m .93182 .40378 L .93296 .40549 L 0 .024 .123 r
F
.92994 .40639 m .9288 .40468 L .93182 .40378 L F
.62719 .41351 m .62863 .41106 L .63005 .41264 L 0 .04 .142 r
F
.62719 .41351 m .62577 .41198 L .62863 .41106 L F
.8828 .4066 m .88461 .40403 L .88579 .40569 L 0 .025 .123 r
F
.8828 .4066 m .88162 .40496 L .88461 .40403 L F
.36854 .41096 m .3696 .40829 L .37127 .40997 L 0 .034 .135 r
F
.36854 .41096 m .36687 .40931 L .3696 .40829 L F
.83566 .40683 m .8374 .40419 L .83862 .40585 L 0 .025 .124 r
F
.83566 .40683 m .83443 .40516 L .8374 .40419 L F
.25845 .40745 m .25935 .40484 L .26113 .40652 L 0 .027 .126 r
F
.25845 .40745 m .25668 .40578 L .25935 .40484 L F
.63433 .41319 m .63577 .41053 L .63719 .4121 L 0 .039 .141 r
F
.63433 .41319 m .63291 .41161 L .63577 .41053 L F
.39427 .41204 m .39537 .40935 L .39701 .41111 L 0 .037 .138 r
F
.39427 .41204 m .39263 .41028 L .39537 .40935 L F
.53442 .41877 m .53573 .41658 L .53724 .41812 L 0 .055 .157 r
F
.53442 .41877 m .53291 .41724 L .53573 .41658 L F
.59151 .41561 m .5929 .41301 L .59435 .41458 L 0 .046 .148 r
F
.59151 .41561 m .59005 .41406 L .5929 .41301 L F
.77425 .4079 m .77591 .40545 L .77719 .40706 L 0 .028 .127 r
F
.77425 .4079 m .77297 .40631 L .77591 .40545 L F
.69856 .40974 m .7001 .40722 L .70145 .40881 L 0 .032 .132 r
F
.69856 .40974 m .69721 .40818 L .7001 .40722 L F
.4014 .41173 m .4025 .40942 L .40414 .41097 L 0 .037 .138 r
F
.4014 .41173 m .39976 .41018 L .4025 .40942 L F
.37567 .41076 m .37673 .40823 L .37839 .40997 L 0 .034 .135 r
F
.37567 .41076 m .374 .40906 L .37673 .40823 L F
.84281 .40662 m .84458 .40412 L .84579 .40576 L 0 .025 .124 r
F
.84281 .40662 m .84159 .40499 L .84458 .40412 L F
.59865 .41534 m .60005 .41298 L .6015 .41453 L 0 .045 .148 r
F
.59865 .41534 m .5972 .41378 L .60005 .41298 L F
.68429 .41059 m .68582 .40817 L .68718 .40975 L 0 .034 .135 r
F
.68429 .41059 m .68292 .409 L .68582 .40817 L F
.61292 .41456 m .61435 .41225 L .61577 .41354 L 0 .044 .146 r
F
.61292 .41456 m .6115 .41331 L .61435 .41225 L F
.32418 .40886 m .32518 .40624 L .32689 .40795 L 0 .03 .13 r
F
.32418 .40886 m .32247 .40713 L .32518 .40624 L F
.88997 .40649 m .8918 .40398 L .89297 .40564 L 0 .025 .124 r
F
.88997 .40649 m .88879 .40483 L .8918 .40398 L F
.69143 .41026 m .69296 .40762 L .69431 .40919 L 0 .033 .134 r
F
.69143 .41026 m .69007 .40869 L .69296 .40762 L F
.29844 .40791 m .29941 .40513 L .30114 .40693 L 0 .028 .127 r
F
.29844 .40791 m .29671 .40612 L .29941 .40513 L F
.7057 .40951 m .70726 .40689 L .7086 .40852 L 0 .031 .132 r
F
.7057 .40951 m .70436 .40788 L .70726 .40689 L F
.60579 .41505 m .60721 .41286 L .60864 .41418 L 0 .045 .148 r
F
.60579 .41505 m .60435 .4137 L .60721 .41286 L F
.46434 .41566 m .46554 .41331 L .46712 .41495 L 0 .047 .149 r
F
.46434 .41566 m .46276 .41403 L .46554 .41331 L F
.22555 .40715 m .22639 .40465 L .2282 .40636 L 0 .026 .126 r
F
.22555 .40715 m .22375 .40544 L .22639 .40465 L F
.71284 .40914 m .7144 .4065 L .71574 .40813 L 0 .03 .131 r
F
.71284 .40914 m .7115 .40751 L .7144 .4065 L F
.49441 .41885 m .49565 .41695 L .4972 .41836 L 0 .056 .159 r
F
.49441 .41885 m .49286 .41743 L .49565 .41695 L F
.4386 .41471 m .43975 .41258 L .44136 .41412 L 0 .045 .147 r
F
.4386 .41471 m .43699 .41313 L .43975 .41258 L F
.71998 .40878 m .72155 .40609 L .72288 .40775 L 0 .03 .13 r
F
.71998 .40878 m .71864 .40711 L .72155 .40609 L F
.26556 .4074 m .26648 .40469 L .26824 .4065 L 0 .027 .126 r
F
.26556 .4074 m .2638 .40559 L .26648 .40469 L F
.58438 .41632 m .58576 .41384 L .58722 .41519 L 0 .048 .151 r
F
.58438 .41632 m .58292 .41497 L .58576 .41384 L F
.78141 .40782 m .78307 .40521 L .78434 .40684 L 0 .028 .127 r
F
.78141 .40782 m .78013 .40621 L .78307 .40521 L F
.48294 .41713 m .48416 .41504 L .48572 .4167 L 0 .051 .154 r
F
.48294 .41713 m .48138 .41544 L .48416 .41504 L F
.34991 .41001 m .35095 .40727 L .35263 .4091 L 0 .032 .133 r
F
.34991 .41001 m .34823 .40819 L .35095 .40727 L F
.84997 .40649 m .85174 .40391 L .85295 .40555 L 0 .025 .124 r
F
.84997 .40649 m .84876 .40485 L .85174 .40391 L F
.72712 .40847 m .72871 .40597 L .73004 .40759 L 0 .029 .129 r
F
.72712 .40847 m .72579 .40683 L .72871 .40597 L F
.54156 .41878 m .54287 .41647 L .54438 .41788 L 0 .055 .158 r
F
.54156 .41878 m .54005 .4173 L .54287 .41647 L F
.42713 .41306 m .42827 .41083 L .42988 .41251 L 0 .04 .142 r
F
.42713 .41306 m .42552 .41141 L .42827 .41083 L F
.78855 .40753 m .79022 .40488 L .79149 .40656 L 0 .027 .127 r
F
.78855 .40753 m .78728 .40585 L .79022 .40488 L F
.30556 .40775 m .30653 .40514 L .30825 .40694 L 0 .028 .127 r
F
.30556 .40775 m .30384 .40595 L .30653 .40514 L F
.5487 .41844 m .55002 .41617 L .55152 .41755 L 0 .054 .157 r
F
.5487 .41844 m .5472 .41701 L .55002 .41617 L F
.55583 .41805 m .55717 .41586 L .55866 .41725 L 0 .054 .156 r
F
.55583 .41805 m .55434 .41667 L .55717 .41586 L F
.3313 .40878 m .33231 .40617 L .33401 .40791 L 0 .03 .13 r
F
.3313 .40878 m .3296 .40706 L .33231 .40617 L F
.89714 .40642 m .89897 .40378 L .90013 .40546 L 0 .025 .124 r
F
.89714 .40642 m .89597 .40474 L .89897 .40378 L F
.85713 .40626 m .85891 .40373 L .86011 .40539 L F
.85713 .40626 m .85592 .40461 L .85891 .40373 L F
.74141 .40788 m .74302 .40535 L .74433 .40693 L 0 .028 .128 r
F
.74141 .40788 m .7401 .40631 L .74302 .40535 L F
.73427 .4083 m .73587 .40573 L .73719 .4073 L 0 .029 .129 r
F
.73427 .4083 m .73296 .40671 L .73587 .40573 L F
.40852 .41187 m .40963 .40965 L .41126 .41121 L 0 .038 .139 r
F
.40852 .41187 m .40688 .41031 L .40963 .40965 L F
.79571 .40734 m .79739 .40475 L .79866 .40644 L 0 .027 .126 r
F
.79571 .40734 m .79444 .40566 L .79739 .40475 L F
.90429 .40616 m .90614 .4036 L .9073 .40527 L 0 .025 .123 r
F
.90429 .40616 m .90313 .40449 L .90614 .4036 L F
.38278 .41092 m .38386 .40833 L .38551 .41011 L 0 .035 .136 r
F
.38278 .41092 m .38112 .40917 L .38386 .40833 L F
.23265 .4072 m .23352 .40448 L .23531 .40623 L 0 .027 .126 r
F
.23265 .4072 m .23086 .40544 L .23352 .40448 L F
.50868 .4185 m .50994 .41661 L .51148 .41776 L 0 .056 .158 r
F
.50868 .4185 m .50714 .41729 L .50994 .41661 L F
.56297 .41791 m .56432 .41575 L .56581 .41719 L 0 .054 .156 r
F
.56297 .41791 m .56149 .4165 L .56432 .41575 L F
.27267 .40742 m .27359 .40478 L .27534 .40654 L 0 .027 .127 r
F
.27267 .40742 m .27091 .40564 L .27359 .40478 L F
.51582 .41813 m .51709 .41638 L .51862 .41741 L 0 .055 .158 r
F
.51582 .41813 m .51429 .41706 L .51709 .41638 L F
.74856 .40768 m .75019 .40522 L .75149 .40685 L 0 .028 .128 r
F
.74856 .40768 m .74726 .40608 L .75019 .40522 L F
.50154 .41898 m .50279 .41691 L .50434 .41814 L 0 .057 .159 r
F
.50154 .41898 m .49999 .41773 L .50279 .41691 L F
.57725 .4172 m .57862 .41486 L .58008 .41608 L 0 .051 .154 r
F
.57725 .4172 m .57579 .41596 L .57862 .41486 L F
.44573 .41482 m .44689 .41247 L .44849 .41395 L 0 .045 .147 r
F
.44573 .41482 m .44412 .4133 L .44689 .41247 L F
.57011 .41763 m .57148 .41564 L .57295 .41688 L 0 .053 .156 r
F
.57011 .41763 m .56864 .41642 L .57148 .41564 L F
.80286 .40715 m .80455 .4045 L .80581 .40615 L 0 .027 .126 r
F
.80286 .40715 m .8016 .40548 L .80455 .4045 L F
.35702 .41014 m .35806 .4076 L .35974 .4094 L 0 .034 .134 r
F
.35702 .41014 m .35535 .40832 L .35806 .4076 L F
.81 .40678 m .81171 .40414 L .81295 .4058 L 0 .026 .125 r
F
.81 .40678 m .80876 .40515 L .81171 .40414 L F
.52296 .41788 m .52424 .41628 L .52577 .41732 L 0 .055 .158 r
F
.52296 .41788 m .52143 .41684 L .52424 .41628 L F
.8643 .4062 m .86609 .40367 L .86729 .40533 L 0 .025 .124 r
F
.8643 .4062 m .8631 .40453 L .86609 .40367 L F
.23977 .407 m .24064 .40444 L .24243 .40615 L 0 .027 .126 r
F
.23977 .407 m .23798 .40527 L .24064 .40444 L F
.47147 .41594 m .47268 .41343 L .47425 .41512 L 0 .048 .15 r
F
.47147 .41594 m .46989 .41422 L .47268 .41343 L F
.91146 .40605 m .91332 .40348 L .91447 .40515 L 0 .025 .123 r
F
.91146 .40605 m .91031 .40439 L .91332 .40348 L F
.81715 .40649 m .81887 .40387 L .82011 .40555 L 0 .026 .125 r
F
.81715 .40649 m .81591 .40481 L .81887 .40387 L F
.33841 .4089 m .33942 .40633 L .34112 .40813 L 0 .031 .131 r
F
.33841 .4089 m .33672 .40712 L .33942 .40633 L F
.27978 .40733 m .28072 .40462 L .28247 .40634 L 0 .027 .127 r
F
.27978 .40733 m .27803 .4056 L .28072 .40462 L F
.45286 .41469 m .45403 .41264 L .45563 .41404 L 0 .046 .148 r
F
.45286 .41469 m .45126 .41323 L .45403 .41264 L F
.31266 .40797 m .31364 .40539 L .31535 .40718 L 0 .029 .129 r
F
.31266 .40797 m .31094 .40618 L .31364 .40539 L F
.41564 .41193 m .41677 .4095 L .41839 .4111 L 0 .038 .14 r
F
.41564 .41193 m .41401 .41036 L .41677 .4095 L F
.65145 .41096 m .65293 .4086 L .65433 .41011 L 0 .036 .137 r
F
.65145 .41096 m .65005 .40942 L .65293 .4086 L F
.91862 .40582 m .92048 .40316 L .92163 .40483 L 0 .024 .123 r
F
.91862 .40582 m .91748 .40415 L .92048 .40316 L F
.28691 .40705 m .28784 .40455 L .28959 .40622 L 0 .027 .127 r
F
.28691 .40705 m .28516 .40536 L .28784 .40455 L F
.75573 .40767 m .75736 .40518 L .75866 .4068 L 0 .029 .128 r
F
.75573 .40767 m .75443 .40601 L .75736 .40518 L F
.87147 .40611 m .87328 .40359 L .87446 .40521 L 0 .025 .124 r
F
.87147 .40611 m .87028 .40446 L .87328 .40359 L F
.64432 .41146 m .64578 .40879 L .64718 .41036 L 0 .037 .138 r
F
.64432 .41146 m .64291 .4099 L .64578 .40879 L F
.66573 .41029 m .66724 .40785 L .66861 .40933 L 0 .035 .136 r
F
.66573 .41029 m .66435 .40881 L .66724 .40785 L F
.38989 .41111 m .39098 .40845 L .39263 .41028 L 0 .036 .137 r
F
.38989 .41111 m .38825 .4093 L .39098 .40845 L F
.82431 .40636 m .82604 .40377 L .82728 .40546 L 0 .026 .125 r
F
.82431 .40636 m .82307 .40466 L .82604 .40377 L F
.92578 .40557 m .92766 .40297 L .9288 .40468 L 0 .024 .123 r
F
.92578 .40557 m .92464 .40389 L .92766 .40297 L F
.67287 .40994 m .67439 .40749 L .67576 .40905 L 0 .034 .135 r
F
.67287 .40994 m .6715 .40841 L .67439 .40749 L F
.24688 .40697 m .24776 .4044 L .24954 .40605 L 0 .027 .126 r
F
.24688 .40697 m .24509 .4053 L .24776 .4044 L F
.6586 .41074 m .66009 .40833 L .66147 .40978 L 0 .036 .137 r
F
.6586 .41074 m .65721 .40926 L .66009 .40833 L F
.53009 .4179 m .53139 .416 L .53291 .41724 L 0 .055 .158 r
F
.53009 .4179 m .52858 .41669 L .53139 .416 L F
.4786 .41598 m .47981 .41381 L .48138 .41544 L 0 .049 .152 r
F
.4786 .41598 m .47703 .41431 L .47981 .41381 L F
.87863 .4059 m .88044 .40333 L .88162 .40496 L 0 .025 .124 r
F
.87863 .4059 m .87745 .40428 L .88044 .40333 L F
.21398 .4065 m .21481 .40387 L .21664 .40552 L 0 .026 .125 r
F
.21398 .4065 m .21216 .40486 L .21481 .40387 L F
.43424 .41363 m .43538 .41155 L .43699 .41313 L 0 .043 .146 r
F
.43424 .41363 m .43263 .41202 L .43538 .41155 L F
.76288 .40752 m .76452 .40496 L .76581 .40656 L 0 .028 .128 r
F
.76288 .40752 m .76159 .40593 L .76452 .40496 L F
.254 .40674 m .25489 .40414 L .25668 .40578 L 0 .027 .126 r
F
.254 .40674 m .25222 .4051 L .25489 .40414 L F
.63719 .4121 m .63864 .40944 L .64005 .41101 L 0 .039 .14 r
F
.63719 .4121 m .63577 .41053 L .63864 .40944 L F
.83147 .40616 m .8332 .40349 L .83443 .40516 L 0 .026 .124 r
F
.83147 .40616 m .83024 .40449 L .8332 .40349 L F
.62291 .4129 m .62435 .41056 L .62577 .41198 L 0 .041 .143 r
F
.62291 .4129 m .62149 .41152 L .62435 .41056 L F
.36413 .41033 m .36519 .40761 L .36687 .40931 L 0 .034 .136 r
F
.36413 .41033 m .36246 .40863 L .36519 .40761 L F
.37127 .40997 m .37234 .40734 L .374 .40906 L 0 .034 .135 r
F
.37127 .40997 m .3696 .40829 L .37234 .40734 L F
.77003 .40721 m .77168 .4047 L .77297 .40631 L 0 .028 .128 r
F
.77003 .40721 m .76875 .4056 L .77168 .4047 L F
.45999 .41474 m .46117 .41268 L .46276 .41403 L 0 .047 .149 r
F
.45999 .41474 m .4584 .4134 L .46117 .41268 L F
.49007 .41791 m .4913 .41581 L .49286 .41743 L 0 .055 .157 r
F
.49007 .41791 m .48851 .41627 L .4913 .41581 L F
.29402 .40703 m .29497 .40448 L .29671 .40612 L 0 .028 .127 r
F
.29402 .40703 m .29228 .40538 L .29497 .40448 L F
.42277 .41198 m .4239 .40975 L .42552 .41141 L 0 .039 .141 r
F
.42277 .41198 m .42115 .41036 L .4239 .40975 L F
.2211 .40624 m .22193 .40379 L .22375 .40544 L 0 .026 .125 r
F
.2211 .40624 m .21929 .4046 L .22193 .40379 L F
.83862 .40585 m .84038 .40334 L .84159 .40499 L 0 .025 .124 r
F
.83862 .40585 m .8374 .40419 L .84038 .40334 L F
.68003 .40981 m .68155 .40739 L .68292 .409 L 0 .034 .135 r
F
.68003 .40981 m .67865 .40821 L .68155 .40739 L F
.31977 .40804 m .32076 .40539 L .32247 .40713 L 0 .03 .13 r
F
.31977 .40804 m .31806 .40628 L .32076 .40539 L F
.59435 .41458 m .59575 .41222 L .5972 .41378 L 0 .046 .148 r
F
.59435 .41458 m .5929 .41301 L .59575 .41222 L F
.88579 .40569 m .88762 .40317 L .88879 .40483 L 0 .025 .124 r
F
.88579 .40569 m .88461 .40403 L .88762 .40317 L F
.63005 .41264 m .63149 .41002 L .63291 .41161 L 0 .04 .142 r
F
.63005 .41264 m .62863 .41106 L .63149 .41002 L F
.26113 .40652 m .26203 .40391 L .2638 .40559 L 0 .027 .126 r
F
.26113 .40652 m .25935 .40484 L .26203 .40391 L F
.34551 .40911 m .34655 .40637 L .34823 .40819 L 0 .032 .132 r
F
.34551 .40911 m .34383 .4073 L .34655 .40637 L F
.39701 .41111 m .39812 .40843 L .39976 .41018 L 0 .037 .138 r
F
.39701 .41111 m .39537 .40935 L .39812 .40843 L F
.61577 .41354 m .6172 .41119 L .61863 .41251 L 0 .043 .145 r
F
.61577 .41354 m .61435 .41225 L .6172 .41119 L F
.69431 .40919 m .69585 .4066 L .69721 .40818 L 0 .032 .133 r
F
.69431 .40919 m .69296 .40762 L .69585 .4066 L F
.70145 .40881 m .70301 .40626 L .70436 .40788 L 0 .032 .132 r
F
.70145 .40881 m .7001 .40722 L .70301 .40626 L F
.77719 .40706 m .77886 .40459 L .78013 .40621 L 0 .028 .128 r
F
.77719 .40706 m .77591 .40545 L .77886 .40459 L F
.58722 .41519 m .5886 .4127 L .59005 .41406 L 0 .047 .15 r
F
.58722 .41519 m .58576 .41384 L .5886 .4127 L F
.30114 .40693 m .30212 .40414 L .30384 .40595 L 0 .027 .127 r
F
.30114 .40693 m .29941 .40513 L .30212 .40414 L F
.7086 .40852 m .71016 .40589 L .7115 .40751 L 0 .031 .131 r
F
.7086 .40852 m .70726 .40689 L .71016 .40589 L F
.71574 .40813 m .71731 .40546 L .71864 .40711 L 0 .03 .13 r
F
.71574 .40813 m .7144 .4065 L .71731 .40546 L F
.84579 .40576 m .84755 .40322 L .84876 .40485 L 0 .025 .124 r
F
.84579 .40576 m .84458 .40412 L .84755 .40322 L F
.72288 .40775 m .72446 .40518 L .72579 .40683 L 0 .029 .129 r
F
.72288 .40775 m .72155 .40609 L .72446 .40518 L F
.32689 .40795 m .32789 .40538 L .3296 .40706 L 0 .03 .13 r
F
.32689 .40795 m .32518 .40624 L .32789 .40538 L F
.68718 .40975 m .68871 .40711 L .69007 .40869 L 0 .034 .135 r
F
.68718 .40975 m .68582 .40817 L .68871 .40711 L F
.37839 .40997 m .37947 .4074 L .38112 .40917 L 0 .034 .136 r
F
.37839 .40997 m .37673 .40823 L .37947 .4074 L F
.40414 .41097 m .40524 .40875 L .40688 .41031 L 0 .037 .139 r
F
.40414 .41097 m .4025 .40942 L .40524 .40875 L F
.6015 .41453 m .60291 .41216 L .60435 .4137 L 0 .046 .148 r
F
.6015 .41453 m .60005 .41298 L .60291 .41216 L F
.89297 .40564 m .8948 .40306 L .89597 .40474 L 0 .025 .124 r
F
.89297 .40564 m .8918 .40398 L .8948 .40306 L F
.53724 .41812 m .53855 .41582 L .54005 .4173 L 0 .056 .158 r
F
.53724 .41812 m .53573 .41658 L .53855 .41582 L F
.78434 .40684 m .78601 .40419 L .78728 .40585 L 0 .028 .127 r
F
.78434 .40684 m .78307 .40521 L .78601 .40419 L F
.60864 .41418 m .61006 .41201 L .6115 .41331 L 0 .045 .148 r
F
.60864 .41418 m .60721 .41286 L .61006 .41201 L F
.26824 .4065 m .26915 .40385 L .27091 .40564 L 0 .027 .126 r
F
.26824 .4065 m .26648 .40469 L .26915 .40385 L F
.35263 .4091 m .35367 .40651 L .35535 .40832 L 0 .033 .133 r
F
.35263 .4091 m .35095 .40727 L .35367 .40651 L F
.85295 .40555 m .85472 .40297 L .85592 .40461 L 0 .025 .124 r
F
.85295 .40555 m .85174 .40391 L .85472 .40297 L F
.2282 .40636 m .22905 .40372 L .23086 .40544 L 0 .027 .126 r
F
.2282 .40636 m .22639 .40465 L .22905 .40372 L F
.79149 .40656 m .79317 .40396 L .79444 .40566 L F
.79149 .40656 m .79022 .40488 L .79317 .40396 L F
.54438 .41788 m .5457 .41566 L .5472 .41701 L 0 .055 .158 r
F
.54438 .41788 m .54287 .41647 L .5457 .41566 L F
.73004 .40759 m .73164 .40512 L .73296 .40671 L 0 .03 .13 r
F
.73004 .40759 m .72871 .40597 L .73164 .40512 L F
.46712 .41495 m .46832 .41258 L .46989 .41422 L 0 .047 .15 r
F
.46712 .41495 m .46554 .41331 L .46832 .41258 L F
.90013 .40546 m .90197 .40281 L .90313 .40449 L 0 .025 .123 r
F
.90013 .40546 m .89897 .40378 L .90197 .40281 L F
.55152 .41755 m .55285 .41534 L .55434 .41667 L 0 .055 .157 r
F
.55152 .41755 m .55002 .41617 L .55285 .41534 L F
.73719 .4073 m .73879 .40474 L .7401 .40631 L 0 .029 .129 r
F
.73719 .4073 m .73587 .40573 L .73879 .40474 L F
.33401 .40791 m .33502 .40537 L .33672 .40712 L 0 .03 .13 r
F
.33401 .40791 m .33231 .40617 L .33502 .40537 L F
.74433 .40693 m .74595 .40448 L .74726 .40608 L 0 .028 .128 r
F
.74433 .40693 m .74302 .40535 L .74595 .40448 L F
.30825 .40694 m .30922 .40438 L .31094 .40618 L F
.30825 .40694 m .30653 .40514 L .30922 .40438 L F
.55866 .41725 m .56 .41507 L .56149 .4165 L 0 .054 .157 r
F
.55866 .41725 m .55717 .41586 L .56 .41507 L F
.58008 .41608 m .58146 .41376 L .58292 .41497 L 0 .051 .153 r
F
.58008 .41608 m .57862 .41486 L .58146 .41376 L F
.86011 .40539 m .8619 .40285 L .8631 .40453 L 0 .025 .124 r
F
.86011 .40539 m .85891 .40373 L .8619 .40285 L F
.44136 .41412 m .44252 .4118 L .44412 .4133 L 0 .045 .148 r
F
.44136 .41412 m .43975 .41258 L .44252 .4118 L F
.23531 .40623 m .23619 .40354 L .23798 .40527 L 0 .027 .126 r
F
.23531 .40623 m .23352 .40448 L .23619 .40354 L F
.79866 .40644 m .80035 .40381 L .8016 .40548 L F
.79866 .40644 m .79739 .40475 L .80035 .40381 L F
.9073 .40527 m .90916 .40272 L .91031 .40439 L 0 .025 .123 r
F
.9073 .40527 m .90614 .4036 L .90916 .40272 L F
.4972 .41836 m .49844 .41634 L .49999 .41773 L 0 .058 .16 r
F
.4972 .41836 m .49565 .41695 L .49844 .41634 L F
.27534 .40654 m .27627 .40385 L .27803 .4056 L 0 .027 .127 r
F
.27534 .40654 m .27359 .40478 L .27627 .40385 L F
.38551 .41011 m .3866 .40748 L .38825 .4093 L 0 .035 .137 r
F
.38551 .41011 m .38386 .40833 L .3866 .40748 L F
.80581 .40615 m .80751 .40352 L .80876 .40515 L 0 .027 .126 r
F
.80581 .40615 m .80455 .4045 L .80751 .40352 L F
.42988 .41251 m .43102 .41031 L .43263 .41202 L 0 .042 .144 r
F
.42988 .41251 m .42827 .41083 L .43102 .41031 L F
.81295 .4058 m .81466 .40313 L .81591 .40481 L 0 .026 .125 r
F
.81295 .4058 m .81171 .40414 L .81466 .40313 L F
.48572 .4167 m .48695 .41463 L .48851 .41627 L 0 .053 .156 r
F
.48572 .4167 m .48416 .41504 L .48695 .41463 L F
.44849 .41395 m .44966 .4118 L .45126 .41323 L 0 .046 .148 r
F
.44849 .41395 m .44689 .41247 L .44966 .4118 L F
.50434 .41814 m .5056 .41609 L .50714 .41729 L 0 .057 .16 r
F
.50434 .41814 m .50279 .41691 L .5056 .41609 L F
.75149 .40685 m .75312 .40438 L .75443 .40601 L 0 .029 .128 r
F
.75149 .40685 m .75019 .40522 L .75312 .40438 L F
.41126 .41121 m .41238 .40876 L .41401 .41036 L 0 .038 .14 r
F
.41126 .41121 m .40963 .40965 L .41238 .40876 L F
.51148 .41776 m .51275 .41595 L .51429 .41706 L 0 .057 .159 r
F
.51148 .41776 m .50994 .41661 L .51275 .41595 L F
.56581 .41719 m .56716 .41493 L .56864 .41642 L 0 .054 .157 r
F
.56581 .41719 m .56432 .41575 L .56716 .41493 L F
.51862 .41741 m .5199 .4158 L .52143 .41684 L 0 .056 .159 r
F
.51862 .41741 m .51709 .41638 L .5199 .4158 L F
.86729 .40533 m .86909 .40282 L .87028 .40446 L 0 .025 .124 r
F
.86729 .40533 m .86609 .40367 L .86909 .40282 L F
.91447 .40515 m .91633 .40249 L .91748 .40415 L 0 .025 .123 r
F
.91447 .40515 m .91332 .40348 L .91633 .40249 L F
.28247 .40634 m .28341 .40366 L .28516 .40536 L 0 .027 .127 r
F
.28247 .40634 m .28072 .40462 L .28341 .40366 L F
.82011 .40555 m .82183 .40298 L .82307 .40466 L 0 .026 .125 r
F
.82011 .40555 m .81887 .40387 L .82183 .40298 L F
.24243 .40615 m .2433 .40361 L .24509 .4053 L 0 .027 .126 r
F
.24243 .40615 m .24064 .40444 L .2433 .40361 L F
.57295 .41688 m .57432 .41472 L .57579 .41596 L 0 .054 .156 r
F
.57295 .41688 m .57148 .41564 L .57432 .41472 L F
.64718 .41036 m .64865 .40785 L .65005 .40942 L 0 .036 .138 r
F
.64718 .41036 m .64578 .40879 L .64865 .40785 L F
.47425 .41512 m .47546 .41264 L .47703 .41431 L 0 .048 .151 r
F
.47425 .41512 m .47268 .41343 L .47546 .41264 L F
.92163 .40483 m .92349 .40219 L .92464 .40389 L 0 .024 .123 r
F
.92163 .40483 m .92048 .40316 L .92349 .40219 L F
.35974 .4094 m .36078 .40685 L .36246 .40863 L 0 .034 .135 r
F
.35974 .4094 m .35806 .4076 L .36078 .40685 L F
.34112 .40813 m .34214 .40549 L .34383 .4073 L 0 .031 .132 r
F
.34112 .40813 m .33942 .40633 L .34214 .40549 L F
.65433 .41011 m .65582 .40778 L .65721 .40926 L 0 .036 .138 r
F
.65433 .41011 m .65293 .4086 L .65582 .40778 L F
.41839 .4111 m .41952 .40872 L .42115 .41036 L 0 .039 .14 r
F
.41839 .4111 m .41677 .4095 L .41952 .40872 L F
.66861 .40933 m .67012 .40688 L .6715 .40841 L 0 .034 .136 r
F
.66861 .40933 m .66724 .40785 L .67012 .40688 L F
.31535 .40718 m .31634 .40451 L .31806 .40628 L 0 .029 .129 r
F
.31535 .40718 m .31364 .40539 L .31634 .40451 L F
.87446 .40521 m .87627 .40266 L .87745 .40428 L 0 .025 .124 r
F
.87446 .40521 m .87328 .40359 L .87627 .40266 L F
.75866 .4068 m .7603 .40432 L .76159 .40593 L 0 .029 .129 r
F
.75866 .4068 m .75736 .40518 L .7603 .40432 L F
.66147 .40978 m .66297 .4074 L .66435 .40881 L 0 .036 .137 r
F
.66147 .40978 m .66009 .40833 L .66297 .4074 L F
.28959 .40622 m .29053 .40373 L .29228 .40538 L 0 .028 .127 r
F
.28959 .40622 m .28784 .40455 L .29053 .40373 L F
.52577 .41732 m .52706 .41562 L .52858 .41669 L 0 .056 .159 r
F
.52577 .41732 m .52424 .41628 L .52706 .41562 L F
.2095 .40584 m .21033 .4032 L .21216 .40486 L 0 .027 .126 r
F
.2095 .40584 m .20767 .40417 L .21033 .4032 L F
.82728 .40546 m .82901 .4028 L .83024 .40449 L 0 .026 .125 r
F
.82728 .40546 m .82604 .40377 L .82901 .4028 L F
.24954 .40605 m .25043 .40344 L .25222 .4051 L 0 .027 .126 r
F
.24954 .40605 m .24776 .4044 L .25043 .40344 L F
.64005 .41101 m .6415 .40832 L .64291 .4099 L 0 .038 .14 r
F
.64005 .41101 m .63864 .40944 L .6415 .40832 L F
.9288 .40468 m .93068 .40205 L .93182 .40378 L 0 .024 .123 r
F
.9288 .40468 m .92766 .40297 L .93068 .40205 L F
.67576 .40905 m .67728 .40662 L .67865 .40821 L 0 .034 .135 r
F
.67576 .40905 m .67439 .40749 L .67728 .40662 L F
.21664 .40552 m .21747 .40295 L .21929 .4046 L 0 .026 .125 r
F
.21664 .40552 m .21481 .40387 L .21747 .40295 L F
.45563 .41404 m .4568 .41205 L .4584 .4134 L 0 .047 .149 r
F
.45563 .41404 m .45403 .41264 L .4568 .41205 L F
.39263 .41028 m .39373 .40753 L .39537 .40935 L 0 .036 .138 r
F
.39263 .41028 m .39098 .40845 L .39373 .40753 L F
.36687 .40931 m .36793 .40658 L .3696 .40829 L 0 .034 .135 r
F
.36687 .40931 m .36519 .40761 L .36793 .40658 L F
.88162 .40496 m .88344 .40239 L .88461 .40403 L 0 .025 .124 r
F
.88162 .40496 m .88044 .40333 L .88344 .40239 L F
.83443 .40516 m .83617 .40253 L .8374 .40419 L F
.83443 .40516 m .8332 .40349 L .83617 .40253 L F
.76581 .40656 m .76746 .40399 L .76875 .4056 L 0 .028 .128 r
F
.76581 .40656 m .76452 .40496 L .76746 .40399 L F
.25668 .40578 m .25757 .4032 L .25935 .40484 L 0 .027 .126 r
F
.25668 .40578 m .25489 .40414 L .25757 .4032 L F
.62577 .41198 m .62721 .4096 L .62863 .41106 L 0 .041 .143 r
F
.62577 .41198 m .62435 .41056 L .62721 .4096 L F
.63291 .41161 m .63436 .40895 L .63577 .41053 L 0 .04 .142 r
F
.63291 .41161 m .63149 .41002 L .63436 .40895 L F
.374 .40906 m .37507 .40649 L .37673 .40823 L 0 .034 .135 r
F
.374 .40906 m .37234 .40734 L .37507 .40649 L F
.77297 .40631 m .77463 .40384 L .77591 .40545 L 0 .028 .128 r
F
.77297 .40631 m .77168 .4047 L .77463 .40384 L F
.29671 .40612 m .29767 .4035 L .29941 .40513 L 0 .028 .127 r
F
.29671 .40612 m .29497 .40448 L .29767 .4035 L F
.59005 .41406 m .59144 .41165 L .5929 .41301 L 0 .047 .149 r
F
.59005 .41406 m .5886 .4127 L .59144 .41165 L F
.32247 .40713 m .32347 .40453 L .32518 .40624 L 0 .03 .13 r
F
.32247 .40713 m .32076 .40539 L .32347 .40453 L F
.53291 .41724 m .53421 .41532 L .53573 .41658 L 0 .056 .159 r
F
.53291 .41724 m .53139 .416 L .53421 .41532 L F
.61863 .41251 m .62006 .41016 L .62149 .41152 L 0 .043 .145 r
F
.61863 .41251 m .6172 .41119 L .62006 .41016 L F
.84159 .40499 m .84336 .40249 L .84458 .40412 L 0 .025 .124 r
F
.84159 .40499 m .84038 .40334 L .84336 .40249 L F
.2638 .40559 m .26471 .40301 L .26648 .40469 L 0 .027 .126 r
F
.2638 .40559 m .26203 .40391 L .26471 .40301 L F
.69721 .40818 m .69875 .40563 L .7001 .40722 L 0 .032 .133 r
F
.69721 .40818 m .69585 .4066 L .69875 .40563 L F
.34823 .40819 m .34927 .40544 L .35095 .40727 L 0 .032 .132 r
F
.34823 .40819 m .34655 .40637 L .34927 .40544 L F
.39976 .41018 m .40086 .40767 L .4025 .40942 L 0 .037 .138 r
F
.39976 .41018 m .39812 .40843 L .40086 .40767 L F
.88879 .40483 m .89063 .40231 L .8918 .40398 L 0 .025 .124 r
F
.88879 .40483 m .88762 .40317 L .89063 .40231 L F
.68292 .409 m .68445 .40655 L .68582 .40817 L 0 .034 .135 r
F
.68292 .409 m .68155 .40739 L .68445 .40655 L F
.22375 .40544 m .22458 .40298 L .22639 .40465 L 0 .027 .126 r
F
.22375 .40544 m .22193 .40379 L .22458 .40298 L F
.5972 .41378 m .5986 .41143 L .60005 .41298 L 0 .046 .149 r
F
.5972 .41378 m .59575 .41222 L .5986 .41143 L F
.70436 .40788 m .70591 .40527 L .70726 .40689 L 0 .032 .132 r
F
.70436 .40788 m .70301 .40626 L .70591 .40527 L F
.46276 .41403 m .46395 .41195 L .46554 .41331 L 0 .047 .15 r
F
.46276 .41403 m .46117 .41268 L .46395 .41195 L F
.69007 .40869 m .6916 .40605 L .69296 .40762 L 0 .033 .134 r
F
.69007 .40869 m .68871 .40711 L .6916 .40605 L F
.71864 .40711 m .72021 .40442 L .72155 .40609 L 0 .03 .13 r
F
.71864 .40711 m .71731 .40546 L .72021 .40442 L F
.7115 .40751 m .71306 .40487 L .7144 .4065 L 0 .031 .131 r
F
.7115 .40751 m .71016 .40589 L .71306 .40487 L F
.48138 .41544 m .4826 .41345 L .48416 .41504 L 0 .051 .154 r
F
.48138 .41544 m .47981 .41381 L .4826 .41345 L F
.30384 .40595 m .30481 .40334 L .30653 .40514 L 0 .027 .127 r
F
.30384 .40595 m .30212 .40414 L .30481 .40334 L F
.43699 .41313 m .43814 .41103 L .43975 .41258 L 0 .045 .147 r
F
.43699 .41313 m .43538 .41155 L .43814 .41103 L F
.78013 .40621 m .7818 .40357 L .78307 .40521 L 0 .028 .128 r
F
.78013 .40621 m .77886 .40459 L .7818 .40357 L F
.72579 .40683 m .72739 .40435 L .72871 .40597 L 0 .03 .13 r
F
.72579 .40683 m .72446 .40518 L .72739 .40435 L F
.84876 .40485 m .85053 .40227 L .85174 .40391 L 0 .025 .124 r
F
.84876 .40485 m .84755 .40322 L .85053 .40227 L F
.78728 .40585 m .78895 .4032 L .79022 .40488 L 0 .027 .127 r
F
.78728 .40585 m .78601 .40419 L .78895 .4032 L F
.42552 .41141 m .42665 .40915 L .42827 .41083 L 0 .041 .143 r
F
.42552 .41141 m .4239 .40975 L .42665 .40915 L F
.3296 .40706 m .3306 .40451 L .33231 .40617 L 0 .03 .13 r
F
.3296 .40706 m .32789 .40538 L .3306 .40451 L F
.89597 .40474 m .8978 .40208 L .89897 .40378 L 0 .025 .124 r
F
.89597 .40474 m .8948 .40306 L .8978 .40208 L F
.49286 .41743 m .49409 .41535 L .49565 .41695 L 0 .057 .159 r
F
.49286 .41743 m .4913 .41581 L .49409 .41535 L F
.6115 .41331 m .61292 .41092 L .61435 .41225 L 0 .045 .148 r
F
.6115 .41331 m .61006 .41201 L .61292 .41092 L F
.60435 .4137 m .60576 .41133 L .60721 .41286 L 0 .046 .149 r
F
.60435 .4137 m .60291 .41216 L .60576 .41133 L F
.38112 .40917 m .3822 .40653 L .38386 .40833 L 0 .035 .136 r
F
.38112 .40917 m .37947 .4074 L .3822 .40653 L F
.85592 .40461 m .85771 .40207 L .85891 .40373 L 0 .025 .124 r
F
.85592 .40461 m .85472 .40297 L .85771 .40207 L F
.54005 .4173 m .54137 .41506 L .54287 .41647 L 0 .056 .159 r
F
.54005 .4173 m .53855 .41582 L .54137 .41506 L F
.23086 .40544 m .23172 .40276 L .23352 .40448 L 0 .027 .126 r
F
.23086 .40544 m .22905 .40372 L .23172 .40276 L F
.27091 .40564 m .27183 .403 L .27359 .40478 L F
.27091 .40564 m .26915 .40385 L .27183 .403 L F
.79444 .40566 m .79613 .40305 L .79739 .40475 L 0 .027 .127 r
F
.79444 .40566 m .79317 .40396 L .79613 .40305 L F
.58292 .41497 m .5843 .41264 L .58576 .41384 L 0 .05 .152 r
F
.58292 .41497 m .58146 .41376 L .5843 .41264 L F
.90313 .40449 m .90498 .40192 L .90614 .4036 L 0 .025 .123 r
F
.90313 .40449 m .90197 .40281 L .90498 .40192 L F
.7401 .40631 m .74171 .40379 L .74302 .40535 L 0 .029 .129 r
F
.7401 .40631 m .73879 .40474 L .74171 .40379 L F
.5472 .41701 m .54853 .4149 L .55002 .41617 L 0 .056 .158 r
F
.5472 .41701 m .5457 .41566 L .54853 .4149 L F
.73296 .40671 m .73456 .40415 L .73587 .40573 L 0 .03 .13 r
F
.73296 .40671 m .73164 .40512 L .73456 .40415 L F
.35535 .40832 m .35639 .4058 L .35806 .4076 L 0 .033 .134 r
F
.35535 .40832 m .35367 .40651 L .35639 .4058 L F
.40688 .41031 m .40799 .40808 L .40963 .40965 L 0 .038 .14 r
F
.40688 .41031 m .40524 .40875 L .40799 .40808 L F
.55434 .41667 m .55568 .41452 L .55717 .41586 L 0 .055 .158 r
F
.55434 .41667 m .55285 .41534 L .55568 .41452 L F
.23798 .40527 m .23884 .40272 L .24064 .40444 L 0 .027 .126 r
F
.23798 .40527 m .23619 .40354 L .23884 .40272 L F
.74726 .40608 m .74888 .4036 L .75019 .40522 L 0 .029 .128 r
F
.74726 .40608 m .74595 .40448 L .74888 .4036 L F
.8016 .40548 m .8033 .40285 L .80455 .4045 L 0 .027 .126 r
F
.8016 .40548 m .80035 .40381 L .8033 .40285 L F
.46989 .41422 m .4711 .4118 L .47268 .41343 L 0 .048 .151 r
F
.46989 .41422 m .46832 .41258 L .4711 .4118 L F
.8631 .40453 m .86489 .40198 L .86609 .40367 L 0 .025 .124 r
F
.8631 .40453 m .8619 .40285 L .86489 .40198 L F
.33672 .40712 m .33773 .40458 L .33942 .40633 L 0 .031 .131 r
F
.33672 .40712 m .33502 .40537 L .33773 .40458 L F
.80876 .40515 m .81046 .40251 L .81171 .40414 L 0 .026 .126 r
F
.80876 .40515 m .80751 .40352 L .81046 .40251 L F
.44412 .4133 m .44529 .41101 L .44689 .41247 L 0 .046 .148 r
F
.44412 .4133 m .44252 .4118 L .44529 .41101 L F
.91031 .40439 m .91217 .40182 L .91332 .40348 L 0 .025 .124 r
F
.91031 .40439 m .90916 .40272 L .91217 .40182 L F
.31094 .40618 m .31192 .4036 L .31364 .40539 L 0 .029 .128 r
F
.31094 .40618 m .30922 .40438 L .31192 .4036 L F
.27803 .4056 m .27896 .40289 L .28072 .40462 L 0 .027 .127 r
F
.27803 .4056 m .27627 .40385 L .27896 .40289 L F
.56149 .4165 m .56284 .41428 L .56432 .41575 L 0 .055 .157 r
F
.56149 .4165 m .56 .41507 L .56284 .41428 L F
.81591 .40481 m .81762 .40218 L .81887 .40387 L 0 .026 .125 r
F
.81591 .40481 m .81466 .40313 L .81762 .40218 L F
.38825 .4093 m .38934 .40662 L .39098 .40845 L 0 .036 .137 r
F
.38825 .4093 m .3866 .40748 L .38934 .40662 L F
.91748 .40415 m .91934 .4015 L .92048 .40316 L 0 .025 .123 r
F
.91748 .40415 m .91633 .40249 L .91934 .4015 L F
.28516 .40536 m .28609 .40286 L .28784 .40455 L 0 .027 .127 r
F
.28516 .40536 m .28341 .40366 L .28609 .40286 L F
.41401 .41036 m .41514 .40787 L .41677 .4095 L 0 .039 .14 r
F
.41401 .41036 m .41238 .40876 L .41514 .40787 L F
.50714 .41729 m .5084 .41545 L .50994 .41661 L 0 .058 .16 r
F
.50714 .41729 m .5056 .41609 L .5084 .41545 L F
.75443 .40601 m .75606 .40353 L .75736 .40518 L 0 .029 .129 r
F
.75443 .40601 m .75312 .40438 L .75606 .40353 L F
.49999 .41773 m .50124 .41557 L .50279 .41691 L 0 .059 .161 r
F
.49999 .41773 m .49844 .41634 L .50124 .41557 L F
.65005 .40942 m .65154 .40704 L .65293 .4086 L 0 .037 .138 r
F
.65005 .40942 m .64865 .40785 L .65154 .40704 L F
.87028 .40446 m .87209 .40196 L .87328 .40359 L 0 .026 .124 r
F
.87028 .40446 m .86909 .40282 L .87209 .40196 L F
.57579 .41596 m .57715 .41364 L .57862 .41486 L 0 .053 .156 r
F
.57579 .41596 m .57432 .41472 L .57715 .41364 L F
.82307 .40466 m .8248 .40208 L .82604 .40377 L 0 .026 .125 r
F
.82307 .40466 m .82183 .40298 L .8248 .40208 L F
.92464 .40389 m .92651 .40125 L .92766 .40297 L 0 .024 .123 r
F
.92464 .40389 m .92349 .40219 L .92651 .40125 L F
.24509 .4053 m .24597 .40271 L .24776 .4044 L 0 .027 .127 r
F
.24509 .4053 m .2433 .40361 L .24597 .40271 L F
.45126 .41323 m .45243 .41124 L .45403 .41264 L 0 .047 .149 r
F
.45126 .41323 m .44966 .4118 L .45243 .41124 L F
.56864 .41642 m .57 .41411 L .57148 .41564 L 0 .055 .157 r
F
.56864 .41642 m .56716 .41493 L .57 .41411 L F
.64291 .4099 m .64437 .4072 L .64578 .40879 L 0 .037 .139 r
F
.64291 .4099 m .6415 .40832 L .64437 .4072 L F
.51429 .41706 m .51556 .41531 L .51709 .41638 L 0 .058 .16 r
F
.51429 .41706 m .51275 .41595 L .51556 .41531 L F
.47703 .41431 m .47825 .41218 L .47981 .41381 L 0 .05 .152 r
F
.47703 .41431 m .47546 .41264 L .47825 .41218 L F
.6715 .40841 m .67301 .40592 L .67439 .40749 L 0 .034 .135 r
F
.6715 .40841 m .67012 .40688 L .67301 .40592 L F
.66435 .40881 m .66586 .40644 L .66724 .40785 L 0 .035 .137 r
F
.66435 .40881 m .66297 .4074 L .66586 .40644 L F
.21216 .40486 m .21299 .40222 L .21481 .40387 L 0 .026 .125 r
F
.21216 .40486 m .21033 .4032 L .21299 .40222 L F
.36246 .40863 m .36352 .40585 L .36519 .40761 L 0 .034 .135 r
F
.36246 .40863 m .36078 .40685 L .36352 .40585 L F
.87745 .40428 m .87926 .4017 L .88044 .40333 L 0 .025 .124 r
F
.87745 .40428 m .87627 .40266 L .87926 .4017 L F
.83024 .40449 m .83197 .40181 L .8332 .40349 L 0 .026 .124 r
F
.83024 .40449 m .82901 .4028 L .83197 .40181 L F
.43263 .41202 m .43378 .4098 L .43538 .41155 L 0 .044 .146 r
F
.43263 .41202 m .43102 .41031 L .43378 .4098 L F
.31806 .40628 m .31905 .40364 L .32076 .40539 L 0 .029 .129 r
F
.31806 .40628 m .31634 .40451 L .31905 .40364 L F
.25222 .4051 m .25311 .40249 L .25489 .40414 L 0 .027 .126 r
F
.25222 .4051 m .25043 .40344 L .25311 .40249 L F
.65721 .40926 m .6587 .40688 L .66009 .40833 L 0 .037 .138 r
F
.65721 .40926 m .65582 .40778 L .6587 .40688 L F
.3696 .40829 m .37067 .40564 L .37234 .40734 L 0 .034 .135 r
F
.3696 .40829 m .36793 .40658 L .37067 .40564 L F
.34383 .4073 m .34486 .40455 L .34655 .40637 L 0 .031 .132 r
F
.34383 .4073 m .34214 .40549 L .34486 .40455 L F
.76159 .40593 m .76323 .40334 L .76452 .40496 L 0 .029 .129 r
F
.76159 .40593 m .7603 .40432 L .76323 .40334 L F
.52143 .41684 m .52272 .41522 L .52424 .41628 L 0 .058 .16 r
F
.52143 .41684 m .5199 .4158 L .52272 .41522 L F
.48851 .41627 m .48974 .41419 L .4913 .41581 L 0 .055 .158 r
F
.48851 .41627 m .48695 .41463 L .48974 .41419 L F
.63577 .41053 m .63722 .40787 L .63864 .40944 L 0 .039 .141 r
F
.63577 .41053 m .63436 .40895 L .63722 .40787 L F
.8374 .40419 m .83916 .40169 L .84038 .40334 L 0 .025 .124 r
F
.8374 .40419 m .83617 .40253 L .83916 .40169 L F
.29228 .40538 m .29322 .40285 L .29497 .40448 L 0 .028 .127 r
F
.29228 .40538 m .29053 .40373 L .29322 .40285 L F
.39537 .40935 m .39648 .4066 L .39812 .40843 L 0 .036 .138 r
F
.39537 .40935 m .39373 .40753 L .39648 .4066 L F
.21929 .4046 m .22012 .40213 L .22193 .40379 L 0 .026 .125 r
F
.21929 .4046 m .21747 .40295 L .22012 .40213 L F
.42115 .41036 m .42227 .40808 L .4239 .40975 L 0 .04 .141 r
F
.42115 .41036 m .41952 .40872 L .42227 .40808 L F
.76875 .4056 m .7704 .40308 L .77168 .4047 L 0 .028 .128 r
F
.76875 .4056 m .76746 .40399 L .7704 .40308 L F
.88461 .40403 m .88644 .40152 L .88762 .40317 L 0 .025 .124 r
F
.88461 .40403 m .88344 .40239 L .88644 .40152 L F
.67865 .40821 m .68018 .40577 L .68155 .40739 L 0 .034 .135 r
F
.67865 .40821 m .67728 .40662 L .68018 .40577 L F
.25935 .40484 m .26025 .40227 L .26203 .40391 L 0 .027 .126 r
F
.25935 .40484 m .25757 .4032 L .26025 .40227 L F
.5929 .41301 m .5943 .41084 L .59575 .41222 L 0 .047 .149 r
F
.5929 .41301 m .59144 .41165 L .5943 .41084 L F
.62863 .41106 m .63008 .40857 L .63149 .41002 L 0 .041 .143 r
F
.62863 .41106 m .62721 .4096 L .63008 .40857 L F
.29941 .40513 m .30037 .40252 L .30212 .40414 L 0 .027 .127 r
F
.29941 .40513 m .29767 .4035 L .30037 .40252 L F
.62149 .41152 m .62293 .40916 L .62435 .41056 L 0 .042 .145 r
F
.62149 .41152 m .62006 .41016 L .62293 .40916 L F
.52858 .41669 m .52987 .4149 L .53139 .416 L 0 .058 .16 r
F
.52858 .41669 m .52706 .41562 L .52987 .4149 L F
.7001 .40722 m .70165 .40465 L .70301 .40626 L 0 .032 .133 r
F
.7001 .40722 m .69875 .40563 L .70165 .40465 L F
.69296 .40762 m .6945 .40503 L .69585 .4066 L 0 .033 .134 r
F
.69296 .40762 m .6916 .40605 L .6945 .40503 L F
.77591 .40545 m .77758 .40298 L .77886 .40459 L 0 .028 .128 r
F
.77591 .40545 m .77463 .40384 L .77758 .40298 L F
.32518 .40624 m .32617 .40369 L .32789 .40538 L 0 .03 .13 r
F
.32518 .40624 m .32347 .40453 L .32617 .40369 L F
.37673 .40823 m .37781 .40563 L .37947 .4074 L 0 .034 .135 r
F
.37673 .40823 m .37507 .40649 L .37781 .40563 L F
.4584 .4134 m .45958 .41133 L .46117 .41268 L 0 .048 .15 r
F
.4584 .4134 m .4568 .41205 L .45958 .41133 L F
.26648 .40469 m .26738 .40216 L .26915 .40385 L 0 .027 .126 r
F
.26648 .40469 m .26471 .40301 L .26738 .40216 L F
.35095 .40727 m .35199 .40468 L .35367 .40651 L 0 .032 .133 r
F
.35095 .40727 m .34927 .40544 L .35199 .40468 L F
.72155 .40609 m .72313 .4035 L .72446 .40518 L 0 .03 .13 r
F
.72155 .40609 m .72021 .40442 L .72313 .4035 L F
.70726 .40689 m .70881 .40428 L .71016 .40589 L 0 .031 .132 r
F
.70726 .40689 m .70591 .40527 L .70881 .40428 L F
.7144 .4065 m .71597 .40381 L .71731 .40546 L 0 .03 .131 r
F
.7144 .4065 m .71306 .40487 L .71597 .40381 L F
.84458 .40412 m .84634 .40159 L .84755 .40322 L 0 .026 .124 r
F
.84458 .40412 m .84336 .40249 L .84634 .40159 L F
.8918 .40398 m .89363 .40138 L .8948 .40306 L 0 .025 .124 r
F
.8918 .40398 m .89063 .40231 L .89363 .40138 L F
.68582 .40817 m .68734 .40548 L .68871 .40711 L 0 .034 .135 r
F
.68582 .40817 m .68445 .40655 L .68734 .40548 L F
.78307 .40521 m .78473 .40254 L .78601 .40419 L 0 .028 .127 r
F
.78307 .40521 m .7818 .40357 L .78473 .40254 L F
.22639 .40465 m .22725 .40204 L .22905 .40372 L 0 .027 .126 r
F
.22639 .40465 m .22458 .40298 L .22725 .40204 L F
.60005 .41298 m .60146 .41062 L .60291 .41216 L 0 .047 .149 r
F
.60005 .41298 m .5986 .41143 L .60146 .41062 L F
.4025 .40942 m .40361 .407 L .40524 .40875 L 0 .038 .139 r
F
.4025 .40942 m .40086 .40767 L .40361 .407 L F
.79022 .40488 m .7919 .40226 L .79317 .40396 L 0 .027 .127 r
F
.79022 .40488 m .78895 .4032 L .7919 .40226 L F
.53573 .41658 m .53703 .41462 L .53855 .41582 L 0 .057 .16 r
F
.53573 .41658 m .53421 .41532 L .53703 .41462 L F
.85174 .40391 m .85351 .40133 L .85472 .40297 L 0 .025 .124 r
F
.85174 .40391 m .85053 .40227 L .85351 .40133 L F
.61435 .41225 m .61578 .40983 L .6172 .41119 L 0 .045 .147 r
F
.61435 .41225 m .61292 .41092 L .61578 .40983 L F
.58576 .41384 m .58714 .41151 L .5886 .4127 L 0 .049 .152 r
F
.58576 .41384 m .5843 .41264 L .58714 .41151 L F
.30653 .40514 m .3075 .40258 L .30922 .40438 L 0 .028 .127 r
F
.30653 .40514 m .30481 .40334 L .3075 .40258 L F
.89897 .40378 m .9008 .4011 L .90197 .40281 L 0 .025 .124 r
F
.89897 .40378 m .8978 .40208 L .9008 .4011 L F
.72871 .40597 m .73031 .40351 L .73164 .40512 L 0 .03 .13 r
F
.72871 .40597 m .72739 .40435 L .73031 .40351 L F
.33231 .40617 m .33331 .40373 L .33502 .40537 L 0 .03 .131 r
F
.33231 .40617 m .3306 .40451 L .33331 .40373 L F
.46554 .41331 m .46673 .41122 L .46832 .41258 L 0 .048 .151 r
F
.46554 .41331 m .46395 .41195 L .46673 .41122 L F
.23352 .40448 m .23439 .40182 L .23619 .40354 L 0 .027 .126 r
F
.23352 .40448 m .23172 .40276 L .23439 .40182 L F
.85891 .40373 m .8607 .40117 L .8619 .40285 L 0 .025 .124 r
F
.85891 .40373 m .85771 .40207 L .8607 .40117 L F
.60721 .41286 m .60862 .41049 L .61006 .41201 L 0 .047 .149 r
F
.60721 .41286 m .60576 .41133 L .60862 .41049 L F
.73587 .40573 m .73748 .40318 L .73879 .40474 L 0 .029 .129 r
F
.73587 .40573 m .73456 .40415 L .73748 .40318 L F
.79739 .40475 m .79908 .40211 L .80035 .40381 L 0 .027 .127 r
F
.79739 .40475 m .79613 .40305 L .79908 .40211 L F
.74302 .40535 m .74464 .4029 L .74595 .40448 L 0 .029 .129 r
F
.74302 .40535 m .74171 .40379 L .74464 .4029 L F
.38386 .40833 m .38494 .40566 L .3866 .40748 L 0 .035 .136 r
F
.38386 .40833 m .3822 .40653 L .38494 .40566 L F
.54287 .41647 m .54419 .41432 L .5457 .41566 L 0 .057 .159 r
F
.54287 .41647 m .54137 .41506 L .54419 .41432 L F
.27359 .40478 m .27452 .40209 L .27627 .40385 L 0 .027 .127 r
F
.27359 .40478 m .27183 .403 L .27452 .40209 L F
.90614 .4036 m .908 .40105 L .90916 .40272 L 0 .025 .124 r
F
.90614 .4036 m .90498 .40192 L .908 .40105 L F
.43975 .41258 m .44091 .41029 L .44252 .4118 L 0 .046 .149 r
F
.43975 .41258 m .43814 .41103 L .44091 .41029 L F
.55002 .41617 m .55136 .41413 L .55285 .41534 L 0 .056 .159 r
F
.55002 .41617 m .54853 .4149 L .55136 .41413 L F
.42827 .41083 m .4294 .40859 L .43102 .41031 L 0 .042 .144 r
F
.42827 .41083 m .42665 .40915 L .4294 .40859 L F
.80455 .4045 m .80625 .40188 L .80751 .40352 L 0 .027 .126 r
F
.80455 .4045 m .8033 .40285 L .80625 .40188 L F
.48416 .41504 m .48539 .4131 L .48695 .41463 L 0 .054 .156 r
F
.48416 .41504 m .4826 .41345 L .48539 .4131 L F
.81171 .40414 m .81342 .4015 L .81466 .40313 L 0 .026 .125 r
F
.81171 .40414 m .81046 .40251 L .81342 .4015 L F
.55717 .41586 m .55852 .4137 L .56 .41507 L 0 .056 .158 r
F
.55717 .41586 m .55568 .41452 L .55852 .4137 L F
.28072 .40462 m .28166 .40194 L .28341 .40366 L 0 .027 .127 r
F
.28072 .40462 m .27896 .40289 L .28166 .40194 L F
.35806 .4076 m .35911 .40506 L .36078 .40685 L 0 .034 .135 r
F
.35806 .4076 m .35639 .4058 L .35911 .40506 L F
.75019 .40522 m .75182 .40273 L .75312 .40438 L 0 .029 .129 r
F
.75019 .40522 m .74888 .4036 L .75182 .40273 L F
.24064 .40444 m .2415 .40191 L .2433 .40361 L 0 .027 .126 r
F
.24064 .40444 m .23884 .40272 L .2415 .40191 L F
.49565 .41695 m .49689 .41479 L .49844 .41634 L 0 .059 .161 r
F
.49565 .41695 m .49409 .41535 L .49689 .41479 L F
.81887 .40387 m .82059 .40129 L .82183 .40298 L 0 .026 .125 r
F
.81887 .40387 m .81762 .40218 L .82059 .40129 L F
.86609 .40367 m .86789 .40112 L .86909 .40282 L 0 .026 .124 r
F
.86609 .40367 m .86489 .40198 L .86789 .40112 L F
.91332 .40348 m .91518 .40083 L .91633 .40249 L 0 .025 .124 r
F
.91332 .40348 m .91217 .40182 L .91518 .40083 L F
.40963 .40965 m .41074 .40716 L .41238 .40876 L 0 .039 .141 r
F
.40963 .40965 m .40799 .40808 L .41074 .40716 L F
.47268 .41343 m .47389 .41103 L .47546 .41264 L 0 .049 .151 r
F
.47268 .41343 m .4711 .4118 L .47389 .41103 L F
.44689 .41247 m .44806 .41037 L .44966 .4118 L 0 .047 .149 r
F
.44689 .41247 m .44529 .41101 L .44806 .41037 L F
.33942 .40633 m .34044 .40373 L .34214 .40549 L 0 .031 .132 r
F
.33942 .40633 m .33773 .40458 L .34044 .40373 L F
.92048 .40316 m .92235 .40053 L .92349 .40219 L 0 .024 .123 r
F
.92048 .40316 m .91934 .4015 L .92235 .40053 L F
.57862 .41486 m .58 .41255 L .58146 .41376 L 0 .053 .155 r
F
.57862 .41486 m .57715 .41364 L .58 .41255 L F
.31364 .40539 m .31462 .40274 L .31634 .40451 L 0 .029 .129 r
F
.31364 .40539 m .31192 .4036 L .31462 .40274 L F
.64578 .40879 m .64725 .40623 L .64865 .40785 L 0 .037 .138 r
F
.64578 .40879 m .64437 .4072 L .64725 .40623 L F
.56432 .41575 m .56568 .41342 L .56716 .41493 L 0 .055 .158 r
F
.56432 .41575 m .56284 .41428 L .56568 .41342 L F
.39098 .40845 m .39209 .40569 L .39373 .40753 L 0 .036 .137 r
F
.39098 .40845 m .38934 .40662 L .39209 .40569 L F
.41677 .4095 m .41789 .40706 L .41952 .40872 L 0 .039 .141 r
F
.41677 .4095 m .41514 .40787 L .41789 .40706 L F
.28784 .40455 m .28878 .40207 L .29053 .40373 L 0 .028 .127 r
F
.28784 .40455 m .28609 .40286 L .28878 .40207 L F
.92766 .40297 m .92953 .40031 L .93068 .40205 L 0 .024 .123 r
F
.92766 .40297 m .92651 .40125 L .92953 .40031 L F
.82604 .40377 m .82777 .40111 L .82901 .4028 L 0 .026 .125 r
F
.82604 .40377 m .8248 .40208 L .82777 .40111 L F
.20767 .40417 m .2085 .40154 L .21033 .4032 L 0 .027 .126 r
F
.20767 .40417 m .20584 .4025 L .2085 .40154 L F
.87328 .40359 m .87509 .40103 L .87627 .40266 L 0 .026 .125 r
F
.87328 .40359 m .87209 .40196 L .87509 .40103 L F
.75736 .40518 m .759 .40266 L .7603 .40432 L 0 .029 .129 r
F
.75736 .40518 m .75606 .40353 L .759 .40266 L F
.24776 .4044 m .24864 .40177 L .25043 .40344 L 0 .027 .127 r
F
.24776 .4044 m .24597 .40271 L .24864 .40177 L F
.50279 .41691 m .50405 .41481 L .5056 .41609 L 0 .059 .162 r
F
.50279 .41691 m .50124 .41557 L .50405 .41481 L F
.65293 .4086 m .65442 .40622 L .65582 .40778 L 0 .037 .139 r
F
.65293 .4086 m .65154 .40704 L .65442 .40622 L F
.36519 .40761 m .36626 .40485 L .36793 .40658 L 0 .034 .135 r
F
.36519 .40761 m .36352 .40585 L .36626 .40485 L F
.21481 .40387 m .21565 .4013 L .21747 .40295 L 0 .026 .125 r
F
.21481 .40387 m .21299 .40222 L .21565 .4013 L F
.66724 .40785 m .66875 .40545 L .67012 .40688 L 0 .035 .137 r
F
.66724 .40785 m .66586 .40644 L .66875 .40545 L F
.63864 .40944 m .64009 .40673 L .6415 .40832 L 0 .038 .14 r
F
.63864 .40944 m .63722 .40787 L .64009 .40673 L F
.8332 .40349 m .83494 .40085 L .83617 .40253 L 0 .025 .124 r
F
.8332 .40349 m .83197 .40181 L .83494 .40085 L F
.50994 .41661 m .51121 .41485 L .51275 .41595 L 0 .059 .162 r
F
.50994 .41661 m .5084 .41545 L .51121 .41485 L F
.67439 .40749 m .6759 .40502 L .67728 .40662 L 0 .034 .136 r
F
.67439 .40749 m .67301 .40592 L .6759 .40502 L F
.88044 .40333 m .88226 .40075 L .88344 .40239 L 0 .025 .124 r
F
.88044 .40333 m .87926 .4017 L .88226 .40075 L F
.25489 .40414 m .25579 .40155 L .25757 .4032 L 0 .027 .126 r
F
.25489 .40414 m .25311 .40249 L .25579 .40155 L F
.57148 .41564 m .57284 .41318 L .57432 .41472 L 0 .055 .158 r
F
.57148 .41564 m .57 .41411 L .57284 .41318 L F
.76452 .40496 m .76617 .40236 L .76746 .40399 L 0 .029 .128 r
F
.76452 .40496 m .76323 .40334 L .76617 .40236 L F
.66009 .40833 m .66159 .40598 L .66297 .4074 L 0 .037 .138 r
F
.66009 .40833 m .6587 .40688 L .66159 .40598 L F
.37234 .40734 m .3734 .40478 L .37507 .40649 L 0 .034 .135 r
F
.37234 .40734 m .37067 .40564 L .3734 .40478 L F
.34655 .40637 m .34759 .40361 L .34927 .40544 L 0 .031 .132 r
F
.34655 .40637 m .34486 .40455 L .34759 .40361 L F
.32076 .40539 m .32175 .4028 L .32347 .40453 L 0 .03 .13 r
F
.32076 .40539 m .31905 .40364 L .32175 .4028 L F
.39812 .40843 m .39922 .40584 L .40086 .40767 L 0 .037 .138 r
F
.39812 .40843 m .39648 .4066 L .39922 .40584 L F
.63149 .41002 m .63294 .40751 L .63436 .40895 L 0 .04 .142 r
F
.63149 .41002 m .63008 .40857 L .63294 .40751 L F
.51709 .41638 m .51837 .41469 L .5199 .4158 L 0 .059 .162 r
F
.51709 .41638 m .51556 .41531 L .51837 .41469 L F
.29497 .40448 m .29592 .40187 L .29767 .4035 L 0 .028 .127 r
F
.29497 .40448 m .29322 .40285 L .29592 .40187 L F
.77168 .4047 m .77335 .40222 L .77463 .40384 L 0 .028 .128 r
F
.77168 .4047 m .7704 .40308 L .77335 .40222 L F
.26203 .40391 m .26293 .40135 L .26471 .40301 L 0 .027 .126 r
F
.26203 .40391 m .26025 .40227 L .26293 .40135 L F
.45403 .41264 m .4552 .41069 L .4568 .41205 L 0 .048 .151 r
F
.45403 .41264 m .45243 .41124 L .4552 .41069 L F
.84038 .40334 m .84214 .40085 L .84336 .40249 L 0 .026 .125 r
F
.84038 .40334 m .83916 .40169 L .84214 .40085 L F
.30212 .40414 m .30307 .40171 L .30481 .40334 L 0 .027 .127 r
F
.30212 .40414 m .30037 .40252 L .30307 .40171 L F
.88762 .40317 m .88945 .40066 L .89063 .40231 L 0 .025 .124 r
F
.88762 .40317 m .88644 .40152 L .88945 .40066 L F
.22193 .40379 m .22277 .40131 L .22458 .40298 L 0 .027 .126 r
F
.22193 .40379 m .22012 .40213 L .22277 .40131 L F
.62435 .41056 m .62579 .40816 L .62721 .4096 L 0 .042 .144 r
F
.62435 .41056 m .62293 .40916 L .62579 .40816 L F
.68155 .40739 m .68308 .40491 L .68445 .40655 L 0 .035 .136 r
F
.68155 .40739 m .68018 .40577 L .68308 .40491 L F
.69585 .4066 m .6974 .40403 L .69875 .40563 L 0 .033 .133 r
F
.69585 .4066 m .6945 .40503 L .6974 .40403 L F
.71731 .40546 m .71887 .40275 L .72021 .40442 L 0 .03 .13 r
F
.71731 .40546 m .71597 .40381 L .71887 .40275 L F
.70301 .40626 m .70456 .40368 L .70591 .40527 L 0 .032 .132 r
F
.70301 .40626 m .70165 .40465 L .70456 .40368 L F
.47981 .41381 m .48103 .41188 L .4826 .41345 L 0 .052 .154 r
F
.47981 .41381 m .47825 .41218 L .48103 .41188 L F
.59575 .41222 m .59715 .41004 L .5986 .41143 L 0 .047 .149 r
F
.59575 .41222 m .5943 .41084 L .59715 .41004 L F
.71016 .40589 m .71172 .40327 L .71306 .40487 L 0 .031 .131 r
F
.71016 .40589 m .70881 .40428 L .71172 .40327 L F
.68871 .40711 m .69024 .40441 L .6916 .40605 L 0 .034 .135 r
F
.68871 .40711 m .68734 .40548 L .69024 .40441 L F
.5886 .4127 m .58999 .41046 L .59144 .41165 L 0 .048 .151 r
F
.5886 .4127 m .58714 .41151 L .58999 .41046 L F
.52424 .41628 m .52553 .41454 L .52706 .41562 L 0 .059 .162 r
F
.52424 .41628 m .52272 .41522 L .52553 .41454 L F
.72446 .40518 m .72605 .40266 L .72739 .40435 L 0 .03 .13 r
F
.72446 .40518 m .72313 .4035 L .72605 .40266 L F
.32789 .40538 m .32889 .40285 L .3306 .40451 L F
.32789 .40538 m .32617 .40369 L .32889 .40285 L F
.78601 .40419 m .78768 .40151 L .78895 .4032 L 0 .027 .127 r
F
.78601 .40419 m .78473 .40254 L .78768 .40151 L F
.77886 .40459 m .78052 .40196 L .7818 .40357 L 0 .028 .128 r
F
.77886 .40459 m .77758 .40298 L .78052 .40196 L F
.4239 .40975 m .42503 .40744 L .42665 .40915 L 0 .041 .143 r
F
.4239 .40975 m .42227 .40808 L .42503 .40744 L F
.84755 .40322 m .84933 .40066 L .85053 .40227 L 0 .026 .124 r
F
.84755 .40322 m .84634 .40159 L .84933 .40066 L F
.43538 .41155 m .43654 .40925 L .43814 .41103 L 0 .045 .148 r
F
.43538 .41155 m .43378 .4098 L .43654 .40925 L F
.37947 .4074 m .38055 .40473 L .3822 .40653 L 0 .035 .136 r
F
.37947 .4074 m .37781 .40563 L .38055 .40473 L F
.26915 .40385 m .27006 .40131 L .27183 .403 L 0 .027 .126 r
F
.26915 .40385 m .26738 .40216 L .27006 .40131 L F
.8948 .40306 m .89663 .40038 L .8978 .40208 L 0 .025 .124 r
F
.8948 .40306 m .89363 .40138 L .89663 .40038 L F
.6172 .41119 m .61864 .40876 L .62006 .41016 L 0 .044 .146 r
F
.6172 .41119 m .61578 .40983 L .61864 .40876 L F
.53139 .416 m .5327 .41418 L .53421 .41532 L 0 .059 .161 r
F
.53139 .416 m .52987 .4149 L .5327 .41418 L F
.4913 .41581 m .49254 .41375 L .49409 .41535 L 0 .057 .16 r
F
.4913 .41581 m .48974 .41419 L .49254 .41375 L F
.22905 .40372 m .22992 .40106 L .23172 .40276 L 0 .027 .126 r
F
.22905 .40372 m .22725 .40204 L .22992 .40106 L F
.35367 .40651 m .35471 .40398 L .35639 .4058 L 0 .033 .134 r
F
.35367 .40651 m .35199 .40468 L .35471 .40398 L F
.46117 .41268 m .46236 .41059 L .46395 .41195 L 0 .049 .151 r
F
.46117 .41268 m .45958 .41133 L .46236 .41059 L F
.85472 .40297 m .8565 .40041 L .85771 .40207 L 0 .025 .124 r
F
.85472 .40297 m .85351 .40133 L .8565 .40041 L F
.79317 .40396 m .79486 .40131 L .79613 .40305 L 0 .027 .127 r
F
.79317 .40396 m .7919 .40226 L .79486 .40131 L F
.90197 .40281 m .90381 .40019 L .90498 .40192 L 0 .025 .124 r
F
.90197 .40281 m .9008 .4011 L .90381 .40019 L F
.60291 .41216 m .60432 .4098 L .60576 .41133 L 0 .047 .149 r
F
.60291 .41216 m .60146 .41062 L .60432 .4098 L F
.53855 .41582 m .53986 .41392 L .54137 .41506 L 0 .058 .16 r
F
.53855 .41582 m .53703 .41462 L .53986 .41392 L F
.73164 .40512 m .73324 .40257 L .73456 .40415 L 0 .03 .13 r
F
.73164 .40512 m .73031 .40351 L .73324 .40257 L F
.23619 .40354 m .23705 .40099 L .23884 .40272 L 0 .027 .126 r
F
.23619 .40354 m .23439 .40182 L .23705 .40099 L F
.73879 .40474 m .7404 .40224 L .74171 .40379 L 0 .029 .129 r
F
.73879 .40474 m .73748 .40318 L .7404 .40224 L F
.30922 .40438 m .3102 .4018 L .31192 .4036 L 0 .028 .128 r
F
.30922 .40438 m .3075 .40258 L .3102 .4018 L F
.33502 .40537 m .33602 .40295 L .33773 .40458 L 0 .031 .131 r
F
.33502 .40537 m .33331 .40373 L .33602 .40295 L F
.40524 .40875 m .40635 .40633 L .40799 .40808 L 0 .039 .14 r
F
.40524 .40875 m .40361 .407 L .40635 .40633 L F
.80035 .40381 m .80204 .40116 L .8033 .40285 L 0 .027 .126 r
F
.80035 .40381 m .79908 .40211 L .80204 .40116 L F
.8619 .40285 m .86369 .40028 L .86489 .40198 L 0 .025 .124 r
F
.8619 .40285 m .8607 .40117 L .86369 .40028 L F
.27627 .40385 m .27721 .40115 L .27896 .40289 L 0 .027 .127 r
F
.27627 .40385 m .27452 .40209 L .27721 .40115 L F
.46832 .41258 m .46952 .41045 L .4711 .4118 L 0 .049 .151 r
F
.46832 .41258 m .46673 .41122 L .46952 .41045 L F
.61006 .41201 m .61148 .40935 L .61292 .41092 L 0 .046 .149 r
F
.61006 .41201 m .60862 .41049 L .61148 .40935 L F
.74595 .40448 m .74758 .402 L .74888 .4036 L 0 .029 .129 r
F
.74595 .40448 m .74464 .4029 L .74758 .402 L F
.3866 .40748 m .38769 .40477 L .38934 .40662 L 0 .035 .136 r
F
.3866 .40748 m .38494 .40566 L .38769 .40477 L F
.90916 .40272 m .91102 .40014 L .91217 .40182 L 0 .025 .124 r
F
.90916 .40272 m .908 .40105 L .91102 .40014 L F
.80751 .40352 m .80921 .40088 L .81046 .40251 L 0 .027 .126 r
F
.80751 .40352 m .80625 .40188 L .80921 .40088 L F
.81466 .40313 m .81638 .40055 L .81762 .40218 L 0 .026 .125 r
F
.81466 .40313 m .81342 .4015 L .81638 .40055 L F
.5457 .41566 m .54702 .41362 L .54853 .4149 L 0 .058 .16 r
F
.5457 .41566 m .54419 .41432 L .54702 .41362 L F
.55285 .41534 m .55419 .4133 L .55568 .41452 L 0 .057 .159 r
F
.55285 .41534 m .55136 .41413 L .55419 .4133 L F
.58146 .41376 m .58284 .41144 L .5843 .41264 L 0 .052 .154 r
F
.58146 .41376 m .58 .41255 L .58284 .41144 L F
.28341 .40366 m .28434 .40116 L .28609 .40286 L 0 .027 .127 r
F
.28341 .40366 m .28166 .40194 L .28434 .40116 L F
.44252 .4118 m .44368 .40955 L .44529 .41101 L 0 .047 .149 r
F
.44252 .4118 m .44091 .41029 L .44368 .40955 L F
.91633 .40249 m .91819 .39984 L .91934 .4015 L 0 .025 .123 r
F
.91633 .40249 m .91518 .40083 L .91819 .39984 L F
.56 .41507 m .56135 .41287 L .56284 .41428 L 0 .056 .159 r
F
.56 .41507 m .55852 .4137 L .56135 .41287 L F
.82183 .40298 m .82356 .40039 L .8248 .40208 L 0 .026 .125 r
F
.82183 .40298 m .82059 .40129 L .82356 .40039 L F
.75312 .40438 m .75476 .40188 L .75606 .40353 L 0 .029 .129 r
F
.75312 .40438 m .75182 .40273 L .75476 .40188 L F
.92349 .40219 m .92537 .39957 L .92651 .40125 L 0 .024 .123 r
F
.92349 .40219 m .92235 .40053 L .92537 .39957 L F
.41238 .40876 m .4135 .40623 L .41514 .40787 L 0 .039 .141 r
F
.41238 .40876 m .41074 .40716 L .4135 .40623 L F
.2433 .40361 m .24417 .40103 L .24597 .40271 L 0 .027 .127 r
F
.2433 .40361 m .2415 .40191 L .24417 .40103 L F
.86909 .40282 m .87089 .40026 L .87209 .40196 L 0 .026 .125 r
F
.86909 .40282 m .86789 .40112 L .87089 .40026 L F
.36078 .40685 m .36184 .40409 L .36352 .40585 L 0 .034 .135 r
F
.36078 .40685 m .35911 .40506 L .36184 .40409 L F
.64865 .40785 m .65013 .4054 L .65154 .40704 L 0 .037 .139 r
F
.64865 .40785 m .64725 .40623 L .65013 .4054 L F
.34214 .40549 m .34317 .40278 L .34486 .40455 L 0 .031 .132 r
F
.34214 .40549 m .34044 .40373 L .34317 .40278 L F
.47546 .41264 m .47667 .41061 L .47825 .41218 L 0 .05 .152 r
F
.47546 .41264 m .47389 .41103 L .47667 .41061 L F
.31634 .40451 m .31733 .40187 L .31905 .40364 L 0 .029 .129 r
F
.31634 .40451 m .31462 .40274 L .31733 .40187 L F
.6415 .40832 m .64296 .4056 L .64437 .4072 L 0 .038 .139 r
F
.6415 .40832 m .64009 .40673 L .64296 .4056 L F
.39373 .40753 m .39484 .40477 L .39648 .4066 L 0 .036 .137 r
F
.39373 .40753 m .39209 .40569 L .39484 .40477 L F
.43102 .41031 m .43216 .40805 L .43378 .4098 L 0 .044 .146 r
F
.43102 .41031 m .4294 .40859 L .43216 .40805 L F
.82901 .4028 m .83074 .40012 L .83197 .40181 L 0 .026 .125 r
F
.82901 .4028 m .82777 .40111 L .83074 .40012 L F
.21033 .4032 m .21116 .40057 L .21299 .40222 L 0 .027 .126 r
F
.21033 .4032 m .2085 .40154 L .21116 .40057 L F
.36793 .40658 m .36899 .40393 L .37067 .40564 L 0 .034 .135 r
F
.36793 .40658 m .36626 .40485 L .36899 .40393 L F
.56716 .41493 m .56852 .41256 L .57 .41411 L 0 .056 .158 r
F
.56716 .41493 m .56568 .41342 L .56852 .41256 L F
.25043 .40344 m .25132 .40083 L .25311 .40249 L 0 .027 .127 r
F
.25043 .40344 m .24864 .40177 L .25132 .40083 L F
.49844 .41634 m .49969 .41411 L .50124 .41557 L 0 .06 .162 r
F
.49844 .41634 m .49689 .41479 L .49969 .41411 L F
.87627 .40266 m .87808 .40007 L .87926 .4017 L 0 .026 .124 r
F
.87627 .40266 m .87509 .40103 L .87808 .40007 L F
.44966 .4118 m .45083 .40985 L .45243 .41124 L 0 .048 .151 r
F
.44966 .4118 m .44806 .41037 L .45083 .40985 L F
.67012 .40688 m .67163 .40445 L .67301 .40592 L 0 .035 .136 r
F
.67012 .40688 m .66875 .40545 L .67163 .40445 L F
.48695 .41463 m .48818 .4127 L .48974 .41419 L 0 .056 .158 r
F
.48695 .41463 m .48539 .4131 L .48818 .4127 L F
.83617 .40253 m .83793 .4 L .83916 .40169 L 0 .026 .124 r
F
.83617 .40253 m .83494 .40085 L .83793 .4 L F
.7603 .40432 m .76193 .40165 L .76323 .40334 L 0 .029 .129 r
F
.7603 .40432 m .759 .40266 L .76193 .40165 L F
.29053 .40373 m .29147 .4012 L .29322 .40285 L 0 .028 .128 r
F
.29053 .40373 m .28878 .40207 L .29147 .4012 L F
.21747 .40295 m .2183 .40048 L .22012 .40213 L 0 .027 .126 r
F
.21747 .40295 m .21565 .4013 L .2183 .40048 L F
.41952 .40872 m .42065 .40638 L .42227 .40808 L 0 .04 .142 r
F
.41952 .40872 m .41789 .40706 L .42065 .40638 L F
.88344 .40239 m .88527 .39988 L .88644 .40152 L 0 .025 .124 r
F
.88344 .40239 m .88226 .40075 L .88527 .39988 L F
.5056 .41609 m .50686 .41424 L .5084 .41545 L 0 .06 .163 r
F
.5056 .41609 m .50405 .41481 L .50686 .41424 L F
.76746 .40399 m .76911 .40145 L .7704 .40308 L 0 .029 .128 r
F
.76746 .40399 m .76617 .40236 L .76911 .40145 L F
.63436 .40895 m .63581 .40645 L .63722 .40787 L 0 .04 .142 r
F
.63436 .40895 m .63294 .40751 L .63581 .40645 L F
.25757 .4032 m .25847 .40061 L .26025 .40227 L 0 .027 .126 r
F
.25757 .4032 m .25579 .40155 L .25847 .40061 L F
.57432 .41472 m .57568 .41214 L .57715 .41364 L 0 .055 .157 r
F
.57432 .41472 m .57284 .41318 L .57568 .41214 L F
.65582 .40778 m .65731 .40535 L .6587 .40688 L 0 .037 .139 r
F
.65582 .40778 m .65442 .40622 L .65731 .40535 L F
.66297 .4074 m .66448 .40503 L .66586 .40644 L 0 .037 .138 r
F
.66297 .4074 m .66159 .40598 L .66448 .40503 L F
.67728 .40662 m .6788 .40415 L .68018 .40577 L 0 .035 .136 r
F
.67728 .40662 m .6759 .40502 L .6788 .40415 L F
.34927 .40544 m .35031 .40285 L .35199 .40468 L 0 .032 .132 r
F
.34927 .40544 m .34759 .40361 L .35031 .40285 L F
.29767 .4035 m .29863 .40089 L .30037 .40252 L 0 .028 .127 r
F
.29767 .4035 m .29592 .40187 L .29863 .40089 L F
.37507 .40649 m .37614 .40392 L .37781 .40563 L 0 .034 .135 r
F
.37507 .40649 m .3734 .40478 L .37614 .40392 L F
.32347 .40453 m .32446 .40199 L .32617 .40369 L 0 .03 .13 r
F
.32347 .40453 m .32175 .4028 L .32446 .40199 L F
.26471 .40301 m .26561 .40049 L .26738 .40216 L 0 .027 .126 r
F
.26471 .40301 m .26293 .40135 L .26561 .40049 L F
.72021 .40442 m .72179 .40182 L .72313 .4035 L 0 .03 .13 r
F
.72021 .40442 m .71887 .40275 L .72179 .40182 L F
.77463 .40384 m .7763 .40136 L .77758 .40298 L 0 .029 .128 r
F
.77463 .40384 m .77335 .40222 L .7763 .40136 L F
.69875 .40563 m .7003 .40304 L .70165 .40465 L 0 .032 .133 r
F
.69875 .40563 m .6974 .40403 L .7003 .40304 L F
.62721 .4096 m .62866 .40714 L .63008 .40857 L 0 .042 .144 r
F
.62721 .4096 m .62579 .40816 L .62866 .40714 L F
.51275 .41595 m .51402 .41423 L .51556 .41531 L 0 .061 .163 r
F
.51275 .41595 m .51121 .41485 L .51402 .41423 L F
.6916 .40605 m .69313 .40336 L .6945 .40503 L 0 .033 .134 r
F
.6916 .40605 m .69024 .40441 L .69313 .40336 L F
.84336 .40249 m .84513 .39997 L .84634 .40159 L 0 .026 .125 r
F
.84336 .40249 m .84214 .40085 L .84513 .39997 L F
.71306 .40487 m .71463 .40219 L .71597 .40381 L 0 .031 .131 r
F
.71306 .40487 m .71172 .40327 L .71463 .40219 L F
.70591 .40527 m .70747 .40272 L .70881 .40428 L 0 .032 .132 r
F
.70591 .40527 m .70456 .40368 L .70747 .40272 L F
.40086 .40767 m .40197 .40519 L .40361 .407 L 0 .037 .139 r
F
.40086 .40767 m .39922 .40584 L .40197 .40519 L F
.89063 .40231 m .89246 .39972 L .89363 .40138 L 0 .025 .124 r
F
.89063 .40231 m .88945 .40066 L .89246 .39972 L F
.59144 .41165 m .59285 .40962 L .5943 .41084 L 0 .048 .151 r
F
.59144 .41165 m .58999 .41046 L .59285 .40962 L F
.30481 .40334 m .30576 .40094 L .3075 .40258 L 0 .028 .127 r
F
.30481 .40334 m .30307 .40171 L .30576 .40094 L F
.7818 .40357 m .78346 .40091 L .78473 .40254 L 0 .028 .128 r
F
.7818 .40357 m .78052 .40196 L .78346 .40091 L F
.22458 .40298 m .22543 .40036 L .22725 .40204 L 0 .027 .126 r
F
.22458 .40298 m .22277 .40131 L .22543 .40036 L F
.68445 .40655 m .68597 .40382 L .68734 .40548 L 0 .034 .136 r
F
.68445 .40655 m .68308 .40491 L .68597 .40382 L F
.78895 .4032 m .79063 .40054 L .7919 .40226 L 0 .027 .127 r
F
.78895 .4032 m .78768 .40151 L .79063 .40054 L F
.62006 .41016 m .6215 .40772 L .62293 .40916 L 0 .044 .146 r
F
.62006 .41016 m .61864 .40876 L .6215 .40772 L F
.85053 .40227 m .85231 .39973 L .85351 .40133 L 0 .026 .124 r
F
.85053 .40227 m .84933 .40066 L .85231 .39973 L F
.8978 .40208 m .89963 .39938 L .9008 .4011 L 0 .025 .124 r
F
.8978 .40208 m .89663 .40038 L .89963 .39938 L F
.5986 .41143 m .60001 .40922 L .60146 .41062 L 0 .047 .15 r
F
.5986 .41143 m .59715 .41004 L .60001 .40922 L F
.5199 .4158 m .52119 .41406 L .52272 .41522 L 0 .061 .163 r
F
.5199 .4158 m .51837 .41469 L .52119 .41406 L F
.4568 .41205 m .45798 .40996 L .45958 .41133 L 0 .049 .152 r
F
.4568 .41205 m .4552 .41069 L .45798 .40996 L F
.3306 .40451 m .33159 .40208 L .33331 .40373 L 0 .031 .131 r
F
.3306 .40451 m .32889 .40285 L .33159 .40208 L F
.23172 .40276 m .23259 .4001 L .23439 .40182 L 0 .027 .126 r
F
.23172 .40276 m .22992 .40106 L .23259 .4001 L F
.72739 .40435 m .72898 .40182 L .73031 .40351 L 0 .03 .13 r
F
.72739 .40435 m .72605 .40266 L .72898 .40182 L F
.3822 .40653 m .38329 .40384 L .38494 .40566 L 0 .035 .136 r
F
.3822 .40653 m .38055 .40473 L .38329 .40384 L F
.27183 .403 m .27275 .40038 L .27452 .40209 L 0 .027 .126 r
F
.27183 .403 m .27006 .40131 L .27275 .40038 L F
.79613 .40305 m .79781 .40037 L .79908 .40211 L 0 .027 .127 r
F
.79613 .40305 m .79486 .40131 L .79781 .40037 L F
.85771 .40207 m .85949 .3995 L .8607 .40117 L 0 .025 .124 r
F
.85771 .40207 m .8565 .40041 L .85949 .3995 L F
.90498 .40192 m .90683 .39929 L .908 .40105 L F
.90498 .40192 m .90381 .40019 L .90683 .39929 L F
.52706 .41562 m .52835 .41379 L .52987 .4149 L 0 .06 .163 r
F
.52706 .41562 m .52553 .41454 L .52835 .41379 L F
.73456 .40415 m .73616 .40162 L .73748 .40318 L 0 .03 .13 r
F
.73456 .40415 m .73324 .40257 L .73616 .40162 L F
.61292 .41092 m .61434 .40822 L .61578 .40983 L 0 .046 .148 r
F
.61292 .41092 m .61148 .40935 L .61434 .40822 L F
.42665 .40915 m .42779 .40685 L .4294 .40859 L 0 .042 .144 r
F
.42665 .40915 m .42503 .40744 L .42779 .40685 L F
.60576 .41133 m .60718 .40897 L .60862 .41049 L 0 .047 .15 r
F
.60576 .41133 m .60432 .4098 L .60718 .40897 L F
.74171 .40379 m .74333 .40134 L .74464 .4029 L 0 .029 .129 r
F
.74171 .40379 m .7404 .40224 L .74333 .40134 L F
.53421 .41532 m .53552 .41354 L .53703 .41462 L 0 .06 .162 r
F
.53421 .41532 m .5327 .41418 L .53552 .41354 L F
.35639 .4058 m .35743 .40326 L .35911 .40506 L 0 .034 .135 r
F
.35639 .4058 m .35471 .40398 L .35743 .40326 L F
.46395 .41195 m .46514 .40985 L .46673 .41122 L 0 .05 .152 r
F
.46395 .41195 m .46236 .41059 L .46514 .40985 L F
.8033 .40285 m .805 .4002 L .80625 .40188 L 0 .027 .126 r
F
.8033 .40285 m .80204 .40116 L .805 .4002 L F
.27896 .40289 m .2799 .40021 L .28166 .40194 L F
.27896 .40289 m .27721 .40115 L .2799 .40021 L F
.43814 .41103 m .43931 .4085 L .44091 .41029 L 0 .046 .149 r
F
.43814 .41103 m .43654 .40925 L .43931 .4085 L F
.81046 .40251 m .81217 .39987 L .81342 .4015 L 0 .026 .126 r
F
.81046 .40251 m .80921 .40088 L .81217 .39987 L F
.5843 .41264 m .58569 .41032 L .58714 .41151 L 0 .051 .154 r
F
.5843 .41264 m .58284 .41144 L .58569 .41032 L F
.23884 .40272 m .23971 .40017 L .2415 .40191 L 0 .027 .126 r
F
.23884 .40272 m .23705 .40099 L .23971 .40017 L F
.4826 .41345 m .48382 .41158 L .48539 .4131 L 0 .054 .157 r
F
.4826 .41345 m .48103 .41188 L .48382 .41158 L F
.54137 .41506 m .54269 .41324 L .54419 .41432 L 0 .059 .161 r
F
.54137 .41506 m .53986 .41392 L .54269 .41324 L F
.81762 .40218 m .81935 .39966 L .82059 .40129 L 0 .026 .125 r
F
.81762 .40218 m .81638 .40055 L .81935 .39966 L F
.86489 .40198 m .86669 .39941 L .86789 .40112 L 0 .026 .124 r
F
.86489 .40198 m .86369 .40028 L .86669 .39941 L F
.33773 .40458 m .33874 .40211 L .34044 .40373 L 0 .031 .132 r
F
.33773 .40458 m .33602 .40295 L .33874 .40211 L F
.31192 .4036 m .3129 .40096 L .31462 .40274 L 0 .029 .129 r
F
.31192 .4036 m .3102 .4018 L .3129 .40096 L F
.74888 .4036 m .75051 .40113 L .75182 .40273 L F
.74888 .4036 m .74758 .402 L .75051 .40113 L F
.91217 .40182 m .91403 .39916 L .91518 .40083 L 0 .025 .124 r
F
.91217 .40182 m .91102 .40014 L .91403 .39916 L F
.38934 .40662 m .39044 .40385 L .39209 .40569 L 0 .035 .137 r
F
.38934 .40662 m .38769 .40477 L .39044 .40385 L F
.49409 .41535 m .49534 .41324 L .49689 .41479 L 0 .059 .162 r
F
.49409 .41535 m .49254 .41375 L .49534 .41324 L F
.4711 .4118 m .47231 .40968 L .47389 .41103 L 0 .05 .152 r
F
.4711 .4118 m .46952 .41045 L .47231 .40968 L F
.91934 .4015 m .92121 .39887 L .92235 .40053 L 0 .025 .123 r
F
.91934 .4015 m .91819 .39984 L .92121 .39887 L F
.40799 .40808 m .40911 .40542 L .41074 .40716 L 0 .039 .141 r
F
.40799 .40808 m .40635 .40633 L .40911 .40542 L F
.54853 .4149 m .54986 .41292 L .55136 .41413 L 0 .059 .161 r
F
.54853 .4149 m .54702 .41362 L .54986 .41292 L F
.55568 .41452 m .55702 .41245 L .55852 .4137 L 0 .057 .16 r
F
.55568 .41452 m .55419 .4133 L .55702 .41245 L F
.64437 .4072 m .64584 .40462 L .64725 .40623 L 0 .037 .139 r
F
.64437 .4072 m .64296 .4056 L .64584 .40462 L F
.92651 .40125 m .92839 .39862 L .92953 .40031 L 0 .024 .123 r
F
.92651 .40125 m .92537 .39957 L .92839 .39862 L F
.28609 .40286 m .28702 .40039 L .28878 .40207 L 0 .028 .127 r
F
.28609 .40286 m .28434 .40116 L .28702 .40039 L F
.36352 .40585 m .36458 .40312 L .36626 .40485 L 0 .034 .135 r
F
.36352 .40585 m .36184 .40409 L .36458 .40312 L F
.44529 .41101 m .44645 .40895 L .44806 .41037 L 0 .048 .15 r
F
.44529 .41101 m .44368 .40955 L .44645 .40895 L F
.8248 .40208 m .82653 .39942 L .82777 .40111 L 0 .026 .125 r
F
.8248 .40208 m .82356 .40039 L .82653 .39942 L F
.20584 .4025 m .20667 .39983 L .2085 .40154 L 0 .027 .126 r
F
.20584 .4025 m .20402 .4008 L .20667 .39983 L F
.41514 .40787 m .41626 .40539 L .41789 .40706 L 0 .039 .141 r
F
.41514 .40787 m .4135 .40623 L .41626 .40539 L F
.24597 .40271 m .24685 .4001 L .24864 .40177 L 0 .027 .127 r
F
.24597 .40271 m .24417 .40103 L .24685 .4001 L F
.75606 .40353 m .7577 .401 L .759 .40266 L 0 .029 .129 r
F
.75606 .40353 m .75476 .40188 L .7577 .401 L F
.87209 .40196 m .87389 .39932 L .87509 .40103 L 0 .026 .125 r
F
.87209 .40196 m .87089 .40026 L .87389 .39932 L F
.34486 .40455 m .3459 .40183 L .34759 .40361 L 0 .031 .132 r
F
.34486 .40455 m .34317 .40278 L .3459 .40183 L F
.56284 .41428 m .56419 .41196 L .56568 .41342 L 0 .056 .159 r
F
.56284 .41428 m .56135 .41287 L .56419 .41196 L F
.83197 .40181 m .83371 .39915 L .83494 .40085 L 0 .026 .124 r
F
.83197 .40181 m .83074 .40012 L .83371 .39915 L F
.21299 .40222 m .21382 .39965 L .21565 .4013 L 0 .027 .126 r
F
.21299 .40222 m .21116 .40057 L .21382 .39965 L F
.39648 .4066 m .39758 .40402 L .39922 .40584 L 0 .036 .138 r
F
.39648 .4066 m .39484 .40477 L .39758 .40402 L F
.31905 .40364 m .32003 .40106 L .32175 .4028 L 0 .03 .13 r
F
.31905 .40364 m .31733 .40187 L .32003 .40106 L F
.37067 .40564 m .37173 .4031 L .3734 .40478 L 0 .034 .135 r
F
.37067 .40564 m .36899 .40393 L .37173 .4031 L F
.65154 .40704 m .65302 .40456 L .65442 .40622 L 0 .037 .139 r
F
.65154 .40704 m .65013 .4054 L .65302 .40456 L F
.25311 .40249 m .254 .3999 L .25579 .40155 L 0 .027 .126 r
F
.25311 .40249 m .25132 .40083 L .254 .3999 L F
.87926 .4017 m .88108 .39911 L .88226 .40075 L 0 .026 .124 r
F
.87926 .4017 m .87808 .40007 L .88108 .39911 L F
.63722 .40787 m .63868 .40532 L .64009 .40673 L 0 .039 .141 r
F
.63722 .40787 m .63581 .40645 L .63868 .40532 L F
.57715 .41364 m .57853 .4111 L .58 .41255 L 0 .054 .157 r
F
.57715 .41364 m .57568 .41214 L .57853 .4111 L F
.67301 .40592 m .67453 .40353 L .6759 .40502 L 0 .035 .136 r
F
.67301 .40592 m .67163 .40445 L .67453 .40353 L F
.76323 .40334 m .76487 .40065 L .76617 .40236 L 0 .029 .129 r
F
.76323 .40334 m .76193 .40165 L .76487 .40065 L F
.57 .41411 m .57136 .41162 L .57284 .41318 L 0 .056 .158 r
F
.57 .41411 m .56852 .41256 L .57136 .41162 L F
.29322 .40285 m .29417 .40023 L .29592 .40187 L 0 .028 .128 r
F
.29322 .40285 m .29147 .4012 L .29417 .40023 L F
.26025 .40227 m .26115 .39969 L .26293 .40135 L 0 .027 .126 r
F
.26025 .40227 m .25847 .40061 L .26115 .39969 L F
.66586 .40644 m .66737 .40401 L .66875 .40545 L 0 .036 .138 r
F
.66586 .40644 m .66448 .40503 L .66737 .40401 L F
.50124 .41557 m .5025 .41343 L .50405 .41481 L 0 .061 .163 r
F
.50124 .41557 m .49969 .41411 L .5025 .41343 L F
.7704 .40308 m .77206 .40059 L .77335 .40222 L 0 .029 .129 r
F
.7704 .40308 m .76911 .40145 L .77206 .40059 L F
.83916 .40169 m .84092 .39916 L .84214 .40085 L 0 .026 .125 r
F
.83916 .40169 m .83793 .4 L .84092 .39916 L F
.6587 .40688 m .6602 .40446 L .66159 .40598 L 0 .037 .139 r
F
.6587 .40688 m .65731 .40535 L .6602 .40446 L F
.88644 .40152 m .88828 .39902 L .88945 .40066 L 0 .026 .124 r
F
.88644 .40152 m .88527 .39988 L .88828 .39902 L F
.30037 .40252 m .30132 .40008 L .30307 .40171 L 0 .028 .127 r
F
.30037 .40252 m .29863 .40089 L .30132 .40008 L F
.22012 .40213 m .22095 .39965 L .22277 .40131 L 0 .027 .126 r
F
.22012 .40213 m .2183 .40048 L .22095 .39965 L F
.68018 .40577 m .6817 .40326 L .68308 .40491 L 0 .035 .136 r
F
.68018 .40577 m .6788 .40415 L .6817 .40326 L F
.63008 .40857 m .63153 .40611 L .63294 .40751 L 0 .042 .144 r
F
.63008 .40857 m .62866 .40714 L .63153 .40611 L F
.71597 .40381 m .71754 .40112 L .71887 .40275 L 0 .03 .13 r
F
.71597 .40381 m .71463 .40219 L .71754 .40112 L F
.6945 .40503 m .69603 .40234 L .6974 .40403 L 0 .033 .134 r
F
.6945 .40503 m .69313 .40336 L .69603 .40234 L F
.37781 .40563 m .37888 .40302 L .38055 .40473 L 0 .034 .135 r
F
.37781 .40563 m .37614 .40392 L .37888 .40302 L F
.47825 .41218 m .47946 .41036 L .48103 .41188 L 0 .052 .155 r
F
.47825 .41218 m .47667 .41061 L .47946 .41036 L F
.43378 .4098 m .43493 .40747 L .43654 .40925 L 0 .045 .147 r
F
.43378 .4098 m .43216 .40805 L .43493 .40747 L F
.70165 .40465 m .70321 .40209 L .70456 .40368 L 0 .032 .133 r
F
.70165 .40465 m .7003 .40304 L .70321 .40209 L F
.70881 .40428 m .71038 .40173 L .71172 .40327 L 0 .031 .132 r
F
.70881 .40428 m .70747 .40272 L .71038 .40173 L F
.35199 .40468 m .35302 .40216 L .35471 .40398 L 0 .032 .133 r
F
.35199 .40468 m .35031 .40285 L .35302 .40216 L F
.32617 .40369 m .32717 .40117 L .32889 .40285 L 0 .03 .13 r
F
.32617 .40369 m .32446 .40199 L .32717 .40117 L F
.68734 .40548 m .68887 .40272 L .69024 .40441 L 0 .034 .135 r
F
.68734 .40548 m .68597 .40382 L .68887 .40272 L F
.45243 .41124 m .4536 .40933 L .4552 .41069 L 0 .05 .152 r
F
.45243 .41124 m .45083 .40985 L .4536 .40933 L F
.72313 .4035 m .72472 .40097 L .72605 .40266 L 0 .03 .13 r
F
.72313 .4035 m .72179 .40182 L .72472 .40097 L F
.42227 .40808 m .42341 .4057 L .42503 .40744 L 0 .041 .143 r
F
.42227 .40808 m .42065 .40638 L .42341 .4057 L F
.78473 .40254 m .78641 .39988 L .78768 .40151 L 0 .028 .127 r
F
.78473 .40254 m .78346 .40091 L .78641 .39988 L F
.5084 .41545 m .50967 .41371 L .51121 .41485 L 0 .062 .164 r
F
.5084 .41545 m .50686 .41424 L .50967 .41371 L F
.26738 .40216 m .26829 .39962 L .27006 .40131 L 0 .027 .126 r
F
.26738 .40216 m .26561 .40049 L .26829 .39962 L F
.89363 .40138 m .89546 .3987 L .89663 .40038 L 0 .025 .124 r
F
.89363 .40138 m .89246 .39972 L .89546 .3987 L F
.77758 .40298 m .77924 .40035 L .78052 .40196 L 0 .029 .128 r
F
.77758 .40298 m .7763 .40136 L .77924 .40035 L F
.84634 .40159 m .84812 .39905 L .84933 .40066 L 0 .026 .125 r
F
.84634 .40159 m .84513 .39997 L .84812 .39905 L F
.62293 .40916 m .62437 .40668 L .62579 .40816 L 0 .043 .146 r
F
.62293 .40916 m .6215 .40772 L .62437 .40668 L F
.22725 .40204 m .22811 .39937 L .22992 .40106 L 0 .027 .126 r
F
.22725 .40204 m .22543 .40036 L .22811 .39937 L F
.7919 .40226 m .79358 .39957 L .79486 .40131 L 0 .027 .127 r
F
.7919 .40226 m .79063 .40054 L .79358 .39957 L F
.48974 .41419 m .49098 .41231 L .49254 .41375 L 0 .058 .16 r
F
.48974 .41419 m .48818 .4127 L .49098 .41231 L F
.9008 .4011 m .90264 .39845 L .90381 .40019 L 0 .025 .123 r
F
.9008 .4011 m .89963 .39938 L .90264 .39845 L F
.5943 .41084 m .5957 .40879 L .59715 .41004 L 0 .049 .151 r
F
.5943 .41084 m .59285 .40962 L .5957 .40879 L F
.85351 .40133 m .8553 .3988 L .8565 .40041 L 0 .026 .124 r
F
.85351 .40133 m .85231 .39973 L .8553 .3988 L F
.3075 .40258 m .30846 .40015 L .3102 .4018 L 0 .028 .128 r
F
.3075 .40258 m .30576 .40094 L .30846 .40015 L F
.51556 .41531 m .51683 .41357 L .51837 .41469 L 0 .062 .164 r
F
.51556 .41531 m .51402 .41423 L .51683 .41357 L F
.23439 .40182 m .23525 .39925 L .23705 .40099 L 0 .027 .126 r
F
.23439 .40182 m .23259 .4001 L .23525 .39925 L F
.40361 .407 m .40471 .40453 L .40635 .40633 L 0 .038 .14 r
F
.40361 .407 m .40197 .40519 L .40471 .40453 L F
.60146 .41062 m .60287 .40839 L .60432 .4098 L 0 .048 .15 r
F
.60146 .41062 m .60001 .40922 L .60287 .40839 L F
.61578 .40983 m .6172 .4071 L .61864 .40876 L 0 .045 .147 r
F
.61578 .40983 m .61434 .40822 L .6172 .4071 L F
.38494 .40566 m .38604 .40293 L .38769 .40477 L 0 .035 .136 r
F
.38494 .40566 m .38329 .40384 L .38604 .40293 L F
.27452 .40209 m .27544 .39942 L .27721 .40115 L 0 .027 .126 r
F
.27452 .40209 m .27275 .40038 L .27544 .39942 L F
.79908 .40211 m .80077 .39941 L .80204 .40116 L F
.79908 .40211 m .79781 .40037 L .80077 .39941 L F
.73031 .40351 m .73191 .40089 L .73324 .40257 L 0 .03 .13 r
F
.73031 .40351 m .72898 .40182 L .73191 .40089 L F
.33331 .40373 m .33431 .40132 L .33602 .40295 L 0 .031 .131 r
F
.33331 .40373 m .33159 .40208 L .33431 .40132 L F
.8607 .40117 m .86249 .3986 L .86369 .40028 L 0 .025 .124 r
F
.8607 .40117 m .85949 .3995 L .86249 .3986 L F
.58714 .41151 m .58854 .40926 L .58999 .41046 L 0 .05 .153 r
F
.58714 .41151 m .58569 .41032 L .58854 .40926 L F
.73748 .40318 m .73909 .40069 L .7404 .40224 L 0 .03 .13 r
F
.73748 .40318 m .73616 .40162 L .73909 .40069 L F
.45958 .41133 m .46077 .4092 L .46236 .41059 L 0 .05 .153 r
F
.45958 .41133 m .45798 .40996 L .46077 .4092 L F
.908 .40105 m .90985 .39837 L .91102 .40014 L 0 .025 .124 r
F
.908 .40105 m .90683 .39929 L .90985 .39837 L F
.80625 .40188 m .80796 .3992 L .80921 .40088 L 0 .027 .126 r
F
.80625 .40188 m .805 .4002 L .80796 .3992 L F
.81342 .4015 m .81513 .39891 L .81638 .40055 L 0 .026 .125 r
F
.81342 .4015 m .81217 .39987 L .81513 .39891 L F
.74464 .4029 m .74627 .40044 L .74758 .402 L 0 .029 .129 r
F
.74464 .4029 m .74333 .40134 L .74627 .40044 L F
.52272 .41522 m .52401 .41334 L .52553 .41454 L 0 .062 .164 r
F
.52272 .41522 m .52119 .41406 L .52401 .41334 L F
.28166 .40194 m .28258 .39946 L .28434 .40116 L 0 .027 .127 r
F
.28166 .40194 m .2799 .40021 L .28258 .39946 L F
.60862 .41049 m .61004 .40779 L .61148 .40935 L 0 .047 .15 r
F
.60862 .41049 m .60718 .40897 L .61004 .40779 L F
.52987 .4149 m .53118 .41303 L .5327 .41418 L 0 .061 .163 r
F
.52987 .4149 m .52835 .41379 L .53118 .41303 L F
.91518 .40083 m .91704 .39817 L .91819 .39984 L 0 .025 .124 r
F
.91518 .40083 m .91403 .39916 L .91704 .39817 L F
.82059 .40129 m .82233 .39877 L .82356 .40039 L 0 .026 .125 r
F
.82059 .40129 m .81935 .39966 L .82233 .39877 L F
.46673 .41122 m .46793 .40909 L .46952 .41045 L 0 .05 .153 r
F
.46673 .41122 m .46514 .40985 L .46793 .40909 L F
.35911 .40506 m .36016 .40231 L .36184 .40409 L 0 .034 .135 r
F
.35911 .40506 m .35743 .40326 L .36016 .40231 L F
.2415 .40191 m .24238 .39929 L .24417 .40103 L 0 .027 .127 r
F
.2415 .40191 m .23971 .40017 L .24238 .39929 L F
.53703 .41462 m .53835 .4129 L .53986 .41392 L 0 .061 .163 r
F
.53703 .41462 m .53552 .41354 L .53835 .4129 L F
.86789 .40112 m .86969 .39854 L .87089 .40026 L 0 .026 .125 r
F
.86789 .40112 m .86669 .39941 L .86969 .39854 L F
.92235 .40053 m .92423 .39791 L .92537 .39957 L 0 .025 .123 r
F
.92235 .40053 m .92121 .39887 L .92423 .39791 L F
.39209 .40569 m .39319 .40293 L .39484 .40477 L 0 .035 .137 r
F
.39209 .40569 m .39044 .40385 L .39319 .40293 L F
.34044 .40373 m .34146 .40116 L .34317 .40278 L 0 .031 .132 r
F
.34044 .40373 m .33874 .40211 L .34146 .40116 L F
.75182 .40273 m .75346 .40027 L .75476 .40188 L 0 .029 .129 r
F
.75182 .40273 m .75051 .40113 L .75346 .40027 L F
.31462 .40274 m .31561 .40011 L .31733 .40187 L F
.31462 .40274 m .3129 .40096 L .31561 .40011 L F
.44091 .41029 m .44208 .40774 L .44368 .40955 L 0 .047 .15 r
F
.44091 .41029 m .43931 .4085 L .44208 .40774 L F
.41074 .40716 m .41187 .40451 L .4135 .40623 L 0 .039 .141 r
F
.41074 .40716 m .40911 .40542 L .41187 .40451 L F
.54419 .41432 m .54552 .4126 L .54702 .41362 L 0 .06 .162 r
F
.54419 .41432 m .54269 .41324 L .54552 .4126 L F
.4294 .40859 m .43055 .40627 L .43216 .40805 L 0 .043 .146 r
F
.4294 .40859 m .42779 .40685 L .43055 .40627 L F
.64725 .40623 m .64873 .40376 L .65013 .4054 L 0 .037 .139 r
F
.64725 .40623 m .64584 .40462 L .64873 .40376 L F
.36626 .40485 m .36732 .40223 L .36899 .40393 L 0 .034 .135 r
F
.36626 .40485 m .36458 .40312 L .36732 .40223 L F
.47389 .41103 m .47509 .40926 L .47667 .41061 L 0 .051 .153 r
F
.47389 .41103 m .47231 .40968 L .47509 .40926 L F
.82777 .40111 m .8295 .39842 L .83074 .40012 L 0 .026 .125 r
F
.82777 .40111 m .82653 .39942 L .8295 .39842 L F
.2085 .40154 m .20933 .39887 L .21116 .40057 L 0 .027 .126 r
F
.2085 .40154 m .20667 .39983 L .20933 .39887 L F
.64009 .40673 m .64156 .40419 L .64296 .4056 L 0 .039 .14 r
F
.64009 .40673 m .63868 .40532 L .64156 .40419 L F
.24864 .40177 m .24953 .39917 L .25132 .40083 L 0 .027 .127 r
F
.24864 .40177 m .24685 .4001 L .24953 .39917 L F
.55852 .4137 m .55986 .41159 L .56135 .41287 L 0 .058 .16 r
F
.55852 .4137 m .55702 .41245 L .55986 .41159 L F
.55136 .41413 m .55269 .41209 L .55419 .4133 L 0 .059 .161 r
F
.55136 .41413 m .54986 .41292 L .55269 .41209 L F
.34759 .40361 m .34861 .40107 L .35031 .40285 L 0 .031 .132 r
F
.34759 .40361 m .3459 .40183 L .34861 .40107 L F
.87509 .40103 m .87689 .39834 L .87808 .40007 L 0 .026 .125 r
F
.87509 .40103 m .87389 .39932 L .87689 .39834 L F
.58 .41255 m .58137 .41001 L .58284 .41144 L 0 .054 .156 r
F
.58 .41255 m .57853 .4111 L .58137 .41001 L F
.83494 .40085 m .8367 .39828 L .83793 .4 L 0 .026 .124 r
F
.83494 .40085 m .83371 .39915 L .8367 .39828 L F
.759 .40266 m .76063 .39996 L .76193 .40165 L 0 .029 .129 r
F
.759 .40266 m .7577 .401 L .76063 .39996 L F
.28878 .40207 m .28972 .39954 L .29147 .4012 L 0 .028 .128 r
F
.28878 .40207 m .28702 .40039 L .28972 .39954 L F
.49689 .41479 m .49814 .41265 L .49969 .41411 L 0 .061 .163 r
F
.49689 .41479 m .49534 .41324 L .49814 .41265 L F
.41789 .40706 m .41902 .40468 L .42065 .40638 L 0 .04 .142 r
F
.41789 .40706 m .41626 .40539 L .41902 .40468 L F
.56568 .41342 m .56703 .41106 L .56852 .41256 L 0 .057 .159 r
F
.56568 .41342 m .56419 .41196 L .56703 .41106 L F
.21565 .4013 m .21647 .39882 L .2183 .40048 L 0 .027 .126 r
F
.21565 .4013 m .21382 .39965 L .21647 .39882 L F
.88226 .40075 m .88409 .39824 L .88527 .39988 L 0 .026 .124 r
F
.88226 .40075 m .88108 .39911 L .88409 .39824 L F
.25579 .40155 m .25668 .39896 L .25847 .40061 L 0 .027 .126 r
F
.25579 .40155 m .254 .3999 L .25668 .39896 L F
.76617 .40236 m .76781 .3997 L .76911 .40145 L 0 .029 .129 r
F
.76617 .40236 m .76487 .40065 L .76781 .3997 L F
.48539 .4131 m .48661 .41124 L .48818 .4127 L 0 .057 .159 r
F
.48539 .4131 m .48382 .41158 L .48661 .41124 L F
.3734 .40478 m .37447 .40227 L .37614 .40392 L 0 .034 .135 r
F
.3734 .40478 m .37173 .4031 L .37447 .40227 L F
.32175 .4028 m .32274 .40027 L .32446 .40199 L 0 .03 .13 r
F
.32175 .4028 m .32003 .40106 L .32274 .40027 L F
.44806 .41037 m .44922 .40845 L .45083 .40985 L 0 .049 .152 r
F
.44806 .41037 m .44645 .40895 L .44922 .40845 L F
.6759 .40502 m .67743 .40265 L .6788 .40415 L 0 .035 .136 r
F
.6759 .40502 m .67453 .40353 L .67743 .40265 L F
.65442 .40622 m .65591 .40369 L .65731 .40535 L 0 .038 .139 r
F
.65442 .40622 m .65302 .40456 L .65591 .40369 L F
.57284 .41318 m .5742 .41062 L .57568 .41214 L 0 .056 .158 r
F
.57284 .41318 m .57136 .41162 L .5742 .41062 L F
.29592 .40187 m .29688 .39926 L .29863 .40089 L 0 .028 .127 r
F
.29592 .40187 m .29417 .40023 L .29688 .39926 L F
.39922 .40584 m .40033 .40337 L .40197 .40519 L 0 .037 .138 r
F
.39922 .40584 m .39758 .40402 L .40033 .40337 L F
.66875 .40545 m .67026 .40299 L .67163 .40445 L 0 .036 .137 r
F
.66875 .40545 m .66737 .40401 L .67026 .40299 L F
.26293 .40135 m .26383 .39882 L .26561 .40049 L 0 .027 .126 r
F
.26293 .40135 m .26115 .39969 L .26383 .39882 L F
.63294 .40751 m .6344 .40507 L .63581 .40645 L 0 .041 .143 r
F
.63294 .40751 m .63153 .40611 L .6344 .40507 L F
.71887 .40275 m .72046 .40017 L .72179 .40182 L 0 .03 .13 r
F
.71887 .40275 m .71754 .40112 L .72046 .40017 L F
.66159 .40598 m .66309 .40352 L .66448 .40503 L 0 .037 .139 r
F
.66159 .40598 m .6602 .40446 L .66309 .40352 L F
.77335 .40222 m .77502 .39973 L .7763 .40136 L 0 .029 .129 r
F
.77335 .40222 m .77206 .40059 L .77502 .39973 L F
.69024 .40441 m .69176 .40165 L .69313 .40336 L 0 .033 .134 r
F
.69024 .40441 m .68887 .40272 L .69176 .40165 L F
.88945 .40066 m .89129 .39808 L .89246 .39972 L 0 .026 .124 r
F
.88945 .40066 m .88828 .39902 L .89129 .39808 L F
.6974 .40403 m .69894 .40132 L .7003 .40304 L 0 .033 .133 r
F
.6974 .40403 m .69603 .40234 L .69894 .40132 L F
.84214 .40085 m .84391 .39827 L .84513 .39997 L 0 .026 .125 r
F
.84214 .40085 m .84092 .39916 L .84391 .39827 L F
.71172 .40327 m .71329 .40066 L .71463 .40219 L 0 .031 .132 r
F
.71172 .40327 m .71038 .40173 L .71329 .40066 L F
.70456 .40368 m .70612 .40115 L .70747 .40272 L 0 .032 .133 r
F
.70456 .40368 m .70321 .40209 L .70612 .40115 L F
.50405 .41481 m .50531 .41296 L .50686 .41424 L 0 .062 .164 r
F
.50405 .41481 m .5025 .41343 L .50531 .41296 L F
.22277 .40131 m .22362 .39869 L .22543 .40036 L 0 .027 .126 r
F
.22277 .40131 m .22095 .39965 L .22362 .39869 L F
.30307 .40171 m .30402 .3993 L .30576 .40094 L 0 .028 .128 r
F
.30307 .40171 m .30132 .40008 L .30402 .3993 L F
.78768 .40151 m .78936 .39889 L .79063 .40054 L 0 .027 .127 r
F
.78768 .40151 m .78641 .39988 L .78936 .39889 L F
.68308 .40491 m .6846 .40215 L .68597 .40382 L 0 .035 .136 r
F
.68308 .40491 m .6817 .40326 L .6846 .40215 L F
.38055 .40473 m .38163 .40212 L .38329 .40384 L 0 .034 .136 r
F
.38055 .40473 m .37888 .40302 L .38163 .40212 L F
.78052 .40196 m .78219 .39931 L .78346 .40091 L 0 .028 .128 r
F
.78052 .40196 m .77924 .40035 L .78219 .39931 L F
.89663 .40038 m .89846 .39769 L .89963 .39938 L 0 .025 .124 r
F
.89663 .40038 m .89546 .3987 L .89846 .39769 L F
.62579 .40816 m .62724 .40567 L .62866 .40714 L 0 .043 .145 r
F
.62579 .40816 m .62437 .40668 L .62724 .40567 L F
.84933 .40066 m .8511 .39812 L .85231 .39973 L 0 .026 .125 r
F
.84933 .40066 m .84812 .39905 L .8511 .39812 L F
.22992 .40106 m .23078 .39839 L .23259 .4001 L 0 .027 .126 r
F
.22992 .40106 m .22811 .39937 L .23078 .39839 L F
.32889 .40285 m .32988 .40042 L .33159 .40208 L 0 .031 .131 r
F
.32889 .40285 m .32717 .40117 L .32988 .40042 L F
.72605 .40266 m .72765 .40012 L .72898 .40182 L 0 .03 .13 r
F
.72605 .40266 m .72472 .40097 L .72765 .40012 L F
.27006 .40131 m .27098 .39868 L .27275 .40038 L 0 .027 .127 r
F
.27006 .40131 m .26829 .39962 L .27098 .39868 L F
.79486 .40131 m .79654 .39861 L .79781 .40037 L 0 .027 .126 r
F
.79486 .40131 m .79358 .39957 L .79654 .39861 L F
.90381 .40019 m .90566 .39754 L .90683 .39929 L 0 .025 .124 r
F
.90381 .40019 m .90264 .39845 L .90566 .39754 L F
.35471 .40398 m .35574 .40145 L .35743 .40326 L 0 .033 .134 r
F
.35471 .40398 m .35302 .40216 L .35574 .40145 L F
.61864 .40876 m .62006 .40601 L .6215 .40772 L 0 .044 .147 r
F
.61864 .40876 m .6172 .4071 L .62006 .40601 L F
.8565 .40041 m .85829 .39788 L .85949 .3995 L 0 .026 .124 r
F
.8565 .40041 m .8553 .3988 L .85829 .39788 L F
.42503 .40744 m .42617 .40508 L .42779 .40685 L 0 .042 .144 r
F
.42503 .40744 m .42341 .4057 L .42617 .40508 L F
.59715 .41004 m .59856 .40795 L .60001 .40922 L 0 .049 .152 r
F
.59715 .41004 m .5957 .40879 L .59856 .40795 L F
.43654 .40925 m .4377 .4067 L .43931 .4085 L 0 .046 .149 r
F
.43654 .40925 m .43493 .40747 L .4377 .4067 L F
.58999 .41046 m .59139 .4084 L .59285 .40962 L 0 .05 .153 r
F
.58999 .41046 m .58854 .40926 L .59139 .4084 L F
.51121 .41485 m .51248 .41315 L .51402 .41423 L 0 .063 .165 r
F
.51121 .41485 m .50967 .41371 L .51248 .41315 L F
.27721 .40115 m .27814 .39847 L .2799 .40021 L 0 .027 .126 r
F
.27721 .40115 m .27544 .39942 L .27814 .39847 L F
.4552 .41069 m .45638 .40857 L .45798 .40996 L 0 .051 .153 r
F
.4552 .41069 m .4536 .40933 L .45638 .40857 L F
.80204 .40116 m .80373 .39846 L .805 .4002 L 0 .027 .126 r
F
.80204 .40116 m .80077 .39941 L .80373 .39846 L F
.73324 .40257 m .73484 .39995 L .73616 .40162 L 0 .03 .13 r
F
.73324 .40257 m .73191 .40089 L .73484 .39995 L F
.23705 .40099 m .23792 .39839 L .23971 .40017 L 0 .027 .126 r
F
.23705 .40099 m .23525 .39925 L .23792 .39839 L F
.38769 .40477 m .38879 .40201 L .39044 .40385 L 0 .035 .136 r
F
.38769 .40477 m .38604 .40293 L .38879 .40201 L F
.3102 .4018 m .31117 .39929 L .3129 .40096 L 0 .029 .129 r
F
.3102 .4018 m .30846 .40015 L .31117 .39929 L F
.61148 .40935 m .6129 .40661 L .61434 .40822 L 0 .046 .149 r
F
.61148 .40935 m .61004 .40779 L .6129 .40661 L F
.7404 .40224 m .74202 .39978 L .74333 .40134 L 0 .03 .13 r
F
.7404 .40224 m .73909 .40069 L .74202 .39978 L F
.60432 .4098 m .60574 .40756 L .60718 .40897 L 0 .048 .151 r
F
.60432 .4098 m .60287 .40839 L .60574 .40756 L F
.80921 .40088 m .81092 .39818 L .81217 .39987 L 0 .027 .126 r
F
.80921 .40088 m .80796 .3992 L .81092 .39818 L F
.86369 .40028 m .86549 .39772 L .86669 .39941 L 0 .026 .124 r
F
.86369 .40028 m .86249 .3986 L .86549 .39772 L F
.91102 .40014 m .91286 .39739 L .91403 .39916 L 0 .025 .124 r
F
.91102 .40014 m .90985 .39837 L .91286 .39739 L F
.81638 .40055 m .81811 .39803 L .81935 .39966 L 0 .026 .125 r
F
.81638 .40055 m .81513 .39891 L .81811 .39803 L F
.48103 .41188 m .48225 .4101 L .48382 .41158 L 0 .055 .158 r
F
.48103 .41188 m .47946 .41036 L .48225 .4101 L F
.33602 .40295 m .33702 .40049 L .33874 .40211 L 0 .032 .132 r
F
.33602 .40295 m .33431 .40132 L .33702 .40049 L F
.40635 .40633 m .40747 .40364 L .40911 .40542 L 0 .039 .141 r
F
.40635 .40633 m .40471 .40453 L .40747 .40364 L F
.51837 .41469 m .51965 .4129 L .52119 .41406 L 0 .063 .165 r
F
.51837 .41469 m .51683 .41357 L .51965 .4129 L F
.74758 .402 m .74921 .39956 L .75051 .40113 L 0 .03 .13 r
F
.74758 .402 m .74627 .40044 L .74921 .39956 L F
.91819 .39984 m .92006 .3972 L .92121 .39887 L 0 .025 .123 r
F
.91819 .39984 m .91704 .39817 L .92006 .3972 L F
.49254 .41375 m .49378 .41186 L .49534 .41324 L 0 .06 .163 r
F
.49254 .41375 m .49098 .41231 L .49378 .41186 L F
.46236 .41059 m .46355 .40845 L .46514 .40985 L 0 .051 .154 r
F
.46236 .41059 m .46077 .4092 L .46355 .40845 L F
.36184 .40409 m .3629 .40137 L .36458 .40312 L 0 .034 .135 r
F
.36184 .40409 m .36016 .40231 L .3629 .40137 L F
.92537 .39957 m .92725 .39695 L .92839 .39862 L 0 .024 .123 r
F
.92537 .39957 m .92423 .39791 L .92725 .39695 L F
.28434 .40116 m .28527 .39871 L .28702 .40039 L 0 .028 .127 r
F
.28434 .40116 m .28258 .39946 L .28527 .39871 L F
.82356 .40039 m .8253 .3978 L .82653 .39942 L 0 .026 .125 r
F
.82356 .40039 m .82233 .39877 L .8253 .3978 L F
.34317 .40278 m .34419 .40022 L .3459 .40183 L 0 .031 .132 r
F
.34317 .40278 m .34146 .40116 L .34419 .40022 L F
.39484 .40477 m .39594 .40218 L .39758 .40402 L 0 .036 .137 r
F
.39484 .40477 m .39319 .40293 L .39594 .40218 L F
.20402 .4008 m .20485 .39805 L .20667 .39983 L 0 .027 .126 r
F
.20402 .4008 m .20219 .39903 L .20485 .39805 L F
.52553 .41454 m .52683 .41253 L .52835 .41379 L 0 .063 .165 r
F
.52553 .41454 m .52401 .41334 L .52683 .41253 L F
.24417 .40103 m .24506 .39836 L .24685 .4001 L 0 .027 .127 r
F
.24417 .40103 m .24238 .39929 L .24506 .39836 L F
.64296 .4056 m .64444 .40319 L .64584 .40462 L 0 .038 .14 r
F
.64296 .4056 m .64156 .40419 L .64444 .40319 L F
.87089 .40026 m .87269 .39758 L .87389 .39932 L 0 .026 .125 r
F
.87089 .40026 m .86969 .39854 L .87269 .39758 L F
.4135 .40623 m .41463 .40368 L .41626 .40539 L 0 .039 .141 r
F
.4135 .40623 m .41187 .40451 L .41463 .40368 L F
.5327 .41418 m .534 .41245 L .53552 .41354 L 0 .062 .164 r
F
.5327 .41418 m .53118 .41303 L .534 .41245 L F
.31733 .40187 m .31831 .39931 L .32003 .40106 L 0 .029 .129 r
F
.31733 .40187 m .31561 .40011 L .31831 .39931 L F
.75476 .40188 m .7564 .39938 L .7577 .401 L 0 .03 .13 r
F
.75476 .40188 m .75346 .40027 L .7564 .39938 L F
.58284 .41144 m .58422 .40893 L .58569 .41032 L 0 .053 .155 r
F
.58284 .41144 m .58137 .41001 L .58422 .40893 L F
.83074 .40012 m .83248 .39744 L .83371 .39915 L 0 .026 .124 r
F
.83074 .40012 m .8295 .39842 L .83248 .39744 L F
.46952 .41045 m .47072 .40833 L .47231 .40968 L 0 .051 .154 r
F
.46952 .41045 m .46793 .40909 L .47072 .40833 L F
.36899 .40393 m .37005 .40142 L .37173 .4031 L 0 .034 .135 r
F
.36899 .40393 m .36732 .40223 L .37005 .40142 L F
.21116 .40057 m .21199 .39795 L .21382 .39965 L 0 .027 .126 r
F
.21116 .40057 m .20933 .39887 L .21199 .39795 L F
.53986 .41392 m .54118 .41228 L .54269 .41324 L 0 .062 .164 r
F
.53986 .41392 m .53835 .4129 L .54118 .41228 L F
.44368 .40955 m .44485 .40714 L .44645 .40895 L 0 .048 .151 r
F
.44368 .40955 m .44208 .40774 L .44485 .40714 L F
.65013 .4054 m .65162 .4029 L .65302 .40456 L 0 .038 .139 r
F
.65013 .4054 m .64873 .40376 L .65162 .4029 L F
.25132 .40083 m .25221 .39824 L .254 .3999 L 0 .027 .127 r
F
.25132 .40083 m .24953 .39917 L .25221 .39824 L F
.76193 .40165 m .76357 .39893 L .76487 .40065 L 0 .029 .129 r
F
.76193 .40165 m .76063 .39996 L .76357 .39893 L F
.87808 .40007 m .87988 .39737 L .88108 .39911 L 0 .026 .124 r
F
.87808 .40007 m .87689 .39834 L .87988 .39737 L F
.54702 .41362 m .54836 .41196 L .54986 .41292 L 0 .061 .163 r
F
.54702 .41362 m .54552 .4126 L .54836 .41196 L F
.56135 .41287 m .5627 .41065 L .56419 .41196 L 0 .058 .16 r
F
.56135 .41287 m .55986 .41159 L .5627 .41065 L F
.55419 .4133 m .55553 .41121 L .55702 .41245 L 0 .06 .162 r
F
.55419 .4133 m .55269 .41209 L .55553 .41121 L F
.83793 .4 m .83969 .39742 L .84092 .39916 L 0 .026 .125 r
F
.83793 .4 m .8367 .39828 L .83969 .39742 L F
.29147 .4012 m .29242 .39858 L .29417 .40023 L 0 .028 .128 r
F
.29147 .4012 m .28972 .39954 L .29242 .39858 L F
.25847 .40061 m .25937 .39804 L .26115 .39969 L 0 .027 .126 r
F
.25847 .40061 m .25668 .39896 L .25937 .39804 L F
.57568 .41214 m .57705 .40962 L .57853 .4111 L 0 .055 .158 r
F
.57568 .41214 m .5742 .41062 L .57705 .40962 L F
.56852 .41256 m .56988 .41012 L .57136 .41162 L 0 .057 .159 r
F
.56852 .41256 m .56703 .41106 L .56988 .41012 L F
.76911 .40145 m .77076 .39881 L .77206 .40059 L 0 .029 .129 r
F
.76911 .40145 m .76781 .3997 L .77076 .39881 L F
.35031 .40285 m .35133 .40039 L .35302 .40216 L 0 .032 .133 r
F
.35031 .40285 m .34861 .40107 L .35133 .40039 L F
.2183 .40048 m .21913 .39799 L .22095 .39965 L 0 .027 .126 r
F
.2183 .40048 m .21647 .39882 L .21913 .39799 L F
.88527 .39988 m .8871 .39737 L .88828 .39902 L 0 .026 .125 r
F
.88527 .39988 m .88409 .39824 L .8871 .39737 L F
.67163 .40445 m .67315 .40204 L .67453 .40353 L 0 .036 .137 r
F
.67163 .40445 m .67026 .40299 L .67315 .40204 L F
.63581 .40645 m .63727 .40394 L .63868 .40532 L 0 .04 .142 r
F
.63581 .40645 m .6344 .40507 L .63727 .40394 L F
.29863 .40089 m .29958 .39844 L .30132 .40008 L 0 .028 .128 r
F
.29863 .40089 m .29688 .39926 L .29958 .39844 L F
.43216 .40805 m .43331 .40566 L .43493 .40747 L 0 .045 .147 r
F
.43216 .40805 m .43055 .40627 L .43331 .40566 L F
.37614 .40392 m .37721 .40139 L .37888 .40302 L 0 .035 .136 r
F
.37614 .40392 m .37447 .40227 L .37721 .40139 L F
.6788 .40415 m .68033 .40174 L .6817 .40326 L 0 .035 .137 r
F
.6788 .40415 m .67743 .40265 L .68033 .40174 L F
.65731 .40535 m .6588 .40281 L .6602 .40446 L 0 .038 .14 r
F
.65731 .40535 m .65591 .40369 L .6588 .40281 L F
.69313 .40336 m .69467 .40059 L .69603 .40234 L 0 .033 .134 r
F
.69313 .40336 m .69176 .40165 L .69467 .40059 L F
.32446 .40199 m .32545 .39948 L .32717 .40117 L 0 .03 .131 r
F
.32446 .40199 m .32274 .40027 L .32545 .39948 L F
.49969 .41411 m .50095 .41206 L .5025 .41343 L 0 .062 .164 r
F
.49969 .41411 m .49814 .41265 L .50095 .41206 L F
.71463 .40219 m .7162 .39959 L .71754 .40112 L 0 .031 .131 r
F
.71463 .40219 m .71329 .40066 L .7162 .39959 L F
.42065 .40638 m .42178 .40396 L .42341 .4057 L 0 .041 .143 r
F
.42065 .40638 m .41902 .40468 L .42178 .40396 L F
.72179 .40182 m .72338 .39931 L .72472 .40097 L 0 .03 .13 r
F
.72179 .40182 m .72046 .40017 L .72338 .39931 L F
.68597 .40382 m .68749 .40103 L .68887 .40272 L 0 .034 .135 r
F
.68597 .40382 m .6846 .40215 L .68749 .40103 L F
.7003 .40304 m .70185 .40038 L .70321 .40209 L 0 .032 .133 r
F
.7003 .40304 m .69894 .40132 L .70185 .40038 L F
.66448 .40503 m .66598 .40247 L .66737 .40401 L 0 .037 .139 r
F
.66448 .40503 m .66309 .40352 L .66598 .40247 L F
.47667 .41061 m .47788 .409 L .47946 .41036 L 0 .053 .156 r
F
.47667 .41061 m .47509 .40926 L .47788 .409 L F
.26561 .40049 m .26652 .39794 L .26829 .39962 L 0 .027 .127 r
F
.26561 .40049 m .26383 .39882 L .26652 .39794 L F
.89246 .39972 m .89429 .39706 L .89546 .3987 L 0 .026 .124 r
F
.89246 .39972 m .89129 .39808 L .89429 .39706 L F
.78346 .40091 m .78513 .39827 L .78641 .39988 L 0 .028 .128 r
F
.78346 .40091 m .78219 .39931 L .78513 .39827 L F
.70747 .40272 m .70904 .40018 L .71038 .40173 L 0 .032 .133 r
F
.70747 .40272 m .70612 .40115 L .70904 .40018 L F
.79063 .40054 m .79231 .39789 L .79358 .39957 L 0 .027 .127 r
F
.79063 .40054 m .78936 .39889 L .79231 .39789 L F
.22543 .40036 m .22629 .3977 L .22811 .39937 L 0 .027 .126 r
F
.22543 .40036 m .22362 .39869 L .22629 .3977 L F
.84513 .39997 m .8469 .39736 L .84812 .39905 L 0 .026 .125 r
F
.84513 .39997 m .84391 .39827 L .8469 .39736 L F
.89963 .39938 m .90147 .39674 L .90264 .39845 L 0 .025 .124 r
F
.89963 .39938 m .89846 .39769 L .90147 .39674 L F
.7763 .40136 m .77796 .39871 L .77924 .40035 L 0 .029 .129 r
F
.7763 .40136 m .77502 .39973 L .77796 .39871 L F
.62866 .40714 m .63011 .40466 L .63153 .40611 L 0 .043 .145 r
F
.62866 .40714 m .62724 .40567 L .63011 .40466 L F
.40197 .40519 m .40308 .40272 L .40471 .40453 L 0 .038 .14 r
F
.40197 .40519 m .40033 .40337 L .40308 .40272 L F
.38329 .40384 m .38438 .40121 L .38604 .40293 L 0 .035 .136 r
F
.38329 .40384 m .38163 .40212 L .38438 .40121 L F
.23259 .4001 m .23345 .3975 L .23525 .39925 L 0 .027 .126 r
F
.23259 .4001 m .23078 .39839 L .23345 .3975 L F
.45083 .40985 m .452 .40796 L .4536 .40933 L 0 .051 .154 r
F
.45083 .40985 m .44922 .40845 L .452 .40796 L F
.85231 .39973 m .85409 .39719 L .8553 .3988 L 0 .026 .125 r
F
.85231 .39973 m .8511 .39812 L .85409 .39719 L F
.30576 .40094 m .30672 .3985 L .30846 .40015 L 0 .029 .128 r
F
.30576 .40094 m .30402 .3993 L .30672 .3985 L F
.6215 .40772 m .62293 .40493 L .62437 .40668 L 0 .044 .146 r
F
.6215 .40772 m .62006 .40601 L .62293 .40493 L F
.79781 .40037 m .7995 .39766 L .80077 .39941 L 0 .027 .126 r
F
.79781 .40037 m .79654 .39861 L .7995 .39766 L F
.48818 .4127 m .48941 .41089 L .49098 .41231 L 0 .059 .162 r
F
.48818 .4127 m .48661 .41124 L .48941 .41089 L F
.27275 .40038 m .27368 .3977 L .27544 .39942 L 0 .027 .126 r
F
.27275 .40038 m .27098 .39868 L .27368 .3977 L F
.72898 .40182 m .73058 .39919 L .73191 .40089 L 0 .03 .131 r
F
.72898 .40182 m .72765 .40012 L .73058 .39919 L F
.61434 .40822 m .61576 .40544 L .6172 .4071 L 0 .045 .148 r
F
.61434 .40822 m .6129 .40661 L .61576 .40544 L F
.90683 .39929 m .90868 .3966 L .90985 .39837 L 0 .025 .124 r
F
.90683 .39929 m .90566 .39754 L .90868 .3966 L F
.85949 .3995 m .86129 .39697 L .86249 .3986 L 0 .026 .125 r
F
.85949 .3995 m .85829 .39788 L .86129 .39697 L F
.33159 .40208 m .33259 .39967 L .33431 .40132 L 0 .031 .132 r
F
.33159 .40208 m .32988 .40042 L .33259 .39967 L F
.50686 .41424 m .50812 .41253 L .50967 .41371 L 0 .064 .166 r
F
.50686 .41424 m .50531 .41296 L .50812 .41253 L F
.805 .4002 m .80669 .39743 L .80796 .3992 L 0 .027 .126 r
F
.805 .4002 m .80373 .39846 L .80669 .39743 L F
.2799 .40021 m .28082 .39771 L .28258 .39946 L 0 .027 .127 r
F
.2799 .40021 m .27814 .39847 L .28082 .39771 L F
.73616 .40162 m .73777 .39901 L .73909 .40069 L 0 .03 .13 r
F
.73616 .40162 m .73484 .39995 L .73777 .39901 L F
.81217 .39987 m .81388 .39723 L .81513 .39891 L 0 .026 .126 r
F
.81217 .39987 m .81092 .39818 L .81388 .39723 L F
.60001 .40922 m .60143 .40711 L .60287 .40839 L 0 .049 .152 r
F
.60001 .40922 m .59856 .40795 L .60143 .40711 L F
.39044 .40385 m .39154 .40109 L .39319 .40293 L 0 .035 .136 r
F
.39044 .40385 m .38879 .40201 L .39154 .40109 L F
.35743 .40326 m .35848 .40053 L .36016 .40231 L 0 .034 .135 r
F
.35743 .40326 m .35574 .40145 L .35848 .40053 L F
.59285 .40962 m .59425 .40754 L .5957 .40879 L 0 .051 .153 r
F
.59285 .40962 m .59139 .4084 L .59425 .40754 L F
.74333 .40134 m .74496 .39887 L .74627 .40044 L 0 .03 .13 r
F
.74333 .40134 m .74202 .39978 L .74496 .39887 L F
.43931 .4085 m .44047 .40592 L .44208 .40774 L 0 .047 .149 r
F
.43931 .4085 m .4377 .4067 L .44047 .40592 L F
.91403 .39916 m .91588 .3964 L .91704 .39817 L 0 .025 .124 r
F
.91403 .39916 m .91286 .39739 L .91588 .3964 L F
.3129 .40096 m .31388 .39844 L .31561 .40011 L 0 .029 .129 r
F
.3129 .40096 m .31117 .39929 L .31388 .39844 L F
.23971 .40017 m .24059 .39749 L .24238 .39929 L 0 .027 .126 r
F
.23971 .40017 m .23792 .39839 L .24059 .39749 L F
.86669 .39941 m .86849 .39684 L .86969 .39854 L 0 .026 .125 r
F
.86669 .39941 m .86549 .39772 L .86849 .39684 L F
.45798 .40996 m .45917 .4078 L .46077 .4092 L 0 .052 .154 r
F
.45798 .40996 m .45638 .40857 L .45917 .4078 L F
.60718 .40897 m .6086 .40634 L .61004 .40779 L 0 .048 .151 r
F
.60718 .40897 m .60574 .40756 L .6086 .40634 L F
.40911 .40542 m .41024 .40275 L .41187 .40451 L 0 .039 .141 r
F
.40911 .40542 m .40747 .40364 L .41024 .40275 L F
.81935 .39966 m .82109 .39715 L .82233 .39877 L 0 .026 .126 r
F
.81935 .39966 m .81811 .39803 L .82109 .39715 L F
.92121 .39887 m .92308 .39623 L .92423 .39791 L 0 .025 .123 r
F
.92121 .39887 m .92006 .3972 L .92308 .39623 L F
.42779 .40685 m .42893 .40447 L .43055 .40627 L 0 .043 .145 r
F
.42779 .40685 m .42617 .40508 L .42893 .40447 L F
.33874 .40211 m .33975 .39955 L .34146 .40116 L 0 .032 .132 r
F
.33874 .40211 m .33702 .40049 L .33975 .39955 L F
.51402 .41423 m .5153 .41247 L .51683 .41357 L 0 .065 .167 r
F
.51402 .41423 m .51248 .41315 L .5153 .41247 L F
.75051 .40113 m .75215 .3987 L .75346 .40027 L 0 .03 .13 r
F
.75051 .40113 m .74921 .39956 L .75215 .3987 L F
.36458 .40312 m .36564 .4005 L .36732 .40223 L 0 .034 .135 r
F
.36458 .40312 m .3629 .40137 L .36564 .4005 L F
.58569 .41032 m .58707 .40788 L .58854 .40926 L 0 .052 .155 r
F
.58569 .41032 m .58422 .40893 L .58707 .40788 L F
.82653 .39942 m .82827 .39681 L .8295 .39842 L 0 .026 .125 r
F
.82653 .39942 m .8253 .3978 L .82827 .39681 L F
.20667 .39983 m .20751 .39707 L .20933 .39887 L 0 .027 .126 r
F
.20667 .39983 m .20485 .39805 L .20751 .39707 L F
.3459 .40183 m .34691 .39945 L .34861 .40107 L 0 .032 .132 r
F
.3459 .40183 m .34419 .40022 L .34691 .39945 L F
.64584 .40462 m .64732 .4023 L .64873 .40376 L 0 .038 .14 r
F
.64584 .40462 m .64444 .40319 L .64732 .4023 L F
.24685 .4001 m .24774 .39743 L .24953 .39917 L 0 .027 .127 r
F
.24685 .4001 m .24506 .39836 L .24774 .39743 L F
.46514 .40985 m .46634 .40769 L .46793 .40909 L 0 .052 .154 r
F
.46514 .40985 m .46355 .40845 L .46634 .40769 L F
.87389 .39932 m .87569 .39659 L .87689 .39834 L 0 .026 .125 r
F
.87389 .39932 m .87269 .39758 L .87569 .39659 L F
.83371 .39915 m .83546 .39656 L .8367 .39828 L 0 .026 .124 r
F
.83371 .39915 m .83248 .39744 L .83546 .39656 L F
.52119 .41406 m .52247 .41213 L .52401 .41334 L 0 .064 .166 r
F
.52119 .41406 m .51965 .4129 L .52247 .41213 L F
.28702 .40039 m .28796 .39787 L .28972 .39954 L 0 .028 .128 r
F
.28702 .40039 m .28527 .39871 L .28796 .39787 L F
.7577 .401 m .75933 .39832 L .76063 .39996 L 0 .029 .129 r
F
.7577 .401 m .7564 .39938 L .75933 .39832 L F
.41626 .40539 m .41739 .40299 L .41902 .40468 L 0 .04 .142 r
F
.41626 .40539 m .41463 .40368 L .41739 .40299 L F
.39758 .40402 m .39868 .40154 L .40033 .40337 L 0 .037 .138 r
F
.39758 .40402 m .39594 .40218 L .39868 .40154 L F
.21382 .39965 m .21465 .39711 L .21647 .39882 L 0 .027 .126 r
F
.21382 .39965 m .21199 .39795 L .21465 .39711 L F
.76487 .40065 m .76651 .39796 L .76781 .3997 L 0 .029 .128 r
F
.76487 .40065 m .76357 .39893 L .76651 .39796 L F
.32003 .40106 m .32102 .39855 L .32274 .40027 L 0 .03 .13 r
F
.32003 .40106 m .31831 .39931 L .32102 .39855 L F
.52835 .41379 m .52965 .41173 L .53118 .41303 L 0 .063 .165 r
F
.52835 .41379 m .52683 .41253 L .52965 .41173 L F
.254 .3999 m .25489 .39731 L .25668 .39896 L 0 .027 .127 r
F
.254 .3999 m .25221 .39824 L .25489 .39731 L F
.88108 .39911 m .8829 .39649 L .88409 .39824 L 0 .026 .125 r
F
.88108 .39911 m .87988 .39737 L .8829 .39649 L F
.37173 .4031 m .37279 .40061 L .37447 .40227 L 0 .034 .136 r
F
.37173 .4031 m .37005 .40142 L .37279 .40061 L F
.49534 .41324 m .49658 .41137 L .49814 .41265 L 0 .062 .164 r
F
.49534 .41324 m .49378 .41186 L .49658 .41137 L F
.47231 .40968 m .47351 .40791 L .47509 .40926 L 0 .052 .155 r
F
.47231 .40968 m .47072 .40833 L .47351 .40791 L F
.63868 .40532 m .64015 .40282 L .64156 .40419 L 0 .04 .142 r
F
.63868 .40532 m .63727 .40394 L .64015 .40282 L F
.57853 .4111 m .5799 .40857 L .58137 .41001 L 0 .055 .157 r
F
.57853 .4111 m .57705 .40962 L .5799 .40857 L F
.65302 .40456 m .65451 .40203 L .65591 .40369 L 0 .038 .14 r
F
.65302 .40456 m .65162 .4029 L .65451 .40203 L F
.53552 .41354 m .53683 .41187 L .53835 .4129 L 0 .064 .166 r
F
.53552 .41354 m .534 .41245 L .53683 .41187 L F
.29417 .40023 m .29513 .39763 L .29688 .39926 L 0 .028 .128 r
F
.29417 .40023 m .29242 .39858 L .29513 .39763 L F
.56419 .41196 m .56555 .4097 L .56703 .41106 L 0 .058 .16 r
F
.56419 .41196 m .5627 .41065 L .56555 .4097 L F
.48382 .41158 m .48504 .40978 L .48661 .41124 L F
.48382 .41158 m .48225 .4101 L .48504 .40978 L F
.26115 .39969 m .26205 .39716 L .26383 .39882 L 0 .027 .127 r
F
.26115 .39969 m .25937 .39804 L .26205 .39716 L F
.57136 .41162 m .57272 .40916 L .5742 .41062 L 0 .057 .159 r
F
.57136 .41162 m .56988 .41012 L .57272 .40916 L F
.54269 .41324 m .54402 .4117 L .54552 .4126 L 0 .063 .165 r
F
.54269 .41324 m .54118 .41228 L .54402 .4117 L F
.71754 .40112 m .71912 .39864 L .72046 .40017 L 0 .03 .131 r
F
.71754 .40112 m .7162 .39959 L .71912 .39864 L F
.55702 .41245 m .55837 .41032 L .55986 .41159 L 0 .06 .162 r
F
.55702 .41245 m .55553 .41121 L .55837 .41032 L F
.68887 .40272 m .69039 .39993 L .69176 .40165 L 0 .033 .134 r
F
.68887 .40272 m .68749 .40103 L .69039 .39993 L F
.84092 .39916 m .84268 .39653 L .84391 .39827 L 0 .026 .125 r
F
.84092 .39916 m .83969 .39742 L .84268 .39653 L F
.69603 .40234 m .69757 .39954 L .69894 .40132 L 0 .033 .133 r
F
.69603 .40234 m .69467 .40059 L .69757 .39954 L F
.67453 .40353 m .67606 .40114 L .67743 .40265 L 0 .036 .137 r
F
.67453 .40353 m .67315 .40204 L .67606 .40114 L F
.77206 .40059 m .77372 .39793 L .77502 .39973 L 0 .029 .129 r
F
.77206 .40059 m .77076 .39881 L .77372 .39793 L F
.54986 .41292 m .55119 .41111 L .55269 .41209 L 0 .062 .164 r
F
.54986 .41292 m .54836 .41196 L .55119 .41111 L F
.44645 .40895 m .44762 .40666 L .44922 .40845 L 0 .05 .152 r
F
.44645 .40895 m .44485 .40714 L .44762 .40666 L F
.88828 .39902 m .89011 .39643 L .89129 .39808 L 0 .026 .125 r
F
.88828 .39902 m .8871 .39737 L .89011 .39643 L F
.66737 .40401 m .66887 .40141 L .67026 .40299 L 0 .037 .138 r
F
.66737 .40401 m .66598 .40247 L .66887 .40141 L F
.37888 .40302 m .37996 .40051 L .38163 .40212 L 0 .035 .136 r
F
.37888 .40302 m .37721 .40139 L .37996 .40051 L F
.22095 .39965 m .2218 .39703 L .22362 .39869 L 0 .027 .127 r
F
.22095 .39965 m .21913 .39799 L .2218 .39703 L F
.30132 .40008 m .30228 .39766 L .30402 .3993 L 0 .028 .128 r
F
.30132 .40008 m .29958 .39844 L .30228 .39766 L F
.6817 .40326 m .68323 .40062 L .6846 .40215 L 0 .035 .136 r
F
.6817 .40326 m .68033 .40174 L .68323 .40062 L F
.78641 .39988 m .78809 .39725 L .78936 .39889 L 0 .028 .127 r
F
.78641 .39988 m .78513 .39827 L .78809 .39725 L F
.6602 .40446 m .66169 .40186 L .66309 .40352 L 0 .038 .14 r
F
.6602 .40446 m .6588 .40281 L .66169 .40186 L F
.89546 .3987 m .89729 .39603 L .89846 .39769 L 0 .025 .124 r
F
.89546 .3987 m .89429 .39706 L .89729 .39603 L F
.70321 .40209 m .70477 .39945 L .70612 .40115 L 0 .032 .133 r
F
.70321 .40209 m .70185 .40038 L .70477 .39945 L F
.71038 .40173 m .71195 .39912 L .71329 .40066 L 0 .032 .132 r
F
.71038 .40173 m .70904 .40018 L .71195 .39912 L F
.77924 .40035 m .78091 .39767 L .78219 .39931 L 0 .029 .128 r
F
.77924 .40035 m .77796 .39871 L .78091 .39767 L F
.63153 .40611 m .63299 .40364 L .6344 .40507 L 0 .042 .144 r
F
.63153 .40611 m .63011 .40466 L .63299 .40364 L F
.22811 .39937 m .22897 .39671 L .23078 .39839 L 0 .027 .126 r
F
.22811 .39937 m .22629 .3977 L .22897 .39671 L F
.79358 .39957 m .79527 .39693 L .79654 .39861 L F
.79358 .39957 m .79231 .39789 L .79527 .39693 L F
.72472 .40097 m .72631 .39844 L .72765 .40012 L 0 .03 .13 r
F
.72472 .40097 m .72338 .39931 L .72631 .39844 L F
.35302 .40216 m .35406 .39968 L .35574 .40145 L 0 .033 .134 r
F
.35302 .40216 m .35133 .40039 L .35406 .39968 L F
.32717 .40117 m .32816 .39875 L .32988 .40042 L 0 .031 .131 r
F
.32717 .40117 m .32545 .39948 L .32816 .39875 L F
.26829 .39962 m .26921 .39698 L .27098 .39868 L 0 .027 .127 r
F
.26829 .39962 m .26652 .39794 L .26921 .39698 L F
.90264 .39845 m .90449 .39581 L .90566 .39754 L 0 .025 .124 r
F
.90264 .39845 m .90147 .39674 L .90449 .39581 L F
.84812 .39905 m .84989 .39644 L .8511 .39812 L 0 .026 .125 r
F
.84812 .39905 m .8469 .39736 L .84989 .39644 L F
.43493 .40747 m .43609 .40488 L .4377 .4067 L 0 .046 .148 r
F
.43493 .40747 m .43331 .40566 L .43609 .40488 L F
.5025 .41343 m .50376 .41168 L .50531 .41296 L 0 .064 .166 r
F
.5025 .41343 m .50095 .41206 L .50376 .41168 L F
.62437 .40668 m .6258 .40393 L .62724 .40567 L 0 .043 .146 r
F
.62437 .40668 m .62293 .40493 L .6258 .40393 L F
.42341 .4057 m .42455 .40331 L .42617 .40508 L 0 .042 .144 r
F
.42341 .4057 m .42178 .40396 L .42455 .40331 L F
.6172 .4071 m .61862 .40431 L .62006 .40601 L 0 .044 .147 r
F
.6172 .4071 m .61576 .40544 L .61862 .40431 L F
.38604 .40293 m .38713 .40029 L .38879 .40201 L 0 .035 .136 r
F
.38604 .40293 m .38438 .40121 L .38713 .40029 L F
.8553 .3988 m .85709 .39625 L .85829 .39788 L 0 .026 .125 r
F
.8553 .3988 m .85409 .39719 L .85709 .39625 L F
.80077 .39941 m .80246 .3967 L .80373 .39846 L 0 .027 .126 r
F
.80077 .39941 m .7995 .39766 L .80246 .3967 L F
.27544 .39942 m .27638 .39673 L .27814 .39847 L F
.27544 .39942 m .27368 .3977 L .27638 .39673 L F
.23525 .39925 m .23612 .39662 L .23792 .39839 L F
.23525 .39925 m .23345 .3975 L .23612 .39662 L F
.73191 .40089 m .73351 .39825 L .73484 .39995 L 0 .03 .131 r
F
.73191 .40089 m .73058 .39919 L .73351 .39825 L F
.30846 .40015 m .30943 .39763 L .31117 .39929 L 0 .029 .129 r
F
.30846 .40015 m .30672 .3985 L .30943 .39763 L F
.40471 .40453 m .40583 .40186 L .40747 .40364 L 0 .039 .14 r
F
.40471 .40453 m .40308 .40272 L .40583 .40186 L F
.90985 .39837 m .91169 .39561 L .91286 .39739 L 0 .025 .124 r
F
.90985 .39837 m .90868 .3966 L .91169 .39561 L F
.86249 .3986 m .86429 .39609 L .86549 .39772 L 0 .026 .125 r
F
.86249 .3986 m .86129 .39697 L .86429 .39609 L F
.80796 .3992 m .80965 .39641 L .81092 .39818 L 0 .027 .126 r
F
.80796 .3992 m .80669 .39743 L .80965 .39641 L F
.61004 .40779 m .61146 .40512 L .6129 .40661 L 0 .047 .149 r
F
.61004 .40779 m .6086 .40634 L .61146 .40512 L F
.73909 .40069 m .7407 .39807 L .74202 .39978 L 0 .03 .13 r
F
.73909 .40069 m .73777 .39901 L .7407 .39807 L F
.81513 .39891 m .81686 .39635 L .81811 .39803 L 0 .027 .126 r
F
.81513 .39891 m .81388 .39723 L .81686 .39635 L F
.33431 .40132 m .33531 .39886 L .33702 .40049 L 0 .032 .132 r
F
.33431 .40132 m .33259 .39967 L .33531 .39886 L F
.36016 .40231 m .36122 .39961 L .3629 .40137 L 0 .034 .135 r
F
.36016 .40231 m .35848 .40053 L .36122 .39961 L F
.39319 .40293 m .39429 .40035 L .39594 .40218 L 0 .035 .137 r
F
.39319 .40293 m .39154 .40109 L .39429 .40035 L F
.91704 .39817 m .9189 .39542 L .92006 .3972 L 0 .025 .123 r
F
.91704 .39817 m .91588 .3964 L .9189 .39542 L F
.4536 .40933 m .45478 .40719 L .45638 .40857 L 0 .052 .155 r
F
.4536 .40933 m .452 .40796 L .45478 .40719 L F
.47946 .41036 m .48067 .40873 L .48225 .4101 L 0 .056 .159 r
F
.47946 .41036 m .47788 .409 L .48067 .40873 L F
.20219 .39903 m .20302 .39626 L .20485 .39805 L 0 .027 .126 r
F
.20219 .39903 m .20036 .39726 L .20302 .39626 L F
.5957 .40879 m .59711 .40668 L .59856 .40795 L 0 .051 .154 r
F
.5957 .40879 m .59425 .40754 L .59711 .40668 L F
.74627 .40044 m .7479 .39799 L .74921 .39956 L 0 .03 .13 r
F
.74627 .40044 m .74496 .39887 L .7479 .39799 L F
.60287 .40839 m .60429 .40625 L .60574 .40756 L 0 .05 .152 r
F
.60287 .40839 m .60143 .40711 L .60429 .40625 L F
.28258 .39946 m .28351 .39694 L .28527 .39871 L 0 .028 .127 r
F
.28258 .39946 m .28082 .39771 L .28351 .39694 L F
.24238 .39929 m .24327 .39656 L .24506 .39836 L 0 .027 .127 r
F
.24238 .39929 m .24059 .39749 L .24327 .39656 L F
.92423 .39791 m .92611 .39527 L .92725 .39695 L 0 .025 .123 r
F
.92423 .39791 m .92308 .39623 L .92611 .39527 L F
.31561 .40011 m .31658 .39761 L .31831 .39931 L 0 .029 .129 r
F
.31561 .40011 m .31388 .39844 L .31658 .39761 L F
.58854 .40926 m .58993 .40698 L .59139 .4084 L 0 .052 .155 r
F
.58854 .40926 m .58707 .40788 L .58993 .40698 L F
.86969 .39854 m .87149 .39587 L .87269 .39758 L 0 .026 .125 r
F
.86969 .39854 m .86849 .39684 L .87149 .39587 L F
.41187 .40451 m .413 .40196 L .41463 .40368 L 0 .039 .141 r
F
.41187 .40451 m .41024 .40275 L .413 .40196 L F
.82233 .39877 m .82406 .39619 L .8253 .3978 L 0 .027 .126 r
F
.82233 .39877 m .82109 .39715 L .82406 .39619 L F
.34146 .40116 m .34248 .3986 L .34419 .40022 L 0 .032 .132 r
F
.34146 .40116 m .33975 .39955 L .34248 .3986 L F
.49098 .41231 m .49221 .41052 L .49378 .41186 L 0 .062 .164 r
F
.49098 .41231 m .48941 .41089 L .49221 .41052 L F
.44208 .40774 m .44325 .40532 L .44485 .40714 L 0 .048 .15 r
F
.44208 .40774 m .44047 .40592 L .44325 .40532 L F
.50967 .41371 m .51093 .41205 L .51248 .41315 L 0 .066 .168 r
F
.50967 .41371 m .50812 .41253 L .51093 .41205 L F
.8295 .39842 m .83125 .39583 L .83248 .39744 L 0 .026 .125 r
F
.8295 .39842 m .82827 .39681 L .83125 .39583 L F
.36732 .40223 m .36837 .39972 L .37005 .40142 L 0 .034 .135 r
F
.36732 .40223 m .36564 .4005 L .36837 .39972 L F
.46077 .4092 m .46196 .40702 L .46355 .40845 L 0 .052 .155 r
F
.46077 .4092 m .45917 .4078 L .46196 .40702 L F
.20933 .39887 m .21018 .39614 L .21199 .39795 L 0 .027 .126 r
F
.20933 .39887 m .20751 .39707 L .21018 .39614 L F
.75346 .40027 m .7551 .39781 L .7564 .39938 L 0 .03 .13 r
F
.75346 .40027 m .75215 .3987 L .7551 .39781 L F
.87689 .39834 m .87869 .3956 L .87988 .39737 L 0 .026 .124 r
F
.87689 .39834 m .87569 .39659 L .87869 .3956 L F
.76063 .39996 m .76227 .39726 L .76357 .39893 L 0 .029 .129 r
F
.76063 .39996 m .75933 .39832 L .76227 .39726 L F
.24953 .39917 m .25042 .39649 L .25221 .39824 L 0 .027 .127 r
F
.24953 .39917 m .24774 .39743 L .25042 .39649 L F
.64873 .40376 m .65021 .4014 L .65162 .4029 L 0 .038 .14 r
F
.64873 .40376 m .64732 .4023 L .65021 .4014 L F
.64156 .40419 m .64303 .40181 L .64444 .40319 L 0 .039 .141 r
F
.64156 .40419 m .64015 .40282 L .64303 .40181 L F
.51683 .41357 m .51812 .41178 L .51965 .4129 L 0 .066 .168 r
F
.51683 .41357 m .5153 .41247 L .51812 .41178 L F
.58137 .41001 m .58275 .40752 L .58422 .40893 L 0 .054 .157 r
F
.58137 .41001 m .5799 .40857 L .58275 .40752 L F
.8367 .39828 m .83845 .39567 L .83969 .39742 L 0 .026 .125 r
F
.8367 .39828 m .83546 .39656 L .83845 .39567 L F
.34861 .40107 m .34963 .39875 L .35133 .40039 L 0 .032 .133 r
F
.34861 .40107 m .34691 .39945 L .34963 .39875 L F
.76781 .3997 m .76946 .39704 L .77076 .39881 L 0 .029 .129 r
F
.76781 .3997 m .76651 .39796 L .76946 .39704 L F
.43055 .40627 m .4317 .40383 L .43331 .40566 L 0 .044 .147 r
F
.43055 .40627 m .42893 .40447 L .4317 .40383 L F
.28972 .39954 m .29066 .39693 L .29242 .39858 L 0 .028 .128 r
F
.28972 .39954 m .28796 .39787 L .29066 .39693 L F
.46793 .40909 m .46913 .40693 L .47072 .40833 L 0 .052 .155 r
F
.46793 .40909 m .46634 .40769 L .46913 .40693 L F
.25668 .39896 m .25758 .39639 L .25937 .39804 L 0 .027 .127 r
F
.25668 .39896 m .25489 .39731 L .25758 .39639 L F
.52401 .41334 m .5253 .41128 L .52683 .41253 L 0 .065 .167 r
F
.52401 .41334 m .52247 .41213 L .5253 .41128 L F
.21647 .39882 m .2173 .39627 L .21913 .39799 L 0 .027 .127 r
F
.21647 .39882 m .21465 .39711 L .2173 .39627 L F
.88409 .39824 m .88591 .39561 L .8871 .39737 L 0 .026 .125 r
F
.88409 .39824 m .8829 .39649 L .88591 .39561 L F
.29688 .39926 m .29783 .39681 L .29958 .39844 L 0 .028 .128 r
F
.29688 .39926 m .29513 .39763 L .29783 .39681 L F
.69176 .40165 m .69329 .39884 L .69467 .40059 L 0 .033 .134 r
F
.69176 .40165 m .69039 .39993 L .69329 .39884 L F
.32274 .40027 m .32373 .39778 L .32545 .39948 L 0 .03 .131 r
F
.32274 .40027 m .32102 .39855 L .32373 .39778 L F
.37447 .40227 m .37554 .39976 L .37721 .40139 L 0 .035 .136 r
F
.37447 .40227 m .37279 .40061 L .37554 .39976 L F
.5742 .41062 m .57557 .4082 L .57705 .40962 L 0 .056 .159 r
F
.5742 .41062 m .57272 .40916 L .57557 .4082 L F
.41902 .40468 m .42015 .4023 L .42178 .40396 L 0 .041 .143 r
F
.41902 .40468 m .41739 .40299 L .42015 .4023 L F
.53118 .41303 m .53248 .41118 L .534 .41245 L 0 .065 .167 r
F
.53118 .41303 m .52965 .41173 L .53248 .41118 L F
.65591 .40369 m .6574 .40115 L .6588 .40281 L 0 .038 .14 r
F
.65591 .40369 m .65451 .40203 L .6574 .40115 L F
.56703 .41106 m .56839 .40876 L .56988 .41012 L 0 .058 .16 r
F
.56703 .41106 m .56555 .4097 L .56839 .40876 L F
.69894 .40132 m .70048 .39859 L .70185 .40038 L 0 .032 .133 r
F
.69894 .40132 m .69757 .39954 L .70048 .39859 L F
.6846 .40215 m .68613 .3995 L .68749 .40103 L 0 .034 .136 r
F
.6846 .40215 m .68323 .40062 L .68613 .3995 L F
.72046 .40017 m .72205 .39776 L .72338 .39931 L 0 .03 .131 r
F
.72046 .40017 m .71912 .39864 L .72205 .39776 L F
.40033 .40337 m .40143 .4009 L .40308 .40272 L 0 .038 .139 r
F
.40033 .40337 m .39868 .40154 L .40143 .4009 L F
.67026 .40299 m .67177 .40044 L .67315 .40204 L 0 .037 .138 r
F
.67026 .40299 m .66887 .40141 L .67177 .40044 L F
.26383 .39882 m .26474 .39628 L .26652 .39794 L 0 .027 .127 r
F
.26383 .39882 m .26205 .39716 L .26474 .39628 L F
.55986 .41159 m .56121 .40933 L .5627 .41065 L 0 .06 .162 r
F
.55986 .41159 m .55837 .41032 L .56121 .40933 L F
.67743 .40265 m .67896 .40021 L .68033 .40174 L 0 .036 .137 r
F
.67743 .40265 m .67606 .40114 L .67896 .40021 L F
.71329 .40066 m .71486 .39806 L .7162 .39959 L 0 .031 .132 r
F
.71329 .40066 m .71195 .39912 L .71486 .39806 L F
.84391 .39827 m .84567 .39561 L .8469 .39736 L 0 .026 .125 r
F
.84391 .39827 m .84268 .39653 L .84567 .39561 L F
.89129 .39808 m .89312 .39541 L .89429 .39706 L F
.89129 .39808 m .89011 .39643 L .89312 .39541 L F
.89846 .39769 m .90031 .39507 L .90147 .39674 L 0 .025 .124 r
F
.89846 .39769 m .89729 .39603 L .90031 .39507 L F
.78936 .39889 m .79104 .39624 L .79231 .39789 L 0 .027 .127 r
F
.78936 .39889 m .78809 .39725 L .79104 .39624 L F
.22362 .39869 m .22447 .39602 L .22629 .3977 L 0 .027 .126 r
F
.22362 .39869 m .2218 .39703 L .22447 .39602 L F
.6344 .40507 m .63586 .40252 L .63727 .40394 L 0 .042 .144 r
F
.6344 .40507 m .63299 .40364 L .63586 .40252 L F
.78219 .39931 m .78386 .39664 L .78513 .39827 L 0 .028 .128 r
F
.78219 .39931 m .78091 .39767 L .78386 .39664 L F
.49814 .41265 m .49939 .41087 L .50095 .41206 L 0 .064 .166 r
F
.49814 .41265 m .49658 .41137 L .49939 .41087 L F
.77502 .39973 m .77667 .39691 L .77796 .39871 L 0 .029 .129 r
F
.77502 .39973 m .77372 .39793 L .77667 .39691 L F
.38163 .40212 m .38271 .39962 L .38438 .40121 L 0 .035 .136 r
F
.38163 .40212 m .37996 .40051 L .38271 .39962 L F
.66309 .40352 m .66458 .40076 L .66598 .40247 L 0 .038 .139 r
F
.66309 .40352 m .66169 .40186 L .66458 .40076 L F
.55269 .41209 m .55403 .41019 L .55553 .41121 L 0 .062 .164 r
F
.55269 .41209 m .55119 .41111 L .55403 .41019 L F
.70612 .40115 m .70768 .3985 L .70904 .40018 L 0 .032 .133 r
F
.70612 .40115 m .70477 .39945 L .70768 .3985 L F
.53835 .4129 m .53967 .41131 L .54118 .41228 L 0 .065 .167 r
F
.53835 .4129 m .53683 .41187 L .53967 .41131 L F
.23078 .39839 m .23164 .3958 L .23345 .3975 L 0 .027 .126 r
F
.23078 .39839 m .22897 .39671 L .23164 .3958 L F
.79654 .39861 m .79823 .39598 L .7995 .39766 L F
.79654 .39861 m .79527 .39693 L .79823 .39598 L F
.62006 .40601 m .62149 .40317 L .62293 .40493 L 0 .044 .146 r
F
.62006 .40601 m .61862 .40431 L .62149 .40317 L F
.54552 .4126 m .54685 .41112 L .54836 .41196 L 0 .065 .167 r
F
.54552 .4126 m .54402 .4117 L .54685 .41112 L F
.27098 .39868 m .27191 .39598 L .27368 .3977 L 0 .027 .127 r
F
.27098 .39868 m .26921 .39698 L .27191 .39598 L F
.30402 .3993 m .30498 .39685 L .30672 .3985 L 0 .029 .129 r
F
.30402 .3993 m .30228 .39766 L .30498 .39685 L F
.62724 .40567 m .62868 .40295 L .63011 .40466 L 0 .043 .145 r
F
.62724 .40567 m .6258 .40393 L .62868 .40295 L F
.47509 .40926 m .4763 .40764 L .47788 .409 L 0 .055 .157 r
F
.47509 .40926 m .47351 .40791 L .4763 .40764 L F
.8511 .39812 m .85288 .39549 L .85409 .39719 L 0 .026 .125 r
F
.8511 .39812 m .84989 .39644 L .85288 .39549 L F
.72765 .40012 m .72924 .39752 L .73058 .39919 L 0 .03 .131 r
F
.72765 .40012 m .72631 .39844 L .72924 .39752 L F
.90566 .39754 m .90751 .39486 L .90868 .3966 L 0 .025 .124 r
F
.90566 .39754 m .90449 .39581 L .90751 .39486 L F
.38879 .40201 m .38988 .39936 L .39154 .40109 L 0 .035 .136 r
F
.38879 .40201 m .38713 .40029 L .38988 .39936 L F
.32988 .40042 m .33087 .39802 L .33259 .39967 L 0 .032 .132 r
F
.32988 .40042 m .32816 .39875 L .33087 .39802 L F
.6129 .40661 m .61432 .40392 L .61576 .40544 L 0 .046 .148 r
F
.6129 .40661 m .61146 .40512 L .61432 .40392 L F
.80373 .39846 m .80542 .39567 L .80669 .39743 L 0 .027 .126 r
F
.80373 .39846 m .80246 .3967 L .80542 .39567 L F
.35574 .40145 m .35679 .39877 L .35848 .40053 L 0 .033 .134 r
F
.35574 .40145 m .35406 .39968 L .35679 .39877 L F
.27814 .39847 m .27906 .39594 L .28082 .39771 L 0 .027 .127 r
F
.27814 .39847 m .27638 .39673 L .27906 .39594 L F
.85829 .39788 m .86009 .39534 L .86129 .39697 L 0 .026 .125 r
F
.85829 .39788 m .85709 .39625 L .86009 .39534 L F
.48661 .41124 m .48784 .40946 L .48941 .41089 L 0 .06 .163 r
F
.48661 .41124 m .48504 .40978 L .48784 .40946 L F
.44922 .40845 m .4504 .40618 L .452 .40796 L 0 .052 .154 r
F
.44922 .40845 m .44762 .40666 L .4504 .40618 L F
.4377 .4067 m .43886 .40409 L .44047 .40592 L 0 .046 .149 r
F
.4377 .4067 m .43609 .40488 L .43886 .40409 L F
.73484 .39995 m .73644 .3973 L .73777 .39901 L 0 .03 .13 r
F
.73484 .39995 m .73351 .39825 L .73644 .3973 L F
.91286 .39739 m .91471 .39462 L .91588 .3964 L 0 .025 .123 r
F
.91286 .39739 m .91169 .39561 L .91471 .39462 L F
.81092 .39818 m .81262 .39544 L .81388 .39723 L 0 .026 .126 r
F
.81092 .39818 m .80965 .39641 L .81262 .39544 L F
.23792 .39839 m .2388 .3957 L .24059 .39749 L 0 .027 .126 r
F
.23792 .39839 m .23612 .39662 L .2388 .3957 L F
.40747 .40364 m .4086 .40099 L .41024 .40275 L 0 .039 .141 r
F
.40747 .40364 m .40583 .40186 L .4086 .40099 L F
.31117 .39929 m .31214 .39676 L .31388 .39844 L 0 .029 .129 r
F
.31117 .39929 m .30943 .39763 L .31214 .39676 L F
.86549 .39772 m .8673 .39521 L .86849 .39684 L 0 .026 .125 r
F
.86549 .39772 m .86429 .39609 L .8673 .39521 L F
.42617 .40508 m .42731 .40267 L .42893 .40447 L 0 .043 .145 r
F
.42617 .40508 m .42455 .40331 L .42731 .40267 L F
.3629 .40137 m .36396 .39877 L .36564 .4005 L 0 .034 .135 r
F
.3629 .40137 m .36122 .39961 L .36396 .39877 L F
.74202 .39978 m .74364 .39712 L .74496 .39887 L 0 .03 .13 r
F
.74202 .39978 m .7407 .39807 L .74364 .39712 L F
.92006 .3972 m .92192 .39444 L .92308 .39623 L 0 .025 .123 r
F
.92006 .3972 m .9189 .39542 L .92192 .39444 L F
.81811 .39803 m .81984 .39547 L .82109 .39715 L 0 .027 .126 r
F
.81811 .39803 m .81686 .39635 L .81984 .39547 L F
.50531 .41296 m .50657 .41135 L .50812 .41253 L 0 .066 .168 r
F
.50531 .41296 m .50376 .41168 L .50657 .41135 L F
.20485 .39805 m .20569 .39527 L .20751 .39707 L 0 .026 .126 r
F
.20485 .39805 m .20302 .39626 L .20569 .39527 L F
.33702 .40049 m .33804 .39792 L .33975 .39955 L 0 .032 .133 r
F
.33702 .40049 m .33531 .39886 L .33804 .39792 L F
.24506 .39836 m .24595 .39562 L .24774 .39743 L 0 .027 .127 r
F
.24506 .39836 m .24327 .39656 L .24595 .39562 L F
.74921 .39956 m .75085 .39713 L .75215 .3987 L 0 .03 .131 r
F
.74921 .39956 m .7479 .39799 L .75085 .39713 L F
.87269 .39758 m .87449 .39485 L .87569 .39659 L 0 .026 .125 r
F
.87269 .39758 m .87149 .39587 L .87449 .39485 L F
.59856 .40795 m .59998 .40582 L .60143 .40711 L 0 .051 .154 r
F
.59856 .40795 m .59711 .40668 L .59998 .40582 L F
.8253 .3978 m .82704 .3952 L .82827 .39681 L 0 .026 .125 r
F
.8253 .3978 m .82406 .39619 L .82704 .3952 L F
.39594 .40218 m .39704 .39972 L .39868 .40154 L 0 .036 .138 r
F
.39594 .40218 m .39429 .40035 L .39704 .39972 L F
.60574 .40756 m .60715 .405 L .6086 .40634 L 0 .049 .152 r
F
.60574 .40756 m .60429 .40625 L .60715 .405 L F
.45638 .40857 m .45757 .40639 L .45917 .4078 L 0 .053 .155 r
F
.45638 .40857 m .45478 .40719 L .45757 .40639 L F
.34419 .40022 m .34521 .39782 L .34691 .39945 L 0 .032 .132 r
F
.34419 .40022 m .34248 .3986 L .34521 .39782 L F
.83248 .39744 m .83424 .39493 L .83546 .39656 L 0 .026 .125 r
F
.83248 .39744 m .83125 .39583 L .83424 .39493 L F
.59139 .4084 m .59279 .40607 L .59425 .40754 L 0 .052 .155 r
F
.59139 .4084 m .58993 .40698 L .59279 .40607 L F
.28527 .39871 m .28621 .3961 L .28796 .39787 L 0 .028 .128 r
F
.28527 .39871 m .28351 .39694 L .28621 .3961 L F
.41463 .40368 m .41576 .40131 L .41739 .40299 L 0 .04 .142 r
F
.41463 .40368 m .413 .40196 L .41576 .40131 L F
.31831 .39931 m .3193 .39681 L .32102 .39855 L 0 .03 .13 r
F
.31831 .39931 m .31658 .39761 L .3193 .39681 L F
.76357 .39893 m .76521 .39626 L .76651 .39796 L 0 .029 .129 r
F
.76357 .39893 m .76227 .39726 L .76521 .39626 L F
.21199 .39795 m .21283 .3953 L .21465 .39711 L 0 .027 .126 r
F
.21199 .39795 m .21018 .39614 L .21283 .3953 L F
.87988 .39737 m .8817 .39471 L .8829 .39649 L 0 .026 .124 r
F
.87988 .39737 m .87869 .3956 L .8817 .39471 L F
.58422 .40893 m .58561 .40649 L .58707 .40788 L 0 .054 .156 r
F
.58422 .40893 m .58275 .40752 L .58561 .40649 L F
.7564 .39938 m .75803 .39673 L .75933 .39832 L 0 .03 .13 r
F
.7564 .39938 m .7551 .39781 L .75803 .39673 L F
.64444 .40319 m .64592 .40088 L .64732 .4023 L 0 .039 .141 r
F
.64444 .40319 m .64303 .40181 L .64592 .40088 L F
.37005 .40142 m .37111 .39894 L .37279 .40061 L 0 .035 .136 r
F
.37005 .40142 m .36837 .39972 L .37111 .39894 L F
.25221 .39824 m .25311 .39555 L .25489 .39731 L 0 .027 .127 r
F
.25221 .39824 m .25042 .39649 L .25311 .39555 L F
.46355 .40845 m .46475 .40626 L .46634 .40769 L 0 .053 .156 r
F
.46355 .40845 m .46196 .40702 L .46475 .40626 L F
.65162 .4029 m .65311 .40051 L .65451 .40203 L 0 .038 .14 r
F
.65162 .4029 m .65021 .4014 L .65311 .40051 L F
.44485 .40714 m .44602 .40485 L .44762 .40666 L 0 .049 .152 r
F
.44485 .40714 m .44325 .40532 L .44602 .40485 L F
.29242 .39858 m .29337 .39599 L .29513 .39763 L 0 .028 .128 r
F
.29242 .39858 m .29066 .39693 L .29337 .39599 L F
.69467 .40059 m .6962 .39775 L .69757 .39954 L 0 .032 .133 r
F
.69467 .40059 m .69329 .39884 L .6962 .39775 L F
.83969 .39742 m .84145 .39477 L .84268 .39653 L 0 .026 .125 r
F
.83969 .39742 m .83845 .39567 L .84145 .39477 L F
.77076 .39881 m .77242 .39612 L .77372 .39793 L 0 .029 .129 r
F
.77076 .39881 m .76946 .39704 L .77242 .39612 L F
.51248 .41315 m .51375 .41138 L .5153 .41247 L 0 .068 .169 r
F
.51248 .41315 m .51093 .41205 L .51375 .41138 L F
.25937 .39804 m .26026 .39551 L .26205 .39716 L 0 .027 .127 r
F
.25937 .39804 m .25758 .39639 L .26026 .39551 L F
.68749 .40103 m .68903 .39838 L .69039 .39993 L 0 .034 .135 r
F
.68749 .40103 m .68613 .3995 L .68903 .39838 L F
.57705 .40962 m .57843 .40718 L .5799 .40857 L 0 .056 .158 r
F
.57705 .40962 m .57557 .4082 L .57843 .40718 L F
.49378 .41186 m .49502 .41012 L .49658 .41137 L 0 .064 .166 r
F
.49378 .41186 m .49221 .41052 L .49502 .41012 L F
.48225 .4101 m .48347 .40837 L .48504 .40978 L 0 .059 .161 r
F
.48225 .4101 m .48067 .40873 L .48347 .40837 L F
.8871 .39737 m .88892 .39466 L .89011 .39643 L 0 .026 .125 r
F
.8871 .39737 m .88591 .39561 L .88892 .39466 L F
.63727 .40394 m .63874 .40141 L .64015 .40282 L 0 .041 .143 r
F
.63727 .40394 m .63586 .40252 L .63874 .40141 L F
.51965 .4129 m .52094 .41098 L .52247 .41213 L 0 .067 .169 r
F
.51965 .4129 m .51812 .41178 L .52094 .41098 L F
.56988 .41012 m .57124 .40784 L .57272 .40916 L 0 .058 .16 r
F
.56988 .41012 m .56839 .40876 L .57124 .40784 L F
.47072 .40833 m .47192 .40649 L .47351 .40791 L 0 .054 .156 r
F
.47072 .40833 m .46913 .40693 L .47192 .40649 L F
.21913 .39799 m .21998 .39531 L .2218 .39703 L 0 .027 .127 r
F
.21913 .39799 m .2173 .39627 L .21998 .39531 L F
.70185 .40038 m .7034 .39767 L .70477 .39945 L 0 .032 .133 r
F
.70185 .40038 m .70048 .39859 L .7034 .39767 L F
.7162 .39959 m .71779 .3971 L .71912 .39864 L 0 .031 .131 r
F
.7162 .39959 m .71486 .39806 L .71779 .3971 L F
.35133 .40039 m .35236 .39802 L .35406 .39968 L 0 .033 .134 r
F
.35133 .40039 m .34963 .39875 L .35236 .39802 L F
.52683 .41253 m .52813 .41043 L .52965 .41173 L 0 .065 .167 r
F
.52683 .41253 m .5253 .41128 L .52813 .41043 L F
.37721 .40139 m .37828 .3989 L .37996 .40051 L 0 .035 .136 r
F
.37721 .40139 m .37554 .39976 L .37828 .3989 L F
.6588 .40281 m .6603 .40019 L .66169 .40186 L 0 .038 .14 r
F
.6588 .40281 m .6574 .40115 L .6603 .40019 L F
.29958 .39844 m .30053 .39602 L .30228 .39766 L 0 .029 .129 r
F
.29958 .39844 m .29783 .39681 L .30053 .39602 L F
.89429 .39706 m .89612 .39438 L .89729 .39603 L 0 .025 .124 r
F
.89429 .39706 m .89312 .39541 L .89612 .39438 L F
.67315 .40204 m .67467 .3995 L .67606 .40114 L 0 .037 .138 r
F
.67315 .40204 m .67177 .40044 L .67467 .3995 L F
.78513 .39827 m .78681 .3956 L .78809 .39725 L 0 .028 .128 r
F
.78513 .39827 m .78386 .39664 L .78681 .3956 L F
.32545 .39948 m .32644 .39707 L .32816 .39875 L 0 .031 .131 r
F
.32545 .39948 m .32373 .39778 L .32644 .39707 L F
.66598 .40247 m .66748 .39967 L .66887 .40141 L 0 .037 .139 r
F
.66598 .40247 m .66458 .40076 L .66748 .39967 L F
.79231 .39789 m .794 .39527 L .79527 .39693 L 0 .027 .127 r
F
.79231 .39789 m .79104 .39624 L .794 .39527 L F
.22629 .3977 m .22715 .39503 L .22897 .39671 L 0 .027 .126 r
F
.22629 .3977 m .22447 .39602 L .22715 .39503 L F
.43331 .40566 m .43448 .40304 L .43609 .40488 L 0 .045 .148 r
F
.43331 .40566 m .4317 .40383 L .43448 .40304 L F
.5627 .41065 m .56406 .40834 L .56555 .4097 L 0 .06 .162 r
F
.5627 .41065 m .56121 .40933 L .56406 .40834 L F
.72338 .39931 m .72498 .39687 L .72631 .39844 L 0 .031 .131 r
F
.72338 .39931 m .72205 .39776 L .72498 .39687 L F
.77796 .39871 m .77961 .39587 L .78091 .39767 L 0 .029 .128 r
F
.77796 .39871 m .77667 .39691 L .77961 .39587 L F
.90147 .39674 m .90332 .39412 L .90449 .39581 L 0 .025 .124 r
F
.90147 .39674 m .90031 .39507 L .90332 .39412 L F
.26652 .39794 m .26743 .39531 L .26921 .39698 L 0 .027 .127 r
F
.26652 .39794 m .26474 .39628 L .26743 .39531 L F
.8469 .39736 m .84866 .3947 L .84989 .39644 L 0 .026 .125 r
F
.8469 .39736 m .84567 .39561 L .84866 .3947 L F
.68033 .40174 m .68186 .39909 L .68323 .40062 L 0 .036 .137 r
F
.68033 .40174 m .67896 .40021 L .68186 .39909 L F
.62293 .40493 m .62437 .40218 L .6258 .40393 L 0 .043 .146 r
F
.62293 .40493 m .62149 .40317 L .62437 .40218 L F
.42178 .40396 m .42292 .40166 L .42455 .40331 L 0 .042 .144 r
F
.42178 .40396 m .42015 .4023 L .42292 .40166 L F
.70904 .40018 m .7106 .39744 L .71195 .39912 L 0 .032 .133 r
F
.70904 .40018 m .70768 .3985 L .7106 .39744 L F
.38438 .40121 m .38546 .39869 L .38713 .40029 L 0 .035 .136 r
F
.38438 .40121 m .38271 .39962 L .38546 .39869 L F
.7995 .39766 m .8012 .39503 L .80246 .3967 L 0 .027 .126 r
F
.7995 .39766 m .79823 .39598 L .8012 .39503 L F
.55553 .41121 m .55688 .40925 L .55837 .41032 L 0 .062 .164 r
F
.55553 .41121 m .55403 .41019 L .55688 .40925 L F
.61576 .40544 m .61719 .40273 L .61862 .40431 L 0 .045 .147 r
F
.61576 .40544 m .61432 .40392 L .61719 .40273 L F
.63011 .40466 m .63156 .40195 L .63299 .40364 L 0 .043 .145 r
F
.63011 .40466 m .62868 .40295 L .63156 .40195 L F
.27368 .3977 m .27461 .39499 L .27638 .39673 L 0 .027 .126 r
F
.27368 .3977 m .27191 .39598 L .27461 .39499 L F
.23345 .3975 m .23431 .39488 L .23612 .39662 L F
.23345 .3975 m .23164 .3958 L .23431 .39488 L F
.534 .41245 m .53532 .41064 L .53683 .41187 L 0 .066 .168 r
F
.534 .41245 m .53248 .41118 L .53532 .41064 L F
.40308 .40272 m .40419 .40007 L .40583 .40186 L 0 .038 .14 r
F
.40308 .40272 m .40143 .4009 L .40419 .40007 L F
.85409 .39719 m .85587 .39454 L .85709 .39625 L 0 .026 .125 r
F
.85409 .39719 m .85288 .39549 L .85587 .39454 L F
.73058 .39919 m .73218 .39659 L .73351 .39825 L 0 .03 .131 r
F
.73058 .39919 m .72924 .39752 L .73218 .39659 L F
.90868 .3966 m .91053 .39387 L .91169 .39561 L 0 .025 .123 r
F
.90868 .3966 m .90751 .39486 L .91053 .39387 L F
.80669 .39743 m .80839 .39463 L .80965 .39641 L 0 .026 .126 r
F
.80669 .39743 m .80542 .39567 L .80839 .39463 L F
.39154 .40109 m .39263 .39862 L .39429 .40035 L 0 .035 .136 r
F
.39154 .40109 m .38988 .39936 L .39263 .39862 L F
.30672 .3985 m .30769 .39597 L .30943 .39763 L 0 .029 .129 r
F
.30672 .3985 m .30498 .39685 L .30769 .39597 L F
.50095 .41206 m .5022 .41058 L .50376 .41168 L 0 .066 .168 r
F
.50095 .41206 m .49939 .41087 L .5022 .41058 L F
.35848 .40053 m .35953 .39786 L .36122 .39961 L 0 .033 .134 r
F
.35848 .40053 m .35679 .39877 L .35953 .39786 L F
.54118 .41228 m .54251 .41078 L .54402 .4117 L 0 .067 .169 r
F
.54118 .41228 m .53967 .41131 L .54251 .41078 L F
.86129 .39697 m .86309 .39446 L .86429 .39609 L 0 .026 .125 r
F
.86129 .39697 m .86009 .39534 L .86309 .39446 L F
.91588 .3964 m .91773 .39363 L .9189 .39542 L 0 .025 .123 r
F
.91588 .3964 m .91471 .39462 L .91773 .39363 L F
.73777 .39901 m .73937 .39633 L .7407 .39807 L 0 .03 .13 r
F
.73777 .39901 m .73644 .3973 L .73937 .39633 L F
.81388 .39723 m .8156 .39457 L .81686 .39635 L 0 .027 .126 r
F
.81388 .39723 m .81262 .39544 L .8156 .39457 L F
.54836 .41196 m .54969 .41025 L .55119 .41111 L 0 .066 .167 r
F
.54836 .41196 m .54685 .41112 L .54969 .41025 L F
.20036 .39726 m .20119 .39451 L .20302 .39626 L 0 .026 .126 r
F
.20036 .39726 m .19852 .39552 L .20119 .39451 L F
.33259 .39967 m .33359 .39722 L .33531 .39886 L 0 .032 .133 r
F
.33259 .39967 m .33087 .39802 L .33359 .39722 L F
.24059 .39749 m .24148 .39476 L .24327 .39656 L 0 .027 .126 r
F
.24059 .39749 m .2388 .3957 L .24148 .39476 L F
.28082 .39771 m .28175 .39516 L .28351 .39694 L 0 .028 .127 r
F
.28082 .39771 m .27906 .39594 L .28175 .39516 L F
.44047 .40592 m .44164 .40348 L .44325 .40532 L 0 .047 .15 r
F
.44047 .40592 m .43886 .40409 L .44164 .40348 L F
.41024 .40275 m .41136 .40023 L .413 .40196 L 0 .039 .141 r
F
.41024 .40275 m .4086 .40099 L .41136 .40023 L F
.6086 .40634 m .61002 .40376 L .61146 .40512 L 0 .048 .151 r
F
.6086 .40634 m .60715 .405 L .61002 .40376 L F
.92308 .39623 m .92495 .39346 L .92611 .39527 L 0 .025 .123 r
F
.92308 .39623 m .92192 .39444 L .92495 .39346 L F
.86849 .39684 m .8703 .39422 L .87149 .39587 L 0 .026 .125 r
F
.86849 .39684 m .8673 .39521 L .8703 .39422 L F
.31388 .39844 m .31485 .39591 L .31658 .39761 L 0 .03 .13 r
F
.31388 .39844 m .31214 .39676 L .31485 .39591 L F
.20751 .39707 m .20835 .39433 L .21018 .39614 L 0 .026 .125 r
F
.20751 .39707 m .20569 .39527 L .20835 .39433 L F
.74496 .39887 m .74658 .39623 L .7479 .39799 L 0 .03 .131 r
F
.74496 .39887 m .74364 .39712 L .74658 .39623 L F
.36564 .4005 m .36669 .39801 L .36837 .39972 L 0 .034 .135 r
F
.36564 .4005 m .36396 .39877 L .36669 .39801 L F
.82109 .39715 m .82282 .39451 L .82406 .39619 L 0 .027 .126 r
F
.82109 .39715 m .81984 .39547 L .82282 .39451 L F
.33975 .39955 m .34077 .39698 L .34248 .3986 L 0 .032 .133 r
F
.33975 .39955 m .33804 .39792 L .34077 .39698 L F
.87569 .39659 m .87749 .39385 L .87869 .3956 L 0 .026 .124 r
F
.87569 .39659 m .87449 .39485 L .87749 .39385 L F
.82827 .39681 m .83002 .39422 L .83125 .39583 L 0 .026 .125 r
F
.82827 .39681 m .82704 .3952 L .83002 .39422 L F
.452 .40796 m .45318 .40543 L .45478 .40719 L 0 .053 .155 r
F
.452 .40796 m .4504 .40618 L .45318 .40543 L F
.24774 .39743 m .24864 .39467 L .25042 .39649 L 0 .027 .127 r
F
.24774 .39743 m .24595 .39562 L .24864 .39467 L F
.47788 .409 m .47909 .40736 L .48067 .40873 L 0 .058 .16 r
F
.47788 .409 m .4763 .40764 L .47909 .40736 L F
.42893 .40447 m .43008 .402 L .4317 .40383 L 0 .044 .146 r
F
.42893 .40447 m .42731 .40267 L .43008 .402 L F
.75215 .3987 m .7538 .39624 L .7551 .39781 L 0 .031 .131 r
F
.75215 .3987 m .75085 .39713 L .7538 .39624 L F
.75933 .39832 m .76097 .39565 L .76227 .39726 L 0 .029 .129 r
F
.75933 .39832 m .75803 .39673 L .76097 .39565 L F
.58707 .40788 m .58847 .40553 L .58993 .40698 L 0 .053 .156 r
F
.58707 .40788 m .58561 .40649 L .58847 .40553 L F
.48941 .41089 m .49065 .40914 L .49221 .41052 L 0 .063 .165 r
F
.48941 .41089 m .48784 .40946 L .49065 .40914 L F
.60143 .40711 m .60285 .40494 L .60429 .40625 L 0 .052 .154 r
F
.60143 .40711 m .59998 .40582 L .60285 .40494 L F
.83546 .39656 m .83723 .39402 L .83845 .39567 L 0 .026 .125 r
F
.83546 .39656 m .83424 .39493 L .83723 .39402 L F
.76651 .39796 m .76816 .39532 L .76946 .39704 L 0 .029 .128 r
F
.76651 .39796 m .76521 .39626 L .76816 .39532 L F
.59425 .40754 m .59566 .40517 L .59711 .40668 L 0 .052 .155 r
F
.59425 .40754 m .59279 .40607 L .59566 .40517 L F
.45917 .4078 m .46036 .4056 L .46196 .40702 L 0 .054 .156 r
F
.45917 .4078 m .45757 .40639 L .46036 .4056 L F
.34691 .39945 m .34793 .3971 L .34963 .39875 L 0 .033 .133 r
F
.34691 .39945 m .34521 .39782 L .34793 .3971 L F
.28796 .39787 m .28891 .39515 L .29066 .39693 L 0 .029 .128 r
F
.28796 .39787 m .28621 .3961 L .28891 .39515 L F
.8829 .39649 m .88472 .39382 L .88591 .39561 L 0 .026 .125 r
F
.8829 .39649 m .8817 .39471 L .88472 .39382 L F
.25489 .39731 m .25579 .39463 L .25758 .39639 L 0 .027 .127 r
F
.25489 .39731 m .25311 .39555 L .25579 .39463 L F
.21465 .39711 m .21549 .39445 L .2173 .39627 L 0 .027 .126 r
F
.21465 .39711 m .21283 .3953 L .21549 .39445 L F
.64732 .4023 m .64881 .39995 L .65021 .4014 L 0 .039 .141 r
F
.64732 .4023 m .64592 .40088 L .64881 .39995 L F
.69039 .39993 m .69193 .39725 L .69329 .39884 L 0 .033 .134 r
F
.69039 .39993 m .68903 .39838 L .69193 .39725 L F
.69757 .39954 m .69912 .39681 L .70048 .39859 L 0 .032 .133 r
F
.69757 .39954 m .6962 .39775 L .69912 .39681 L F
.32102 .39855 m .32201 .39601 L .32373 .39778 L 0 .03 .131 r
F
.32102 .39855 m .3193 .39681 L .32201 .39601 L F
.39868 .40154 m .39979 .39908 L .40143 .4009 L 0 .037 .139 r
F
.39868 .40154 m .39704 .39972 L .39979 .39908 L F
.50812 .41253 m .50939 .41095 L .51093 .41205 L 0 .069 .17 r
F
.50812 .41253 m .50657 .41135 L .50939 .41095 L F
.41739 .40299 m .41852 .40067 L .42015 .4023 L 0 .041 .143 r
F
.41739 .40299 m .41576 .40131 L .41852 .40067 L F
.5799 .40857 m .58128 .40616 L .58275 .40752 L 0 .055 .158 r
F
.5799 .40857 m .57843 .40718 L .58128 .40616 L F
.37279 .40061 m .37386 .39811 L .37554 .39976 L 0 .035 .136 r
F
.37279 .40061 m .37111 .39894 L .37386 .39811 L F
.29513 .39763 m .29607 .39517 L .29783 .39681 L 0 .029 .128 r
F
.29513 .39763 m .29337 .39599 L .29607 .39517 L F
.64015 .40282 m .64162 .40038 L .64303 .40181 L 0 .04 .142 r
F
.64015 .40282 m .63874 .40141 L .64162 .40038 L F
.65451 .40203 m .656 .39962 L .6574 .40115 L 0 .039 .14 r
F
.65451 .40203 m .65311 .40051 L .656 .39962 L F
.84268 .39653 m .84444 .39386 L .84567 .39561 L 0 .026 .125 r
F
.84268 .39653 m .84145 .39477 L .84444 .39386 L F
.77372 .39793 m .77537 .3951 L .77667 .39691 L 0 .029 .129 r
F
.77372 .39793 m .77242 .39612 L .77537 .3951 L F
.46634 .40769 m .46754 .4055 L .46913 .40693 L 0 .054 .156 r
F
.46634 .40769 m .46475 .40626 L .46754 .4055 L F
.26205 .39716 m .26295 .39462 L .26474 .39628 L 0 .028 .127 r
F
.26205 .39716 m .26026 .39551 L .26295 .39462 L F
.57272 .40916 m .5741 .40691 L .57557 .4082 L 0 .058 .16 r
F
.57272 .40916 m .57124 .40784 L .5741 .40691 L F
.2218 .39703 m .22265 .39431 L .22447 .39602 L 0 .027 .126 r
F
.2218 .39703 m .21998 .39531 L .22265 .39431 L F
.89729 .39603 m .89914 .3934 L .90031 .39507 L 0 .025 .124 r
F
.89729 .39603 m .89612 .39438 L .89914 .3934 L F
.89011 .39643 m .89193 .39364 L .89312 .39541 L 0 .026 .125 r
F
.89011 .39643 m .88892 .39466 L .89193 .39364 L F
.66887 .40141 m .67037 .39866 L .67177 .40044 L 0 .037 .138 r
F
.66887 .40141 m .66748 .39967 L .67037 .39866 L F
.68323 .40062 m .68476 .39796 L .68613 .3995 L 0 .035 .136 r
F
.68323 .40062 m .68186 .39909 L .68476 .39796 L F
.71912 .39864 m .72072 .3962 L .72205 .39776 L 0 .031 .131 r
F
.71912 .39864 m .71779 .3971 L .72072 .3962 L F
.78809 .39725 m .78976 .39456 L .79104 .39624 L 0 .028 .127 r
F
.78809 .39725 m .78681 .3956 L .78976 .39456 L F
.70477 .39945 m .70632 .39672 L .70768 .3985 L 0 .032 .133 r
F
.70477 .39945 m .7034 .39767 L .70632 .39672 L F
.78091 .39767 m .78257 .39484 L .78386 .39664 L 0 .028 .128 r
F
.78091 .39767 m .77961 .39587 L .78257 .39484 L F
.66169 .40186 m .66319 .39906 L .66458 .40076 L 0 .038 .139 r
F
.66169 .40186 m .6603 .40019 L .66319 .39906 L F
.22897 .39671 m .22983 .39409 L .23164 .3958 L 0 .027 .126 r
F
.22897 .39671 m .22715 .39503 L .22983 .39409 L F
.37996 .40051 m .38103 .39802 L .38271 .39962 L 0 .035 .137 r
F
.37996 .40051 m .37828 .3989 L .38103 .39802 L F
.79527 .39693 m .79697 .39433 L .79823 .39598 L 0 .027 .127 r
F
.79527 .39693 m .794 .39527 L .79697 .39433 L F
.71195 .39912 m .71351 .39639 L .71486 .39806 L 0 .032 .132 r
F
.71195 .39912 m .7106 .39744 L .71351 .39639 L F
.5153 .41247 m .51658 .4107 L .51812 .41178 L 0 .069 .17 r
F
.5153 .41247 m .51375 .41138 L .51658 .4107 L F
.61862 .40431 m .62005 .40154 L .62149 .40317 L 0 .044 .146 r
F
.61862 .40431 m .61719 .40273 L .62005 .40154 L F
.67606 .40114 m .67758 .39855 L .67896 .40021 L 0 .037 .138 r
F
.67606 .40114 m .67467 .3995 L .67758 .39855 L F
.6258 .40393 m .62725 .40123 L .62868 .40295 L 0 .043 .145 r
F
.6258 .40393 m .62437 .40218 L .62725 .40123 L F
.56555 .4097 m .56691 .4074 L .56839 .40876 L 0 .06 .162 r
F
.56555 .4097 m .56406 .40834 L .56691 .4074 L F
.26921 .39698 m .27013 .39429 L .27191 .39598 L 0 .027 .127 r
F
.26921 .39698 m .26743 .39531 L .27013 .39429 L F
.52247 .41213 m .52377 .41011 L .5253 .41128 L 0 .067 .169 r
F
.52247 .41213 m .52094 .41098 L .52377 .41011 L F
.52965 .41173 m .53096 .40991 L .53248 .41118 L 0 .067 .168 r
F
.52965 .41173 m .52813 .41043 L .53096 .40991 L F
.90449 .39581 m .90634 .39315 L .90751 .39486 L 0 .025 .124 r
F
.90449 .39581 m .90332 .39412 L .90634 .39315 L F
.84989 .39644 m .85166 .39373 L .85288 .39549 L 0 .026 .125 r
F
.84989 .39644 m .84866 .3947 L .85166 .39373 L F
.72631 .39844 m .72792 .39595 L .72924 .39752 L 0 .031 .131 r
F
.72631 .39844 m .72498 .39687 L .72792 .39595 L F
.30228 .39766 m .30323 .39521 L .30498 .39685 L 0 .029 .129 r
F
.30228 .39766 m .30053 .39602 L .30323 .39521 L F
.63299 .40364 m .63444 .40086 L .63586 .40252 L 0 .042 .145 r
F
.63299 .40364 m .63156 .40195 L .63444 .40086 L F
.35406 .39968 m .3551 .39708 L .35679 .39877 L 0 .033 .134 r
F
.35406 .39968 m .35236 .39802 L .3551 .39708 L F
.44762 .40666 m .4488 .40438 L .4504 .40618 L 0 .051 .154 r
F
.44762 .40666 m .44602 .40485 L .4488 .40438 L F
.38713 .40029 m .38822 .39776 L .38988 .39936 L 0 .035 .136 r
F
.38713 .40029 m .38546 .39869 L .38822 .39776 L F
.80246 .3967 m .80416 .39398 L .80542 .39567 L 0 .027 .126 r
F
.80246 .3967 m .8012 .39503 L .80416 .39398 L F
.43609 .40488 m .43725 .40224 L .43886 .40409 L 0 .046 .148 r
F
.43609 .40488 m .43448 .40304 L .43725 .40224 L F
.27638 .39673 m .2773 .39418 L .27906 .39594 L 0 .027 .127 r
F
.27638 .39673 m .27461 .39499 L .2773 .39418 L F
.32816 .39875 m .32915 .39635 L .33087 .39802 L 0 .032 .132 r
F
.32816 .39875 m .32644 .39707 L .32915 .39635 L F
.55837 .41032 m .55972 .40822 L .56121 .40933 L 0 .062 .164 r
F
.55837 .41032 m .55688 .40925 L .55972 .40822 L F
.80965 .39641 m .81136 .39365 L .81262 .39544 L 0 .026 .125 r
F
.80965 .39641 m .80839 .39463 L .81136 .39365 L F
.91169 .39561 m .91355 .39288 L .91471 .39462 L 0 .025 .123 r
F
.91169 .39561 m .91053 .39387 L .91355 .39288 L F
.23612 .39662 m .23699 .39395 L .2388 .3957 L 0 .027 .126 r
F
.23612 .39662 m .23431 .39488 L .23699 .39395 L F
.49658 .41137 m .49783 .40973 L .49939 .41087 L 0 .066 .168 r
F
.49658 .41137 m .49502 .41012 L .49783 .40973 L F
.85709 .39625 m .85887 .39361 L .86009 .39534 L 0 .026 .125 r
F
.85709 .39625 m .85587 .39454 L .85887 .39361 L F
.73351 .39825 m .73511 .39563 L .73644 .3973 L 0 .03 .131 r
F
.73351 .39825 m .73218 .39659 L .73511 .39563 L F
.40583 .40186 m .40696 .39924 L .4086 .40099 L 0 .039 .14 r
F
.40583 .40186 m .40419 .40007 L .40696 .39924 L F
.42455 .40331 m .42569 .40103 L .42731 .40267 L 0 .043 .145 r
F
.42455 .40331 m .42292 .40166 L .42569 .40103 L F
.47351 .40791 m .47472 .4062 L .4763 .40764 L 0 .056 .159 r
F
.47351 .40791 m .47192 .40649 L .47472 .4062 L F
.61146 .40512 m .61288 .40251 L .61432 .40392 L 0 .047 .149 r
F
.61146 .40512 m .61002 .40376 L .61288 .40251 L F
.9189 .39542 m .92076 .39264 L .92192 .39444 L 0 .024 .123 r
F
.9189 .39542 m .91773 .39363 L .92076 .39264 L F
.36122 .39961 m .36227 .39703 L .36396 .39877 L 0 .034 .135 r
F
.36122 .39961 m .35953 .39786 L .36227 .39703 L F
.30943 .39763 m .3104 .3951 L .31214 .39676 L 0 .029 .129 r
F
.30943 .39763 m .30769 .39597 L .3104 .3951 L F
.48504 .40978 m .48627 .408 L .48784 .40946 L 0 .062 .164 r
F
.48504 .40978 m .48347 .40837 L .48627 .408 L F
.20302 .39626 m .20386 .39349 L .20569 .39527 L 0 .026 .125 r
F
.20302 .39626 m .20119 .39451 L .20386 .39349 L F
.7407 .39807 m .74231 .39535 L .74364 .39712 L 0 .03 .13 r
F
.7407 .39807 m .73937 .39633 L .74231 .39535 L F
.86429 .39609 m .8661 .39358 L .8673 .39521 L 0 .026 .125 r
F
.86429 .39609 m .86309 .39446 L .8661 .39358 L F
.53683 .41187 m .53815 .4101 L .53967 .41131 L 0 .068 .17 r
F
.53683 .41187 m .53532 .41064 L .53815 .4101 L F
.81686 .39635 m .81859 .39369 L .81984 .39547 L 0 .027 .126 r
F
.81686 .39635 m .8156 .39457 L .81859 .39369 L F
.24327 .39656 m .24416 .39381 L .24595 .39562 L F
.24327 .39656 m .24148 .39476 L .24416 .39381 L F
.39429 .40035 m .39538 .39799 L .39704 .39972 L 0 .036 .137 r
F
.39429 .40035 m .39263 .39862 L .39538 .39799 L F
.55119 .41111 m .55254 .40927 L .55403 .41019 L 0 .066 .168 r
F
.55119 .41111 m .54969 .41025 L .55254 .40927 L F
.87149 .39587 m .87329 .39319 L .87449 .39485 L 0 .026 .125 r
F
.87149 .39587 m .8703 .39422 L .87329 .39319 L F
.33531 .39886 m .33632 .39629 L .33804 .39792 L 0 .032 .133 r
F
.33531 .39886 m .33359 .39722 L .33632 .39629 L F
.21018 .39614 m .21101 .39348 L .21283 .3953 L 0 .026 .126 r
F
.21018 .39614 m .20835 .39433 L .21101 .39348 L F
.28351 .39694 m .28445 .39429 L .28621 .3961 L 0 .028 .128 r
F
.28351 .39694 m .28175 .39516 L .28445 .39429 L F
.54402 .4117 m .54535 .41025 L .54685 .41112 L 0 .069 .17 r
F
.54402 .4117 m .54251 .41078 L .54535 .41025 L F
.413 .40196 m .41412 .39963 L .41576 .40131 L 0 .04 .142 r
F
.413 .40196 m .41136 .40023 L .41412 .39963 L F
.82406 .39619 m .8258 .39353 L .82704 .3952 L 0 .027 .126 r
F
.82406 .39619 m .82282 .39451 L .8258 .39353 L F
.87869 .3956 m .8805 .39294 L .8817 .39471 L 0 .025 .124 r
F
.87869 .3956 m .87749 .39385 L .8805 .39294 L F
.7479 .39799 m .74953 .39536 L .75085 .39713 L 0 .031 .131 r
F
.7479 .39799 m .74658 .39623 L .74953 .39536 L F
.34248 .3986 m .3435 .3962 L .34521 .39782 L 0 .032 .133 r
F
.34248 .3986 m .34077 .39698 L .3435 .3962 L F
.31658 .39761 m .31757 .39507 L .3193 .39681 L 0 .03 .13 r
F
.31658 .39761 m .31485 .39591 L .31757 .39507 L F
.83125 .39583 m .83301 .3933 L .83424 .39493 L 0 .026 .125 r
F
.83125 .39583 m .83002 .39422 L .83301 .3933 L F
.76227 .39726 m .76392 .39463 L .76521 .39626 L 0 .029 .129 r
F
.76227 .39726 m .76097 .39565 L .76392 .39463 L F
.25042 .39649 m .25133 .39371 L .25311 .39555 L 0 .027 .127 r
F
.25042 .39649 m .24864 .39467 L .25133 .39371 L F
.36837 .39972 m .36943 .39725 L .37111 .39894 L 0 .035 .136 r
F
.36837 .39972 m .36669 .39801 L .36943 .39725 L F
.50376 .41168 m .50501 .41034 L .50657 .41135 L 0 .069 .171 r
F
.50376 .41168 m .5022 .41058 L .50501 .41034 L F
.44325 .40532 m .44441 .40303 L .44602 .40485 L 0 .049 .151 r
F
.44325 .40532 m .44164 .40348 L .44441 .40303 L F
.7551 .39781 m .75673 .39514 L .75803 .39673 L 0 .03 .131 r
F
.7551 .39781 m .7538 .39624 L .75673 .39514 L F
.58993 .40698 m .59133 .40458 L .59279 .40607 L 0 .053 .156 r
F
.58993 .40698 m .58847 .40553 L .59133 .40458 L F
.45478 .40719 m .45597 .40466 L .45757 .40639 L 0 .054 .156 r
F
.45478 .40719 m .45318 .40543 L .45597 .40466 L F
.76946 .39704 m .77112 .39437 L .77242 .39612 L 0 .029 .128 r
F
.76946 .39704 m .76816 .39532 L .77112 .39437 L F
.69329 .39884 m .69484 .39613 L .6962 .39775 L 0 .033 .133 r
F
.69329 .39884 m .69193 .39725 L .69484 .39613 L F
.83845 .39567 m .84022 .39311 L .84145 .39477 L 0 .026 .125 r
F
.83845 .39567 m .83723 .39402 L .84022 .39311 L F
.60429 .40625 m .60571 .40366 L .60715 .405 L 0 .051 .154 r
F
.60429 .40625 m .60285 .40494 L .60571 .40366 L F
.59711 .40668 m .59852 .40428 L .59998 .40582 L 0 .053 .155 r
F
.59711 .40668 m .59566 .40517 L .59852 .40428 L F
.29066 .39693 m .29162 .3942 L .29337 .39599 L 0 .028 .128 r
F
.29066 .39693 m .28891 .39515 L .29162 .3942 L F
.58275 .40752 m .58414 .40514 L .58561 .40649 L 0 .055 .158 r
F
.58275 .40752 m .58128 .40616 L .58414 .40514 L F
.25758 .39639 m .25848 .39375 L .26026 .39551 L 0 .028 .127 r
F
.25758 .39639 m .25579 .39463 L .25848 .39375 L F
.70048 .39859 m .70204 .39589 L .7034 .39767 L 0 .032 .133 r
F
.70048 .39859 m .69912 .39681 L .70204 .39589 L F
.88591 .39561 m .88773 .39286 L .88892 .39466 L 0 .026 .125 r
F
.88591 .39561 m .88472 .39382 L .88773 .39286 L F
.65021 .4014 m .65171 .39904 L .65311 .40051 L 0 .039 .141 r
F
.65021 .4014 m .64881 .39995 L .65171 .39904 L F
.64303 .40181 m .64451 .39942 L .64592 .40088 L 0 .04 .142 r
F
.64303 .40181 m .64162 .40038 L .64451 .39942 L F
.4317 .40383 m .43286 .40119 L .43448 .40304 L 0 .045 .147 r
F
.4317 .40383 m .43008 .402 L .43286 .40119 L F
.46196 .40702 m .46315 .40483 L .46475 .40626 L 0 .054 .157 r
F
.46196 .40702 m .46036 .4056 L .46315 .40483 L F
.2173 .39627 m .21816 .39349 L .21998 .39531 L 0 .027 .127 r
F
.2173 .39627 m .21549 .39445 L .21816 .39349 L F
.77667 .39691 m .77832 .39407 L .77961 .39587 L 0 .028 .128 r
F
.77667 .39691 m .77537 .3951 L .77832 .39407 L F
.68613 .3995 m .68766 .39682 L .68903 .39838 L 0 .034 .136 r
F
.68613 .3995 m .68476 .39796 L .68766 .39682 L F
.34963 .39875 m .35066 .39635 L .35236 .39802 L 0 .033 .134 r
F
.34963 .39875 m .34793 .3971 L .35066 .39635 L F
.6574 .40115 m .6589 .39864 L .6603 .40019 L 0 .039 .14 r
F
.6574 .40115 m .656 .39962 L .6589 .39864 L F
.37554 .39976 m .37661 .39728 L .37828 .3989 L 0 .035 .137 r
F
.37554 .39976 m .37386 .39811 L .37661 .39728 L F
.66458 .40076 m .66608 .39792 L .66748 .39967 L 0 .037 .139 r
F
.66458 .40076 m .66319 .39906 L .66608 .39792 L F
.32373 .39778 m .32472 .39527 L .32644 .39707 L 0 .031 .131 r
F
.32373 .39778 m .32201 .39601 L .32472 .39527 L F
.62149 .40317 m .62293 .40055 L .62437 .40218 L 0 .043 .146 r
F
.62149 .40317 m .62005 .40154 L .62293 .40055 L F
.89312 .39541 m .89494 .39261 L .89612 .39438 L 0 .026 .124 r
F
.89312 .39541 m .89193 .39364 L .89494 .39261 L F
.29783 .39681 m .29877 .39438 L .30053 .39602 L 0 .029 .129 r
F
.29783 .39681 m .29607 .39517 L .29877 .39438 L F
.84567 .39561 m .84744 .39296 L .84866 .3947 L 0 .026 .125 r
F
.84567 .39561 m .84444 .39386 L .84744 .39296 L F
.22447 .39602 m .22533 .39331 L .22715 .39503 L 0 .027 .126 r
F
.22447 .39602 m .22265 .39431 L .22533 .39331 L F
.79104 .39624 m .79273 .39359 L .794 .39527 L 0 .028 .127 r
F
.79104 .39624 m .78976 .39456 L .79273 .39359 L F
.78386 .39664 m .78552 .39379 L .78681 .3956 L 0 .028 .128 r
F
.78386 .39664 m .78257 .39484 L .78552 .39379 L F
.57557 .4082 m .57695 .40593 L .57843 .40718 L 0 .058 .16 r
F
.57557 .4082 m .5741 .40691 L .57695 .40593 L F
.67177 .40044 m .67328 .39769 L .67467 .3995 L 0 .037 .138 r
F
.67177 .40044 m .67037 .39866 L .67328 .39769 L F
.90031 .39507 m .90216 .39242 L .90332 .39412 L 0 .025 .124 r
F
.90031 .39507 m .89914 .3934 L .90216 .39242 L F
.71486 .39806 m .71644 .39542 L .71779 .3971 L 0 .031 .132 r
F
.71486 .39806 m .71351 .39639 L .71644 .39542 L F
.26474 .39628 m .26565 .39364 L .26743 .39531 L 0 .028 .127 r
F
.26474 .39628 m .26295 .39462 L .26565 .39364 L F
.70768 .3985 m .70924 .39567 L .7106 .39744 L 0 .032 .133 r
F
.70768 .3985 m .70632 .39672 L .70924 .39567 L F
.40143 .4009 m .40255 .39828 L .40419 .40007 L 0 .038 .14 r
F
.40143 .4009 m .39979 .39908 L .40255 .39828 L F
.42015 .4023 m .42128 .40005 L .42292 .40166 L 0 .042 .144 r
F
.42015 .4023 m .41852 .40067 L .42128 .40005 L F
.63586 .40252 m .63732 .39977 L .63874 .40141 L F
.63586 .40252 m .63444 .40086 L .63732 .39977 L F
.72205 .39776 m .72365 .3953 L .72498 .39687 L 0 .031 .132 r
F
.72205 .39776 m .72072 .3962 L .72365 .3953 L F
.62868 .40295 m .63013 .40025 L .63156 .40195 L 0 .043 .145 r
F
.62868 .40295 m .62725 .40123 L .63013 .40025 L F
.49221 .41052 m .49345 .40883 L .49502 .41012 L 0 .066 .168 r
F
.49221 .41052 m .49065 .40914 L .49345 .40883 L F
.46913 .40693 m .47034 .40503 L .47192 .40649 L 0 .055 .158 r
F
.46913 .40693 m .46754 .4055 L .47034 .40503 L F
.48067 .40873 m .48189 .40695 L .48347 .40837 L 0 .061 .163 r
F
.48067 .40873 m .47909 .40736 L .48189 .40695 L F
.79823 .39598 m .79994 .39338 L .8012 .39503 L 0 .027 .127 r
F
.79823 .39598 m .79697 .39433 L .79994 .39338 L F
.27191 .39598 m .27284 .39329 L .27461 .39499 L 0 .027 .126 r
F
.27191 .39598 m .27013 .39429 L .27284 .39329 L F
.23164 .3958 m .23251 .39315 L .23431 .39488 L F
.23164 .3958 m .22983 .39409 L .23251 .39315 L F
.56839 .40876 m .56976 .40652 L .57124 .40784 L 0 .06 .162 r
F
.56839 .40876 m .56691 .4074 L .56976 .40652 L F
.67896 .40021 m .68048 .39744 L .68186 .39909 L 0 .036 .138 r
F
.67896 .40021 m .67758 .39855 L .68048 .39744 L F
.38271 .39962 m .38379 .39709 L .38546 .39869 L 0 .035 .137 r
F
.38271 .39962 m .38103 .39802 L .38379 .39709 L F
.90751 .39486 m .90937 .39216 L .91053 .39387 L 0 .025 .123 r
F
.90751 .39486 m .90634 .39315 L .90937 .39216 L F
.80542 .39567 m .80713 .39293 L .80839 .39463 L 0 .026 .126 r
F
.80542 .39567 m .80416 .39398 L .80713 .39293 L F
.85288 .39549 m .85465 .39276 L .85587 .39454 L 0 .026 .125 r
F
.85288 .39549 m .85166 .39373 L .85465 .39276 L F
.51093 .41205 m .51221 .41029 L .51375 .41138 L 0 .071 .172 r
F
.51093 .41205 m .50939 .41095 L .51221 .41029 L F
.72924 .39752 m .73085 .39502 L .73218 .39659 L 0 .031 .131 r
F
.72924 .39752 m .72792 .39595 L .73085 .39502 L F
.5253 .41128 m .5266 .40924 L .52813 .41043 L 0 .068 .169 r
F
.5253 .41128 m .52377 .41011 L .5266 .40924 L F
.61432 .40392 m .61575 .40127 L .61719 .40273 L 0 .046 .148 r
F
.61432 .40392 m .61288 .40251 L .61575 .40127 L F
.38988 .39936 m .39097 .397 L .39263 .39862 L 0 .035 .137 r
F
.38988 .39936 m .38822 .39776 L .39097 .397 L F
.56121 .40933 m .56257 .40719 L .56406 .40834 L 0 .062 .164 r
F
.56121 .40933 m .55972 .40822 L .56257 .40719 L F
.35679 .39877 m .35784 .39614 L .35953 .39786 L 0 .033 .134 r
F
.35679 .39877 m .3551 .39708 L .35784 .39614 L F
.91471 .39462 m .91657 .39188 L .91773 .39363 L 0 .025 .123 r
F
.91471 .39462 m .91355 .39288 L .91657 .39188 L F
.51812 .41178 m .5194 .40992 L .52094 .41098 L 0 .07 .171 r
F
.51812 .41178 m .51658 .4107 L .5194 .40992 L F
.81262 .39544 m .81434 .39278 L .8156 .39457 L 0 .026 .125 r
F
.81262 .39544 m .81136 .39365 L .81434 .39278 L F
.30498 .39685 m .30594 .39433 L .30769 .39597 L 0 .03 .13 r
F
.30498 .39685 m .30323 .39521 L .30594 .39433 L F
.2388 .3957 m .23968 .39299 L .24148 .39476 L 0 .027 .126 r
F
.2388 .3957 m .23699 .39395 L .23968 .39299 L F
.73644 .3973 m .73804 .39462 L .73937 .39633 L 0 .03 .13 r
F
.73644 .3973 m .73511 .39563 L .73804 .39462 L F
.19852 .39552 m .19935 .39276 L .20119 .39451 L 0 .026 .126 r
F
.19852 .39552 m .19668 .3938 L .19935 .39276 L F
.43886 .40409 m .44003 .40164 L .44164 .40348 L 0 .047 .149 r
F
.43886 .40409 m .43725 .40224 L .44003 .40164 L F
.86009 .39534 m .86188 .39273 L .86309 .39446 L 0 .026 .125 r
F
.86009 .39534 m .85887 .39361 L .86188 .39273 L F
.27906 .39594 m .27999 .39337 L .28175 .39516 L 0 .028 .127 r
F
.27906 .39594 m .2773 .39418 L .27999 .39337 L F
.4086 .40099 m .40972 .39851 L .41136 .40023 L 0 .039 .141 r
F
.4086 .40099 m .40696 .39924 L .40972 .39851 L F
.33087 .39802 m .33187 .39557 L .33359 .39722 L 0 .032 .133 r
F
.33087 .39802 m .32915 .39635 L .33187 .39557 L F
.92192 .39444 m .92379 .39164 L .92495 .39346 L 0 .024 .123 r
F
.92192 .39444 m .92076 .39264 L .92379 .39164 L F
.53248 .41118 m .53379 .4094 L .53532 .41064 L 0 .069 .17 r
F
.53248 .41118 m .53096 .40991 L .53379 .4094 L F
.20569 .39527 m .20652 .39253 L .20835 .39433 L 0 .026 .125 r
F
.20569 .39527 m .20386 .39349 L .20652 .39253 L F
.74364 .39712 m .74525 .39444 L .74658 .39623 L 0 .03 .13 r
F
.74364 .39712 m .74231 .39535 L .74525 .39444 L F
.31214 .39676 m .31312 .39422 L .31485 .39591 L F
.31214 .39676 m .3104 .3951 L .31312 .39422 L F
.36396 .39877 m .36501 .39628 L .36669 .39801 L 0 .034 .135 r
F
.36396 .39877 m .36227 .39703 L .36501 .39628 L F
.8673 .39521 m .8691 .39257 L .8703 .39422 L 0 .026 .125 r
F
.8673 .39521 m .8661 .39358 L .8691 .39257 L F
.4504 .40618 m .45158 .40366 L .45318 .40543 L 0 .053 .155 r
F
.4504 .40618 m .4488 .40438 L .45158 .40366 L F
.24595 .39562 m .24685 .39284 L .24864 .39467 L 0 .027 .126 r
F
.24595 .39562 m .24416 .39381 L .24685 .39284 L F
.55403 .41019 m .55538 .40829 L .55688 .40925 L 0 .066 .167 r
F
.55403 .41019 m .55254 .40927 L .55538 .40829 L F
.87449 .39485 m .8763 .39216 L .87749 .39385 L 0 .026 .124 r
F
.87449 .39485 m .87329 .39319 L .8763 .39216 L F
.81984 .39547 m .82157 .39273 L .82282 .39451 L 0 .027 .126 r
F
.81984 .39547 m .81859 .39369 L .82157 .39273 L F
.42731 .40267 m .42846 .40037 L .43008 .402 L 0 .044 .146 r
F
.42731 .40267 m .42569 .40103 L .42846 .40037 L F
.49939 .41087 m .50064 .40952 L .5022 .41058 L 0 .069 .17 r
F
.49939 .41087 m .49783 .40973 L .50064 .40952 L F
.33804 .39792 m .33906 .39536 L .34077 .39698 L 0 .032 .133 r
F
.33804 .39792 m .33632 .39629 L .33906 .39536 L F
.82704 .3952 m .82878 .39255 L .83002 .39422 L 0 .026 .126 r
F
.82704 .3952 m .8258 .39353 L .82878 .39255 L F
.60715 .405 m .60857 .40238 L .61002 .40376 L 0 .05 .152 r
F
.60715 .405 m .60571 .40366 L .60857 .40238 L F
.76521 .39626 m .76687 .39366 L .76816 .39532 L 0 .029 .129 r
F
.76521 .39626 m .76392 .39463 L .76687 .39366 L F
.21283 .3953 m .21367 .39262 L .21549 .39445 L 0 .027 .126 r
F
.21283 .3953 m .21101 .39348 L .21367 .39262 L F
.28621 .3961 m .28716 .39334 L .28891 .39515 L 0 .028 .128 r
F
.28621 .3961 m .28445 .39429 L .28716 .39334 L F
.8817 .39471 m .88352 .39203 L .88472 .39382 L 0 .026 .124 r
F
.8817 .39471 m .8805 .39294 L .88352 .39203 L F
.83424 .39493 m .836 .39237 L .83723 .39402 L 0 .026 .125 r
F
.83424 .39493 m .83301 .3933 L .836 .39237 L F
.39704 .39972 m .39813 .39735 L .39979 .39908 L 0 .037 .139 r
F
.39704 .39972 m .39538 .39799 L .39813 .39735 L F
.75803 .39673 m .75967 .39404 L .76097 .39565 L 0 .03 .13 r
F
.75803 .39673 m .75673 .39514 L .75967 .39404 L F
.75085 .39713 m .75248 .39446 L .7538 .39624 L 0 .031 .131 r
F
.75085 .39713 m .74953 .39536 L .75248 .39446 L F
.25311 .39555 m .25401 .39278 L .25579 .39463 L 0 .027 .127 r
F
.25311 .39555 m .25133 .39371 L .25401 .39278 L F
.6962 .39775 m .69775 .39518 L .69912 .39681 L 0 .032 .133 r
F
.6962 .39775 m .69484 .39613 L .69775 .39518 L F
.53967 .41131 m .54099 .40959 L .54251 .41078 L 0 .07 .171 r
F
.53967 .41131 m .53815 .4101 L .54099 .40959 L F
.3193 .39681 m .32029 .39423 L .32201 .39601 L 0 .03 .13 r
F
.3193 .39681 m .31757 .39507 L .32029 .39423 L F
.34521 .39782 m .34622 .39546 L .34793 .3971 L 0 .033 .134 r
F
.34521 .39782 m .3435 .3962 L .34622 .39546 L F
.4763 .40764 m .47751 .40589 L .47909 .40736 L 0 .059 .162 r
F
.4763 .40764 m .47472 .4062 L .47751 .40589 L F
.59279 .40607 m .59419 .40364 L .59566 .40517 L 0 .053 .156 r
F
.59279 .40607 m .59133 .40458 L .59419 .40364 L F
.48784 .40946 m .48908 .40767 L .49065 .40914 L 0 .065 .166 r
F
.48784 .40946 m .48627 .408 L .48908 .40767 L F
.77242 .39612 m .77407 .39335 L .77537 .3951 L 0 .029 .128 r
F
.77242 .39612 m .77112 .39437 L .77407 .39335 L F
.58561 .40649 m .587 .40413 L .58847 .40553 L 0 .055 .157 r
F
.58561 .40649 m .58414 .40514 L .587 .40413 L F
.41576 .40131 m .41688 .39903 L .41852 .40067 L 0 .041 .143 r
F
.41576 .40131 m .41412 .39963 L .41688 .39903 L F
.37111 .39894 m .37218 .39645 L .37386 .39811 L 0 .035 .137 r
F
.37111 .39894 m .36943 .39725 L .37218 .39645 L F
.84145 .39477 m .84322 .39219 L .84444 .39386 L 0 .026 .125 r
F
.84145 .39477 m .84022 .39311 L .84322 .39219 L F
.54685 .41112 m .54819 .40936 L .54969 .41025 L 0 .07 .171 r
F
.54685 .41112 m .54535 .41025 L .54819 .40936 L F
.68903 .39838 m .69056 .39566 L .69193 .39725 L 0 .034 .135 r
F
.68903 .39838 m .68766 .39682 L .69056 .39566 L F
.29337 .39599 m .29432 .39338 L .29607 .39517 L 0 .029 .128 r
F
.29337 .39599 m .29162 .3942 L .29432 .39338 L F
.45757 .40639 m .45876 .4039 L .46036 .4056 L 0 .054 .157 r
F
.45757 .40639 m .45597 .40466 L .45876 .4039 L F
.59998 .40582 m .60139 .40337 L .60285 .40494 L 0 .053 .155 r
F
.59998 .40582 m .59852 .40428 L .60139 .40337 L F
.88892 .39466 m .89074 .39183 L .89193 .39364 L 0 .026 .124 r
F
.88892 .39466 m .88773 .39286 L .89074 .39183 L F
.77961 .39587 m .78127 .39303 L .78257 .39484 L 0 .028 .128 r
F
.77961 .39587 m .77832 .39407 L .78127 .39303 L F
.7034 .39767 m .70496 .39495 L .70632 .39672 L 0 .032 .133 r
F
.7034 .39767 m .70204 .39589 L .70496 .39495 L F
.66748 .39967 m .66898 .39688 L .67037 .39866 L 0 .037 .138 r
F
.66748 .39967 m .66608 .39792 L .66898 .39688 L F
.64592 .40088 m .6474 .39846 L .64881 .39995 L 0 .04 .142 r
F
.64592 .40088 m .64451 .39942 L .6474 .39846 L F
.26026 .39551 m .26117 .39286 L .26295 .39462 L 0 .028 .127 r
F
.26026 .39551 m .25848 .39375 L .26117 .39286 L F
.21998 .39531 m .22084 .39249 L .22265 .39431 L 0 .027 .126 r
F
.21998 .39531 m .21816 .39349 L .22084 .39249 L F
.65311 .40051 m .6546 .39812 L .656 .39962 L 0 .039 .141 r
F
.65311 .40051 m .65171 .39904 L .6546 .39812 L F
.89612 .39438 m .89795 .39162 L .89914 .3934 L 0 .025 .124 r
F
.89612 .39438 m .89494 .39261 L .89795 .39162 L F
.78681 .3956 m .78848 .39275 L .78976 .39456 L 0 .028 .127 r
F
.78681 .3956 m .78552 .39379 L .78848 .39275 L F
.62437 .40218 m .62581 .39961 L .62725 .40123 L 0 .043 .146 r
F
.62437 .40218 m .62293 .40055 L .62581 .39961 L F
.6603 .40019 m .66179 .39747 L .66319 .39906 L 0 .038 .14 r
F
.6603 .40019 m .6589 .39864 L .66179 .39747 L F
.57843 .40718 m .57981 .40493 L .58128 .40616 L 0 .057 .16 r
F
.57843 .40718 m .57695 .40593 L .57981 .40493 L F
.22715 .39503 m .22801 .39235 L .22983 .39409 L 0 .027 .126 r
F
.22715 .39503 m .22533 .39331 L .22801 .39235 L F
.63874 .40141 m .6402 .39873 L .64162 .40038 L 0 .041 .143 r
F
.63874 .40141 m .63732 .39977 L .6402 .39873 L F
.7106 .39744 m .71216 .39462 L .71351 .39639 L 0 .032 .132 r
F
.7106 .39744 m .70924 .39567 L .71216 .39462 L F
.43448 .40304 m .43564 .40038 L .43725 .40224 L 0 .045 .148 r
F
.43448 .40304 m .43286 .40119 L .43564 .40038 L F
.794 .39527 m .7957 .39266 L .79697 .39433 L 0 .027 .127 r
F
.794 .39527 m .79273 .39359 L .7957 .39266 L F
.44602 .40485 m .44719 .40258 L .4488 .40438 L 0 .051 .153 r
F
.44602 .40485 m .44441 .40303 L .44719 .40258 L F
.84866 .3947 m .85043 .39197 L .85166 .39373 L 0 .026 .125 r
F
.84866 .3947 m .84744 .39296 L .85043 .39197 L F
.68186 .39909 m .68338 .39632 L .68476 .39796 L 0 .036 .137 r
F
.68186 .39909 m .68048 .39744 L .68338 .39632 L F
.46475 .40626 m .46595 .40406 L .46754 .4055 L 0 .055 .157 r
F
.46475 .40626 m .46315 .40483 L .46595 .40406 L F
.71779 .3971 m .71937 .39451 L .72072 .3962 L 0 .031 .132 r
F
.71779 .3971 m .71644 .39542 L .71937 .39451 L F
.26743 .39531 m .26836 .3926 L .27013 .39429 L 0 .027 .127 r
F
.26743 .39531 m .26565 .39364 L .26836 .3926 L F
.90332 .39412 m .90518 .39144 L .90634 .39315 L 0 .025 .124 r
F
.90332 .39412 m .90216 .39242 L .90518 .39144 L F
.37828 .3989 m .37936 .39642 L .38103 .39802 L 0 .036 .137 r
F
.37828 .3989 m .37661 .39728 L .37936 .39642 L F
.67467 .3995 m .67618 .3967 L .67758 .39855 L 0 .037 .138 r
F
.67467 .3995 m .67328 .39769 L .67618 .3967 L F
.61719 .40273 m .61862 .40002 L .62005 .40154 L 0 .045 .147 r
F
.61719 .40273 m .61575 .40127 L .61862 .40002 L F
.63156 .40195 m .63301 .39919 L .63444 .40086 L 0 .043 .145 r
F
.63156 .40195 m .63013 .40025 L .63301 .39919 L F
.27461 .39499 m .27553 .39246 L .2773 .39418 L 0 .027 .127 r
F
.27461 .39499 m .27284 .39329 L .27553 .39246 L F
.50657 .41135 m .50783 .41 L .50939 .41095 L 0 .072 .173 r
F
.50657 .41135 m .50501 .41034 L .50783 .41 L F
.30053 .39602 m .30148 .39357 L .30323 .39521 L 0 .03 .13 r
F
.30053 .39602 m .29877 .39438 L .30148 .39357 L F
.80839 .39463 m .8101 .39195 L .81136 .39365 L 0 .026 .125 r
F
.80839 .39463 m .80713 .39293 L .8101 .39195 L F
.35236 .39802 m .3534 .39539 L .3551 .39708 L 0 .034 .135 r
F
.35236 .39802 m .35066 .39635 L .3534 .39539 L F
.8012 .39503 m .8029 .39232 L .80416 .39398 L 0 .027 .126 r
F
.8012 .39503 m .79994 .39338 L .8029 .39232 L F
.91053 .39387 m .91239 .39117 L .91355 .39288 L 0 .025 .123 r
F
.91053 .39387 m .90937 .39216 L .91239 .39117 L F
.32644 .39707 m .32744 .39454 L .32915 .39635 L 0 .032 .132 r
F
.32644 .39707 m .32472 .39527 L .32744 .39454 L F
.72498 .39687 m .72658 .39437 L .72792 .39595 L 0 .031 .132 r
F
.72498 .39687 m .72365 .3953 L .72658 .39437 L F
.23431 .39488 m .23519 .39219 L .23699 .39395 L 0 .027 .126 r
F
.23431 .39488 m .23251 .39315 L .23519 .39219 L F
.57124 .40784 m .57262 .40563 L .5741 .40691 L 0 .06 .162 r
F
.57124 .40784 m .56976 .40652 L .57262 .40563 L F
.40419 .40007 m .40531 .39747 L .40696 .39924 L 0 .038 .14 r
F
.40419 .40007 m .40255 .39828 L .40531 .39747 L F
.38546 .39869 m .38655 .39615 L .38822 .39776 L 0 .035 .137 r
F
.38546 .39869 m .38379 .39709 L .38655 .39615 L F
.85587 .39454 m .85765 .39182 L .85887 .39361 L 0 .026 .125 r
F
.85587 .39454 m .85465 .39276 L .85765 .39182 L F
.56406 .40834 m .56542 .40625 L .56691 .4074 L 0 .062 .164 r
F
.56406 .40834 m .56257 .40719 L .56542 .40625 L F
.73218 .39659 m .73379 .39405 L .73511 .39563 L 0 .031 .131 r
F
.73218 .39659 m .73085 .39502 L .73379 .39405 L F
.91773 .39363 m .9196 .39087 L .92076 .39264 L 0 .024 .123 r
F
.91773 .39363 m .91657 .39188 L .9196 .39087 L F
.35953 .39786 m .36059 .39528 L .36227 .39703 L 0 .034 .135 r
F
.35953 .39786 m .35784 .39614 L .36059 .39528 L F
.42292 .40166 m .42405 .39945 L .42569 .40103 L 0 .043 .146 r
F
.42292 .40166 m .42128 .40005 L .42405 .39945 L F
.52813 .41043 m .52943 .40876 L .53096 .40991 L 0 .069 .17 r
F
.52813 .41043 m .5266 .40924 L .52943 .40876 L F
.20119 .39451 m .20202 .39172 L .20386 .39349 L 0 .026 .125 r
F
.20119 .39451 m .19935 .39276 L .20202 .39172 L F
.73937 .39633 m .74098 .3936 L .74231 .39535 L 0 .03 .13 r
F
.73937 .39633 m .73804 .39462 L .74098 .3936 L F
.24148 .39476 m .24236 .39204 L .24416 .39381 L 0 .027 .126 r
F
.24148 .39476 m .23968 .39299 L .24236 .39204 L F
.8156 .39457 m .81733 .3919 L .81859 .39369 L F
.8156 .39457 m .81434 .39278 L .81733 .3919 L F
.30769 .39597 m .30866 .39345 L .3104 .3951 L 0 .03 .13 r
F
.30769 .39597 m .30594 .39433 L .30866 .39345 L F
.39263 .39862 m .39372 .39636 L .39538 .39799 L 0 .036 .138 r
F
.39263 .39862 m .39097 .397 L .39372 .39636 L F
.51375 .41138 m .51503 .40963 L .51658 .4107 L 0 .072 .173 r
F
.51375 .41138 m .51221 .41029 L .51503 .40963 L F
.52094 .41098 m .52223 .40905 L .52377 .41011 L 0 .07 .172 r
F
.52094 .41098 m .5194 .40992 L .52223 .40905 L F
.86309 .39446 m .86489 .39185 L .8661 .39358 L 0 .026 .126 r
F
.86309 .39446 m .86188 .39273 L .86489 .39185 L F
.20835 .39433 m .20919 .39167 L .21101 .39348 L 0 .026 .125 r
F
.20835 .39433 m .20652 .39253 L .20919 .39167 L F
.47192 .40649 m .47313 .40471 L .47472 .4062 L 0 .058 .16 r
F
.47192 .40649 m .47034 .40503 L .47313 .40471 L F
.28175 .39516 m .2827 .39249 L .28445 .39429 L 0 .028 .128 r
F
.28175 .39516 m .27999 .39337 L .2827 .39249 L F
.49502 .41012 m .49626 .40852 L .49783 .40973 L 0 .069 .17 r
F
.49502 .41012 m .49345 .40883 L .49626 .40852 L F
.61002 .40376 m .61144 .40109 L .61288 .40251 L 0 .048 .151 r
F
.61002 .40376 m .60857 .40238 L .61144 .40109 L F
.48347 .40837 m .4847 .40654 L .48627 .408 L 0 .063 .165 r
F
.48347 .40837 m .48189 .40695 L .4847 .40654 L F
.8703 .39422 m .8721 .39152 L .87329 .39319 L 0 .026 .125 r
F
.8703 .39422 m .8691 .39257 L .8721 .39152 L F
.33359 .39722 m .33461 .39465 L .33632 .39629 L 0 .033 .133 r
F
.33359 .39722 m .33187 .39557 L .33461 .39465 L F
.74658 .39623 m .7482 .39356 L .74953 .39536 L 0 .03 .131 r
F
.74658 .39623 m .74525 .39444 L .7482 .39356 L F
.87749 .39385 m .87931 .39124 L .8805 .39294 L 0 .025 .124 r
F
.87749 .39385 m .8763 .39216 L .87931 .39124 L F
.41136 .40023 m .41248 .39795 L .41412 .39963 L 0 .04 .142 r
F
.41136 .40023 m .40972 .39851 L .41248 .39795 L F
.24864 .39467 m .24954 .39187 L .25133 .39371 L 0 .027 .126 r
F
.24864 .39467 m .24685 .39284 L .24954 .39187 L F
.55688 .40925 m .55823 .40721 L .55972 .40822 L 0 .065 .167 r
F
.55688 .40925 m .55538 .40829 L .55823 .40721 L F
.82282 .39451 m .82455 .39175 L .8258 .39353 L 0 .027 .126 r
F
.82282 .39451 m .82157 .39273 L .82455 .39175 L F
.31485 .39591 m .31584 .39334 L .31757 .39507 L 0 .03 .13 r
F
.31485 .39591 m .31312 .39422 L .31584 .39334 L F
.44164 .40348 m .44281 .40121 L .44441 .40303 L 0 .048 .151 r
F
.44164 .40348 m .44003 .40164 L .44281 .40121 L F
.34077 .39698 m .34179 .39457 L .3435 .3962 L 0 .033 .133 r
F
.34077 .39698 m .33906 .39536 L .34179 .39457 L F
.83002 .39422 m .83177 .39162 L .83301 .3933 L 0 .026 .126 r
F
.83002 .39422 m .82878 .39255 L .83177 .39162 L F
.36669 .39801 m .36775 .39553 L .36943 .39725 L 0 .035 .136 r
F
.36669 .39801 m .36501 .39628 L .36775 .39553 L F
.76097 .39565 m .76262 .39299 L .76392 .39463 L 0 .029 .129 r
F
.76097 .39565 m .75967 .39404 L .76262 .39299 L F
.45318 .40543 m .45437 .40291 L .45597 .40466 L 0 .053 .156 r
F
.45318 .40543 m .45158 .40366 L .45437 .40291 L F
.53532 .41064 m .53663 .4089 L .53815 .4101 L 0 .071 .172 r
F
.53532 .41064 m .53379 .4094 L .53663 .4089 L F
.76816 .39532 m .76982 .39268 L .77112 .39437 L 0 .029 .129 r
F
.76816 .39532 m .76687 .39366 L .76982 .39268 L F
.28891 .39515 m .28987 .39238 L .29162 .3942 L 0 .028 .128 r
F
.28891 .39515 m .28716 .39334 L .28987 .39238 L F
.88472 .39382 m .88653 .39107 L .88773 .39286 L 0 .026 .124 r
F
.88472 .39382 m .88352 .39203 L .88653 .39107 L F
.69912 .39681 m .70068 .39426 L .70204 .39589 L 0 .032 .133 r
F
.69912 .39681 m .69775 .39518 L .70068 .39426 L F
.83723 .39402 m .83899 .39145 L .84022 .39311 L 0 .026 .125 r
F
.83723 .39402 m .836 .39237 L .83899 .39145 L F
.43008 .402 m .43124 .39957 L .43286 .40119 L 0 .045 .147 r
F
.43008 .402 m .42846 .40037 L .43124 .39957 L F
.25579 .39463 m .2567 .39191 L .25848 .39375 L 0 .027 .127 r
F
.25579 .39463 m .25401 .39278 L .2567 .39191 L F
.7538 .39624 m .75542 .39336 L .75673 .39514 L 0 .03 .131 r
F
.7538 .39624 m .75248 .39446 L .75542 .39336 L F
.21549 .39445 m .21635 .39167 L .21816 .39349 L 0 .027 .126 r
F
.21549 .39445 m .21367 .39262 L .21635 .39167 L F
.69193 .39725 m .69347 .3945 L .69484 .39613 L 0 .033 .134 r
F
.69193 .39725 m .69056 .39566 L .69347 .3945 L F
.77537 .3951 m .77702 .39231 L .77832 .39407 L 0 .028 .128 r
F
.77537 .3951 m .77407 .39335 L .77702 .39231 L F
.58847 .40553 m .58986 .40313 L .59133 .40458 L 0 .055 .157 r
F
.58847 .40553 m .587 .40413 L .58986 .40313 L F
.59566 .40517 m .59706 .40271 L .59852 .40428 L 0 .053 .156 r
F
.59566 .40517 m .59419 .40364 L .59706 .40271 L F
.32201 .39601 m .323 .39348 L .32472 .39527 L 0 .031 .131 r
F
.32201 .39601 m .32029 .39423 L .323 .39348 L F
.89193 .39364 m .89375 .39081 L .89494 .39261 L 0 .025 .124 r
F
.89193 .39364 m .89074 .39183 L .89375 .39081 L F
.78257 .39484 m .78423 .39198 L .78552 .39379 L 0 .028 .127 r
F
.78257 .39484 m .78127 .39303 L .78423 .39198 L F
.84444 .39386 m .84621 .39128 L .84744 .39296 L 0 .026 .125 r
F
.84444 .39386 m .84322 .39219 L .84621 .39128 L F
.66319 .39906 m .66468 .3963 L .66608 .39792 L 0 .037 .139 r
F
.66319 .39906 m .66179 .39747 L .66468 .3963 L F
.67037 .39866 m .67188 .39587 L .67328 .39769 L 0 .036 .138 r
F
.67037 .39866 m .66898 .39688 L .67188 .39587 L F
.54969 .41025 m .55104 .40833 L .55254 .40927 L 0 .07 .171 r
F
.54969 .41025 m .54819 .40936 L .55104 .40833 L F
.39979 .39908 m .4009 .39655 L .40255 .39828 L 0 .038 .14 r
F
.39979 .39908 m .39813 .39735 L .4009 .39655 L F
.22265 .39431 m .22352 .3915 L .22533 .39331 L 0 .027 .126 r
F
.22265 .39431 m .22084 .39249 L .22352 .3915 L F
.34793 .3971 m .34896 .3947 L .35066 .39635 L 0 .034 .134 r
F
.34793 .3971 m .34622 .39546 L .34896 .3947 L F
.37386 .39811 m .37493 .39565 L .37661 .39728 L 0 .036 .137 r
F
.37386 .39811 m .37218 .39645 L .37493 .39565 L F
.70632 .39672 m .70788 .39391 L .70924 .39567 L 0 .032 .133 r
F
.70632 .39672 m .70496 .39495 L .70788 .39391 L F
.78976 .39456 m .79144 .39178 L .79273 .39359 L 0 .027 .127 r
F
.78976 .39456 m .78848 .39275 L .79144 .39178 L F
.62005 .40154 m .6215 .39902 L .62293 .40055 L 0 .044 .146 r
F
.62005 .40154 m .61862 .40002 L .6215 .39902 L F
.64881 .39995 m .6503 .39753 L .65171 .39904 L 0 .04 .142 r
F
.64881 .39995 m .6474 .39846 L .6503 .39753 L F
.68476 .39796 m .68628 .39518 L .68766 .39682 L 0 .035 .136 r
F
.68476 .39796 m .68338 .39632 L .68628 .39518 L F
.29607 .39517 m .29703 .39258 L .29877 .39438 L 0 .029 .129 r
F
.29607 .39517 m .29432 .39338 L .29703 .39258 L F
.60285 .40494 m .60426 .40211 L .60571 .40366 L 0 .052 .155 r
F
.60285 .40494 m .60139 .40337 L .60426 .40211 L F
.71351 .39639 m .71509 .39365 L .71644 .39542 L 0 .031 .132 r
F
.71351 .39639 m .71216 .39462 L .71509 .39365 L F
.89914 .3934 m .90097 .39064 L .90216 .39242 L 0 .025 .124 r
F
.89914 .3934 m .89795 .39162 L .90097 .39064 L F
.58128 .40616 m .58267 .40391 L .58414 .40514 L 0 .057 .159 r
F
.58128 .40616 m .57981 .40493 L .58267 .40391 L F
.64162 .40038 m .64309 .39774 L .64451 .39942 L 0 .041 .143 r
F
.64162 .40038 m .6402 .39873 L .64309 .39774 L F
.26295 .39462 m .26387 .39188 L .26565 .39364 L 0 .028 .127 r
F
.26295 .39462 m .26117 .39286 L .26387 .39188 L F
.46036 .4056 m .46156 .4032 L .46315 .40483 L 0 .055 .158 r
F
.46036 .4056 m .45876 .4039 L .46156 .4032 L F
.54251 .41078 m .54384 .40907 L .54535 .41025 L 0 .072 .173 r
F
.54251 .41078 m .54099 .40959 L .54384 .40907 L F
.5022 .41058 m .50346 .40936 L .50501 .41034 L F
.5022 .41058 m .50064 .40952 L .50346 .40936 L F
.656 .39962 m .6575 .39712 L .6589 .39864 L 0 .039 .141 r
F
.656 .39962 m .6546 .39812 L .6575 .39712 L F
.62725 .40123 m .6287 .39865 L .63013 .40025 L 0 .043 .145 r
F
.62725 .40123 m .62581 .39961 L .6287 .39865 L F
.63444 .40086 m .63589 .39812 L .63732 .39977 L 0 .042 .144 r
F
.63444 .40086 m .63301 .39919 L .63589 .39812 L F
.41852 .40067 m .41965 .39844 L .42128 .40005 L 0 .043 .145 r
F
.41852 .40067 m .41688 .39903 L .41965 .39844 L F
.22983 .39409 m .23069 .39139 L .23251 .39315 L 0 .027 .126 r
F
.22983 .39409 m .22801 .39235 L .23069 .39139 L F
.27013 .39429 m .27106 .39158 L .27284 .39329 L 0 .027 .127 r
F
.27013 .39429 m .26836 .3926 L .27106 .39158 L F
.79697 .39433 m .79867 .39172 L .79994 .39338 L F
.79697 .39433 m .7957 .39266 L .79867 .39172 L F
.85166 .39373 m .85343 .39098 L .85465 .39276 L 0 .026 .125 r
F
.85166 .39373 m .85043 .39197 L .85343 .39098 L F
.90634 .39315 m .9082 .39045 L .90937 .39216 L 0 .025 .124 r
F
.90634 .39315 m .90518 .39144 L .9082 .39045 L F
.67758 .39855 m .67909 .39561 L .68048 .39744 L 0 .036 .138 r
F
.67758 .39855 m .67618 .3967 L .67909 .39561 L F
.80416 .39398 m .80587 .39126 L .80713 .39293 L 0 .027 .126 r
F
.80416 .39398 m .8029 .39232 L .80587 .39126 L F
.72072 .3962 m .72231 .39359 L .72365 .3953 L 0 .032 .132 r
F
.72072 .3962 m .71937 .39451 L .72231 .39359 L F
.38103 .39802 m .38212 .39548 L .38379 .39709 L 0 .036 .137 r
F
.38103 .39802 m .37936 .39642 L .38212 .39548 L F
.81136 .39365 m .81308 .39105 L .81434 .39278 L 0 .026 .125 r
F
.81136 .39365 m .8101 .39195 L .81308 .39105 L F
.43725 .40224 m .43842 .39979 L .44003 .40164 L 0 .046 .149 r
F
.43725 .40224 m .43564 .40038 L .43842 .39979 L F
.91355 .39288 m .91541 .39016 L .91657 .39188 L 0 .025 .123 r
F
.91355 .39288 m .91239 .39117 L .91541 .39016 L F
.3551 .39708 m .35615 .39442 L .35784 .39614 L 0 .034 .134 r
F
.3551 .39708 m .3534 .39539 L .35615 .39442 L F
.46754 .4055 m .46875 .40357 L .47034 .40503 L 0 .056 .159 r
F
.46754 .4055 m .46595 .40406 L .46875 .40357 L F
.23699 .39395 m .23787 .39123 L .23968 .39299 L 0 .027 .126 r
F
.23699 .39395 m .23519 .39219 L .23787 .39123 L F
.5741 .40691 m .57547 .40467 L .57695 .40593 L 0 .06 .162 r
F
.5741 .40691 m .57262 .40563 L .57547 .40467 L F
.72792 .39595 m .72952 .39345 L .73085 .39502 L 0 .031 .132 r
F
.72792 .39595 m .72658 .39437 L .72952 .39345 L F
.38822 .39776 m .3893 .39538 L .39097 .397 L 0 .036 .137 r
F
.38822 .39776 m .38655 .39615 L .3893 .39538 L F
.2773 .39418 m .27823 .39163 L .27999 .39337 L 0 .028 .127 r
F
.2773 .39418 m .27553 .39246 L .27823 .39163 L F
.49065 .40914 m .49188 .40737 L .49345 .40883 L 0 .067 .169 r
F
.49065 .40914 m .48908 .40767 L .49188 .40737 L F
.47909 .40736 m .48032 .40544 L .48189 .40695 L 0 .062 .164 r
F
.47909 .40736 m .47751 .40589 L .48032 .40544 L F
.19668 .3938 m .19751 .39101 L .19935 .39276 L 0 .026 .126 r
F
.19668 .3938 m .19483 .39207 L .19751 .39101 L F
.85887 .39361 m .86066 .39094 L .86188 .39273 L 0 .026 .125 r
F
.85887 .39361 m .85765 .39182 L .86066 .39094 L F
.30323 .39521 m .30419 .39269 L .30594 .39433 L 0 .03 .13 r
F
.30323 .39521 m .30148 .39357 L .30419 .39269 L F
.92076 .39264 m .92262 .38986 L .92379 .39164 L 0 .024 .122 r
F
.92076 .39264 m .9196 .39087 L .92262 .38986 L F
.73511 .39563 m .73672 .39299 L .73804 .39462 L 0 .031 .131 r
F
.73511 .39563 m .73379 .39405 L .73672 .39299 L F
.56691 .4074 m .56828 .40541 L .56976 .40652 L 0 .062 .164 r
F
.56691 .4074 m .56542 .40625 L .56828 .40541 L F
.40696 .39924 m .40807 .39678 L .40972 .39851 L 0 .039 .141 r
F
.40696 .39924 m .40531 .39747 L .40807 .39678 L F
.20386 .39349 m .20469 .39075 L .20652 .39253 L 0 .026 .125 r
F
.20386 .39349 m .20202 .39172 L .20469 .39075 L F
.61288 .40251 m .61431 .3998 L .61575 .40127 L 0 .047 .149 r
F
.61288 .40251 m .61144 .40109 L .61431 .3998 L F
.74231 .39535 m .74393 .39267 L .74525 .39444 L 0 .03 .13 r
F
.74231 .39535 m .74098 .3936 L .74393 .39267 L F
.32915 .39635 m .33016 .39374 L .33187 .39557 L 0 .032 .133 r
F
.32915 .39635 m .32744 .39454 L .33016 .39374 L F
.4488 .40438 m .44998 .40189 L .45158 .40366 L 0 .052 .155 r
F
.4488 .40438 m .44719 .40258 L .44998 .40189 L F
.24416 .39381 m .24505 .39105 L .24685 .39284 L 0 .027 .126 r
F
.24416 .39381 m .24236 .39204 L .24505 .39105 L F
.36227 .39703 m .36333 .39449 L .36501 .39628 L 0 .034 .135 r
F
.36227 .39703 m .36059 .39528 L .36333 .39449 L F
.81859 .39369 m .82031 .39095 L .82157 .39273 L 0 .027 .126 r
F
.81859 .39369 m .81733 .3919 L .82031 .39095 L F
.3104 .3951 m .31138 .39256 L .31312 .39422 L 0 .03 .13 r
F
.3104 .3951 m .30866 .39345 L .31138 .39256 L F
.52377 .41011 m .52506 .40819 L .5266 .40924 L 0 .071 .172 r
F
.52377 .41011 m .52223 .40905 L .52506 .40819 L F
.8661 .39358 m .86789 .39084 L .8691 .39257 L 0 .026 .126 r
F
.8661 .39358 m .86489 .39185 L .86789 .39084 L F
.87329 .39319 m .8751 .39047 L .8763 .39216 L 0 .026 .125 r
F
.87329 .39319 m .8721 .39152 L .8751 .39047 L F
.50939 .41095 m .51066 .40933 L .51221 .41029 L 0 .074 .175 r
F
.50939 .41095 m .50783 .41 L .51066 .40933 L F
.42569 .40103 m .42682 .39881 L .42846 .40037 L 0 .045 .147 r
F
.42569 .40103 m .42405 .39945 L .42682 .39881 L F
.55972 .40822 m .56108 .40613 L .56257 .40719 L 0 .065 .167 r
F
.55972 .40822 m .55823 .40721 L .56108 .40613 L F
.21101 .39348 m .21185 .39081 L .21367 .39262 L 0 .027 .126 r
F
.21101 .39348 m .20919 .39167 L .21185 .39081 L F
.28445 .39429 m .28541 .39152 L .28716 .39334 L 0 .028 .128 r
F
.28445 .39429 m .2827 .39249 L .28541 .39152 L F
.33632 .39629 m .33734 .39373 L .33906 .39536 L 0 .033 .133 r
F
.33632 .39629 m .33461 .39465 L .33734 .39373 L F
.25133 .39371 m .25223 .39093 L .25401 .39278 L 0 .027 .126 r
F
.25133 .39371 m .24954 .39187 L .25223 .39093 L F
.8258 .39353 m .82753 .39078 L .82878 .39255 L F
.8258 .39353 m .82455 .39175 L .82753 .39078 L F
.8805 .39294 m .88233 .39031 L .88352 .39203 L 0 .026 .124 r
F
.8805 .39294 m .87931 .39124 L .88233 .39031 L F
.51658 .4107 m .51786 .40885 L .5194 .40992 L 0 .073 .174 r
F
.51658 .4107 m .51503 .40963 L .51786 .40885 L F
.53096 .40991 m .53227 .40828 L .53379 .4094 L 0 .071 .172 r
F
.53096 .40991 m .52943 .40876 L .53227 .40828 L F
.74953 .39536 m .75115 .39265 L .75248 .39446 L 0 .031 .131 r
F
.74953 .39536 m .7482 .39356 L .75115 .39265 L F
.39538 .39799 m .39648 .39571 L .39813 .39735 L 0 .037 .139 r
F
.39538 .39799 m .39372 .39636 L .39648 .39571 L F
.76392 .39463 m .76557 .39199 L .76687 .39366 L 0 .029 .129 r
F
.76392 .39463 m .76262 .39299 L .76557 .39199 L F
.31757 .39507 m .31856 .39247 L .32029 .39423 L 0 .03 .13 r
F
.31757 .39507 m .31584 .39334 L .31856 .39247 L F
.83301 .3933 m .83476 .39068 L .836 .39237 L 0 .026 .126 r
F
.83301 .3933 m .83177 .39162 L .83476 .39068 L F
.69484 .39613 m .69639 .39354 L .69775 .39518 L 0 .033 .133 r
F
.69484 .39613 m .69347 .3945 L .69639 .39354 L F
.75673 .39514 m .75836 .39226 L .75967 .39404 L 0 .03 .13 r
F
.75673 .39514 m .75542 .39336 L .75836 .39226 L F
.77112 .39437 m .77277 .39165 L .77407 .39335 L 0 .029 .128 r
F
.77112 .39437 m .76982 .39268 L .77277 .39165 L F
.3435 .3962 m .34451 .39383 L .34622 .39546 L 0 .033 .134 r
F
.3435 .3962 m .34179 .39457 L .34451 .39383 L F
.29162 .3942 m .29258 .39154 L .29432 .39338 L 0 .028 .128 r
F
.29162 .3942 m .28987 .39238 L .29258 .39154 L F
.41412 .39963 m .41524 .39739 L .41688 .39903 L 0 .042 .144 r
F
.41412 .39963 m .41248 .39795 L .41524 .39739 L F
.88773 .39286 m .88954 .39004 L .89074 .39183 L 0 .025 .124 r
F
.88773 .39286 m .88653 .39107 L .88954 .39004 L F
.36943 .39725 m .3705 .39475 L .37218 .39645 L 0 .035 .137 r
F
.36943 .39725 m .36775 .39553 L .3705 .39475 L F
.77832 .39407 m .77998 .39127 L .78127 .39303 L 0 .028 .128 r
F
.77832 .39407 m .77702 .39231 L .77998 .39127 L F
.45597 .40466 m .45717 .4022 L .45876 .4039 L 0 .054 .157 r
F
.45597 .40466 m .45437 .40291 L .45717 .4022 L F
.21816 .39349 m .21903 .39067 L .22084 .39249 L 0 .027 .126 r
F
.21816 .39349 m .21635 .39167 L .21903 .39067 L F
.60571 .40366 m .60712 .40085 L .60857 .40238 L 0 .051 .153 r
F
.60571 .40366 m .60426 .40211 L .60712 .40085 L F
.70204 .39589 m .7036 .39331 L .70496 .39495 L 0 .032 .133 r
F
.70204 .39589 m .70068 .39426 L .7036 .39331 L F
.84022 .39311 m .84199 .39052 L .84322 .39219 L 0 .026 .125 r
F
.84022 .39311 m .83899 .39145 L .84199 .39052 L F
.66608 .39792 m .66758 .3952 L .66898 .39688 L 0 .037 .138 r
F
.66608 .39792 m .66468 .3963 L .66758 .3952 L F
.25848 .39375 m .25939 .39103 L .26117 .39286 L 0 .028 .127 r
F
.25848 .39375 m .2567 .39191 L .25939 .39103 L F
.49783 .40973 m .49908 .40837 L .50064 .40952 L 0 .072 .173 r
F
.49783 .40973 m .49626 .40852 L .49908 .40837 L F
.78552 .39379 m .78719 .39093 L .78848 .39275 L 0 .027 .127 r
F
.78552 .39379 m .78423 .39198 L .78719 .39093 L F
.89494 .39261 m .89677 .38982 L .89795 .39162 L 0 .025 .124 r
F
.89494 .39261 m .89375 .39081 L .89677 .38982 L F
.59133 .40458 m .59273 .40214 L .59419 .40364 L 0 .054 .157 r
F
.59133 .40458 m .58986 .40313 L .59273 .40214 L F
.43286 .40119 m .43402 .39878 L .43564 .40038 L 0 .045 .148 r
F
.43286 .40119 m .43124 .39957 L .43402 .39878 L F
.68766 .39682 m .68919 .394 L .69056 .39566 L 0 .034 .135 r
F
.68766 .39682 m .68628 .39518 L .68919 .394 L F
.47472 .4062 m .47593 .40437 L .47751 .40589 L 0 .06 .163 r
F
.47472 .4062 m .47313 .40471 L .47593 .40437 L F
.48627 .408 m .4875 .40619 L .48908 .40767 L 0 .066 .167 r
F
.48627 .408 m .4847 .40654 L .4875 .40619 L F
.44441 .40303 m .44558 .40078 L .44719 .40258 L 0 .051 .153 r
F
.44441 .40303 m .44281 .40121 L .44558 .40078 L F
.70924 .39567 m .7108 .39286 L .71216 .39462 L 0 .032 .132 r
F
.70924 .39567 m .70788 .39391 L .7108 .39286 L F
.67328 .39769 m .67479 .39485 L .67618 .3967 L 0 .036 .138 r
F
.67328 .39769 m .67188 .39587 L .67479 .39485 L F
.59852 .40428 m .59993 .40178 L .60139 .40337 L 0 .054 .156 r
F
.59852 .40428 m .59706 .40271 L .59993 .40178 L F
.22533 .39331 m .2262 .39056 L .22801 .39235 L 0 .027 .126 r
F
.22533 .39331 m .22352 .3915 L .2262 .39056 L F
.55254 .40927 m .55388 .4073 L .55538 .40829 L 0 .069 .171 r
F
.55254 .40927 m .55104 .40833 L .55388 .4073 L F
.53815 .4101 m .53947 .40839 L .54099 .40959 L 0 .073 .173 r
F
.53815 .4101 m .53663 .4089 L .53947 .40839 L F
.84744 .39296 m .84921 .39027 L .85043 .39197 L 0 .026 .125 r
F
.84744 .39296 m .84621 .39128 L .84921 .39027 L F
.62293 .40055 m .62438 .39808 L .62581 .39961 L 0 .044 .146 r
F
.62293 .40055 m .6215 .39902 L .62438 .39808 L F
.58414 .40514 m .58553 .40284 L .587 .40413 L 0 .056 .159 r
F
.58414 .40514 m .58267 .40391 L .58553 .40284 L F
.63732 .39977 m .63878 .39708 L .6402 .39873 L 0 .041 .144 r
F
.63732 .39977 m .63589 .39812 L .63878 .39708 L F
.79273 .39359 m .79442 .39086 L .7957 .39266 L 0 .027 .127 r
F
.79273 .39359 m .79144 .39178 L .79442 .39086 L F
.90216 .39242 m .904 .38966 L .90518 .39144 L 0 .025 .124 r
F
.90216 .39242 m .90097 .39064 L .904 .38966 L F
.71644 .39542 m .71802 .39273 L .71937 .39451 L 0 .031 .132 r
F
.71644 .39542 m .71509 .39365 L .71802 .39273 L F
.64451 .39942 m .64599 .39675 L .6474 .39846 L 0 .041 .143 r
F
.64451 .39942 m .64309 .39774 L .64599 .39675 L F
.26565 .39364 m .26658 .39085 L .26836 .3926 L 0 .028 .127 r
F
.26565 .39364 m .26387 .39188 L .26658 .39085 L F
.68048 .39744 m .68199 .39452 L .68338 .39632 L 0 .036 .137 r
F
.68048 .39744 m .67909 .39561 L .68199 .39452 L F
.6589 .39864 m .66039 .39591 L .66179 .39747 L 0 .039 .141 r
F
.6589 .39864 m .6575 .39712 L .66039 .39591 L F
.65171 .39904 m .6532 .3966 L .6546 .39812 L 0 .04 .142 r
F
.65171 .39904 m .6503 .39753 L .6532 .3966 L F
.63013 .40025 m .63158 .3976 L .63301 .39919 L 0 .043 .145 r
F
.63013 .40025 m .6287 .39865 L .63158 .3976 L F
.32472 .39527 m .32572 .39273 L .32744 .39454 L 0 .031 .132 r
F
.32472 .39527 m .323 .39348 L .32572 .39273 L F
.27284 .39329 m .27376 .39073 L .27553 .39246 L 0 .027 .127 r
F
.27284 .39329 m .27106 .39158 L .27376 .39073 L F
.37661 .39728 m .37768 .39481 L .37936 .39642 L 0 .036 .137 r
F
.37661 .39728 m .37493 .39565 L .37768 .39481 L F
.40255 .39828 m .40366 .39574 L .40531 .39747 L 0 .038 .14 r
F
.40255 .39828 m .4009 .39655 L .40366 .39574 L F
.80713 .39293 m .80884 .39026 L .8101 .39195 L 0 .026 .125 r
F
.80713 .39293 m .80587 .39126 L .80884 .39026 L F
.23251 .39315 m .23338 .39043 L .23519 .39219 L 0 .027 .126 r
F
.23251 .39315 m .23069 .39139 L .23338 .39043 L F
.90937 .39216 m .91123 .38946 L .91239 .39117 L 0 .025 .123 r
F
.90937 .39216 m .9082 .39045 L .91123 .38946 L F
.35066 .39635 m .3517 .39371 L .3534 .39539 L 0 .034 .135 r
F
.35066 .39635 m .34896 .3947 L .3517 .39371 L F
.85465 .39276 m .85643 .39003 L .85765 .39182 L 0 .026 .125 r
F
.85465 .39276 m .85343 .39098 L .85643 .39003 L F
.29877 .39438 m .29974 .39177 L .30148 .39357 L 0 .03 .13 r
F
.29877 .39438 m .29703 .39258 L .29974 .39177 L F
.79994 .39338 m .80164 .39065 L .8029 .39232 L 0 .027 .127 r
F
.79994 .39338 m .79867 .39172 L .80164 .39065 L F
.46315 .40483 m .46436 .4025 L .46595 .40406 L 0 .056 .158 r
F
.46315 .40483 m .46156 .4032 L .46436 .4025 L F
.91657 .39188 m .91844 .38913 L .9196 .39087 L 0 .024 .123 r
F
.91657 .39188 m .91541 .39016 L .91844 .38913 L F
.61575 .40127 m .61718 .3985 L .61862 .40002 L 0 .046 .148 r
F
.61575 .40127 m .61431 .3998 L .61718 .3985 L F
.38379 .39709 m .38488 .39453 L .38655 .39615 L 0 .036 .137 r
F
.38379 .39709 m .38212 .39548 L .38488 .39453 L F
.72365 .3953 m .72524 .39267 L .72658 .39437 L 0 .032 .132 r
F
.72365 .3953 m .72231 .39359 L .72524 .39267 L F
.35784 .39614 m .35889 .39352 L .36059 .39528 L 0 .034 .135 r
F
.35784 .39614 m .35615 .39442 L .35889 .39352 L F
.57695 .40593 m .57833 .4037 L .57981 .40493 L 0 .059 .162 r
F
.57695 .40593 m .57547 .40467 L .57833 .4037 L F
.19935 .39276 m .20018 .38996 L .20202 .39172 L 0 .026 .125 r
F
.19935 .39276 m .19751 .39101 L .20018 .38996 L F
.81434 .39278 m .81607 .39016 L .81733 .3919 L 0 .026 .126 r
F
.81434 .39278 m .81308 .39105 L .81607 .39016 L F
.23968 .39299 m .24056 .39026 L .24236 .39204 L 0 .027 .126 r
F
.23968 .39299 m .23787 .39123 L .24056 .39026 L F
.73804 .39462 m .73966 .39193 L .74098 .3936 L 0 .03 .13 r
F
.73804 .39462 m .73672 .39299 L .73966 .39193 L F
.73085 .39502 m .73246 .39246 L .73379 .39405 L 0 .031 .132 r
F
.73085 .39502 m .72952 .39345 L .73246 .39246 L F
.42128 .40005 m .42242 .39786 L .42405 .39945 L 0 .044 .146 r
F
.42128 .40005 m .41965 .39844 L .42242 .39786 L F
.54535 .41025 m .54668 .40815 L .54819 .40936 L 0 .073 .174 r
F
.54535 .41025 m .54384 .40907 L .54668 .40815 L F
.86188 .39273 m .86368 .39005 L .86489 .39185 L 0 .026 .125 r
F
.86188 .39273 m .86066 .39094 L .86368 .39005 L F
.20652 .39253 m .20736 .38987 L .20919 .39167 L F
.20652 .39253 m .20469 .39075 L .20736 .38987 L F
.30594 .39433 m .30691 .39181 L .30866 .39345 L 0 .03 .13 r
F
.30594 .39433 m .30419 .39269 L .30691 .39181 L F
.56976 .40652 m .57114 .40456 L .57262 .40563 L 0 .062 .164 r
F
.56976 .40652 m .56828 .40541 L .57114 .40456 L F
.27999 .39337 m .28093 .39073 L .2827 .39249 L 0 .028 .127 r
F
.27999 .39337 m .27823 .39163 L .28093 .39073 L F
.39097 .397 m .39206 .39472 L .39372 .39636 L 0 .037 .138 r
F
.39097 .397 m .3893 .39538 L .39206 .39472 L F
.24685 .39284 m .24775 .39005 L .24954 .39187 L 0 .027 .126 r
F
.24685 .39284 m .24505 .39105 L .24775 .39005 L F
.74525 .39444 m .74688 .39177 L .7482 .39356 L 0 .03 .13 r
F
.74525 .39444 m .74393 .39267 L .74688 .39177 L F
.44003 .40164 m .44119 .39938 L .44281 .40121 L 0 .048 .151 r
F
.44003 .40164 m .43842 .39979 L .44119 .39938 L F
.40972 .39851 m .41083 .39627 L .41248 .39795 L 0 .04 .142 r
F
.40972 .39851 m .40807 .39678 L .41083 .39627 L F
.82157 .39273 m .82329 .38998 L .82455 .39175 L 0 .027 .126 r
F
.82157 .39273 m .82031 .39095 L .82329 .38998 L F
.8763 .39216 m .87811 .38953 L .87931 .39124 L 0 .026 .124 r
F
.8763 .39216 m .8751 .39047 L .87811 .38953 L F
.8691 .39257 m .87089 .38978 L .8721 .39152 L 0 .026 .125 r
F
.8691 .39257 m .86789 .39084 L .87089 .38978 L F
.50501 .41034 m .50628 .40908 L .50783 .41 L 0 .076 .176 r
F
.50501 .41034 m .50346 .40936 L .50628 .40908 L F
.33187 .39557 m .3329 .3928 L .33461 .39465 L 0 .033 .133 r
F
.33187 .39557 m .33016 .39374 L .3329 .3928 L F
.56257 .40719 m .56393 .40519 L .56542 .40625 L 0 .064 .166 r
F
.56257 .40719 m .56108 .40613 L .56393 .40519 L F
.31312 .39422 m .3141 .39164 L .31584 .39334 L 0 .03 .13 r
F
.31312 .39422 m .31138 .39256 L .3141 .39164 L F
.47034 .40503 m .47154 .40321 L .47313 .40471 L 0 .059 .161 r
F
.47034 .40503 m .46875 .40357 L .47154 .40321 L F
.5266 .40924 m .5279 .40774 L .52943 .40876 L 0 .072 .173 r
F
.5266 .40924 m .52506 .40819 L .5279 .40774 L F
.45158 .40366 m .45277 .40118 L .45437 .40291 L 0 .053 .156 r
F
.45158 .40366 m .44998 .40189 L .45277 .40118 L F
.36501 .39628 m .36607 .39371 L .36775 .39553 L 0 .035 .136 r
F
.36501 .39628 m .36333 .39449 L .36607 .39371 L F
.28716 .39334 m .28812 .39055 L .28987 .39238 L 0 .028 .128 r
F
.28716 .39334 m .28541 .39152 L .28812 .39055 L F
.82878 .39255 m .83052 .38984 L .83177 .39162 L 0 .026 .126 r
F
.82878 .39255 m .82753 .39078 L .83052 .38984 L F
.33906 .39536 m .34007 .39294 L .34179 .39457 L 0 .033 .134 r
F
.33906 .39536 m .33734 .39373 L .34007 .39294 L F
.25401 .39278 m .25492 .39006 L .2567 .39191 L 0 .027 .126 r
F
.25401 .39278 m .25223 .39093 L .25492 .39006 L F
.48189 .40695 m .48312 .40498 L .4847 .40654 L 0 .064 .166 r
F
.48189 .40695 m .48032 .40544 L .48312 .40498 L F
.60857 .40238 m .60999 .39957 L .61144 .40109 L 0 .049 .152 r
F
.60857 .40238 m .60712 .40085 L .60999 .39957 L F
.21367 .39262 m .21452 .38984 L .21635 .39167 L 0 .027 .126 r
F
.21367 .39262 m .21185 .39081 L .21452 .38984 L F
.88352 .39203 m .88534 .38933 L .88653 .39107 L 0 .026 .124 r
F
.88352 .39203 m .88233 .39031 L .88534 .38933 L F
.75967 .39404 m .7613 .39121 L .76262 .39299 L 0 .029 .129 r
F
.75967 .39404 m .75836 .39226 L .7613 .39121 L F
.76687 .39366 m .76852 .39099 L .76982 .39268 L F
.76687 .39366 m .76557 .39199 L .76852 .39099 L F
.49345 .40883 m .4947 .40706 L .49626 .40852 L 0 .07 .172 r
F
.49345 .40883 m .49188 .40737 L .4947 .40706 L F
.75248 .39446 m .75409 .39156 L .75542 .39336 L 0 .03 .13 r
F
.75248 .39446 m .75115 .39265 L .75409 .39156 L F
.51221 .41029 m .51348 .40866 L .51503 .40963 L 0 .075 .176 r
F
.51221 .41029 m .51066 .40933 L .51348 .40866 L F
.77407 .39335 m .77573 .3906 L .77702 .39231 L 0 .028 .128 r
F
.77407 .39335 m .77277 .39165 L .77573 .3906 L F
.5194 .40992 m .52069 .40799 L .52223 .40905 L 0 .074 .174 r
F
.5194 .40992 m .51786 .40885 L .52069 .40799 L F
.836 .39237 m .83776 .38975 L .83899 .39145 L 0 .027 .126 r
F
.836 .39237 m .83476 .39068 L .83776 .38975 L F
.69775 .39518 m .69931 .39262 L .70068 .39426 L 0 .033 .133 r
F
.69775 .39518 m .69639 .39354 L .69931 .39262 L F
.42846 .40037 m .4296 .39803 L .43124 .39957 L 0 .045 .148 r
F
.42846 .40037 m .42682 .39881 L .4296 .39803 L F
.89074 .39183 m .89256 .38901 L .89375 .39081 L 0 .025 .124 r
F
.89074 .39183 m .88954 .39004 L .89256 .38901 L F
.32029 .39423 m .32128 .39169 L .323 .39348 L 0 .031 .131 r
F
.32029 .39423 m .31856 .39247 L .32128 .39169 L F
.78127 .39303 m .78293 .3902 L .78423 .39198 L 0 .028 .127 r
F
.78127 .39303 m .77998 .39127 L .78293 .3902 L F
.69056 .39566 m .6921 .39282 L .69347 .3945 L 0 .033 .134 r
F
.69056 .39566 m .68919 .394 L .6921 .39282 L F
.66898 .39688 m .67048 .39414 L .67188 .39587 L 0 .036 .138 r
F
.66898 .39688 m .66758 .3952 L .67048 .39414 L F
.22084 .39249 m .22171 .38969 L .22352 .3915 L 0 .027 .126 r
F
.22084 .39249 m .21903 .39067 L .22171 .38969 L F
.78848 .39275 m .79015 .38997 L .79144 .39178 L 0 .027 .127 r
F
.78848 .39275 m .78719 .39093 L .79015 .38997 L F
.70496 .39495 m .70652 .39226 L .70788 .39391 L 0 .032 .133 r
F
.70496 .39495 m .7036 .39331 L .70652 .39226 L F
.39813 .39735 m .39924 .39487 L .4009 .39655 L 0 .038 .14 r
F
.39813 .39735 m .39648 .39571 L .39924 .39487 L F
.29432 .39338 m .29528 .39074 L .29703 .39258 L 0 .029 .129 r
F
.29432 .39338 m .29258 .39154 L .29528 .39074 L F
.84322 .39219 m .84499 .3896 L .84621 .39128 L 0 .026 .126 r
F
.84322 .39219 m .84199 .39052 L .84499 .3896 L F
.89795 .39162 m .89979 .38883 L .90097 .39064 L 0 .025 .124 r
F
.89795 .39162 m .89677 .38982 L .89979 .38883 L F
.71216 .39462 m .71373 .39188 L .71509 .39365 L 0 .031 .132 r
F
.71216 .39462 m .7108 .39286 L .71373 .39188 L F
.53379 .4094 m .53511 .4078 L .53663 .4089 L 0 .073 .174 r
F
.53379 .4094 m .53227 .40828 L .53511 .4078 L F
.37218 .39645 m .37325 .39395 L .37493 .39565 L 0 .036 .137 r
F
.37218 .39645 m .3705 .39475 L .37325 .39395 L F
.59419 .40364 m .5956 .40117 L .59706 .40271 L 0 .054 .157 r
F
.59419 .40364 m .59273 .40214 L .5956 .40117 L F
.26117 .39286 m .26209 .39006 L .26387 .39188 L 0 .028 .127 r
F
.26117 .39286 m .25939 .39103 L .26209 .39006 L F
.34622 .39546 m .34725 .39306 L .34896 .3947 L 0 .034 .135 r
F
.34622 .39546 m .34451 .39383 L .34725 .39306 L F
.66179 .39747 m .66329 .3947 L .66468 .3963 L 0 .038 .14 r
F
.66179 .39747 m .66039 .39591 L .66329 .3947 L F
.67618 .3967 m .67769 .39379 L .67909 .39561 L 0 .036 .137 r
F
.67618 .3967 m .67479 .39485 L .67769 .39379 L F
.55538 .40829 m .55673 .40618 L .55823 .40721 L 0 .069 .17 r
F
.55538 .40829 m .55388 .4073 L .55673 .40618 L F
.45876 .4039 m .45996 .40157 L .46156 .4032 L 0 .055 .158 r
F
.45876 .4039 m .45717 .4022 L .45996 .40157 L F
.68338 .39632 m .6849 .3934 L .68628 .39518 L 0 .035 .136 r
F
.68338 .39632 m .68199 .39452 L .6849 .3934 L F
.6402 .39873 m .64167 .39606 L .64309 .39774 L 0 .041 .143 r
F
.6402 .39873 m .63878 .39708 L .64167 .39606 L F
.22801 .39235 m .22888 .38961 L .23069 .39139 L 0 .027 .126 r
F
.22801 .39235 m .2262 .39056 L .22888 .38961 L F
.587 .40413 m .58839 .40176 L .58986 .40313 L 0 .056 .158 r
F
.587 .40413 m .58553 .40284 L .58839 .40176 L F
.85043 .39197 m .8522 .38926 L .85343 .39098 L 0 .026 .125 r
F
.85043 .39197 m .84921 .39027 L .8522 .38926 L F
.60139 .40337 m .6028 .40054 L .60426 .40211 L 0 .053 .155 r
F
.60139 .40337 m .59993 .40178 L .6028 .40054 L F
.43564 .40038 m .4368 .39819 L .43842 .39979 L 0 .046 .149 r
F
.43564 .40038 m .43402 .39878 L .4368 .39819 L F
.63301 .39919 m .63447 .39654 L .63589 .39812 L 0 .042 .145 r
F
.63301 .39919 m .63158 .3976 L .63447 .39654 L F
.26836 .3926 m .26929 .38982 L .27106 .39158 L 0 .027 .127 r
F
.26836 .3926 m .26658 .39085 L .26929 .38982 L F
.62581 .39961 m .62727 .39712 L .6287 .39865 L 0 .044 .146 r
F
.62581 .39961 m .62438 .39808 L .62727 .39712 L F
.61862 .40002 m .62006 .39748 L .6215 .39902 L 0 .045 .147 r
F
.61862 .40002 m .61718 .3985 L .62006 .39748 L F
.90518 .39144 m .90702 .38868 L .9082 .39045 L 0 .025 .124 r
F
.90518 .39144 m .904 .38966 L .90702 .38868 L F
.41688 .39903 m .41801 .39683 L .41965 .39844 L 0 .043 .145 r
F
.41688 .39903 m .41524 .39739 L .41801 .39683 L F
.7957 .39266 m .79739 .38993 L .79867 .39172 L 0 .027 .127 r
F
.7957 .39266 m .79442 .39086 L .79739 .38993 L F
.6474 .39846 m .64888 .39582 L .6503 .39753 L 0 .041 .143 r
F
.6474 .39846 m .64599 .39675 L .64888 .39582 L F
.71937 .39451 m .72096 .39181 L .72231 .39359 L 0 .032 .132 r
F
.71937 .39451 m .71802 .39273 L .72096 .39181 L F
.8029 .39232 m .8046 .38958 L .80587 .39126 L 0 .027 .126 r
F
.8029 .39232 m .80164 .39065 L .8046 .38958 L F
.6546 .39812 m .6561 .39557 L .6575 .39712 L 0 .04 .142 r
F
.6546 .39812 m .6532 .3966 L .6561 .39557 L F
.8101 .39195 m .81182 .38935 L .81308 .39105 L 0 .026 .125 r
F
.8101 .39195 m .80884 .39026 L .81182 .38935 L F
.91239 .39117 m .91425 .38844 L .91541 .39016 L 0 .025 .123 r
F
.91239 .39117 m .91123 .38946 L .91425 .38844 L F
.23519 .39219 m .23607 .38947 L .23787 .39123 L 0 .027 .126 r
F
.23519 .39219 m .23338 .39043 L .23607 .38947 L F
.3534 .39539 m .35445 .39272 L .35615 .39442 L 0 .034 .135 r
F
.3534 .39539 m .3517 .39371 L .35445 .39272 L F
.85765 .39182 m .85944 .38914 L .86066 .39094 L 0 .026 .125 r
F
.85765 .39182 m .85643 .39003 L .85944 .38914 L F
.37936 .39642 m .38044 .39386 L .38212 .39548 L 0 .036 .138 r
F
.37936 .39642 m .37768 .39481 L .38044 .39386 L F
.27553 .39246 m .27646 .38988 L .27823 .39163 L 0 .028 .127 r
F
.27553 .39246 m .27376 .39073 L .27646 .38988 L F
.9196 .39087 m .92147 .3881 L .92262 .38986 L 0 .024 .122 r
F
.9196 .39087 m .91844 .38913 L .92147 .3881 L F
.19483 .39207 m .19566 .38927 L .19751 .39101 L 0 .026 .125 r
F
.19483 .39207 m .19298 .39031 L .19566 .38927 L F
.40531 .39747 m .40643 .39504 L .40807 .39678 L 0 .039 .141 r
F
.40531 .39747 m .40366 .39574 L .40643 .39504 L F
.20202 .39172 m .20286 .38896 L .20469 .39075 L 0 .026 .125 r
F
.20202 .39172 m .20018 .38996 L .20286 .38896 L F
.32744 .39454 m .32845 .3919 L .33016 .39374 L 0 .032 .133 r
F
.32744 .39454 m .32572 .39273 L .32845 .3919 L F
.38655 .39615 m .38763 .39376 L .3893 .39538 L 0 .036 .137 r
F
.38655 .39615 m .38488 .39453 L .38763 .39376 L F
.57981 .40493 m .5812 .40269 L .58267 .40391 L 0 .059 .161 r
F
.57981 .40493 m .57833 .4037 L .5812 .40269 L F
.30148 .39357 m .30245 .39089 L .30419 .39269 L 0 .03 .13 r
F
.30148 .39357 m .29974 .39177 L .30245 .39089 L F
.72658 .39437 m .72818 .39176 L .72952 .39345 L 0 .032 .132 r
F
.72658 .39437 m .72524 .39267 L .72818 .39176 L F
.44719 .40258 m .44837 .40013 L .44998 .40189 L 0 .052 .155 r
F
.44719 .40258 m .44558 .40078 L .44837 .40013 L F
.74098 .3936 m .7426 .39097 L .74393 .39267 L 0 .03 .13 r
F
.74098 .3936 m .73966 .39193 L .7426 .39097 L F
.54099 .40959 m .54232 .40788 L .54384 .40907 L 0 .075 .175 r
F
.54099 .40959 m .53947 .40839 L .54232 .40788 L F
.24236 .39204 m .24326 .38925 L .24505 .39105 L 0 .027 .126 r
F
.24236 .39204 m .24056 .39026 L .24326 .38925 L F
.73379 .39405 m .73539 .39136 L .73672 .39299 L 0 .031 .131 r
F
.73379 .39405 m .73246 .39246 L .73539 .39136 L F
.46595 .40406 m .46715 .40207 L .46875 .40357 L 0 .057 .16 r
F
.46595 .40406 m .46436 .4025 L .46715 .40207 L F
.36059 .39528 m .36164 .3927 L .36333 .39449 L 0 .034 .135 r
F
.36059 .39528 m .35889 .39352 L .36164 .3927 L F
.81733 .3919 m .81906 .38921 L .82031 .39095 L 0 .027 .126 r
F
.81733 .3919 m .81607 .39016 L .81906 .38921 L F
.48908 .40767 m .49031 .4059 L .49188 .40737 L 0 .069 .17 r
F
.48908 .40767 m .4875 .40619 L .49031 .4059 L F
.47751 .40589 m .47873 .40386 L .48032 .40544 L 0 .063 .165 r
F
.47751 .40589 m .47593 .40437 L .47873 .40386 L F
.50064 .40952 m .50189 .40827 L .50346 .40936 L 0 .076 .176 r
F
.50064 .40952 m .49908 .40837 L .50189 .40827 L F
.54819 .40936 m .54953 .4071 L .55104 .40833 L 0 .073 .174 r
F
.54819 .40936 m .54668 .40815 L .54953 .4071 L F
.86489 .39185 m .86668 .38904 L .86789 .39084 L 0 .026 .125 r
F
.86489 .39185 m .86368 .39005 L .86668 .38904 L F
.57262 .40563 m .574 .40364 L .57547 .40467 L 0 .062 .164 r
F
.57262 .40563 m .57114 .40456 L .574 .40364 L F
.30866 .39345 m .30963 .39089 L .31138 .39256 L 0 .03 .13 r
F
.30866 .39345 m .30691 .39181 L .30963 .39089 L F
.24954 .39187 m .25044 .3891 L .25223 .39093 L 0 .027 .126 r
F
.24954 .39187 m .24775 .39005 L .25044 .3891 L F
.20919 .39167 m .21002 .38899 L .21185 .39081 L 0 .026 .125 r
F
.20919 .39167 m .20736 .38987 L .21002 .38899 L F
.2827 .39249 m .28365 .38974 L .28541 .39152 L 0 .028 .127 r
F
.2827 .39249 m .28093 .39073 L .28365 .38974 L F
.61144 .40109 m .61286 .39828 L .61431 .3998 L 0 .048 .15 r
F
.61144 .40109 m .60999 .39957 L .61286 .39828 L F
.8721 .39152 m .8739 .38873 L .8751 .39047 L 0 .026 .125 r
F
.8721 .39152 m .87089 .38978 L .8739 .38873 L F
.82455 .39175 m .82628 .38901 L .82753 .39078 L 0 .026 .126 r
F
.82455 .39175 m .82329 .38998 L .82628 .38901 L F
.7482 .39356 m .74983 .39085 L .75115 .39265 L 0 .03 .13 r
F
.7482 .39356 m .74688 .39177 L .74983 .39085 L F
.87931 .39124 m .88113 .38858 L .88233 .39031 L 0 .026 .124 r
F
.87931 .39124 m .87811 .38953 L .88113 .38858 L F
.42405 .39945 m .42519 .39725 L .42682 .39881 L 0 .045 .148 r
F
.42405 .39945 m .42242 .39786 L .42519 .39725 L F
.33461 .39465 m .33563 .39186 L .33734 .39373 L 0 .033 .133 r
F
.33461 .39465 m .3329 .3928 L .33563 .39186 L F
.56542 .40625 m .56679 .40439 L .56828 .40541 L 0 .065 .167 r
F
.56542 .40625 m .56393 .40519 L .56679 .40439 L F
.31584 .39334 m .31683 .39073 L .31856 .39247 L 0 .03 .13 r
F
.31584 .39334 m .3141 .39164 L .31683 .39073 L F
.39372 .39636 m .39481 .39406 L .39648 .39571 L 0 .038 .139 r
F
.39372 .39636 m .39206 .39472 L .39481 .39406 L F
.75542 .39336 m .75704 .39046 L .75836 .39226 L 0 .03 .13 r
F
.75542 .39336 m .75409 .39156 L .75704 .39046 L F
.28987 .39238 m .29083 .38971 L .29258 .39154 L 0 .028 .128 r
F
.28987 .39238 m .28812 .39055 L .29083 .38971 L F
.76262 .39299 m .76426 .39019 L .76557 .39199 L 0 .029 .129 r
F
.76262 .39299 m .7613 .39121 L .76426 .39019 L F
.83177 .39162 m .83352 .3889 L .83476 .39068 L 0 .026 .126 r
F
.83177 .39162 m .83052 .38984 L .83352 .3889 L F
.21635 .39167 m .21721 .38885 L .21903 .39067 L F
.21635 .39167 m .21452 .38984 L .21721 .38885 L F
.88653 .39107 m .88835 .38829 L .88954 .39004 L 0 .025 .124 r
F
.88653 .39107 m .88534 .38933 L .88835 .38829 L F
.76982 .39268 m .77148 .38994 L .77277 .39165 L 0 .029 .129 r
F
.76982 .39268 m .76852 .39099 L .77148 .38994 L F
.69347 .3945 m .69502 .39186 L .69639 .39354 L 0 .033 .134 r
F
.69347 .3945 m .6921 .39282 L .69502 .39186 L F
.2567 .39191 m .25761 .3892 L .25939 .39103 L 0 .027 .127 r
F
.2567 .39191 m .25492 .39006 L .25761 .3892 L F
.77702 .39231 m .77869 .38955 L .77998 .39127 L 0 .028 .128 r
F
.77702 .39231 m .77573 .3906 L .77869 .38955 L F
.45437 .40291 m .45556 .40051 L .45717 .4022 L 0 .054 .157 r
F
.45437 .40291 m .45277 .40118 L .45556 .40051 L F
.36775 .39553 m .36882 .3929 L .3705 .39475 L 0 .035 .137 r
F
.36775 .39553 m .36607 .39371 L .36882 .3929 L F
.41248 .39795 m .4136 .39575 L .41524 .39739 L 0 .042 .144 r
F
.41248 .39795 m .41083 .39627 L .4136 .39575 L F
.34179 .39457 m .3428 .39219 L .34451 .39383 L 0 .034 .135 r
F
.34179 .39457 m .34007 .39294 L .3428 .39219 L F
.78423 .39198 m .78589 .38914 L .78719 .39093 L 0 .027 .127 r
F
.78423 .39198 m .78293 .3902 L .78589 .38914 L F
.89375 .39081 m .89558 .38802 L .89677 .38982 L 0 .025 .124 r
F
.89375 .39081 m .89256 .38901 L .89558 .38802 L F
.44281 .40121 m .44397 .39897 L .44558 .40078 L 0 .05 .153 r
F
.44281 .40121 m .44119 .39938 L .44397 .39897 L F
.83899 .39145 m .84076 .38882 L .84199 .39052 L 0 .027 .126 r
F
.83899 .39145 m .83776 .38975 L .84076 .38882 L F
.70068 .39426 m .70224 .39167 L .7036 .39331 L 0 .033 .133 r
F
.70068 .39426 m .69931 .39262 L .70224 .39167 L F
.67188 .39587 m .67339 .39308 L .67479 .39485 L 0 .036 .137 r
F
.67188 .39587 m .67048 .39414 L .67339 .39308 L F
.52223 .40905 m .52353 .40713 L .52506 .40819 L 0 .074 .175 r
F
.52223 .40905 m .52069 .40799 L .52353 .40713 L F
.22352 .3915 m .22439 .38876 L .2262 .39056 L 0 .027 .126 r
F
.22352 .3915 m .22171 .38969 L .22439 .38876 L F
.66468 .3963 m .66618 .39356 L .66758 .3952 L 0 .037 .139 r
F
.66468 .3963 m .66329 .3947 L .66618 .39356 L F
.70788 .39391 m .70945 .39121 L .7108 .39286 L 0 .032 .132 r
F
.70788 .39391 m .70652 .39226 L .70945 .39121 L F
.60426 .40211 m .60567 .3993 L .60712 .40085 L 0 .052 .154 r
F
.60426 .40211 m .6028 .40054 L .60567 .3993 L F
.79144 .39178 m .79313 .38905 L .79442 .39086 L 0 .027 .127 r
F
.79144 .39178 m .79015 .38997 L .79313 .38905 L F
.68628 .39518 m .68781 .39224 L .68919 .394 L 0 .034 .135 r
F
.68628 .39518 m .6849 .3934 L .68781 .39224 L F
.52943 .40876 m .53074 .4073 L .53227 .40828 L 0 .074 .175 r
F
.52943 .40876 m .5279 .40774 L .53074 .4073 L F
.43124 .39957 m .43239 .39726 L .43402 .39878 L 0 .046 .148 r
F
.43124 .39957 m .4296 .39803 L .43239 .39726 L F
.67909 .39561 m .6806 .39272 L .68199 .39452 L 0 .035 .137 r
F
.67909 .39561 m .67769 .39379 L .6806 .39272 L F
.50783 .41 m .5091 .4084 L .51066 .40933 L 0 .078 .178 r
F
.50783 .41 m .50628 .40908 L .5091 .4084 L F
.55823 .40721 m .55958 .40505 L .56108 .40613 L 0 .068 .169 r
F
.55823 .40721 m .55673 .40618 L .55958 .40505 L F
.90097 .39064 m .90281 .38785 L .904 .38966 L 0 .025 .123 r
F
.90097 .39064 m .89979 .38883 L .90281 .38785 L F
.51503 .40963 m .51632 .40789 L .51786 .40885 L 0 .077 .177 r
F
.51503 .40963 m .51348 .40866 L .51632 .40789 L F
.71509 .39365 m .71666 .39095 L .71802 .39273 L 0 .031 .132 r
F
.71509 .39365 m .71373 .39188 L .71666 .39095 L F
.84621 .39128 m .84798 .38857 L .84921 .39027 L 0 .026 .125 r
F
.84621 .39128 m .84499 .3896 L .84798 .38857 L F
.323 .39348 m .324 .39092 L .32572 .39273 L 0 .031 .132 r
F
.323 .39348 m .32128 .39169 L .324 .39092 L F
.26387 .39188 m .2648 .38904 L .26658 .39085 L 0 .027 .127 r
F
.26387 .39188 m .26209 .39006 L .2648 .38904 L F
.47313 .40471 m .47434 .40284 L .47593 .40437 L 0 .061 .163 r
F
.47313 .40471 m .47154 .40321 L .47434 .40284 L F
.63589 .39812 m .63736 .39548 L .63878 .39708 L 0 .042 .144 r
F
.63589 .39812 m .63447 .39654 L .63736 .39548 L F
.59706 .40271 m .59847 .40019 L .59993 .40178 L 0 .054 .157 r
F
.59706 .40271 m .5956 .40117 L .59847 .40019 L F
.58986 .40313 m .59126 .4007 L .59273 .40214 L 0 .056 .158 r
F
.58986 .40313 m .58839 .40176 L .59126 .4007 L F
.64309 .39774 m .64457 .39504 L .64599 .39675 L 0 .041 .143 r
F
.64309 .39774 m .64167 .39606 L .64457 .39504 L F
.4009 .39655 m .40201 .39403 L .40366 .39574 L 0 .038 .14 r
F
.4009 .39655 m .39924 .39487 L .40201 .39403 L F
.4847 .40654 m .48593 .40461 L .4875 .40619 L 0 .067 .168 r
F
.4847 .40654 m .48312 .40498 L .48593 .40461 L F
.27106 .39158 m .27198 .38897 L .27376 .39073 L 0 .027 .127 r
F
.27106 .39158 m .26929 .38982 L .27198 .38897 L F
.85343 .39098 m .85521 .38828 L .85643 .39003 L 0 .026 .125 r
F
.85343 .39098 m .8522 .38926 L .85521 .38828 L F
.29703 .39258 m .29799 .38992 L .29974 .39177 L 0 .029 .129 r
F
.29703 .39258 m .29528 .39074 L .29799 .38992 L F
.23069 .39139 m .23157 .38866 L .23338 .39043 L 0 .027 .126 r
F
.23069 .39139 m .22888 .38961 L .23157 .38866 L F
.6215 .39902 m .62294 .39654 L .62438 .39808 L 0 .045 .147 r
F
.6215 .39902 m .62006 .39748 L .62294 .39654 L F
.9082 .39045 m .91005 .38769 L .91123 .38946 L 0 .025 .123 r
F
.9082 .39045 m .90702 .38868 L .91005 .38769 L F
.37493 .39565 m .376 .39312 L .37768 .39481 L 0 .036 .138 r
F
.37493 .39565 m .37325 .39395 L .376 .39312 L F
.6287 .39865 m .63015 .39607 L .63158 .3976 L 0 .044 .146 r
F
.6287 .39865 m .62727 .39712 L .63015 .39607 L F
.80587 .39126 m .80758 .38857 L .80884 .39026 L 0 .027 .126 r
F
.80587 .39126 m .8046 .38958 L .80758 .38857 L F
.34896 .3947 m .35 .39204 L .3517 .39371 L 0 .034 .135 r
F
.34896 .3947 m .34725 .39306 L .35 .39204 L F
.79867 .39172 m .80036 .38888 L .80164 .39065 L 0 .027 .127 r
F
.79867 .39172 m .79739 .38993 L .80036 .38888 L F
.6575 .39712 m .65899 .39433 L .66039 .39591 L 0 .039 .141 r
F
.6575 .39712 m .6561 .39557 L .65899 .39433 L F
.6503 .39753 m .65179 .39489 L .6532 .3966 L 0 .041 .143 r
F
.6503 .39753 m .64888 .39582 L .65179 .39489 L F
.49626 .40852 m .49751 .40691 L .49908 .40837 L 0 .074 .175 r
F
.49626 .40852 m .4947 .40706 L .49751 .40691 L F
.91541 .39016 m .91728 .38739 L .91844 .38913 L 0 .024 .123 r
F
.91541 .39016 m .91425 .38844 L .91728 .38739 L F
.72231 .39359 m .7239 .3909 L .72524 .39267 L 0 .032 .132 r
F
.72231 .39359 m .72096 .39181 L .7239 .3909 L F
.19751 .39101 m .19834 .38823 L .20018 .38996 L 0 .026 .125 r
F
.19751 .39101 m .19566 .38927 L .19834 .38823 L F
.46156 .4032 m .46276 .40093 L .46436 .4025 L 0 .056 .159 r
F
.46156 .4032 m .45996 .40157 L .46276 .40093 L F
.35615 .39442 m .3572 .39179 L .35889 .39352 L 0 .034 .135 r
F
.35615 .39442 m .35445 .39272 L .3572 .39179 L F
.23787 .39123 m .23876 .3885 L .24056 .39026 L 0 .027 .126 r
F
.23787 .39123 m .23607 .38947 L .23876 .3885 L F
.81308 .39105 m .81481 .38844 L .81607 .39016 L 0 .026 .126 r
F
.81308 .39105 m .81182 .38935 L .81481 .38844 L F
.38212 .39548 m .3832 .39292 L .38488 .39453 L 0 .036 .138 r
F
.38212 .39548 m .38044 .39386 L .3832 .39292 L F
.53663 .4089 m .53795 .4073 L .53947 .40839 L 0 .075 .176 r
F
.53663 .4089 m .53511 .4078 L .53795 .4073 L F
.58267 .40391 m .58406 .40154 L .58553 .40284 L 0 .059 .161 r
F
.58267 .40391 m .5812 .40269 L .58406 .40154 L F
.86066 .39094 m .86245 .38824 L .86368 .39005 L 0 .026 .125 r
F
.86066 .39094 m .85944 .38914 L .86245 .38824 L F
.20469 .39075 m .20552 .38807 L .20736 .38987 L F
.20469 .39075 m .20286 .38896 L .20552 .38807 L F
.73672 .39299 m .73833 .39027 L .73966 .39193 L 0 .031 .131 r
F
.73672 .39299 m .73539 .39136 L .73833 .39027 L F
.43842 .39979 m .43957 .39778 L .44119 .39938 L 0 .048 .151 r
F
.43842 .39979 m .4368 .39819 L .43957 .39778 L F
.61431 .3998 m .61573 .39698 L .61718 .3985 L 0 .046 .149 r
F
.61431 .3998 m .61286 .39828 L .61573 .39698 L F
.27823 .39163 m .27916 .38896 L .28093 .39073 L 0 .028 .127 r
F
.27823 .39163 m .27646 .38988 L .27916 .38896 L F
.24505 .39105 m .24596 .38824 L .24775 .39005 L 0 .026 .125 r
F
.24505 .39105 m .24326 .38925 L .24596 .38824 L F
.72952 .39345 m .73112 .39077 L .73246 .39246 L 0 .032 .132 r
F
.72952 .39345 m .72818 .39176 L .73112 .39077 L F
.41965 .39844 m .42078 .39627 L .42242 .39786 L 0 .044 .147 r
F
.41965 .39844 m .41801 .39683 L .42078 .39627 L F
.74393 .39267 m .74555 .39003 L .74688 .39177 L 0 .03 .13 r
F
.74393 .39267 m .7426 .39097 L .74555 .39003 L F
.30419 .39269 m .30517 .39002 L .30691 .39181 L F
.30419 .39269 m .30245 .39089 L .30517 .39002 L F
.33016 .39374 m .33118 .39095 L .3329 .3928 L 0 .032 .133 r
F
.33016 .39374 m .32845 .3919 L .33118 .39095 L F
.82031 .39095 m .82204 .38824 L .82329 .38998 L 0 .026 .126 r
F
.82031 .39095 m .81906 .38921 L .82204 .38824 L F
.55104 .40833 m .55238 .40603 L .55388 .4073 L 0 .072 .173 r
F
.55104 .40833 m .54953 .4071 L .55238 .40603 L F
.3893 .39538 m .39039 .39309 L .39206 .39472 L 0 .037 .138 r
F
.3893 .39538 m .38763 .39376 L .39039 .39309 L F
.40807 .39678 m .40919 .39453 L .41083 .39627 L 0 .04 .142 r
F
.40807 .39678 m .40643 .39504 L .40919 .39453 L F
.86789 .39084 m .86968 .38799 L .87089 .38978 L 0 .026 .125 r
F
.86789 .39084 m .86668 .38904 L .86968 .38799 L F
.8751 .39047 m .87691 .38777 L .87811 .38953 L 0 .026 .124 r
F
.8751 .39047 m .8739 .38873 L .87691 .38777 L F
.57547 .40467 m .57686 .40271 L .57833 .4037 L 0 .062 .164 r
F
.57547 .40467 m .574 .40364 L .57686 .40271 L F
.36333 .39449 m .36439 .39188 L .36607 .39371 L 0 .034 .136 r
F
.36333 .39449 m .36164 .3927 L .36439 .39188 L F
.44998 .40189 m .45116 .39946 L .45277 .40118 L 0 .053 .156 r
F
.44998 .40189 m .44837 .40013 L .45116 .39946 L F
.28541 .39152 m .28636 .38875 L .28812 .39055 L 0 .028 .127 r
F
.28541 .39152 m .28365 .38974 L .28636 .38875 L F
.25223 .39093 m .25313 .38823 L .25492 .39006 L 0 .027 .126 r
F
.25223 .39093 m .25044 .3891 L .25313 .38823 L F
.31138 .39256 m .31236 .38994 L .3141 .39164 L 0 .03 .13 r
F
.31138 .39256 m .30963 .39089 L .31236 .38994 L F
.82753 .39078 m .82928 .38806 L .83052 .38984 L 0 .026 .125 r
F
.82753 .39078 m .82628 .38901 L .82928 .38806 L F
.21185 .39081 m .2127 .38801 L .21452 .38984 L F
.21185 .39081 m .21002 .38899 L .2127 .38801 L F
.75115 .39265 m .75277 .38975 L .75409 .39156 L 0 .03 .13 r
F
.75115 .39265 m .74983 .39085 L .75277 .38975 L F
.75836 .39226 m .75999 .3894 L .7613 .39121 L 0 .029 .129 r
F
.75836 .39226 m .75704 .39046 L .75999 .3894 L F
.54384 .40907 m .54517 .40694 L .54668 .40815 L 0 .076 .176 r
F
.54384 .40907 m .54232 .40788 L .54517 .40694 L F
.88233 .39031 m .88415 .38759 L .88534 .38933 L 0 .026 .124 r
F
.88233 .39031 m .88113 .38858 L .88415 .38759 L F
.33734 .39373 m .33836 .39106 L .34007 .39294 L 0 .033 .134 r
F
.33734 .39373 m .33563 .39186 L .33836 .39106 L F
.46875 .40357 m .46995 .40177 L .47154 .40321 L 0 .06 .162 r
F
.46875 .40357 m .46715 .40207 L .46995 .40177 L F
.76557 .39199 m .76721 .38918 L .76852 .39099 L 0 .029 .129 r
F
.76557 .39199 m .76426 .39019 L .76721 .38918 L F
.56828 .40541 m .56965 .40359 L .57114 .40456 L 0 .065 .167 r
F
.56828 .40541 m .56679 .40439 L .56965 .40359 L F
.88954 .39004 m .89137 .38725 L .89256 .38901 L 0 .025 .124 r
F
.88954 .39004 m .88835 .38829 L .89137 .38725 L F
.77277 .39165 m .77443 .38889 L .77573 .3906 L 0 .028 .128 r
F
.77277 .39165 m .77148 .38994 L .77443 .38889 L F
.48032 .40544 m .48154 .40336 L .48312 .40498 L 0 .065 .167 r
F
.48032 .40544 m .47873 .40386 L .48154 .40336 L F
.60712 .40085 m .60854 .39804 L .60999 .39957 L 0 .05 .153 r
F
.60712 .40085 m .60567 .3993 L .60854 .39804 L F
.77998 .39127 m .78164 .38846 L .78293 .3902 L 0 .028 .127 r
F
.77998 .39127 m .77869 .38955 L .78164 .38846 L F
.31856 .39247 m .31955 .38994 L .32128 .39169 L 0 .031 .131 r
F
.31856 .39247 m .31683 .39073 L .31955 .38994 L F
.21903 .39067 m .21989 .38786 L .22171 .38969 L 0 .026 .125 r
F
.21903 .39067 m .21721 .38885 L .21989 .38786 L F
.83476 .39068 m .83652 .38797 L .83776 .38975 L 0 .027 .126 r
F
.83476 .39068 m .83352 .3889 L .83652 .38797 L F
.78719 .39093 m .78887 .38817 L .79015 .38997 L F
.78719 .39093 m .78589 .38914 L .78887 .38817 L F
.29258 .39154 m .29353 .3889 L .29528 .39074 L 0 .028 .128 r
F
.29258 .39154 m .29083 .38971 L .29353 .3889 L F
.69639 .39354 m .69795 .39094 L .69931 .39262 L 0 .033 .134 r
F
.69639 .39354 m .69502 .39186 L .69795 .39094 L F
.49188 .40737 m .49313 .40561 L .4947 .40706 L 0 .072 .173 r
F
.49188 .40737 m .49031 .4059 L .49313 .40561 L F
.68919 .394 m .69072 .39107 L .6921 .39282 L 0 .033 .134 r
F
.68919 .394 m .68781 .39224 L .69072 .39107 L F
.66758 .3952 m .66909 .39245 L .67048 .39414 L 0 .037 .138 r
F
.66758 .3952 m .66618 .39356 L .66909 .39245 L F
.89677 .38982 m .8986 .38703 L .89979 .38883 L 0 .025 .123 r
F
.89677 .38982 m .89558 .38802 L .8986 .38703 L F
.42682 .39881 m .42797 .39649 L .4296 .39803 L 0 .046 .149 r
F
.42682 .39881 m .42519 .39725 L .42797 .39649 L F
.25939 .39103 m .26031 .38824 L .26209 .39006 L 0 .027 .127 r
F
.25939 .39103 m .25761 .3892 L .26031 .38824 L F
.67479 .39485 m .6763 .39203 L .67769 .39379 L 0 .036 .137 r
F
.67479 .39485 m .67339 .39308 L .6763 .39203 L F
.7108 .39286 m .71238 .39021 L .71373 .39188 L 0 .031 .132 r
F
.7108 .39286 m .70945 .39121 L .71238 .39021 L F
.39648 .39571 m .39758 .39318 L .39924 .39487 L 0 .038 .14 r
F
.39648 .39571 m .39481 .39406 L .39758 .39318 L F
.7036 .39331 m .70516 .39062 L .70652 .39226 L 0 .032 .133 r
F
.7036 .39331 m .70224 .39167 L .70516 .39062 L F
.84199 .39052 m .84376 .38789 L .84499 .3896 L 0 .027 .126 r
F
.84199 .39052 m .84076 .38882 L .84376 .38789 L F
.68199 .39452 m .68351 .39162 L .6849 .3934 L 0 .035 .136 r
F
.68199 .39452 m .6806 .39272 L .68351 .39162 L F
.56108 .40613 m .56244 .40411 L .56393 .40519 L 0 .068 .169 r
F
.56108 .40613 m .55958 .40505 L .56244 .40411 L F
.3705 .39475 m .37157 .39208 L .37325 .39395 L 0 .036 .137 r
F
.3705 .39475 m .36882 .3929 L .37157 .39208 L F
.2262 .39056 m .22707 .38782 L .22888 .38961 L 0 .027 .126 r
F
.2262 .39056 m .22439 .38876 L .22707 .38782 L F
.50346 .40936 m .50472 .40804 L .50628 .40908 L 0 .079 .179 r
F
.50346 .40936 m .50189 .40827 L .50472 .40804 L F
.52506 .40819 m .52637 .40672 L .5279 .40774 L 0 .075 .176 r
F
.52506 .40819 m .52353 .40713 L .52637 .40672 L F
.45717 .4022 m .45836 .39994 L .45996 .40157 L 0 .056 .158 r
F
.45717 .4022 m .45556 .40051 L .45836 .39994 L F
.34451 .39383 m .34554 .39141 L .34725 .39306 L 0 .034 .135 r
F
.34451 .39383 m .3428 .39219 L .34554 .39141 L F
.26658 .39085 m .26751 .38803 L .26929 .38982 L 0 .027 .126 r
F
.26658 .39085 m .2648 .38904 L .26751 .38803 L F
.904 .38966 m .90584 .38688 L .90702 .38868 L 0 .025 .123 r
F
.904 .38966 m .90281 .38785 L .90584 .38688 L F
.79442 .39086 m .79611 .38813 L .79739 .38993 L 0 .027 .127 r
F
.79442 .39086 m .79313 .38905 L .79611 .38813 L F
.84921 .39027 m .85098 .38753 L .8522 .38926 L 0 .026 .125 r
F
.84921 .39027 m .84798 .38857 L .85098 .38753 L F
.63878 .39708 m .64025 .39441 L .64167 .39606 L 0 .042 .144 r
F
.63878 .39708 m .63736 .39548 L .64025 .39441 L F
.66039 .39591 m .66189 .39309 L .66329 .3947 L 0 .038 .14 r
F
.66039 .39591 m .65899 .39433 L .66189 .39309 L F
.71802 .39273 m .7196 .39002 L .72096 .39181 L 0 .031 .132 r
F
.71802 .39273 m .71666 .39095 L .7196 .39002 L F
.59273 .40214 m .59413 .39966 L .5956 .40117 L 0 .055 .158 r
F
.59273 .40214 m .59126 .4007 L .59413 .39966 L F
.64599 .39675 m .64747 .39411 L .64888 .39582 L 0 .041 .143 r
F
.64599 .39675 m .64457 .39504 L .64747 .39411 L F
.43402 .39878 m .43517 .39667 L .4368 .39819 L 0 .047 .149 r
F
.43402 .39878 m .43239 .39726 L .43517 .39667 L F
.59993 .40178 m .60134 .39896 L .6028 .40054 L 0 .054 .156 r
F
.59993 .40178 m .59847 .40019 L .60134 .39896 L F
.41524 .39739 m .41636 .39521 L .41801 .39683 L 0 .043 .146 r
F
.41524 .39739 m .4136 .39575 L .41636 .39521 L F
.63158 .3976 m .63304 .39503 L .63447 .39654 L 0 .043 .145 r
F
.63158 .3976 m .63015 .39607 L .63304 .39503 L F
.85643 .39003 m .85822 .38737 L .85944 .38914 L 0 .026 .125 r
F
.85643 .39003 m .85521 .38828 L .85822 .38737 L F
.23338 .39043 m .23425 .38771 L .23607 .38947 L 0 .027 .126 r
F
.23338 .39043 m .23157 .38866 L .23425 .38771 L F
.80164 .39065 m .80333 .38782 L .8046 .38958 L F
.80164 .39065 m .80036 .38888 L .80333 .38782 L F
.80884 .39026 m .81056 .38765 L .81182 .38935 L F
.80884 .39026 m .80758 .38857 L .81056 .38765 L F
.91123 .38946 m .91308 .38667 L .91425 .38844 L 0 .025 .123 r
F
.91123 .38946 m .91005 .38769 L .91308 .38667 L F
.51786 .40885 m .51915 .40704 L .52069 .40799 L 0 .077 .177 r
F
.51786 .40885 m .51632 .40789 L .51915 .40704 L F
.62438 .39808 m .62583 .39558 L .62727 .39712 L 0 .045 .147 r
F
.62438 .39808 m .62294 .39654 L .62583 .39558 L F
.61718 .3985 m .61862 .39597 L .62006 .39748 L 0 .046 .148 r
F
.61718 .3985 m .61573 .39698 L .61862 .39597 L F
.19298 .39031 m .19381 .38752 L .19566 .38927 L 0 .026 .125 r
F
.19298 .39031 m .19113 .38854 L .19381 .38752 L F
.3517 .39371 m .35275 .39102 L .35445 .39272 L 0 .034 .135 r
F
.3517 .39371 m .35 .39204 L .35275 .39102 L F
.32572 .39273 m .32673 .39008 L .32845 .3919 L 0 .032 .132 r
F
.32572 .39273 m .324 .39092 L .32673 .39008 L F
.91844 .38913 m .9203 .38634 L .92147 .3881 L 0 .024 .122 r
F
.91844 .38913 m .91728 .38739 L .9203 .38634 L F
.27376 .39073 m .27468 .38813 L .27646 .38988 L 0 .028 .127 r
F
.27376 .39073 m .27198 .38897 L .27468 .38813 L F
.40366 .39574 m .40478 .39329 L .40643 .39504 L 0 .039 .141 r
F
.40366 .39574 m .40201 .39403 L .40478 .39329 L F
.51066 .40933 m .51193 .40772 L .51348 .40866 L 0 .079 .179 r
F
.51066 .40933 m .5091 .4084 L .51193 .40772 L F
.20018 .38996 m .20101 .38725 L .20286 .38896 L 0 .026 .125 r
F
.20018 .38996 m .19834 .38823 L .20101 .38725 L F
.29974 .39177 m .30071 .38906 L .30245 .39089 L 0 .03 .13 r
F
.29974 .39177 m .29799 .38992 L .30071 .38906 L F
.44558 .40078 m .44676 .39836 L .44837 .40013 L 0 .052 .154 r
F
.44558 .40078 m .44397 .39897 L .44676 .39836 L F
.6532 .3966 m .65469 .39387 L .6561 .39557 L 0 .041 .143 r
F
.6532 .3966 m .65179 .39489 L .65469 .39387 L F
.37768 .39481 m .37876 .39217 L .38044 .39386 L 0 .037 .138 r
F
.37768 .39481 m .376 .39312 L .37876 .39217 L F
.58553 .40284 m .58692 .40038 L .58839 .40176 L 0 .058 .16 r
F
.58553 .40284 m .58406 .40154 L .58692 .40038 L F
.24056 .39026 m .24145 .38748 L .24326 .38925 L 0 .026 .126 r
F
.24056 .39026 m .23876 .3885 L .24145 .38748 L F
.72524 .39267 m .72684 .39 L .72818 .39176 L 0 .032 .132 r
F
.72524 .39267 m .7239 .3909 L .72684 .39 L F
.53227 .40828 m .53358 .40684 L .53511 .4078 L 0 .077 .177 r
F
.53227 .40828 m .53074 .4073 L .53358 .40684 L F
.35889 .39352 m .35995 .39093 L .36164 .3927 L 0 .034 .135 r
F
.35889 .39352 m .3572 .39179 L .35995 .39093 L F
.73966 .39193 m .74127 .38926 L .7426 .39097 L 0 .03 .13 r
F
.73966 .39193 m .73833 .39027 L .74127 .38926 L F
.38488 .39453 m .38596 .39214 L .38763 .39376 L 0 .037 .138 r
F
.38488 .39453 m .3832 .39292 L .38596 .39214 L F
.81607 .39016 m .8178 .38749 L .81906 .38921 L 0 .027 .126 r
F
.81607 .39016 m .81481 .38844 L .8178 .38749 L F
.86368 .39005 m .86546 .38724 L .86668 .38904 L 0 .026 .125 r
F
.86368 .39005 m .86245 .38824 L .86546 .38724 L F
.24775 .39005 m .24865 .38726 L .25044 .3891 L F
.24775 .39005 m .24596 .38824 L .24865 .38726 L F
.73246 .39246 m .73406 .38966 L .73539 .39136 L 0 .031 .132 r
F
.73246 .39246 m .73112 .39077 L .73406 .38966 L F
.20736 .38987 m .20819 .38717 L .21002 .38899 L 0 .026 .125 r
F
.20736 .38987 m .20552 .38807 L .20819 .38717 L F
.46436 .4025 m .46555 .40057 L .46715 .40207 L 0 .058 .161 r
F
.46436 .4025 m .46276 .40093 L .46555 .40057 L F
.55388 .4073 m .55523 .40489 L .55673 .40618 L 0 .072 .173 r
F
.55388 .4073 m .55238 .40603 L .55523 .40489 L F
.28093 .39073 m .28188 .38796 L .28365 .38974 L 0 .028 .127 r
F
.28093 .39073 m .27916 .38896 L .28188 .38796 L F
.74688 .39177 m .7485 .38908 L .74983 .39085 L 0 .03 .13 r
F
.74688 .39177 m .74555 .39003 L .7485 .38908 L F
.82329 .38998 m .82503 .38727 L .82628 .38901 L 0 .026 .125 r
F
.82329 .38998 m .82204 .38824 L .82503 .38727 L F
.87089 .38978 m .87269 .38694 L .8739 .38873 L F
.87089 .38978 m .86968 .38799 L .87269 .38694 L F
.47593 .40437 m .47715 .40229 L .47873 .40386 L 0 .064 .166 r
F
.47593 .40437 m .47434 .40284 L .47715 .40229 L F
.4875 .40619 m .48874 .40433 L .49031 .4059 L 0 .07 .171 r
F
.4875 .40619 m .48593 .40461 L .48874 .40433 L F
.3329 .3928 m .33392 .38999 L .33563 .39186 L 0 .032 .133 r
F
.3329 .3928 m .33118 .39095 L .33392 .38999 L F
.30691 .39181 m .30789 .38911 L .30963 .39089 L 0 .03 .13 r
F
.30691 .39181 m .30517 .39002 L .30789 .38911 L F
.57833 .4037 m .57973 .40171 L .5812 .40269 L 0 .062 .164 r
F
.57833 .4037 m .57686 .40271 L .57973 .40171 L F
.87811 .38953 m .87993 .38682 L .88113 .38858 L 0 .026 .124 r
F
.87811 .38953 m .87691 .38777 L .87993 .38682 L F
.28812 .39055 m .28907 .38789 L .29083 .38971 L 0 .028 .127 r
F
.28812 .39055 m .28636 .38875 L .28907 .38789 L F
.75409 .39156 m .75572 .38866 L .75704 .39046 L 0 .03 .13 r
F
.75409 .39156 m .75277 .38975 L .75572 .38866 L F
.60999 .39957 m .61141 .39675 L .61286 .39828 L 0 .049 .151 r
F
.60999 .39957 m .60854 .39804 L .61141 .39675 L F
.53947 .40839 m .5408 .40681 L .54232 .40788 L 0 .078 .178 r
F
.53947 .40839 m .53795 .4073 L .5408 .40681 L F
.7613 .39121 m .76294 .38838 L .76426 .39019 L 0 .029 .129 r
F
.7613 .39121 m .75999 .3894 L .76294 .38838 L F
.21452 .38984 m .21538 .38701 L .21721 .38885 L 0 .026 .125 r
F
.21452 .38984 m .2127 .38801 L .21538 .38701 L F
.83052 .38984 m .83227 .38711 L .83352 .3889 L F
.83052 .38984 m .82928 .38806 L .83227 .38711 L F
.3141 .39164 m .31509 .38899 L .31683 .39073 L 0 .03 .13 r
F
.3141 .39164 m .31236 .38994 L .31509 .38899 L F
.25492 .39006 m .25583 .38736 L .25761 .3892 L 0 .027 .126 r
F
.25492 .39006 m .25313 .38823 L .25583 .38736 L F
.42242 .39786 m .42355 .39568 L .42519 .39725 L 0 .046 .148 r
F
.42242 .39786 m .42078 .39627 L .42355 .39568 L F
.36607 .39371 m .36714 .39104 L .36882 .3929 L 0 .035 .136 r
F
.36607 .39371 m .36439 .39188 L .36714 .39104 L F
.39206 .39472 m .39315 .39242 L .39481 .39406 L 0 .038 .14 r
F
.39206 .39472 m .39039 .39309 L .39315 .39242 L F
.88534 .38933 m .88716 .38654 L .88835 .38829 L 0 .025 .124 r
F
.88534 .38933 m .88415 .38759 L .88716 .38654 L F
.54668 .40815 m .54802 .40585 L .54953 .4071 L 0 .075 .176 r
F
.54668 .40815 m .54517 .40694 L .54802 .40585 L F
.45277 .40118 m .45396 .39884 L .45556 .40051 L 0 .054 .157 r
F
.45277 .40118 m .45116 .39946 L .45396 .39884 L F
.44119 .39938 m .44236 .39737 L .44397 .39897 L 0 .05 .153 r
F
.44119 .39938 m .43957 .39778 L .44236 .39737 L F
.49908 .40837 m .50033 .40679 L .50189 .40827 L 0 .078 .178 r
F
.49908 .40837 m .49751 .40691 L .50033 .40679 L F
.76852 .39099 m .77017 .38816 L .77148 .38994 L 0 .029 .128 r
F
.76852 .39099 m .76721 .38918 L .77017 .38816 L F
.78293 .3902 m .7846 .38738 L .78589 .38914 L 0 .027 .126 r
F
.78293 .3902 m .78164 .38846 L .7846 .38738 L F
.77573 .3906 m .77739 .38783 L .77869 .38955 L 0 .028 .128 r
F
.77573 .3906 m .77443 .38889 L .77739 .38783 L F
.89256 .38901 m .89439 .38624 L .89558 .38802 L 0 .025 .123 r
F
.89256 .38901 m .89137 .38725 L .89439 .38624 L F
.6921 .39282 m .69364 .39012 L .69502 .39186 L 0 .033 .134 r
F
.6921 .39282 m .69072 .39107 L .69364 .39012 L F
.41083 .39627 m .41195 .39401 L .4136 .39575 L 0 .042 .144 r
F
.41083 .39627 m .40919 .39453 L .41195 .39401 L F
.22171 .38969 m .22257 .38693 L .22439 .38876 L 0 .026 .125 r
F
.22171 .38969 m .21989 .38786 L .22257 .38693 L F
.34007 .39294 m .3411 .39031 L .3428 .39219 L 0 .033 .134 r
F
.34007 .39294 m .33836 .39106 L .3411 .39031 L F
.83776 .38975 m .83952 .38706 L .84076 .38882 L 0 .027 .126 r
F
.83776 .38975 m .83652 .38797 L .83952 .38706 L F
.67048 .39414 m .67199 .39134 L .67339 .39308 L 0 .036 .137 r
F
.67048 .39414 m .66909 .39245 L .67199 .39134 L F
.79015 .38997 m .79184 .38726 L .79313 .38905 L 0 .027 .126 r
F
.79015 .38997 m .78887 .38817 L .79184 .38726 L F
.57114 .40456 m .57252 .40272 L .574 .40364 L 0 .066 .167 r
F
.57114 .40456 m .56965 .40359 L .57252 .40272 L F
.67769 .39379 m .67921 .39097 L .6806 .39272 L 0 .035 .136 r
F
.67769 .39379 m .6763 .39203 L .67921 .39097 L F
.6849 .3934 m .68642 .39047 L .68781 .39224 L 0 .034 .135 r
F
.6849 .3934 m .68351 .39162 L .68642 .39047 L F
.69931 .39262 m .70087 .39 L .70224 .39167 L 0 .033 .134 r
F
.69931 .39262 m .69795 .39094 L .70087 .39 L F
.89979 .38883 m .90163 .38605 L .90281 .38785 L 0 .025 .123 r
F
.89979 .38883 m .8986 .38703 L .90163 .38605 L F
.26209 .39006 m .26302 .38723 L .2648 .38904 L 0 .027 .126 r
F
.26209 .39006 m .26031 .38824 L .26302 .38723 L F
.70652 .39226 m .70809 .38956 L .70945 .39121 L 0 .032 .133 r
F
.70652 .39226 m .70516 .39062 L .70809 .38956 L F
.71373 .39188 m .71531 .38924 L .71666 .39095 L 0 .031 .132 r
F
.71373 .39188 m .71238 .39021 L .71531 .38924 L F
.32128 .39169 m .32227 .38914 L .324 .39092 L 0 .031 .131 r
F
.32128 .39169 m .31955 .38994 L .32227 .38914 L F
.66329 .3947 m .66479 .39191 L .66618 .39356 L 0 .037 .139 r
F
.66329 .3947 m .66189 .39309 L .66479 .39191 L F
.29528 .39074 m .29625 .38807 L .29799 .38992 L 0 .029 .129 r
F
.29528 .39074 m .29353 .3889 L .29625 .38807 L F
.6028 .40054 m .60421 .39774 L .60567 .3993 L 0 .052 .155 r
F
.6028 .40054 m .60134 .39896 L .60421 .39774 L F
.84499 .3896 m .84676 .38685 L .84798 .38857 L 0 .026 .126 r
F
.84499 .3896 m .84376 .38789 L .84676 .38685 L F
.56393 .40519 m .5653 .40336 L .56679 .40439 L 0 .068 .169 r
F
.56393 .40519 m .56244 .40411 L .5653 .40336 L F
.22888 .38961 m .22975 .38689 L .23157 .38866 L 0 .027 .126 r
F
.22888 .38961 m .22707 .38782 L .22975 .38689 L F
.26929 .38982 m .27021 .3872 L .27198 .38897 L F
.26929 .38982 m .26751 .38803 L .27021 .3872 L F
.4296 .39803 m .43076 .39573 L .43239 .39726 L 0 .047 .149 r
F
.4296 .39803 m .42797 .39649 L .43076 .39573 L F
.8522 .38926 m .85398 .38653 L .85521 .38828 L 0 .026 .125 r
F
.8522 .38926 m .85098 .38753 L .85398 .38653 L F
.64167 .39606 m .64314 .39334 L .64457 .39504 L 0 .041 .143 r
F
.64167 .39606 m .64025 .39441 L .64314 .39334 L F
.39924 .39487 m .40035 .39231 L .40201 .39403 L 0 .039 .14 r
F
.39924 .39487 m .39758 .39318 L .40035 .39231 L F
.90702 .38868 m .90888 .38591 L .91005 .38769 L 0 .025 .123 r
F
.90702 .38868 m .90584 .38688 L .90888 .38591 L F
.79739 .38993 m .79908 .3871 L .80036 .38888 L 0 .027 .126 r
F
.79739 .38993 m .79611 .38813 L .79908 .3871 L F
.63447 .39654 m .63593 .39393 L .63736 .39548 L 0 .043 .145 r
F
.63447 .39654 m .63304 .39503 L .63593 .39393 L F
.37325 .39395 m .37433 .39123 L .376 .39312 L 0 .036 .138 r
F
.37325 .39395 m .37157 .39208 L .37433 .39123 L F
.5956 .40117 m .59701 .39861 L .59847 .40019 L 0 .055 .157 r
F
.5956 .40117 m .59413 .39966 L .59701 .39861 L F
.8046 .38958 m .80631 .38682 L .80758 .38857 L 0 .027 .126 r
F
.8046 .38958 m .80333 .38782 L .80631 .38682 L F
.48312 .40498 m .48435 .40296 L .48593 .40461 L 0 .067 .169 r
F
.48312 .40498 m .48154 .40336 L .48435 .40296 L F
.72096 .39181 m .72254 .38912 L .7239 .3909 L 0 .031 .132 r
F
.72096 .39181 m .7196 .39002 L .72254 .38912 L F
.47154 .40321 m .47275 .40146 L .47434 .40284 L 0 .063 .165 r
F
.47154 .40321 m .46995 .40177 L .47275 .40146 L F
.64888 .39582 m .65037 .39319 L .65179 .39489 L 0 .041 .143 r
F
.64888 .39582 m .64747 .39411 L .65037 .39319 L F
.91425 .38844 m .91611 .38563 L .91728 .38739 L 0 .024 .123 r
F
.91425 .38844 m .91308 .38667 L .91611 .38563 L F
.34725 .39306 m .34829 .39037 L .35 .39204 L 0 .034 .135 r
F
.34725 .39306 m .34554 .39141 L .34829 .39037 L F
.23607 .38947 m .23695 .38676 L .23876 .3885 L 0 .027 .126 r
F
.23607 .38947 m .23425 .38771 L .23695 .38676 L F
.19566 .38927 m .19648 .3865 L .19834 .38823 L 0 .026 .125 r
F
.19566 .38927 m .19381 .38752 L .19648 .3865 L F
.62006 .39748 m .62151 .39503 L .62294 .39654 L 0 .045 .148 r
F
.62006 .39748 m .61862 .39597 L .62151 .39503 L F
.35445 .39272 m .3555 .39007 L .3572 .39179 L 0 .034 .135 r
F
.35445 .39272 m .35275 .39102 L .3555 .39007 L F
.62727 .39712 m .62872 .39455 L .63015 .39607 L 0 .044 .147 r
F
.62727 .39712 m .62583 .39558 L .62872 .39455 L F
.85944 .38914 m .86123 .38646 L .86245 .38824 L 0 .026 .125 r
F
.85944 .38914 m .85822 .38737 L .86123 .38646 L F
.81182 .38935 m .81355 .38672 L .81481 .38844 L 0 .027 .126 r
F
.81182 .38935 m .81056 .38765 L .81355 .38672 L F
.20286 .38896 m .20368 .38635 L .20552 .38807 L 0 .026 .125 r
F
.20286 .38896 m .20101 .38725 L .20368 .38635 L F
.58839 .40176 m .58979 .39926 L .59126 .4007 L 0 .057 .159 r
F
.58839 .40176 m .58692 .40038 L .58979 .39926 L F
.6561 .39557 m .65758 .39264 L .65899 .39433 L 0 .04 .142 r
F
.6561 .39557 m .65469 .39387 L .65758 .39264 L F
.45996 .40157 m .46116 .39937 L .46276 .40093 L 0 .057 .159 r
F
.45996 .40157 m .45836 .39994 L .46116 .39937 L F
.52069 .40799 m .52199 .40619 L .52353 .40713 L 0 .078 .178 r
F
.52069 .40799 m .51915 .40704 L .52199 .40619 L F
.24326 .38925 m .24416 .38645 L .24596 .38824 L 0 .026 .125 r
F
.24326 .38925 m .24145 .38748 L .24416 .38645 L F
.38044 .39386 m .38153 .39122 L .3832 .39292 L 0 .037 .138 r
F
.38044 .39386 m .37876 .39217 L .38153 .39122 L F
.4947 .40706 m .49595 .40545 L .49751 .40691 L 0 .075 .176 r
F
.4947 .40706 m .49313 .40561 L .49595 .40545 L F
.27646 .38988 m .27739 .38721 L .27916 .38896 L 0 .028 .127 r
F
.27646 .38988 m .27468 .38813 L .27739 .38721 L F
.30245 .39089 m .30343 .38819 L .30517 .39002 L 0 .03 .13 r
F
.30245 .39089 m .30071 .38906 L .30343 .38819 L F
.32845 .3919 m .32947 .3891 L .33118 .39095 L 0 .032 .132 r
F
.32845 .3919 m .32673 .39008 L .32947 .3891 L F
.5279 .40774 m .52921 .40632 L .53074 .4073 L 0 .078 .178 r
F
.5279 .40774 m .52637 .40672 L .52921 .40632 L F
.72818 .39176 m .72978 .38902 L .73112 .39077 L 0 .032 .132 r
F
.72818 .39176 m .72684 .39 L .72978 .38902 L F
.73539 .39136 m .737 .38855 L .73833 .39027 L 0 .031 .131 r
F
.73539 .39136 m .73406 .38966 L .737 .38855 L F
.7426 .39097 m .74422 .38829 L .74555 .39003 L 0 .03 .13 r
F
.7426 .39097 m .74127 .38926 L .74422 .38829 L F
.55673 .40618 m .55808 .40374 L .55958 .40505 L 0 .071 .172 r
F
.55673 .40618 m .55523 .40489 L .55808 .40374 L F
.4368 .39819 m .43795 .39625 L .43957 .39778 L 0 .049 .151 r
F
.4368 .39819 m .43517 .39667 L .43795 .39625 L F
.81906 .38921 m .82079 .38652 L .82204 .38824 L 0 .026 .126 r
F
.81906 .38921 m .8178 .38749 L .82079 .38652 L F
.41801 .39683 m .41913 .39467 L .42078 .39627 L 0 .045 .147 r
F
.41801 .39683 m .41636 .39521 L .41913 .39467 L F
.86668 .38904 m .86847 .38619 L .86968 .38799 L 0 .026 .125 r
F
.86668 .38904 m .86546 .38724 L .86847 .38619 L F
.40643 .39504 m .40754 .39273 L .40919 .39453 L 0 .04 .142 r
F
.40643 .39504 m .40478 .39329 L .40754 .39273 L F
.51348 .40866 m .51477 .40694 L .51632 .40789 L 0 .08 .18 r
F
.51348 .40866 m .51193 .40772 L .51477 .40694 L F
.61286 .39828 m .61429 .39546 L .61573 .39698 L 0 .047 .15 r
F
.61286 .39828 m .61141 .39675 L .61429 .39546 L F
.50628 .40908 m .50755 .40735 L .5091 .4084 L 0 .082 .181 r
F
.50628 .40908 m .50472 .40804 L .50755 .40735 L F
.25044 .3891 m .25134 .38639 L .25313 .38823 L 0 .026 .125 r
F
.25044 .3891 m .24865 .38726 L .25134 .38639 L F
.36164 .3927 m .3627 .39007 L .36439 .39188 L 0 .034 .135 r
F
.36164 .3927 m .35995 .39093 L .3627 .39007 L F
.8739 .38873 m .87571 .38598 L .87691 .38777 L 0 .026 .124 r
F
.8739 .38873 m .87269 .38694 L .87571 .38598 L F
.44837 .40013 m .44956 .39773 L .45116 .39946 L 0 .053 .156 r
F
.44837 .40013 m .44676 .39836 L .44956 .39773 L F
.28365 .38974 m .2846 .38695 L .28636 .38875 L 0 .028 .127 r
F
.28365 .38974 m .28188 .38796 L .2846 .38695 L F
.38763 .39376 m .38872 .39146 L .39039 .39309 L 0 .037 .139 r
F
.38763 .39376 m .38596 .39214 L .38872 .39146 L F
.21002 .38899 m .21087 .38619 L .2127 .38801 L 0 .026 .125 r
F
.21002 .38899 m .20819 .38717 L .21087 .38619 L F
.82628 .38901 m .82803 .3863 L .82928 .38806 L F
.82628 .38901 m .82503 .38727 L .82803 .3863 L F
.74983 .39085 m .75145 .38797 L .75277 .38975 L 0 .03 .13 r
F
.74983 .39085 m .7485 .38908 L .75145 .38797 L F
.75704 .39046 m .75867 .38759 L .75999 .3894 L 0 .029 .129 r
F
.75704 .39046 m .75572 .38866 L .75867 .38759 L F
.33563 .39186 m .33666 .38918 L .33836 .39106 L 0 .032 .133 r
F
.33563 .39186 m .33392 .38999 L .33666 .38918 L F
.30963 .39089 m .31062 .38817 L .31236 .38994 L 0 .03 .13 r
F
.30963 .39089 m .30789 .38911 L .31062 .38817 L F
.5812 .40269 m .58259 .4005 L .58406 .40154 L 0 .061 .163 r
F
.5812 .40269 m .57973 .40171 L .58259 .4005 L F
.88113 .38858 m .88295 .38582 L .88415 .38759 L 0 .026 .124 r
F
.88113 .38858 m .87993 .38682 L .88295 .38582 L F
.76426 .39019 m .7659 .38735 L .76721 .38918 L 0 .029 .129 r
F
.76426 .39019 m .76294 .38838 L .7659 .38735 L F
.53511 .4078 m .53643 .40636 L .53795 .4073 L 0 .079 .179 r
F
.53511 .4078 m .53358 .40684 L .53643 .40636 L F
.21721 .38885 m .21807 .38602 L .21989 .38786 L 0 .026 .125 r
F
.21721 .38885 m .21538 .38701 L .21807 .38602 L F
.88835 .38829 m .89018 .38549 L .89137 .38725 L 0 .025 .124 r
F
.88835 .38829 m .88716 .38654 L .89018 .38549 L F
.83352 .3889 m .83527 .38619 L .83652 .38797 L 0 .026 .125 r
F
.83352 .3889 m .83227 .38711 L .83527 .38619 L F
.54953 .4071 m .55087 .40475 L .55238 .40603 L 0 .075 .175 r
F
.54953 .4071 m .54802 .40585 L .55087 .40475 L F
.29083 .38971 m .29178 .38706 L .29353 .3889 L 0 .028 .128 r
F
.29083 .38971 m .28907 .38789 L .29178 .38706 L F
.31683 .39073 m .31781 .38817 L .31955 .38994 L 0 .031 .131 r
F
.31683 .39073 m .31509 .38899 L .31781 .38817 L F
.78589 .38914 m .78758 .3864 L .78887 .38817 L 0 .027 .126 r
F
.78589 .38914 m .7846 .38738 L .78758 .3864 L F
.77148 .38994 m .77313 .38713 L .77443 .38889 L 0 .028 .128 r
F
.77148 .38994 m .77017 .38816 L .77313 .38713 L F
.77869 .38955 m .78035 .38672 L .78164 .38846 L 0 .028 .127 r
F
.77869 .38955 m .77739 .38783 L .78035 .38672 L F
.25761 .3892 m .25853 .3864 L .26031 .38824 L 0 .027 .126 r
F
.25761 .3892 m .25583 .38736 L .25853 .3864 L F
.89558 .38802 m .89741 .38523 L .8986 .38703 L 0 .025 .123 r
F
.89558 .38802 m .89439 .38624 L .89741 .38523 L F
.68781 .39224 m .68934 .38931 L .69072 .39107 L 0 .033 .134 r
F
.68781 .39224 m .68642 .39047 L .68934 .38931 L F
.69502 .39186 m .69657 .38921 L .69795 .39094 L F
.69502 .39186 m .69364 .39012 L .69657 .38921 L F
.47873 .40386 m .47996 .40173 L .48154 .40336 L 0 .065 .167 r
F
.47873 .40386 m .47715 .40229 L .47996 .40173 L F
.46715 .40207 m .46835 .40033 L .46995 .40177 L 0 .061 .163 r
F
.46715 .40207 m .46555 .40057 L .46835 .40033 L F
.67339 .39308 m .67491 .39028 L .6763 .39203 L 0 .036 .137 r
F
.67339 .39308 m .67199 .39134 L .67491 .39028 L F
.36882 .3929 m .36989 .3902 L .37157 .39208 L 0 .035 .137 r
F
.36882 .3929 m .36714 .39104 L .36989 .3902 L F
.60567 .3993 m .60709 .39649 L .60854 .39804 L 0 .051 .154 r
F
.60567 .3993 m .60421 .39774 L .60709 .39649 L F
.6806 .39272 m .68212 .38987 L .68351 .39162 L 0 .035 .136 r
F
.6806 .39272 m .67921 .39097 L .68212 .38987 L F
.22439 .38876 m .22525 .38601 L .22707 .38782 L 0 .026 .125 r
F
.22439 .38876 m .22257 .38693 L .22525 .38601 L F
.66618 .39356 m .66769 .39075 L .66909 .39245 L 0 .037 .138 r
F
.66618 .39356 m .66479 .39191 L .66769 .39075 L F
.70945 .39121 m .71102 .38853 L .71238 .39021 L 0 .032 .132 r
F
.70945 .39121 m .70809 .38956 L .71102 .38853 L F
.84076 .38882 m .84253 .38614 L .84376 .38789 L 0 .027 .126 r
F
.84076 .38882 m .83952 .38706 L .84253 .38614 L F
.2648 .38904 m .26573 .38623 L .26751 .38803 L F
.2648 .38904 m .26302 .38723 L .26573 .38623 L F
.574 .40364 m .57538 .40183 L .57686 .40271 L 0 .066 .167 r
F
.574 .40364 m .57252 .40272 L .57538 .40183 L F
.42519 .39725 m .42633 .39493 L .42797 .39649 L 0 .047 .149 r
F
.42519 .39725 m .42355 .39568 L .42633 .39493 L F
.79313 .38905 m .79482 .38634 L .79611 .38813 L 0 .027 .126 r
F
.79313 .38905 m .79184 .38726 L .79482 .38634 L F
.90281 .38785 m .90466 .38508 L .90584 .38688 L 0 .025 .123 r
F
.90281 .38785 m .90163 .38605 L .90466 .38508 L F
.39481 .39406 m .39592 .39152 L .39758 .39318 L 0 .039 .14 r
F
.39481 .39406 m .39315 .39242 L .39592 .39152 L F
.70224 .39167 m .7038 .38896 L .70516 .39062 L 0 .033 .133 r
F
.70224 .39167 m .70087 .39 L .7038 .38896 L F
.54232 .40788 m .54365 .40587 L .54517 .40694 L 0 .079 .179 r
F
.54232 .40788 m .5408 .40681 L .54365 .40587 L F
.49031 .4059 m .49156 .40405 L .49313 .40561 L 0 .073 .174 r
F
.49031 .4059 m .48874 .40433 L .49156 .40405 L F
.45556 .40051 m .45675 .39834 L .45836 .39994 L 0 .056 .158 r
F
.45556 .40051 m .45396 .39884 L .45675 .39834 L F
.71666 .39095 m .71825 .38826 L .7196 .39002 L 0 .031 .132 r
F
.71666 .39095 m .71531 .38924 L .71825 .38826 L F
.84798 .38857 m .84975 .3858 L .85098 .38753 L 0 .026 .125 r
F
.84798 .38857 m .84676 .38685 L .84975 .3858 L F
.3428 .39219 m .34383 .38953 L .34554 .39141 L 0 .034 .135 r
F
.3428 .39219 m .3411 .39031 L .34383 .38953 L F
.64457 .39504 m .64605 .39239 L .64747 .39411 L 0 .041 .143 r
F
.64457 .39504 m .64314 .39334 L .64605 .39239 L F
.23157 .38866 m .23244 .38596 L .23425 .38771 L 0 .027 .126 r
F
.23157 .38866 m .22975 .38689 L .23244 .38596 L F
.80036 .38888 m .80206 .38606 L .80333 .38782 L F
.80036 .38888 m .79908 .3871 L .80206 .38606 L F
.85521 .38828 m .85699 .3856 L .85822 .38737 L 0 .026 .125 r
F
.85521 .38828 m .85398 .38653 L .85699 .3856 L F
.63736 .39548 m .63882 .3928 L .64025 .39441 L 0 .042 .144 r
F
.63736 .39548 m .63593 .39393 L .63882 .3928 L F
.91005 .38769 m .91191 .3849 L .91308 .38667 L 0 .025 .123 r
F
.91005 .38769 m .90888 .38591 L .91191 .3849 L F
.29799 .38992 m .29896 .38721 L .30071 .38906 L 0 .029 .129 r
F
.29799 .38992 m .29625 .38807 L .29896 .38721 L F
.324 .39092 m .325 .38827 L .32673 .39008 L 0 .032 .132 r
F
.324 .39092 m .32227 .38914 L .325 .38827 L F
.65899 .39433 m .66048 .39141 L .66189 .39309 L 0 .039 .141 r
F
.65899 .39433 m .65758 .39264 L .66048 .39141 L F
.19113 .38854 m .19196 .38574 L .19381 .38752 L 0 .026 .125 r
F
.19113 .38854 m .18928 .38674 L .19196 .38574 L F
.4136 .39575 m .41472 .39347 L .41636 .39521 L 0 .044 .146 r
F
.4136 .39575 m .41195 .39401 L .41472 .39347 L F
.44397 .39897 m .44515 .39674 L .44676 .39836 L 0 .052 .155 r
F
.44397 .39897 m .44236 .39737 L .44515 .39674 L F
.80758 .38857 m .8093 .3859 L .81056 .38765 L 0 .027 .126 r
F
.80758 .38857 m .80631 .38682 L .8093 .3859 L F
.27198 .38897 m .27291 .38637 L .27468 .38813 L 0 .027 .127 r
F
.27198 .38897 m .27021 .3872 L .27291 .38637 L F
.59847 .40019 m .59988 .39739 L .60134 .39896 L 0 .054 .157 r
F
.59847 .40019 m .59701 .39861 L .59988 .39739 L F
.91728 .38739 m .91914 .38459 L .9203 .38634 L 0 .024 .122 r
F
.91728 .38739 m .91611 .38563 L .91914 .38459 L F
.56679 .40439 m .56817 .4026 L .56965 .40359 L 0 .069 .17 r
F
.56679 .40439 m .5653 .40336 L .56817 .4026 L F
.40201 .39403 m .40312 .39154 L .40478 .39329 L 0 .039 .141 r
F
.40201 .39403 m .40035 .39231 L .40312 .39154 L F
.19834 .38823 m .19916 .38553 L .20101 .38725 L 0 .026 .125 r
F
.19834 .38823 m .19648 .3865 L .19916 .38553 L F
.35 .39204 m .35104 .38932 L .35275 .39102 L 0 .034 .135 r
F
.35 .39204 m .34829 .39037 L .35104 .38932 L F
.43239 .39726 m .43354 .39515 L .43517 .39667 L 0 .048 .15 r
F
.43239 .39726 m .43076 .39573 L .43354 .39515 L F
.63015 .39607 m .63161 .39351 L .63304 .39503 L 0 .044 .146 r
F
.63015 .39607 m .62872 .39455 L .63161 .39351 L F
.65179 .39489 m .65327 .39217 L .65469 .39387 L 0 .041 .143 r
F
.65179 .39489 m .65037 .39319 L .65327 .39217 L F
.23876 .3885 m .23964 .38575 L .24145 .38748 L 0 .026 .126 r
F
.23876 .3885 m .23695 .38676 L .23964 .38575 L F
.59126 .4007 m .59266 .39815 L .59413 .39966 L 0 .056 .159 r
F
.59126 .4007 m .58979 .39926 L .59266 .39815 L F
.7239 .3909 m .72549 .38823 L .72684 .39 L 0 .032 .132 r
F
.7239 .3909 m .72254 .38912 L .72549 .38823 L F
.376 .39312 m .37709 .39028 L .37876 .39217 L 0 .036 .138 r
F
.376 .39312 m .37433 .39123 L .37709 .39028 L F
.62294 .39654 m .6244 .39409 L .62583 .39558 L 0 .045 .148 r
F
.62294 .39654 m .62151 .39503 L .6244 .39409 L F
.61573 .39698 m .61717 .39445 L .61862 .39597 L 0 .046 .149 r
F
.61573 .39698 m .61429 .39546 L .61717 .39445 L F
.3572 .39179 m .35825 .38917 L .35995 .39093 L 0 .034 .135 r
F
.3572 .39179 m .3555 .39007 L .35825 .38917 L F
.24596 .38824 m .24685 .38547 L .24865 .38726 L 0 .026 .125 r
F
.24596 .38824 m .24416 .38645 L .24685 .38547 L F
.81481 .38844 m .81654 .38576 L .8178 .38749 L 0 .027 .126 r
F
.81481 .38844 m .81355 .38672 L .81654 .38576 L F
.86245 .38824 m .86424 .38544 L .86546 .38724 L 0 .026 .125 r
F
.86245 .38824 m .86123 .38646 L .86424 .38544 L F
.55958 .40505 m .56094 .4028 L .56244 .40411 L 0 .07 .171 r
F
.55958 .40505 m .55808 .40374 L .56094 .4028 L F
.73833 .39027 m .73994 .38753 L .74127 .38926 L 0 .03 .131 r
F
.73833 .39027 m .737 .38855 L .73994 .38753 L F
.20552 .38807 m .20635 .38546 L .20819 .38717 L 0 .026 .125 r
F
.20552 .38807 m .20368 .38635 L .20635 .38546 L F
.50189 .40827 m .50316 .40655 L .50472 .40804 L 0 .082 .181 r
F
.50189 .40827 m .50033 .40679 L .50316 .40655 L F
.3832 .39292 m .38429 .39044 L .38596 .39214 L 0 .037 .138 r
F
.3832 .39292 m .38153 .39122 L .38429 .39044 L F
.52353 .40713 m .52483 .40583 L .52637 .40672 L 0 .079 .179 r
F
.52353 .40713 m .52199 .40619 L .52483 .40583 L F
.33118 .39095 m .33221 .38812 L .33392 .38999 L 0 .032 .132 r
F
.33118 .39095 m .32947 .3891 L .33221 .38812 L F
.27916 .38896 m .28011 .38621 L .28188 .38796 L 0 .028 .127 r
F
.27916 .38896 m .27739 .38721 L .28011 .38621 L F
.73112 .39077 m .73272 .38791 L .73406 .38966 L 0 .031 .132 r
F
.73112 .39077 m .72978 .38902 L .73272 .38791 L F
.86968 .38799 m .87147 .38515 L .87269 .38694 L 0 .026 .124 r
F
.86968 .38799 m .86847 .38619 L .87147 .38515 L F
.30517 .39002 m .30615 .38729 L .30789 .38911 L 0 .03 .13 r
F
.30517 .39002 m .30343 .38819 L .30615 .38729 L F
.74555 .39003 m .74717 .3873 L .7485 .38908 L F
.74555 .39003 m .74422 .38829 L .74717 .3873 L F
.82204 .38824 m .82378 .38555 L .82503 .38727 L 0 .026 .125 r
F
.82204 .38824 m .82079 .38652 L .82378 .38555 L F
.46276 .40093 m .46395 .39907 L .46555 .40057 L 0 .059 .161 r
F
.46276 .40093 m .46116 .39937 L .46395 .39907 L F
.58406 .40154 m .58546 .39928 L .58692 .40038 L 0 .06 .162 r
F
.58406 .40154 m .58259 .4005 L .58546 .39928 L F
.28636 .38875 m .28731 .38607 L .28907 .38789 L 0 .028 .127 r
F
.28636 .38875 m .2846 .38695 L .28731 .38607 L F
.75277 .38975 m .75439 .38687 L .75572 .38866 L 0 .029 .129 r
F
.75277 .38975 m .75145 .38797 L .75439 .38687 L F
.87691 .38777 m .87873 .38503 L .87993 .38682 L 0 .026 .124 r
F
.87691 .38777 m .87571 .38598 L .87873 .38503 L F
.75999 .3894 m .76162 .38655 L .76294 .38838 L 0 .029 .129 r
F
.75999 .3894 m .75867 .38759 L .76162 .38655 L F
.48593 .40461 m .48717 .40268 L .48874 .40433 L 0 .07 .171 r
F
.48593 .40461 m .48435 .40296 L .48717 .40268 L F
.2127 .38801 m .21356 .38519 L .21538 .38701 L 0 .026 .125 r
F
.2127 .38801 m .21087 .38619 L .21356 .38519 L F
.25313 .38823 m .25404 .38552 L .25583 .38736 L 0 .027 .126 r
F
.25313 .38823 m .25134 .38639 L .25404 .38552 L F
.47434 .40284 m .47556 .40093 L .47715 .40229 L 0 .065 .167 r
F
.47434 .40284 m .47275 .40146 L .47556 .40093 L F
.82928 .38806 m .83102 .38533 L .83227 .38711 L 0 .026 .125 r
F
.82928 .38806 m .82803 .3863 L .83102 .38533 L F
.36439 .39188 m .36545 .38921 L .36714 .39104 L 0 .035 .136 r
F
.36439 .39188 m .3627 .39007 L .36545 .38921 L F
.51632 .40789 m .5176 .40611 L .51915 .40704 L 0 .081 .181 r
F
.51632 .40789 m .51477 .40694 L .5176 .40611 L F
.31236 .38994 m .31335 .38723 L .31509 .38899 L 0 .03 .13 r
F
.31236 .38994 m .31062 .38817 L .31335 .38723 L F
.76721 .38918 m .76886 .38635 L .77017 .38816 L 0 .029 .128 r
F
.76721 .38918 m .7659 .38735 L .76886 .38635 L F
.88415 .38759 m .88597 .38478 L .88716 .38654 L 0 .025 .124 r
F
.88415 .38759 m .88295 .38582 L .88597 .38478 L F
.5091 .4084 m .51038 .40665 L .51193 .40772 L 0 .083 .182 r
F
.5091 .4084 m .50755 .40735 L .51038 .40665 L F
.55238 .40603 m .55372 .4036 L .55523 .40489 L 0 .074 .174 r
F
.55238 .40603 m .55087 .40475 L .55372 .4036 L F
.60854 .39804 m .60996 .3952 L .61141 .39675 L 0 .05 .152 r
F
.60854 .39804 m .60709 .39649 L .60996 .3952 L F
.89137 .38725 m .8932 .38446 L .89439 .38624 L 0 .025 .123 r
F
.89137 .38725 m .89018 .38549 L .8932 .38446 L F
.45116 .39946 m .45235 .39716 L .45396 .39884 L 0 .055 .157 r
F
.45116 .39946 m .44956 .39773 L .45235 .39716 L F
.21989 .38786 m .22075 .3851 L .22257 .38693 L 0 .026 .125 r
F
.21989 .38786 m .21807 .38602 L .22075 .3851 L F
.33836 .39106 m .33939 .38843 L .3411 .39031 L 0 .033 .134 r
F
.33836 .39106 m .33666 .38918 L .33939 .38843 L F
.78164 .38846 m .78331 .38561 L .7846 .38738 L 0 .027 .126 r
F
.78164 .38846 m .78035 .38672 L .78331 .38561 L F
.42078 .39627 m .42191 .3941 L .42355 .39568 L 0 .046 .149 r
F
.42078 .39627 m .41913 .39467 L .42191 .3941 L F
.69072 .39107 m .69226 .38838 L .69364 .39012 L 0 .033 .134 r
F
.69072 .39107 m .68934 .38931 L .69226 .38838 L F
.39039 .39309 m .39148 .39078 L .39315 .39242 L 0 .038 .14 r
F
.39039 .39309 m .38872 .39146 L .39148 .39078 L F
.77443 .38889 m .77609 .38608 L .77739 .38783 L 0 .028 .128 r
F
.77443 .38889 m .77313 .38713 L .77609 .38608 L F
.53074 .4073 m .53205 .40589 L .53358 .40684 L 0 .081 .18 r
F
.53074 .4073 m .52921 .40632 L .53205 .40589 L F
.40919 .39453 m .41031 .39217 L .41195 .39401 L 0 .042 .144 r
F
.40919 .39453 m .40754 .39273 L .41031 .39217 L F
.78887 .38817 m .79056 .38548 L .79184 .38726 L 0 .027 .126 r
F
.78887 .38817 m .78758 .3864 L .79056 .38548 L F
.83652 .38797 m .83828 .38529 L .83952 .38706 L 0 .026 .126 r
F
.83652 .38797 m .83527 .38619 L .83828 .38529 L F
.43957 .39778 m .44073 .39583 L .44236 .39737 L 0 .051 .154 r
F
.43957 .39778 m .43795 .39625 L .44073 .39583 L F
.68351 .39162 m .68504 .38872 L .68642 .39047 L 0 .034 .135 r
F
.68351 .39162 m .68212 .38987 L .68504 .38872 L F
.6763 .39203 m .67782 .38923 L .67921 .39097 L 0 .035 .136 r
F
.6763 .39203 m .67491 .39028 L .67782 .38923 L F
.8986 .38703 m .90044 .38424 L .90163 .38605 L 0 .025 .123 r
F
.8986 .38703 m .89741 .38523 L .90044 .38424 L F
.26031 .38824 m .26124 .3854 L .26302 .38723 L 0 .027 .126 r
F
.26031 .38824 m .25853 .3864 L .26124 .3854 L F
.66909 .39245 m .6706 .3896 L .67199 .39134 L 0 .036 .137 r
F
.66909 .39245 m .66769 .39075 L .6706 .3896 L F
.29353 .3889 m .2945 .38622 L .29625 .38807 L 0 .029 .128 r
F
.29353 .3889 m .29178 .38706 L .2945 .38622 L F
.49751 .40691 m .49877 .40532 L .50033 .40679 L 0 .079 .179 r
F
.49751 .40691 m .49595 .40545 L .49877 .40532 L F
.31955 .38994 m .32054 .38736 L .32227 .38914 L 0 .031 .131 r
F
.31955 .38994 m .31781 .38817 L .32054 .38736 L F
.69795 .39094 m .6995 .38828 L .70087 .39 L 0 .033 .134 r
F
.69795 .39094 m .69657 .38921 L .6995 .38828 L F
.71238 .39021 m .71395 .38752 L .71531 .38924 L 0 .032 .132 r
F
.71238 .39021 m .71102 .38853 L .71395 .38752 L F
.70516 .39062 m .70673 .38792 L .70809 .38956 L 0 .032 .133 r
F
.70516 .39062 m .7038 .38896 L .70673 .38792 L F
.22707 .38782 m .22794 .38508 L .22975 .38689 L 0 .026 .125 r
F
.22707 .38782 m .22525 .38601 L .22794 .38508 L F
.26751 .38803 m .26843 .38542 L .27021 .3872 L 0 .027 .126 r
F
.26751 .38803 m .26573 .38623 L .26843 .38542 L F
.37157 .39208 m .37265 .38933 L .37433 .39123 L 0 .036 .137 r
F
.37157 .39208 m .36989 .3902 L .37265 .38933 L F
.90584 .38688 m .9077 .38412 L .90888 .38591 L 0 .025 .123 r
F
.90584 .38688 m .90466 .38508 L .9077 .38412 L F
.66189 .39309 m .66338 .39023 L .66479 .39191 L 0 .038 .139 r
F
.66189 .39309 m .66048 .39141 L .66338 .39023 L F
.84376 .38789 m .84552 .3851 L .84676 .38685 L 0 .027 .126 r
F
.84376 .38789 m .84253 .38614 L .84552 .3851 L F
.53795 .4073 m .53928 .40588 L .5408 .40681 L 0 .081 .181 r
F
.53795 .4073 m .53643 .40636 L .53928 .40588 L F
.57686 .40271 m .57825 .40085 L .57973 .40171 L 0 .066 .167 r
F
.57686 .40271 m .57538 .40183 L .57825 .40085 L F
.79611 .38813 m .7978 .38531 L .79908 .3871 L 0 .027 .126 r
F
.79611 .38813 m .79482 .38634 L .7978 .38531 L F
.85098 .38753 m .85276 .38479 L .85398 .38653 L 0 .026 .125 r
F
.85098 .38753 m .84975 .3858 L .85276 .38479 L F
.54517 .40694 m .5465 .40477 L .54802 .40585 L 0 .078 .178 r
F
.54517 .40694 m .54365 .40587 L .5465 .40477 L F
.60134 .39896 m .60275 .39617 L .60421 .39774 L 0 .053 .156 r
F
.60134 .39896 m .59988 .39739 L .60275 .39617 L F
.39758 .39318 m .39869 .39061 L .40035 .39231 L 0 .039 .141 r
F
.39758 .39318 m .39592 .39152 L .39869 .39061 L F
.64025 .39441 m .64172 .39166 L .64314 .39334 L 0 .041 .144 r
F
.64025 .39441 m .63882 .3928 L .64172 .39166 L F
.7196 .39002 m .72119 .38736 L .72254 .38912 L 0 .031 .132 r
F
.7196 .39002 m .71825 .38826 L .72119 .38736 L F
.80333 .38782 m .80504 .38507 L .80631 .38682 L 0 .027 .126 r
F
.80333 .38782 m .80206 .38606 L .80504 .38507 L F
.91308 .38667 m .91494 .38386 L .91611 .38563 L 0 .024 .123 r
F
.91308 .38667 m .91191 .3849 L .91494 .38386 L F
.42797 .39649 m .42912 .39419 L .43076 .39573 L 0 .048 .15 r
F
.42797 .39649 m .42633 .39493 L .42912 .39419 L F
.64747 .39411 m .64895 .39145 L .65037 .39319 L 0 .041 .143 r
F
.64747 .39411 m .64605 .39239 L .64895 .39145 L F
.23425 .38771 m .23513 .38502 L .23695 .38676 L 0 .027 .126 r
F
.23425 .38771 m .23244 .38596 L .23513 .38502 L F
.19381 .38752 m .19463 .38474 L .19648 .3865 L 0 .026 .125 r
F
.19381 .38752 m .19196 .38574 L .19463 .38474 L F
.48154 .40336 m .48277 .4013 L .48435 .40296 L 0 .068 .169 r
F
.48154 .40336 m .47996 .40173 L .48277 .4013 L F
.85822 .38737 m .86001 .38466 L .86123 .38646 L 0 .026 .125 r
F
.85822 .38737 m .85699 .3856 L .86001 .38466 L F
.34554 .39141 m .34659 .38851 L .34829 .39037 L 0 .034 .135 r
F
.34554 .39141 m .34383 .38953 L .34659 .38851 L F
.35275 .39102 m .3538 .38834 L .3555 .39007 L F
.35275 .39102 m .35104 .38932 L .3538 .38834 L F
.63304 .39503 m .63451 .39238 L .63593 .39393 L 0 .043 .146 r
F
.63304 .39503 m .63161 .39351 L .63451 .39238 L F
.20101 .38725 m .20183 .38464 L .20368 .38635 L 0 .026 .125 r
F
.20101 .38725 m .19916 .38553 L .20183 .38464 L F
.81056 .38765 m .81229 .38498 L .81355 .38672 L 0 .027 .126 r
F
.81056 .38765 m .8093 .3859 L .81229 .38498 L F
.59413 .39966 m .59554 .39703 L .59701 .39861 L 0 .056 .158 r
F
.59413 .39966 m .59266 .39815 L .59554 .39703 L F
.30071 .38906 m .30168 .38635 L .30343 .38819 L 0 .03 .13 r
F
.30071 .38906 m .29896 .38721 L .30168 .38635 L F
.65469 .39387 m .65617 .39095 L .65758 .39264 L 0 .04 .142 r
F
.65469 .39387 m .65327 .39217 L .65617 .39095 L F
.24145 .38748 m .24234 .38474 L .24416 .38645 L 0 .026 .125 r
F
.24145 .38748 m .23964 .38575 L .24234 .38474 L F
.32673 .39008 m .32775 .38727 L .32947 .3891 L 0 .032 .132 r
F
.32673 .39008 m .325 .38827 L .32775 .38727 L F
.27468 .38813 m .27562 .38547 L .27739 .38721 L 0 .028 .127 r
F
.27468 .38813 m .27291 .38637 L .27562 .38547 L F
.45836 .39994 m .45955 .39784 L .46116 .39937 L 0 .058 .16 r
F
.45836 .39994 m .45675 .39834 L .45955 .39784 L F
.46995 .40177 m .47116 .40007 L .47275 .40146 L 0 .064 .166 r
F
.46995 .40177 m .46835 .40033 L .47116 .40007 L F
.61862 .39597 m .62007 .39353 L .62151 .39503 L 0 .046 .149 r
F
.61862 .39597 m .61717 .39445 L .62007 .39353 L F
.37876 .39217 m .37986 .38932 L .38153 .39122 L 0 .036 .138 r
F
.37876 .39217 m .37709 .39028 L .37986 .38932 L F
.62583 .39558 m .62729 .39308 L .62872 .39455 L 0 .045 .148 r
F
.62583 .39558 m .6244 .39409 L .62729 .39308 L F
.56965 .40359 m .57103 .40177 L .57252 .40272 L 0 .069 .171 r
F
.56965 .40359 m .56817 .4026 L .57103 .40177 L F
.72684 .39 m .72844 .38726 L .72978 .38902 L 0 .032 .132 r
F
.72684 .39 m .72549 .38823 L .72844 .38726 L F
.86546 .38724 m .86725 .38439 L .86847 .38619 L 0 .026 .125 r
F
.86546 .38724 m .86424 .38544 L .86725 .38439 L F
.73406 .38966 m .73566 .3868 L .737 .38855 L 0 .031 .131 r
F
.73406 .38966 m .73272 .38791 L .73566 .3868 L F
.74127 .38926 m .74289 .38655 L .74422 .38829 L 0 .03 .13 r
F
.74127 .38926 m .73994 .38753 L .74289 .38655 L F
.24865 .38726 m .24955 .3846 L .25134 .38639 L 0 .026 .125 r
F
.24865 .38726 m .24685 .38547 L .24955 .3846 L F
.8178 .38749 m .81953 .3848 L .82079 .38652 L 0 .027 .126 r
F
.8178 .38749 m .81654 .38576 L .81953 .3848 L F
.40478 .39329 m .40589 .39093 L .40754 .39273 L 0 .04 .142 r
F
.40478 .39329 m .40312 .39154 L .40589 .39093 L F
.56244 .40411 m .56381 .40207 L .5653 .40336 L 0 .071 .172 r
F
.56244 .40411 m .56094 .4028 L .56381 .40207 L F
.35995 .39093 m .36101 .38828 L .3627 .39007 L 0 .034 .135 r
F
.35995 .39093 m .35825 .38917 L .36101 .38828 L F
.87269 .38694 m .8745 .38419 L .87571 .38598 L 0 .025 .124 r
F
.87269 .38694 m .87147 .38515 L .8745 .38419 L F
.44676 .39836 m .44794 .3961 L .44956 .39773 L 0 .053 .156 r
F
.44676 .39836 m .44515 .39674 L .44794 .3961 L F
.28188 .38796 m .28283 .38521 L .2846 .38695 L 0 .028 .127 r
F
.28188 .38796 m .28011 .38621 L .28283 .38521 L F
.20819 .38717 m .20903 .38449 L .21087 .38619 L 0 .026 .125 r
F
.20819 .38717 m .20635 .38546 L .20903 .38449 L F
.58692 .40038 m .58833 .39809 L .58979 .39926 L 0 .059 .161 r
F
.58692 .40038 m .58546 .39928 L .58833 .39809 L F
.33392 .38999 m .33494 .3873 L .33666 .38918 L 0 .032 .133 r
F
.33392 .38999 m .33221 .38812 L .33494 .3873 L F
.49313 .40561 m .49438 .40388 L .49595 .40545 L 0 .076 .177 r
F
.49313 .40561 m .49156 .40405 L .49438 .40388 L F
.41636 .39521 m .41749 .39293 L .41913 .39467 L 0 .045 .147 r
F
.41636 .39521 m .41472 .39347 L .41749 .39293 L F
.75572 .38866 m .75735 .38579 L .75867 .38759 L 0 .029 .129 r
F
.75572 .38866 m .75439 .38687 L .75735 .38579 L F
.43517 .39667 m .43632 .39472 L .43795 .39625 L 0 .05 .152 r
F
.43517 .39667 m .43354 .39515 L .43632 .39472 L F
.82503 .38727 m .82677 .38455 L .82803 .3863 L 0 .026 .125 r
F
.82503 .38727 m .82378 .38555 L .82677 .38455 L F
.7485 .38908 m .75012 .38619 L .75145 .38797 L 0 .03 .13 r
F
.7485 .38908 m .74717 .3873 L .75012 .38619 L F
.30789 .38911 m .30888 .38637 L .31062 .38817 L F
.30789 .38911 m .30615 .38729 L .30888 .38637 L F
.38596 .39214 m .38705 .38976 L .38872 .39146 L 0 .038 .139 r
F
.38596 .39214 m .38429 .39044 L .38705 .38976 L F
.61141 .39675 m .61284 .39391 L .61429 .39546 L 0 .048 .151 r
F
.61141 .39675 m .60996 .3952 L .61284 .39391 L F
.76294 .38838 m .76458 .38552 L .7659 .38735 L 0 .028 .128 r
F
.76294 .38838 m .76162 .38655 L .76458 .38552 L F
.21538 .38701 m .21624 .3842 L .21807 .38602 L 0 .026 .125 r
F
.21538 .38701 m .21356 .38519 L .21624 .3842 L F
.87993 .38682 m .88175 .38404 L .88295 .38582 L 0 .025 .124 r
F
.87993 .38682 m .87873 .38503 L .88175 .38404 L F
.55523 .40489 m .55658 .40243 L .55808 .40374 L 0 .073 .174 r
F
.55523 .40489 m .55372 .4036 L .55658 .40243 L F
.28907 .38789 m .29003 .38522 L .29178 .38706 L 0 .028 .127 r
F
.28907 .38789 m .28731 .38607 L .29003 .38522 L F
.83227 .38711 m .83402 .3844 L .83527 .38619 L 0 .026 .125 r
F
.83227 .38711 m .83102 .38533 L .83402 .3844 L F
.88716 .38654 m .88899 .38373 L .89018 .38549 L 0 .025 .124 r
F
.88716 .38654 m .88597 .38478 L .88899 .38373 L F
.77017 .38816 m .77183 .38536 L .77313 .38713 L 0 .028 .128 r
F
.77017 .38816 m .76886 .38635 L .77183 .38536 L F
.25583 .38736 m .25674 .38456 L .25853 .3864 L 0 .027 .126 r
F
.25583 .38736 m .25404 .38552 L .25674 .38456 L F
.7846 .38738 m .78628 .38462 L .78758 .3864 L F
.7846 .38738 m .78331 .38561 L .78628 .38462 L F
.31509 .38899 m .31608 .38642 L .31781 .38817 L 0 .03 .131 r
F
.31509 .38899 m .31335 .38723 L .31608 .38642 L F
.51915 .40704 m .52044 .40527 L .52199 .40619 L 0 .082 .181 r
F
.51915 .40704 m .5176 .40611 L .52044 .40527 L F
.77739 .38783 m .77905 .38499 L .78035 .38672 L 0 .028 .127 r
F
.77739 .38783 m .77609 .38608 L .77905 .38499 L F
.36714 .39104 m .36821 .38834 L .36989 .3902 L 0 .035 .136 r
F
.36714 .39104 m .36545 .38921 L .36821 .38834 L F
.89439 .38624 m .89622 .38344 L .89741 .38523 L 0 .025 .123 r
F
.89439 .38624 m .8932 .38446 L .89622 .38344 L F
.68642 .39047 m .68795 .38756 L .68934 .38931 L 0 .033 .134 r
F
.68642 .39047 m .68504 .38872 L .68795 .38756 L F
.52637 .40672 m .52767 .40547 L .52921 .40632 L 0 .082 .181 r
F
.52637 .40672 m .52483 .40583 L .52767 .40547 L F
.69364 .39012 m .6952 .38748 L .69657 .38921 L 0 .033 .134 r
F
.69364 .39012 m .69226 .38838 L .6952 .38748 L F
.22257 .38693 m .22343 .38417 L .22525 .38601 L 0 .026 .125 r
F
.22257 .38693 m .22075 .3851 L .22343 .38417 L F
.67199 .39134 m .67351 .38855 L .67491 .39028 L 0 .036 .137 r
F
.67199 .39134 m .6706 .3896 L .67351 .38855 L F
.67921 .39097 m .68073 .38812 L .68212 .38987 L 0 .035 .136 r
F
.67921 .39097 m .67782 .38923 L .68073 .38812 L F
.50472 .40804 m .50599 .40584 L .50755 .40735 L 0 .084 .183 r
F
.50472 .40804 m .50316 .40655 L .50599 .40584 L F
.26302 .38723 m .26395 .3844 L .26573 .38623 L 0 .027 .126 r
F
.26302 .38723 m .26124 .3854 L .26395 .3844 L F
.90163 .38605 m .90348 .38328 L .90466 .38508 L 0 .024 .123 r
F
.90163 .38605 m .90044 .38424 L .90348 .38328 L F
.79184 .38726 m .79354 .38455 L .79482 .38634 L 0 .027 .126 r
F
.79184 .38726 m .79056 .38548 L .79354 .38455 L F
.83952 .38706 m .84129 .38439 L .84253 .38614 L F
.83952 .38706 m .83828 .38529 L .84129 .38439 L F
.47715 .40229 m .47837 .40041 L .47996 .40173 L 0 .067 .168 r
F
.47715 .40229 m .47556 .40093 L .47837 .40041 L F
.51193 .40772 m .51321 .4059 L .51477 .40694 L 0 .084 .183 r
F
.51193 .40772 m .51038 .40665 L .51321 .4059 L F
.3411 .39031 m .34213 .38765 L .34383 .38953 L 0 .034 .135 r
F
.3411 .39031 m .33939 .38843 L .34213 .38765 L F
.66479 .39191 m .66629 .38907 L .66769 .39075 L 0 .037 .139 r
F
.66479 .39191 m .66338 .39023 L .66629 .38907 L F
.60421 .39774 m .60563 .39492 L .60709 .39649 L 0 .052 .154 r
F
.60421 .39774 m .60275 .39617 L .60563 .39492 L F
.46555 .40057 m .46675 .39889 L .46835 .40033 L 0 .062 .164 r
F
.46555 .40057 m .46395 .39907 L .46675 .39889 L F
.70809 .38956 m .70966 .38687 L .71102 .38853 L 0 .032 .133 r
F
.70809 .38956 m .70673 .38792 L .70966 .38687 L F
.70087 .39 m .70243 .38728 L .7038 .38896 L 0 .033 .134 r
F
.70087 .39 m .6995 .38828 L .70243 .38728 L F
.39315 .39242 m .39425 .38985 L .39592 .39152 L 0 .039 .141 r
F
.39315 .39242 m .39148 .39078 L .39425 .38985 L F
.45396 .39884 m .45515 .39673 L .45675 .39834 L 0 .056 .159 r
F
.45396 .39884 m .45235 .39716 L .45515 .39673 L F
.71531 .38924 m .71689 .3865 L .71825 .38826 L 0 .031 .132 r
F
.71531 .38924 m .71395 .38752 L .71689 .3865 L F
.54802 .40585 m .54936 .40366 L .55087 .40475 L 0 .077 .178 r
F
.54802 .40585 m .5465 .40477 L .54936 .40366 L F
.84676 .38685 m .84852 .38406 L .84975 .3858 L 0 .026 .125 r
F
.84676 .38685 m .84552 .3851 L .84852 .38406 L F
.42355 .39568 m .42469 .39338 L .42633 .39493 L 0 .048 .15 r
F
.42355 .39568 m .42191 .3941 L .42469 .39338 L F
.29625 .38807 m .29721 .38536 L .29896 .38721 L 0 .029 .129 r
F
.29625 .38807 m .2945 .38622 L .29721 .38536 L F
.22975 .38689 m .23062 .38416 L .23244 .38596 L 0 .026 .126 r
F
.22975 .38689 m .22794 .38508 L .23062 .38416 L F
.79908 .3871 m .80078 .38428 L .80206 .38606 L 0 .027 .126 r
F
.79908 .3871 m .7978 .38531 L .80078 .38428 L F
.57973 .40171 m .58112 .39957 L .58259 .4005 L 0 .065 .167 r
F
.57973 .40171 m .57825 .40085 L .58112 .39957 L F
.90888 .38591 m .91073 .38311 L .91191 .3849 L 0 .024 .123 r
F
.90888 .38591 m .9077 .38412 L .91073 .38311 L F
.48874 .40433 m .48998 .4024 L .49156 .40405 L 0 .073 .174 r
F
.48874 .40433 m .48717 .40268 L .48998 .4024 L F
.85398 .38653 m .85577 .38384 L .85699 .3856 L 0 .026 .125 r
F
.85398 .38653 m .85276 .38479 L .85577 .38384 L F
.64314 .39334 m .64462 .39066 L .64605 .39239 L 0 .041 .143 r
F
.64314 .39334 m .64172 .39166 L .64462 .39066 L F
.32227 .38914 m .32328 .38646 L .325 .38827 L 0 .031 .132 r
F
.32227 .38914 m .32054 .38736 L .32328 .38646 L F
.18928 .38674 m .1901 .38394 L .19196 .38574 L 0 .026 .125 r
F
.18928 .38674 m .18743 .38492 L .1901 .38394 L F
.27021 .3872 m .27113 .3846 L .27291 .38637 L 0 .027 .127 r
F
.27021 .3872 m .26843 .38542 L .27113 .3846 L F
.41195 .39401 m .41308 .3916 L .41472 .39347 L 0 .043 .146 r
F
.41195 .39401 m .41031 .39217 L .41308 .3916 L F
.37433 .39123 m .37542 .38837 L .37709 .39028 L 0 .036 .137 r
F
.37433 .39123 m .37265 .38933 L .37542 .38837 L F
.80631 .38682 m .80803 .38416 L .8093 .3859 L 0 .027 .126 r
F
.80631 .38682 m .80504 .38507 L .80803 .38416 L F
.53358 .40684 m .5349 .40541 L .53643 .40636 L 0 .083 .182 r
F
.53358 .40684 m .53205 .40589 L .5349 .40541 L F
.91611 .38563 m .91798 .38283 L .91914 .38459 L 0 .024 .122 r
F
.91611 .38563 m .91494 .38386 L .91798 .38283 L F
.65758 .39264 m .65907 .38973 L .66048 .39141 L 0 .039 .141 r
F
.65758 .39264 m .65617 .39095 L .65907 .38973 L F
.19648 .3865 m .19731 .38378 L .19916 .38553 L 0 .026 .125 r
F
.19648 .3865 m .19463 .38474 L .19731 .38378 L F
.40035 .39231 m .40147 .38981 L .40312 .39154 L 0 .039 .141 r
F
.40035 .39231 m .39869 .39061 L .40147 .38981 L F
.72254 .38912 m .72414 .38645 L .72549 .38823 L 0 .032 .132 r
F
.72254 .38912 m .72119 .38736 L .72414 .38645 L F
.63593 .39393 m .6374 .39118 L .63882 .3928 L 0 .043 .145 r
F
.63593 .39393 m .63451 .39238 L .6374 .39118 L F
.44236 .39737 m .44353 .39517 L .44515 .39674 L 0 .053 .155 r
F
.44236 .39737 m .44073 .39583 L .44353 .39517 L F
.23695 .38676 m .23783 .38403 L .23964 .38575 L 0 .026 .126 r
F
.23695 .38676 m .23513 .38502 L .23783 .38403 L F
.34829 .39037 m .34934 .38749 L .35104 .38932 L 0 .034 .135 r
F
.34829 .39037 m .34659 .38851 L .34934 .38749 L F
.65037 .39319 m .65186 .39042 L .65327 .39217 L 0 .041 .143 r
F
.65037 .39319 m .64895 .39145 L .65186 .39042 L F
.59701 .39861 m .59841 .39582 L .59988 .39739 L 0 .055 .157 r
F
.59701 .39861 m .59554 .39703 L .59841 .39582 L F
.24416 .38645 m .24504 .38377 L .24685 .38547 L 0 .026 .125 r
F
.24416 .38645 m .24234 .38474 L .24504 .38377 L F
.86123 .38646 m .86302 .38364 L .86424 .38544 L F
.86123 .38646 m .86001 .38466 L .86302 .38364 L F
.3555 .39007 m .35655 .38741 L .35825 .38917 L 0 .034 .135 r
F
.3555 .39007 m .3538 .38834 L .35655 .38741 L F
.32947 .3891 m .33049 .38626 L .33221 .38812 L 0 .031 .132 r
F
.32947 .3891 m .32775 .38727 L .33049 .38626 L F
.81355 .38672 m .81528 .38404 L .81654 .38576 L 0 .027 .126 r
F
.81355 .38672 m .81229 .38498 L .81528 .38404 L F
.43076 .39573 m .4319 .39361 L .43354 .39515 L 0 .049 .151 r
F
.43076 .39573 m .42912 .39419 L .4319 .39361 L F
.62872 .39455 m .63019 .39207 L .63161 .39351 L 0 .045 .147 r
F
.62872 .39455 m .62729 .39308 L .63019 .39207 L F
.737 .38855 m .73861 .38579 L .73994 .38753 L 0 .03 .131 r
F
.737 .38855 m .73566 .3868 L .73861 .38579 L F
.20368 .38635 m .2045 .38375 L .20635 .38546 L 0 .026 .125 r
F
.20368 .38635 m .20183 .38464 L .2045 .38375 L F
.30343 .38819 m .30441 .38547 L .30615 .38729 L 0 .03 .13 r
F
.30343 .38819 m .30168 .38635 L .30441 .38547 L F
.5408 .40681 m .54213 .40495 L .54365 .40587 L 0 .082 .182 r
F
.5408 .40681 m .53928 .40588 L .54213 .40495 L F
.86847 .38619 m .87026 .38334 L .87147 .38515 L 0 .025 .124 r
F
.86847 .38619 m .86725 .38439 L .87026 .38334 L F
.72978 .38902 m .73138 .38615 L .73272 .38791 L 0 .031 .132 r
F
.72978 .38902 m .72844 .38726 L .73138 .38615 L F
.27739 .38721 m .27833 .3845 L .28011 .38621 L 0 .028 .127 r
F
.27739 .38721 m .27562 .38547 L .27833 .3845 L F
.38153 .39122 m .38262 .38854 L .38429 .39044 L 0 .037 .138 r
F
.38153 .39122 m .37986 .38932 L .38262 .38854 L F
.62151 .39503 m .62296 .39259 L .6244 .39409 L 0 .046 .149 r
F
.62151 .39503 m .62007 .39353 L .62296 .39259 L F
.58979 .39926 m .5912 .39691 L .59266 .39815 L 0 .058 .16 r
F
.58979 .39926 m .58833 .39809 L .5912 .39691 L F
.61429 .39546 m .61573 .39291 L .61717 .39445 L 0 .047 .15 r
F
.61429 .39546 m .61284 .39391 L .61573 .39291 L F
.74422 .38829 m .74585 .38555 L .74717 .3873 L 0 .03 .13 r
F
.74422 .38829 m .74289 .38655 L .74585 .38555 L F
.57252 .40272 m .5739 .40093 L .57538 .40183 L 0 .07 .171 r
F
.57252 .40272 m .57103 .40177 L .5739 .40093 L F
.82079 .38652 m .82253 .38382 L .82378 .38555 L 0 .026 .126 r
F
.82079 .38652 m .81953 .3848 L .82253 .38382 L F
.2846 .38695 m .28555 .38433 L .28731 .38607 L 0 .028 .127 r
F
.2846 .38695 m .28283 .38521 L .28555 .38433 L F
.75145 .38797 m .75307 .38508 L .75439 .38687 L 0 .029 .129 r
F
.75145 .38797 m .75012 .38619 L .75307 .38508 L F
.50033 .40679 m .50159 .40506 L .50316 .40655 L 0 .083 .182 r
F
.50033 .40679 m .49877 .40532 L .50159 .40506 L F
.87571 .38598 m .87752 .38323 L .87873 .38503 L 0 .025 .124 r
F
.87571 .38598 m .8745 .38419 L .87752 .38323 L F
.75867 .38759 m .7603 .38473 L .76162 .38655 L 0 .029 .128 r
F
.75867 .38759 m .75735 .38579 L .7603 .38473 L F
.25134 .38639 m .25224 .38372 L .25404 .38552 L 0 .026 .125 r
F
.25134 .38639 m .24955 .3846 L .25224 .38372 L F
.21087 .38619 m .21171 .3835 L .21356 .38519 L F
.21087 .38619 m .20903 .38449 L .21171 .3835 L F
.3627 .39007 m .36376 .38738 L .36545 .38921 L 0 .034 .135 r
F
.3627 .39007 m .36101 .38828 L .36376 .38738 L F
.82803 .3863 m .82977 .38355 L .83102 .38533 L 0 .026 .125 r
F
.82803 .3863 m .82677 .38455 L .82977 .38355 L F
.55808 .40374 m .55944 .4015 L .56094 .4028 L 0 .072 .173 r
F
.55808 .40374 m .55658 .40243 L .55944 .4015 L F
.5653 .40336 m .56667 .40133 L .56817 .4026 L 0 .071 .173 r
F
.5653 .40336 m .56381 .40207 L .56667 .40133 L F
.48435 .40296 m .48559 .40103 L .48717 .40268 L 0 .071 .172 r
F
.48435 .40296 m .48277 .4013 L .48559 .40103 L F
.7659 .38735 m .76755 .38454 L .76886 .38635 L 0 .028 .128 r
F
.7659 .38735 m .76458 .38552 L .76755 .38454 L F
.46116 .39937 m .46235 .3976 L .46395 .39907 L 0 .06 .162 r
F
.46116 .39937 m .45955 .39784 L .46235 .3976 L F
.31062 .38817 m .31161 .38545 L .31335 .38723 L 0 .03 .13 r
F
.31062 .38817 m .30888 .38637 L .31161 .38545 L F
.33666 .38918 m .33768 .38654 L .33939 .38843 L 0 .033 .133 r
F
.33666 .38918 m .33494 .3873 L .33768 .38654 L F
.88295 .38582 m .88477 .38302 L .88597 .38478 L 0 .025 .124 r
F
.88295 .38582 m .88175 .38404 L .88477 .38302 L F
.21807 .38602 m .21893 .38327 L .22075 .3851 L 0 .026 .125 r
F
.21807 .38602 m .21624 .3842 L .21893 .38327 L F
.89018 .38549 m .89201 .3827 L .8932 .38446 L 0 .025 .123 r
F
.89018 .38549 m .88899 .38373 L .89201 .3827 L F
.68934 .38931 m .69088 .38661 L .69226 .38838 L 0 .033 .134 r
F
.68934 .38931 m .68795 .38756 L .69088 .38661 L F
.44956 .39773 m .45074 .39551 L .45235 .39716 L 0 .055 .157 r
F
.44956 .39773 m .44794 .3961 L .45074 .39551 L F
.78035 .38672 m .78202 .38389 L .78331 .38561 L 0 .027 .126 r
F
.78035 .38672 m .77905 .38499 L .78202 .38389 L F
.40754 .39273 m .40866 .39032 L .41031 .39217 L 0 .041 .144 r
F
.40754 .39273 m .40589 .39093 L .40866 .39032 L F
.77313 .38713 m .77479 .38434 L .77609 .38608 L 0 .028 .128 r
F
.77313 .38713 m .77183 .38536 L .77479 .38434 L F
.83527 .38619 m .83703 .3835 L .83828 .38529 L 0 .026 .125 r
F
.83527 .38619 m .83402 .3844 L .83703 .3835 L F
.78758 .3864 m .78927 .38369 L .79056 .38548 L 0 .027 .126 r
F
.78758 .3864 m .78628 .38462 L .78927 .38369 L F
.25853 .3864 m .25945 .38356 L .26124 .3854 L F
.25853 .3864 m .25674 .38456 L .25945 .38356 L F
.89741 .38523 m .89925 .38243 L .90044 .38424 L 0 .024 .123 r
F
.89741 .38523 m .89622 .38344 L .89925 .38243 L F
.47275 .40146 m .47397 .39958 L .47556 .40093 L 0 .067 .168 r
F
.47275 .40146 m .47116 .40007 L .47397 .39958 L F
.38872 .39146 m .38981 .38907 L .39148 .39078 L 0 .039 .14 r
F
.38872 .39146 m .38705 .38976 L .38981 .38907 L F
.29178 .38706 m .29274 .38437 L .2945 .38622 L 0 .028 .128 r
F
.29178 .38706 m .29003 .38522 L .29274 .38437 L F
.41913 .39467 m .42027 .39236 L .42191 .3941 L 0 .047 .149 r
F
.41913 .39467 m .41749 .39293 L .42027 .39236 L F
.68212 .38987 m .68365 .38696 L .68504 .38872 L 0 .034 .135 r
F
.68212 .38987 m .68073 .38812 L .68365 .38696 L F
.60709 .39649 m .60851 .39363 L .60996 .3952 L 0 .05 .153 r
F
.60709 .39649 m .60563 .39492 L .60851 .39363 L F
.67491 .39028 m .67643 .3875 L .67782 .38923 L 0 .035 .136 r
F
.67491 .39028 m .67351 .38855 L .67643 .3875 L F
.66769 .39075 m .6692 .38791 L .6706 .3896 L 0 .036 .138 r
F
.66769 .39075 m .66629 .38907 L .6692 .38791 L F
.52199 .40619 m .52329 .40495 L .52483 .40583 L 0 .083 .182 r
F
.52199 .40619 m .52044 .40527 L .52329 .40495 L F
.31781 .38817 m .3188 .38561 L .32054 .38736 L 0 .031 .131 r
F
.31781 .38817 m .31608 .38642 L .3188 .38561 L F
.36989 .3902 m .37097 .38745 L .37265 .38933 L 0 .035 .136 r
F
.36989 .3902 m .36821 .38834 L .37097 .38745 L F
.22525 .38601 m .22612 .38326 L .22794 .38508 L 0 .026 .125 r
F
.22525 .38601 m .22343 .38417 L .22612 .38326 L F
.69657 .38921 m .69813 .38656 L .6995 .38828 L 0 .033 .134 r
F
.69657 .38921 m .6952 .38748 L .69813 .38656 L F
.26573 .38623 m .26665 .3836 L .26843 .38542 L 0 .027 .126 r
F
.26573 .38623 m .26395 .3844 L .26665 .3836 L F
.43795 .39625 m .43911 .39429 L .44073 .39583 L 0 .052 .154 r
F
.43795 .39625 m .43632 .39472 L .43911 .39429 L F
.58259 .4005 m .58399 .3983 L .58546 .39928 L 0 .063 .165 r
F
.58259 .4005 m .58112 .39957 L .58399 .3983 L F
.90466 .38508 m .90652 .38231 L .9077 .38412 L 0 .024 .123 r
F
.90466 .38508 m .90348 .38328 L .90652 .38231 L F
.55087 .40475 m .55221 .4025 L .55372 .4036 L 0 .076 .177 r
F
.55087 .40475 m .54936 .40366 L .55221 .4025 L F
.71102 .38853 m .7126 .38583 L .71395 .38752 L 0 .032 .132 r
F
.71102 .38853 m .70966 .38687 L .7126 .38583 L F
.79482 .38634 m .79652 .38352 L .7978 .38531 L 0 .027 .126 r
F
.79482 .38634 m .79354 .38455 L .79652 .38352 L F
.84253 .38614 m .84429 .38336 L .84552 .3851 L F
.84253 .38614 m .84129 .38439 L .84429 .38336 L F
.7038 .38896 m .70537 .38627 L .70673 .38792 L 0 .033 .133 r
F
.7038 .38896 m .70243 .38728 L .70537 .38627 L F
.84975 .3858 m .85153 .38305 L .85276 .38479 L 0 .026 .125 r
F
.84975 .3858 m .84852 .38406 L .85153 .38305 L F
.66048 .39141 m .66198 .38855 L .66338 .39023 L 0 .038 .14 r
F
.66048 .39141 m .65907 .38973 L .66198 .38855 L F
.49595 .40545 m .4972 .40374 L .49877 .40532 L 0 .08 .18 r
F
.49595 .40545 m .49438 .40388 L .4972 .40374 L F
.71825 .38826 m .71984 .38558 L .72119 .38736 L 0 .031 .132 r
F
.71825 .38826 m .71689 .3865 L .71984 .38558 L F
.80206 .38606 m .80376 .3833 L .80504 .38507 L 0 .027 .126 r
F
.80206 .38606 m .80078 .38428 L .80376 .3833 L F
.91191 .3849 m .91377 .38208 L .91494 .38386 L 0 .024 .122 r
F
.91191 .3849 m .91073 .38311 L .91377 .38208 L F
.39592 .39152 m .39703 .38892 L .39869 .39061 L 0 .039 .141 r
F
.39592 .39152 m .39425 .38985 L .39703 .38892 L F
.51477 .40694 m .51605 .4051 L .5176 .40611 L 0 .085 .184 r
F
.51477 .40694 m .51321 .4059 L .51605 .4051 L F
.50755 .40735 m .50882 .40513 L .51038 .40665 L F
.50755 .40735 m .50599 .40584 L .50882 .40513 L F
.34383 .38953 m .34488 .38665 L .34659 .38851 L 0 .034 .135 r
F
.34383 .38953 m .34213 .38765 L .34488 .38665 L F
.19196 .38574 m .19278 .38295 L .19463 .38474 L 0 .026 .125 r
F
.19196 .38574 m .1901 .38394 L .19278 .38295 L F
.23244 .38596 m .23331 .38324 L .23513 .38502 L 0 .027 .126 r
F
.23244 .38596 m .23062 .38416 L .23331 .38324 L F
.59988 .39739 m .60129 .3946 L .60275 .39617 L 0 .054 .156 r
F
.59988 .39739 m .59841 .39582 L .60129 .3946 L F
.64605 .39239 m .64753 .38968 L .64895 .39145 L 0 .041 .143 r
F
.64605 .39239 m .64462 .39066 L .64753 .38968 L F
.63882 .3928 m .64029 .38997 L .64172 .39166 L 0 .042 .144 r
F
.63882 .3928 m .6374 .39118 L .64029 .38997 L F
.85699 .3856 m .85879 .38289 L .86001 .38466 L 0 .026 .125 r
F
.85699 .3856 m .85577 .38384 L .85879 .38289 L F
.29896 .38721 m .29994 .3845 L .30168 .38635 L 0 .029 .129 r
F
.29896 .38721 m .29721 .38536 L .29994 .3845 L F
.37709 .39028 m .37818 .38742 L .37986 .38932 L 0 .036 .137 r
F
.37709 .39028 m .37542 .38837 L .37818 .38742 L F
.325 .38827 m .32602 .38543 L .32775 .38727 L 0 .031 .132 r
F
.325 .38827 m .32328 .38646 L .32602 .38543 L F
.52921 .40632 m .53052 .40509 L .53205 .40589 L 0 .085 .184 r
F
.52921 .40632 m .52767 .40547 L .53052 .40509 L F
.8093 .3859 m .81102 .38324 L .81229 .38498 L 0 .027 .126 r
F
.8093 .3859 m .80803 .38416 L .81102 .38324 L F
.47996 .40173 m .48119 .40001 L .48277 .4013 L 0 .069 .17 r
F
.47996 .40173 m .47837 .40041 L .48119 .40001 L F
.35104 .38932 m .3521 .38653 L .3538 .38834 L 0 .034 .135 r
F
.35104 .38932 m .34934 .38749 L .3521 .38653 L F
.42633 .39493 m .42748 .39265 L .42912 .39419 L 0 .048 .151 r
F
.42633 .39493 m .42469 .39338 L .42748 .39265 L F
.19916 .38553 m .19998 .3829 L .20183 .38464 L 0 .026 .125 r
F
.19916 .38553 m .19731 .38378 L .19998 .3829 L F
.23964 .38575 m .24053 .38302 L .24234 .38474 L F
.23964 .38575 m .23783 .38403 L .24053 .38302 L F
.65327 .39217 m .65476 .38921 L .65617 .39095 L 0 .04 .142 r
F
.65327 .39217 m .65186 .39042 L .65476 .38921 L F
.27291 .38637 m .27384 .38373 L .27562 .38547 L 0 .028 .127 r
F
.27291 .38637 m .27113 .3846 L .27384 .38373 L F
.72549 .38823 m .72709 .38547 L .72844 .38726 L 0 .032 .132 r
F
.72549 .38823 m .72414 .38645 L .72709 .38547 L F
.86424 .38544 m .86603 .38258 L .86725 .38439 L 0 .026 .124 r
F
.86424 .38544 m .86302 .38364 L .86603 .38258 L F
.24685 .38547 m .24774 .3829 L .24955 .3846 L 0 .026 .125 r
F
.24685 .38547 m .24504 .38377 L .24774 .3829 L F
.63161 .39351 m .63308 .39094 L .63451 .39238 L 0 .044 .147 r
F
.63161 .39351 m .63019 .39207 L .63308 .39094 L F
.73272 .38791 m .73432 .38505 L .73566 .3868 L 0 .031 .131 r
F
.73272 .38791 m .73138 .38615 L .73432 .38505 L F
.33221 .38812 m .33323 .38542 L .33494 .3873 L 0 .032 .132 r
F
.33221 .38812 m .33049 .38626 L .33323 .38542 L F
.45675 .39834 m .45794 .3963 L .45955 .39784 L 0 .058 .161 r
F
.45675 .39834 m .45515 .39673 L .45794 .3963 L F
.59266 .39815 m .59407 .39573 L .59554 .39703 L 0 .057 .16 r
F
.59266 .39815 m .5912 .39691 L .59407 .39573 L F
.73994 .38753 m .74156 .38481 L .74289 .38655 L 0 .03 .13 r
F
.73994 .38753 m .73861 .38579 L .74156 .38481 L F
.40312 .39154 m .40424 .38915 L .40589 .39093 L 0 .04 .142 r
F
.40312 .39154 m .40147 .38981 L .40424 .38915 L F
.87147 .38515 m .87328 .38237 L .8745 .38419 L 0 .025 .124 r
F
.87147 .38515 m .87026 .38334 L .87328 .38237 L F
.81654 .38576 m .81828 .38309 L .81953 .3848 L 0 .027 .126 r
F
.81654 .38576 m .81528 .38404 L .81828 .38309 L F
.35825 .38917 m .35931 .38648 L .36101 .38828 L 0 .034 .135 r
F
.35825 .38917 m .35655 .38741 L .35931 .38648 L F
.28011 .38621 m .28105 .38352 L .28283 .38521 L 0 .028 .127 r
F
.28011 .38621 m .27833 .3845 L .28105 .38352 L F
.54365 .40587 m .54499 .40387 L .5465 .40477 L 0 .082 .181 r
F
.54365 .40587 m .54213 .40495 L .54499 .40387 L F
.61717 .39445 m .61862 .39198 L .62007 .39353 L 0 .047 .15 r
F
.61717 .39445 m .61573 .39291 L .61862 .39198 L F
.41472 .39347 m .41585 .39104 L .41749 .39293 L 0 .045 .147 r
F
.41472 .39347 m .41308 .3916 L .41585 .39104 L F
.20635 .38546 m .20718 .38279 L .20903 .38449 L 0 .026 .125 r
F
.20635 .38546 m .2045 .38375 L .20718 .38279 L F
.75439 .38687 m .75602 .38398 L .75735 .38579 L 0 .029 .129 r
F
.75439 .38687 m .75307 .38508 L .75602 .38398 L F
.6244 .39409 m .62586 .39161 L .62729 .39308 L 0 .046 .149 r
F
.6244 .39409 m .62296 .39259 L .62586 .39161 L F
.30615 .38729 m .30714 .38457 L .30888 .38637 L 0 .03 .13 r
F
.30615 .38729 m .30441 .38547 L .30714 .38457 L F
.74717 .3873 m .7488 .38446 L .75012 .38619 L F
.74717 .3873 m .74585 .38555 L .7488 .38446 L F
.46835 .40033 m .46956 .3987 L .47116 .40007 L 0 .065 .167 r
F
.46835 .40033 m .46675 .39889 L .46956 .3987 L F
.44515 .39674 m .44632 .39449 L .44794 .3961 L 0 .054 .156 r
F
.44515 .39674 m .44353 .39517 L .44632 .39449 L F
.53643 .40636 m .53776 .40494 L .53928 .40588 L 0 .085 .184 r
F
.53643 .40636 m .5349 .40541 L .53776 .40494 L F
.82378 .38555 m .82552 .3828 L .82677 .38455 L 0 .026 .125 r
F
.82378 .38555 m .82253 .38382 L .82552 .3828 L F
.76162 .38655 m .76326 .38367 L .76458 .38552 L 0 .028 .128 r
F
.76162 .38655 m .7603 .38473 L .76326 .38367 L F
.21356 .38519 m .2144 .38251 L .21624 .3842 L 0 .026 .125 r
F
.21356 .38519 m .21171 .3835 L .2144 .38251 L F
.57538 .40183 m .57678 .39996 L .57825 .40085 L 0 .07 .171 r
F
.57538 .40183 m .5739 .40093 L .57678 .39996 L F
.49156 .40405 m .4928 .40224 L .49438 .40388 L 0 .077 .177 r
F
.49156 .40405 m .48998 .4024 L .4928 .40224 L F
.87873 .38503 m .88054 .38225 L .88175 .38404 L 0 .025 .124 r
F
.87873 .38503 m .87752 .38323 L .88054 .38225 L F
.38429 .39044 m .38538 .38787 L .38705 .38976 L 0 .037 .139 r
F
.38429 .39044 m .38262 .38854 L .38538 .38787 L F
.28731 .38607 m .28826 .38347 L .29003 .38522 L 0 .028 .127 r
F
.28731 .38607 m .28555 .38433 L .28826 .38347 L F
.25404 .38552 m .25495 .38277 L .25674 .38456 L 0 .026 .126 r
F
.25404 .38552 m .25224 .38372 L .25495 .38277 L F
.83102 .38533 m .83277 .3826 L .83402 .3844 L 0 .026 .125 r
F
.83102 .38533 m .82977 .38355 L .83277 .3826 L F
.43354 .39515 m .43469 .39316 L .43632 .39472 L 0 .051 .153 r
F
.43354 .39515 m .4319 .39361 L .43469 .39316 L F
.76886 .38635 m .77052 .38357 L .77183 .38536 L 0 .028 .128 r
F
.76886 .38635 m .76755 .38454 L .77052 .38357 L F
.56094 .4028 m .56231 .40078 L .56381 .40207 L 0 .073 .174 r
F
.56094 .4028 m .55944 .4015 L .56231 .40078 L F
.88597 .38478 m .88779 .38199 L .88899 .38373 L 0 .025 .124 r
F
.88597 .38478 m .88477 .38302 L .88779 .38199 L F
.60996 .3952 m .61139 .39233 L .61284 .39391 L 0 .049 .151 r
F
.60996 .3952 m .60851 .39363 L .61139 .39233 L F
.36545 .38921 m .36652 .38648 L .36821 .38834 L 0 .035 .136 r
F
.36545 .38921 m .36376 .38738 L .36652 .38648 L F
.78331 .38561 m .785 .38291 L .78628 .38462 L 0 .027 .126 r
F
.78331 .38561 m .78202 .38389 L .785 .38291 L F
.31335 .38723 m .31434 .38467 L .31608 .38642 L 0 .03 .131 r
F
.31335 .38723 m .31161 .38545 L .31434 .38467 L F
.8932 .38446 m .89504 .38167 L .89622 .38344 L 0 .024 .123 r
F
.8932 .38446 m .89201 .3827 L .89504 .38167 L F
.77609 .38608 m .77776 .38325 L .77905 .38499 L 0 .028 .127 r
F
.77609 .38608 m .77479 .38434 L .77776 .38325 L F
.22075 .3851 m .22161 .38234 L .22343 .38417 L 0 .026 .125 r
F
.22075 .3851 m .21893 .38327 L .22161 .38234 L F
.68504 .38872 m .68657 .38581 L .68795 .38756 L 0 .033 .134 r
F
.68504 .38872 m .68365 .38696 L .68657 .38581 L F
.69226 .38838 m .69382 .3857 L .6952 .38748 L F
.69226 .38838 m .69088 .38661 L .69382 .3857 L F
.56817 .4026 m .56954 .40053 L .57103 .40177 L 0 .072 .173 r
F
.56817 .4026 m .56667 .40133 L .56954 .40053 L F
.6706 .3896 m .67211 .3869 L .67351 .38855 L 0 .036 .137 r
F
.6706 .3896 m .6692 .38791 L .67211 .3869 L F
.26124 .3854 m .26216 .38257 L .26395 .3844 L 0 .026 .126 r
F
.26124 .3854 m .25945 .38356 L .26216 .38257 L F
.67782 .38923 m .67934 .3864 L .68073 .38812 L 0 .035 .136 r
F
.67782 .38923 m .67643 .3875 L .67934 .3864 L F
.33939 .38843 m .34042 .38575 L .34213 .38765 L 0 .033 .134 r
F
.33939 .38843 m .33768 .38654 L .34042 .38575 L F
.90044 .38424 m .90229 .38147 L .90348 .38328 L 0 .024 .123 r
F
.90044 .38424 m .89925 .38243 L .90229 .38147 L F
.58546 .39928 m .58686 .39705 L .58833 .39809 L 0 .062 .164 r
F
.58546 .39928 m .58399 .3983 L .58686 .39705 L F
.79056 .38548 m .79225 .38276 L .79354 .38455 L 0 .027 .126 r
F
.79056 .38548 m .78927 .38369 L .79225 .38276 L F
.83828 .38529 m .84005 .38261 L .84129 .38439 L F
.83828 .38529 m .83703 .3835 L .84005 .38261 L F
.55372 .4036 m .55507 .40134 L .55658 .40243 L 0 .075 .176 r
F
.55372 .4036 m .55221 .4025 L .55507 .40134 L F
.2945 .38622 m .29546 .38351 L .29721 .38536 L 0 .029 .128 r
F
.2945 .38622 m .29274 .38437 L .29546 .38351 L F
.66338 .39023 m .66488 .38738 L .66629 .38907 L 0 .037 .139 r
F
.66338 .39023 m .66198 .38855 L .66488 .38738 L F
.6995 .38828 m .70107 .38559 L .70243 .38728 L 0 .033 .134 r
F
.6995 .38828 m .69813 .38656 L .70107 .38559 L F
.22794 .38508 m .22881 .38235 L .23062 .38416 L 0 .026 .125 r
F
.22794 .38508 m .22612 .38326 L .22881 .38235 L F
.84552 .3851 m .84729 .38231 L .84852 .38406 L F
.84552 .3851 m .84429 .38336 L .84729 .38231 L F
.70673 .38792 m .7083 .38524 L .70966 .38687 L 0 .032 .133 r
F
.70673 .38792 m .70537 .38627 L .7083 .38524 L F
.7978 .38531 m .7995 .38249 L .80078 .38428 L 0 .027 .126 r
F
.7978 .38531 m .79652 .38352 L .7995 .38249 L F
.50316 .40655 m .50443 .40433 L .50599 .40584 L 0 .085 .184 r
F
.50316 .40655 m .50159 .40506 L .50443 .40433 L F
.71395 .38752 m .71553 .38478 L .71689 .3865 L 0 .031 .132 r
F
.71395 .38752 m .7126 .38583 L .71553 .38478 L F
.9077 .38412 m .90955 .38131 L .91073 .38311 L 0 .024 .123 r
F
.9077 .38412 m .90652 .38231 L .90955 .38131 L F
.18743 .38492 m .18825 .38213 L .1901 .38394 L 0 .026 .125 r
F
.18743 .38492 m .18558 .38309 L .18825 .38213 L F
.37265 .38933 m .37374 .38648 L .37542 .38837 L 0 .035 .137 r
F
.37265 .38933 m .37097 .38745 L .37374 .38648 L F
.45235 .39716 m .45353 .39508 L .45515 .39673 L 0 .057 .159 r
F
.45235 .39716 m .45074 .39551 L .45353 .39508 L F
.32054 .38736 m .32154 .38473 L .32328 .38646 L 0 .031 .132 r
F
.32054 .38736 m .3188 .38561 L .32154 .38473 L F
.60275 .39617 m .60417 .39335 L .60563 .39492 L 0 .052 .155 r
F
.60275 .39617 m .60129 .3946 L .60417 .39335 L F
.41031 .39217 m .41144 .38973 L .41308 .3916 L 0 .043 .145 r
F
.41031 .39217 m .40866 .39032 L .41144 .38973 L F
.39148 .39078 m .39258 .38813 L .39425 .38985 L 0 .039 .141 r
F
.39148 .39078 m .38981 .38907 L .39258 .38813 L F
.85276 .38479 m .85455 .38211 L .85577 .38384 L 0 .026 .125 r
F
.85276 .38479 m .85153 .38305 L .85455 .38211 L F
.26843 .38542 m .26935 .38279 L .27113 .3846 L 0 .027 .127 r
F
.26843 .38542 m .26665 .3836 L .26935 .38279 L F
.46395 .39907 m .46515 .39748 L .46675 .39889 L 0 .063 .165 r
F
.46395 .39907 m .46235 .3976 L .46515 .39748 L F
.64172 .39166 m .64319 .38893 L .64462 .39066 L 0 .041 .143 r
F
.64172 .39166 m .64029 .38997 L .64319 .38893 L F
.48717 .40268 m .48841 .40076 L .48998 .4024 L 0 .074 .174 r
F
.48717 .40268 m .48559 .40103 L .48841 .40076 L F
.91494 .38386 m .91681 .38106 L .91798 .38283 L 0 .024 .122 r
F
.91494 .38386 m .91377 .38208 L .91681 .38106 L F
.80504 .38507 m .80676 .38238 L .80803 .38416 L 0 .027 .126 r
F
.80504 .38507 m .80376 .3833 L .80676 .38238 L F
.42191 .3941 m .42306 .39163 L .42469 .39338 L 0 .048 .15 r
F
.42191 .3941 m .42027 .39236 L .42306 .39163 L F
.47556 .40093 m .47678 .39909 L .47837 .40041 L 0 .069 .17 r
F
.47556 .40093 m .47397 .39958 L .47678 .39909 L F
.34659 .38851 m .34764 .38566 L .34934 .38749 L 0 .034 .135 r
F
.34659 .38851 m .34488 .38665 L .34764 .38566 L F
.19463 .38474 m .19545 .382 L .19731 .38378 L 0 .026 .125 r
F
.19463 .38474 m .19278 .38295 L .19545 .382 L F
.65617 .39095 m .65766 .38799 L .65907 .38973 L 0 .039 .141 r
F
.65617 .39095 m .65476 .38921 L .65766 .38799 L F
.72119 .38736 m .72279 .38467 L .72414 .38645 L 0 .031 .132 r
F
.72119 .38736 m .71984 .38558 L .72279 .38467 L F
.39869 .39061 m .39981 .38807 L .40147 .38981 L 0 .039 .141 r
F
.39869 .39061 m .39703 .38892 L .39981 .38807 L F
.23513 .38502 m .23601 .38226 L .23783 .38403 L 0 .026 .126 r
F
.23513 .38502 m .23331 .38324 L .23601 .38226 L F
.64895 .39145 m .65043 .38862 L .65186 .39042 L 0 .041 .143 r
F
.64895 .39145 m .64753 .38968 L .65043 .38862 L F
.32775 .38727 m .32877 .38439 L .33049 .38626 L 0 .031 .131 r
F
.32775 .38727 m .32602 .38543 L .32877 .38439 L F
.86001 .38466 m .8618 .38187 L .86302 .38364 L 0 .026 .125 r
F
.86001 .38466 m .85879 .38289 L .8618 .38187 L F
.5176 .40611 m .5189 .4043 L .52044 .40527 L 0 .086 .184 r
F
.5176 .40611 m .51605 .4051 L .5189 .4043 L F
.37986 .38932 m .38095 .38664 L .38262 .38854 L 0 .036 .137 r
F
.37986 .38932 m .37818 .38742 L .38095 .38664 L F
.3538 .38834 m .35485 .38562 L .35655 .38741 L 0 .034 .135 r
F
.3538 .38834 m .3521 .38653 L .35485 .38562 L F
.24234 .38474 m .24323 .38206 L .24504 .38377 L 0 .026 .125 r
F
.24234 .38474 m .24053 .38302 L .24323 .38206 L F
.30168 .38635 m .30266 .38362 L .30441 .38547 L 0 .029 .129 r
F
.30168 .38635 m .29994 .3845 L .30266 .38362 L F
.63451 .39238 m .63597 .38972 L .6374 .39118 L 0 .044 .146 r
F
.63451 .39238 m .63308 .39094 L .63597 .38972 L F
.81229 .38498 m .81402 .38231 L .81528 .38404 L 0 .027 .126 r
F
.81229 .38498 m .81102 .38324 L .81402 .38231 L F
.52483 .40583 m .52613 .40465 L .52767 .40547 L 0 .087 .185 r
F
.52483 .40583 m .52329 .40495 L .52613 .40465 L F
.86725 .38439 m .86904 .38153 L .87026 .38334 L 0 .025 .124 r
F
.86725 .38439 m .86603 .38258 L .86904 .38153 L F
.73566 .3868 m .73727 .38404 L .73861 .38579 L 0 .03 .131 r
F
.73566 .3868 m .73432 .38505 L .73727 .38404 L F
.59554 .39703 m .59695 .39454 L .59841 .39582 L 0 .056 .159 r
F
.59554 .39703 m .59407 .39573 L .59695 .39454 L F
.51038 .40665 m .51166 .40446 L .51321 .4059 L 0 .087 .185 r
F
.51038 .40665 m .50882 .40513 L .51166 .40446 L F
.44073 .39583 m .4419 .3936 L .44353 .39517 L 0 .054 .156 r
F
.44073 .39583 m .43911 .39429 L .4419 .3936 L F
.20183 .38464 m .20265 .38201 L .2045 .38375 L 0 .026 .125 r
F
.20183 .38464 m .19998 .3829 L .20265 .38201 L F
.72844 .38726 m .73003 .38435 L .73138 .38615 L 0 .031 .132 r
F
.72844 .38726 m .72709 .38547 L .73003 .38435 L F
.27562 .38547 m .27655 .38278 L .27833 .3845 L 0 .028 .127 r
F
.27562 .38547 m .27384 .38373 L .27655 .38278 L F
.5465 .40477 m .54785 .40279 L .54936 .40366 L 0 .081 .181 r
F
.5465 .40477 m .54499 .40387 L .54785 .40279 L F
.74289 .38655 m .74452 .38383 L .74585 .38555 L 0 .03 .13 r
F
.74289 .38655 m .74156 .38481 L .74452 .38383 L F
.42912 .39419 m .43027 .39206 L .4319 .39361 L 0 .05 .152 r
F
.42912 .39419 m .42748 .39265 L .43027 .39206 L F
.75735 .38579 m .75898 .3829 L .7603 .38473 L 0 .028 .128 r
F
.75735 .38579 m .75602 .38398 L .75898 .3829 L F
.75012 .38619 m .75175 .38336 L .75307 .38508 L 0 .029 .129 r
F
.75012 .38619 m .7488 .38446 L .75175 .38336 L F
.8745 .38419 m .87631 .3814 L .87752 .38323 L 0 .025 .124 r
F
.8745 .38419 m .87328 .38237 L .87631 .3814 L F
.24955 .3846 m .25043 .38204 L .25224 .38372 L 0 .026 .125 r
F
.24955 .3846 m .24774 .3829 L .25043 .38204 L F
.81953 .3848 m .82128 .38213 L .82253 .38382 L 0 .027 .126 r
F
.81953 .3848 m .81828 .38309 L .82128 .38213 L F
.28283 .38521 m .28377 .38265 L .28555 .38433 L 0 .028 .127 r
F
.28283 .38521 m .28105 .38352 L .28377 .38265 L F
.62729 .39308 m .62875 .39063 L .63019 .39207 L 0 .046 .149 r
F
.62729 .39308 m .62586 .39161 L .62875 .39063 L F
.36101 .38828 m .36207 .38555 L .36376 .38738 L 0 .034 .135 r
F
.36101 .38828 m .35931 .38648 L .36207 .38555 L F
.33494 .3873 m .33597 .38464 L .33768 .38654 L 0 .032 .133 r
F
.33494 .3873 m .33323 .38542 L .33597 .38464 L F
.20903 .38449 m .20987 .3818 L .21171 .3835 L 0 .026 .125 r
F
.20903 .38449 m .20718 .38279 L .20987 .3818 L F
.61284 .39391 m .61428 .39131 L .61573 .39291 L 0 .048 .151 r
F
.61284 .39391 m .61139 .39233 L .61428 .39131 L F
.62007 .39353 m .62152 .39104 L .62296 .39259 L 0 .047 .15 r
F
.62007 .39353 m .61862 .39198 L .62152 .39104 L F
.76458 .38552 m .76623 .3827 L .76755 .38454 L 0 .028 .128 r
F
.76458 .38552 m .76326 .38367 L .76623 .3827 L F
.82677 .38455 m .82852 .38177 L .82977 .38355 L 0 .026 .125 r
F
.82677 .38455 m .82552 .3828 L .82852 .38177 L F
.30888 .38637 m .30987 .38367 L .31161 .38545 L 0 .03 .13 r
F
.30888 .38637 m .30714 .38457 L .30987 .38367 L F
.21624 .3842 m .21709 .38157 L .21893 .38327 L 0 .026 .125 r
F
.21624 .3842 m .2144 .38251 L .21709 .38157 L F
.57825 .40085 m .57964 .39863 L .58112 .39957 L 0 .069 .17 r
F
.57825 .40085 m .57678 .39996 L .57964 .39863 L F
.88175 .38404 m .88357 .38125 L .88477 .38302 L 0 .025 .124 r
F
.88175 .38404 m .88054 .38225 L .88357 .38125 L F
.53205 .40589 m .53337 .40468 L .5349 .40541 L 0 .088 .186 r
F
.53205 .40589 m .53052 .40509 L .53337 .40468 L F
.48277 .4013 m .484 .39978 L .48559 .40103 L 0 .072 .173 r
F
.48277 .4013 m .48119 .40001 L .484 .39978 L F
.49877 .40532 m .50003 .4035 L .50159 .40506 L 0 .084 .183 r
F
.49877 .40532 m .4972 .40374 L .50003 .4035 L F
.40589 .39093 m .40701 .38849 L .40866 .39032 L 0 .041 .143 r
F
.40589 .39093 m .40424 .38915 L .40701 .38849 L F
.88899 .38373 m .89082 .38096 L .89201 .3827 L 0 .025 .123 r
F
.88899 .38373 m .88779 .38199 L .89082 .38096 L F
.68795 .38756 m .6895 .38484 L .69088 .38661 L 0 .033 .134 r
F
.68795 .38756 m .68657 .38581 L .6895 .38484 L F
.77183 .38536 m .77349 .38257 L .77479 .38434 L 0 .028 .128 r
F
.77183 .38536 m .77052 .38357 L .77349 .38257 L F
.25674 .38456 m .25766 .38177 L .25945 .38356 L 0 .026 .125 r
F
.25674 .38456 m .25495 .38277 L .25766 .38177 L F
.77905 .38499 m .78072 .38216 L .78202 .38389 L 0 .027 .127 r
F
.77905 .38499 m .77776 .38325 L .78072 .38216 L F
.83402 .3844 m .83578 .3817 L .83703 .3835 L 0 .026 .125 r
F
.83402 .3844 m .83277 .3826 L .83578 .3817 L F
.45955 .39784 m .46074 .39612 L .46235 .3976 L 0 .061 .163 r
F
.45955 .39784 m .45794 .3963 L .46074 .39612 L F
.29003 .38522 m .29098 .38262 L .29274 .38437 L 0 .028 .128 r
F
.29003 .38522 m .28826 .38347 L .29098 .38262 L F
.78628 .38462 m .78798 .38199 L .78927 .38369 L 0 .027 .126 r
F
.78628 .38462 m .785 .38291 L .78798 .38199 L F
.89622 .38344 m .89807 .38066 L .89925 .38243 L 0 .024 .123 r
F
.89622 .38344 m .89504 .38167 L .89807 .38066 L F
.58833 .39809 m .58973 .3958 L .5912 .39691 L 0 .061 .163 r
F
.58833 .39809 m .58686 .39705 L .58973 .3958 L F
.44794 .3961 m .44912 .39387 L .45074 .39551 L 0 .055 .158 r
F
.44794 .3961 m .44632 .39449 L .44912 .39387 L F
.41749 .39293 m .41863 .39044 L .42027 .39236 L 0 .046 .149 r
F
.41749 .39293 m .41585 .39104 L .41863 .39044 L F
.68073 .38812 m .68226 .38524 L .68365 .38696 L 0 .034 .135 r
F
.68073 .38812 m .67934 .3864 L .68226 .38524 L F
.36821 .38834 m .36929 .38557 L .37097 .38745 L 0 .035 .136 r
F
.36821 .38834 m .36652 .38648 L .36929 .38557 L F
.67351 .38855 m .67503 .38589 L .67643 .3875 L 0 .035 .137 r
F
.67351 .38855 m .67211 .3869 L .67503 .38589 L F
.38705 .38976 m .38814 .38719 L .38981 .38907 L 0 .038 .14 r
F
.38705 .38976 m .38538 .38787 L .38814 .38719 L F
.22343 .38417 m .2243 .38143 L .22612 .38326 L 0 .026 .125 r
F
.22343 .38417 m .22161 .38234 L .2243 .38143 L F
.55658 .40243 m .55794 .4004 L .55944 .4015 L 0 .075 .175 r
F
.55658 .40243 m .55507 .40134 L .55794 .4004 L F
.26395 .3844 m .26486 .38178 L .26665 .3836 L 0 .027 .126 r
F
.26395 .3844 m .26216 .38257 L .26486 .38178 L F
.31608 .38642 m .31706 .38388 L .3188 .38561 L 0 .031 .131 r
F
.31608 .38642 m .31434 .38467 L .31706 .38388 L F
.53928 .40588 m .54061 .40404 L .54213 .40495 L 0 .087 .185 r
F
.53928 .40588 m .53776 .40494 L .54061 .40404 L F
.56381 .40207 m .56518 .40006 L .56667 .40133 L 0 .074 .174 r
F
.56381 .40207 m .56231 .40078 L .56518 .40006 L F
.66629 .38907 m .66779 .38622 L .6692 .38791 L 0 .036 .138 r
F
.66629 .38907 m .66488 .38738 L .66779 .38622 L F
.6952 .38748 m .69675 .38478 L .69813 .38656 L 0 .033 .134 r
F
.6952 .38748 m .69382 .3857 L .69675 .38478 L F
.90348 .38328 m .90533 .3805 L .90652 .38231 L 0 .024 .123 r
F
.90348 .38328 m .90229 .38147 L .90533 .3805 L F
.60563 .39492 m .60705 .39205 L .60851 .39363 L 0 .051 .154 r
F
.60563 .39492 m .60417 .39335 L .60705 .39205 L F
.57103 .40177 m .57242 .39971 L .5739 .40093 L 0 .073 .174 r
F
.57103 .40177 m .56954 .40053 L .57242 .39971 L F
.79354 .38455 m .79523 .38173 L .79652 .38352 L 0 .027 .126 r
F
.79354 .38455 m .79225 .38276 L .79523 .38173 L F
.84129 .38439 m .84305 .38156 L .84429 .38336 L 0 .026 .126 r
F
.84129 .38439 m .84005 .38261 L .84305 .38156 L F
.47116 .40007 m .47237 .39823 L .47397 .39958 L 0 .068 .17 r
F
.47116 .40007 m .46956 .3987 L .47237 .39823 L F
.34213 .38765 m .34317 .38478 L .34488 .38665 L 0 .033 .134 r
F
.34213 .38765 m .34042 .38575 L .34317 .38478 L F
.84852 .38406 m .8503 .3813 L .85153 .38305 L 0 .026 .125 r
F
.84852 .38406 m .84729 .38231 L .8503 .3813 L F
.70966 .38687 m .71124 .38419 L .7126 .38583 L 0 .032 .133 r
F
.70966 .38687 m .7083 .38524 L .71124 .38419 L F
.70243 .38728 m .704 .38462 L .70537 .38627 L 0 .033 .134 r
F
.70243 .38728 m .70107 .38559 L .704 .38462 L F
.80078 .38428 m .80248 .38151 L .80376 .3833 L 0 .026 .126 r
F
.80078 .38428 m .7995 .38249 L .80248 .38151 L F
.71689 .3865 m .71848 .38386 L .71984 .38558 L 0 .031 .132 r
F
.71689 .3865 m .71553 .38478 L .71848 .38386 L F
.43632 .39472 m .43748 .39272 L .43911 .39429 L 0 .053 .155 r
F
.43632 .39472 m .43469 .39316 L .43748 .39272 L F
.91073 .38311 m .91259 .38027 L .91377 .38208 L 0 .024 .122 r
F
.91073 .38311 m .90955 .38131 L .91259 .38027 L F
.65907 .38973 m .66056 .3868 L .66198 .38855 L 0 .038 .14 r
F
.65907 .38973 m .65766 .38799 L .66056 .3868 L F
.1901 .38394 m .19092 .38116 L .19278 .38295 L 0 .026 .125 r
F
.1901 .38394 m .18825 .38213 L .19092 .38116 L F
.29721 .38536 m .29819 .38264 L .29994 .3845 L 0 .029 .129 r
F
.29721 .38536 m .29546 .38351 L .29819 .38264 L F
.23062 .38416 m .2315 .38144 L .23331 .38324 L 0 .026 .125 r
F
.23062 .38416 m .22881 .38235 L .2315 .38144 L F
.37542 .38837 m .37651 .38551 L .37818 .38742 L 0 .035 .136 r
F
.37542 .38837 m .37374 .38648 L .37651 .38551 L F
.39425 .38985 m .39536 .38718 L .39703 .38892 L 0 .039 .141 r
F
.39425 .38985 m .39258 .38813 L .39536 .38718 L F
.49438 .40388 m .49563 .4021 L .4972 .40374 L 0 .081 .18 r
F
.49438 .40388 m .4928 .40224 L .49563 .4021 L F
.85577 .38384 m .85757 .38117 L .85879 .38289 L 0 .026 .125 r
F
.85577 .38384 m .85455 .38211 L .85757 .38117 L F
.64462 .39066 m .6461 .3879 L .64753 .38968 L 0 .041 .143 r
F
.64462 .39066 m .64319 .38893 L .6461 .3879 L F
.32328 .38646 m .32429 .38371 L .32602 .38543 L 0 .031 .132 r
F
.32328 .38646 m .32154 .38473 L .32429 .38371 L F
.34934 .38749 m .35039 .38471 L .3521 .38653 L 0 .033 .134 r
F
.34934 .38749 m .34764 .38566 L .35039 .38471 L F
.80803 .38416 m .80975 .38147 L .81102 .38324 L 0 .027 .126 r
F
.80803 .38416 m .80676 .38238 L .80975 .38147 L F
.6374 .39118 m .63887 .38849 L .64029 .38997 L 0 .042 .145 r
F
.6374 .39118 m .63597 .38972 L .63887 .38849 L F
.19731 .38378 m .19812 .38113 L .19998 .3829 L 0 .026 .125 r
F
.19731 .38378 m .19545 .382 L .19812 .38113 L F
.59841 .39582 m .59983 .39334 L .60129 .3946 L 0 .055 .158 r
F
.59841 .39582 m .59695 .39454 L .59983 .39334 L F
.50599 .40584 m .50726 .40361 L .50882 .40513 L 0 .087 .185 r
F
.50599 .40584 m .50443 .40433 L .50726 .40361 L F
.65186 .39042 m .65334 .38741 L .65476 .38921 L 0 .04 .142 r
F
.65186 .39042 m .65043 .38862 L .65334 .38741 L F
.27113 .3846 m .27206 .38194 L .27384 .38373 L 0 .028 .127 r
F
.27113 .3846 m .26935 .38279 L .27206 .38194 L F
.23783 .38403 m .23872 .38127 L .24053 .38302 L 0 .026 .125 r
F
.23783 .38403 m .23601 .38226 L .23872 .38127 L F
.86302 .38364 m .86481 .38081 L .86603 .38258 L 0 .025 .124 r
F
.86302 .38364 m .8618 .38187 L .86481 .38081 L F
.72414 .38645 m .72573 .38367 L .72709 .38547 L 0 .031 .132 r
F
.72414 .38645 m .72279 .38467 L .72573 .38367 L F
.33049 .38626 m .33151 .38353 L .33323 .38542 L F
.33049 .38626 m .32877 .38439 L .33151 .38353 L F
.87026 .38334 m .87206 .38055 L .87328 .38237 L 0 .025 .124 r
F
.87026 .38334 m .86904 .38153 L .87206 .38055 L F
.73138 .38615 m .73297 .38322 L .73432 .38505 L 0 .031 .131 r
F
.73138 .38615 m .73003 .38435 L .73297 .38322 L F
.42469 .39338 m .42585 .3909 L .42748 .39265 L 0 .049 .151 r
F
.42469 .39338 m .42306 .39163 L .42585 .3909 L F
.24504 .38377 m .24592 .38121 L .24774 .3829 L 0 .026 .125 r
F
.24504 .38377 m .24323 .38206 L .24592 .38121 L F
.41308 .3916 m .41421 .38914 L .41585 .39104 L 0 .044 .147 r
F
.41308 .3916 m .41144 .38973 L .41421 .38914 L F
.73861 .38579 m .74023 .38307 L .74156 .38481 L 0 .03 .13 r
F
.73861 .38579 m .73727 .38404 L .74023 .38307 L F
.40147 .38981 m .40258 .38737 L .40424 .38915 L 0 .04 .142 r
F
.40147 .38981 m .39981 .38807 L .40258 .38737 L F
.35655 .38741 m .35761 .3847 L .35931 .38648 L 0 .034 .135 r
F
.35655 .38741 m .35485 .38562 L .35761 .3847 L F
.54936 .40366 m .5507 .40165 L .55221 .4025 L 0 .08 .18 r
F
.54936 .40366 m .54785 .40279 L .5507 .40165 L F
.52044 .40527 m .52174 .40408 L .52329 .40495 L 0 .088 .186 r
F
.52044 .40527 m .5189 .4043 L .52174 .40408 L F
.81528 .38404 m .81702 .38138 L .81828 .38309 L 0 .027 .126 r
F
.81528 .38404 m .81402 .38231 L .81702 .38138 L F
.30441 .38547 m .30539 .38273 L .30714 .38457 L 0 .03 .13 r
F
.30441 .38547 m .30266 .38362 L .30539 .38273 L F
.75307 .38508 m .7547 .38226 L .75602 .38398 L 0 .029 .128 r
F
.75307 .38508 m .75175 .38336 L .7547 .38226 L F
.27833 .3845 m .27927 .38183 L .28105 .38352 L 0 .028 .127 r
F
.27833 .3845 m .27655 .38278 L .27927 .38183 L F
.45515 .39673 m .45634 .39465 L .45794 .3963 L 0 .059 .161 r
F
.45515 .39673 m .45353 .39508 L .45634 .39465 L F
.7603 .38473 m .76194 .38181 L .76326 .38367 L 0 .028 .127 r
F
.7603 .38473 m .75898 .3829 L .76194 .38181 L F
.38262 .38854 m .38371 .38597 L .38538 .38787 L 0 .037 .138 r
F
.38262 .38854 m .38095 .38664 L .38371 .38597 L F
.58112 .39957 m .58251 .3973 L .58399 .3983 L 0 .067 .169 r
F
.58112 .39957 m .57964 .39863 L .58251 .3973 L F
.2045 .38375 m .20533 .38106 L .20718 .38279 L 0 .026 .125 r
F
.2045 .38375 m .20265 .38201 L .20533 .38106 L F
.74585 .38555 m .74747 .38275 L .7488 .38446 L 0 .03 .13 r
F
.74585 .38555 m .74452 .38383 L .74747 .38275 L F
.47837 .40041 m .47959 .39873 L .48119 .40001 L 0 .071 .172 r
F
.47837 .40041 m .47678 .39909 L .47959 .39873 L F
.82253 .38382 m .82427 .38111 L .82552 .3828 L 0 .026 .126 r
F
.82253 .38382 m .82128 .38213 L .82427 .38111 L F
.87752 .38323 m .87933 .38042 L .88054 .38225 L 0 .025 .124 r
F
.87752 .38323 m .87631 .3814 L .87933 .38042 L F
.51321 .4059 m .5145 .40382 L .51605 .4051 L 0 .088 .186 r
F
.51321 .4059 m .51166 .40446 L .5145 .40382 L F
.63019 .39207 m .63165 .38951 L .63308 .39094 L 0 .046 .148 r
F
.63019 .39207 m .62875 .39063 L .63165 .38951 L F
.61573 .39291 m .61717 .39035 L .61862 .39198 L 0 .048 .15 r
F
.61573 .39291 m .61428 .39131 L .61717 .39035 L F
.21171 .3835 m .21255 .38082 L .2144 .38251 L 0 .026 .125 r
F
.21171 .3835 m .20987 .3818 L .21255 .38082 L F
.25224 .38372 m .25314 .38108 L .25495 .38277 L 0 .026 .126 r
F
.25224 .38372 m .25043 .38204 L .25314 .38108 L F
.28555 .38433 m .28649 .3818 L .28826 .38347 L 0 .028 .127 r
F
.28555 .38433 m .28377 .38265 L .28649 .3818 L F
.76755 .38454 m .7692 .38173 L .77052 .38357 L F
.76755 .38454 m .76623 .3827 L .7692 .38173 L F
.44353 .39517 m .4447 .39288 L .44632 .39449 L 0 .055 .157 r
F
.44353 .39517 m .4419 .3936 L .4447 .39288 L F
.82977 .38355 m .83152 .38081 L .83277 .3826 L 0 .026 .125 r
F
.82977 .38355 m .82852 .38177 L .83152 .38081 L F
.48998 .4024 m .49123 .4006 L .4928 .40224 L 0 .077 .178 r
F
.48998 .4024 m .48841 .40076 L .49123 .4006 L F
.62296 .39259 m .62442 .39009 L .62586 .39161 L 0 .047 .15 r
F
.62296 .39259 m .62152 .39104 L .62442 .39009 L F
.36376 .38738 m .36483 .38463 L .36652 .38648 L 0 .034 .135 r
F
.36376 .38738 m .36207 .38555 L .36483 .38463 L F
.88477 .38302 m .8866 .38024 L .88779 .38199 L 0 .025 .124 r
F
.88477 .38302 m .88357 .38125 L .8866 .38024 L F
.31161 .38545 m .31259 .3829 L .31434 .38467 L 0 .03 .131 r
F
.31161 .38545 m .30987 .38367 L .31259 .3829 L F
.46675 .39889 m .46795 .39733 L .46956 .3987 L 0 .067 .169 r
F
.46675 .39889 m .46515 .39748 L .46795 .39733 L F
.21893 .38327 m .21977 .38062 L .22161 .38234 L 0 .026 .125 r
F
.21893 .38327 m .21709 .38157 L .21977 .38062 L F
.5912 .39691 m .59261 .39456 L .59407 .39573 L 0 .06 .162 r
F
.5912 .39691 m .58973 .3958 L .59261 .39456 L F
.78202 .38389 m .7837 .3812 L .785 .38291 L 0 .027 .126 r
F
.78202 .38389 m .78072 .38216 L .7837 .3812 L F
.89201 .3827 m .89385 .37994 L .89504 .38167 L 0 .024 .123 r
F
.89201 .3827 m .89082 .38096 L .89385 .37994 L F
.33768 .38654 m .33871 .38384 L .34042 .38575 L 0 .033 .133 r
F
.33768 .38654 m .33597 .38464 L .33871 .38384 L F
.77479 .38434 m .77646 .38149 L .77776 .38325 L 0 .028 .127 r
F
.77479 .38434 m .77349 .38257 L .77646 .38149 L F
.68365 .38696 m .68518 .38408 L .68657 .38581 L 0 .033 .134 r
F
.68365 .38696 m .68226 .38524 L .68518 .38408 L F
.25945 .38356 m .26037 .38079 L .26216 .38257 L 0 .026 .125 r
F
.25945 .38356 m .25766 .38177 L .26037 .38079 L F
.4319 .39361 m .43305 .3916 L .43469 .39316 L 0 .051 .154 r
F
.4319 .39361 m .43027 .39206 L .43305 .3916 L F
.60851 .39363 m .60993 .39075 L .61139 .39233 L 0 .05 .152 r
F
.60851 .39363 m .60705 .39205 L .60993 .39075 L F
.69088 .38661 m .69243 .38391 L .69382 .3857 L 0 .033 .134 r
F
.69088 .38661 m .6895 .38484 L .69243 .38391 L F
.52767 .40547 m .52898 .40433 L .53052 .40509 L 0 .09 .187 r
F
.52767 .40547 m .52613 .40465 L .52898 .40433 L F
.89925 .38243 m .90111 .37971 L .90229 .38147 L 0 .024 .122 r
F
.89925 .38243 m .89807 .38066 L .90111 .37971 L F
.67643 .3875 m .67796 .38482 L .67934 .3864 L 0 .035 .136 r
F
.67643 .3875 m .67503 .38589 L .67796 .38482 L F
.78927 .38369 m .79097 .38107 L .79225 .38276 L 0 .027 .126 r
F
.78927 .38369 m .78798 .38199 L .79097 .38107 L F
.6692 .38791 m .67072 .38524 L .67211 .3869 L 0 .036 .137 r
F
.6692 .38791 m .66779 .38622 L .67072 .38524 L F
.83703 .3835 m .8388 .3808 L .84005 .38261 L 0 .026 .125 r
F
.83703 .3835 m .83578 .3817 L .8388 .3808 L F
.29274 .38437 m .2937 .38176 L .29546 .38351 L 0 .028 .128 r
F
.29274 .38437 m .29098 .38262 L .2937 .38176 L F
.37097 .38745 m .37206 .38458 L .37374 .38648 L 0 .035 .136 r
F
.37097 .38745 m .36929 .38557 L .37206 .38458 L F
.55944 .4015 m .56081 .39968 L .56231 .40078 L 0 .075 .176 r
F
.55944 .4015 m .55794 .4004 L .56081 .39968 L F
.22612 .38326 m .22699 .38054 L .22881 .38235 L 0 .026 .125 r
F
.22612 .38326 m .2243 .38143 L .22699 .38054 L F
.54213 .40495 m .54347 .40298 L .54499 .40387 L 0 .086 .185 r
F
.54213 .40495 m .54061 .40404 L .54347 .40298 L F
.18558 .38309 m .18638 .38039 L .18825 .38213 L 0 .026 .125 r
F
.18558 .38309 m .18371 .38137 L .18638 .38039 L F
.40866 .39032 m .40979 .38787 L .41144 .38973 L 0 .042 .145 r
F
.40866 .39032 m .40701 .38849 L .40979 .38787 L F
.90652 .38231 m .90837 .37949 L .90955 .38131 L 0 .024 .122 r
F
.90652 .38231 m .90533 .3805 L .90837 .37949 L F
.79652 .38352 m .79821 .3807 L .7995 .38249 L 0 .027 .126 r
F
.79652 .38352 m .79523 .38173 L .79821 .3807 L F
.66198 .38855 m .66347 .38562 L .66488 .38738 L 0 .037 .139 r
F
.66198 .38855 m .66056 .3868 L .66347 .38562 L F
.5349 .40541 m .53623 .40426 L .53776 .40494 L 0 .09 .188 r
F
.5349 .40541 m .53337 .40468 L .53623 .40426 L F
.69813 .38656 m .69969 .38383 L .70107 .38559 L 0 .033 .134 r
F
.69813 .38656 m .69675 .38478 L .69969 .38383 L F
.84429 .38336 m .84605 .38051 L .84729 .38231 L 0 .026 .125 r
F
.84429 .38336 m .84305 .38156 L .84605 .38051 L F
.26665 .3836 m .26757 .38098 L .26935 .38279 L 0 .027 .126 r
F
.26665 .3836 m .26486 .38178 L .26757 .38098 L F
.3188 .38561 m .3198 .38302 L .32154 .38473 L 0 .031 .132 r
F
.3188 .38561 m .31706 .38388 L .3198 .38302 L F
.7126 .38583 m .71418 .38314 L .71553 .38478 L 0 .032 .132 r
F
.7126 .38583 m .71124 .38419 L .71418 .38314 L F
.34488 .38665 m .34593 .38381 L .34764 .38566 L 0 .033 .134 r
F
.34488 .38665 m .34317 .38478 L .34593 .38381 L F
.85153 .38305 m .85332 .38038 L .85455 .38211 L 0 .026 .125 r
F
.85153 .38305 m .8503 .3813 L .85332 .38038 L F
.38981 .38907 m .39092 .38628 L .39258 .38813 L 0 .039 .141 r
F
.38981 .38907 m .38814 .38719 L .39092 .38628 L F
.70537 .38627 m .70694 .3836 L .7083 .38524 L 0 .033 .134 r
F
.70537 .38627 m .704 .38462 L .70694 .3836 L F
.45074 .39551 m .45192 .39341 L .45353 .39508 L 0 .057 .16 r
F
.45074 .39551 m .44912 .39387 L .45192 .39341 L F
.56667 .40133 m .56805 .39928 L .56954 .40053 L 0 .075 .175 r
F
.56667 .40133 m .56518 .40006 L .56805 .39928 L F
.5739 .40093 m .57529 .39876 L .57678 .39996 L 0 .073 .174 r
F
.5739 .40093 m .57242 .39971 L .57529 .39876 L F
.91377 .38208 m .91563 .37924 L .91681 .38106 L 0 .024 .122 r
F
.91377 .38208 m .91259 .38027 L .91563 .37924 L F
.80376 .3833 m .80548 .38058 L .80676 .38238 L 0 .026 .126 r
F
.80376 .3833 m .80248 .38151 L .80548 .38058 L F
.42027 .39236 m .42142 .3897 L .42306 .39163 L 0 .047 .15 r
F
.42027 .39236 m .41863 .39044 L .42142 .3897 L F
.19278 .38295 m .1936 .38022 L .19545 .382 L 0 .026 .125 r
F
.19278 .38295 m .19092 .38116 L .1936 .38022 L F
.64029 .38997 m .64177 .38743 L .64319 .38893 L 0 .042 .144 r
F
.64029 .38997 m .63887 .38849 L .64177 .38743 L F
.60129 .3946 m .60271 .39211 L .60417 .39335 L 0 .054 .156 r
F
.60129 .3946 m .59983 .39334 L .60271 .39211 L F
.71984 .38558 m .72143 .38294 L .72279 .38467 L 0 .031 .132 r
F
.71984 .38558 m .71848 .38386 L .72143 .38294 L F
.48559 .40103 m .48682 .39954 L .48841 .40076 L 0 .075 .176 r
F
.48559 .40103 m .484 .39978 L .48682 .39954 L F
.65476 .38921 m .65624 .38621 L .65766 .38799 L 0 .039 .141 r
F
.65476 .38921 m .65334 .38741 L .65624 .38621 L F
.50159 .40506 m .50286 .40285 L .50443 .40433 L 0 .087 .185 r
F
.50159 .40506 m .50003 .4035 L .50286 .40285 L F
.37818 .38742 m .37927 .38473 L .38095 .38664 L 0 .035 .137 r
F
.37818 .38742 m .37651 .38551 L .37927 .38473 L F
.32602 .38543 m .32704 .38268 L .32877 .38439 L 0 .031 .131 r
F
.32602 .38543 m .32429 .38371 L .32704 .38268 L F
.23331 .38324 m .2342 .38047 L .23601 .38226 L 0 .026 .125 r
F
.23331 .38324 m .2315 .38144 L .2342 .38047 L F
.64753 .38968 m .64901 .38682 L .65043 .38862 L 0 .041 .143 r
F
.64753 .38968 m .6461 .3879 L .64901 .38682 L F
.85879 .38289 m .86058 .38016 L .8618 .38187 L 0 .026 .125 r
F
.85879 .38289 m .85757 .38117 L .86058 .38016 L F
.29994 .3845 m .30091 .38177 L .30266 .38362 L 0 .029 .129 r
F
.29994 .3845 m .29819 .38264 L .30091 .38177 L F
.39703 .38892 m .39814 .38632 L .39981 .38807 L 0 .039 .141 r
F
.39703 .38892 m .39536 .38718 L .39814 .38632 L F
.3521 .38653 m .35315 .38382 L .35485 .38562 L 0 .034 .135 r
F
.3521 .38653 m .35039 .38471 L .35315 .38382 L F
.46235 .3976 m .46354 .39606 L .46515 .39748 L 0 .065 .167 r
F
.46235 .3976 m .46074 .39612 L .46354 .39606 L F
.86603 .38258 m .86782 .37976 L .86904 .38153 L 0 .025 .124 r
F
.86603 .38258 m .86481 .38081 L .86782 .37976 L F
.24053 .38302 m .24142 .38032 L .24323 .38206 L 0 .026 .125 r
F
.24053 .38302 m .23872 .38127 L .24142 .38032 L F
.73432 .38505 m .73592 .38221 L .73727 .38404 L 0 .03 .13 r
F
.73432 .38505 m .73297 .38322 L .73592 .38221 L F
.81102 .38324 m .81275 .38055 L .81402 .38231 L 0 .027 .126 r
F
.81102 .38324 m .80975 .38147 L .81275 .38055 L F
.55221 .4025 m .55357 .40052 L .55507 .40134 L 0 .079 .179 r
F
.55221 .4025 m .5507 .40165 L .55357 .40052 L F
.58399 .3983 m .58539 .39599 L .58686 .39705 L 0 .065 .167 r
F
.58399 .3983 m .58251 .3973 L .58539 .39599 L F
.72709 .38547 m .72868 .38253 L .73003 .38435 L 0 .031 .131 r
F
.72709 .38547 m .72573 .38367 L .72868 .38253 L F
.19998 .3829 m .2008 .38025 L .20265 .38201 L 0 .026 .125 r
F
.19998 .3829 m .19812 .38113 L .2008 .38025 L F
.27384 .38373 m .27477 .38101 L .27655 .38278 L 0 .028 .127 r
F
.27384 .38373 m .27206 .38194 L .27477 .38101 L F
.47397 .39958 m .47518 .39777 L .47678 .39909 L 0 .071 .172 r
F
.47397 .39958 m .47237 .39823 L .47518 .39777 L F
.87328 .38237 m .87509 .37957 L .87631 .3814 L 0 .025 .124 r
F
.87328 .38237 m .87206 .38055 L .87509 .37957 L F
.75602 .38398 m .75766 .38117 L .75898 .3829 L 0 .028 .128 r
F
.75602 .38398 m .7547 .38226 L .75766 .38117 L F
.33323 .38542 m .33425 .38273 L .33597 .38464 L 0 .032 .132 r
F
.33323 .38542 m .33151 .38353 L .33425 .38273 L F
.74156 .38481 m .74318 .38209 L .74452 .38383 L 0 .03 .13 r
F
.74156 .38481 m .74023 .38307 L .74318 .38209 L F
.7488 .38446 m .75043 .38167 L .75175 .38336 L 0 .029 .129 r
F
.7488 .38446 m .74747 .38275 L .75043 .38167 L F
.43911 .39429 m .44027 .39198 L .4419 .3936 L 0 .054 .157 r
F
.43911 .39429 m .43748 .39272 L .44027 .39198 L F
.76326 .38367 m .76491 .38085 L .76623 .3827 L 0 .028 .127 r
F
.76326 .38367 m .76194 .38181 L .76491 .38085 L F
.50882 .40513 m .5101 .40302 L .51166 .40446 L 0 .088 .186 r
F
.50882 .40513 m .50726 .40361 L .5101 .40302 L F
.35931 .38648 m .36037 .38381 L .36207 .38555 L 0 .034 .135 r
F
.35931 .38648 m .35761 .3847 L .36037 .38381 L F
.81828 .38309 m .82002 .38043 L .82128 .38213 L 0 .027 .126 r
F
.81828 .38309 m .81702 .38138 L .82002 .38043 L F
.24774 .3829 m .24862 .38035 L .25043 .38204 L F
.24774 .3829 m .24592 .38121 L .24862 .38035 L F
.28105 .38352 m .28199 .38096 L .28377 .38265 L 0 .028 .127 r
F
.28105 .38352 m .27927 .38183 L .28199 .38096 L F
.63308 .39094 m .63455 .38827 L .63597 .38972 L 0 .045 .147 r
F
.63308 .39094 m .63165 .38951 L .63455 .38827 L F
.30714 .38457 m .30812 .38183 L .30987 .38367 L 0 .03 .13 r
F
.30714 .38457 m .30539 .38273 L .30812 .38183 L F
.20718 .38279 m .20802 .38009 L .20987 .3818 L 0 .026 .125 r
F
.20718 .38279 m .20533 .38106 L .20802 .38009 L F
.82552 .3828 m .82727 .38009 L .82852 .38177 L F
.82552 .3828 m .82427 .38111 L .82727 .38009 L F
.42748 .39265 m .42863 .39032 L .43027 .39206 L 0 .05 .152 r
F
.42748 .39265 m .42585 .3909 L .42863 .39032 L F
.88054 .38225 m .88236 .37943 L .88357 .38125 L 0 .025 .124 r
F
.88054 .38225 m .87933 .38042 L .88236 .37943 L F
.59407 .39573 m .59549 .3934 L .59695 .39454 L 0 .058 .161 r
F
.59407 .39573 m .59261 .39456 L .59549 .3934 L F
.61139 .39233 m .61282 .3897 L .61428 .39131 L 0 .049 .151 r
F
.61139 .39233 m .60993 .39075 L .61282 .3897 L F
.2144 .38251 m .21524 .37986 L .21709 .38157 L 0 .026 .125 r
F
.2144 .38251 m .21255 .38082 L .21524 .37986 L F
.40424 .38915 m .40536 .38666 L .40701 .38849 L 0 .041 .143 r
F
.40424 .38915 m .40258 .38737 L .40536 .38666 L F
.61862 .39198 m .62007 .38939 L .62152 .39104 L 0 .048 .15 r
F
.61862 .39198 m .61717 .39035 L .62007 .38939 L F
.77052 .38357 m .77218 .38075 L .77349 .38257 L 0 .028 .127 r
F
.77052 .38357 m .7692 .38173 L .77218 .38075 L F
.25495 .38277 m .25585 .38009 L .25766 .38177 L 0 .026 .125 r
F
.25495 .38277 m .25314 .38108 L .25585 .38009 L F
.62586 .39161 m .62732 .38913 L .62875 .39063 L 0 .047 .15 r
F
.62586 .39161 m .62442 .39009 L .62732 .38913 L F
.88779 .38199 m .88963 .37922 L .89082 .38096 L 0 .025 .123 r
F
.88779 .38199 m .8866 .38024 L .88963 .37922 L F
.68657 .38581 m .68811 .3831 L .6895 .38484 L 0 .033 .134 r
F
.68657 .38581 m .68518 .38408 L .68811 .3831 L F
.83277 .3826 m .83454 .37991 L .83578 .3817 L 0 .026 .125 r
F
.83277 .3826 m .83152 .38081 L .83454 .37991 L F
.41585 .39104 m .41699 .38853 L .41863 .39044 L 0 .046 .148 r
F
.41585 .39104 m .41421 .38914 L .41699 .38853 L F
.51605 .4051 m .51734 .40317 L .5189 .4043 L 0 .089 .187 r
F
.51605 .4051 m .5145 .40382 L .51734 .40317 L F
.77776 .38325 m .77943 .38042 L .78072 .38216 L 0 .027 .127 r
F
.77776 .38325 m .77646 .38149 L .77943 .38042 L F
.38538 .38787 m .38647 .3853 L .38814 .38719 L 0 .038 .14 r
F
.38538 .38787 m .38371 .38597 L .38647 .3853 L F
.28826 .38347 m .2892 .38095 L .29098 .38262 L 0 .028 .128 r
F
.28826 .38347 m .28649 .3818 L .2892 .38095 L F
.36652 .38648 m .3676 .38369 L .36929 .38557 L 0 .034 .135 r
F
.36652 .38648 m .36483 .38463 L .3676 .38369 L F
.89504 .38167 m .89688 .37893 L .89807 .38066 L 0 .024 .123 r
F
.89504 .38167 m .89385 .37994 L .89688 .37893 L F
.4972 .40374 m .49846 .40189 L .50003 .4035 L 0 .085 .184 r
F
.4972 .40374 m .49563 .4021 L .49846 .40189 L F
.785 .38291 m .78669 .38029 L .78798 .38199 L 0 .027 .126 r
F
.785 .38291 m .7837 .3812 L .78669 .38029 L F
.22161 .38234 m .22246 .3797 L .2243 .38143 L 0 .026 .125 r
F
.22161 .38234 m .21977 .38062 L .22246 .3797 L F
.26216 .38257 m .26307 .37999 L .26486 .38178 L 0 .026 .126 r
F
.26216 .38257 m .26037 .38079 L .26307 .37999 L F
.67934 .3864 m .68088 .38368 L .68226 .38524 L 0 .034 .135 r
F
.67934 .3864 m .67796 .38482 L .68088 .38368 L F
.44632 .39449 m .4475 .39222 L .44912 .39387 L 0 .056 .158 r
F
.44632 .39449 m .4447 .39288 L .4475 .39222 L F
.45794 .3963 m .45914 .39445 L .46074 .39612 L 0 .062 .164 r
F
.45794 .3963 m .45634 .39465 L .45914 .39445 L F
.31434 .38467 m .31532 .38214 L .31706 .38388 L 0 .031 .131 r
F
.31434 .38467 m .31259 .3829 L .31532 .38214 L F
.90229 .38147 m .90415 .37875 L .90533 .3805 L 0 .024 .122 r
F
.90229 .38147 m .90111 .37971 L .90415 .37875 L F
.52329 .40495 m .52459 .40388 L .52613 .40465 L 0 .091 .189 r
F
.52329 .40495 m .52174 .40408 L .52459 .40388 L F
.67211 .3869 m .67364 .38427 L .67503 .38589 L 0 .036 .137 r
F
.67211 .3869 m .67072 .38524 L .67364 .38427 L F
.69382 .3857 m .69537 .38298 L .69675 .38478 L 0 .033 .134 r
F
.69382 .3857 m .69243 .38391 L .69537 .38298 L F
.34042 .38575 m .34146 .38288 L .34317 .38478 L F
.34042 .38575 m .33871 .38384 L .34146 .38288 L F
.79225 .38276 m .79395 .38006 L .79523 .38173 L 0 .027 .126 r
F
.79225 .38276 m .79097 .38107 L .79395 .38006 L F
.48119 .40001 m .48241 .39853 L .484 .39978 L 0 .074 .175 r
F
.48119 .40001 m .47959 .39873 L .48241 .39853 L F
.66488 .38738 m .66639 .38446 L .66779 .38622 L 0 .036 .138 r
F
.66488 .38738 m .66347 .38562 L .66639 .38446 L F
.84005 .38261 m .8418 .37975 L .84305 .38156 L 0 .026 .125 r
F
.84005 .38261 m .8388 .3808 L .8418 .37975 L F
.54499 .40387 m .54633 .40191 L .54785 .40279 L 0 .086 .184 r
F
.54499 .40387 m .54347 .40298 L .54633 .40191 L F
.37374 .38648 m .37483 .3836 L .37651 .38551 L 0 .035 .136 r
F
.37374 .38648 m .37206 .38458 L .37483 .3836 L F
.7995 .38249 m .8012 .37971 L .80248 .38151 L 0 .026 .125 r
F
.7995 .38249 m .79821 .3807 L .8012 .37971 L F
.29546 .38351 m .29642 .3809 L .29819 .38264 L 0 .029 .128 r
F
.29546 .38351 m .2937 .38176 L .29642 .3809 L F
.90955 .38131 m .91141 .37846 L .91259 .38027 L 0 .024 .122 r
F
.90955 .38131 m .90837 .37949 L .91141 .37846 L F
.84729 .38231 m .84906 .3795 L .8503 .3813 L 0 .026 .125 r
F
.84729 .38231 m .84605 .38051 L .84906 .3795 L F
.60417 .39335 m .6056 .39081 L .60705 .39205 L 0 .052 .155 r
F
.60417 .39335 m .60271 .39211 L .6056 .39081 L F
.18825 .38213 m .18906 .37941 L .19092 .38116 L 0 .026 .125 r
F
.18825 .38213 m .18638 .38039 L .18906 .37941 L F
.22881 .38235 m .22968 .37965 L .2315 .38144 L F
.22881 .38235 m .22699 .38054 L .22968 .37965 L F
.65766 .38799 m .65915 .38501 L .66056 .3868 L 0 .038 .14 r
F
.65766 .38799 m .65624 .38621 L .65915 .38501 L F
.71553 .38478 m .71713 .38223 L .71848 .38386 L 0 .032 .132 r
F
.71553 .38478 m .71418 .38314 L .71713 .38223 L F
.70107 .38559 m .70263 .38287 L .704 .38462 L 0 .033 .134 r
F
.70107 .38559 m .69969 .38383 L .70263 .38287 L F
.7083 .38524 m .70988 .38255 L .71124 .38419 L 0 .032 .133 r
F
.7083 .38524 m .70694 .3836 L .70988 .38255 L F
.34764 .38566 m .34869 .38288 L .35039 .38471 L 0 .033 .134 r
F
.34764 .38566 m .34593 .38381 L .34869 .38288 L F
.57678 .39996 m .57816 .39741 L .57964 .39863 L 0 .072 .173 r
F
.57678 .39996 m .57529 .39876 L .57816 .39741 L F
.39258 .38813 m .3937 .38536 L .39536 .38718 L 0 .039 .141 r
F
.39258 .38813 m .39092 .38628 L .3937 .38536 L F
.64319 .38893 m .64468 .38638 L .6461 .3879 L 0 .041 .143 r
F
.64319 .38893 m .64177 .38743 L .64468 .38638 L F
.85455 .38211 m .85634 .37945 L .85757 .38117 L 0 .026 .125 r
F
.85455 .38211 m .85332 .38038 L .85634 .37945 L F
.56231 .40078 m .56368 .39896 L .56518 .40006 L 0 .076 .177 r
F
.56231 .40078 m .56081 .39968 L .56368 .39896 L F
.32154 .38473 m .32255 .38201 L .32429 .38371 L 0 .031 .132 r
F
.32154 .38473 m .3198 .38302 L .32255 .38201 L F
.43469 .39316 m .43584 .39114 L .43748 .39272 L 0 .053 .156 r
F
.43469 .39316 m .43305 .3916 L .43584 .39114 L F
.4928 .40224 m .49405 .40046 L .49563 .4021 L 0 .081 .181 r
F
.4928 .40224 m .49123 .4006 L .49405 .40046 L F
.80676 .38238 m .80848 .37965 L .80975 .38147 L 0 .027 .126 r
F
.80676 .38238 m .80548 .38058 L .80848 .37965 L F
.32877 .38439 m .32978 .38181 L .33151 .38353 L 0 .031 .131 r
F
.32877 .38439 m .32704 .38268 L .32978 .38181 L F
.26935 .38279 m .27027 .38013 L .27206 .38194 L 0 .027 .127 r
F
.26935 .38279 m .26757 .38098 L .27027 .38013 L F
.58686 .39705 m .58826 .39468 L .58973 .3958 L 0 .064 .166 r
F
.58686 .39705 m .58539 .39599 L .58826 .39468 L F
.65043 .38862 m .65191 .38562 L .65334 .38741 L 0 .04 .142 r
F
.65043 .38862 m .64901 .38682 L .65191 .38562 L F
.19545 .382 m .19627 .37935 L .19812 .38113 L 0 .026 .125 r
F
.19545 .382 m .1936 .38022 L .19627 .37935 L F
.53052 .40509 m .53184 .40398 L .53337 .40468 L 0 .093 .19 r
F
.53052 .40509 m .52898 .40433 L .53184 .40398 L F
.46956 .3987 m .47077 .39689 L .47237 .39823 L 0 .07 .171 r
F
.46956 .3987 m .46795 .39733 L .47077 .39689 L F
.23601 .38226 m .2369 .37949 L .23872 .38127 L 0 .026 .125 r
F
.23601 .38226 m .2342 .38047 L .2369 .37949 L F
.72279 .38467 m .72438 .38194 L .72573 .38367 L 0 .031 .132 r
F
.72279 .38467 m .72143 .38294 L .72438 .38194 L F
.56954 .40053 m .57093 .3985 L .57242 .39971 L 0 .075 .176 r
F
.56954 .40053 m .56805 .39928 L .57093 .3985 L F
.8618 .38187 m .8636 .3791 L .86481 .38081 L 0 .026 .124 r
F
.8618 .38187 m .86058 .38016 L .8636 .3791 L F
.55507 .40134 m .55643 .39958 L .55794 .4004 L 0 .079 .179 r
F
.55507 .40134 m .55357 .40052 L .55643 .39958 L F
.41144 .38973 m .41257 .38725 L .41421 .38914 L 0 .044 .146 r
F
.41144 .38973 m .40979 .38787 L .41257 .38725 L F
.86904 .38153 m .87085 .37877 L .87206 .38055 L 0 .025 .124 r
F
.86904 .38153 m .86782 .37976 L .87085 .37877 L F
.73003 .38435 m .73162 .3814 L .73297 .38322 L 0 .03 .131 r
F
.73003 .38435 m .72868 .38253 L .73162 .3814 L F
.42306 .39163 m .42421 .38896 L .42585 .3909 L 0 .048 .151 r
F
.42306 .39163 m .42142 .3897 L .42421 .38896 L F
.35485 .38562 m .35591 .38293 L .35761 .3847 L 0 .034 .135 r
F
.35485 .38562 m .35315 .38382 L .35591 .38293 L F
.30266 .38362 m .30364 .38088 L .30539 .38273 L 0 .029 .129 r
F
.30266 .38362 m .30091 .38177 L .30364 .38088 L F
.38095 .38664 m .38204 .38406 L .38371 .38597 L 0 .036 .138 r
F
.38095 .38664 m .37927 .38473 L .38204 .38406 L F
.73727 .38404 m .73888 .38123 L .74023 .38307 L 0 .03 .13 r
F
.73727 .38404 m .73592 .38221 L .73888 .38123 L F
.39981 .38807 m .40092 .38559 L .40258 .38737 L 0 .04 .142 r
F
.39981 .38807 m .39814 .38632 L .40092 .38559 L F
.50443 .40433 m .5057 .40221 L .50726 .40361 L 0 .088 .186 r
F
.50443 .40433 m .50286 .40285 L .5057 .40221 L F
.53776 .40494 m .53909 .40345 L .54061 .40404 L 0 .092 .189 r
F
.53776 .40494 m .53623 .40426 L .53909 .40345 L F
.24323 .38206 m .24411 .37948 L .24592 .38121 L 0 .026 .125 r
F
.24323 .38206 m .24142 .38032 L .24411 .37948 L F
.63597 .38972 m .63744 .38703 L .63887 .38849 L 0 .044 .146 r
F
.63597 .38972 m .63455 .38827 L .63744 .38703 L F
.75898 .3829 m .76062 .38008 L .76194 .38181 L 0 .028 .127 r
F
.75898 .3829 m .75766 .38117 L .76062 .38008 L F
.81402 .38231 m .81576 .37963 L .81702 .38138 L 0 .027 .126 r
F
.81402 .38231 m .81275 .38055 L .81576 .37963 L F
.75175 .38336 m .75338 .38058 L .7547 .38226 L 0 .029 .129 r
F
.75175 .38336 m .75043 .38167 L .75338 .38058 L F
.27655 .38278 m .27749 .38008 L .27927 .38183 L 0 .028 .127 r
F
.27655 .38278 m .27477 .38101 L .27749 .38008 L F
.87631 .3814 m .87812 .37858 L .87933 .38042 L 0 .025 .123 r
F
.87631 .3814 m .87509 .37957 L .87812 .37858 L F
.20265 .38201 m .20348 .37931 L .20533 .38106 L 0 .026 .125 r
F
.20265 .38201 m .2008 .38025 L .20348 .37931 L F
.74452 .38383 m .74614 .38103 L .74747 .38275 L 0 .03 .13 r
F
.74452 .38383 m .74318 .38209 L .74614 .38103 L F
.45353 .39508 m .45472 .39295 L .45634 .39465 L 0 .059 .162 r
F
.45353 .39508 m .45192 .39341 L .45472 .39295 L F
.76623 .3827 m .76789 .3799 L .7692 .38173 L 0 .028 .127 r
F
.76623 .3827 m .76491 .38085 L .76789 .3799 L F
.59695 .39454 m .59837 .39223 L .59983 .39334 L 0 .057 .16 r
F
.59695 .39454 m .59549 .3934 L .59837 .39223 L F
.82128 .38213 m .82302 .37942 L .82427 .38111 L 0 .027 .126 r
F
.82128 .38213 m .82002 .38043 L .82302 .37942 L F
.36207 .38555 m .36313 .38292 L .36483 .38463 L 0 .034 .135 r
F
.36207 .38555 m .36037 .38381 L .36313 .38292 L F
.82852 .38177 m .83028 .37913 L .83152 .38081 L 0 .026 .125 r
F
.82852 .38177 m .82727 .38009 L .83028 .37913 L F
.20987 .3818 m .21071 .37912 L .21255 .38082 L F
.20987 .3818 m .20802 .38009 L .21071 .37912 L F
.33597 .38464 m .337 .38192 L .33871 .38384 L 0 .032 .133 r
F
.33597 .38464 m .33425 .38273 L .337 .38192 L F
.25043 .38204 m .25133 .3794 L .25314 .38108 L 0 .027 .126 r
F
.25043 .38204 m .24862 .38035 L .25133 .3794 L F
.28377 .38265 m .28471 .38012 L .28649 .3818 L 0 .028 .128 r
F
.28377 .38265 m .28199 .38096 L .28471 .38012 L F
.88357 .38125 m .88539 .37843 L .8866 .38024 L 0 .025 .123 r
F
.88357 .38125 m .88236 .37943 L .88539 .37843 L F
.30987 .38367 m .31085 .38109 L .31259 .3829 L 0 .03 .13 r
F
.30987 .38367 m .30812 .38183 L .31085 .38109 L F
.61428 .39131 m .61572 .38871 L .61717 .39035 L 0 .048 .151 r
F
.61428 .39131 m .61282 .3897 L .61572 .38871 L F
.48841 .40076 m .48965 .39942 L .49123 .4006 L 0 .079 .179 r
F
.48841 .40076 m .48682 .39954 L .48965 .39942 L F
.4419 .3936 m .44308 .39122 L .4447 .39288 L 0 .055 .158 r
F
.4419 .3936 m .44027 .39198 L .44308 .39122 L F
.78072 .38216 m .78241 .37947 L .7837 .3812 L 0 .027 .126 r
F
.78072 .38216 m .77943 .38042 L .78241 .37947 L F
.77349 .38257 m .77515 .37969 L .77646 .38149 L 0 .028 .127 r
F
.77349 .38257 m .77218 .38075 L .77515 .37969 L F
.89082 .38096 m .89266 .37819 L .89385 .37994 L 0 .025 .123 r
F
.89082 .38096 m .88963 .37922 L .89266 .37819 L F
.21709 .38157 m .21793 .3789 L .21977 .38062 L 0 .026 .125 r
F
.21709 .38157 m .21524 .37986 L .21793 .3789 L F
.25766 .38177 m .25857 .37909 L .26037 .38079 L F
.25766 .38177 m .25585 .38009 L .25857 .37909 L F
.51166 .40446 m .51294 .40253 L .5145 .40382 L 0 .09 .188 r
F
.51166 .40446 m .5101 .40302 L .51294 .40253 L F
.62875 .39063 m .63022 .38801 L .63165 .38951 L 0 .047 .149 r
F
.62875 .39063 m .62732 .38913 L .63022 .38801 L F
.62152 .39104 m .62297 .38844 L .62442 .39009 L 0 .048 .15 r
F
.62152 .39104 m .62007 .38939 L .62297 .38844 L F
.47678 .39909 m .478 .39744 L .47959 .39873 L 0 .073 .174 r
F
.47678 .39909 m .47518 .39777 L .478 .39744 L F
.68226 .38524 m .6838 .38254 L .68518 .38408 L 0 .034 .135 r
F
.68226 .38524 m .68088 .38368 L .6838 .38254 L F
.6895 .38484 m .69105 .38216 L .69243 .38391 L 0 .033 .134 r
F
.6895 .38484 m .68811 .3831 L .69105 .38216 L F
.89807 .38066 m .89993 .37799 L .90111 .37971 L 0 .024 .122 r
F
.89807 .38066 m .89688 .37893 L .89993 .37799 L F
.83578 .3817 m .83755 .379 L .8388 .3808 L 0 .026 .125 r
F
.83578 .3817 m .83454 .37991 L .83755 .379 L F
.36929 .38557 m .37037 .38269 L .37206 .38458 L 0 .034 .135 r
F
.36929 .38557 m .3676 .38369 L .37037 .38269 L F
.78798 .38199 m .78968 .37939 L .79097 .38107 L 0 .027 .126 r
F
.78798 .38199 m .78669 .38029 L .78968 .37939 L F
.66779 .38622 m .66931 .38352 L .67072 .38524 L 0 .036 .138 r
F
.66779 .38622 m .66639 .38446 L .66931 .38352 L F
.60705 .39205 m .60848 .38951 L .60993 .39075 L 0 .051 .154 r
F
.60705 .39205 m .6056 .39081 L .60848 .38951 L F
.29098 .38262 m .29193 .3801 L .2937 .38176 L 0 .029 .128 r
F
.29098 .38262 m .2892 .38095 L .29193 .3801 L F
.46515 .39748 m .46635 .39597 L .46795 .39733 L 0 .069 .17 r
F
.46515 .39748 m .46354 .39606 L .46635 .39597 L F
.5189 .4043 m .52019 .40321 L .52174 .40408 L 0 .092 .189 r
F
.5189 .4043 m .51734 .40317 L .52019 .40321 L F
.43027 .39206 m .43142 .38986 L .43305 .3916 L 0 .052 .154 r
F
.43027 .39206 m .42863 .39032 L .43142 .38986 L F
.2243 .38143 m .22515 .37881 L .22699 .38054 L 0 .026 .125 r
F
.2243 .38143 m .22246 .3797 L .22515 .37881 L F
.40701 .38849 m .40814 .38601 L .40979 .38787 L 0 .042 .144 r
F
.40701 .38849 m .40536 .38666 L .40814 .38601 L F
.67503 .38589 m .67657 .38323 L .67796 .38482 L 0 .036 .137 r
F
.67503 .38589 m .67364 .38427 L .67657 .38323 L F
.90533 .3805 m .9072 .37775 L .90837 .37949 L 0 .024 .122 r
F
.90533 .3805 m .90415 .37875 L .9072 .37775 L F
.54785 .40279 m .54919 .4008 L .5507 .40165 L 0 .085 .184 r
F
.54785 .40279 m .54633 .40191 L .54919 .4008 L F
.79523 .38173 m .79694 .37904 L .79821 .3807 L 0 .027 .126 r
F
.79523 .38173 m .79395 .38006 L .79694 .37904 L F
.84305 .38156 m .84481 .3787 L .84605 .38051 L 0 .026 .125 r
F
.84305 .38156 m .8418 .37975 L .84481 .3787 L F
.38814 .38719 m .38925 .38442 L .39092 .38628 L 0 .038 .14 r
F
.38814 .38719 m .38647 .3853 L .38925 .38442 L F
.34317 .38478 m .34422 .38192 L .34593 .38381 L 0 .033 .134 r
F
.34317 .38478 m .34146 .38288 L .34422 .38192 L F
.57964 .39863 m .58103 .39606 L .58251 .3973 L 0 .07 .171 r
F
.57964 .39863 m .57816 .39741 L .58103 .39606 L F
.69675 .38478 m .69831 .38204 L .69969 .38383 L 0 .033 .134 r
F
.69675 .38478 m .69537 .38298 L .69831 .38204 L F
.18371 .38137 m .18451 .37867 L .18638 .38039 L 0 .026 .125 r
F
.18371 .38137 m .18183 .37967 L .18451 .37867 L F
.26486 .38178 m .26578 .37919 L .26757 .38098 L 0 .027 .126 r
F
.26486 .38178 m .26307 .37999 L .26578 .37919 L F
.66056 .3868 m .66206 .38381 L .66347 .38562 L 0 .037 .139 r
F
.66056 .3868 m .65915 .38501 L .66206 .38381 L F
.41863 .39044 m .41978 .38777 L .42142 .3897 L 0 .047 .149 r
F
.41863 .39044 m .41699 .38853 L .41978 .38777 L F
.31706 .38388 m .31806 .3813 L .3198 .38302 L 0 .031 .132 r
F
.31706 .38388 m .31532 .38214 L .31806 .3813 L F
.91259 .38027 m .91445 .37742 L .91563 .37924 L 0 .024 .122 r
F
.91259 .38027 m .91141 .37846 L .91445 .37742 L F
.37651 .38551 m .3776 .38281 L .37927 .38473 L 0 .035 .136 r
F
.37651 .38551 m .37483 .3836 L .3776 .38281 L F
.8503 .3813 m .85209 .37858 L .85332 .38038 L 0 .026 .125 r
F
.8503 .3813 m .84906 .3795 L .85209 .37858 L F
.80248 .38151 m .8042 .37878 L .80548 .38058 L F
.80248 .38151 m .8012 .37971 L .8042 .37878 L F
.58973 .3958 m .59114 .39338 L .59261 .39456 L 0 .062 .164 r
F
.58973 .3958 m .58826 .39468 L .59114 .39338 L F
.19092 .38116 m .19174 .37846 L .1936 .38022 L 0 .026 .125 r
F
.19092 .38116 m .18906 .37941 L .19174 .37846 L F
.71124 .38419 m .71282 .38149 L .71418 .38314 L 0 .032 .133 r
F
.71124 .38419 m .70988 .38255 L .71282 .38149 L F
.65334 .38741 m .65482 .38442 L .65624 .38621 L 0 .039 .141 r
F
.65334 .38741 m .65191 .38562 L .65482 .38442 L F
.704 .38462 m .70557 .38186 L .70694 .3836 L 0 .033 .134 r
F
.704 .38462 m .70263 .38287 L .70557 .38186 L F
.44912 .39387 m .4503 .39173 L .45192 .39341 L 0 .057 .16 r
F
.44912 .39387 m .4475 .39222 L .4503 .39173 L F
.29819 .38264 m .29915 .38002 L .30091 .38177 L 0 .029 .129 r
F
.29819 .38264 m .29642 .3809 L .29915 .38002 L F
.2315 .38144 m .23238 .37868 L .2342 .38047 L 0 .026 .125 r
F
.2315 .38144 m .22968 .37965 L .23238 .37868 L F
.71848 .38386 m .72009 .38131 L .72143 .38294 L 0 .032 .132 r
F
.71848 .38386 m .71713 .38223 L .72009 .38131 L F
.6461 .3879 m .64759 .38528 L .64901 .38682 L 0 .041 .143 r
F
.6461 .3879 m .64468 .38638 L .64759 .38528 L F
.32429 .38371 m .3253 .381 L .32704 .38268 L 0 .031 .132 r
F
.32429 .38371 m .32255 .38201 L .3253 .381 L F
.35039 .38471 m .35144 .382 L .35315 .38382 L 0 .033 .134 r
F
.35039 .38471 m .34869 .38288 L .35144 .382 L F
.39536 .38718 m .39648 .38453 L .39814 .38632 L 0 .039 .141 r
F
.39536 .38718 m .3937 .38536 L .39648 .38453 L F
.85757 .38117 m .85936 .37844 L .86058 .38016 L 0 .026 .125 r
F
.85757 .38117 m .85634 .37945 L .85936 .37844 L F
.50003 .4035 m .50129 .40139 L .50286 .40285 L 0 .088 .186 r
F
.50003 .4035 m .49846 .40189 L .50129 .40139 L F
.86481 .38081 m .86661 .37806 L .86782 .37976 L 0 .025 .124 r
F
.86481 .38081 m .8636 .3791 L .86661 .37806 L F
.73297 .38322 m .73457 .38037 L .73592 .38221 L 0 .03 .13 r
F
.73297 .38322 m .73162 .3814 L .73457 .38037 L F
.72573 .38367 m .72733 .3808 L .72868 .38253 L 0 .031 .131 r
F
.72573 .38367 m .72438 .38194 L .72733 .3808 L F
.63887 .38849 m .64035 .38594 L .64177 .38743 L 0 .043 .145 r
F
.63887 .38849 m .63744 .38703 L .64035 .38594 L F
.80975 .38147 m .81148 .37874 L .81275 .38055 L 0 .027 .126 r
F
.80975 .38147 m .80848 .37965 L .81148 .37874 L F
.23872 .38127 m .2396 .37856 L .24142 .38032 L 0 .026 .125 r
F
.23872 .38127 m .2369 .37949 L .2396 .37856 L F
.33151 .38353 m .33252 .38102 L .33425 .38273 L 0 .031 .132 r
F
.33151 .38353 m .32978 .38181 L .33252 .38102 L F
.19812 .38113 m .19894 .37848 L .2008 .38025 L 0 .026 .125 r
F
.19812 .38113 m .19627 .37935 L .19894 .37848 L F
.55794 .4004 m .5593 .39884 L .56081 .39968 L 0 .079 .179 r
F
.55794 .4004 m .55643 .39958 L .5593 .39884 L F
.27206 .38194 m .27299 .37923 L .27477 .38101 L 0 .028 .127 r
F
.27206 .38194 m .27027 .38013 L .27299 .37923 L F
.87206 .38055 m .87388 .37777 L .87509 .37957 L 0 .025 .123 r
F
.87206 .38055 m .87085 .37877 L .87388 .37777 L F
.52613 .40465 m .52744 .40366 L .52898 .40433 L 0 .095 .192 r
F
.52613 .40465 m .52459 .40388 L .52744 .40366 L F
.56518 .40006 m .56655 .39819 L .56805 .39928 L 0 .077 .178 r
F
.56518 .40006 m .56368 .39896 L .56655 .39819 L F
.76194 .38181 m .7636 .37912 L .76491 .38085 L 0 .028 .127 r
F
.76194 .38181 m .76062 .38008 L .7636 .37912 L F
.57242 .39971 m .5738 .39756 L .57529 .39876 L 0 .076 .176 r
F
.57242 .39971 m .57093 .3985 L .5738 .39756 L F
.7547 .38226 m .75635 .37949 L .75766 .38117 L 0 .028 .128 r
F
.7547 .38226 m .75338 .38058 L .75635 .37949 L F
.46074 .39612 m .46194 .39436 L .46354 .39606 L 0 .066 .167 r
F
.46074 .39612 m .45914 .39445 L .46194 .39436 L F
.74023 .38307 m .74184 .38024 L .74318 .38209 L 0 .03 .13 r
F
.74023 .38307 m .73888 .38123 L .74184 .38024 L F
.35761 .3847 m .35867 .38207 L .36037 .38381 L 0 .034 .135 r
F
.35761 .3847 m .35591 .38293 L .35867 .38207 L F
.59983 .39334 m .60126 .39102 L .60271 .39211 L 0 .056 .159 r
F
.59983 .39334 m .59837 .39223 L .60126 .39102 L F
.484 .39978 m .48523 .39833 L .48682 .39954 L 0 .078 .178 r
F
.484 .39978 m .48241 .39853 L .48523 .39833 L F
.30539 .38273 m .30638 .38 L .30812 .38183 L 0 .03 .13 r
F
.30539 .38273 m .30364 .38088 L .30638 .38 L F
.74747 .38275 m .7491 .37997 L .75043 .38167 L F
.74747 .38275 m .74614 .38103 L .7491 .37997 L F
.54061 .40404 m .54195 .4025 L .54347 .40298 L 0 .092 .189 r
F
.54061 .40404 m .53909 .40345 L .54195 .4025 L F
.81702 .38138 m .81876 .37869 L .82002 .38043 L 0 .027 .126 r
F
.81702 .38138 m .81576 .37963 L .81876 .37869 L F
.24592 .38121 m .24681 .37864 L .24862 .38035 L F
.24592 .38121 m .24411 .37948 L .24681 .37864 L F
.27927 .38183 m .28021 .37923 L .28199 .38096 L 0 .028 .128 r
F
.27927 .38183 m .27749 .38008 L .28021 .37923 L F
.87933 .38042 m .88115 .3776 L .88236 .37943 L 0 .025 .123 r
F
.87933 .38042 m .87812 .37858 L .88115 .3776 L F
.20533 .38106 m .20617 .37836 L .20802 .38009 L 0 .026 .125 r
F
.20533 .38106 m .20348 .37931 L .20617 .37836 L F
.42585 .3909 m .427 .38837 L .42863 .39032 L 0 .05 .152 r
F
.42585 .3909 m .42421 .38896 L .427 .38837 L F
.43748 .39272 m .43865 .39036 L .44027 .39198 L 0 .055 .157 r
F
.43748 .39272 m .43584 .39114 L .43865 .39036 L F
.82427 .38111 m .82602 .3784 L .82727 .38009 L 0 .026 .126 r
F
.82427 .38111 m .82302 .37942 L .82602 .3784 L F
.41421 .38914 m .41535 .38661 L .41699 .38853 L 0 .045 .147 r
F
.41421 .38914 m .41257 .38725 L .41535 .38661 L F
.50726 .40361 m .50854 .40186 L .5101 .40302 L 0 .09 .188 r
F
.50726 .40361 m .5057 .40221 L .50854 .40186 L F
.7692 .38173 m .77086 .37892 L .77218 .38075 L 0 .028 .127 r
F
.7692 .38173 m .76789 .3799 L .77086 .37892 L F
.40258 .38737 m .4037 .38486 L .40536 .38666 L 0 .041 .143 r
F
.40258 .38737 m .40092 .38559 L .4037 .38486 L F
.38371 .38597 m .3848 .38339 L .38647 .3853 L 0 .037 .139 r
F
.38371 .38597 m .38204 .38406 L .3848 .38339 L F
.47237 .39823 m .47358 .39644 L .47518 .39777 L 0 .072 .173 r
F
.47237 .39823 m .47077 .39689 L .47358 .39644 L F
.53337 .40468 m .5347 .40362 L .53623 .40426 L 0 .096 .192 r
F
.53337 .40468 m .53184 .40398 L .5347 .40362 L F
.83152 .38081 m .83329 .37823 L .83454 .37991 L 0 .026 .125 r
F
.83152 .38081 m .83028 .37913 L .83329 .37823 L F
.36483 .38463 m .3659 .38201 L .3676 .38369 L 0 .034 .135 r
F
.36483 .38463 m .36313 .38292 L .3659 .38201 L F
.21255 .38082 m .2134 .37815 L .21524 .37986 L 0 .026 .125 r
F
.21255 .38082 m .21071 .37912 L .2134 .37815 L F
.8866 .38024 m .88843 .37741 L .88963 .37922 L 0 .025 .123 r
F
.8866 .38024 m .88539 .37843 L .88843 .37741 L F
.68518 .38408 m .68673 .38156 L .68811 .3831 L 0 .033 .134 r
F
.68518 .38408 m .6838 .38254 L .68673 .38156 L F
.63165 .38951 m .63311 .38676 L .63455 .38827 L 0 .046 .148 r
F
.63165 .38951 m .63022 .38801 L .63311 .38676 L F
.25314 .38108 m .25405 .37839 L .25585 .38009 L 0 .027 .126 r
F
.25314 .38108 m .25133 .3794 L .25405 .37839 L F
.77646 .38149 m .77812 .37863 L .77943 .38042 L 0 .027 .127 r
F
.77646 .38149 m .77515 .37969 L .77812 .37863 L F
.61717 .39035 m .61862 .38773 L .62007 .38939 L 0 .048 .151 r
F
.61717 .39035 m .61572 .38871 L .61862 .38773 L F
.60993 .39075 m .61137 .38842 L .61282 .3897 L 0 .05 .153 r
F
.60993 .39075 m .60848 .38951 L .61137 .38842 L F
.89385 .37994 m .8957 .37719 L .89688 .37893 L 0 .024 .123 r
F
.89385 .37994 m .89266 .37819 L .8957 .37719 L F
.26037 .38079 m .26127 .37828 L .26307 .37999 L 0 .026 .126 r
F
.26037 .38079 m .25857 .37909 L .26127 .37828 L F
.28649 .3818 m .28743 .37927 L .2892 .38095 L 0 .028 .128 r
F
.28649 .3818 m .28471 .38012 L .28743 .37927 L F
.7837 .3812 m .7854 .37857 L .78669 .38029 L 0 .027 .126 r
F
.7837 .3812 m .78241 .37947 L .7854 .37857 L F
.49563 .4021 m .49688 .40028 L .49846 .40189 L 0 .085 .184 r
F
.49563 .4021 m .49405 .40046 L .49688 .40028 L F
.21977 .38062 m .22063 .37797 L .22246 .3797 L 0 .026 .125 r
F
.21977 .38062 m .21793 .3789 L .22063 .37797 L F
.33871 .38384 m .33975 .38098 L .34146 .38288 L 0 .032 .133 r
F
.33871 .38384 m .337 .38192 L .33975 .38098 L F
.58251 .3973 m .58391 .39472 L .58539 .39599 L 0 .068 .17 r
F
.58251 .3973 m .58103 .39606 L .58391 .39472 L F
.62442 .39009 m .62587 .38749 L .62732 .38913 L 0 .048 .15 r
F
.62442 .39009 m .62297 .38844 L .62587 .38749 L F
.31259 .3829 m .31358 .38034 L .31532 .38214 L 0 .031 .131 r
F
.31259 .3829 m .31085 .38109 L .31358 .38034 L F
.69243 .38391 m .69399 .38121 L .69537 .38298 L 0 .033 .134 r
F
.69243 .38391 m .69105 .38216 L .69399 .38121 L F
.90111 .37971 m .90298 .37704 L .90415 .37875 L 0 .024 .122 r
F
.90111 .37971 m .89993 .37799 L .90298 .37704 L F
.37206 .38458 m .37315 .38169 L .37483 .3836 L 0 .034 .135 r
F
.37206 .38458 m .37037 .38269 L .37315 .38169 L F
.5507 .40165 m .55206 .39969 L .55357 .40052 L 0 .084 .183 r
F
.5507 .40165 m .54919 .4008 L .55206 .39969 L F
.45634 .39465 m .45753 .39271 L .45914 .39445 L 0 .062 .164 r
F
.45634 .39465 m .45472 .39295 L .45753 .39271 L F
.8388 .3808 m .84056 .37795 L .8418 .37975 L 0 .026 .125 r
F
.8388 .3808 m .83755 .379 L .84056 .37795 L F
.67796 .38482 m .67949 .38212 L .68088 .38368 L 0 .035 .136 r
F
.67796 .38482 m .67657 .38323 L .67949 .38212 L F
.66347 .38562 m .66497 .38264 L .66639 .38446 L 0 .036 .138 r
F
.66347 .38562 m .66206 .38381 L .66497 .38264 L F
.67072 .38524 m .67224 .38257 L .67364 .38427 L 0 .036 .137 r
F
.67072 .38524 m .66931 .38352 L .67224 .38257 L F
.4447 .39288 m .44588 .39052 L .4475 .39222 L 0 .056 .159 r
F
.4447 .39288 m .44308 .39122 L .44588 .39052 L F
.79097 .38107 m .79267 .3784 L .79395 .38006 L 0 .027 .126 r
F
.79097 .38107 m .78968 .37939 L .79267 .3784 L F
.90837 .37949 m .91024 .37671 L .91141 .37846 L 0 .024 .122 r
F
.90837 .37949 m .9072 .37775 L .91024 .37671 L F
.79821 .3807 m .79993 .37806 L .8012 .37971 L 0 .026 .126 r
F
.79821 .3807 m .79694 .37904 L .79993 .37806 L F
.59261 .39456 m .59403 .39224 L .59549 .3934 L 0 .061 .163 r
F
.59261 .39456 m .59114 .39338 L .59403 .39224 L F
.84605 .38051 m .84782 .37768 L .84906 .3795 L 0 .026 .125 r
F
.84605 .38051 m .84481 .3787 L .84782 .37768 L F
.5145 .40382 m .51579 .40204 L .51734 .40317 L 0 .092 .189 r
F
.5145 .40382 m .51294 .40253 L .51579 .40204 L F
.22699 .38054 m .22785 .37791 L .22968 .37965 L 0 .026 .125 r
F
.22699 .38054 m .22515 .37881 L .22785 .37791 L F
.2937 .38176 m .29465 .37925 L .29642 .3809 L 0 .029 .129 r
F
.2937 .38176 m .29193 .3801 L .29465 .37925 L F
.65624 .38621 m .65773 .38321 L .65915 .38501 L 0 .038 .14 r
F
.65624 .38621 m .65482 .38442 L .65773 .38321 L F
.18638 .38039 m .18719 .37767 L .18906 .37941 L 0 .026 .125 r
F
.18638 .38039 m .18451 .37867 L .18719 .37767 L F
.34593 .38381 m .34698 .38101 L .34869 .38288 L 0 .033 .134 r
F
.34593 .38381 m .34422 .38192 L .34698 .38101 L F
.69969 .38383 m .70125 .3811 L .70263 .38287 L F
.69969 .38383 m .69831 .38204 L .70125 .3811 L F
.39092 .38628 m .39203 .38354 L .3937 .38536 L 0 .039 .14 r
F
.39092 .38628 m .38925 .38442 L .39203 .38354 L F
.71418 .38314 m .71578 .38058 L .71713 .38223 L 0 .032 .133 r
F
.71418 .38314 m .71282 .38149 L .71578 .38058 L F
.26757 .38098 m .26849 .37835 L .27027 .38013 L 0 .027 .127 r
F
.26757 .38098 m .26578 .37919 L .26849 .37835 L F
.85332 .38038 m .85511 .37765 L .85634 .37945 L 0 .026 .125 r
F
.85332 .38038 m .85209 .37858 L .85511 .37765 L F
.80548 .38058 m .8072 .37784 L .80848 .37965 L F
.80548 .38058 m .8042 .37878 L .8072 .37784 L F
.70694 .3836 m .70851 .3808 L .70988 .38255 L 0 .033 .133 r
F
.70694 .3836 m .70557 .38186 L .70851 .3808 L F
.64901 .38682 m .6505 .3841 L .65191 .38562 L 0 .04 .142 r
F
.64901 .38682 m .64759 .38528 L .6505 .3841 L F
.3198 .38302 m .3208 .3803 L .32255 .38201 L 0 .032 .132 r
F
.3198 .38302 m .31806 .3813 L .3208 .3803 L F
.1936 .38022 m .19441 .37757 L .19627 .37935 L 0 .026 .125 r
F
.1936 .38022 m .19174 .37846 L .19441 .37757 L F
.40979 .38787 m .41092 .38536 L .41257 .38725 L 0 .043 .146 r
F
.40979 .38787 m .40814 .38601 L .41092 .38536 L F
.47959 .39873 m .48082 .39727 L .48241 .39853 L 0 .076 .177 r
F
.47959 .39873 m .478 .39744 L .48082 .39727 L F
.42142 .3897 m .42258 .38701 L .42421 .38896 L 0 .048 .15 r
F
.42142 .3897 m .41978 .38777 L .42258 .38701 L F
.32704 .38268 m .32804 .38014 L .32978 .38181 L 0 .031 .132 r
F
.32704 .38268 m .3253 .381 L .32804 .38014 L F
.2342 .38047 m .23508 .37771 L .2369 .37949 L 0 .026 .125 r
F
.2342 .38047 m .23238 .37868 L .23508 .37771 L F
.49123 .4006 m .49247 .39933 L .49405 .40046 L 0 .083 .182 r
F
.49123 .4006 m .48965 .39942 L .49247 .39933 L F
.37927 .38473 m .38036 .38214 L .38204 .38406 L 0 .036 .137 r
F
.37927 .38473 m .3776 .38281 L .38036 .38214 L F
.72868 .38253 m .73027 .37965 L .73162 .3814 L 0 .03 .131 r
F
.72868 .38253 m .72733 .3808 L .73027 .37965 L F
.72143 .38294 m .72304 .38031 L .72438 .38194 L 0 .032 .132 r
F
.72143 .38294 m .72009 .38131 L .72304 .38031 L F
.43305 .3916 m .43421 .38939 L .43584 .39114 L 0 .054 .156 r
F
.43305 .3916 m .43142 .38986 L .43421 .38939 L F
.86058 .38016 m .86238 .37739 L .8636 .3791 L 0 .026 .125 r
F
.86058 .38016 m .85936 .37844 L .86238 .37739 L F
.86782 .37976 m .86964 .37706 L .87085 .37877 L 0 .025 .124 r
F
.86782 .37976 m .86661 .37806 L .86964 .37706 L F
.30091 .38177 m .30188 .37912 L .30364 .38088 L 0 .029 .129 r
F
.30091 .38177 m .29915 .38002 L .30188 .37912 L F
.64177 .38743 m .64326 .38487 L .64468 .38638 L 0 .042 .144 r
F
.64177 .38743 m .64035 .38594 L .64326 .38487 L F
.73592 .38221 m .73753 .37938 L .73888 .38123 L 0 .03 .13 r
F
.73592 .38221 m .73457 .38037 L .73753 .37938 L F
.35315 .38382 m .3542 .38112 L .35591 .38293 L 0 .034 .135 r
F
.35315 .38382 m .35144 .382 L .3542 .38112 L F
.60271 .39211 m .60414 .38973 L .6056 .39081 L 0 .055 .157 r
F
.60271 .39211 m .60126 .39102 L .60414 .38973 L F
.39814 .38632 m .39925 .38384 L .40092 .38559 L 0 .04 .142 r
F
.39814 .38632 m .39648 .38453 L .39925 .38384 L F
.24142 .38032 m .24229 .37774 L .24411 .37948 L 0 .026 .126 r
F
.24142 .38032 m .2396 .37856 L .24229 .37774 L F
.81275 .38055 m .81449 .37783 L .81576 .37963 L 0 .027 .126 r
F
.81275 .38055 m .81148 .37874 L .81449 .37783 L F
.75766 .38117 m .75931 .3784 L .76062 .38008 L 0 .028 .128 r
F
.75766 .38117 m .75635 .37949 L .75931 .3784 L F
.87509 .37957 m .87691 .37679 L .87812 .37858 L 0 .025 .123 r
F
.87509 .37957 m .87388 .37777 L .87691 .37679 L F
.52174 .40408 m .52304 .40327 L .52459 .40388 L 0 .097 .193 r
F
.52174 .40408 m .52019 .40321 L .52304 .40327 L F
.27477 .38101 m .27571 .37833 L .27749 .38008 L 0 .028 .127 r
F
.27477 .38101 m .27299 .37923 L .27571 .37833 L F
.76491 .38085 m .76658 .37818 L .76789 .3799 L F
.76491 .38085 m .7636 .37912 L .76658 .37818 L F
.2008 .38025 m .20162 .37756 L .20348 .37931 L 0 .026 .125 r
F
.2008 .38025 m .19894 .37848 L .20162 .37756 L F
.46795 .39733 m .46916 .39554 L .47077 .39689 L 0 .072 .173 r
F
.46795 .39733 m .46635 .39597 L .46916 .39554 L F
.75043 .38167 m .75206 .3789 L .75338 .38058 L 0 .029 .129 r
F
.75043 .38167 m .7491 .37997 L .75206 .3789 L F
.54347 .40298 m .54481 .40155 L .54633 .40191 L 0 .091 .189 r
F
.54347 .40298 m .54195 .4025 L .54481 .40155 L F
.57529 .39876 m .57668 .39619 L .57816 .39741 L 0 .075 .175 r
F
.57529 .39876 m .5738 .39756 L .57668 .39619 L F
.74318 .38209 m .7448 .37921 L .74614 .38103 L 0 .03 .13 r
F
.74318 .38209 m .74184 .38024 L .7448 .37921 L F
.33425 .38273 m .33527 .3802 L .337 .38192 L 0 .032 .132 r
F
.33425 .38273 m .33252 .38102 L .33527 .3802 L F
.50286 .40285 m .50413 .40089 L .5057 .40221 L 0 .09 .187 r
F
.50286 .40285 m .50129 .40139 L .50413 .40089 L F
.45192 .39341 m .45311 .39124 L .45472 .39295 L 0 .06 .162 r
F
.45192 .39341 m .4503 .39173 L .45311 .39124 L F
.56805 .39928 m .56943 .39741 L .57093 .3985 L 0 .078 .178 r
F
.56805 .39928 m .56655 .39819 L .56943 .39741 L F
.36037 .38381 m .36143 .38121 L .36313 .38292 L 0 .034 .135 r
F
.36037 .38381 m .35867 .38207 L .36143 .38121 L F
.56081 .39968 m .56218 .39809 L .56368 .39896 L 0 .08 .18 r
F
.56081 .39968 m .5593 .39884 L .56218 .39809 L F
.30812 .38183 m .3091 .37927 L .31085 .38109 L 0 .03 .13 r
F
.30812 .38183 m .30638 .38 L .3091 .37927 L F
.88236 .37943 m .88419 .37661 L .88539 .37843 L 0 .025 .123 r
F
.88236 .37943 m .88115 .3776 L .88419 .37661 L F
.82002 .38043 m .82176 .37768 L .82302 .37942 L 0 .027 .126 r
F
.82002 .38043 m .81876 .37869 L .82176 .37768 L F
.63455 .38827 m .63601 .38551 L .63744 .38703 L 0 .045 .147 r
F
.63455 .38827 m .63311 .38676 L .63601 .38551 L F
.82727 .38009 m .82903 .37745 L .83028 .37913 L 0 .026 .125 r
F
.82727 .38009 m .82602 .3784 L .82903 .37745 L F
.20802 .38009 m .20885 .3774 L .21071 .37912 L F
.20802 .38009 m .20617 .37836 L .20885 .3774 L F
.58539 .39599 m .58679 .39338 L .58826 .39468 L 0 .066 .168 r
F
.58539 .39599 m .58391 .39472 L .58679 .39338 L F
.77218 .38075 m .77384 .37787 L .77515 .37969 L 0 .027 .127 r
F
.77218 .38075 m .77086 .37892 L .77384 .37787 L F
.24862 .38035 m .24952 .3777 L .25133 .3794 L 0 .027 .126 r
F
.24862 .38035 m .24681 .37864 L .24952 .3777 L F
.28199 .38096 m .28293 .37839 L .28471 .38012 L 0 .028 .128 r
F
.28199 .38096 m .28021 .37923 L .28293 .37839 L F
.77943 .38042 m .78111 .37768 L .78241 .37947 L 0 .027 .126 r
F
.77943 .38042 m .77812 .37863 L .78111 .37768 L F
.88963 .37922 m .89146 .37639 L .89266 .37819 L 0 .024 .123 r
F
.88963 .37922 m .88843 .37741 L .89146 .37639 L F
.61282 .3897 m .61427 .38739 L .61572 .38871 L 0 .05 .152 r
F
.61282 .3897 m .61137 .38842 L .61427 .38739 L F
.21524 .37986 m .21609 .37718 L .21793 .3789 L 0 .026 .125 r
F
.21524 .37986 m .2134 .37815 L .21609 .37718 L F
.3676 .38369 m .36867 .38102 L .37037 .38269 L 0 .034 .135 r
F
.3676 .38369 m .3659 .38201 L .36867 .38102 L F
.25585 .38009 m .25676 .3774 L .25857 .37909 L 0 .027 .126 r
F
.25585 .38009 m .25405 .37839 L .25676 .3774 L F
.68811 .3831 m .68967 .38061 L .69105 .38216 L 0 .033 .134 r
F
.68811 .3831 m .68673 .38156 L .68967 .38061 L F
.83454 .37991 m .83631 .37733 L .83755 .379 L 0 .026 .125 r
F
.83454 .37991 m .83329 .37823 L .83631 .37733 L F
.44027 .39198 m .44145 .38956 L .44308 .39122 L 0 .056 .158 r
F
.44027 .39198 m .43865 .39036 L .44145 .38956 L F
.89688 .37893 m .89875 .37626 L .89993 .37799 L 0 .024 .123 r
F
.89688 .37893 m .8957 .37719 L .89875 .37626 L F
.62007 .38939 m .62152 .38679 L .62297 .38844 L 0 .048 .151 r
F
.62007 .38939 m .61862 .38773 L .62152 .38679 L F
.52898 .40433 m .5303 .40343 L .53184 .40398 L 0 .099 .194 r
F
.52898 .40433 m .52744 .40366 L .5303 .40343 L F
.55357 .40052 m .55493 .39875 L .55643 .39958 L 0 .083 .182 r
F
.55357 .40052 m .55206 .39969 L .55493 .39875 L F
.40536 .38666 m .40648 .38418 L .40814 .38601 L 0 .042 .144 r
F
.40536 .38666 m .4037 .38486 L .40648 .38418 L F
.66639 .38446 m .6679 .38173 L .66931 .38352 L 0 .036 .137 r
F
.66639 .38446 m .66497 .38264 L .6679 .38173 L F
.68088 .38368 m .68242 .381 L .6838 .38254 L 0 .034 .136 r
F
.68088 .38368 m .67949 .38212 L .68242 .381 L F
.34146 .38288 m .34251 .38004 L .34422 .38192 L 0 .032 .133 r
F
.34146 .38288 m .33975 .38098 L .34251 .38004 L F
.42863 .39032 m .42979 .38793 L .43142 .38986 L 0 .051 .154 r
F
.42863 .39032 m .427 .38837 L .42979 .38793 L F
.38647 .3853 m .38758 .38253 L .38925 .38442 L 0 .038 .14 r
F
.38647 .3853 m .3848 .38339 L .38758 .38253 L F
.41699 .38853 m .41814 .38583 L .41978 .38777 L 0 .046 .149 r
F
.41699 .38853 m .41535 .38661 L .41814 .38583 L F
.78669 .38029 m .7884 .37768 L .78968 .37939 L 0 .027 .127 r
F
.78669 .38029 m .7854 .37857 L .7884 .37768 L F
.62732 .38913 m .62877 .38638 L .63022 .38801 L 0 .047 .15 r
F
.62732 .38913 m .62587 .38749 L .62877 .38638 L F
.22246 .3797 m .22332 .37707 L .22515 .37881 L 0 .026 .125 r
F
.22246 .3797 m .22063 .37797 L .22332 .37707 L F
.5101 .40302 m .51138 .40172 L .51294 .40253 L 0 .093 .19 r
F
.5101 .40302 m .50854 .40186 L .51138 .40172 L F
.59549 .3934 m .59691 .39111 L .59837 .39223 L 0 .06 .162 r
F
.59549 .3934 m .59403 .39224 L .59691 .39111 L F
.2892 .38095 m .29015 .37844 L .29193 .3801 L 0 .029 .129 r
F
.2892 .38095 m .28743 .37927 L .29015 .37844 L F
.8418 .37975 m .84357 .37689 L .84481 .3787 L 0 .026 .125 r
F
.8418 .37975 m .84056 .37795 L .84357 .37689 L F
.90415 .37875 m .90602 .37605 L .9072 .37775 L 0 .024 .122 r
F
.90415 .37875 m .90298 .37704 L .90602 .37605 L F
.69537 .38298 m .69693 .38028 L .69831 .38204 L 0 .033 .134 r
F
.69537 .38298 m .69399 .38121 L .69693 .38028 L F
.37483 .3836 m .37592 .3809 L .3776 .38281 L 0 .034 .135 r
F
.37483 .3836 m .37315 .38169 L .37592 .3809 L F
.65915 .38501 m .66064 .382 L .66206 .38381 L 0 .037 .139 r
F
.65915 .38501 m .65773 .38321 L .66064 .382 L F
.26307 .37999 m .26398 .37747 L .26578 .37919 L 0 .027 .126 r
F
.26307 .37999 m .26127 .37828 L .26398 .37747 L F
.48682 .39954 m .48806 .39826 L .48965 .39942 L 0 .082 .181 r
F
.48682 .39954 m .48523 .39833 L .48806 .39826 L F
.67364 .38427 m .67517 .38157 L .67657 .38323 L 0 .036 .137 r
F
.67364 .38427 m .67224 .38257 L .67517 .38157 L F
.79395 .38006 m .79566 .37741 L .79694 .37904 L 0 .027 .126 r
F
.79395 .38006 m .79267 .3784 L .79566 .37741 L F
.91141 .37846 m .91328 .37568 L .91445 .37742 L 0 .024 .122 r
F
.91141 .37846 m .91024 .37671 L .91328 .37568 L F
.18183 .37967 m .18263 .37695 L .18451 .37867 L 0 .026 .125 r
F
.18183 .37967 m .17995 .37796 L .18263 .37695 L F
.47518 .39777 m .4764 .39613 L .478 .39744 L 0 .075 .176 r
F
.47518 .39777 m .47358 .39644 L .4764 .39613 L F
.84906 .3795 m .85085 .37676 L .85209 .37858 L 0 .026 .125 r
F
.84906 .3795 m .84782 .37768 L .85085 .37676 L F
.8012 .37971 m .80293 .37711 L .8042 .37878 L F
.8012 .37971 m .79993 .37806 L .80293 .37711 L F
.31532 .38214 m .31631 .37952 L .31806 .3813 L 0 .031 .132 r
F
.31532 .38214 m .31358 .38034 L .31631 .37952 L F
.53623 .40426 m .53756 .40293 L .53909 .40345 L 0 .098 .194 r
F
.53623 .40426 m .5347 .40362 L .53756 .40293 L F
.46354 .39606 m .46474 .39426 L .46635 .39597 L 0 .07 .171 r
F
.46354 .39606 m .46194 .39436 L .46474 .39426 L F
.65191 .38562 m .65341 .38292 L .65482 .38442 L 0 .039 .141 r
F
.65191 .38562 m .6505 .3841 L .65341 .38292 L F
.18906 .37941 m .18987 .3767 L .19174 .37846 L 0 .026 .125 r
F
.18906 .37941 m .18719 .37767 L .18987 .3767 L F
.22968 .37965 m .23055 .37693 L .23238 .37868 L F
.22968 .37965 m .22785 .37791 L .23055 .37693 L F
.70263 .38287 m .7042 .38008 L .70557 .38186 L 0 .033 .134 r
F
.70263 .38287 m .70125 .3811 L .7042 .38008 L F
.34869 .38288 m .34974 .38014 L .35144 .382 L F
.34869 .38288 m .34698 .38101 L .34974 .38014 L F
.29642 .3809 m .29738 .37836 L .29915 .38002 L 0 .029 .129 r
F
.29642 .3809 m .29465 .37925 L .29738 .37836 L F
.70988 .38255 m .71146 .37975 L .71282 .38149 L 0 .032 .133 r
F
.70988 .38255 m .70851 .3808 L .71146 .37975 L F
.3937 .38536 m .39481 .38274 L .39648 .38453 L 0 .039 .141 r
F
.3937 .38536 m .39203 .38354 L .39481 .38274 L F
.6056 .39081 m .60703 .38843 L .60848 .38951 L 0 .053 .156 r
F
.6056 .39081 m .60414 .38973 L .60703 .38843 L F
.4475 .39222 m .44869 .38999 L .4503 .39173 L 0 .058 .16 r
F
.4475 .39222 m .44588 .39052 L .44869 .38999 L F
.73162 .3814 m .73323 .37861 L .73457 .38037 L 0 .03 .13 r
F
.73162 .3814 m .73027 .37965 L .73323 .37861 L F
.32255 .38201 m .32356 .37931 L .3253 .381 L 0 .031 .132 r
F
.32255 .38201 m .3208 .3803 L .32356 .37931 L F
.71713 .38223 m .71873 .37967 L .72009 .38131 L 0 .032 .133 r
F
.71713 .38223 m .71578 .38058 L .71873 .37967 L F
.85634 .37945 m .85813 .37666 L .85936 .37844 L 0 .026 .125 r
F
.85634 .37945 m .85511 .37765 L .85813 .37666 L F
.80848 .37965 m .8102 .37693 L .81148 .37874 L 0 .026 .126 r
F
.80848 .37965 m .8072 .37784 L .8102 .37693 L F
.51734 .40317 m .51864 .40234 L .52019 .40321 L 0 .096 .192 r
F
.51734 .40317 m .51579 .40204 L .51864 .40234 L F
.2369 .37949 m .23778 .37679 L .2396 .37856 L 0 .026 .125 r
F
.2369 .37949 m .23508 .37771 L .23778 .37679 L F
.8636 .3791 m .8654 .37635 L .86661 .37806 L 0 .025 .124 r
F
.8636 .3791 m .86238 .37739 L .8654 .37635 L F
.57816 .39741 m .57955 .39482 L .58103 .39606 L 0 .073 .174 r
F
.57816 .39741 m .57668 .39619 L .57955 .39482 L F
.72438 .38194 m .72598 .37917 L .72733 .3808 L 0 .031 .132 r
F
.72438 .38194 m .72304 .38031 L .72598 .37917 L F
.27027 .38013 m .2712 .37747 L .27299 .37923 L 0 .028 .127 r
F
.27027 .38013 m .26849 .37835 L .2712 .37747 L F
.64468 .38638 m .64617 .38377 L .64759 .38528 L 0 .042 .144 r
F
.64468 .38638 m .64326 .38487 L .64617 .38377 L F
.19627 .37935 m .19709 .37668 L .19894 .37848 L 0 .026 .125 r
F
.19627 .37935 m .19441 .37757 L .19709 .37668 L F
.87085 .37877 m .87267 .37606 L .87388 .37777 L 0 .025 .123 r
F
.87085 .37877 m .86964 .37706 L .87267 .37606 L F
.49846 .40189 m .49972 .39993 L .50129 .40139 L 0 .089 .187 r
F
.49846 .40189 m .49688 .40028 L .49972 .39993 L F
.32978 .38181 m .33079 .37934 L .33252 .38102 L 0 .032 .132 r
F
.32978 .38181 m .32804 .38014 L .33079 .37934 L F
.73888 .38123 m .7405 .37839 L .74184 .38024 L 0 .03 .13 r
F
.73888 .38123 m .73753 .37938 L .7405 .37839 L F
.76062 .38008 m .76229 .37746 L .7636 .37912 L 0 .028 .127 r
F
.76062 .38008 m .75931 .3784 L .76229 .37746 L F
.30364 .38088 m .30462 .37823 L .30638 .38 L 0 .029 .129 r
F
.30364 .38088 m .30188 .37912 L .30462 .37823 L F
.42421 .38896 m .42537 .38643 L .427 .38837 L 0 .049 .151 r
F
.42421 .38896 m .42258 .38701 L .42537 .38643 L F
.35591 .38293 m .35696 .38029 L .35867 .38207 L 0 .034 .135 r
F
.35591 .38293 m .3542 .38112 L .35696 .38029 L F
.75338 .38058 m .75503 .37781 L .75635 .37949 L 0 .029 .128 r
F
.75338 .38058 m .75206 .3789 L .75503 .37781 L F
.45914 .39445 m .46033 .39257 L .46194 .39436 L 0 .066 .167 r
F
.45914 .39445 m .45753 .39271 L .46033 .39257 L F
.87812 .37858 m .87994 .37581 L .88115 .3776 L 0 .025 .123 r
F
.87812 .37858 m .87691 .37679 L .87994 .37581 L F
.63744 .38703 m .63892 .38441 L .64035 .38594 L 0 .044 .146 r
F
.63744 .38703 m .63601 .38551 L .63892 .38441 L F
.54633 .40191 m .54768 .40051 L .54919 .4008 L 0 .091 .188 r
F
.54633 .40191 m .54481 .40155 L .54768 .40051 L F
.58826 .39468 m .58967 .39204 L .59114 .39338 L 0 .065 .167 r
F
.58826 .39468 m .58679 .39338 L .58967 .39204 L F
.41257 .38725 m .4137 .38469 L .41535 .38661 L 0 .044 .147 r
F
.41257 .38725 m .41092 .38536 L .4137 .38469 L F
.74614 .38103 m .74777 .37817 L .7491 .37997 L 0 .03 .13 r
F
.74614 .38103 m .7448 .37921 L .74777 .37817 L F
.81576 .37963 m .81749 .3769 L .81876 .37869 L 0 .027 .126 r
F
.81576 .37963 m .81449 .37783 L .81749 .3769 L F
.38204 .38406 m .38313 .38147 L .3848 .38339 L 0 .037 .138 r
F
.38204 .38406 m .38036 .38214 L .38313 .38147 L F
.27749 .38008 m .27843 .37749 L .28021 .37923 L 0 .028 .128 r
F
.27749 .38008 m .27571 .37833 L .27843 .37749 L F
.24411 .37948 m .24499 .37692 L .24681 .37864 L 0 .027 .126 r
F
.24411 .37948 m .24229 .37774 L .24499 .37692 L F
.76789 .3799 m .76956 .37721 L .77086 .37892 L 0 .028 .127 r
F
.76789 .3799 m .76658 .37818 L .76956 .37721 L F
.20348 .37931 m .20431 .37662 L .20617 .37836 L 0 .026 .125 r
F
.20348 .37931 m .20162 .37756 L .20431 .37662 L F
.40092 .38559 m .40204 .38314 L .4037 .38486 L 0 .041 .143 r
F
.40092 .38559 m .39925 .38384 L .40204 .38314 L F
.82302 .37942 m .82477 .37666 L .82602 .3784 L 0 .027 .126 r
F
.82302 .37942 m .82176 .37768 L .82477 .37666 L F
.88539 .37843 m .88722 .3756 L .88843 .37741 L 0 .025 .123 r
F
.88539 .37843 m .88419 .37661 L .88722 .3756 L F
.43584 .39114 m .43702 .38862 L .43865 .39036 L 0 .055 .158 r
F
.43584 .39114 m .43421 .38939 L .43702 .38862 L F
.77515 .37969 m .77682 .37683 L .77812 .37863 L 0 .027 .126 r
F
.77515 .37969 m .77384 .37787 L .77682 .37683 L F
.36313 .38292 m .3642 .38033 L .3659 .38201 L 0 .034 .136 r
F
.36313 .38292 m .36143 .38121 L .3642 .38033 L F
.337 .38192 m .33803 .37925 L .33975 .38098 L 0 .032 .133 r
F
.337 .38192 m .33527 .3802 L .33803 .37925 L F
.21071 .37912 m .21155 .37644 L .2134 .37815 L 0 .026 .125 r
F
.21071 .37912 m .20885 .3774 L .21155 .37644 L F
.83028 .37913 m .83205 .37655 L .83329 .37823 L 0 .026 .126 r
F
.83028 .37913 m .82903 .37745 L .83205 .37655 L F
.25133 .3794 m .25223 .3767 L .25405 .37839 L 0 .027 .126 r
F
.25133 .3794 m .24952 .3777 L .25223 .3767 L F
.57093 .3985 m .57231 .39647 L .5738 .39756 L 0 .079 .179 r
F
.57093 .3985 m .56943 .39741 L .57231 .39647 L F
.89266 .37819 m .8945 .3754 L .8957 .37719 L 0 .024 .123 r
F
.89266 .37819 m .89146 .37639 L .8945 .3754 L F
.48241 .39853 m .48364 .39709 L .48523 .39833 L 0 .08 .18 r
F
.48241 .39853 m .48082 .39727 L .48364 .39709 L F
.56368 .39896 m .56506 .39729 L .56655 .39819 L 0 .081 .181 r
F
.56368 .39896 m .56218 .39809 L .56506 .39729 L F
.78241 .37947 m .7841 .37679 L .7854 .37857 L 0 .027 .126 r
F
.78241 .37947 m .78111 .37768 L .7841 .37679 L F
.61572 .38871 m .61717 .38636 L .61862 .38773 L 0 .049 .152 r
F
.61572 .38871 m .61427 .38739 L .61717 .38636 L F
.37037 .38269 m .37145 .38002 L .37315 .38169 L 0 .034 .135 r
F
.37037 .38269 m .36867 .38102 L .37145 .38002 L F
.31085 .38109 m .31183 .37855 L .31358 .38034 L 0 .031 .131 r
F
.31085 .38109 m .3091 .37927 L .31183 .37855 L F
.5057 .40221 m .50697 .40089 L .50854 .40186 L 0 .093 .19 r
F
.5057 .40221 m .50413 .40089 L .50697 .40089 L F
.25857 .37909 m .25947 .37658 L .26127 .37828 L 0 .027 .126 r
F
.25857 .37909 m .25676 .3774 L .25947 .37658 L F
.21793 .3789 m .21878 .37625 L .22063 .37797 L 0 .026 .125 r
F
.21793 .3789 m .21609 .37718 L .21878 .37625 L F
.28471 .38012 m .28565 .37756 L .28743 .37927 L 0 .029 .128 r
F
.28471 .38012 m .28293 .37839 L .28565 .37756 L F
.6838 .38254 m .68535 .38002 L .68673 .38156 L 0 .034 .135 r
F
.6838 .38254 m .68242 .381 L .68535 .38002 L F
.69105 .38216 m .69261 .37967 L .69399 .38121 L 0 .033 .134 r
F
.69105 .38216 m .68967 .38061 L .69261 .37967 L F
.49405 .40046 m .4953 .39924 L .49688 .40028 L 0 .088 .186 r
F
.49405 .40046 m .49247 .39933 L .4953 .39924 L F
.59837 .39223 m .5998 .38991 L .60126 .39102 L 0 .059 .161 r
F
.59837 .39223 m .59691 .39111 L .5998 .38991 L F
.63022 .38801 m .63167 .38512 L .63311 .38676 L 0 .047 .149 r
F
.63022 .38801 m .62877 .38638 L .63167 .38512 L F
.66206 .38381 m .66356 .38082 L .66497 .38264 L 0 .036 .138 r
F
.66206 .38381 m .66064 .382 L .66356 .38082 L F
.89993 .37799 m .9018 .37533 L .90298 .37704 L 0 .024 .123 r
F
.89993 .37799 m .89875 .37626 L .9018 .37533 L F
.62297 .38844 m .62443 .38585 L .62587 .38749 L 0 .048 .151 r
F
.62297 .38844 m .62152 .38679 L .62443 .38585 L F
.47077 .39689 m .47198 .39512 L .47358 .39644 L 0 .075 .175 r
F
.47077 .39689 m .46916 .39554 L .47198 .39512 L F
.83755 .379 m .83932 .37627 L .84056 .37795 L 0 .026 .125 r
F
.83755 .379 m .83631 .37733 L .83932 .37627 L F
.55643 .39958 m .5578 .39799 L .5593 .39884 L 0 .084 .183 r
F
.55643 .39958 m .55493 .39875 L .5578 .39799 L F
.45472 .39295 m .45591 .39095 L .45753 .39271 L 0 .062 .164 r
F
.45472 .39295 m .45311 .39124 L .45591 .39095 L F
.66931 .38352 m .67083 .38081 L .67224 .38257 L 0 .036 .138 r
F
.66931 .38352 m .6679 .38173 L .67083 .38081 L F
.84481 .3787 m .84658 .37587 L .84782 .37768 L 0 .026 .124 r
F
.84481 .3787 m .84357 .37689 L .84658 .37587 L F
.34422 .38192 m .34527 .37914 L .34698 .38101 L 0 .032 .133 r
F
.34422 .38192 m .34251 .38004 L .34527 .37914 L F
.52459 .40388 m .5259 .40335 L .52744 .40366 L 0 .102 .196 r
F
.52459 .40388 m .52304 .40327 L .5259 .40335 L F
.9072 .37775 m .90907 .37501 L .91024 .37671 L 0 .024 .122 r
F
.9072 .37775 m .90602 .37605 L .90907 .37501 L F
.44308 .39122 m .44426 .38882 L .44588 .39052 L 0 .056 .159 r
F
.44308 .39122 m .44145 .38956 L .44426 .38882 L F
.78968 .37939 m .79139 .37671 L .79267 .3784 L 0 .027 .127 r
F
.78968 .37939 m .7884 .37768 L .79139 .37671 L F
.65482 .38442 m .65632 .38171 L .65773 .38321 L 0 .038 .14 r
F
.65482 .38442 m .65341 .38292 L .65632 .38171 L F
.38925 .38442 m .39036 .38168 L .39203 .38354 L F
.38925 .38442 m .38758 .38253 L .39036 .38168 L F
.22515 .37881 m .22601 .37616 L .22785 .37791 L 0 .026 .125 r
F
.22515 .37881 m .22332 .37707 L .22601 .37616 L F
.67657 .38323 m .6781 .38049 L .67949 .38212 L 0 .036 .137 r
F
.67657 .38323 m .67517 .38157 L .6781 .38049 L F
.69831 .38204 m .69988 .37935 L .70125 .3811 L 0 .033 .134 r
F
.69831 .38204 m .69693 .38028 L .69988 .37935 L F
.79694 .37904 m .79866 .37643 L .79993 .37806 L 0 .027 .126 r
F
.79694 .37904 m .79566 .37741 L .79866 .37643 L F
.60848 .38951 m .60993 .3873 L .61137 .38842 L 0 .052 .155 r
F
.60848 .38951 m .60703 .38843 L .60993 .3873 L F
.18451 .37867 m .18532 .37593 L .18719 .37767 L 0 .026 .125 r
F
.18451 .37867 m .18263 .37695 L .18532 .37593 L F
.29193 .3801 m .29288 .3776 L .29465 .37925 L 0 .029 .129 r
F
.29193 .3801 m .29015 .37844 L .29288 .3776 L F
.41978 .38777 m .42094 .38504 L .42258 .38701 L 0 .047 .149 r
F
.41978 .38777 m .41814 .38583 L .42094 .38504 L F
.40814 .38601 m .40926 .38353 L .41092 .38536 L 0 .043 .145 r
F
.40814 .38601 m .40648 .38418 L .40926 .38353 L F
.58103 .39606 m .58243 .39345 L .58391 .39472 L 0 .071 .172 r
F
.58103 .39606 m .57955 .39482 L .58243 .39345 L F
.8042 .37878 m .80593 .37617 L .8072 .37784 L 0 .026 .126 r
F
.8042 .37878 m .80293 .37711 L .80593 .37617 L F
.85209 .37858 m .85388 .37583 L .85511 .37765 L 0 .026 .125 r
F
.85209 .37858 m .85085 .37676 L .85388 .37583 L F
.26578 .37919 m .26669 .37662 L .26849 .37835 L 0 .027 .127 r
F
.26578 .37919 m .26398 .37747 L .26669 .37662 L F
.3776 .38281 m .37868 .38022 L .38036 .38214 L 0 .035 .136 r
F
.3776 .38281 m .37592 .3809 L .37868 .38022 L F
.70557 .38186 m .70714 .37903 L .70851 .3808 L 0 .033 .133 r
F
.70557 .38186 m .7042 .38008 L .70714 .37903 L F
.19174 .37846 m .19255 .37579 L .19441 .37757 L 0 .026 .125 r
F
.19174 .37846 m .18987 .3767 L .19255 .37579 L F
.71282 .38149 m .71441 .37884 L .71578 .38058 L 0 .032 .133 r
F
.71282 .38149 m .71146 .37975 L .71441 .37884 L F
.31806 .3813 m .31906 .37855 L .3208 .3803 L 0 .032 .132 r
F
.31806 .3813 m .31631 .37952 L .31906 .37855 L F
.23238 .37868 m .23326 .37594 L .23508 .37771 L 0 .026 .125 r
F
.23238 .37868 m .23055 .37693 L .23326 .37594 L F
.53909 .40345 m .54042 .40211 L .54195 .4025 L 0 .099 .194 r
F
.53909 .40345 m .53756 .40293 L .54042 .40211 L F
.73457 .38037 m .73619 .37761 L .73753 .37938 L 0 .03 .13 r
F
.73457 .38037 m .73323 .37861 L .73619 .37761 L F
.35144 .382 m .3525 .37927 L .3542 .38112 L 0 .033 .134 r
F
.35144 .382 m .34974 .38014 L .3525 .37927 L F
.72733 .3808 m .72893 .37803 L .73027 .37965 L 0 .031 .131 r
F
.72733 .3808 m .72598 .37917 L .72893 .37803 L F
.3253 .381 m .3263 .37846 L .32804 .38014 L 0 .031 .132 r
F
.3253 .381 m .32356 .37931 L .3263 .37846 L F
.43142 .38986 m .43258 .38748 L .43421 .38939 L 0 .053 .156 r
F
.43142 .38986 m .42979 .38793 L .43258 .38748 L F
.51294 .40253 m .51423 .40158 L .51579 .40204 L 0 .096 .193 r
F
.51294 .40253 m .51138 .40172 L .51423 .40158 L F
.29915 .38002 m .30012 .37744 L .30188 .37912 L 0 .029 .129 r
F
.29915 .38002 m .29738 .37836 L .30012 .37744 L F
.85936 .37844 m .86116 .37562 L .86238 .37739 L 0 .026 .125 r
F
.85936 .37844 m .85813 .37666 L .86116 .37562 L F
.53184 .40398 m .53316 .40321 L .5347 .40362 L 0 .103 .197 r
F
.53184 .40398 m .5303 .40343 L .53316 .40321 L F
.64759 .38528 m .64908 .38261 L .6505 .3841 L 0 .041 .143 r
F
.64759 .38528 m .64617 .38377 L .64908 .38261 L F
.86661 .37806 m .86843 .37535 L .86964 .37706 L 0 .025 .124 r
F
.86661 .37806 m .8654 .37635 L .86843 .37535 L F
.72009 .38131 m .72169 .37868 L .72304 .38031 L 0 .032 .133 r
F
.72009 .38131 m .71873 .37967 L .72169 .37868 L F
.59114 .39338 m .59255 .39095 L .59403 .39224 L 0 .063 .165 r
F
.59114 .39338 m .58967 .39204 L .59255 .39095 L F
.39648 .38453 m .39759 .38208 L .39925 .38384 L 0 .04 .142 r
F
.39648 .38453 m .39481 .38274 L .39759 .38208 L F
.81148 .37874 m .81321 .37603 L .81449 .37783 L 0 .027 .126 r
F
.81148 .37874 m .8102 .37693 L .81321 .37603 L F
.2396 .37856 m .24047 .37599 L .24229 .37774 L 0 .026 .126 r
F
.2396 .37856 m .23778 .37679 L .24047 .37599 L F
.87388 .37777 m .8757 .37508 L .87691 .37679 L 0 .025 .123 r
F
.87388 .37777 m .87267 .37606 L .8757 .37508 L F
.27299 .37923 m .27392 .37658 L .27571 .37833 L 0 .028 .127 r
F
.27299 .37923 m .2712 .37747 L .27392 .37658 L F
.74184 .38024 m .74346 .37738 L .7448 .37921 L 0 .03 .13 r
F
.74184 .38024 m .7405 .37839 L .74346 .37738 L F
.19894 .37848 m .19977 .37575 L .20162 .37756 L 0 .026 .125 r
F
.19894 .37848 m .19709 .37668 L .19977 .37575 L F
.54919 .4008 m .55055 .39948 L .55206 .39969 L 0 .09 .188 r
F
.54919 .4008 m .54768 .40051 L .55055 .39948 L F
.75635 .37949 m .75799 .37672 L .75931 .3784 L 0 .028 .128 r
F
.75635 .37949 m .75503 .37781 L .75799 .37672 L F
.64035 .38594 m .64183 .38332 L .64326 .38487 L 0 .043 .145 r
F
.64035 .38594 m .63892 .38441 L .64183 .38332 L F
.7636 .37912 m .76527 .37653 L .76658 .37818 L 0 .028 .127 r
F
.7636 .37912 m .76229 .37746 L .76527 .37653 L F
.478 .39744 m .47922 .39597 L .48082 .39727 L 0 .079 .179 r
F
.478 .39744 m .4764 .39613 L .47922 .39597 L F
.7491 .37997 m .75073 .37711 L .75206 .3789 L 0 .029 .129 r
F
.7491 .37997 m .74777 .37817 L .75073 .37711 L F
.30638 .38 m .30735 .37749 L .3091 .37927 L 0 .03 .13 r
F
.30638 .38 m .30462 .37823 L .30735 .37749 L F
.88115 .3776 m .88298 .37483 L .88419 .37661 L 0 .025 .123 r
F
.88115 .3776 m .87994 .37581 L .88298 .37483 L F
.33252 .38102 m .33353 .37852 L .33527 .3802 L 0 .032 .133 r
F
.33252 .38102 m .33079 .37934 L .33353 .37852 L F
.35867 .38207 m .35972 .37948 L .36143 .38121 L 0 .034 .135 r
F
.35867 .38207 m .35696 .38029 L .35972 .37948 L F
.4503 .39173 m .45149 .38945 L .45311 .39124 L 0 .06 .162 r
F
.4503 .39173 m .44869 .38999 L .45149 .38945 L F
.81876 .37869 m .8205 .37589 L .82176 .37768 L 0 .027 .126 r
F
.81876 .37869 m .81749 .3769 L .8205 .37589 L F
.48965 .39942 m .49089 .39822 L .49247 .39933 L 0 .086 .185 r
F
.48965 .39942 m .48806 .39826 L .49089 .39822 L F
.77086 .37892 m .77253 .37617 L .77384 .37787 L 0 .027 .127 r
F
.77086 .37892 m .76956 .37721 L .77253 .37617 L F
.20617 .37836 m .207 .37568 L .20885 .3774 L 0 .026 .125 r
F
.20617 .37836 m .20431 .37662 L .207 .37568 L F
.82602 .3784 m .82778 .37572 L .82903 .37745 L 0 .027 .126 r
F
.82602 .3784 m .82477 .37666 L .82778 .37572 L F
.88843 .37741 m .89026 .37459 L .89146 .37639 L 0 .024 .123 r
F
.88843 .37741 m .88722 .3756 L .89026 .37459 L F
.77812 .37863 m .7798 .37589 L .78111 .37768 L 0 .027 .126 r
F
.77812 .37863 m .77682 .37683 L .7798 .37589 L F
.28021 .37923 m .28115 .37667 L .28293 .37839 L 0 .028 .128 r
F
.28021 .37923 m .27843 .37749 L .28115 .37667 L F
.24681 .37864 m .2477 .37599 L .24952 .3777 L 0 .027 .126 r
F
.24681 .37864 m .24499 .37692 L .2477 .37599 L F
.50129 .40139 m .50256 .39957 L .50413 .40089 L 0 .092 .189 r
F
.50129 .40139 m .49972 .39993 L .50256 .39957 L F
.46635 .39597 m .46756 .39381 L .46916 .39554 L 0 .073 .174 r
F
.46635 .39597 m .46474 .39426 L .46756 .39381 L F
.63311 .38676 m .63458 .38386 L .63601 .38551 L 0 .045 .148 r
F
.63311 .38676 m .63167 .38512 L .63458 .38386 L F
.427 .38837 m .42816 .386 L .42979 .38793 L 0 .051 .153 r
F
.427 .38837 m .42537 .38643 L .42816 .386 L F
.60126 .39102 m .60269 .38863 L .60414 .38973 L 0 .058 .16 r
F
.60126 .39102 m .5998 .38991 L .60269 .38863 L F
.2134 .37815 m .21424 .37547 L .21609 .37718 L 0 .026 .125 r
F
.2134 .37815 m .21155 .37644 L .21424 .37547 L F
.3848 .38339 m .38591 .38063 L .38758 .38253 L 0 .037 .139 r
F
.3848 .38339 m .38313 .38147 L .38591 .38063 L F
.41535 .38661 m .4165 .38388 L .41814 .38583 L 0 .045 .148 r
F
.41535 .38661 m .4137 .38469 L .4165 .38388 L F
.33975 .38098 m .34078 .3783 L .34251 .38004 L 0 .032 .133 r
F
.33975 .38098 m .33803 .37925 L .34078 .3783 L F
.3659 .38201 m .36697 .37934 L .36867 .38102 L 0 .034 .136 r
F
.3659 .38201 m .3642 .38033 L .36697 .37934 L F
.25405 .37839 m .25495 .3757 L .25676 .3774 L 0 .027 .126 r
F
.25405 .37839 m .25223 .3767 L .25495 .3757 L F
.8957 .37719 m .89756 .37448 L .89875 .37626 L 0 .024 .123 r
F
.8957 .37719 m .8945 .3754 L .89756 .37448 L F
.66497 .38264 m .66649 .37993 L .6679 .38173 L 0 .036 .137 r
F
.66497 .38264 m .66356 .38082 L .66649 .37993 L F
.4037 .38486 m .40482 .38249 L .40648 .38418 L 0 .042 .144 r
F
.4037 .38486 m .40204 .38314 L .40482 .38249 L F
.83329 .37823 m .83507 .37565 L .83631 .37733 L 0 .027 .126 r
F
.83329 .37823 m .83205 .37655 L .83507 .37565 L F
.5738 .39756 m .57519 .39508 L .57668 .39619 L 0 .078 .178 r
F
.5738 .39756 m .57231 .39647 L .57519 .39508 L F
.37315 .38169 m .37422 .37923 L .37592 .3809 L 0 .034 .135 r
F
.37315 .38169 m .37145 .38002 L .37422 .37923 L F
.61862 .38773 m .62008 .3854 L .62152 .38679 L 0 .049 .152 r
F
.61862 .38773 m .61717 .38636 L .62008 .3854 L F
.43865 .39036 m .43982 .38781 L .44145 .38956 L 0 .056 .158 r
F
.43865 .39036 m .43702 .38862 L .43982 .38781 L F
.68673 .38156 m .68829 .37906 L .68967 .38061 L 0 .034 .135 r
F
.68673 .38156 m .68535 .38002 L .68829 .37906 L F
.84056 .37795 m .84233 .37521 L .84357 .37689 L 0 .026 .125 r
F
.84056 .37795 m .83932 .37627 L .84233 .37521 L F
.7854 .37857 m .7871 .3759 L .7884 .37768 L 0 .027 .127 r
F
.7854 .37857 m .7841 .37679 L .7871 .3759 L F
.22063 .37797 m .22148 .37534 L .22332 .37707 L 0 .026 .125 r
F
.22063 .37797 m .21878 .37625 L .22148 .37534 L F
.65773 .38321 m .65924 .38048 L .66064 .382 L 0 .037 .139 r
F
.65773 .38321 m .65632 .38171 L .65924 .38048 L F
.69399 .38121 m .69556 .37875 L .69693 .38028 L 0 .033 .134 r
F
.69399 .38121 m .69261 .37967 L .69556 .37875 L F
.58391 .39472 m .58531 .39207 L .58679 .39338 L 0 .069 .17 r
F
.58391 .39472 m .58243 .39345 L .58531 .39207 L F
.62587 .38749 m .62733 .38473 L .62877 .38638 L 0 .048 .15 r
F
.62587 .38749 m .62443 .38585 L .62733 .38473 L F
.90298 .37704 m .90485 .37434 L .90602 .37605 L 0 .024 .123 r
F
.90298 .37704 m .9018 .37533 L .90485 .37434 L F
.28743 .37927 m .28837 .37675 L .29015 .37844 L 0 .029 .129 r
F
.28743 .37927 m .28565 .37756 L .28837 .37675 L F
.52019 .40321 m .52149 .40266 L .52304 .40327 L 0 .102 .197 r
F
.52019 .40321 m .51864 .40234 L .52149 .40266 L F
.56655 .39819 m .56794 .39648 L .56943 .39741 L 0 .082 .181 r
F
.56655 .39819 m .56506 .39729 L .56794 .39648 L F
.26127 .37828 m .26218 .37575 L .26398 .37747 L 0 .027 .126 r
F
.26127 .37828 m .25947 .37658 L .26218 .37575 L F
.84782 .37768 m .84961 .37494 L .85085 .37676 L 0 .026 .124 r
F
.84782 .37768 m .84658 .37587 L .84961 .37494 L F
.67949 .38212 m .68103 .3794 L .68242 .381 L 0 .035 .136 r
F
.67949 .38212 m .6781 .38049 L .68103 .3794 L F
.91024 .37671 m .91212 .37398 L .91328 .37568 L 0 .024 .122 r
F
.91024 .37671 m .90907 .37501 L .91212 .37398 L F
.31358 .38034 m .31457 .37775 L .31631 .37952 L 0 .031 .132 r
F
.31358 .38034 m .31183 .37855 L .31457 .37775 L F
.67224 .38257 m .67377 .37984 L .67517 .38157 L 0 .036 .137 r
F
.67224 .38257 m .67083 .38081 L .67377 .37984 L F
.17995 .37796 m .18075 .37524 L .18263 .37695 L 0 .026 .125 r
F
.17995 .37796 m .17807 .37626 L .18075 .37524 L F
.61137 .38842 m .61282 .3862 L .61427 .38739 L 0 .052 .154 r
F
.61137 .38842 m .60993 .3873 L .61282 .3862 L F
.34698 .38101 m .34803 .37828 L .34974 .38014 L 0 .033 .133 r
F
.34698 .38101 m .34527 .37914 L .34803 .37828 L F
.79267 .3784 m .79438 .37574 L .79566 .37741 L 0 .027 .127 r
F
.79267 .3784 m .79139 .37671 L .79438 .37574 L F
.79993 .37806 m .80166 .37547 L .80293 .37711 L 0 .027 .126 r
F
.79993 .37806 m .79866 .37643 L .80166 .37547 L F
.18719 .37767 m .188 .37495 L .18987 .3767 L 0 .026 .125 r
F
.18719 .37767 m .18532 .37593 L .188 .37495 L F
.46194 .39436 m .46314 .39241 L .46474 .39426 L 0 .07 .171 r
F
.46194 .39436 m .46033 .39257 L .46314 .39241 L F
.70125 .3811 m .70282 .37834 L .7042 .38008 L 0 .033 .134 r
F
.70125 .3811 m .69988 .37935 L .70282 .37834 L F
.39203 .38354 m .39314 .38091 L .39481 .38274 L 0 .039 .141 r
F
.39203 .38354 m .39036 .38168 L .39314 .38091 L F
.22785 .37791 m .22872 .37516 L .23055 .37693 L 0 .026 .125 r
F
.22785 .37791 m .22601 .37616 L .22872 .37516 L F
.5593 .39884 m .56068 .39722 L .56218 .39809 L 0 .085 .184 r
F
.5593 .39884 m .5578 .39799 L .56068 .39722 L F
.70851 .3808 m .71009 .37797 L .71146 .37975 L 0 .032 .133 r
F
.70851 .3808 m .70714 .37903 L .71009 .37797 L F
.8072 .37784 m .80894 .37526 L .8102 .37693 L 0 .027 .126 r
F
.8072 .37784 m .80593 .37617 L .80894 .37526 L F
.73027 .37965 m .73189 .37698 L .73323 .37861 L 0 .03 .13 r
F
.73027 .37965 m .72893 .37803 L .73189 .37698 L F
.29465 .37925 m .29561 .3767 L .29738 .37836 L F
.29465 .37925 m .29288 .3776 L .29561 .3767 L F
.44588 .39052 m .44707 .38824 L .44869 .38999 L 0 .058 .16 r
F
.44588 .39052 m .44426 .38882 L .44707 .38824 L F
.85511 .37765 m .8569 .37484 L .85813 .37666 L 0 .026 .125 r
F
.85511 .37765 m .85388 .37583 L .8569 .37484 L F
.6505 .3841 m .652 .38144 L .65341 .38292 L 0 .04 .142 r
F
.6505 .3841 m .64908 .38261 L .652 .38144 L F
.3208 .3803 m .32181 .37758 L .32356 .37931 L 0 .031 .132 r
F
.3208 .3803 m .31906 .37855 L .32181 .37758 L F
.23508 .37771 m .23596 .37499 L .23778 .37679 L 0 .026 .125 r
F
.23508 .37771 m .23326 .37594 L .23596 .37499 L F
.50854 .40186 m .50981 .40124 L .51138 .40172 L 0 .098 .194 r
F
.50854 .40186 m .50697 .40089 L .50981 .40124 L F
.47358 .39644 m .4748 .39482 L .4764 .39613 L 0 .077 .178 r
F
.47358 .39644 m .47198 .39512 L .4748 .39482 L F
.26849 .37835 m .26941 .37572 L .2712 .37747 L 0 .028 .127 r
F
.26849 .37835 m .26669 .37662 L .26941 .37572 L F
.42258 .38701 m .42373 .38445 L .42537 .38643 L 0 .048 .15 r
F
.42258 .38701 m .42094 .38504 L .42373 .38445 L F
.59403 .39224 m .59544 .38987 L .59691 .39111 L 0 .063 .165 r
F
.59403 .39224 m .59255 .39095 L .59544 .38987 L F
.54195 .4025 m .54329 .40128 L .54481 .40155 L 0 .099 .194 r
F
.54195 .4025 m .54042 .40211 L .54329 .40128 L F
.71578 .38058 m .71737 .37794 L .71873 .37967 L 0 .032 .133 r
F
.71578 .38058 m .71441 .37884 L .71737 .37794 L F
.73753 .37938 m .73916 .3766 L .7405 .37839 L 0 .03 .13 r
F
.73753 .37938 m .73619 .37761 L .73916 .3766 L F
.19441 .37757 m .19523 .37488 L .19709 .37668 L 0 .026 .125 r
F
.19441 .37757 m .19255 .37579 L .19523 .37488 L F
.86238 .37739 m .86418 .3746 L .8654 .37635 L 0 .025 .124 r
F
.86238 .37739 m .86116 .37562 L .86418 .3746 L F
.48523 .39833 m .48647 .39708 L .48806 .39826 L 0 .085 .183 r
F
.48523 .39833 m .48364 .39709 L .48647 .39708 L F
.86964 .37706 m .87146 .37435 L .87267 .37606 L 0 .025 .124 r
F
.86964 .37706 m .86843 .37535 L .87146 .37435 L F
.72304 .38031 m .72464 .37755 L .72598 .37917 L 0 .032 .132 r
F
.72304 .38031 m .72169 .37868 L .72464 .37755 L F
.3542 .38112 m .35526 .37848 L .35696 .38029 L 0 .034 .135 r
F
.3542 .38112 m .3525 .37927 L .35526 .37848 L F
.38036 .38214 m .38145 .37955 L .38313 .38147 L 0 .036 .138 r
F
.38036 .38214 m .37868 .38022 L .38145 .37955 L F
.30188 .37912 m .30286 .37651 L .30462 .37823 L 0 .029 .129 r
F
.30188 .37912 m .30012 .37744 L .30286 .37651 L F
.41092 .38536 m .41205 .38284 L .4137 .38469 L 0 .044 .146 r
F
.41092 .38536 m .40926 .38353 L .41205 .38284 L F
.32804 .38014 m .32905 .37766 L .33079 .37934 L 0 .032 .132 r
F
.32804 .38014 m .3263 .37846 L .32905 .37766 L F
.49688 .40028 m .49814 .39915 L .49972 .39993 L 0 .092 .189 r
F
.49688 .40028 m .4953 .39924 L .49814 .39915 L F
.55206 .39969 m .55342 .39854 L .55493 .39875 L 0 .09 .188 r
F
.55206 .39969 m .55055 .39948 L .55342 .39854 L F
.87691 .37679 m .87874 .37411 L .87994 .37581 L 0 .025 .123 r
F
.87691 .37679 m .8757 .37508 L .87874 .37411 L F
.75931 .3784 m .76097 .37579 L .76229 .37746 L 0 .028 .128 r
F
.75931 .3784 m .75799 .37672 L .76097 .37579 L F
.7448 .37921 m .74643 .37637 L .74777 .37817 L 0 .029 .129 r
F
.7448 .37921 m .74346 .37738 L .74643 .37637 L F
.45753 .39271 m .45872 .39077 L .46033 .39257 L 0 .066 .167 r
F
.45753 .39271 m .45591 .39095 L .45872 .39077 L F
.64326 .38487 m .64475 .38221 L .64617 .38377 L 0 .043 .145 r
F
.64326 .38487 m .64183 .38332 L .64475 .38221 L F
.81449 .37783 m .81622 .37511 L .81749 .3769 L 0 .027 .126 r
F
.81449 .37783 m .81321 .37603 L .81622 .37511 L F
.75206 .3789 m .7537 .37603 L .75503 .37781 L 0 .029 .129 r
F
.75206 .3789 m .75073 .37711 L .7537 .37603 L F
.52744 .40366 m .52876 .40348 L .5303 .40343 L 0 .107 .2 r
F
.52744 .40366 m .5259 .40335 L .52876 .40348 L F
.27571 .37833 m .27664 .37574 L .27843 .37749 L 0 .028 .128 r
F
.27571 .37833 m .27392 .37658 L .27664 .37574 L F
.24229 .37774 m .24317 .37519 L .24499 .37692 L 0 .027 .126 r
F
.24229 .37774 m .24047 .37599 L .24317 .37519 L F
.20162 .37756 m .20246 .37481 L .20431 .37662 L 0 .026 .125 r
F
.20162 .37756 m .19977 .37575 L .20246 .37481 L F
.76658 .37818 m .76825 .37557 L .76956 .37721 L 0 .028 .127 r
F
.76658 .37818 m .76527 .37653 L .76825 .37557 L F
.39925 .38384 m .40037 .38141 L .40204 .38314 L 0 .041 .143 r
F
.39925 .38384 m .39759 .38208 L .40037 .38141 L F
.88419 .37661 m .88602 .37382 L .88722 .3756 L 0 .024 .123 r
F
.88419 .37661 m .88298 .37483 L .88602 .37382 L F
.60414 .38973 m .60558 .38735 L .60703 .38843 L 0 .056 .159 r
F
.60414 .38973 m .60269 .38863 L .60558 .38735 L F
.63601 .38551 m .63749 .38275 L .63892 .38441 L 0 .044 .147 r
F
.63601 .38551 m .63458 .38386 L .63749 .38275 L F
.77384 .37787 m .77551 .37513 L .77682 .37683 L 0 .027 .126 r
F
.77384 .37787 m .77253 .37617 L .77551 .37513 L F
.82176 .37768 m .8235 .37488 L .82477 .37666 L F
.82176 .37768 m .8205 .37589 L .8235 .37488 L F
.57668 .39619 m .57806 .3937 L .57955 .39482 L 0 .075 .176 r
F
.57668 .39619 m .57519 .39508 L .57806 .3937 L F
.51579 .40204 m .51708 .40242 L .51864 .40234 L 0 .102 .197 r
F
.51579 .40204 m .51423 .40158 L .51708 .40242 L F
.43421 .38939 m .43539 .38674 L .43702 .38862 L 0 .055 .157 r
F
.43421 .38939 m .43258 .38748 L .43539 .38674 L F
.33527 .3802 m .33629 .37757 L .33803 .37925 L 0 .032 .133 r
F
.33527 .3802 m .33353 .37852 L .33629 .37757 L F
.36143 .38121 m .36249 .37862 L .3642 .38033 L 0 .035 .136 r
F
.36143 .38121 m .35972 .37948 L .36249 .37862 L F
.89146 .37639 m .89331 .3736 L .8945 .3754 L 0 .024 .123 r
F
.89146 .37639 m .89026 .37459 L .89331 .3736 L F
.20885 .3774 m .20969 .37472 L .21155 .37644 L 0 .026 .125 r
F
.20885 .3774 m .207 .37568 L .20969 .37472 L F
.82903 .37745 m .8308 .37483 L .83205 .37655 L 0 .027 .126 r
F
.82903 .37745 m .82778 .37572 L .8308 .37483 L F
.3091 .37927 m .31008 .37677 L .31183 .37855 L 0 .031 .131 r
F
.3091 .37927 m .30735 .37749 L .31008 .37677 L F
.5347 .40362 m .53603 .4027 L .53756 .40293 L 0 .105 .199 r
F
.5347 .40362 m .53316 .40321 L .53603 .4027 L F
.78111 .37768 m .7828 .375 L .7841 .37679 L 0 .027 .126 r
F
.78111 .37768 m .7798 .37589 L .7828 .375 L F
.58679 .39338 m .58819 .39071 L .58967 .39204 L 0 .067 .168 r
F
.58679 .39338 m .58531 .39207 L .58819 .39071 L F
.24952 .3777 m .25042 .37499 L .25223 .3767 L 0 .027 .126 r
F
.24952 .3777 m .2477 .37599 L .25042 .37499 L F
.66064 .382 m .66215 .37929 L .66356 .38082 L 0 .036 .138 r
F
.66064 .382 m .65924 .38048 L .66215 .37929 L F
.21609 .37718 m .21694 .37454 L .21878 .37625 L 0 .026 .125 r
F
.21609 .37718 m .21424 .37547 L .21694 .37454 L F
.28293 .37839 m .28387 .37585 L .28565 .37756 L 0 .029 .129 r
F
.28293 .37839 m .28115 .37667 L .28387 .37585 L F
.36867 .38102 m .36975 .37835 L .37145 .38002 L 0 .034 .135 r
F
.36867 .38102 m .36697 .37934 L .36975 .37835 L F
.25676 .3774 m .25766 .37488 L .25947 .37658 L 0 .027 .126 r
F
.25676 .3774 m .25495 .3757 L .25766 .37488 L F
.34251 .38004 m .34355 .37739 L .34527 .37914 L 0 .032 .133 r
F
.34251 .38004 m .34078 .3783 L .34355 .37739 L F
.89875 .37626 m .90061 .37356 L .9018 .37533 L 0 .024 .123 r
F
.89875 .37626 m .89756 .37448 L .90061 .37356 L F
.84357 .37689 m .84535 .37419 L .84658 .37587 L 0 .026 .125 r
F
.84357 .37689 m .84233 .37521 L .84535 .37419 L F
.6679 .38173 m .66943 .37905 L .67083 .38081 L 0 .036 .137 r
F
.6679 .38173 m .66649 .37993 L .66943 .37905 L F
.38758 .38253 m .38869 .3798 L .39036 .38168 L 0 .038 .139 r
F
.38758 .38253 m .38591 .38063 L .38869 .3798 L F
.62877 .38638 m .63023 .38347 L .63167 .38512 L 0 .047 .149 r
F
.62877 .38638 m .62733 .38473 L .63023 .38347 L F
.83631 .37733 m .83808 .37459 L .83932 .37627 L 0 .027 .126 r
F
.83631 .37733 m .83507 .37565 L .83808 .37459 L F
.62152 .38679 m .62298 .38444 L .62443 .38585 L 0 .049 .152 r
F
.62152 .38679 m .62008 .3854 L .62298 .38444 L F
.45311 .39124 m .4543 .38912 L .45591 .39095 L 0 .062 .164 r
F
.45311 .39124 m .45149 .38945 L .4543 .38912 L F
.41814 .38583 m .4193 .38307 L .42094 .38504 L 0 .046 .148 r
F
.41814 .38583 m .4165 .38388 L .4193 .38307 L F
.68242 .381 m .68397 .37842 L .68535 .38002 L 0 .035 .136 r
F
.68242 .381 m .68103 .3794 L .68397 .37842 L F
.68967 .38061 m .69124 .37811 L .69261 .37967 L 0 .034 .135 r
F
.68967 .38061 m .68829 .37906 L .69124 .37811 L F
.90602 .37605 m .9079 .37331 L .90907 .37501 L 0 .024 .122 r
F
.90602 .37605 m .90485 .37434 L .9079 .37331 L F
.69693 .38028 m .69851 .37782 L .69988 .37935 L 0 .033 .134 r
F
.69693 .38028 m .69556 .37875 L .69851 .37782 L F
.22332 .37707 m .22417 .37444 L .22601 .37616 L 0 .026 .125 r
F
.22332 .37707 m .22148 .37534 L .22417 .37444 L F
.37592 .3809 m .37699 .37856 L .37868 .38022 L 0 .035 .136 r
F
.37592 .3809 m .37422 .37923 L .37699 .37856 L F
.7884 .37768 m .7901 .37496 L .79139 .37671 L 0 .027 .127 r
F
.7884 .37768 m .7871 .3759 L .7901 .37496 L F
.44145 .38956 m .44263 .38707 L .44426 .38882 L 0 .057 .159 r
F
.44145 .38956 m .43982 .38781 L .44263 .38707 L F
.61427 .38739 m .61573 .38512 L .61717 .38636 L 0 .051 .154 r
F
.61427 .38739 m .61282 .3862 L .61573 .38512 L F
.67517 .38157 m .6767 .3788 L .6781 .38049 L 0 .036 .137 r
F
.67517 .38157 m .67377 .37984 L .6767 .3788 L F
.40648 .38418 m .4076 .38186 L .40926 .38353 L 0 .043 .145 r
F
.40648 .38418 m .40482 .38249 L .4076 .38186 L F
.48082 .39727 m .48205 .39582 L .48364 .39709 L 0 .083 .182 r
F
.48082 .39727 m .47922 .39597 L .48205 .39582 L F
.50413 .40089 m .5054 .39992 L .50697 .40089 L 0 .096 .192 r
F
.50413 .40089 m .50256 .39957 L .5054 .39992 L F
.18263 .37695 m .18344 .37422 L .18532 .37593 L 0 .026 .125 r
F
.18263 .37695 m .18075 .37524 L .18344 .37422 L F
.85085 .37676 m .85264 .37401 L .85388 .37583 L 0 .026 .124 r
F
.85085 .37676 m .84961 .37494 L .85264 .37401 L F
.79566 .37741 m .79738 .37478 L .79866 .37643 L 0 .027 .126 r
F
.79566 .37741 m .79438 .37574 L .79738 .37478 L F
.29015 .37844 m .2911 .37593 L .29288 .3776 L 0 .03 .13 r
F
.29015 .37844 m .28837 .37675 L .2911 .37593 L F
.46916 .39554 m .47038 .39336 L .47198 .39512 L 0 .076 .176 r
F
.46916 .39554 m .46756 .39381 L .47038 .39336 L F
.42979 .38793 m .43095 .38557 L .43258 .38748 L 0 .053 .155 r
F
.42979 .38793 m .42816 .386 L .43095 .38557 L F
.7042 .38008 m .70577 .37728 L .70714 .37903 L 0 .033 .133 r
F
.7042 .38008 m .70282 .37834 L .70577 .37728 L F
.26398 .37747 m .26489 .37489 L .26669 .37662 L 0 .027 .127 r
F
.26398 .37747 m .26218 .37575 L .26489 .37489 L F
.56943 .39741 m .57082 .39551 L .57231 .39647 L 0 .082 .182 r
F
.56943 .39741 m .56794 .39648 L .57082 .39551 L F
.65341 .38292 m .65491 .38023 L .65632 .38171 L 0 .039 .141 r
F
.65341 .38292 m .652 .38144 L .65491 .38023 L F
.18987 .3767 m .19068 .37402 L .19255 .37579 L 0 .026 .125 r
F
.18987 .3767 m .188 .37495 L .19068 .37402 L F
.31631 .37952 m .31731 .37679 L .31906 .37855 L 0 .032 .132 r
F
.31631 .37952 m .31457 .37775 L .31731 .37679 L F
.80293 .37711 m .80466 .37451 L .80593 .37617 L 0 .027 .126 r
F
.80293 .37711 m .80166 .37547 L .80466 .37451 L F
.34974 .38014 m .35079 .37742 L .3525 .37927 L 0 .033 .134 r
F
.34974 .38014 m .34803 .37828 L .35079 .37742 L F
.23055 .37693 m .23143 .37415 L .23326 .37594 L 0 .026 .125 r
F
.23055 .37693 m .22872 .37516 L .23143 .37415 L F
.71146 .37975 m .71305 .37707 L .71441 .37884 L 0 .032 .133 r
F
.71146 .37975 m .71009 .37797 L .71305 .37707 L F
.49247 .39933 m .49372 .39822 L .4953 .39924 L 0 .091 .188 r
F
.49247 .39933 m .49089 .39822 L .49372 .39822 L F
.73323 .37861 m .73485 .37595 L .73619 .37761 L 0 .03 .13 r
F
.73323 .37861 m .73189 .37698 L .73485 .37595 L F
.59691 .39111 m .59834 .38871 L .5998 .38991 L 0 .062 .164 r
F
.59691 .39111 m .59544 .38987 L .59834 .38871 L F
.85813 .37666 m .85993 .37383 L .86116 .37562 L 0 .026 .124 r
F
.85813 .37666 m .8569 .37484 L .85993 .37383 L F
.32356 .37931 m .32456 .37674 L .3263 .37846 L 0 .032 .132 r
F
.32356 .37931 m .32181 .37758 L .32456 .37674 L F
.39481 .38274 m .39592 .38027 L .39759 .38208 L 0 .04 .142 r
F
.39481 .38274 m .39314 .38091 L .39592 .38027 L F
.8102 .37693 m .81195 .37436 L .81321 .37603 L 0 .027 .126 r
F
.8102 .37693 m .80894 .37526 L .81195 .37436 L F
.29738 .37836 m .29835 .37575 L .30012 .37744 L 0 .03 .13 r
F
.29738 .37836 m .29561 .3767 L .29835 .37575 L F
.8654 .37635 m .86721 .3736 L .86843 .37535 L 0 .025 .124 r
F
.8654 .37635 m .86418 .3746 L .86721 .3736 L F
.56218 .39809 m .56356 .39639 L .56506 .39729 L 0 .086 .184 r
F
.56218 .39809 m .56068 .39722 L .56356 .39639 L F
.72598 .37917 m .72759 .37642 L .72893 .37803 L 0 .031 .132 r
F
.72598 .37917 m .72464 .37755 L .72759 .37642 L F
.7405 .37839 m .74212 .37561 L .74346 .37738 L 0 .029 .129 r
F
.7405 .37839 m .73916 .3766 L .74212 .37561 L F
.54481 .40155 m .54616 .40034 L .54768 .40051 L 0 .099 .194 r
F
.54481 .40155 m .54329 .40128 L .54616 .40034 L F
.23778 .37679 m .23866 .37417 L .24047 .37599 L 0 .026 .126 r
F
.23778 .37679 m .23596 .37499 L .23866 .37417 L F
.71873 .37967 m .72033 .37695 L .72169 .37868 L 0 .032 .133 r
F
.71873 .37967 m .71737 .37794 L .72033 .37695 L F
.2712 .37747 m .27213 .37482 L .27392 .37658 L 0 .028 .127 r
F
.2712 .37747 m .26941 .37572 L .27213 .37482 L F
.87267 .37606 m .8745 .37337 L .8757 .37508 L 0 .025 .124 r
F
.87267 .37606 m .87146 .37435 L .8745 .37337 L F
.19709 .37668 m .19792 .37393 L .19977 .37575 L 0 .026 .125 r
F
.19709 .37668 m .19523 .37488 L .19792 .37393 L F
.57955 .39482 m .58094 .39229 L .58243 .39345 L 0 .073 .174 r
F
.57955 .39482 m .57806 .3937 L .58094 .39229 L F
.64617 .38377 m .64766 .38107 L .64908 .38261 L 0 .042 .144 r
F
.64617 .38377 m .64475 .38221 L .64766 .38107 L F
.60703 .38843 m .60848 .38617 L .60993 .3873 L 0 .055 .158 r
F
.60703 .38843 m .60558 .38735 L .60848 .38617 L F
.74777 .37817 m .7494 .37532 L .75073 .37711 L 0 .029 .129 r
F
.74777 .37817 m .74643 .37637 L .7494 .37532 L F
.75503 .37781 m .75667 .37495 L .75799 .37672 L 0 .028 .128 r
F
.75503 .37781 m .7537 .37603 L .75667 .37495 L F
.55493 .39875 m .5563 .3977 L .5578 .39799 L 0 .09 .188 r
F
.55493 .39875 m .55342 .39854 L .5563 .3977 L F
.87994 .37581 m .88178 .37313 L .88298 .37483 L 0 .025 .123 r
F
.87994 .37581 m .87874 .37411 L .88178 .37313 L F
.30462 .37823 m .30559 .37576 L .30735 .37749 L 0 .03 .13 r
F
.30462 .37823 m .30286 .37651 L .30559 .37576 L F
.76229 .37746 m .76396 .37488 L .76527 .37653 L 0 .028 .128 r
F
.76229 .37746 m .76097 .37579 L .76396 .37488 L F
.35696 .38029 m .35802 .3777 L .35972 .37948 L 0 .034 .135 r
F
.35696 .38029 m .35526 .37848 L .35802 .3777 L F
.81749 .3769 m .81923 .3741 L .8205 .37589 L 0 .027 .126 r
F
.81749 .3769 m .81622 .37511 L .81923 .3741 L F
.44869 .38999 m .44988 .38766 L .45149 .38945 L 0 .06 .162 r
F
.44869 .38999 m .44707 .38824 L .44988 .38766 L F
.33079 .37934 m .3318 .37685 L .33353 .37852 L 0 .032 .133 r
F
.33079 .37934 m .32905 .37766 L .3318 .37685 L F
.58967 .39204 m .59108 .38966 L .59255 .39095 L 0 .065 .167 r
F
.58967 .39204 m .58819 .39071 L .59108 .38966 L F
.63892 .38441 m .6404 .38166 L .64183 .38332 L 0 .044 .146 r
F
.63892 .38441 m .63749 .38275 L .6404 .38166 L F
.42537 .38643 m .42652 .38403 L .42816 .386 L 0 .05 .152 r
F
.42537 .38643 m .42373 .38445 L .42652 .38403 L F
.88722 .3756 m .88906 .37281 L .89026 .37459 L 0 .024 .123 r
F
.88722 .3756 m .88602 .37382 L .88906 .37281 L F
.76956 .37721 m .77123 .37453 L .77253 .37617 L 0 .028 .127 r
F
.76956 .37721 m .76825 .37557 L .77123 .37453 L F
.20431 .37662 m .20515 .37386 L .207 .37568 L 0 .026 .125 r
F
.20431 .37662 m .20246 .37481 L .20515 .37386 L F
.77682 .37683 m .77851 .37419 L .7798 .37589 L 0 .027 .126 r
F
.77682 .37683 m .77551 .37513 L .77851 .37419 L F
.38313 .38147 m .38423 .37873 L .38591 .38063 L 0 .037 .138 r
F
.38313 .38147 m .38145 .37955 L .38423 .37873 L F
.4137 .38469 m .41485 .38201 L .4165 .38388 L 0 .045 .147 r
F
.4137 .38469 m .41205 .38284 L .41485 .38201 L F
.82477 .37666 m .82652 .37395 L .82778 .37572 L 0 .027 .126 r
F
.82477 .37666 m .8235 .37488 L .82652 .37395 L F
.27843 .37749 m .27936 .37491 L .28115 .37667 L 0 .029 .128 r
F
.27843 .37749 m .27664 .37574 L .27936 .37491 L F
.52304 .40327 m .52435 .40303 L .5259 .40335 L 0 .109 .202 r
F
.52304 .40327 m .52149 .40266 L .52435 .40303 L F
.24499 .37692 m .24588 .37426 L .2477 .37599 L 0 .027 .127 r
F
.24499 .37692 m .24317 .37519 L .24588 .37426 L F
.46474 .39426 m .46596 .39194 L .46756 .39381 L 0 .073 .174 r
F
.46474 .39426 m .46314 .39241 L .46596 .39194 L F
.66356 .38082 m .66509 .37839 L .66649 .37993 L 0 .036 .138 r
F
.66356 .38082 m .66215 .37929 L .66509 .37839 L F
.4764 .39613 m .47762 .39468 L .47922 .39597 L 0 .081 .181 r
F
.4764 .39613 m .4748 .39482 L .47762 .39468 L F
.8945 .3754 m .89636 .37269 L .89756 .37448 L 0 .024 .123 r
F
.8945 .3754 m .89331 .3736 L .89636 .37269 L F
.33803 .37925 m .33905 .37661 L .34078 .3783 L 0 .032 .133 r
F
.33803 .37925 m .33629 .37757 L .33905 .37661 L F
.21155 .37644 m .21239 .37375 L .21424 .37547 L 0 .026 .125 r
F
.21155 .37644 m .20969 .37472 L .21239 .37375 L F
.63167 .38512 m .63314 .38221 L .63458 .38386 L 0 .046 .148 r
F
.63167 .38512 m .63023 .38347 L .63314 .38221 L F
.40204 .38314 m .40315 .38079 L .40482 .38249 L 0 .042 .144 r
F
.40204 .38314 m .40037 .38141 L .40315 .38079 L F
.25223 .3767 m .25314 .37401 L .25495 .3757 L 0 .027 .126 r
F
.25223 .3767 m .25042 .37499 L .25314 .37401 L F
.3642 .38033 m .36527 .37764 L .36697 .37934 L 0 .035 .136 r
F
.3642 .38033 m .36249 .37862 L .36527 .37764 L F
.43702 .38862 m .43819 .38598 L .43982 .38781 L 0 .056 .158 r
F
.43702 .38862 m .43539 .38674 L .43819 .38598 L F
.83205 .37655 m .83383 .37393 L .83507 .37565 L 0 .027 .126 r
F
.83205 .37655 m .8308 .37483 L .83383 .37393 L F
.51138 .40172 m .51266 .40159 L .51423 .40158 L 0 .104 .198 r
F
.51138 .40172 m .50981 .40124 L .51266 .40159 L F
.49972 .39993 m .50098 .39905 L .50256 .39957 L 0 .096 .192 r
F
.49972 .39993 m .49814 .39915 L .50098 .39905 L F
.7841 .37679 m .7858 .37412 L .7871 .3759 L 0 .027 .127 r
F
.7841 .37679 m .7828 .375 L .7858 .37412 L F
.37145 .38002 m .37252 .37756 L .37422 .37923 L 0 .035 .136 r
F
.37145 .38002 m .36975 .37835 L .37252 .37756 L F
.21878 .37625 m .21963 .37363 L .22148 .37534 L 0 .026 .125 r
F
.21878 .37625 m .21694 .37454 L .21963 .37363 L F
.83932 .37627 m .8411 .37353 L .84233 .37521 L F
.83932 .37627 m .83808 .37459 L .8411 .37353 L F
.84658 .37587 m .84838 .37324 L .84961 .37494 L 0 .026 .124 r
F
.84658 .37587 m .84535 .37419 L .84838 .37324 L F
.48806 .39826 m .4893 .39709 L .49089 .39822 L 0 .09 .187 r
F
.48806 .39826 m .48647 .39708 L .4893 .39709 L F
.34527 .37914 m .34631 .37651 L .34803 .37828 L 0 .032 .133 r
F
.34527 .37914 m .34355 .37739 L .34631 .37651 L F
.31183 .37855 m .31282 .37596 L .31457 .37775 L 0 .031 .132 r
F
.31183 .37855 m .31008 .37677 L .31282 .37596 L F
.9018 .37533 m .90367 .37258 L .90485 .37434 L 0 .024 .123 r
F
.9018 .37533 m .90061 .37356 L .90367 .37258 L F
.28565 .37756 m .28659 .37505 L .28837 .37675 L 0 .029 .129 r
F
.28565 .37756 m .28387 .37585 L .28659 .37505 L F
.53756 .40293 m .5389 .40208 L .54042 .40211 L 0 .107 .2 r
F
.53756 .40293 m .53603 .4027 L .5389 .40208 L F
.25947 .37658 m .26037 .37405 L .26218 .37575 L 0 .027 .127 r
F
.25947 .37658 m .25766 .37488 L .26037 .37405 L F
.67083 .38081 m .67236 .37811 L .67377 .37984 L 0 .036 .138 r
F
.67083 .38081 m .66943 .37905 L .67236 .37811 L F
.62443 .38585 m .62589 .3833 L .62733 .38473 L 0 .049 .151 r
F
.62443 .38585 m .62298 .38444 L .62589 .3833 L F
.68535 .38002 m .68691 .37746 L .68829 .37906 L 0 .035 .136 r
F
.68535 .38002 m .68397 .37842 L .68691 .37746 L F
.90907 .37501 m .91095 .37228 L .91212 .37398 L 0 .024 .122 r
F
.90907 .37501 m .9079 .37331 L .91095 .37228 L F
.39036 .38168 m .39147 .37905 L .39314 .38091 L 0 .038 .14 r
F
.39036 .38168 m .38869 .3798 L .39147 .37905 L F
.69261 .37967 m .69419 .3772 L .69556 .37875 L 0 .034 .135 r
F
.69261 .37967 m .69124 .37811 L .69419 .3772 L F
.5303 .40343 m .53163 .4036 L .53316 .40321 L 0 .112 .204 r
F
.5303 .40343 m .52876 .40348 L .53163 .4036 L F
.17807 .37626 m .17886 .37353 L .18075 .37524 L 0 .026 .125 r
F
.17807 .37626 m .17618 .37455 L .17886 .37353 L F
.6781 .38049 m .67963 .37775 L .68103 .3794 L 0 .035 .137 r
F
.6781 .38049 m .6767 .3788 L .67963 .37775 L F
.46033 .39257 m .46153 .39056 L .46314 .39241 L 0 .069 .171 r
F
.46033 .39257 m .45872 .39077 L .46153 .39056 L F
.65632 .38171 m .65783 .37899 L .65924 .38048 L 0 .038 .14 r
F
.65632 .38171 m .65491 .38023 L .65783 .37899 L F
.61717 .38636 m .61863 .38413 L .62008 .3854 L 0 .051 .154 r
F
.61717 .38636 m .61573 .38512 L .61863 .38413 L F
.79139 .37671 m .7931 .37402 L .79438 .37574 L 0 .027 .127 r
F
.79139 .37671 m .7901 .37496 L .7931 .37402 L F
.69988 .37935 m .70146 .37679 L .70282 .37834 L 0 .033 .134 r
F
.69988 .37935 m .69851 .37782 L .70146 .37679 L F
.18532 .37593 m .18612 .37323 L .188 .37495 L 0 .026 .125 r
F
.18532 .37593 m .18344 .37422 L .18612 .37323 L F
.22601 .37616 m .22688 .37342 L .22872 .37516 L F
.22601 .37616 m .22417 .37444 L .22688 .37342 L F
.42094 .38504 m .42209 .38247 L .42373 .38445 L 0 .047 .149 r
F
.42094 .38504 m .4193 .38307 L .42209 .38247 L F
.70714 .37903 m .70872 .37621 L .71009 .37797 L 0 .032 .133 r
F
.70714 .37903 m .70577 .37728 L .70872 .37621 L F
.5998 .38991 m .60123 .38747 L .60269 .38863 L 0 .061 .163 r
F
.5998 .38991 m .59834 .38871 L .60123 .38747 L F
.79866 .37643 m .80038 .37381 L .80166 .37547 L 0 .027 .126 r
F
.79866 .37643 m .79738 .37478 L .80038 .37381 L F
.85388 .37583 m .85567 .37304 L .8569 .37484 L 0 .026 .124 r
F
.85388 .37583 m .85264 .37401 L .85567 .37304 L F
.57231 .39647 m .5737 .39411 L .57519 .39508 L 0 .081 .181 r
F
.57231 .39647 m .57082 .39551 L .5737 .39411 L F
.31906 .37855 m .32007 .37584 L .32181 .37758 L 0 .032 .132 r
F
.31906 .37855 m .31731 .37679 L .32007 .37584 L F
.44426 .38882 m .44544 .38649 L .44707 .38824 L 0 .058 .16 r
F
.44426 .38882 m .44263 .38707 L .44544 .38649 L F
.58243 .39345 m .58383 .39088 L .58531 .39207 L 0 .071 .172 r
F
.58243 .39345 m .58094 .39229 L .58383 .39088 L F
.23326 .37594 m .23414 .37319 L .23596 .37499 L 0 .026 .125 r
F
.23326 .37594 m .23143 .37415 L .23414 .37319 L F
.80593 .37617 m .80767 .3736 L .80894 .37526 L 0 .027 .126 r
F
.80593 .37617 m .80466 .37451 L .80767 .3736 L F
.29288 .3776 m .29383 .37503 L .29561 .3767 L 0 .03 .13 r
F
.29288 .3776 m .2911 .37593 L .29383 .37503 L F
.19255 .37579 m .19337 .37308 L .19523 .37488 L 0 .026 .125 r
F
.19255 .37579 m .19068 .37402 L .19337 .37308 L F
.37868 .38022 m .37976 .37788 L .38145 .37955 L 0 .036 .137 r
F
.37868 .38022 m .37699 .37856 L .37976 .37788 L F
.73619 .37761 m .73782 .37493 L .73916 .3766 L 0 .03 .13 r
F
.73619 .37761 m .73485 .37595 L .73782 .37493 L F
.26669 .37662 m .26761 .37397 L .26941 .37572 L 0 .028 .127 r
F
.26669 .37662 m .26489 .37489 L .26761 .37397 L F
.72893 .37803 m .73055 .37534 L .73189 .37698 L 0 .031 .131 r
F
.72893 .37803 m .72759 .37642 L .73055 .37534 L F
.71441 .37884 m .71601 .37617 L .71737 .37794 L 0 .032 .133 r
F
.71441 .37884 m .71305 .37707 L .71601 .37617 L F
.86116 .37562 m .86296 .37282 L .86418 .3746 L 0 .025 .124 r
F
.86116 .37562 m .85993 .37383 L .86296 .37282 L F
.3525 .37927 m .35355 .37666 L .35526 .37848 L 0 .033 .134 r
F
.3525 .37927 m .35079 .37742 L .35355 .37666 L F
.40926 .38353 m .41039 .3812 L .41205 .38284 L 0 .044 .146 r
F
.40926 .38353 m .4076 .38186 L .41039 .3812 L F
.54768 .40051 m .54904 .39939 L .55055 .39948 L 0 .099 .194 r
F
.54768 .40051 m .54616 .40034 L .54904 .39939 L F
.86843 .37535 m .87025 .37259 L .87146 .37435 L 0 .025 .124 r
F
.86843 .37535 m .86721 .3736 L .87025 .37259 L F
.64908 .38261 m .65058 .37993 L .652 .38144 L 0 .041 .143 r
F
.64908 .38261 m .64766 .38107 L .65058 .37993 L F
.74346 .37738 m .74509 .37461 L .74643 .37637 L 0 .029 .129 r
F
.74346 .37738 m .74212 .37561 L .74509 .37461 L F
.60993 .3873 m .61137 .38501 L .61282 .3862 L 0 .054 .157 r
F
.60993 .3873 m .60848 .38617 L .61137 .38501 L F
.30012 .37744 m .30109 .3748 L .30286 .37651 L 0 .03 .13 r
F
.30012 .37744 m .29835 .37575 L .30109 .3748 L F
.81321 .37603 m .81496 .37344 L .81622 .37511 L 0 .027 .126 r
F
.81321 .37603 m .81195 .37436 L .81496 .37344 L F
.3263 .37846 m .32731 .37596 L .32905 .37766 L 0 .032 .133 r
F
.3263 .37846 m .32456 .37674 L .32731 .37596 L F
.45591 .39095 m .45711 .38888 L .45872 .39077 L 0 .065 .167 r
F
.45591 .39095 m .4543 .38912 L .45711 .38888 L F
.72169 .37868 m .72328 .37584 L .72464 .37755 L 0 .032 .133 r
F
.72169 .37868 m .72033 .37695 L .72328 .37584 L F
.8757 .37508 m .87754 .3724 L .87874 .37411 L 0 .025 .123 r
F
.8757 .37508 m .8745 .37337 L .87754 .3724 L F
.75073 .37711 m .75237 .37425 L .7537 .37603 L 0 .029 .129 r
F
.75073 .37711 m .7494 .37532 L .75237 .37425 L F
.75799 .37672 m .75965 .37405 L .76097 .37579 L 0 .028 .128 r
F
.75799 .37672 m .75667 .37495 L .75965 .37405 L F
.56506 .39729 m .56644 .39555 L .56794 .39648 L 0 .086 .185 r
F
.56506 .39729 m .56356 .39639 L .56644 .39555 L F
.19977 .37575 m .20061 .37298 L .20246 .37481 L 0 .026 .125 r
F
.19977 .37575 m .19792 .37393 L .20061 .37298 L F
.51864 .40234 m .51993 .40329 L .52149 .40266 L 0 .111 .203 r
F
.51864 .40234 m .51708 .40242 L .51993 .40329 L F
.27392 .37658 m .27485 .37395 L .27664 .37574 L 0 .028 .128 r
F
.27392 .37658 m .27213 .37482 L .27485 .37395 L F
.47198 .39512 m .4732 .39306 L .4748 .39482 L 0 .078 .178 r
F
.47198 .39512 m .47038 .39336 L .4732 .39306 L F
.24047 .37599 m .24136 .37335 L .24317 .37519 L 0 .027 .126 r
F
.24047 .37599 m .23866 .37417 L .24136 .37335 L F
.43258 .38748 m .43375 .38487 L .43539 .38674 L 0 .054 .157 r
F
.43258 .38748 m .43095 .38557 L .43375 .38487 L F
.39759 .38208 m .3987 .37964 L .40037 .38141 L 0 .041 .143 r
F
.39759 .38208 m .39592 .38027 L .3987 .37964 L F
.88298 .37483 m .88482 .37211 L .88602 .37382 L 0 .025 .123 r
F
.88298 .37483 m .88178 .37313 L .88482 .37211 L F
.59255 .39095 m .59397 .38862 L .59544 .38987 L 0 .065 .167 r
F
.59255 .39095 m .59108 .38966 L .59397 .38862 L F
.64183 .38332 m .64332 .38056 L .64475 .38221 L 0 .043 .146 r
F
.64183 .38332 m .6404 .38166 L .64332 .38056 L F
.8205 .37589 m .82224 .3731 L .8235 .37488 L 0 .027 .126 r
F
.8205 .37589 m .81923 .3741 L .82224 .3731 L F
.76527 .37653 m .76695 .37393 L .76825 .37557 L 0 .028 .128 r
F
.76527 .37653 m .76396 .37488 L .76695 .37393 L F
.48364 .39709 m .48487 .39586 L .48647 .39708 L 0 .087 .186 r
F
.48364 .39709 m .48205 .39582 L .48487 .39586 L F
.77253 .37617 m .77422 .37349 L .77551 .37513 L 0 .027 .127 r
F
.77253 .37617 m .77123 .37453 L .77422 .37349 L F
.89026 .37459 m .89211 .37182 L .89331 .3736 L 0 .024 .122 r
F
.89026 .37459 m .88906 .37281 L .89211 .37182 L F
.63458 .38386 m .63605 .38109 L .63749 .38275 L 0 .045 .147 r
F
.63458 .38386 m .63314 .38221 L .63605 .38109 L F
.5578 .39799 m .55918 .39685 L .56068 .39722 L 0 .091 .188 r
F
.5578 .39799 m .5563 .3977 L .55918 .39685 L F
.35972 .37948 m .36079 .37687 L .36249 .37862 L 0 .035 .136 r
F
.35972 .37948 m .35802 .3777 L .36079 .37687 L F
.30735 .37749 m .30832 .37501 L .31008 .37677 L 0 .031 .131 r
F
.30735 .37749 m .30559 .37576 L .30832 .37501 L F
.207 .37568 m .20785 .37288 L .20969 .37472 L 0 .026 .125 r
F
.207 .37568 m .20515 .37386 L .20785 .37288 L F
.7798 .37589 m .7815 .37329 L .7828 .375 L 0 .027 .126 r
F
.7798 .37589 m .77851 .37419 L .7815 .37329 L F
.33353 .37852 m .33456 .37588 L .33629 .37757 L 0 .033 .133 r
F
.33353 .37852 m .3318 .37685 L .33456 .37588 L F
.50697 .40089 m .50824 .40076 L .50981 .40124 L 0 .104 .198 r
F
.50697 .40089 m .5054 .39992 L .50824 .40076 L F
.82778 .37572 m .82955 .37307 L .8308 .37483 L 0 .027 .126 r
F
.82778 .37572 m .82652 .37395 L .82955 .37307 L F
.2477 .37599 m .2486 .37328 L .25042 .37499 L 0 .027 .127 r
F
.2477 .37599 m .24588 .37426 L .2486 .37328 L F
.38591 .38063 m .38701 .37792 L .38869 .3798 L 0 .037 .139 r
F
.38591 .38063 m .38423 .37873 L .38701 .37792 L F
.4165 .38388 m .41765 .38118 L .4193 .38307 L 0 .045 .148 r
F
.4165 .38388 m .41485 .38201 L .41765 .38118 L F
.28115 .37667 m .28208 .37409 L .28387 .37585 L 0 .029 .129 r
F
.28115 .37667 m .27936 .37491 L .28208 .37409 L F
.21424 .37547 m .21509 .37282 L .21694 .37454 L 0 .026 .125 r
F
.21424 .37547 m .21239 .37375 L .21509 .37282 L F
.4953 .39924 m .49656 .39839 L .49814 .39915 L 0 .096 .192 r
F
.4953 .39924 m .49372 .39822 L .49656 .39839 L F
.34078 .3783 m .34182 .37567 L .34355 .37739 L 0 .032 .133 r
F
.34078 .3783 m .33905 .37661 L .34182 .37567 L F
.89756 .37448 m .89942 .37178 L .90061 .37356 L 0 .024 .123 r
F
.89756 .37448 m .89636 .37269 L .89942 .37178 L F
.66649 .37993 m .66802 .37749 L .66943 .37905 L 0 .036 .138 r
F
.66649 .37993 m .66509 .37839 L .66802 .37749 L F
.25495 .3757 m .25585 .37319 L .25766 .37488 L 0 .027 .126 r
F
.25495 .3757 m .25314 .37401 L .25585 .37319 L F
.36697 .37934 m .36805 .37667 L .36975 .37835 L 0 .035 .136 r
F
.36697 .37934 m .36527 .37764 L .36805 .37667 L F
.45149 .38945 m .45269 .38728 L .4543 .38912 L 0 .062 .164 r
F
.45149 .38945 m .44988 .38766 L .45269 .38728 L F
.84233 .37521 m .84411 .3725 L .84535 .37419 L 0 .026 .125 r
F
.84233 .37521 m .8411 .37353 L .84411 .3725 L F
.83507 .37565 m .83684 .37288 L .83808 .37459 L 0 .027 .126 r
F
.83507 .37565 m .83383 .37393 L .83684 .37288 L F
.65924 .38048 m .66075 .37778 L .66215 .37929 L 0 .037 .139 r
F
.65924 .38048 m .65783 .37899 L .66075 .37778 L F
.62733 .38473 m .62879 .382 L .63023 .38347 L 0 .048 .15 r
F
.62733 .38473 m .62589 .3833 L .62879 .382 L F
.7871 .3759 m .7888 .3732 L .7901 .37496 L 0 .027 .127 r
F
.7871 .3759 m .7858 .37412 L .7888 .3732 L F
.43982 .38781 m .441 .38528 L .44263 .38707 L 0 .057 .159 r
F
.43982 .38781 m .43819 .38598 L .441 .38528 L F
.42816 .386 m .42931 .3836 L .43095 .38557 L 0 .052 .154 r
F
.42816 .386 m .42652 .38403 L .42931 .3836 L F
.60269 .38863 m .60412 .38623 L .60558 .38735 L 0 .059 .161 r
F
.60269 .38863 m .60123 .38747 L .60412 .38623 L F
.57519 .39508 m .57658 .39271 L .57806 .3937 L 0 .079 .179 r
F
.57519 .39508 m .5737 .39411 L .57658 .39271 L F
.22148 .37534 m .22233 .37273 L .22417 .37444 L 0 .026 .126 r
F
.22148 .37534 m .21963 .37363 L .22233 .37273 L F
.84961 .37494 m .85141 .3723 L .85264 .37401 L 0 .026 .124 r
F
.84961 .37494 m .84838 .37324 L .85141 .3723 L F
.90485 .37434 m .90672 .37157 L .9079 .37331 L 0 .024 .123 r
F
.90485 .37434 m .90367 .37258 L .90672 .37157 L F
.58531 .39207 m .58671 .38948 L .58819 .39071 L 0 .069 .17 r
F
.58531 .39207 m .58383 .39088 L .58671 .38948 L F
.68103 .3794 m .68258 .37678 L .68397 .37842 L 0 .035 .136 r
F
.68103 .3794 m .67963 .37775 L .68258 .37678 L F
.37422 .37923 m .37529 .37689 L .37699 .37856 L 0 .035 .137 r
F
.37422 .37923 m .37252 .37756 L .37529 .37689 L F
.67377 .37984 m .6753 .3771 L .6767 .3788 L 0 .036 .137 r
F
.67377 .37984 m .67236 .37811 L .6753 .3771 L F
.68829 .37906 m .68986 .37652 L .69124 .37811 L 0 .035 .136 r
F
.68829 .37906 m .68691 .37746 L .68986 .37652 L F
.40482 .38249 m .40594 .38019 L .4076 .38186 L 0 .043 .145 r
F
.40482 .38249 m .40315 .38079 L .40594 .38019 L F
.18075 .37524 m .18155 .37251 L .18344 .37422 L 0 .026 .125 r
F
.18075 .37524 m .17886 .37353 L .18155 .37251 L F
.34803 .37828 m .34907 .37562 L .35079 .37742 L 0 .033 .134 r
F
.34803 .37828 m .34631 .37651 L .34907 .37562 L F
.46756 .39381 m .46878 .39146 L .47038 .39336 L 0 .075 .176 r
F
.46756 .39381 m .46596 .39194 L .46878 .39146 L F
.70282 .37834 m .7044 .37569 L .70577 .37728 L 0 .033 .134 r
F
.70282 .37834 m .70146 .37679 L .7044 .37569 L F
.69556 .37875 m .69714 .37629 L .69851 .37782 L 0 .034 .135 r
F
.69556 .37875 m .69419 .3772 L .69714 .37629 L F
.54042 .40211 m .54177 .40145 L .54329 .40128 L 0 .108 .201 r
F
.54042 .40211 m .5389 .40208 L .54177 .40145 L F
.31457 .37775 m .31557 .375 L .31731 .37679 L 0 .032 .132 r
F
.31457 .37775 m .31282 .37596 L .31557 .375 L F
.62008 .3854 m .62154 .38314 L .62298 .38444 L 0 .051 .154 r
F
.62008 .3854 m .61863 .38413 L .62154 .38314 L F
.28837 .37675 m .28932 .37426 L .2911 .37593 L 0 .03 .13 r
F
.28837 .37675 m .28659 .37505 L .28932 .37426 L F
.79438 .37574 m .7961 .37307 L .79738 .37478 L 0 .027 .127 r
F
.79438 .37574 m .7931 .37402 L .7961 .37307 L F
.71009 .37797 m .71168 .37531 L .71305 .37707 L 0 .032 .133 r
F
.71009 .37797 m .70872 .37621 L .71168 .37531 L F
.26218 .37575 m .26309 .37319 L .26489 .37489 L 0 .028 .127 r
F
.26218 .37575 m .26037 .37405 L .26309 .37319 L F
.188 .37495 m .18881 .37228 L .19068 .37402 L 0 .026 .125 r
F
.188 .37495 m .18612 .37323 L .18881 .37228 L F
.22872 .37516 m .2296 .3724 L .23143 .37415 L F
.22872 .37516 m .22688 .37342 L .2296 .3724 L F
.8569 .37484 m .8587 .37204 L .85993 .37383 L 0 .026 .124 r
F
.8569 .37484 m .85567 .37304 L .8587 .37204 L F
.39314 .38091 m .39425 .37845 L .39592 .38027 L 0 .039 .141 r
F
.39314 .38091 m .39147 .37905 L .39425 .37845 L F
.80166 .37547 m .80339 .37284 L .80466 .37451 L 0 .027 .126 r
F
.80166 .37547 m .80038 .37381 L .80339 .37284 L F
.32181 .37758 m .32281 .37502 L .32456 .37674 L 0 .032 .132 r
F
.32181 .37758 m .32007 .37584 L .32281 .37502 L F
.73189 .37698 m .73351 .37429 L .73485 .37595 L 0 .03 .131 r
F
.73189 .37698 m .73055 .37534 L .73351 .37429 L F
.73916 .3766 m .74079 .37394 L .74212 .37561 L 0 .03 .13 r
F
.73916 .3766 m .73782 .37493 L .74079 .37394 L F
.23596 .37499 m .23684 .37235 L .23866 .37417 L 0 .026 .125 r
F
.23596 .37499 m .23414 .37319 L .23684 .37235 L F
.652 .38144 m .6535 .37872 L .65491 .38023 L 0 .04 .142 r
F
.652 .38144 m .65058 .37993 L .6535 .37872 L F
.50256 .39957 m .50382 .39994 L .5054 .39992 L 0 .102 .197 r
F
.50256 .39957 m .50098 .39905 L .50382 .39994 L F
.86418 .3746 m .86599 .37182 L .86721 .3736 L 0 .025 .124 r
F
.86418 .3746 m .86296 .37282 L .86599 .37182 L F
.47922 .39597 m .48045 .39454 L .48205 .39582 L 0 .085 .184 r
F
.47922 .39597 m .47762 .39468 L .48045 .39454 L F
.80894 .37526 m .81069 .37271 L .81195 .37436 L 0 .027 .126 r
F
.80894 .37526 m .80767 .3736 L .81069 .37271 L F
.19523 .37488 m .19606 .37212 L .19792 .37393 L 0 .026 .125 r
F
.19523 .37488 m .19337 .37308 L .19606 .37212 L F
.29561 .3767 m .29657 .37407 L .29835 .37575 L 0 .03 .13 r
F
.29561 .3767 m .29383 .37503 L .29657 .37407 L F
.55055 .39948 m .55191 .39845 L .55342 .39854 L 0 .099 .194 r
F
.55055 .39948 m .54904 .39939 L .55191 .39845 L F
.71737 .37794 m .71897 .3752 L .72033 .37695 L 0 .032 .133 r
F
.71737 .37794 m .71601 .37617 L .71897 .3752 L F
.26941 .37572 m .27034 .37305 L .27213 .37482 L 0 .028 .127 r
F
.26941 .37572 m .26761 .37397 L .27034 .37305 L F
.61282 .3862 m .61428 .38387 L .61573 .38512 L 0 .054 .156 r
F
.61282 .3862 m .61137 .38501 L .61428 .38387 L F
.72464 .37755 m .72624 .37473 L .72759 .37642 L 0 .031 .132 r
F
.72464 .37755 m .72328 .37584 L .72624 .37473 L F
.5259 .40335 m .52721 .40352 L .52876 .40348 L 0 .116 .207 r
F
.5259 .40335 m .52435 .40303 L .52721 .40352 L F
.87146 .37435 m .87329 .37162 L .8745 .37337 L 0 .025 .124 r
F
.87146 .37435 m .87025 .37259 L .87329 .37162 L F
.74643 .37637 m .74807 .37358 L .7494 .37532 L 0 .029 .129 r
F
.74643 .37637 m .74509 .37461 L .74807 .37358 L F
.42373 .38445 m .42488 .38204 L .42652 .38403 L 0 .049 .151 r
F
.42373 .38445 m .42209 .38247 L .42488 .38204 L F
.51423 .40158 m .51551 .40317 L .51708 .40242 L 0 .113 .205 r
F
.51423 .40158 m .51266 .40159 L .51551 .40317 L F
.7537 .37603 m .75534 .37318 L .75667 .37495 L 0 .028 .128 r
F
.7537 .37603 m .75237 .37425 L .75534 .37318 L F
.35526 .37848 m .35631 .37592 L .35802 .3777 L 0 .034 .135 r
F
.35526 .37848 m .35355 .37666 L .35631 .37592 L F
.30286 .37651 m .30382 .37402 L .30559 .37576 L 0 .03 .13 r
F
.30286 .37651 m .30109 .3748 L .30382 .37402 L F
.81622 .37511 m .81797 .37241 L .81923 .3741 L 0 .027 .126 r
F
.81622 .37511 m .81496 .37344 L .81797 .37241 L F
.87874 .37411 m .88058 .37143 L .88178 .37313 L 0 .025 .123 r
F
.87874 .37411 m .87754 .3724 L .88058 .37143 L F
.38145 .37955 m .38254 .37705 L .38423 .37873 L 0 .037 .138 r
F
.38145 .37955 m .37976 .37788 L .38254 .37705 L F
.44707 .38824 m .44825 .38591 L .44988 .38766 L 0 .06 .162 r
F
.44707 .38824 m .44544 .38649 L .44825 .38591 L F
.59544 .38987 m .59687 .38751 L .59834 .38871 L 0 .064 .166 r
F
.59544 .38987 m .59397 .38862 L .59687 .38751 L F
.64475 .38221 m .64623 .37946 L .64766 .38107 L 0 .043 .145 r
F
.64475 .38221 m .64332 .38056 L .64623 .37946 L F
.76097 .37579 m .76264 .37316 L .76396 .37488 L 0 .028 .128 r
F
.76097 .37579 m .75965 .37405 L .76264 .37316 L F
.41205 .38284 m .41319 .38038 L .41485 .38201 L 0 .045 .147 r
F
.41205 .38284 m .41039 .3812 L .41319 .38038 L F
.53316 .40321 m .5345 .40354 L .53603 .4027 L 0 .117 .207 r
F
.53316 .40321 m .53163 .4036 L .5345 .40354 L F
.20246 .37481 m .2033 .37202 L .20515 .37386 L 0 .026 .125 r
F
.20246 .37481 m .20061 .37298 L .2033 .37202 L F
.88602 .37382 m .88787 .37109 L .88906 .37281 L 0 .024 .123 r
F
.88602 .37382 m .88482 .37211 L .88787 .37109 L F
.32905 .37766 m .33006 .37515 L .3318 .37685 L 0 .033 .133 r
F
.32905 .37766 m .32731 .37596 L .33006 .37515 L F
.49089 .39822 m .49213 .3972 L .49372 .39822 L 0 .095 .191 r
F
.49089 .39822 m .4893 .39709 L .49213 .3972 L F
.8235 .37488 m .82526 .37217 L .82652 .37395 L 0 .027 .126 r
F
.8235 .37488 m .82224 .3731 L .82526 .37217 L F
.46314 .39241 m .46435 .39005 L .46596 .39194 L 0 .072 .173 r
F
.46314 .39241 m .46153 .39056 L .46435 .39005 L F
.63749 .38275 m .63896 .37999 L .6404 .38166 L 0 .044 .147 r
F
.63749 .38275 m .63605 .38109 L .63896 .37999 L F
.56794 .39648 m .56932 .39456 L .57082 .39551 L 0 .087 .185 r
F
.56794 .39648 m .56644 .39555 L .56932 .39456 L F
.77551 .37513 m .77721 .37253 L .77851 .37419 L 0 .027 .127 r
F
.77551 .37513 m .77422 .37349 L .77721 .37253 L F
.27664 .37574 m .27758 .37309 L .27936 .37491 L 0 .028 .128 r
F
.27664 .37574 m .27485 .37395 L .27758 .37309 L F
.76825 .37557 m .76993 .37288 L .77123 .37453 L F
.76825 .37557 m .76695 .37393 L .76993 .37288 L F
.24317 .37519 m .24407 .37242 L .24588 .37426 L 0 .027 .127 r
F
.24317 .37519 m .24136 .37335 L .24407 .37242 L F
.89331 .3736 m .89517 .37092 L .89636 .37269 L 0 .024 .122 r
F
.89331 .3736 m .89211 .37182 L .89517 .37092 L F
.43539 .38674 m .43656 .38414 L .43819 .38598 L 0 .055 .158 r
F
.43539 .38674 m .43375 .38487 L .43656 .38414 L F
.20969 .37472 m .21055 .3719 L .21239 .37375 L 0 .026 .125 r
F
.20969 .37472 m .20785 .37288 L .21055 .3719 L F
.33629 .37757 m .33732 .37491 L .33905 .37661 L 0 .033 .133 r
F
.33629 .37757 m .33456 .37588 L .33732 .37491 L F
.57806 .3937 m .57946 .39128 L .58094 .39229 L 0 .077 .177 r
F
.57806 .3937 m .57658 .39271 L .57946 .39128 L F
.40037 .38141 m .40148 .37905 L .40315 .38079 L 0 .042 .144 r
F
.40037 .38141 m .3987 .37964 L .40148 .37905 L F
.58819 .39071 m .5896 .38846 L .59108 .38966 L 0 .068 .169 r
F
.58819 .39071 m .58671 .38948 L .5896 .38846 L F
.36249 .37862 m .36356 .37592 L .36527 .37764 L 0 .035 .136 r
F
.36249 .37862 m .36079 .37687 L .36356 .37592 L F
.25042 .37499 m .25132 .3723 L .25314 .37401 L 0 .027 .126 r
F
.25042 .37499 m .2486 .37328 L .25132 .3723 L F
.7828 .375 m .78451 .3724 L .7858 .37412 L 0 .027 .127 r
F
.7828 .375 m .7815 .37329 L .78451 .3724 L F
.63023 .38347 m .6317 .3807 L .63314 .38221 L 0 .047 .149 r
F
.63023 .38347 m .62879 .382 L .6317 .3807 L F
.8308 .37483 m .83258 .37218 L .83383 .37393 L 0 .027 .126 r
F
.8308 .37483 m .82955 .37307 L .83258 .37218 L F
.56068 .39722 m .56206 .39591 L .56356 .39639 L 0 .092 .189 r
F
.56068 .39722 m .55918 .39685 L .56206 .39591 L F
.66215 .37929 m .66368 .37687 L .66509 .37839 L 0 .037 .139 r
F
.66215 .37929 m .66075 .37778 L .66368 .37687 L F
.60558 .38735 m .60702 .38501 L .60848 .38617 L 0 .058 .16 r
F
.60558 .38735 m .60412 .38623 L .60702 .38501 L F
.36975 .37835 m .37082 .37588 L .37252 .37756 L 0 .035 .136 r
F
.36975 .37835 m .36805 .37667 L .37082 .37588 L F
.21694 .37454 m .21778 .37192 L .21963 .37363 L 0 .027 .126 r
F
.21694 .37454 m .21509 .37282 L .21778 .37192 L F
.31008 .37677 m .31106 .37417 L .31282 .37596 L 0 .031 .132 r
F
.31008 .37677 m .30832 .37501 L .31106 .37417 L F
.38869 .3798 m .38979 .37719 L .39147 .37905 L 0 .038 .14 r
F
.38869 .3798 m .38701 .37792 L .38979 .37719 L F
.34355 .37739 m .34458 .37475 L .34631 .37651 L 0 .033 .133 r
F
.34355 .37739 m .34182 .37567 L .34458 .37475 L F
.90061 .37356 m .90248 .37082 L .90367 .37258 L 0 .024 .123 r
F
.90061 .37356 m .89942 .37178 L .90248 .37082 L F
.84535 .37419 m .84714 .37154 L .84838 .37324 L 0 .026 .125 r
F
.84535 .37419 m .84411 .3725 L .84714 .37154 L F
.83808 .37459 m .83986 .37182 L .8411 .37353 L 0 .026 .126 r
F
.83808 .37459 m .83684 .37288 L .83986 .37182 L F
.4193 .38307 m .42045 .38057 L .42209 .38247 L 0 .046 .149 r
F
.4193 .38307 m .41765 .38118 L .42045 .38057 L F
.66943 .37905 m .67096 .37654 L .67236 .37811 L 0 .037 .138 r
F
.66943 .37905 m .66802 .37749 L .67096 .37654 L F
.28387 .37585 m .28481 .37331 L .28659 .37505 L 0 .029 .129 r
F
.28387 .37585 m .28208 .37409 L .28481 .37331 L F
.45872 .39077 m .45992 .38863 L .46153 .39056 L 0 .069 .17 r
F
.45872 .39077 m .45711 .38888 L .45992 .38863 L F
.4748 .39482 m .47603 .39295 L .47762 .39468 L 0 .082 .181 r
F
.4748 .39482 m .4732 .39306 L .47603 .39295 L F
.25766 .37488 m .25856 .37236 L .26037 .37405 L 0 .028 .127 r
F
.25766 .37488 m .25585 .37319 L .25856 .37236 L F
.9079 .37331 m .90977 .37055 L .91095 .37228 L 0 .024 .122 r
F
.9079 .37331 m .90672 .37157 L .90977 .37055 L F
.17618 .37455 m .17698 .37172 L .17886 .37353 L 0 .026 .126 r
F
.17618 .37455 m .1743 .37274 L .17698 .37172 L F
.7901 .37496 m .79181 .37229 L .7931 .37402 L 0 .028 .127 r
F
.7901 .37496 m .7888 .3732 L .79181 .37229 L F
.6767 .3788 m .67824 .3761 L .67963 .37775 L 0 .036 .137 r
F
.6767 .3788 m .6753 .3771 L .67824 .3761 L F
.68397 .37842 m .68552 .37582 L .68691 .37746 L 0 .035 .136 r
F
.68397 .37842 m .68258 .37678 L .68552 .37582 L F
.85264 .37401 m .85444 .37131 L .85567 .37304 L 0 .026 .124 r
F
.85264 .37401 m .85141 .3723 L .85444 .37131 L F
.18344 .37422 m .18424 .37151 L .18612 .37323 L 0 .026 .125 r
F
.18344 .37422 m .18155 .37251 L .18424 .37151 L F
.22417 .37444 m .22504 .37171 L .22688 .37342 L 0 .026 .126 r
F
.22417 .37444 m .22233 .37273 L .22504 .37171 L F
.70577 .37728 m .70735 .37459 L .70872 .37621 L 0 .033 .133 r
F
.70577 .37728 m .7044 .37569 L .70735 .37459 L F
.69124 .37811 m .69281 .37562 L .69419 .3772 L 0 .035 .136 r
F
.69124 .37811 m .68986 .37652 L .69281 .37562 L F
.23143 .37415 m .23231 .37142 L .23414 .37319 L 0 .026 .125 r
F
.23143 .37415 m .2296 .3724 L .23231 .37142 L F
.62298 .38444 m .62445 .38196 L .62589 .3833 L 0 .05 .153 r
F
.62298 .38444 m .62154 .38314 L .62445 .38196 L F
.79738 .37478 m .7991 .3721 L .80038 .37381 L 0 .027 .127 r
F
.79738 .37478 m .7961 .37307 L .7991 .3721 L F
.44263 .38707 m .44381 .38474 L .44544 .38649 L 0 .058 .16 r
F
.44263 .38707 m .441 .38528 L .44381 .38474 L F
.31731 .37679 m .31832 .37404 L .32007 .37584 L 0 .032 .132 r
F
.31731 .37679 m .31557 .375 L .31832 .37404 L F
.65491 .38023 m .65641 .37749 L .65783 .37899 L 0 .039 .141 r
F
.65491 .38023 m .6535 .37872 L .65641 .37749 L F
.69851 .37782 m .70009 .37524 L .70146 .37679 L 0 .034 .135 r
F
.69851 .37782 m .69714 .37629 L .70009 .37524 L F
.35079 .37742 m .35183 .37485 L .35355 .37666 L 0 .033 .134 r
F
.35079 .37742 m .34907 .37562 L .35183 .37485 L F
.19068 .37402 m .1915 .37132 L .19337 .37308 L 0 .026 .125 r
F
.19068 .37402 m .18881 .37228 L .1915 .37132 L F
.85993 .37383 m .86173 .37104 L .86296 .37282 L 0 .025 .124 r
F
.85993 .37383 m .8587 .37204 L .86173 .37104 L F
.71305 .37707 m .71464 .37441 L .71601 .37617 L 0 .032 .133 r
F
.71305 .37707 m .71168 .37531 L .71464 .37441 L F
.54329 .40128 m .54464 .40063 L .54616 .40034 L 0 .109 .202 r
F
.54329 .40128 m .54177 .40145 L .54464 .40063 L F
.26489 .37489 m .26581 .37226 L .26761 .37397 L 0 .028 .127 r
F
.26489 .37489 m .26309 .37319 L .26581 .37226 L F
.48647 .39708 m .48771 .39594 L .4893 .39709 L 0 .093 .19 r
F
.48647 .39708 m .48487 .39586 L .48771 .39594 L F
.80466 .37451 m .8064 .37194 L .80767 .3736 L 0 .027 .127 r
F
.80466 .37451 m .80339 .37284 L .8064 .37194 L F
.2911 .37593 m .29205 .37337 L .29383 .37503 L 0 .03 .13 r
F
.2911 .37593 m .28932 .37426 L .29205 .37337 L F
.37699 .37856 m .37806 .37621 L .37976 .37788 L 0 .036 .138 r
F
.37699 .37856 m .37529 .37689 L .37806 .37621 L F
.73485 .37595 m .73648 .37325 L .73782 .37493 L 0 .03 .13 r
F
.73485 .37595 m .73351 .37429 L .73648 .37325 L F
.72759 .37642 m .7292 .37367 L .73055 .37534 L 0 .031 .131 r
F
.72759 .37642 m .72624 .37473 L .7292 .37367 L F
.74212 .37561 m .74376 .37295 L .74509 .37461 L 0 .029 .129 r
F
.74212 .37561 m .74079 .37394 L .74376 .37295 L F
.86721 .3736 m .86903 .37082 L .87025 .37259 L 0 .025 .124 r
F
.86721 .3736 m .86599 .37182 L .86903 .37082 L F
.4076 .38186 m .40873 .37955 L .41039 .3812 L 0 .044 .147 r
F
.4076 .38186 m .40594 .38019 L .40873 .37955 L F
.4543 .38912 m .4555 .38699 L .45711 .38888 L 0 .065 .167 r
F
.4543 .38912 m .45269 .38728 L .4555 .38699 L F
.52149 .40266 m .5228 .40427 L .52435 .40303 L 0 .121 .21 r
F
.52149 .40266 m .51993 .40329 L .5228 .40427 L F
.61573 .38512 m .61719 .38286 L .61863 .38413 L 0 .053 .156 r
F
.61573 .38512 m .61428 .38387 L .61719 .38286 L F
.43095 .38557 m .43212 .38293 L .43375 .38487 L 0 .054 .156 r
F
.43095 .38557 m .42931 .3836 L .43212 .38293 L F
.7494 .37532 m .75104 .37251 L .75237 .37425 L 0 .029 .129 r
F
.7494 .37532 m .74807 .37358 L .75104 .37251 L F
.32456 .37674 m .32556 .37425 L .32731 .37596 L 0 .032 .133 r
F
.32456 .37674 m .32281 .37502 L .32556 .37425 L F
.72033 .37695 m .72193 .37412 L .72328 .37584 L F
.72033 .37695 m .71897 .3752 L .72193 .37412 L F
.19792 .37393 m .19875 .37116 L .20061 .37298 L 0 .026 .125 r
F
.19792 .37393 m .19606 .37212 L .19875 .37116 L F
.29835 .37575 m .29932 .37311 L .30109 .3748 L 0 .03 .13 r
F
.29835 .37575 m .29657 .37407 L .29932 .37311 L F
.75667 .37495 m .75833 .3723 L .75965 .37405 L 0 .028 .128 r
F
.75667 .37495 m .75534 .37318 L .75833 .3723 L F
.55342 .39854 m .55479 .39752 L .5563 .3977 L 0 .099 .194 r
F
.55342 .39854 m .55191 .39845 L .55479 .39752 L F
.49814 .39915 m .4994 .39855 L .50098 .39905 L 0 .102 .197 r
F
.49814 .39915 m .49656 .39839 L .4994 .39855 L F
.81195 .37436 m .8137 .37178 L .81496 .37344 L 0 .027 .127 r
F
.81195 .37436 m .81069 .37271 L .8137 .37178 L F
.8745 .37337 m .87633 .37066 L .87754 .3724 L 0 .025 .124 r
F
.8745 .37337 m .87329 .37162 L .87633 .37066 L F
.23866 .37417 m .23954 .37152 L .24136 .37335 L 0 .027 .126 r
F
.23866 .37417 m .23684 .37235 L .23954 .37152 L F
.59834 .38871 m .59976 .38631 L .60123 .38747 L 0 .063 .165 r
F
.59834 .38871 m .59687 .38751 L .59976 .38631 L F
.27213 .37482 m .27306 .37216 L .27485 .37395 L 0 .028 .128 r
F
.27213 .37482 m .27034 .37305 L .27306 .37216 L F
.47038 .39336 m .4716 .39115 L .4732 .39306 L 0 .078 .178 r
F
.47038 .39336 m .46878 .39146 L .4716 .39115 L F
.64766 .38107 m .64916 .37836 L .65058 .37993 L 0 .042 .144 r
F
.64766 .38107 m .64623 .37946 L .64916 .37836 L F
.39592 .38027 m .39703 .37784 L .3987 .37964 L 0 .041 .143 r
F
.39592 .38027 m .39425 .37845 L .39703 .37784 L F
.81923 .3741 m .82098 .37139 L .82224 .3731 L 0 .027 .126 r
F
.81923 .3741 m .81797 .37241 L .82098 .37139 L F
.88178 .37313 m .88363 .3704 L .88482 .37211 L 0 .025 .123 r
F
.88178 .37313 m .88058 .37143 L .88363 .3704 L F
.58094 .39229 m .58234 .38983 L .58383 .39088 L 0 .074 .175 r
F
.58094 .39229 m .57946 .39128 L .58234 .38983 L F
.6404 .38166 m .64188 .3789 L .64332 .38056 L 0 .044 .146 r
F
.6404 .38166 m .63896 .37999 L .64188 .3789 L F
.88906 .37281 m .89091 .37009 L .89211 .37182 L 0 .024 .122 r
F
.88906 .37281 m .88787 .37109 L .89091 .37009 L F
.50981 .40124 m .51109 .4016 L .51266 .40159 L 0 .113 .204 r
F
.50981 .40124 m .50824 .40076 L .51109 .4016 L F
.20515 .37386 m .206 .37102 L .20785 .37288 L 0 .026 .125 r
F
.20515 .37386 m .2033 .37202 L .206 .37102 L F
.76396 .37488 m .76563 .37223 L .76695 .37393 L 0 .028 .128 r
F
.76396 .37488 m .76264 .37316 L .76563 .37223 L F
.35802 .3777 m .35908 .37513 L .36079 .37687 L 0 .035 .136 r
F
.35802 .3777 m .35631 .37592 L .35908 .37513 L F
.38423 .37873 m .38532 .37622 L .38701 .37792 L 0 .037 .139 r
F
.38423 .37873 m .38254 .37705 L .38532 .37622 L F
.77123 .37453 m .77291 .37184 L .77422 .37349 L 0 .028 .127 r
F
.77123 .37453 m .76993 .37288 L .77291 .37184 L F
.63314 .38221 m .63461 .37954 L .63605 .38109 L 0 .045 .148 r
F
.63314 .38221 m .6317 .3807 L .63461 .37954 L F
.30559 .37576 m .30656 .37324 L .30832 .37501 L 0 .031 .131 r
F
.30559 .37576 m .30382 .37402 L .30656 .37324 L F
.57082 .39551 m .57221 .39314 L .5737 .39411 L 0 .085 .184 r
F
.57082 .39551 m .56932 .39456 L .57221 .39314 L F
.82652 .37395 m .82829 .3713 L .82955 .37307 L 0 .027 .126 r
F
.82652 .37395 m .82526 .37217 L .82829 .3713 L F
.41485 .38201 m .41599 .37955 L .41765 .38118 L 0 .045 .148 r
F
.41485 .38201 m .41319 .38038 L .41599 .37955 L F
.77851 .37419 m .78021 .37163 L .7815 .37329 L 0 .027 .127 r
F
.77851 .37419 m .77721 .37253 L .78021 .37163 L F
.3318 .37685 m .33282 .37419 L .33456 .37588 L 0 .033 .134 r
F
.3318 .37685 m .33006 .37515 L .33282 .37419 L F
.24588 .37426 m .24679 .37143 L .2486 .37328 L 0 .027 .127 r
F
.24588 .37426 m .24407 .37242 L .24679 .37143 L F
.60848 .38617 m .60992 .3838 L .61137 .38501 L 0 .057 .159 r
F
.60848 .38617 m .60702 .38501 L .60992 .3838 L F
.89636 .37269 m .89823 .37002 L .89942 .37178 L 0 .024 .123 r
F
.89636 .37269 m .89517 .37092 L .89823 .37002 L F
.27936 .37491 m .28031 .37225 L .28208 .37409 L 0 .029 .129 r
F
.27936 .37491 m .27758 .37309 L .28031 .37225 L F
.59108 .38966 m .5925 .38743 L .59397 .38862 L 0 .067 .169 r
F
.59108 .38966 m .5896 .38846 L .5925 .38743 L F
.42652 .38403 m .42768 .38162 L .42931 .3836 L 0 .051 .154 r
F
.42652 .38403 m .42488 .38204 L .42768 .38162 L F
.21239 .37375 m .21324 .37097 L .21509 .37282 L 0 .026 .125 r
F
.21239 .37375 m .21055 .3719 L .21324 .37097 L F
.44988 .38766 m .45106 .38553 L .45269 .38728 L 0 .062 .164 r
F
.44988 .38766 m .44825 .38591 L .45106 .38553 L F
.33905 .37661 m .34009 .37395 L .34182 .37567 L 0 .033 .133 r
F
.33905 .37661 m .33732 .37491 L .34009 .37395 L F
.25314 .37401 m .25403 .37148 L .25585 .37319 L 0 .027 .127 r
F
.25314 .37401 m .25132 .3723 L .25403 .37148 L F
.36527 .37764 m .36634 .37497 L .36805 .37667 L 0 .035 .136 r
F
.36527 .37764 m .36356 .37592 L .36634 .37497 L F
.48205 .39582 m .48328 .39464 L .48487 .39586 L 0 .09 .188 r
F
.48205 .39582 m .48045 .39454 L .48328 .39464 L F
.53603 .4027 m .53737 .40341 L .5389 .40208 L 0 .12 .21 r
F
.53603 .4027 m .5345 .40354 L .53737 .40341 L F
.43819 .38598 m .43937 .38348 L .441 .38528 L 0 .056 .159 r
F
.43819 .38598 m .43656 .38414 L .43937 .38348 L F
.7858 .37412 m .78751 .37149 L .7888 .3732 L 0 .028 .127 r
F
.7858 .37412 m .78451 .3724 L .78751 .37149 L F
.83383 .37393 m .83559 .37114 L .83684 .37288 L 0 .027 .126 r
F
.83383 .37393 m .83258 .37218 L .83559 .37114 L F
.8411 .37353 m .84288 .37079 L .84411 .3725 L 0 .026 .125 r
F
.8411 .37353 m .83986 .37182 L .84288 .37079 L F
.66509 .37839 m .66662 .37595 L .66802 .37749 L 0 .037 .139 r
F
.66509 .37839 m .66368 .37687 L .66662 .37595 L F
.46596 .39194 m .46718 .38954 L .46878 .39146 L 0 .074 .175 r
F
.46596 .39194 m .46435 .39005 L .46718 .38954 L F
.90367 .37258 m .90554 .36982 L .90672 .37157 L 0 .024 .123 r
F
.90367 .37258 m .90248 .37082 L .90554 .36982 L F
.56356 .39639 m .56494 .39495 L .56644 .39555 L 0 .092 .189 r
F
.56356 .39639 m .56206 .39591 L .56494 .39495 L F
.21963 .37363 m .22048 .37102 L .22233 .37273 L 0 .027 .126 r
F
.21963 .37363 m .21778 .37192 L .22048 .37102 L F
.84838 .37324 m .85018 .37057 L .85141 .3723 L 0 .026 .125 r
F
.84838 .37324 m .84714 .37154 L .85018 .37057 L F
.67236 .37811 m .6739 .37554 L .6753 .3771 L 0 .036 .138 r
F
.67236 .37811 m .67096 .37654 L .6739 .37554 L F
.34631 .37651 m .34735 .37384 L .34907 .37562 L 0 .033 .134 r
F
.34631 .37651 m .34458 .37475 L .34735 .37384 L F
.67963 .37775 m .68118 .37513 L .68258 .37678 L 0 .036 .137 r
F
.67963 .37775 m .67824 .3761 L .68118 .37513 L F
.37252 .37756 m .37359 .37521 L .37529 .37689 L F
.37252 .37756 m .37082 .37588 L .37359 .37521 L F
.17886 .37353 m .17967 .37071 L .18155 .37251 L 0 .026 .125 r
F
.17886 .37353 m .17698 .37172 L .17967 .37071 L F
.40315 .38079 m .40427 .37848 L .40594 .38019 L 0 .043 .146 r
F
.40315 .38079 m .40148 .37905 L .40427 .37848 L F
.31282 .37596 m .31382 .37318 L .31557 .375 L 0 .031 .132 r
F
.31282 .37596 m .31106 .37417 L .31382 .37318 L F
.65783 .37899 m .65934 .37627 L .66075 .37778 L 0 .038 .14 r
F
.65783 .37899 m .65641 .37749 L .65934 .37627 L F
.70872 .37621 m .71031 .37365 L .71168 .37531 L 0 .032 .133 r
F
.70872 .37621 m .70735 .37459 L .71031 .37365 L F
.39147 .37905 m .39257 .37662 L .39425 .37845 L 0 .039 .141 r
F
.39147 .37905 m .38979 .37719 L .39257 .37662 L F
.7931 .37402 m .79481 .37135 L .7961 .37307 L 0 .028 .127 r
F
.7931 .37402 m .79181 .37229 L .79481 .37135 L F
.62589 .3833 m .62735 .38061 L .62879 .382 L 0 .049 .152 r
F
.62589 .3833 m .62445 .38196 L .62735 .38061 L F
.22688 .37342 m .22776 .37067 L .2296 .3724 L 0 .026 .125 r
F
.22688 .37342 m .22504 .37171 L .22776 .37067 L F
.68691 .37746 m .68847 .37488 L .68986 .37652 L 0 .035 .136 r
F
.68691 .37746 m .68552 .37582 L .68847 .37488 L F
.52876 .40348 m .53008 .404 L .53163 .4036 L 0 .124 .212 r
F
.52876 .40348 m .52721 .40352 L .53008 .404 L F
.18612 .37323 m .18693 .37054 L .18881 .37228 L 0 .026 .125 r
F
.18612 .37323 m .18424 .37151 L .18693 .37054 L F
.85567 .37304 m .85747 .3703 L .8587 .37204 L 0 .026 .124 r
F
.85567 .37304 m .85444 .37131 L .85747 .3703 L F
.28659 .37505 m .28753 .37252 L .28932 .37426 L 0 .03 .13 r
F
.28659 .37505 m .28481 .37331 L .28753 .37252 L F
.26037 .37405 m .26128 .37149 L .26309 .37319 L 0 .028 .127 r
F
.26037 .37405 m .25856 .37236 L .26128 .37149 L F
.5054 .39992 m .50666 .40152 L .50824 .40076 L 0 .113 .204 r
F
.5054 .39992 m .50382 .39994 L .50666 .40152 L F
.70146 .37679 m .70303 .37411 L .7044 .37569 L 0 .034 .135 r
F
.70146 .37679 m .70009 .37524 L .70303 .37411 L F
.69419 .3772 m .69576 .37473 L .69714 .37629 L 0 .035 .136 r
F
.69419 .3772 m .69281 .37562 L .69576 .37473 L F
.23414 .37319 m .23501 .37056 L .23684 .37235 L 0 .026 .125 r
F
.23414 .37319 m .23231 .37142 L .23501 .37056 L F
.42209 .38247 m .42324 .38014 L .42488 .38204 L 0 .048 .151 r
F
.42209 .38247 m .42045 .38057 L .42324 .38014 L F
.80038 .37381 m .80211 .37114 L .80339 .37284 L 0 .027 .127 r
F
.80038 .37381 m .7991 .3721 L .80211 .37114 L F
.49372 .39822 m .49497 .39766 L .49656 .39839 L 0 .101 .196 r
F
.49372 .39822 m .49213 .3972 L .49497 .39766 L F
.32007 .37584 m .32107 .37321 L .32281 .37502 L 0 .032 .132 r
F
.32007 .37584 m .31832 .37404 L .32107 .37321 L F
.86296 .37282 m .86477 .37004 L .86599 .37182 L 0 .025 .124 r
F
.86296 .37282 m .86173 .37104 L .86477 .37004 L F
.19337 .37308 m .19419 .37036 L .19606 .37212 L 0 .026 .125 r
F
.19337 .37308 m .1915 .37132 L .19419 .37036 L F
.73782 .37493 m .73945 .37226 L .74079 .37394 L 0 .03 .13 r
F
.73782 .37493 m .73648 .37325 L .73945 .37226 L F
.54616 .40034 m .54752 .39981 L .54904 .39939 L 0 .11 .202 r
F
.54616 .40034 m .54464 .40063 L .54752 .39981 L F
.73055 .37534 m .73217 .37261 L .73351 .37429 L 0 .031 .131 r
F
.73055 .37534 m .7292 .37367 L .73217 .37261 L F
.58383 .39088 m .58523 .38839 L .58671 .38948 L 0 .072 .173 r
F
.58383 .39088 m .58234 .38983 L .58523 .38839 L F
.71601 .37617 m .71761 .37345 L .71897 .3752 L 0 .032 .133 r
F
.71601 .37617 m .71464 .37441 L .71761 .37345 L F
.60123 .38747 m .60266 .38511 L .60412 .38623 L 0 .062 .164 r
F
.60123 .38747 m .59976 .38631 L .60266 .38511 L F
.26761 .37397 m .26854 .37133 L .27034 .37305 L 0 .028 .128 r
F
.26761 .37397 m .26581 .37226 L .26854 .37133 L F
.87025 .37259 m .87207 .36985 L .87329 .37162 L 0 .025 .124 r
F
.87025 .37259 m .86903 .37082 L .87207 .36985 L F
.80767 .3736 m .80942 .37105 L .81069 .37271 L 0 .027 .127 r
F
.80767 .3736 m .8064 .37194 L .80942 .37105 L F
.74509 .37461 m .74674 .37191 L .74807 .37358 L 0 .029 .129 r
F
.74509 .37461 m .74376 .37295 L .74674 .37191 L F
.29383 .37503 m .2948 .3724 L .29657 .37407 L 0 .03 .13 r
F
.29383 .37503 m .29205 .37337 L .2948 .3724 L F
.72328 .37584 m .72489 .37303 L .72624 .37473 L 0 .032 .132 r
F
.72328 .37584 m .72193 .37412 L .72489 .37303 L F
.35355 .37666 m .3546 .37409 L .35631 .37592 L 0 .034 .135 r
F
.35355 .37666 m .35183 .37485 L .3546 .37409 L F
.61863 .38413 m .6201 .38184 L .62154 .38314 L 0 .053 .156 r
F
.61863 .38413 m .61719 .38286 L .6201 .38184 L F
.75237 .37425 m .75401 .37144 L .75534 .37318 L 0 .028 .128 r
F
.75237 .37425 m .75104 .37251 L .75401 .37144 L F
.65058 .37993 m .65208 .37718 L .6535 .37872 L 0 .041 .143 r
F
.65058 .37993 m .64916 .37836 L .65208 .37718 L F
.5737 .39411 m .57509 .39172 L .57658 .39271 L 0 .083 .182 r
F
.5737 .39411 m .57221 .39314 L .57509 .39172 L F
.20061 .37298 m .20144 .37018 L .2033 .37202 L 0 .026 .125 r
F
.20061 .37298 m .19875 .37116 L .20144 .37018 L F
.44544 .38649 m .44663 .3842 L .44825 .38591 L 0 .06 .162 r
F
.44544 .38649 m .44381 .38474 L .44663 .3842 L F
.30109 .3748 m .30205 .37231 L .30382 .37402 L 0 .03 .13 r
F
.30109 .3748 m .29932 .37311 L .30205 .37231 L F
.87754 .3724 m .87938 .36971 L .88058 .37143 L 0 .025 .124 r
F
.87754 .3724 m .87633 .37066 L .87938 .36971 L F
.46153 .39056 m .46275 .38809 L .46435 .39005 L 0 .072 .173 r
F
.46153 .39056 m .45992 .38863 L .46275 .38809 L F
.81496 .37344 m .81671 .37073 L .81797 .37241 L 0 .027 .126 r
F
.81496 .37344 m .8137 .37178 L .81671 .37073 L F
.37976 .37788 m .38085 .37536 L .38254 .37705 L 0 .037 .139 r
F
.37976 .37788 m .37806 .37621 L .38085 .37536 L F
.75965 .37405 m .76132 .37144 L .76264 .37316 L 0 .028 .128 r
F
.75965 .37405 m .75833 .3723 L .76132 .37144 L F
.5563 .3977 m .55767 .39659 L .55918 .39685 L 0 .099 .195 r
F
.5563 .3977 m .55479 .39752 L .55767 .39659 L F
.64332 .38056 m .6448 .37784 L .64623 .37946 L 0 .043 .145 r
F
.64332 .38056 m .64188 .3789 L .6448 .37784 L F
.82224 .3731 m .824 .37044 L .82526 .37217 L 0 .027 .126 r
F
.82224 .3731 m .82098 .37139 L .824 .37044 L F
.47762 .39468 m .47885 .39283 L .48045 .39454 L 0 .087 .185 r
F
.47762 .39468 m .47603 .39295 L .47885 .39283 L F
.88482 .37211 m .88667 .36936 L .88787 .37109 L 0 .025 .123 r
F
.88482 .37211 m .88363 .3704 L .88667 .36936 L F
.41039 .3812 m .41153 .37873 L .41319 .38038 L 0 .045 .148 r
F
.41039 .3812 m .40873 .37955 L .41153 .37873 L F
.32731 .37596 m .32831 .37346 L .33006 .37515 L 0 .033 .134 r
F
.32731 .37596 m .32556 .37425 L .32831 .37346 L F
.27485 .37395 m .27579 .37127 L .27758 .37309 L 0 .028 .128 r
F
.27485 .37395 m .27306 .37216 L .27579 .37127 L F
.24136 .37335 m .24225 .37058 L .24407 .37242 L 0 .027 .126 r
F
.24136 .37335 m .23954 .37152 L .24225 .37058 L F
.43375 .38487 m .43493 .38224 L .43656 .38414 L 0 .055 .157 r
F
.43375 .38487 m .43212 .38293 L .43493 .38224 L F
.51708 .40242 m .51837 .40478 L .51993 .40329 L 0 .127 .214 r
F
.51708 .40242 m .51551 .40317 L .51837 .40478 L F
.63605 .38109 m .63753 .37838 L .63896 .37999 L 0 .045 .147 r
F
.63605 .38109 m .63461 .37954 L .63753 .37838 L F
.89211 .37182 m .89398 .36918 L .89517 .37092 L 0 .024 .123 r
F
.89211 .37182 m .89091 .37009 L .89398 .36918 L F
.77422 .37349 m .77591 .37088 L .77721 .37253 L 0 .028 .127 r
F
.77422 .37349 m .77291 .37184 L .77591 .37088 L F
.20785 .37288 m .2087 .37003 L .21055 .3719 L 0 .026 .125 r
F
.20785 .37288 m .206 .37102 L .2087 .37003 L F
.61137 .38501 m .61283 .38261 L .61428 .38387 L 0 .056 .158 r
F
.61137 .38501 m .60992 .3838 L .61283 .38261 L F
.76695 .37393 m .76862 .37121 L .76993 .37288 L 0 .028 .128 r
F
.76695 .37393 m .76563 .37223 L .76862 .37121 L F
.3987 .37964 m .39981 .37728 L .40148 .37905 L 0 .042 .144 r
F
.3987 .37964 m .39703 .37784 L .39981 .37728 L F
.36079 .37687 m .36185 .37419 L .36356 .37592 L 0 .035 .136 r
F
.36079 .37687 m .35908 .37513 L .36185 .37419 L F
.33456 .37588 m .33558 .37323 L .33732 .37491 L 0 .033 .134 r
F
.33456 .37588 m .33282 .37419 L .33558 .37323 L F
.82955 .37307 m .83132 .37043 L .83258 .37218 L 0 .027 .126 r
F
.82955 .37307 m .82829 .3713 L .83132 .37043 L F
.2486 .37328 m .24951 .37045 L .25132 .3723 L F
.2486 .37328 m .24679 .37143 L .24951 .37045 L F
.38701 .37792 m .38811 .37547 L .38979 .37719 L 0 .038 .14 r
F
.38701 .37792 m .38532 .37622 L .38811 .37547 L F
.59397 .38862 m .5954 .38635 L .59687 .38751 L 0 .067 .168 r
F
.59397 .38862 m .5925 .38743 L .5954 .38635 L F
.7815 .37329 m .78321 .37072 L .78451 .3724 L 0 .028 .127 r
F
.7815 .37329 m .78021 .37163 L .78321 .37072 L F
.41765 .38118 m .41879 .37893 L .42045 .38057 L 0 .046 .149 r
F
.41765 .38118 m .41599 .37955 L .41879 .37893 L F
.45711 .38888 m .45831 .38669 L .45992 .38863 L 0 .068 .17 r
F
.45711 .38888 m .4555 .38699 L .45831 .38669 L F
.30832 .37501 m .30931 .37238 L .31106 .37417 L 0 .031 .132 r
F
.30832 .37501 m .30656 .37324 L .30931 .37238 L F
.89942 .37178 m .90129 .36906 L .90248 .37082 L 0 .024 .123 r
F
.89942 .37178 m .89823 .37002 L .90129 .36906 L F
.21509 .37282 m .21594 .37007 L .21778 .37192 L 0 .026 .126 r
F
.21509 .37282 m .21324 .37097 L .21594 .37007 L F
.36805 .37667 m .36912 .3742 L .37082 .37588 L 0 .035 .136 r
F
.36805 .37667 m .36634 .37497 L .36912 .3742 L F
.34182 .37567 m .34286 .373 L .34458 .37475 L 0 .033 .133 r
F
.34182 .37567 m .34009 .37395 L .34286 .373 L F
.28208 .37409 m .28303 .37145 L .28481 .37331 L 0 .029 .129 r
F
.28208 .37409 m .28031 .37225 L .28303 .37145 L F
.83684 .37288 m .83861 .37009 L .83986 .37182 L 0 .027 .126 r
F
.83684 .37288 m .83559 .37114 L .83861 .37009 L F
.4893 .39709 m .49054 .39618 L .49213 .3972 L 0 .099 .194 r
F
.4893 .39709 m .48771 .39594 L .49054 .39618 L F
.4732 .39306 m .47443 .39105 L .47603 .39295 L 0 .082 .181 r
F
.4732 .39306 m .4716 .39115 L .47443 .39105 L F
.84411 .3725 m .84591 .36983 L .84714 .37154 L 0 .026 .125 r
F
.84411 .3725 m .84288 .37079 L .84591 .36983 L F
.62879 .382 m .63026 .37927 L .6317 .3807 L 0 .048 .15 r
F
.62879 .382 m .62735 .38061 L .63026 .37927 L F
.66075 .37778 m .66227 .37535 L .66368 .37687 L 0 .038 .14 r
F
.66075 .37778 m .65934 .37627 L .66227 .37535 L F
.1743 .37274 m .17511 .36985 L .17698 .37172 L 0 .026 .125 r
F
.1743 .37274 m .17242 .37086 L .17511 .36985 L F
.90672 .37157 m .9086 .36882 L .90977 .37055 L 0 .024 .122 r
F
.90672 .37157 m .90554 .36982 L .9086 .36882 L F
.25585 .37319 m .25674 .37065 L .25856 .37236 L 0 .028 .127 r
F
.25585 .37319 m .25403 .37148 L .25674 .37065 L F
.7888 .3732 m .79052 .37058 L .79181 .37229 L F
.7888 .3732 m .78751 .37149 L .79052 .37058 L F
.50098 .39905 m .50223 .39999 L .50382 .39994 L 0 .111 .203 r
F
.50098 .39905 m .4994 .39855 L .50223 .39999 L F
.66802 .37749 m .66956 .37499 L .67096 .37654 L 0 .037 .139 r
F
.66802 .37749 m .66662 .37595 L .66956 .37499 L F
.6753 .3771 m .67684 .37453 L .67824 .3761 L 0 .036 .138 r
F
.6753 .3771 m .6739 .37554 L .67684 .37453 L F
.85141 .3723 m .85321 .36958 L .85444 .37131 L 0 .026 .125 r
F
.85141 .3723 m .85018 .37057 L .85321 .36958 L F
.18155 .37251 m .18236 .3697 L .18424 .37151 L F
.18155 .37251 m .17967 .37071 L .18236 .3697 L F
.22233 .37273 m .22319 .36999 L .22504 .37171 L 0 .027 .126 r
F
.22233 .37273 m .22048 .37102 L .22319 .36999 L F
.58671 .38948 m .58813 .38736 L .5896 .38846 L 0 .071 .172 r
F
.58671 .38948 m .58523 .38839 L .58813 .38736 L F
.68258 .37678 m .68413 .37417 L .68552 .37582 L 0 .036 .137 r
F
.68258 .37678 m .68118 .37513 L .68413 .37417 L F
.56644 .39555 m .56783 .39386 L .56932 .39456 L 0 .092 .189 r
F
.56644 .39555 m .56494 .39495 L .56783 .39386 L F
.441 .38528 m .44218 .38298 L .44381 .38474 L 0 .058 .16 r
F
.441 .38528 m .43937 .38348 L .44218 .38298 L F
.31557 .375 m .31657 .37219 L .31832 .37404 L 0 .031 .132 r
F
.31557 .375 m .31382 .37318 L .31657 .37219 L F
.34907 .37562 m .35012 .37303 L .35183 .37485 L 0 .033 .134 r
F
.34907 .37562 m .34735 .37384 L .35012 .37303 L F
.2296 .3724 m .23047 .36968 L .23231 .37142 L 0 .026 .125 r
F
.2296 .3724 m .22776 .37067 L .23047 .36968 L F
.5389 .40208 m .54025 .40323 L .54177 .40145 L 0 .124 .212 r
F
.5389 .40208 m .53737 .40341 L .54025 .40323 L F
.8587 .37204 m .86051 .3693 L .86173 .37104 L 0 .025 .124 r
F
.8587 .37204 m .85747 .3703 L .86051 .3693 L F
.7961 .37307 m .79782 .37039 L .7991 .3721 L 0 .028 .127 r
F
.7961 .37307 m .79481 .37135 L .79782 .37039 L F
.7044 .37569 m .70598 .37297 L .70735 .37459 L 0 .033 .134 r
F
.7044 .37569 m .70303 .37411 L .70598 .37297 L F
.18881 .37228 m .18962 .36956 L .1915 .37132 L 0 .026 .125 r
F
.18881 .37228 m .18693 .37054 L .18962 .36956 L F
.68986 .37652 m .69143 .37401 L .69281 .37562 L 0 .035 .137 r
F
.68986 .37652 m .68847 .37488 L .69143 .37401 L F
.71168 .37531 m .71328 .37272 L .71464 .37441 L 0 .033 .133 r
F
.71168 .37531 m .71031 .37365 L .71328 .37272 L F
.42931 .3836 m .43048 .38098 L .43212 .38293 L 0 .053 .155 r
F
.42931 .3836 m .42768 .38162 L .43048 .38098 L F
.60412 .38623 m .60556 .38385 L .60702 .38501 L 0 .061 .163 r
F
.60412 .38623 m .60266 .38511 L .60556 .38385 L F
.57658 .39271 m .57797 .39026 L .57946 .39128 L 0 .08 .18 r
F
.57658 .39271 m .57509 .39172 L .57797 .39026 L F
.45269 .38728 m .45388 .38524 L .4555 .38699 L 0 .065 .166 r
F
.45269 .38728 m .45106 .38553 L .45388 .38524 L F
.52435 .40303 m .52566 .40545 L .52721 .40352 L 0 .132 .217 r
F
.52435 .40303 m .5228 .40427 L .52566 .40545 L F
.26309 .37319 m .264 .37056 L .26581 .37226 L 0 .028 .128 r
F
.26309 .37319 m .26128 .37149 L .264 .37056 L F
.86599 .37182 m .8678 .36904 L .86903 .37082 L 0 .025 .124 r
F
.86599 .37182 m .86477 .37004 L .8678 .36904 L F
.80339 .37284 m .80513 .37024 L .8064 .37194 L 0 .027 .127 r
F
.80339 .37284 m .80211 .37114 L .80513 .37024 L F
.28932 .37426 m .29027 .37163 L .29205 .37337 L 0 .03 .131 r
F
.28932 .37426 m .28753 .37252 L .29027 .37163 L F
.37529 .37689 m .37637 .37454 L .37806 .37621 L 0 .037 .138 r
F
.37529 .37689 m .37359 .37521 L .37637 .37454 L F
.69714 .37629 m .69871 .37367 L .70009 .37524 L 0 .035 .136 r
F
.69714 .37629 m .69576 .37473 L .69871 .37367 L F
.6535 .37872 m .655 .37596 L .65641 .37749 L 0 .04 .142 r
F
.6535 .37872 m .65208 .37718 L .655 .37596 L F
.73351 .37429 m .73514 .37157 L .73648 .37325 L 0 .03 .131 r
F
.73351 .37429 m .73217 .37261 L .73514 .37157 L F
.46878 .39146 m .47 .38922 L .4716 .39115 L 0 .077 .177 r
F
.46878 .39146 m .46718 .38954 L .47 .38922 L F
.72624 .37473 m .72785 .37198 L .7292 .37367 L 0 .031 .132 r
F
.72624 .37473 m .72489 .37303 L .72785 .37198 L F
.40594 .38019 m .40706 .37787 L .40873 .37955 L 0 .045 .147 r
F
.40594 .38019 m .40427 .37848 L .40706 .37787 L F
.74079 .37394 m .74243 .37128 L .74376 .37295 L 0 .03 .13 r
F
.74079 .37394 m .73945 .37226 L .74243 .37128 L F
.19606 .37212 m .19688 .36938 L .19875 .37116 L 0 .026 .125 r
F
.19606 .37212 m .19419 .37036 L .19688 .36938 L F
.23684 .37235 m .23771 .36971 L .23954 .37152 L 0 .027 .126 r
F
.23684 .37235 m .23501 .37056 L .23771 .36971 L F
.54904 .39939 m .5504 .39887 L .55191 .39845 L 0 .11 .202 r
F
.54904 .39939 m .54752 .39981 L .5504 .39887 L F
.74807 .37358 m .74971 .37082 L .75104 .37251 L 0 .029 .129 r
F
.74807 .37358 m .74674 .37191 L .74971 .37082 L F
.71897 .3752 m .72057 .37238 L .72193 .37412 L 0 .032 .133 r
F
.71897 .3752 m .71761 .37345 L .72057 .37238 L F
.75534 .37318 m .757 .37056 L .75833 .3723 L 0 .028 .128 r
F
.75534 .37318 m .75401 .37144 L .757 .37056 L F
.39425 .37845 m .39535 .37604 L .39703 .37784 L 0 .04 .142 r
F
.39425 .37845 m .39257 .37662 L .39535 .37604 L F
.32281 .37502 m .32382 .37242 L .32556 .37425 L 0 .032 .133 r
F
.32281 .37502 m .32107 .37321 L .32382 .37242 L F
.87329 .37162 m .87512 .36892 L .87633 .37066 L 0 .025 .124 r
F
.87329 .37162 m .87207 .36985 L .87512 .36892 L F
.27034 .37305 m .27127 .37042 L .27306 .37216 L 0 .028 .128 r
F
.27034 .37305 m .26854 .37133 L .27127 .37042 L F
.62154 .38314 m .62301 .38062 L .62445 .38196 L 0 .052 .155 r
F
.62154 .38314 m .6201 .38184 L .62301 .38062 L F
.29657 .37407 m .29754 .37143 L .29932 .37311 L 0 .03 .13 r
F
.29657 .37407 m .2948 .3724 L .29754 .37143 L F
.81069 .37271 m .81244 .37012 L .8137 .37178 L 0 .028 .127 r
F
.81069 .37271 m .80942 .37105 L .81244 .37012 L F
.51266 .40159 m .51394 .40391 L .51551 .40317 L 0 .126 .213 r
F
.51266 .40159 m .51109 .4016 L .51394 .40391 L F
.64623 .37946 m .64773 .37678 L .64916 .37836 L 0 .043 .145 r
F
.64623 .37946 m .6448 .37784 L .64773 .37678 L F
.81797 .37241 m .81972 .36969 L .82098 .37139 L 0 .027 .126 r
F
.81797 .37241 m .81671 .37073 L .81972 .36969 L F
.2033 .37202 m .20415 .36917 L .206 .37102 L 0 .026 .125 r
F
.2033 .37202 m .20144 .37018 L .20415 .36917 L F
.88058 .37143 m .88243 .36868 L .88363 .3704 L 0 .025 .123 r
F
.88058 .37143 m .87938 .36971 L .88243 .36868 L F
.48487 .39586 m .48611 .3948 L .48771 .39594 L 0 .096 .192 r
F
.48487 .39586 m .48328 .39464 L .48611 .3948 L F
.35631 .37592 m .35737 .37328 L .35908 .37513 L 0 .035 .136 r
F
.35631 .37592 m .3546 .37409 L .35737 .37328 L F
.88787 .37109 m .88972 .36835 L .89091 .37009 L 0 .024 .123 r
F
.88787 .37109 m .88667 .36936 L .88972 .36835 L F
.63896 .37999 m .64045 .37726 L .64188 .3789 L 0 .044 .146 r
F
.63896 .37999 m .63753 .37838 L .64045 .37726 L F
.76264 .37316 m .76432 .37054 L .76563 .37223 L 0 .029 .128 r
F
.76264 .37316 m .76132 .37144 L .76432 .37054 L F
.42488 .38204 m .42604 .37972 L .42768 .38162 L 0 .05 .153 r
F
.42488 .38204 m .42324 .38014 L .42604 .37972 L F
.61428 .38387 m .61574 .38157 L .61719 .38286 L 0 .055 .158 r
F
.61428 .38387 m .61283 .38261 L .61574 .38157 L F
.82526 .37217 m .82703 .36955 L .82829 .3713 L 0 .027 .126 r
F
.82526 .37217 m .824 .37044 L .82703 .36955 L F
.30382 .37402 m .30479 .37152 L .30656 .37324 L 0 .031 .131 r
F
.30382 .37402 m .30205 .37231 L .30479 .37152 L F
.38254 .37705 m .38363 .37452 L .38532 .37622 L 0 .038 .139 r
F
.38254 .37705 m .38085 .37536 L .38363 .37452 L F
.24407 .37242 m .24498 .36958 L .24679 .37143 L 0 .027 .126 r
F
.24407 .37242 m .24225 .37058 L .24498 .36958 L F
.55918 .39685 m .56056 .39551 L .56206 .39591 L 0 .099 .195 r
F
.55918 .39685 m .55767 .39659 L .56056 .39551 L F
.76993 .37288 m .77161 .37018 L .77291 .37184 L 0 .028 .128 r
F
.76993 .37288 m .76862 .37121 L .77161 .37018 L F
.27758 .37309 m .27852 .3704 L .28031 .37225 L 0 .029 .128 r
F
.27758 .37309 m .27579 .37127 L .27852 .3704 L F
.41319 .38038 m .41433 .37792 L .41599 .37955 L 0 .046 .148 r
F
.41319 .38038 m .41153 .37873 L .41433 .37792 L F
.21055 .3719 m .2114 .36908 L .21324 .37097 L 0 .026 .125 r
F
.21055 .3719 m .2087 .37003 L .2114 .36908 L F
.33006 .37515 m .33108 .3725 L .33282 .37419 L 0 .033 .134 r
F
.33006 .37515 m .32831 .37346 L .33108 .3725 L F
.77721 .37253 m .77891 .36996 L .78021 .37163 L 0 .028 .127 r
F
.77721 .37253 m .77591 .37088 L .77891 .36996 L F
.89517 .37092 m .89704 .36828 L .89823 .37002 L 0 .024 .123 r
F
.89517 .37092 m .89398 .36918 L .89704 .36828 L F
.59687 .38751 m .5983 .38516 L .59976 .38631 L 0 .066 .168 r
F
.59687 .38751 m .5954 .38635 L .5983 .38516 L F
.44825 .38591 m .44944 .38386 L .45106 .38553 L 0 .062 .164 r
F
.44825 .38591 m .44663 .3842 L .44944 .38386 L F
.6317 .3807 m .63317 .37803 L .63461 .37954 L 0 .047 .149 r
F
.6317 .3807 m .63026 .37927 L .63317 .37803 L F
.43656 .38414 m .43774 .38161 L .43937 .38348 L 0 .056 .158 r
F
.43656 .38414 m .43493 .38224 L .43774 .38161 L F
.33732 .37491 m .33835 .37226 L .34009 .37395 L 0 .033 .134 r
F
.33732 .37491 m .33558 .37323 L .33835 .37226 L F
.36356 .37592 m .36463 .37326 L .36634 .37497 L 0 .035 .136 r
F
.36356 .37592 m .36185 .37419 L .36463 .37326 L F
.46435 .39005 m .46557 .38756 L .46718 .38954 L 0 .074 .174 r
F
.46435 .39005 m .46275 .38809 L .46557 .38756 L F
.25132 .3723 m .25222 .36961 L .25403 .37148 L 0 .027 .127 r
F
.25132 .3723 m .24951 .37045 L .25222 .36961 L F
.53163 .4036 m .53296 .40439 L .5345 .40354 L 0 .131 .217 r
F
.53163 .4036 m .53008 .404 L .53296 .40439 L F
.83258 .37218 m .83434 .3694 L .83559 .37114 L 0 .027 .126 r
F
.83258 .37218 m .83132 .37043 L .83434 .3694 L F
.78451 .3724 m .78622 .3698 L .78751 .37149 L 0 .028 .127 r
F
.78451 .3724 m .78321 .37072 L .78622 .3698 L F
.83986 .37182 m .84164 .36907 L .84288 .37079 L 0 .026 .125 r
F
.83986 .37182 m .83861 .37009 L .84164 .36907 L F
.90248 .37082 m .90435 .36806 L .90554 .36982 L 0 .024 .123 r
F
.90248 .37082 m .90129 .36906 L .90435 .36806 L F
.57946 .39128 m .58086 .38878 L .58234 .38983 L 0 .078 .178 r
F
.57946 .39128 m .57797 .39026 L .58086 .38878 L F
.21778 .37192 m .21864 .36917 L .22048 .37102 L 0 .027 .126 r
F
.21778 .37192 m .21594 .37007 L .21864 .36917 L F
.17698 .37172 m .1778 .36884 L .17967 .37071 L 0 .026 .125 r
F
.17698 .37172 m .17511 .36985 L .1778 .36884 L F
.34458 .37475 m .34563 .37206 L .34735 .37384 L 0 .033 .134 r
F
.34458 .37475 m .34286 .373 L .34563 .37206 L F
.84714 .37154 m .84894 .36886 L .85018 .37057 L 0 .026 .125 r
F
.84714 .37154 m .84591 .36983 L .84894 .36886 L F
.38979 .37719 m .39089 .37483 L .39257 .37662 L 0 .039 .141 r
F
.38979 .37719 m .38811 .37547 L .39089 .37483 L F
.49656 .39839 m .49781 .39813 L .4994 .39855 L 0 .108 .201 r
F
.49656 .39839 m .49497 .39766 L .49781 .39813 L F
.31106 .37417 m .31206 .37136 L .31382 .37318 L 0 .031 .132 r
F
.31106 .37417 m .30931 .37238 L .31206 .37136 L F
.40148 .37905 m .4026 .37674 L .40427 .37848 L 0 .044 .146 r
F
.40148 .37905 m .39981 .37728 L .4026 .37674 L F
.66368 .37687 m .66521 .37442 L .66662 .37595 L 0 .038 .14 r
F
.66368 .37687 m .66227 .37535 L .66521 .37442 L F
.37082 .37588 m .37189 .37353 L .37359 .37521 L 0 .036 .137 r
F
.37082 .37588 m .36912 .3742 L .37189 .37353 L F
.67824 .3761 m .67979 .37352 L .68118 .37513 L 0 .036 .138 r
F
.67824 .3761 m .67684 .37453 L .67979 .37352 L F
.79181 .37229 m .79352 .36964 L .79481 .37135 L 0 .028 .127 r
F
.79181 .37229 m .79052 .37058 L .79352 .36964 L F
.60702 .38501 m .60846 .38258 L .60992 .3838 L 0 .059 .162 r
F
.60702 .38501 m .60556 .38385 L .60846 .38258 L F
.42045 .38057 m .42158 .37847 L .42324 .38014 L 0 .048 .151 r
F
.42045 .38057 m .41879 .37893 L .42158 .37847 L F
.28481 .37331 m .28576 .37065 L .28753 .37252 L 0 .03 .13 r
F
.28481 .37331 m .28303 .37145 L .28576 .37065 L F
.67096 .37654 m .6725 .37398 L .6739 .37554 L 0 .037 .139 r
F
.67096 .37654 m .66956 .37499 L .6725 .37398 L F
.5896 .38846 m .59103 .38633 L .5925 .38743 L 0 .07 .172 r
F
.5896 .38846 m .58813 .38736 L .59103 .38633 L F
.22504 .37171 m .22591 .36895 L .22776 .37067 L 0 .026 .126 r
F
.22504 .37171 m .22319 .36999 L .22591 .36895 L F
.18424 .37151 m .18505 .36872 L .18693 .37054 L 0 .026 .125 r
F
.18424 .37151 m .18236 .3697 L .18505 .36872 L F
.85444 .37131 m .85624 .36857 L .85747 .3703 L F
.85444 .37131 m .85321 .36958 L .85624 .36857 L F
.48045 .39454 m .48168 .39303 L .48328 .39464 L 0 .092 .189 r
F
.48045 .39454 m .47885 .39283 L .48168 .39303 L F
.56932 .39456 m .57071 .39238 L .57221 .39314 L 0 .09 .188 r
F
.56932 .39456 m .56783 .39386 L .57071 .39238 L F
.25856 .37236 m .25946 .36978 L .26128 .37149 L 0 .028 .128 r
F
.25856 .37236 m .25674 .37065 L .25946 .36978 L F
.70735 .37459 m .70894 .372 L .71031 .37365 L 0 .033 .134 r
F
.70735 .37459 m .70598 .37297 L .70894 .372 L F
.68552 .37582 m .68708 .37323 L .68847 .37488 L 0 .036 .137 r
F
.68552 .37582 m .68413 .37417 L .68708 .37323 L F
.31832 .37404 m .31933 .37132 L .32107 .37321 L 0 .032 .132 r
F
.31832 .37404 m .31657 .37219 L .31933 .37132 L F
.23231 .37142 m .23317 .36881 L .23501 .37056 L 0 .026 .125 r
F
.23231 .37142 m .23047 .36968 L .23317 .36881 L F
.65641 .37749 m .65792 .37476 L .65934 .37627 L 0 .039 .141 r
F
.65641 .37749 m .655 .37596 L .65792 .37476 L F
.86173 .37104 m .86354 .36828 L .86477 .37004 L 0 .025 .124 r
F
.86173 .37104 m .86051 .3693 L .86354 .36828 L F
.7991 .3721 m .80083 .36943 L .80211 .37114 L 0 .028 .127 r
F
.7991 .3721 m .79782 .37039 L .80083 .36943 L F
.1915 .37132 m .19231 .36858 L .19419 .37036 L 0 .026 .125 r
F
.1915 .37132 m .18962 .36956 L .19231 .36858 L F
.71464 .37441 m .71624 .37173 L .71761 .37345 L 0 .033 .133 r
F
.71464 .37441 m .71328 .37272 L .71624 .37173 L F
.69281 .37562 m .69439 .37314 L .69576 .37473 L 0 .036 .137 r
F
.69281 .37562 m .69143 .37401 L .69439 .37314 L F
.70009 .37524 m .70166 .37252 L .70303 .37411 L 0 .034 .136 r
F
.70009 .37524 m .69871 .37367 L .70166 .37252 L F
.35183 .37485 m .35288 .37225 L .3546 .37409 L 0 .034 .135 r
F
.35183 .37485 m .35012 .37303 L .35288 .37225 L F
.86903 .37082 m .87085 .36808 L .87207 .36985 L 0 .025 .124 r
F
.86903 .37082 m .8678 .36904 L .87085 .36808 L F
.73648 .37325 m .73811 .3706 L .73945 .37226 L 0 .03 .13 r
F
.73648 .37325 m .73514 .37157 L .73811 .3706 L F
.7292 .37367 m .73082 .37093 L .73217 .37261 L 0 .031 .131 r
F
.7292 .37367 m .72785 .37198 L .73082 .37093 L F
.26581 .37226 m .26673 .36963 L .26854 .37133 L 0 .028 .128 r
F
.26581 .37226 m .264 .37056 L .26673 .36963 L F
.62445 .38196 m .62591 .37923 L .62735 .38061 L 0 .051 .154 r
F
.62445 .38196 m .62301 .38062 L .62591 .37923 L F
.45992 .38863 m .46114 .38613 L .46275 .38809 L 0 .071 .172 r
F
.45992 .38863 m .45831 .38669 L .46114 .38613 L F
.50824 .40076 m .50951 .4031 L .51109 .4016 L 0 .126 .213 r
F
.50824 .40076 m .50666 .40152 L .50951 .4031 L F
.72193 .37412 m .72353 .37132 L .72489 .37303 L 0 .032 .132 r
F
.72193 .37412 m .72057 .37238 L .72353 .37132 L F
.75104 .37251 m .75268 .36973 L .75401 .37144 L 0 .029 .128 r
F
.75104 .37251 m .74971 .37082 L .75268 .36973 L F
.8064 .37194 m .80815 .36936 L .80942 .37105 L 0 .028 .127 r
F
.8064 .37194 m .80513 .37024 L .80815 .36936 L F
.74376 .37295 m .7454 .37023 L .74674 .37191 L 0 .03 .13 r
F
.74376 .37295 m .74243 .37128 L .7454 .37023 L F
.29205 .37337 m .29302 .37065 L .2948 .3724 L 0 .031 .131 r
F
.29205 .37337 m .29027 .37163 L .29302 .37065 L F
.19875 .37116 m .19958 .3684 L .20144 .37018 L 0 .026 .125 r
F
.19875 .37116 m .19688 .36938 L .19958 .3684 L F
.54177 .40145 m .54313 .40267 L .54464 .40063 L 0 .126 .214 r
F
.54177 .40145 m .54025 .40323 L .54313 .40267 L F
.55191 .39845 m .55328 .39781 L .55479 .39752 L 0 .11 .202 r
F
.55191 .39845 m .5504 .39887 L .55328 .39781 L F
.44381 .38474 m .445 .38248 L .44663 .3842 L 0 .06 .162 r
F
.44381 .38474 m .44218 .38298 L .445 .38248 L F
.43212 .38293 m .43329 .38032 L .43493 .38224 L 0 .054 .157 r
F
.43212 .38293 m .43048 .38098 L .43329 .38032 L F
.87633 .37066 m .87817 .36799 L .87938 .36971 L 0 .025 .124 r
F
.87633 .37066 m .87512 .36892 L .87817 .36799 L F
.75833 .3723 m .76 .36971 L .76132 .37144 L 0 .029 .128 r
F
.75833 .3723 m .757 .37056 L .76 .36971 L F
.64916 .37836 m .65065 .37563 L .65208 .37718 L 0 .042 .144 r
F
.64916 .37836 m .64773 .37678 L .65065 .37563 L F
.29932 .37311 m .30028 .37061 L .30205 .37231 L 0 .031 .131 r
F
.29932 .37311 m .29754 .37143 L .30028 .37061 L F
.23954 .37152 m .24043 .36876 L .24225 .37058 L 0 .027 .126 r
F
.23954 .37152 m .23771 .36971 L .24043 .36876 L F
.47603 .39295 m .47726 .39096 L .47885 .39283 L 0 .086 .185 r
F
.47603 .39295 m .47443 .39105 L .47726 .39096 L F
.27306 .37216 m .274 .3695 L .27579 .37127 L 0 .028 .128 r
F
.27306 .37216 m .27127 .37042 L .274 .3695 L F
.37806 .37621 m .37915 .37369 L .38085 .37536 L 0 .037 .139 r
F
.37806 .37621 m .37637 .37454 L .37915 .37369 L F
.8137 .37178 m .81545 .36905 L .81671 .37073 L 0 .027 .127 r
F
.8137 .37178 m .81244 .37012 L .81545 .36905 L F
.82098 .37139 m .82274 .36871 L .824 .37044 L 0 .027 .126 r
F
.82098 .37139 m .81972 .36969 L .82274 .36871 L F
.88363 .3704 m .88547 .36764 L .88667 .36936 L 0 .025 .123 r
F
.88363 .3704 m .88243 .36868 L .88547 .36764 L F
.32556 .37425 m .32657 .37162 L .32831 .37346 L 0 .033 .134 r
F
.32556 .37425 m .32382 .37242 L .32657 .37162 L F
.206 .37102 m .20685 .36816 L .2087 .37003 L 0 .026 .125 r
F
.206 .37102 m .20415 .36917 L .20685 .36816 L F
.64188 .3789 m .64337 .37621 L .6448 .37784 L 0 .044 .146 r
F
.64188 .3789 m .64045 .37726 L .64337 .37621 L F
.40873 .37955 m .40986 .37706 L .41153 .37873 L 0 .046 .148 r
F
.40873 .37955 m .40706 .37787 L .40986 .37706 L F
.89091 .37009 m .89278 .36744 L .89398 .36918 L 0 .024 .123 r
F
.89091 .37009 m .88972 .36835 L .89278 .36744 L F
.61719 .38286 m .61865 .38052 L .6201 .38184 L 0 .055 .157 r
F
.61719 .38286 m .61574 .38157 L .61865 .38052 L F
.49213 .3972 m .49337 .39701 L .49497 .39766 L 0 .106 .2 r
F
.49213 .3972 m .49054 .39618 L .49337 .39701 L F
.59976 .38631 m .6012 .38397 L .60266 .38511 L 0 .065 .167 r
F
.59976 .38631 m .5983 .38516 L .6012 .38397 L F
.39703 .37784 m .39814 .37551 L .39981 .37728 L 0 .042 .144 r
F
.39703 .37784 m .39535 .37604 L .39814 .37551 L F
.76563 .37223 m .76731 .36953 L .76862 .37121 L 0 .029 .128 r
F
.76563 .37223 m .76432 .37054 L .76731 .36953 L F
.24679 .37143 m .2477 .3686 L .24951 .37045 L 0 .027 .126 r
F
.24679 .37143 m .24498 .36958 L .2477 .3686 L F
.77291 .37184 m .77461 .36923 L .77591 .37088 L 0 .028 .128 r
F
.77291 .37184 m .77161 .37018 L .77461 .36923 L F
.4555 .38699 m .45669 .38493 L .45831 .38669 L 0 .068 .169 r
F
.4555 .38699 m .45388 .38524 L .45669 .38493 L F
.58234 .38983 m .58375 .3873 L .58523 .38839 L 0 .075 .176 r
F
.58234 .38983 m .58086 .38878 L .58375 .3873 L F
.63461 .37954 m .63609 .3768 L .63753 .37838 L 0 .046 .148 r
F
.63461 .37954 m .63317 .37803 L .63609 .3768 L F
.56206 .39591 m .56344 .39442 L .56494 .39495 L 0 .099 .194 r
F
.56206 .39591 m .56056 .39551 L .56344 .39442 L F
.35908 .37513 m .36015 .37234 L .36185 .37419 L 0 .035 .136 r
F
.35908 .37513 m .35737 .37328 L .36015 .37234 L F
.82829 .3713 m .83006 .36866 L .83132 .37043 L 0 .027 .126 r
F
.82829 .3713 m .82703 .36955 L .83006 .36866 L F
.4716 .39115 m .47283 .38915 L .47443 .39105 L 0 .081 .181 r
F
.4716 .39115 m .47 .38922 L .47283 .38915 L F
.33282 .37419 m .33384 .37154 L .33558 .37323 L 0 .033 .134 r
F
.33282 .37419 m .33108 .3725 L .33384 .37154 L F
.21324 .37097 m .2141 .36819 L .21594 .37007 L 0 .026 .125 r
F
.21324 .37097 m .2114 .36908 L .2141 .36819 L F
.38532 .37622 m .38642 .37374 L .38811 .37547 L 0 .038 .14 r
F
.38532 .37622 m .38363 .37452 L .38642 .37374 L F
.51993 .40329 m .52123 .40657 L .5228 .40427 L 0 .141 .223 r
F
.51993 .40329 m .51837 .40478 L .52123 .40657 L F
.30656 .37324 m .30754 .37064 L .30931 .37238 L 0 .031 .132 r
F
.30656 .37324 m .30479 .37152 L .30754 .37064 L F
.78021 .37163 m .78191 .36904 L .78321 .37072 L 0 .028 .127 r
F
.78021 .37163 m .77891 .36996 L .78191 .36904 L F
.89823 .37002 m .90011 .36731 L .90129 .36906 L 0 .024 .123 r
F
.89823 .37002 m .89704 .36828 L .90011 .36731 L F
.28031 .37225 m .28125 .36958 L .28303 .37145 L 0 .029 .129 r
F
.28031 .37225 m .27852 .3704 L .28125 .36958 L F
.17242 .37086 m .17323 .36797 L .17511 .36985 L 0 .026 .125 r
F
.17242 .37086 m .17054 .36897 L .17323 .36797 L F
.41599 .37955 m .41713 .37728 L .41879 .37893 L 0 .047 .149 r
F
.41599 .37955 m .41433 .37792 L .41713 .37728 L F
.34009 .37395 m .34112 .37129 L .34286 .373 L 0 .033 .134 r
F
.34009 .37395 m .33835 .37226 L .34112 .37129 L F
.36634 .37497 m .36741 .3725 L .36912 .3742 L 0 .035 .137 r
F
.36634 .37497 m .36463 .37326 L .36741 .3725 L F
.57221 .39314 m .5736 .3909 L .57509 .39172 L 0 .088 .186 r
F
.57221 .39314 m .57071 .39238 L .5736 .3909 L F
.83559 .37114 m .83736 .36836 L .83861 .37009 L 0 .027 .126 r
F
.83559 .37114 m .83434 .3694 L .83736 .36836 L F
.84288 .37079 m .84467 .36811 L .84591 .36983 L 0 .026 .125 r
F
.84288 .37079 m .84164 .36907 L .84467 .36811 L F
.90554 .36982 m .90742 .36707 L .9086 .36882 L 0 .024 .123 r
F
.90554 .36982 m .90435 .36806 L .90742 .36707 L F
.25403 .37148 m .25494 .36877 L .25674 .37065 L 0 .028 .127 r
F
.25403 .37148 m .25222 .36961 L .25494 .36877 L F
.60992 .3838 m .61137 .38135 L .61283 .38261 L 0 .058 .161 r
F
.60992 .3838 m .60846 .38258 L .61137 .38135 L F
.78751 .37149 m .78922 .36888 L .79052 .37058 L 0 .028 .127 r
F
.78751 .37149 m .78622 .3698 L .78922 .36888 L F
.17967 .37071 m .18049 .36784 L .18236 .3697 L 0 .026 .125 r
F
.17967 .37071 m .1778 .36884 L .18049 .36784 L F
.42768 .38162 m .42884 .37909 L .43048 .38098 L 0 .052 .155 r
F
.42768 .38162 m .42604 .37972 L .42884 .37909 L F
.31382 .37318 m .31483 .37034 L .31657 .37219 L 0 .031 .132 r
F
.31382 .37318 m .31206 .37136 L .31483 .37034 L F
.43937 .38348 m .44055 .38114 L .44218 .38298 L 0 .058 .16 r
F
.43937 .38348 m .43774 .38161 L .44055 .38114 L F
.85018 .37057 m .85198 .36786 L .85321 .36958 L 0 .026 .125 r
F
.85018 .37057 m .84894 .36886 L .85198 .36786 L F
.34735 .37384 m .3484 .37123 L .35012 .37303 L 0 .033 .134 r
F
.34735 .37384 m .34563 .37206 L .3484 .37123 L F
.22048 .37102 m .22136 .36814 L .22319 .36999 L 0 .027 .126 r
F
.22048 .37102 m .21864 .36917 L .22136 .36814 L F
.65934 .37627 m .66086 .37384 L .66227 .37535 L 0 .039 .141 r
F
.65934 .37627 m .65792 .37476 L .66086 .37384 L F
.22776 .37067 m .22863 .36795 L .23047 .36968 L 0 .026 .125 r
F
.22776 .37067 m .22591 .36895 L .22863 .36795 L F
.5925 .38743 m .59393 .38523 L .5954 .38635 L 0 .07 .171 r
F
.5925 .38743 m .59103 .38633 L .59393 .38523 L F
.68118 .37513 m .68273 .37251 L .68413 .37417 L 0 .036 .137 r
F
.68118 .37513 m .67979 .37352 L .68273 .37251 L F
.6739 .37554 m .67544 .37296 L .67684 .37453 L 0 .037 .139 r
F
.6739 .37554 m .6725 .37398 L .67544 .37296 L F
.66662 .37595 m .66816 .37345 L .66956 .37499 L 0 .038 .14 r
F
.66662 .37595 m .66521 .37442 L .66816 .37345 L F
.85747 .3703 m .85928 .36756 L .86051 .3693 L 0 .026 .124 r
F
.85747 .3703 m .85624 .36857 L .85928 .36756 L F
.62735 .38061 m .62882 .37783 L .63026 .37927 L 0 .049 .152 r
F
.62735 .38061 m .62591 .37923 L .62882 .37783 L F
.18693 .37054 m .18775 .36774 L .18962 .36956 L 0 .026 .125 r
F
.18693 .37054 m .18505 .36872 L .18775 .36774 L F
.79481 .37135 m .79653 .36866 L .79782 .37039 L 0 .028 .127 r
F
.79481 .37135 m .79352 .36964 L .79653 .36866 L F
.46718 .38954 m .4684 .38724 L .47 .38922 L 0 .076 .177 r
F
.46718 .38954 m .46557 .38756 L .4684 .38724 L F
.45106 .38553 m .45225 .38361 L .45388 .38524 L 0 .065 .167 r
F
.45106 .38553 m .44944 .38386 L .45225 .38361 L F
.52721 .40352 m .52854 .40665 L .53008 .404 L 0 .143 .224 r
F
.52721 .40352 m .52566 .40545 L .52854 .40665 L F
.71031 .37365 m .71191 .37102 L .71328 .37272 L 0 .033 .134 r
F
.71031 .37365 m .70894 .372 L .71191 .37102 L F
.68847 .37488 m .69004 .37239 L .69143 .37401 L 0 .036 .137 r
F
.68847 .37488 m .68708 .37323 L .69004 .37239 L F
.86477 .37004 m .86658 .36726 L .8678 .36904 L 0 .025 .124 r
F
.86477 .37004 m .86354 .36828 L .86658 .36726 L F
.50382 .39994 m .50507 .40232 L .50666 .40152 L 0 .126 .213 r
F
.50382 .39994 m .50223 .39999 L .50507 .40232 L F
.70303 .37411 m .70461 .37136 L .70598 .37297 L 0 .034 .135 r
F
.70303 .37411 m .70166 .37252 L .70461 .37136 L F
.26128 .37149 m .26219 .36885 L .264 .37056 L 0 .028 .128 r
F
.26128 .37149 m .25946 .36978 L .26219 .36885 L F
.48771 .39594 m .48894 .39517 L .49054 .39618 L 0 .102 .197 r
F
.48771 .39594 m .48611 .3948 L .48894 .39517 L F
.28753 .37252 m .2885 .36974 L .29027 .37163 L 0 .03 .13 r
F
.28753 .37252 m .28576 .37065 L .2885 .36974 L F
.80211 .37114 m .80385 .36854 L .80513 .37024 L 0 .028 .127 r
F
.80211 .37114 m .80083 .36943 L .80385 .36854 L F
.39257 .37662 m .39368 .3742 L .39535 .37604 L 0 .04 .142 r
F
.39257 .37662 m .39089 .37483 L .39368 .3742 L F
.19419 .37036 m .19501 .36761 L .19688 .36938 L 0 .026 .125 r
F
.19419 .37036 m .19231 .36858 L .19501 .36761 L F
.23501 .37056 m .23588 .36794 L .23771 .36971 L 0 .027 .126 r
F
.23501 .37056 m .23317 .36881 L .23588 .36794 L F
.37359 .37521 m .37466 .37287 L .37637 .37454 L 0 .037 .139 r
F
.37359 .37521 m .37189 .37353 L .37466 .37287 L F
.32107 .37321 m .32208 .3705 L .32382 .37242 L 0 .032 .133 r
F
.32107 .37321 m .31933 .37132 L .32208 .3705 L F
.73217 .37261 m .73379 .36989 L .73514 .37157 L 0 .031 .131 r
F
.73217 .37261 m .73082 .37093 L .73379 .36989 L F
.40427 .37848 m .40539 .37616 L .40706 .37787 L 0 .045 .147 r
F
.40427 .37848 m .4026 .37674 L .40539 .37616 L F
.72489 .37303 m .7265 .37027 L .72785 .37198 L 0 .032 .132 r
F
.72489 .37303 m .72353 .37132 L .7265 .37027 L F
.71761 .37345 m .7192 .37065 L .72057 .37238 L 0 .032 .133 r
F
.71761 .37345 m .71624 .37173 L .7192 .37065 L F
.75401 .37144 m .75568 .36883 L .757 .37056 L 0 .028 .128 r
F
.75401 .37144 m .75268 .36973 L .75568 .36883 L F
.73945 .37226 m .74109 .36963 L .74243 .37128 L 0 .03 .13 r
F
.73945 .37226 m .73811 .3706 L .74109 .36963 L F
.87207 .36985 m .87391 .36716 L .87512 .36892 L 0 .025 .124 r
F
.87207 .36985 m .87085 .36808 L .87391 .36716 L F
.69576 .37473 m .69734 .37209 L .69871 .37367 L 0 .036 .137 r
F
.69576 .37473 m .69439 .37314 L .69734 .37209 L F
.74674 .37191 m .74838 .36912 L .74971 .37082 L 0 .029 .129 r
F
.74674 .37191 m .7454 .37023 L .74838 .36912 L F
.65208 .37718 m .65358 .37443 L .655 .37596 L 0 .041 .143 r
F
.65208 .37718 m .65065 .37563 L .65358 .37443 L F
.26854 .37133 m .26946 .36869 L .27127 .37042 L 0 .028 .128 r
F
.26854 .37133 m .26673 .36963 L .26946 .36869 L F
.2948 .3724 m .29577 .36967 L .29754 .37143 L 0 .03 .131 r
F
.2948 .3724 m .29302 .37065 L .29577 .36967 L F
.20144 .37018 m .20229 .36736 L .20415 .36917 L 0 .026 .125 r
F
.20144 .37018 m .19958 .3684 L .20229 .36736 L F
.58523 .38839 m .58665 .38626 L .58813 .38736 L 0 .074 .175 r
F
.58523 .38839 m .58375 .3873 L .58665 .38626 L F
.5345 .40354 m .53584 .40474 L .53737 .40341 L 0 .139 .221 r
F
.5345 .40354 m .53296 .40439 L .53584 .40474 L F
.80942 .37105 m .81117 .36844 L .81244 .37012 L 0 .028 .127 r
F
.80942 .37105 m .80815 .36936 L .81117 .36844 L F
.42324 .38014 m .42438 .37801 L .42604 .37972 L 0 .05 .153 r
F
.42324 .38014 m .42158 .37847 L .42438 .37801 L F
.3546 .37409 m .35566 .37141 L .35737 .37328 L 0 .034 .135 r
F
.3546 .37409 m .35288 .37225 L .35566 .37141 L F
.55479 .39752 m .55617 .39675 L .55767 .39659 L 0 .109 .202 r
F
.55479 .39752 m .55328 .39781 L .55617 .39675 L F
.87938 .36971 m .88122 .36696 L .88243 .36868 L 0 .025 .124 r
F
.87938 .36971 m .87817 .36799 L .88122 .36696 L F
.81671 .37073 m .81846 .36799 L .81972 .36969 L 0 .027 .126 r
F
.81671 .37073 m .81545 .36905 L .81846 .36799 L F
.54464 .40063 m .54602 .40211 L .54752 .39981 L 0 .128 .215 r
F
.54464 .40063 m .54313 .40267 L .54602 .40211 L F
.60266 .38511 m .6041 .38266 L .60556 .38385 L 0 .063 .165 r
F
.60266 .38511 m .6012 .38397 L .6041 .38266 L F
.6448 .37784 m .6463 .37516 L .64773 .37678 L 0 .043 .146 r
F
.6448 .37784 m .64337 .37621 L .6463 .37516 L F
.88667 .36936 m .88852 .36663 L .88972 .36835 L 0 .024 .123 r
F
.88667 .36936 m .88547 .36764 L .88852 .36663 L F
.24225 .37058 m .24316 .36776 L .24498 .36958 L 0 .027 .126 r
F
.24225 .37058 m .24043 .36876 L .24316 .36776 L F
.76132 .37144 m .763 .36881 L .76432 .37054 L 0 .029 .129 r
F
.76132 .37144 m .76 .36971 L .763 .36881 L F
.2087 .37003 m .20956 .36721 L .2114 .36908 L 0 .026 .125 r
F
.2087 .37003 m .20685 .36816 L .20956 .36721 L F
.824 .37044 m .82577 .3678 L .82703 .36955 L 0 .027 .126 r
F
.824 .37044 m .82274 .36871 L .82577 .3678 L F
.27579 .37127 m .27673 .3686 L .27852 .3704 L 0 .029 .128 r
F
.27579 .37127 m .274 .3695 L .27673 .3686 L F
.30205 .37231 m .30302 .3698 L .30479 .37152 L 0 .031 .131 r
F
.30205 .37231 m .30028 .37061 L .30302 .3698 L F
.63753 .37838 m .63901 .37563 L .64045 .37726 L 0 .045 .147 r
F
.63753 .37838 m .63609 .3768 L .63901 .37563 L F
.57509 .39172 m .57648 .38938 L .57797 .39026 L 0 .085 .184 r
F
.57509 .39172 m .5736 .3909 L .57648 .38938 L F
.38085 .37536 m .38194 .37284 L .38363 .37452 L 0 .038 .14 r
F
.38085 .37536 m .37915 .37369 L .38194 .37284 L F
.46275 .38809 m .46397 .38557 L .46557 .38756 L 0 .073 .173 r
F
.46275 .38809 m .46114 .38613 L .46397 .38557 L F
.43493 .38224 m .43611 .37973 L .43774 .38161 L 0 .055 .158 r
F
.43493 .38224 m .43329 .38032 L .43611 .37973 L F
.6201 .38184 m .62156 .37928 L .62301 .38062 L 0 .054 .157 r
F
.6201 .38184 m .61865 .38052 L .62156 .37928 L F
.89398 .36918 m .89585 .36653 L .89704 .36828 L 0 .025 .123 r
F
.89398 .36918 m .89278 .36744 L .89585 .36653 L F
.76862 .37121 m .7703 .36853 L .77161 .37018 L 0 .029 .128 r
F
.76862 .37121 m .76731 .36953 L .7703 .36853 L F
.32831 .37346 m .32934 .37066 L .33108 .3725 L 0 .033 .134 r
F
.32831 .37346 m .32657 .37162 L .32934 .37066 L F
.24951 .37045 m .25041 .36775 L .25222 .36961 L 0 .027 .126 r
F
.24951 .37045 m .2477 .3686 L .25041 .36775 L F
.41153 .37873 m .41266 .37626 L .41433 .37792 L 0 .046 .149 r
F
.41153 .37873 m .40986 .37706 L .41266 .37626 L F
.44663 .3842 m .44781 .38218 L .44944 .38386 L 0 .062 .164 r
F
.44663 .3842 m .445 .38248 L .44781 .38218 L F
.77591 .37088 m .77761 .36831 L .77891 .36996 L 0 .028 .128 r
F
.77591 .37088 m .77461 .36923 L .77761 .36831 L F
.4994 .39855 m .50064 .40017 L .50223 .39999 L 0 .12 .21 r
F
.4994 .39855 m .49781 .39813 L .50064 .40017 L F
.56494 .39495 m .56633 .39321 L .56783 .39386 L 0 .098 .194 r
F
.56494 .39495 m .56344 .39442 L .56633 .39321 L F
.36185 .37419 m .36293 .37139 L .36463 .37326 L 0 .035 .136 r
F
.36185 .37419 m .36015 .37234 L .36293 .37139 L F
.33558 .37323 m .33661 .37057 L .33835 .37226 L 0 .033 .134 r
F
.33558 .37323 m .33384 .37154 L .33661 .37057 L F
.48328 .39464 m .48451 .39329 L .48611 .3948 L 0 .098 .194 r
F
.48328 .39464 m .48168 .39303 L .48451 .39329 L F
.83132 .37043 m .83309 .36762 L .83434 .3694 L 0 .027 .126 r
F
.83132 .37043 m .83006 .36866 L .83309 .36762 L F
.17511 .36985 m .17592 .36696 L .1778 .36884 L 0 .026 .125 r
F
.17511 .36985 m .17323 .36797 L .17592 .36696 L F
.90129 .36906 m .90317 .36631 L .90435 .36806 L 0 .024 .123 r
F
.90129 .36906 m .90011 .36731 L .90317 .36631 L F
.21594 .37007 m .2168 .36729 L .21864 .36917 L 0 .026 .125 r
F
.21594 .37007 m .2141 .36819 L .2168 .36729 L F
.61283 .38261 m .61428 .38028 L .61574 .38157 L 0 .057 .16 r
F
.61283 .38261 m .61137 .38135 L .61428 .38028 L F
.83861 .37009 m .84039 .36735 L .84164 .36907 L 0 .027 .126 r
F
.83861 .37009 m .83736 .36836 L .84039 .36735 L F
.78321 .37072 m .78492 .36811 L .78622 .3698 L 0 .028 .128 r
F
.78321 .37072 m .78191 .36904 L .78492 .36811 L F
.30931 .37238 m .3103 .3696 L .31206 .37136 L 0 .031 .132 r
F
.30931 .37238 m .30754 .37064 L .3103 .3696 L F
.34286 .373 m .3439 .37033 L .34563 .37206 L 0 .033 .134 r
F
.34286 .373 m .34112 .37129 L .3439 .37033 L F
.63026 .37927 m .63173 .37653 L .63317 .37803 L 0 .048 .15 r
F
.63026 .37927 m .62882 .37783 L .63173 .37653 L F
.39981 .37728 m .40092 .375 L .4026 .37674 L 0 .044 .146 r
F
.39981 .37728 m .39814 .37551 L .40092 .375 L F
.38811 .37547 m .38921 .37304 L .39089 .37483 L 0 .039 .141 r
F
.38811 .37547 m .38642 .37374 L .38921 .37304 L F
.84591 .36983 m .84771 .36714 L .84894 .36886 L 0 .026 .125 r
F
.84591 .36983 m .84467 .36811 L .84771 .36714 L F
.28303 .37145 m .28398 .36877 L .28576 .37065 L 0 .03 .13 r
F
.28303 .37145 m .28125 .36958 L .28398 .36877 L F
.18236 .3697 m .18318 .36685 L .18505 .36872 L 0 .026 .125 r
F
.18236 .3697 m .18049 .36784 L .18318 .36685 L F
.36912 .3742 m .37018 .37185 L .37189 .37353 L 0 .036 .138 r
F
.36912 .3742 m .36741 .3725 L .37018 .37185 L F
.31657 .37219 m .31758 .36943 L .31933 .37132 L 0 .031 .132 r
F
.31657 .37219 m .31483 .37034 L .31758 .36943 L F
.79052 .37058 m .79223 .36792 L .79352 .36964 L 0 .028 .128 r
F
.79052 .37058 m .78922 .36888 L .79223 .36792 L F
.5954 .38635 m .59683 .38403 L .5983 .38516 L 0 .069 .17 r
F
.5954 .38635 m .59393 .38523 L .59683 .38403 L F
.85321 .36958 m .85501 .36685 L .85624 .36857 L 0 .026 .125 r
F
.85321 .36958 m .85198 .36786 L .85501 .36685 L F
.22319 .36999 m .22407 .36711 L .22591 .36895 L 0 .026 .126 r
F
.22319 .36999 m .22136 .36814 L .22407 .36711 L F
.47885 .39283 m .48008 .39127 L .48168 .39303 L 0 .092 .189 r
F
.47885 .39283 m .47726 .39096 L .48008 .39127 L F
.51551 .40317 m .5168 .40627 L .51837 .40478 L 0 .145 .226 r
F
.51551 .40317 m .51394 .40391 L .5168 .40627 L F
.41879 .37893 m .41993 .37679 L .42158 .37847 L 0 .048 .151 r
F
.41879 .37893 m .41713 .37728 L .41993 .37679 L F
.25674 .37065 m .25766 .3679 L .25946 .36978 L 0 .028 .128 r
F
.25674 .37065 m .25494 .36877 L .25766 .3679 L F
.67684 .37453 m .67839 .3719 L .67979 .37352 L 0 .037 .138 r
F
.67684 .37453 m .67544 .37296 L .67839 .3719 L F
.23047 .36968 m .23134 .36705 L .23317 .36881 L 0 .026 .125 r
F
.23047 .36968 m .22863 .36795 L .23134 .36705 L F
.66227 .37535 m .66381 .37292 L .66521 .37442 L 0 .039 .141 r
F
.66227 .37535 m .66086 .37384 L .66381 .37292 L F
.86051 .3693 m .86232 .36652 L .86354 .36828 L 0 .025 .124 r
F
.86051 .3693 m .85928 .36756 L .86232 .36652 L F
.45831 .38669 m .45952 .38437 L .46114 .38613 L 0 .07 .171 r
F
.45831 .38669 m .45669 .38493 L .45952 .38437 L F
.68413 .37417 m .68569 .37152 L .68708 .37323 L 0 .036 .137 r
F
.68413 .37417 m .68273 .37251 L .68569 .37152 L F
.70598 .37297 m .70757 .37036 L .70894 .372 L 0 .033 .134 r
F
.70598 .37297 m .70461 .37136 L .70757 .37036 L F
.66956 .37499 m .6711 .37244 L .6725 .37398 L 0 .038 .14 r
F
.66956 .37499 m .66816 .37345 L .6711 .37244 L F
.18962 .36956 m .19044 .36676 L .19231 .36858 L 0 .026 .125 r
F
.18962 .36956 m .18775 .36774 L .19044 .36676 L F
.79782 .37039 m .79954 .36768 L .80083 .36943 L 0 .028 .127 r
F
.79782 .37039 m .79653 .36866 L .79954 .36768 L F
.35012 .37303 m .35117 .37041 L .35288 .37225 L 0 .034 .135 r
F
.35012 .37303 m .3484 .37123 L .35117 .37041 L F
.8678 .36904 m .86963 .36629 L .87085 .36808 L 0 .025 .124 r
F
.8678 .36904 m .86658 .36726 L .86963 .36629 L F
.43048 .38098 m .43165 .37844 L .43329 .38032 L 0 .053 .156 r
F
.43048 .38098 m .42884 .37909 L .43165 .37844 L F
.71328 .37272 m .71487 .37001 L .71624 .37173 L 0 .033 .134 r
F
.71328 .37272 m .71191 .37102 L .71487 .37001 L F
.655 .37596 m .65651 .37325 L .65792 .37476 L 0 .04 .142 r
F
.655 .37596 m .65358 .37443 L .65651 .37325 L F
.72785 .37198 m .72947 .36922 L .73082 .37093 L 0 .031 .132 r
F
.72785 .37198 m .7265 .37027 L .72947 .36922 L F
.73514 .37157 m .73677 .36894 L .73811 .3706 L 0 .031 .131 r
F
.73514 .37157 m .73379 .36989 L .73677 .36894 L F
.264 .37056 m .26492 .36792 L .26673 .36963 L 0 .028 .128 r
F
.264 .37056 m .26219 .36885 L .26492 .36792 L F
.72057 .37238 m .72217 .36957 L .72353 .37132 L 0 .032 .133 r
F
.72057 .37238 m .7192 .37065 L .72217 .36957 L F
.69143 .37401 m .693 .37155 L .69439 .37314 L 0 .036 .138 r
F
.69143 .37401 m .69004 .37239 L .693 .37155 L F
.19688 .36938 m .19771 .36661 L .19958 .3684 L 0 .026 .125 r
F
.19688 .36938 m .19501 .36761 L .19771 .36661 L F
.29027 .37163 m .29125 .36875 L .29302 .37065 L 0 .03 .131 r
F
.29027 .37163 m .2885 .36974 L .29125 .36875 L F
.74971 .37082 m .75135 .36802 L .75268 .36973 L 0 .029 .129 r
F
.74971 .37082 m .74838 .36912 L .75135 .36802 L F
.80513 .37024 m .80687 .36767 L .80815 .36936 L 0 .028 .128 r
F
.80513 .37024 m .80385 .36854 L .80687 .36767 L F
.69871 .37367 m .70029 .37093 L .70166 .37252 L 0 .035 .136 r
F
.69871 .37367 m .69734 .37209 L .70029 .37093 L F
.47443 .39105 m .47566 .38907 L .47726 .39096 L 0 .086 .184 r
F
.47443 .39105 m .47283 .38915 L .47566 .38907 L F
.44218 .38298 m .44336 .38066 L .445 .38248 L 0 .06 .162 r
F
.44218 .38298 m .44055 .38114 L .44336 .38066 L F
.57797 .39026 m .57937 .38785 L .58086 .38878 L 0 .082 .181 r
F
.57797 .39026 m .57648 .38938 L .57937 .38785 L F
.74243 .37128 m .74407 .36858 L .7454 .37023 L 0 .03 .13 r
F
.74243 .37128 m .74109 .36963 L .74407 .36858 L F
.23771 .36971 m .2386 .36698 L .24043 .36876 L 0 .027 .126 r
F
.23771 .36971 m .23588 .36794 L .2386 .36698 L F
.60556 .38385 m .607 .38132 L .60846 .38258 L 0 .062 .164 r
F
.60556 .38385 m .6041 .38266 L .607 .38132 L F
.87512 .36892 m .87697 .36625 L .87817 .36799 L 0 .025 .124 r
F
.87512 .36892 m .87391 .36716 L .87697 .36625 L F
.757 .37056 m .75868 .36796 L .76 .36971 L 0 .029 .129 r
F
.757 .37056 m .75568 .36883 L .75868 .36796 L F
.20415 .36917 m .205 .36632 L .20685 .36816 L 0 .026 .124 r
F
.20415 .36917 m .20229 .36736 L .205 .36632 L F
.58813 .38736 m .58955 .38522 L .59103 .38633 L 0 .074 .174 r
F
.58813 .38736 m .58665 .38626 L .58955 .38522 L F
.32382 .37242 m .32484 .36966 L .32657 .37162 L 0 .033 .133 r
F
.32382 .37242 m .32208 .3705 L .32484 .36966 L F
.27127 .37042 m .2722 .36775 L .274 .3695 L 0 .028 .128 r
F
.27127 .37042 m .26946 .36869 L .2722 .36775 L F
.29754 .37143 m .29851 .36884 L .30028 .37061 L 0 .031 .131 r
F
.29754 .37143 m .29577 .36967 L .29851 .36884 L F
.51109 .4016 m .51236 .40661 L .51394 .40391 L 0 .146 .226 r
F
.51109 .4016 m .50951 .4031 L .51236 .40661 L F
.81972 .36969 m .82148 .36699 L .82274 .36871 L 0 .027 .126 r
F
.81972 .36969 m .81846 .36799 L .82148 .36699 L F
.37637 .37454 m .37745 .37203 L .37915 .37369 L 0 .038 .14 r
F
.37637 .37454 m .37466 .37287 L .37745 .37203 L F
.88243 .36868 m .88427 .36592 L .88547 .36764 L 0 .025 .123 r
F
.88243 .36868 m .88122 .36696 L .88427 .36592 L F
.62301 .38062 m .62447 .37789 L .62591 .37923 L 0 .053 .155 r
F
.62301 .38062 m .62156 .37928 L .62447 .37789 L F
.64773 .37678 m .64923 .374 L .65065 .37563 L 0 .043 .145 r
F
.64773 .37678 m .6463 .37516 L .64923 .374 L F
.55767 .39659 m .55905 .39548 L .56056 .39551 L 0 .109 .201 r
F
.55767 .39659 m .55617 .39675 L .55905 .39548 L F
.81244 .37012 m .81418 .36738 L .81545 .36905 L 0 .028 .127 r
F
.81244 .37012 m .81117 .36844 L .81418 .36738 L F
.88972 .36835 m .89159 .36572 L .89278 .36744 L 0 .025 .123 r
F
.88972 .36835 m .88852 .36663 L .89159 .36572 L F
.39535 .37604 m .39646 .37363 L .39814 .37551 L 0 .042 .144 r
F
.39535 .37604 m .39368 .3742 L .39646 .37363 L F
.49497 .39766 m .49621 .39783 L .49781 .39813 L 0 .116 .206 r
F
.49497 .39766 m .49337 .39701 L .49621 .39783 L F
.64045 .37726 m .64194 .37457 L .64337 .37621 L 0 .044 .147 r
F
.64045 .37726 m .63901 .37563 L .64194 .37457 L F
.40706 .37787 m .40819 .37537 L .40986 .37706 L 0 .046 .149 r
F
.40706 .37787 m .40539 .37616 L .40819 .37537 L F
.24498 .36958 m .24588 .36677 L .2477 .3686 L 0 .027 .126 r
F
.24498 .36958 m .24316 .36776 L .24588 .36677 L F
.47 .38922 m .47123 .38718 L .47283 .38915 L 0 .08 .18 r
F
.47 .38922 m .4684 .38724 L .47123 .38718 L F
.35737 .37328 m .35844 .37044 L .36015 .37234 L 0 .035 .136 r
F
.35737 .37328 m .35566 .37141 L .35844 .37044 L F
.45388 .38524 m .45507 .38335 L .45669 .38493 L 0 .068 .17 r
F
.45388 .38524 m .45225 .38361 L .45507 .38335 L F
.2114 .36908 m .21225 .36631 L .2141 .36819 L 0 .026 .125 r
F
.2114 .36908 m .20956 .36721 L .21225 .36631 L F
.54752 .39981 m .5489 .40117 L .5504 .39887 L 0 .129 .215 r
F
.54752 .39981 m .54602 .40211 L .5489 .40117 L F
.76432 .37054 m .76599 .36782 L .76731 .36953 L 0 .029 .129 r
F
.76432 .37054 m .763 .36881 L .76599 .36782 L F
.82703 .36955 m .8288 .36688 L .83006 .36866 L 0 .027 .126 r
F
.82703 .36955 m .82577 .3678 L .8288 .36688 L F
.17054 .36897 m .17134 .36612 L .17323 .36797 L 0 .026 .124 r
F
.17054 .36897 m .16865 .36714 L .17134 .36612 L F
.77161 .37018 m .7733 .36758 L .77461 .36923 L 0 .028 .128 r
F
.77161 .37018 m .7703 .36853 L .7733 .36758 L F
.27852 .3704 m .27946 .36777 L .28125 .36958 L 0 .029 .129 r
F
.27852 .3704 m .27673 .3686 L .27946 .36777 L F
.56783 .39386 m .56922 .39166 L .57071 .39238 L 0 .096 .192 r
F
.56783 .39386 m .56633 .39321 L .56922 .39166 L F
.38363 .37452 m .38473 .37203 L .38642 .37374 L 0 .038 .14 r
F
.38363 .37452 m .38194 .37284 L .38473 .37203 L F
.33108 .3725 m .33211 .36971 L .33384 .37154 L 0 .033 .134 r
F
.33108 .3725 m .32934 .37066 L .33211 .36971 L F
.89704 .36828 m .89892 .36556 L .90011 .36731 L 0 .025 .123 r
F
.89704 .36828 m .89585 .36653 L .89892 .36556 L F
.30479 .37152 m .30577 .3689 L .30754 .37064 L 0 .031 .132 r
F
.30479 .37152 m .30302 .3698 L .30577 .3689 L F
.63317 .37803 m .63465 .37523 L .63609 .3768 L 0 .047 .149 r
F
.63317 .37803 m .63173 .37653 L .63465 .37523 L F
.77891 .36996 m .78062 .36739 L .78191 .36904 L 0 .028 .128 r
F
.77891 .36996 m .77761 .36831 L .78062 .36739 L F
.83434 .3694 m .83611 .36657 L .83736 .36836 L 0 .027 .126 r
F
.83434 .3694 m .83309 .36762 L .83611 .36657 L F
.42604 .37972 m .42719 .37734 L .42884 .37909 L 0 .052 .154 r
F
.42604 .37972 m .42438 .37801 L .42719 .37734 L F
.25222 .36961 m .25313 .36689 L .25494 .36877 L 0 .027 .127 r
F
.25222 .36961 m .25041 .36775 L .25313 .36689 L F
.36463 .37326 m .36571 .37062 L .36741 .3725 L 0 .035 .137 r
F
.36463 .37326 m .36293 .37139 L .36571 .37062 L F
.41433 .37792 m .41546 .37561 L .41713 .37728 L 0 .047 .15 r
F
.41433 .37792 m .41266 .37626 L .41546 .37561 L F
.33835 .37226 m .33939 .36958 L .34112 .37129 L 0 .033 .134 r
F
.33835 .37226 m .33661 .37057 L .33939 .36958 L F
.61574 .38157 m .6172 .3792 L .61865 .38052 L 0 .057 .159 r
F
.61574 .38157 m .61428 .38028 L .6172 .3792 L F
.1778 .36884 m .17861 .36597 L .18049 .36784 L 0 .026 .124 r
F
.1778 .36884 m .17592 .36696 L .17861 .36597 L F
.84164 .36907 m .84343 .36638 L .84467 .36811 L 0 .026 .126 r
F
.84164 .36907 m .84039 .36735 L .84343 .36638 L F
.90435 .36806 m .90623 .3653 L .90742 .36707 L 0 .024 .123 r
F
.90435 .36806 m .90317 .36631 L .90623 .3653 L F
.43774 .38161 m .43892 .37928 L .44055 .38114 L 0 .057 .16 r
F
.43774 .38161 m .43611 .37973 L .43892 .37928 L F
.31206 .37136 m .31307 .36856 L .31483 .37034 L 0 .031 .132 r
F
.31206 .37136 m .3103 .3696 L .31307 .36856 L F
.46557 .38756 m .46679 .38525 L .4684 .38724 L 0 .075 .176 r
F
.46557 .38756 m .46397 .38557 L .46679 .38525 L F
.21864 .36917 m .21952 .36627 L .22136 .36814 L 0 .026 .125 r
F
.21864 .36917 m .2168 .36729 L .21952 .36627 L F
.5983 .38516 m .59973 .38282 L .6012 .38397 L 0 .068 .169 r
F
.5983 .38516 m .59683 .38403 L .59973 .38282 L F
.78622 .3698 m .78793 .36718 L .78922 .36888 L 0 .028 .128 r
F
.78622 .3698 m .78492 .36811 L .78793 .36718 L F
.34563 .37206 m .34667 .36948 L .3484 .37123 L 0 .033 .134 r
F
.34563 .37206 m .3439 .37033 L .34667 .36948 L F
.53737 .40341 m .53872 .40502 L .54025 .40323 L 0 .145 .226 r
F
.53737 .40341 m .53584 .40474 L .53872 .40502 L F
.84894 .36886 m .85074 .36615 L .85198 .36786 L 0 .026 .125 r
F
.84894 .36886 m .84771 .36714 L .85074 .36615 L F
.5228 .40427 m .52411 .40871 L .52566 .40545 L 0 .158 .233 r
F
.5228 .40427 m .52123 .40657 L .52411 .40871 L F
.49054 .39618 m .49178 .39635 L .49337 .39701 L 0 .112 .204 r
F
.49054 .39618 m .48894 .39517 L .49178 .39635 L F
.18505 .36872 m .18588 .36587 L .18775 .36774 L 0 .026 .125 r
F
.18505 .36872 m .18318 .36685 L .18588 .36587 L F
.22591 .36895 m .22679 .36611 L .22863 .36795 L F
.22591 .36895 m .22407 .36711 L .22679 .36611 L F
.58086 .38878 m .58226 .38633 L .58375 .3873 L 0 .079 .179 r
F
.58086 .38878 m .57937 .38785 L .58226 .38633 L F
.85624 .36857 m .85805 .36583 L .85928 .36756 L 0 .026 .125 r
F
.85624 .36857 m .85501 .36685 L .85805 .36583 L F
.28576 .37065 m .28673 .36784 L .2885 .36974 L 0 .03 .13 r
F
.28576 .37065 m .28398 .36877 L .28673 .36784 L F
.53008 .404 m .53142 .4078 L .53296 .40439 L 0 .155 .232 r
F
.53008 .404 m .52854 .40665 L .53142 .4078 L F
.79352 .36964 m .79524 .36691 L .79653 .36866 L 0 .028 .128 r
F
.79352 .36964 m .79223 .36792 L .79524 .36691 L F
.67979 .37352 m .68134 .37084 L .68273 .37251 L 0 .037 .138 r
F
.67979 .37352 m .67839 .3719 L .68134 .37084 L F
.86354 .36828 m .86536 .36548 L .86658 .36726 L 0 .025 .124 r
F
.86354 .36828 m .86232 .36652 L .86536 .36548 L F
.31933 .37132 m .32034 .36857 L .32208 .3705 L 0 .032 .132 r
F
.31933 .37132 m .31758 .36943 L .32034 .36857 L F
.65792 .37476 m .65945 .37233 L .66086 .37384 L 0 .04 .142 r
F
.65792 .37476 m .65651 .37325 L .65945 .37233 L F
.44944 .38386 m .45062 .38199 L .45225 .38361 L 0 .065 .167 r
F
.44944 .38386 m .44781 .38218 L .45062 .38199 L F
.6725 .37398 m .67405 .37142 L .67544 .37296 L 0 .038 .14 r
F
.6725 .37398 m .6711 .37244 L .67405 .37142 L F
.66521 .37442 m .66675 .37195 L .66816 .37345 L 0 .039 .141 r
F
.66521 .37442 m .66381 .37292 L .66675 .37195 L F
.70894 .372 m .71054 .36936 L .71191 .37102 L 0 .033 .134 r
F
.70894 .372 m .70757 .37036 L .71054 .36936 L F
.39089 .37483 m .392 .37235 L .39368 .3742 L 0 .04 .142 r
F
.39089 .37483 m .38921 .37304 L .392 .37235 L F
.25946 .36978 m .26039 .36699 L .26219 .36885 L 0 .028 .128 r
F
.25946 .36978 m .25766 .3679 L .26039 .36699 L F
.68708 .37323 m .68865 .37065 L .69004 .37239 L 0 .036 .138 r
F
.68708 .37323 m .68569 .37152 L .68865 .37065 L F
.19231 .36858 m .19314 .36579 L .19501 .36761 L 0 .026 .125 r
F
.19231 .36858 m .19044 .36676 L .19314 .36579 L F
.23317 .36881 m .23405 .36616 L .23588 .36794 L 0 .027 .126 r
F
.23317 .36881 m .23134 .36705 L .23405 .36616 L F
.80083 .36943 m .80256 .36678 L .80385 .36854 L 0 .028 .127 r
F
.80083 .36943 m .79954 .36768 L .80256 .36678 L F
.60846 .38258 m .60991 .38001 L .61137 .38135 L 0 .06 .163 r
F
.60846 .38258 m .607 .38132 L .60991 .38001 L F
.4026 .37674 m .40371 .37445 L .40539 .37616 L 0 .045 .148 r
F
.4026 .37674 m .40092 .375 L .40371 .37445 L F
.70166 .37252 m .70324 .36977 L .70461 .37136 L 0 .034 .136 r
F
.70166 .37252 m .70029 .37093 L .70324 .36977 L F
.37189 .37353 m .37296 .3712 L .37466 .37287 L 0 .037 .139 r
F
.37189 .37353 m .37018 .37185 L .37296 .3712 L F
.87085 .36808 m .87269 .36536 L .87391 .36716 L 0 .025 .124 r
F
.87085 .36808 m .86963 .36629 L .87269 .36536 L F
.72353 .37132 m .72513 .36848 L .7265 .37027 L 0 .032 .132 r
F
.72353 .37132 m .72217 .36957 L .72513 .36848 L F
.71624 .37173 m .71784 .36891 L .7192 .37065 L 0 .033 .133 r
F
.71624 .37173 m .71487 .37001 L .71784 .36891 L F
.73082 .37093 m .73244 .36818 L .73379 .36989 L 0 .031 .131 r
F
.73082 .37093 m .72947 .36922 L .73244 .36818 L F
.62591 .37923 m .62738 .37649 L .62882 .37783 L 0 .051 .153 r
F
.62591 .37923 m .62447 .37789 L .62738 .37649 L F
.75268 .36973 m .75435 .3671 L .75568 .36883 L 0 .029 .128 r
F
.75268 .36973 m .75135 .36802 L .75435 .3671 L F
.73811 .3706 m .73975 .36798 L .74109 .36963 L 0 .031 .131 r
F
.73811 .3706 m .73677 .36894 L .73975 .36798 L F
.19958 .3684 m .20042 .36555 L .20229 .36736 L 0 .026 .125 r
F
.19958 .3684 m .19771 .36661 L .20042 .36555 L F
.35288 .37225 m .35394 .36955 L .35566 .37141 L 0 .034 .135 r
F
.35288 .37225 m .35117 .37041 L .35394 .36955 L F
.7454 .37023 m .74705 .36748 L .74838 .36912 L 0 .03 .13 r
F
.7454 .37023 m .74407 .36858 L .74705 .36748 L F
.26673 .36963 m .26766 .36696 L .26946 .36869 L 0 .029 .128 r
F
.26673 .36963 m .26492 .36792 L .26766 .36696 L F
.29302 .37065 m .294 .36776 L .29577 .36967 L 0 .03 .131 r
F
.29302 .37065 m .29125 .36875 L .294 .36776 L F
.69439 .37314 m .69596 .37051 L .69734 .37209 L 0 .036 .138 r
F
.69439 .37314 m .693 .37155 L .69596 .37051 L F
.57071 .39238 m .5721 .3901 L .5736 .3909 L 0 .093 .19 r
F
.57071 .39238 m .56922 .39166 L .5721 .3901 L F
.59103 .38633 m .59245 .38411 L .59393 .38523 L 0 .073 .174 r
F
.59103 .38633 m .58955 .38522 L .59245 .38411 L F
.46114 .38613 m .46235 .38381 L .46397 .38557 L 0 .072 .173 r
F
.46114 .38613 m .45952 .38437 L .46235 .38381 L F
.65065 .37563 m .65215 .37279 L .65358 .37443 L 0 .042 .144 r
F
.65065 .37563 m .64923 .374 L .65215 .37279 L F
.80815 .36936 m .8099 .36676 L .81117 .36844 L 0 .028 .128 r
F
.80815 .36936 m .80687 .36767 L .8099 .36676 L F
.24043 .36876 m .24133 .36597 L .24316 .36776 L 0 .027 .126 r
F
.24043 .36876 m .2386 .36698 L .24133 .36597 L F
.20685 .36816 m .2077 .36536 L .20956 .36721 L 0 .026 .124 r
F
.20685 .36816 m .205 .36632 L .2077 .36536 L F
.42158 .37847 m .42273 .37631 L .42438 .37801 L 0 .05 .153 r
F
.42158 .37847 m .41993 .37679 L .42273 .37631 L F
.87817 .36799 m .88002 .36523 L .88122 .36696 L 0 .025 .124 r
F
.87817 .36799 m .87697 .36625 L .88002 .36523 L F
.43329 .38032 m .43447 .37785 L .43611 .37973 L 0 .055 .157 r
F
.43329 .38032 m .43165 .37844 L .43447 .37785 L F
.56056 .39551 m .56194 .39418 L .56344 .39442 L 0 .107 .2 r
F
.56056 .39551 m .55905 .39548 L .56194 .39418 L F
.81545 .36905 m .81719 .36631 L .81846 .36799 L 0 .027 .127 r
F
.81545 .36905 m .81418 .36738 L .81719 .36631 L F
.88547 .36764 m .88733 .36491 L .88852 .36663 L 0 .025 .123 r
F
.88547 .36764 m .88427 .36592 L .88733 .36491 L F
.274 .3695 m .27494 .36683 L .27673 .3686 L 0 .029 .128 r
F
.274 .3695 m .2722 .36775 L .27494 .36683 L F
.76 .36971 m .76167 .36705 L .763 .36881 L 0 .029 .129 r
F
.76 .36971 m .75868 .36796 L .76167 .36705 L F
.82274 .36871 m .82451 .36605 L .82577 .3678 L 0 .027 .126 r
F
.82274 .36871 m .82148 .36699 L .82451 .36605 L F
.48611 .3948 m .48735 .39385 L .48894 .39517 L 0 .105 .199 r
F
.48611 .3948 m .48451 .39329 L .48735 .39385 L F
.64337 .37621 m .64487 .37351 L .6463 .37516 L 0 .044 .146 r
F
.64337 .37621 m .64194 .37457 L .64487 .37351 L F
.32657 .37162 m .3276 .36871 L .32934 .37066 L 0 .033 .134 r
F
.32657 .37162 m .32484 .36966 L .3276 .36871 L F
.30028 .37061 m .30125 .36802 L .30302 .3698 L 0 .031 .132 r
F
.30028 .37061 m .29851 .36884 L .30125 .36802 L F
.2477 .3686 m .2486 .3659 L .25041 .36775 L 0 .027 .126 r
F
.2477 .3686 m .24588 .36677 L .2486 .3659 L F
.37915 .37369 m .38024 .37119 L .38194 .37284 L 0 .038 .14 r
F
.37915 .37369 m .37745 .37203 L .38024 .37119 L F
.89278 .36744 m .89466 .36482 L .89585 .36653 L 0 .025 .123 r
F
.89278 .36744 m .89159 .36572 L .89466 .36482 L F
.36015 .37234 m .36122 .36947 L .36293 .37139 L 0 .035 .136 r
F
.36015 .37234 m .35844 .37044 L .36122 .36947 L F
.63609 .3768 m .63757 .374 L .63901 .37563 L 0 .045 .148 r
F
.63609 .3768 m .63465 .37523 L .63757 .374 L F
.76731 .36953 m .76899 .36682 L .7703 .36853 L 0 .029 .129 r
F
.76731 .36953 m .76599 .36782 L .76899 .36682 L F
.445 .38248 m .44618 .38041 L .44781 .38218 L 0 .062 .164 r
F
.445 .38248 m .44336 .38066 L .44618 .38041 L F
.5504 .39887 m .55179 .39985 L .55328 .39781 L 0 .128 .215 r
F
.5504 .39887 m .5489 .40117 L .55179 .39985 L F
.40986 .37706 m .411 .37458 L .41266 .37626 L 0 .047 .149 r
F
.40986 .37706 m .40819 .37537 L .411 .37458 L F
.17323 .36797 m .17404 .36511 L .17592 .36696 L 0 .026 .124 r
F
.17323 .36797 m .17134 .36612 L .17404 .36511 L F
.2141 .36819 m .21496 .36542 L .2168 .36729 L 0 .026 .125 r
F
.2141 .36819 m .21225 .36631 L .21496 .36542 L F
.77461 .36923 m .77631 .36666 L .77761 .36831 L 0 .029 .128 r
F
.77461 .36923 m .7733 .36758 L .77631 .36666 L F
.83006 .36866 m .83183 .36583 L .83309 .36762 L 0 .027 .126 r
F
.83006 .36866 m .8288 .36688 L .83183 .36583 L F
.58375 .3873 m .58516 .38528 L .58665 .38626 L 0 .078 .178 r
F
.58375 .3873 m .58226 .38633 L .58516 .38528 L F
.33384 .37154 m .33488 .36873 L .33661 .37057 L 0 .033 .134 r
F
.33384 .37154 m .33211 .36971 L .33488 .36873 L F
.90011 .36731 m .90198 .36454 L .90317 .36631 L 0 .025 .123 r
F
.90011 .36731 m .89892 .36556 L .90198 .36454 L F
.48168 .39303 m .48292 .39166 L .48451 .39329 L 0 .099 .194 r
F
.48168 .39303 m .48008 .39127 L .48292 .39166 L F
.50666 .40152 m .50792 .40465 L .50951 .4031 L 0 .145 .225 r
F
.50666 .40152 m .50507 .40232 L .50792 .40465 L F
.83736 .36836 m .83914 .36555 L .84039 .36735 L 0 .027 .126 r
F
.83736 .36836 m .83611 .36657 L .83914 .36555 L F
.28125 .36958 m .2822 .36693 L .28398 .36877 L 0 .029 .129 r
F
.28125 .36958 m .27946 .36777 L .2822 .36693 L F
.61865 .38052 m .62011 .37795 L .62156 .37928 L 0 .056 .159 r
F
.61865 .38052 m .6172 .3792 L .62011 .37795 L F
.6012 .38397 m .60263 .38143 L .6041 .38266 L 0 .066 .168 r
F
.6012 .38397 m .59973 .38282 L .60263 .38143 L F
.30754 .37064 m .30854 .36784 L .3103 .3696 L 0 .031 .132 r
F
.30754 .37064 m .30577 .3689 L .30854 .36784 L F
.78191 .36904 m .78363 .36647 L .78492 .36811 L 0 .028 .128 r
F
.78191 .36904 m .78062 .36739 L .78363 .36647 L F
.39814 .37551 m .39925 .37309 L .40092 .375 L 0 .043 .146 r
F
.39814 .37551 m .39646 .37363 L .39925 .37309 L F
.18049 .36784 m .18131 .36499 L .18318 .36685 L 0 .026 .124 r
F
.18049 .36784 m .17861 .36597 L .18131 .36499 L F
.34112 .37129 m .34216 .36859 L .3439 .37033 L 0 .033 .134 r
F
.34112 .37129 m .33939 .36958 L .34216 .36859 L F
.38642 .37374 m .38752 .37129 L .38921 .37304 L 0 .039 .141 r
F
.38642 .37374 m .38473 .37203 L .38752 .37129 L F
.84467 .36811 m .84647 .36542 L .84771 .36714 L 0 .026 .126 r
F
.84467 .36811 m .84343 .36638 L .84647 .36542 L F
.47726 .39096 m .47849 .38949 L .48008 .39127 L 0 .091 .189 r
F
.47726 .39096 m .47566 .38907 L .47849 .38949 L F
.31483 .37034 m .31583 .36762 L .31758 .36943 L 0 .031 .131 r
F
.31483 .37034 m .31307 .36856 L .31583 .36762 L F
.22136 .36814 m .22224 .36524 L .22407 .36711 L 0 .026 .125 r
F
.22136 .36814 m .21952 .36627 L .22224 .36524 L F
.25494 .36877 m .25586 .36602 L .25766 .3679 L 0 .028 .127 r
F
.25494 .36877 m .25313 .36689 L .25586 .36602 L F
.36741 .3725 m .36848 .36995 L .37018 .37185 L 0 .036 .138 r
F
.36741 .3725 m .36571 .37062 L .36848 .36995 L F
.85198 .36786 m .85378 .36514 L .85501 .36685 L 0 .026 .125 r
F
.85198 .36786 m .85074 .36615 L .85378 .36514 L F
.78922 .36888 m .79094 .3662 L .79223 .36792 L 0 .028 .128 r
F
.78922 .36888 m .78793 .36718 L .79094 .3662 L F
.62882 .37783 m .63029 .37514 L .63173 .37653 L 0 .049 .152 r
F
.62882 .37783 m .62738 .37649 L .63029 .37514 L F
.18775 .36774 m .18857 .36491 L .19044 .36676 L 0 .026 .125 r
F
.18775 .36774 m .18588 .36587 L .18857 .36491 L F
.45669 .38493 m .4579 .3828 L .45952 .38437 L 0 .071 .172 r
F
.45669 .38493 m .45507 .38335 L .4579 .3828 L F
.22863 .36795 m .2295 .36523 L .23134 .36705 L 0 .026 .125 r
F
.22863 .36795 m .22679 .36611 L .2295 .36523 L F
.85928 .36756 m .86109 .36478 L .86232 .36652 L 0 .026 .124 r
F
.85928 .36756 m .85805 .36583 L .86109 .36478 L F
.42884 .37909 m .43001 .37664 L .43165 .37844 L 0 .053 .156 r
F
.42884 .37909 m .42719 .37734 L .43001 .37664 L F
.41713 .37728 m .41827 .37511 L .41993 .37679 L 0 .049 .151 r
F
.41713 .37728 m .41546 .37561 L .41827 .37511 L F
.3484 .37123 m .34944 .36865 L .35117 .37041 L 0 .034 .135 r
F
.3484 .37123 m .34667 .36948 L .34944 .36865 L F
.61137 .38135 m .61282 .37888 L .61428 .38028 L 0 .059 .162 r
F
.61137 .38135 m .60991 .38001 L .61282 .37888 L F
.5736 .3909 m .57499 .38853 L .57648 .38938 L 0 .09 .187 r
F
.5736 .3909 m .5721 .3901 L .57499 .38853 L F
.79653 .36866 m .79825 .3659 L .79954 .36768 L 0 .028 .127 r
F
.79653 .36866 m .79524 .36691 L .79825 .3659 L F
.68273 .37251 m .68429 .36981 L .68569 .37152 L 0 .036 .138 r
F
.68273 .37251 m .68134 .37084 L .68429 .36981 L F
.86658 .36726 m .8684 .3645 L .86963 .36629 L 0 .025 .124 r
F
.86658 .36726 m .86536 .36548 L .8684 .3645 L F
.67544 .37296 m .67699 .37032 L .67839 .3719 L 0 .038 .139 r
F
.67544 .37296 m .67405 .37142 L .67699 .37032 L F
.47283 .38915 m .47406 .38712 L .47566 .38907 L 0 .085 .183 r
F
.47283 .38915 m .47123 .38718 L .47406 .38712 L F
.2885 .36974 m .28948 .36684 L .29125 .36875 L 0 .03 .13 r
F
.2885 .36974 m .28673 .36784 L .28948 .36684 L F
.70461 .37136 m .7062 .36874 L .70757 .37036 L 0 .034 .135 r
F
.70461 .37136 m .70324 .36977 L .7062 .36874 L F
.66086 .37384 m .6624 .37141 L .66381 .37292 L 0 .04 .142 r
F
.66086 .37384 m .65945 .37233 L .6624 .37141 L F
.44055 .38114 m .44173 .37883 L .44336 .38066 L 0 .059 .162 r
F
.44055 .38114 m .43892 .37928 L .44173 .37883 L F
.71191 .37102 m .71351 .36832 L .71487 .37001 L 0 .033 .134 r
F
.71191 .37102 m .71054 .36936 L .71351 .36832 L F
.66816 .37345 m .6697 .37094 L .6711 .37244 L 0 .039 .141 r
F
.66816 .37345 m .66675 .37195 L .6697 .37094 L F
.19501 .36761 m .19584 .36481 L .19771 .36661 L 0 .026 .125 r
F
.19501 .36761 m .19314 .36579 L .19584 .36481 L F
.7192 .37065 m .7208 .36781 L .72217 .36957 L 0 .032 .133 r
F
.7192 .37065 m .71784 .36891 L .7208 .36781 L F
.50223 .39999 m .50348 .40332 L .50507 .40232 L 0 .141 .223 r
F
.50223 .39999 m .50064 .40017 L .50348 .40332 L F
.7265 .37027 m .7281 .3674 L .72947 .36922 L 0 .031 .132 r
F
.7265 .37027 m .72513 .36848 L .7281 .3674 L F
.26219 .36885 m .26312 .36607 L .26492 .36792 L 0 .028 .128 r
F
.26219 .36885 m .26039 .36699 L .26312 .36607 L F
.73379 .36989 m .73542 .36724 L .73677 .36894 L 0 .031 .131 r
F
.73379 .36989 m .73244 .36818 L .73542 .36724 L F
.32208 .3705 m .3231 .3677 L .32484 .36966 L 0 .032 .133 r
F
.32208 .3705 m .32034 .36857 L .3231 .3677 L F
.74838 .36912 m .75003 .36637 L .75135 .36802 L 0 .029 .129 r
F
.74838 .36912 m .74705 .36748 L .75003 .36637 L F
.80385 .36854 m .80559 .3659 L .80687 .36767 L 0 .028 .128 r
F
.80385 .36854 m .80256 .36678 L .80559 .3659 L F
.23588 .36794 m .23677 .36519 L .2386 .36698 L 0 .027 .126 r
F
.23588 .36794 m .23405 .36616 L .23677 .36519 L F
.69004 .37239 m .69161 .36977 L .693 .37155 L 0 .037 .138 r
F
.69004 .37239 m .68865 .37065 L .69161 .36977 L F
.65358 .37443 m .65508 .3716 L .65651 .37325 L 0 .041 .143 r
F
.65358 .37443 m .65215 .37279 L .65508 .3716 L F
.20229 .36736 m .20314 .36449 L .205 .36632 L 0 .025 .124 r
F
.20229 .36736 m .20042 .36555 L .20314 .36449 L F
.87391 .36716 m .87575 .36444 L .87697 .36625 L F
.87391 .36716 m .87269 .36536 L .87575 .36444 L F
.74109 .36963 m .74273 .36695 L .74407 .36858 L 0 .03 .131 r
F
.74109 .36963 m .73975 .36798 L .74273 .36695 L F
.4684 .38724 m .46962 .38521 L .47123 .38718 L 0 .079 .179 r
F
.4684 .38724 m .46679 .38525 L .46962 .38521 L F
.75568 .36883 m .75735 .3662 L .75868 .36796 L 0 .029 .129 r
F
.75568 .36883 m .75435 .3671 L .75735 .3662 L F
.59393 .38523 m .59536 .38289 L .59683 .38403 L 0 .072 .173 r
F
.59393 .38523 m .59245 .38411 L .59536 .38289 L F
.69734 .37209 m .69891 .36934 L .70029 .37093 L 0 .036 .137 r
F
.69734 .37209 m .69596 .37051 L .69891 .36934 L F
.29577 .36967 m .29674 .36693 L .29851 .36884 L 0 .03 .131 r
F
.29577 .36967 m .294 .36776 L .29674 .36693 L F
.26946 .36869 m .2704 .36599 L .2722 .36775 L 0 .029 .128 r
F
.26946 .36869 m .26766 .36696 L .2704 .36599 L F
.56344 .39442 m .56483 .39277 L .56633 .39321 L 0 .105 .199 r
F
.56344 .39442 m .56194 .39418 L .56483 .39277 L F
.39368 .3742 m .39479 .37175 L .39646 .37363 L 0 .041 .144 r
F
.39368 .3742 m .392 .37235 L .39479 .37175 L F
.24316 .36776 m .24406 .36497 L .24588 .36677 L 0 .027 .126 r
F
.24316 .36776 m .24133 .36597 L .24406 .36497 L F
.88122 .36696 m .88307 .36419 L .88427 .36592 L 0 .025 .124 r
F
.88122 .36696 m .88002 .36523 L .88307 .36419 L F
.35566 .37141 m .35673 .36856 L .35844 .37044 L 0 .034 .135 r
F
.35566 .37141 m .35394 .36955 L .35673 .36856 L F
.49781 .39813 m .49904 .40059 L .50064 .40017 L 0 .131 .217 r
F
.49781 .39813 m .49621 .39783 L .49904 .40059 L F
.81846 .36799 m .82022 .3653 L .82148 .36699 L 0 .027 .127 r
F
.81846 .36799 m .81719 .36631 L .82022 .3653 L F
.37466 .37287 m .37575 .37036 L .37745 .37203 L 0 .038 .14 r
F
.37466 .37287 m .37296 .3712 L .37575 .37036 L F
.20956 .36721 m .2104 .36446 L .21225 .36631 L 0 .026 .124 r
F
.20956 .36721 m .2077 .36536 L .2104 .36446 L F
.54025 .40323 m .54161 .40472 L .54313 .40267 L 0 .151 .229 r
F
.54025 .40323 m .53872 .40502 L .54161 .40472 L F
.81117 .36844 m .81291 .3657 L .81418 .36738 L 0 .028 .128 r
F
.81117 .36844 m .8099 .36676 L .81291 .3657 L F
.88852 .36663 m .8904 .36401 L .89159 .36572 L 0 .025 .123 r
F
.88852 .36663 m .88733 .36491 L .8904 .36401 L F
.40539 .37616 m .40652 .37367 L .40819 .37537 L 0 .046 .149 r
F
.40539 .37616 m .40371 .37445 L .40652 .37367 L F
.6463 .37516 m .64779 .37233 L .64923 .374 L 0 .043 .146 r
F
.6463 .37516 m .64487 .37351 L .64779 .37233 L F
.63901 .37563 m .6405 .37293 L .64194 .37457 L 0 .045 .147 r
F
.63901 .37563 m .63757 .374 L .6405 .37293 L F
.16865 .36714 m .16945 .36428 L .17134 .36612 L 0 .025 .124 r
F
.16865 .36714 m .16676 .3653 L .16945 .36428 L F
.27673 .3686 m .27767 .36597 L .27946 .36777 L 0 .029 .129 r
F
.27673 .3686 m .27494 .36683 L .27767 .36597 L F
.82577 .3678 m .82754 .36511 L .8288 .36688 L 0 .027 .126 r
F
.82577 .3678 m .82451 .36605 L .82754 .36511 L F
.763 .36881 m .76467 .36605 L .76599 .36782 L 0 .029 .129 r
F
.763 .36881 m .76167 .36705 L .76467 .36605 L F
.32934 .37066 m .33037 .36776 L .33211 .36971 L 0 .033 .134 r
F
.32934 .37066 m .3276 .36871 L .33037 .36776 L F
.45225 .38361 m .45344 .38177 L .45507 .38335 L 0 .069 .17 r
F
.45225 .38361 m .45062 .38199 L .45344 .38177 L F
.55328 .39781 m .55468 .39854 L .55617 .39675 L 0 .127 .214 r
F
.55328 .39781 m .55179 .39985 L .55468 .39854 L F
.6041 .38266 m .60554 .37998 L .607 .38132 L 0 .064 .166 r
F
.6041 .38266 m .60263 .38143 L .60554 .37998 L F
.7703 .36853 m .77199 .36587 L .7733 .36758 L 0 .029 .129 r
F
.7703 .36853 m .76899 .36682 L .77199 .36587 L F
.36293 .37139 m .364 .36867 L .36571 .37062 L 0 .035 .136 r
F
.36293 .37139 m .36122 .36947 L .364 .36867 L F
.25041 .36775 m .25132 .36502 L .25313 .36689 L 0 .027 .126 r
F
.25041 .36775 m .2486 .3659 L .25132 .36502 L F
.89585 .36653 m .89773 .36384 L .89892 .36556 L 0 .025 .123 r
F
.89585 .36653 m .89466 .36482 L .89773 .36384 L F
.62156 .37928 m .62302 .37655 L .62447 .37789 L 0 .055 .157 r
F
.62156 .37928 m .62011 .37795 L .62302 .37655 L F
.51837 .40478 m .51967 .40889 L .52123 .40657 L 0 .167 .238 r
F
.51837 .40478 m .5168 .40627 L .51967 .40889 L F
.46397 .38557 m .46518 .38348 L .46679 .38525 L 0 .075 .175 r
F
.46397 .38557 m .46235 .38381 L .46518 .38348 L F
.17592 .36696 m .17673 .36411 L .17861 .36597 L 0 .025 .124 r
F
.17592 .36696 m .17404 .36511 L .17673 .36411 L F
.30302 .3698 m .30401 .36711 L .30577 .3689 L 0 .032 .132 r
F
.30302 .3698 m .30125 .36802 L .30401 .36711 L F
.38194 .37284 m .38303 .37036 L .38473 .37203 L 0 .039 .141 r
F
.38194 .37284 m .38024 .37119 L .38303 .37036 L F
.43611 .37973 m .43728 .3774 L .43892 .37928 L 0 .057 .159 r
F
.43611 .37973 m .43447 .37785 L .43728 .3774 L F
.83309 .36762 m .83485 .36477 L .83611 .36657 L 0 .027 .126 r
F
.83309 .36762 m .83183 .36583 L .83485 .36477 L F
.58665 .38626 m .58807 .38422 L .58955 .38522 L 0 .077 .177 r
F
.58665 .38626 m .58516 .38528 L .58807 .38422 L F
.42438 .37801 m .42554 .37559 L .42719 .37734 L 0 .052 .155 r
F
.42438 .37801 m .42273 .37631 L .42554 .37559 L F
.2168 .36729 m .21767 .3644 L .21952 .36627 L 0 .026 .125 r
F
.2168 .36729 m .21496 .36542 L .21767 .3644 L F
.77761 .36831 m .77932 .36573 L .78062 .36739 L 0 .029 .128 r
F
.77761 .36831 m .77631 .36666 L .77932 .36573 L F
.90317 .36631 m .90504 .36353 L .90623 .3653 L 0 .024 .123 r
F
.90317 .36631 m .90198 .36454 L .90504 .36353 L F
.33661 .37057 m .33766 .36773 L .33939 .36958 L 0 .033 .134 r
F
.33661 .37057 m .33488 .36873 L .33766 .36773 L F
.57648 .38938 m .57788 .38694 L .57937 .38785 L 0 .087 .185 r
F
.57648 .38938 m .57499 .38853 L .57788 .38694 L F
.84039 .36735 m .84218 .36456 L .84343 .36638 L 0 .026 .126 r
F
.84039 .36735 m .83914 .36555 L .84218 .36456 L F
.41266 .37626 m .4138 .37394 L .41546 .37561 L 0 .048 .15 r
F
.41266 .37626 m .411 .37458 L .4138 .37394 L F
.3103 .3696 m .31131 .36678 L .31307 .36856 L 0 .031 .132 r
F
.3103 .3696 m .30854 .36784 L .31131 .36678 L F
.63173 .37653 m .63321 .37379 L .63465 .37523 L 0 .048 .15 r
F
.63173 .37653 m .63029 .37514 L .63321 .37379 L F
.18318 .36685 m .184 .364 L .18588 .36587 L 0 .026 .124 r
F
.18318 .36685 m .18131 .36499 L .184 .364 L F
.3439 .37033 m .34494 .36773 L .34667 .36948 L 0 .033 .134 r
F
.3439 .37033 m .34216 .36859 L .34494 .36773 L F
.78492 .36811 m .78664 .36555 L .78793 .36718 L 0 .029 .128 r
F
.78492 .36811 m .78363 .36647 L .78664 .36555 L F
.22407 .36711 m .22495 .36425 L .22679 .36611 L 0 .026 .125 r
F
.22407 .36711 m .22224 .36524 L .22495 .36425 L F
.84771 .36714 m .84951 .36443 L .85074 .36615 L F
.84771 .36714 m .84647 .36542 L .84951 .36443 L F
.28398 .36877 m .28494 .36599 L .28673 .36784 L 0 .03 .13 r
F
.28398 .36877 m .2822 .36693 L .28494 .36599 L F
.53296 .40439 m .53431 .40895 L .53584 .40474 L 0 .167 .239 r
F
.53296 .40439 m .53142 .4078 L .53431 .40895 L F
.31758 .36943 m .31859 .36671 L .32034 .36857 L 0 .031 .132 r
F
.31758 .36943 m .31583 .36762 L .31859 .36671 L F
.85501 .36685 m .85682 .36413 L .85805 .36583 L 0 .026 .125 r
F
.85501 .36685 m .85378 .36514 L .85682 .36413 L F
.25766 .3679 m .25858 .36512 L .26039 .36699 L 0 .028 .128 r
F
.25766 .3679 m .25586 .36602 L .25858 .36512 L F
.79223 .36792 m .79395 .36516 L .79524 .36691 L F
.79223 .36792 m .79094 .3662 L .79395 .36516 L F
.61428 .38028 m .61574 .37775 L .6172 .3792 L 0 .059 .161 r
F
.61428 .38028 m .61282 .37888 L .61574 .37775 L F
.86232 .36652 m .86413 .36373 L .86536 .36548 L 0 .025 .124 r
F
.86232 .36652 m .86109 .36478 L .86413 .36373 L F
.19044 .36676 m .19127 .36396 L .19314 .36579 L 0 .026 .125 r
F
.19044 .36676 m .18857 .36491 L .19127 .36396 L F
.38921 .37304 m .39031 .37054 L .392 .37235 L 0 .04 .142 r
F
.38921 .37304 m .38752 .37129 L .39031 .37054 L F
.44781 .38218 m .44899 .38026 L .45062 .38199 L 0 .066 .167 r
F
.44781 .38218 m .44618 .38041 L .44899 .38026 L F
.67839 .3719 m .67994 .3692 L .68134 .37084 L 0 .037 .139 r
F
.67839 .3719 m .67699 .37032 L .67994 .3692 L F
.23134 .36705 m .23221 .36434 L .23405 .36616 L 0 .027 .126 r
F
.23134 .36705 m .2295 .36523 L .23221 .36434 L F
.49337 .39701 m .49461 .39754 L .49621 .39783 L 0 .124 .212 r
F
.49337 .39701 m .49178 .39635 L .49461 .39754 L F
.79954 .36768 m .80127 .36498 L .80256 .36678 L 0 .028 .127 r
F
.79954 .36768 m .79825 .3659 L .80127 .36498 L F
.68569 .37152 m .68725 .36889 L .68865 .37065 L 0 .036 .138 r
F
.68569 .37152 m .68429 .36981 L .68725 .36889 L F
.86963 .36629 m .87146 .36356 L .87269 .36536 L 0 .025 .124 r
F
.86963 .36629 m .8684 .3645 L .87146 .36356 L F
.40092 .375 m .40205 .3725 L .40371 .37445 L 0 .045 .147 r
F
.40092 .375 m .39925 .37309 L .40205 .3725 L F
.70757 .37036 m .70917 .36772 L .71054 .36936 L 0 .034 .135 r
F
.70757 .37036 m .7062 .36874 L .70917 .36772 L F
.29125 .36875 m .29223 .36584 L .294 .36776 L 0 .03 .13 r
F
.29125 .36875 m .28948 .36684 L .29223 .36584 L F
.72217 .36957 m .72377 .3667 L .72513 .36848 L 0 .032 .132 r
F
.72217 .36957 m .7208 .36781 L .72377 .3667 L F
.71487 .37001 m .71647 .36722 L .71784 .36891 L 0 .033 .134 r
F
.71487 .37001 m .71351 .36832 L .71647 .36722 L F
.6711 .37244 m .67265 .36993 L .67405 .37142 L 0 .039 .141 r
F
.6711 .37244 m .6697 .37094 L .67265 .36993 L F
.35117 .37041 m .35222 .36777 L .35394 .36955 L 0 .034 .135 r
F
.35117 .37041 m .34944 .36865 L .35222 .36777 L F
.65651 .37325 m .65803 .37066 L .65945 .37233 L 0 .041 .143 r
F
.65651 .37325 m .65508 .3716 L .65803 .37066 L F
.72947 .36922 m .73108 .36633 L .73244 .36818 L 0 .031 .131 r
F
.72947 .36922 m .7281 .3674 L .73108 .36633 L F
.37018 .37185 m .37126 .36928 L .37296 .3712 L 0 .037 .139 r
F
.37018 .37185 m .36848 .36995 L .37126 .36928 L F
.75135 .36802 m .75302 .36544 L .75435 .3671 L 0 .029 .129 r
F
.75135 .36802 m .75003 .36637 L .75302 .36544 L F
.19771 .36661 m .19856 .36374 L .20042 .36555 L 0 .026 .125 r
F
.19771 .36661 m .19584 .36481 L .19856 .36374 L F
.59683 .38403 m .59826 .38167 L .59973 .38282 L 0 .071 .172 r
F
.59683 .38403 m .59536 .38289 L .59826 .38167 L F
.66381 .37292 m .66534 .37045 L .66675 .37195 L 0 .04 .142 r
F
.66381 .37292 m .6624 .37141 L .66534 .37045 L F
.70029 .37093 m .70187 .36817 L .70324 .36977 L 0 .035 .136 r
F
.70029 .37093 m .69891 .36934 L .70187 .36817 L F
.56633 .39321 m .56772 .39109 L .56922 .39166 L 0 .103 .197 r
F
.56633 .39321 m .56483 .39277 L .56772 .39109 L F
.43165 .37844 m .43282 .376 L .43447 .37785 L 0 .055 .157 r
F
.43165 .37844 m .43001 .37664 L .43282 .376 L F
.26492 .36792 m .26586 .36512 L .26766 .36696 L 0 .029 .128 r
F
.26492 .36792 m .26312 .36607 L .26586 .36512 L F
.73677 .36894 m .73841 .3663 L .73975 .36798 L 0 .031 .131 r
F
.73677 .36894 m .73542 .36724 L .73841 .3663 L F
.205 .36632 m .20584 .36351 L .2077 .36536 L 0 .025 .124 r
F
.205 .36632 m .20314 .36449 L .20584 .36351 L F
.45952 .38437 m .46073 .38226 L .46235 .38381 L 0 .073 .173 r
F
.45952 .38437 m .4579 .3828 L .46073 .38226 L F
.74407 .36858 m .74571 .36585 L .74705 .36748 L 0 .03 .13 r
F
.74407 .36858 m .74273 .36695 L .74571 .36585 L F
.2386 .36698 m .2395 .36418 L .24133 .36597 L 0 .027 .126 r
F
.2386 .36698 m .23677 .36519 L .2395 .36418 L F
.52566 .40545 m .52699 .41085 L .52854 .40665 L 0 .177 .244 r
F
.52566 .40545 m .52411 .40871 L .52699 .41085 L F
.32484 .36966 m .32587 .36675 L .3276 .36871 L 0 .032 .133 r
F
.32484 .36966 m .3231 .3677 L .32587 .36675 L F
.48735 .39385 m .48857 .39453 L .49018 .39548 L 0 .12 .209 r
F
.49018 .39548 m .48857 .39453 L .4888 .3947 L 0 .138 .221 r
F
.48894 .39517 m .49018 .39548 L .49155 .39625 L 0 .116 .207 r
F
.49018 .39548 m .4888 .3947 L .4914 .39665 L 0 .138 .221 r
F
.49155 .39625 m .49018 .39548 L .49178 .39635 L 0 .116 .207 r
F
.48894 .39517 m .48735 .39385 L .49018 .39548 L F
.87697 .36625 m .8788 .36341 L .88002 .36523 L 0 .025 .124 r
F
.87697 .36625 m .87575 .36444 L .8788 .36341 L F
.80687 .36767 m .80862 .36499 L .8099 .36676 L 0 .028 .128 r
F
.80687 .36767 m .80559 .3659 L .80862 .36499 L F
.41993 .37679 m .42107 .37461 L .42273 .37631 L 0 .051 .153 r
F
.41993 .37679 m .41827 .37511 L .42107 .37461 L F
.693 .37155 m .69457 .36871 L .69596 .37051 L 0 .037 .138 r
F
.693 .37155 m .69161 .36977 L .69457 .36871 L F
.64923 .374 m .65072 .37111 L .65215 .37279 L 0 .042 .145 r
F
.64923 .374 m .64779 .37233 L .65072 .37111 L F
.88427 .36592 m .88612 .36318 L .88733 .36491 L 0 .025 .123 r
F
.88427 .36592 m .88307 .36419 L .88612 .36318 L F
.2722 .36775 m .27314 .36504 L .27494 .36683 L 0 .029 .128 r
F
.2722 .36775 m .2704 .36599 L .27314 .36504 L F
.75868 .36796 m .76035 .36527 L .76167 .36705 L 0 .029 .129 r
F
.75868 .36796 m .75735 .3662 L .76035 .36527 L F
.607 .38132 m .60844 .37857 L .60991 .38001 L 0 .062 .164 r
F
.607 .38132 m .60554 .37998 L .60844 .37857 L F
.62447 .37789 m .62593 .37515 L .62738 .37649 L 0 .053 .155 r
F
.62447 .37789 m .62302 .37655 L .62593 .37515 L F
.81418 .36738 m .81593 .36463 L .81719 .36631 L 0 .028 .127 r
F
.81418 .36738 m .81291 .3657 L .81593 .36463 L F
.24588 .36677 m .24678 .36407 L .2486 .3659 L 0 .027 .126 r
F
.24588 .36677 m .24406 .36497 L .24678 .36407 L F
.82148 .36699 m .82325 .36435 L .82451 .36605 L 0 .027 .127 r
F
.82148 .36699 m .82022 .3653 L .82325 .36435 L F
.35844 .37044 m .35952 .36756 L .36122 .36947 L 0 .034 .135 r
F
.35844 .37044 m .35673 .36856 L .35952 .36756 L F
.57937 .38785 m .58078 .38537 L .58226 .38633 L 0 .083 .182 r
F
.57937 .38785 m .57788 .38694 L .58078 .38537 L F
.29851 .36884 m .29949 .36611 L .30125 .36802 L 0 .031 .131 r
F
.29851 .36884 m .29674 .36693 L .29949 .36611 L F
.51394 .40391 m .51522 .41018 L .5168 .40627 L 0 .173 .242 r
F
.51394 .40391 m .51236 .40661 L .51522 .41018 L F
.64194 .37457 m .64343 .37187 L .64487 .37351 L 0 .044 .147 r
F
.64194 .37457 m .6405 .37293 L .64343 .37187 L F
.44336 .38066 m .44454 .37862 L .44618 .38041 L 0 .062 .164 r
F
.44336 .38066 m .44173 .37883 L .44454 .37862 L F
.21225 .36631 m .21311 .36356 L .21496 .36542 L 0 .026 .125 r
F
.21225 .36631 m .2104 .36446 L .21311 .36356 L F
.17134 .36612 m .17215 .36325 L .17404 .36511 L 0 .025 .124 r
F
.17134 .36612 m .16945 .36428 L .17215 .36325 L F
.89159 .36572 m .89347 .36311 L .89466 .36482 L 0 .025 .123 r
F
.89159 .36572 m .8904 .36401 L .89347 .36311 L F
.37745 .37203 m .37854 .36953 L .38024 .37119 L 0 .039 .141 r
F
.37745 .37203 m .37575 .37036 L .37854 .36953 L F
.48451 .39329 m .48575 .39241 L .48735 .39385 L 0 .107 .2 r
F
.48451 .39329 m .48292 .39166 L .48575 .39241 L F
.55617 .39675 m .55756 .3968 L .55905 .39548 L 0 .124 .212 r
F
.55617 .39675 m .55468 .39854 L .55756 .3968 L F
.76599 .36782 m .76767 .36505 L .76899 .36682 L 0 .029 .129 r
F
.76599 .36782 m .76467 .36605 L .76767 .36505 L F
.40819 .37537 m .40932 .3729 L .411 .37458 L 0 .047 .15 r
F
.40819 .37537 m .40652 .37367 L .40932 .3729 L F
.33211 .36971 m .33315 .36678 L .33488 .36873 L 0 .033 .134 r
F
.33211 .36971 m .33037 .36776 L .33315 .36678 L F
.8288 .36688 m .83057 .36405 L .83183 .36583 L 0 .027 .126 r
F
.8288 .36688 m .82754 .36511 L .83057 .36405 L F
.63465 .37523 m .63613 .37253 L .63757 .374 L 0 .046 .149 r
F
.63465 .37523 m .63321 .37379 L .63613 .37253 L F
.39646 .37363 m .39758 .37117 L .39925 .37309 L 0 .043 .145 r
F
.39646 .37363 m .39479 .37175 L .39758 .37117 L F
.27946 .36777 m .28041 .36512 L .2822 .36693 L 0 .029 .129 r
F
.27946 .36777 m .27767 .36597 L .28041 .36512 L F
.7733 .36758 m .775 .36494 L .77631 .36666 L F
.7733 .36758 m .77199 .36587 L .775 .36494 L F
.89892 .36556 m .90079 .36283 L .90198 .36454 L 0 .025 .123 r
F
.89892 .36556 m .89773 .36384 L .90079 .36283 L F
.48008 .39127 m .48132 .39 L .48292 .39166 L 0 .099 .194 r
F
.48008 .39127 m .47849 .38949 L .48132 .39 L F
.83611 .36657 m .83788 .36373 L .83914 .36555 L 0 .027 .126 r
F
.83611 .36657 m .83485 .36477 L .83788 .36373 L F
.17861 .36597 m .17943 .36312 L .18131 .36499 L 0 .025 .124 r
F
.17861 .36597 m .17673 .36411 L .17943 .36312 L F
.58955 .38522 m .59098 .3831 L .59245 .38411 L 0 .076 .177 r
F
.58955 .38522 m .58807 .38422 L .59098 .3831 L F
.47566 .38907 m .47688 .38761 L .47849 .38949 L 0 .091 .188 r
F
.47566 .38907 m .47406 .38712 L .47688 .38761 L F
.54313 .40267 m .5445 .40442 L .54602 .40211 L 0 .154 .231 r
F
.54313 .40267 m .54161 .40472 L .5445 .40442 L F
.30577 .3689 m .30677 .36605 L .30854 .36784 L 0 .031 .132 r
F
.30577 .3689 m .30401 .36711 L .30677 .36605 L F
.21952 .36627 m .22039 .36337 L .22224 .36524 L 0 .026 .125 r
F
.21952 .36627 m .21767 .3644 L .22039 .36337 L F
.25313 .36689 m .25405 .36414 L .25586 .36602 L 0 .027 .127 r
F
.25313 .36689 m .25132 .36502 L .25405 .36414 L F
.31307 .36856 m .31407 .3658 L .31583 .36762 L 0 .031 .131 r
F
.31307 .36856 m .31131 .36678 L .31407 .3658 L F
.33939 .36958 m .34043 .36673 L .34216 .36859 L 0 .033 .134 r
F
.33939 .36958 m .33766 .36773 L .34043 .36673 L F
.38473 .37203 m .38583 .36957 L .38752 .37129 L 0 .039 .141 r
F
.38473 .37203 m .38303 .37036 L .38583 .36957 L F
.36571 .37062 m .36678 .36798 L .36848 .36995 L 0 .036 .137 r
F
.36571 .37062 m .364 .36867 L .36678 .36798 L F
.78062 .36739 m .78233 .36482 L .78363 .36647 L 0 .029 .129 r
F
.78062 .36739 m .77932 .36573 L .78233 .36482 L F
.84343 .36638 m .84521 .36357 L .84647 .36542 L 0 .026 .126 r
F
.84343 .36638 m .84218 .36456 L .84521 .36357 L F
.18588 .36587 m .1867 .36306 L .18857 .36491 L 0 .026 .124 r
F
.18588 .36587 m .184 .364 L .1867 .36306 L F
.22679 .36611 m .22766 .36338 L .2295 .36523 L 0 .026 .125 r
F
.22679 .36611 m .22495 .36425 L .22766 .36338 L F
.47123 .38718 m .47245 .38517 L .47406 .38712 L 0 .084 .183 r
F
.47123 .38718 m .46962 .38521 L .47245 .38517 L F
.85074 .36615 m .85255 .36343 L .85378 .36514 L 0 .026 .125 r
F
.85074 .36615 m .84951 .36443 L .85255 .36343 L F
.56922 .39166 m .57061 .3894 L .5721 .3901 L 0 .099 .194 r
F
.56922 .39166 m .56772 .39109 L .57061 .3894 L F
.78793 .36718 m .78965 .36456 L .79094 .3662 L 0 .029 .128 r
F
.78793 .36718 m .78664 .36555 L .78965 .36456 L F
.42719 .37734 m .42836 .37485 L .43001 .37664 L 0 .053 .156 r
F
.42719 .37734 m .42554 .37559 L .42836 .37485 L F
.28673 .36784 m .2877 .36497 L .28948 .36684 L 0 .03 .13 r
F
.28673 .36784 m .28494 .36599 L .2877 .36497 L F
.85805 .36583 m .85986 .36307 L .86109 .36478 L 0 .026 .125 r
F
.85805 .36583 m .85682 .36413 L .85986 .36307 L F
.34667 .36948 m .34771 .36688 L .34944 .36865 L 0 .034 .135 r
F
.34667 .36948 m .34494 .36773 L .34771 .36688 L F
.6172 .3792 m .61865 .37646 L .62011 .37795 L 0 .058 .16 r
F
.6172 .3792 m .61574 .37775 L .61865 .37646 L F
.86536 .36548 m .86718 .36273 L .8684 .3645 L 0 .025 .124 r
F
.86536 .36548 m .86413 .36373 L .86718 .36273 L F
.41546 .37561 m .4166 .37343 L .41827 .37511 L 0 .049 .152 r
F
.41546 .37561 m .4138 .37394 L .4166 .37343 L F
.79524 .36691 m .79696 .36412 L .79825 .3659 L 0 .028 .128 r
F
.79524 .36691 m .79395 .36516 L .79696 .36412 L F
.43892 .37928 m .4401 .37695 L .44173 .37883 L 0 .059 .161 r
F
.43892 .37928 m .43728 .3774 L .4401 .37695 L F
.32034 .36857 m .32135 .36579 L .3231 .3677 L 0 .032 .132 r
F
.32034 .36857 m .31859 .36671 L .32135 .36579 L F
.45507 .38335 m .45627 .38124 L .4579 .3828 L 0 .072 .173 r
F
.45507 .38335 m .45344 .38177 L .45627 .38124 L F
.26039 .36699 m .26132 .36422 L .26312 .36607 L 0 .028 .128 r
F
.26039 .36699 m .25858 .36512 L .26132 .36422 L F
.68134 .37084 m .68289 .36812 L .68429 .36981 L 0 .037 .138 r
F
.68134 .37084 m .67994 .3692 L .68289 .36812 L F
.19314 .36579 m .19397 .36299 L .19584 .36481 L 0 .026 .125 r
F
.19314 .36579 m .19127 .36396 L .19397 .36299 L F
.46679 .38525 m .46801 .38344 L .46962 .38521 L 0 .078 .178 r
F
.46679 .38525 m .46518 .38348 L .46801 .38344 L F
.59973 .38282 m .60116 .38019 L .60263 .38143 L 0 .069 .17 r
F
.59973 .38282 m .59826 .38167 L .60116 .38019 L F
.72513 .36848 m .72674 .36558 L .7281 .3674 L 0 .031 .132 r
F
.72513 .36848 m .72377 .3667 L .72674 .36558 L F
.71784 .36891 m .71944 .36611 L .7208 .36781 L 0 .032 .133 r
F
.71784 .36891 m .71647 .36722 L .71944 .36611 L F
.58226 .38633 m .58368 .38431 L .58516 .38528 L 0 .082 .181 r
F
.58226 .38633 m .58078 .38537 L .58368 .38431 L F
.71054 .36936 m .71214 .36666 L .71351 .36832 L 0 .034 .135 r
F
.71054 .36936 m .70917 .36772 L .71214 .36666 L F
.70324 .36977 m .70483 .36712 L .7062 .36874 L 0 .035 .136 r
F
.70324 .36977 m .70187 .36817 L .70483 .36712 L F
.294 .36776 m .29497 .36502 L .29674 .36693 L 0 .03 .13 r
F
.294 .36776 m .29223 .36584 L .29497 .36502 L F
.67405 .37142 m .67559 .3688 L .67699 .37032 L 0 .038 .14 r
F
.67405 .37142 m .67265 .36993 L .67559 .3688 L F
.73244 .36818 m .73406 .36539 L .73542 .36724 L 0 .031 .131 r
F
.73244 .36818 m .73108 .36633 L .73406 .36539 L F
.20042 .36555 m .20127 .36268 L .20314 .36449 L 0 .025 .124 r
F
.20042 .36555 m .19856 .36374 L .20127 .36268 L F
.23405 .36616 m .23494 .36338 L .23677 .36519 L 0 .027 .126 r
F
.23405 .36616 m .23221 .36434 L .23494 .36338 L F
.62738 .37649 m .62885 .37375 L .63029 .37514 L 0 .051 .154 r
F
.62738 .37649 m .62593 .37515 L .62885 .37375 L F
.80256 .36678 m .8043 .36408 L .80559 .3659 L 0 .028 .128 r
F
.80256 .36678 m .80127 .36498 L .8043 .36408 L F
.87269 .36536 m .87452 .36263 L .87575 .36444 L 0 .025 .124 r
F
.87269 .36536 m .87146 .36356 L .87452 .36263 L F
.68865 .37065 m .69021 .36798 L .69161 .36977 L 0 .037 .138 r
F
.68865 .37065 m .68725 .36889 L .69021 .36798 L F
.60991 .38001 m .61136 .37735 L .61282 .37888 L 0 .061 .163 r
F
.60991 .38001 m .60844 .37857 L .61136 .37735 L F
.65945 .37233 m .66097 .36971 L .6624 .37141 L 0 .041 .143 r
F
.65945 .37233 m .65803 .37066 L .66097 .36971 L F
.74705 .36748 m .7487 .36474 L .75003 .36637 L 0 .03 .13 r
F
.74705 .36748 m .74571 .36585 L .7487 .36474 L F
.392 .37235 m .39311 .3699 L .39479 .37175 L 0 .041 .143 r
F
.392 .37235 m .39031 .37054 L .39311 .3699 L F
.66675 .37195 m .66829 .36945 L .6697 .37094 L 0 .04 .142 r
F
.66675 .37195 m .66534 .37045 L .66829 .36945 L F
.75435 .3671 m .75602 .36452 L .75735 .3662 L 0 .029 .129 r
F
.75435 .3671 m .75302 .36544 L .75602 .36452 L F
.65215 .37279 m .65366 .3699 L .65508 .3716 L 0 .041 .144 r
F
.65215 .37279 m .65072 .37111 L .65366 .3699 L F
.35394 .36955 m .35501 .36674 L .35673 .36856 L 0 .034 .135 r
F
.35394 .36955 m .35222 .36777 L .35501 .36674 L F
.26766 .36696 m .2686 .36415 L .2704 .36599 L 0 .029 .128 r
F
.26766 .36696 m .26586 .36512 L .2686 .36415 L F
.73975 .36798 m .74139 .36527 L .74273 .36695 L 0 .031 .131 r
F
.73975 .36798 m .73841 .3663 L .74139 .36527 L F
.2077 .36536 m .20855 .3626 L .2104 .36446 L 0 .025 .124 r
F
.2077 .36536 m .20584 .36351 L .20855 .3626 L F
.24133 .36597 m .24223 .36317 L .24406 .36497 L 0 .027 .126 r
F
.24133 .36597 m .2395 .36418 L .24223 .36317 L F
.88002 .36523 m .88185 .36237 L .88307 .36419 L 0 .025 .124 r
F
.88002 .36523 m .8788 .36341 L .88185 .36237 L F
.50951 .4031 m .51077 .40937 L .51236 .40661 L 0 .173 .242 r
F
.50951 .4031 m .50792 .40465 L .51077 .40937 L F
.69596 .37051 m .69752 .36753 L .69891 .36934 L 0 .036 .138 r
F
.69596 .37051 m .69457 .36871 L .69752 .36753 L F
.3276 .36871 m .32864 .3658 L .33037 .36776 L 0 .032 .133 r
F
.3276 .36871 m .32587 .36675 L .32864 .3658 L F
.81719 .36631 m .81895 .36361 L .82022 .3653 L 0 .028 .127 r
F
.81719 .36631 m .81593 .36463 L .81895 .36361 L F
.16676 .3653 m .16755 .36245 L .16945 .36428 L 0 .025 .124 r
F
.16676 .3653 m .16486 .36347 L .16755 .36245 L F
.55905 .39548 m .56045 .39501 L .56194 .39418 L 0 .121 .21 r
F
.55905 .39548 m .55756 .3968 L .56045 .39501 L F
.88733 .36491 m .8892 .36228 L .8904 .36401 L 0 .025 .123 r
F
.88733 .36491 m .88612 .36318 L .8892 .36228 L F
.37296 .3712 m .37405 .36845 L .37575 .37036 L 0 .038 .14 r
F
.37296 .3712 m .37126 .36928 L .37405 .36845 L F
.40371 .37445 m .40485 .37168 L .40652 .37367 L 0 .046 .149 r
F
.40371 .37445 m .40205 .3725 L .40485 .37168 L F
.8099 .36676 m .81163 .36391 L .81291 .3657 L 0 .028 .128 r
F
.8099 .36676 m .80862 .36499 L .81163 .36391 L F
.27494 .36683 m .27587 .36417 L .27767 .36597 L 0 .029 .129 r
F
.27494 .36683 m .27314 .36504 L .27587 .36417 L F
.64487 .37351 m .64636 .37068 L .64779 .37233 L 0 .044 .146 r
F
.64487 .37351 m .64343 .37187 L .64636 .37068 L F
.36122 .36947 m .3623 .36674 L .364 .36867 L 0 .034 .136 r
F
.36122 .36947 m .35952 .36756 L .3623 .36674 L F
.76167 .36705 m .76334 .36427 L .76467 .36605 L 0 .029 .129 r
F
.76167 .36705 m .76035 .36527 L .76334 .36427 L F
.82451 .36605 m .82628 .36339 L .82754 .36511 L 0 .027 .127 r
F
.82451 .36605 m .82325 .36435 L .82628 .36339 L F
.2486 .3659 m .2495 .36317 L .25132 .36502 L 0 .027 .126 r
F
.2486 .3659 m .24678 .36407 L .2495 .36317 L F
.63757 .374 m .63906 .37146 L .6405 .37293 L 0 .046 .148 r
F
.63757 .374 m .63613 .37253 L .63906 .37146 L F
.43447 .37785 m .43564 .37548 L .43728 .3774 L 0 .056 .159 r
F
.43447 .37785 m .43282 .376 L .43564 .37548 L F
.17404 .36511 m .17484 .36224 L .17673 .36411 L 0 .025 .124 r
F
.17404 .36511 m .17215 .36325 L .17484 .36224 L F
.46235 .38381 m .46356 .38193 L .46518 .38348 L 0 .075 .176 r
F
.46235 .38381 m .46073 .38226 L .46356 .38193 L F
.45062 .38199 m .45181 .38009 L .45344 .38177 L 0 .069 .171 r
F
.45062 .38199 m .44899 .38026 L .45181 .38009 L F
.30125 .36802 m .30224 .36521 L .30401 .36711 L 0 .031 .132 r
F
.30125 .36802 m .29949 .36611 L .30224 .36521 L F
.5721 .3901 m .5735 .38772 L .57499 .38853 L 0 .095 .191 r
F
.5721 .3901 m .57061 .3894 L .5735 .38772 L F
.76899 .36682 m .77067 .36408 L .77199 .36587 L 0 .029 .129 r
F
.76899 .36682 m .76767 .36505 L .77067 .36408 L F
.21496 .36542 m .21583 .36254 L .21767 .3644 L 0 .026 .125 r
F
.21496 .36542 m .21311 .36356 L .21583 .36254 L F
.83183 .36583 m .83359 .36299 L .83485 .36477 L 0 .027 .126 r
F
.83183 .36583 m .83057 .36405 L .83359 .36299 L F
.89466 .36482 m .89654 .36214 L .89773 .36384 L 0 .025 .124 r
F
.89466 .36482 m .89347 .36311 L .89654 .36214 L F
.59245 .38411 m .59388 .38189 L .59536 .38289 L 0 .075 .176 r
F
.59245 .38411 m .59098 .3831 L .59388 .38189 L F
.33488 .36873 m .33593 .36578 L .33766 .36773 L 0 .033 .134 r
F
.33488 .36873 m .33315 .36678 L .33593 .36578 L F
.38024 .37119 m .38133 .36869 L .38303 .37036 L 0 .039 .141 r
F
.38024 .37119 m .37854 .36953 L .38133 .36869 L F
.83914 .36555 m .84092 .36272 L .84218 .36456 L 0 .026 .125 r
F
.83914 .36555 m .83788 .36373 L .84092 .36272 L F
.90198 .36454 m .90386 .36181 L .90504 .36353 L 0 .025 .123 r
F
.90198 .36454 m .90079 .36283 L .90386 .36181 L F
.42273 .37631 m .42389 .37386 L .42554 .37559 L 0 .052 .155 r
F
.42273 .37631 m .42107 .37461 L .42389 .37386 L F
.18131 .36499 m .18212 .36212 L .184 .364 L 0 .025 .124 r
F
.18131 .36499 m .17943 .36312 L .18212 .36212 L F
.30854 .36784 m .30954 .36498 L .31131 .36678 L 0 .031 .132 r
F
.30854 .36784 m .30677 .36605 L .30954 .36498 L F
.77631 .36666 m .77801 .364 L .77932 .36573 L 0 .029 .129 r
F
.77631 .36666 m .775 .36494 L .77801 .364 L F
.22224 .36524 m .22311 .36239 L .22495 .36425 L 0 .026 .125 r
F
.22224 .36524 m .22039 .36337 L .22311 .36239 L F
.53584 .40474 m .5372 .40998 L .53872 .40502 L 0 .18 .246 r
F
.53584 .40474 m .53431 .40895 L .5372 .40998 L F
.411 .37458 m .41213 .37226 L .4138 .37394 L 0 .048 .151 r
F
.411 .37458 m .40932 .3729 L .41213 .37226 L F
.2822 .36693 m .28316 .36415 L .28494 .36599 L 0 .03 .129 r
F
.2822 .36693 m .28041 .36512 L .28316 .36415 L F
.34216 .36859 m .34321 .36587 L .34494 .36773 L 0 .033 .134 r
F
.34216 .36859 m .34043 .36673 L .34321 .36587 L F
.31583 .36762 m .31684 .36485 L .31859 .36671 L 0 .031 .131 r
F
.31583 .36762 m .31407 .3658 L .31684 .36485 L F
.62011 .37795 m .62157 .37505 L .62302 .37655 L 0 .056 .159 r
F
.62011 .37795 m .61865 .37646 L .62157 .37505 L F
.25586 .36602 m .25678 .36325 L .25858 .36512 L 0 .028 .127 r
F
.25586 .36602 m .25405 .36414 L .25678 .36325 L F
.84647 .36542 m .84826 .36258 L .84951 .36443 L 0 .026 .125 r
F
.84647 .36542 m .84521 .36357 L .84826 .36258 L F
.60263 .38143 m .60407 .37864 L .60554 .37998 L 0 .067 .168 r
F
.60263 .38143 m .60116 .38019 L .60407 .37864 L F
.78363 .36647 m .78535 .36391 L .78664 .36555 L 0 .029 .129 r
F
.78363 .36647 m .78233 .36482 L .78535 .36391 L F
.18857 .36491 m .18939 .36211 L .19127 .36396 L 0 .026 .124 r
F
.18857 .36491 m .1867 .36306 L .18939 .36211 L F
.85378 .36514 m .8556 .36242 L .85682 .36413 L 0 .026 .125 r
F
.85378 .36514 m .85255 .36343 L .8556 .36242 L F
.86109 .36478 m .86291 .36201 L .86413 .36373 L 0 .025 .124 r
F
.86109 .36478 m .85986 .36307 L .86291 .36201 L F
.39925 .37309 m .40038 .37055 L .40205 .3725 L 0 .044 .147 r
F
.39925 .37309 m .39758 .37117 L .40038 .37055 L F
.79094 .3662 m .79266 .36349 L .79395 .36516 L 0 .028 .128 r
F
.79094 .3662 m .78965 .36456 L .79266 .36349 L F
.38752 .37129 m .38862 .36878 L .39031 .37054 L 0 .04 .142 r
F
.38752 .37129 m .38583 .36957 L .38862 .36878 L F
.63029 .37514 m .63177 .37235 L .63321 .37379 L 0 .049 .152 r
F
.63029 .37514 m .62885 .37375 L .63177 .37235 L F
.44618 .38041 m .44736 .37852 L .44899 .38026 L 0 .066 .168 r
F
.44618 .38041 m .44454 .37862 L .44736 .37852 L F
.28948 .36684 m .29046 .36394 L .29223 .36584 L 0 .03 .129 r
F
.28948 .36684 m .2877 .36497 L .29046 .36394 L F
.2295 .36523 m .23038 .36251 L .23221 .36434 L 0 .026 .126 r
F
.2295 .36523 m .22766 .36338 L .23038 .36251 L F
.54602 .40211 m .54739 .40348 L .5489 .40117 L 0 .156 .232 r
F
.54602 .40211 m .5445 .40442 L .54739 .40348 L F
.36848 .36995 m .36956 .36729 L .37126 .36928 L 0 .037 .138 r
F
.36848 .36995 m .36678 .36798 L .36956 .36729 L F
.79825 .3659 m .79998 .36318 L .80127 .36498 L 0 .028 .127 r
F
.79825 .3659 m .79696 .36412 L .79998 .36318 L F
.8684 .3645 m .87024 .36179 L .87146 .36356 L 0 .025 .124 r
F
.8684 .3645 m .86718 .36273 L .87024 .36179 L F
.68429 .36981 m .68585 .36717 L .68725 .36889 L 0 .037 .138 r
F
.68429 .36981 m .68289 .36812 L .68585 .36717 L F
.7281 .3674 m .72972 .36448 L .73108 .36633 L 0 .031 .131 r
F
.7281 .3674 m .72674 .36558 L .72972 .36448 L F
.7208 .36781 m .72241 .36497 L .72377 .3667 L 0 .032 .132 r
F
.7208 .36781 m .71944 .36611 L .72241 .36497 L F
.34944 .36865 m .35049 .36598 L .35222 .36777 L 0 .034 .135 r
F
.34944 .36865 m .34771 .36688 L .35049 .36598 L F
.19584 .36481 m .19668 .36194 L .19856 .36374 L 0 .026 .124 r
F
.19584 .36481 m .19397 .36299 L .19668 .36194 L F
.58516 .38528 m .58659 .38325 L .58807 .38422 L 0 .081 .181 r
F
.58516 .38528 m .58368 .38431 L .58659 .38325 L F
.67699 .37032 m .67854 .36765 L .67994 .3692 L 0 .038 .14 r
F
.67699 .37032 m .67559 .3688 L .67854 .36765 L F
.26312 .36607 m .26405 .36327 L .26586 .36512 L 0 .028 .128 r
F
.26312 .36607 m .26132 .36422 L .26405 .36327 L F
.3231 .3677 m .32412 .36484 L .32587 .36675 L 0 .032 .132 r
F
.3231 .3677 m .32135 .36579 L .32412 .36484 L F
.71351 .36832 m .71511 .36556 L .71647 .36722 L 0 .033 .134 r
F
.71351 .36832 m .71214 .36666 L .71511 .36556 L F
.20314 .36449 m .20398 .3617 L .20584 .36351 L 0 .025 .124 r
F
.20314 .36449 m .20127 .36268 L .20398 .3617 L F
.7062 .36874 m .7078 .36607 L .70917 .36772 L 0 .034 .135 r
F
.7062 .36874 m .70483 .36712 L .7078 .36607 L F
.43001 .37664 m .43118 .37415 L .43282 .376 L 0 .054 .157 r
F
.43001 .37664 m .42836 .37485 L .43118 .37415 L F
.61282 .37888 m .61427 .37613 L .61574 .37775 L 0 .06 .162 r
F
.61282 .37888 m .61136 .37735 L .61427 .37613 L F
.65508 .3716 m .6566 .36891 L .65803 .37066 L 0 .041 .143 r
F
.65508 .3716 m .65366 .3699 L .6566 .36891 L F
.75003 .36637 m .75169 .36379 L .75302 .36544 L 0 .029 .129 r
F
.75003 .36637 m .7487 .36474 L .75169 .36379 L F
.23677 .36519 m .23766 .36239 L .2395 .36418 L 0 .027 .126 r
F
.23677 .36519 m .23494 .36338 L .23766 .36239 L F
.56194 .39418 m .56334 .39315 L .56483 .39277 L 0 .117 .207 r
F
.56194 .39418 m .56045 .39501 L .56334 .39315 L F
.73542 .36724 m .73705 .36445 L .73841 .3663 L 0 .031 .131 r
F
.73542 .36724 m .73406 .36539 L .73705 .36445 L F
.49621 .39783 m .49744 .401 L .49904 .40059 L 0 .143 .224 r
F
.49621 .39783 m .49461 .39754 L .49744 .401 L F
.57499 .38853 m .57639 .38604 L .57788 .38694 L 0 .091 .189 r
F
.57499 .38853 m .5735 .38772 L .57639 .38604 L F
.87575 .36444 m .87758 .36159 L .8788 .36341 L 0 .025 .124 r
F
.87575 .36444 m .87452 .36263 L .87758 .36159 L F
.50507 .40232 m .50632 .40648 L .50792 .40465 L 0 .166 .238 r
F
.50507 .40232 m .50348 .40332 L .50632 .40648 L F
.6697 .37094 m .67124 .36844 L .67265 .36993 L 0 .04 .142 r
F
.6697 .37094 m .66829 .36945 L .67124 .36844 L F
.69891 .36934 m .70048 .36634 L .70187 .36817 L 0 .035 .137 r
F
.69891 .36934 m .69752 .36753 L .70048 .36634 L F
.80559 .3659 m .80733 .36315 L .80862 .36499 L 0 .028 .128 r
F
.80559 .3659 m .8043 .36408 L .80733 .36315 L F
.29674 .36693 m .29772 .3642 L .29949 .36611 L 0 .031 .131 r
F
.29674 .36693 m .29497 .36502 L .29772 .3642 L F
.69161 .36977 m .69317 .36689 L .69457 .36871 L 0 .037 .138 r
F
.69161 .36977 m .69021 .36798 L .69317 .36689 L F
.35673 .36856 m .3578 .36571 L .35952 .36756 L 0 .034 .135 r
F
.35673 .36856 m .35501 .36674 L .3578 .36571 L F
.74273 .36695 m .74438 .36417 L .74571 .36585 L 0 .031 .131 r
F
.74273 .36695 m .74139 .36527 L .74438 .36417 L F
.50064 .40017 m .50187 .40469 L .50348 .40332 L 0 .158 .233 r
F
.50064 .40017 m .49904 .40059 L .50187 .40469 L F
.6624 .37141 m .66392 .36874 L .66534 .37045 L 0 .041 .143 r
F
.6624 .37141 m .66097 .36971 L .66392 .36874 L F
.24406 .36497 m .24496 .36224 L .24678 .36407 L 0 .027 .126 r
F
.24406 .36497 m .24223 .36317 L .24496 .36224 L F
.2704 .36599 m .27134 .36321 L .27314 .36504 L 0 .029 .128 r
F
.2704 .36599 m .2686 .36415 L .27134 .36321 L F
.4579 .3828 m .4591 .38071 L .46073 .38226 L 0 .074 .174 r
F
.4579 .3828 m .45627 .38124 L .4591 .38071 L F
.41827 .37511 m .41941 .37292 L .42107 .37461 L 0 .051 .154 r
F
.41827 .37511 m .4166 .37343 L .41941 .37292 L F
.75735 .3662 m .75902 .36358 L .76035 .36527 L 0 .029 .129 r
F
.75735 .3662 m .75602 .36452 L .75902 .36358 L F
.88307 .36419 m .88491 .36135 L .88612 .36318 L 0 .025 .123 r
F
.88307 .36419 m .88185 .36237 L .88491 .36135 L F
.64779 .37233 m .64929 .36943 L .65072 .37111 L 0 .043 .145 r
F
.64779 .37233 m .64636 .37068 L .64929 .36943 L F
.52123 .40657 m .52254 .41198 L .52411 .40871 L 0 .191 .252 r
F
.52123 .40657 m .51967 .40889 L .52254 .41198 L F
.44173 .37883 m .44291 .37676 L .44454 .37862 L 0 .062 .164 r
F
.44173 .37883 m .4401 .37695 L .44291 .37676 L F
.2104 .36446 m .21125 .3617 L .21311 .36356 L 0 .026 .124 r
F
.2104 .36446 m .20855 .3626 L .21125 .3617 L F
.16945 .36428 m .17025 .36143 L .17215 .36325 L 0 .025 .124 r
F
.16945 .36428 m .16755 .36245 L .17025 .36143 L F
.81291 .3657 m .81465 .36283 L .81593 .36463 L 0 .028 .128 r
F
.81291 .3657 m .81163 .36391 L .81465 .36283 L F
.82022 .3653 m .82198 .36264 L .82325 .36435 L 0 .028 .127 r
F
.82022 .3653 m .81895 .36361 L .82198 .36264 L F
.33037 .36776 m .33141 .36483 L .33315 .36678 L 0 .032 .133 r
F
.33037 .36776 m .32864 .3658 L .33141 .36483 L F
.8904 .36401 m .89228 .36139 L .89347 .36311 L 0 .025 .124 r
F
.8904 .36401 m .8892 .36228 L .89228 .36139 L F
.6405 .37293 m .642 .37038 L .64343 .37187 L 0 .045 .148 r
F
.6405 .37293 m .63906 .37146 L .642 .37038 L F
.76467 .36605 m .76634 .36327 L .76767 .36505 L 0 .029 .129 r
F
.76467 .36605 m .76334 .36427 L .76634 .36327 L F
.47406 .38712 m .47528 .38573 L .47688 .38761 L 0 .09 .188 r
F
.47406 .38712 m .47245 .38517 L .47528 .38573 L F
.59536 .38289 m .59679 .38067 L .59826 .38167 L 0 .074 .175 r
F
.59536 .38289 m .59388 .38189 L .59679 .38067 L F
.39479 .37175 m .3959 .36929 L .39758 .37117 L 0 .043 .145 r
F
.39479 .37175 m .39311 .3699 L .3959 .36929 L F
.48735 .39385 m .48575 .39241 L .48857 .39453 L 0 .12 .209 r
F
.37575 .37036 m .37684 .36763 L .37854 .36953 L 0 .039 .141 r
F
.37575 .37036 m .37405 .36845 L .37684 .36763 L F
.82754 .36511 m .82931 .36233 L .83057 .36405 L 0 .027 .127 r
F
.82754 .36511 m .82628 .36339 L .82931 .36233 L F
.17673 .36411 m .17754 .36124 L .17943 .36312 L 0 .025 .124 r
F
.17673 .36411 m .17484 .36224 L .17754 .36124 L F
.48292 .39166 m .48415 .39095 L .48575 .39241 L 0 .108 .201 r
F
.48292 .39166 m .48132 .39 L .48415 .39095 L F
.27767 .36597 m .27861 .36331 L .28041 .36512 L 0 .029 .129 r
F
.27767 .36597 m .27587 .36417 L .27861 .36331 L F
.40652 .37367 m .40766 .37086 L .40932 .3729 L 0 .047 .149 r
F
.40652 .37367 m .40485 .37168 L .40766 .37086 L F
.47849 .38949 m .47971 .38821 L .48132 .39 L 0 .099 .194 r
F
.47849 .38949 m .47688 .38761 L .47971 .38821 L F
.83485 .36477 m .83662 .36193 L .83788 .36373 L 0 .026 .126 r
F
.83485 .36477 m .83359 .36299 L .83662 .36193 L F
.60554 .37998 m .60697 .37713 L .60844 .37857 L 0 .064 .166 r
F
.60554 .37998 m .60407 .37864 L .60697 .37713 L F
.62302 .37655 m .62448 .37364 L .62593 .37515 L 0 .054 .157 r
F
.62302 .37655 m .62157 .37505 L .62448 .37364 L F
.21767 .3644 m .21855 .3615 L .22039 .36337 L 0 .026 .125 r
F
.21767 .3644 m .21583 .36254 L .21855 .3615 L F
.25132 .36502 m .25223 .36227 L .25405 .36414 L 0 .027 .127 r
F
.25132 .36502 m .2495 .36317 L .25223 .36227 L F
.364 .36867 m .36508 .36602 L .36678 .36798 L 0 .035 .136 r
F
.364 .36867 m .3623 .36674 L .36508 .36602 L F
.77199 .36587 m .77368 .36311 L .775 .36494 L 0 .029 .129 r
F
.77199 .36587 m .77067 .36408 L .77368 .36311 L F
.89773 .36384 m .89961 .36113 L .90079 .36283 L 0 .025 .124 r
F
.89773 .36384 m .89654 .36214 L .89961 .36113 L F
.30401 .36711 m .30501 .36416 L .30677 .36605 L 0 .031 .132 r
F
.30401 .36711 m .30224 .36521 L .30501 .36416 L F
.33766 .36773 m .33871 .36478 L .34043 .36673 L 0 .033 .133 r
F
.33766 .36773 m .33593 .36578 L .33871 .36478 L F
.52854 .40665 m .52988 .41301 L .53142 .4078 L 0 .197 .255 r
F
.52854 .40665 m .52699 .41085 L .52988 .41301 L F
.49178 .39635 m .49301 .39712 L .49461 .39754 L 0 .131 .217 r
F
.49178 .39635 m .49018 .39548 L .49301 .39712 L F
.46962 .38521 m .47084 .3834 L .47245 .38517 L 0 .083 .182 r
F
.46962 .38521 m .46801 .38344 L .47084 .3834 L F
.31131 .36678 m .31231 .36397 L .31407 .3658 L 0 .031 .131 r
F
.31131 .36678 m .30954 .36498 L .31231 .36397 L F
.84218 .36456 m .84396 .3617 L .84521 .36357 L 0 .026 .125 r
F
.84218 .36456 m .84092 .36272 L .84396 .3617 L F
.184 .364 m .18482 .36117 L .1867 .36306 L 0 .025 .124 r
F
.184 .364 m .18212 .36212 L .18482 .36117 L F
.22495 .36425 m .22582 .36153 L .22766 .36338 L 0 .026 .125 r
F
.22495 .36425 m .22311 .36239 L .22582 .36153 L F
.63321 .37379 m .63469 .37106 L .63613 .37253 L 0 .048 .15 r
F
.63321 .37379 m .63177 .37235 L .63469 .37106 L F
.38303 .37036 m .38413 .36785 L .38583 .36957 L 0 .04 .142 r
F
.38303 .37036 m .38133 .36869 L .38413 .36785 L F
.77932 .36573 m .78102 .36309 L .78233 .36482 L 0 .029 .129 r
F
.77932 .36573 m .77801 .364 L .78102 .36309 L F
.28494 .36599 m .28592 .3631 L .2877 .36497 L F
.28494 .36599 m .28316 .36415 L .28592 .3631 L F
.84951 .36443 m .8513 .36158 L .85255 .36343 L 0 .026 .125 r
F
.84951 .36443 m .84826 .36258 L .8513 .36158 L F
.43728 .3774 m .43846 .37496 L .4401 .37695 L 0 .058 .161 r
F
.43728 .3774 m .43564 .37548 L .43846 .37496 L F
.42554 .37559 m .42671 .37308 L .42836 .37485 L 0 .053 .156 r
F
.42554 .37559 m .42389 .37386 L .42671 .37308 L F
.57788 .38694 m .57928 .38437 L .58078 .38537 L 0 .088 .186 r
F
.57788 .38694 m .57639 .38604 L .57928 .38437 L F
.31859 .36671 m .31961 .36389 L .32135 .36579 L 0 .031 .132 r
F
.31859 .36671 m .31684 .36485 L .31961 .36389 L F
.34494 .36773 m .34599 .36503 L .34771 .36688 L 0 .034 .135 r
F
.34494 .36773 m .34321 .36587 L .34599 .36503 L F
.25858 .36512 m .25951 .36235 L .26132 .36422 L 0 .028 .128 r
F
.25858 .36512 m .25678 .36325 L .25951 .36235 L F
.78664 .36555 m .78836 .36291 L .78965 .36456 L 0 .029 .129 r
F
.78664 .36555 m .78535 .36391 L .78836 .36291 L F
.85682 .36413 m .85864 .36135 L .85986 .36307 L 0 .026 .125 r
F
.85682 .36413 m .8556 .36242 L .85864 .36135 L F
.86413 .36373 m .86596 .361 L .86718 .36273 L 0 .025 .124 r
F
.86413 .36373 m .86291 .36201 L .86596 .361 L F
.79395 .36516 m .79567 .36242 L .79696 .36412 L 0 .028 .128 r
F
.79395 .36516 m .79266 .36349 L .79567 .36242 L F
.19127 .36396 m .1921 .36116 L .19397 .36299 L 0 .026 .124 r
F
.19127 .36396 m .18939 .36211 L .1921 .36116 L F
.56483 .39277 m .56622 .39111 L .56772 .39109 L 0 .112 .204 r
F
.56483 .39277 m .56334 .39315 L .56622 .39111 L F
.4138 .37394 m .41493 .37173 L .4166 .37343 L 0 .05 .152 r
F
.4138 .37394 m .41213 .37226 L .41493 .37173 L F
.29223 .36584 m .2932 .3631 L .29497 .36502 L 0 .03 .13 r
F
.29223 .36584 m .29046 .36394 L .2932 .3631 L F
.46518 .38348 m .46639 .38186 L .46801 .38344 L 0 .079 .179 r
F
.46518 .38348 m .46356 .38193 L .46639 .38186 L F
.72377 .3667 m .72538 .36381 L .72674 .36558 L 0 .031 .132 r
F
.72377 .3667 m .72241 .36497 L .72538 .36381 L F
.5489 .40117 m .55028 .40191 L .55179 .39985 L 0 .154 .231 r
F
.5489 .40117 m .54739 .40348 L .55028 .40191 L F
.73108 .36633 m .7327 .36353 L .73406 .36539 L 0 .031 .131 r
F
.73108 .36633 m .72972 .36448 L .7327 .36353 L F
.45344 .38177 m .45464 .37959 L .45627 .38124 L 0 .072 .173 r
F
.45344 .38177 m .45181 .38009 L .45464 .37959 L F
.67994 .3692 m .68149 .36653 L .68289 .36812 L 0 .037 .139 r
F
.67994 .3692 m .67854 .36765 L .68149 .36653 L F
.23221 .36434 m .2331 .36157 L .23494 .36338 L 0 .027 .126 r
F
.23221 .36434 m .23038 .36251 L .2331 .36157 L F
.19856 .36374 m .1994 .36089 L .20127 .36268 L 0 .025 .124 r
F
.19856 .36374 m .19668 .36194 L .1994 .36089 L F
.58807 .38422 m .5895 .38212 L .59098 .3831 L 0 .08 .18 r
F
.58807 .38422 m .58659 .38325 L .5895 .38212 L F
.61574 .37775 m .61719 .37478 L .61865 .37646 L 0 .059 .161 r
F
.61574 .37775 m .61427 .37613 L .61719 .37478 L F
.80127 .36498 m .80301 .36226 L .8043 .36408 L 0 .028 .128 r
F
.80127 .36498 m .79998 .36318 L .80301 .36226 L F
.87146 .36356 m .8733 .36085 L .87452 .36263 L 0 .025 .124 r
F
.87146 .36356 m .87024 .36179 L .8733 .36085 L F
.71647 .36722 m .71808 .36446 L .71944 .36611 L 0 .033 .134 r
F
.71647 .36722 m .71511 .36556 L .71808 .36446 L F
.68725 .36889 m .68881 .36622 L .69021 .36798 L 0 .037 .138 r
F
.68725 .36889 m .68585 .36717 L .68881 .36622 L F
.39031 .37054 m .39142 .3681 L .39311 .3699 L 0 .041 .143 r
F
.39031 .37054 m .38862 .36878 L .39142 .3681 L F
.70917 .36772 m .71077 .365 L .71214 .36666 L 0 .034 .135 r
F
.70917 .36772 m .7078 .36607 L .71077 .365 L F
.26586 .36512 m .26679 .36231 L .2686 .36415 L 0 .028 .128 r
F
.26586 .36512 m .26405 .36327 L .26679 .36231 L F
.20584 .36351 m .20668 .3608 L .20855 .3626 L 0 .025 .124 r
F
.20584 .36351 m .20398 .3617 L .20668 .3608 L F
.32587 .36675 m .3269 .36389 L .32864 .3658 L 0 .032 .132 r
F
.32587 .36675 m .32412 .36484 L .3269 .36389 L F
.35222 .36777 m .35329 .36492 L .35501 .36674 L 0 .034 .135 r
F
.35222 .36777 m .35049 .36598 L .35329 .36492 L F
.70187 .36817 m .70344 .36527 L .70483 .36712 L 0 .035 .136 r
F
.70187 .36817 m .70048 .36634 L .70344 .36527 L F
.65803 .37066 m .65955 .36792 L .66097 .36971 L 0 .041 .143 r
F
.65803 .37066 m .6566 .36891 L .65955 .36792 L F
.2395 .36418 m .24039 .36139 L .24223 .36317 L 0 .027 .126 r
F
.2395 .36418 m .23766 .36239 L .24039 .36139 L F
.40205 .3725 m .40319 .36969 L .40485 .37168 L 0 .045 .148 r
F
.40205 .3725 m .40038 .37055 L .40319 .36969 L F
.37126 .36928 m .37235 .36647 L .37405 .36845 L 0 .038 .139 r
F
.37126 .36928 m .36956 .36729 L .37235 .36647 L F
.65072 .37111 m .65222 .3682 L .65366 .3699 L 0 .042 .144 r
F
.65072 .37111 m .64929 .36943 L .65222 .3682 L F
.75302 .36544 m .75469 .36286 L .75602 .36452 L 0 .03 .13 r
F
.75302 .36544 m .75169 .36379 L .75469 .36286 L F
.8788 .36341 m .88063 .36054 L .88185 .36237 L 0 .025 .124 r
F
.8788 .36341 m .87758 .36159 L .88063 .36054 L F
.74571 .36585 m .74736 .36307 L .7487 .36474 L 0 .03 .13 r
F
.74571 .36585 m .74438 .36417 L .74736 .36307 L F
.69457 .36871 m .69612 .36569 L .69752 .36753 L 0 .036 .137 r
F
.69457 .36871 m .69317 .36689 L .69612 .36569 L F
.67265 .36993 m .67419 .36728 L .67559 .3688 L 0 .04 .141 r
F
.67265 .36993 m .67124 .36844 L .67419 .36728 L F
.73841 .3663 m .74004 .36342 L .74139 .36527 L 0 .031 .131 r
F
.73841 .3663 m .73705 .36445 L .74004 .36342 L F
.16486 .36347 m .16565 .36067 L .16755 .36245 L 0 .025 .124 r
F
.16486 .36347 m .16295 .36167 L .16565 .36067 L F
.35952 .36756 m .36059 .36486 L .3623 .36674 L 0 .034 .135 r
F
.35952 .36756 m .3578 .36571 L .36059 .36486 L F
.66534 .37045 m .66687 .36774 L .66829 .36945 L 0 .041 .143 r
F
.66534 .37045 m .66392 .36874 L .66687 .36774 L F
.80862 .36499 m .81034 .36206 L .81163 .36391 L 0 .028 .128 r
F
.80862 .36499 m .80733 .36315 L .81034 .36206 L F
.60844 .37857 m .60989 .37582 L .61136 .37735 L 0 .062 .164 r
F
.60844 .37857 m .60697 .37713 L .60989 .37582 L F
.88612 .36318 m .88799 .36045 L .8892 .36228 L 0 .025 .124 r
F
.88612 .36318 m .88491 .36135 L .88799 .36045 L F
.62593 .37515 m .6274 .3722 L .62885 .37375 L 0 .052 .155 r
F
.62593 .37515 m .62448 .37364 L .6274 .3722 L F
.81593 .36463 m .81768 .36181 L .81895 .36361 L 0 .028 .127 r
F
.81593 .36463 m .81465 .36283 L .81768 .36181 L F
.27314 .36504 m .27408 .36236 L .27587 .36417 L 0 .029 .129 r
F
.27314 .36504 m .27134 .36321 L .27408 .36236 L F
.59826 .38167 m .59969 .37912 L .60116 .38019 L 0 .072 .173 r
F
.59826 .38167 m .59679 .38067 L .59969 .37912 L F
.43282 .376 m .434 .37356 L .43564 .37548 L 0 .056 .158 r
F
.43282 .376 m .43118 .37415 L .434 .37356 L F
.76035 .36527 m .76202 .36257 L .76334 .36427 L 0 .029 .129 r
F
.76035 .36527 m .75902 .36358 L .76202 .36257 L F
.17215 .36325 m .17295 .36041 L .17484 .36224 L 0 .025 .124 r
F
.17215 .36325 m .17025 .36143 L .17295 .36041 L F
.24678 .36407 m .24768 .36131 L .2495 .36317 L 0 .027 .126 r
F
.24678 .36407 m .24496 .36224 L .24768 .36131 L F
.29949 .36611 m .30048 .3633 L .30224 .36521 L 0 .031 .131 r
F
.29949 .36611 m .29772 .3642 L .30048 .3633 L F
.82325 .36435 m .82502 .36166 L .82628 .36339 L 0 .028 .127 r
F
.82325 .36435 m .82198 .36264 L .82502 .36166 L F
.33315 .36678 m .33419 .36382 L .33593 .36578 L 0 .032 .133 r
F
.33315 .36678 m .33141 .36483 L .33419 .36382 L F
.64343 .37187 m .64493 .36918 L .64636 .37068 L 0 .045 .147 r
F
.64343 .37187 m .642 .37038 L .64493 .36918 L F
.21311 .36356 m .21397 .36067 L .21583 .36254 L 0 .026 .124 r
F
.21311 .36356 m .21125 .3617 L .21397 .36067 L F
.76767 .36505 m .76935 .36228 L .77067 .36408 L 0 .029 .129 r
F
.76767 .36505 m .76634 .36327 L .76935 .36228 L F
.44899 .38026 m .45018 .37839 L .45181 .38009 L 0 .07 .171 r
F
.44899 .38026 m .44736 .37852 L .45018 .37839 L F
.83057 .36405 m .83234 .36126 L .83359 .36299 L 0 .027 .126 r
F
.83057 .36405 m .82931 .36233 L .83234 .36126 L F
.53872 .40502 m .5401 .41007 L .54161 .40472 L 0 .189 .251 r
F
.53872 .40502 m .5372 .40998 L .5401 .41007 L F
.58078 .38537 m .58219 .38327 L .58368 .38431 L 0 .086 .184 r
F
.58078 .38537 m .57928 .38437 L .58219 .38327 L F
.5168 .40627 m .51809 .41412 L .51967 .40889 L 0 .204 .259 r
F
.5168 .40627 m .51522 .41018 L .51809 .41412 L F
.89347 .36311 m .89535 .36042 L .89654 .36214 L 0 .025 .124 r
F
.89347 .36311 m .89228 .36139 L .89535 .36042 L F
.56772 .39109 m .56911 .38906 L .57061 .3894 L 0 .107 .2 r
F
.56772 .39109 m .56622 .39111 L .56911 .38906 L F
.17943 .36312 m .18024 .36024 L .18212 .36212 L 0 .025 .124 r
F
.17943 .36312 m .17754 .36124 L .18024 .36024 L F
.83788 .36373 m .83966 .36089 L .84092 .36272 L 0 .026 .125 r
F
.83788 .36373 m .83662 .36193 L .83966 .36089 L F
.22039 .36337 m .22127 .36051 L .22311 .36239 L 0 .026 .124 r
F
.22039 .36337 m .21855 .3615 L .22127 .36051 L F
.63613 .37253 m .63762 .36998 L .63906 .37146 L 0 .047 .149 r
F
.63613 .37253 m .63469 .37106 L .63762 .36998 L F
.46073 .38226 m .46194 .38038 L .46356 .38193 L 0 .076 .177 r
F
.46073 .38226 m .4591 .38071 L .46194 .38038 L F
.30677 .36605 m .30778 .36311 L .30954 .36498 L 0 .031 .131 r
F
.30677 .36605 m .30501 .36416 L .30778 .36311 L F
.90079 .36283 m .90268 .36011 L .90386 .36181 L 0 .025 .123 r
F
.90079 .36283 m .89961 .36113 L .90268 .36011 L F
.37854 .36953 m .37964 .36679 L .38133 .36869 L 0 .039 .141 r
F
.37854 .36953 m .37684 .36763 L .37964 .36679 L F
.42107 .37461 m .42223 .37213 L .42389 .37386 L 0 .053 .155 r
F
.42107 .37461 m .41941 .37292 L .42223 .37213 L F
.34043 .36673 m .34148 .36394 L .34321 .36587 L 0 .033 .134 r
F
.34043 .36673 m .33871 .36478 L .34148 .36394 L F
.28041 .36512 m .28137 .36232 L .28316 .36415 L 0 .029 .129 r
F
.28041 .36512 m .27861 .36331 L .28137 .36232 L F
.775 .36494 m .77669 .36215 L .77801 .364 L F
.775 .36494 m .77368 .36311 L .77669 .36215 L F
.25405 .36414 m .25496 .36137 L .25678 .36325 L 0 .027 .127 r
F
.25405 .36414 m .25223 .36227 L .25496 .36137 L F
.31407 .3658 m .31508 .36299 L .31684 .36485 L 0 .031 .131 r
F
.31407 .3658 m .31231 .36397 L .31508 .36299 L F
.84521 .36357 m .847 .36071 L .84826 .36258 L 0 .026 .125 r
F
.84521 .36357 m .84396 .3617 L .847 .36071 L F
.40932 .3729 m .41047 .37018 L .41213 .37226 L 0 .048 .15 r
F
.40932 .3729 m .40766 .37086 L .41047 .37018 L F
.1867 .36306 m .18752 .36023 L .18939 .36211 L 0 .025 .124 r
F
.1867 .36306 m .18482 .36117 L .18752 .36023 L F
.39758 .37117 m .3987 .36863 L .40038 .37055 L 0 .044 .146 r
F
.39758 .37117 m .3959 .36929 L .3987 .36863 L F
.36678 .36798 m .36786 .36531 L .36956 .36729 L 0 .036 .138 r
F
.36678 .36798 m .36508 .36602 L .36786 .36531 L F
.2877 .36497 m .28868 .36205 L .29046 .36394 L 0 .029 .129 r
F
.2877 .36497 m .28592 .3631 L .28868 .36205 L F
.55179 .39985 m .55318 .40033 L .55468 .39854 L 0 .151 .229 r
F
.55179 .39985 m .55028 .40191 L .55318 .40033 L F
.22766 .36338 m .22854 .36067 L .23038 .36251 L 0 .026 .125 r
F
.22766 .36338 m .22582 .36153 L .22854 .36067 L F
.78233 .36482 m .78404 .36218 L .78535 .36391 L 0 .029 .129 r
F
.78233 .36482 m .78102 .36309 L .78404 .36218 L F
.44454 .37862 m .44572 .37668 L .44736 .37852 L 0 .066 .167 r
F
.44454 .37862 m .44291 .37676 L .44572 .37668 L F
.85255 .36343 m .85435 .36058 L .8556 .36242 L 0 .026 .125 r
F
.85255 .36343 m .8513 .36158 L .85435 .36058 L F
.85986 .36307 m .86168 .36028 L .86291 .36201 L F
.85986 .36307 m .85864 .36135 L .86168 .36028 L F
.61865 .37646 m .6201 .37335 L .62157 .37505 L 0 .057 .159 r
F
.61865 .37646 m .61719 .37478 L .6201 .37335 L F
.38583 .36957 m .38693 .36701 L .38862 .36878 L 0 .04 .142 r
F
.38583 .36957 m .38413 .36785 L .38693 .36701 L F
.79696 .36412 m .79869 .36146 L .79998 .36318 L 0 .028 .128 r
F
.79696 .36412 m .79567 .36242 L .79869 .36146 L F
.86718 .36273 m .86902 .36006 L .87024 .36179 L 0 .025 .124 r
F
.86718 .36273 m .86596 .361 L .86902 .36006 L F
.78965 .36456 m .79137 .36182 L .79266 .36349 L 0 .029 .129 r
F
.78965 .36456 m .78836 .36291 L .79137 .36182 L F
.72674 .36558 m .72835 .36268 L .72972 .36448 L 0 .031 .131 r
F
.72674 .36558 m .72538 .36381 L .72835 .36268 L F
.32135 .36579 m .32238 .36293 L .32412 .36484 L 0 .031 .132 r
F
.32135 .36579 m .31961 .36389 L .32238 .36293 L F
.19397 .36299 m .19481 .36013 L .19668 .36194 L 0 .026 .124 r
F
.19397 .36299 m .1921 .36116 L .19481 .36013 L F
.26132 .36422 m .26225 .3614 L .26405 .36327 L 0 .028 .128 r
F
.26132 .36422 m .25951 .36235 L .26225 .3614 L F
.34771 .36688 m .34877 .36414 L .35049 .36598 L 0 .034 .135 r
F
.34771 .36688 m .34599 .36503 L .34877 .36414 L F
.59098 .3831 m .59241 .38091 L .59388 .38189 L 0 .079 .179 r
F
.59098 .3831 m .5895 .38212 L .59241 .38091 L F
.68289 .36812 m .68445 .36553 L .68585 .36717 L 0 .037 .139 r
F
.68289 .36812 m .68149 .36653 L .68445 .36553 L F
.71944 .36611 m .72105 .36329 L .72241 .36497 L 0 .032 .133 r
F
.71944 .36611 m .71808 .36446 L .72105 .36329 L F
.20127 .36268 m .20211 .35992 L .20398 .3617 L 0 .025 .124 r
F
.20127 .36268 m .1994 .36089 L .20211 .35992 L F
.42836 .37485 m .42953 .37234 L .43118 .37415 L 0 .054 .157 r
F
.42836 .37485 m .42671 .37308 L .42953 .37234 L F
.73406 .36539 m .73569 .36259 L .73705 .36445 L 0 .031 .131 r
F
.73406 .36539 m .7327 .36353 L .73569 .36259 L F
.60116 .38019 m .6026 .37749 L .60407 .37864 L 0 .069 .171 r
F
.60116 .38019 m .59969 .37912 L .6026 .37749 L F
.23494 .36338 m .23583 .36059 L .23766 .36239 L 0 .027 .126 r
F
.23494 .36338 m .2331 .36157 L .23583 .36059 L F
.29497 .36502 m .29595 .36227 L .29772 .3642 L 0 .03 .13 r
F
.29497 .36502 m .2932 .3631 L .29595 .36227 L F
.65366 .3699 m .65517 .36717 L .6566 .36891 L 0 .041 .143 r
F
.65366 .3699 m .65222 .3682 L .65517 .36717 L F
.62885 .37375 m .63032 .37076 L .63177 .37235 L 0 .05 .153 r
F
.62885 .37375 m .6274 .3722 L .63032 .37076 L F
.71214 .36666 m .71374 .36391 L .71511 .36556 L 0 .034 .135 r
F
.71214 .36666 m .71077 .365 L .71374 .36391 L F
.87452 .36263 m .87636 .35981 L .87758 .36159 L 0 .025 .124 r
F
.87452 .36263 m .8733 .36085 L .87636 .35981 L F
.57061 .3894 m .572 .38708 L .5735 .38772 L 0 .101 .196 r
F
.57061 .3894 m .56911 .38906 L .572 .38708 L F
.69752 .36753 m .69908 .36449 L .70048 .36634 L 0 .035 .136 r
F
.69752 .36753 m .69612 .36569 L .69908 .36449 L F
.70483 .36712 m .70641 .36419 L .7078 .36607 L 0 .034 .136 r
F
.70483 .36712 m .70344 .36527 L .70641 .36419 L F
.8043 .36408 m .80604 .36131 L .80733 .36315 L 0 .028 .128 r
F
.8043 .36408 m .80301 .36226 L .80604 .36131 L F
.35501 .36674 m .35608 .36386 L .3578 .36571 L 0 .034 .135 r
F
.35501 .36674 m .35329 .36492 L .35608 .36386 L F
.69021 .36798 m .69177 .3651 L .69317 .36689 L 0 .037 .138 r
F
.69021 .36798 m .68881 .36622 L .69177 .3651 L F
.7487 .36474 m .75036 .36211 L .75169 .36379 L 0 .03 .13 r
F
.7487 .36474 m .74736 .36307 L .75036 .36211 L F
.67559 .3688 m .67714 .36609 L .67854 .36765 L 0 .039 .141 r
F
.67559 .3688 m .67419 .36728 L .67714 .36609 L F
.2686 .36415 m .26954 .36138 L .27134 .36321 L 0 .028 .128 r
F
.2686 .36415 m .26679 .36231 L .26954 .36138 L F
.61136 .37735 m .6128 .3745 L .61427 .37613 L 0 .061 .163 r
F
.61136 .37735 m .60989 .37582 L .6128 .3745 L F
.4401 .37695 m .44128 .3747 L .44291 .37676 L F
.4401 .37695 m .43846 .37496 L .44128 .3747 L F
.24223 .36317 m .24312 .36047 L .24496 .36224 L 0 .027 .126 r
F
.24223 .36317 m .24039 .36139 L .24312 .36047 L F
.32864 .3658 m .32967 .3629 L .33141 .36483 L 0 .032 .132 r
F
.32864 .3658 m .3269 .36389 L .32967 .3629 L F
.88185 .36237 m .88369 .35953 L .88491 .36135 L 0 .025 .123 r
F
.88185 .36237 m .88063 .36054 L .88369 .35953 L F
.20855 .3626 m .20939 .3599 L .21125 .3617 L 0 .026 .124 r
F
.20855 .3626 m .20668 .3608 L .20939 .3599 L F
.66097 .36971 m .6625 .36693 L .66392 .36874 L 0 .041 .143 r
F
.66097 .36971 m .65955 .36792 L .6625 .36693 L F
.74139 .36527 m .74302 .36232 L .74438 .36417 L 0 .031 .131 r
F
.74139 .36527 m .74004 .36342 L .74302 .36232 L F
.16755 .36245 m .16834 .35966 L .17025 .36143 L 0 .025 .124 r
F
.16755 .36245 m .16565 .36067 L .16834 .35966 L F
.47245 .38517 m .47367 .38395 L .47528 .38573 L 0 .09 .187 r
F
.47245 .38517 m .47084 .3834 L .47367 .38395 L F
.4166 .37343 m .41774 .37121 L .41941 .37292 L 0 .052 .154 r
F
.4166 .37343 m .41493 .37173 L .41774 .37121 L F
.81163 .36391 m .81336 .36097 L .81465 .36283 L 0 .028 .127 r
F
.81163 .36391 m .81034 .36206 L .81336 .36097 L F
.75602 .36452 m .7577 .3619 L .75902 .36358 L 0 .03 .13 r
F
.75602 .36452 m .75469 .36286 L .7577 .3619 L F
.66829 .36945 m .66983 .36674 L .67124 .36844 L 0 .041 .143 r
F
.66829 .36945 m .66687 .36774 L .66983 .36674 L F
.40485 .37168 m .406 .36882 L .40766 .37086 L 0 .046 .148 r
F
.40485 .37168 m .40319 .36969 L .406 .36882 L F
.64636 .37068 m .64786 .36792 L .64929 .36943 L 0 .044 .146 r
F
.64636 .37068 m .64493 .36918 L .64786 .36792 L F
.37405 .36845 m .37515 .36566 L .37684 .36763 L 0 .038 .14 r
F
.37405 .36845 m .37235 .36647 L .37515 .36566 L F
.45627 .38124 m .45748 .37909 L .4591 .38071 L 0 .075 .175 r
F
.45627 .38124 m .45464 .37959 L .45748 .37909 L F
.81895 .36361 m .82071 .36082 L .82198 .36264 L 0 .028 .127 r
F
.81895 .36361 m .81768 .36181 L .82071 .36082 L F
.39311 .3699 m .39422 .36745 L .3959 .36929 L 0 .042 .145 r
F
.39311 .3699 m .39142 .3681 L .39422 .36745 L F
.17484 .36224 m .17565 .35941 L .17754 .36124 L 0 .025 .123 r
F
.17484 .36224 m .17295 .36041 L .17565 .35941 L F
.76334 .36427 m .76502 .36156 L .76634 .36327 L 0 .029 .129 r
F
.76334 .36427 m .76202 .36257 L .76502 .36156 L F
.47688 .38761 m .47811 .3864 L .47971 .38821 L 0 .098 .194 r
F
.47688 .38761 m .47528 .38573 L .47811 .3864 L F
.3623 .36674 m .36337 .36411 L .36508 .36602 L 0 .035 .136 r
F
.3623 .36674 m .36059 .36486 L .36337 .36411 L F
.8892 .36228 m .89106 .35954 L .89228 .36139 L 0 .025 .124 r
F
.8892 .36228 m .88799 .36045 L .89106 .35954 L F
.21583 .36254 m .2167 .35962 L .21855 .3615 L F
.21583 .36254 m .21397 .36067 L .2167 .35962 L F
.33593 .36578 m .33698 .36282 L .33871 .36478 L 0 .032 .133 r
F
.33593 .36578 m .33419 .36382 L .33698 .36282 L F
.27587 .36417 m .27682 .36151 L .27861 .36331 L 0 .029 .129 r
F
.27587 .36417 m .27408 .36236 L .27682 .36151 L F
.2495 .36317 m .25042 .36039 L .25223 .36227 L 0 .027 .126 r
F
.2495 .36317 m .24768 .36131 L .25042 .36039 L F
.30224 .36521 m .30324 .36227 L .30501 .36416 L 0 .031 .131 r
F
.30224 .36521 m .30048 .3633 L .30324 .36227 L F
.82628 .36339 m .82805 .36059 L .82931 .36233 L 0 .027 .127 r
F
.82628 .36339 m .82502 .36166 L .82805 .36059 L F
.83359 .36299 m .83537 .36019 L .83662 .36193 L 0 .027 .126 r
F
.83359 .36299 m .83234 .36126 L .83537 .36019 L F
.58368 .38431 m .5851 .38216 L .58659 .38325 L 0 .085 .184 r
F
.58368 .38431 m .58219 .38327 L .5851 .38216 L F
.48132 .39 m .48255 .38927 L .48415 .39095 L 0 .109 .202 r
F
.48132 .39 m .47971 .38821 L .48255 .38927 L F
.77067 .36408 m .77236 .36128 L .77368 .36311 L 0 .029 .129 r
F
.77067 .36408 m .76935 .36228 L .77236 .36128 L F
.84092 .36272 m .8427 .35985 L .84396 .3617 L 0 .026 .125 r
F
.84092 .36272 m .83966 .36089 L .8427 .35985 L F
.18212 .36212 m .18294 .35929 L .18482 .36117 L 0 .025 .124 r
F
.18212 .36212 m .18024 .36024 L .18294 .35929 L F
.63906 .37146 m .64056 .3689 L .642 .37038 L 0 .046 .149 r
F
.63906 .37146 m .63762 .36998 L .64056 .3689 L F
.30954 .36498 m .31055 .36213 L .31231 .36397 L 0 .031 .131 r
F
.30954 .36498 m .30778 .36311 L .31055 .36213 L F
.89654 .36214 m .89842 .35941 L .89961 .36113 L 0 .025 .124 r
F
.89654 .36214 m .89535 .36042 L .89842 .35941 L F
.46801 .38344 m .46923 .3818 L .47084 .3834 L 0 .084 .183 r
F
.46801 .38344 m .46639 .38186 L .46923 .3818 L F
.22311 .36239 m .22398 .35965 L .22582 .36153 L 0 .026 .125 r
F
.22311 .36239 m .22127 .36051 L .22398 .35965 L F
.48575 .39241 m .48697 .39352 L .48857 .39453 L 0 .124 .212 r
F
.48575 .39241 m .48415 .39095 L .48697 .39352 L F
.55468 .39854 m .55606 .39813 L .55756 .3968 L 0 .146 .226 r
F
.55468 .39854 m .55318 .40033 L .55606 .39813 L F
.62157 .37505 m .62302 .37191 L .62448 .37364 L 0 .055 .157 r
F
.62157 .37505 m .6201 .37335 L .62302 .37191 L F
.43564 .37548 m .43682 .37296 L .43846 .37496 L 0 .058 .16 r
F
.43564 .37548 m .434 .37356 L .43682 .37296 L F
.28316 .36415 m .28413 .36124 L .28592 .3631 L 0 .029 .129 r
F
.28316 .36415 m .28137 .36232 L .28413 .36124 L F
.5735 .38772 m .57489 .38513 L .57639 .38604 L 0 .097 .193 r
F
.5735 .38772 m .572 .38708 L .57489 .38513 L F
.84826 .36258 m .85005 .35972 L .8513 .36158 L 0 .026 .125 r
F
.84826 .36258 m .847 .36071 L .85005 .35972 L F
.77801 .364 m .77971 .36123 L .78102 .36309 L 0 .029 .129 r
F
.77801 .364 m .77669 .36215 L .77971 .36123 L F
.38133 .36869 m .38244 .36595 L .38413 .36785 L 0 .04 .142 r
F
.38133 .36869 m .37964 .36679 L .38244 .36595 L F
.31684 .36485 m .31785 .36202 L .31961 .36389 L 0 .031 .131 r
F
.31684 .36485 m .31508 .36299 L .31785 .36202 L F
.60407 .37864 m .60551 .37588 L .60697 .37713 L 0 .066 .168 r
F
.60407 .37864 m .6026 .37749 L .60551 .37588 L F
.34321 .36587 m .34426 .36313 L .34599 .36503 L 0 .033 .134 r
F
.34321 .36587 m .34148 .36394 L .34426 .36313 L F
.25678 .36325 m .2577 .36047 L .25951 .36235 L 0 .028 .127 r
F
.25678 .36325 m .25496 .36137 L .2577 .36047 L F
.42389 .37386 m .42505 .37132 L .42671 .37308 L 0 .053 .156 r
F
.42389 .37386 m .42223 .37213 L .42505 .37132 L F
.18939 .36211 m .19022 .35928 L .1921 .36116 L 0 .025 .124 r
F
.18939 .36211 m .18752 .36023 L .19022 .35928 L F
.29046 .36394 m .29143 .36119 L .2932 .3631 L 0 .029 .129 r
F
.29046 .36394 m .28868 .36205 L .29143 .36119 L F
.86291 .36201 m .86474 .35927 L .86596 .361 L 0 .025 .124 r
F
.86291 .36201 m .86168 .36028 L .86474 .35927 L F
.63177 .37235 m .63324 .36944 L .63469 .37106 L 0 .049 .151 r
F
.63177 .37235 m .63032 .37076 L .63324 .36944 L F
.59388 .38189 m .59532 .3797 L .59679 .38067 L 0 .078 .178 r
F
.59388 .38189 m .59241 .38091 L .59532 .3797 L F
.8556 .36242 m .85739 .35951 L .85864 .36135 L 0 .026 .125 r
F
.8556 .36242 m .85435 .36058 L .85739 .35951 L F
.72972 .36448 m .73134 .36173 L .7327 .36353 L 0 .031 .131 r
F
.72972 .36448 m .72835 .36268 L .73134 .36173 L F
.79266 .36349 m .79438 .36072 L .79567 .36242 L 0 .028 .128 r
F
.79266 .36349 m .79137 .36182 L .79438 .36072 L F
.78535 .36391 m .78706 .36118 L .78836 .36291 L 0 .029 .129 r
F
.78535 .36391 m .78404 .36218 L .78706 .36118 L F
.23038 .36251 m .23126 .35975 L .2331 .36157 L 0 .027 .126 r
F
.23038 .36251 m .22854 .36067 L .23126 .35975 L F
.41213 .37226 m .41328 .36963 L .41493 .37173 L 0 .049 .152 r
F
.41213 .37226 m .41047 .37018 L .41328 .36963 L F
.54161 .40472 m .543 .41016 L .5445 .40442 L 0 .195 .254 r
F
.54161 .40472 m .5401 .41007 L .543 .41016 L F
.72241 .36497 m .72402 .3621 L .72538 .36381 L 0 .032 .132 r
F
.72241 .36497 m .72105 .36329 L .72402 .3621 L F
.19668 .36194 m .19752 .35909 L .1994 .36089 L 0 .025 .124 r
F
.19668 .36194 m .19481 .36013 L .19752 .35909 L F
.53142 .4078 m .53278 .41517 L .53431 .40895 L 0 .217 .266 r
F
.53142 .4078 m .52988 .41301 L .53278 .41517 L F
.79998 .36318 m .80172 .36052 L .80301 .36226 L 0 .028 .128 r
F
.79998 .36318 m .79869 .36146 L .80172 .36052 L F
.87024 .36179 m .87209 .35911 L .8733 .36085 L 0 .025 .124 r
F
.87024 .36179 m .86902 .36006 L .87209 .35911 L F
.32412 .36484 m .32515 .36197 L .3269 .36389 L 0 .031 .132 r
F
.32412 .36484 m .32238 .36293 L .32515 .36197 L F
.36956 .36729 m .37065 .3645 L .37235 .36647 L 0 .037 .138 r
F
.36956 .36729 m .36786 .36531 L .37065 .3645 L F
.40038 .37055 m .40151 .36772 L .40319 .36969 L 0 .045 .147 r
F
.40038 .37055 m .3987 .36863 L .40151 .36772 L F
.45181 .38009 m .45301 .37793 L .45464 .37959 L 0 .073 .174 r
F
.45181 .38009 m .45018 .37839 L .45301 .37793 L F
.49461 .39754 m .49583 .40136 L .49744 .401 L 0 .155 .232 r
F
.49461 .39754 m .49301 .39712 L .49583 .40136 L F
.46356 .38193 m .46477 .38029 L .46639 .38186 L 0 .08 .18 r
F
.46356 .38193 m .46194 .38038 L .46477 .38029 L F
.26405 .36327 m .26499 .36044 L .26679 .36231 L 0 .028 .128 r
F
.26405 .36327 m .26225 .3614 L .26499 .36044 L F
.70048 .36634 m .70205 .36339 L .70344 .36527 L 0 .035 .136 r
F
.70048 .36634 m .69908 .36449 L .70205 .36339 L F
.38862 .36878 m .38973 .36629 L .39142 .3681 L 0 .041 .143 r
F
.38862 .36878 m .38693 .36701 L .38973 .36629 L F
.68585 .36717 m .68742 .36454 L .68881 .36622 L 0 .037 .139 r
F
.68585 .36717 m .68445 .36553 L .68742 .36454 L F
.20398 .3617 m .20481 .35903 L .20668 .3608 L 0 .025 .124 r
F
.20398 .3617 m .20211 .35992 L .20481 .35903 L F
.71511 .36556 m .71671 .36281 L .71808 .36446 L 0 .033 .134 r
F
.71511 .36556 m .71374 .36391 L .71671 .36281 L F
.35049 .36598 m .35156 .36309 L .35329 .36492 L 0 .034 .135 r
F
.35049 .36598 m .34877 .36414 L .35156 .36309 L F
.61427 .37613 m .61572 .37311 L .61719 .37478 L 0 .059 .162 r
F
.61427 .37613 m .6128 .3745 L .61572 .37311 L F
.67854 .36765 m .68009 .36493 L .68149 .36653 L 0 .038 .14 r
F
.67854 .36765 m .67714 .36609 L .68009 .36493 L F
.51236 .40661 m .51362 .41417 L .51522 .41018 L 0 .212 .263 r
F
.51236 .40661 m .51077 .40937 L .51362 .41417 L F
.23766 .36239 m .23856 .35962 L .24039 .36139 L 0 .027 .126 r
F
.23766 .36239 m .23583 .36059 L .23856 .35962 L F
.87758 .36159 m .87942 .35875 L .88063 .36054 L 0 .025 .124 r
F
.87758 .36159 m .87636 .35981 L .87942 .35875 L F
.49018 .39548 m .4914 .39665 L .49301 .39712 L 0 .138 .221 r
F
.73705 .36445 m .73868 .36157 L .74004 .36342 L 0 .031 .131 r
F
.73705 .36445 m .73569 .36259 L .73868 .36157 L F
.6566 .36891 m .65812 .36613 L .65955 .36792 L 0 .041 .143 r
F
.6566 .36891 m .65517 .36717 L .65812 .36613 L F
.7078 .36607 m .70938 .36312 L .71077 .365 L 0 .034 .135 r
F
.7078 .36607 m .70641 .36419 L .70938 .36312 L F
.69317 .36689 m .69473 .36388 L .69612 .36569 L 0 .036 .137 r
F
.69317 .36689 m .69177 .3651 L .69473 .36388 L F
.3578 .36571 m .35887 .36298 L .36059 .36486 L 0 .034 .135 r
F
.3578 .36571 m .35608 .36386 L .35887 .36298 L F
.16295 .36167 m .16374 .35888 L .16565 .36067 L 0 .025 .124 r
F
.16295 .36167 m .16105 .35987 L .16374 .35888 L F
.55756 .3968 m .55895 .39585 L .56045 .39501 L 0 .139 .221 r
F
.55756 .3968 m .55606 .39813 L .55895 .39585 L F
.64929 .36943 m .6508 .36667 L .65222 .3682 L 0 .042 .145 r
F
.64929 .36943 m .64786 .36792 L .6508 .36667 L F
.80733 .36315 m .80905 .36021 L .81034 .36206 L 0 .028 .128 r
F
.80733 .36315 m .80604 .36131 L .80905 .36021 L F
.74438 .36417 m .74601 .36122 L .74736 .36307 L 0 .03 .13 r
F
.74438 .36417 m .74302 .36232 L .74601 .36122 L F
.88491 .36135 m .88677 .35861 L .88799 .36045 L 0 .025 .123 r
F
.88491 .36135 m .88369 .35953 L .88677 .35861 L F
.29772 .3642 m .29871 .36137 L .30048 .3633 L 0 .03 .131 r
F
.29772 .3642 m .29595 .36227 L .29871 .36137 L F
.75169 .36379 m .75336 .36116 L .75469 .36286 L 0 .03 .13 r
F
.75169 .36379 m .75036 .36211 L .75336 .36116 L F
.43118 .37415 m .43235 .37167 L .434 .37356 L 0 .055 .158 r
F
.43118 .37415 m .42953 .37234 L .43235 .37167 L F
.33141 .36483 m .33246 .36188 L .33419 .36382 L 0 .032 .132 r
F
.33141 .36483 m .32967 .3629 L .33246 .36188 L F
.27134 .36321 m .27227 .36055 L .27408 .36236 L 0 .029 .128 r
F
.27134 .36321 m .26954 .36138 L .27227 .36055 L F
.81465 .36283 m .81639 .35993 L .81768 .36181 L 0 .028 .127 r
F
.81465 .36283 m .81336 .36097 L .81639 .35993 L F
.24496 .36224 m .24585 .35954 L .24768 .36131 L 0 .027 .126 r
F
.24496 .36224 m .24312 .36047 L .24585 .35954 L F
.17025 .36143 m .17104 .35865 L .17295 .36041 L 0 .025 .124 r
F
.17025 .36143 m .16834 .35966 L .17104 .35865 L F
.66392 .36874 m .66545 .36593 L .66687 .36774 L 0 .041 .143 r
F
.66392 .36874 m .6625 .36693 L .66545 .36593 L F
.52411 .40871 m .52543 .41508 L .52699 .41085 L 0 .22 .267 r
F
.52411 .40871 m .52254 .41198 L .52543 .41508 L F
.50792 .40465 m .50916 .41251 L .51077 .40937 L 0 .204 .259 r
F
.50792 .40465 m .50632 .40648 L .50916 .41251 L F
.57639 .38604 m .57779 .3832 L .57928 .38437 L 0 .092 .189 r
F
.57639 .38604 m .57489 .38513 L .57779 .3832 L F
.21125 .3617 m .21211 .35887 L .21397 .36067 L 0 .026 .124 r
F
.21125 .3617 m .20939 .3599 L .21211 .35887 L F
.67124 .36844 m .67278 .36556 L .67419 .36728 L 0 .04 .142 r
F
.67124 .36844 m .66983 .36674 L .67278 .36556 L F
.75902 .36358 m .7607 .36088 L .76202 .36257 L 0 .03 .13 r
F
.75902 .36358 m .7577 .3619 L .7607 .36088 L F
.82198 .36264 m .82374 .35983 L .82502 .36166 L 0 .028 .127 r
F
.82198 .36264 m .82071 .36082 L .82374 .35983 L F
.17754 .36124 m .17835 .3584 L .18024 .36024 L 0 .025 .123 r
F
.17754 .36124 m .17565 .35941 L .17835 .3584 L F
.76634 .36327 m .76803 .36054 L .76935 .36228 L 0 .029 .129 r
F
.76634 .36327 m .76502 .36156 L .76803 .36054 L F
.62448 .37364 m .62594 .37045 L .6274 .3722 L 0 .053 .155 r
F
.62448 .37364 m .62302 .37191 L .62594 .37045 L F
.44736 .37852 m .44854 .37657 L .45018 .37839 L 0 .07 .171 r
F
.44736 .37852 m .44572 .37668 L .44854 .37657 L F
.21855 .3615 m .21942 .35863 L .22127 .36051 L 0 .025 .124 r
F
.21855 .3615 m .2167 .35962 L .21942 .35863 L F
.60697 .37713 m .60842 .37447 L .60989 .37582 L 0 .064 .166 r
F
.60697 .37713 m .60551 .37588 L .60842 .37447 L F
.82931 .36233 m .83108 .35952 L .83234 .36126 L 0 .027 .126 r
F
.82931 .36233 m .82805 .36059 L .83108 .35952 L F
.30501 .36416 m .30601 .36124 L .30778 .36311 L 0 .031 .131 r
F
.30501 .36416 m .30324 .36227 L .30601 .36124 L F
.83662 .36193 m .83841 .35912 L .83966 .36089 L 0 .026 .125 r
F
.83662 .36193 m .83537 .36019 L .83841 .35912 L F
.40766 .37086 m .40881 .3681 L .41047 .37018 L 0 .047 .149 r
F
.40766 .37086 m .406 .36882 L .40881 .3681 L F
.33871 .36478 m .33975 .362 L .34148 .36394 L 0 .032 .133 r
F
.33871 .36478 m .33698 .36282 L .33975 .362 L F
.58659 .38325 m .58801 .38102 L .5895 .38212 L 0 .084 .183 r
F
.58659 .38325 m .5851 .38216 L .58801 .38102 L F
.37684 .36763 m .37794 .36483 L .37964 .36679 L 0 .039 .14 r
F
.37684 .36763 m .37515 .36566 L .37794 .36483 L F
.89228 .36139 m .89414 .35857 L .89535 .36042 L 0 .025 .124 r
F
.89228 .36139 m .89106 .35954 L .89414 .35857 L F
.49904 .40059 m .50026 .40606 L .50187 .40469 L 0 .177 .244 r
F
.49904 .40059 m .49744 .401 L .50026 .40606 L F
.25223 .36227 m .25315 .35949 L .25496 .36137 L 0 .027 .126 r
F
.25223 .36227 m .25042 .36039 L .25315 .35949 L F
.642 .37038 m .64349 .36768 L .64493 .36918 L 0 .046 .148 r
F
.642 .37038 m .64056 .3689 L .64349 .36768 L F
.27861 .36331 m .27957 .36054 L .28137 .36232 L 0 .029 .129 r
F
.27861 .36331 m .27682 .36151 L .27957 .36054 L F
.77368 .36311 m .77537 .36029 L .77669 .36215 L F
.77368 .36311 m .77236 .36128 L .77537 .36029 L F
.84396 .3617 m .84575 .35885 L .847 .36071 L 0 .026 .125 r
F
.84396 .3617 m .8427 .35985 L .84575 .35885 L F
.89961 .36113 m .90149 .35839 L .90268 .36011 L 0 .025 .124 r
F
.89961 .36113 m .89842 .35941 L .90149 .35839 L F
.31231 .36397 m .31332 .36116 L .31508 .36299 L 0 .031 .131 r
F
.31231 .36397 m .31055 .36213 L .31332 .36116 L F
.41941 .37292 m .42056 .37039 L .42223 .37213 L 0 .053 .155 r
F
.41941 .37292 m .41774 .37121 L .42056 .37039 L F
.36508 .36602 m .36616 .36336 L .36786 .36531 L 0 .036 .137 r
F
.36508 .36602 m .36337 .36411 L .36616 .36336 L F
.3959 .36929 m .39702 .36675 L .3987 .36863 L 0 .044 .146 r
F
.3959 .36929 m .39422 .36745 L .39702 .36675 L F
.18482 .36117 m .18564 .35835 L .18752 .36023 L 0 .025 .124 r
F
.18482 .36117 m .18294 .35929 L .18564 .35835 L F
.4591 .38071 m .46031 .37877 L .46194 .38038 L 0 .077 .177 r
F
.4591 .38071 m .45748 .37909 L .46031 .37877 L F
.28592 .3631 m .28689 .36016 L .28868 .36205 L 0 .029 .129 r
F
.28592 .3631 m .28413 .36124 L .28689 .36016 L F
.63469 .37106 m .63618 .36836 L .63762 .36998 L 0 .048 .15 r
F
.63469 .37106 m .63324 .36944 L .63618 .36836 L F
.56045 .39501 m .56184 .39354 L .56334 .39315 L 0 .132 .217 r
F
.56045 .39501 m .55895 .39585 L .56184 .39354 L F
.22582 .36153 m .2267 .35879 L .22854 .36067 L 0 .026 .125 r
F
.22582 .36153 m .22398 .35965 L .2267 .35879 L F
.44291 .37676 m .44409 .37456 L .44572 .37668 L 0 .065 .167 r
F
.44291 .37676 m .44128 .3747 L .44409 .37456 L F
.8513 .36158 m .8531 .35872 L .85435 .36058 L 0 .026 .125 r
F
.8513 .36158 m .85005 .35972 L .8531 .35872 L F
.59679 .38067 m .59822 .37809 L .59969 .37912 L 0 .076 .176 r
F
.59679 .38067 m .59532 .3797 L .59822 .37809 L F
.31961 .36389 m .32063 .36106 L .32238 .36293 L 0 .031 .131 r
F
.31961 .36389 m .31785 .36202 L .32063 .36106 L F
.78102 .36309 m .78273 .36032 L .78404 .36218 L 0 .029 .129 r
F
.78102 .36309 m .77971 .36123 L .78273 .36032 L F
.50348 .40332 m .50472 .4088 L .50632 .40648 L 0 .191 .252 r
F
.50348 .40332 m .50187 .40469 L .50472 .4088 L F
.25951 .36235 m .26044 .35951 L .26225 .3614 L 0 .028 .127 r
F
.25951 .36235 m .2577 .36047 L .26044 .35951 L F
.85864 .36135 m .86044 .35843 L .86168 .36028 L 0 .026 .125 r
F
.85864 .36135 m .85739 .35951 L .86044 .35843 L F
.38413 .36785 m .38524 .36511 L .38693 .36701 L 0 .04 .142 r
F
.38413 .36785 m .38244 .36595 L .38524 .36511 L F
.1921 .36116 m .19293 .35826 L .19481 .36013 L 0 .025 .124 r
F
.1921 .36116 m .19022 .35928 L .19293 .35826 L F
.72538 .36381 m .72699 .36094 L .72835 .36268 L 0 .031 .131 r
F
.72538 .36381 m .72402 .3621 L .72699 .36094 L F
.34599 .36503 m .34704 .36226 L .34877 .36414 L 0 .034 .135 r
F
.34599 .36503 m .34426 .36313 L .34704 .36226 L F
.61719 .37478 m .61863 .37164 L .6201 .37335 L 0 .057 .16 r
F
.61719 .37478 m .61572 .37311 L .61863 .37164 L F
.79567 .36242 m .7974 .35973 L .79869 .36146 L 0 .028 .128 r
F
.79567 .36242 m .79438 .36072 L .7974 .35973 L F
.86596 .361 m .8678 .35832 L .86902 .36006 L 0 .025 .124 r
F
.86596 .361 m .86474 .35927 L .8678 .35832 L F
.57928 .38437 m .58069 .38195 L .58219 .38327 L 0 .089 .187 r
F
.57928 .38437 m .57779 .3832 L .58069 .38195 L F
.2932 .3631 m .29418 .36034 L .29595 .36227 L 0 .03 .13 r
F
.2932 .3631 m .29143 .36119 L .29418 .36034 L F
.78836 .36291 m .79007 .36007 L .79137 .36182 L 0 .029 .129 r
F
.78836 .36291 m .78706 .36118 L .79007 .36007 L F
.1994 .36089 m .20023 .35814 L .20211 .35992 L 0 .025 .124 r
F
.1994 .36089 m .19752 .35909 L .20023 .35814 L F
.7327 .36353 m .73434 .36078 L .73569 .36259 L 0 .031 .131 r
F
.7327 .36353 m .73134 .36173 L .73434 .36078 L F
.42671 .37308 m .42787 .37054 L .42953 .37234 L 0 .054 .157 r
F
.42671 .37308 m .42505 .37132 L .42787 .37054 L F
.43846 .37496 m .43964 .37264 L .44128 .3747 L 0 .06 .162 r
F
.43846 .37496 m .43682 .37296 L .43964 .37264 L F
.2331 .36157 m .23399 .35879 L .23583 .36059 L 0 .027 .126 r
F
.2331 .36157 m .23126 .35975 L .23399 .35879 L F
.70344 .36527 m .70502 .36229 L .70641 .36419 L 0 .034 .135 r
F
.70344 .36527 m .70205 .36339 L .70502 .36229 L F
.71808 .36446 m .71968 .36161 L .72105 .36329 L 0 .033 .133 r
F
.71808 .36446 m .71671 .36281 L .71968 .36161 L F
.69612 .36569 m .69769 .36266 L .69908 .36449 L 0 .035 .136 r
F
.69612 .36569 m .69473 .36388 L .69769 .36266 L F
.3269 .36389 m .32793 .36097 L .32967 .3629 L 0 .031 .132 r
F
.3269 .36389 m .32515 .36197 L .32793 .36097 L F
.80301 .36226 m .80475 .35955 L .80604 .36131 L 0 .028 .128 r
F
.80301 .36226 m .80172 .36052 L .80475 .35955 L F
.68149 .36653 m .68305 .3639 L .68445 .36553 L 0 .038 .139 r
F
.68149 .36653 m .68009 .36493 L .68305 .3639 L F
.8733 .36085 m .87514 .35806 L .87636 .35981 L 0 .025 .124 r
F
.8733 .36085 m .87209 .35911 L .87514 .35806 L F
.35329 .36492 m .35436 .36204 L .35608 .36386 L 0 .034 .135 r
F
.35329 .36492 m .35156 .36309 L .35436 .36204 L F
.26679 .36231 m .26773 .35951 L .26954 .36138 L 0 .028 .128 r
F
.26679 .36231 m .26499 .36044 L .26773 .35951 L F
.65222 .3682 m .65374 .36556 L .65517 .36717 L 0 .042 .144 r
F
.65222 .3682 m .6508 .36667 L .65374 .36556 L F
.68881 .36622 m .69038 .36339 L .69177 .3651 L 0 .037 .138 r
F
.68881 .36622 m .68742 .36454 L .69038 .36339 L F
.71077 .365 m .71235 .36204 L .71374 .36391 L 0 .034 .135 r
F
.71077 .365 m .70938 .36312 L .71235 .36204 L F
.88063 .36054 m .88248 .35772 L .88369 .35953 L 0 .025 .123 r
F
.88063 .36054 m .87942 .35875 L .88248 .35772 L F
.40319 .36969 m .40433 .3668 L .406 .36882 L 0 .045 .147 r
F
.40319 .36969 m .40151 .36772 L .40433 .3668 L F
.24039 .36139 m .24128 .3587 L .24312 .36047 L 0 .027 .126 r
F
.24039 .36139 m .23856 .35962 L .24128 .3587 L F
.74004 .36342 m .74167 .36047 L .74302 .36232 L 0 .03 .131 r
F
.74004 .36342 m .73868 .36157 L .74167 .36047 L F
.37235 .36647 m .37345 .36368 L .37515 .36566 L 0 .037 .139 r
F
.37235 .36647 m .37065 .3645 L .37345 .36368 L F
.20668 .3608 m .20752 .35814 L .20939 .3599 L 0 .026 .124 r
F
.20668 .3608 m .20481 .35903 L .20752 .35814 L F
.65955 .36792 m .66107 .36512 L .6625 .36693 L 0 .041 .143 r
F
.65955 .36792 m .65812 .36613 L .66107 .36512 L F
.6274 .3722 m .62886 .36899 L .63032 .37076 L 0 .051 .153 r
F
.6274 .3722 m .62594 .37045 L .62886 .36899 L F
.74736 .36307 m .74901 .36026 L .75036 .36211 L 0 .03 .13 r
F
.74736 .36307 m .74601 .36122 L .74901 .36026 L F
.81034 .36206 m .81207 .35911 L .81336 .36097 L 0 .028 .127 r
F
.81034 .36206 m .80905 .36021 L .81207 .35911 L F
.47084 .3834 m .47206 .38227 L .47367 .38395 L 0 .09 .188 r
F
.47084 .3834 m .46923 .3818 L .47206 .38227 L F
.16565 .36067 m .16643 .35789 L .16834 .35966 L 0 .025 .124 r
F
.16565 .36067 m .16374 .35888 L .16643 .35789 L F
.56334 .39315 m .56472 .39113 L .56622 .39111 L 0 .124 .212 r
F
.56334 .39315 m .56184 .39354 L .56472 .39113 L F
.47528 .38573 m .4765 .38462 L .47811 .3864 L 0 .098 .194 r
F
.47528 .38573 m .47367 .38395 L .4765 .38462 L F
.41493 .37173 m .41609 .36907 L .41774 .37121 L 0 .051 .154 r
F
.41493 .37173 m .41328 .36963 L .41609 .36907 L F
.33419 .36382 m .33524 .36085 L .33698 .36282 L 0 .032 .132 r
F
.33419 .36382 m .33246 .36188 L .33524 .36085 L F
.67419 .36728 m .67573 .36434 L .67714 .36609 L 0 .039 .141 r
F
.67419 .36728 m .67278 .36556 L .67573 .36434 L F
.81768 .36181 m .81943 .35894 L .82071 .36082 L 0 .027 .127 r
F
.81768 .36181 m .81639 .35993 L .81943 .35894 L F
.39142 .3681 m .39253 .36561 L .39422 .36745 L 0 .042 .144 r
F
.39142 .3681 m .38973 .36629 L .39253 .36561 L F
.60989 .37582 m .61133 .37305 L .6128 .3745 L 0 .062 .164 r
F
.60989 .37582 m .60842 .37447 L .61133 .37305 L F
.36059 .36486 m .36166 .3622 L .36337 .36411 L 0 .034 .135 r
F
.36059 .36486 m .35887 .36298 L .36166 .3622 L F
.17295 .36041 m .17375 .35764 L .17565 .35941 L 0 .025 .123 r
F
.17295 .36041 m .17104 .35865 L .17375 .35764 L F
.75469 .36286 m .75637 .36019 L .7577 .3619 L 0 .03 .13 r
F
.75469 .36286 m .75336 .36116 L .75637 .36019 L F
.66687 .36774 m .66841 .36494 L .66983 .36674 L 0 .041 .143 r
F
.66687 .36774 m .66545 .36593 L .66841 .36494 L F
.88799 .36045 m .88985 .35769 L .89106 .35954 L 0 .025 .124 r
F
.88799 .36045 m .88677 .35861 L .88985 .35769 L F
.30048 .3633 m .30148 .36035 L .30324 .36227 L 0 .031 .131 r
F
.30048 .3633 m .29871 .36137 L .30148 .36035 L F
.21397 .36067 m .21484 .35784 L .2167 .35962 L 0 .025 .124 r
F
.21397 .36067 m .21211 .35887 L .21484 .35784 L F
.24768 .36131 m .24858 .35863 L .25042 .36039 L 0 .027 .126 r
F
.24768 .36131 m .24585 .35954 L .24858 .35863 L F
.45464 .37959 m .45584 .37747 L .45748 .37909 L 0 .075 .176 r
F
.45464 .37959 m .45301 .37793 L .45584 .37747 L F
.27408 .36236 m .27501 .35972 L .27682 .36151 L 0 .029 .129 r
F
.27408 .36236 m .27227 .36055 L .27501 .35972 L F
.76202 .36257 m .7637 .35986 L .76502 .36156 L 0 .03 .129 r
F
.76202 .36257 m .7607 .36088 L .7637 .35986 L F
.5445 .40442 m .5459 .40922 L .54739 .40348 L 0 .198 .256 r
F
.5445 .40442 m .543 .41016 L .5459 .40922 L F
.47971 .38821 m .48094 .38759 L .48255 .38927 L 0 .109 .202 r
F
.47971 .38821 m .47811 .3864 L .48094 .38759 L F
.5895 .38212 m .59092 .37981 L .59241 .38091 L 0 .083 .182 r
F
.5895 .38212 m .58801 .38102 L .59092 .37981 L F
.82502 .36166 m .82678 .35877 L .82805 .36059 L 0 .027 .127 r
F
.82502 .36166 m .82374 .35983 L .82678 .35877 L F
.18024 .36024 m .18105 .35745 L .18294 .35929 L 0 .025 .123 r
F
.18024 .36024 m .17835 .3584 L .18105 .35745 L F
.83234 .36126 m .83411 .35845 L .83537 .36019 L 0 .027 .126 r
F
.83234 .36126 m .83108 .35952 L .83411 .35845 L F
.59969 .37912 m .60113 .37637 L .6026 .37749 L 0 .073 .173 r
F
.59969 .37912 m .59822 .37809 L .60113 .37637 L F
.64493 .36918 m .64643 .3664 L .64786 .36792 L 0 .045 .147 r
F
.64493 .36918 m .64349 .36768 L .64643 .3664 L F
.76935 .36228 m .77104 .35951 L .77236 .36128 L 0 .029 .129 r
F
.76935 .36228 m .76803 .36054 L .77104 .35951 L F
.30778 .36311 m .30878 .36027 L .31055 .36213 L 0 .031 .131 r
F
.30778 .36311 m .30601 .36124 L .30878 .36027 L F
.83966 .36089 m .84145 .35806 L .8427 .35985 L 0 .026 .125 r
F
.83966 .36089 m .83841 .35912 L .84145 .35806 L F
.22127 .36051 m .22214 .35777 L .22398 .35965 L 0 .025 .124 r
F
.22127 .36051 m .21942 .35863 L .22214 .35777 L F
.434 .37356 m .43518 .371 L .43682 .37296 L 0 .057 .159 r
F
.434 .37356 m .43235 .37167 L .43518 .371 L F
.89535 .36042 m .89721 .35756 L .89842 .35941 L 0 .025 .124 r
F
.89535 .36042 m .89414 .35857 L .89721 .35756 L F
.56622 .39111 m .56761 .38871 L .56911 .38906 L 0 .116 .207 r
F
.56622 .39111 m .56472 .39113 L .56761 .38871 L F
.34148 .36394 m .34253 .36121 L .34426 .36313 L 0 .033 .134 r
F
.34148 .36394 m .33975 .362 L .34253 .36121 L F
.28137 .36232 m .28233 .35948 L .28413 .36124 L 0 .029 .129 r
F
.28137 .36232 m .27957 .36054 L .28233 .35948 L F
.37964 .36679 m .38074 .364 L .38244 .36595 L 0 .039 .141 r
F
.37964 .36679 m .37794 .36483 L .38074 .364 L F
.847 .36071 m .8488 .35786 L .85005 .35972 L 0 .026 .125 r
F
.847 .36071 m .84575 .35885 L .8488 .35786 L F
.77669 .36215 m .77839 .35937 L .77971 .36123 L 0 .029 .129 r
F
.77669 .36215 m .77537 .36029 L .77839 .35937 L F
.46639 .38186 m .46761 .3802 L .46923 .3818 L 0 .085 .183 r
F
.46639 .38186 m .46477 .38029 L .46761 .3802 L F
.25496 .36137 m .25588 .35858 L .2577 .36047 L 0 .027 .127 r
F
.25496 .36137 m .25315 .35949 L .25588 .35858 L F
.6201 .37335 m .62155 .37018 L .62302 .37191 L 0 .055 .158 r
F
.6201 .37335 m .61863 .37164 L .62155 .37018 L F
.31508 .36299 m .31609 .3602 L .31785 .36202 L 0 .031 .131 r
F
.31508 .36299 m .31332 .36116 L .31609 .3602 L F
.28868 .36205 m .28964 .35929 L .29143 .36119 L 0 .029 .129 r
F
.28868 .36205 m .28689 .36016 L .28964 .35929 L F
.63762 .36998 m .63912 .36728 L .64056 .3689 L 0 .047 .15 r
F
.63762 .36998 m .63618 .36836 L .63912 .36728 L F
.41047 .37018 m .41162 .36751 L .41328 .36963 L 0 .048 .151 r
F
.41047 .37018 m .40881 .3681 L .41162 .36751 L F
.18752 .36023 m .18834 .3574 L .19022 .35928 L 0 .025 .124 r
F
.18752 .36023 m .18564 .35835 L .18834 .3574 L F
.48415 .39095 m .48536 .3921 L .48697 .39352 L 0 .126 .213 r
F
.48415 .39095 m .48255 .38927 L .48536 .3921 L F
.42223 .37213 m .42339 .36956 L .42505 .37132 L 0 .054 .156 r
F
.42223 .37213 m .42056 .37039 L .42339 .36956 L F
.51967 .40889 m .52097 .41872 L .52254 .41198 L 0 .241 .277 r
F
.51967 .40889 m .51809 .41412 L .52097 .41872 L F
.85435 .36058 m .85615 .35764 L .85739 .35951 L 0 .026 .125 r
F
.85435 .36058 m .8531 .35872 L .85615 .35764 L F
.36786 .36531 m .36895 .36254 L .37065 .3645 L 0 .036 .138 r
F
.36786 .36531 m .36616 .36336 L .36895 .36254 L F
.72835 .36268 m .72998 .35997 L .73134 .36173 L 0 .031 .131 r
F
.72835 .36268 m .72699 .36094 L .72998 .35997 L F
.22854 .36067 m .22942 .35787 L .23126 .35975 L 0 .026 .125 r
F
.22854 .36067 m .2267 .35879 L .22942 .35787 L F
.86168 .36028 m .8635 .35742 L .86474 .35927 L 0 .025 .124 r
F
.86168 .36028 m .86044 .35843 L .8635 .35742 L F
.32238 .36293 m .3234 .3601 L .32515 .36197 L 0 .031 .131 r
F
.32238 .36293 m .32063 .36106 L .3234 .3601 L F
.3987 .36863 m .39984 .36579 L .40151 .36772 L 0 .044 .147 r
F
.3987 .36863 m .39702 .36675 L .39984 .36579 L F
.58219 .38327 m .5836 .38069 L .5851 .38216 L 0 .088 .186 r
F
.58219 .38327 m .58069 .38195 L .5836 .38069 L F
.19481 .36013 m .19565 .35723 L .19752 .35909 L 0 .025 .124 r
F
.19481 .36013 m .19293 .35826 L .19565 .35723 L F
.78404 .36218 m .78575 .35932 L .78706 .36118 L 0 .029 .129 r
F
.78404 .36218 m .78273 .36032 L .78575 .35932 L F
.26225 .3614 m .26318 .35855 L .26499 .36044 L 0 .028 .127 r
F
.26225 .3614 m .26044 .35951 L .26318 .35855 L F
.79137 .36182 m .79308 .35895 L .79438 .36072 L 0 .029 .129 r
F
.79137 .36182 m .79007 .36007 L .79308 .35895 L F
.63032 .37076 m .63178 .36765 L .63324 .36944 L 0 .049 .152 r
F
.63032 .37076 m .62886 .36899 L .63178 .36765 L F
.69908 .36449 m .70065 .36153 L .70205 .36339 L 0 .034 .135 r
F
.69908 .36449 m .69769 .36266 L .70065 .36153 L F
.56911 .38906 m .5705 .38643 L .572 .38708 L 0 .109 .202 r
F
.56911 .38906 m .56761 .38871 L .5705 .38643 L F
.79869 .36146 m .80043 .35878 L .80172 .36052 L 0 .028 .128 r
F
.79869 .36146 m .7974 .35973 L .80043 .35878 L F
.72105 .36329 m .72265 .36039 L .72402 .3621 L 0 .032 .132 r
F
.72105 .36329 m .71968 .36161 L .72265 .36039 L F
.86902 .36006 m .87087 .35737 L .87209 .35911 L 0 .026 .124 r
F
.86902 .36006 m .8678 .35832 L .87087 .35737 L F
.34877 .36414 m .34983 .36125 L .35156 .36309 L 0 .034 .135 r
F
.34877 .36414 m .34704 .36226 L .34983 .36125 L F
.38693 .36701 m .38804 .3644 L .38973 .36629 L 0 .041 .143 r
F
.38693 .36701 m .38524 .36511 L .38804 .3644 L F
.45018 .37839 m .45138 .37613 L .45301 .37793 L 0 .073 .174 r
F
.45018 .37839 m .44854 .37657 L .45138 .37613 L F
.20211 .35992 m .20294 .35726 L .20481 .35903 L 0 .025 .124 r
F
.20211 .35992 m .20023 .35814 L .20294 .35726 L F
.70641 .36419 m .70799 .36121 L .70938 .36312 L 0 .034 .135 r
F
.70641 .36419 m .70502 .36229 L .70799 .36121 L F
.73569 .36259 m .73733 .35975 L .73868 .36157 L 0 .031 .131 r
F
.73569 .36259 m .73434 .36078 L .73733 .35975 L F
.23583 .36059 m .23672 .35783 L .23856 .35962 L 0 .027 .126 r
F
.23583 .36059 m .23399 .35879 L .23672 .35783 L F
.35608 .36386 m .35715 .36115 L .35887 .36298 L 0 .034 .135 r
F
.35608 .36386 m .35436 .36204 L .35715 .36115 L F
.87636 .35981 m .8782 .35699 L .87942 .35875 L 0 .025 .124 r
F
.87636 .35981 m .87514 .35806 L .8782 .35699 L F
.6026 .37749 m .60404 .37468 L .60551 .37588 L 0 .069 .171 r
F
.6026 .37749 m .60113 .37637 L .60404 .37468 L F
.69177 .3651 m .69333 .36214 L .69473 .36388 L 0 .036 .137 r
F
.69177 .3651 m .69038 .36339 L .69333 .36214 L F
.29595 .36227 m .29694 .35943 L .29871 .36137 L 0 .03 .13 r
F
.29595 .36227 m .29418 .36034 L .29694 .35943 L F
.71374 .36391 m .71533 .36095 L .71671 .36281 L 0 .033 .134 r
F
.71374 .36391 m .71235 .36204 L .71533 .36095 L F
.68445 .36553 m .68602 .36286 L .68742 .36454 L 0 .038 .139 r
F
.68445 .36553 m .68305 .3639 L .68602 .36286 L F
.32967 .3629 m .33072 .35993 L .33246 .36188 L 0 .031 .132 r
F
.32967 .3629 m .32793 .36097 L .33072 .35993 L F
.65517 .36717 m .65669 .36446 L .65812 .36613 L 0 .041 .144 r
F
.65517 .36717 m .65374 .36556 L .65669 .36446 L F
.46194 .38038 m .46314 .37866 L .46477 .38029 L 0 .081 .181 r
F
.46194 .38038 m .46031 .37877 L .46314 .37866 L F
.16105 .35987 m .16183 .35704 L .16374 .35888 L 0 .025 .124 r
F
.16105 .35987 m .15914 .35801 L .16183 .35704 L F
.6128 .3745 m .61425 .37158 L .61572 .37311 L 0 .06 .163 r
F
.6128 .3745 m .61133 .37305 L .61425 .37158 L F
.74302 .36232 m .74466 .35937 L .74601 .36122 L 0 .03 .13 r
F
.74302 .36232 m .74167 .36047 L .74466 .35937 L F
.80604 .36131 m .80777 .35843 L .80905 .36021 L 0 .028 .128 r
F
.80604 .36131 m .80475 .35955 L .80777 .35843 L F
.88369 .35953 m .88556 .35679 L .88677 .35861 L 0 .025 .123 r
F
.88369 .35953 m .88248 .35772 L .88556 .35679 L F
.42953 .37234 m .4307 .3698 L .43235 .37167 L 0 .055 .158 r
F
.42953 .37234 m .42787 .37054 L .4307 .3698 L F
.26954 .36138 m .27047 .35869 L .27227 .36055 L 0 .029 .128 r
F
.26954 .36138 m .26773 .35951 L .27047 .35869 L F
.81336 .36097 m .8151 .35806 L .81639 .35993 L 0 .027 .127 r
F
.81336 .36097 m .81207 .35911 L .8151 .35806 L F
.67714 .36609 m .67868 .36316 L .68009 .36493 L 0 .039 .14 r
F
.67714 .36609 m .67573 .36434 L .67868 .36316 L F
.6625 .36693 m .66402 .36413 L .66545 .36593 L 0 .041 .143 r
F
.6625 .36693 m .66107 .36512 L .66402 .36413 L F
.24312 .36047 m .24402 .35779 L .24585 .35954 L 0 .027 .126 r
F
.24312 .36047 m .24128 .3587 L .24402 .35779 L F
.16834 .35966 m .16913 .35689 L .17104 .35865 L 0 .025 .124 r
F
.16834 .35966 m .16643 .35789 L .16913 .35689 L F
.75036 .36211 m .75202 .35931 L .75336 .36116 L 0 .03 .13 r
F
.75036 .36211 m .74901 .36026 L .75202 .35931 L F
.406 .36882 m .40714 .36604 L .40881 .3681 L 0 .046 .148 r
F
.406 .36882 m .40433 .3668 L .40714 .36604 L F
.20939 .3599 m .21024 .35713 L .21211 .35887 L 0 .026 .124 r
F
.20939 .3599 m .20752 .35814 L .21024 .35713 L F
.37515 .36566 m .37625 .36286 L .37794 .36483 L 0 .038 .14 r
F
.37515 .36566 m .37345 .36368 L .37625 .36286 L F
.33698 .36282 m .33802 .36004 L .33975 .362 L 0 .032 .132 r
F
.33698 .36282 m .33524 .36085 L .33802 .36004 L F
.59241 .38091 m .59384 .37861 L .59532 .3797 L 0 .082 .181 r
F
.59241 .38091 m .59092 .37981 L .59384 .37861 L F
.64786 .36792 m .64937 .36513 L .6508 .36667 L 0 .044 .146 r
F
.64786 .36792 m .64643 .3664 L .64937 .36513 L F
.82071 .36082 m .82246 .35794 L .82374 .35983 L 0 .027 .127 r
F
.82071 .36082 m .81943 .35894 L .82246 .35794 L F
.53431 .40895 m .53568 .41715 L .5372 .40998 L 0 .238 .276 r
F
.53431 .40895 m .53278 .41517 L .53568 .41715 L F
.17565 .35941 m .17645 .35663 L .17835 .3584 L 0 .025 .123 r
F
.17565 .35941 m .17375 .35764 L .17645 .35663 L F
.44572 .37668 m .44692 .3744 L .44854 .37657 L 0 .069 .17 r
F
.44572 .37668 m .44409 .37456 L .44692 .3744 L F
.2167 .35962 m .21756 .35685 L .21942 .35863 L 0 .025 .124 r
F
.2167 .35962 m .21484 .35784 L .21756 .35685 L F
.66983 .36674 m .67136 .36374 L .67278 .36556 L 0 .04 .142 r
F
.66983 .36674 m .66841 .36494 L .67136 .36374 L F
.30324 .36227 m .30425 .35933 L .30601 .36124 L 0 .03 .131 r
F
.30324 .36227 m .30148 .36035 L .30425 .35933 L F
.572 .38708 m .57339 .38422 L .57489 .38513 L 0 .102 .197 r
F
.572 .38708 m .5705 .38643 L .57339 .38422 L F
.7577 .3619 m .75937 .35917 L .7607 .36088 L 0 .03 .13 r
F
.7577 .3619 m .75637 .36019 L .75937 .35917 L F
.62302 .37191 m .62447 .36869 L .62594 .37045 L 0 .053 .156 r
F
.62302 .37191 m .62155 .37018 L .62447 .36869 L F
.76502 .36156 m .76671 .35882 L .76803 .36054 L 0 .029 .129 r
F
.76502 .36156 m .7637 .35986 L .76671 .35882 L F
.89106 .35954 m .89293 .35672 L .89414 .35857 L 0 .025 .124 r
F
.89106 .35954 m .88985 .35769 L .89293 .35672 L F
.25042 .36039 m .25132 .35774 L .25315 .35949 L 0 .027 .126 r
F
.25042 .36039 m .24858 .35863 L .25132 .35774 L F
.82805 .36059 m .82981 .3577 L .83108 .35952 L F
.82805 .36059 m .82678 .35877 L .82981 .3577 L F
.83537 .36019 m .83715 .35735 L .83841 .35912 L 0 .026 .126 r
F
.83537 .36019 m .83411 .35845 L .83715 .35735 L F
.54739 .40348 m .5488 .40725 L .55028 .40191 L 0 .195 .254 r
F
.54739 .40348 m .5459 .40922 L .5488 .40725 L F
.36337 .36411 m .36445 .36141 L .36616 .36336 L 0 .035 .136 r
F
.36337 .36411 m .36166 .3622 L .36445 .36141 L F
.8427 .35985 m .84449 .35704 L .84575 .35885 L 0 .026 .125 r
F
.8427 .35985 m .84145 .35806 L .84449 .35704 L F
.77236 .36128 m .77405 .35849 L .77537 .36029 L 0 .029 .129 r
F
.77236 .36128 m .77104 .35951 L .77405 .35849 L F
.44128 .3747 m .44246 .37244 L .44409 .37456 L 0 .063 .165 r
F
.44128 .3747 m .43964 .37264 L .44246 .37244 L F
.27682 .36151 m .27777 .35876 L .27957 .36054 L 0 .029 .129 r
F
.27682 .36151 m .27501 .35972 L .27777 .35876 L F
.31055 .36213 m .31155 .35933 L .31332 .36116 L 0 .031 .131 r
F
.31055 .36213 m .30878 .36027 L .31155 .35933 L F
.18294 .35929 m .18375 .35651 L .18564 .35835 L 0 .025 .123 r
F
.18294 .35929 m .18105 .35745 L .18375 .35651 L F
.39422 .36745 m .39534 .36487 L .39702 .36675 L 0 .043 .146 r
F
.39422 .36745 m .39253 .36561 L .39534 .36487 L F
.48857 .39453 m .48979 .3961 L .4914 .39665 L 0 .145 .225 r
F
.48857 .39453 m .48697 .39352 L .48979 .3961 L F
.89842 .35941 m .90029 .35655 L .90149 .35839 L 0 .025 .124 r
F
.89842 .35941 m .89721 .35756 L .90029 .35655 L F
.28413 .36124 m .2851 .35841 L .28689 .36016 L 0 .029 .129 r
F
.28413 .36124 m .28233 .35948 L .2851 .35841 L F
.41774 .37121 m .41891 .36827 L .42056 .37039 L 0 .052 .155 r
F
.41774 .37121 m .41609 .36907 L .41891 .36827 L F
.22398 .35965 m .22485 .3569 L .2267 .35879 L 0 .026 .125 r
F
.22398 .35965 m .22214 .35777 L .22485 .3569 L F
.85005 .35972 m .85185 .35686 L .8531 .35872 L F
.85005 .35972 m .8488 .35786 L .85185 .35686 L F
.64056 .3689 m .64205 .36606 L .64349 .36768 L 0 .047 .149 r
F
.64056 .3689 m .63912 .36728 L .64205 .36606 L F
.31785 .36202 m .31886 .35927 L .32063 .36106 L 0 .031 .131 r
F
.31785 .36202 m .31609 .3602 L .31886 .35927 L F
.45748 .37909 m .45868 .37715 L .46031 .37877 L 0 .078 .178 r
F
.45748 .37909 m .45584 .37747 L .45868 .37715 L F
.77971 .36123 m .78141 .35845 L .78273 .36032 L 0 .029 .129 r
F
.77971 .36123 m .77839 .35937 L .78141 .35845 L F
.60551 .37588 m .60695 .37316 L .60842 .37447 L 0 .066 .168 r
F
.60551 .37588 m .60404 .37468 L .60695 .37316 L F
.38244 .36595 m .38355 .36316 L .38524 .36511 L 0 .04 .142 r
F
.38244 .36595 m .38074 .364 L .38355 .36316 L F
.2577 .36047 m .25863 .35762 L .26044 .35951 L 0 .028 .127 r
F
.2577 .36047 m .25588 .35858 L .25863 .35762 L F
.34426 .36313 m .34531 .36038 L .34704 .36226 L 0 .033 .134 r
F
.34426 .36313 m .34253 .36121 L .34531 .36038 L F
.19022 .35928 m .19106 .35639 L .19293 .35826 L 0 .025 .124 r
F
.19022 .35928 m .18834 .3574 L .19106 .35639 L F
.63324 .36944 m .63472 .36657 L .63618 .36836 L 0 .048 .151 r
F
.63324 .36944 m .63178 .36765 L .63472 .36657 L F
.85739 .35951 m .8592 .35656 L .86044 .35843 L 0 .026 .124 r
F
.85739 .35951 m .85615 .35764 L .8592 .35656 L F
.49301 .39712 m .49422 .40169 L .49583 .40136 L 0 .167 .239 r
F
.49301 .39712 m .4914 .39665 L .49422 .40169 L F
.57489 .38513 m .57628 .38203 L .57779 .3832 L 0 .096 .192 r
F
.57489 .38513 m .57339 .38422 L .57628 .38203 L F
.43682 .37296 m .438 .37061 L .43964 .37264 L 0 .059 .161 r
F
.43682 .37296 m .43518 .371 L .438 .37061 L F
.29143 .36119 m .2924 .35842 L .29418 .36034 L 0 .029 .129 r
F
.29143 .36119 m .28964 .35929 L .2924 .35842 L F
.5851 .38216 m .58651 .37946 L .58801 .38102 L 0 .087 .185 r
F
.5851 .38216 m .5836 .38069 L .58651 .37946 L F
.72402 .3621 m .72563 .35919 L .72699 .36094 L 0 .031 .132 r
F
.72402 .3621 m .72265 .36039 L .72563 .35919 L F
.86474 .35927 m .86656 .35648 L .8678 .35832 L 0 .025 .124 r
F
.86474 .35927 m .8635 .35742 L .86656 .35648 L F
.61572 .37311 m .61717 .37007 L .61863 .37164 L 0 .058 .16 r
F
.61572 .37311 m .61425 .37158 L .61717 .37007 L F
.73134 .36173 m .73298 .35901 L .73434 .36078 L 0 .031 .131 r
F
.73134 .36173 m .72998 .35997 L .73298 .35901 L F
.79438 .36072 m .7961 .35795 L .7974 .35973 L 0 .028 .128 r
F
.79438 .36072 m .79308 .35895 L .7961 .35795 L F
.19752 .35909 m .19836 .35629 L .20023 .35814 L 0 .025 .124 r
F
.19752 .35909 m .19565 .35723 L .19836 .35629 L F
.32515 .36197 m .32618 .35909 L .32793 .36097 L 0 .031 .131 r
F
.32515 .36197 m .3234 .3601 L .32618 .35909 L F
.70205 .36339 m .70362 .36041 L .70502 .36229 L 0 .034 .135 r
F
.70205 .36339 m .70065 .36153 L .70362 .36041 L F
.42505 .37132 m .42622 .36873 L .42787 .37054 L 0 .054 .157 r
F
.42505 .37132 m .42339 .36956 L .42622 .36873 L F
.23126 .35975 m .23215 .35693 L .23399 .35879 L 0 .026 .126 r
F
.23126 .35975 m .22942 .35787 L .23215 .35693 L F
.78706 .36118 m .78876 .3582 L .79007 .36007 L 0 .029 .129 r
F
.78706 .36118 m .78575 .35932 L .78876 .3582 L F
.40151 .36772 m .40266 .36482 L .40433 .3668 L 0 .044 .147 r
F
.40151 .36772 m .39984 .36579 L .40266 .36482 L F
.69473 .36388 m .69629 .36089 L .69769 .36266 L 0 .035 .136 r
F
.69473 .36388 m .69333 .36214 L .69629 .36089 L F
.37065 .3645 m .37175 .36171 L .37345 .36368 L 0 .037 .138 r
F
.37065 .3645 m .36895 .36254 L .37175 .36171 L F
.26499 .36044 m .26593 .35761 L .26773 .35951 L 0 .028 .128 r
F
.26499 .36044 m .26318 .35855 L .26593 .35761 L F
.35156 .36309 m .35263 .36023 L .35436 .36204 L 0 .034 .134 r
F
.35156 .36309 m .34983 .36125 L .35263 .36023 L F
.70938 .36312 m .71097 .36014 L .71235 .36204 L 0 .033 .134 r
F
.70938 .36312 m .70799 .36121 L .71097 .36014 L F
.41328 .36963 m .41443 .36693 L .41609 .36907 L 0 .05 .152 r
F
.41328 .36963 m .41162 .36751 L .41443 .36693 L F
.80172 .36052 m .80346 .35779 L .80475 .35955 L 0 .028 .128 r
F
.80172 .36052 m .80043 .35878 L .80346 .35779 L F
.87209 .35911 m .87392 .3563 L .87514 .35806 L 0 .025 .124 r
F
.87209 .35911 m .87087 .35737 L .87392 .3563 L F
.73868 .36157 m .74032 .35864 L .74167 .36047 L 0 .03 .13 r
F
.73868 .36157 m .73733 .35975 L .74032 .35864 L F
.71671 .36281 m .7183 .35977 L .71968 .36161 L 0 .033 .134 r
F
.71671 .36281 m .71533 .36095 L .7183 .35977 L F
.87942 .35875 m .88127 .35595 L .88248 .35772 L 0 .025 .123 r
F
.87942 .35875 m .8782 .35699 L .88127 .35595 L F
.74601 .36122 m .74766 .3584 L .74901 .36026 L 0 .03 .13 r
F
.74601 .36122 m .74466 .35937 L .74766 .3584 L F
.80905 .36021 m .81079 .3573 L .81207 .35911 L 0 .028 .127 r
F
.80905 .36021 m .80777 .35843 L .81079 .3573 L F
.23856 .35962 m .23944 .35692 L .24128 .3587 L 0 .027 .126 r
F
.23856 .35962 m .23672 .35783 L .23944 .35692 L F
.65812 .36613 m .65964 .36339 L .66107 .36512 L 0 .041 .143 r
F
.65812 .36613 m .65669 .36446 L .65964 .36339 L F
.20481 .35903 m .20564 .35638 L .20752 .35814 L 0 .026 .124 r
F
.20481 .35903 m .20294 .35726 L .20564 .35638 L F
.33246 .36188 m .33351 .35889 L .33524 .36085 L 0 .031 .131 r
F
.33246 .36188 m .33072 .35993 L .33351 .35889 L F
.55028 .40191 m .5517 .40528 L .55318 .40033 L 0 .189 .251 r
F
.55028 .40191 m .5488 .40725 L .5517 .40528 L F
.68009 .36493 m .68164 .36212 L .68305 .3639 L 0 .038 .14 r
F
.68009 .36493 m .67868 .36316 L .68164 .36212 L F
.68742 .36454 m .68898 .36168 L .69038 .36339 L 0 .037 .139 r
F
.68742 .36454 m .68602 .36286 L .68898 .36168 L F
.62594 .37045 m .62739 .3672 L .62886 .36899 L 0 .051 .154 r
F
.62594 .37045 m .62447 .36869 L .62739 .3672 L F
.16374 .35888 m .16453 .35607 L .16643 .35789 L 0 .025 .124 r
F
.16374 .35888 m .16183 .35704 L .16453 .35607 L F
.35887 .36298 m .35994 .36036 L .36166 .3622 L 0 .034 .135 r
F
.35887 .36298 m .35715 .36115 L .35994 .36036 L F
.81639 .35993 m .81814 .35706 L .81943 .35894 L 0 .027 .127 r
F
.81639 .35993 m .8151 .35806 L .81814 .35706 L F
.29871 .36137 m .29971 .35841 L .30148 .36035 L 0 .03 .13 r
F
.29871 .36137 m .29694 .35943 L .29971 .35841 L F
.6508 .36667 m .65231 .36396 L .65374 .36556 L 0 .043 .145 r
F
.6508 .36667 m .64937 .36513 L .65231 .36396 L F
.47367 .38395 m .47489 .38286 L .4765 .38462 L 0 .098 .194 r
F
.47367 .38395 m .47206 .38227 L .47489 .38286 L F
.59532 .3797 m .59675 .37695 L .59822 .37809 L 0 .08 .179 r
F
.59532 .3797 m .59384 .37861 L .59675 .37695 L F
.38973 .36629 m .39084 .36372 L .39253 .36561 L 0 .042 .144 r
F
.38973 .36629 m .38804 .3644 L .39084 .36372 L F
.88677 .35861 m .88864 .35586 L .88985 .35769 L 0 .025 .123 r
F
.88677 .35861 m .88556 .35679 L .88864 .35586 L F
.57779 .3832 m .57919 .38062 L .58069 .38195 L 0 .092 .189 r
F
.57779 .3832 m .57628 .38203 L .57919 .38062 L F
.66545 .36593 m .66698 .36313 L .66841 .36494 L 0 .041 .143 r
F
.66545 .36593 m .66402 .36413 L .66698 .36313 L F
.52699 .41085 m .52833 .41824 L .52988 .41301 L 0 .25 .282 r
F
.52699 .41085 m .52543 .41508 L .52833 .41824 L F
.46923 .3818 m .47044 .3806 L .47206 .38227 L 0 .091 .188 r
F
.46923 .3818 m .46761 .3802 L .47044 .3806 L F
.67278 .36556 m .67431 .36251 L .67573 .36434 L 0 .039 .141 r
F
.67278 .36556 m .67136 .36374 L .67431 .36251 L F
.17104 .35865 m .17184 .35588 L .17375 .35764 L 0 .025 .124 r
F
.17104 .35865 m .16913 .35689 L .17184 .35588 L F
.21211 .35887 m .21297 .3561 L .21484 .35784 L F
.21211 .35887 m .21024 .35713 L .21297 .3561 L F
.27227 .36055 m .27321 .35787 L .27501 .35972 L 0 .029 .129 r
F
.27227 .36055 m .27047 .35869 L .27321 .35787 L F
.75336 .36116 m .75502 .35834 L .75637 .36019 L 0 .03 .13 r
F
.75336 .36116 m .75202 .35931 L .75502 .35834 L F
.24585 .35954 m .24675 .35689 L .24858 .35863 L 0 .027 .126 r
F
.24585 .35954 m .24402 .35779 L .24675 .35689 L F
.47811 .3864 m .47933 .38581 L .48094 .38759 L 0 .109 .202 r
F
.47811 .3864 m .4765 .38462 L .47933 .38581 L F
.17835 .3584 m .17915 .35569 L .18105 .35745 L 0 .025 .123 r
F
.17835 .3584 m .17645 .35663 L .17915 .35569 L F
.30601 .36124 m .30702 .35837 L .30878 .36027 L 0 .03 .13 r
F
.30601 .36124 m .30425 .35933 L .30702 .35837 L F
.82374 .35983 m .8255 .35689 L .82678 .35877 L 0 .027 .127 r
F
.82374 .35983 m .82246 .35794 L .8255 .35689 L F
.45301 .37793 m .45421 .37568 L .45584 .37747 L 0 .076 .176 r
F
.45301 .37793 m .45138 .37613 L .45421 .37568 L F
.21942 .35863 m .22028 .35598 L .22214 .35777 L 0 .025 .124 r
F
.21942 .35863 m .21756 .35685 L .22028 .35598 L F
.7607 .36088 m .76238 .35815 L .7637 .35986 L 0 .03 .13 r
F
.7607 .36088 m .75937 .35917 L .76238 .35815 L F
.43235 .37167 m .43353 .36906 L .43518 .371 L 0 .056 .159 r
F
.43235 .37167 m .4307 .3698 L .43353 .36906 L F
.83108 .35952 m .83285 .35663 L .83411 .35845 L 0 .027 .126 r
F
.83108 .35952 m .82981 .3577 L .83285 .35663 L F
.76803 .36054 m .76971 .35775 L .77104 .35951 L 0 .029 .129 r
F
.76803 .36054 m .76671 .35882 L .76971 .35775 L F
.83841 .35912 m .84019 .35626 L .84145 .35806 L 0 .026 .125 r
F
.83841 .35912 m .83715 .35735 L .84019 .35626 L F
.37794 .36483 m .37905 .36203 L .38074 .364 L 0 .039 .14 r
F
.37794 .36483 m .37625 .36286 L .37905 .36203 L F
.33975 .362 m .3408 .35925 L .34253 .36121 L 0 .032 .133 r
F
.33975 .362 m .33802 .36004 L .3408 .35925 L F
.40881 .3681 m .40996 .36541 L .41162 .36751 L 0 .047 .149 r
F
.40881 .3681 m .40714 .36604 L .40996 .36541 L F
.89414 .35857 m .89601 .35572 L .89721 .35756 L 0 .025 .124 r
F
.89414 .35857 m .89293 .35672 L .89601 .35572 L F
.60842 .37447 m .60986 .37164 L .61133 .37305 L 0 .064 .166 r
F
.60842 .37447 m .60695 .37316 L .60986 .37164 L F
.84575 .35885 m .84755 .35605 L .8488 .35786 L 0 .026 .125 r
F
.84575 .35885 m .84449 .35704 L .84755 .35605 L F
.77537 .36029 m .77707 .35755 L .77839 .35937 L 0 .029 .129 r
F
.77537 .36029 m .77405 .35849 L .77707 .35755 L F
.25315 .35949 m .25405 .35685 L .25588 .35858 L 0 .027 .127 r
F
.25315 .35949 m .25132 .35774 L .25405 .35685 L F
.27957 .36054 m .28053 .35771 L .28233 .35948 L 0 .029 .129 r
F
.27957 .36054 m .27777 .35876 L .28053 .35771 L F
.31332 .36116 m .31433 .35838 L .31609 .3602 L 0 .031 .131 r
F
.31332 .36116 m .31155 .35933 L .31433 .35838 L F
.64349 .36768 m .64499 .36479 L .64643 .3664 L 0 .046 .148 r
F
.64349 .36768 m .64205 .36606 L .64499 .36479 L F
.28689 .36016 m .28785 .35754 L .28964 .35929 L 0 .029 .129 r
F
.28689 .36016 m .2851 .35841 L .28785 .35754 L F
.18564 .35835 m .18646 .35557 L .18834 .3574 L 0 .025 .124 r
F
.18564 .35835 m .18375 .35651 L .18646 .35557 L F
.61863 .37164 m .62009 .36856 L .62155 .37018 L 0 .056 .158 r
F
.61863 .37164 m .61717 .37007 L .62009 .36856 L F
.36616 .36336 m .36724 .36058 L .36895 .36254 L 0 .036 .137 r
F
.36616 .36336 m .36445 .36141 L .36724 .36058 L F
.8531 .35872 m .8549 .35578 L .85615 .35764 L 0 .026 .124 r
F
.8531 .35872 m .85185 .35686 L .8549 .35578 L F
.46477 .38029 m .46598 .37855 L .46761 .3802 L 0 .086 .184 r
F
.46477 .38029 m .46314 .37866 L .46598 .37855 L F
.48255 .38927 m .48375 .39068 L .48536 .3921 L 0 .127 .214 r
F
.48255 .38927 m .48094 .38759 L .48375 .39068 L F
.2267 .35879 m .22757 .356 L .22942 .35787 L 0 .026 .125 r
F
.2267 .35879 m .22485 .3569 L .22757 .356 L F
.63618 .36836 m .63766 .3655 L .63912 .36728 L 0 .048 .15 r
F
.63618 .36836 m .63472 .36657 L .63766 .3655 L F
.42056 .37039 m .42174 .36746 L .42339 .36956 L 0 .053 .155 r
F
.42056 .37039 m .41891 .36827 L .42174 .36746 L F
.32063 .36106 m .32164 .35833 L .3234 .3601 L 0 .031 .131 r
F
.32063 .36106 m .31886 .35927 L .32164 .35833 L F
.39702 .36675 m .39816 .36385 L .39984 .36579 L 0 .044 .146 r
F
.39702 .36675 m .39534 .36487 L .39816 .36385 L F
.86044 .35843 m .86225 .35555 L .8635 .35742 L 0 .025 .124 r
F
.86044 .35843 m .8592 .35656 L .86225 .35555 L F
.58801 .38102 m .58943 .37826 L .59092 .37981 L 0 .085 .184 r
F
.58801 .38102 m .58651 .37946 L .58943 .37826 L F
.55318 .40033 m .55458 .40234 L .55606 .39813 L 0 .18 .246 r
F
.55318 .40033 m .5517 .40528 L .55458 .40234 L F
.19293 .35826 m .19377 .35537 L .19565 .35723 L 0 .025 .124 r
F
.19293 .35826 m .19106 .35639 L .19377 .35537 L F
.78273 .36032 m .78443 .35745 L .78575 .35932 L 0 .029 .129 r
F
.78273 .36032 m .78141 .35845 L .78443 .35745 L F
.26044 .35951 m .26137 .35665 L .26318 .35855 L 0 .028 .127 r
F
.26044 .35951 m .25863 .35762 L .26137 .35665 L F
.72699 .36094 m .72862 .35821 L .72998 .35997 L 0 .031 .131 r
F
.72699 .36094 m .72563 .35919 L .72862 .35821 L F
.49744 .401 m .49865 .40741 L .50026 .40606 L 0 .197 .255 r
F
.49744 .401 m .49583 .40136 L .49865 .40741 L F
.59822 .37809 m .59965 .37516 L .60113 .37637 L 0 .076 .176 r
F
.59822 .37809 m .59675 .37695 L .59965 .37516 L F
.69769 .36266 m .69926 .35972 L .70065 .36153 L 0 .034 .135 r
F
.69769 .36266 m .69629 .36089 L .69926 .35972 L F
.34704 .36226 m .3481 .3594 L .34983 .36125 L 0 .033 .134 r
F
.34704 .36226 m .34531 .36038 L .3481 .3594 L F
.38524 .36511 m .38635 .36247 L .38804 .3644 L 0 .04 .142 r
F
.38524 .36511 m .38355 .36316 L .38635 .36247 L F
.62886 .36899 m .63032 .36585 L .63178 .36765 L 0 .049 .152 r
F
.62886 .36899 m .62739 .3672 L .63032 .36585 L F
.70502 .36229 m .7066 .35931 L .70799 .36121 L 0 .033 .134 r
F
.70502 .36229 m .70362 .36041 L .7066 .35931 L F
.79007 .36007 m .79177 .35709 L .79308 .35895 L 0 .029 .128 r
F
.79007 .36007 m .78876 .3582 L .79177 .35709 L F
.44854 .37657 m .44975 .37393 L .45138 .37613 L 0 .072 .173 r
F
.44854 .37657 m .44692 .3744 L .44975 .37393 L F
.29418 .36034 m .29516 .3575 L .29694 .35943 L 0 .03 .13 r
F
.29418 .36034 m .2924 .35842 L .29516 .3575 L F
.7974 .35973 m .79914 .35699 L .80043 .35878 L 0 .028 .128 r
F
.7974 .35973 m .7961 .35795 L .79914 .35699 L F
.8678 .35832 m .86963 .35553 L .87087 .35737 L 0 .026 .124 r
F
.8678 .35832 m .86656 .35648 L .86963 .35553 L F
.32793 .36097 m .32897 .35804 L .33072 .35993 L 0 .031 .131 r
F
.32793 .36097 m .32618 .35909 L .32897 .35804 L F
.73434 .36078 m .73597 .35796 L .73733 .35975 L F
.73434 .36078 m .73298 .35901 L .73597 .35796 L F
.20023 .35814 m .20106 .35542 L .20294 .35726 L 0 .025 .124 r
F
.20023 .35814 m .19836 .35629 L .20106 .35542 L F
.51522 .41018 m .51649 .41945 L .51809 .41412 L 0 .257 .285 r
F
.51522 .41018 m .51362 .41417 L .51649 .41945 L F
.71968 .36161 m .72128 .35856 L .72265 .36039 L 0 .032 .133 r
F
.71968 .36161 m .7183 .35977 L .72128 .35856 L F
.71235 .36204 m .71395 .35908 L .71533 .36095 L 0 .033 .134 r
F
.71235 .36204 m .71097 .36014 L .71395 .35908 L F
.23399 .35879 m .23488 .35599 L .23672 .35783 L 0 .027 .126 r
F
.23399 .35879 m .23215 .35693 L .23488 .35599 L F
.35436 .36204 m .35542 .35937 L .35715 .36115 L 0 .034 .135 r
F
.35436 .36204 m .35263 .36023 L .35542 .35937 L F
.15914 .35801 m .15992 .35518 L .16183 .35704 L 0 .025 .124 r
F
.15914 .35801 m .15723 .35613 L .15992 .35518 L F
.74167 .36047 m .74331 .35754 L .74466 .35937 L 0 .03 .13 r
F
.74167 .36047 m .74032 .35864 L .74331 .35754 L F
.87514 .35806 m .87698 .35522 L .8782 .35699 L 0 .025 .124 r
F
.87514 .35806 m .87392 .3563 L .87698 .35522 L F
.40433 .3668 m .40547 .364 L .40714 .36604 L 0 .045 .147 r
F
.40433 .3668 m .40266 .36482 L .40547 .364 L F
.55606 .39813 m .55747 .39926 L .55895 .39585 L 0 .168 .239 r
F
.55606 .39813 m .55458 .40234 L .55747 .39926 L F
.26773 .35951 m .26867 .35679 L .27047 .35869 L 0 .028 .128 r
F
.26773 .35951 m .26593 .35761 L .26867 .35679 L F
.81207 .35911 m .81382 .35623 L .8151 .35806 L 0 .027 .127 r
F
.81207 .35911 m .81079 .3573 L .81382 .35623 L F
.44409 .37456 m .44529 .37222 L .44692 .3744 L 0 .067 .169 r
F
.44409 .37456 m .44246 .37244 L .44529 .37222 L F
.69038 .36339 m .69194 .3604 L .69333 .36214 L 0 .036 .138 r
F
.69038 .36339 m .68898 .36168 L .69194 .3604 L F
.88248 .35772 m .88434 .355 L .88556 .35679 L 0 .025 .123 r
F
.88248 .35772 m .88127 .35595 L .88434 .355 L F
.80475 .35955 m .80648 .35664 L .80777 .35843 L 0 .028 .128 r
F
.80475 .35955 m .80346 .35779 L .80648 .35664 L F
.42787 .37054 m .42905 .36792 L .4307 .3698 L 0 .055 .157 r
F
.42787 .37054 m .42622 .36873 L .42905 .36792 L F
.58069 .38195 m .5821 .37921 L .5836 .38069 L 0 .09 .188 r
F
.58069 .38195 m .57919 .38062 L .5821 .37921 L F
.37345 .36368 m .37455 .36088 L .37625 .36286 L 0 .037 .139 r
F
.37345 .36368 m .37175 .36171 L .37455 .36088 L F
.68305 .3639 m .68461 .36107 L .68602 .36286 L 0 .038 .14 r
F
.68305 .3639 m .68164 .36212 L .68461 .36107 L F
.66107 .36512 m .6626 .36237 L .66402 .36413 L 0 .041 .143 r
F
.66107 .36512 m .65964 .36339 L .6626 .36237 L F
.33524 .36085 m .33628 .35807 L .33802 .36004 L 0 .031 .132 r
F
.33524 .36085 m .33351 .35889 L .33628 .35807 L F
.74901 .36026 m .75067 .35745 L .75202 .35931 L 0 .03 .13 r
F
.74901 .36026 m .74766 .3584 L .75067 .35745 L F
.46031 .37877 m .46152 .37702 L .46314 .37866 L 0 .082 .181 r
F
.46031 .37877 m .45868 .37715 L .46152 .37702 L F
.67573 .36434 m .67726 .36131 L .67868 .36316 L 0 .039 .14 r
F
.67573 .36434 m .67431 .36251 L .67726 .36131 L F
.65374 .36556 m .65526 .36278 L .65669 .36446 L 0 .042 .144 r
F
.65374 .36556 m .65231 .36396 L .65526 .36278 L F
.24128 .3587 m .24218 .35602 L .24402 .35779 L 0 .027 .126 r
F
.24128 .3587 m .23944 .35692 L .24218 .35602 L F
.16643 .35789 m .16723 .35508 L .16913 .35689 L 0 .025 .124 r
F
.16643 .35789 m .16453 .35607 L .16723 .35508 L F
.30148 .36035 m .30248 .35739 L .30425 .35933 L 0 .03 .13 r
F
.30148 .36035 m .29971 .35841 L .30248 .35739 L F
.81943 .35894 m .82118 .35605 L .82246 .35794 L 0 .027 .126 r
F
.81943 .35894 m .81814 .35706 L .82118 .35605 L F
.20752 .35814 m .20837 .35538 L .21024 .35713 L 0 .026 .125 r
F
.20752 .35814 m .20564 .35638 L .20837 .35538 L F
.43964 .37264 m .44082 .37035 L .44246 .37244 L 0 .062 .164 r
F
.43964 .37264 m .438 .37061 L .44082 .37035 L F
.61133 .37305 m .61278 .37009 L .61425 .37158 L F
.61133 .37305 m .60986 .37164 L .61278 .37009 L F
.66841 .36494 m .66993 .36192 L .67136 .36374 L 0 .04 .142 r
F
.66841 .36494 m .66698 .36313 L .66993 .36192 L F
.21484 .35784 m .21569 .35512 L .21756 .35685 L 0 .025 .124 r
F
.21484 .35784 m .21297 .3561 L .21569 .35512 L F
.55895 .39585 m .56036 .39617 L .56184 .39354 L 0 .155 .232 r
F
.55895 .39585 m .55747 .39926 L .56036 .39617 L F
.17375 .35764 m .17454 .35486 L .17645 .35663 L 0 .025 .123 r
F
.17375 .35764 m .17184 .35588 L .17454 .35486 L F
.41609 .36907 m .41725 .36615 L .41891 .36827 L 0 .051 .153 r
F
.41609 .36907 m .41443 .36693 L .41725 .36615 L F
.88985 .35769 m .89172 .35489 L .89293 .35672 L 0 .025 .124 r
F
.88985 .35769 m .88864 .35586 L .89172 .35489 L F
.36166 .3622 m .36273 .35957 L .36445 .36141 L 0 .035 .136 r
F
.36166 .3622 m .35994 .36036 L .36273 .35957 L F
.75637 .36019 m .75803 .35734 L .75937 .35917 L 0 .03 .13 r
F
.75637 .36019 m .75502 .35834 L .75803 .35734 L F
.82678 .35877 m .82854 .35583 L .82981 .3577 L 0 .027 .126 r
F
.82678 .35877 m .8255 .35689 L .82854 .35583 L F
.62155 .37018 m .62301 .36702 L .62447 .36869 L 0 .054 .156 r
F
.62155 .37018 m .62009 .36856 L .62301 .36702 L F
.24858 .35863 m .24948 .35602 L .25132 .35774 L 0 .027 .127 r
F
.24858 .35863 m .24675 .35689 L .24948 .35602 L F
.7637 .35986 m .76538 .35708 L .76671 .35882 L 0 .03 .13 r
F
.7637 .35986 m .76238 .35815 L .76538 .35708 L F
.30878 .36027 m .30979 .35743 L .31155 .35933 L 0 .03 .131 r
F
.30878 .36027 m .30702 .35837 L .30979 .35743 L F
.83411 .35845 m .83589 .35553 L .83715 .35735 L 0 .026 .126 r
F
.83411 .35845 m .83285 .35663 L .83589 .35553 L F
.84145 .35806 m .84324 .35523 L .84449 .35704 L 0 .026 .125 r
F
.84145 .35806 m .84019 .35626 L .84324 .35523 L F
.18105 .35745 m .18185 .35476 L .18375 .35651 L 0 .025 .123 r
F
.18105 .35745 m .17915 .35569 L .18185 .35476 L F
.64643 .3664 m .64793 .36352 L .64937 .36513 L 0 .044 .147 r
F
.64643 .3664 m .64499 .36479 L .64793 .36352 L F
.60113 .37637 m .60256 .3734 L .60404 .37468 L 0 .072 .173 r
F
.60113 .37637 m .59965 .37516 L .60256 .3734 L F
.39253 .36561 m .39365 .363 L .39534 .36487 L 0 .043 .145 r
F
.39253 .36561 m .39084 .36372 L .39365 .363 L F
.77104 .35951 m .77272 .35669 L .77405 .35849 L 0 .029 .129 r
F
.77104 .35951 m .76971 .35775 L .77272 .35669 L F
.27501 .35972 m .27596 .35693 L .27777 .35876 L F
.27501 .35972 m .27321 .35787 L .27596 .35693 L F
.50632 .40648 m .50755 .41636 L .50916 .41251 L 0 .241 .278 r
F
.50632 .40648 m .50472 .4088 L .50755 .41636 L F
.56184 .39354 m .56324 .39305 L .56472 .39113 L 0 .143 .224 r
F
.56184 .39354 m .56036 .39617 L .56324 .39305 L F
.89721 .35756 m .89909 .35471 L .90029 .35655 L 0 .025 .124 r
F
.89721 .35756 m .89601 .35572 L .89909 .35471 L F
.22214 .35777 m .223 .35511 L .22485 .3569 L 0 .026 .125 r
F
.22214 .35777 m .22028 .35598 L .223 .35511 L F
.28233 .35948 m .28329 .35667 L .2851 .35841 L 0 .029 .129 r
F
.28233 .35948 m .28053 .35771 L .28329 .35667 L F
.8488 .35786 m .8506 .35504 L .85185 .35686 L 0 .026 .125 r
F
.8488 .35786 m .84755 .35605 L .8506 .35504 L F
.38074 .364 m .38185 .3612 L .38355 .36316 L 0 .039 .141 r
F
.38074 .364 m .37905 .36203 L .38185 .3612 L F
.5372 .40998 m .53859 .41772 L .5401 .41007 L 0 .254 .284 r
F
.5372 .40998 m .53568 .41715 L .53859 .41772 L F
.77839 .35937 m .78009 .35661 L .78141 .35845 L 0 .029 .129 r
F
.77839 .35937 m .77707 .35755 L .78009 .35661 L F
.34253 .36121 m .34358 .35843 L .34531 .36038 L 0 .033 .134 r
F
.34253 .36121 m .3408 .35925 L .34358 .35843 L F
.31609 .3602 m .3171 .35747 L .31886 .35927 L 0 .031 .131 r
F
.31609 .3602 m .31433 .35838 L .3171 .35747 L F
.25588 .35858 m .2568 .35588 L .25863 .35762 L 0 .028 .127 r
F
.25588 .35858 m .25405 .35685 L .2568 .35588 L F
.5652 .39072 m .56613 .38993 L .56761 .38871 L 0 .132 .217 r
F
.56613 .38993 m .56465 .39222 L .56705 .38912 L 0 .141 .223 r
F
.56761 .38871 m .56613 .38993 L .56901 .38704 L 0 .121 .21 r
F
.56613 .38993 m .56705 .38912 L .56753 .38851 L 0 .141 .223 r
F
.56472 .39113 m .56613 .38993 L .5652 .39072 L 0 .132 .217 r
F
.56472 .39113 m .56324 .39305 L .56613 .38993 L F
.43518 .371 m .43636 .36861 L .438 .37061 L 0 .058 .161 r
F
.43518 .371 m .43353 .36906 L .43636 .36861 L F
.18834 .3574 m .18917 .35456 L .19106 .35639 L 0 .025 .124 r
F
.18834 .3574 m .18646 .35557 L .18917 .35456 L F
.85615 .35764 m .85795 .3547 L .8592 .35656 L F
.85615 .35764 m .8549 .35578 L .85795 .3547 L F
.59092 .37981 m .59235 .37706 L .59384 .37861 L 0 .084 .183 r
F
.59092 .37981 m .58943 .37826 L .59235 .37706 L F
.28964 .35929 m .29061 .35667 L .2924 .35842 L 0 .029 .129 r
F
.28964 .35929 m .28785 .35754 L .29061 .35667 L F
.63178 .36765 m .63326 .36478 L .63472 .36657 L 0 .048 .151 r
F
.63178 .36765 m .63032 .36585 L .63326 .36478 L F
.50187 .40469 m .5031 .41114 L .50472 .4088 L 0 .22 .267 r
F
.50187 .40469 m .50026 .40606 L .5031 .41114 L F
.63912 .36728 m .6406 .36431 L .64205 .36606 L 0 .047 .15 r
F
.63912 .36728 m .63766 .3655 L .6406 .36431 L F
.45584 .37747 m .45705 .37537 L .45868 .37715 L 0 .078 .178 r
F
.45584 .37747 m .45421 .37568 L .45705 .37537 L F
.41162 .36751 m .41277 .36478 L .41443 .36693 L 0 .048 .151 r
F
.41162 .36751 m .40996 .36541 L .41277 .36478 L F
.56761 .38871 m .56901 .38704 L .5705 .38643 L 0 .121 .21 r
F
.8635 .35742 m .86532 .35462 L .86656 .35648 L 0 .025 .124 r
F
.8635 .35742 m .86225 .35555 L .86532 .35462 L F
.19565 .35723 m .19648 .35444 L .19836 .35629 L F
.19565 .35723 m .19377 .35537 L .19648 .35444 L F
.39984 .36579 m .40098 .36284 L .40266 .36482 L 0 .044 .146 r
F
.39984 .36579 m .39816 .36385 L .40098 .36284 L F
.3234 .3601 m .32442 .35734 L .32618 .35909 L 0 .031 .131 r
F
.3234 .3601 m .32164 .35833 L .32442 .35734 L F
.36895 .36254 m .37004 .35974 L .37175 .36171 L 0 .036 .138 r
F
.36895 .36254 m .36724 .36058 L .37004 .35974 L F
.70065 .36153 m .70223 .35856 L .70362 .36041 L 0 .034 .135 r
F
.70065 .36153 m .69926 .35972 L .70223 .35856 L F
.22942 .35787 m .2303 .35507 L .23215 .35693 L 0 .026 .125 r
F
.22942 .35787 m .22757 .356 L .2303 .35507 L F
.78575 .35932 m .78744 .35634 L .78876 .3582 L 0 .029 .129 r
F
.78575 .35932 m .78443 .35745 L .78744 .35634 L F
.51077 .40937 m .51202 .41866 L .51362 .41417 L 0 .257 .285 r
F
.51077 .40937 m .50916 .41251 L .51202 .41866 L F
.79308 .35895 m .7948 .3561 L .7961 .35795 L 0 .028 .128 r
F
.79308 .35895 m .79177 .35709 L .7948 .3561 L F
.26318 .35855 m .26412 .35571 L .26593 .35761 L 0 .028 .127 r
F
.26318 .35855 m .26137 .35665 L .26412 .35571 L F
.72998 .35997 m .73162 .35723 L .73298 .35901 L 0 .031 .131 r
F
.72998 .35997 m .72862 .35821 L .73162 .35723 L F
.72265 .36039 m .72426 .35738 L .72563 .35919 L 0 .031 .132 r
F
.72265 .36039 m .72128 .35856 L .72426 .35738 L F
.70799 .36121 m .70958 .35825 L .71097 .36014 L 0 .033 .134 r
F
.70799 .36121 m .7066 .35931 L .70958 .35825 L F
.42339 .36956 m .42457 .36665 L .42622 .36873 L 0 .054 .156 r
F
.42339 .36956 m .42174 .36746 L .42457 .36665 L F
.34983 .36125 m .3509 .35842 L .35263 .36023 L 0 .033 .134 r
F
.34983 .36125 m .3481 .3594 L .3509 .35842 L F
.69333 .36214 m .6949 .35912 L .69629 .36089 L 0 .035 .136 r
F
.69333 .36214 m .69194 .3604 L .6949 .35912 L F
.33072 .35993 m .33176 .35699 L .33351 .35889 L 0 .031 .131 r
F
.33072 .35993 m .32897 .35804 L .33176 .35699 L F
.71533 .36095 m .71692 .35792 L .7183 .35977 L 0 .033 .133 r
F
.71533 .36095 m .71395 .35908 L .71692 .35792 L F
.5836 .38069 m .58501 .37789 L .58651 .37946 L 0 .088 .186 r
F
.5836 .38069 m .5821 .37921 L .58501 .37789 L F
.73733 .35975 m .73896 .35685 L .74032 .35864 L 0 .03 .13 r
F
.73733 .35975 m .73597 .35796 L .73896 .35685 L F
.48697 .39352 m .48819 .39494 L .48979 .3961 L 0 .15 .228 r
F
.48697 .39352 m .48536 .3921 L .48819 .39494 L F
.74466 .35937 m .74631 .35656 L .74766 .3584 L 0 .03 .13 r
F
.74466 .35937 m .74331 .35754 L .74631 .35656 L F
.61425 .37158 m .6157 .36853 L .61717 .37007 L 0 .059 .162 r
F
.61425 .37158 m .61278 .37009 L .6157 .36853 L F
.5705 .38643 m .5719 .38428 L .57339 .38422 L 0 .111 .203 r
F
.5705 .38643 m .56901 .38704 L .5719 .38428 L F
.80043 .35878 m .80217 .35599 L .80346 .35779 L 0 .028 .128 r
F
.80043 .35878 m .79914 .35699 L .80217 .35599 L F
.87087 .35737 m .8727 .35448 L .87392 .3563 L 0 .025 .124 r
F
.87087 .35737 m .86963 .35553 L .8727 .35448 L F
.60404 .37468 m .60547 .3718 L .60695 .37316 L 0 .069 .17 r
F
.60404 .37468 m .60256 .3734 L .60547 .3718 L F
.8782 .35699 m .88005 .35417 L .88127 .35595 L 0 .025 .123 r
F
.8782 .35699 m .87698 .35522 L .88005 .35417 L F
.29694 .35943 m .29793 .35649 L .29971 .35841 L 0 .03 .13 r
F
.29694 .35943 m .29516 .3575 L .29793 .35649 L F
.80777 .35843 m .8095 .35549 L .81079 .3573 L 0 .028 .127 r
F
.80777 .35843 m .80648 .35664 L .8095 .35549 L F
.23672 .35783 m .23761 .35509 L .23944 .35692 L 0 .027 .126 r
F
.23672 .35783 m .23488 .35599 L .23761 .35509 L F
.8151 .35806 m .81685 .3552 L .81814 .35706 L F
.8151 .35806 m .81382 .35623 L .81685 .3552 L F
.16183 .35704 m .16262 .35423 L .16453 .35607 L 0 .025 .124 r
F
.16183 .35704 m .15992 .35518 L .16262 .35423 L F
.20294 .35726 m .20377 .35455 L .20564 .35638 L 0 .026 .124 r
F
.20294 .35726 m .20106 .35542 L .20377 .35455 L F
.67868 .36316 m .68023 .36027 L .68164 .36212 L 0 .038 .14 r
F
.67868 .36316 m .67726 .36131 L .68023 .36027 L F
.38804 .3644 m .38915 .36182 L .39084 .36372 L 0 .042 .144 r
F
.38804 .3644 m .38635 .36247 L .38915 .36182 L F
.35715 .36115 m .35821 .35859 L .35994 .36036 L 0 .034 .135 r
F
.35715 .36115 m .35542 .35937 L .35821 .35859 L F
.62447 .36869 m .62593 .36548 L .62739 .3672 L 0 .051 .154 r
F
.62447 .36869 m .62301 .36702 L .62593 .36548 L F
.65669 .36446 m .65821 .36167 L .65964 .36339 L 0 .041 .144 r
F
.65669 .36446 m .65526 .36278 L .65821 .36167 L F
.68602 .36286 m .68757 .35989 L .68898 .36168 L 0 .037 .139 r
F
.68602 .36286 m .68461 .36107 L .68757 .35989 L F
.88556 .35679 m .88743 .35406 L .88864 .35586 L 0 .025 .123 r
F
.88556 .35679 m .88434 .355 L .88743 .35406 L F
.66402 .36413 m .66555 .36135 L .66698 .36313 L 0 .041 .143 r
F
.66402 .36413 m .6626 .36237 L .66555 .36135 L F
.67136 .36374 m .67289 .36067 L .67431 .36251 L 0 .039 .141 r
F
.67136 .36374 m .66993 .36192 L .67289 .36067 L F
.47206 .38227 m .47328 .3811 L .47489 .38286 L 0 .099 .194 r
F
.47206 .38227 m .47044 .3806 L .47328 .3811 L F
.27047 .35869 m .27141 .35598 L .27321 .35787 L 0 .029 .129 r
F
.27047 .35869 m .26867 .35679 L .27141 .35598 L F
.75202 .35931 m .75368 .35649 L .75502 .35834 L 0 .03 .13 r
F
.75202 .35931 m .75067 .35745 L .75368 .35649 L F
.40714 .36604 m .40829 .36331 L .40996 .36541 L 0 .046 .148 r
F
.40714 .36604 m .40547 .364 L .40829 .36331 L F
.30425 .35933 m .30525 .35643 L .30702 .35837 L 0 .03 .13 r
F
.30425 .35933 m .30248 .35739 L .30525 .35643 L F
.16913 .35689 m .16993 .35407 L .17184 .35588 L 0 .025 .124 r
F
.16913 .35689 m .16723 .35508 L .16993 .35407 L F
.21024 .35713 m .21109 .35437 L .21297 .3561 L 0 .026 .124 r
F
.21024 .35713 m .20837 .35538 L .21109 .35437 L F
.82246 .35794 m .82422 .35501 L .8255 .35689 L 0 .027 .126 r
F
.82246 .35794 m .82118 .35605 L .82422 .35501 L F
.37625 .36286 m .37735 .36003 L .37905 .36203 L 0 .038 .14 r
F
.37625 .36286 m .37455 .36088 L .37735 .36003 L F
.4765 .38462 m .47772 .38392 L .47933 .38581 L 0 .109 .202 r
F
.4765 .38462 m .47489 .38286 L .47772 .38392 L F
.57339 .38422 m .57479 .38154 L .57628 .38203 L 0 .102 .197 r
F
.57339 .38422 m .5719 .38428 L .57479 .38154 L F
.24402 .35779 m .24491 .35513 L .24675 .35689 L 0 .027 .127 r
F
.24402 .35779 m .24218 .35602 L .24491 .35513 L F
.4307 .3698 m .43188 .36712 L .43353 .36906 L 0 .056 .158 r
F
.4307 .3698 m .42905 .36792 L .43188 .36712 L F
.33802 .36004 m .33906 .35729 L .3408 .35925 L 0 .032 .132 r
F
.33802 .36004 m .33628 .35807 L .33906 .35729 L F
.64937 .36513 m .65087 .36231 L .65231 .36396 L 0 .043 .146 r
F
.64937 .36513 m .64793 .36352 L .65087 .36231 L F
.45138 .37613 m .45259 .37347 L .45421 .37568 L 0 .074 .175 r
F
.45138 .37613 m .44975 .37393 L .45259 .37347 L F
.46761 .3802 m .46882 .37884 L .47044 .3806 L 0 .091 .189 r
F
.46761 .3802 m .46598 .37855 L .46882 .37884 L F
.17645 .35663 m .17725 .35392 L .17915 .35569 L 0 .025 .123 r
F
.17645 .35663 m .17454 .35486 L .17725 .35392 L F
.21756 .35685 m .21841 .35425 L .22028 .35598 L 0 .025 .124 r
F
.21756 .35685 m .21569 .35512 L .21841 .35425 L F
.52254 .41198 m .52386 .42335 L .52543 .41508 L 0 .284 .297 r
F
.52254 .41198 m .52097 .41872 L .52386 .42335 L F
.82981 .3577 m .83158 .35477 L .83285 .35663 L 0 .027 .126 r
F
.82981 .3577 m .82854 .35583 L .83158 .35477 L F
.89293 .35672 m .8948 .35388 L .89601 .35572 L 0 .025 .124 r
F
.89293 .35672 m .89172 .35489 L .8948 .35388 L F
.75937 .35917 m .76104 .35634 L .76238 .35815 L 0 .03 .13 r
F
.75937 .35917 m .75803 .35734 L .76104 .35634 L F
.83715 .35735 m .83893 .35443 L .84019 .35626 L 0 .026 .125 r
F
.83715 .35735 m .83589 .35553 L .83893 .35443 L F
.76671 .35882 m .76839 .35599 L .76971 .35775 L 0 .029 .129 r
F
.76671 .35882 m .76538 .35708 L .76839 .35599 L F
.84449 .35704 m .84629 .35423 L .84755 .35605 L 0 .026 .125 r
F
.84449 .35704 m .84324 .35523 L .84629 .35423 L F
.77405 .35849 m .77574 .35573 L .77707 .35755 L 0 .029 .129 r
F
.77405 .35849 m .77272 .35669 L .77574 .35573 L F
.41891 .36827 m .42008 .36536 L .42174 .36746 L 0 .052 .154 r
F
.41891 .36827 m .41725 .36615 L .42008 .36536 L F
.31155 .35933 m .31256 .35649 L .31433 .35838 L 0 .03 .131 r
F
.31155 .35933 m .30979 .35743 L .31256 .35649 L F
.18375 .35651 m .18456 .35382 L .18646 .35557 L 0 .025 .124 r
F
.18375 .35651 m .18185 .35476 L .18456 .35382 L F
.25132 .35774 m .25222 .35514 L .25405 .35685 L 0 .028 .127 r
F
.25132 .35774 m .24948 .35602 L .25222 .35514 L F
.27777 .35876 m .27873 .3559 L .28053 .35771 L 0 .029 .129 r
F
.27777 .35876 m .27596 .35693 L .27873 .3559 L F
.36445 .36141 m .36553 .35874 L .36724 .36058 L 0 .035 .137 r
F
.36445 .36141 m .36273 .35957 L .36553 .35874 L F
.4914 .39665 m .4926 .40189 L .49422 .40169 L 0 .179 .245 r
F
.4914 .39665 m .48979 .3961 L .4926 .40189 L F
.2851 .35841 m .28605 .35578 L .28785 .35754 L 0 .029 .129 r
F
.2851 .35841 m .28329 .35667 L .28605 .35578 L F
.57628 .38203 m .57769 .37978 L .57919 .38062 L 0 .096 .193 r
F
.57628 .38203 m .57479 .38154 L .57769 .37978 L F
.59384 .37861 m .59526 .37541 L .59675 .37695 L 0 .082 .181 r
F
.59384 .37861 m .59235 .37706 L .59526 .37541 L F
.85185 .35686 m .85365 .35395 L .8549 .35578 L 0 .026 .124 r
F
.85185 .35686 m .8506 .35504 L .85365 .35395 L F
.44692 .3744 m .44812 .37174 L .44975 .37393 L 0 .07 .171 r
F
.44692 .3744 m .44529 .37222 L .44812 .37174 L F
.22485 .3569 m .22572 .3542 L .22757 .356 L 0 .026 .125 r
F
.22485 .3569 m .223 .35511 L .22572 .3542 L F
.64205 .36606 m .64354 .36306 L .64499 .36479 L 0 .046 .148 r
F
.64205 .36606 m .6406 .36431 L .64354 .36306 L F
.39534 .36487 m .39647 .36199 L .39816 .36385 L 0 .043 .146 r
F
.39534 .36487 m .39365 .363 L .39647 .36199 L F
.8592 .35656 m .86101 .35369 L .86225 .35555 L 0 .025 .124 r
F
.8592 .35656 m .85795 .3547 L .86101 .35369 L F
.19106 .35639 m .19189 .35354 L .19377 .35537 L 0 .025 .123 r
F
.19106 .35639 m .18917 .35456 L .19189 .35354 L F
.63472 .36657 m .63621 .36372 L .63766 .3655 L 0 .048 .15 r
F
.63472 .36657 m .63326 .36478 L .63621 .36372 L F
.25863 .35762 m .25955 .3549 L .26137 .35665 L 0 .028 .127 r
F
.25863 .35762 m .2568 .35588 L .25955 .3549 L F
.31886 .35927 m .31988 .35656 L .32164 .35833 L 0 .031 .131 r
F
.31886 .35927 m .3171 .35747 L .31988 .35656 L F
.78141 .35845 m .78311 .35559 L .78443 .35745 L 0 .029 .129 r
F
.78141 .35845 m .78009 .35661 L .78311 .35559 L F
.61717 .37007 m .61862 .36696 L .62009 .36856 L 0 .057 .159 r
F
.61717 .37007 m .6157 .36853 L .61862 .36696 L F
.38355 .36316 m .38466 .36053 L .38635 .36247 L 0 .04 .142 r
F
.38355 .36316 m .38185 .3612 L .38466 .36053 L F
.48094 .38759 m .48215 .38889 L .48375 .39068 L 0 .128 .215 r
F
.48094 .38759 m .47933 .38581 L .48215 .38889 L F
.60695 .37316 m .60839 .37019 L .60986 .37164 L 0 .066 .168 r
F
.60695 .37316 m .60547 .3718 L .60839 .37019 L F
.46314 .37866 m .46436 .37689 L .46598 .37855 L 0 .086 .185 r
F
.46314 .37866 m .46152 .37702 L .46436 .37689 L F
.34531 .36038 m .34637 .35748 L .3481 .3594 L 0 .033 .134 r
F
.34531 .36038 m .34358 .35843 L .34637 .35748 L F
.70362 .36041 m .7052 .35743 L .7066 .35931 L F
.70362 .36041 m .70223 .35856 L .7052 .35743 L F
.72563 .35919 m .72725 .35642 L .72862 .35821 L 0 .031 .131 r
F
.72563 .35919 m .72426 .35738 L .72725 .35642 L F
.44246 .37244 m .44365 .37007 L .44529 .37222 L 0 .065 .167 r
F
.44246 .37244 m .44082 .37035 L .44365 .37007 L F
.78876 .3582 m .79046 .35523 L .79177 .35709 L 0 .029 .128 r
F
.78876 .3582 m .78744 .35634 L .79046 .35523 L F
.2924 .35842 m .29337 .35575 L .29516 .3575 L 0 .029 .129 r
F
.2924 .35842 m .29061 .35667 L .29337 .35575 L F
.69629 .36089 m .69786 .35791 L .69926 .35972 L 0 .034 .135 r
F
.69629 .36089 m .6949 .35912 L .69786 .35791 L F
.62739 .3672 m .62886 .36408 L .63032 .36585 L 0 .049 .152 r
F
.62739 .3672 m .62593 .36548 L .62886 .36408 L F
.32618 .35909 m .32721 .3563 L .32897 .35804 L 0 .031 .131 r
F
.32618 .35909 m .32442 .35734 L .32721 .3563 L F
.58651 .37946 m .58793 .3767 L .58943 .37826 L 0 .087 .185 r
F
.58651 .37946 m .58501 .37789 L .58793 .3767 L F
.86656 .35648 m .8684 .35368 L .86963 .35553 L 0 .025 .124 r
F
.86656 .35648 m .86532 .35462 L .8684 .35368 L F
.40266 .36482 m .4038 .36196 L .40547 .364 L 0 .044 .146 r
F
.40266 .36482 m .40098 .36284 L .4038 .36196 L F
.71097 .36014 m .71256 .3572 L .71395 .35908 L 0 .033 .134 r
F
.71097 .36014 m .70958 .35825 L .71256 .3572 L F
.19836 .35629 m .19919 .35358 L .20106 .35542 L 0 .025 .124 r
F
.19836 .35629 m .19648 .35444 L .19919 .35358 L F
.7183 .35977 m .7199 .35673 L .72128 .35856 L 0 .032 .132 r
F
.7183 .35977 m .71692 .35792 L .7199 .35673 L F
.23215 .35693 m .23303 .35414 L .23488 .35599 L 0 .026 .125 r
F
.23215 .35693 m .2303 .35507 L .23303 .35414 L F
.7961 .35795 m .79783 .35513 L .79914 .35699 L 0 .028 .128 r
F
.7961 .35795 m .7948 .3561 L .79783 .35513 L F
.15723 .35613 m .15801 .35332 L .15992 .35518 L 0 .025 .123 r
F
.15723 .35613 m .15532 .35426 L .15801 .35332 L F
.73298 .35901 m .73461 .35618 L .73597 .35796 L 0 .031 .131 r
F
.73298 .35901 m .73162 .35723 L .73461 .35618 L F
.35263 .36023 m .35369 .35758 L .35542 .35937 L 0 .034 .135 r
F
.35263 .36023 m .3509 .35842 L .35369 .35758 L F
.26593 .35761 m .26686 .35489 L .26867 .35679 L 0 .028 .128 r
F
.26593 .35761 m .26412 .35571 L .26686 .35489 L F
.74032 .35864 m .74195 .35573 L .74331 .35754 L 0 .03 .13 r
F
.74032 .35864 m .73896 .35685 L .74195 .35573 L F
.37175 .36171 m .37285 .35889 L .37455 .36088 L 0 .037 .138 r
F
.37175 .36171 m .37004 .35974 L .37285 .35889 L F
.33351 .35889 m .33454 .35618 L .33628 .35807 L 0 .031 .131 r
F
.33351 .35889 m .33176 .35699 L .33454 .35618 L F
.81079 .3573 m .81253 .3544 L .81382 .35623 L 0 .027 .126 r
F
.81079 .3573 m .8095 .35549 L .81253 .3544 L F
.87392 .3563 m .87576 .35341 L .87698 .35522 L 0 .025 .124 r
F
.87392 .3563 m .8727 .35448 L .87576 .35341 L F
.42622 .36873 m .4274 .36585 L .42905 .36792 L 0 .054 .157 r
F
.42622 .36873 m .42457 .36665 L .4274 .36585 L F
.41443 .36693 m .4156 .36401 L .41725 .36615 L 0 .049 .152 r
F
.41443 .36693 m .41277 .36478 L .4156 .36401 L F
.88127 .35595 m .88313 .35321 L .88434 .355 L 0 .025 .123 r
F
.88127 .35595 m .88005 .35417 L .88313 .35321 L F
.80346 .35779 m .80519 .35483 L .80648 .35664 L 0 .028 .128 r
F
.80346 .35779 m .80217 .35599 L .80519 .35483 L F
.74766 .3584 m .74932 .35559 L .75067 .35745 L 0 .03 .13 r
F
.74766 .3584 m .74631 .35656 L .74932 .35559 L F
.438 .37061 m .43918 .36828 L .44082 .37035 L 0 .061 .163 r
F
.438 .37061 m .43636 .36861 L .43918 .36828 L F
.29971 .35841 m .3007 .35547 L .30248 .35739 L 0 .029 .129 r
F
.29971 .35841 m .29793 .35649 L .3007 .35547 L F
.68898 .36168 m .69053 .35862 L .69194 .3604 L 0 .036 .138 r
F
.68898 .36168 m .68757 .35989 L .69053 .35862 L F
.67431 .36251 m .67584 .35946 L .67726 .36131 L 0 .038 .14 r
F
.67431 .36251 m .67289 .36067 L .67584 .35946 L F
.68164 .36212 m .6832 .35923 L .68461 .36107 L 0 .038 .139 r
F
.68164 .36212 m .68023 .36027 L .6832 .35923 L F
.81814 .35706 m .81989 .35417 L .82118 .35605 L 0 .027 .126 r
F
.81814 .35706 m .81685 .3552 L .81989 .35417 L F
.65964 .36339 m .66117 .36061 L .6626 .36237 L 0 .041 .143 r
F
.65964 .36339 m .65821 .36167 L .66117 .36061 L F
.16453 .35607 m .16531 .35325 L .16723 .35508 L 0 .025 .124 r
F
.16453 .35607 m .16262 .35423 L .16531 .35325 L F
.23944 .35692 m .24034 .35418 L .24218 .35602 L 0 .027 .126 r
F
.23944 .35692 m .23761 .35509 L .24034 .35418 L F
.20564 .35638 m .20649 .35357 L .20837 .35538 L 0 .026 .125 r
F
.20564 .35638 m .20377 .35455 L .20649 .35357 L F
.59675 .37695 m .59816 .37363 L .59965 .37516 L 0 .078 .178 r
F
.59675 .37695 m .59526 .37541 L .59816 .37363 L F
.45868 .37715 m .45989 .37522 L .46152 .37702 L 0 .082 .181 r
F
.45868 .37715 m .45705 .37537 L .45989 .37522 L F
.66698 .36313 m .66851 .3601 L .66993 .36192 L 0 .04 .142 r
F
.66698 .36313 m .66555 .36135 L .66851 .3601 L F
.65231 .36396 m .65382 .3611 L .65526 .36278 L 0 .043 .145 r
F
.65231 .36396 m .65087 .36231 L .65382 .3611 L F
.52988 .41301 m .53123 .42144 L .53278 .41517 L 0 .282 .296 r
F
.52988 .41301 m .52833 .41824 L .53123 .42144 L F
.88864 .35586 m .89051 .35307 L .89172 .35489 L 0 .025 .124 r
F
.88864 .35586 m .88743 .35406 L .89051 .35307 L F
.8255 .35689 m .82726 .35396 L .82854 .35583 L 0 .027 .126 r
F
.8255 .35689 m .82422 .35501 L .82726 .35396 L F
.17184 .35588 m .17264 .35306 L .17454 .35486 L 0 .025 .124 r
F
.17184 .35588 m .16993 .35407 L .17264 .35306 L F
.35994 .36036 m .361 .35781 L .36273 .35957 L 0 .035 .136 r
F
.35994 .36036 m .35821 .35859 L .361 .35781 L F
.21297 .3561 m .21382 .3534 L .21569 .35512 L 0 .026 .124 r
F
.21297 .3561 m .21109 .35437 L .21382 .3534 L F
.75502 .35834 m .75669 .35551 L .75803 .35734 L 0 .03 .13 r
F
.75502 .35834 m .75368 .35649 L .75669 .35551 L F
.30702 .35837 m .30802 .3555 L .30979 .35743 L F
.30702 .35837 m .30525 .35643 L .30802 .3555 L F
.5401 .41007 m .5415 .41829 L .543 .41016 L 0 .266 .289 r
F
.5401 .41007 m .53859 .41772 L .5415 .41829 L F
.39084 .36372 m .39196 .36112 L .39365 .363 L 0 .043 .145 r
F
.39084 .36372 m .38915 .36182 L .39196 .36112 L F
.57919 .38062 m .5806 .37801 L .5821 .37921 L 0 .093 .19 r
F
.57919 .38062 m .57769 .37978 L .5806 .37801 L F
.83285 .35663 m .83462 .35368 L .83589 .35553 L 0 .026 .125 r
F
.83285 .35663 m .83158 .35477 L .83462 .35368 L F
.27321 .35787 m .27416 .35505 L .27596 .35693 L 0 .029 .129 r
F
.27321 .35787 m .27141 .35598 L .27416 .35505 L F
.84019 .35626 m .84198 .35341 L .84324 .35523 L 0 .026 .125 r
F
.84019 .35626 m .83893 .35443 L .84198 .35341 L F
.24675 .35689 m .24764 .35427 L .24948 .35602 L 0 .027 .127 r
F
.24675 .35689 m .24491 .35513 L .24764 .35427 L F
.17915 .35569 m .17995 .353 L .18185 .35476 L 0 .025 .124 r
F
.17915 .35569 m .17725 .35392 L .17995 .353 L F
.76238 .35815 m .76405 .35529 L .76538 .35708 L 0 .03 .13 r
F
.76238 .35815 m .76104 .35634 L .76405 .35529 L F
.89601 .35572 m .89788 .35287 L .89909 .35471 L 0 .025 .123 r
F
.89601 .35572 m .8948 .35388 L .89788 .35287 L F
.76971 .35775 m .7714 .3549 L .77272 .35669 L 0 .029 .129 r
F
.76971 .35775 m .76839 .35599 L .7714 .3549 L F
.37905 .36203 m .38016 .35918 L .38185 .3612 L 0 .038 .14 r
F
.37905 .36203 m .37735 .36003 L .38016 .35918 L F
.62009 .36856 m .62154 .36536 L .62301 .36702 L 0 .054 .157 r
F
.62009 .36856 m .61862 .36696 L .62154 .36536 L F
.60986 .37164 m .61131 .36859 L .61278 .37009 L 0 .063 .165 r
F
.60986 .37164 m .60839 .37019 L .61131 .36859 L F
.22028 .35598 m .22113 .35337 L .223 .35511 L 0 .026 .125 r
F
.22028 .35598 m .21841 .35425 L .22113 .35337 L F
.3408 .35925 m .34185 .35647 L .34358 .35843 L 0 .032 .133 r
F
.3408 .35925 m .33906 .35729 L .34185 .35647 L F
.64499 .36479 m .64649 .36182 L .64793 .36352 L 0 .045 .147 r
F
.64499 .36479 m .64354 .36306 L .64649 .36182 L F
.43353 .36906 m .43471 .3666 L .43636 .36861 L 0 .057 .16 r
F
.43353 .36906 m .43188 .36712 L .43471 .3666 L F
.40996 .36541 m .41111 .36262 L .41277 .36478 L 0 .047 .149 r
F
.40996 .36541 m .40829 .36331 L .41111 .36262 L F
.84755 .35605 m .84935 .35322 L .8506 .35504 L 0 .026 .125 r
F
.84755 .35605 m .84629 .35423 L .84935 .35322 L F
.28053 .35771 m .28149 .35487 L .28329 .35667 L 0 .029 .129 r
F
.28053 .35771 m .27873 .3559 L .28149 .35487 L F
.77707 .35755 m .77877 .35477 L .78009 .35661 L F
.77707 .35755 m .77574 .35573 L .77877 .35477 L F
.31433 .35838 m .31533 .35561 L .3171 .35747 L 0 .031 .131 r
F
.31433 .35838 m .31256 .35649 L .31533 .35561 L F
.18646 .35557 m .18727 .3528 L .18917 .35456 L 0 .025 .124 r
F
.18646 .35557 m .18456 .35382 L .18727 .3528 L F
.8549 .35578 m .8567 .35286 L .85795 .3547 L F
.8549 .35578 m .85365 .35395 L .8567 .35286 L F
.25405 .35685 m .25496 .35417 L .2568 .35588 L 0 .028 .127 r
F
.25405 .35685 m .25222 .35514 L .25496 .35417 L F
.42174 .36746 m .42291 .36457 L .42457 .36665 L 0 .052 .155 r
F
.42174 .36746 m .42008 .36536 L .42291 .36457 L F
.63032 .36585 m .6318 .36299 L .63326 .36478 L 0 .048 .151 r
F
.63032 .36585 m .62886 .36408 L .6318 .36299 L F
.36724 .36058 m .36833 .35792 L .37004 .35974 L 0 .036 .137 r
F
.36724 .36058 m .36553 .35874 L .36833 .35792 L F
.28785 .35754 m .28881 .35491 L .29061 .35667 L 0 .029 .129 r
F
.28785 .35754 m .28605 .35578 L .28881 .35491 L F
.39816 .36385 m .3993 .36098 L .40098 .36284 L 0 .043 .145 r
F
.39816 .36385 m .39647 .36199 L .3993 .36098 L F
.63766 .3655 m .63915 .36255 L .6406 .36431 L 0 .047 .15 r
F
.63766 .3655 m .63621 .36372 L .63915 .36255 L F
.45421 .37568 m .45543 .37314 L .45705 .37537 L 0 .077 .178 r
F
.45421 .37568 m .45259 .37347 L .45543 .37314 L F
.86225 .35555 m .86408 .35276 L .86532 .35462 L 0 .025 .124 r
F
.86225 .35555 m .86101 .35369 L .86408 .35276 L F
.19377 .35537 m .1946 .35261 L .19648 .35444 L 0 .025 .123 r
F
.19377 .35537 m .19189 .35354 L .1946 .35261 L F
.22757 .356 m .22845 .35328 L .2303 .35507 L 0 .026 .125 r
F
.22757 .356 m .22572 .3542 L .22845 .35328 L F
.59965 .37516 m .60108 .37188 L .60256 .3734 L 0 .074 .175 r
F
.59965 .37516 m .59816 .37363 L .60108 .37188 L F
.78443 .35745 m .78613 .35447 L .78744 .35634 L 0 .029 .129 r
F
.78443 .35745 m .78311 .35559 L .78613 .35447 L F
.26137 .35665 m .2623 .35394 L .26412 .35571 L 0 .028 .127 r
F
.26137 .35665 m .25955 .3549 L .2623 .35394 L F
.7066 .35931 m .70819 .35638 L .70958 .35825 L 0 .033 .134 r
F
.7066 .35931 m .7052 .35743 L .70819 .35638 L F
.69926 .35972 m .70083 .35671 L .70223 .35856 L 0 .034 .135 r
F
.69926 .35972 m .69786 .35791 L .70083 .35671 L F
.79177 .35709 m .79349 .35423 L .7948 .3561 L 0 .028 .128 r
F
.79177 .35709 m .79046 .35523 L .79349 .35423 L F
.58943 .37826 m .59085 .37552 L .59235 .37706 L 0 .085 .184 r
F
.58943 .37826 m .58793 .3767 L .59085 .37552 L F
.32164 .35833 m .32266 .35559 L .32442 .35734 L 0 .031 .131 r
F
.32164 .35833 m .31988 .35656 L .32266 .35559 L F
.72128 .35856 m .72288 .35557 L .72426 .35738 L 0 .031 .132 r
F
.72128 .35856 m .7199 .35673 L .72288 .35557 L F
.3481 .3594 m .34917 .35653 L .3509 .35842 L 0 .033 .134 r
F
.3481 .3594 m .34637 .35748 L .34917 .35653 L F
.72862 .35821 m .73025 .35545 L .73162 .35723 L 0 .031 .131 r
F
.72862 .35821 m .72725 .35642 L .73025 .35545 L F
.32897 .35804 m .33 .35526 L .33176 .35699 L F
.32897 .35804 m .32721 .3563 L .33 .35526 L F
.71395 .35908 m .71554 .35605 L .71692 .35792 L 0 .032 .133 r
F
.71395 .35908 m .71256 .3572 L .71554 .35605 L F
.29516 .3575 m .29614 .35474 L .29793 .35649 L 0 .03 .13 r
F
.29516 .3575 m .29337 .35575 L .29614 .35474 L F
.74331 .35754 m .74496 .35473 L .74631 .35656 L F
.74331 .35754 m .74195 .35573 L .74496 .35473 L F
.69194 .3604 m .6935 .35736 L .6949 .35912 L 0 .035 .137 r
F
.69194 .3604 m .69053 .35862 L .6935 .35736 L F
.73597 .35796 m .7376 .35505 L .73896 .35685 L 0 .03 .131 r
F
.73597 .35796 m .73461 .35618 L .7376 .35505 L F
.86963 .35553 m .87146 .35264 L .8727 .35448 L 0 .025 .124 r
F
.86963 .35553 m .8684 .35368 L .87146 .35264 L F
.38635 .36247 m .38746 .3599 L .38915 .36182 L 0 .041 .143 r
F
.38635 .36247 m .38466 .36053 L .38746 .3599 L F
.79914 .35699 m .80087 .35413 L .80217 .35599 L 0 .028 .128 r
F
.79914 .35699 m .79783 .35513 L .80087 .35413 L F
.23488 .35599 m .23576 .35324 L .23761 .35509 L 0 .027 .126 r
F
.23488 .35599 m .23303 .35414 L .23576 .35324 L F
.15992 .35518 m .1607 .35239 L .16262 .35423 L 0 .025 .123 r
F
.15992 .35518 m .15801 .35332 L .1607 .35239 L F
.67726 .36131 m .67881 .35842 L .68023 .36027 L 0 .038 .14 r
F
.67726 .36131 m .67584 .35946 L .67881 .35842 L F
.44975 .37393 m .45096 .37125 L .45259 .37347 L 0 .072 .173 r
F
.44975 .37393 m .44812 .37174 L .45096 .37125 L F
.81382 .35623 m .81557 .35334 L .81685 .3552 L 0 .027 .126 r
F
.81382 .35623 m .81253 .3544 L .81557 .35334 L F
.80648 .35664 m .80821 .35368 L .8095 .35549 L 0 .028 .127 r
F
.80648 .35664 m .80519 .35483 L .80821 .35368 L F
.20106 .35542 m .2019 .35272 L .20377 .35455 L 0 .026 .124 r
F
.20106 .35542 m .19919 .35358 L .2019 .35272 L F
.87698 .35522 m .87883 .35236 L .88005 .35417 L 0 .025 .124 r
F
.87698 .35522 m .87576 .35341 L .87883 .35236 L F
.40547 .364 m .40662 .36121 L .40829 .36331 L 0 .045 .147 r
F
.40547 .364 m .4038 .36196 L .40662 .36121 L F
.35542 .35937 m .35648 .35681 L .35821 .35859 L 0 .034 .135 r
F
.35542 .35937 m .35369 .35758 L .35648 .35681 L F
.49583 .40136 m .49702 .40876 L .49865 .40741 L 0 .217 .266 r
F
.49583 .40136 m .49422 .40169 L .49702 .40876 L F
.30248 .35739 m .30348 .35451 L .30525 .35643 L 0 .029 .129 r
F
.30248 .35739 m .3007 .35547 L .30348 .35451 L F
.26867 .35679 m .2696 .35408 L .27141 .35598 L 0 .028 .128 r
F
.26867 .35679 m .26686 .35489 L .2696 .35408 L F
.68461 .36107 m .68616 .35807 L .68757 .35989 L 0 .037 .139 r
F
.68461 .36107 m .6832 .35923 L .68616 .35807 L F
.37455 .36088 m .37565 .35803 L .37735 .36003 L F
.37455 .36088 m .37285 .35889 L .37565 .35803 L F
.5821 .37921 m .58351 .37645 L .58501 .37789 L 0 .09 .188 r
F
.5821 .37921 m .5806 .37801 L .58351 .37645 L F
.66993 .36192 m .67146 .35882 L .67289 .36067 L 0 .039 .141 r
F
.66993 .36192 m .66851 .3601 L .67146 .35882 L F
.88434 .355 m .88621 .35225 L .88743 .35406 L 0 .025 .123 r
F
.88434 .355 m .88313 .35321 L .88621 .35225 L F
.75067 .35745 m .75233 .35463 L .75368 .35649 L 0 .03 .13 r
F
.75067 .35745 m .74932 .35559 L .75233 .35463 L F
.62301 .36702 m .62447 .36376 L .62593 .36548 L 0 .052 .154 r
F
.62301 .36702 m .62154 .36536 L .62447 .36376 L F
.33628 .35807 m .33732 .35539 L .33906 .35729 L 0 .031 .132 r
F
.33628 .35807 m .33454 .35618 L .33732 .35539 L F
.61278 .37009 m .61423 .36699 L .6157 .36853 L 0 .06 .163 r
F
.61278 .37009 m .61131 .36859 L .61423 .36699 L F
.82118 .35605 m .82293 .35313 L .82422 .35501 L 0 .027 .126 r
F
.82118 .35605 m .81989 .35417 L .82293 .35313 L F
.6626 .36237 m .66413 .35956 L .66555 .36135 L 0 .041 .143 r
F
.6626 .36237 m .66117 .36061 L .66413 .35956 L F
.65526 .36278 m .65677 .35997 L .65821 .36167 L 0 .042 .144 r
F
.65526 .36278 m .65382 .3611 L .65677 .35997 L F
.48536 .3921 m .48657 .39377 L .48819 .39494 L 0 .153 .23 r
F
.48536 .3921 m .48375 .39068 L .48657 .39377 L F
.16723 .35508 m .16802 .35225 L .16993 .35407 L 0 .025 .124 r
F
.16723 .35508 m .16531 .35325 L .16802 .35225 L F
.42905 .36792 m .43023 .36505 L .43188 .36712 L 0 .055 .157 r
F
.42905 .36792 m .4274 .36585 L .43023 .36505 L F
.47044 .3806 m .47166 .37922 L .47328 .3811 L 0 .099 .194 r
F
.47044 .3806 m .46882 .37884 L .47166 .37922 L F
.41725 .36615 m .41842 .36324 L .42008 .36536 L 0 .05 .153 r
F
.41725 .36615 m .4156 .36401 L .41842 .36324 L F
.47489 .38286 m .47611 .38203 L .47772 .38392 L 0 .109 .201 r
F
.47489 .38286 m .47328 .3811 L .47611 .38203 L F
.20837 .35538 m .20922 .35258 L .21109 .35437 L 0 .026 .125 r
F
.20837 .35538 m .20649 .35357 L .20922 .35258 L F
.24218 .35602 m .24307 .35331 L .24491 .35513 L 0 .027 .127 r
F
.24218 .35602 m .24034 .35418 L .24307 .35331 L F
.82854 .35583 m .8303 .3529 L .83158 .35477 L 0 .027 .126 r
F
.82854 .35583 m .82726 .35396 L .8303 .3529 L F
.17454 .35486 m .17534 .35213 L .17725 .35392 L 0 .025 .124 r
F
.17454 .35486 m .17264 .35306 L .17534 .35213 L F
.60256 .3734 m .60399 .37026 L .60547 .3718 L 0 .071 .172 r
F
.60256 .3734 m .60108 .37188 L .60399 .37026 L F
.89172 .35489 m .89359 .35205 L .8948 .35388 L 0 .025 .123 r
F
.89172 .35489 m .89051 .35307 L .89359 .35205 L F
.75803 .35734 m .7597 .35454 L .76104 .35634 L 0 .03 .13 r
F
.75803 .35734 m .75669 .35551 L .7597 .35454 L F
.44529 .37222 m .44649 .36955 L .44812 .37174 L 0 .068 .17 r
F
.44529 .37222 m .44365 .37007 L .44649 .36955 L F
.21569 .35512 m .21654 .35251 L .21841 .35425 L 0 .026 .125 r
F
.21569 .35512 m .21382 .3534 L .21654 .35251 L F
.83589 .35553 m .83766 .35259 L .83893 .35443 L F
.83589 .35553 m .83462 .35368 L .83766 .35259 L F
.46598 .37855 m .4672 .37707 L .46882 .37884 L 0 .092 .189 r
F
.46598 .37855 m .46436 .37689 L .4672 .37707 L F
.64793 .36352 m .64943 .36063 L .65087 .36231 L 0 .044 .146 r
F
.64793 .36352 m .64649 .36182 L .64943 .36063 L F
.30979 .35743 m .3108 .35457 L .31256 .35649 L 0 .03 .13 r
F
.30979 .35743 m .30802 .3555 L .3108 .35457 L F
.84324 .35523 m .84504 .35242 L .84629 .35423 L 0 .026 .125 r
F
.84324 .35523 m .84198 .35341 L .84504 .35242 L F
.76538 .35708 m .76706 .3542 L .76839 .35599 L 0 .029 .129 r
F
.76538 .35708 m .76405 .35529 L .76706 .3542 L F
.77272 .35669 m .77442 .35392 L .77574 .35573 L F
.77272 .35669 m .7714 .3549 L .77442 .35392 L F
.36273 .35957 m .3638 .35702 L .36553 .35874 L 0 .035 .137 r
F
.36273 .35957 m .361 .35781 L .3638 .35702 L F
.27596 .35693 m .27693 .35404 L .27873 .3559 L 0 .029 .129 r
F
.27596 .35693 m .27416 .35505 L .27693 .35404 L F
.18185 .35476 m .18265 .35207 L .18456 .35382 L 0 .025 .124 r
F
.18185 .35476 m .17995 .353 L .18265 .35207 L F
.24948 .35602 m .25038 .35342 L .25222 .35514 L 0 .028 .127 r
F
.24948 .35602 m .24764 .35427 L .25038 .35342 L F
.28329 .35667 m .28425 .35399 L .28605 .35578 L 0 .029 .129 r
F
.28329 .35667 m .28149 .35487 L .28425 .35399 L F
.8506 .35504 m .8524 .35212 L .85365 .35395 L 0 .025 .124 r
F
.8506 .35504 m .84935 .35322 L .8524 .35212 L F
.39365 .363 m .39478 .36015 L .39647 .36199 L 0 .043 .145 r
F
.39365 .363 m .39196 .36112 L .39478 .36015 L F
.44082 .37035 m .44202 .36793 L .44365 .37007 L 0 .064 .166 r
F
.44082 .37035 m .43918 .36828 L .44202 .36793 L F
.38185 .3612 m .38296 .35851 L .38466 .36053 L 0 .039 .141 r
F
.38185 .3612 m .38016 .35918 L .38296 .35851 L F
.85795 .3547 m .85977 .35184 L .86101 .35369 L 0 .025 .124 r
F
.85795 .3547 m .8567 .35286 L .85977 .35184 L F
.223 .35511 m .22386 .35246 L .22572 .3542 L 0 .026 .125 r
F
.223 .35511 m .22113 .35337 L .22386 .35246 L F
.6406 .36431 m .64209 .36134 L .64354 .36306 L 0 .046 .149 r
F
.6406 .36431 m .63915 .36255 L .64209 .36134 L F
.18917 .35456 m .18999 .35177 L .19189 .35354 L 0 .025 .123 r
F
.18917 .35456 m .18727 .3528 L .18999 .35177 L F
.34358 .35843 m .34464 .35555 L .34637 .35748 L 0 .033 .133 r
F
.34358 .35843 m .34185 .35647 L .34464 .35555 L F
.78009 .35661 m .78179 .35373 L .78311 .35559 L 0 .029 .129 r
F
.78009 .35661 m .77877 .35477 L .78179 .35373 L F
.63326 .36478 m .63475 .3619 L .63621 .36372 L 0 .048 .15 r
F
.63326 .36478 m .6318 .36299 L .63475 .3619 L F
.3171 .35747 m .31811 .35472 L .31988 .35656 L 0 .031 .131 r
F
.3171 .35747 m .31533 .35561 L .31811 .35472 L F
.47933 .38581 m .48054 .38675 L .48215 .38889 L 0 .127 .214 r
F
.47933 .38581 m .47772 .38392 L .48054 .38675 L F
.2568 .35588 m .25772 .35317 L .25955 .3549 L 0 .028 .127 r
F
.2568 .35588 m .25496 .35417 L .25772 .35317 L F
.59235 .37706 m .59376 .37387 L .59526 .37541 L 0 .083 .182 r
F
.59235 .37706 m .59085 .37552 L .59376 .37387 L F
.40098 .36284 m .40212 .36011 L .4038 .36196 L 0 .043 .146 r
F
.40098 .36284 m .3993 .36098 L .40212 .36011 L F
.70223 .35856 m .70381 .35556 L .7052 .35743 L 0 .033 .134 r
F
.70223 .35856 m .70083 .35671 L .70381 .35556 L F
.78744 .35634 m .78914 .35335 L .79046 .35523 L 0 .028 .128 r
F
.78744 .35634 m .78613 .35447 L .78914 .35335 L F
.72426 .35738 m .72588 .35462 L .72725 .35642 L 0 .031 .131 r
F
.72426 .35738 m .72288 .35557 L .72588 .35462 L F
.70958 .35825 m .71117 .35532 L .71256 .3572 L 0 .033 .133 r
F
.70958 .35825 m .70819 .35638 L .71117 .35532 L F
.41277 .36478 m .41394 .36185 L .4156 .36401 L 0 .048 .151 r
F
.41277 .36478 m .41111 .36262 L .41394 .36185 L F
.86532 .35462 m .86716 .35182 L .8684 .35368 L 0 .025 .124 r
F
.86532 .35462 m .86408 .35276 L .86716 .35182 L F
.46152 .37702 m .46273 .37506 L .46436 .37689 L 0 .087 .185 r
F
.46152 .37702 m .45989 .37522 L .46273 .37506 L F
.29061 .35667 m .29157 .35399 L .29337 .35575 L 0 .03 .13 r
F
.29061 .35667 m .28881 .35491 L .29157 .35399 L F
.42457 .36665 m .42575 .36377 L .4274 .36585 L 0 .053 .156 r
F
.42457 .36665 m .42291 .36457 L .42575 .36377 L F
.6949 .35912 m .69647 .35615 L .69786 .35791 L 0 .034 .136 r
F
.6949 .35912 m .6935 .35736 L .69647 .35615 L F
.19648 .35444 m .19731 .35175 L .19919 .35358 L 0 .025 .124 r
F
.19648 .35444 m .1946 .35261 L .19731 .35175 L F
.37004 .35974 m .37113 .35707 L .37285 .35889 L 0 .036 .138 r
F
.37004 .35974 m .36833 .35792 L .37113 .35707 L F
.71692 .35792 m .71852 .35487 L .7199 .35673 L 0 .032 .132 r
F
.71692 .35792 m .71554 .35605 L .71852 .35487 L F
.2303 .35507 m .23118 .35236 L .23303 .35414 L 0 .026 .125 r
F
.2303 .35507 m .22845 .35328 L .23118 .35236 L F
.15532 .35426 m .15608 .35153 L .15801 .35332 L 0 .025 .123 r
F
.15532 .35426 m .15339 .35247 L .15608 .35153 L F
.7948 .3561 m .79652 .35327 L .79783 .35513 L 0 .028 .128 r
F
.7948 .3561 m .79349 .35423 L .79652 .35327 L F
.6157 .36853 m .61715 .36539 L .61862 .36696 L 0 .058 .16 r
F
.6157 .36853 m .61423 .36699 L .61715 .36539 L F
.62593 .36548 m .6274 .36231 L .62886 .36408 L 0 .049 .152 r
F
.62593 .36548 m .62447 .36376 L .6274 .36231 L F
.26412 .35571 m .26504 .35312 L .26686 .35489 L 0 .028 .127 r
F
.26412 .35571 m .2623 .35394 L .26504 .35312 L F
.32442 .35734 m .32545 .35455 L .32721 .3563 L 0 .031 .131 r
F
.32442 .35734 m .32266 .35559 L .32545 .35455 L F
.33176 .35699 m .33278 .35444 L .33454 .35618 L F
.33176 .35699 m .33 .35526 L .33278 .35444 L F
.3509 .35842 m .35196 .3557 L .35369 .35758 L 0 .033 .134 r
F
.3509 .35842 m .34917 .35653 L .35196 .3557 L F
.43636 .36861 m .43754 .3662 L .43918 .36828 L 0 .06 .162 r
F
.43636 .36861 m .43471 .3666 L .43754 .3662 L F
.73162 .35723 m .73325 .35442 L .73461 .35618 L 0 .031 .131 r
F
.73162 .35723 m .73025 .35545 L .73325 .35442 L F
.73896 .35685 m .7406 .35393 L .74195 .35573 L 0 .03 .13 r
F
.73896 .35685 m .7376 .35505 L .7406 .35393 L F
.29793 .35649 m .29892 .35373 L .3007 .35547 L 0 .029 .129 r
F
.29793 .35649 m .29614 .35474 L .29892 .35373 L F
.58501 .37789 m .58643 .37518 L .58793 .3767 L 0 .088 .186 r
F
.58501 .37789 m .58351 .37645 L .58643 .37518 L F
.8095 .35549 m .81124 .35258 L .81253 .3544 L 0 .027 .126 r
F
.8095 .35549 m .80821 .35368 L .81124 .35258 L F
.8727 .35448 m .87453 .35159 L .87576 .35341 L 0 .025 .124 r
F
.8727 .35448 m .87146 .35264 L .87453 .35159 L F
.60547 .3718 m .60691 .36864 L .60839 .37019 L 0 .067 .169 r
F
.60547 .3718 m .60399 .37026 L .60691 .36864 L F
.74631 .35656 m .74797 .35373 L .74932 .35559 L 0 .03 .13 r
F
.74631 .35656 m .74496 .35473 L .74797 .35373 L F
.67289 .36067 m .67442 .35758 L .67584 .35946 L 0 .038 .14 r
F
.67289 .36067 m .67146 .35882 L .67442 .35758 L F
.543 .41016 m .54442 .41735 L .5459 .40922 L 0 .271 .292 r
F
.543 .41016 m .5415 .41829 L .54442 .41735 L F
.80217 .35599 m .80389 .35301 L .80519 .35483 L 0 .028 .128 r
F
.80217 .35599 m .80087 .35413 L .80389 .35301 L F
.68023 .36027 m .68178 .35738 L .6832 .35923 L 0 .038 .139 r
F
.68023 .36027 m .67881 .35842 L .68178 .35738 L F
.88005 .35417 m .88191 .35141 L .88313 .35321 L 0 .025 .123 r
F
.88005 .35417 m .87883 .35236 L .88191 .35141 L F
.81685 .3552 m .81861 .35229 L .81989 .35417 L 0 .027 .126 r
F
.81685 .3552 m .81557 .35334 L .81861 .35229 L F
.68757 .35989 m .68913 .35684 L .69053 .35862 L 0 .036 .138 r
F
.68757 .35989 m .68616 .35807 L .68913 .35684 L F
.16262 .35423 m .1634 .35142 L .16531 .35325 L 0 .025 .124 r
F
.16262 .35423 m .1607 .35239 L .1634 .35142 L F
.51809 .41412 m .51938 .42561 L .52097 .41872 L 0 .309 .307 r
F
.51809 .41412 m .51649 .41945 L .51938 .42561 L F
.23761 .35509 m .2385 .35235 L .24034 .35418 L 0 .027 .126 r
F
.23761 .35509 m .23576 .35324 L .2385 .35235 L F
.65821 .36167 m .65973 .35891 L .66117 .36061 L 0 .041 .143 r
F
.65821 .36167 m .65677 .35997 L .65973 .35891 L F
.20377 .35455 m .20462 .35175 L .20649 .35357 L 0 .026 .125 r
F
.20377 .35455 m .2019 .35272 L .20462 .35175 L F
.45705 .37537 m .45827 .37297 L .45989 .37522 L 0 .081 .181 r
F
.45705 .37537 m .45543 .37314 L .45827 .37297 L F
.82422 .35501 m .82598 .35208 L .82726 .35396 L 0 .027 .126 r
F
.82422 .35501 m .82293 .35313 L .82598 .35208 L F
.30525 .35643 m .30625 .35357 L .30802 .3555 L 0 .03 .13 r
F
.30525 .35643 m .30348 .35451 L .30625 .35357 L F
.66555 .36135 m .66708 .35828 L .66851 .3601 L 0 .04 .142 r
F
.66555 .36135 m .66413 .35956 L .66708 .35828 L F
.75368 .35649 m .75534 .35366 L .75669 .35551 L 0 .03 .13 r
F
.75368 .35649 m .75233 .35463 L .75534 .35366 L F
.88743 .35406 m .88929 .35125 L .89051 .35307 L 0 .025 .124 r
F
.88743 .35406 m .88621 .35225 L .88929 .35125 L F
.16993 .35407 m .17073 .35124 L .17264 .35306 L 0 .025 .123 r
F
.16993 .35407 m .16802 .35225 L .17073 .35124 L F
.38915 .36182 m .39027 .35923 L .39196 .36112 L 0 .042 .144 r
F
.38915 .36182 m .38746 .3599 L .39027 .35923 L F
.35821 .35859 m .35928 .35605 L .361 .35781 L 0 .035 .136 r
F
.35821 .35859 m .35648 .35681 L .35928 .35605 L F
.37735 .36003 m .37846 .35716 L .38016 .35918 L 0 .038 .139 r
F
.37735 .36003 m .37565 .35803 L .37846 .35716 L F
.27141 .35598 m .27236 .35316 L .27416 .35505 L 0 .029 .129 r
F
.27141 .35598 m .2696 .35408 L .27236 .35316 L F
.40829 .36331 m .40945 .36045 L .41111 .36262 L 0 .046 .148 r
F
.40829 .36331 m .40662 .36121 L .40945 .36045 L F
.48979 .3961 m .49099 .40111 L .4926 .40189 L 0 .188 .25 r
F
.48979 .3961 m .48819 .39494 L .49099 .40111 L F
.83158 .35477 m .83335 .35182 L .83462 .35368 L 0 .026 .125 r
F
.83158 .35477 m .8303 .3529 L .83335 .35182 L F
.65087 .36231 m .65238 .35943 L .65382 .3611 L 0 .043 .145 r
F
.65087 .36231 m .64943 .36063 L .65238 .35943 L F
.21109 .35437 m .21195 .35162 L .21382 .3534 L 0 .026 .125 r
F
.21109 .35437 m .20922 .35258 L .21195 .35162 L F
.59526 .37541 m .59667 .3721 L .59816 .37363 L 0 .079 .179 r
F
.59526 .37541 m .59376 .37387 L .59667 .3721 L F
.83893 .35443 m .84072 .35158 L .84198 .35341 L 0 .026 .125 r
F
.83893 .35443 m .83766 .35259 L .84072 .35158 L F
.33906 .35729 m .34011 .35458 L .34185 .35647 L 0 .032 .133 r
F
.33906 .35729 m .33732 .35539 L .34011 .35458 L F
.57479 .38154 m .5762 .37927 L .57769 .37978 L 0 .104 .198 r
F
.57479 .38154 m .5733 .38152 L .5762 .37927 L F
.5719 .38428 m .5733 .38152 L .57479 .38154 L 0 .113 .205 r
F
.43188 .36712 m .43306 .36455 L .43471 .3666 L 0 .056 .159 r
F
.43188 .36712 m .43023 .36505 L .43306 .36455 L F
.8948 .35388 m .89667 .35104 L .89788 .35287 L 0 .025 .123 r
F
.8948 .35388 m .89359 .35205 L .89667 .35104 L F
.76104 .35634 m .76272 .35349 L .76405 .35529 L 0 .03 .13 r
F
.76104 .35634 m .7597 .35454 L .76272 .35349 L F
.24491 .35513 m .2458 .35248 L .24764 .35427 L 0 .028 .127 r
F
.24491 .35513 m .24307 .35331 L .2458 .35248 L F
.45259 .37347 m .4538 .3709 L .45543 .37314 L 0 .075 .176 r
F
.45259 .37347 m .45096 .37125 L .4538 .3709 L F
.17725 .35392 m .17804 .35122 L .17995 .353 L 0 .025 .124 r
F
.17725 .35392 m .17534 .35213 L .17804 .35122 L F
.5719 .38428 m .57042 .385 L .5733 .38152 L 0 .113 .205 r
F
.56901 .38704 m .57042 .385 L .5719 .38428 L 0 .126 .214 r
F
.76839 .35599 m .77007 .35312 L .7714 .3549 L 0 .029 .129 r
F
.76839 .35599 m .76706 .3542 L .77007 .35312 L F
.42008 .36536 m .42126 .36245 L .42291 .36457 L 0 .051 .154 r
F
.42008 .36536 m .41842 .36324 L .42126 .36245 L F
.84629 .35423 m .8481 .35142 L .84935 .35322 L 0 .026 .125 r
F
.84629 .35423 m .84504 .35242 L .8481 .35142 L F
.56901 .38704 m .56753 .38851 L .57042 .385 L 0 .126 .214 r
F
.56613 .38993 m .56753 .38851 L .56901 .38704 L 0 .141 .223 r
F
.21841 .35425 m .21926 .35163 L .22113 .35337 L 0 .026 .125 r
F
.21841 .35425 m .21654 .35251 L .21926 .35163 L F
.31256 .35649 m .31357 .35371 L .31533 .35561 L 0 .03 .131 r
F
.31256 .35649 m .3108 .35457 L .31357 .35371 L F
.27873 .3559 m .27969 .35303 L .28149 .35487 L 0 .029 .129 r
F
.27873 .3559 m .27693 .35404 L .27969 .35303 L F
.64354 .36306 m .64504 .36012 L .64649 .36182 L 0 .045 .148 r
F
.64354 .36306 m .64209 .36134 L .64504 .36012 L F
.77574 .35573 m .77745 .35294 L .77877 .35477 L 0 .029 .129 r
F
.77574 .35573 m .77442 .35392 L .77745 .35294 L F
.61862 .36696 m .62007 .36374 L .62154 .36536 L 0 .055 .157 r
F
.61862 .36696 m .61715 .36539 L .62007 .36374 L F
.85365 .35395 m .85545 .35102 L .8567 .35286 L 0 .025 .124 r
F
.85365 .35395 m .8524 .35212 L .85545 .35102 L F
.18456 .35382 m .18537 .35103 L .18727 .3528 L F
.18456 .35382 m .18265 .35207 L .18537 .35103 L F
.39647 .36199 m .39761 .35917 L .3993 .36098 L 0 .043 .145 r
F
.39647 .36199 m .39478 .36015 L .39761 .35917 L F
.36553 .35874 m .3666 .35622 L .36833 .35792 L 0 .036 .137 r
F
.36553 .35874 m .3638 .35702 L .3666 .35622 L F
.56324 .39305 m .56465 .39222 L .56613 .38993 L 0 .158 .233 r
F
.86101 .35369 m .86284 .3509 L .86408 .35276 L 0 .025 .124 r
F
.86101 .35369 m .85977 .35184 L .86284 .3509 L F
.60839 .37019 m .60983 .36705 L .61131 .36859 L 0 .065 .166 r
F
.60839 .37019 m .60691 .36864 L .60983 .36705 L F
.62886 .36408 m .63034 .3612 L .6318 .36299 L 0 .048 .151 r
F
.62886 .36408 m .6274 .36231 L .63034 .3612 L F
.50026 .40606 m .50148 .4135 L .5031 .41114 L 0 .25 .282 r
F
.50026 .40606 m .49865 .40741 L .50148 .4135 L F
.25222 .35514 m .25313 .35244 L .25496 .35417 L 0 .028 .128 r
F
.25222 .35514 m .25038 .35342 L .25313 .35244 L F
.63621 .36372 m .63769 .36074 L .63915 .36255 L 0 .047 .15 r
F
.63621 .36372 m .63475 .3619 L .63769 .36074 L F
.19189 .35354 m .19271 .35083 L .1946 .35261 L 0 .025 .123 r
F
.19189 .35354 m .18999 .35177 L .19271 .35083 L F
.28605 .35578 m .28701 .35312 L .28881 .35491 L 0 .029 .129 r
F
.28605 .35578 m .28425 .35399 L .28701 .35312 L F
.78311 .35559 m .78481 .3526 L .78613 .35447 L 0 .029 .128 r
F
.78311 .35559 m .78179 .35373 L .78481 .3526 L F
.7052 .35743 m .70679 .35449 L .70819 .35638 L 0 .033 .133 r
F
.7052 .35743 m .70381 .35556 L .70679 .35449 L F
.22572 .3542 m .22659 .35154 L .22845 .35328 L 0 .026 .125 r
F
.22572 .3542 m .22386 .35246 L .22659 .35154 L F
.79046 .35523 m .79218 .35235 L .79349 .35423 L 0 .028 .128 r
F
.79046 .35523 m .78914 .35335 L .79218 .35235 L F
.44812 .37174 m .44933 .36904 L .45096 .37125 L 0 .07 .172 r
F
.44812 .37174 m .44649 .36955 L .44933 .36904 L F
.34637 .35748 m .34744 .35463 L .34917 .35653 L 0 .033 .134 r
F
.34637 .35748 m .34464 .35555 L .34744 .35463 L F
.69786 .35791 m .69944 .35494 L .70083 .35671 L 0 .034 .135 r
F
.69786 .35791 m .69647 .35615 L .69944 .35494 L F
.7199 .35673 m .72151 .35373 L .72288 .35557 L 0 .031 .131 r
F
.7199 .35673 m .71852 .35487 L .72151 .35373 L F
.25955 .3549 m .26047 .3522 L .2623 .35394 L 0 .028 .127 r
F
.25955 .3549 m .25772 .35317 L .26047 .3522 L F
.31988 .35656 m .32089 .35377 L .32266 .35559 L 0 .031 .131 r
F
.31988 .35656 m .31811 .35472 L .32089 .35377 L F
.71256 .3572 m .71415 .35417 L .71554 .35605 L 0 .032 .133 r
F
.71256 .3572 m .71117 .35532 L .71415 .35417 L F
.72725 .35642 m .72889 .35367 L .73025 .35545 L 0 .031 .131 r
F
.72725 .35642 m .72588 .35462 L .72889 .35367 L F
.38466 .36053 m .38577 .35789 L .38746 .3599 L 0 .04 .142 r
F
.38466 .36053 m .38296 .35851 L .38577 .35789 L F
.4038 .36196 m .40494 .35934 L .40662 .36121 L 0 .044 .146 r
F
.4038 .36196 m .40212 .36011 L .40494 .35934 L F
.32721 .3563 m .32824 .35352 L .33 .35526 L 0 .031 .131 r
F
.32721 .3563 m .32545 .35455 L .32824 .35352 L F
.59816 .37363 m .59959 .37036 L .60108 .37188 L 0 .075 .176 r
F
.59816 .37363 m .59667 .3721 L .59959 .37036 L F
.8684 .35368 m .87023 .3508 L .87146 .35264 L 0 .025 .124 r
F
.8684 .35368 m .86716 .35182 L .87023 .3508 L F
.58793 .3767 m .58935 .3739 L .59085 .37552 L 0 .087 .185 r
F
.58793 .3767 m .58643 .37518 L .58935 .3739 L F
.74195 .35573 m .7436 .35289 L .74496 .35473 L 0 .03 .13 r
F
.74195 .35573 m .7406 .35393 L .7436 .35289 L F
.57769 .37978 m .5791 .37701 L .5806 .37801 L 0 .098 .194 r
F
.57769 .37978 m .5762 .37927 L .5791 .37701 L F
.79783 .35513 m .79956 .35228 L .80087 .35413 L 0 .028 .128 r
F
.79783 .35513 m .79652 .35327 L .79956 .35228 L F
.29337 .35575 m .29435 .35299 L .29614 .35474 L 0 .03 .13 r
F
.29337 .35575 m .29157 .35399 L .29435 .35299 L F
.56324 .39305 m .56177 .39629 L .56465 .39222 L 0 .158 .233 r
F
.56036 .39617 m .56177 .39629 L .56324 .39305 L 0 .177 .244 r
F
.73461 .35618 m .73625 .35332 L .7376 .35505 L 0 .03 .131 r
F
.73461 .35618 m .73325 .35442 L .73625 .35332 L F
.15801 .35332 m .15878 .35058 L .1607 .35239 L 0 .025 .123 r
F
.15801 .35332 m .15608 .35153 L .15878 .35058 L F
.23303 .35414 m .23391 .35145 L .23576 .35324 L 0 .027 .126 r
F
.23303 .35414 m .23118 .35236 L .23391 .35145 L F
.69053 .35862 m .6921 .3556 L .6935 .35736 L 0 .035 .137 r
F
.69053 .35862 m .68913 .35684 L .6921 .3556 L F
.52543 .41508 m .52677 .428 L .52833 .41824 L 0 .317 .304 r
F
.52543 .41508 m .52386 .42335 L .52677 .428 L F
.67584 .35946 m .67739 .35652 L .67881 .35842 L 0 .038 .139 r
F
.67584 .35946 m .67442 .35758 L .67739 .35652 L F
.19919 .35358 m .20002 .35089 L .2019 .35272 L 0 .026 .124 r
F
.19919 .35358 m .19731 .35175 L .20002 .35089 L F
.81253 .3544 m .81428 .35151 L .81557 .35334 L 0 .027 .126 r
F
.81253 .3544 m .81124 .35258 L .81428 .35151 L F
.50472 .4088 m .50593 .42023 L .50755 .41636 L 0 .284 .297 r
F
.50472 .4088 m .5031 .41114 L .50593 .42023 L F
.37285 .35889 m .37394 .35618 L .37565 .35803 L 0 .037 .138 r
F
.37285 .35889 m .37113 .35707 L .37394 .35618 L F
.80519 .35483 m .80692 .35188 L .80821 .35368 L 0 .028 .127 r
F
.80519 .35483 m .80389 .35301 L .80692 .35188 L F
.87576 .35341 m .8776 .35056 L .87883 .35236 L 0 .025 .124 r
F
.87576 .35341 m .87453 .35159 L .8776 .35056 L F
.4156 .36401 m .41676 .36108 L .41842 .36324 L 0 .049 .151 r
F
.4156 .36401 m .41394 .36185 L .41676 .36108 L F
.4274 .36585 m .42858 .36297 L .43023 .36505 L 0 .054 .156 r
F
.4274 .36585 m .42575 .36377 L .42858 .36297 L F
.3007 .35547 m .30169 .35275 L .30348 .35451 L 0 .029 .129 r
F
.3007 .35547 m .29892 .35373 L .30169 .35275 L F
.26686 .35489 m .26779 .35229 L .2696 .35408 L 0 .028 .128 r
F
.26686 .35489 m .26504 .35312 L .26779 .35229 L F
.35369 .35758 m .35475 .35494 L .35648 .35681 L 0 .034 .135 r
F
.35369 .35758 m .35196 .3557 L .35475 .35494 L F
.6832 .35923 m .68475 .35624 L .68616 .35807 L 0 .037 .139 r
F
.6832 .35923 m .68178 .35738 L .68475 .35624 L F
.33454 .35618 m .33557 .35366 L .33732 .35539 L 0 .031 .132 r
F
.33454 .35618 m .33278 .35444 L .33557 .35366 L F
.74932 .35559 m .75098 .35275 L .75233 .35463 L 0 .03 .13 r
F
.74932 .35559 m .74797 .35373 L .75098 .35275 L F
.81989 .35417 m .82165 .35124 L .82293 .35313 L 0 .027 .126 r
F
.81989 .35417 m .81861 .35229 L .82165 .35124 L F
.44365 .37007 m .44486 .36738 L .44649 .36955 L 0 .066 .168 r
F
.44365 .37007 m .44202 .36793 L .44486 .36738 L F
.66851 .3601 m .67003 .35696 L .67146 .35882 L 0 .039 .141 r
F
.66851 .3601 m .66708 .35828 L .67003 .35696 L F
.5459 .40922 m .54732 .41491 L .5488 .40725 L 0 .266 .289 r
F
.5459 .40922 m .54442 .41735 L .54732 .41491 L F
.88313 .35321 m .885 .35045 L .88621 .35225 L 0 .025 .124 r
F
.88313 .35321 m .88191 .35141 L .885 .35045 L F
.16531 .35325 m .16611 .35042 L .16802 .35225 L F
.16531 .35325 m .1634 .35142 L .16611 .35042 L F
.66117 .36061 m .6627 .35785 L .66413 .35956 L 0 .041 .143 r
F
.66117 .36061 m .65973 .35891 L .6627 .35785 L F
.62154 .36536 m .623 .3621 L .62447 .36376 L 0 .052 .155 r
F
.62154 .36536 m .62007 .36374 L .623 .3621 L F
.82726 .35396 m .82902 .35102 L .8303 .3529 L 0 .026 .125 r
F
.82726 .35396 m .82598 .35208 L .82902 .35102 L F
.65382 .3611 m .65534 .3583 L .65677 .35997 L 0 .042 .144 r
F
.65382 .3611 m .65238 .35943 L .65534 .3583 L F
.20649 .35357 m .20734 .35078 L .20922 .35258 L 0 .026 .125 r
F
.20649 .35357 m .20462 .35175 L .20734 .35078 L F
.46882 .37884 m .47004 .37732 L .47166 .37922 L 0 .099 .194 r
F
.46882 .37884 m .4672 .37707 L .47004 .37732 L F
.24034 .35418 m .24123 .35149 L .24307 .35331 L 0 .027 .126 r
F
.24034 .35418 m .2385 .35235 L .24123 .35149 L F
.56036 .39617 m .55889 .40037 L .56177 .39629 L 0 .177 .244 r
F
.55747 .39926 m .55889 .40037 L .56036 .39617 L 0 .197 .255 r
F
.47328 .3811 m .4745 .37996 L .47611 .38203 L 0 .108 .201 r
F
.47328 .3811 m .47166 .37922 L .4745 .37996 L F
.53278 .41517 m .53415 .42439 L .53568 .41715 L 0 .311 .307 r
F
.53278 .41517 m .53123 .42144 L .53415 .42439 L F
.30802 .3555 m .30903 .35265 L .3108 .35457 L 0 .03 .13 r
F
.30802 .3555 m .30625 .35357 L .30903 .35265 L F
.17264 .35306 m .17343 .35032 L .17534 .35213 L 0 .025 .124 r
F
.17264 .35306 m .17073 .35124 L .17343 .35032 L F
.83462 .35368 m .8364 .35074 L .83766 .35259 L 0 .026 .125 r
F
.83462 .35368 m .83335 .35182 L .8364 .35074 L F
.75669 .35551 m .75836 .3527 L .7597 .35454 L 0 .03 .13 r
F
.75669 .35551 m .75534 .35366 L .75836 .3527 L F
.89051 .35307 m .89238 .35023 L .89359 .35205 L 0 .025 .123 r
F
.89051 .35307 m .88929 .35125 L .89238 .35023 L F
.61131 .36859 m .61276 .36549 L .61423 .36699 L 0 .062 .164 r
F
.61131 .36859 m .60983 .36705 L .61276 .36549 L F
.48215 .38889 m .48337 .38958 L .48497 .39199 L 0 .153 .23 r
F
.48497 .39199 m .48337 .38958 L .48393 .39082 L 0 .194 .254 r
F
.48375 .39068 m .48497 .39199 L .486 .39315 L 0 .155 .231 r
F
.48497 .39199 m .48393 .39082 L .48616 .39576 L 0 .194 .254 r
F
.486 .39315 m .48497 .39199 L .48657 .39377 L 0 .155 .231 r
F
.48375 .39068 m .48215 .38889 L .48497 .39199 L F
.21382 .3534 m .21467 .35074 L .21654 .35251 L 0 .026 .125 r
F
.21382 .3534 m .21195 .35162 L .21467 .35074 L F
.43918 .36828 m .44038 .3658 L .44202 .36793 L 0 .062 .165 r
F
.43918 .36828 m .43754 .3662 L .44038 .3658 L F
.84198 .35341 m .84378 .35061 L .84504 .35242 L 0 .026 .125 r
F
.84198 .35341 m .84072 .35158 L .84378 .35061 L F
.27416 .35505 m .27512 .35218 L .27693 .35404 L 0 .029 .129 r
F
.27416 .35505 m .27236 .35316 L .27512 .35218 L F
.46436 .37689 m .46558 .37515 L .4672 .37707 L 0 .092 .189 r
F
.46436 .37689 m .46273 .37506 L .46558 .37515 L F
.76405 .35529 m .76573 .35241 L .76706 .3542 L 0 .029 .129 r
F
.76405 .35529 m .76272 .35349 L .76573 .35241 L F
.64649 .36182 m .64799 .35893 L .64943 .36063 L 0 .044 .147 r
F
.64649 .36182 m .64504 .36012 L .64799 .35893 L F
.7714 .3549 m .7731 .35216 L .77442 .35392 L 0 .029 .129 r
F
.7714 .3549 m .77007 .35312 L .7731 .35216 L F
.38016 .35918 m .38127 .35649 L .38296 .35851 L 0 .038 .14 r
F
.38016 .35918 m .37846 .35716 L .38127 .35649 L F
.361 .35781 m .36207 .35529 L .3638 .35702 L 0 .036 .137 r
F
.361 .35781 m .35928 .35605 L .36207 .35529 L F
.60108 .37188 m .60251 .36872 L .60399 .37026 L 0 .072 .173 r
F
.60108 .37188 m .59959 .37036 L .60251 .36872 L F
.5806 .37801 m .58201 .37509 L .58351 .37645 L 0 .093 .19 r
F
.5806 .37801 m .5791 .37701 L .58201 .37509 L F
.39196 .36112 m .39309 .35827 L .39478 .36015 L 0 .043 .145 r
F
.39196 .36112 m .39027 .35923 L .39309 .35827 L F
.55747 .39926 m .556 .40446 L .55889 .40037 L 0 .197 .255 r
F
.55458 .40234 m .556 .40446 L .55747 .39926 L 0 .218 .266 r
F
.17995 .353 m .18075 .3503 L .18265 .35207 L 0 .025 .124 r
F
.17995 .353 m .17804 .35122 L .18075 .3503 L F
.34185 .35647 m .3429 .35368 L .34464 .35555 L 0 .032 .133 r
F
.34185 .35647 m .34011 .35458 L .3429 .35368 L F
.84935 .35322 m .85115 .35032 L .8524 .35212 L 0 .025 .124 r
F
.84935 .35322 m .8481 .35142 L .85115 .35032 L F
.51362 .41417 m .51489 .42541 L .51649 .41945 L 0 .313 .306 r
F
.51362 .41417 m .51202 .41866 L .51489 .42541 L F
.5488 .40725 m .55022 .41246 L .5517 .40528 L 0 .255 .284 r
F
.5488 .40725 m .54732 .41491 L .55022 .41246 L F
.41111 .36262 m .41227 .35969 L .41394 .36185 L 0 .047 .149 r
F
.41111 .36262 m .40945 .36045 L .41227 .35969 L F
.28149 .35487 m .28245 .35216 L .28425 .35399 L 0 .029 .129 r
F
.28149 .35487 m .27969 .35303 L .28245 .35216 L F
.24764 .35427 m .24854 .35165 L .25038 .35342 L 0 .028 .128 r
F
.24764 .35427 m .2458 .35248 L .24854 .35165 L F
.8567 .35286 m .85852 .34999 L .85977 .35184 L 0 .025 .123 r
F
.8567 .35286 m .85545 .35102 L .85852 .34999 L F
.77877 .35477 m .78047 .35189 L .78179 .35373 L 0 .029 .129 r
F
.77877 .35477 m .77745 .35294 L .78047 .35189 L F
.47772 .38392 m .47893 .3846 L .48054 .38675 L 0 .126 .213 r
F
.47772 .38392 m .47611 .38203 L .47893 .3846 L F
.42291 .36457 m .42409 .36165 L .42575 .36377 L 0 .052 .154 r
F
.42291 .36457 m .42126 .36245 L .42409 .36165 L F
.31533 .35561 m .31635 .35286 L .31811 .35472 L 0 .031 .131 r
F
.31533 .35561 m .31357 .35371 L .31635 .35286 L F
.22113 .35337 m .22199 .35072 L .22386 .35246 L 0 .026 .125 r
F
.22113 .35337 m .21926 .35163 L .22199 .35072 L F
.63915 .36255 m .64064 .35954 L .64209 .36134 L 0 .046 .149 r
F
.63915 .36255 m .63769 .36074 L .64064 .35954 L F
.18727 .3528 m .1881 .34999 L .18999 .35177 L 0 .025 .124 r
F
.18727 .3528 m .18537 .35103 L .1881 .34999 L F
.6318 .36299 m .63329 .36008 L .63475 .3619 L 0 .048 .15 r
F
.6318 .36299 m .63034 .3612 L .63329 .36008 L F
.3993 .36098 m .40043 .3583 L .40212 .36011 L 0 .043 .146 r
F
.3993 .36098 m .39761 .35917 L .40043 .3583 L F
.70083 .35671 m .70242 .35379 L .70381 .35556 L 0 .033 .134 r
F
.70083 .35671 m .69944 .35494 L .70242 .35379 L F
.78613 .35447 m .78783 .35147 L .78914 .35335 L 0 .028 .128 r
F
.78613 .35447 m .78481 .3526 L .78783 .35147 L F
.70819 .35638 m .70978 .35343 L .71117 .35532 L 0 .032 .133 r
F
.70819 .35638 m .70679 .35449 L .70978 .35343 L F
.72288 .35557 m .72451 .3528 L .72588 .35462 L 0 .031 .131 r
F
.72288 .35557 m .72151 .35373 L .72451 .3528 L F
.43471 .3666 m .43589 .36418 L .43754 .3662 L 0 .059 .161 r
F
.43471 .3666 m .43306 .36455 L .43589 .36418 L F
.25496 .35417 m .25588 .35143 L .25772 .35317 L 0 .028 .128 r
F
.25496 .35417 m .25313 .35244 L .25588 .35143 L F
.86408 .35276 m .86592 .34995 L .86716 .35182 L 0 .025 .124 r
F
.86408 .35276 m .86284 .3509 L .86592 .34995 L F
.71554 .35605 m .71714 .35299 L .71852 .35487 L 0 .031 .132 r
F
.71554 .35605 m .71415 .35417 L .71714 .35299 L F
.45989 .37522 m .46111 .3728 L .46273 .37506 L 0 .085 .184 r
F
.45989 .37522 m .45827 .37297 L .46111 .3728 L F
.55458 .40234 m .55312 .40856 L .556 .40446 L 0 .218 .266 r
F
.5517 .40528 m .55312 .40856 L .55458 .40234 L 0 .239 .276 r
F
.79349 .35423 m .79521 .35137 L .79652 .35327 L 0 .028 .128 r
F
.79349 .35423 m .79218 .35235 L .79521 .35137 L F
.1946 .35261 m .19542 .34996 L .19731 .35175 L 0 .025 .124 r
F
.1946 .35261 m .19271 .35083 L .19542 .34996 L F
.36833 .35792 m .36941 .35538 L .37113 .35707 L 0 .037 .138 r
F
.36833 .35792 m .3666 .35622 L .36941 .35538 L F
.34917 .35653 m .35023 .35381 L .35196 .3557 L 0 .033 .134 r
F
.34917 .35653 m .34744 .35463 L .35023 .35381 L F
.28881 .35491 m .28978 .3522 L .29157 .35399 L 0 .03 .13 r
F
.28881 .35491 m .28701 .35312 L .28978 .3522 L F
.6935 .35736 m .69507 .3544 L .69647 .35615 L 0 .035 .136 r
F
.6935 .35736 m .6921 .3556 L .69507 .3544 L F
.22845 .35328 m .22932 .35062 L .23118 .35236 L 0 .027 .126 r
F
.22845 .35328 m .22659 .35154 L .22932 .35062 L F
.15339 .35247 m .15415 .34973 L .15608 .35153 L 0 .025 .123 r
F
.15339 .35247 m .15146 .35068 L .15415 .34973 L F
.59085 .37552 m .59226 .37224 L .59376 .37387 L 0 .084 .183 r
F
.59085 .37552 m .58935 .3739 L .59226 .37224 L F
.2623 .35394 m .26321 .35137 L .26504 .35312 L 0 .028 .128 r
F
.2623 .35394 m .26047 .3522 L .26321 .35137 L F
.32266 .35559 m .32369 .35275 L .32545 .35455 L 0 .031 .131 r
F
.32266 .35559 m .32089 .35377 L .32369 .35275 L F
.62447 .36376 m .62593 .36061 L .6274 .36231 L 0 .05 .152 r
F
.62447 .36376 m .623 .3621 L .62593 .36061 L F
.45543 .37314 m .45664 .37072 L .45827 .37297 L 0 .079 .179 r
F
.45543 .37314 m .4538 .3709 L .45664 .37072 L F
.50916 .41251 m .5104 .42406 L .51202 .41866 L 0 .31 .307 r
F
.50916 .41251 m .50755 .41636 L .5104 .42406 L F
.73025 .35545 m .73189 .35266 L .73325 .35442 L 0 .031 .131 r
F
.73025 .35545 m .72889 .35367 L .73189 .35266 L F
.7376 .35505 m .73925 .35222 L .7406 .35393 L 0 .03 .13 r
F
.7376 .35505 m .73625 .35332 L .73925 .35222 L F
.33 .35526 m .33102 .3527 L .33278 .35444 L 0 .031 .131 r
F
.33 .35526 m .32824 .35352 L .33102 .3527 L F
.87146 .35264 m .8733 .34976 L .87453 .35159 L 0 .025 .124 r
F
.87146 .35264 m .87023 .3508 L .8733 .34976 L F
.80821 .35368 m .80995 .35078 L .81124 .35258 L 0 .027 .126 r
F
.80821 .35368 m .80692 .35188 L .80995 .35078 L F
.5517 .40528 m .55022 .41246 L .55312 .40856 L 0 .239 .276 r
F
.74496 .35473 m .74661 .35187 L .74797 .35373 L 0 .029 .129 r
F
.74496 .35473 m .7436 .35289 L .74661 .35187 L F
.67146 .35882 m .67299 .35569 L .67442 .35758 L 0 .038 .14 r
F
.67146 .35882 m .67003 .35696 L .67299 .35569 L F
.29614 .35474 m .29712 .35199 L .29892 .35373 L 0 .03 .13 r
F
.29614 .35474 m .29435 .35299 L .29712 .35199 L F
.80087 .35413 m .80259 .35117 L .80389 .35301 L 0 .028 .128 r
F
.80087 .35413 m .79956 .35228 L .80259 .35117 L F
.67881 .35842 m .68036 .35545 L .68178 .35738 L 0 .037 .139 r
F
.67881 .35842 m .67739 .35652 L .68036 .35545 L F
.61423 .36699 m .61568 .36393 L .61715 .36539 L 0 .059 .161 r
F
.61423 .36699 m .61276 .36549 L .61568 .36393 L F
.81557 .35334 m .81732 .35044 L .81861 .35229 L 0 .027 .126 r
F
.81557 .35334 m .81428 .35151 L .81732 .35044 L F
.68616 .35807 m .68772 .35504 L .68913 .35684 L 0 .036 .138 r
F
.68616 .35807 m .68475 .35624 L .68772 .35504 L F
.87883 .35236 m .88069 .3496 L .88191 .35141 L 0 .025 .123 r
F
.87883 .35236 m .8776 .35056 L .88069 .3496 L F
.1607 .35239 m .16148 .34961 L .1634 .35142 L 0 .025 .124 r
F
.1607 .35239 m .15878 .35058 L .16148 .34961 L F
.23576 .35324 m .23665 .35054 L .2385 .35235 L 0 .027 .126 r
F
.23576 .35324 m .23391 .35145 L .23665 .35054 L F
.40662 .36121 m .40777 .35858 L .40945 .36045 L 0 .045 .147 r
F
.40662 .36121 m .40494 .35934 L .40777 .35858 L F
.30348 .35451 m .30447 .35178 L .30625 .35357 L 0 .029 .129 r
F
.30348 .35451 m .30169 .35275 L .30447 .35178 L F
.45096 .37125 m .45218 .36866 L .4538 .3709 L 0 .073 .174 r
F
.45096 .37125 m .44933 .36904 L .45218 .36866 L F
.82293 .35313 m .8247 .3502 L .82598 .35208 L 0 .026 .125 r
F
.82293 .35313 m .82165 .35124 L .8247 .3502 L F
.2019 .35272 m .20274 .34994 L .20462 .35175 L F
.2019 .35272 m .20002 .35089 L .20274 .34994 L F
.37565 .35803 m .37675 .3553 L .37846 .35716 L 0 .037 .139 r
F
.37565 .35803 m .37394 .35618 L .37675 .3553 L F
.60399 .37026 m .60543 .36709 L .60691 .36864 L 0 .069 .17 r
F
.60399 .37026 m .60251 .36872 L .60543 .36709 L F
.38746 .3599 m .38858 .35722 L .39027 .35923 L 0 .042 .144 r
F
.38746 .3599 m .38577 .35789 L .38858 .35722 L F
.75233 .35463 m .75399 .35179 L .75534 .35366 L 0 .03 .13 r
F
.75233 .35463 m .75098 .35275 L .75399 .35179 L F
.58351 .37645 m .58492 .37367 L .58643 .37518 L 0 .09 .187 r
F
.58351 .37645 m .58201 .37509 L .58492 .37367 L F
.43023 .36505 m .43141 .36249 L .43306 .36455 L 0 .055 .158 r
F
.43023 .36505 m .42858 .36297 L .43141 .36249 L F
.65677 .35997 m .6583 .35727 L .65973 .35891 L 0 .042 .144 r
F
.65677 .35997 m .65534 .3583 L .6583 .35727 L F
.66413 .35956 m .66565 .35656 L .66708 .35828 L 0 .04 .142 r
F
.66413 .35956 m .6627 .35785 L .66565 .35656 L F
.41842 .36324 m .4196 .36029 L .42126 .36245 L 0 .05 .152 r
F
.41842 .36324 m .41676 .36108 L .4196 .36029 L F
.2696 .35408 m .27054 .35137 L .27236 .35316 L 0 .029 .129 r
F
.2696 .35408 m .26779 .35229 L .27054 .35137 L F
.16802 .35225 m .16882 .34941 L .17073 .35124 L 0 .025 .123 r
F
.16802 .35225 m .16611 .35042 L .16882 .34941 L F
.88621 .35225 m .88808 .34946 L .88929 .35125 L 0 .025 .124 r
F
.88621 .35225 m .885 .35045 L .88808 .34946 L F
.8303 .3529 m .83207 .34993 L .83335 .35182 L 0 .026 .125 r
F
.8303 .3529 m .82902 .35102 L .83207 .34993 L F
.35648 .35681 m .35755 .35418 L .35928 .35605 L 0 .035 .136 r
F
.35648 .35681 m .35475 .35494 L .35755 .35418 L F
.33732 .35539 m .33835 .35284 L .34011 .35458 L 0 .032 .132 r
F
.33732 .35539 m .33557 .35366 L .33835 .35284 L F
.20922 .35258 m .21007 .34983 L .21195 .35162 L 0 .026 .125 r
F
.20922 .35258 m .20734 .35078 L .21007 .34983 L F
.83766 .35259 m .83945 .34975 L .84072 .35158 L F
.83766 .35259 m .8364 .35074 L .83945 .34975 L F
.89359 .35205 m .89546 .3492 L .89667 .35104 L 0 .025 .123 r
F
.89359 .35205 m .89238 .35023 L .89546 .3492 L F
.64943 .36063 m .65094 .35774 L .65238 .35943 L 0 .044 .146 r
F
.64943 .36063 m .64799 .35893 L .65094 .35774 L F
.24307 .35331 m .24396 .35068 L .2458 .35248 L 0 .028 .127 r
F
.24307 .35331 m .24123 .35149 L .24396 .35068 L F
.7597 .35454 m .76138 .35166 L .76272 .35349 L 0 .03 .13 r
F
.7597 .35454 m .75836 .3527 L .76138 .35166 L F
.3108 .35457 m .3118 .35182 L .31357 .35371 L F
.3108 .35457 m .30903 .35265 L .3118 .35182 L F
.17534 .35213 m .17613 .34944 L .17804 .35122 L 0 .025 .124 r
F
.17534 .35213 m .17343 .35032 L .17613 .34944 L F
.49422 .40169 m .4954 .40992 L .49702 .40876 L 0 .238 .276 r
F
.49422 .40169 m .4926 .40189 L .4954 .40992 L F
.76706 .3542 m .76874 .35133 L .77007 .35312 L 0 .029 .129 r
F
.76706 .3542 m .76573 .35241 L .76874 .35133 L F
.27693 .35404 m .27789 .35119 L .27969 .35303 L F
.27693 .35404 m .27512 .35218 L .27789 .35119 L F
.84504 .35242 m .84685 .34962 L .8481 .35142 L 0 .026 .125 r
F
.84504 .35242 m .84378 .35061 L .84685 .34962 L F
.44649 .36955 m .4477 .36683 L .44933 .36904 L 0 .069 .17 r
F
.44649 .36955 m .44486 .36738 L .4477 .36683 L F
.59376 .37387 m .59518 .37047 L .59667 .3721 L 0 .08 .18 r
F
.59376 .37387 m .59226 .37224 L .59518 .37047 L F
.77442 .35392 m .77613 .3512 L .77745 .35294 L 0 .029 .129 r
F
.77442 .35392 m .7731 .35216 L .77613 .3512 L F
.21654 .35251 m .21739 .34987 L .21926 .35163 L 0 .026 .125 r
F
.21654 .35251 m .21467 .35074 L .21739 .34987 L F
.8524 .35212 m .85421 .34922 L .85545 .35102 L 0 .025 .124 r
F
.8524 .35212 m .85115 .35032 L .85421 .34922 L F
.64209 .36134 m .64359 .35834 L .64504 .36012 L 0 .045 .148 r
F
.64209 .36134 m .64064 .35954 L .64359 .35834 L F
.39478 .36015 m .39592 .35732 L .39761 .35917 L 0 .043 .145 r
F
.39478 .36015 m .39309 .35827 L .39592 .35732 L F
.85977 .35184 m .86159 .34903 L .86284 .3509 L 0 .025 .123 r
F
.85977 .35184 m .85852 .34999 L .86159 .34903 L F
.18265 .35207 m .18347 .34927 L .18537 .35103 L 0 .025 .124 r
F
.18265 .35207 m .18075 .3503 L .18347 .34927 L F
.34464 .35555 m .3457 .35277 L .34744 .35463 L 0 .033 .133 r
F
.34464 .35555 m .3429 .35368 L .3457 .35277 L F
.70381 .35556 m .7054 .35274 L .70679 .35449 L F
.70381 .35556 m .70242 .35379 L .7054 .35274 L F
.78179 .35373 m .78349 .35075 L .78481 .3526 L 0 .028 .128 r
F
.78179 .35373 m .78047 .35189 L .78349 .35075 L F
.63475 .3619 m .63623 .35892 L .63769 .36074 L 0 .047 .15 r
F
.63475 .3619 m .63329 .36008 L .63623 .35892 L F
.6274 .36231 m .62888 .35947 L .63034 .3612 L 0 .049 .151 r
F
.6274 .36231 m .62593 .36061 L .62888 .35947 L F
.48819 .39494 m .48937 .40034 L .49099 .40111 L 0 .194 .254 r
F
.48819 .39494 m .48657 .39377 L .48937 .40034 L F
.3638 .35702 m .36487 .35452 L .3666 .35622 L 0 .036 .138 r
F
.3638 .35702 m .36207 .35529 L .36487 .35452 L F
.78914 .35335 m .79086 .35045 L .79218 .35235 L 0 .028 .127 r
F
.78914 .35335 m .78783 .35147 L .79086 .35045 L F
.61715 .36539 m .61861 .3623 L .62007 .36374 L 0 .056 .159 r
F
.61715 .36539 m .61568 .36393 L .61861 .3623 L F
.28425 .35399 m .28521 .35129 L .28701 .35312 L 0 .029 .129 r
F
.28425 .35399 m .28245 .35216 L .28521 .35129 L F
.18999 .35177 m .19081 .34904 L .19271 .35083 L 0 .025 .124 r
F
.18999 .35177 m .1881 .34999 L .19081 .34904 L F
.38296 .35851 m .38407 .35587 L .38577 .35789 L 0 .04 .142 r
F
.38296 .35851 m .38127 .35649 L .38407 .35587 L F
.25038 .35342 m .25129 .35067 L .25313 .35244 L 0 .028 .128 r
F
.25038 .35342 m .24854 .35165 L .25129 .35067 L F
.71852 .35487 m .72013 .35185 L .72151 .35373 L 0 .031 .131 r
F
.71852 .35487 m .71714 .35299 L .72013 .35185 L F
.71117 .35532 m .71276 .35228 L .71415 .35417 L 0 .032 .132 r
F
.71117 .35532 m .70978 .35343 L .71276 .35228 L F
.22386 .35246 m .22472 .3498 L .22659 .35154 L 0 .027 .126 r
F
.22386 .35246 m .22199 .35072 L .22472 .3498 L F
.41394 .36185 m .4151 .35892 L .41676 .36108 L 0 .047 .15 r
F
.41394 .36185 m .41227 .35969 L .4151 .35892 L F
.69647 .35615 m .69804 .3532 L .69944 .35494 L 0 .034 .135 r
F
.69647 .35615 m .69507 .3544 L .69804 .3532 L F
.31811 .35472 m .31913 .35193 L .32089 .35377 L 0 .031 .131 r
F
.31811 .35472 m .31635 .35286 L .31913 .35193 L F
.60691 .36864 m .60835 .36551 L .60983 .36705 L 0 .066 .167 r
F
.60691 .36864 m .60543 .36709 L .60835 .36551 L F
.42575 .36377 m .42693 .36085 L .42858 .36297 L 0 .053 .155 r
F
.42575 .36377 m .42409 .36165 L .42693 .36085 L F
.25772 .35317 m .25864 .35045 L .26047 .3522 L 0 .028 .128 r
F
.25772 .35317 m .25588 .35143 L .25864 .35045 L F
.40212 .36011 m .40326 .35754 L .40494 .35934 L 0 .044 .146 r
F
.40212 .36011 m .40043 .3583 L .40326 .35754 L F
.72588 .35462 m .72751 .35186 L .72889 .35367 L 0 .031 .131 r
F
.72588 .35462 m .72451 .3528 L .72751 .35186 L F
.44202 .36793 m .44322 .36521 L .44486 .36738 L 0 .065 .167 r
F
.44202 .36793 m .44038 .3658 L .44322 .36521 L F
.86716 .35182 m .86899 .34893 L .87023 .3508 L 0 .025 .124 r
F
.86716 .35182 m .86592 .34995 L .86899 .34893 L F
.79652 .35327 m .79825 .35038 L .79956 .35228 L 0 .028 .128 r
F
.79652 .35327 m .79521 .35137 L .79825 .35038 L F
.67442 .35758 m .67596 .35461 L .67739 .35652 L 0 .037 .139 r
F
.67442 .35758 m .67299 .35569 L .67596 .35461 L F
.7406 .35393 m .74225 .35119 L .7436 .35289 L 0 .03 .13 r
F
.7406 .35393 m .73925 .35222 L .74225 .35119 L F
.32545 .35455 m .32648 .35173 L .32824 .35352 L 0 .031 .131 r
F
.32545 .35455 m .32369 .35275 L .32648 .35173 L F
.15608 .35153 m .15685 .34877 L .15878 .35058 L 0 .025 .123 r
F
.15608 .35153 m .15415 .34973 L .15685 .34877 L F
.68913 .35684 m .69069 .35384 L .6921 .3556 L 0 .036 .137 r
F
.68913 .35684 m .68772 .35504 L .69069 .35384 L F
.29157 .35399 m .29255 .35122 L .29435 .35299 L 0 .03 .13 r
F
.29157 .35399 m .28978 .3522 L .29255 .35122 L F
.23118 .35236 m .23206 .34968 L .23391 .35145 L 0 .027 .126 r
F
.23118 .35236 m .22932 .35062 L .23206 .34968 L F
.19731 .35175 m .19813 .34909 L .20002 .35089 L 0 .026 .124 r
F
.19731 .35175 m .19542 .34996 L .19813 .34909 L F
.81124 .35258 m .81299 .34972 L .81428 .35151 L 0 .027 .126 r
F
.81124 .35258 m .80995 .35078 L .81299 .34972 L F
.37113 .35707 m .37222 .35447 L .37394 .35618 L 0 .037 .138 r
F
.37113 .35707 m .36941 .35538 L .37222 .35447 L F
.73325 .35442 m .73489 .35159 L .73625 .35332 L 0 .031 .131 r
F
.73325 .35442 m .73189 .35266 L .73489 .35159 L F
.80389 .35301 m .80562 .35007 L .80692 .35188 L 0 .028 .127 r
F
.80389 .35301 m .80259 .35117 L .80562 .35007 L F
.87453 .35159 m .87638 .34874 L .8776 .35056 L 0 .025 .123 r
F
.87453 .35159 m .8733 .34976 L .87638 .34874 L F
.35196 .3557 m .35302 .35306 L .35475 .35494 L 0 .034 .135 r
F
.35196 .3557 m .35023 .35381 L .35302 .35306 L F
.68178 .35738 m .68333 .35432 L .68475 .35624 L 0 .037 .138 r
F
.68178 .35738 m .68036 .35545 L .68333 .35432 L F
.81861 .35229 m .82037 .3494 L .82165 .35124 L 0 .026 .125 r
F
.81861 .35229 m .81732 .35044 L .82037 .3494 L F
.26504 .35312 m .26596 .35053 L .26779 .35229 L 0 .029 .128 r
F
.26504 .35312 m .26321 .35137 L .26596 .35053 L F
.29892 .35373 m .2999 .35099 L .30169 .35275 L 0 .03 .13 r
F
.29892 .35373 m .29712 .35199 L .2999 .35099 L F
.74797 .35373 m .74962 .35087 L .75098 .35275 L 0 .029 .129 r
F
.74797 .35373 m .74661 .35187 L .74962 .35087 L F
.59667 .3721 m .5981 .36872 L .59959 .37036 L 0 .076 .177 r
F
.59667 .3721 m .59518 .37047 L .5981 .36872 L F
.58643 .37518 m .58785 .37224 L .58935 .3739 L 0 .088 .186 r
F
.58643 .37518 m .58492 .37367 L .58785 .37224 L F
.66708 .35828 m .66861 .35522 L .67003 .35696 L 0 .039 .141 r
F
.66708 .35828 m .66565 .35656 L .66861 .35522 L F
.33278 .35444 m .33381 .35192 L .33557 .35366 L 0 .032 .132 r
F
.33278 .35444 m .33102 .3527 L .33381 .35192 L F
.88191 .35141 m .88378 .34865 L .885 .35045 L 0 .025 .124 r
F
.88191 .35141 m .88069 .3496 L .88378 .34865 L F
.1634 .35142 m .16419 .34859 L .16611 .35042 L F
.1634 .35142 m .16148 .34961 L .16419 .34859 L F
.82598 .35208 m .82774 .34913 L .82902 .35102 L 0 .026 .125 r
F
.82598 .35208 m .8247 .3502 L .82774 .34913 L F
.47166 .37922 m .47289 .37786 L .4745 .37996 L 0 .107 .2 r
F
.47166 .37922 m .47004 .37732 L .47289 .37786 L F
.43754 .3662 m .43873 .36381 L .44038 .3658 L 0 .061 .163 r
F
.43754 .3662 m .43589 .36418 L .43873 .36381 L F
.2385 .35235 m .23939 .34967 L .24123 .35149 L 0 .027 .126 r
F
.2385 .35235 m .23665 .35054 L .23939 .34967 L F
.30625 .35357 m .30725 .35083 L .30903 .35265 L 0 .03 .13 r
F
.30625 .35357 m .30447 .35178 L .30725 .35083 L F
.20462 .35175 m .20546 .34897 L .20734 .35078 L 0 .026 .125 r
F
.20462 .35175 m .20274 .34994 L .20546 .34897 L F
.65973 .35891 m .66127 .35623 L .6627 .35785 L 0 .042 .144 r
F
.65973 .35891 m .6583 .35727 L .66127 .35623 L F
.4672 .37707 m .46842 .37529 L .47004 .37732 L 0 .098 .194 r
F
.4672 .37707 m .46558 .37515 L .46842 .37529 L F
.83335 .35182 m .83512 .34885 L .8364 .35074 L 0 .026 .125 r
F
.83335 .35182 m .83207 .34993 L .83512 .34885 L F
.75534 .35366 m .75702 .35084 L .75836 .3527 L 0 .03 .13 r
F
.75534 .35366 m .75399 .35179 L .75702 .35084 L F
.17073 .35124 m .17152 .34851 L .17343 .35032 L 0 .025 .124 r
F
.17073 .35124 m .16882 .34941 L .17152 .34851 L F
.37846 .35716 m .37956 .35461 L .38127 .35649 L 0 .038 .14 r
F
.37846 .35716 m .37675 .3553 L .37956 .35461 L F
.88929 .35125 m .89117 .34845 L .89238 .35023 L 0 .025 .123 r
F
.88929 .35125 m .88808 .34946 L .89117 .34845 L F
.65238 .35943 m .6539 .35663 L .65534 .3583 L 0 .043 .145 r
F
.65238 .35943 m .65094 .35774 L .6539 .35663 L F
.40945 .36045 m .4106 .35781 L .41227 .35969 L 0 .046 .148 r
F
.40945 .36045 m .40777 .35858 L .4106 .35781 L F
.62007 .36374 m .62154 .36066 L .623 .3621 L 0 .053 .156 r
F
.62007 .36374 m .61861 .3623 L .62154 .36066 L F
.27236 .35316 m .27331 .35036 L .27512 .35218 L 0 .029 .129 r
F
.27236 .35316 m .27054 .35137 L .27331 .35036 L F
.48215 .38889 m .48054 .38675 L .48337 .38958 L 0 .153 .23 r
F
.84072 .35158 m .84252 .34879 L .84378 .35061 L 0 .026 .125 r
F
.84072 .35158 m .83945 .34975 L .84252 .34879 L F
.46273 .37506 m .46396 .37283 L .46558 .37515 L 0 .09 .188 r
F
.46273 .37506 m .46111 .3728 L .46396 .37283 L F
.21195 .35162 m .21279 .34897 L .21467 .35074 L 0 .026 .125 r
F
.21195 .35162 m .21007 .34983 L .21279 .34897 L F
.42126 .36245 m .42243 .35948 L .42409 .36165 L 0 .05 .153 r
F
.42126 .36245 m .4196 .36029 L .42243 .35948 L F
.76272 .35349 m .76439 .35058 L .76573 .35241 L 0 .029 .129 r
F
.76272 .35349 m .76138 .35166 L .76439 .35058 L F
.39027 .35923 m .3914 .35629 L .39309 .35827 L 0 .042 .145 r
F
.39027 .35923 m .38858 .35722 L .3914 .35629 L F
.77007 .35312 m .77177 .35039 L .7731 .35216 L 0 .029 .129 r
F
.77007 .35312 m .76874 .35133 L .77177 .35039 L F
.34011 .35458 m .34115 .35193 L .3429 .35368 L 0 .032 .133 r
F
.34011 .35458 m .33835 .35284 L .34115 .35193 L F
.5733 .38152 m .5747 .37875 L .5762 .37927 L 0 .113 .204 r
F
.5733 .38152 m .5718 .3815 L .5747 .37875 L F
.57042 .385 m .5718 .3815 L .5733 .38152 L 0 .126 .213 r
F
.60983 .36705 m .61128 .36399 L .61276 .36549 L 0 .063 .165 r
F
.60983 .36705 m .60835 .36551 L .61128 .36399 L F
.45827 .37297 m .45949 .37053 L .46111 .3728 L 0 .083 .182 r
F
.45827 .37297 m .45664 .37072 L .45949 .37053 L F
.64504 .36012 m .64654 .35715 L .64799 .35893 L 0 .045 .147 r
F
.64504 .36012 m .64359 .35834 L .64654 .35715 L F
.35928 .35605 m .36034 .35345 L .36207 .35529 L 0 .036 .137 r
F
.35928 .35605 m .35755 .35418 L .36034 .35345 L F
.27969 .35303 m .28065 .35032 L .28245 .35216 L 0 .029 .129 r
F
.27969 .35303 m .27789 .35119 L .28065 .35032 L F
.8481 .35142 m .8499 .34853 L .85115 .35032 L 0 .026 .124 r
F
.8481 .35142 m .84685 .34962 L .8499 .34853 L F
.85545 .35102 m .85728 .34819 L .85852 .34999 L 0 .025 .123 r
F
.85545 .35102 m .85421 .34922 L .85728 .34819 L F
.17804 .35122 m .17884 .34853 L .18075 .3503 L 0 .025 .124 r
F
.17804 .35122 m .17613 .34944 L .17884 .34853 L F
.47611 .38203 m .47733 .38207 L .47893 .3846 L 0 .123 .212 r
F
.47611 .38203 m .4745 .37996 L .47733 .38207 L F
.2458 .35248 m .2467 .34987 L .24854 .35165 L 0 .028 .128 r
F
.2458 .35248 m .24396 .35068 L .2467 .34987 L F
.31357 .35371 m .31458 .35099 L .31635 .35286 L 0 .03 .131 r
F
.31357 .35371 m .3118 .35182 L .31458 .35099 L F
.43306 .36455 m .43424 .36216 L .43589 .36418 L 0 .058 .16 r
F
.43306 .36455 m .43141 .36249 L .43424 .36216 L F
.77745 .35294 m .77916 .35016 L .78047 .35189 L 0 .029 .129 r
F
.77745 .35294 m .77613 .3512 L .77916 .35016 L F
.4538 .3709 m .45502 .36844 L .45664 .37072 L 0 .076 .177 r
F
.4538 .3709 m .45218 .36866 L .45502 .36844 L F
.63769 .36074 m .63918 .35772 L .64064 .35954 L 0 .046 .149 r
F
.63769 .36074 m .63623 .35892 L .63918 .35772 L F
.78481 .3526 m .78651 .34961 L .78783 .35147 L 0 .028 .127 r
F
.78481 .3526 m .78349 .35075 L .78651 .34961 L F
.59959 .37036 m .60102 .36708 L .60251 .36872 L 0 .073 .174 r
F
.59959 .37036 m .5981 .36872 L .60102 .36708 L F
.63034 .3612 m .63182 .35834 L .63329 .36008 L 0 .048 .15 r
F
.63034 .3612 m .62888 .35947 L .63182 .35834 L F
.39761 .35917 m .39874 .35647 L .40043 .3583 L 0 .043 .145 r
F
.39761 .35917 m .39592 .35732 L .39874 .35647 L F
.21926 .35163 m .22012 .34897 L .22199 .35072 L 0 .027 .126 r
F
.21926 .35163 m .21739 .34987 L .22012 .34897 L F
.70679 .35449 m .70839 .35169 L .70978 .35343 L 0 .032 .133 r
F
.70679 .35449 m .7054 .35274 L .70839 .35169 L F
.18537 .35103 m .18619 .34823 L .1881 .34999 L 0 .025 .124 r
F
.18537 .35103 m .18347 .34927 L .18619 .34823 L F
.69944 .35494 m .70102 .35206 L .70242 .35379 L 0 .033 .134 r
F
.69944 .35494 m .69804 .3532 L .70102 .35206 L F
.72151 .35373 m .72313 .35093 L .72451 .3528 L 0 .031 .131 r
F
.72151 .35373 m .72013 .35185 L .72313 .35093 L F
.86284 .3509 m .86467 .34808 L .86592 .34995 L 0 .025 .124 r
F
.86284 .3509 m .86159 .34903 L .86467 .34808 L F
.71415 .35417 m .71575 .35111 L .71714 .35299 L 0 .031 .132 r
F
.71415 .35417 m .71276 .35228 L .71575 .35111 L F
.5762 .37927 m .5776 .376 L .5791 .37701 L 0 .104 .198 r
F
.5762 .37927 m .5747 .37875 L .5776 .376 L F
.79218 .35235 m .7939 .34947 L .79521 .35137 L 0 .028 .127 r
F
.79218 .35235 m .79086 .35045 L .7939 .34947 L F
.34744 .35463 m .34849 .35196 L .35023 .35381 L 0 .033 .134 r
F
.34744 .35463 m .3457 .35277 L .34849 .35196 L F
.25313 .35244 m .25405 .34967 L .25588 .35143 L 0 .028 .128 r
F
.25313 .35244 m .25129 .35067 L .25405 .34967 L F
.19271 .35083 m .19352 .34816 L .19542 .34996 L 0 .025 .124 r
F
.19271 .35083 m .19081 .34904 L .19352 .34816 L F
.28701 .35312 m .28798 .35039 L .28978 .3522 L 0 .03 .13 r
F
.28701 .35312 m .28521 .35129 L .28798 .35039 L F
.44933 .36904 m .45054 .3664 L .45218 .36866 L 0 .071 .172 r
F
.44933 .36904 m .4477 .36683 L .45054 .3664 L F
.15146 .35068 m .15222 .34794 L .15415 .34973 L 0 .025 .123 r
F
.15146 .35068 m .14952 .3489 L .15222 .34794 L F
.6921 .3556 m .69367 .35264 L .69507 .3544 L 0 .035 .136 r
F
.6921 .3556 m .69069 .35384 L .69367 .35264 L F
.32089 .35377 m .32192 .35092 L .32369 .35275 L 0 .031 .131 r
F
.32089 .35377 m .31913 .35193 L .32192 .35092 L F
.3666 .35622 m .36768 .35369 L .36941 .35538 L 0 .037 .139 r
F
.3666 .35622 m .36487 .35452 L .36768 .35369 L F
.22659 .35154 m .22745 .34888 L .22932 .35062 L 0 .027 .126 r
F
.22659 .35154 m .22472 .3498 L .22745 .34888 L F
.26047 .3522 m .26138 .34961 L .26321 .35137 L 0 .028 .128 r
F
.26047 .3522 m .25864 .35045 L .26138 .34961 L F
.87023 .3508 m .87207 .3479 L .8733 .34976 L 0 .025 .124 r
F
.87023 .3508 m .86899 .34893 L .87207 .3479 L F
.67739 .35652 m .67894 .35352 L .68036 .35545 L 0 .037 .138 r
F
.67739 .35652 m .67596 .35461 L .67894 .35352 L F
.72889 .35367 m .73052 .35087 L .73189 .35266 L 0 .031 .131 r
F
.72889 .35367 m .72751 .35186 L .73052 .35087 L F
.67003 .35696 m .67157 .35393 L .67299 .35569 L 0 .038 .14 r
F
.67003 .35696 m .66861 .35522 L .67157 .35393 L F
.58935 .3739 m .59076 .37054 L .59226 .37224 L 0 .085 .184 r
F
.58935 .3739 m .58785 .37224 L .59076 .37054 L F
.79956 .35228 m .80129 .34929 L .80259 .35117 L 0 .028 .127 r
F
.79956 .35228 m .79825 .35038 L .80129 .34929 L F
.7436 .35289 m .74526 .35017 L .74661 .35187 L 0 .03 .13 r
F
.7436 .35289 m .74225 .35119 L .74526 .35017 L F
.80692 .35188 m .80866 .34899 L .80995 .35078 L 0 .027 .127 r
F
.80692 .35188 m .80562 .35007 L .80866 .34899 L F
.32824 .35352 m .32926 .35093 L .33102 .3527 L 0 .031 .131 r
F
.32824 .35352 m .32648 .35173 L .32926 .35093 L F
.73625 .35332 m .73789 .35051 L .73925 .35222 L 0 .03 .131 r
F
.73625 .35332 m .73489 .35159 L .73789 .35051 L F
.623 .3621 m .62447 .35917 L .62593 .36061 L 0 .051 .153 r
F
.623 .3621 m .62154 .36066 L .62447 .35917 L F
.41676 .36108 m .41794 .35813 L .4196 .36029 L 0 .048 .151 r
F
.41676 .36108 m .4151 .35892 L .41794 .35813 L F
.5791 .37701 m .5805 .37373 L .58201 .37509 L 0 .096 .192 r
F
.5791 .37701 m .5776 .376 L .5805 .37373 L F
.81428 .35151 m .81604 .34866 L .81732 .35044 L 0 .027 .126 r
F
.81428 .35151 m .81299 .34972 L .81604 .34866 L F
.57042 .385 m .56893 .38572 L .5718 .3815 L 0 .126 .213 r
F
.56753 .38851 m .56893 .38572 L .57042 .385 L 0 .145 .225 r
F
.42858 .36297 m .42976 .36038 L .43141 .36249 L 0 .054 .157 r
F
.42858 .36297 m .42693 .36085 L .42976 .36038 L F
.68475 .35624 m .6863 .35315 L .68772 .35504 L 0 .036 .138 r
F
.68475 .35624 m .68333 .35432 L .6863 .35315 L F
.29435 .35299 m .29533 .35023 L .29712 .35199 L 0 .03 .13 r
F
.29435 .35299 m .29255 .35122 L .29533 .35023 L F
.38577 .35789 m .38688 .35521 L .38858 .35722 L 0 .041 .143 r
F
.38577 .35789 m .38407 .35587 L .38688 .35521 L F
.8776 .35056 m .87947 .34779 L .88069 .3496 L 0 .025 .123 r
F
.8776 .35056 m .87638 .34874 L .87947 .34779 L F
.40494 .35934 m .40608 .35677 L .40777 .35858 L 0 .045 .147 r
F
.40494 .35934 m .40326 .35754 L .40608 .35677 L F
.15878 .35058 m .15956 .34779 L .16148 .34961 L 0 .025 .124 r
F
.15878 .35058 m .15685 .34877 L .15956 .34779 L F
.82165 .35124 m .82342 .34836 L .8247 .3502 L 0 .026 .125 r
F
.82165 .35124 m .82037 .3494 L .82342 .34836 L F
.23391 .35145 m .2348 .34874 L .23665 .35054 L 0 .027 .126 r
F
.23391 .35145 m .23206 .34968 L .2348 .34874 L F
.37394 .35618 m .37503 .35356 L .37675 .3553 L 0 .037 .139 r
F
.37394 .35618 m .37222 .35447 L .37503 .35356 L F
.20002 .35089 m .20085 .34813 L .20274 .34994 L 0 .026 .125 r
F
.20002 .35089 m .19813 .34909 L .20085 .34813 L F
.75098 .35275 m .75264 .34992 L .75399 .35179 L 0 .029 .129 r
F
.75098 .35275 m .74962 .35087 L .75264 .34992 L F
.30169 .35275 m .30268 .34999 L .30447 .35178 L 0 .03 .13 r
F
.30169 .35275 m .2999 .35099 L .30268 .34999 L F
.61276 .36549 m .61421 .36247 L .61568 .36393 L 0 .06 .163 r
F
.61276 .36549 m .61128 .36399 L .61421 .36247 L F
.82902 .35102 m .83079 .34804 L .83207 .34993 L 0 .026 .125 r
F
.82902 .35102 m .82774 .34913 L .83079 .34804 L F
.16611 .35042 m .1669 .34757 L .16882 .34941 L 0 .025 .123 r
F
.16611 .35042 m .16419 .34859 L .1669 .34757 L F
.53568 .41715 m .53707 .42544 L .53859 .41772 L 0 .322 .302 r
F
.53568 .41715 m .53415 .42439 L .53707 .42544 L F
.44486 .36738 m .44606 .36462 L .4477 .36683 L 0 .067 .168 r
F
.44486 .36738 m .44322 .36521 L .44606 .36462 L F
.885 .35045 m .88687 .34768 L .88808 .34946 L 0 .025 .124 r
F
.885 .35045 m .88378 .34865 L .88687 .34768 L F
.35475 .35494 m .35582 .3523 L .35755 .35418 L 0 .035 .136 r
F
.35475 .35494 m .35302 .35306 L .35582 .3523 L F
.26779 .35229 m .26872 .34958 L .27054 .35137 L 0 .029 .129 r
F
.26779 .35229 m .26596 .35053 L .26872 .34958 L F
.6627 .35785 m .66423 .35495 L .66565 .35656 L 0 .041 .143 r
F
.6627 .35785 m .66127 .35623 L .66423 .35495 L F
.8364 .35074 m .83818 .34786 L .83945 .34975 L 0 .026 .124 r
F
.8364 .35074 m .83512 .34885 L .83818 .34786 L F
.65534 .3583 m .65687 .35562 L .6583 .35727 L 0 .042 .145 r
F
.65534 .3583 m .6539 .35663 L .65687 .35562 L F
.60251 .36872 m .60394 .36543 L .60543 .36709 L 0 .07 .171 r
F
.60251 .36872 m .60102 .36708 L .60394 .36543 L F
.20734 .35078 m .20819 .34803 L .21007 .34983 L 0 .026 .125 r
F
.20734 .35078 m .20546 .34897 L .20819 .34803 L F
.33557 .35366 m .3366 .35111 L .33835 .35284 L 0 .032 .133 r
F
.33557 .35366 m .33381 .35192 L .3366 .35111 L F
.30903 .35265 m .31002 .34999 L .3118 .35182 L 0 .03 .13 r
F
.30903 .35265 m .30725 .35083 L .31002 .34999 L F
.89238 .35023 m .89426 .34744 L .89546 .3492 L 0 .025 .123 r
F
.89238 .35023 m .89117 .34845 L .89426 .34744 L F
.75836 .3527 m .76003 .3498 L .76138 .35166 L 0 .03 .13 r
F
.75836 .3527 m .75702 .35084 L .76003 .3498 L F
.24123 .35149 m .24212 .34886 L .24396 .35068 L 0 .028 .127 r
F
.24123 .35149 m .23939 .34967 L .24212 .34886 L F
.17343 .35032 m .17422 .34763 L .17613 .34944 L 0 .025 .124 r
F
.17343 .35032 m .17152 .34851 L .17422 .34763 L F
.27512 .35218 m .27608 .34936 L .27789 .35119 L 0 .029 .129 r
F
.27512 .35218 m .27331 .35036 L .27608 .34936 L F
.64799 .35893 m .6495 .35596 L .65094 .35774 L 0 .044 .146 r
F
.64799 .35893 m .64654 .35715 L .6495 .35596 L F
.76573 .35241 m .76741 .3495 L .76874 .35133 L 0 .029 .129 r
F
.76573 .35241 m .76439 .35058 L .76741 .3495 L F
.58201 .37509 m .58342 .37215 L .58492 .37367 L 0 .092 .189 r
F
.58201 .37509 m .5805 .37373 L .58342 .37215 L F
.84378 .35061 m .84559 .34782 L .84685 .34962 L 0 .026 .125 r
F
.84378 .35061 m .84252 .34879 L .84559 .34782 L F
.41227 .35969 m .41343 .35705 L .4151 .35892 L 0 .047 .149 r
F
.41227 .35969 m .4106 .35781 L .41343 .35705 L F
.39309 .35827 m .39423 .35536 L .39592 .35732 L 0 .042 .145 r
F
.39309 .35827 m .3914 .35629 L .39423 .35536 L F
.85115 .35032 m .85296 .34744 L .85421 .34922 L 0 .025 .124 r
F
.85115 .35032 m .8499 .34853 L .85296 .34744 L F
.7731 .35216 m .77481 .34945 L .77613 .3512 L 0 .029 .129 r
F
.7731 .35216 m .77177 .35039 L .77481 .34945 L F
.21467 .35074 m .21551 .3481 L .21739 .34987 L 0 .026 .125 r
F
.21467 .35074 m .21279 .34897 L .21551 .3481 L F
.56753 .38851 m .56605 .38998 L .56893 .38572 L 0 .145 .225 r
F
.56465 .39222 m .56605 .38998 L .56753 .38851 L 0 .166 .238 r
F
.64064 .35954 m .64213 .35653 L .64359 .35834 L 0 .046 .148 r
F
.64064 .35954 m .63918 .35772 L .64213 .35653 L F
.38127 .35649 m .38237 .35398 L .38407 .35587 L 0 .039 .141 r
F
.38127 .35649 m .37956 .35461 L .38237 .35398 L F
.85852 .34999 m .86035 .34724 L .86159 .34903 L 0 .025 .123 r
F
.85852 .34999 m .85728 .34819 L .86035 .34724 L F
.59226 .37224 m .59368 .36876 L .59518 .37047 L 0 .081 .18 r
F
.59226 .37224 m .59076 .37054 L .59368 .36876 L F
.3429 .35368 m .34395 .35102 L .3457 .35277 L 0 .033 .133 r
F
.3429 .35368 m .34115 .35193 L .34395 .35102 L F
.42409 .36165 m .42527 .35866 L .42693 .36085 L 0 .051 .154 r
F
.42409 .36165 m .42243 .35948 L .42527 .35866 L F
.78783 .35147 m .78954 .34858 L .79086 .35045 L 0 .028 .127 r
F
.78783 .35147 m .78651 .34961 L .78954 .34858 L F
.49865 .40741 m .49985 .41588 L .50148 .4135 L 0 .283 .297 r
F
.49865 .40741 m .49702 .40876 L .49985 .41588 L F
.78047 .35189 m .78218 .34902 L .78349 .35075 L 0 .029 .128 r
F
.78047 .35189 m .77916 .35016 L .78218 .34902 L F
.52833 .41824 m .52968 .43268 L .53123 .42144 L 0 .337 .294 r
F
.52833 .41824 m .52677 .428 L .52968 .43268 L F
.63329 .36008 m .63477 .35717 L .63623 .35892 L 0 .047 .15 r
F
.63329 .36008 m .63182 .35834 L .63477 .35717 L F
.44038 .3658 m .44157 .36327 L .44322 .36521 L 0 .064 .166 r
F
.44038 .3658 m .43873 .36381 L .44157 .36327 L F
.18075 .3503 m .18156 .3475 L .18347 .34927 L 0 .025 .124 r
F
.18075 .3503 m .17884 .34853 L .18156 .3475 L F
.70242 .35379 m .70401 .35104 L .7054 .35274 L 0 .033 .134 r
F
.70242 .35379 m .70102 .35206 L .70401 .35104 L F
.28245 .35216 m .28341 .34945 L .28521 .35129 L 0 .029 .129 r
F
.28245 .35216 m .28065 .35032 L .28341 .34945 L F
.71714 .35299 m .71874 .34997 L .72013 .35185 L 0 .031 .131 r
F
.71714 .35299 m .71575 .35111 L .71874 .34997 L F
.52097 .41872 m .52228 .4318 L .52386 .42335 L 0 .335 .295 r
F
.52097 .41872 m .51938 .42561 L .52228 .4318 L F
.70978 .35343 m .71138 .35055 L .71276 .35228 L 0 .032 .132 r
F
.70978 .35343 m .70839 .35169 L .71138 .35055 L F
.36207 .35529 m .36315 .35273 L .36487 .35452 L 0 .037 .138 r
F
.36207 .35529 m .36034 .35345 L .36315 .35273 L F
.1881 .34999 m .18891 .34728 L .19081 .34904 L 0 .025 .124 r
F
.1881 .34999 m .18619 .34823 L .18891 .34728 L F
.31635 .35286 m .31736 .35008 L .31913 .35193 L 0 .031 .131 r
F
.31635 .35286 m .31458 .35099 L .31736 .35008 L F
.62593 .36061 m .62742 .35803 L .62888 .35947 L 0 .049 .152 r
F
.62593 .36061 m .62447 .35917 L .62742 .35803 L F
.24854 .35165 m .24945 .3489 L .25129 .35067 L 0 .028 .128 r
F
.24854 .35165 m .2467 .34987 L .24945 .3489 L F
.22199 .35072 m .22285 .34806 L .22472 .3498 L 0 .027 .126 r
F
.22199 .35072 m .22012 .34897 L .22285 .34806 L F
.69507 .3544 m .69664 .35145 L .69804 .3532 L 0 .034 .135 r
F
.69507 .3544 m .69367 .35264 L .69664 .35145 L F
.40043 .3583 m .40157 .35571 L .40326 .35754 L 0 .044 .146 r
F
.40043 .3583 m .39874 .35647 L .40157 .35571 L F
.72451 .3528 m .72614 .35 L .72751 .35186 L 0 .031 .131 r
F
.72451 .3528 m .72313 .35093 L .72614 .35 L F
.79521 .35137 m .79694 .34847 L .79825 .35038 L 0 .028 .127 r
F
.79521 .35137 m .7939 .34947 L .79694 .34847 L F
.86592 .34995 m .86775 .34707 L .86899 .34893 L 0 .025 .124 r
F
.86592 .34995 m .86467 .34808 L .86775 .34707 L F
.67299 .35569 m .67454 .35283 L .67596 .35461 L 0 .037 .139 r
F
.67299 .35569 m .67157 .35393 L .67454 .35283 L F
.25588 .35143 m .2568 .34869 L .25864 .35045 L 0 .028 .128 r
F
.25588 .35143 m .25405 .34967 L .2568 .34869 L F
.61568 .36393 m .61714 .36085 L .61861 .3623 L 0 .058 .16 r
F
.61568 .36393 m .61421 .36247 L .61714 .36085 L F
.32369 .35275 m .32472 .34992 L .32648 .35173 L 0 .031 .131 r
F
.32369 .35275 m .32192 .35092 L .32472 .34992 L F
.35023 .35381 m .35129 .35119 L .35302 .35306 L 0 .034 .135 r
F
.35023 .35381 m .34849 .35196 L .35129 .35119 L F
.15415 .34973 m .15492 .34699 L .15685 .34877 L 0 .025 .124 r
F
.15415 .34973 m .15222 .34794 L .15492 .34699 L F
.68772 .35504 m .68928 .35198 L .69069 .35384 L 0 .036 .137 r
F
.68772 .35504 m .6863 .35315 L .68928 .35198 L F
.60543 .36709 m .60687 .36388 L .60835 .36551 L 0 .067 .168 r
F
.60543 .36709 m .60394 .36543 L .60687 .36388 L F
.68036 .35545 m .68191 .35241 L .68333 .35432 L 0 .037 .138 r
F
.68036 .35545 m .67894 .35352 L .68191 .35241 L F
.80259 .35117 m .80432 .3482 L .80562 .35007 L 0 .027 .127 r
F
.80259 .35117 m .80129 .34929 L .80432 .3482 L F
.28978 .3522 m .29075 .34943 L .29255 .35122 L 0 .03 .13 r
F
.28978 .3522 m .28798 .35039 L .29075 .34943 L F
.19542 .34996 m .19624 .34728 L .19813 .34909 L 0 .026 .124 r
F
.19542 .34996 m .19352 .34816 L .19624 .34728 L F
.8733 .34976 m .87515 .34688 L .87638 .34874 L 0 .025 .123 r
F
.8733 .34976 m .87207 .3479 L .87515 .34688 L F
.80995 .35078 m .81171 .34793 L .81299 .34972 L 0 .027 .126 r
F
.80995 .35078 m .80866 .34899 L .81171 .34793 L F
.73925 .35222 m .7409 .34949 L .74225 .35119 L 0 .03 .13 r
F
.73925 .35222 m .73789 .35051 L .7409 .34949 L F
.73189 .35266 m .73352 .34983 L .73489 .35159 L 0 .031 .131 r
F
.73189 .35266 m .73052 .35087 L .73352 .34983 L F
.22932 .35062 m .2302 .34791 L .23206 .34968 L 0 .027 .126 r
F
.22932 .35062 m .22745 .34888 L .2302 .34791 L F
.81732 .35044 m .81909 .34763 L .82037 .3494 L 0 .026 .125 r
F
.81732 .35044 m .81604 .34866 L .81909 .34763 L F
.74661 .35187 m .74828 .34917 L .74962 .35087 L 0 .029 .129 r
F
.74661 .35187 m .74526 .35017 L .74828 .34917 L F
.36941 .35538 m .37049 .35276 L .37222 .35447 L 0 .037 .139 r
F
.36941 .35538 m .36768 .35369 L .37049 .35276 L F
.48657 .39377 m .48776 .39855 L .48937 .40034 L 0 .197 .255 r
F
.48657 .39377 m .48497 .39199 L .48776 .39855 L F
.43589 .36418 m .43708 .36182 L .43873 .36381 L 0 .06 .163 r
F
.43589 .36418 m .43424 .36216 L .43708 .36182 L F
.46111 .3728 m .46234 .3705 L .46396 .37283 L 0 .087 .186 r
F
.46111 .3728 m .45949 .37053 L .46234 .3705 L F
.26321 .35137 m .26413 .34876 L .26596 .35053 L 0 .029 .128 r
F
.26321 .35137 m .26138 .34961 L .26413 .34876 L F
.29712 .35199 m .29811 .34923 L .2999 .35099 L 0 .03 .13 r
F
.29712 .35199 m .29533 .35023 L .29811 .34923 L F
.47004 .37732 m .47127 .37564 L .47289 .37786 L 0 .105 .199 r
F
.47004 .37732 m .46842 .37529 L .47127 .37564 L F
.8247 .3502 m .82647 .3473 L .82774 .34913 L 0 .026 .125 r
F
.8247 .3502 m .82342 .34836 L .82647 .3473 L F
.48054 .38675 m .48176 .38717 L .48337 .38958 L 0 .15 .228 r
F
.48054 .38675 m .47893 .3846 L .48176 .38717 L F
.88069 .3496 m .88256 .34684 L .88378 .34865 L 0 .025 .124 r
F
.88069 .3496 m .87947 .34779 L .88256 .34684 L F
.16148 .34961 m .16227 .34675 L .16419 .34859 L 0 .025 .123 r
F
.16148 .34961 m .15956 .34779 L .16227 .34675 L F
.66565 .35656 m .66719 .35361 L .66861 .35522 L 0 .04 .142 r
F
.66565 .35656 m .66423 .35495 L .66719 .35361 L F
.46558 .37515 m .46681 .37289 L .46842 .37529 L 0 .096 .192 r
F
.46558 .37515 m .46396 .37283 L .46681 .37289 L F
.33102 .3527 m .33205 .35016 L .33381 .35192 L 0 .032 .132 r
F
.33102 .3527 m .32926 .35093 L .33205 .35016 L F
.59518 .37047 m .5966 .36701 L .5981 .36872 L 0 .077 .177 r
F
.59518 .37047 m .59368 .36876 L .5966 .36701 L F
.4196 .36029 m .42078 .3573 L .42243 .35948 L 0 .049 .151 r
F
.4196 .36029 m .41794 .35813 L .42078 .3573 L F
.45664 .37072 m .45787 .36822 L .45949 .37053 L 0 .08 .18 r
F
.45664 .37072 m .45502 .36844 L .45787 .36822 L F
.23665 .35054 m .23754 .34785 L .23939 .34967 L 0 .027 .126 r
F
.23665 .35054 m .2348 .34874 L .23754 .34785 L F
.83207 .34993 m .83384 .34695 L .83512 .34885 L 0 .025 .124 r
F
.83207 .34993 m .83079 .34804 L .83384 .34695 L F
.20274 .34994 m .20358 .34715 L .20546 .34897 L 0 .026 .125 r
F
.20274 .34994 m .20085 .34813 L .20358 .34715 L F
.30447 .35178 m .30547 .34901 L .30725 .35083 L 0 .03 .13 r
F
.30447 .35178 m .30268 .34999 L .30547 .34901 L F
.56465 .39222 m .56317 .39452 L .56605 .38998 L 0 .166 .238 r
F
.56177 .39629 m .56317 .39452 L .56465 .39222 L 0 .191 .252 r
F
.75399 .35179 m .75567 .34897 L .75702 .35084 L 0 .03 .13 r
F
.75399 .35179 m .75264 .34992 L .75567 .34897 L F
.58492 .37367 m .58634 .37057 L .58785 .37224 L 0 .089 .187 r
F
.58492 .37367 m .58342 .37215 L .58634 .37057 L F
.37675 .3553 m .37784 .35284 L .37956 .35461 L 0 .038 .14 r
F
.37675 .3553 m .37503 .35356 L .37784 .35284 L F
.40777 .35858 m .40891 .35602 L .4106 .35781 L 0 .046 .148 r
F
.40777 .35858 m .40608 .35677 L .40891 .35602 L F
.16882 .34941 m .16961 .34665 L .17152 .34851 L 0 .025 .123 r
F
.16882 .34941 m .1669 .34757 L .16961 .34665 L F
.88808 .34946 m .88996 .34669 L .89117 .34845 L 0 .025 .124 r
F
.88808 .34946 m .88687 .34768 L .88996 .34669 L F
.38858 .35722 m .38971 .3543 L .3914 .35629 L 0 .042 .144 r
F
.38858 .35722 m .38688 .35521 L .38971 .3543 L F
.45218 .36866 m .45339 .36614 L .45502 .36844 L 0 .074 .175 r
F
.45218 .36866 m .45054 .3664 L .45339 .36614 L F
.6583 .35727 m .65984 .35461 L .66127 .35623 L 0 .042 .144 r
F
.6583 .35727 m .65687 .35562 L .65984 .35461 L F
.27054 .35137 m .27149 .34855 L .27331 .35036 L 0 .029 .129 r
F
.27054 .35137 m .26872 .34958 L .27149 .34855 L F
.4745 .37996 m .47572 .37948 L .47733 .38207 L 0 .12 .209 r
F
.4745 .37996 m .47289 .37786 L .47572 .37948 L F
.83945 .34975 m .84125 .34692 L .84252 .34879 L 0 .026 .124 r
F
.83945 .34975 m .83818 .34786 L .84125 .34692 L F
.65094 .35774 m .65246 .35487 L .6539 .35663 L 0 .043 .145 r
F
.65094 .35774 m .6495 .35596 L .65246 .35487 L F
.76138 .35166 m .76305 .34871 L .76439 .35058 L 0 .029 .129 r
F
.76138 .35166 m .76003 .3498 L .76305 .34871 L F
.43141 .36249 m .43259 .36007 L .43424 .36216 L 0 .056 .159 r
F
.43141 .36249 m .42976 .36038 L .43259 .36007 L F
.21007 .34983 m .21091 .34716 L .21279 .34897 L 0 .026 .125 r
F
.21007 .34983 m .20819 .34803 L .21091 .34716 L F
.35755 .35418 m .35861 .35161 L .36034 .35345 L 0 .036 .137 r
F
.35755 .35418 m .35582 .3523 L .35861 .35161 L F
.76874 .35133 m .77044 .34858 L .77177 .35039 L 0 .029 .129 r
F
.76874 .35133 m .76741 .3495 L .77044 .34858 L F
.27789 .35119 m .27884 .34846 L .28065 .35032 L F
.27789 .35119 m .27608 .34936 L .27884 .34846 L F
.64359 .35834 m .64509 .35535 L .64654 .35715 L 0 .045 .147 r
F
.64359 .35834 m .64213 .35653 L .64509 .35535 L F
.3118 .35182 m .3128 .34915 L .31458 .35099 L 0 .03 .131 r
F
.3118 .35182 m .31002 .34999 L .3128 .34915 L F
.33835 .35284 m .33939 .35019 L .34115 .35193 L 0 .033 .133 r
F
.33835 .35284 m .3366 .35111 L .33939 .35019 L F
.84685 .34962 m .84865 .34674 L .8499 .34853 L 0 .026 .124 r
F
.84685 .34962 m .84559 .34782 L .84865 .34674 L F
.85421 .34922 m .85603 .34643 L .85728 .34819 L 0 .025 .124 r
F
.85421 .34922 m .85296 .34744 L .85603 .34643 L F
.61861 .3623 m .62007 .35921 L .62154 .36066 L 0 .055 .157 r
F
.61861 .3623 m .61714 .36085 L .62007 .35921 L F
.17613 .34944 m .17693 .34674 L .17884 .34853 L 0 .026 .124 r
F
.17613 .34944 m .17422 .34763 L .17693 .34674 L F
.24396 .35068 m .24486 .34804 L .2467 .34987 L 0 .028 .128 r
F
.24396 .35068 m .24212 .34886 L .24486 .34804 L F
.5031 .41114 m .5043 .42408 L .50593 .42023 L 0 .317 .304 r
F
.5031 .41114 m .50148 .4135 L .5043 .42408 L F
.4477 .36683 m .44891 .36416 L .45054 .3664 L 0 .069 .17 r
F
.4477 .36683 m .44606 .36462 L .44891 .36416 L F
.63623 .35892 m .63773 .35598 L .63918 .35772 L 0 .046 .149 r
F
.63623 .35892 m .63477 .35717 L .63773 .35598 L F
.78349 .35075 m .7852 .34788 L .78651 .34961 L 0 .028 .128 r
F
.78349 .35075 m .78218 .34902 L .7852 .34788 L F
.39592 .35732 m .39705 .35452 L .39874 .35647 L 0 .043 .145 r
F
.39592 .35732 m .39423 .35536 L .39705 .35452 L F
.77613 .3512 m .77784 .34843 L .77916 .35016 L 0 .029 .129 r
F
.77613 .3512 m .77481 .34945 L .77784 .34843 L F
.60835 .36551 m .6098 .3624 L .61128 .36399 L 0 .064 .166 r
F
.60835 .36551 m .60687 .36388 L .6098 .3624 L F
.72013 .35185 m .72175 .34905 L .72313 .35093 L 0 .03 .131 r
F
.72013 .35185 m .71874 .34997 L .72175 .34905 L F
.4926 .40189 m .49378 .40963 L .4954 .40992 L 0 .254 .284 r
F
.4926 .40189 m .49099 .40111 L .49378 .40963 L F
.71276 .35228 m .71437 .34938 L .71575 .35111 L 0 .031 .132 r
F
.71276 .35228 m .71138 .35055 L .71437 .34938 L F
.79086 .35045 m .79258 .34759 L .7939 .34947 L 0 .028 .127 r
F
.79086 .35045 m .78954 .34858 L .79258 .34759 L F
.86159 .34903 m .86344 .34629 L .86467 .34808 L 0 .025 .123 r
F
.86159 .34903 m .86035 .34724 L .86344 .34629 L F
.21739 .34987 m .21824 .34721 L .22012 .34897 L 0 .027 .126 r
F
.21739 .34987 m .21551 .3481 L .21824 .34721 L F
.62888 .35947 m .63037 .35688 L .63182 .35834 L 0 .049 .151 r
F
.62888 .35947 m .62742 .35803 L .63037 .35688 L F
.7054 .35274 m .70701 .35002 L .70839 .35169 L 0 .033 .133 r
F
.7054 .35274 m .70401 .35104 L .70701 .35002 L F
.18347 .34927 m .18428 .34648 L .18619 .34823 L 0 .025 .124 r
F
.18347 .34927 m .18156 .3475 L .18428 .34648 L F
.3457 .35277 m .34675 .35018 L .34849 .35196 L 0 .033 .134 r
F
.3457 .35277 m .34395 .35102 L .34675 .35018 L F
.69804 .3532 m .69963 .35032 L .70102 .35206 L F
.69804 .3532 m .69664 .35145 L .69963 .35032 L F
.4151 .35892 m .41626 .35626 L .41794 .35813 L 0 .047 .15 r
F
.4151 .35892 m .41343 .35705 L .41626 .35626 L F
.5981 .36872 m .59952 .36536 L .60102 .36708 L 0 .073 .174 r
F
.5981 .36872 m .5966 .36701 L .59952 .36536 L F
.42693 .36085 m .42811 .3582 L .42976 .36038 L 0 .053 .155 r
F
.42693 .36085 m .42527 .35866 L .42811 .3582 L F
.25129 .35067 m .25221 .3479 L .25405 .34967 L 0 .028 .128 r
F
.25129 .35067 m .24945 .3489 L .25221 .3479 L F
.19081 .34904 m .19162 .3464 L .19352 .34816 L 0 .025 .124 r
F
.19081 .34904 m .18891 .34728 L .19162 .3464 L F
.28521 .35129 m .28617 .34856 L .28798 .35039 L 0 .03 .13 r
F
.28521 .35129 m .28341 .34945 L .28617 .34856 L F
.31913 .35193 m .32015 .34909 L .32192 .35092 L 0 .031 .131 r
F
.31913 .35193 m .31736 .35008 L .32015 .34909 L F
.67596 .35461 m .67751 .35173 L .67894 .35352 L 0 .037 .138 r
F
.67596 .35461 m .67454 .35283 L .67751 .35173 L F
.14952 .3489 m .15028 .34617 L .15222 .34794 L 0 .025 .124 r
F
.14952 .3489 m .14758 .34712 L .15028 .34617 L F
.38407 .35587 m .38518 .3533 L .38688 .35521 L 0 .04 .142 r
F
.38407 .35587 m .38237 .35398 L .38518 .3533 L F
.86899 .34893 m .87083 .34604 L .87207 .3479 L 0 .025 .123 r
F
.86899 .34893 m .86775 .34707 L .87083 .34604 L F
.69069 .35384 m .69226 .3508 L .69367 .35264 L 0 .035 .136 r
F
.69069 .35384 m .68928 .35198 L .69226 .3508 L F
.79825 .35038 m .79998 .3474 L .80129 .34929 L 0 .028 .127 r
F
.79825 .35038 m .79694 .34847 L .79998 .3474 L F
.22472 .3498 m .22558 .34715 L .22745 .34888 L 0 .027 .126 r
F
.22472 .3498 m .22285 .34806 L .22558 .34715 L F
.72751 .35186 m .72915 .34903 L .73052 .35087 L 0 .031 .131 r
F
.72751 .35186 m .72614 .35 L .72915 .34903 L F
.36487 .35452 m .36595 .35192 L .36768 .35369 L 0 .037 .139 r
F
.36487 .35452 m .36315 .35273 L .36595 .35192 L F
.68333 .35432 m .68489 .35127 L .6863 .35315 L 0 .036 .137 r
F
.68333 .35432 m .68191 .35241 L .68489 .35127 L F
.25864 .35045 m .25955 .34785 L .26138 .34961 L 0 .028 .128 r
F
.25864 .35045 m .2568 .34869 L .25955 .34785 L F
.80562 .35007 m .80736 .34714 L .80866 .34899 L 0 .027 .126 r
F
.80562 .35007 m .80432 .3482 L .80736 .34714 L F
.44322 .36521 m .44442 .36272 L .44606 .36462 L 0 .065 .167 r
F
.44322 .36521 m .44157 .36327 L .44442 .36272 L F
.32648 .35173 m .3275 .34914 L .32926 .35093 L 0 .031 .132 r
F
.32648 .35173 m .32472 .34992 L .3275 .34914 L F
.66861 .35522 m .67015 .35233 L .67157 .35393 L 0 .038 .14 r
F
.66861 .35522 m .66719 .35361 L .67015 .35233 L F
.81299 .34972 m .81475 .34687 L .81604 .34866 L 0 .027 .126 r
F
.81299 .34972 m .81171 .34793 L .81475 .34687 L F
.73489 .35159 m .73653 .34878 L .73789 .35051 L 0 .031 .131 r
F
.73489 .35159 m .73352 .34983 L .73653 .34878 L F
.87638 .34874 m .87824 .34593 L .87947 .34779 L 0 .025 .123 r
F
.87638 .34874 m .87515 .34688 L .87824 .34593 L F
.74225 .35119 m .74392 .34847 L .74526 .35017 L 0 .03 .13 r
F
.74225 .35119 m .7409 .34949 L .74392 .34847 L F
.58785 .37224 m .58926 .36883 L .59076 .37054 L 0 .085 .184 r
F
.58785 .37224 m .58634 .37057 L .58926 .36883 L F
.40326 .35754 m .4044 .35494 L .40608 .35677 L 0 .045 .147 r
F
.40326 .35754 m .40157 .35571 L .4044 .35494 L F
.29255 .35122 m .29353 .34846 L .29533 .35023 L 0 .03 .13 r
F
.29255 .35122 m .29075 .34943 L .29353 .34846 L F
.15685 .34877 m .15763 .34599 L .15956 .34779 L 0 .025 .124 r
F
.15685 .34877 m .15492 .34699 L .15763 .34599 L F
.82037 .3494 m .82214 .34661 L .82342 .34836 L 0 .026 .125 r
F
.82037 .3494 m .81909 .34763 L .82214 .34661 L F
.74962 .35087 m .7513 .34823 L .75264 .34992 L 0 .029 .129 r
F
.74962 .35087 m .74828 .34917 L .7513 .34823 L F
.23206 .34968 m .23294 .34694 L .2348 .34874 L 0 .027 .126 r
F
.23206 .34968 m .2302 .34791 L .23294 .34694 L F
.19813 .34909 m .19897 .34631 L .20085 .34813 L 0 .026 .125 r
F
.19813 .34909 m .19624 .34728 L .19897 .34631 L F
.56177 .39629 m .56029 .39955 L .56317 .39452 L 0 .191 .252 r
F
.55889 .40037 m .56029 .39955 L .56177 .39629 L 0 .219 .267 r
F
.82774 .34913 m .82952 .34621 L .83079 .34804 L 0 .026 .124 r
F
.82774 .34913 m .82647 .3473 L .82952 .34621 L F
.2999 .35099 m .30089 .34821 L .30268 .34999 L 0 .03 .13 r
F
.2999 .35099 m .29811 .34923 L .30089 .34821 L F
.37222 .35447 m .37331 .35182 L .37503 .35356 L 0 .038 .139 r
F
.37222 .35447 m .37049 .35276 L .37331 .35182 L F
.35302 .35306 m .35408 .35043 L .35582 .3523 L 0 .034 .136 r
F
.35302 .35306 m .35129 .35119 L .35408 .35043 L F
.16419 .34859 m .16499 .34572 L .1669 .34757 L 0 .025 .123 r
F
.16419 .34859 m .16227 .34675 L .16499 .34572 L F
.62154 .36066 m .62301 .35773 L .62447 .35917 L 0 .052 .155 r
F
.62154 .36066 m .62007 .35921 L .62301 .35773 L F
.83512 .34885 m .83691 .34597 L .83818 .34786 L 0 .025 .124 r
F
.83512 .34885 m .83384 .34695 L .83691 .34597 L F
.88378 .34865 m .88565 .34588 L .88687 .34768 L F
.88378 .34865 m .88256 .34684 L .88565 .34588 L F
.53859 .41772 m .53999 .4265 L .5415 .41829 L 0 .329 .299 r
F
.53859 .41772 m .53707 .42544 L .53999 .4265 L F
.26596 .35053 m .2669 .3478 L .26872 .34958 L 0 .029 .129 r
F
.26596 .35053 m .26413 .34876 L .2669 .3478 L F
.20546 .34897 m .20631 .3462 L .20819 .34803 L 0 .026 .125 r
F
.20546 .34897 m .20358 .34715 L .20631 .3462 L F
.30725 .35083 m .30824 .34816 L .31002 .34999 L 0 .03 .13 r
F
.30725 .35083 m .30547 .34901 L .30824 .34816 L F
.75702 .35084 m .75869 .34793 L .76003 .3498 L 0 .029 .129 r
F
.75702 .35084 m .75567 .34897 L .75869 .34793 L F
.23939 .34967 m .24027 .34701 L .24212 .34886 L 0 .028 .127 r
F
.23939 .34967 m .23754 .34785 L .24027 .34701 L F
.42243 .35948 m .42362 .35648 L .42527 .35866 L 0 .05 .152 r
F
.42243 .35948 m .42078 .3573 L .42362 .35648 L F
.33381 .35192 m .33484 .34936 L .3366 .35111 L 0 .032 .133 r
F
.33381 .35192 m .33205 .35016 L .33484 .34936 L F
.89117 .34845 m .89305 .3457 L .89426 .34744 L 0 .025 .124 r
F
.89117 .34845 m .88996 .34669 L .89305 .3457 L F
.6539 .35663 m .65543 .35388 L .65687 .35562 L 0 .043 .145 r
F
.6539 .35663 m .65246 .35487 L .65543 .35388 L F
.66127 .35623 m .6628 .35333 L .66423 .35495 L 0 .042 .144 r
F
.66127 .35623 m .65984 .35461 L .6628 .35333 L F
.61128 .36399 m .61273 .36092 L .61421 .36247 L 0 .062 .164 r
F
.61128 .36399 m .6098 .3624 L .61273 .36092 L F
.60102 .36708 m .60245 .3637 L .60394 .36543 L 0 .07 .171 r
F
.60102 .36708 m .59952 .36536 L .60245 .3637 L F
.17152 .34851 m .17231 .34576 L .17422 .34763 L 0 .025 .124 r
F
.17152 .34851 m .16961 .34665 L .17231 .34576 L F
.27331 .35036 m .27426 .34752 L .27608 .34936 L 0 .029 .129 r
F
.27331 .35036 m .27149 .34855 L .27426 .34752 L F
.3914 .35629 m .39253 .3534 L .39423 .35536 L 0 .042 .144 r
F
.3914 .35629 m .38971 .3543 L .39253 .3534 L F
.76439 .35058 m .76607 .34763 L .76741 .3495 L 0 .029 .129 r
F
.76439 .35058 m .76305 .34871 L .76607 .34763 L F
.64654 .35715 m .64805 .35416 L .6495 .35596 L 0 .044 .146 r
F
.64654 .35715 m .64509 .35535 L .64805 .35416 L F
.84252 .34879 m .84433 .34596 L .84559 .34782 L 0 .026 .125 r
F
.84252 .34879 m .84125 .34692 L .84433 .34596 L F
.4106 .35781 m .41175 .35526 L .41343 .35705 L 0 .046 .149 r
F
.4106 .35781 m .40891 .35602 L .41175 .35526 L F
.5776 .376 m .579 .37317 L .5805 .37373 L 0 .102 .197 r
F
.5776 .376 m .5761 .37599 L .579 .37317 L F
.5747 .37875 m .5761 .37599 L .5776 .376 L 0 .113 .205 r
F
.37956 .35461 m .38065 .35217 L .38237 .35398 L 0 .039 .141 r
F
.37956 .35461 m .37784 .35284 L .38065 .35217 L F
.43873 .36381 m .43992 .36132 L .44157 .36327 L 0 .063 .165 r
F
.43873 .36381 m .43708 .36182 L .43992 .36132 L F
.5747 .37875 m .57321 .37949 L .5761 .37599 L 0 .113 .205 r
F
.5718 .3815 m .57321 .37949 L .5747 .37875 L 0 .126 .213 r
F
.63918 .35772 m .64068 .3548 L .64213 .35653 L 0 .046 .148 r
F
.63918 .35772 m .63773 .35598 L .64068 .3548 L F
.8499 .34853 m .85171 .34566 L .85296 .34744 L 0 .025 .124 r
F
.8499 .34853 m .84865 .34674 L .85171 .34566 L F
.77177 .35039 m .77348 .34766 L .77481 .34945 L 0 .029 .129 r
F
.77177 .35039 m .77044 .34858 L .77348 .34766 L F
.51649 .41945 m .51778 .43326 L .51938 .42561 L 0 .343 .291 r
F
.51649 .41945 m .51489 .42541 L .51778 .43326 L F
.21279 .34897 m .21364 .34629 L .21551 .3481 L 0 .026 .126 r
F
.21279 .34897 m .21091 .34716 L .21364 .34629 L F
.78651 .34961 m .78824 .34686 L .78954 .34858 L 0 .028 .127 r
F
.78651 .34961 m .7852 .34788 L .78824 .34686 L F
.85728 .34819 m .85912 .34548 L .86035 .34724 L 0 .025 .124 r
F
.85728 .34819 m .85603 .34643 L .85912 .34548 L F
.5718 .3815 m .57032 .38298 L .57321 .37949 L 0 .126 .213 r
F
.56893 .38572 m .57032 .38298 L .5718 .3815 L 0 .146 .226 r
F
.71575 .35111 m .71736 .34824 L .71874 .34997 L 0 .031 .131 r
F
.71575 .35111 m .71437 .34938 L .71736 .34824 L F
.34115 .35193 m .34219 .34927 L .34395 .35102 L 0 .033 .134 r
F
.34115 .35193 m .33939 .35019 L .34219 .34927 L F
.59076 .37054 m .59218 .36705 L .59368 .36876 L 0 .081 .181 r
F
.59076 .37054 m .58926 .36883 L .59218 .36705 L F
.28065 .35032 m .28161 .34756 L .28341 .34945 L 0 .029 .129 r
F
.28065 .35032 m .27884 .34846 L .28161 .34756 L F
.63182 .35834 m .63332 .35571 L .63477 .35717 L 0 .048 .151 r
F
.63182 .35834 m .63037 .35688 L .63332 .35571 L F
.77916 .35016 m .78086 .34729 L .78218 .34902 L 0 .029 .129 r
F
.77916 .35016 m .77784 .34843 L .78086 .34729 L F
.17884 .34853 m .17965 .34572 L .18156 .3475 L 0 .026 .124 r
F
.17884 .34853 m .17693 .34674 L .17965 .34572 L F
.31458 .35099 m .31559 .34823 L .31736 .35008 L 0 .031 .131 r
F
.31458 .35099 m .3128 .34915 L .31559 .34823 L F
.36034 .35345 m .36141 .35092 L .36315 .35273 L 0 .036 .138 r
F
.36034 .35345 m .35861 .35161 L .36141 .35092 L F
.70102 .35206 m .70262 .34934 L .70401 .35104 L 0 .033 .134 r
F
.70102 .35206 m .69963 .35032 L .70262 .34934 L F
.5805 .37373 m .58192 .37133 L .58342 .37215 L 0 .096 .192 r
F
.5805 .37373 m .579 .37317 L .58192 .37133 L F
.70839 .35169 m .71 .34889 L .71138 .35055 L 0 .032 .133 r
F
.70839 .35169 m .70701 .35002 L .71 .34889 L F
.18619 .34823 m .187 .34553 L .18891 .34728 L 0 .025 .124 r
F
.18619 .34823 m .18428 .34648 L .187 .34553 L F
.2467 .34987 m .24761 .34707 L .24945 .3489 L 0 .028 .128 r
F
.2467 .34987 m .24486 .34804 L .24761 .34707 L F
.7939 .34947 m .79563 .34658 L .79694 .34847 L 0 .028 .127 r
F
.7939 .34947 m .79258 .34759 L .79563 .34658 L F
.45949 .37053 m .46072 .36813 L .46234 .3705 L 0 .085 .183 r
F
.45949 .37053 m .45787 .36822 L .46072 .36813 L F
.72313 .35093 m .72476 .34813 L .72614 .35 L 0 .031 .131 r
F
.72313 .35093 m .72175 .34905 L .72476 .34813 L F
.86467 .34808 m .86652 .34528 L .86775 .34707 L 0 .025 .124 r
F
.86467 .34808 m .86344 .34629 L .86652 .34528 L F
.39874 .35647 m .39988 .35377 L .40157 .35571 L 0 .044 .146 r
F
.39874 .35647 m .39705 .35452 L .39988 .35377 L F
.46396 .37283 m .46519 .3705 L .46681 .37289 L 0 .093 .19 r
F
.46396 .37283 m .46234 .3705 L .46519 .3705 L F
.69367 .35264 m .69524 .34962 L .69664 .35145 L 0 .034 .135 r
F
.69367 .35264 m .69226 .3508 L .69524 .34962 L F
.22012 .34897 m .22097 .34632 L .22285 .34806 L 0 .027 .126 r
F
.22012 .34897 m .21824 .34721 L .22097 .34632 L F
.45502 .36844 m .45624 .36588 L .45787 .36822 L 0 .078 .178 r
F
.45502 .36844 m .45339 .36614 L .45624 .36588 L F
.67894 .35352 m .68049 .35061 L .68191 .35241 L 0 .036 .138 r
F
.67894 .35352 m .67751 .35173 L .68049 .35061 L F
.67157 .35393 m .67312 .35121 L .67454 .35283 L 0 .038 .139 r
F
.67157 .35393 m .67015 .35233 L .67312 .35121 L F
.47893 .3846 m .48016 .38418 L .48176 .38717 L 0 .145 .225 r
F
.47893 .3846 m .47733 .38207 L .48016 .38418 L F
.25405 .34967 m .25496 .34693 L .2568 .34869 L 0 .028 .128 r
F
.25405 .34967 m .25221 .3479 L .25496 .34693 L F
.6863 .35315 m .68787 .35013 L .68928 .35198 L 0 .035 .137 r
F
.6863 .35315 m .68489 .35127 L .68787 .35013 L F
.43424 .36216 m .43543 .35975 L .43708 .36182 L 0 .059 .162 r
F
.43424 .36216 m .43259 .36007 L .43543 .35975 L F
.32192 .35092 m .32295 .3481 L .32472 .34992 L 0 .031 .131 r
F
.32192 .35092 m .32015 .34909 L .32295 .3481 L F
.80129 .34929 m .80302 .34632 L .80432 .3482 L 0 .027 .127 r
F
.80129 .34929 m .79998 .3474 L .80302 .34632 L F
.34849 .35196 m .34954 .34938 L .35129 .35119 L 0 .034 .135 r
F
.34849 .35196 m .34675 .35018 L .34954 .34938 L F
.87207 .3479 m .87391 .34503 L .87515 .34688 L 0 .025 .123 r
F
.87207 .3479 m .87083 .34604 L .87391 .34503 L F
.46842 .37529 m .46966 .37312 L .47127 .37564 L 0 .102 .197 r
F
.46842 .37529 m .46681 .37289 L .46966 .37312 L F
.41794 .35813 m .4191 .35541 L .42078 .3573 L 0 .048 .151 r
F
.41794 .35813 m .41626 .35626 L .4191 .35541 L F
.28798 .35039 m .28895 .34763 L .29075 .34943 L 0 .03 .13 r
F
.28798 .35039 m .28617 .34856 L .28895 .34763 L F
.62447 .35917 m .62596 .35657 L .62742 .35803 L 0 .051 .154 r
F
.62447 .35917 m .62301 .35773 L .62596 .35657 L F
.15222 .34794 m .15298 .34522 L .15492 .34699 L 0 .025 .124 r
F
.15222 .34794 m .15028 .34617 L .15298 .34522 L F
.19352 .34816 m .19434 .34551 L .19624 .34728 L 0 .026 .125 r
F
.19352 .34816 m .19162 .3464 L .19434 .34551 L F
.80866 .34899 m .81041 .34609 L .81171 .34793 L 0 .027 .126 r
F
.80866 .34899 m .80736 .34714 L .81041 .34609 L F
.73052 .35087 m .73216 .348 L .73352 .34983 L 0 .031 .131 r
F
.73052 .35087 m .72915 .34903 L .73216 .348 L F
.45054 .3664 m .45176 .36385 L .45339 .36614 L 0 .072 .173 r
F
.45054 .3664 m .44891 .36416 L .45176 .36385 L F
.81604 .34866 m .81781 .34586 L .81909 .34763 L 0 .027 .126 r
F
.81604 .34866 m .81475 .34687 L .81781 .34586 L F
.48497 .39199 m .48616 .39576 L .48776 .39855 L 0 .194 .254 r
F
.55889 .40037 m .55741 .40459 L .56029 .39955 L 0 .219 .267 r
F
.556 .40446 m .55741 .40459 L .55889 .40037 L 0 .25 .282 r
F
.22745 .34888 m .22833 .34617 L .2302 .34791 L 0 .027 .126 r
F
.22745 .34888 m .22558 .34715 L .22833 .34617 L F
.73789 .35051 m .73955 .34777 L .7409 .34949 L 0 .03 .131 r
F
.73789 .35051 m .73653 .34878 L .73955 .34777 L F
.60394 .36543 m .60538 .36217 L .60687 .36388 L 0 .067 .169 r
F
.60394 .36543 m .60245 .3637 L .60538 .36217 L F
.74526 .35017 m .74693 .34748 L .74828 .34917 L 0 .03 .13 r
F
.74526 .35017 m .74392 .34847 L .74693 .34748 L F
.82342 .34836 m .8252 .34556 L .82647 .3473 L 0 .026 .125 r
F
.82342 .34836 m .82214 .34661 L .8252 .34556 L F
.61421 .36247 m .61566 .35932 L .61714 .36085 L 0 .059 .161 r
F
.61421 .36247 m .61273 .36092 L .61566 .35932 L F
.36768 .35369 m .36877 .35098 L .37049 .35276 L 0 .038 .139 r
F
.36768 .35369 m .36595 .35192 L .36877 .35098 L F
.26138 .34961 m .2623 .34701 L .26413 .34876 L 0 .029 .129 r
F
.26138 .34961 m .25955 .34785 L .2623 .34701 L F
.29533 .35023 m .29631 .34746 L .29811 .34923 L 0 .03 .13 r
F
.29533 .35023 m .29353 .34846 L .29631 .34746 L F
.87947 .34779 m .88133 .34498 L .88256 .34684 L 0 .025 .124 r
F
.87947 .34779 m .87824 .34593 L .88133 .34498 L F
.15956 .34779 m .16034 .34495 L .16227 .34675 L 0 .025 .123 r
F
.15956 .34779 m .15763 .34599 L .16034 .34495 L F
.47289 .37786 m .47411 .37682 L .47572 .37948 L 0 .116 .207 r
F
.47289 .37786 m .47127 .37564 L .47411 .37682 L F
.83079 .34804 m .83257 .34511 L .83384 .34695 L 0 .025 .124 r
F
.83079 .34804 m .82952 .34621 L .83257 .34511 L F
.38688 .35521 m .38801 .35239 L .38971 .3543 L 0 .041 .143 r
F
.38688 .35521 m .38518 .3533 L .38801 .35239 L F
.32926 .35093 m .33028 .34839 L .33205 .35016 L 0 .032 .132 r
F
.32926 .35093 m .3275 .34914 L .33028 .34839 L F
.75264 .34992 m .75433 .34728 L .75567 .34897 L 0 .03 .13 r
F
.75264 .34992 m .7513 .34823 L .75433 .34728 L F
.42976 .36038 m .43094 .35789 L .43259 .36007 L 0 .055 .158 r
F
.42976 .36038 m .42811 .3582 L .43094 .35789 L F
.59368 .36876 m .5951 .36529 L .5966 .36701 L 0 .077 .178 r
F
.59368 .36876 m .59218 .36705 L .5951 .36529 L F
.20085 .34813 m .2017 .34533 L .20358 .34715 L 0 .026 .125 r
F
.20085 .34813 m .19897 .34631 L .2017 .34533 L F
.2348 .34874 m .23568 .34602 L .23754 .34785 L 0 .027 .126 r
F
.2348 .34874 m .23294 .34694 L .23568 .34602 L F
.30268 .34999 m .30368 .34721 L .30547 .34901 L 0 .03 .13 r
F
.30268 .34999 m .30089 .34821 L .30368 .34721 L F
.1669 .34757 m .16769 .34478 L .16961 .34665 L 0 .025 .123 r
F
.1669 .34757 m .16499 .34572 L .16769 .34478 L F
.40608 .35677 m .40723 .3542 L .40891 .35602 L 0 .046 .148 r
F
.40608 .35677 m .4044 .35494 L .40723 .3542 L F
.66423 .35495 m .66576 .35201 L .66719 .35361 L 0 .04 .142 r
F
.66423 .35495 m .6628 .35333 L .66576 .35201 L F
.37503 .35356 m .37613 .35107 L .37784 .35284 L 0 .038 .14 r
F
.37503 .35356 m .37331 .35182 L .37613 .35107 L F
.44606 .36462 m .44727 .36228 L .44891 .36416 L 0 .068 .169 r
F
.44606 .36462 m .44442 .36272 L .44727 .36228 L F
.83818 .34786 m .83998 .34504 L .84125 .34692 L 0 .025 .124 r
F
.83818 .34786 m .83691 .34597 L .83998 .34504 L F
.88687 .34768 m .88875 .3449 L .88996 .34669 L F
.88687 .34768 m .88565 .34588 L .88875 .3449 L F
.26872 .34958 m .26967 .34675 L .27149 .34855 L 0 .029 .129 r
F
.26872 .34958 m .2669 .3478 L .26967 .34675 L F
.76003 .3498 m .76171 .34685 L .76305 .34871 L F
.76003 .3498 m .75869 .34793 L .76171 .34685 L F
.6495 .35596 m .65101 .35308 L .65246 .35487 L 0 .043 .146 r
F
.6495 .35596 m .64805 .35416 L .65101 .35308 L F
.35582 .3523 m .35688 .34975 L .35861 .35161 L 0 .035 .137 r
F
.35582 .3523 m .35408 .35043 L .35688 .34975 L F
.20819 .34803 m .20904 .3453 L .21091 .34716 L 0 .026 .125 r
F
.20819 .34803 m .20631 .3462 L .20904 .3453 L F
.58342 .37215 m .58484 .36948 L .58634 .37057 L 0 .092 .189 r
F
.58342 .37215 m .58192 .37133 L .58484 .36948 L F
.65687 .35562 m .6584 .35289 L .65984 .35461 L 0 .043 .145 r
F
.65687 .35562 m .65543 .35388 L .6584 .35289 L F
.76741 .3495 m .76911 .34673 L .77044 .34858 L 0 .029 .129 r
F
.76741 .3495 m .76607 .34763 L .76911 .34673 L F
.50755 .41636 m .50878 .42949 L .5104 .42406 L 0 .336 .295 r
F
.50755 .41636 m .50593 .42023 L .50878 .42949 L F
.27608 .34936 m .27703 .34659 L .27884 .34846 L 0 .029 .129 r
F
.27608 .34936 m .27426 .34752 L .27703 .34659 L F
.51202 .41866 m .51327 .4325 L .51489 .42541 L 0 .343 .29 r
F
.51202 .41866 m .5104 .42406 L .51327 .4325 L F
.31002 .34999 m .31102 .3473 L .3128 .34915 L 0 .03 .13 r
F
.31002 .34999 m .30824 .34816 L .31102 .3473 L F
.64213 .35653 m .64364 .3536 L .64509 .35535 L 0 .045 .147 r
F
.64213 .35653 m .64068 .3548 L .64364 .3536 L F
.39423 .35536 m .39536 .35258 L .39705 .35452 L 0 .042 .144 r
F
.39423 .35536 m .39253 .3534 L .39536 .35258 L F
.84559 .34782 m .84739 .3449 L .84865 .34674 L 0 .026 .124 r
F
.84559 .34782 m .84433 .34596 L .84739 .3449 L F
.42527 .35866 m .42645 .35601 L .42811 .3582 L 0 .051 .154 r
F
.42527 .35866 m .42362 .35648 L .42645 .35601 L F
.24212 .34886 m .24301 .34618 L .24486 .34804 L 0 .028 .128 r
F
.24212 .34886 m .24027 .34701 L .24301 .34618 L F
.3366 .35111 m .33764 .34846 L .33939 .35019 L 0 .033 .134 r
F
.3366 .35111 m .33484 .34936 L .33764 .34846 L F
.17422 .34763 m .17502 .34485 L .17693 .34674 L 0 .025 .124 r
F
.17422 .34763 m .17231 .34576 L .17502 .34485 L F
.85296 .34744 m .85479 .34466 L .85603 .34643 L F
.85296 .34744 m .85171 .34566 L .85479 .34466 L F
.56893 .38572 m .56745 .3884 L .57032 .38298 L 0 .146 .226 r
F
.56605 .38998 m .56458 .39387 L .56745 .3884 L 0 .173 .242 r
F
.56745 .3884 m .56598 .39114 L .56604 .39099 L F
.56605 .38998 m .56745 .3884 L .56886 .38582 L F
.56745 .3884 m .56604 .39099 L .56884 .38451 L F
.56886 .38582 m .56745 .3884 L .56893 .38572 L F
.71874 .34997 m .72037 .34732 L .72175 .34905 L 0 .031 .131 r
F
.71874 .34997 m .71736 .34824 L .72037 .34732 L F
.63477 .35717 m .63627 .35453 L .63773 .35598 L 0 .047 .15 r
F
.63477 .35717 m .63332 .35571 L .63627 .35453 L F
.78954 .34858 m .79128 .34586 L .79258 .34759 L 0 .028 .127 r
F
.78954 .34858 m .78824 .34686 L .79128 .34586 L F
.78218 .34902 m .78389 .34616 L .7852 .34788 L 0 .028 .128 r
F
.78218 .34902 m .78086 .34729 L .78389 .34616 L F
.77481 .34945 m .77652 .34665 L .77784 .34843 L 0 .029 .129 r
F
.77481 .34945 m .77348 .34766 L .77652 .34665 L F
.41343 .35705 m .41458 .35447 L .41626 .35626 L 0 .047 .15 r
F
.41343 .35705 m .41175 .35526 L .41458 .35447 L F
.86035 .34724 m .8622 .34454 L .86344 .34629 L 0 .025 .124 r
F
.86035 .34724 m .85912 .34548 L .8622 .34454 L F
.71138 .35055 m .71299 .34772 L .71437 .34938 L 0 .032 .132 r
F
.71138 .35055 m .71 .34889 L .71299 .34772 L F
.21551 .3481 m .21637 .34541 L .21824 .34721 L 0 .027 .126 r
F
.21551 .3481 m .21364 .34629 L .21637 .34541 L F
.18156 .3475 m .18237 .3447 L .18428 .34648 L 0 .026 .124 r
F
.18156 .3475 m .17965 .34572 L .18237 .3447 L F
.60687 .36388 m .60831 .36074 L .6098 .3624 L 0 .065 .167 r
F
.60687 .36388 m .60538 .36217 L .60831 .36074 L F
.34395 .35102 m .345 .3484 L .34675 .35018 L 0 .033 .134 r
F
.34395 .35102 m .34219 .34927 L .345 .3484 L F
.61714 .36085 m .6186 .35771 L .62007 .35921 L 0 .056 .159 r
F
.61714 .36085 m .61566 .35932 L .6186 .35771 L F
.69664 .35145 m .69823 .34852 L .69963 .35032 L 0 .034 .134 r
F
.69664 .35145 m .69524 .34962 L .69823 .34852 L F
.70401 .35104 m .70562 .34834 L .70701 .35002 L 0 .033 .134 r
F
.70401 .35104 m .70262 .34934 L .70562 .34834 L F
.5966 .36701 m .59802 .36363 L .59952 .36536 L 0 .074 .175 r
F
.5966 .36701 m .5951 .36529 L .59802 .36363 L F
.28341 .34945 m .28438 .34665 L .28617 .34856 L 0 .03 .13 r
F
.28341 .34945 m .28161 .34756 L .28438 .34665 L F
.31736 .35008 m .31838 .34722 L .32015 .34909 L 0 .031 .131 r
F
.31736 .35008 m .31559 .34823 L .31838 .34722 L F
.38237 .35398 m .38347 .35146 L .38518 .3533 L 0 .04 .142 r
F
.38237 .35398 m .38065 .35217 L .38347 .35146 L F
.79694 .34847 m .79867 .34552 L .79998 .3474 L 0 .027 .127 r
F
.79694 .34847 m .79563 .34658 L .79867 .34552 L F
.24945 .3489 m .25037 .34605 L .25221 .3479 L 0 .028 .128 r
F
.24945 .3489 m .24761 .34707 L .25037 .34605 L F
.86775 .34707 m .8696 .34426 L .87083 .34604 L 0 .025 .123 r
F
.86775 .34707 m .86652 .34528 L .8696 .34426 L F
.18891 .34728 m .18972 .34464 L .19162 .3464 L 0 .026 .124 r
F
.18891 .34728 m .187 .34553 L .18972 .34464 L F
.68928 .35198 m .69085 .34896 L .69226 .3508 L 0 .035 .136 r
F
.68928 .35198 m .68787 .35013 L .69085 .34896 L F
.68191 .35241 m .68347 .34948 L .68489 .35127 L 0 .036 .137 r
F
.68191 .35241 m .68049 .35061 L .68347 .34948 L F
.67454 .35283 m .6761 .35009 L .67751 .35173 L 0 .037 .139 r
F
.67454 .35283 m .67312 .35121 L .6761 .35009 L F
.44157 .36327 m .44277 .36083 L .44442 .36272 L 0 .065 .167 r
F
.44157 .36327 m .43992 .36132 L .44277 .36083 L F
.14758 .34712 m .14833 .34439 L .15028 .34617 L 0 .025 .124 r
F
.14758 .34712 m .14564 .34533 L .14833 .34439 L F
.72614 .35 m .72777 .34718 L .72915 .34903 L 0 .031 .131 r
F
.72614 .35 m .72476 .34813 L .72777 .34718 L F
.80432 .3482 m .80606 .34527 L .80736 .34714 L 0 .027 .126 r
F
.80432 .3482 m .80302 .34632 L .80606 .34527 L F
.62742 .35803 m .62891 .35542 L .63037 .35688 L 0 .05 .153 r
F
.62742 .35803 m .62596 .35657 L .62891 .35542 L F
.36315 .35273 m .36422 .35013 L .36595 .35192 L 0 .037 .139 r
F
.36315 .35273 m .36141 .35092 L .36422 .35013 L F
.556 .40446 m .55452 .40969 L .55741 .40459 L 0 .25 .282 r
F
.55312 .40856 m .55452 .40969 L .556 .40446 L 0 .282 .297 r
F
.22285 .34806 m .22371 .34541 L .22558 .34715 L 0 .027 .127 r
F
.22285 .34806 m .22097 .34632 L .22371 .34541 L F
.2568 .34869 m .25771 .34609 L .25955 .34785 L 0 .029 .128 r
F
.2568 .34869 m .25496 .34693 L .25771 .34609 L F
.32472 .34992 m .32573 .34734 L .3275 .34914 L 0 .031 .132 r
F
.32472 .34992 m .32295 .3481 L .32573 .34734 L F
.87515 .34688 m .877 .34408 L .87824 .34593 L 0 .025 .123 r
F
.87515 .34688 m .87391 .34503 L .877 .34408 L F
.81171 .34793 m .81346 .34504 L .81475 .34687 L 0 .027 .126 r
F
.81171 .34793 m .81041 .34609 L .81346 .34504 L F
.40157 .35571 m .40271 .35301 L .4044 .35494 L 0 .044 .147 r
F
.40157 .35571 m .39988 .35377 L .40271 .35301 L F
.73352 .34983 m .73517 .34698 L .73653 .34878 L 0 .031 .131 r
F
.73352 .34983 m .73216 .348 L .73517 .34698 L F
.29075 .34943 m .29172 .34669 L .29353 .34846 L 0 .03 .13 r
F
.29075 .34943 m .28895 .34763 L .29172 .34669 L F
.15492 .34699 m .15569 .34422 L .15763 .34599 L 0 .025 .124 r
F
.15492 .34699 m .15298 .34522 L .15569 .34422 L F
.81909 .34763 m .82086 .34485 L .82214 .34661 L 0 .026 .125 r
F
.81909 .34763 m .81781 .34586 L .82086 .34485 L F
.7409 .34949 m .74256 .34676 L .74392 .34847 L 0 .03 .131 r
F
.7409 .34949 m .73955 .34777 L .74256 .34676 L F
.58634 .37057 m .58776 .36765 L .58926 .36883 L 0 .088 .186 r
F
.58634 .37057 m .58484 .36948 L .58776 .36765 L F
.66719 .35361 m .66873 .35072 L .67015 .35233 L 0 .039 .141 r
F
.66719 .35361 m .66576 .35201 L .66873 .35072 L F
.19624 .34728 m .19707 .34454 L .19897 .34631 L 0 .026 .125 r
F
.19624 .34728 m .19434 .34551 L .19707 .34454 L F
.42078 .3573 m .42195 .35455 L .42362 .35648 L 0 .049 .151 r
F
.42078 .3573 m .4191 .35541 L .42195 .35455 L F
.2302 .34791 m .23108 .3452 L .23294 .34694 L 0 .027 .126 r
F
.2302 .34791 m .22833 .34617 L .23108 .3452 L F
.82647 .3473 m .82825 .34447 L .82952 .34621 L 0 .026 .125 r
F
.82647 .3473 m .8252 .34556 L .82825 .34447 L F
.35129 .35119 m .35235 .34857 L .35408 .35043 L 0 .034 .135 r
F
.35129 .35119 m .34954 .34938 L .35235 .34857 L F
.74828 .34917 m .74996 .34654 L .7513 .34823 L 0 .03 .13 r
F
.74828 .34917 m .74693 .34748 L .74996 .34654 L F
.83384 .34695 m .83564 .34414 L .83691 .34597 L 0 .025 .124 r
F
.83384 .34695 m .83257 .34511 L .83564 .34414 L F
.16227 .34675 m .16306 .3439 L .16499 .34572 L 0 .025 .123 r
F
.16227 .34675 m .16034 .34495 L .16306 .3439 L F
.29811 .34923 m .2991 .34645 L .30089 .34821 L 0 .03 .13 r
F
.29811 .34923 m .29631 .34746 L .2991 .34645 L F
.37049 .35276 m .37159 .35005 L .37331 .35182 L 0 .038 .139 r
F
.37049 .35276 m .36877 .35098 L .37159 .35005 L F
.88256 .34684 m .88443 .34403 L .88565 .34588 L 0 .025 .124 r
F
.88256 .34684 m .88133 .34498 L .88443 .34403 L F
.26413 .34876 m .26507 .34605 L .2669 .3478 L 0 .029 .129 r
F
.26413 .34876 m .2623 .34701 L .26507 .34605 L F
.49099 .40111 m .49216 .40933 L .49378 .40963 L 0 .265 .289 r
F
.49099 .40111 m .48937 .40034 L .49216 .40933 L F
.5415 .41829 m .54292 .42556 L .54442 .41735 L 0 .332 .297 r
F
.5415 .41829 m .53999 .4265 L .54292 .42556 L F
.75567 .34897 m .75735 .34623 L .75869 .34793 L 0 .03 .13 r
F
.75567 .34897 m .75433 .34728 L .75735 .34623 L F
.38971 .3543 m .39084 .35147 L .39253 .3534 L 0 .041 .143 r
F
.38971 .3543 m .38801 .35239 L .39084 .35147 L F
.20358 .34715 m .20443 .34436 L .20631 .3462 L 0 .026 .125 r
F
.20358 .34715 m .2017 .34533 L .20443 .34436 L F
.30547 .34901 m .30646 .34636 L .30824 .34816 L 0 .03 .13 r
F
.30547 .34901 m .30368 .34721 L .30646 .34636 L F
.53123 .42144 m .53262 .43702 L .53415 .42439 L 0 .356 .281 r
F
.53123 .42144 m .52968 .43268 L .53262 .43702 L F
.23754 .34785 m .23842 .34517 L .24027 .34701 L 0 .028 .127 r
F
.23754 .34785 m .23568 .34602 L .23842 .34517 L F
.16961 .34665 m .1704 .34388 L .17231 .34576 L 0 .025 .124 r
F
.16961 .34665 m .16769 .34478 L .1704 .34388 L F
.76305 .34871 m .76473 .34576 L .76607 .34763 L 0 .029 .129 r
F
.76305 .34871 m .76171 .34685 L .76473 .34576 L F
.43708 .36182 m .43827 .3593 L .43992 .36132 L 0 .062 .164 r
F
.43708 .36182 m .43543 .35975 L .43827 .3593 L F
.33205 .35016 m .33307 .34761 L .33484 .34936 L 0 .033 .133 r
F
.33205 .35016 m .33028 .34839 L .33307 .34761 L F
.88996 .34669 m .89185 .34393 L .89305 .3457 L 0 .025 .124 r
F
.88996 .34669 m .88875 .3449 L .89185 .34393 L F
.65246 .35487 m .65399 .35212 L .65543 .35388 L 0 .043 .145 r
F
.65246 .35487 m .65101 .35308 L .65399 .35212 L F
.47733 .38207 m .47856 .38111 L .48016 .38418 L 0 .138 .221 r
F
.47733 .38207 m .47572 .37948 L .47856 .38111 L F
.27149 .34855 m .27244 .3457 L .27426 .34752 L 0 .029 .129 r
F
.27149 .34855 m .26967 .34675 L .27244 .3457 L F
.84125 .34692 m .84306 .3441 L .84433 .34596 L 0 .026 .124 r
F
.84125 .34692 m .83998 .34504 L .84306 .3441 L F
.62007 .35921 m .62154 .35624 L .62301 .35773 L 0 .054 .156 r
F
.62007 .35921 m .6186 .35771 L .62154 .35624 L F
.45787 .36822 m .45909 .36574 L .46072 .36813 L 0 .082 .181 r
F
.45787 .36822 m .45624 .36588 L .45909 .36574 L F
.59952 .36536 m .60095 .36197 L .60245 .3637 L 0 .071 .172 r
F
.59952 .36536 m .59802 .36363 L .60095 .36197 L F
.64509 .35535 m .6466 .35241 L .64805 .35416 L 0 .044 .146 r
F
.64509 .35535 m .64364 .3536 L .6466 .35241 L F
.46234 .3705 m .46357 .36807 L .46519 .3705 L 0 .09 .187 r
F
.46234 .3705 m .46072 .36813 L .46357 .36807 L F
.40891 .35602 m .41006 .35346 L .41175 .35526 L 0 .046 .149 r
F
.40891 .35602 m .40723 .3542 L .41006 .35346 L F
.65984 .35461 m .66137 .35164 L .6628 .35333 L 0 .042 .144 r
F
.65984 .35461 m .6584 .35289 L .66137 .35164 L F
.6098 .3624 m .61125 .35931 L .61273 .36092 L 0 .063 .165 r
F
.6098 .3624 m .60831 .36074 L .61125 .35931 L F
.37784 .35284 m .37894 .35037 L .38065 .35217 L 0 .039 .141 r
F
.37784 .35284 m .37613 .35107 L .37894 .35037 L F
.45339 .36614 m .45461 .36355 L .45624 .36588 L 0 .075 .176 r
F
.45339 .36614 m .45176 .36385 L .45461 .36355 L F
.46681 .37289 m .46804 .37059 L .46966 .37312 L 0 .099 .194 r
F
.46681 .37289 m .46519 .3705 L .46804 .37059 L F
.77044 .34858 m .77215 .34582 L .77348 .34766 L 0 .029 .129 r
F
.77044 .34858 m .76911 .34673 L .77215 .34582 L F
.84865 .34674 m .85046 .34383 L .85171 .34566 L 0 .025 .124 r
F
.84865 .34674 m .84739 .3449 L .85046 .34383 L F
.21091 .34716 m .21177 .34441 L .21364 .34629 L 0 .026 .126 r
F
.21091 .34716 m .20904 .3453 L .21177 .34441 L F
.63773 .35598 m .63923 .35334 L .64068 .3548 L 0 .047 .149 r
F
.63773 .35598 m .63627 .35453 L .63923 .35334 L F
.49702 .40876 m .49822 .41801 L .49985 .41588 L 0 .311 .307 r
F
.49702 .40876 m .4954 .40992 L .49822 .41801 L F
.27884 .34846 m .2798 .34566 L .28161 .34756 L 0 .029 .129 r
F
.27884 .34846 m .27703 .34659 L .2798 .34566 L F
.56317 .39452 m .56458 .39387 L .56605 .38998 L 0 .204 .259 r
F
.85603 .34643 m .85787 .34373 L .85912 .34548 L 0 .025 .124 r
F
.85603 .34643 m .85479 .34466 L .85787 .34373 L F
.48337 .38958 m .48456 .39296 L .48616 .39576 L 0 .188 .25 r
F
.48337 .38958 m .48176 .38717 L .48456 .39296 L F
.7852 .34788 m .78693 .34512 L .78824 .34686 L 0 .028 .128 r
F
.7852 .34788 m .78389 .34616 L .78693 .34512 L F
.3128 .34915 m .31381 .34637 L .31559 .34823 L 0 .031 .131 r
F
.3128 .34915 m .31102 .3473 L .31381 .34637 L F
.35861 .35161 m .35968 .34907 L .36141 .35092 L 0 .036 .138 r
F
.35861 .35161 m .35688 .34975 L .35968 .34907 L F
.33939 .35019 m .34044 .34755 L .34219 .34927 L 0 .033 .134 r
F
.33939 .35019 m .33764 .34846 L .34044 .34755 L F
.71437 .34938 m .71599 .34659 L .71736 .34824 L 0 .031 .132 r
F
.71437 .34938 m .71299 .34772 L .71599 .34659 L F
.17693 .34674 m .17774 .34383 L .17965 .34572 L 0 .026 .124 r
F
.17693 .34674 m .17502 .34485 L .17774 .34383 L F
.58926 .36883 m .59068 .36582 L .59218 .36705 L 0 .083 .182 r
F
.58926 .36883 m .58776 .36765 L .59068 .36582 L F
.39705 .35452 m .39819 .35183 L .39988 .35377 L 0 .043 .145 r
F
.39705 .35452 m .39536 .35258 L .39819 .35183 L F
.79258 .34759 m .79432 .34484 L .79563 .34658 L 0 .028 .127 r
F
.79258 .34759 m .79128 .34586 L .79432 .34484 L F
.44891 .36416 m .45011 .36197 L .45176 .36385 L 0 .071 .172 r
F
.44891 .36416 m .44727 .36228 L .45011 .36197 L F
.43259 .36007 m .43378 .35758 L .43543 .35975 L 0 .058 .16 r
F
.43259 .36007 m .43094 .35789 L .43378 .35758 L F
.77784 .34843 m .77954 .34553 L .78086 .34729 L 0 .029 .129 r
F
.77784 .34843 m .77652 .34665 L .77954 .34553 L F
.72175 .34905 m .72339 .34639 L .72476 .34813 L 0 .031 .131 r
F
.72175 .34905 m .72037 .34732 L .72339 .34639 L F
.24486 .34804 m .24577 .34518 L .24761 .34707 L 0 .028 .128 r
F
.24486 .34804 m .24301 .34618 L .24577 .34518 L F
.69963 .35032 m .70123 .34757 L .70262 .34934 L 0 .033 .134 r
F
.69963 .35032 m .69823 .34852 L .70123 .34757 L F
.18428 .34648 m .18509 .34375 L .187 .34553 L 0 .026 .124 r
F
.18428 .34648 m .18237 .3447 L .18509 .34375 L F
.86344 .34629 m .86528 .34354 L .86652 .34528 L 0 .025 .124 r
F
.86344 .34629 m .8622 .34454 L .86528 .34354 L F
.69226 .3508 m .69383 .34779 L .69524 .34962 L 0 .034 .135 r
F
.69226 .3508 m .69085 .34896 L .69383 .34779 L F
.70701 .35002 m .70862 .34723 L .71 .34889 L 0 .033 .134 r
F
.70701 .35002 m .70562 .34834 L .70862 .34723 L F
.68489 .35127 m .68645 .34835 L .68787 .35013 L 0 .035 .137 r
F
.68489 .35127 m .68347 .34948 L .68645 .34835 L F
.79998 .3474 m .80171 .34446 L .80302 .34632 L 0 .027 .126 r
F
.79998 .3474 m .79867 .34552 L .80171 .34446 L F
.55312 .40856 m .55164 .41482 L .55452 .40969 L 0 .282 .297 r
F
.55022 .41246 m .55164 .41482 L .55312 .40856 L 0 .311 .306 r
F
.47127 .37564 m .4725 .37393 L .47411 .37682 L 0 .112 .204 r
F
.47127 .37564 m .46966 .37312 L .4725 .37393 L F
.21824 .34721 m .2191 .34451 L .22097 .34632 L 0 .027 .126 r
F
.21824 .34721 m .21637 .34541 L .2191 .34451 L F
.67751 .35173 m .67908 .34896 L .68049 .35061 L 0 .037 .138 r
F
.67751 .35173 m .6761 .35009 L .67908 .34896 L F
.32015 .34909 m .32118 .34622 L .32295 .3481 L 0 .031 .131 r
F
.32015 .34909 m .31838 .34722 L .32118 .34622 L F
.41626 .35626 m .41743 .35358 L .4191 .35541 L 0 .048 .15 r
F
.41626 .35626 m .41458 .35447 L .41743 .35358 L F
.63037 .35688 m .63186 .35425 L .63332 .35571 L 0 .05 .152 r
F
.63037 .35688 m .62891 .35542 L .63186 .35425 L F
.87083 .34604 m .87268 .34325 L .87391 .34503 L 0 .025 .123 r
F
.87083 .34604 m .8696 .34426 L .87268 .34325 L F
.25221 .3479 m .25313 .34507 L .25496 .34693 L 0 .028 .128 r
F
.25221 .3479 m .25037 .34605 L .25313 .34507 L F
.34675 .35018 m .3478 .34755 L .34954 .34938 L 0 .034 .135 r
F
.34675 .35018 m .345 .3484 L .3478 .34755 L F
.28617 .34856 m .28715 .34571 L .28895 .34763 L 0 .03 .13 r
F
.28617 .34856 m .28438 .34665 L .28715 .34571 L F
.80736 .34714 m .80911 .34423 L .81041 .34609 L 0 .027 .126 r
F
.80736 .34714 m .80606 .34527 L .80911 .34423 L F
.42811 .3582 m .42928 .3557 L .43094 .35789 L 0 .053 .156 r
F
.42811 .3582 m .42645 .35601 L .42928 .3557 L F
.72915 .34903 m .73078 .34618 L .73216 .348 L 0 .031 .131 r
F
.72915 .34903 m .72777 .34718 L .73078 .34618 L F
.15028 .34617 m .15104 .34344 L .15298 .34522 L 0 .025 .124 r
F
.15028 .34617 m .14833 .34439 L .15104 .34344 L F
.19162 .3464 m .19244 .34375 L .19434 .34551 L 0 .026 .125 r
F
.19162 .3464 m .18972 .34464 L .19244 .34375 L F
.67015 .35233 m .6717 .34959 L .67312 .35121 L 0 .038 .14 r
F
.67015 .35233 m .66873 .35072 L .6717 .34959 L F
.81475 .34687 m .81652 .34405 L .81781 .34586 L 0 .027 .126 r
F
.81475 .34687 m .81346 .34504 L .81652 .34405 L F
.60245 .3637 m .60389 .36047 L .60538 .36217 L 0 .068 .169 r
F
.60245 .3637 m .60095 .36197 L .60389 .36047 L F
.73653 .34878 m .73818 .34599 L .73955 .34777 L 0 .031 .131 r
F
.73653 .34878 m .73517 .34698 L .73818 .34599 L F
.22558 .34715 m .22646 .34443 L .22833 .34617 L 0 .027 .127 r
F
.22558 .34715 m .22371 .34541 L .22646 .34443 L F
.87824 .34593 m .8801 .34312 L .88133 .34498 L 0 .025 .123 r
F
.87824 .34593 m .877 .34408 L .8801 .34312 L F
.38518 .3533 m .3863 .35052 L .38801 .35239 L 0 .041 .143 r
F
.38518 .3533 m .38347 .35146 L .3863 .35052 L F
.36595 .35192 m .36704 .34921 L .36877 .35098 L 0 .038 .139 r
F
.36595 .35192 m .36422 .35013 L .36704 .34921 L F
.15763 .34599 m .15841 .34316 L .16034 .34495 L 0 .025 .124 r
F
.15763 .34599 m .15569 .34422 L .15841 .34316 L F
.82214 .34661 m .82392 .34382 L .8252 .34556 L 0 .026 .125 r
F
.82214 .34661 m .82086 .34485 L .82392 .34382 L F
.82952 .34621 m .83131 .34337 L .83257 .34511 L 0 .025 .124 r
F
.82952 .34621 m .82825 .34447 L .83131 .34337 L F
.29353 .34846 m .29451 .3457 L .29631 .34746 L 0 .03 .13 r
F
.29353 .34846 m .29172 .34669 L .29451 .3457 L F
.25955 .34785 m .26047 .34525 L .2623 .34701 L 0 .029 .129 r
F
.25955 .34785 m .25771 .34609 L .26047 .34525 L F
.74392 .34847 m .74558 .34577 L .74693 .34748 L 0 .03 .13 r
F
.74392 .34847 m .74256 .34676 L .74558 .34577 L F
.62301 .35773 m .62449 .35508 L .62596 .35657 L 0 .052 .155 r
F
.62301 .35773 m .62154 .35624 L .62449 .35508 L F
.3275 .34914 m .32852 .34661 L .33028 .34839 L 0 .032 .133 r
F
.3275 .34914 m .32573 .34734 L .32852 .34661 L F
.19897 .34631 m .1998 .34357 L .2017 .34533 L 0 .026 .125 r
F
.19897 .34631 m .19707 .34454 L .1998 .34357 L F
.16499 .34572 m .16577 .34295 L .16769 .34478 L 0 .025 .123 r
F
.16499 .34572 m .16306 .3439 L .16577 .34295 L F
.23294 .34694 m .23382 .34427 L .23568 .34602 L 0 .027 .127 r
F
.23294 .34694 m .23108 .3452 L .23382 .34427 L F
.4044 .35494 m .40554 .3523 L .40723 .3542 L 0 .045 .148 r
F
.4044 .35494 m .40271 .35301 L .40554 .3523 L F
.44442 .36272 m .44562 .36041 L .44727 .36228 L 0 .067 .169 r
F
.44442 .36272 m .44277 .36083 L .44562 .36041 L F
.30089 .34821 m .30188 .34545 L .30368 .34721 L 0 .03 .13 r
F
.30089 .34821 m .2991 .34645 L .30188 .34545 L F
.83691 .34597 m .83872 .34321 L .83998 .34504 L 0 .025 .124 r
F
.83691 .34597 m .83564 .34414 L .83872 .34321 L F
.7513 .34823 m .75299 .3456 L .75433 .34728 L 0 .03 .13 r
F
.7513 .34823 m .74996 .34654 L .75299 .3456 L F
.59218 .36705 m .5936 .364 L .5951 .36529 L 0 .079 .179 r
F
.59218 .36705 m .59068 .36582 L .5936 .364 L F
.61273 .36092 m .61419 .35774 L .61566 .35932 L 0 .06 .162 r
F
.61273 .36092 m .61125 .35931 L .61419 .35774 L F
.52386 .42335 m .52519 .43798 L .52677 .428 L 0 .361 .277 r
F
.52386 .42335 m .52228 .4318 L .52519 .43798 L F
.42362 .35648 m .42479 .35404 L .42645 .35601 L 0 .05 .152 r
F
.42362 .35648 m .42195 .35455 L .42479 .35404 L F
.88565 .34588 m .88753 .34307 L .88875 .3449 L 0 .025 .124 r
F
.88565 .34588 m .88443 .34403 L .88753 .34307 L F
.37331 .35182 m .3744 .34929 L .37613 .35107 L 0 .038 .14 r
F
.37331 .35182 m .37159 .35005 L .3744 .34929 L F
.75869 .34793 m .76037 .34513 L .76171 .34685 L 0 .029 .129 r
F
.75869 .34793 m .75735 .34623 L .76037 .34513 L F
.35408 .35043 m .35515 .34786 L .35688 .34975 L 0 .035 .136 r
F
.35408 .35043 m .35235 .34857 L .35515 .34786 L F
.54442 .41735 m .54583 .42263 L .54732 .41491 L 0 .329 .299 r
F
.54442 .41735 m .54292 .42556 L .54583 .42263 L F
.2669 .3478 m .26784 .345 L .26967 .34675 L 0 .029 .129 r
F
.2669 .3478 m .26507 .34605 L .26784 .345 L F
.6628 .35333 m .66433 .35033 L .66576 .35201 L 0 .041 .143 r
F
.6628 .35333 m .66137 .35164 L .66433 .35033 L F
.64805 .35416 m .64956 .35132 L .65101 .35308 L 0 .043 .146 r
F
.64805 .35416 m .6466 .35241 L .64956 .35132 L F
.20631 .3462 m .20716 .34344 L .20904 .3453 L 0 .026 .125 r
F
.20631 .3462 m .20443 .34436 L .20716 .34344 L F
.76607 .34763 m .76777 .34487 L .76911 .34673 L 0 .029 .129 r
F
.76607 .34763 m .76473 .34576 L .76777 .34487 L F
.39253 .3534 m .39367 .35063 L .39536 .35258 L 0 .042 .144 r
F
.39253 .3534 m .39084 .35147 L .39367 .35063 L F
.27426 .34752 m .27522 .34474 L .27703 .34659 L 0 .029 .129 r
F
.27426 .34752 m .27244 .3457 L .27522 .34474 L F
.65543 .35388 m .65696 .35116 L .6584 .35289 L 0 .043 .145 r
F
.65543 .35388 m .65399 .35212 L .65696 .35116 L F
.30824 .34816 m .30924 .3455 L .31102 .3473 L 0 .03 .13 r
F
.30824 .34816 m .30646 .34636 L .30924 .3455 L F
.54732 .41491 m .54874 .41969 L .55022 .41246 L 0 .322 .302 r
F
.54732 .41491 m .54583 .42263 L .54874 .41969 L F
.84433 .34596 m .84613 .34304 L .84739 .3449 L 0 .025 .124 r
F
.84433 .34596 m .84306 .3441 L .84613 .34304 L F
.579 .37317 m .58042 .37052 L .58192 .37133 L 0 .102 .197 r
F
.579 .37317 m .5775 .37264 L .58042 .37052 L F
.5761 .37599 m .5775 .37264 L .579 .37317 L 0 .111 .203 r
F
.17231 .34576 m .17311 .34296 L .17502 .34485 L 0 .025 .124 r
F
.17231 .34576 m .1704 .34388 L .17311 .34296 L F
.24027 .34701 m .24117 .34431 L .24301 .34618 L 0 .028 .128 r
F
.24027 .34701 m .23842 .34517 L .24117 .34431 L F
.64068 .3548 m .64219 .35209 L .64364 .3536 L 0 .046 .148 r
F
.64068 .3548 m .63923 .35334 L .64219 .35209 L F
.85171 .34566 m .85354 .34283 L .85479 .34466 L 0 .025 .124 r
F
.85171 .34566 m .85046 .34383 L .85354 .34283 L F
.33484 .34936 m .33587 .34673 L .33764 .34846 L 0 .033 .134 r
F
.33484 .34936 m .33307 .34761 L .33587 .34673 L F
.5761 .37599 m .57461 .37601 L .5775 .37264 L 0 .111 .203 r
F
.57321 .37949 m .57461 .37601 L .5761 .37599 L 0 .126 .214 r
F
.55022 .41246 m .54874 .41969 L .55164 .41482 L 0 .311 .306 r
F
.71736 .34824 m .719 .34565 L .72037 .34732 L 0 .031 .131 r
F
.71736 .34824 m .71599 .34659 L .719 .34565 L F
.77348 .34766 m .77519 .34483 L .77652 .34665 L 0 .029 .129 r
F
.77348 .34766 m .77215 .34582 L .77519 .34483 L F
.78824 .34686 m .78997 .34412 L .79128 .34586 L 0 .028 .127 r
F
.78824 .34686 m .78693 .34512 L .78997 .34412 L F
.41175 .35526 m .4129 .35266 L .41458 .35447 L 0 .047 .15 r
F
.41175 .35526 m .41006 .35346 L .4129 .35266 L F
.78086 .34729 m .78257 .3444 L .78389 .34616 L 0 .029 .128 r
F
.78086 .34729 m .77954 .34553 L .78257 .3444 L F
.21364 .34629 m .2145 .34351 L .21637 .34541 L 0 .027 .126 r
F
.21364 .34629 m .21177 .34441 L .2145 .34351 L F
.85912 .34548 m .86096 .34279 L .8622 .34454 L 0 .025 .124 r
F
.85912 .34548 m .85787 .34373 L .86096 .34279 L F
.28161 .34756 m .28257 .34472 L .28438 .34665 L 0 .029 .129 r
F
.28161 .34756 m .2798 .34566 L .28257 .34472 L F
.17965 .34572 m .18047 .34281 L .18237 .3447 L 0 .025 .124 r
F
.17965 .34572 m .17774 .34383 L .18047 .34281 L F
.69524 .34962 m .69682 .34671 L .69823 .34852 L 0 .034 .134 r
F
.69524 .34962 m .69383 .34779 L .69682 .34671 L F
.79563 .34658 m .79737 .34378 L .79867 .34552 L 0 .027 .127 r
F
.79563 .34658 m .79432 .34484 L .79737 .34378 L F
.43992 .36132 m .44112 .35885 L .44277 .36083 L 0 .064 .166 r
F
.43992 .36132 m .43827 .3593 L .44112 .35885 L F
.31559 .34823 m .31661 .34535 L .31838 .34722 L 0 .031 .131 r
F
.31559 .34823 m .31381 .34637 L .31661 .34535 L F
.34219 .34927 m .34324 .34666 L .345 .3484 L 0 .033 .134 r
F
.34219 .34927 m .34044 .34755 L .34324 .34666 L F
.60538 .36217 m .60682 .35908 L .60831 .36074 L 0 .065 .167 r
F
.60538 .36217 m .60389 .36047 L .60682 .35908 L F
.56317 .39452 m .56171 .39974 L .56458 .39387 L 0 .204 .259 r
F
.56029 .39955 m .56171 .39974 L .56317 .39452 L 0 .241 .277 r
F
.71 .34889 m .71161 .34606 L .71299 .34772 L 0 .032 .133 r
F
.71 .34889 m .70862 .34723 L .71161 .34606 L F
.68787 .35013 m .68944 .34718 L .69085 .34896 L 0 .035 .136 r
F
.68787 .35013 m .68645 .34835 L .68944 .34718 L F
.38065 .35217 m .38176 .34962 L .38347 .35146 L 0 .04 .142 r
F
.38065 .35217 m .37894 .35037 L .38176 .34962 L F
.24761 .34707 m .24853 .34415 L .25037 .34605 L 0 .028 .128 r
F
.24761 .34707 m .24577 .34518 L .24853 .34415 L F
.5951 .36529 m .59653 .36231 L .59802 .36363 L 0 .075 .176 r
F
.5951 .36529 m .5936 .364 L .59653 .36231 L F
.70262 .34934 m .70423 .34661 L .70562 .34834 L 0 .033 .134 r
F
.70262 .34934 m .70123 .34757 L .70423 .34661 L F
.72476 .34813 m .7264 .34543 L .72777 .34718 L 0 .031 .131 r
F
.72476 .34813 m .72339 .34639 L .7264 .34543 L F
.63332 .35571 m .63482 .35307 L .63627 .35453 L 0 .049 .151 r
F
.63332 .35571 m .63186 .35425 L .63482 .35307 L F
.86652 .34528 m .86837 .34252 L .8696 .34426 L 0 .025 .124 r
F
.86652 .34528 m .86528 .34354 L .86837 .34252 L F
.68049 .35061 m .68206 .34782 L .68347 .34948 L 0 .036 .138 r
F
.68049 .35061 m .67908 .34896 L .68206 .34782 L F
.80302 .34632 m .80476 .34342 L .80606 .34527 L 0 .027 .126 r
F
.80302 .34632 m .80171 .34446 L .80476 .34342 L F
.47572 .37948 m .47696 .37799 L .47856 .38111 L 0 .131 .217 r
F
.47572 .37948 m .47411 .37682 L .47696 .37799 L F
.187 .34553 m .18781 .34286 L .18972 .34464 L 0 .026 .125 r
F
.187 .34553 m .18509 .34375 L .18781 .34286 L F
.14564 .34533 m .1464 .34248 L .14833 .34439 L 0 .025 .124 r
F
.14564 .34533 m .1437 .34342 L .1464 .34248 L F
.39988 .35377 m .40102 .35108 L .40271 .35301 L 0 .044 .146 r
F
.39988 .35377 m .39819 .35183 L .40102 .35108 L F
.36141 .35092 m .36249 .34829 L .36422 .35013 L 0 .037 .139 r
F
.36141 .35092 m .35968 .34907 L .36249 .34829 L F
.61566 .35932 m .61712 .35616 L .6186 .35771 L 0 .057 .16 r
F
.61566 .35932 m .61419 .35774 L .61712 .35616 L F
.87391 .34503 m .87578 .34229 L .877 .34408 L 0 .025 .123 r
F
.87391 .34503 m .87268 .34325 L .87578 .34229 L F
.32295 .3481 m .32397 .34542 L .32573 .34734 L 0 .031 .132 r
F
.32295 .3481 m .32118 .34622 L .32397 .34542 L F
.81041 .34609 m .81217 .34319 L .81346 .34504 L 0 .027 .126 r
F
.81041 .34609 m .80911 .34423 L .81217 .34319 L F
.67312 .35121 m .67468 .34845 L .6761 .35009 L 0 .038 .14 r
F
.67312 .35121 m .6717 .34959 L .67468 .34845 L F
.22097 .34632 m .22184 .34361 L .22371 .34541 L 0 .027 .127 r
F
.22097 .34632 m .2191 .34451 L .22184 .34361 L F
.25496 .34693 m .25588 .34421 L .25771 .34609 L 0 .029 .128 r
F
.25496 .34693 m .25313 .34507 L .25588 .34421 L F
.58192 .37133 m .58334 .36841 L .58484 .36948 L 0 .096 .192 r
F
.58192 .37133 m .58042 .37052 L .58334 .36841 L F
.73216 .348 m .7338 .34518 L .73517 .34698 L 0 .031 .131 r
F
.73216 .348 m .73078 .34618 L .7338 .34518 L F
.28895 .34763 m .28993 .34477 L .29172 .34669 L 0 .03 .13 r
F
.28895 .34763 m .28715 .34571 L .28993 .34477 L F
.4191 .35541 m .42027 .3527 L .42195 .35455 L 0 .048 .151 r
F
.4191 .35541 m .41743 .35358 L .42027 .3527 L F
.46072 .36813 m .46195 .36562 L .46357 .36807 L 0 .086 .185 r
F
.46072 .36813 m .45909 .36574 L .46195 .36562 L F
.45624 .36588 m .45746 .36336 L .45909 .36574 L 0 .079 .179 r
F
.45624 .36588 m .45461 .36355 L .45746 .36336 L F
.15298 .34522 m .15375 .34245 L .15569 .34422 L 0 .025 .124 r
F
.15298 .34522 m .15104 .34344 L .15375 .34245 L F
.81781 .34586 m .81958 .34306 L .82086 .34485 L 0 .027 .126 r
F
.81781 .34586 m .81652 .34405 L .81958 .34306 L F
.34954 .34938 m .35061 .34671 L .35235 .34857 L 0 .034 .135 r
F
.34954 .34938 m .3478 .34755 L .35061 .34671 L F
.57321 .37949 m .57172 .38026 L .57461 .37601 L 0 .126 .214 r
F
.57032 .38298 m .57172 .38026 L .57321 .37949 L 0 .145 .226 r
F
.19434 .34551 m .19517 .34279 L .19707 .34454 L 0 .026 .125 r
F
.19434 .34551 m .19244 .34375 L .19517 .34279 L F
.73955 .34777 m .7412 .345 L .74256 .34676 L 0 .031 .131 r
F
.73955 .34777 m .73818 .34599 L .7412 .345 L F
.83257 .34511 m .83438 .34239 L .83564 .34414 L 0 .025 .124 r
F
.83257 .34511 m .83131 .34337 L .83438 .34239 L F
.62596 .35657 m .62745 .35392 L .62891 .35542 L 0 .052 .154 r
F
.62596 .35657 m .62449 .35508 L .62745 .35392 L F
.46519 .3705 m .46643 .36805 L .46804 .37059 L 0 .095 .191 r
F
.46519 .3705 m .46357 .36807 L .46643 .36805 L F
.50148 .4135 m .50266 .42794 L .5043 .42408 L 0 .337 .294 r
F
.50148 .4135 m .49985 .41588 L .50266 .42794 L F
.22833 .34617 m .22921 .34345 L .23108 .3452 L 0 .027 .127 r
F
.22833 .34617 m .22646 .34443 L .22921 .34345 L F
.16034 .34495 m .16113 .3421 L .16306 .3439 L 0 .025 .123 r
F
.16034 .34495 m .15841 .34316 L .16113 .3421 L F
.8252 .34556 m .82698 .34272 L .82825 .34447 L 0 .026 .125 r
F
.8252 .34556 m .82392 .34382 L .82698 .34272 L F
.88133 .34498 m .8832 .34218 L .88443 .34403 L 0 .025 .124 r
F
.88133 .34498 m .8801 .34312 L .8832 .34218 L F
.48176 .38717 m .48297 .38922 L .48456 .39296 L 0 .179 .245 r
F
.48176 .38717 m .48016 .38418 L .48297 .38922 L F
.29631 .34746 m .2973 .34468 L .2991 .34645 L 0 .03 .13 r
F
.29631 .34746 m .29451 .3457 L .2973 .34468 L F
.43543 .35975 m .43662 .35717 L .43827 .3593 L 0 .061 .163 r
F
.43543 .35975 m .43378 .35758 L .43662 .35717 L F
.38801 .35239 m .38913 .34958 L .39084 .35147 L 0 .041 .143 r
F
.38801 .35239 m .3863 .35052 L .38913 .34958 L F
.45176 .36385 m .45297 .36166 L .45461 .36355 L 0 .074 .175 r
F
.45176 .36385 m .45011 .36197 L .45297 .36166 L F
.74693 .34748 m .74861 .34484 L .74996 .34654 L 0 .03 .131 r
F
.74693 .34748 m .74558 .34577 L .74861 .34484 L F
.66576 .35201 m .6673 .34907 L .66873 .35072 L 0 .04 .142 r
F
.66576 .35201 m .66433 .35033 L .6673 .34907 L F
.36877 .35098 m .36986 .34828 L .37159 .35005 L 0 .038 .14 r
F
.36877 .35098 m .36704 .34921 L .36986 .34828 L F
.2017 .34533 m .20253 .34259 L .20443 .34436 L 0 .026 .125 r
F
.2017 .34533 m .1998 .34357 L .20253 .34259 L F
.30368 .34721 m .30466 .34459 L .30646 .34636 L 0 .03 .13 r
F
.30368 .34721 m .30188 .34545 L .30466 .34459 L F
.2623 .34701 m .26323 .34429 L .26507 .34605 L 0 .029 .129 r
F
.2623 .34701 m .26047 .34525 L .26323 .34429 L F
.16769 .34478 m .16848 .34204 L .1704 .34388 L 0 .025 .124 r
F
.16769 .34478 m .16577 .34295 L .16848 .34204 L F
.23568 .34602 m .23656 .3434 L .23842 .34517 L 0 .028 .127 r
F
.23568 .34602 m .23382 .34427 L .23656 .3434 L F
.76171 .34685 m .7634 .34403 L .76473 .34576 L 0 .029 .129 r
F
.76171 .34685 m .76037 .34513 L .7634 .34403 L F
.75433 .34728 m .75601 .34454 L .75735 .34623 L 0 .03 .13 r
F
.75433 .34728 m .75299 .3456 L .75601 .34454 L F
.83998 .34504 m .8418 .34228 L .84306 .3441 L 0 .025 .124 r
F
.83998 .34504 m .83872 .34321 L .8418 .34228 L F
.46966 .37312 m .4709 .37104 L .4725 .37393 L 0 .106 .2 r
F
.46966 .37312 m .46804 .37059 L .4709 .37104 L F
.65101 .35308 m .65254 .35037 L .65399 .35212 L 0 .043 .146 r
F
.65101 .35308 m .64956 .35132 L .65254 .35037 L F
.88875 .3449 m .89063 .34212 L .89185 .34393 L 0 .025 .124 r
F
.88875 .3449 m .88753 .34307 L .89063 .34212 L F
.26967 .34675 m .27062 .34394 L .27244 .3457 L 0 .029 .129 r
F
.26967 .34675 m .26784 .345 L .27062 .34394 L F
.33028 .34839 m .33131 .34584 L .33307 .34761 L 0 .033 .134 r
F
.33028 .34839 m .32852 .34661 L .33131 .34584 L F
.40723 .3542 m .40837 .35159 L .41006 .35346 L 0 .046 .149 r
F
.40723 .3542 m .40554 .3523 L .40837 .35159 L F
.43094 .35789 m .43212 .3554 L .43378 .35758 L 0 .056 .159 r
F
.43094 .35789 m .42928 .3557 L .43212 .3554 L F
.59802 .36363 m .59946 .36061 L .60095 .36197 L 0 .072 .173 r
F
.59802 .36363 m .59653 .36231 L .59946 .36061 L F
.64364 .3536 m .64515 .35084 L .6466 .35241 L 0 .045 .147 r
F
.64364 .3536 m .64219 .35209 L .64515 .35084 L F
.76911 .34673 m .77081 .34398 L .77215 .34582 L 0 .029 .129 r
F
.76911 .34673 m .76777 .34487 L .77081 .34398 L F
.20904 .3453 m .20989 .34252 L .21177 .34441 L 0 .026 .125 r
F
.20904 .3453 m .20716 .34344 L .20989 .34252 L F
.84739 .3449 m .8492 .34199 L .85046 .34383 L 0 .025 .124 r
F
.84739 .3449 m .84613 .34304 L .8492 .34199 L F
.6584 .35289 m .65993 .34993 L .66137 .35164 L 0 .043 .145 r
F
.6584 .35289 m .65696 .35116 L .65993 .34993 L F
.58484 .36948 m .58626 .36647 L .58776 .36765 L 0 .091 .188 r
F
.58484 .36948 m .58334 .36841 L .58626 .36647 L F
.37613 .35107 m .37722 .34857 L .37894 .35037 L 0 .039 .141 r
F
.37613 .35107 m .3744 .34929 L .37722 .34857 L F
.27703 .34659 m .27799 .34377 L .2798 .34566 L 0 .029 .129 r
F
.27703 .34659 m .27522 .34474 L .27799 .34377 L F
.60831 .36074 m .60976 .3577 L .61125 .35931 L 0 .063 .165 r
F
.60831 .36074 m .60682 .35908 L .60976 .3577 L F
.39536 .35258 m .3965 .34984 L .39819 .35183 L 0 .043 .145 r
F
.39536 .35258 m .39367 .35063 L .3965 .34984 L F
.6186 .35771 m .62007 .35471 L .62154 .35624 L 0 .055 .158 r
F
.6186 .35771 m .61712 .35616 L .62007 .35471 L F
.35688 .34975 m .35795 .34716 L .35968 .34907 L 0 .036 .138 r
F
.35688 .34975 m .35515 .34786 L .35795 .34716 L F
.31102 .3473 m .31203 .34456 L .31381 .34637 L 0 .031 .131 r
F
.31102 .3473 m .30924 .3455 L .31203 .34456 L F
.17502 .34485 m .17584 .34194 L .17774 .34383 L 0 .025 .124 r
F
.17502 .34485 m .17311 .34296 L .17584 .34194 L F
.85479 .34466 m .85663 .34192 L .85787 .34373 L F
.85479 .34466 m .85354 .34283 L .85663 .34192 L F
.44727 .36228 m .44847 .36008 L .45011 .36197 L 0 .07 .171 r
F
.44727 .36228 m .44562 .36041 L .44847 .36008 L F
.57032 .38298 m .56884 .38451 L .57172 .38026 L 0 .145 .226 r
F
.56745 .3884 m .56884 .38451 L .57032 .38298 L 0 .173 .242 r
F
.78389 .34616 m .78561 .34337 L .78693 .34512 L 0 .028 .128 r
F
.78389 .34616 m .78257 .3444 L .78561 .34337 L F
.24301 .34618 m .24393 .3433 L .24577 .34518 L F
.24301 .34618 m .24117 .34431 L .24393 .3433 L F
.42645 .35601 m .42762 .35369 L .42928 .3557 L 0 .052 .155 r
F
.42645 .35601 m .42479 .35404 L .42762 .35369 L F
.33764 .34846 m .33867 .34584 L .34044 .34755 L 0 .033 .134 r
F
.33764 .34846 m .33587 .34673 L .33867 .34584 L F
.77652 .34665 m .77822 .34372 L .77954 .34553 L 0 .029 .129 r
F
.77652 .34665 m .77519 .34483 L .77822 .34372 L F
.79128 .34586 m .79302 .3431 L .79432 .34484 L 0 .028 .127 r
F
.79128 .34586 m .78997 .34412 L .79302 .3431 L F
.69823 .34852 m .69983 .34579 L .70123 .34757 L 0 .033 .134 r
F
.69823 .34852 m .69682 .34671 L .69983 .34579 L F
.71299 .34772 m .71461 .34493 L .71599 .34659 L 0 .032 .132 r
F
.71299 .34772 m .71161 .34606 L .71461 .34493 L F
.72037 .34732 m .72201 .34471 L .72339 .34639 L 0 .031 .132 r
F
.72037 .34732 m .719 .34565 L .72201 .34471 L F
.69085 .34896 m .69242 .346 L .69383 .34779 L 0 .034 .135 r
F
.69085 .34896 m .68944 .34718 L .69242 .346 L F
.63627 .35453 m .63778 .35189 L .63923 .35334 L 0 .048 .15 r
F
.63627 .35453 m .63482 .35307 L .63778 .35189 L F
.18237 .3447 m .18319 .34185 L .18509 .34375 L 0 .025 .124 r
F
.18237 .3447 m .18047 .34281 L .18319 .34185 L F
.79867 .34552 m .80041 .34272 L .80171 .34446 L 0 .027 .126 r
F
.79867 .34552 m .79737 .34378 L .80041 .34272 L F
.8622 .34454 m .86405 .34179 L .86528 .34354 L 0 .025 .124 r
F
.8622 .34454 m .86096 .34279 L .86405 .34179 L F
.31838 .34722 m .31941 .34433 L .32118 .34622 L 0 .031 .131 r
F
.31838 .34722 m .31661 .34535 L .31941 .34433 L F
.68347 .34948 m .68504 .34668 L .68645 .34835 L 0 .036 .137 r
F
.68347 .34948 m .68206 .34782 L .68504 .34668 L F
.21637 .34541 m .21723 .34262 L .2191 .34451 L 0 .027 .126 r
F
.21637 .34541 m .2145 .34351 L .21723 .34262 L F
.28438 .34665 m .28535 .34377 L .28715 .34571 L 0 .029 .129 r
F
.28438 .34665 m .28257 .34472 L .28535 .34377 L F
.25037 .34605 m .2513 .34314 L .25313 .34507 L 0 .028 .128 r
F
.25037 .34605 m .24853 .34415 L .2513 .34314 L F
.41458 .35447 m .41575 .35176 L .41743 .35358 L 0 .048 .15 r
F
.41458 .35447 m .4129 .35266 L .41575 .35176 L F
.48937 .40034 m .49054 .40755 L .49216 .40933 L 0 .27 .291 r
F
.48937 .40034 m .48776 .39855 L .49054 .40755 L F
.80606 .34527 m .80781 .34239 L .80911 .34423 L 0 .027 .126 r
F
.80606 .34527 m .80476 .34342 L .80781 .34239 L F
.70562 .34834 m .70723 .34552 L .70862 .34723 L 0 .033 .134 r
F
.70562 .34834 m .70423 .34661 L .70723 .34552 L F
.8696 .34426 m .87146 .34151 L .87268 .34325 L 0 .025 .124 r
F
.8696 .34426 m .86837 .34252 L .87146 .34151 L F
.345 .3484 m .34605 .34579 L .3478 .34755 L 0 .034 .135 r
F
.345 .3484 m .34324 .34666 L .34605 .34579 L F
.72777 .34718 m .72941 .34444 L .73078 .34618 L 0 .031 .131 r
F
.72777 .34718 m .7264 .34543 L .72941 .34444 L F
.6761 .35009 m .67766 .34731 L .67908 .34896 L 0 .037 .139 r
F
.6761 .35009 m .67468 .34845 L .67766 .34731 L F
.14833 .34439 m .1491 .34154 L .15104 .34344 L 0 .025 .124 r
F
.14833 .34439 m .1464 .34248 L .1491 .34154 L F
.81346 .34504 m .81523 .34222 L .81652 .34405 L 0 .027 .126 r
F
.81346 .34504 m .81217 .34319 L .81523 .34222 L F
.18972 .34464 m .19053 .34197 L .19244 .34375 L 0 .026 .125 r
F
.18972 .34464 m .18781 .34286 L .19053 .34197 L F
.877 .34408 m .87888 .34133 L .8801 .34312 L 0 .025 .123 r
F
.877 .34408 m .87578 .34229 L .87888 .34133 L F
.38347 .35146 m .38459 .34865 L .3863 .35052 L 0 .041 .143 r
F
.38347 .35146 m .38176 .34962 L .38459 .34865 L F
.58776 .36765 m .58918 .36459 L .59068 .36582 L 0 .086 .185 r
F
.58776 .36765 m .58626 .36647 L .58918 .36459 L F
.73517 .34698 m .73682 .34421 L .73818 .34599 L 0 .031 .131 r
F
.73517 .34698 m .7338 .34518 L .73682 .34421 L F
.62891 .35542 m .6304 .35276 L .63186 .35425 L 0 .051 .154 r
F
.62891 .35542 m .62745 .35392 L .6304 .35276 L F
.60095 .36197 m .6024 .35907 L .60389 .36047 L 0 .069 .17 r
F
.60095 .36197 m .59946 .36061 L .6024 .35907 L F
.66873 .35072 m .67028 .34794 L .6717 .34959 L 0 .039 .141 r
F
.66873 .35072 m .6673 .34907 L .67028 .34794 L F
.22371 .34541 m .22459 .34262 L .22646 .34443 L 0 .028 .127 r
F
.22371 .34541 m .22184 .34361 L .22459 .34262 L F
.36422 .35013 m .36531 .34736 L .36704 .34921 L 0 .038 .139 r
F
.36422 .35013 m .36249 .34829 L .36531 .34736 L F
.40271 .35301 m .40385 .3504 L .40554 .3523 L 0 .045 .147 r
F
.40271 .35301 m .40102 .35108 L .40385 .3504 L F
.15569 .34422 m .15647 .34138 L .15841 .34316 L 0 .025 .124 r
F
.15569 .34422 m .15375 .34245 L .15647 .34138 L F
.29172 .34669 m .29271 .34377 L .29451 .3457 L 0 .03 .13 r
F
.29172 .34669 m .28993 .34477 L .29271 .34377 L F
.44277 .36083 m .44397 .35845 L .44562 .36041 L 0 .067 .168 r
F
.44277 .36083 m .44112 .35885 L .44397 .35845 L F
.82086 .34485 m .82264 .34204 L .82392 .34382 L 0 .026 .126 r
F
.82086 .34485 m .81958 .34306 L .82264 .34204 L F
.25771 .34609 m .25864 .34336 L .26047 .34525 L 0 .029 .129 r
F
.25771 .34609 m .25588 .34421 L .25864 .34336 L F
.82825 .34447 m .83004 .34162 L .83131 .34337 L 0 .026 .125 r
F
.82825 .34447 m .82698 .34272 L .83004 .34162 L F
.32573 .34734 m .32676 .34466 L .32852 .34661 L 0 .032 .132 r
F
.32573 .34734 m .32397 .34542 L .32676 .34466 L F
.74256 .34676 m .74423 .34402 L .74558 .34577 L 0 .031 .131 r
F
.74256 .34676 m .7412 .345 L .74423 .34402 L F
.16306 .3439 m .16384 .34116 L .16577 .34295 L 0 .025 .123 r
F
.16306 .3439 m .16113 .3421 L .16384 .34116 L F
.42195 .35455 m .42311 .35214 L .42479 .35404 L 0 .05 .152 r
F
.42195 .35455 m .42027 .3527 L .42311 .35214 L F
.19707 .34454 m .1979 .34182 L .1998 .34357 L 0 .026 .125 r
F
.19707 .34454 m .19517 .34279 L .1979 .34182 L F
.83564 .34414 m .83746 .34146 L .83872 .34321 L 0 .025 .124 r
F
.83564 .34414 m .83438 .34239 L .83746 .34146 L F
.23108 .3452 m .23195 .34251 L .23382 .34427 L 0 .028 .127 r
F
.23108 .3452 m .22921 .34345 L .23195 .34251 L F
.2991 .34645 m .30008 .34368 L .30188 .34545 L 0 .03 .13 r
F
.2991 .34645 m .2973 .34468 L .30008 .34368 L F
.88443 .34403 m .88631 .34124 L .88753 .34307 L 0 .025 .124 r
F
.88443 .34403 m .8832 .34218 L .88631 .34124 L F
.47411 .37682 m .47536 .37475 L .47696 .37799 L 0 .124 .212 r
F
.47411 .37682 m .4725 .37393 L .47536 .37475 L F
.56029 .39955 m .55884 .4063 L .56171 .39974 L 0 .241 .277 r
F
.55741 .40459 m .55884 .4063 L .56029 .39955 L 0 .284 .297 r
F
.35235 .34857 m .35341 .34597 L .35515 .34786 L 0 .035 .136 r
F
.35235 .34857 m .35061 .34671 L .35341 .34597 L F
.74996 .34654 m .75164 .34391 L .75299 .3456 L 0 .031 .131 r
F
.74996 .34654 m .74861 .34484 L .75164 .34391 L F
.39084 .35147 m .39197 .34868 L .39367 .35063 L 0 .041 .143 r
F
.39084 .35147 m .38913 .34958 L .39197 .34868 L F
.37159 .35005 m .37268 .3475 L .3744 .34929 L 0 .038 .14 r
F
.37159 .35005 m .36986 .34828 L .37268 .3475 L F
.76473 .34576 m .76644 .34312 L .76777 .34487 L 0 .029 .129 r
F
.76473 .34576 m .7634 .34403 L .76644 .34312 L F
.62154 .35624 m .62302 .35355 L .62449 .35508 L 0 .054 .156 r
F
.62154 .35624 m .62007 .35471 L .62302 .35355 L F
.20443 .34436 m .20527 .34164 L .20716 .34344 L 0 .026 .125 r
F
.20443 .34436 m .20253 .34259 L .20527 .34164 L F
.61125 .35931 m .6127 .35616 L .61419 .35774 L 0 .061 .163 r
F
.61125 .35931 m .60976 .3577 L .6127 .35616 L F
.75735 .34623 m .75903 .34342 L .76037 .34513 L 0 .03 .13 r
F
.75735 .34623 m .75601 .34454 L .75903 .34342 L F
.26507 .34605 m .26601 .34324 L .26784 .345 L 0 .029 .129 r
F
.26507 .34605 m .26323 .34429 L .26601 .34324 L F
.6466 .35241 m .64812 .3497 L .64956 .35132 L 0 .044 .146 r
F
.6466 .35241 m .64515 .35084 L .64812 .3497 L F
.48016 .38418 m .48137 .38535 L .48297 .38922 L 0 .167 .239 r
F
.48016 .38418 m .47856 .38111 L .48137 .38535 L F
.66137 .35164 m .6629 .34864 L .66433 .35033 L 0 .042 .144 r
F
.66137 .35164 m .65993 .34993 L .6629 .34864 L F
.27244 .3457 m .27339 .34295 L .27522 .34474 L 0 .029 .129 r
F
.27244 .3457 m .27062 .34394 L .27339 .34295 L F
.1704 .34388 m .17119 .34112 L .17311 .34296 L 0 .025 .124 r
F
.1704 .34388 m .16848 .34204 L .17119 .34112 L F
.84306 .3441 m .84487 .34123 L .84613 .34304 L F
.84306 .3441 m .8418 .34228 L .84487 .34123 L F
.30646 .34636 m .30745 .34374 L .30924 .3455 L 0 .03 .131 r
F
.30646 .34636 m .30466 .34459 L .30745 .34374 L F
.65399 .35212 m .65552 .34942 L .65696 .35116 L 0 .043 .146 r
F
.65399 .35212 m .65254 .35037 L .65552 .34942 L F
.23842 .34517 m .23931 .34253 L .24117 .34431 L 0 .028 .128 r
F
.23842 .34517 m .23656 .3434 L .23931 .34253 L F
.85046 .34383 m .85228 .341 L .85354 .34283 L 0 .025 .124 r
F
.85046 .34383 m .8492 .34199 L .85228 .341 L F
.59068 .36582 m .59211 .36273 L .5936 .364 L 0 .082 .181 r
F
.59068 .36582 m .58918 .36459 L .59211 .36273 L F
.33307 .34761 m .33411 .34497 L .33587 .34673 L 0 .033 .134 r
F
.33307 .34761 m .33131 .34584 L .33411 .34497 L F
.43827 .3593 m .43947 .35676 L .44112 .35885 L 0 .063 .165 r
F
.43827 .3593 m .43662 .35717 L .43947 .35676 L F
.77215 .34582 m .77386 .34301 L .77519 .34483 L 0 .029 .129 r
F
.77215 .34582 m .77081 .34398 L .77386 .34301 L F
.21177 .34441 m .21263 .34161 L .2145 .34351 L 0 .027 .126 r
F
.21177 .34441 m .20989 .34252 L .21263 .34161 L F
.2798 .34566 m .28077 .34281 L .28257 .34472 L 0 .029 .129 r
F
.2798 .34566 m .27799 .34377 L .28077 .34281 L F
.45909 .36574 m .46032 .36319 L .46195 .36562 L 0 .083 .182 r
F
.45909 .36574 m .45746 .36336 L .46032 .36319 L F
.41006 .35346 m .41122 .35083 L .4129 .35266 L 0 .047 .15 r
F
.41006 .35346 m .40837 .35159 L .41122 .35083 L F
.17774 .34383 m .17857 .34091 L .18047 .34281 L 0 .025 .124 r
F
.17774 .34383 m .17584 .34194 L .17857 .34091 L F
.45461 .36355 m .45582 .36146 L .45746 .36336 L 0 .077 .178 r
F
.45461 .36355 m .45297 .36166 L .45582 .36146 L F
.77954 .34553 m .78125 .34261 L .78257 .3444 L 0 .029 .128 r
F
.77954 .34553 m .77822 .34372 L .78125 .34261 L F
.78693 .34512 m .78866 .34236 L .78997 .34412 L 0 .028 .128 r
F
.78693 .34512 m .78561 .34337 L .78866 .34236 L F
.46357 .36807 m .46481 .36551 L .46643 .36805 L 0 .091 .189 r
F
.46357 .36807 m .46195 .36562 L .46481 .36551 L F
.69383 .34779 m .69542 .34492 L .69682 .34671 L 0 .034 .135 r
F
.69383 .34779 m .69242 .346 L .69542 .34492 L F
.31381 .34637 m .31483 .34353 L .31661 .34535 L 0 .031 .131 r
F
.31381 .34637 m .31203 .34456 L .31483 .34353 L F
.63923 .35334 m .64074 .35058 L .64219 .35209 L 0 .047 .149 r
F
.63923 .35334 m .63778 .35189 L .64074 .35058 L F
.71599 .34659 m .71762 .34397 L .719 .34565 L 0 .031 .132 r
F
.71599 .34659 m .71461 .34493 L .71762 .34397 L F
.85787 .34373 m .85972 .341 L .86096 .34279 L 0 .025 .124 r
F
.85787 .34373 m .85663 .34192 L .85972 .341 L F
.24577 .34518 m .24669 .34224 L .24853 .34415 L 0 .028 .128 r
F
.24577 .34518 m .24393 .3433 L .24669 .34224 L F
.37894 .35037 m .38004 .34781 L .38176 .34962 L 0 .04 .142 r
F
.37894 .35037 m .37722 .34857 L .38004 .34781 L F
.79432 .34484 m .79606 .34203 L .79737 .34378 L 0 .028 .127 r
F
.79432 .34484 m .79302 .3431 L .79606 .34203 L F
.1437 .34342 m .14447 .34056 L .1464 .34248 L 0 .025 .123 r
F
.1437 .34342 m .14177 .3415 L .14447 .34056 L F
.39819 .35183 m .39933 .34906 L .40102 .35108 L 0 .043 .146 r
F
.39819 .35183 m .3965 .34984 L .39933 .34906 L F
.68645 .34835 m .68803 .34548 L .68944 .34718 L 0 .035 .136 r
F
.68645 .34835 m .68504 .34668 L .68803 .34548 L F
.80171 .34446 m .80346 .34165 L .80476 .34342 L 0 .027 .126 r
F
.80171 .34446 m .80041 .34272 L .80346 .34165 L F
.34044 .34755 m .34148 .34495 L .34324 .34666 L 0 .034 .135 r
F
.34044 .34755 m .33867 .34584 L .34148 .34495 L F
.60389 .36047 m .60534 .35765 L .60682 .35908 L 0 .067 .168 r
F
.60389 .36047 m .6024 .35907 L .60534 .35765 L F
.70123 .34757 m .70283 .34487 L .70423 .34661 L 0 .034 .135 r
F
.70123 .34757 m .69983 .34579 L .70283 .34487 L F
.53415 .42439 m .53555 .43873 L .53707 .42544 L 0 .37 .27 r
F
.53415 .42439 m .53262 .43702 L .53555 .43873 L F
.72339 .34639 m .72503 .34374 L .7264 .34543 L 0 .031 .132 r
F
.72339 .34639 m .72201 .34471 L .72503 .34374 L F
.86528 .34354 m .86714 .34077 L .86837 .34252 L 0 .025 .124 r
F
.86528 .34354 m .86405 .34179 L .86714 .34077 L F
.70862 .34723 m .71022 .34438 L .71161 .34606 L 0 .033 .134 r
F
.70862 .34723 m .70723 .34552 L .71022 .34438 L F
.35968 .34907 m .36076 .34634 L .36249 .34829 L 0 .037 .139 r
F
.35968 .34907 m .35795 .34716 L .36076 .34634 L F
.18509 .34375 m .18591 .34095 L .18781 .34286 L 0 .026 .125 r
F
.18509 .34375 m .18319 .34185 L .18591 .34095 L F
.46804 .37059 m .46928 .3682 L .4709 .37104 L 0 .101 .196 r
F
.46804 .37059 m .46643 .36805 L .46928 .3682 L F
.32118 .34622 m .3222 .3435 L .32397 .34542 L 0 .031 .131 r
F
.32118 .34622 m .31941 .34433 L .3222 .3435 L F
.80911 .34423 m .81087 .34135 L .81217 .34319 L 0 .027 .126 r
F
.80911 .34423 m .80781 .34239 L .81087 .34135 L F
.67908 .34896 m .68064 .34616 L .68206 .34782 L 0 .037 .138 r
F
.67908 .34896 m .67766 .34731 L .68064 .34616 L F
.25313 .34507 m .25405 .34226 L .25588 .34421 L 0 .028 .128 r
F
.25313 .34507 m .2513 .34314 L .25405 .34226 L F
.43378 .35758 m .43497 .35503 L .43662 .35717 L 0 .059 .161 r
F
.43378 .35758 m .43212 .3554 L .43497 .35503 L F
.87268 .34325 m .87455 .34054 L .87578 .34229 L 0 .025 .124 r
F
.87268 .34325 m .87146 .34151 L .87455 .34054 L F
.28715 .34571 m .28813 .34282 L .28993 .34477 L 0 .03 .13 r
F
.28715 .34571 m .28535 .34377 L .28813 .34282 L F
.2191 .34451 m .21997 .34172 L .22184 .34361 L 0 .027 .127 r
F
.2191 .34451 m .21723 .34262 L .21997 .34172 L F
.73078 .34618 m .73243 .34344 L .7338 .34518 L 0 .031 .131 r
F
.73078 .34618 m .72941 .34444 L .73243 .34344 L F
.41743 .35358 m .4186 .35085 L .42027 .3527 L 0 .048 .151 r
F
.41743 .35358 m .41575 .35176 L .4186 .35085 L F
.63186 .35425 m .63336 .3516 L .63482 .35307 L 0 .05 .153 r
F
.63186 .35425 m .6304 .35276 L .63336 .3516 L F
.61419 .35774 m .61564 .3546 L .61712 .35616 L 0 .059 .161 r
F
.61419 .35774 m .6127 .35616 L .61564 .3546 L F
.81652 .34405 m .8183 .34125 L .81958 .34306 L 0 .027 .126 r
F
.81652 .34405 m .81523 .34222 L .8183 .34125 L F
.6717 .34959 m .67326 .3468 L .67468 .34845 L 0 .039 .14 r
F
.6717 .34959 m .67028 .34794 L .67326 .3468 L F
.15104 .34344 m .15182 .34055 L .15375 .34245 L 0 .025 .124 r
F
.15104 .34344 m .1491 .34154 L .15182 .34055 L F
.3478 .34755 m .34886 .34492 L .35061 .34671 L 0 .034 .135 r
F
.3478 .34755 m .34605 .34579 L .34886 .34492 L F
.51938 .42561 m .52068 .44115 L .52228 .4318 L 0 .375 .265 r
F
.51938 .42561 m .51778 .43326 L .52068 .44115 L F
.5936 .364 m .59504 .36099 L .59653 .36231 L 0 .078 .178 r
F
.5936 .364 m .59211 .36273 L .59504 .36099 L F
.73818 .34599 m .73984 .34323 L .7412 .345 L 0 .031 .131 r
F
.73818 .34599 m .73682 .34421 L .73984 .34323 L F
.8801 .34312 m .88198 .34038 L .8832 .34218 L 0 .025 .124 r
F
.8801 .34312 m .87888 .34133 L .88198 .34038 L F
.45011 .36197 m .45132 .35976 L .45297 .36166 L 0 .073 .174 r
F
.45011 .36197 m .44847 .36008 L .45132 .35976 L F
.19244 .34375 m .19326 .34101 L .19517 .34279 L 0 .026 .125 r
F
.19244 .34375 m .19053 .34197 L .19326 .34101 L F
.3863 .35052 m .38743 .34768 L .38913 .34958 L 0 .041 .143 r
F
.3863 .35052 m .38459 .34865 L .38743 .34768 L F
.83131 .34337 m .83311 .34064 L .83438 .34239 L 0 .026 .124 r
F
.83131 .34337 m .83004 .34162 L .83311 .34064 L F
.15841 .34316 m .15919 .34031 L .16113 .3421 L 0 .025 .124 r
F
.15841 .34316 m .15647 .34138 L .15919 .34031 L F
.22646 .34443 m .22734 .34163 L .22921 .34345 L 0 .028 .127 r
F
.22646 .34443 m .22459 .34262 L .22734 .34163 L F
.82392 .34382 m .8257 .34095 L .82698 .34272 L 0 .026 .125 r
F
.82392 .34382 m .82264 .34204 L .8257 .34095 L F
.42928 .3557 m .43046 .35334 L .43212 .3554 L 0 .055 .158 r
F
.42928 .3557 m .42762 .35369 L .43046 .35334 L F
.29451 .3457 m .2955 .34274 L .2973 .34468 L 0 .03 .13 r
F
.29451 .3457 m .29271 .34377 L .2955 .34274 L F
.36704 .34921 m .36814 .34642 L .36986 .34828 L 0 .038 .14 r
F
.36704 .34921 m .36531 .34736 L .36814 .34642 L F
.74558 .34577 m .74726 .34311 L .74861 .34484 L 0 .031 .131 r
F
.74558 .34577 m .74423 .34402 L .74726 .34311 L F
.5775 .37264 m .57891 .36975 L .58042 .37052 L 0 .109 .201 r
F
.5775 .37264 m .576 .37217 L .57891 .36975 L F
.57461 .37601 m .576 .37217 L .5775 .37264 L 0 .121 .21 r
F
.1998 .34357 m .20063 .34085 L .20253 .34259 L 0 .026 .125 r
F
.1998 .34357 m .1979 .34182 L .20063 .34085 L F
.16577 .34295 m .16655 .34024 L .16848 .34204 L 0 .025 .124 r
F
.16577 .34295 m .16384 .34116 L .16655 .34024 L F
.66433 .35033 m .66587 .3474 L .6673 .34907 L 0 .04 .142 r
F
.66433 .35033 m .6629 .34864 L .66587 .3474 L F
.30188 .34545 m .30287 .34283 L .30466 .34459 L 0 .03 .13 r
F
.30188 .34545 m .30008 .34368 L .30287 .34283 L F
.62449 .35508 m .62598 .35239 L .62745 .35392 L 0 .053 .156 r
F
.62449 .35508 m .62302 .35355 L .62598 .35239 L F
.26047 .34525 m .26141 .34239 L .26323 .34429 L 0 .029 .129 r
F
.26047 .34525 m .25864 .34336 L .26141 .34239 L F
.83872 .34321 m .84054 .34052 L .8418 .34228 L 0 .026 .124 r
F
.83872 .34321 m .83746 .34146 L .84054 .34052 L F
.23382 .34427 m .2347 .34163 L .23656 .3434 L 0 .028 .127 r
F
.23382 .34427 m .23195 .34251 L .2347 .34163 L F
.88753 .34307 m .88941 .3403 L .89063 .34212 L 0 .025 .124 r
F
.88753 .34307 m .88631 .34124 L .88941 .3403 L F
.76037 .34513 m .76206 .34231 L .7634 .34403 L 0 .029 .129 r
F
.76037 .34513 m .75903 .34342 L .76206 .34231 L F
.40554 .3523 m .40669 .34973 L .40837 .35159 L 0 .046 .149 r
F
.40554 .3523 m .40385 .3504 L .40669 .34973 L F
.56458 .39387 m .56598 .39114 L .56702 .38923 L 0 .212 .263 r
F
.56458 .39387 m .56311 .39785 L .56598 .39114 L F
.56598 .39114 m .5645 .39427 L .56493 .39306 L 0 .204 .259 r
F
.56598 .39114 m .56493 .39306 L .56735 .38631 L F
.56702 .38923 m .56598 .39114 L .56745 .3884 L 0 .212 .263 r
F
.32852 .34661 m .32955 .34386 L .33131 .34584 L 0 .033 .133 r
F
.32852 .34661 m .32676 .34466 L .32955 .34386 L F
.4954 .40992 m .49659 .4182 L .49822 .41801 L 0 .322 .302 r
F
.4954 .40992 m .49378 .40963 L .49659 .4182 L F
.64956 .35132 m .65109 .34869 L .65254 .35037 L 0 .044 .146 r
F
.64956 .35132 m .64812 .3497 L .65109 .34869 L F
.75299 .3456 m .75467 .34285 L .75601 .34454 L 0 .03 .131 r
F
.75299 .3456 m .75164 .34391 L .75467 .34285 L F
.26784 .345 m .26879 .34218 L .27062 .34394 L 0 .029 .129 r
F
.26784 .345 m .26601 .34324 L .26879 .34218 L F
.20716 .34344 m .20801 .34069 L .20989 .34252 L 0 .026 .125 r
F
.20716 .34344 m .20527 .34164 L .20801 .34069 L F
.76777 .34487 m .76948 .3422 L .77081 .34398 L 0 .029 .129 r
F
.76777 .34487 m .76644 .34312 L .76948 .3422 L F
.84613 .34304 m .84794 .34017 L .8492 .34199 L 0 .025 .124 r
F
.84613 .34304 m .84487 .34123 L .84794 .34017 L F
.39367 .35063 m .3948 .34782 L .3965 .34984 L 0 .042 .144 r
F
.39367 .35063 m .39197 .34868 L .3948 .34782 L F
.27522 .34474 m .27617 .34195 L .27799 .34377 L 0 .029 .129 r
F
.27522 .34474 m .27339 .34295 L .27617 .34195 L F
.3744 .34929 m .3755 .34677 L .37722 .34857 L 0 .039 .141 r
F
.3744 .34929 m .37268 .3475 L .3755 .34677 L F
.35515 .34786 m .35622 .34523 L .35795 .34716 L 0 .036 .137 r
F
.35515 .34786 m .35341 .34597 L .35622 .34523 L F
.65696 .35116 m .65849 .3482 L .65993 .34993 L 0 .043 .145 r
F
.65696 .35116 m .65552 .34942 L .65849 .3482 L F
.17311 .34296 m .17392 .34008 L .17584 .34194 L 0 .025 .124 r
F
.17311 .34296 m .17119 .34112 L .17392 .34008 L F
.42479 .35404 m .42595 .35172 L .42762 .35369 L 0 .052 .154 r
F
.42479 .35404 m .42311 .35214 L .42595 .35172 L F
.44562 .36041 m .44682 .35811 L .44847 .36008 L 0 .07 .171 r
F
.44562 .36041 m .44397 .35845 L .44682 .35811 L F
.4725 .37393 m .47375 .37149 L .47536 .37475 L 0 .116 .207 r
F
.4725 .37393 m .4709 .37104 L .47375 .37149 L F
.47856 .38111 m .47978 .38146 L .48137 .38535 L 0 .155 .232 r
F
.47856 .38111 m .47696 .37799 L .47978 .38146 L F
.85354 .34283 m .85538 .3401 L .85663 .34192 L 0 .025 .124 r
F
.85354 .34283 m .85228 .341 L .85538 .3401 L F
.30924 .3455 m .31024 .3428 L .31203 .34456 L 0 .031 .131 r
F
.30924 .3455 m .30745 .34374 L .31024 .3428 L F
.58042 .37052 m .58183 .36734 L .58334 .36841 L 0 .101 .196 r
F
.58042 .37052 m .57891 .36975 L .58183 .36734 L F
.64219 .35209 m .6437 .34926 L .64515 .35084 L 0 .046 .148 r
F
.64219 .35209 m .64074 .35058 L .6437 .34926 L F
.24117 .34431 m .24207 .3415 L .24393 .3433 L 0 .028 .128 r
F
.24117 .34431 m .23931 .34253 L .24207 .3415 L F
.60682 .35908 m .60828 .35623 L .60976 .3577 L 0 .065 .167 r
F
.60682 .35908 m .60534 .35765 L .60828 .35623 L F
.78257 .3444 m .7843 .34159 L .78561 .34337 L 0 .028 .128 r
F
.78257 .3444 m .78125 .34261 L .7843 .34159 L F
.77519 .34483 m .77689 .34192 L .77822 .34372 L 0 .029 .129 r
F
.77519 .34483 m .77386 .34301 L .77689 .34192 L F
.18047 .34281 m .18129 .33995 L .18319 .34185 L 0 .025 .124 r
F
.18047 .34281 m .17857 .34091 L .18129 .33995 L F
.57461 .37601 m .57311 .37616 L .576 .37217 L 0 .121 .21 r
F
.57172 .38026 m .57311 .37616 L .57461 .37601 L 0 .141 .223 r
F
.69682 .34671 m .69842 .34401 L .69983 .34579 L 0 .034 .135 r
F
.69682 .34671 m .69542 .34492 L .69842 .34401 L F
.33587 .34673 m .33691 .34411 L .33867 .34584 L F
.33587 .34673 m .33411 .34497 L .33691 .34411 L F
.61712 .35616 m .61859 .35318 L .62007 .35471 L 0 .056 .159 r
F
.61712 .35616 m .61564 .3546 L .61859 .35318 L F
.59653 .36231 m .59797 .35926 L .59946 .36061 L 0 .074 .175 r
F
.59653 .36231 m .59504 .36099 L .59797 .35926 L F
.68944 .34718 m .69101 .34427 L .69242 .346 L 0 .034 .135 r
F
.68944 .34718 m .68803 .34548 L .69101 .34427 L F
.28257 .34472 m .28355 .34185 L .28535 .34377 L 0 .029 .129 r
F
.28257 .34472 m .28077 .34281 L .28355 .34185 L F
.78997 .34412 m .79171 .34135 L .79302 .3431 L 0 .028 .128 r
F
.78997 .34412 m .78866 .34236 L .79171 .34135 L F
.31661 .34535 m .31763 .3425 L .31941 .34433 L 0 .031 .131 r
F
.31661 .34535 m .31483 .34353 L .31763 .3425 L F
.2145 .34351 m .21536 .34072 L .21723 .34262 L 0 .027 .126 r
F
.2145 .34351 m .21263 .34161 L .21536 .34072 L F
.55741 .40459 m .55596 .41287 L .55884 .4063 L 0 .284 .297 r
F
.55452 .40969 m .55596 .41287 L .55741 .40459 L 0 .317 .304 r
F
.24853 .34415 m .24946 .34122 L .2513 .34314 L 0 .028 .128 r
F
.24853 .34415 m .24669 .34224 L .24946 .34122 L F
.79737 .34378 m .79911 .34097 L .80041 .34272 L 0 .027 .127 r
F
.79737 .34378 m .79606 .34203 L .79911 .34097 L F
.719 .34565 m .72064 .34302 L .72201 .34471 L 0 .032 .132 r
F
.719 .34565 m .71762 .34397 L .72064 .34302 L F
.71161 .34606 m .71323 .34327 L .71461 .34493 L 0 .032 .133 r
F
.71161 .34606 m .71022 .34438 L .71323 .34327 L F
.86096 .34279 m .86281 .34001 L .86405 .34179 L 0 .026 .124 r
F
.86096 .34279 m .85972 .341 L .86281 .34001 L F
.80476 .34342 m .80652 .3406 L .80781 .34239 L 0 .027 .126 r
F
.80476 .34342 m .80346 .34165 L .80652 .3406 L F
.48776 .39855 m .48894 .40428 L .49054 .40755 L 0 .265 .289 r
F
.48776 .39855 m .48616 .39576 L .48894 .40428 L F
.4129 .35266 m .41406 .34993 L .41575 .35176 L 0 .048 .15 r
F
.4129 .35266 m .41122 .35083 L .41406 .34993 L F
.1464 .34248 m .14717 .33962 L .1491 .34154 L 0 .025 .124 r
F
.1464 .34248 m .14447 .34056 L .14717 .33962 L F
.68206 .34782 m .68363 .34501 L .68504 .34668 L 0 .036 .138 r
F
.68206 .34782 m .68064 .34616 L .68363 .34501 L F
.70423 .34661 m .70583 .34381 L .70723 .34552 L 0 .034 .135 r
F
.70423 .34661 m .70283 .34487 L .70583 .34381 L F
.86837 .34252 m .87023 .33977 L .87146 .34151 L 0 .025 .124 r
F
.86837 .34252 m .86714 .34077 L .87023 .33977 L F
.50593 .42023 m .50714 .43487 L .50878 .42949 L 0 .362 .277 r
F
.50593 .42023 m .5043 .42408 L .50714 .43487 L F
.7264 .34543 m .72805 .34273 L .72941 .34444 L 0 .031 .132 r
F
.7264 .34543 m .72503 .34374 L .72805 .34273 L F
.34324 .34666 m .34429 .34405 L .34605 .34579 L 0 .034 .135 r
F
.34324 .34666 m .34148 .34495 L .34429 .34405 L F
.81217 .34319 m .81394 .34039 L .81523 .34222 L 0 .027 .126 r
F
.81217 .34319 m .81087 .34135 L .81394 .34039 L F
.58334 .36841 m .58475 .36529 L .58626 .36647 L 0 .095 .191 r
F
.58334 .36841 m .58183 .36734 L .58475 .36529 L F
.63482 .35307 m .63633 .35042 L .63778 .35189 L 0 .049 .152 r
F
.63482 .35307 m .63336 .3516 L .63633 .35042 L F
.38176 .34962 m .38288 .34684 L .38459 .34865 L 0 .041 .143 r
F
.38176 .34962 m .38004 .34781 L .38288 .34684 L F
.44112 .35885 m .44232 .35637 L .44397 .35845 L 0 .066 .168 r
F
.44112 .35885 m .43947 .35676 L .44232 .35637 L F
.18781 .34286 m .18864 .34005 L .19053 .34197 L 0 .026 .125 r
F
.18781 .34286 m .18591 .34095 L .18864 .34005 L F
.40102 .35108 m .40216 .34838 L .40385 .3504 L 0 .044 .147 r
F
.40102 .35108 m .39933 .34906 L .40216 .34838 L F
.87578 .34229 m .87765 .33957 L .87888 .34133 L 0 .025 .124 r
F
.87578 .34229 m .87455 .34054 L .87765 .33957 L F
.67468 .34845 m .67624 .34566 L .67766 .34731 L 0 .038 .14 r
F
.67468 .34845 m .67326 .3468 L .67624 .34566 L F
.28993 .34477 m .29092 .3418 L .29271 .34377 L 0 .03 .13 r
F
.28993 .34477 m .28813 .34282 L .29092 .3418 L F
.7338 .34518 m .73545 .34244 L .73682 .34421 L 0 .031 .131 r
F
.7338 .34518 m .73243 .34344 L .73545 .34244 L F
.32397 .34542 m .32499 .3427 L .32676 .34466 L 0 .032 .132 r
F
.32397 .34542 m .3222 .3435 L .32499 .3427 L F
.36249 .34829 m .36359 .34537 L .36531 .34736 L 0 .038 .139 r
F
.36249 .34829 m .36076 .34634 L .36359 .34537 L F
.25588 .34421 m .25681 .34138 L .25864 .34336 L 0 .029 .129 r
F
.25588 .34421 m .25405 .34226 L .25681 .34138 L F
.22184 .34361 m .22272 .34071 L .22459 .34262 L 0 .027 .127 r
F
.22184 .34361 m .21997 .34172 L .22272 .34071 L F
.81958 .34306 m .82136 .34025 L .82264 .34204 L 0 .027 .126 r
F
.81958 .34306 m .8183 .34125 L .82136 .34025 L F
.15375 .34245 m .15454 .33948 L .15647 .34138 L 0 .025 .124 r
F
.15375 .34245 m .15182 .34055 L .15454 .33948 L F
.42027 .3527 m .42144 .35024 L .42311 .35214 L 0 .049 .152 r
F
.42027 .3527 m .4186 .35085 L .42144 .35024 L F
.6673 .34907 m .66885 .34627 L .67028 .34794 L 0 .04 .142 r
F
.6673 .34907 m .66587 .3474 L .66885 .34627 L F
.16113 .3421 m .16191 .33935 L .16384 .34116 L 0 .025 .123 r
F
.16113 .3421 m .15919 .34031 L .16191 .33935 L F
.82698 .34272 m .82876 .33986 L .83004 .34162 L 0 .026 .125 r
F
.82698 .34272 m .8257 .34095 L .82876 .33986 L F
.7412 .345 m .74287 .34227 L .74423 .34402 L 0 .031 .131 r
F
.7412 .345 m .73984 .34323 L .74287 .34227 L F
.8832 .34218 m .88509 .33944 L .88631 .34124 L 0 .025 .124 r
F
.8832 .34218 m .88198 .34038 L .88509 .33944 L F
.19517 .34279 m .19599 .34005 L .1979 .34182 L 0 .026 .125 r
F
.19517 .34279 m .19326 .34101 L .19599 .34005 L F
.83438 .34239 m .83619 .3397 L .83746 .34146 L 0 .026 .124 r
F
.83438 .34239 m .83311 .34064 L .83619 .3397 L F
.38913 .34958 m .39026 .34673 L .39197 .34868 L 0 .041 .143 r
F
.38913 .34958 m .38743 .34768 L .39026 .34673 L F
.35061 .34671 m .35166 .34416 L .35341 .34597 L 0 .035 .136 r
F
.35061 .34671 m .34886 .34492 L .35166 .34416 L F
.22921 .34345 m .23009 .34068 L .23195 .34251 L 0 .028 .127 r
F
.22921 .34345 m .22734 .34163 L .23009 .34068 L F
.2973 .34468 m .2983 .34172 L .30008 .34368 L 0 .03 .13 r
F
.2973 .34468 m .2955 .34274 L .2983 .34172 L F
.62745 .35392 m .62894 .35125 L .6304 .35276 L 0 .052 .155 r
F
.62745 .35392 m .62598 .35239 L .62894 .35125 L F
.45746 .36336 m .45868 .36128 L .46032 .36319 L 0 .081 .181 r
F
.45746 .36336 m .45582 .36146 L .45868 .36128 L F
.46195 .36562 m .46318 .36297 L .46481 .36551 L 0 .088 .186 r
F
.46195 .36562 m .46032 .36319 L .46318 .36297 L F
.36986 .34828 m .37096 .34563 L .37268 .3475 L 0 .038 .14 r
F
.36986 .34828 m .36814 .34642 L .37096 .34563 L F
.59946 .36061 m .60091 .35767 L .6024 .35907 L 0 .071 .172 r
F
.59946 .36061 m .59797 .35926 L .60091 .35767 L F
.74861 .34484 m .7503 .3422 L .75164 .34391 L 0 .031 .131 r
F
.74861 .34484 m .74726 .34311 L .7503 .3422 L F
.20253 .34259 m .20337 .33987 L .20527 .34164 L 0 .026 .125 r
F
.20253 .34259 m .20063 .34085 L .20337 .33987 L F
.7634 .34403 m .7651 .34137 L .76644 .34312 L 0 .029 .129 r
F
.7634 .34403 m .76206 .34231 L .7651 .34137 L F
.51489 .42541 m .51616 .44226 L .51778 .43326 L 0 .38 .261 r
F
.51489 .42541 m .51327 .4325 L .51616 .44226 L F
.43662 .35717 m .43781 .35466 L .43947 .35676 L 0 .062 .164 r
F
.43662 .35717 m .43497 .35503 L .43781 .35466 L F
.46643 .36805 m .46767 .36538 L .46928 .3682 L 0 .096 .192 r
F
.46643 .36805 m .46481 .36551 L .46767 .36538 L F
.26323 .34429 m .26418 .34134 L .26601 .34324 L 0 .029 .129 r
F
.26323 .34429 m .26141 .34239 L .26418 .34134 L F
.16848 .34204 m .16927 .33931 L .17119 .34112 L 0 .025 .124 r
F
.16848 .34204 m .16655 .34024 L .16927 .33931 L F
.8418 .34228 m .84361 .33946 L .84487 .34123 L 0 .026 .124 r
F
.8418 .34228 m .84054 .34052 L .84361 .33946 L F
.58626 .36647 m .58768 .36334 L .58918 .36459 L 0 .09 .187 r
F
.58626 .36647 m .58475 .36529 L .58768 .36334 L F
.75601 .34454 m .75769 .34171 L .75903 .34342 L 0 .03 .13 r
F
.75601 .34454 m .75467 .34285 L .75769 .34171 L F
.27062 .34394 m .27157 .34116 L .27339 .34295 L 0 .029 .129 r
F
.27062 .34394 m .26879 .34218 L .27157 .34116 L F
.60976 .3577 m .61122 .35463 L .6127 .35616 L 0 .062 .164 r
F
.60976 .3577 m .60828 .35623 L .61122 .35463 L F
.30466 .34459 m .30565 .34197 L .30745 .34374 L 0 .031 .131 r
F
.30466 .34459 m .30287 .34283 L .30565 .34197 L F
.65993 .34993 m .66146 .34693 L .6629 .34864 L 0 .042 .144 r
F
.65993 .34993 m .65849 .3482 L .66146 .34693 L F
.65254 .35037 m .65407 .34769 L .65552 .34942 L 0 .044 .146 r
F
.65254 .35037 m .65109 .34869 L .65407 .34769 L F
.23656 .3434 m .23745 .34075 L .23931 .34253 L 0 .028 .128 r
F
.23656 .3434 m .2347 .34163 L .23745 .34075 L F
.8492 .34199 m .85103 .33919 L .85228 .341 L 0 .025 .124 r
F
.8492 .34199 m .84794 .34017 L .85103 .33919 L F
.62007 .35471 m .62155 .35202 L .62302 .35355 L 0 .055 .157 r
F
.62007 .35471 m .61859 .35318 L .62155 .35202 L F
.64515 .35084 m .64667 .34807 L .64812 .3497 L 0 .045 .147 r
F
.64515 .35084 m .6437 .34926 L .64667 .34807 L F
.20989 .34252 m .21074 .33977 L .21263 .34161 L 0 .026 .126 r
F
.20989 .34252 m .20801 .34069 L .21074 .33977 L F
.27799 .34377 m .27895 .34097 L .28077 .34281 L 0 .029 .129 r
F
.27799 .34377 m .27617 .34195 L .27895 .34097 L F
.77081 .34398 m .77252 .34121 L .77386 .34301 L F
.77081 .34398 m .76948 .3422 L .77252 .34121 L F
.17584 .34194 m .17665 .33905 L .17857 .34091 L 0 .025 .124 r
F
.17584 .34194 m .17392 .34008 L .17665 .33905 L F
.33131 .34584 m .33235 .343 L .33411 .34497 L 0 .033 .134 r
F
.33131 .34584 m .32955 .34386 L .33235 .343 L F
.40837 .35159 m .40953 .34899 L .41122 .35083 L 0 .047 .15 r
F
.40837 .35159 m .40669 .34973 L .40953 .34899 L F
.45297 .36166 m .45418 .35955 L .45582 .36146 L 0 .077 .177 r
F
.45297 .36166 m .45132 .35976 L .45418 .35955 L F
.3965 .34984 m .39764 .34697 L .39933 .34906 L 0 .043 .145 r
F
.3965 .34984 m .3948 .34782 L .39764 .34697 L F
.24393 .3433 m .24484 .34043 L .24669 .34224 L 0 .028 .128 r
F
.24393 .3433 m .24207 .3415 L .24484 .34043 L F
.43212 .3554 m .43331 .35294 L .43497 .35503 L 0 .058 .16 r
F
.43212 .3554 m .43046 .35334 L .43331 .35294 L F
.77822 .34372 m .77993 .34083 L .78125 .34261 L 0 .029 .129 r
F
.77822 .34372 m .77689 .34192 L .77993 .34083 L F
.31203 .34456 m .31304 .34177 L .31483 .34353 L 0 .031 .131 r
F
.31203 .34456 m .31024 .3428 L .31304 .34177 L F
.69242 .346 m .69401 .34316 L .69542 .34492 L 0 .034 .135 r
F
.69242 .346 m .69101 .34427 L .69401 .34316 L F
.14177 .3415 m .14253 .33865 L .14447 .34056 L 0 .025 .123 r
F
.14177 .3415 m .13982 .33959 L .14253 .33865 L F
.47696 .37799 m .47819 .3775 L .47978 .38146 L 0 .143 .224 r
F
.47696 .37799 m .47536 .37475 L .47819 .3775 L F
.85663 .34192 m .85847 .3392 L .85972 .341 L 0 .026 .124 r
F
.85663 .34192 m .85538 .3401 L .85847 .3392 L F
.57172 .38026 m .57023 .38123 L .57311 .37616 L 0 .141 .223 r
F
.56884 .38451 m .57023 .38123 L .57172 .38026 L 0 .166 .238 r
F
.78561 .34337 m .78735 .34059 L .78866 .34236 L 0 .028 .128 r
F
.78561 .34337 m .7843 .34159 L .78735 .34059 L F
.37722 .34857 m .37832 .346 L .38004 .34781 L 0 .04 .142 r
F
.37722 .34857 m .3755 .34677 L .37832 .346 L F
.35795 .34716 m .35903 .34439 L .36076 .34634 L 0 .037 .138 r
F
.35795 .34716 m .35622 .34523 L .35903 .34439 L F
.18319 .34185 m .18401 .33904 L .18591 .34095 L 0 .025 .124 r
F
.18319 .34185 m .18129 .33995 L .18401 .33904 L F
.71461 .34493 m .71624 .34231 L .71762 .34397 L 0 .032 .133 r
F
.71461 .34493 m .71323 .34327 L .71624 .34231 L F
.79302 .3431 m .79476 .34028 L .79606 .34203 L 0 .028 .127 r
F
.79302 .3431 m .79171 .34135 L .79476 .34028 L F
.31941 .34433 m .32043 .34164 L .3222 .3435 L 0 .031 .131 r
F
.31941 .34433 m .31763 .3425 L .32043 .34164 L F
.52677 .428 m .52812 .44417 L .52968 .43268 L 0 .387 .254 r
F
.52677 .428 m .52519 .43798 L .52812 .44417 L F
.80041 .34272 m .80216 .33989 L .80346 .34165 L 0 .027 .127 r
F
.80041 .34272 m .79911 .34097 L .80216 .33989 L F
.69983 .34579 m .70143 .3431 L .70283 .34487 L 0 .034 .135 r
F
.69983 .34579 m .69842 .34401 L .70143 .3431 L F
.2513 .34314 m .25222 .3403 L .25405 .34226 L 0 .028 .128 r
F
.2513 .34314 m .24946 .34122 L .25222 .3403 L F
.4709 .37104 m .47215 .36835 L .47375 .37149 L 0 .109 .201 r
F
.4709 .37104 m .46928 .3682 L .47215 .36835 L F
.28535 .34377 m .28633 .34089 L .28813 .34282 L 0 .029 .129 r
F
.28535 .34377 m .28355 .34185 L .28633 .34089 L F
.33867 .34584 m .33972 .34321 L .34148 .34495 L 0 .034 .135 r
F
.33867 .34584 m .33691 .34411 L .33972 .34321 L F
.68504 .34668 m .68662 .34377 L .68803 .34548 L 0 .036 .137 r
F
.68504 .34668 m .68363 .34501 L .68662 .34377 L F
.80781 .34239 m .80957 .33953 L .81087 .34135 L 0 .027 .126 r
F
.80781 .34239 m .80652 .3406 L .80957 .33953 L F
.86405 .34179 m .8659 .33901 L .86714 .34077 L 0 .026 .124 r
F
.86405 .34179 m .86281 .34001 L .8659 .33901 L F
.21723 .34262 m .2181 .33981 L .21997 .34172 L 0 .027 .126 r
F
.21723 .34262 m .21536 .34072 L .2181 .33981 L F
.58918 .36459 m .59061 .36143 L .59211 .36273 L 0 .085 .183 r
F
.58918 .36459 m .58768 .36334 L .59061 .36143 L F
.70723 .34552 m .70884 .3427 L .71022 .34438 L 0 .033 .134 r
F
.70723 .34552 m .70583 .34381 L .70884 .3427 L F
.5104 .42406 m .51164 .43963 L .51327 .4325 L 0 .376 .265 r
F
.5104 .42406 m .50878 .42949 L .51164 .43963 L F
.72201 .34471 m .72365 .34204 L .72503 .34374 L 0 .032 .132 r
F
.72201 .34471 m .72064 .34302 L .72365 .34204 L F
.63778 .35189 m .63929 .34906 L .64074 .35058 L 0 .048 .151 r
F
.63778 .35189 m .63633 .35042 L .63929 .34906 L F
.41575 .35176 m .41691 .34903 L .4186 .35085 L F
.41575 .35176 m .41406 .34993 L .41691 .34903 L F
.87146 .34151 m .87333 .33879 L .87455 .34054 L 0 .025 .124 r
F
.87146 .34151 m .87023 .33977 L .87333 .33879 L F
.1491 .34154 m .14988 .33863 L .15182 .34055 L F
.1491 .34154 m .14717 .33962 L .14988 .33863 L F
.72941 .34444 m .73107 .34173 L .73243 .34344 L 0 .031 .132 r
F
.72941 .34444 m .72805 .34273 L .73107 .34173 L F
.67766 .34731 m .67923 .34452 L .68064 .34616 L 0 .037 .139 r
F
.67766 .34731 m .67624 .34566 L .67923 .34452 L F
.42762 .35369 m .4288 .35131 L .43046 .35334 L 0 .054 .157 r
F
.42762 .35369 m .42595 .35172 L .4288 .35131 L F
.81523 .34222 m .81701 .33944 L .8183 .34125 L 0 .027 .126 r
F
.81523 .34222 m .81394 .34039 L .81701 .33944 L F
.44847 .36008 m .44968 .35778 L .45132 .35976 L 0 .073 .174 r
F
.44847 .36008 m .44682 .35811 L .44968 .35778 L F
.6024 .35907 m .60385 .35622 L .60534 .35765 L 0 .068 .17 r
F
.6024 .35907 m .60091 .35767 L .60385 .35622 L F
.38459 .34865 m .38571 .34587 L .38743 .34768 L 0 .041 .143 r
F
.38459 .34865 m .38288 .34684 L .38571 .34587 L F
.34605 .34579 m .3471 .34316 L .34886 .34492 L 0 .035 .136 r
F
.34605 .34579 m .34429 .34405 L .3471 .34316 L F
.29271 .34377 m .29371 .34075 L .2955 .34274 L 0 .03 .13 r
F
.29271 .34377 m .29092 .3418 L .29371 .34075 L F
.87888 .34133 m .88076 .33861 L .88198 .34038 L 0 .025 .124 r
F
.87888 .34133 m .87765 .33957 L .88076 .33861 L F
.73682 .34421 m .73848 .34144 L .73984 .34323 L 0 .031 .131 r
F
.73682 .34421 m .73545 .34244 L .73848 .34144 L F
.19053 .34197 m .19137 .3391 L .19326 .34101 L 0 .026 .125 r
F
.19053 .34197 m .18864 .34005 L .19137 .3391 L F
.53707 .42544 m .5385 .44045 L .53999 .4265 L 0 .38 .261 r
F
.53707 .42544 m .53555 .43873 L .5385 .44045 L F
.67028 .34794 m .67183 .34515 L .67326 .3468 L 0 .039 .141 r
F
.67028 .34794 m .66885 .34627 L .67183 .34515 L F
.56171 .39974 m .56311 .39785 L .56458 .39387 L 0 .257 .285 r
F
.15647 .34138 m .15726 .33842 L .15919 .34031 L 0 .025 .124 r
F
.15647 .34138 m .15454 .33948 L .15726 .33842 L F
.6127 .35616 m .61416 .35301 L .61564 .3546 L 0 .06 .162 r
F
.6127 .35616 m .61122 .35463 L .61416 .35301 L F
.22459 .34262 m .22548 .3397 L .22734 .34163 L 0 .027 .127 r
F
.22459 .34262 m .22272 .34071 L .22548 .3397 L F
.48616 .39576 m .48734 .401 L .48894 .40428 L 0 .254 .283 r
F
.48616 .39576 m .48456 .39296 L .48734 .401 L F
.36531 .34736 m .36641 .34439 L .36814 .34642 L 0 .038 .139 r
F
.36531 .34736 m .36359 .34537 L .36641 .34439 L F
.83004 .34162 m .83184 .33888 L .83311 .34064 L 0 .026 .125 r
F
.83004 .34162 m .82876 .33986 L .83184 .33888 L F
.82264 .34204 m .82442 .33917 L .8257 .34095 L F
.82264 .34204 m .82136 .34025 L .82442 .33917 L F
.6304 .35276 m .6319 .35011 L .63336 .3516 L 0 .052 .154 r
F
.6304 .35276 m .62894 .35125 L .6319 .35011 L F
.25864 .34336 m .25958 .3404 L .26141 .34239 L 0 .029 .129 r
F
.25864 .34336 m .25681 .34138 L .25958 .3404 L F
.74423 .34402 m .74591 .34138 L .74726 .34311 L 0 .031 .131 r
F
.74423 .34402 m .74287 .34227 L .74591 .34138 L F
.16384 .34116 m .16462 .33844 L .16655 .34024 L 0 .025 .124 r
F
.16384 .34116 m .16191 .33935 L .16462 .33844 L F
.32676 .34466 m .32779 .34188 L .32955 .34386 L 0 .032 .133 r
F
.32676 .34466 m .32499 .3427 L .32779 .34188 L F
.40385 .3504 m .405 .34772 L .40669 .34973 L 0 .046 .148 r
F
.40385 .3504 m .40216 .34838 L .405 .34772 L F
.55452 .40969 m .55308 .41946 L .55596 .41287 L 0 .317 .304 r
F
.55164 .41482 m .55308 .41946 L .55452 .40969 L 0 .337 .294 r
F
.1979 .34182 m .19873 .33907 L .20063 .34085 L 0 .026 .125 r
F
.1979 .34182 m .19599 .34005 L .19873 .33907 L F
.30008 .34368 m .30108 .34087 L .30287 .34283 L 0 .03 .13 r
F
.30008 .34368 m .2983 .34172 L .30108 .34087 L F
.88631 .34124 m .8882 .3385 L .88941 .3403 L 0 .025 .124 r
F
.88631 .34124 m .88509 .33944 L .8882 .3385 L F
.83746 .34146 m .83927 .33876 L .84054 .34052 L 0 .026 .125 r
F
.83746 .34146 m .83619 .3397 L .83927 .33876 L F
.6629 .34864 m .66443 .34569 L .66587 .3474 L 0 .041 .143 r
F
.6629 .34864 m .66146 .34693 L .66443 .34569 L F
.23195 .34251 m .23284 .3398 L .2347 .34163 L 0 .028 .127 r
F
.23195 .34251 m .23009 .34068 L .23284 .3398 L F
.39197 .34868 m .3931 .3458 L .3948 .34782 L 0 .041 .143 r
F
.39197 .34868 m .39026 .34673 L .3931 .3458 L F
.75903 .34342 m .76072 .34059 L .76206 .34231 L 0 .03 .13 r
F
.75903 .34342 m .75769 .34171 L .76072 .34059 L F
.26601 .34324 m .26696 .34029 L .26879 .34218 L 0 .029 .129 r
F
.26601 .34324 m .26418 .34134 L .26696 .34029 L F
.59211 .36273 m .59354 .35966 L .59504 .36099 L 0 .08 .18 r
F
.59211 .36273 m .59061 .36143 L .59354 .35966 L F
.44397 .35845 m .44517 .35602 L .44682 .35811 L 0 .069 .17 r
F
.44397 .35845 m .44232 .35637 L .44517 .35602 L F
.84487 .34123 m .84669 .3384 L .84794 .34017 L 0 .025 .124 r
F
.84487 .34123 m .84361 .33946 L .84669 .3384 L F
.20527 .34164 m .20612 .33889 L .20801 .34069 L 0 .026 .125 r
F
.20527 .34164 m .20337 .33987 L .20612 .33889 L F
.75164 .34391 m .75333 .34114 L .75467 .34285 L 0 .031 .131 r
F
.75164 .34391 m .7503 .3422 L .75333 .34114 L F
.62302 .35355 m .62451 .35087 L .62598 .35239 L 0 .054 .157 r
F
.62302 .35355 m .62155 .35202 L .62451 .35087 L F
.35341 .34597 m .35447 .3434 L .35622 .34523 L 0 .036 .137 r
F
.35341 .34597 m .35166 .34416 L .35447 .3434 L F
.42311 .35214 m .42428 .34977 L .42595 .35172 L 0 .051 .154 r
F
.42311 .35214 m .42144 .35024 L .42428 .34977 L F
.76644 .34312 m .76815 .34042 L .76948 .3422 L 0 .029 .129 r
F
.76644 .34312 m .7651 .34137 L .76815 .34042 L F
.64812 .3497 m .64964 .34701 L .65109 .34869 L 0 .044 .147 r
F
.64812 .3497 m .64667 .34807 L .64964 .34701 L F
.27339 .34295 m .27435 .34013 L .27617 .34195 L 0 .029 .129 r
F
.27339 .34295 m .27157 .34116 L .27435 .34013 L F
.17119 .34112 m .172 .33827 L .17392 .34008 L 0 .025 .124 r
F
.17119 .34112 m .16927 .33931 L .172 .33827 L F
.37268 .3475 m .37378 .34487 L .3755 .34677 L 0 .039 .141 r
F
.37268 .3475 m .37096 .34563 L .37378 .34487 L F
.85228 .341 m .85412 .33829 L .85538 .3401 L 0 .025 .124 r
F
.85228 .341 m .85103 .33919 L .85412 .33829 L F
.65552 .34942 m .65704 .34643 L .65849 .3482 L 0 .043 .146 r
F
.65552 .34942 m .65407 .34769 L .65704 .34643 L F
.30745 .34374 m .30845 .34103 L .31024 .3428 L 0 .031 .131 r
F
.30745 .34374 m .30565 .34197 L .30845 .34103 L F
.23931 .34253 m .24021 .3397 L .24207 .3415 L 0 .028 .128 r
F
.23931 .34253 m .23745 .34075 L .24021 .3397 L F
.17857 .34091 m .17938 .33807 L .18129 .33995 L 0 .025 .124 r
F
.17857 .34091 m .17665 .33905 L .17938 .33807 L F
.77386 .34301 m .77556 .3401 L .77689 .34192 L 0 .029 .129 r
F
.77386 .34301 m .77252 .34121 L .77556 .3401 L F
.28077 .34281 m .28173 .34001 L .28355 .34185 L F
.28077 .34281 m .27895 .34097 L .28173 .34001 L F
.78125 .34261 m .78298 .33981 L .7843 .34159 L 0 .029 .128 r
F
.78125 .34261 m .77993 .34083 L .78298 .33981 L F
.21263 .34161 m .21348 .33887 L .21536 .34072 L 0 .027 .126 r
F
.21263 .34161 m .21074 .33977 L .21348 .33887 L F
.49985 .41588 m .50101 .43146 L .50266 .42794 L 0 .356 .281 r
F
.49985 .41588 m .49822 .41801 L .50101 .43146 L F
.24669 .34224 m .24761 .33938 L .24946 .34122 L 0 .028 .127 r
F
.24669 .34224 m .24484 .34043 L .24761 .33938 L F
.56884 .38451 m .56735 .38631 L .57023 .38123 L 0 .166 .238 r
F
.56598 .39114 m .56735 .38631 L .56884 .38451 L 0 .204 .259 r
F
.69542 .34492 m .69702 .34222 L .69842 .34401 L 0 .034 .135 r
F
.69542 .34492 m .69401 .34316 L .69702 .34222 L F
.31483 .34353 m .31585 .34074 L .31763 .3425 L 0 .031 .131 r
F
.31483 .34353 m .31304 .34177 L .31585 .34074 L F
.33411 .34497 m .33516 .34214 L .33691 .34411 L 0 .034 .135 r
F
.33411 .34497 m .33235 .343 L .33516 .34214 L F
.47536 .37475 m .47659 .37354 L .47819 .3775 L 0 .131 .217 r
F
.47536 .37475 m .47375 .37149 L .47659 .37354 L F
.78866 .34236 m .7904 .33958 L .79171 .34135 L 0 .028 .128 r
F
.78866 .34236 m .78735 .34059 L .7904 .33958 L F
.64074 .35058 m .64225 .34771 L .6437 .34926 L 0 .047 .149 r
F
.64074 .35058 m .63929 .34906 L .64225 .34771 L F
.43947 .35676 m .44066 .35429 L .44232 .35637 L 0 .065 .166 r
F
.43947 .35676 m .43781 .35466 L .44066 .35429 L F
.68803 .34548 m .6896 .34253 L .69101 .34427 L 0 .035 .136 r
F
.68803 .34548 m .68662 .34377 L .6896 .34253 L F
.14447 .34056 m .14523 .33771 L .14717 .33962 L 0 .025 .123 r
F
.14447 .34056 m .14253 .33865 L .14523 .33771 L F
.41122 .35083 m .41238 .3481 L .41406 .34993 L 0 .048 .15 r
F
.41122 .35083 m .40953 .34899 L .41238 .3481 L F
.85972 .341 m .86157 .33823 L .86281 .34001 L 0 .026 .125 r
F
.85972 .341 m .85847 .3392 L .86157 .33823 L F
.79606 .34203 m .79781 .33922 L .79911 .34097 L 0 .028 .127 r
F
.79606 .34203 m .79476 .34028 L .79781 .33922 L F
.46032 .36319 m .46155 .36103 L .46318 .36297 L 0 .085 .184 r
F
.46032 .36319 m .45868 .36128 L .46155 .36103 L F
.60534 .35765 m .60679 .35476 L .60828 .35623 L 0 .066 .168 r
F
.60534 .35765 m .60385 .35622 L .60679 .35476 L F
.80346 .34165 m .80522 .3388 L .80652 .3406 L 0 .027 .126 r
F
.80346 .34165 m .80216 .33989 L .80522 .3388 L F
.39933 .34906 m .40047 .34627 L .40216 .34838 L 0 .043 .146 r
F
.39933 .34906 m .39764 .34697 L .40047 .34627 L F
.61564 .3546 m .61711 .35152 L .61859 .35318 L 0 .057 .16 r
F
.61564 .3546 m .61416 .35301 L .61711 .35152 L F
.46481 .36551 m .46605 .36258 L .46767 .36538 L 0 .092 .189 r
F
.46481 .36551 m .46318 .36297 L .46605 .36258 L F
.71022 .34438 m .71184 .34161 L .71323 .34327 L 0 .033 .134 r
F
.71022 .34438 m .70884 .3427 L .71184 .34161 L F
.71762 .34397 m .71926 .34135 L .72064 .34302 L 0 .032 .133 r
F
.71762 .34397 m .71624 .34231 L .71926 .34135 L F
.81087 .34135 m .81264 .33857 L .81394 .34039 L 0 .027 .126 r
F
.81087 .34135 m .80957 .33953 L .81264 .33857 L F
.18591 .34095 m .18674 .33813 L .18864 .34005 L 0 .026 .125 r
F
.18591 .34095 m .18401 .33904 L .18674 .33813 L F
.70283 .34487 m .70444 .34204 L .70583 .34381 L 0 .034 .135 r
F
.70283 .34487 m .70143 .3431 L .70444 .34204 L F
.28813 .34282 m .28912 .33986 L .29092 .3418 L 0 .029 .129 r
F
.28813 .34282 m .28633 .34089 L .28912 .33986 L F
.86714 .34077 m .869 .33801 L .87023 .33977 L 0 .025 .124 r
F
.86714 .34077 m .8659 .33901 L .869 .33801 L F
.36076 .34634 m .36186 .34337 L .36359 .34537 L 0 .037 .139 r
F
.36076 .34634 m .35903 .34439 L .36186 .34337 L F
.25405 .34226 m .25498 .33939 L .25681 .34138 L 0 .028 .128 r
F
.25405 .34226 m .25222 .3403 L .25498 .33939 L F
.68064 .34616 m .68222 .34337 L .68363 .34501 L 0 .037 .138 r
F
.68064 .34616 m .67923 .34452 L .68222 .34337 L F
.38004 .34781 m .38116 .34504 L .38288 .34684 L 0 .041 .143 r
F
.38004 .34781 m .37832 .346 L .38116 .34504 L F
.3222 .3435 m .32322 .3408 L .32499 .3427 L 0 .031 .132 r
F
.3222 .3435 m .32043 .34164 L .32322 .3408 L F
.34148 .34495 m .34253 .34229 L .34429 .34405 L 0 .034 .136 r
F
.34148 .34495 m .33972 .34321 L .34253 .34229 L F
.72503 .34374 m .72667 .34103 L .72805 .34273 L 0 .032 .132 r
F
.72503 .34374 m .72365 .34204 L .72667 .34103 L F
.59504 .36099 m .59647 .35789 L .59797 .35926 L 0 .076 .177 r
F
.59504 .36099 m .59354 .35966 L .59647 .35789 L F
.21997 .34172 m .22086 .33879 L .22272 .34071 L 0 .027 .127 r
F
.21997 .34172 m .2181 .33981 L .22086 .33879 L F
.87455 .34054 m .87643 .33781 L .87765 .33957 L 0 .025 .124 r
F
.87455 .34054 m .87333 .33879 L .87643 .33781 L F
.15182 .34055 m .15261 .33757 L .15454 .33948 L F
.15182 .34055 m .14988 .33863 L .15261 .33757 L F
.73243 .34344 m .73409 .34069 L .73545 .34244 L 0 .031 .132 r
F
.73243 .34344 m .73107 .34173 L .73409 .34069 L F
.576 .37217 m .57741 .36905 L .57891 .36975 L 0 .116 .207 r
F
.576 .37217 m .5745 .37184 L .57741 .36905 L F
.57311 .37616 m .5745 .37184 L .576 .37217 L 0 .132 .217 r
F
.4186 .35085 m .41976 .34841 L .42144 .35024 L 0 .049 .152 r
F
.4186 .35085 m .41691 .34903 L .41976 .34841 L F
.8183 .34125 m .82008 .33845 L .82136 .34025 L 0 .027 .126 r
F
.8183 .34125 m .81701 .33944 L .82008 .33845 L F
.67326 .3468 m .67482 .34402 L .67624 .34566 L 0 .039 .14 r
F
.67326 .3468 m .67183 .34515 L .67482 .34402 L F
.43497 .35503 m .43616 .35253 L .43781 .35466 L 0 .06 .163 r
F
.43497 .35503 m .43331 .35294 L .43616 .35253 L F
.2955 .34274 m .29651 .33973 L .2983 .34172 L 0 .029 .129 r
F
.2955 .34274 m .29371 .34075 L .29651 .33973 L F
.38743 .34768 m .38855 .3449 L .39026 .34673 L 0 .041 .143 r
F
.38743 .34768 m .38571 .34587 L .38855 .3449 L F
.46928 .3682 m .47054 .36526 L .47215 .36835 L 0 .102 .197 r
F
.46928 .3682 m .46767 .36538 L .47054 .36526 L F
.15919 .34031 m .15998 .33746 L .16191 .33935 L 0 .025 .123 r
F
.15919 .34031 m .15726 .33842 L .15998 .33746 L F
.63336 .3516 m .63487 .34895 L .63633 .35042 L 0 .051 .153 r
F
.63336 .3516 m .6319 .35011 L .63487 .34895 L F
.45582 .36146 m .45704 .35937 L .45868 .36128 L 0 .081 .18 r
F
.45582 .36146 m .45418 .35955 L .45704 .35937 L F
.8257 .34095 m .82749 .3381 L .82876 .33986 L 0 .026 .125 r
F
.8257 .34095 m .82442 .33917 L .82749 .3381 L F
.73984 .34323 m .74151 .34047 L .74287 .34227 L 0 .031 .131 r
F
.73984 .34323 m .73848 .34144 L .74151 .34047 L F
.88198 .34038 m .88387 .33767 L .88509 .33944 L 0 .025 .124 r
F
.88198 .34038 m .88076 .33861 L .88387 .33767 L F
.19326 .34101 m .1941 .33814 L .19599 .34005 L 0 .026 .125 r
F
.19326 .34101 m .19137 .3391 L .1941 .33814 L F
.22734 .34163 m .22823 .33874 L .23009 .34068 L 0 .028 .127 r
F
.22734 .34163 m .22548 .3397 L .22823 .33874 L F
.34886 .34492 m .34991 .34238 L .35166 .34416 L 0 .035 .136 r
F
.34886 .34492 m .3471 .34316 L .34991 .34238 L F
.57891 .36975 m .58032 .36627 L .58183 .36734 L 0 .106 .2 r
F
.57891 .36975 m .57741 .36905 L .58032 .36627 L F
.66587 .3474 m .66742 .34456 L .66885 .34627 L 0 .04 .142 r
F
.66587 .3474 m .66443 .34569 L .66742 .34456 L F
.83311 .34064 m .83493 .33795 L .83619 .3397 L 0 .026 .125 r
F
.83311 .34064 m .83184 .33888 L .83493 .33795 L F
.36814 .34642 m .36924 .34356 L .37096 .34563 L 0 .038 .14 r
F
.36814 .34642 m .36641 .34439 L .36924 .34356 L F
.49378 .40963 m .49496 .41839 L .49659 .4182 L 0 .329 .299 r
F
.49378 .40963 m .49216 .40933 L .49496 .41839 L F
.26141 .34239 m .26236 .33936 L .26418 .34134 L 0 .029 .129 r
F
.26141 .34239 m .25958 .3404 L .26236 .33936 L F
.20063 .34085 m .20148 .33807 L .20337 .33987 L 0 .026 .126 r
F
.20063 .34085 m .19873 .33907 L .20148 .33807 L F
.74726 .34311 m .74895 .34048 L .7503 .3422 L 0 .031 .132 r
F
.74726 .34311 m .74591 .34138 L .74895 .34048 L F
.16655 .34024 m .16734 .3375 L .16927 .33931 L 0 .025 .124 r
F
.16655 .34024 m .16462 .33844 L .16734 .3375 L F
.58183 .36734 m .58324 .36409 L .58475 .36529 L 0 .099 .194 r
F
.58183 .36734 m .58032 .36627 L .58324 .36409 L F
.76206 .34231 m .76376 .33962 L .7651 .34137 L 0 .03 .13 r
F
.76206 .34231 m .76072 .34059 L .76376 .33962 L F
.62598 .35239 m .62747 .34974 L .62894 .35125 L 0 .054 .156 r
F
.62598 .35239 m .62451 .35087 L .62747 .34974 L F
.84054 .34052 m .84235 .33769 L .84361 .33946 L 0 .026 .125 r
F
.84054 .34052 m .83927 .33876 L .84235 .33769 L F
.26879 .34218 m .26974 .33926 L .27157 .34116 L 0 .029 .129 r
F
.26879 .34218 m .26696 .34029 L .26974 .33926 L F
.30287 .34283 m .30387 .34002 L .30565 .34197 L 0 .031 .131 r
F
.30287 .34283 m .30108 .34087 L .30387 .34002 L F
.32955 .34386 m .33059 .34102 L .33235 .343 L 0 .033 .134 r
F
.32955 .34386 m .32779 .34188 L .33059 .34102 L F
.84794 .34017 m .84977 .33741 L .85103 .33919 L 0 .025 .124 r
F
.84794 .34017 m .84669 .3384 L .84977 .33741 L F
.75467 .34285 m .75635 .34001 L .75769 .34171 L 0 .031 .131 r
F
.75467 .34285 m .75333 .34114 L .75635 .34001 L F
.2347 .34163 m .23559 .33891 L .23745 .34075 L 0 .028 .128 r
F
.2347 .34163 m .23284 .3398 L .23559 .33891 L F
.65849 .3482 m .66002 .34512 L .66146 .34693 L 0 .042 .144 r
F
.65849 .3482 m .65704 .34643 L .66002 .34512 L F
.43046 .35334 m .43165 .35085 L .43331 .35294 L 0 .057 .159 r
F
.43046 .35334 m .4288 .35131 L .43165 .35085 L F
.48456 .39296 m .48576 .39631 L .48734 .401 L 0 .238 .276 r
F
.48456 .39296 m .48297 .38922 L .48576 .39631 L F
.3948 .34782 m .39595 .34487 L .39764 .34697 L 0 .042 .144 r
F
.3948 .34782 m .3931 .3458 L .39595 .34487 L F
.45132 .35976 m .45253 .35757 L .45418 .35955 L 0 .076 .177 r
F
.45132 .35976 m .44968 .35778 L .45253 .35757 L F
.65109 .34869 m .65262 .34596 L .65407 .34769 L 0 .044 .147 r
F
.65109 .34869 m .64964 .34701 L .65262 .34596 L F
.20801 .34069 m .20886 .33795 L .21074 .33977 L 0 .026 .126 r
F
.20801 .34069 m .20612 .33889 L .20886 .33795 L F
.40669 .34973 m .40784 .34698 L .40953 .34899 L 0 .047 .149 r
F
.40669 .34973 m .405 .34772 L .40784 .34698 L F
.17392 .34008 m .17473 .33722 L .17665 .33905 L 0 .025 .124 r
F
.17392 .34008 m .172 .33827 L .17473 .33722 L F
.27617 .34195 m .27713 .33912 L .27895 .34097 L 0 .029 .129 r
F
.27617 .34195 m .27435 .34013 L .27713 .33912 L F
.76948 .3422 m .77119 .3394 L .77252 .34121 L 0 .03 .13 r
F
.76948 .3422 m .76815 .34042 L .77119 .3394 L F
.59797 .35926 m .59941 .35628 L .60091 .35767 L 0 .073 .174 r
F
.59797 .35926 m .59647 .35789 L .59941 .35628 L F
.13982 .33959 m .14058 .33679 L .14253 .33865 L 0 .024 .123 r
F
.13982 .33959 m .13787 .33774 L .14058 .33679 L F
.60828 .35623 m .60973 .3531 L .61122 .35463 L 0 .064 .166 r
F
.60828 .35623 m .60679 .35476 L .60973 .3531 L F
.6437 .34926 m .64522 .34647 L .64667 .34807 L 0 .046 .148 r
F
.6437 .34926 m .64225 .34771 L .64522 .34647 L F
.61859 .35318 m .62007 .3503 L .62155 .35202 L 0 .056 .158 r
F
.61859 .35318 m .61711 .35152 L .62007 .3503 L F
.24207 .3415 m .24299 .33861 L .24484 .34043 L 0 .028 .128 r
F
.24207 .3415 m .24021 .3397 L .24299 .33861 L F
.77689 .34192 m .7786 .33899 L .77993 .34083 L 0 .029 .129 r
F
.77689 .34192 m .77556 .3401 L .7786 .33899 L F
.35622 .34523 m .35729 .34253 L .35903 .34439 L 0 .036 .138 r
F
.35622 .34523 m .35447 .3434 L .35729 .34253 L F
.85538 .3401 m .85722 .33739 L .85847 .3392 L 0 .026 .124 r
F
.85538 .3401 m .85412 .33829 L .85722 .33739 L F
.31024 .3428 m .31125 .34 L .31304 .34177 L 0 .031 .131 r
F
.31024 .3428 m .30845 .34103 L .31125 .34 L F
.18129 .33995 m .18211 .33715 L .18401 .33904 L 0 .025 .124 r
F
.18129 .33995 m .17938 .33807 L .18211 .33715 L F
.7843 .34159 m .78603 .33881 L .78735 .34059 L 0 .029 .128 r
F
.7843 .34159 m .78298 .33981 L .78603 .33881 L F
.69101 .34427 m .6926 .34139 L .69401 .34316 L 0 .034 .135 r
F
.69101 .34427 m .6896 .34253 L .6926 .34139 L F
.24946 .34122 m .25038 .33844 L .25222 .3403 L 0 .028 .127 r
F
.24946 .34122 m .24761 .33938 L .25038 .33844 L F
.3755 .34677 m .3766 .34408 L .37832 .346 L 0 .04 .142 r
F
.3755 .34677 m .37378 .34487 L .3766 .34408 L F
.28355 .34185 m .28452 .33905 L .28633 .34089 L 0 .029 .129 r
F
.28355 .34185 m .28173 .34001 L .28452 .33905 L F
.31763 .3425 m .31864 .33985 L .32043 .34164 L 0 .031 .131 r
F
.31763 .3425 m .31585 .34074 L .31864 .33985 L F
.58475 .36529 m .58617 .36206 L .58768 .36334 L 0 .093 .19 r
F
.58475 .36529 m .58324 .36409 L .58617 .36206 L F
.47375 .37149 m .475 .36978 L .47659 .37354 L 0 .121 .21 r
F
.47375 .37149 m .47215 .36835 L .475 .36978 L F
.21536 .34072 m .21623 .33796 L .2181 .33981 L 0 .027 .126 r
F
.21536 .34072 m .21348 .33887 L .21623 .33796 L F
.55164 .41482 m .55018 .42607 L .55308 .41946 L 0 .337 .294 r
F
.54874 .41969 m .55018 .42607 L .55164 .41482 L 0 .356 .281 r
F
.69842 .34401 m .70003 .34127 L .70143 .3431 L 0 .034 .135 r
F
.69842 .34401 m .69702 .34222 L .70003 .34127 L F
.79171 .34135 m .79345 .33853 L .79476 .34028 L 0 .028 .128 r
F
.79171 .34135 m .7904 .33958 L .79345 .33853 L F
.79911 .34097 m .80086 .33813 L .80216 .33989 L 0 .027 .127 r
F
.79911 .34097 m .79781 .33922 L .80086 .33813 L F
.80652 .3406 m .80827 .33771 L .80957 .33953 L 0 .027 .126 r
F
.80652 .3406 m .80522 .3388 L .80827 .33771 L F
.71323 .34327 m .71486 .34064 L .71624 .34231 L 0 .033 .133 r
F
.71323 .34327 m .71184 .34161 L .71486 .34064 L F
.33691 .34411 m .33797 .34122 L .33972 .34321 L 0 .034 .135 r
F
.33691 .34411 m .33516 .34214 L .33797 .34122 L F
.86281 .34001 m .86466 .33724 L .8659 .33901 L 0 .026 .125 r
F
.86281 .34001 m .86157 .33823 L .86466 .33724 L F
.42595 .35172 m .42713 .3493 L .4288 .35131 L 0 .054 .156 r
F
.42595 .35172 m .42428 .34977 L .42713 .3493 L F
.14717 .33962 m .14794 .33672 L .14988 .33863 L 0 .025 .123 r
F
.14717 .33962 m .14523 .33771 L .14794 .33672 L F
.57311 .37616 m .57161 .37654 L .5745 .37184 L 0 .132 .217 r
F
.57023 .38123 m .57161 .37654 L .57311 .37616 L 0 .158 .233 r
F
.44682 .35811 m .44803 .35567 L .44968 .35778 L 0 .072 .173 r
F
.44682 .35811 m .44517 .35602 L .44803 .35567 L F
.41406 .34993 m .41523 .34721 L .41691 .34903 L 0 .048 .151 r
F
.41406 .34993 m .41238 .3481 L .41523 .34721 L F
.68363 .34501 m .6852 .3421 L .68662 .34377 L 0 .036 .138 r
F
.68363 .34501 m .68222 .34337 L .6852 .3421 L F
.70583 .34381 m .70744 .34093 L .70884 .3427 L 0 .034 .134 r
F
.70583 .34381 m .70444 .34204 L .70744 .34093 L F
.72064 .34302 m .72228 .34037 L .72365 .34204 L 0 .032 .133 r
F
.72064 .34302 m .71926 .34135 L .72228 .34037 L F
.29092 .3418 m .29192 .33879 L .29371 .34075 L 0 .029 .129 r
F
.29092 .3418 m .28912 .33986 L .29192 .33879 L F
.87023 .33977 m .8721 .33704 L .87333 .33879 L 0 .026 .124 r
F
.87023 .33977 m .869 .33801 L .8721 .33704 L F
.81394 .34039 m .81571 .3376 L .81701 .33944 L 0 .027 .126 r
F
.81394 .34039 m .81264 .33857 L .81571 .3376 L F
.36359 .34537 m .36469 .34236 L .36641 .34439 L 0 .037 .139 r
F
.36359 .34537 m .36186 .34337 L .36469 .34236 L F
.18864 .34005 m .18947 .33718 L .19137 .3391 L 0 .026 .125 r
F
.18864 .34005 m .18674 .33813 L .18947 .33718 L F
.72805 .34273 m .7297 .34002 L .73107 .34173 L 0 .032 .132 r
F
.72805 .34273 m .72667 .34103 L .7297 .34002 L F
.38288 .34684 m .384 .34408 L .38571 .34587 L 0 .041 .143 r
F
.38288 .34684 m .38116 .34504 L .384 .34408 L F
.22272 .34071 m .22362 .33776 L .22548 .3397 L 0 .027 .127 r
F
.22272 .34071 m .22086 .33879 L .22362 .33776 L F
.15454 .33948 m .15533 .33651 L .15726 .33842 L 0 .025 .123 r
F
.15454 .33948 m .15261 .33757 L .15533 .33651 L F
.67624 .34566 m .67781 .34287 L .67923 .34452 L 0 .038 .14 r
F
.67624 .34566 m .67482 .34402 L .67781 .34287 L F
.25681 .34138 m .25776 .33841 L .25958 .3404 L 0 .029 .128 r
F
.25681 .34138 m .25498 .33939 L .25776 .33841 L F
.34429 .34405 m .34535 .34137 L .3471 .34316 L 0 .035 .136 r
F
.34429 .34405 m .34253 .34229 L .34535 .34137 L F
.63633 .35042 m .63783 .34756 L .63929 .34906 L 0 .05 .152 r
F
.63633 .35042 m .63487 .34895 L .63783 .34756 L F
.40216 .34838 m .40331 .34559 L .405 .34772 L 0 .045 .147 r
F
.40216 .34838 m .40047 .34627 L .40331 .34559 L F
.73545 .34244 m .73711 .33964 L .73848 .34144 L 0 .031 .132 r
F
.73545 .34244 m .73409 .34069 L .73711 .33964 L F
.87765 .33957 m .87953 .33685 L .88076 .33861 L 0 .025 .124 r
F
.87765 .33957 m .87643 .33781 L .87953 .33685 L F
.56171 .39974 m .56025 .40507 L .56311 .39785 L 0 .257 .285 r
F
.55884 .4063 m .56025 .40507 L .56171 .39974 L 0 .309 .307 r
F
.32499 .3427 m .32602 .33996 L .32779 .34188 L 0 .032 .132 r
F
.32499 .3427 m .32322 .3408 L .32602 .33996 L F
.82136 .34025 m .82314 .33738 L .82442 .33917 L 0 .027 .126 r
F
.82136 .34025 m .82008 .33845 L .82314 .33738 L F
.82876 .33986 m .83057 .33713 L .83184 .33888 L 0 .026 .125 r
F
.82876 .33986 m .82749 .3381 L .83057 .33713 L F
.2983 .34172 m .29929 .33888 L .30108 .34087 L 0 .03 .13 r
F
.2983 .34172 m .29651 .33973 L .29929 .33888 L F
.66885 .34627 m .6704 .34343 L .67183 .34515 L 0 .04 .142 r
F
.66885 .34627 m .66742 .34456 L .6704 .34343 L F
.58768 .36334 m .5891 .36008 L .59061 .36143 L 0 .087 .186 r
F
.58768 .36334 m .58617 .36206 L .5891 .36008 L F
.44232 .35637 m .44352 .35393 L .44517 .35602 L 0 .067 .169 r
F
.44232 .35637 m .44066 .35429 L .44352 .35393 L F
.48297 .38922 m .48418 .39142 L .48576 .39631 L 0 .217 .266 r
F
.48297 .38922 m .48137 .38535 L .48418 .39142 L F
.39026 .34673 m .3914 .34393 L .3931 .3458 L 0 .041 .143 r
F
.39026 .34673 m .38855 .3449 L .3914 .34393 L F
.16191 .33935 m .16269 .33655 L .16462 .33844 L 0 .025 .124 r
F
.16191 .33935 m .15998 .33746 L .16269 .33655 L F
.74287 .34227 m .74455 .33956 L .74591 .34138 L 0 .031 .132 r
F
.74287 .34227 m .74151 .34047 L .74455 .33956 L F
.60091 .35767 m .60236 .35479 L .60385 .35622 L 0 .07 .172 r
F
.60091 .35767 m .59941 .35628 L .60236 .35479 L F
.19599 .34005 m .19684 .33717 L .19873 .33907 L 0 .026 .125 r
F
.19599 .34005 m .1941 .33814 L .19684 .33717 L F
.61122 .35463 m .61268 .35141 L .61416 .35301 L 0 .061 .163 r
F
.61122 .35463 m .60973 .3531 L .61268 .35141 L F
.88509 .33944 m .88698 .33672 L .8882 .3385 L 0 .025 .124 r
F
.88509 .33944 m .88387 .33767 L .88698 .33672 L F
.23009 .34068 m .23098 .33785 L .23284 .3398 L 0 .028 .127 r
F
.23009 .34068 m .22823 .33874 L .23098 .33785 L F
.26418 .34134 m .26514 .33832 L .26696 .34029 L 0 .029 .129 r
F
.26418 .34134 m .26236 .33936 L .26514 .33832 L F
.83619 .3397 m .83801 .33701 L .83927 .33876 L 0 .026 .125 r
F
.83619 .3397 m .83493 .33795 L .83801 .33701 L F
.66146 .34693 m .66299 .34384 L .66443 .34569 L 0 .041 .143 r
F
.66146 .34693 m .66002 .34512 L .66299 .34384 L F
.62894 .35125 m .63044 .34861 L .6319 .35011 L 0 .053 .155 r
F
.62894 .35125 m .62747 .34974 L .63044 .34861 L F
.42144 .35024 m .42261 .34791 L .42428 .34977 L 0 .051 .154 r
F
.42144 .35024 m .41976 .34841 L .42261 .34791 L F
.46318 .36297 m .46442 .36049 L .46605 .36258 L 0 .089 .187 r
F
.46318 .36297 m .46155 .36103 L .46442 .36049 L F
.35166 .34416 m .35272 .34161 L .35447 .3434 L 0 .036 .137 r
F
.35166 .34416 m .34991 .34238 L .35272 .34161 L F
.53999 .4265 m .54143 .43951 L .54292 .42556 L 0 .384 .257 r
F
.53999 .4265 m .5385 .44045 L .54143 .43951 L F
.75769 .34171 m .75938 .33888 L .76072 .34059 L 0 .03 .13 r
F
.75769 .34171 m .75635 .34001 L .75938 .33888 L F
.20337 .33987 m .20422 .33707 L .20612 .33889 L 0 .026 .126 r
F
.20337 .33987 m .20148 .33807 L .20422 .33707 L F
.84361 .33946 m .84543 .33663 L .84669 .3384 L 0 .026 .124 r
F
.84361 .33946 m .84235 .33769 L .84543 .33663 L F
.37096 .34563 m .37206 .34276 L .37378 .34487 L 0 .039 .141 r
F
.37096 .34563 m .36924 .34356 L .37206 .34276 L F
.27157 .34116 m .27253 .33822 L .27435 .34013 L 0 .029 .129 r
F
.27157 .34116 m .26974 .33926 L .27253 .33822 L F
.16927 .33931 m .17007 .33645 L .172 .33827 L 0 .025 .124 r
F
.16927 .33931 m .16734 .3375 L .17007 .33645 L F
.46767 .36538 m .46893 .3622 L .47054 .36526 L 0 .096 .192 r
F
.46767 .36538 m .46605 .36258 L .46893 .3622 L F
.7651 .34137 m .76681 .33866 L .76815 .34042 L 0 .03 .13 r
F
.7651 .34137 m .76376 .33962 L .76681 .33866 L F
.7503 .3422 m .75198 .33943 L .75333 .34114 L 0 .031 .132 r
F
.7503 .3422 m .74895 .34048 L .75198 .33943 L F
.85103 .33919 m .85287 .33649 L .85412 .33829 L 0 .025 .124 r
F
.85103 .33919 m .84977 .33741 L .85287 .33649 L F
.64667 .34807 m .64819 .34536 L .64964 .34701 L 0 .045 .148 r
F
.64667 .34807 m .64522 .34647 L .64819 .34536 L F
.17665 .33905 m .17746 .33623 L .17938 .33807 L 0 .025 .124 r
F
.17665 .33905 m .17473 .33722 L .17746 .33623 L F
.43781 .35466 m .43901 .35211 L .44066 .35429 L 0 .063 .165 r
F
.43781 .35466 m .43616 .35253 L .43901 .35211 L F
.65407 .34769 m .6556 .34466 L .65704 .34643 L 0 .044 .146 r
F
.65407 .34769 m .65262 .34596 L .6556 .34466 L F
.62155 .35202 m .62303 .34907 L .62451 .35087 L 0 .055 .158 r
F
.62155 .35202 m .62007 .3503 L .62303 .34907 L F
.30565 .34197 m .30666 .33909 L .30845 .34103 L 0 .031 .131 r
F
.30565 .34197 m .30387 .34002 L .30666 .33909 L F
.33235 .343 m .3334 .34016 L .33516 .34214 L 0 .033 .134 r
F
.33235 .343 m .33059 .34102 L .3334 .34016 L F
.23745 .34075 m .23836 .33785 L .24021 .3397 L 0 .028 .128 r
F
.23745 .34075 m .23559 .33891 L .23836 .33785 L F
.27895 .34097 m .27992 .33816 L .28173 .34001 L 0 .029 .129 r
F
.27895 .34097 m .27713 .33912 L .27992 .33816 L F
.77252 .34121 m .77423 .33828 L .77556 .3401 L F
.77252 .34121 m .77119 .3394 L .77423 .33828 L F
.21074 .33977 m .2116 .33704 L .21348 .33887 L 0 .027 .126 r
F
.21074 .33977 m .20886 .33795 L .2116 .33704 L F
.39764 .34697 m .39878 .34415 L .40047 .34627 L 0 .042 .145 r
F
.39764 .34697 m .39595 .34487 L .39878 .34415 L F
.77993 .34083 m .78165 .33795 L .78298 .33981 L 0 .029 .128 r
F
.77993 .34083 m .7786 .33899 L .78165 .33795 L F
.24484 .34043 m .24576 .33754 L .24761 .33938 L 0 .028 .127 r
F
.24484 .34043 m .24299 .33861 L .24576 .33754 L F
.59061 .36143 m .59204 .3583 L .59354 .35966 L 0 .083 .182 r
F
.59061 .36143 m .5891 .36008 L .59204 .3583 L F
.69401 .34316 m .69561 .34042 L .69702 .34222 L 0 .034 .135 r
F
.69401 .34316 m .6926 .34139 L .69561 .34042 L F
.14253 .33865 m .14328 .33584 L .14523 .33771 L 0 .025 .123 r
F
.14253 .33865 m .14058 .33679 L .14328 .33584 L F
.31304 .34177 m .31406 .33898 L .31585 .34074 L 0 .031 .131 r
F
.31304 .34177 m .31125 .34 L .31406 .33898 L F
.45868 .36128 m .45991 .35908 L .46155 .36103 L 0 .085 .184 r
F
.45868 .36128 m .45704 .35937 L .45991 .35908 L F
.40953 .34899 m .41069 .34609 L .41238 .3481 L 0 .047 .15 r
F
.40953 .34899 m .40784 .34698 L .41069 .34609 L F
.78735 .34059 m .78908 .33781 L .7904 .33958 L 0 .029 .128 r
F
.78735 .34059 m .78603 .33881 L .78908 .33781 L F
.85847 .3392 m .86032 .33642 L .86157 .33823 L 0 .026 .125 r
F
.85847 .3392 m .85722 .33739 L .86032 .33642 L F
.18401 .33904 m .18483 .33622 L .18674 .33813 L 0 .026 .124 r
F
.18401 .33904 m .18211 .33715 L .18483 .33622 L F
.28633 .34089 m .28731 .338 L .28912 .33986 L 0 .029 .129 r
F
.28633 .34089 m .28452 .33905 L .28731 .338 L F
.68662 .34377 m .68819 .34084 L .6896 .34253 L 0 .035 .136 r
F
.68662 .34377 m .6852 .3421 L .68819 .34084 L F
.35903 .34439 m .36012 .34148 L .36186 .34337 L 0 .037 .138 r
F
.35903 .34439 m .35729 .34253 L .36012 .34148 L F
.79476 .34028 m .79651 .33748 L .79781 .33922 L 0 .028 .128 r
F
.79476 .34028 m .79345 .33853 L .79651 .33748 L F
.80216 .33989 m .80392 .33703 L .80522 .3388 L 0 .027 .126 r
F
.80216 .33989 m .80086 .33813 L .80392 .33703 L F
.25222 .3403 m .25314 .33749 L .25498 .33939 L 0 .028 .128 r
F
.25222 .3403 m .25038 .33844 L .25314 .33749 L F
.80957 .33953 m .81134 .33674 L .81264 .33857 L 0 .027 .126 r
F
.80957 .33953 m .80827 .33771 L .81134 .33674 L F
.48137 .38535 m .48259 .38653 L .48418 .39142 L 0 .197 .255 r
F
.48137 .38535 m .47978 .38146 L .48259 .38653 L F
.32043 .34164 m .32144 .33897 L .32322 .3408 L 0 .031 .132 r
F
.32043 .34164 m .31864 .33985 L .32144 .33897 L F
.43331 .35294 m .4345 .3504 L .43616 .35253 L 0 .059 .162 r
F
.43331 .35294 m .43165 .35085 L .4345 .3504 L F
.47215 .36835 m .4734 .36614 L .475 .36978 L 0 .111 .203 r
F
.47215 .36835 m .47054 .36526 L .4734 .36614 L F
.70143 .3431 m .70303 .3402 L .70444 .34204 L 0 .034 .135 r
F
.70143 .3431 m .70003 .34127 L .70303 .3402 L F
.2181 .33981 m .21898 .33691 L .22086 .33879 L 0 .027 .126 r
F
.2181 .33981 m .21623 .33796 L .21898 .33691 L F
.70884 .3427 m .71045 .33984 L .71184 .34161 L 0 .033 .134 r
F
.70884 .3427 m .70744 .34093 L .71045 .33984 L F
.63929 .34906 m .64079 .34617 L .64225 .34771 L 0 .048 .151 r
F
.63929 .34906 m .63783 .34756 L .64079 .34617 L F
.8659 .33901 m .86776 .33626 L .869 .33801 L 0 .026 .125 r
F
.8659 .33901 m .86466 .33724 L .86776 .33626 L F
.37832 .346 m .37944 .34313 L .38116 .34504 L 0 .041 .143 r
F
.37832 .346 m .3766 .34408 L .37944 .34313 L F
.71624 .34231 m .71788 .33968 L .71926 .34135 L 0 .033 .134 r
F
.71624 .34231 m .71486 .34064 L .71788 .33968 L F
.14988 .33863 m .15067 .33566 L .15261 .33757 L 0 .025 .123 r
F
.14988 .33863 m .14794 .33672 L .15067 .33566 L F
.61416 .35301 m .61562 .34985 L .61711 .35152 L 0 .058 .161 r
F
.61416 .35301 m .61268 .35141 L .61562 .34985 L F
.33972 .34321 m .34078 .34028 L .34253 .34229 L 0 .034 .135 r
F
.33972 .34321 m .33797 .34122 L .34078 .34028 L F
.29371 .34075 m .29471 .33775 L .29651 .33973 L 0 .029 .129 r
F
.29371 .34075 m .29192 .33879 L .29471 .33775 L F
.72365 .34204 m .7253 .33936 L .72667 .34103 L 0 .032 .133 r
F
.72365 .34204 m .72228 .34037 L .7253 .33936 L F
.41691 .34903 m .41808 .34657 L .41976 .34841 L 0 .049 .152 r
F
.41691 .34903 m .41523 .34721 L .41808 .34657 L F
.60385 .35622 m .6053 .3533 L .60679 .35476 L 0 .068 .17 r
F
.60385 .35622 m .60236 .35479 L .6053 .3533 L F
.67923 .34452 m .6808 .34173 L .68222 .34337 L 0 .038 .139 r
F
.67923 .34452 m .67781 .34287 L .6808 .34173 L F
.87333 .33879 m .8752 .33606 L .87643 .33781 L 0 .026 .124 r
F
.87333 .33879 m .8721 .33704 L .8752 .33606 L F
.45418 .35955 m .4554 .35739 L .45704 .35937 L 0 .08 .18 r
F
.45418 .35955 m .45253 .35757 L .4554 .35739 L F
.81701 .33944 m .81878 .3366 L .82008 .33845 L 0 .027 .126 r
F
.81701 .33944 m .81571 .3376 L .81878 .3366 L F
.15726 .33842 m .15805 .33556 L .15998 .33746 L 0 .025 .123 r
F
.15726 .33842 m .15533 .33651 L .15805 .33556 L F
.36641 .34439 m .36752 .34148 L .36924 .34356 L 0 .037 .139 r
F
.36641 .34439 m .36469 .34236 L .36752 .34148 L F
.73107 .34173 m .73272 .33894 L .73409 .34069 L 0 .032 .132 r
F
.73107 .34173 m .7297 .34002 L .73272 .33894 L F
.22548 .3397 m .22637 .33679 L .22823 .33874 L 0 .027 .127 r
F
.22548 .3397 m .22362 .33776 L .22637 .33679 L F
.38571 .34587 m .38684 .34309 L .38855 .3449 L 0 .041 .143 r
F
.38571 .34587 m .384 .34408 L .38684 .34309 L F
.19137 .3391 m .1922 .33622 L .1941 .33814 L 0 .026 .125 r
F
.19137 .3391 m .18947 .33718 L .1922 .33622 L F
.25958 .3404 m .26053 .33738 L .26236 .33936 L 0 .029 .128 r
F
.25958 .3404 m .25776 .33841 L .26053 .33738 L F
.82442 .33917 m .82621 .33631 L .82749 .3381 L 0 .026 .125 r
F
.82442 .33917 m .82314 .33738 L .82621 .33631 L F
.56311 .39785 m .5645 .39427 L .56598 .39114 L 0 .257 .285 r
F
.54874 .41969 m .54728 .43233 L .55018 .42607 L 0 .356 .281 r
F
.54583 .42263 m .54728 .43233 L .54874 .41969 L 0 .37 .27 r
F
.73848 .34144 m .74014 .33863 L .74151 .34047 L 0 .031 .131 r
F
.73848 .34144 m .73711 .33964 L .74014 .33863 L F
.67183 .34515 m .67339 .3423 L .67482 .34402 L 0 .039 .141 r
F
.67183 .34515 m .6704 .34343 L .67339 .3423 L F
.88076 .33861 m .88264 .33589 L .88387 .33767 L 0 .026 .124 r
F
.88076 .33861 m .87953 .33685 L .88264 .33589 L F
.3471 .34316 m .34816 .34058 L .34991 .34238 L 0 .035 .137 r
F
.3471 .34316 m .34535 .34137 L .34816 .34058 L F
.83184 .33888 m .83366 .3362 L .83493 .33795 L 0 .026 .125 r
F
.83184 .33888 m .83057 .33713 L .83366 .3362 L F
.66443 .34569 m .66597 .34267 L .66742 .34456 L 0 .04 .142 r
F
.66443 .34569 m .66299 .34384 L .66597 .34267 L F
.59354 .35966 m .59497 .35651 L .59647 .35789 L 0 .079 .179 r
F
.59354 .35966 m .59204 .3583 L .59497 .35651 L F
.4288 .35131 m .42998 .34879 L .43165 .35085 L 0 .056 .158 r
F
.4288 .35131 m .42713 .3493 L .42998 .34879 L F
.32779 .34188 m .32883 .33909 L .33059 .34102 L 0 .032 .133 r
F
.32779 .34188 m .32602 .33996 L .32883 .33909 L F
.6319 .35011 m .63341 .34747 L .63487 .34895 L 0 .052 .155 r
F
.6319 .35011 m .63044 .34861 L .63341 .34747 L F
.3931 .3458 m .39424 .34296 L .39595 .34487 L 0 .041 .143 r
F
.3931 .3458 m .3914 .34393 L .39424 .34296 L F
.30108 .34087 m .30208 .33803 L .30387 .34002 L 0 .03 .13 r
F
.30108 .34087 m .29929 .33888 L .30208 .33803 L F
.54583 .42263 m .54436 .43592 L .54728 .43233 L 0 .37 .27 r
F
.54292 .42556 m .54436 .43592 L .54583 .42263 L 0 .38 .261 r
F
.16462 .33844 m .16541 .33561 L .16734 .3375 L 0 .025 .124 r
F
.16462 .33844 m .16269 .33655 L .16541 .33561 L F
.26696 .34029 m .26792 .33729 L .26974 .33926 L 0 .029 .128 r
F
.26696 .34029 m .26514 .33832 L .26792 .33729 L F
.19873 .33907 m .19958 .33617 L .20148 .33807 L 0 .026 .126 r
F
.19873 .33907 m .19684 .33717 L .19958 .33617 L F
.44968 .35778 m .45089 .35548 L .45253 .35757 L 0 .075 .176 r
F
.44968 .35778 m .44803 .35567 L .45089 .35548 L F
.405 .34772 m .40616 .34484 L .40784 .34698 L 0 .046 .148 r
F
.405 .34772 m .40331 .34559 L .40616 .34484 L F
.74591 .34138 m .74759 .33865 L .74895 .34048 L 0 .032 .132 r
F
.74591 .34138 m .74455 .33956 L .74759 .33865 L F
.57023 .38123 m .56874 .38257 L .57161 .37654 L 0 .158 .233 r
F
.56735 .38631 m .56874 .38257 L .57023 .38123 L 0 .191 .252 r
F
.76072 .34059 m .76243 .3379 L .76376 .33962 L 0 .03 .13 r
F
.76072 .34059 m .75938 .33888 L .76243 .3379 L F
.83927 .33876 m .84109 .33595 L .84235 .33769 L 0 .026 .125 r
F
.83927 .33876 m .83801 .33701 L .84109 .33595 L F
.23284 .3398 m .23373 .33696 L .23559 .33891 L 0 .028 .128 r
F
.23284 .3398 m .23098 .33785 L .23373 .33696 L F
.84669 .3384 m .84852 .33562 L .84977 .33741 L 0 .026 .124 r
F
.84669 .3384 m .84543 .33663 L .84852 .33562 L F
.65704 .34643 m .65857 .34331 L .66002 .34512 L 0 .042 .145 r
F
.65704 .34643 m .6556 .34466 L .65857 .34331 L F
.54292 .42556 m .54143 .43951 L .54436 .43592 L 0 .38 .261 r
F
.75333 .34114 m .75501 .3383 L .75635 .34001 L 0 .031 .131 r
F
.75333 .34114 m .75198 .33943 L .75501 .3383 L F
.172 .33827 m .17281 .33539 L .17473 .33722 L 0 .025 .124 r
F
.172 .33827 m .17007 .33645 L .17281 .33539 L F
.20612 .33889 m .20696 .33612 L .20886 .33795 L 0 .027 .126 r
F
.20612 .33889 m .20422 .33707 L .20696 .33612 L F
.27435 .34013 m .27531 .33721 L .27713 .33912 L 0 .029 .129 r
F
.27435 .34013 m .27253 .33822 L .27531 .33721 L F
.47978 .38146 m .48101 .38161 L .48259 .38653 L 0 .177 .244 r
F
.47978 .38146 m .47819 .3775 L .48101 .38161 L F
.52228 .4318 m .5236 .44897 L .52519 .43798 L 0 .408 .231 r
F
.52228 .4318 m .52068 .44115 L .5236 .44897 L F
.62451 .35087 m .62599 .3479 L .62747 .34974 L 0 .054 .157 r
F
.62451 .35087 m .62303 .34907 L .62599 .3479 L F
.13787 .33774 m .13862 .33493 L .14058 .33679 L 0 .024 .123 r
F
.13787 .33774 m .13591 .33589 L .13862 .33493 L F
.76815 .34042 m .76985 .33761 L .77119 .3394 L 0 .03 .13 r
F
.76815 .34042 m .76681 .33866 L .76985 .33761 L F
.64964 .34701 m .65117 .34426 L .65262 .34596 L 0 .045 .147 r
F
.64964 .34701 m .64819 .34536 L .65117 .34426 L F
.77556 .3401 m .77727 .33715 L .7786 .33899 L 0 .029 .129 r
F
.77556 .3401 m .77423 .33828 L .77727 .33715 L F
.24021 .3397 m .24113 .33675 L .24299 .33861 L 0 .028 .128 r
F
.24021 .3397 m .23836 .33785 L .24113 .33675 L F
.35447 .3434 m .35554 .34071 L .35729 .34253 L 0 .037 .138 r
F
.35447 .3434 m .35272 .34161 L .35554 .34071 L F
.17938 .33807 m .18019 .33529 L .18211 .33715 L 0 .025 .124 r
F
.17938 .33807 m .17746 .33623 L .18019 .33529 L F
.85412 .33829 m .85597 .33556 L .85722 .33739 L 0 .026 .125 r
F
.85412 .33829 m .85287 .33649 L .85597 .33556 L F
.37378 .34487 m .37489 .34194 L .3766 .34408 L 0 .039 .141 r
F
.37378 .34487 m .37206 .34276 L .37489 .34194 L F
.24761 .33938 m .24853 .33657 L .25038 .33844 L 0 .028 .127 r
F
.24761 .33938 m .24576 .33754 L .24853 .33657 L F
.44517 .35602 m .44638 .35357 L .44803 .35567 L 0 .07 .172 r
F
.44517 .35602 m .44352 .35393 L .44638 .35357 L F
.30845 .34103 m .30947 .33808 L .31125 .34 L 0 .031 .131 r
F
.30845 .34103 m .30666 .33909 L .30947 .33808 L F
.28173 .34001 m .2827 .3372 L .28452 .33905 L 0 .029 .129 r
F
.28173 .34001 m .27992 .33816 L .2827 .3372 L F
.61711 .35152 m .61858 .34856 L .62007 .3503 L 0 .056 .159 r
F
.61711 .35152 m .61562 .34985 L .61858 .34856 L F
.78298 .33981 m .7847 .33693 L .78603 .33881 L 0 .029 .128 r
F
.78298 .33981 m .78165 .33795 L .7847 .33693 L F
.6896 .34253 m .69119 .33967 L .6926 .34139 L 0 .034 .136 r
F
.6896 .34253 m .68819 .34084 L .69119 .33967 L F
.33516 .34214 m .33621 .33924 L .33797 .34122 L 0 .034 .134 r
F
.33516 .34214 m .3334 .34016 L .33621 .33924 L F
.21348 .33887 m .21434 .33612 L .21623 .33796 L 0 .027 .126 r
F
.21348 .33887 m .2116 .33704 L .21434 .33612 L F
.64225 .34771 m .64376 .34489 L .64522 .34647 L 0 .047 .149 r
F
.64225 .34771 m .64079 .34617 L .64376 .34489 L F
.42428 .34977 m .42545 .34742 L .42713 .3493 L 0 .053 .156 r
F
.42428 .34977 m .42261 .34791 L .42545 .34742 L F
.31585 .34074 m .31686 .33805 L .31864 .33985 L 0 .031 .131 r
F
.31585 .34074 m .31406 .33898 L .31686 .33805 L F
.69702 .34222 m .69862 .33945 L .70003 .34127 L 0 .034 .135 r
F
.69702 .34222 m .69561 .34042 L .69862 .33945 L F
.14523 .33771 m .146 .33484 L .14794 .33672 L 0 .025 .123 r
F
.14523 .33771 m .14328 .33584 L .146 .33484 L F
.58032 .36627 m .58173 .36288 L .58324 .36409 L 0 .102 .197 r
F
.58032 .36627 m .57881 .3652 L .58173 .36288 L F
.57741 .36905 m .57881 .3652 L .58032 .36627 L 0 .112 .204 r
F
.60679 .35476 m .60824 .35157 L .60973 .3531 L 0 .065 .167 r
F
.60679 .35476 m .6053 .3533 L .60824 .35157 L F
.46605 .36258 m .4673 .35995 L .46893 .3622 L 0 .092 .189 r
F
.46605 .36258 m .46442 .36049 L .4673 .35995 L F
.7904 .33958 m .79214 .33677 L .79345 .33853 L 0 .028 .128 r
F
.7904 .33958 m .78908 .33781 L .79214 .33677 L F
.59647 .35789 m .59791 .35487 L .59941 .35628 L 0 .075 .176 r
F
.59647 .35789 m .59497 .35651 L .59791 .35487 L F
.80522 .3388 m .80697 .33592 L .80827 .33771 L 0 .027 .126 r
F
.80522 .3388 m .80392 .33703 L .80697 .33592 L F
.79781 .33922 m .79956 .33639 L .80086 .33813 L 0 .028 .127 r
F
.79781 .33922 m .79651 .33748 L .79956 .33639 L F
.28912 .33986 m .29011 .33691 L .29192 .33879 L 0 .029 .129 r
F
.28912 .33986 m .28731 .338 L .29011 .33691 L F
.86157 .33823 m .86342 .33544 L .86466 .33724 L 0 .026 .125 r
F
.86157 .33823 m .86032 .33642 L .86342 .33544 L F
.57741 .36905 m .5759 .36835 L .57881 .3652 L 0 .112 .204 r
F
.5745 .37184 m .5759 .36835 L .57741 .36905 L 0 .124 .212 r
F
.41238 .3481 m .41355 .3452 L .41523 .34721 L 0 .048 .15 r
F
.41238 .3481 m .41069 .34609 L .41355 .3452 L F
.36186 .34337 m .36296 .34042 L .36469 .34236 L 0 .037 .138 r
F
.36186 .34337 m .36012 .34148 L .36296 .34042 L F
.40047 .34627 m .40162 .34345 L .40331 .34559 L 0 .044 .146 r
F
.40047 .34627 m .39878 .34415 L .40162 .34345 L F
.71184 .34161 m .71347 .33887 L .71486 .34064 L 0 .033 .134 r
F
.71184 .34161 m .71045 .33984 L .71347 .33887 L F
.18674 .33813 m .18757 .33527 L .18947 .33718 L 0 .026 .125 r
F
.18674 .33813 m .18483 .33622 L .18757 .33527 L F
.70444 .34204 m .70604 .33907 L .70744 .34093 L 0 .034 .135 r
F
.70444 .34204 m .70303 .3402 L .70604 .33907 L F
.5745 .37184 m .57299 .3715 L .5759 .36835 L 0 .124 .212 r
F
.57161 .37654 m .57299 .3715 L .5745 .37184 L 0 .143 .224 r
F
.81264 .33857 m .81442 .33577 L .81571 .3376 L 0 .027 .126 r
F
.81264 .33857 m .81134 .33674 L .81442 .33577 L F
.25498 .33939 m .25592 .33649 L .25776 .33841 L 0 .028 .128 r
F
.25498 .33939 m .25314 .33749 L .25592 .33649 L F
.22086 .33879 m .22175 .33586 L .22362 .33776 L 0 .027 .126 r
F
.22086 .33879 m .21898 .33691 L .22175 .33586 L F
.15261 .33757 m .1534 .33461 L .15533 .33651 L 0 .025 .123 r
F
.15261 .33757 m .15067 .33566 L .1534 .33461 L F
.869 .33801 m .87087 .33528 L .8721 .33704 L 0 .026 .125 r
F
.869 .33801 m .86776 .33626 L .87087 .33528 L F
.68222 .34337 m .68379 .34044 L .6852 .3421 L 0 .037 .138 r
F
.68222 .34337 m .6808 .34173 L .68379 .34044 L F
.38116 .34504 m .38228 .34218 L .384 .34408 L 0 .041 .143 r
F
.38116 .34504 m .37944 .34313 L .38228 .34218 L F
.44066 .35429 m .44187 .35166 L .44352 .35393 L 0 .066 .168 r
F
.44066 .35429 m .43901 .35211 L .44187 .35166 L F
.71926 .34135 m .7209 .3387 L .72228 .34037 L 0 .033 .134 r
F
.71926 .34135 m .71788 .33968 L .7209 .3387 L F
.29651 .33973 m .2975 .3369 L .29929 .33888 L 0 .029 .129 r
F
.29651 .33973 m .29471 .33775 L .2975 .3369 L F
.32322 .3408 m .32425 .33809 L .32602 .33996 L 0 .032 .132 r
F
.32322 .3408 m .32144 .33897 L .32425 .33809 L F
.47054 .36526 m .47179 .36252 L .4734 .36614 L 0 .102 .197 r
F
.47054 .36526 m .46893 .3622 L .47179 .36252 L F
.72667 .34103 m .72833 .33835 L .7297 .34002 L 0 .032 .133 r
F
.72667 .34103 m .7253 .33936 L .72833 .33835 L F
.34253 .34229 m .3436 .33934 L .34535 .34137 L 0 .035 .136 r
F
.34253 .34229 m .34078 .34028 L .3436 .33934 L F
.58324 .36409 m .58466 .36078 L .58617 .36206 L 0 .096 .192 r
F
.58324 .36409 m .58173 .36288 L .58466 .36078 L F
.87643 .33781 m .87831 .3351 L .87953 .33685 L 0 .026 .124 r
F
.87643 .33781 m .8752 .33606 L .87831 .3351 L F
.73409 .34069 m .73574 .33784 L .73711 .33964 L 0 .031 .132 r
F
.73409 .34069 m .73272 .33894 L .73574 .33784 L F
.49216 .40933 m .49335 .41661 L .49496 .41839 L 0 .332 .297 r
F
.49216 .40933 m .49054 .40755 L .49335 .41661 L F
.82008 .33845 m .82185 .33552 L .82314 .33738 L 0 .027 .126 r
F
.82008 .33845 m .81878 .3366 L .82185 .33552 L F
.47819 .3775 m .47943 .37669 L .48101 .38161 L 0 .158 .233 r
F
.47819 .3775 m .47659 .37354 L .47943 .37669 L F
.67482 .34402 m .67638 .34116 L .67781 .34287 L 0 .039 .14 r
F
.67482 .34402 m .67339 .3423 L .67638 .34116 L F
.15998 .33746 m .16076 .33464 L .16269 .33655 L 0 .025 .123 r
F
.15998 .33746 m .15805 .33556 L .16076 .33464 L F
.82749 .3381 m .82929 .33535 L .83057 .33713 L 0 .026 .125 r
F
.82749 .3381 m .82621 .33631 L .82929 .33535 L F
.38855 .3449 m .38969 .34207 L .3914 .34393 L 0 .041 .143 r
F
.38855 .3449 m .38684 .34309 L .38969 .34207 L F
.22823 .33874 m .22912 .33591 L .23098 .33785 L 0 .027 .127 r
F
.22823 .33874 m .22637 .33679 L .22912 .33591 L F
.26236 .33936 m .26332 .33635 L .26514 .33832 L 0 .028 .128 r
F
.26236 .33936 m .26053 .33738 L .26332 .33635 L F
.1941 .33814 m .19494 .33526 L .19684 .33717 L 0 .026 .125 r
F
.1941 .33814 m .1922 .33622 L .19494 .33526 L F
.66742 .34456 m .66896 .34149 L .6704 .34343 L 0 .04 .142 r
F
.66742 .34456 m .66597 .34267 L .66896 .34149 L F
.74151 .34047 m .74318 .3377 L .74455 .33956 L 0 .031 .132 r
F
.74151 .34047 m .74014 .33863 L .74318 .3377 L F
.36924 .34356 m .37034 .34065 L .37206 .34276 L 0 .038 .139 r
F
.36924 .34356 m .36752 .34148 L .37034 .34065 L F
.46155 .36103 m .46279 .35839 L .46442 .36049 L 0 .088 .186 r
F
.46155 .36103 m .45991 .35908 L .46279 .35839 L F
.63487 .34895 m .63637 .34604 L .63783 .34756 L 0 .051 .154 r
F
.63487 .34895 m .63341 .34747 L .63637 .34604 L F
.88387 .33767 m .88576 .33493 L .88698 .33672 L 0 .026 .124 r
F
.88387 .33767 m .88264 .33589 L .88576 .33493 L F
.41976 .34841 m .42092 .34605 L .42261 .34791 L 0 .051 .153 r
F
.41976 .34841 m .41808 .34657 L .42092 .34605 L F
.66002 .34512 m .66154 .34199 L .66299 .34384 L 0 .041 .143 r
F
.66002 .34512 m .65857 .34331 L .66154 .34199 L F
.52968 .43268 m .53107 .44993 L .53262 .43702 L 0 .412 .226 r
F
.52968 .43268 m .52812 .44417 L .53107 .44993 L F
.43616 .35253 m .43736 .34989 L .43901 .35211 L 0 .062 .164 r
F
.43616 .35253 m .4345 .3504 L .43736 .34989 L F
.83493 .33795 m .83675 .33526 L .83801 .33701 L 0 .026 .125 r
F
.83493 .33795 m .83366 .3362 L .83675 .33526 L F
.5043 .42408 m .50549 .44025 L .50714 .43487 L 0 .387 .254 r
F
.5043 .42408 m .50266 .42794 L .50549 .44025 L F
.26974 .33926 m .27071 .33625 L .27253 .33822 L 0 .029 .128 r
F
.26974 .33926 m .26792 .33729 L .27071 .33625 L F
.34991 .34238 m .35097 .3398 L .35272 .34161 L 0 .036 .137 r
F
.34991 .34238 m .34816 .34058 L .35097 .3398 L F
.20148 .33807 m .20233 .33517 L .20422 .33707 L 0 .026 .125 r
F
.20148 .33807 m .19958 .33617 L .20233 .33517 L F
.39595 .34487 m .39708 .34222 L .39878 .34415 L 0 .042 .144 r
F
.39595 .34487 m .39424 .34296 L .39708 .34222 L F
.60973 .3531 m .61119 .34983 L .61268 .35141 L 0 .062 .164 r
F
.60973 .3531 m .60824 .35157 L .61119 .34983 L F
.84235 .33769 m .84417 .33488 L .84543 .33663 L 0 .026 .125 r
F
.84235 .33769 m .84109 .33595 L .84417 .33488 L F
.16734 .3375 m .16814 .33458 L .17007 .33645 L 0 .025 .124 r
F
.16734 .3375 m .16541 .33561 L .16814 .33458 L F
.33059 .34102 m .33163 .33823 L .3334 .34016 L 0 .033 .134 r
F
.33059 .34102 m .32883 .33909 L .33163 .33823 L F
.75635 .34001 m .75804 .33717 L .75938 .33888 L 0 .031 .131 r
F
.75635 .34001 m .75501 .3383 L .75804 .33717 L F
.30387 .34002 m .30488 .33711 L .30666 .33909 L 0 .03 .131 r
F
.30387 .34002 m .30208 .33803 L .30488 .33711 L F
.76376 .33962 m .76547 .33692 L .76681 .33866 L 0 .03 .13 r
F
.76376 .33962 m .76243 .3379 L .76547 .33692 L F
.59941 .35628 m .60086 .35336 L .60236 .35479 L 0 .072 .173 r
F
.59941 .35628 m .59791 .35487 L .60086 .35336 L F
.74895 .34048 m .75062 .33759 L .75198 .33943 L 0 .032 .132 r
F
.74895 .34048 m .74759 .33865 L .75062 .33759 L F
.58617 .36206 m .58759 .35874 L .5891 .36008 L 0 .09 .188 r
F
.58617 .36206 m .58466 .36078 L .58759 .35874 L F
.62747 .34974 m .62896 .34674 L .63044 .34861 L 0 .054 .156 r
F
.62747 .34974 m .62599 .3479 L .62896 .34674 L F
.84977 .33741 m .85161 .33467 L .85287 .33649 L 0 .026 .124 r
F
.84977 .33741 m .84852 .33562 L .85161 .33467 L F
.17473 .33722 m .17554 .33439 L .17746 .33623 L 0 .025 .124 r
F
.17473 .33722 m .17281 .33539 L .17554 .33439 L F
.55884 .4063 m .55738 .41318 L .56025 .40507 L 0 .309 .307 r
F
.55596 .41287 m .55738 .41318 L .55884 .4063 L 0 .335 .295 r
F
.23559 .33891 m .2365 .33592 L .23836 .33785 L 0 .028 .128 r
F
.23559 .33891 m .23373 .33696 L .2365 .33592 L F
.27713 .33912 m .2781 .33626 L .27992 .33816 L 0 .029 .129 r
F
.27713 .33912 m .27531 .33721 L .2781 .33626 L F
.40784 .34698 m .40901 .34394 L .41069 .34609 L 0 .046 .149 r
F
.40784 .34698 m .40616 .34484 L .40901 .34394 L F
.65262 .34596 m .65415 .34292 L .6556 .34466 L 0 .044 .146 r
F
.65262 .34596 m .65117 .34426 L .65415 .34292 L F
.20886 .33795 m .20971 .3352 L .2116 .33704 L 0 .027 .126 r
F
.20886 .33795 m .20696 .33612 L .20971 .3352 L F
.62007 .3503 m .62154 .34727 L .62303 .34907 L 0 .055 .158 r
F
.62007 .3503 m .61858 .34856 L .62154 .34727 L F
.7786 .33899 m .78032 .33608 L .78165 .33795 L 0 .029 .128 r
F
.7786 .33899 m .77727 .33715 L .78032 .33608 L F
.77119 .3394 m .77289 .33647 L .77423 .33828 L 0 .029 .129 r
F
.77119 .3394 m .76985 .33761 L .77289 .33647 L F
.24299 .33861 m .24391 .33568 L .24576 .33754 L 0 .028 .127 r
F
.24299 .33861 m .24113 .33675 L .24391 .33568 L F
.45704 .35937 m .45826 .35709 L .45991 .35908 L 0 .084 .183 r
F
.45704 .35937 m .4554 .35739 L .45826 .35709 L F
.14058 .33679 m .14133 .33396 L .14328 .33584 L 0 .024 .123 r
F
.14058 .33679 m .13862 .33493 L .14133 .33396 L F
.64522 .34647 m .64674 .34373 L .64819 .34536 L 0 .046 .148 r
F
.64522 .34647 m .64376 .34489 L .64674 .34373 L F
.6926 .34139 m .6942 .33868 L .69561 .34042 L 0 .034 .135 r
F
.6926 .34139 m .69119 .33967 L .6942 .33868 L F
.43165 .35085 m .43284 .34829 L .4345 .3504 L 0 .058 .16 r
F
.43165 .35085 m .42998 .34879 L .43284 .34829 L F
.31125 .34 m .31227 .33706 L .31406 .33898 L 0 .031 .131 r
F
.31125 .34 m .30947 .33808 L .31227 .33706 L F
.18211 .33715 m .18292 .33434 L .18483 .33622 L 0 .025 .124 r
F
.18211 .33715 m .18019 .33529 L .18292 .33434 L F
.47659 .37354 m .47784 .3721 L .47943 .37669 L 0 .141 .223 r
F
.47659 .37354 m .475 .36978 L .47784 .3721 L F
.78603 .33881 m .78776 .3359 L .78908 .33781 L 0 .029 .128 r
F
.78603 .33881 m .7847 .33693 L .78776 .3359 L F
.85722 .33739 m .85907 .33458 L .86032 .33642 L 0 .026 .125 r
F
.85722 .33739 m .85597 .33556 L .85907 .33458 L F
.35729 .34253 m .35838 .33962 L .36012 .34148 L 0 .037 .138 r
F
.35729 .34253 m .35554 .34071 L .35838 .33962 L F
.28452 .33905 m .2855 .33613 L .28731 .338 L 0 .029 .129 r
F
.28452 .33905 m .2827 .3372 L .2855 .33613 L F
.25038 .33844 m .2513 .33559 L .25314 .33749 L 0 .028 .127 r
F
.25038 .33844 m .24853 .33657 L .2513 .33559 L F
.79345 .33853 m .7952 .33574 L .79651 .33748 L 0 .028 .128 r
F
.79345 .33853 m .79214 .33677 L .7952 .33574 L F
.3766 .34408 m .37773 .341 L .37944 .34313 L 0 .04 .142 r
F
.3766 .34408 m .37489 .34194 L .37773 .341 L F
.80827 .33771 m .81005 .33494 L .81134 .33674 L 0 .027 .126 r
F
.80827 .33771 m .80697 .33592 L .81005 .33494 L F
.80086 .33813 m .80262 .33527 L .80392 .33703 L 0 .027 .127 r
F
.80086 .33813 m .79956 .33639 L .80262 .33527 L F
.33797 .34122 m .33903 .33827 L .34078 .34028 L 0 .034 .135 r
F
.33797 .34122 m .33621 .33924 L .33903 .33827 L F
.14794 .33672 m .14873 .33378 L .15067 .33566 L 0 .025 .123 r
F
.14794 .33672 m .146 .33484 L .14873 .33378 L F
.21623 .33796 m .2171 .33504 L .21898 .33691 L 0 .027 .126 r
F
.21623 .33796 m .21434 .33612 L .2171 .33504 L F
.29192 .33879 m .29291 .33584 L .29471 .33775 L 0 .029 .128 r
F
.29192 .33879 m .29011 .33691 L .29291 .33584 L F
.70003 .34127 m .70162 .33835 L .70303 .3402 L 0 .034 .135 r
F
.70003 .34127 m .69862 .33945 L .70162 .33835 L F
.6852 .3421 m .68678 .33915 L .68819 .34084 L 0 .036 .137 r
F
.6852 .3421 m .68379 .34044 L .68678 .33915 L F
.31864 .33985 m .31966 .33714 L .32144 .33897 L 0 .031 .132 r
F
.31864 .33985 m .31686 .33805 L .31966 .33714 L F
.56735 .38631 m .56586 .38862 L .56874 .38257 L 0 .191 .252 r
F
.5645 .39427 m .56586 .38862 L .56735 .38631 L 0 .241 .277 r
F
.36469 .34236 m .36579 .3395 L .36752 .34148 L 0 .037 .138 r
F
.36469 .34236 m .36296 .34042 L .36579 .3395 L F
.45253 .35757 m .45375 .35531 L .4554 .35739 L 0 .079 .179 r
F
.45253 .35757 m .45089 .35548 L .45375 .35531 L F
.70744 .34093 m .70905 .33796 L .71045 .33984 L 0 .033 .134 r
F
.70744 .34093 m .70604 .33907 L .70905 .33796 L F
.86466 .33724 m .86652 .33446 L .86776 .33626 L 0 .026 .125 r
F
.86466 .33724 m .86342 .33544 L .86652 .33446 L F
.5891 .36008 m .59053 .35693 L .59204 .3583 L 0 .085 .184 r
F
.5891 .36008 m .58759 .35874 L .59053 .35693 L F
.15533 .33651 m .15611 .33365 L .15805 .33556 L 0 .025 .123 r
F
.15533 .33651 m .1534 .33461 L .15611 .33365 L F
.41523 .34721 m .4164 .34454 L .41808 .34657 L 0 .049 .151 r
F
.41523 .34721 m .41355 .3452 L .4164 .34454 L F
.22362 .33776 m .2245 .33487 L .22637 .33679 L 0 .027 .126 r
F
.22362 .33776 m .22175 .33586 L .2245 .33487 L F
.71486 .34064 m .71649 .33789 L .71788 .33968 L 0 .033 .134 r
F
.71486 .34064 m .71347 .33887 L .71649 .33789 L F
.25776 .33841 m .2587 .33545 L .26053 .33738 L 0 .028 .128 r
F
.25776 .33841 m .25592 .33649 L .2587 .33545 L F
.18947 .33718 m .1903 .33432 L .1922 .33622 L 0 .026 .125 r
F
.18947 .33718 m .18757 .33527 L .1903 .33432 L F
.81571 .3376 m .81749 .33475 L .81878 .3366 L 0 .027 .126 r
F
.81571 .3376 m .81442 .33577 L .81749 .33475 L F
.49822 .41801 m .49938 .43232 L .50101 .43146 L 0 .37 .27 r
F
.49822 .41801 m .49659 .4182 L .49938 .43232 L F
.61268 .35141 m .61414 .3482 L .61562 .34985 L 0 .059 .161 r
F
.61268 .35141 m .61119 .34983 L .61414 .3482 L F
.8721 .33704 m .87397 .3343 L .8752 .33606 L 0 .026 .125 r
F
.8721 .33704 m .87087 .33528 L .87397 .3343 L F
.63783 .34756 m .63934 .34462 L .64079 .34617 L 0 .049 .152 r
F
.63783 .34756 m .63637 .34604 L .63934 .34462 L F
.72228 .34037 m .72393 .33769 L .7253 .33936 L 0 .033 .134 r
F
.72228 .34037 m .7209 .3387 L .72393 .33769 L F
.384 .34408 m .38512 .34117 L .38684 .34309 L 0 .041 .143 r
F
.384 .34408 m .38228 .34218 L .38512 .34117 L F
.67781 .34287 m .67938 .34003 L .6808 .34173 L 0 .038 .14 r
F
.67781 .34287 m .67638 .34116 L .67938 .34003 L F
.7297 .34002 m .73135 .33724 L .73272 .33894 L 0 .032 .133 r
F
.7297 .34002 m .72833 .33835 L .73135 .33724 L F
.40331 .34559 m .40447 .34269 L .40616 .34484 L 0 .045 .147 r
F
.40331 .34559 m .40162 .34345 L .40447 .34269 L F
.42713 .3493 m .42831 .34689 L .42998 .34879 L 0 .055 .158 r
F
.42713 .3493 m .42545 .34742 L .42831 .34689 L F
.44803 .35567 m .44924 .35338 L .45089 .35548 L 0 .074 .175 r
F
.44803 .35567 m .44638 .35357 L .44924 .35338 L F
.82314 .33738 m .82492 .33443 L .82621 .33631 L 0 .026 .125 r
F
.82314 .33738 m .82185 .33552 L .82492 .33443 L F
.73711 .33964 m .73877 .33679 L .74014 .33863 L 0 .031 .132 r
F
.73711 .33964 m .73574 .33784 L .73877 .33679 L F
.29929 .33888 m .30029 .33605 L .30208 .33803 L 0 .03 .13 r
F
.29929 .33888 m .2975 .3369 L .30029 .33605 L F
.34535 .34137 m .34641 .33855 L .34816 .34058 L 0 .035 .136 r
F
.34535 .34137 m .3436 .33934 L .34641 .33855 L F
.87953 .33685 m .88142 .33415 L .88264 .33589 L 0 .026 .125 r
F
.87953 .33685 m .87831 .3351 L .88142 .33415 L F
.66299 .34384 m .66453 .34077 L .66597 .34267 L 0 .04 .142 r
F
.66299 .34384 m .66154 .34199 L .66453 .34077 L F
.6704 .34343 m .67195 .34034 L .67339 .3423 L 0 .039 .141 r
F
.6704 .34343 m .66896 .34149 L .67195 .34034 L F
.57161 .37654 m .57011 .37692 L .57299 .3715 L 0 .143 .224 r
F
.56874 .38257 m .57011 .37692 L .57161 .37654 L 0 .177 .244 r
F
.32602 .33996 m .32706 .33721 L .32883 .33909 L 0 .032 .133 r
F
.32602 .33996 m .32425 .33809 L .32706 .33721 L F
.26514 .33832 m .2661 .33531 L .26792 .33729 L 0 .028 .128 r
F
.26514 .33832 m .26332 .33635 L .2661 .33531 L F
.60236 .35479 m .60381 .35185 L .6053 .3533 L 0 .07 .171 r
F
.60236 .35479 m .60086 .35336 L .60381 .35185 L F
.46893 .3622 m .47017 .35991 L .47179 .36252 L 0 .096 .192 r
F
.46893 .3622 m .4673 .35995 L .47017 .35991 L F
.83057 .33713 m .83238 .33442 L .83366 .3362 L 0 .026 .125 r
F
.83057 .33713 m .82929 .33535 L .83238 .33442 L F
.3914 .34393 m .39254 .34105 L .39424 .34296 L 0 .041 .143 r
F
.3914 .34393 m .38969 .34207 L .39254 .34105 L F
.16269 .33655 m .16348 .33371 L .16541 .33561 L 0 .025 .124 r
F
.16269 .33655 m .16076 .33464 L .16348 .33371 L F
.19684 .33717 m .19769 .33426 L .19958 .33617 L 0 .026 .125 r
F
.19684 .33717 m .19494 .33526 L .19769 .33426 L F
.23098 .33785 m .23187 .33502 L .23373 .33696 L 0 .028 .127 r
F
.23098 .33785 m .22912 .33591 L .23187 .33502 L F
.74455 .33956 m .74622 .33677 L .74759 .33865 L 0 .031 .132 r
F
.74455 .33956 m .74318 .3377 L .74622 .33677 L F
.27253 .33822 m .2735 .33524 L .27531 .33721 L 0 .028 .128 r
F
.27253 .33822 m .27071 .33625 L .2735 .33524 L F
.37206 .34276 m .37318 .3398 L .37489 .34194 L 0 .038 .14 r
F
.37206 .34276 m .37034 .34065 L .37318 .3398 L F
.83801 .33701 m .83983 .3342 L .84109 .33595 L 0 .026 .125 r
F
.83801 .33701 m .83675 .33526 L .83983 .3342 L F
.75938 .33888 m .76109 .33618 L .76243 .3379 L 0 .03 .131 r
F
.75938 .33888 m .75804 .33717 L .76109 .33618 L F
.84543 .33663 m .84726 .33387 L .84852 .33562 L 0 .026 .125 r
F
.84543 .33663 m .84417 .33488 L .84726 .33387 L F
.6556 .34466 m .65712 .34154 L .65857 .34331 L 0 .043 .145 r
F
.6556 .34466 m .65415 .34292 L .65712 .34154 L F
.17007 .33645 m .17088 .33354 L .17281 .33539 L 0 .025 .124 r
F
.17007 .33645 m .16814 .33458 L .17088 .33354 L F
.20422 .33707 m .20507 .33423 L .20696 .33612 L 0 .026 .126 r
F
.20422 .33707 m .20233 .33517 L .20507 .33423 L F
.44352 .35393 m .44473 .35121 L .44638 .35357 L 0 .069 .17 r
F
.44352 .35393 m .44187 .35166 L .44473 .35121 L F
.475 .36978 m .47625 .3677 L .47784 .3721 L 0 .126 .214 r
F
.475 .36978 m .4734 .36614 L .47625 .3677 L F
.63044 .34861 m .63193 .34557 L .63341 .34747 L 0 .053 .155 r
F
.63044 .34861 m .62896 .34674 L .63193 .34557 L F
.59204 .3583 m .59347 .35512 L .59497 .35651 L 0 .081 .181 r
F
.59204 .3583 m .59053 .35693 L .59347 .35512 L F
.13591 .33589 m .13666 .33306 L .13862 .33493 L 0 .024 .123 r
F
.13591 .33589 m .13395 .33402 L .13666 .33306 L F
.62303 .34907 m .62451 .34605 L .62599 .3479 L 0 .054 .157 r
F
.62303 .34907 m .62154 .34727 L .62451 .34605 L F
.75198 .33943 m .75365 .33644 L .75501 .3383 L 0 .031 .132 r
F
.75198 .33943 m .75062 .33759 L .75365 .33644 L F
.76681 .33866 m .76852 .33587 L .76985 .33761 L 0 .03 .13 r
F
.76681 .33866 m .76547 .33692 L .76852 .33587 L F
.23836 .33785 m .23928 .33483 L .24113 .33675 L 0 .028 .128 r
F
.23836 .33785 m .2365 .33592 L .23928 .33483 L F
.30666 .33909 m .30768 .33612 L .30947 .33808 L 0 .031 .131 r
F
.30666 .33909 m .30488 .33711 L .30768 .33612 L F
.77423 .33828 m .77593 .33532 L .77727 .33715 L 0 .029 .129 r
F
.77423 .33828 m .77289 .33647 L .77593 .33532 L F
.46442 .36049 m .46567 .35769 L .4673 .35995 L 0 .09 .187 r
F
.46442 .36049 m .46279 .35839 L .46567 .35769 L F
.17746 .33623 m .17827 .33342 L .18019 .33529 L 0 .025 .124 r
F
.17746 .33623 m .17554 .33439 L .17827 .33342 L F
.3334 .34016 m .33445 .33728 L .33621 .33924 L 0 .033 .134 r
F
.3334 .34016 m .33163 .33823 L .33445 .33728 L F
.35272 .34161 m .3538 .33888 L .35554 .34071 L 0 .037 .138 r
F
.35272 .34161 m .35097 .3398 L .3538 .33888 L F
.85287 .33649 m .85471 .33372 L .85597 .33556 L 0 .026 .125 r
F
.85287 .33649 m .85161 .33467 L .85471 .33372 L F
.78165 .33795 m .78337 .33503 L .7847 .33693 L 0 .028 .128 r
F
.78165 .33795 m .78032 .33608 L .78337 .33503 L F
.24576 .33754 m .24668 .33468 L .24853 .33657 L 0 .028 .127 r
F
.24576 .33754 m .24391 .33568 L .24668 .33468 L F
.27992 .33816 m .28088 .33531 L .2827 .3372 L 0 .029 .129 r
F
.27992 .33816 m .2781 .33626 L .28088 .33531 L F
.64819 .34536 m .64972 .34258 L .65117 .34426 L 0 .045 .148 r
F
.64819 .34536 m .64674 .34373 L .64972 .34258 L F
.39878 .34415 m .39993 .34149 L .40162 .34345 L 0 .043 .145 r
F
.39878 .34415 m .39708 .34222 L .39993 .34149 L F
.56311 .39785 m .56164 .40234 L .5645 .39427 L 0 .257 .285 r
F
.56025 .40507 m .56164 .40234 L .56311 .39785 L 0 .312 .306 r
F
.42261 .34791 m .42378 .34553 L .42545 .34742 L 0 .053 .155 r
F
.42261 .34791 m .42092 .34605 L .42378 .34553 L F
.2116 .33704 m .21245 .33427 L .21434 .33612 L 0 .027 .126 r
F
.2116 .33704 m .20971 .3352 L .21245 .33427 L F
.41069 .34609 m .41187 .34304 L .41355 .3452 L 0 .047 .149 r
F
.41069 .34609 m .40901 .34394 L .41187 .34304 L F
.14328 .33584 m .14405 .33296 L .146 .33484 L 0 .025 .123 r
F
.14328 .33584 m .14133 .33396 L .14405 .33296 L F
.43901 .35211 m .44022 .34934 L .44187 .35166 L 0 .064 .166 r
F
.43901 .35211 m .43736 .34989 L .44022 .34934 L F
.61562 .34985 m .61709 .34684 L .61858 .34856 L 0 .057 .159 r
F
.61562 .34985 m .61414 .3482 L .61709 .34684 L F
.31406 .33898 m .31508 .33614 L .31686 .33805 L 0 .031 .131 r
F
.31406 .33898 m .31227 .33706 L .31508 .33614 L F
.69561 .34042 m .69721 .33768 L .69862 .33945 L 0 .034 .135 r
F
.69561 .34042 m .6942 .33868 L .69721 .33768 L F
.68819 .34084 m .68978 .33796 L .69119 .33967 L 0 .035 .136 r
F
.68819 .34084 m .68678 .33915 L .68978 .33796 L F
.36012 .34148 m .36122 .33853 L .36296 .34042 L 0 .036 .138 r
F
.36012 .34148 m .35838 .33962 L .36122 .33853 L F
.28731 .338 m .2883 .33502 L .29011 .33691 L 0 .029 .129 r
F
.28731 .338 m .2855 .33613 L .2883 .33502 L F
.78908 .33781 m .79081 .33486 L .79214 .33677 L 0 .028 .128 r
F
.78908 .33781 m .78776 .3359 L .79081 .33486 L F
.51778 .43326 m .51907 .4521 L .52068 .44115 L 0 .42 .216 r
F
.51778 .43326 m .51616 .44226 L .51907 .4521 L F
.80392 .33703 m .80567 .33414 L .80697 .33592 L 0 .027 .126 r
F
.80392 .33703 m .80262 .33527 L .80567 .33414 L F
.86032 .33642 m .86217 .33359 L .86342 .33544 L 0 .026 .125 r
F
.86032 .33642 m .85907 .33458 L .86217 .33359 L F
.18483 .33622 m .18566 .33339 L .18757 .33527 L 0 .026 .124 r
F
.18483 .33622 m .18292 .33434 L .18566 .33339 L F
.79651 .33748 m .79826 .33464 L .79956 .33639 L 0 .028 .128 r
F
.79651 .33748 m .7952 .33574 L .79826 .33464 L F
.25314 .33749 m .25408 .33457 L .25592 .33649 L F
.25314 .33749 m .2513 .33559 L .25408 .33457 L F
.15067 .33566 m .15145 .33272 L .1534 .33461 L 0 .024 .123 r
F
.15067 .33566 m .14873 .33378 L .15145 .33272 L F
.70303 .3402 m .70463 .3372 L .70604 .33907 L 0 .034 .135 r
F
.70303 .3402 m .70162 .33835 L .70463 .3372 L F
.21898 .33691 m .21987 .33396 L .22175 .33586 L 0 .027 .126 r
F
.21898 .33691 m .2171 .33504 L .21987 .33396 L F
.64079 .34617 m .64231 .3433 L .64376 .34489 L 0 .048 .15 r
F
.64079 .34617 m .63934 .34462 L .64231 .3433 L F
.29471 .33775 m .2957 .33497 L .2975 .3369 L 0 .029 .129 r
F
.29471 .33775 m .29291 .33584 L .2957 .33497 L F
.81134 .33674 m .81312 .33396 L .81442 .33577 L 0 .027 .126 r
F
.81134 .33674 m .81005 .33494 L .81312 .33396 L F
.37944 .34313 m .38057 .34006 L .38228 .34218 L 0 .04 .142 r
F
.37944 .34313 m .37773 .341 L .38057 .34006 L F
.71045 .33984 m .71207 .33697 L .71347 .33887 L 0 .033 .134 r
F
.71045 .33984 m .70905 .33796 L .71207 .33697 L F
.34078 .34028 m .34185 .33731 L .3436 .33934 L 0 .034 .135 r
F
.34078 .34028 m .33903 .33827 L .34185 .33731 L F
.6053 .3533 m .60675 .35007 L .60824 .35157 L 0 .067 .169 r
F
.6053 .3533 m .60381 .35185 L .60675 .35007 L F
.86776 .33626 m .86963 .33347 L .87087 .33528 L 0 .026 .125 r
F
.86776 .33626 m .86652 .33446 L .86963 .33347 L F
.32144 .33897 m .32247 .33623 L .32425 .33809 L 0 .032 .132 r
F
.32144 .33897 m .31966 .33714 L .32247 .33623 L F
.36752 .34148 m .36862 .33862 L .37034 .34065 L 0 .037 .139 r
F
.36752 .34148 m .36579 .3395 L .36862 .33862 L F
.59497 .35651 m .59641 .35347 L .59791 .35487 L 0 .077 .177 r
F
.59497 .35651 m .59347 .35512 L .59641 .35347 L F
.26053 .33738 m .26148 .33441 L .26332 .33635 L 0 .028 .128 r
F
.26053 .33738 m .2587 .33545 L .26148 .33441 L F
.22637 .33679 m .22726 .33396 L .22912 .33591 L 0 .027 .126 r
F
.22637 .33679 m .2245 .33487 L .22726 .33396 L F
.15805 .33556 m .15883 .33274 L .16076 .33464 L 0 .025 .123 r
F
.15805 .33556 m .15611 .33365 L .15883 .33274 L F
.49054 .40755 m .49175 .41286 L .49335 .41661 L 0 .328 .299 r
F
.49054 .40755 m .48894 .40428 L .49175 .41286 L F
.6808 .34173 m .68237 .33872 L .68379 .34044 L 0 .037 .139 r
F
.6808 .34173 m .67938 .34003 L .68237 .33872 L F
.71788 .33968 m .71952 .33691 L .7209 .3387 L 0 .033 .134 r
F
.71788 .33968 m .71649 .33789 L .71952 .33691 L F
.81878 .3366 m .82056 .33365 L .82185 .33552 L 0 .027 .126 r
F
.81878 .3366 m .81749 .33475 L .82056 .33365 L F
.4345 .3504 m .4357 .34772 L .43736 .34989 L 0 .06 .162 r
F
.4345 .3504 m .43284 .34829 L .4357 .34772 L F
.1922 .33622 m .19304 .33335 L .19494 .33526 L 0 .026 .125 r
F
.1922 .33622 m .1903 .33432 L .19304 .33335 L F
.45991 .35908 m .46115 .35631 L .46279 .35839 L 0 .087 .185 r
F
.45991 .35908 m .45826 .35709 L .46115 .35631 L F
.73272 .33894 m .73437 .33611 L .73574 .33784 L 0 .032 .132 r
F
.73272 .33894 m .73135 .33724 L .73437 .33611 L F
.8752 .33606 m .87708 .33334 L .87831 .3351 L 0 .026 .125 r
F
.8752 .33606 m .87397 .3343 L .87708 .33334 L F
.7253 .33936 m .72695 .33669 L .72833 .33835 L 0 .033 .134 r
F
.7253 .33936 m .72393 .33769 L .72695 .33669 L F
.66597 .34267 m .66751 .33954 L .66896 .34149 L 0 .039 .141 r
F
.66597 .34267 m .66453 .34077 L .66751 .33954 L F
.38684 .34309 m .38797 .34013 L .38969 .34207 L 0 .041 .143 r
F
.38684 .34309 m .38512 .34117 L .38797 .34013 L F
.82621 .33631 m .82801 .33345 L .82929 .33535 L 0 .026 .125 r
F
.82621 .33631 m .82492 .33443 L .82801 .33345 L F
.67339 .3423 m .67494 .33921 L .67638 .34116 L 0 .039 .14 r
F
.67339 .3423 m .67195 .34034 L .67494 .33921 L F
.74014 .33863 m .74181 .33584 L .74318 .3377 L 0 .031 .132 r
F
.74014 .33863 m .73877 .33679 L .74181 .33584 L F
.57881 .3652 m .58021 .36131 L .58173 .36288 L 0 .105 .199 r
F
.57881 .3652 m .57729 .36382 L .58021 .36131 L F
.5759 .36835 m .57729 .36382 L .57881 .3652 L 0 .117 .207 r
F
.26792 .33729 m .26889 .33427 L .27071 .33625 L 0 .028 .128 r
F
.26792 .33729 m .2661 .33531 L .26889 .33427 L F
.41808 .34657 m .41925 .34398 L .42092 .34605 L 0 .05 .153 r
F
.41808 .34657 m .4164 .34454 L .41925 .34398 L F
.88264 .33589 m .88454 .33319 L .88576 .33493 L 0 .026 .125 r
F
.88264 .33589 m .88142 .33415 L .88454 .33319 L F
.50878 .42949 m .51 .44666 L .51164 .43963 L 0 .408 .231 r
F
.50878 .42949 m .50714 .43487 L .51 .44666 L F
.4734 .36614 m .47466 .36333 L .47625 .3677 L 0 .113 .204 r
F
.4734 .36614 m .47179 .36252 L .47466 .36333 L F
.65857 .34331 m .6601 .34018 L .66154 .34199 L 0 .041 .143 r
F
.65857 .34331 m .65712 .34154 L .6601 .34018 L F
.39424 .34296 m .39538 .34029 L .39708 .34222 L 0 .041 .144 r
F
.39424 .34296 m .39254 .34105 L .39538 .34029 L F
.19958 .33617 m .20044 .33327 L .20233 .33517 L 0 .026 .125 r
F
.19958 .33617 m .19769 .33426 L .20044 .33327 L F
.30208 .33803 m .30309 .33514 L .30488 .33711 L 0 .03 .13 r
F
.30208 .33803 m .30029 .33605 L .30309 .33514 L F
.40616 .34484 m .40733 .34178 L .40901 .34394 L 0 .045 .148 r
F
.40616 .34484 m .40447 .34269 L .40733 .34178 L F
.83366 .3362 m .83548 .33348 L .83675 .33526 L 0 .027 .126 r
F
.83366 .3362 m .83238 .33442 L .83548 .33348 L F
.32883 .33909 m .32987 .33633 L .33163 .33823 L 0 .033 .133 r
F
.32883 .33909 m .32706 .33721 L .32987 .33633 L F
.16541 .33561 m .16621 .3327 L .16814 .33458 L 0 .025 .124 r
F
.16541 .33561 m .16348 .33371 L .16621 .3327 L F
.34816 .34058 m .34923 .33776 L .35097 .3398 L 0 .036 .137 r
F
.34816 .34058 m .34641 .33855 L .34923 .33776 L F
.58173 .36288 m .58314 .3591 L .58466 .36078 L 0 .098 .194 r
F
.58173 .36288 m .58021 .36131 L .58314 .3591 L F
.23373 .33696 m .23465 .33398 L .2365 .33592 L 0 .028 .127 r
F
.23373 .33696 m .23187 .33502 L .23465 .33398 L F
.84109 .33595 m .84291 .33314 L .84417 .33488 L 0 .026 .125 r
F
.84109 .33595 m .83983 .3342 L .84291 .33314 L F
.63341 .34747 m .63489 .34413 L .63637 .34604 L 0 .052 .154 r
F
.63341 .34747 m .63193 .34557 L .63489 .34413 L F
.62599 .3479 m .62748 .34486 L .62896 .34674 L 0 .053 .156 r
F
.62599 .3479 m .62451 .34605 L .62748 .34486 L F
.27531 .33721 m .27628 .33431 L .2781 .33626 L 0 .029 .128 r
F
.27531 .33721 m .2735 .33524 L .27628 .33431 L F
.74759 .33865 m .74925 .33569 L .75062 .33759 L 0 .031 .132 r
F
.74759 .33865 m .74622 .33677 L .74925 .33569 L F
.4554 .35739 m .45662 .35502 L .45826 .35709 L 0 .083 .182 r
F
.4554 .35739 m .45375 .35531 L .45662 .35502 L F
.17281 .33539 m .17361 .33254 L .17554 .33439 L 0 .025 .124 r
F
.17281 .33539 m .17088 .33354 L .17361 .33254 L F
.75501 .3383 m .75668 .3353 L .75804 .33717 L 0 .031 .131 r
F
.75501 .3383 m .75365 .33644 L .75668 .3353 L F
.84852 .33562 m .85036 .3329 L .85161 .33467 L 0 .026 .125 r
F
.84852 .33562 m .84726 .33387 L .85036 .3329 L F
.42998 .34879 m .43117 .34636 L .43284 .34829 L 0 .057 .16 r
F
.42998 .34879 m .42831 .34689 L .43117 .34636 L F
.76243 .3379 m .76414 .33518 L .76547 .33692 L 0 .03 .131 r
F
.76243 .3379 m .76109 .33618 L .76414 .33518 L F
.5759 .36835 m .57438 .36743 L .57729 .36382 L 0 .117 .207 r
F
.57299 .3715 m .57438 .36743 L .5759 .36835 L 0 .132 .217 r
F
.20696 .33612 m .20782 .33332 L .20971 .3352 L 0 .027 .126 r
F
.20696 .33612 m .20507 .33423 L .20782 .33332 L F
.77727 .33715 m .77898 .33423 L .78032 .33608 L 0 .029 .128 r
F
.77727 .33715 m .77593 .33532 L .77898 .33423 L F
.24113 .33675 m .24206 .33376 L .24391 .33568 L 0 .028 .127 r
F
.24113 .33675 m .23928 .33483 L .24206 .33376 L F
.60824 .35157 m .6097 .34826 L .61119 .34983 L 0 .063 .165 r
F
.60824 .35157 m .60675 .35007 L .6097 .34826 L F
.13862 .33493 m .13937 .3321 L .14133 .33396 L 0 .024 .123 r
F
.13862 .33493 m .13666 .33306 L .13937 .3321 L F
.76985 .33761 m .77156 .3347 L .77289 .33647 L 0 .03 .13 r
F
.76985 .33761 m .76852 .33587 L .77156 .3347 L F
.37489 .34194 m .37601 .33887 L .37773 .341 L 0 .039 .141 r
F
.37489 .34194 m .37318 .3398 L .37601 .33887 L F
.61858 .34856 m .62006 .34547 L .62154 .34727 L 0 .056 .158 r
F
.61858 .34856 m .61709 .34684 L .62006 .34547 L F
.30947 .33808 m .31049 .33512 L .31227 .33706 L 0 .031 .131 r
F
.30947 .33808 m .30768 .33612 L .31049 .33512 L F
.65117 .34426 m .65269 .34121 L .65415 .34292 L 0 .045 .147 r
F
.65117 .34426 m .64972 .34258 L .65269 .34121 L F
.7847 .33693 m .78642 .33398 L .78776 .3359 L 0 .028 .128 r
F
.7847 .33693 m .78337 .33503 L .78642 .33398 L F
.18019 .33529 m .18101 .33246 L .18292 .33434 L 0 .025 .124 r
F
.18019 .33529 m .17827 .33342 L .18101 .33246 L F
.45089 .35548 m .4521 .35322 L .45375 .35531 L 0 .078 .178 r
F
.45089 .35548 m .44924 .35338 L .4521 .35322 L F
.59791 .35487 m .59936 .35194 L .60086 .35336 L 0 .074 .175 r
F
.59791 .35487 m .59641 .35347 L .59936 .35194 L F
.33621 .33924 m .33727 .33628 L .33903 .33827 L 0 .033 .134 r
F
.33621 .33924 m .33445 .33728 L .33727 .33628 L F
.24853 .33657 m .24946 .33369 L .2513 .33559 L 0 .028 .127 r
F
.24853 .33657 m .24668 .33468 L .24946 .33369 L F
.69119 .33967 m .69279 .33694 L .6942 .33868 L 0 .035 .136 r
F
.69119 .33967 m .68978 .33796 L .69279 .33694 L F
.2827 .3372 m .28368 .33425 L .2855 .33613 L 0 .029 .129 r
F
.2827 .3372 m .28088 .33531 L .28368 .33425 L F
.85597 .33556 m .85781 .33274 L .85907 .33458 L 0 .026 .125 r
F
.85597 .33556 m .85471 .33372 L .85781 .33274 L F
.35554 .34071 m .35663 .33775 L .35838 .33962 L 0 .037 .138 r
F
.35554 .34071 m .3538 .33888 L .35663 .33775 L F
.51327 .4325 m .51453 .45134 L .51616 .44226 L 0 .42 .216 r
F
.51327 .4325 m .51164 .43963 L .51453 .45134 L F
.64376 .34489 m .64528 .3421 L .64674 .34373 L 0 .047 .149 r
F
.64376 .34489 m .64231 .3433 L .64528 .3421 L F
.146 .33484 m .14678 .33189 L .14873 .33378 L 0 .024 .123 r
F
.146 .33484 m .14405 .33296 L .14678 .33189 L F
.29011 .33691 m .29111 .33392 L .29291 .33584 L 0 .028 .128 r
F
.29011 .33691 m .2883 .33502 L .29111 .33392 L F
.58466 .36078 m .58607 .35695 L .58759 .35874 L 0 .092 .189 r
F
.58466 .36078 m .58314 .3591 L .58607 .35695 L F
.36296 .34042 m .36405 .33756 L .36579 .3395 L 0 .036 .138 r
F
.36296 .34042 m .36122 .33853 L .36405 .33756 L F
.57299 .3715 m .57147 .37104 L .57438 .36743 L 0 .132 .217 r
F
.57011 .37692 m .57147 .37104 L .57299 .3715 L 0 .156 .232 r
F
.21434 .33612 m .21522 .33317 L .2171 .33504 L 0 .027 .126 r
F
.21434 .33612 m .21245 .33427 L .21522 .33317 L F
.80697 .33592 m .80875 .33316 L .81005 .33494 L F
.80697 .33592 m .80567 .33414 L .80875 .33316 L F
.41355 .3452 m .41472 .34234 L .4164 .34454 L 0 .048 .15 r
F
.41355 .3452 m .41187 .34304 L .41472 .34234 L F
.79214 .33677 m .79388 .33382 L .7952 .33574 L 0 .028 .128 r
F
.79214 .33677 m .79081 .33486 L .79388 .33382 L F
.69862 .33945 m .70022 .33655 L .70162 .33835 L 0 .034 .135 r
F
.69862 .33945 m .69721 .33768 L .70022 .33655 L F
.79956 .33639 m .80131 .3335 L .80262 .33527 L 0 .028 .127 r
F
.79956 .33639 m .79826 .33464 L .80131 .3335 L F
.70604 .33907 m .70764 .33608 L .70905 .33796 L 0 .033 .134 r
F
.70604 .33907 m .70463 .3372 L .70764 .33608 L F
.31686 .33805 m .31788 .33522 L .31966 .33714 L 0 .031 .132 r
F
.31686 .33805 m .31508 .33614 L .31788 .33522 L F
.40162 .34345 m .40277 .34072 L .40447 .34269 L 0 .044 .146 r
F
.40162 .34345 m .39993 .34149 L .40277 .34072 L F
.1534 .33461 m .15417 .33176 L .15611 .33365 L 0 .024 .123 r
F
.1534 .33461 m .15145 .33272 L .15417 .33176 L F
.86342 .33544 m .86527 .3326 L .86652 .33446 L 0 .026 .125 r
F
.86342 .33544 m .86217 .33359 L .86527 .3326 L F
.22175 .33586 m .22263 .33295 L .2245 .33487 L 0 .027 .126 r
F
.22175 .33586 m .21987 .33396 L .22263 .33295 L F
.44638 .35357 m .4476 .35095 L .44924 .35338 L 0 .072 .173 r
F
.44638 .35357 m .44473 .35121 L .4476 .35095 L F
.4673 .35995 m .46855 .3573 L .47017 .35991 L 0 .093 .19 r
F
.4673 .35995 m .46567 .35769 L .46855 .3573 L F
.25592 .33649 m .25686 .33352 L .2587 .33545 L 0 .028 .127 r
F
.25592 .33649 m .25408 .33457 L .25686 .33352 L F
.18757 .33527 m .1884 .33243 L .1903 .33432 L 0 .026 .125 r
F
.18757 .33527 m .18566 .33339 L .1884 .33243 L F
.55596 .41287 m .5545 .42132 L .55738 .41318 L 0 .335 .295 r
F
.55308 .41946 m .5545 .42132 L .55596 .41287 L 0 .361 .277 r
F
.68379 .34044 m .68536 .33742 L .68678 .33915 L 0 .036 .138 r
F
.68379 .34044 m .68237 .33872 L .68536 .33742 L F
.81442 .33577 m .8162 .33293 L .81749 .33475 L 0 .027 .126 r
F
.81442 .33577 m .81312 .33396 L .8162 .33293 L F
.71347 .33887 m .71509 .33597 L .71649 .33789 L 0 .033 .134 r
F
.71347 .33887 m .71207 .33697 L .71509 .33597 L F
.38228 .34218 m .38342 .33906 L .38512 .34117 L 0 .04 .142 r
F
.38228 .34218 m .38057 .34006 L .38342 .33906 L F
.3436 .33934 m .34466 .33652 L .34641 .33855 L 0 .034 .135 r
F
.3436 .33934 m .34185 .33731 L .34466 .33652 L F
.2975 .3369 m .29849 .3341 L .30029 .33605 L 0 .029 .129 r
F
.2975 .3369 m .2957 .33497 L .29849 .3341 L F
.42545 .34742 m .42663 .34498 L .42831 .34689 L 0 .055 .157 r
F
.42545 .34742 m .42378 .34553 L .42663 .34498 L F
.87087 .33528 m .87274 .33249 L .87397 .3343 L 0 .026 .125 r
F
.87087 .33528 m .86963 .33347 L .87274 .33249 L F
.82185 .33552 m .82363 .33254 L .82492 .33443 L F
.82185 .33552 m .82056 .33365 L .82363 .33254 L F
.66896 .34149 m .67051 .33837 L .67195 .34034 L 0 .039 .141 r
F
.66896 .34149 m .66751 .33954 L .67051 .33837 L F
.26332 .33635 m .26427 .33336 L .2661 .33531 L 0 .028 .127 r
F
.26332 .33635 m .26148 .33441 L .26427 .33336 L F
.48894 .40428 m .49015 .4091 L .49175 .41286 L 0 .321 .302 r
F
.48894 .40428 m .48822 .4028 L .49015 .4091 L F
.48822 .4028 m .48894 .40559 L .49015 .4091 L F
.48822 .4028 m .48734 .401 L .48894 .40559 L F
.48986 .40826 m .48857 .40343 L .49015 .4091 L 0 .311 .307 r
F
.48734 .401 m .48857 .40343 L .48986 .40826 L F
.48576 .39631 m .48699 .39752 L .48857 .40343 L 0 .282 .297 r
F
.48857 .40343 m .48699 .39752 L .48728 .3986 L 0 .337 .294 r
F
.48734 .401 m .48694 .39981 L .48857 .40343 L 0 .311 .307 r
F
.48694 .39981 m .48576 .39631 L .48738 .40042 L F
.48694 .39981 m .48738 .40042 L .48857 .40343 L F
.48699 .39752 m .48821 .40073 L .48846 .40192 L 0 .317 .304 r
F
.48857 .40343 m .48728 .3986 L .48978 .40813 L 0 .337 .294 r
F
.48797 .40123 m .48846 .40192 L .48978 .40813 L 0 .317 .304 r
F
.48699 .39752 m .48846 .40192 L .48797 .40123 L F
.49015 .4091 m .48857 .40343 L .49135 .41552 L 0 .356 .281 r
F
.48857 .40343 m .48978 .40813 L .49075 .41269 L 0 .337 .294 r
F
.49024 .41072 m .49075 .41269 L .49135 .41552 L F
.48857 .40343 m .49075 .41269 L .49024 .41072 L F
.47179 .36252 m .47305 .36023 L .47466 .36333 L 0 .104 .198 r
F
.47179 .36252 m .47017 .35991 L .47305 .36023 L F
.73574 .33784 m .7374 .33502 L .73877 .33679 L 0 .031 .132 r
F
.73574 .33784 m .73437 .33611 L .7374 .33502 L F
.67638 .34116 m .67794 .33807 L .67938 .34003 L 0 .038 .14 r
F
.67638 .34116 m .67494 .33921 L .67794 .33807 L F
.44187 .35166 m .44309 .34878 L .44473 .35121 L 0 .066 .168 r
F
.44187 .35166 m .44022 .34934 L .44309 .34878 L F
.7209 .3387 m .72254 .3359 L .72393 .33769 L 0 .033 .134 r
F
.7209 .3387 m .71952 .33691 L .72254 .3359 L F
.66154 .34199 m .66308 .3389 L .66453 .34077 L 0 .04 .142 r
F
.66154 .34199 m .6601 .34018 L .66308 .3389 L F
.32425 .33809 m .32528 .33533 L .32706 .33721 L 0 .032 .133 r
F
.32425 .33809 m .32247 .33623 L .32528 .33533 L F
.61119 .34983 m .61265 .34657 L .61414 .3482 L 0 .06 .162 r
F
.61119 .34983 m .6097 .34826 L .61265 .34657 L F
.19494 .33526 m .19579 .33235 L .19769 .33426 L 0 .026 .125 r
F
.19494 .33526 m .19304 .33335 L .19579 .33235 L F
.16076 .33464 m .16155 .33181 L .16348 .33371 L 0 .025 .124 r
F
.16076 .33464 m .15883 .33274 L .16155 .33181 L F
.72833 .33835 m .72998 .33553 L .73135 .33724 L 0 .033 .133 r
F
.72833 .33835 m .72695 .33669 L .72998 .33553 L F
.58759 .35874 m .58901 .35512 L .59053 .35693 L 0 .087 .185 r
F
.58759 .35874 m .58607 .35695 L .58901 .35512 L F
.38969 .34207 m .39083 .33908 L .39254 .34105 L 0 .041 .143 r
F
.38969 .34207 m .38797 .34013 L .39083 .33908 L F
.22912 .33591 m .23001 .33306 L .23187 .33502 L 0 .027 .127 r
F
.22912 .33591 m .22726 .33396 L .23001 .33306 L F
.37034 .34065 m .37145 .33772 L .37318 .3398 L 0 .038 .139 r
F
.37034 .34065 m .36862 .33862 L .37145 .33772 L F
.87831 .3351 m .8802 .3324 L .88142 .33415 L 0 .026 .125 r
F
.87831 .3351 m .87708 .33334 L .8802 .3324 L F
.63637 .34604 m .63786 .34269 L .63934 .34462 L 0 .05 .152 r
F
.63637 .34604 m .63489 .34413 L .63786 .34269 L F
.82929 .33535 m .8311 .33252 L .83238 .33442 L 0 .026 .126 r
F
.82929 .33535 m .82801 .33345 L .8311 .33252 L F
.27071 .33625 m .27168 .33328 L .2735 .33524 L 0 .028 .128 r
F
.27071 .33625 m .26889 .33427 L .27168 .33328 L F
.74318 .3377 m .74485 .3349 L .74622 .33677 L 0 .031 .132 r
F
.74318 .3377 m .74181 .33584 L .74485 .3349 L F
.56874 .38257 m .56724 .38392 L .57011 .37692 L 0 .177 .244 r
F
.56586 .38862 m .56724 .38392 L .56874 .38257 L 0 .22 .267 r
F
.46279 .35839 m .46403 .35552 L .46567 .35769 L 0 .088 .186 r
F
.46279 .35839 m .46115 .35631 L .46403 .35552 L F
.20233 .33517 m .20318 .33234 L .20507 .33423 L 0 .026 .125 r
F
.20233 .33517 m .20044 .33327 L .20318 .33234 L F
.16814 .33458 m .16895 .33169 L .17088 .33354 L 0 .025 .124 r
F
.16814 .33458 m .16621 .3327 L .16895 .33169 L F
.62896 .34674 m .63045 .34365 L .63193 .34557 L 0 .053 .155 r
F
.62896 .34674 m .62748 .34486 L .63045 .34365 L F
.13395 .33402 m .1347 .33119 L .13666 .33306 L 0 .024 .123 r
F
.13395 .33402 m .13199 .33213 L .1347 .33119 L F
.60086 .35336 m .60231 .3504 L .60381 .35185 L 0 .072 .173 r
F
.60086 .35336 m .59936 .35194 L .60231 .3504 L F
.30488 .33711 m .30589 .33416 L .30768 .33612 L 0 .03 .13 r
F
.30488 .33711 m .30309 .33514 L .30589 .33416 L F
.83675 .33526 m .83856 .33243 L .83983 .3342 L 0 .027 .126 r
F
.83675 .33526 m .83548 .33348 L .83856 .33243 L F
.43736 .34989 m .43856 .34706 L .44022 .34934 L 0 .062 .164 r
F
.43736 .34989 m .4357 .34772 L .43856 .34706 L F
.40901 .34394 m .41018 .34088 L .41187 .34304 L 0 .046 .148 r
F
.40901 .34394 m .40733 .34178 L .41018 .34088 L F
.84417 .33488 m .846 .33212 L .84726 .33387 L 0 .026 .125 r
F
.84417 .33488 m .84291 .33314 L .846 .33212 L F
.2365 .33592 m .23742 .33291 L .23928 .33483 L 0 .028 .127 r
F
.2365 .33592 m .23465 .33398 L .23742 .33291 L F
.65415 .34292 m .65567 .33979 L .65712 .34154 L 0 .043 .145 r
F
.65415 .34292 m .65269 .34121 L .65567 .33979 L F
.75804 .33717 m .75973 .3343 L .76109 .33618 L 0 .031 .131 r
F
.75804 .33717 m .75668 .3353 L .75973 .3343 L F
.75062 .33759 m .75229 .33453 L .75365 .33644 L 0 .031 .132 r
F
.75062 .33759 m .74925 .33569 L .75229 .33453 L F
.62154 .34727 m .62302 .3442 L .62451 .34605 L 0 .054 .157 r
F
.62154 .34727 m .62006 .34547 L .62302 .3442 L F
.33163 .33823 m .33268 .33535 L .33445 .33728 L 0 .033 .134 r
F
.33163 .33823 m .32987 .33633 L .33268 .33535 L F
.17554 .33439 m .17635 .33158 L .17827 .33342 L 0 .025 .124 r
F
.17554 .33439 m .17361 .33254 L .17635 .33158 L F
.39708 .34222 m .39822 .33955 L .39993 .34149 L 0 .042 .145 r
F
.39708 .34222 m .39538 .34029 L .39822 .33955 L F
.2781 .33626 m .27907 .33338 L .28088 .33531 L 0 .029 .129 r
F
.2781 .33626 m .27628 .33431 L .27907 .33338 L F
.77289 .33647 m .7746 .33354 L .77593 .33532 L F
.77289 .33647 m .77156 .3347 L .7746 .33354 L F
.78032 .33608 m .78204 .33315 L .78337 .33503 L 0 .028 .128 r
F
.78032 .33608 m .77898 .33423 L .78204 .33315 L F
.24391 .33568 m .24483 .33277 L .24668 .33468 L 0 .028 .127 r
F
.24391 .33568 m .24206 .33376 L .24483 .33277 L F
.35097 .3398 m .35205 .33685 L .3538 .33888 L 0 .036 .138 r
F
.35097 .3398 m .34923 .33776 L .35205 .33685 L F
.76547 .33692 m .76718 .33411 L .76852 .33587 L 0 .03 .131 r
F
.76547 .33692 m .76414 .33518 L .76718 .33411 L F
.85161 .33467 m .85346 .33193 L .85471 .33372 L 0 .026 .125 r
F
.85161 .33467 m .85036 .3329 L .85346 .33193 L F
.42092 .34605 m .4221 .34342 L .42378 .34553 L 0 .052 .155 r
F
.42092 .34605 m .41925 .34398 L .4221 .34342 L F
.14133 .33396 m .14209 .3311 L .14405 .33296 L 0 .024 .123 r
F
.14133 .33396 m .13937 .3321 L .14209 .3311 L F
.20971 .3352 m .21057 .3324 L .21245 .33427 L 0 .027 .126 r
F
.20971 .3352 m .20782 .33332 L .21057 .3324 L F
.31227 .33706 m .31329 .3342 L .31508 .33614 L 0 .031 .131 r
F
.31227 .33706 m .31049 .33512 L .31329 .3342 L F
.37773 .341 m .37886 .33793 L .38057 .34006 L 0 .039 .141 r
F
.37773 .341 m .37601 .33887 L .37886 .33793 L F
.78776 .3359 m .78948 .33294 L .79081 .33486 L 0 .028 .128 r
F
.78776 .3359 m .78642 .33398 L .78948 .33294 L F
.64674 .34373 m .64827 .3409 L .64972 .34258 L 0 .046 .149 r
F
.64674 .34373 m .64528 .3421 L .64827 .3409 L F
.35838 .33962 m .35948 .33663 L .36122 .33853 L 0 .036 .138 r
F
.35838 .33962 m .35663 .33775 L .35948 .33663 L F
.2855 .33613 m .28649 .33314 L .2883 .33502 L 0 .029 .128 r
F
.2855 .33613 m .28368 .33425 L .28649 .33314 L F
.59053 .35693 m .59195 .35329 L .59347 .35512 L 0 .082 .181 r
F
.59053 .35693 m .58901 .35512 L .59195 .35329 L F
.18292 .33434 m .18374 .3315 L .18566 .33339 L 0 .025 .124 r
F
.18292 .33434 m .18101 .33246 L .18374 .3315 L F
.6942 .33868 m .6958 .33592 L .69721 .33768 L 0 .035 .136 r
F
.6942 .33868 m .69279 .33694 L .6958 .33592 L F
.2513 .33559 m .25224 .33266 L .25408 .33457 L 0 .028 .127 r
F
.2513 .33559 m .24946 .33369 L .25224 .33266 L F
.33903 .33827 m .3401 .33529 L .34185 .33731 L 0 .033 .134 r
F
.33903 .33827 m .33727 .33628 L .3401 .33529 L F
.85907 .33458 m .86092 .33174 L .86217 .33359 L 0 .026 .125 r
F
.85907 .33458 m .85781 .33274 L .86092 .33174 L F
.29291 .33584 m .2939 .33304 L .2957 .33497 L 0 .029 .128 r
F
.29291 .33584 m .29111 .33392 L .2939 .33304 L F
.14873 .33378 m .14951 .33083 L .15145 .33272 L 0 .024 .123 r
F
.14873 .33378 m .14678 .33189 L .14951 .33083 L F
.61414 .3482 m .61561 .34513 L .61709 .34684 L 0 .058 .16 r
F
.61414 .3482 m .61265 .34657 L .61561 .34513 L F
.68678 .33915 m .68836 .33621 L .68978 .33796 L 0 .035 .137 r
F
.68678 .33915 m .68536 .33742 L .68836 .33621 L F
.2171 .33504 m .21799 .33207 L .21987 .33396 L 0 .027 .126 r
F
.2171 .33504 m .21522 .33317 L .21799 .33207 L F
.70162 .33835 m .70322 .33538 L .70463 .3372 L 0 .034 .135 r
F
.70162 .33835 m .70022 .33655 L .70322 .33538 L F
.80262 .33527 m .80437 .33236 L .80567 .33414 L 0 .027 .127 r
F
.80262 .33527 m .80131 .3335 L .80437 .33236 L F
.70905 .33796 m .71066 .33506 L .71207 .33697 L 0 .033 .134 r
F
.70905 .33796 m .70764 .33608 L .71066 .33506 L F
.43284 .34829 m .43403 .34574 L .4357 .34772 L 0 .059 .162 r
F
.43284 .34829 m .43117 .34636 L .43403 .34574 L F
.7952 .33574 m .79693 .33273 L .79826 .33464 L 0 .028 .128 r
F
.7952 .33574 m .79388 .33382 L .79693 .33273 L F
.81005 .33494 m .81183 .33218 L .81312 .33396 L 0 .027 .126 r
F
.81005 .33494 m .80875 .33316 L .81183 .33218 L F
.36579 .3395 m .36689 .33662 L .36862 .33862 L 0 .036 .138 r
F
.36579 .3395 m .36405 .33756 L .36689 .33662 L F
.2587 .33545 m .25965 .33248 L .26148 .33441 L 0 .028 .127 r
F
.2587 .33545 m .25686 .33352 L .25965 .33248 L F
.45826 .35709 m .4595 .35425 L .46115 .35631 L 0 .085 .184 r
F
.45826 .35709 m .45662 .35502 L .4595 .35425 L F
.2245 .33487 m .22539 .33202 L .22726 .33396 L 0 .027 .126 r
F
.2245 .33487 m .22263 .33295 L .22539 .33202 L F
.86652 .33446 m .86838 .33159 L .86963 .33347 L 0 .026 .125 r
F
.86652 .33446 m .86527 .3326 L .86838 .33159 L F
.31966 .33714 m .32069 .33432 L .32247 .33623 L 0 .032 .132 r
F
.31966 .33714 m .31788 .33522 L .32069 .33432 L F
.15611 .33365 m .15689 .33082 L .15883 .33274 L 0 .025 .123 r
F
.15611 .33365 m .15417 .33176 L .15689 .33082 L F
.1903 .33432 m .19114 .33145 L .19304 .33335 L 0 .026 .125 r
F
.1903 .33432 m .1884 .33243 L .19114 .33145 L F
.63934 .34462 m .64083 .34136 L .64231 .3433 L 0 .048 .151 r
F
.63934 .34462 m .63786 .34269 L .64083 .34136 L F
.81749 .33475 m .81927 .33181 L .82056 .33365 L 0 .027 .126 r
F
.81749 .33475 m .8162 .33293 L .81927 .33181 L F
.67195 .34034 m .6735 .33725 L .67494 .33921 L 0 .038 .14 r
F
.67195 .34034 m .67051 .33837 L .6735 .33725 L F
.38512 .34117 m .38627 .33802 L .38797 .34013 L 0 .04 .142 r
F
.38512 .34117 m .38342 .33906 L .38627 .33802 L F
.66453 .34077 m .66607 .33762 L .66751 .33954 L 0 .039 .141 r
F
.66453 .34077 m .66308 .3389 L .66607 .33762 L F
.71649 .33789 m .71812 .33497 L .71952 .33691 L 0 .033 .134 r
F
.71649 .33789 m .71509 .33597 L .71812 .33497 L F
.82492 .33443 m .82671 .33156 L .82801 .33345 L 0 .026 .125 r
F
.82492 .33443 m .82363 .33254 L .82671 .33156 L F
.4164 .34454 m .41757 .34174 L .41925 .34398 L 0 .049 .152 r
F
.4164 .34454 m .41472 .34234 L .41757 .34174 L F
.40447 .34269 m .40563 .33981 L .40733 .34178 L 0 .044 .147 r
F
.40447 .34269 m .40277 .34072 L .40563 .33981 L F
.67938 .34003 m .68093 .33678 L .68237 .33872 L 0 .037 .139 r
F
.67938 .34003 m .67794 .33807 L .68093 .33678 L F
.2661 .33531 m .26706 .3323 L .26889 .33427 L 0 .028 .127 r
F
.2661 .33531 m .26427 .33336 L .26706 .3323 L F
.87397 .3343 m .87585 .33153 L .87708 .33334 L 0 .026 .125 r
F
.87397 .3343 m .87274 .33249 L .87585 .33153 L F
.73877 .33679 m .74044 .33404 L .74181 .33584 L 0 .031 .132 r
F
.73877 .33679 m .7374 .33502 L .74044 .33404 L F
.60381 .35185 m .60526 .34856 L .60675 .35007 L 0 .069 .17 r
F
.60381 .35185 m .60231 .3504 L .60526 .34856 L F
.73135 .33724 m .733 .33436 L .73437 .33611 L 0 .032 .133 r
F
.73135 .33724 m .72998 .33553 L .733 .33436 L F
.5645 .39427 m .56302 .39811 L .56586 .38862 L 0 .241 .277 r
F
.56164 .40234 m .56302 .39811 L .5645 .39427 L 0 .309 .307 r
F
.72393 .33769 m .72557 .3349 L .72695 .33669 L 0 .033 .134 r
F
.72393 .33769 m .72254 .3359 L .72557 .3349 L F
.49659 .4182 m .49774 .43317 L .49938 .43232 L 0 .38 .261 r
F
.49659 .4182 m .49496 .41839 L .49774 .43317 L F
.30029 .33605 m .30129 .33318 L .30309 .33514 L 0 .03 .13 r
F
.30029 .33605 m .29849 .3341 L .30129 .33318 L F
.34641 .33855 m .34748 .33572 L .34923 .33776 L 0 .035 .136 r
F
.34641 .33855 m .34466 .33652 L .34748 .33572 L F
.39254 .34105 m .39367 .33831 L .39538 .34029 L 0 .041 .143 r
F
.39254 .34105 m .39083 .33908 L .39367 .33831 L F
.19769 .33426 m .19854 .33135 L .20044 .33327 L 0 .026 .125 r
F
.19769 .33426 m .19579 .33235 L .19854 .33135 L F
.45375 .35531 m .45497 .35295 L .45662 .35502 L 0 .082 .181 r
F
.45375 .35531 m .4521 .35322 L .45497 .35295 L F
.48576 .39631 m .48418 .39142 L .48699 .39752 L 0 .282 .297 r
F
.59347 .35512 m .5949 .35163 L .59641 .35347 L 0 .078 .178 r
F
.59347 .35512 m .59195 .35329 L .5949 .35163 L F
.32706 .33721 m .32809 .33443 L .32987 .33633 L 0 .032 .133 r
F
.32706 .33721 m .32528 .33533 L .32809 .33443 L F
.65712 .34154 m .65865 .33839 L .6601 .34018 L 0 .042 .144 r
F
.65712 .34154 m .65567 .33979 L .65865 .33839 L F
.16348 .33371 m .16428 .33081 L .16621 .3327 L 0 .025 .124 r
F
.16348 .33371 m .16155 .33181 L .16428 .33081 L F
.88142 .33415 m .88332 .33145 L .88454 .33319 L 0 .026 .125 r
F
.88142 .33415 m .8802 .3324 L .88332 .33145 L F
.48418 .39142 m .48542 .39161 L .48699 .39752 L 0 .25 .282 r
F
.48418 .39142 m .48259 .38653 L .48542 .39161 L F
.23187 .33502 m .23279 .33202 L .23465 .33398 L 0 .028 .127 r
F
.23187 .33502 m .23001 .33306 L .23279 .33202 L F
.2735 .33524 m .27446 .33237 L .27628 .33431 L 0 .028 .128 r
F
.2735 .33524 m .27168 .33328 L .27446 .33237 L F
.83238 .33442 m .83419 .33157 L .83548 .33348 L 0 .027 .126 r
F
.83238 .33442 m .8311 .33252 L .83419 .33157 L F
.48259 .38653 m .48384 .38573 L .48542 .39161 L 0 .22 .267 r
F
.48259 .38653 m .48101 .38161 L .48384 .38573 L F
.37318 .3398 m .3743 .33679 L .37601 .33887 L 0 .038 .14 r
F
.37318 .3398 m .37145 .33772 L .3743 .33679 L F
.63193 .34557 m .63342 .34219 L .63489 .34413 L 0 .051 .154 r
F
.63193 .34557 m .63045 .34365 L .63342 .34219 L F
.48101 .38161 m .48227 .37985 L .48384 .38573 L 0 .192 .252 r
F
.48101 .38161 m .47943 .37669 L .48227 .37985 L F
.47943 .37669 m .48069 .37443 L .48227 .37985 L 0 .167 .238 r
F
.47943 .37669 m .47784 .3721 L .48069 .37443 L F
.74622 .33677 m .74789 .33379 L .74925 .33569 L 0 .031 .132 r
F
.74622 .33677 m .74485 .3349 L .74789 .33379 L F
.62451 .34605 m .62599 .34298 L .62748 .34486 L 0 .053 .156 r
F
.62451 .34605 m .62302 .3442 L .62599 .34298 L F
.42831 .34689 m .42949 .34443 L .43117 .34636 L 0 .057 .159 r
F
.42831 .34689 m .42663 .34498 L .42949 .34443 L F
.17088 .33354 m .17168 .3307 L .17361 .33254 L 0 .025 .124 r
F
.17088 .33354 m .16895 .33169 L .17168 .3307 L F
.57729 .36382 m .57868 .35962 L .58021 .36131 L 0 .107 .2 r
F
.57729 .36382 m .57576 .36233 L .57868 .35962 L F
.57438 .36743 m .57576 .36233 L .57729 .36382 L 0 .12 .21 r
F
.75365 .33644 m .75532 .33337 L .75668 .3353 L 0 .031 .131 r
F
.75365 .33644 m .75229 .33453 L .75532 .33337 L F
.83983 .3342 m .84165 .33137 L .84291 .33314 L 0 .026 .126 r
F
.83983 .3342 m .83856 .33243 L .84165 .33137 L F
.23928 .33483 m .2402 .33185 L .24206 .33376 L 0 .027 .127 r
F
.23928 .33483 m .23742 .33291 L .2402 .33185 L F
.44924 .35338 m .45046 .35074 L .4521 .35322 L 0 .076 .176 r
F
.44924 .35338 m .4476 .35095 L .45046 .35074 L F
.56025 .40507 m .55878 .41103 L .56164 .40234 L 0 .312 .306 r
F
.55738 .41318 m .55878 .41103 L .56025 .40507 L 0 .343 .291 r
F
.20507 .33423 m .20593 .33144 L .20782 .33332 L 0 .027 .126 r
F
.20507 .33423 m .20318 .33234 L .20593 .33144 L F
.30768 .33612 m .3087 .33318 L .31049 .33512 L 0 .03 .13 r
F
.30768 .33612 m .30589 .33416 L .3087 .33318 L F
.84726 .33387 m .8491 .33113 L .85036 .3329 L 0 .026 .125 r
F
.84726 .33387 m .846 .33212 L .8491 .33113 L F
.13666 .33306 m .13741 .33024 L .13937 .3321 L 0 .024 .123 r
F
.13666 .33306 m .1347 .33119 L .13741 .33024 L F
.77593 .33532 m .77765 .33242 L .77898 .33423 L 0 .029 .129 r
F
.77593 .33532 m .7746 .33354 L .77765 .33242 L F
.57011 .37692 m .5686 .37724 L .57147 .37104 L 0 .156 .232 r
F
.56724 .38392 m .5686 .37724 L .57011 .37692 L 0 .197 .255 r
F
.44473 .35121 m .44595 .34844 L .4476 .35095 L 0 .069 .17 r
F
.44473 .35121 m .44309 .34878 L .44595 .34844 L F
.76109 .33618 m .76278 .3333 L .76414 .33518 L 0 .031 .131 r
F
.76109 .33618 m .75973 .3343 L .76278 .3333 L F
.58021 .36131 m .58161 .35727 L .58314 .3591 L 0 .099 .194 r
F
.58021 .36131 m .57868 .35962 L .58161 .35727 L F
.47017 .35991 m .47143 .35711 L .47305 .36023 L 0 .098 .194 r
F
.47017 .35991 m .46855 .3573 L .47143 .35711 L F
.41187 .34304 m .41304 .34015 L .41472 .34234 L 0 .046 .149 r
F
.41187 .34304 m .41018 .34088 L .41304 .34015 L F
.33445 .33728 m .33551 .33432 L .33727 .33628 L 0 .033 .134 r
F
.33445 .33728 m .33268 .33535 L .33551 .33432 L F
.78337 .33503 m .78509 .33207 L .78642 .33398 L 0 .028 .128 r
F
.78337 .33503 m .78204 .33315 L .78509 .33207 L F
.47784 .3721 m .47911 .36927 L .48069 .37443 L 0 .145 .226 r
F
.47784 .3721 m .47625 .3677 L .47911 .36927 L F
.46567 .35769 m .46692 .35489 L .46855 .3573 L 0 .09 .188 r
F
.46567 .35769 m .46403 .35552 L .46692 .35489 L F
.76852 .33587 m .77022 .33293 L .77156 .3347 L 0 .03 .13 r
F
.76852 .33587 m .76718 .33411 L .77022 .33293 L F
.17827 .33342 m .17908 .33062 L .18101 .33246 L 0 .025 .124 r
F
.17827 .33342 m .17635 .33158 L .17908 .33062 L F
.53262 .43702 m .53402 .45232 L .53555 .43873 L 0 .43 .202 r
F
.53262 .43702 m .53107 .44993 L .53402 .45232 L F
.24668 .33468 m .2476 .33178 L .24946 .33369 L 0 .028 .127 r
F
.24668 .33468 m .24483 .33277 L .2476 .33178 L F
.61709 .34684 m .61857 .34369 L .62006 .34547 L 0 .056 .158 r
F
.61709 .34684 m .61561 .34513 L .61857 .34369 L F
.28088 .33531 m .28187 .33235 L .28368 .33425 L 0 .029 .129 r
F
.28088 .33531 m .27907 .33338 L .28187 .33235 L F
.85471 .33372 m .85656 .33093 L .85781 .33274 L 0 .026 .125 r
F
.85471 .33372 m .85346 .33193 L .85656 .33093 L F
.3538 .33888 m .35489 .33575 L .35663 .33775 L 0 .036 .138 r
F
.3538 .33888 m .35205 .33685 L .35489 .33575 L F
.64972 .34258 m .65124 .33949 L .65269 .34121 L 0 .045 .147 r
F
.64972 .34258 m .64827 .3409 L .65124 .33949 L F
.14405 .33296 m .14482 .33004 L .14678 .33189 L 0 .024 .123 r
F
.14405 .33296 m .14209 .3311 L .14482 .33004 L F
.2883 .33502 m .28929 .33205 L .29111 .33392 L 0 .028 .128 r
F
.2883 .33502 m .28649 .33314 L .28929 .33205 L F
.36122 .33853 m .36232 .33561 L .36405 .33756 L 0 .036 .137 r
F
.36122 .33853 m .35948 .33663 L .36232 .33561 L F
.60675 .35007 m .6082 .34669 L .6097 .34826 L 0 .065 .167 r
F
.60675 .35007 m .60526 .34856 L .6082 .34669 L F
.79081 .33486 m .79255 .33189 L .79388 .33382 L 0 .028 .128 r
F
.79081 .33486 m .78948 .33294 L .79255 .33189 L F
.68978 .33796 m .69137 .33517 L .69279 .33694 L 0 .035 .136 r
F
.68978 .33796 m .68836 .33621 L .69137 .33517 L F
.21245 .33427 m .21333 .33132 L .21522 .33317 L 0 .027 .126 r
F
.21245 .33427 m .21057 .3324 L .21333 .33132 L F
.31508 .33614 m .3161 .33329 L .31788 .33522 L 0 .031 .131 r
F
.31508 .33614 m .31329 .3342 L .3161 .33329 L F
.39993 .34149 m .40107 .33875 L .40277 .34072 L 0 .043 .146 r
F
.39993 .34149 m .39822 .33955 L .40107 .33875 L F
.38057 .34006 m .3817 .33694 L .38342 .33906 L 0 .039 .141 r
F
.38057 .34006 m .37886 .33793 L .3817 .33694 L F
.44022 .34934 m .44144 .3464 L .44309 .34878 L 0 .064 .166 r
F
.44022 .34934 m .43856 .34706 L .44144 .3464 L F
.70463 .3372 m .70624 .33423 L .70764 .33608 L 0 .033 .134 r
F
.70463 .3372 m .70322 .33538 L .70624 .33423 L F
.80567 .33414 m .80745 .33137 L .80875 .33316 L 0 .027 .126 r
F
.80567 .33414 m .80437 .33236 L .80745 .33137 L F
.15145 .33272 m .15223 .32985 L .15417 .33176 L 0 .024 .123 r
F
.15145 .33272 m .14951 .33083 L .15223 .32985 L F
.25408 .33457 m .25502 .33162 L .25686 .33352 L 0 .028 .127 r
F
.25408 .33457 m .25224 .33266 L .25502 .33162 L F
.21987 .33396 m .22076 .33104 L .22263 .33295 L 0 .027 .126 r
F
.21987 .33396 m .21799 .33207 L .22076 .33104 L F
.69721 .33768 m .69881 .33477 L .70022 .33655 L 0 .034 .135 r
F
.69721 .33768 m .6958 .33592 L .69881 .33477 L F
.58314 .3591 m .58454 .35501 L .58607 .35695 L 0 .092 .189 r
F
.58314 .3591 m .58161 .35727 L .58454 .35501 L F
.18566 .33339 m .18649 .33053 L .1884 .33243 L 0 .026 .124 r
F
.18566 .33339 m .18374 .3315 L .18649 .33053 L F
.86217 .33359 m .86402 .33074 L .86527 .3326 L 0 .026 .125 r
F
.86217 .33359 m .86092 .33174 L .86402 .33074 L F
.34185 .33731 m .34291 .33448 L .34466 .33652 L 0 .034 .135 r
F
.34185 .33731 m .3401 .33529 L .34291 .33448 L F
.79826 .33464 m .79999 .33159 L .80131 .3335 L 0 .028 .127 r
F
.79826 .33464 m .79693 .33273 L .79999 .33159 L F
.64231 .3433 m .64381 .34018 L .64528 .3421 L 0 .047 .15 r
F
.64231 .3433 m .64083 .34136 L .64381 .34018 L F
.71207 .33697 m .71369 .33404 L .71509 .33597 L 0 .033 .134 r
F
.71207 .33697 m .71066 .33506 L .71369 .33404 L F
.59641 .35347 m .59785 .35012 L .59936 .35194 L 0 .075 .176 r
F
.59641 .35347 m .5949 .35163 L .59785 .35012 L F
.47625 .3677 m .47753 .36415 L .47911 .36927 L 0 .126 .213 r
F
.47625 .3677 m .47466 .36333 L .47753 .36415 L F
.2957 .33497 m .29669 .33215 L .29849 .3341 L 0 .029 .129 r
F
.2957 .33497 m .2939 .33304 L .29669 .33215 L F
.52519 .43798 m .52654 .45679 L .52812 .44417 L 0 .44 .188 r
F
.52519 .43798 m .5236 .44897 L .52654 .45679 L F
.81312 .33396 m .8149 .33114 L .8162 .33293 L 0 .027 .126 r
F
.81312 .33396 m .81183 .33218 L .8149 .33114 L F
.66751 .33954 m .66906 .33643 L .67051 .33837 L 0 .038 .14 r
F
.66751 .33954 m .66607 .33762 L .66906 .33643 L F
.68237 .33872 m .68393 .33548 L .68536 .33742 L 0 .036 .138 r
F
.68237 .33872 m .68093 .33678 L .68393 .33548 L F
.42378 .34553 m .42496 .34286 L .42663 .34498 L 0 .054 .157 r
F
.42378 .34553 m .4221 .34342 L .42496 .34286 L F
.26148 .33441 m .26244 .3314 L .26427 .33336 L 0 .028 .127 r
F
.26148 .33441 m .25965 .33248 L .26244 .3314 L F
.67494 .33921 m .6765 .33612 L .67794 .33807 L 0 .038 .139 r
F
.67494 .33921 m .6735 .33725 L .6765 .33612 L F
.82056 .33365 m .82234 .33069 L .82363 .33254 L 0 .026 .125 r
F
.82056 .33365 m .81927 .33181 L .82234 .33069 L F
.57438 .36743 m .57286 .36643 L .57576 .36233 L 0 .12 .21 r
F
.57147 .37104 m .57286 .36643 L .57438 .36743 L 0 .139 .221 r
F
.36862 .33862 m .36973 .33567 L .37145 .33772 L 0 .037 .138 r
F
.36862 .33862 m .36689 .33662 L .36973 .33567 L F
.86963 .33347 m .87149 .33059 L .87274 .33249 L 0 .026 .125 r
F
.86963 .33347 m .86838 .33159 L .87149 .33059 L F
.38797 .34013 m .38912 .33698 L .39083 .33908 L 0 .04 .142 r
F
.38797 .34013 m .38627 .33802 L .38912 .33698 L F
.32247 .33623 m .3235 .33344 L .32528 .33533 L 0 .032 .132 r
F
.32247 .33623 m .32069 .33432 L .3235 .33344 L F
.22726 .33396 m .22815 .33109 L .23001 .33306 L 0 .027 .126 r
F
.22726 .33396 m .22539 .33202 L .22815 .33109 L F
.19304 .33335 m .19389 .33043 L .19579 .33235 L 0 .026 .125 r
F
.19304 .33335 m .19114 .33145 L .19389 .33043 L F
.15883 .33274 m .15962 .32988 L .16155 .33181 L 0 .025 .123 r
F
.15883 .33274 m .15689 .33082 L .15962 .32988 L F
.6601 .34018 m .66163 .33705 L .66308 .3389 L 0 .04 .142 r
F
.6601 .34018 m .65865 .33839 L .66163 .33705 L F
.71952 .33691 m .72115 .33397 L .72254 .3359 L 0 .033 .134 r
F
.71952 .33691 m .71812 .33497 L .72115 .33397 L F
.63489 .34413 m .63638 .34074 L .63786 .34269 L 0 .049 .152 r
F
.63489 .34413 m .63342 .34219 L .63638 .34074 L F
.73437 .33611 m .73603 .33324 L .7374 .33502 L 0 .032 .132 r
F
.73437 .33611 m .733 .33436 L .73603 .33324 L F
.46115 .35631 m .46239 .35349 L .46403 .35552 L 0 .087 .185 r
F
.46115 .35631 m .4595 .35425 L .46239 .35349 L F
.26889 .33427 m .26985 .3313 L .27168 .33328 L 0 .028 .127 r
F
.26889 .33427 m .26706 .3323 L .26985 .3313 L F
.82801 .33345 m .82981 .33061 L .8311 .33252 L 0 .026 .125 r
F
.82801 .33345 m .82671 .33156 L .82981 .33061 L F
.58607 .35695 m .58749 .35315 L .58901 .35512 L 0 .086 .185 r
F
.58607 .35695 m .58454 .35501 L .58749 .35315 L F
.4357 .34772 m .4369 .34499 L .43856 .34706 L 0 .061 .163 r
F
.4357 .34772 m .43403 .34574 L .4369 .34499 L F
.40733 .34178 m .40849 .33889 L .41018 .34088 L 0 .045 .147 r
F
.40733 .34178 m .40563 .33981 L .40849 .33889 L F
.87708 .33334 m .87897 .33058 L .8802 .3324 L 0 .026 .125 r
F
.87708 .33334 m .87585 .33153 L .87897 .33058 L F
.74181 .33584 m .74348 .33306 L .74485 .3349 L 0 .031 .132 r
F
.74181 .33584 m .74044 .33404 L .74348 .33306 L F
.72695 .33669 m .7286 .33373 L .72998 .33553 L 0 .033 .134 r
F
.72695 .33669 m .72557 .3349 L .7286 .33373 L F
.6097 .34826 m .61115 .34494 L .61265 .34657 L 0 .061 .163 r
F
.6097 .34826 m .6082 .34669 L .61115 .34494 L F
.47466 .36333 m .47592 .36054 L .47753 .36415 L 0 .113 .204 r
F
.47466 .36333 m .47305 .36023 L .47592 .36054 L F
.20044 .33327 m .20129 .33042 L .20318 .33234 L 0 .026 .125 r
F
.20044 .33327 m .19854 .33135 L .20129 .33042 L F
.30309 .33514 m .3041 .33221 L .30589 .33416 L 0 .03 .13 r
F
.30309 .33514 m .30129 .33318 L .3041 .33221 L F
.16621 .3327 m .16702 .32981 L .16895 .33169 L 0 .025 .124 r
F
.16621 .3327 m .16428 .33081 L .16702 .32981 L F
.62748 .34486 m .62897 .34173 L .63045 .34365 L 0 .052 .155 r
F
.62748 .34486 m .62599 .34298 L .62897 .34173 L F
.55308 .41946 m .55162 .42944 L .5545 .42132 L 0 .361 .277 r
F
.55018 .42607 m .55162 .42944 L .55308 .41946 L 0 .387 .254 r
F
.23465 .33398 m .23556 .33095 L .23742 .33291 L 0 .027 .127 r
F
.23465 .33398 m .23279 .33202 L .23556 .33095 L F
.13199 .33213 m .13273 .32931 L .1347 .33119 L 0 .024 .122 r
F
.13199 .33213 m .13003 .33024 L .13273 .32931 L F
.56586 .38862 m .56437 .39093 L .56724 .38392 L 0 .22 .267 r
F
.56302 .39811 m .56437 .39093 L .56586 .38862 L 0 .284 .297 r
F
.74925 .33569 m .75092 .33261 L .75229 .33453 L 0 .031 .131 r
F
.74925 .33569 m .74789 .33379 L .75092 .33261 L F
.34923 .33776 m .35031 .33482 L .35205 .33685 L 0 .036 .137 r
F
.34923 .33776 m .34748 .33572 L .35031 .33482 L F
.32987 .33633 m .33091 .33343 L .33268 .33535 L 0 .033 .133 r
F
.32987 .33633 m .32809 .33443 L .33091 .33343 L F
.75668 .3353 m .75837 .33235 L .75973 .3343 L 0 .03 .131 r
F
.75668 .3353 m .75532 .33337 L .75837 .33235 L F
.41925 .34398 m .42043 .34113 L .4221 .34342 L 0 .051 .153 r
F
.41925 .34398 m .41757 .34174 L .42043 .34113 L F
.83548 .33348 m .83728 .33052 L .83856 .33243 L 0 .027 .126 r
F
.83548 .33348 m .83419 .33157 L .83728 .33052 L F
.39538 .34029 m .39652 .33756 L .39822 .33955 L 0 .042 .144 r
F
.39538 .34029 m .39367 .33831 L .39652 .33756 L F
.27628 .33431 m .27725 .33146 L .27907 .33338 L 0 .028 .128 r
F
.27628 .33431 m .27446 .33237 L .27725 .33146 L F
.37601 .33887 m .37714 .33585 L .37886 .33793 L 0 .038 .14 r
F
.37601 .33887 m .3743 .33679 L .37714 .33585 L F
.62006 .34547 m .62153 .34237 L .62302 .3442 L 0 .054 .157 r
F
.62006 .34547 m .61857 .34369 L .62153 .34237 L F
.84291 .33314 m .84474 .33034 L .846 .33212 L 0 .026 .125 r
F
.84291 .33314 m .84165 .33137 L .84474 .33034 L F
.24206 .33376 m .24297 .33086 L .24483 .33277 L 0 .027 .127 r
F
.24206 .33376 m .2402 .33185 L .24297 .33086 L F
.17361 .33254 m .17442 .32974 L .17635 .33158 L 0 .025 .124 r
F
.17361 .33254 m .17168 .3307 L .17442 .32974 L F
.65269 .34121 m .65422 .33803 L .65567 .33979 L 0 .043 .146 r
F
.65269 .34121 m .65124 .33949 L .65422 .33803 L F
.77898 .33423 m .7807 .33131 L .78204 .33315 L 0 .028 .128 r
F
.77898 .33423 m .77765 .33242 L .7807 .33131 L F
.77156 .3347 m .77327 .33175 L .7746 .33354 L 0 .029 .129 r
F
.77156 .3347 m .77022 .33293 L .77327 .33175 L F
.31049 .33512 m .3115 .33226 L .31329 .3342 L 0 .03 .131 r
F
.31049 .33512 m .3087 .33318 L .3115 .33226 L F
.85036 .3329 m .8522 .33015 L .85346 .33193 L 0 .026 .125 r
F
.85036 .3329 m .8491 .33113 L .8522 .33015 L F
.20782 .33332 m .20867 .33053 L .21057 .3324 L 0 .027 .126 r
F
.20782 .33332 m .20593 .33144 L .20867 .33053 L F
.76414 .33518 m .76583 .33222 L .76718 .33411 L 0 .03 .131 r
F
.76414 .33518 m .76278 .3333 L .76583 .33222 L F
.13937 .3321 m .14013 .32926 L .14209 .3311 L 0 .024 .123 r
F
.13937 .3321 m .13741 .33024 L .14013 .32926 L F
.57147 .37104 m .56995 .37054 L .57286 .36643 L 0 .139 .221 r
F
.5686 .37724 m .56995 .37054 L .57147 .37104 L 0 .168 .239 r
F
.78642 .33398 m .78815 .33102 L .78948 .33294 L 0 .028 .128 r
F
.78642 .33398 m .78509 .33207 L .78815 .33102 L F
.59936 .35194 m .6008 .3486 L .60231 .3504 L 0 .073 .174 r
F
.59936 .35194 m .59785 .35012 L .6008 .3486 L F
.33727 .33628 m .33834 .33329 L .3401 .33529 L 0 .033 .134 r
F
.33727 .33628 m .33551 .33432 L .33834 .33329 L F
.28368 .33425 m .28467 .33127 L .28649 .33314 L 0 .029 .128 r
F
.28368 .33425 m .28187 .33235 L .28467 .33127 L F
.35663 .33775 m .35773 .33466 L .35948 .33663 L 0 .036 .137 r
F
.35663 .33775 m .35489 .33575 L .35773 .33466 L F
.24946 .33369 m .25038 .33077 L .25224 .33266 L 0 .028 .127 r
F
.24946 .33369 m .2476 .33178 L .25038 .33077 L F
.58901 .35512 m .59043 .3513 L .59195 .35329 L 0 .082 .181 r
F
.58901 .35512 m .58749 .35315 L .59043 .3513 L F
.18101 .33246 m .18182 .32967 L .18374 .3315 L 0 .025 .124 r
F
.18101 .33246 m .17908 .33062 L .18182 .32967 L F
.29111 .33392 m .29209 .33116 L .2939 .33304 L 0 .028 .128 r
F
.29111 .33392 m .28929 .33205 L .29209 .33116 L F
.14678 .33189 m .14755 .32898 L .14951 .33083 L 0 .024 .123 r
F
.14678 .33189 m .14482 .33004 L .14755 .32898 L F
.85781 .33274 m .85966 .32993 L .86092 .33174 L 0 .026 .125 r
F
.85781 .33274 m .85656 .33093 L .85966 .32993 L F
.50266 .42794 m .50384 .4452 L .50549 .44025 L 0 .412 .225 r
F
.50266 .42794 m .50101 .43146 L .50384 .4452 L F
.21522 .33317 m .2161 .33023 L .21799 .33207 L 0 .027 .126 r
F
.21522 .33317 m .21333 .33132 L .2161 .33023 L F
.43117 .34636 m .43236 .34375 L .43403 .34574 L 0 .059 .161 r
F
.43117 .34636 m .42949 .34443 L .43236 .34375 L F
.45662 .35502 m .45786 .3522 L .4595 .35425 L 0 .084 .183 r
F
.45662 .35502 m .45497 .35295 L .45786 .3522 L F
.70764 .33608 m .70926 .33318 L .71066 .33506 L 0 .033 .134 r
F
.70764 .33608 m .70624 .33423 L .70926 .33318 L F
.79388 .33382 m .79561 .3308 L .79693 .33273 L 0 .028 .127 r
F
.79388 .33382 m .79255 .33189 L .79561 .3308 L F
.36405 .33756 m .36516 .33461 L .36689 .33662 L 0 .036 .137 r
F
.36405 .33756 m .36232 .33561 L .36516 .33461 L F
.69279 .33694 m .69438 .33413 L .6958 .33592 L 0 .035 .136 r
F
.69279 .33694 m .69137 .33517 L .69438 .33413 L F
.64528 .3421 m .6468 .33899 L .64827 .3409 L 0 .046 .149 r
F
.64528 .3421 m .64381 .34018 L .6468 .33899 L F
.70022 .33655 m .70182 .33357 L .70322 .33538 L 0 .034 .135 r
F
.70022 .33655 m .69881 .33477 L .70182 .33357 L F
.41472 .34234 m .41589 .33949 L .41757 .34174 L 0 .048 .15 r
F
.41472 .34234 m .41304 .34015 L .41589 .33949 L F
.38342 .33906 m .38456 .33591 L .38627 .33802 L 0 .039 .141 r
F
.38342 .33906 m .3817 .33694 L .38456 .33591 L F
.68536 .33742 m .68693 .33429 L .68836 .33621 L 0 .035 .137 r
F
.68536 .33742 m .68393 .33548 L .68693 .33429 L F
.80131 .3335 m .80306 .33045 L .80437 .33236 L 0 .027 .127 r
F
.80131 .3335 m .79999 .33159 L .80306 .33045 L F
.25686 .33352 m .25781 .33057 L .25965 .33248 L 0 .028 .127 r
F
.25686 .33352 m .25502 .33162 L .25781 .33057 L F
.22263 .33295 m .22352 .33009 L .22539 .33202 L 0 .027 .126 r
F
.22263 .33295 m .22076 .33104 L .22352 .33009 L F
.80875 .33316 m .81053 .33039 L .81183 .33218 L F
.80875 .33316 m .80745 .33137 L .81053 .33039 L F
.31788 .33522 m .31891 .3324 L .32069 .33432 L 0 .031 .132 r
F
.31788 .33522 m .3161 .33329 L .31891 .3324 L F
.61265 .34657 m .61411 .34342 L .61561 .34513 L 0 .058 .161 r
F
.61265 .34657 m .61115 .34494 L .61411 .34342 L F
.15417 .33176 m .15495 .3289 L .15689 .33082 L 0 .024 .123 r
F
.15417 .33176 m .15223 .32985 L .15495 .3289 L F
.63786 .34269 m .63936 .33941 L .64083 .34136 L 0 .048 .15 r
F
.63786 .34269 m .63638 .34074 L .63936 .33941 L F
.86527 .3326 m .86713 .32971 L .86838 .33159 L 0 .026 .125 r
F
.86527 .3326 m .86402 .33074 L .86713 .32971 L F
.67051 .33837 m .67206 .3353 L .6735 .33725 L 0 .038 .14 r
F
.67051 .33837 m .66906 .33643 L .67206 .3353 L F
.1884 .33243 m .18923 .32954 L .19114 .33145 L 0 .026 .124 r
F
.1884 .33243 m .18649 .33053 L .18923 .32954 L F
.71509 .33597 m .71672 .33303 L .71812 .33497 L 0 .033 .134 r
F
.71509 .33597 m .71369 .33404 L .71672 .33303 L F
.40277 .34072 m .40393 .33783 L .40563 .33981 L 0 .044 .146 r
F
.40277 .34072 m .40107 .33875 L .40393 .33783 L F
.67794 .33807 m .6795 .33483 L .68093 .33678 L 0 .037 .139 r
F
.67794 .33807 m .6765 .33612 L .6795 .33483 L F
.66308 .3389 m .66462 .33572 L .66607 .33762 L 0 .039 .141 r
F
.66308 .3389 m .66163 .33705 L .66462 .33572 L F
.8162 .33293 m .81797 .33 L .81927 .33181 L 0 .027 .126 r
F
.8162 .33293 m .8149 .33114 L .81797 .33 L F
.26427 .33336 m .26523 .33033 L .26706 .3323 L 0 .027 .127 r
F
.26427 .33336 m .26244 .3314 L .26523 .33033 L F
.82363 .33254 m .82542 .32969 L .82671 .33156 L 0 .026 .125 r
F
.82363 .33254 m .82234 .33069 L .82542 .32969 L F
.46855 .3573 m .46981 .35434 L .47143 .35711 L 0 .093 .19 r
F
.46855 .3573 m .46692 .35489 L .46981 .35434 L F
.34466 .33652 m .34573 .33367 L .34748 .33572 L 0 .034 .135 r
F
.34466 .33652 m .34291 .33448 L .34573 .33367 L F
.4476 .35095 m .44882 .34814 L .45046 .35074 L 0 .072 .173 r
F
.4476 .35095 m .44595 .34844 L .44882 .34814 L F
.4521 .35322 m .45333 .35041 L .45497 .35295 L 0 .079 .179 r
F
.4521 .35322 m .45046 .35074 L .45333 .35041 L F
.29849 .3341 m .29949 .33123 L .30129 .33318 L 0 .029 .129 r
F
.29849 .3341 m .29669 .33215 L .29949 .33123 L F
.87274 .33249 m .8746 .32962 L .87585 .33153 L 0 .026 .125 r
F
.87274 .33249 m .87149 .33059 L .8746 .32962 L F
.39083 .33908 m .39197 .33622 L .39367 .33831 L 0 .04 .142 r
F
.39083 .33908 m .38912 .33698 L .39197 .33622 L F
.44309 .34878 m .4443 .34596 L .44595 .34844 L 0 .066 .168 r
F
.44309 .34878 m .44144 .3464 L .4443 .34596 L F
.7374 .33502 m .73907 .33223 L .74044 .33404 L 0 .031 .132 r
F
.7374 .33502 m .73603 .33324 L .73907 .33223 L F
.19579 .33235 m .19664 .32941 L .19854 .33135 L 0 .026 .125 r
F
.19579 .33235 m .19389 .33043 L .19664 .32941 L F
.37145 .33772 m .37257 .33473 L .3743 .33679 L 0 .037 .139 r
F
.37145 .33772 m .36973 .33567 L .37257 .33473 L F
.72254 .3359 m .72418 .33297 L .72557 .3349 L 0 .033 .134 r
F
.72254 .3359 m .72115 .33397 L .72418 .33297 L F
.16155 .33181 m .16235 .32889 L .16428 .33081 L 0 .025 .123 r
F
.16155 .33181 m .15962 .32988 L .16235 .32889 L F
.23001 .33306 m .23092 .33005 L .23279 .33202 L 0 .027 .127 r
F
.23001 .33306 m .22815 .33109 L .23092 .33005 L F
.72998 .33553 m .73162 .33255 L .733 .33436 L 0 .032 .133 r
F
.72998 .33553 m .7286 .33373 L .73162 .33255 L F
.32528 .33533 m .32631 .33257 L .32809 .33443 L F
.32528 .33533 m .3235 .33344 L .32631 .33257 L F
.27168 .33328 m .27264 .33038 L .27446 .33237 L 0 .028 .127 r
F
.27168 .33328 m .26985 .3313 L .27264 .33038 L F
.59195 .35329 m .59338 .34964 L .5949 .35163 L 0 .078 .178 r
F
.59195 .35329 m .59043 .3513 L .59338 .34964 L F
.63045 .34365 m .63193 .34026 L .63342 .34219 L 0 .051 .153 r
F
.63045 .34365 m .62897 .34173 L .63193 .34026 L F
.8311 .33252 m .8329 .32966 L .83419 .33157 L 0 .026 .126 r
F
.8311 .33252 m .82981 .33061 L .8329 .32966 L F
.65567 .33979 m .6572 .33659 L .65865 .33839 L 0 .042 .144 r
F
.65567 .33979 m .65422 .33803 L .6572 .33659 L F
.8802 .3324 m .88209 .32964 L .88332 .33145 L 0 .026 .126 r
F
.8802 .3324 m .87897 .33058 L .88209 .32964 L F
.42663 .34498 m .42782 .3423 L .42949 .34443 L 0 .056 .159 r
F
.42663 .34498 m .42496 .34286 L .42782 .3423 L F
.74485 .3349 m .74652 .33193 L .74789 .33379 L 0 .031 .132 r
F
.74485 .3349 m .74348 .33306 L .74652 .33193 L F
.41018 .34088 m .41135 .3381 L .41304 .34015 L 0 .045 .148 r
F
.41018 .34088 m .40849 .33889 L .41135 .3381 L F
.46403 .35552 m .46528 .35276 L .46692 .35489 L 0 .088 .186 r
F
.46403 .35552 m .46239 .35349 L .46528 .35276 L F
.62302 .3442 m .6245 .3411 L .62599 .34298 L 0 .053 .156 r
F
.62302 .3442 m .62153 .34237 L .6245 .3411 L F
.75229 .33453 m .75396 .33143 L .75532 .33337 L 0 .03 .131 r
F
.75229 .33453 m .75092 .33261 L .75396 .33143 L F
.60231 .3504 m .60375 .34678 L .60526 .34856 L 0 .07 .171 r
F
.60231 .3504 m .6008 .3486 L .60375 .34678 L F
.23742 .33291 m .23834 .3299 L .2402 .33185 L 0 .027 .127 r
F
.23742 .33291 m .23556 .33095 L .23834 .3299 L F
.30589 .33416 m .30691 .33123 L .3087 .33318 L 0 .03 .13 r
F
.30589 .33416 m .3041 .33221 L .30691 .33123 L F
.16895 .33169 m .16975 .32883 L .17168 .3307 L 0 .025 .124 r
F
.16895 .33169 m .16702 .32981 L .16975 .32883 L F
.20318 .33234 m .20403 .32952 L .20593 .33144 L 0 .026 .126 r
F
.20318 .33234 m .20129 .33042 L .20403 .32952 L F
.47305 .36023 m .47432 .35693 L .47592 .36054 L 0 .104 .198 r
F
.47305 .36023 m .47143 .35711 L .47432 .35693 L F
.43856 .34706 m .43978 .34424 L .44144 .3464 L 0 .062 .164 r
F
.43856 .34706 m .4369 .34499 L .43978 .34424 L F
.1347 .33119 m .13544 .32838 L .13741 .33024 L 0 .024 .123 r
F
.1347 .33119 m .13273 .32931 L .13544 .32838 L F
.83856 .33243 m .84037 .32946 L .84165 .33137 L 0 .026 .126 r
F
.83856 .33243 m .83728 .33052 L .84037 .32946 L F
.75973 .3343 m .76142 .33134 L .76278 .3333 L 0 .03 .131 r
F
.75973 .3343 m .75837 .33235 L .76142 .33134 L F
.33268 .33535 m .33374 .33236 L .33551 .33432 L 0 .033 .133 r
F
.33268 .33535 m .33091 .33343 L .33374 .33236 L F
.7746 .33354 m .77632 .33061 L .77765 .33242 L 0 .029 .129 r
F
.7746 .33354 m .77327 .33175 L .77632 .33061 L F
.35205 .33685 m .35315 .33375 L .35489 .33575 L 0 .036 .137 r
F
.35205 .33685 m .35031 .33482 L .35315 .33375 L F
.846 .33212 m .84784 .32934 L .8491 .33113 L 0 .026 .125 r
F
.846 .33212 m .84474 .33034 L .84784 .32934 L F
.78204 .33315 m .78376 .33021 L .78509 .33207 L 0 .028 .128 r
F
.78204 .33315 m .7807 .33131 L .78376 .33021 L F
.27907 .33338 m .28004 .33044 L .28187 .33235 L 0 .029 .128 r
F
.27907 .33338 m .27725 .33146 L .28004 .33044 L F
.24483 .33277 m .24575 .32987 L .2476 .33178 L 0 .027 .127 r
F
.24483 .33277 m .24297 .33086 L .24575 .32987 L F
.37886 .33793 m .37999 .33485 L .3817 .33694 L 0 .038 .14 r
F
.37886 .33793 m .37714 .33585 L .37999 .33485 L F
.17635 .33158 m .17716 .32877 L .17908 .33062 L 0 .025 .124 r
F
.17635 .33158 m .17442 .32974 L .17716 .32877 L F
.57868 .35962 m .58008 .35542 L .58161 .35727 L 0 .099 .194 r
F
.57868 .35962 m .57715 .3579 L .58008 .35542 L F
.57576 .36233 m .57715 .3579 L .57868 .35962 L 0 .108 .201 r
F
.57576 .36233 m .57423 .36082 L .57715 .3579 L F
.57286 .36643 m .57423 .36082 L .57576 .36233 L 0 .124 .212 r
F
.76718 .33411 m .76888 .33105 L .77022 .33293 L 0 .03 .13 r
F
.76718 .33411 m .76583 .33222 L .76888 .33105 L F
.35948 .33663 m .36058 .33364 L .36232 .33561 L 0 .036 .137 r
F
.35948 .33663 m .35773 .33466 L .36058 .33364 L F
.28649 .33314 m .28747 .3302 L .28929 .33205 L 0 .028 .128 r
F
.28649 .33314 m .28467 .33127 L .28747 .3302 L F
.78948 .33294 m .79122 .32997 L .79255 .33189 L 0 .028 .127 r
F
.78948 .33294 m .78815 .33102 L .79122 .32997 L F
.39822 .33955 m .39937 .33676 L .40107 .33875 L 0 .043 .145 r
F
.39822 .33955 m .39652 .33756 L .39937 .33676 L F
.14209 .3311 m .14286 .32821 L .14482 .33004 L 0 .024 .123 r
F
.14209 .3311 m .14013 .32926 L .14286 .32821 L F
.85346 .33193 m .85531 .32914 L .85656 .33093 L 0 .026 .125 r
F
.85346 .33193 m .8522 .33015 L .85531 .32914 L F
.31329 .3342 m .31431 .33135 L .3161 .33329 L 0 .031 .131 r
F
.31329 .3342 m .3115 .33226 L .31431 .33135 L F
.61561 .34513 m .61707 .34191 L .61857 .34369 L 0 .056 .159 r
F
.61561 .34513 m .61411 .34342 L .61707 .34191 L F
.21057 .3324 m .21144 .32946 L .21333 .33132 L 0 .027 .126 r
F
.21057 .3324 m .20867 .33053 L .21144 .32946 L F
.3401 .33529 m .34116 .33244 L .34291 .33448 L 0 .033 .134 r
F
.3401 .33529 m .33834 .33329 L .34116 .33244 L F
.64827 .3409 m .64978 .3376 L .65124 .33949 L 0 .045 .148 r
F
.64827 .3409 m .6468 .33899 L .64978 .3376 L F
.25224 .33266 m .25317 .32976 L .25502 .33162 L 0 .028 .127 r
F
.25224 .33266 m .25038 .33077 L .25317 .32976 L F
.14951 .33083 m .15028 .32801 L .15223 .32985 L 0 .024 .122 r
F
.14951 .33083 m .14755 .32898 L .15028 .32801 L F
.21799 .33207 m .21887 .3292 L .22076 .33104 L 0 .026 .126 r
F
.21799 .33207 m .2161 .33023 L .21887 .3292 L F
.4221 .34342 m .42329 .34057 L .42496 .34286 L 0 .053 .155 r
F
.4221 .34342 m .42043 .34113 L .42329 .34057 L F
.64083 .34136 m .64234 .33824 L .64381 .34018 L 0 .047 .149 r
F
.64083 .34136 m .63936 .33941 L .64234 .33824 L F
.68836 .33621 m .68994 .33327 L .69137 .33517 L 0 .035 .136 r
F
.68836 .33621 m .68693 .33429 L .68994 .33327 L F
.70322 .33538 m .70483 .33239 L .70624 .33423 L 0 .033 .134 r
F
.70322 .33538 m .70182 .33357 L .70483 .33239 L F
.79693 .33273 m .79867 .32966 L .79999 .33159 L 0 .028 .127 r
F
.79693 .33273 m .79561 .3308 L .79867 .32966 L F
.18374 .3315 m .18456 .32872 L .18649 .33053 L 0 .026 .124 r
F
.18374 .3315 m .18182 .32967 L .18456 .32872 L F
.58161 .35727 m .58301 .35305 L .58454 .35501 L 0 .091 .189 r
F
.58161 .35727 m .58008 .35542 L .58301 .35305 L F
.86092 .33174 m .86277 .32891 L .86402 .33074 L 0 .026 .125 r
F
.86092 .33174 m .85966 .32993 L .86277 .32891 L F
.80437 .33236 m .80613 .32946 L .80745 .33137 L 0 .027 .126 r
F
.80437 .33236 m .80306 .33045 L .80613 .32946 L F
.71066 .33506 m .71228 .33213 L .71369 .33404 L 0 .033 .133 r
F
.71066 .33506 m .70926 .33318 L .71228 .33213 L F
.6958 .33592 m .69739 .33297 L .69881 .33477 L 0 .035 .136 r
F
.6958 .33592 m .69438 .33413 L .69739 .33297 L F
.2939 .33304 m .29488 .33028 L .29669 .33215 L 0 .029 .129 r
F
.2939 .33304 m .29209 .33116 L .29488 .33028 L F
.68093 .33678 m .68249 .33355 L .68393 .33548 L 0 .036 .137 r
F
.68093 .33678 m .6795 .33483 L .68249 .33355 L F
.38627 .33802 m .38741 .33487 L .38912 .33698 L 0 .039 .141 r
F
.38627 .33802 m .38456 .33591 L .38741 .33487 L F
.5949 .35163 m .59633 .34816 L .59785 .35012 L 0 .075 .176 r
F
.5949 .35163 m .59338 .34964 L .59633 .34816 L F
.66607 .33762 m .66761 .3345 L .66906 .33643 L 0 .038 .14 r
F
.66607 .33762 m .66462 .33572 L .66761 .3345 L F
.25965 .33248 m .2606 .32949 L .26244 .3314 L 0 .027 .127 r
F
.25965 .33248 m .25781 .33057 L .2606 .32949 L F
.60526 .34856 m .6067 .34493 L .6082 .34669 L 0 .066 .167 r
F
.60526 .34856 m .60375 .34678 L .6067 .34493 L F
.36689 .33662 m .368 .33363 L .36973 .33567 L 0 .036 .138 r
F
.36689 .33662 m .36516 .33461 L .368 .33363 L F
.6735 .33725 m .67506 .33417 L .6765 .33612 L 0 .037 .139 r
F
.6735 .33725 m .67206 .3353 L .67506 .33417 L F
.81183 .33218 m .81361 .32935 L .8149 .33114 L 0 .027 .126 r
F
.81183 .33218 m .81053 .33039 L .81361 .32935 L F
.4595 .35425 m .46075 .35145 L .46239 .35349 L 0 .085 .184 r
F
.4595 .35425 m .45786 .3522 L .46075 .35145 L F
.86838 .33159 m .87024 .32869 L .87149 .33059 L 0 .026 .125 r
F
.86838 .33159 m .86713 .32971 L .87024 .32869 L F
.22539 .33202 m .22628 .32913 L .22815 .33109 L 0 .027 .126 r
F
.22539 .33202 m .22352 .33009 L .22628 .32913 L F
.81927 .33181 m .82105 .32886 L .82234 .33069 L 0 .026 .125 r
F
.81927 .33181 m .81797 .33 L .82105 .32886 L F
.32069 .33432 m .32172 .33155 L .3235 .33344 L 0 .032 .132 r
F
.32069 .33432 m .31891 .3324 L .32172 .33155 L F
.15689 .33082 m .15768 .32795 L .15962 .32988 L 0 .025 .123 r
F
.15689 .33082 m .15495 .3289 L .15768 .32795 L F
.19114 .33145 m .19198 .32851 L .19389 .33043 L 0 .026 .124 r
F
.19114 .33145 m .18923 .32954 L .19198 .32851 L F
.71812 .33497 m .71975 .33204 L .72115 .33397 L 0 .033 .134 r
F
.71812 .33497 m .71672 .33303 L .71975 .33204 L F
.63342 .34219 m .6349 .33878 L .63638 .34074 L 0 .049 .152 r
F
.63342 .34219 m .63193 .34026 L .6349 .33878 L F
.26706 .3323 m .26803 .32931 L .26985 .3313 L 0 .027 .127 r
F
.26706 .3323 m .26523 .33033 L .26803 .32931 L F
.58454 .35501 m .58596 .35117 L .58749 .35315 L 0 .086 .184 r
F
.58454 .35501 m .58301 .35305 L .58596 .35117 L F
.43403 .34574 m .43523 .34291 L .4369 .34499 L 0 .06 .162 r
F
.43403 .34574 m .43236 .34375 L .43523 .34291 L F
.82671 .33156 m .82852 .32873 L .82981 .33061 L 0 .026 .125 r
F
.82671 .33156 m .82542 .32969 L .82852 .32873 L F
.40563 .33981 m .40679 .33692 L .40849 .33889 L 0 .044 .147 r
F
.40563 .33981 m .40393 .33783 L .40679 .33692 L F
.65865 .33839 m .66018 .33521 L .66163 .33705 L 0 .04 .142 r
F
.65865 .33839 m .6572 .33659 L .66018 .33521 L F
.41757 .34174 m .41875 .33884 L .42043 .34113 L 0 .049 .152 r
F
.41757 .34174 m .41589 .33949 L .41875 .33884 L F
.733 .33436 m .73465 .33141 L .73603 .33324 L 0 .032 .132 r
F
.733 .33436 m .73162 .33255 L .73465 .33141 L F
.87585 .33153 m .87772 .32867 L .87897 .33058 L 0 .026 .125 r
F
.87585 .33153 m .8746 .32962 L .87772 .32867 L F
.30129 .33318 m .3023 .33025 L .3041 .33221 L 0 .029 .129 r
F
.30129 .33318 m .29949 .33123 L .3023 .33025 L F
.56724 .38392 m .56574 .38525 L .5686 .37724 L 0 .197 .255 r
F
.56437 .39093 m .56574 .38525 L .56724 .38392 L 0 .25 .282 r
F
.19854 .33135 m .19939 .32847 L .20129 .33042 L 0 .026 .125 r
F
.19854 .33135 m .19664 .32941 L .19939 .32847 L F
.74044 .33404 m .74211 .33122 L .74348 .33306 L 0 .032 .132 r
F
.74044 .33404 m .73907 .33223 L .74211 .33122 L F
.34748 .33572 m .34856 .33276 L .35031 .33482 L 0 .035 .136 r
F
.34748 .33572 m .34573 .33367 L .34856 .33276 L F
.72557 .3349 m .7272 .33182 L .7286 .33373 L 0 .033 .134 r
F
.72557 .3349 m .72418 .33297 L .7272 .33182 L F
.23279 .33202 m .2337 .32898 L .23556 .33095 L 0 .027 .126 r
F
.23279 .33202 m .23092 .33005 L .2337 .32898 L F
.3743 .33679 m .37542 .33378 L .37714 .33585 L 0 .037 .139 r
F
.3743 .33679 m .37257 .33473 L .37542 .33378 L F
.62599 .34298 m .62748 .33981 L .62897 .34173 L 0 .052 .155 r
F
.62599 .34298 m .6245 .3411 L .62748 .33981 L F
.16428 .33081 m .16508 .3279 L .16702 .32981 L 0 .025 .123 r
F
.16428 .33081 m .16235 .32889 L .16508 .3279 L F
.13003 .33024 m .13077 .32738 L .13273 .32931 L 0 .024 .122 r
F
.13003 .33024 m .12806 .32831 L .13077 .32738 L F
.53555 .43873 m .53698 .45472 L .5385 .44045 L 0 .442 .184 r
F
.53555 .43873 m .53402 .45232 L .53698 .45472 L F
.39367 .33831 m .39481 .33549 L .39652 .33756 L 0 .041 .143 r
F
.39367 .33831 m .39197 .33622 L .39481 .33549 L F
.75532 .33337 m .75701 .3304 L .75837 .33235 L 0 .03 .13 r
F
.75532 .33337 m .75396 .33143 L .75701 .3304 L F
.74789 .33379 m .74955 .33072 L .75092 .33261 L 0 .031 .131 r
F
.74789 .33379 m .74652 .33193 L .74955 .33072 L F
.27446 .33237 m .27543 .32947 L .27725 .33146 L 0 .028 .128 r
F
.27446 .33237 m .27264 .33038 L .27543 .32947 L F
.32809 .33443 m .32914 .33157 L .33091 .33343 L 0 .032 .133 r
F
.32809 .33443 m .32631 .33257 L .32914 .33157 L F
.49496 .41839 m .49612 .4314 L .49774 .43317 L 0 .384 .257 r
F
.49496 .41839 m .49335 .41661 L .49612 .4314 L F
.83419 .33157 m .83599 .32861 L .83728 .33052 L 0 .026 .126 r
F
.83419 .33157 m .8329 .32966 L .83599 .32861 L F
.6082 .34669 m .60965 .34318 L .61115 .34494 L 0 .062 .164 r
F
.6082 .34669 m .6067 .34493 L .60965 .34318 L F
.2402 .33185 m .24112 .3289 L .24297 .33086 L 0 .027 .126 r
F
.2402 .33185 m .23834 .3299 L .24112 .3289 L F
.17168 .3307 m .17249 .32787 L .17442 .32974 L 0 .025 .124 r
F
.17168 .3307 m .16975 .32883 L .17249 .32787 L F
.61857 .34369 m .62004 .34054 L .62153 .34237 L 0 .055 .157 r
F
.61857 .34369 m .61707 .34191 L .62004 .34054 L F
.3087 .33318 m .30972 .33029 L .3115 .33226 L 0 .03 .13 r
F
.3087 .33318 m .30691 .33123 L .30972 .33029 L F
.47911 .36927 m .47753 .36415 L .48038 .36645 L 0 .146 .226 r
F
.47753 .36415 m .47879 .36209 L .48038 .36645 L 0 .126 .213 r
F
.47753 .36415 m .47592 .36054 L .47879 .36209 L F
.84165 .33137 m .84346 .32843 L .84474 .33034 L 0 .026 .125 r
F
.84165 .33137 m .84037 .32946 L .84346 .32843 L F
.57286 .36643 m .57133 .36538 L .57423 .36082 L 0 .124 .212 r
F
.56995 .37054 m .57133 .36538 L .57286 .36643 L 0 .145 .226 r
F
.56164 .40234 m .56017 .40773 L .56302 .39811 L 0 .309 .307 r
F
.55878 .41103 m .56017 .40773 L .56164 .40234 L 0 .343 .291 r
F
.77765 .33242 m .77937 .32947 L .7807 .33131 L 0 .028 .128 r
F
.77765 .33242 m .77632 .33061 L .77937 .32947 L F
.35489 .33575 m .35599 .33268 L .35773 .33466 L 0 .035 .137 r
F
.35489 .33575 m .35315 .33375 L .35599 .33268 L F
.33551 .33432 m .33658 .33129 L .33834 .33329 L 0 .032 .133 r
F
.33551 .33432 m .33374 .33236 L .33658 .33129 L F
.20593 .33144 m .20678 .32862 L .20867 .33053 L 0 .027 .126 r
F
.20593 .33144 m .20403 .32952 L .20678 .32862 L F
.76278 .3333 m .76447 .33027 L .76583 .33222 L 0 .03 .13 r
F
.76278 .3333 m .76142 .33134 L .76447 .33027 L F
.65124 .33949 m .65276 .33618 L .65422 .33803 L 0 .044 .146 r
F
.65124 .33949 m .64978 .3376 L .65276 .33618 L F
.78509 .33207 m .78682 .32914 L .78815 .33102 L 0 .028 .127 r
F
.78509 .33207 m .78376 .33021 L .78682 .32914 L F
.13741 .33024 m .13816 .32741 L .14013 .32926 L 0 .024 .123 r
F
.13741 .33024 m .13544 .32838 L .13816 .32741 L F
.41304 .34015 m .41421 .33737 L .41589 .33949 L 0 .046 .149 r
F
.41304 .34015 m .41135 .3381 L .41421 .33737 L F
.77022 .33293 m .77192 .32988 L .77327 .33175 L 0 .029 .129 r
F
.77022 .33293 m .76888 .33105 L .77192 .32988 L F
.45497 .35295 m .45622 .34967 L .45786 .3522 L 0 .082 .181 r
F
.45497 .35295 m .45333 .35041 L .45622 .34967 L F
.58749 .35315 m .5889 .34929 L .59043 .3513 L 0 .081 .181 r
F
.58749 .35315 m .58596 .35117 L .5889 .34929 L F
.28187 .33235 m .28285 .32939 L .28467 .33127 L 0 .028 .128 r
F
.28187 .33235 m .28004 .33044 L .28285 .32939 L F
.48069 .37443 m .47911 .36927 L .48195 .37277 L 0 .173 .242 r
F
.47911 .36927 m .48038 .36645 L .48195 .37277 L 0 .146 .226 r
F
.44595 .34844 m .44718 .34558 L .44882 .34814 L 0 .069 .17 r
F
.44595 .34844 m .4443 .34596 L .44718 .34558 L F
.47143 .35711 m .4727 .3538 L .47432 .35693 L 0 .096 .192 r
F
.47143 .35711 m .46981 .35434 L .4727 .3538 L F
.8491 .33113 m .85094 .32835 L .8522 .33015 L 0 .026 .125 r
F
.8491 .33113 m .84784 .32934 L .85094 .32835 L F
.45046 .35074 m .4517 .34775 L .45333 .35041 L 0 .076 .176 r
F
.45046 .35074 m .44882 .34814 L .4517 .34775 L F
.59785 .35012 m .59929 .34667 L .6008 .3486 L 0 .073 .174 r
F
.59785 .35012 m .59633 .34816 L .59929 .34667 L F
.2476 .33178 m .24853 .32888 L .25038 .33077 L 0 .027 .127 r
F
.2476 .33178 m .24575 .32987 L .24853 .32888 L F
.46692 .35489 m .46817 .35206 L .46981 .35434 L 0 .09 .187 r
F
.46692 .35489 m .46528 .35276 L .46817 .35206 L F
.3817 .33694 m .38284 .3338 L .38456 .33591 L 0 .038 .14 r
F
.3817 .33694 m .37999 .33485 L .38284 .3338 L F
.28929 .33205 m .29027 .32933 L .29209 .33116 L 0 .028 .128 r
F
.28929 .33205 m .28747 .3302 L .29027 .32933 L F
.42949 .34443 m .43069 .34159 L .43236 .34375 L 0 .058 .16 r
F
.42949 .34443 m .42782 .3423 L .43069 .34159 L F
.17908 .33062 m .17989 .32784 L .18182 .32967 L 0 .025 .124 r
F
.17908 .33062 m .17716 .32877 L .17989 .32784 L F
.79255 .33189 m .79428 .32887 L .79561 .3308 L 0 .028 .127 r
F
.79255 .33189 m .79122 .32997 L .79428 .32887 L F
.36232 .33561 m .36342 .33265 L .36516 .33461 L 0 .036 .137 r
F
.36232 .33561 m .36058 .33364 L .36342 .33265 L F
.14482 .33004 m .14559 .32716 L .14755 .32898 L 0 .024 .123 r
F
.14482 .33004 m .14286 .32821 L .14559 .32716 L F
.64381 .34018 m .64533 .33707 L .6468 .33899 L 0 .046 .149 r
F
.64381 .34018 m .64234 .33824 L .64533 .33707 L F
.21333 .33132 m .21421 .32838 L .2161 .33023 L 0 .027 .126 r
F
.21333 .33132 m .21144 .32946 L .21421 .32838 L F
.48227 .37985 m .48069 .37443 L .48352 .37916 L 0 .204 .259 r
F
.48069 .37443 m .48195 .37277 L .48352 .37916 L 0 .173 .242 r
F
.70624 .33423 m .70785 .33131 L .70926 .33318 L 0 .033 .134 r
F
.70624 .33423 m .70483 .33239 L .70785 .33131 L F
.44144 .3464 m .44265 .3437 L .4443 .34596 L 0 .064 .166 r
F
.44144 .3464 m .43978 .34424 L .44265 .3437 L F
.85656 .33093 m .85841 .32812 L .85966 .32993 L 0 .026 .125 r
F
.85656 .33093 m .85531 .32914 L .85841 .32812 L F
.68393 .33548 m .6855 .33236 L .68693 .33429 L 0 .035 .136 r
F
.68393 .33548 m .68249 .33355 L .6855 .33236 L F
.79999 .33159 m .80174 .32852 L .80306 .33045 L 0 .027 .126 r
F
.79999 .33159 m .79867 .32966 L .80174 .32852 L F
.55018 .42607 m .54872 .43757 L .55162 .42944 L 0 .387 .254 r
F
.54728 .43233 m .54872 .43757 L .55018 .42607 L 0 .412 .225 r
F
.25502 .33162 m .25596 .32874 L .25781 .33057 L 0 .027 .127 r
F
.25502 .33162 m .25317 .32976 L .25596 .32874 L F
.3161 .33329 m .31712 .33046 L .31891 .3324 L 0 .031 .131 r
F
.3161 .33329 m .31431 .33135 L .31712 .33046 L F
.22076 .33104 m .22163 .32825 L .22352 .33009 L 0 .027 .126 r
F
.22076 .33104 m .21887 .3292 L .22163 .32825 L F
.5686 .37724 m .56708 .37754 L .56995 .37054 L 0 .168 .239 r
F
.56574 .38525 m .56708 .37754 L .5686 .37724 L 0 .218 .266 r
F
.63638 .34074 m .63788 .33745 L .63936 .33941 L 0 .047 .15 r
F
.63638 .34074 m .6349 .33878 L .63788 .33745 L F
.69137 .33517 m .69296 .33225 L .69438 .33413 L 0 .035 .136 r
F
.69137 .33517 m .68994 .33327 L .69296 .33225 L F
.69881 .33477 m .70041 .33176 L .70182 .33357 L 0 .034 .135 r
F
.69881 .33477 m .69739 .33297 L .70041 .33176 L F
.66906 .33643 m .67061 .33336 L .67206 .3353 L 0 .038 .139 r
F
.66906 .33643 m .66761 .3345 L .67061 .33336 L F
.55738 .41318 m .55591 .42083 L .55878 .41103 L 0 .343 .291 r
F
.5545 .42132 m .55591 .42083 L .55738 .41318 L 0 .375 .265 r
F
.15223 .32985 m .153 .32706 L .15495 .3289 L 0 .024 .123 r
F
.15223 .32985 m .15028 .32801 L .153 .32706 L F
.40107 .33875 m .40223 .33585 L .40393 .33783 L 0 .043 .146 r
F
.40107 .33875 m .39937 .33676 L .40223 .33585 L F
.18649 .33053 m .18731 .32774 L .18923 .32954 L 0 .026 .124 r
F
.18649 .33053 m .18456 .32872 L .18731 .32774 L F
.86402 .33074 m .86588 .32786 L .86713 .32971 L 0 .026 .125 r
F
.86402 .33074 m .86277 .32891 L .86588 .32786 L F
.71369 .33404 m .71531 .33111 L .71672 .33303 L 0 .033 .133 r
F
.71369 .33404 m .71228 .33213 L .71531 .33111 L F
.80745 .33137 m .80922 .32848 L .81053 .33039 L 0 .027 .127 r
F
.80745 .33137 m .80613 .32946 L .80922 .32848 L F
.6765 .33612 m .67806 .33288 L .6795 .33483 L 0 .037 .138 r
F
.6765 .33612 m .67506 .33417 L .67806 .33288 L F
.34291 .33448 m .34398 .33159 L .34573 .33367 L 0 .034 .135 r
F
.34291 .33448 m .34116 .33244 L .34398 .33159 L F
.26244 .3314 m .2634 .32841 L .26523 .33033 L 0 .027 .126 r
F
.26244 .3314 m .2606 .32949 L .2634 .32841 L F
.38912 .33698 m .39026 .33413 L .39197 .33622 L 0 .039 .141 r
F
.38912 .33698 m .38741 .33487 L .39026 .33413 L F
.66163 .33705 m .66316 .33382 L .66462 .33572 L F
.66163 .33705 m .66018 .33521 L .66316 .33382 L F
.82234 .33069 m .82413 .32784 L .82542 .32969 L 0 .026 .125 r
F
.82234 .33069 m .82105 .32886 L .82413 .32784 L F
.61115 .34494 m .61262 .34167 L .61411 .34342 L 0 .059 .161 r
F
.61115 .34494 m .60965 .34318 L .61262 .34167 L F
.29669 .33215 m .29768 .32936 L .29949 .33123 L 0 .029 .129 r
F
.29669 .33215 m .29488 .33028 L .29768 .32936 L F
.36973 .33567 m .37084 .33268 L .37257 .33473 L 0 .036 .138 r
F
.36973 .33567 m .368 .33363 L .37084 .33268 L F
.8149 .33114 m .81668 .32819 L .81797 .33 L 0 .027 .126 r
F
.8149 .33114 m .81361 .32935 L .81668 .32819 L F
.48384 .38573 m .48227 .37985 L .48509 .3859 L 0 .242 .278 r
F
.48227 .37985 m .48352 .37916 L .48509 .3859 L 0 .204 .259 r
F
.87149 .33059 m .87335 .3277 L .8746 .32962 L 0 .026 .125 r
F
.87149 .33059 m .87024 .32869 L .87335 .3277 L F
.19389 .33043 m .19474 .32747 L .19664 .32941 L 0 .026 .124 r
F
.19389 .33043 m .19198 .32851 L .19474 .32747 L F
.59043 .3513 m .59185 .34764 L .59338 .34964 L 0 .077 .177 r
F
.59043 .3513 m .5889 .34929 L .59185 .34764 L F
.72115 .33397 m .72278 .33104 L .72418 .33297 L 0 .033 .134 r
F
.72115 .33397 m .71975 .33204 L .72278 .33104 L F
.22815 .33109 m .22906 .32809 L .23092 .33005 L 0 .027 .126 r
F
.22815 .33109 m .22628 .32913 L .22906 .32809 L F
.26985 .3313 m .27081 .3284 L .27264 .33038 L 0 .027 .127 r
F
.26985 .3313 m .26803 .32931 L .27081 .3284 L F
.42496 .34286 m .42615 .34002 L .42782 .3423 L 0 .055 .157 r
F
.42496 .34286 m .42329 .34057 L .42615 .34002 L F
.15962 .32988 m .16041 .32696 L .16235 .32889 L 0 .025 .123 r
F
.15962 .32988 m .15768 .32795 L .16041 .32696 L F
.73603 .33324 m .73769 .33039 L .73907 .33223 L 0 .032 .132 r
F
.73603 .33324 m .73465 .33141 L .73769 .33039 L F
.3235 .33344 m .32453 .33071 L .32631 .33257 L 0 .032 .133 r
F
.3235 .33344 m .32172 .33155 L .32453 .33071 L F
.46239 .35349 m .46364 .35063 L .46528 .35276 L 0 .087 .185 r
F
.46239 .35349 m .46075 .35145 L .46364 .35063 L F
.62897 .34173 m .63045 .33831 L .63193 .34026 L 0 .051 .153 r
F
.62897 .34173 m .62748 .33981 L .63045 .33831 L F
.82981 .33061 m .83161 .32776 L .8329 .32966 L 0 .026 .125 r
F
.82981 .33061 m .82852 .32873 L .83161 .32776 L F
.7286 .33373 m .73023 .33064 L .73162 .33255 L 0 .032 .133 r
F
.7286 .33373 m .7272 .33182 L .73023 .33064 L F
.40849 .33889 m .40966 .33607 L .41135 .3381 L 0 .045 .147 r
F
.40849 .33889 m .40679 .33692 L .40966 .33607 L F
.23556 .33095 m .23648 .32792 L .23834 .3299 L 0 .027 .126 r
F
.23556 .33095 m .2337 .32898 L .23648 .32792 L F
.75092 .33261 m .75259 .32951 L .75396 .33143 L 0 .03 .13 r
F
.75092 .33261 m .74955 .33072 L .75259 .32951 L F
.4369 .34499 m .43811 .34207 L .43978 .34424 L 0 .061 .163 r
F
.4369 .34499 m .43523 .34291 L .43811 .34207 L F
.3041 .33221 m .30511 .32928 L .30691 .33123 L 0 .03 .13 r
F
.3041 .33221 m .3023 .33025 L .30511 .32928 L F
.52068 .44115 m .522 .46177 L .5236 .44897 L 0 .459 .158 r
F
.52068 .44115 m .51907 .4521 L .522 .46177 L F
.87897 .33058 m .88085 .32772 L .88209 .32964 L 0 .026 .126 r
F
.87897 .33058 m .87772 .32867 L .88085 .32772 L F
.74348 .33306 m .74515 .33006 L .74652 .33193 L 0 .031 .132 r
F
.74348 .33306 m .74211 .33122 L .74515 .33006 L F
.65422 .33803 m .65574 .33477 L .6572 .33659 L 0 .042 .144 r
F
.65422 .33803 m .65276 .33618 L .65574 .33477 L F
.62153 .34237 m .62301 .33922 L .6245 .3411 L 0 .053 .156 r
F
.62153 .34237 m .62004 .34054 L .62301 .33922 L F
.47592 .36054 m .47719 .35774 L .47879 .36209 L 0 .113 .205 r
F
.47592 .36054 m .47432 .35693 L .47719 .35774 L F
.20129 .33042 m .20214 .32758 L .20403 .32952 L 0 .026 .125 r
F
.20129 .33042 m .19939 .32847 L .20214 .32758 L F
.16702 .32981 m .16782 .32692 L .16975 .32883 L 0 .025 .124 r
F
.16702 .32981 m .16508 .3279 L .16782 .32692 L F
.6008 .3486 m .60224 .34489 L .60375 .34678 L 0 .069 .171 r
F
.6008 .3486 m .59929 .34667 L .60224 .34489 L F
.37714 .33585 m .37827 .33277 L .37999 .33485 L 0 .037 .139 r
F
.37714 .33585 m .37542 .33378 L .37827 .33277 L F
.35031 .33482 m .3514 .33171 L .35315 .33375 L 0 .035 .136 r
F
.35031 .33482 m .34856 .33276 L .3514 .33171 L F
.75837 .33235 m .76006 .32938 L .76142 .33134 L 0 .03 .13 r
F
.75837 .33235 m .75701 .3304 L .76006 .32938 L F
.56995 .37054 m .56842 .36995 L .57133 .36538 L 0 .145 .226 r
F
.56708 .37754 m .56842 .36995 L .56995 .37054 L 0 .18 .246 r
F
.83728 .33052 m .83908 .32755 L .84037 .32946 L 0 .026 .125 r
F
.83728 .33052 m .83599 .32861 L .83908 .32755 L F
.33091 .33343 m .33197 .3305 L .33374 .33236 L 0 .032 .133 r
F
.33091 .33343 m .32914 .33157 L .33197 .3305 L F
.13273 .32931 m .13348 .32646 L .13544 .32838 L 0 .024 .122 r
F
.13273 .32931 m .13077 .32738 L .13348 .32646 L F
.42043 .34113 m .42161 .33828 L .42329 .34057 L 0 .051 .153 r
F
.42043 .34113 m .41875 .33884 L .42161 .33828 L F
.27725 .33146 m .27822 .32847 L .28004 .33044 L 0 .028 .128 r
F
.27725 .33146 m .27543 .32947 L .27822 .32847 L F
.24297 .33086 m .2439 .3279 L .24575 .32987 L 0 .027 .126 r
F
.24297 .33086 m .24112 .3289 L .2439 .3279 L F
.7807 .33131 m .78243 .32834 L .78376 .33021 L 0 .028 .128 r
F
.7807 .33131 m .77937 .32947 L .78243 .32834 L F
.77327 .33175 m .77497 .32873 L .77632 .33061 L 0 .029 .129 r
F
.77327 .33175 m .77192 .32988 L .77497 .32873 L F
.35773 .33466 m .35883 .33167 L .36058 .33364 L 0 .035 .136 r
F
.35773 .33466 m .35599 .33268 L .35883 .33167 L F
.39652 .33756 m .39767 .33472 L .39937 .33676 L 0 .042 .144 r
F
.39652 .33756 m .39481 .33549 L .39767 .33472 L F
.84474 .33034 m .84657 .32744 L .84784 .32934 L 0 .026 .125 r
F
.84474 .33034 m .84346 .32843 L .84657 .32744 L F
.17442 .32974 m .17523 .32691 L .17716 .32877 L 0 .025 .124 r
F
.17442 .32974 m .17249 .32787 L .17523 .32691 L F
.76583 .33222 m .76752 .32912 L .76888 .33105 L 0 .03 .13 r
F
.76583 .33222 m .76447 .33027 L .76752 .32912 L F
.3115 .33226 m .31253 .32935 L .31431 .33135 L 0 .03 .131 r
F
.3115 .33226 m .30972 .33029 L .31253 .32935 L F
.33834 .33329 m .3394 .3304 L .34116 .33244 L 0 .033 .133 r
F
.33834 .33329 m .33658 .33129 L .3394 .3304 L F
.78815 .33102 m .78989 .32808 L .79122 .32997 L 0 .028 .127 r
F
.78815 .33102 m .78682 .32914 L .78989 .32808 L F
.48542 .39161 m .48384 .38573 L .48665 .39331 L 0 .284 .298 r
F
.48384 .38573 m .48509 .3859 L .48665 .39331 L 0 .242 .278 r
F
.28467 .33127 m .28565 .32835 L .28747 .3302 L 0 .028 .128 r
F
.28467 .33127 m .28285 .32939 L .28565 .32835 L F
.50714 .43487 m .50835 .45367 L .51 .44666 L 0 .44 .188 r
F
.50714 .43487 m .50549 .44025 L .50835 .45367 L F
.57715 .3579 m .57855 .35348 L .58008 .35542 L 0 .099 .194 r
F
.57715 .3579 m .57561 .35604 L .57855 .35348 L F
.57423 .36082 m .57561 .35604 L .57715 .3579 L 0 .109 .202 r
F
.14013 .32926 m .14089 .32637 L .14286 .32821 L 0 .024 .123 r
F
.14013 .32926 m .13816 .32741 L .14089 .32637 L F
.6468 .33899 m .64831 .33571 L .64978 .3376 L 0 .045 .147 r
F
.6468 .33899 m .64533 .33707 L .64831 .33571 L F
.20867 .33053 m .20955 .32755 L .21144 .32946 L 0 .027 .126 r
F
.20867 .33053 m .20678 .32862 L .20955 .32755 L F
.63936 .33941 m .64087 .33629 L .64234 .33824 L 0 .046 .149 r
F
.63936 .33941 m .63788 .33745 L .64087 .33629 L F
.38456 .33591 m .3857 .33275 L .38741 .33487 L 0 .038 .14 r
F
.38456 .33591 m .38284 .3338 L .3857 .33275 L F
.8522 .33015 m .85405 .32732 L .85531 .32914 L 0 .026 .125 r
F
.8522 .33015 m .85094 .32835 L .85405 .32732 L F
.25038 .33077 m .25131 .32789 L .25317 .32976 L 0 .027 .127 r
F
.25038 .33077 m .24853 .32888 L .25131 .32789 L F
.68693 .33429 m .68852 .33137 L .68994 .33327 L 0 .035 .136 r
F
.68693 .33429 m .6855 .33236 L .68852 .33137 L F
.79561 .3308 m .79735 .32773 L .79867 .32966 L 0 .027 .127 r
F
.79561 .3308 m .79428 .32887 L .79735 .32773 L F
.61411 .34342 m .61558 .34016 L .61707 .34191 L 0 .057 .159 r
F
.61411 .34342 m .61262 .34167 L .61558 .34016 L F
.14755 .32898 m .14832 .32619 L .15028 .32801 L 0 .024 .123 r
F
.14755 .32898 m .14559 .32716 L .14832 .32619 L F
.2161 .33023 m .21698 .32736 L .21887 .3292 L 0 .027 .126 r
F
.2161 .33023 m .21421 .32838 L .21698 .32736 L F
.80306 .33045 m .80482 .32754 L .80613 .32946 L F
.80306 .33045 m .80174 .32852 L .80482 .32754 L F
.59338 .34964 m .59481 .34619 L .59633 .34816 L 0 .074 .175 r
F
.59338 .34964 m .59185 .34764 L .59481 .34619 L F
.58008 .35542 m .58148 .35103 L .58301 .35305 L 0 .091 .188 r
F
.58008 .35542 m .57855 .35348 L .58148 .35103 L F
.70182 .33357 m .70342 .33056 L .70483 .33239 L 0 .033 .134 r
F
.70182 .33357 m .70041 .33176 L .70342 .33056 L F
.57423 .36082 m .57269 .35908 L .57561 .35604 L 0 .109 .202 r
F
.57133 .36538 m .57269 .35908 L .57423 .36082 L 0 .126 .213 r
F
.36516 .33461 m .36626 .33167 L .368 .33363 L 0 .036 .137 r
F
.36516 .33461 m .36342 .33265 L .36626 .33167 L F
.18182 .32967 m .18263 .32691 L .18456 .32872 L 0 .026 .124 r
F
.18182 .32967 m .17989 .32784 L .18263 .32691 L F
.70926 .33318 m .71088 .33023 L .71228 .33213 L 0 .033 .133 r
F
.70926 .33318 m .70785 .33131 L .71088 .33023 L F
.6795 .33483 m .68106 .3316 L .68249 .33355 L 0 .036 .137 r
F
.6795 .33483 m .67806 .33288 L .68106 .3316 L F
.45786 .3522 m .45911 .34893 L .46075 .35145 L 0 .083 .182 r
F
.45786 .3522 m .45622 .34967 L .45911 .34893 L F
.29209 .33116 m .29307 .32845 L .29488 .33028 L 0 .029 .129 r
F
.29209 .33116 m .29027 .32933 L .29307 .32845 L F
.85966 .32993 m .86152 .32709 L .86277 .32891 L 0 .026 .125 r
F
.85966 .32993 m .85841 .32812 L .86152 .32709 L F
.67206 .3353 m .67361 .33221 L .67506 .33417 L 0 .037 .139 r
F
.67206 .3353 m .67061 .33336 L .67361 .33221 L F
.66462 .33572 m .66616 .33257 L .66761 .3345 L 0 .038 .14 r
F
.66462 .33572 m .66316 .33382 L .66616 .33257 L F
.25781 .33057 m .25875 .32766 L .2606 .32949 L 0 .027 .127 r
F
.25781 .33057 m .25596 .32874 L .25875 .32766 L F
.41589 .33949 m .41707 .33665 L .41875 .33884 L 0 .048 .15 r
F
.41589 .33949 m .41421 .33737 L .41707 .33665 L F
.69438 .33413 m .69598 .33112 L .69739 .33297 L 0 .035 .136 r
F
.69438 .33413 m .69296 .33225 L .69598 .33112 L F
.60375 .34678 m .60519 .34309 L .6067 .34493 L 0 .066 .167 r
F
.60375 .34678 m .60224 .34489 L .60519 .34309 L F
.22352 .33009 m .2244 .32731 L .22628 .32913 L 0 .027 .126 r
F
.22352 .33009 m .22163 .32825 L .2244 .32731 L F
.26523 .33033 m .26619 .32739 L .26803 .32931 L F
.26523 .33033 m .2634 .32841 L .26619 .32739 L F
.86713 .32971 m .86899 .32681 L .87024 .32869 L 0 .026 .125 r
F
.86713 .32971 m .86588 .32786 L .86899 .32681 L F
.43236 .34375 m .43357 .3407 L .43523 .34291 L 0 .059 .161 r
F
.43236 .34375 m .43069 .34159 L .43357 .3407 L F
.31891 .3324 m .31993 .32963 L .32172 .33155 L 0 .031 .132 r
F
.31891 .3324 m .31712 .33046 L .31993 .32963 L F
.58301 .35305 m .58443 .34913 L .58596 .35117 L 0 .085 .183 r
F
.58301 .35305 m .58148 .35103 L .58443 .34913 L F
.63193 .34026 m .63342 .33681 L .6349 .33878 L 0 .049 .151 r
F
.63193 .34026 m .63045 .33831 L .63342 .33681 L F
.15495 .3289 m .15573 .3261 L .15768 .32795 L 0 .024 .123 r
F
.15495 .3289 m .153 .32706 L .15573 .3261 L F
.71672 .33303 m .71835 .3301 L .71975 .33204 L 0 .033 .133 r
F
.71672 .33303 m .71531 .33111 L .71835 .3301 L F
.18923 .32954 m .19006 .3267 L .19198 .32851 L 0 .026 .124 r
F
.18923 .32954 m .18731 .32774 L .19006 .3267 L F
.81053 .33039 m .8123 .32745 L .81361 .32935 L 0 .027 .126 r
F
.81053 .33039 m .80922 .32848 L .8123 .32745 L F
.46981 .35434 m .47107 .35137 L .4727 .3538 L 0 .092 .189 r
F
.46981 .35434 m .46817 .35206 L .47107 .35137 L F
.40393 .33783 m .40509 .33494 L .40679 .33692 L 0 .044 .146 r
F
.40393 .33783 m .40223 .33585 L .40509 .33494 L F
.81797 .33 m .81975 .32703 L .82105 .32886 L 0 .026 .125 r
F
.81797 .33 m .81668 .32819 L .81975 .32703 L F
.82542 .32969 m .82723 .32686 L .82852 .32873 L F
.82542 .32969 m .82413 .32784 L .82723 .32686 L F
.34573 .33367 m .34681 .33067 L .34856 .33276 L 0 .034 .135 r
F
.34573 .33367 m .34398 .33159 L .34681 .33067 L F
.44882 .34814 m .45005 .34512 L .4517 .34775 L 0 .072 .173 r
F
.44882 .34814 m .44718 .34558 L .45005 .34512 L F
.45333 .35041 m .45458 .34702 L .45622 .34967 L 0 .078 .178 r
F
.45333 .35041 m .4517 .34775 L .45458 .34702 L F
.37257 .33473 m .37369 .33173 L .37542 .33378 L 0 .037 .138 r
F
.37257 .33473 m .37084 .33268 L .37369 .33173 L F
.29949 .33123 m .30049 .3284 L .3023 .33025 L 0 .029 .129 r
F
.29949 .33123 m .29768 .32936 L .30049 .3284 L F
.6572 .33659 m .65873 .3334 L .66018 .33521 L 0 .04 .142 r
F
.6572 .33659 m .65574 .33477 L .65873 .3334 L F
.19664 .32941 m .19749 .32652 L .19939 .32847 L 0 .026 .124 r
F
.19664 .32941 m .19474 .32747 L .19749 .32652 L F
.8746 .32962 m .87648 .32675 L .87772 .32867 L 0 .026 .125 r
F
.8746 .32962 m .87335 .3277 L .87648 .32675 L F
.39197 .33622 m .39311 .33342 L .39481 .33549 L 0 .04 .142 r
F
.39197 .33622 m .39026 .33413 L .39311 .33342 L F
.23092 .33005 m .23184 .32703 L .2337 .32898 L 0 .027 .126 r
F
.23092 .33005 m .22906 .32809 L .23184 .32703 L F
.73162 .33255 m .73327 .32951 L .73465 .33141 L 0 .032 .132 r
F
.73162 .33255 m .73023 .33064 L .73327 .32951 L F
.4443 .34596 m .44552 .34321 L .44718 .34558 L 0 .066 .168 r
F
.4443 .34596 m .44265 .3437 L .44552 .34321 L F
.72418 .33297 m .72581 .32989 L .7272 .33182 L 0 .033 .133 r
F
.72418 .33297 m .72278 .33104 L .72581 .32989 L F
.47432 .35693 m .47558 .35405 L .47719 .35774 L 0 .102 .197 r
F
.47432 .35693 m .4727 .3538 L .47558 .35405 L F
.48699 .39752 m .48542 .39161 L .48821 .40073 L 0 .317 .304 r
F
.48542 .39161 m .48665 .39331 L .48821 .40073 L 0 .284 .298 r
F
.16235 .32889 m .16315 .32598 L .16508 .3279 L 0 .025 .123 r
F
.16235 .32889 m .16041 .32696 L .16315 .32598 L F
.6245 .3411 m .62599 .33788 L .62748 .33981 L 0 .052 .154 r
F
.6245 .3411 m .62301 .33922 L .62599 .33788 L F
.73907 .33223 m .74074 .32937 L .74211 .33122 L 0 .032 .132 r
F
.73907 .33223 m .73769 .33039 L .74074 .32937 L F
.12806 .32831 m .1288 .32545 L .13077 .32738 L 0 .024 .122 r
F
.12806 .32831 m .12609 .32637 L .1288 .32545 L F
.27264 .33038 m .2736 .32748 L .27543 .32947 L 0 .028 .127 r
F
.27264 .33038 m .27081 .3284 L .2736 .32748 L F
.75396 .33143 m .75564 .32847 L .75701 .3304 L 0 .03 .13 r
F
.75396 .33143 m .75259 .32951 L .75564 .32847 L F
.74652 .33193 m .74818 .32883 L .74955 .33072 L 0 .031 .131 r
F
.74652 .33193 m .74515 .33006 L .74818 .32883 L F
.8329 .32966 m .83471 .32671 L .83599 .32861 L 0 .026 .125 r
F
.8329 .32966 m .83161 .32776 L .83471 .32671 L F
.32631 .33257 m .32736 .32972 L .32914 .33157 L 0 .032 .133 r
F
.32631 .33257 m .32453 .33071 L .32736 .32972 L F
.23834 .3299 m .23926 .32691 L .24112 .3289 L 0 .027 .126 r
F
.23834 .3299 m .23648 .32792 L .23926 .32691 L F
.49335 .41661 m .49452 .42699 L .49612 .4314 L 0 .38 .261 r
F
.49335 .41661 m .49175 .41286 L .49452 .42699 L F
.30691 .33123 m .30792 .32832 L .30972 .33029 L 0 .03 .13 r
F
.30691 .33123 m .30511 .32928 L .30792 .32832 L F
.35315 .33375 m .35424 .33066 L .35599 .33268 L 0 .035 .136 r
F
.35315 .33375 m .3514 .33171 L .35424 .33066 L F
.46528 .35276 m .46654 .34978 L .46817 .35206 L 0 .088 .186 r
F
.46528 .35276 m .46364 .35063 L .46654 .34978 L F
.41135 .3381 m .41252 .33526 L .41421 .33737 L 0 .046 .148 r
F
.41135 .3381 m .40966 .33607 L .41252 .33526 L F
.6067 .34493 m .60815 .34138 L .60965 .34318 L 0 .062 .164 r
F
.6067 .34493 m .60519 .34309 L .60815 .34138 L F
.16975 .32883 m .17056 .32595 L .17249 .32787 L 0 .025 .124 r
F
.16975 .32883 m .16782 .32692 L .17056 .32595 L F
.84037 .32946 m .84218 .32652 L .84346 .32843 L 0 .026 .125 r
F
.84037 .32946 m .83908 .32755 L .84218 .32652 L F
.33374 .33236 m .3348 .32943 L .33658 .33129 L 0 .032 .133 r
F
.33374 .33236 m .33197 .3305 L .3348 .32943 L F
.76142 .33134 m .76311 .32831 L .76447 .33027 L 0 .03 .13 r
F
.76142 .33134 m .76006 .32938 L .76311 .32831 L F
.37999 .33485 m .38113 .3317 L .38284 .3338 L 0 .037 .139 r
F
.37999 .33485 m .37827 .33277 L .38113 .3317 L F
.58596 .35117 m .58737 .34722 L .5889 .34929 L 0 .08 .18 r
F
.58596 .35117 m .58443 .34913 L .58737 .34722 L F
.42782 .3423 m .42902 .3393 L .43069 .34159 L 0 .056 .159 r
F
.42782 .3423 m .42615 .34002 L .42902 .3393 L F
.20403 .32952 m .20489 .32667 L .20678 .32862 L 0 .027 .126 r
F
.20403 .32952 m .20214 .32758 L .20489 .32667 L F
.61707 .34191 m .61855 .33879 L .62004 .34054 L 0 .055 .157 r
F
.61707 .34191 m .61558 .34016 L .61855 .33879 L F
.64978 .3376 m .65129 .33431 L .65276 .33618 L 0 .044 .146 r
F
.64978 .3376 m .64831 .33571 L .65129 .33431 L F
.77632 .33061 m .77803 .32759 L .77937 .32947 L 0 .029 .128 r
F
.77632 .33061 m .77497 .32873 L .77803 .32759 L F
.43978 .34424 m .44099 .34143 L .44265 .3437 L 0 .062 .164 r
F
.43978 .34424 m .43811 .34207 L .44099 .34143 L F
.59633 .34816 m .59777 .34473 L .59929 .34667 L 0 .072 .173 r
F
.59633 .34816 m .59481 .34619 L .59777 .34473 L F
.78376 .33021 m .78549 .32726 L .78682 .32914 L 0 .028 .127 r
F
.78376 .33021 m .78243 .32834 L .78549 .32726 L F
.76888 .33105 m .77057 .32797 L .77192 .32988 L 0 .029 .129 r
F
.76888 .33105 m .76752 .32912 L .77057 .32797 L F
.28004 .33044 m .28103 .32743 L .28285 .32939 L 0 .028 .128 r
F
.28004 .33044 m .27822 .32847 L .28103 .32743 L F
.13544 .32838 m .1362 .32549 L .13816 .32741 L 0 .024 .123 r
F
.13544 .32838 m .13348 .32646 L .1362 .32549 L F
.24575 .32987 m .24668 .32692 L .24853 .32888 L 0 .027 .127 r
F
.24575 .32987 m .2439 .3279 L .24668 .32692 L F
.36058 .33364 m .36168 .33068 L .36342 .33265 L 0 .035 .136 r
F
.36058 .33364 m .35883 .33167 L .36168 .33068 L F
.84784 .32934 m .84967 .32644 L .85094 .32835 L 0 .026 .125 r
F
.84784 .32934 m .84657 .32744 L .84967 .32644 L F
.79122 .32997 m .79296 .32696 L .79428 .32887 L 0 .027 .127 r
F
.79122 .32997 m .78989 .32808 L .79296 .32696 L F
.56302 .39811 m .56154 .40196 L .56437 .39093 L 0 .284 .297 r
F
.56017 .40773 m .56154 .40196 L .56302 .39811 L 0 .336 .295 r
F
.64234 .33824 m .64385 .33513 L .64533 .33707 L 0 .046 .148 r
F
.64234 .33824 m .64087 .33629 L .64385 .33513 L F
.28747 .3302 m .28845 .32748 L .29027 .32933 L 0 .028 .128 r
F
.28747 .3302 m .28565 .32835 L .28845 .32748 L F
.17716 .32877 m .17796 .32599 L .17989 .32784 L 0 .025 .124 r
F
.17716 .32877 m .17523 .32691 L .17796 .32599 L F
.68249 .33355 m .68406 .33042 L .6855 .33236 L 0 .035 .136 r
F
.68249 .33355 m .68106 .3316 L .68406 .33042 L F
.14286 .32821 m .14362 .32533 L .14559 .32716 L 0 .024 .123 r
F
.14286 .32821 m .14089 .32637 L .14362 .32533 L F
.79867 .32966 m .80041 .32659 L .80174 .32852 L 0 .027 .126 r
F
.79867 .32966 m .79735 .32773 L .80041 .32659 L F
.21144 .32946 m .21232 .32649 L .21421 .32838 L F
.21144 .32946 m .20955 .32755 L .21232 .32649 L F
.6349 .33878 m .6364 .33547 L .63788 .33745 L 0 .047 .149 r
F
.6349 .33878 m .63342 .33681 L .6364 .33547 L F
.31431 .33135 m .31534 .32844 L .31712 .33046 L 0 .031 .131 r
F
.31431 .33135 m .31253 .32935 L .31534 .32844 L F
.70483 .33239 m .70644 .32945 L .70785 .33131 L 0 .033 .134 r
F
.70483 .33239 m .70342 .33056 L .70644 .32945 L F
.38741 .33487 m .38855 .33201 L .39026 .33413 L 0 .038 .14 r
F
.38741 .33487 m .3857 .33275 L .38855 .33201 L F
.39937 .33676 m .40053 .33385 L .40223 .33585 L 0 .043 .145 r
F
.39937 .33676 m .39767 .33472 L .40053 .33385 L F
.66761 .3345 m .66916 .33141 L .67061 .33336 L 0 .037 .139 r
F
.66761 .3345 m .66616 .33257 L .66916 .33141 L F
.85531 .32914 m .85715 .3263 L .85841 .32812 L 0 .026 .125 r
F
.85531 .32914 m .85405 .32732 L .85715 .3263 L F
.25317 .32976 m .2541 .3269 L .25596 .32874 L 0 .027 .127 r
F
.25317 .32976 m .25131 .32789 L .2541 .3269 L F
.34116 .33244 m .34223 .32951 L .34398 .33159 L 0 .033 .134 r
F
.34116 .33244 m .3394 .3304 L .34223 .32951 L F
.68994 .33327 m .69154 .33037 L .69296 .33225 L 0 .035 .136 r
F
.68994 .33327 m .68852 .33137 L .69154 .33037 L F
.21887 .3292 m .21974 .32642 L .22163 .32825 L 0 .027 .126 r
F
.21887 .3292 m .21698 .32736 L .21974 .32642 L F
.67506 .33417 m .67661 .33093 L .67806 .33288 L 0 .036 .138 r
F
.67506 .33417 m .67361 .33221 L .67661 .33093 L F
.42329 .34057 m .42448 .33772 L .42615 .34002 L 0 .053 .155 r
F
.42329 .34057 m .42161 .33828 L .42448 .33772 L F
.71228 .33213 m .71391 .32918 L .71531 .33111 L 0 .032 .133 r
F
.71228 .33213 m .71088 .33023 L .71391 .32918 L F
.15028 .32801 m .15104 .32525 L .153 .32706 L 0 .024 .123 r
F
.15028 .32801 m .14832 .32619 L .15104 .32525 L F
.69739 .33297 m .69899 .32994 L .70041 .33176 L 0 .034 .135 r
F
.69739 .33297 m .69598 .33112 L .69899 .32994 L F
.80613 .32946 m .8079 .32657 L .80922 .32848 L 0 .027 .126 r
F
.80613 .32946 m .80482 .32754 L .8079 .32657 L F
.2606 .32949 m .26155 .32658 L .2634 .32841 L F
.2606 .32949 m .25875 .32766 L .26155 .32658 L F
.368 .33363 m .36911 .33076 L .37084 .33268 L 0 .036 .137 r
F
.368 .33363 m .36626 .33167 L .36911 .33076 L F
.86277 .32891 m .86462 .32602 L .86588 .32786 L 0 .026 .125 r
F
.86277 .32891 m .86152 .32709 L .86462 .32602 L F
.18456 .32872 m .18538 .32594 L .18731 .32774 L F
.18456 .32872 m .18263 .32691 L .18538 .32594 L F
.56437 .39093 m .56287 .39328 L .56574 .38525 L 0 .25 .282 r
F
.56154 .40196 m .56287 .39328 L .56437 .39093 L 0 .317 .304 r
F
.66018 .33521 m .66172 .33204 L .66316 .33382 L 0 .039 .141 r
F
.66018 .33521 m .65873 .3334 L .66172 .33204 L F
.57133 .36538 m .56979 .3639 L .57269 .35908 L 0 .126 .213 r
F
.56842 .36995 m .56979 .3639 L .57133 .36538 L 0 .15 .229 r
F
.29488 .33028 m .29587 .32754 L .29768 .32936 L 0 .029 .129 r
F
.29488 .33028 m .29307 .32845 L .29587 .32754 L F
.5889 .34929 m .59033 .34558 L .59185 .34764 L 0 .076 .177 r
F
.5889 .34929 m .58737 .34722 L .59033 .34558 L F
.82105 .32886 m .82284 .32599 L .82413 .32784 L 0 .026 .125 r
F
.82105 .32886 m .81975 .32703 L .82284 .32599 L F
.54728 .43233 m .54581 .44526 L .54872 .43757 L 0 .412 .225 r
F
.54436 .43592 m .54581 .44526 L .54728 .43233 L 0 .43 .202 r
F
.87024 .32869 m .8721 .32581 L .87335 .3277 L 0 .026 .125 r
F
.87024 .32869 m .86899 .32681 L .8721 .32581 L F
.26803 .32931 m .26898 .32648 L .27081 .3284 L 0 .027 .126 r
F
.26803 .32931 m .26619 .32739 L .26898 .32648 L F
.19198 .32851 m .19282 .32565 L .19474 .32747 L 0 .026 .124 r
F
.19198 .32851 m .19006 .3267 L .19282 .32565 L F
.22628 .32913 m .22717 .32627 L .22906 .32809 L 0 .027 .126 r
F
.22628 .32913 m .2244 .32731 L .22717 .32627 L F
.60965 .34318 m .61112 .3399 L .61262 .34167 L 0 .059 .162 r
F
.60965 .34318 m .60815 .34138 L .61112 .3399 L F
.81361 .32935 m .81537 .32631 L .81668 .32819 L 0 .027 .126 r
F
.81361 .32935 m .8123 .32745 L .81537 .32631 L F
.5385 .44045 m .53993 .45378 L .54143 .43951 L 0 .448 .175 r
F
.5385 .44045 m .53698 .45472 L .53993 .45378 L F
.46075 .35145 m .462 .3481 L .46364 .35063 L 0 .084 .183 r
F
.46075 .35145 m .45911 .34893 L .462 .3481 L F
.71975 .33204 m .72138 .3291 L .72278 .33104 L 0 .033 .133 r
F
.71975 .33204 m .71835 .3301 L .72138 .3291 L F
.15768 .32795 m .15846 .32513 L .16041 .32696 L 0 .025 .123 r
F
.15768 .32795 m .15573 .3261 L .15846 .32513 L F
.49175 .41286 m .49292 .42257 L .49452 .42699 L 0 .37 .27 r
F
.49175 .41286 m .49015 .4091 L .49292 .42257 L F
.40679 .33692 m .40796 .33406 L .40966 .33607 L 0 .044 .146 r
F
.40679 .33692 m .40509 .33494 L .40796 .33406 L F
.62748 .33981 m .62896 .33636 L .63045 .33831 L 0 .05 .153 r
F
.62748 .33981 m .62599 .33788 L .62896 .33636 L F
.43523 .34291 m .43645 .3398 L .43811 .34207 L 0 .059 .162 r
F
.43523 .34291 m .43357 .3407 L .43645 .3398 L F
.32172 .33155 m .32275 .32881 L .32453 .33071 L 0 .032 .133 r
F
.32172 .33155 m .31993 .32963 L .32275 .32881 L F
.7272 .33182 m .72884 .32873 L .73023 .33064 L F
.7272 .33182 m .72581 .32989 L .72884 .32873 L F
.41875 .33884 m .41994 .33605 L .42161 .33828 L 0 .049 .152 r
F
.41875 .33884 m .41707 .33665 L .41994 .33605 L F
.73465 .33141 m .73631 .32852 L .73769 .33039 L 0 .032 .132 r
F
.73465 .33141 m .73327 .32951 L .73631 .32852 L F
.82852 .32873 m .83032 .32588 L .83161 .32776 L 0 .026 .125 r
F
.82852 .32873 m .82723 .32686 L .83032 .32588 L F
.51164 .43963 m .51288 .46022 L .51453 .45134 L 0 .459 .158 r
F
.51164 .43963 m .51 .44666 L .51288 .46022 L F
.2337 .32898 m .23462 .32597 L .23648 .32792 L 0 .027 .126 r
F
.2337 .32898 m .23184 .32703 L .23462 .32597 L F
.3023 .33025 m .3033 .32744 L .30511 .32928 L 0 .029 .129 r
F
.3023 .33025 m .30049 .3284 L .3033 .32744 L F
.37542 .33378 m .37654 .33071 L .37827 .33277 L 0 .037 .138 r
F
.37542 .33378 m .37369 .33173 L .37654 .33071 L F
.34856 .33276 m .34965 .32963 L .3514 .33171 L 0 .034 .135 r
F
.34856 .33276 m .34681 .33067 L .34965 .32963 L F
.74955 .33072 m .75122 .3276 L .75259 .32951 L 0 .03 .13 r
F
.74955 .33072 m .74818 .32883 L .75122 .3276 L F
.87772 .32867 m .8796 .32579 L .88085 .32772 L 0 .026 .125 r
F
.87772 .32867 m .87648 .32675 L .8796 .32579 L F
.19939 .32847 m .20024 .32563 L .20214 .32758 L F
.19939 .32847 m .19749 .32652 L .20024 .32563 L F
.59929 .34667 m .60073 .34299 L .60224 .34489 L 0 .069 .17 r
F
.59929 .34667 m .59777 .34473 L .60073 .34299 L F
.16508 .3279 m .16589 .325 L .16782 .32692 L 0 .025 .123 r
F
.16508 .3279 m .16315 .32598 L .16589 .325 L F
.74211 .33122 m .74378 .32821 L .74515 .33006 L 0 .031 .132 r
F
.74211 .33122 m .74074 .32937 L .74378 .32821 L F
.65276 .33618 m .65428 .33293 L .65574 .33477 L 0 .042 .144 r
F
.65276 .33618 m .65129 .33431 L .65428 .33293 L F
.75701 .3304 m .75869 .32742 L .76006 .32938 L 0 .03 .13 r
F
.75701 .3304 m .75564 .32847 L .75869 .32742 L F
.62004 .34054 m .62153 .33749 L .62301 .33922 L 0 .053 .156 r
F
.62004 .34054 m .61855 .33879 L .62153 .33749 L F
.4727 .3538 m .47396 .35136 L .47558 .35405 L 0 .096 .192 r
F
.4727 .3538 m .47107 .35137 L .47396 .35136 L F
.45622 .34967 m .45747 .34629 L .45911 .34893 L 0 .079 .179 r
F
.45622 .34967 m .45458 .34702 L .45747 .34629 L F
.83599 .32861 m .8378 .32565 L .83908 .32755 L 0 .026 .125 r
F
.83599 .32861 m .83471 .32671 L .8378 .32565 L F
.13077 .32738 m .13151 .32453 L .13348 .32646 L 0 .024 .122 r
F
.13077 .32738 m .1288 .32545 L .13151 .32453 L F
.27543 .32947 m .2764 .32649 L .27822 .32847 L 0 .028 .127 r
F
.27543 .32947 m .2736 .32748 L .2764 .32649 L F
.51616 .44226 m .51744 .46316 L .51907 .4521 L 0 .467 .145 r
F
.51616 .44226 m .51453 .45134 L .51744 .46316 L F
.32914 .33157 m .33019 .32866 L .33197 .3305 L 0 .032 .133 r
F
.32914 .33157 m .32736 .32972 L .33019 .32866 L F
.39481 .33549 m .39596 .33268 L .39767 .33472 L 0 .041 .143 r
F
.39481 .33549 m .39311 .33342 L .39596 .33268 L F
.24112 .3289 m .24204 .3259 L .2439 .3279 L 0 .027 .126 r
F
.24112 .3289 m .23926 .32691 L .24204 .3259 L F
.52812 .44417 m .5295 .4641 L .53107 .44993 L 0 .47 .139 r
F
.52812 .44417 m .52654 .45679 L .5295 .4641 L F
.35599 .33268 m .35709 .32965 L .35883 .33167 L 0 .035 .136 r
F
.35599 .33268 m .35424 .33066 L .35709 .32965 L F
.33658 .33129 m .33763 .32853 L .3394 .3304 L 0 .032 .133 r
F
.33658 .33129 m .3348 .32943 L .33763 .32853 L F
.76447 .33027 m .76616 .32718 L .76752 .32912 L 0 .03 .13 r
F
.76447 .33027 m .76311 .32831 L .76616 .32718 L F
.30972 .33029 m .31074 .32735 L .31253 .32935 L F
.30972 .33029 m .30792 .32832 L .31074 .32735 L F
.38284 .3338 m .38399 .33063 L .3857 .33275 L 0 .037 .139 r
F
.38284 .3338 m .38113 .3317 L .38399 .33063 L F
.84346 .32843 m .84529 .32553 L .84657 .32744 L 0 .026 .125 r
F
.84346 .32843 m .84218 .32652 L .84529 .32553 L F
.77192 .32988 m .77363 .32683 L .77497 .32873 L 0 .029 .129 r
F
.77192 .32988 m .77057 .32797 L .77363 .32683 L F
.77937 .32947 m .78109 .32647 L .78243 .32834 L 0 .028 .128 r
F
.77937 .32947 m .77803 .32759 L .78109 .32647 L F
.17249 .32787 m .1733 .32498 L .17523 .32691 L 0 .025 .124 r
F
.17249 .32787 m .17056 .32595 L .1733 .32498 L F
.54436 .43592 m .54287 .44952 L .54581 .44526 L 0 .43 .202 r
F
.54143 .43951 m .54287 .44952 L .54436 .43592 L 0 .442 .184 r
F
.78682 .32914 m .78856 .32618 L .78989 .32808 L 0 .028 .127 r
F
.78682 .32914 m .78549 .32726 L .78856 .32618 L F
.4517 .34775 m .45294 .34439 L .45458 .34702 L 0 .074 .175 r
F
.4517 .34775 m .45005 .34512 L .45294 .34439 L F
.28285 .32939 m .28383 .3264 L .28565 .32835 L 0 .028 .128 r
F
.28285 .32939 m .28103 .32743 L .28383 .3264 L F
.57561 .35604 m .57701 .35152 L .57855 .35348 L 0 .098 .194 r
F
.57561 .35604 m .57408 .35417 L .57701 .35152 L F
.57269 .35908 m .57408 .35417 L .57561 .35604 L 0 .109 .202 r
F
.63788 .33745 m .63939 .33431 L .64087 .33629 L 0 .046 .148 r
F
.63788 .33745 m .6364 .33547 L .63939 .33431 L F
.64533 .33707 m .64684 .3338 L .64831 .33571 L 0 .045 .147 r
F
.64533 .33707 m .64385 .33513 L .64684 .3338 L F
.20678 .32862 m .20766 .32561 L .20955 .32755 L 0 .027 .126 r
F
.20678 .32862 m .20489 .32667 L .20766 .32561 L F
.44718 .34558 m .4484 .34266 L .45005 .34512 L 0 .069 .17 r
F
.44718 .34558 m .44552 .34321 L .4484 .34266 L F
.59185 .34764 m .59329 .34414 L .59481 .34619 L 0 .074 .174 r
F
.59185 .34764 m .59033 .34558 L .59329 .34414 L F
.6855 .33236 m .68708 .32944 L .68852 .33137 L 0 .035 .136 r
F
.6855 .33236 m .68406 .33042 L .68708 .32944 L F
.13816 .32741 m .13893 .32446 L .14089 .32637 L 0 .024 .123 r
F
.13816 .32741 m .1362 .32549 L .13893 .32446 L F
.48195 .37277 m .48038 .36645 L .48325 .3688 L 0 .173 .242 r
F
.48038 .36645 m .48166 .36368 L .48325 .3688 L 0 .145 .226 r
F
.48038 .36645 m .47879 .36209 L .48166 .36368 L F
.79428 .32887 m .79602 .32581 L .79735 .32773 L 0 .027 .126 r
F
.79428 .32887 m .79296 .32696 L .79602 .32581 L F
.24853 .32888 m .24946 .32595 L .25131 .32789 L 0 .027 .127 r
F
.24853 .32888 m .24668 .32692 L .24946 .32595 L F
.57855 .35348 m .57994 .349 L .58148 .35103 L 0 .09 .188 r
F
.57855 .35348 m .57701 .35152 L .57994 .349 L F
.41421 .33737 m .41539 .33446 L .41707 .33665 L 0 .046 .149 r
F
.41421 .33737 m .41252 .33526 L .41539 .33446 L F
.46817 .35206 m .46944 .34893 L .47107 .35137 L 0 .089 .187 r
F
.46817 .35206 m .46654 .34978 L .46944 .34893 L F
.36342 .33265 m .36452 .3297 L .36626 .33167 L 0 .035 .137 r
F
.36342 .33265 m .36168 .33068 L .36452 .3297 L F
.80174 .32852 m .8035 .32561 L .80482 .32754 L 0 .027 .126 r
F
.80174 .32852 m .80041 .32659 L .8035 .32561 L F
.67806 .33288 m .67961 .32965 L .68106 .3316 L 0 .035 .137 r
F
.67806 .33288 m .67661 .33093 L .67961 .32965 L F
.85094 .32835 m .85278 .32543 L .85405 .32732 L 0 .026 .125 r
F
.85094 .32835 m .84967 .32644 L .85278 .32543 L F
.43069 .34159 m .4319 .33837 L .43357 .3407 L 0 .057 .159 r
F
.43069 .34159 m .42902 .3393 L .4319 .33837 L F
.21421 .32838 m .21509 .32547 L .21698 .32736 L 0 .027 .126 r
F
.21421 .32838 m .21232 .32649 L .21509 .32547 L F
.14559 .32716 m .14635 .32437 L .14832 .32619 L 0 .024 .123 r
F
.14559 .32716 m .14362 .32533 L .14635 .32437 L F
.67061 .33336 m .67217 .33025 L .67361 .33221 L 0 .037 .138 r
F
.67061 .33336 m .66916 .33141 L .67217 .33025 L F
.70785 .33131 m .70947 .32835 L .71088 .33023 L 0 .032 .133 r
F
.70785 .33131 m .70644 .32945 L .70947 .32835 L F
.66316 .33382 m .66471 .33082 L .66616 .33257 L 0 .038 .14 r
F
.66316 .33382 m .66172 .33204 L .66471 .33082 L F
.70041 .33176 m .70201 .32878 L .70342 .33056 L 0 .033 .134 r
F
.70041 .33176 m .69899 .32994 L .70201 .32878 L F
.61262 .34167 m .61408 .33842 L .61558 .34016 L 0 .057 .16 r
F
.61262 .34167 m .61112 .3399 L .61408 .33842 L F
.17989 .32784 m .1807 .32507 L .18263 .32691 L 0 .026 .125 r
F
.17989 .32784 m .17796 .32599 L .1807 .32507 L F
.29027 .32933 m .29125 .32661 L .29307 .32845 L 0 .029 .129 r
F
.29027 .32933 m .28845 .32748 L .29125 .32661 L F
.57269 .35908 m .57115 .35734 L .57408 .35417 L 0 .109 .202 r
F
.56979 .3639 m .57115 .35734 L .57269 .35908 L 0 .128 .214 r
F
.58148 .35103 m .58289 .34708 L .58443 .34913 L 0 .084 .183 r
F
.58148 .35103 m .57994 .349 L .58289 .34708 L F
.49015 .4091 m .49135 .41552 L .49292 .42257 L 0 .356 .281 r
F
.25596 .32874 m .2569 .32583 L .25875 .32766 L 0 .027 .127 r
F
.25596 .32874 m .2541 .3269 L .2569 .32583 L F
.85841 .32812 m .86026 .32526 L .86152 .32709 L 0 .026 .125 r
F
.85841 .32812 m .85715 .3263 L .86026 .32526 L F
.69296 .33225 m .69456 .32927 L .69598 .33112 L 0 .035 .136 r
F
.69296 .33225 m .69154 .33037 L .69456 .32927 L F
.60224 .34489 m .60368 .34124 L .60519 .34309 L 0 .066 .167 r
F
.60224 .34489 m .60073 .34299 L .60368 .34124 L F
.31712 .33046 m .31815 .32763 L .31993 .32963 L 0 .031 .132 r
F
.31712 .33046 m .31534 .32844 L .31815 .32763 L F
.63045 .33831 m .63193 .33483 L .63342 .33681 L 0 .048 .151 r
F
.63045 .33831 m .62896 .33636 L .63193 .33483 L F
.2634 .32841 m .26434 .32556 L .26619 .32739 L 0 .027 .126 r
F
.2634 .32841 m .26155 .32658 L .26434 .32556 L F
.44265 .3437 m .44387 .34084 L .44552 .34321 L 0 .064 .166 r
F
.44265 .3437 m .44099 .34143 L .44387 .34084 L F
.40223 .33585 m .40339 .33299 L .40509 .33494 L 0 .043 .145 r
F
.40223 .33585 m .40053 .33385 L .40339 .33299 L F
.71531 .33111 m .71694 .32816 L .71835 .3301 L 0 .032 .133 r
F
.71531 .33111 m .71391 .32918 L .71694 .32816 L F
.22163 .32825 m .22251 .32548 L .2244 .32731 L 0 .027 .126 r
F
.22163 .32825 m .21974 .32642 L .22251 .32548 L F
.86588 .32786 m .86773 .32494 L .86899 .32681 L 0 .026 .125 r
F
.86588 .32786 m .86462 .32602 L .86773 .32494 L F
.80922 .32848 m .81099 .32555 L .8123 .32745 L 0 .027 .126 r
F
.80922 .32848 m .8079 .32657 L .81099 .32555 L F
.34398 .33159 m .34506 .32857 L .34681 .33067 L 0 .033 .134 r
F
.34398 .33159 m .34223 .32951 L .34506 .32857 L F
.153 .32706 m .15377 .3243 L .15573 .3261 L 0 .025 .123 r
F
.153 .32706 m .15104 .32525 L .15377 .3243 L F
.37084 .33268 m .37195 .32985 L .37369 .33173 L 0 .036 .138 r
F
.37084 .33268 m .36911 .33076 L .37195 .32985 L F
.39026 .33413 m .3914 .3313 L .39311 .33342 L 0 .039 .141 r
F
.39026 .33413 m .38855 .33201 L .3914 .3313 L F
.18731 .32774 m .18814 .3249 L .19006 .3267 L 0 .026 .125 r
F
.18731 .32774 m .18538 .32594 L .18814 .3249 L F
.50101 .43146 m .5022 .44673 L .50384 .4452 L 0 .43 .202 r
F
.50101 .43146 m .49938 .43232 L .5022 .44673 L F
.81668 .32819 m .81845 .32517 L .81975 .32703 L 0 .026 .126 r
F
.81668 .32819 m .81537 .32631 L .81845 .32517 L F
.47879 .36209 m .48007 .35857 L .48166 .36368 L 0 .126 .214 r
F
.47879 .36209 m .47719 .35774 L .48007 .35857 L F
.82413 .32784 m .82593 .32499 L .82723 .32686 L 0 .026 .125 r
F
.82413 .32784 m .82284 .32599 L .82593 .32499 L F
.19474 .32747 m .19557 .32471 L .19749 .32652 L 0 .026 .124 r
F
.19474 .32747 m .19282 .32565 L .19557 .32471 L F
.22906 .32809 m .22995 .32522 L .23184 .32703 L 0 .027 .126 r
F
.22906 .32809 m .22717 .32627 L .22995 .32522 L F
.29768 .32936 m .29868 .32661 L .30049 .3284 L 0 .029 .129 r
F
.29768 .32936 m .29587 .32754 L .29868 .32661 L F
.87335 .3277 m .87523 .32484 L .87648 .32675 L 0 .026 .125 r
F
.87335 .3277 m .8721 .32581 L .87523 .32484 L F
.54143 .43951 m .53993 .45378 L .54287 .44952 L 0 .442 .184 r
F
.72278 .33104 m .72441 .32795 L .72581 .32989 L 0 .032 .133 r
F
.72278 .33104 m .72138 .3291 L .72441 .32795 L F
.65574 .33477 m .65727 .3316 L .65873 .3334 L 0 .041 .143 r
F
.65574 .33477 m .65428 .33293 L .65727 .3316 L F
.73023 .33064 m .73188 .32762 L .73327 .32951 L 0 .032 .132 r
F
.73023 .33064 m .72884 .32873 L .73188 .32762 L F
.56574 .38525 m .56423 .38657 L .56708 .37754 L 0 .218 .266 r
F
.56708 .37754 m .56556 .37771 L .56842 .36995 L 0 .18 .246 r
F
.56423 .38657 m .56556 .37771 L .56708 .37754 L 0 .239 .276 r
F
.27081 .3284 m .27177 .32557 L .2736 .32748 L 0 .027 .127 r
F
.27081 .3284 m .26898 .32648 L .27177 .32557 L F
.16041 .32696 m .1612 .32415 L .16315 .32598 L 0 .025 .123 r
F
.16041 .32696 m .15846 .32513 L .1612 .32415 L F
.56842 .36995 m .56689 .36874 L .56979 .3639 L 0 .15 .229 r
F
.56556 .37771 m .56689 .36874 L .56842 .36995 L 0 .189 .251 r
F
.56287 .39328 m .56423 .38657 L .56574 .38525 L 0 .283 .297 r
F
.12609 .32637 m .12682 .32357 L .1288 .32545 L 0 .024 .122 r
F
.12609 .32637 m .12411 .32449 L .12682 .32357 L F
.42615 .34002 m .42735 .33699 L .42902 .3393 L 0 .054 .157 r
F
.42615 .34002 m .42448 .33772 L .42735 .33699 L F
.62301 .33922 m .6245 .33616 L .62599 .33788 L 0 .052 .155 r
F
.62301 .33922 m .62153 .33749 L .6245 .33616 L F
.75259 .32951 m .75427 .32652 L .75564 .32847 L 0 .03 .13 r
F
.75259 .32951 m .75122 .3276 L .75427 .32652 L F
.46364 .35063 m .4649 .3472 L .46654 .34978 L 0 .085 .184 r
F
.46364 .35063 m .462 .3481 L .4649 .3472 L F
.73769 .33039 m .73936 .32752 L .74074 .32937 L 0 .032 .132 r
F
.73769 .33039 m .73631 .32852 L .73936 .32752 L F
.23648 .32792 m .2374 .32495 L .23926 .32691 L 0 .026 .126 r
F
.23648 .32792 m .23462 .32597 L .2374 .32495 L F
.5545 .42132 m .55304 .43068 L .55591 .42083 L 0 .375 .265 r
F
.55162 .42944 m .55304 .43068 L .5545 .42132 L 0 .408 .231 r
F
.55878 .41103 m .55731 .41811 L .56017 .40773 L 0 .343 .291 r
F
.55591 .42083 m .55731 .41811 L .55878 .41103 L 0 .38 .261 r
F
.83161 .32776 m .83342 .32482 L .83471 .32671 L 0 .026 .125 r
F
.83161 .32776 m .83032 .32588 L .83342 .32482 L F
.3514 .33171 m .3525 .32859 L .35424 .33066 L 0 .034 .135 r
F
.3514 .33171 m .34965 .32963 L .3525 .32859 L F
.74515 .33006 m .74681 .32697 L .74818 .32883 L 0 .031 .131 r
F
.74515 .33006 m .74378 .32821 L .74681 .32697 L F
.40966 .33607 m .41083 .3332 L .41252 .33526 L 0 .045 .147 r
F
.40966 .33607 m .40796 .33406 L .41083 .3332 L F
.37827 .33277 m .3794 .32962 L .38113 .3317 L 0 .036 .138 r
F
.37827 .33277 m .37654 .33071 L .3794 .32962 L F
.32453 .33071 m .32557 .32784 L .32736 .32972 L 0 .032 .133 r
F
.32453 .33071 m .32275 .32881 L .32557 .32784 L F
.43811 .34207 m .43933 .33909 L .44099 .34143 L 0 .06 .163 r
F
.43811 .34207 m .43645 .3398 L .43933 .33909 L F
.30511 .32928 m .30612 .32647 L .30792 .32832 L 0 .03 .13 r
F
.30511 .32928 m .3033 .32744 L .30612 .32647 L F
.58443 .34913 m .58584 .34515 L .58737 .34722 L 0 .079 .179 r
F
.58443 .34913 m .58289 .34708 L .58584 .34515 L F
.76006 .32938 m .76175 .32634 L .76311 .32831 L 0 .03 .13 r
F
.76006 .32938 m .75869 .32742 L .76175 .32634 L F
.16782 .32692 m .16863 .32402 L .17056 .32595 L 0 .025 .123 r
F
.16782 .32692 m .16589 .325 L .16863 .32402 L F
.83908 .32755 m .8409 .32462 L .84218 .32652 L 0 .026 .125 r
F
.83908 .32755 m .8378 .32565 L .8409 .32462 L F
.47719 .35774 m .47847 .35433 L .48007 .35857 L 0 .111 .203 r
F
.47719 .35774 m .47558 .35405 L .47847 .35433 L F
.20214 .32758 m .20299 .32472 L .20489 .32667 L 0 .026 .125 r
F
.20214 .32758 m .20024 .32563 L .20299 .32472 L F
.59481 .34619 m .59625 .34271 L .59777 .34473 L 0 .071 .172 r
F
.59481 .34619 m .59329 .34414 L .59625 .34271 L F
.60519 .34309 m .60664 .33957 L .60815 .34138 L 0 .062 .164 r
F
.60519 .34309 m .60368 .34124 L .60664 .33957 L F
.33197 .3305 m .33302 .32759 L .3348 .32943 L 0 .032 .133 r
F
.33197 .3305 m .33019 .32866 L .33302 .32759 L F
.27822 .32847 m .27921 .32546 L .28103 .32743 L 0 .028 .127 r
F
.27822 .32847 m .2764 .32649 L .27921 .32546 L F
.64831 .33571 m .64983 .33243 L .65129 .33431 L 0 .043 .146 r
F
.64831 .33571 m .64684 .3338 L .64983 .33243 L F
.76752 .32912 m .76922 .32604 L .77057 .32797 L 0 .029 .129 r
F
.76752 .32912 m .76616 .32718 L .76922 .32604 L F
.2439 .3279 m .24483 .32492 L .24668 .32692 L 0 .027 .126 r
F
.2439 .3279 m .24204 .3259 L .24483 .32492 L F
.13348 .32646 m .13423 .32357 L .1362 .32549 L 0 .024 .122 r
F
.13348 .32646 m .13151 .32453 L .13423 .32357 L F
.77497 .32873 m .77669 .3257 L .77803 .32759 L 0 .028 .128 r
F
.77497 .32873 m .77363 .32683 L .77669 .3257 L F
.78243 .32834 m .78416 .3254 L .78549 .32726 L 0 .028 .127 r
F
.78243 .32834 m .78109 .32647 L .78416 .3254 L F
.48352 .37916 m .48195 .37277 L .48481 .37635 L 0 .212 .263 r
F
.48195 .37277 m .48325 .3688 L .48481 .37635 L 0 .173 .242 r
F
.42161 .33828 m .4228 .33544 L .42448 .33772 L 0 .051 .153 r
F
.42161 .33828 m .41994 .33605 L .4228 .33544 L F
.35883 .33167 m .35993 .32865 L .36168 .33068 L 0 .035 .136 r
F
.35883 .33167 m .35709 .32965 L .35993 .32865 L F
.61558 .34016 m .61706 .33708 L .61855 .33879 L 0 .055 .158 r
F
.61558 .34016 m .61408 .33842 L .61706 .33708 L F
.3857 .33275 m .38684 .32987 L .38855 .33201 L 0 .037 .139 r
F
.3857 .33275 m .38399 .33063 L .38684 .32987 L F
.64087 .33629 m .64238 .33316 L .64385 .33513 L 0 .045 .148 r
F
.64087 .33629 m .63939 .33431 L .64238 .33316 L F
.84657 .32744 m .8484 .32453 L .84967 .32644 L 0 .026 .125 r
F
.84657 .32744 m .84529 .32553 L .8484 .32453 L F
.45911 .34893 m .46037 .34545 L .462 .3481 L 0 .08 .18 r
F
.45911 .34893 m .45747 .34629 L .46037 .34545 L F
.78989 .32808 m .79162 .32505 L .79296 .32696 L 0 .027 .127 r
F
.78989 .32808 m .78856 .32618 L .79162 .32505 L F
.68106 .3316 m .68263 .32847 L .68406 .33042 L 0 .035 .136 r
F
.68106 .3316 m .67961 .32965 L .68263 .32847 L F
.39767 .33472 m .39882 .33185 L .40053 .33385 L 0 .042 .144 r
F
.39767 .33472 m .39596 .33268 L .39882 .33185 L F
.31253 .32935 m .31355 .32643 L .31534 .32844 L 0 .03 .13 r
F
.31253 .32935 m .31074 .32735 L .31355 .32643 L F
.63342 .33681 m .63491 .33348 L .6364 .33547 L 0 .046 .149 r
F
.63342 .33681 m .63193 .33483 L .63491 .33348 L F
.3394 .3304 m .34046 .32764 L .34223 .32951 L 0 .033 .133 r
F
.3394 .3304 m .33763 .32853 L .34046 .32764 L F
.79735 .32773 m .79909 .32465 L .80041 .32659 L 0 .027 .126 r
F
.79735 .32773 m .79602 .32581 L .79909 .32465 L F
.17523 .32691 m .17604 .32406 L .17796 .32599 L 0 .025 .124 r
F
.17523 .32691 m .1733 .32498 L .17604 .32406 L F
.28565 .32835 m .28663 .32553 L .28845 .32748 L 0 .028 .128 r
F
.28565 .32835 m .28383 .3264 L .28663 .32553 L F
.20955 .32755 m .21043 .32454 L .21232 .32649 L 0 .026 .126 r
F
.20955 .32755 m .20766 .32561 L .21043 .32454 L F
.66616 .33257 m .66772 .32968 L .66916 .33141 L 0 .037 .139 r
F
.66616 .33257 m .66471 .33082 L .66772 .32968 L F
.14089 .32637 m .14166 .32344 L .14362 .32533 L 0 .024 .123 r
F
.14089 .32637 m .13893 .32446 L .14166 .32344 L F
.68852 .33137 m .69011 .32846 L .69154 .33037 L 0 .035 .136 r
F
.68852 .33137 m .68708 .32944 L .69011 .32846 L F
.70342 .33056 m .70504 .32769 L .70644 .32945 L 0 .033 .134 r
F
.70342 .33056 m .70201 .32878 L .70504 .32769 L F
.67361 .33221 m .67517 .32897 L .67661 .33093 L 0 .036 .137 r
F
.67361 .33221 m .67217 .33025 L .67517 .32897 L F
.25131 .32789 m .25225 .32498 L .2541 .3269 L 0 .027 .127 r
F
.25131 .32789 m .24946 .32595 L .25225 .32498 L F
.85405 .32732 m .85589 .32442 L .85715 .3263 L 0 .026 .125 r
F
.85405 .32732 m .85278 .32543 L .85589 .32442 L F
.36626 .33167 m .36736 .32883 L .36911 .33076 L 0 .036 .137 r
F
.36626 .33167 m .36452 .3297 L .36736 .32883 L F
.80482 .32754 m .80659 .32464 L .8079 .32657 L 0 .027 .126 r
F
.80482 .32754 m .8035 .32561 L .80659 .32464 L F
.71088 .33023 m .7125 .32729 L .71391 .32918 L 0 .032 .133 r
F
.71088 .33023 m .70947 .32835 L .7125 .32729 L F
.21698 .32736 m .21785 .32453 L .21974 .32642 L 0 .027 .126 r
F
.21698 .32736 m .21509 .32547 L .21785 .32453 L F
.45458 .34702 m .45583 .34367 L .45747 .34629 L 0 .075 .176 r
F
.45458 .34702 m .45294 .34439 L .45583 .34367 L F
.58737 .34722 m .5888 .34351 L .59033 .34558 L F
.58737 .34722 m .58584 .34515 L .5888 .34351 L F
.69598 .33112 m .69758 .32813 L .69899 .32994 L 0 .034 .135 r
F
.69598 .33112 m .69456 .32927 L .69758 .32813 L F
.14832 .32619 m .14907 .32343 L .15104 .32525 L 0 .025 .123 r
F
.14832 .32619 m .14635 .32437 L .14907 .32343 L F
.25875 .32766 m .25969 .32475 L .26155 .32658 L 0 .027 .126 r
F
.25875 .32766 m .2569 .32583 L .25969 .32475 L F
.43357 .3407 m .43479 .33745 L .43645 .3398 L 0 .057 .16 r
F
.43357 .3407 m .4319 .33837 L .43479 .33745 L F
.86152 .32709 m .86337 .32417 L .86462 .32602 L 0 .026 .125 r
F
.86152 .32709 m .86026 .32526 L .86337 .32417 L F
.18263 .32691 m .18345 .32412 L .18538 .32594 L F
.18263 .32691 m .1807 .32507 L .18345 .32412 L F
.41707 .33665 m .41825 .33381 L .41994 .33605 L 0 .048 .15 r
F
.41707 .33665 m .41539 .33446 L .41825 .33381 L F
.26619 .32739 m .26713 .32467 L .26898 .32648 L 0 .027 .126 r
F
.26619 .32739 m .26434 .32556 L .26713 .32467 L F
.47107 .35137 m .47233 .34866 L .47396 .35136 L 0 .092 .189 r
F
.47107 .35137 m .46944 .34893 L .47233 .34866 L F
.65873 .3334 m .66026 .33027 L .66172 .33204 L 0 .039 .141 r
F
.65873 .3334 m .65727 .3316 L .66026 .33027 L F
.29307 .32845 m .29405 .32572 L .29587 .32754 L 0 .029 .129 r
F
.29307 .32845 m .29125 .32661 L .29405 .32572 L F
.71835 .3301 m .71998 .32715 L .72138 .3291 L 0 .032 .133 r
F
.71835 .3301 m .71694 .32816 L .71998 .32715 L F
.86899 .32681 m .87085 .32392 L .8721 .32581 L 0 .026 .125 r
F
.86899 .32681 m .86773 .32494 L .87085 .32392 L F
.81975 .32703 m .82154 .32414 L .82284 .32599 L F
.81975 .32703 m .81845 .32517 L .82154 .32414 L F
.8123 .32745 m .81407 .32442 L .81537 .32631 L 0 .027 .126 r
F
.8123 .32745 m .81099 .32555 L .81407 .32442 L F
.40509 .33494 m .40626 .33212 L .40796 .33406 L 0 .044 .146 r
F
.40509 .33494 m .40339 .33299 L .40626 .33212 L F
.2244 .32731 m .22528 .32445 L .22717 .32627 L 0 .027 .126 r
F
.2244 .32731 m .22251 .32548 L .22528 .32445 L F
.19006 .3267 m .1909 .32385 L .19282 .32565 L 0 .026 .125 r
F
.19006 .3267 m .18814 .3249 L .1909 .32385 L F
.60815 .34138 m .60961 .33812 L .61112 .3399 L 0 .06 .162 r
F
.60815 .34138 m .60664 .33957 L .60961 .33812 L F
.45005 .34512 m .45129 .34192 L .45294 .34439 L 0 .071 .172 r
F
.45005 .34512 m .4484 .34266 L .45129 .34192 L F
.62599 .33788 m .62748 .33464 L .62896 .33636 L 0 .05 .153 r
F
.62599 .33788 m .6245 .33616 L .62748 .33464 L F
.15573 .3261 m .1565 .32333 L .15846 .32513 L 0 .025 .123 r
F
.15573 .3261 m .15377 .3243 L .1565 .32333 L F
.34681 .33067 m .3479 .32754 L .34965 .32963 L 0 .033 .134 r
F
.34681 .33067 m .34506 .32857 L .3479 .32754 L F
.31993 .32963 m .32097 .32681 L .32275 .32881 L 0 .032 .132 r
F
.31993 .32963 m .31815 .32763 L .32097 .32681 L F
.37369 .33173 m .37481 .32886 L .37654 .33071 L 0 .036 .138 r
F
.37369 .33173 m .37195 .32985 L .37481 .32886 L F
.72581 .32989 m .72745 .32679 L .72884 .32873 L 0 .032 .132 r
F
.72581 .32989 m .72441 .32795 L .72745 .32679 L F
.23184 .32703 m .23274 .32417 L .23462 .32597 L 0 .026 .126 r
F
.23184 .32703 m .22995 .32522 L .23274 .32417 L F
.73327 .32951 m .73493 .32664 L .73631 .32852 L 0 .032 .132 r
F
.73327 .32951 m .73188 .32762 L .73493 .32664 L F
.82723 .32686 m .82903 .32399 L .83032 .32588 L 0 .026 .125 r
F
.82723 .32686 m .82593 .32499 L .82903 .32399 L F
.56979 .3639 m .56825 .36243 L .57115 .35734 L 0 .128 .214 r
F
.56689 .36874 m .56825 .36243 L .56979 .3639 L 0 .154 .231 r
F
.19749 .32652 m .19832 .3238 L .20024 .32563 L 0 .026 .125 r
F
.19749 .32652 m .19557 .32471 L .19832 .3238 L F
.59777 .34473 m .59921 .34101 L .60073 .34299 L 0 .069 .17 r
F
.59777 .34473 m .59625 .34271 L .59921 .34101 L F
.30049 .3284 m .30149 .32568 L .3033 .32744 L 0 .03 .13 r
F
.30049 .3284 m .29868 .32661 L .30149 .32568 L F
.87648 .32675 m .87836 .32387 L .8796 .32579 L 0 .026 .125 r
F
.87648 .32675 m .87523 .32484 L .87836 .32387 L F
.74818 .32883 m .74985 .32573 L .75122 .3276 L 0 .03 .13 r
F
.74818 .32883 m .74681 .32697 L .74985 .32573 L F
.47558 .35405 m .47685 .35137 L .47847 .35433 L 0 .102 .197 r
F
.47558 .35405 m .47396 .35136 L .47685 .35137 L F
.16315 .32598 m .16394 .32316 L .16589 .325 L 0 .025 .123 r
F
.16315 .32598 m .1612 .32415 L .16394 .32316 L F
.39311 .33342 m .39425 .33055 L .39596 .33268 L 0 .04 .142 r
F
.39311 .33342 m .3914 .3313 L .39425 .33055 L F
.75564 .32847 m .75733 .32545 L .75869 .32742 L 0 .029 .129 r
F
.75564 .32847 m .75427 .32652 L .75733 .32545 L F
.2736 .32748 m .27457 .32458 L .2764 .32649 L 0 .028 .127 r
F
.2736 .32748 m .27177 .32557 L .27457 .32458 L F
.65129 .33431 m .65282 .33108 L .65428 .33293 L 0 .042 .144 r
F
.65129 .33431 m .64983 .33243 L .65282 .33108 L F
.44552 .34321 m .44675 .3402 L .4484 .34266 L 0 .066 .168 r
F
.44552 .34321 m .44387 .34084 L .44675 .3402 L F
.74074 .32937 m .7424 .32638 L .74378 .32821 L 0 .031 .132 r
F
.74074 .32937 m .73936 .32752 L .7424 .32638 L F
.1288 .32545 m .12954 .32264 L .13151 .32453 L 0 .024 .122 r
F
.1288 .32545 m .12682 .32357 L .12954 .32264 L F
.23926 .32691 m .24019 .32392 L .24204 .3259 L 0 .026 .125 r
F
.23926 .32691 m .2374 .32495 L .24019 .32392 L F
.83471 .32671 m .83652 .32375 L .8378 .32565 L F
.83471 .32671 m .83342 .32482 L .83652 .32375 L F
.35424 .33066 m .35534 .32757 L .35709 .32965 L 0 .034 .135 r
F
.35424 .33066 m .3525 .32859 L .35534 .32757 L F
.38113 .3317 m .38227 .32853 L .38399 .33063 L 0 .036 .138 r
F
.38113 .3317 m .3794 .32962 L .38227 .32853 L F
.61855 .33879 m .62003 .33581 L .62153 .33749 L 0 .054 .157 r
F
.61855 .33879 m .61706 .33708 L .62003 .33581 L F
.32736 .32972 m .32841 .32678 L .33019 .32866 L 0 .032 .133 r
F
.32736 .32972 m .32557 .32784 L .32841 .32678 L F
.46654 .34978 m .46781 .34631 L .46944 .34893 L 0 .086 .184 r
F
.46654 .34978 m .4649 .3472 L .46781 .34631 L F
.48509 .3859 m .48352 .37916 L .48637 .38397 L 0 .258 .285 r
F
.48352 .37916 m .48481 .37635 L .48637 .38397 L 0 .212 .263 r
F
.76311 .32831 m .7648 .32522 L .76616 .32718 L 0 .029 .129 r
F
.76311 .32831 m .76175 .32634 L .7648 .32522 L F
.30792 .32832 m .30894 .32549 L .31074 .32735 L 0 .03 .13 r
F
.30792 .32832 m .30612 .32647 L .30894 .32549 L F
.42902 .3393 m .43023 .33605 L .4319 .33837 L 0 .055 .157 r
F
.42902 .3393 m .42735 .33699 L .43023 .33605 L F
.77057 .32797 m .77228 .32492 L .77363 .32683 L 0 .029 .128 r
F
.77057 .32797 m .76922 .32604 L .77228 .32492 L F
.84218 .32652 m .84401 .32361 L .84529 .32553 L 0 .026 .125 r
F
.84218 .32652 m .8409 .32462 L .84401 .32361 L F
.3348 .32943 m .33585 .3267 L .33763 .32853 L 0 .032 .133 r
F
.3348 .32943 m .33302 .32759 L .33585 .3267 L F
.59033 .34558 m .59176 .3421 L .59329 .34414 L 0 .072 .173 r
F
.59033 .34558 m .5888 .34351 L .59176 .3421 L F
.77803 .32759 m .77975 .32458 L .78109 .32647 L 0 .028 .128 r
F
.77803 .32759 m .77669 .3257 L .77975 .32458 L F
.17056 .32595 m .17137 .32305 L .1733 .32498 L 0 .025 .124 r
F
.17056 .32595 m .16863 .32402 L .17137 .32305 L F
.6364 .33547 m .6379 .33233 L .63939 .33431 L 0 .045 .148 r
F
.6364 .33547 m .63491 .33348 L .6379 .33233 L F
.41252 .33526 m .4137 .33234 L .41539 .33446 L F
.41252 .33526 m .41083 .3332 L .4137 .33234 L F
.28103 .32743 m .28201 .32444 L .28383 .3264 L 0 .028 .127 r
F
.28103 .32743 m .27921 .32546 L .28201 .32444 L F
.78549 .32726 m .78723 .32433 L .78856 .32618 L F
.78549 .32726 m .78416 .3254 L .78723 .32433 L F
.64385 .33513 m .64537 .33185 L .64684 .3338 L 0 .044 .147 r
F
.64385 .33513 m .64238 .33316 L .64537 .33185 L F
.20489 .32667 m .20576 .32366 L .20766 .32561 L 0 .026 .125 r
F
.20489 .32667 m .20299 .32472 L .20576 .32366 L F
.57408 .35417 m .57547 .34968 L .57701 .35152 L 0 .098 .194 r
F
.57408 .35417 m .57253 .35233 L .57547 .34968 L F
.57115 .35734 m .57253 .35233 L .57408 .35417 L 0 .109 .202 r
F
.68406 .33042 m .68565 .3275 L .68708 .32944 L 0 .034 .135 r
F
.68406 .33042 m .68263 .32847 L .68565 .3275 L F
.24668 .32692 m .24761 .32398 L .24946 .32595 L 0 .027 .126 r
F
.24668 .32692 m .24483 .32492 L .24761 .32398 L F
.57701 .35152 m .57841 .34715 L .57994 .349 L 0 .09 .187 r
F
.57701 .35152 m .57547 .34968 L .57841 .34715 L F
.1362 .32549 m .13696 .32255 L .13893 .32446 L 0 .024 .123 r
F
.1362 .32549 m .13423 .32357 L .13696 .32255 L F
.36168 .33068 m .36278 .32768 L .36452 .3297 L 0 .035 .136 r
F
.36168 .33068 m .35993 .32865 L .36278 .32768 L F
.44099 .34143 m .44221 .33842 L .44387 .34084 L 0 .062 .164 r
F
.44099 .34143 m .43933 .33909 L .44221 .33842 L F
.79296 .32696 m .79469 .32388 L .79602 .32581 L 0 .027 .126 r
F
.79296 .32696 m .79162 .32505 L .79469 .32388 L F
.80041 .32659 m .80218 .32367 L .8035 .32561 L 0 .026 .126 r
F
.80041 .32659 m .79909 .32465 L .80218 .32367 L F
.67661 .33093 m .67817 .32769 L .67961 .32965 L 0 .035 .136 r
F
.67661 .33093 m .67517 .32897 L .67817 .32769 L F
.84967 .32644 m .85151 .32353 L .85278 .32543 L 0 .026 .125 r
F
.84967 .32644 m .8484 .32453 L .85151 .32353 L F
.66916 .33141 m .67073 .32855 L .67217 .33025 L 0 .037 .138 r
F
.66916 .33141 m .66772 .32968 L .67073 .32855 L F
.57994 .349 m .58136 .34523 L .58289 .34708 L 0 .083 .182 r
F
.57994 .349 m .57841 .34715 L .58136 .34523 L F
.21232 .32649 m .2132 .32353 L .21509 .32547 L 0 .026 .125 r
F
.21232 .32649 m .21043 .32454 L .2132 .32353 L F
.70644 .32945 m .70807 .32659 L .70947 .32835 L 0 .033 .133 r
F
.70644 .32945 m .70504 .32769 L .70807 .32659 L F
.14362 .32533 m .14439 .32248 L .14635 .32437 L 0 .024 .123 r
F
.14362 .32533 m .14166 .32344 L .14439 .32248 L F
.31534 .32844 m .31637 .32562 L .31815 .32763 L 0 .031 .131 r
F
.31534 .32844 m .31355 .32643 L .31637 .32562 L F
.462 .3481 m .46327 .34454 L .4649 .3472 L 0 .081 .181 r
F
.462 .3481 m .46037 .34545 L .46327 .34454 L F
.17796 .32599 m .17878 .32315 L .1807 .32507 L 0 .026 .125 r
F
.17796 .32599 m .17604 .32406 L .17878 .32315 L F
.40053 .33385 m .40168 .33102 L .40339 .33299 L 0 .043 .145 r
F
.40053 .33385 m .39882 .33185 L .40168 .33102 L F
.34223 .32951 m .34329 .32669 L .34506 .32857 L 0 .033 .134 r
F
.34223 .32951 m .34046 .32764 L .34329 .32669 L F
.69899 .32994 m .7006 .32699 L .70201 .32878 L 0 .034 .135 r
F
.69899 .32994 m .69758 .32813 L .7006 .32699 L F
.38855 .33201 m .38969 .32914 L .3914 .3313 L 0 .038 .14 r
F
.38855 .33201 m .38684 .32987 L .38969 .32914 L F
.62896 .33636 m .63045 .3331 L .63193 .33483 L 0 .048 .151 r
F
.62896 .33636 m .62748 .33464 L .63045 .3331 L F
.69154 .33037 m .69313 .32738 L .69456 .32927 L 0 .035 .136 r
F
.69154 .33037 m .69011 .32846 L .69313 .32738 L F
.28845 .32748 m .28943 .32466 L .29125 .32661 L 0 .029 .129 r
F
.28845 .32748 m .28663 .32553 L .28943 .32466 L F
.60073 .34299 m .60217 .33931 L .60368 .34124 L 0 .065 .167 r
F
.60073 .34299 m .59921 .34101 L .60217 .33931 L F
.61112 .3399 m .61258 .33666 L .61408 .33842 L 0 .058 .16 r
F
.61112 .3399 m .60961 .33812 L .61258 .33666 L F
.66172 .33204 m .66327 .32907 L .66471 .33082 L 0 .038 .14 r
F
.66172 .33204 m .66026 .33027 L .66327 .32907 L F
.2541 .3269 m .25504 .32392 L .2569 .32583 L 0 .027 .127 r
F
.2541 .3269 m .25225 .32498 L .25504 .32392 L F
.71391 .32918 m .71554 .32627 L .71694 .32816 L 0 .032 .133 r
F
.71391 .32918 m .7125 .32729 L .71554 .32627 L F
.85715 .3263 m .859 .32339 L .86026 .32526 L 0 .026 .125 r
F
.85715 .3263 m .85589 .32442 L .859 .32339 L F
.57115 .35734 m .5696 .35549 L .57253 .35233 L 0 .109 .202 r
F
.56825 .36243 m .5696 .35549 L .57115 .35734 L 0 .128 .215 r
F
.42448 .33772 m .42568 .33467 L .42735 .33699 L 0 .052 .155 r
F
.42448 .33772 m .4228 .33544 L .42568 .33467 L F
.8079 .32657 m .80967 .32363 L .81099 .32555 L 0 .027 .126 r
F
.8079 .32657 m .80659 .32464 L .80967 .32363 L F
.26155 .32658 m .26249 .32374 L .26434 .32556 L F
.26155 .32658 m .25969 .32475 L .26249 .32374 L F
.36911 .33076 m .37021 .32796 L .37195 .32985 L 0 .036 .137 r
F
.36911 .33076 m .36736 .32883 L .37021 .32796 L F
.21974 .32642 m .22062 .32359 L .22251 .32548 L 0 .027 .126 r
F
.21974 .32642 m .21785 .32453 L .22062 .32359 L F
.86462 .32602 m .86648 .32308 L .86773 .32494 L 0 .026 .125 r
F
.86462 .32602 m .86337 .32417 L .86648 .32308 L F
.15104 .32525 m .1518 .32249 L .15377 .3243 L 0 .025 .123 r
F
.15104 .32525 m .14907 .32343 L .1518 .32249 L F
.81537 .32631 m .81715 .3233 L .81845 .32517 L 0 .026 .125 r
F
.81537 .32631 m .81407 .32442 L .81715 .3233 L F
.18538 .32594 m .18621 .32307 L .18814 .3249 L F
.18538 .32594 m .18345 .32412 L .18621 .32307 L F
.43645 .3398 m .43767 .33669 L .43933 .33909 L 0 .058 .161 r
F
.43645 .3398 m .43479 .33745 L .43767 .33669 L F
.82284 .32599 m .82464 .32315 L .82593 .32499 L 0 .026 .125 r
F
.82284 .32599 m .82154 .32414 L .82464 .32315 L F
.72138 .3291 m .72301 .326 L .72441 .32795 L 0 .032 .133 r
F
.72138 .3291 m .71998 .32715 L .72301 .326 L F
.45747 .34629 m .45873 .34283 L .46037 .34545 L 0 .076 .177 r
F
.45747 .34629 m .45583 .34367 L .45873 .34283 L F
.8721 .32581 m .87398 .32294 L .87523 .32484 L 0 .026 .125 r
F
.8721 .32581 m .87085 .32392 L .87398 .32294 L F
.72884 .32873 m .73049 .32569 L .73188 .32762 L 0 .031 .132 r
F
.72884 .32873 m .72745 .32679 L .73049 .32569 L F
.26898 .32648 m .26992 .32377 L .27177 .32557 L 0 .027 .127 r
F
.26898 .32648 m .26713 .32467 L .26992 .32377 L F
.22717 .32627 m .22807 .3234 L .22995 .32522 L 0 .027 .126 r
F
.22717 .32627 m .22528 .32445 L .22807 .3234 L F
.19282 .32565 m .19365 .3229 L .19557 .32471 L 0 .026 .125 r
F
.19282 .32565 m .1909 .32385 L .19365 .3229 L F
.29587 .32754 m .29686 .32482 L .29868 .32661 L 0 .03 .13 r
F
.29587 .32754 m .29405 .32572 L .29686 .32482 L F
.65428 .33293 m .65581 .32978 L .65727 .3316 L 0 .041 .143 r
F
.65428 .33293 m .65282 .33108 L .65581 .32978 L F
.34965 .32963 m .35075 .32651 L .3525 .32859 L 0 .033 .134 r
F
.34965 .32963 m .3479 .32754 L .35075 .32651 L F
.12411 .32449 m .12483 .32176 L .12682 .32357 L 0 .024 .122 r
F
.12411 .32449 m .12212 .32269 L .12483 .32176 L F
.75122 .3276 m .75291 .32465 L .75427 .32652 L 0 .029 .129 r
F
.75122 .3276 m .74985 .32573 L .75291 .32465 L F
.37654 .33071 m .37767 .3278 L .3794 .32962 L 0 .036 .138 r
F
.37654 .33071 m .37481 .32886 L .37767 .3278 L F
.15846 .32513 m .15924 .32236 L .1612 .32415 L 0 .025 .123 r
F
.15846 .32513 m .1565 .32333 L .15924 .32236 L F
.23462 .32597 m .23552 .32313 L .2374 .32495 L 0 .026 .125 r
F
.23462 .32597 m .23274 .32417 L .23552 .32313 L F
.58289 .34708 m .58431 .34331 L .58584 .34515 L 0 .078 .178 r
F
.58289 .34708 m .58136 .34523 L .58431 .34331 L F
.40796 .33406 m .40913 .33124 L .41083 .3332 L 0 .044 .147 r
F
.40796 .33406 m .40626 .33212 L .40913 .33124 L F
.73631 .32852 m .73798 .32566 L .73936 .32752 L 0 .032 .132 r
F
.73631 .32852 m .73493 .32664 L .73798 .32566 L F
.83032 .32588 m .83213 .32292 L .83342 .32482 L 0 .026 .125 r
F
.83032 .32588 m .82903 .32399 L .83213 .32292 L F
.62153 .33749 m .62302 .33452 L .6245 .33616 L 0 .053 .155 r
F
.62153 .33749 m .62003 .33581 L .62302 .33452 L F
.41994 .33605 m .42112 .33316 L .4228 .33544 L 0 .049 .152 r
F
.41994 .33605 m .41825 .33381 L .42112 .33316 L F
.32275 .32881 m .32379 .32584 L .32557 .32784 L 0 .032 .133 r
F
.32275 .32881 m .32097 .32681 L .32379 .32584 L F
.74378 .32821 m .74544 .32516 L .74681 .32697 L 0 .031 .131 r
F
.74378 .32821 m .7424 .32638 L .74544 .32516 L F
.59329 .34414 m .59472 .34068 L .59625 .34271 L 0 .07 .172 r
F
.59329 .34414 m .59176 .3421 L .59472 .34068 L F
.75869 .32742 m .76038 .32436 L .76175 .32634 L 0 .029 .129 r
F
.75869 .32742 m .75733 .32545 L .76038 .32436 L F
.45294 .34439 m .45419 .34118 L .45583 .34367 L 0 .072 .173 r
F
.45294 .34439 m .45129 .34192 L .45419 .34118 L F
.3033 .32744 m .3043 .3247 L .30612 .32647 L 0 .03 .13 r
F
.3033 .32744 m .30149 .32568 L .3043 .3247 L F
.16589 .325 m .16668 .32218 L .16863 .32402 L 0 .025 .123 r
F
.16589 .325 m .16394 .32316 L .16668 .32218 L F
.20024 .32563 m .20108 .32289 L .20299 .32472 L 0 .026 .125 r
F
.20024 .32563 m .19832 .3238 L .20108 .32289 L F
.8378 .32565 m .83962 .32271 L .8409 .32462 L F
.8378 .32565 m .83652 .32375 L .83962 .32271 L F
.2764 .32649 m .27737 .32356 L .27921 .32546 L 0 .028 .127 r
F
.2764 .32649 m .27457 .32458 L .27737 .32356 L F
.38399 .33063 m .38512 .32776 L .38684 .32987 L 0 .037 .138 r
F
.38399 .33063 m .38227 .32853 L .38512 .32776 L F
.24204 .3259 m .24297 .32295 L .24483 .32492 L 0 .026 .126 r
F
.24204 .3259 m .24019 .32392 L .24297 .32295 L F
.35709 .32965 m .35819 .32656 L .35993 .32865 L 0 .034 .135 r
F
.35709 .32965 m .35534 .32757 L .35819 .32656 L F
.60368 .34124 m .60513 .33769 L .60664 .33957 L 0 .062 .164 r
F
.60368 .34124 m .60217 .33931 L .60513 .33769 L F
.64684 .3338 m .64836 .33052 L .64983 .33243 L 0 .043 .145 r
F
.64684 .3338 m .64537 .33185 L .64836 .33052 L F
.76616 .32718 m .76786 .32409 L .76922 .32604 L 0 .029 .129 r
F
.76616 .32718 m .7648 .32522 L .76786 .32409 L F
.33019 .32866 m .33124 .32572 L .33302 .32759 L 0 .032 .133 r
F
.33019 .32866 m .32841 .32678 L .33124 .32572 L F
.13151 .32453 m .13226 .32169 L .13423 .32357 L 0 .024 .122 r
F
.13151 .32453 m .12954 .32264 L .13226 .32169 L F
.77363 .32683 m .77534 .3238 L .77669 .3257 L 0 .028 .128 r
F
.77363 .32683 m .77228 .32492 L .77534 .3238 L F
.63939 .33431 m .6409 .33119 L .64238 .33316 L 0 .045 .147 r
F
.63939 .33431 m .6379 .33233 L .6409 .33119 L F
.78109 .32647 m .78282 .32354 L .78416 .3254 L 0 .028 .127 r
F
.78109 .32647 m .77975 .32458 L .78282 .32354 L F
.39596 .33268 m .39711 .32976 L .39882 .33185 L 0 .041 .143 r
F
.39596 .33268 m .39425 .33055 L .39711 .32976 L F
.31074 .32735 m .31176 .32455 L .31355 .32643 L 0 .03 .13 r
F
.31074 .32735 m .30894 .32549 L .31176 .32455 L F
.48665 .39331 m .48509 .3859 L .48792 .39207 L 0 .31 .307 r
F
.48509 .3859 m .48637 .38397 L .48792 .39207 L 0 .258 .285 r
F
.56556 .37771 m .56402 .37689 L .56689 .36874 L 0 .189 .251 r
F
.56689 .36874 m .56534 .36752 L .56825 .36243 L 0 .154 .231 r
F
.56402 .37689 m .56534 .36752 L .56689 .36874 L 0 .195 .254 r
F
.67961 .32965 m .68118 .32652 L .68263 .32847 L 0 .034 .135 r
F
.67961 .32965 m .67817 .32769 L .68118 .32652 L F
.63193 .33483 m .63343 .33174 L .63491 .33348 L 0 .046 .149 r
F
.63193 .33483 m .63045 .3331 L .63343 .33174 L F
.84529 .32553 m .84712 .3226 L .8484 .32453 L 0 .026 .125 r
F
.84529 .32553 m .84401 .32361 L .84712 .3226 L F
.4319 .33837 m .43312 .3351 L .43479 .33745 L 0 .055 .158 r
F
.4319 .33837 m .43023 .33605 L .43312 .3351 L F
.46944 .34893 m .4707 .34594 L .47233 .34866 L 0 .088 .186 r
F
.46944 .34893 m .46781 .34631 L .4707 .34594 L F
.78856 .32618 m .7903 .3232 L .79162 .32505 L 0 .027 .127 r
F
.78856 .32618 m .78723 .32433 L .7903 .3232 L F
.28383 .3264 m .28481 .32358 L .28663 .32553 L 0 .028 .128 r
F
.28383 .3264 m .28201 .32444 L .28481 .32358 L F
.61408 .33842 m .61556 .33536 L .61706 .33708 L 0 .056 .158 r
F
.61408 .33842 m .61258 .33666 L .61556 .33536 L F
.1733 .32498 m .17411 .32214 L .17604 .32406 L 0 .025 .124 r
F
.1733 .32498 m .17137 .32305 L .17411 .32214 L F
.79602 .32581 m .79776 .32272 L .79909 .32465 L 0 .026 .126 r
F
.79602 .32581 m .79469 .32388 L .79776 .32272 L F
.20766 .32561 m .20854 .32259 L .21043 .32454 L 0 .026 .125 r
F
.20766 .32561 m .20576 .32366 L .20854 .32259 L F
.33763 .32853 m .33868 .3258 L .34046 .32764 L 0 .033 .133 r
F
.33763 .32853 m .33585 .3267 L .33868 .3258 L F
.48166 .36368 m .48007 .35857 L .48296 .35952 L 0 .141 .223 r
F
.48007 .35857 m .48137 .35467 L .48296 .35952 L 0 .121 .21 r
F
.48007 .35857 m .47847 .35433 L .48137 .35467 L F
.4484 .34266 m .44964 .33945 L .45129 .34192 L 0 .068 .169 r
F
.4484 .34266 m .44675 .3402 L .44964 .33945 L F
.67217 .33025 m .67373 .32727 L .67517 .32897 L 0 .036 .137 r
F
.67217 .33025 m .67073 .32855 L .67373 .32727 L F
.13893 .32446 m .13969 .32154 L .14166 .32344 L 0 .024 .123 r
F
.13893 .32446 m .13696 .32255 L .13969 .32154 L F
.47396 .35136 m .47523 .3484 L .47685 .35137 L 0 .097 .193 r
F
.47396 .35136 m .47233 .34866 L .47523 .3484 L F
.58584 .34515 m .58727 .34166 L .5888 .34351 L 0 .075 .175 r
F
.58584 .34515 m .58431 .34331 L .58727 .34166 L F
.68708 .32944 m .68868 .32652 L .69011 .32846 L 0 .034 .135 r
F
.68708 .32944 m .68565 .3275 L .68868 .32652 L F
.24946 .32595 m .25039 .32303 L .25225 .32498 L 0 .027 .126 r
F
.24946 .32595 m .24761 .32398 L .25039 .32303 L F
.36452 .3297 m .36562 .32684 L .36736 .32883 L 0 .035 .136 r
F
.36452 .3297 m .36278 .32768 L .36562 .32684 L F
.41539 .33446 m .41657 .33166 L .41825 .33381 L 0 .046 .149 r
F
.41539 .33446 m .4137 .33234 L .41657 .33166 L F
.8035 .32561 m .80527 .3227 L .80659 .32464 L 0 .027 .126 r
F
.8035 .32561 m .80218 .32367 L .80527 .3227 L F
.48325 .3688 m .48166 .36368 L .48454 .36546 L 0 .166 .238 r
F
.48166 .36368 m .48296 .35952 L .48454 .36546 L 0 .141 .223 r
F
.85278 .32543 m .85462 .32254 L .85589 .32442 L 0 .026 .125 r
F
.85278 .32543 m .85151 .32353 L .85462 .32254 L F
.66471 .33082 m .66627 .32796 L .66772 .32968 L 0 .038 .139 r
F
.66471 .33082 m .66327 .32907 L .66627 .32796 L F
.70947 .32835 m .7111 .32555 L .7125 .32729 L 0 .032 .133 r
F
.70947 .32835 m .70807 .32659 L .7111 .32555 L F
.70201 .32878 m .70363 .32592 L .70504 .32769 L 0 .033 .134 r
F
.70201 .32878 m .7006 .32699 L .70363 .32592 L F
.21509 .32547 m .21596 .32259 L .21785 .32453 L 0 .026 .126 r
F
.21509 .32547 m .2132 .32353 L .21596 .32259 L F
.69456 .32927 m .69615 .32628 L .69758 .32813 L 0 .034 .135 r
F
.69456 .32927 m .69313 .32738 L .69615 .32628 L F
.48481 .37635 m .48325 .3688 L .48612 .37141 L 0 .204 .259 r
F
.48325 .3688 m .48454 .36546 L .48612 .37141 L 0 .166 .238 r
F
.14635 .32437 m .14711 .32154 L .14907 .32343 L 0 .025 .123 r
F
.14635 .32437 m .14439 .32248 L .14711 .32154 L F
.2569 .32583 m .25784 .32285 L .25969 .32475 L 0 .027 .126 r
F
.2569 .32583 m .25504 .32392 L .25784 .32285 L F
.86026 .32526 m .86211 .32231 L .86337 .32417 L 0 .026 .125 r
F
.86026 .32526 m .859 .32339 L .86211 .32231 L F
.34506 .32857 m .34614 .32567 L .3479 .32754 L 0 .033 .134 r
F
.34506 .32857 m .34329 .32669 L .34614 .32567 L F
.71694 .32816 m .71858 .32524 L .71998 .32715 L 0 .032 .133 r
F
.71694 .32816 m .71554 .32627 L .71858 .32524 L F
.4649 .3472 m .46617 .34364 L .46781 .34631 L 0 .082 .181 r
F
.4649 .3472 m .46327 .34454 L .46617 .34364 L F
.1807 .32507 m .18152 .32221 L .18345 .32412 L 0 .026 .125 r
F
.1807 .32507 m .17878 .32315 L .18152 .32221 L F
.44387 .34084 m .4451 .33773 L .44675 .3402 L 0 .063 .165 r
F
.44387 .34084 m .44221 .33842 L .4451 .33773 L F
.40339 .33299 m .40455 .33016 L .40626 .33212 L 0 .043 .146 r
F
.40339 .33299 m .40168 .33102 L .40455 .33016 L F
.81099 .32555 m .81276 .32252 L .81407 .32442 L 0 .027 .126 r
F
.81099 .32555 m .80967 .32363 L .81276 .32252 L F
.31815 .32763 m .31918 .32481 L .32097 .32681 L 0 .031 .132 r
F
.31815 .32763 m .31637 .32562 L .31918 .32481 L F
.86773 .32494 m .8696 .32204 L .87085 .32392 L 0 .026 .125 r
F
.86773 .32494 m .86648 .32308 L .8696 .32204 L F
.26434 .32556 m .26528 .32285 L .26713 .32467 L 0 .027 .127 r
F
.26434 .32556 m .26249 .32374 L .26528 .32285 L F
.29125 .32661 m .29223 .32378 L .29405 .32572 L 0 .029 .129 r
F
.29125 .32661 m .28943 .32466 L .29223 .32378 L F
.81845 .32517 m .82025 .32228 L .82154 .32414 L 0 .026 .125 r
F
.81845 .32517 m .81715 .3233 L .82025 .32228 L F
.56017 .40773 m .55869 .41315 L .56154 .40196 L 0 .336 .295 r
F
.55731 .41811 m .55869 .41315 L .56017 .40773 L 0 .375 .265 r
F
.65727 .3316 m .65881 .32848 L .66026 .33027 L 0 .04 .141 r
F
.65727 .3316 m .65581 .32978 L .65881 .32848 L F
.72441 .32795 m .72605 .32484 L .72745 .32679 L 0 .032 .132 r
F
.72441 .32795 m .72301 .326 L .72605 .32484 L F
.22251 .32548 m .2234 .32258 L .22528 .32445 L 0 .027 .126 r
F
.22251 .32548 m .22062 .32359 L .2234 .32258 L F
.3914 .3313 m .39254 .3284 L .39425 .33055 L 0 .039 .141 r
F
.3914 .3313 m .38969 .32914 L .39254 .3284 L F
.37195 .32985 m .37307 .32701 L .37481 .32886 L 0 .036 .138 r
F
.37195 .32985 m .37021 .32796 L .37307 .32701 L F
.60664 .33957 m .6081 .33627 L .60961 .33812 L 0 .06 .162 r
F
.60664 .33957 m .60513 .33769 L .6081 .33627 L F
.18814 .3249 m .18897 .32203 L .1909 .32385 L 0 .026 .125 r
F
.18814 .3249 m .18621 .32307 L .18897 .32203 L F
.59625 .34271 m .59769 .33903 L .59921 .34101 L 0 .068 .169 r
F
.59625 .34271 m .59472 .34068 L .59769 .33903 L F
.15377 .3243 m .15454 .32153 L .1565 .32333 L 0 .025 .123 r
F
.15377 .3243 m .1518 .32249 L .15454 .32153 L F
.73188 .32762 m .73354 .32473 L .73493 .32664 L 0 .031 .132 r
F
.73188 .32762 m .73049 .32569 L .73354 .32473 L F
.47847 .35433 m .47975 .35141 L .48137 .35467 L 0 .109 .202 r
F
.47847 .35433 m .47685 .35137 L .47975 .35141 L F
.6245 .33616 m .62599 .33299 L .62748 .33464 L 0 .051 .154 r
F
.6245 .33616 m .62302 .33452 L .62599 .33299 L F
.42735 .33699 m .42856 .3337 L .43023 .33605 L 0 .053 .156 r
F
.42735 .33699 m .42568 .33467 L .42856 .3337 L F
.82593 .32499 m .82774 .32216 L .82903 .32399 L 0 .026 .125 r
F
.82593 .32499 m .82464 .32315 L .82774 .32216 L F
.22995 .32522 m .23085 .32236 L .23274 .32417 L 0 .027 .126 r
F
.22995 .32522 m .22807 .3234 L .23085 .32236 L F
.87523 .32484 m .87711 .32195 L .87836 .32387 L 0 .026 .125 r
F
.87523 .32484 m .87398 .32294 L .87711 .32195 L F
.3794 .32962 m .38053 .32674 L .38227 .32853 L 0 .036 .137 r
F
.3794 .32962 m .37767 .3278 L .38053 .32674 L F
.3525 .32859 m .35359 .32549 L .35534 .32757 L 0 .033 .134 r
F
.3525 .32859 m .35075 .32651 L .35359 .32549 L F
.75427 .32652 m .75596 .32357 L .75733 .32545 L 0 .029 .129 r
F
.75427 .32652 m .75291 .32465 L .75596 .32357 L F
.74681 .32697 m .74849 .32394 L .74985 .32573 L 0 .03 .13 r
F
.74681 .32697 m .74544 .32516 L .74849 .32394 L F
.19557 .32471 m .1964 .32199 L .19832 .3238 L 0 .026 .125 r
F
.19557 .32471 m .19365 .3229 L .1964 .32199 L F
.27177 .32557 m .27272 .32279 L .27457 .32458 L 0 .028 .127 r
F
.27177 .32557 m .26992 .32377 L .27272 .32279 L F
.2374 .32495 m .23831 .32209 L .24019 .32392 L 0 .026 .125 r
F
.2374 .32495 m .23552 .32313 L .23831 .32209 L F
.29868 .32661 m .29967 .32391 L .30149 .32568 L 0 .03 .13 r
F
.29868 .32661 m .29686 .32482 L .29967 .32391 L F
.46037 .34545 m .46163 .34191 L .46327 .34454 L 0 .077 .177 r
F
.46037 .34545 m .45873 .34283 L .46163 .34191 L F
.1612 .32415 m .16198 .32137 L .16394 .32316 L 0 .025 .123 r
F
.1612 .32415 m .15924 .32236 L .16198 .32137 L F
.64983 .33243 m .65135 .32919 L .65282 .33108 L 0 .042 .144 r
F
.64983 .33243 m .64836 .33052 L .65135 .32919 L F
.12682 .32357 m .12755 .32083 L .12954 .32264 L 0 .024 .122 r
F
.12682 .32357 m .12483 .32176 L .12755 .32083 L F
.43933 .33909 m .44055 .33596 L .44221 .33842 L 0 .059 .162 r
F
.43933 .33909 m .43767 .33669 L .44055 .33596 L F
.83342 .32482 m .83523 .32186 L .83652 .32375 L 0 .026 .125 r
F
.83342 .32482 m .83213 .32292 L .83523 .32186 L F
.73936 .32752 m .74103 .32454 L .7424 .32638 L 0 .031 .132 r
F
.73936 .32752 m .73798 .32566 L .74103 .32454 L F
.5888 .34351 m .59023 .34025 L .59176 .3421 L 0 .072 .173 r
F
.5888 .34351 m .58727 .34166 L .59023 .34025 L F
.76175 .32634 m .76344 .32325 L .7648 .32522 L 0 .029 .129 r
F
.76175 .32634 m .76038 .32436 L .76344 .32325 L F
.41083 .3332 m .412 .33038 L .4137 .33234 L 0 .045 .147 r
F
.41083 .3332 m .40913 .33124 L .412 .33038 L F
.56423 .38657 m .56271 .3877 L .56556 .37771 L 0 .239 .276 r
F
.56271 .3877 m .56402 .37689 L .56556 .37771 L 0 .254 .284 r
F
.32557 .32784 m .32663 .32479 L .32841 .32678 L 0 .032 .133 r
F
.32557 .32784 m .32379 .32584 L .32663 .32479 L F
.56825 .36243 m .5667 .36059 L .5696 .35549 L 0 .128 .215 r
F
.56534 .36752 m .5667 .36059 L .56825 .36243 L 0 .155 .232 r
F
.63491 .33348 m .63643 .33058 L .6379 .33233 L 0 .045 .148 r
F
.63491 .33348 m .63343 .33174 L .63643 .33058 L F
.76922 .32604 m .77092 .32298 L .77228 .32492 L 0 .028 .128 r
F
.76922 .32604 m .76786 .32409 L .77092 .32298 L F
.30612 .32647 m .30713 .3237 L .30894 .32549 L 0 .03 .13 r
F
.30612 .32647 m .3043 .3247 L .30713 .3237 L F
.8409 .32462 m .84272 .32169 L .84401 .32361 L 0 .026 .125 r
F
.8409 .32462 m .83962 .32271 L .84272 .32169 L F
.27921 .32546 m .28018 .32255 L .28201 .32444 L 0 .028 .127 r
F
.27921 .32546 m .27737 .32356 L .28018 .32255 L F
.16863 .32402 m .16943 .32119 L .17137 .32305 L 0 .025 .124 r
F
.16863 .32402 m .16668 .32218 L .16943 .32119 L F
.61706 .33708 m .61854 .33412 L .62003 .33581 L 0 .055 .157 r
F
.61706 .33708 m .61556 .33536 L .61854 .33412 L F
.77669 .3257 m .77841 .3227 L .77975 .32458 L 0 .028 .128 r
F
.77669 .3257 m .77534 .3238 L .77841 .3227 L F
.64238 .33316 m .64389 .3299 L .64537 .33185 L 0 .044 .146 r
F
.64238 .33316 m .6409 .33119 L .64389 .3299 L F
.33302 .32759 m .33407 .32482 L .33585 .3267 L 0 .032 .133 r
F
.33302 .32759 m .33124 .32572 L .33407 .32482 L F
.24483 .32492 m .24575 .32202 L .24761 .32398 L 0 .027 .126 r
F
.24483 .32492 m .24297 .32295 L .24575 .32202 L F
.20299 .32472 m .20385 .32182 L .20576 .32366 L 0 .026 .125 r
F
.20299 .32472 m .20108 .32289 L .20385 .32182 L F
.35993 .32865 m .36104 .32558 L .36278 .32768 L 0 .034 .135 r
F
.35993 .32865 m .35819 .32656 L .36104 .32558 L F
.68263 .32847 m .68421 .32555 L .68565 .3275 L F
.68263 .32847 m .68118 .32652 L .68421 .32555 L F
.56154 .40196 m .56004 .4058 L .56287 .39328 L 0 .317 .304 r
F
.56287 .39328 m .56136 .39564 L .56423 .38657 L 0 .283 .297 r
F
.56004 .4058 m .56136 .39564 L .56287 .39328 L 0 .337 .294 r
F
.78416 .3254 m .7859 .3225 L .78723 .32433 L 0 .028 .127 r
F
.78416 .3254 m .78282 .32354 L .7859 .3225 L F
.57253 .35233 m .57393 .34794 L .57547 .34968 L 0 .098 .194 r
F
.57253 .35233 m .57099 .35051 L .57393 .34794 L F
.5696 .35549 m .57099 .35051 L .57253 .35233 L 0 .109 .202 r
F
.13423 .32357 m .13499 .32068 L .13696 .32255 L 0 .024 .122 r
F
.13423 .32357 m .13226 .32169 L .13499 .32068 L F
.45583 .34367 m .45709 .34033 L .45873 .34283 L 0 .073 .174 r
F
.45583 .34367 m .45419 .34118 L .45709 .34033 L F
.67517 .32897 m .67674 .32598 L .67817 .32769 L 0 .035 .136 r
F
.67517 .32897 m .67373 .32727 L .67674 .32598 L F
.79162 .32505 m .79337 .32204 L .79469 .32388 L 0 .027 .126 r
F
.79162 .32505 m .7903 .3232 L .79337 .32204 L F
.57547 .34968 m .57687 .34549 L .57841 .34715 L 0 .09 .188 r
F
.57547 .34968 m .57393 .34794 L .57687 .34549 L F
.79909 .32465 m .80085 .32174 L .80218 .32367 L 0 .026 .125 r
F
.79909 .32465 m .79776 .32272 L .80085 .32174 L F
.4228 .33544 m .424 .33235 L .42568 .33467 L 0 .05 .153 r
F
.4228 .33544 m .42112 .33316 L .424 .33235 L F
.49938 .43232 m .50055 .44827 L .5022 .44673 L 0 .442 .184 r
F
.49938 .43232 m .49774 .43317 L .50055 .44827 L F
.38684 .32987 m .38797 .32701 L .38969 .32914 L 0 .037 .139 r
F
.38684 .32987 m .38512 .32776 L .38797 .32701 L F
.55162 .42944 m .55015 .44044 L .55304 .43068 L 0 .408 .231 r
F
.54872 .43757 m .55015 .44044 L .55162 .42944 L 0 .44 .188 r
F
.8484 .32453 m .85023 .32162 L .85151 .32353 L 0 .026 .125 r
F
.8484 .32453 m .84712 .3226 L .85023 .32162 L F
.21043 .32454 m .21131 .32158 L .2132 .32353 L F
.21043 .32454 m .20854 .32259 L .21131 .32158 L F
.31355 .32643 m .31457 .32373 L .31637 .32562 L 0 .03 .131 r
F
.31355 .32643 m .31176 .32455 L .31457 .32373 L F
.57841 .34715 m .57983 .34359 L .58136 .34523 L 0 .084 .183 r
F
.57841 .34715 m .57687 .34549 L .57983 .34359 L F
.39882 .33185 m .39998 .32895 L .40168 .33102 L 0 .042 .144 r
F
.39882 .33185 m .39711 .32976 L .39998 .32895 L F
.43479 .33745 m .43601 .33429 L .43767 .33669 L 0 .056 .158 r
F
.43479 .33745 m .43312 .3351 L .43601 .33429 L F
.59921 .34101 m .60065 .33737 L .60217 .33931 L 0 .065 .167 r
F
.59921 .34101 m .59769 .33903 L .60065 .33737 L F
.14166 .32344 m .14242 .32059 L .14439 .32248 L 0 .024 .123 r
F
.14166 .32344 m .13969 .32154 L .14242 .32059 L F
.17604 .32406 m .17685 .32124 L .17878 .32315 L 0 .026 .124 r
F
.17604 .32406 m .17411 .32214 L .17685 .32124 L F
.28663 .32553 m .28761 .32271 L .28943 .32466 L 0 .028 .128 r
F
.28663 .32553 m .28481 .32358 L .28761 .32271 L F
.66772 .32968 m .66929 .32684 L .67073 .32855 L 0 .037 .139 r
F
.66772 .32968 m .66627 .32796 L .66929 .32684 L F
.69011 .32846 m .6917 .32548 L .69313 .32738 L 0 .034 .135 r
F
.69011 .32846 m .68868 .32652 L .6917 .32548 L F
.34046 .32764 m .34152 .32485 L .34329 .32669 L 0 .033 .134 r
F
.34046 .32764 m .33868 .3258 L .34152 .32485 L F
.25225 .32498 m .25319 .32198 L .25504 .32392 L 0 .027 .126 r
F
.25225 .32498 m .25039 .32303 L .25319 .32198 L F
.5236 .44897 m .52495 .47143 L .52654 .45679 L 0 .497 .088 r
F
.5236 .44897 m .522 .46177 L .52495 .47143 L F
.70504 .32769 m .70666 .32484 L .70807 .32659 L 0 .033 .134 r
F
.70504 .32769 m .70363 .32592 L .70666 .32484 L F
.7125 .32729 m .71414 .32454 L .71554 .32627 L 0 .032 .133 r
F
.7125 .32729 m .7111 .32555 L .71414 .32454 L F
.69758 .32813 m .69918 .32518 L .7006 .32699 L 0 .034 .135 r
F
.69758 .32813 m .69615 .32628 L .69918 .32518 L F
.85589 .32442 m .85774 .32153 L .859 .32339 L 0 .026 .125 r
F
.85589 .32442 m .85462 .32254 L .85774 .32153 L F
.80659 .32464 m .80836 .32169 L .80967 .32363 L 0 .027 .126 r
F
.80659 .32464 m .80527 .3227 L .80836 .32169 L F
.5696 .35549 m .56805 .35355 L .57099 .35051 L 0 .109 .202 r
F
.5667 .36059 m .56805 .35355 L .5696 .35549 L 0 .127 .214 r
F
.60961 .33812 m .61108 .33485 L .61258 .33666 L 0 .058 .16 r
F
.60961 .33812 m .6081 .33627 L .61108 .33485 L F
.66026 .33027 m .66181 .32731 L .66327 .32907 L 0 .039 .14 r
F
.66026 .33027 m .65881 .32848 L .66181 .32731 L F
.36736 .32883 m .36847 .326 L .37021 .32796 L 0 .036 .137 r
F
.36736 .32883 m .36562 .32684 L .36847 .326 L F
.62748 .33464 m .62897 .33147 L .63045 .3331 L 0 .049 .151 r
F
.62748 .33464 m .62599 .33299 L .62897 .33147 L F
.21785 .32453 m .21873 .32166 L .22062 .32359 L 0 .027 .126 r
F
.21785 .32453 m .21596 .32259 L .21873 .32166 L F
.45129 .34192 m .45254 .33869 L .45419 .34118 L 0 .069 .17 r
F
.45129 .34192 m .44964 .33945 L .45254 .33869 L F
.25969 .32475 m .26064 .32185 L .26249 .32374 L 0 .027 .126 r
F
.25969 .32475 m .25784 .32285 L .26064 .32185 L F
.86337 .32417 m .86523 .32123 L .86648 .32308 L 0 .026 .125 r
F
.86337 .32417 m .86211 .32231 L .86523 .32123 L F
.81407 .32442 m .81584 .32142 L .81715 .3233 L F
.81407 .32442 m .81276 .32252 L .81584 .32142 L F
.3479 .32754 m .34898 .32465 L .35075 .32651 L 0 .033 .134 r
F
.3479 .32754 m .34614 .32567 L .34898 .32465 L F
.71998 .32715 m .72161 .3241 L .72301 .326 L 0 .032 .132 r
F
.71998 .32715 m .71858 .32524 L .72161 .3241 L F
.14907 .32343 m .14984 .32061 L .1518 .32249 L 0 .025 .123 r
F
.14907 .32343 m .14711 .32154 L .14984 .32061 L F
.41825 .33381 m .41944 .33097 L .42112 .33316 L 0 .048 .15 r
F
.41825 .33381 m .41657 .33166 L .41944 .33097 L F
.72745 .32679 m .72909 .32374 L .73049 .32569 L 0 .031 .132 r
F
.72745 .32679 m .72605 .32484 L .72909 .32374 L F
.50549 .44025 m .50669 .46017 L .50835 .45367 L 0 .471 .138 r
F
.50549 .44025 m .50384 .4452 L .50669 .46017 L F
.18345 .32412 m .18428 .32118 L .18621 .32307 L 0 .026 .125 r
F
.18345 .32412 m .18152 .32221 L .18428 .32118 L F
.87085 .32392 m .87273 .32105 L .87398 .32294 L F
.87085 .32392 m .8696 .32204 L .87273 .32105 L F
.82154 .32414 m .82335 .32131 L .82464 .32315 L F
.82154 .32414 m .82025 .32228 L .82335 .32131 L F
.46781 .34631 m .46907 .34321 L .4707 .34594 L 0 .083 .182 r
F
.46781 .34631 m .46617 .34364 L .46907 .34321 L F
.48821 .40073 m .48665 .39331 L .48947 .40103 L 0 .336 .295 r
F
.48665 .39331 m .48792 .39207 L .48947 .40103 L 0 .31 .307 r
F
.47233 .34866 m .4736 .34558 L .47523 .3484 L 0 .091 .189 r
F
.47233 .34866 m .4707 .34594 L .4736 .34558 L F
.22528 .32445 m .22618 .32155 L .22807 .3234 L 0 .027 .126 r
F
.22528 .32445 m .2234 .32258 L .22618 .32155 L F
.65282 .33108 m .65435 .32793 L .65581 .32978 L 0 .041 .143 r
F
.65282 .33108 m .65135 .32919 L .65435 .32793 L F
.40626 .33212 m .40742 .32928 L .40913 .33124 L 0 .044 .146 r
F
.40626 .33212 m .40455 .33016 L .40742 .32928 L F
.26713 .32467 m .26807 .32197 L .26992 .32377 L 0 .028 .127 r
F
.26713 .32467 m .26528 .32285 L .26807 .32197 L F
.56136 .39564 m .56271 .3877 L .56423 .38657 L 0 .311 .306 r
F
.1909 .32385 m .19173 .32107 L .19365 .3229 L 0 .026 .125 r
F
.1909 .32385 m .18897 .32203 L .19173 .32107 L F
.29405 .32572 m .29504 .3229 L .29686 .32482 L 0 .03 .13 r
F
.29405 .32572 m .29223 .32378 L .29504 .3229 L F
.74985 .32573 m .75154 .32287 L .75291 .32465 L F
.74985 .32573 m .74849 .32394 L .75154 .32287 L F
.59176 .3421 m .5932 .33883 L .59472 .34068 L 0 .07 .171 r
F
.59176 .3421 m .59023 .34025 L .5932 .33883 L F
.37481 .32886 m .37593 .32598 L .37767 .3278 L 0 .036 .138 r
F
.37481 .32886 m .37307 .32701 L .37593 .32598 L F
.58136 .34523 m .58278 .34168 L .58431 .34331 L 0 .079 .179 r
F
.58136 .34523 m .57983 .34359 L .58278 .34168 L F
.55869 .41315 m .56004 .4058 L .56154 .40196 L 0 .361 .277 r
F
.32097 .32681 m .32201 .32385 L .32379 .32584 L 0 .032 .132 r
F
.32097 .32681 m .31918 .32481 L .32201 .32385 L F
.12212 .32269 m .12284 .31995 L .12483 .32176 L 0 .024 .122 r
F
.12212 .32269 m .12012 .32088 L .12284 .31995 L F
.73493 .32664 m .7366 .32377 L .73798 .32566 L 0 .032 .132 r
F
.73493 .32664 m .73354 .32473 L .7366 .32377 L F
.1565 .32333 m .15728 .32057 L .15924 .32236 L 0 .025 .124 r
F
.1565 .32333 m .15454 .32153 L .15728 .32057 L F
.23274 .32417 m .23364 .32131 L .23552 .32313 L 0 .027 .126 r
F
.23274 .32417 m .23085 .32236 L .23364 .32131 L F
.38227 .32853 m .38338 .32595 L .38512 .32776 L 0 .036 .138 r
F
.38227 .32853 m .38053 .32674 L .38338 .32595 L F
.82903 .32399 m .83084 .3211 L .83213 .32292 L 0 .026 .125 r
F
.82903 .32399 m .82774 .32216 L .83084 .3211 L F
.75733 .32545 m .75902 .32248 L .76038 .32436 L 0 .029 .129 r
F
.75733 .32545 m .75596 .32357 L .75902 .32248 L F
.43023 .33605 m .43145 .33272 L .43312 .3351 L 0 .053 .156 r
F
.43023 .33605 m .42856 .3337 L .43145 .33272 L F
.35534 .32757 m .35644 .32447 L .35819 .32656 L 0 .033 .134 r
F
.35534 .32757 m .35359 .32549 L .35644 .32447 L F
.44675 .3402 m .44799 .33699 L .44964 .33945 L 0 .065 .167 r
F
.44675 .3402 m .4451 .33773 L .44799 .33699 L F
.7424 .32638 m .74407 .32334 L .74544 .32516 L 0 .031 .131 r
F
.7424 .32638 m .74103 .32454 L .74407 .32334 L F
.24019 .32392 m .24109 .32112 L .24297 .32295 L 0 .026 .125 r
F
.24019 .32392 m .23831 .32209 L .24109 .32112 L F
.39425 .33055 m .3954 .32762 L .39711 .32976 L 0 .04 .142 r
F
.39425 .33055 m .39254 .3284 L .3954 .32762 L F
.27457 .32458 m .27553 .32178 L .27737 .32356 L 0 .028 .127 r
F
.27457 .32458 m .27272 .32279 L .27553 .32178 L F
.83652 .32375 m .83833 .3208 L .83962 .32271 L 0 .026 .125 r
F
.83652 .32375 m .83523 .32186 L .83833 .3208 L F
.7648 .32522 m .7665 .32214 L .76786 .32409 L 0 .029 .128 r
F
.7648 .32522 m .76344 .32325 L .7665 .32214 L F
.60217 .33931 m .60362 .3358 L .60513 .33769 L 0 .062 .164 r
F
.60217 .33931 m .60065 .33737 L .60362 .3358 L F
.64537 .33185 m .64688 .3286 L .64836 .33052 L 0 .043 .145 r
F
.64537 .33185 m .64389 .3299 L .64688 .3286 L F
.16394 .32316 m .16473 .32038 L .16668 .32218 L 0 .025 .124 r
F
.16394 .32316 m .16198 .32137 L .16473 .32038 L F
.62003 .33581 m .62153 .33286 L .62302 .33452 L 0 .054 .156 r
F
.62003 .33581 m .61854 .33412 L .62153 .33286 L F
.19832 .3238 m .19916 .32107 L .20108 .32289 L 0 .026 .125 r
F
.19832 .3238 m .1964 .32199 L .19916 .32107 L F
.30149 .32568 m .30249 .32292 L .3043 .3247 L 0 .03 .13 r
F
.30149 .32568 m .29967 .32391 L .30249 .32292 L F
.47685 .35137 m .47813 .34814 L .47975 .35141 L 0 .102 .196 r
F
.47685 .35137 m .47523 .3484 L .47813 .34814 L F
.46327 .34454 m .46454 .34099 L .46617 .34364 L 0 .077 .178 r
F
.46327 .34454 m .46163 .34191 L .46454 .34099 L F
.6379 .33233 m .63942 .32942 L .6409 .33119 L 0 .045 .147 r
F
.6379 .33233 m .63643 .33058 L .63942 .32942 L F
.32841 .32678 m .32947 .32374 L .33124 .32572 L 0 .032 .133 r
F
.32841 .32678 m .32663 .32479 L .32947 .32374 L F
.77228 .32492 m .77399 .32186 L .77534 .3238 L 0 .028 .128 r
F
.77228 .32492 m .77092 .32298 L .77399 .32186 L F
.12954 .32264 m .13027 .31987 L .13226 .32169 L 0 .024 .122 r
F
.12954 .32264 m .12755 .32083 L .13027 .31987 L F
.48637 .38397 m .48481 .37635 L .48767 .38029 L 0 .258 .285 r
F
.48481 .37635 m .48612 .37141 L .48767 .38029 L 0 .204 .259 r
F
.67817 .32769 m .67975 .32481 L .68118 .32652 L 0 .034 .135 r
F
.67817 .32769 m .67674 .32598 L .67975 .32481 L F
.77975 .32458 m .78148 .32168 L .78282 .32354 L 0 .028 .127 r
F
.77975 .32458 m .77841 .3227 L .78148 .32168 L F
.84401 .32361 m .84584 .32067 L .84712 .3226 L 0 .026 .125 r
F
.84401 .32361 m .84272 .32169 L .84584 .32067 L F
.28201 .32444 m .28298 .32168 L .28481 .32358 L 0 .028 .127 r
F
.28201 .32444 m .28018 .32255 L .28298 .32168 L F
.30894 .32549 m .30995 .32275 L .31176 .32455 L 0 .03 .13 r
F
.30894 .32549 m .30713 .3237 L .30995 .32275 L F
.4137 .33234 m .41487 .32969 L .41657 .33166 L 0 .046 .148 r
F
.4137 .33234 m .412 .33038 L .41487 .32969 L F
.20576 .32366 m .20663 .32076 L .20854 .32259 L 0 .026 .125 r
F
.20576 .32366 m .20385 .32182 L .20663 .32076 L F
.17137 .32305 m .17217 .32028 L .17411 .32214 L 0 .025 .124 r
F
.17137 .32305 m .16943 .32119 L .17217 .32028 L F
.79469 .32388 m .79644 .32088 L .79776 .32272 L 0 .026 .125 r
F
.79469 .32388 m .79337 .32204 L .79644 .32088 L F
.78723 .32433 m .78897 .32139 L .7903 .3232 L 0 .027 .127 r
F
.78723 .32433 m .7859 .3225 L .78897 .32139 L F
.44221 .33842 m .44344 .33524 L .4451 .33773 L 0 .061 .163 r
F
.44221 .33842 m .44055 .33596 L .44344 .33524 L F
.36278 .32768 m .36388 .32477 L .36562 .32684 L 0 .034 .136 r
F
.36278 .32768 m .36104 .32558 L .36388 .32477 L F
.24761 .32398 m .24853 .32109 L .25039 .32303 L 0 .027 .126 r
F
.24761 .32398 m .24575 .32202 L .24853 .32109 L F
.68565 .3275 m .68724 .32458 L .68868 .32652 L 0 .034 .135 r
F
.68565 .3275 m .68421 .32555 L .68724 .32458 L F
.63045 .3331 m .63195 .3301 L .63343 .33174 L 0 .047 .15 r
F
.63045 .3331 m .62897 .33147 L .63195 .3301 L F
.33585 .3267 m .33691 .32392 L .33868 .3258 L 0 .033 .133 r
F
.33585 .3267 m .33407 .32482 L .33691 .32392 L F
.13696 .32255 m .13772 .31968 L .13969 .32154 L 0 .024 .122 r
F
.13696 .32255 m .13499 .32068 L .13772 .31968 L F
.61258 .33666 m .61406 .33359 L .61556 .33536 L 0 .056 .159 r
F
.61258 .33666 m .61108 .33485 L .61406 .33359 L F
.53107 .44993 m .53247 .46721 L .53402 .45232 L 0 .493 .098 r
F
.53107 .44993 m .5295 .4641 L .53247 .46721 L F
.58431 .34331 m .58574 .34004 L .58727 .34166 L 0 .075 .176 r
F
.58431 .34331 m .58278 .34168 L .58574 .34004 L F
.80218 .32367 m .80394 .32076 L .80527 .3227 L 0 .026 .125 r
F
.80218 .32367 m .80085 .32174 L .80394 .32076 L F
.55591 .42083 m .55445 .42984 L .55731 .41811 L 0 .38 .261 r
F
.55304 .43068 m .55445 .42984 L .55591 .42083 L 0 .42 .216 r
F
.2132 .32353 m .21407 .32065 L .21596 .32259 L 0 .026 .125 r
F
.2132 .32353 m .21131 .32158 L .21407 .32065 L F
.85151 .32353 m .85335 .32064 L .85462 .32254 L F
.85151 .32353 m .85023 .32162 L .85335 .32064 L F
.45873 .34283 m .45999 .33939 L .46163 .34191 L 0 .074 .174 r
F
.45873 .34283 m .45709 .34033 L .45999 .33939 L F
.67073 .32855 m .67229 .32556 L .67373 .32727 L 0 .037 .138 r
F
.67073 .32855 m .66929 .32684 L .67229 .32556 L F
.69313 .32738 m .69473 .32441 L .69615 .32628 L 0 .034 .135 r
F
.69313 .32738 m .6917 .32548 L .69473 .32441 L F
.7006 .32699 m .70221 .32412 L .70363 .32592 L 0 .034 .134 r
F
.7006 .32699 m .69918 .32518 L .70221 .32412 L F
.66327 .32907 m .66483 .32622 L .66627 .32796 L 0 .038 .14 r
F
.66327 .32907 m .66181 .32731 L .66483 .32622 L F
.70807 .32659 m .7097 .3238 L .7111 .32555 L 0 .033 .134 r
F
.70807 .32659 m .70666 .32484 L .7097 .3238 L F
.42568 .33467 m .42689 .33135 L .42856 .3337 L 0 .051 .154 r
F
.42568 .33467 m .424 .33235 L .42689 .33135 L F
.25504 .32392 m .25599 .32093 L .25784 .32285 L 0 .027 .126 r
F
.25504 .32392 m .25319 .32198 L .25599 .32093 L F
.14439 .32248 m .14515 .31965 L .14711 .32154 L 0 .024 .123 r
F
.14439 .32248 m .14242 .32059 L .14515 .31965 L F
.31637 .32562 m .31739 .32291 L .31918 .32481 L 0 .031 .131 r
F
.31637 .32562 m .31457 .32373 L .31739 .32291 L F
.38969 .32914 m .39083 .32626 L .39254 .3284 L 0 .038 .14 r
F
.38969 .32914 m .38797 .32701 L .39083 .32626 L F
.40168 .33102 m .40285 .32809 L .40455 .33016 L 0 .043 .145 r
F
.40168 .33102 m .39998 .32895 L .40285 .32809 L F
.17878 .32315 m .1796 .3203 L .18152 .32221 L 0 .026 .125 r
F
.17878 .32315 m .17685 .32124 L .1796 .3203 L F
.71554 .32627 m .71719 .32354 L .71858 .32524 L 0 .032 .133 r
F
.71554 .32627 m .71414 .32454 L .71719 .32354 L F
.34329 .32669 m .34436 .32385 L .34614 .32567 L 0 .033 .134 r
F
.34329 .32669 m .34152 .32485 L .34436 .32385 L F
.859 .32339 m .86085 .32045 L .86211 .32231 L 0 .026 .125 r
F
.859 .32339 m .85774 .32153 L .86085 .32045 L F
.56402 .37689 m .56247 .37607 L .56534 .36752 L 0 .195 .254 r
F
.56534 .36752 m .56379 .36568 L .5667 .36059 L 0 .155 .232 r
F
.56247 .37607 m .56379 .36568 L .56534 .36752 L 0 .198 .256 r
F
.28943 .32466 m .29042 .32184 L .29223 .32378 L 0 .029 .129 r
F
.28943 .32466 m .28761 .32271 L .29042 .32184 L F
.80967 .32363 m .81144 .3206 L .81276 .32252 L 0 .027 .126 r
F
.80967 .32363 m .80836 .32169 L .81144 .3206 L F
.43767 .33669 m .43889 .3335 L .44055 .33596 L 0 .057 .159 r
F
.43767 .33669 m .43601 .33429 L .43889 .3335 L F
.48454 .36546 m .48296 .35952 L .48585 .36068 L 0 .158 .233 r
F
.48296 .35952 m .48427 .35512 L .48585 .36068 L 0 .131 .217 r
F
.48296 .35952 m .48137 .35467 L .48427 .35512 L F
.59472 .34068 m .59616 .33718 L .59769 .33903 L 0 .068 .169 r
F
.59472 .34068 m .5932 .33883 L .59616 .33718 L F
.86648 .32308 m .86835 .32021 L .8696 .32204 L 0 .026 .125 r
F
.86648 .32308 m .86523 .32123 L .86835 .32021 L F
.81715 .3233 m .81894 .32041 L .82025 .32228 L F
.81715 .3233 m .81584 .32142 L .81894 .32041 L F
.72301 .326 m .72465 .32294 L .72605 .32484 L 0 .031 .132 r
F
.72301 .326 m .72161 .3241 L .72465 .32294 L F
.26249 .32374 m .26343 .32098 L .26528 .32285 L 0 .027 .127 r
F
.26249 .32374 m .26064 .32185 L .26343 .32098 L F
.65581 .32978 m .65735 .32666 L .65881 .32848 L 0 .04 .142 r
F
.65581 .32978 m .65435 .32793 L .65735 .32666 L F
.22062 .32359 m .22151 .32066 L .2234 .32258 L 0 .027 .126 r
F
.22062 .32359 m .21873 .32166 L .22151 .32066 L F
.48137 .35467 m .48265 .35149 L .48427 .35512 L 0 .116 .207 r
F
.48137 .35467 m .47975 .35141 L .48265 .35149 L F
.60513 .33769 m .60659 .33442 L .6081 .33627 L 0 .06 .162 r
F
.60513 .33769 m .60362 .3358 L .60659 .33442 L F
.35075 .32651 m .35183 .32362 L .35359 .32549 L 0 .033 .134 r
F
.35075 .32651 m .34898 .32465 L .35183 .32362 L F
.37021 .32796 m .37133 .32508 L .37307 .32701 L 0 .036 .137 r
F
.37021 .32796 m .36847 .326 L .37133 .32508 L F
.73049 .32569 m .73215 .3228 L .73354 .32473 L 0 .031 .132 r
F
.73049 .32569 m .72909 .32374 L .73215 .3228 L F
.18621 .32307 m .18705 .32014 L .18897 .32203 L 0 .026 .125 r
F
.18621 .32307 m .18428 .32118 L .18705 .32014 L F
.1518 .32249 m .15258 .31967 L .15454 .32153 L 0 .025 .124 r
F
.1518 .32249 m .14984 .32061 L .15258 .31967 L F
.87398 .32294 m .87586 .32005 L .87711 .32195 L 0 .026 .125 r
F
.87398 .32294 m .87273 .32105 L .87586 .32005 L F
.82464 .32315 m .82645 .32033 L .82774 .32216 L F
.82464 .32315 m .82335 .32131 L .82645 .32033 L F
.45419 .34118 m .45544 .33782 L .45709 .34033 L 0 .07 .171 r
F
.45419 .34118 m .45254 .33869 L .45544 .33782 L F
.22807 .3234 m .22896 .32051 L .23085 .32236 L 0 .027 .126 r
F
.22807 .3234 m .22618 .32155 L .22896 .32051 L F
.75291 .32465 m .7546 .32179 L .75596 .32357 L 0 .029 .129 r
F
.75291 .32465 m .75154 .32287 L .7546 .32179 L F
.37767 .3278 m .37879 .32495 L .38053 .32674 L 0 .036 .138 r
F
.37767 .3278 m .37593 .32598 L .37879 .32495 L F
.64836 .33052 m .64988 .3273 L .65135 .32919 L 0 .042 .144 r
F
.64836 .33052 m .64688 .3286 L .64988 .3273 L F
.74544 .32516 m .74712 .32215 L .74849 .32394 L 0 .03 .13 r
F
.74544 .32516 m .74407 .32334 L .74712 .32215 L F
.19365 .3229 m .19448 .32016 L .1964 .32199 L 0 .026 .125 r
F
.19365 .3229 m .19173 .32107 L .19448 .32016 L F
.76038 .32436 m .76208 .32137 L .76344 .32325 L 0 .029 .128 r
F
.76038 .32436 m .75902 .32248 L .76208 .32137 L F
.62302 .33452 m .6245 .33134 L .62599 .33299 L 0 .052 .154 r
F
.62302 .33452 m .62153 .33286 L .6245 .33134 L F
.23552 .32313 m .23643 .32026 L .23831 .32209 L 0 .026 .126 r
F
.23552 .32313 m .23364 .32131 L .23643 .32026 L F
.83213 .32292 m .83395 .32005 L .83523 .32186 L 0 .026 .125 r
F
.83213 .32292 m .83084 .3211 L .83395 .32005 L F
.26992 .32377 m .27087 .321 L .27272 .32279 L 0 .028 .127 r
F
.26992 .32377 m .26807 .32197 L .27087 .321 L F
.32379 .32584 m .32485 .3228 L .32663 .32479 L 0 .032 .132 r
F
.32379 .32584 m .32201 .32385 L .32485 .3228 L F
.29686 .32482 m .29785 .32201 L .29967 .32391 L 0 .03 .13 r
F
.29686 .32482 m .29504 .3229 L .29785 .32201 L F
.40913 .33124 m .4103 .32842 L .412 .33038 L 0 .044 .147 r
F
.40913 .33124 m .40742 .32928 L .4103 .32842 L F
.73798 .32566 m .73965 .32266 L .74103 .32454 L 0 .031 .132 r
F
.73798 .32566 m .7366 .32377 L .73965 .32266 L F
.15924 .32236 m .16002 .31958 L .16198 .32137 L 0 .025 .124 r
F
.15924 .32236 m .15728 .32057 L .16002 .31958 L F
.12483 .32176 m .12555 .31901 L .12755 .32083 L 0 .024 .122 r
F
.12483 .32176 m .12284 .31995 L .12555 .31901 L F
.42112 .33316 m .42232 .33014 L .424 .33235 L 0 .049 .151 r
F
.42112 .33316 m .41944 .33097 L .42232 .33014 L F
.58727 .34166 m .58871 .3386 L .59023 .34025 L 0 .073 .173 r
F
.58727 .34166 m .58574 .34004 L .58871 .3386 L F
.35819 .32656 m .3593 .32349 L .36104 .32558 L 0 .033 .134 r
F
.35819 .32656 m .35644 .32447 L .3593 .32349 L F
.76786 .32409 m .76957 .32103 L .77092 .32298 L 0 .028 .128 r
F
.76786 .32409 m .7665 .32214 L .76957 .32103 L F
.43312 .3351 m .43434 .33185 L .43601 .33429 L 0 .054 .156 r
F
.43312 .3351 m .43145 .33272 L .43434 .33185 L F
.5667 .36059 m .56514 .35838 L .56805 .35355 L 0 .127 .214 r
F
.56379 .36568 m .56514 .35838 L .5667 .36059 L 0 .153 .231 r
F
.6409 .33119 m .64242 .32812 L .64389 .3299 L 0 .044 .146 r
F
.6409 .33119 m .63942 .32942 L .64242 .32812 L F
.83962 .32271 m .84144 .31977 L .84272 .32169 L 0 .026 .125 r
F
.83962 .32271 m .83833 .3208 L .84144 .31977 L F
.27737 .32356 m .27834 .32078 L .28018 .32255 L 0 .028 .127 r
F
.27737 .32356 m .27553 .32178 L .27834 .32078 L F
.24297 .32295 m .24388 .32019 L .24575 .32202 L 0 .027 .126 r
F
.24297 .32295 m .24109 .32112 L .24388 .32019 L F
.77534 .3238 m .77706 .32077 L .77841 .3227 L 0 .028 .127 r
F
.77534 .3238 m .77399 .32186 L .77706 .32077 L F
.38512 .32776 m .38624 .32519 L .38797 .32701 L 0 .037 .139 r
F
.38512 .32776 m .38338 .32595 L .38624 .32519 L F
.68118 .32652 m .68278 .32383 L .68421 .32555 L 0 .034 .135 r
F
.68118 .32652 m .67975 .32481 L .68278 .32383 L F
.16668 .32218 m .16747 .31938 L .16943 .32119 L 0 .025 .124 r
F
.16668 .32218 m .16473 .32038 L .16747 .31938 L F
.33124 .32572 m .3323 .32283 L .33407 .32482 L 0 .032 .133 r
F
.33124 .32572 m .32947 .32374 L .3323 .32283 L F
.3043 .3247 m .30531 .32192 L .30713 .3237 L 0 .03 .13 r
F
.3043 .3247 m .30249 .32292 L .30531 .32192 L F
.63343 .33174 m .63495 .32891 L .63643 .33058 L 0 .046 .149 r
F
.63343 .33174 m .63195 .3301 L .63495 .32891 L F
.44964 .33945 m .45089 .33625 L .45254 .33869 L 0 .066 .168 r
F
.44964 .33945 m .44799 .33699 L .45089 .33625 L F
.20108 .32289 m .20193 .32 L .20385 .32182 L 0 .026 .125 r
F
.20108 .32289 m .19916 .32107 L .20193 .32 L F
.39711 .32976 m .39827 .32684 L .39998 .32895 L 0 .041 .143 r
F
.39711 .32976 m .3954 .32762 L .39827 .32684 L F
.46617 .34364 m .46744 .34051 L .46907 .34321 L 0 .079 .179 r
F
.46617 .34364 m .46454 .34099 L .46744 .34051 L F
.78282 .32354 m .78456 .32066 L .7859 .3225 L 0 .028 .127 r
F
.78282 .32354 m .78148 .32168 L .78456 .32066 L F
.79776 .32272 m .79953 .3199 L .80085 .32174 L 0 .026 .125 r
F
.79776 .32272 m .79644 .32088 L .79953 .3199 L F
.61556 .33536 m .61704 .33239 L .61854 .33412 L 0 .055 .158 r
F
.61556 .33536 m .61406 .33359 L .61704 .33239 L F
.13226 .32169 m .133 .31887 L .13499 .32068 L 0 .024 .123 r
F
.13226 .32169 m .13027 .31987 L .133 .31887 L F
.4707 .34594 m .47197 .3428 L .4736 .34558 L 0 .087 .185 r
F
.4707 .34594 m .46907 .34321 L .47197 .3428 L F
.57099 .35051 m .57239 .3462 L .57393 .34794 L 0 .099 .194 r
F
.57099 .35051 m .56944 .34868 L .57239 .3462 L F
.56805 .35355 m .56944 .34868 L .57099 .35051 L 0 .109 .201 r
F
.48612 .37141 m .48454 .36546 L .48742 .36758 L 0 .191 .252 r
F
.48454 .36546 m .48585 .36068 L .48742 .36758 L 0 .158 .233 r
F
.7903 .3232 m .79204 .32024 L .79337 .32204 L 0 .027 .126 r
F
.7903 .3232 m .78897 .32139 L .79204 .32024 L F
.20854 .32259 m .2094 .31973 L .21131 .32158 L 0 .026 .125 r
F
.20854 .32259 m .20663 .32076 L .2094 .31973 L F
.84712 .3226 m .84895 .31969 L .85023 .32162 L F
.84712 .3226 m .84584 .32067 L .84895 .31969 L F
.48978 .40813 m .48821 .40073 L .49103 .41002 L 0 .362 .277 r
F
.48821 .40073 m .48947 .40103 L .49103 .41002 L 0 .336 .295 r
F
.57393 .34794 m .57533 .34382 L .57687 .34549 L 0 .091 .188 r
F
.57393 .34794 m .57239 .3462 L .57533 .34382 L F
.59769 .33903 m .59913 .33552 L .60065 .33737 L 0 .064 .166 r
F
.59769 .33903 m .59616 .33718 L .59913 .33552 L F
.31176 .32455 m .31276 .32192 L .31457 .32373 L 0 .03 .131 r
F
.31176 .32455 m .30995 .32275 L .31276 .32192 L F
.67373 .32727 m .6753 .32428 L .67674 .32598 L 0 .036 .137 r
F
.67373 .32727 m .67229 .32556 L .6753 .32428 L F
.47523 .3484 m .47651 .34521 L .47813 .34814 L 0 .095 .192 r
F
.47523 .3484 m .4736 .34558 L .47651 .34521 L F
.28481 .32358 m .28579 .3208 L .28761 .32271 L 0 .028 .128 r
F
.28481 .32358 m .28298 .32168 L .28579 .3208 L F
.17411 .32214 m .17491 .31938 L .17685 .32124 L 0 .025 .124 r
F
.17411 .32214 m .17217 .32028 L .17491 .31938 L F
.13969 .32154 m .14045 .31872 L .14242 .32059 L 0 .024 .123 r
F
.13969 .32154 m .13772 .31968 L .14045 .31872 L F
.68868 .32652 m .69027 .32357 L .6917 .32548 L 0 .034 .135 r
F
.68868 .32652 m .68724 .32458 L .69027 .32357 L F
.25039 .32303 m .25133 .32006 L .25319 .32198 L 0 .027 .126 r
F
.25039 .32303 m .24853 .32109 L .25133 .32006 L F
.56805 .35355 m .5665 .3516 L .56944 .34868 L 0 .109 .201 r
F
.56514 .35838 m .5665 .3516 L .56805 .35355 L 0 .126 .213 r
F
.33868 .3258 m .33974 .32298 L .34152 .32485 L 0 .033 .134 r
F
.33868 .3258 m .33691 .32392 L .33974 .32298 L F
.36562 .32684 m .36673 .32395 L .36847 .326 L 0 .035 .136 r
F
.36562 .32684 m .36388 .32477 L .36673 .32395 L F
.57687 .34549 m .57829 .34194 L .57983 .34359 L 0 .085 .183 r
F
.57687 .34549 m .57533 .34382 L .57829 .34194 L F
.80527 .3227 m .80704 .31975 L .80836 .32169 L 0 .026 .126 r
F
.80527 .3227 m .80394 .32076 L .80704 .31975 L F
.85462 .32254 m .85647 .31964 L .85774 .32153 L 0 .026 .125 r
F
.85462 .32254 m .85335 .32064 L .85647 .31964 L F
.41657 .33166 m .41774 .329 L .41944 .33097 L 0 .047 .149 r
F
.41657 .33166 m .41487 .32969 L .41774 .329 L F
.69615 .32628 m .69776 .32334 L .69918 .32518 L 0 .034 .135 r
F
.69615 .32628 m .69473 .32441 L .69776 .32334 L F
.66627 .32796 m .66784 .32513 L .66929 .32684 L 0 .038 .14 r
F
.66627 .32796 m .66483 .32622 L .66784 .32513 L F
.21596 .32259 m .21684 .31972 L .21873 .32166 L 0 .026 .126 r
F
.21596 .32259 m .21407 .32065 L .21684 .31972 L F
.6081 .33627 m .60957 .33304 L .61108 .33485 L 0 .058 .16 r
F
.6081 .33627 m .60659 .33442 L .60957 .33304 L F
.70363 .32592 m .70525 .32305 L .70666 .32484 L 0 .033 .134 r
F
.70363 .32592 m .70221 .32412 L .70525 .32305 L F
.4451 .33773 m .44634 .33454 L .44799 .33699 L 0 .062 .164 r
F
.4451 .33773 m .44344 .33524 L .44634 .33454 L F
.46163 .34191 m .4629 .33846 L .46454 .34099 L 0 .074 .175 r
F
.46163 .34191 m .45999 .33939 L .4629 .33846 L F
.25784 .32285 m .25879 .31994 L .26064 .32185 L 0 .027 .126 r
F
.25784 .32285 m .25599 .32093 L .25879 .31994 L F
.7111 .32555 m .71274 .32281 L .71414 .32454 L 0 .033 .134 r
F
.7111 .32555 m .7097 .3238 L .71274 .32281 L F
.65881 .32848 m .66036 .32552 L .66181 .32731 L 0 .039 .141 r
F
.65881 .32848 m .65735 .32666 L .66036 .32552 L F
.42856 .3337 m .42978 .33034 L .43145 .33272 L 0 .051 .154 r
F
.42856 .3337 m .42689 .33135 L .42978 .33034 L F
.86211 .32231 m .86397 .31937 L .86523 .32123 L 0 .026 .125 r
F
.86211 .32231 m .86085 .32045 L .86397 .31937 L F
.81276 .32252 m .81453 .3195 L .81584 .32142 L F
.81276 .32252 m .81144 .3206 L .81453 .3195 L F
.71858 .32524 m .72022 .32238 L .72161 .3241 L 0 .032 .133 r
F
.71858 .32524 m .71719 .32354 L .72022 .32238 L F
.72605 .32484 m .7277 .32184 L .72909 .32374 L 0 .031 .131 r
F
.72605 .32484 m .72465 .32294 L .7277 .32184 L F
.34614 .32567 m .34721 .32284 L .34898 .32465 L 0 .033 .134 r
F
.34614 .32567 m .34436 .32385 L .34721 .32284 L F
.14711 .32154 m .14788 .31872 L .14984 .32061 L 0 .025 .123 r
F
.14711 .32154 m .14515 .31965 L .14788 .31872 L F
.56271 .3877 m .56117 .38737 L .56402 .37689 L 0 .254 .284 r
F
.56117 .38737 m .56247 .37607 L .56402 .37689 L 0 .265 .289 r
F
.18152 .32221 m .18236 .31927 L .18428 .32118 L 0 .026 .125 r
F
.18152 .32221 m .1796 .3203 L .18236 .31927 L F
.62599 .33299 m .62748 .32982 L .62897 .33147 L 0 .05 .152 r
F
.62599 .33299 m .6245 .33134 L .62748 .32982 L F
.8696 .32204 m .87148 .31923 L .87273 .32105 L 0 .026 .125 r
F
.8696 .32204 m .86835 .32021 L .87148 .31923 L F
.82025 .32228 m .82205 .31945 L .82335 .32131 L F
.82025 .32228 m .81894 .32041 L .82205 .31945 L F
.40455 .33016 m .40572 .32719 L .40742 .32928 L 0 .043 .146 r
F
.40455 .33016 m .40285 .32809 L .40572 .32719 L F
.31918 .32481 m .32022 .32194 L .32201 .32385 L 0 .031 .132 r
F
.31918 .32481 m .31739 .32291 L .32022 .32194 L F
.29223 .32378 m .29322 .32097 L .29504 .3229 L 0 .029 .129 r
F
.29223 .32378 m .29042 .32184 L .29322 .32097 L F
.65135 .32919 m .65288 .32607 L .65435 .32793 L 0 .041 .143 r
F
.65135 .32919 m .64988 .3273 L .65288 .32607 L F
.2234 .32258 m .22429 .31964 L .22618 .32155 L 0 .027 .126 r
F
.2234 .32258 m .22151 .32066 L .22429 .31964 L F
.35359 .32549 m .35468 .32258 L .35644 .32447 L 0 .033 .134 r
F
.35359 .32549 m .35183 .32362 L .35468 .32258 L F
.39254 .3284 m .39369 .3255 L .3954 .32762 L 0 .039 .141 r
F
.39254 .3284 m .39083 .32626 L .39369 .3255 L F
.47975 .35141 m .48104 .34786 L .48265 .35149 L 0 .107 .2 r
F
.47975 .35141 m .47813 .34814 L .48104 .34786 L F
.48792 .39207 m .48637 .38397 L .48922 .38927 L 0 .313 .306 r
F
.48637 .38397 m .48767 .38029 L .48922 .38927 L 0 .258 .285 r
F
.59023 .34025 m .59168 .33716 L .5932 .33883 L 0 .07 .172 r
F
.59023 .34025 m .58871 .3386 L .59168 .33716 L F
.26528 .32285 m .26622 .32011 L .26807 .32197 L 0 .028 .127 r
F
.26528 .32285 m .26343 .32098 L .26622 .32011 L F
.18897 .32203 m .1898 .31919 L .19173 .32107 L 0 .026 .125 r
F
.18897 .32203 m .18705 .32014 L .1898 .31919 L F
.73354 .32473 m .73521 .32186 L .7366 .32377 L 0 .031 .132 r
F
.73354 .32473 m .73215 .3228 L .73521 .32186 L F
.37307 .32701 m .37419 .32408 L .37593 .32598 L 0 .036 .138 r
F
.37307 .32701 m .37133 .32508 L .37419 .32408 L F
.44055 .33596 m .44178 .33274 L .44344 .33524 L 0 .058 .16 r
F
.44055 .33596 m .43889 .3335 L .44178 .33274 L F
.74849 .32394 m .75018 .32108 L .75154 .32287 L 0 .03 .13 r
F
.74849 .32394 m .74712 .32215 L .75018 .32108 L F
.48767 .38029 m .48612 .37141 L .48899 .3745 L 0 .241 .278 r
F
.48612 .37141 m .48742 .36758 L .48899 .3745 L 0 .191 .252 r
F
.75596 .32357 m .75767 .32071 L .75902 .32248 L 0 .029 .129 r
F
.75596 .32357 m .7546 .32179 L .75767 .32071 L F
.12012 .32088 m .12084 .3181 L .12284 .31995 L 0 .024 .122 r
F
.12012 .32088 m .11813 .31902 L .12084 .3181 L F
.23085 .32236 m .23175 .31946 L .23364 .32131 L 0 .027 .126 r
F
.23085 .32236 m .22896 .32051 L .23175 .31946 L F
.15454 .32153 m .15531 .31873 L .15728 .32057 L 0 .025 .124 r
F
.15454 .32153 m .15258 .31967 L .15531 .31873 L F
.82774 .32216 m .82956 .31929 L .83084 .3211 L 0 .026 .125 r
F
.82774 .32216 m .82645 .32033 L .82956 .31929 L F
.38053 .32674 m .38165 .32415 L .38338 .32595 L 0 .036 .138 r
F
.38053 .32674 m .37879 .32495 L .38165 .32415 L F
.76344 .32325 m .76515 .32027 L .7665 .32214 L 0 .028 .128 r
F
.76344 .32325 m .76208 .32137 L .76515 .32027 L F
.64389 .3299 m .64541 .3268 L .64688 .3286 L 0 .043 .145 r
F
.64389 .3299 m .64242 .32812 L .64541 .3268 L F
.57983 .34359 m .58125 .34005 L .58278 .34168 L 0 .08 .18 r
F
.57983 .34359 m .57829 .34194 L .58125 .34005 L F
.60065 .33737 m .6021 .33394 L .60362 .3358 L 0 .062 .164 r
F
.60065 .33737 m .59913 .33552 L .6021 .33394 L F
.74103 .32454 m .7427 .32149 L .74407 .32334 L 0 .031 .131 r
F
.74103 .32454 m .73965 .32266 L .7427 .32149 L F
.83523 .32186 m .83705 .319 L .83833 .3208 L 0 .026 .125 r
F
.83523 .32186 m .83395 .32005 L .83705 .319 L F
.45709 .34033 m .45834 .33688 L .45999 .33939 L 0 .07 .172 r
F
.45709 .34033 m .45544 .33782 L .45834 .33688 L F
.23831 .32209 m .23921 .31928 L .24109 .32112 L 0 .026 .126 r
F
.23831 .32209 m .23643 .32026 L .23921 .31928 L F
.32663 .32479 m .32768 .32175 L .32947 .32374 L 0 .032 .132 r
F
.32663 .32479 m .32485 .3228 L .32768 .32175 L F
.77092 .32298 m .77264 .31992 L .77399 .32186 L 0 .028 .127 r
F
.77092 .32298 m .76957 .32103 L .77264 .31992 L F
.27272 .32279 m .27368 .32 L .27553 .32178 L 0 .028 .128 r
F
.27272 .32279 m .27087 .321 L .27368 .32 L F
.1964 .32199 m .19724 .31924 L .19916 .32107 L 0 .026 .126 r
F
.1964 .32199 m .19448 .32016 L .19724 .31924 L F
.16198 .32137 m .16277 .31857 L .16473 .32038 L 0 .025 .124 r
F
.16198 .32137 m .16002 .31958 L .16277 .31857 L F
.29967 .32391 m .30067 .32103 L .30249 .32292 L 0 .03 .13 r
F
.29967 .32391 m .29785 .32201 L .30067 .32103 L F
.36104 .32558 m .36214 .32269 L .36388 .32477 L 0 .034 .135 r
F
.36104 .32558 m .3593 .32349 L .36214 .32269 L F
.12755 .32083 m .12828 .31805 L .13027 .31987 L 0 .024 .123 r
F
.12755 .32083 m .12555 .31901 L .12828 .31805 L F
.77841 .3227 m .78014 .31978 L .78148 .32168 L 0 .028 .127 r
F
.77841 .3227 m .77706 .32077 L .78014 .31978 L F
.63643 .33058 m .63795 .32772 L .63942 .32942 L 0 .045 .148 r
F
.63643 .33058 m .63495 .32891 L .63795 .32772 L F
.412 .33038 m .41317 .32772 L .41487 .32969 L F
.412 .33038 m .4103 .32842 L .41317 .32772 L F
.61854 .33412 m .62003 .33117 L .62153 .33286 L 0 .054 .157 r
F
.61854 .33412 m .61704 .33239 L .62003 .33117 L F
.84272 .32169 m .84455 .31873 L .84584 .32067 L 0 .026 .125 r
F
.84272 .32169 m .84144 .31977 L .84455 .31873 L F
.28018 .32255 m .28114 .31988 L .28298 .32168 L 0 .028 .127 r
F
.28018 .32255 m .27834 .32078 L .28114 .31988 L F
.424 .33235 m .42521 .32912 L .42689 .33135 L 0 .049 .152 r
F
.424 .33235 m .42232 .33014 L .42521 .32912 L F
.24575 .32202 m .24666 .31926 L .24853 .32109 L 0 .027 .126 r
F
.24575 .32202 m .24388 .32019 L .24666 .31926 L F
.16943 .32119 m .17022 .31846 L .17217 .32028 L 0 .025 .124 r
F
.16943 .32119 m .16747 .31938 L .17022 .31846 L F
.68421 .32555 m .68581 .32284 L .68724 .32458 L 0 .034 .135 r
F
.68421 .32555 m .68278 .32383 L .68581 .32284 L F
.20385 .32182 m .20471 .31893 L .20663 .32076 L 0 .026 .125 r
F
.20385 .32182 m .20193 .32 L .20471 .31893 L F
.79337 .32204 m .79512 .31908 L .79644 .32088 L 0 .027 .126 r
F
.79337 .32204 m .79204 .32024 L .79512 .31908 L F
.67674 .32598 m .67832 .3231 L .67975 .32481 L 0 .035 .136 r
F
.67674 .32598 m .6753 .32428 L .67832 .3231 L F
.30713 .3237 m .30813 .32095 L .30995 .32275 L 0 .03 .13 r
F
.30713 .3237 m .30531 .32192 L .30813 .32095 L F
.43601 .33429 m .43723 .331 L .43889 .3335 L 0 .054 .157 r
F
.43601 .33429 m .43434 .33185 L .43723 .331 L F
.51 .44666 m .51122 .46908 L .51288 .46022 L 0 .498 .088 r
F
.51 .44666 m .50835 .45367 L .51122 .46908 L F
.7859 .3225 m .78764 .31957 L .78897 .32139 L 0 .028 .127 r
F
.7859 .3225 m .78456 .32066 L .78764 .31957 L F
.33407 .32482 m .33513 .32192 L .33691 .32392 L 0 .032 .133 r
F
.33407 .32482 m .3323 .32283 L .33513 .32192 L F
.13499 .32068 m .13573 .31786 L .13772 .31968 L 0 .024 .123 r
F
.13499 .32068 m .133 .31887 L .13573 .31786 L F
.80085 .32174 m .80263 .31893 L .80394 .32076 L 0 .026 .125 r
F
.80085 .32174 m .79953 .3199 L .80263 .31893 L F
.21131 .32158 m .21217 .31877 L .21407 .32065 L F
.21131 .32158 m .2094 .31973 L .21217 .31877 L F
.61108 .33485 m .61255 .33182 L .61406 .33359 L 0 .057 .159 r
F
.61108 .33485 m .60957 .33304 L .61255 .33182 L F
.85023 .32162 m .85208 .31872 L .85335 .32064 L 0 .026 .125 r
F
.85023 .32162 m .84895 .31969 L .85208 .31872 L F
.38797 .32701 m .3891 .32443 L .39083 .32626 L 0 .038 .14 r
F
.38797 .32701 m .38624 .32519 L .3891 .32443 L F
.45254 .33869 m .45379 .3354 L .45544 .33782 L 0 .067 .169 r
F
.45254 .33869 m .45089 .33625 L .45379 .3354 L F
.39998 .32895 m .40114 .32596 L .40285 .32809 L 0 .042 .144 r
F
.39998 .32895 m .39827 .32684 L .40114 .32596 L F
.62897 .33147 m .63047 .32844 L .63195 .3301 L 0 .048 .15 r
F
.62897 .33147 m .62748 .32982 L .63047 .32844 L F
.6917 .32548 m .6933 .32253 L .69473 .32441 L 0 .034 .135 r
F
.6917 .32548 m .69027 .32357 L .6933 .32253 L F
.25319 .32198 m .25413 .31901 L .25599 .32093 L 0 .027 .126 r
F
.25319 .32198 m .25133 .32006 L .25413 .31901 L F
.58278 .34168 m .58421 .33841 L .58574 .34004 L 0 .076 .177 r
F
.58278 .34168 m .58125 .34005 L .58421 .33841 L F
.14242 .32059 m .14318 .31778 L .14515 .31965 L 0 .024 .123 r
F
.14242 .32059 m .14045 .31872 L .14318 .31778 L F
.17685 .32124 m .17766 .31844 L .1796 .3203 L 0 .026 .125 r
F
.17685 .32124 m .17491 .31938 L .17766 .31844 L F
.69918 .32518 m .7008 .3223 L .70221 .32412 L 0 .034 .135 r
F
.69918 .32518 m .69776 .32334 L .7008 .3223 L F
.31457 .32373 m .31558 .32108 L .31739 .32291 L 0 .031 .131 r
F
.31457 .32373 m .31276 .32192 L .31558 .32108 L F
.66929 .32684 m .67085 .32385 L .67229 .32556 L 0 .037 .139 r
F
.66929 .32684 m .66784 .32513 L .67085 .32385 L F
.28761 .32271 m .28859 .31993 L .29042 .32184 L 0 .029 .129 r
F
.28761 .32271 m .28579 .3208 L .28859 .31993 L F
.80836 .32169 m .81013 .31866 L .81144 .3206 L 0 .026 .125 r
F
.80836 .32169 m .80704 .31975 L .81013 .31866 L F
.66181 .32731 m .66337 .32446 L .66483 .32622 L 0 .039 .14 r
F
.66181 .32731 m .66036 .32552 L .66337 .32446 L F
.70666 .32484 m .70829 .32204 L .7097 .3238 L 0 .033 .134 r
F
.70666 .32484 m .70525 .32305 L .70829 .32204 L F
.85774 .32153 m .85959 .31857 L .86085 .32045 L 0 .026 .125 r
F
.85774 .32153 m .85647 .31964 L .85959 .31857 L F
.56247 .37607 m .56092 .37424 L .56379 .36568 L 0 .198 .256 r
F
.56379 .36568 m .56223 .36322 L .56514 .35838 L 0 .153 .231 r
F
.56092 .37424 m .56223 .36322 L .56379 .36568 L 0 .195 .254 r
F
.34152 .32485 m .34259 .32199 L .34436 .32385 L 0 .033 .134 r
F
.34152 .32485 m .33974 .32298 L .34259 .32199 L F
.72161 .3241 m .72326 .3212 L .72465 .32294 L 0 .032 .132 r
F
.72161 .3241 m .72022 .32238 L .72326 .3212 L F
.81584 .32142 m .81764 .31851 L .81894 .32041 L 0 .026 .125 r
F
.81584 .32142 m .81453 .3195 L .81764 .31851 L F
.5932 .33883 m .59464 .33547 L .59616 .33718 L 0 .068 .169 r
F
.5932 .33883 m .59168 .33716 L .59464 .33547 L F
.71414 .32454 m .71579 .32182 L .71719 .32354 L 0 .033 .134 r
F
.71414 .32454 m .71274 .32281 L .71579 .32182 L F
.86523 .32123 m .8671 .31837 L .86835 .32021 L 0 .026 .125 r
F
.86523 .32123 m .86397 .31937 L .8671 .31837 L F
.26064 .32185 m .26158 .31909 L .26343 .32098 L 0 .027 .127 r
F
.26064 .32185 m .25879 .31994 L .26158 .31909 L F
.36847 .326 m .36959 .32306 L .37133 .32508 L 0 .036 .137 r
F
.36847 .326 m .36673 .32395 L .36959 .32306 L F
.46907 .34321 m .47034 .34005 L .47197 .3428 L 0 .082 .181 r
F
.46907 .34321 m .46744 .34051 L .47034 .34005 L F
.21873 .32166 m .21962 .31873 L .22151 .32066 L 0 .027 .126 r
F
.21873 .32166 m .21684 .31972 L .21962 .31873 L F
.72909 .32374 m .73076 .32091 L .73215 .3228 L 0 .031 .131 r
F
.72909 .32374 m .7277 .32184 L .73076 .32091 L F
.54872 .43757 m .54725 .45021 L .55015 .44044 L 0 .44 .188 r
F
.54581 .44526 m .54725 .45021 L .54872 .43757 L 0 .471 .138 r
F
.60362 .3358 m .60508 .33256 L .60659 .33442 L 0 .06 .162 r
F
.60362 .3358 m .6021 .33394 L .60508 .33256 L F
.46454 .34099 m .4658 .33795 L .46744 .34051 L 0 .075 .176 r
F
.46454 .34099 m .4629 .33846 L .4658 .33795 L F
.65435 .32793 m .65589 .32484 L .65735 .32666 L 0 .04 .142 r
F
.65435 .32793 m .65288 .32607 L .65589 .32484 L F
.43145 .33272 m .43267 .32941 L .43434 .33185 L 0 .051 .154 r
F
.43145 .33272 m .42978 .33034 L .43267 .32941 L F
.48585 .36068 m .48427 .35512 L .48717 .35556 L 0 .143 .224 r
F
.48427 .35512 m .48556 .35157 L .48717 .35556 L 0 .124 .212 r
F
.48427 .35512 m .48265 .35149 L .48556 .35157 L F
.4736 .34558 m .47488 .34237 L .47651 .34521 L 0 .09 .187 r
F
.4736 .34558 m .47197 .3428 L .47488 .34237 L F
.34898 .32465 m .35006 .32179 L .35183 .32362 L 0 .033 .134 r
F
.34898 .32465 m .34721 .32284 L .35006 .32179 L F
.18428 .32118 m .18512 .31825 L .18705 .32014 L 0 .026 .125 r
F
.18428 .32118 m .18236 .31927 L .18512 .31825 L F
.41944 .33097 m .42063 .32817 L .42232 .33014 L 0 .048 .15 r
F
.41944 .33097 m .41774 .329 L .42063 .32817 L F
.14984 .32061 m .15061 .3178 L .15258 .31967 L 0 .025 .124 r
F
.14984 .32061 m .14788 .31872 L .15061 .3178 L F
.44799 .33699 m .44923 .33384 L .45089 .33625 L 0 .063 .165 r
F
.44799 .33699 m .44634 .33454 L .44923 .33384 L F
.87273 .32105 m .87462 .31824 L .87586 .32005 L 0 .026 .125 r
F
.87273 .32105 m .87148 .31923 L .87462 .31824 L F
.49135 .41552 m .48978 .40813 L .49258 .41894 L 0 .387 .254 r
F
.48978 .40813 m .49103 .41002 L .49258 .41894 L 0 .362 .277 r
F
.56514 .35838 m .56358 .35618 L .5665 .3516 L 0 .126 .213 r
F
.56223 .36322 m .56358 .35618 L .56514 .35838 L 0 .15 .228 r
F
.51907 .4521 m .52037 .47472 L .522 .46177 L 0 .513 .056 r
F
.51907 .4521 m .51744 .46316 L .52037 .47472 L F
.82335 .32131 m .82516 .31848 L .82645 .32033 L 0 .026 .125 r
F
.82335 .32131 m .82205 .31945 L .82516 .31848 L F
.22618 .32155 m .22708 .31862 L .22896 .32051 L 0 .027 .126 r
F
.22618 .32155 m .22429 .31964 L .22708 .31862 L F
.64688 .3286 m .64841 .3255 L .64988 .3273 L 0 .042 .144 r
F
.64688 .3286 m .64541 .3268 L .64841 .3255 L F
.32201 .32385 m .32305 .32089 L .32485 .3228 L 0 .031 .132 r
F
.32201 .32385 m .32022 .32194 L .32305 .32089 L F
.35644 .32447 m .35754 .32158 L .3593 .32349 L 0 .033 .134 r
F
.35644 .32447 m .35468 .32258 L .35754 .32158 L F
.47813 .34814 m .47942 .3448 L .48104 .34786 L 0 .099 .194 r
F
.47813 .34814 m .47651 .34521 L .47942 .3448 L F
.40742 .32928 m .4086 .32631 L .4103 .32842 L 0 .044 .146 r
F
.40742 .32928 m .40572 .32719 L .4086 .32631 L F
.37593 .32598 m .37705 .32308 L .37879 .32495 L 0 .036 .138 r
F
.37593 .32598 m .37419 .32408 L .37705 .32308 L F
.75154 .32287 m .75324 .32002 L .7546 .32179 L 0 .03 .13 r
F
.75154 .32287 m .75018 .32108 L .75324 .32002 L F
.49774 .43317 m .49892 .4465 L .50055 .44827 L 0 .448 .175 r
F
.49774 .43317 m .49612 .4314 L .49892 .4465 L F
.75902 .32248 m .76073 .3196 L .76208 .32137 L 0 .029 .129 r
F
.75902 .32248 m .75767 .32071 L .76073 .3196 L F
.29504 .3229 m .29603 .32011 L .29785 .32201 L 0 .03 .13 r
F
.29504 .3229 m .29322 .32097 L .29603 .32011 L F
.74407 .32334 m .74575 .32031 L .74712 .32215 L 0 .03 .131 r
F
.74407 .32334 m .7427 .32149 L .74575 .32031 L F
.19173 .32107 m .19256 .31828 L .19448 .32016 L 0 .026 .125 r
F
.19173 .32107 m .1898 .31919 L .19256 .31828 L F
.7366 .32377 m .73826 .32078 L .73965 .32266 L 0 .031 .132 r
F
.7366 .32377 m .73521 .32186 L .73826 .32078 L F
.83084 .3211 m .83266 .31825 L .83395 .32005 L 0 .026 .125 r
F
.83084 .3211 m .82956 .31929 L .83266 .31825 L F
.7665 .32214 m .76821 .31916 L .76957 .32103 L 0 .028 .128 r
F
.7665 .32214 m .76515 .32027 L .76821 .31916 L F
.23364 .32131 m .23454 .31841 L .23643 .32026 L 0 .027 .126 r
F
.23364 .32131 m .23175 .31946 L .23454 .31841 L F
.26807 .32197 m .26902 .31916 L .27087 .321 L 0 .028 .128 r
F
.26807 .32197 m .26622 .32011 L .26902 .31916 L F
.3954 .32762 m .39656 .32474 L .39827 .32684 L 0 .04 .142 r
F
.3954 .32762 m .39369 .3255 L .39656 .32474 L F
.12284 .31995 m .12356 .31717 L .12555 .31901 L 0 .024 .123 r
F
.12284 .31995 m .12084 .3181 L .12356 .31717 L F
.15728 .32057 m .15806 .31775 L .16002 .31958 L 0 .025 .124 r
F
.15728 .32057 m .15531 .31873 L .15806 .31775 L F
.83833 .3208 m .84016 .31797 L .84144 .31977 L 0 .026 .125 r
F
.83833 .3208 m .83705 .319 L .84016 .31797 L F
.77399 .32186 m .77571 .31883 L .77706 .32077 L 0 .028 .127 r
F
.77399 .32186 m .77264 .31992 L .77571 .31883 L F
.62153 .33286 m .62301 .32966 L .6245 .33134 L 0 .053 .155 r
F
.62153 .33286 m .62003 .33117 L .62301 .32966 L F
.32947 .32374 m .33052 .32084 L .3323 .32283 L 0 .032 .132 r
F
.32947 .32374 m .32768 .32175 L .33052 .32084 L F
.48742 .36758 m .48585 .36068 L .48875 .36184 L 0 .177 .244 r
F
.48585 .36068 m .48717 .35556 L .48875 .36184 L 0 .143 .224 r
F
.24109 .32112 m .242 .31835 L .24388 .32019 L 0 .027 .126 r
F
.24109 .32112 m .23921 .31928 L .242 .31835 L F
.63942 .32942 m .64094 .3264 L .64242 .32812 L 0 .045 .147 r
F
.63942 .32942 m .63795 .32772 L .64094 .3264 L F
.44344 .33524 m .44468 .33209 L .44634 .33454 L 0 .059 .162 r
F
.44344 .33524 m .44178 .33274 L .44468 .33209 L F
.45999 .33939 m .46125 .33593 L .4629 .33846 L 0 .071 .172 r
F
.45999 .33939 m .45834 .33688 L .46125 .33593 L F
.27553 .32178 m .27649 .31901 L .27834 .32078 L 0 .028 .128 r
F
.27553 .32178 m .27368 .32 L .27649 .31901 L F
.58574 .34004 m .58718 .33695 L .58871 .3386 L 0 .074 .174 r
F
.58574 .34004 m .58421 .33841 L .58718 .33695 L F
.38338 .32595 m .38451 .32336 L .38624 .32519 L 0 .037 .139 r
F
.38338 .32595 m .38165 .32415 L .38451 .32336 L F
.16473 .32038 m .16552 .31756 L .16747 .31938 L 0 .025 .124 r
F
.16473 .32038 m .16277 .31857 L .16552 .31756 L F
.30249 .32292 m .3035 .32004 L .30531 .32192 L 0 .03 .13 r
F
.30249 .32292 m .30067 .32103 L .3035 .32004 L F
.78148 .32168 m .78323 .31878 L .78456 .32066 L 0 .028 .127 r
F
.78148 .32168 m .78014 .31978 L .78323 .31878 L F
.19916 .32107 m .20001 .31817 L .20193 .32 L 0 .027 .126 r
F
.19916 .32107 m .19724 .31924 L .20001 .31817 L F
.67975 .32481 m .68135 .3221 L .68278 .32383 L 0 .035 .136 r
F
.67975 .32481 m .67832 .3231 L .68135 .3221 L F
.84584 .32067 m .84767 .31776 L .84895 .31969 L 0 .026 .125 r
F
.84584 .32067 m .84455 .31873 L .84767 .31776 L F
.79644 .32088 m .79821 .31811 L .79953 .3199 L F
.79644 .32088 m .79512 .31908 L .79821 .31811 L F
.56944 .34868 m .57084 .34438 L .57239 .3462 L 0 .099 .194 r
F
.56944 .34868 m .56789 .34674 L .57084 .34438 L F
.5665 .3516 m .56789 .34674 L .56944 .34868 L 0 .108 .201 r
F
.13027 .31987 m .13101 .31705 L .133 .31887 L 0 .024 .123 r
F
.13027 .31987 m .12828 .31805 L .13101 .31705 L F
.61406 .33359 m .61554 .33066 L .61704 .33239 L 0 .056 .158 r
F
.61406 .33359 m .61255 .33182 L .61554 .33066 L F
.20663 .32076 m .20749 .31789 L .2094 .31973 L 0 .026 .125 r
F
.20663 .32076 m .20471 .31893 L .20749 .31789 L F
.63195 .3301 m .63347 .32724 L .63495 .32891 L 0 .047 .149 r
F
.63195 .3301 m .63047 .32844 L .63347 .32724 L F
.78897 .32139 m .79072 .31842 L .79204 .32024 L 0 .027 .127 r
F
.78897 .32139 m .78764 .31957 L .79072 .31842 L F
.42689 .33135 m .4281 .32809 L .42978 .33034 L 0 .049 .152 r
F
.42689 .33135 m .42521 .32912 L .4281 .32809 L F
.59616 .33718 m .59761 .33375 L .59913 .33552 L 0 .065 .167 r
F
.59616 .33718 m .59464 .33547 L .59761 .33375 L F
.36388 .32477 m .36499 .3219 L .36673 .32395 L 0 .034 .136 r
F
.36388 .32477 m .36214 .32269 L .36499 .3219 L F
.28298 .32168 m .28395 .31897 L .28579 .3208 L 0 .028 .128 r
F
.28298 .32168 m .28114 .31988 L .28395 .31897 L F
.68724 .32458 m .68884 .3218 L .69027 .32357 L 0 .034 .135 r
F
.68724 .32458 m .68581 .32284 L .68884 .3218 L F
.24853 .32109 m .24946 .31821 L .25133 .32006 L 0 .027 .126 r
F
.24853 .32109 m .24666 .31926 L .24946 .31821 L F
.30995 .32275 m .31095 .3201 L .31276 .32192 L 0 .031 .131 r
F
.30995 .32275 m .30813 .32095 L .31095 .3201 L F
.57239 .3462 m .57379 .3421 L .57533 .34382 L 0 .091 .189 r
F
.57239 .3462 m .57084 .34438 L .57379 .3421 L F
.17217 .32028 m .17296 .31755 L .17491 .31938 L 0 .026 .124 r
F
.17217 .32028 m .17022 .31846 L .17296 .31755 L F
.5665 .3516 m .56494 .34947 L .56789 .34674 L 0 .108 .201 r
F
.56358 .35618 m .56494 .34947 L .5665 .3516 L 0 .124 .212 r
F
.13772 .31968 m .13847 .31689 L .14045 .31872 L 0 .024 .123 r
F
.13772 .31968 m .13573 .31786 L .13847 .31689 L F
.80394 .32076 m .80572 .31792 L .80704 .31975 L 0 .026 .125 r
F
.80394 .32076 m .80263 .31893 L .80572 .31792 L F
.41487 .32969 m .41604 .32703 L .41774 .329 L 0 .047 .149 r
F
.41487 .32969 m .41317 .32772 L .41604 .32703 L F
.67229 .32556 m .67386 .32257 L .6753 .32428 L 0 .036 .138 r
F
.67229 .32556 m .67085 .32385 L .67386 .32257 L F
.33691 .32392 m .33797 .321 L .33974 .32298 L 0 .033 .134 r
F
.33691 .32392 m .33513 .32192 L .33797 .321 L F
.53402 .45232 m .53545 .47034 L .53698 .45472 L 0 .507 .068 r
F
.53402 .45232 m .53247 .46721 L .53545 .47034 L F
.55731 .41811 m .55583 .42524 L .55869 .41315 L 0 .375 .265 r
F
.55445 .42984 m .55583 .42524 L .55731 .41811 L 0 .42 .216 r
F
.85335 .32064 m .8552 .31773 L .85647 .31964 L 0 .026 .125 r
F
.85335 .32064 m .85208 .31872 L .8552 .31773 L F
.43889 .3335 m .44012 .33019 L .44178 .33274 L 0 .055 .158 r
F
.43889 .3335 m .43723 .331 L .44012 .33019 L F
.21407 .32065 m .21494 .31781 L .21684 .31972 L 0 .026 .125 r
F
.21407 .32065 m .21217 .31877 L .21494 .31781 L F
.69473 .32441 m .69634 .3215 L .69776 .32334 L 0 .034 .135 r
F
.69473 .32441 m .6933 .32253 L .69634 .3215 L F
.25599 .32093 m .25693 .31804 L .25879 .31994 L 0 .027 .126 r
F
.25599 .32093 m .25413 .31901 L .25693 .31804 L F
.60659 .33442 m .60806 .33118 L .60957 .33304 L 0 .058 .16 r
F
.60659 .33442 m .60508 .33256 L .60806 .33118 L F
.48265 .35149 m .48395 .34758 L .48556 .35157 L 0 .112 .204 r
F
.48265 .35149 m .48104 .34786 L .48395 .34758 L F
.70221 .32412 m .70384 .32125 L .70525 .32305 L 0 .034 .134 r
F
.70221 .32412 m .7008 .3223 L .70384 .32125 L F
.57533 .34382 m .57675 .34024 L .57829 .34194 L 0 .085 .184 r
F
.57533 .34382 m .57379 .3421 L .57675 .34024 L F
.81144 .3206 m .81322 .31758 L .81453 .3195 L 0 .026 .125 r
F
.81144 .3206 m .81013 .31866 L .81322 .31758 L F
.45544 .33782 m .45669 .33447 L .45834 .33688 L 0 .067 .169 r
F
.45544 .33782 m .45379 .3354 L .45669 .33447 L F
.66483 .32622 m .66639 .3234 L .66784 .32513 L 0 .038 .14 r
F
.66483 .32622 m .66337 .32446 L .66639 .3234 L F
.40285 .32809 m .40402 .32504 L .40572 .32719 L 0 .042 .145 r
F
.40285 .32809 m .40114 .32596 L .40402 .32504 L F
.65735 .32666 m .6589 .32373 L .66036 .32552 L 0 .039 .141 r
F
.65735 .32666 m .65589 .32484 L .6589 .32373 L F
.72465 .32294 m .72631 .32008 L .7277 .32184 L 0 .031 .132 r
F
.72465 .32294 m .72326 .3212 L .72631 .32008 L F
.86085 .32045 m .86271 .31749 L .86397 .31937 L 0 .026 .125 r
F
.86085 .32045 m .85959 .31857 L .86271 .31749 L F
.39083 .32626 m .39196 .32367 L .39369 .3255 L 0 .039 .141 r
F
.39083 .32626 m .3891 .32443 L .39196 .32367 L F
.14515 .31965 m .14591 .31684 L .14788 .31872 L 0 .025 .123 r
F
.14515 .31965 m .14318 .31778 L .14591 .31684 L F
.7097 .3238 m .71134 .32107 L .71274 .32281 L 0 .033 .134 r
F
.7097 .3238 m .70829 .32204 L .71134 .32107 L F
.56136 .39564 m .55984 .39774 L .56271 .3877 L 0 .311 .306 r
F
.55984 .39774 m .56117 .38737 L .56271 .3877 L 0 .322 .302 r
F
.1796 .3203 m .18042 .3174 L .18236 .31927 L 0 .026 .125 r
F
.1796 .3203 m .17766 .31844 L .18042 .3174 L F
.34436 .32385 m .34544 .321 L .34721 .32284 L 0 .033 .134 r
F
.34436 .32385 m .34259 .32199 L .34544 .321 L F
.29042 .32184 m .2914 .31908 L .29322 .32097 L 0 .029 .129 r
F
.29042 .32184 m .28859 .31993 L .2914 .31908 L F
.81894 .32041 m .82075 .31755 L .82205 .31945 L 0 .026 .125 r
F
.81894 .32041 m .81764 .31851 L .82075 .31755 L F
.86835 .32021 m .87024 .3174 L .87148 .31923 L F
.86835 .32021 m .8671 .31837 L .87024 .3174 L F
.31739 .32291 m .31841 .3201 L .32022 .32194 L 0 .031 .132 r
F
.31739 .32291 m .31558 .32108 L .31841 .3201 L F
.71719 .32354 m .71883 .32065 L .72022 .32238 L 0 .033 .133 r
F
.71719 .32354 m .71579 .32182 L .71883 .32065 L F
.22151 .32066 m .2224 .31774 L .22429 .31964 L 0 .027 .126 r
F
.22151 .32066 m .21962 .31873 L .2224 .31774 L F
.51453 .45134 m .51579 .47393 L .51744 .46316 L 0 .513 .056 r
F
.51453 .45134 m .51288 .46022 L .51579 .47393 L F
.64988 .3273 m .65141 .32424 L .65288 .32607 L 0 .041 .143 r
F
.64988 .3273 m .64841 .3255 L .65141 .32424 L F
.48947 .40103 m .48792 .39207 L .49076 .39885 L 0 .343 .29 r
F
.48792 .39207 m .48922 .38927 L .49076 .39885 L 0 .313 .306 r
F
.35183 .32362 m .35292 .32073 L .35468 .32258 L 0 .033 .134 r
F
.35183 .32362 m .35006 .32179 L .35292 .32073 L F
.37133 .32508 m .37245 .3221 L .37419 .32408 L 0 .036 .137 r
F
.37133 .32508 m .36959 .32306 L .37245 .3221 L F
.73215 .3228 m .73382 .31997 L .73521 .32186 L 0 .031 .132 r
F
.73215 .3228 m .73076 .32091 L .73382 .31997 L F
.56004 .4058 m .55854 .40966 L .56136 .39564 L 0 .337 .294 r
F
.55854 .40966 m .55984 .39774 L .56136 .39564 L 0 .356 .281 r
F
.6245 .33134 m .626 .32815 L .62748 .32982 L 0 .051 .153 r
F
.6245 .33134 m .62301 .32966 L .626 .32815 L F
.18705 .32014 m .18788 .3173 L .1898 .31919 L 0 .026 .125 r
F
.18705 .32014 m .18512 .31825 L .18788 .3173 L F
.26343 .32098 m .26437 .31823 L .26622 .32011 L 0 .028 .127 r
F
.26343 .32098 m .26158 .31909 L .26437 .31823 L F
.43434 .33185 m .43557 .32849 L .43723 .331 L 0 .052 .154 r
F
.43434 .33185 m .43267 .32941 L .43557 .32849 L F
.11813 .31902 m .11884 .31623 L .12084 .3181 L 0 .024 .122 r
F
.11813 .31902 m .11613 .31715 L .11884 .31623 L F
.74712 .32215 m .74881 .31926 L .75018 .32108 L 0 .03 .13 r
F
.74712 .32215 m .74575 .32031 L .74881 .31926 L F
.15258 .31967 m .15335 .31688 L .15531 .31873 L 0 .025 .124 r
F
.15258 .31967 m .15061 .3178 L .15335 .31688 L F
.22896 .32051 m .22987 .31758 L .23175 .31946 L 0 .027 .126 r
F
.22896 .32051 m .22708 .31862 L .22987 .31758 L F
.32485 .3228 m .3259 .31983 L .32768 .32175 L 0 .031 .132 r
F
.32485 .3228 m .32305 .32089 L .3259 .31983 L F
.82645 .32033 m .82827 .31745 L .82956 .31929 L 0 .026 .126 r
F
.82645 .32033 m .82516 .31848 L .82827 .31745 L F
.76208 .32137 m .7638 .3185 L .76515 .32027 L 0 .029 .128 r
F
.76208 .32137 m .76073 .3196 L .7638 .3185 L F
.7546 .32179 m .75631 .31893 L .75767 .32071 L 0 .029 .129 r
F
.7546 .32179 m .75324 .32002 L .75631 .31893 L F
.58871 .3386 m .59015 .33549 L .59168 .33716 L 0 .071 .172 r
F
.58871 .3386 m .58718 .33695 L .59015 .33549 L F
.59913 .33552 m .60058 .33213 L .6021 .33394 L 0 .062 .164 r
F
.59913 .33552 m .59761 .33375 L .60058 .33213 L F
.3593 .32349 m .36038 .32079 L .36214 .32269 L 0 .033 .134 r
F
.3593 .32349 m .35754 .32158 L .36038 .32079 L F
.37879 .32495 m .37991 .32227 L .38165 .32415 L 0 .037 .138 r
F
.37879 .32495 m .37705 .32308 L .37991 .32227 L F
.73965 .32266 m .74132 .31962 L .7427 .32149 L 0 .031 .131 r
F
.73965 .32266 m .73826 .32078 L .74132 .31962 L F
.42232 .33014 m .42352 .32716 L .42521 .32912 L 0 .048 .151 r
F
.42232 .33014 m .42063 .32817 L .42352 .32716 L F
.76957 .32103 m .77128 .31804 L .77264 .31992 L 0 .028 .127 r
F
.76957 .32103 m .76821 .31916 L .77128 .31804 L F
.64242 .32812 m .64394 .32505 L .64541 .3268 L 0 .043 .146 r
F
.64242 .32812 m .64094 .3264 L .64394 .32505 L F
.83395 .32005 m .83577 .31721 L .83705 .319 L 0 .026 .125 r
F
.83395 .32005 m .83266 .31825 L .83577 .31721 L F
.23643 .32026 m .23733 .31743 L .23921 .31928 L 0 .027 .126 r
F
.23643 .32026 m .23454 .31841 L .23733 .31743 L F
.45089 .33625 m .45213 .33303 L .45379 .3354 L 0 .064 .166 r
F
.45089 .33625 m .44923 .33384 L .45213 .33303 L F
.4103 .32842 m .41147 .3256 L .41317 .32772 L 0 .045 .147 r
F
.4103 .32842 m .4086 .32631 L .41147 .3256 L F
.77706 .32077 m .77879 .31787 L .78014 .31978 L 0 .028 .127 r
F
.77706 .32077 m .77571 .31883 L .77879 .31787 L F
.29785 .32201 m .29886 .31914 L .30067 .32103 L 0 .03 .13 r
F
.29785 .32201 m .29603 .32011 L .29886 .31914 L F
.57829 .34194 m .57971 .33837 L .58125 .34005 L 0 .081 .18 r
F
.57829 .34194 m .57675 .34024 L .57971 .33837 L F
.19448 .32016 m .19532 .31736 L .19724 .31924 L 0 .027 .126 r
F
.19448 .32016 m .19256 .31828 L .19532 .31736 L F
.27087 .321 m .27183 .31819 L .27368 .32 L 0 .028 .128 r
F
.27087 .321 m .26902 .31916 L .27183 .31819 L F
.46744 .34051 m .4687 .33744 L .47034 .34005 L 0 .078 .178 r
F
.46744 .34051 m .4658 .33795 L .4687 .33744 L F
.84144 .31977 m .84328 .31693 L .84455 .31873 L 0 .026 .125 r
F
.84144 .31977 m .84016 .31797 L .84328 .31693 L F
.47197 .3428 m .47325 .33956 L .47488 .34237 L 0 .085 .184 r
F
.47197 .3428 m .47034 .34005 L .47325 .33956 L F
.16002 .31958 m .16081 .31673 L .16277 .31857 L 0 .025 .124 r
F
.16002 .31958 m .15806 .31775 L .16081 .31673 L F
.12555 .31901 m .12628 .31621 L .12828 .31805 L 0 .024 .123 r
F
.12555 .31901 m .12356 .31717 L .12628 .31621 L F
.56092 .37424 m .55934 .37139 L .56223 .36322 L 0 .195 .254 r
F
.56223 .36322 m .56066 .36076 L .56358 .35618 L 0 .15 .228 r
F
.55934 .37139 m .56066 .36076 L .56223 .36322 L 0 .188 .25 r
F
.47651 .34521 m .47779 .34189 L .47942 .3448 L 0 .093 .19 r
F
.47651 .34521 m .47488 .34237 L .47779 .34189 L F
.3323 .32283 m .33336 .31992 L .33513 .32192 L 0 .032 .133 r
F
.3323 .32283 m .33052 .32084 L .33336 .31992 L F
.61704 .33239 m .61853 .32947 L .62003 .33117 L 0 .055 .157 r
F
.61704 .33239 m .61554 .33066 L .61853 .32947 L F
.27834 .32078 m .2793 .31807 L .28114 .31988 L 0 .028 .128 r
F
.27834 .32078 m .27649 .31901 L .2793 .31807 L F
.24388 .32019 m .24479 .31742 L .24666 .31926 L 0 .027 .126 r
F
.24388 .32019 m .242 .31835 L .24479 .31742 L F
.39827 .32684 m .39943 .32385 L .40114 .32596 L 0 .041 .143 r
F
.39827 .32684 m .39656 .32474 L .39943 .32385 L F
.63495 .32891 m .63647 .32603 L .63795 .32772 L 0 .046 .149 r
F
.63495 .32891 m .63347 .32724 L .63647 .32603 L F
.4629 .33846 m .46416 .33538 L .4658 .33795 L 0 .072 .173 r
F
.4629 .33846 m .46125 .33593 L .46416 .33538 L F
.16747 .31938 m .16826 .31664 L .17022 .31846 L 0 .025 .124 r
F
.16747 .31938 m .16552 .31756 L .16826 .31664 L F
.20193 .32 m .20279 .3171 L .20471 .31893 L 0 .026 .125 r
F
.20193 .32 m .20001 .31817 L .20279 .3171 L F
.79204 .32024 m .7938 .31728 L .79512 .31908 L 0 .027 .126 r
F
.79204 .32024 m .79072 .31842 L .7938 .31728 L F
.78456 .32066 m .78631 .31771 L .78764 .31957 L 0 .028 .127 r
F
.78456 .32066 m .78323 .31878 L .78631 .31771 L F
.30531 .32192 m .30632 .31908 L .30813 .32095 L 0 .03 .131 r
F
.30531 .32192 m .3035 .32004 L .30632 .31908 L F
.56117 .38737 m .55962 .38704 L .56247 .37607 L 0 .265 .289 r
F
.55962 .38704 m .56092 .37424 L .56247 .37607 L 0 .271 .291 r
F
.48899 .3745 m .48742 .36758 L .49031 .36971 L 0 .22 .267 r
F
.48742 .36758 m .48875 .36184 L .49031 .36971 L 0 .177 .244 r
F
.49452 .42699 m .49292 .42257 L .49572 .43633 L 0 .43 .202 r
F
.49292 .42257 m .49135 .41552 L .49415 .42785 L 0 .412 .226 r
F
.49135 .41552 m .49258 .41894 L .49415 .42785 L 0 .387 .254 r
F
.68278 .32383 m .68438 .32111 L .68581 .32284 L 0 .035 .136 r
F
.68278 .32383 m .68135 .3221 L .68438 .32111 L F
.79953 .3199 m .80131 .31714 L .80263 .31893 L 0 .027 .126 r
F
.79953 .3199 m .79821 .31811 L .80131 .31714 L F
.84895 .31969 m .8508 .3168 L .85208 .31872 L 0 .026 .125 r
F
.84895 .31969 m .84767 .31776 L .8508 .3168 L F
.133 .31887 m .13375 .31604 L .13573 .31786 L 0 .024 .123 r
F
.133 .31887 m .13101 .31705 L .13375 .31604 L F
.48922 .38927 m .48767 .38029 L .49053 .38491 L 0 .31 .307 r
F
.48767 .38029 m .48899 .3745 L .49053 .38491 L 0 .241 .278 r
F
.6753 .32428 m .67688 .32138 L .67832 .3231 L 0 .035 .137 r
F
.6753 .32428 m .67386 .32257 L .67688 .32138 L F
.2094 .31973 m .21026 .3169 L .21217 .31877 L 0 .026 .125 r
F
.2094 .31973 m .20749 .31789 L .21026 .3169 L F
.42978 .33034 m .431 .32711 L .43267 .32941 L 0 .049 .152 r
F
.42978 .33034 m .4281 .32809 L .431 .32711 L F
.60957 .33304 m .61104 .32996 L .61255 .33182 L 0 .057 .159 r
F
.60957 .33304 m .60806 .33118 L .61104 .32996 L F
.38624 .32519 m .38737 .32259 L .3891 .32443 L 0 .038 .14 r
F
.38624 .32519 m .38451 .32336 L .38737 .32259 L F
.44634 .33454 m .44757 .33143 L .44923 .33384 L 0 .061 .163 r
F
.44634 .33454 m .44468 .33209 L .44757 .33143 L F
.69027 .32357 m .69188 .32074 L .6933 .32253 L 0 .034 .135 r
F
.69027 .32357 m .68884 .3218 L .69188 .32074 L F
.25133 .32006 m .25227 .31716 L .25413 .31901 L 0 .027 .126 r
F
.25133 .32006 m .24946 .31821 L .25227 .31716 L F
.48104 .34786 m .48233 .3444 L .48395 .34758 L 0 .103 .197 r
F
.48104 .34786 m .47942 .3448 L .48233 .3444 L F
.80704 .31975 m .80882 .31683 L .81013 .31866 L 0 .026 .125 r
F
.80704 .31975 m .80572 .31792 L .80882 .31683 L F
.14045 .31872 m .1412 .31593 L .14318 .31778 L 0 .025 .123 r
F
.14045 .31872 m .13847 .31689 L .1412 .31593 L F
.28579 .3208 m .28676 .31809 L .28859 .31993 L 0 .029 .129 r
F
.28579 .3208 m .28395 .31897 L .28676 .31809 L F
.17491 .31938 m .17571 .3166 L .17766 .31844 L 0 .026 .125 r
F
.17491 .31938 m .17296 .31755 L .17571 .3166 L F
.36673 .32395 m .36784 .32104 L .36959 .32306 L 0 .035 .136 r
F
.36673 .32395 m .36499 .3219 L .36784 .32104 L F
.69776 .32334 m .69938 .32047 L .7008 .3223 L 0 .034 .135 r
F
.69776 .32334 m .69634 .3215 L .69938 .32047 L F
.31276 .32192 m .31378 .31925 L .31558 .32108 L 0 .031 .132 r
F
.31276 .32192 m .31095 .3201 L .31378 .31925 L F
.85647 .31964 m .85832 .31666 L .85959 .31857 L 0 .026 .125 r
F
.85647 .31964 m .8552 .31773 L .85832 .31666 L F
.62748 .32982 m .62899 .32678 L .63047 .32844 L 0 .049 .151 r
F
.62748 .32982 m .626 .32815 L .62899 .32678 L F
.56358 .35618 m .56202 .35358 L .56494 .34947 L 0 .124 .212 r
F
.56066 .36076 m .56202 .35358 L .56358 .35618 L 0 .145 .225 r
F
.33974 .32298 m .34082 .32005 L .34259 .32199 L 0 .033 .134 r
F
.33974 .32298 m .33797 .321 L .34082 .32005 L F
.81453 .3195 m .81633 .3166 L .81764 .31851 L 0 .026 .125 r
F
.81453 .3195 m .81322 .31758 L .81633 .3166 L F
.66036 .32552 m .66192 .3227 L .66337 .32446 L 0 .039 .141 r
F
.66036 .32552 m .6589 .32373 L .66192 .3227 L F
.58125 .34005 m .58267 .33671 L .58421 .33841 L 0 .077 .177 r
F
.58125 .34005 m .57971 .33837 L .58267 .33671 L F
.21684 .31972 m .21772 .31683 L .21962 .31873 L 0 .026 .126 r
F
.21684 .31972 m .21494 .31781 L .21772 .31683 L F
.70525 .32305 m .70688 .32025 L .70829 .32204 L 0 .033 .134 r
F
.70525 .32305 m .70384 .32125 L .70688 .32025 L F
.66784 .32513 m .6694 .32213 L .67085 .32385 L 0 .038 .139 r
F
.66784 .32513 m .66639 .3234 L .6694 .32213 L F
.25879 .31994 m .25972 .31719 L .26158 .31909 L 0 .027 .126 r
F
.25879 .31994 m .25693 .31804 L .25972 .31719 L F
.7277 .32184 m .72937 .31912 L .73076 .32091 L 0 .031 .132 r
F
.7277 .32184 m .72631 .32008 L .72937 .31912 L F
.86397 .31937 m .86584 .3165 L .8671 .31837 L 0 .026 .125 r
F
.86397 .31937 m .86271 .31749 L .86584 .3165 L F
.6021 .33394 m .60356 .33071 L .60508 .33256 L 0 .06 .162 r
F
.6021 .33394 m .60058 .33213 L .60356 .33071 L F
.65288 .32607 m .65442 .32297 L .65589 .32484 L 0 .04 .142 r
F
.65288 .32607 m .65141 .32424 L .65442 .32297 L F
.45834 .33688 m .4596 .33354 L .46125 .33593 L 0 .068 .169 r
F
.45834 .33688 m .45669 .33447 L .4596 .33354 L F
.48875 .36184 m .48717 .35556 L .49008 .35591 L 0 .155 .232 r
F
.48717 .35556 m .48848 .35147 L .49008 .35591 L 0 .131 .217 r
F
.48717 .35556 m .48556 .35157 L .48848 .35147 L F
.41774 .329 m .41893 .3262 L .42063 .32817 L 0 .048 .15 r
F
.41774 .329 m .41604 .32703 L .41893 .3262 L F
.44178 .33274 m .44302 .32954 L .44468 .33209 L 0 .056 .159 r
F
.44178 .33274 m .44012 .33019 L .44302 .32954 L F
.72022 .32238 m .72187 .31946 L .72326 .3212 L 0 .032 .133 r
F
.72022 .32238 m .71883 .32065 L .72187 .31946 L F
.18236 .31927 m .18319 .31637 L .18512 .31825 L 0 .026 .125 r
F
.18236 .31927 m .18042 .3174 L .18319 .31637 L F
.71274 .32281 m .71439 .3201 L .71579 .32182 L 0 .033 .134 r
F
.71274 .32281 m .71134 .32107 L .71439 .3201 L F
.40572 .32719 m .4069 .32413 L .4086 .32631 L 0 .043 .145 r
F
.40572 .32719 m .40402 .32504 L .4069 .32413 L F
.34721 .32284 m .34829 .31995 L .35006 .32179 L 0 .033 .134 r
F
.34721 .32284 m .34544 .321 L .34829 .31995 L F
.59168 .33716 m .59312 .33374 L .59464 .33547 L 0 .069 .17 r
F
.59168 .33716 m .59015 .33549 L .59312 .33374 L F
.14788 .31872 m .14864 .31593 L .15061 .3178 L 0 .025 .124 r
F
.14788 .31872 m .14591 .31684 L .14864 .31593 L F
.87148 .31923 m .87338 .31644 L .87462 .31824 L 0 .026 .125 r
F
.87148 .31923 m .87024 .3174 L .87338 .31644 L F
.22429 .31964 m .22519 .31673 L .22708 .31862 L 0 .027 .126 r
F
.22429 .31964 m .2224 .31774 L .22519 .31673 L F
.55304 .43068 m .55157 .44164 L .55445 .42984 L 0 .42 .216 r
F
.55015 .44044 m .55157 .44164 L .55304 .43068 L 0 .459 .158 r
F
.82205 .31945 m .82386 .3166 L .82516 .31848 L 0 .026 .126 r
F
.82205 .31945 m .82075 .31755 L .82386 .3166 L F
.32022 .32194 m .32126 .31904 L .32305 .32089 L 0 .031 .132 r
F
.32022 .32194 m .31841 .3201 L .32126 .31904 L F
.35468 .32258 m .35577 .31972 L .35754 .32158 L 0 .033 .134 r
F
.35468 .32258 m .35292 .32073 L .35577 .31972 L F
.39369 .3255 m .39483 .32292 L .39656 .32474 L 0 .04 .142 r
F
.39369 .3255 m .39196 .32367 L .39483 .32292 L F
.37419 .32408 m .37531 .32114 L .37705 .32308 L 0 .036 .137 r
F
.37419 .32408 m .37245 .3221 L .37531 .32114 L F
.29322 .32097 m .29421 .31822 L .29603 .32011 L 0 .03 .13 r
F
.29322 .32097 m .2914 .31908 L .29421 .31822 L F
.49612 .4314 m .49732 .44141 L .49892 .4465 L 0 .442 .185 r
F
.49612 .4314 m .49452 .42699 L .49732 .44141 L F
.64541 .3268 m .64694 .32371 L .64841 .3255 L 0 .042 .144 r
F
.64541 .3268 m .64394 .32505 L .64694 .32371 L F
.73521 .32186 m .73688 .3189 L .73826 .32078 L 0 .031 .132 r
F
.73521 .32186 m .73382 .31997 L .73688 .3189 L F
.1898 .31919 m .19063 .31639 L .19256 .31828 L 0 .026 .125 r
F
.1898 .31919 m .18788 .3173 L .19063 .31639 L F
.7427 .32149 m .74437 .31847 L .74575 .32031 L 0 .03 .131 r
F
.7427 .32149 m .74132 .31962 L .74437 .31847 L F
.75018 .32108 m .75188 .31822 L .75324 .32002 L 0 .03 .13 r
F
.75018 .32108 m .74881 .31926 L .75188 .31822 L F
.76515 .32027 m .76686 .31737 L .76821 .31916 L 0 .028 .128 r
F
.76515 .32027 m .7638 .3185 L .76686 .31737 L F
.23175 .31946 m .23266 .31653 L .23454 .31841 L 0 .027 .126 r
F
.23175 .31946 m .22987 .31758 L .23266 .31653 L F
.75767 .32071 m .75937 .31783 L .76073 .3196 L 0 .029 .129 r
F
.75767 .32071 m .75631 .31893 L .75937 .31783 L F
.32768 .32175 m .32873 .31889 L .33052 .32084 L 0 .031 .132 r
F
.32768 .32175 m .3259 .31983 L .32873 .31889 L F
.26622 .32011 m .26717 .31731 L .26902 .31916 L 0 .028 .128 r
F
.26622 .32011 m .26437 .31823 L .26717 .31731 L F
.82956 .31929 m .83138 .31643 L .83266 .31825 L 0 .026 .125 r
F
.82956 .31929 m .82827 .31745 L .83138 .31643 L F
.77264 .31992 m .77436 .31695 L .77571 .31883 L 0 .028 .127 r
F
.77264 .31992 m .77128 .31804 L .77436 .31695 L F
.12084 .3181 m .12156 .31532 L .12356 .31717 L 0 .024 .123 r
F
.12084 .3181 m .11884 .31623 L .12156 .31532 L F
.15531 .31873 m .15609 .31591 L .15806 .31775 L 0 .025 .124 r
F
.15531 .31873 m .15335 .31688 L .15609 .31591 L F
.42521 .32912 m .42641 .32614 L .4281 .32809 L 0 .048 .151 r
F
.42521 .32912 m .42352 .32716 L .42641 .32614 L F
.43723 .331 m .43846 .32763 L .44012 .33019 L 0 .052 .155 r
F
.43723 .331 m .43557 .32849 L .43846 .32763 L F
.83705 .319 m .83889 .31618 L .84016 .31797 L 0 .026 .125 r
F
.83705 .319 m .83577 .31721 L .83889 .31618 L F
.23921 .31928 m .24012 .31651 L .242 .31835 L 0 .027 .126 r
F
.23921 .31928 m .23733 .31743 L .24012 .31651 L F
.55869 .41315 m .5572 .41853 L .56004 .4058 L 0 .361 .277 r
F
.55583 .42524 m .5572 .41853 L .55869 .41315 L 0 .408 .231 r
F
.62003 .33117 m .62152 .32798 L .62301 .32966 L 0 .053 .156 r
F
.62003 .33117 m .61853 .32947 L .62152 .32798 L F
.56789 .34674 m .56929 .34254 L .57084 .34438 L 0 .099 .194 r
F
.56789 .34674 m .56633 .34477 L .56929 .34254 L F
.56494 .34947 m .56633 .34477 L .56789 .34674 L 0 .107 .2 r
F
.84455 .31873 m .8464 .31596 L .84767 .31776 L 0 .026 .125 r
F
.84455 .31873 m .84328 .31693 L .8464 .31596 L F
.78014 .31978 m .78188 .3169 L .78323 .31878 L 0 .028 .127 r
F
.78014 .31978 m .77879 .31787 L .78188 .3169 L F
.56494 .34947 m .56338 .3473 L .56633 .34477 L 0 .107 .2 r
F
.56202 .35358 m .56338 .3473 L .56494 .34947 L 0 .12 .209 r
F
.30067 .32103 m .30168 .31815 L .3035 .32004 L 0 .03 .13 r
F
.30067 .32103 m .29886 .31914 L .30168 .31815 L F
.38165 .32415 m .38277 .32148 L .38451 .32336 L 0 .037 .139 r
F
.38165 .32415 m .37991 .32227 L .38277 .32148 L F
.36214 .32269 m .36323 .31999 L .36499 .3219 L 0 .034 .135 r
F
.36214 .32269 m .36038 .32079 L .36323 .31999 L F
.27368 .32 m .27464 .31721 L .27649 .31901 L 0 .028 .128 r
F
.27368 .32 m .27183 .31819 L .27464 .31721 L F
.16277 .31857 m .16356 .31572 L .16552 .31756 L 0 .025 .124 r
F
.16277 .31857 m .16081 .31673 L .16356 .31572 L F
.45379 .3354 m .45504 .33215 L .45669 .33447 L 0 .065 .167 r
F
.45379 .3354 m .45213 .33303 L .45504 .33215 L F
.63795 .32772 m .63946 .32468 L .64094 .3264 L 0 .045 .148 r
F
.63795 .32772 m .63647 .32603 L .63946 .32468 L F
.19724 .31924 m .19809 .3163 L .20001 .31817 L 0 .027 .126 r
F
.19724 .31924 m .19532 .31736 L .19809 .3163 L F
.49452 .42699 m .49572 .43633 L .49732 .44141 L 0 .43 .202 r
F
.79512 .31908 m .7969 .31631 L .79821 .31811 L 0 .027 .126 r
F
.79512 .31908 m .7938 .31728 L .7969 .31631 L F
.12828 .31805 m .12902 .31522 L .13101 .31705 L 0 .025 .123 r
F
.12828 .31805 m .12628 .31621 L .12902 .31522 L F
.58421 .33841 m .58565 .33521 L .58718 .33695 L 0 .074 .175 r
F
.58421 .33841 m .58267 .33671 L .58565 .33521 L F
.20471 .31893 m .20557 .31605 L .20749 .31789 L 0 .026 .125 r
F
.20471 .31893 m .20279 .3171 L .20557 .31605 L F
.61255 .33182 m .61404 .32879 L .61554 .33066 L 0 .056 .158 r
F
.61255 .33182 m .61104 .32996 L .61404 .32879 L F
.67832 .3231 m .67991 .32038 L .68135 .3221 L 0 .035 .136 r
F
.67832 .3231 m .67688 .32138 L .67991 .32038 L F
.78764 .31957 m .78939 .31658 L .79072 .31842 L 0 .027 .127 r
F
.78764 .31957 m .78631 .31771 L .78939 .31658 L F
.48556 .35157 m .48687 .34702 L .48848 .35147 L 0 .117 .207 r
F
.48556 .35157 m .48395 .34758 L .48687 .34702 L F
.41317 .32772 m .41435 .3249 L .41604 .32703 L 0 .046 .148 r
F
.41317 .32772 m .41147 .3256 L .41435 .3249 L F
.33513 .32192 m .3362 .31901 L .33797 .321 L 0 .032 .133 r
F
.33513 .32192 m .33336 .31992 L .3362 .31901 L F
.5572 .41853 m .55854 .40966 L .56004 .4058 L 0 .387 .254 r
F
.28114 .31988 m .28211 .31714 L .28395 .31897 L 0 .029 .128 r
F
.28114 .31988 m .2793 .31807 L .28211 .31714 L F
.24666 .31926 m .24759 .31636 L .24946 .31821 L 0 .027 .126 r
F
.24666 .31926 m .24479 .31742 L .24759 .31636 L F
.57084 .34438 m .57224 .34037 L .57379 .3421 L 0 .092 .189 r
F
.57084 .34438 m .56929 .34254 L .57224 .34037 L F
.59464 .33547 m .59609 .33198 L .59761 .33375 L 0 .065 .167 r
F
.59464 .33547 m .59312 .33374 L .59609 .33198 L F
.30813 .32095 m .30914 .31823 L .31095 .3201 L 0 .031 .131 r
F
.30813 .32095 m .30632 .31908 L .30914 .31823 L F
.17022 .31846 m .17101 .31572 L .17296 .31755 L 0 .026 .125 r
F
.17022 .31846 m .16826 .31664 L .17101 .31572 L F
.63047 .32844 m .63199 .32555 L .63347 .32724 L 0 .048 .15 r
F
.63047 .32844 m .62899 .32678 L .63199 .32555 L F
.13573 .31786 m .13648 .31506 L .13847 .31689 L 0 .025 .123 r
F
.13573 .31786 m .13375 .31604 L .13648 .31506 L F
.68581 .32284 m .68741 .32004 L .68884 .3218 L 0 .035 .136 r
F
.68581 .32284 m .68438 .32111 L .68741 .32004 L F
.40114 .32596 m .40231 .32291 L .40402 .32504 L 0 .041 .143 r
F
.40114 .32596 m .39943 .32385 L .40231 .32291 L F
.80263 .31893 m .80441 .31614 L .80572 .31792 L 0 .027 .126 r
F
.80263 .31893 m .80131 .31714 L .80441 .31614 L F
.85208 .31872 m .85393 .31582 L .8552 .31773 L 0 .026 .125 r
F
.85208 .31872 m .8508 .3168 L .85393 .31582 L F
.21217 .31877 m .21304 .31591 L .21494 .31781 L F
.21217 .31877 m .21026 .3169 L .21304 .31591 L F
.6933 .32253 m .69491 .31968 L .69634 .3215 L 0 .034 .135 r
F
.6933 .32253 m .69188 .32074 L .69491 .31968 L F
.25413 .31901 m .25507 .31617 L .25693 .31804 L 0 .027 .126 r
F
.25413 .31901 m .25227 .31716 L .25507 .31617 L F
.43267 .32941 m .43389 .32614 L .43557 .32849 L 0 .05 .152 r
F
.43267 .32941 m .431 .32711 L .43389 .32614 L F
.49053 .38491 m .48899 .3745 L .49188 .37759 L 0 .284 .297 r
F
.48899 .3745 m .49031 .36971 L .49188 .37759 L 0 .22 .267 r
F
.60508 .33256 m .60654 .32928 L .60806 .33118 L 0 .058 .16 r
F
.60508 .33256 m .60356 .33071 L .60654 .32928 L F
.49031 .36971 m .48875 .36184 L .49165 .36297 L 0 .196 .255 r
F
.48875 .36184 m .49008 .35591 L .49165 .36297 L 0 .155 .232 r
F
.67085 .32385 m .67242 .32085 L .67386 .32257 L 0 .037 .138 r
F
.67085 .32385 m .6694 .32213 L .67242 .32085 L F
.81013 .31866 m .81191 .31575 L .81322 .31758 L 0 .026 .125 r
F
.81013 .31866 m .80882 .31683 L .81191 .31575 L F
.47034 .34005 m .47162 .33692 L .47325 .33956 L 0 .08 .18 r
F
.47034 .34005 m .4687 .33744 L .47162 .33692 L F
.47488 .34237 m .47616 .33903 L .47779 .34189 L 0 .088 .186 r
F
.47488 .34237 m .47325 .33956 L .47616 .33903 L F
.49292 .42257 m .49415 .42785 L .49572 .43633 L 0 .412 .226 r
F
.7008 .3223 m .70242 .31944 L .70384 .32125 L 0 .034 .135 r
F
.7008 .3223 m .69938 .32047 L .70242 .31944 L F
.85959 .31857 m .86144 .31559 L .86271 .31749 L 0 .026 .125 r
F
.85959 .31857 m .85832 .31666 L .86144 .31559 L F
.14318 .31778 m .14394 .31497 L .14591 .31684 L 0 .025 .123 r
F
.14318 .31778 m .1412 .31593 L .14394 .31497 L F
.65589 .32484 m .65743 .32184 L .6589 .32373 L 0 .039 .141 r
F
.65589 .32484 m .65442 .32297 L .65743 .32184 L F
.3891 .32443 m .39023 .32185 L .39196 .32367 L F
.3891 .32443 m .38737 .32259 L .39023 .32185 L F
.4658 .33795 m .46706 .33483 L .4687 .33744 L 0 .074 .175 r
F
.4658 .33795 m .46416 .33538 L .46706 .33483 L F
.57379 .3421 m .5752 .33852 L .57675 .34024 L 0 .086 .185 r
F
.57379 .3421 m .57224 .34037 L .5752 .33852 L F
.47942 .3448 m .48071 .34142 L .48233 .3444 L 0 .096 .192 r
F
.47942 .3448 m .47779 .34189 L .48071 .34142 L F
.17766 .31844 m .17848 .31554 L .18042 .3174 L 0 .026 .125 r
F
.17766 .31844 m .17571 .3166 L .17848 .31554 L F
.66337 .32446 m .66494 .32167 L .66639 .3234 L 0 .039 .141 r
F
.66337 .32446 m .66192 .3227 L .66494 .32167 L F
.34259 .32199 m .34366 .31909 L .34544 .321 L 0 .033 .134 r
F
.34259 .32199 m .34082 .32005 L .34366 .31909 L F
.44923 .33384 m .45047 .33067 L .45213 .33303 L 0 .062 .164 r
F
.44923 .33384 m .44757 .33143 L .45047 .33067 L F
.28859 .31993 m .28957 .31723 L .2914 .31908 L 0 .029 .129 r
F
.28859 .31993 m .28676 .31809 L .28957 .31723 L F
.36959 .32306 m .3707 .32012 L .37245 .3221 L 0 .035 .137 r
F
.36959 .32306 m .36784 .32104 L .3707 .32012 L F
.72326 .3212 m .72492 .31832 L .72631 .32008 L 0 .032 .132 r
F
.72326 .3212 m .72187 .31946 L .72492 .31832 L F
.81764 .31851 m .81944 .31566 L .82075 .31755 L 0 .026 .125 r
F
.81764 .31851 m .81633 .3166 L .81944 .31566 L F
.70829 .32204 m .70993 .31931 L .71134 .32107 L 0 .034 .135 r
F
.70829 .32204 m .70688 .32025 L .70993 .31931 L F
.21962 .31873 m .22051 .31583 L .2224 .31774 L 0 .027 .126 r
F
.21962 .31873 m .21772 .31683 L .22051 .31583 L F
.8671 .31837 m .86898 .31555 L .87024 .3174 L 0 .026 .125 r
F
.8671 .31837 m .86584 .3165 L .86898 .31555 L F
.31558 .32108 m .31661 .31826 L .31841 .3201 L 0 .032 .132 r
F
.31558 .32108 m .31378 .31925 L .31661 .31826 L F
.54581 .44526 m .54433 .45944 L .54725 .45021 L 0 .471 .138 r
F
.54287 .44952 m .54433 .45944 L .54581 .44526 L 0 .493 .097 r
F
.55934 .37139 m .55777 .36854 L .56066 .36076 L 0 .188 .25 r
F
.56066 .36076 m .55909 .35771 L .56202 .35358 L 0 .145 .225 r
F
.55777 .36854 m .55909 .35771 L .56066 .36076 L 0 .179 .245 r
F
.73076 .32091 m .73243 .31816 L .73382 .31997 L 0 .031 .132 r
F
.73076 .32091 m .72937 .31912 L .73243 .31816 L F
.64841 .3255 m .64994 .3224 L .65141 .32424 L 0 .041 .143 r
F
.64841 .3255 m .64694 .32371 L .64994 .3224 L F
.18512 .31825 m .18595 .3154 L .18788 .3173 L 0 .026 .125 r
F
.18512 .31825 m .18319 .31637 L .18595 .3154 L F
.26158 .31909 m .26251 .31634 L .26437 .31823 L 0 .028 .127 r
F
.26158 .31909 m .25972 .31719 L .26251 .31634 L F
.35006 .32179 m .35115 .31888 L .35292 .32073 L 0 .033 .134 r
F
.35006 .32179 m .34829 .31995 L .35115 .31888 L F
.46125 .33593 m .46251 .33295 L .46416 .33538 L 0 .069 .17 r
F
.46125 .33593 m .4596 .33354 L .46251 .33295 L F
.71579 .32182 m .71743 .31892 L .71883 .32065 L 0 .033 .134 r
F
.71579 .32182 m .71439 .3201 L .71743 .31892 L F
.50384 .4452 m .50504 .46243 L .50669 .46017 L 0 .493 .097 r
F
.50384 .4452 m .5022 .44673 L .50504 .46243 L F
.11613 .31715 m .11684 .31436 L .11884 .31623 L 0 .024 .122 r
F
.11613 .31715 m .11413 .31528 L .11684 .31436 L F
.32305 .32089 m .3241 .31797 L .3259 .31983 L 0 .031 .132 r
F
.32305 .32089 m .32126 .31904 L .3241 .31797 L F
.42063 .32817 m .42182 .32519 L .42352 .32716 L 0 .048 .15 r
F
.42063 .32817 m .41893 .3262 L .42182 .32519 L F
.22708 .31862 m .22798 .31569 L .22987 .31758 L 0 .027 .126 r
F
.22708 .31862 m .22519 .31673 L .22798 .31569 L F
.4086 .32631 m .40977 .32341 L .41147 .3256 L 0 .044 .146 r
F
.4086 .32631 m .4069 .32413 L .40977 .32341 L F
.15061 .3178 m .15138 .31501 L .15335 .31688 L 0 .025 .124 r
F
.15061 .3178 m .14864 .31593 L .15138 .31501 L F
.74575 .32031 m .74744 .31744 L .74881 .31926 L 0 .03 .13 r
F
.74575 .32031 m .74437 .31847 L .74744 .31744 L F
.62301 .32966 m .62451 .32648 L .626 .32815 L 0 .051 .154 r
F
.62301 .32966 m .62152 .32798 L .62451 .32648 L F
.35754 .32158 m .35862 .31891 L .36038 .32079 L 0 .033 .134 r
F
.35754 .32158 m .35577 .31972 L .35862 .31891 L F
.82516 .31848 m .82697 .31559 L .82827 .31745 L 0 .027 .126 r
F
.82516 .31848 m .82386 .3166 L .82697 .31559 L F
.73826 .32078 m .73993 .31775 L .74132 .31962 L 0 .031 .131 r
F
.73826 .32078 m .73688 .3189 L .73993 .31775 L F
.52654 .45679 m .52792 .48047 L .5295 .4641 L 0 .535 .009 r
F
.52654 .45679 m .52495 .47143 L .52792 .48047 L F
.48395 .34758 m .48526 .34364 L .48687 .34702 L 0 .105 .199 r
F
.48395 .34758 m .48233 .3444 L .48526 .34364 L F
.37705 .32308 m .37817 .32033 L .37991 .32227 L 0 .036 .138 r
F
.37705 .32308 m .37531 .32114 L .37817 .32033 L F
.76821 .31916 m .76994 .31624 L .77128 .31804 L 0 .028 .127 r
F
.76821 .31916 m .76686 .31737 L .76994 .31624 L F
.75324 .32002 m .75494 .31715 L .75631 .31893 L 0 .03 .13 r
F
.75324 .32002 m .75188 .31822 L .75494 .31715 L F
.76073 .3196 m .76244 .31672 L .7638 .3185 L 0 .029 .129 r
F
.76073 .3196 m .75937 .31783 L .76244 .31672 L F
.44468 .33209 m .44591 .32889 L .44757 .33143 L 0 .058 .16 r
F
.44468 .33209 m .44302 .32954 L .44591 .32889 L F
.59761 .33375 m .59906 .33031 L .60058 .33213 L 0 .062 .164 r
F
.59761 .33375 m .59609 .33198 L .59906 .33031 L F
.23454 .31841 m .23545 .31557 L .23733 .31743 L 0 .027 .126 r
F
.23454 .31841 m .23266 .31653 L .23545 .31557 L F
.77571 .31883 m .77745 .31599 L .77879 .31787 L 0 .027 .127 r
F
.77571 .31883 m .77436 .31695 L .77745 .31599 L F
.29603 .32011 m .29703 .31724 L .29886 .31914 L 0 .03 .13 r
F
.29603 .32011 m .29421 .31822 L .29703 .31724 L F
.83266 .31825 m .83449 .3154 L .83577 .31721 L 0 .026 .125 r
F
.83266 .31825 m .83138 .31643 L .83449 .3154 L F
.58718 .33695 m .58862 .33372 L .59015 .33549 L 0 .072 .173 r
F
.58718 .33695 m .58565 .33521 L .58862 .33372 L F
.19256 .31828 m .19339 .31548 L .19532 .31736 L 0 .027 .126 r
F
.19256 .31828 m .19063 .31639 L .19339 .31548 L F
.56202 .35358 m .56045 .35094 L .56338 .3473 L 0 .12 .209 r
F
.55909 .35771 m .56045 .35094 L .56202 .35358 L 0 .138 .221 r
F
.39656 .32474 m .39771 .32201 L .39943 .32385 L 0 .041 .143 r
F
.39656 .32474 m .39483 .32292 L .39771 .32201 L F
.64094 .3264 m .64246 .3233 L .64394 .32505 L 0 .044 .146 r
F
.64094 .3264 m .63946 .32468 L .64246 .3233 L F
.26902 .31916 m .26998 .31636 L .27183 .31819 L 0 .028 .128 r
F
.26902 .31916 m .26717 .31731 L .26998 .31636 L F
.4281 .32809 m .42931 .32514 L .431 .32711 L 0 .048 .151 r
F
.4281 .32809 m .42641 .32614 L .42931 .32514 L F
.33052 .32084 m .33157 .31795 L .33336 .31992 L 0 .032 .132 r
F
.33052 .32084 m .32873 .31889 L .33157 .31795 L F
.15806 .31775 m .15884 .31489 L .16081 .31673 L 0 .026 .124 r
F
.15806 .31775 m .15609 .31591 L .15884 .31489 L F
.84016 .31797 m .84201 .31514 L .84328 .31693 L 0 .026 .125 r
F
.84016 .31797 m .83889 .31618 L .84201 .31514 L F
.12356 .31717 m .12429 .31437 L .12628 .31621 L 0 .025 .123 r
F
.12356 .31717 m .12156 .31532 L .12429 .31437 L F
.57675 .34024 m .57817 .33667 L .57971 .33837 L 0 .082 .181 r
F
.57675 .34024 m .5752 .33852 L .57817 .33667 L F
.242 .31835 m .24291 .31558 L .24479 .31742 L 0 .027 .126 r
F
.242 .31835 m .24012 .31651 L .24291 .31558 L F
.44012 .33019 m .44136 .32699 L .44302 .32954 L 0 .054 .156 r
F
.44012 .33019 m .43846 .32763 L .44136 .32699 L F
.78323 .31878 m .78497 .31585 L .78631 .31771 L 0 .028 .127 r
F
.78323 .31878 m .78188 .3169 L .78497 .31585 L F
.55962 .38704 m .55806 .38522 L .56092 .37424 L 0 .271 .291 r
F
.55806 .38522 m .55934 .37139 L .56092 .37424 L 0 .265 .289 r
F
.49103 .41002 m .48947 .40103 L .49231 .40951 L 0 .376 .265 r
F
.48947 .40103 m .49076 .39885 L .49231 .40951 L 0 .343 .29 r
F
.3035 .32004 m .30451 .31719 L .30632 .31908 L 0 .03 .131 r
F
.3035 .32004 m .30168 .31815 L .30451 .31719 L F
.20001 .31817 m .20087 .31525 L .20279 .3171 L 0 .026 .126 r
F
.20001 .31817 m .19809 .3163 L .20087 .31525 L F
.27649 .31901 m .27745 .31627 L .2793 .31807 L 0 .028 .128 r
F
.27649 .31901 m .27464 .31721 L .27745 .31627 L F
.84767 .31776 m .84953 .315 L .8508 .3168 L 0 .026 .125 r
F
.84767 .31776 m .8464 .31596 L .84953 .315 L F
.16552 .31756 m .16631 .3148 L .16826 .31664 L 0 .026 .124 r
F
.16552 .31756 m .16356 .31572 L .16631 .3148 L F
.61554 .33066 m .61703 .32761 L .61853 .32947 L 0 .055 .158 r
F
.61554 .33066 m .61404 .32879 L .61703 .32761 L F
.79072 .31842 m .79247 .31545 L .7938 .31728 L 0 .027 .126 r
F
.79072 .31842 m .78939 .31658 L .79247 .31545 L F
.45669 .33447 m .45795 .33127 L .4596 .33354 L 0 .066 .167 r
F
.45669 .33447 m .45504 .33215 L .45795 .33127 L F
.13101 .31705 m .13175 .31422 L .13375 .31604 L 0 .025 .123 r
F
.13101 .31705 m .12902 .31522 L .13175 .31422 L F
.63347 .32724 m .63499 .32432 L .63647 .32603 L 0 .047 .149 r
F
.63347 .32724 m .63199 .32555 L .63499 .32432 L F
.60806 .33118 m .60953 .32801 L .61104 .32996 L 0 .057 .159 r
F
.60806 .33118 m .60654 .32928 L .60953 .32801 L F
.20749 .31789 m .20835 .31504 L .21026 .3169 L 0 .026 .125 r
F
.20749 .31789 m .20557 .31605 L .20835 .31504 L F
.79821 .31811 m .8 .31535 L .80131 .31714 L 0 .027 .126 r
F
.79821 .31811 m .7969 .31631 L .8 .31535 L F
.68135 .3221 m .68295 .31937 L .68438 .32111 L 0 .035 .136 r
F
.68135 .3221 m .67991 .32038 L .68295 .31937 L F
.36499 .3219 m .36609 .31913 L .36784 .32104 L F
.36499 .3219 m .36323 .31999 L .36609 .31913 L F
.38451 .32336 m .38563 .3207 L .38737 .32259 L 0 .038 .14 r
F
.38451 .32336 m .38277 .32148 L .38563 .3207 L F
.67386 .32257 m .67544 .31967 L .67688 .32138 L 0 .036 .137 r
F
.67386 .32257 m .67242 .32085 L .67544 .31967 L F
.24946 .31821 m .25039 .31531 L .25227 .31716 L 0 .027 .126 r
F
.24946 .31821 m .24759 .31636 L .25039 .31531 L F
.68884 .3218 m .69045 .31895 L .69188 .32074 L 0 .035 .136 r
F
.68884 .3218 m .68741 .32004 L .69045 .31895 L F
.33797 .321 m .33904 .3181 L .34082 .32005 L 0 .033 .133 r
F
.33797 .321 m .3362 .31901 L .33904 .3181 L F
.80572 .31792 m .80751 .31505 L .80882 .31683 L 0 .027 .126 r
F
.80572 .31792 m .80441 .31614 L .80751 .31505 L F
.13847 .31689 m .13922 .31408 L .1412 .31593 L 0 .025 .123 r
F
.13847 .31689 m .13648 .31506 L .13922 .31408 L F
.28395 .31897 m .28492 .31624 L .28676 .31809 L 0 .029 .129 r
F
.28395 .31897 m .28211 .31714 L .28492 .31624 L F
.8552 .31773 m .85705 .31475 L .85832 .31666 L 0 .026 .125 r
F
.8552 .31773 m .85393 .31582 L .85705 .31475 L F
.69634 .3215 m .69795 .31862 L .69938 .32047 L 0 .034 .135 r
F
.69634 .3215 m .69491 .31968 L .69795 .31862 L F
.17296 .31755 m .17376 .31476 L .17571 .3166 L 0 .026 .125 r
F
.17296 .31755 m .17101 .31572 L .17376 .31476 L F
.40402 .32504 m .40519 .32198 L .4069 .32413 L 0 .042 .144 r
F
.40402 .32504 m .40231 .32291 L .40519 .32198 L F
.81322 .31758 m .81502 .31476 L .81633 .3166 L 0 .026 .125 r
F
.81322 .31758 m .81191 .31575 L .81502 .31476 L F
.55984 .39774 m .5583 .39791 L .56117 .38737 L 0 .322 .302 r
F
.5583 .39791 m .55962 .38704 L .56117 .38737 L 0 .329 .299 r
F
.21494 .31781 m .21582 .31492 L .21772 .31683 L 0 .026 .125 r
F
.21494 .31781 m .21304 .31591 L .21582 .31492 L F
.31095 .3201 m .31197 .31738 L .31378 .31925 L 0 .031 .132 r
F
.31095 .3201 m .30914 .31823 L .31197 .31738 L F
.53698 .45472 m .53842 .4694 L .53993 .45378 L 0 .515 .053 r
F
.53698 .45472 m .53545 .47034 L .53842 .4694 L F
.25693 .31804 m .25786 .3153 L .25972 .31719 L 0 .027 .126 r
F
.25693 .31804 m .25507 .31617 L .25786 .3153 L F
.41604 .32703 m .41723 .32407 L .41893 .3262 L 0 .047 .149 r
F
.41604 .32703 m .41435 .3249 L .41723 .32407 L F
.43557 .32849 m .43679 .32524 L .43846 .32763 L 0 .05 .153 r
F
.43557 .32849 m .43389 .32614 L .43679 .32524 L F
.49165 .36297 m .49008 .35591 L .493 .35623 L 0 .167 .239 r
F
.49008 .35591 m .4914 .35129 L .493 .35623 L 0 .138 .221 r
F
.49008 .35591 m .48848 .35147 L .4914 .35129 L F
.86271 .31749 m .86458 .31461 L .86584 .3165 L 0 .026 .125 r
F
.86271 .31749 m .86144 .31559 L .86458 .31461 L F
.6589 .32373 m .66045 .3208 L .66192 .3227 L 0 .039 .141 r
F
.6589 .32373 m .65743 .32184 L .66045 .3208 L F
.70384 .32125 m .70547 .31847 L .70688 .32025 L 0 .034 .135 r
F
.70384 .32125 m .70242 .31944 L .70547 .31847 L F
.626 .32815 m .6275 .3251 L .62899 .32678 L 0 .05 .152 r
F
.626 .32815 m .62451 .32648 L .6275 .3251 L F
.66639 .3234 m .66796 .3204 L .6694 .32213 L 0 .038 .14 r
F
.66639 .3234 m .66494 .32167 L .66796 .3204 L F
.60058 .33213 m .60204 .32884 L .60356 .33071 L 0 .06 .162 r
F
.60058 .33213 m .59906 .33031 L .60204 .32884 L F
.65141 .32424 m .65295 .32109 L .65442 .32297 L 0 .04 .142 r
F
.65141 .32424 m .64994 .3224 L .65295 .32109 L F
.72631 .32008 m .72798 .31734 L .72937 .31912 L 0 .031 .132 r
F
.72631 .32008 m .72492 .31832 L .72798 .31734 L F
.57971 .33837 m .58114 .335 L .58267 .33671 L 0 .078 .178 r
F
.57971 .33837 m .57817 .33667 L .58114 .335 L F
.54287 .44952 m .54138 .46442 L .54433 .45944 L 0 .493 .097 r
F
.53993 .45378 m .54138 .46442 L .54287 .44952 L 0 .507 .068 r
F
.18042 .3174 m .18125 .31448 L .18319 .31637 L 0 .026 .125 r
F
.18042 .3174 m .17848 .31554 L .18125 .31448 L F
.14591 .31684 m .14667 .31405 L .14864 .31593 L 0 .025 .124 r
F
.14591 .31684 m .14394 .31497 L .14667 .31405 L F
.34544 .321 m .34652 .31806 L .34829 .31995 L 0 .033 .134 r
F
.34544 .321 m .34366 .31909 L .34652 .31806 L F
.2224 .31774 m .22329 .31482 L .22519 .31673 L 0 .027 .126 r
F
.2224 .31774 m .22051 .31583 L .22329 .31482 L F
.37245 .3221 m .37357 .3192 L .37531 .32114 L 0 .036 .137 r
F
.37245 .3221 m .3707 .32012 L .37357 .3192 L F
.71134 .32107 m .71299 .31836 L .71439 .3201 L 0 .034 .135 r
F
.71134 .32107 m .70993 .31931 L .71299 .31836 L F
.71883 .32065 m .72048 .31772 L .72187 .31946 L 0 .033 .133 r
F
.71883 .32065 m .71743 .31892 L .72048 .31772 L F
.82075 .31755 m .82256 .31471 L .82386 .3166 L 0 .026 .125 r
F
.82075 .31755 m .81944 .31566 L .82256 .31471 L F
.49076 .39885 m .48922 .38927 L .49207 .39545 L 0 .343 .29 r
F
.48922 .38927 m .49053 .38491 L .49207 .39545 L 0 .31 .307 r
F
.31841 .3201 m .31945 .31718 L .32126 .31904 L 0 .032 .132 r
F
.31841 .3201 m .31661 .31826 L .31945 .31718 L F
.87024 .3174 m .87213 .31461 L .87338 .31644 L 0 .026 .125 r
F
.87024 .3174 m .86898 .31555 L .87213 .31461 L F
.35292 .32073 m .35401 .31784 L .35577 .31972 L 0 .033 .134 r
F
.35292 .32073 m .35115 .31888 L .35401 .31784 L F
.59015 .33549 m .59159 .33192 L .59312 .33374 L 0 .069 .171 r
F
.59015 .33549 m .58862 .33372 L .59159 .33192 L F
.2914 .31908 m .29238 .31637 L .29421 .31822 L 0 .03 .13 r
F
.2914 .31908 m .28957 .31723 L .29238 .31637 L F
.39196 .32367 m .3931 .3211 L .39483 .32292 L 0 .04 .142 r
F
.39196 .32367 m .39023 .32185 L .3931 .3211 L F
.45213 .33303 m .45338 .32983 L .45504 .33215 L 0 .063 .165 r
F
.45213 .33303 m .45047 .33067 L .45338 .32983 L F
.73382 .31997 m .73549 .31706 L .73688 .3189 L 0 .031 .132 r
F
.73382 .31997 m .73243 .31816 L .73549 .31706 L F
.18788 .3173 m .18871 .31448 L .19063 .31639 L 0 .026 .125 r
F
.18788 .3173 m .18595 .3154 L .18871 .31448 L F
.47325 .33956 m .47453 .33637 L .47616 .33903 L 0 .083 .182 r
F
.47325 .33956 m .47162 .33692 L .47453 .33637 L F
.74132 .31962 m .74299 .31661 L .74437 .31847 L 0 .031 .131 r
F
.74132 .31962 m .73993 .31775 L .74299 .31661 L F
.3259 .31983 m .32694 .31698 L .32873 .31889 L 0 .031 .132 r
F
.3259 .31983 m .3241 .31797 L .32694 .31698 L F
.64394 .32505 m .64546 .32193 L .64694 .32371 L 0 .042 .145 r
F
.64394 .32505 m .64246 .3233 L .64546 .32193 L F
.22987 .31758 m .23077 .31465 L .23266 .31653 L 0 .027 .126 r
F
.22987 .31758 m .22798 .31569 L .23077 .31465 L F
.47779 .34189 m .47908 .33849 L .48071 .34142 L 0 .09 .188 r
F
.47779 .34189 m .47616 .33903 L .47908 .33849 L F
.56338 .3473 m .56477 .34268 L .56633 .34477 L 0 .105 .199 r
F
.56338 .3473 m .56182 .34502 L .56477 .34268 L F
.56045 .35094 m .56182 .34502 L .56338 .3473 L 0 .117 .207 r
F
.42352 .32716 m .42472 .32419 L .42641 .32614 L 0 .048 .15 r
F
.42352 .32716 m .42182 .32519 L .42472 .32419 L F
.26437 .31823 m .26532 .31544 L .26717 .31731 L 0 .028 .128 r
F
.26437 .31823 m .26251 .31634 L .26532 .31544 L F
.48848 .35147 m .4898 .34635 L .4914 .35129 L 0 .12 .209 r
F
.48848 .35147 m .48687 .34702 L .4898 .34635 L F
.74881 .31926 m .75051 .31641 L .75188 .31822 L 0 .03 .13 r
F
.74881 .31926 m .74744 .31744 L .75051 .31641 L F
.55777 .36854 m .55618 .36474 L .55909 .35771 L 0 .179 .245 r
F
.55909 .35771 m .55751 .35458 L .56045 .35094 L 0 .138 .221 r
F
.55618 .36474 m .55751 .35458 L .55909 .35771 L 0 .167 .239 r
F
.77128 .31804 m .77301 .31513 L .77436 .31695 L 0 .028 .127 r
F
.77128 .31804 m .76994 .31624 L .77301 .31513 L F
.82827 .31745 m .83008 .31458 L .83138 .31643 L 0 .027 .126 r
F
.82827 .31745 m .82697 .31559 L .83008 .31458 L F
.7638 .3185 m .76551 .31558 L .76686 .31737 L 0 .029 .128 r
F
.7638 .3185 m .76244 .31672 L .76551 .31558 L F
.75631 .31893 m .75801 .31605 L .75937 .31783 L 0 .029 .129 r
F
.75631 .31893 m .75494 .31715 L .75801 .31605 L F
.11884 .31623 m .11956 .31345 L .12156 .31532 L 0 .024 .123 r
F
.11884 .31623 m .11684 .31436 L .11956 .31345 L F
.4687 .33744 m .46998 .33428 L .47162 .33692 L 0 .077 .177 r
F
.4687 .33744 m .46706 .33483 L .46998 .33428 L F
.15335 .31688 m .15413 .31404 L .15609 .31591 L 0 .026 .124 r
F
.15335 .31688 m .15138 .31501 L .15413 .31404 L F
.56633 .34477 m .56773 .34056 L .56929 .34254 L 0 .098 .194 r
F
.56633 .34477 m .56477 .34268 L .56773 .34056 L F
.48233 .3444 m .48364 .34055 L .48526 .34364 L F
.48233 .3444 m .48071 .34142 L .48364 .34055 L F
.83577 .31721 m .83761 .31437 L .83889 .31618 L 0 .026 .125 r
F
.83577 .31721 m .83449 .3154 L .83761 .31437 L F
.23733 .31743 m .23823 .31466 L .24012 .31651 L 0 .027 .126 r
F
.23733 .31743 m .23545 .31557 L .23823 .31466 L F
.77879 .31787 m .78054 .31503 L .78188 .3169 L 0 .028 .127 r
F
.77879 .31787 m .77745 .31599 L .78054 .31503 L F
.36038 .32079 m .36147 .31811 L .36323 .31999 L 0 .034 .135 r
F
.36038 .32079 m .35862 .31891 L .36147 .31811 L F
.29886 .31914 m .29986 .31625 L .30168 .31815 L 0 .03 .13 r
F
.29886 .31914 m .29703 .31724 L .29986 .31625 L F
.37991 .32227 m .38103 .31953 L .38277 .32148 L 0 .037 .139 r
F
.37991 .32227 m .37817 .32033 L .38103 .31953 L F
.41147 .3256 m .41265 .32269 L .41435 .3249 L 0 .045 .147 r
F
.41147 .3256 m .40977 .32341 L .41265 .32269 L F
.46416 .33538 m .46542 .33237 L .46706 .33483 L 0 .071 .172 r
F
.46416 .33538 m .46251 .33295 L .46542 .33237 L F
.431 .32711 m .43221 .32413 L .43389 .32614 L 0 .048 .151 r
F
.431 .32711 m .42931 .32514 L .43221 .32413 L F
.84328 .31693 m .84513 .31416 L .8464 .31596 L 0 .026 .125 r
F
.84328 .31693 m .84201 .31514 L .84513 .31416 L F
.16081 .31673 m .1616 .31387 L .16356 .31572 L 0 .026 .124 r
F
.16081 .31673 m .15884 .31489 L .1616 .31387 L F
.27183 .31819 m .27279 .31542 L .27464 .31721 L 0 .029 .128 r
F
.27183 .31819 m .26998 .31636 L .27279 .31542 L F
.19532 .31736 m .19617 .31444 L .19809 .3163 L 0 .027 .126 r
F
.19532 .31736 m .19339 .31548 L .19617 .31444 L F
.39943 .32385 m .40059 .32102 L .40231 .32291 L 0 .041 .143 r
F
.39943 .32385 m .39771 .32201 L .40059 .32102 L F
.61853 .32947 m .62002 .32611 L .62152 .32798 L 0 .054 .156 r
F
.61853 .32947 m .61703 .32761 L .62002 .32611 L F
.33336 .31992 m .33442 .31703 L .3362 .31901 L 0 .032 .133 r
F
.33336 .31992 m .33157 .31795 L .33442 .31703 L F
.12628 .31621 m .12702 .31338 L .12902 .31522 L 0 .025 .123 r
F
.12628 .31621 m .12429 .31437 L .12702 .31338 L F
.7938 .31728 m .79557 .3145 L .7969 .31631 L 0 .027 .126 r
F
.7938 .31728 m .79247 .31545 L .79557 .3145 L F
.61104 .32996 m .61252 .3268 L .61404 .32879 L 0 .056 .158 r
F
.61104 .32996 m .60953 .32801 L .61252 .3268 L F
.78631 .31771 m .78805 .31474 L .78939 .31658 L 0 .027 .127 r
F
.78631 .31771 m .78497 .31585 L .78805 .31474 L F
.63647 .32603 m .63798 .32294 L .63946 .32468 L 0 .046 .148 r
F
.63647 .32603 m .63499 .32432 L .63798 .32294 L F
.44757 .33143 m .44882 .32815 L .45047 .33067 L 0 .059 .162 r
F
.44757 .33143 m .44591 .32889 L .44882 .32815 L F
.48687 .34702 m .48819 .34277 L .4898 .34635 L 0 .107 .2 r
F
.48687 .34702 m .48526 .34364 L .48819 .34277 L F
.20279 .3171 m .20365 .31421 L .20557 .31605 L 0 .026 .125 r
F
.20279 .3171 m .20087 .31525 L .20365 .31421 L F
.49188 .37759 m .49031 .36971 L .49321 .37185 L 0 .25 .282 r
F
.49031 .36971 m .49165 .36297 L .49321 .37185 L 0 .196 .255 r
F
.58267 .33671 m .58411 .33347 L .58565 .33521 L 0 .075 .176 r
F
.58267 .33671 m .58114 .335 L .58411 .33347 L F
.56929 .34254 m .57069 .33848 L .57224 .34037 L 0 .092 .189 r
F
.56929 .34254 m .56773 .34056 L .57069 .33848 L F
.30632 .31908 m .30733 .31635 L .30914 .31823 L 0 .031 .131 r
F
.30632 .31908 m .30451 .31719 L .30733 .31635 L F
.24479 .31742 m .24571 .31453 L .24759 .31636 L 0 .027 .126 r
F
.24479 .31742 m .24291 .31558 L .24571 .31453 L F
.8508 .3168 m .85266 .314 L .85393 .31582 L 0 .026 .125 r
F
.8508 .3168 m .84953 .315 L .85266 .314 L F
.67688 .32138 m .67848 .31865 L .67991 .32038 L 0 .036 .137 r
F
.67688 .32138 m .67544 .31967 L .67848 .31865 L F
.2793 .31807 m .28026 .31532 L .28211 .31714 L 0 .029 .129 r
F
.2793 .31807 m .27745 .31627 L .28026 .31532 L F
.16826 .31664 m .16905 .3139 L .17101 .31572 L 0 .026 .125 r
F
.16826 .31664 m .16631 .3148 L .16905 .3139 L F
.13375 .31604 m .13449 .31323 L .13648 .31506 L 0 .025 .123 r
F
.13375 .31604 m .13175 .31422 L .13449 .31323 L F
.21026 .3169 m .21113 .31402 L .21304 .31591 L 0 .026 .125 r
F
.21026 .3169 m .20835 .31504 L .21113 .31402 L F
.59312 .33374 m .59456 .33011 L .59609 .33198 L 0 .066 .167 r
F
.59312 .33374 m .59159 .33192 L .59456 .33011 L F
.4596 .33354 m .46086 .33064 L .46251 .33295 L 0 .067 .168 r
F
.4596 .33354 m .45795 .33127 L .46086 .33064 L F
.80131 .31714 m .8031 .31435 L .80441 .31614 L 0 .027 .126 r
F
.80131 .31714 m .8 .31535 L .8031 .31435 L F
.68438 .32111 m .68598 .31828 L .68741 .32004 L 0 .035 .136 r
F
.68438 .32111 m .68295 .31937 L .68598 .31828 L F
.25227 .31716 m .2532 .3143 L .25507 .31617 L 0 .027 .126 r
F
.25227 .31716 m .25039 .31531 L .2532 .3143 L F
.60356 .33071 m .60502 .32737 L .60654 .32928 L 0 .058 .16 r
F
.60356 .33071 m .60204 .32884 L .60502 .32737 L F
.69188 .32074 m .69349 .31786 L .69491 .31968 L 0 .034 .135 r
F
.69188 .32074 m .69045 .31895 L .69349 .31786 L F
.62899 .32678 m .6305 .32386 L .63199 .32555 L 0 .048 .151 r
F
.62899 .32678 m .6275 .3251 L .6305 .32386 L F
.80882 .31683 m .81061 .31396 L .81191 .31575 L 0 .026 .125 r
F
.80882 .31683 m .80751 .31505 L .81061 .31396 L F
.56045 .35094 m .55887 .34821 L .56182 .34502 L 0 .117 .207 r
F
.55751 .35458 m .55887 .34821 L .56045 .35094 L 0 .131 .217 r
F
.44302 .32954 m .44425 .32634 L .44591 .32889 L 0 .055 .158 r
F
.44302 .32954 m .44136 .32699 L .44425 .32634 L F
.85832 .31666 m .86018 .31368 L .86144 .31559 L 0 .026 .125 r
F
.85832 .31666 m .85705 .31475 L .86018 .31368 L F
.36784 .32104 m .36895 .31822 L .3707 .32012 L 0 .035 .136 r
F
.36784 .32104 m .36609 .31913 L .36895 .31822 L F
.34082 .32005 m .34189 .31718 L .34366 .31909 L 0 .033 .134 r
F
.34082 .32005 m .33904 .3181 L .34189 .31718 L F
.6694 .32213 m .67097 .31913 L .67242 .32085 L 0 .037 .139 r
F
.6694 .32213 m .66796 .3204 L .67097 .31913 L F
.69938 .32047 m .701 .31755 L .70242 .31944 L 0 .034 .135 r
F
.69938 .32047 m .69795 .31862 L .701 .31755 L F
.55806 .38522 m .55647 .38189 L .55934 .37139 L 0 .265 .289 r
F
.55647 .38189 m .55777 .36854 L .55934 .37139 L 0 .254 .284 r
F
.65442 .32297 m .65596 .31993 L .65743 .32184 L 0 .039 .141 r
F
.65442 .32297 m .65295 .32109 L .65596 .31993 L F
.1412 .31593 m .14196 .3131 L .14394 .31497 L 0 .025 .123 r
F
.1412 .31593 m .13922 .31408 L .14196 .3131 L F
.38737 .32259 m .3885 .31996 L .39023 .32185 L 0 .039 .141 r
F
.38737 .32259 m .38563 .3207 L .3885 .31996 L F
.81633 .3166 m .81814 .31381 L .81944 .31566 L 0 .026 .125 r
F
.81633 .3166 m .81502 .31476 L .81814 .31381 L F
.17571 .3166 m .17653 .31368 L .17848 .31554 L F
.17571 .3166 m .17376 .31476 L .17653 .31368 L F
.53993 .45378 m .53842 .4694 L .54138 .46442 L 0 .507 .068 r
F
.21772 .31683 m .21861 .31392 L .22051 .31583 L 0 .026 .126 r
F
.21772 .31683 m .21582 .31492 L .21861 .31392 L F
.28676 .31809 m .28773 .31538 L .28957 .31723 L 0 .029 .129 r
F
.28676 .31809 m .28492 .31624 L .28773 .31538 L F
.4069 .32413 m .40807 .32123 L .40977 .32341 L 0 .042 .145 r
F
.4069 .32413 m .40519 .32198 L .40807 .32123 L F
.66192 .3227 m .66348 .31975 L .66494 .32167 L 0 .039 .141 r
F
.66192 .3227 m .66045 .3208 L .66348 .31975 L F
.57224 .34037 m .57366 .33665 L .5752 .33852 L 0 .087 .185 r
F
.57224 .34037 m .57069 .33848 L .57366 .33665 L F
.86584 .3165 m .86773 .31368 L .86898 .31555 L 0 .026 .125 r
F
.86584 .3165 m .86458 .31461 L .86773 .31368 L F
.70688 .32025 m .70852 .31754 L .70993 .31931 L 0 .034 .135 r
F
.70688 .32025 m .70547 .31847 L .70852 .31754 L F
.31378 .31925 m .3148 .31639 L .31661 .31826 L 0 .032 .132 r
F
.31378 .31925 m .31197 .31738 L .3148 .31639 L F
.72187 .31946 m .72353 .31657 L .72492 .31832 L 0 .032 .133 r
F
.72187 .31946 m .72048 .31772 L .72353 .31657 L F
.25972 .31719 m .26066 .31442 L .26251 .31634 L 0 .028 .127 r
F
.25972 .31719 m .25786 .3153 L .26066 .31442 L F
.18319 .31637 m .18401 .3135 L .18595 .3154 L 0 .026 .125 r
F
.18319 .31637 m .18125 .31448 L .18401 .3135 L F
.43846 .32763 m .43969 .32459 L .44136 .32699 L 0 .051 .154 r
F
.43846 .32763 m .43679 .32524 L .43969 .32459 L F
.34829 .31995 m .34938 .31699 L .35115 .31888 L 0 .033 .134 r
F
.34829 .31995 m .34652 .31806 L .34938 .31699 L F
.72937 .31912 m .73104 .31635 L .73243 .31816 L 0 .032 .132 r
F
.72937 .31912 m .72798 .31734 L .73104 .31635 L F
.41893 .3262 m .42013 .32309 L .42182 .32519 L 0 .047 .15 r
F
.41893 .3262 m .41723 .32407 L .42013 .32309 L F
.64694 .32371 m .64847 .32057 L .64994 .3224 L 0 .041 .143 r
F
.64694 .32371 m .64546 .32193 L .64847 .32057 L F
.11413 .31528 m .11484 .31247 L .11684 .31436 L 0 .024 .122 r
F
.11413 .31528 m .11212 .3134 L .11484 .31247 L F
.22519 .31673 m .22609 .31377 L .22798 .31569 L 0 .027 .126 r
F
.22519 .31673 m .22329 .31482 L .22609 .31377 L F
.32126 .31904 m .3223 .3161 L .3241 .31797 L 0 .031 .132 r
F
.32126 .31904 m .31945 .31718 L .3223 .3161 L F
.14864 .31593 m .14941 .31312 L .15138 .31501 L 0 .025 .124 r
F
.14864 .31593 m .14667 .31405 L .14941 .31312 L F
.71439 .3201 m .71603 .31718 L .71743 .31892 L 0 .034 .135 r
F
.71439 .3201 m .71299 .31836 L .71603 .31718 L F
.37531 .32114 m .37643 .31838 L .37817 .32033 L 0 .036 .138 r
F
.37531 .32114 m .37357 .3192 L .37643 .31838 L F
.35577 .31972 m .35686 .31704 L .35862 .31891 L 0 .033 .134 r
F
.35577 .31972 m .35401 .31784 L .35686 .31704 L F
.74437 .31847 m .74606 .31559 L .74744 .31744 L 0 .03 .131 r
F
.74437 .31847 m .74299 .31661 L .74606 .31559 L F
.82386 .3166 m .82567 .31372 L .82697 .31559 L 0 .027 .126 r
F
.82386 .3166 m .82256 .31471 L .82567 .31372 L F
.73688 .3189 m .73855 .3159 L .73993 .31775 L 0 .031 .131 r
F
.73688 .3189 m .73549 .31706 L .73855 .3159 L F
.49321 .37185 m .49165 .36297 L .49457 .36409 L 0 .217 .266 r
F
.49165 .36297 m .493 .35623 L .49457 .36409 L 0 .167 .239 r
F
.23266 .31653 m .23356 .3137 L .23545 .31557 L 0 .027 .126 r
F
.23266 .31653 m .23077 .31465 L .23356 .3137 L F
.77436 .31695 m .7761 .31415 L .77745 .31599 L 0 .028 .127 r
F
.77436 .31695 m .77301 .31513 L .7761 .31415 L F
.76686 .31737 m .76859 .31443 L .76994 .31624 L 0 .028 .128 r
F
.76686 .31737 m .76551 .31558 L .76859 .31443 L F
.62152 .32798 m .623 .32461 L .62451 .32648 L 0 .052 .154 r
F
.62152 .32798 m .62002 .32611 L .623 .32461 L F
.75188 .31822 m .75358 .31535 L .75494 .31715 L 0 .03 .13 r
F
.75188 .31822 m .75051 .31641 L .75358 .31535 L F
.29421 .31822 m .29521 .31536 L .29703 .31724 L F
.29421 .31822 m .29238 .31637 L .29521 .31536 L F
.45504 .33215 m .45629 .32899 L .45795 .33127 L 0 .064 .166 r
F
.45504 .33215 m .45338 .32983 L .45629 .32899 L F
.75937 .31783 m .76109 .31495 L .76244 .31672 L 0 .029 .129 r
F
.75937 .31783 m .75801 .31605 L .76109 .31495 L F
.42641 .32614 m .42762 .32316 L .42931 .32514 L 0 .048 .15 r
F
.42641 .32614 m .42472 .32419 L .42762 .32316 L F
.59609 .33198 m .59753 .32839 L .59906 .33031 L 0 .062 .164 r
F
.59609 .33198 m .59456 .33011 L .59753 .32839 L F
.19063 .31639 m .19147 .31355 L .19339 .31548 L 0 .026 .126 r
F
.19063 .31639 m .18871 .31448 L .19147 .31355 L F
.32873 .31889 m .32979 .316 L .33157 .31795 L 0 .031 .132 r
F
.32873 .31889 m .32694 .31698 L .32979 .316 L F
.83138 .31643 m .8332 .31356 L .83449 .3154 L 0 .027 .126 r
F
.83138 .31643 m .83008 .31458 L .8332 .31356 L F
.26717 .31731 m .26812 .31452 L .26998 .31636 L 0 .028 .128 r
F
.26717 .31731 m .26532 .31544 L .26812 .31452 L F
.39483 .32292 m .39598 .32016 L .39771 .32201 L 0 .041 .143 r
F
.39483 .32292 m .3931 .3211 L .39598 .32016 L F
.58565 .33521 m .58708 .33193 L .58862 .33372 L 0 .073 .174 r
F
.58565 .33521 m .58411 .33347 L .58708 .33193 L F
.15609 .31591 m .15688 .31301 L .15884 .31489 L 0 .026 .124 r
F
.15609 .31591 m .15413 .31404 L .15688 .31301 L F
.55618 .36474 m .55459 .36081 L .55751 .35458 L 0 .167 .239 r
F
.55751 .35458 m .55593 .3514 L .55887 .34821 L 0 .131 .217 r
F
.55459 .36081 m .55593 .3514 L .55751 .35458 L 0 .155 .232 r
F
.12156 .31532 m .12228 .31251 L .12429 .31437 L 0 .025 .123 r
F
.12156 .31532 m .11956 .31345 L .12228 .31251 L F
.63946 .32468 m .64098 .32154 L .64246 .3233 L 0 .044 .147 r
F
.63946 .32468 m .63798 .32294 L .64098 .32154 L F
.83889 .31618 m .84073 .31334 L .84201 .31514 L 0 .026 .125 r
F
.83889 .31618 m .83761 .31437 L .84073 .31334 L F
.55854 .40966 m .55702 .41317 L .55984 .39774 L 0 .356 .281 r
F
.55702 .41317 m .5583 .39791 L .55984 .39774 L 0 .37 .27 r
F
.78188 .3169 m .78363 .31398 L .78497 .31585 L 0 .028 .127 r
F
.78188 .3169 m .78054 .31503 L .78363 .31398 L F
.30168 .31815 m .30269 .31528 L .30451 .31719 L 0 .03 .131 r
F
.30168 .31815 m .29986 .31625 L .30269 .31528 L F
.5752 .33852 m .57662 .33482 L .57817 .33667 L 0 .082 .181 r
F
.5752 .33852 m .57366 .33665 L .57662 .33482 L F
.24012 .31651 m .24102 .31375 L .24291 .31558 L 0 .027 .127 r
F
.24012 .31651 m .23823 .31466 L .24102 .31375 L F
.19809 .3163 m .19895 .3134 L .20087 .31525 L 0 .027 .126 r
F
.19809 .3163 m .19617 .31444 L .19895 .3134 L F
.61404 .32879 m .61552 .32557 L .61703 .32761 L 0 .055 .157 r
F
.61404 .32879 m .61252 .3268 L .61552 .32557 L F
.16356 .31572 m .16434 .31297 L .16631 .3148 L 0 .026 .125 r
F
.16356 .31572 m .1616 .31387 L .16434 .31297 L F
.47616 .33903 m .47745 .33582 L .47908 .33849 L 0 .085 .184 r
F
.47616 .33903 m .47453 .33637 L .47745 .33582 L F
.43389 .32614 m .43511 .3232 L .43679 .32524 L 0 .049 .151 r
F
.43389 .32614 m .43221 .32413 L .43511 .3232 L F
.78939 .31658 m .79114 .31362 L .79247 .31545 L 0 .027 .126 r
F
.78939 .31658 m .78805 .31474 L .79114 .31362 L F
.8464 .31596 m .84826 .3132 L .84953 .315 L 0 .026 .125 r
F
.8464 .31596 m .84513 .31416 L .84826 .3132 L F
.27464 .31721 m .2756 .31446 L .27745 .31627 L 0 .029 .129 r
F
.27464 .31721 m .27279 .31542 L .2756 .31446 L F
.60654 .32928 m .60801 .32606 L .60953 .32801 L 0 .056 .159 r
F
.60654 .32928 m .60502 .32737 L .60801 .32606 L F
.48526 .34364 m .48657 .33954 L .48819 .34277 L 0 .099 .194 r
F
.48526 .34364 m .48364 .34055 L .48657 .33954 L F
.36323 .31999 m .36433 .31725 L .36609 .31913 L 0 .035 .136 r
F
.36323 .31999 m .36147 .31811 L .36433 .31725 L F
.40231 .32291 m .40348 .32004 L .40519 .32198 L 0 .041 .143 r
F
.40231 .32291 m .40059 .32102 L .40348 .32004 L F
.12902 .31522 m .12975 .3124 L .13175 .31422 L 0 .025 .123 r
F
.12902 .31522 m .12702 .31338 L .12975 .3124 L F
.20557 .31605 m .20643 .31319 L .20835 .31504 L 0 .026 .125 r
F
.20557 .31605 m .20365 .31421 L .20643 .31319 L F
.48071 .34142 m .48201 .33752 L .48364 .34055 L 0 .092 .189 r
F
.48071 .34142 m .47908 .33849 L .48201 .33752 L F
.38277 .32148 m .3839 .31875 L .38563 .3207 L 0 .038 .14 r
F
.38277 .32148 m .38103 .31953 L .3839 .31875 L F
.3362 .31901 m .33726 .31612 L .33904 .3181 L 0 .032 .133 r
F
.3362 .31901 m .33442 .31703 L .33726 .31612 L F
.7969 .31631 m .79868 .31355 L .8 .31535 L 0 .027 .126 r
F
.7969 .31631 m .79557 .3145 L .79868 .31355 L F
.47162 .33692 m .47289 .33372 L .47453 .33637 L 0 .079 .179 r
F
.47162 .33692 m .46998 .33428 L .47289 .33372 L F
.24759 .31636 m .24852 .31347 L .25039 .31531 L 0 .027 .126 r
F
.24759 .31636 m .24571 .31453 L .24852 .31347 L F
.41435 .3249 m .41554 .32187 L .41723 .32407 L 0 .046 .148 r
F
.41435 .3249 m .41265 .32269 L .41554 .32187 L F
.63199 .32555 m .6335 .32261 L .63499 .32432 L 0 .048 .15 r
F
.63199 .32555 m .6305 .32386 L .6335 .32261 L F
.67991 .32038 m .68151 .31764 L .68295 .31937 L 0 .036 .137 r
F
.67991 .32038 m .67848 .31865 L .68151 .31764 L F
.85393 .31582 m .85579 .31293 L .85705 .31475 L 0 .026 .125 r
F
.85393 .31582 m .85266 .314 L .85579 .31293 L F
.67242 .32085 m .674 .31795 L .67544 .31967 L 0 .037 .138 r
F
.67242 .32085 m .67097 .31913 L .674 .31795 L F
.68741 .32004 m .68902 .31717 L .69045 .31895 L 0 .035 .136 r
F
.68741 .32004 m .68598 .31828 L .68902 .31717 L F
.13648 .31506 m .13723 .31225 L .13922 .31408 L 0 .025 .123 r
F
.13648 .31506 m .13449 .31323 L .13723 .31225 L F
.49457 .36409 m .493 .35623 L .49592 .35647 L 0 .179 .245 r
F
.493 .35623 m .49432 .35106 L .49592 .35647 L 0 .145 .225 r
F
.493 .35623 m .4914 .35129 L .49432 .35106 L F
.28211 .31714 m .28308 .31442 L .28492 .31624 L 0 .029 .129 r
F
.28211 .31714 m .28026 .31532 L .28308 .31442 L F
.45047 .33067 m .45172 .32734 L .45338 .32983 L 0 .06 .163 r
F
.45047 .33067 m .44882 .32815 L .45172 .32734 L F
.21304 .31591 m .21392 .31302 L .21582 .31492 L 0 .026 .125 r
F
.21304 .31591 m .21113 .31402 L .21392 .31302 L F
.46706 .33483 m .46833 .33179 L .46998 .33428 L 0 .073 .174 r
F
.46706 .33483 m .46542 .33237 L .46833 .33179 L F
.80441 .31614 m .8062 .31326 L .80751 .31505 L 0 .027 .126 r
F
.80441 .31614 m .8031 .31435 L .8062 .31326 L F
.17101 .31572 m .17181 .31294 L .17376 .31476 L 0 .026 .125 r
F
.17101 .31572 m .16905 .3139 L .17181 .31294 L F
.69491 .31968 m .69653 .31676 L .69795 .31862 L 0 .034 .135 r
F
.69491 .31968 m .69349 .31786 L .69653 .31676 L F
.30914 .31823 m .31015 .3155 L .31197 .31738 L 0 .031 .132 r
F
.30914 .31823 m .30733 .31635 L .31015 .3155 L F
.4914 .35129 m .49273 .34566 L .49432 .35106 L 0 .124 .212 r
F
.4914 .35129 m .4898 .34635 L .49273 .34566 L F
.81191 .31575 m .81372 .31295 L .81502 .31476 L 0 .026 .125 r
F
.81191 .31575 m .81061 .31396 L .81372 .31295 L F
.25507 .31617 m .256 .31341 L .25786 .3153 L 0 .027 .126 r
F
.25507 .31617 m .2532 .3143 L .256 .31341 L F
.4898 .34635 m .49112 .34188 L .49273 .34566 L 0 .108 .201 r
F
.4898 .34635 m .48819 .34277 L .49112 .34188 L F
.86144 .31559 m .86332 .31271 L .86458 .31461 L 0 .026 .125 r
F
.86144 .31559 m .86018 .31368 L .86332 .31271 L F
.65743 .32184 m .65899 .31885 L .66045 .3208 L 0 .039 .141 r
F
.65743 .32184 m .65596 .31993 L .65899 .31885 L F
.70242 .31944 m .70405 .31655 L .70547 .31847 L 0 .034 .135 r
F
.70242 .31944 m .701 .31755 L .70405 .31655 L F
.56182 .34502 m .56321 .34022 L .56477 .34268 L 0 .102 .197 r
F
.56182 .34502 m .56025 .34243 L .56321 .34022 L F
.55887 .34821 m .56025 .34243 L .56182 .34502 L 0 .112 .204 r
F
.64994 .3224 m .65148 .31921 L .65295 .32109 L 0 .04 .142 r
F
.64994 .3224 m .64847 .32057 L .65148 .31921 L F
.17848 .31554 m .17931 .3126 L .18125 .31448 L 0 .026 .125 r
F
.17848 .31554 m .17653 .31368 L .17931 .3126 L F
.3707 .32012 m .37182 .31731 L .37357 .3192 L 0 .036 .137 r
F
.3707 .32012 m .36895 .31822 L .37182 .31731 L F
.59906 .33031 m .60051 .32689 L .60204 .32884 L 0 .06 .162 r
F
.59906 .33031 m .59753 .32839 L .60051 .32689 L F
.34366 .31909 m .34474 .31616 L .34652 .31806 L 0 .033 .134 r
F
.34366 .31909 m .34189 .31718 L .34474 .31616 L F
.14394 .31497 m .1447 .31216 L .14667 .31405 L 0 .025 .124 r
F
.14394 .31497 m .14196 .3131 L .1447 .31216 L F
.49258 .41894 m .49103 .41002 L .49385 .4202 L 0 .408 .231 r
F
.49103 .41002 m .49231 .40951 L .49385 .4202 L 0 .376 .265 r
F
.72492 .31832 m .72659 .31556 L .72798 .31734 L 0 .032 .132 r
F
.72492 .31832 m .72353 .31657 L .72659 .31556 L F
.22051 .31583 m .2214 .31291 L .22329 .31482 L 0 .027 .126 r
F
.22051 .31583 m .21861 .31392 L .2214 .31291 L F
.66494 .32167 m .6665 .31848 L .66796 .3204 L 0 .038 .14 r
F
.66494 .32167 m .66348 .31975 L .6665 .31848 L F
.81944 .31566 m .82125 .31286 L .82256 .31471 L 0 .026 .126 r
F
.81944 .31566 m .81814 .31381 L .82125 .31286 L F
.62451 .32648 m .626 .32323 L .6275 .3251 L 0 .05 .153 r
F
.62451 .32648 m .623 .32461 L .626 .32323 L F
.57817 .33667 m .57959 .33313 L .58114 .335 L 0 .078 .178 r
F
.57817 .33667 m .57662 .33482 L .57959 .33313 L F
.46251 .33295 m .46377 .33002 L .46542 .33237 L 0 .069 .17 r
F
.46251 .33295 m .46086 .33064 L .46377 .33002 L F
.35115 .31888 m .35224 .31597 L .35401 .31784 L 0 .033 .134 r
F
.35115 .31888 m .34938 .31699 L .35224 .31597 L F
.31661 .31826 m .31765 .31533 L .31945 .31718 L 0 .032 .132 r
F
.31661 .31826 m .3148 .31639 L .31765 .31533 L F
.86898 .31555 m .87088 .31275 L .87213 .31461 L 0 .026 .125 r
F
.86898 .31555 m .86773 .31368 L .87088 .31275 L F
.70993 .31931 m .71158 .31662 L .71299 .31836 L 0 .034 .135 r
F
.70993 .31931 m .70852 .31754 L .71158 .31662 L F
.28957 .31723 m .29055 .31451 L .29238 .31637 L 0 .03 .13 r
F
.28957 .31723 m .28773 .31538 L .29055 .31451 L F
.44591 .32889 m .44716 .32562 L .44882 .32815 L 0 .057 .159 r
F
.44591 .32889 m .44425 .32634 L .44716 .32562 L F
.71743 .31892 m .71908 .31598 L .72048 .31772 L 0 .033 .134 r
F
.71743 .31892 m .71603 .31718 L .71908 .31598 L F
.39023 .32185 m .39137 .31922 L .3931 .3211 L 0 .04 .142 r
F
.39023 .32185 m .3885 .31996 L .39137 .31922 L F
.18595 .3154 m .18678 .31255 L .18871 .31448 L 0 .026 .125 r
F
.18595 .3154 m .18401 .3135 L .18678 .31255 L F
.58862 .33372 m .59006 .33009 L .59159 .33192 L 0 .07 .171 r
F
.58862 .33372 m .58708 .33193 L .59006 .33009 L F
.42182 .32519 m .42302 .32211 L .42472 .32419 L 0 .047 .15 r
F
.42182 .32519 m .42013 .32309 L .42302 .32211 L F
.56477 .34268 m .56617 .33816 L .56773 .34056 L 0 .096 .192 r
F
.56477 .34268 m .56321 .34022 L .56617 .33816 L F
.49207 .39545 m .49053 .38491 L .49341 .38955 L 0 .336 .295 r
F
.49053 .38491 m .49188 .37759 L .49341 .38955 L 0 .284 .297 r
F
.73243 .31816 m .7341 .31523 L .73549 .31706 L 0 .032 .132 r
F
.73243 .31816 m .73104 .31635 L .7341 .31523 L F
.73993 .31775 m .74161 .31473 L .74299 .31661 L 0 .031 .131 r
F
.73993 .31775 m .73855 .3159 L .74161 .31473 L F
.3241 .31797 m .32515 .31507 L .32694 .31698 L 0 .031 .132 r
F
.3241 .31797 m .3223 .3161 L .32515 .31507 L F
.22798 .31569 m .22888 .31271 L .23077 .31465 L 0 .027 .126 r
F
.22798 .31569 m .22609 .31377 L .22888 .31271 L F
.26251 .31634 m .26346 .31351 L .26532 .31544 L 0 .028 .128 r
F
.26251 .31634 m .26066 .31442 L .26346 .31351 L F
.55647 .38189 m .55489 .37856 L .55777 .36854 L 0 .254 .284 r
F
.55489 .37856 m .55618 .36474 L .55777 .36854 L 0 .238 .276 r
F
.40977 .32341 m .41095 .32049 L .41265 .32269 L 0 .043 .146 r
F
.40977 .32341 m .40807 .32123 L .41095 .32049 L F
.55887 .34821 m .5573 .34526 L .56025 .34243 L 0 .112 .204 r
F
.55593 .3514 m .5573 .34526 L .55887 .34821 L 0 .124 .212 r
F
.74744 .31744 m .74913 .31457 L .75051 .31641 L 0 .03 .13 r
F
.74744 .31744 m .74606 .31559 L .74913 .31457 L F
.82697 .31559 m .82879 .31272 L .83008 .31458 L 0 .027 .126 r
F
.82697 .31559 m .82567 .31372 L .82879 .31272 L F
.64246 .3233 m .64399 .32014 L .64546 .32193 L 0 .043 .145 r
F
.64246 .3233 m .64098 .32154 L .64399 .32014 L F
.11684 .31436 m .11756 .31153 L .11956 .31345 L 0 .024 .123 r
F
.11684 .31436 m .11484 .31247 L .11756 .31153 L F
.76994 .31624 m .77166 .31331 L .77301 .31513 L 0 .028 .127 r
F
.76994 .31624 m .76859 .31443 L .77166 .31331 L F
.15138 .31501 m .15216 .31214 L .15413 .31404 L 0 .026 .124 r
F
.15138 .31501 m .14941 .31312 L .15216 .31214 L F
.55445 .42984 m .55297 .43893 L .55583 .42524 L 0 .42 .216 r
F
.55157 .44164 m .55297 .43893 L .55445 .42984 L 0 .467 .145 r
F
.76244 .31672 m .76416 .3138 L .76551 .31558 L 0 .029 .129 r
F
.76244 .31672 m .76109 .31495 L .76416 .3138 L F
.75494 .31715 m .75665 .31426 L .75801 .31605 L 0 .03 .13 r
F
.75494 .31715 m .75358 .31535 L .75665 .31426 L F
.44136 .32699 m .44259 .32394 L .44425 .32634 L 0 .053 .155 r
F
.44136 .32699 m .43969 .32459 L .44259 .32394 L F
.37817 .32033 m .37929 .31757 L .38103 .31953 L 0 .037 .139 r
F
.37817 .32033 m .37643 .31838 L .37929 .31757 L F
.23545 .31557 m .23635 .31281 L .23823 .31466 L 0 .027 .126 r
F
.23545 .31557 m .23356 .3137 L .23635 .31281 L F
.42931 .32514 m .43052 .32212 L .43221 .32413 L 0 .048 .15 r
F
.42931 .32514 m .42762 .32316 L .43052 .32212 L F
.77745 .31599 m .7792 .31317 L .78054 .31503 L 0 .028 .127 r
F
.77745 .31599 m .7761 .31415 L .7792 .31317 L F
.29703 .31724 m .29804 .31432 L .29986 .31625 L 0 .03 .13 r
F
.29703 .31724 m .29521 .31536 L .29804 .31432 L F
.35862 .31891 m .35971 .31623 L .36147 .31811 L 0 .034 .135 r
F
.35862 .31891 m .35686 .31704 L .35971 .31623 L F
.83449 .3154 m .83632 .31255 L .83761 .31437 L 0 .027 .126 r
F
.83449 .3154 m .8332 .31356 L .83632 .31255 L F
.49341 .38955 m .49188 .37759 L .49477 .38075 L 0 .317 .304 r
F
.49188 .37759 m .49321 .37185 L .49477 .38075 L 0 .25 .282 r
F
.55015 .44044 m .54868 .45326 L .55157 .44164 L 0 .459 .158 r
F
.54725 .45021 m .54868 .45326 L .55015 .44044 L 0 .498 .088 r
F
.33157 .31795 m .33263 .31504 L .33442 .31703 L 0 .032 .132 r
F
.33157 .31795 m .32979 .316 L .33263 .31504 L F
.45795 .33127 m .4592 .32833 L .46086 .33064 L 0 .065 .167 r
F
.45795 .33127 m .45629 .32899 L .4592 .32833 L F
.19339 .31548 m .19425 .31251 L .19617 .31444 L 0 .027 .126 r
F
.19339 .31548 m .19147 .31355 L .19425 .31251 L F
.15884 .31489 m .15964 .31199 L .1616 .31387 L 0 .026 .124 r
F
.15884 .31489 m .15688 .31301 L .15964 .31199 L F
.60953 .32801 m .611 .32481 L .61252 .3268 L 0 .055 .158 r
F
.60953 .32801 m .60801 .32606 L .611 .32481 L F
.26998 .31636 m .27093 .3136 L .27279 .31542 L 0 .029 .129 r
F
.26998 .31636 m .26812 .31452 L .27093 .3136 L F
.61703 .32761 m .6185 .32405 L .62002 .32611 L 0 .053 .156 r
F
.61703 .32761 m .61552 .32557 L .6185 .32405 L F
.39771 .32201 m .39887 .31912 L .40059 .32102 L 0 .041 .143 r
F
.39771 .32201 m .39598 .32016 L .39887 .31912 L F
.84201 .31514 m .84386 .31237 L .84513 .31416 L 0 .026 .125 r
F
.84201 .31514 m .84073 .31334 L .84386 .31237 L F
.56773 .34056 m .56913 .33614 L .57069 .33848 L 0 .09 .188 r
F
.56773 .34056 m .56617 .33816 L .56913 .33614 L F
.12429 .31437 m .12502 .31153 L .12702 .31338 L 0 .025 .123 r
F
.12429 .31437 m .12228 .31251 L .12502 .31153 L F
.55459 .36081 m .553 .35686 L .55593 .3514 L 0 .155 .232 r
F
.55593 .3514 m .55435 .34808 L .5573 .34526 L 0 .124 .212 r
F
.553 .35686 m .55435 .34808 L .55593 .3514 L 0 .144 .224 r
F
.78497 .31585 m .78672 .31287 L .78805 .31474 L 0 .028 .127 r
F
.78497 .31585 m .78363 .31398 L .78672 .31287 L F
.79247 .31545 m .79425 .31268 L .79557 .3145 L 0 .027 .126 r
F
.79247 .31545 m .79114 .31362 L .79425 .31268 L F
.20087 .31525 m .20173 .31236 L .20365 .31421 L F
.20087 .31525 m .19895 .3134 L .20173 .31236 L F
.30451 .31719 m .30552 .31442 L .30733 .31635 L 0 .031 .131 r
F
.30451 .31719 m .30269 .31528 L .30552 .31442 L F
.63499 .32432 m .6365 .32121 L .63798 .32294 L 0 .046 .149 r
F
.63499 .32432 m .6335 .32261 L .6365 .32121 L F
.24291 .31558 m .24383 .31271 L .24571 .31453 L 0 .027 .127 r
F
.24291 .31558 m .24102 .31375 L .24383 .31271 L F
.84953 .315 m .8514 .3122 L .85266 .314 L 0 .026 .125 r
F
.84953 .315 m .84826 .3132 L .8514 .3122 L F
.16631 .3148 m .16709 .31207 L .16905 .3139 L F
.16631 .3148 m .16434 .31297 L .16709 .31207 L F
.27745 .31627 m .27842 .31351 L .28026 .31532 L 0 .029 .129 r
F
.27745 .31627 m .2756 .31446 L .27842 .31351 L F
.58114 .335 m .58257 .33158 L .58411 .33347 L 0 .075 .176 r
F
.58114 .335 m .57959 .33313 L .58257 .33158 L F
.20835 .31504 m .20922 .31217 L .21113 .31402 L 0 .026 .125 r
F
.20835 .31504 m .20643 .31319 L .20922 .31217 L F
.43679 .32524 m .43801 .32255 L .43969 .32459 L 0 .05 .152 r
F
.43679 .32524 m .43511 .3232 L .43801 .32255 L F
.13175 .31422 m .13249 .31141 L .13449 .31323 L 0 .025 .123 r
F
.13175 .31422 m .12975 .3124 L .13249 .31141 L F
.5583 .39791 m .55675 .39807 L .55962 .38704 L 0 .329 .299 r
F
.55675 .39807 m .55806 .38522 L .55962 .38704 L 0 .332 .297 r
F
.59159 .33192 m .59303 .32822 L .59456 .33011 L 0 .066 .167 r
F
.59159 .33192 m .59006 .33009 L .59303 .32822 L F
.67544 .31967 m .67703 .31693 L .67848 .31865 L 0 .036 .138 r
F
.67544 .31967 m .674 .31795 L .67703 .31693 L F
.25039 .31531 m .25132 .31247 L .2532 .3143 L 0 .027 .126 r
F
.25039 .31531 m .24852 .31347 L .25132 .31247 L F
.48819 .34277 m .4895 .33852 L .49112 .34188 L 0 .099 .194 r
F
.48819 .34277 m .48657 .33954 L .4895 .33852 L F
.40519 .32198 m .40636 .31923 L .40807 .32123 L 0 .042 .144 r
F
.40519 .32198 m .40348 .32004 L .40636 .31923 L F
.60204 .32884 m .6035 .32539 L .60502 .32737 L 0 .058 .16 r
F
.60204 .32884 m .60051 .32689 L .6035 .32539 L F
.8 .31535 m .80178 .31256 L .8031 .31435 L 0 .027 .127 r
F
.8 .31535 m .79868 .31355 L .80178 .31256 L F
.85705 .31475 m .85891 .31184 L .86018 .31368 L 0 .026 .125 r
F
.85705 .31475 m .85579 .31293 L .85891 .31184 L F
.48364 .34055 m .48494 .3364 L .48657 .33954 L 0 .092 .189 r
F
.48364 .34055 m .48201 .33752 L .48494 .3364 L F
.36609 .31913 m .3672 .31633 L .36895 .31822 L 0 .035 .136 r
F
.36609 .31913 m .36433 .31725 L .3672 .31633 L F
.33904 .3181 m .34011 .31522 L .34189 .31718 L 0 .033 .134 r
F
.33904 .3181 m .33726 .31612 L .34011 .31522 L F
.69045 .31895 m .69206 .31605 L .69349 .31786 L 0 .035 .136 r
F
.69045 .31895 m .68902 .31717 L .69206 .31605 L F
.68295 .31937 m .68455 .31653 L .68598 .31828 L 0 .036 .137 r
F
.68295 .31937 m .68151 .31764 L .68455 .31653 L F
.80751 .31505 m .8093 .31216 L .81061 .31396 L 0 .027 .126 r
F
.80751 .31505 m .8062 .31326 L .8093 .31216 L F
.65295 .32109 m .65449 .31801 L .65596 .31993 L 0 .039 .141 r
F
.65295 .32109 m .65148 .31921 L .65449 .31801 L F
.69795 .31862 m .69957 .31566 L .701 .31755 L 0 .034 .135 r
F
.69795 .31862 m .69653 .31676 L .69957 .31566 L F
.38563 .3207 m .38677 .31802 L .3885 .31996 L 0 .039 .141 r
F
.38563 .3207 m .3839 .31875 L .38677 .31802 L F
.13922 .31408 m .13997 .31127 L .14196 .3131 L 0 .025 .124 r
F
.13922 .31408 m .13723 .31225 L .13997 .31127 L F
.6275 .3251 m .629 .32198 L .6305 .32386 L 0 .049 .151 r
F
.6275 .3251 m .626 .32323 L .629 .32198 L F
.50835 .45367 m .50956 .47731 L .51122 .46908 L 0 .535 .008 r
F
.50835 .45367 m .50669 .46017 L .50956 .47731 L F
.41723 .32407 m .41843 .32092 L .42013 .32309 L 0 .046 .149 r
F
.41723 .32407 m .41554 .32187 L .41843 .32092 L F
.21582 .31492 m .2167 .31203 L .21861 .31392 L 0 .026 .126 r
F
.21582 .31492 m .21392 .31302 L .2167 .31203 L F
.81502 .31476 m .81683 .31198 L .81814 .31381 L 0 .026 .125 r
F
.81502 .31476 m .81372 .31295 L .81683 .31198 L F
.17376 .31476 m .17458 .31186 L .17653 .31368 L F
.17376 .31476 m .17181 .31294 L .17458 .31186 L F
.57069 .33848 m .5721 .33432 L .57366 .33665 L 0 .085 .184 r
F
.57069 .33848 m .56913 .33614 L .5721 .33432 L F
.66045 .3208 m .66201 .31778 L .66348 .31975 L 0 .039 .141 r
F
.66045 .3208 m .65899 .31885 L .66201 .31778 L F
.47908 .33849 m .48038 .33483 L .48201 .33752 L 0 .087 .185 r
F
.47908 .33849 m .47745 .33582 L .48038 .33483 L F
.66796 .3204 m .66952 .3172 L .67097 .31913 L 0 .038 .139 r
F
.66796 .3204 m .6665 .31848 L .66952 .3172 L F
.28492 .31624 m .28589 .31355 L .28773 .31538 L 0 .03 .129 r
F
.28492 .31624 m .28308 .31442 L .28589 .31355 L F
.49231 .40951 m .49076 .39885 L .49361 .40672 L 0 .38 .26 r
F
.49076 .39885 m .49207 .39545 L .49361 .40672 L 0 .343 .29 r
F
.55489 .37856 m .55329 .37381 L .55618 .36474 L 0 .238 .276 r
F
.55329 .37381 m .55459 .36081 L .55618 .36474 L 0 .217 .266 r
F
.86458 .31461 m .86647 .3118 L .86773 .31368 L 0 .026 .125 r
F
.86458 .31461 m .86332 .31271 L .86647 .3118 L F
.45338 .32983 m .45464 .32654 L .45629 .32899 L 0 .061 .163 r
F
.45338 .32983 m .45172 .32734 L .45464 .32654 L F
.31197 .31738 m .31299 .31453 L .3148 .31639 L 0 .032 .132 r
F
.31197 .31738 m .31015 .3155 L .31299 .31453 L F
.25786 .3153 m .2588 .31251 L .26066 .31442 L 0 .028 .127 r
F
.25786 .3153 m .256 .31341 L .2588 .31251 L F
.18125 .31448 m .18208 .31159 L .18401 .3135 L 0 .026 .125 r
F
.18125 .31448 m .17931 .3126 L .18208 .31159 L F
.70547 .31847 m .7071 .3156 L .70852 .31754 L 0 .034 .135 r
F
.70547 .31847 m .70405 .31655 L .7071 .3156 L F
.34652 .31806 m .3476 .31511 L .34938 .31699 L 0 .033 .134 r
F
.34652 .31806 m .34474 .31616 L .3476 .31511 L F
.47453 .33637 m .47581 .33315 L .47745 .33582 L 0 .081 .181 r
F
.47453 .33637 m .47289 .33372 L .47581 .33315 L F
.72048 .31772 m .72213 .31482 L .72353 .31657 L 0 .033 .133 r
F
.72048 .31772 m .71908 .31598 L .72213 .31482 L F
.5022 .44673 m .50338 .4647 L .50504 .46243 L 0 .507 .068 r
F
.5022 .44673 m .50055 .44827 L .50338 .4647 L F
.22329 .31482 m .22419 .31183 L .22609 .31377 L 0 .026 .126 r
F
.22329 .31482 m .2214 .31291 L .22419 .31183 L F
.37357 .3192 m .37468 .31645 L .37643 .31838 L 0 .036 .137 r
F
.37357 .3192 m .37182 .31731 L .37468 .31645 L F
.72798 .31734 m .72965 .31455 L .73104 .31635 L 0 .032 .133 r
F
.72798 .31734 m .72659 .31556 L .72965 .31455 L F
.64546 .32193 m .64699 .31873 L .64847 .32057 L 0 .042 .144 r
F
.64546 .32193 m .64399 .32014 L .64699 .31873 L F
.11212 .3134 m .11283 .31057 L .11484 .31247 L 0 .024 .122 r
F
.11212 .3134 m .11011 .31153 L .11283 .31057 L F
.49432 .35106 m .49273 .34566 L .49566 .34479 L 0 .126 .213 r
F
.49273 .34566 m .49405 .34087 L .49566 .34479 L 0 .109 .202 r
F
.49273 .34566 m .49112 .34188 L .49405 .34087 L F
.14667 .31405 m .14744 .31123 L .14941 .31312 L 0 .025 .124 r
F
.14667 .31405 m .1447 .31216 L .14744 .31123 L F
.31945 .31718 m .32049 .31427 L .3223 .3161 L 0 .031 .132 r
F
.31945 .31718 m .31765 .31533 L .32049 .31427 L F
.82256 .31471 m .82437 .31186 L .82567 .31372 L 0 .027 .126 r
F
.82256 .31471 m .82125 .31286 L .82437 .31186 L F
.35401 .31784 m .35509 .31518 L .35686 .31704 L 0 .033 .134 r
F
.35401 .31784 m .35224 .31597 L .35509 .31518 L F
.46998 .33428 m .47125 .33121 L .47289 .33372 L 0 .075 .176 r
F
.46998 .33428 m .46833 .33179 L .47125 .33121 L F
.74299 .31661 m .74468 .31367 L .74606 .31559 L 0 .03 .131 r
F
.74299 .31661 m .74161 .31473 L .74468 .31367 L F
.73549 .31706 m .73716 .31403 L .73855 .3159 L 0 .031 .132 r
F
.73549 .31706 m .7341 .31523 L .73716 .31403 L F
.71299 .31836 m .71463 .31544 L .71603 .31718 L 0 .034 .135 r
F
.71299 .31836 m .71158 .31662 L .71463 .31544 L F
.42472 .32419 m .42593 .32108 L .42762 .32316 L 0 .047 .15 r
F
.42472 .32419 m .42302 .32211 L .42593 .32108 L F
.23077 .31465 m .23168 .31174 L .23356 .3137 L 0 .027 .126 r
F
.23077 .31465 m .22888 .31271 L .23168 .31174 L F
.62002 .32611 m .6215 .32254 L .623 .32461 L 0 .051 .154 r
F
.62002 .32611 m .6185 .32405 L .6215 .32254 L F
.18871 .31448 m .18954 .3116 L .19147 .31355 L 0 .026 .125 r
F
.18871 .31448 m .18678 .31255 L .18954 .3116 L F
.32694 .31698 m .328 .31404 L .32979 .316 L 0 .031 .132 r
F
.32694 .31698 m .32515 .31507 L .328 .31404 L F
.29238 .31637 m .29338 .31346 L .29521 .31536 L 0 .03 .13 r
F
.29238 .31637 m .29055 .31451 L .29338 .31346 L F
.59456 .33011 m .596 .32646 L .59753 .32839 L 0 .062 .164 r
F
.59456 .33011 m .59303 .32822 L .596 .32646 L F
.77301 .31513 m .77475 .31231 L .7761 .31415 L 0 .028 .127 r
F
.77301 .31513 m .77166 .31331 L .77475 .31231 L F
.75051 .31641 m .75221 .31352 L .75358 .31535 L 0 .03 .13 r
F
.75051 .31641 m .74913 .31457 L .75221 .31352 L F
.76551 .31558 m .76723 .31264 L .76859 .31443 L 0 .028 .128 r
F
.76551 .31558 m .76416 .3138 L .76723 .31264 L F
.83008 .31458 m .83191 .31173 L .8332 .31356 L 0 .027 .126 r
F
.83008 .31458 m .82879 .31272 L .83191 .31173 L F
.75801 .31605 m .75973 .31317 L .76109 .31495 L 0 .03 .13 r
F
.75801 .31605 m .75665 .31426 L .75973 .31317 L F
.26532 .31544 m .26627 .31259 L .26812 .31452 L 0 .028 .128 r
F
.26532 .31544 m .26346 .31351 L .26627 .31259 L F
.44882 .32815 m .45007 .32484 L .45172 .32734 L 0 .058 .16 r
F
.44882 .32815 m .44716 .32562 L .45007 .32484 L F
.3931 .3211 m .39425 .31827 L .39598 .32016 L 0 .041 .143 r
F
.3931 .3211 m .39137 .31922 L .39425 .31827 L F
.49592 .35647 m .49432 .35106 L .49726 .35045 L 0 .15 .229 r
F
.49432 .35106 m .49566 .34479 L .49726 .35045 L 0 .126 .213 r
F
.15413 .31404 m .15492 .31109 L .15688 .31301 L 0 .026 .124 r
F
.15413 .31404 m .15216 .31214 L .15492 .31109 L F
.46542 .33237 m .46668 .32941 L .46833 .33179 L 0 .071 .172 r
F
.46542 .33237 m .46377 .33002 L .46668 .32941 L F
.11956 .31345 m .12029 .31058 L .12228 .31251 L 0 .025 .123 r
F
.11956 .31345 m .11756 .31153 L .12029 .31058 L F
.61252 .3268 m .614 .32353 L .61552 .32557 L 0 .054 .157 r
F
.61252 .3268 m .611 .32481 L .614 .32353 L F
.58411 .33347 m .58554 .33002 L .58708 .33193 L 0 .073 .174 r
F
.58411 .33347 m .58257 .33158 L .58554 .33002 L F
.56025 .34243 m .56164 .33775 L .56321 .34022 L 0 .099 .194 r
F
.56025 .34243 m .55868 .33984 L .56164 .33775 L F
.5573 .34526 m .55868 .33984 L .56025 .34243 L 0 .107 .2 r
F
.43221 .32413 m .43342 .32116 L .43511 .3232 L 0 .048 .151 r
F
.43221 .32413 m .43052 .32212 L .43342 .32116 L F
.41265 .32269 m .41384 .31967 L .41554 .32187 L 0 .044 .147 r
F
.41265 .32269 m .41095 .32049 L .41384 .31967 L F
.83761 .31437 m .83945 .31153 L .84073 .31334 L 0 .027 .126 r
F
.83761 .31437 m .83632 .31255 L .83945 .31153 L F
.29986 .31625 m .30087 .31332 L .30269 .31528 L 0 .03 .13 r
F
.29986 .31625 m .29804 .31432 L .30087 .31332 L F
.57366 .33665 m .57507 .3325 L .57662 .33482 L 0 .081 .181 r
F
.57366 .33665 m .5721 .33432 L .57507 .3325 L F
.78054 .31503 m .78229 .31211 L .78363 .31398 L 0 .028 .127 r
F
.78054 .31503 m .7792 .31317 L .78229 .31211 L F
.63798 .32294 m .6395 .31978 L .64098 .32154 L 0 .045 .147 r
F
.63798 .32294 m .6365 .32121 L .6395 .31978 L F
.19617 .31444 m .19703 .31147 L .19895 .3134 L 0 .027 .126 r
F
.19617 .31444 m .19425 .31251 L .19703 .31147 L F
.23823 .31466 m .23913 .31192 L .24102 .31375 L 0 .027 .127 r
F
.23823 .31466 m .23635 .31281 L .23913 .31192 L F
.5573 .34526 m .55572 .3423 L .55868 .33984 L 0 .107 .2 r
F
.55435 .34808 m .55572 .3423 L .5573 .34526 L 0 .116 .207 r
F
.60502 .32737 m .60649 .32404 L .60801 .32606 L 0 .056 .158 r
F
.60502 .32737 m .6035 .32539 L .60649 .32404 L F
.1616 .31387 m .16239 .31107 L .16434 .31297 L 0 .026 .125 r
F
.1616 .31387 m .15964 .31199 L .16239 .31107 L F
.33442 .31703 m .33548 .31413 L .33726 .31612 L 0 .032 .133 r
F
.33442 .31703 m .33263 .31504 L .33548 .31413 L F
.78805 .31474 m .78981 .31175 L .79114 .31362 L 0 .027 .127 r
F
.78805 .31474 m .78672 .31287 L .78981 .31175 L F
.38103 .31953 m .38216 .31679 L .3839 .31875 L 0 .038 .139 r
F
.38103 .31953 m .37929 .31757 L .38216 .31679 L F
.49612 .374 m .49457 .36409 L .49749 .36509 L 0 .238 .276 r
F
.49321 .37185 m .49457 .36409 L .49612 .374 L 0 .217 .266 r
F
.49457 .36409 m .49592 .35647 L .49749 .36509 L 0 .179 .245 r
F
.40059 .32102 m .40176 .3181 L .40348 .32004 L 0 .041 .143 r
F
.40059 .32102 m .39887 .31912 L .40176 .3181 L F
.36147 .31811 m .36257 .31537 L .36433 .31725 L 0 .035 .136 r
F
.36147 .31811 m .35971 .31623 L .36257 .31537 L F
.553 .35686 m .55141 .35283 L .55435 .34808 L 0 .144 .224 r
F
.55435 .34808 m .55276 .34477 L .55572 .3423 L 0 .116 .207 r
F
.55141 .35283 m .55276 .34477 L .55435 .34808 L 0 .132 .217 r
F
.84513 .31416 m .84699 .3114 L .84826 .3132 L 0 .026 .126 r
F
.84513 .31416 m .84386 .31237 L .84699 .3114 L F
.27279 .31542 m .27375 .31263 L .2756 .31446 L 0 .029 .129 r
F
.27279 .31542 m .27093 .3136 L .27375 .31263 L F
.55329 .37381 m .55169 .36886 L .55459 .36081 L 0 .217 .266 r
F
.55169 .36886 m .553 .35686 L .55459 .36081 L 0 .197 .255 r
F
.49477 .38075 m .49321 .37185 L .49612 .374 L 0 .282 .296 r
F
.20365 .31421 m .20451 .31134 L .20643 .31319 L 0 .026 .126 r
F
.20365 .31421 m .20173 .31236 L .20451 .31134 L F
.12702 .31338 m .12775 .31055 L .12975 .3124 L 0 .025 .124 r
F
.12702 .31338 m .12502 .31153 L .12775 .31055 L F
.49749 .36509 m .49592 .35647 L .49885 .35612 L 0 .188 .25 r
F
.49592 .35647 m .49726 .35045 L .49885 .35612 L 0 .15 .229 r
F
.522 .46177 m .52333 .48625 L .52495 .47143 L .05 .559 0 r
F
.522 .46177 m .52037 .47472 L .52333 .48625 L F
.44425 .32634 m .44549 .32324 L .44716 .32562 L 0 .054 .157 r
F
.44425 .32634 m .44259 .32394 L .44549 .32324 L F
.79557 .3145 m .79736 .31175 L .79868 .31355 L 0 .027 .127 r
F
.79557 .3145 m .79425 .31268 L .79736 .31175 L F
.24571 .31453 m .24664 .31166 L .24852 .31347 L F
.24571 .31453 m .24383 .31271 L .24664 .31166 L F
.56321 .34022 m .5646 .33576 L .56617 .33816 L 0 .093 .19 r
F
.56321 .34022 m .56164 .33775 L .5646 .33576 L F
.46086 .33064 m .46212 .32767 L .46377 .33002 L 0 .067 .168 r
F
.46086 .33064 m .4592 .32833 L .46212 .32767 L F
.85266 .314 m .85452 .3111 L .85579 .31293 L 0 .026 .125 r
F
.85266 .314 m .8514 .3122 L .85452 .3111 L F
.21113 .31402 m .212 .31118 L .21392 .31302 L F
.21113 .31402 m .20922 .31217 L .212 .31118 L F
.30733 .31635 m .30834 .31356 L .31015 .3155 L 0 .031 .132 r
F
.30733 .31635 m .30552 .31442 L .30834 .31356 L F
.13449 .31323 m .13523 .31042 L .13723 .31225 L 0 .025 .124 r
F
.13449 .31323 m .13249 .31141 L .13523 .31042 L F
.28026 .31532 m .28123 .3126 L .28308 .31442 L 0 .029 .129 r
F
.28026 .31532 m .27842 .31351 L .28123 .3126 L F
.67848 .31865 m .68007 .31591 L .68151 .31764 L 0 .036 .138 r
F
.67848 .31865 m .67703 .31693 L .68007 .31591 L F
.6305 .32386 m .63201 .32073 L .6335 .32261 L 0 .048 .15 r
F
.6305 .32386 m .629 .32198 L .63201 .32073 L F
.2532 .3143 m .25412 .31155 L .256 .31341 L 0 .027 .127 r
F
.2532 .3143 m .25132 .31247 L .25412 .31155 L F
.65596 .31993 m .65751 .3169 L .65899 .31885 L 0 .039 .141 r
F
.65596 .31993 m .65449 .31801 L .65751 .3169 L F
.86018 .31368 m .86205 .31086 L .86332 .31271 L 0 .026 .125 r
F
.86018 .31368 m .85891 .31184 L .86205 .31086 L F
.16905 .3139 m .16985 .31111 L .17181 .31294 L F
.16905 .3139 m .16709 .31207 L .16985 .31111 L F
.69349 .31786 m .6951 .31491 L .69653 .31676 L 0 .034 .135 r
F
.69349 .31786 m .69206 .31605 L .6951 .31491 L F
.68598 .31828 m .68758 .31539 L .68902 .31717 L 0 .035 .137 r
F
.68598 .31828 m .68455 .31653 L .68758 .31539 L F
.67097 .31913 m .67254 .31601 L .674 .31795 L 0 .037 .138 r
F
.67097 .31913 m .66952 .3172 L .67254 .31601 L F
.8031 .31435 m .80488 .31148 L .8062 .31326 L 0 .027 .126 r
F
.8031 .31435 m .80178 .31256 L .80488 .31148 L F
.48657 .33954 m .48788 .33526 L .4895 .33852 L 0 .092 .189 r
F
.48657 .33954 m .48494 .3364 L .48788 .33526 L F
.81061 .31396 m .81241 .31114 L .81372 .31295 L 0 .027 .126 r
F
.81061 .31396 m .8093 .31216 L .81241 .31114 L F
.49112 .34188 m .49244 .33742 L .49405 .34087 L 0 .099 .195 r
F
.49112 .34188 m .4895 .33852 L .49244 .33742 L F
.701 .31755 m .70262 .31462 L .70405 .31655 L 0 .034 .135 r
F
.701 .31755 m .69957 .31566 L .70262 .31462 L F
.59753 .32839 m .59899 .32493 L .60051 .32689 L 0 .059 .162 r
F
.59753 .32839 m .596 .32646 L .59899 .32493 L F
.36895 .31822 m .37006 .31542 L .37182 .31731 L 0 .036 .137 r
F
.36895 .31822 m .3672 .31633 L .37006 .31542 L F
.34189 .31718 m .34296 .3142 L .34474 .31616 L 0 .033 .134 r
F
.34189 .31718 m .34011 .31522 L .34296 .3142 L F
.17653 .31368 m .17736 .31077 L .17931 .3126 L 0 .026 .125 r
F
.17653 .31368 m .17458 .31186 L .17736 .31077 L F
.64847 .32057 m .65 .31733 L .65148 .31921 L 0 .04 .142 r
F
.64847 .32057 m .64699 .31873 L .65 .31733 L F
.21861 .31392 m .21949 .31102 L .2214 .31291 L 0 .027 .126 r
F
.21861 .31392 m .2167 .31203 L .21949 .31102 L F
.66348 .31975 m .66503 .31649 L .6665 .31848 L 0 .038 .14 r
F
.66348 .31975 m .66201 .31778 L .66503 .31649 L F
.42013 .32309 m .42133 .31997 L .42302 .32211 L 0 .046 .149 r
F
.42013 .32309 m .41843 .32092 L .42133 .31997 L F
.14196 .3131 m .14271 .31033 L .1447 .31216 L 0 .025 .124 r
F
.14196 .3131 m .13997 .31127 L .14271 .31033 L F
.40807 .32123 m .40924 .31841 L .41095 .32049 L 0 .043 .145 r
F
.40807 .32123 m .40636 .31923 L .40924 .31841 L F
.43969 .32459 m .44091 .32189 L .44259 .32394 L 0 .051 .154 r
F
.43969 .32459 m .43801 .32255 L .44091 .32189 L F
.623 .32461 m .62449 .32115 L .626 .32323 L 0 .05 .152 r
F
.623 .32461 m .6215 .32254 L .62449 .32115 L F
.57662 .33482 m .57804 .33083 L .57959 .33313 L 0 .077 .177 r
F
.57662 .33482 m .57507 .3325 L .57804 .33083 L F
.48201 .33752 m .48331 .33368 L .48494 .3364 L 0 .086 .185 r
F
.48201 .33752 m .48038 .33483 L .48331 .33368 L F
.81814 .31381 m .81995 .31101 L .82125 .31286 L 0 .027 .126 r
F
.81814 .31381 m .81683 .31198 L .81995 .31101 L F
.72353 .31657 m .72519 .31379 L .72659 .31556 L 0 .032 .133 r
F
.72353 .31657 m .72213 .31482 L .72519 .31379 L F
.34938 .31699 m .35046 .3141 L .35224 .31597 L 0 .033 .134 r
F
.34938 .31699 m .3476 .31511 L .35046 .3141 L F
.86773 .31368 m .86962 .31089 L .87088 .31275 L 0 .026 .125 r
F
.86773 .31368 m .86647 .3118 L .86962 .31089 L F
.3148 .31639 m .31584 .31348 L .31765 .31533 L 0 .032 .132 r
F
.3148 .31639 m .31299 .31453 L .31584 .31348 L F
.5572 .41853 m .55569 .42391 L .55854 .40966 L 0 .387 .254 r
F
.55569 .42391 m .55702 .41317 L .55854 .40966 L 0 .412 .225 r
F
.18401 .3135 m .18484 .31062 L .18678 .31255 L 0 .026 .125 r
F
.18401 .3135 m .18208 .31159 L .18484 .31062 L F
.28773 .31538 m .28871 .31269 L .29055 .31451 L 0 .03 .13 r
F
.28773 .31538 m .28589 .31355 L .28871 .31269 L F
.3885 .31996 m .38964 .31729 L .39137 .31922 L 0 .04 .142 r
F
.3885 .31996 m .38677 .31802 L .38964 .31729 L F
.22609 .31377 m .22699 .31076 L .22888 .31271 L 0 .026 .125 r
F
.22609 .31377 m .22419 .31183 L .22699 .31076 L F
.70852 .31754 m .71016 .31465 L .71158 .31662 L 0 .034 .135 r
F
.70852 .31754 m .7071 .3156 L .71016 .31465 L F
.45629 .32899 m .45755 .32581 L .4592 .32833 L 0 .062 .165 r
F
.45629 .32899 m .45464 .32654 L .45755 .32581 L F
.26066 .31442 m .2616 .31158 L .26346 .31351 L 0 .028 .128 r
F
.26066 .31442 m .2588 .31251 L .2616 .31158 L F
.56617 .33816 m .56757 .3338 L .56913 .33614 L 0 .087 .186 r
F
.56617 .33816 m .5646 .33576 L .56757 .3338 L F
.3223 .3161 m .32334 .31323 L .32515 .31507 L 0 .031 .132 r
F
.3223 .3161 m .32049 .31427 L .32334 .31323 L F
.73855 .3159 m .74022 .31284 L .74161 .31473 L 0 .031 .131 r
F
.73855 .3159 m .73716 .31403 L .74022 .31284 L F
.58708 .33193 m .58852 .32815 L .59006 .33009 L 0 .07 .171 r
F
.58708 .33193 m .58554 .33002 L .58852 .32815 L F
.73104 .31635 m .73271 .3134 L .7341 .31523 L 0 .032 .132 r
F
.73104 .31635 m .72965 .31455 L .73271 .3134 L F
.71603 .31718 m .71768 .31423 L .71908 .31598 L 0 .034 .134 r
F
.71603 .31718 m .71463 .31544 L .71768 .31423 L F
.55583 .42524 m .55434 .43227 L .5572 .41853 L 0 .408 .231 r
F
.55297 .43893 m .55434 .43227 L .55583 .42524 L 0 .459 .158 r
F
.74606 .31559 m .74775 .31261 L .74913 .31457 L 0 .03 .13 r
F
.74606 .31559 m .74468 .31367 L .74775 .31261 L F
.11484 .31247 m .11556 .30962 L .11756 .31153 L 0 .024 .123 r
F
.11484 .31247 m .11283 .31057 L .11556 .30962 L F
.82567 .31372 m .82749 .31086 L .82879 .31272 L 0 .027 .126 r
F
.82567 .31372 m .82437 .31186 L .82749 .31086 L F
.14941 .31312 m .15019 .31023 L .15216 .31214 L 0 .026 .124 r
F
.14941 .31312 m .14744 .31123 L .15019 .31023 L F
.55169 .36886 m .55008 .3639 L .553 .35686 L 0 .197 .255 r
F
.55008 .3639 m .55141 .35283 L .553 .35686 L 0 .177 .244 r
F
.49726 .35045 m .49566 .34479 L .4986 .34391 L 0 .128 .215 r
F
.49566 .34479 m .49699 .33986 L .4986 .34391 L 0 .11 .202 r
F
.49566 .34479 m .49405 .34087 L .49699 .33986 L F
.42762 .32316 m .42883 .32004 L .43052 .32212 L 0 .047 .15 r
F
.42762 .32316 m .42593 .32108 L .42883 .32004 L F
.37643 .31838 m .37755 .31559 L .37929 .31757 L 0 .037 .138 r
F
.37643 .31838 m .37468 .31645 L .37755 .31559 L F
.76859 .31443 m .77031 .31151 L .77166 .31331 L 0 .028 .128 r
F
.76859 .31443 m .76723 .31264 L .77031 .31151 L F
.64098 .32154 m .64251 .31834 L .64399 .32014 L 0 .043 .146 r
F
.64098 .32154 m .6395 .31978 L .64251 .31834 L F
.75358 .31535 m .75528 .31243 L .75665 .31426 L 0 .03 .13 r
F
.75358 .31535 m .75221 .31352 L .75528 .31243 L F
.29521 .31536 m .29622 .31239 L .29804 .31432 L F
.29521 .31536 m .29338 .31346 L .29622 .31239 L F
.76109 .31495 m .7628 .31201 L .76416 .3138 L 0 .029 .129 r
F
.76109 .31495 m .75973 .31317 L .7628 .31201 L F
.23356 .3137 m .23446 .31085 L .23635 .31281 L 0 .027 .126 r
F
.23356 .3137 m .23168 .31174 L .23446 .31085 L F
.61552 .32557 m .61699 .322 L .6185 .32405 L 0 .053 .155 r
F
.61552 .32557 m .614 .32353 L .61699 .322 L F
.35686 .31704 m .35794 .31438 L .35971 .31623 L 0 .034 .135 r
F
.35686 .31704 m .35509 .31518 L .35794 .31438 L F
.32979 .316 m .33084 .31306 L .33263 .31504 L 0 .031 .132 r
F
.32979 .316 m .328 .31404 L .33084 .31306 L F
.7761 .31415 m .77785 .31132 L .7792 .31317 L 0 .028 .127 r
F
.7761 .31415 m .77475 .31231 L .77785 .31132 L F
.47745 .33582 m .47874 .33213 L .48038 .33483 L 0 .082 .182 r
F
.47745 .33582 m .47581 .33315 L .47874 .33213 L F
.19147 .31355 m .19232 .31055 L .19425 .31251 L 0 .026 .126 r
F
.19147 .31355 m .18954 .3116 L .19232 .31055 L F
.8332 .31356 m .83504 .31072 L .83632 .31255 L 0 .027 .126 r
F
.8332 .31356 m .83191 .31173 L .83504 .31072 L F
.60801 .32606 m .60948 .32275 L .611 .32481 L 0 .055 .157 r
F
.60801 .32606 m .60649 .32404 L .60948 .32275 L F
.49415 .42785 m .49258 .41894 L .49541 .43077 L 0 .44 .188 r
F
.49258 .41894 m .49385 .4202 L .49541 .43077 L 0 .408 .231 r
F
.15688 .31301 m .15768 .31005 L .15964 .31199 L 0 .026 .124 r
F
.15688 .31301 m .15492 .31109 L .15768 .31005 L F
.26812 .31452 m .26908 .31165 L .27093 .3136 L 0 .029 .129 r
F
.26812 .31452 m .26627 .31259 L .26908 .31165 L F
.39598 .32016 m .39714 .31722 L .39887 .31912 L 0 .041 .143 r
F
.39598 .32016 m .39425 .31827 L .39714 .31722 L F
.47289 .33372 m .47417 .33063 L .47581 .33315 L 0 .078 .178 r
F
.47289 .33372 m .47125 .33121 L .47417 .33063 L F
.84073 .31334 m .84258 .31056 L .84386 .31237 L 0 .027 .126 r
F
.84073 .31334 m .83945 .31153 L .84258 .31056 L F
.12228 .31251 m .12302 .30961 L .12502 .31153 L 0 .025 .123 r
F
.12228 .31251 m .12029 .31058 L .12302 .30961 L F
.78363 .31398 m .78537 .31098 L .78672 .31287 L 0 .028 .127 r
F
.78363 .31398 m .78229 .31211 L .78537 .31098 L F
.45172 .32734 m .45298 .32406 L .45464 .32654 L 0 .059 .161 r
F
.45172 .32734 m .45007 .32484 L .45298 .32406 L F
.19895 .3134 m .19981 .31043 L .20173 .31236 L 0 .026 .126 r
F
.19895 .3134 m .19703 .31147 L .19981 .31043 L F
.30269 .31528 m .3037 .31242 L .30552 .31442 L 0 .03 .131 r
F
.30269 .31528 m .30087 .31332 L .3037 .31242 L F
.79114 .31362 m .79291 .31081 L .79425 .31268 L 0 .027 .127 r
F
.79114 .31362 m .78981 .31175 L .79291 .31081 L F
.43511 .3232 m .43632 .3205 L .43801 .32255 L 0 .049 .152 r
F
.43511 .3232 m .43342 .32116 L .43632 .3205 L F
.56913 .33614 m .57053 .33199 L .5721 .33432 L 0 .083 .182 r
F
.56913 .33614 m .56757 .3338 L .57053 .33199 L F
.55141 .35283 m .54982 .34881 L .55276 .34477 L 0 .132 .217 r
F
.55276 .34477 m .55414 .3394 L .55572 .3423 L 0 .109 .202 r
F
.55276 .34477 m .55118 .34156 L .55414 .3394 L F
.54982 .34881 m .55118 .34156 L .55276 .34477 L 0 .121 .21 r
F
.41554 .32187 m .41673 .31876 L .41843 .32092 L 0 .045 .147 r
F
.41554 .32187 m .41384 .31967 L .41673 .31876 L F
.24102 .31375 m .24194 .31089 L .24383 .31271 L 0 .028 .127 r
F
.24102 .31375 m .23913 .31192 L .24194 .31089 L F
.57959 .33313 m .58101 .32929 L .58257 .33158 L 0 .074 .175 r
F
.57959 .33313 m .57804 .33083 L .58101 .32929 L F
.60051 .32689 m .60197 .32339 L .6035 .32539 L 0 .057 .16 r
F
.60051 .32689 m .59899 .32493 L .60197 .32339 L F
.55702 .41317 m .55547 .414 L .5583 .39791 L 0 .37 .27 r
F
.55547 .414 m .55675 .39807 L .5583 .39791 L 0 .38 .261 r
F
.40348 .32004 m .40464 .31722 L .40636 .31923 L 0 .041 .143 r
F
.40348 .32004 m .40176 .3181 L .40464 .31722 L F
.55675 .39807 m .55518 .39625 L .55806 .38522 L 0 .332 .297 r
F
.55518 .39625 m .55647 .38189 L .55806 .38522 L 0 .329 .299 r
F
.16434 .31297 m .16513 .31017 L .16709 .31207 L 0 .026 .125 r
F
.16434 .31297 m .16239 .31107 L .16513 .31017 L F
.49885 .35612 m .49726 .35045 L .50019 .34984 L 0 .154 .231 r
F
.49726 .35045 m .4986 .34391 L .50019 .34984 L 0 .128 .215 r
F
.20643 .31319 m .2073 .31031 L .20922 .31217 L 0 .026 .126 r
F
.20643 .31319 m .20451 .31134 L .2073 .31031 L F
.84826 .3132 m .85013 .31039 L .8514 .3122 L 0 .027 .126 r
F
.84826 .3132 m .84699 .3114 L .85013 .31039 L F
.33726 .31612 m .33833 .31323 L .34011 .31522 L 0 .032 .133 r
F
.33726 .31612 m .33548 .31413 L .33833 .31323 L F
.2756 .31446 m .27656 .31166 L .27842 .31351 L 0 .029 .129 r
F
.2756 .31446 m .27375 .31263 L .27656 .31166 L F
.59006 .33009 m .59149 .32626 L .59303 .32822 L 0 .066 .167 r
F
.59006 .33009 m .58852 .32815 L .59149 .32626 L F
.12975 .3124 m .13049 .30956 L .13249 .31141 L 0 .025 .124 r
F
.12975 .3124 m .12775 .31055 L .13049 .30956 L F
.6335 .32261 m .63501 .31932 L .6365 .32121 L 0 .047 .149 r
F
.6335 .32261 m .63201 .32073 L .63501 .31932 L F
.46833 .33179 m .4696 .32882 L .47125 .33121 L 0 .073 .174 r
F
.46833 .33179 m .46668 .32941 L .4696 .32882 L F
.24852 .31347 m .24944 .31066 L .25132 .31247 L 0 .027 .127 r
F
.24852 .31347 m .24664 .31166 L .24944 .31066 L F
.36433 .31725 m .36544 .31446 L .3672 .31633 L 0 .035 .136 r
F
.36433 .31725 m .36257 .31537 L .36544 .31446 L F
.3839 .31875 m .38503 .31608 L .38677 .31802 L 0 .039 .141 r
F
.3839 .31875 m .38216 .31679 L .38503 .31608 L F
.85579 .31293 m .85765 .31001 L .85891 .31184 L 0 .026 .125 r
F
.85579 .31293 m .85452 .3111 L .85765 .31001 L F
.79868 .31355 m .80046 .31077 L .80178 .31256 L 0 .028 .127 r
F
.79868 .31355 m .79736 .31175 L .80046 .31077 L F
.55572 .3423 m .5571 .33723 L .55868 .33984 L 0 .101 .196 r
F
.55572 .3423 m .55414 .3394 L .5571 .33723 L F
.674 .31795 m .67558 .31499 L .67703 .31693 L 0 .037 .138 r
F
.674 .31795 m .67254 .31601 L .67558 .31499 L F
.55434 .43227 m .55569 .42391 L .5572 .41853 L 0 .44 .188 r
F
.65148 .31921 m .65302 .31609 L .65449 .31801 L 0 .039 .141 r
F
.65148 .31921 m .65 .31733 L .65302 .31609 L F
.68902 .31717 m .69062 .31424 L .69206 .31605 L 0 .035 .136 r
F
.68902 .31717 m .68758 .31539 L .69062 .31424 L F
.69653 .31676 m .69814 .31377 L .69957 .31566 L 0 .034 .135 r
F
.69653 .31676 m .6951 .31491 L .69814 .31377 L F
.65899 .31885 m .66054 .3158 L .66201 .31778 L 0 .038 .14 r
F
.65899 .31885 m .65751 .3169 L .66054 .3158 L F
.21392 .31302 m .21479 .31019 L .2167 .31203 L 0 .027 .126 r
F
.21392 .31302 m .212 .31118 L .21479 .31019 L F
.626 .32323 m .6275 .31991 L .629 .32198 L 0 .048 .151 r
F
.626 .32323 m .62449 .32115 L .6275 .31991 L F
.8062 .31326 m .80799 .31039 L .8093 .31216 L 0 .027 .126 r
F
.8062 .31326 m .80488 .31148 L .80799 .31039 L F
.68151 .31764 m .68311 .31478 L .68455 .31653 L 0 .036 .138 r
F
.68151 .31764 m .68007 .31591 L .68311 .31478 L F
.55008 .3639 m .54848 .35892 L .55141 .35283 L 0 .177 .244 r
F
.54848 .35892 m .54982 .34881 L .55141 .35283 L 0 .158 .233 r
F
.6665 .31848 m .66805 .3152 L .66952 .3172 L 0 .037 .139 r
F
.6665 .31848 m .66503 .31649 L .66805 .3152 L F
.13723 .31225 m .13798 .30944 L .13997 .31127 L 0 .025 .124 r
F
.13723 .31225 m .13523 .31042 L .13798 .30944 L F
.4895 .33852 m .49082 .33408 L .49244 .33742 L 0 .091 .188 r
F
.4895 .33852 m .48788 .33526 L .49082 .33408 L F
.44716 .32562 m .4484 .32248 L .45007 .32484 L 0 .055 .158 r
F
.44716 .32562 m .44549 .32324 L .4484 .32248 L F
.86332 .31271 m .86521 .30993 L .86647 .3118 L 0 .026 .125 r
F
.86332 .31271 m .86205 .31086 L .86521 .30993 L F
.17181 .31294 m .17262 .31003 L .17458 .31186 L F
.17181 .31294 m .16985 .31111 L .17262 .31003 L F
.81372 .31295 m .81552 .31015 L .81683 .31198 L 0 .027 .126 r
F
.81372 .31295 m .81241 .31114 L .81552 .31015 L F
.28308 .31442 m .28405 .31174 L .28589 .31355 L 0 .03 .13 r
F
.28308 .31442 m .28123 .3126 L .28405 .31174 L F
.49405 .34087 m .49538 .33632 L .49699 .33986 L 0 .099 .194 r
F
.49405 .34087 m .49244 .33742 L .49538 .33632 L F
.55868 .33984 m .56006 .33525 L .56164 .33775 L 0 .095 .191 r
F
.55868 .33984 m .5571 .33723 L .56006 .33525 L F
.256 .31341 m .25693 .31064 L .2588 .31251 L 0 .028 .127 r
F
.256 .31341 m .25412 .31155 L .25693 .31064 L F
.31015 .3155 m .31118 .31259 L .31299 .31453 L 0 .032 .132 r
F
.31015 .3155 m .30834 .31356 L .31118 .31259 L F
.70405 .31655 m .70568 .31365 L .7071 .3156 L 0 .034 .135 r
F
.70405 .31655 m .70262 .31462 L .70568 .31365 L F
.17931 .3126 m .18013 .30975 L .18208 .31159 L 0 .026 .125 r
F
.17931 .3126 m .17736 .31077 L .18013 .30975 L F
.34474 .31616 m .34583 .31315 L .3476 .31511 L 0 .033 .134 r
F
.34474 .31616 m .34296 .3142 L .34583 .31315 L F
.48494 .3364 m .48625 .33252 L .48788 .33526 L 0 .086 .184 r
F
.48494 .3364 m .48331 .33368 L .48625 .33252 L F
.2214 .31291 m .22229 .30993 L .22419 .31183 L 0 .026 .126 r
F
.2214 .31291 m .21949 .31102 L .22229 .30993 L F
.37182 .31731 m .37293 .31451 L .37468 .31645 L 0 .036 .137 r
F
.37182 .31731 m .37006 .31542 L .37293 .31451 L F
.42302 .32211 m .42423 .31895 L .42593 .32108 L 0 .046 .149 r
F
.42302 .32211 m .42133 .31997 L .42423 .31895 L F
.46377 .33002 m .46503 .32703 L .46668 .32941 L 0 .068 .17 r
F
.46377 .33002 m .46212 .32767 L .46503 .32703 L F
.11011 .31153 m .11081 .30872 L .11283 .31057 L 0 .024 .122 r
F
.11011 .31153 m .10809 .30969 L .11081 .30872 L F
.1447 .31216 m .14545 .30939 L .14744 .31123 L 0 .025 .124 r
F
.1447 .31216 m .14271 .31033 L .14545 .30939 L F
.50042 .36514 m .49885 .35612 L .50179 .35578 L 0 .195 .254 r
F
.49749 .36509 m .49885 .35612 L .50042 .36514 L 0 .188 .25 r
F
.49885 .35612 m .50019 .34984 L .50179 .35578 L 0 .154 .231 r
F
.6185 .32405 m .61998 .32046 L .6215 .32254 L 0 .051 .153 r
F
.6185 .32405 m .61699 .322 L .61998 .32046 L F
.31765 .31533 m .31868 .31243 L .32049 .31427 L 0 .032 .132 r
F
.31765 .31533 m .31584 .31348 L .31868 .31243 L F
.64399 .32014 m .64551 .31689 L .64699 .31873 L 0 .042 .144 r
F
.64399 .32014 m .64251 .31834 L .64551 .31689 L F
.35224 .31597 m .35332 .31332 L .35509 .31518 L 0 .033 .134 r
F
.35224 .31597 m .35046 .3141 L .35332 .31332 L F
.72659 .31556 m .72826 .31275 L .72965 .31455 L 0 .032 .133 r
F
.72659 .31556 m .72519 .31379 L .72826 .31275 L F
.71908 .31598 m .72073 .31306 L .72213 .31482 L 0 .033 .134 r
F
.71908 .31598 m .71768 .31423 L .72073 .31306 L F
.82125 .31286 m .82307 .31 L .82437 .31186 L 0 .027 .126 r
F
.82125 .31286 m .81995 .31101 L .82307 .31 L F
.74161 .31473 m .74329 .31175 L .74468 .31367 L 0 .03 .13 r
F
.74161 .31473 m .74022 .31284 L .74329 .31175 L F
.5721 .33432 m .57351 .33018 L .57507 .3325 L 0 .079 .179 r
F
.5721 .33432 m .57053 .33199 L .57351 .33018 L F
.22888 .31271 m .22979 .30978 L .23168 .31174 L 0 .026 .125 r
F
.22888 .31271 m .22699 .31076 L .22979 .30978 L F
.7341 .31523 m .73577 .31219 L .73716 .31403 L 0 .031 .132 r
F
.7341 .31523 m .73271 .3134 L .73577 .31219 L F
.18678 .31255 m .18761 .30964 L .18954 .3116 L 0 .026 .125 r
F
.18678 .31255 m .18484 .31062 L .18761 .30964 L F
.32515 .31507 m .32619 .31219 L .328 .31404 L 0 .031 .132 r
F
.32515 .31507 m .32334 .31323 L .32619 .31219 L F
.41095 .32049 m .41213 .31756 L .41384 .31967 L 0 .043 .146 r
F
.41095 .32049 m .40924 .31841 L .41213 .31756 L F
.59303 .32822 m .59447 .32448 L .596 .32646 L 0 .062 .164 r
F
.59303 .32822 m .59149 .32626 L .59447 .32448 L F
.29055 .31451 m .29154 .31163 L .29338 .31346 L 0 .03 .13 r
F
.29055 .31451 m .28871 .31269 L .29154 .31163 L F
.71158 .31662 m .71321 .31346 L .71463 .31544 L 0 .034 .135 r
F
.71158 .31662 m .71016 .31465 L .71321 .31346 L F
.5295 .4641 m .53091 .48438 L .53247 .46721 L .056 .562 0 r
F
.5295 .4641 m .52792 .48047 L .53091 .48438 L F
.26346 .31351 m .26441 .31065 L .26627 .31259 L 0 .028 .128 r
F
.26346 .31351 m .2616 .31158 L .26441 .31065 L F
.77166 .31331 m .77341 .3105 L .77475 .31231 L F
.77166 .31331 m .77031 .31151 L .77341 .3105 L F
.74913 .31457 m .75083 .31154 L .75221 .31352 L 0 .03 .13 r
F
.74913 .31457 m .74775 .31261 L .75083 .31154 L F
.44259 .32394 m .44381 .32118 L .44549 .32324 L 0 .053 .155 r
F
.44259 .32394 m .44091 .32189 L .44381 .32118 L F
.82879 .31272 m .83062 .30985 L .83191 .31173 L 0 .027 .126 r
F
.82879 .31272 m .82749 .31086 L .83062 .30985 L F
.611 .32481 m .61248 .32144 L .614 .32353 L 0 .054 .156 r
F
.611 .32481 m .60948 .32275 L .61248 .32144 L F
.43052 .32212 m .43174 .31907 L .43342 .32116 L 0 .047 .15 r
F
.43052 .32212 m .42883 .32004 L .43174 .31907 L F
.56164 .33775 m .56303 .33332 L .5646 .33576 L 0 .09 .187 r
F
.56164 .33775 m .56006 .33525 L .56303 .33332 L F
.76416 .3138 m .76588 .31085 L .76723 .31264 L 0 .029 .129 r
F
.76416 .3138 m .7628 .31201 L .76588 .31085 L F
.15216 .31214 m .15295 .30916 L .15492 .31109 L 0 .026 .124 r
F
.15216 .31214 m .15019 .31023 L .15295 .30916 L F
.39137 .31922 m .39252 .31635 L .39425 .31827 L 0 .041 .143 r
F
.39137 .31922 m .38964 .31729 L .39252 .31635 L F
.11756 .31153 m .11829 .30865 L .12029 .31058 L 0 .025 .123 r
F
.11756 .31153 m .11556 .30962 L .11829 .30865 L F
.75665 .31426 m .75836 .31134 L .75973 .31317 L 0 .03 .13 r
F
.75665 .31426 m .75528 .31243 L .75836 .31134 L F
.58257 .33158 m .58399 .32775 L .58554 .33002 L 0 .072 .173 r
F
.58257 .33158 m .58101 .32929 L .58399 .32775 L F
.29804 .31432 m .29905 .31135 L .30087 .31332 L 0 .03 .13 r
F
.29804 .31432 m .29622 .31239 L .29905 .31135 L F
.50019 .34984 m .4986 .34391 L .50154 .34291 L 0 .129 .215 r
F
.4986 .34391 m .49993 .33886 L .50154 .34291 L 0 .11 .202 r
F
.4986 .34391 m .49699 .33986 L .49993 .33886 L F
.6035 .32539 m .60496 .32201 L .60649 .32404 L 0 .055 .158 r
F
.6035 .32539 m .60197 .32339 L .60496 .32201 L F
.4592 .32833 m .46047 .32509 L .46212 .32767 L 0 .064 .166 r
F
.4592 .32833 m .45755 .32581 L .46047 .32509 L F
.19425 .31251 m .19511 .3095 L .19703 .31147 L 0 .026 .125 r
F
.19425 .31251 m .19232 .31055 L .19511 .3095 L F
.51288 .46022 m .51413 .48466 L .51579 .47393 L .05 .559 0 r
F
.51288 .46022 m .51122 .46908 L .51413 .48466 L F
.48038 .33483 m .48168 .33095 L .48331 .33368 L 0 .082 .181 r
F
.48038 .33483 m .47874 .33213 L .48168 .33095 L F
.33263 .31504 m .33369 .31214 L .33548 .31413 L 0 .032 .132 r
F
.33263 .31504 m .33084 .31306 L .33369 .31214 L F
.83632 .31255 m .83817 .30972 L .83945 .31153 L 0 .027 .126 r
F
.83632 .31255 m .83504 .31072 L .83817 .30972 L F
.7792 .31317 m .78094 .31023 L .78229 .31211 L 0 .028 .127 r
F
.7792 .31317 m .77785 .31132 L .78094 .31023 L F
.54848 .35892 m .54688 .35394 L .54982 .34881 L 0 .158 .233 r
F
.54982 .34881 m .54823 .34499 L .55118 .34156 L 0 .121 .21 r
F
.54688 .35394 m .54823 .34499 L .54982 .34881 L 0 .141 .223 r
F
.37929 .31757 m .38042 .31476 L .38216 .31679 L 0 .037 .139 r
F
.37929 .31757 m .37755 .31559 L .38042 .31476 L F
.23635 .31281 m .23725 .30995 L .23913 .31192 L 0 .027 .127 r
F
.23635 .31281 m .23446 .31085 L .23725 .30995 L F
.15964 .31199 m .16043 .30911 L .16239 .31107 L 0 .026 .125 r
F
.15964 .31199 m .15768 .31005 L .16043 .30911 L F
.78672 .31287 m .78846 .30984 L .78981 .31175 L 0 .027 .127 r
F
.78672 .31287 m .78537 .31098 L .78846 .30984 L F
.39887 .31912 m .40003 .31618 L .40176 .3181 L 0 .041 .143 r
F
.39887 .31912 m .39714 .31722 L .40003 .31618 L F
.6365 .32121 m .63801 .31789 L .6395 .31978 L 0 .045 .147 r
F
.6365 .32121 m .63501 .31932 L .63801 .31789 L F
.35971 .31623 m .3608 .31355 L .36257 .31537 L 0 .035 .136 r
F
.35971 .31623 m .35794 .31438 L .3608 .31355 L F
.49361 .40672 m .49207 .39545 L .49495 .40166 L 0 .376 .265 r
F
.49207 .39545 m .49341 .38955 L .49495 .40166 L 0 .336 .295 r
F
.27093 .3136 m .2719 .31066 L .27375 .31263 L 0 .029 .129 r
F
.27093 .3136 m .26908 .31165 L .2719 .31066 L F
.12502 .31153 m .12576 .30863 L .12775 .31055 L 0 .025 .124 r
F
.12502 .31153 m .12302 .30961 L .12576 .30863 L F
.20173 .31236 m .2026 .30939 L .20451 .31134 L 0 .026 .126 r
F
.20173 .31236 m .19981 .31043 L .2026 .30939 L F
.84386 .31237 m .84572 .30959 L .84699 .3114 L 0 .027 .126 r
F
.84386 .31237 m .84258 .31056 L .84572 .30959 L F
.79425 .31268 m .79602 .30988 L .79736 .31175 L 0 .027 .127 r
F
.79425 .31268 m .79291 .31081 L .79602 .30988 L F
.57507 .3325 m .57648 .32853 L .57804 .33083 L 0 .075 .176 r
F
.57507 .3325 m .57351 .33018 L .57648 .32853 L F
.24383 .31271 m .24475 .30985 L .24664 .31166 L 0 .027 .127 r
F
.24383 .31271 m .24194 .31089 L .24475 .30985 L F
.55518 .39625 m .55359 .39244 L .55647 .38189 L 0 .329 .299 r
F
.55359 .39244 m .55489 .37856 L .55647 .38189 L 0 .321 .302 r
F
.30552 .31442 m .30654 .31151 L .30834 .31356 L 0 .031 .131 r
F
.30552 .31442 m .3037 .31242 L .30654 .31151 L F
.45464 .32654 m .45589 .32328 L .45755 .32581 L 0 .06 .162 r
F
.45464 .32654 m .45298 .32406 L .45589 .32328 L F
.20922 .31217 m .21008 .30933 L .212 .31118 L 0 .027 .126 r
F
.20922 .31217 m .2073 .31031 L .21008 .30933 L F
.41843 .32092 m .41963 .31784 L .42133 .31997 L 0 .045 .148 r
F
.41843 .32092 m .41673 .31876 L .41963 .31784 L F
.65449 .31801 m .65604 .31495 L .65751 .3169 L 0 .039 .14 r
F
.65449 .31801 m .65302 .31609 L .65604 .31495 L F
.55118 .34156 m .55256 .33652 L .55414 .3394 L 0 .102 .197 r
F
.55118 .34156 m .54959 .33841 L .55256 .33652 L F
.54823 .34499 m .54959 .33841 L .55118 .34156 L 0 .111 .203 r
F
.629 .32198 m .6305 .31867 L .63201 .32073 L 0 .048 .15 r
F
.629 .32198 m .6275 .31991 L .6305 .31867 L F
.8514 .3122 m .85325 .30928 L .85452 .3111 L 0 .027 .126 r
F
.8514 .3122 m .85013 .31039 L .85325 .30928 L F
.66952 .3172 m .67108 .314 L .67254 .31601 L 0 .037 .138 r
F
.66952 .3172 m .66805 .3152 L .67108 .314 L F
.5646 .33576 m .566 .33141 L .56757 .3338 L 0 .085 .183 r
F
.5646 .33576 m .56303 .33332 L .566 .33141 L F
.13249 .31141 m .13324 .30857 L .13523 .31042 L 0 .025 .124 r
F
.13249 .31141 m .13049 .30956 L .13324 .30857 L F
.27842 .31351 m .27938 .31075 L .28123 .3126 L 0 .029 .129 r
F
.27842 .31351 m .27656 .31166 L .27938 .31075 L F
.25132 .31247 m .25224 .30974 L .25412 .31155 L 0 .027 .127 r
F
.25132 .31247 m .24944 .31066 L .25224 .30974 L F
.85891 .31184 m .86079 .309 L .86205 .31086 L 0 .026 .125 r
F
.85891 .31184 m .85765 .31001 L .86079 .309 L F
.16709 .31207 m .16789 .30921 L .16985 .31111 L 0 .026 .126 r
F
.16709 .31207 m .16513 .31017 L .16789 .30921 L F
.596 .32646 m .59745 .32294 L .59899 .32493 L 0 .059 .161 r
F
.596 .32646 m .59447 .32448 L .59745 .32294 L F
.69206 .31605 m .69367 .31307 L .6951 .31491 L 0 .035 .136 r
F
.69206 .31605 m .69062 .31424 L .69367 .31307 L F
.34011 .31522 m .34119 .3122 L .34296 .3142 L 0 .033 .133 r
F
.34011 .31522 m .33833 .31323 L .34119 .3122 L F
.51744 .46316 m .51873 .48726 L .52037 .47472 L .07 .567 0 r
F
.51744 .46316 m .51579 .47393 L .51873 .48726 L F
.47581 .33315 m .4771 .32961 L .47874 .33213 L 0 .079 .179 r
F
.47581 .33315 m .47417 .33063 L .4771 .32961 L F
.6215 .32254 m .62298 .31906 L .62449 .32115 L 0 .049 .151 r
F
.6215 .32254 m .61998 .32046 L .62298 .31906 L F
.69957 .31566 m .70119 .3127 L .70262 .31462 L 0 .034 .135 r
F
.69957 .31566 m .69814 .31377 L .70119 .3127 L F
.43801 .32255 m .43923 .31984 L .44091 .32189 L 0 .05 .153 r
F
.43801 .32255 m .43632 .3205 L .43923 .31984 L F
.67703 .31693 m .67862 .31396 L .68007 .31591 L 0 .037 .138 r
F
.67703 .31693 m .67558 .31499 L .67862 .31396 L F
.40636 .31923 m .40753 .31633 L .40924 .31841 L 0 .042 .144 r
F
.40636 .31923 m .40464 .31722 L .40753 .31633 L F
.80178 .31256 m .80357 .30969 L .80488 .31148 L 0 .027 .127 r
F
.80178 .31256 m .80046 .31077 L .80357 .30969 L F
.66201 .31778 m .66356 .3145 L .66503 .31649 L 0 .038 .14 r
F
.66201 .31778 m .66054 .3158 L .66356 .3145 L F
.68455 .31653 m .68615 .31361 L .68758 .31539 L 0 .036 .137 r
F
.68455 .31653 m .68311 .31478 L .68615 .31361 L F
.8093 .31216 m .8111 .30936 L .81241 .31114 L 0 .027 .126 r
F
.8093 .31216 m .80799 .31039 L .8111 .30936 L F
.3672 .31633 m .3683 .31355 L .37006 .31542 L 0 .036 .137 r
F
.3672 .31633 m .36544 .31446 L .3683 .31355 L F
.49904 .37597 m .49749 .36509 L .50042 .36514 L 0 .254 .284 r
F
.49612 .374 m .49749 .36509 L .49904 .37597 L 0 .238 .276 r
F
.49244 .33742 m .49376 .3329 L .49538 .33632 L 0 .09 .188 r
F
.49244 .33742 m .49082 .33408 L .49376 .3329 L F
.2167 .31203 m .21758 .30918 L .21949 .31102 L 0 .027 .126 r
F
.2167 .31203 m .21479 .31019 L .21758 .30918 L F
.17458 .31186 m .1754 .30894 L .17736 .31077 L 0 .026 .125 r
F
.17458 .31186 m .17262 .31003 L .1754 .30894 L F
.64699 .31873 m .64852 .31544 L .65 .31733 L 0 .04 .142 r
F
.64699 .31873 m .64551 .31689 L .64852 .31544 L F
.13997 .31127 m .14072 .30851 L .14271 .31033 L 0 .025 .124 r
F
.13997 .31127 m .13798 .30944 L .14072 .30851 L F
.50179 .35578 m .50019 .34984 L .50314 .34885 L 0 .156 .232 r
F
.50019 .34984 m .50154 .34291 L .50314 .34885 L 0 .129 .215 r
F
.48788 .33526 m .48919 .33131 L .49082 .33408 L 0 .085 .184 r
F
.48788 .33526 m .48625 .33252 L .48919 .33131 L F
.49699 .33986 m .49832 .33531 L .49993 .33886 L 0 .099 .194 r
F
.49699 .33986 m .49538 .33632 L .49832 .33531 L F
.38677 .31802 m .3879 .31536 L .38964 .31729 L 0 .04 .142 r
F
.38677 .31802 m .38503 .31608 L .3879 .31536 L F
.3476 .31511 m .34869 .31214 L .35046 .3141 L 0 .033 .134 r
F
.3476 .31511 m .34583 .31315 L .34869 .31214 L F
.81683 .31198 m .81864 .30916 L .81995 .31101 L 0 .027 .126 r
F
.81683 .31198 m .81552 .31015 L .81864 .30916 L F
.4963 .39421 m .49477 .38075 L .49768 .38394 L 0 .337 .294 r
F
.49341 .38955 m .49477 .38075 L .4963 .39421 L 0 .317 .304 r
F
.49477 .38075 m .49612 .374 L .49768 .38394 L 0 .282 .296 r
F
.18208 .31159 m .1829 .30876 L .18484 .31062 L 0 .026 .125 r
F
.18208 .31159 m .18013 .30975 L .1829 .30876 L F
.86647 .3118 m .86836 .309 L .86962 .31089 L 0 .026 .126 r
F
.86647 .3118 m .86521 .30993 L .86836 .309 L F
.31299 .31453 m .31403 .31155 L .31584 .31348 L 0 .032 .132 r
F
.31299 .31453 m .31118 .31259 L .31403 .31155 L F
.47125 .33121 m .47253 .32822 L .47417 .33063 L 0 .075 .175 r
F
.47125 .33121 m .4696 .32882 L .47253 .32822 L F
.22419 .31183 m .2251 .30883 L .22699 .31076 L 0 .026 .125 r
F
.22419 .31183 m .22229 .30993 L .2251 .30883 L F
.7071 .3156 m .70874 .31267 L .71016 .31465 L 0 .034 .135 r
F
.7071 .3156 m .70568 .31365 L .70874 .31267 L F
.2588 .31251 m .25974 .30971 L .2616 .31158 L 0 .028 .128 r
F
.2588 .31251 m .25693 .31064 L .25974 .30971 L F
.28589 .31355 m .28686 .31088 L .28871 .31269 L 0 .03 .13 r
F
.28589 .31355 m .28405 .31174 L .28686 .31088 L F
.55414 .3394 m .55552 .33462 L .5571 .33723 L 0 .096 .193 r
F
.55414 .3394 m .55256 .33652 L .55552 .33462 L F
.58554 .33002 m .58697 .32593 L .58852 .32815 L 0 .069 .17 r
F
.58554 .33002 m .58399 .32775 L .58697 .32593 L F
.72213 .31482 m .7238 .31201 L .72519 .31379 L 0 .033 .133 r
F
.72213 .31482 m .72073 .31306 L .7238 .31201 L F
.42593 .32108 m .42714 .31792 L .42883 .32004 L 0 .046 .149 r
F
.42593 .32108 m .42423 .31895 L .42714 .31792 L F
.45007 .32484 m .45131 .32173 L .45298 .32406 L 0 .056 .159 r
F
.45007 .32484 m .4484 .32248 L .45131 .32173 L F
.73716 .31403 m .73883 .31098 L .74022 .31284 L 0 .031 .131 r
F
.73716 .31403 m .73577 .31219 L .73883 .31098 L F
.32049 .31427 m .32154 .31138 L .32334 .31323 L 0 .032 .132 r
F
.32049 .31427 m .31868 .31243 L .32154 .31138 L F
.74468 .31367 m .74636 .31065 L .74775 .31261 L 0 .03 .13 r
F
.74468 .31367 m .74329 .31175 L .74636 .31065 L F
.11283 .31057 m .11354 .30774 L .11556 .30962 L 0 .024 .123 r
F
.11283 .31057 m .11081 .30872 L .11354 .30774 L F
.72965 .31455 m .73132 .31159 L .73271 .3134 L 0 .032 .133 r
F
.72965 .31455 m .72826 .31275 L .73132 .31159 L F
.54688 .35394 m .54528 .34929 L .54823 .34499 L 0 .141 .223 r
F
.54823 .34499 m .54664 .34128 L .54959 .33841 L 0 .111 .203 r
F
.54528 .34929 m .54664 .34128 L .54823 .34499 L 0 .127 .214 r
F
.14744 .31123 m .14821 .30838 L .15019 .31023 L 0 .026 .124 r
F
.14744 .31123 m .14545 .30939 L .14821 .30838 L F
.82437 .31186 m .82619 .30899 L .82749 .31086 L 0 .027 .126 r
F
.82437 .31186 m .82307 .31 L .82619 .30899 L F
.37468 .31645 m .37581 .31359 L .37755 .31559 L 0 .036 .138 r
F
.37468 .31645 m .37293 .31451 L .37581 .31359 L F
.614 .32353 m .61547 .3199 L .61699 .322 L 0 .052 .155 r
F
.614 .32353 m .61248 .32144 L .61547 .3199 L F
.71463 .31544 m .71626 .31224 L .71768 .31423 L 0 .034 .135 r
F
.71463 .31544 m .71321 .31346 L .71626 .31224 L F
.56757 .3338 m .56897 .32963 L .57053 .33199 L 0 .08 .18 r
F
.56757 .3338 m .566 .33141 L .56897 .32963 L F
.23168 .31174 m .23258 .30887 L .23446 .31085 L 0 .027 .126 r
F
.23168 .31174 m .22979 .30978 L .23258 .30887 L F
.60649 .32404 m .60796 .32068 L .60948 .32275 L 0 .054 .157 r
F
.60649 .32404 m .60496 .32201 L .60796 .32068 L F
.328 .31404 m .32905 .3112 L .33084 .31306 L 0 .031 .132 r
F
.328 .31404 m .32619 .31219 L .32905 .3112 L F
.29338 .31346 m .29438 .31054 L .29622 .31239 L 0 .03 .13 r
F
.29338 .31346 m .29154 .31163 L .29438 .31054 L F
.18954 .3116 m .1904 .30859 L .19232 .31055 L 0 .026 .125 r
F
.18954 .3116 m .18761 .30964 L .1904 .30859 L F
.76723 .31264 m .76896 .3097 L .77031 .31151 L 0 .028 .128 r
F
.76723 .31264 m .76588 .31085 L .76896 .3097 L F
.35509 .31518 m .35617 .31253 L .35794 .31438 L 0 .034 .135 r
F
.35509 .31518 m .35332 .31332 L .35617 .31253 L F
.75221 .31352 m .7539 .31045 L .75528 .31243 L 0 .03 .13 r
F
.75221 .31352 m .75083 .31154 L .7539 .31045 L F
.6395 .31978 m .64102 .31645 L .64251 .31834 L 0 .043 .146 r
F
.6395 .31978 m .63801 .31789 L .64102 .31645 L F
.57804 .33083 m .57946 .327 L .58101 .32929 L 0 .072 .173 r
F
.57804 .33083 m .57648 .32853 L .57946 .327 L F
.77475 .31231 m .7765 .30948 L .77785 .31132 L 0 .028 .128 r
F
.77475 .31231 m .77341 .3105 L .7765 .30948 L F
.46668 .32941 m .46795 .32642 L .4696 .32882 L 0 .07 .171 r
F
.46668 .32941 m .46503 .32703 L .46795 .32642 L F
.75973 .31317 m .76144 .31019 L .7628 .31201 L 0 .03 .13 r
F
.75973 .31317 m .75836 .31134 L .76144 .31019 L F
.15492 .31109 m .15572 .3081 L .15768 .31005 L 0 .025 .124 r
F
.15492 .31109 m .15295 .30916 L .15572 .3081 L F
.83191 .31173 m .83374 .30883 L .83504 .31072 L 0 .027 .126 r
F
.83191 .31173 m .83062 .30985 L .83374 .30883 L F
.26627 .31259 m .26723 .30971 L .26908 .31165 L 0 .029 .128 r
F
.26627 .31259 m .26441 .31065 L .26723 .30971 L F
.41384 .31967 m .41503 .31665 L .41673 .31876 L 0 .044 .146 r
F
.41384 .31967 m .41213 .31756 L .41503 .31665 L F
.49385 .4202 m .49231 .40951 L .49515 .41931 L 0 .42 .216 r
F
.49231 .40951 m .49361 .40672 L .49515 .41931 L 0 .38 .26 r
F
.43342 .32116 m .43464 .31841 L .43632 .3205 L 0 .048 .151 r
F
.43342 .32116 m .43174 .31907 L .43464 .31841 L F
.48331 .33368 m .48462 .32977 L .48625 .33252 L 0 .081 .181 r
F
.48331 .33368 m .48168 .33095 L .48462 .32977 L F
.5571 .33723 m .55849 .33274 L .56006 .33525 L 0 .091 .189 r
F
.5571 .33723 m .55552 .33462 L .55849 .33274 L F
.39425 .31827 m .39541 .31531 L .39714 .31722 L 0 .041 .143 r
F
.39425 .31827 m .39252 .31635 L .39541 .31531 L F
.12029 .31058 m .12102 .30768 L .12302 .30961 L 0 .025 .123 r
F
.12029 .31058 m .11829 .30865 L .12102 .30768 L F
.50314 .34885 m .50154 .34291 L .50449 .34179 L 0 .128 .215 r
F
.50154 .34291 m .50288 .33786 L .50449 .34179 L 0 .11 .202 r
F
.50154 .34291 m .49993 .33886 L .50288 .33786 L F
.30087 .31332 m .30189 .3104 L .3037 .31242 L 0 .03 .13 r
F
.30087 .31332 m .29905 .31135 L .30189 .3104 L F
.19703 .31147 m .19789 .30845 L .19981 .31043 L 0 .026 .125 r
F
.19703 .31147 m .19511 .3095 L .19789 .30845 L F
.78229 .31211 m .78403 .30908 L .78537 .31098 L 0 .028 .127 r
F
.78229 .31211 m .78094 .31023 L .78403 .30908 L F
.83945 .31153 m .8413 .30875 L .84258 .31056 L 0 .027 .126 r
F
.83945 .31153 m .83817 .30972 L .8413 .30875 L F
.78981 .31175 m .79157 .30888 L .79291 .31081 L 0 .027 .127 r
F
.78981 .31175 m .78846 .30984 L .79157 .30888 L F
.44549 .32324 m .44672 .32043 L .4484 .32248 L 0 .054 .156 r
F
.44549 .32324 m .44381 .32118 L .44672 .32043 L F
.59899 .32493 m .60044 .3214 L .60197 .32339 L 0 .057 .159 r
F
.59899 .32493 m .59745 .32294 L .60044 .3214 L F
.50336 .3652 m .50179 .35578 L .50473 .35479 L 0 .198 .256 r
F
.50042 .36514 m .50179 .35578 L .50336 .3652 L 0 .195 .254 r
F
.50179 .35578 m .50314 .34885 L .50473 .35479 L 0 .156 .232 r
F
.33548 .31413 m .33654 .31123 L .33833 .31323 L 0 .032 .133 r
F
.33548 .31413 m .33369 .31214 L .33654 .31123 L F
.40176 .3181 m .40292 .31524 L .40464 .31722 L 0 .041 .143 r
F
.40176 .3181 m .40003 .31618 L .40292 .31524 L F
.49768 .38394 m .49612 .374 L .49904 .37597 L 0 .311 .307 r
F
.58852 .32815 m .58995 .3241 L .59149 .32626 L 0 .065 .167 r
F
.58852 .32815 m .58697 .32593 L .58995 .3241 L F
.16239 .31107 m .16318 .30818 L .16513 .31017 L 0 .026 .125 r
F
.16239 .31107 m .16043 .30911 L .16318 .30818 L F
.23913 .31192 m .24006 .30892 L .24194 .31089 L 0 .028 .127 r
F
.23913 .31192 m .23725 .30995 L .24006 .30892 L F
.20451 .31134 m .20539 .30835 L .2073 .31031 L 0 .026 .126 r
F
.20451 .31134 m .2026 .30939 L .20539 .30835 L F
.63201 .32073 m .63351 .31729 L .63501 .31932 L 0 .046 .149 r
F
.63201 .32073 m .6305 .31867 L .63351 .31729 L F
.62449 .32115 m .62599 .31784 L .6275 .31991 L 0 .048 .15 r
F
.62449 .32115 m .62298 .31906 L .62599 .31784 L F
.38216 .31679 m .38329 .31402 L .38503 .31608 L 0 .038 .14 r
F
.38216 .31679 m .38042 .31476 L .38329 .31402 L F
.27375 .31263 m .27472 .30966 L .27656 .31166 L 0 .029 .129 r
F
.27375 .31263 m .2719 .31066 L .27472 .30966 L F
.49495 .40166 m .49341 .38955 L .4963 .39421 L 0 .361 .277 r
F
.12775 .31055 m .1285 .30762 L .13049 .30956 L 0 .025 .124 r
F
.12775 .31055 m .12576 .30863 L .1285 .30762 L F
.54725 .45021 m .54577 .46486 L .54868 .45326 L 0 .498 .088 r
F
.54433 .45944 m .54577 .46486 L .54725 .45021 L 0 .535 .008 r
F
.84699 .3114 m .84886 .30859 L .85013 .31039 L 0 .027 .126 r
F
.84699 .3114 m .84572 .30959 L .84886 .30859 L F
.36257 .31537 m .36367 .31267 L .36544 .31446 L 0 .035 .137 r
F
.36257 .31537 m .3608 .31355 L .36367 .31267 L F
.46212 .32767 m .46339 .32439 L .46503 .32703 L 0 .065 .167 r
F
.46212 .32767 m .46047 .32509 L .46339 .32439 L F
.67254 .31601 m .67412 .31298 L .67558 .31499 L 0 .036 .138 r
F
.67254 .31601 m .67108 .314 L .67412 .31298 L F
.55359 .39244 m .55199 .38863 L .55489 .37856 L 0 .321 .302 r
F
.55199 .38863 m .55329 .37381 L .55489 .37856 L 0 .311 .307 r
F
.24664 .31166 m .24756 .30885 L .24944 .31066 L 0 .027 .127 r
F
.24664 .31166 m .24475 .30985 L .24756 .30885 L F
.65751 .3169 m .65907 .31381 L .66054 .3158 L 0 .038 .14 r
F
.65751 .3169 m .65604 .31495 L .65907 .31381 L F
.66503 .31649 m .66659 .31319 L .66805 .3152 L 0 .037 .138 r
F
.66503 .31649 m .66356 .3145 L .66659 .31319 L F
.65 .31733 m .65154 .31416 L .65302 .31609 L 0 .039 .141 r
F
.65 .31733 m .64852 .31544 L .65154 .31416 L F
.85452 .3111 m .85638 .30818 L .85765 .31001 L 0 .026 .125 r
F
.85452 .3111 m .85325 .30928 L .85638 .30818 L F
.79736 .31175 m .79914 .3089 L .80046 .31077 L 0 .028 .127 r
F
.79736 .31175 m .79602 .30988 L .79914 .3089 L F
.49732 .44141 m .49572 .43633 L .49854 .45133 L 0 .493 .098 r
F
.49572 .43633 m .49415 .42785 L .49697 .44131 L 0 .471 .138 r
F
.49415 .42785 m .49541 .43077 L .49697 .44131 L 0 .44 .188 r
F
.57053 .33199 m .57194 .32785 L .57351 .33018 L 0 .076 .177 r
F
.57053 .33199 m .56897 .32963 L .57194 .32785 L F
.6951 .31491 m .69671 .31189 L .69814 .31377 L 0 .034 .135 r
F
.6951 .31491 m .69367 .31307 L .69671 .31189 L F
.212 .31118 m .21287 .30835 L .21479 .31019 L 0 .027 .126 r
F
.212 .31118 m .21008 .30933 L .21287 .30835 L F
.42133 .31997 m .42254 .31683 L .42423 .31895 L 0 .046 .148 r
F
.42133 .31997 m .41963 .31784 L .42254 .31683 L F
.68758 .31539 m .68919 .31244 L .69062 .31424 L 0 .035 .137 r
F
.68758 .31539 m .68615 .31361 L .68919 .31244 L F
.13523 .31042 m .13598 .30759 L .13798 .30944 L 0 .025 .124 r
F
.13523 .31042 m .13324 .30857 L .13598 .30759 L F
.80488 .31148 m .80668 .30861 L .80799 .31039 L 0 .027 .127 r
F
.80488 .31148 m .80357 .30969 L .80668 .30861 L F
.55199 .38863 m .55038 .38291 L .55329 .37381 L 0 .311 .307 r
F
.55038 .38291 m .55169 .36886 L .55329 .37381 L 0 .282 .297 r
F
.30834 .31356 m .30938 .31053 L .31118 .31259 L 0 .031 .132 r
F
.30834 .31356 m .30654 .31151 L .30938 .31053 L F
.86205 .31086 m .86394 .30805 L .86521 .30993 L 0 .026 .125 r
F
.86205 .31086 m .86079 .309 L .86394 .30805 L F
.56006 .33525 m .56146 .33086 L .56303 .33332 L 0 .086 .185 r
F
.56006 .33525 m .55849 .33274 L .56146 .33086 L F
.34296 .3142 m .34405 .31115 L .34583 .31315 L 0 .033 .133 r
F
.34296 .3142 m .34119 .3122 L .34405 .31115 L F
.47874 .33213 m .48004 .32843 L .48168 .33095 L 0 .078 .178 r
F
.47874 .33213 m .4771 .32961 L .48004 .32843 L F
.70262 .31462 m .70425 .3117 L .70568 .31365 L 0 .034 .135 r
F
.70262 .31462 m .70119 .3127 L .70425 .3117 L F
.49538 .33632 m .4967 .33189 L .49832 .33531 L 0 .09 .188 r
F
.49538 .33632 m .49376 .3329 L .4967 .33189 L F
.54959 .33841 m .55097 .33365 L .55256 .33652 L 0 .096 .192 r
F
.54959 .33841 m .548 .33527 L .55097 .33365 L F
.54664 .34128 m .548 .33527 L .54959 .33841 L 0 .102 .197 r
F
.68007 .31591 m .68166 .31284 L .68311 .31478 L 0 .036 .138 r
F
.68007 .31591 m .67862 .31396 L .68166 .31284 L F
.16985 .31111 m .17067 .30813 L .17262 .31003 L 0 .026 .126 r
F
.16985 .31111 m .16789 .30921 L .17067 .30813 L F
.55038 .38291 m .54877 .37693 L .55169 .36886 L 0 .282 .297 r
F
.54877 .37693 m .55008 .3639 L .55169 .36886 L 0 .25 .282 r
F
.25412 .31155 m .25505 .30882 L .25693 .31064 L 0 .028 .127 r
F
.25412 .31155 m .25224 .30974 L .25505 .30882 L F
.28123 .3126 m .2822 .30989 L .28405 .31174 L 0 .03 .13 r
F
.28123 .3126 m .27938 .31075 L .2822 .30989 L F
.81241 .31114 m .81422 .30835 L .81552 .31015 L 0 .027 .126 r
F
.81241 .31114 m .8111 .30936 L .81422 .30835 L F
.49082 .33408 m .49213 .33009 L .49376 .3329 L 0 .084 .183 r
F
.49082 .33408 m .48919 .33131 L .49213 .33009 L F
.61699 .322 m .61847 .31835 L .61998 .32046 L 0 .05 .152 r
F
.61699 .322 m .61547 .3199 L .61847 .31835 L F
.54877 .37693 m .54716 .37097 L .55008 .3639 L 0 .25 .282 r
F
.54716 .37097 m .54848 .35892 L .55008 .3639 L 0 .22 .267 r
F
.54716 .37097 m .54555 .36502 L .54848 .35892 L F
.54555 .36502 m .54688 .35394 L .54848 .35892 L 0 .192 .252 r
F
.17736 .31077 m .17817 .3079 L .18013 .30975 L 0 .026 .125 r
F
.17736 .31077 m .1754 .30894 L .17817 .3079 L F
.54555 .36502 m .54394 .35908 L .54688 .35394 L 0 .192 .252 r
F
.54394 .35908 m .54528 .34929 L .54688 .35394 L 0 .167 .238 r
F
.45755 .32581 m .45881 .32248 L .46047 .32509 L 0 .061 .163 r
F
.45755 .32581 m .45589 .32328 L .45881 .32248 L F
.21949 .31102 m .22038 .30809 L .22229 .30993 L 0 .027 .126 r
F
.21949 .31102 m .21758 .30918 L .22038 .30809 L F
.37006 .31542 m .37118 .3126 L .37293 .31451 L 0 .036 .137 r
F
.37006 .31542 m .3683 .31355 L .37118 .3126 L F
.54528 .34929 m .54368 .34483 L .54664 .34128 L 0 .127 .214 r
F
.54664 .34128 m .54504 .3376 L .548 .33527 L 0 .102 .197 r
F
.54368 .34483 m .54504 .3376 L .54664 .34128 L 0 .113 .205 r
F
.50055 .44827 m .50175 .46294 L .50338 .4647 L 0 .515 .053 r
F
.50055 .44827 m .49892 .4465 L .50175 .46294 L F
.50473 .35479 m .50314 .34885 L .50609 .34747 L 0 .154 .231 r
F
.50314 .34885 m .50449 .34179 L .50609 .34747 L 0 .128 .215 r
F
.40924 .31841 m .41043 .31544 L .41213 .31756 L 0 .043 .145 r
F
.40924 .31841 m .40753 .31633 L .41043 .31544 L F
.49993 .33886 m .50127 .3344 L .50288 .33786 L 0 .099 .194 r
F
.49993 .33886 m .49832 .33531 L .50127 .3344 L F
.10809 .30969 m .10879 .30689 L .11081 .30872 L 0 .024 .123 r
F
.10809 .30969 m .10606 .30788 L .10879 .30689 L F
.58101 .32929 m .58244 .32548 L .58399 .32775 L 0 .07 .171 r
F
.58101 .32929 m .57946 .327 L .58244 .32548 L F
.14271 .31033 m .14346 .30757 L .14545 .30939 L 0 .026 .124 r
F
.14271 .31033 m .14072 .30851 L .14346 .30757 L F
.22699 .31076 m .22789 .30784 L .22979 .30978 L 0 .026 .125 r
F
.22699 .31076 m .2251 .30883 L .22789 .30784 L F
.74022 .31284 m .7419 .30984 L .74329 .31175 L 0 .03 .13 r
F
.74022 .31284 m .73883 .31098 L .7419 .30984 L F
.35046 .3141 m .35154 .31134 L .35332 .31332 L 0 .033 .134 r
F
.35046 .3141 m .34869 .31214 L .35154 .31134 L F
.31584 .31348 m .31688 .31052 L .31868 .31243 L 0 .032 .132 r
F
.31584 .31348 m .31403 .31155 L .31688 .31052 L F
.81995 .31101 m .82177 .30814 L .82307 .31 L 0 .027 .126 r
F
.81995 .31101 m .81864 .30916 L .82177 .30814 L F
.18484 .31062 m .18567 .30776 L .18761 .30964 L 0 .026 .125 r
F
.18484 .31062 m .1829 .30876 L .18567 .30776 L F
.59149 .32626 m .59293 .32238 L .59447 .32448 L 0 .061 .163 r
F
.59149 .32626 m .58995 .3241 L .59293 .32238 L F
.64251 .31834 m .64403 .315 L .64551 .31689 L 0 .042 .144 r
F
.64251 .31834 m .64102 .31645 L .64403 .315 L F
.44091 .32189 m .44213 .31912 L .44381 .32118 L 0 .052 .154 r
F
.44091 .32189 m .43923 .31984 L .44213 .31912 L F
.42883 .32004 m .43005 .31696 L .43174 .31907 L 0 .047 .149 r
F
.42883 .32004 m .42714 .31792 L .43005 .31696 L F
.60948 .32275 m .61096 .31934 L .61248 .32144 L 0 .053 .155 r
F
.60948 .32275 m .60796 .32068 L .61096 .31934 L F
.72519 .31379 m .72686 .31095 L .72826 .31275 L 0 .033 .133 r
F
.72519 .31379 m .7238 .31201 L .72686 .31095 L F
.71768 .31423 m .71932 .31106 L .72073 .31306 L 0 .033 .134 r
F
.71768 .31423 m .71626 .31224 L .71932 .31106 L F
.71016 .31465 m .71179 .31147 L .71321 .31346 L 0 .034 .135 r
F
.71016 .31465 m .70874 .31267 L .71179 .31147 L F
.73271 .3134 m .73438 .31035 L .73577 .31219 L 0 .032 .132 r
F
.73271 .3134 m .73132 .31159 L .73438 .31035 L F
.54394 .35908 m .54233 .3536 L .54528 .34929 L 0 .167 .238 r
F
.54233 .3536 m .54368 .34483 L .54528 .34929 L 0 .145 .226 r
F
.32334 .31323 m .32439 .31033 L .32619 .31219 L 0 .031 .132 r
F
.32334 .31323 m .32154 .31138 L .32439 .31033 L F
.74775 .31261 m .74944 .30956 L .75083 .31154 L 0 .03 .13 r
F
.74775 .31261 m .74636 .31065 L .74944 .30956 L F
.2616 .31158 m .26255 .30878 L .26441 .31065 L 0 .028 .128 r
F
.2616 .31158 m .25974 .30971 L .26255 .30878 L F
.28871 .31269 m .2897 .30981 L .29154 .31163 L 0 .03 .131 r
F
.28871 .31269 m .28686 .31088 L .2897 .30981 L F
.38964 .31729 m .39079 .31442 L .39252 .31635 L 0 .041 .143 r
F
.38964 .31729 m .3879 .31536 L .39079 .31442 L F
.15019 .31023 m .15097 .3073 L .15295 .30916 L 0 .026 .124 r
F
.15019 .31023 m .14821 .30838 L .15097 .3073 L F
.82749 .31086 m .82932 .30797 L .83062 .30985 L 0 .027 .126 r
F
.82749 .31086 m .82619 .30899 L .82932 .30797 L F
.11556 .30962 m .11628 .30677 L .11829 .30865 L 0 .025 .123 r
F
.11556 .30962 m .11354 .30774 L .11628 .30677 L F
.77031 .31151 m .77205 .30868 L .77341 .3105 L 0 .028 .128 r
F
.77031 .31151 m .76896 .3097 L .77205 .30868 L F
.60197 .32339 m .60344 .32001 L .60496 .32201 L 0 .055 .157 r
F
.60197 .32339 m .60044 .3214 L .60344 .32001 L F
.45298 .32406 m .45423 .32087 L .45589 .32328 L 0 .057 .16 r
F
.45298 .32406 m .45131 .32173 L .45423 .32087 L F
.29622 .31239 m .29722 .30947 L .29905 .31135 L 0 .03 .13 r
F
.29622 .31239 m .29438 .31054 L .29722 .30947 L F
.19232 .31055 m .19318 .30753 L .19511 .3095 L 0 .026 .125 r
F
.19232 .31055 m .1904 .30859 L .19318 .30753 L F
.33084 .31306 m .3319 .31029 L .33369 .31214 L 0 .032 .132 r
F
.33084 .31306 m .32905 .3112 L .3319 .31029 L F
.75528 .31243 m .75698 .30936 L .75836 .31134 L 0 .03 .13 r
F
.75528 .31243 m .7539 .31045 L .75698 .30936 L F
.7628 .31201 m .76452 .30901 L .76588 .31085 L 0 .029 .129 r
F
.7628 .31201 m .76144 .31019 L .76452 .30901 L F
.57351 .33018 m .57492 .32623 L .57648 .32853 L 0 .073 .174 r
F
.57351 .33018 m .57194 .32785 L .57492 .32623 L F
.37755 .31559 m .37868 .31272 L .38042 .31476 L 0 .037 .139 r
F
.37755 .31559 m .37581 .31359 L .37868 .31272 L F
.56303 .33332 m .56443 .329 L .566 .33141 L 0 .082 .181 r
F
.56303 .33332 m .56146 .33086 L .56443 .329 L F
.47417 .33063 m .47546 .32722 L .4771 .32961 L 0 .076 .176 r
F
.47417 .33063 m .47253 .32822 L .47546 .32722 L F
.48625 .33252 m .48756 .32853 L .48919 .33131 L 0 .08 .18 r
F
.48625 .33252 m .48462 .32977 L .48756 .32853 L F
.23446 .31085 m .23537 .30796 L .23725 .30995 L 0 .027 .126 r
F
.23446 .31085 m .23258 .30887 L .23537 .30796 L F
.55256 .33652 m .55394 .33202 L .55552 .33462 L 0 .092 .189 r
F
.55256 .33652 m .55097 .33365 L .55394 .33202 L F
.15768 .31005 m .15847 .30714 L .16043 .30911 L 0 .026 .124 r
F
.15768 .31005 m .15572 .3081 L .15847 .30714 L F
.77785 .31132 m .77959 .30838 L .78094 .31023 L 0 .028 .128 r
F
.77785 .31132 m .7765 .30948 L .77959 .30838 L F
.83504 .31072 m .83687 .30781 L .83817 .30972 L 0 .027 .126 r
F
.83504 .31072 m .83374 .30883 L .83687 .30781 L F
.50609 .34747 m .50449 .34179 L .50744 .34067 L 0 .127 .214 r
F
.50449 .34179 m .50583 .33687 L .50744 .34067 L 0 .109 .202 r
F
.50449 .34179 m .50288 .33786 L .50583 .33687 L F
.39714 .31722 m .3983 .31427 L .40003 .31618 L 0 .041 .143 r
F
.39714 .31722 m .39541 .31531 L .3983 .31427 L F
.78537 .31098 m .78712 .30792 L .78846 .30984 L 0 .027 .127 r
F
.78537 .31098 m .78403 .30908 L .78712 .30792 L F
.63501 .31932 m .63652 .31587 L .63801 .31789 L 0 .045 .147 r
F
.63501 .31932 m .63351 .31729 L .63652 .31587 L F
.26908 .31165 m .27005 .30868 L .2719 .31066 L 0 .029 .129 r
F
.26908 .31165 m .26723 .30971 L .27005 .30868 L F
.41673 .31876 m .41793 .31574 L .41963 .31784 L 0 .044 .147 r
F
.41673 .31876 m .41503 .31665 L .41793 .31574 L F
.35794 .31438 m .35903 .31172 L .3608 .31355 L 0 .035 .136 r
F
.35794 .31438 m .35617 .31253 L .35903 .31172 L F
.54233 .3536 m .54073 .34839 L .54368 .34483 L 0 .145 .226 r
F
.54368 .34483 m .54208 .3404 L .54504 .3376 L 0 .113 .205 r
F
.54073 .34839 m .54208 .3404 L .54368 .34483 L 0 .126 .213 r
F
.19981 .31043 m .20068 .30738 L .2026 .30939 L 0 .026 .125 r
F
.19981 .31043 m .19789 .30845 L .20068 .30738 L F
.12302 .30961 m .12376 .3067 L .12576 .30863 L 0 .025 .123 r
F
.12302 .30961 m .12102 .30768 L .12376 .3067 L F
.50198 .37651 m .50042 .36514 L .50336 .3652 L 0 .265 .289 r
F
.49904 .37597 m .50042 .36514 L .50198 .37651 L 0 .254 .284 r
F
.6275 .31991 m .629 .31661 L .6305 .31867 L 0 .047 .149 r
F
.6275 .31991 m .62599 .31784 L .629 .31661 L F
.3037 .31242 m .30472 .30946 L .30654 .31151 L 0 .031 .131 r
F
.3037 .31242 m .30189 .3104 L .30472 .30946 L F
.84258 .31056 m .84444 .30779 L .84572 .30959 L 0 .027 .126 r
F
.84258 .31056 m .8413 .30875 L .84444 .30779 L F
.50631 .36421 m .50473 .35479 L .50769 .35315 L 0 .195 .254 r
F
.50336 .3652 m .50473 .35479 L .50631 .36421 L 0 .198 .256 r
F
.50473 .35479 m .50609 .34747 L .50769 .35315 L 0 .154 .231 r
F
.79291 .31081 m .79469 .30793 L .79602 .30988 L 0 .027 .127 r
F
.79291 .31081 m .79157 .30888 L .79469 .30793 L F
.66805 .3152 m .66962 .31199 L .67108 .314 L 0 .036 .137 r
F
.66805 .3152 m .66659 .31319 L .66962 .31199 L F
.61998 .32046 m .62147 .31696 L .62298 .31906 L 0 .048 .151 r
F
.61998 .32046 m .61847 .31835 L .62147 .31696 L F
.65302 .31609 m .65456 .31299 L .65604 .31495 L 0 .038 .14 r
F
.65302 .31609 m .65154 .31416 L .65456 .31299 L F
.4696 .32882 m .47088 .32581 L .47253 .32822 L 0 .072 .173 r
F
.4696 .32882 m .46795 .32642 L .47088 .32581 L F
.24194 .31089 m .24287 .30789 L .24475 .30985 L 0 .027 .127 r
F
.24194 .31089 m .24006 .30892 L .24287 .30789 L F
.43632 .3205 m .43754 .31775 L .43923 .31984 L 0 .05 .152 r
F
.43632 .3205 m .43464 .31841 L .43754 .31775 L F
.59447 .32448 m .59592 .32091 L .59745 .32294 L 0 .058 .161 r
F
.59447 .32448 m .59293 .32238 L .59592 .32091 L F
.33833 .31323 m .33941 .3102 L .34119 .3122 L 0 .032 .133 r
F
.33833 .31323 m .33654 .31123 L .33941 .3102 L F
.2073 .31031 m .20817 .30736 L .21008 .30933 L 0 .026 .126 r
F
.2073 .31031 m .20539 .30835 L .20817 .30736 L F
.40464 .31722 m .40582 .3143 L .40753 .31633 L 0 .041 .144 r
F
.40464 .31722 m .40292 .31524 L .40582 .3143 L F
.66054 .3158 m .66209 .3125 L .66356 .3145 L 0 .038 .139 r
F
.66054 .3158 m .65907 .31381 L .66209 .3125 L F
.16513 .31017 m .16594 .30721 L .16789 .30921 L 0 .026 .125 r
F
.16513 .31017 m .16318 .30818 L .16594 .30721 L F
.4484 .32248 m .44964 .31968 L .45131 .32173 L 0 .055 .157 r
F
.4484 .32248 m .44672 .32043 L .44964 .31968 L F
.85013 .31039 m .85198 .30748 L .85325 .30928 L 0 .027 .126 r
F
.85013 .31039 m .84886 .30859 L .85198 .30748 L F
.13049 .30956 m .13125 .30661 L .13324 .30857 L 0 .025 .124 r
F
.13049 .30956 m .1285 .30762 L .13125 .30661 L F
.67558 .31499 m .67716 .31194 L .67862 .31396 L 0 .036 .138 r
F
.67558 .31499 m .67412 .31298 L .67716 .31194 L F
.27656 .31166 m .27754 .30872 L .27938 .31075 L 0 .029 .129 r
F
.27656 .31166 m .27472 .30966 L .27754 .30872 L F
.85765 .31001 m .85952 .30715 L .86079 .309 L 0 .026 .125 r
F
.85765 .31001 m .85638 .30818 L .85952 .30715 L F
.69814 .31377 m .69976 .31079 L .70119 .3127 L 0 .034 .135 r
F
.69814 .31377 m .69671 .31189 L .69976 .31079 L F
.58399 .32775 m .58542 .32371 L .58697 .32593 L 0 .067 .168 r
F
.58399 .32775 m .58244 .32548 L .58542 .32371 L F
.24944 .31066 m .25036 .30792 L .25224 .30974 L 0 .028 .127 r
F
.24944 .31066 m .24756 .30885 L .25036 .30792 L F
.55157 .44164 m .5501 .45271 L .55297 .43893 L 0 .467 .145 r
F
.54868 .45326 m .5501 .45271 L .55157 .44164 L 0 .513 .056 r
F
.55547 .414 m .55392 .41483 L .55675 .39807 L 0 .38 .261 r
F
.55392 .41483 m .55518 .39625 L .55675 .39807 L 0 .384 .257 r
F
.54504 .3376 m .54642 .33296 L .548 .33527 L 0 .096 .192 r
F
.54504 .3376 m .54345 .33493 L .54642 .33296 L F
.54208 .3404 m .54345 .33493 L .54504 .3376 L 0 .104 .198 r
F
.69062 .31424 m .69223 .31122 L .69367 .31307 L 0 .035 .136 r
F
.69062 .31424 m .68919 .31244 L .69223 .31122 L F
.36544 .31446 m .36654 .31179 L .3683 .31355 L 0 .036 .137 r
F
.36544 .31446 m .36367 .31267 L .36654 .31179 L F
.48168 .33095 m .48298 .32725 L .48462 .32977 L 0 .077 .178 r
F
.48168 .33095 m .48004 .32843 L .48298 .32725 L F
.50769 .35315 m .50609 .34747 L .50904 .34609 L 0 .151 .229 r
F
.50609 .34747 m .50744 .34067 L .50904 .34609 L 0 .127 .214 r
F
.566 .33141 m .5674 .32726 L .56897 .32963 L 0 .078 .178 r
F
.566 .33141 m .56443 .329 L .5674 .32726 L F
.80046 .31077 m .80224 .30782 L .80357 .30969 L 0 .028 .127 r
F
.80046 .31077 m .79914 .3089 L .80224 .30782 L F
.54073 .34839 m .53913 .34321 L .54208 .3404 L 0 .126 .213 r
F
.54208 .3404 m .54049 .33724 L .54345 .33493 L 0 .104 .198 r
F
.53913 .34321 m .54049 .33724 L .54208 .3404 L 0 .113 .204 r
F
.49376 .3329 m .49508 .32908 L .4967 .33189 L 0 .083 .182 r
F
.49376 .3329 m .49213 .33009 L .49508 .32908 L F
.80799 .31039 m .80979 .30757 L .8111 .30936 L 0 .027 .127 r
F
.80799 .31039 m .80668 .30861 L .80979 .30757 L F
.68311 .31478 m .6847 .31169 L .68615 .31361 L 0 .036 .137 r
F
.68311 .31478 m .68166 .31284 L .6847 .31169 L F
.21479 .31019 m .21566 .30735 L .21758 .30918 L 0 .027 .126 r
F
.21479 .31019 m .21287 .30835 L .21566 .30735 L F
.42423 .31895 m .42544 .3158 L .42714 .31792 L 0 .046 .148 r
F
.42423 .31895 m .42254 .31683 L .42544 .3158 L F
.64551 .31689 m .64704 .31355 L .64852 .31544 L 0 .04 .142 r
F
.64551 .31689 m .64403 .315 L .64704 .31355 L F
.55552 .33462 m .55691 .33024 L .55849 .33274 L 0 .088 .186 r
F
.55552 .33462 m .55394 .33202 L .55691 .33024 L F
.34583 .31315 m .34692 .31013 L .34869 .31214 L 0 .033 .133 r
F
.34583 .31315 m .34405 .31115 L .34692 .31013 L F
.17262 .31003 m .17345 .30704 L .1754 .30894 L 0 .026 .125 r
F
.17262 .31003 m .17067 .30813 L .17345 .30704 L F
.38503 .31608 m .38617 .31327 L .3879 .31536 L 0 .039 .141 r
F
.38503 .31608 m .38329 .31402 L .38617 .31327 L F
.53778 .35387 m .53913 .34321 L .54073 .34839 L 0 .146 .226 r
F
.53778 .35387 m .53617 .3475 L .53913 .34321 L F
.53913 .34321 m .53753 .33955 L .54049 .33724 L 0 .113 .204 r
F
.53617 .3475 m .53753 .33955 L .53913 .34321 L 0 .126 .213 r
F
.13798 .30944 m .13873 .30665 L .14072 .30851 L 0 .026 .124 r
F
.13798 .30944 m .13598 .30759 L .13873 .30665 L F
.49832 .33531 m .49965 .33105 L .50127 .3344 L 0 .09 .188 r
F
.49832 .33531 m .4967 .33189 L .49965 .33105 L F
.31118 .31259 m .31222 .30949 L .31403 .31155 L 0 .031 .132 r
F
.31118 .31259 m .30938 .31053 L .31222 .30949 L F
.70568 .31365 m .70731 .31069 L .70874 .31267 L 0 .034 .135 r
F
.70568 .31365 m .70425 .3117 L .70731 .31069 L F
.22229 .30993 m .22319 .307 L .2251 .30883 L 0 .026 .125 r
F
.22229 .30993 m .22038 .30809 L .22319 .307 L F
.86521 .30993 m .8671 .3071 L .86836 .309 L 0 .026 .126 r
F
.86521 .30993 m .86394 .30805 L .8671 .3071 L F
.46503 .32703 m .46631 .32372 L .46795 .32642 L 0 .067 .169 r
F
.46503 .32703 m .46339 .32439 L .46631 .32372 L F
.81552 .31015 m .81734 .30734 L .81864 .30916 L 0 .027 .126 r
F
.81552 .31015 m .81422 .30835 L .81734 .30734 L F
.18013 .30975 m .18095 .30689 L .1829 .30876 L 0 .026 .125 r
F
.18013 .30975 m .17817 .3079 L .18095 .30689 L F
.57648 .32853 m .5779 .32473 L .57946 .327 L 0 .07 .172 r
F
.57648 .32853 m .57492 .32623 L .5779 .32473 L F
.61248 .32144 m .61395 .31779 L .61547 .3199 L 0 .051 .154 r
F
.61248 .32144 m .61096 .31934 L .61395 .31779 L F
.53939 .36031 m .54073 .34839 L .54233 .3536 L 0 .173 .242 r
F
.53939 .36031 m .53778 .35387 L .54073 .34839 L F
.25693 .31064 m .25786 .30789 L .25974 .30971 L 0 .028 .128 r
F
.25693 .31064 m .25505 .30882 L .25786 .30789 L F
.548 .33527 m .54939 .33149 L .55097 .33365 L 0 .092 .189 r
F
.548 .33527 m .54642 .33296 L .54939 .33149 L F
.28405 .31174 m .28502 .30903 L .28686 .31088 L 0 .03 .131 r
F
.28405 .31174 m .2822 .30989 L .28502 .30903 L F
.74329 .31175 m .74498 .30871 L .74636 .31065 L 0 .03 .13 r
F
.74329 .31175 m .7419 .30984 L .74498 .30871 L F
.73577 .31219 m .73744 .30912 L .73883 .31098 L 0 .031 .131 r
F
.73577 .31219 m .73438 .31035 L .73744 .30912 L F
.60496 .32201 m .60643 .31866 L .60796 .32068 L 0 .053 .156 r
F
.60496 .32201 m .60344 .32001 L .60643 .31866 L F
.71321 .31346 m .71484 .31023 L .71626 .31224 L 0 .033 .134 r
F
.71321 .31346 m .71179 .31147 L .71484 .31023 L F
.50288 .33786 m .50421 .33349 L .50583 .33687 L 0 .099 .195 r
F
.50288 .33786 m .50127 .3344 L .50421 .33349 L F
.37293 .31451 m .37406 .31163 L .37581 .31359 L 0 .036 .138 r
F
.37293 .31451 m .37118 .3126 L .37406 .31163 L F
.31868 .31243 m .31973 .30945 L .32154 .31138 L 0 .032 .132 r
F
.31868 .31243 m .31688 .31052 L .31973 .30945 L F
.72073 .31306 m .72238 .31002 L .7238 .31201 L 0 .033 .134 r
F
.72073 .31306 m .71932 .31106 L .72238 .31002 L F
.11081 .30872 m .11152 .3059 L .11354 .30774 L 0 .024 .123 r
F
.11081 .30872 m .10879 .30689 L .11152 .3059 L F
.22979 .30978 m .23069 .30692 L .23258 .30887 L 0 .026 .126 r
F
.22979 .30978 m .22789 .30784 L .23069 .30692 L F
.82307 .31 m .82489 .30712 L .82619 .30899 L 0 .027 .126 r
F
.82307 .31 m .82177 .30814 L .82489 .30712 L F
.54101 .36712 m .54233 .3536 L .54394 .35908 L 0 .204 .259 r
F
.54101 .36712 m .53939 .36031 L .54233 .3536 L F
.14545 .30939 m .14622 .30655 L .14821 .30838 L 0 .026 .125 r
F
.14545 .30939 m .14346 .30757 L .14622 .30655 L F
.72826 .31275 m .72993 .30977 L .73132 .31159 L 0 .032 .133 r
F
.72826 .31275 m .72686 .31095 L .72993 .30977 L F
.41213 .31756 m .41332 .31454 L .41503 .31665 L 0 .043 .145 r
F
.41213 .31756 m .41043 .31544 L .41332 .31454 L F
.18761 .30964 m .18846 .30671 L .1904 .30859 L 0 .026 .125 r
F
.18761 .30964 m .18567 .30776 L .18846 .30671 L F
.46047 .32509 m .46173 .32171 L .46339 .32439 L 0 .062 .164 r
F
.46047 .32509 m .45881 .32248 L .46173 .32171 L F
.75083 .31154 m .75252 .30846 L .7539 .31045 L 0 .03 .13 r
F
.75083 .31154 m .74944 .30956 L .75252 .30846 L F
.32619 .31219 m .32724 .30934 L .32905 .3112 L 0 .031 .132 r
F
.32619 .31219 m .32439 .31033 L .32724 .30934 L F
.43174 .31907 m .43295 .3163 L .43464 .31841 L 0 .047 .15 r
F
.43174 .31907 m .43005 .31696 L .43295 .3163 L F
.29154 .31163 m .29254 .30871 L .29438 .31054 L 0 .03 .13 r
F
.29154 .31163 m .2897 .30981 L .29254 .30871 L F
.63801 .31789 m .63953 .31446 L .64102 .31645 L 0 .043 .146 r
F
.63801 .31789 m .63652 .31587 L .63953 .31446 L F
.50927 .36219 m .50769 .35315 L .51064 .35152 L 0 .189 .251 r
F
.50631 .36421 m .50769 .35315 L .50927 .36219 L 0 .195 .254 r
F
.50769 .35315 m .50904 .34609 L .51064 .35152 L 0 .151 .229 r
F
.35332 .31332 m .3544 .31054 L .35617 .31253 L 0 .034 .135 r
F
.35332 .31332 m .35154 .31134 L .3544 .31054 L F
.15295 .30916 m .15374 .30623 L .15572 .3081 L 0 .025 .124 r
F
.15295 .30916 m .15097 .3073 L .15374 .30623 L F
.76588 .31085 m .7676 .30786 L .76896 .3097 L 0 .029 .128 r
F
.76588 .31085 m .76452 .30901 L .7676 .30786 L F
.26441 .31065 m .26536 .30783 L .26723 .30971 L F
.26441 .31065 m .26255 .30878 L .26536 .30783 L F
.48919 .33131 m .49051 .32728 L .49213 .33009 L 0 .079 .179 r
F
.48919 .33131 m .48756 .32853 L .49051 .32728 L F
.83062 .30985 m .83244 .30692 L .83374 .30883 L 0 .027 .126 r
F
.83062 .30985 m .82932 .30797 L .83244 .30692 L F
.58697 .32593 m .5884 .32193 L .58995 .3241 L 0 .063 .165 r
F
.58697 .32593 m .58542 .32371 L .5884 .32193 L F
.77341 .3105 m .77515 .30766 L .7765 .30948 L 0 .028 .128 r
F
.77341 .3105 m .77205 .30868 L .77515 .30766 L F
.75836 .31134 m .76006 .30819 L .76144 .31019 L 0 .029 .129 r
F
.75836 .31134 m .75698 .30936 L .76006 .30819 L F
.39252 .31635 m .39368 .31339 L .39541 .31531 L 0 .041 .143 r
F
.39252 .31635 m .39079 .31442 L .39368 .31339 L F
.29905 .31135 m .30006 .30849 L .30189 .3104 L 0 .03 .13 r
F
.29905 .31135 m .29722 .30947 L .30006 .30849 L F
.11829 .30865 m .11901 .30579 L .12102 .30768 L 0 .025 .123 r
F
.11829 .30865 m .11628 .30677 L .11901 .30579 L F
.44381 .32118 m .44504 .31838 L .44672 .32043 L 0 .053 .156 r
F
.44381 .32118 m .44213 .31912 L .44504 .31838 L F
.19511 .3095 m .19597 .30646 L .19789 .30845 L 0 .026 .125 r
F
.19511 .3095 m .19318 .30753 L .19597 .30646 L F
.4771 .32961 m .4784 .32608 L .48004 .32843 L 0 .075 .176 r
F
.4771 .32961 m .47546 .32722 L .4784 .32608 L F
.55849 .33274 m .55988 .32841 L .56146 .33086 L 0 .083 .182 r
F
.55849 .33274 m .55691 .33024 L .55988 .32841 L F
.50904 .34609 m .50744 .34067 L .51039 .33934 L 0 .124 .212 r
F
.50744 .34067 m .50878 .33573 L .51039 .33934 L 0 .109 .201 r
F
.50744 .34067 m .50583 .33687 L .50878 .33573 L F
.59745 .32294 m .59891 .31944 L .60044 .3214 L 0 .056 .159 r
F
.59745 .32294 m .59592 .32091 L .59891 .31944 L F
.78094 .31023 m .78268 .30721 L .78403 .30908 L 0 .028 .127 r
F
.78094 .31023 m .77959 .30838 L .78268 .30721 L F
.56897 .32963 m .57038 .32552 L .57194 .32785 L 0 .074 .175 r
F
.56897 .32963 m .5674 .32726 L .57038 .32552 L F
.78846 .30984 m .79023 .30694 L .79157 .30888 L 0 .027 .126 r
F
.78846 .30984 m .78712 .30792 L .79023 .30694 L F
.54263 .37459 m .54394 .35908 L .54555 .36502 L 0 .242 .278 r
F
.54263 .37459 m .54101 .36712 L .54394 .35908 L F
.33369 .31214 m .33475 .30938 L .33654 .31123 L 0 .032 .133 r
F
.33369 .31214 m .3319 .31029 L .33475 .30938 L F
.62298 .31906 m .62448 .31575 L .62599 .31784 L 0 .047 .149 r
F
.62298 .31906 m .62147 .31696 L .62448 .31575 L F
.6305 .31867 m .63201 .31524 L .63351 .31729 L 0 .046 .148 r
F
.6305 .31867 m .629 .31661 L .63201 .31524 L F
.40003 .31618 m .4012 .3133 L .40292 .31524 L 0 .041 .143 r
F
.40003 .31618 m .3983 .31427 L .4012 .3133 L F
.45589 .32328 m .45715 .32001 L .45881 .32248 L 0 .058 .16 r
F
.45589 .32328 m .45423 .32087 L .45715 .32001 L F
.83817 .30972 m .84001 .30684 L .8413 .30875 L 0 .027 .126 r
F
.83817 .30972 m .83687 .30781 L .84001 .30684 L F
.16043 .30911 m .16123 .30619 L .16318 .30818 L 0 .026 .125 r
F
.16043 .30911 m .15847 .30714 L .16123 .30619 L F
.23725 .30995 m .23818 .30694 L .24006 .30892 L 0 .027 .127 r
F
.23725 .30995 m .23537 .30796 L .23818 .30694 L F
.38042 .31476 m .38156 .31194 L .38329 .31402 L 0 .038 .139 r
F
.38042 .31476 m .37868 .31272 L .38156 .31194 L F
.2026 .30939 m .20347 .30632 L .20539 .30835 L 0 .026 .125 r
F
.2026 .30939 m .20068 .30738 L .20347 .30632 L F
.2719 .31066 m .27288 .30766 L .27472 .30966 L 0 .029 .129 r
F
.2719 .31066 m .27005 .30868 L .27288 .30766 L F
.67108 .314 m .67266 .31096 L .67412 .31298 L 0 .036 .137 r
F
.67108 .314 m .66962 .31199 L .67266 .31096 L F
.12576 .30863 m .12651 .30568 L .1285 .30762 L 0 .025 .124 r
F
.12576 .30863 m .12376 .3067 L .12651 .30568 L F
.66356 .3145 m .66512 .31118 L .66659 .31319 L 0 .036 .138 r
F
.66356 .3145 m .66209 .3125 L .66512 .31118 L F
.41963 .31784 m .42084 .31473 L .42254 .31683 L 0 .045 .147 r
F
.41963 .31784 m .41793 .31574 L .42084 .31473 L F
.65604 .31495 m .65759 .31182 L .65907 .31381 L 0 .038 .14 r
F
.65604 .31495 m .65456 .31299 L .65759 .31182 L F
.51064 .35152 m .50904 .34609 L .512 .34429 L 0 .145 .226 r
F
.50904 .34609 m .51039 .33934 L .512 .34429 L 0 .124 .212 r
F
.3608 .31355 m .3619 .31087 L .36367 .31267 L 0 .036 .137 r
F
.3608 .31355 m .35903 .31172 L .3619 .31087 L F
.84572 .30959 m .84758 .30679 L .84886 .30859 L 0 .027 .127 r
F
.84572 .30959 m .84444 .30779 L .84758 .30679 L F
.64852 .31544 m .65006 .31226 L .65154 .31416 L 0 .039 .141 r
F
.64852 .31544 m .64704 .31355 L .65006 .31226 L F
.30654 .31151 m .30757 .30846 L .30938 .31053 L 0 .031 .131 r
F
.30654 .31151 m .30472 .30946 L .30757 .30846 L F
.24475 .30985 m .24568 .30689 L .24756 .30885 L 0 .028 .127 r
F
.24475 .30985 m .24287 .30789 L .24568 .30689 L F
.55097 .33365 m .55236 .33002 L .55394 .33202 L 0 .089 .187 r
F
.55097 .33365 m .54939 .33149 L .55236 .33002 L F
.79602 .30988 m .7978 .30693 L .79914 .3089 L 0 .028 .127 r
F
.79602 .30988 m .79469 .30793 L .7978 .30693 L F
.61547 .3199 m .61695 .31623 L .61847 .31835 L 0 .049 .151 r
F
.61547 .3199 m .61395 .31779 L .61695 .31623 L F
.53247 .46721 m .53391 .48832 L .53545 .47034 L .102 .579 0 r
F
.53247 .46721 m .53091 .48438 L .53391 .48832 L F
.57946 .327 m .58089 .32323 L .58244 .32548 L 0 .068 .17 r
F
.57946 .327 m .5779 .32473 L .58089 .32323 L F
.34119 .3122 m .34227 .30915 L .34405 .31115 L 0 .032 .133 r
F
.34119 .3122 m .33941 .3102 L .34227 .30915 L F
.85325 .30928 m .85512 .30636 L .85638 .30818 L 0 .027 .126 r
F
.85325 .30928 m .85198 .30748 L .85512 .30636 L F
.53617 .3475 m .53457 .34309 L .53753 .33955 L 0 .126 .213 r
F
.53753 .33955 m .53889 .33407 L .54049 .33724 L 0 .104 .198 r
F
.53753 .33955 m .53593 .33589 L .53889 .33407 L F
.53457 .34309 m .53593 .33589 L .53753 .33955 L 0 .113 .205 r
F
.69367 .31307 m .69528 .31001 L .69671 .31189 L 0 .034 .135 r
F
.69367 .31307 m .69223 .31122 L .69528 .31001 L F
.48462 .32977 m .48593 .326 L .48756 .32853 L 0 .076 .177 r
F
.48462 .32977 m .48298 .32725 L .48593 .326 L F
.21008 .30933 m .21096 .30639 L .21287 .30835 L 0 .027 .126 r
F
.21008 .30933 m .20817 .30736 L .21096 .30639 L F
.70119 .3127 m .70282 .30976 L .70425 .3117 L 0 .034 .135 r
F
.70119 .3127 m .69976 .31079 L .70282 .30976 L F
.67862 .31396 m .68021 .31084 L .68166 .31284 L 0 .036 .137 r
F
.67862 .31396 m .67716 .31194 L .68021 .31084 L F
.13324 .30857 m .134 .3056 L .13598 .30759 L 0 .025 .124 r
F
.13324 .30857 m .13125 .30661 L .134 .3056 L F
.86079 .309 m .86268 .30618 L .86394 .30805 L 0 .026 .125 r
F
.86079 .309 m .85952 .30715 L .86268 .30618 L F
.16789 .30921 m .16872 .30612 L .17067 .30813 L F
.16789 .30921 m .16594 .30721 L .16872 .30612 L F
.68615 .31361 m .68775 .31052 L .68919 .31244 L 0 .035 .137 r
F
.68615 .31361 m .6847 .31169 L .68775 .31052 L F
.40753 .31633 m .40871 .31338 L .41043 .31544 L 0 .042 .144 r
F
.40753 .31633 m .40582 .3143 L .40871 .31338 L F
.49572 .43633 m .49697 .44131 L .49854 .45133 L 0 .471 .138 r
F
.80357 .30969 m .80535 .30674 L .80668 .30861 L 0 .028 .127 r
F
.80357 .30969 m .80224 .30782 L .80535 .30674 L F
.58995 .3241 m .59139 .32027 L .59293 .32238 L 0 .06 .162 r
F
.58995 .3241 m .5884 .32193 L .59139 .32027 L F
.27938 .31075 m .28036 .30784 L .2822 .30989 L 0 .03 .13 r
F
.27938 .31075 m .27754 .30872 L .28036 .30784 L F
.53483 .35943 m .53617 .3475 L .53778 .35387 L 0 .173 .242 r
F
.53483 .35943 m .53322 .35183 L .53617 .3475 L F
.53322 .35183 m .53457 .34309 L .53617 .3475 L 0 .145 .225 r
F
.25224 .30974 m .25317 .307 L .25505 .30882 L 0 .028 .128 r
F
.25224 .30974 m .25036 .30792 L .25317 .307 L F
.49892 .4465 m .49732 .44141 L .50014 .45713 L 0 .507 .069 r
F
.49732 .44141 m .49854 .45133 L .50014 .45713 L 0 .493 .098 r
F
.4967 .33189 m .49803 .32826 L .49965 .33105 L 0 .084 .183 r
F
.4967 .33189 m .49508 .32908 L .49803 .32826 L F
.1754 .30894 m .17623 .30599 L .17817 .3079 L 0 .026 .125 r
F
.1754 .30894 m .17345 .30704 L .17623 .30599 L F
.8111 .30936 m .81291 .30654 L .81422 .30835 L 0 .027 .127 r
F
.8111 .30936 m .80979 .30757 L .81291 .30654 L F
.42714 .31792 m .42835 .31484 L .43005 .31696 L 0 .046 .148 r
F
.42714 .31792 m .42544 .3158 L .42835 .31484 L F
.51223 .36016 m .51064 .35152 L .5136 .34925 L 0 .18 .246 r
F
.50927 .36219 m .51064 .35152 L .51223 .36016 L 0 .189 .251 r
F
.51064 .35152 m .512 .34429 L .5136 .34925 L 0 .145 .226 r
F
.56146 .33086 m .56286 .3266 L .56443 .329 L 0 .079 .179 r
F
.56146 .33086 m .55988 .32841 L .56286 .3266 L F
.3683 .31355 m .36941 .3108 L .37118 .3126 L 0 .036 .138 r
F
.3683 .31355 m .36654 .31179 L .36941 .3108 L F
.21758 .30918 m .21847 .30626 L .22038 .30809 L 0 .027 .126 r
F
.21758 .30918 m .21566 .30735 L .21847 .30626 L F
.49892 .4465 m .50014 .45713 L .50175 .46294 L 0 .507 .069 r
F
.43923 .31984 m .44045 .31705 L .44213 .31912 L 0 .051 .154 r
F
.43923 .31984 m .43754 .31775 L .44045 .31705 L F
.60796 .32068 m .60943 .31731 L .61096 .31934 L 0 .052 .155 r
F
.60796 .32068 m .60643 .31866 L .60943 .31731 L F
.45131 .32173 m .45256 .31876 L .45423 .32087 L 0 .056 .158 r
F
.45131 .32173 m .44964 .31968 L .45256 .31876 L F
.34869 .31214 m .34977 .30929 L .35154 .31134 L 0 .033 .134 r
F
.34869 .31214 m .34692 .31013 L .34977 .30929 L F
.47253 .32822 m .47381 .32483 L .47546 .32722 L 0 .073 .174 r
F
.47253 .32822 m .47088 .32581 L .47381 .32483 L F
.2251 .30883 m .22599 .306 L .22789 .30784 L 0 .026 .125 r
F
.2251 .30883 m .22319 .307 L .22599 .306 L F
.31403 .31155 m .31508 .30846 L .31688 .31052 L 0 .031 .132 r
F
.31403 .31155 m .31222 .30949 L .31508 .30846 L F
.54049 .33724 m .54186 .33226 L .54345 .33493 L 0 .098 .194 r
F
.54049 .33724 m .53889 .33407 L .54186 .33226 L F
.57194 .32785 m .57336 .32393 L .57492 .32623 L 0 .071 .172 r
F
.57194 .32785 m .57038 .32552 L .57336 .32393 L F
.54425 .38206 m .54555 .36502 L .54716 .37097 L 0 .284 .297 r
F
.54425 .38206 m .54263 .37459 L .54555 .36502 L F
.73883 .31098 m .74051 .30795 L .7419 .30984 L 0 .03 .131 r
F
.73883 .31098 m .73744 .30912 L .74051 .30795 L F
.71626 .31224 m .7179 .30905 L .71932 .31106 L 0 .033 .133 r
F
.71626 .31224 m .71484 .31023 L .7179 .30905 L F
.70874 .31267 m .71036 .30948 L .71179 .31147 L 0 .034 .135 r
F
.70874 .31267 m .70731 .31069 L .71036 .30948 L F
.10606 .30788 m .10676 .30506 L .10879 .30689 L 0 .025 .123 r
F
.10606 .30788 m .10402 .30606 L .10676 .30506 L F
.14072 .30851 m .14147 .30571 L .14346 .30757 L 0 .026 .125 r
F
.14072 .30851 m .13873 .30665 L .14147 .30571 L F
.64102 .31645 m .64254 .31305 L .64403 .315 L 0 .042 .144 r
F
.64102 .31645 m .63953 .31446 L .64254 .31305 L F
.50127 .3344 m .5026 .33021 L .50421 .33349 L 0 .091 .188 r
F
.50127 .3344 m .49965 .33105 L .5026 .33021 L F
.81864 .30916 m .82046 .30631 L .82177 .30814 L 0 .027 .126 r
F
.81864 .30916 m .81734 .30734 L .82046 .30631 L F
.1829 .30876 m .18373 .30588 L .18567 .30776 L 0 .026 .125 r
F
.1829 .30876 m .18095 .30689 L .18373 .30588 L F
.74636 .31065 m .74805 .30759 L .74944 .30956 L 0 .03 .13 r
F
.74636 .31065 m .74498 .30871 L .74805 .30759 L F
.73132 .31159 m .73299 .30851 L .73438 .31035 L 0 .032 .132 r
F
.73132 .31159 m .72993 .30977 L .73299 .30851 L F
.25974 .30971 m .26067 .30696 L .26255 .30878 L 0 .028 .128 r
F
.25974 .30971 m .25786 .30789 L .26067 .30696 L F
.32154 .31138 m .32259 .30838 L .32439 .31033 L 0 .031 .132 r
F
.32154 .31138 m .31973 .30945 L .32259 .30838 L F
.7238 .31201 m .72545 .30897 L .72686 .31095 L 0 .033 .133 r
F
.7238 .31201 m .72238 .31002 L .72545 .30897 L F
.60044 .3214 m .60191 .3181 L .60344 .32001 L 0 .055 .157 r
F
.60044 .3214 m .59891 .31944 L .60191 .3181 L F
.3879 .31536 m .38905 .31232 L .39079 .31442 L 0 .04 .142 r
F
.3879 .31536 m .38617 .31327 L .38905 .31232 L F
.50583 .33687 m .50717 .33248 L .50878 .33573 L 0 .099 .195 r
F
.50583 .33687 m .50421 .33349 L .50717 .33248 L F
.51519 .35715 m .5136 .34925 L .51656 .34691 L 0 .167 .239 r
F
.51223 .36016 m .5136 .34925 L .51519 .35715 L 0 .18 .246 r
F
.5136 .34925 m .51495 .34244 L .51656 .34691 L 0 .138 .221 r
F
.5136 .34925 m .512 .34429 L .51495 .34244 L F
.7539 .31045 m .7556 .30737 L .75698 .30936 L 0 .03 .13 r
F
.7539 .31045 m .75252 .30846 L .7556 .30737 L F
.82619 .30899 m .82802 .30608 L .82932 .30797 L 0 .027 .126 r
F
.82619 .30899 m .82489 .30712 L .82802 .30608 L F
.11354 .30774 m .11426 .30492 L .11628 .30677 L 0 .025 .123 r
F
.11354 .30774 m .11152 .3059 L .11426 .30492 L F
.28686 .31088 m .28786 .30795 L .2897 .30981 L 0 .031 .131 r
F
.28686 .31088 m .28502 .30903 L .28786 .30795 L F
.37581 .31359 m .37693 .31071 L .37868 .31272 L 0 .037 .138 r
F
.37581 .31359 m .37406 .31163 L .37693 .31071 L F
.1904 .30859 m .19124 .30566 L .19318 .30753 L 0 .026 .125 r
F
.1904 .30859 m .18846 .30671 L .19124 .30566 L F
.14821 .30838 m .14899 .30546 L .15097 .3073 L F
.14821 .30838 m .14622 .30655 L .14899 .30546 L F
.49213 .33009 m .49345 .32627 L .49508 .32908 L 0 .079 .179 r
F
.49213 .33009 m .49051 .32728 L .49345 .32627 L F
.55569 .42391 m .55418 .42886 L .55702 .41317 L 0 .412 .225 r
F
.55418 .42886 m .55547 .414 L .55702 .41317 L 0 .43 .202 r
F
.512 .34429 m .51335 .33797 L .51495 .34244 L 0 .121 .21 r
F
.512 .34429 m .51039 .33934 L .51335 .33797 L F
.54345 .33493 m .54483 .33065 L .54642 .33296 L 0 .093 .19 r
F
.54345 .33493 m .54186 .33226 L .54483 .33065 L F
.50492 .37705 m .50336 .3652 L .50631 .36421 L 0 .271 .292 r
F
.50198 .37651 m .50336 .3652 L .50492 .37705 L 0 .265 .289 r
F
.53322 .35183 m .53161 .34667 L .53457 .34309 L 0 .145 .225 r
F
.53457 .34309 m .53297 .33869 L .53593 .33589 L 0 .113 .205 r
F
.53161 .34667 m .53297 .33869 L .53457 .34309 L 0 .126 .213 r
F
.51039 .33934 m .51174 .33457 L .51335 .33797 L 0 .107 .2 r
F
.51039 .33934 m .50878 .33573 L .51174 .33457 L F
.23258 .30887 m .23348 .306 L .23537 .30796 L 0 .027 .126 r
F
.23258 .30887 m .23069 .30692 L .23348 .306 L F
.29438 .31054 m .29539 .30763 L .29722 .30947 L 0 .03 .13 r
F
.29438 .31054 m .29254 .30871 L .29539 .30763 L F
.76896 .3097 m .7707 .30683 L .77205 .30868 L 0 .028 .128 r
F
.76896 .3097 m .7676 .30786 L .7707 .30683 L F
.46795 .32642 m .46923 .32305 L .47088 .32581 L 0 .069 .17 r
F
.46795 .32642 m .46631 .32372 L .46923 .32305 L F
.32905 .3112 m .33009 .30844 L .3319 .31029 L 0 .032 .132 r
F
.32905 .3112 m .32724 .30934 L .33009 .30844 L F
.41503 .31665 m .41622 .31364 L .41793 .31574 L 0 .044 .146 r
F
.41503 .31665 m .41332 .31454 L .41622 .31364 L F
.76144 .31019 m .76314 .30701 L .76452 .30901 L 0 .029 .129 r
F
.76144 .31019 m .76006 .30819 L .76314 .30701 L F
.15572 .3081 m .1565 .30525 L .15847 .30714 L 0 .025 .124 r
F
.15572 .3081 m .15374 .30623 L .1565 .30525 L F
.63351 .31729 m .63502 .31385 L .63652 .31587 L 0 .044 .147 r
F
.63351 .31729 m .63201 .31524 L .63502 .31385 L F
.48004 .32843 m .48134 .32492 L .48298 .32725 L 0 .075 .175 r
F
.48004 .32843 m .4784 .32608 L .48134 .32492 L F
.49515 .41931 m .49361 .40672 L .49648 .41465 L 0 .42 .216 r
F
.49361 .40672 m .49495 .40166 L .49648 .41465 L 0 .376 .265 r
F
.83374 .30883 m .83557 .30587 L .83687 .30781 L 0 .027 .126 r
F
.83374 .30883 m .83244 .30692 L .83557 .30587 L F
.39541 .31531 m .39657 .31235 L .3983 .31427 L 0 .041 .143 r
F
.39541 .31531 m .39368 .31339 L .39657 .31235 L F
.55394 .33202 m .55534 .32827 L .55691 .33024 L 0 .086 .184 r
F
.55394 .33202 m .55236 .33002 L .55534 .32827 L F
.7765 .30948 m .77824 .30653 L .77959 .30838 L 0 .028 .128 r
F
.7765 .30948 m .77515 .30766 L .77824 .30653 L F
.62599 .31784 m .62749 .31455 L .629 .31661 L 0 .046 .149 r
F
.62599 .31784 m .62448 .31575 L .62749 .31455 L F
.19789 .30845 m .19876 .30538 L .20068 .30738 L 0 .026 .125 r
F
.19789 .30845 m .19597 .30646 L .19876 .30538 L F
.78403 .30908 m .78577 .30603 L .78712 .30792 L 0 .027 .127 r
F
.78403 .30908 m .78268 .30721 L .78577 .30603 L F
.26723 .30971 m .26819 .30677 L .27005 .30868 L 0 .029 .128 r
F
.26723 .30971 m .26536 .30783 L .26819 .30677 L F
.51816 .354 m .51656 .34691 L .51952 .34453 L 0 .155 .232 r
F
.51519 .35715 m .51656 .34691 L .51816 .354 L 0 .167 .239 r
F
.51656 .34691 m .51791 .34051 L .51952 .34453 L 0 .131 .217 r
F
.51656 .34691 m .51495 .34244 L .51791 .34051 L F
.12102 .30768 m .12175 .30482 L .12376 .3067 L 0 .025 .123 r
F
.12102 .30768 m .11901 .30579 L .12175 .30482 L F
.46339 .32439 m .46466 .32099 L .46631 .32372 L 0 .063 .165 r
F
.46339 .32439 m .46173 .32171 L .46466 .32099 L F
.30189 .3104 m .3029 .30751 L .30472 .30946 L 0 .03 .13 r
F
.30189 .3104 m .30006 .30849 L .3029 .30751 L F
.61847 .31835 m .61995 .31485 L .62147 .31696 L 0 .047 .15 r
F
.61847 .31835 m .61695 .31623 L .61995 .31485 L F
.56443 .329 m .56583 .32489 L .5674 .32726 L 0 .075 .176 r
F
.56443 .329 m .56286 .3266 L .56583 .32489 L F
.5006 .38689 m .49904 .37597 L .50198 .37651 L 0 .321 .302 r
F
.49768 .38394 m .49904 .37597 L .5006 .38689 L 0 .311 .307 r
F
.35617 .31253 m .35727 .30972 L .35903 .31172 L 0 .035 .136 r
F
.35617 .31253 m .3544 .31054 L .35727 .30972 L F
.58244 .32548 m .58387 .32153 L .58542 .32371 L 0 .065 .167 r
F
.58244 .32548 m .58089 .32323 L .58387 .32153 L F
.59293 .32238 m .59438 .31888 L .59592 .32091 L 0 .058 .16 r
F
.59293 .32238 m .59139 .32027 L .59438 .31888 L F
.43464 .31841 m .43585 .31565 L .43754 .31775 L 0 .049 .151 r
F
.43464 .31841 m .43295 .3163 L .43585 .31565 L F
.66659 .31319 m .66815 .30997 L .66962 .31199 L 0 .036 .137 r
F
.66659 .31319 m .66512 .31118 L .66815 .30997 L F
.79157 .30888 m .79334 .30597 L .79469 .30793 L 0 .027 .127 r
F
.79157 .30888 m .79023 .30694 L .79334 .30597 L F
.24006 .30892 m .24099 .30592 L .24287 .30789 L F
.24006 .30892 m .23818 .30694 L .24099 .30592 L F
.33654 .31123 m .33761 .30836 L .33941 .3102 L 0 .032 .133 r
F
.33654 .31123 m .33475 .30938 L .33761 .30836 L F
.65154 .31416 m .65309 .31109 L .65456 .31299 L 0 .038 .14 r
F
.65154 .31416 m .65006 .31226 L .65309 .31109 L F
.44672 .32043 m .44796 .31763 L .44964 .31968 L 0 .054 .157 r
F
.44672 .32043 m .44504 .31838 L .44796 .31763 L F
.8413 .30875 m .84315 .30588 L .84444 .30779 L 0 .027 .127 r
F
.8413 .30875 m .84001 .30684 L .84315 .30588 L F
.53593 .33589 m .5373 .33125 L .53889 .33407 L 0 .096 .192 r
F
.53593 .33589 m .53433 .33271 L .5373 .33125 L F
.53297 .33869 m .53433 .33271 L .53593 .33589 L 0 .102 .197 r
F
.54587 .38952 m .54716 .37097 L .54877 .37693 L 0 .317 .304 r
F
.54587 .38952 m .54425 .38206 L .54716 .37097 L F
.20539 .30835 m .20626 .30534 L .20817 .30736 L 0 .026 .125 r
F
.20539 .30835 m .20347 .30632 L .20626 .30534 L F
.40292 .31524 m .40409 .31233 L .40582 .3143 L 0 .041 .143 r
F
.40292 .31524 m .4012 .3133 L .40409 .31233 L F
.49921 .39889 m .49768 .38394 L .5006 .38689 L 0 .356 .281 r
F
.4963 .39421 m .49768 .38394 L .49921 .39889 L 0 .337 .294 r
F
.67412 .31298 m .6757 .30992 L .67716 .31194 L 0 .036 .137 r
F
.67412 .31298 m .67266 .31096 L .6757 .30992 L F
.65907 .31381 m .66062 .3105 L .66209 .3125 L 0 .037 .139 r
F
.65907 .31381 m .65759 .31182 L .66062 .3105 L F
.16318 .30818 m .16399 .3052 L .16594 .30721 L 0 .026 .125 r
F
.16318 .30818 m .16123 .30619 L .16399 .3052 L F
.27472 .30966 m .2757 .30669 L .27754 .30872 L 0 .029 .129 r
F
.27472 .30966 m .27288 .30766 L .2757 .30669 L F
.52112 .35084 m .51952 .34453 L .52248 .34205 L 0 .143 .224 r
F
.51816 .354 m .51952 .34453 L .52112 .35084 L 0 .155 .232 r
F
.51952 .34453 m .52087 .3384 L .52248 .34205 L 0 .124 .212 r
F
.51952 .34453 m .51791 .34051 L .52087 .3384 L F
.53161 .34667 m .53001 .34151 L .53297 .33869 L 0 .126 .213 r
F
.53297 .33869 m .53137 .33496 L .53433 .33271 L 0 .102 .197 r
F
.53001 .34151 m .53137 .33496 L .53297 .33869 L 0 .111 .203 r
F
.1285 .30762 m .12926 .30464 L .13125 .30661 L 0 .025 .124 r
F
.1285 .30762 m .12651 .30568 L .12926 .30464 L F
.42254 .31683 m .42375 .3137 L .42544 .3158 L 0 .045 .147 r
F
.42254 .31683 m .42084 .31473 L .42375 .3137 L F
.57492 .32623 m .57634 .32247 L .5779 .32473 L 0 .068 .17 r
F
.57492 .32623 m .57336 .32393 L .57634 .32247 L F
.48756 .32853 m .48887 .32476 L .49051 .32728 L 0 .075 .176 r
F
.48756 .32853 m .48593 .326 L .48887 .32476 L F
.45881 .32248 m .46008 .31917 L .46173 .32171 L 0 .059 .161 r
F
.45881 .32248 m .45715 .32001 L .46008 .31917 L F
.52865 .35045 m .53001 .34151 L .53161 .34667 L 0 .141 .223 r
F
.52865 .35045 m .52705 .34446 L .53001 .34151 L F
.53001 .34151 m .5284 .33723 L .53137 .33496 L 0 .111 .203 r
F
.52705 .34446 m .5284 .33723 L .53001 .34151 L 0 .12 .21 r
F
.54642 .33296 m .54781 .32933 L .54939 .33149 L 0 .09 .187 r
F
.54642 .33296 m .54483 .33065 L .54781 .32933 L F
.69671 .31189 m .69833 .30888 L .69976 .31079 L 0 .034 .135 r
F
.69671 .31189 m .69528 .31001 L .69833 .30888 L F
.55392 .41483 m .55234 .41302 L .55518 .39625 L 0 .384 .257 r
F
.55234 .41302 m .55359 .39244 L .55518 .39625 L 0 .379 .261 r
F
.53644 .3671 m .53778 .35387 L .53939 .36031 L 0 .212 .263 r
F
.53644 .3671 m .53483 .35943 L .53778 .35387 L F
.38329 .31402 m .38443 .31115 L .38617 .31327 L 0 .039 .141 r
F
.38329 .31402 m .38156 .31194 L .38443 .31115 L F
.84886 .30859 m .85071 .30566 L .85198 .30748 L 0 .027 .126 r
F
.84886 .30859 m .84758 .30679 L .85071 .30566 L F
.85638 .30818 m .85826 .30532 L .85952 .30715 L 0 .026 .125 r
F
.85638 .30818 m .85512 .30636 L .85826 .30532 L F
.50669 .46017 m .5079 .48038 L .50956 .47731 L .056 .562 0 r
F
.50669 .46017 m .50504 .46243 L .5079 .48038 L F
.51495 .34244 m .51631 .3365 L .51791 .34051 L 0 .117 .207 r
F
.51495 .34244 m .51335 .33797 L .51631 .3365 L F
.24756 .30885 m .24849 .30594 L .25036 .30792 L 0 .028 .127 r
F
.24756 .30885 m .24568 .30689 L .24849 .30594 L F
.34405 .31115 m .34514 .30812 L .34692 .31013 L 0 .032 .133 r
F
.34405 .31115 m .34227 .30915 L .34514 .30812 L F
.30938 .31053 m .31042 .30743 L .31222 .30949 L 0 .031 .131 r
F
.30938 .31053 m .30757 .30846 L .31042 .30743 L F
.52408 .34765 m .52248 .34205 L .52544 .33958 L 0 .131 .217 r
F
.52112 .35084 m .52248 .34205 L .52408 .34765 L 0 .143 .224 r
F
.52248 .34205 m .52384 .33629 L .52544 .33958 L 0 .116 .206 r
F
.52248 .34205 m .52087 .3384 L .52384 .33629 L F
.68166 .31284 m .68325 .30971 L .6847 .31169 L 0 .036 .137 r
F
.68166 .31284 m .68021 .31084 L .68325 .30971 L F
.53026 .35644 m .53161 .34667 L .53322 .35183 L 0 .166 .238 r
F
.53026 .35644 m .52865 .35045 L .53161 .34667 L F
.68919 .31244 m .69079 .30932 L .69223 .31122 L 0 .035 .136 r
F
.68919 .31244 m .68775 .31052 L .69079 .30932 L F
.79914 .3089 m .80091 .30585 L .80224 .30782 L 0 .028 .127 r
F
.79914 .3089 m .7978 .30693 L .80091 .30585 L F
.61096 .31934 m .61243 .31576 L .61395 .31779 L 0 .05 .153 r
F
.61096 .31934 m .60943 .31731 L .61243 .31576 L F
.36367 .31267 m .36477 .31002 L .36654 .31179 L 0 .036 .138 r
F
.36367 .31267 m .3619 .31087 L .36477 .31002 L F
.49541 .43077 m .49385 .4202 L .49669 .43195 L 0 .459 .158 r
F
.49385 .4202 m .49515 .41931 L .49669 .43195 L 0 .42 .216 r
F
.64403 .315 m .64555 .31164 L .64704 .31355 L 0 .04 .142 r
F
.64403 .315 m .64254 .31305 L .64555 .31164 L F
.17067 .30813 m .1715 .30503 L .17345 .30704 L 0 .026 .125 r
F
.17067 .30813 m .16872 .30612 L .1715 .30503 L F
.52569 .35459 m .52705 .34446 L .52865 .35045 L 0 .158 .233 r
F
.52569 .35459 m .52408 .34765 L .52705 .34446 L F
.52705 .34446 m .52544 .33958 L .5284 .33723 L 0 .12 .21 r
F
.52408 .34765 m .52544 .33958 L .52705 .34446 L 0 .131 .217 r
F
.21287 .30835 m .21375 .3054 L .21566 .30735 L 0 .027 .126 r
F
.21287 .30835 m .21096 .30639 L .21375 .3054 L F
.70425 .3117 m .70588 .30872 L .70731 .31069 L 0 .034 .135 r
F
.70425 .3117 m .70282 .30976 L .70588 .30872 L F
.53187 .36536 m .53322 .35183 L .53483 .35943 L 0 .204 .259 r
F
.53187 .36536 m .53026 .35644 L .53322 .35183 L F
.80668 .30861 m .80847 .3057 L .80979 .30757 L 0 .027 .127 r
F
.80668 .30861 m .80535 .30674 L .80847 .3057 L F
.13598 .30759 m .13674 .30467 L .13873 .30665 L 0 .025 .124 r
F
.13598 .30759 m .134 .3056 L .13674 .30467 L F
.86394 .30805 m .86583 .30521 L .8671 .3071 L 0 .027 .126 r
F
.86394 .30805 m .86268 .30618 L .86583 .30521 L F
.52544 .33958 m .5268 .33424 L .5284 .33723 L 0 .109 .201 r
F
.52544 .33958 m .52384 .33629 L .5268 .33424 L F
.22038 .30809 m .22127 .30516 L .22319 .307 L 0 .027 .126 r
F
.22038 .30809 m .21847 .30626 L .22127 .30516 L F
.55691 .33024 m .55831 .32644 L .55988 .32841 L 0 .081 .181 r
F
.55691 .33024 m .55534 .32827 L .55831 .32644 L F
.60344 .32001 m .60491 .3168 L .60643 .31866 L 0 .053 .156 r
F
.60344 .32001 m .60191 .3181 L .60491 .3168 L F
.17817 .3079 m .179 .30496 L .18095 .30689 L 0 .026 .125 r
F
.17817 .3079 m .17623 .30599 L .179 .30496 L F
.71179 .31147 m .71342 .30823 L .71484 .31023 L 0 .033 .134 r
F
.71179 .31147 m .71036 .30948 L .71342 .30823 L F
.41043 .31544 m .41161 .3125 L .41332 .31454 L 0 .042 .145 r
F
.41043 .31544 m .40871 .31338 L .41161 .3125 L F
.81422 .30835 m .81603 .30551 L .81734 .30734 L 0 .027 .127 r
F
.81422 .30835 m .81291 .30654 L .81603 .30551 L F
.71932 .31106 m .72097 .30801 L .72238 .31002 L 0 .032 .133 r
F
.71932 .31106 m .7179 .30905 L .72097 .30801 L F
.7419 .30984 m .74359 .30678 L .74498 .30871 L 0 .03 .13 r
F
.7419 .30984 m .74051 .30795 L .74359 .30678 L F
.43005 .31696 m .43126 .31419 L .43295 .3163 L 0 .046 .149 r
F
.43005 .31696 m .42835 .31484 L .43126 .31419 L F
.25505 .30882 m .25598 .30607 L .25786 .30789 L 0 .028 .128 r
F
.25505 .30882 m .25317 .307 L .25598 .30607 L F
.37118 .3126 m .3723 .30979 L .37406 .31163 L 0 .036 .138 r
F
.37118 .3126 m .36941 .3108 L .3723 .30979 L F
.2822 .30989 m .28319 .30696 L .28502 .30903 L 0 .03 .13 r
F
.2822 .30989 m .28036 .30784 L .28319 .30696 L F
.31688 .31052 m .31793 .30737 L .31973 .30945 L 0 .031 .132 r
F
.31688 .31052 m .31508 .30846 L .31793 .30737 L F
.47546 .32722 m .47675 .32372 L .4784 .32608 L 0 .073 .174 r
F
.47546 .32722 m .47381 .32483 L .47675 .32372 L F
.22789 .30784 m .22878 .30506 L .23069 .30692 L 0 .026 .126 r
F
.22789 .30784 m .22599 .306 L .22878 .30506 L F
.5674 .32726 m .56881 .32318 L .57038 .32552 L 0 .072 .173 r
F
.5674 .32726 m .56583 .32489 L .56881 .32318 L F
.58542 .32371 m .58685 .3198 L .5884 .32193 L 0 .062 .164 r
F
.58542 .32371 m .58387 .32153 L .58685 .3198 L F
.73438 .31035 m .73605 .30726 L .73744 .30912 L 0 .031 .131 r
F
.73438 .31035 m .73299 .30851 L .73605 .30726 L F
.49965 .33105 m .50097 .32745 L .5026 .33021 L 0 .085 .184 r
F
.49965 .33105 m .49803 .32826 L .50097 .32745 L F
.74944 .30956 m .75113 .30649 L .75252 .30846 L 0 .029 .129 r
F
.74944 .30956 m .74805 .30759 L .75113 .30649 L F
.51335 .33797 m .5147 .33328 L .51631 .3365 L 0 .105 .199 r
F
.51335 .33797 m .51174 .33457 L .5147 .33328 L F
.45423 .32087 m .45549 .31783 L .45715 .32001 L 0 .056 .159 r
F
.45423 .32087 m .45256 .31876 L .45549 .31783 L F
.82177 .30814 m .82359 .30529 L .82489 .30712 L 0 .027 .126 r
F
.82177 .30814 m .82046 .30631 L .82359 .30529 L F
.10879 .30689 m .1095 .30406 L .11152 .3059 L 0 .025 .123 r
F
.10879 .30689 m .10676 .30506 L .1095 .30406 L F
.63652 .31587 m .63803 .31246 L .63953 .31446 L 0 .043 .145 r
F
.63652 .31587 m .63502 .31385 L .63803 .31246 L F
.50878 .33573 m .51012 .33145 L .51174 .33457 L 0 .099 .194 r
F
.50878 .33573 m .50717 .33248 L .51012 .33145 L F
.18567 .30776 m .18651 .30483 L .18846 .30671 L 0 .026 .125 r
F
.18567 .30776 m .18373 .30588 L .18651 .30483 L F
.53889 .33407 m .54027 .32979 L .54186 .33226 L 0 .093 .19 r
F
.53889 .33407 m .5373 .33125 L .54027 .32979 L F
.52272 .35875 m .52408 .34765 L .52569 .35459 L 0 .177 .244 r
F
.52272 .35875 m .52112 .35084 L .52408 .34765 L F
.14346 .30757 m .14423 .30469 L .14622 .30655 L 0 .026 .125 r
F
.14346 .30757 m .14147 .30571 L .14423 .30469 L F
.5284 .33723 m .52977 .33223 L .53137 .33496 L 0 .102 .197 r
F
.5284 .33723 m .5268 .33424 L .52977 .33223 L F
.35154 .31134 m .35264 .30846 L .3544 .31054 L 0 .034 .135 r
F
.35154 .31134 m .34977 .30929 L .35264 .30846 L F
.50421 .33349 m .50555 .32931 L .50717 .33248 L 0 .092 .189 r
F
.50421 .33349 m .5026 .33021 L .50555 .32931 L F
.5475 .39698 m .54877 .37693 L .55038 .38291 L 0 .337 .294 r
F
.5475 .39698 m .54587 .38952 L .54877 .37693 L F
.72686 .31095 m .72852 .3078 L .72993 .30977 L 0 .032 .133 r
F
.72686 .31095 m .72545 .30897 L .72852 .3078 L F
.32439 .31033 m .32544 .30738 L .32724 .30934 L 0 .031 .132 r
F
.32439 .31033 m .32259 .30838 L .32544 .30738 L F
.44213 .31912 m .44336 .31632 L .44504 .31838 L 0 .052 .155 r
F
.44213 .31912 m .44045 .31705 L .44336 .31632 L F
.75698 .30936 m .75868 .3062 L .76006 .30819 L 0 .029 .129 r
F
.75698 .30936 m .7556 .30737 L .75868 .3062 L F
.2897 .30981 m .2907 .30685 L .29254 .30871 L 0 .03 .131 r
F
.2897 .30981 m .28786 .30795 L .2907 .30685 L F
.15097 .3073 m .15176 .30437 L .15374 .30623 L 0 .026 .124 r
F
.15097 .3073 m .14899 .30546 L .15176 .30437 L F
.51791 .34051 m .51927 .33474 L .52087 .3384 L 0 .112 .204 r
F
.51791 .34051 m .51631 .3365 L .51927 .33474 L F
.26255 .30878 m .26349 .30601 L .26536 .30783 L 0 .029 .128 r
F
.26255 .30878 m .26067 .30696 L .26349 .30601 L F
.19318 .30753 m .19403 .30458 L .19597 .30646 L 0 .026 .125 r
F
.19318 .30753 m .19124 .30566 L .19403 .30458 L F
.39079 .31442 m .39195 .31126 L .39368 .31339 L 0 .04 .142 r
F
.39079 .31442 m .38905 .31232 L .39195 .31126 L F
.59592 .32091 m .59738 .31748 L .59891 .31944 L 0 .056 .158 r
F
.59592 .32091 m .59438 .31888 L .59738 .31748 L F
.76452 .30901 m .76623 .30586 L .7676 .30786 L 0 .029 .128 r
F
.76452 .30901 m .76314 .30701 L .76623 .30586 L F
.82932 .30797 m .83114 .305 L .83244 .30692 L 0 .027 .126 r
F
.82932 .30797 m .82802 .30608 L .83114 .305 L F
.62147 .31696 m .62296 .31367 L .62448 .31575 L 0 .046 .149 r
F
.62147 .31696 m .61995 .31485 L .62296 .31367 L F
.49508 .32908 m .4964 .32547 L .49803 .32826 L 0 .079 .179 r
F
.49508 .32908 m .49345 .32627 L .4964 .32547 L F
.29722 .30947 m .29823 .30661 L .30006 .30849 L 0 .03 .13 r
F
.29722 .30947 m .29539 .30763 L .29823 .30661 L F
.11628 .30677 m .117 .30394 L .11901 .30579 L 0 .025 .123 r
F
.11628 .30677 m .11426 .30492 L .117 .30394 L F
.48298 .32725 m .48429 .32369 L .48593 .326 L 0 .074 .175 r
F
.48298 .32725 m .48134 .32492 L .48429 .32369 L F
.50788 .37607 m .50631 .36421 L .50927 .36219 L 0 .266 .289 r
F
.50492 .37705 m .50631 .36421 L .50788 .37607 L 0 .271 .292 r
F
.629 .31661 m .6305 .31321 L .63201 .31524 L 0 .045 .147 r
F
.629 .31661 m .62749 .31455 L .6305 .31321 L F
.77205 .30868 m .7738 .3058 L .77515 .30766 L 0 .028 .128 r
F
.77205 .30868 m .7707 .30683 L .7738 .3058 L F
.37868 .31272 m .37981 .30989 L .38156 .31194 L 0 .037 .139 r
F
.37868 .31272 m .37693 .31071 L .37981 .30989 L F
.78712 .30792 m .78889 .30503 L .79023 .30694 L 0 .027 .126 r
F
.78712 .30792 m .78577 .30603 L .78889 .30503 L F
.23537 .30796 m .23629 .30498 L .23818 .30694 L F
.23537 .30796 m .23348 .306 L .23629 .30498 L F
.77959 .30838 m .78133 .30534 L .78268 .30721 L 0 .028 .127 r
F
.77959 .30838 m .77824 .30653 L .78133 .30534 L F
.15847 .30714 m .15926 .30428 L .16123 .30619 L 0 .026 .124 r
F
.15847 .30714 m .1565 .30525 L .15926 .30428 L F
.3319 .31029 m .33295 .30753 L .33475 .30938 L 0 .032 .133 r
F
.3319 .31029 m .33009 .30844 L .33295 .30753 L F
.3983 .31427 m .39947 .31135 L .4012 .3133 L 0 .041 .143 r
F
.3983 .31427 m .39657 .31235 L .39947 .31135 L F
.20068 .30738 m .20156 .3043 L .20347 .30632 L 0 .026 .125 r
F
.20068 .30738 m .19876 .30538 L .20156 .3043 L F
.41793 .31574 m .41913 .31263 L .42084 .31473 L 0 .044 .146 r
F
.41793 .31574 m .41622 .31364 L .41913 .31263 L F
.53137 .33496 m .53273 .33023 L .53433 .33271 L 0 .096 .192 r
F
.53137 .33496 m .52977 .33223 L .53273 .33023 L F
.66962 .31199 m .67119 .30893 L .67266 .31096 L 0 .035 .137 r
F
.66962 .31199 m .66815 .30997 L .67119 .30893 L F
.83687 .30781 m .83871 .30489 L .84001 .30684 L 0 .027 .126 r
F
.83687 .30781 m .83557 .30587 L .83871 .30489 L F
.5779 .32473 m .57933 .321 L .58089 .32323 L 0 .066 .168 r
F
.5779 .32473 m .57634 .32247 L .57933 .321 L F
.51976 .36291 m .52112 .35084 L .52272 .35875 L 0 .196 .255 r
F
.51976 .36291 m .51816 .354 L .52112 .35084 L F
.5273 .36155 m .52865 .35045 L .53026 .35644 L 0 .191 .252 r
F
.5273 .36155 m .52569 .35459 L .52865 .35045 L F
.27005 .30868 m .27102 .30572 L .27288 .30766 L 0 .029 .128 r
F
.27005 .30868 m .26819 .30677 L .27102 .30572 L F
.55234 .41302 m .55073 .40856 L .55359 .39244 L 0 .379 .261 r
F
.55073 .40856 m .55199 .38863 L .55359 .39244 L 0 .37 .27 r
F
.54939 .33149 m .55078 .32801 L .55236 .33002 L 0 .088 .186 r
F
.54939 .33149 m .54781 .32933 L .55078 .32801 L F
.66209 .3125 m .66364 .30917 L .66512 .31118 L 0 .036 .138 r
F
.66209 .3125 m .66062 .3105 L .66364 .30917 L F
.55988 .32841 m .56129 .32464 L .56286 .3266 L 0 .077 .178 r
F
.55988 .32841 m .55831 .32644 L .56129 .32464 L F
.12376 .3067 m .1245 .30378 L .12651 .30568 L 0 .025 .124 r
F
.12376 .3067 m .12175 .30482 L .1245 .30378 L F
.61395 .31779 m .61543 .31421 L .61695 .31623 L 0 .048 .151 r
F
.61395 .31779 m .61243 .31576 L .61543 .31421 L F
.65456 .31299 m .65612 .30992 L .65759 .31182 L 0 .038 .139 r
F
.65456 .31299 m .65309 .31109 L .65612 .30992 L F
.30472 .30946 m .30575 .3065 L .30757 .30846 L 0 .03 .131 r
F
.30472 .30946 m .3029 .30751 L .30575 .3065 L F
.54433 .45944 m .54284 .47582 L .54577 .46486 L 0 .535 .008 r
F
.54138 .46442 m .54284 .47582 L .54433 .45944 L .057 .562 0 r
F
.47088 .32581 m .47217 .32209 L .47381 .32483 L 0 .07 .171 r
F
.47088 .32581 m .46923 .32305 L .47217 .32209 L F
.49051 .32728 m .49182 .32373 L .49345 .32627 L 0 .075 .175 r
F
.49051 .32728 m .48887 .32476 L .49182 .32373 L F
.53806 .37526 m .53939 .36031 L .54101 .36712 L 0 .257 .285 r
F
.53806 .37526 m .53644 .3671 L .53939 .36031 L F
.24287 .30789 m .2438 .30491 L .24568 .30689 L 0 .027 .127 r
F
.24287 .30789 m .24099 .30592 L .2438 .30491 L F
.64704 .31355 m .64858 .31039 L .65006 .31226 L 0 .039 .141 r
F
.64704 .31355 m .64555 .31164 L .64858 .31039 L F
.33941 .3102 m .34048 .30731 L .34227 .30915 L 0 .032 .133 r
F
.33941 .3102 m .33761 .30836 L .34048 .30731 L F
.52087 .3384 m .52223 .33299 L .52384 .33629 L 0 .106 .2 r
F
.52087 .3384 m .51927 .33474 L .52223 .33299 L F
.79469 .30793 m .79646 .30496 L .7978 .30693 L 0 .027 .127 r
F
.79469 .30793 m .79334 .30597 L .79646 .30496 L F
.5884 .32193 m .58984 .31821 L .59139 .32027 L 0 .059 .161 r
F
.5884 .32193 m .58685 .3198 L .58984 .31821 L F
.35903 .31172 m .36013 .30888 L .3619 .31087 L 0 .036 .137 r
F
.35903 .31172 m .35727 .30972 L .36013 .30888 L F
.57038 .32552 m .57179 .32163 L .57336 .32393 L 0 .069 .17 r
F
.57038 .32552 m .56881 .32318 L .57179 .32163 L F
.67716 .31194 m .67875 .30883 L .68021 .31084 L 0 .036 .137 r
F
.67716 .31194 m .6757 .30992 L .67875 .30883 L F
.20817 .30736 m .20905 .30437 L .21096 .30639 L 0 .026 .125 r
F
.20817 .30736 m .20626 .30534 L .20905 .30437 L F
.84444 .30779 m .84629 .30487 L .84758 .30679 L 0 .027 .127 r
F
.84444 .30779 m .84315 .30588 L .84629 .30487 L F
.54186 .33226 m .54324 .32842 L .54483 .33065 L 0 .09 .188 r
F
.54186 .33226 m .54027 .32979 L .54324 .32842 L F
.40582 .3143 m .40699 .31141 L .40871 .31338 L 0 .041 .144 r
F
.40582 .3143 m .40409 .31233 L .40699 .31141 L F
.16594 .30721 m .16677 .30412 L .16872 .30612 L 0 .026 .125 r
F
.16594 .30721 m .16399 .3052 L .16677 .30412 L F
.51679 .36708 m .51816 .354 L .51976 .36291 L 0 .217 .266 r
F
.51679 .36708 m .51519 .35715 L .51816 .354 L F
.46631 .32372 m .46759 .32026 L .46923 .32305 L 0 .065 .167 r
F
.46631 .32372 m .46466 .32099 L .46759 .32026 L F
.53433 .33271 m .5357 .32892 L .5373 .33125 L 0 .092 .189 r
F
.53433 .33271 m .53273 .33023 L .5357 .32892 L F
.42544 .3158 m .42666 .31273 L .42835 .31484 L 0 .045 .147 r
F
.42544 .3158 m .42375 .3137 L .42666 .31273 L F
.13125 .30661 m .13201 .30362 L .134 .3056 L 0 .025 .124 r
F
.13125 .30661 m .12926 .30464 L .13201 .30362 L F
.69976 .31079 m .70139 .30781 L .70282 .30976 L 0 .034 .134 r
F
.69976 .31079 m .69833 .30888 L .70139 .30781 L F
.51085 .37356 m .50927 .36219 L .51223 .36016 L 0 .255 .284 r
F
.50788 .37607 m .50927 .36219 L .51085 .37356 L 0 .266 .289 r
F
.69223 .31122 m .69384 .30811 L .69528 .31001 L 0 .034 .135 r
F
.69223 .31122 m .69079 .30932 L .69384 .30811 L F
.27754 .30872 m .27852 .30579 L .28036 .30784 L 0 .029 .129 r
F
.27754 .30872 m .2757 .30669 L .27852 .30579 L F
.85198 .30748 m .85385 .30454 L .85512 .30636 L 0 .027 .126 r
F
.85198 .30748 m .85071 .30566 L .85385 .30454 L F
.54912 .4041 m .55038 .38291 L .55199 .38863 L 0 .356 .281 r
F
.54912 .4041 m .5475 .39698 L .55038 .38291 L F
.6847 .31169 m .6863 .30857 L .68775 .31052 L 0 .035 .137 r
F
.6847 .31169 m .68325 .30971 L .6863 .30857 L F
.43754 .31775 m .43876 .31496 L .44045 .31705 L 0 .05 .153 r
F
.43754 .31775 m .43585 .31565 L .43876 .31496 L F
.55297 .43893 m .55148 .44782 L .55434 .43227 L 0 .459 .158 r
F
.5501 .45271 m .55148 .44782 L .55297 .43893 L 0 .513 .056 r
F
.44964 .31968 m .45089 .31664 L .45256 .31876 L 0 .055 .157 r
F
.44964 .31968 m .44796 .31763 L .45089 .31664 L F
.85952 .30715 m .86141 .30433 L .86268 .30618 L 0 .026 .126 r
F
.85952 .30715 m .85826 .30532 L .86141 .30433 L F
.60643 .31866 m .60791 .31548 L .60943 .31731 L 0 .052 .154 r
F
.60643 .31866 m .60491 .3168 L .60791 .31548 L F
.80224 .30782 m .80402 .30477 L .80535 .30674 L 0 .027 .127 r
F
.80224 .30782 m .80091 .30585 L .80402 .30477 L F
.31222 .30949 m .31327 .30639 L .31508 .30846 L 0 .031 .131 r
F
.31222 .30949 m .31042 .30743 L .31327 .30639 L F
.34692 .31013 m .348 .30724 L .34977 .30929 L 0 .032 .133 r
F
.34692 .31013 m .34514 .30812 L .348 .30724 L F
.17345 .30704 m .17428 .30398 L .17623 .30599 L 0 .026 .125 r
F
.17345 .30704 m .1715 .30503 L .17428 .30398 L F
.51631 .3365 m .51766 .33166 L .51927 .33474 L 0 .102 .197 r
F
.51631 .3365 m .5147 .33328 L .51766 .33166 L F
.25036 .30792 m .2513 .30499 L .25317 .307 L 0 .028 .128 r
F
.25036 .30792 m .24849 .30594 L .2513 .30499 L F
.46173 .32171 m .46301 .31838 L .46466 .32099 L 0 .06 .162 r
F
.46173 .32171 m .46008 .31917 L .46301 .31838 L F
.71484 .31023 m .71648 .30704 L .7179 .30905 L 0 .032 .133 r
F
.71484 .31023 m .71342 .30823 L .71648 .30704 L F
.21566 .30735 m .21656 .30431 L .21847 .30626 L 0 .027 .126 r
F
.21566 .30735 m .21375 .3054 L .21656 .30431 L F
.70731 .31069 m .70893 .30749 L .71036 .30948 L 0 .033 .134 r
F
.70731 .31069 m .70588 .30872 L .70893 .30749 L F
.63953 .31446 m .64105 .3111 L .64254 .31305 L 0 .041 .144 r
F
.63953 .31446 m .63803 .31246 L .64105 .3111 L F
.80979 .30757 m .81159 .30466 L .81291 .30654 L 0 .027 .127 r
F
.80979 .30757 m .80847 .3057 L .81159 .30466 L F
.36654 .31179 m .36765 .30899 L .36941 .3108 L 0 .037 .138 r
F
.36654 .31179 m .36477 .31002 L .36765 .30899 L F
.22319 .307 m .22408 .30415 L .22599 .306 L 0 .026 .126 r
F
.22319 .307 m .22127 .30516 L .22408 .30415 L F
.38617 .31327 m .38732 .31017 L .38905 .31232 L 0 .039 .141 r
F
.38617 .31327 m .38443 .31115 L .38732 .31017 L F
.51381 .37106 m .51519 .35715 L .51679 .36708 L 0 .238 .276 r
F
.51381 .37106 m .51223 .36016 L .51519 .35715 L F
.52495 .47143 m .52632 .49705 L .52792 .48047 L .168 .603 0 r
F
.52495 .47143 m .52333 .48625 L .52632 .49705 L F
.73744 .30912 m .73912 .30605 L .74051 .30795 L 0 .03 .131 r
F
.73744 .30912 m .73605 .30726 L .73912 .30605 L F
.49648 .41465 m .49495 .40166 L .49783 .40786 L 0 .408 .231 r
F
.49495 .40166 m .4963 .39421 L .49783 .40786 L 0 .361 .277 r
F
.74498 .30871 m .74666 .30563 L .74805 .30759 L 0 .03 .13 r
F
.74498 .30871 m .74359 .30678 L .74666 .30563 L F
.52384 .33629 m .5252 .33124 L .5268 .33424 L 0 .101 .196 r
F
.52384 .33629 m .52223 .33299 L .5252 .33124 L F
.4784 .32608 m .4797 .32259 L .48134 .32492 L 0 .072 .173 r
F
.4784 .32608 m .47675 .32372 L .4797 .32259 L F
.13873 .30665 m .13949 .30373 L .14147 .30571 L 0 .026 .125 r
F
.13873 .30665 m .13674 .30467 L .13949 .30373 L F
.72238 .31002 m .72404 .30697 L .72545 .30897 L 0 .032 .133 r
F
.72238 .31002 m .72097 .30801 L .72404 .30697 L F
.18095 .30689 m .18178 .30393 L .18373 .30588 L 0 .026 .125 r
F
.18095 .30689 m .179 .30496 L .18178 .30393 L F
.10402 .30606 m .10474 .3031 L .10676 .30506 L 0 .025 .123 r
F
.10402 .30606 m .10201 .3041 L .10474 .3031 L F
.59891 .31944 m .60038 .31618 L .60191 .3181 L 0 .054 .157 r
F
.59891 .31944 m .59738 .31748 L .60038 .31618 L F
.81734 .30734 m .81916 .30448 L .82046 .30631 L 0 .027 .127 r
F
.81734 .30734 m .81603 .30551 L .81916 .30448 L F
.55434 .43227 m .55284 .4393 L .55569 .42391 L 0 .44 .188 r
F
.55284 .4393 m .55418 .42886 L .55569 .42391 L 0 .471 .139 r
F
.52891 .37201 m .53026 .35644 L .53187 .36536 L 0 .241 .277 r
F
.52891 .37201 m .5273 .36155 L .53026 .35644 L F
.31973 .30945 m .32079 .30628 L .32259 .30838 L 0 .031 .131 r
F
.31973 .30945 m .31793 .30737 L .32079 .30628 L F
.56286 .3266 m .56427 .32293 L .56583 .32489 L 0 .074 .175 r
F
.56286 .3266 m .56129 .32464 L .56427 .32293 L F
.51174 .33457 m .51308 .33028 L .5147 .33328 L 0 .098 .194 r
F
.51174 .33457 m .51012 .33145 L .51308 .33028 L F
.75252 .30846 m .75422 .30538 L .7556 .30737 L 0 .029 .129 r
F
.75252 .30846 m .75113 .30649 L .75422 .30538 L F
.41332 .31454 m .41451 .31161 L .41622 .31364 L 0 .043 .145 r
F
.41332 .31454 m .41161 .3125 L .41451 .31161 L F
.37406 .31163 m .37518 .30884 L .37693 .31071 L 0 .037 .138 r
F
.37406 .31163 m .3723 .30979 L .37518 .30884 L F
.72993 .30977 m .73158 .30656 L .73299 .30851 L 0 .032 .132 r
F
.72993 .30977 m .72852 .3078 L .73158 .30656 L F
.25786 .30789 m .25879 .30514 L .26067 .30696 L 0 .029 .128 r
F
.25786 .30789 m .25598 .30607 L .25879 .30514 L F
.49783 .40786 m .4963 .39421 L .49921 .39889 L 0 .387 .254 r
F
.51085 .37356 m .51223 .36016 L .51381 .37106 L 0 .255 .284 r
F
.63201 .31524 m .63352 .31184 L .63502 .31385 L 0 .044 .146 r
F
.63201 .31524 m .6305 .31321 L .63352 .31184 L F
.82489 .30712 m .82671 .30422 L .82802 .30608 L 0 .027 .126 r
F
.82489 .30712 m .82359 .30529 L .82671 .30422 L F
.23069 .30692 m .23158 .30412 L .23348 .306 L F
.23069 .30692 m .22878 .30506 L .23158 .30412 L F
.18846 .30671 m .1893 .30378 L .19124 .30566 L 0 .026 .125 r
F
.18846 .30671 m .18651 .30483 L .1893 .30378 L F
.58089 .32323 m .58232 .31936 L .58387 .32153 L 0 .064 .166 r
F
.58089 .32323 m .57933 .321 L .58232 .31936 L F
.28502 .30903 m .28603 .30589 L .28786 .30795 L 0 .03 .131 r
F
.28502 .30903 m .28319 .30696 L .28603 .30589 L F
.76006 .30819 m .76177 .30502 L .76314 .30701 L 0 .029 .128 r
F
.76006 .30819 m .75868 .3062 L .76177 .30502 L F
.55073 .40856 m .54912 .4041 L .55199 .38863 L 0 .37 .27 r
F
.11152 .3059 m .11223 .30306 L .11426 .30492 L 0 .025 .123 r
F
.11152 .3059 m .1095 .30406 L .11223 .30306 L F
.14622 .30655 m .147 .30359 L .14899 .30546 L 0 .026 .125 r
F
.14622 .30655 m .14423 .30469 L .147 .30359 L F
.62448 .31575 m .62598 .31249 L .62749 .31455 L 0 .045 .148 r
F
.62448 .31575 m .62296 .31367 L .62598 .31249 L F
.50717 .33248 m .50851 .3284 L .51012 .33145 L 0 .092 .189 r
F
.50717 .33248 m .50555 .32931 L .50851 .3284 L F
.48593 .326 m .48724 .32246 L .48887 .32476 L 0 .073 .174 r
F
.48593 .326 m .48429 .32369 L .48724 .32246 L F
.5026 .33021 m .50393 .32657 L .50555 .32931 L 0 .086 .184 r
F
.5026 .33021 m .50097 .32745 L .50393 .32657 L F
.7676 .30786 m .76933 .30485 L .7707 .30683 L 0 .028 .128 r
F
.7676 .30786 m .76623 .30586 L .76933 .30485 L F
.55236 .33002 m .55376 .32629 L .55534 .32827 L 0 .085 .184 r
F
.55236 .33002 m .55078 .32801 L .55376 .32629 L F
.29254 .30871 m .29355 .30575 L .29539 .30763 L 0 .03 .13 r
F
.29254 .30871 m .2907 .30685 L .29355 .30575 L F
.32724 .30934 m .3283 .30649 L .33009 .30844 L 0 .032 .132 r
F
.32724 .30934 m .32544 .30738 L .3283 .30649 L F
.61695 .31623 m .61844 .31283 L .61995 .31485 L 0 .046 .149 r
F
.61695 .31623 m .61543 .31421 L .61844 .31283 L F
.45715 .32001 m .45841 .31692 L .46008 .31917 L 0 .057 .159 r
F
.45715 .32001 m .45549 .31783 L .45841 .31692 L F
.15374 .30623 m .15452 .30337 L .1565 .30525 L 0 .026 .124 r
F
.15374 .30623 m .15176 .30437 L .15452 .30337 L F
.19597 .30646 m .19683 .30348 L .19876 .30538 L 0 .026 .125 r
F
.19597 .30646 m .19403 .30458 L .19683 .30348 L F
.59139 .32027 m .59284 .31688 L .59438 .31888 L 0 .057 .159 r
F
.59139 .32027 m .58984 .31821 L .59284 .31688 L F
.43295 .3163 m .43416 .31353 L .43585 .31565 L 0 .048 .15 r
F
.43295 .3163 m .43126 .31419 L .43416 .31353 L F
.39368 .31339 m .39485 .31021 L .39657 .31235 L 0 .04 .142 r
F
.39368 .31339 m .39195 .31126 L .39485 .31021 L F
.83244 .30692 m .83427 .30392 L .83557 .30587 L 0 .027 .126 r
F
.83244 .30692 m .83114 .305 L .83427 .30392 L F
.52433 .36666 m .52569 .35459 L .5273 .36155 L 0 .219 .267 r
F
.52433 .36666 m .52272 .35875 L .52569 .35459 L F
.3544 .31054 m .3555 .30762 L .35727 .30972 L 0 .034 .135 r
F
.3544 .31054 m .35264 .30846 L .3555 .30762 L F
.26536 .30783 m .26632 .30493 L .26819 .30677 L 0 .029 .129 r
F
.26536 .30783 m .26349 .30601 L .26632 .30493 L F
.78268 .30721 m .78443 .30414 L .78577 .30603 L 0 .027 .127 r
F
.78268 .30721 m .78133 .30534 L .78443 .30414 L F
.57336 .32393 m .57478 .3202 L .57634 .32247 L 0 .067 .168 r
F
.57336 .32393 m .57179 .32163 L .57478 .3202 L F
.66512 .31118 m .66668 .30794 L .66815 .30997 L 0 .035 .136 r
F
.66512 .31118 m .66364 .30917 L .66668 .30794 L F
.30006 .30849 m .30107 .30559 L .3029 .30751 L 0 .03 .13 r
F
.30006 .30849 m .29823 .30661 L .30107 .30559 L F
.77515 .30766 m .77689 .30466 L .77824 .30653 L 0 .028 .128 r
F
.77515 .30766 m .7738 .3058 L .77689 .30466 L F
.54483 .33065 m .54622 .32718 L .54781 .32933 L 0 .088 .186 r
F
.54483 .33065 m .54324 .32842 L .54622 .32718 L F
.11901 .30579 m .11974 .30296 L .12175 .30482 L 0 .025 .124 r
F
.11901 .30579 m .117 .30394 L .11974 .30296 L F
.5268 .33424 m .52816 .32949 L .52977 .33223 L 0 .096 .193 r
F
.5268 .33424 m .5252 .33124 L .52816 .32949 L F
.44504 .31838 m .44628 .3156 L .44796 .31763 L 0 .054 .156 r
F
.44504 .31838 m .44336 .31632 L .44628 .3156 L F
.55148 .44782 m .55284 .4393 L .55434 .43227 L 0 .498 .088 r
F
.50354 .38792 m .50198 .37651 L .50492 .37705 L 0 .329 .299 r
F
.5006 .38689 m .50198 .37651 L .50354 .38792 L 0 .321 .302 r
F
.23818 .30694 m .2391 .30397 L .24099 .30592 L 0 .027 .126 r
F
.23818 .30694 m .23629 .30498 L .2391 .30397 L F
.79023 .30694 m .792 .30404 L .79334 .30597 L 0 .027 .127 r
F
.79023 .30694 m .78889 .30503 L .792 .30404 L F
.20347 .30632 m .20435 .30332 L .20626 .30534 L 0 .026 .125 r
F
.20347 .30632 m .20156 .3043 L .20435 .30332 L F
.49803 .32826 m .49935 .32468 L .50097 .32745 L 0 .08 .18 r
F
.49803 .32826 m .4964 .32547 L .49935 .32468 L F
.51927 .33474 m .52062 .33004 L .52223 .33299 L 0 .099 .194 r
F
.51927 .33474 m .51766 .33166 L .52062 .33004 L F
.53349 .3744 m .53483 .35943 L .53644 .3671 L 0 .257 .285 r
F
.53349 .3744 m .53187 .36536 L .53483 .35943 L F
.67266 .31096 m .67424 .30789 L .6757 .30992 L 0 .035 .137 r
F
.67266 .31096 m .67119 .30893 L .67424 .30789 L F
.42084 .31473 m .42204 .31159 L .42375 .3137 L 0 .044 .146 r
F
.42084 .31473 m .41913 .31263 L .42204 .31159 L F
.5373 .33125 m .53868 .3276 L .54027 .32979 L 0 .09 .187 r
F
.5373 .33125 m .5357 .32892 L .53868 .3276 L F
.65759 .31182 m .65914 .30859 L .66062 .3105 L 0 .037 .139 r
F
.65759 .31182 m .65612 .30992 L .65914 .30859 L F
.4012 .3133 m .40237 .31036 L .40409 .31233 L 0 .041 .143 r
F
.4012 .3133 m .39947 .31135 L .40237 .31036 L F
.16123 .30619 m .16203 .30328 L .16399 .3052 L 0 .026 .125 r
F
.16123 .30619 m .15926 .30428 L .16203 .30328 L F
.27288 .30766 m .27385 .30473 L .2757 .30669 L 0 .029 .128 r
F
.27288 .30766 m .27102 .30572 L .27385 .30473 L F
.65006 .31226 m .65161 .30925 L .65309 .31109 L 0 .038 .14 r
F
.65006 .31226 m .64858 .31039 L .65161 .30925 L F
.84001 .30684 m .84186 .30392 L .84315 .30588 L 0 .027 .126 r
F
.84001 .30684 m .83871 .30489 L .84186 .30392 L F
.33475 .30938 m .33581 .30652 L .33761 .30836 L 0 .032 .133 r
F
.33475 .30938 m .33295 .30753 L .33581 .30652 L F
.38156 .31194 m .38269 .30907 L .38443 .31115 L 0 .038 .14 r
F
.38156 .31194 m .37981 .30989 L .38269 .30907 L F
.12651 .30568 m .12726 .30272 L .12926 .30464 L 0 .025 .123 r
F
.12651 .30568 m .1245 .30378 L .12726 .30272 L F
.30757 .30846 m .3086 .30547 L .31042 .30743 L 0 .03 .131 r
F
.30757 .30846 m .30575 .3065 L .3086 .30547 L F
.49345 .32627 m .49477 .32294 L .4964 .32547 L 0 .075 .176 r
F
.49345 .32627 m .49182 .32373 L .49477 .32294 L F
.34227 .30915 m .34335 .30628 L .34514 .30812 L 0 .032 .133 r
F
.34227 .30915 m .34048 .30731 L .34335 .30628 L F
.47381 .32483 m .47511 .32102 L .47675 .32372 L 0 .07 .171 r
F
.47381 .32483 m .47217 .32209 L .47511 .32102 L F
.60943 .31731 m .61091 .31396 L .61243 .31576 L 0 .05 .153 r
F
.60943 .31731 m .60791 .31548 L .61091 .31396 L F
.68021 .31084 m .6818 .30773 L .68325 .30971 L 0 .035 .137 r
F
.68021 .31084 m .67875 .30883 L .6818 .30773 L F
.69528 .31001 m .69689 .30699 L .69833 .30888 L 0 .034 .135 r
F
.69528 .31001 m .69384 .30811 L .69689 .30699 L F
.24568 .30689 m .24661 .30394 L .24849 .30594 L 0 .027 .127 r
F
.24568 .30689 m .2438 .30491 L .24661 .30394 L F
.56583 .32489 m .56725 .32123 L .56881 .32318 L 0 .071 .172 r
F
.56583 .32489 m .56427 .32293 L .56725 .32123 L F
.53969 .38428 m .54101 .36712 L .54263 .37459 L 0 .31 .307 r
F
.53969 .38428 m .53806 .37526 L .54101 .36712 L F
.7978 .30693 m .79957 .30388 L .80091 .30585 L 0 .027 .127 r
F
.7978 .30693 m .79646 .30496 L .79957 .30388 L F
.16872 .30612 m .16955 .30303 L .1715 .30503 L 0 .026 .125 r
F
.16872 .30612 m .16677 .30412 L .16955 .30303 L F
.68775 .31052 m .68935 .30739 L .69079 .30932 L 0 .035 .136 r
F
.68775 .31052 m .6863 .30857 L .68935 .30739 L F
.85512 .30636 m .85699 .30349 L .85826 .30532 L 0 .027 .126 r
F
.85512 .30636 m .85385 .30454 L .85699 .30349 L F
.64254 .31305 m .64407 .30972 L .64555 .31164 L 0 .04 .142 r
F
.64254 .31305 m .64105 .3111 L .64407 .30972 L F
.84758 .30679 m .84943 .30374 L .85071 .30566 L 0 .027 .127 r
F
.84758 .30679 m .84629 .30487 L .84943 .30374 L F
.21096 .30639 m .21185 .30338 L .21375 .3054 L 0 .027 .126 r
F
.21096 .30639 m .20905 .30437 L .21185 .30338 L F
.70282 .30976 m .70445 .30675 L .70588 .30872 L 0 .033 .134 r
F
.70282 .30976 m .70139 .30781 L .70445 .30675 L F
.134 .3056 m .13476 .30268 L .13674 .30467 L 0 .025 .124 r
F
.134 .3056 m .13201 .30362 L .13476 .30268 L F
.3619 .31087 m .363 .30804 L .36477 .31002 L 0 .036 .138 r
F
.3619 .31087 m .36013 .30888 L .363 .30804 L F
.58387 .32153 m .5853 .3177 L .58685 .3198 L 0 .061 .163 r
F
.58387 .32153 m .58232 .31936 L .5853 .3177 L F
.42835 .31484 m .42956 .31201 L .43126 .31419 L 0 .046 .148 r
F
.42835 .31484 m .42666 .31273 L .42956 .31201 L F
.40871 .31338 m .40989 .31055 L .41161 .3125 L 0 .042 .144 r
F
.40871 .31338 m .40699 .31141 L .40989 .31055 L F
.52977 .33223 m .53113 .32775 L .53273 .33023 L 0 .092 .189 r
F
.52977 .33223 m .52816 .32949 L .53113 .32775 L F
.55534 .32827 m .55673 .32447 L .55831 .32644 L 0 .081 .181 r
F
.55534 .32827 m .55376 .32629 L .55673 .32447 L F
.80535 .30674 m .80714 .30372 L .80847 .3057 L 0 .027 .127 r
F
.80535 .30674 m .80402 .30477 L .80714 .30372 L F
.7179 .30905 m .71955 .30601 L .72097 .30801 L 0 .032 .133 r
F
.7179 .30905 m .71648 .30704 L .71955 .30601 L F
.71036 .30948 m .71199 .30622 L .71342 .30823 L 0 .033 .133 r
F
.71036 .30948 m .70893 .30749 L .71199 .30622 L F
.31508 .30846 m .31613 .30529 L .31793 .30737 L 0 .031 .131 r
F
.31508 .30846 m .31327 .30639 L .31613 .30529 L F
.28036 .30784 m .28135 .30489 L .28319 .30696 L 0 .03 .13 r
F
.28036 .30784 m .27852 .30579 L .28135 .30489 L F
.86268 .30618 m .86457 .30334 L .86583 .30521 L 0 .027 .126 r
F
.86268 .30618 m .86141 .30433 L .86457 .30334 L F
.60191 .3181 m .60338 .31493 L .60491 .3168 L 0 .053 .156 r
F
.60191 .3181 m .60038 .31618 L .60338 .31493 L F
.17623 .30599 m .17706 .30294 L .179 .30496 L 0 .026 .125 r
F
.17623 .30599 m .17428 .30398 L .17706 .30294 L F
.54138 .46442 m .53987 .4816 L .54284 .47582 L .057 .562 0 r
F
.53842 .4694 m .53987 .4816 L .54138 .46442 L .102 .579 0 r
F
.45256 .31876 m .45381 .31564 L .45549 .31783 L 0 .055 .158 r
F
.45256 .31876 m .45089 .31664 L .45381 .31564 L F
.21847 .30626 m .21937 .30322 L .22127 .30516 L 0 .027 .126 r
F
.21847 .30626 m .21656 .30431 L .21937 .30322 L F
.74051 .30795 m .74219 .30484 L .74359 .30678 L 0 .03 .13 r
F
.74051 .30795 m .73912 .30605 L .74219 .30484 L F
.48134 .32492 m .48264 .32137 L .48429 .32369 L 0 .072 .173 r
F
.48134 .32492 m .4797 .32259 L .48264 .32137 L F
.5147 .33328 m .51605 .32873 L .51766 .33166 L 0 .096 .192 r
F
.5147 .33328 m .51308 .33028 L .51605 .32873 L F
.46923 .32305 m .47052 .31931 L .47217 .32209 L 0 .066 .168 r
F
.46923 .32305 m .46759 .32026 L .47052 .31931 L F
.63502 .31385 m .63653 .31048 L .63803 .31246 L 0 .042 .145 r
F
.63502 .31385 m .63352 .31184 L .63653 .31048 L F
.81291 .30654 m .81471 .30363 L .81603 .30551 L 0 .027 .127 r
F
.81291 .30654 m .81159 .30466 L .81471 .30363 L F
.74805 .30759 m .74975 .30452 L .75113 .30649 L 0 .029 .129 r
F
.74805 .30759 m .74666 .30563 L .74975 .30452 L F
.34977 .30929 m .35087 .30637 L .35264 .30846 L 0 .033 .134 r
F
.34977 .30929 m .348 .30724 L .35087 .30637 L F
.25317 .307 m .25411 .30406 L .25598 .30607 L 0 .028 .128 r
F
.25317 .307 m .2513 .30499 L .25411 .30406 L F
.44045 .31705 m .44168 .31427 L .44336 .31632 L 0 .052 .154 r
F
.44045 .31705 m .43876 .31496 L .44168 .31427 L F
.36941 .3108 m .37053 .30795 L .3723 .30979 L 0 .037 .138 r
F
.36941 .3108 m .36765 .30899 L .37053 .30795 L F
.22599 .306 m .22688 .3032 L .22878 .30506 L 0 .027 .126 r
F
.22599 .306 m .22408 .30415 L .22688 .3032 L F
.73299 .30851 m .73465 .30532 L .73605 .30726 L 0 .031 .131 r
F
.73299 .30851 m .73158 .30656 L .73465 .30532 L F
.52223 .33299 m .52359 .32839 L .5252 .33124 L 0 .095 .191 r
F
.52223 .33299 m .52062 .33004 L .52359 .32839 L F
.72545 .30897 m .72711 .30581 L .72852 .3078 L 0 .032 .133 r
F
.72545 .30897 m .72404 .30697 L .72711 .30581 L F
.38905 .31232 m .39022 .3091 L .39195 .31126 L 0 .039 .141 r
F
.38905 .31232 m .38732 .31017 L .39022 .3091 L F
.61995 .31485 m .62145 .31166 L .62296 .31367 L 0 .045 .148 r
F
.61995 .31485 m .61844 .31283 L .62145 .31166 L F
.32259 .30838 m .32365 .30528 L .32544 .30738 L 0 .031 .131 r
F
.32259 .30838 m .32079 .30628 L .32365 .30528 L F
.18373 .30588 m .18457 .30289 L .18651 .30483 L 0 .026 .125 r
F
.18373 .30588 m .18178 .30393 L .18457 .30289 L F
.82046 .30631 m .82228 .30344 L .82359 .30529 L 0 .027 .127 r
F
.82046 .30631 m .81916 .30448 L .82228 .30344 L F
.10676 .30506 m .10748 .30209 L .1095 .30406 L 0 .025 .123 r
F
.10676 .30506 m .10474 .3031 L .10748 .30209 L F
.7556 .30737 m .7573 .30421 L .75868 .3062 L 0 .029 .129 r
F
.7556 .30737 m .75422 .30538 L .7573 .30421 L F
.59438 .31888 m .59584 .31555 L .59738 .31748 L 0 .055 .158 r
F
.59438 .31888 m .59284 .31688 L .59584 .31555 L F
.14147 .30571 m .14225 .3027 L .14423 .30469 L 0 .026 .125 r
F
.14147 .30571 m .13949 .30373 L .14225 .3027 L F
.46466 .32099 m .46594 .31759 L .46759 .32026 L 0 .061 .163 r
F
.46466 .32099 m .46301 .31838 L .46594 .31759 L F
.48887 .32476 m .49018 .32143 L .49182 .32373 L 0 .072 .173 r
F
.48887 .32476 m .48724 .32246 L .49018 .32143 L F
.57634 .32247 m .57777 .31877 L .57933 .321 L 0 .065 .167 r
F
.57634 .32247 m .57478 .3202 L .57777 .31877 L F
.76314 .30701 m .76485 .30387 L .76623 .30586 L 0 .028 .128 r
F
.76314 .30701 m .76177 .30502 L .76485 .30387 L F
.62749 .31455 m .629 .31117 L .6305 .31321 L 0 .044 .147 r
F
.62749 .31455 m .62598 .31249 L .629 .31117 L F
.53545 .47034 m .5369 .48739 L .53842 .4694 L .126 .588 0 r
F
.53545 .47034 m .53391 .48832 L .5369 .48739 L F
.52136 .37184 m .52272 .35875 L .52433 .36666 L 0 .25 .282 r
F
.52136 .37184 m .51976 .36291 L .52272 .35875 L F
.28786 .30795 m .28887 .30478 L .2907 .30685 L 0 .03 .13 r
F
.28786 .30795 m .28603 .30589 L .28887 .30478 L F
.19124 .30566 m .19209 .3027 L .19403 .30458 L 0 .026 .125 r
F
.19124 .30566 m .1893 .30378 L .19209 .3027 L F
.82802 .30608 m .82984 .30311 L .83114 .305 L 0 .027 .126 r
F
.82802 .30608 m .82671 .30422 L .82984 .30311 L F
.14899 .30546 m .14978 .30248 L .15176 .30437 L 0 .026 .124 r
F
.14899 .30546 m .147 .30359 L .14978 .30248 L F
.41622 .31364 m .41742 .31062 L .41913 .31263 L 0 .043 .145 r
F
.41622 .31364 m .41451 .31161 L .41742 .31062 L F
.37693 .31071 m .37806 .30798 L .37981 .30989 L 0 .037 .139 r
F
.37693 .31071 m .37518 .30884 L .37806 .30798 L F
.26067 .30696 m .26161 .30419 L .26349 .30601 L 0 .029 .129 r
F
.26067 .30696 m .25879 .30514 L .26161 .30419 L F
.54781 .32933 m .5492 .32595 L .55078 .32801 L 0 .087 .185 r
F
.54781 .32933 m .54622 .32718 L .5492 .32595 L F
.51012 .33145 m .51147 .32733 L .51308 .33028 L 0 .092 .189 r
F
.51012 .33145 m .50851 .3284 L .51147 .32733 L F
.29539 .30763 m .2964 .3047 L .29823 .30661 L 0 .03 .13 r
F
.29539 .30763 m .29355 .30575 L .2964 .3047 L F
.54027 .32979 m .54165 .32632 L .54324 .32842 L 0 .088 .186 r
F
.54027 .32979 m .53868 .3276 L .54165 .32632 L F
.11426 .30492 m .11497 .30208 L .117 .30394 L 0 .025 .124 r
F
.11426 .30492 m .11223 .30306 L .11497 .30208 L F
.53273 .33023 m .5341 .32658 L .5357 .32892 L 0 .089 .187 r
F
.53273 .33023 m .53113 .32775 L .5341 .32658 L F
.7707 .30683 m .77243 .30383 L .7738 .3058 L 0 .028 .128 r
F
.7707 .30683 m .76933 .30485 L .77243 .30383 L F
.23348 .306 m .23439 .30311 L .23629 .30498 L 0 .027 .126 r
F
.23348 .306 m .23158 .30412 L .23439 .30311 L F
.66815 .30997 m .66972 .3069 L .67119 .30893 L 0 .035 .136 r
F
.66815 .30997 m .66668 .30794 L .66972 .3069 L F
.19876 .30538 m .19963 .30238 L .20156 .3043 L 0 .026 .124 r
F
.19876 .30538 m .19683 .30348 L .19963 .30238 L F
.78577 .30603 m .78754 .30312 L .78889 .30503 L 0 .027 .126 r
F
.78577 .30603 m .78443 .30414 L .78754 .30312 L F
.56881 .32318 m .57023 .31965 L .57179 .32163 L 0 .068 .169 r
F
.56881 .32318 m .56725 .32123 L .57023 .31965 L F
.83557 .30587 m .83741 .30293 L .83871 .30489 L 0 .027 .126 r
F
.83557 .30587 m .83427 .30392 L .83741 .30293 L F
.39657 .31235 m .39775 .30918 L .39947 .31135 L 0 .04 .142 r
F
.39657 .31235 m .39485 .31021 L .39775 .30918 L F
.1565 .30525 m .15728 .30239 L .15926 .30428 L 0 .026 .125 r
F
.1565 .30525 m .15452 .30337 L .15728 .30239 L F
.66062 .3105 m .66217 .30726 L .66364 .30917 L 0 .036 .137 r
F
.66062 .3105 m .65914 .30859 L .66217 .30726 L F
.50555 .32931 m .50689 .32569 L .50851 .3284 L 0 .086 .185 r
F
.50555 .32931 m .50393 .32657 L .50689 .32569 L F
.77824 .30653 m .77998 .30345 L .78133 .30534 L 0 .028 .127 r
F
.77824 .30653 m .77689 .30466 L .77998 .30345 L F
.33009 .30844 m .33115 .30559 L .33295 .30753 L 0 .032 .133 r
F
.33009 .30844 m .3283 .30649 L .33115 .30559 L F
.61243 .31576 m .61391 .31243 L .61543 .31421 L 0 .048 .151 r
F
.61243 .31576 m .61091 .31396 L .61391 .31243 L F
.26819 .30677 m .26916 .30384 L .27102 .30572 L 0 .029 .128 r
F
.26819 .30677 m .26632 .30493 L .26916 .30384 L F
.55831 .32644 m .55971 .32267 L .56129 .32464 L 0 .077 .177 r
F
.55831 .32644 m .55673 .32447 L .55971 .32267 L F
.46008 .31917 m .46134 .31605 L .46301 .31838 L 0 .058 .16 r
F
.46008 .31917 m .45841 .31692 L .46134 .31605 L F
.58685 .3198 m .5883 .31616 L .58984 .31821 L F
.58685 .3198 m .5853 .3177 L .5883 .31616 L F
.3029 .30751 m .30392 .30457 L .30575 .3065 L 0 .03 .13 r
F
.3029 .30751 m .30107 .30559 L .30392 .30457 L F
.12175 .30482 m .12249 .30191 L .1245 .30378 L 0 .025 .124 r
F
.12175 .30482 m .11974 .30296 L .12249 .30191 L F
.65309 .31109 m .65464 .30811 L .65612 .30992 L 0 .038 .14 r
F
.65309 .31109 m .65161 .30925 L .65464 .30811 L F
.24099 .30592 m .24192 .30296 L .2438 .30491 L 0 .027 .126 r
F
.24099 .30592 m .2391 .30397 L .24192 .30296 L F
.52594 .37867 m .5273 .36155 L .52891 .37201 L 0 .284 .297 r
F
.52594 .37867 m .52433 .36666 L .5273 .36155 L F
.6757 .30992 m .67729 .30682 L .67875 .30883 L 0 .035 .136 r
F
.6757 .30992 m .67424 .30789 L .67729 .30682 L F
.35727 .30972 m .35837 .30677 L .36013 .30888 L F
.35727 .30972 m .3555 .30762 L .35837 .30677 L F
.42375 .3137 m .42496 .31061 L .42666 .31273 L 0 .044 .146 r
F
.42375 .3137 m .42204 .31159 L .42496 .31061 L F
.20626 .30534 m .20714 .30235 L .20905 .30437 L 0 .026 .125 r
F
.20626 .30534 m .20435 .30332 L .20714 .30235 L F
.79334 .30597 m .79511 .30301 L .79646 .30496 L 0 .027 .127 r
F
.79334 .30597 m .792 .30404 L .79511 .30301 L F
.64555 .31164 m .64709 .30851 L .64858 .31039 L 0 .039 .141 r
F
.64555 .31164 m .64407 .30972 L .64709 .30851 L F
.43585 .31565 m .43707 .31286 L .43876 .31496 L 0 .049 .152 r
F
.43585 .31565 m .43416 .31353 L .43707 .31286 L F
.16399 .3052 m .16481 .30218 L .16677 .30412 L 0 .026 .125 r
F
.16399 .3052 m .16203 .30328 L .16481 .30218 L F
.40409 .31233 m .40527 .30943 L .40699 .31141 L 0 .041 .143 r
F
.40409 .31233 m .40237 .31036 L .40527 .30943 L F
.33761 .30836 m .33868 .30547 L .34048 .30731 L 0 .032 .133 r
F
.33761 .30836 m .33581 .30652 L .33868 .30547 L F
.2757 .30669 m .27668 .3038 L .27852 .30579 L 0 .029 .129 r
F
.2757 .30669 m .27385 .30473 L .27668 .3038 L F
.84315 .30588 m .845 .30291 L .84629 .30487 L 0 .027 .127 r
F
.84315 .30588 m .84186 .30392 L .845 .30291 L F
.12926 .30464 m .13002 .30168 L .13201 .30362 L 0 .025 .123 r
F
.12926 .30464 m .12726 .30272 L .13002 .30168 L F
.50097 .32745 m .5023 .32383 L .50393 .32657 L 0 .081 .181 r
F
.50097 .32745 m .49935 .32468 L .5023 .32383 L F
.44796 .31763 m .44921 .31456 L .45089 .31664 L 0 .054 .157 r
F
.44796 .31763 m .44628 .3156 L .44921 .31456 L F
.5252 .33124 m .52656 .32673 L .52816 .32949 L 0 .091 .189 r
F
.5252 .33124 m .52359 .32839 L .52656 .32673 L F
.68325 .30971 m .68485 .30661 L .6863 .30857 L 0 .035 .136 r
F
.68325 .30971 m .6818 .30773 L .68485 .30661 L F
.47675 .32372 m .47805 .31994 L .4797 .32259 L 0 .07 .171 r
F
.47675 .32372 m .47511 .32102 L .47805 .31994 L F
.51766 .33166 m .51901 .32717 L .52062 .33004 L 0 .093 .19 r
F
.51766 .33166 m .51605 .32873 L .51901 .32717 L F
.69833 .30888 m .69996 .30594 L .70139 .30781 L 0 .034 .134 r
F
.69833 .30888 m .69689 .30699 L .69996 .30594 L F
.31042 .30743 m .31145 .30444 L .31327 .30639 L 0 .03 .131 r
F
.31042 .30743 m .3086 .30547 L .31145 .30444 L F
.69079 .30932 m .6924 .30621 L .69384 .30811 L 0 .034 .135 r
F
.69079 .30932 m .68935 .30739 L .6924 .30621 L F
.34514 .30812 m .34621 .30537 L .348 .30724 L 0 .032 .133 r
F
.34514 .30812 m .34335 .30628 L .34621 .30537 L F
.80091 .30585 m .80268 .30279 L .80402 .30477 L 0 .027 .127 r
F
.80091 .30585 m .79957 .30388 L .80268 .30279 L F
.1715 .30503 m .17234 .30197 L .17428 .30398 L 0 .026 .125 r
F
.1715 .30503 m .16955 .30303 L .17234 .30197 L F
.85071 .30566 m .85256 .30261 L .85385 .30454 L 0 .027 .126 r
F
.85071 .30566 m .84943 .30374 L .85256 .30261 L F
.55418 .42886 m .55262 .43038 L .55547 .414 L 0 .43 .202 r
F
.55262 .43038 m .55392 .41483 L .55547 .414 L 0 .442 .185 r
F
.38443 .31115 m .38559 .30807 L .38732 .31017 L 0 .039 .14 r
F
.38443 .31115 m .38269 .30907 L .38559 .30807 L F
.60491 .3168 m .60639 .31366 L .60791 .31548 L 0 .052 .155 r
F
.60491 .3168 m .60338 .31493 L .60639 .31366 L F
.71342 .30823 m .71505 .30502 L .71648 .30704 L 0 .032 .133 r
F
.71342 .30823 m .71199 .30622 L .71505 .30502 L F
.24849 .30594 m .24943 .30297 L .2513 .30499 L 0 .028 .127 r
F
.24849 .30594 m .24661 .30394 L .24943 .30297 L F
.85826 .30532 m .86014 .30248 L .86141 .30433 L 0 .027 .126 r
F
.85826 .30532 m .85699 .30349 L .86014 .30248 L F
.63803 .31246 m .63955 .30916 L .64105 .3111 L 0 .041 .143 r
F
.63803 .31246 m .63653 .31048 L .63955 .30916 L F
.70588 .30872 m .7075 .30549 L .70893 .30749 L 0 .033 .134 r
F
.70588 .30872 m .70445 .30675 L .7075 .30549 L F
.21375 .3054 m .21465 .3023 L .21656 .30431 L 0 .026 .126 r
F
.21375 .3054 m .21185 .30338 L .21465 .3023 L F
.4964 .32547 m .49772 .32214 L .49935 .32468 L 0 .076 .177 r
F
.4964 .32547 m .49477 .32294 L .49772 .32214 L F
.80847 .3057 m .81026 .30269 L .81159 .30466 L 0 .027 .127 r
F
.80847 .3057 m .80714 .30372 L .81026 .30269 L F
.31793 .30737 m .31899 .30418 L .32079 .30628 L 0 .03 .131 r
F
.31793 .30737 m .31613 .30529 L .31899 .30418 L F
.48429 .32369 m .48559 .32015 L .48724 .32246 L 0 .071 .172 r
F
.48429 .32369 m .48264 .32137 L .48559 .32015 L F
.13674 .30467 m .13751 .30173 L .13949 .30373 L 0 .025 .124 r
F
.13674 .30467 m .13476 .30268 L .13751 .30173 L F
.72097 .30801 m .72262 .30497 L .72404 .30697 L 0 .032 .133 r
F
.72097 .30801 m .71955 .30601 L .72262 .30497 L F
.74359 .30678 m .74527 .30367 L .74666 .30563 L 0 .029 .129 r
F
.74359 .30678 m .74219 .30484 L .74527 .30367 L F
.57933 .321 m .58076 .31719 L .58232 .31936 L 0 .062 .164 r
F
.57933 .321 m .57777 .31877 L .58076 .31719 L F
.59738 .31748 m .59884 .3143 L .60038 .31618 L 0 .054 .157 r
F
.59738 .31748 m .59584 .31555 L .59884 .3143 L F
.10201 .3041 m .10272 .30113 L .10474 .3031 L 0 .024 .123 r
F
.10201 .3041 m .09998 .30214 L .10272 .30113 L F
.22127 .30516 m .22217 .3022 L .22408 .30415 L 0 .026 .126 r
F
.22127 .30516 m .21937 .30322 L .22217 .3022 L F
.73605 .30726 m .73772 .30414 L .73912 .30605 L 0 .03 .131 r
F
.73605 .30726 m .73465 .30532 L .73772 .30414 L F
.179 .30496 m .17985 .3019 L .18178 .30393 L 0 .026 .125 r
F
.179 .30496 m .17706 .30294 L .17985 .3019 L F
.41161 .3125 m .41279 .30969 L .41451 .31161 L 0 .043 .145 r
F
.41161 .3125 m .40989 .31055 L .41279 .30969 L F
.56129 .32464 m .56269 .32097 L .56427 .32293 L 0 .073 .174 r
F
.56129 .32464 m .55971 .32267 L .56269 .32097 L F
.36477 .31002 m .36589 .30699 L .36765 .30899 L 0 .037 .138 r
F
.36477 .31002 m .363 .30804 L .36589 .30699 L F
.75113 .30649 m .75283 .3034 L .75422 .30538 L 0 .029 .129 r
F
.75113 .30649 m .74975 .30452 L .75283 .3034 L F
.6305 .31321 m .63201 .30983 L .63352 .31184 L 0 .043 .146 r
F
.6305 .31321 m .629 .31117 L .63201 .30983 L F
.45549 .31783 m .45675 .31466 L .45841 .31692 L 0 .055 .158 r
F
.45549 .31783 m .45381 .31564 L .45675 .31466 L F
.72852 .3078 m .73018 .30459 L .73158 .30656 L 0 .032 .132 r
F
.72852 .3078 m .72711 .30581 L .73018 .30459 L F
.28319 .30696 m .28419 .30382 L .28603 .30589 L 0 .03 .13 r
F
.28319 .30696 m .28135 .30489 L .28419 .30382 L F
.62296 .31367 m .62447 .3105 L .62598 .31249 L 0 .045 .147 r
F
.62296 .31367 m .62145 .31166 L .62447 .3105 L F
.81603 .30551 m .81784 .30259 L .81916 .30448 L 0 .027 .127 r
F
.81603 .30551 m .81471 .30363 L .81784 .30259 L F
.57179 .32163 m .57322 .31817 L .57478 .3202 L 0 .065 .167 r
F
.57179 .32163 m .57023 .31965 L .57322 .31817 L F
.50213 .40324 m .5006 .38689 L .50354 .38792 L 0 .37 .27 r
F
.49921 .39889 m .5006 .38689 L .50213 .40324 L 0 .356 .281 r
F
.47217 .32209 m .47347 .31829 L .47511 .32102 L 0 .066 .168 r
F
.47217 .32209 m .47052 .31931 L .47347 .31829 L F
.75868 .3062 m .76039 .30302 L .76177 .30502 L 0 .028 .128 r
F
.75868 .3062 m .7573 .30421 L .76039 .30302 L F
.51838 .37705 m .51976 .36291 L .52136 .37184 L 0 .282 .297 r
F
.51838 .37705 m .51679 .36708 L .51976 .36291 L F
.3723 .30979 m .37342 .30696 L .37518 .30884 L 0 .037 .138 r
F
.3723 .30979 m .37053 .30795 L .37342 .30696 L F
.43126 .31419 m .43247 .31129 L .43416 .31353 L 0 .047 .149 r
F
.43126 .31419 m .42956 .31201 L .43247 .31129 L F
.39195 .31126 m .39312 .30803 L .39485 .31021 L 0 .039 .141 r
F
.39195 .31126 m .39022 .3091 L .39312 .30803 L F
.53511 .38403 m .53644 .3671 L .53806 .37526 L 0 .313 .306 r
F
.53511 .38403 m .53349 .3744 L .53644 .3671 L F
.54868 .45326 m .5472 .46622 L .5501 .45271 L 0 .513 .056 r
F
.54577 .46486 m .5472 .46622 L .54868 .45326 L .05 .559 0 r
F
.54324 .32842 m .54463 .32507 L .54622 .32718 L 0 .087 .185 r
F
.54324 .32842 m .54165 .32632 L .54463 .32507 L F
.55078 .32801 m .55218 .32425 L .55376 .32629 L 0 .084 .183 r
F
.55078 .32801 m .5492 .32595 L .55218 .32425 L F
.61543 .31421 m .61692 .31107 L .61844 .31283 L 0 .046 .149 r
F
.61543 .31421 m .61391 .31243 L .61692 .31107 L F
.25598 .30607 m .25693 .30314 L .25879 .30514 L 0 .029 .128 r
F
.25598 .30607 m .25411 .30406 L .25693 .30314 L F
.76623 .30586 m .76796 .30286 L .76933 .30485 L 0 .028 .128 r
F
.76623 .30586 m .76485 .30387 L .76796 .30286 L F
.58984 .31821 m .5913 .3149 L .59284 .31688 L 0 .056 .159 r
F
.58984 .31821 m .5883 .31616 L .5913 .3149 L F
.18651 .30483 m .18736 .30185 L .1893 .30378 L 0 .026 .125 r
F
.18651 .30483 m .18457 .30289 L .18736 .30185 L F
.22878 .30506 m .22968 .30224 L .23158 .30412 L 0 .027 .126 r
F
.22878 .30506 m .22688 .3032 L .22968 .30224 L F
.82359 .30529 m .82541 .30236 L .82671 .30422 L 0 .027 .127 r
F
.82359 .30529 m .82228 .30344 L .82541 .30236 L F
.5357 .32892 m .53708 .32542 L .53868 .3276 L 0 .088 .186 r
F
.5357 .32892 m .5341 .32658 L .53708 .32542 L F
.49697 .44131 m .49541 .43077 L .49824 .44438 L 0 .498 .088 r
F
.49541 .43077 m .49669 .43195 L .49824 .44438 L 0 .459 .158 r
F
.32544 .30738 m .3265 .30439 L .3283 .30649 L 0 .031 .132 r
F
.32544 .30738 m .32365 .30528 L .3265 .30439 L F
.1095 .30406 m .11022 .3011 L .11223 .30306 L 0 .025 .123 r
F
.1095 .30406 m .10748 .30209 L .11022 .3011 L F
.14423 .30469 m .14502 .30159 L .147 .30359 L 0 .026 .125 r
F
.14423 .30469 m .14225 .3027 L .14502 .30159 L F
.35264 .30846 m .35373 .30551 L .3555 .30762 L 0 .034 .135 r
F
.35264 .30846 m .35087 .30637 L .35373 .30551 L F
.49182 .32373 m .49313 .32061 L .49477 .32294 L 0 .073 .174 r
F
.49182 .32373 m .49018 .32143 L .49313 .32061 L F
.54132 .39333 m .54263 .37459 L .54425 .38206 L 0 .336 .295 r
F
.54132 .39333 m .53969 .38428 L .54263 .37459 L F
.2907 .30685 m .29172 .30369 L .29355 .30575 L 0 .03 .13 r
F
.2907 .30685 m .28887 .30478 L .29172 .30369 L F
.51308 .33028 m .51443 .32584 L .51605 .32873 L 0 .09 .188 r
F
.51308 .33028 m .51147 .32733 L .51443 .32584 L F
.66364 .30917 m .66521 .30604 L .66668 .30794 L 0 .035 .136 r
F
.66364 .30917 m .66217 .30726 L .66521 .30604 L F
.15176 .30437 m .15254 .30147 L .15452 .30337 L 0 .026 .124 r
F
.15176 .30437 m .14978 .30248 L .15254 .30147 L F
.83114 .305 m .83297 .302 L .83427 .30392 L 0 .027 .126 r
F
.83114 .305 m .82984 .30311 L .83297 .302 L F
.19403 .30458 m .19489 .30158 L .19683 .30348 L 0 .026 .125 r
F
.19403 .30458 m .19209 .3027 L .19489 .30158 L F
.52816 .32949 m .52953 .32508 L .53113 .32775 L 0 .088 .186 r
F
.52816 .32949 m .52656 .32673 L .52953 .32508 L F
.53842 .4694 m .5369 .48739 L .53987 .4816 L .102 .579 0 r
F
.44336 .31632 m .44459 .31357 L .44628 .3156 L 0 .053 .155 r
F
.44336 .31632 m .44168 .31427 L .44459 .31357 L F
.41913 .31263 m .42033 .30959 L .42204 .31159 L 0 .043 .145 r
F
.41913 .31263 m .41742 .31062 L .42033 .30959 L F
.78133 .30534 m .78308 .30224 L .78443 .30414 L 0 .027 .127 r
F
.78133 .30534 m .77998 .30345 L .78308 .30224 L F
.20156 .3043 m .20242 .30139 L .20435 .30332 L 0 .026 .124 r
F
.20156 .3043 m .19963 .30238 L .20242 .30139 L F
.29823 .30661 m .29924 .30365 L .30107 .30559 L 0 .03 .13 r
F
.29823 .30661 m .2964 .3047 L .29924 .30365 L F
.52062 .33004 m .52198 .32558 L .52359 .32839 L 0 .09 .187 r
F
.52062 .33004 m .51901 .32717 L .52198 .32558 L F
.67119 .30893 m .67277 .30586 L .67424 .30789 L 0 .035 .136 r
F
.67119 .30893 m .66972 .3069 L .67277 .30586 L F
.7738 .3058 m .77553 .30271 L .77689 .30466 L 0 .028 .128 r
F
.7738 .3058 m .77243 .30383 L .77553 .30271 L F
.26349 .30601 m .26445 .30308 L .26632 .30493 L 0 .029 .129 r
F
.26349 .30601 m .26161 .30419 L .26445 .30308 L F
.23629 .30498 m .23721 .30209 L .2391 .30397 L 0 .027 .126 r
F
.23629 .30498 m .23439 .30311 L .23721 .30209 L F
.117 .30394 m .11772 .3011 L .11974 .30296 L 0 .025 .124 r
F
.117 .30394 m .11497 .30208 L .11772 .3011 L F
.46759 .32026 m .46887 .31666 L .47052 .31931 L 0 .062 .164 r
F
.46759 .32026 m .46594 .31759 L .46887 .31666 L F
.78889 .30503 m .79065 .30211 L .792 .30404 L 0 .027 .126 r
F
.78889 .30503 m .78754 .30312 L .79065 .30211 L F
.37981 .30989 m .38094 .30712 L .38269 .30907 L 0 .038 .139 r
F
.37981 .30989 m .37806 .30798 L .38094 .30712 L F
.39947 .31135 m .40065 .30814 L .40237 .31036 L 0 .04 .142 r
F
.39947 .31135 m .39775 .30918 L .40065 .30814 L F
.27102 .30572 m .27199 .30282 L .27385 .30473 L 0 .029 .128 r
F
.27102 .30572 m .26916 .30384 L .27199 .30282 L F
.83871 .30489 m .84056 .30195 L .84186 .30392 L 0 .027 .126 r
F
.83871 .30489 m .83741 .30293 L .84056 .30195 L F
.50649 .38895 m .50492 .37705 L .50788 .37607 L 0 .332 .297 r
F
.50354 .38792 m .50492 .37705 L .50649 .38895 L 0 .329 .299 r
F
.65612 .30992 m .65767 .30679 L .65914 .30859 L 0 .037 .139 r
F
.65612 .30992 m .65464 .30811 L .65767 .30679 L F
.15926 .30428 m .16006 .30137 L .16203 .30328 L 0 .026 .125 r
F
.15926 .30428 m .15728 .30239 L .16006 .30137 L F
.53053 .3826 m .53187 .36536 L .53349 .3744 L 0 .309 .307 r
F
.53053 .3826 m .52891 .37201 L .53187 .36536 L F
.64858 .31039 m .65013 .3074 L .65161 .30925 L 0 .038 .14 r
F
.64858 .31039 m .64709 .30851 L .65013 .3074 L F
.50851 .3284 m .50985 .32464 L .51147 .32733 L 0 .087 .185 r
F
.50851 .3284 m .50689 .32569 L .50985 .32464 L F
.33295 .30753 m .33402 .30459 L .33581 .30652 L 0 .032 .133 r
F
.33295 .30753 m .33115 .30559 L .33402 .30459 L F
.1245 .30378 m .12525 .30083 L .12726 .30272 L 0 .025 .124 r
F
.1245 .30378 m .12249 .30191 L .12525 .30083 L F
.30575 .3065 m .30677 .30355 L .3086 .30547 L 0 .03 .13 r
F
.30575 .3065 m .30392 .30457 L .30677 .30355 L F
.67875 .30883 m .68034 .30573 L .6818 .30773 L 0 .035 .136 r
F
.67875 .30883 m .67729 .30682 L .68034 .30573 L F
.2438 .30491 m .24473 .30196 L .24661 .30394 L 0 .027 .127 r
F
.2438 .30491 m .24192 .30296 L .24473 .30196 L F
.58232 .31936 m .58375 .31558 L .5853 .3177 L 0 .06 .162 r
F
.58232 .31936 m .58076 .31719 L .58375 .31558 L F
.56427 .32293 m .56568 .31927 L .56725 .32123 L 0 .07 .171 r
F
.56427 .32293 m .56269 .32097 L .56568 .31927 L F
.16677 .30412 m .16759 .30108 L .16955 .30303 L 0 .026 .124 r
F
.16677 .30412 m .16481 .30218 L .16759 .30108 L F
.79646 .30496 m .79823 .30191 L .79957 .30388 L 0 .027 .127 r
F
.79646 .30496 m .79511 .30301 L .79823 .30191 L F
.69384 .30811 m .69546 .30511 L .69689 .30699 L 0 .034 .135 r
F
.69384 .30811 m .6924 .30621 L .69546 .30511 L F
.42666 .31273 m .42787 .30983 L .42956 .31201 L 0 .045 .147 r
F
.42666 .31273 m .42496 .31061 L .42787 .30983 L F
.46301 .31838 m .46428 .31518 L .46594 .31759 L 0 .059 .161 r
F
.46301 .31838 m .46134 .31605 L .46428 .31518 L F
.20905 .30437 m .20993 .30137 L .21185 .30338 L 0 .026 .125 r
F
.20905 .30437 m .20714 .30235 L .20993 .30137 L F
.34048 .30731 m .34155 .30444 L .34335 .30628 L 0 .032 .133 r
F
.34048 .30731 m .33868 .30547 L .34155 .30444 L F
.6863 .30857 m .6879 .30546 L .68935 .30739 L 0 .035 .136 r
F
.6863 .30857 m .68485 .30661 L .6879 .30546 L F
.4797 .32259 m .481 .31876 L .48264 .32137 L 0 .069 .17 r
F
.4797 .32259 m .47805 .31994 L .481 .31876 L F
.60791 .31548 m .60939 .31216 L .61091 .31396 L 0 .051 .153 r
F
.60791 .31548 m .60639 .31366 L .60939 .31216 L F
.64105 .3111 m .64258 .30783 L .64407 .30972 L 0 .04 .142 r
F
.64105 .3111 m .63955 .30916 L .64258 .30783 L F
.51122 .46908 m .51246 .49467 L .51413 .48466 L .169 .603 0 r
F
.51122 .46908 m .50956 .47731 L .51246 .49467 L F
.84629 .30487 m .84813 .30177 L .84943 .30374 L 0 .027 .126 r
F
.84629 .30487 m .845 .30291 L .84813 .30177 L F
.13201 .30362 m .13277 .30072 L .13476 .30268 L 0 .025 .124 r
F
.13201 .30362 m .13002 .30168 L .13277 .30072 L F
.70139 .30781 m .70302 .30489 L .70445 .30675 L 0 .033 .134 r
F
.70139 .30781 m .69996 .30594 L .70302 .30489 L F
.36013 .30888 m .36124 .30593 L .363 .30804 L 0 .036 .137 r
F
.36013 .30888 m .35837 .30677 L .36124 .30593 L F
.40699 .31141 m .40817 .30859 L .40989 .31055 L 0 .042 .144 r
F
.40699 .31141 m .40527 .30943 L .40817 .30859 L F
.45089 .31664 m .45214 .31351 L .45381 .31564 L 0 .054 .157 r
F
.45089 .31664 m .44921 .31456 L .45214 .31351 L F
.31327 .30639 m .31431 .30332 L .31613 .30529 L 0 .03 .13 r
F
.31327 .30639 m .31145 .30444 L .31431 .30332 L F
.71648 .30704 m .71813 .304 L .71955 .30601 L 0 .032 .132 r
F
.71648 .30704 m .71505 .30502 L .71813 .304 L F
.55376 .32629 m .55516 .32242 L .55673 .32447 L 0 .08 .18 r
F
.55376 .32629 m .55218 .32425 L .55516 .32242 L F
.85385 .30454 m .85571 .30156 L .85699 .30349 L 0 .027 .126 r
F
.85385 .30454 m .85256 .30261 L .85571 .30156 L F
.27852 .30579 m .2795 .30288 L .28135 .30489 L 0 .029 .129 r
F
.27852 .30579 m .27668 .3038 L .2795 .30288 L F
.80402 .30477 m .8058 .30174 L .80714 .30372 L 0 .027 .126 r
F
.80402 .30477 m .80268 .30279 L .8058 .30174 L F
.70893 .30749 m .71056 .30422 L .71199 .30622 L 0 .032 .133 r
F
.70893 .30749 m .7075 .30549 L .71056 .30422 L F
.50393 .32657 m .50526 .32297 L .50689 .32569 L 0 .082 .181 r
F
.50393 .32657 m .5023 .32383 L .50526 .32297 L F
.17428 .30398 m .17512 .30092 L .17706 .30294 L 0 .026 .124 r
F
.17428 .30398 m .17234 .30197 L .17512 .30092 L F
.48724 .32246 m .48854 .31912 L .49018 .32143 L 0 .07 .171 r
F
.48724 .32246 m .48559 .32015 L .48854 .31912 L F
.60038 .31618 m .60185 .31308 L .60338 .31493 L 0 .053 .156 r
F
.60038 .31618 m .59884 .3143 L .60185 .31308 L F
.43876 .31496 m .43999 .31218 L .44168 .31427 L 0 .051 .153 r
F
.43876 .31496 m .43707 .31286 L .43999 .31218 L F
.57478 .3202 m .57621 .31669 L .57777 .31877 L 0 .063 .165 r
F
.57478 .3202 m .57322 .31817 L .57621 .31669 L F
.21656 .30431 m .21746 .30121 L .21937 .30322 L 0 .026 .125 r
F
.21656 .30431 m .21465 .3023 L .21746 .30121 L F
.63352 .31184 m .63503 .3085 L .63653 .31048 L 0 .042 .144 r
F
.63352 .31184 m .63201 .30983 L .63503 .3085 L F
.348 .30724 m .34908 .30446 L .35087 .30637 L 0 .033 .134 r
F
.348 .30724 m .34621 .30537 L .34908 .30446 L F
.38732 .31017 m .38848 .30698 L .39022 .3091 L 0 .039 .14 r
F
.38732 .31017 m .38559 .30807 L .38848 .30698 L F
.53113 .32775 m .5325 .32395 L .5341 .32658 L 0 .086 .184 r
F
.53113 .32775 m .52953 .32508 L .5325 .32395 L F
.86141 .30433 m .8633 .30148 L .86457 .30334 L 0 .027 .126 r
F
.86141 .30433 m .86014 .30248 L .8633 .30148 L F
.2513 .30499 m .25224 .30204 L .25411 .30406 L 0 .028 .128 r
F
.2513 .30499 m .24943 .30297 L .25224 .30204 L F
.74666 .30563 m .74836 .30254 L .74975 .30452 L 0 .029 .129 r
F
.74666 .30563 m .74527 .30367 L .74836 .30254 L F
.73912 .30605 m .7408 .30295 L .74219 .30484 L 0 .03 .13 r
F
.73912 .30605 m .73772 .30414 L .7408 .30295 L F
.32079 .30628 m .32185 .30316 L .32365 .30528 L 0 .03 .131 r
F
.32079 .30628 m .31899 .30418 L .32185 .30316 L F
.49669 .43195 m .49515 .41931 L .49801 .42919 L 0 .467 .145 r
F
.49515 .41931 m .49648 .41465 L .49801 .42919 L 0 .42 .216 r
F
.81159 .30466 m .81339 .30165 L .81471 .30363 L 0 .027 .127 r
F
.81159 .30466 m .81026 .30269 L .81339 .30165 L F
.51605 .32873 m .5174 .32434 L .51901 .32717 L 0 .087 .186 r
F
.51605 .32873 m .51443 .32584 L .5174 .32434 L F
.72404 .30697 m .7257 .30383 L .72711 .30581 L 0 .032 .132 r
F
.72404 .30697 m .72262 .30497 L .7257 .30383 L F
.61844 .31283 m .61994 .30989 L .62145 .31166 L 0 .045 .148 r
F
.61844 .31283 m .61692 .31107 L .61994 .30989 L F
.73158 .30656 m .73325 .30338 L .73465 .30532 L 0 .031 .131 r
F
.73158 .30656 m .73018 .30459 L .73325 .30338 L F
.51541 .38199 m .51679 .36708 L .51838 .37705 L 0 .311 .307 r
F
.51541 .38199 m .51381 .37106 L .51679 .36708 L F
.52296 .38534 m .52433 .36666 L .52594 .37867 L 0 .317 .304 r
F
.52296 .38534 m .52136 .37184 L .52433 .36666 L F
.59284 .31688 m .5943 .31364 L .59584 .31555 L 0 .055 .158 r
F
.59284 .31688 m .5913 .3149 L .5943 .31364 L F
.62598 .31249 m .62749 .30919 L .629 .31117 L 0 .044 .146 r
F
.62598 .31249 m .62447 .3105 L .62749 .30919 L F
.52359 .32839 m .52495 .32397 L .52656 .32673 L 0 .086 .185 r
F
.52359 .32839 m .52198 .32558 L .52495 .32397 L F
.75422 .30538 m .75592 .30222 L .7573 .30421 L 0 .029 .128 r
F
.75422 .30538 m .75283 .3034 L .75592 .30222 L F
.18178 .30393 m .18263 .30087 L .18457 .30289 L 0 .026 .125 r
F
.18178 .30393 m .17985 .3019 L .18263 .30087 L F
.13949 .30373 m .14027 .3007 L .14225 .3027 L 0 .026 .124 r
F
.13949 .30373 m .13751 .30173 L .14027 .3007 L F
.10474 .3031 m .10546 .30011 L .10748 .30209 L 0 .025 .123 r
F
.10474 .3031 m .10272 .30113 L .10546 .30011 L F
.22408 .30415 m .22497 .30125 L .22688 .3032 L 0 .027 .126 r
F
.22408 .30415 m .22217 .3022 L .22497 .30125 L F
.54622 .32718 m .54761 .32382 L .5492 .32595 L 0 .085 .184 r
F
.54622 .32718 m .54463 .32507 L .54761 .32382 L F
.53868 .3276 m .54006 .32421 L .54165 .32632 L 0 .087 .185 r
F
.53868 .3276 m .53708 .32542 L .54006 .32421 L F
.49935 .32468 m .50068 .32129 L .5023 .32383 L 0 .077 .178 r
F
.49935 .32468 m .49772 .32214 L .50068 .32129 L F
.76177 .30502 m .76348 .30186 L .76485 .30387 L 0 .028 .128 r
F
.76177 .30502 m .76039 .30302 L .76348 .30186 L F
.36765 .30899 m .36877 .30593 L .37053 .30795 L 0 .037 .138 r
F
.36765 .30899 m .36589 .30699 L .36877 .30593 L F
.28603 .30589 m .28704 .30271 L .28887 .30478 L 0 .03 .13 r
F
.28603 .30589 m .28419 .30382 L .28704 .30271 L F
.50504 .46243 m .50624 .48347 L .5079 .48038 L .102 .579 0 r
F
.50504 .46243 m .50338 .4647 L .50624 .48347 L F
.81916 .30448 m .82097 .30155 L .82228 .30344 L 0 .027 .127 r
F
.81916 .30448 m .81784 .30259 L .82097 .30155 L F
.47511 .32102 m .47641 .31726 L .47805 .31994 L 0 .066 .168 r
F
.47511 .32102 m .47347 .31829 L .47641 .31726 L F
.41451 .31161 m .4157 .30871 L .41742 .31062 L 0 .043 .145 r
F
.41451 .31161 m .41279 .30969 L .4157 .30871 L F
.39485 .31021 m .39602 .30696 L .39775 .30918 L 0 .039 .141 r
F
.39485 .31021 m .39312 .30803 L .39602 .30696 L F
.45841 .31692 m .45968 .31371 L .46134 .31605 L 0 .056 .158 r
F
.45841 .31692 m .45675 .31466 L .45968 .31371 L F
.66668 .30794 m .66826 .30499 L .66972 .3069 L 0 .035 .136 r
F
.66668 .30794 m .66521 .30604 L .66826 .30499 L F
.1893 .30378 m .19015 .30077 L .19209 .3027 L 0 .026 .125 r
F
.1893 .30378 m .18736 .30185 L .19015 .30077 L F
.147 .30359 m .1478 .30049 L .14978 .30248 L 0 .026 .124 r
F
.147 .30359 m .14502 .30159 L .1478 .30049 L F
.76933 .30485 m .77106 .30185 L .77243 .30383 L 0 .028 .128 r
F
.76933 .30485 m .76796 .30286 L .77106 .30185 L F
.82671 .30422 m .82854 .30122 L .82984 .30311 L 0 .027 .126 r
F
.82671 .30422 m .82541 .30236 L .82854 .30122 L F
.37518 .30884 m .3763 .30606 L .37806 .30798 L 0 .037 .139 r
F
.37518 .30884 m .37342 .30696 L .3763 .30606 L F
.56725 .32123 m .56866 .31767 L .57023 .31965 L 0 .067 .169 r
F
.56725 .32123 m .56568 .31927 L .56866 .31767 L F
.29355 .30575 m .29457 .30263 L .2964 .3047 L 0 .03 .13 r
F
.29355 .30575 m .29172 .30369 L .29457 .30263 L F
.25879 .30514 m .25975 .3022 L .26161 .30419 L 0 .029 .129 r
F
.25879 .30514 m .25693 .30314 L .25975 .3022 L F
.5853 .3177 m .58675 .31411 L .5883 .31616 L 0 .057 .16 r
F
.5853 .3177 m .58375 .31558 L .58675 .31411 L F
.19683 .30348 m .1977 .30045 L .19963 .30238 L 0 .026 .124 r
F
.19683 .30348 m .19489 .30158 L .1977 .30045 L F
.11223 .30306 m .11296 .30012 L .11497 .30208 L 0 .025 .124 r
F
.11223 .30306 m .11022 .3011 L .11296 .30012 L F
.23158 .30412 m .23249 .30123 L .23439 .30311 L 0 .027 .126 r
F
.23158 .30412 m .22968 .30224 L .23249 .30123 L F
.83427 .30392 m .83611 .30099 L .83741 .30293 L F
.83427 .30392 m .83297 .302 L .83611 .30099 L F
.78443 .30414 m .78619 .30121 L .78754 .30312 L F
.78443 .30414 m .78308 .30224 L .78619 .30121 L F
.52037 .47472 m .5217 .50054 L .52333 .48625 L .217 .619 0 r
F
.52037 .47472 m .51873 .48726 L .5217 .50054 L F
.55673 .32447 m .55814 .32062 L .55971 .32267 L 0 .076 .177 r
F
.55673 .32447 m .55516 .32242 L .55814 .32062 L F
.3283 .30649 m .32936 .3035 L .33115 .30559 L 0 .032 .132 r
F
.3283 .30649 m .3265 .30439 L .32936 .3035 L F
.65914 .30859 m .6607 .30547 L .66217 .30726 L 0 .036 .137 r
F
.65914 .30859 m .65767 .30679 L .6607 .30547 L F
.15452 .30337 m .15531 .30048 L .15728 .30239 L 0 .026 .125 r
F
.15452 .30337 m .15254 .30147 L .15531 .30048 L F
.77689 .30466 m .77863 .30152 L .77998 .30345 L 0 .028 .127 r
F
.77689 .30466 m .77553 .30271 L .77863 .30152 L F
.42204 .31159 m .42325 .30861 L .42496 .31061 L 0 .043 .146 r
F
.42204 .31159 m .42033 .30959 L .42325 .30861 L F
.3555 .30762 m .3566 .30466 L .35837 .30677 L 0 .034 .135 r
F
.3555 .30762 m .35373 .30551 L .3566 .30466 L F
.26632 .30493 m .26729 .30196 L .26916 .30384 L 0 .029 .129 r
F
.26632 .30493 m .26445 .30308 L .26729 .30196 L F
.49477 .32294 m .49609 .31979 L .49772 .32214 L 0 .074 .175 r
F
.49477 .32294 m .49313 .32061 L .49609 .31979 L F
.43416 .31353 m .43539 .31058 L .43707 .31286 L 0 .048 .151 r
F
.43416 .31353 m .43247 .31129 L .43539 .31058 L F
.61091 .31396 m .6124 .31066 L .61391 .31243 L 0 .049 .151 r
F
.61091 .31396 m .60939 .31216 L .6124 .31066 L F
.67424 .30789 m .67582 .3048 L .67729 .30682 L 0 .035 .136 r
F
.67424 .30789 m .67277 .30586 L .67582 .3048 L F
.30107 .30559 m .3021 .30262 L .30392 .30457 L 0 .03 .13 r
F
.30107 .30559 m .29924 .30365 L .3021 .30262 L F
.20435 .30332 m .20521 .30042 L .20714 .30235 L 0 .026 .125 r
F
.20435 .30332 m .20242 .30139 L .20521 .30042 L F
.2391 .30397 m .24002 .30107 L .24192 .30296 L 0 .027 .126 r
F
.2391 .30397 m .23721 .30209 L .24002 .30107 L F
.11974 .30296 m .12047 .30003 L .12249 .30191 L 0 .025 .124 r
F
.11974 .30296 m .11772 .3011 L .12047 .30003 L F
.65161 .30925 m .65317 .30629 L .65464 .30811 L 0 .038 .14 r
F
.65161 .30925 m .65013 .3074 L .65317 .30629 L F
.47052 .31931 m .47182 .31568 L .47347 .31829 L 0 .062 .164 r
F
.47052 .31931 m .46887 .31666 L .47182 .31568 L F
.792 .30404 m .79377 .30106 L .79511 .30301 L 0 .027 .127 r
F
.792 .30404 m .79065 .30211 L .79377 .30106 L F
.64407 .30972 m .64561 .30665 L .64709 .30851 L 0 .039 .141 r
F
.64407 .30972 m .64258 .30783 L .64561 .30665 L F
.50945 .38798 m .50788 .37607 L .51085 .37356 L 0 .329 .299 r
F
.50649 .38895 m .50788 .37607 L .50945 .38798 L 0 .332 .297 r
F
.40237 .31036 m .40355 .3072 L .40527 .30943 L 0 .04 .142 r
F
.40237 .31036 m .40065 .30814 L .40355 .3072 L F
.44628 .3156 m .44753 .3125 L .44921 .31456 L 0 .054 .156 r
F
.44628 .3156 m .44459 .31357 L .44753 .3125 L F
.27385 .30473 m .27482 .30187 L .27668 .3038 L 0 .029 .129 r
F
.27385 .30473 m .27199 .30282 L .27482 .30187 L F
.51147 .32733 m .51281 .32316 L .51443 .32584 L 0 .085 .184 r
F
.51147 .32733 m .50985 .32464 L .51281 .32316 L F
.16203 .30328 m .16284 .30027 L .16481 .30218 L 0 .026 .125 r
F
.16203 .30328 m .16006 .30137 L .16284 .30027 L F
.84186 .30392 m .8437 .30093 L .845 .30291 L 0 .027 .126 r
F
.84186 .30392 m .84056 .30195 L .8437 .30093 L F
.6818 .30773 m .68339 .30464 L .68485 .30661 L 0 .035 .136 r
F
.6818 .30773 m .68034 .30573 L .68339 .30464 L F
.12726 .30272 m .12801 .29977 L .13002 .30168 L 0 .025 .123 r
F
.12726 .30272 m .12525 .30083 L .12801 .29977 L F
.48264 .32137 m .48395 .31758 L .48559 .32015 L 0 .068 .17 r
F
.48264 .32137 m .481 .31876 L .48395 .31758 L F
.3086 .30547 m .30963 .30253 L .31145 .30444 L 0 .03 .131 r
F
.3086 .30547 m .30677 .30355 L .30963 .30253 L F
.33581 .30652 m .33689 .30356 L .33868 .30547 L 0 .032 .133 r
F
.33581 .30652 m .33402 .30459 L .33689 .30356 L F
.68935 .30739 m .69095 .3043 L .6924 .30621 L 0 .034 .135 r
F
.68935 .30739 m .6879 .30546 L .69095 .3043 L F
.38269 .30907 m .38384 .30611 L .38559 .30807 L 0 .038 .14 r
F
.38269 .30907 m .38094 .30712 L .38384 .30611 L F
.69689 .30699 m .69852 .30409 L .69996 .30594 L 0 .034 .135 r
F
.69689 .30699 m .69546 .30511 L .69852 .30409 L F
.16955 .30303 m .17038 .30001 L .17234 .30197 L 0 .025 .124 r
F
.16955 .30303 m .16759 .30108 L .17038 .30001 L F
.51243 .38499 m .51085 .37356 L .51381 .37106 L 0 .322 .302 r
F
.50945 .38798 m .51085 .37356 L .51243 .38499 L 0 .329 .299 r
F
.79957 .30388 m .80134 .30081 L .80268 .30279 L 0 .027 .126 r
F
.79957 .30388 m .79823 .30191 L .80134 .30081 L F
.57777 .31877 m .5792 .31507 L .58076 .31719 L 0 .061 .163 r
F
.57777 .31877 m .57621 .31669 L .5792 .31507 L F
.52656 .32673 m .52792 .32237 L .52953 .32508 L 0 .083 .182 r
F
.52656 .32673 m .52495 .32397 L .52792 .32237 L F
.71199 .30622 m .71362 .30301 L .71505 .30502 L 0 .032 .132 r
F
.71199 .30622 m .71056 .30422 L .71362 .30301 L F
.51901 .32717 m .52037 .32279 L .52198 .32558 L 0 .085 .184 r
F
.51901 .32717 m .5174 .32434 L .52037 .32279 L F
.24661 .30394 m .24755 .30096 L .24943 .30297 L 0 .027 .127 r
F
.24661 .30394 m .24473 .30196 L .24755 .30096 L F
.84943 .30374 m .85127 .30063 L .85256 .30261 L 0 .027 .126 r
F
.84943 .30374 m .84813 .30177 L .85127 .30063 L F
.34335 .30628 m .34442 .3035 L .34621 .30537 L 0 .033 .133 r
F
.34335 .30628 m .34155 .30444 L .34442 .3035 L F
.63653 .31048 m .63806 .30722 L .63955 .30916 L 0 .041 .143 r
F
.63653 .31048 m .63503 .3085 L .63806 .30722 L F
.54296 .40231 m .54425 .38206 L .54587 .38952 L 0 .361 .277 r
F
.54296 .40231 m .54132 .39333 L .54425 .38206 L F
.21185 .30338 m .21274 .30029 L .21465 .3023 L 0 .026 .125 r
F
.21185 .30338 m .20993 .30137 L .21274 .30029 L F
.70445 .30675 m .70608 .30364 L .7075 .30549 L 0 .033 .134 r
F
.70445 .30675 m .70302 .30489 L .70608 .30364 L F
.31613 .30529 m .31718 .3022 L .31899 .30418 L 0 .03 .13 r
F
.31613 .30529 m .31431 .30332 L .31718 .3022 L F
.60338 .31493 m .60486 .31184 L .60639 .31366 L 0 .052 .155 r
F
.60338 .31493 m .60185 .31308 L .60486 .31184 L F
.51243 .38499 m .51381 .37106 L .51541 .38199 L 0 .322 .302 r
F
.85699 .30349 m .85887 .30055 L .86014 .30248 L 0 .027 .126 r
F
.85699 .30349 m .85571 .30156 L .85887 .30055 L F
.71955 .30601 m .7212 .30296 L .72262 .30497 L 0 .032 .132 r
F
.71955 .30601 m .71813 .304 L .7212 .30296 L F
.45381 .31564 m .45507 .31248 L .45675 .31466 L 0 .054 .157 r
F
.45381 .31564 m .45214 .31351 L .45507 .31248 L F
.80714 .30372 m .80893 .30071 L .81026 .30269 L 0 .027 .126 r
F
.80714 .30372 m .8058 .30174 L .80893 .30071 L F
.13476 .30268 m .13552 .29976 L .13751 .30173 L 0 .025 .124 r
F
.13476 .30268 m .13277 .30072 L .13552 .29976 L F
.5341 .32658 m .53548 .32282 L .53708 .32542 L 0 .085 .184 r
F
.5341 .32658 m .5325 .32395 L .53548 .32282 L F
.46594 .31759 m .46722 .31425 L .46887 .31666 L 0 .059 .161 r
F
.46594 .31759 m .46428 .31518 L .46722 .31425 L F
.17706 .30294 m .1779 .29987 L .17985 .3019 L 0 .026 .124 r
F
.17706 .30294 m .17512 .30092 L .1779 .29987 L F
.74219 .30484 m .74388 .3018 L .74527 .30367 L 0 .029 .129 r
F
.74219 .30484 m .7408 .30295 L .74388 .3018 L F
.09998 .30214 m .1007 .29917 L .10272 .30113 L 0 .024 .123 r
F
.09998 .30214 m .09795 .3002 L .1007 .29917 L F
.59584 .31555 m .59731 .31243 L .59884 .3143 L 0 .054 .157 r
F
.59584 .31555 m .5943 .31364 L .59731 .31243 L F
.55971 .32267 m .56112 .31893 L .56269 .32097 L 0 .073 .174 r
F
.55971 .32267 m .55814 .32062 L .56112 .31893 L F
.21937 .30322 m .22027 .3002 L .22217 .3022 L 0 .026 .125 r
F
.21937 .30322 m .21746 .30121 L .22027 .3002 L F
.629 .31117 m .63051 .30786 L .63201 .30983 L 0 .043 .145 r
F
.629 .31117 m .62749 .30919 L .63051 .30786 L F
.28135 .30489 m .28235 .3018 L .28419 .30382 L 0 .029 .129 r
F
.28135 .30489 m .2795 .30288 L .28235 .3018 L F
.49018 .32143 m .4915 .31828 L .49313 .32061 L 0 .071 .172 r
F
.49018 .32143 m .48854 .31912 L .4915 .31828 L F
.42956 .31201 m .43078 .30906 L .43247 .31129 L 0 .046 .148 r
F
.42956 .31201 m .42787 .30983 L .43078 .30906 L F
.40989 .31055 m .41107 .30775 L .41279 .30969 L 0 .042 .145 r
F
.40989 .31055 m .40817 .30859 L .41107 .30775 L F
.73465 .30532 m .73633 .30222 L .73772 .30414 L 0 .03 .131 r
F
.73465 .30532 m .73325 .30338 L .73633 .30222 L F
.363 .30804 m .36413 .30487 L .36589 .30699 L 0 .036 .137 r
F
.363 .30804 m .36124 .30593 L .36413 .30487 L F
.39022 .3091 m .39139 .30589 L .39312 .30803 L 0 .038 .14 r
F
.39022 .3091 m .38848 .30698 L .39139 .30589 L F
.74975 .30452 m .75144 .30141 L .75283 .3034 L 0 .029 .129 r
F
.74975 .30452 m .74836 .30254 L .75144 .30141 L F
.50689 .32569 m .50823 .32195 L .50985 .32464 L 0 .082 .182 r
F
.50689 .32569 m .50526 .32297 L .50823 .32195 L F
.54165 .32632 m .54304 .32295 L .54463 .32507 L 0 .085 .184 r
F
.54165 .32632 m .54006 .32421 L .54304 .32295 L F
.62145 .31166 m .62296 .30871 L .62447 .3105 L 0 .045 .147 r
F
.62145 .31166 m .61994 .30989 L .62296 .30871 L F
.72711 .30581 m .72877 .30262 L .73018 .30459 L 0 .031 .132 r
F
.72711 .30581 m .7257 .30383 L .72877 .30262 L F
.57023 .31965 m .57165 .31614 L .57322 .31817 L 0 .065 .167 r
F
.57023 .31965 m .56866 .31767 L .57165 .31614 L F
.5492 .32595 m .55059 .3221 L .55218 .32425 L 0 .083 .182 r
F
.5492 .32595 m .54761 .32382 L .55059 .3221 L F
.7573 .30421 m .759 .30102 L .76039 .30302 L 0 .028 .128 r
F
.7573 .30421 m .75592 .30222 L .759 .30102 L F
.32365 .30528 m .32471 .30228 L .3265 .30439 L 0 .031 .131 r
F
.32365 .30528 m .32185 .30316 L .32471 .30228 L F
.5883 .31616 m .58975 .31291 L .5913 .3149 L 0 .056 .158 r
F
.5883 .31616 m .58675 .31411 L .58975 .31291 L F
.81471 .30363 m .81652 .30063 L .81784 .30259 L 0 .027 .127 r
F
.81471 .30363 m .81339 .30165 L .81652 .30063 L F
.35087 .30637 m .35195 .30357 L .35373 .30551 L 0 .033 .134 r
F
.35087 .30637 m .34908 .30446 L .35195 .30357 L F
.25411 .30406 m .25506 .30112 L .25693 .30314 L 0 .028 .128 r
F
.25411 .30406 m .25224 .30204 L .25506 .30112 L F
.76485 .30387 m .76658 .30087 L .76796 .30286 L 0 .028 .127 r
F
.76485 .30387 m .76348 .30186 L .76658 .30087 L F
.53675 .39474 m .53806 .37526 L .53969 .38428 L 0 .343 .29 r
F
.53675 .39474 m .53511 .38403 L .53806 .37526 L F
.18457 .30289 m .18542 .29985 L .18736 .30185 L 0 .026 .125 r
F
.18457 .30289 m .18263 .30087 L .18542 .29985 L F
.28887 .30478 m .28989 .30162 L .29172 .30369 L 0 .03 .13 r
F
.28887 .30478 m .28704 .30271 L .28989 .30162 L F
.14225 .3027 m .14304 .2996 L .14502 .30159 L 0 .026 .124 r
F
.14225 .3027 m .14027 .3007 L .14304 .2996 L F
.10748 .30209 m .1082 .29912 L .11022 .3011 L 0 .025 .123 r
F
.10748 .30209 m .10546 .30011 L .1082 .29912 L F
.37053 .30795 m .37166 .3049 L .37342 .30696 L 0 .037 .138 r
F
.37053 .30795 m .36877 .30593 L .37166 .3049 L F
.44168 .31427 m .44291 .31151 L .44459 .31357 L 0 .052 .155 r
F
.44168 .31427 m .43999 .31218 L .44291 .31151 L F
.47805 .31994 m .47936 .31613 L .481 .31876 L 0 .065 .167 r
F
.47805 .31994 m .47641 .31726 L .47936 .31613 L F
.22688 .3032 m .22778 .30029 L .22968 .30224 L 0 .027 .126 r
F
.22688 .3032 m .22497 .30125 L .22778 .30029 L F
.61391 .31243 m .61541 .3093 L .61692 .31107 L 0 .047 .149 r
F
.61391 .31243 m .6124 .31066 L .61541 .3093 L F
.82228 .30344 m .8241 .30046 L .82541 .30236 L 0 .027 .127 r
F
.82228 .30344 m .82097 .30155 L .8241 .30046 L F
.66217 .30726 m .66374 .30425 L .66521 .30604 L 0 .035 .136 r
F
.66217 .30726 m .6607 .30547 L .66374 .30425 L F
.41742 .31062 m .41862 .30772 L .42033 .30959 L 0 .043 .145 r
F
.41742 .31062 m .4157 .30871 L .41862 .30772 L F
.51579 .47393 m .51707 .49974 L .51873 .48726 L .217 .619 0 r
F
.51579 .47393 m .51413 .48466 L .51707 .49974 L F
.5023 .32383 m .50364 .32042 L .50526 .32297 L 0 .078 .178 r
F
.5023 .32383 m .50068 .32129 L .50364 .32042 L F
.39775 .30918 m .39893 .30588 L .40065 .30814 L 0 .039 .141 r
F
.39775 .30918 m .39602 .30696 L .39893 .30588 L F
.14978 .30248 m .15057 .29948 L .15254 .30147 L 0 .026 .124 r
F
.14978 .30248 m .1478 .30049 L .15057 .29948 L F
.82984 .30311 m .83166 .30008 L .83297 .302 L 0 .027 .126 r
F
.82984 .30311 m .82854 .30122 L .83166 .30008 L F
.19209 .3027 m .19296 .29964 L .19489 .30158 L 0 .026 .125 r
F
.19209 .3027 m .19015 .30077 L .19296 .29964 L F
.66972 .3069 m .67131 .30395 L .67277 .30586 L 0 .035 .136 r
F
.66972 .3069 m .66826 .30499 L .67131 .30395 L F
.77243 .30383 m .77417 .30076 L .77553 .30271 L 0 .028 .128 r
F
.77243 .30383 m .77106 .30185 L .77417 .30076 L F
.19963 .30238 m .20049 .29945 L .20242 .30139 L 0 .026 .124 r
F
.19963 .30238 m .1977 .30045 L .20049 .29945 L F
.51443 .32584 m .51578 .32167 L .5174 .32434 L 0 .083 .182 r
F
.51443 .32584 m .51281 .32316 L .51578 .32167 L F
.2964 .3047 m .29742 .30157 L .29924 .30365 L 0 .03 .13 r
F
.2964 .3047 m .29457 .30263 L .29742 .30157 L F
.77998 .30345 m .78173 .30033 L .78308 .30224 L 0 .027 .127 r
F
.77998 .30345 m .77863 .30152 L .78173 .30033 L F
.46134 .31605 m .46262 .31277 L .46428 .31518 L 0 .056 .159 r
F
.46134 .31605 m .45968 .31371 L .46262 .31277 L F
.52953 .32508 m .5309 .32124 L .5325 .32395 L 0 .082 .181 r
F
.52953 .32508 m .52792 .32237 L .5309 .32124 L F
.23439 .30311 m .2353 .30021 L .23721 .30209 L 0 .027 .126 r
F
.23439 .30311 m .23249 .30123 L .2353 .30021 L F
.78754 .30312 m .78931 .30018 L .79065 .30211 L F
.78754 .30312 m .78619 .30121 L .78931 .30018 L F
.50508 .40494 m .50354 .38792 L .50649 .38895 L 0 .38 .261 r
F
.50213 .40324 m .50354 .38792 L .50508 .40494 L 0 .37 .27 r
F
.11497 .30208 m .11571 .29914 L .11772 .3011 L 0 .025 .124 r
F
.11497 .30208 m .11296 .30012 L .11571 .29914 L F
.83741 .30293 m .83926 .3 L .84056 .30195 L 0 .027 .126 r
F
.83741 .30293 m .83611 .30099 L .83926 .3 L F
.26161 .30419 m .26259 .30108 L .26445 .30308 L 0 .029 .129 r
F
.26161 .30419 m .25975 .3022 L .26259 .30108 L F
.58076 .31719 m .58219 .31343 L .58375 .31558 L 0 .059 .161 r
F
.58076 .31719 m .5792 .31507 L .58219 .31343 L F
.37806 .30798 m .37919 .30517 L .38094 .30712 L 0 .038 .139 r
F
.37806 .30798 m .3763 .30606 L .37919 .30517 L F
.52198 .32558 m .52334 .32123 L .52495 .32397 L 0 .082 .181 r
F
.52198 .32558 m .52037 .32279 L .52334 .32123 L F
.26916 .30384 m .27012 .30091 L .27199 .30282 L 0 .029 .128 r
F
.26916 .30384 m .26729 .30196 L .27012 .30091 L F
.15728 .30239 m .15808 .29945 L .16006 .30137 L 0 .026 .125 r
F
.15728 .30239 m .15531 .30048 L .15808 .29945 L F
.67729 .30682 m .67888 .30374 L .68034 .30573 L 0 .035 .136 r
F
.67729 .30682 m .67582 .3048 L .67888 .30374 L F
.64709 .30851 m .64864 .30557 L .65013 .3074 L 0 .039 .14 r
F
.64709 .30851 m .64561 .30665 L .64864 .30557 L F
.42496 .31061 m .42616 .30778 L .42787 .30983 L 0 .044 .146 r
F
.42496 .31061 m .42325 .30861 L .42616 .30778 L F
.65464 .30811 m .6562 .30498 L .65767 .30679 L 0 .037 .139 r
F
.65464 .30811 m .65317 .30629 L .6562 .30498 L F
.33115 .30559 m .33222 .30252 L .33402 .30459 L 0 .032 .133 r
F
.33115 .30559 m .32936 .3035 L .33222 .30252 L F
.30392 .30457 m .30495 .30161 L .30677 .30355 L 0 .03 .13 r
F
.30392 .30457 m .3021 .30262 L .30495 .30161 L F
.51998 .39203 m .52136 .37184 L .52296 .38534 L 0 .337 .294 r
F
.51998 .39203 m .51838 .37705 L .52136 .37184 L F
.12249 .30191 m .12324 .29894 L .12525 .30083 L 0 .025 .124 r
F
.12249 .30191 m .12047 .30003 L .12324 .29894 L F
.24192 .30296 m .24284 .30004 L .24473 .30196 L 0 .027 .126 r
F
.24192 .30296 m .24002 .30107 L .24284 .30004 L F
.56269 .32097 m .56411 .31723 L .56568 .31927 L 0 .07 .171 r
F
.56269 .32097 m .56112 .31893 L .56411 .31723 L F
.48559 .32015 m .4869 .31655 L .48854 .31912 L 0 .068 .169 r
F
.48559 .32015 m .48395 .31758 L .4869 .31655 L F
.20714 .30235 m .20801 .29943 L .20993 .30137 L 0 .026 .125 r
F
.20714 .30235 m .20521 .30042 L .20801 .29943 L F
.35837 .30677 m .35948 .30381 L .36124 .30593 L 0 .035 .136 r
F
.35837 .30677 m .3566 .30466 L .35948 .30381 L F
.47347 .31829 m .47476 .31468 L .47641 .31726 L 0 .062 .164 r
F
.47347 .31829 m .47182 .31568 L .47476 .31468 L F
.79511 .30301 m .79688 .29995 L .79823 .30191 L 0 .027 .126 r
F
.79511 .30301 m .79377 .30106 L .79688 .29995 L F
.16481 .30218 m .16563 .29916 L .16759 .30108 L 0 .026 .124 r
F
.16481 .30218 m .16284 .30027 L .16563 .29916 L F
.44921 .31456 m .45046 .31142 L .45214 .31351 L 0 .053 .156 r
F
.44921 .31456 m .44753 .3125 L .45046 .31142 L F
.68485 .30661 m .68645 .30351 L .6879 .30546 L 0 .034 .136 r
F
.68485 .30661 m .68339 .30464 L .68645 .30351 L F
.6924 .30621 m .69402 .30323 L .69546 .30511 L 0 .034 .135 r
F
.6924 .30621 m .69095 .3043 L .69402 .30323 L F
.63955 .30916 m .64108 .30594 L .64258 .30783 L 0 .04 .142 r
F
.63955 .30916 m .63806 .30722 L .64108 .30594 L F
.49772 .32214 m .49905 .31891 L .50068 .32129 L 0 .075 .175 r
F
.49772 .32214 m .49609 .31979 L .49905 .31891 L F
.55218 .32425 m .55357 .32026 L .55516 .32242 L 0 .079 .179 r
F
.55218 .32425 m .55059 .3221 L .55357 .32026 L F
.845 .30291 m .84684 .29979 L .84813 .30177 L 0 .027 .126 r
F
.845 .30291 m .8437 .30093 L .84684 .29979 L F
.71505 .30502 m .7167 .30198 L .71813 .304 L 0 .031 .132 r
F
.71505 .30502 m .71362 .30301 L .7167 .30198 L F
.13002 .30168 m .13076 .29879 L .13277 .30072 L 0 .025 .124 r
F
.13002 .30168 m .12801 .29977 L .13076 .29879 L F
.40527 .30943 m .40645 .30637 L .40817 .30859 L 0 .041 .143 r
F
.40527 .30943 m .40355 .3072 L .40645 .30637 L F
.33868 .30547 m .33976 .30254 L .34155 .30444 L 0 .032 .133 r
F
.33868 .30547 m .33689 .30356 L .33976 .30254 L F
.27668 .3038 m .27765 .30092 L .2795 .30288 L 0 .029 .129 r
F
.27668 .3038 m .27482 .30187 L .27765 .30092 L F
.31145 .30444 m .31249 .3014 L .31431 .30332 L 0 .03 .13 r
F
.31145 .30444 m .30963 .30253 L .31249 .3014 L F
.60639 .31366 m .60787 .31035 L .60939 .31216 L 0 .051 .153 r
F
.60639 .31366 m .60486 .31184 L .60787 .31035 L F
.7075 .30549 m .70914 .30236 L .71056 .30422 L 0 .032 .133 r
F
.7075 .30549 m .70608 .30364 L .70914 .30236 L F
.50074 .41407 m .49921 .39889 L .50213 .40324 L 0 .412 .225 r
F
.49783 .40786 m .49921 .39889 L .50074 .41407 L 0 .387 .254 r
F
.80268 .30279 m .80447 .29976 L .8058 .30174 L 0 .027 .126 r
F
.80268 .30279 m .80134 .30081 L .80447 .29976 L F
.69996 .30594 m .70159 .30306 L .70302 .30489 L 0 .034 .135 r
F
.69996 .30594 m .69852 .30409 L .70159 .30306 L F
.17234 .30197 m .17316 .29894 L .17512 .30092 L 0 .025 .124 r
F
.17234 .30197 m .17038 .30001 L .17316 .29894 L F
.43707 .31286 m .4383 .30988 L .43999 .31218 L 0 .05 .152 r
F
.43707 .31286 m .43539 .31058 L .4383 .30988 L F
.85256 .30261 m .85442 .29958 L .85571 .30156 L 0 .027 .126 r
F
.85256 .30261 m .85127 .30063 L .85442 .29958 L F
.38559 .30807 m .38674 .30503 L .38848 .30698 L 0 .038 .14 r
F
.38559 .30807 m .38384 .30611 L .38674 .30503 L F
.57322 .31817 m .57465 .31461 L .57621 .31669 L 0 .063 .165 r
F
.57322 .31817 m .57165 .31614 L .57465 .31461 L F
.63201 .30983 m .63353 .30654 L .63503 .3085 L 0 .042 .144 r
F
.63201 .30983 m .63051 .30786 L .63353 .30654 L F
.31899 .30418 m .32004 .30117 L .32185 .30316 L 0 .03 .13 r
F
.31899 .30418 m .31718 .3022 L .32004 .30117 L F
.21465 .3023 m .21555 .29921 L .21746 .30121 L 0 .026 .125 r
F
.21465 .3023 m .21274 .30029 L .21555 .29921 L F
.24943 .30297 m .25037 .30002 L .25224 .30204 L 0 .028 .127 r
F
.24943 .30297 m .24755 .30096 L .25037 .30002 L F
.59884 .3143 m .60032 .31123 L .60185 .31308 L 0 .053 .156 r
F
.59884 .3143 m .59731 .31243 L .60032 .31123 L F
.53708 .32542 m .53846 .32163 L .54006 .32421 L 0 .084 .183 r
F
.53708 .32542 m .53548 .32282 L .53846 .32163 L F
.49801 .42919 m .49648 .41465 L .49937 .4225 L 0 .459 .158 r
F
.49648 .41465 m .49783 .40786 L .49937 .4225 L 0 .408 .231 r
F
.74527 .30367 m .74697 .30069 L .74836 .30254 L 0 .029 .129 r
F
.74527 .30367 m .74388 .3018 L .74697 .30069 L F
.34621 .30537 m .3473 .30255 L .34908 .30446 L 0 .033 .134 r
F
.34621 .30537 m .34442 .3035 L .3473 .30255 L F
.54463 .32507 m .54602 .32168 L .54761 .32382 L 0 .084 .183 r
F
.54463 .32507 m .54304 .32295 L .54602 .32168 L F
.72262 .30497 m .72428 .30183 L .7257 .30383 L 0 .032 .132 r
F
.72262 .30497 m .7212 .30296 L .72428 .30183 L F
.73772 .30414 m .73941 .30106 L .7408 .30295 L 0 .03 .13 r
F
.73772 .30414 m .73633 .30222 L .73941 .30106 L F
.81026 .30269 m .81206 .29968 L .81339 .30165 L 0 .027 .126 r
F
.81026 .30269 m .80893 .30071 L .81206 .29968 L F
.52756 .39083 m .52891 .37201 L .53053 .3826 L 0 .336 .295 r
F
.52756 .39083 m .52594 .37867 L .52891 .37201 L F
.86014 .30248 m .86203 .29955 L .8633 .30148 L 0 .027 .126 r
F
.86014 .30248 m .85887 .30055 L .86203 .29955 L F
.73018 .30459 m .73184 .30142 L .73325 .30338 L 0 .031 .131 r
F
.73018 .30459 m .72877 .30262 L .73184 .30142 L F
.45675 .31466 m .45801 .31148 L .45968 .31371 L 0 .054 .157 r
F
.45675 .31466 m .45507 .31248 L .45801 .31148 L F
.17985 .3019 m .18069 .29885 L .18263 .30087 L 0 .026 .124 r
F
.17985 .3019 m .1779 .29987 L .18069 .29885 L F
.62447 .3105 m .62598 .30738 L .62749 .30919 L 0 .044 .146 r
F
.62447 .3105 m .62296 .30871 L .62598 .30738 L F
.5913 .3149 m .59276 .31172 L .5943 .31364 L 0 .055 .157 r
F
.5913 .3149 m .58975 .31291 L .59276 .31172 L F
.28419 .30382 m .2852 .30069 L .28704 .30271 L 0 .029 .129 r
F
.28419 .30382 m .28235 .3018 L .2852 .30069 L F
.75283 .3034 m .75453 .30022 L .75592 .30222 L 0 .028 .128 r
F
.75283 .3034 m .75144 .30141 L .75453 .30022 L F
.53215 .39392 m .53349 .3744 L .53511 .38403 L 0 .343 .29 r
F
.53215 .39392 m .53053 .3826 L .53349 .3744 L F
.13751 .30173 m .13828 .29873 L .14027 .3007 L 0 .025 .124 r
F
.13751 .30173 m .13552 .29976 L .13828 .29873 L F
.39312 .30803 m .39429 .30479 L .39602 .30696 L 0 .038 .14 r
F
.39312 .30803 m .39139 .30589 L .39429 .30479 L F
.10272 .30113 m .10344 .29815 L .10546 .30011 L 0 .024 .123 r
F
.10272 .30113 m .1007 .29917 L .10344 .29815 L F
.36589 .30699 m .36702 .30378 L .36877 .30593 L 0 .036 .137 r
F
.36589 .30699 m .36413 .30487 L .36702 .30378 L F
.76039 .30302 m .7621 .29986 L .76348 .30186 L 0 .028 .127 r
F
.76039 .30302 m .759 .30102 L .7621 .29986 L F
.22217 .3022 m .22307 .29925 L .22497 .30125 L 0 .026 .126 r
F
.22217 .3022 m .22027 .3002 L .22307 .29925 L F
.46887 .31666 m .47016 .3133 L .47182 .31568 L 0 .06 .162 r
F
.46887 .31666 m .46722 .31425 L .47016 .3133 L F
.50985 .32464 m .51119 .32048 L .51281 .32316 L 0 .081 .181 r
F
.50985 .32464 m .50823 .32195 L .51119 .32048 L F
.61692 .31107 m .61843 .30811 L .61994 .30989 L 0 .046 .148 r
F
.61692 .31107 m .61541 .3093 L .61843 .30811 L F
.5174 .32434 m .51875 .32016 L .52037 .32279 L 0 .08 .18 r
F
.5174 .32434 m .51578 .32167 L .51875 .32016 L F
.41279 .30969 m .41398 .30681 L .4157 .30871 L 0 .043 .145 r
F
.41279 .30969 m .41107 .30775 L .41398 .30681 L F
.81784 .30259 m .81965 .2996 L .82097 .30155 L 0 .027 .127 r
F
.81784 .30259 m .81652 .30063 L .81965 .2996 L F
.58375 .31558 m .58519 .31193 L .58675 .31411 L 0 .056 .159 r
F
.58375 .31558 m .58219 .31343 L .58519 .31193 L F
.49313 .32061 m .49445 .31744 L .49609 .31979 L 0 .072 .173 r
F
.49313 .32061 m .4915 .31828 L .49445 .31744 L F
.52495 .32397 m .52631 .31967 L .52792 .32237 L 0 .079 .179 r
F
.52495 .32397 m .52334 .32123 L .52631 .31967 L F
.481 .31876 m .48231 .31499 L .48395 .31758 L 0 .065 .167 r
F
.481 .31876 m .47936 .31613 L .48231 .31499 L F
.29172 .30369 m .29274 .30055 L .29457 .30263 L 0 .029 .129 r
F
.29172 .30369 m .28989 .30162 L .29274 .30055 L F
.14502 .30159 m .14582 .29849 L .1478 .30049 L 0 .025 .124 r
F
.14502 .30159 m .14304 .2996 L .14582 .29849 L F
.76796 .30286 m .76969 .29987 L .77106 .30185 L 0 .028 .128 r
F
.76796 .30286 m .76658 .30087 L .76969 .29987 L F
.66521 .30604 m .66679 .30321 L .66826 .30499 L 0 .035 .136 r
F
.66521 .30604 m .66374 .30425 L .66679 .30321 L F
.18736 .30185 m .18821 .29878 L .19015 .30077 L 0 .026 .125 r
F
.18736 .30185 m .18542 .29985 L .18821 .29878 L F
.43247 .31129 m .4337 .3083 L .43539 .31058 L 0 .047 .149 r
F
.43247 .31129 m .43078 .30906 L .4337 .3083 L F
.3265 .30439 m .32756 .3014 L .32936 .3035 L 0 .031 .132 r
F
.3265 .30439 m .32471 .30228 L .32756 .3014 L F
.25693 .30314 m .25788 .30018 L .25975 .3022 L 0 .029 .128 r
F
.25693 .30314 m .25506 .30112 L .25788 .30018 L F
.56568 .31927 m .56709 .3156 L .56866 .31767 L 0 .067 .168 r
F
.56568 .31927 m .56411 .31723 L .56709 .3156 L F
.55516 .32242 m .55656 .31844 L .55814 .32062 L 0 .075 .176 r
F
.55516 .32242 m .55357 .32026 L .55656 .31844 L F
.37342 .30696 m .37455 .30398 L .3763 .30606 L 0 .037 .138 r
F
.37342 .30696 m .37166 .3049 L .37455 .30398 L F
.11022 .3011 m .11095 .29815 L .11296 .30012 L 0 .025 .123 r
F
.11022 .3011 m .1082 .29912 L .11095 .29815 L F
.82541 .30236 m .82723 .29932 L .82854 .30122 L 0 .027 .126 r
F
.82541 .30236 m .8241 .30046 L .82723 .29932 L F
.35373 .30551 m .35483 .3027 L .3566 .30466 L 0 .034 .135 r
F
.35373 .30551 m .35195 .30357 L .35483 .3027 L F
.54459 .41129 m .54587 .38952 L .5475 .39698 L 0 .387 .254 r
F
.54459 .41129 m .54296 .40231 L .54587 .38952 L F
.19489 .30158 m .19576 .29851 L .1977 .30045 L 0 .026 .124 r
F
.19489 .30158 m .19296 .29964 L .19576 .29851 L F
.83297 .302 m .83481 .29905 L .83611 .30099 L 0 .027 .126 r
F
.83297 .302 m .83166 .30008 L .83481 .29905 L F
.78308 .30224 m .78484 .29931 L .78619 .30121 L F
.78308 .30224 m .78173 .30033 L .78484 .29931 L F
.22968 .30224 m .23059 .29929 L .23249 .30123 L F
.22968 .30224 m .22778 .30029 L .23059 .29929 L F
.42033 .30959 m .42153 .30675 L .42325 .30861 L 0 .043 .145 r
F
.42033 .30959 m .41862 .30772 L .42153 .30675 L F
.40065 .30814 m .40183 .30492 L .40355 .3072 L 0 .039 .141 r
F
.40065 .30814 m .39893 .30588 L .40183 .30492 L F
.77553 .30271 m .77727 .29959 L .77863 .30152 L 0 .028 .127 r
F
.77553 .30271 m .77417 .30076 L .77727 .29959 L F
.67277 .30586 m .67436 .30289 L .67582 .3048 L 0 .035 .136 r
F
.67277 .30586 m .67131 .30395 L .67436 .30289 L F
.15254 .30147 m .15334 .29847 L .15531 .30048 L 0 .026 .124 r
F
.15254 .30147 m .15057 .29948 L .15334 .29847 L F
.55262 .43038 m .55106 .4319 L .55392 .41483 L 0 .442 .185 r
F
.55106 .4319 m .55234 .41302 L .55392 .41483 L 0 .448 .176 r
F
.5325 .32395 m .53387 .32012 L .53548 .32282 L 0 .081 .18 r
F
.5325 .32395 m .5309 .32124 L .53387 .32012 L F
.29924 .30365 m .30027 .30055 L .3021 .30262 L 0 .03 .13 r
F
.29924 .30365 m .29742 .30157 L .30027 .30055 L F
.65767 .30679 m .65923 .30367 L .6607 .30547 L 0 .036 .138 r
F
.65767 .30679 m .6562 .30498 L .65923 .30367 L F
.20242 .30139 m .20328 .29848 L .20521 .30042 L 0 .026 .125 r
F
.20242 .30139 m .20049 .29945 L .20328 .29848 L F
.50526 .32297 m .5066 .3194 L .50823 .32195 L 0 .079 .179 r
F
.50526 .32297 m .50364 .32042 L .5066 .3194 L F
.26445 .30308 m .26543 .29996 L .26729 .30196 L 0 .029 .129 r
F
.26445 .30308 m .26259 .30108 L .26543 .29996 L F
.44459 .31357 m .44584 .31041 L .44753 .3125 L 0 .053 .155 r
F
.44459 .31357 m .44291 .31151 L .44584 .31041 L F
.49937 .4225 m .49783 .40786 L .50074 .41407 L 0 .44 .188 r
F
.23721 .30209 m .23812 .29918 L .24002 .30107 L 0 .027 .127 r
F
.23721 .30209 m .2353 .30021 L .23812 .29918 L F
.60939 .31216 m .61087 .30886 L .6124 .31066 L 0 .049 .152 r
F
.60939 .31216 m .60787 .31035 L .61087 .30886 L F
.79065 .30211 m .79243 .29913 L .79377 .30106 L 0 .027 .126 r
F
.79065 .30211 m .78931 .30018 L .79243 .29913 L F
.11772 .3011 m .11846 .29808 L .12047 .30003 L 0 .025 .124 r
F
.11772 .3011 m .11571 .29914 L .11846 .29808 L F
.84056 .30195 m .8424 .29897 L .8437 .30093 L 0 .027 .126 r
F
.84056 .30195 m .83926 .3 L .8424 .29897 L F
.65013 .3074 m .65169 .30448 L .65317 .30629 L 0 .038 .14 r
F
.65013 .3074 m .64864 .30557 L .65169 .30448 L F
.68034 .30573 m .68194 .30267 L .68339 .30464 L 0 .034 .136 r
F
.68034 .30573 m .67888 .30374 L .68194 .30267 L F
.64258 .30783 m .64412 .30479 L .64561 .30665 L 0 .039 .141 r
F
.64258 .30783 m .64108 .30594 L .64412 .30479 L F
.46428 .31518 m .46556 .31184 L .46722 .31425 L 0 .057 .159 r
F
.46428 .31518 m .46262 .31277 L .46556 .31184 L F
.27199 .30282 m .27296 .29993 L .27482 .30187 L 0 .029 .129 r
F
.27199 .30282 m .27012 .30091 L .27296 .29993 L F
.16006 .30137 m .16087 .29833 L .16284 .30027 L 0 .026 .125 r
F
.16006 .30137 m .15808 .29945 L .16087 .29833 L F
.50014 .45713 m .49854 .45133 L .50137 .46851 L .056 .561 0 r
F
.49854 .45133 m .49697 .44131 L .4998 .45676 L 0 .535 .009 r
F
.49697 .44131 m .49824 .44438 L .4998 .45676 L 0 .498 .088 r
F
.57621 .31669 m .57764 .31295 L .5792 .31507 L 0 .06 .163 r
F
.57621 .31669 m .57465 .31461 L .57764 .31295 L F
.33402 .30459 m .33509 .30152 L .33689 .30356 L 0 .032 .133 r
F
.33402 .30459 m .33222 .30252 L .33509 .30152 L F
.30677 .30355 m .3078 .3006 L .30963 .30253 L 0 .03 .13 r
F
.30677 .30355 m .30495 .30161 L .3078 .3006 L F
.12525 .30083 m .126 .29786 L .12801 .29977 L 0 .025 .123 r
F
.12525 .30083 m .12324 .29894 L .126 .29786 L F
.38094 .30712 m .38209 .30415 L .38384 .30611 L 0 .038 .14 r
F
.38094 .30712 m .37919 .30517 L .38209 .30415 L F
.6879 .30546 m .68951 .30239 L .69095 .3043 L 0 .034 .135 r
F
.6879 .30546 m .68645 .30351 L .68951 .30239 L F
.71056 .30422 m .7122 .30115 L .71362 .30301 L 0 .032 .132 r
F
.71056 .30422 m .70914 .30236 L .7122 .30115 L F
.79823 .30191 m .8 .29883 L .80134 .30081 L 0 .027 .126 r
F
.79823 .30191 m .79688 .29995 L .8 .29883 L F
.16759 .30108 m .16842 .29806 L .17038 .30001 L 0 .025 .124 r
F
.16759 .30108 m .16563 .29916 L .16842 .29806 L F
.48854 .31912 m .48986 .31566 L .4915 .31828 L 0 .068 .17 r
F
.48854 .31912 m .4869 .31655 L .48986 .31566 L F
.24473 .30196 m .24566 .29902 L .24755 .30096 L 0 .027 .127 r
F
.24473 .30196 m .24284 .30004 L .24566 .29902 L F
.47641 .31726 m .47771 .31359 L .47936 .31613 L 0 .062 .164 r
F
.47641 .31726 m .47476 .31468 L .47771 .31359 L F
.69546 .30511 m .69709 .30223 L .69852 .30409 L 0 .034 .135 r
F
.69546 .30511 m .69402 .30323 L .69709 .30223 L F
.84813 .30177 m .84998 .29864 L .85127 .30063 L 0 .027 .126 r
F
.84813 .30177 m .84684 .29979 L .84998 .29864 L F
.45214 .31351 m .4534 .31035 L .45507 .31248 L 0 .053 .156 r
F
.45214 .31351 m .45046 .31142 L .4534 .31035 L F
.20993 .30137 m .21082 .29835 L .21274 .30029 L 0 .026 .125 r
F
.20993 .30137 m .20801 .29943 L .21082 .29835 L F
.63503 .3085 m .63656 .30529 L .63806 .30722 L 0 .041 .143 r
F
.63503 .3085 m .63353 .30654 L .63656 .30529 L F
.31431 .30332 m .31536 .30026 L .31718 .3022 L 0 .03 .13 r
F
.31431 .30332 m .31249 .3014 L .31536 .30026 L F
.42787 .30983 m .42908 .30694 L .43078 .30906 L 0 .045 .147 r
F
.42787 .30983 m .42616 .30778 L .42908 .30694 L F
.71813 .304 m .71978 .30095 L .7212 .30296 L 0 .031 .132 r
F
.71813 .304 m .7167 .30198 L .71978 .30095 L F
.34155 .30444 m .34263 .30156 L .34442 .3035 L 0 .033 .133 r
F
.34155 .30444 m .33976 .30254 L .34263 .30156 L F
.36124 .30593 m .36237 .30273 L .36413 .30487 L 0 .035 .137 r
F
.36124 .30593 m .35948 .30381 L .36237 .30273 L F
.8058 .30174 m .80759 .29873 L .80893 .30071 L 0 .027 .126 r
F
.8058 .30174 m .80447 .29976 L .80759 .29873 L F
.38848 .30698 m .38964 .30394 L .39139 .30589 L 0 .038 .14 r
F
.38848 .30698 m .38674 .30503 L .38964 .30394 L F
.70302 .30489 m .70465 .30182 L .70608 .30364 L 0 .033 .134 r
F
.70302 .30489 m .70159 .30306 L .70465 .30182 L F
.17512 .30092 m .17595 .29788 L .1779 .29987 L 0 .025 .124 r
F
.17512 .30092 m .17316 .29894 L .17595 .29788 L F
.55814 .32062 m .55954 .31676 L .56112 .31893 L 0 .072 .173 r
F
.55814 .32062 m .55656 .31844 L .55954 .31676 L F
.60185 .31308 m .60333 .31002 L .60486 .31184 L 0 .053 .155 r
F
.60185 .31308 m .60032 .31123 L .60333 .31002 L F
.85571 .30156 m .85758 .29858 L .85887 .30055 L 0 .027 .126 r
F
.85571 .30156 m .85442 .29958 L .85758 .29858 L F
.13277 .30072 m .13352 .29781 L .13552 .29976 L 0 .025 .124 r
F
.13277 .30072 m .13076 .29879 L .13352 .29781 L F
.51281 .32316 m .51416 .319 L .51578 .32167 L 0 .079 .179 r
F
.51281 .32316 m .51119 .32048 L .51416 .319 L F
.54006 .32421 m .54144 .32035 L .54304 .32295 L 0 .083 .182 r
F
.54006 .32421 m .53846 .32163 L .54144 .32035 L F
.50068 .32129 m .50201 .31801 L .50364 .32042 L 0 .075 .176 r
F
.50068 .32129 m .49905 .31891 L .50201 .31801 L F
.54761 .32382 m .549 .31995 L .55059 .3221 L 0 .082 .181 r
F
.54761 .32382 m .54602 .32168 L .549 .31995 L F
.2795 .30288 m .2805 .29982 L .28235 .3018 L 0 .029 .129 r
F
.2795 .30288 m .27765 .30092 L .2805 .29982 L F
.52792 .32237 m .52929 .31855 L .5309 .32124 L 0 .077 .178 r
F
.52792 .32237 m .52631 .31967 L .52929 .31855 L F
.21746 .30121 m .21836 .2982 L .22027 .3002 L 0 .026 .125 r
F
.21746 .30121 m .21555 .29921 L .21836 .2982 L F
.52037 .32279 m .52173 .31862 L .52334 .32123 L 0 .078 .178 r
F
.52037 .32279 m .51875 .32016 L .52173 .31862 L F
.62749 .30919 m .629 .30602 L .63051 .30786 L 0 .043 .145 r
F
.62749 .30919 m .62598 .30738 L .629 .30602 L F
.09795 .3002 m .09866 .29726 L .1007 .29917 L 0 .024 .123 r
F
.09795 .3002 m .09591 .29831 L .09866 .29726 L F
.40817 .30859 m .40936 .30554 L .41107 .30775 L 0 .042 .144 r
F
.40817 .30859 m .40645 .30637 L .40936 .30554 L F
.7408 .30295 m .74249 .29993 L .74388 .3018 L 0 .029 .129 r
F
.7408 .30295 m .73941 .30106 L .74249 .29993 L F
.5943 .31364 m .59577 .31054 L .59731 .31243 L 0 .054 .157 r
F
.5943 .31364 m .59276 .31172 L .59577 .31054 L F
.32185 .30316 m .3229 .30027 L .32471 .30228 L 0 .03 .13 r
F
.32185 .30316 m .32004 .30117 L .3229 .30027 L F
.73325 .30338 m .73492 .30029 L .73633 .30222 L F
.73325 .30338 m .73184 .30142 L .73492 .30029 L F
.74836 .30254 m .75006 .29957 L .75144 .30141 L 0 .029 .129 r
F
.74836 .30254 m .74697 .30069 L .75006 .29957 L F
.7257 .30383 m .72735 .30064 L .72877 .30262 L 0 .031 .131 r
F
.7257 .30383 m .72428 .30183 L .72735 .30064 L F
.56866 .31767 m .57009 .31403 L .57165 .31614 L 0 .064 .166 r
F
.56866 .31767 m .56709 .3156 L .57009 .31403 L F
.58675 .31411 m .5882 .31072 L .58975 .31291 L 0 .055 .157 r
F
.58675 .31411 m .58519 .31193 L .5882 .31072 L F
.75592 .30222 m .75762 .29902 L .759 .30102 L 0 .028 .127 r
F
.75592 .30222 m .75453 .30022 L .75762 .29902 L F
.25224 .30204 m .25319 .2991 L .25506 .30112 L 0 .028 .128 r
F
.25224 .30204 m .25037 .30002 L .25319 .2991 L F
.76348 .30186 m .76521 .29887 L .76658 .30087 L 0 .028 .127 r
F
.76348 .30186 m .7621 .29986 L .76521 .29887 L F
.81339 .30165 m .81519 .29867 L .81652 .30063 L 0 .027 .126 r
F
.81339 .30165 m .81206 .29968 L .81519 .29867 L F
.28704 .30271 m .28805 .29958 L .28989 .30162 L 0 .029 .129 r
F
.28704 .30271 m .2852 .30069 L .28805 .29958 L F
.43999 .31218 m .44122 .30917 L .44291 .31151 L 0 .051 .154 r
F
.43999 .31218 m .4383 .30988 L .44122 .30917 L F
.18263 .30087 m .18348 .29783 L .18542 .29985 L 0 .026 .124 r
F
.18263 .30087 m .18069 .29885 L .18348 .29783 L F
.39602 .30696 m .3972 .30368 L .39893 .30588 L 0 .038 .14 r
F
.39602 .30696 m .39429 .30479 L .3972 .30368 L F
.61994 .30989 m .62145 .30692 L .62296 .30871 L 0 .045 .148 r
F
.61994 .30989 m .61843 .30811 L .62145 .30692 L F
.34908 .30446 m .35017 .30163 L .35195 .30357 L 0 .033 .134 r
F
.34908 .30446 m .3473 .30255 L .35017 .30163 L F
.36877 .30593 m .36991 .30274 L .37166 .3049 L 0 .036 .137 r
F
.36877 .30593 m .36702 .30378 L .36991 .30274 L F
.14027 .3007 m .14106 .29762 L .14304 .2996 L 0 .025 .124 r
F
.14027 .3007 m .13828 .29873 L .14106 .29762 L F
.45968 .31371 m .46095 .31049 L .46262 .31277 L 0 .055 .157 r
F
.45968 .31371 m .45801 .31148 L .46095 .31049 L F
.10546 .30011 m .10618 .29714 L .1082 .29912 L 0 .024 .123 r
F
.10546 .30011 m .10344 .29815 L .10618 .29714 L F
.51699 .39837 m .51838 .37705 L .51998 .39203 L 0 .356 .281 r
F
.51699 .39837 m .51541 .38199 L .51838 .37705 L F
.47182 .31568 m .47311 .31233 L .47476 .31468 L 0 .06 .162 r
F
.47182 .31568 m .47016 .3133 L .47311 .31233 L F
.48395 .31758 m .48526 .31396 L .4869 .31655 L 0 .065 .166 r
F
.48395 .31758 m .48231 .31499 L .48526 .31396 L F
.55284 .4393 m .55132 .4458 L .55418 .42886 L 0 .471 .139 r
F
.55132 .4458 m .55262 .43038 L .55418 .42886 L 0 .493 .098 r
F
.22497 .30125 m .22587 .29829 L .22778 .30029 L 0 .027 .126 r
F
.22497 .30125 m .22307 .29925 L .22587 .29829 L F
.1478 .30049 m .14859 .29748 L .15057 .29948 L 0 .025 .124 r
F
.1478 .30049 m .14582 .29849 L .14859 .29748 L F
.82097 .30155 m .82279 .29853 L .8241 .30046 L 0 .027 .127 r
F
.82097 .30155 m .81965 .2996 L .82279 .29853 L F
.29457 .30263 m .29559 .29948 L .29742 .30157 L 0 .029 .129 r
F
.29457 .30263 m .29274 .30055 L .29559 .29948 L F
.4157 .30871 m .4169 .30584 L .41862 .30772 L 0 .043 .145 r
F
.4157 .30871 m .41398 .30681 L .4169 .30584 L F
.19015 .30077 m .19102 .29766 L .19296 .29964 L 0 .026 .125 r
F
.19015 .30077 m .18821 .29878 L .19102 .29766 L F
.82854 .30122 m .83036 .29817 L .83166 .30008 L 0 .027 .126 r
F
.82854 .30122 m .82723 .29932 L .83036 .29817 L F
.66826 .30499 m .66985 .30217 L .67131 .30395 L 0 .035 .136 r
F
.66826 .30499 m .66679 .30321 L .66985 .30217 L F
.6124 .31066 m .61389 .30751 L .61541 .3093 L 0 .047 .15 r
F
.6124 .31066 m .61087 .30886 L .61389 .30751 L F
.77106 .30185 m .7728 .29879 L .77417 .30076 L 0 .028 .127 r
F
.77106 .30185 m .76969 .29987 L .7728 .29879 L F
.5792 .31507 m .58063 .31127 L .58219 .31343 L 0 .058 .16 r
F
.5792 .31507 m .57764 .31295 L .58063 .31127 L F
.6607 .30547 m .66228 .30246 L .66374 .30425 L 0 .036 .137 r
F
.6607 .30547 m .65923 .30367 L .66228 .30246 L F
.1977 .30045 m .19856 .29751 L .20049 .29945 L 0 .025 .124 r
F
.1977 .30045 m .19576 .29851 L .19856 .29751 L F
.77863 .30152 m .78037 .29842 L .78173 .30033 L 0 .027 .127 r
F
.77863 .30152 m .77727 .29959 L .78037 .29842 L F
.49609 .31979 m .49741 .31653 L .49905 .31891 L 0 .072 .173 r
F
.49609 .31979 m .49445 .31744 L .49741 .31653 L F
.25975 .3022 m .26072 .29907 L .26259 .30108 L 0 .029 .128 r
F
.25975 .3022 m .25788 .30018 L .26072 .29907 L F
.11296 .30012 m .11369 .29718 L .11571 .29914 L 0 .025 .124 r
F
.11296 .30012 m .11095 .29815 L .11369 .29718 L F
.32936 .3035 m .33043 .30045 L .33222 .30252 L 0 .032 .132 r
F
.32936 .3035 m .32756 .3014 L .33043 .30045 L F
.83611 .30099 m .83796 .29805 L .83926 .3 L 0 .027 .126 r
F
.83611 .30099 m .83481 .29905 L .83796 .29805 L F
.78619 .30121 m .78796 .2983 L .78931 .30018 L F
.78619 .30121 m .78484 .29931 L .78796 .2983 L F
.23249 .30123 m .2334 .29828 L .2353 .30021 L F
.23249 .30123 m .23059 .29929 L .2334 .29828 L F
.67582 .3048 m .67742 .30183 L .67888 .30374 L 0 .034 .136 r
F
.67582 .3048 m .67436 .30289 L .67742 .30183 L F
.53548 .32282 m .53686 .31893 L .53846 .32163 L 0 .08 .18 r
F
.53548 .32282 m .53387 .32012 L .53686 .31893 L F
.3763 .30606 m .37744 .30304 L .37919 .30517 L 0 .037 .139 r
F
.3763 .30606 m .37455 .30398 L .37744 .30304 L F
.42325 .30861 m .42445 .30586 L .42616 .30778 L 0 .044 .146 r
F
.42325 .30861 m .42153 .30675 L .42445 .30586 L F
.3566 .30466 m .3577 .30184 L .35948 .30381 L 0 .035 .136 r
F
.3566 .30466 m .35483 .3027 L .3577 .30184 L F
.15531 .30048 m .15611 .29744 L .15808 .29945 L 0 .026 .125 r
F
.15531 .30048 m .15334 .29847 L .15611 .29744 L F
.56112 .31893 m .56253 .31507 L .56411 .31723 L 0 .069 .17 r
F
.56112 .31893 m .55954 .31676 L .56253 .31507 L F
.40355 .3072 m .40473 .3041 L .40645 .30637 L 0 .04 .142 r
F
.40355 .3072 m .40183 .30492 L .40473 .3041 L F
.26729 .30196 m .26826 .29891 L .27012 .30091 L 0 .029 .128 r
F
.26729 .30196 m .26543 .29996 L .26826 .29891 L F
.55059 .3221 m .55199 .31809 L .55357 .32026 L 0 .078 .178 r
F
.55059 .3221 m .549 .31995 L .55199 .31809 L F
.43539 .31058 m .43662 .30757 L .4383 .30988 L 0 .048 .151 r
F
.43539 .31058 m .4337 .3083 L .43662 .30757 L F
.3021 .30262 m .30312 .29956 L .30495 .30161 L 0 .03 .13 r
F
.3021 .30262 m .30027 .30055 L .30312 .29956 L F
.44753 .3125 m .44878 .30929 L .45046 .31142 L 0 .053 .155 r
F
.44753 .3125 m .44584 .31041 L .44878 .30929 L F
.5501 .45271 m .5486 .4635 L .55148 .44782 L 0 .513 .056 r
F
.5472 .46622 m .5486 .4635 L .5501 .45271 L .07 .567 0 r
F
.50823 .32195 m .50957 .31794 L .51119 .32048 L 0 .078 .178 r
F
.50823 .32195 m .5066 .3194 L .50957 .31794 L F
.64561 .30665 m .64716 .30373 L .64864 .30557 L 0 .039 .141 r
F
.64561 .30665 m .64412 .30479 L .64716 .30373 L F
.65317 .30629 m .65472 .30318 L .6562 .30498 L 0 .038 .139 r
F
.65317 .30629 m .65169 .30448 L .65472 .30318 L F
.20521 .30042 m .20608 .29749 L .20801 .29943 L 0 .026 .125 r
F
.20521 .30042 m .20328 .29848 L .20608 .29749 L F
.79377 .30106 m .79554 .29801 L .79688 .29995 L 0 .027 .126 r
F
.79377 .30106 m .79243 .29913 L .79554 .29801 L F
.24002 .30107 m .24095 .29812 L .24284 .30004 L 0 .027 .127 r
F
.24002 .30107 m .23812 .29918 L .24095 .29812 L F
.53838 .40549 m .53969 .38428 L .54132 .39333 L 0 .376 .265 r
F
.53838 .40549 m .53675 .39474 L .53969 .38428 L F
.68339 .30464 m .685 .30157 L .68645 .30351 L 0 .034 .135 r
F
.68339 .30464 m .68194 .30267 L .685 .30157 L F
.12047 .30003 m .12123 .29699 L .12324 .29894 L 0 .025 .124 r
F
.12047 .30003 m .11846 .29808 L .12123 .29699 L F
.16284 .30027 m .16366 .29722 L .16563 .29916 L F
.16284 .30027 m .16087 .29833 L .16366 .29722 L F
.52334 .32123 m .5247 .3171 L .52631 .31967 L 0 .075 .176 r
F
.52334 .32123 m .52173 .31862 L .5247 .3171 L F
.71362 .30301 m .71528 .30012 L .7167 .30198 L 0 .031 .132 r
F
.71362 .30301 m .7122 .30115 L .71528 .30012 L F
.51578 .32167 m .51714 .31751 L .51875 .32016 L 0 .077 .177 r
F
.51578 .32167 m .51416 .319 L .51714 .31751 L F
.63806 .30722 m .63959 .30403 L .64108 .30594 L 0 .04 .142 r
F
.63806 .30722 m .63656 .30529 L .63959 .30403 L F
.8437 .30093 m .84554 .29781 L .84684 .29979 L 0 .027 .126 r
F
.8437 .30093 m .8424 .29897 L .84554 .29781 L F
.69095 .3043 m .69257 .30134 L .69402 .30323 L 0 .034 .135 r
F
.69095 .3043 m .68951 .30239 L .69257 .30134 L F
.80134 .30081 m .80313 .29777 L .80447 .29976 L 0 .027 .126 r
F
.80134 .30081 m .8 .29883 L .80313 .29777 L F
.12801 .29977 m .12876 .29686 L .13076 .29879 L 0 .025 .124 r
F
.12801 .29977 m .126 .29786 L .12876 .29686 L F
.27482 .30187 m .2758 .29895 L .27765 .30092 L 0 .029 .129 r
F
.27482 .30187 m .27296 .29993 L .2758 .29895 L F
.47936 .31613 m .48066 .3125 L .48231 .31499 L 0 .062 .164 r
F
.47936 .31613 m .47771 .31359 L .48066 .3125 L F
.46722 .31425 m .4685 .31091 L .47016 .3133 L 0 .057 .16 r
F
.46722 .31425 m .46556 .31184 L .4685 .31091 L F
.33689 .30356 m .33797 .30051 L .33976 .30254 L 0 .032 .133 r
F
.33689 .30356 m .33509 .30152 L .33797 .30051 L F
.57165 .31614 m .57308 .31245 L .57465 .31461 L 0 .062 .164 r
F
.57165 .31614 m .57009 .31403 L .57308 .31245 L F
.85127 .30063 m .85313 .29759 L .85442 .29958 L 0 .026 .125 r
F
.85127 .30063 m .84998 .29864 L .85313 .29759 L F
.17038 .30001 m .17121 .29697 L .17316 .29894 L 0 .025 .124 r
F
.17038 .30001 m .16842 .29806 L .17121 .29697 L F
.30963 .30253 m .31067 .29946 L .31249 .3014 L 0 .03 .13 r
F
.30963 .30253 m .3078 .3006 L .31067 .29946 L F
.38384 .30611 m .38499 .30307 L .38674 .30503 L 0 .038 .14 r
F
.38384 .30611 m .38209 .30415 L .38499 .30307 L F
.70608 .30364 m .70772 .30056 L .70914 .30236 L 0 .032 .133 r
F
.70608 .30364 m .70465 .30182 L .70772 .30056 L F
.21274 .30029 m .21363 .29727 L .21555 .29921 L 0 .026 .125 r
F
.21274 .30029 m .21082 .29835 L .21363 .29727 L F
.50803 .40664 m .50649 .38895 L .50945 .38798 L 0 .384 .257 r
F
.50508 .40494 m .50649 .38895 L .50803 .40664 L 0 .38 .261 r
F
.54304 .32295 m .54442 .31907 L .54602 .32168 L 0 .082 .181 r
F
.54304 .32295 m .54144 .32035 L .54442 .31907 L F
.60486 .31184 m .60634 .30854 L .60787 .31035 L 0 .051 .154 r
F
.60486 .31184 m .60333 .31002 L .60634 .30854 L F
.63051 .30786 m .63202 .30467 L .63353 .30654 L 0 .042 .144 r
F
.63051 .30786 m .629 .30602 L .63202 .30467 L F
.69852 .30409 m .70016 .30123 L .70159 .30306 L 0 .034 .135 r
F
.69852 .30409 m .69709 .30223 L .70016 .30123 L F
.31718 .3022 m .31823 .29921 L .32004 .30117 L 0 .03 .13 r
F
.31718 .3022 m .31536 .30026 L .31823 .29921 L F
.45507 .31248 m .45634 .3093 L .45801 .31148 L 0 .053 .156 r
F
.45507 .31248 m .4534 .31035 L .45634 .3093 L F
.24755 .30096 m .24848 .29805 L .25037 .30002 L 0 .027 .127 r
F
.24755 .30096 m .24566 .29902 L .24848 .29805 L F
.54623 .41983 m .5475 .39698 L .54912 .4041 L 0 .412 .226 r
F
.54623 .41983 m .54459 .41129 L .5475 .39698 L F
.39139 .30589 m .39255 .30281 L .39429 .30479 L 0 .038 .139 r
F
.39139 .30589 m .38964 .30394 L .39255 .30281 L F
.7212 .30296 m .72286 .29983 L .72428 .30183 L 0 .031 .132 r
F
.7212 .30296 m .71978 .30095 L .72286 .29983 L F
.36413 .30487 m .36526 .30163 L .36702 .30378 L 0 .035 .136 r
F
.36413 .30487 m .36237 .30273 L .36526 .30163 L F
.4915 .31828 m .49282 .31477 L .49445 .31744 L 0 .069 .17 r
F
.4915 .31828 m .48986 .31566 L .49282 .31477 L F
.59731 .31243 m .59878 .30938 L .60032 .31123 L 0 .054 .156 r
F
.59731 .31243 m .59577 .31054 L .59878 .30938 L F
.5309 .32124 m .53227 .31743 L .53387 .32012 L 0 .077 .177 r
F
.5309 .32124 m .52929 .31855 L .53227 .31743 L F
.1779 .29987 m .17874 .29686 L .18069 .29885 L 0 .025 .124 r
F
.1779 .29987 m .17595 .29788 L .17874 .29686 L F
.80893 .30071 m .81073 .29769 L .81206 .29968 L 0 .027 .126 r
F
.80893 .30071 m .80759 .29873 L .81073 .29769 L F
.72877 .30262 m .73043 .29946 L .73184 .30142 L 0 .031 .131 r
F
.72877 .30262 m .72735 .30064 L .73043 .29946 L F
.28235 .3018 m .28335 .2987 L .2852 .30069 L 0 .029 .129 r
F
.28235 .3018 m .2805 .29982 L .28335 .2987 L F
.74388 .3018 m .74558 .29883 L .74697 .30069 L F
.74388 .3018 m .74249 .29993 L .74558 .29883 L F
.73633 .30222 m .73801 .29916 L .73941 .30106 L 0 .03 .13 r
F
.73633 .30222 m .73492 .30029 L .73801 .29916 L F
.58975 .31291 m .5912 .30952 L .59276 .31172 L 0 .054 .157 r
F
.58975 .31291 m .5882 .31072 L .5912 .30952 L F
.85887 .30055 m .86074 .29758 L .86203 .29955 L 0 .027 .126 r
F
.85887 .30055 m .85758 .29858 L .86074 .29758 L F
.34442 .3035 m .34551 .30058 L .3473 .30255 L 0 .033 .134 r
F
.34442 .3035 m .34263 .30156 L .34551 .30058 L F
.75144 .30141 m .75315 .29839 L .75453 .30022 L 0 .028 .128 r
F
.75144 .30141 m .75006 .29957 L .75315 .29839 L F
.759 .30102 m .76071 .29785 L .7621 .29986 L 0 .027 .127 r
F
.759 .30102 m .75762 .29902 L .76071 .29785 L F
.13552 .29976 m .13629 .29676 L .13828 .29873 L 0 .025 .124 r
F
.13552 .29976 m .13352 .29781 L .13629 .29676 L F
.22027 .3002 m .22116 .29725 L .22307 .29925 L 0 .026 .125 r
F
.22027 .3002 m .21836 .2982 L .22116 .29725 L F
.1007 .29917 m .10141 .29621 L .10344 .29815 L 0 .024 .123 r
F
.1007 .29917 m .09866 .29726 L .10141 .29621 L F
.58219 .31343 m .58363 .30975 L .58519 .31193 L 0 .055 .158 r
F
.58219 .31343 m .58063 .31127 L .58363 .30975 L F
.43078 .30906 m .432 .30615 L .4337 .3083 L 0 .046 .148 r
F
.43078 .30906 m .42908 .30694 L .432 .30615 L F
.50364 .32042 m .50497 .31697 L .5066 .3194 L 0 .076 .176 r
F
.50364 .32042 m .50201 .31801 L .50497 .31697 L F
.62296 .30871 m .62447 .30556 L .62598 .30738 L 0 .044 .147 r
F
.62296 .30871 m .62145 .30692 L .62447 .30556 L F
.55357 .32026 m .55497 .31626 L .55656 .31844 L 0 .074 .175 r
F
.55357 .32026 m .55199 .31809 L .55497 .31626 L F
.28989 .30162 m .2909 .2985 L .29274 .30055 L 0 .029 .129 r
F
.28989 .30162 m .28805 .29958 L .2909 .2985 L F
.52792 .48047 m .52932 .50179 L .53091 .48438 L .264 .634 0 r
F
.52792 .48047 m .52632 .49705 L .52932 .50179 L F
.32471 .30228 m .32576 .29937 L .32756 .3014 L 0 .031 .131 r
F
.32471 .30228 m .3229 .30027 L .32576 .29937 L F
.41107 .30775 m .41227 .30462 L .41398 .30681 L 0 .042 .145 r
F
.41107 .30775 m .40936 .30554 L .41227 .30462 L F
.81652 .30063 m .81833 .29765 L .81965 .2996 L 0 .027 .127 r
F
.81652 .30063 m .81519 .29867 L .81833 .29765 L F
.39893 .30588 m .40011 .3027 L .40183 .30492 L 0 .038 .14 r
F
.39893 .30588 m .3972 .30368 L .40011 .3027 L F
.14304 .2996 m .14384 .29651 L .14582 .29849 L 0 .025 .124 r
F
.14304 .2996 m .14106 .29762 L .14384 .29651 L F
.76658 .30087 m .76832 .29788 L .76969 .29987 L 0 .028 .127 r
F
.76658 .30087 m .76521 .29887 L .76832 .29788 L F
.56411 .31723 m .56552 .31342 L .56709 .3156 L 0 .066 .168 r
F
.56411 .31723 m .56253 .31507 L .56552 .31342 L F
.18542 .29985 m .18627 .29678 L .18821 .29878 L 0 .026 .124 r
F
.18542 .29985 m .18348 .29783 L .18627 .29678 L F
.25506 .30112 m .25601 .29816 L .25788 .30018 L 0 .028 .128 r
F
.25506 .30112 m .25319 .2991 L .25601 .29816 L F
.61541 .3093 m .61691 .3063 L .61843 .30811 L 0 .046 .149 r
F
.61541 .3093 m .61389 .30751 L .61691 .3063 L F
.37166 .3049 m .3728 .30178 L .37455 .30398 L 0 .036 .137 r
F
.37166 .3049 m .36991 .30274 L .3728 .30178 L F
.1082 .29912 m .10893 .29618 L .11095 .29815 L 0 .025 .123 r
F
.1082 .29912 m .10618 .29714 L .10893 .29618 L F
.46262 .31277 m .46389 .30956 L .46556 .31184 L 0 .055 .158 r
F
.46262 .31277 m .46095 .31049 L .46389 .30956 L F
.4869 .31655 m .48822 .31302 L .48986 .31566 L 0 .065 .167 r
F
.4869 .31655 m .48526 .31396 L .48822 .31302 L F
.35195 .30357 m .35305 .30075 L .35483 .3027 L 0 .034 .135 r
F
.35195 .30357 m .35017 .30163 L .35305 .30075 L F
.47476 .31468 m .47606 .31128 L .47771 .31359 L 0 .06 .162 r
F
.47476 .31468 m .47311 .31233 L .47606 .31128 L F
.8241 .30046 m .82592 .2974 L .82723 .29932 L 0 .027 .126 r
F
.8241 .30046 m .82279 .29853 L .82592 .2974 L F
.19296 .29964 m .19382 .29653 L .19576 .29851 L 0 .025 .124 r
F
.19296 .29964 m .19102 .29766 L .19382 .29653 L F
.66374 .30425 m .66533 .30142 L .66679 .30321 L 0 .035 .137 r
F
.66374 .30425 m .66228 .30246 L .66533 .30142 L F
.22778 .30029 m .22869 .29731 L .23059 .29929 L 0 .027 .126 r
F
.22778 .30029 m .22587 .29829 L .22869 .29731 L F
.83166 .30008 m .8335 .29714 L .83481 .29905 L F
.83166 .30008 m .83036 .29817 L .8335 .29714 L F
.29742 .30157 m .29845 .29848 L .30027 .30055 L 0 .029 .129 r
F
.29742 .30157 m .29559 .29948 L .29845 .29848 L F
.15057 .29948 m .15136 .29647 L .15334 .29847 L 0 .025 .124 r
F
.15057 .29948 m .14859 .29748 L .15136 .29647 L F
.78173 .30033 m .78349 .29741 L .78484 .29931 L 0 .027 .126 r
F
.78173 .30033 m .78037 .29842 L .78349 .29741 L F
.77417 .30076 m .7759 .29764 L .77727 .29959 L 0 .028 .127 r
F
.77417 .30076 m .7728 .29879 L .7759 .29764 L F
.51119 .32048 m .51254 .31648 L .51416 .319 L 0 .075 .176 r
F
.51119 .32048 m .50957 .31794 L .51254 .31648 L F
.41862 .30772 m .41982 .30488 L .42153 .30675 L 0 .043 .146 r
F
.41862 .30772 m .4169 .30584 L .41982 .30488 L F
.52631 .31967 m .52768 .31599 L .52929 .31855 L 0 .074 .175 r
F
.52631 .31967 m .5247 .3171 L .52768 .31599 L F
.67131 .30395 m .6729 .30109 L .67436 .30289 L 0 .035 .136 r
F
.67131 .30395 m .66985 .30217 L .6729 .30109 L F
.44291 .31151 m .44416 .30805 L .44584 .31041 L 0 .052 .154 r
F
.44291 .31151 m .44122 .30917 L .44416 .30805 L F
.55106 .4319 m .54947 .4301 L .55234 .41302 L 0 .448 .176 r
F
.54947 .4301 m .55073 .40856 L .55234 .41302 L 0 .442 .185 r
F
.51875 .32016 m .52011 .31601 L .52173 .31862 L 0 .074 .175 r
F
.51875 .32016 m .51714 .31751 L .52011 .31601 L F
.26259 .30108 m .26356 .29795 L .26543 .29996 L 0 .028 .128 r
F
.26259 .30108 m .26072 .29907 L .26356 .29795 L F
.52458 .39903 m .52594 .37867 L .52756 .39083 L 0 .362 .277 r
F
.52458 .39903 m .52296 .38534 L .52594 .37867 L F
.53846 .32163 m .53984 .31763 L .54144 .32035 L 0 .079 .179 r
F
.53846 .32163 m .53686 .31893 L .53984 .31763 L F
.20049 .29945 m .20135 .29654 L .20328 .29848 L 0 .026 .124 r
F
.20049 .29945 m .19856 .29751 L .20135 .29654 L F
.57465 .31461 m .57607 .31076 L .57764 .31295 L 0 .059 .162 r
F
.57465 .31461 m .57308 .31245 L .57607 .31076 L F
.6562 .30498 m .65776 .30188 L .65923 .30367 L 0 .037 .138 r
F
.6562 .30498 m .65472 .30318 L .65776 .30188 L F
.67888 .30374 m .68048 .30076 L .68194 .30267 L 0 .034 .135 r
F
.67888 .30374 m .67742 .30183 L .68048 .30076 L F
.78931 .30018 m .79108 .29726 L .79243 .29913 L 0 .027 .126 r
F
.78931 .30018 m .78796 .2983 L .79108 .29726 L F
.11571 .29914 m .11645 .29611 L .11846 .29808 L 0 .025 .124 r
F
.11571 .29914 m .11369 .29718 L .11645 .29611 L F
.83926 .3 m .8411 .297 L .8424 .29897 L 0 .027 .126 r
F
.83926 .3 m .83796 .29805 L .8411 .297 L F
.2353 .30021 m .23622 .29726 L .23812 .29918 L 0 .027 .127 r
F
.2353 .30021 m .2334 .29828 L .23622 .29726 L F
.33222 .30252 m .3333 .29947 L .33509 .30152 L 0 .032 .132 r
F
.33222 .30252 m .33043 .30045 L .3333 .29947 L F
.514 .40202 m .51541 .38199 L .51699 .39837 L 0 .37 .27 r
F
.514 .40202 m .51243 .38499 L .51541 .38199 L F
.49905 .31891 m .50037 .3156 L .50201 .31801 L 0 .073 .174 r
F
.49905 .31891 m .49741 .31653 L .50037 .3156 L F
.54577 .46486 m .54428 .47969 L .5472 .46622 L .05 .559 0 r
F
.54284 .47582 m .54428 .47969 L .54577 .46486 L .169 .603 0 r
F
.64108 .30594 m .64262 .3029 L .64412 .30479 L 0 .039 .141 r
F
.64108 .30594 m .63959 .30403 L .64262 .3029 L F
.27012 .30091 m .2711 .29792 L .27296 .29993 L 0 .029 .128 r
F
.27012 .30091 m .26826 .29891 L .2711 .29792 L F
.60787 .31035 m .60935 .30706 L .61087 .30886 L 0 .049 .152 r
F
.60787 .31035 m .60634 .30854 L .60935 .30706 L F
.15808 .29945 m .1589 .29635 L .16087 .29833 L 0 .026 .124 r
F
.15808 .29945 m .15611 .29744 L .1589 .29635 L F
.50338 .4647 m .50459 .48171 L .50624 .48347 L .125 .588 0 r
F
.50338 .4647 m .50175 .46294 L .50459 .48171 L F
.45046 .31142 m .45172 .30819 L .4534 .31035 L 0 .052 .155 r
F
.45046 .31142 m .44878 .30929 L .45172 .30819 L F
.64864 .30557 m .6502 .30267 L .65169 .30448 L 0 .039 .141 r
F
.64864 .30557 m .64716 .30373 L .6502 .30267 L F
.37919 .30517 m .38034 .30203 L .38209 .30415 L 0 .037 .139 r
F
.37919 .30517 m .37744 .30304 L .38034 .30203 L F
.30495 .30161 m .30598 .29857 L .3078 .3006 L 0 .03 .13 r
F
.30495 .30161 m .30312 .29956 L .30598 .29857 L F
.79688 .29995 m .79866 .29688 L .8 .29883 L 0 .027 .126 r
F
.79688 .29995 m .79554 .29801 L .79866 .29688 L F
.68645 .30351 m .68806 .30047 L .68951 .30239 L 0 .034 .135 r
F
.68645 .30351 m .685 .30157 L .68806 .30047 L F
.55656 .31844 m .55796 .31459 L .55954 .31676 L 0 .071 .172 r
F
.55656 .31844 m .55497 .31626 L .55796 .31459 L F
.12324 .29894 m .12399 .29591 L .126 .29786 L 0 .025 .123 r
F
.12324 .29894 m .12123 .29699 L .12399 .29591 L F
.16563 .29916 m .16645 .29611 L .16842 .29806 L 0 .025 .124 r
F
.16563 .29916 m .16366 .29722 L .16645 .29611 L F
.84684 .29979 m .84868 .29666 L .84998 .29864 L 0 .026 .125 r
F
.84684 .29979 m .84554 .29781 L .84868 .29666 L F
.42616 .30778 m .42737 .30498 L .42908 .30694 L 0 .044 .147 r
F
.42616 .30778 m .42445 .30586 L .42737 .30498 L F
.35948 .30381 m .36059 .30073 L .36237 .30273 L 0 .035 .136 r
F
.35948 .30381 m .3577 .30184 L .36059 .30073 L F
.63353 .30654 m .63505 .30337 L .63656 .30529 L 0 .041 .143 r
F
.63353 .30654 m .63202 .30467 L .63505 .30337 L F
.24284 .30004 m .24377 .29706 L .24566 .29902 L 0 .027 .126 r
F
.24284 .30004 m .24095 .29812 L .24377 .29706 L F
.49824 .44438 m .49669 .43195 L .49955 .44381 L 0 .513 .056 r
F
.49669 .43195 m .49801 .42919 L .49955 .44381 L 0 .467 .145 r
F
.51101 .40567 m .51243 .38499 L .514 .40202 L 0 .38 .261 r
F
.51101 .40567 m .50945 .38798 L .51243 .38499 L F
.70914 .30236 m .71078 .29936 L .7122 .30115 L 0 .032 .132 r
F
.70914 .30236 m .70772 .30056 L .71078 .29936 L F
.20801 .29943 m .20889 .29641 L .21082 .29835 L 0 .026 .125 r
F
.20801 .29943 m .20608 .29749 L .20889 .29641 L F
.54602 .32168 m .54741 .31739 L .549 .31995 L 0 .079 .179 r
F
.54602 .32168 m .54442 .31907 L .54741 .31739 L F
.40645 .30637 m .40764 .30328 L .40936 .30554 L 0 .04 .143 r
F
.40645 .30637 m .40473 .3041 L .40764 .30328 L F
.69402 .30323 m .69565 .30037 L .69709 .30223 L 0 .034 .135 r
F
.69402 .30323 m .69257 .30134 L .69565 .30037 L F
.7167 .30198 m .71837 .29909 L .71978 .30095 L 0 .031 .132 r
F
.7167 .30198 m .71528 .30012 L .71837 .29909 L F
.48231 .31499 m .48362 .31146 L .48526 .31396 L 0 .062 .164 r
F
.48231 .31499 m .48066 .3125 L .48362 .31146 L F
.31249 .3014 m .31354 .29831 L .31536 .30026 L 0 .03 .13 r
F
.31249 .3014 m .31067 .29946 L .31354 .29831 L F
.54947 .4301 m .54785 .42496 L .55073 .40856 L 0 .442 .185 r
F
.54785 .42496 m .54912 .4041 L .55073 .40856 L 0 .43 .202 r
F
.80447 .29976 m .80626 .29674 L .80759 .29873 L 0 .027 .126 r
F
.80447 .29976 m .80313 .29777 L .80626 .29674 L F
.58519 .31193 m .58664 .30853 L .5882 .31072 L 0 .054 .156 r
F
.58519 .31193 m .58363 .30975 L .58664 .30853 L F
.17316 .29894 m .174 .29589 L .17595 .29788 L 0 .025 .124 r
F
.17316 .29894 m .17121 .29697 L .174 .29589 L F
.38674 .30503 m .3879 .30198 L .38964 .30394 L 0 .038 .139 r
F
.38674 .30503 m .38499 .30307 L .3879 .30198 L F
.85442 .29958 m .85629 .2966 L .85758 .29858 L 0 .026 .126 r
F
.85442 .29958 m .85313 .29759 L .85629 .2966 L F
.33976 .30254 m .34084 .29952 L .34263 .30156 L 0 .032 .133 r
F
.33976 .30254 m .33797 .30051 L .34084 .29952 L F
.4383 .30988 m .43954 .30683 L .44122 .30917 L 0 .049 .152 r
F
.4383 .30988 m .43662 .30757 L .43954 .30683 L F
.5486 .4635 m .54998 .45669 L .55148 .44782 L .05 .559 0 r
F
.55148 .44782 m .54998 .45669 L .55284 .4393 L 0 .498 .088 r
F
.54998 .45669 m .55132 .4458 L .55284 .4393 L 0 .535 .009 r
F
.21555 .29921 m .21644 .29625 L .21836 .2982 L 0 .026 .125 r
F
.21555 .29921 m .21363 .29727 L .21644 .29625 L F
.13076 .29879 m .13152 .29586 L .13352 .29781 L 0 .025 .124 r
F
.13076 .29879 m .12876 .29686 L .13152 .29586 L F
.27765 .30092 m .27865 .29784 L .2805 .29982 L 0 .029 .129 r
F
.27765 .30092 m .2758 .29895 L .27865 .29784 L F
.56709 .3156 m .56851 .3118 L .57009 .31403 L 0 .063 .165 r
F
.56709 .3156 m .56552 .31342 L .56851 .3118 L F
.47016 .3133 m .47145 .30998 L .47311 .31233 L 0 .058 .16 r
F
.47016 .3133 m .4685 .31091 L .47145 .30998 L F
.50803 .40664 m .50945 .38798 L .51101 .40567 L 0 .384 .257 r
F
.60032 .31123 m .6018 .30819 L .60333 .31002 L 0 .053 .155 r
F
.60032 .31123 m .59878 .30938 L .6018 .30819 L F
.32004 .30117 m .32109 .29829 L .3229 .30027 L 0 .03 .13 r
F
.32004 .30117 m .31823 .29921 L .32109 .29829 L F
.70159 .30306 m .70322 .30001 L .70465 .30182 L 0 .034 .134 r
F
.70159 .30306 m .70016 .30123 L .70322 .30001 L F
.53379 .40657 m .53511 .38403 L .53675 .39474 L 0 .38 .261 r
F
.53379 .40657 m .53215 .39392 L .53511 .38403 L F
.72428 .30183 m .72594 .29866 L .72735 .30064 L 0 .031 .131 r
F
.72428 .30183 m .72286 .29983 L .72594 .29866 L F
.45801 .31148 m .45928 .30825 L .46095 .31049 L 0 .053 .156 r
F
.45801 .31148 m .45634 .3093 L .45928 .30825 L F
.73184 .30142 m .73352 .29835 L .73492 .30029 L 0 .03 .13 r
F
.73184 .30142 m .73043 .29946 L .73352 .29835 L F
.39429 .30479 m .39546 .30167 L .3972 .30368 L 0 .037 .139 r
F
.39429 .30479 m .39255 .30281 L .39546 .30167 L F
.59276 .31172 m .59422 .30832 L .59577 .31054 L 0 .054 .156 r
F
.59276 .31172 m .5912 .30952 L .59422 .30832 L F
.53387 .32012 m .53525 .31624 L .53686 .31893 L 0 .076 .177 r
F
.53387 .32012 m .53227 .31743 L .53525 .31624 L F
.09591 .29831 m .09662 .29534 L .09866 .29726 L 0 .024 .123 r
F
.09591 .29831 m .09387 .29641 L .09662 .29534 L F
.36702 .30378 m .36815 .30056 L .36991 .30274 L 0 .035 .136 r
F
.36702 .30378 m .36526 .30163 L .36815 .30056 L F
.73941 .30106 m .7411 .29805 L .74249 .29993 L 0 .03 .13 r
F
.73941 .30106 m .73801 .29916 L .7411 .29805 L F
.75453 .30022 m .75624 .29719 L .75762 .29902 L 0 .028 .127 r
F
.75453 .30022 m .75315 .29839 L .75624 .29719 L F
.25037 .30002 m .25131 .29711 L .25319 .2991 L F
.25037 .30002 m .24848 .29805 L .25131 .29711 L F
.62598 .30738 m .62749 .30417 L .629 .30602 L 0 .043 .145 r
F
.62598 .30738 m .62447 .30556 L .62749 .30417 L F
.74697 .30069 m .74868 .29773 L .75006 .29957 L 0 .029 .129 r
F
.74697 .30069 m .74558 .29883 L .74868 .29773 L F
.2852 .30069 m .28621 .29758 L .28805 .29958 L F
.2852 .30069 m .28335 .2987 L .28621 .29758 L F
.7621 .29986 m .76383 .29687 L .76521 .29887 L 0 .027 .127 r
F
.7621 .29986 m .76071 .29785 L .76383 .29687 L F
.81206 .29968 m .81386 .29669 L .81519 .29867 L 0 .027 .126 r
F
.81206 .29968 m .81073 .29769 L .81386 .29669 L F
.18069 .29885 m .18153 .29584 L .18348 .29783 L 0 .025 .124 r
F
.18069 .29885 m .17874 .29686 L .18153 .29584 L F
.13828 .29873 m .13907 .29565 L .14106 .29762 L F
.13828 .29873 m .13629 .29676 L .13907 .29565 L F
.3473 .30255 m .34838 .29965 L .35017 .30163 L 0 .033 .134 r
F
.3473 .30255 m .34551 .30058 L .34838 .29965 L F
.49445 .31744 m .49578 .31381 L .49741 .31653 L 0 .069 .171 r
F
.49445 .31744 m .49282 .31477 L .49578 .31381 L F
.10344 .29815 m .10416 .29519 L .10618 .29714 L 0 .024 .123 r
F
.10344 .29815 m .10141 .29621 L .10416 .29519 L F
.54785 .42496 m .54623 .41983 L .54912 .4041 L 0 .43 .202 r
F
.22307 .29925 m .22397 .29629 L .22587 .29829 L 0 .026 .126 r
F
.22307 .29925 m .22116 .29725 L .22397 .29629 L F
.5066 .3194 m .50794 .31553 L .50957 .31794 L 0 .075 .175 r
F
.5066 .3194 m .50497 .31697 L .50794 .31553 L F
.51416 .319 m .51552 .31502 L .51714 .31751 L 0 .073 .174 r
F
.51416 .319 m .51254 .31648 L .51552 .31502 L F
.29274 .30055 m .29376 .29741 L .29559 .29948 L 0 .029 .129 r
F
.29274 .30055 m .2909 .2985 L .29376 .29741 L F
.61843 .30811 m .61994 .3051 L .62145 .30692 L 0 .046 .148 r
F
.61843 .30811 m .61691 .3063 L .61994 .3051 L F
.57764 .31295 m .57907 .30906 L .58063 .31127 L 0 .056 .159 r
F
.57764 .31295 m .57607 .31076 L .57907 .30906 L F
.52173 .31862 m .52309 .31452 L .5247 .3171 L 0 .072 .173 r
F
.52173 .31862 m .52011 .31601 L .52309 .31452 L F
.14582 .29849 m .14661 .29548 L .14859 .29748 L 0 .025 .124 r
F
.14582 .29849 m .14384 .29651 L .14661 .29548 L F
.81965 .2996 m .82147 .29659 L .82279 .29853 L 0 .027 .127 r
F
.81965 .2996 m .81833 .29765 L .82147 .29659 L F
.18821 .29878 m .18908 .29567 L .19102 .29766 L 0 .025 .124 r
F
.18821 .29878 m .18627 .29678 L .18908 .29567 L F
.76969 .29987 m .77143 .29681 L .7728 .29879 L 0 .028 .127 r
F
.76969 .29987 m .76832 .29788 L .77143 .29681 L F
.40183 .30492 m .40301 .30188 L .40473 .3041 L 0 .038 .14 r
F
.40183 .30492 m .40011 .3027 L .40301 .30188 L F
.41398 .30681 m .41518 .30368 L .4169 .30584 L 0 .043 .145 r
F
.41398 .30681 m .41227 .30462 L .41518 .30368 L F
.4337 .3083 m .43492 .30537 L .43662 .30757 L 0 .047 .149 r
F
.4337 .3083 m .432 .30615 L .43492 .30537 L F
.32756 .3014 m .32863 .29842 L .33043 .30045 L 0 .031 .131 r
F
.32756 .3014 m .32576 .29937 L .32863 .29842 L F
.82723 .29932 m .82905 .29627 L .83036 .29817 L 0 .027 .126 r
F
.82723 .29932 m .82592 .2974 L .82905 .29627 L F
.47771 .31359 m .47901 .31023 L .48066 .3125 L 0 .06 .162 r
F
.47771 .31359 m .47606 .31128 L .47901 .31023 L F
.25788 .30018 m .25885 .29705 L .26072 .29907 L 0 .028 .128 r
F
.25788 .30018 m .25601 .29816 L .25885 .29705 L F
.19576 .29851 m .19662 .29554 L .19856 .29751 L 0 .025 .124 r
F
.19576 .29851 m .19382 .29653 L .19662 .29554 L F
.55954 .31676 m .56095 .31291 L .56253 .31507 L 0 .068 .169 r
F
.55954 .31676 m .55796 .31459 L .56095 .31291 L F
.37455 .30398 m .3757 .30081 L .37744 .30304 L 0 .036 .138 r
F
.37455 .30398 m .3728 .30178 L .3757 .30081 L F
.77727 .29959 m .77901 .29649 L .78037 .29842 L 0 .027 .127 r
F
.77727 .29959 m .7759 .29764 L .77901 .29649 L F
.54144 .32035 m .54282 .31634 L .54442 .31907 L 0 .078 .178 r
F
.54144 .32035 m .53984 .31763 L .54282 .31634 L F
.549 .31995 m .55039 .31559 L .55199 .31809 L 0 .076 .176 r
F
.549 .31995 m .54741 .31739 L .55039 .31559 L F
.11095 .29815 m .11167 .29521 L .11369 .29718 L 0 .025 .123 r
F
.11095 .29815 m .10893 .29618 L .11167 .29521 L F
.61087 .30886 m .61237 .3057 L .61389 .30751 L 0 .048 .15 r
F
.61087 .30886 m .60935 .30706 L .61237 .3057 L F
.66679 .30321 m .66839 .30039 L .66985 .30217 L 0 .035 .137 r
F
.66679 .30321 m .66533 .30142 L .66839 .30039 L F
.52929 .31855 m .53066 .31488 L .53227 .31743 L 0 .073 .174 r
F
.52929 .31855 m .52768 .31599 L .53066 .31488 L F
.46556 .31184 m .46684 .30867 L .4685 .31091 L 0 .056 .158 r
F
.46556 .31184 m .46389 .30956 L .46684 .30867 L F
.83481 .29905 m .83665 .29613 L .83796 .29805 L 0 .027 .126 r
F
.83481 .29905 m .8335 .29714 L .83665 .29613 L F
.65923 .30367 m .6608 .30067 L .66228 .30246 L 0 .036 .137 r
F
.65923 .30367 m .65776 .30188 L .6608 .30067 L F
.44584 .31041 m .4471 .30693 L .44878 .30929 L 0 .051 .154 r
F
.44584 .31041 m .44416 .30805 L .4471 .30693 L F
.23059 .29929 m .2315 .29633 L .2334 .29828 L 0 .027 .126 r
F
.23059 .29929 m .22869 .29731 L .2315 .29633 L F
.30027 .30055 m .3013 .29751 L .30312 .29956 L 0 .029 .129 r
F
.30027 .30055 m .29845 .29848 L .3013 .29751 L F
.48986 .31566 m .49118 .31208 L .49282 .31477 L 0 .065 .167 r
F
.48986 .31566 m .48822 .31302 L .49118 .31208 L F
.78484 .29931 m .78661 .29642 L .78796 .2983 L 0 .027 .127 r
F
.78484 .29931 m .78349 .29741 L .78661 .29642 L F
.15334 .29847 m .15414 .29544 L .15611 .29744 L 0 .025 .124 r
F
.15334 .29847 m .15136 .29647 L .15414 .29544 L F
.52918 .40386 m .53053 .3826 L .53215 .39392 L 0 .376 .265 r
F
.52918 .40386 m .52756 .39083 L .53053 .3826 L F
.67436 .30289 m .67596 .3 L .67742 .30183 L 0 .035 .136 r
F
.67436 .30289 m .6729 .30109 L .67596 .3 L F
.26543 .29996 m .2664 .29689 L .26826 .29891 L 0 .028 .128 r
F
.26543 .29996 m .26356 .29795 L .2664 .29689 L F
.35483 .3027 m .35592 .29986 L .3577 .30184 L 0 .034 .135 r
F
.35483 .3027 m .35305 .30075 L .35592 .29986 L F
.42153 .30675 m .42274 .30395 L .42445 .30586 L 0 .044 .146 r
F
.42153 .30675 m .41982 .30488 L .42274 .30395 L F
.68194 .30267 m .68354 .29966 L .685 .30157 L 0 .034 .135 r
F
.68194 .30267 m .68048 .30076 L .68354 .29966 L F
.20328 .29848 m .20415 .29554 L .20608 .29749 L 0 .026 .125 r
F
.20328 .29848 m .20135 .29654 L .20415 .29554 L F
.79243 .29913 m .7942 .29616 L .79554 .29801 L 0 .027 .126 r
F
.79243 .29913 m .79108 .29726 L .7942 .29616 L F
.64412 .30479 m .64567 .30184 L .64716 .30373 L 0 .039 .141 r
F
.64412 .30479 m .64262 .3029 L .64567 .30184 L F
.11846 .29808 m .11922 .29502 L .12123 .29699 L 0 .025 .123 r
F
.11846 .29808 m .11645 .29611 L .11922 .29502 L F
.57009 .31403 m .57151 .31018 L .57308 .31245 L 0 .061 .163 r
F
.57009 .31403 m .56851 .3118 L .57151 .31018 L F
.16087 .29833 m .16169 .29526 L .16366 .29722 L 0 .025 .124 r
F
.16087 .29833 m .1589 .29635 L .16169 .29526 L F
.8424 .29897 m .84424 .29583 L .84554 .29781 L 0 .027 .126 r
F
.8424 .29897 m .8411 .297 L .84424 .29583 L F
.23812 .29918 m .23905 .29619 L .24095 .29812 L 0 .027 .127 r
F
.23812 .29918 m .23622 .29726 L .23905 .29619 L F
.63656 .30529 m .63808 .30208 L .63959 .30403 L 0 .04 .142 r
F
.63656 .30529 m .63505 .30337 L .63808 .30208 L F
.33509 .30152 m .33617 .29849 L .33797 .30051 L 0 .032 .132 r
F
.33509 .30152 m .3333 .29947 L .33617 .29849 L F
.49854 .45133 m .4998 .45676 L .50137 .46851 L 0 .535 .009 r
F
.4534 .31035 m .45466 .30709 L .45634 .3093 L 0 .052 .155 r
F
.4534 .31035 m .45172 .30819 L .45466 .30709 L F
.65169 .30448 m .65324 .30137 L .65472 .30318 L 0 .038 .14 r
F
.65169 .30448 m .6502 .30267 L .65324 .30137 L F
.68951 .30239 m .69113 .29945 L .69257 .30134 L 0 .034 .135 r
F
.68951 .30239 m .68806 .30047 L .69113 .29945 L F
.8 .29883 m .80179 .29582 L .80313 .29777 L 0 .027 .126 r
F
.8 .29883 m .79866 .29688 L .80179 .29582 L F
.7122 .30115 m .71387 .29832 L .71528 .30012 L 0 .032 .132 r
F
.7122 .30115 m .71078 .29936 L .71387 .29832 L F
.84998 .29864 m .85184 .2956 L .85313 .29759 L 0 .026 .125 r
F
.84998 .29864 m .84868 .29666 L .85184 .2956 L F
.27296 .29993 m .27394 .29693 L .2758 .29895 L 0 .029 .129 r
F
.27296 .29993 m .2711 .29792 L .27394 .29693 L F
.38209 .30415 m .38324 .30098 L .38499 .30307 L 0 .037 .139 r
F
.38209 .30415 m .38034 .30203 L .38324 .30098 L F
.16842 .29806 m .16924 .29501 L .17121 .29697 L 0 .025 .124 r
F
.16842 .29806 m .16645 .29611 L .16924 .29501 L F
.126 .29786 m .12675 .29491 L .12876 .29686 L 0 .025 .123 r
F
.126 .29786 m .12399 .29591 L .12675 .29491 L F
.50201 .31801 m .50334 .31454 L .50497 .31697 L 0 .073 .174 r
F
.50201 .31801 m .50037 .3156 L .50334 .31454 L F
.3078 .3006 m .30885 .29745 L .31067 .29946 L 0 .03 .13 r
F
.3078 .3006 m .30598 .29857 L .30885 .29745 L F
.36237 .30273 m .36349 .2996 L .36526 .30163 L 0 .035 .136 r
F
.36237 .30273 m .36059 .30073 L .36349 .2996 L F
.5882 .31072 m .58965 .30732 L .5912 .30952 L 0 .053 .156 r
F
.5882 .31072 m .58664 .30853 L .58965 .30732 L F
.21082 .29835 m .21171 .29533 L .21363 .29727 L 0 .026 .125 r
F
.21082 .29835 m .20889 .29641 L .21171 .29533 L F
.31536 .30026 m .31641 .29725 L .31823 .29921 L 0 .03 .13 r
F
.31536 .30026 m .31354 .29831 L .31641 .29725 L F
.24566 .29902 m .2466 .29607 L .24848 .29805 L 0 .027 .127 r
F
.24566 .29902 m .24377 .29706 L .2466 .29607 L F
.48526 .31396 m .48657 .31048 L .48822 .31302 L 0 .062 .164 r
F
.48526 .31396 m .48362 .31146 L .48657 .31048 L F
.71978 .30095 m .72145 .29796 L .72286 .29983 L 0 .031 .132 r
F
.71978 .30095 m .71837 .29909 L .72145 .29796 L F
.69709 .30223 m .69873 .2994 L .70016 .30123 L 0 .034 .135 r
F
.69709 .30223 m .69565 .30037 L .69873 .2994 L F
.629 .30602 m .63052 .30279 L .63202 .30467 L 0 .042 .144 r
F
.629 .30602 m .62749 .30417 L .63052 .30279 L F
.70465 .30182 m .70629 .29876 L .70772 .30056 L 0 .033 .134 r
F
.70465 .30182 m .70322 .30001 L .70629 .29876 L F
.58063 .31127 m .58207 .30752 L .58363 .30975 L 0 .054 .156 r
F
.58063 .31127 m .57907 .30906 L .58207 .30752 L F
.60333 .31002 m .60481 .30672 L .60634 .30854 L 0 .052 .154 r
F
.60333 .31002 m .6018 .30819 L .60481 .30672 L F
.38964 .30394 m .39081 .30082 L .39255 .30281 L 0 .037 .139 r
F
.38964 .30394 m .3879 .30198 L .39081 .30082 L F
.17595 .29788 m .17679 .29487 L .17874 .29686 L 0 .025 .124 r
F
.17595 .29788 m .174 .29589 L .17679 .29487 L F
.80759 .29873 m .80939 .2957 L .81073 .29769 L 0 .027 .126 r
F
.80759 .29873 m .80626 .29674 L .80939 .2957 L F
.72735 .30064 m .72902 .29749 L .73043 .29946 L 0 .03 .131 r
F
.72735 .30064 m .72594 .29866 L .72902 .29749 L F
.42908 .30694 m .43029 .30414 L .432 .30615 L 0 .045 .147 r
F
.42908 .30694 m .42737 .30498 L .43029 .30414 L F
.2805 .29982 m .2815 .29671 L .28335 .2987 L 0 .029 .129 r
F
.2805 .29982 m .27865 .29784 L .2815 .29671 L F
.53686 .31893 m .53824 .31494 L .53984 .31763 L 0 .075 .176 r
F
.53686 .31893 m .53525 .31624 L .53824 .31494 L F
.55199 .31809 m .55338 .31383 L .55497 .31626 L 0 .072 .173 r
F
.55199 .31809 m .55039 .31559 L .55338 .31383 L F
.85758 .29858 m .85946 .29561 L .86074 .29758 L 0 .027 .126 r
F
.85758 .29858 m .85629 .2966 L .85946 .29561 L F
.59577 .31054 m .59723 .30713 L .59878 .30938 L 0 .053 .155 r
F
.59577 .31054 m .59422 .30832 L .59723 .30713 L F
.75762 .29902 m .75934 .29602 L .76071 .29785 L 0 .027 .127 r
F
.75762 .29902 m .75624 .29719 L .75934 .29602 L F
.73492 .30029 m .73661 .29725 L .73801 .29916 L 0 .03 .13 r
F
.73492 .30029 m .73352 .29835 L .73661 .29725 L F
.21836 .2982 m .21925 .29527 L .22116 .29725 L 0 .026 .125 r
F
.21836 .2982 m .21644 .29625 L .21925 .29527 L F
.40936 .30554 m .41055 .30238 L .41227 .30462 L 0 .041 .143 r
F
.40936 .30554 m .40764 .30328 L .41055 .30238 L F
.34263 .30156 m .34372 .29853 L .34551 .30058 L 0 .033 .133 r
F
.34263 .30156 m .34084 .29952 L .34372 .29853 L F
.51714 .31751 m .51849 .31355 L .52011 .31601 L 0 .071 .172 r
F
.51714 .31751 m .51552 .31502 L .51849 .31355 L F
.5247 .3171 m .52607 .31342 L .52768 .31599 L F
.5247 .3171 m .52309 .31452 L .52607 .31342 L F
.50957 .31794 m .51092 .31408 L .51254 .31648 L 0 .073 .174 r
F
.50957 .31794 m .50794 .31553 L .51092 .31408 L F
.3972 .30368 m .39837 .30067 L .40011 .3027 L 0 .037 .139 r
F
.3972 .30368 m .39546 .30167 L .39837 .30067 L F
.13352 .29781 m .13429 .29479 L .13629 .29676 L 0 .025 .124 r
F
.13352 .29781 m .13152 .29586 L .13429 .29479 L F
.74249 .29993 m .7442 .29697 L .74558 .29883 L 0 .029 .129 r
F
.74249 .29993 m .7411 .29805 L .7442 .29697 L F
.47311 .31233 m .4744 .30896 L .47606 .31128 L 0 .058 .16 r
F
.47311 .31233 m .47145 .30998 L .4744 .30896 L F
.56253 .31507 m .56394 .31124 L .56552 .31342 L 0 .065 .166 r
F
.56253 .31507 m .56095 .31291 L .56394 .31124 L F
.09866 .29726 m .09937 .29426 L .10141 .29621 L 0 .024 .123 r
F
.09866 .29726 m .09662 .29534 L .09937 .29426 L F
.75006 .29957 m .75177 .29656 L .75315 .29839 L 0 .029 .128 r
F
.75006 .29957 m .74868 .29773 L .75177 .29656 L F
.46095 .31049 m .46222 .30734 L .46389 .30956 L 0 .054 .156 r
F
.46095 .31049 m .45928 .30825 L .46222 .30734 L F
.28805 .29958 m .28906 .29647 L .2909 .2985 L 0 .029 .128 r
F
.28805 .29958 m .28621 .29758 L .28906 .29647 L F
.36991 .30274 m .37105 .29957 L .3728 .30178 L 0 .035 .136 r
F
.36991 .30274 m .36815 .30056 L .37105 .29957 L F
.3229 .30027 m .32395 .29736 L .32576 .29937 L 0 .03 .131 r
F
.3229 .30027 m .32109 .29829 L .32395 .29736 L F
.76521 .29887 m .76694 .29588 L .76832 .29788 L 0 .027 .127 r
F
.76521 .29887 m .76383 .29687 L .76694 .29588 L F
.81519 .29867 m .817 .29568 L .81833 .29765 L 0 .027 .126 r
F
.81519 .29867 m .81386 .29669 L .817 .29568 L F
.14106 .29762 m .14185 .29453 L .14384 .29651 L 0 .025 .123 r
F
.14106 .29762 m .13907 .29565 L .14185 .29453 L F
.18348 .29783 m .18433 .29478 L .18627 .29678 L 0 .025 .124 r
F
.18348 .29783 m .18153 .29584 L .18433 .29478 L F
.44122 .30917 m .44248 .3057 L .44416 .30805 L 0 .05 .152 r
F
.44122 .30917 m .43954 .30683 L .44248 .3057 L F
.25319 .2991 m .25413 .29614 L .25601 .29816 L 0 .028 .128 r
F
.25319 .2991 m .25131 .29711 L .25413 .29614 L F
.54003 .41613 m .54132 .39333 L .54296 .40231 L 0 .408 .231 r
F
.54003 .41613 m .53838 .40549 L .54132 .39333 L F
.50175 .46294 m .50014 .45713 L .50298 .47511 L .101 .579 0 r
F
.50014 .45713 m .50137 .46851 L .50298 .47511 L .056 .561 0 r
F
.50366 .41986 m .50213 .40324 L .50508 .40494 L 0 .43 .202 r
F
.50074 .41407 m .50213 .40324 L .50366 .41986 L 0 .412 .225 r
F
.62145 .30692 m .62296 .30371 L .62447 .30556 L 0 .045 .147 r
F
.62145 .30692 m .61994 .3051 L .62296 .30371 L F
.10618 .29714 m .1069 .29421 L .10893 .29618 L 0 .024 .123 r
F
.10618 .29714 m .10416 .29519 L .1069 .29421 L F
.29559 .29948 m .29661 .29641 L .29845 .29848 L 0 .029 .129 r
F
.29559 .29948 m .29376 .29741 L .29661 .29641 L F
.49741 .31653 m .49874 .31283 L .50037 .3156 L 0 .07 .171 r
F
.49741 .31653 m .49578 .31381 L .49874 .31283 L F
.61389 .30751 m .61539 .30448 L .61691 .3063 L 0 .047 .149 r
F
.61389 .30751 m .61237 .3057 L .61539 .30448 L F
.35017 .30163 m .35126 .29875 L .35305 .30075 L 0 .034 .135 r
F
.35017 .30163 m .34838 .29965 L .35126 .29875 L F
.19102 .29766 m .19188 .29456 L .19382 .29653 L 0 .025 .124 r
F
.19102 .29766 m .18908 .29567 L .19188 .29456 L F
.22587 .29829 m .22678 .29533 L .22869 .29731 L 0 .027 .126 r
F
.22587 .29829 m .22397 .29629 L .22678 .29533 L F
.54442 .31907 m .54581 .31472 L .54741 .31739 L 0 .076 .176 r
F
.54442 .31907 m .54282 .31634 L .54581 .31472 L F
.14859 .29748 m .14938 .29445 L .15136 .29647 L 0 .025 .124 r
F
.14859 .29748 m .14661 .29548 L .14938 .29445 L F
.82279 .29853 m .8246 .29547 L .82592 .2974 L 0 .027 .126 r
F
.82279 .29853 m .82147 .29659 L .8246 .29547 L F
.7728 .29879 m .77454 .29568 L .7759 .29764 L 0 .028 .127 r
F
.7728 .29879 m .77143 .29681 L .77454 .29568 L F
.83036 .29817 m .8322 .29525 L .8335 .29714 L 0 .027 .126 r
F
.83036 .29817 m .82905 .29627 L .8322 .29525 L F
.57308 .31245 m .5745 .30848 L .57607 .31076 L 0 .058 .16 r
F
.57308 .31245 m .57151 .31018 L .5745 .30848 L F
.78037 .29842 m .78213 .2955 L .78349 .29741 L 0 .027 .126 r
F
.78037 .29842 m .77901 .29649 L .78213 .2955 L F
.26072 .29907 m .26169 .29593 L .26356 .29795 L 0 .028 .128 r
F
.26072 .29907 m .25885 .29705 L .26169 .29593 L F
.48066 .3125 m .48197 .30919 L .48362 .31146 L 0 .059 .162 r
F
.48066 .3125 m .47901 .31023 L .48197 .30919 L F
.66228 .30246 m .66386 .29963 L .66533 .30142 L 0 .036 .137 r
F
.66228 .30246 m .6608 .30067 L .66386 .29963 L F
.4169 .30584 m .4181 .30273 L .41982 .30488 L 0 .043 .145 r
F
.4169 .30584 m .41518 .30368 L .4181 .30273 L F
.53227 .31743 m .53364 .31369 L .53525 .31624 L 0 .073 .174 r
F
.53227 .31743 m .53066 .31488 L .53364 .31369 L F
.19856 .29751 m .19942 .29458 L .20135 .29654 L 0 .026 .124 r
F
.19856 .29751 m .19662 .29554 L .19942 .29458 L F
.33043 .30045 m .3315 .29746 L .3333 .29947 L 0 .031 .132 r
F
.33043 .30045 m .32863 .29842 L .3315 .29746 L F
.44878 .30929 m .45004 .3058 L .45172 .30819 L 0 .051 .153 r
F
.44878 .30929 m .4471 .30693 L .45004 .3058 L F
.66985 .30217 m .67144 .29929 L .6729 .30109 L 0 .035 .136 r
F
.66985 .30217 m .66839 .30039 L .67144 .29929 L F
.55497 .31626 m .55637 .31224 L .55796 .31459 L 0 .069 .17 r
F
.55497 .31626 m .55338 .31383 L .55637 .31224 L F
.37744 .30304 m .37859 .29981 L .38034 .30203 L 0 .037 .138 r
F
.37744 .30304 m .3757 .30081 L .37859 .29981 L F
.40473 .3041 m .40592 .30106 L .40764 .30328 L 0 .039 .141 r
F
.40473 .3041 m .40301 .30188 L .40592 .30106 L F
.11369 .29718 m .11443 .29414 L .11645 .29611 L 0 .025 .123 r
F
.11369 .29718 m .11167 .29521 L .11443 .29414 L F
.83796 .29805 m .8398 .29508 L .8411 .297 L 0 .027 .126 r
F
.83796 .29805 m .83665 .29613 L .8398 .29508 L F
.67742 .30183 m .67902 .29891 L .68048 .30076 L 0 .035 .136 r
F
.67742 .30183 m .67596 .3 L .67902 .29891 L F
.26826 .29891 m .26924 .2959 L .2711 .29792 L 0 .028 .128 r
F
.26826 .29891 m .2664 .29689 L .26924 .2959 L F
.15611 .29744 m .15692 .29436 L .1589 .29635 L 0 .025 .124 r
F
.15611 .29744 m .15414 .29544 L .15692 .29436 L F
.2334 .29828 m .23432 .29531 L .23622 .29726 L 0 .027 .126 r
F
.2334 .29828 m .2315 .29633 L .23432 .29531 L F
.30312 .29956 m .30415 .29653 L .30598 .29857 L 0 .03 .13 r
F
.30312 .29956 m .3013 .29751 L .30415 .29653 L F
.78796 .2983 m .78974 .29539 L .79108 .29726 L 0 .027 .127 r
F
.78796 .2983 m .78661 .29642 L .78974 .29539 L F
.4685 .31091 m .46978 .30776 L .47145 .30998 L 0 .056 .158 r
F
.4685 .31091 m .46684 .30867 L .46978 .30776 L F
.43662 .30757 m .43785 .3046 L .43954 .30683 L 0 .048 .15 r
F
.43662 .30757 m .43492 .30537 L .43785 .3046 L F
.65472 .30318 m .65628 .30008 L .65776 .30188 L 0 .037 .139 r
F
.65472 .30318 m .65324 .30137 L .65628 .30008 L F
.63959 .30403 m .64112 .30091 L .64262 .3029 L 0 .039 .141 r
F
.63959 .30403 m .63808 .30208 L .64112 .30091 L F
.50175 .46294 m .50298 .47511 L .50459 .48171 L .101 .579 0 r
F
.49282 .31477 m .49414 .31106 L .49578 .31381 L 0 .066 .167 r
F
.49282 .31477 m .49118 .31208 L .49414 .31106 L F
.58363 .30975 m .58508 .3063 L .58664 .30853 L 0 .053 .155 r
F
.58363 .30975 m .58207 .30752 L .58508 .3063 L F
.685 .30157 m .68661 .29855 L .68806 .30047 L 0 .034 .135 r
F
.685 .30157 m .68354 .29966 L .68661 .29855 L F
.79554 .29801 m .79733 .29505 L .79866 .29688 L 0 .027 .126 r
F
.79554 .29801 m .7942 .29616 L .79733 .29505 L F
.84554 .29781 m .84738 .29467 L .84868 .29666 L 0 .026 .125 r
F
.84554 .29781 m .84424 .29583 L .84738 .29467 L F
.12123 .29699 m .12198 .29394 L .12399 .29591 L 0 .025 .123 r
F
.12123 .29699 m .11922 .29502 L .12198 .29394 L F
.60634 .30854 m .60782 .30525 L .60935 .30706 L 0 .05 .152 r
F
.60634 .30854 m .60481 .30672 L .60782 .30525 L F
.16366 .29722 m .16448 .29415 L .16645 .29611 L 0 .025 .124 r
F
.16366 .29722 m .16169 .29526 L .16448 .29415 L F
.3577 .30184 m .35882 .29873 L .36059 .30073 L 0 .035 .136 r
F
.3577 .30184 m .35592 .29986 L .35882 .29873 L F
.64716 .30373 m .64871 .30079 L .6502 .30267 L 0 .039 .141 r
F
.64716 .30373 m .64567 .30184 L .64871 .30079 L F
.42445 .30586 m .42566 .30301 L .42737 .30498 L 0 .044 .147 r
F
.42445 .30586 m .42274 .30395 L .42566 .30301 L F
.56552 .31342 m .56694 .30957 L .56851 .3118 L 0 .062 .164 r
F
.56552 .31342 m .56394 .31124 L .56694 .30957 L F
.20608 .29749 m .20696 .29447 L .20889 .29641 L 0 .026 .125 r
F
.20608 .29749 m .20415 .29554 L .20696 .29447 L F
.24095 .29812 m .24188 .29512 L .24377 .29706 L 0 .027 .126 r
F
.24095 .29812 m .23905 .29619 L .24188 .29512 L F
.63202 .30467 m .63355 .30145 L .63505 .30337 L 0 .041 .143 r
F
.63202 .30467 m .63052 .30279 L .63355 .30145 L F
.52011 .31601 m .52147 .31209 L .52309 .31452 L 0 .069 .17 r
F
.52011 .31601 m .51849 .31355 L .52147 .31209 L F
.45634 .3093 m .4576 .306 L .45928 .30825 L 0 .052 .155 r
F
.45634 .3093 m .45466 .30709 L .4576 .306 L F
.5912 .30952 m .59266 .3061 L .59422 .30832 L F
.5912 .30952 m .58965 .30732 L .59266 .3061 L F
.69257 .30134 m .69421 .2985 L .69565 .30037 L 0 .034 .135 r
F
.69257 .30134 m .69113 .29945 L .69421 .2985 L F
.80313 .29777 m .80492 .29478 L .80626 .29674 L 0 .027 .126 r
F
.80313 .29777 m .80179 .29582 L .80492 .29478 L F
.31067 .29946 m .31172 .29633 L .31354 .29831 L 0 .03 .13 r
F
.31067 .29946 m .30885 .29745 L .31172 .29633 L F
.33797 .30051 m .33905 .29748 L .34084 .29952 L 0 .032 .133 r
F
.33797 .30051 m .33617 .29849 L .33905 .29748 L F
.51254 .31648 m .51389 .31264 L .51552 .31502 L 0 .071 .172 r
F
.51254 .31648 m .51092 .31408 L .51389 .31264 L F
.85313 .29759 m .855 .29461 L .85629 .2966 L 0 .026 .125 r
F
.85313 .29759 m .85184 .2956 L .855 .29461 L F
.71528 .30012 m .71695 .29727 L .71837 .29909 L 0 .032 .132 r
F
.71528 .30012 m .71387 .29832 L .71695 .29727 L F
.17121 .29697 m .17204 .2939 L .174 .29589 L 0 .025 .124 r
F
.17121 .29697 m .16924 .29501 L .17204 .2939 L F
.38499 .30307 m .38615 .29991 L .3879 .30198 L 0 .037 .139 r
F
.38499 .30307 m .38324 .30098 L .38615 .29991 L F
.70772 .30056 m .70936 .29756 L .71078 .29936 L 0 .032 .133 r
F
.70772 .30056 m .70629 .29876 L .70936 .29756 L F
.36526 .30163 m .36639 .29851 L .36815 .30056 L 0 .034 .135 r
F
.36526 .30163 m .36349 .2996 L .36639 .29851 L F
.50497 .31697 m .50631 .31311 L .50794 .31553 L 0 .072 .173 r
F
.50497 .31697 m .50334 .31454 L .50631 .31311 L F
.21363 .29727 m .21452 .29429 L .21644 .29625 L 0 .026 .125 r
F
.21363 .29727 m .21171 .29533 L .21452 .29429 L F
.53984 .31763 m .54122 .31364 L .54282 .31634 L 0 .074 .175 r
F
.53984 .31763 m .53824 .31494 L .54122 .31364 L F
.2758 .29895 m .27679 .29584 L .27865 .29784 L 0 .029 .129 r
F
.2758 .29895 m .27394 .29693 L .27679 .29584 L F
.12876 .29686 m .12951 .29391 L .13152 .29586 L 0 .025 .124 r
F
.12876 .29686 m .12675 .29491 L .12951 .29391 L F
.72286 .29983 m .72453 .29678 L .72594 .29866 L 0 .031 .131 r
F
.72286 .29983 m .72145 .29796 L .72453 .29678 L F
.31823 .29921 m .31927 .2963 L .32109 .29829 L 0 .03 .13 r
F
.31823 .29921 m .31641 .29725 L .31927 .2963 L F
.39255 .30281 m .39372 .29966 L .39546 .30167 L 0 .037 .139 r
F
.39255 .30281 m .39081 .30082 L .39372 .29966 L F
.73043 .29946 m .73211 .29641 L .73352 .29835 L 0 .03 .13 r
F
.73043 .29946 m .72902 .29749 L .73211 .29641 L F
.52158 .40724 m .52296 .38534 L .52458 .39903 L 0 .387 .254 r
F
.52158 .40724 m .51998 .39203 L .52296 .38534 L F
.59878 .30938 m .60025 .30592 L .6018 .30819 L 0 .052 .155 r
F
.59878 .30938 m .59723 .30713 L .60025 .30592 L F
.24848 .29805 m .24942 .29511 L .25131 .29711 L 0 .027 .127 r
F
.24848 .29805 m .2466 .29607 L .24942 .29511 L F
.76071 .29785 m .76246 .29503 L .76383 .29687 L F
.76071 .29785 m .75934 .29602 L .76246 .29503 L F
.54741 .31739 m .5488 .313 L .55039 .31559 L 0 .073 .173 r
F
.54741 .31739 m .54581 .31472 L .5488 .313 L F
.28335 .2987 m .28436 .29558 L .28621 .29758 L 0 .029 .128 r
F
.28335 .2987 m .2815 .29671 L .28436 .29558 L F
.70016 .30123 m .70179 .29819 L .70322 .30001 L 0 .034 .135 r
F
.70016 .30123 m .69873 .2994 L .70179 .29819 L F
.09387 .29641 m .09457 .29341 L .09662 .29534 L 0 .024 .123 r
F
.09387 .29641 m .09182 .29449 L .09457 .29341 L F
.73801 .29916 m .7397 .29616 L .7411 .29805 L 0 .03 .13 r
F
.73801 .29916 m .73661 .29725 L .7397 .29616 L F
.81073 .29769 m .81253 .2947 L .81386 .29669 L 0 .027 .126 r
F
.81073 .29769 m .80939 .2957 L .81253 .2947 L F
.48822 .31302 m .48954 .30949 L .49118 .31208 L 0 .062 .164 r
F
.48822 .31302 m .48657 .31048 L .48954 .30949 L F
.17874 .29686 m .17958 .29384 L .18153 .29584 L 0 .025 .124 r
F
.17874 .29686 m .17679 .29487 L .17958 .29384 L F
.52768 .31599 m .52905 .31231 L .53066 .31488 L 0 .07 .171 r
F
.52768 .31599 m .52607 .31342 L .52905 .31231 L F
.57607 .31076 m .5775 .30677 L .57907 .30906 L 0 .055 .157 r
F
.57607 .31076 m .5745 .30848 L .5775 .30677 L F
.75315 .29839 m .75487 .29536 L .75624 .29719 L 0 .028 .128 r
F
.75315 .29839 m .75177 .29656 L .75487 .29536 L F
.74558 .29883 m .74729 .29589 L .74868 .29773 L 0 .029 .129 r
F
.74558 .29883 m .7442 .29697 L .74729 .29589 L F
.62447 .30556 m .62598 .30228 L .62749 .30417 L 0 .043 .146 r
F
.62447 .30556 m .62296 .30371 L .62598 .30228 L F
.13629 .29676 m .13707 .29367 L .13907 .29565 L 0 .025 .124 r
F
.13629 .29676 m .13429 .29479 L .13707 .29367 L F
.47606 .31128 m .47735 .30795 L .47901 .31023 L 0 .058 .16 r
F
.47606 .31128 m .4744 .30896 L .47735 .30795 L F
.34551 .30058 m .3466 .29759 L .34838 .29965 L 0 .033 .134 r
F
.34551 .30058 m .34372 .29853 L .3466 .29759 L F
.40011 .3027 m .40128 .29983 L .40301 .30188 L 0 .038 .139 r
F
.40011 .3027 m .39837 .30067 L .40128 .29983 L F
.2909 .2985 m .29192 .29536 L .29376 .29741 L 0 .028 .128 r
F
.2909 .2985 m .28906 .29647 L .29192 .29536 L F
.22116 .29725 m .22206 .29428 L .22397 .29629 L 0 .026 .125 r
F
.22116 .29725 m .21925 .29527 L .22206 .29428 L F
.10141 .29621 m .10212 .29322 L .10416 .29519 L 0 .024 .123 r
F
.10141 .29621 m .09937 .29426 L .10212 .29322 L F
.41227 .30462 m .41347 .30146 L .41518 .30368 L 0 .042 .144 r
F
.41227 .30462 m .41055 .30238 L .41347 .30146 L F
.432 .30615 m .43322 .30332 L .43492 .30537 L 0 .046 .148 r
F
.432 .30615 m .43029 .30414 L .43322 .30332 L F
.44416 .30805 m .44542 .30455 L .4471 .30693 L 0 .049 .152 r
F
.44416 .30805 m .44248 .3057 L .44542 .30455 L F
.14384 .29651 m .14462 .29348 L .14661 .29548 L 0 .025 .123 r
F
.14384 .29651 m .14185 .29453 L .14462 .29348 L F
.3728 .30178 m .37395 .29858 L .3757 .30081 L 0 .035 .137 r
F
.3728 .30178 m .37105 .29957 L .37395 .29858 L F
.55796 .31459 m .55937 .31064 L .56095 .31291 L 0 .066 .168 r
F
.55796 .31459 m .55637 .31224 L .55937 .31064 L F
.46389 .30956 m .46517 .30648 L .46684 .30867 L 0 .054 .157 r
F
.46389 .30956 m .46222 .30734 L .46517 .30648 L F
.18627 .29678 m .18713 .29367 L .18908 .29567 L 0 .025 .124 r
F
.18627 .29678 m .18433 .29478 L .18713 .29367 L F
.81833 .29765 m .82014 .29462 L .82147 .29659 L 0 .027 .126 r
F
.81833 .29765 m .817 .29568 L .82014 .29462 L F
.76832 .29788 m .77005 .29483 L .77143 .29681 L 0 .028 .127 r
F
.76832 .29788 m .76694 .29588 L .77005 .29483 L F
.55132 .4458 m .54976 .44805 L .55262 .43038 L 0 .493 .098 r
F
.54976 .44805 m .55106 .4319 L .55262 .43038 L 0 .507 .069 r
F
.32576 .29937 m .32682 .29641 L .32863 .29842 L 0 .031 .131 r
F
.32576 .29937 m .32395 .29736 L .32682 .29641 L F
.61691 .3063 m .61842 .30325 L .61994 .3051 L 0 .046 .149 r
F
.61691 .3063 m .61539 .30448 L .61842 .30325 L F
.25601 .29816 m .25698 .29502 L .25885 .29705 L 0 .028 .128 r
F
.25601 .29816 m .25413 .29614 L .25698 .29502 L F
.19382 .29653 m .19468 .29358 L .19662 .29554 L 0 .025 .124 r
F
.19382 .29653 m .19188 .29456 L .19468 .29358 L F
.82592 .2974 m .82774 .29436 L .82905 .29627 L 0 .027 .126 r
F
.82592 .2974 m .8246 .29547 L .82774 .29436 L F
.29845 .29848 m .29947 .29545 L .3013 .29751 L 0 .029 .129 r
F
.29845 .29848 m .29661 .29641 L .29947 .29545 L F
.7759 .29764 m .77765 .29455 L .77901 .29649 L 0 .027 .127 r
F
.7759 .29764 m .77454 .29568 L .77765 .29455 L F
.10893 .29618 m .10965 .29324 L .11167 .29521 L 0 .025 .123 r
F
.10893 .29618 m .1069 .29421 L .10965 .29324 L F
.15136 .29647 m .15216 .29341 L .15414 .29544 L 0 .025 .124 r
F
.15136 .29647 m .14938 .29445 L .15216 .29341 L F
.22869 .29731 m .22959 .29436 L .2315 .29633 L 0 .027 .126 r
F
.22869 .29731 m .22678 .29533 L .22959 .29436 L F
.56851 .3118 m .56993 .3079 L .57151 .31018 L 0 .059 .161 r
F
.56851 .3118 m .56694 .30957 L .56993 .3079 L F
.26356 .29795 m .26454 .29487 L .2664 .29689 L 0 .028 .128 r
F
.26356 .29795 m .26169 .29593 L .26454 .29487 L F
.50037 .3156 m .50171 .31175 L .50334 .31454 L 0 .07 .171 r
F
.50037 .3156 m .49874 .31283 L .50171 .31175 L F
.53525 .31624 m .53663 .31241 L .53824 .31494 L 0 .072 .173 r
F
.53525 .31624 m .53364 .31369 L .53663 .31241 L F
.8335 .29714 m .83536 .29425 L .83665 .29613 L 0 .027 .126 r
F
.8335 .29714 m .8322 .29525 L .83536 .29425 L F
.35305 .30075 m .35414 .29785 L .35592 .29986 L 0 .034 .135 r
F
.35305 .30075 m .35126 .29875 L .35414 .29785 L F
.48362 .31146 m .48493 .30816 L .48657 .31048 L 0 .06 .162 r
F
.48362 .31146 m .48197 .30919 L .48493 .30816 L F
.60935 .30706 m .61084 .30388 L .61237 .3057 L 0 .048 .151 r
F
.60935 .30706 m .60782 .30525 L .61084 .30388 L F
.78349 .29741 m .78526 .29452 L .78661 .29642 L 0 .027 .127 r
F
.78349 .29741 m .78213 .2955 L .78526 .29452 L F
.66533 .30142 m .66692 .29859 L .66839 .30039 L 0 .036 .137 r
F
.66533 .30142 m .66386 .29963 L .66692 .29859 L F
.65776 .30188 m .65933 .29887 L .6608 .30067 L 0 .036 .138 r
F
.65776 .30188 m .65628 .30008 L .65933 .29887 L F
.45172 .30819 m .45298 .30467 L .45466 .30709 L 0 .051 .153 r
F
.45172 .30819 m .45004 .3058 L .45298 .30467 L F
.52309 .31452 m .52445 .31096 L .52607 .31342 L 0 .068 .169 r
F
.52309 .31452 m .52147 .31209 L .52445 .31096 L F
.6729 .30109 m .6745 .29818 L .67596 .3 L 0 .035 .136 r
F
.6729 .30109 m .67144 .29929 L .6745 .29818 L F
.55039 .31559 m .55179 .31132 L .55338 .31383 L 0 .069 .17 r
F
.55039 .31559 m .5488 .313 L .55179 .31132 L F
.41982 .30488 m .42103 .30175 L .42274 .30395 L 0 .043 .146 r
F
.41982 .30488 m .4181 .30273 L .42103 .30175 L F
.3333 .29947 m .33437 .29648 L .33617 .29849 L 0 .032 .132 r
F
.3333 .29947 m .3315 .29746 L .33437 .29648 L F
.11645 .29611 m .1172 .29305 L .11922 .29502 L 0 .025 .123 r
F
.11645 .29611 m .11443 .29414 L .1172 .29305 L F
.20135 .29654 m .20222 .2936 L .20415 .29554 L 0 .026 .125 r
F
.20135 .29654 m .19942 .29458 L .20222 .2936 L F
.51552 .31502 m .51687 .31121 L .51849 .31355 L 0 .069 .17 r
F
.51552 .31502 m .51389 .31264 L .51687 .31121 L F
.68048 .30076 m .68209 .29778 L .68354 .29966 L 0 .034 .135 r
F
.68048 .30076 m .67902 .29891 L .68209 .29778 L F
.1589 .29635 m .15971 .29329 L .16169 .29526 L 0 .025 .124 r
F
.1589 .29635 m .15692 .29436 L .15971 .29329 L F
.58664 .30853 m .58809 .30508 L .58965 .30732 L 0 .052 .154 r
F
.58664 .30853 m .58508 .3063 L .58809 .30508 L F
.38034 .30203 m .3815 .29879 L .38324 .30098 L 0 .037 .138 r
F
.38034 .30203 m .37859 .29981 L .3815 .29879 L F
.8411 .297 m .84295 .29391 L .84424 .29583 L 0 .026 .126 r
F
.8411 .297 m .8398 .29508 L .84295 .29391 L F
.64262 .3029 m .64417 .29982 L .64567 .30184 L 0 .039 .141 r
F
.64262 .3029 m .64112 .30091 L .64417 .29982 L F
.50794 .31553 m .50929 .31168 L .51092 .31408 L 0 .07 .171 r
F
.50794 .31553 m .50631 .31311 L .50929 .31168 L F
.23622 .29726 m .23715 .29424 L .23905 .29619 L 0 .027 .126 r
F
.23622 .29726 m .23432 .29531 L .23715 .29424 L F
.79108 .29726 m .79286 .29431 L .7942 .29616 L 0 .027 .127 r
F
.79108 .29726 m .78974 .29539 L .79286 .29431 L F
.63505 .30337 m .63658 .30012 L .63808 .30208 L 0 .04 .142 r
F
.63505 .30337 m .63355 .30145 L .63658 .30012 L F
.84868 .29666 m .85054 .29361 L .85184 .2956 L 0 .026 .125 r
F
.84868 .29666 m .84738 .29467 L .85054 .29361 L F
.2711 .29792 m .27208 .2949 L .27394 .29693 L 0 .028 .128 r
F
.2711 .29792 m .26924 .2959 L .27208 .2949 L F
.57907 .30906 m .58051 .30522 L .58207 .30752 L 0 .052 .155 r
F
.57907 .30906 m .5775 .30677 L .58051 .30522 L F
.79866 .29688 m .80046 .29399 L .80179 .29582 L 0 .027 .126 r
F
.79866 .29688 m .79733 .29505 L .80046 .29399 L F
.30598 .29857 m .30702 .29544 L .30885 .29745 L 0 .03 .13 r
F
.30598 .29857 m .30415 .29653 L .30702 .29544 L F
.68806 .30047 m .68968 .29753 L .69113 .29945 L 0 .034 .135 r
F
.68806 .30047 m .68661 .29855 L .68968 .29753 L F
.16645 .29611 m .16727 .29305 L .16924 .29501 L 0 .025 .124 r
F
.16645 .29611 m .16448 .29415 L .16727 .29305 L F
.36059 .30073 m .36172 .29757 L .36349 .2996 L 0 .034 .135 r
F
.36059 .30073 m .35882 .29873 L .36172 .29757 L F
.47145 .30998 m .47274 .30679 L .4744 .30896 L 0 .056 .159 r
F
.47145 .30998 m .46978 .30776 L .47274 .30679 L F
.12399 .29591 m .12474 .29296 L .12675 .29491 L 0 .025 .123 r
F
.12399 .29591 m .12198 .29394 L .12474 .29296 L F
.40764 .30328 m .40883 .30017 L .41055 .30238 L 0 .04 .142 r
F
.40764 .30328 m .40592 .30106 L .40883 .30017 L F
.59422 .30832 m .59568 .30488 L .59723 .30713 L 0 .052 .154 r
F
.59422 .30832 m .59266 .3061 L .59568 .30488 L F
.6502 .30267 m .65175 .2995 L .65324 .30137 L 0 .038 .14 r
F
.6502 .30267 m .64871 .30079 L .65175 .2995 L F
.49578 .31381 m .49711 .31004 L .49874 .31283 L 0 .066 .168 r
F
.49578 .31381 m .49414 .31106 L .49711 .31004 L F
.54282 .31634 m .54421 .31208 L .54581 .31472 L 0 .072 .173 r
F
.54282 .31634 m .54122 .31364 L .54421 .31208 L F
.20889 .29641 m .20978 .2934 L .21171 .29533 L 0 .026 .125 r
F
.20889 .29641 m .20696 .29447 L .20978 .2934 L F
.71078 .29936 m .71245 .29651 L .71387 .29832 L 0 .032 .133 r
F
.71078 .29936 m .70936 .29756 L .71245 .29651 L F
.31354 .29831 m .31459 .29528 L .31641 .29725 L 0 .029 .129 r
F
.31354 .29831 m .31172 .29633 L .31459 .29528 L F
.24377 .29706 m .24471 .29412 L .2466 .29607 L 0 .027 .126 r
F
.24377 .29706 m .24188 .29512 L .24471 .29412 L F
.49955 .44381 m .49801 .42919 L .5009 .4389 L 0 .513 .056 r
F
.49801 .42919 m .49937 .4225 L .5009 .4389 L 0 .459 .158 r
F
.50956 .47731 m .5108 .49857 L .51246 .49467 L .263 .634 0 r
F
.50956 .47731 m .5079 .48038 L .5108 .49857 L F
.45928 .30825 m .46055 .3051 L .46222 .30734 L 0 .052 .155 r
F
.45928 .30825 m .4576 .306 L .46055 .3051 L F
.174 .29589 m .17483 .29288 L .17679 .29487 L 0 .025 .123 r
F
.174 .29589 m .17204 .2939 L .17483 .29288 L F
.3879 .30198 m .38906 .29876 L .39081 .30082 L 0 .037 .139 r
F
.3879 .30198 m .38615 .29991 L .38906 .29876 L F
.80626 .29674 m .80806 .29374 L .80939 .2957 L 0 .027 .126 r
F
.80626 .29674 m .80492 .29478 L .80806 .29374 L F
.56095 .31291 m .56236 .30903 L .56394 .31124 L 0 .063 .165 r
F
.56095 .31291 m .55937 .31064 L .56236 .30903 L F
.43954 .30683 m .44079 .30347 L .44248 .3057 L 0 .048 .151 r
F
.43954 .30683 m .43785 .3046 L .44079 .30347 L F
.72594 .29866 m .72761 .2956 L .72902 .29749 L 0 .03 .131 r
F
.72594 .29866 m .72453 .29678 L .72761 .2956 L F
.71837 .29909 m .72003 .29613 L .72145 .29796 L 0 .031 .132 r
F
.71837 .29909 m .71695 .29727 L .72003 .29613 L F
.36815 .30056 m .36929 .29747 L .37105 .29957 L 0 .034 .135 r
F
.36815 .30056 m .36639 .29851 L .36929 .29747 L F
.42737 .30498 m .42859 .30212 L .43029 .30414 L 0 .045 .147 r
F
.42737 .30498 m .42566 .30301 L .42859 .30212 L F
.34084 .29952 m .34193 .29647 L .34372 .29853 L 0 .032 .133 r
F
.34084 .29952 m .33905 .29748 L .34193 .29647 L F
.27865 .29784 m .27964 .29474 L .2815 .29671 L 0 .029 .128 r
F
.27865 .29784 m .27679 .29584 L .27964 .29474 L F
.69565 .30037 m .69729 .29756 L .69873 .2994 L 0 .034 .135 r
F
.69565 .30037 m .69421 .2985 L .69729 .29756 L F
.85629 .2966 m .85817 .29362 L .85946 .29561 L 0 .026 .125 r
F
.85629 .2966 m .855 .29461 L .85817 .29362 L F
.62749 .30417 m .62901 .30086 L .63052 .30279 L 0 .042 .144 r
F
.62749 .30417 m .62598 .30228 L .62901 .30086 L F
.39546 .30167 m .39663 .29864 L .39837 .30067 L 0 .037 .138 r
F
.39546 .30167 m .39372 .29966 L .39663 .29864 L F
.6018 .30819 m .60326 .30448 L .60481 .30672 L 0 .051 .154 r
F
.6018 .30819 m .60025 .30592 L .60326 .30448 L F
.70322 .30001 m .70486 .29695 L .70629 .29876 L 0 .033 .134 r
F
.70322 .30001 m .70179 .29819 L .70486 .29695 L F
.21644 .29625 m .21733 .29328 L .21925 .29527 L 0 .026 .125 r
F
.21644 .29625 m .21452 .29429 L .21733 .29328 L F
.73352 .29835 m .7352 .29533 L .73661 .29725 L 0 .03 .13 r
F
.73352 .29835 m .73211 .29641 L .7352 .29533 L F
.13152 .29586 m .13228 .29286 L .13429 .29479 L 0 .025 .124 r
F
.13152 .29586 m .12951 .29391 L .13228 .29286 L F
.28621 .29758 m .28722 .29444 L .28906 .29647 L 0 .028 .128 r
F
.28621 .29758 m .28436 .29558 L .28722 .29444 L F
.75624 .29719 m .75797 .29419 L .75934 .29602 L 0 .028 .127 r
F
.75624 .29719 m .75487 .29536 L .75797 .29419 L F
.7411 .29805 m .7428 .2951 L .7442 .29697 L 0 .03 .13 r
F
.7411 .29805 m .7397 .29616 L .7428 .2951 L F
.09662 .29534 m .09733 .29234 L .09937 .29426 L 0 .024 .123 r
F
.09662 .29534 m .09457 .29341 L .09733 .29234 L F
.53066 .31488 m .53203 .31114 L .53364 .31369 L 0 .07 .171 r
F
.53066 .31488 m .52905 .31231 L .53203 .31114 L F
.32109 .29829 m .32214 .29536 L .32395 .29736 L 0 .03 .13 r
F
.32109 .29829 m .31927 .2963 L .32214 .29536 L F
.50227 .43035 m .50074 .41407 L .50366 .41986 L 0 .471 .138 r
F
.49937 .4225 m .50074 .41407 L .50227 .43035 L 0 .44 .188 r
F
.76383 .29687 m .76557 .29404 L .76694 .29588 L 0 .027 .127 r
F
.76383 .29687 m .76246 .29503 L .76557 .29404 L F
.18153 .29584 m .18238 .29278 L .18433 .29478 L 0 .025 .124 r
F
.18153 .29584 m .17958 .29384 L .18238 .29278 L F
.74868 .29773 m .75039 .29472 L .75177 .29656 L 0 .029 .129 r
F
.74868 .29773 m .74729 .29589 L .75039 .29472 L F
.25131 .29711 m .25225 .29412 L .25413 .29614 L 0 .028 .127 r
F
.25131 .29711 m .24942 .29511 L .25225 .29412 L F
.81386 .29669 m .81568 .2937 L .817 .29568 L 0 .027 .126 r
F
.81386 .29669 m .81253 .2947 L .81568 .2937 L F
.13907 .29565 m .13985 .29255 L .14185 .29453 L 0 .025 .123 r
F
.13907 .29565 m .13707 .29367 L .13985 .29255 L F
.57151 .31018 m .57293 .30619 L .5745 .30848 L 0 .056 .159 r
F
.57151 .31018 m .56993 .3079 L .57293 .30619 L F
.49118 .31208 m .4925 .30843 L .49414 .31106 L 0 .062 .164 r
F
.49118 .31208 m .48954 .30949 L .4925 .30843 L F
.29376 .29741 m .29478 .29434 L .29661 .29641 L 0 .028 .128 r
F
.29376 .29741 m .29192 .29536 L .29478 .29434 L F
.47901 .31023 m .48031 .30691 L .48197 .30919 L 0 .058 .16 r
F
.47901 .31023 m .47735 .30795 L .48031 .30691 L F
.53091 .48438 m .53234 .50655 L .53391 .48832 L .33 .655 0 r
F
.53091 .48438 m .52932 .50179 L .53234 .50655 L F
.55338 .31383 m .55478 .30983 L .55637 .31224 L 0 .066 .168 r
F
.55338 .31383 m .55179 .31132 L .55478 .30983 L F
.4471 .30693 m .44836 .3034 L .45004 .3058 L 0 .049 .152 r
F
.4471 .30693 m .44542 .30455 L .44836 .3034 L F
.10416 .29519 m .10487 .29225 L .1069 .29421 L 0 .024 .123 r
F
.10416 .29519 m .10212 .29322 L .10487 .29225 L F
.61994 .3051 m .62144 .30183 L .62296 .30371 L 0 .045 .147 r
F
.61994 .3051 m .61842 .30325 L .62144 .30183 L F
.34838 .29965 m .34948 .29669 L .35126 .29875 L 0 .033 .134 r
F
.34838 .29965 m .3466 .29759 L .34948 .29669 L F
.22397 .29629 m .22487 .29332 L .22678 .29533 L 0 .026 .126 r
F
.22397 .29629 m .22206 .29428 L .22487 .29332 L F
.18908 .29567 m .18994 .29256 L .19188 .29456 L 0 .025 .124 r
F
.18908 .29567 m .18713 .29367 L .18994 .29256 L F
.14661 .29548 m .1474 .29243 L .14938 .29445 L 0 .025 .123 r
F
.14661 .29548 m .14462 .29348 L .1474 .29243 L F
.41518 .30368 m .41639 .30052 L .4181 .30273 L 0 .042 .144 r
F
.41518 .30368 m .41347 .30146 L .41639 .30052 L F
.82147 .29659 m .82328 .29353 L .8246 .29547 L 0 .027 .126 r
F
.82147 .29659 m .82014 .29462 L .82328 .29353 L F
.77143 .29681 m .77317 .29371 L .77454 .29568 L 0 .027 .127 r
F
.77143 .29681 m .77005 .29483 L .77317 .29371 L F
.3757 .30081 m .37685 .29759 L .37859 .29981 L 0 .035 .137 r
F
.3757 .30081 m .37395 .29858 L .37685 .29759 L F
.40301 .30188 m .40419 .299 L .40592 .30106 L 0 .038 .14 r
F
.40301 .30188 m .40128 .29983 L .40419 .299 L F
.25885 .29705 m .25982 .2939 L .26169 .29593 L 0 .028 .127 r
F
.25885 .29705 m .25698 .29502 L .25982 .2939 L F
.61237 .3057 m .61387 .30264 L .61539 .30448 L 0 .047 .15 r
F
.61237 .3057 m .61084 .30388 L .61387 .30264 L F
.53824 .31494 m .53962 .31112 L .54122 .31364 L 0 .071 .172 r
F
.53824 .31494 m .53663 .31241 L .53962 .31112 L F
.82905 .29627 m .83089 .29336 L .8322 .29525 L 0 .027 .126 r
F
.82905 .29627 m .82774 .29436 L .83089 .29336 L F
.46684 .30867 m .46812 .30561 L .46978 .30776 L 0 .055 .157 r
F
.46684 .30867 m .46517 .30648 L .46812 .30561 L F
.77901 .29649 m .78078 .29357 L .78213 .2955 L 0 .027 .126 r
F
.77901 .29649 m .77765 .29455 L .78078 .29357 L F
.32863 .29842 m .32969 .29545 L .3315 .29746 L 0 .031 .131 r
F
.32863 .29842 m .32682 .29641 L .32969 .29545 L F
.51849 .31355 m .51985 .30977 L .52147 .31209 L 0 .067 .168 r
F
.51849 .31355 m .51687 .31121 L .51985 .30977 L F
.43492 .30537 m .43615 .30251 L .43785 .3046 L 0 .047 .149 r
F
.43492 .30537 m .43322 .30332 L .43615 .30251 L F
.58207 .30752 m .58352 .30401 L .58508 .3063 L 0 .051 .154 r
F
.58207 .30752 m .58051 .30522 L .58352 .30401 L F
.19662 .29554 m .19748 .29262 L .19942 .29458 L 0 .025 .124 r
F
.19662 .29554 m .19468 .29358 L .19748 .29262 L F
.53543 .41927 m .53675 .39474 L .53838 .40549 L 0 .42 .216 r
F
.53543 .41927 m .53379 .40657 L .53675 .39474 L F
.51092 .31408 m .51227 .31026 L .51389 .31264 L 0 .068 .17 r
F
.51092 .31408 m .50929 .31168 L .51227 .31026 L F
.5009 .4389 m .49937 .4225 L .50227 .43035 L 0 .498 .088 r
F
.54581 .31472 m .5472 .31045 L .5488 .313 L 0 .069 .171 r
F
.54581 .31472 m .54421 .31208 L .5472 .31045 L F
.3013 .29751 m .30232 .29448 L .30415 .29653 L 0 .029 .129 r
F
.3013 .29751 m .29947 .29545 L .30232 .29448 L F
.50334 .31454 m .50468 .31038 L .50631 .31311 L 0 .069 .17 r
F
.50334 .31454 m .50171 .31175 L .50468 .31038 L F
.6608 .30067 m .66239 .29783 L .66386 .29963 L 0 .036 .138 r
F
.6608 .30067 m .65933 .29887 L .66239 .29783 L F
.11167 .29521 m .11241 .29216 L .11443 .29414 L 0 .025 .123 r
F
.11167 .29521 m .10965 .29324 L .11241 .29216 L F
.2664 .29689 m .26738 .29386 L .26924 .2959 L 0 .028 .128 r
F
.2664 .29689 m .26454 .29487 L .26738 .29386 L F
.15414 .29544 m .15495 .29235 L .15692 .29436 L 0 .025 .124 r
F
.15414 .29544 m .15216 .29341 L .15495 .29235 L F
.56394 .31124 m .56536 .30739 L .56694 .30957 L 0 .06 .163 r
F
.56394 .31124 m .56236 .30903 L .56536 .30739 L F
.2315 .29633 m .23242 .29336 L .23432 .29531 L 0 .027 .126 r
F
.2315 .29633 m .22959 .29436 L .23242 .29336 L F
.83665 .29613 m .83851 .29321 L .8398 .29508 L F
.83665 .29613 m .83536 .29425 L .83851 .29321 L F
.45466 .30709 m .45593 .30354 L .4576 .306 L 0 .05 .153 r
F
.45466 .30709 m .45298 .30467 L .45593 .30354 L F
.58965 .30732 m .59111 .30385 L .59266 .3061 L 0 .051 .154 r
F
.58965 .30732 m .58809 .30508 L .59111 .30385 L F
.66839 .30039 m .66998 .29747 L .67144 .29929 L 0 .036 .137 r
F
.66839 .30039 m .66692 .29859 L .66998 .29747 L F
.52607 .31342 m .52744 .30983 L .52905 .31231 L 0 .067 .169 r
F
.52607 .31342 m .52445 .31096 L .52744 .30983 L F
.48657 .31048 m .48789 .30713 L .48954 .30949 L 0 .06 .162 r
F
.48657 .31048 m .48493 .30816 L .48789 .30713 L F
.63808 .30208 m .63962 .29891 L .64112 .30091 L 0 .039 .141 r
F
.63808 .30208 m .63658 .30012 L .63962 .29891 L F
.54168 .42674 m .54296 .40231 L .54459 .41129 L 0 .44 .188 r
F
.54168 .42674 m .54003 .41613 L .54296 .40231 L F
.78661 .29642 m .78839 .29351 L .78974 .29539 L 0 .027 .127 r
F
.78661 .29642 m .78526 .29452 L .78839 .29351 L F
.67596 .3 m .67757 .29705 L .67902 .29891 L 0 .035 .136 r
F
.67596 .3 m .6745 .29818 L .67757 .29705 L F
.84424 .29583 m .84609 .29274 L .84738 .29467 L 0 .026 .125 r
F
.84424 .29583 m .84295 .29391 L .84609 .29274 L F
.11922 .29502 m .11997 .29197 L .12198 .29394 L 0 .025 .123 r
F
.11922 .29502 m .1172 .29305 L .11997 .29197 L F
.35592 .29986 m .35704 .29671 L .35882 .29873 L 0 .034 .135 r
F
.35592 .29986 m .35414 .29785 L .35704 .29671 L F
.68354 .29966 m .68515 .29664 L .68661 .29855 L F
.68354 .29966 m .68209 .29778 L .68515 .29664 L F
.16169 .29526 m .1625 .2922 L .16448 .29415 L 0 .025 .124 r
F
.16169 .29526 m .15971 .29329 L .1625 .2922 L F
.65324 .30137 m .6548 .2982 L .65628 .30008 L 0 .038 .139 r
F
.65324 .30137 m .65175 .2995 L .6548 .2982 L F
.38324 .30098 m .3844 .29777 L .38615 .29991 L 0 .037 .138 r
F
.38324 .30098 m .3815 .29879 L .3844 .29777 L F
.7942 .29616 m .79599 .29322 L .79733 .29505 L 0 .027 .126 r
F
.7942 .29616 m .79286 .29431 L .79599 .29322 L F
.64567 .30184 m .64722 .29873 L .64871 .30079 L 0 .039 .141 r
F
.64567 .30184 m .64417 .29982 L .64722 .29873 L F
.42274 .30395 m .42395 .30078 L .42566 .30301 L 0 .044 .146 r
F
.42274 .30395 m .42103 .30175 L .42395 .30078 L F
.33617 .29849 m .33725 .29543 L .33905 .29748 L 0 .032 .132 r
F
.33617 .29849 m .33437 .29648 L .33725 .29543 L F
.20415 .29554 m .20503 .29255 L .20696 .29447 L 0 .026 .125 r
F
.20415 .29554 m .20222 .2936 L .20503 .29255 L F
.23905 .29619 m .23998 .29317 L .24188 .29512 L 0 .027 .126 r
F
.23905 .29619 m .23715 .29424 L .23998 .29317 L F
.30885 .29745 m .30989 .29435 L .31172 .29633 L 0 .029 .129 r
F
.30885 .29745 m .30702 .29544 L .30989 .29435 L F
.59723 .30713 m .5987 .30365 L .60025 .30592 L 0 .051 .153 r
F
.59723 .30713 m .59568 .30488 L .5987 .30365 L F
.60481 .30672 m .60628 .30303 L .60782 .30525 L 0 .049 .152 r
F
.60481 .30672 m .60326 .30448 L .60628 .30303 L F
.85184 .2956 m .85371 .29261 L .855 .29461 L 0 .026 .125 r
F
.85184 .2956 m .85054 .29361 L .85371 .29261 L F
.80179 .29582 m .80359 .29295 L .80492 .29478 L 0 .027 .126 r
F
.80179 .29582 m .80046 .29399 L .80359 .29295 L F
.36349 .2996 m .36462 .29644 L .36639 .29851 L 0 .034 .135 r
F
.36349 .2996 m .36172 .29757 L .36462 .29644 L F
.16924 .29501 m .17007 .29195 L .17204 .2939 L 0 .025 .123 r
F
.16924 .29501 m .16727 .29305 L .17007 .29195 L F
.63052 .30279 m .63204 .29949 L .63355 .30145 L 0 .041 .143 r
F
.63052 .30279 m .62901 .30086 L .63204 .29949 L F
.5745 .30848 m .57593 .30448 L .5775 .30677 L 0 .053 .156 r
F
.5745 .30848 m .57293 .30619 L .57593 .30448 L F
.69113 .29945 m .69276 .29658 L .69421 .2985 L 0 .034 .135 r
F
.69113 .29945 m .68968 .29753 L .69276 .29658 L F
.27394 .29693 m .27493 .29384 L .27679 .29584 L 0 .029 .128 r
F
.27394 .29693 m .27208 .2949 L .27493 .29384 L F
.4744 .30896 m .47569 .30582 L .47735 .30795 L 0 .057 .159 r
F
.4744 .30896 m .47274 .30679 L .47569 .30582 L F
.21171 .29533 m .21259 .29236 L .21452 .29429 L 0 .026 .125 r
F
.21171 .29533 m .20978 .2934 L .21259 .29236 L F
.12675 .29491 m .1275 .29197 L .12951 .29391 L 0 .025 .124 r
F
.12675 .29491 m .12474 .29296 L .1275 .29197 L F
.31641 .29725 m .31745 .29434 L .31927 .2963 L 0 .03 .13 r
F
.31641 .29725 m .31459 .29528 L .31745 .29434 L F
.39081 .30082 m .39198 .2976 L .39372 .29966 L 0 .037 .138 r
F
.39081 .30082 m .38906 .29876 L .39198 .2976 L F
.71387 .29832 m .71553 .29546 L .71695 .29727 L 0 .032 .132 r
F
.71387 .29832 m .71245 .29651 L .71553 .29546 L F
.49874 .31283 m .50008 .30893 L .50171 .31175 L 0 .066 .168 r
F
.49874 .31283 m .49711 .31004 L .50008 .30893 L F
.72902 .29749 m .7307 .29451 L .73211 .29641 L 0 .03 .13 r
F
.72902 .29749 m .72761 .2956 L .7307 .29451 L F
.70629 .29876 m .70794 .29576 L .70936 .29756 L 0 .033 .133 r
F
.70629 .29876 m .70486 .29695 L .70794 .29576 L F
.44248 .3057 m .44373 .30232 L .44542 .30455 L 0 .048 .15 r
F
.44248 .3057 m .44079 .30347 L .44373 .30232 L F
.5262 .41372 m .52756 .39083 L .52918 .40386 L 0 .408 .231 r
F
.5262 .41372 m .52458 .39903 L .52756 .39083 L F
.55637 .31224 m .55778 .30834 L .55937 .31064 L 0 .064 .166 r
F
.55637 .31224 m .55478 .30983 L .55778 .30834 L F
.72145 .29796 m .72311 .29493 L .72453 .29678 L 0 .031 .131 r
F
.72145 .29796 m .72003 .29613 L .72311 .29493 L F
.2466 .29607 m .24753 .29315 L .24942 .29511 L 0 .027 .127 r
F
.2466 .29607 m .24471 .29412 L .24753 .29315 L F
.41055 .30238 m .41175 .29928 L .41347 .30146 L 0 .04 .142 r
F
.41055 .30238 m .40883 .30017 L .41175 .29928 L F
.50662 .42223 m .50508 .40494 L .50803 .40664 L 0 .442 .184 r
F
.50366 .41986 m .50508 .40494 L .50662 .42223 L 0 .43 .202 r
F
.2815 .29671 m .2825 .29363 L .28436 .29558 L 0 .028 .128 r
F
.2815 .29671 m .27964 .29474 L .2825 .29363 L F
.80939 .2957 m .8112 .29274 L .81253 .2947 L 0 .027 .126 r
F
.80939 .2957 m .80806 .29374 L .8112 .29274 L F
.17679 .29487 m .17762 .29186 L .17958 .29384 L 0 .025 .124 r
F
.17679 .29487 m .17483 .29288 L .17762 .29186 L F
.09182 .29449 m .09252 .29149 L .09457 .29341 L 0 .024 .123 r
F
.09182 .29449 m .08977 .29256 L .09252 .29149 L F
.73661 .29725 m .7383 .29427 L .7397 .29616 L 0 .03 .13 r
F
.73661 .29725 m .7352 .29533 L .7383 .29427 L F
.46222 .30734 m .4635 .30427 L .46517 .30648 L 0 .053 .155 r
F
.46222 .30734 m .46055 .3051 L .4635 .30427 L F
.37105 .29957 m .37219 .29644 L .37395 .29858 L 0 .034 .135 r
F
.37105 .29957 m .36929 .29747 L .37219 .29644 L F
.34372 .29853 m .34481 .29552 L .3466 .29759 L 0 .032 .133 r
F
.34372 .29853 m .34193 .29647 L .34481 .29552 L F
.75934 .29602 m .76108 .2932 L .76246 .29503 L 0 .028 .127 r
F
.75934 .29602 m .75797 .29419 L .76108 .2932 L F
.69873 .2994 m .70036 .29636 L .70179 .29819 L 0 .034 .135 r
F
.69873 .2994 m .69729 .29756 L .70036 .29636 L F
.53364 .31369 m .53502 .30987 L .53663 .31241 L 0 .069 .17 r
F
.53364 .31369 m .53203 .31114 L .53502 .30987 L F
.39837 .30067 m .39954 .29779 L .40128 .29983 L 0 .037 .139 r
F
.39837 .30067 m .39663 .29864 L .39954 .29779 L F
.28906 .29647 m .29008 .29329 L .29192 .29536 L 0 .028 .128 r
F
.28906 .29647 m .28722 .29444 L .29008 .29329 L F
.52333 .48625 m .5247 .513 L .52632 .49705 L .38 .67 0 r
F
.52333 .48625 m .5217 .50054 L .5247 .513 L F
.13429 .29479 m .13506 .29174 L .13707 .29367 L 0 .025 .123 r
F
.13429 .29479 m .13228 .29286 L .13506 .29174 L F
.21925 .29527 m .22015 .29227 L .22206 .29428 L 0 .026 .125 r
F
.21925 .29527 m .21733 .29328 L .22015 .29227 L F
.7442 .29697 m .7459 .29403 L .74729 .29589 L 0 .029 .129 r
F
.7442 .29697 m .7428 .2951 L .7459 .29403 L F
.75177 .29656 m .75349 .29352 L .75487 .29536 L 0 .028 .128 r
F
.75177 .29656 m .75039 .29472 L .75349 .29352 L F
.62296 .30371 m .62447 .30036 L .62598 .30228 L 0 .044 .146 r
F
.62296 .30371 m .62144 .30183 L .62447 .30036 L F
.43029 .30414 m .43151 .30127 L .43322 .30332 L 0 .046 .148 r
F
.43029 .30414 m .42859 .30212 L .43151 .30127 L F
.09937 .29426 m .10008 .29129 L .10212 .29322 L 0 .024 .122 r
F
.09937 .29426 m .09733 .29234 L .10008 .29129 L F
.5488 .313 m .5502 .30886 L .55179 .31132 L 0 .066 .168 r
F
.5488 .313 m .5472 .31045 L .5502 .30886 L F
.14185 .29453 m .14263 .29148 L .14462 .29348 L 0 .025 .123 r
F
.14185 .29453 m .13985 .29255 L .14263 .29148 L F
.18433 .29478 m .18519 .29167 L .18713 .29367 L 0 .025 .124 r
F
.18433 .29478 m .18238 .29278 L .18519 .29167 L F
.76694 .29588 m .76869 .29298 L .77005 .29483 L 0 .028 .127 r
F
.76694 .29588 m .76557 .29404 L .76869 .29298 L F
.817 .29568 m .81882 .29265 L .82014 .29462 L 0 .027 .126 r
F
.817 .29568 m .81568 .2937 L .81882 .29265 L F
.32395 .29736 m .32501 .29441 L .32682 .29641 L 0 .03 .131 r
F
.32395 .29736 m .32214 .29536 L .32501 .29441 L F
.52147 .31209 m .52283 .3086 L .52445 .31096 L 0 .066 .167 r
F
.52147 .31209 m .51985 .30977 L .52283 .3086 L F
.56694 .30957 m .56836 .30575 L .56993 .3079 L 0 .058 .16 r
F
.56694 .30957 m .56536 .30739 L .56836 .30575 L F
.45004 .3058 m .45131 .30224 L .45298 .30467 L 0 .049 .151 r
F
.45004 .3058 m .44836 .3034 L .45131 .30224 L F
.25413 .29614 m .2551 .29299 L .25698 .29502 L 0 .028 .127 r
F
.25413 .29614 m .25225 .29412 L .2551 .29299 L F
.49414 .31106 m .49547 .30736 L .49711 .31004 L 0 .062 .164 r
F
.49414 .31106 m .4925 .30843 L .49547 .30736 L F
.48197 .30919 m .48327 .30583 L .48493 .30816 L 0 .058 .16 r
F
.48197 .30919 m .48031 .30691 L .48327 .30583 L F
.29661 .29641 m .29763 .29338 L .29947 .29545 L 0 .029 .128 r
F
.29661 .29641 m .29478 .29434 L .29763 .29338 L F
.4998 .45676 m .49824 .44438 L .5011 .45813 L .05 .559 0 r
F
.49824 .44438 m .49955 .44381 L .5011 .45813 L 0 .513 .056 r
F
.54122 .31364 m .54261 .30964 L .54421 .31208 L 0 .069 .17 r
F
.54122 .31364 m .53962 .31112 L .54261 .30964 L F
.19188 .29456 m .19274 .29157 L .19468 .29358 L 0 .025 .124 r
F
.19188 .29456 m .18994 .29256 L .19274 .29157 L F
.51389 .31264 m .51525 .30886 L .51687 .31121 L 0 .067 .168 r
F
.51389 .31264 m .51227 .31026 L .51525 .30886 L F
.61539 .30448 m .6169 .3014 L .61842 .30325 L 0 .046 .149 r
F
.61539 .30448 m .61387 .30264 L .6169 .3014 L F
.50631 .31311 m .50766 .309 L .50929 .31168 L 0 .067 .169 r
F
.50631 .31311 m .50468 .31038 L .50766 .309 L F
.77454 .29568 m .77628 .2926 L .77765 .29455 L 0 .027 .126 r
F
.77454 .29568 m .77317 .29371 L .77628 .2926 L F
.1069 .29421 m .10762 .29127 L .10965 .29324 L 0 .025 .123 r
F
.1069 .29421 m .10487 .29225 L .10762 .29127 L F
.8246 .29547 m .82643 .29243 L .82774 .29436 L 0 .027 .126 r
F
.8246 .29547 m .82328 .29353 L .82643 .29243 L F
.14938 .29445 m .15018 .29138 L .15216 .29341 L 0 .025 .123 r
F
.14938 .29445 m .1474 .29243 L .15018 .29138 L F
.26169 .29593 m .26267 .29281 L .26454 .29487 L 0 .028 .127 r
F
.26169 .29593 m .25982 .2939 L .26267 .29281 L F
.22678 .29533 m .22769 .29236 L .22959 .29436 L 0 .027 .126 r
F
.22678 .29533 m .22487 .29332 L .22769 .29236 L F
.51858 .41502 m .51998 .39203 L .52158 .40724 L 0 .412 .225 r
F
.51858 .41502 m .51699 .39837 L .51998 .39203 L F
.53082 .41846 m .53215 .39392 L .53379 .40657 L 0 .42 .216 r
F
.53082 .41846 m .52918 .40386 L .53215 .39392 L F
.58508 .3063 m .58653 .3028 L .58809 .30508 L 0 .05 .153 r
F
.58508 .3063 m .58352 .30401 L .58653 .3028 L F
.4181 .30273 m .41932 .29951 L .42103 .30175 L 0 .042 .144 r
F
.4181 .30273 m .41639 .30052 L .41932 .29951 L F
.35126 .29875 m .35236 .2958 L .35414 .29785 L 0 .034 .135 r
F
.35126 .29875 m .34948 .29669 L .35236 .2958 L F
.37859 .29981 m .37975 .29661 L .3815 .29879 L 0 .036 .137 r
F
.37859 .29981 m .37685 .29759 L .37975 .29661 L F
.5775 .30677 m .57894 .30292 L .58051 .30522 L 0 .051 .153 r
F
.5775 .30677 m .57593 .30448 L .57894 .30292 L F
.8322 .29525 m .83405 .29237 L .83536 .29425 L 0 .027 .126 r
F
.8322 .29525 m .83089 .29336 L .83405 .29237 L F
.78213 .2955 m .78391 .29261 L .78526 .29452 L 0 .027 .127 r
F
.78213 .2955 m .78078 .29357 L .78391 .29261 L F
.3315 .29746 m .33257 .29447 L .33437 .29648 L 0 .031 .132 r
F
.3315 .29746 m .32969 .29545 L .33257 .29447 L F
.46978 .30776 m .47107 .30469 L .47274 .30679 L 0 .055 .158 r
F
.46978 .30776 m .46812 .30561 L .47107 .30469 L F
.60782 .30525 m .6093 .3017 L .61084 .30388 L 0 .048 .15 r
F
.60782 .30525 m .60628 .30303 L .6093 .3017 L F
.59266 .3061 m .59413 .30262 L .59568 .30488 L 0 .05 .153 r
F
.59266 .3061 m .59111 .30385 L .59413 .30262 L F
.40592 .30106 m .4071 .29812 L .40883 .30017 L 0 .039 .141 r
F
.40592 .30106 m .40419 .299 L .4071 .29812 L F
.11443 .29414 m .11518 .29105 L .1172 .29305 L 0 .025 .123 r
F
.11443 .29414 m .11241 .29216 L .11518 .29105 L F
.15692 .29436 m .15774 .29129 L .15971 .29329 L 0 .025 .124 r
F
.15692 .29436 m .15495 .29235 L .15774 .29129 L F
.19942 .29458 m .20028 .29165 L .20222 .2936 L 0 .026 .124 r
F
.19942 .29458 m .19748 .29262 L .20028 .29165 L F
.66386 .29963 m .66545 .29679 L .66692 .29859 L 0 .036 .138 r
F
.66386 .29963 m .66239 .29783 L .66545 .29679 L F
.64112 .30091 m .64267 .29779 L .64417 .29982 L 0 .039 .14 r
F
.64112 .30091 m .63962 .29891 L .64267 .29779 L F
.65628 .30008 m .65785 .297 L .65933 .29887 L 0 .037 .138 r
F
.65628 .30008 m .6548 .2982 L .65785 .297 L F
.54284 .47582 m .54133 .49242 L .54428 .47969 L .169 .603 0 r
F
.53987 .4816 m .54133 .49242 L .54284 .47582 L .264 .635 0 r
F
.26924 .2959 m .27022 .29284 L .27208 .2949 L 0 .028 .128 r
F
.26924 .2959 m .26738 .29386 L .27022 .29284 L F
.30415 .29653 m .30519 .29341 L .30702 .29544 L 0 .029 .129 r
F
.30415 .29653 m .30232 .29448 L .30519 .29341 L F
.4576 .306 m .45888 .30264 L .46055 .3051 L 0 .05 .153 r
F
.4576 .306 m .45593 .30354 L .45888 .30264 L F
.52905 .31231 m .53042 .30864 L .53203 .31114 L 0 .067 .168 r
F
.52905 .31231 m .52744 .30983 L .53042 .30864 L F
.8398 .29508 m .84165 .29205 L .84295 .29391 L 0 .027 .126 r
F
.8398 .29508 m .83851 .29321 L .84165 .29205 L F
.84738 .29467 m .84925 .29167 L .85054 .29361 L 0 .026 .125 r
F
.84738 .29467 m .84609 .29274 L .84925 .29167 L F
.67144 .29929 m .67304 .29633 L .6745 .29818 L 0 .035 .137 r
F
.67144 .29929 m .66998 .29747 L .67304 .29633 L F
.55937 .31064 m .56078 .3068 L .56236 .30903 L 0 .062 .164 r
F
.55937 .31064 m .55778 .30834 L .56078 .3068 L F
.23432 .29531 m .23525 .29229 L .23715 .29424 L 0 .027 .126 r
F
.23432 .29531 m .23242 .29336 L .23525 .29229 L F
.67902 .29891 m .68063 .29589 L .68209 .29778 L 0 .035 .136 r
F
.67902 .29891 m .67757 .29705 L .68063 .29589 L F
.43785 .3046 m .43909 .30138 L .44079 .30347 L 0 .047 .15 r
F
.43785 .3046 m .43615 .30251 L .43909 .30138 L F
.63355 .30145 m .63507 .29812 L .63658 .30012 L 0 .04 .142 r
F
.63355 .30145 m .63204 .29949 L .63507 .29812 L F
.35882 .29873 m .35994 .29555 L .36172 .29757 L 0 .034 .135 r
F
.35882 .29873 m .35704 .29671 L .35994 .29555 L F
.78974 .29539 m .79152 .29245 L .79286 .29431 L 0 .027 .127 r
F
.78974 .29539 m .78839 .29351 L .79152 .29245 L F
.68661 .29855 m .68823 .29559 L .68968 .29753 L 0 .034 .135 r
F
.68661 .29855 m .68515 .29664 L .68823 .29559 L F
.48954 .30949 m .49086 .30603 L .4925 .30843 L 0 .06 .162 r
F
.48954 .30949 m .48789 .30713 L .49086 .30603 L F
.60025 .30592 m .60172 .30223 L .60326 .30448 L 0 .05 .152 r
F
.60025 .30592 m .5987 .30365 L .60172 .30223 L F
.12198 .29394 m .12273 .29098 L .12474 .29296 L 0 .025 .123 r
F
.12198 .29394 m .11997 .29197 L .12273 .29098 L F
.16448 .29415 m .1653 .29109 L .16727 .29305 L F
.16448 .29415 m .1625 .2922 L .1653 .29109 L F
.79733 .29505 m .79912 .29216 L .80046 .29399 L 0 .027 .126 r
F
.79733 .29505 m .79599 .29322 L .79912 .29216 L F
.31172 .29633 m .31276 .29332 L .31459 .29528 L 0 .029 .129 r
F
.31172 .29633 m .30989 .29435 L .31276 .29332 L F
.38615 .29991 m .38732 .29664 L .38906 .29876 L 0 .036 .138 r
F
.38615 .29991 m .3844 .29777 L .38732 .29664 L F
.20696 .29447 m .20784 .29149 L .20978 .2934 L 0 .026 .125 r
F
.20696 .29447 m .20503 .29255 L .20784 .29149 L F
.64871 .30079 m .65026 .29743 L .65175 .2995 L 0 .038 .14 r
F
.64871 .30079 m .64722 .29873 L .65026 .29743 L F
.24188 .29512 m .24281 .29218 L .24471 .29412 L 0 .027 .126 r
F
.24188 .29512 m .23998 .29317 L .24281 .29218 L F
.55179 .31132 m .55319 .30747 L .55478 .30983 L 0 .064 .166 r
F
.55179 .31132 m .5502 .30886 L .55319 .30747 L F
.36639 .29851 m .36752 .29537 L .36929 .29747 L 0 .034 .135 r
F
.36639 .29851 m .36462 .29644 L .36752 .29537 L F
.33905 .29748 m .34014 .29439 L .34193 .29647 L 0 .032 .132 r
F
.33905 .29748 m .33725 .29543 L .34014 .29439 L F
.17204 .2939 m .17286 .29095 L .17483 .29288 L 0 .025 .123 r
F
.17204 .2939 m .17007 .29195 L .17286 .29095 L F
.80492 .29478 m .80673 .2919 L .80806 .29374 L 0 .027 .126 r
F
.80492 .29478 m .80359 .29295 L .80673 .2919 L F
.27679 .29584 m .27778 .29276 L .27964 .29474 L 0 .028 .128 r
F
.27679 .29584 m .27493 .29384 L .27778 .29276 L F
.42566 .30301 m .42688 .29985 L .42859 .30212 L 0 .044 .146 r
F
.42566 .30301 m .42395 .30078 L .42688 .29985 L F
.855 .29461 m .85688 .29162 L .85817 .29362 L 0 .026 .125 r
F
.855 .29461 m .85371 .29261 L .85688 .29162 L F
.39372 .29966 m .39489 .29658 L .39663 .29864 L 0 .036 .138 r
F
.39372 .29966 m .39198 .2976 L .39489 .29658 L F
.70936 .29756 m .71102 .2947 L .71245 .29651 L 0 .032 .133 r
F
.70936 .29756 m .70794 .29576 L .71102 .2947 L F
.56993 .3079 m .57136 .30408 L .57293 .30619 L 0 .055 .157 r
F
.56993 .3079 m .56836 .30575 L .57136 .30408 L F
.44542 .30455 m .44667 .30116 L .44836 .3034 L 0 .047 .15 r
F
.44542 .30455 m .44373 .30232 L .44667 .30116 L F
.72453 .29678 m .7262 .29374 L .72761 .2956 L 0 .03 .131 r
F
.72453 .29678 m .72311 .29493 L .7262 .29374 L F
.47735 .30795 m .47865 .30478 L .48031 .30691 L 0 .057 .159 r
F
.47735 .30795 m .47569 .30582 L .47865 .30478 L F
.21452 .29429 m .21541 .29133 L .21733 .29328 L 0 .026 .125 r
F
.21452 .29429 m .21259 .29236 L .21541 .29133 L F
.62598 .30228 m .62749 .29891 L .62901 .30086 L 0 .042 .144 r
F
.62598 .30228 m .62447 .30036 L .62749 .29891 L F
.50171 .31175 m .50305 .30762 L .50468 .31038 L 0 .065 .167 r
F
.50171 .31175 m .50008 .30893 L .50305 .30762 L F
.69421 .2985 m .69584 .29564 L .69729 .29756 L 0 .034 .136 r
F
.69421 .2985 m .69276 .29658 L .69584 .29564 L F
.73211 .29641 m .7338 .29341 L .7352 .29533 L 0 .03 .13 r
F
.73211 .29641 m .7307 .29451 L .7338 .29341 L F
.28436 .29558 m .28536 .29249 L .28722 .29444 L 0 .028 .128 r
F
.28436 .29558 m .2825 .29363 L .28536 .29249 L F
.53663 .31241 m .53801 .3086 L .53962 .31112 L 0 .068 .169 r
F
.53663 .31241 m .53502 .30987 L .53801 .3086 L F
.71695 .29727 m .71862 .2943 L .72003 .29613 L 0 .032 .132 r
F
.71695 .29727 m .71553 .29546 L .71862 .2943 L F
.12951 .29391 m .13027 .29092 L .13228 .29286 L 0 .025 .124 r
F
.12951 .29391 m .1275 .29197 L .13027 .29092 L F
.70179 .29819 m .70343 .29514 L .70486 .29695 L 0 .034 .135 r
F
.70179 .29819 m .70036 .29636 L .70343 .29514 L F
.31927 .2963 m .32032 .2934 L .32214 .29536 L 0 .03 .13 r
F
.31927 .2963 m .31745 .29434 L .32032 .2934 L F
.54421 .31208 m .5456 .30811 L .5472 .31045 L 0 .066 .168 r
F
.54421 .31208 m .54261 .30964 L .5456 .30811 L F
.09457 .29341 m .09528 .29041 L .09733 .29234 L 0 .024 .123 r
F
.09457 .29341 m .09252 .29149 L .09528 .29041 L F
.24942 .29511 m .25036 .29217 L .25225 .29412 L 0 .028 .127 r
F
.24942 .29511 m .24753 .29315 L .25036 .29217 L F
.17958 .29384 m .18042 .2908 L .18238 .29278 L 0 .025 .124 r
F
.17958 .29384 m .17762 .29186 L .18042 .2908 L F
.7397 .29616 m .74141 .29322 L .7428 .2951 L 0 .03 .13 r
F
.7397 .29616 m .7383 .29427 L .74141 .29322 L F
.81253 .2947 m .81435 .29174 L .81568 .2937 L 0 .027 .126 r
F
.81253 .2947 m .8112 .29274 L .81435 .29174 L F
.29192 .29536 m .29294 .29227 L .29478 .29434 L 0 .028 .127 r
F
.29192 .29536 m .29008 .29329 L .29294 .29227 L F
.75487 .29536 m .75659 .29236 L .75797 .29419 L 0 .028 .128 r
F
.75487 .29536 m .75349 .29352 L .75659 .29236 L F
.13707 .29367 m .13785 .29063 L .13985 .29255 L 0 .025 .123 r
F
.13707 .29367 m .13506 .29174 L .13785 .29063 L F
.41347 .30146 m .41467 .29835 L .41639 .30052 L 0 .041 .143 r
F
.41347 .30146 m .41175 .29928 L .41467 .29835 L F
.37395 .29858 m .37509 .29544 L .37685 .29759 L 0 .035 .136 r
F
.37395 .29858 m .37219 .29644 L .37509 .29544 L F
.51687 .31121 m .51823 .30745 L .51985 .30977 L 0 .065 .167 r
F
.51687 .31121 m .51525 .30886 L .51823 .30745 L F
.76246 .29503 m .7642 .29221 L .76557 .29404 L 0 .028 .127 r
F
.76246 .29503 m .76108 .2932 L .7642 .29221 L F
.74729 .29589 m .749 .29287 L .75039 .29472 L 0 .029 .129 r
F
.74729 .29589 m .7459 .29403 L .749 .29287 L F
.5472 .46622 m .54569 .47878 L .5486 .4635 L .07 .567 0 r
F
.54428 .47969 m .54569 .47878 L .5472 .46622 L .217 .619 0 r
F
.3466 .29759 m .34769 .29463 L .34948 .29669 L 0 .033 .134 r
F
.3466 .29759 m .34481 .29552 L .34769 .29463 L F
.50929 .31168 m .51064 .30764 L .51227 .31026 L 0 .066 .167 r
F
.50929 .31168 m .50766 .309 L .51064 .30764 L F
.10212 .29322 m .10283 .29032 L .10487 .29225 L 0 .024 .123 r
F
.10212 .29322 m .10008 .29129 L .10283 .29032 L F
.22206 .29428 m .22296 .29131 L .22487 .29332 L 0 .026 .125 r
F
.22206 .29428 m .22015 .29227 L .22296 .29131 L F
.58051 .30522 m .58195 .30172 L .58352 .30401 L 0 .05 .152 r
F
.58051 .30522 m .57894 .30292 L .58195 .30172 L F
.46517 .30648 m .46645 .30344 L .46812 .30561 L 0 .054 .156 r
F
.46517 .30648 m .4635 .30427 L .46645 .30344 L F
.18713 .29367 m .188 .29055 L .18994 .29256 L 0 .025 .123 r
F
.18713 .29367 m .18519 .29167 L .188 .29055 L F
.14462 .29348 m .14542 .29041 L .1474 .29243 L F
.14462 .29348 m .14263 .29148 L .14542 .29041 L F
.52445 .31096 m .52582 .30742 L .52744 .30983 L 0 .065 .167 r
F
.52445 .31096 m .52283 .3086 L .52582 .30742 L F
.40128 .29983 m .40246 .29693 L .40419 .299 L 0 .038 .14 r
F
.40128 .29983 m .39954 .29779 L .40246 .29693 L F
.45298 .30467 m .45426 .30108 L .45593 .30354 L 0 .048 .151 r
F
.45298 .30467 m .45131 .30224 L .45426 .30108 L F
.25698 .29502 m .25795 .29186 L .25982 .2939 L 0 .027 .127 r
F
.25698 .29502 m .2551 .29299 L .25795 .29186 L F
.77005 .29483 m .7718 .29185 L .77317 .29371 L F
.77005 .29483 m .76869 .29298 L .7718 .29185 L F
.82014 .29462 m .82196 .29157 L .82328 .29353 L 0 .027 .126 r
F
.82014 .29462 m .81882 .29265 L .82196 .29157 L F
.61842 .30325 m .61992 .29994 L .62144 .30183 L 0 .045 .148 r
F
.61842 .30325 m .6169 .3014 L .61992 .29994 L F
.49711 .31004 m .49844 .30624 L .50008 .30893 L 0 .062 .164 r
F
.49711 .31004 m .49547 .30736 L .49844 .30624 L F
.48493 .30816 m .48624 .30476 L .48789 .30713 L 0 .058 .16 r
F
.48493 .30816 m .48327 .30583 L .48624 .30476 L F
.43322 .30332 m .43444 .30041 L .43615 .30251 L 0 .046 .149 r
F
.43322 .30332 m .43151 .30127 L .43444 .30041 L F
.56236 .30903 m .56378 .30521 L .56536 .30739 L 0 .059 .161 r
F
.56236 .30903 m .56078 .3068 L .56378 .30521 L F
.32682 .29641 m .32788 .29346 L .32969 .29545 L 0 .031 .131 r
F
.32682 .29641 m .32501 .29441 L .32788 .29346 L F
.77765 .29455 m .77941 .29165 L .78078 .29357 L 0 .027 .126 r
F
.77765 .29455 m .77628 .2926 L .77941 .29165 L F
.58809 .30508 m .58955 .30157 L .59111 .30385 L 0 .05 .152 r
F
.58809 .30508 m .58653 .3028 L .58955 .30157 L F
.82774 .29436 m .82959 .29144 L .83089 .29336 L 0 .027 .126 r
F
.82774 .29436 m .82643 .29243 L .82959 .29144 L F
.29947 .29545 m .30049 .29242 L .30232 .29448 L 0 .029 .129 r
F
.29947 .29545 m .29763 .29338 L .30049 .29242 L F
.61084 .30388 m .61233 .3005 L .61387 .30264 L 0 .047 .149 r
F
.61084 .30388 m .6093 .3017 L .61233 .3005 L F
.19468 .29358 m .19554 .29061 L .19748 .29262 L 0 .025 .124 r
F
.19468 .29358 m .19274 .29157 L .19554 .29061 L F
.26454 .29487 m .26551 .29178 L .26738 .29386 L 0 .028 .127 r
F
.26454 .29487 m .26267 .29281 L .26551 .29178 L F
.15216 .29341 m .15297 .29032 L .15495 .29235 L 0 .025 .123 r
F
.15216 .29341 m .15018 .29138 L .15297 .29032 L F
.10965 .29324 m .11039 .29018 L .11241 .29216 L F
.10965 .29324 m .10762 .29127 L .11039 .29018 L F
.22959 .29436 m .23051 .29135 L .23242 .29336 L 0 .027 .126 r
F
.22959 .29436 m .22769 .29236 L .23051 .29135 L F
.59568 .30488 m .59715 .30137 L .5987 .30365 L 0 .049 .152 r
F
.59568 .30488 m .59413 .30262 L .59715 .30137 L F
.3815 .29879 m .38265 .29561 L .3844 .29777 L 0 .036 .137 r
F
.3815 .29879 m .37975 .29661 L .38265 .29561 L F
.60326 .30448 m .60474 .30082 L .60628 .30303 L 0 .048 .151 r
F
.60326 .30448 m .60172 .30223 L .60474 .30082 L F
.42103 .30175 m .42225 .29849 L .42395 .30078 L 0 .042 .145 r
F
.42103 .30175 m .41932 .29951 L .42225 .29849 L F
.57293 .30619 m .57436 .30241 L .57593 .30448 L 0 .052 .155 r
F
.57293 .30619 m .57136 .30408 L .57436 .30241 L F
.63658 .30012 m .63811 .29689 L .63962 .29891 L 0 .039 .141 r
F
.63658 .30012 m .63507 .29812 L .63811 .29689 L F
.65933 .29887 m .66091 .29595 L .66239 .29783 L 0 .037 .138 r
F
.65933 .29887 m .65785 .297 L .66091 .29595 L F
.83536 .29425 m .83721 .29135 L .83851 .29321 L 0 .027 .126 r
F
.83536 .29425 m .83405 .29237 L .83721 .29135 L F
.55478 .30983 m .55619 .30608 L .55778 .30834 L 0 .062 .164 r
F
.55478 .30983 m .55319 .30747 L .55619 .30608 L F
.35414 .29785 m .35526 .29467 L .35704 .29671 L 0 .034 .135 r
F
.35414 .29785 m .35236 .2958 L .35526 .29467 L F
.1172 .29305 m .11795 .28996 L .11997 .29197 L 0 .024 .123 r
F
.1172 .29305 m .11518 .29105 L .11795 .28996 L F
.78526 .29452 m .78704 .29162 L .78839 .29351 L 0 .028 .127 r
F
.78526 .29452 m .78391 .29261 L .78704 .29162 L F
.53203 .31114 m .53341 .30735 L .53502 .30987 L 0 .066 .168 r
F
.53203 .31114 m .53042 .30864 L .53341 .30735 L F
.84295 .29391 m .8448 .29088 L .84609 .29274 L 0 .026 .125 r
F
.84295 .29391 m .84165 .29205 L .8448 .29088 L F
.15971 .29329 m .16053 .2902 L .1625 .2922 L 0 .025 .123 r
F
.15971 .29329 m .15774 .29129 L .16053 .2902 L F
.64417 .29982 m .64571 .29667 L .64722 .29873 L 0 .038 .14 r
F
.64417 .29982 m .64267 .29779 L .64571 .29667 L F
.33437 .29648 m .33545 .29339 L .33725 .29543 L 0 .031 .132 r
F
.33437 .29648 m .33257 .29447 L .33545 .29339 L F
.66692 .29859 m .66851 .29565 L .66998 .29747 L 0 .036 .137 r
F
.66692 .29859 m .66545 .29679 L .66851 .29565 L F
.47274 .30679 m .47403 .30375 L .47569 .30582 L 0 .056 .158 r
F
.47274 .30679 m .47107 .30469 L .47403 .30375 L F
.30702 .29544 m .30806 .29233 L .30989 .29435 L 0 .029 .129 r
F
.30702 .29544 m .30519 .29341 L .30806 .29233 L F
.6745 .29818 m .6761 .29518 L .67757 .29705 L 0 .035 .136 r
F
.6745 .29818 m .67304 .29633 L .6761 .29518 L F
.68209 .29778 m .6837 .29473 L .68515 .29664 L 0 .034 .135 r
F
.68209 .29778 m .68063 .29589 L .6837 .29473 L F
.36172 .29757 m .36285 .2944 L .36462 .29644 L 0 .033 .134 r
F
.36172 .29757 m .35994 .29555 L .36285 .2944 L F
.44079 .30347 m .44203 .30025 L .44373 .30232 L 0 .047 .149 r
F
.44079 .30347 m .43909 .30138 L .44203 .30025 L F
.20222 .2936 m .20309 .29062 L .20503 .29255 L 0 .026 .125 r
F
.20222 .2936 m .20028 .29165 L .20309 .29062 L F
.85054 .29361 m .85242 .29068 L .85371 .29261 L F
.85054 .29361 m .84925 .29167 L .85242 .29068 L F
.65175 .2995 m .6533 .29612 L .6548 .2982 L 0 .037 .139 r
F
.65175 .2995 m .65026 .29743 L .6533 .29612 L F
.23715 .29424 m .23808 .29121 L .23998 .29317 L 0 .027 .126 r
F
.23715 .29424 m .23525 .29229 L .23808 .29121 L F
.5472 .31045 m .5486 .30662 L .5502 .30886 L 0 .064 .166 r
F
.5472 .31045 m .5456 .30811 L .5486 .30662 L F
.27208 .2949 m .27307 .2918 L .27493 .29384 L 0 .028 .128 r
F
.27208 .2949 m .27022 .29284 L .27307 .2918 L F
.40883 .30017 m .41002 .29723 L .41175 .29928 L 0 .04 .142 r
F
.40883 .30017 m .4071 .29812 L .41002 .29723 L F
.79286 .29431 m .79465 .29138 L .79599 .29322 L 0 .027 .127 r
F
.79286 .29431 m .79152 .29245 L .79465 .29138 L F
.16727 .29305 m .1681 .28999 L .17007 .29195 L 0 .025 .123 r
F
.16727 .29305 m .1653 .29109 L .1681 .28999 L F
.4925 .30843 m .49383 .30493 L .49547 .30736 L 0 .059 .162 r
F
.4925 .30843 m .49086 .30603 L .49383 .30493 L F
.62901 .30086 m .63053 .29751 L .63204 .29949 L 0 .041 .143 r
F
.62901 .30086 m .62749 .29891 L .63053 .29751 L F
.38906 .29876 m .39024 .29551 L .39198 .2976 L 0 .036 .137 r
F
.38906 .29876 m .38732 .29664 L .39024 .29551 L F
.46055 .3051 m .46183 .30182 L .4635 .30427 L 0 .051 .154 r
F
.46055 .3051 m .45888 .30264 L .46183 .30182 L F
.68968 .29753 m .69131 .29461 L .69276 .29658 L 0 .034 .135 r
F
.68968 .29753 m .68823 .29559 L .69131 .29461 L F
.50468 .31038 m .50603 .3063 L .50766 .309 L 0 .064 .165 r
F
.50468 .31038 m .50305 .30762 L .50603 .3063 L F
.80046 .29399 m .80226 .29111 L .80359 .29295 L 0 .027 .126 r
F
.80046 .29399 m .79912 .29216 L .80226 .29111 L F
.12474 .29296 m .12549 .28999 L .1275 .29197 L 0 .025 .123 r
F
.12474 .29296 m .12273 .29098 L .12549 .28999 L F
.31459 .29528 m .31563 .29238 L .31745 .29434 L 0 .029 .129 r
F
.31459 .29528 m .31276 .29332 L .31563 .29238 L F
.20978 .2934 m .21066 .29046 L .21259 .29236 L 0 .026 .125 r
F
.20978 .2934 m .20784 .29149 L .21066 .29046 L F
.51413 .48466 m .5154 .51141 L .51707 .49974 L .38 .67 0 r
F
.51413 .48466 m .51246 .49467 L .5154 .51141 L F
.53962 .31112 m .54101 .3072 L .54261 .30964 L 0 .066 .168 r
F
.53962 .31112 m .53801 .3086 L .54101 .3072 L F
.36929 .29747 m .37043 .29429 L .37219 .29644 L 0 .034 .135 r
F
.36929 .29747 m .36752 .29537 L .37043 .29429 L F
.27964 .29474 m .28064 .29168 L .2825 .29363 L 0 .028 .128 r
F
.27964 .29474 m .27778 .29276 L .28064 .29168 L F
.24471 .29412 m .24564 .29122 L .24753 .29315 L 0 .027 .127 r
F
.24471 .29412 m .24281 .29218 L .24564 .29122 L F
.72761 .2956 m .72929 .29261 L .7307 .29451 L 0 .03 .13 r
F
.72761 .2956 m .7262 .29374 L .72929 .29261 L F
.17483 .29288 m .17565 .28995 L .17762 .29186 L 0 .025 .123 r
F
.17483 .29288 m .17286 .29095 L .17565 .28995 L F
.44836 .3034 m .44962 .29999 L .45131 .30224 L 0 .047 .149 r
F
.44836 .3034 m .44667 .30116 L .44962 .29999 L F
.34193 .29647 m .34302 .29342 L .34481 .29552 L 0 .032 .132 r
F
.34193 .29647 m .34014 .29439 L .34302 .29342 L F
.80806 .29374 m .80988 .2909 L .8112 .29274 L 0 .027 .126 r
F
.80806 .29374 m .80673 .2919 L .80988 .2909 L F
.71245 .29651 m .71411 .29364 L .71553 .29546 L 0 .032 .133 r
F
.71245 .29651 m .71102 .2947 L .71411 .29364 L F
.51985 .30977 m .52121 .30622 L .52283 .3086 L 0 .064 .166 r
F
.51985 .30977 m .51823 .30745 L .52121 .30622 L F
.70486 .29695 m .70651 .29395 L .70794 .29576 L 0 .033 .134 r
F
.70486 .29695 m .70343 .29514 L .70651 .29395 L F
.39663 .29864 m .3978 .29571 L .39954 .29779 L 0 .037 .138 r
F
.39663 .29864 m .39489 .29658 L .3978 .29571 L F
.28722 .29444 m .28823 .29135 L .29008 .29329 L 0 .028 .127 r
F
.28722 .29444 m .28536 .29249 L .28823 .29135 L F
.72003 .29613 m .7217 .29309 L .72311 .29493 L 0 .031 .132 r
F
.72003 .29613 m .71862 .2943 L .7217 .29309 L F
.08977 .29256 m .09047 .28955 L .09252 .29149 L 0 .024 .123 r
F
.08977 .29256 m .08772 .29062 L .09047 .28955 L F
.51227 .31026 m .51362 .3063 L .51525 .30886 L 0 .064 .166 r
F
.51227 .31026 m .51064 .30764 L .51362 .3063 L F
.7352 .29533 m .7369 .29233 L .7383 .29427 L 0 .03 .13 r
F
.7352 .29533 m .7338 .29341 L .7369 .29233 L F
.48031 .30691 m .48162 .30366 L .48327 .30583 L 0 .056 .159 r
F
.48031 .30691 m .47865 .30478 L .48162 .30366 L F
.54333 .43681 m .54459 .41129 L .54623 .41983 L 0 .47 .139 r
F
.54333 .43681 m .54168 .42674 L .54459 .41129 L F
.13228 .29286 m .13305 .28981 L .13506 .29174 L 0 .025 .123 r
F
.13228 .29286 m .13027 .29092 L .13305 .28981 L F
.21733 .29328 m .21823 .29031 L .22015 .29227 L 0 .026 .125 r
F
.21733 .29328 m .21541 .29133 L .21823 .29031 L F
.42859 .30212 m .42981 .29896 L .43151 .30127 L 0 .045 .147 r
F
.42859 .30212 m .42688 .29985 L .42981 .29896 L F
.56536 .30739 m .56678 .30363 L .56836 .30575 L 0 .057 .159 r
F
.56536 .30739 m .56378 .30521 L .56678 .30363 L F
.51873 .48726 m .52005 .51475 L .5217 .50054 L .409 .678 0 r
F
.51873 .48726 m .51707 .49974 L .52005 .51475 L F
.69729 .29756 m .69892 .29444 L .70036 .29636 L 0 .034 .135 r
F
.69729 .29756 m .69584 .29564 L .69892 .29444 L F
.75797 .29419 m .75971 .29137 L .76108 .2932 L 0 .028 .127 r
F
.75797 .29419 m .75659 .29236 L .75971 .29137 L F
.09733 .29234 m .09804 .28938 L .10008 .29129 L 0 .024 .122 r
F
.09733 .29234 m .09528 .29041 L .09804 .28938 L F
.13985 .29255 m .14063 .28956 L .14263 .29148 L 0 .025 .123 r
F
.13985 .29255 m .13785 .29063 L .14063 .28956 L F
.62144 .30183 m .62295 .29844 L .62447 .30036 L 0 .044 .146 r
F
.62144 .30183 m .61992 .29994 L .62295 .29844 L F
.18238 .29278 m .18323 .28968 L .18519 .29167 L 0 .025 .123 r
F
.18238 .29278 m .18042 .2908 L .18323 .28968 L F
.7428 .2951 m .74451 .29218 L .7459 .29403 L 0 .03 .13 r
F
.7428 .2951 m .74141 .29322 L .74451 .29218 L F
.75039 .29472 m .7521 .29168 L .75349 .29352 L 0 .029 .129 r
F
.75039 .29472 m .749 .29287 L .7521 .29168 L F
.32214 .29536 m .32319 .29247 L .32501 .29441 L 0 .03 .13 r
F
.32214 .29536 m .32032 .2934 L .32319 .29247 L F
.81568 .2937 m .81749 .29071 L .81882 .29265 L 0 .027 .126 r
F
.81568 .2937 m .81435 .29174 L .81749 .29071 L F
.25225 .29412 m .25321 .29104 L .2551 .29299 L 0 .028 .127 r
F
.25225 .29412 m .25036 .29217 L .25321 .29104 L F
.58352 .30401 m .58497 .30052 L .58653 .3028 L 0 .049 .151 r
F
.58352 .30401 m .58195 .30172 L .58497 .30052 L F
.29478 .29434 m .2958 .29131 L .29763 .29338 L 0 .028 .128 r
F
.29478 .29434 m .29294 .29227 L .2958 .29131 L F
.57593 .30448 m .57737 .30089 L .57894 .30292 L 0 .05 .152 r
F
.57593 .30448 m .57436 .30241 L .57737 .30089 L F
.41639 .30052 m .4176 .29729 L .41932 .29951 L 0 .041 .143 r
F
.41639 .30052 m .41467 .29835 L .4176 .29729 L F
.37685 .29759 m .37799 .29446 L .37975 .29661 L 0 .035 .136 r
F
.37685 .29759 m .37509 .29544 L .37799 .29446 L F
.18994 .29256 m .1908 .28956 L .19274 .29157 L 0 .025 .123 r
F
.18994 .29256 m .188 .29055 L .1908 .28956 L F
.76557 .29404 m .76732 .29113 L .76869 .29298 L 0 .028 .127 r
F
.76557 .29404 m .7642 .29221 L .76732 .29113 L F
.52744 .30983 m .52881 .30617 L .53042 .30864 L 0 .064 .166 r
F
.52744 .30983 m .52582 .30742 L .52881 .30617 L F
.45593 .30354 m .4572 .30018 L .45888 .30264 L 0 .048 .151 r
F
.45593 .30354 m .45426 .30108 L .4572 .30018 L F
.54976 .44805 m .54819 .45031 L .55106 .4319 L 0 .507 .069 r
F
.54819 .45031 m .54947 .4301 L .55106 .4319 L 0 .514 .054 r
F
.25982 .2939 m .2608 .29076 L .26267 .29281 L 0 .027 .127 r
F
.25982 .2939 m .25795 .29186 L .2608 .29076 L F
.1474 .29243 m .1482 .28934 L .15018 .29138 L 0 .025 .123 r
F
.1474 .29243 m .14542 .29041 L .1482 .28934 L F
.77317 .29371 m .77492 .29072 L .77628 .2926 L 0 .027 .126 r
F
.77317 .29371 m .7718 .29185 L .77492 .29072 L F
.10487 .29225 m .10558 .28934 L .10762 .29127 L 0 .024 .123 r
F
.10487 .29225 m .10283 .29032 L .10558 .28934 L F
.82328 .29353 m .82511 .29049 L .82643 .29243 L 0 .027 .126 r
F
.82328 .29353 m .82196 .29157 L .82511 .29049 L F
.22487 .29332 m .22578 .29035 L .22769 .29236 L 0 .026 .126 r
F
.22487 .29332 m .22296 .29131 L .22578 .29035 L F
.34948 .29669 m .35058 .29374 L .35236 .2958 L 0 .033 .134 r
F
.34948 .29669 m .34769 .29463 L .35058 .29374 L F
.59111 .30385 m .59257 .30033 L .59413 .30262 L 0 .049 .151 r
F
.59111 .30385 m .58955 .30157 L .59257 .30033 L F
.60628 .30303 m .60776 .29952 L .6093 .3017 L 0 .047 .149 r
F
.60628 .30303 m .60474 .30082 L .60776 .29952 L F
.50008 .30893 m .50142 .30498 L .50305 .30762 L 0 .061 .163 r
F
.50008 .30893 m .49844 .30624 L .50142 .30498 L F
.61387 .30264 m .61536 .2993 L .6169 .3014 L 0 .046 .149 r
F
.61387 .30264 m .61233 .3005 L .61536 .2993 L F
.55778 .30834 m .55919 .30461 L .56078 .3068 L 0 .06 .162 r
F
.55778 .30834 m .55619 .30608 L .55919 .30461 L F
.46812 .30561 m .4694 .30255 L .47107 .30469 L 0 .054 .157 r
F
.46812 .30561 m .46645 .30344 L .4694 .30255 L F
.48789 .30713 m .48921 .30364 L .49086 .30603 L 0 .058 .16 r
F
.48789 .30713 m .48624 .30476 L .48921 .30364 L F
.53987 .4816 m .53835 .49901 L .54133 .49242 L .264 .635 0 r
F
.5369 .48739 m .53835 .49901 L .53987 .4816 L .33 .655 0 r
F
.5502 .30886 m .5516 .30532 L .55319 .30747 L 0 .062 .164 r
F
.5502 .30886 m .5486 .30662 L .5516 .30532 L F
.40419 .299 m .40537 .29606 L .4071 .29812 L 0 .039 .14 r
F
.40419 .299 m .40246 .29693 L .40537 .29606 L F
.5987 .30365 m .60017 .29999 L .60172 .30223 L 0 .048 .151 r
F
.5987 .30365 m .59715 .30137 L .60017 .29999 L F
.32969 .29545 m .33076 .29248 L .33257 .29447 L 0 .031 .131 r
F
.32969 .29545 m .32788 .29346 L .33076 .29248 L F
.83089 .29336 m .83275 .29048 L .83405 .29237 L 0 .027 .126 r
F
.83089 .29336 m .82959 .29144 L .83275 .29048 L F
.78078 .29357 m .78255 .2907 L .78391 .29261 L 0 .027 .127 r
F
.78078 .29357 m .77941 .29165 L .78255 .2907 L F
.15495 .29235 m .15576 .28927 L .15774 .29129 L 0 .025 .123 r
F
.15495 .29235 m .15297 .29032 L .15576 .28927 L F
.11241 .29216 m .11316 .28905 L .11518 .29105 L 0 .024 .123 r
F
.11241 .29216 m .11039 .29018 L .11316 .28905 L F
.30232 .29448 m .30336 .29135 L .30519 .29341 L 0 .029 .129 r
F
.30232 .29448 m .30049 .29242 L .30336 .29135 L F
.26738 .29386 m .26836 .29074 L .27022 .29284 L 0 .028 .127 r
F
.26738 .29386 m .26551 .29178 L .26836 .29074 L F
.63962 .29891 m .64116 .29574 L .64267 .29779 L 0 .038 .14 r
F
.63962 .29891 m .63811 .29689 L .64116 .29574 L F
.53502 .30987 m .53641 .30606 L .53801 .3086 L 0 .065 .167 r
F
.53502 .30987 m .53341 .30735 L .53641 .30606 L F
.43615 .30251 m .43739 .2993 L .43909 .30138 L 0 .047 .149 r
F
.43615 .30251 m .43444 .30041 L .43739 .2993 L F
.19748 .29262 m .19834 .28964 L .20028 .29165 L 0 .026 .124 r
F
.19748 .29262 m .19554 .29061 L .19834 .28964 L F
.35704 .29671 m .35816 .29353 L .35994 .29555 L 0 .034 .134 r
F
.35704 .29671 m .35526 .29467 L .35816 .29353 L F
.3844 .29777 m .38557 .29452 L .38732 .29664 L 0 .036 .137 r
F
.3844 .29777 m .38265 .29561 L .38557 .29452 L F
.23242 .29336 m .23334 .29026 L .23525 .29229 L 0 .027 .126 r
F
.23242 .29336 m .23051 .29135 L .23334 .29026 L F
.6548 .2982 m .65636 .29491 L .65785 .297 L 0 .037 .138 r
F
.6548 .2982 m .6533 .29612 L .65636 .29491 L F
.84609 .29274 m .84796 .28982 L .84925 .29167 L 0 .026 .125 r
F
.84609 .29274 m .8448 .29088 L .84796 .28982 L F
.51558 .41933 m .51699 .39837 L .51858 .41502 L 0 .431 .201 r
F
.51558 .41933 m .514 .40202 L .51699 .39837 L F
.63204 .29949 m .63356 .2961 L .63507 .29812 L 0 .039 .141 r
F
.63204 .29949 m .63053 .29751 L .63356 .2961 L F
.66239 .29783 m .66397 .29491 L .66545 .29679 L 0 .037 .138 r
F
.66239 .29783 m .66091 .29595 L .66397 .29491 L F
.42395 .30078 m .42518 .29753 L .42688 .29985 L 0 .043 .145 r
F
.42395 .30078 m .42225 .29849 L .42518 .29753 L F
.50959 .42462 m .50803 .40664 L .51101 .40567 L 0 .448 .175 r
F
.50662 .42223 m .50803 .40664 L .50959 .42462 L 0 .442 .184 r
F
.83851 .29321 m .84036 .29019 L .84165 .29205 L 0 .027 .126 r
F
.83851 .29321 m .83721 .29135 L .84036 .29019 L F
.50766 .309 m .50901 .305 L .51064 .30764 L 0 .062 .164 r
F
.50766 .309 m .50603 .3063 L .50901 .305 L F
.11997 .29197 m .12072 .28896 L .12273 .29098 L 0 .024 .123 r
F
.11997 .29197 m .11795 .28996 L .12072 .28896 L F
.54261 .30964 m .544 .30577 L .5456 .30811 L 0 .064 .166 r
F
.54261 .30964 m .54101 .3072 L .544 .30577 L F
.1625 .2922 m .16333 .2891 L .1653 .29109 L 0 .025 .123 r
F
.1625 .2922 m .16053 .2902 L .16333 .2891 L F
.64722 .29873 m .64876 .29535 L .65026 .29743 L 0 .038 .139 r
F
.64722 .29873 m .64571 .29667 L .64876 .29535 L F
.66998 .29747 m .67157 .29447 L .67304 .29633 L 0 .036 .137 r
F
.66998 .29747 m .66851 .29565 L .67157 .29447 L F
.67757 .29705 m .67917 .29398 L .68063 .29589 L 0 .035 .136 r
F
.67757 .29705 m .6761 .29518 L .67917 .29398 L F
.44373 .30232 m .44498 .2991 L .44667 .30116 L 0 .046 .149 r
F
.44373 .30232 m .44203 .30025 L .44498 .2991 L F
.68515 .29664 m .68677 .29364 L .68823 .29559 L 0 .034 .135 r
F
.68515 .29664 m .6837 .29473 L .68677 .29364 L F
.36462 .29644 m .36575 .2933 L .36752 .29537 L 0 .033 .134 r
F
.36462 .29644 m .36285 .2944 L .36575 .2933 L F
.30989 .29435 m .31093 .2913 L .31276 .29332 L 0 .029 .129 r
F
.30989 .29435 m .30806 .29233 L .31093 .2913 L F
.78839 .29351 m .79017 .29057 L .79152 .29245 L 0 .028 .127 r
F
.78839 .29351 m .78704 .29162 L .79017 .29057 L F
.33725 .29543 m .33834 .29231 L .34014 .29439 L 0 .031 .132 r
F
.33725 .29543 m .33545 .29339 L .33834 .29231 L F
.56836 .30575 m .56979 .30202 L .57136 .30408 L 0 .054 .157 r
F
.56836 .30575 m .56678 .30363 L .56979 .30202 L F
.23998 .29317 m .24091 .29023 L .24281 .29218 L 0 .027 .126 r
F
.23998 .29317 m .23808 .29121 L .24091 .29023 L F
.20503 .29255 m .2059 .28959 L .20784 .29149 L 0 .026 .125 r
F
.20503 .29255 m .20309 .29062 L .2059 .28959 L F
.39198 .2976 m .39315 .2945 L .39489 .29658 L 0 .036 .137 r
F
.39198 .2976 m .39024 .29551 L .39315 .2945 L F
.47569 .30582 m .47699 .30271 L .47865 .30478 L 0 .056 .158 r
F
.47569 .30582 m .47403 .30375 L .47699 .30271 L F
.27493 .29384 m .27592 .29076 L .27778 .29276 L 0 .028 .128 r
F
.27493 .29384 m .27307 .2918 L .27592 .29076 L F
.17007 .29195 m .17089 .28901 L .17286 .29095 L 0 .025 .123 r
F
.17007 .29195 m .1681 .28999 L .17089 .28901 L F
.79599 .29322 m .79779 .29032 L .79912 .29216 L 0 .027 .127 r
F
.79599 .29322 m .79465 .29138 L .79779 .29032 L F
.85371 .29261 m .85559 .28968 L .85688 .29162 L 0 .026 .125 r
F
.85371 .29261 m .85242 .29068 L .85559 .28968 L F
.49547 .30736 m .4968 .30381 L .49844 .30624 L 0 .059 .161 r
F
.49547 .30736 m .49383 .30493 L .4968 .30381 L F
.51525 .30886 m .5166 .30495 L .51823 .30745 L 0 .062 .165 r
F
.51525 .30886 m .51362 .3063 L .5166 .30495 L F
.80359 .29295 m .8054 .29006 L .80673 .2919 L 0 .027 .126 r
F
.80359 .29295 m .80226 .29111 L .8054 .29006 L F
.41175 .29928 m .41295 .2963 L .41467 .29835 L 0 .04 .142 r
F
.41175 .29928 m .41002 .29723 L .41295 .2963 L F
.45131 .30224 m .45257 .29881 L .45426 .30108 L 0 .046 .149 r
F
.45131 .30224 m .44962 .29999 L .45257 .29881 L F
.21259 .29236 m .21347 .28944 L .21541 .29133 L 0 .026 .125 r
F
.21259 .29236 m .21066 .29046 L .21347 .28944 L F
.62447 .30036 m .62598 .29695 L .62749 .29891 L 0 .042 .144 r
F
.62447 .30036 m .62295 .29844 L .62598 .29695 L F
.2825 .29363 m .28351 .29055 L .28536 .29249 L 0 .028 .128 r
F
.2825 .29363 m .28064 .29168 L .28351 .29055 L F
.5486 .4635 m .54709 .47425 L .54998 .45669 L .05 .559 0 r
F
.54998 .45669 m .54845 .46494 L .55132 .4458 L 0 .535 .009 r
F
.54569 .47878 m .54709 .47425 L .5486 .4635 L .217 .619 0 r
F
.54845 .46494 m .54976 .44805 L .55132 .4458 L .056 .561 0 r
F
.69276 .29658 m .69439 .29363 L .69584 .29564 L 0 .034 .135 r
F
.69276 .29658 m .69131 .29461 L .69439 .29363 L F
.1275 .29197 m .12826 .28895 L .13027 .29092 L 0 .025 .123 r
F
.1275 .29197 m .12549 .28999 L .12826 .28895 L F
.52283 .3086 m .5242 .30499 L .52582 .30742 L 0 .063 .165 r
F
.52283 .3086 m .52121 .30622 L .5242 .30499 L F
.70794 .29576 m .7096 .29288 L .71102 .2947 L 0 .033 .134 r
F
.70794 .29576 m .70651 .29395 L .7096 .29288 L F
.57894 .30292 m .58039 .29971 L .58195 .30172 L 0 .049 .151 r
F
.57894 .30292 m .57737 .30089 L .58039 .29971 L F
.7307 .29451 m .73239 .29148 L .7338 .29341 L 0 .03 .13 r
F
.7307 .29451 m .72929 .29261 L .73239 .29148 L F
.72311 .29493 m .72479 .29188 L .7262 .29374 L 0 .031 .131 r
F
.72311 .29493 m .7217 .29309 L .72479 .29188 L F
.37219 .29644 m .37333 .29328 L .37509 .29544 L 0 .034 .135 r
F
.37219 .29644 m .37043 .29429 L .37333 .29328 L F
.31745 .29434 m .3185 .29144 L .32032 .2934 L 0 .03 .13 r
F
.31745 .29434 m .31563 .29238 L .3185 .29144 L F
.29008 .29329 m .29109 .29033 L .29294 .29227 L 0 .028 .127 r
F
.29008 .29329 m .28823 .29135 L .29109 .29033 L F
.53709 .43175 m .53838 .40549 L .54003 .41613 L 0 .459 .158 r
F
.53709 .43175 m .53543 .41927 L .53838 .40549 L F
.4635 .30427 m .46478 .30099 L .46645 .30344 L 0 .052 .155 r
F
.4635 .30427 m .46183 .30182 L .46478 .30099 L F
.17762 .29186 m .17845 .2889 L .18042 .2908 L 0 .025 .123 r
F
.17762 .29186 m .17565 .28995 L .17845 .2889 L F
.71553 .29546 m .7172 .29247 L .71862 .2943 L 0 .032 .133 r
F
.71553 .29546 m .71411 .29364 L .7172 .29247 L F
.24753 .29315 m .24847 .29024 L .25036 .29217 L 0 .028 .127 r
F
.24753 .29315 m .24564 .29122 L .24847 .29024 L F
.8112 .29274 m .81303 .2899 L .81435 .29174 L 0 .027 .126 r
F
.8112 .29274 m .80988 .2909 L .81303 .2899 L F
.09252 .29149 m .09323 .28848 L .09528 .29041 L 0 .024 .123 r
F
.09252 .29149 m .09047 .28955 L .09323 .28848 L F
.48327 .30583 m .48458 .30254 L .48624 .30476 L 0 .056 .159 r
F
.48327 .30583 m .48162 .30366 L .48458 .30254 L F
.34481 .29552 m .34591 .2925 L .34769 .29463 L 0 .032 .133 r
F
.34481 .29552 m .34302 .29342 L .34591 .2925 L F
.70036 .29636 m .70199 .29321 L .70343 .29514 L 0 .034 .135 r
F
.70036 .29636 m .69892 .29444 L .70199 .29321 L F
.7383 .29427 m .74 .29127 L .74141 .29322 L 0 .03 .13 r
F
.7383 .29427 m .7369 .29233 L .74 .29127 L F
.13506 .29174 m .13584 .28871 L .13785 .29063 L 0 .025 .123 r
F
.13506 .29174 m .13305 .28981 L .13584 .28871 L F
.75349 .29352 m .75521 .29053 L .75659 .29236 L 0 .028 .128 r
F
.75349 .29352 m .7521 .29168 L .75521 .29053 L F
.22015 .29227 m .22104 .28935 L .22296 .29131 L 0 .026 .125 r
F
.22015 .29227 m .21823 .29031 L .22104 .28935 L F
.56078 .3068 m .5622 .30307 L .56378 .30521 L 0 .058 .16 r
F
.56078 .3068 m .55919 .30461 L .5622 .30307 L F
.58653 .3028 m .58799 .29928 L .58955 .30157 L 0 .048 .151 r
F
.58653 .3028 m .58497 .30052 L .58799 .29928 L F
.18519 .29167 m .18604 .28856 L .188 .29055 L 0 .025 .123 r
F
.18519 .29167 m .18323 .28968 L .18604 .28856 L F
.39954 .29779 m .40072 .29485 L .40246 .29693 L 0 .037 .139 r
F
.39954 .29779 m .3978 .29571 L .40072 .29485 L F
.14263 .29148 m .14342 .28848 L .14542 .29041 L 0 .024 .123 r
F
.14263 .29148 m .14063 .28956 L .14342 .28848 L F
.10008 .29129 m .10078 .2884 L .10283 .29032 L F
.10008 .29129 m .09804 .28938 L .10078 .2884 L F
.53391 .48832 m .53535 .50562 L .5369 .48739 L .365 .665 0 r
F
.53391 .48832 m .53234 .50655 L .53535 .50562 L F
.7459 .29403 m .74762 .29102 L .749 .29287 L 0 .029 .129 r
F
.7459 .29403 m .74451 .29218 L .74762 .29102 L F
.51258 .42365 m .514 .40202 L .51558 .41933 L 0 .442 .184 r
F
.51258 .42365 m .51101 .40567 L .514 .40202 L F
.2551 .29299 m .25606 .28991 L .25795 .29186 L 0 .027 .127 r
F
.2551 .29299 m .25321 .29104 L .25606 .28991 L F
.76108 .2932 m .76283 .29037 L .7642 .29221 L 0 .028 .128 r
F
.76108 .2932 m .75971 .29137 L .76283 .29037 L F
.43151 .30127 m .43275 .29806 L .43444 .30041 L 0 .045 .148 r
F
.43151 .30127 m .42981 .29896 L .43275 .29806 L F
.53042 .30864 m .5318 .30483 L .53341 .30735 L 0 .063 .165 r
F
.53042 .30864 m .52881 .30617 L .5318 .30483 L F
.6093 .3017 m .61079 .29836 L .61233 .3005 L 0 .046 .148 r
F
.6093 .3017 m .60776 .29952 L .61079 .29836 L F
.81882 .29265 m .82064 .28963 L .82196 .29157 L 0 .027 .126 r
F
.81882 .29265 m .81749 .29071 L .82064 .28963 L F
.50305 .30762 m .50439 .30372 L .50603 .3063 L 0 .06 .162 r
F
.50305 .30762 m .50142 .30498 L .50439 .30372 L F
.59413 .30262 m .59559 .29908 L .59715 .30137 L 0 .048 .15 r
F
.59413 .30262 m .59257 .30033 L .59559 .29908 L F
.32501 .29441 m .32606 .29154 L .32788 .29346 L 0 .031 .131 r
F
.32501 .29441 m .32319 .29247 L .32606 .29154 L F
.5232 .42356 m .52458 .39903 L .5262 .41372 L 0 .44 .188 r
F
.5232 .42356 m .52158 .40724 L .52458 .39903 L F
.55319 .30747 m .5546 .30401 L .55619 .30608 L 0 .061 .163 r
F
.55319 .30747 m .5516 .30532 L .5546 .30401 L F
.29763 .29338 m .29866 .29035 L .30049 .29242 L 0 .028 .128 r
F
.29763 .29338 m .2958 .29131 L .29866 .29035 L F
.60172 .30223 m .60319 .29862 L .60474 .30082 L 0 .047 .149 r
F
.60172 .30223 m .60017 .29999 L .60319 .29862 L F
.76869 .29298 m .77043 .28998 L .7718 .29185 L 0 .028 .127 r
F
.76869 .29298 m .76732 .29113 L .77043 .28998 L F
.6169 .3014 m .61839 .29788 L .61992 .29994 L 0 .045 .147 r
F
.6169 .3014 m .61536 .2993 L .61839 .29788 L F
.41932 .29951 m .42053 .29623 L .42225 .29849 L 0 .041 .143 r
F
.41932 .29951 m .4176 .29729 L .42053 .29623 L F
.77628 .2926 m .77805 .28974 L .77941 .29165 L 0 .027 .126 r
F
.77628 .2926 m .77492 .29072 L .77805 .28974 L F
.26267 .29281 m .26364 .2897 L .26551 .29178 L 0 .027 .127 r
F
.26267 .29281 m .2608 .29076 L .26364 .2897 L F
.37975 .29661 m .3809 .29347 L .38265 .29561 L 0 .035 .136 r
F
.37975 .29661 m .37799 .29446 L .3809 .29347 L F
.19274 .29157 m .1936 .28859 L .19554 .29061 L 0 .025 .124 r
F
.19274 .29157 m .1908 .28956 L .1936 .28859 L F
.82643 .29243 m .82827 .28952 L .82959 .29144 L 0 .027 .126 r
F
.82643 .29243 m .82511 .29049 L .82827 .28952 L F
.15018 .29138 m .15099 .28829 L .15297 .29032 L 0 .025 .123 r
F
.15018 .29138 m .1482 .28934 L .15099 .28829 L F
.57136 .30408 m .57279 .3004 L .57436 .30241 L 0 .052 .154 r
F
.57136 .30408 m .56979 .30202 L .57279 .3004 L F
.10762 .29127 m .10835 .28825 L .11039 .29018 L 0 .025 .123 r
F
.10762 .29127 m .10558 .28934 L .10835 .28825 L F
.5456 .30811 m .547 .30438 L .5486 .30662 L 0 .062 .164 r
F
.5456 .30811 m .544 .30577 L .547 .30438 L F
.45888 .30264 m .46015 .29936 L .46183 .30182 L 0 .049 .151 r
F
.45888 .30264 m .4572 .30018 L .46015 .29936 L F
.49086 .30603 m .49218 .3025 L .49383 .30493 L 0 .057 .16 r
F
.49086 .30603 m .48921 .30364 L .49218 .3025 L F
.22769 .29236 m .2286 .28934 L .23051 .29135 L 0 .027 .126 r
F
.22769 .29236 m .22578 .29035 L .2286 .28934 L F
.53801 .3086 m .5394 .30471 L .54101 .3072 L 0 .063 .165 r
F
.53801 .3086 m .53641 .30606 L .5394 .30471 L F
.35236 .2958 m .35348 .29263 L .35526 .29467 L 0 .033 .134 r
F
.35236 .2958 m .35058 .29374 L .35348 .29263 L F
.63507 .29812 m .6366 .29484 L .63811 .29689 L 0 .038 .14 r
F
.63507 .29812 m .63356 .2961 L .6366 .29484 L F
.47107 .30469 m .47236 .30166 L .47403 .30375 L 0 .055 .157 r
F
.47107 .30469 m .4694 .30255 L .47236 .30166 L F
.51064 .30764 m .51199 .30372 L .51362 .3063 L 0 .061 .163 r
F
.51064 .30764 m .50901 .305 L .51199 .30372 L F
.11518 .29105 m .11593 .28795 L .11795 .28996 L 0 .024 .123 r
F
.11518 .29105 m .11316 .28905 L .11593 .28795 L F
.64267 .29779 m .64421 .29458 L .64571 .29667 L 0 .038 .14 r
F
.64267 .29779 m .64116 .29574 L .64421 .29458 L F
.43909 .30138 m .44033 .29818 L .44203 .30025 L 0 .046 .149 r
F
.43909 .30138 m .43739 .2993 L .44033 .29818 L F
.15774 .29129 m .15855 .28818 L .16053 .2902 L 0 .025 .123 r
F
.15774 .29129 m .15576 .28927 L .15855 .28818 L F
.30519 .29341 m .30623 .29028 L .30806 .29233 L 0 .029 .129 r
F
.30519 .29341 m .30336 .29135 L .30623 .29028 L F
.65785 .297 m .65942 .29386 L .66091 .29595 L 0 .036 .138 r
F
.65785 .297 m .65636 .29491 L .65942 .29386 L F
.33257 .29447 m .33365 .29136 L .33545 .29339 L 0 .031 .131 r
F
.33257 .29447 m .33076 .29248 L .33365 .29136 L F
.65026 .29743 m .65181 .29403 L .6533 .29612 L 0 .037 .138 r
F
.65026 .29743 m .64876 .29535 L .65181 .29403 L F
.83405 .29237 m .83591 .28946 L .83721 .29135 L 0 .027 .126 r
F
.83405 .29237 m .83275 .29048 L .83591 .28946 L F
.35994 .29555 m .36107 .2924 L .36285 .2944 L 0 .033 .134 r
F
.35994 .29555 m .35816 .29353 L .36107 .2924 L F
.78391 .29261 m .78569 .28972 L .78704 .29162 L 0 .028 .127 r
F
.78391 .29261 m .78255 .2907 L .78569 .28972 L F
.27022 .29284 m .27121 .28971 L .27307 .2918 L F
.27022 .29284 m .26836 .29074 L .27121 .28971 L F
.38732 .29664 m .38849 .29342 L .39024 .29551 L 0 .035 .137 r
F
.38732 .29664 m .38557 .29452 L .38849 .29342 L F
.4071 .29812 m .40829 .29519 L .41002 .29723 L 0 .039 .141 r
F
.4071 .29812 m .40537 .29606 L .40829 .29519 L F
.84165 .29205 m .84351 .28902 L .8448 .29088 L 0 .026 .125 r
F
.84165 .29205 m .84036 .29019 L .84351 .28902 L F
.20028 .29165 m .20115 .28862 L .20309 .29062 L 0 .026 .124 r
F
.20028 .29165 m .19834 .28964 L .20115 .28862 L F
.23525 .29229 m .23618 .28917 L .23808 .29121 L 0 .027 .126 r
F
.23525 .29229 m .23334 .29026 L .23618 .28917 L F
.51823 .30745 m .51959 .30369 L .52121 .30622 L 0 .061 .163 r
F
.51823 .30745 m .5166 .30495 L .51959 .30369 L F
.84925 .29167 m .85114 .28882 L .85242 .29068 L 0 .026 .125 r
F
.84925 .29167 m .84796 .28982 L .85114 .28882 L F
.68063 .29589 m .68223 .29279 L .6837 .29473 L 0 .034 .135 r
F
.68063 .29589 m .67917 .29398 L .68223 .29279 L F
.44667 .30116 m .44793 .29793 L .44962 .29999 L 0 .046 .148 r
F
.44667 .30116 m .44498 .2991 L .44793 .29793 L F
.67304 .29633 m .67464 .29329 L .6761 .29518 L 0 .035 .137 r
F
.67304 .29633 m .67157 .29447 L .67464 .29329 L F
.1653 .29109 m .16613 .288 L .1681 .28999 L 0 .025 .123 r
F
.1653 .29109 m .16333 .2891 L .16613 .288 L F
.5079 .48038 m .50913 .50249 L .5108 .49857 L .329 .655 0 r
F
.5079 .48038 m .50624 .48347 L .50913 .50249 L F
.66545 .29679 m .66704 .29376 L .66851 .29565 L 0 .036 .138 r
F
.66545 .29679 m .66397 .29491 L .66704 .29376 L F
.62749 .29891 m .62901 .29552 L .63053 .29751 L 0 .04 .142 r
F
.62749 .29891 m .62598 .29695 L .62901 .29552 L F
.50959 .42462 m .51101 .40567 L .51258 .42365 L 0 .448 .175 r
F
.36752 .29537 m .36866 .29219 L .37043 .29429 L 0 .033 .134 r
F
.36752 .29537 m .36575 .2933 L .36866 .29219 L F
.68823 .29559 m .68985 .29263 L .69131 .29461 L 0 .034 .135 r
F
.68823 .29559 m .68677 .29364 L .68985 .29263 L F
.79152 .29245 m .79331 .28953 L .79465 .29138 L 0 .028 .127 r
F
.79152 .29245 m .79017 .29057 L .79331 .28953 L F
.12273 .29098 m .12348 .28796 L .12549 .28999 L 0 .025 .123 r
F
.12273 .29098 m .12072 .28896 L .12348 .28796 L F
.31276 .29332 m .3138 .29036 L .31563 .29238 L 0 .029 .129 r
F
.31276 .29332 m .31093 .2913 L .3138 .29036 L F
.42688 .29985 m .42811 .2966 L .42981 .29896 L 0 .043 .145 r
F
.42688 .29985 m .42518 .29753 L .42811 .2966 L F
.34014 .29439 m .34123 .29129 L .34302 .29342 L 0 .031 .132 r
F
.34014 .29439 m .33834 .29231 L .34123 .29129 L F
.20784 .29149 m .20872 .28856 L .21066 .29046 L 0 .026 .125 r
F
.20784 .29149 m .2059 .28959 L .20872 .28856 L F
.49844 .30624 m .49978 .30262 L .50142 .30498 L 0 .059 .161 r
F
.49844 .30624 m .4968 .30381 L .49978 .30262 L F
.27778 .29276 m .27878 .28969 L .28064 .29168 L 0 .028 .128 r
F
.27778 .29276 m .27592 .29076 L .27878 .28969 L F
.47865 .30478 m .47996 .30155 L .48162 .30366 L 0 .056 .158 r
F
.47865 .30478 m .47699 .30271 L .47996 .30155 L F
.39489 .29658 m .39606 .29362 L .3978 .29571 L 0 .036 .138 r
F
.39489 .29658 m .39315 .2945 L .39606 .29362 L F
.56378 .30521 m .5652 .30153 L .56678 .30363 L 0 .056 .158 r
F
.56378 .30521 m .5622 .30307 L .5652 .30153 L F
.79912 .29216 m .80093 .28927 L .80226 .29111 L 0 .027 .127 r
F
.79912 .29216 m .79779 .29032 L .80093 .28927 L F
.24281 .29218 m .24374 .28928 L .24564 .29122 L F
.24281 .29218 m .24091 .29023 L .24374 .28928 L F
.17286 .29095 m .17368 .28802 L .17565 .28995 L 0 .025 .123 r
F
.17286 .29095 m .17089 .28901 L .17368 .28802 L F
.45426 .30108 m .45552 .29789 L .4572 .30018 L 0 .046 .149 r
F
.45426 .30108 m .45257 .29881 L .45552 .29789 L F
.58195 .30172 m .58341 .29853 L .58497 .30052 L 0 .048 .15 r
F
.58195 .30172 m .58039 .29971 L .58341 .29853 L F
.52582 .30742 m .52719 .3037 L .52881 .30617 L 0 .062 .164 r
F
.52582 .30742 m .5242 .30499 L .52719 .3037 L F
.7262 .29374 m .72788 .29071 L .72929 .29261 L 0 .03 .131 r
F
.7262 .29374 m .72479 .29188 L .72788 .29071 L F
.28536 .29249 m .28637 .28942 L .28823 .29135 L 0 .028 .127 r
F
.28536 .29249 m .28351 .29055 L .28637 .28942 L F
.08772 .29062 m .08842 .28755 L .09047 .28955 L 0 .024 .122 r
F
.08772 .29062 m .08567 .28863 L .08842 .28755 L F
.80673 .2919 m .80855 .28906 L .80988 .2909 L 0 .027 .126 r
F
.80673 .2919 m .8054 .29006 L .80855 .28906 L F
.7338 .29341 m .73549 .29037 L .7369 .29233 L 0 .03 .13 r
F
.7338 .29341 m .73239 .29148 L .73549 .29037 L F
.71102 .2947 m .71269 .29181 L .71411 .29364 L 0 .033 .133 r
F
.71102 .2947 m .7096 .29288 L .71269 .29181 L F
.21541 .29133 m .21629 .28842 L .21823 .29031 L 0 .026 .125 r
F
.21541 .29133 m .21347 .28944 L .21629 .28842 L F
.13027 .29092 m .13104 .28785 L .13305 .28981 L 0 .025 .123 r
F
.13027 .29092 m .12826 .28895 L .13104 .28785 L F
.70343 .29514 m .70507 .29202 L .70651 .29395 L 0 .033 .134 r
F
.70343 .29514 m .70199 .29321 L .70507 .29202 L F
.71862 .2943 m .72028 .29124 L .7217 .29309 L 0 .032 .132 r
F
.71862 .2943 m .7172 .29247 L .72028 .29124 L F
.41467 .29835 m .41588 .2952 L .4176 .29729 L 0 .04 .142 r
F
.41467 .29835 m .41295 .2963 L .41588 .2952 L F
.69584 .29564 m .69747 .29241 L .69892 .29444 L 0 .034 .135 r
F
.69584 .29564 m .69439 .29363 L .69747 .29241 L F
.29294 .29227 m .29395 .28939 L .2958 .29131 L 0 .028 .127 r
F
.29294 .29227 m .29109 .29033 L .29395 .28939 L F
.18042 .2908 m .18126 .2878 L .18323 .28968 L 0 .025 .123 r
F
.18042 .2908 m .17845 .2889 L .18126 .2878 L F
.37509 .29544 m .37624 .29231 L .37799 .29446 L 0 .034 .135 r
F
.37509 .29544 m .37333 .29328 L .37624 .29231 L F
.57436 .30241 m .5758 .29893 L .57737 .30089 L 0 .049 .152 r
F
.57436 .30241 m .57279 .3004 L .5758 .29893 L F
.58955 .30157 m .59101 .29803 L .59257 .30033 L 0 .047 .15 r
F
.58955 .30157 m .58799 .29928 L .59101 .29803 L F
.09528 .29041 m .09599 .28745 L .09804 .28938 L 0 .024 .123 r
F
.09528 .29041 m .09323 .28848 L .09599 .28745 L F
.13785 .29063 m .13862 .28763 L .14063 .28956 L 0 .025 .123 r
F
.13785 .29063 m .13584 .28871 L .13862 .28763 L F
.48624 .30476 m .48756 .30138 L .48921 .30364 L 0 .056 .158 r
F
.48624 .30476 m .48458 .30254 L .48756 .30138 L F
.32032 .2934 m .32137 .29053 L .32319 .29247 L 0 .03 .13 r
F
.32032 .2934 m .3185 .29144 L .32137 .29053 L F
.61992 .29994 m .62142 .29641 L .62295 .29844 L 0 .043 .146 r
F
.61992 .29994 m .61839 .29788 L .62142 .29641 L F
.75659 .29236 m .75833 .28953 L .75971 .29137 L 0 .028 .128 r
F
.75659 .29236 m .75521 .29053 L .75833 .28953 L F
.81435 .29174 m .81617 .28885 L .81749 .29071 L 0 .027 .126 r
F
.81435 .29174 m .81303 .2899 L .81617 .28885 L F
.25036 .29217 m .25132 .28912 L .25321 .29104 L 0 .028 .127 r
F
.25036 .29217 m .24847 .29024 L .25132 .28912 L F
.74141 .29322 m .74311 .29022 L .74451 .29218 L 0 .03 .13 r
F
.74141 .29322 m .74 .29127 L .74311 .29022 L F
.55619 .30608 m .55761 .30259 L .55919 .30461 L 0 .059 .162 r
F
.55619 .30608 m .5546 .30401 L .55761 .30259 L F
.60474 .30082 m .60622 .29736 L .60776 .29952 L 0 .046 .148 r
F
.60474 .30082 m .60319 .29862 L .60622 .29736 L F
.53341 .30735 m .53479 .3035 L .53641 .30606 L 0 .062 .164 r
F
.53341 .30735 m .5318 .30483 L .53479 .3035 L F
.50603 .3063 m .50738 .30249 L .50901 .305 L 0 .059 .161 r
F
.50603 .3063 m .50439 .30372 L .50738 .30249 L F
.54496 .44266 m .54623 .41983 L .54785 .42496 L 0 .492 .098 r
F
.54496 .44266 m .54333 .43681 L .54623 .41983 L F
.188 .29055 m .18885 .28757 L .1908 .28956 L 0 .025 .123 r
F
.188 .29055 m .18604 .28856 L .18885 .28757 L F
.749 .29287 m .75072 .28984 L .7521 .29168 L 0 .029 .129 r
F
.749 .29287 m .74762 .29102 L .75072 .28984 L F
.46645 .30344 m .46773 .30012 L .4694 .30255 L 0 .053 .155 r
F
.46645 .30344 m .46478 .30099 L .46773 .30012 L F
.25795 .29186 m .25891 .28881 L .2608 .29076 L 0 .027 .126 r
F
.25795 .29186 m .25606 .28991 L .25891 .28881 L F
.54659 .44852 m .54785 .42496 L .54947 .4301 L 0 .507 .069 r
F
.54659 .44852 m .54496 .44266 L .54785 .42496 L F
.61233 .3005 m .61383 .2972 L .61536 .2993 L 0 .045 .148 r
F
.61233 .3005 m .61079 .29836 L .61383 .2972 L F
.5486 .30662 m .55 .30316 L .5516 .30532 L 0 .061 .163 r
F
.5486 .30662 m .547 .30438 L .55 .30316 L F
.14542 .29041 m .1462 .28742 L .1482 .28934 L 0 .024 .123 r
F
.14542 .29041 m .14342 .28848 L .1462 .28742 L F
.59715 .30137 m .59861 .29776 L .60017 .29999 L 0 .047 .149 r
F
.59715 .30137 m .59559 .29908 L .59861 .29776 L F
.34769 .29463 m .34879 .29158 L .35058 .29374 L 0 .033 .133 r
F
.34769 .29463 m .34591 .2925 L .34879 .29158 L F
.54819 .45031 m .54659 .44852 L .54947 .4301 L 0 .514 .054 r
F
.22296 .29131 m .22386 .28839 L .22578 .29035 L 0 .026 .125 r
F
.22296 .29131 m .22104 .28935 L .22386 .28839 L F
.5369 .48739 m .53535 .50562 L .53835 .49901 L .33 .655 0 r
F
.82196 .29157 m .82379 .28856 L .82511 .29049 L 0 .027 .126 r
F
.82196 .29157 m .82064 .28963 L .82379 .28856 L F
.7642 .29221 m .76595 .28927 L .76732 .29113 L 0 .028 .128 r
F
.7642 .29221 m .76283 .29037 L .76595 .28927 L F
.10283 .29032 m .10354 .28742 L .10558 .28934 L 0 .025 .123 r
F
.10283 .29032 m .10078 .2884 L .10354 .28742 L F
.5052 .43769 m .50366 .41986 L .50662 .42223 L 0 .493 .097 r
F
.50227 .43035 m .50366 .41986 L .5052 .43769 L 0 .471 .138 r
F
.54101 .3072 m .5424 .30335 L .544 .30577 L 0 .062 .164 r
F
.54101 .3072 m .5394 .30471 L .5424 .30335 L F
.7718 .29185 m .77355 .28883 L .77492 .29072 L 0 .027 .127 r
F
.7718 .29185 m .77043 .28998 L .77355 .28883 L F
.40246 .29693 m .40364 .29398 L .40537 .29606 L 0 .038 .14 r
F
.40246 .29693 m .40072 .29485 L .40364 .29398 L F
.42225 .29849 m .42347 .29523 L .42518 .29753 L 0 .041 .143 r
F
.42225 .29849 m .42053 .29623 L .42347 .29523 L F
.51362 .3063 m .51498 .30243 L .5166 .30495 L 0 .06 .162 r
F
.51362 .3063 m .51199 .30372 L .51498 .30243 L F
.43444 .30041 m .43569 .29698 L .43739 .2993 L 0 .045 .148 r
F
.43444 .30041 m .43275 .29806 L .43569 .29698 L F
.32788 .29346 m .32894 .29057 L .33076 .29248 L 0 .031 .131 r
F
.32788 .29346 m .32606 .29154 L .32894 .29057 L F
.26551 .29178 m .26649 .28864 L .26836 .29074 L 0 .027 .127 r
F
.26551 .29178 m .26364 .2897 L .26649 .28864 L F
.30049 .29242 m .30153 .28929 L .30336 .29135 L 0 .028 .128 r
F
.30049 .29242 m .29866 .29035 L .30153 .28929 L F
.15297 .29032 m .15378 .28724 L .15576 .28927 L 0 .024 .123 r
F
.15297 .29032 m .15099 .28829 L .15378 .28724 L F
.38265 .29561 m .38382 .29239 L .38557 .29452 L 0 .035 .136 r
F
.38265 .29561 m .3809 .29347 L .38382 .29239 L F
.63811 .29689 m .63965 .29366 L .64116 .29574 L 0 .038 .139 r
F
.63811 .29689 m .6366 .29484 L .63965 .29366 L F
.77941 .29165 m .78119 .28877 L .78255 .2907 L 0 .027 .127 r
F
.77941 .29165 m .77805 .28974 L .78119 .28877 L F
.11039 .29018 m .11112 .28713 L .11316 .28905 L 0 .024 .123 r
F
.11039 .29018 m .10835 .28825 L .11112 .28713 L F
.82959 .29144 m .83144 .28857 L .83275 .29048 L 0 .027 .126 r
F
.82959 .29144 m .82827 .28952 L .83144 .28857 L F
.49383 .30493 m .49515 .30137 L .4968 .30381 L 0 .057 .159 r
F
.49383 .30493 m .49218 .3025 L .49515 .30137 L F
.19554 .29061 m .1964 .28762 L .19834 .28964 L 0 .025 .124 r
F
.19554 .29061 m .1936 .28859 L .1964 .28762 L F
.6533 .29612 m .65486 .29281 L .65636 .29491 L 0 .036 .137 r
F
.6533 .29612 m .65181 .29403 L .65486 .29281 L F
.35526 .29467 m .35638 .29151 L .35816 .29353 L 0 .033 .134 r
F
.35526 .29467 m .35348 .29263 L .35638 .29151 L F
.23051 .29135 m .23144 .28823 L .23334 .29026 L 0 .027 .126 r
F
.23051 .29135 m .2286 .28934 L .23144 .28823 L F
.63053 .29751 m .63205 .29408 L .63356 .2961 L 0 .039 .141 r
F
.63053 .29751 m .62901 .29552 L .63205 .29408 L F
.64571 .29667 m .64726 .29326 L .64876 .29535 L 0 .037 .139 r
F
.64571 .29667 m .64421 .29458 L .64726 .29326 L F
.44203 .30025 m .44328 .29704 L .44498 .2991 L 0 .046 .148 r
F
.44203 .30025 m .44033 .29818 L .44328 .29704 L F
.56678 .30363 m .56821 .29997 L .56979 .30202 L 0 .053 .156 r
F
.56678 .30363 m .5652 .30153 L .56821 .29997 L F
.11795 .28996 m .1187 .28693 L .12072 .28896 L 0 .024 .123 r
F
.11795 .28996 m .11593 .28795 L .1187 .28693 L F
.36285 .2944 m .36398 .29128 L .36575 .2933 L 0 .033 .134 r
F
.36285 .2944 m .36107 .2924 L .36398 .29128 L F
.16053 .2902 m .16135 .28708 L .16333 .2891 L 0 .025 .123 r
F
.16053 .2902 m .15855 .28818 L .16135 .28708 L F
.52121 .30622 m .52258 .30242 L .5242 .30499 L 0 .06 .163 r
F
.52121 .30622 m .51959 .30369 L .52258 .30242 L F
.30806 .29233 m .30911 .28925 L .31093 .2913 L 0 .029 .129 r
F
.30806 .29233 m .30623 .29028 L .30911 .28925 L F
.33545 .29339 m .33654 .29024 L .33834 .29231 L 0 .031 .131 r
F
.33545 .29339 m .33365 .29136 L .33654 .29024 L F
.46183 .30182 m .46311 .29853 L .46478 .30099 L 0 .05 .152 r
F
.46183 .30182 m .46015 .29936 L .46311 .29853 L F
.39024 .29551 m .3914 .29242 L .39315 .2945 L 0 .035 .137 r
F
.39024 .29551 m .38849 .29342 L .3914 .29242 L F
.5011 .45813 m .49955 .44381 L .50244 .45541 L .07 .567 0 r
F
.49955 .44381 m .5009 .4389 L .50244 .45541 L 0 .513 .056 r
F
.8448 .29088 m .84668 .28796 L .84796 .28982 L 0 .026 .125 r
F
.8448 .29088 m .84351 .28902 L .84668 .28796 L F
.66091 .29595 m .66248 .29282 L .66397 .29491 L 0 .036 .138 r
F
.66091 .29595 m .65942 .29386 L .66248 .29282 L F
.47403 .30375 m .47532 .30061 L .47699 .30271 L 0 .055 .158 r
F
.47403 .30375 m .47236 .30166 L .47532 .30061 L F
.83721 .29135 m .83906 .28831 L .84036 .29019 L 0 .027 .126 r
F
.83721 .29135 m .83591 .28946 L .83906 .28831 L F
.44962 .29999 m .45088 .29676 L .45257 .29881 L 0 .045 .148 r
F
.44962 .29999 m .44793 .29793 L .45088 .29676 L F
.6837 .29473 m .68531 .29168 L .68677 .29364 L 0 .034 .135 r
F
.6837 .29473 m .68223 .29279 L .68531 .29168 L F
.27307 .2918 m .27406 .28868 L .27592 .29076 L 0 .028 .127 r
F
.27307 .2918 m .27121 .28971 L .27406 .28868 L F
.6761 .29518 m .6777 .29207 L .67917 .29398 L 0 .035 .136 r
F
.6761 .29518 m .67464 .29329 L .6777 .29207 L F
.50137 .46851 m .4998 .45676 L .50266 .47238 L .168 .603 0 r
F
.4998 .45676 m .5011 .45813 L .50266 .47238 L .05 .559 0 r
F
.78704 .29162 m .78882 .2887 L .79017 .29057 L 0 .028 .127 r
F
.78704 .29162 m .78569 .28972 L .78882 .2887 L F
.23808 .29121 m .23901 .28817 L .24091 .29023 L 0 .027 .126 r
F
.23808 .29121 m .23618 .28917 L .23901 .28817 L F
.66851 .29565 m .6701 .29257 L .67157 .29447 L 0 .036 .137 r
F
.66851 .29565 m .66704 .29376 L .6701 .29257 L F
.20309 .29062 m .20396 .2876 L .2059 .28959 L 0 .026 .125 r
F
.20309 .29062 m .20115 .28862 L .20396 .2876 L F
.1681 .28999 m .16892 .28702 L .17089 .28901 L 0 .025 .123 r
F
.1681 .28999 m .16613 .288 L .16892 .28702 L F
.50142 .30498 m .50276 .30143 L .50439 .30372 L 0 .058 .16 r
F
.50142 .30498 m .49978 .30262 L .50276 .30143 L F
.85242 .29068 m .85431 .28782 L .85559 .28968 L 0 .026 .125 r
F
.85242 .29068 m .85114 .28882 L .85431 .28782 L F
.54709 .47425 m .54845 .46494 L .54998 .45669 L .168 .603 0 r
F
.41002 .29723 m .41122 .29425 L .41295 .2963 L 0 .04 .142 r
F
.41002 .29723 m .40829 .29519 L .41122 .29425 L F
.37043 .29429 m .37157 .29118 L .37333 .29328 L 0 .033 .134 r
F
.37043 .29429 m .36866 .29219 L .37157 .29118 L F
.52783 .43017 m .52918 .40386 L .53082 .41846 L 0 .459 .158 r
F
.52783 .43017 m .5262 .41372 L .52918 .40386 L F
.79465 .29138 m .79645 .28848 L .79779 .29032 L 0 .028 .127 r
F
.79465 .29138 m .79331 .28953 L .79645 .28848 L F
.57737 .30089 m .57882 .29778 L .58039 .29971 L 0 .048 .151 r
F
.57737 .30089 m .5758 .29893 L .57882 .29778 L F
.52881 .30617 m .53019 .30232 L .5318 .30483 L 0 .061 .163 r
F
.52881 .30617 m .52719 .3037 L .53019 .30232 L F
.48162 .30366 m .48293 .30038 L .48458 .30254 L 0 .055 .158 r
F
.48162 .30366 m .47996 .30155 L .48293 .30038 L F
.69131 .29461 m .69294 .29162 L .69439 .29363 L 0 .034 .135 r
F
.69131 .29461 m .68985 .29263 L .69294 .29162 L F
.58497 .30052 m .58643 .2973 L .58799 .29928 L 0 .047 .15 r
F
.58497 .30052 m .58341 .29853 L .58643 .2973 L F
.28064 .29168 m .28164 .28857 L .28351 .29055 L 0 .028 .127 r
F
.28064 .29168 m .27878 .28969 L .28164 .28857 L F
.12549 .28999 m .12625 .28691 L .12826 .28895 L 0 .025 .123 r
F
.12549 .28999 m .12348 .28796 L .12625 .28691 L F
.62295 .29844 m .62445 .29496 L .62598 .29695 L 0 .042 .144 r
F
.62295 .29844 m .62142 .29641 L .62445 .29496 L F
.21066 .29046 m .21153 .28754 L .21347 .28944 L 0 .026 .125 r
F
.21066 .29046 m .20872 .28856 L .21153 .28754 L F
.34302 .29342 m .34412 .29034 L .34591 .2925 L 0 .032 .132 r
F
.34302 .29342 m .34123 .29129 L .34412 .29034 L F
.80226 .29111 m .80407 .28822 L .8054 .29006 L 0 .027 .127 r
F
.80226 .29111 m .80093 .28927 L .80407 .28822 L F
.31563 .29238 m .31667 .28942 L .3185 .29144 L 0 .03 .13 r
F
.31563 .29238 m .3138 .29036 L .31667 .28942 L F
.55919 .30461 m .56061 .30107 L .5622 .30307 L 0 .057 .16 r
F
.55919 .30461 m .55761 .30259 L .56061 .30107 L F
.72929 .29261 m .73097 .28954 L .73239 .29148 L 0 .03 .13 r
F
.72929 .29261 m .72788 .29071 L .73097 .28954 L F
.28823 .29135 m .28923 .28841 L .29109 .29033 L 0 .028 .127 r
F
.28823 .29135 m .28637 .28942 L .28923 .28841 L F
.42981 .29896 m .43105 .29567 L .43275 .29806 L 0 .044 .146 r
F
.42981 .29896 m .42811 .2966 L .43105 .29567 L F
.7217 .29309 m .72337 .29001 L .72479 .29188 L 0 .031 .131 r
F
.7217 .29309 m .72028 .29124 L .72337 .29001 L F
.17565 .28995 m .17648 .28699 L .17845 .2889 L 0 .025 .124 r
F
.17565 .28995 m .17368 .28802 L .17648 .28699 L F
.70651 .29395 m .70816 .29095 L .7096 .29288 L 0 .033 .134 r
F
.70651 .29395 m .70507 .29202 L .70816 .29095 L F
.24564 .29122 m .24657 .28831 L .24847 .29024 L 0 .028 .127 r
F
.24564 .29122 m .24374 .28928 L .24657 .28831 L F
.09047 .28955 m .09118 .28648 L .09323 .28848 L 0 .024 .122 r
F
.09047 .28955 m .08842 .28755 L .09118 .28648 L F
.59257 .30033 m .59403 .29678 L .59559 .29908 L 0 .047 .149 r
F
.59257 .30033 m .59101 .29803 L .59403 .29678 L F
.7369 .29233 m .73859 .28929 L .74 .29127 L 0 .03 .13 r
F
.7369 .29233 m .73549 .29037 L .73859 .28929 L F
.69892 .29444 m .70054 .29116 L .70199 .29321 L 0 .034 .135 r
F
.69892 .29444 m .69747 .29241 L .70054 .29116 L F
.13305 .28981 m .13383 .28675 L .13584 .28871 L 0 .025 .123 r
F
.13305 .28981 m .13104 .28785 L .13383 .28675 L F
.3978 .29571 m .39898 .29275 L .40072 .29485 L 0 .037 .138 r
F
.3978 .29571 m .39606 .29362 L .39898 .29275 L F
.60776 .29952 m .60925 .29625 L .61079 .29836 L 0 .045 .147 r
F
.60776 .29952 m .60622 .29736 L .60925 .29625 L F
.53641 .30606 m .53779 .30218 L .5394 .30471 L 0 .061 .163 r
F
.53641 .30606 m .53479 .3035 L .53779 .30218 L F
.50901 .305 m .51036 .30127 L .51199 .30372 L 0 .058 .161 r
F
.50901 .305 m .50738 .30249 L .51036 .30127 L F
.53246 .43314 m .53379 .40657 L .53543 .41927 L 0 .467 .145 r
F
.53246 .43314 m .53082 .41846 L .53379 .40657 L F
.71411 .29364 m .71577 .29063 L .7172 .29247 L 0 .032 .133 r
F
.71411 .29364 m .71269 .29181 L .71577 .29063 L F
.80988 .2909 m .8117 .28805 L .81303 .2899 L 0 .027 .126 r
F
.80988 .2909 m .80855 .28906 L .8117 .28805 L F
.4572 .30018 m .45847 .29706 L .46015 .29936 L 0 .047 .15 r
F
.4572 .30018 m .45552 .29789 L .45847 .29706 L F
.60017 .29999 m .60164 .29644 L .60319 .29862 L 0 .046 .148 r
F
.60017 .29999 m .59861 .29776 L .60164 .29644 L F
.21823 .29031 m .21911 .28746 L .22104 .28935 L 0 .026 .125 r
F
.21823 .29031 m .21629 .28842 L .21911 .28746 L F
.18323 .28968 m .18407 .28669 L .18604 .28856 L 0 .025 .123 r
F
.18323 .28968 m .18126 .2878 L .18407 .28669 L F
.4176 .29729 m .41881 .29409 L .42053 .29623 L 0 .04 .142 r
F
.4176 .29729 m .41588 .2952 L .41881 .29409 L F
.5516 .30532 m .55301 .30195 L .5546 .30401 L 0 .06 .162 r
F
.5516 .30532 m .55 .30316 L .55301 .30195 L F
.48921 .30364 m .49053 .30021 L .49218 .3025 L 0 .055 .158 r
F
.48921 .30364 m .48756 .30138 L .49053 .30021 L F
.544 .30577 m .5454 .30203 L .547 .30438 L 0 .06 .163 r
F
.544 .30577 m .5424 .30335 L .5454 .30203 L F
.14063 .28956 m .14141 .28656 L .14342 .28848 L 0 .024 .123 r
F
.14063 .28956 m .13862 .28763 L .14141 .28656 L F
.25321 .29104 m .25417 .288 L .25606 .28991 L 0 .027 .127 r
F
.25321 .29104 m .25132 .28912 L .25417 .288 L F
.7521 .29168 m .75383 .28869 L .75521 .29053 L 0 .029 .128 r
F
.7521 .29168 m .75072 .28984 L .75383 .28869 L F
.09804 .28938 m .09873 .28647 L .10078 .2884 L 0 .024 .123 r
F
.09804 .28938 m .09599 .28745 L .09873 .28647 L F
.61536 .2993 m .61686 .29581 L .61839 .29788 L 0 .044 .147 r
F
.61536 .2993 m .61383 .2972 L .61686 .29581 L F
.37799 .29446 m .37915 .29133 L .3809 .29347 L 0 .034 .135 r
F
.37799 .29446 m .37624 .29231 L .37915 .29133 L F
.2958 .29131 m .29681 .28844 L .29866 .29035 L 0 .028 .128 r
F
.2958 .29131 m .29395 .28939 L .29681 .28844 L F
.74451 .29218 m .74622 .28905 L .74762 .29102 L 0 .029 .129 r
F
.74451 .29218 m .74311 .29022 L .74622 .28905 L F
.81749 .29071 m .81932 .28775 L .82064 .28963 L 0 .027 .126 r
F
.81749 .29071 m .81617 .28885 L .81932 .28775 L F
.75971 .29137 m .76146 .28853 L .76283 .29037 L 0 .028 .128 r
F
.75971 .29137 m .75833 .28953 L .76146 .28853 L F
.2608 .29076 m .26176 .28773 L .26364 .2897 L 0 .027 .126 r
F
.2608 .29076 m .25891 .28881 L .26176 .28773 L F
.32319 .29247 m .32424 .28961 L .32606 .29154 L 0 .031 .131 r
F
.32319 .29247 m .32137 .29053 L .32424 .28961 L F
.1482 .28934 m .14899 .28638 L .15099 .28829 L 0 .024 .123 r
F
.1482 .28934 m .1462 .28742 L .14899 .28638 L F
.1908 .28956 m .19165 .28659 L .1936 .28859 L 0 .025 .123 r
F
.1908 .28956 m .18885 .28757 L .19165 .28659 L F
.5166 .30495 m .51797 .30114 L .51959 .30369 L 0 .059 .161 r
F
.5166 .30495 m .51498 .30243 L .51797 .30114 L F
.56979 .30202 m .57122 .2984 L .57279 .3004 L 0 .051 .154 r
F
.56979 .30202 m .56821 .29997 L .57122 .2984 L F
.82511 .29049 m .82696 .2876 L .82827 .28952 L 0 .027 .126 r
F
.82511 .29049 m .82379 .28856 L .82696 .2876 L F
.76732 .29113 m .76907 .28811 L .77043 .28998 L 0 .028 .127 r
F
.76732 .29113 m .76595 .28927 L .76907 .28811 L F
.77492 .29072 m .77669 .28783 L .77805 .28974 L 0 .027 .127 r
F
.77492 .29072 m .77355 .28883 L .77669 .28783 L F
.4694 .30255 m .47069 .29925 L .47236 .30166 L 0 .053 .156 r
F
.4694 .30255 m .46773 .30012 L .47069 .29925 L F
.22578 .29035 m .22668 .28738 L .2286 .28934 L 0 .026 .126 r
F
.22578 .29035 m .22386 .28839 L .22668 .28738 L F
.35058 .29374 m .35169 .29049 L .35348 .29263 L 0 .033 .134 r
F
.35058 .29374 m .34879 .29158 L .35169 .29049 L F
.10558 .28934 m .1063 .28634 L .10835 .28825 L 0 .025 .123 r
F
.10558 .28934 m .10354 .28742 L .1063 .28634 L F
.63356 .2961 m .63509 .29279 L .6366 .29484 L 0 .038 .14 r
F
.63356 .2961 m .63205 .29408 L .63509 .29279 L F
.43739 .2993 m .43864 .29589 L .44033 .29818 L 0 .045 .148 r
F
.43739 .2993 m .43569 .29698 L .43864 .29589 L F
.64116 .29574 m .6427 .29248 L .64421 .29458 L 0 .037 .139 r
F
.64116 .29574 m .63965 .29366 L .6427 .29248 L F
.65636 .29491 m .65793 .29177 L .65942 .29386 L 0 .036 .137 r
F
.65636 .29491 m .65486 .29281 L .65793 .29177 L F
.64876 .29535 m .65031 .29194 L .65181 .29403 L 0 .036 .138 r
F
.64876 .29535 m .64726 .29326 L .65031 .29194 L F
.30336 .29135 m .3044 .28822 L .30623 .29028 L 0 .028 .128 r
F
.30336 .29135 m .30153 .28929 L .3044 .28822 L F
.38557 .29452 m .38674 .2913 L .38849 .29342 L 0 .035 .136 r
F
.38557 .29452 m .38382 .29239 L .38674 .2913 L F
.11316 .28905 m .1139 .28602 L .11593 .28795 L 0 .024 .122 r
F
.11316 .28905 m .11112 .28713 L .1139 .28602 L F
.15576 .28927 m .15657 .28615 L .15855 .28818 L 0 .024 .123 r
F
.15576 .28927 m .15378 .28724 L .15657 .28615 L F
.4968 .30381 m .49813 .30026 L .49978 .30262 L 0 .056 .159 r
F
.4968 .30381 m .49515 .30137 L .49813 .30026 L F
.26836 .29074 m .26935 .28761 L .27121 .28971 L 0 .027 .127 r
F
.26836 .29074 m .26649 .28864 L .26935 .28761 L F
.42518 .29753 m .4264 .29426 L .42811 .2966 L 0 .042 .144 r
F
.42518 .29753 m .42347 .29523 L .4264 .29426 L F
.33076 .29248 m .33183 .28946 L .33365 .29136 L 0 .031 .131 r
F
.33076 .29248 m .32894 .29057 L .33183 .28946 L F
.35816 .29353 m .35929 .29039 L .36107 .2924 L 0 .033 .134 r
F
.35816 .29353 m .35638 .29151 L .35929 .29039 L F
.40537 .29606 m .40656 .29312 L .40829 .29519 L 0 .039 .141 r
F
.40537 .29606 m .40364 .29398 L .40656 .29312 L F
.5242 .30499 m .52557 .30111 L .52719 .3037 L 0 .059 .162 r
F
.5242 .30499 m .52258 .30242 L .52557 .30111 L F
.44498 .2991 m .44623 .29587 L .44793 .29793 L 0 .045 .148 r
F
.44498 .2991 m .44328 .29704 L .44623 .29587 L F
.23334 .29026 m .23428 .28713 L .23618 .28917 L 0 .026 .126 r
F
.23334 .29026 m .23144 .28823 L .23428 .28713 L F
.83275 .29048 m .83461 .28757 L .83591 .28946 L 0 .027 .127 r
F
.83275 .29048 m .83144 .28857 L .83461 .28757 L F
.19834 .28964 m .19921 .2866 L .20115 .28862 L 0 .025 .124 r
F
.19834 .28964 m .1964 .28762 L .19921 .2866 L F
.78255 .2907 m .78433 .28777 L .78569 .28972 L 0 .028 .127 r
F
.78255 .2907 m .78119 .28877 L .78433 .28777 L F
.36575 .2933 m .36689 .29016 L .36866 .29219 L 0 .033 .133 r
F
.36575 .2933 m .36398 .29128 L .36689 .29016 L F
.16333 .2891 m .16415 .28598 L .16613 .288 L 0 .024 .123 r
F
.16333 .2891 m .16135 .28708 L .16415 .28598 L F
.45257 .29881 m .45384 .29582 L .45552 .29789 L 0 .045 .148 r
F
.45257 .29881 m .45088 .29676 L .45384 .29582 L F
.84036 .29019 m .84222 .28716 L .84351 .28902 L 0 .027 .126 r
F
.84036 .29019 m .83906 .28831 L .84222 .28716 L F
.67917 .29398 m .68077 .29085 L .68223 .29279 L 0 .034 .135 r
F
.67917 .29398 m .6777 .29207 L .68077 .29085 L F
.33834 .29231 m .33943 .2892 L .34123 .29129 L 0 .031 .131 r
F
.33834 .29231 m .33654 .29024 L .33943 .2892 L F
.62598 .29695 m .62749 .29357 L .62901 .29552 L 0 .04 .142 r
F
.62598 .29695 m .62445 .29496 L .62749 .29357 L F
.5622 .30307 m .56362 .29955 L .5652 .30153 L 0 .055 .158 r
F
.5622 .30307 m .56061 .30107 L .56362 .29955 L F
.12072 .28896 m .12147 .28592 L .12348 .28796 L 0 .024 .123 r
F
.12072 .28896 m .1187 .28693 L .12147 .28592 L F
.50439 .30372 m .50574 .30027 L .50738 .30249 L 0 .057 .159 r
F
.50439 .30372 m .50276 .30143 L .50574 .30027 L F
.84796 .28982 m .84985 .28696 L .85114 .28882 L 0 .026 .125 r
F
.84796 .28982 m .84668 .28796 L .84985 .28696 L F
.31093 .2913 m .31198 .28829 L .3138 .29036 L 0 .029 .129 r
F
.31093 .2913 m .30911 .28925 L .31198 .28829 L F
.67157 .29447 m .67316 .29137 L .67464 .29329 L 0 .035 .137 r
F
.67157 .29447 m .6701 .29257 L .67316 .29137 L F
.68677 .29364 m .68839 .29064 L .68985 .29263 L 0 .034 .135 r
F
.68677 .29364 m .68531 .29168 L .68839 .29064 L F
.47699 .30271 m .47829 .2994 L .47996 .30155 L 0 .055 .157 r
F
.47699 .30271 m .47532 .30061 L .47829 .2994 L F
.66397 .29491 m .66555 .29168 L .66704 .29376 L 0 .036 .138 r
F
.66397 .29491 m .66248 .29282 L .66555 .29168 L F
.39315 .2945 m .39432 .29153 L .39606 .29362 L 0 .036 .137 r
F
.39315 .2945 m .3914 .29242 L .39432 .29153 L F
.5318 .30483 m .53318 .30093 L .53479 .3035 L 0 .059 .162 r
F
.5318 .30483 m .53019 .30232 L .53318 .30093 L F
.27592 .29076 m .27692 .28762 L .27878 .28969 L 0 .028 .127 r
F
.27592 .29076 m .27406 .28868 L .27692 .28762 L F
.79017 .29057 m .79196 .28767 L .79331 .28953 L F
.79017 .29057 m .78882 .2887 L .79196 .28767 L F
.2059 .28959 m .20678 .28657 L .20872 .28856 L 0 .026 .125 r
F
.2059 .28959 m .20396 .2876 L .20678 .28657 L F
.58799 .29928 m .58945 .29604 L .59101 .29803 L 0 .046 .149 r
F
.58799 .29928 m .58643 .2973 L .58945 .29604 L F
.58039 .29971 m .58184 .29662 L .58341 .29853 L 0 .048 .15 r
F
.58039 .29971 m .57882 .29778 L .58184 .29662 L F
.24091 .29023 m .24184 .28721 L .24374 .28928 L 0 .027 .126 r
F
.24091 .29023 m .23901 .28817 L .24184 .28721 L F
.46478 .30099 m .46606 .29768 L .46773 .30012 L 0 .051 .153 r
F
.46478 .30099 m .46311 .29853 L .46606 .29768 L F
.17089 .28901 m .17171 .28605 L .17368 .28802 L 0 .025 .123 r
F
.17089 .28901 m .16892 .28702 L .17171 .28605 L F
.08567 .28863 m .08637 .28555 L .08842 .28755 L 0 .024 .122 r
F
.08567 .28863 m .08361 .28663 L .08637 .28555 L F
.48458 .30254 m .4859 .29918 L .48756 .30138 L 0 .055 .157 r
F
.48458 .30254 m .48293 .30038 L .4859 .29918 L F
.79779 .29032 m .79959 .28742 L .80093 .28927 L 0 .028 .127 r
F
.79779 .29032 m .79645 .28848 L .79959 .28742 L F
.37333 .29328 m .37447 .29022 L .37624 .29231 L 0 .033 .134 r
F
.37333 .29328 m .37157 .29118 L .37447 .29022 L F
.28351 .29055 m .28451 .28745 L .28637 .28942 L 0 .028 .127 r
F
.28351 .29055 m .28164 .28857 L .28451 .28745 L F
.5394 .30471 m .54079 .30087 L .5424 .30335 L 0 .059 .162 r
F
.5394 .30471 m .53779 .30218 L .54079 .30087 L F
.50381 .4486 m .50227 .43035 L .5052 .43769 L 0 .535 .008 r
F
.5009 .4389 m .50227 .43035 L .50381 .4486 L 0 .498 .088 r
F
.60319 .29862 m .60467 .29524 L .60622 .29736 L 0 .045 .147 r
F
.60319 .29862 m .60164 .29644 L .60467 .29524 L F
.72479 .29188 m .72646 .28881 L .72788 .29071 L 0 .03 .131 r
F
.72479 .29188 m .72337 .29001 L .72646 .28881 L F
.41295 .2963 m .41415 .2931 L .41588 .2952 L 0 .04 .142 r
F
.41295 .2963 m .41122 .29425 L .41415 .2931 L F
.73239 .29148 m .73408 .2884 L .73549 .29037 L 0 .03 .13 r
F
.73239 .29148 m .73097 .28954 L .73408 .2884 L F
.12826 .28895 m .12904 .28582 L .13104 .28785 L 0 .025 .123 r
F
.12826 .28895 m .12625 .28691 L .12904 .28582 L F
.59559 .29908 m .59706 .29552 L .59861 .29776 L 0 .046 .148 r
F
.59559 .29908 m .59403 .29678 L .59706 .29552 L F
.51199 .30372 m .51335 .30005 L .51498 .30243 L 0 .057 .16 r
F
.51199 .30372 m .51036 .30127 L .51335 .30005 L F
.547 .30438 m .5484 .30086 L .55 .30316 L 0 .059 .162 r
F
.547 .30438 m .5454 .30203 L .5484 .30086 L F
.70199 .29321 m .70362 .28996 L .70507 .29202 L 0 .033 .134 r
F
.70199 .29321 m .70054 .29116 L .70362 .28996 L F
.69439 .29363 m .69601 .29038 L .69747 .29241 L 0 .034 .135 r
F
.69439 .29363 m .69294 .29162 L .69601 .29038 L F
.8054 .29006 m .80722 .28721 L .80855 .28906 L 0 .027 .127 r
F
.8054 .29006 m .80407 .28822 L .80722 .28721 L F
.21347 .28944 m .21436 .28652 L .21629 .28842 L 0 .026 .125 r
F
.21347 .28944 m .21153 .28754 L .21436 .28652 L F
.57279 .3004 m .57423 .29697 L .5758 .29893 L 0 .049 .152 r
F
.57279 .3004 m .57122 .2984 L .57423 .29697 L F
.61839 .29788 m .61989 .29437 L .62142 .29641 L 0 .043 .145 r
F
.61839 .29788 m .61686 .29581 L .61989 .29437 L F
.5546 .30401 m .55602 .30057 L .55761 .30259 L 0 .059 .161 r
F
.5546 .30401 m .55301 .30195 L .55602 .30057 L F
.29109 .29033 m .29209 .28748 L .29395 .28939 L 0 .028 .127 r
F
.29109 .29033 m .28923 .28841 L .29209 .28748 L F
.61079 .29836 m .61229 .29514 L .61383 .2972 L 0 .045 .147 r
F
.61079 .29836 m .60925 .29625 L .61229 .29514 L F
.7096 .29288 m .71125 .28988 L .71269 .29181 L 0 .033 .134 r
F
.7096 .29288 m .70816 .29095 L .71125 .28988 L F
.7172 .29247 m .71886 .28938 L .72028 .29124 L 0 .032 .132 r
F
.7172 .29247 m .71577 .29063 L .71886 .28938 L F
.17845 .2889 m .17929 .28591 L .18126 .2878 L 0 .025 .124 r
F
.17845 .2889 m .17648 .28699 L .17929 .28591 L F
.09323 .28848 m .09394 .28544 L .09599 .28745 L 0 .024 .122 r
F
.09323 .28848 m .09118 .28648 L .09394 .28544 L F
.3185 .29144 m .31955 .28851 L .32137 .29053 L 0 .03 .13 r
F
.3185 .29144 m .31667 .28942 L .31955 .28851 L F
.34591 .2925 m .34701 .28939 L .34879 .29158 L 0 .032 .133 r
F
.34591 .2925 m .34412 .29034 L .34701 .28939 L F
.13584 .28871 m .13661 .28568 L .13862 .28763 L 0 .025 .123 r
F
.13584 .28871 m .13383 .28675 L .13661 .28568 L F
.74 .29127 m .7417 .28822 L .74311 .29022 L 0 .03 .13 r
F
.74 .29127 m .73859 .28929 L .7417 .28822 L F
.24847 .29024 m .24942 .2872 L .25132 .28912 L 0 .028 .127 r
F
.24847 .29024 m .24657 .28831 L .24942 .2872 L F
.18604 .28856 m .18688 .28569 L .18885 .28757 L 0 .025 .123 r
F
.18604 .28856 m .18407 .28669 L .18688 .28569 L F
.43275 .29806 m .43399 .29462 L .43569 .29698 L 0 .044 .146 r
F
.43275 .29806 m .43105 .29567 L .43399 .29462 L F
.49218 .3025 m .49351 .29907 L .49515 .30137 L 0 .055 .158 r
F
.49218 .3025 m .49053 .30021 L .49351 .29907 L F
.75521 .29053 m .75695 .28769 L .75833 .28953 L 0 .029 .128 r
F
.75521 .29053 m .75383 .28869 L .75695 .28769 L F
.81303 .2899 m .81485 .28699 L .81617 .28885 L 0 .027 .127 r
F
.81303 .2899 m .8117 .28805 L .81485 .28699 L F
.25606 .28991 m .25702 .2869 L .25891 .28881 L 0 .027 .126 r
F
.25606 .28991 m .25417 .288 L .25702 .2869 L F
.42053 .29623 m .42175 .29303 L .42347 .29523 L 0 .04 .142 r
F
.42053 .29623 m .41881 .29409 L .42175 .29303 L F
.14342 .28848 m .1442 .2855 L .1462 .28742 L 0 .024 .123 r
F
.14342 .28848 m .14141 .28656 L .1442 .2855 L F
.74762 .29102 m .74932 .28787 L .75072 .28984 L 0 .029 .129 r
F
.74762 .29102 m .74622 .28905 L .74932 .28787 L F
.22104 .28935 m .22193 .28651 L .22386 .28839 L 0 .026 .125 r
F
.22104 .28935 m .21911 .28746 L .22193 .28651 L F
.51959 .30369 m .52096 .29984 L .52258 .30242 L 0 .058 .16 r
F
.51959 .30369 m .51797 .30114 L .52096 .29984 L F
.40072 .29485 m .4019 .29189 L .40364 .29398 L 0 .038 .139 r
F
.40072 .29485 m .39898 .29275 L .4019 .29189 L F
.82064 .28963 m .82247 .28665 L .82379 .28856 L 0 .027 .126 r
F
.82064 .28963 m .81932 .28775 L .82247 .28665 L F
.46015 .29936 m .46143 .29623 L .46311 .29853 L 0 .048 .15 r
F
.46015 .29936 m .45847 .29706 L .46143 .29623 L F
.10078 .2884 m .10149 .28549 L .10354 .28742 L 0 .025 .123 r
F
.10078 .2884 m .09873 .28647 L .10149 .28549 L F
.3809 .29347 m .38206 .29025 L .38382 .29239 L 0 .034 .135 r
F
.3809 .29347 m .37915 .29133 L .38206 .29025 L F
.26364 .2897 m .26462 .28666 L .26649 .28864 L 0 .027 .126 r
F
.26364 .2897 m .26176 .28773 L .26462 .28666 L F
.29866 .29035 m .29968 .2874 L .30153 .28929 L 0 .028 .128 r
F
.29866 .29035 m .29681 .28844 L .29968 .2874 L F
.76283 .29037 m .76458 .28743 L .76595 .28927 L F
.76283 .29037 m .76146 .28853 L .76458 .28743 L F
.77043 .28998 m .77218 .28694 L .77355 .28883 L 0 .027 .127 r
F
.77043 .28998 m .76907 .28811 L .77218 .28694 L F
.15099 .28829 m .15178 .28534 L .15378 .28724 L 0 .024 .123 r
F
.15099 .28829 m .14899 .28638 L .15178 .28534 L F
.6366 .29484 m .63814 .29159 L .63965 .29366 L 0 .037 .139 r
F
.6366 .29484 m .63509 .29279 L .63814 .29159 L F
.65181 .29403 m .65336 .29072 L .65486 .29281 L 0 .035 .137 r
F
.65181 .29403 m .65031 .29194 L .65336 .29072 L F
.53874 .4442 m .54003 .41613 L .54168 .42674 L 0 .497 .088 r
F
.53874 .4442 m .53709 .43175 L .54003 .41613 L F
.50244 .45541 m .5009 .4389 L .50381 .4486 L .05 .559 0 r
F
.32606 .29154 m .32712 .28867 L .32894 .29057 L 0 .031 .131 r
F
.32606 .29154 m .32424 .28961 L .32712 .28867 L F
.1936 .28859 m .19445 .28561 L .1964 .28762 L 0 .025 .124 r
F
.1936 .28859 m .19165 .28659 L .19445 .28561 L F
.35348 .29263 m .3546 .28939 L .35638 .29151 L 0 .033 .133 r
F
.35348 .29263 m .35169 .29049 L .3546 .28939 L F
.5652 .30153 m .56663 .29801 L .56821 .29997 L 0 .053 .156 r
F
.5652 .30153 m .56362 .29955 L .56663 .29801 L F
.10835 .28825 m .10908 .28522 L .11112 .28713 L 0 .024 .123 r
F
.10835 .28825 m .1063 .28634 L .10908 .28522 L F
.82827 .28952 m .83013 .28665 L .83144 .28857 L 0 .027 .126 r
F
.82827 .28952 m .82696 .2876 L .83013 .28665 L F
.64421 .29458 m .64575 .29116 L .64726 .29326 L 0 .037 .138 r
F
.64421 .29458 m .6427 .29248 L .64575 .29116 L F
.77805 .28974 m .77982 .28684 L .78119 .28877 L 0 .027 .127 r
F
.77805 .28974 m .77669 .28783 L .77982 .28684 L F
.44033 .29818 m .44159 .29478 L .44328 .29704 L 0 .045 .147 r
F
.44033 .29818 m .43864 .29589 L .44159 .29478 L F
.2286 .28934 m .22952 .28627 L .23144 .28823 L 0 .026 .126 r
F
.2286 .28934 m .22668 .28738 L .22952 .28627 L F
.49978 .30262 m .50111 .29914 L .50276 .30143 L 0 .056 .158 r
F
.49978 .30262 m .49813 .30026 L .50111 .29914 L F
.52719 .3037 m .52857 .29971 L .53019 .30232 L 0 .058 .16 r
F
.52719 .3037 m .52557 .30111 L .52857 .29971 L F
.62901 .29552 m .63053 .29219 L .63205 .29408 L 0 .039 .141 r
F
.62901 .29552 m .62749 .29357 L .63053 .29219 L F
.38849 .29342 m .38965 .29029 L .3914 .29242 L 0 .035 .136 r
F
.38849 .29342 m .38674 .2913 L .38965 .29029 L F
.11593 .28795 m .11667 .285 L .1187 .28693 L 0 .024 .122 r
F
.11593 .28795 m .1139 .28602 L .11667 .285 L F
.47236 .30166 m .47366 .2982 L .47532 .30061 L 0 .054 .156 r
F
.47236 .30166 m .47069 .29925 L .47366 .2982 L F
.30623 .29028 m .30727 .28719 L .30911 .28925 L 0 .028 .128 r
F
.30623 .29028 m .3044 .28822 L .30727 .28719 L F
.65942 .29386 m .66099 .29073 L .66248 .29282 L 0 .036 .137 r
F
.65942 .29386 m .65793 .29177 L .66099 .29073 L F
.15855 .28818 m .15937 .28505 L .16135 .28708 L 0 .024 .123 r
F
.15855 .28818 m .15657 .28615 L .15937 .28505 L F
.36107 .2924 m .36219 .28926 L .36398 .29128 L 0 .033 .133 r
F
.36107 .2924 m .35929 .29039 L .36219 .28926 L F
.33365 .29136 m .33473 .28834 L .33654 .29024 L 0 .031 .131 r
F
.33365 .29136 m .33183 .28946 L .33473 .28834 L F
.44793 .29793 m .44919 .2947 L .45088 .29676 L 0 .045 .147 r
F
.44793 .29793 m .44623 .29587 L .44919 .2947 L F
.27121 .28971 m .2722 .28659 L .27406 .28868 L 0 .027 .127 r
F
.27121 .28971 m .26935 .28761 L .2722 .28659 L F
.53479 .3035 m .53618 .29965 L .53779 .30218 L 0 .058 .16 r
F
.53479 .3035 m .53318 .30093 L .53618 .29965 L F
.52019 .43288 m .52158 .40724 L .5232 .42356 L 0 .471 .138 r
F
.52019 .43288 m .51858 .41502 L .52158 .40724 L F
.23618 .28917 m .23711 .28611 L .23901 .28817 L 0 .026 .126 r
F
.23618 .28917 m .23428 .28713 L .23711 .28611 L F
.68223 .29279 m .68385 .2897 L .68531 .29168 L 0 .034 .135 r
F
.68223 .29279 m .68077 .29085 L .68385 .2897 L F
.50738 .30249 m .50872 .29912 L .51036 .30127 L 0 .056 .159 r
F
.50738 .30249 m .50574 .30027 L .50872 .29912 L F
.42811 .2966 m .42934 .29329 L .43105 .29567 L 0 .042 .144 r
F
.42811 .2966 m .4264 .29426 L .42934 .29329 L F
.36866 .29219 m .36979 .28917 L .37157 .29118 L 0 .033 .133 r
F
.36866 .29219 m .36689 .29016 L .36979 .28917 L F
.84351 .28902 m .84538 .2861 L .84668 .28796 L 0 .026 .126 r
F
.84351 .28902 m .84222 .28716 L .84538 .2861 L F
.20115 .28862 m .20203 .28558 L .20396 .2876 L 0 .026 .124 r
F
.20115 .28862 m .19921 .2866 L .20203 .28558 L F
.83591 .28946 m .83776 .28643 L .83906 .28831 L 0 .027 .126 r
F
.83591 .28946 m .83461 .28757 L .83776 .28643 L F
.16613 .288 m .16694 .285 L .16892 .28702 L 0 .024 .123 r
F
.16613 .288 m .16415 .28598 L .16694 .285 L F
.40829 .29519 m .40948 .29219 L .41122 .29425 L 0 .039 .141 r
F
.40829 .29519 m .40656 .29312 L .40948 .29219 L F
.67464 .29329 m .67623 .29013 L .6777 .29207 L 0 .035 .136 r
F
.67464 .29329 m .67316 .29137 L .67623 .29013 L F
.78569 .28972 m .78746 .28673 L .78882 .2887 L 0 .028 .127 r
F
.78569 .28972 m .78433 .28777 L .78746 .28673 L F
.47996 .30155 m .48126 .2982 L .48293 .30038 L 0 .054 .157 r
F
.47996 .30155 m .47829 .2994 L .48126 .2982 L F
.66704 .29376 m .66862 .29051 L .6701 .29257 L 0 .036 .137 r
F
.66704 .29376 m .66555 .29168 L .66862 .29051 L F
.59101 .29803 m .59248 .29478 L .59403 .29678 L 0 .046 .148 r
F
.59101 .29803 m .58945 .29604 L .59248 .29478 L F
.34123 .29129 m .34232 .28821 L .34412 .29034 L 0 .031 .131 r
F
.34123 .29129 m .33943 .2892 L .34232 .28821 L F
.5424 .30335 m .54379 .29959 L .5454 .30203 L 0 .058 .161 r
F
.5424 .30335 m .54079 .30087 L .54379 .29959 L F
.12348 .28796 m .12424 .28487 L .12625 .28691 L 0 .024 .123 r
F
.12348 .28796 m .12147 .28592 L .12424 .28487 L F
.5758 .29893 m .57725 .29584 L .57882 .29778 L 0 .048 .151 r
F
.5758 .29893 m .57423 .29697 L .57725 .29584 L F
.62142 .29641 m .62293 .29296 L .62445 .29496 L 0 .041 .144 r
F
.62142 .29641 m .61989 .29437 L .62293 .29296 L F
.85114 .28882 m .85303 .28595 L .85431 .28782 L 0 .026 .125 r
F
.85114 .28882 m .84985 .28696 L .85303 .28595 L F
.45552 .29789 m .45679 .29497 L .45847 .29706 L 0 .046 .149 r
F
.45552 .29789 m .45384 .29582 L .45679 .29497 L F
.58341 .29853 m .58487 .29539 L .58643 .2973 L 0 .047 .15 r
F
.58341 .29853 m .58184 .29662 L .58487 .29539 L F
.68985 .29263 m .69148 .2896 L .69294 .29162 L 0 .034 .135 r
F
.68985 .29263 m .68839 .29064 L .69148 .2896 L F
.27878 .28969 m .27979 .28651 L .28164 .28857 L 0 .028 .127 r
F
.27878 .28969 m .27692 .28762 L .27979 .28651 L F
.3138 .29036 m .31485 .28732 L .31667 .28942 L 0 .029 .129 r
F
.3138 .29036 m .31198 .28829 L .31485 .28732 L F
.55761 .30259 m .55902 .29907 L .56061 .30107 L 0 .057 .159 r
F
.55761 .30259 m .55602 .30057 L .55902 .29907 L F
.79331 .28953 m .79511 .28663 L .79645 .28848 L 0 .028 .127 r
F
.79331 .28953 m .79196 .28767 L .79511 .28663 L F
.59861 .29776 m .60009 .29426 L .60164 .29644 L 0 .045 .147 r
F
.59861 .29776 m .59706 .29552 L .60009 .29426 L F
.60622 .29736 m .60771 .29418 L .60925 .29625 L 0 .044 .147 r
F
.60622 .29736 m .60467 .29524 L .60771 .29418 L F
.48756 .30138 m .48888 .29797 L .49053 .30021 L 0 .054 .157 r
F
.48756 .30138 m .4859 .29918 L .48888 .29797 L F
.51498 .30243 m .51634 .29873 L .51797 .30114 L 0 .056 .159 r
F
.51498 .30243 m .51335 .30005 L .51634 .29873 L F
.20872 .28856 m .2096 .28555 L .21153 .28754 L 0 .026 .125 r
F
.20872 .28856 m .20678 .28657 L .2096 .28555 L F
.39606 .29362 m .39724 .29064 L .39898 .29275 L 0 .036 .138 r
F
.39606 .29362 m .39432 .29153 L .39724 .29064 L F
.28637 .28942 m .28737 .28645 L .28923 .28841 L 0 .028 .127 r
F
.28637 .28942 m .28451 .28745 L .28737 .28645 L F
.72788 .29071 m .72956 .28761 L .73097 .28954 L 0 .03 .13 r
F
.72788 .29071 m .72646 .28881 L .72956 .28761 L F
.08842 .28755 m .08913 .28447 L .09118 .28648 L 0 .024 .122 r
F
.08842 .28755 m .08637 .28555 L .08913 .28447 L F
.55 .30316 m .55141 .2997 L .55301 .30195 L 0 .059 .161 r
F
.55 .30316 m .5484 .30086 L .55141 .2997 L F
.69747 .29241 m .69909 .28912 L .70054 .29116 L 0 .033 .134 r
F
.69747 .29241 m .69601 .29038 L .69909 .28912 L F
.80093 .28927 m .80274 .28638 L .80407 .28822 L 0 .028 .127 r
F
.80093 .28927 m .79959 .28742 L .80274 .28638 L F
.24374 .28928 m .24468 .28623 L .24657 .28831 L 0 .027 .127 r
F
.24374 .28928 m .24184 .28721 L .24468 .28623 L F
.70507 .29202 m .70672 .2889 L .70816 .29095 L 0 .033 .134 r
F
.70507 .29202 m .70362 .28996 L .70672 .2889 L F
.17368 .28802 m .17451 .28503 L .17648 .28699 L 0 .025 .124 r
F
.17368 .28802 m .17171 .28605 L .17451 .28503 L F
.41588 .2952 m .41709 .29194 L .41881 .29409 L 0 .04 .141 r
F
.41588 .2952 m .41415 .2931 L .41709 .29194 L F
.73549 .29037 m .73718 .28731 L .73859 .28929 L 0 .03 .13 r
F
.73549 .29037 m .73408 .2884 L .73718 .28731 L F
.13104 .28785 m .13182 .28473 L .13383 .28675 L 0 .025 .123 r
F
.13104 .28785 m .12904 .28582 L .13182 .28473 L F
.72028 .29124 m .72195 .28814 L .72337 .29001 L 0 .031 .132 r
F
.72028 .29124 m .71886 .28938 L .72195 .28814 L F
.37624 .29231 m .37738 .28925 L .37915 .29133 L 0 .034 .134 r
F
.37624 .29231 m .37447 .29022 L .37738 .28925 L F
.46773 .30012 m .46902 .29683 L .47069 .29925 L 0 .051 .154 r
F
.46773 .30012 m .46606 .29768 L .46902 .29683 L F
.61383 .2972 m .61533 .29378 L .61686 .29581 L 0 .044 .146 r
F
.61383 .2972 m .61229 .29514 L .61533 .29378 L F
.21629 .28842 m .21717 .28557 L .21911 .28746 L 0 .026 .125 r
F
.21629 .28842 m .21436 .28652 L .21717 .28557 L F
.80855 .28906 m .81038 .2862 L .8117 .28805 L 0 .027 .127 r
F
.80855 .28906 m .80722 .28721 L .81038 .2862 L F
.18126 .2878 m .1821 .28482 L .18407 .28669 L 0 .025 .123 r
F
.18126 .2878 m .17929 .28591 L .1821 .28482 L F
.71269 .29181 m .71434 .28869 L .71577 .29063 L 0 .033 .133 r
F
.71269 .29181 m .71125 .28988 L .71434 .28869 L F
.13862 .28763 m .1394 .28461 L .14141 .28656 L 0 .024 .123 r
F
.13862 .28763 m .13661 .28568 L .1394 .28461 L F
.25132 .28912 m .25227 .28609 L .25417 .288 L 0 .027 .127 r
F
.25132 .28912 m .24942 .2872 L .25227 .28609 L F
.09599 .28745 m .09669 .28446 L .09873 .28647 L 0 .024 .123 r
F
.09599 .28745 m .09394 .28544 L .09669 .28446 L F
.52258 .30242 m .52395 .2985 L .52557 .30111 L 0 .056 .159 r
F
.52258 .30242 m .52096 .29984 L .52395 .2985 L F
.49515 .30137 m .49649 .298 L .49813 .30026 L 0 .055 .157 r
F
.49515 .30137 m .49351 .29907 L .49649 .298 L F
.74311 .29022 m .74481 .28704 L .74622 .28905 L 0 .029 .129 r
F
.74311 .29022 m .7417 .28822 L .74481 .28704 L F
.43569 .29698 m .43694 .29356 L .43864 .29589 L 0 .044 .146 r
F
.43569 .29698 m .43399 .29462 L .43694 .29356 L F
.29395 .28939 m .29495 .28655 L .29681 .28844 L 0 .028 .128 r
F
.29395 .28939 m .29209 .28748 L .29495 .28655 L F
.75072 .28984 m .75243 .28671 L .75383 .28869 L 0 .029 .128 r
F
.75072 .28984 m .74932 .28787 L .75243 .28671 L F
.56821 .29997 m .56964 .29647 L .57122 .2984 L 0 .051 .154 r
F
.56821 .29997 m .56663 .29801 L .56964 .29647 L F
.25891 .28881 m .25987 .28582 L .26176 .28773 L 0 .027 .126 r
F
.25891 .28881 m .25702 .2869 L .25987 .28582 L F
.18885 .28757 m .18968 .28472 L .19165 .28659 L 0 .025 .123 r
F
.18885 .28757 m .18688 .28569 L .18968 .28472 L F
.32137 .29053 m .32242 .2876 L .32424 .28961 L 0 .03 .131 r
F
.32137 .29053 m .31955 .28851 L .32242 .2876 L F
.34879 .29158 m .34991 .28831 L .35169 .29049 L 0 .032 .133 r
F
.34879 .29158 m .34701 .28939 L .34991 .28831 L F
.81617 .28885 m .818 .28586 L .81932 .28775 L 0 .027 .126 r
F
.81617 .28885 m .81485 .28699 L .818 .28586 L F
.1462 .28742 m .14698 .28447 L .14899 .28638 L 0 .024 .123 r
F
.1462 .28742 m .1442 .2855 L .14698 .28447 L F
.75833 .28953 m .76008 .28669 L .76146 .28853 L 0 .029 .128 r
F
.75833 .28953 m .75695 .28769 L .76008 .28669 L F
.42347 .29523 m .42469 .292 L .4264 .29426 L 0 .04 .142 r
F
.42347 .29523 m .42175 .29303 L .42469 .292 L F
.82379 .28856 m .82564 .28567 L .82696 .2876 L 0 .027 .126 r
F
.82379 .28856 m .82247 .28665 L .82564 .28567 L F
.54845 .46494 m .54688 .468 L .54976 .44805 L .056 .561 0 r
F
.54688 .468 m .54819 .45031 L .54976 .44805 L .101 .579 0 r
F
.38382 .29239 m .38498 .28918 L .38674 .2913 L 0 .034 .135 r
F
.38382 .29239 m .38206 .29025 L .38498 .28918 L F
.65486 .29281 m .65643 .28968 L .65793 .29177 L 0 .035 .136 r
F
.65486 .29281 m .65336 .29072 L .65643 .28968 L F
.63205 .29408 m .63358 .29093 L .63509 .29279 L 0 .038 .14 r
F
.63205 .29408 m .63053 .29219 L .63358 .29093 L F
.63965 .29366 m .64119 .29039 L .6427 .29248 L 0 .037 .138 r
F
.63965 .29366 m .63814 .29159 L .64119 .29039 L F
.22386 .28839 m .22476 .2855 L .22668 .28738 L 0 .027 .126 r
F
.22386 .28839 m .22193 .28651 L .22476 .2855 L F
.53019 .30232 m .53157 .29831 L .53318 .30093 L 0 .056 .159 r
F
.53019 .30232 m .52857 .29971 L .53157 .29831 L F
.77355 .28883 m .77532 .28592 L .77669 .28783 L 0 .027 .127 r
F
.77355 .28883 m .77218 .28694 L .77532 .28592 L F
.64726 .29326 m .6488 .28983 L .65031 .29194 L 0 .036 .137 r
F
.64726 .29326 m .64575 .29116 L .6488 .28983 L F
.26649 .28864 m .26747 .28564 L .26935 .28761 L 0 .027 .126 r
F
.26649 .28864 m .26462 .28666 L .26747 .28564 L F
.76595 .28927 m .76769 .28624 L .76907 .28811 L 0 .028 .128 r
F
.76595 .28927 m .76458 .28743 L .76769 .28624 L F
.30153 .28929 m .30255 .28637 L .3044 .28822 L F
.30153 .28929 m .29968 .2874 L .30255 .28637 L F
.10354 .28742 m .10426 .28442 L .1063 .28634 L 0 .025 .123 r
F
.10354 .28742 m .10149 .28549 L .10426 .28442 L F
.50817 .44079 m .50662 .42223 L .50959 .42462 L 0 .508 .068 r
F
.5052 .43769 m .50662 .42223 L .50817 .44079 L 0 .493 .097 r
F
.40364 .29398 m .40482 .29103 L .40656 .29312 L 0 .038 .14 r
F
.40364 .29398 m .4019 .29189 L .40482 .29103 L F
.15378 .28724 m .15457 .28425 L .15657 .28615 L 0 .024 .123 r
F
.15378 .28724 m .15178 .28534 L .15457 .28425 L F
.35638 .29151 m .35751 .28827 L .35929 .29039 L 0 .032 .133 r
F
.35638 .29151 m .3546 .28939 L .35751 .28827 L F
.50276 .30143 m .5041 .29804 L .50574 .30027 L 0 .056 .158 r
F
.50276 .30143 m .50111 .29914 L .5041 .29804 L F
.44328 .29704 m .44454 .29363 L .44623 .29587 L 0 .045 .147 r
F
.44328 .29704 m .44159 .29478 L .44454 .29363 L F
.11112 .28713 m .11186 .28412 L .1139 .28602 L 0 .024 .123 r
F
.11112 .28713 m .10908 .28522 L .11186 .28412 L F
.46311 .29853 m .46439 .29539 L .46606 .29768 L 0 .049 .151 r
F
.46311 .29853 m .46143 .29623 L .46439 .29539 L F
.23144 .28823 m .23237 .28515 L .23428 .28713 L 0 .026 .125 r
F
.23144 .28823 m .22952 .28627 L .23237 .28515 L F
.1964 .28762 m .19727 .28461 L .19921 .2866 L 0 .025 .124 r
F
.1964 .28762 m .19445 .28561 L .19727 .28461 L F
.32894 .29057 m .33001 .28755 L .33183 .28946 L 0 .031 .131 r
F
.32894 .29057 m .32712 .28867 L .33001 .28755 L F
.53779 .30218 m .53918 .29839 L .54079 .30087 L 0 .057 .159 r
F
.53779 .30218 m .53618 .29965 L .53918 .29839 L F
.45088 .29676 m .45214 .29375 L .45384 .29582 L 0 .045 .147 r
F
.45088 .29676 m .44919 .2947 L .45214 .29375 L F
.36398 .29128 m .36511 .28814 L .36689 .29016 L 0 .032 .133 r
F
.36398 .29128 m .36219 .28926 L .36511 .28814 L F
.16135 .28708 m .16218 .28395 L .16415 .28598 L 0 .024 .122 r
F
.16135 .28708 m .15937 .28505 L .16218 .28395 L F
.33654 .29024 m .33762 .28728 L .33943 .2892 L 0 .031 .131 r
F
.33654 .29024 m .33473 .28834 L .33762 .28728 L F
.78119 .28877 m .78296 .28582 L .78433 .28777 L 0 .028 .127 r
F
.78119 .28877 m .77982 .28684 L .78296 .28582 L F
.54428 .47969 m .54276 .494 L .54569 .47878 L .217 .619 0 r
F
.54133 .49242 m .54276 .494 L .54428 .47969 L .381 .67 0 r
F
.83144 .28857 m .8333 .28566 L .83461 .28757 L 0 .027 .127 r
F
.83144 .28857 m .83013 .28665 L .8333 .28566 L F
.47532 .30061 m .47663 .29697 L .47829 .2994 L 0 .053 .156 r
F
.47532 .30061 m .47366 .2982 L .47663 .29697 L F
.66248 .29282 m .66406 .28961 L .66555 .29168 L 0 .036 .137 r
F
.66248 .29282 m .66099 .29073 L .66406 .28961 L F
.51036 .30127 m .51171 .29796 L .51335 .30005 L 0 .056 .158 r
F
.51036 .30127 m .50872 .29912 L .51171 .29796 L F
.30911 .28925 m .31015 .28621 L .31198 .28829 L 0 .029 .128 r
F
.30911 .28925 m .30727 .28719 L .31015 .28621 L F
.3914 .29242 m .39257 .28937 L .39432 .29153 L 0 .035 .136 r
F
.3914 .29242 m .38965 .29029 L .39257 .28937 L F
.1187 .28693 m .11944 .28397 L .12147 .28592 L 0 .024 .123 r
F
.1187 .28693 m .11667 .285 L .11944 .28397 L F
.56061 .30107 m .56203 .29757 L .56362 .29955 L 0 .055 .157 r
F
.56061 .30107 m .55902 .29907 L .56203 .29757 L F
.62445 .29496 m .62597 .29163 L .62749 .29357 L 0 .04 .142 r
F
.62445 .29496 m .62293 .29296 L .62597 .29163 L F
.27406 .28868 m .27506 .28555 L .27692 .28762 L 0 .027 .127 r
F
.27406 .28868 m .2722 .28659 L .27506 .28555 L F
.6777 .29207 m .6793 .2889 L .68077 .29085 L 0 .034 .135 r
F
.6777 .29207 m .67623 .29013 L .6793 .2889 L F
.68531 .29168 m .68693 .28863 L .68839 .29064 L F
.68531 .29168 m .68385 .2897 L .68693 .28863 L F
.83906 .28831 m .84092 .28528 L .84222 .28716 L 0 .027 .126 r
F
.83906 .28831 m .83776 .28643 L .84092 .28528 L F
.5454 .30203 m .5468 .29845 L .5484 .30086 L 0 .057 .16 r
F
.5454 .30203 m .54379 .29959 L .5468 .29845 L F
.59403 .29678 m .59551 .29353 L .59706 .29552 L 0 .045 .147 r
F
.59403 .29678 m .59248 .29478 L .59551 .29353 L F
.6701 .29257 m .67169 .28934 L .67316 .29137 L 0 .035 .137 r
F
.6701 .29257 m .66862 .29051 L .67169 .28934 L F
.48293 .30038 m .48424 .29696 L .4859 .29918 L 0 .054 .156 r
F
.48293 .30038 m .48126 .2982 L .48424 .29696 L F
.84668 .28796 m .84856 .28509 L .84985 .28696 L 0 .026 .126 r
F
.84668 .28796 m .84538 .2861 L .84856 .28509 L F
.23901 .28817 m .23995 .28514 L .24184 .28721 L 0 .027 .126 r
F
.23901 .28817 m .23711 .28611 L .23995 .28514 L F
.60164 .29644 m .60313 .29311 L .60467 .29524 L 0 .044 .146 r
F
.60164 .29644 m .60009 .29426 L .60313 .29311 L F
.58643 .2973 m .58789 .29412 L .58945 .29604 L 0 .046 .149 r
F
.58643 .2973 m .58487 .29539 L .58789 .29412 L F
.37157 .29118 m .3727 .28825 L .37447 .29022 L 0 .033 .134 r
F
.37157 .29118 m .36979 .28917 L .3727 .28825 L F
.20396 .2876 m .20485 .28456 L .20678 .28657 L 0 .026 .124 r
F
.20396 .2876 m .20203 .28558 L .20485 .28456 L F
.51797 .30114 m .51933 .29741 L .52096 .29984 L 0 .055 .158 r
F
.51797 .30114 m .51634 .29873 L .51933 .29741 L F
.78882 .2887 m .79061 .28568 L .79196 .28767 L 0 .028 .127 r
F
.78882 .2887 m .78746 .28673 L .79061 .28568 L F
.57882 .29778 m .58028 .2947 L .58184 .29662 L 0 .048 .15 r
F
.57882 .29778 m .57725 .29584 L .58028 .2947 L F
.43105 .29567 m .43229 .29227 L .43399 .29462 L 0 .042 .144 r
F
.43105 .29567 m .42934 .29329 L .43229 .29227 L F
.16892 .28702 m .16974 .28403 L .17171 .28605 L 0 .025 .123 r
F
.16892 .28702 m .16694 .285 L .16974 .28403 L F
.08361 .28663 m .08431 .28361 L .08637 .28555 L 0 .024 .122 r
F
.08361 .28663 m .08155 .28469 L .08431 .28361 L F
.41122 .29425 m .41242 .29102 L .41415 .2931 L 0 .039 .141 r
F
.41122 .29425 m .40948 .29219 L .41242 .29102 L F
.28164 .28857 m .28265 .2854 L .28451 .28745 L 0 .027 .127 r
F
.28164 .28857 m .27979 .28651 L .28265 .2854 L F
.12625 .28691 m .12703 .28379 L .12904 .28582 L 0 .024 .123 r
F
.12625 .28691 m .12424 .28487 L .12703 .28379 L F
.49053 .30021 m .49185 .29681 L .49351 .29907 L 0 .054 .156 r
F
.49053 .30021 m .48888 .29797 L .49185 .29681 L F
.70054 .29116 m .70217 .2879 L .70362 .28996 L 0 .033 .133 r
F
.70054 .29116 m .69909 .28912 L .70217 .2879 L F
.61686 .29581 m .61836 .29237 L .61989 .29437 L 0 .043 .145 r
F
.61686 .29581 m .61533 .29378 L .61836 .29237 L F
.55301 .30195 m .55442 .29836 L .55602 .30057 L 0 .058 .16 r
F
.55301 .30195 m .55141 .2997 L .55442 .29836 L F
.60925 .29625 m .61075 .29311 L .61229 .29514 L 0 .044 .147 r
F
.60925 .29625 m .60771 .29418 L .61075 .29311 L F
.34412 .29034 m .34522 .28722 L .34701 .28939 L 0 .031 .132 r
F
.34412 .29034 m .34232 .28821 L .34522 .28722 L F
.69294 .29162 m .69455 .28834 L .69601 .29038 L 0 .034 .135 r
F
.69294 .29162 m .69148 .2896 L .69455 .28834 L F
.79645 .28848 m .79825 .28558 L .79959 .28742 L 0 .028 .127 r
F
.79645 .28848 m .79511 .28663 L .79825 .28558 L F
.73097 .28954 m .73266 .28644 L .73408 .2884 L 0 .03 .13 r
F
.73097 .28954 m .72956 .28761 L .73266 .28644 L F
.57122 .2984 m .57266 .29505 L .57423 .29697 L 0 .049 .152 r
F
.57122 .2984 m .56964 .29647 L .57266 .29505 L F
.72337 .29001 m .72504 .28691 L .72646 .28881 L 0 .031 .131 r
F
.72337 .29001 m .72195 .28814 L .72504 .28691 L F
.31667 .28942 m .31772 .28641 L .31955 .28851 L 0 .03 .13 r
F
.31667 .28942 m .31485 .28732 L .31772 .28641 L F
.09118 .28648 m .09189 .28343 L .09394 .28544 L 0 .024 .122 r
F
.09118 .28648 m .08913 .28447 L .09189 .28343 L F
.21153 .28754 m .21243 .28452 L .21436 .28652 L 0 .026 .125 r
F
.21153 .28754 m .2096 .28555 L .21243 .28452 L F
.41881 .29409 m .42003 .29082 L .42175 .29303 L 0 .039 .141 r
F
.41881 .29409 m .41709 .29194 L .42003 .29082 L F
.28923 .28841 m .29023 .28553 L .29209 .28748 L 0 .028 .127 r
F
.28923 .28841 m .28737 .28645 L .29023 .28553 L F
.45847 .29706 m .45974 .29412 L .46143 .29623 L 0 .047 .149 r
F
.45847 .29706 m .45679 .29497 L .45974 .29412 L F
.70816 .29095 m .70981 .28782 L .71125 .28988 L 0 .033 .133 r
F
.70816 .29095 m .70672 .2889 L .70981 .28782 L F
.80407 .28822 m .80589 .28537 L .80722 .28721 L 0 .028 .127 r
F
.80407 .28822 m .80274 .28638 L .80589 .28537 L F
.13383 .28675 m .13461 .28366 L .13661 .28568 L 0 .024 .123 r
F
.13383 .28675 m .13182 .28473 L .13461 .28366 L F
.52557 .30111 m .52695 .29709 L .52857 .29971 L 0 .055 .158 r
F
.52557 .30111 m .52395 .2985 L .52695 .29709 L F
.73859 .28929 m .74029 .28622 L .7417 .28822 L 0 .029 .129 r
F
.73859 .28929 m .73718 .28731 L .74029 .28622 L F
.17648 .28699 m .17732 .28396 L .17929 .28591 L 0 .025 .124 r
F
.17648 .28699 m .17451 .28503 L .17732 .28396 L F
.71577 .29063 m .71743 .28744 L .71886 .28938 L 0 .032 .133 r
F
.71577 .29063 m .71434 .28869 L .71743 .28744 L F
.24657 .28831 m .24753 .28514 L .24942 .2872 L 0 .027 .127 r
F
.24657 .28831 m .24468 .28623 L .24753 .28514 L F
.39898 .29275 m .40016 .28979 L .4019 .29189 L 0 .037 .139 r
F
.39898 .29275 m .39724 .29064 L .40016 .28979 L F
.52632 .49705 m .52772 .51849 L .52932 .50179 L .511 .705 0 r
F
.52632 .49705 m .5247 .513 L .52772 .51849 L F
.37915 .29133 m .3803 .2882 L .38206 .29025 L 0 .034 .135 r
F
.37915 .29133 m .37738 .28925 L .3803 .2882 L F
.18407 .28669 m .18491 .28382 L .18688 .28569 L 0 .025 .123 r
F
.18407 .28669 m .1821 .28482 L .18491 .28382 L F
.74622 .28905 m .74792 .28584 L .74932 .28787 L 0 .029 .129 r
F
.74622 .28905 m .74481 .28704 L .74792 .28584 L F
.25417 .288 m .25512 .28499 L .25702 .2869 L 0 .027 .126 r
F
.25417 .288 m .25227 .28609 L .25512 .28499 L F
.49813 .30026 m .49947 .29693 L .50111 .29914 L 0 .055 .157 r
F
.49813 .30026 m .49649 .298 L .49947 .29693 L F
.14141 .28656 m .14219 .28355 L .1442 .2855 L 0 .024 .123 r
F
.14141 .28656 m .1394 .28461 L .14219 .28355 L F
.8117 .28805 m .81353 .28513 L .81485 .28699 L 0 .027 .127 r
F
.8117 .28805 m .81038 .2862 L .81353 .28513 L F
.75383 .28869 m .75556 .28571 L .75695 .28769 L 0 .029 .128 r
F
.75383 .28869 m .75243 .28671 L .75556 .28571 L F
.53318 .30093 m .53457 .29707 L .53618 .29965 L 0 .055 .158 r
F
.53318 .30093 m .53157 .29831 L .53457 .29707 L F
.47069 .29925 m .47199 .29578 L .47366 .2982 L 0 .052 .154 r
F
.47069 .29925 m .46902 .29683 L .47199 .29578 L F
.43864 .29589 m .43989 .29248 L .44159 .29478 L 0 .044 .146 r
F
.43864 .29589 m .43694 .29356 L .43989 .29248 L F
.21911 .28746 m .21999 .28462 L .22193 .28651 L 0 .026 .126 r
F
.21911 .28746 m .21717 .28557 L .21999 .28462 L F
.65031 .29194 m .65186 .28862 L .65336 .29072 L 0 .035 .136 r
F
.65031 .29194 m .6488 .28983 L .65186 .28862 L F
.63509 .29279 m .63663 .28974 L .63814 .29159 L 0 .037 .139 r
F
.63509 .29279 m .63358 .29093 L .63663 .28974 L F
.26176 .28773 m .26273 .28474 L .26462 .28666 L 0 .027 .126 r
F
.26176 .28773 m .25987 .28582 L .26273 .28474 L F
.09873 .28647 m .09945 .28349 L .10149 .28549 L 0 .024 .123 r
F
.09873 .28647 m .09669 .28446 L .09945 .28349 L F
.35169 .29049 m .35281 .28723 L .3546 .28939 L 0 .032 .133 r
F
.35169 .29049 m .34991 .28831 L .35281 .28723 L F
.81932 .28775 m .82115 .28473 L .82247 .28665 L 0 .027 .126 r
F
.81932 .28775 m .818 .28586 L .82115 .28473 L F
.29681 .28844 m .29782 .28554 L .29968 .2874 L 0 .028 .128 r
F
.29681 .28844 m .29495 .28655 L .29782 .28554 L F
.6427 .29248 m .64424 .28906 L .64575 .29116 L 0 .036 .137 r
F
.6427 .29248 m .64119 .29039 L .64424 .28906 L F
.14899 .28638 m .14977 .28344 L .15178 .28534 L 0 .025 .123 r
F
.14899 .28638 m .14698 .28447 L .14977 .28344 L F
.19165 .28659 m .19249 .28374 L .19445 .28561 L 0 .025 .124 r
F
.19165 .28659 m .18968 .28472 L .19249 .28374 L F
.76907 .28811 m .77081 .28505 L .77218 .28694 L 0 .028 .127 r
F
.76907 .28811 m .76769 .28624 L .77081 .28505 L F
.76146 .28853 m .7632 .28558 L .76458 .28743 L 0 .029 .128 r
F
.76146 .28853 m .76008 .28669 L .7632 .28558 L F
.32424 .28961 m .3253 .28667 L .32712 .28867 L 0 .031 .131 r
F
.32424 .28961 m .32242 .2876 L .3253 .28667 L F
.38674 .2913 m .3879 .28816 L .38965 .29029 L 0 .034 .135 r
F
.38674 .2913 m .38498 .28918 L .3879 .28816 L F
.4264 .29426 m .42763 .29097 L .42934 .29329 L 0 .04 .142 r
F
.4264 .29426 m .42469 .292 L .42763 .29097 L F
.56362 .29955 m .56505 .29605 L .56663 .29801 L 0 .053 .155 r
F
.56362 .29955 m .56203 .29757 L .56505 .29605 L F
.65793 .29177 m .6595 .28865 L .66099 .29073 L 0 .035 .136 r
F
.65793 .29177 m .65643 .28968 L .6595 .28865 L F
.54079 .30087 m .54219 .29716 L .54379 .29959 L 0 .056 .158 r
F
.54079 .30087 m .53918 .29839 L .54219 .29716 L F
.3044 .28822 m .30543 .28534 L .30727 .28719 L 0 .028 .128 r
F
.3044 .28822 m .30255 .28637 L .30543 .28534 L F
.22668 .28738 m .2276 .28439 L .22952 .28627 L 0 .027 .126 r
F
.22668 .28738 m .22476 .2855 L .2276 .28439 L F
.82696 .2876 m .82881 .2847 L .83013 .28665 L F
.82696 .2876 m .82564 .28567 L .82881 .2847 L F
.1063 .28634 m .10703 .28331 L .10908 .28522 L 0 .024 .123 r
F
.1063 .28634 m .10426 .28442 L .10703 .28331 L F
.50574 .30027 m .50708 .29696 L .50872 .29912 L 0 .055 .158 r
F
.50574 .30027 m .5041 .29804 L .50708 .29696 L F
.26935 .28761 m .27032 .28463 L .2722 .28659 L 0 .027 .126 r
F
.26935 .28761 m .26747 .28564 L .27032 .28463 L F
.77669 .28783 m .77846 .2849 L .77982 .28684 L 0 .028 .127 r
F
.77669 .28783 m .77532 .28592 L .77846 .2849 L F
.15657 .28615 m .15738 .28315 L .15937 .28505 L 0 .024 .123 r
F
.15657 .28615 m .15457 .28425 L .15738 .28315 L F
.44623 .29587 m .4475 .29248 L .44919 .2947 L 0 .044 .146 r
F
.44623 .29587 m .44454 .29363 L .4475 .29248 L F
.35929 .29039 m .36042 .28715 L .36219 .28926 L 0 .032 .133 r
F
.35929 .29039 m .35751 .28827 L .36042 .28715 L F
.62749 .29357 m .62902 .2903 L .63053 .29219 L 0 .039 .141 r
F
.62749 .29357 m .62597 .29163 L .62902 .2903 L F
.1139 .28602 m .11463 .28309 L .11667 .285 L 0 .024 .122 r
F
.1139 .28602 m .11186 .28412 L .11463 .28309 L F
.23428 .28713 m .2352 .28412 L .23711 .28611 L 0 .026 .125 r
F
.23428 .28713 m .23237 .28515 L .2352 .28412 L F
.33183 .28946 m .33291 .28643 L .33473 .28834 L 0 .031 .131 r
F
.33183 .28946 m .33001 .28755 L .33291 .28643 L F
.47829 .2994 m .4796 .29574 L .48126 .2982 L 0 .053 .155 r
F
.47829 .2994 m .47663 .29697 L .4796 .29574 L F
.51335 .30005 m .51471 .29663 L .51634 .29873 L 0 .055 .157 r
F
.51335 .30005 m .51171 .29796 L .51471 .29663 L F
.50624 .48347 m .50748 .50074 L .50913 .50249 L .364 .665 0 r
F
.50624 .48347 m .50459 .48171 L .50748 .50074 L F
.36689 .29016 m .36801 .28717 L .36979 .28917 L 0 .032 .133 r
F
.36689 .29016 m .36511 .28814 L .36801 .28717 L F
.40656 .29312 m .40775 .29011 L .40948 .29219 L 0 .039 .141 r
F
.40656 .29312 m .40482 .29103 L .40775 .29011 L F
.19921 .2866 m .20008 .2836 L .20203 .28558 L 0 .025 .124 r
F
.19921 .2866 m .19727 .28461 L .20008 .2836 L F
.16415 .28598 m .16497 .28298 L .16694 .285 L 0 .024 .122 r
F
.16415 .28598 m .16218 .28395 L .16497 .28298 L F
.66555 .29168 m .66713 .28846 L .66862 .29051 L 0 .035 .137 r
F
.66555 .29168 m .66406 .28961 L .66713 .28846 L F
.68077 .29085 m .68238 .28774 L .68385 .2897 L 0 .034 .135 r
F
.68077 .29085 m .6793 .2889 L .68238 .28774 L F
.59706 .29552 m .59854 .29227 L .60009 .29426 L 0 .044 .146 r
F
.59706 .29552 m .59551 .29353 L .59854 .29227 L F
.33943 .2892 m .34052 .28628 L .34232 .28821 L 0 .031 .131 r
F
.33943 .2892 m .33762 .28728 L .34052 .28628 L F
.46606 .29768 m .46735 .29454 L .46902 .29683 L 0 .05 .152 r
F
.46606 .29768 m .46439 .29539 L .46735 .29454 L F
.78433 .28777 m .7861 .28475 L .78746 .28673 L 0 .028 .127 r
F
.78433 .28777 m .78296 .28582 L .7861 .28475 L F
.5484 .30086 m .54981 .29732 L .55141 .2997 L 0 .057 .159 r
F
.5484 .30086 m .5468 .29845 L .54981 .29732 L F
.67316 .29137 m .67476 .28814 L .67623 .29013 L 0 .035 .136 r
F
.67316 .29137 m .67169 .28934 L .67476 .28814 L F
.4859 .29918 m .48722 .29571 L .48888 .29797 L 0 .053 .155 r
F
.4859 .29918 m .48424 .29696 L .48722 .29571 L F
.83461 .28757 m .83646 .28452 L .83776 .28643 L 0 .027 .127 r
F
.83461 .28757 m .8333 .28566 L .83646 .28452 L F
.84222 .28716 m .84409 .28423 L .84538 .2861 L 0 .027 .126 r
F
.84222 .28716 m .84092 .28528 L .84409 .28423 L F
.45384 .29582 m .4551 .29287 L .45679 .29497 L 0 .045 .148 r
F
.45384 .29582 m .45214 .29375 L .4551 .29287 L F
.58945 .29604 m .59092 .29285 L .59248 .29478 L 0 .046 .148 r
F
.58945 .29604 m .58789 .29412 L .59092 .29285 L F
.52096 .29984 m .52233 .29605 L .52395 .2985 L 0 .054 .156 r
F
.52096 .29984 m .51933 .29741 L .52233 .29605 L F
.50298 .47511 m .50137 .46851 L .50424 .48589 L .263 .634 0 r
F
.50137 .46851 m .50266 .47238 L .50424 .48589 L .168 .603 0 r
F
.12147 .28592 m .12222 .28293 L .12424 .28487 L 0 .024 .123 r
F
.12147 .28592 m .11944 .28397 L .12222 .28293 L F
.61989 .29437 m .6214 .29099 L .62293 .29296 L 0 .041 .143 r
F
.61989 .29437 m .61836 .29237 L .6214 .29099 L F
.27692 .28762 m .27792 .28445 L .27979 .28651 L 0 .027 .127 r
F
.27692 .28762 m .27506 .28555 L .27792 .28445 L F
.60467 .29524 m .60617 .2921 L .60771 .29418 L 0 .044 .146 r
F
.60467 .29524 m .60313 .29311 L .60617 .2921 L F
.31198 .28829 m .31303 .28523 L .31485 .28732 L 0 .029 .129 r
F
.31198 .28829 m .31015 .28621 L .31303 .28523 L F
.68839 .29064 m .69002 .28756 L .69148 .2896 L 0 .034 .135 r
F
.68839 .29064 m .68693 .28863 L .69002 .28756 L F
.57423 .29697 m .57568 .2939 L .57725 .29584 L 0 .048 .151 r
F
.57423 .29697 m .57266 .29505 L .57568 .2939 L F
.55602 .30057 m .55743 .29687 L .55902 .29907 L 0 .056 .159 r
F
.55602 .30057 m .55442 .29836 L .55743 .29687 L F
.39432 .29153 m .39549 .28845 L .39724 .29064 L 0 .036 .137 r
F
.39432 .29153 m .39257 .28937 L .39549 .28845 L F
.58184 .29662 m .5833 .29346 L .58487 .29539 L 0 .047 .15 r
F
.58184 .29662 m .58028 .2947 L .5833 .29346 L F
.84985 .28696 m .85174 .28409 L .85303 .28595 L 0 .027 .126 r
F
.84985 .28696 m .84856 .28509 L .85174 .28409 L F
.41415 .2931 m .41537 .28984 L .41709 .29194 L 0 .039 .141 r
F
.41415 .2931 m .41242 .29102 L .41537 .28984 L F
.20678 .28657 m .20767 .28353 L .2096 .28555 L 0 .026 .125 r
F
.20678 .28657 m .20485 .28456 L .20767 .28353 L F
.24184 .28721 m .24278 .28415 L .24468 .28623 L 0 .027 .126 r
F
.24184 .28721 m .23995 .28514 L .24278 .28415 L F
.69601 .29038 m .69763 .28706 L .69909 .28912 L 0 .033 .134 r
F
.69601 .29038 m .69455 .28834 L .69763 .28706 L F
.70362 .28996 m .70527 .28684 L .70672 .2889 L 0 .032 .133 r
F
.70362 .28996 m .70217 .2879 L .70527 .28684 L F
.43399 .29462 m .43524 .29124 L .43694 .29356 L 0 .042 .144 r
F
.43399 .29462 m .43229 .29227 L .43524 .29124 L F
.28451 .28745 m .28552 .28441 L .28737 .28645 L 0 .027 .127 r
F
.28451 .28745 m .28265 .2854 L .28552 .28441 L F
.08637 .28555 m .08707 .28252 L .08913 .28447 L 0 .024 .122 r
F
.08637 .28555 m .08431 .28361 L .08707 .28252 L F
.49351 .29907 m .49484 .29578 L .49649 .298 L 0 .053 .156 r
F
.49351 .29907 m .49185 .29681 L .49484 .29578 L F
.79196 .28767 m .79375 .28462 L .79511 .28663 L 0 .028 .127 r
F
.79196 .28767 m .79061 .28568 L .79375 .28462 L F
.52857 .29971 m .52995 .29569 L .53157 .29831 L 0 .054 .156 r
F
.52857 .29971 m .52695 .29709 L .52995 .29569 L F
.37447 .29022 m .37561 .28731 L .37738 .28925 L 0 .033 .134 r
F
.37447 .29022 m .3727 .28825 L .37561 .28731 L F
.12904 .28582 m .12981 .28271 L .13182 .28473 L 0 .024 .123 r
F
.12904 .28582 m .12703 .28379 L .12981 .28271 L F
.17171 .28605 m .17254 .28302 L .17451 .28503 L 0 .025 .123 r
F
.17171 .28605 m .16974 .28403 L .17254 .28302 L F
.61229 .29514 m .61379 .29179 L .61533 .29378 L 0 .044 .146 r
F
.61229 .29514 m .61075 .29311 L .61379 .29179 L F
.72646 .28881 m .72814 .28567 L .72956 .28761 L 0 .03 .13 r
F
.72646 .28881 m .72504 .28691 L .72814 .28567 L F
.73408 .2884 m .73577 .28533 L .73718 .28731 L 0 .029 .129 r
F
.73408 .2884 m .73266 .28644 L .73577 .28533 L F
.79959 .28742 m .8014 .28453 L .80274 .28638 L 0 .028 .127 r
F
.79959 .28742 m .79825 .28558 L .8014 .28453 L F
.71886 .28938 m .72052 .28619 L .72195 .28814 L 0 .031 .132 r
F
.71886 .28938 m .71743 .28744 L .72052 .28619 L F
.34701 .28939 m .34812 .28616 L .34991 .28831 L F
.34701 .28939 m .34522 .28722 L .34812 .28616 L F
.42175 .29303 m .42298 .28974 L .42469 .292 L 0 .039 .141 r
F
.42175 .29303 m .42003 .29082 L .42298 .28974 L F
.09394 .28544 m .09464 .28245 L .09669 .28446 L 0 .024 .122 r
F
.09394 .28544 m .09189 .28343 L .09464 .28245 L F
.71125 .28988 m .7129 .28665 L .71434 .28869 L 0 .032 .133 r
F
.71125 .28988 m .70981 .28782 L .7129 .28665 L F
.21436 .28652 m .21524 .28358 L .21717 .28557 L 0 .026 .125 r
F
.21436 .28652 m .21243 .28452 L .21524 .28358 L F
.13661 .28568 m .1374 .28258 L .1394 .28461 L 0 .024 .123 r
F
.13661 .28568 m .13461 .28366 L .1374 .28258 L F
.7417 .28822 m .7434 .28503 L .74481 .28704 L 0 .029 .129 r
F
.7417 .28822 m .74029 .28622 L .7434 .28503 L F
.17929 .28591 m .18013 .28288 L .1821 .28482 L 0 .025 .123 r
F
.17929 .28591 m .17732 .28396 L .18013 .28288 L F
.53618 .29965 m .53757 .29587 L .53918 .29839 L 0 .054 .157 r
F
.53618 .29965 m .53457 .29707 L .53757 .29587 L F
.24942 .2872 m .25038 .28405 L .25227 .28609 L 0 .027 .127 r
F
.24942 .2872 m .24753 .28514 L .25038 .28405 L F
.80722 .28721 m .80905 .28436 L .81038 .2862 L 0 .028 .127 r
F
.80722 .28721 m .80589 .28537 L .80905 .28436 L F
.74932 .28787 m .75103 .28467 L .75243 .28671 L 0 .029 .128 r
F
.74932 .28787 m .74792 .28584 L .75103 .28467 L F
.31955 .28851 m .3206 .28552 L .32242 .2876 L 0 .03 .13 r
F
.31955 .28851 m .31772 .28641 L .3206 .28552 L F
.56663 .29801 m .56806 .29453 L .56964 .29647 L 0 .051 .153 r
F
.56663 .29801 m .56505 .29605 L .56806 .29453 L F
.52482 .44185 m .5262 .41372 L .52783 .43017 L 0 .498 .088 r
F
.52482 .44185 m .5232 .42356 L .5262 .41372 L F
.29209 .28748 m .29309 .28461 L .29495 .28655 L 0 .028 .128 r
F
.29209 .28748 m .29023 .28553 L .29309 .28461 L F
.38206 .29025 m .38322 .28715 L .38498 .28918 L 0 .034 .135 r
F
.38206 .29025 m .3803 .2882 L .38322 .28715 L F
.50111 .29914 m .50245 .29588 L .5041 .29804 L 0 .054 .157 r
F
.50111 .29914 m .49947 .29693 L .50245 .29588 L F
.25702 .2869 m .25798 .2839 L .25987 .28582 L 0 .027 .126 r
F
.25702 .2869 m .25512 .28499 L .25798 .2839 L F
.65336 .29072 m .65493 .28759 L .65643 .28968 L 0 .035 .136 r
F
.65336 .29072 m .65186 .28862 L .65493 .28759 L F
.64575 .29116 m .6473 .28773 L .6488 .28983 L F
.64575 .29116 m .64424 .28906 L .6473 .28773 L F
.63814 .29159 m .63969 .28854 L .64119 .29039 L 0 .037 .138 r
F
.63814 .29159 m .63663 .28974 L .63969 .28854 L F
.46143 .29623 m .4627 .29326 L .46439 .29539 L 0 .048 .15 r
F
.46143 .29623 m .45974 .29412 L .4627 .29326 L F
.18688 .28569 m .18771 .28284 L .18968 .28472 L 0 .025 .124 r
F
.18688 .28569 m .18491 .28382 L .18771 .28284 L F
.44159 .29478 m .44284 .29135 L .44454 .29363 L 0 .043 .146 r
F
.44159 .29478 m .43989 .29248 L .44284 .29135 L F
.1442 .2855 m .14498 .28253 L .14698 .28447 L 0 .024 .123 r
F
.1442 .2855 m .14219 .28355 L .14498 .28253 L F
.81485 .28699 m .81668 .28398 L .818 .28586 L 0 .027 .127 r
F
.81485 .28699 m .81353 .28513 L .81668 .28398 L F
.47366 .2982 m .47496 .29454 L .47663 .29697 L 0 .051 .154 r
F
.47366 .2982 m .47199 .29578 L .47496 .29454 L F
.4019 .29189 m .40308 .28895 L .40482 .29103 L 0 .038 .139 r
F
.4019 .29189 m .40016 .28979 L .40308 .28895 L F
.75695 .28769 m .75869 .2847 L .76008 .28669 L 0 .029 .129 r
F
.75695 .28769 m .75556 .28571 L .75869 .2847 L F
.3546 .28939 m .35572 .28613 L .35751 .28827 L 0 .032 .132 r
F
.3546 .28939 m .35281 .28723 L .35572 .28613 L F
.82247 .28665 m .82432 .28373 L .82564 .28567 L 0 .027 .126 r
F
.82247 .28665 m .82115 .28473 L .82432 .28373 L F
.26462 .28666 m .26558 .28373 L .26747 .28564 L F
.26462 .28666 m .26273 .28474 L .26558 .28373 L F
.63053 .29219 m .63207 .28906 L .63358 .29093 L 0 .038 .14 r
F
.63053 .29219 m .62902 .2903 L .63207 .28906 L F
.54379 .29959 m .5452 .29604 L .5468 .29845 L 0 .055 .158 r
F
.54379 .29959 m .54219 .29716 L .5452 .29604 L F
.22193 .28651 m .22282 .28362 L .22476 .2855 L 0 .027 .126 r
F
.22193 .28651 m .21999 .28462 L .22282 .28362 L F
.77218 .28694 m .77395 .28401 L .77532 .28592 L 0 .028 .127 r
F
.77218 .28694 m .77081 .28505 L .77395 .28401 L F
.10149 .28549 m .10222 .28241 L .10426 .28442 L 0 .025 .123 r
F
.10149 .28549 m .09945 .28349 L .10222 .28241 L F
.29968 .2874 m .30069 .28453 L .30255 .28637 L 0 .029 .128 r
F
.29968 .2874 m .29782 .28554 L .30069 .28453 L F
.76458 .28743 m .76632 .28437 L .76769 .28624 L 0 .028 .128 r
F
.76458 .28743 m .7632 .28558 L .76632 .28437 L F
.15178 .28534 m .15257 .28236 L .15457 .28425 L 0 .024 .123 r
F
.15178 .28534 m .14977 .28344 L .15257 .28236 L F
.50872 .29912 m .51008 .29587 L .51171 .29796 L 0 .055 .157 r
F
.50872 .29912 m .50708 .29696 L .51008 .29587 L F
.19445 .28561 m .1953 .28274 L .19727 .28461 L 0 .025 .124 r
F
.19445 .28561 m .19249 .28374 L .1953 .28274 L F
.44919 .2947 m .45045 .29151 L .45214 .29375 L 0 .044 .146 r
F
.44919 .2947 m .4475 .29248 L .45045 .29151 L F
.22952 .28627 m .23044 .28327 L .23237 .28515 L 0 .026 .125 r
F
.22952 .28627 m .2276 .28439 L .23044 .28327 L F
.51634 .29873 m .5177 .2953 L .51933 .29741 L 0 .054 .156 r
F
.51634 .29873 m .51471 .29663 L .5177 .2953 L F
.38965 .29029 m .39082 .2872 L .39257 .28937 L 0 .034 .135 r
F
.38965 .29029 m .3879 .28816 L .39082 .2872 L F
.10908 .28522 m .10981 .28221 L .11186 .28412 L 0 .024 .123 r
F
.10908 .28522 m .10703 .28331 L .10981 .28221 L F
.66099 .29073 m .66257 .28754 L .66406 .28961 L 0 .035 .136 r
F
.66099 .29073 m .6595 .28865 L .66257 .28754 L F
.36219 .28926 m .36333 .28602 L .36511 .28814 L 0 .032 .133 r
F
.36219 .28926 m .36042 .28715 L .36333 .28602 L F
.15937 .28505 m .16018 .28205 L .16218 .28395 L 0 .024 .122 r
F
.15937 .28505 m .15738 .28315 L .16018 .28205 L F
.42934 .29329 m .43058 .28998 L .43229 .29227 L 0 .041 .143 r
F
.42934 .29329 m .42763 .29097 L .43058 .28998 L F
.32712 .28867 m .3282 .28555 L .33001 .28755 L 0 .031 .131 r
F
.32712 .28867 m .3253 .28667 L .3282 .28555 L F
.30727 .28719 m .3083 .28434 L .31015 .28621 L 0 .028 .128 r
F
.30727 .28719 m .30543 .28534 L .3083 .28434 L F
.48126 .2982 m .48258 .29449 L .48424 .29696 L 0 .052 .154 r
F
.48126 .2982 m .4796 .29574 L .48258 .29449 L F
.2722 .28659 m .27318 .2836 L .27506 .28555 L 0 .027 .126 r
F
.2722 .28659 m .27032 .28463 L .27318 .2836 L F
.55902 .29907 m .56044 .29537 L .56203 .29757 L 0 .054 .157 r
F
.55902 .29907 m .55743 .29687 L .56044 .29537 L F
.62293 .29296 m .62445 .28971 L .62597 .29163 L 0 .04 .142 r
F
.62293 .29296 m .6214 .29099 L .62445 .28971 L F
.77982 .28684 m .7816 .28387 L .78296 .28582 L 0 .028 .127 r
F
.77982 .28684 m .77846 .2849 L .7816 .28387 L F
.33473 .28834 m .33581 .28537 L .33762 .28728 L 0 .031 .131 r
F
.33473 .28834 m .33291 .28643 L .33581 .28537 L F
.83013 .28665 m .83198 .28369 L .8333 .28566 L 0 .027 .127 r
F
.83013 .28665 m .82881 .2847 L .83198 .28369 L F
.60009 .29426 m .60158 .29112 L .60313 .29311 L 0 .043 .146 r
F
.60009 .29426 m .59854 .29227 L .60158 .29112 L F
.52395 .2985 m .52532 .29464 L .52695 .29709 L 0 .052 .155 r
F
.52395 .2985 m .52233 .29605 L .52532 .29464 L F
.11667 .285 m .1174 .28206 L .11944 .28397 L 0 .024 .123 r
F
.11667 .285 m .11463 .28309 L .1174 .28206 L F
.66862 .29051 m .6702 .2873 L .67169 .28934 L 0 .035 .136 r
F
.66862 .29051 m .66713 .28846 L .6702 .2873 L F
.50459 .48171 m .50298 .47511 L .50586 .49331 L .329 .654 0 r
F
.50298 .47511 m .50424 .48589 L .50586 .49331 L .263 .634 0 r
F
.68385 .2897 m .68547 .28665 L .68693 .28863 L 0 .034 .134 r
F
.68385 .2897 m .68238 .28774 L .68547 .28665 L F
.23711 .28611 m .23804 .28313 L .23995 .28514 L 0 .026 .125 r
F
.23711 .28611 m .2352 .28412 L .23804 .28313 L F
.59248 .29478 m .59395 .29159 L .59551 .29353 L 0 .045 .147 r
F
.59248 .29478 m .59092 .29285 L .59395 .29159 L F
.67623 .29013 m .67783 .28693 L .6793 .2889 L 0 .034 .135 r
F
.67623 .29013 m .67476 .28814 L .67783 .28693 L F
.48888 .29797 m .4902 .29453 L .49185 .29681 L 0 .052 .155 r
F
.48888 .29797 m .48722 .29571 L .4902 .29453 L F
.55141 .2997 m .55282 .29598 L .55442 .29836 L 0 .056 .159 r
F
.55141 .2997 m .54981 .29732 L .55282 .29598 L F
.51717 .43791 m .51858 .41502 L .52019 .43288 L 0 .493 .097 r
F
.51717 .43791 m .51558 .41933 L .51858 .41502 L F
.83776 .28643 m .83962 .28338 L .84092 .28528 L 0 .027 .126 r
F
.83776 .28643 m .83646 .28452 L .83962 .28338 L F
.20203 .28558 m .2029 .28257 L .20485 .28456 L 0 .025 .124 r
F
.20203 .28558 m .20008 .2836 L .2029 .28257 L F
.36979 .28917 m .37092 .28627 L .3727 .28825 L 0 .033 .134 r
F
.36979 .28917 m .36801 .28717 L .37092 .28627 L F
.53412 .44751 m .53543 .41927 L .53709 .43175 L 0 .513 .056 r
F
.53412 .44751 m .53246 .43314 L .53543 .41927 L F
.16694 .285 m .16776 .282 L .16974 .28403 L 0 .024 .123 r
F
.16694 .285 m .16497 .28298 L .16776 .282 L F
.53157 .29831 m .53295 .29449 L .53457 .29707 L 0 .052 .155 r
F
.53157 .29831 m .52995 .29569 L .53295 .29449 L F
.40948 .29219 m .41069 .28894 L .41242 .29102 L 0 .039 .141 r
F
.40948 .29219 m .40775 .29011 L .41069 .28894 L F
.5404 .456 m .54168 .42674 L .54333 .43681 L 0 .535 .009 r
F
.5404 .456 m .53874 .4442 L .54168 .42674 L F
.27979 .28651 m .28079 .28335 L .28265 .2854 L 0 .027 .126 r
F
.27979 .28651 m .27792 .28445 L .28079 .28335 L F
.58487 .29539 m .58633 .29218 L .58789 .29412 L 0 .046 .149 r
F
.58487 .29539 m .5833 .29346 L .58633 .29218 L F
.78746 .28673 m .78924 .28369 L .79061 .28568 L 0 .028 .127 r
F
.78746 .28673 m .7861 .28475 L .78924 .28369 L F
.84538 .2861 m .84727 .28323 L .84856 .28509 L 0 .027 .126 r
F
.84538 .2861 m .84409 .28423 L .84727 .28323 L F
.34232 .28821 m .34341 .28528 L .34522 .28722 L 0 .031 .131 r
F
.34232 .28821 m .34052 .28628 L .34341 .28528 L F
.57725 .29584 m .57871 .29275 L .58028 .2947 L 0 .048 .15 r
F
.57725 .29584 m .57568 .2939 L .57871 .29275 L F
.12424 .28487 m .125 .28185 L .12703 .28379 L 0 .024 .123 r
F
.12424 .28487 m .12222 .28293 L .125 .28185 L F
.60771 .29418 m .60921 .29108 L .61075 .29311 L 0 .044 .146 r
F
.60771 .29418 m .60617 .2921 L .60921 .29108 L F
.69909 .28912 m .70072 .28584 L .70217 .2879 L 0 .032 .133 r
F
.69909 .28912 m .69763 .28706 L .70072 .28584 L F
.08155 .28469 m .08223 .28172 L .08431 .28361 L 0 .024 .122 r
F
.08155 .28469 m .07947 .28282 L .08223 .28172 L F
.61533 .29378 m .61683 .29042 L .61836 .29237 L 0 .042 .145 r
F
.61533 .29378 m .61379 .29179 L .61683 .29042 L F
.69148 .2896 m .69309 .28629 L .69455 .28834 L 0 .033 .134 r
F
.69148 .2896 m .69002 .28756 L .69309 .28629 L F
.41709 .29194 m .41831 .2887 L .42003 .29082 L 0 .039 .14 r
F
.41709 .29194 m .41537 .28984 L .41831 .2887 L F
.31485 .28732 m .3159 .28432 L .31772 .28641 L 0 .029 .129 r
F
.31485 .28732 m .31303 .28523 L .3159 .28432 L F
.46902 .29683 m .47032 .29349 L .47199 .29578 L 0 .05 .153 r
F
.46902 .29683 m .46735 .29454 L .47032 .29349 L F
.45679 .29497 m .45806 .29199 L .45974 .29412 L 0 .046 .149 r
F
.45679 .29497 m .4551 .29287 L .45806 .29199 L F
.56964 .29647 m .57108 .29312 L .57266 .29505 L 0 .049 .152 r
F
.56964 .29647 m .56806 .29453 L .57108 .29312 L F
.72956 .28761 m .73124 .28448 L .73266 .28644 L 0 .03 .13 r
F
.72956 .28761 m .72814 .28567 L .73124 .28448 L F
.70672 .2889 m .70837 .28577 L .70981 .28782 L 0 .032 .133 r
F
.70672 .2889 m .70527 .28684 L .70837 .28577 L F
.08913 .28447 m .08983 .28147 L .09189 .28343 L 0 .024 .122 r
F
.08913 .28447 m .08707 .28252 L .08983 .28147 L F
.43694 .29356 m .43819 .29019 L .43989 .29248 L 0 .042 .144 r
F
.43694 .29356 m .43524 .29124 L .43819 .29019 L F
.49649 .298 m .49782 .29476 L .49947 .29693 L 0 .053 .156 r
F
.49649 .298 m .49484 .29578 L .49782 .29476 L F
.2096 .28555 m .21049 .2825 L .21243 .28452 L 0 .026 .125 r
F
.2096 .28555 m .20767 .28353 L .21049 .2825 L F
.79511 .28663 m .7969 .28356 L .79825 .28558 L 0 .028 .127 r
F
.79511 .28663 m .79375 .28462 L .7969 .28356 L F
.39724 .29064 m .39842 .28757 L .40016 .28979 L 0 .036 .138 r
F
.39724 .29064 m .39549 .28845 L .39842 .28757 L F
.13182 .28473 m .1326 .28163 L .13461 .28366 L 0 .024 .123 r
F
.13182 .28473 m .12981 .28271 L .1326 .28163 L F
.24468 .28623 m .24563 .28308 L .24753 .28514 L 0 .027 .126 r
F
.24468 .28623 m .24278 .28415 L .24563 .28308 L F
.72195 .28814 m .72362 .28496 L .72504 .28691 L 0 .031 .131 r
F
.72195 .28814 m .72052 .28619 L .72362 .28496 L F
.28737 .28645 m .28838 .28349 L .29023 .28553 L 0 .028 .127 r
F
.28737 .28645 m .28552 .28441 L .28838 .28349 L F
.73718 .28731 m .73888 .28422 L .74029 .28622 L 0 .029 .129 r
F
.73718 .28731 m .73577 .28533 L .73888 .28422 L F
.37738 .28925 m .37853 .28629 L .3803 .2882 L 0 .033 .134 r
F
.37738 .28925 m .37561 .28731 L .37853 .28629 L F
.17451 .28503 m .17535 .28196 L .17732 .28396 L 0 .025 .123 r
F
.17451 .28503 m .17254 .28302 L .17535 .28196 L F
.53918 .29839 m .54058 .29469 L .54219 .29716 L 0 .054 .156 r
F
.53918 .29839 m .53757 .29587 L .54058 .29469 L F
.71434 .28869 m .716 .28541 L .71743 .28744 L 0 .032 .132 r
F
.71434 .28869 m .7129 .28665 L .716 .28541 L F
.80274 .28638 m .80456 .28352 L .80589 .28537 L 0 .028 .127 r
F
.80274 .28638 m .8014 .28453 L .80456 .28352 L F
.74481 .28704 m .74651 .28381 L .74792 .28584 L 0 .029 .128 r
F
.74481 .28704 m .7434 .28503 L .74651 .28381 L F
.34991 .28831 m .35103 .28509 L .35281 .28723 L 0 .031 .132 r
F
.34991 .28831 m .34812 .28616 L .35103 .28509 L F
.6488 .28983 m .65036 .28652 L .65186 .28862 L 0 .034 .135 r
F
.6488 .28983 m .6473 .28773 L .65036 .28652 L F
.75243 .28671 m .75416 .28367 L .75556 .28571 L 0 .028 .128 r
F
.75243 .28671 m .75103 .28467 L .75416 .28367 L F
.1821 .28482 m .18294 .28188 L .18491 .28382 L 0 .025 .124 r
F
.1821 .28482 m .18013 .28288 L .18294 .28188 L F
.1394 .28461 m .14019 .28152 L .14219 .28355 L 0 .024 .123 r
F
.1394 .28461 m .1374 .28258 L .14019 .28152 L F
.42469 .292 m .42592 .28865 L .42763 .29097 L 0 .039 .141 r
F
.42469 .292 m .42298 .28974 L .42592 .28865 L F
.25227 .28609 m .25323 .28295 L .25512 .28499 L 0 .027 .126 r
F
.25227 .28609 m .25038 .28405 L .25323 .28295 L F
.09669 .28446 m .0974 .28148 L .09945 .28349 L 0 .024 .123 r
F
.09669 .28446 m .09464 .28245 L .0974 .28148 L F
.64119 .29039 m .64274 .28721 L .64424 .28906 L 0 .036 .137 r
F
.64119 .29039 m .63969 .28854 L .64274 .28721 L F
.50266 .47238 m .5011 .45813 L .504 .47151 L .216 .619 0 r
F
.5011 .45813 m .50244 .45541 L .504 .47151 L .07 .567 0 r
F
.47663 .29697 m .47794 .29329 L .4796 .29574 L 0 .051 .153 r
F
.47663 .29697 m .47496 .29454 L .47794 .29329 L F
.21717 .28557 m .21806 .28264 L .21999 .28462 L 0 .027 .126 r
F
.21717 .28557 m .21524 .28358 L .21806 .28264 L F
.81038 .2862 m .8122 .28327 L .81353 .28513 L 0 .028 .127 r
F
.81038 .2862 m .80905 .28436 L .8122 .28327 L F
.5041 .29804 m .50544 .29484 L .50708 .29696 L 0 .054 .157 r
F
.5041 .29804 m .50245 .29588 L .50544 .29484 L F
.38498 .28918 m .38614 .28612 L .3879 .28816 L 0 .034 .135 r
F
.38498 .28918 m .38322 .28715 L .38614 .28612 L F
.44454 .29363 m .4458 .29023 L .4475 .29248 L 0 .043 .145 r
F
.44454 .29363 m .44284 .29135 L .4458 .29023 L F
.25987 .28582 m .26084 .28281 L .26273 .28474 L 0 .027 .126 r
F
.25987 .28582 m .25798 .2839 L .26084 .28281 L F
.63358 .29093 m .63512 .28788 L .63663 .28974 L 0 .038 .139 r
F
.63358 .29093 m .63207 .28906 L .63512 .28788 L F
.818 .28586 m .81983 .28283 L .82115 .28473 L 0 .027 .126 r
F
.818 .28586 m .81668 .28398 L .81983 .28283 L F
.65643 .28968 m .658 .28657 L .6595 .28865 L 0 .035 .136 r
F
.65643 .28968 m .65493 .28759 L .658 .28657 L F
.29495 .28655 m .29596 .28362 L .29782 .28554 L 0 .029 .128 r
F
.29495 .28655 m .29309 .28461 L .29596 .28362 L F
.32242 .2876 m .32348 .28458 L .3253 .28667 L 0 .031 .131 r
F
.32242 .2876 m .3206 .28552 L .32348 .28458 L F
.35751 .28827 m .35864 .285 L .36042 .28715 L 0 .032 .132 r
F
.35751 .28827 m .35572 .28613 L .35864 .285 L F
.14698 .28447 m .14777 .28151 L .14977 .28344 L 0 .025 .123 r
F
.14698 .28447 m .14498 .28253 L .14777 .28151 L F
.56203 .29757 m .56346 .29388 L .56505 .29605 L 0 .052 .155 r
F
.56203 .29757 m .56044 .29537 L .56346 .29388 L F
.18968 .28472 m .19052 .28185 L .19249 .28374 L 0 .025 .124 r
F
.18968 .28472 m .18771 .28284 L .19052 .28185 L F
.5468 .29845 m .54821 .29493 L .54981 .29732 L 0 .055 .158 r
F
.5468 .29845 m .5452 .29604 L .54821 .29493 L F
.51933 .29741 m .5207 .29394 L .52233 .29605 L 0 .052 .155 r
F
.51933 .29741 m .5177 .2953 L .5207 .29394 L F
.76769 .28624 m .76944 .28316 L .77081 .28505 L 0 .028 .127 r
F
.76769 .28624 m .76632 .28437 L .76944 .28316 L F
.76008 .28669 m .76181 .28359 L .7632 .28558 L 0 .029 .129 r
F
.76008 .28669 m .75869 .2847 L .76181 .28359 L F
.26747 .28564 m .26844 .28274 L .27032 .28463 L 0 .027 .126 r
F
.26747 .28564 m .26558 .28373 L .26844 .28274 L F
.82564 .28567 m .82749 .28275 L .82881 .2847 L F
.82564 .28567 m .82432 .28373 L .82749 .28275 L F
.46439 .29539 m .46567 .29239 L .46735 .29454 L 0 .048 .151 r
F
.46439 .29539 m .4627 .29326 L .46567 .29239 L F
.52695 .29709 m .52833 .29322 L .52995 .29569 L 0 .051 .154 r
F
.52695 .29709 m .52532 .29464 L .52833 .29322 L F
.10426 .28442 m .10499 .28131 L .10703 .28331 L 0 .024 .123 r
F
.10426 .28442 m .10222 .28241 L .10499 .28131 L F
.77532 .28592 m .77709 .28298 L .77846 .2849 L 0 .028 .127 r
F
.77532 .28592 m .77395 .28401 L .77709 .28298 L F
.51171 .29796 m .51307 .29453 L .51471 .29663 L 0 .054 .157 r
F
.51171 .29796 m .51008 .29587 L .51307 .29453 L F
.22476 .2855 m .22566 .2825 L .2276 .28439 L 0 .027 .126 r
F
.22476 .2855 m .22282 .28362 L .22566 .2825 L F
.62597 .29163 m .6275 .28843 L .62902 .2903 L 0 .039 .141 r
F
.62597 .29163 m .62445 .28971 L .6275 .28843 L F
.30255 .28637 m .30357 .28351 L .30543 .28534 L 0 .029 .128 r
F
.30255 .28637 m .30069 .28453 L .30357 .28351 L F
.15457 .28425 m .15538 .28125 L .15738 .28315 L 0 .024 .123 r
F
.15457 .28425 m .15257 .28236 L .15538 .28125 L F
.40482 .29103 m .40601 .28803 L .40775 .29011 L 0 .038 .14 r
F
.40482 .29103 m .40308 .28895 L .40601 .28803 L F
.48424 .29696 m .48556 .29323 L .48722 .29571 L 0 .051 .154 r
F
.48424 .29696 m .48258 .29449 L .48556 .29323 L F
.23237 .28515 m .23328 .28223 L .2352 .28412 L 0 .026 .125 r
F
.23237 .28515 m .23044 .28327 L .23328 .28223 L F
.66406 .28961 m .66564 .28642 L .66713 .28846 L 0 .035 .136 r
F
.66406 .28961 m .66257 .28754 L .66564 .28642 L F
.51115 .44391 m .50959 .42462 L .51258 .42365 L 0 .515 .052 r
F
.50817 .44079 m .50959 .42462 L .51115 .44391 L 0 .508 .068 r
F
.11186 .28412 m .11258 .28118 L .11463 .28309 L 0 .024 .123 r
F
.11186 .28412 m .10981 .28221 L .11258 .28118 L F
.36511 .28814 m .36624 .28505 L .36801 .28717 L 0 .032 .133 r
F
.36511 .28814 m .36333 .28602 L .36624 .28505 L F
.16218 .28395 m .16298 .28107 L .16497 .28298 L 0 .024 .122 r
F
.16218 .28395 m .16018 .28205 L .16298 .28107 L F
.50459 .48171 m .50586 .49331 L .50748 .50074 L .329 .654 0 r
F
.33001 .28755 m .33109 .28443 L .33291 .28643 L 0 .031 .131 r
F
.33001 .28755 m .3282 .28555 L .33109 .28443 L F
.19727 .28461 m .19812 .28175 L .20008 .2836 L 0 .025 .124 r
F
.19727 .28461 m .1953 .28274 L .19812 .28175 L F
.55442 .29836 m .55583 .29449 L .55743 .29687 L 0 .055 .157 r
F
.55442 .29836 m .55282 .29598 L .55583 .29449 L F
.59551 .29353 m .59699 .29033 L .59854 .29227 L 0 .044 .146 r
F
.59551 .29353 m .59395 .29159 L .59699 .29033 L F
.45214 .29375 m .45341 .29061 L .4551 .29287 L 0 .045 .147 r
F
.45214 .29375 m .45045 .29151 L .45341 .29061 L F
.60313 .29311 m .60462 .29009 L .60617 .2921 L 0 .043 .146 r
F
.60313 .29311 m .60158 .29112 L .60462 .29009 L F
.43229 .29227 m .43353 .28898 L .43524 .29124 L 0 .041 .143 r
F
.43229 .29227 m .43058 .28998 L .43353 .28898 L F
.6793 .2889 m .68091 .2858 L .68238 .28774 L 0 .034 .135 r
F
.6793 .2889 m .67783 .28693 L .68091 .2858 L F
.67169 .28934 m .67328 .28613 L .67476 .28814 L 0 .034 .136 r
F
.67169 .28934 m .6702 .2873 L .67328 .28613 L F
.27506 .28555 m .27605 .28251 L .27792 .28445 L 0 .027 .126 r
F
.27506 .28555 m .27318 .2836 L .27605 .28251 L F
.52947 .44673 m .53082 .41846 L .53246 .43314 L 0 .513 .056 r
F
.52947 .44673 m .52783 .43017 L .53082 .41846 L F
.39257 .28937 m .39375 .28624 L .39549 .28845 L 0 .035 .136 r
F
.39257 .28937 m .39082 .2872 L .39375 .28624 L F
.31015 .28621 m .31118 .28333 L .31303 .28523 L 0 .029 .128 r
F
.31015 .28621 m .3083 .28434 L .31118 .28333 L F
.51416 .44295 m .51558 .41933 L .51717 .43791 L 0 .508 .068 r
F
.51416 .44295 m .51258 .42365 L .51558 .41933 L F
.33762 .28728 m .3387 .28435 L .34052 .28628 L 0 .031 .131 r
F
.33762 .28728 m .33581 .28537 L .3387 .28435 L F
.78296 .28582 m .78474 .28278 L .7861 .28475 L 0 .028 .127 r
F
.78296 .28582 m .7816 .28387 L .78474 .28278 L F
.49185 .29681 m .49318 .29355 L .49484 .29578 L 0 .052 .155 r
F
.49185 .29681 m .4902 .29453 L .49318 .29355 L F
.61836 .29237 m .61988 .28908 L .6214 .29099 L 0 .041 .143 r
F
.61836 .29237 m .61683 .29042 L .61988 .28908 L F
.53457 .29707 m .53595 .29335 L .53757 .29587 L 0 .052 .154 r
F
.53457 .29707 m .53295 .29449 L .53595 .29335 L F
.8333 .28566 m .83514 .28253 L .83646 .28452 L 0 .027 .127 r
F
.8333 .28566 m .83198 .28369 L .83514 .28253 L F
.11944 .28397 m .12018 .28101 L .12222 .28293 L 0 .024 .123 r
F
.11944 .28397 m .1174 .28206 L .12018 .28101 L F
.58789 .29412 m .58936 .29089 L .59092 .29285 L 0 .046 .148 r
F
.58789 .29412 m .58633 .29218 L .58936 .29089 L F
.68693 .28863 m .68855 .28557 L .69002 .28756 L 0 .033 .134 r
F
.68693 .28863 m .68547 .28665 L .68855 .28557 L F
.84092 .28528 m .84279 .28233 L .84409 .28423 L 0 .027 .126 r
F
.84092 .28528 m .83962 .28338 L .84279 .28233 L F
.41242 .29102 m .41363 .28777 L .41537 .28984 L 0 .038 .14 r
F
.41242 .29102 m .41069 .28894 L .41363 .28777 L F
.57266 .29505 m .57411 .29195 L .57568 .2939 L 0 .048 .151 r
F
.57266 .29505 m .57108 .29312 L .57411 .29195 L F
.23995 .28514 m .24088 .28213 L .24278 .28415 L 0 .027 .126 r
F
.23995 .28514 m .23804 .28313 L .24088 .28213 L F
.70217 .2879 m .70382 .28478 L .70527 .28684 L 0 .032 .133 r
F
.70217 .2879 m .70072 .28584 L .70382 .28478 L F
.69455 .28834 m .69617 .28499 L .69763 .28706 L 0 .033 .133 r
F
.69455 .28834 m .69309 .28629 L .69617 .28499 L F
.28265 .2854 m .28366 .28236 L .28552 .28441 L 0 .027 .126 r
F
.28265 .2854 m .28079 .28335 L .28366 .28236 L F
.58028 .2947 m .58174 .29148 L .5833 .29346 L 0 .047 .15 r
F
.58028 .2947 m .57871 .29275 L .58174 .29148 L F
.20485 .28456 m .20573 .28154 L .20767 .28353 L 0 .026 .124 r
F
.20485 .28456 m .2029 .28257 L .20573 .28154 L F
.51246 .49467 m .51374 .51607 L .5154 .51141 L .51 .705 0 r
F
.51246 .49467 m .5108 .49857 L .51374 .51607 L F
.79061 .28568 m .79239 .28261 L .79375 .28462 L 0 .028 .127 r
F
.79061 .28568 m .78924 .28369 L .79239 .28261 L F
.12703 .28379 m .12779 .28078 L .12981 .28271 L 0 .024 .122 r
F
.12703 .28379 m .125 .28185 L .12779 .28078 L F
.3727 .28825 m .37383 .28536 L .37561 .28731 L 0 .033 .134 r
F
.3727 .28825 m .37092 .28627 L .37383 .28536 L F
.61075 .29311 m .61225 .2898 L .61379 .29179 L 0 .043 .146 r
F
.61075 .29311 m .60921 .29108 L .61225 .2898 L F
.16974 .28403 m .17057 .281 L .17254 .28302 L 0 .025 .123 r
F
.16974 .28403 m .16776 .282 L .17057 .281 L F
.08431 .28361 m .085 .28063 L .08707 .28252 L 0 .024 .122 r
F
.08431 .28361 m .08223 .28172 L .085 .28063 L F
.84856 .28509 m .85046 .28223 L .85174 .28409 L 0 .027 .126 r
F
.84856 .28509 m .84727 .28323 L .85046 .28223 L F
.34522 .28722 m .34632 .28424 L .34812 .28616 L 0 .031 .131 r
F
.34522 .28722 m .34341 .28528 L .34632 .28424 L F
.42003 .29082 m .42126 .28758 L .42298 .28974 L 0 .038 .14 r
F
.42003 .29082 m .41831 .2887 L .42126 .28758 L F
.73266 .28644 m .73435 .28335 L .73577 .28533 L 0 .029 .129 r
F
.73266 .28644 m .73124 .28448 L .73435 .28335 L F
.47199 .29578 m .47329 .29224 L .47496 .29454 L 0 .05 .152 r
F
.47199 .29578 m .47032 .29349 L .47329 .29224 L F
.72504 .28691 m .72672 .28372 L .72814 .28567 L 0 .03 .13 r
F
.72504 .28691 m .72362 .28496 L .72672 .28372 L F
.70981 .28782 m .71146 .2846 L .7129 .28665 L 0 .032 .133 r
F
.70981 .28782 m .70837 .28577 L .71146 .2846 L F
.43989 .29248 m .44114 .28909 L .44284 .29135 L 0 .042 .144 r
F
.43989 .29248 m .43819 .29019 L .44114 .28909 L F
.49947 .29693 m .50081 .29374 L .50245 .29588 L 0 .053 .156 r
F
.49947 .29693 m .49782 .29476 L .50081 .29374 L F
.54219 .29716 m .54359 .29361 L .5452 .29604 L F
.54219 .29716 m .54058 .29469 L .54359 .29361 L F
.71743 .28744 m .71909 .28417 L .72052 .28619 L 0 .031 .132 r
F
.71743 .28744 m .716 .28541 L .71909 .28417 L F
.09189 .28343 m .09259 .28049 L .09464 .28245 L 0 .024 .122 r
F
.09189 .28343 m .08983 .28147 L .09259 .28049 L F
.13461 .28366 m .13539 .28055 L .1374 .28258 L F
.13461 .28366 m .1326 .28163 L .13539 .28055 L F
.24753 .28514 m .24848 .282 L .25038 .28405 L 0 .027 .126 r
F
.24753 .28514 m .24563 .28308 L .24848 .282 L F
.31772 .28641 m .31878 .28342 L .3206 .28552 L 0 .03 .13 r
F
.31772 .28641 m .3159 .28432 L .31878 .28342 L F
.79825 .28558 m .80005 .2825 L .8014 .28453 L 0 .028 .127 r
F
.79825 .28558 m .7969 .28356 L .80005 .2825 L F
.21243 .28452 m .21331 .28156 L .21524 .28358 L 0 .026 .125 r
F
.21243 .28452 m .21049 .2825 L .21331 .28156 L F
.74029 .28622 m .74199 .28301 L .7434 .28503 L 0 .029 .129 r
F
.74029 .28622 m .73888 .28422 L .74199 .28301 L F
.74792 .28584 m .74962 .28263 L .75103 .28467 L 0 .028 .128 r
F
.74792 .28584 m .74651 .28381 L .74962 .28263 L F
.17732 .28396 m .17816 .28091 L .18013 .28288 L 0 .025 .123 r
F
.17732 .28396 m .17535 .28196 L .17816 .28091 L F
.65186 .28862 m .65343 .28551 L .65493 .28759 L 0 .034 .135 r
F
.65186 .28862 m .65036 .28652 L .65343 .28551 L F
.45974 .29412 m .46102 .29112 L .4627 .29326 L 0 .047 .149 r
F
.45974 .29412 m .45806 .29199 L .46102 .29112 L F
.3803 .2882 m .38145 .28528 L .38322 .28715 L 0 .034 .134 r
F
.3803 .2882 m .37853 .28629 L .38145 .28528 L F
.64424 .28906 m .6458 .28588 L .6473 .28773 L 0 .035 .136 r
F
.64424 .28906 m .64274 .28721 L .6458 .28588 L F
.56505 .29605 m .56648 .29239 L .56806 .29453 L 0 .05 .153 r
F
.56505 .29605 m .56346 .29388 L .56648 .29239 L F
.29023 .28553 m .29124 .28256 L .29309 .28461 L 0 .028 .128 r
F
.29023 .28553 m .28838 .28349 L .29124 .28256 L F
.35281 .28723 m .35394 .28401 L .35572 .28613 L 0 .031 .132 r
F
.35281 .28723 m .35103 .28509 L .35394 .28401 L F
.40016 .28979 m .40134 .2867 L .40308 .28895 L 0 .037 .138 r
F
.40016 .28979 m .39842 .28757 L .40134 .2867 L F
.80589 .28537 m .80772 .28251 L .80905 .28436 L 0 .028 .128 r
F
.80589 .28537 m .80456 .28352 L .80772 .28251 L F
.4796 .29574 m .48092 .29202 L .48258 .29449 L 0 .05 .152 r
F
.4796 .29574 m .47794 .29329 L .48092 .29202 L F
.25512 .28499 m .25609 .28186 L .25798 .2839 L 0 .027 .126 r
F
.25512 .28499 m .25323 .28295 L .25609 .28186 L F
.14219 .28355 m .14297 .28052 L .14498 .28253 L 0 .024 .123 r
F
.14219 .28355 m .14019 .28152 L .14297 .28052 L F
.42763 .29097 m .42887 .28768 L .43058 .28998 L 0 .039 .141 r
F
.42763 .29097 m .42592 .28865 L .42887 .28768 L F
.52233 .29605 m .5237 .29253 L .52532 .29464 L 0 .051 .154 r
F
.52233 .29605 m .5207 .29394 L .5237 .29253 L F
.75556 .28571 m .75729 .28266 L .75869 .2847 L 0 .029 .128 r
F
.75556 .28571 m .75416 .28367 L .75729 .28266 L F
.4475 .29248 m .44876 .28925 L .45045 .29151 L 0 .043 .145 r
F
.4475 .29248 m .4458 .29023 L .44876 .28925 L F
.18491 .28382 m .18575 .2809 L .18771 .28284 L 0 .025 .124 r
F
.18491 .28382 m .18294 .28188 L .18575 .2809 L F
.63663 .28974 m .63818 .2867 L .63969 .28854 L 0 .037 .139 r
F
.63663 .28974 m .63512 .28788 L .63818 .2867 L F
.52995 .29569 m .53133 .29207 L .53295 .29449 L 0 .05 .153 r
F
.52995 .29569 m .52833 .29322 L .53133 .29207 L F
.50708 .29696 m .50843 .29379 L .51008 .29587 L 0 .054 .157 r
F
.50708 .29696 m .50544 .29484 L .50843 .29379 L F
.81353 .28513 m .81535 .2821 L .81668 .28398 L 0 .028 .127 r
F
.81353 .28513 m .8122 .28327 L .81535 .2821 L F
.82115 .28473 m .82299 .2818 L .82432 .28373 L 0 .027 .126 r
F
.82115 .28473 m .81983 .28283 L .82299 .2818 L F
.26273 .28474 m .26369 .28182 L .26558 .28373 L F
.26273 .28474 m .26084 .28281 L .26369 .28182 L F
.09945 .28349 m .10017 .28041 L .10222 .28241 L 0 .024 .123 r
F
.09945 .28349 m .0974 .28148 L .10017 .28041 L F
.3879 .28816 m .38907 .28514 L .39082 .2872 L 0 .034 .135 r
F
.3879 .28816 m .38614 .28612 L .38907 .28514 L F
.51471 .29663 m .51607 .2932 L .5177 .2953 L 0 .053 .156 r
F
.51471 .29663 m .51307 .29453 L .51607 .2932 L F
.62902 .2903 m .63055 .28721 L .63207 .28906 L 0 .038 .14 r
F
.62902 .2903 m .6275 .28843 L .63055 .28721 L F
.55743 .29687 m .55885 .29299 L .56044 .29537 L 0 .053 .155 r
F
.55743 .29687 m .55583 .29449 L .55885 .29299 L F
.36042 .28715 m .36155 .28387 L .36333 .28602 L 0 .031 .132 r
F
.36042 .28715 m .35864 .285 L .36155 .28387 L F
.21999 .28462 m .22089 .28164 L .22282 .28362 L 0 .027 .126 r
F
.21999 .28462 m .21806 .28264 L .22089 .28164 L F
.77081 .28505 m .77258 .2821 L .77395 .28401 L 0 .028 .127 r
F
.77081 .28505 m .76944 .28316 L .77258 .2821 L F
.6595 .28865 m .66108 .28549 L .66257 .28754 L 0 .035 .136 r
F
.6595 .28865 m .658 .28657 L .66108 .28549 L F
.54981 .29732 m .55122 .2936 L .55282 .29598 L 0 .054 .157 r
F
.54981 .29732 m .54821 .29493 L .55122 .2936 L F
.29782 .28554 m .29884 .28264 L .30069 .28453 L 0 .029 .129 r
F
.29782 .28554 m .29596 .28362 L .29884 .28264 L F
.14977 .28344 m .15057 .28043 L .15257 .28236 L 0 .025 .123 r
F
.14977 .28344 m .14777 .28151 L .15057 .28043 L F
.48722 .29571 m .48854 .29205 L .4902 .29453 L 0 .05 .153 r
F
.48722 .29571 m .48556 .29323 L .48854 .29205 L F
.7632 .28558 m .76493 .28239 L .76632 .28437 L 0 .028 .128 r
F
.7632 .28558 m .76181 .28359 L .76493 .28239 L F
.3253 .28667 m .32638 .28346 L .3282 .28555 L 0 .031 .131 r
F
.3253 .28667 m .32348 .28458 L .32638 .28346 L F
.10703 .28331 m .10777 .28022 L .10981 .28221 L 0 .024 .123 r
F
.10703 .28331 m .10499 .28131 L .10777 .28022 L F
.19249 .28374 m .19333 .28088 L .1953 .28274 L 0 .025 .124 r
F
.19249 .28374 m .19052 .28185 L .19333 .28088 L F
.2276 .28439 m .22851 .28138 L .23044 .28327 L 0 .027 .126 r
F
.2276 .28439 m .22566 .2825 L .22851 .28138 L F
.15738 .28315 m .15818 .28015 L .16018 .28205 L 0 .024 .123 r
F
.15738 .28315 m .15538 .28125 L .15818 .28015 L F
.27032 .28463 m .2713 .28172 L .27318 .2836 L 0 .027 .126 r
F
.27032 .28463 m .26844 .28274 L .2713 .28172 L F
.6214 .29099 m .62292 .28784 L .62445 .28971 L 0 .04 .142 r
F
.6214 .29099 m .61988 .28908 L .62292 .28784 L F
.66713 .28846 m .66872 .28529 L .6702 .2873 L 0 .035 .136 r
F
.66713 .28846 m .66564 .28642 L .66872 .28529 L F
.59854 .29227 m .60003 .28916 L .60158 .29112 L 0 .043 .146 r
F
.59854 .29227 m .59699 .29033 L .60003 .28916 L F
.77846 .2849 m .78023 .28192 L .7816 .28387 L 0 .028 .127 r
F
.77846 .2849 m .77709 .28298 L .78023 .28192 L F
.82881 .2847 m .83066 .28172 L .83198 .28369 L 0 .027 .127 r
F
.82881 .2847 m .82749 .28275 L .83066 .28172 L F
.30543 .28534 m .30645 .28248 L .3083 .28434 L 0 .029 .129 r
F
.30543 .28534 m .30357 .28351 L .30645 .28248 L F
.5217 .50054 m .52306 .52885 L .5247 .513 L .623 .734 0 r
F
.5217 .50054 m .52005 .51475 L .52306 .52885 L F
.33291 .28643 m .33399 .28336 L .33581 .28537 L 0 .031 .131 r
F
.33291 .28643 m .33109 .28443 L .33399 .28336 L F
.67476 .28814 m .67636 .28496 L .67783 .28693 L 0 .034 .135 r
F
.67476 .28814 m .67328 .28613 L .67636 .28496 L F
.2352 .28412 m .23612 .28122 L .23804 .28313 L 0 .026 .125 r
F
.2352 .28412 m .23328 .28223 L .23612 .28122 L F
.51115 .44391 m .51258 .42365 L .51416 .44295 L 0 .515 .052 r
F
.68238 .28774 m .684 .28474 L .68547 .28665 L 0 .034 .134 r
F
.68238 .28774 m .68091 .2858 L .684 .28474 L F
.11463 .28309 m .11536 .28014 L .1174 .28206 L 0 .024 .123 r
F
.11463 .28309 m .11258 .28118 L .11536 .28014 L F
.59092 .29285 m .5924 .28963 L .59395 .29159 L 0 .045 .147 r
F
.59092 .29285 m .58936 .29089 L .5924 .28963 L F
.46735 .29454 m .46864 .29134 L .47032 .29349 L 0 .049 .151 r
F
.46735 .29454 m .46567 .29239 L .46864 .29134 L F
.40775 .29011 m .40895 .28687 L .41069 .28894 L 0 .038 .14 r
F
.40775 .29011 m .40601 .28803 L .40895 .28687 L F
.36801 .28717 m .36915 .28416 L .37092 .28627 L 0 .032 .133 r
F
.36801 .28717 m .36624 .28505 L .36915 .28416 L F
.20008 .2836 m .20094 .28072 L .2029 .28257 L 0 .026 .124 r
F
.20008 .2836 m .19812 .28175 L .20094 .28072 L F
.27792 .28445 m .27892 .28142 L .28079 .28335 L 0 .027 .126 r
F
.27792 .28445 m .27605 .28251 L .27892 .28142 L F
.16497 .28298 m .16577 .2801 L .16776 .282 L 0 .024 .123 r
F
.16497 .28298 m .16298 .28107 L .16577 .2801 L F
.53757 .29587 m .53896 .29222 L .54058 .29469 L 0 .051 .154 r
F
.53757 .29587 m .53595 .29335 L .53896 .29222 L F
.43524 .29124 m .43648 .28796 L .43819 .29019 L 0 .041 .143 r
F
.43524 .29124 m .43353 .28898 L .43648 .28796 L F
.60617 .2921 m .60767 .28906 L .60921 .29108 L 0 .043 .146 r
F
.60617 .2921 m .60462 .29009 L .60767 .28906 L F
.54569 .47878 m .54417 .49128 L .54709 .47425 L .217 .619 0 r
F
.54276 .494 m .54417 .49128 L .54569 .47878 L .41 .678 0 r
F
.69763 .28706 m .69926 .28376 L .70072 .28584 L 0 .032 .132 r
F
.69763 .28706 m .69617 .28499 L .69926 .28376 L F
.83646 .28452 m .8383 .28137 L .83962 .28338 L 0 .027 .126 r
F
.83646 .28452 m .83514 .28253 L .8383 .28137 L F
.7861 .28475 m .78788 .28169 L .78924 .28369 L 0 .028 .127 r
F
.7861 .28475 m .78474 .28278 L .78788 .28169 L F
.41537 .28984 m .41658 .28663 L .41831 .2887 L 0 .038 .14 r
F
.41537 .28984 m .41363 .28777 L .41658 .28663 L F
.54688 .468 m .5453 .47108 L .54819 .45031 L .101 .579 0 r
F
.5453 .47108 m .54659 .44852 L .54819 .45031 L .125 .587 0 r
F
.49484 .29578 m .49617 .29256 L .49782 .29476 L 0 .052 .155 r
F
.49484 .29578 m .49318 .29355 L .49617 .29256 L F
.5833 .29346 m .58476 .29015 L .58633 .29218 L 0 .046 .149 r
F
.5833 .29346 m .58174 .29148 L .58476 .29015 L F
.34052 .28628 m .3416 .28334 L .34341 .28528 L 0 .031 .131 r
F
.34052 .28628 m .3387 .28435 L .3416 .28334 L F
.31303 .28523 m .31406 .2824 L .3159 .28432 L 0 .029 .129 r
F
.31303 .28523 m .31118 .28333 L .31406 .2824 L F
.57568 .2939 m .57713 .29079 L .57871 .29275 L 0 .048 .15 r
F
.57568 .2939 m .57411 .29195 L .57713 .29079 L F
.61379 .29179 m .6153 .28846 L .61683 .29042 L 0 .042 .144 r
F
.61379 .29179 m .61225 .2898 L .6153 .28846 L F
.69002 .28756 m .69163 .28429 L .69309 .28629 L 0 .033 .134 r
F
.69002 .28756 m .68855 .28557 L .69163 .28429 L F
.12222 .28293 m .12296 .27994 L .125 .28185 L 0 .024 .123 r
F
.12222 .28293 m .12018 .28101 L .12296 .27994 L F
.4551 .29287 m .45637 .28971 L .45806 .29199 L 0 .045 .148 r
F
.4551 .29287 m .45341 .29061 L .45637 .28971 L F
.39549 .28845 m .39667 .28534 L .39842 .28757 L 0 .035 .137 r
F
.39549 .28845 m .39375 .28624 L .39667 .28534 L F
.84409 .28423 m .84597 .28133 L .84727 .28323 L 0 .027 .126 r
F
.84409 .28423 m .84279 .28233 L .84597 .28133 L F
.07947 .28282 m .08015 .27984 L .08223 .28172 L 0 .024 .123 r
F
.07947 .28282 m .07738 .28094 L .08015 .27984 L F
.70527 .28684 m .70692 .28372 L .70837 .28577 L 0 .032 .132 r
F
.70527 .28684 m .70382 .28478 L .70692 .28372 L F
.24278 .28415 m .24373 .28107 L .24563 .28308 L 0 .027 .126 r
F
.24278 .28415 m .24088 .28213 L .24373 .28107 L F
.20767 .28353 m .20855 .2805 L .21049 .2825 L 0 .026 .124 r
F
.20767 .28353 m .20573 .28154 L .20855 .2805 L F
.56806 .29453 m .5695 .291 L .57108 .29312 L 0 .049 .151 r
F
.56806 .29453 m .56648 .29239 L .5695 .291 L F
.47496 .29454 m .47627 .29098 L .47794 .29329 L F
.47496 .29454 m .47329 .29224 L .47627 .29098 L F
.72814 .28567 m .72982 .28253 L .73124 .28448 L 0 .03 .13 r
F
.72814 .28567 m .72672 .28372 L .72982 .28253 L F
.12981 .28271 m .13058 .27969 L .1326 .28163 L 0 .024 .122 r
F
.12981 .28271 m .12779 .28078 L .13058 .27969 L F
.28552 .28441 m .28652 .28144 L .28838 .28349 L 0 .027 .127 r
F
.28552 .28441 m .28366 .28236 L .28652 .28144 L F
.79375 .28462 m .79554 .28154 L .7969 .28356 L 0 .028 .127 r
F
.79375 .28462 m .79239 .28261 L .79554 .28154 L F
.08707 .28252 m .08776 .27957 L .08983 .28147 L 0 .024 .122 r
F
.08707 .28252 m .085 .28063 L .08776 .27957 L F
.42298 .28974 m .4242 .28646 L .42592 .28865 L 0 .038 .14 r
F
.42298 .28974 m .42126 .28758 L .4242 .28646 L F
.34812 .28616 m .34922 .28319 L .35103 .28509 L 0 .031 .131 r
F
.34812 .28616 m .34632 .28424 L .34922 .28319 L F
.73577 .28533 m .73747 .28221 L .73888 .28422 L 0 .029 .129 r
F
.73577 .28533 m .73435 .28335 L .73747 .28221 L F
.17254 .28302 m .17337 .27996 L .17535 .28196 L 0 .025 .123 r
F
.17254 .28302 m .17057 .281 L .17337 .27996 L F
.72052 .28619 m .72219 .28297 L .72362 .28496 L 0 .031 .131 r
F
.72052 .28619 m .71909 .28417 L .72219 .28297 L F
.7129 .28665 m .71456 .28337 L .716 .28541 L 0 .032 .132 r
F
.7129 .28665 m .71146 .2846 L .71456 .28337 L F
.6473 .28773 m .64886 .28466 L .65036 .28652 L 0 .034 .135 r
F
.6473 .28773 m .6458 .28588 L .64886 .28466 L F
.37561 .28731 m .37675 .28438 L .37853 .28629 L 0 .034 .134 r
F
.37561 .28731 m .37383 .28536 L .37675 .28438 L F
.44284 .29135 m .4441 .28799 L .4458 .29023 L 0 .042 .144 r
F
.44284 .29135 m .44114 .28909 L .4441 .28799 L F
.50675 .45767 m .5052 .43769 L .50817 .44079 L .057 .562 0 r
F
.50381 .4486 m .5052 .43769 L .50675 .45767 L 0 .535 .008 r
F
.7434 .28503 m .7451 .28178 L .74651 .28381 L 0 .028 .128 r
F
.7434 .28503 m .74199 .28301 L .7451 .28178 L F
.5452 .29604 m .5466 .29252 L .54821 .29493 L 0 .053 .156 r
F
.5452 .29604 m .54359 .29361 L .5466 .29252 L F
.75103 .28467 m .75275 .28162 L .75416 .28367 L 0 .028 .128 r
F
.75103 .28467 m .74962 .28263 L .75275 .28162 L F
.50245 .29588 m .5038 .29274 L .50544 .29484 L 0 .053 .156 r
F
.50245 .29588 m .50081 .29374 L .5038 .29274 L F
.25038 .28405 m .25134 .28091 L .25323 .28295 L 0 .027 .126 r
F
.25038 .28405 m .24848 .282 L .25134 .28091 L F
.1374 .28258 m .13818 .27949 L .14019 .28152 L 0 .024 .122 r
F
.1374 .28258 m .13539 .28055 L .13818 .27949 L F
.52532 .29464 m .5267 .29112 L .52833 .29322 L 0 .05 .152 r
F
.52532 .29464 m .5237 .29253 L .5267 .29112 L F
.8014 .28453 m .8032 .28149 L .80456 .28352 L 0 .028 .127 r
F
.8014 .28453 m .80005 .2825 L .8032 .28149 L F
.48258 .29449 m .4839 .29075 L .48556 .29323 L 0 .049 .151 r
F
.48258 .29449 m .48092 .29202 L .4839 .29075 L F
.09464 .28245 m .09534 .27951 L .0974 .28148 L 0 .024 .122 r
F
.09464 .28245 m .09259 .28049 L .09534 .27951 L F
.18013 .28288 m .18097 .27991 L .18294 .28188 L 0 .025 .123 r
F
.18013 .28288 m .17816 .28091 L .18097 .27991 L F
.56044 .29537 m .56187 .29154 L .56346 .29388 L 0 .051 .153 r
F
.56044 .29537 m .55885 .29299 L .56187 .29154 L F
.38322 .28715 m .38437 .28426 L .38614 .28612 L 0 .034 .135 r
F
.38322 .28715 m .38145 .28528 L .38437 .28426 L F
.65493 .28759 m .65651 .2845 L .658 .28657 L F
.65493 .28759 m .65343 .28551 L .65651 .2845 L F
.21524 .28358 m .21613 .28063 L .21806 .28264 L 0 .026 .125 r
F
.21524 .28358 m .21331 .28156 L .21613 .28063 L F
.35572 .28613 m .35685 .28288 L .35864 .285 L 0 .031 .131 r
F
.35572 .28613 m .35394 .28401 L .35685 .28288 L F
.3206 .28552 m .32166 .28249 L .32348 .28458 L 0 .03 .13 r
F
.3206 .28552 m .31878 .28342 L .32166 .28249 L F
.5177 .2953 m .51907 .29183 L .5207 .29394 L 0 .052 .154 r
F
.5177 .2953 m .51607 .2932 L .51907 .29183 L F
.63969 .28854 m .64124 .28537 L .64274 .28721 L 0 .036 .138 r
F
.63969 .28854 m .63818 .2867 L .64124 .28537 L F
.25798 .2839 m .25895 .28077 L .26084 .28281 L 0 .027 .126 r
F
.25798 .2839 m .25609 .28186 L .25895 .28077 L F
.53295 .29449 m .53434 .29098 L .53595 .29335 L 0 .05 .152 r
F
.53295 .29449 m .53133 .29207 L .53434 .29098 L F
.55282 .29598 m .55423 .2921 L .55583 .29449 L 0 .053 .155 r
F
.55282 .29598 m .55122 .2936 L .55423 .2921 L F
.80905 .28436 m .81087 .28141 L .8122 .28327 L 0 .028 .128 r
F
.80905 .28436 m .80772 .28251 L .81087 .28141 L F
.4627 .29326 m .46399 .29025 L .46567 .29239 L 0 .048 .15 r
F
.4627 .29326 m .46102 .29112 L .46399 .29025 L F
.29309 .28461 m .29411 .2816 L .29596 .28362 L 0 .028 .128 r
F
.29309 .28461 m .29124 .28256 L .29411 .2816 L F
.81668 .28398 m .8185 .28093 L .81983 .28283 L 0 .027 .127 r
F
.81668 .28398 m .81535 .2821 L .8185 .28093 L F
.63207 .28906 m .63361 .28603 L .63512 .28788 L 0 .038 .14 r
F
.63207 .28906 m .63055 .28721 L .63361 .28603 L F
.14498 .28253 m .14576 .27952 L .14777 .28151 L 0 .025 .123 r
F
.14498 .28253 m .14297 .28052 L .14576 .27952 L F
.51008 .29587 m .51143 .29243 L .51307 .29453 L 0 .054 .156 r
F
.51008 .29587 m .50843 .29379 L .51143 .29243 L F
.43058 .28998 m .43182 .28671 L .43353 .28898 L 0 .04 .141 r
F
.43058 .28998 m .42887 .28768 L .43182 .28671 L F
.75869 .2847 m .76042 .28155 L .76181 .28359 L 0 .029 .128 r
F
.75869 .2847 m .75729 .28266 L .76042 .28155 L F
.40308 .28895 m .40427 .28578 L .40601 .28803 L 0 .037 .139 r
F
.40308 .28895 m .40134 .2867 L .40427 .28578 L F
.18771 .28284 m .18856 .27992 L .19052 .28185 L 0 .025 .124 r
F
.18771 .28284 m .18575 .2809 L .18856 .27992 L F
.10222 .28241 m .10295 .27931 L .10499 .28131 L 0 .024 .123 r
F
.10222 .28241 m .10017 .28041 L .10295 .27931 L F
.45045 .29151 m .45172 .28832 L .45341 .29061 L 0 .043 .146 r
F
.45045 .29151 m .44876 .28925 L .45172 .28832 L F
.36333 .28602 m .36446 .2829 L .36624 .28505 L 0 .031 .132 r
F
.36333 .28602 m .36155 .28387 L .36446 .2829 L F
.82432 .28373 m .82617 .2808 L .82749 .28275 L 0 .027 .126 r
F
.82432 .28373 m .82299 .2818 L .82617 .2808 L F
.26558 .28373 m .26655 .28084 L .26844 .28274 L F
.26558 .28373 m .26369 .28182 L .26655 .28084 L F
.76632 .28437 m .76806 .28119 L .76944 .28316 L 0 .028 .128 r
F
.76632 .28437 m .76493 .28239 L .76806 .28119 L F
.66257 .28754 m .66416 .28439 L .66564 .28642 L 0 .035 .136 r
F
.66257 .28754 m .66108 .28549 L .66416 .28439 L F
.4902 .29453 m .49153 .29109 L .49318 .29355 L 0 .05 .153 r
F
.4902 .29453 m .48854 .29205 L .49153 .29109 L F
.62445 .28971 m .62598 .2866 L .6275 .28843 L 0 .039 .141 r
F
.62445 .28971 m .62292 .28784 L .62598 .2866 L F
.77395 .28401 m .77572 .28105 L .77709 .28298 L 0 .028 .127 r
F
.77395 .28401 m .77258 .2821 L .77572 .28105 L F
.51707 .49974 m .51838 .52805 L .52005 .51475 L .623 .734 0 r
F
.51707 .49974 m .5154 .51141 L .51838 .52805 L F
.39082 .2872 m .39199 .28414 L .39375 .28624 L 0 .034 .135 r
F
.39082 .2872 m .38907 .28514 L .39199 .28414 L F
.22282 .28362 m .22374 .28053 L .22566 .2825 L 0 .027 .126 r
F
.22282 .28362 m .22089 .28164 L .22374 .28053 L F
.15257 .28236 m .15337 .27933 L .15538 .28125 L 0 .024 .123 r
F
.15257 .28236 m .15057 .28043 L .15337 .27933 L F
.3282 .28555 m .32928 .28234 L .33109 .28443 L 0 .03 .131 r
F
.3282 .28555 m .32638 .28346 L .32928 .28234 L F
.30069 .28453 m .30171 .28163 L .30357 .28351 L 0 .029 .129 r
F
.30069 .28453 m .29884 .28264 L .30171 .28163 L F
.23044 .28327 m .23135 .28033 L .23328 .28223 L 0 .026 .126 r
F
.23044 .28327 m .22851 .28138 L .23135 .28033 L F
.10981 .28221 m .11055 .27918 L .11258 .28118 L 0 .024 .123 r
F
.10981 .28221 m .10777 .28022 L .11055 .27918 L F
.6702 .2873 m .6718 .28415 L .67328 .28613 L 0 .034 .135 r
F
.6702 .2873 m .66872 .28529 L .6718 .28415 L F
.60158 .29112 m .60307 .2881 L .60462 .29009 L 0 .043 .145 r
F
.60158 .29112 m .60003 .28916 L .60307 .2881 L F
.52932 .50179 m .53075 .52401 L .53234 .50655 L .601 .729 0 r
F
.52932 .50179 m .52772 .51849 L .53075 .52401 L F
.16018 .28205 m .16098 .27917 L .16298 .28107 L 0 .024 .123 r
F
.16018 .28205 m .15818 .28015 L .16098 .27917 L F
.67783 .28693 m .67944 .28386 L .68091 .2858 L 0 .034 .135 r
F
.67783 .28693 m .67636 .28496 L .67944 .28386 L F
.59395 .29159 m .59543 .28836 L .59699 .29033 L 0 .044 .146 r
F
.59395 .29159 m .5924 .28963 L .59543 .28836 L F
.1953 .28274 m .19615 .27989 L .19812 .28175 L 0 .026 .125 r
F
.1953 .28274 m .19333 .28088 L .19615 .27989 L F
.27318 .2836 m .27416 .28063 L .27605 .28251 L 0 .027 .126 r
F
.27318 .2836 m .2713 .28172 L .27416 .28063 L F
.61683 .29042 m .61834 .28716 L .61988 .28908 L 0 .041 .143 r
F
.61683 .29042 m .6153 .28846 L .61834 .28716 L F
.7816 .28387 m .78337 .28081 L .78474 .28278 L 0 .028 .127 r
F
.7816 .28387 m .78023 .28192 L .78337 .28081 L F
.41069 .28894 m .4119 .28571 L .41363 .28777 L 0 .038 .14 r
F
.41069 .28894 m .40895 .28687 L .4119 .28571 L F
.33581 .28537 m .33689 .28233 L .3387 .28435 L 0 .031 .131 r
F
.33581 .28537 m .33399 .28336 L .33689 .28233 L F
.83198 .28369 m .83382 .28054 L .83514 .28253 L 0 .027 .126 r
F
.83198 .28369 m .83066 .28172 L .83382 .28054 L F
.68547 .28665 m .68709 .28368 L .68855 .28557 L 0 .033 .134 r
F
.68547 .28665 m .684 .28474 L .68709 .28368 L F
.54058 .29469 m .54197 .29116 L .54359 .29361 L 0 .051 .154 r
F
.54058 .29469 m .53896 .29222 L .54197 .29116 L F
.3083 .28434 m .30933 .28145 L .31118 .28333 L 0 .029 .129 r
F
.3083 .28434 m .30645 .28248 L .30933 .28145 L F
.58633 .29218 m .5878 .28883 L .58936 .29089 L 0 .045 .148 r
F
.58633 .29218 m .58476 .29015 L .5878 .28883 L F
.70072 .28584 m .70236 .28271 L .70382 .28478 L 0 .032 .132 r
F
.70072 .28584 m .69926 .28376 L .70236 .28271 L F
.69309 .28629 m .69472 .28298 L .69617 .28499 L 0 .032 .133 r
F
.69309 .28629 m .69163 .28429 L .69472 .28298 L F
.1174 .28206 m .11814 .27909 L .12018 .28101 L 0 .024 .123 r
F
.1174 .28206 m .11536 .28014 L .11814 .27909 L F
.47032 .29349 m .47162 .2901 L .47329 .29224 L 0 .048 .151 r
F
.47032 .29349 m .46864 .29134 L .47162 .2901 L F
.23804 .28313 m .23896 .28021 L .24088 .28213 L 0 .027 .126 r
F
.23804 .28313 m .23612 .28122 L .23896 .28021 L F
.28079 .28335 m .28179 .28042 L .28366 .28236 L F
.28079 .28335 m .27892 .28142 L .28179 .28042 L F
.83962 .28338 m .84148 .28031 L .84279 .28233 L F
.83962 .28338 m .8383 .28137 L .84148 .28031 L F
.57108 .29312 m .57253 .28983 L .57411 .29195 L 0 .048 .15 r
F
.57108 .29312 m .5695 .291 L .57253 .28983 L F
.41831 .2887 m .41953 .28549 L .42126 .28758 L 0 .038 .139 r
F
.41831 .2887 m .41658 .28663 L .41953 .28549 L F
.43819 .29019 m .43944 .28689 L .44114 .28909 L 0 .041 .143 r
F
.43819 .29019 m .43648 .28796 L .43944 .28689 L F
.2029 .28257 m .20377 .27966 L .20573 .28154 L 0 .026 .124 r
F
.2029 .28257 m .20094 .28072 L .20377 .27966 L F
.57871 .29275 m .58016 .28949 L .58174 .29148 L 0 .047 .15 r
F
.57871 .29275 m .57713 .29079 L .58016 .28949 L F
.54417 .49128 m .54556 .48427 L .54709 .47425 L .38 .67 0 r
F
.54709 .47425 m .54556 .48427 L .54845 .46494 L .168 .603 0 r
F
.54556 .48427 m .54688 .468 L .54845 .46494 L .263 .634 0 r
F
.54205 .46265 m .54333 .43681 L .54496 .44266 L .055 .561 0 r
F
.54205 .46265 m .5404 .456 L .54333 .43681 L F
.60921 .29108 m .61071 .28776 L .61225 .2898 L 0 .043 .145 r
F
.60921 .29108 m .60767 .28906 L .61071 .28776 L F
.78924 .28369 m .79103 .2806 L .79239 .28261 L 0 .028 .127 r
F
.78924 .28369 m .78788 .28169 L .79103 .2806 L F
.16776 .282 m .16857 .2791 L .17057 .281 L 0 .025 .123 r
F
.16776 .282 m .16577 .2801 L .16857 .2791 L F
.37092 .28627 m .37206 .28327 L .37383 .28536 L 0 .033 .134 r
F
.37092 .28627 m .36915 .28416 L .37206 .28327 L F
.125 .28185 m .12575 .27887 L .12779 .28078 L 0 .024 .123 r
F
.125 .28185 m .12296 .27994 L .12575 .27887 L F
.49782 .29476 m .49916 .29158 L .50081 .29374 L 0 .052 .155 r
F
.49782 .29476 m .49617 .29256 L .49916 .29158 L F
.47794 .29329 m .47925 .28972 L .48092 .29202 L 0 .048 .15 r
F
.47794 .29329 m .47627 .29098 L .47925 .28972 L F
.34341 .28528 m .34451 .28231 L .34632 .28424 L 0 .031 .131 r
F
.34341 .28528 m .3416 .28334 L .34451 .28231 L F
.08223 .28172 m .08292 .27873 L .085 .28063 L 0 .024 .122 r
F
.08223 .28172 m .08015 .27984 L .08292 .27873 L F
.73124 .28448 m .73294 .28139 L .73435 .28335 L 0 .029 .129 r
F
.73124 .28448 m .72982 .28253 L .73294 .28139 L F
.70837 .28577 m .71002 .28256 L .71146 .2846 L 0 .032 .132 r
F
.70837 .28577 m .70692 .28372 L .71002 .28256 L F
.84727 .28323 m .84916 .28033 L .85046 .28223 L 0 .027 .126 r
F
.84727 .28323 m .84597 .28133 L .84916 .28033 L F
.3159 .28432 m .31694 .2815 L .31878 .28342 L 0 .029 .129 r
F
.3159 .28432 m .31406 .2824 L .31694 .2815 L F
.72362 .28496 m .72529 .28176 L .72672 .28372 L 0 .03 .13 r
F
.72362 .28496 m .72219 .28297 L .72529 .28176 L F
.52833 .29322 m .52971 .28999 L .53133 .29207 L 0 .049 .151 r
F
.52833 .29322 m .5267 .29112 L .52971 .28999 L F
.24563 .28308 m .24658 .28001 L .24848 .282 L 0 .027 .126 r
F
.24563 .28308 m .24373 .28107 L .24658 .28001 L F
.716 .28541 m .71765 .28215 L .71909 .28417 L 0 .031 .131 r
F
.716 .28541 m .71456 .28337 L .71765 .28215 L F
.56346 .29388 m .56489 .29009 L .56648 .29239 L 0 .049 .152 r
F
.56346 .29388 m .56187 .29154 L .56489 .29009 L F
.45806 .29199 m .45934 .28881 L .46102 .29112 L 0 .046 .148 r
F
.45806 .29199 m .45637 .28971 L .45934 .28881 L F
.1326 .28163 m .13337 .27859 L .13539 .28055 L 0 .024 .122 r
F
.1326 .28163 m .13058 .27969 L .13337 .27859 L F
.39842 .28757 m .3996 .28446 L .40134 .2867 L 0 .036 .137 r
F
.39842 .28757 m .39667 .28534 L .3996 .28446 L F
.65036 .28652 m .65193 .28364 L .65343 .28551 L 0 .034 .135 r
F
.65036 .28652 m .64886 .28466 L .65193 .28364 L F
.21049 .2825 m .21137 .27956 L .21331 .28156 L 0 .026 .125 r
F
.21049 .2825 m .20855 .2805 L .21137 .27956 L F
.7969 .28356 m .79869 .28047 L .80005 .2825 L 0 .028 .127 r
F
.7969 .28356 m .79554 .28154 L .79869 .28047 L F
.42592 .28865 m .42715 .28551 L .42887 .28768 L 0 .038 .14 r
F
.42592 .28865 m .4242 .28646 L .42715 .28551 L F
.73888 .28422 m .74058 .28099 L .74199 .28301 L 0 .029 .129 r
F
.73888 .28422 m .73747 .28221 L .74058 .28099 L F
.08983 .28147 m .09052 .27858 L .09259 .28049 L 0 .024 .122 r
F
.08983 .28147 m .08776 .27957 L .09052 .27858 L F
.74651 .28381 m .74822 .28059 L .74962 .28263 L 0 .028 .128 r
F
.74651 .28381 m .7451 .28178 L .74822 .28059 L F
.35103 .28509 m .35213 .28211 L .35394 .28401 L 0 .031 .131 r
F
.35103 .28509 m .34922 .28319 L .35213 .28211 L F
.17535 .28196 m .17618 .27892 L .17816 .28091 L 0 .025 .123 r
F
.17535 .28196 m .17337 .27996 L .17618 .27892 L F
.4458 .29023 m .44706 .287 L .44876 .28925 L 0 .042 .144 r
F
.4458 .29023 m .4441 .28799 L .44706 .287 L F
.55583 .29449 m .55725 .2906 L .55885 .29299 L 0 .051 .153 r
F
.55583 .29449 m .55423 .2921 L .55725 .2906 L F
.28838 .28349 m .28938 .28051 L .29124 .28256 L 0 .028 .127 r
F
.28838 .28349 m .28652 .28144 L .28938 .28051 L F
.48556 .29323 m .48689 .28957 L .48854 .29205 L 0 .048 .151 r
F
.48556 .29323 m .4839 .29075 L .48689 .28957 L F
.54821 .29493 m .54961 .29123 L .55122 .2936 L 0 .052 .155 r
F
.54821 .29493 m .5466 .29252 L .54961 .29123 L F
.37853 .28629 m .37967 .2834 L .38145 .28528 L 0 .034 .135 r
F
.37853 .28629 m .37675 .28438 L .37967 .2834 L F
.5207 .29394 m .52207 .29043 L .5237 .29253 L 0 .05 .153 r
F
.5207 .29394 m .51907 .29183 L .52207 .29043 L F
.25323 .28295 m .2542 .27982 L .25609 .28186 L 0 .027 .126 r
F
.25323 .28295 m .25134 .28091 L .2542 .27982 L F
.64274 .28721 m .64429 .28403 L .6458 .28588 L 0 .035 .137 r
F
.64274 .28721 m .64124 .28537 L .64429 .28403 L F
.50544 .29484 m .50679 .29171 L .50843 .29379 L 0 .054 .156 r
F
.50544 .29484 m .5038 .29274 L .50679 .29171 L F
.14019 .28152 m .14097 .27851 L .14297 .28052 L 0 .024 .122 r
F
.14019 .28152 m .13818 .27949 L .14097 .27851 L F
.75416 .28367 m .75589 .28061 L .75729 .28266 L 0 .028 .128 r
F
.75416 .28367 m .75275 .28162 L .75589 .28061 L F
.35864 .285 m .35977 .28175 L .36155 .28387 L 0 .031 .131 r
F
.35864 .285 m .35685 .28288 L .35977 .28175 L F
.80456 .28352 m .80637 .28048 L .80772 .28251 L 0 .028 .128 r
F
.80456 .28352 m .8032 .28149 L .80637 .28048 L F
.51307 .29453 m .51443 .29107 L .51607 .2932 L 0 .052 .155 r
F
.51307 .29453 m .51143 .29243 L .51443 .29107 L F
.54369 .4693 m .54496 .44266 L .54659 .44852 L .101 .579 0 r
F
.54369 .4693 m .54205 .46265 L .54496 .44266 L F
.18294 .28188 m .18378 .27892 L .18575 .2809 L 0 .025 .124 r
F
.18294 .28188 m .18097 .27991 L .18378 .27892 L F
.38614 .28612 m .3873 .28324 L .38907 .28514 L 0 .034 .135 r
F
.38614 .28612 m .38437 .28426 L .3873 .28324 L F
.0974 .28148 m .09812 .27844 L .10017 .28041 L 0 .024 .123 r
F
.0974 .28148 m .09534 .27951 L .09812 .27844 L F
.658 .28657 m .65958 .28343 L .66108 .28549 L 0 .034 .135 r
F
.658 .28657 m .65651 .2845 L .65958 .28343 L F
.504 .47151 m .50244 .45541 L .50536 .46699 L .217 .619 0 r
F
.50244 .45541 m .50381 .4486 L .50536 .46699 L .05 .559 0 r
F
.53595 .29335 m .53735 .28989 L .53896 .29222 L 0 .049 .152 r
F
.53595 .29335 m .53434 .29098 L .53735 .28989 L F
.63512 .28788 m .63667 .28485 L .63818 .2867 L 0 .037 .139 r
F
.63512 .28788 m .63361 .28603 L .63667 .28485 L F
.26084 .28281 m .2618 .27979 L .26369 .28182 L 0 .027 .126 r
F
.26084 .28281 m .25895 .28077 L .2618 .27979 L F
.81983 .28283 m .82167 .27988 L .82299 .2818 L F
.81983 .28283 m .8185 .28093 L .82167 .27988 L F
.8122 .28327 m .81402 .28022 L .81535 .2821 L 0 .028 .127 r
F
.8122 .28327 m .81087 .28141 L .81402 .28022 L F
.21806 .28264 m .21896 .27963 L .22089 .28164 L 0 .027 .126 r
F
.21806 .28264 m .21613 .28063 L .21896 .27963 L F
.32348 .28458 m .32456 .28137 L .32638 .28346 L 0 .03 .13 r
F
.32348 .28458 m .32166 .28249 L .32456 .28137 L F
.6275 .28843 m .62903 .28539 L .63055 .28721 L 0 .039 .141 r
F
.6275 .28843 m .62598 .2866 L .62903 .28539 L F
.76944 .28316 m .7712 .28013 L .77258 .2821 L 0 .028 .127 r
F
.76944 .28316 m .76806 .28119 L .7712 .28013 L F
.76181 .28359 m .76354 .28037 L .76493 .28239 L 0 .028 .128 r
F
.76181 .28359 m .76042 .28155 L .76354 .28037 L F
.29596 .28362 m .29698 .28063 L .29884 .28264 L 0 .029 .129 r
F
.29596 .28362 m .29411 .2816 L .29698 .28063 L F
.14777 .28151 m .14856 .27845 L .15057 .28043 L 0 .025 .123 r
F
.14777 .28151 m .14576 .27952 L .14856 .27845 L F
.10499 .28131 m .10573 .27822 L .10777 .28022 L 0 .024 .122 r
F
.10499 .28131 m .10295 .27931 L .10573 .27822 L F
.66564 .28642 m .66724 .28329 L .66872 .28529 L 0 .034 .135 r
F
.66564 .28642 m .66416 .28439 L .66724 .28329 L F
.43353 .28898 m .43477 .28572 L .43648 .28796 L 0 .04 .142 r
F
.43353 .28898 m .43182 .28671 L .43477 .28572 L F
.5218 .45289 m .5232 .42356 L .52482 .44185 L 0 .535 .008 r
F
.5218 .45289 m .52019 .43288 L .5232 .42356 L F
.46567 .29239 m .46696 .28919 L .46864 .29134 L 0 .048 .151 r
F
.46567 .29239 m .46399 .29025 L .46696 .28919 L F
.19052 .28185 m .19137 .27895 L .19333 .28088 L 0 .026 .124 r
F
.19052 .28185 m .18856 .27992 L .19137 .27895 L F
.59699 .29033 m .59847 .28718 L .60003 .28916 L 0 .043 .145 r
F
.59699 .29033 m .59543 .28836 L .59847 .28718 L F
.22566 .2825 m .22658 .27942 L .22851 .28138 L 0 .027 .126 r
F
.22566 .2825 m .22374 .28053 L .22658 .27942 L F
.54133 .49242 m .5398 .50837 L .54276 .494 L .381 .67 0 r
F
.53835 .49901 m .5398 .50837 L .54133 .49242 L .511 .706 0 r
F
.36624 .28505 m .36737 .28201 L .36915 .28416 L 0 .032 .132 r
F
.36624 .28505 m .36446 .2829 L .36737 .28201 L F
.61988 .28908 m .6214 .28596 L .62292 .28784 L 0 .04 .142 r
F
.61988 .28908 m .61834 .28716 L .6214 .28596 L F
.15538 .28125 m .15618 .27822 L .15818 .28015 L 0 .024 .123 r
F
.15538 .28125 m .15337 .27933 L .15618 .27822 L F
.33109 .28443 m .33218 .28126 L .33399 .28336 L 0 .03 .131 r
F
.33109 .28443 m .32928 .28234 L .33218 .28126 L F
.26844 .28274 m .26941 .27983 L .2713 .28172 L 0 .027 .127 r
F
.26844 .28274 m .26655 .28084 L .26941 .27983 L F
.40601 .28803 m .40722 .28462 L .40895 .28687 L 0 .038 .139 r
F
.40601 .28803 m .40427 .28578 L .40722 .28462 L F
.82749 .28275 m .82934 .27975 L .83066 .28172 L 0 .027 .127 r
F
.82749 .28275 m .82617 .2808 L .82934 .27975 L F
.67328 .28613 m .67488 .28302 L .67636 .28496 L 0 .034 .135 r
F
.67328 .28613 m .6718 .28415 L .67488 .28302 L F
.49318 .29355 m .49451 .29013 L .49617 .29256 L 0 .051 .153 r
F
.49318 .29355 m .49153 .29109 L .49451 .29013 L F
.77709 .28298 m .77886 .27997 L .78023 .28192 L 0 .028 .127 r
F
.77709 .28298 m .77572 .28105 L .77886 .27997 L F
.45341 .29061 m .45468 .28739 L .45637 .28971 L 0 .044 .146 r
F
.45341 .29061 m .45172 .28832 L .45468 .28739 L F
.68091 .2858 m .68254 .28283 L .684 .28474 L 0 .034 .135 r
F
.68091 .2858 m .67944 .28386 L .68254 .28283 L F
.58936 .29089 m .59083 .28756 L .5924 .28963 L 0 .044 .147 r
F
.58936 .29089 m .5878 .28883 L .59083 .28756 L F
.39375 .28624 m .39492 .28322 L .39667 .28534 L 0 .034 .136 r
F
.39375 .28624 m .39199 .28414 L .39492 .28322 L F
.23328 .28223 m .2342 .27931 L .23612 .28122 L 0 .027 .126 r
F
.23328 .28223 m .23135 .28033 L .2342 .27931 L F
.11258 .28118 m .11332 .27815 L .11536 .28014 L 0 .024 .123 r
F
.11258 .28118 m .11055 .27918 L .11332 .27815 L F
.30357 .28351 m .3046 .28058 L .30645 .28248 L 0 .029 .129 r
F
.30357 .28351 m .30171 .28163 L .3046 .28058 L F
.69617 .28499 m .69781 .28175 L .69926 .28376 L 0 .032 .132 r
F
.69617 .28499 m .69472 .28298 L .69781 .28175 L F
.60462 .29009 m .60612 .28704 L .60767 .28906 L 0 .043 .145 r
F
.60462 .29009 m .60307 .2881 L .60612 .28704 L F
.41363 .28777 m .41485 .28455 L .41658 .28663 L 0 .038 .139 r
F
.41363 .28777 m .4119 .28571 L .41485 .28455 L F
.47329 .29224 m .4746 .28886 L .47627 .29098 L 0 .048 .15 r
F
.47329 .29224 m .47162 .2901 L .4746 .28886 L F
.27605 .28251 m .27704 .27954 L .27892 .28142 L 0 .027 .126 r
F
.27605 .28251 m .27416 .28063 L .27704 .27954 L F
.83514 .28253 m .83698 .27936 L .8383 .28137 L F
.83514 .28253 m .83382 .28054 L .83698 .27936 L F
.16298 .28107 m .16377 .2782 L .16577 .2801 L 0 .025 .123 r
F
.16298 .28107 m .16098 .27917 L .16377 .2782 L F
.78474 .28278 m .78651 .2797 L .78788 .28169 L 0 .027 .127 r
F
.78474 .28278 m .78337 .28081 L .78651 .2797 L F
.58174 .29148 m .5832 .28813 L .58476 .29015 L 0 .046 .149 r
F
.58174 .29148 m .58016 .28949 L .5832 .28813 L F
.19812 .28175 m .19898 .27886 L .20094 .28072 L 0 .026 .125 r
F
.19812 .28175 m .19615 .27989 L .19898 .27886 L F
.54359 .29361 m .54499 .2901 L .5466 .29252 L 0 .051 .154 r
F
.54359 .29361 m .54197 .29116 L .54499 .2901 L F
.61225 .2898 m .61376 .28641 L .6153 .28846 L 0 .042 .144 r
F
.61225 .2898 m .61071 .28776 L .61376 .28641 L F
.5453 .47108 m .54369 .4693 L .54659 .44852 L .125 .587 0 r
F
.68855 .28557 m .69018 .28242 L .69163 .28429 L 0 .033 .134 r
F
.68855 .28557 m .68709 .28368 L .69018 .28242 L F
.57411 .29195 m .57556 .28866 L .57713 .29079 L 0 .047 .15 r
F
.57411 .29195 m .57253 .28983 L .57556 .28866 L F
.56648 .29239 m .56791 .28873 L .5695 .291 L 0 .048 .15 r
F
.56648 .29239 m .56489 .29009 L .56791 .28873 L F
.3387 .28435 m .33979 .2813 L .3416 .28334 L 0 .031 .131 r
F
.3387 .28435 m .33689 .28233 L .33979 .2813 L F
.70382 .28478 m .70547 .28166 L .70692 .28372 L 0 .032 .132 r
F
.70382 .28478 m .70236 .28271 L .70547 .28166 L F
.31118 .28333 m .31222 .28051 L .31406 .2824 L 0 .029 .129 r
F
.31118 .28333 m .30933 .28145 L .31222 .28051 L F
.12018 .28101 m .12092 .27802 L .12296 .27994 L 0 .024 .123 r
F
.12018 .28101 m .11814 .27909 L .12092 .27802 L F
.48092 .29202 m .48224 .28845 L .4839 .29075 L 0 .047 .15 r
F
.48092 .29202 m .47925 .28972 L .48224 .28845 L F
.42126 .28758 m .42248 .28436 L .4242 .28646 L 0 .037 .139 r
F
.42126 .28758 m .41953 .28549 L .42248 .28436 L F
.44114 .28909 m .4424 .28583 L .4441 .28799 L 0 .041 .143 r
F
.44114 .28909 m .43944 .28689 L .4424 .28583 L F
.84279 .28233 m .84466 .27929 L .84597 .28133 L 0 .027 .126 r
F
.84279 .28233 m .84148 .28031 L .84466 .27929 L F
.24088 .28213 m .24181 .27915 L .24373 .28107 L F
.24088 .28213 m .23896 .28021 L .24181 .27915 L F
.28366 .28236 m .28465 .27949 L .28652 .28144 L 0 .027 .127 r
F
.28366 .28236 m .28179 .28042 L .28465 .27949 L F
.20573 .28154 m .2066 .27859 L .20855 .2805 L 0 .026 .124 r
F
.20573 .28154 m .20377 .27966 L .2066 .27859 L F
.79239 .28261 m .79417 .27951 L .79554 .28154 L 0 .027 .127 r
F
.79239 .28261 m .79103 .2806 L .79417 .27951 L F
.55885 .29299 m .56027 .28919 L .56187 .29154 L 0 .049 .152 r
F
.55885 .29299 m .55725 .2906 L .56027 .28919 L F
.07738 .28094 m .07807 .27787 L .08015 .27984 L 0 .024 .123 r
F
.07738 .28094 m .0753 .27897 L .07807 .27787 L F
.72672 .28372 m .7284 .28059 L .72982 .28253 L 0 .03 .13 r
F
.72672 .28372 m .72529 .28176 L .7284 .28059 L F
.50536 .46699 m .50381 .4486 L .50675 .45767 L .169 .603 0 r
F
.12779 .28078 m .12854 .27777 L .13058 .27969 L 0 .024 .122 r
F
.12779 .28078 m .12575 .27887 L .12854 .27777 L F
.71909 .28417 m .72076 .28097 L .72219 .28297 L 0 .03 .131 r
F
.71909 .28417 m .71765 .28215 L .72076 .28097 L F
.71146 .2846 m .71311 .28134 L .71456 .28337 L 0 .031 .132 r
F
.71146 .2846 m .71002 .28256 L .71311 .28134 L F
.17057 .281 m .17138 .27806 L .17337 .27996 L 0 .025 .123 r
F
.17057 .281 m .16857 .2791 L .17138 .27806 L F
.73435 .28335 m .73605 .28026 L .73747 .28221 L 0 .029 .129 r
F
.73435 .28335 m .73294 .28139 L .73605 .28026 L F
.50081 .29374 m .50215 .2906 L .5038 .29274 L 0 .053 .155 r
F
.50081 .29374 m .49916 .29158 L .50215 .2906 L F
.085 .28063 m .08568 .27766 L .08776 .27957 L 0 .024 .122 r
F
.085 .28063 m .08292 .27873 L .08568 .27766 L F
.53133 .29207 m .53272 .28892 L .53434 .29098 L 0 .048 .151 r
F
.53133 .29207 m .52971 .28999 L .53272 .28892 L F
.34632 .28424 m .34741 .28127 L .34922 .28319 L 0 .031 .131 r
F
.34632 .28424 m .34451 .28231 L .34741 .28127 L F
.5237 .29253 m .52507 .28902 L .5267 .29112 L 0 .049 .151 r
F
.5237 .29253 m .52207 .29043 L .52507 .28902 L F
.74199 .28301 m .74369 .27975 L .7451 .28178 L 0 .028 .128 r
F
.74199 .28301 m .74058 .28099 L .74369 .27975 L F
.55122 .2936 m .55263 .28977 L .55423 .2921 L 0 .051 .154 r
F
.55122 .2936 m .54961 .29123 L .55263 .28977 L F
.37383 .28536 m .37498 .28232 L .37675 .28438 L 0 .033 .134 r
F
.37383 .28536 m .37206 .28327 L .37498 .28232 L F
.74962 .28263 m .75135 .27958 L .75275 .28162 L 0 .028 .127 r
F
.74962 .28263 m .74822 .28059 L .75135 .27958 L F
.24848 .282 m .24944 .27892 L .25134 .28091 L 0 .027 .126 r
F
.24848 .282 m .24658 .28001 L .24944 .27892 L F
.13539 .28055 m .13616 .27753 L .13818 .27949 L 0 .024 .122 r
F
.13539 .28055 m .13337 .27859 L .13616 .27753 L F
.6458 .28588 m .64736 .28281 L .64886 .28466 L 0 .035 .136 r
F
.6458 .28588 m .64429 .28403 L .64736 .28281 L F
.80005 .2825 m .80185 .27945 L .8032 .28149 L 0 .028 .127 r
F
.80005 .2825 m .79869 .28047 L .80185 .27945 L F
.48854 .29205 m .48987 .28863 L .49153 .29109 L 0 .048 .151 r
F
.48854 .29205 m .48689 .28957 L .48987 .28863 L F
.35394 .28401 m .35505 .28099 L .35685 .28288 L 0 .031 .131 r
F
.35394 .28401 m .35213 .28211 L .35505 .28099 L F
.65343 .28551 m .65501 .28262 L .65651 .2845 L 0 .034 .135 r
F
.65343 .28551 m .65193 .28364 L .65501 .28262 L F
.31878 .28342 m .31983 .28055 L .32166 .28249 L 0 .03 .13 r
F
.31878 .28342 m .31694 .2815 L .31983 .28055 L F
.17816 .28091 m .17899 .27793 L .18097 .27991 L 0 .025 .123 r
F
.17816 .28091 m .17618 .27892 L .17899 .27793 L F
.42887 .28768 m .4301 .28457 L .43182 .28671 L 0 .039 .14 r
F
.42887 .28768 m .42715 .28551 L .4301 .28457 L F
.09259 .28049 m .09328 .27758 L .09534 .27951 L 0 .024 .123 r
F
.09259 .28049 m .09052 .27858 L .09328 .27758 L F
.51607 .2932 m .51743 .28969 L .51907 .29183 L 0 .051 .154 r
F
.51607 .2932 m .51443 .29107 L .51743 .28969 L F
.21331 .28156 m .2142 .27862 L .21613 .28063 L 0 .026 .125 r
F
.21331 .28156 m .21137 .27956 L .2142 .27862 L F
.46102 .29112 m .4623 .28792 L .46399 .29025 L 0 .047 .149 r
F
.46102 .29112 m .45934 .28881 L .4623 .28792 L F
.40134 .2867 m .40254 .28351 L .40427 .28578 L 0 .036 .138 r
F
.40134 .2867 m .3996 .28446 L .40254 .28351 L F
.44876 .28925 m .45002 .28603 L .45172 .28832 L 0 .042 .144 r
F
.44876 .28925 m .44706 .287 L .45002 .28603 L F
.25609 .28186 m .25706 .27872 L .25895 .28077 L 0 .027 .126 r
F
.25609 .28186 m .2542 .27982 L .25706 .27872 L F
.53578 .46182 m .53709 .43175 L .53874 .4442 L .049 .559 0 r
F
.53578 .46182 m .53412 .44751 L .53709 .43175 L F
.38145 .28528 m .3826 .28239 L .38437 .28426 L 0 .034 .135 r
F
.38145 .28528 m .37967 .2834 L .3826 .28239 L F
.29124 .28256 m .29225 .27956 L .29411 .2816 L 0 .028 .128 r
F
.29124 .28256 m .28938 .28051 L .29225 .27956 L F
.50843 .29379 m .50979 .29033 L .51143 .29243 L 0 .053 .155 r
F
.50843 .29379 m .50679 .29171 L .50979 .29033 L F
.36155 .28387 m .36268 .28078 L .36446 .2829 L 0 .031 .131 r
F
.36155 .28387 m .35977 .28175 L .36268 .28078 L F
.14297 .28052 m .14376 .27752 L .14576 .27952 L 0 .024 .123 r
F
.14297 .28052 m .14097 .27851 L .14376 .27752 L F
.75729 .28266 m .75902 .27951 L .76042 .28155 L 0 .028 .128 r
F
.75729 .28266 m .75589 .28061 L .75902 .27951 L F
.63818 .2867 m .63973 .28351 L .64124 .28537 L 0 .037 .138 r
F
.63818 .2867 m .63667 .28485 L .63973 .28351 L F
.53896 .29222 m .54036 .28885 L .54197 .29116 L 0 .049 .152 r
F
.53896 .29222 m .53735 .28989 L .54036 .28885 L F
.80772 .28251 m .80952 .27938 L .81087 .28141 L 0 .028 .128 r
F
.80772 .28251 m .80637 .28048 L .80952 .27938 L F
.10017 .28041 m .1009 .27734 L .10295 .27931 L 0 .024 .122 r
F
.10017 .28041 m .09812 .27844 L .1009 .27734 L F
.81535 .2821 m .81717 .27903 L .8185 .28093 L 0 .027 .127 r
F
.81535 .2821 m .81402 .28022 L .81717 .27903 L F
.66108 .28549 m .66266 .28236 L .66416 .28439 L 0 .034 .135 r
F
.66108 .28549 m .65958 .28343 L .66266 .28236 L F
.63055 .28721 m .63209 .2842 L .63361 .28603 L 0 .038 .14 r
F
.63055 .28721 m .62903 .28539 L .63209 .2842 L F
.18575 .2809 m .18659 .27794 L .18856 .27992 L 0 .025 .124 r
F
.18575 .2809 m .18378 .27892 L .18659 .27794 L F
.38907 .28514 m .39023 .28222 L .39199 .28414 L 0 .034 .135 r
F
.38907 .28514 m .3873 .28324 L .39023 .28222 L F
.76493 .28239 m .76667 .27918 L .76806 .28119 L 0 .028 .127 r
F
.76493 .28239 m .76354 .28037 L .76667 .27918 L F
.32638 .28346 m .32746 .28025 L .32928 .28234 L 0 .03 .13 r
F
.32638 .28346 m .32456 .28137 L .32746 .28025 L F
.82299 .2818 m .82484 .27885 L .82617 .2808 L 0 .027 .127 r
F
.82299 .2818 m .82167 .27988 L .82484 .27885 L F
.26369 .28182 m .26466 .27884 L .26655 .28084 L 0 .027 .126 r
F
.26369 .28182 m .2618 .27979 L .26466 .27884 L F
.22089 .28164 m .22181 .27853 L .22374 .28053 L F
.22089 .28164 m .21896 .27963 L .22181 .27853 L F
.77258 .2821 m .77434 .27908 L .77572 .28105 L 0 .028 .127 r
F
.77258 .2821 m .7712 .28013 L .77434 .27908 L F
.66872 .28529 m .67032 .28218 L .6718 .28415 L 0 .034 .135 r
F
.66872 .28529 m .66724 .28329 L .67032 .28218 L F
.10777 .28022 m .1085 .27719 L .11055 .27918 L 0 .024 .122 r
F
.10777 .28022 m .10573 .27822 L .1085 .27719 L F
.62292 .28784 m .62445 .28477 L .62598 .2866 L 0 .04 .142 r
F
.62292 .28784 m .6214 .28596 L .62445 .28477 L F
.15057 .28043 m .15137 .27735 L .15337 .27933 L 0 .024 .123 r
F
.15057 .28043 m .14856 .27845 L .15137 .27735 L F
.60003 .28916 m .60152 .28609 L .60307 .2881 L 0 .043 .145 r
F
.60003 .28916 m .59847 .28718 L .60152 .28609 L F
.67636 .28496 m .67797 .28194 L .67944 .28386 L 0 .034 .135 r
F
.67636 .28496 m .67488 .28302 L .67797 .28194 L F
.40895 .28687 m .41017 .28346 L .4119 .28571 L 0 .037 .139 r
F
.40895 .28687 m .40722 .28462 L .41017 .28346 L F
.29884 .28264 m .29986 .27963 L .30171 .28163 L 0 .029 .129 r
F
.29884 .28264 m .29698 .28063 L .29986 .27963 L F
.5924 .28963 m .59387 .28628 L .59543 .28836 L 0 .044 .146 r
F
.5924 .28963 m .59083 .28756 L .59387 .28628 L F
.22851 .28138 m .22943 .27836 L .23135 .28033 L 0 .027 .126 r
F
.22851 .28138 m .22658 .27942 L .22943 .27836 L F
.46864 .29134 m .46994 .28797 L .47162 .2901 L 0 .048 .15 r
F
.46864 .29134 m .46696 .28919 L .46994 .28797 L F
.43648 .28796 m .43773 .28469 L .43944 .28689 L 0 .04 .142 r
F
.43648 .28796 m .43477 .28572 L .43773 .28469 L F
.15818 .28015 m .15898 .27726 L .16098 .27917 L 0 .024 .123 r
F
.15818 .28015 m .15618 .27822 L .15898 .27726 L F
.69926 .28376 m .70091 .2807 L .70236 .28271 L 0 .031 .132 r
F
.69926 .28376 m .69781 .28175 L .70091 .2807 L F
.33399 .28336 m .33508 .28022 L .33689 .28233 L 0 .03 .131 r
F
.33399 .28336 m .33218 .28126 L .33508 .28022 L F
.47627 .29098 m .47758 .28761 L .47925 .28972 L 0 .047 .149 r
F
.47627 .29098 m .4746 .28886 L .47758 .28761 L F
.5695 .291 m .57094 .28757 L .57253 .28983 L F
.5695 .291 m .56791 .28873 L .57094 .28757 L F
.6153 .28846 m .61681 .28509 L .61834 .28716 L 0 .041 .143 r
F
.6153 .28846 m .61376 .28641 L .61681 .28509 L F
.58476 .29015 m .58623 .28677 L .5878 .28883 L 0 .045 .147 r
F
.58476 .29015 m .5832 .28813 L .58623 .28677 L F
.78023 .28192 m .782 .27884 L .78337 .28081 L 0 .028 .127 r
F
.78023 .28192 m .77886 .27997 L .782 .27884 L F
.83066 .28172 m .8325 .27855 L .83382 .28054 L 0 .027 .126 r
F
.83066 .28172 m .82934 .27975 L .8325 .27855 L F
.2713 .28172 m .27228 .27875 L .27416 .28063 L 0 .027 .127 r
F
.2713 .28172 m .26941 .27983 L .27228 .27875 L F
.19333 .28088 m .19418 .27798 L .19615 .27989 L 0 .026 .125 r
F
.19333 .28088 m .19137 .27895 L .19418 .27798 L F
.69163 .28429 m .69326 .28113 L .69472 .28298 L 0 .032 .133 r
F
.69163 .28429 m .69018 .28242 L .69326 .28113 L F
.41658 .28663 m .4178 .2834 L .41953 .28549 L 0 .037 .139 r
F
.41658 .28663 m .41485 .28455 L .4178 .2834 L F
.49617 .29256 m .4975 .28917 L .49916 .29158 L 0 .051 .153 r
F
.49617 .29256 m .49451 .29013 L .4975 .28917 L F
.684 .28474 m .68563 .2818 L .68709 .28368 L 0 .034 .135 r
F
.684 .28474 m .68254 .28283 L .68563 .2818 L F
.8383 .28137 m .84016 .27828 L .84148 .28031 L 0 .027 .126 r
F
.8383 .28137 m .83698 .27936 L .84016 .27828 L F
.56187 .29154 m .56329 .28779 L .56489 .29009 L 0 .048 .15 r
F
.56187 .29154 m .56027 .28919 L .56329 .28779 L F
.11536 .28014 m .1161 .2771 L .11814 .27909 L 0 .024 .123 r
F
.11536 .28014 m .11332 .27815 L .1161 .2771 L F
.36915 .28416 m .37029 .28112 L .37206 .28327 L 0 .032 .133 r
F
.36915 .28416 m .36737 .28201 L .37029 .28112 L F
.27892 .28142 m .2799 .27854 L .28179 .28042 L 0 .027 .126 r
F
.27892 .28142 m .27704 .27954 L .2799 .27854 L F
.30645 .28248 m .30748 .27954 L .30933 .28145 L 0 .029 .129 r
F
.30645 .28248 m .3046 .28058 L .30748 .27954 L F
.4839 .29075 m .48522 .28727 L .48689 .28957 L 0 .046 .149 r
F
.4839 .29075 m .48224 .28845 L .48522 .28727 L F
.23612 .28122 m .23704 .27827 L .23896 .28021 L 0 .027 .126 r
F
.23612 .28122 m .2342 .27931 L .23704 .27827 L F
.60767 .28906 m .60917 .28571 L .61071 .28776 L 0 .043 .145 r
F
.60767 .28906 m .60612 .28704 L .60917 .28571 L F
.45637 .28971 m .45765 .28647 L .45934 .28881 L 0 .044 .147 r
F
.45637 .28971 m .45468 .28739 L .45765 .28647 L F
.57713 .29079 m .57859 .28735 L .58016 .28949 L 0 .047 .149 r
F
.57713 .29079 m .57556 .28866 L .57859 .28735 L F
.78788 .28169 m .78966 .27859 L .79103 .2806 L 0 .027 .127 r
F
.78788 .28169 m .78651 .2797 L .78966 .27859 L F
.5466 .29252 m .54801 .28885 L .54961 .29123 L 0 .05 .153 r
F
.5466 .29252 m .54499 .2901 L .54801 .28885 L F
.55423 .2921 m .55565 .28832 L .55725 .2906 L 0 .049 .152 r
F
.55423 .2921 m .55263 .28977 L .55565 .28832 L F
.39667 .28534 m .39785 .28231 L .3996 .28446 L 0 .035 .136 r
F
.39667 .28534 m .39492 .28322 L .39785 .28231 L F
.20094 .28072 m .20181 .27777 L .20377 .27966 L 0 .026 .125 r
F
.20094 .28072 m .19898 .27886 L .20181 .27777 L F
.16577 .2801 m .16658 .2772 L .16857 .2791 L 0 .025 .123 r
F
.16577 .2801 m .16377 .2782 L .16658 .2772 L F
.4242 .28646 m .42543 .28343 L .42715 .28551 L 0 .038 .139 r
F
.4242 .28646 m .42248 .28436 L .42543 .28343 L F
.5267 .29112 m .52808 .28791 L .52971 .28999 L 0 .048 .151 r
F
.5267 .29112 m .52507 .28902 L .52808 .28791 L F
.70692 .28372 m .70857 .28051 L .71002 .28256 L 0 .031 .132 r
F
.70692 .28372 m .70547 .28166 L .70857 .28051 L F
.12296 .27994 m .12371 .27696 L .12575 .27887 L 0 .024 .123 r
F
.12296 .27994 m .12092 .27802 L .12371 .27696 L F
.3416 .28334 m .3427 .28029 L .34451 .28231 L 0 .031 .131 r
F
.3416 .28334 m .33979 .2813 L .3427 .28029 L F
.4441 .28799 m .44536 .2848 L .44706 .287 L 0 .041 .143 r
F
.4441 .28799 m .4424 .28583 L .44536 .2848 L F
.71456 .28337 m .71622 .28013 L .71765 .28215 L 0 .031 .131 r
F
.71456 .28337 m .71311 .28134 L .71622 .28013 L F
.72982 .28253 m .73152 .27947 L .73294 .28139 L 0 .029 .129 r
F
.72982 .28253 m .7284 .28059 L .73152 .27947 L F
.72219 .28297 m .72387 .27979 L .72529 .28176 L 0 .03 .13 r
F
.72219 .28297 m .72076 .28097 L .72387 .27979 L F
.24373 .28107 m .24467 .27809 L .24658 .28001 L 0 .027 .126 r
F
.24373 .28107 m .24181 .27915 L .24467 .27809 L F
.08015 .27984 m .08084 .27677 L .08292 .27873 L 0 .024 .122 r
F
.08015 .27984 m .07807 .27787 L .08084 .27677 L F
.79554 .28154 m .79733 .27843 L .79869 .28047 L 0 .027 .127 r
F
.79554 .28154 m .79417 .27951 L .79733 .27843 L F
.84597 .28133 m .84785 .27828 L .84916 .28033 L 0 .027 .126 r
F
.84597 .28133 m .84466 .27929 L .84785 .27828 L F
.20855 .2805 m .20942 .27764 L .21137 .27956 L 0 .026 .125 r
F
.20855 .2805 m .2066 .27859 L .20942 .27764 L F
.31406 .2824 m .3151 .27959 L .31694 .2815 L 0 .03 .13 r
F
.31406 .2824 m .31222 .28051 L .3151 .27959 L F
.7451 .28178 m .74681 .27855 L .74822 .28059 L 0 .028 .127 r
F
.7451 .28178 m .74369 .27975 L .74681 .27855 L F
.73747 .28221 m .73917 .27903 L .74058 .28099 L 0 .029 .128 r
F
.73747 .28221 m .73605 .28026 L .73917 .27903 L F
.13058 .27969 m .13134 .27667 L .13337 .27859 L 0 .024 .122 r
F
.13058 .27969 m .12854 .27777 L .13134 .27667 L F
.28652 .28144 m .28752 .27855 L .28938 .28051 L 0 .028 .127 r
F
.28652 .28144 m .28465 .27949 L .28752 .27855 L F
.17337 .27996 m .1742 .27703 L .17618 .27892 L 0 .025 .123 r
F
.17337 .27996 m .17138 .27806 L .1742 .27703 L F
.53434 .29098 m .53573 .28786 L .53735 .28989 L 0 .048 .151 r
F
.53434 .29098 m .53272 .28892 L .53573 .28786 L F
.51907 .29183 m .52044 .28828 L .52207 .29043 L 0 .05 .152 r
F
.51907 .29183 m .51743 .28969 L .52044 .28828 L F
.08776 .27957 m .08844 .27666 L .09052 .27858 L 0 .024 .122 r
F
.08776 .27957 m .08568 .27766 L .08844 .27666 L F
.64886 .28466 m .65044 .28178 L .65193 .28364 L 0 .034 .135 r
F
.64886 .28466 m .64736 .28281 L .65044 .28178 L F
.34922 .28319 m .35032 .28021 L .35213 .28211 L 0 .031 .131 r
F
.34922 .28319 m .34741 .28127 L .35032 .28021 L F
.5038 .29274 m .50514 .28961 L .50679 .29171 L 0 .053 .155 r
F
.5038 .29274 m .50215 .2906 L .50514 .28961 L F
.25134 .28091 m .2523 .27782 L .2542 .27982 L 0 .026 .126 r
F
.25134 .28091 m .24944 .27892 L .2523 .27782 L F
.35685 .28288 m .35797 .27986 L .35977 .28175 L 0 .031 .131 r
F
.35685 .28288 m .35505 .28099 L .35797 .27986 L F
.13818 .27949 m .13895 .27655 L .14097 .27851 L 0 .024 .122 r
F
.13818 .27949 m .13616 .27753 L .13895 .27655 L F
.75275 .28162 m .75449 .27856 L .75589 .28061 L 0 .028 .128 r
F
.75275 .28162 m .75135 .27958 L .75449 .27856 L F
.37675 .28438 m .3779 .28137 L .37967 .2834 L 0 .034 .135 r
F
.37675 .28438 m .37498 .28232 L .3779 .28137 L F
.51143 .29243 m .51279 .28894 L .51443 .29107 L 0 .052 .154 r
F
.51143 .29243 m .50979 .29033 L .51279 .28894 L F
.8032 .28149 m .80501 .27844 L .80637 .28048 L 0 .028 .127 r
F
.8032 .28149 m .80185 .27945 L .80501 .27844 L F
.65651 .2845 m .65809 .28153 L .65958 .28343 L 0 .034 .135 r
F
.65651 .2845 m .65501 .28262 L .65809 .28153 L F
.64124 .28537 m .64279 .28217 L .64429 .28403 L 0 .036 .137 r
F
.64124 .28537 m .63973 .28351 L .64279 .28217 L F
.49153 .29109 m .49286 .2877 L .49451 .29013 L 0 .049 .151 r
F
.49153 .29109 m .48987 .28863 L .49286 .2877 L F
.18097 .27991 m .18181 .27693 L .18378 .27892 L 0 .025 .124 r
F
.18097 .27991 m .17899 .27793 L .18181 .27693 L F
.25895 .28077 m .25991 .27776 L .2618 .27979 L 0 .027 .126 r
F
.25895 .28077 m .25706 .27872 L .25991 .27776 L F
.09534 .27951 m .09605 .27651 L .09812 .27844 L 0 .024 .123 r
F
.09534 .27951 m .09328 .27758 L .09605 .27651 L F
.43182 .28671 m .43306 .28361 L .43477 .28572 L 0 .039 .141 r
F
.43182 .28671 m .4301 .28457 L .43306 .28361 L F
.32166 .28249 m .32273 .27943 L .32456 .28137 L 0 .03 .13 r
F
.32166 .28249 m .31983 .28055 L .32273 .27943 L F
.21613 .28063 m .21703 .27763 L .21896 .27963 L 0 .026 .126 r
F
.21613 .28063 m .2142 .27862 L .21703 .27763 L F
.38437 .28426 m .38553 .28135 L .3873 .28324 L 0 .034 .135 r
F
.38437 .28426 m .3826 .28239 L .38553 .28135 L F
.40427 .28578 m .40548 .28236 L .40722 .28462 L 0 .036 .138 r
F
.40427 .28578 m .40254 .28351 L .40548 .28236 L F
.45172 .28832 m .45299 .28507 L .45468 .28739 L 0 .043 .145 r
F
.45172 .28832 m .45002 .28603 L .45299 .28507 L F
.76042 .28155 m .76215 .27834 L .76354 .28037 L 0 .028 .128 r
F
.76042 .28155 m .75902 .27951 L .76215 .27834 L F
.46399 .29025 m .46528 .28686 L .46696 .28919 L 0 .047 .149 r
F
.46399 .29025 m .4623 .28792 L .46528 .28686 L F
.8185 .28093 m .82034 .27795 L .82167 .27988 L 0 .027 .127 r
F
.8185 .28093 m .81717 .27903 L .82034 .27795 L F
.63361 .28603 m .63516 .28301 L .63667 .28485 L 0 .038 .139 r
F
.63361 .28603 m .63209 .2842 L .63516 .28301 L F
.29411 .2816 m .29513 .27862 L .29698 .28063 L 0 .029 .128 r
F
.29411 .2816 m .29225 .27956 L .29513 .27862 L F
.76806 .28119 m .76981 .27814 L .7712 .28013 L 0 .028 .127 r
F
.76806 .28119 m .76667 .27918 L .76981 .27814 L F
.81087 .28141 m .81268 .2782 L .81402 .28022 L F
.81087 .28141 m .80952 .27938 L .81268 .2782 L F
.36446 .2829 m .36559 .27989 L .36737 .28201 L 0 .031 .132 r
F
.36446 .2829 m .36268 .28078 L .36559 .27989 L F
.54197 .29116 m .54338 .2878 L .54499 .2901 L 0 .049 .152 r
F
.54197 .29116 m .54036 .28885 L .54338 .2878 L F
.66416 .28439 m .66575 .28128 L .66724 .28329 L 0 .034 .135 r
F
.66416 .28439 m .66266 .28236 L .66575 .28128 L F
.14576 .27952 m .14656 .27647 L .14856 .27845 L 0 .024 .123 r
F
.14576 .27952 m .14376 .27752 L .14656 .27647 L F
.10295 .27931 m .10368 .27625 L .10573 .27822 L 0 .024 .122 r
F
.10295 .27931 m .1009 .27734 L .10368 .27625 L F
.32928 .28234 m .33037 .27917 L .33218 .28126 L 0 .03 .13 r
F
.32928 .28234 m .32746 .28025 L .33037 .27917 L F
.62598 .2866 m .62751 .28357 L .62903 .28539 L 0 .039 .141 r
F
.62598 .2866 m .62445 .28477 L .62751 .28357 L F
.59543 .28836 m .59691 .28507 L .59847 .28718 L 0 .043 .145 r
F
.59543 .28836 m .59387 .28628 L .59691 .28507 L F
.22374 .28053 m .22466 .27742 L .22658 .27942 L 0 .026 .126 r
F
.22374 .28053 m .22181 .27853 L .22466 .27742 L F
.39199 .28414 m .39316 .28127 L .39492 .28322 L 0 .034 .135 r
F
.39199 .28414 m .39023 .28222 L .39316 .28127 L F
.6718 .28415 m .67341 .28108 L .67488 .28302 L F
.6718 .28415 m .67032 .28218 L .67341 .28108 L F
.18856 .27992 m .1894 .27698 L .19137 .27895 L 0 .026 .124 r
F
.18856 .27992 m .18659 .27794 L .1894 .27698 L F
.56489 .29009 m .56632 .28646 L .56791 .28873 L 0 .046 .149 r
F
.56489 .29009 m .56329 .28779 L .56632 .28646 L F
.47162 .2901 m .47292 .28674 L .4746 .28886 L 0 .047 .149 r
F
.47162 .2901 m .46994 .28797 L .47292 .28674 L F
.5878 .28883 m .58927 .28548 L .59083 .28756 L 0 .044 .146 r
F
.5878 .28883 m .58623 .28677 L .58927 .28548 L F
.82617 .2808 m .82802 .27778 L .82934 .27975 L 0 .027 .127 r
F
.82617 .2808 m .82484 .27885 L .82802 .27778 L F
.61834 .28716 m .61986 .2839 L .6214 .28596 L 0 .04 .142 r
F
.61834 .28716 m .61681 .28509 L .61986 .2839 L F
.15337 .27933 m .15418 .27626 L .15618 .27822 L 0 .024 .123 r
F
.15337 .27933 m .15137 .27735 L .15418 .27626 L F
.47925 .28972 m .48057 .28636 L .48224 .28845 L 0 .046 .149 r
F
.47925 .28972 m .47758 .28761 L .48057 .28636 L F
.4119 .28571 m .41312 .28231 L .41485 .28455 L 0 .037 .138 r
F
.4119 .28571 m .41017 .28346 L .41312 .28231 L F
.77572 .28105 m .77748 .27801 L .77886 .27997 L 0 .028 .127 r
F
.77572 .28105 m .77434 .27908 L .77748 .27801 L F
.26655 .28084 m .26752 .27785 L .26941 .27983 L 0 .027 .127 r
F
.26655 .28084 m .26466 .27884 L .26752 .27785 L F
.55725 .2906 m .55867 .28698 L .56027 .28919 L 0 .048 .15 r
F
.55725 .2906 m .55565 .28832 L .55867 .28698 L F
.69472 .28298 m .69636 .27991 L .69781 .28175 L 0 .032 .132 r
F
.69472 .28298 m .69326 .28113 L .69636 .27991 L F
.50973 .46159 m .50817 .44079 L .51115 .44391 L .102 .579 0 r
F
.50675 .45767 m .50817 .44079 L .50973 .46159 L .057 .562 0 r
F
.11055 .27918 m .11128 .27616 L .11332 .27815 L 0 .024 .123 r
F
.11055 .27918 m .1085 .27719 L .11128 .27616 L F
.67944 .28386 m .68107 .28093 L .68254 .28283 L 0 .034 .135 r
F
.67944 .28386 m .67797 .28194 L .68107 .28093 L F
.60307 .2881 m .60457 .28499 L .60612 .28704 L 0 .043 .145 r
F
.60307 .2881 m .60152 .28609 L .60457 .28499 L F
.57253 .28983 m .57397 .2864 L .57556 .28866 L 0 .046 .149 r
F
.57253 .28983 m .57094 .28757 L .57397 .2864 L F
.43944 .28689 m .44069 .28366 L .4424 .28583 L 0 .04 .142 r
F
.43944 .28689 m .43773 .28469 L .44069 .28366 L F
.83382 .28054 m .83566 .27736 L .83698 .27936 L 0 .027 .126 r
F
.83382 .28054 m .8325 .27855 L .83566 .27736 L F
.23135 .28033 m .23227 .27733 L .2342 .27931 L F
.23135 .28033 m .22943 .27836 L .23227 .27733 L F
.61071 .28776 m .61221 .28433 L .61376 .28641 L 0 .042 .144 r
F
.61071 .28776 m .60917 .28571 L .61221 .28433 L F
.30171 .28163 m .30275 .27859 L .3046 .28058 L 0 .029 .129 r
F
.30171 .28163 m .29986 .27963 L .30275 .27859 L F
.58016 .28949 m .58162 .28598 L .5832 .28813 L 0 .046 .148 r
F
.58016 .28949 m .57859 .28735 L .58162 .28598 L F
.70236 .28271 m .70402 .27965 L .70547 .28166 L 0 .031 .132 r
F
.70236 .28271 m .70091 .2807 L .70402 .27965 L F
.78337 .28081 m .78514 .2777 L .78651 .2797 L 0 .027 .127 r
F
.78337 .28081 m .782 .27884 L .78514 .2777 L F
.41953 .28549 m .42075 .28225 L .42248 .28436 L 0 .037 .138 r
F
.41953 .28549 m .4178 .2834 L .42075 .28225 L F
.27416 .28063 m .27515 .27766 L .27704 .27954 L 0 .027 .127 r
F
.27416 .28063 m .27228 .27875 L .27515 .27766 L F
.54961 .29123 m .55103 .28744 L .55263 .28977 L 0 .049 .152 r
F
.54961 .29123 m .54801 .28885 L .55103 .28744 L F
.33689 .28233 m .33799 .27918 L .33979 .2813 L 0 .03 .131 r
F
.33689 .28233 m .33508 .28022 L .33799 .27918 L F
.16098 .27917 m .16177 .27628 L .16377 .2782 L 0 .025 .123 r
F
.16098 .27917 m .15898 .27726 L .16177 .27628 L F
.48689 .28957 m .48821 .28634 L .48987 .28863 L 0 .046 .149 r
F
.48689 .28957 m .48522 .28727 L .48821 .28634 L F
.50424 .48589 m .50266 .47238 L .50556 .48751 L .38 .669 0 r
F
.50266 .47238 m .504 .47151 L .50556 .48751 L .216 .619 0 r
F
.68709 .28368 m .68872 .28055 L .69018 .28242 L 0 .033 .134 r
F
.68709 .28368 m .68563 .2818 L .68872 .28055 L F
.84148 .28031 m .84335 .27726 L .84466 .27929 L 0 .027 .126 r
F
.84148 .28031 m .84016 .27828 L .84335 .27726 L F
.19615 .27989 m .19701 .27694 L .19898 .27886 L 0 .026 .125 r
F
.19615 .27989 m .19418 .27798 L .19701 .27694 L F
.49916 .29158 m .5005 .28821 L .50215 .2906 L 0 .051 .154 r
F
.49916 .29158 m .4975 .28917 L .5005 .28821 L F
.11814 .27909 m .11889 .27605 L .12092 .27802 L 0 .024 .123 r
F
.11814 .27909 m .1161 .2771 L .11889 .27605 L F
.53835 .49901 m .5368 .51572 L .5398 .50837 L .511 .706 0 r
F
.53535 .50562 m .5368 .51572 L .53835 .49901 L .601 .729 0 r
F
.79103 .2806 m .79281 .27749 L .79417 .27951 L 0 .027 .127 r
F
.79103 .2806 m .78966 .27859 L .79281 .27749 L F
.30933 .28145 m .31037 .27858 L .31222 .28051 L 0 .029 .129 r
F
.30933 .28145 m .30748 .27954 L .31037 .27858 L F
.23896 .28021 m .23989 .27722 L .24181 .27915 L 0 .027 .126 r
F
.23896 .28021 m .23704 .27827 L .23989 .27722 L F
.28179 .28042 m .28277 .27759 L .28465 .27949 L 0 .027 .127 r
F
.28179 .28042 m .2799 .27854 L .28277 .27759 L F
.71002 .28256 m .71167 .27931 L .71311 .28134 L 0 .031 .131 r
F
.71002 .28256 m .70857 .28051 L .71167 .27931 L F
.71765 .28215 m .71933 .27898 L .72076 .28097 L 0 .03 .13 r
F
.71765 .28215 m .71622 .28013 L .71933 .27898 L F
.0753 .27897 m .07599 .27589 L .07807 .27787 L 0 .024 .123 r
F
.0753 .27897 m .07322 .27698 L .07599 .27589 L F
.52971 .28999 m .53109 .28687 L .53272 .28892 L 0 .048 .15 r
F
.52971 .28999 m .52808 .28791 L .53109 .28687 L F
.52207 .29043 m .52344 .28687 L .52507 .28902 L 0 .048 .151 r
F
.52207 .29043 m .52044 .28828 L .52344 .28687 L F
.72529 .28176 m .72698 .27864 L .7284 .28059 L 0 .03 .13 r
F
.72529 .28176 m .72387 .27979 L .72698 .27864 L F
.20377 .27966 m .20464 .27669 L .2066 .27859 L 0 .026 .125 r
F
.20377 .27966 m .20181 .27777 L .20464 .27669 L F
.37206 .28327 m .3732 .2802 L .37498 .28232 L 0 .033 .134 r
F
.37206 .28327 m .37029 .28112 L .3732 .2802 L F
.73294 .28139 m .73464 .27835 L .73605 .28026 L 0 .029 .129 r
F
.73294 .28139 m .73152 .27947 L .73464 .27835 L F
.45934 .28881 m .46062 .28555 L .4623 .28792 L 0 .045 .147 r
F
.45934 .28881 m .45765 .28647 L .46062 .28555 L F
.12575 .27887 m .12651 .27585 L .12854 .27777 L 0 .024 .123 r
F
.12575 .27887 m .12371 .27696 L .12651 .27585 L F
.74058 .28099 m .74228 .27779 L .74369 .27975 L 0 .028 .128 r
F
.74058 .28099 m .73917 .27903 L .74228 .27779 L F
.16857 .2791 m .16939 .27617 L .17138 .27806 L 0 .025 .123 r
F
.16857 .2791 m .16658 .2772 L .16939 .27617 L F
.74822 .28059 m .74994 .27753 L .75135 .27958 L 0 .028 .127 r
F
.74822 .28059 m .74681 .27855 L .74994 .27753 L F
.34451 .28231 m .34561 .27928 L .34741 .28127 L 0 .031 .131 r
F
.34451 .28231 m .3427 .28029 L .34561 .27928 L F
.08292 .27873 m .08361 .27571 L .08568 .27766 L 0 .024 .122 r
F
.08292 .27873 m .08084 .27677 L .08361 .27571 L F
.44706 .287 m .44832 .28379 L .45002 .28603 L 0 .041 .143 r
F
.44706 .287 m .44536 .2848 L .44832 .28379 L F
.42715 .28551 m .42838 .28251 L .4301 .28457 L 0 .038 .14 r
F
.42715 .28551 m .42543 .28343 L .42838 .28251 L F
.24658 .28001 m .24753 .277 L .24944 .27892 L 0 .027 .126 r
F
.24658 .28001 m .24467 .27809 L .24753 .277 L F
.3996 .28446 m .40079 .28135 L .40254 .28351 L 0 .035 .137 r
F
.3996 .28446 m .39785 .28231 L .40079 .28135 L F
.79869 .28047 m .80049 .27741 L .80185 .27945 L 0 .027 .127 r
F
.79869 .28047 m .79733 .27843 L .80049 .27741 L F
.51443 .29107 m .5158 .28754 L .51743 .28969 L 0 .05 .153 r
F
.51443 .29107 m .51279 .28894 L .5158 .28754 L F
.13337 .27859 m .13414 .2756 L .13616 .27753 L 0 .024 .122 r
F
.13337 .27859 m .13134 .27667 L .13414 .2756 L F
.53735 .28989 m .53875 .2868 L .54036 .28885 L 0 .048 .151 r
F
.53735 .28989 m .53573 .28786 L .53875 .2868 L F
.52646 .46029 m .52783 .43017 L .52947 .44673 L .05 .559 0 r
F
.52646 .46029 m .52482 .44185 L .52783 .43017 L F
.21137 .27956 m .21225 .27669 L .2142 .27862 L 0 .026 .125 r
F
.21137 .27956 m .20942 .27764 L .21225 .27669 L F
.17618 .27892 m .17701 .27601 L .17899 .27793 L 0 .025 .123 r
F
.17618 .27892 m .1742 .27703 L .17701 .27601 L F
.35213 .28211 m .35324 .2791 L .35505 .28099 L 0 .031 .131 r
F
.35213 .28211 m .35032 .28021 L .35324 .2791 L F
.64429 .28403 m .64586 .28094 L .64736 .28281 L 0 .035 .136 r
F
.64429 .28403 m .64279 .28217 L .64586 .28094 L F
.31694 .2815 m .31799 .27863 L .31983 .28055 L 0 .03 .13 r
F
.31694 .2815 m .3151 .27959 L .31799 .27863 L F
.2542 .27982 m .25516 .27671 L .25706 .27872 L 0 .026 .125 r
F
.2542 .27982 m .2523 .27782 L .25516 .27671 L F
.65193 .28364 m .65352 .28074 L .65501 .28262 L 0 .034 .136 r
F
.65193 .28364 m .65044 .28178 L .65352 .28074 L F
.35977 .28175 m .36088 .27889 L .36268 .28078 L 0 .031 .131 r
F
.35977 .28175 m .35797 .27986 L .36088 .27889 L F
.09052 .27858 m .09121 .27565 L .09328 .27758 L 0 .024 .123 r
F
.09052 .27858 m .08844 .27666 L .09121 .27565 L F
.50679 .29171 m .50815 .2882 L .50979 .29033 L 0 .052 .155 r
F
.50679 .29171 m .50514 .28961 L .50815 .2882 L F
.28938 .28051 m .29039 .27761 L .29225 .27956 L 0 .028 .128 r
F
.28938 .28051 m .28752 .27855 L .29039 .27761 L F
.5108 .49857 m .51206 .52076 L .51374 .51607 L .6 .728 0 r
F
.5108 .49857 m .50913 .50249 L .51206 .52076 L F
.75589 .28061 m .75762 .27747 L .75902 .27951 L 0 .028 .128 r
F
.75589 .28061 m .75449 .27856 L .75762 .27747 L F
.14097 .27851 m .14174 .27556 L .14376 .27752 L 0 .024 .123 r
F
.14097 .27851 m .13895 .27655 L .14174 .27556 L F
.37967 .2834 m .38083 .28036 L .3826 .28239 L 0 .034 .135 r
F
.37967 .2834 m .3779 .28137 L .38083 .28036 L F
.65958 .28343 m .66117 .28041 L .66266 .28236 L F
.65958 .28343 m .65809 .28153 L .66117 .28041 L F
.80637 .28048 m .80817 .27735 L .80952 .27938 L 0 .028 .127 r
F
.80637 .28048 m .80501 .27844 L .80817 .27735 L F
.32456 .28137 m .32563 .27831 L .32746 .28025 L 0 .03 .13 r
F
.32456 .28137 m .32273 .27943 L .32563 .27831 L F
.09812 .27844 m .09883 .27541 L .1009 .27734 L 0 .024 .123 r
F
.09812 .27844 m .09605 .27651 L .09883 .27541 L F
.76354 .28037 m .76528 .27717 L .76667 .27918 L 0 .028 .127 r
F
.76354 .28037 m .76215 .27834 L .76528 .27717 L F
.40722 .28462 m .40843 .28122 L .41017 .28346 L 0 .036 .137 r
F
.40722 .28462 m .40548 .28236 L .40843 .28122 L F
.49451 .29013 m .49585 .28675 L .4975 .28917 L 0 .049 .152 r
F
.49451 .29013 m .49286 .2877 L .49585 .28675 L F
.18378 .27892 m .18462 .27595 L .18659 .27794 L 0 .025 .124 r
F
.18378 .27892 m .18181 .27693 L .18462 .27595 L F
.63667 .28485 m .63822 .28166 L .63973 .28351 L 0 .037 .139 r
F
.63667 .28485 m .63516 .28301 L .63822 .28166 L F
.43477 .28572 m .43601 .28261 L .43773 .28469 L 0 .039 .141 r
F
.43477 .28572 m .43306 .28361 L .43601 .28261 L F
.2618 .27979 m .26277 .27683 L .26466 .27884 L 0 .027 .126 r
F
.2618 .27979 m .25991 .27776 L .26277 .27683 L F
.81402 .28022 m .81583 .27702 L .81717 .27903 L 0 .027 .127 r
F
.81402 .28022 m .81268 .2782 L .81583 .27702 L F
.56791 .28873 m .56935 .2853 L .57094 .28757 L 0 .046 .148 r
F
.56791 .28873 m .56632 .28646 L .56935 .2853 L F
.21896 .27963 m .21988 .27653 L .22181 .27853 L 0 .027 .126 r
F
.21896 .27963 m .21703 .27763 L .21988 .27653 L F
.3873 .28324 m .38846 .2803 L .39023 .28222 L 0 .034 .135 r
F
.3873 .28324 m .38553 .28135 L .38846 .2803 L F
.56027 .28919 m .5617 .28564 L .56329 .28779 L 0 .046 .149 r
F
.56027 .28919 m .55867 .28698 L .5617 .28564 L F
.46696 .28919 m .46826 .28565 L .46994 .28797 L 0 .047 .149 r
F
.46696 .28919 m .46528 .28686 L .46826 .28565 L F
.82167 .27988 m .82352 .2769 L .82484 .27885 L 0 .027 .127 r
F
.82167 .27988 m .82034 .27795 L .82352 .2769 L F
.62903 .28539 m .63058 .28237 L .63209 .2842 L 0 .039 .14 r
F
.62903 .28539 m .62751 .28357 L .63058 .28237 L F
.66724 .28329 m .66883 .28021 L .67032 .28218 L 0 .034 .135 r
F
.66724 .28329 m .66575 .28128 L .66883 .28021 L F
.10573 .27822 m .10645 .27521 L .1085 .27719 L 0 .024 .122 r
F
.10573 .27822 m .10368 .27625 L .10645 .27521 L F
.7712 .28013 m .77296 .2771 L .77434 .27908 L 0 .028 .127 r
F
.7712 .28013 m .76981 .27814 L .77296 .2771 L F
.53113 .46287 m .53246 .43314 L .53412 .44751 L .07 .567 0 r
F
.53113 .46287 m .52947 .44673 L .53246 .43314 L F
.59083 .28756 m .59231 .28419 L .59387 .28628 L 0 .043 .145 r
F
.59083 .28756 m .58927 .28548 L .59231 .28419 L F
.54499 .2901 m .5464 .28657 L .54801 .28885 L 0 .049 .151 r
F
.54499 .2901 m .54338 .2878 L .5464 .28657 L F
.14856 .27845 m .14936 .27538 L .15137 .27735 L 0 .024 .123 r
F
.14856 .27845 m .14656 .27647 L .14936 .27538 L F
.4746 .28886 m .4759 .2855 L .47758 .28761 L 0 .046 .149 r
F
.4746 .28886 m .47292 .28674 L .4759 .2855 L F
.48224 .28845 m .48355 .28519 L .48522 .28727 L 0 .045 .148 r
F
.48224 .28845 m .48057 .28636 L .48355 .28519 L F
.45468 .28739 m .45596 .28412 L .45765 .28647 L 0 .043 .145 r
F
.45468 .28739 m .45299 .28507 L .45596 .28412 L F
.59847 .28718 m .59996 .28396 L .60152 .28609 L F
.59847 .28718 m .59691 .28507 L .59996 .28396 L F
.33218 .28126 m .33327 .27811 L .33508 .28022 L 0 .03 .13 r
F
.33218 .28126 m .33037 .27917 L .33327 .27811 L F
.29698 .28063 m .29801 .27763 L .29986 .27963 L 0 .029 .129 r
F
.29698 .28063 m .29513 .27862 L .29801 .27763 L F
.55263 .28977 m .55405 .28604 L .55565 .28832 L 0 .048 .15 r
F
.55263 .28977 m .55103 .28744 L .55405 .28604 L F
.6214 .28596 m .62292 .2827 L .62445 .28477 L 0 .04 .142 r
F
.6214 .28596 m .61986 .2839 L .62292 .2827 L F
.67488 .28302 m .6765 .28003 L .67797 .28194 L 0 .034 .135 r
F
.67488 .28302 m .67341 .28108 L .6765 .28003 L F
.22658 .27942 m .2275 .27637 L .22943 .27836 L 0 .026 .126 r
F
.22658 .27942 m .22466 .27742 L .2275 .27637 L F
.61376 .28641 m .61526 .28299 L .61681 .28509 L 0 .041 .143 r
F
.61376 .28641 m .61221 .28433 L .61526 .28299 L F
.69781 .28175 m .69946 .27885 L .70091 .2807 L 0 .031 .132 r
F
.69781 .28175 m .69636 .27991 L .69946 .27885 L F
.5832 .28813 m .58466 .28462 L .58623 .28677 L 0 .044 .147 r
F
.5832 .28813 m .58162 .28598 L .58466 .28462 L F
.41485 .28455 m .41607 .28115 L .4178 .2834 L 0 .036 .138 r
F
.41485 .28455 m .41312 .28231 L .41607 .28115 L F
.36737 .28201 m .36851 .279 L .37029 .28112 L 0 .032 .132 r
F
.36737 .28201 m .36559 .27989 L .36851 .279 L F
.15618 .27822 m .15697 .2753 L .15898 .27726 L 0 .024 .123 r
F
.15618 .27822 m .15418 .27626 L .15697 .2753 L F
.82934 .27975 m .83118 .27657 L .8325 .27855 L 0 .027 .126 r
F
.82934 .27975 m .82802 .27778 L .83118 .27657 L F
.77886 .27997 m .78063 .27689 L .782 .27884 L 0 .028 .127 r
F
.77886 .27997 m .77748 .27801 L .78063 .27689 L F
.57556 .28866 m .57701 .2851 L .57859 .28735 L 0 .046 .148 r
F
.57556 .28866 m .57397 .2864 L .57701 .2851 L F
.83698 .27936 m .83884 .27626 L .84016 .27828 L 0 .026 .126 r
F
.83698 .27936 m .83566 .27736 L .83884 .27626 L F
.19137 .27895 m .19222 .27602 L .19418 .27798 L 0 .026 .125 r
F
.19137 .27895 m .1894 .27698 L .19222 .27602 L F
.39492 .28322 m .3961 .28034 L .39785 .28231 L 0 .035 .136 r
F
.39492 .28322 m .39316 .28127 L .3961 .28034 L F
.26941 .27983 m .27039 .27679 L .27228 .27875 L 0 .027 .127 r
F
.26941 .27983 m .26752 .27785 L .27039 .27679 L F
.60612 .28704 m .60762 .28364 L .60917 .28571 L 0 .042 .144 r
F
.60612 .28704 m .60457 .28499 L .60762 .28364 L F
.11332 .27815 m .11406 .27512 L .1161 .2771 L 0 .024 .123 r
F
.11332 .27815 m .11128 .27616 L .11406 .27512 L F
.68254 .28283 m .68417 .27992 L .68563 .2818 L 0 .034 .135 r
F
.68254 .28283 m .68107 .28093 L .68417 .27992 L F
.69018 .28242 m .69181 .27927 L .69326 .28113 L 0 .033 .133 r
F
.69018 .28242 m .68872 .28055 L .69181 .27927 L F
.4424 .28583 m .44365 .28261 L .44536 .2848 L 0 .04 .142 r
F
.4424 .28583 m .44069 .28366 L .44365 .28261 L F
.42248 .28436 m .4237 .28135 L .42543 .28343 L 0 .037 .139 r
F
.42248 .28436 m .42075 .28225 L .4237 .28135 L F
.52507 .28902 m .52646 .28575 L .52808 .28791 L 0 .047 .15 r
F
.52507 .28902 m .52344 .28687 L .52646 .28575 L F
.78651 .2797 m .78829 .27658 L .78966 .27859 L 0 .027 .127 r
F
.78651 .2797 m .78514 .2777 L .78829 .27658 L F
.2342 .27931 m .23512 .2763 L .23704 .27827 L 0 .027 .126 r
F
.2342 .27931 m .23227 .27733 L .23512 .2763 L F
.3046 .28058 m .30564 .27754 L .30748 .27954 L 0 .029 .129 r
F
.3046 .28058 m .30275 .27859 L .30564 .27754 L F
.70547 .28166 m .70712 .27851 L .70857 .28051 L 0 .031 .132 r
F
.70547 .28166 m .70402 .27965 L .70712 .27851 L F
.27704 .27954 m .27802 .27665 L .2799 .27854 L 0 .027 .127 r
F
.27704 .27954 m .27515 .27766 L .27802 .27665 L F
.33979 .2813 m .34089 .2782 L .3427 .28029 L 0 .031 .131 r
F
.33979 .2813 m .33799 .27918 L .34089 .2782 L F
.71311 .28134 m .71477 .27811 L .71622 .28013 L 0 .03 .131 r
F
.71311 .28134 m .71167 .27931 L .71477 .27811 L F
.16377 .2782 m .16458 .27529 L .16658 .2772 L 0 .025 .123 r
F
.16377 .2782 m .16177 .27628 L .16458 .27529 L F
.72076 .28097 m .72244 .27783 L .72387 .27979 L 0 .03 .13 r
F
.72076 .28097 m .71933 .27898 L .72244 .27783 L F
.19898 .27886 m .19985 .27585 L .20181 .27777 L 0 .026 .125 r
F
.19898 .27886 m .19701 .27694 L .19985 .27585 L F
.84466 .27929 m .84654 .27623 L .84785 .27828 L 0 .027 .126 r
F
.84466 .27929 m .84335 .27726 L .84654 .27623 L F
.12092 .27802 m .12168 .275 L .12371 .27696 L 0 .024 .123 r
F
.12092 .27802 m .11889 .27605 L .12168 .275 L F
.79417 .27951 m .79597 .27639 L .79733 .27843 L 0 .027 .126 r
F
.79417 .27951 m .79281 .27749 L .79597 .27639 L F
.51743 .28969 m .5188 .28611 L .52044 .28828 L 0 .049 .151 r
F
.51743 .28969 m .5158 .28754 L .5188 .28611 L F
.48987 .28863 m .4912 .28542 L .49286 .2877 L 0 .047 .149 r
F
.48987 .28863 m .48821 .28634 L .4912 .28542 L F
.7284 .28059 m .7301 .27754 L .73152 .27947 L 0 .029 .129 r
F
.7284 .28059 m .72698 .27864 L .7301 .27754 L F
.74369 .27975 m .7454 .27659 L .74681 .27855 L 0 .028 .127 r
F
.74369 .27975 m .74228 .27779 L .7454 .27659 L F
.07807 .27787 m .07876 .2748 L .08084 .27677 L 0 .024 .122 r
F
.07807 .27787 m .07599 .27589 L .07876 .2748 L F
.24181 .27915 m .24275 .27616 L .24467 .27809 L 0 .027 .126 r
F
.24181 .27915 m .23989 .27722 L .24275 .27616 L F
.50215 .2906 m .5035 .28723 L .50514 .28961 L 0 .052 .154 r
F
.50215 .2906 m .5005 .28821 L .5035 .28723 L F
.53272 .28892 m .53411 .28582 L .53573 .28786 L 0 .048 .15 r
F
.53272 .28892 m .53109 .28687 L .53411 .28582 L F
.73605 .28026 m .73776 .27714 L .73917 .27903 L 0 .029 .128 r
F
.73605 .28026 m .73464 .27835 L .73776 .27714 L F
.2066 .27859 m .20747 .27571 L .20942 .27764 L 0 .026 .125 r
F
.2066 .27859 m .20464 .27669 L .20747 .27571 L F
.31222 .28051 m .31325 .27764 L .3151 .27959 L 0 .03 .13 r
F
.31222 .28051 m .31037 .27858 L .31325 .27764 L F
.12854 .27777 m .12931 .27474 L .13134 .27667 L 0 .024 .122 r
F
.12854 .27777 m .12651 .27585 L .12931 .27474 L F
.28465 .27949 m .28564 .27663 L .28752 .27855 L 0 .028 .127 r
F
.28465 .27949 m .28277 .27759 L .28564 .27663 L F
.50979 .29033 m .51115 .28679 L .51279 .28894 L 0 .051 .153 r
F
.50979 .29033 m .50815 .2882 L .51115 .28679 L F
.53234 .50655 m .53378 .52309 L .53535 .50562 L .648 .74 0 r
F
.53234 .50655 m .53075 .52401 L .53378 .52309 L F
.17138 .27806 m .1722 .27513 L .1742 .27703 L 0 .025 .124 r
F
.17138 .27806 m .16939 .27617 L .1722 .27513 L F
.24944 .27892 m .25039 .27589 L .2523 .27782 L 0 .026 .126 r
F
.24944 .27892 m .24753 .277 L .25039 .27589 L F
.37498 .28232 m .37613 .27928 L .3779 .28137 L 0 .033 .134 r
F
.37498 .28232 m .3732 .2802 L .37613 .27928 L F
.08568 .27766 m .08637 .2747 L .08844 .27666 L 0 .024 .123 r
F
.08568 .27766 m .08361 .27571 L .08637 .2747 L F
.34741 .28127 m .34852 .27825 L .35032 .28021 L 0 .031 .132 r
F
.34741 .28127 m .34561 .27928 L .34852 .27825 L F
.75135 .27958 m .75308 .27651 L .75449 .27856 L 0 .028 .127 r
F
.75135 .27958 m .74994 .27753 L .75308 .27651 L F
.64736 .28281 m .64894 .27989 L .65044 .28178 L 0 .035 .136 r
F
.64736 .28281 m .64586 .28094 L .64894 .27989 L F
.4623 .28792 m .46359 .2845 L .46528 .28686 L 0 .045 .148 r
F
.4623 .28792 m .46062 .28555 L .46359 .2845 L F
.13616 .27753 m .13693 .27461 L .13895 .27655 L 0 .024 .122 r
F
.13616 .27753 m .13414 .2756 L .13693 .27461 L F
.80185 .27945 m .80366 .27639 L .80501 .27844 L 0 .028 .127 r
F
.80185 .27945 m .80049 .27741 L .80366 .27639 L F
.45002 .28603 m .45129 .28278 L .45299 .28507 L 0 .041 .143 r
F
.45002 .28603 m .44832 .28379 L .45129 .28278 L F
.4301 .28457 m .43133 .28158 L .43306 .28361 L 0 .038 .14 r
F
.4301 .28457 m .42838 .28251 L .43133 .28158 L F
.40254 .28351 m .40374 .28022 L .40548 .28236 L 0 .036 .137 r
F
.40254 .28351 m .40079 .28135 L .40374 .28022 L F
.35505 .28099 m .35616 .27798 L .35797 .27986 L 0 .031 .131 r
F
.35505 .28099 m .35324 .2791 L .35616 .27798 L F
.54036 .28885 m .54177 .28575 L .54338 .2878 L 0 .048 .151 r
F
.54036 .28885 m .53875 .2868 L .54177 .28575 L F
.25706 .27872 m .25802 .27576 L .25991 .27776 L 0 .026 .126 r
F
.25706 .27872 m .25516 .27671 L .25802 .27576 L F
.17899 .27793 m .17982 .275 L .18181 .27693 L 0 .025 .124 r
F
.17899 .27793 m .17701 .27601 L .17982 .275 L F
.65501 .28262 m .6566 .27962 L .65809 .28153 L 0 .034 .135 r
F
.65501 .28262 m .65352 .28074 L .6566 .27962 L F
.2142 .27862 m .21509 .27568 L .21703 .27763 L 0 .026 .126 r
F
.2142 .27862 m .21225 .27669 L .21509 .27568 L F
.63973 .28351 m .64128 .2803 L .64279 .28217 L 0 .036 .137 r
F
.63973 .28351 m .63822 .28166 L .64128 .2803 L F
.09328 .27758 m .09398 .27458 L .09605 .27651 L 0 .024 .123 r
F
.09328 .27758 m .09121 .27565 L .09398 .27458 L F
.31983 .28055 m .32089 .27751 L .32273 .27943 L 0 .03 .13 r
F
.31983 .28055 m .31799 .27863 L .32089 .27751 L F
.36268 .28078 m .3638 .27798 L .36559 .27989 L 0 .031 .131 r
F
.36268 .28078 m .36088 .27889 L .3638 .27798 L F
.75902 .27951 m .76075 .27631 L .76215 .27834 L 0 .028 .127 r
F
.75902 .27951 m .75762 .27747 L .76075 .27631 L F
.56329 .28779 m .56473 .28436 L .56632 .28646 L 0 .045 .148 r
F
.56329 .28779 m .5617 .28564 L .56473 .28436 L F
.29225 .27956 m .29326 .27667 L .29513 .27862 L 0 .028 .128 r
F
.29225 .27956 m .29039 .27761 L .29326 .27667 L F
.80952 .27938 m .81133 .27618 L .81268 .2782 L 0 .028 .127 r
F
.80952 .27938 m .80817 .27735 L .81133 .27618 L F
.66266 .28236 m .66426 .2793 L .66575 .28128 L 0 .034 .135 r
F
.66266 .28236 m .66117 .28041 L .66426 .2793 L F
.76667 .27918 m .76843 .27614 L .76981 .27814 L 0 .027 .127 r
F
.76667 .27918 m .76528 .27717 L .76843 .27614 L F
.32746 .28025 m .32854 .27721 L .33037 .27917 L 0 .03 .13 r
F
.32746 .28025 m .32563 .27831 L .32854 .27721 L F
.55565 .28832 m .55707 .28477 L .55867 .28698 L 0 .047 .149 r
F
.55565 .28832 m .55405 .28604 L .55707 .28477 L F
.3826 .28239 m .38376 .2793 L .38553 .28135 L 0 .034 .135 r
F
.3826 .28239 m .38083 .28036 L .38376 .2793 L F
.14376 .27752 m .14454 .27451 L .14656 .27647 L 0 .024 .123 r
F
.14376 .27752 m .14174 .27556 L .14454 .27451 L F
.41017 .28346 m .41138 .28006 L .41312 .28231 L 0 .036 .137 r
F
.41017 .28346 m .40843 .28122 L .41138 .28006 L F
.81717 .27903 m .81901 .27596 L .82034 .27795 L 0 .027 .127 r
F
.81717 .27903 m .81583 .27702 L .81901 .27596 L F
.1009 .27734 m .10162 .27431 L .10368 .27625 L 0 .024 .122 r
F
.1009 .27734 m .09883 .27541 L .10162 .27431 L F
.46994 .28797 m .47124 .28444 L .47292 .28674 L 0 .046 .148 r
F
.46994 .28797 m .46826 .28565 L .47124 .28444 L F
.59387 .28628 m .59535 .28296 L .59691 .28507 L 0 .042 .145 r
F
.59387 .28628 m .59231 .28419 L .59535 .28296 L F
.57094 .28757 m .57239 .28413 L .57397 .2864 L 0 .045 .148 r
F
.57094 .28757 m .56935 .2853 L .57239 .28413 L F
.54801 .28885 m .54942 .2852 L .55103 .28744 L 0 .048 .15 r
F
.54801 .28885 m .5464 .28657 L .54942 .2852 L F
.63209 .2842 m .63364 .28117 L .63516 .28301 L 0 .038 .14 r
F
.63209 .2842 m .63058 .28237 L .63364 .28117 L F
.47758 .28761 m .47889 .28427 L .48057 .28636 L 0 .046 .148 r
F
.47758 .28761 m .4759 .2855 L .47889 .28427 L F
.58623 .28677 m .5877 .28336 L .58927 .28548 L 0 .043 .146 r
F
.58623 .28677 m .58466 .28462 L .5877 .28336 L F
.61681 .28509 m .61832 .28178 L .61986 .2839 L 0 .04 .142 r
F
.61681 .28509 m .61526 .28299 L .61832 .28178 L F
.51878 .45873 m .52019 .43288 L .5218 .45289 L .057 .562 0 r
F
.51878 .45873 m .51717 .43791 L .52019 .43288 L F
.22181 .27853 m .22272 .27543 L .22466 .27742 L 0 .026 .125 r
F
.22181 .27853 m .21988 .27653 L .22272 .27543 L F
.43773 .28469 m .43898 .28162 L .44069 .28366 L 0 .039 .141 r
F
.43773 .28469 m .43601 .28261 L .43898 .28162 L F
.4975 .28917 m .49885 .2858 L .5005 .28821 L 0 .049 .152 r
F
.4975 .28917 m .49585 .28675 L .49885 .2858 L F
.18659 .27794 m .18743 .27501 L .1894 .27698 L 0 .026 .124 r
F
.18659 .27794 m .18462 .27595 L .18743 .27501 L F
.48522 .28727 m .48654 .28426 L .48821 .28634 L 0 .045 .148 r
F
.48522 .28727 m .48355 .28519 L .48654 .28426 L F
.67032 .28218 m .67192 .27913 L .67341 .28108 L 0 .034 .135 r
F
.67032 .28218 m .66883 .28021 L .67192 .27913 L F
.39023 .28222 m .3914 .27932 L .39316 .28127 L F
.39023 .28222 m .38846 .2803 L .3914 .27932 L F
.62445 .28477 m .62598 .2815 L .62751 .28357 L 0 .039 .141 r
F
.62445 .28477 m .62292 .2827 L .62598 .2815 L F
.26466 .27884 m .26563 .27587 L .26752 .27785 L 0 .027 .127 r
F
.26466 .27884 m .26277 .27683 L .26563 .27587 L F
.15137 .27735 m .15217 .2743 L .15418 .27626 L 0 .024 .123 r
F
.15137 .27735 m .14936 .27538 L .15217 .2743 L F
.82484 .27885 m .82669 .27581 L .82802 .27778 L 0 .027 .127 r
F
.82484 .27885 m .82352 .2769 L .82669 .27581 L F
.77434 .27908 m .77611 .27605 L .77748 .27801 L 0 .028 .127 r
F
.77434 .27908 m .77296 .2771 L .77611 .27605 L F
.57859 .28735 m .58004 .28374 L .58162 .28598 L 0 .045 .147 r
F
.57859 .28735 m .57701 .2851 L .58004 .28374 L F
.60152 .28609 m .60302 .28284 L .60457 .28499 L 0 .042 .145 r
F
.60152 .28609 m .59996 .28396 L .60302 .28284 L F
.1085 .27719 m .10923 .27417 L .11128 .27616 L 0 .024 .122 r
F
.1085 .27719 m .10645 .27521 L .10923 .27417 L F
.60917 .28571 m .61067 .28223 L .61221 .28433 L 0 .041 .143 r
F
.60917 .28571 m .60762 .28364 L .61067 .28223 L F
.4178 .2834 m .41902 .28 L .42075 .28225 L 0 .036 .138 r
F
.4178 .2834 m .41607 .28115 L .41902 .28 L F
.33508 .28022 m .33618 .27706 L .33799 .27918 L 0 .03 .13 r
F
.33508 .28022 m .33327 .27811 L .33618 .27706 L F
.67797 .28194 m .6796 .27905 L .68107 .28093 L 0 .034 .135 r
F
.67797 .28194 m .6765 .28003 L .6796 .27905 L F
.8325 .27855 m .83434 .27536 L .83566 .27736 L 0 .027 .126 r
F
.8325 .27855 m .83118 .27657 L .83434 .27536 L F
.29986 .27963 m .30089 .27658 L .30275 .27859 L 0 .029 .129 r
F
.29986 .27963 m .29801 .27763 L .30089 .27658 L F
.22943 .27836 m .23035 .27534 L .23227 .27733 L 0 .026 .126 r
F
.22943 .27836 m .2275 .27637 L .23035 .27534 L F
.70091 .2807 m .70257 .2778 L .70402 .27965 L 0 .031 .132 r
F
.70091 .2807 m .69946 .27885 L .70257 .2778 L F
.69326 .28113 m .6949 .27806 L .69636 .27991 L 0 .032 .133 r
F
.69326 .28113 m .69181 .27927 L .6949 .27806 L F
.782 .27884 m .78378 .27576 L .78514 .2777 L 0 .027 .127 r
F
.782 .27884 m .78063 .27689 L .78378 .27576 L F
.45765 .28647 m .45893 .28318 L .46062 .28555 L 0 .043 .146 r
F
.45765 .28647 m .45596 .28412 L .45893 .28318 L F
.54556 .48427 m .54397 .48816 L .54688 .468 L .263 .634 0 r
F
.54397 .48816 m .5453 .47108 L .54688 .468 L .329 .655 0 r
F
.84016 .27828 m .84203 .27522 L .84335 .27726 L 0 .026 .126 r
F
.84016 .27828 m .83884 .27626 L .84203 .27522 L F
.52044 .28828 m .52181 .28469 L .52344 .28687 L 0 .047 .15 r
F
.52044 .28828 m .5188 .28611 L .52181 .28469 L F
.15898 .27726 m .15977 .27433 L .16177 .27628 L 0 .025 .123 r
F
.15898 .27726 m .15697 .2753 L .15977 .27433 L F
.27228 .27875 m .27326 .27573 L .27515 .27766 L 0 .027 .127 r
F
.27228 .27875 m .27039 .27679 L .27326 .27573 L F
.37029 .28112 m .37143 .2781 L .3732 .2802 L 0 .032 .133 r
F
.37029 .28112 m .36851 .279 L .37143 .2781 L F
.52808 .28791 m .52947 .28471 L .53109 .28687 L 0 .047 .15 r
F
.52808 .28791 m .52646 .28575 L .52947 .28471 L F
.1161 .2771 m .11685 .27408 L .11889 .27605 L 0 .024 .123 r
F
.1161 .2771 m .11406 .27512 L .11685 .27408 L F
.78966 .27859 m .79144 .27546 L .79281 .27749 L 0 .027 .126 r
F
.78966 .27859 m .78829 .27658 L .79144 .27546 L F
.70857 .28051 m .71022 .27732 L .71167 .27931 L 0 .031 .131 r
F
.70857 .28051 m .70712 .27851 L .71022 .27732 L F
.68563 .2818 m .68726 .27869 L .68872 .28055 L 0 .034 .135 r
F
.68563 .2818 m .68417 .27992 L .68726 .27869 L F
.19418 .27798 m .19505 .27499 L .19701 .27694 L 0 .026 .125 r
F
.19418 .27798 m .19222 .27602 L .19505 .27499 L F
.71622 .28013 m .71789 .277 L .71933 .27898 L 0 .03 .13 r
F
.71622 .28013 m .71477 .27811 L .71789 .277 L F
.44536 .2848 m .44662 .28154 L .44832 .28379 L 0 .04 .142 r
F
.44536 .2848 m .44365 .28261 L .44662 .28154 L F
.07322 .27698 m .07391 .27392 L .07599 .27589 L 0 .024 .123 r
F
.07322 .27698 m .07114 .275 L .07391 .27392 L F
.30748 .27954 m .30852 .27657 L .31037 .27858 L 0 .029 .129 r
F
.30748 .27954 m .30564 .27754 L .30852 .27657 L F
.23704 .27827 m .23797 .27526 L .23989 .27722 L 0 .027 .126 r
F
.23704 .27827 m .23512 .2763 L .23797 .27526 L F
.39785 .28231 m .39903 .27937 L .40079 .28135 L 0 .035 .136 r
F
.39785 .28231 m .3961 .28034 L .39903 .27937 L F
.72387 .27979 m .72555 .27671 L .72698 .27864 L 0 .03 .13 r
F
.72387 .27979 m .72244 .27783 L .72555 .27671 L F
.2799 .27854 m .28089 .27568 L .28277 .27759 L 0 .028 .127 r
F
.2799 .27854 m .27802 .27665 L .28089 .27568 L F
.74681 .27855 m .74854 .27557 L .74994 .27753 L 0 .027 .127 r
F
.74681 .27855 m .7454 .27659 L .74854 .27557 L F
.51279 .28894 m .51416 .28537 L .5158 .28754 L 0 .049 .152 r
F
.51279 .28894 m .51115 .28679 L .51416 .28537 L F
.42543 .28343 m .42665 .28045 L .42838 .28251 L 0 .038 .139 r
F
.42543 .28343 m .4237 .28135 L .42665 .28045 L F
.3427 .28029 m .3438 .27722 L .34561 .27928 L 0 .031 .131 r
F
.3427 .28029 m .34089 .2782 L .3438 .27722 L F
.73917 .27903 m .74087 .2759 L .74228 .27779 L 0 .028 .128 r
F
.73917 .27903 m .73776 .27714 L .74087 .2759 L F
.20181 .27777 m .20268 .27476 L .20464 .27669 L 0 .026 .125 r
F
.20181 .27777 m .19985 .27585 L .20268 .27476 L F
.73152 .27947 m .73322 .27644 L .73464 .27835 L 0 .029 .129 r
F
.73152 .27947 m .7301 .27754 L .73322 .27644 L F
.79733 .27843 m .79913 .27537 L .80049 .27741 L 0 .027 .126 r
F
.79733 .27843 m .79597 .27639 L .79913 .27537 L F
.12371 .27696 m .12447 .2739 L .12651 .27585 L 0 .024 .123 r
F
.12371 .27696 m .12168 .275 L .12447 .2739 L F
.08084 .27677 m .08153 .27374 L .08361 .27571 L 0 .024 .122 r
F
.08084 .27677 m .07876 .2748 L .08153 .27374 L F
.16658 .2772 m .16739 .27426 L .16939 .27617 L 0 .025 .124 r
F
.16658 .2772 m .16458 .27529 L .16739 .27426 L F
.24467 .27809 m .24561 .27507 L .24753 .277 L 0 .027 .126 r
F
.24467 .27809 m .24275 .27616 L .24561 .27507 L F
.53573 .28786 m .53713 .28476 L .53875 .2868 L 0 .048 .15 r
F
.53573 .28786 m .53411 .28582 L .53713 .28476 L F
.49286 .2877 m .49419 .28448 L .49585 .28675 L 0 .047 .15 r
F
.49286 .2877 m .4912 .28542 L .49419 .28448 L F
.13134 .27667 m .13211 .27366 L .13414 .2756 L 0 .024 .122 r
F
.13134 .27667 m .12931 .27474 L .13211 .27366 L F
.50514 .28961 m .5065 .28585 L .50815 .2882 L 0 .051 .154 r
F
.50514 .28961 m .5035 .28723 L .5065 .28585 L F
.2523 .27782 m .25326 .27477 L .25516 .27671 L 0 .026 .125 r
F
.2523 .27782 m .25039 .27589 L .25326 .27477 L F
.53535 .50562 m .53378 .52309 L .5368 .51572 L .601 .729 0 r
F
.20942 .27764 m .2103 .27474 L .21225 .27669 L 0 .026 .125 r
F
.20942 .27764 m .20747 .27571 L .2103 .27474 L F
.1742 .27703 m .17502 .2741 L .17701 .27601 L 0 .025 .124 r
F
.1742 .27703 m .1722 .27513 L .17502 .2741 L F
.35032 .28021 m .35144 .27714 L .35324 .2791 L 0 .031 .131 r
F
.35032 .28021 m .34852 .27825 L .35144 .27714 L F
.3151 .27959 m .31614 .27668 L .31799 .27863 L 0 .03 .13 r
F
.3151 .27959 m .31325 .27764 L .31614 .27668 L F
.40548 .28236 m .40669 .27908 L .40843 .28122 L 0 .035 .136 r
F
.40548 .28236 m .40374 .28022 L .40669 .27908 L F
.28752 .27855 m .28852 .2757 L .29039 .27761 L 0 .028 .128 r
F
.28752 .27855 m .28564 .27663 L .28852 .2757 L F
.75449 .27856 m .75622 .27542 L .75762 .27747 L 0 .028 .127 r
F
.75449 .27856 m .75308 .27651 L .75622 .27542 L F
.64279 .28217 m .64435 .27905 L .64586 .28094 L 0 .035 .136 r
F
.64279 .28217 m .64128 .2803 L .64435 .27905 L F
.08844 .27666 m .08913 .27369 L .09121 .27565 L 0 .024 .123 r
F
.08844 .27666 m .08637 .2747 L .08913 .27369 L F
.35797 .27986 m .35908 .27699 L .36088 .27889 L 0 .031 .131 r
F
.35797 .27986 m .35616 .27798 L .35908 .27699 L F
.46528 .28686 m .46658 .28331 L .46826 .28565 L 0 .045 .147 r
F
.46528 .28686 m .46359 .2845 L .46658 .28331 L F
.65044 .28178 m .65202 .27884 L .65352 .28074 L 0 .035 .136 r
F
.65044 .28178 m .64894 .27989 L .65202 .27884 L F
.56632 .28646 m .56776 .2832 L .56935 .2853 L 0 .045 .147 r
F
.56632 .28646 m .56473 .28436 L .56776 .2832 L F
.3779 .28137 m .37905 .27828 L .38083 .28036 L 0 .034 .134 r
F
.3779 .28137 m .37613 .27928 L .37905 .27828 L F
.80501 .27844 m .80682 .27531 L .80817 .27735 L 0 .028 .127 r
F
.80501 .27844 m .80366 .27639 L .80682 .27531 L F
.13895 .27655 m .13972 .27362 L .14174 .27556 L 0 .024 .123 r
F
.13895 .27655 m .13693 .27461 L .13972 .27362 L F
.54338 .2878 m .54479 .28452 L .5464 .28657 L 0 .048 .151 r
F
.54338 .2878 m .54177 .28575 L .54479 .28452 L F
.55867 .28698 m .5601 .2835 L .5617 .28564 L 0 .046 .148 r
F
.55867 .28698 m .55707 .28477 L .5601 .2835 L F
.45299 .28507 m .45426 .28179 L .45596 .28412 L 0 .042 .144 r
F
.45299 .28507 m .45129 .28278 L .45426 .28179 L F
.43306 .28361 m .43429 .28061 L .43601 .28261 L 0 .039 .141 r
F
.43306 .28361 m .43133 .28158 L .43429 .28061 L F
.55103 .28744 m .55244 .28382 L .55405 .28604 L 0 .047 .149 r
F
.55103 .28744 m .54942 .2852 L .55244 .28382 L F
.76215 .27834 m .76389 .27516 L .76528 .27717 L 0 .027 .127 r
F
.76215 .27834 m .76075 .27631 L .76389 .27516 L F
.65809 .28153 m .65968 .27846 L .66117 .28041 L 0 .034 .135 r
F
.65809 .28153 m .6566 .27962 L .65968 .27846 L F
.32273 .27943 m .3238 .27638 L .32563 .27831 L 0 .03 .13 r
F
.32273 .27943 m .32089 .27751 L .3238 .27638 L F
.25991 .27776 m .26087 .27484 L .26277 .27683 L 0 .027 .126 r
F
.25991 .27776 m .25802 .27576 L .26087 .27484 L F
.81268 .2782 m .81449 .27501 L .81583 .27702 L 0 .027 .127 r
F
.81268 .2782 m .81133 .27618 L .81449 .27501 L F
.09605 .27651 m .09677 .27347 L .09883 .27541 L 0 .024 .123 r
F
.09605 .27651 m .09398 .27458 L .09677 .27347 L F
.18181 .27693 m .18264 .274 L .18462 .27595 L 0 .025 .124 r
F
.18181 .27693 m .17982 .275 L .18264 .274 L F
.47292 .28674 m .47423 .28323 L .4759 .2855 L 0 .045 .148 r
F
.47292 .28674 m .47124 .28444 L .47423 .28323 L F
.21703 .27763 m .21793 .27457 L .21988 .27653 L 0 .026 .126 r
F
.21703 .27763 m .21509 .27568 L .21793 .27457 L F
.58927 .28548 m .59074 .2821 L .59231 .28419 L 0 .043 .145 r
F
.58927 .28548 m .5877 .28336 L .59074 .2821 L F
.41312 .28231 m .41434 .2789 L .41607 .28115 L 0 .035 .137 r
F
.41312 .28231 m .41138 .28006 L .41434 .2789 L F
.59691 .28507 m .5984 .28182 L .59996 .28396 L 0 .042 .144 r
F
.59691 .28507 m .59535 .28296 L .5984 .28182 L F
.48057 .28636 m .48188 .28311 L .48355 .28519 L 0 .045 .147 r
F
.48057 .28636 m .47889 .28427 L .48188 .28311 L F
.66575 .28128 m .66735 .2782 L .66883 .28021 L 0 .034 .135 r
F
.66575 .28128 m .66426 .2793 L .66735 .2782 L F
.33037 .27917 m .33144 .27613 L .33327 .27811 L 0 .03 .13 r
F
.33037 .27917 m .32854 .27721 L .33144 .27613 L F
.57397 .2864 m .57542 .28284 L .57701 .2851 L 0 .045 .147 r
F
.57397 .2864 m .57239 .28413 L .57542 .28284 L F
.63516 .28301 m .6367 .2798 L .63822 .28166 L 0 .037 .139 r
F
.63516 .28301 m .63364 .28117 L .6367 .2798 L F
.58162 .28598 m .58308 .2824 L .58466 .28462 L 0 .043 .146 r
F
.58162 .28598 m .58004 .28374 L .58308 .2824 L F
.76981 .27814 m .77158 .27512 L .77296 .2771 L 0 .028 .127 r
F
.76981 .27814 m .76843 .27614 L .77158 .27512 L F
.10368 .27625 m .1044 .27325 L .10645 .27521 L 0 .024 .122 r
F
.10368 .27625 m .10162 .27431 L .1044 .27325 L F
.38553 .28135 m .3867 .27822 L .38846 .2803 L 0 .034 .135 r
F
.38553 .28135 m .38376 .2793 L .3867 .27822 L F
.14656 .27647 m .14735 .27343 L .14936 .27538 L 0 .024 .123 r
F
.14656 .27647 m .14454 .27451 L .14735 .27343 L F
.82034 .27795 m .82218 .27493 L .82352 .2769 L 0 .027 .127 r
F
.82034 .27795 m .81901 .27596 L .82218 .27493 L F
.61986 .2839 m .62138 .28057 L .62292 .2827 L 0 .039 .141 r
F
.61986 .2839 m .61832 .28178 L .62138 .28057 L F
.61221 .28433 m .61372 .28086 L .61526 .28299 L 0 .04 .142 r
F
.61221 .28433 m .61067 .28223 L .61372 .28086 L F
.36559 .27989 m .36671 .27708 L .36851 .279 L 0 .032 .132 r
F
.36559 .27989 m .3638 .27798 L .36671 .27708 L F
.29513 .27862 m .29614 .27568 L .29801 .27763 L 0 .029 .129 r
F
.29513 .27862 m .29326 .27667 L .29614 .27568 L F
.62751 .28357 m .62905 .28028 L .63058 .28237 L 0 .039 .14 r
F
.62751 .28357 m .62598 .2815 L .62905 .28028 L F
.22466 .27742 m .22557 .27438 L .2275 .27637 L 0 .026 .125 r
F
.22466 .27742 m .22272 .27543 L .22557 .27438 L F
.67341 .28108 m .67502 .27812 L .6765 .28003 L 0 .034 .135 r
F
.67341 .28108 m .67192 .27913 L .67502 .27812 L F
.44069 .28366 m .44194 .28054 L .44365 .28261 L 0 .039 .141 r
F
.44069 .28366 m .43898 .28162 L .44194 .28054 L F
.52344 .28687 m .52482 .28356 L .52646 .28575 L 0 .047 .149 r
F
.52344 .28687 m .52181 .28469 L .52482 .28356 L F
.15418 .27626 m .15497 .27334 L .15697 .2753 L 0 .024 .123 r
F
.15418 .27626 m .15217 .2743 L .15497 .27334 L F
.82802 .27778 m .82985 .27458 L .83118 .27657 L 0 .027 .126 r
F
.82802 .27778 m .82669 .27581 L .82985 .27458 L F
.60457 .28499 m .60606 .28147 L .60762 .28364 L 0 .042 .144 r
F
.60457 .28499 m .60302 .28284 L .60606 .28147 L F
.83566 .27736 m .83752 .27424 L .83884 .27626 L 0 .026 .125 r
F
.83566 .27736 m .83434 .27536 L .83752 .27424 L F
.69636 .27991 m .69801 .277 L .69946 .27885 L 0 .032 .132 r
F
.69636 .27991 m .6949 .27806 L .69801 .277 L F
.42075 .28225 m .42197 .27909 L .4237 .28135 L 0 .036 .138 r
F
.42075 .28225 m .41902 .28 L .42197 .27909 L F
.77748 .27801 m .77926 .27495 L .78063 .27689 L 0 .028 .127 r
F
.77748 .27801 m .77611 .27605 L .77926 .27495 L F
.5005 .28821 m .50184 .28484 L .5035 .28723 L 0 .05 .152 r
F
.5005 .28821 m .49885 .2858 L .50184 .28484 L F
.1894 .27698 m .19025 .27406 L .19222 .27602 L 0 .026 .125 r
F
.1894 .27698 m .18743 .27501 L .19025 .27406 L F
.26752 .27785 m .2685 .27484 L .27039 .27679 L 0 .027 .127 r
F
.26752 .27785 m .26563 .27587 L .2685 .27484 L F
.11128 .27616 m .11202 .27313 L .11406 .27512 L 0 .024 .123 r
F
.11128 .27616 m .10923 .27417 L .11202 .27313 L F
.48821 .28634 m .48953 .28332 L .4912 .28542 L 0 .046 .148 r
F
.48821 .28634 m .48654 .28426 L .48953 .28332 L F
.53745 .47539 m .53874 .4442 L .5404 .456 L .168 .603 0 r
F
.53745 .47539 m .53578 .46182 L .53874 .4442 L F
.39316 .28127 m .39433 .27837 L .3961 .28034 L 0 .035 .136 r
F
.39316 .28127 m .3914 .27932 L .39433 .27837 L F
.33799 .27918 m .33908 .2761 L .34089 .2782 L 0 .03 .13 r
F
.33799 .27918 m .33618 .27706 L .33908 .2761 L F
.78514 .2777 m .78693 .27465 L .78829 .27658 L 0 .027 .127 r
F
.78514 .2777 m .78378 .27576 L .78693 .27465 L F
.30275 .27859 m .30378 .27553 L .30564 .27754 L 0 .029 .129 r
F
.30275 .27859 m .30089 .27658 L .30378 .27553 L F
.70402 .27965 m .70568 .27664 L .70712 .27851 L 0 .031 .132 r
F
.70402 .27965 m .70257 .2778 L .70568 .27664 L F
.68107 .28093 m .6827 .27806 L .68417 .27992 L 0 .034 .135 r
F
.68107 .28093 m .6796 .27905 L .6827 .27806 L F
.23227 .27733 m .2332 .27431 L .23512 .2763 L 0 .027 .126 r
F
.23227 .27733 m .23035 .27534 L .2332 .27431 L F
.5158 .28754 m .51716 .28394 L .5188 .28611 L 0 .048 .15 r
F
.5158 .28754 m .51416 .28537 L .51716 .28394 L F
.68872 .28055 m .69035 .27742 L .69181 .27927 L 0 .033 .134 r
F
.68872 .28055 m .68726 .27869 L .69035 .27742 L F
.71167 .27931 m .71333 .27612 L .71477 .27811 L 0 .03 .131 r
F
.71167 .27931 m .71022 .27732 L .71333 .27612 L F
.27515 .27766 m .27613 .27473 L .27802 .27665 L 0 .028 .127 r
F
.27515 .27766 m .27326 .27573 L .27613 .27473 L F
.84335 .27726 m .84522 .27418 L .84654 .27623 L 0 .027 .126 r
F
.84335 .27726 m .84203 .27522 L .84522 .27418 L F
.46062 .28555 m .46191 .28212 L .46359 .2845 L 0 .044 .146 r
F
.46062 .28555 m .45893 .28318 L .46191 .28212 L F
.79281 .27749 m .7946 .27435 L .79597 .27639 L 0 .027 .126 r
F
.79281 .27749 m .79144 .27546 L .7946 .27435 L F
.71933 .27898 m .721 .27588 L .72244 .27783 L 0 .03 .13 r
F
.71933 .27898 m .71789 .277 L .721 .27588 L F
.51574 .46457 m .51717 .43791 L .51878 .45873 L .103 .579 0 r
F
.51574 .46457 m .51416 .44295 L .51717 .43791 L F
.53109 .28687 m .53249 .28366 L .53411 .28582 L 0 .047 .15 r
F
.53109 .28687 m .52947 .28471 L .53249 .28366 L F
.11889 .27605 m .11964 .27303 L .12168 .275 L 0 .024 .123 r
F
.11889 .27605 m .11685 .27408 L .11964 .27303 L F
.16177 .27628 m .16258 .27335 L .16458 .27529 L 0 .025 .124 r
F
.16177 .27628 m .15977 .27433 L .16258 .27335 L F
.74228 .27779 m .744 .27471 L .7454 .27659 L 0 .028 .127 r
F
.74228 .27779 m .74087 .2759 L .744 .27471 L F
.19701 .27694 m .19788 .27391 L .19985 .27585 L 0 .026 .125 r
F
.19701 .27694 m .19505 .27499 L .19788 .27391 L F
.72698 .27864 m .72868 .27562 L .7301 .27754 L 0 .029 .129 r
F
.72698 .27864 m .72555 .27671 L .72868 .27562 L F
.50815 .2882 m .5095 .28446 L .51115 .28679 L 0 .05 .152 r
F
.50815 .2882 m .5065 .28585 L .5095 .28446 L F
.07599 .27589 m .07668 .27283 L .07876 .2748 L 0 .024 .122 r
F
.07599 .27589 m .07391 .27392 L .07668 .27283 L F
.44832 .28379 m .44959 .28048 L .45129 .28278 L 0 .04 .142 r
F
.44832 .28379 m .44662 .28154 L .44959 .28048 L F
.23989 .27722 m .24083 .27422 L .24275 .27616 L 0 .027 .126 r
F
.23989 .27722 m .23797 .27526 L .24083 .27422 L F
.3732 .2802 m .37435 .2772 L .37613 .27928 L 0 .033 .134 r
F
.3732 .2802 m .37143 .2781 L .37435 .2772 L F
.73464 .27835 m .73634 .27524 L .73776 .27714 L 0 .029 .129 r
F
.73464 .27835 m .73322 .27644 L .73634 .27524 L F
.31037 .27858 m .31141 .27563 L .31325 .27764 L 0 .03 .13 r
F
.31037 .27858 m .30852 .27657 L .31141 .27563 L F
.74994 .27753 m .75168 .27455 L .75308 .27651 L 0 .028 .127 r
F
.74994 .27753 m .74854 .27557 L .75168 .27455 L F
.40079 .28135 m .40198 .27825 L .40374 .28022 L 0 .035 .136 r
F
.40079 .28135 m .39903 .27937 L .40198 .27825 L F
.20464 .27669 m .20551 .27378 L .20747 .27571 L 0 .026 .125 r
F
.20464 .27669 m .20268 .27476 L .20551 .27378 L F
.12651 .27585 m .12727 .27279 L .12931 .27474 L 0 .024 .123 r
F
.12651 .27585 m .12447 .2739 L .12727 .27279 L F
.28277 .27759 m .28376 .27471 L .28564 .27663 L 0 .028 .127 r
F
.28277 .27759 m .28089 .27568 L .28376 .27471 L F
.34561 .27928 m .34671 .27621 L .34852 .27825 L 0 .031 .131 r
F
.34561 .27928 m .3438 .27722 L .34671 .27621 L F
.08361 .27571 m .08429 .27273 L .08637 .2747 L 0 .024 .123 r
F
.08361 .27571 m .08153 .27374 L .08429 .27273 L F
.80049 .27741 m .8023 .27435 L .80366 .27639 L 0 .027 .127 r
F
.80049 .27741 m .79913 .27537 L .8023 .27435 L F
.42838 .28251 m .42961 .27954 L .43133 .28158 L 0 .038 .14 r
F
.42838 .28251 m .42665 .28045 L .42961 .27954 L F
.24753 .277 m .24848 .27395 L .25039 .27589 L 0 .027 .126 r
F
.24753 .277 m .24561 .27507 L .24848 .27395 L F
.16939 .27617 m .1702 .27323 L .1722 .27513 L 0 .025 .124 r
F
.16939 .27617 m .16739 .27426 L .1702 .27323 L F
.53875 .2868 m .54015 .28369 L .54177 .28575 L 0 .048 .15 r
F
.53875 .2868 m .53713 .28476 L .54015 .28369 L F
.13414 .2756 m .1349 .27267 L .13693 .27461 L 0 .024 .123 r
F
.13414 .2756 m .13211 .27366 L .1349 .27267 L F
.64586 .28094 m .64743 .27797 L .64894 .27989 L 0 .035 .136 r
F
.64586 .28094 m .64435 .27905 L .64743 .27797 L F
.55405 .28604 m .55547 .2826 L .55707 .28477 L 0 .046 .148 r
F
.55405 .28604 m .55244 .28382 L .55547 .2826 L F
.51272 .46552 m .51115 .44391 L .51416 .44295 L .126 .588 0 r
F
.50973 .46159 m .51115 .44391 L .51272 .46552 L .102 .579 0 r
F
.54276 .494 m .54122 .50822 L .54417 .49128 L .41 .678 0 r
F
.5398 .50837 m .54122 .50822 L .54276 .494 L .623 .734 0 r
F
.25516 .27671 m .25611 .27381 L .25802 .27576 L 0 .026 .125 r
F
.25516 .27671 m .25326 .27477 L .25611 .27381 L F
.5617 .28564 m .56313 .28228 L .56473 .28436 L 0 .045 .147 r
F
.5617 .28564 m .5601 .2835 L .56313 .28228 L F
.46826 .28565 m .46956 .28212 L .47124 .28444 L 0 .044 .147 r
F
.46826 .28565 m .46658 .28331 L .46956 .28212 L F
.40843 .28122 m .40964 .27793 L .41138 .28006 L 0 .035 .136 r
F
.40843 .28122 m .40669 .27908 L .40964 .27793 L F
.35324 .2791 m .35436 .27604 L .35616 .27798 L 0 .031 .131 r
F
.35324 .2791 m .35144 .27714 L .35436 .27604 L F
.49585 .28675 m .49719 .28353 L .49885 .2858 L 0 .048 .15 r
F
.49585 .28675 m .49419 .28448 L .49719 .28353 L F
.56935 .2853 m .5708 .28204 L .57239 .28413 L 0 .044 .147 r
F
.56935 .2853 m .56776 .2832 L .5708 .28204 L F
.5464 .28657 m .54781 .28314 L .54942 .2852 L 0 .047 .15 r
F
.5464 .28657 m .54479 .28452 L .54781 .28314 L F
.75762 .27747 m .75935 .27428 L .76075 .27631 L 0 .028 .127 r
F
.75762 .27747 m .75622 .27542 L .75935 .27428 L F
.17701 .27601 m .17784 .27307 L .17982 .275 L 0 .025 .124 r
F
.17701 .27601 m .17502 .2741 L .17784 .27307 L F
.21225 .27669 m .21314 .27372 L .21509 .27568 L 0 .026 .126 r
F
.21225 .27669 m .2103 .27474 L .21314 .27372 L F
.65352 .28074 m .6551 .27768 L .6566 .27962 L 0 .035 .136 r
F
.65352 .28074 m .65202 .27884 L .6551 .27768 L F
.80817 .27735 m .80998 .27415 L .81133 .27618 L 0 .027 .127 r
F
.80817 .27735 m .80682 .27531 L .80998 .27415 L F
.09121 .27565 m .09191 .27262 L .09398 .27458 L 0 .024 .123 r
F
.09121 .27565 m .08913 .27369 L .09191 .27262 L F
.31799 .27863 m .31905 .27556 L .32089 .27751 L 0 .03 .13 r
F
.31799 .27863 m .31614 .27668 L .31905 .27556 L F
.76528 .27717 m .76704 .27414 L .76843 .27614 L 0 .027 .127 r
F
.76528 .27717 m .76389 .27516 L .76704 .27414 L F
.38083 .28036 m .38199 .27719 L .38376 .2793 L 0 .034 .135 r
F
.38083 .28036 m .37905 .27828 L .38199 .27719 L F
.59231 .28419 m .59379 .28089 L .59535 .28296 L 0 .042 .144 r
F
.59231 .28419 m .59074 .2821 L .59379 .28089 L F
.29039 .27761 m .29139 .27476 L .29326 .27667 L 0 .029 .128 r
F
.29039 .27761 m .28852 .2757 L .29139 .27476 L F
.36088 .27889 m .362 .27607 L .3638 .27798 L 0 .031 .132 r
F
.36088 .27889 m .35908 .27699 L .362 .27607 L F
.58466 .28462 m .58612 .2812 L .5877 .28336 L 0 .043 .145 r
F
.58466 .28462 m .58308 .2824 L .58612 .2812 L F
.63822 .28166 m .63977 .27842 L .64128 .2803 L 0 .036 .138 r
F
.63822 .28166 m .6367 .2798 L .63977 .27842 L F
.4759 .2855 m .47722 .28202 L .47889 .28427 L 0 .045 .147 r
F
.4759 .2855 m .47423 .28323 L .47722 .28202 L F
.66117 .28041 m .66276 .27731 L .66426 .2793 L 0 .034 .135 r
F
.66117 .28041 m .65968 .27846 L .66276 .27731 L F
.81583 .27702 m .81767 .27397 L .81901 .27596 L 0 .027 .126 r
F
.81583 .27702 m .81449 .27501 L .81767 .27397 L F
.32563 .27831 m .3267 .27526 L .32854 .27721 L 0 .03 .13 r
F
.32563 .27831 m .3238 .27638 L .3267 .27526 L F
.57701 .2851 m .57846 .2815 L .58004 .28374 L 0 .043 .146 r
F
.57701 .2851 m .57542 .28284 L .57846 .2815 L F
.61526 .28299 m .61678 .27965 L .61832 .28178 L 0 .039 .141 r
F
.61526 .28299 m .61372 .28086 L .61678 .27965 L F
.14174 .27556 m .14252 .27257 L .14454 .27451 L 0 .024 .123 r
F
.14174 .27556 m .13972 .27362 L .14252 .27257 L F
.43601 .28261 m .43726 .27965 L .43898 .28162 L 0 .039 .141 r
F
.43601 .28261 m .43429 .28061 L .43726 .27965 L F
.09883 .27541 m .09955 .27237 L .10162 .27431 L 0 .024 .123 r
F
.09883 .27541 m .09677 .27347 L .09955 .27237 L F
.41607 .28115 m .41729 .27774 L .41902 .28 L 0 .035 .136 r
F
.41607 .28115 m .41434 .2789 L .41729 .27774 L F
.45596 .28412 m .45724 .28079 L .45893 .28318 L 0 .042 .144 r
F
.45596 .28412 m .45426 .28179 L .45724 .28079 L F
.48355 .28519 m .48487 .28216 L .48654 .28426 L 0 .045 .147 r
F
.48355 .28519 m .48188 .28311 L .48487 .28216 L F
.59996 .28396 m .60146 .28068 L .60302 .28284 L 0 .042 .144 r
F
.59996 .28396 m .5984 .28182 L .60146 .28068 L F
.21988 .27653 m .22079 .27347 L .22272 .27543 L 0 .026 .125 r
F
.21988 .27653 m .21793 .27457 L .22079 .27347 L F
.62292 .2827 m .62444 .27935 L .62598 .2815 L 0 .039 .14 r
F
.62292 .2827 m .62138 .28057 L .62444 .27935 L F
.18462 .27595 m .18546 .27305 L .18743 .27501 L 0 .026 .124 r
F
.18462 .27595 m .18264 .274 L .18546 .27305 L F
.66883 .28021 m .67044 .27711 L .67192 .27913 L 0 .034 .135 r
F
.66883 .28021 m .66735 .2782 L .67044 .27711 L F
.26277 .27683 m .26374 .27389 L .26563 .27587 L 0 .027 .127 r
F
.26277 .27683 m .26087 .27484 L .26374 .27389 L F
.33327 .27811 m .33435 .27504 L .33618 .27706 L 0 .03 .13 r
F
.33327 .27811 m .33144 .27613 L .33435 .27504 L F
.60762 .28364 m .60911 .28005 L .61067 .28223 L 0 .04 .142 r
F
.60762 .28364 m .60606 .28147 L .60911 .28005 L F
.63058 .28237 m .63211 .27907 L .63364 .28117 L 0 .038 .14 r
F
.63058 .28237 m .62905 .28028 L .63211 .27907 L F
.14936 .27538 m .15016 .27235 L .15217 .2743 L 0 .024 .123 r
F
.14936 .27538 m .14735 .27343 L .15016 .27235 L F
.77296 .2771 m .77473 .27408 L .77611 .27605 L 0 .028 .127 r
F
.77296 .2771 m .77158 .27512 L .77473 .27408 L F
.38846 .2803 m .38963 .27723 L .3914 .27932 L 0 .034 .135 r
F
.38846 .2803 m .3867 .27822 L .38963 .27723 L F
.82352 .2769 m .82536 .27385 L .82669 .27581 L 0 .027 .127 r
F
.82352 .2769 m .82218 .27493 L .82536 .27385 L F
.10645 .27521 m .10718 .27218 L .10923 .27417 L 0 .024 .122 r
F
.10645 .27521 m .1044 .27325 L .10718 .27218 L F
.5188 .28611 m .52018 .28251 L .52181 .28469 L 0 .046 .149 r
F
.5188 .28611 m .51716 .28394 L .52018 .28251 L F
.83118 .27657 m .83302 .27335 L .83434 .27536 L 0 .026 .126 r
F
.83118 .27657 m .82985 .27458 L .83302 .27335 L F
.29801 .27763 m .29903 .27461 L .30089 .27658 L 0 .029 .129 r
F
.29801 .27763 m .29614 .27568 L .29903 .27461 L F
.2275 .27637 m .22842 .27334 L .23035 .27534 L 0 .026 .125 r
F
.2275 .27637 m .22557 .27438 L .22842 .27334 L F
.52646 .28575 m .52784 .28251 L .52947 .28471 L 0 .046 .149 r
F
.52646 .28575 m .52482 .28356 L .52784 .28251 L F
.6765 .28003 m .67812 .27715 L .6796 .27905 L 0 .034 .135 r
F
.6765 .28003 m .67502 .27812 L .67812 .27715 L F
.36851 .279 m .36963 .27618 L .37143 .2781 L 0 .032 .133 r
F
.36851 .279 m .36671 .27708 L .36963 .27618 L F
.44365 .28261 m .44491 .27944 L .44662 .28154 L 0 .039 .141 r
F
.44365 .28261 m .44194 .28054 L .44491 .27944 L F
.78063 .27689 m .78241 .27384 L .78378 .27576 L 0 .027 .127 r
F
.78063 .27689 m .77926 .27495 L .78241 .27384 L F
.83884 .27626 m .84071 .27318 L .84203 .27522 L 0 .026 .125 r
F
.83884 .27626 m .83752 .27424 L .84071 .27318 L F
.69181 .27927 m .69345 .27621 L .6949 .27806 L 0 .032 .133 r
F
.69181 .27927 m .69035 .27742 L .69345 .27621 L F
.69946 .27885 m .70112 .27594 L .70257 .2778 L 0 .032 .132 r
F
.69946 .27885 m .69801 .277 L .70112 .27594 L F
.15697 .2753 m .15777 .27238 L .15977 .27433 L 0 .025 .123 r
F
.15697 .2753 m .15497 .27334 L .15777 .27238 L F
.78829 .27658 m .79008 .27353 L .79144 .27546 L 0 .027 .126 r
F
.78829 .27658 m .78693 .27465 L .79008 .27353 L F
.27039 .27679 m .27137 .2738 L .27326 .27573 L 0 .028 .127 r
F
.27039 .27679 m .2685 .27484 L .27137 .2738 L F
.51115 .28679 m .51251 .28308 L .51416 .28537 L 0 .048 .151 r
F
.51115 .28679 m .5095 .28446 L .51251 .28308 L F
.70712 .27851 m .70878 .27542 L .71022 .27732 L 0 .031 .131 r
F
.70712 .27851 m .70568 .27664 L .70878 .27542 L F
.11406 .27512 m .1148 .27209 L .11685 .27408 L 0 .024 .123 r
F
.11406 .27512 m .11202 .27313 L .1148 .27209 L F
.5035 .28723 m .50485 .28349 L .5065 .28585 L 0 .049 .152 r
F
.5035 .28723 m .50184 .28484 L .50485 .28349 L F
.71477 .27811 m .71645 .27502 L .71789 .277 L 0 .03 .13 r
F
.71477 .27811 m .71333 .27612 L .71645 .27502 L F
.19222 .27602 m .19308 .27304 L .19505 .27499 L 0 .026 .125 r
F
.19222 .27602 m .19025 .27406 L .19308 .27304 L F
.4237 .28135 m .42493 .2782 L .42665 .28045 L 0 .037 .138 r
F
.4237 .28135 m .42197 .27909 L .42493 .2782 L F
.30564 .27754 m .30667 .27456 L .30852 .27657 L 0 .029 .129 r
F
.30564 .27754 m .30378 .27553 L .30667 .27456 L F
.07114 .275 m .07181 .27197 L .07391 .27392 L 0 .024 .123 r
F
.07114 .275 m .06904 .27307 L .07181 .27197 L F
.34089 .2782 m .34199 .27515 L .3438 .27722 L 0 .03 .131 r
F
.34089 .2782 m .33908 .2761 L .34199 .27515 L F
.4912 .28542 m .49253 .28237 L .49419 .28448 L 0 .046 .149 r
F
.4912 .28542 m .48953 .28332 L .49253 .28237 L F
.23512 .2763 m .23605 .27329 L .23797 .27526 L 0 .027 .126 r
F
.23512 .2763 m .2332 .27431 L .23605 .27329 L F
.3961 .28034 m .39727 .27738 L .39903 .27937 L 0 .035 .136 r
F
.3961 .28034 m .39433 .27837 L .39727 .27738 L F
.68417 .27992 m .68579 .27683 L .68726 .27869 L 0 .034 .135 r
F
.68417 .27992 m .6827 .27806 L .68579 .27683 L F
.72244 .27783 m .72413 .27478 L .72555 .27671 L 0 .03 .13 r
F
.72244 .27783 m .721 .27588 L .72413 .27478 L F
.7454 .27659 m .74714 .27369 L .74854 .27557 L 0 .028 .127 r
F
.7454 .27659 m .744 .27471 L .74714 .27369 L F
.79597 .27639 m .79777 .27333 L .79913 .27537 L 0 .027 .126 r
F
.79597 .27639 m .7946 .27435 L .79777 .27333 L F
.50556 .48751 m .504 .47151 L .50692 .48483 L .409 .678 0 r
F
.504 .47151 m .50536 .46699 L .50692 .48483 L .217 .619 0 r
F
.46359 .2845 m .46489 .28096 L .46658 .28331 L 0 .043 .146 r
F
.46359 .2845 m .46191 .28212 L .46489 .28096 L F
.27802 .27665 m .27901 .27375 L .28089 .27568 L 0 .028 .127 r
F
.27802 .27665 m .27613 .27473 L .27901 .27375 L F
.7301 .27754 m .7318 .27454 L .73322 .27644 L 0 .029 .129 r
F
.7301 .27754 m .72868 .27562 L .7318 .27454 L F
.53411 .28582 m .53551 .28257 L .53713 .28476 L 0 .047 .15 r
F
.53411 .28582 m .53249 .28366 L .53551 .28257 L F
.12168 .275 m .12243 .27194 L .12447 .2739 L 0 .024 .123 r
F
.12168 .275 m .11964 .27303 L .12243 .27194 L F
.19985 .27585 m .20072 .27282 L .20268 .27476 L 0 .026 .125 r
F
.19985 .27585 m .19788 .27391 L .20072 .27282 L F
.73776 .27714 m .73946 .27401 L .74087 .2759 L 0 .028 .128 r
F
.73776 .27714 m .73634 .27524 L .73946 .27401 L F
.07876 .2748 m .07945 .27177 L .08153 .27374 L 0 .024 .122 r
F
.07876 .2748 m .07668 .27283 L .07945 .27177 L F
.16458 .27529 m .16539 .27234 L .16739 .27426 L 0 .025 .124 r
F
.16458 .27529 m .16258 .27335 L .16539 .27234 L F
.24275 .27616 m .24369 .27314 L .24561 .27507 L 0 .027 .126 r
F
.24275 .27616 m .24083 .27422 L .24369 .27314 L F
.40374 .28022 m .40493 .27714 L .40669 .27908 L 0 .035 .136 r
F
.40374 .28022 m .40198 .27825 L .40493 .27714 L F
.45129 .28278 m .45257 .27944 L .45426 .28179 L 0 .04 .142 r
F
.45129 .28278 m .44959 .28048 L .45257 .27944 L F
.12931 .27474 m .13007 .27172 L .13211 .27366 L 0 .024 .122 r
F
.12931 .27474 m .12727 .27279 L .13007 .27172 L F
.55707 .28477 m .5585 .28139 L .5601 .2835 L 0 .045 .147 r
F
.55707 .28477 m .55547 .2826 L .5585 .28139 L F
.54942 .2852 m .55084 .28177 L .55244 .28382 L 0 .046 .148 r
F
.54942 .2852 m .54781 .28314 L .55084 .28177 L F
.56473 .28436 m .56617 .28112 L .56776 .2832 L 0 .044 .147 r
F
.56473 .28436 m .56313 .28228 L .56617 .28112 L F
.75308 .27651 m .75482 .27346 L .75622 .27542 L 0 .028 .127 r
F
.75308 .27651 m .75168 .27455 L .75482 .27346 L F
.37613 .27928 m .37728 .27621 L .37905 .27828 L 0 .033 .134 r
F
.37613 .27928 m .37435 .2772 L .37728 .27621 L F
.25039 .27589 m .25135 .27282 L .25326 .27477 L 0 .026 .125 r
F
.25039 .27589 m .24848 .27395 L .25135 .27282 L F
.34852 .27825 m .34963 .27513 L .35144 .27714 L 0 .031 .131 r
F
.34852 .27825 m .34671 .27621 L .34963 .27513 L F
.20747 .27571 m .20835 .27279 L .2103 .27474 L 0 .026 .125 r
F
.20747 .27571 m .20551 .27378 L .20835 .27279 L F
.31325 .27764 m .3143 .27466 L .31614 .27668 L 0 .03 .13 r
F
.31325 .27764 m .31141 .27563 L .3143 .27466 L F
.47124 .28444 m .47255 .28093 L .47423 .28323 L 0 .044 .146 r
F
.47124 .28444 m .46956 .28212 L .47255 .28093 L F
.80366 .27639 m .80547 .27326 L .80682 .27531 L 0 .027 .127 r
F
.80366 .27639 m .8023 .27435 L .80547 .27326 L F
.08637 .2747 m .08706 .27172 L .08913 .27369 L 0 .024 .123 r
F
.08637 .2747 m .08429 .27273 L .08706 .27172 L F
.1722 .27513 m .17302 .27219 L .17502 .2741 L 0 .025 .124 r
F
.1722 .27513 m .1702 .27323 L .17302 .27219 L F
.54177 .28575 m .54317 .28245 L .54479 .28452 L 0 .048 .15 r
F
.54177 .28575 m .54015 .28369 L .54317 .28245 L F
.28564 .27663 m .28664 .27378 L .28852 .2757 L 0 .028 .128 r
F
.28564 .27663 m .28376 .27471 L .28664 .27378 L F
.41138 .28006 m .4126 .27677 L .41434 .2789 L 0 .035 .136 r
F
.41138 .28006 m .40964 .27793 L .4126 .27677 L F
.64128 .2803 m .64284 .27715 L .64435 .27905 L 0 .035 .137 r
F
.64128 .2803 m .63977 .27842 L .64284 .27715 L F
.43133 .28158 m .43257 .27861 L .43429 .28061 L 0 .039 .14 r
F
.43133 .28158 m .42961 .27954 L .43257 .27861 L F
.57239 .28413 m .57384 .28076 L .57542 .28284 L 0 .044 .146 r
F
.57239 .28413 m .5708 .28204 L .57384 .28076 L F
.35616 .27798 m .35728 .27505 L .35908 .27699 L 0 .031 .131 r
F
.35616 .27798 m .35436 .27604 L .35728 .27505 L F
.64894 .27989 m .65051 .2769 L .65202 .27884 L 0 .035 .136 r
F
.64894 .27989 m .64743 .27797 L .65051 .2769 L F
.51272 .46552 m .51416 .44295 L .51574 .46457 L .126 .588 0 r
F
.13693 .27461 m .13769 .27168 L .13972 .27362 L 0 .024 .123 r
F
.13693 .27461 m .1349 .27267 L .13769 .27168 L F
.58004 .28374 m .5815 .28017 L .58308 .2824 L 0 .042 .145 r
F
.58004 .28374 m .57846 .2815 L .5815 .28017 L F
.76075 .27631 m .76249 .27314 L .76389 .27516 L 0 .027 .127 r
F
.76075 .27631 m .75935 .27428 L .76249 .27314 L F
.5877 .28336 m .58917 .28001 L .59074 .2821 L 0 .042 .144 r
F
.5877 .28336 m .58612 .2812 L .58917 .28001 L F
.59535 .28296 m .59684 .27976 L .5984 .28182 L 0 .041 .144 r
F
.59535 .28296 m .59379 .28089 L .59684 .27976 L F
.81133 .27618 m .81315 .27299 L .81449 .27501 L 0 .027 .126 r
F
.81133 .27618 m .80998 .27415 L .81315 .27299 L F
.25802 .27576 m .25897 .27287 L .26087 .27484 L F
.25802 .27576 m .25611 .27381 L .25897 .27287 L F
.47889 .28427 m .48021 .28086 L .48188 .28311 L 0 .044 .146 r
F
.47889 .28427 m .47722 .28202 L .48021 .28086 L F
.6566 .27962 m .65818 .27648 L .65968 .27846 L 0 .034 .135 r
F
.6566 .27962 m .6551 .27768 L .65818 .27648 L F
.32089 .27751 m .32196 .27444 L .3238 .27638 L 0 .03 .13 r
F
.32089 .27751 m .31905 .27556 L .32196 .27444 L F
.49885 .2858 m .50019 .28257 L .50184 .28484 L 0 .048 .151 r
F
.49885 .2858 m .49719 .28353 L .50019 .28257 L F
.61832 .28178 m .61984 .27843 L .62138 .28057 L 0 .039 .14 r
F
.61832 .28178 m .61678 .27965 L .61984 .27843 L F
.09398 .27458 m .09469 .27153 L .09677 .27347 L 0 .024 .123 r
F
.09398 .27458 m .09191 .27262 L .09469 .27153 L F
.17982 .275 m .18066 .27205 L .18264 .274 L 0 .025 .124 r
F
.17982 .275 m .17784 .27307 L .18066 .27205 L F
.61067 .28223 m .61217 .27868 L .61372 .28086 L 0 .039 .141 r
F
.61067 .28223 m .60911 .28005 L .61217 .27868 L F
.21509 .27568 m .21599 .27261 L .21793 .27457 L 0 .026 .126 r
F
.21509 .27568 m .21314 .27372 L .21599 .27261 L F
.38376 .2793 m .38493 .2761 L .3867 .27822 L 0 .034 .135 r
F
.38376 .2793 m .38199 .27719 L .38493 .2761 L F
.66426 .2793 m .66585 .27619 L .66735 .2782 L F
.66426 .2793 m .66276 .27731 L .66585 .27619 L F
.76843 .27614 m .77019 .27314 L .77158 .27512 L 0 .028 .127 r
F
.76843 .27614 m .76704 .27414 L .77019 .27314 L F
.32854 .27721 m .32961 .27415 L .33144 .27613 L 0 .03 .13 r
F
.32854 .27721 m .3267 .27526 L .32961 .27415 L F
.41902 .28 m .42025 .27684 L .42197 .27909 L 0 .035 .136 r
F
.41902 .28 m .41729 .27774 L .42025 .27684 L F
.81901 .27596 m .82085 .27295 L .82218 .27493 L 0 .027 .127 r
F
.81901 .27596 m .81767 .27397 L .82085 .27295 L F
.62598 .2815 m .62751 .27813 L .62905 .28028 L 0 .038 .14 r
F
.62598 .2815 m .62444 .27935 L .62751 .27813 L F
.52181 .28469 m .52319 .28136 L .52482 .28356 L 0 .046 .148 r
F
.52181 .28469 m .52018 .28251 L .52319 .28136 L F
.14454 .27451 m .14533 .27149 L .14735 .27343 L 0 .024 .123 r
F
.14454 .27451 m .14252 .27257 L .14533 .27149 L F
.10162 .27431 m .10234 .27128 L .1044 .27325 L 0 .024 .122 r
F
.10162 .27431 m .09955 .27237 L .10234 .27128 L F
.29326 .27667 m .29428 .27376 L .29614 .27568 L 0 .029 .129 r
F
.29326 .27667 m .29139 .27476 L .29428 .27376 L F
.60302 .28284 m .60451 .2793 L .60606 .28147 L 0 .041 .143 r
F
.60302 .28284 m .60146 .28068 L .60451 .2793 L F
.22272 .27543 m .22364 .27239 L .22557 .27438 L 0 .026 .125 r
F
.22272 .27543 m .22079 .27347 L .22364 .27239 L F
.3638 .27798 m .36492 .27515 L .36671 .27708 L 0 .032 .132 r
F
.3638 .27798 m .362 .27607 L .36492 .27515 L F
.63364 .28117 m .63518 .27771 L .6367 .2798 L 0 .037 .139 r
F
.63364 .28117 m .63211 .27907 L .63518 .27771 L F
.43898 .28162 m .44022 .27856 L .44194 .28054 L 0 .039 .141 r
F
.43898 .28162 m .43726 .27965 L .44022 .27856 L F
.67192 .27913 m .67354 .27606 L .67502 .27812 L 0 .034 .135 r
F
.67192 .27913 m .67044 .27711 L .67354 .27606 L F
.45893 .28318 m .46022 .27973 L .46191 .28212 L 0 .042 .144 r
F
.45893 .28318 m .45724 .28079 L .46022 .27973 L F
.48654 .28426 m .48787 .28122 L .48953 .28332 L 0 .045 .148 r
F
.48654 .28426 m .48487 .28216 L .48787 .28122 L F
.83434 .27536 m .8362 .27222 L .83752 .27424 L 0 .026 .125 r
F
.83434 .27536 m .83302 .27335 L .8362 .27222 L F
.15217 .2743 m .15296 .27138 L .15497 .27334 L 0 .024 .123 r
F
.15217 .2743 m .15016 .27235 L .15296 .27138 L F
.33618 .27706 m .33726 .27409 L .33908 .2761 L 0 .03 .13 r
F
.33618 .27706 m .33435 .27504 L .33726 .27409 L F
.5247 .513 m .52609 .53507 L .52772 .51849 L .774 .757 0 r
F
.5247 .513 m .52306 .52885 L .52609 .53507 L F
.82669 .27581 m .82853 .27263 L .82985 .27458 L 0 .027 .126 r
F
.82669 .27581 m .82536 .27385 L .82853 .27263 L F
.51416 .28537 m .51552 .2817 L .51716 .28394 L 0 .047 .149 r
F
.51416 .28537 m .51251 .28308 L .51552 .2817 L F
.77611 .27605 m .77788 .273 L .77926 .27495 L 0 .028 .127 r
F
.77611 .27605 m .77473 .27408 L .77788 .273 L F
.18743 .27501 m .18828 .2721 L .19025 .27406 L 0 .026 .125 r
F
.18743 .27501 m .18546 .27305 L .18828 .2721 L F
.5065 .28585 m .50786 .28213 L .5095 .28446 L 0 .048 .151 r
F
.5065 .28585 m .50485 .28349 L .50786 .28213 L F
.10923 .27417 m .10997 .27113 L .11202 .27313 L 0 .024 .122 r
F
.10923 .27417 m .10718 .27218 L .10997 .27113 L F
.26563 .27587 m .2666 .27287 L .2685 .27484 L 0 .027 .127 r
F
.26563 .27587 m .26374 .27389 L .2666 .27287 L F
.3914 .27932 m .39257 .27624 L .39433 .27837 L 0 .034 .136 r
F
.3914 .27932 m .38963 .27723 L .39257 .27624 L F
.6949 .27806 m .69656 .27514 L .69801 .277 L 0 .032 .133 r
F
.6949 .27806 m .69345 .27621 L .69656 .27514 L F
.30089 .27658 m .30193 .27354 L .30378 .27553 L 0 .029 .129 r
F
.30089 .27658 m .29903 .27461 L .30193 .27354 L F
.78378 .27576 m .78556 .27274 L .78693 .27465 L 0 .027 .127 r
F
.78378 .27576 m .78241 .27384 L .78556 .27274 L F
.23035 .27534 m .23127 .27231 L .2332 .27431 L 0 .026 .126 r
F
.23035 .27534 m .22842 .27334 L .23127 .27231 L F
.52947 .28471 m .53086 .28144 L .53249 .28366 L 0 .046 .149 r
F
.52947 .28471 m .52784 .28251 L .53086 .28144 L F
.44662 .28154 m .44789 .27834 L .44959 .28048 L 0 .039 .141 r
F
.44662 .28154 m .44491 .27944 L .44789 .27834 L F
.71022 .27732 m .71189 .27421 L .71333 .27612 L 0 .03 .131 r
F
.71022 .27732 m .70878 .27542 L .71189 .27421 L F
.50586 .49331 m .50424 .48589 L .50715 .50267 L .509 .705 0 r
F
.50748 .50074 m .50586 .49331 L .50877 .51084 L .599 .728 0 r
F
.50586 .49331 m .50715 .50267 L .50877 .51084 L .509 .705 0 r
F
.50424 .48589 m .50556 .48751 L .50715 .50267 L .38 .669 0 r
F
.84203 .27522 m .8439 .27212 L .84522 .27418 L 0 .026 .125 r
F
.84203 .27522 m .84071 .27318 L .8439 .27212 L F
.6796 .27905 m .68123 .27618 L .6827 .27806 L 0 .034 .135 r
F
.6796 .27905 m .67812 .27715 L .68123 .27618 L F
.70257 .2778 m .70423 .27476 L .70568 .27664 L 0 .032 .132 r
F
.70257 .2778 m .70112 .27594 L .70423 .27476 L F
.79144 .27546 m .79324 .27242 L .7946 .27435 L 0 .027 .126 r
F
.79144 .27546 m .79008 .27353 L .79324 .27242 L F
.68726 .27869 m .68889 .27557 L .69035 .27742 L 0 .033 .134 r
F
.68726 .27869 m .68579 .27683 L .68889 .27557 L F
.71789 .277 m .71957 .27392 L .721 .27588 L 0 .03 .13 r
F
.71789 .277 m .71645 .27502 L .71957 .27392 L F
.27326 .27573 m .27424 .2728 L .27613 .27473 L 0 .028 .127 r
F
.27326 .27573 m .27137 .2738 L .27424 .2728 L F
.37143 .2781 m .37256 .27528 L .37435 .2772 L 0 .033 .133 r
F
.37143 .2781 m .36963 .27618 L .37256 .27528 L F
.11685 .27408 m .11759 .27105 L .11964 .27303 L 0 .024 .123 r
F
.11685 .27408 m .1148 .27209 L .11759 .27105 L F
.15977 .27433 m .16057 .27141 L .16258 .27335 L 0 .025 .124 r
F
.15977 .27433 m .15777 .27238 L .16057 .27141 L F
.07391 .27392 m .07459 .27086 L .07668 .27283 L 0 .024 .122 r
F
.07391 .27392 m .07181 .27197 L .07459 .27086 L F
.19505 .27499 m .19591 .27196 L .19788 .27391 L 0 .026 .125 r
F
.19505 .27499 m .19308 .27304 L .19591 .27196 L F
.72555 .27671 m .72725 .27371 L .72868 .27562 L 0 .03 .13 r
F
.72555 .27671 m .72413 .27478 L .72725 .27371 L F
.46658 .28331 m .46788 .27979 L .46956 .28212 L 0 .043 .145 r
F
.46658 .28331 m .46489 .28096 L .46788 .27979 L F
.23797 .27526 m .23891 .27226 L .24083 .27422 L 0 .027 .126 r
F
.23797 .27526 m .23605 .27329 L .23891 .27226 L F
.74087 .2759 m .74259 .27283 L .744 .27471 L 0 .028 .127 r
F
.74087 .2759 m .73946 .27401 L .74259 .27283 L F
.30852 .27657 m .30956 .27361 L .31141 .27563 L 0 .029 .129 r
F
.30852 .27657 m .30667 .27456 L .30956 .27361 L F
.3438 .27722 m .3449 .27417 L .34671 .27621 L 0 .031 .131 r
F
.3438 .27722 m .34199 .27515 L .3449 .27417 L F
.55244 .28382 m .55387 .28055 L .55547 .2826 L 0 .045 .147 r
F
.55244 .28382 m .55084 .28177 L .55387 .28055 L F
.39903 .27937 m .40022 .27628 L .40198 .27825 L 0 .035 .136 r
F
.39903 .27937 m .39727 .27738 L .40022 .27628 L F
.49419 .28448 m .49553 .2814 L .49719 .28353 L 0 .047 .149 r
F
.49419 .28448 m .49253 .28237 L .49553 .2814 L F
.42665 .28045 m .42789 .27729 L .42961 .27954 L 0 .037 .139 r
F
.42665 .28045 m .42493 .2782 L .42789 .27729 L F
.74854 .27557 m .75028 .27267 L .75168 .27455 L 0 .028 .127 r
F
.74854 .27557 m .74714 .27369 L .75028 .27267 L F
.79913 .27537 m .80094 .2723 L .8023 .27435 L 0 .027 .126 r
F
.79913 .27537 m .79777 .27333 L .80094 .2723 L F
.73322 .27644 m .73493 .27335 L .73634 .27524 L 0 .029 .129 r
F
.73322 .27644 m .7318 .27454 L .73493 .27335 L F
.12447 .2739 m .12523 .27083 L .12727 .27279 L 0 .024 .123 r
F
.12447 .2739 m .12243 .27194 L .12523 .27083 L F
.20268 .27476 m .20355 .27183 L .20551 .27378 L 0 .026 .125 r
F
.20268 .27476 m .20072 .27282 L .20355 .27183 L F
.53713 .28476 m .53853 .28147 L .54015 .28369 L 0 .047 .15 r
F
.53713 .28476 m .53551 .28257 L .53853 .28147 L F
.5083 .47784 m .50675 .45767 L .50973 .46159 L .264 .634 0 r
F
.50536 .46699 m .50675 .45767 L .5083 .47784 L .169 .603 0 r
F
.5601 .2835 m .56154 .28019 L .56313 .28228 L 0 .044 .146 r
F
.5601 .2835 m .5585 .28139 L .56154 .28019 L F
.08153 .27374 m .08221 .27075 L .08429 .27273 L 0 .024 .122 r
F
.08153 .27374 m .07945 .27177 L .08221 .27075 L F
.28089 .27568 m .28188 .27277 L .28376 .27471 L 0 .028 .128 r
F
.28089 .27568 m .27901 .27375 L .28188 .27277 L F
.40669 .27908 m .40789 .276 L .40964 .27793 L 0 .035 .136 r
F
.40669 .27908 m .40493 .27714 L .40789 .276 L F
.24561 .27507 m .24656 .27202 L .24848 .27395 L 0 .027 .126 r
F
.24561 .27507 m .24369 .27314 L .24656 .27202 L F
.16739 .27426 m .1682 .27134 L .1702 .27323 L 0 .025 .124 r
F
.16739 .27426 m .16539 .27234 L .1682 .27134 L F
.56776 .2832 m .56921 .27996 L .5708 .28204 L 0 .044 .146 r
F
.56776 .2832 m .56617 .28112 L .56921 .27996 L F
.13211 .27366 m .13286 .27074 L .1349 .27267 L 0 .024 .123 r
F
.13211 .27366 m .13007 .27172 L .13286 .27074 L F
.47423 .28323 m .47554 .27973 L .47722 .28202 L 0 .043 .146 r
F
.47423 .28323 m .47255 .28093 L .47554 .27973 L F
.54479 .28452 m .5462 .28108 L .54781 .28314 L 0 .047 .149 r
F
.54479 .28452 m .54317 .28245 L .5462 .28108 L F
.58308 .2824 m .58455 .27904 L .58612 .2812 L 0 .042 .144 r
F
.58308 .2824 m .5815 .28017 L .58455 .27904 L F
.57542 .28284 m .57688 .27943 L .57846 .2815 L 0 .043 .145 r
F
.57542 .28284 m .57384 .28076 L .57688 .27943 L F
.25326 .27477 m .25421 .27185 L .25611 .27381 L 0 .026 .126 r
F
.25326 .27477 m .25135 .27282 L .25421 .27185 L F
.45426 .28179 m .45555 .2784 L .45724 .28079 L 0 .04 .142 r
F
.45426 .28179 m .45257 .27944 L .45555 .2784 L F
.75622 .27542 m .75795 .27231 L .75935 .27428 L 0 .027 .127 r
F
.75622 .27542 m .75482 .27346 L .75795 .27231 L F
.64435 .27905 m .64592 .27605 L .64743 .27797 L 0 .035 .136 r
F
.64435 .27905 m .64284 .27715 L .64592 .27605 L F
.35144 .27714 m .35255 .27405 L .35436 .27604 L 0 .031 .131 r
F
.35144 .27714 m .34963 .27513 L .35255 .27405 L F
.41434 .2789 m .41556 .27561 L .41729 .27774 L 0 .034 .135 r
F
.41434 .2789 m .4126 .27677 L .41556 .27561 L F
.59074 .2821 m .59222 .27885 L .59379 .28089 L 0 .041 .144 r
F
.59074 .2821 m .58917 .28001 L .59222 .27885 L F
.37905 .27828 m .38022 .2751 L .38199 .27719 L 0 .033 .134 r
F
.37905 .27828 m .37728 .27621 L .38022 .2751 L F
.80682 .27531 m .80863 .27212 L .80998 .27415 L 0 .027 .126 r
F
.80682 .27531 m .80547 .27326 L .80863 .27212 L F
.61372 .28086 m .61523 .27748 L .61678 .27965 L 0 .038 .14 r
F
.61372 .28086 m .61217 .27868 L .61523 .27748 L F
.76389 .27516 m .76564 .27214 L .76704 .27414 L 0 .027 .127 r
F
.76389 .27516 m .76249 .27314 L .76564 .27214 L F
.17502 .2741 m .17585 .27114 L .17784 .27307 L 0 .025 .124 r
F
.17502 .2741 m .17302 .27219 L .17585 .27114 L F
.2103 .27474 m .21119 .27176 L .21314 .27372 L 0 .027 .126 r
F
.2103 .27474 m .20835 .27279 L .21119 .27176 L F
.08913 .27369 m .08984 .27065 L .09191 .27262 L 0 .024 .123 r
F
.08913 .27369 m .08706 .27172 L .08984 .27065 L F
.31614 .27668 m .31721 .27356 L .31905 .27556 L 0 .03 .13 r
F
.31614 .27668 m .3143 .27466 L .31721 .27356 L F
.81449 .27501 m .81633 .27197 L .81767 .27397 L 0 .027 .126 r
F
.81449 .27501 m .81315 .27299 L .81633 .27197 L F
.65202 .27884 m .65359 .2757 L .6551 .27768 L 0 .035 .136 r
F
.65202 .27884 m .65051 .2769 L .65359 .2757 L F
.5984 .28182 m .5999 .27862 L .60146 .28068 L 0 .041 .143 r
F
.5984 .28182 m .59684 .27976 L .5999 .27862 L F
.48188 .28311 m .4832 .27989 L .48487 .28216 L 0 .044 .146 r
F
.48188 .28311 m .48021 .28086 L .4832 .27989 L F
.62138 .28057 m .6229 .2772 L .62444 .27935 L 0 .038 .14 r
F
.62138 .28057 m .61984 .27843 L .6229 .2772 L F
.28852 .2757 m .28952 .27284 L .29139 .27476 L 0 .029 .128 r
F
.28852 .2757 m .28664 .27378 L .28952 .27284 L F
.65968 .27846 m .66127 .2753 L .66276 .27731 L 0 .034 .135 r
F
.65968 .27846 m .65818 .27648 L .66127 .2753 L F
.35908 .27699 m .3602 .27412 L .362 .27607 L 0 .031 .132 r
F
.35908 .27699 m .35728 .27505 L .3602 .27412 L F
.43429 .28061 m .43553 .27767 L .43726 .27965 L 0 .039 .141 r
F
.43429 .28061 m .43257 .27861 L .43553 .27767 L F
.60606 .28147 m .60756 .27787 L .60911 .28005 L 0 .04 .142 r
F
.60606 .28147 m .60451 .2793 L .60756 .27787 L F
.3238 .27638 m .32487 .27331 L .3267 .27526 L 0 .03 .13 r
F
.3238 .27638 m .32196 .27444 L .32487 .27331 L F
.13972 .27362 m .14049 .27062 L .14252 .27257 L 0 .025 .123 r
F
.13972 .27362 m .13769 .27168 L .14049 .27062 L F
.6367 .2798 m .63825 .27635 L .63977 .27842 L 0 .036 .138 r
F
.6367 .2798 m .63518 .27771 L .63825 .27635 L F
.09677 .27347 m .09748 .27044 L .09955 .27237 L 0 .024 .123 r
F
.09677 .27347 m .09469 .27153 L .09748 .27044 L F
.62905 .28028 m .63058 .2769 L .63211 .27907 L 0 .038 .139 r
F
.62905 .28028 m .62751 .27813 L .63058 .2769 L F
.21793 .27457 m .21884 .2715 L .22079 .27347 L 0 .026 .125 r
F
.21793 .27457 m .21599 .27261 L .21884 .2715 L F
.51716 .28394 m .51854 .28032 L .52018 .28251 L 0 .046 .148 r
F
.51716 .28394 m .51552 .2817 L .51854 .28032 L F
.66735 .2782 m .66895 .27508 L .67044 .27711 L 0 .034 .135 r
F
.66735 .2782 m .66585 .27619 L .66895 .27508 L F
.3867 .27822 m .38787 .27507 L .38963 .27723 L F
.3867 .27822 m .38493 .2761 L .38787 .27507 L F
.26087 .27484 m .26184 .27191 L .26374 .27389 L 0 .027 .126 r
F
.26087 .27484 m .25897 .27287 L .26184 .27191 L F
.52482 .28356 m .52621 .2803 L .52784 .28251 L 0 .045 .148 r
F
.52482 .28356 m .52319 .28136 L .52621 .2803 L F
.33144 .27613 m .33253 .27304 L .33435 .27504 L 0 .029 .129 r
F
.33144 .27613 m .32961 .27415 L .33253 .27304 L F
.18264 .274 m .18348 .27109 L .18546 .27305 L 0 .026 .124 r
F
.18264 .274 m .18066 .27205 L .18348 .27109 L F
.50184 .28484 m .5032 .28125 L .50485 .28349 L 0 .048 .15 r
F
.50184 .28484 m .50019 .28257 L .5032 .28125 L F
.52343 .47309 m .52482 .44185 L .52646 .46029 L .169 .603 0 r
F
.52343 .47309 m .5218 .45289 L .52482 .44185 L F
.5095 .28446 m .51087 .28079 L .51251 .28308 L 0 .047 .149 r
F
.5095 .28446 m .50786 .28213 L .51087 .28079 L F
.77158 .27512 m .77335 .27211 L .77473 .27408 L 0 .028 .127 r
F
.77158 .27512 m .77019 .27314 L .77335 .27211 L F
.14735 .27343 m .14814 .2704 L .15016 .27235 L 0 .024 .123 r
F
.14735 .27343 m .14533 .27149 L .14814 .2704 L F
.82218 .27493 m .82403 .27189 L .82536 .27385 L 0 .027 .127 r
F
.82218 .27493 m .82085 .27295 L .82403 .27189 L F
.50913 .50249 m .5104 .51902 L .51206 .52076 L .646 .74 0 r
F
.50913 .50249 m .50748 .50074 L .5104 .51902 L F
.1044 .27325 m .10513 .27019 L .10718 .27218 L 0 .024 .122 r
F
.1044 .27325 m .10234 .27128 L .10513 .27019 L F
.82985 .27458 m .8317 .27142 L .83302 .27335 L 0 .026 .126 r
F
.82985 .27458 m .82853 .27263 L .8317 .27142 L F
.22557 .27438 m .22649 .27132 L .22842 .27334 L 0 .026 .125 r
F
.22557 .27438 m .22364 .27239 L .22649 .27132 L F
.44194 .28054 m .4432 .27743 L .44491 .27944 L 0 .039 .141 r
F
.44194 .28054 m .44022 .27856 L .4432 .27743 L F
.29614 .27568 m .29717 .27265 L .29903 .27461 L 0 .029 .129 r
F
.29614 .27568 m .29428 .27376 L .29717 .27265 L F
.42197 .27909 m .4232 .27594 L .42493 .2782 L 0 .036 .137 r
F
.42197 .27909 m .42025 .27684 L .4232 .27594 L F
.83752 .27424 m .83939 .27114 L .84071 .27318 L 0 .026 .125 r
F
.83752 .27424 m .8362 .27222 L .83939 .27114 L F
.46191 .28212 m .4632 .27861 L .46489 .28096 L 0 .042 .144 r
F
.46191 .28212 m .46022 .27973 L .4632 .27861 L F
.67502 .27812 m .67664 .27507 L .67812 .27715 L 0 .034 .135 r
F
.67502 .27812 m .67354 .27606 L .67664 .27507 L F
.77926 .27495 m .78104 .27192 L .78241 .27384 L 0 .028 .127 r
F
.77926 .27495 m .77788 .273 L .78104 .27192 L F
.36671 .27708 m .36784 .27425 L .36963 .27618 L 0 .032 .133 r
F
.36671 .27708 m .36492 .27515 L .36784 .27425 L F
.48953 .28332 m .49086 .28025 L .49253 .28237 L 0 .046 .148 r
F
.48953 .28332 m .48787 .28122 L .49086 .28025 L F
.15497 .27334 m .15576 .2704 L .15777 .27238 L 0 .025 .123 r
F
.15497 .27334 m .15296 .27138 L .15576 .2704 L F
.11202 .27313 m .11275 .2701 L .1148 .27209 L 0 .024 .123 r
F
.11202 .27313 m .10997 .27113 L .11275 .2701 L F
.33908 .2761 m .34017 .27314 L .34199 .27515 L 0 .03 .13 r
F
.33908 .2761 m .33726 .27409 L .34017 .27314 L F
.2685 .27484 m .26948 .27185 L .27137 .2738 L 0 .028 .127 r
F
.2685 .27484 m .2666 .27287 L .26948 .27185 L F
.71333 .27612 m .71501 .27308 L .71645 .27502 L 0 .03 .13 r
F
.71333 .27612 m .71189 .27421 L .71501 .27308 L F
.78693 .27465 m .78872 .27163 L .79008 .27353 L 0 .027 .126 r
F
.78693 .27465 m .78556 .27274 L .78872 .27163 L F
.69035 .27742 m .69199 .27435 L .69345 .27621 L 0 .033 .133 r
F
.69035 .27742 m .68889 .27557 L .69199 .27435 L F
.69801 .277 m .69967 .27406 L .70112 .27594 L 0 .032 .133 r
F
.69801 .277 m .69656 .27514 L .69967 .27406 L F
.30378 .27553 m .30482 .27254 L .30667 .27456 L 0 .029 .129 r
F
.30378 .27553 m .30193 .27354 L .30482 .27254 L F
.19025 .27406 m .19111 .27106 L .19308 .27304 L 0 .026 .125 r
F
.19025 .27406 m .18828 .2721 L .19111 .27106 L F
.70568 .27664 m .70734 .27353 L .70878 .27542 L 0 .031 .131 r
F
.70568 .27664 m .70423 .27476 L .70734 .27353 L F
.2332 .27431 m .23412 .2713 L .23605 .27329 L 0 .027 .126 r
F
.2332 .27431 m .23127 .27231 L .23412 .2713 L F
.53249 .28366 m .53388 .28031 L .53551 .28257 L 0 .046 .149 r
F
.53249 .28366 m .53086 .28144 L .53388 .28031 L F
.44959 .28048 m .45086 .27726 L .45257 .27944 L 0 .039 .141 r
F
.44959 .28048 m .44789 .27834 L .45086 .27726 L F
.39433 .27837 m .39552 .27524 L .39727 .27738 L 0 .035 .136 r
F
.39433 .27837 m .39257 .27624 L .39552 .27524 L F
.06904 .27307 m .06972 .27001 L .07181 .27197 L 0 .024 .123 r
F
.06904 .27307 m .06694 .27112 L .06972 .27001 L F
.7946 .27435 m .79641 .2714 L .79777 .27333 L 0 .027 .126 r
F
.7946 .27435 m .79324 .27242 L .79641 .2714 L F
.721 .27588 m .72269 .27283 L .72413 .27478 L 0 .03 .13 r
F
.721 .27588 m .71957 .27392 L .72269 .27283 L F
.6827 .27806 m .68433 .27496 L .68579 .27683 L 0 .034 .135 r
F
.6827 .27806 m .68123 .27618 L .68433 .27496 L F
.50692 .48483 m .50536 .46699 L .5083 .47784 L .38 .67 0 r
F
.46956 .28212 m .47087 .27863 L .47255 .28093 L 0 .043 .145 r
F
.46956 .28212 m .46788 .27979 L .47087 .27863 L F
.744 .27471 m .74573 .27181 L .74714 .27369 L 0 .028 .127 r
F
.744 .27471 m .74259 .27283 L .74573 .27181 L F
.27613 .27473 m .27712 .27181 L .27901 .27375 L F
.27613 .27473 m .27424 .2728 L .27712 .27181 L F
.11964 .27303 m .12039 .26996 L .12243 .27194 L 0 .024 .123 r
F
.11964 .27303 m .11759 .27105 L .12039 .26996 L F
.55547 .2826 m .5569 .27934 L .5585 .28139 L 0 .044 .147 r
F
.55547 .2826 m .55387 .28055 L .5569 .27934 L F
.07668 .27283 m .07736 .26979 L .07945 .27177 L 0 .024 .122 r
F
.07668 .27283 m .07459 .27086 L .07736 .26979 L F
.19788 .27391 m .19875 .27088 L .20072 .27282 L 0 .026 .125 r
F
.19788 .27391 m .19591 .27196 L .19875 .27088 L F
.72868 .27562 m .73038 .27263 L .7318 .27454 L 0 .03 .13 r
F
.72868 .27562 m .72725 .27371 L .73038 .27263 L F
.73634 .27524 m .73805 .27213 L .73946 .27401 L 0 .029 .128 r
F
.73634 .27524 m .73493 .27335 L .73805 .27213 L F
.56313 .28228 m .56457 .27903 L .56617 .28112 L 0 .044 .146 r
F
.56313 .28228 m .56154 .28019 L .56457 .27903 L F
.16258 .27335 m .16338 .27042 L .16539 .27234 L 0 .025 .124 r
F
.16258 .27335 m .16057 .27141 L .16338 .27042 L F
.40198 .27825 m .40317 .27519 L .40493 .27714 L 0 .035 .136 r
F
.40198 .27825 m .40022 .27628 L .40317 .27519 L F
.54781 .28314 m .54923 .2797 L .55084 .28177 L 0 .045 .148 r
F
.54781 .28314 m .5462 .28108 L .54923 .2797 L F
.24083 .27422 m .24177 .2712 L .24369 .27314 L 0 .027 .126 r
F
.24083 .27422 m .23891 .27226 L .24177 .2712 L F
.37435 .2772 m .37549 .27428 L .37728 .27621 L 0 .033 .134 r
F
.37435 .2772 m .37256 .27528 L .37549 .27428 L F
.57846 .2815 m .57992 .27812 L .5815 .28017 L 0 .042 .144 r
F
.57846 .2815 m .57688 .27943 L .57992 .27812 L F
.12727 .27279 m .12803 .26977 L .13007 .27172 L 0 .024 .123 r
F
.12727 .27279 m .12523 .27083 L .12803 .26977 L F
.34671 .27621 m .34782 .27311 L .34963 .27513 L 0 .031 .131 r
F
.34671 .27621 m .3449 .27417 L .34782 .27311 L F
.53279 .47893 m .53412 .44751 L .53578 .46182 L .216 .619 0 r
F
.53279 .47893 m .53113 .46287 L .53412 .44751 L F
.40964 .27793 m .41085 .27484 L .4126 .27677 L 0 .034 .135 r
F
.40964 .27793 m .40789 .276 L .41085 .27484 L F
.75168 .27455 m .75342 .27157 L .75482 .27346 L 0 .028 .127 r
F
.75168 .27455 m .75028 .27267 L .75342 .27157 L F
.54015 .28369 m .54155 .28023 L .54317 .28245 L 0 .047 .149 r
F
.54015 .28369 m .53853 .28147 L .54155 .28023 L F
.8023 .27435 m .80411 .27122 L .80547 .27326 L 0 .027 .126 r
F
.8023 .27435 m .80094 .2723 L .80411 .27122 L F
.31141 .27563 m .31246 .27263 L .3143 .27466 L 0 .03 .13 r
F
.31141 .27563 m .30956 .27361 L .31246 .27263 L F
.47722 .28202 m .47853 .27859 L .48021 .28086 L 0 .043 .145 r
F
.47722 .28202 m .47554 .27973 L .47853 .27859 L F
.24848 .27395 m .24943 .27089 L .25135 .27282 L 0 .026 .126 r
F
.24848 .27395 m .24656 .27202 L .24943 .27089 L F
.49719 .28353 m .49853 .28043 L .50019 .28257 L 0 .047 .15 r
F
.49719 .28353 m .49553 .2814 L .49853 .28043 L F
.5708 .28204 m .57225 .2787 L .57384 .28076 L 0 .043 .145 r
F
.5708 .28204 m .56921 .27996 L .57225 .2787 L F
.58612 .2812 m .5876 .27791 L .58917 .28001 L 0 .041 .143 r
F
.58612 .2812 m .58455 .27904 L .5876 .27791 L F
.20551 .27378 m .20639 .27083 L .20835 .27279 L 0 .026 .125 r
F
.20551 .27378 m .20355 .27183 L .20639 .27083 L F
.08429 .27273 m .08498 .26973 L .08706 .27172 L 0 .024 .123 r
F
.08429 .27273 m .08221 .27075 L .08498 .26973 L F
.42961 .27954 m .43085 .27637 L .43257 .27861 L 0 .038 .14 r
F
.42961 .27954 m .42789 .27729 L .43085 .27637 L F
.75935 .27428 m .7611 .27117 L .76249 .27314 L 0 .027 .126 r
F
.75935 .27428 m .75795 .27231 L .7611 .27117 L F
.54417 .49128 m .54263 .50296 L .54556 .48427 L .38 .67 0 r
F
.54122 .50822 m .54263 .50296 L .54417 .49128 L .623 .734 0 r
F
.28376 .27471 m .28476 .27185 L .28664 .27378 L 0 .028 .128 r
F
.28376 .27471 m .28188 .27277 L .28476 .27185 L F
.1702 .27323 m .17102 .27029 L .17302 .27219 L 0 .025 .124 r
F
.1702 .27323 m .1682 .27134 L .17102 .27029 L F
.59379 .28089 m .59528 .27774 L .59684 .27976 L 0 .041 .143 r
F
.59379 .28089 m .59222 .27885 L .59528 .27774 L F
.60911 .28005 m .61062 .2765 L .61217 .27868 L 0 .038 .14 r
F
.60911 .28005 m .60756 .27787 L .61062 .2765 L F
.61678 .27965 m .61829 .27628 L .61984 .27843 L F
.61678 .27965 m .61523 .27748 L .61829 .27628 L F
.35436 .27604 m .35547 .27306 L .35728 .27505 L 0 .031 .131 r
F
.35436 .27604 m .35255 .27405 L .35547 .27306 L F
.41729 .27774 m .41851 .2747 L .42025 .27684 L 0 .034 .135 r
F
.41729 .27774 m .41556 .27561 L .41851 .2747 L F
.64743 .27797 m .64901 .27495 L .65051 .2769 L 0 .035 .136 r
F
.64743 .27797 m .64592 .27605 L .64901 .27495 L F
.80998 .27415 m .8118 .27097 L .81315 .27299 L 0 .027 .126 r
F
.80998 .27415 m .80863 .27212 L .8118 .27097 L F
.1349 .27267 m .13566 .26975 L .13769 .27168 L 0 .025 .123 r
F
.1349 .27267 m .13286 .27074 L .13566 .26975 L F
.63977 .27842 m .64132 .27509 L .64284 .27715 L 0 .035 .137 r
F
.63977 .27842 m .63825 .27635 L .64132 .27509 L F
.45724 .28079 m .45853 .27734 L .46022 .27973 L 0 .04 .142 r
F
.45724 .28079 m .45555 .2784 L .45853 .27734 L F
.38199 .27719 m .38316 .27399 L .38493 .2761 L 0 .033 .134 r
F
.38199 .27719 m .38022 .2751 L .38316 .27399 L F
.52018 .28251 m .52155 .27919 L .52319 .28136 L 0 .045 .147 r
F
.52018 .28251 m .51854 .28032 L .52155 .27919 L F
.25611 .27381 m .25707 .27089 L .25897 .27287 L 0 .027 .126 r
F
.25611 .27381 m .25421 .27185 L .25707 .27089 L F
.62444 .27935 m .62597 .27597 L .62751 .27813 L 0 .037 .139 r
F
.62444 .27935 m .6229 .2772 L .62597 .27597 L F
.6551 .27768 m .65668 .27446 L .65818 .27648 L 0 .034 .135 r
F
.6551 .27768 m .65359 .2757 L .65668 .27446 L F
.31905 .27556 m .32011 .27247 L .32196 .27444 L 0 .03 .13 r
F
.31905 .27556 m .31721 .27356 L .32011 .27247 L F
.60146 .28068 m .60295 .27725 L .60451 .2793 L 0 .04 .142 r
F
.60146 .28068 m .5999 .27862 L .60295 .27725 L F
.09191 .27262 m .09262 .26958 L .09469 .27153 L 0 .024 .123 r
F
.09191 .27262 m .08984 .27065 L .09262 .26958 L F
.66276 .27731 m .66436 .27416 L .66585 .27619 L 0 .034 .135 r
F
.66276 .27731 m .66127 .2753 L .66436 .27416 L F
.17784 .27307 m .17867 .27011 L .18066 .27205 L 0 .025 .124 r
F
.17784 .27307 m .17585 .27114 L .17867 .27011 L F
.50485 .28349 m .50621 .27993 L .50786 .28213 L 0 .047 .149 r
F
.50485 .28349 m .5032 .28125 L .50621 .27993 L F
.76704 .27414 m .7688 .27115 L .77019 .27314 L 0 .027 .127 r
F
.76704 .27414 m .76564 .27214 L .7688 .27115 L F
.21314 .27372 m .21404 .27066 L .21599 .27261 L 0 .027 .126 r
F
.21314 .27372 m .21119 .27176 L .21404 .27066 L F
.51251 .28308 m .51388 .27946 L .51552 .2817 L 0 .046 .148 r
F
.51251 .28308 m .51087 .28079 L .51388 .27946 L F
.81767 .27397 m .81951 .27097 L .82085 .27295 L 0 .027 .126 r
F
.81767 .27397 m .81633 .27197 L .81951 .27097 L F
.63211 .27907 m .63365 .27556 L .63518 .27771 L 0 .037 .138 r
F
.63211 .27907 m .63058 .2769 L .63365 .27556 L F
.5154 .51141 m .51671 .53346 L .51838 .52805 L .774 .758 0 r
F
.5154 .51141 m .51374 .51607 L .51671 .53346 L F
.3267 .27526 m .32778 .27218 L .32961 .27415 L 0 .03 .13 r
F
.3267 .27526 m .32487 .27331 L .32778 .27218 L F
.14252 .27257 m .1433 .26954 L .14533 .27149 L 0 .025 .123 r
F
.14252 .27257 m .14049 .27062 L .1433 .26954 L F
.09955 .27237 m .10027 .26934 L .10234 .27128 L 0 .024 .123 r
F
.09955 .27237 m .09748 .27044 L .10027 .26934 L F
.48487 .28216 m .4862 .27892 L .48787 .28122 L 0 .045 .147 r
F
.48487 .28216 m .4832 .27989 L .4862 .27892 L F
.22079 .27347 m .2217 .27039 L .22364 .27239 L 0 .026 .125 r
F
.22079 .27347 m .21884 .2715 L .2217 .27039 L F
.43726 .27965 m .4385 .27657 L .44022 .27856 L 0 .039 .141 r
F
.43726 .27965 m .43553 .27767 L .4385 .27657 L F
.29139 .27476 m .2924 .27183 L .29428 .27376 L 0 .029 .129 r
F
.29139 .27476 m .28952 .27284 L .2924 .27183 L F
.67044 .27711 m .67205 .27401 L .67354 .27606 L 0 .034 .134 r
F
.67044 .27711 m .66895 .27508 L .67205 .27401 L F
.362 .27607 m .36312 .27319 L .36492 .27515 L 0 .032 .132 r
F
.362 .27607 m .3602 .27412 L .36312 .27319 L F
.33435 .27504 m .33544 .27208 L .33726 .27409 L 0 .03 .13 r
F
.33435 .27504 m .33253 .27304 L .33544 .27208 L F
.83302 .27335 m .83488 .27029 L .8362 .27222 L 0 .026 .125 r
F
.83302 .27335 m .8317 .27142 L .83488 .27029 L F
.52784 .28251 m .52923 .27922 L .53086 .28144 L 0 .045 .148 r
F
.52784 .28251 m .52621 .2803 L .52923 .27922 L F
.54397 .48816 m .54238 .49208 L .5453 .47108 L .329 .655 0 r
F
.54238 .49208 m .54369 .4693 L .5453 .47108 L .363 .665 0 r
F
.38963 .27723 m .39081 .27406 L .39257 .27624 L 0 .034 .135 r
F
.38963 .27723 m .38787 .27507 L .39081 .27406 L F
.15016 .27235 m .15094 .26941 L .15296 .27138 L 0 .025 .123 r
F
.15016 .27235 m .14814 .2704 L .15094 .26941 L F
.82536 .27385 m .8272 .27069 L .82853 .27263 L 0 .027 .126 r
F
.82536 .27385 m .82403 .27189 L .8272 .27069 L F
.77473 .27408 m .7765 .27105 L .77788 .273 L 0 .028 .127 r
F
.77473 .27408 m .77335 .27211 L .7765 .27105 L F
.10718 .27218 m .10792 .26913 L .10997 .27113 L 0 .024 .122 r
F
.10718 .27218 m .10513 .27019 L .10792 .26913 L F
.26374 .27389 m .26471 .27089 L .2666 .27287 L 0 .027 .127 r
F
.26374 .27389 m .26184 .27191 L .26471 .27089 L F
.18546 .27305 m .1863 .27013 L .18828 .2721 L 0 .026 .125 r
F
.18546 .27305 m .18348 .27109 L .1863 .27013 L F
.44491 .27944 m .44618 .2763 L .44789 .27834 L 0 .039 .141 r
F
.44491 .27944 m .4432 .27743 L .44618 .2763 L F
.46489 .28096 m .46619 .27749 L .46788 .27979 L 0 .042 .144 r
F
.46489 .28096 m .4632 .27861 L .46619 .27749 L F
.29903 .27461 m .30007 .27155 L .30193 .27354 L 0 .029 .129 r
F
.29903 .27461 m .29717 .27265 L .30007 .27155 L F
.22842 .27334 m .22935 .27025 L .23127 .27231 L 0 .026 .125 r
F
.22842 .27334 m .22649 .27132 L .22935 .27025 L F
.54263 .50296 m .54397 .48816 L .54556 .48427 L .51 .705 0 r
F
.5391 .48284 m .5404 .456 L .54205 .46265 L .263 .634 0 r
F
.5391 .48284 m .53745 .47539 L .5404 .456 L F
.84071 .27318 m .84258 .27006 L .8439 .27212 L 0 .026 .125 r
F
.84071 .27318 m .83939 .27114 L .84258 .27006 L F
.78241 .27384 m .7842 .27083 L .78556 .27274 L 0 .027 .127 r
F
.78241 .27384 m .78104 .27192 L .7842 .27083 L F
.69345 .27621 m .6951 .27327 L .69656 .27514 L 0 .032 .133 r
F
.69345 .27621 m .69199 .27435 L .6951 .27327 L F
.70878 .27542 m .71045 .2723 L .71189 .27421 L 0 .031 .131 r
F
.70878 .27542 m .70734 .27353 L .71045 .2723 L F
.42493 .2782 m .42616 .27503 L .42789 .27729 L 0 .036 .138 r
F
.42493 .2782 m .4232 .27594 L .42616 .27503 L F
.79008 .27353 m .79189 .27053 L .79324 .27242 L 0 .027 .126 r
F
.79008 .27353 m .78872 .27163 L .79189 .27053 L F
.71645 .27502 m .71813 .27194 L .71957 .27392 L 0 .03 .13 r
F
.71645 .27502 m .71501 .27308 L .71813 .27194 L F
.67812 .27715 m .67975 .27407 L .68123 .27618 L 0 .034 .135 r
F
.67812 .27715 m .67664 .27507 L .67975 .27407 L F
.1148 .27209 m .11554 .26906 L .11759 .27105 L 0 .024 .123 r
F
.1148 .27209 m .11275 .2701 L .11554 .26906 L F
.27137 .2738 m .27235 .27084 L .27424 .2728 L 0 .028 .127 r
F
.27137 .2738 m .26948 .27185 L .27235 .27084 L F
.70112 .27594 m .70278 .27287 L .70423 .27476 L 0 .032 .132 r
F
.70112 .27594 m .69967 .27406 L .70278 .27287 L F
.36963 .27618 m .37077 .27335 L .37256 .27528 L 0 .033 .134 r
F
.36963 .27618 m .36784 .27425 L .37077 .27335 L F
.53551 .28257 m .5369 .27918 L .53853 .28147 L 0 .046 .149 r
F
.53551 .28257 m .53388 .28031 L .5369 .27918 L F
.68579 .27683 m .68743 .2737 L .68889 .27557 L 0 .034 .135 r
F
.68579 .27683 m .68433 .27496 L .68743 .2737 L F
.49253 .28237 m .49386 .27927 L .49553 .2814 L 0 .046 .149 r
F
.49253 .28237 m .49086 .28025 L .49386 .27927 L F
.15777 .27238 m .15857 .26943 L .16057 .27141 L 0 .025 .124 r
F
.15777 .27238 m .15576 .2704 L .15857 .26943 L F
.34199 .27515 m .34308 .27217 L .3449 .27417 L 0 .03 .131 r
F
.34199 .27515 m .34017 .27314 L .34308 .27217 L F
.07181 .27197 m .0725 .26889 L .07459 .27086 L 0 .024 .122 r
F
.07181 .27197 m .06972 .27001 L .0725 .26889 L F
.19308 .27304 m .19395 .26996 L .19591 .27196 L 0 .026 .125 r
F
.19308 .27304 m .19111 .27106 L .19395 .26996 L F
.55084 .28177 m .55226 .27849 L .55387 .28055 L 0 .044 .147 r
F
.55084 .28177 m .54923 .2797 L .55226 .27849 L F
.47255 .28093 m .47386 .27746 L .47554 .27973 L 0 .042 .144 r
F
.47255 .28093 m .47087 .27863 L .47386 .27746 L F
.45257 .27944 m .45384 .27618 L .45555 .2784 L 0 .039 .141 r
F
.45257 .27944 m .45086 .27726 L .45384 .27618 L F
.30667 .27456 m .30771 .27156 L .30956 .27361 L 0 .029 .129 r
F
.30667 .27456 m .30482 .27254 L .30771 .27156 L F
.23605 .27329 m .23698 .27029 L .23891 .27226 L 0 .027 .126 r
F
.23605 .27329 m .23412 .2713 L .23698 .27029 L F
.72413 .27478 m .72582 .27176 L .72725 .27371 L 0 .03 .13 r
F
.72413 .27478 m .72269 .27283 L .72582 .27176 L F
.5585 .28139 m .55994 .27812 L .56154 .28019 L 0 .044 .146 r
F
.5585 .28139 m .5569 .27934 L .55994 .27812 L F
.79777 .27333 m .79959 .27037 L .80094 .2723 L 0 .027 .126 r
F
.79777 .27333 m .79641 .2714 L .79959 .27037 L F
.39727 .27738 m .39847 .27418 L .40022 .27628 L 0 .035 .136 r
F
.39727 .27738 m .39552 .27524 L .39847 .27418 L F
.5815 .28017 m .58297 .27704 L .58455 .27904 L 0 .041 .143 r
F
.5815 .28017 m .57992 .27812 L .58297 .27704 L F
.73946 .27401 m .74118 .27095 L .74259 .27283 L 0 .028 .128 r
F
.73946 .27401 m .73805 .27213 L .74118 .27095 L F
.12243 .27194 m .12319 .26885 L .12523 .27083 L 0 .024 .123 r
F
.12243 .27194 m .12039 .26996 L .12319 .26885 L F
.52005 .51475 m .52139 .5437 L .52306 .52885 L .796 .703 0 r
F
.52005 .51475 m .51838 .52805 L .52139 .5437 L F
.52811 .47817 m .52947 .44673 L .53113 .46287 L .217 .619 0 r
F
.52811 .47817 m .52646 .46029 L .52947 .44673 L F
.20072 .27282 m .20159 .26987 L .20355 .27183 L 0 .026 .125 r
F
.20072 .27282 m .19875 .27088 L .20159 .26987 L F
.56617 .28112 m .56762 .27786 L .56921 .27996 L 0 .043 .146 r
F
.56617 .28112 m .56457 .27903 L .56762 .27786 L F
.07945 .27177 m .08013 .26875 L .08221 .27075 L 0 .024 .122 r
F
.07945 .27177 m .07736 .26979 L .08013 .26875 L F
.7318 .27454 m .73351 .27145 L .73493 .27335 L 0 .029 .129 r
F
.7318 .27454 m .73038 .27263 L .73351 .27145 L F
.74714 .27369 m .74888 .27079 L .75028 .27267 L 0 .028 .128 r
F
.74714 .27369 m .74573 .27181 L .74888 .27079 L F
.40493 .27714 m .40613 .27406 L .40789 .276 L 0 .035 .136 r
F
.40493 .27714 m .40317 .27519 L .40613 .27406 L F
.54317 .28245 m .54458 .27886 L .5462 .28108 L 0 .046 .148 r
F
.54317 .28245 m .54155 .28023 L .54458 .27886 L F
.57384 .28076 m .57529 .27738 L .57688 .27943 L 0 .042 .145 r
F
.57384 .28076 m .57225 .2787 L .57529 .27738 L F
.27901 .27375 m .28 .27083 L .28188 .27277 L 0 .028 .128 r
F
.27901 .27375 m .27712 .27181 L .28 .27083 L F
.24369 .27314 m .24464 .27008 L .24656 .27202 L 0 .027 .126 r
F
.24369 .27314 m .24177 .2712 L .24464 .27008 L F
.4126 .27677 m .41381 .27368 L .41556 .27561 L 0 .034 .135 r
F
.4126 .27677 m .41085 .27484 L .41381 .27368 L F
.61217 .27868 m .61368 .27531 L .61523 .27748 L 0 .038 .139 r
F
.61217 .27868 m .61062 .2765 L .61368 .27531 L F
.16539 .27234 m .1662 .26944 L .1682 .27134 L 0 .026 .124 r
F
.16539 .27234 m .16338 .27042 L .1662 .26944 L F
.58917 .28001 m .59065 .27681 L .59222 .27885 L 0 .041 .143 r
F
.58917 .28001 m .5876 .27791 L .59065 .27681 L F
.13007 .27172 m .13082 .2688 L .13286 .27074 L 0 .024 .123 r
F
.13007 .27172 m .12803 .26977 L .13082 .2688 L F
.48021 .28086 m .48153 .27759 L .4832 .27989 L 0 .043 .145 r
F
.48021 .28086 m .47853 .27859 L .48153 .27759 L F
.34963 .27513 m .35074 .27206 L .35255 .27405 L 0 .031 .131 r
F
.34963 .27513 m .34782 .27311 L .35074 .27206 L F
.37728 .27621 m .37843 .27314 L .38022 .2751 L 0 .033 .134 r
F
.37728 .27621 m .37549 .27428 L .37843 .27314 L F
.75482 .27346 m .75656 .27041 L .75795 .27231 L 0 .028 .127 r
F
.75482 .27346 m .75342 .27157 L .75656 .27041 L F
.25135 .27282 m .25229 .26992 L .25421 .27185 L 0 .027 .126 r
F
.25135 .27282 m .24943 .27089 L .25229 .26992 L F
.80547 .27326 m .80728 .27008 L .80863 .27212 L F
.80547 .27326 m .80411 .27122 L .80728 .27008 L F
.64284 .27715 m .6444 .274 L .64592 .27605 L 0 .035 .136 r
F
.64284 .27715 m .64132 .27509 L .6444 .274 L F
.61984 .27843 m .62136 .27506 L .6229 .2772 L 0 .037 .139 r
F
.61984 .27843 m .61829 .27628 L .62136 .27506 L F
.60451 .2793 m .606 .27583 L .60756 .27787 L 0 .039 .141 r
F
.60451 .2793 m .60295 .27725 L .606 .27583 L F
.76249 .27314 m .76425 .27017 L .76564 .27214 L 0 .027 .126 r
F
.76249 .27314 m .7611 .27117 L .76425 .27017 L F
.59684 .27976 m .59834 .27663 L .5999 .27862 L 0 .041 .143 r
F
.59684 .27976 m .59528 .27774 L .59834 .27663 L F
.3143 .27466 m .31536 .27156 L .31721 .27356 L 0 .03 .13 r
F
.3143 .27466 m .31246 .27263 L .31536 .27156 L F
.51552 .2817 m .51689 .27814 L .51854 .28032 L 0 .045 .147 r
F
.51552 .2817 m .51388 .27946 L .51689 .27814 L F
.50786 .28213 m .50922 .27862 L .51087 .28079 L 0 .046 .148 r
F
.50786 .28213 m .50621 .27993 L .50922 .27862 L F
.81315 .27299 m .81498 .26996 L .81633 .27197 L 0 .027 .126 r
F
.81315 .27299 m .8118 .27097 L .81498 .26996 L F
.08706 .27172 m .08776 .26867 L .08984 .27065 L 0 .024 .123 r
F
.08706 .27172 m .08498 .26973 L .08776 .26867 L F
.50019 .28257 m .50154 .27915 L .5032 .28125 L 0 .047 .149 r
F
.50019 .28257 m .49853 .28043 L .50154 .27915 L F
.20835 .27279 m .20923 .26981 L .21119 .27176 L 0 .027 .126 r
F
.20835 .27279 m .20639 .27083 L .20923 .26981 L F
.62751 .27813 m .62904 .27474 L .63058 .2769 L 0 .037 .138 r
F
.62751 .27813 m .62597 .27597 L .62904 .27474 L F
.63518 .27771 m .63672 .27422 L .63825 .27635 L 0 .036 .137 r
F
.63518 .27771 m .63365 .27556 L .63672 .27422 L F
.17302 .27219 m .17385 .26923 L .17585 .27114 L 0 .026 .124 r
F
.17302 .27219 m .17102 .27029 L .17385 .26923 L F
.65051 .2769 m .65209 .27372 L .65359 .2757 L 0 .035 .136 r
F
.65051 .2769 m .64901 .27495 L .65209 .27372 L F
.52319 .28136 m .52457 .27813 L .52621 .2803 L 0 .045 .147 r
F
.52319 .28136 m .52155 .27919 L .52457 .27813 L F
.43257 .27861 m .43381 .27544 L .43553 .27767 L 0 .038 .14 r
F
.43257 .27861 m .43085 .27637 L .43381 .27544 L F
.65818 .27648 m .65976 .27324 L .66127 .2753 L 0 .034 .135 r
F
.65818 .27648 m .65668 .27446 L .65976 .27324 L F
.38493 .2761 m .3861 .27294 L .38787 .27507 L 0 .033 .134 r
F
.38493 .2761 m .38316 .27399 L .3861 .27294 L F
.35728 .27505 m .35839 .27212 L .3602 .27412 L 0 .031 .132 r
F
.35728 .27505 m .35547 .27306 L .35839 .27212 L F
.28664 .27378 m .28764 .27093 L .28952 .27284 L 0 .029 .129 r
F
.28664 .27378 m .28476 .27185 L .28764 .27093 L F
.46022 .27973 m .46151 .27627 L .4632 .27861 L 0 .04 .142 r
F
.46022 .27973 m .45853 .27734 L .46151 .27627 L F
.32196 .27444 m .32303 .27136 L .32487 .27331 L 0 .03 .13 r
F
.32196 .27444 m .32011 .27247 L .32303 .27136 L F
.13769 .27168 m .13846 .26871 L .14049 .27062 L 0 .025 .123 r
F
.13769 .27168 m .13566 .26975 L .13846 .26871 L F
.66585 .27619 m .66745 .27302 L .66895 .27508 L 0 .033 .134 r
F
.66585 .27619 m .66436 .27416 L .66745 .27302 L F
.42025 .27684 m .42147 .27379 L .4232 .27594 L 0 .035 .136 r
F
.42025 .27684 m .41851 .2747 L .42147 .27379 L F
.09469 .27153 m .09541 .2685 L .09748 .27044 L 0 .024 .123 r
F
.09469 .27153 m .09262 .26958 L .09541 .2685 L F
.21599 .27261 m .21689 .26955 L .21884 .2715 L 0 .026 .125 r
F
.21599 .27261 m .21404 .27066 L .21689 .26955 L F
.25897 .27287 m .25993 .26992 L .26184 .27191 L 0 .027 .126 r
F
.25897 .27287 m .25707 .27089 L .25993 .26992 L F
.32961 .27415 m .3307 .27104 L .33253 .27304 L 0 .029 .129 r
F
.32961 .27415 m .32778 .27218 L .3307 .27104 L F
.18066 .27205 m .18149 .26914 L .18348 .27109 L 0 .026 .124 r
F
.18066 .27205 m .17867 .27011 L .18149 .26914 L F
.77019 .27314 m .77196 .27014 L .77335 .27211 L 0 .028 .127 r
F
.77019 .27314 m .7688 .27115 L .77196 .27014 L F
.82085 .27295 m .8227 .26992 L .82403 .27189 L 0 .027 .127 r
F
.82085 .27295 m .81951 .27097 L .8227 .26992 L F
.50748 .50074 m .50877 .51084 L .5104 .51902 L .599 .728 0 r
F
.14533 .27149 m .14612 .26846 L .14814 .2704 L 0 .025 .123 r
F
.14533 .27149 m .1433 .26954 L .14612 .26846 L F
.10234 .27128 m .10306 .26824 L .10513 .27019 L 0 .024 .122 r
F
.10234 .27128 m .10027 .26934 L .10306 .26824 L F
.22364 .27239 m .22456 .26929 L .22649 .27132 L 0 .026 .125 r
F
.22364 .27239 m .2217 .27039 L .22456 .26929 L F
.44022 .27856 m .44148 .27541 L .4432 .27743 L 0 .039 .141 r
F
.44022 .27856 m .4385 .27657 L .44148 .27541 L F
.82853 .27263 m .83038 .26948 L .8317 .27142 L 0 .027 .126 r
F
.82853 .27263 m .8272 .27069 L .83038 .26948 L F
.8362 .27222 m .83808 .26923 L .83939 .27114 L 0 .026 .125 r
F
.8362 .27222 m .83488 .27029 L .83808 .26923 L F
.67354 .27606 m .67515 .27298 L .67664 .27507 L 0 .034 .135 r
F
.67354 .27606 m .67205 .27401 L .67515 .27298 L F
.29428 .27376 m .2953 .27069 L .29717 .27265 L 0 .029 .129 r
F
.29428 .27376 m .2924 .27183 L .2953 .27069 L F
.48787 .28122 m .4892 .27792 L .49086 .28025 L 0 .045 .147 r
F
.48787 .28122 m .4862 .27892 L .4892 .27792 L F
.54076 .49031 m .54205 .46265 L .54369 .4693 L .329 .654 0 r
F
.54076 .49031 m .5391 .48284 L .54205 .46265 L F
.53086 .28144 m .53225 .27806 L .53388 .28031 L 0 .045 .148 r
F
.53086 .28144 m .52923 .27922 L .53225 .27806 L F
.46788 .27979 m .46918 .27637 L .47087 .27863 L 0 .041 .143 r
F
.46788 .27979 m .46619 .27749 L .46918 .27637 L F
.77788 .273 m .77967 .26999 L .78104 .27192 L 0 .028 .127 r
F
.77788 .273 m .7765 .27105 L .77967 .26999 L F
.44789 .27834 m .44916 .27518 L .45086 .27726 L 0 .039 .14 r
F
.44789 .27834 m .44618 .2763 L .44916 .27518 L F
.36492 .27515 m .36604 .27229 L .36784 .27425 L 0 .032 .133 r
F
.36492 .27515 m .36312 .27319 L .36604 .27229 L F
.33726 .27409 m .33835 .27114 L .34017 .27314 L 0 .03 .13 r
F
.33726 .27409 m .33544 .27208 L .33835 .27114 L F
.10997 .27113 m .1107 .2681 L .11275 .2701 L 0 .024 .122 r
F
.10997 .27113 m .10792 .26913 L .1107 .2681 L F
.39257 .27624 m .39376 .27304 L .39552 .27524 L 0 .034 .135 r
F
.39257 .27624 m .39081 .27406 L .39376 .27304 L F
.15296 .27138 m .15375 .26842 L .15576 .2704 L 0 .025 .123 r
F
.15296 .27138 m .15094 .26941 L .15375 .26842 L F
.2666 .27287 m .26758 .26988 L .26948 .27185 L 0 .028 .127 r
F
.2666 .27287 m .26471 .27089 L .26758 .26988 L F
.30193 .27354 m .30296 .27051 L .30482 .27254 L 0 .029 .129 r
F
.30193 .27354 m .30007 .27155 L .30296 .27051 L F
.71189 .27421 m .71357 .27113 L .71501 .27308 L 0 .03 .13 r
F
.71189 .27421 m .71045 .2723 L .71357 .27113 L F
.23127 .27231 m .2322 .26925 L .23412 .2713 L 0 .026 .126 r
F
.23127 .27231 m .22935 .27025 L .2322 .26925 L F
.18828 .2721 m .18913 .26907 L .19111 .27106 L 0 .026 .125 r
F
.18828 .2721 m .1863 .27013 L .18913 .26907 L F
.78556 .27274 m .78736 .26973 L .78872 .27163 L 0 .027 .127 r
F
.78556 .27274 m .7842 .27083 L .78736 .26973 L F
.69656 .27514 m .69822 .27218 L .69967 .27406 L 0 .032 .133 r
F
.69656 .27514 m .6951 .27327 L .69822 .27218 L F
.68889 .27557 m .69053 .27249 L .69199 .27435 L 0 .033 .134 r
F
.68889 .27557 m .68743 .2737 L .69053 .27249 L F
.06694 .27112 m .06762 .26806 L .06972 .27001 L 0 .024 .123 r
F
.06694 .27112 m .06484 .26918 L .06762 .26806 L F
.70423 .27476 m .70589 .27161 L .70734 .27353 L 0 .031 .132 r
F
.70423 .27476 m .70278 .27287 L .70589 .27161 L F
.79324 .27242 m .79506 .26951 L .79641 .2714 L 0 .027 .126 r
F
.79324 .27242 m .79189 .27053 L .79506 .26951 L F
.71957 .27392 m .72126 .27083 L .72269 .27283 L 0 .03 .13 r
F
.71957 .27392 m .71813 .27194 L .72126 .27083 L F
.55387 .28055 m .55529 .27728 L .5569 .27934 L 0 .044 .146 r
F
.55387 .28055 m .55226 .27849 L .55529 .27728 L F
.47554 .27973 m .47685 .27633 L .47853 .27859 L 0 .042 .144 r
F
.47554 .27973 m .47386 .27746 L .47685 .27633 L F
.56154 .28019 m .56298 .27691 L .56457 .27903 L 0 .043 .145 r
F
.56154 .28019 m .55994 .27812 L .56298 .27691 L F
.53853 .28147 m .53993 .27793 L .54155 .28023 L 0 .046 .148 r
F
.53853 .28147 m .5369 .27918 L .53993 .27793 L F
.11759 .27105 m .11835 .26796 L .12039 .26996 L 0 .024 .123 r
F
.11759 .27105 m .11554 .26906 L .11835 .26796 L F
.68123 .27618 m .68285 .27284 L .68433 .27496 L 0 .034 .135 r
F
.68123 .27618 m .67975 .27407 L .68285 .27284 L F
.07459 .27086 m .07527 .2678 L .07736 .26979 L 0 .024 .122 r
F
.07459 .27086 m .0725 .26889 L .07527 .2678 L F
.5462 .28108 m .54761 .2775 L .54923 .2797 L 0 .045 .147 r
F
.5462 .28108 m .54458 .27886 L .54761 .2775 L F
.27424 .2728 m .27523 .26984 L .27712 .27181 L 0 .028 .127 r
F
.27424 .2728 m .27235 .27084 L .27523 .26984 L F
.19591 .27196 m .19679 .26886 L .19875 .27088 L 0 .026 .125 r
F
.19591 .27196 m .19395 .26996 L .19679 .26886 L F
.42789 .27729 m .42912 .27412 L .43085 .27637 L 0 .037 .138 r
F
.42789 .27729 m .42616 .27503 L .42912 .27412 L F
.74259 .27283 m .74433 .26993 L .74573 .27181 L 0 .028 .128 r
F
.74259 .27283 m .74118 .27095 L .74433 .26993 L F
.57688 .27943 m .57834 .27609 L .57992 .27812 L 0 .041 .143 r
F
.57688 .27943 m .57529 .27738 L .57834 .27609 L F
.72725 .27371 m .72896 .27069 L .73038 .27263 L 0 .03 .13 r
F
.72725 .27371 m .72582 .27176 L .72896 .27069 L F
.58455 .27904 m .58602 .27595 L .5876 .27791 L 0 .041 .143 r
F
.58455 .27904 m .58297 .27704 L .58602 .27595 L F
.45555 .2784 m .45683 .27512 L .45853 .27734 L 0 .039 .141 r
F
.45555 .2784 m .45384 .27618 L .45683 .27512 L F
.40022 .27628 m .40142 .27311 L .40317 .27519 L 0 .035 .136 r
F
.40022 .27628 m .39847 .27418 L .40142 .27311 L F
.3449 .27417 m .346 .27113 L .34782 .27311 L 0 .031 .131 r
F
.3449 .27417 m .34308 .27217 L .346 .27113 L F
.49553 .2814 m .49687 .27828 L .49853 .28043 L 0 .047 .149 r
F
.49553 .2814 m .49386 .27927 L .49687 .27828 L F
.16057 .27141 m .16138 .26844 L .16338 .27042 L 0 .025 .124 r
F
.16057 .27141 m .15857 .26943 L .16138 .26844 L F
.23891 .27226 m .23984 .26924 L .24177 .2712 L 0 .027 .126 r
F
.23891 .27226 m .23698 .27029 L .23984 .26924 L F
.73493 .27335 m .73664 .27024 L .73805 .27213 L 0 .029 .129 r
F
.73493 .27335 m .73351 .27145 L .73664 .27024 L F
.80094 .2723 m .80276 .26929 L .80411 .27122 L 0 .027 .126 r
F
.80094 .2723 m .79959 .27037 L .80276 .26929 L F
.37256 .27528 m .3737 .27234 L .37549 .27428 L 0 .033 .134 r
F
.37256 .27528 m .37077 .27335 L .3737 .27234 L F
.56921 .27996 m .57066 .27659 L .57225 .2787 L 0 .043 .145 r
F
.56921 .27996 m .56762 .27786 L .57066 .27659 L F
.12523 .27083 m .12599 .26779 L .12803 .26977 L 0 .024 .123 r
F
.12523 .27083 m .12319 .26885 L .12599 .26779 L F
.30956 .27361 m .31061 .27057 L .31246 .27263 L 0 .03 .13 r
F
.30956 .27361 m .30771 .27156 L .31061 .27057 L F
.60756 .27787 m .60906 .27447 L .61062 .2765 L 0 .038 .14 r
F
.60756 .27787 m .606 .27583 L .60906 .27447 L F
.61523 .27748 m .61675 .27412 L .61829 .27628 L 0 .037 .139 r
F
.61523 .27748 m .61368 .27531 L .61675 .27412 L F
.40789 .276 m .40909 .27291 L .41085 .27484 L 0 .034 .136 r
F
.40789 .276 m .40613 .27406 L .40909 .27291 L F
.41556 .27561 m .41676 .27276 L .41851 .2747 L 0 .034 .135 r
F
.41556 .27561 m .41381 .27368 L .41676 .27276 L F
.24656 .27202 m .24751 .26897 L .24943 .27089 L 0 .027 .126 r
F
.24656 .27202 m .24464 .27008 L .24751 .26897 L F
.51854 .28032 m .51991 .27702 L .52155 .27919 L 0 .044 .146 r
F
.51854 .28032 m .51689 .27814 L .51991 .27702 L F
.08221 .27075 m .08291 .26771 L .08498 .26973 L 0 .024 .123 r
F
.08221 .27075 m .08013 .26875 L .08291 .26771 L F
.75028 .27267 m .75202 .26968 L .75342 .27157 L 0 .028 .128 r
F
.75028 .27267 m .74888 .27079 L .75202 .26968 L F
.20355 .27183 m .20443 .26887 L .20639 .27083 L 0 .026 .126 r
F
.20355 .27183 m .20159 .26987 L .20443 .26887 L F
.59222 .27885 m .59371 .27573 L .59528 .27774 L 0 .041 .143 r
F
.59222 .27885 m .59065 .27681 L .59371 .27573 L F
.51087 .28079 m .51223 .27735 L .51388 .27946 L 0 .045 .147 r
F
.51087 .28079 m .50922 .27862 L .51223 .27735 L F
.63825 .27635 m .6398 .27297 L .64132 .27509 L 0 .035 .136 r
F
.63825 .27635 m .63672 .27422 L .6398 .27297 L F
.6229 .2772 m .62443 .27384 L .62597 .27597 L 0 .037 .138 r
F
.6229 .2772 m .62136 .27506 L .62443 .27384 L F
.5032 .28125 m .50455 .27787 L .50621 .27993 L 0 .046 .148 r
F
.5032 .28125 m .50154 .27915 L .50455 .27787 L F
.75795 .27231 m .7597 .26925 L .7611 .27117 L 0 .027 .127 r
F
.75795 .27231 m .75656 .27041 L .7597 .26925 L F
.80863 .27212 m .81045 .26894 L .8118 .27097 L 0 .027 .126 r
F
.80863 .27212 m .80728 .27008 L .81045 .26894 L F
.38022 .2751 m .38138 .27201 L .38316 .27399 L 0 .033 .134 r
F
.38022 .2751 m .37843 .27314 L .38138 .27201 L F
.35255 .27405 m .35366 .27107 L .35547 .27306 L 0 .031 .131 r
F
.35255 .27405 m .35074 .27206 L .35366 .27107 L F
.28188 .27277 m .28287 .26992 L .28476 .27185 L 0 .029 .128 r
F
.28188 .27277 m .28 .27083 L .28287 .26992 L F
.1682 .27134 m .16902 .26838 L .17102 .27029 L 0 .026 .125 r
F
.1682 .27134 m .1662 .26944 L .16902 .26838 L F
.63058 .2769 m .63211 .27342 L .63365 .27556 L 0 .036 .138 r
F
.63058 .2769 m .62904 .27474 L .63211 .27342 L F
.64592 .27605 m .64749 .27291 L .64901 .27495 L 0 .035 .136 r
F
.64592 .27605 m .6444 .274 L .64749 .27291 L F
.13286 .27074 m .13362 .26782 L .13566 .26975 L 0 .025 .123 r
F
.13286 .27074 m .13082 .2688 L .13362 .26782 L F
.5999 .27862 m .60139 .27529 L .60295 .27725 L 0 .04 .142 r
F
.5999 .27862 m .59834 .27663 L .60139 .27529 L F
.4832 .27989 m .48452 .27658 L .4862 .27892 L 0 .043 .146 r
F
.4832 .27989 m .48153 .27759 L .48452 .27658 L F
.25421 .27185 m .25515 .26897 L .25707 .27089 L 0 .027 .126 r
F
.25421 .27185 m .25229 .26992 L .25515 .26897 L F
.31721 .27356 m .31827 .27049 L .32011 .27247 L 0 .03 .13 r
F
.31721 .27356 m .31536 .27156 L .31827 .27049 L F
.65359 .2757 m .65517 .27244 L .65668 .27446 L 0 .034 .135 r
F
.65359 .2757 m .65209 .27372 L .65517 .27244 L F
.66127 .2753 m .66286 .27208 L .66436 .27416 L 0 .033 .134 r
F
.66127 .2753 m .65976 .27324 L .66286 .27208 L F
.76564 .27214 m .76741 .26918 L .7688 .27115 L 0 .027 .127 r
F
.76564 .27214 m .76425 .27017 L .76741 .26918 L F
.08984 .27065 m .09054 .2676 L .09262 .26958 L 0 .024 .123 r
F
.08984 .27065 m .08776 .26867 L .09054 .2676 L F
.81633 .27197 m .81817 .26898 L .81951 .27097 L 0 .027 .126 r
F
.81633 .27197 m .81498 .26996 L .81817 .26898 L F
.21119 .27176 m .21208 .26872 L .21404 .27066 L F
.21119 .27176 m .20923 .26981 L .21208 .26872 L F
.17585 .27114 m .17668 .26819 L .17867 .27011 L 0 .026 .124 r
F
.17585 .27114 m .17385 .26923 L .17668 .26819 L F
.52621 .2803 m .52759 .27704 L .52923 .27922 L 0 .045 .147 r
F
.52621 .2803 m .52457 .27813 L .52759 .27704 L F
.4632 .27861 m .4645 .27519 L .46619 .27749 L 0 .04 .142 r
F
.4632 .27861 m .46151 .27627 L .4645 .27519 L F
.32487 .27331 m .32594 .27023 L .32778 .27218 L 0 .03 .13 r
F
.32487 .27331 m .32303 .27136 L .32594 .27023 L F
.38787 .27507 m .38905 .27189 L .39081 .27406 L 0 .033 .134 r
F
.38787 .27507 m .3861 .27294 L .38905 .27189 L F
.66895 .27508 m .67055 .27193 L .67205 .27401 L F
.66895 .27508 m .66745 .27302 L .67055 .27193 L F
.14049 .27062 m .14127 .26763 L .1433 .26954 L 0 .025 .123 r
F
.14049 .27062 m .13846 .26871 L .14127 .26763 L F
.21884 .2715 m .21975 .26844 L .2217 .27039 L 0 .026 .125 r
F
.21884 .2715 m .21689 .26955 L .21975 .26844 L F
.09748 .27044 m .0982 .2674 L .10027 .26934 L 0 .024 .123 r
F
.09748 .27044 m .09541 .2685 L .0982 .2674 L F
.43553 .27767 m .43679 .27434 L .4385 .27657 L 0 .039 .14 r
F
.43553 .27767 m .43381 .27544 L .43679 .27434 L F
.33253 .27304 m .33361 .27009 L .33544 .27208 L 0 .029 .129 r
F
.33253 .27304 m .3307 .27104 L .33361 .27009 L F
.3602 .27412 m .36132 .27119 L .36312 .27319 L 0 .032 .132 r
F
.3602 .27412 m .35839 .27212 L .36132 .27119 L F
.28952 .27284 m .29052 .26992 L .2924 .27183 L 0 .029 .129 r
F
.28952 .27284 m .28764 .27093 L .29052 .26992 L F
.54238 .49208 m .54076 .49031 L .54369 .4693 L .363 .665 0 r
F
.8317 .27142 m .83357 .26837 L .83488 .27029 L 0 .026 .125 r
F
.8317 .27142 m .83038 .26948 L .83357 .26837 L F
.82403 .27189 m .82587 .26873 L .8272 .27069 L 0 .027 .126 r
F
.82403 .27189 m .8227 .26992 L .82587 .26873 L F
.10513 .27019 m .10585 .26718 L .10792 .26913 L 0 .024 .122 r
F
.10513 .27019 m .10306 .26824 L .10585 .26718 L F
.14814 .2704 m .14893 .26745 L .15094 .26941 L 0 .025 .123 r
F
.14814 .2704 m .14612 .26846 L .14893 .26745 L F
.4432 .27743 m .44446 .27425 L .44618 .2763 L 0 .039 .14 r
F
.4432 .27743 m .44148 .27541 L .44446 .27425 L F
.4232 .27594 m .42443 .27289 L .42616 .27503 L 0 .036 .137 r
F
.4232 .27594 m .42147 .27379 L .42443 .27289 L F
.77335 .27211 m .77512 .2691 L .7765 .27105 L 0 .028 .127 r
F
.77335 .27211 m .77196 .27014 L .77512 .2691 L F
.26184 .27191 m .26281 .26891 L .26471 .27089 L 0 .027 .127 r
F
.26184 .27191 m .25993 .26992 L .26281 .26891 L F
.18348 .27109 m .18431 .26817 L .1863 .27013 L 0 .026 .125 r
F
.18348 .27109 m .18149 .26914 L .18431 .26817 L F
.22649 .27132 m .22742 .2682 L .22935 .27025 L F
.22649 .27132 m .22456 .26929 L .22742 .2682 L F
.83939 .27114 m .84127 .26816 L .84258 .27006 L F
.83939 .27114 m .83808 .26923 L .84127 .26816 L F
.53388 .28031 m .53528 .2769 L .5369 .27918 L 0 .045 .147 r
F
.53388 .28031 m .53225 .27806 L .53528 .2769 L F
.29717 .27265 m .2982 .26956 L .30007 .27155 L 0 .029 .129 r
F
.29717 .27265 m .2953 .27069 L .2982 .26956 L F
.47087 .27863 m .47217 .27525 L .47386 .27746 L 0 .041 .143 r
F
.47087 .27863 m .46918 .27637 L .47217 .27525 L F
.67664 .27507 m .67826 .27196 L .67975 .27407 L 0 .034 .135 r
F
.67664 .27507 m .67515 .27298 L .67826 .27196 L F
.78104 .27192 m .78283 .26891 L .7842 .27083 L 0 .028 .127 r
F
.78104 .27192 m .77967 .26999 L .78283 .26891 L F
.45086 .27726 m .45214 .27407 L .45384 .27618 L 0 .039 .14 r
F
.45086 .27726 m .44916 .27518 L .45214 .27407 L F
.49086 .28025 m .4922 .27691 L .49386 .27927 L 0 .045 .148 r
F
.49086 .28025 m .4892 .27792 L .4922 .27691 L F
.69199 .27435 m .69364 .27139 L .6951 .27327 L 0 .033 .134 r
F
.69199 .27435 m .69053 .27249 L .69364 .27139 L F
.71501 .27308 m .71669 .26997 L .71813 .27194 L 0 .03 .13 r
F
.71501 .27308 m .71357 .27113 L .71669 .26997 L F
.11275 .2701 m .11349 .26707 L .11554 .26906 L 0 .024 .123 r
F
.11275 .2701 m .1107 .2681 L .11349 .26707 L F
.70734 .27353 m .709 .27036 L .71045 .2723 L 0 .031 .131 r
F
.70734 .27353 m .70589 .27161 L .709 .27036 L F
.54923 .2797 m .55065 .27629 L .55226 .27849 L 0 .044 .146 r
F
.54923 .2797 m .54761 .2775 L .55065 .27629 L F
.39552 .27524 m .39671 .27202 L .39847 .27418 L 0 .034 .135 r
F
.39552 .27524 m .39376 .27304 L .39671 .27202 L F
.78872 .27163 m .79053 .26864 L .79189 .27053 L 0 .027 .127 r
F
.78872 .27163 m .78736 .26973 L .79053 .26864 L F
.26948 .27185 m .27046 .26885 L .27235 .27084 L 0 .028 .127 r
F
.26948 .27185 m .26758 .26988 L .27046 .26885 L F
.34017 .27314 m .34126 .27017 L .34308 .27217 L 0 .03 .131 r
F
.34017 .27314 m .33835 .27114 L .34126 .27017 L F
.5569 .27934 m .55833 .27605 L .55994 .27812 L 0 .043 .146 r
F
.5569 .27934 m .55529 .27728 L .55833 .27605 L F
.15576 .2704 m .15656 .26742 L .15857 .26943 L 0 .025 .124 r
F
.15576 .2704 m .15375 .26842 L .15656 .26742 L F
.30482 .27254 m .30586 .2695 L .30771 .27156 L 0 .029 .129 r
F
.30482 .27254 m .30296 .27051 L .30586 .2695 L F
.19111 .27106 m .19198 .26795 L .19395 .26996 L 0 .026 .125 r
F
.19111 .27106 m .18913 .26907 L .19198 .26795 L F
.36784 .27425 m .36897 .27139 L .37077 .27335 L 0 .033 .134 r
F
.36784 .27425 m .36604 .27229 L .36897 .27139 L F
.06972 .27001 m .07039 .26694 L .0725 .26889 L 0 .024 .123 r
F
.06972 .27001 m .06762 .26806 L .07039 .26694 L F
.54155 .28023 m .54296 .27658 L .54458 .27886 L 0 .045 .147 r
F
.54155 .28023 m .53993 .27793 L .54296 .27658 L F
.69967 .27406 m .70133 .27097 L .70278 .27287 L 0 .032 .133 r
F
.69967 .27406 m .69822 .27218 L .70133 .27097 L F
.23412 .2713 m .23506 .26825 L .23698 .27029 L 0 .027 .126 r
F
.23412 .2713 m .2322 .26925 L .23506 .26825 L F
.57992 .27812 m .58139 .27504 L .58297 .27704 L 0 .041 .143 r
F
.57992 .27812 m .57834 .27609 L .58139 .27504 L F
.72269 .27283 m .72439 .26974 L .72582 .27176 L 0 .03 .13 r
F
.72269 .27283 m .72126 .27083 L .72439 .26974 L F
.68433 .27496 m .68595 .27158 L .68743 .2737 L 0 .034 .134 r
F
.68433 .27496 m .68285 .27284 L .68595 .27158 L F
.47853 .27859 m .47985 .2753 L .48153 .27759 L 0 .042 .144 r
F
.47853 .27859 m .47685 .27633 L .47985 .2753 L F
.56457 .27903 m .56602 .2757 L .56762 .27786 L 0 .043 .145 r
F
.56457 .27903 m .56298 .27691 L .56602 .2757 L F
.61062 .2765 m .61213 .2733 L .61368 .27531 L 0 .037 .139 r
F
.61062 .2765 m .60906 .27447 L .61213 .2733 L F
.79641 .2714 m .79824 .26848 L .79959 .27037 L 0 .027 .127 r
F
.79641 .2714 m .79506 .26951 L .79824 .26848 L F
.12039 .26996 m .12115 .26685 L .12319 .26885 L 0 .024 .123 r
F
.12039 .26996 m .11835 .26796 L .12115 .26685 L F
.57225 .2787 m .5737 .27528 L .57529 .27738 L 0 .042 .144 r
F
.57225 .2787 m .57066 .27659 L .5737 .27528 L F
.07736 .26979 m .07805 .26674 L .08013 .26875 L 0 .024 .122 r
F
.07736 .26979 m .07527 .2678 L .07805 .26674 L F
.73805 .27213 m .73977 .26907 L .74118 .27095 L 0 .028 .128 r
F
.73805 .27213 m .73664 .27024 L .73977 .26907 L F
.19875 .27088 m .19963 .26783 L .20159 .26987 L 0 .026 .125 r
F
.19875 .27088 m .19679 .26886 L .19963 .26783 L F
.5113 .48258 m .50973 .46159 L .51272 .46552 L .33 .655 0 r
F
.5083 .47784 m .50973 .46159 L .5113 .48258 L .264 .634 0 r
F
.5876 .27791 m .58908 .27486 L .59065 .27681 L 0 .041 .143 r
F
.5876 .27791 m .58602 .27595 L .58908 .27486 L F
.73038 .27263 m .73208 .26951 L .73351 .27145 L 0 .029 .129 r
F
.73038 .27263 m .72896 .27069 L .73208 .26951 L F
.40317 .27519 m .40438 .27201 L .40613 .27406 L 0 .035 .136 r
F
.40317 .27519 m .40142 .27311 L .40438 .27201 L F
.51388 .27946 m .51525 .27607 L .51689 .27814 L 0 .044 .146 r
F
.51388 .27946 m .51223 .27735 L .51525 .27607 L F
.61829 .27628 m .61982 .27291 L .62136 .27506 L 0 .037 .138 r
F
.61829 .27628 m .61675 .27412 L .61982 .27291 L F
.45853 .27734 m .45981 .27408 L .46151 .27627 L 0 .039 .141 r
F
.45853 .27734 m .45683 .27512 L .45981 .27408 L F
.74573 .27181 m .74747 .26891 L .74888 .27079 L 0 .028 .128 r
F
.74573 .27181 m .74433 .26993 L .74747 .26891 L F
.27712 .27181 m .27811 .26884 L .28 .27083 L F
.27712 .27181 m .27523 .26984 L .27811 .26884 L F
.34782 .27311 m .34893 .27009 L .35074 .27206 L 0 .031 .131 r
F
.34782 .27311 m .346 .27113 L .34893 .27009 L F
.24177 .2712 m .24271 .26813 L .24464 .27008 L 0 .027 .126 r
F
.24177 .2712 m .23984 .26924 L .24271 .26813 L F
.50621 .27993 m .50756 .27661 L .50922 .27862 L 0 .045 .148 r
F
.50621 .27993 m .50455 .27787 L .50756 .27661 L F
.80411 .27122 m .80593 .26814 L .80728 .27008 L 0 .027 .126 r
F
.80411 .27122 m .80276 .26929 L .80593 .26814 L F
.41085 .27484 m .41205 .27175 L .41381 .27368 L 0 .034 .135 r
F
.41085 .27484 m .40909 .27291 L .41205 .27175 L F
.64132 .27509 m .64288 .2719 L .6444 .274 L 0 .035 .136 r
F
.64132 .27509 m .6398 .27297 L .64288 .2719 L F
.43085 .27637 m .43209 .2732 L .43381 .27544 L 0 .037 .139 r
F
.43085 .27637 m .42912 .27412 L .43209 .2732 L F
.12803 .26977 m .12879 .26681 L .13082 .2688 L 0 .024 .123 r
F
.12803 .26977 m .12599 .26779 L .12879 .26681 L F
.49853 .28043 m .49988 .27704 L .50154 .27915 L 0 .046 .149 r
F
.49853 .28043 m .49687 .27828 L .49988 .27704 L F
.16338 .27042 m .16419 .26746 L .1662 .26944 L 0 .026 .124 r
F
.16338 .27042 m .16138 .26844 L .16419 .26746 L F
.60295 .27725 m .60445 .27391 L .606 .27583 L 0 .039 .141 r
F
.60295 .27725 m .60139 .27529 L .60445 .27391 L F
.62597 .27597 m .62751 .27261 L .62904 .27474 L 0 .036 .138 r
F
.62597 .27597 m .62443 .27384 L .62751 .27261 L F
.37549 .27428 m .37665 .27118 L .37843 .27314 L 0 .033 .134 r
F
.37549 .27428 m .3737 .27234 L .37665 .27118 L F
.63365 .27556 m .63519 .27209 L .63672 .27422 L 0 .035 .136 r
F
.63365 .27556 m .63211 .27342 L .63519 .27209 L F
.52155 .27919 m .52293 .27595 L .52457 .27813 L 0 .044 .146 r
F
.52155 .27919 m .51991 .27702 L .52293 .27595 L F
.24943 .27089 m .25037 .268 L .25229 .26992 L 0 .027 .126 r
F
.24943 .27089 m .24751 .26897 L .25037 .268 L F
.31246 .27263 m .31352 .26951 L .31536 .27156 L 0 .03 .13 r
F
.31246 .27263 m .31061 .27057 L .31352 .26951 L F
.59528 .27774 m .59677 .27464 L .59834 .27663 L 0 .041 .143 r
F
.59528 .27774 m .59371 .27573 L .59677 .27464 L F
.75342 .27157 m .75516 .26851 L .75656 .27041 L 0 .028 .127 r
F
.75342 .27157 m .75202 .26968 L .75516 .26851 L F
.7611 .27117 m .76286 .26823 L .76425 .27017 L 0 .027 .127 r
F
.7611 .27117 m .7597 .26925 L .76286 .26823 L F
.8118 .27097 m .81364 .26795 L .81498 .26996 L 0 .027 .126 r
F
.8118 .27097 m .81045 .26894 L .81364 .26795 L F
.08498 .26973 m .08569 .26665 L .08776 .26867 L 0 .024 .123 r
F
.08498 .26973 m .08291 .26771 L .08569 .26665 L F
.38316 .27399 m .38432 .27092 L .3861 .27294 L 0 .033 .134 r
F
.38316 .27399 m .38138 .27201 L .38432 .27092 L F
.20639 .27083 m .20727 .26785 L .20923 .26981 L 0 .027 .126 r
F
.20639 .27083 m .20443 .26887 L .20727 .26785 L F
.65668 .27446 m .65826 .27117 L .65976 .27324 L 0 .033 .134 r
F
.65668 .27446 m .65517 .27244 L .65826 .27117 L F
.41851 .2747 m .41972 .27184 L .42147 .27379 L 0 .035 .136 r
F
.41851 .2747 m .41676 .27276 L .41972 .27184 L F
.64901 .27495 m .65058 .27168 L .65209 .27372 L F
.64901 .27495 m .64749 .27291 L .65058 .27168 L F
.17102 .27029 m .17185 .26731 L .17385 .26923 L 0 .026 .125 r
F
.17102 .27029 m .16902 .26838 L .17185 .26731 L F
.35547 .27306 m .35659 .27013 L .35839 .27212 L 0 .031 .132 r
F
.35547 .27306 m .35366 .27107 L .35659 .27013 L F
.66436 .27416 m .66595 .27093 L .66745 .27302 L 0 .033 .134 r
F
.66436 .27416 m .66286 .27208 L .66595 .27093 L F
.32011 .27247 m .32118 .26939 L .32303 .27136 L 0 .03 .13 r
F
.32011 .27247 m .31827 .27049 L .32118 .26939 L F
.28476 .27185 m .28575 .269 L .28764 .27093 L 0 .029 .129 r
F
.28476 .27185 m .28287 .26992 L .28575 .269 L F
.13566 .26975 m .13642 .26678 L .13846 .26871 L 0 .025 .123 r
F
.13566 .26975 m .13362 .26782 L .13642 .26678 L F
.4862 .27892 m .48753 .27555 L .4892 .27792 L 0 .043 .146 r
F
.4862 .27892 m .48452 .27658 L .48753 .27555 L F
.09262 .26958 m .09333 .26653 L .09541 .2685 L 0 .024 .123 r
F
.09262 .26958 m .09054 .2676 L .09333 .26653 L F
.21404 .27066 m .21494 .26763 L .21689 .26955 L 0 .026 .126 r
F
.21404 .27066 m .21208 .26872 L .21494 .26763 L F
.25707 .27089 m .25802 .268 L .25993 .26992 L 0 .027 .127 r
F
.25707 .27089 m .25515 .26897 L .25802 .268 L F
.46619 .27749 m .46749 .27411 L .46918 .27637 L 0 .04 .142 r
F
.46619 .27749 m .4645 .27519 L .46749 .27411 L F
.32778 .27218 m .32886 .2691 L .3307 .27104 L 0 .029 .129 r
F
.32778 .27218 m .32594 .27023 L .32886 .2691 L F
.52772 .51849 m .52914 .54133 L .53075 .52401 L .8 .693 0 r
F
.52772 .51849 m .52609 .53507 L .52914 .54133 L F
.52923 .27922 m .53062 .27587 L .53225 .27806 L 0 .044 .147 r
F
.52923 .27922 m .52759 .27704 L .53062 .27587 L F
.7688 .27115 m .77058 .26817 L .77196 .27014 L 0 .028 .127 r
F
.7688 .27115 m .76741 .26918 L .77058 .26817 L F
.17867 .27011 m .1795 .26722 L .18149 .26914 L 0 .026 .125 r
F
.17867 .27011 m .17668 .26819 L .1795 .26722 L F
.81951 .27097 m .82136 .26795 L .8227 .26992 L 0 .027 .127 r
F
.81951 .27097 m .81817 .26898 L .82136 .26795 L F
.67205 .27401 m .67366 .27088 L .67515 .27298 L 0 .033 .134 r
F
.67205 .27401 m .67055 .27193 L .67366 .27088 L F
.2217 .27039 m .22261 .26732 L .22456 .26929 L 0 .026 .125 r
F
.2217 .27039 m .21975 .26844 L .22261 .26732 L F
.1433 .26954 m .14409 .26656 L .14612 .26846 L 0 .025 .123 r
F
.1433 .26954 m .14127 .26763 L .14409 .26656 L F
.4385 .27657 m .43977 .27316 L .44148 .27541 L 0 .038 .14 r
F
.4385 .27657 m .43679 .27434 L .43977 .27316 L F
.10027 .26934 m .10099 .2663 L .10306 .26824 L 0 .024 .123 r
F
.10027 .26934 m .0982 .2674 L .10099 .2663 L F
.39081 .27406 m .392 .27086 L .39376 .27304 L 0 .033 .134 r
F
.39081 .27406 m .38905 .27189 L .392 .27086 L F
.8272 .27069 m .82905 .26754 L .83038 .26948 L 0 .027 .126 r
F
.8272 .27069 m .82587 .26873 L .82905 .26754 L F
.83488 .27029 m .83676 .26732 L .83808 .26923 L 0 .026 .125 r
F
.83488 .27029 m .83357 .26837 L .83676 .26732 L F
.44618 .2763 m .44744 .2731 L .44916 .27518 L 0 .038 .14 r
F
.44618 .2763 m .44446 .27425 L .44744 .2731 L F
.2924 .27183 m .29343 .26878 L .2953 .27069 L 0 .029 .129 r
F
.2924 .27183 m .29052 .26992 L .29343 .26878 L F
.33544 .27208 m .33652 .26915 L .33835 .27114 L 0 .03 .13 r
F
.33544 .27208 m .33361 .27009 L .33652 .26915 L F
.10792 .26913 m .10864 .26616 L .1107 .2681 L 0 .024 .122 r
F
.10792 .26913 m .10585 .26718 L .10864 .26616 L F
.7765 .27105 m .77829 .26806 L .77967 .26999 L 0 .028 .127 r
F
.7765 .27105 m .77512 .2691 L .77829 .26806 L F
.36312 .27319 m .36424 .27029 L .36604 .27229 L 0 .032 .133 r
F
.36312 .27319 m .36132 .27119 L .36424 .27029 L F
.47386 .27746 m .47517 .27414 L .47685 .27633 L 0 .041 .143 r
F
.47386 .27746 m .47217 .27525 L .47517 .27414 L F
.5369 .27918 m .53831 .27564 L .53993 .27793 L 0 .044 .147 r
F
.5369 .27918 m .53528 .2769 L .53831 .27564 L F
.22935 .27025 m .23027 .2672 L .2322 .26925 L 0 .026 .125 r
F
.22935 .27025 m .22742 .2682 L .23027 .2672 L F
.26471 .27089 m .26568 .2679 L .26758 .26988 L 0 .028 .127 r
F
.26471 .27089 m .26281 .26891 L .26568 .2679 L F
.15094 .26941 m .15174 .26643 L .15375 .26842 L 0 .025 .123 r
F
.15094 .26941 m .14893 .26745 L .15174 .26643 L F
.30007 .27155 m .3011 .26849 L .30296 .27051 L 0 .029 .129 r
F
.30007 .27155 m .2982 .26956 L .3011 .26849 L F
.1863 .27013 m .18715 .26711 L .18913 .26907 L 0 .026 .125 r
F
.1863 .27013 m .18431 .26817 L .18715 .26711 L F
.54458 .27886 m .546 .27522 L .54761 .2775 L 0 .044 .146 r
F
.54458 .27886 m .54296 .27658 L .546 .27522 L F
.42616 .27503 m .42739 .27198 L .42912 .27412 L 0 .036 .137 r
F
.42616 .27503 m .42443 .27289 L .42739 .27198 L F
.71045 .2723 m .71212 .26917 L .71357 .27113 L 0 .03 .13 r
F
.71045 .2723 m .709 .27036 L .71212 .26917 L F
.55226 .27849 m .55368 .2751 L .55529 .27728 L 0 .043 .146 r
F
.55226 .27849 m .55065 .27629 L .55368 .2751 L F
.7842 .27083 m .78599 .26782 L .78736 .26973 L 0 .028 .127 r
F
.7842 .27083 m .78283 .26891 L .78599 .26782 L F
.45384 .27618 m .45512 .273 L .45683 .27512 L 0 .039 .14 r
F
.45384 .27618 m .45214 .27407 L .45512 .273 L F
.71813 .27194 m .71981 .26882 L .72126 .27083 L 0 .03 .13 r
F
.71813 .27194 m .71669 .26997 L .71981 .26882 L F
.67975 .27407 m .68136 .27072 L .68285 .27284 L 0 .034 .135 r
F
.67975 .27407 m .67826 .27196 L .68136 .27072 L F
.55994 .27812 m .56137 .27479 L .56298 .27691 L 0 .043 .145 r
F
.55994 .27812 m .55833 .27605 L .56137 .27479 L F
.06484 .26918 m .06551 .26613 L .06762 .26806 L 0 .024 .123 r
F
.06484 .26918 m .06273 .26724 L .06551 .26613 L F
.6951 .27327 m .69676 .27029 L .69822 .27218 L 0 .033 .133 r
F
.6951 .27327 m .69364 .27139 L .69676 .27029 L F
.68743 .2737 m .68905 .27037 L .69053 .27249 L 0 .033 .134 r
F
.68743 .2737 m .68595 .27158 L .68905 .27037 L F
.70278 .27287 m .70444 .26969 L .70589 .27161 L 0 .032 .132 r
F
.70278 .27287 m .70133 .27097 L .70444 .26969 L F
.79189 .27053 m .7937 .26762 L .79506 .26951 L 0 .027 .127 r
F
.79189 .27053 m .79053 .26864 L .7937 .26762 L F
.49386 .27927 m .49521 .27589 L .49687 .27828 L 0 .045 .148 r
F
.49386 .27927 m .4922 .27691 L .49521 .27589 L F
.11554 .26906 m .1163 .26596 L .11835 .26796 L 0 .024 .123 r
F
.11554 .26906 m .11349 .26707 L .1163 .26596 L F
.39847 .27418 m .39966 .27099 L .40142 .27311 L 0 .034 .135 r
F
.39847 .27418 m .39671 .27202 L .39966 .27099 L F
.57529 .27738 m .57675 .27399 L .57834 .27609 L 0 .041 .143 r
F
.57529 .27738 m .5737 .27528 L .57675 .27399 L F
.0725 .26889 m .07317 .26584 L .07527 .2678 L 0 .024 .122 r
F
.0725 .26889 m .07039 .26694 L .07317 .26584 L F
.19395 .26996 m .19482 .26683 L .19679 .26886 L 0 .026 .125 r
F
.19395 .26996 m .19198 .26795 L .19482 .26683 L F
.56762 .27786 m .56906 .2744 L .57066 .27659 L 0 .042 .144 r
F
.56762 .27786 m .56602 .2757 L .56906 .2744 L F
.61368 .27531 m .6152 .27213 L .61675 .27412 L 0 .037 .138 r
F
.61368 .27531 m .61213 .2733 L .6152 .27213 L F
.27235 .27084 m .27334 .26781 L .27523 .26984 L 0 .028 .127 r
F
.27235 .27084 m .27046 .26885 L .27334 .26781 L F
.58297 .27704 m .58445 .27399 L .58602 .27595 L 0 .041 .143 r
F
.58297 .27704 m .58139 .27504 L .58445 .27399 L F
.34308 .27217 m .34418 .26915 L .346 .27113 L 0 .031 .131 r
F
.34308 .27217 m .34126 .27017 L .34418 .26915 L F
.51689 .27814 m .51827 .27495 L .51991 .27702 L 0 .043 .146 r
F
.51689 .27814 m .51525 .27607 L .51827 .27495 L F
.72582 .27176 m .72752 .26864 L .72896 .27069 L 0 .03 .13 r
F
.72582 .27176 m .72439 .26974 L .72752 .26864 L F
.15857 .26943 m .15938 .26643 L .16138 .26844 L 0 .025 .124 r
F
.15857 .26943 m .15656 .26742 L .15938 .26643 L F
.30771 .27156 m .30876 .26847 L .31061 .27057 L 0 .029 .129 r
F
.30771 .27156 m .30586 .2695 L .30876 .26847 L F
.23698 .27029 m .23792 .2672 L .23984 .26924 L 0 .027 .126 r
F
.23698 .27029 m .23506 .26825 L .23792 .2672 L F
.606 .27583 m .60751 .27258 L .60906 .27447 L 0 .038 .14 r
F
.606 .27583 m .60445 .27391 L .60751 .27258 L F
.5398 .50837 m .53825 .52423 L .54122 .50822 L .623 .734 0 r
F
.5368 .51572 m .53825 .52423 L .5398 .50837 L .774 .757 0 r
F
.74118 .27095 m .74292 .26805 L .74433 .26993 L 0 .028 .128 r
F
.74118 .27095 m .73977 .26907 L .74292 .26805 L F
.50922 .27862 m .51058 .27538 L .51223 .27735 L 0 .044 .147 r
F
.50922 .27862 m .50756 .27661 L .51058 .27538 L F
.12319 .26885 m .12396 .26577 L .12599 .26779 L 0 .024 .122 r
F
.12319 .26885 m .12115 .26685 L .12396 .26577 L F
.48153 .27759 m .48285 .27426 L .48452 .27658 L 0 .042 .144 r
F
.48153 .27759 m .47985 .2753 L .48285 .27426 L F
.37077 .27335 m .37191 .27037 L .3737 .27234 L 0 .033 .134 r
F
.37077 .27335 m .36897 .27139 L .37191 .27037 L F
.79959 .27037 m .80141 .2674 L .80276 .26929 L 0 .027 .127 r
F
.79959 .27037 m .79824 .26848 L .80141 .2674 L F
.62136 .27506 m .62289 .2717 L .62443 .27384 L 0 .036 .138 r
F
.62136 .27506 m .61982 .27291 L .62289 .2717 L F
.63672 .27422 m .63827 .27087 L .6398 .27297 L 0 .034 .136 r
F
.63672 .27422 m .63519 .27209 L .63827 .27087 L F
.73351 .27145 m .73522 .2683 L .73664 .27024 L 0 .029 .129 r
F
.73351 .27145 m .73208 .26951 L .73522 .2683 L F
.50154 .27915 m .50289 .2758 L .50455 .27787 L 0 .046 .148 r
F
.50154 .27915 m .49988 .27704 L .50289 .2758 L F
.59065 .27681 m .59214 .27377 L .59371 .27573 L 0 .041 .143 r
F
.59065 .27681 m .58908 .27486 L .59214 .27377 L F
.40613 .27406 m .40734 .27089 L .40909 .27291 L 0 .034 .136 r
F
.40613 .27406 m .40438 .27201 L .40734 .27089 L F
.08013 .26875 m .08082 .26569 L .08291 .26771 L 0 .024 .122 r
F
.08013 .26875 m .07805 .26674 L .08082 .26569 L F
.62904 .27474 m .63058 .27132 L .63211 .27342 L 0 .036 .137 r
F
.62904 .27474 m .62751 .27261 L .63058 .27132 L F
.41381 .27368 m .41501 .27082 L .41676 .27276 L 0 .034 .135 r
F
.41381 .27368 m .41205 .27175 L .41501 .27082 L F
.80728 .27008 m .8091 .26699 L .81045 .26894 L 0 .027 .126 r
F
.80728 .27008 m .80593 .26814 L .8091 .26699 L F
.24464 .27008 m .24559 .26702 L .24751 .26897 L F
.24464 .27008 m .24271 .26813 L .24559 .26702 L F
.20159 .26987 m .20247 .26681 L .20443 .26887 L 0 .026 .125 r
F
.20159 .26987 m .19963 .26783 L .20247 .26681 L F
.46151 .27627 m .4628 .27303 L .4645 .27519 L 0 .039 .141 r
F
.46151 .27627 m .45981 .27408 L .4628 .27303 L F
.35074 .27206 m .35185 .26909 L .35366 .27107 L 0 .031 .131 r
F
.35074 .27206 m .34893 .27009 L .35185 .26909 L F
.74888 .27079 m .75062 .26779 L .75202 .26968 L 0 .028 .128 r
F
.74888 .27079 m .74747 .26891 L .75062 .26779 L F
.37843 .27314 m .37959 .27003 L .38138 .27201 L 0 .033 .134 r
F
.37843 .27314 m .37665 .27118 L .37959 .27003 L F
.6444 .274 m .64597 .27084 L .64749 .27291 L 0 .035 .136 r
F
.6444 .274 m .64288 .2719 L .64597 .27084 L F
.28 .27083 m .28099 .26792 L .28287 .26992 L 0 .029 .128 r
F
.28 .27083 m .27811 .26884 L .28099 .26792 L F
.75656 .27041 m .75831 .26733 L .7597 .26925 L 0 .027 .127 r
F
.75656 .27041 m .75516 .26851 L .75831 .26733 L F
.59834 .27663 m .59983 .27333 L .60139 .27529 L 0 .04 .142 r
F
.59834 .27663 m .59677 .27464 L .59983 .27333 L F
.52457 .27813 m .52596 .27485 L .52759 .27704 L 0 .044 .146 r
F
.52457 .27813 m .52293 .27595 L .52596 .27485 L F
.65976 .27324 m .66135 .27001 L .66286 .27208 L 0 .033 .134 r
F
.65976 .27324 m .65826 .27117 L .66135 .27001 L F
.31536 .27156 m .31643 .26845 L .31827 .27049 L 0 .03 .13 r
F
.31536 .27156 m .31352 .26951 L .31643 .26845 L F
.13082 .2688 m .13158 .26584 L .13362 .26782 L 0 .025 .123 r
F
.13082 .2688 m .12879 .26681 L .13158 .26584 L F
.1662 .26944 m .16702 .26639 L .16902 .26838 L 0 .026 .125 r
F
.1662 .26944 m .16419 .26746 L .16702 .26639 L F
.65209 .27372 m .65366 .27042 L .65517 .27244 L 0 .034 .135 r
F
.65209 .27372 m .65058 .27168 L .65366 .27042 L F
.43381 .27544 m .43507 .27209 L .43679 .27434 L 0 .038 .139 r
F
.43381 .27544 m .43209 .2732 L .43507 .27209 L F
.25229 .26992 m .25324 .26705 L .25515 .26897 L 0 .027 .126 r
F
.25229 .26992 m .25037 .268 L .25324 .26705 L F
.08776 .26867 m .08847 .26557 L .09054 .2676 L 0 .024 .123 r
F
.08776 .26867 m .08569 .26665 L .08847 .26557 L F
.3861 .27294 m .38727 .26984 L .38905 .27189 L 0 .033 .134 r
F
.3861 .27294 m .38432 .27092 L .38727 .26984 L F
.76425 .27017 m .76602 .26722 L .76741 .26918 L 0 .027 .127 r
F
.76425 .27017 m .76286 .26823 L .76602 .26722 L F
.81498 .26996 m .81683 .26698 L .81817 .26898 L 0 .027 .126 r
F
.81498 .26996 m .81364 .26795 L .81683 .26698 L F
.20923 .26981 m .21012 .26677 L .21208 .26872 L F
.20923 .26981 m .20727 .26785 L .21012 .26677 L F
.66745 .27302 m .66906 .26982 L .67055 .27193 L 0 .033 .134 r
F
.66745 .27302 m .66595 .27093 L .66906 .26982 L F
.50715 .50267 m .50556 .48751 L .5085 .50256 L .622 .734 0 r
F
.50556 .48751 m .50692 .48483 L .5085 .50256 L .409 .678 0 r
F
.32303 .27136 m .3241 .26827 L .32594 .27023 L 0 .03 .13 r
F
.32303 .27136 m .32118 .26939 L .3241 .26827 L F
.17385 .26923 m .17468 .26626 L .17668 .26819 L 0 .026 .125 r
F
.17385 .26923 m .17185 .26731 L .17468 .26626 L F
.52039 .47974 m .5218 .45289 L .52343 .47309 L .264 .635 0 r
F
.52039 .47974 m .51878 .45873 L .5218 .45289 L F
.42147 .27379 m .42269 .27092 L .42443 .27289 L 0 .035 .136 r
F
.42147 .27379 m .41972 .27184 L .42269 .27092 L F
.53225 .27806 m .53365 .27469 L .53528 .2769 L 0 .044 .146 r
F
.53225 .27806 m .53062 .27587 L .53365 .27469 L F
.3307 .27104 m .33177 .26815 L .33361 .27009 L 0 .03 .13 r
F
.3307 .27104 m .32886 .2691 L .33177 .26815 L F
.21689 .26955 m .2178 .26651 L .21975 .26844 L 0 .026 .125 r
F
.21689 .26955 m .21494 .26763 L .2178 .26651 L F
.46918 .27637 m .47048 .27303 L .47217 .27525 L 0 .04 .142 r
F
.46918 .27637 m .46749 .27411 L .47048 .27303 L F
.13846 .26871 m .13923 .26572 L .14127 .26763 L 0 .025 .123 r
F
.13846 .26871 m .13642 .26678 L .13923 .26572 L F
.09541 .2685 m .09612 .26543 L .0982 .2674 L 0 .024 .123 r
F
.09541 .2685 m .09333 .26653 L .09612 .26543 L F
.35839 .27212 m .35951 .26918 L .36132 .27119 L 0 .032 .132 r
F
.35839 .27212 m .35659 .27013 L .35951 .26918 L F
.4892 .27792 m .49053 .2745 L .4922 .27691 L 0 .044 .146 r
F
.4892 .27792 m .48753 .27555 L .49053 .2745 L F
.28764 .27093 m .28864 .268 L .29052 .26992 L 0 .029 .129 r
F
.28764 .27093 m .28575 .269 L .28864 .268 L F
.44148 .27541 m .44275 .27199 L .44446 .27425 L 0 .038 .14 r
F
.44148 .27541 m .43977 .27316 L .44275 .27199 L F
.83038 .26948 m .83224 .26644 L .83357 .26837 L 0 .026 .125 r
F
.83038 .26948 m .82905 .26754 L .83224 .26644 L F
.8227 .26992 m .82454 .26677 L .82587 .26873 L 0 .027 .126 r
F
.8227 .26992 m .82136 .26795 L .82454 .26677 L F
.25993 .26992 m .26089 .267 L .26281 .26891 L 0 .027 .127 r
F
.25993 .26992 m .25802 .268 L .26089 .267 L F
.77196 .27014 m .77374 .26712 L .77512 .2691 L 0 .028 .127 r
F
.77196 .27014 m .77058 .26817 L .77374 .26712 L F
.22456 .26929 m .22547 .26621 L .22742 .2682 L 0 .026 .125 r
F
.22456 .26929 m .22261 .26732 L .22547 .26621 L F
.10306 .26824 m .10378 .26524 L .10585 .26718 L 0 .024 .123 r
F
.10306 .26824 m .10099 .2663 L .10378 .26524 L F
.14612 .26846 m .1469 .26554 L .14893 .26745 L 0 .025 .123 r
F
.14612 .26846 m .14409 .26656 L .1469 .26554 L F
.18149 .26914 m .18232 .26625 L .18431 .26817 L 0 .026 .125 r
F
.18149 .26914 m .1795 .26722 L .18232 .26625 L F
.67515 .27298 m .67677 .26983 L .67826 .27196 L 0 .033 .134 r
F
.67515 .27298 m .67366 .27088 L .67677 .26983 L F
.54761 .2775 m .54903 .27404 L .55065 .27629 L 0 .043 .145 r
F
.54761 .2775 m .546 .27522 L .54903 .27404 L F
.53993 .27793 m .54134 .2743 L .54296 .27658 L 0 .044 .146 r
F
.53993 .27793 m .53831 .27564 L .54134 .2743 L F
.2953 .27069 m .29633 .26764 L .2982 .26956 L 0 .029 .129 r
F
.2953 .27069 m .29343 .26878 L .29633 .26764 L F
.39376 .27304 m .39494 .26987 L .39671 .27202 L 0 .033 .134 r
F
.39376 .27304 m .392 .27086 L .39494 .26987 L F
.44916 .27518 m .45043 .27195 L .45214 .27407 L 0 .038 .14 r
F
.44916 .27518 m .44744 .2731 L .45043 .27195 L F
.83808 .26923 m .83996 .26626 L .84127 .26816 L 0 .026 .125 r
F
.83808 .26923 m .83676 .26732 L .83996 .26626 L F
.47685 .27633 m .47817 .27307 L .47985 .2753 L 0 .041 .143 r
F
.47685 .27633 m .47517 .27414 L .47817 .27307 L F
.77967 .26999 m .78146 .26699 L .78283 .26891 L 0 .028 .127 r
F
.77967 .26999 m .77829 .26806 L .78146 .26699 L F
.1107 .2681 m .11143 .26513 L .11349 .26707 L 0 .024 .123 r
F
.1107 .2681 m .10864 .26616 L .11143 .26513 L F
.55529 .27728 m .55673 .27387 L .55833 .27605 L 0 .043 .145 r
F
.55529 .27728 m .55368 .2751 L .55673 .27387 L F
.71357 .27113 m .71524 .26797 L .71669 .26997 L 0 .03 .13 r
F
.71357 .27113 m .71212 .26917 L .71524 .26797 L F
.68285 .27284 m .68446 .26946 L .68595 .27158 L 0 .033 .134 r
F
.68285 .27284 m .68136 .27072 L .68446 .26946 L F
.33835 .27114 m .33944 .2682 L .34126 .27017 L 0 .03 .13 r
F
.33835 .27114 m .33652 .26915 L .33944 .2682 L F
.30296 .27051 m .30401 .26744 L .30586 .2695 L 0 .029 .129 r
F
.30296 .27051 m .3011 .26849 L .30401 .26744 L F
.26758 .26988 m .26856 .26685 L .27046 .26885 L 0 .028 .127 r
F
.26758 .26988 m .26568 .2679 L .26856 .26685 L F
.56298 .27691 m .56442 .27353 L .56602 .2757 L 0 .042 .144 r
F
.56298 .27691 m .56137 .27479 L .56442 .27353 L F
.2322 .26925 m .23313 .2662 L .23506 .26825 L 0 .026 .126 r
F
.2322 .26925 m .23027 .2672 L .23313 .2662 L F
.15375 .26842 m .15455 .26542 L .15656 .26742 L 0 .025 .124 r
F
.15375 .26842 m .15174 .26643 L .15455 .26542 L F
.57834 .27609 m .57981 .27296 L .58139 .27504 L 0 .041 .143 r
F
.57834 .27609 m .57675 .27399 L .57981 .27296 L F
.70589 .27161 m .70755 .26841 L .709 .27036 L 0 .031 .131 r
F
.70589 .27161 m .70444 .26969 L .70755 .26841 L F
.18913 .26907 m .19 .26597 L .19198 .26795 L 0 .026 .125 r
F
.18913 .26907 m .18715 .26711 L .19 .26597 L F
.69053 .27249 m .69217 .26929 L .69364 .27139 L 0 .033 .133 r
F
.69053 .27249 m .68905 .27037 L .69217 .26929 L F
.78736 .26973 m .78916 .26674 L .79053 .26864 L 0 .028 .127 r
F
.78736 .26973 m .78599 .26782 L .78916 .26674 L F
.36604 .27229 m .36717 .2694 L .36897 .27139 L 0 .033 .134 r
F
.36604 .27229 m .36424 .27029 L .36717 .2694 L F
.72126 .27083 m .72295 .26771 L .72439 .26974 L 0 .03 .13 r
F
.72126 .27083 m .71981 .26882 L .72295 .26771 L F
.06762 .26806 m .06829 .26501 L .07039 .26694 L 0 .024 .123 r
F
.06762 .26806 m .06551 .26613 L .06829 .26501 L F
.57066 .27659 m .57211 .27306 L .5737 .27528 L 0 .041 .143 r
F
.57066 .27659 m .56906 .2744 L .57211 .27306 L F
.60906 .27447 m .61058 .27143 L .61213 .2733 L 0 .037 .139 r
F
.60906 .27447 m .60751 .27258 L .61058 .27143 L F
.45683 .27512 m .45811 .27199 L .45981 .27408 L 0 .039 .14 r
F
.45683 .27512 m .45512 .273 L .45811 .27199 L F
.69822 .27218 m .69987 .26906 L .70133 .27097 L 0 .032 .133 r
F
.69822 .27218 m .69676 .27029 L .69987 .26906 L F
.61675 .27412 m .61827 .27092 L .61982 .27291 L 0 .036 .138 r
F
.61675 .27412 m .6152 .27213 L .61827 .27092 L F
.42912 .27412 m .43036 .27107 L .43209 .2732 L 0 .037 .138 r
F
.42912 .27412 m .42739 .27198 L .43036 .27107 L F
.11835 .26796 m .11911 .26484 L .12115 .26685 L 0 .024 .122 r
F
.11835 .26796 m .1163 .26596 L .11911 .26484 L F
.51223 .27735 m .5136 .27415 L .51525 .27607 L 0 .044 .146 r
F
.51223 .27735 m .51058 .27538 L .5136 .27415 L F
.40142 .27311 m .40262 .26993 L .40438 .27201 L 0 .034 .135 r
F
.40142 .27311 m .39966 .27099 L .40262 .26993 L F
.19679 .26886 m .19767 .26578 L .19963 .26783 L 0 .026 .125 r
F
.19679 .26886 m .19482 .26683 L .19767 .26578 L F
.07527 .2678 m .07595 .26477 L .07805 .26674 L 0 .024 .122 r
F
.07527 .2678 m .07317 .26584 L .07595 .26477 L F
.79506 .26951 m .79688 .2666 L .79824 .26848 L 0 .027 .127 r
F
.79506 .26951 m .7937 .26762 L .79688 .2666 L F
.49687 .27828 m .49822 .27468 L .49988 .27704 L 0 .045 .148 r
F
.49687 .27828 m .49521 .27589 L .49822 .27468 L F
.50455 .27787 m .50591 .27458 L .50756 .27661 L 0 .045 .147 r
F
.50455 .27787 m .50289 .2758 L .50591 .27458 L F
.58602 .27595 m .58751 .27292 L .58908 .27486 L 0 .041 .143 r
F
.58602 .27595 m .58445 .27399 L .58751 .27292 L F
.51991 .27702 m .52129 .27386 L .52293 .27595 L 0 .043 .145 r
F
.51991 .27702 m .51827 .27495 L .52129 .27386 L F
.6398 .27297 m .64136 .26982 L .64288 .2719 L 0 .034 .135 r
F
.6398 .27297 m .63827 .27087 L .64136 .26982 L F
.62443 .27384 m .62597 .27048 L .62751 .27261 L 0 .036 .137 r
F
.62443 .27384 m .62289 .2717 L .62597 .27048 L F
.63211 .27342 m .63366 .27003 L .63519 .27209 L 0 .035 .136 r
F
.63211 .27342 m .63058 .27132 L .63366 .27003 L F
.73664 .27024 m .73835 .26713 L .73977 .26907 L 0 .029 .128 r
F
.73664 .27024 m .73522 .2683 L .73835 .26713 L F
.72896 .27069 m .73065 .26745 L .73208 .26951 L 0 .029 .129 r
F
.72896 .27069 m .72752 .26864 L .73065 .26745 L F
.27523 .26984 m .27623 .26678 L .27811 .26884 L 0 .028 .128 r
F
.27523 .26984 m .27334 .26781 L .27623 .26678 L F
.346 .27113 m .34711 .26813 L .34893 .27009 L 0 .031 .131 r
F
.346 .27113 m .34418 .26915 L .34711 .26813 L F
.23984 .26924 m .24079 .26609 L .24271 .26813 L 0 .027 .126 r
F
.23984 .26924 m .23792 .2672 L .24079 .26609 L F
.12599 .26779 m .12675 .26478 L .12879 .26681 L 0 .024 .123 r
F
.12599 .26779 m .12396 .26577 L .12675 .26478 L F
.40909 .27291 m .4103 .26976 L .41205 .27175 L 0 .034 .135 r
F
.40909 .27291 m .40734 .27089 L .4103 .26976 L F
.80276 .26929 m .80458 .26623 L .80593 .26814 L 0 .027 .126 r
F
.80276 .26929 m .80141 .2674 L .80458 .26623 L F
.31061 .27057 m .31167 .26742 L .31352 .26951 L 0 .029 .129 r
F
.31061 .27057 m .30876 .26847 L .31167 .26742 L F
.74433 .26993 m .74607 .26703 L .74747 .26891 L 0 .029 .128 r
F
.74433 .26993 m .74292 .26805 L .74607 .26703 L F
.16138 .26844 m .16219 .26544 L .16419 .26746 L 0 .026 .124 r
F
.16138 .26844 m .15938 .26643 L .16219 .26544 L F
.60139 .27529 m .60289 .27198 L .60445 .27391 L 0 .039 .141 r
F
.60139 .27529 m .59983 .27333 L .60289 .27198 L F
.59371 .27573 m .59521 .27268 L .59677 .27464 L 0 .041 .143 r
F
.59371 .27573 m .59214 .27377 L .59521 .27268 L F
.48452 .27658 m .48585 .2732 L .48753 .27555 L 0 .042 .144 r
F
.48452 .27658 m .48285 .27426 L .48585 .2732 L F
.3737 .27234 m .37486 .26921 L .37665 .27118 L 0 .033 .134 r
F
.3737 .27234 m .37191 .27037 L .37486 .26921 L F
.81045 .26894 m .81229 .26599 L .81364 .26795 L 0 .027 .126 r
F
.81045 .26894 m .8091 .26699 L .81229 .26599 L F
.24751 .26897 m .24845 .26605 L .25037 .268 L F
.24751 .26897 m .24559 .26702 L .24845 .26605 L F
.08291 .26771 m .08361 .26461 L .08569 .26665 L 0 .024 .123 r
F
.08291 .26771 m .08082 .26569 L .08361 .26461 L F
.4645 .27519 m .46579 .27199 L .46749 .27411 L 0 .039 .141 r
F
.4645 .27519 m .4628 .27303 L .46579 .27199 L F
.65517 .27244 m .65675 .26916 L .65826 .27117 L 0 .033 .134 r
F
.65517 .27244 m .65366 .27042 L .65675 .26916 L F
.38138 .27201 m .38254 .26891 L .38432 .27092 L 0 .033 .133 r
F
.38138 .27201 m .37959 .27003 L .38254 .26891 L F
.7597 .26925 m .76147 .26629 L .76286 .26823 L 0 .027 .127 r
F
.7597 .26925 m .75831 .26733 L .76147 .26629 L F
.75202 .26968 m .75376 .26659 L .75516 .26851 L 0 .028 .128 r
F
.75202 .26968 m .75062 .26779 L .75376 .26659 L F
.64749 .27291 m .64906 .26964 L .65058 .27168 L 0 .034 .135 r
F
.64749 .27291 m .64597 .27084 L .64906 .26964 L F
.20443 .26887 m .20532 .26576 L .20727 .26785 L 0 .026 .126 r
F
.20443 .26887 m .20247 .26681 L .20532 .26576 L F
.66286 .27208 m .66445 .26884 L .66595 .27093 L 0 .033 .133 r
F
.66286 .27208 m .66135 .27001 L .66445 .26884 L F
.41676 .27276 m .41798 .26988 L .41972 .27184 L 0 .035 .136 r
F
.41676 .27276 m .41501 .27082 L .41798 .26988 L F
.52759 .27704 m .52899 .27367 L .53062 .27587 L 0 .043 .146 r
F
.52759 .27704 m .52596 .27485 L .52899 .27367 L F
.35366 .27107 m .35478 .2681 L .35659 .27013 L 0 .031 .132 r
F
.35366 .27107 m .35185 .26909 L .35478 .2681 L F
.31827 .27049 m .31934 .26735 L .32118 .26939 L 0 .03 .13 r
F
.31827 .27049 m .31643 .26845 L .31934 .26735 L F
.43679 .27434 m .43805 .27091 L .43977 .27316 L 0 .037 .139 r
F
.43679 .27434 m .43507 .27209 L .43805 .27091 L F
.16902 .26838 m .16985 .26531 L .17185 .26731 L 0 .026 .125 r
F
.16902 .26838 m .16702 .26639 L .16985 .26531 L F
.28287 .26992 m .28387 .267 L .28575 .269 L 0 .029 .129 r
F
.28287 .26992 m .28099 .26792 L .28387 .267 L F
.09054 .2676 m .09126 .26449 L .09333 .26653 L 0 .024 .123 r
F
.09054 .2676 m .08847 .26557 L .09126 .26449 L F
.13362 .26782 m .13439 .2648 L .13642 .26678 L 0 .025 .123 r
F
.13362 .26782 m .13158 .26584 L .13439 .2648 L F
.38905 .27189 m .39022 .26879 L .392 .27086 L 0 .033 .134 r
F
.38905 .27189 m .38727 .26984 L .39022 .26879 L F
.21208 .26872 m .21298 .2657 L .21494 .26763 L 0 .027 .126 r
F
.21208 .26872 m .21012 .26677 L .21298 .2657 L F
.67055 .27193 m .67216 .26875 L .67366 .27088 L 0 .033 .134 r
F
.67055 .27193 m .66906 .26982 L .67216 .26875 L F
.32594 .27023 m .32702 .26715 L .32886 .2691 L 0 .03 .13 r
F
.32594 .27023 m .3241 .26827 L .32702 .26715 L F
.76741 .26918 m .76919 .26619 L .77058 .26817 L 0 .028 .127 r
F
.76741 .26918 m .76602 .26722 L .76919 .26619 L F
.25515 .26897 m .2561 .26609 L .25802 .268 L 0 .027 .127 r
F
.25515 .26897 m .25324 .26705 L .2561 .26609 L F
.81817 .26898 m .82003 .26597 L .82136 .26795 L F
.81817 .26898 m .81683 .26698 L .82003 .26597 L F
.53528 .2769 m .53668 .27347 L .53831 .27564 L 0 .043 .146 r
F
.53528 .2769 m .53365 .27469 L .53668 .27347 L F
.17668 .26819 m .1775 .2653 L .1795 .26722 L 0 .026 .125 r
F
.17668 .26819 m .17468 .26626 L .1775 .2653 L F
.47217 .27525 m .47348 .27195 L .47517 .27414 L 0 .04 .142 r
F
.47217 .27525 m .47048 .27303 L .47348 .27195 L F
.21975 .26844 m .22066 .26539 L .22261 .26732 L 0 .026 .125 r
F
.21975 .26844 m .2178 .26651 L .22066 .26539 L F
.0982 .2674 m .09892 .26432 L .10099 .2663 L 0 .024 .123 r
F
.0982 .2674 m .09612 .26543 L .09892 .26432 L F
.54296 .27658 m .54437 .27296 L .546 .27522 L 0 .042 .145 r
F
.54296 .27658 m .54134 .2743 L .54437 .27296 L F
.14127 .26763 m .14205 .26465 L .14409 .26656 L 0 .025 .123 r
F
.14127 .26763 m .13923 .26572 L .14205 .26465 L F
.44446 .27425 m .44573 .27082 L .44744 .2731 L 0 .038 .139 r
F
.44446 .27425 m .44275 .27199 L .44573 .27082 L F
.82587 .26873 m .82773 .26559 L .82905 .26754 L 0 .027 .126 r
F
.82587 .26873 m .82454 .26677 L .82773 .26559 L F
.53447 .49414 m .53578 .46182 L .53745 .47539 L .38 .669 0 r
F
.53447 .49414 m .53279 .47893 L .53578 .46182 L F
.83357 .26837 m .83545 .2654 L .83676 .26732 L 0 .026 .125 r
F
.83357 .26837 m .83224 .26644 L .83545 .2654 L F
.33361 .27009 m .33468 .26722 L .33652 .26915 L 0 .03 .13 r
F
.33361 .27009 m .33177 .26815 L .33468 .26722 L F
.4922 .27691 m .49354 .27345 L .49521 .27589 L 0 .044 .146 r
F
.4922 .27691 m .49053 .2745 L .49354 .27345 L F
.55065 .27629 m .55207 .27286 L .55368 .2751 L 0 .042 .145 r
F
.55065 .27629 m .54903 .27404 L .55207 .27286 L F
.42443 .27289 m .42565 .27001 L .42739 .27198 L 0 .036 .137 r
F
.42443 .27289 m .42269 .27092 L .42565 .27001 L F
.22742 .2682 m .22833 .26522 L .23027 .2672 L 0 .026 .125 r
F
.22742 .2682 m .22547 .26621 L .22833 .26522 L F
.36132 .27119 m .36244 .2683 L .36424 .27029 L 0 .032 .133 r
F
.36132 .27119 m .35951 .26918 L .36244 .2683 L F
.29052 .26992 m .29155 .26686 L .29343 .26878 L 0 .029 .129 r
F
.29052 .26992 m .28864 .268 L .29155 .26686 L F
.77512 .2691 m .77691 .26608 L .77829 .26806 L 0 .028 .127 r
F
.77512 .2691 m .77374 .26712 L .77691 .26608 L F
.10585 .26718 m .10657 .26422 L .10864 .26616 L 0 .024 .123 r
F
.10585 .26718 m .10378 .26524 L .10657 .26422 L F
.26281 .26891 m .26377 .266 L .26568 .2679 L 0 .028 .127 r
F
.26281 .26891 m .26089 .267 L .26377 .266 L F
.2982 .26956 m .29923 .26655 L .3011 .26849 L 0 .029 .129 r
F
.2982 .26956 m .29633 .26764 L .29923 .26655 L F
.14893 .26745 m .14971 .26452 L .15174 .26643 L 0 .025 .123 r
F
.14893 .26745 m .1469 .26554 L .14971 .26452 L F
.45214 .27407 m .45342 .27088 L .45512 .273 L 0 .038 .14 r
F
.45214 .27407 m .45043 .27195 L .45342 .27088 L F
.67826 .27196 m .67987 .2686 L .68136 .27072 L 0 .033 .134 r
F
.67826 .27196 m .67677 .26983 L .67987 .2686 L F
.55833 .27605 m .55977 .27258 L .56137 .27479 L 0 .042 .144 r
F
.55833 .27605 m .55673 .27387 L .55977 .27258 L F
.18431 .26817 m .18516 .26519 L .18715 .26711 L 0 .026 .125 r
F
.18431 .26817 m .18232 .26625 L .18516 .26519 L F
.68595 .27158 m .68757 .26826 L .68905 .27037 L 0 .033 .133 r
F
.68595 .27158 m .68446 .26946 L .68757 .26826 L F
.39671 .27202 m .3979 .26888 L .39966 .27099 L 0 .034 .135 r
F
.39671 .27202 m .39494 .26987 L .3979 .26888 L F
.709 .27036 m .71067 .26719 L .71212 .26917 L 0 .03 .131 r
F
.709 .27036 m .70755 .26841 L .71067 .26719 L F
.56602 .2757 m .56746 .2722 L .56906 .2744 L 0 .041 .143 r
F
.56602 .2757 m .56442 .27353 L .56746 .2722 L F
.5737 .27528 m .57516 .27175 L .57675 .27399 L 0 .04 .142 r
F
.5737 .27528 m .57211 .27306 L .57516 .27175 L F
.71669 .26997 m .71837 .2668 L .71981 .26882 L 0 .03 .13 r
F
.71669 .26997 m .71524 .26797 L .71837 .2668 L F
.47985 .2753 m .48117 .272 L .48285 .27426 L 0 .041 .143 r
F
.47985 .2753 m .47817 .27307 L .48117 .272 L F
.78283 .26891 m .78463 .26592 L .78599 .26782 L 0 .028 .127 r
F
.78283 .26891 m .78146 .26699 L .78463 .26592 L F
.06273 .26724 m .06339 .26419 L .06551 .26613 L 0 .025 .123 r
F
.06273 .26724 m .06061 .2653 L .06339 .26419 L F
.11349 .26707 m .11423 .26402 L .1163 .26596 L 0 .024 .123 r
F
.11349 .26707 m .11143 .26513 L .11423 .26402 L F
.19198 .26795 m .19285 .26483 L .19482 .26683 L 0 .026 .125 r
F
.19198 .26795 m .19 .26597 L .19285 .26483 L F
.61213 .2733 m .61366 .27027 L .6152 .27213 L 0 .037 .139 r
F
.61213 .2733 m .61058 .27143 L .61366 .27027 L F
.51525 .27607 m .51662 .273 L .51827 .27495 L 0 .043 .145 r
F
.51525 .27607 m .5136 .27415 L .51662 .273 L F
.69364 .27139 m .69529 .26821 L .69676 .27029 L 0 .033 .133 r
F
.69364 .27139 m .69217 .26929 L .69529 .26821 L F
.70133 .27097 m .70298 .26776 L .70444 .26969 L 0 .032 .132 r
F
.70133 .27097 m .69987 .26906 L .70298 .26776 L F
.79053 .26864 m .79234 .26572 L .7937 .26762 L 0 .028 .127 r
F
.79053 .26864 m .78916 .26674 L .79234 .26572 L F
.27046 .26885 m .27145 .26578 L .27334 .26781 L F
.27046 .26885 m .26856 .26685 L .27145 .26578 L F
.58139 .27504 m .58287 .27194 L .58445 .27399 L 0 .041 .143 r
F
.58139 .27504 m .57981 .27296 L .58287 .27194 L F
.30586 .2695 m .30691 .26638 L .30876 .26847 L 0 .029 .129 r
F
.30586 .2695 m .30401 .26744 L .30691 .26638 L F
.07039 .26694 m .07107 .2639 L .07317 .26584 L 0 .024 .123 r
F
.07039 .26694 m .06829 .26501 L .07107 .2639 L F
.61982 .27291 m .62135 .26969 L .62289 .2717 L 0 .036 .137 r
F
.61982 .27291 m .61827 .27092 L .62135 .26969 L F
.72439 .26974 m .72608 .26659 L .72752 .26864 L 0 .029 .129 r
F
.72439 .26974 m .72295 .26771 L .72608 .26659 L F
.23506 .26825 m .23599 .26515 L .23792 .2672 L 0 .027 .126 r
F
.23506 .26825 m .23313 .2662 L .23599 .26515 L F
.63519 .27209 m .63674 .26883 L .63827 .27087 L 0 .034 .135 r
F
.63519 .27209 m .63366 .27003 L .63674 .26883 L F
.34126 .27017 m .34236 .26719 L .34418 .26915 L 0 .031 .131 r
F
.34126 .27017 m .33944 .2682 L .34236 .26719 L F
.15656 .26742 m .15737 .26443 L .15938 .26643 L 0 .025 .124 r
F
.15656 .26742 m .15455 .26542 L .15737 .26443 L F
.50756 .27661 m .50893 .2734 L .51058 .27538 L 0 .044 .147 r
F
.50756 .27661 m .50591 .27458 L .50893 .2734 L F
.49988 .27704 m .50123 .27348 L .50289 .2758 L 0 .045 .147 r
F
.49988 .27704 m .49822 .27468 L .50123 .27348 L F
.45981 .27408 m .4611 .27097 L .4628 .27303 L 0 .039 .141 r
F
.45981 .27408 m .45811 .27199 L .4611 .27097 L F
.12115 .26685 m .12191 .26375 L .12396 .26577 L 0 .024 .122 r
F
.12115 .26685 m .11911 .26484 L .12191 .26375 L F
.62751 .27261 m .62904 .26922 L .63058 .27132 L 0 .035 .136 r
F
.62751 .27261 m .62597 .27048 L .62904 .26922 L F
.60445 .27391 m .60596 .27068 L .60751 .27258 L 0 .038 .14 r
F
.60445 .27391 m .60289 .27198 L .60596 .27068 L F
.54263 .50296 m .54103 .50762 L .54397 .48816 L .51 .705 0 r
F
.54103 .50762 m .54238 .49208 L .54397 .48816 L .6 .728 0 r
F
.40438 .27201 m .40558 .26884 L .40734 .27089 L 0 .034 .135 r
F
.40438 .27201 m .40262 .26993 L .40558 .26884 L F
.36897 .27139 m .37011 .26839 L .37191 .27037 L 0 .033 .134 r
F
.36897 .27139 m .36717 .2694 L .37011 .26839 L F
.73977 .26907 m .7415 .26611 L .74292 .26805 L 0 .029 .128 r
F
.73977 .26907 m .73835 .26713 L .7415 .26611 L F
.73208 .26951 m .73378 .26623 L .73522 .2683 L 0 .029 .129 r
F
.73208 .26951 m .73065 .26745 L .73378 .26623 L F
.07805 .26674 m .07873 .2637 L .08082 .26569 L 0 .024 .122 r
F
.07805 .26674 m .07595 .26477 L .07873 .2637 L F
.58908 .27486 m .59057 .27182 L .59214 .27377 L 0 .041 .143 r
F
.58908 .27486 m .58751 .27292 L .59057 .27182 L F
.19963 .26783 m .20051 .26473 L .20247 .26681 L 0 .026 .125 r
F
.19963 .26783 m .19767 .26578 L .20051 .26473 L F
.52293 .27595 m .52432 .27275 L .52596 .27485 L 0 .043 .145 r
F
.52293 .27595 m .52129 .27386 L .52432 .27275 L F
.79824 .26848 m .80006 .2655 L .80141 .2674 L 0 .028 .127 r
F
.79824 .26848 m .79688 .2666 L .80006 .2655 L F
.64288 .2719 m .64445 .26878 L .64597 .27084 L 0 .034 .135 r
F
.64288 .2719 m .64136 .26982 L .64445 .26878 L F
.43209 .2732 m .43334 .26995 L .43507 .27209 L 0 .037 .138 r
F
.43209 .2732 m .43036 .27107 L .43334 .26995 L F
.41205 .27175 m .41326 .2688 L .41501 .27082 L 0 .034 .135 r
F
.41205 .27175 m .4103 .26976 L .41326 .2688 L F
.24271 .26813 m .24367 .26499 L .24559 .26702 L 0 .027 .126 r
F
.24271 .26813 m .24079 .26609 L .24367 .26499 L F
.80593 .26814 m .80776 .26507 L .8091 .26699 L F
.80593 .26814 m .80458 .26623 L .80776 .26507 L F
.51374 .51607 m .51503 .5389 L .51671 .53346 L .8 .694 0 r
F
.51374 .51607 m .51206 .52076 L .51503 .5389 L F
.34893 .27009 m .35004 .2671 L .35185 .26909 L 0 .031 .131 r
F
.34893 .27009 m .34711 .26813 L .35004 .2671 L F
.65826 .27117 m .65985 .26802 L .66135 .27001 L 0 .033 .134 r
F
.65826 .27117 m .65675 .26916 L .65985 .26802 L F
.27811 .26884 m .27911 .26583 L .28099 .26792 L 0 .028 .128 r
F
.27811 .26884 m .27623 .26678 L .27911 .26583 L F
.37665 .27118 m .37781 .26805 L .37959 .27003 L 0 .033 .134 r
F
.37665 .27118 m .37486 .26921 L .37781 .26805 L F
.31352 .26951 m .31458 .26636 L .31643 .26845 L 0 .029 .129 r
F
.31352 .26951 m .31167 .26742 L .31458 .26636 L F
.59677 .27464 m .59827 .27138 L .59983 .27333 L 0 .04 .142 r
F
.59677 .27464 m .59521 .27268 L .59827 .27138 L F
.74747 .26891 m .74921 .26589 L .75062 .26779 L 0 .029 .128 r
F
.74747 .26891 m .74607 .26703 L .74921 .26589 L F
.65058 .27168 m .65215 .26839 L .65366 .27042 L 0 .034 .135 r
F
.65058 .27168 m .64906 .26964 L .65215 .26839 L F
.75516 .26851 m .75691 .26539 L .75831 .26733 L 0 .028 .127 r
F
.75516 .26851 m .75376 .26659 L .75691 .26539 L F
.12879 .26681 m .12955 .2638 L .13158 .26584 L 0 .025 .123 r
F
.12879 .26681 m .12675 .26478 L .12955 .2638 L F
.48753 .27555 m .48886 .27211 L .49053 .2745 L 0 .042 .144 r
F
.48753 .27555 m .48585 .2732 L .48886 .27211 L F
.16419 .26746 m .16502 .26436 L .16702 .26639 L 0 .026 .125 r
F
.16419 .26746 m .16219 .26544 L .16502 .26436 L F
.51734 .4864 m .51878 .45873 L .52039 .47974 L .331 .655 0 r
F
.51734 .4864 m .51574 .46457 L .51878 .45873 L F
.08569 .26665 m .08639 .26354 L .08847 .26557 L 0 .024 .123 r
F
.08569 .26665 m .08361 .26461 L .08639 .26354 L F
.46749 .27411 m .46879 .27095 L .47048 .27303 L 0 .039 .141 r
F
.46749 .27411 m .46579 .27199 L .46879 .27095 L F
.38432 .27092 m .3855 .26779 L .38727 .26984 L 0 .033 .133 r
F
.38432 .27092 m .38254 .26891 L .3855 .26779 L F
.66595 .27093 m .66756 .26771 L .66906 .26982 L 0 .032 .133 r
F
.66595 .27093 m .66445 .26884 L .66756 .26771 L F
.81364 .26795 m .81549 .26501 L .81683 .26698 L 0 .027 .126 r
F
.81364 .26795 m .81229 .26599 L .81549 .26501 L F
.53062 .27587 m .53202 .27248 L .53365 .27469 L 0 .043 .145 r
F
.53062 .27587 m .52899 .27367 L .53202 .27248 L F
.25037 .268 m .25132 .2651 L .25324 .26705 L 0 .027 .126 r
F
.25037 .268 m .24845 .26605 L .25132 .2651 L F
.76286 .26823 m .76463 .26526 L .76602 .26722 L 0 .028 .127 r
F
.76286 .26823 m .76147 .26629 L .76463 .26526 L F
.43977 .27316 m .44103 .26972 L .44275 .27199 L 0 .037 .138 r
F
.43977 .27316 m .43805 .27091 L .44103 .26972 L F
.20727 .26785 m .20817 .26469 L .21012 .26677 L 0 .027 .126 r
F
.20727 .26785 m .20532 .26576 L .20817 .26469 L F
.32118 .26939 m .32226 .26623 L .3241 .26827 L 0 .03 .13 r
F
.32118 .26939 m .31934 .26735 L .32226 .26623 L F
.17185 .26731 m .17268 .26424 L .17468 .26626 L 0 .026 .125 r
F
.17185 .26731 m .16985 .26531 L .17268 .26424 L F
.53831 .27564 m .53972 .2722 L .54134 .2743 L 0 .043 .145 r
F
.53831 .27564 m .53668 .27347 L .53972 .2722 L F
.546 .27522 m .54741 .2718 L .54903 .27404 L 0 .042 .144 r
F
.546 .27522 m .54437 .27296 L .54741 .2718 L F
.35659 .27013 m .35771 .26711 L .35951 .26918 L 0 .031 .132 r
F
.35659 .27013 m .35478 .2681 L .35771 .26711 L F
.41972 .27184 m .42094 .26896 L .42269 .27092 L 0 .035 .137 r
F
.41972 .27184 m .41798 .26988 L .42094 .26896 L F
.09333 .26653 m .09405 .26338 L .09612 .26543 L 0 .024 .123 r
F
.09333 .26653 m .09126 .26449 L .09405 .26338 L F
.32886 .2691 m .32993 .26621 L .33177 .26815 L 0 .03 .13 r
F
.32886 .2691 m .32702 .26715 L .32993 .26621 L F
.21494 .26763 m .21584 .26458 L .2178 .26651 L 0 .027 .126 r
F
.21494 .26763 m .21298 .2657 L .21584 .26458 L F
.13642 .26678 m .1372 .26374 L .13923 .26572 L 0 .025 .124 r
F
.13642 .26678 m .13439 .2648 L .1372 .26374 L F
.392 .27086 m .39318 .26781 L .39494 .26987 L 0 .033 .134 r
F
.392 .27086 m .39022 .26879 L .39318 .26781 L F
.67366 .27088 m .67527 .26769 L .67677 .26983 L F
.67366 .27088 m .67216 .26875 L .67527 .26769 L F
.28575 .269 m .28676 .26599 L .28864 .268 L 0 .029 .129 r
F
.28575 .269 m .28387 .267 L .28676 .26599 L F
.82136 .26795 m .82321 .2648 L .82454 .26677 L 0 .027 .126 r
F
.82136 .26795 m .82003 .26597 L .82321 .2648 L F
.77058 .26817 m .77235 .26512 L .77374 .26712 L 0 .028 .127 r
F
.77058 .26817 m .76919 .26619 L .77235 .26512 L F
.22261 .26732 m .22352 .26428 L .22547 .26621 L 0 .026 .125 r
F
.22261 .26732 m .22066 .26539 L .22352 .26428 L F
.47517 .27414 m .47648 .27084 L .47817 .27307 L 0 .04 .142 r
F
.47517 .27414 m .47348 .27195 L .47648 .27084 L F
.82905 .26754 m .83092 .26451 L .83224 .26644 L 0 .027 .126 r
F
.82905 .26754 m .82773 .26559 L .83092 .26451 L F
.44744 .2731 m .44872 .26966 L .45043 .27195 L 0 .037 .139 r
F
.44744 .2731 m .44573 .27082 L .44872 .26966 L F
.25802 .268 m .25898 .2651 L .26089 .267 L 0 .028 .127 r
F
.25802 .268 m .2561 .26609 L .25898 .2651 L F
.10099 .2663 m .10171 .26327 L .10378 .26524 L 0 .024 .123 r
F
.10099 .2663 m .09892 .26432 L .10171 .26327 L F
.14409 .26656 m .14486 .26362 L .1469 .26554 L 0 .025 .124 r
F
.14409 .26656 m .14205 .26465 L .14486 .26362 L F
.55368 .2751 m .55511 .27164 L .55673 .27387 L 0 .042 .144 r
F
.55368 .2751 m .55207 .27286 L .55511 .27164 L F
.1795 .26722 m .18033 .26433 L .18232 .26625 L 0 .026 .125 r
F
.1795 .26722 m .1775 .2653 L .18033 .26433 L F
.29343 .26878 m .29445 .26572 L .29633 .26764 L 0 .029 .129 r
F
.29343 .26878 m .29155 .26686 L .29445 .26572 L F
.5368 .51572 m .53523 .53231 L .53825 .52423 L .774 .757 0 r
F
.53378 .52309 m .53523 .53231 L .5368 .51572 L .8 .693 0 r
F
.68136 .27072 m .68298 .26734 L .68446 .26946 L 0 .033 .133 r
F
.68136 .27072 m .67987 .2686 L .68298 .26734 L F
.83676 .26732 m .83865 .26436 L .83996 .26626 L 0 .026 .126 r
F
.83676 .26732 m .83545 .2654 L .83865 .26436 L F
.56137 .27479 m .56281 .27129 L .56442 .27353 L 0 .041 .143 r
F
.56137 .27479 m .55977 .27258 L .56281 .27129 L F
.56906 .2744 m .57051 .27084 L .57211 .27306 L 0 .04 .142 r
F
.56906 .2744 m .56746 .2722 L .57051 .27084 L F
.49521 .27589 m .49655 .27228 L .49822 .27468 L 0 .044 .146 r
F
.49521 .27589 m .49354 .27345 L .49655 .27228 L F
.57675 .27399 m .57822 .27071 L .57981 .27296 L 0 .04 .142 r
F
.57675 .27399 m .57516 .27175 L .57822 .27071 L F
.68905 .27037 m .69069 .26719 L .69217 .26929 L 0 .032 .133 r
F
.68905 .27037 m .68757 .26826 L .69069 .26719 L F
.23027 .2672 m .23119 .26422 L .23313 .2662 L 0 .026 .125 r
F
.23027 .2672 m .22833 .26522 L .23119 .26422 L F
.77829 .26806 m .78008 .26501 L .78146 .26699 L 0 .028 .127 r
F
.77829 .26806 m .77691 .26608 L .78008 .26501 L F
.3011 .26849 m .30214 .26547 L .30401 .26744 L 0 .029 .129 r
F
.3011 .26849 m .29923 .26655 L .30214 .26547 L F
.10864 .26616 m .10936 .2632 L .11143 .26513 L 0 .024 .123 r
F
.10864 .26616 m .10657 .26422 L .10936 .2632 L F
.33652 .26915 m .3376 .26627 L .33944 .2682 L 0 .03 .131 r
F
.33652 .26915 m .33468 .26722 L .3376 .26627 L F
.71212 .26917 m .71379 .26596 L .71524 .26797 L 0 .03 .13 r
F
.71212 .26917 m .71067 .26719 L .71379 .26596 L F
.45512 .273 m .4564 .2699 L .45811 .27199 L 0 .038 .14 r
F
.45512 .273 m .45342 .27088 L .4564 .2699 L F
.26568 .2679 m .26666 .26494 L .26856 .26685 L 0 .028 .127 r
F
.26568 .2679 m .26377 .266 L .26666 .26494 L F
.15174 .26643 m .15252 .26351 L .15455 .26542 L 0 .025 .124 r
F
.15174 .26643 m .14971 .26452 L .15252 .26351 L F
.42739 .27198 m .42862 .2691 L .43036 .27107 L 0 .036 .138 r
F
.42739 .27198 m .42565 .27001 L .42862 .2691 L F
.36424 .27029 m .36537 .26741 L .36717 .2694 L 0 .033 .134 r
F
.36424 .27029 m .36244 .2683 L .36537 .26741 L F
.18715 .26711 m .18801 .26405 L .19 .26597 L 0 .026 .125 r
F
.18715 .26711 m .18516 .26519 L .18801 .26405 L F
.71981 .26882 m .7215 .26567 L .72295 .26771 L 0 .029 .129 r
F
.71981 .26882 m .71837 .2668 L .7215 .26567 L F
.70444 .26969 m .7061 .26646 L .70755 .26841 L 0 .031 .131 r
F
.70444 .26969 m .70298 .26776 L .7061 .26646 L F
.39966 .27099 m .40086 .26785 L .40262 .26993 L 0 .034 .135 r
F
.39966 .27099 m .3979 .26888 L .40086 .26785 L F
.78599 .26782 m .7878 .26484 L .78916 .26674 L 0 .028 .127 r
F
.78599 .26782 m .78463 .26592 L .7878 .26484 L F
.06551 .26613 m .06617 .26307 L .06829 .26501 L 0 .024 .123 r
F
.06551 .26613 m .06339 .26419 L .06617 .26307 L F
.62289 .2717 m .62443 .26846 L .62597 .27048 L 0 .035 .137 r
F
.62289 .2717 m .62135 .26969 L .62443 .26846 L F
.6152 .27213 m .61673 .26905 L .61827 .27092 L 0 .037 .138 r
F
.6152 .27213 m .61366 .27027 L .61673 .26905 L F
.48285 .27426 m .48418 .2709 L .48585 .2732 L 0 .041 .143 r
F
.48285 .27426 m .48117 .272 L .48418 .2709 L F
.1163 .26596 m .11704 .26291 L .11911 .26484 L 0 .024 .123 r
F
.1163 .26596 m .11423 .26402 L .11704 .26291 L F
.63827 .27087 m .63984 .26781 L .64136 .26982 L 0 .034 .135 r
F
.63827 .27087 m .63674 .26883 L .63984 .26781 L F
.60751 .27258 m .60903 .26955 L .61058 .27143 L 0 .038 .139 r
F
.60751 .27258 m .60596 .27068 L .60903 .26955 L F
.19482 .26683 m .1957 .26376 L .19767 .26578 L 0 .026 .125 r
F
.19482 .26683 m .19285 .26483 L .1957 .26376 L F
.63058 .27132 m .63212 .26796 L .63366 .27003 L 0 .034 .135 r
F
.63058 .27132 m .62904 .26922 L .63212 .26796 L F
.51827 .27495 m .51965 .27189 L .52129 .27386 L 0 .043 .145 r
F
.51827 .27495 m .51662 .273 L .51965 .27189 L F
.50289 .2758 m .50425 .27229 L .50591 .27458 L 0 .044 .146 r
F
.50289 .2758 m .50123 .27348 L .50425 .27229 L F
.51058 .27538 m .51195 .27222 L .5136 .27415 L F
.51058 .27538 m .50893 .2734 L .51195 .27222 L F
.69676 .27029 m .6984 .26699 L .69987 .26906 L 0 .032 .133 r
F
.69676 .27029 m .69529 .26821 L .6984 .26699 L F
.07317 .26584 m .07385 .26282 L .07595 .26477 L 0 .024 .122 r
F
.07317 .26584 m .07107 .2639 L .07385 .26282 L F
.72752 .26864 m .72921 .26539 L .73065 .26745 L 0 .029 .129 r
F
.72752 .26864 m .72608 .26659 L .72921 .26539 L F
.58445 .27399 m .58593 .27087 L .58751 .27292 L 0 .041 .143 r
F
.58445 .27399 m .58287 .27194 L .58593 .27087 L F
.27334 .26781 m .27434 .26472 L .27623 .26678 L 0 .028 .127 r
F
.27334 .26781 m .27145 .26578 L .27434 .26472 L F
.51431 .48735 m .51272 .46552 L .51574 .46457 L .365 .665 0 r
F
.5113 .48258 m .51272 .46552 L .51431 .48735 L .33 .655 0 r
F
.7937 .26762 m .79553 .26471 L .79688 .2666 L 0 .028 .127 r
F
.7937 .26762 m .79234 .26572 L .79553 .26471 L F
.30876 .26847 m .30982 .26533 L .31167 .26742 L 0 .029 .129 r
F
.30876 .26847 m .30691 .26638 L .30982 .26533 L F
.23792 .2672 m .23887 .26405 L .24079 .26609 L 0 .027 .126 r
F
.23792 .2672 m .23599 .26515 L .23887 .26405 L F
.34418 .26915 m .34528 .26619 L .34711 .26813 L 0 .031 .131 r
F
.34418 .26915 m .34236 .26719 L .34528 .26619 L F
.73522 .2683 m .73692 .26505 L .73835 .26713 L 0 .029 .128 r
F
.73522 .2683 m .73378 .26623 L .73692 .26505 L F
.40734 .27089 m .40854 .26774 L .4103 .26976 L 0 .034 .135 r
F
.40734 .27089 m .40558 .26884 L .40854 .26774 L F
.12396 .26577 m .12471 .26275 L .12675 .26478 L 0 .024 .123 r
F
.12396 .26577 m .12191 .26375 L .12471 .26275 L F
.4628 .27303 m .46409 .26996 L .46579 .27199 L 0 .039 .141 r
F
.4628 .27303 m .4611 .27097 L .46409 .26996 L F
.15938 .26643 m .16018 .26343 L .16219 .26544 L 0 .025 .124 r
F
.15938 .26643 m .15737 .26443 L .16018 .26343 L F
.59983 .27333 m .60133 .27005 L .60289 .27198 L 0 .039 .141 r
F
.59983 .27333 m .59827 .27138 L .60133 .27005 L F
.59214 .27377 m .59364 .27072 L .59521 .27268 L 0 .041 .143 r
F
.59214 .27377 m .59057 .27182 L .59364 .27072 L F
.37191 .27037 m .37306 .26723 L .37486 .26921 L 0 .033 .134 r
F
.37191 .27037 m .37011 .26839 L .37306 .26723 L F
.52596 .27485 m .52735 .27155 L .52899 .27367 L 0 .043 .145 r
F
.52596 .27485 m .52432 .27275 L .52735 .27155 L F
.08082 .26569 m .08152 .26263 L .08361 .26461 L 0 .024 .122 r
F
.08082 .26569 m .07873 .2637 L .08152 .26263 L F
.80141 .2674 m .80323 .26432 L .80458 .26623 L 0 .027 .127 r
F
.80141 .2674 m .80006 .2655 L .80323 .26432 L F
.43507 .27209 m .43632 .26875 L .43805 .27091 L 0 .037 .138 r
F
.43507 .27209 m .43334 .26995 L .43632 .26875 L F
.74292 .26805 m .74465 .26508 L .74607 .26703 L 0 .029 .129 r
F
.74292 .26805 m .7415 .26611 L .74465 .26508 L F
.8091 .26699 m .81095 .26405 L .81229 .26599 L 0 .027 .126 r
F
.8091 .26699 m .80776 .26507 L .81095 .26405 L F
.64597 .27084 m .64754 .2676 L .64906 .26964 L 0 .034 .135 r
F
.64597 .27084 m .64445 .26878 L .64754 .2676 L F
.65366 .27042 m .65525 .26717 L .65675 .26916 L 0 .033 .134 r
F
.65366 .27042 m .65215 .26839 L .65525 .26717 L F
.66135 .27001 m .66295 .26687 L .66445 .26884 L 0 .032 .133 r
F
.66135 .27001 m .65985 .26802 L .66295 .26687 L F
.20247 .26681 m .20336 .26367 L .20532 .26576 L 0 .026 .125 r
F
.20247 .26681 m .20051 .26473 L .20336 .26367 L F
.24559 .26702 m .24653 .264 L .24845 .26605 L 0 .027 .126 r
F
.24559 .26702 m .24367 .26499 L .24653 .264 L F
.37959 .27003 m .38076 .26691 L .38254 .26891 L 0 .033 .133 r
F
.37959 .27003 m .37781 .26805 L .38076 .26691 L F
.75831 .26733 m .76007 .26434 L .76147 .26629 L 0 .028 .127 r
F
.75831 .26733 m .75691 .26539 L .76007 .26434 L F
.75062 .26779 m .75236 .26467 L .75376 .26659 L 0 .028 .128 r
F
.75062 .26779 m .74921 .26589 L .75236 .26467 L F
.31643 .26845 m .3175 .26527 L .31934 .26735 L 0 .029 .129 r
F
.31643 .26845 m .31458 .26636 L .3175 .26527 L F
.35185 .26909 m .35297 .26606 L .35478 .2681 L 0 .031 .131 r
F
.35185 .26909 m .35004 .2671 L .35297 .26606 L F
.41501 .27082 m .41623 .26784 L .41798 .26988 L 0 .035 .136 r
F
.41501 .27082 m .41326 .2688 L .41623 .26784 L F
.53365 .27469 m .53505 .27129 L .53668 .27347 L 0 .043 .145 r
F
.53365 .27469 m .53202 .27248 L .53505 .27129 L F
.16702 .26639 m .16786 .26326 L .16985 .26531 L 0 .026 .125 r
F
.16702 .26639 m .16502 .26436 L .16786 .26326 L F
.49053 .2745 m .49187 .27103 L .49354 .27345 L 0 .042 .144 r
F
.49053 .2745 m .48886 .27211 L .49187 .27103 L F
.66906 .26982 m .67066 .26662 L .67216 .26875 L 0 .032 .133 r
F
.66906 .26982 m .66756 .26771 L .67066 .26662 L F
.54134 .2743 m .54275 .27093 L .54437 .27296 L 0 .042 .144 r
F
.54134 .2743 m .53972 .2722 L .54275 .27093 L F
.47048 .27303 m .47179 .26988 L .47348 .27195 L 0 .039 .141 r
F
.47048 .27303 m .46879 .27095 L .47179 .26988 L F
.08847 .26557 m .08918 .26245 L .09126 .26449 L 0 .024 .123 r
F
.08847 .26557 m .08639 .26354 L .08918 .26245 L F
.28099 .26792 m .28199 .26489 L .28387 .267 L 0 .029 .129 r
F
.28099 .26792 m .27911 .26583 L .28199 .26489 L F
.38727 .26984 m .38845 .26671 L .39022 .26879 L 0 .033 .133 r
F
.38727 .26984 m .3855 .26779 L .38845 .26671 L F
.44275 .27199 m .44402 .26854 L .44573 .27082 L 0 .037 .138 r
F
.44275 .27199 m .44103 .26972 L .44402 .26854 L F
.13158 .26584 m .13236 .26276 L .13439 .2648 L 0 .025 .123 r
F
.13158 .26584 m .12955 .2638 L .13236 .26276 L F
.81683 .26698 m .81868 .26399 L .82003 .26597 L 0 .027 .127 r
F
.81683 .26698 m .81549 .26501 L .81868 .26399 L F
.21012 .26677 m .21103 .26362 L .21298 .2657 L 0 .027 .126 r
F
.21012 .26677 m .20817 .26469 L .21103 .26362 L F
.3241 .26827 m .32518 .2651 L .32702 .26715 L 0 .029 .129 r
F
.3241 .26827 m .32226 .26623 L .32518 .2651 L F
.54903 .27404 m .55046 .27064 L .55207 .27286 L 0 .041 .143 r
F
.54903 .27404 m .54741 .2718 L .55046 .27064 L F
.76602 .26722 m .76779 .26421 L .76919 .26619 L 0 .028 .127 r
F
.76602 .26722 m .76463 .26526 L .76779 .26421 L F
.52508 .49262 m .52646 .46029 L .52811 .47817 L .381 .67 0 r
F
.52508 .49262 m .52343 .47309 L .52646 .46029 L F
.5085 .50256 m .50692 .48483 L .50988 .49734 L .622 .734 0 r
F
.50692 .48483 m .5083 .47784 L .50988 .49734 L .38 .67 0 r
F
.25324 .26705 m .25419 .26414 L .2561 .26609 L 0 .028 .127 r
F
.25324 .26705 m .25132 .2651 L .25419 .26414 L F
.17468 .26626 m .17551 .26326 L .1775 .2653 L 0 .026 .125 r
F
.17468 .26626 m .17268 .26424 L .17551 .26326 L F
.09612 .26543 m .09685 .26226 L .09892 .26432 L 0 .024 .123 r
F
.09612 .26543 m .09405 .26338 L .09685 .26226 L F
.2178 .26651 m .2187 .26345 L .22066 .26539 L 0 .026 .125 r
F
.2178 .26651 m .21584 .26458 L .2187 .26345 L F
.82454 .26677 m .8264 .26364 L .82773 .26559 L 0 .027 .126 r
F
.82454 .26677 m .82321 .2648 L .8264 .26364 L F
.13923 .26572 m .14002 .26268 L .14205 .26465 L 0 .025 .124 r
F
.13923 .26572 m .1372 .26374 L .14002 .26268 L F
.52978 .49594 m .53113 .46287 L .53279 .47893 L .409 .678 0 r
F
.52978 .49594 m .52811 .47817 L .53113 .46287 L F
.55673 .27387 m .55816 .27033 L .55977 .27258 L 0 .041 .143 r
F
.55673 .27387 m .55511 .27164 L .55816 .27033 L F
.45043 .27195 m .45171 .26859 L .45342 .27088 L 0 .037 .139 r
F
.45043 .27195 m .44872 .26966 L .45171 .26859 L F
.35951 .26918 m .36064 .26619 L .36244 .2683 L 0 .032 .133 r
F
.35951 .26918 m .35771 .26711 L .36064 .26619 L F
.67677 .26983 m .67838 .26646 L .67987 .2686 L 0 .033 .133 r
F
.67677 .26983 m .67527 .26769 L .67838 .26646 L F
.22547 .26621 m .22638 .26329 L .22833 .26522 L 0 .026 .125 r
F
.22547 .26621 m .22352 .26428 L .22638 .26329 L F
.83224 .26644 m .83413 .26348 L .83545 .2654 L 0 .027 .126 r
F
.83224 .26644 m .83092 .26451 L .83413 .26348 L F
.42269 .27092 m .42391 .26804 L .42565 .27001 L 0 .036 .137 r
F
.42269 .27092 m .42094 .26896 L .42391 .26804 L F
.33177 .26815 m .33285 .26528 L .33468 .26722 L 0 .03 .13 r
F
.33177 .26815 m .32993 .26621 L .33285 .26528 L F
.57211 .27306 m .57357 .2695 L .57516 .27175 L 0 .039 .141 r
F
.57211 .27306 m .57051 .27084 L .57357 .2695 L F
.47817 .27307 m .47949 .26973 L .48117 .272 L 0 .04 .142 r
F
.47817 .27307 m .47648 .27084 L .47949 .26973 L F
.39494 .26987 m .39613 .26683 L .3979 .26888 L 0 .033 .134 r
F
.39494 .26987 m .39318 .26781 L .39613 .26683 L F
.68446 .26946 m .68609 .26614 L .68757 .26826 L 0 .032 .133 r
F
.68446 .26946 m .68298 .26734 L .68609 .26614 L F
.77374 .26712 m .77552 .26405 L .77691 .26608 L 0 .028 .127 r
F
.77374 .26712 m .77235 .26512 L .77552 .26405 L F
.56442 .27353 m .56586 .26995 L .56746 .2722 L 0 .04 .142 r
F
.56442 .27353 m .56281 .27129 L .56586 .26995 L F
.28864 .268 m .28967 .26485 L .29155 .26686 L 0 .029 .129 r
F
.28864 .268 m .28676 .26599 L .28967 .26485 L F
.10378 .26524 m .1045 .26225 L .10657 .26422 L 0 .024 .123 r
F
.10378 .26524 m .10171 .26327 L .1045 .26225 L F
.29633 .26764 m .29736 .26461 L .29923 .26655 L 0 .029 .129 r
F
.29633 .26764 m .29445 .26572 L .29736 .26461 L F
.26089 .267 m .26186 .26412 L .26377 .266 L 0 .028 .127 r
F
.26089 .267 m .25898 .2651 L .26186 .26412 L F
.49822 .27468 m .49957 .2711 L .50123 .27348 L 0 .043 .145 r
F
.49822 .27468 m .49655 .27228 L .49957 .2711 L F
.1469 .26554 m .14768 .2626 L .14971 .26452 L 0 .025 .124 r
F
.1469 .26554 m .14486 .26362 L .14768 .2626 L F
.18232 .26625 m .18317 .26326 L .18516 .26519 L 0 .026 .126 r
F
.18232 .26625 m .18033 .26433 L .18317 .26326 L F
.71524 .26797 m .71692 .26476 L .71837 .2668 L 0 .03 .13 r
F
.71524 .26797 m .71379 .26596 L .71692 .26476 L F
.70755 .26841 m .70922 .2652 L .71067 .26719 L 0 .03 .131 r
F
.70755 .26841 m .7061 .26646 L .70922 .2652 L F
.69217 .26929 m .69381 .26612 L .69529 .26821 L 0 .032 .133 r
F
.69217 .26929 m .69069 .26719 L .69381 .26612 L F
.57981 .27296 m .58128 .26968 L .58287 .27194 L 0 .04 .142 r
F
.57981 .27296 m .57822 .27071 L .58128 .26968 L F
.78146 .26699 m .78325 .26393 L .78463 .26592 L 0 .028 .127 r
F
.78146 .26699 m .78008 .26501 L .78325 .26393 L F
.30401 .26744 m .30505 .2644 L .30691 .26638 L 0 .029 .129 r
F
.30401 .26744 m .30214 .26547 L .30505 .2644 L F
.19 .26597 m .19086 .26291 L .19285 .26483 L 0 .026 .125 r
F
.19 .26597 m .18801 .26405 L .19086 .26291 L F
.63366 .27003 m .63521 .26679 L .63674 .26883 L 0 .034 .135 r
F
.63366 .27003 m .63212 .26796 L .63521 .26679 L F
.23313 .2662 m .23406 .26318 L .23599 .26515 L 0 .027 .126 r
F
.23313 .2662 m .23119 .26422 L .23406 .26318 L F
.11143 .26513 m .11217 .2621 L .11423 .26402 L 0 .024 .123 r
F
.11143 .26513 m .10936 .2632 L .11217 .2621 L F
.26856 .26685 m .26955 .26385 L .27145 .26578 L 0 .028 .127 r
F
.26856 .26685 m .26666 .26494 L .26955 .26385 L F
.62597 .27048 m .62751 .2672 L .62904 .26922 L 0 .035 .136 r
F
.62597 .27048 m .62443 .26846 L .62751 .2672 L F
.72295 .26771 m .72464 .26453 L .72608 .26659 L 0 .029 .129 r
F
.72295 .26771 m .7215 .26567 L .72464 .26453 L F
.61827 .27092 m .61981 .26779 L .62135 .26969 L 0 .036 .137 r
F
.61827 .27092 m .61673 .26905 L .61981 .26779 L F
.45811 .27199 m .4594 .26891 L .4611 .27097 L 0 .038 .14 r
F
.45811 .27199 m .4564 .2699 L .4594 .26891 L F
.5136 .27415 m .51497 .27106 L .51662 .273 L 0 .043 .146 r
F
.5136 .27415 m .51195 .27222 L .51497 .27106 L F
.50591 .27458 m .50727 .27115 L .50893 .2734 L 0 .044 .146 r
F
.50591 .27458 m .50425 .27229 L .50727 .27115 L F
.33944 .2682 m .34052 .26529 L .34236 .26719 L 0 .031 .131 r
F
.33944 .2682 m .3376 .26627 L .34052 .26529 L F
.15455 .26542 m .15534 .26251 L .15737 .26443 L 0 .025 .124 r
F
.15455 .26542 m .15252 .26351 L .15534 .26251 L F
.69987 .26906 m .70152 .26571 L .70298 .26776 L 0 .032 .132 r
F
.69987 .26906 m .6984 .26699 L .70152 .26571 L F
.06829 .26501 m .06896 .26196 L .07107 .2639 L 0 .024 .123 r
F
.06829 .26501 m .06617 .26307 L .06896 .26196 L F
.40262 .26993 m .40382 .26679 L .40558 .26884 L 0 .034 .135 r
F
.40262 .26993 m .40086 .26785 L .40382 .26679 L F
.61058 .27143 m .61211 .26842 L .61366 .27027 L 0 .037 .139 r
F
.61058 .27143 m .60903 .26955 L .61211 .26842 L F
.78916 .26674 m .79098 .26383 L .79234 .26572 L 0 .028 .127 r
F
.78916 .26674 m .7878 .26484 L .79098 .26383 L F
.11911 .26484 m .11985 .26182 L .12191 .26375 L 0 .024 .122 r
F
.11911 .26484 m .11704 .26291 L .11985 .26182 L F
.48585 .2732 m .48719 .26978 L .48886 .27211 L 0 .041 .143 r
F
.48585 .2732 m .48418 .2709 L .48719 .26978 L F
.43036 .27107 m .4316 .26798 L .43334 .26995 L 0 .037 .138 r
F
.43036 .27107 m .42862 .2691 L .4316 .26798 L F
.50988 .49734 m .5083 .47784 L .5113 .48258 L .511 .705 0 r
F
.73065 .26745 m .73235 .26416 L .73378 .26623 L 0 .029 .129 r
F
.73065 .26745 m .72921 .26539 L .73235 .26416 L F
.52129 .27386 m .52268 .27075 L .52432 .27275 L 0 .043 .145 r
F
.52129 .27386 m .51965 .27189 L .52268 .27075 L F
.64136 .26982 m .64293 .26679 L .64445 .26878 L 0 .034 .135 r
F
.64136 .26982 m .63984 .26781 L .64293 .26679 L F
.36717 .2694 m .36831 .2664 L .37011 .26839 L 0 .033 .134 r
F
.36717 .2694 m .36537 .26741 L .36831 .2664 L F
.19767 .26578 m .19855 .26269 L .20051 .26473 L 0 .026 .125 r
F
.19767 .26578 m .1957 .26376 L .19855 .26269 L F
.60289 .27198 m .6044 .26875 L .60596 .27068 L 0 .038 .14 r
F
.60289 .27198 m .60133 .27005 L .6044 .26875 L F
.07595 .26477 m .07663 .26173 L .07873 .2637 L 0 .024 .122 r
F
.07595 .26477 m .07385 .26282 L .07663 .26173 L F
.73835 .26713 m .74007 .26402 L .7415 .26611 L 0 .029 .128 r
F
.73835 .26713 m .73692 .26505 L .74007 .26402 L F
.58751 .27292 m .58899 .26976 L .59057 .27182 L 0 .041 .143 r
F
.58751 .27292 m .58593 .27087 L .58899 .26976 L F
.24079 .26609 m .24174 .26295 L .24367 .26499 L 0 .027 .126 r
F
.24079 .26609 m .23887 .26405 L .24174 .26295 L F
.51431 .48735 m .51574 .46457 L .51734 .4864 L .365 .665 0 r
F
.4103 .26976 m .41151 .26676 L .41326 .2688 L 0 .034 .135 r
F
.4103 .26976 m .40854 .26774 L .41151 .26676 L F
.27623 .26678 m .27723 .26374 L .27911 .26583 L 0 .028 .128 r
F
.27623 .26678 m .27434 .26472 L .27723 .26374 L F
.31167 .26742 m .31273 .26428 L .31458 .26636 L 0 .029 .129 r
F
.31167 .26742 m .30982 .26533 L .31273 .26428 L F
.79688 .2666 m .7987 .2636 L .80006 .2655 L 0 .028 .127 r
F
.79688 .2666 m .79553 .26471 L .7987 .2636 L F
.65675 .26916 m .65835 .26605 L .65985 .26802 L 0 .033 .134 r
F
.65675 .26916 m .65525 .26717 L .65835 .26605 L F
.52899 .27367 m .53038 .27034 L .53202 .27248 L 0 .042 .145 r
F
.52899 .27367 m .52735 .27155 L .53038 .27034 L F
.34711 .26813 m .34821 .26513 L .35004 .2671 L 0 .031 .131 r
F
.34711 .26813 m .34528 .26619 L .34821 .26513 L F
.43805 .27091 m .43931 .26755 L .44103 .26972 L 0 .036 .138 r
F
.43805 .27091 m .43632 .26875 L .43931 .26755 L F
.64906 .26964 m .65064 .26638 L .65215 .26839 L 0 .034 .135 r
F
.64906 .26964 m .64754 .2676 L .65064 .26638 L F
.37486 .26921 m .37601 .26607 L .37781 .26805 L 0 .033 .134 r
F
.37486 .26921 m .37306 .26723 L .37601 .26607 L F
.46579 .27199 m .46709 .26894 L .46879 .27095 L 0 .039 .141 r
F
.46579 .27199 m .46409 .26996 L .46709 .26894 L F
.80458 .26623 m .80641 .26315 L .80776 .26507 L 0 .027 .126 r
F
.80458 .26623 m .80323 .26432 L .80641 .26315 L F
.66445 .26884 m .66606 .26575 L .66756 .26771 L 0 .032 .133 r
F
.66445 .26884 m .66295 .26687 L .66606 .26575 L F
.12675 .26478 m .12751 .26175 L .12955 .2638 L 0 .024 .123 r
F
.12675 .26478 m .12471 .26275 L .12751 .26175 L F
.59521 .27268 m .5967 .26943 L .59827 .27138 L 0 .04 .142 r
F
.59521 .27268 m .59364 .27072 L .5967 .26943 L F
.16219 .26544 m .16302 .26233 L .16502 .26436 L 0 .026 .124 r
F
.16219 .26544 m .16018 .26343 L .16302 .26233 L F
.08361 .26461 m .0843 .26155 L .08639 .26354 L 0 .024 .122 r
F
.08361 .26461 m .08152 .26263 L .0843 .26155 L F
.38254 .26891 m .38371 .26577 L .3855 .26779 L 0 .032 .133 r
F
.38254 .26891 m .38076 .26691 L .38371 .26577 L F
.54437 .27296 m .54579 .2698 L .54741 .2718 L 0 .041 .143 r
F
.54437 .27296 m .54275 .27093 L .54579 .2698 L F
.75376 .26659 m .7555 .26345 L .75691 .26539 L 0 .028 .127 r
F
.75376 .26659 m .75236 .26467 L .7555 .26345 L F
.74607 .26703 m .7478 .26394 L .74921 .26589 L 0 .029 .129 r
F
.74607 .26703 m .74465 .26508 L .7478 .26394 L F
.20532 .26576 m .20622 .2626 L .20817 .26469 L 0 .026 .125 r
F
.20532 .26576 m .20336 .26367 L .20622 .2626 L F
.81229 .26599 m .81414 .26305 L .81549 .26501 L 0 .027 .126 r
F
.81229 .26599 m .81095 .26405 L .81414 .26305 L F
.53075 .52401 m .53219 .54041 L .53378 .52309 L .813 .659 0 r
F
.53075 .52401 m .52914 .54133 L .53219 .54041 L F
.53668 .27347 m .53809 .27009 L .53972 .2722 L 0 .042 .144 r
F
.53668 .27347 m .53505 .27129 L .53809 .27009 L F
.24845 .26605 m .2494 .26302 L .25132 .2651 L 0 .027 .126 r
F
.24845 .26605 m .24653 .264 L .2494 .26302 L F
.31934 .26735 m .32042 .26414 L .32226 .26623 L 0 .029 .129 r
F
.31934 .26735 m .3175 .26527 L .32042 .26414 L F
.76147 .26629 m .76323 .26329 L .76463 .26526 L 0 .028 .127 r
F
.76147 .26629 m .76007 .26434 L .76323 .26329 L F
.44573 .27082 m .44701 .26735 L .44872 .26966 L 0 .036 .138 r
F
.44573 .27082 m .44402 .26854 L .44701 .26735 L F
.16985 .26531 m .17069 .26217 L .17268 .26424 L 0 .026 .124 r
F
.16985 .26531 m .16786 .26326 L .17069 .26217 L F
.35478 .2681 m .3559 .26503 L .35771 .26711 L 0 .031 .132 r
F
.35478 .2681 m .35297 .26606 L .3559 .26503 L F
.47348 .27195 m .47479 .26873 L .47648 .27084 L 0 .039 .141 r
F
.47348 .27195 m .47179 .26988 L .47479 .26873 L F
.67216 .26875 m .67378 .26554 L .67527 .26769 L 0 .032 .133 r
F
.67216 .26875 m .67066 .26662 L .67378 .26554 L F
.49354 .27345 m .49489 .26989 L .49655 .27228 L 0 .042 .144 r
F
.49354 .27345 m .49187 .27103 L .49489 .26989 L F
.09126 .26449 m .09198 .26132 L .09405 .26338 L 0 .024 .122 r
F
.09126 .26449 m .08918 .26245 L .09198 .26132 L F
.39022 .26879 m .3914 .26574 L .39318 .26781 L 0 .033 .133 r
F
.39022 .26879 m .38845 .26671 L .3914 .26574 L F
.55207 .27286 m .5535 .26943 L .55511 .27164 L 0 .041 .143 r
F
.55207 .27286 m .55046 .27064 L .5535 .26943 L F
.41798 .26988 m .4192 .26689 L .42094 .26896 L 0 .035 .136 r
F
.41798 .26988 m .41623 .26784 L .4192 .26689 L F
.32702 .26715 m .3281 .26415 L .32993 .26621 L 0 .03 .13 r
F
.32702 .26715 m .32518 .2651 L .3281 .26415 L F
.13439 .2648 m .13517 .26171 L .1372 .26374 L 0 .025 .123 r
F
.13439 .2648 m .13236 .26276 L .13517 .26171 L F
.21298 .2657 m .21389 .2625 L .21584 .26458 L 0 .026 .126 r
F
.21298 .2657 m .21103 .26362 L .21389 .2625 L F
.28387 .267 m .28489 .26386 L .28676 .26599 L 0 .029 .129 r
F
.28387 .267 m .28199 .26489 L .28489 .26386 L F
.54122 .50822 m .53967 .52153 L .54263 .50296 L .623 .734 0 r
F
.53825 .52423 m .53967 .52153 L .54122 .50822 L .796 .703 0 r
F
.55977 .27258 m .56121 .26902 L .56281 .27129 L 0 .04 .142 r
F
.55977 .27258 m .55816 .27033 L .56121 .26902 L F
.82003 .26597 m .82187 .26281 L .82321 .2648 L 0 .027 .126 r
F
.82003 .26597 m .81868 .26399 L .82187 .26281 L F
.76919 .26619 m .77096 .26312 L .77235 .26512 L 0 .028 .127 r
F
.76919 .26619 m .76779 .26421 L .77096 .26312 L F
.57516 .27175 m .57662 .26846 L .57822 .27071 L 0 .039 .141 r
F
.57516 .27175 m .57357 .2695 L .57662 .26846 L F
.56746 .2722 m .56891 .26859 L .57051 .27084 L F
.56746 .2722 m .56586 .26995 L .56891 .26859 L F
.82773 .26559 m .8296 .26257 L .83092 .26451 L 0 .027 .126 r
F
.82773 .26559 m .8264 .26364 L .8296 .26257 L F
.22066 .26539 m .22157 .26234 L .22352 .26428 L 0 .026 .125 r
F
.22066 .26539 m .2187 .26345 L .22157 .26234 L F
.09892 .26432 m .09965 .2612 L .10171 .26327 L 0 .024 .122 r
F
.09892 .26432 m .09685 .26226 L .09965 .2612 L F
.67987 .2686 m .68149 .26522 L .68298 .26734 L 0 .032 .133 r
F
.67987 .2686 m .67838 .26646 L .68149 .26522 L F
.2561 .26609 m .25706 .26317 L .25898 .2651 L 0 .028 .127 r
F
.2561 .26609 m .25419 .26414 L .25706 .26317 L F
.68757 .26826 m .68921 .2651 L .69069 .26719 L 0 .032 .132 r
F
.68757 .26826 m .68609 .26614 L .68921 .2651 L F
.14205 .26465 m .14283 .26165 L .14486 .26362 L 0 .025 .124 r
F
.14205 .26465 m .14002 .26268 L .14283 .26165 L F
.1775 .2653 m .17834 .26228 L .18033 .26433 L 0 .026 .125 r
F
.1775 .2653 m .17551 .26326 L .17834 .26228 L F
.45342 .27088 m .4547 .26761 L .4564 .2699 L 0 .037 .139 r
F
.45342 .27088 m .45171 .26859 L .4547 .26761 L F
.50123 .27348 m .50259 .26995 L .50425 .27229 L 0 .043 .145 r
F
.50123 .27348 m .49957 .2711 L .50259 .26995 L F
.29155 .26686 m .29258 .26371 L .29445 .26572 L 0 .029 .129 r
F
.29155 .26686 m .28967 .26485 L .29258 .26371 L F
.48117 .272 m .4825 .26859 L .48418 .2709 L 0 .04 .142 r
F
.48117 .272 m .47949 .26973 L .4825 .26859 L F
.83545 .2654 m .83733 .26246 L .83865 .26436 L 0 .027 .126 r
F
.83545 .2654 m .83413 .26348 L .83733 .26246 L F
.22833 .26522 m .22924 .26229 L .23119 .26422 L 0 .026 .126 r
F
.22833 .26522 m .22638 .26329 L .22924 .26229 L F
.77691 .26608 m .77869 .26297 L .78008 .26501 L 0 .028 .127 r
F
.77691 .26608 m .77552 .26405 L .77869 .26297 L F
.3979 .26888 m .39909 .26581 L .40086 .26785 L 0 .034 .134 r
F
.3979 .26888 m .39613 .26683 L .39909 .26581 L F
.71067 .26719 m .71234 .26395 L .71379 .26596 L 0 .03 .13 r
F
.71067 .26719 m .70922 .2652 L .71234 .26395 L F
.29923 .26655 m .30027 .26351 L .30214 .26547 L 0 .029 .129 r
F
.29923 .26655 m .29736 .26461 L .30027 .26351 L F
.10657 .26422 m .10729 .26123 L .10936 .2632 L 0 .025 .123 r
F
.10657 .26422 m .1045 .26225 L .10729 .26123 L F
.33468 .26722 m .33576 .26434 L .3376 .26627 L 0 .031 .131 r
F
.33468 .26722 m .33285 .26528 L .33576 .26434 L F
.71837 .2668 m .72006 .26361 L .7215 .26567 L 0 .029 .129 r
F
.71837 .2668 m .71692 .26476 L .72006 .26361 L F
.36244 .2683 m .36357 .26527 L .36537 .26741 L 0 .033 .133 r
F
.36244 .2683 m .36064 .26619 L .36357 .26527 L F
.42565 .27001 m .42688 .26713 L .42862 .2691 L 0 .036 .138 r
F
.42565 .27001 m .42391 .26804 L .42688 .26713 L F
.26377 .266 m .26474 .26305 L .26666 .26494 L 0 .028 .128 r
F
.26377 .266 m .26186 .26412 L .26474 .26305 L F
.14971 .26452 m .15049 .26159 L .15252 .26351 L 0 .025 .124 r
F
.14971 .26452 m .14768 .2626 L .15049 .26159 L F
.62904 .26922 m .63059 .26594 L .63212 .26796 L 0 .034 .135 r
F
.62904 .26922 m .62751 .2672 L .63059 .26594 L F
.18516 .26519 m .18602 .26212 L .18801 .26405 L 0 .026 .125 r
F
.18516 .26519 m .18317 .26326 L .18602 .26212 L F
.70298 .26776 m .70464 .26442 L .7061 .26646 L 0 .031 .131 r
F
.70298 .26776 m .70152 .26571 L .70464 .26442 L F
.63674 .26883 m .63831 .26579 L .63984 .26781 L 0 .034 .135 r
F
.63674 .26883 m .63521 .26679 L .63831 .26579 L F
.62135 .26969 m .62289 .26652 L .62443 .26846 L 0 .035 .137 r
F
.62135 .26969 m .61981 .26779 L .62289 .26652 L F
.69529 .26821 m .69693 .26492 L .6984 .26699 L 0 .032 .133 r
F
.69529 .26821 m .69381 .26612 L .69693 .26492 L F
.19285 .26483 m .19371 .26181 L .1957 .26376 L 0 .026 .125 r
F
.19285 .26483 m .19086 .26291 L .19371 .26181 L F
.78463 .26592 m .78642 .26285 L .7878 .26484 L 0 .028 .127 r
F
.78463 .26592 m .78325 .26393 L .78642 .26285 L F
.50893 .2734 m .51029 .27 L .51195 .27222 L 0 .043 .146 r
F
.50893 .2734 m .50727 .27115 L .51029 .27 L F
.11423 .26402 m .11498 .26099 L .11704 .26291 L 0 .024 .123 r
F
.11423 .26402 m .11217 .2621 L .11498 .26099 L F
.72608 .26659 m .72777 .26331 L .72921 .26539 L 0 .029 .129 r
F
.72608 .26659 m .72464 .26453 L .72777 .26331 L F
.30691 .26638 m .30795 .26337 L .30982 .26533 L F
.30691 .26638 m .30505 .2644 L .30795 .26337 L F
.58287 .27194 m .58434 .2686 L .58593 .27087 L 0 .04 .142 r
F
.58287 .27194 m .58128 .26968 L .58434 .2686 L F
.51662 .273 m .518 .26991 L .51965 .27189 L 0 .043 .145 r
F
.51662 .273 m .51497 .27106 L .518 .26991 L F
.60596 .27068 m .60748 .26761 L .60903 .26955 L 0 .038 .14 r
F
.60596 .27068 m .6044 .26875 L .60748 .26761 L F
.27145 .26578 m .27244 .26276 L .27434 .26472 L 0 .028 .127 r
F
.27145 .26578 m .26955 .26385 L .27244 .26276 L F
.61366 .27027 m .61518 .26718 L .61673 .26905 L 0 .037 .139 r
F
.61366 .27027 m .61211 .26842 L .61518 .26718 L F
.23599 .26515 m .23693 .26208 L .23887 .26405 L 0 .027 .126 r
F
.23599 .26515 m .23406 .26318 L .23693 .26208 L F
.73378 .26623 m .73549 .26296 L .73692 .26505 L 0 .028 .128 r
F
.73378 .26623 m .73235 .26416 L .73549 .26296 L F
.07107 .2639 m .07174 .26086 L .07385 .26282 L 0 .024 .123 r
F
.07107 .2639 m .06896 .26196 L .07174 .26086 L F
.40558 .26884 m .40678 .26573 L .40854 .26774 L 0 .034 .135 r
F
.40558 .26884 m .40382 .26679 L .40678 .26573 L F
.4611 .27097 m .46239 .26793 L .46409 .26996 L 0 .039 .14 r
F
.4611 .27097 m .4594 .26891 L .46239 .26793 L F
.12191 .26375 m .12265 .26081 L .12471 .26275 L 0 .024 .123 r
F
.12191 .26375 m .11985 .26182 L .12265 .26081 L F
.43334 .26995 m .43459 .26678 L .43632 .26875 L 0 .036 .138 r
F
.43334 .26995 m .4316 .26798 L .43459 .26678 L F
.34236 .26719 m .34345 .2643 L .34528 .26619 L 0 .031 .131 r
F
.34236 .26719 m .34052 .26529 L .34345 .2643 L F
.52432 .27275 m .52571 .26951 L .52735 .27155 L 0 .042 .145 r
F
.52432 .27275 m .52268 .27075 L .52571 .26951 L F
.48886 .27211 m .4902 .26866 L .49187 .27103 L 0 .041 .143 r
F
.48886 .27211 m .48719 .26978 L .4902 .26866 L F
.15737 .26443 m .15816 .26152 L .16018 .26343 L 0 .026 .124 r
F
.15737 .26443 m .15534 .26251 L .15816 .26152 L F
.79234 .26572 m .79417 .26281 L .79553 .26471 L 0 .028 .128 r
F
.79234 .26572 m .79098 .26383 L .79417 .26281 L F
.64445 .26878 m .64603 .26563 L .64754 .2676 L 0 .034 .135 r
F
.64445 .26878 m .64293 .26679 L .64603 .26563 L F
.20051 .26473 m .2014 .26161 L .20336 .26367 L 0 .026 .125 r
F
.20051 .26473 m .19855 .26269 L .2014 .26161 L F
.37011 .26839 m .37126 .26525 L .37306 .26723 L 0 .033 .134 r
F
.37011 .26839 m .36831 .2664 L .37126 .26525 L F
.59827 .27138 m .59977 .2681 L .60133 .27005 L 0 .039 .141 r
F
.59827 .27138 m .5967 .26943 L .59977 .2681 L F
.65215 .26839 m .65374 .26517 L .65525 .26717 L 0 .033 .134 r
F
.65215 .26839 m .65064 .26638 L .65374 .26517 L F
.07873 .2637 m .07942 .26066 L .08152 .26263 L 0 .024 .122 r
F
.07873 .2637 m .07663 .26173 L .07942 .26066 L F
.59057 .27182 m .59206 .26865 L .59364 .27072 L 0 .041 .143 r
F
.59057 .27182 m .58899 .26976 L .59206 .26865 L F
.24367 .26499 m .24461 .26193 L .24653 .264 L 0 .027 .126 r
F
.24367 .26499 m .24174 .26295 L .24461 .26193 L F
.53202 .27248 m .53342 .26916 L .53505 .27129 L 0 .042 .144 r
F
.53202 .27248 m .53038 .27034 L .53342 .26916 L F
.44103 .26972 m .4423 .26636 L .44402 .26854 L 0 .036 .137 r
F
.44103 .26972 m .43931 .26755 L .4423 .26636 L F
.65985 .26802 m .66145 .26493 L .66295 .26687 L 0 .033 .133 r
F
.65985 .26802 m .65835 .26605 L .66145 .26493 L F
.7415 .26611 m .74323 .26299 L .74465 .26508 L 0 .029 .128 r
F
.7415 .26611 m .74007 .26402 L .74323 .26299 L F
.37781 .26805 m .37897 .26492 L .38076 .26691 L 0 .033 .133 r
F
.37781 .26805 m .37601 .26607 L .37897 .26492 L F
.80776 .26507 m .8096 .2621 L .81095 .26405 L 0 .027 .126 r
F
.80776 .26507 m .80641 .26315 L .8096 .2621 L F
.80006 .2655 m .80188 .26241 L .80323 .26432 L 0 .028 .127 r
F
.80006 .2655 m .7987 .2636 L .80188 .26241 L F
.31458 .26636 m .31565 .26319 L .3175 .26527 L 0 .029 .129 r
F
.31458 .26636 m .31273 .26428 L .31565 .26319 L F
.66756 .26771 m .66917 .26467 L .67066 .26662 L 0 .032 .133 r
F
.66756 .26771 m .66606 .26575 L .66917 .26467 L F
.53972 .2722 m .54113 .26889 L .54275 .27093 L 0 .041 .144 r
F
.53972 .2722 m .53809 .27009 L .54113 .26889 L F
.41326 .2688 m .41448 .26577 L .41623 .26784 L 0 .035 .136 r
F
.41326 .2688 m .41151 .26676 L .41448 .26577 L F
.35004 .2671 m .35115 .26406 L .35297 .26606 L 0 .031 .131 r
F
.35004 .2671 m .34821 .26513 L .35115 .26406 L F
.54741 .2718 m .54884 .26869 L .55046 .27064 L 0 .041 .143 r
F
.54741 .2718 m .54579 .2698 L .54884 .26869 L F
.75691 .26539 m .75867 .26238 L .76007 .26434 L 0 .028 .127 r
F
.75691 .26539 m .7555 .26345 L .75867 .26238 L F
.46879 .27095 m .47009 .26789 L .47179 .26988 L 0 .039 .141 r
F
.46879 .27095 m .46709 .26894 L .47009 .26789 L F
.27911 .26583 m .28011 .26277 L .28199 .26489 L 0 .028 .128 r
F
.27911 .26583 m .27723 .26374 L .28011 .26277 L F
.16502 .26436 m .16586 .26121 L .16786 .26326 L 0 .026 .124 r
F
.16502 .26436 m .16302 .26233 L .16586 .26121 L F
.3855 .26779 m .38667 .26466 L .38845 .26671 L 0 .032 .133 r
F
.3855 .26779 m .38371 .26577 L .38667 .26466 L F
.08639 .26354 m .08709 .26047 L .08918 .26245 L 0 .024 .122 r
F
.08639 .26354 m .0843 .26155 L .08709 .26047 L F
.74921 .26589 m .75095 .26271 L .75236 .26467 L 0 .028 .128 r
F
.74921 .26589 m .7478 .26394 L .75095 .26271 L F
.12955 .2638 m .13032 .26072 L .13236 .26276 L 0 .025 .123 r
F
.12955 .2638 m .12751 .26175 L .13032 .26072 L F
.20817 .26469 m .20907 .26153 L .21103 .26362 L 0 .026 .125 r
F
.20817 .26469 m .20622 .2626 L .20907 .26153 L F
.53378 .52309 m .53219 .54041 L .53523 .53231 L .8 .693 0 r
F
.32226 .26623 m .32334 .263 L .32518 .2651 L 0 .029 .129 r
F
.32226 .26623 m .32042 .26414 L .32334 .263 L F
.44872 .26966 m .45 .26628 L .45171 .26859 L 0 .036 .137 r
F
.44872 .26966 m .44701 .26735 L .45 .26628 L F
.81549 .26501 m .81734 .262 L .81868 .26399 L 0 .027 .127 r
F
.81549 .26501 m .81414 .26305 L .81734 .262 L F
.49655 .27228 m .4979 .26874 L .49957 .2711 L 0 .042 .144 r
F
.49655 .27228 m .49489 .26989 L .4979 .26874 L F
.55511 .27164 m .55655 .2681 L .55816 .27033 L 0 .04 .142 r
F
.55511 .27164 m .5535 .26943 L .55655 .2681 L F
.76463 .26526 m .7664 .26222 L .76779 .26421 L 0 .028 .127 r
F
.76463 .26526 m .76323 .26329 L .7664 .26222 L F
.47648 .27084 m .4778 .26759 L .47949 .26973 L 0 .039 .141 r
F
.47648 .27084 m .47479 .26873 L .4778 .26759 L F
.57051 .27084 m .57197 .26725 L .57357 .2695 L 0 .038 .14 r
F
.57051 .27084 m .56891 .26859 L .57197 .26725 L F
.09405 .26338 m .09478 .2602 L .09685 .26226 L 0 .024 .122 r
F
.09405 .26338 m .09198 .26132 L .09478 .2602 L F
.17268 .26424 m .17352 .26117 L .17551 .26326 L 0 .026 .125 r
F
.17268 .26424 m .17069 .26217 L .17352 .26117 L F
.56281 .27129 m .56426 .26768 L .56586 .26995 L 0 .039 .141 r
F
.56281 .27129 m .56121 .26902 L .56426 .26768 L F
.25132 .2651 m .25228 .26204 L .25419 .26414 L 0 .027 .127 r
F
.25132 .2651 m .2494 .26302 L .25228 .26204 L F
.67527 .26769 m .67689 .26432 L .67838 .26646 L 0 .032 .133 r
F
.67527 .26769 m .67378 .26554 L .67689 .26432 L F
.35771 .26711 m .35884 .26407 L .36064 .26619 L 0 .032 .132 r
F
.35771 .26711 m .3559 .26503 L .35884 .26407 L F
.68298 .26734 m .6846 .26404 L .68609 .26614 L F
.68298 .26734 m .68149 .26522 L .6846 .26404 L F
.21584 .26458 m .21676 .26136 L .2187 .26345 L 0 .026 .125 r
F
.21584 .26458 m .21389 .2625 L .21676 .26136 L F
.82321 .2648 m .82506 .26164 L .8264 .26364 L 0 .027 .126 r
F
.82321 .2648 m .82187 .26281 L .82506 .26164 L F
.1372 .26374 m .13798 .26066 L .14002 .26268 L 0 .025 .124 r
F
.1372 .26374 m .13517 .26171 L .13798 .26066 L F
.39318 .26781 m .39436 .26477 L .39613 .26683 L 0 .033 .134 r
F
.39318 .26781 m .3914 .26574 L .39436 .26477 L F
.42094 .26896 m .42217 .26596 L .42391 .26804 L 0 .036 .137 r
F
.42094 .26896 m .4192 .26689 L .42217 .26596 L F
.77235 .26512 m .77413 .26202 L .77552 .26405 L 0 .028 .127 r
F
.77235 .26512 m .77096 .26312 L .77413 .26202 L F
.22352 .26428 m .22443 .26135 L .22638 .26329 L 0 .026 .125 r
F
.22352 .26428 m .22157 .26234 L .22443 .26135 L F
.28676 .26599 m .2878 .26272 L .28967 .26485 L 0 .029 .129 r
F
.28676 .26599 m .28489 .26386 L .2878 .26272 L F
.32993 .26621 m .33101 .26322 L .33285 .26528 L 0 .03 .13 r
F
.32993 .26621 m .3281 .26415 L .33101 .26322 L F
.83092 .26451 m .8328 .26156 L .83413 .26348 L 0 .027 .126 r
F
.83092 .26451 m .8296 .26257 L .8328 .26156 L F
.57822 .27071 m .57969 .26741 L .58128 .26968 L 0 .039 .141 r
F
.57822 .27071 m .57662 .26846 L .57969 .26741 L F
.10171 .26327 m .10244 .26018 L .1045 .26225 L 0 .024 .123 r
F
.10171 .26327 m .09965 .2612 L .10244 .26018 L F
.50425 .27229 m .50561 .26883 L .50727 .27115 L 0 .042 .145 r
F
.50425 .27229 m .50259 .26995 L .50561 .26883 L F
.69069 .26719 m .69234 .26405 L .69381 .26612 L 0 .032 .133 r
F
.69069 .26719 m .68921 .2651 L .69234 .26405 L F
.29445 .26572 m .29549 .26258 L .29736 .26461 L 0 .029 .129 r
F
.29445 .26572 m .29258 .26371 L .29549 .26258 L F
.25898 .2651 m .25994 .26219 L .26186 .26412 L 0 .028 .128 r
F
.25898 .2651 m .25706 .26317 L .25994 .26219 L F
.71379 .26596 m .71547 .26273 L .71692 .26476 L 0 .029 .129 r
F
.71379 .26596 m .71234 .26395 L .71547 .26273 L F
.14486 .26362 m .14565 .26061 L .14768 .2626 L 0 .025 .124 r
F
.14486 .26362 m .14283 .26165 L .14565 .26061 L F
.48418 .2709 m .48551 .26744 L .48719 .26978 L 0 .039 .141 r
F
.48418 .2709 m .4825 .26859 L .48551 .26744 L F
.7061 .26646 m .70776 .2632 L .70922 .2652 L 0 .03 .131 r
F
.7061 .26646 m .70464 .26442 L .70776 .2632 L F
.63212 .26796 m .63368 .26477 L .63521 .26679 L 0 .034 .135 r
F
.63212 .26796 m .63059 .26594 L .63368 .26477 L F
.18033 .26433 m .18118 .2612 L .18317 .26326 L 0 .026 .126 r
F
.18033 .26433 m .17834 .26228 L .18118 .2612 L F
.4564 .2699 m .45769 .26664 L .4594 .26891 L 0 .038 .139 r
F
.4564 .2699 m .4547 .26761 L .45769 .26664 L F
.78008 .26501 m .78186 .26187 L .78325 .26393 L 0 .028 .127 r
F
.78008 .26501 m .77869 .26297 L .78186 .26187 L F
.7215 .26567 m .72319 .26246 L .72464 .26453 L 0 .029 .129 r
F
.7215 .26567 m .72006 .26361 L .72319 .26246 L F
.62443 .26846 m .62597 .26525 L .62751 .2672 L 0 .035 .136 r
F
.62443 .26846 m .62289 .26652 L .62597 .26525 L F
.30214 .26547 m .30318 .26242 L .30505 .2644 L 0 .029 .129 r
F
.30214 .26547 m .30027 .26351 L .30318 .26242 L F
.40086 .26785 m .40205 .26477 L .40382 .26679 L 0 .034 .135 r
F
.40086 .26785 m .39909 .26581 L .40205 .26477 L F
.6984 .26699 m .70005 .26365 L .70152 .26571 L 0 .031 .132 r
F
.6984 .26699 m .69693 .26492 L .70005 .26365 L F
.23119 .26422 m .23211 .26126 L .23406 .26318 L 0 .027 .126 r
F
.23119 .26422 m .22924 .26229 L .23211 .26126 L F
.18801 .26405 m .18887 .26098 L .19086 .26291 L 0 .026 .125 r
F
.18801 .26405 m .18602 .26212 L .18887 .26098 L F
.10936 .2632 m .1101 .26014 L .11217 .2621 L 0 .025 .123 r
F
.10936 .2632 m .10729 .26123 L .1101 .26014 L F
.26666 .26494 m .26764 .26194 L .26955 .26385 L 0 .028 .128 r
F
.26666 .26494 m .26474 .26305 L .26764 .26194 L F
.51195 .27222 m .51332 .26882 L .51497 .27106 L 0 .043 .145 r
F
.51195 .27222 m .51029 .27 L .51332 .26882 L F
.72921 .26539 m .73091 .26207 L .73235 .26416 L 0 .028 .128 r
F
.72921 .26539 m .72777 .26331 L .73091 .26207 L F
.3376 .26627 m .33869 .26338 L .34052 .26529 L 0 .031 .131 r
F
.3376 .26627 m .33576 .26434 L .33869 .26338 L F
.61673 .26905 m .61826 .26588 L .61981 .26779 L 0 .036 .138 r
F
.61673 .26905 m .61518 .26718 L .61826 .26588 L F
.15252 .26351 m .15331 .26059 L .15534 .26251 L 0 .026 .124 r
F
.15252 .26351 m .15049 .26159 L .15331 .26059 L F
.63984 .26781 m .64141 .2648 L .64293 .26679 L 0 .034 .135 r
F
.63984 .26781 m .63831 .26579 L .64141 .2648 L F
.1957 .26376 m .19657 .26071 L .19855 .26269 L 0 .026 .125 r
F
.1957 .26376 m .19371 .26181 L .19657 .26071 L F
.42862 .2691 m .42986 .266 L .4316 .26798 L 0 .037 .138 r
F
.42862 .2691 m .42688 .26713 L .42986 .266 L F
.11704 .26291 m .11779 .2599 L .11985 .26182 L 0 .024 .123 r
F
.11704 .26291 m .11498 .26099 L .11779 .2599 L F
.73692 .26505 m .73864 .26193 L .74007 .26402 L 0 .028 .128 r
F
.73692 .26505 m .73549 .26296 L .73864 .26193 L F
.51965 .27189 m .52103 .26874 L .52268 .27075 L 0 .043 .145 r
F
.51965 .27189 m .518 .26991 L .52103 .26874 L F
.7878 .26484 m .78961 .26184 L .79098 .26383 L 0 .028 .128 r
F
.7878 .26484 m .78642 .26285 L .78961 .26184 L F
.36537 .26741 m .36652 .26425 L .36831 .2664 L 0 .033 .134 r
F
.36537 .26741 m .36357 .26527 L .36652 .26425 L F
.60903 .26955 m .61055 .26647 L .61211 .26842 L 0 .038 .139 r
F
.60903 .26955 m .60748 .26761 L .61055 .26647 L F
.58593 .27087 m .58741 .26748 L .58899 .26976 L 0 .04 .142 r
F
.58593 .27087 m .58434 .2686 L .58741 .26748 L F
.23887 .26405 m .23981 .26099 L .24174 .26295 L 0 .026 .126 r
F
.23887 .26405 m .23693 .26208 L .23981 .26099 L F
.43632 .26875 m .43758 .26557 L .43931 .26755 L 0 .036 .137 r
F
.43632 .26875 m .43459 .26678 L .43758 .26557 L F
.30982 .26533 m .31087 .26235 L .31273 .26428 L 0 .029 .129 r
F
.30982 .26533 m .30795 .26337 L .31087 .26235 L F
.60133 .27005 m .60284 .26682 L .6044 .26875 L 0 .039 .14 r
F
.60133 .27005 m .59977 .2681 L .60284 .26682 L F
.52735 .27155 m .52874 .26828 L .53038 .27034 L 0 .042 .144 r
F
.52735 .27155 m .52571 .26951 L .52874 .26828 L F
.27434 .26472 m .27533 .26177 L .27723 .26374 L 0 .028 .128 r
F
.27434 .26472 m .27244 .26276 L .27533 .26177 L F
.07385 .26282 m .07453 .25976 L .07663 .26173 L 0 .024 .123 r
F
.07385 .26282 m .07174 .26086 L .07453 .25976 L F
.40854 .26774 m .40975 .26471 L .41151 .26676 L 0 .034 .135 r
F
.40854 .26774 m .40678 .26573 L .40975 .26471 L F
.53967 .52153 m .54103 .50762 L .54263 .50296 L .774 .758 0 r
F
.65525 .26717 m .65684 .26408 L .65835 .26605 L 0 .033 .134 r
F
.65525 .26717 m .65374 .26517 L .65684 .26408 L F
.64754 .2676 m .64912 .26442 L .65064 .26638 L 0 .034 .134 r
F
.64754 .2676 m .64603 .26563 L .64912 .26442 L F
.49187 .27103 m .49321 .26757 L .49489 .26989 L 0 .04 .142 r
F
.49187 .27103 m .4902 .26866 L .49321 .26757 L F
.46409 .26996 m .46539 .26694 L .46709 .26894 L 0 .039 .141 r
F
.46409 .26996 m .46239 .26793 L .46539 .26694 L F
.53505 .27129 m .53646 .26801 L .53809 .27009 L 0 .041 .144 r
F
.53505 .27129 m .53342 .26916 L .53646 .26801 L F
.37306 .26723 m .37422 .26409 L .37601 .26607 L 0 .033 .134 r
F
.37306 .26723 m .37126 .26525 L .37422 .26409 L F
.12471 .26275 m .12546 .2598 L .12751 .26175 L 0 .024 .123 r
F
.12471 .26275 m .12265 .26081 L .12546 .2598 L F
.44402 .26854 m .44529 .26516 L .44701 .26735 L 0 .035 .137 r
F
.44402 .26854 m .4423 .26636 L .44529 .26516 L F
.34528 .26619 m .34638 .26324 L .34821 .26513 L 0 .031 .132 r
F
.34528 .26619 m .34345 .2643 L .34638 .26324 L F
.79553 .26471 m .79735 .2617 L .7987 .2636 L 0 .028 .128 r
F
.79553 .26471 m .79417 .26281 L .79735 .2617 L F
.16018 .26343 m .161 .26041 L .16302 .26233 L 0 .026 .124 r
F
.16018 .26343 m .15816 .26152 L .161 .26041 L F
.66295 .26687 m .66456 .26383 L .66606 .26575 L 0 .032 .133 r
F
.66295 .26687 m .66145 .26493 L .66456 .26383 L F
.54275 .27093 m .54417 .2678 L .54579 .2698 L 0 .041 .143 r
F
.54275 .27093 m .54113 .26889 L .54417 .2678 L F
.59364 .27072 m .59513 .26737 L .5967 .26943 L 0 .04 .142 r
F
.59364 .27072 m .59206 .26865 L .59513 .26737 L F
.20336 .26367 m .20425 .26055 L .20622 .2626 L 0 .026 .125 r
F
.20336 .26367 m .2014 .26161 L .20425 .26055 L F
.80323 .26432 m .80506 .26122 L .80641 .26315 L 0 .027 .127 r
F
.80323 .26432 m .80188 .26241 L .80506 .26122 L F
.08152 .26263 m .08221 .2596 L .0843 .26155 L 0 .024 .123 r
F
.08152 .26263 m .07942 .26066 L .08221 .2596 L F
.38076 .26691 m .38193 .26376 L .38371 .26577 L 0 .032 .133 r
F
.38076 .26691 m .37897 .26492 L .38193 .26376 L F
.3175 .26527 m .31857 .26205 L .32042 .26414 L 0 .029 .129 r
F
.3175 .26527 m .31565 .26319 L .31857 .26205 L F
.24653 .264 m .24749 .26093 L .2494 .26302 L 0 .027 .126 r
F
.24653 .264 m .24461 .26193 L .24749 .26093 L F
.74465 .26508 m .74638 .26186 L .7478 .26394 L 0 .029 .128 r
F
.74465 .26508 m .74323 .26299 L .74638 .26186 L F
.55046 .27064 m .55189 .2675 L .5535 .26943 L 0 .041 .143 r
F
.55046 .27064 m .54884 .26869 L .55189 .2675 L F
.75236 .26467 m .7541 .26148 L .7555 .26345 L 0 .028 .128 r
F
.75236 .26467 m .75095 .26271 L .7541 .26148 L F
.50877 .51084 m .50715 .50267 L .51009 .51936 L .774 .758 0 r
F
.5104 .51902 m .50877 .51084 L .51173 .52825 L .8 .694 0 r
F
.50877 .51084 m .51009 .51936 L .51173 .52825 L .774 .758 0 r
F
.50715 .50267 m .5085 .50256 L .51009 .51936 L .622 .734 0 r
F
.81095 .26405 m .8128 .26108 L .81414 .26305 L 0 .027 .126 r
F
.81095 .26405 m .8096 .2621 L .8128 .26108 L F
.67066 .26662 m .67229 .26358 L .67378 .26554 L 0 .032 .133 r
F
.67066 .26662 m .66917 .26467 L .67229 .26358 L F
.47179 .26988 m .4731 .26671 L .47479 .26873 L 0 .039 .141 r
F
.47179 .26988 m .47009 .26789 L .4731 .26671 L F
.16786 .26326 m .1687 .26011 L .17069 .26217 L 0 .025 .124 r
F
.16786 .26326 m .16586 .26121 L .1687 .26011 L F
.76007 .26434 m .76183 .26131 L .76323 .26329 L 0 .028 .127 r
F
.76007 .26434 m .75867 .26238 L .76183 .26131 L F
.55816 .27033 m .5596 .26676 L .56121 .26902 L 0 .039 .141 r
F
.55816 .27033 m .55655 .2681 L .5596 .26676 L F
.35297 .26606 m .35409 .26298 L .3559 .26503 L 0 .031 .131 r
F
.35297 .26606 m .35115 .26406 L .35409 .26298 L F
.38845 .26671 m .38962 .26371 L .3914 .26574 L 0 .032 .133 r
F
.38845 .26671 m .38667 .26466 L .38962 .26371 L F
.08918 .26245 m .0899 .25933 L .09198 .26132 L 0 .024 .122 r
F
.08918 .26245 m .08709 .26047 L .0899 .25933 L F
.57357 .2695 m .57503 .26622 L .57662 .26846 L 0 .038 .14 r
F
.57357 .2695 m .57197 .26725 L .57503 .26622 L F
.56586 .26995 m .56731 .26632 L .56891 .26859 L F
.56586 .26995 m .56426 .26768 L .56731 .26632 L F
.41623 .26784 m .41745 .26479 L .4192 .26689 L 0 .035 .136 r
F
.41623 .26784 m .41448 .26577 L .41745 .26479 L F
.28199 .26489 m .28301 .26173 L .28489 .26386 L 0 .029 .128 r
F
.28199 .26489 m .28011 .26277 L .28301 .26173 L F
.32518 .2651 m .32626 .26204 L .3281 .26415 L 0 .029 .129 r
F
.32518 .2651 m .32334 .263 L .32626 .26204 L F
.21103 .26362 m .21194 .2604 L .21389 .2625 L 0 .026 .125 r
F
.21103 .26362 m .20907 .26153 L .21194 .2604 L F
.13236 .26276 m .13313 .25967 L .13517 .26171 L 0 .025 .123 r
F
.13236 .26276 m .13032 .26072 L .13313 .25967 L F
.49957 .2711 m .50092 .26763 L .50259 .26995 L 0 .041 .143 r
F
.49957 .2711 m .4979 .26874 L .50092 .26763 L F
.45171 .26859 m .45299 .26532 L .4547 .26761 L 0 .036 .138 r
F
.45171 .26859 m .45 .26628 L .45299 .26532 L F
.67838 .26646 m .68 .26309 L .68149 .26522 L 0 .032 .132 r
F
.67838 .26646 m .67689 .26432 L .68 .26309 L F
.47949 .26973 m .48081 .26642 L .4825 .26859 L 0 .039 .141 r
F
.47949 .26973 m .4778 .26759 L .48081 .26642 L F
.09685 .26226 m .09758 .25913 L .09965 .2612 L 0 .024 .122 r
F
.09685 .26226 m .09478 .2602 L .09758 .25913 L F
.81868 .26399 m .82053 .26081 L .82187 .26281 L 0 .027 .126 r
F
.81868 .26399 m .81734 .262 L .82053 .26081 L F
.76779 .26421 m .76956 .2611 L .77096 .26312 L 0 .028 .127 r
F
.76779 .26421 m .7664 .26222 L .76956 .2611 L F
.68609 .26614 m .68773 .26302 L .68921 .2651 L 0 .031 .132 r
F
.68609 .26614 m .6846 .26404 L .68773 .26302 L F
.8264 .26364 m .82826 .26056 L .8296 .26257 L 0 .027 .126 r
F
.8264 .26364 m .82506 .26164 L .82826 .26056 L F
.53613 .50233 m .53745 .47539 L .5391 .48284 L .509 .705 0 r
F
.53613 .50233 m .53447 .49414 L .53745 .47539 L F
.2187 .26345 m .21963 .26024 L .22157 .26234 L 0 .026 .125 r
F
.2187 .26345 m .21676 .26136 L .21963 .26024 L F
.17551 .26326 m .17636 .26016 L .17834 .26228 L F
.17551 .26326 m .17352 .26117 L .17636 .26016 L F
.25419 .26414 m .25515 .26107 L .25706 .26317 L 0 .028 .127 r
F
.25419 .26414 m .25228 .26204 L .25515 .26107 L F
.14002 .26268 m .1408 .2596 L .14283 .26165 L 0 .025 .124 r
F
.14002 .26268 m .13798 .26066 L .1408 .2596 L F
.28967 .26485 m .29071 .26158 L .29258 .26371 L 0 .029 .129 r
F
.28967 .26485 m .2878 .26272 L .29071 .26158 L F
.39613 .26683 m .39732 .26377 L .39909 .26581 L 0 .033 .134 r
F
.39613 .26683 m .39436 .26477 L .39732 .26377 L F
.36064 .26619 m .36178 .26311 L .36357 .26527 L 0 .032 .133 r
F
.36064 .26619 m .35884 .26407 L .36178 .26311 L F
.77552 .26405 m .7773 .26092 L .77869 .26297 L 0 .028 .127 r
F
.77552 .26405 m .77413 .26202 L .7773 .26092 L F
.50727 .27115 m .50863 .26772 L .51029 .27 L 0 .042 .144 r
F
.50727 .27115 m .50561 .26883 L .50863 .26772 L F
.58128 .26968 m .58275 .26633 L .58434 .2686 L 0 .039 .141 r
F
.58128 .26968 m .57969 .26741 L .58275 .26633 L F
.71692 .26476 m .71861 .26156 L .72006 .26361 L 0 .029 .129 r
F
.71692 .26476 m .71547 .26273 L .71861 .26156 L F
.83413 .26348 m .83602 .26055 L .83733 .26246 L 0 .027 .126 r
F
.83413 .26348 m .8328 .26156 L .83602 .26055 L F
.70922 .2652 m .71089 .26198 L .71234 .26395 L 0 .03 .13 r
F
.70922 .2652 m .70776 .2632 L .71089 .26198 L F
.22638 .26329 m .22729 .26036 L .22924 .26229 L 0 .027 .126 r
F
.22638 .26329 m .22443 .26135 L .22729 .26036 L F
.1045 .26225 m .10523 .25916 L .10729 .26123 L 0 .024 .123 r
F
.1045 .26225 m .10244 .26018 L .10523 .25916 L F
.29736 .26461 m .2984 .26146 L .30027 .26351 L 0 .029 .129 r
F
.29736 .26461 m .29549 .26258 L .2984 .26146 L F
.42391 .26804 m .42514 .26503 L .42688 .26713 L 0 .036 .138 r
F
.42391 .26804 m .42217 .26596 L .42514 .26503 L F
.69381 .26612 m .69546 .26287 L .69693 .26492 L 0 .032 .132 r
F
.69381 .26612 m .69234 .26405 L .69546 .26287 L F
.62751 .2672 m .62905 .26397 L .63059 .26594 L 0 .034 .135 r
F
.62751 .2672 m .62597 .26525 L .62905 .26397 L F
.33285 .26528 m .33393 .26227 L .33576 .26434 L 0 .03 .131 r
F
.33285 .26528 m .33101 .26322 L .33393 .26227 L F
.70152 .26571 m .70317 .26239 L .70464 .26442 L 0 .031 .131 r
F
.70152 .26571 m .70005 .26365 L .70317 .26239 L F
.48719 .26978 m .48852 .26629 L .4902 .26866 L 0 .039 .141 r
F
.48719 .26978 m .48551 .26744 L .48852 .26629 L F
.63521 .26679 m .63678 .26377 L .63831 .26579 L 0 .034 .135 r
F
.63521 .26679 m .63368 .26477 L .63678 .26377 L F
.52306 .52885 m .52444 .55063 L .52609 .53507 L .84 .582 0 r
F
.52306 .52885 m .52139 .5437 L .52444 .55063 L F
.14768 .2626 m .14847 .25959 L .15049 .26159 L 0 .025 .124 r
F
.14768 .2626 m .14565 .26061 L .14847 .25959 L F
.72464 .26453 m .72633 .26123 L .72777 .26331 L 0 .029 .128 r
F
.72464 .26453 m .72319 .26246 L .72633 .26123 L F
.26186 .26412 m .26283 .26112 L .26474 .26305 L 0 .028 .128 r
F
.26186 .26412 m .25994 .26219 L .26283 .26112 L F
.18317 .26326 m .18404 .26006 L .18602 .26212 L 0 .026 .125 r
F
.18317 .26326 m .18118 .2612 L .18404 .26006 L F
.78325 .26393 m .78504 .26078 L .78642 .26285 L 0 .028 .127 r
F
.78325 .26393 m .78186 .26187 L .78504 .26078 L F
.61981 .26779 m .62134 .26458 L .62289 .26652 L 0 .036 .137 r
F
.61981 .26779 m .61826 .26588 L .62134 .26458 L F
.73235 .26416 m .73405 .26087 L .73549 .26296 L 0 .028 .128 r
F
.73235 .26416 m .73091 .26207 L .73405 .26087 L F
.19086 .26291 m .19173 .25986 L .19371 .26181 L 0 .026 .125 r
F
.19086 .26291 m .18887 .26098 L .19173 .25986 L F
.30505 .2644 m .30609 .26141 L .30795 .26337 L 0 .029 .129 r
F
.30505 .2644 m .30318 .26242 L .30609 .26141 L F
.4594 .26891 m .46069 .26566 L .46239 .26793 L 0 .038 .14 r
F
.4594 .26891 m .45769 .26664 L .46069 .26566 L F
.51497 .27106 m .51635 .26764 L .518 .26991 L 0 .043 .145 r
F
.51497 .27106 m .51332 .26882 L .51635 .26764 L F
.40382 .26679 m .40502 .26373 L .40678 .26573 L 0 .034 .135 r
F
.40382 .26679 m .40205 .26477 L .40502 .26373 L F
.11217 .2621 m .11291 .25903 L .11498 .26099 L 0 .025 .123 r
F
.11217 .2621 m .1101 .26014 L .11291 .25903 L F
.23406 .26318 m .23498 .26018 L .23693 .26208 L 0 .027 .126 r
F
.23406 .26318 m .23211 .26126 L .23498 .26018 L F
.6044 .26875 m .60592 .26567 L .60748 .26761 L 0 .038 .14 r
F
.6044 .26875 m .60284 .26682 L .60592 .26567 L F
.26955 .26385 m .27053 .26084 L .27244 .26276 L 0 .028 .128 r
F
.26955 .26385 m .26764 .26194 L .27053 .26084 L F
.52268 .27075 m .52406 .26748 L .52571 .26951 L 0 .042 .145 r
F
.52268 .27075 m .52103 .26874 L .52406 .26748 L F
.4316 .26798 m .43285 .2648 L .43459 .26678 L 0 .036 .138 r
F
.4316 .26798 m .42986 .266 L .43285 .2648 L F
.43931 .26755 m .44057 .26437 L .4423 .26636 L 0 .035 .137 r
F
.43931 .26755 m .43758 .26557 L .44057 .26437 L F
.61211 .26842 m .61363 .26521 L .61518 .26718 L 0 .037 .139 r
F
.61211 .26842 m .61055 .26647 L .61363 .26521 L F
.53038 .27034 m .53178 .2671 L .53342 .26916 L 0 .041 .144 r
F
.53038 .27034 m .52874 .26828 L .53178 .2671 L F
.11985 .26182 m .12059 .25888 L .12265 .26081 L 0 .024 .123 r
F
.11985 .26182 m .11779 .2599 L .12059 .25888 L F
.19855 .26269 m .19942 .25963 L .2014 .26161 L 0 .026 .125 r
F
.19855 .26269 m .19657 .26071 L .19942 .25963 L F
.58899 .26976 m .59048 .26635 L .59206 .26865 L 0 .04 .142 r
F
.58899 .26976 m .58741 .26748 L .59048 .26635 L F
.34052 .26529 m .34162 .26241 L .34345 .2643 L 0 .031 .132 r
F
.34052 .26529 m .33869 .26338 L .34162 .26241 L F
.15534 .26251 m .15613 .2596 L .15816 .26152 L 0 .026 .125 r
F
.15534 .26251 m .15331 .26059 L .15613 .2596 L F
.64293 .26679 m .64451 .26365 L .64603 .26563 L 0 .034 .135 r
F
.64293 .26679 m .64141 .2648 L .64451 .26365 L F
.24174 .26295 m .24268 .25996 L .24461 .26193 L 0 .027 .126 r
F
.24174 .26295 m .23981 .26099 L .24268 .25996 L F
.74007 .26402 m .7418 .2609 L .74323 .26299 L 0 .028 .128 r
F
.74007 .26402 m .73864 .26193 L .7418 .2609 L F
.65064 .26638 m .65222 .26323 L .65374 .26517 L 0 .033 .134 r
F
.65064 .26638 m .64912 .26442 L .65222 .26323 L F
.79098 .26383 m .7928 .26082 L .79417 .26281 L 0 .028 .128 r
F
.79098 .26383 m .78961 .26184 L .7928 .26082 L F
.36831 .2664 m .36947 .2631 L .37126 .26525 L 0 .033 .134 r
F
.36831 .2664 m .36652 .26425 L .36947 .2631 L F
.31273 .26428 m .31378 .26127 L .31565 .26319 L 0 .029 .129 r
F
.31273 .26428 m .31087 .26235 L .31378 .26127 L F
.07663 .26173 m .07732 .2587 L .07942 .26066 L 0 .024 .123 r
F
.07663 .26173 m .07453 .25976 L .07732 .2587 L F
.5967 .26943 m .5982 .26607 L .59977 .2681 L 0 .039 .141 r
F
.5967 .26943 m .59513 .26737 L .5982 .26607 L F
.53809 .27009 m .5395 .26686 L .54113 .26889 L 0 .041 .143 r
F
.53809 .27009 m .53646 .26801 L .5395 .26686 L F
.49489 .26989 m .49623 .26648 L .4979 .26874 L 0 .04 .142 r
F
.49489 .26989 m .49321 .26757 L .49623 .26648 L F
.65835 .26605 m .65995 .26299 L .66145 .26493 L 0 .033 .133 r
F
.65835 .26605 m .65684 .26408 L .65995 .26299 L F
.44701 .26735 m .44828 .26408 L .45 .26628 L 0 .035 .136 r
F
.44701 .26735 m .44529 .26516 L .44828 .26408 L F
.37601 .26607 m .37717 .26292 L .37897 .26492 L 0 .033 .133 r
F
.37601 .26607 m .37422 .26409 L .37717 .26292 L F
.27723 .26374 m .27822 .26077 L .28011 .26277 L 0 .028 .128 r
F
.27723 .26374 m .27533 .26177 L .27822 .26077 L F
.41151 .26676 m .41272 .26369 L .41448 .26577 L 0 .034 .135 r
F
.41151 .26676 m .40975 .26471 L .41272 .26369 L F
.80641 .26315 m .80825 .26016 L .8096 .2621 L 0 .027 .126 r
F
.80641 .26315 m .80506 .26122 L .80825 .26016 L F
.46709 .26894 m .46839 .26589 L .47009 .26789 L 0 .039 .141 r
F
.46709 .26894 m .46539 .26694 L .46839 .26589 L F
.54579 .2698 m .54722 .26673 L .54884 .26869 L 0 .041 .143 r
F
.54579 .2698 m .54417 .2678 L .54722 .26673 L F
.7987 .2636 m .80052 .2605 L .80188 .26241 L 0 .028 .127 r
F
.7987 .2636 m .79735 .2617 L .80052 .2605 L F
.66606 .26575 m .66768 .26276 L .66917 .26467 L 0 .032 .133 r
F
.66606 .26575 m .66456 .26383 L .66768 .26276 L F
.16302 .26233 m .16384 .25927 L .16586 .26121 L 0 .026 .124 r
F
.16302 .26233 m .161 .26041 L .16384 .25927 L F
.38371 .26577 m .38489 .26266 L .38667 .26466 L 0 .032 .133 r
F
.38371 .26577 m .38193 .26376 L .38489 .26266 L F
.34821 .26513 m .34932 .26214 L .35115 .26406 L 0 .031 .132 r
F
.34821 .26513 m .34638 .26324 L .34932 .26214 L F
.5535 .26943 m .55494 .26616 L .55655 .2681 L 0 .04 .142 r
F
.5535 .26943 m .55189 .2675 L .55494 .26616 L F
.7555 .26345 m .75726 .2604 L .75867 .26238 L 0 .028 .127 r
F
.7555 .26345 m .7541 .26148 L .75726 .2604 L F
.20622 .2626 m .20711 .25947 L .20907 .26153 L 0 .026 .125 r
F
.20622 .2626 m .20425 .26055 L .20711 .25947 L F
.12751 .26175 m .12827 .25876 L .13032 .26072 L 0 .025 .123 r
F
.12751 .26175 m .12546 .2598 L .12827 .25876 L F
.56121 .26902 m .56265 .26542 L .56426 .26768 L 0 .038 .14 r
F
.56121 .26902 m .5596 .26676 L .56265 .26542 L F
.56891 .26859 m .57037 .265 L .57197 .26725 L 0 .037 .139 r
F
.56891 .26859 m .56731 .26632 L .57037 .265 L F
.0843 .26155 m .085 .25852 L .08709 .26047 L 0 .024 .123 r
F
.0843 .26155 m .08221 .2596 L .085 .25852 L F
.32042 .26414 m .3215 .26091 L .32334 .263 L 0 .029 .129 r
F
.32042 .26414 m .31857 .26205 L .3215 .26091 L F
.7478 .26394 m .74953 .26064 L .75095 .26271 L 0 .028 .128 r
F
.7478 .26394 m .74638 .26186 L .74953 .26064 L F
.54103 .50762 m .53943 .5123 L .54238 .49208 L .6 .728 0 r
F
.53943 .5123 m .54076 .49031 L .54238 .49208 L .646 .74 0 r
F
.47479 .26873 m .47611 .26552 L .4778 .26759 L 0 .039 .14 r
F
.47479 .26873 m .4731 .26671 L .47611 .26552 L F
.67378 .26554 m .6754 .26237 L .67689 .26432 L 0 .032 .132 r
F
.67378 .26554 m .67229 .26358 L .6754 .26237 L F
.2494 .26302 m .25036 .25994 L .25228 .26204 L 0 .027 .126 r
F
.2494 .26302 m .24749 .26093 L .25036 .25994 L F
.17069 .26217 m .17153 .25909 L .17352 .26117 L 0 .026 .124 r
F
.17069 .26217 m .1687 .26011 L .17153 .25909 L F
.09198 .26132 m .0927 .25819 L .09478 .2602 L 0 .024 .122 r
F
.09198 .26132 m .0899 .25933 L .0927 .25819 L F
.81414 .26305 m .81599 .26002 L .81734 .262 L 0 .027 .127 r
F
.81414 .26305 m .8128 .26108 L .81599 .26002 L F
.76323 .26329 m .765 .26022 L .7664 .26222 L 0 .028 .127 r
F
.76323 .26329 m .76183 .26131 L .765 .26022 L F
.68149 .26522 m .68311 .26193 L .6846 .26404 L 0 .031 .132 r
F
.68149 .26522 m .68 .26309 L .68311 .26193 L F
.3559 .26503 m .35703 .26199 L .35884 .26407 L F
.3559 .26503 m .35409 .26298 L .35703 .26199 L F
.50259 .26995 m .50395 .26655 L .50561 .26883 L 0 .041 .143 r
F
.50259 .26995 m .50092 .26763 L .50395 .26655 L F
.57662 .26846 m .57809 .26518 L .57969 .26741 L 0 .038 .14 r
F
.57662 .26846 m .57503 .26622 L .57809 .26518 L F
.21389 .2625 m .21481 .25926 L .21676 .26136 L 0 .026 .125 r
F
.21389 .2625 m .21194 .2604 L .21481 .25926 L F
.3914 .26574 m .39258 .26276 L .39436 .26477 L 0 .033 .134 r
F
.3914 .26574 m .38962 .26371 L .39258 .26276 L F
.13517 .26171 m .13595 .25862 L .13798 .26066 L 0 .025 .123 r
F
.13517 .26171 m .13313 .25967 L .13595 .25862 L F
.28489 .26386 m .28592 .26058 L .2878 .26272 L 0 .029 .128 r
F
.28489 .26386 m .28301 .26173 L .28592 .26058 L F
.82187 .26281 m .82372 .25962 L .82506 .26164 L 0 .027 .126 r
F
.82187 .26281 m .82053 .26081 L .82372 .25962 L F
.4825 .26859 m .48383 .26523 L .48551 .26744 L 0 .038 .14 r
F
.4825 .26859 m .48081 .26642 L .48383 .26523 L F
.4192 .26689 m .42042 .26384 L .42217 .26596 L 0 .035 .137 r
F
.4192 .26689 m .41745 .26479 L .42042 .26384 L F
.3281 .26415 m .32918 .26108 L .33101 .26322 L 0 .03 .13 r
F
.3281 .26415 m .32626 .26204 L .32918 .26108 L F
.77096 .26312 m .77273 .25998 L .77413 .26202 L 0 .028 .127 r
F
.77096 .26312 m .76956 .2611 L .77273 .25998 L F
.4547 .26761 m .45598 .26435 L .45769 .26664 L 0 .037 .138 r
F
.4547 .26761 m .45299 .26532 L .45598 .26435 L F
.09965 .2612 m .10037 .25811 L .10244 .26018 L 0 .024 .122 r
F
.09965 .2612 m .09758 .25913 L .10037 .25811 L F
.68921 .2651 m .69086 .26199 L .69234 .26405 L 0 .032 .132 r
F
.68921 .2651 m .68773 .26302 L .69086 .26199 L F
.22157 .26234 m .22249 .25925 L .22443 .26135 L 0 .026 .125 r
F
.22157 .26234 m .21963 .26024 L .22249 .25925 L F
.8296 .26257 m .83147 .25954 L .8328 .26156 L 0 .027 .126 r
F
.8296 .26257 m .82826 .26056 L .83147 .25954 L F
.29258 .26371 m .29362 .26044 L .29549 .26258 L 0 .029 .129 r
F
.29258 .26371 m .29071 .26158 L .29362 .26044 L F
.71234 .26395 m .71402 .26079 L .71547 .26273 L F
.71234 .26395 m .71089 .26198 L .71402 .26079 L F
.17834 .26228 m .1792 .25908 L .18118 .2612 L 0 .026 .125 r
F
.17834 .26228 m .17636 .26016 L .1792 .25908 L F
.70464 .26442 m .7063 .2612 L .70776 .2632 L 0 .03 .13 r
F
.70464 .26442 m .70317 .26239 L .7063 .2612 L F
.14283 .26165 m .14363 .25853 L .14565 .26061 L 0 .025 .124 r
F
.14283 .26165 m .1408 .2596 L .14363 .25853 L F
.51029 .27 m .51166 .26653 L .51332 .26882 L 0 .042 .144 r
F
.51029 .27 m .50863 .26772 L .51166 .26653 L F
.63059 .26594 m .63214 .26277 L .63368 .26477 L 0 .034 .135 r
F
.63059 .26594 m .62905 .26397 L .63214 .26277 L F
.51838 .52805 m .51972 .54982 L .52139 .5437 L .84 .582 0 r
F
.51838 .52805 m .51671 .53346 L .51972 .54982 L F
.25706 .26317 m .25803 .26009 L .25994 .26219 L 0 .028 .128 r
F
.25706 .26317 m .25515 .26107 L .25803 .26009 L F
.77869 .26297 m .78047 .25981 L .78186 .26187 L 0 .028 .127 r
F
.77869 .26297 m .7773 .26092 L .78047 .25981 L F
.72006 .26361 m .72174 .26038 L .72319 .26246 L 0 .029 .129 r
F
.72006 .26361 m .71861 .26156 L .72174 .26038 L F
.69693 .26492 m .69858 .26162 L .70005 .26365 L 0 .031 .132 r
F
.69693 .26492 m .69546 .26287 L .69858 .26162 L F
.39909 .26581 m .40028 .26275 L .40205 .26477 L 0 .034 .134 r
F
.39909 .26581 m .39732 .26377 L .40028 .26275 L F
.58434 .2686 m .58582 .26519 L .58741 .26748 L 0 .039 .141 r
F
.58434 .2686 m .58275 .26633 L .58582 .26519 L F
.30027 .26351 m .30131 .26036 L .30318 .26242 L 0 .029 .129 r
F
.30027 .26351 m .2984 .26146 L .30131 .26036 L F
.72777 .26331 m .72947 .25998 L .73091 .26207 L 0 .028 .128 r
F
.72777 .26331 m .72633 .26123 L .72947 .25998 L F
.4902 .26866 m .49154 .26526 L .49321 .26757 L 0 .039 .141 r
F
.4902 .26866 m .48852 .26629 L .49154 .26526 L F
.62289 .26652 m .62443 .26329 L .62597 .26525 L 0 .035 .136 r
F
.62289 .26652 m .62134 .26458 L .62443 .26329 L F
.51206 .52076 m .51337 .53717 L .51503 .5389 L .813 .66 0 r
F
.51206 .52076 m .5104 .51902 L .51337 .53717 L F
.36357 .26527 m .36472 .26207 L .36652 .26425 L 0 .032 .133 r
F
.36357 .26527 m .36178 .26311 L .36472 .26207 L F
.22924 .26229 m .23016 .25933 L .23211 .26126 L 0 .027 .126 r
F
.22924 .26229 m .22729 .26036 L .23016 .25933 L F
.10729 .26123 m .10804 .25807 L .1101 .26014 L 0 .025 .123 r
F
.10729 .26123 m .10523 .25916 L .10804 .25807 L F
.73549 .26296 m .73721 .25984 L .73864 .26193 L 0 .028 .127 r
F
.73549 .26296 m .73405 .26087 L .73721 .25984 L F
.18602 .26212 m .18689 .25892 L .18887 .26098 L 0 .026 .125 r
F
.18602 .26212 m .18404 .26006 L .18689 .25892 L F
.63831 .26579 m .63988 .26276 L .64141 .2648 L 0 .034 .135 r
F
.63831 .26579 m .63678 .26377 L .63988 .26276 L F
.53779 .51054 m .5391 .48284 L .54076 .49031 L .599 .728 0 r
F
.53779 .51054 m .53613 .50233 L .5391 .48284 L F
.26474 .26305 m .26572 .25999 L .26764 .26194 L 0 .028 .128 r
F
.26474 .26305 m .26283 .26112 L .26572 .25999 L F
.33576 .26434 m .33686 .26132 L .33869 .26338 L 0 .031 .131 r
F
.33576 .26434 m .33393 .26227 L .33686 .26132 L F
.518 .26991 m .51938 .26645 L .52103 .26874 L 0 .042 .144 r
F
.518 .26991 m .51635 .26764 L .51938 .26645 L F
.42688 .26713 m .42812 .26391 L .42986 .266 L 0 .036 .138 r
F
.42688 .26713 m .42514 .26503 L .42812 .26391 L F
.78642 .26285 m .78822 .25975 L .78961 .26184 L 0 .028 .127 r
F
.78642 .26285 m .78504 .26078 L .78822 .25975 L F
.15049 .26159 m .15129 .25859 L .15331 .26059 L 0 .026 .124 r
F
.15049 .26159 m .14847 .25959 L .15129 .25859 L F
.19371 .26181 m .19459 .25874 L .19657 .26071 L 0 .026 .125 r
F
.19371 .26181 m .19173 .25986 L .19459 .25874 L F
.52571 .26951 m .5271 .26621 L .52874 .26828 L 0 .042 .144 r
F
.52571 .26951 m .52406 .26748 L .5271 .26621 L F
.61518 .26718 m .61671 .26388 L .61826 .26588 L 0 .037 .138 r
F
.61518 .26718 m .61363 .26521 L .61671 .26388 L F
.60748 .26761 m .609 .26452 L .61055 .26647 L 0 .038 .139 r
F
.60748 .26761 m .60592 .26567 L .609 .26452 L F
.11498 .26099 m .11572 .25795 L .11779 .2599 L 0 .025 .123 r
F
.11498 .26099 m .11291 .25903 L .11572 .25795 L F
.43459 .26678 m .43584 .26359 L .43758 .26557 L 0 .036 .137 r
F
.43459 .26678 m .43285 .2648 L .43584 .26359 L F
.4423 .26636 m .44356 .26316 L .44529 .26516 L 0 .035 .136 r
F
.4423 .26636 m .44057 .26437 L .44356 .26316 L F
.23693 .26208 m .23786 .2591 L .23981 .26099 L 0 .027 .126 r
F
.23693 .26208 m .23498 .26018 L .23786 .2591 L F
.40678 .26573 m .40799 .26267 L .40975 .26471 L 0 .034 .135 r
F
.40678 .26573 m .40502 .26373 L .40799 .26267 L F
.30795 .26337 m .309 .26041 L .31087 .26235 L 0 .029 .129 r
F
.30795 .26337 m .30609 .26141 L .309 .26041 L F
.53342 .26916 m .53482 .26597 L .53646 .26801 L 0 .041 .143 r
F
.53342 .26916 m .53178 .2671 L .53482 .26597 L F
.59977 .2681 m .60127 .2648 L .60284 .26682 L 0 .039 .14 r
F
.59977 .2681 m .5982 .26607 L .60127 .2648 L F
.27244 .26276 m .27342 .25982 L .27533 .26177 L 0 .028 .128 r
F
.27244 .26276 m .27053 .26084 L .27342 .25982 L F
.46239 .26793 m .46369 .26468 L .46539 .26694 L 0 .038 .14 r
F
.46239 .26793 m .46069 .26566 L .46369 .26468 L F
.65374 .26517 m .65533 .26216 L .65684 .26408 L 0 .033 .134 r
F
.65374 .26517 m .65222 .26323 L .65533 .26216 L F
.64603 .26563 m .64761 .26246 L .64912 .26442 L 0 .034 .135 r
F
.64603 .26563 m .64451 .26365 L .64761 .26246 L F
.59206 .26865 m .59355 .2651 L .59513 .26737 L 0 .04 .141 r
F
.59206 .26865 m .59048 .26635 L .59355 .2651 L F
.37126 .26525 m .37243 .26196 L .37422 .26409 L 0 .033 .133 r
F
.37126 .26525 m .36947 .2631 L .37243 .26196 L F
.2014 .26161 m .20228 .25857 L .20425 .26055 L 0 .026 .125 r
F
.2014 .26161 m .19942 .25963 L .20228 .25857 L F
.54113 .26889 m .54255 .26579 L .54417 .2678 L 0 .041 .143 r
F
.54113 .26889 m .5395 .26686 L .54255 .26579 L F
.12265 .26081 m .1234 .25785 L .12546 .2598 L 0 .025 .123 r
F
.12265 .26081 m .12059 .25888 L .1234 .25785 L F
.55655 .2681 m .55799 .26482 L .5596 .26676 L 0 .039 .141 r
F
.55655 .2681 m .55494 .26616 L .55799 .26482 L F
.4979 .26874 m .49925 .26542 L .50092 .26763 L 0 .04 .142 r
F
.4979 .26874 m .49623 .26648 L .49925 .26542 L F
.31565 .26319 m .31671 .26014 L .31857 .26205 L 0 .029 .129 r
F
.31565 .26319 m .31378 .26127 L .31671 .26014 L F
.56426 .26768 m .5657 .26408 L .56731 .26632 L 0 .037 .139 r
F
.56426 .26768 m .56265 .26542 L .5657 .26408 L F
.57197 .26725 m .57343 .26398 L .57503 .26622 L F
.57197 .26725 m .57037 .265 L .57343 .26398 L F
.37897 .26492 m .38014 .26176 L .38193 .26376 L 0 .032 .133 r
F
.37897 .26492 m .37717 .26292 L .38014 .26176 L F
.74323 .26299 m .74495 .25977 L .74638 .26186 L 0 .028 .128 r
F
.74323 .26299 m .7418 .2609 L .74495 .25977 L F
.66145 .26493 m .66306 .26191 L .66456 .26383 L 0 .033 .133 r
F
.66145 .26493 m .65995 .26299 L .66306 .26191 L F
.24461 .26193 m .24556 .25893 L .24749 .26093 L 0 .027 .126 r
F
.24461 .26193 m .24268 .25996 L .24556 .25893 L F
.15816 .26152 m .15897 .25848 L .161 .26041 L 0 .026 .125 r
F
.15816 .26152 m .15613 .2596 L .15897 .25848 L F
.07942 .26066 m .0801 .25764 L .08221 .2596 L 0 .024 .123 r
F
.07942 .26066 m .07732 .2587 L .0801 .25764 L F
.34345 .2643 m .34455 .26134 L .34638 .26324 L 0 .031 .132 r
F
.34345 .2643 m .34162 .26241 L .34455 .26134 L F
.79417 .26281 m .79598 .25971 L .79735 .2617 L 0 .028 .128 r
F
.79417 .26281 m .7928 .26082 L .79598 .25971 L F
.80188 .26241 m .8037 .25929 L .80506 .26122 L 0 .027 .127 r
F
.80188 .26241 m .80052 .2605 L .8037 .25929 L F
.45 .26628 m .45128 .26313 L .45299 .26532 L 0 .035 .137 r
F
.45 .26628 m .44828 .26408 L .45128 .26313 L F
.54884 .26869 m .55027 .26557 L .55189 .2675 L 0 .041 .143 r
F
.54884 .26869 m .54722 .26673 L .55027 .26557 L F
.16586 .26121 m .16668 .25815 L .1687 .26011 L 0 .025 .124 r
F
.16586 .26121 m .16384 .25927 L .16668 .25815 L F
.75095 .26271 m .75268 .25942 L .7541 .26148 L 0 .028 .127 r
F
.75095 .26271 m .74953 .26064 L .75268 .25942 L F
.38667 .26466 m .38784 .26172 L .38962 .26371 L 0 .032 .133 r
F
.38667 .26466 m .38489 .26266 L .38784 .26172 L F
.66917 .26467 m .67079 .26168 L .67229 .26358 L F
.66917 .26467 m .66768 .26276 L .67079 .26168 L F
.8096 .2621 m .81145 .25912 L .8128 .26108 L 0 .027 .127 r
F
.8096 .2621 m .80825 .26016 L .81145 .25912 L F
.47009 .26789 m .4714 .26467 L .4731 .26671 L 0 .039 .141 r
F
.47009 .26789 m .46839 .26589 L .4714 .26467 L F
.28011 .26277 m .28112 .25972 L .28301 .26173 L 0 .028 .128 r
F
.28011 .26277 m .27822 .26077 L .28112 .25972 L F
.35115 .26406 m .35227 .26105 L .35409 .26298 L 0 .031 .132 r
F
.35115 .26406 m .34932 .26214 L .35227 .26105 L F
.41448 .26577 m .4157 .26269 L .41745 .26479 L 0 .035 .136 r
F
.41448 .26577 m .41272 .26369 L .4157 .26269 L F
.32334 .263 m .32442 .25993 L .32626 .26204 L 0 .029 .129 r
F
.32334 .263 m .3215 .26091 L .32442 .25993 L F
.75867 .26238 m .76043 .25932 L .76183 .26131 L 0 .028 .127 r
F
.75867 .26238 m .75726 .2604 L .76043 .25932 L F
.20907 .26153 m .20998 .25835 L .21194 .2604 L 0 .026 .125 r
F
.20907 .26153 m .20711 .25947 L .20998 .25835 L F
.08709 .26047 m .0878 .25738 L .0899 .25933 L 0 .024 .122 r
F
.08709 .26047 m .085 .25852 L .0878 .25738 L F
.67689 .26432 m .67851 .26114 L .68 .26309 L 0 .031 .132 r
F
.67689 .26432 m .6754 .26237 L .67851 .26114 L F
.13032 .26072 m .13108 .25772 L .13313 .25967 L 0 .025 .123 r
F
.13032 .26072 m .12827 .25876 L .13108 .25772 L F
.4778 .26759 m .47912 .26432 L .48081 .26642 L 0 .038 .14 r
F
.4778 .26759 m .47611 .26552 L .47912 .26432 L F
.51289 .50284 m .5113 .48258 L .51431 .48735 L .601 .729 0 r
F
.50988 .49734 m .5113 .48258 L .51289 .50284 L .511 .705 0 r
F
.6846 .26404 m .68624 .26093 L .68773 .26302 L 0 .031 .132 r
F
.6846 .26404 m .68311 .26193 L .68624 .26093 L F
.09478 .2602 m .0955 .25712 L .09758 .25913 L 0 .024 .122 r
F
.09478 .2602 m .0927 .25819 L .0955 .25712 L F
.50561 .26883 m .50697 .26548 L .50863 .26772 L 0 .041 .143 r
F
.50561 .26883 m .50395 .26655 L .50697 .26548 L F
.7664 .26222 m .76816 .25907 L .76956 .2611 L 0 .028 .127 r
F
.7664 .26222 m .765 .26022 L .76816 .25907 L F
.81734 .262 m .81918 .25881 L .82053 .26081 L 0 .027 .126 r
F
.81734 .262 m .81599 .26002 L .81918 .25881 L F
.21676 .26136 m .21768 .25813 L .21963 .26024 L 0 .026 .125 r
F
.21676 .26136 m .21481 .25926 L .21768 .25813 L F
.17352 .26117 m .17437 .25806 L .17636 .26016 L F
.17352 .26117 m .17153 .25909 L .17437 .25806 L F
.25228 .26204 m .25324 .25896 L .25515 .26107 L 0 .027 .127 r
F
.25228 .26204 m .25036 .25994 L .25324 .25896 L F
.57969 .26741 m .58116 .2641 L .58275 .26633 L 0 .038 .14 r
F
.57969 .26741 m .57809 .26518 L .58116 .2641 L F
.82506 .26164 m .82692 .25852 L .82826 .26056 L 0 .027 .126 r
F
.82506 .26164 m .82372 .25962 L .82692 .25852 L F
.2878 .26272 m .28883 .25944 L .29071 .26158 L 0 .028 .128 r
F
.2878 .26272 m .28592 .26058 L .28883 .25944 L F
.48551 .26744 m .48684 .26405 L .48852 .26629 L 0 .038 .14 r
F
.48551 .26744 m .48383 .26523 L .48684 .26405 L F
.35884 .26407 m .35997 .26099 L .36178 .26311 L 0 .032 .132 r
F
.35884 .26407 m .35703 .26199 L .35997 .26099 L F
.13798 .26066 m .13877 .25754 L .1408 .2596 L 0 .025 .123 r
F
.13798 .26066 m .13595 .25862 L .13877 .25754 L F
.39436 .26477 m .39554 .26178 L .39732 .26377 L 0 .033 .134 r
F
.39436 .26477 m .39258 .26276 L .39554 .26178 L F
.77413 .26202 m .7759 .25886 L .7773 .26092 L 0 .028 .127 r
F
.77413 .26202 m .77273 .25998 L .7759 .25886 L F
.71547 .26273 m .71716 .25962 L .71861 .26156 L 0 .029 .129 r
F
.71547 .26273 m .71402 .26079 L .71716 .25962 L F
.10244 .26018 m .10317 .25709 L .10523 .25916 L 0 .024 .123 r
F
.10244 .26018 m .10037 .25811 L .10317 .25709 L F
.42217 .26596 m .4234 .26288 L .42514 .26503 L 0 .036 .137 r
F
.42217 .26596 m .42042 .26384 L .4234 .26288 L F
.69234 .26405 m .69399 .26083 L .69546 .26287 L 0 .032 .132 r
F
.69234 .26405 m .69086 .26199 L .69399 .26083 L F
.70776 .2632 m .70944 .26001 L .71089 .26198 L 0 .03 .13 r
F
.70776 .2632 m .7063 .2612 L .70944 .26001 L F
.45769 .26664 m .45898 .26338 L .46069 .26566 L 0 .037 .139 r
F
.45769 .26664 m .45598 .26435 L .45898 .26338 L F
.33101 .26322 m .3321 .26013 L .33393 .26227 L 0 .03 .13 r
F
.33101 .26322 m .32918 .26108 L .3321 .26013 L F
.29549 .26258 m .29653 .2593 L .2984 .26146 L 0 .029 .128 r
F
.29549 .26258 m .29362 .26044 L .29653 .2593 L F
.70005 .26365 m .70171 .26037 L .70317 .26239 L 0 .031 .131 r
F
.70005 .26365 m .69858 .26162 L .70171 .26037 L F
.51332 .26882 m .51469 .26532 L .51635 .26764 L 0 .042 .144 r
F
.51332 .26882 m .51166 .26653 L .51469 .26532 L F
.8328 .26156 m .83468 .25851 L .83602 .26055 L 0 .027 .126 r
F
.8328 .26156 m .83147 .25954 L .83468 .25851 L F
.22443 .26135 m .22535 .25826 L .22729 .26036 L F
.22443 .26135 m .22249 .25925 L .22535 .25826 L F
.63368 .26477 m .63524 .26173 L .63678 .26377 L 0 .033 .134 r
F
.63368 .26477 m .63214 .26277 L .63524 .26173 L F
.72319 .26246 m .72488 .25915 L .72633 .26123 L 0 .028 .128 r
F
.72319 .26246 m .72174 .26038 L .72488 .25915 L F
.62597 .26525 m .62751 .26199 L .62905 .26397 L 0 .034 .135 r
F
.62597 .26525 m .62443 .26329 L .62751 .26199 L F
.18118 .2612 m .18205 .25795 L .18404 .26006 L 0 .026 .125 r
F
.18118 .2612 m .1792 .25908 L .18205 .25795 L F
.73091 .26207 m .73261 .25878 L .73405 .26087 L 0 .028 .127 r
F
.73091 .26207 m .72947 .25998 L .73261 .25878 L F
.78186 .26187 m .78365 .2587 L .78504 .26078 L F
.78186 .26187 m .78047 .25981 L .78365 .2587 L F
.14565 .26061 m .14645 .2575 L .14847 .25959 L 0 .025 .124 r
F
.14565 .26061 m .14363 .25853 L .14645 .2575 L F
.58741 .26748 m .58889 .26405 L .59048 .26635 L 0 .039 .141 r
F
.58741 .26748 m .58582 .26519 L .58889 .26405 L F
.25994 .26219 m .26092 .25901 L .26283 .26112 L 0 .028 .128 r
F
.25994 .26219 m .25803 .26009 L .26092 .25901 L F
.40205 .26477 m .40325 .26172 L .40502 .26373 L 0 .034 .135 r
F
.40205 .26477 m .40028 .26275 L .40325 .26172 L F
.30318 .26242 m .30422 .25936 L .30609 .26141 L 0 .029 .129 r
F
.30318 .26242 m .30131 .26036 L .30422 .25936 L F
.49321 .26757 m .49456 .26422 L .49623 .26648 L 0 .039 .141 r
F
.49321 .26757 m .49154 .26526 L .49456 .26422 L F
.61826 .26588 m .61979 .26254 L .62134 .26458 L 0 .036 .137 r
F
.61826 .26588 m .61671 .26388 L .61979 .26254 L F
.18887 .26098 m .18975 .25779 L .19173 .25986 L 0 .026 .125 r
F
.18887 .26098 m .18689 .25892 L .18975 .25779 L F
.1101 .26014 m .11085 .25697 L .11291 .25903 L 0 .024 .123 r
F
.1101 .26014 m .10804 .25807 L .11085 .25697 L F
.52874 .26828 m .53014 .26504 L .53178 .2671 L 0 .041 .143 r
F
.52874 .26828 m .5271 .26621 L .53014 .26504 L F
.52103 .26874 m .52242 .26517 L .52406 .26748 L 0 .042 .144 r
F
.52103 .26874 m .51938 .26645 L .52242 .26517 L F
.60284 .26682 m .60435 .26365 L .60592 .26567 L 0 .038 .14 r
F
.60284 .26682 m .60127 .2648 L .60435 .26365 L F
.36652 .26425 m .36767 .26094 L .36947 .2631 L 0 .032 .133 r
F
.36652 .26425 m .36472 .26207 L .36767 .26094 L F
.23211 .26126 m .23303 .25826 L .23498 .26018 L 0 .027 .126 r
F
.23211 .26126 m .23016 .25933 L .23303 .25826 L F
.73864 .26193 m .74037 .25881 L .7418 .2609 L 0 .028 .128 r
F
.73864 .26193 m .73721 .25984 L .74037 .25881 L F
.43758 .26557 m .43884 .26237 L .44057 .26437 L 0 .035 .137 r
F
.43758 .26557 m .43584 .26359 L .43884 .26237 L F
.42986 .266 m .43111 .26272 L .43285 .2648 L 0 .036 .138 r
F
.42986 .266 m .42812 .26391 L .43111 .26272 L F
.26764 .26194 m .26862 .25887 L .27053 .26084 L 0 .028 .128 r
F
.26764 .26194 m .26572 .25999 L .26862 .25887 L F
.44529 .26516 m .44656 .26208 L .44828 .26408 L 0 .035 .136 r
F
.44529 .26516 m .44356 .26316 L .44656 .26208 L F
.61055 .26647 m .61208 .26323 L .61363 .26521 L 0 .037 .139 r
F
.61055 .26647 m .609 .26452 L .61208 .26323 L F
.19657 .26071 m .19744 .25764 L .19942 .25963 L 0 .026 .125 r
F
.19657 .26071 m .19459 .25874 L .19744 .25764 L F
.64141 .2648 m .64298 .2616 L .64451 .26365 L 0 .034 .135 r
F
.64141 .2648 m .63988 .26276 L .64298 .2616 L F
.53646 .26801 m .53787 .26484 L .5395 .26686 L 0 .041 .143 r
F
.53646 .26801 m .53482 .26597 L .53787 .26484 L F
.59513 .26737 m .59662 .26383 L .5982 .26607 L 0 .039 .141 r
F
.59513 .26737 m .59355 .2651 L .59662 .26383 L F
.11779 .2599 m .11853 .25691 L .12059 .25888 L 0 .025 .123 r
F
.11779 .2599 m .11572 .25795 L .11853 .25691 L F
.56731 .26632 m .56876 .26276 L .57037 .265 L 0 .036 .138 r
F
.56731 .26632 m .5657 .26408 L .56876 .26276 L F
.78961 .26184 m .79141 .25873 L .7928 .26082 L 0 .028 .128 r
F
.78961 .26184 m .78822 .25975 L .79141 .25873 L F
.5596 .26676 m .56104 .26348 L .56265 .26542 L 0 .038 .14 r
F
.5596 .26676 m .55799 .26482 L .56104 .26348 L F
.23981 .26099 m .24074 .25804 L .24268 .25996 L 0 .027 .126 r
F
.23981 .26099 m .23786 .2591 L .24074 .25804 L F
.64912 .26442 m .65071 .26129 L .65222 .26323 L 0 .033 .134 r
F
.64912 .26442 m .64761 .26246 L .65071 .26129 L F
.15331 .26059 m .15411 .25759 L .15613 .2596 L 0 .026 .125 r
F
.15331 .26059 m .15129 .25859 L .15411 .25759 L F
.33869 .26338 m .33979 .26036 L .34162 .26241 L 0 .031 .132 r
F
.33869 .26338 m .33686 .26132 L .33979 .26036 L F
.31087 .26235 m .31192 .25934 L .31378 .26127 L 0 .029 .129 r
F
.31087 .26235 m .309 .26041 L .31192 .25934 L F
.40975 .26471 m .41096 .26162 L .41272 .26369 L 0 .034 .135 r
F
.40975 .26471 m .40799 .26267 L .41096 .26162 L F
.65684 .26408 m .65844 .26108 L .65995 .26299 L 0 .033 .134 r
F
.65684 .26408 m .65533 .26216 L .65844 .26108 L F
.37422 .26409 m .37538 .26079 L .37717 .26292 L 0 .032 .133 r
F
.37422 .26409 m .37243 .26196 L .37538 .26079 L F
.27533 .26177 m .27632 .25881 L .27822 .26077 L 0 .028 .128 r
F
.27533 .26177 m .27342 .25982 L .27632 .25881 L F
.46539 .26694 m .46669 .26363 L .46839 .26589 L 0 .039 .14 r
F
.46539 .26694 m .46369 .26468 L .46669 .26363 L F
.54417 .2678 m .5456 .26474 L .54722 .26673 L 0 .041 .143 r
F
.54417 .2678 m .54255 .26579 L .5456 .26474 L F
.20425 .26055 m .20514 .25751 L .20711 .25947 L 0 .026 .125 r
F
.20425 .26055 m .20228 .25857 L .20514 .25751 L F
.31857 .26205 m .31964 .25902 L .3215 .26091 L 0 .029 .129 r
F
.31857 .26205 m .31671 .26014 L .31964 .25902 L F
.38193 .26376 m .3831 .26064 L .38489 .26266 L 0 .032 .133 r
F
.38193 .26376 m .38014 .26176 L .3831 .26064 L F
.50092 .26763 m .50228 .26439 L .50395 .26655 L 0 .04 .142 r
F
.50092 .26763 m .49925 .26542 L .50228 .26439 L F
.74638 .26186 m .74811 .25857 L .74953 .26064 L 0 .028 .128 r
F
.74638 .26186 m .74495 .25977 L .74811 .25857 L F
.80506 .26122 m .8069 .25821 L .80825 .26016 L 0 .027 .127 r
F
.80506 .26122 m .8037 .25929 L .8069 .25821 L F
.161 .26041 m .16182 .25733 L .16384 .25927 L 0 .026 .125 r
F
.161 .26041 m .15897 .25848 L .16182 .25733 L F
.66456 .26383 m .66618 .26084 L .66768 .26276 L 0 .033 .133 r
F
.66456 .26383 m .66306 .26191 L .66618 .26084 L F
.7541 .26148 m .75585 .25835 L .75726 .2604 L 0 .028 .127 r
F
.7541 .26148 m .75268 .25942 L .75585 .25835 L F
.79735 .2617 m .79916 .2585 L .80052 .2605 L 0 .028 .128 r
F
.79735 .2617 m .79598 .25971 L .79916 .2585 L F
.12546 .2598 m .12621 .25682 L .12827 .25876 L 0 .025 .123 r
F
.12546 .2598 m .1234 .25785 L .12621 .25682 L F
.57503 .26622 m .5765 .26295 L .57809 .26518 L 0 .037 .139 r
F
.57503 .26622 m .57343 .26398 L .5765 .26295 L F
.55189 .2675 m .55332 .26422 L .55494 .26616 L 0 .04 .142 r
F
.55189 .2675 m .55027 .26557 L .55332 .26422 L F
.08221 .2596 m .08289 .25657 L .085 .25852 L 0 .024 .123 r
F
.08221 .2596 m .0801 .25764 L .08289 .25657 L F
.34638 .26324 m .34749 .26023 L .34932 .26214 L 0 .031 .132 r
F
.34638 .26324 m .34455 .26134 L .34749 .26023 L F
.4731 .26671 m .47441 .26346 L .47611 .26552 L 0 .038 .14 r
F
.4731 .26671 m .4714 .26467 L .47441 .26346 L F
.24749 .26093 m .24844 .25791 L .25036 .25994 L 0 .027 .126 r
F
.24749 .26093 m .24556 .25893 L .24844 .25791 L F
.53943 .5123 m .53779 .51054 L .54076 .49031 L .646 .74 0 r
F
.68 .26309 m .68163 .25997 L .68311 .26193 L 0 .031 .131 r
F
.68 .26309 m .67851 .26114 L .68163 .25997 L F
.1687 .26011 m .16952 .25711 L .17153 .25909 L 0 .025 .124 r
F
.1687 .26011 m .16668 .25815 L .16952 .25711 L F
.67229 .26358 m .67391 .26046 L .6754 .26237 L 0 .032 .133 r
F
.67229 .26358 m .67079 .26168 L .67391 .26046 L F
.45299 .26532 m .45427 .26217 L .45598 .26435 L 0 .036 .137 r
F
.45299 .26532 m .45128 .26313 L .45427 .26217 L F
.0899 .25933 m .09061 .25623 L .0927 .25819 L 0 .024 .122 r
F
.0899 .25933 m .0878 .25738 L .09061 .25623 L F
.21194 .2604 m .21285 .2572 L .21481 .25926 L 0 .026 .125 r
F
.21194 .2604 m .20998 .25835 L .21285 .2572 L F
.52202 .50002 m .52343 .47309 L .52508 .49262 L .511 .706 0 r
F
.52202 .50002 m .52039 .47974 L .52343 .47309 L F
.35409 .26298 m .35521 .26002 L .35703 .26199 L 0 .031 .132 r
F
.35409 .26298 m .35227 .26105 L .35521 .26002 L F
.48081 .26642 m .48214 .26311 L .48383 .26523 L 0 .038 .14 r
F
.48081 .26642 m .47912 .26432 L .48214 .26311 L F
.28301 .26173 m .28403 .25858 L .28592 .26058 L 0 .028 .128 r
F
.28301 .26173 m .28112 .25972 L .28403 .25858 L F
.8128 .26108 m .81465 .25803 L .81599 .26002 L 0 .027 .127 r
F
.8128 .26108 m .81145 .25912 L .81465 .25803 L F
.76183 .26131 m .7636 .25821 L .765 .26022 L 0 .028 .127 r
F
.76183 .26131 m .76043 .25932 L .7636 .25821 L F
.38962 .26371 m .3908 .26078 L .39258 .26276 L 0 .033 .134 r
F
.38962 .26371 m .38784 .26172 L .3908 .26078 L F
.41745 .26479 m .41867 .26171 L .42042 .26384 L 0 .035 .136 r
F
.41745 .26479 m .4157 .26269 L .41867 .26171 L F
.13313 .25967 m .1339 .25667 L .13595 .25862 L 0 .025 .123 r
F
.13313 .25967 m .13108 .25772 L .1339 .25667 L F
.32626 .26204 m .32734 .25895 L .32918 .26108 L 0 .029 .129 r
F
.32626 .26204 m .32442 .25993 L .32734 .25895 L F
.82053 .26081 m .82237 .25759 L .82372 .25962 L 0 .027 .126 r
F
.82053 .26081 m .81918 .25881 L .82237 .25759 L F
.09758 .25913 m .09829 .2561 L .10037 .25811 L 0 .024 .122 r
F
.09758 .25913 m .0955 .25712 L .09829 .2561 L F
.50863 .26772 m .51 .26428 L .51166 .26653 L 0 .041 .143 r
F
.50863 .26772 m .50697 .26548 L .51 .26428 L F
.68773 .26302 m .68938 .25993 L .69086 .26199 L 0 .031 .132 r
F
.68773 .26302 m .68624 .26093 L .68938 .25993 L F
.76956 .2611 m .77133 .25793 L .77273 .25998 L 0 .027 .127 r
F
.76956 .2611 m .76816 .25907 L .77133 .25793 L F
.21963 .26024 m .22054 .25714 L .22249 .25925 L 0 .026 .125 r
F
.21963 .26024 m .21768 .25813 L .22054 .25714 L F
.29071 .26158 m .29175 .25829 L .29362 .26044 L 0 .028 .128 r
F
.29071 .26158 m .28883 .25944 L .29175 .25829 L F
.48852 .26629 m .48986 .26305 L .49154 .26526 L 0 .038 .14 r
F
.48852 .26629 m .48684 .26405 L .48986 .26305 L F
.58275 .26633 m .58423 .26296 L .58582 .26519 L F
.58275 .26633 m .58116 .2641 L .58423 .26296 L F
.82826 .26056 m .83013 .25747 L .83147 .25954 L 0 .027 .126 r
F
.82826 .26056 m .82692 .25852 L .83013 .25747 L F
.17636 .26016 m .17721 .25697 L .1792 .25908 L 0 .026 .125 r
F
.17636 .26016 m .17437 .25806 L .17721 .25697 L F
.25515 .26107 m .25612 .25799 L .25803 .26009 L 0 .028 .127 r
F
.25515 .26107 m .25324 .25896 L .25612 .25799 L F
.1408 .2596 m .1416 .25646 L .14363 .25853 L 0 .025 .124 r
F
.1408 .2596 m .13877 .25754 L .1416 .25646 L F
.70317 .26239 m .70484 .25921 L .7063 .2612 L 0 .03 .13 r
F
.70317 .26239 m .70171 .26037 L .70484 .25921 L F
.71089 .26198 m .71257 .25884 L .71402 .26079 L F
.71089 .26198 m .70944 .26001 L .71257 .25884 L F
.71861 .26156 m .7203 .25846 L .72174 .26038 L 0 .029 .129 r
F
.71861 .26156 m .71716 .25962 L .7203 .25846 L F
.7773 .26092 m .77908 .25773 L .78047 .25981 L 0 .027 .127 r
F
.7773 .26092 m .7759 .25886 L .77908 .25773 L F
.69546 .26287 m .69711 .2596 L .69858 .26162 L 0 .031 .132 r
F
.69546 .26287 m .69399 .26083 L .69711 .2596 L F
.36178 .26311 m .36292 .25994 L .36472 .26207 L 0 .032 .132 r
F
.36178 .26311 m .35997 .26099 L .36292 .25994 L F
.62905 .26397 m .63061 .26077 L .63214 .26277 L 0 .034 .135 r
F
.62905 .26397 m .62751 .26199 L .63061 .26077 L F
.39732 .26377 m .39851 .26077 L .40028 .26275 L 0 .033 .134 r
F
.39732 .26377 m .39554 .26178 L .39851 .26077 L F
.51635 .26764 m .51773 .2641 L .51938 .26645 L 0 .041 .143 r
F
.51635 .26764 m .51469 .26532 L .51773 .2641 L F
.72633 .26123 m .72802 .2579 L .72947 .25998 L 0 .028 .127 r
F
.72633 .26123 m .72488 .25915 L .72802 .2579 L F
.2984 .26146 m .29945 .25819 L .30131 .26036 L 0 .028 .128 r
F
.2984 .26146 m .29653 .2593 L .29945 .25819 L F
.73405 .26087 m .73577 .25775 L .73721 .25984 L 0 .028 .127 r
F
.73405 .26087 m .73261 .25878 L .73577 .25775 L F
.10523 .25916 m .10598 .256 L .10804 .25807 L 0 .024 .123 r
F
.10523 .25916 m .10317 .25709 L .10598 .256 L F
.5104 .51902 m .51173 .52825 L .51337 .53717 L .8 .694 0 r
F
.18404 .26006 m .18491 .25682 L .18689 .25892 L 0 .026 .125 r
F
.18404 .26006 m .18205 .25795 L .18491 .25682 L F
.62134 .26458 m .62288 .26123 L .62443 .26329 L 0 .035 .136 r
F
.62134 .26458 m .61979 .26254 L .62288 .26123 L F
.46069 .26566 m .46198 .26241 L .46369 .26468 L 0 .037 .139 r
F
.46069 .26566 m .45898 .26338 L .46198 .26241 L F
.42514 .26503 m .42638 .26178 L .42812 .26391 L 0 .036 .137 r
F
.42514 .26503 m .4234 .26288 L .42638 .26178 L F
.63678 .26377 m .63835 .26068 L .63988 .26276 L 0 .034 .135 r
F
.63678 .26377 m .63524 .26173 L .63835 .26068 L F
.33393 .26227 m .33503 .25918 L .33686 .26132 L 0 .031 .131 r
F
.33393 .26227 m .3321 .26013 L .33503 .25918 L F
.78504 .26078 m .78684 .25767 L .78822 .25975 L 0 .028 .127 r
F
.78504 .26078 m .78365 .2587 L .78684 .25767 L F
.59048 .26635 m .59197 .26283 L .59355 .2651 L 0 .038 .14 r
F
.59048 .26635 m .58889 .26405 L .59197 .26283 L F
.22729 .26036 m .22822 .25724 L .23016 .25933 L 0 .027 .126 r
F
.22729 .26036 m .22535 .25826 L .22822 .25724 L F
.52406 .26748 m .52546 .26389 L .5271 .26621 L 0 .041 .143 r
F
.52406 .26748 m .52242 .26517 L .52546 .26389 L F
.14847 .25959 m .14927 .2565 L .15129 .25859 L 0 .025 .124 r
F
.14847 .25959 m .14645 .2575 L .14927 .2565 L F
.53178 .2671 m .53319 .26393 L .53482 .26597 L 0 .041 .143 r
F
.53178 .2671 m .53014 .26504 L .53319 .26393 L F
.26283 .26112 m .26382 .25787 L .26572 .25999 L 0 .028 .128 r
F
.26283 .26112 m .26092 .25901 L .26382 .25787 L F
.49623 .26648 m .49758 .26321 L .49925 .26542 L 0 .039 .141 r
F
.49623 .26648 m .49456 .26422 L .49758 .26321 L F
.19173 .25986 m .19261 .25666 L .19459 .25874 L 0 .026 .125 r
F
.19173 .25986 m .18975 .25779 L .19261 .25666 L F
.5982 .26607 m .5997 .2626 L .60127 .2648 L 0 .038 .14 r
F
.5982 .26607 m .59662 .26383 L .5997 .2626 L F
.56265 .26542 m .5641 .26215 L .5657 .26408 L 0 .037 .139 r
F
.56265 .26542 m .56104 .26348 L .5641 .26215 L F
.57037 .265 m .57183 .26175 L .57343 .26398 L 0 .036 .138 r
F
.57037 .265 m .56876 .26276 L .57183 .26175 L F
.61363 .26521 m .61516 .26186 L .61671 .26388 L F
.61363 .26521 m .61208 .26323 L .61516 .26186 L F
.44057 .26437 m .44183 .26115 L .44356 .26316 L 0 .035 .136 r
F
.44057 .26437 m .43884 .26237 L .44183 .26115 L F
.43285 .2648 m .43411 .26153 L .43584 .26359 L 0 .036 .137 r
F
.43285 .2648 m .43111 .26272 L .43411 .26153 L F
.40502 .26373 m .40623 .26063 L .40799 .26267 L 0 .034 .135 r
F
.40502 .26373 m .40325 .26172 L .40623 .26063 L F
.60592 .26567 m .60744 .26251 L .609 .26452 L 0 .038 .14 r
F
.60592 .26567 m .60435 .26365 L .60744 .26251 L F
.11291 .25903 m .11366 .25588 L .11572 .25795 L 0 .024 .123 r
F
.11291 .25903 m .11085 .25697 L .11366 .25588 L F
.36947 .2631 m .37063 .2598 L .37243 .26196 L 0 .032 .133 r
F
.36947 .2631 m .36767 .26094 L .37063 .2598 L F
.30609 .26141 m .30713 .25837 L .309 .26041 L 0 .029 .129 r
F
.30609 .26141 m .30422 .25936 L .30713 .25837 L F
.53145 .51277 m .53279 .47893 L .53447 .49414 L .622 .734 0 r
F
.53145 .51277 m .52978 .49594 L .53279 .47893 L F
.23498 .26018 m .23591 .2572 L .23786 .2591 L 0 .027 .126 r
F
.23498 .26018 m .23303 .25826 L .23591 .2572 L F
.27053 .26084 m .27152 .25783 L .27342 .25982 L 0 .028 .128 r
F
.27053 .26084 m .26862 .25887 L .27152 .25783 L F
.5395 .26686 m .54092 .26377 L .54255 .26579 L 0 .041 .143 r
F
.5395 .26686 m .53787 .26484 L .54092 .26377 L F
.64451 .26365 m .64608 .2604 L .64761 .26246 L 0 .034 .134 r
F
.64451 .26365 m .64298 .2616 L .64608 .2604 L F
.44828 .26408 m .44955 .26113 L .45128 .26313 L 0 .035 .136 r
F
.44828 .26408 m .44656 .26208 L .44955 .26113 L F
.65222 .26323 m .65382 .26023 L .65533 .26216 L 0 .033 .134 r
F
.65222 .26323 m .65071 .26129 L .65382 .26023 L F
.7418 .2609 m .74352 .25769 L .74495 .25977 L 0 .028 .128 r
F
.7418 .2609 m .74037 .25881 L .74352 .25769 L F
.19942 .25963 m .2003 .2566 L .20228 .25857 L 0 .026 .125 r
F
.19942 .25963 m .19744 .25764 L .2003 .2566 L F
.37717 .26292 m .37835 .25962 L .38014 .26176 L 0 .032 .133 r
F
.37717 .26292 m .37538 .26079 L .37835 .25962 L F
.12059 .25888 m .12134 .25588 L .1234 .25785 L 0 .025 .123 r
F
.12059 .25888 m .11853 .25691 L .12134 .25588 L F
.55494 .26616 m .55637 .26287 L .55799 .26482 L 0 .039 .141 r
F
.55494 .26616 m .55332 .26422 L .55637 .26287 L F
.24268 .25996 m .24362 .25699 L .24556 .25893 L 0 .027 .126 r
F
.24268 .25996 m .24074 .25804 L .24362 .25699 L F
.7928 .26082 m .7946 .25762 L .79598 .25971 L 0 .028 .128 r
F
.7928 .26082 m .79141 .25873 L .7946 .25762 L F
.31378 .26127 m .31484 .25824 L .31671 .26014 L 0 .029 .129 r
F
.31378 .26127 m .31192 .25934 L .31484 .25824 L F
.65995 .26299 m .66156 .26001 L .66306 .26191 L 0 .033 .134 r
F
.65995 .26299 m .65844 .26108 L .66156 .26001 L F
.74953 .26064 m .75126 .25736 L .75268 .25942 L 0 .028 .127 r
F
.74953 .26064 m .74811 .25857 L .75126 .25736 L F
.15613 .2596 m .15695 .25647 L .15897 .25848 L 0 .026 .125 r
F
.15613 .2596 m .15411 .25759 L .15695 .25647 L F
.3215 .26091 m .32256 .25801 L .32442 .25993 L 0 .029 .129 r
F
.3215 .26091 m .31964 .25902 L .32256 .25801 L F
.41272 .26369 m .41394 .26058 L .4157 .26269 L 0 .034 .135 r
F
.41272 .26369 m .41096 .26162 L .41394 .26058 L F
.34162 .26241 m .34272 .25928 L .34455 .26134 L 0 .032 .132 r
F
.34162 .26241 m .33979 .26036 L .34272 .25928 L F
.80052 .2605 m .80234 .25729 L .8037 .25929 L 0 .028 .127 r
F
.80052 .2605 m .79916 .2585 L .80234 .25729 L F
.38489 .26266 m .38605 .25973 L .38784 .26172 L 0 .032 .133 r
F
.38489 .26266 m .3831 .26064 L .38605 .25973 L F
.54722 .26673 m .54865 .26359 L .55027 .26557 L 0 .041 .143 r
F
.54722 .26673 m .5456 .26474 L .54865 .26359 L F
.46839 .26589 m .4697 .26241 L .4714 .26467 L 0 .038 .14 r
F
.46839 .26589 m .46669 .26363 L .4697 .26241 L F
.20711 .25947 m .20801 .25639 L .20998 .25835 L 0 .026 .125 r
F
.20711 .25947 m .20514 .25751 L .20801 .25639 L F
.16384 .25927 m .16466 .25619 L .16668 .25815 L 0 .026 .124 r
F
.16384 .25927 m .16182 .25733 L .16466 .25619 L F
.27822 .26077 m .27922 .25774 L .28112 .25972 L 0 .029 .128 r
F
.27822 .26077 m .27632 .25881 L .27922 .25774 L F
.50395 .26655 m .50531 .26337 L .50697 .26548 L 0 .04 .142 r
F
.50395 .26655 m .50228 .26439 L .50531 .26337 L F
.80825 .26016 m .8101 .25714 L .81145 .25912 L 0 .027 .127 r
F
.80825 .26016 m .8069 .25821 L .8101 .25714 L F
.47611 .26552 m .47743 .26223 L .47912 .26432 L 0 .038 .14 r
F
.47611 .26552 m .47441 .26346 L .47743 .26223 L F
.75726 .2604 m .75902 .25729 L .76043 .25932 L 0 .028 .127 r
F
.75726 .2604 m .75585 .25835 L .75902 .25729 L F
.66768 .26276 m .6693 .25977 L .67079 .26168 L 0 .033 .133 r
F
.66768 .26276 m .66618 .26084 L .6693 .25977 L F
.68311 .26193 m .68476 .25896 L .68624 .26093 L 0 .031 .131 r
F
.68311 .26193 m .68163 .25997 L .68476 .25896 L F
.34932 .26214 m .35044 .25911 L .35227 .26105 L 0 .031 .132 r
F
.34932 .26214 m .34749 .26023 L .35044 .25911 L F
.6754 .26237 m .67702 .25923 L .67851 .26114 L 0 .032 .132 r
F
.6754 .26237 m .67391 .26046 L .67702 .25923 L F
.085 .25852 m .0857 .25542 L .0878 .25738 L 0 .024 .123 r
F
.085 .25852 m .08289 .25657 L .0857 .25542 L F
.57809 .26518 m .57957 .26188 L .58116 .2641 L 0 .037 .139 r
F
.57809 .26518 m .5765 .26295 L .57957 .26188 L F
.12827 .25876 m .12902 .25578 L .13108 .25772 L 0 .025 .123 r
F
.12827 .25876 m .12621 .25682 L .12902 .25578 L F
.48383 .26523 m .48516 .2619 L .48684 .26405 L 0 .037 .139 r
F
.48383 .26523 m .48214 .26311 L .48516 .2619 L F
.21481 .25926 m .21573 .25606 L .21768 .25813 L 0 .026 .124 r
F
.21481 .25926 m .21285 .2572 L .21573 .25606 L F
.0927 .25819 m .09341 .25514 L .0955 .25712 L 0 .024 .122 r
F
.0927 .25819 m .09061 .25623 L .09341 .25514 L F
.25036 .25994 m .25132 .25693 L .25324 .25896 L 0 .027 .127 r
F
.25036 .25994 m .24844 .25791 L .25132 .25693 L F
.17153 .25909 m .17236 .25607 L .17437 .25806 L 0 .026 .124 r
F
.17153 .25909 m .16952 .25711 L .17236 .25607 L F
.28592 .26058 m .28694 .25744 L .28883 .25944 L 0 .028 .128 r
F
.28592 .26058 m .28403 .25858 L .28694 .25744 L F
.765 .26022 m .76676 .25706 L .76816 .25907 L 0 .028 .127 r
F
.765 .26022 m .7636 .25821 L .76676 .25706 L F
.81599 .26002 m .81783 .2568 L .81918 .25881 L 0 .027 .126 r
F
.81599 .26002 m .81465 .25803 L .81783 .2568 L F
.82372 .25962 m .82557 .25647 L .82692 .25852 L F
.82372 .25962 m .82237 .25759 L .82557 .25647 L F
.35703 .26199 m .35815 .259 L .35997 .26099 L 0 .031 .132 r
F
.35703 .26199 m .35521 .26002 L .35815 .259 L F
.45598 .26435 m .45727 .26121 L .45898 .26338 L 0 .036 .138 r
F
.45598 .26435 m .45427 .26217 L .45727 .26121 L F
.51166 .26653 m .51304 .26305 L .51469 .26532 L 0 .04 .142 r
F
.51166 .26653 m .51 .26428 L .51304 .26305 L F
.13595 .25862 m .13673 .25557 L .13877 .25754 L 0 .025 .123 r
F
.13595 .25862 m .1339 .25667 L .13673 .25557 L F
.39258 .26276 m .39376 .25982 L .39554 .26178 L 0 .033 .134 r
F
.39258 .26276 m .3908 .26078 L .39376 .25982 L F
.77273 .25998 m .77451 .25679 L .7759 .25886 L 0 .027 .127 r
F
.77273 .25998 m .77133 .25793 L .77451 .25679 L F
.42042 .26384 m .42165 .26073 L .4234 .26288 L 0 .035 .137 r
F
.42042 .26384 m .41867 .26171 L .42165 .26073 L F
.29362 .26044 m .29466 .25714 L .29653 .2593 L 0 .028 .128 r
F
.29362 .26044 m .29175 .25829 L .29466 .25714 L F
.32918 .26108 m .33026 .25799 L .3321 .26013 L 0 .03 .13 r
F
.32918 .26108 m .32734 .25895 L .33026 .25799 L F
.10037 .25811 m .10109 .25507 L .10317 .25709 L 0 .024 .122 r
F
.10037 .25811 m .09829 .2561 L .10109 .25507 L F
.58582 .26519 m .58731 .26182 L .58889 .26405 L 0 .038 .14 r
F
.58582 .26519 m .58423 .26296 L .58731 .26182 L F
.69086 .26199 m .69251 .25879 L .69399 .26083 L 0 .031 .132 r
F
.69086 .26199 m .68938 .25993 L .69251 .25879 L F
.22249 .25925 m .22341 .25615 L .22535 .25826 L 0 .026 .125 r
F
.22249 .25925 m .22054 .25714 L .22341 .25615 L F
.69858 .26162 m .70024 .25837 L .70171 .26037 L 0 .031 .131 r
F
.69858 .26162 m .69711 .2596 L .70024 .25837 L F
.49154 .26526 m .49288 .26204 L .49456 .26422 L 0 .038 .14 r
F
.49154 .26526 m .48986 .26305 L .49288 .26204 L F
.7063 .2612 m .70798 .25806 L .70944 .26001 L 0 .03 .13 r
F
.7063 .2612 m .70484 .25921 L .70798 .25806 L F
.71402 .26079 m .71571 .25769 L .71716 .25962 L 0 .029 .129 r
F
.71402 .26079 m .71257 .25884 L .71571 .25769 L F
.1792 .25908 m .18007 .25584 L .18205 .25795 L 0 .026 .125 r
F
.1792 .25908 m .17721 .25697 L .18007 .25584 L F
.72174 .26038 m .72344 .25723 L .72488 .25915 L 0 .028 .128 r
F
.72174 .26038 m .7203 .25846 L .72344 .25723 L F
.83147 .25954 m .83334 .25643 L .83468 .25851 L 0 .027 .126 r
F
.83147 .25954 m .83013 .25747 L .83334 .25643 L F
.72947 .25998 m .73117 .25668 L .73261 .25878 L 0 .027 .127 r
F
.72947 .25998 m .72802 .2579 L .73117 .25668 L F
.63214 .26277 m .63371 .25968 L .63524 .26173 L 0 .033 .134 r
F
.63214 .26277 m .63061 .26077 L .63371 .25968 L F
.78047 .25981 m .78226 .25662 L .78365 .2587 L 0 .027 .127 r
F
.78047 .25981 m .77908 .25773 L .78226 .25662 L F
.51938 .26645 m .52077 .26281 L .52242 .26517 L 0 .04 .142 r
F
.51938 .26645 m .51773 .2641 L .52077 .26281 L F
.14363 .25853 m .14443 .25541 L .14645 .2575 L 0 .025 .124 r
F
.14363 .25853 m .1416 .25646 L .14443 .25541 L F
.62443 .26329 m .62597 .25992 L .62751 .26199 L 0 .034 .135 r
F
.62443 .26329 m .62288 .26123 L .62597 .25992 L F
.25803 .26009 m .25902 .2569 L .26092 .25901 L 0 .028 .127 r
F
.25803 .26009 m .25612 .25799 L .25902 .2569 L F
.30131 .26036 m .30236 .2572 L .30422 .25936 L 0 .029 .128 r
F
.30131 .26036 m .29945 .25819 L .30236 .2572 L F
.36472 .26207 m .36587 .25882 L .36767 .26094 L 0 .032 .132 r
F
.36472 .26207 m .36292 .25994 L .36587 .25882 L F
.51009 .51936 m .5085 .50256 L .51147 .5167 L .796 .704 0 r
F
.5085 .50256 m .50988 .49734 L .51147 .5167 L .622 .734 0 r
F
.40028 .26275 m .40148 .25977 L .40325 .26172 L 0 .034 .135 r
F
.40028 .26275 m .39851 .26077 L .40148 .25977 L F
.59355 .2651 m .59504 .2616 L .59662 .26383 L 0 .038 .14 r
F
.59355 .2651 m .59197 .26283 L .59504 .2616 L F
.18689 .25892 m .18777 .25568 L .18975 .25779 L 0 .026 .125 r
F
.18689 .25892 m .18491 .25682 L .18777 .25568 L F
.10804 .25807 m .10879 .25489 L .11085 .25697 L 0 .024 .123 r
F
.10804 .25807 m .10598 .256 L .10879 .25489 L F
.5271 .26621 m .5285 .26273 L .53014 .26504 L 0 .04 .142 r
F
.5271 .26621 m .52546 .26389 L .5285 .26273 L F
.5657 .26408 m .56716 .26084 L .56876 .26276 L 0 .036 .138 r
F
.5657 .26408 m .5641 .26215 L .56716 .26084 L F
.61671 .26388 m .61824 .26048 L .61979 .26254 L 0 .036 .137 r
F
.61671 .26388 m .61516 .26186 L .61824 .26048 L F
.73721 .25984 m .73893 .25672 L .74037 .25881 L 0 .028 .127 r
F
.73721 .25984 m .73577 .25775 L .73893 .25672 L F
.42812 .26391 m .42937 .26061 L .43111 .26272 L 0 .036 .137 r
F
.42812 .26391 m .42638 .26178 L .42937 .26061 L F
.60127 .2648 m .60278 .26149 L .60435 .26365 L 0 .038 .139 r
F
.60127 .2648 m .5997 .2626 L .60278 .26149 L F
.44356 .26316 m .44483 .26007 L .44656 .26208 L 0 .035 .136 r
F
.44356 .26316 m .44183 .26115 L .44483 .26007 L F
.43584 .26359 m .4371 .26033 L .43884 .26237 L 0 .035 .137 r
F
.43584 .26359 m .43411 .26153 L .4371 .26033 L F
.52674 .51202 m .52811 .47817 L .52978 .49594 L .623 .734 0 r
F
.52674 .51202 m .52508 .49262 L .52811 .47817 L F
.46369 .26468 m .46499 .26137 L .46669 .26363 L 0 .038 .139 r
F
.46369 .26468 m .46198 .26241 L .46499 .26137 L F
.78822 .25975 m .79003 .25663 L .79141 .25873 L 0 .028 .127 r
F
.78822 .25975 m .78684 .25767 L .79003 .25663 L F
.63988 .26276 m .64145 .25949 L .64298 .2616 L 0 .034 .135 r
F
.63988 .26276 m .63835 .26068 L .64145 .25949 L F
.23016 .25933 m .2311 .25618 L .23303 .25826 L 0 .027 .126 r
F
.23016 .25933 m .22822 .25724 L .2311 .25618 L F
.53482 .26597 m .53623 .26282 L .53787 .26484 L 0 .041 .143 r
F
.53482 .26597 m .53319 .26393 L .53623 .26282 L F
.26572 .25999 m .26673 .25673 L .26862 .25887 L 0 .028 .128 r
F
.26572 .25999 m .26382 .25787 L .26673 .25673 L F
.609 .26452 m .61052 .26121 L .61208 .26323 L 0 .037 .139 r
F
.609 .26452 m .60744 .26251 L .61052 .26121 L F
.19459 .25874 m .19547 .25556 L .19744 .25764 L 0 .026 .125 r
F
.19459 .25874 m .19261 .25666 L .19547 .25556 L F
.37243 .26196 m .37359 .25864 L .37538 .26079 L 0 .032 .132 r
F
.37243 .26196 m .37063 .2598 L .37359 .25864 L F
.33686 .26132 m .33796 .25822 L .33979 .26036 L 0 .031 .131 r
F
.33686 .26132 m .33503 .25918 L .33796 .25822 L F
.49925 .26542 m .50061 .26223 L .50228 .26439 L 0 .04 .141 r
F
.49925 .26542 m .49758 .26321 L .50061 .26223 L F
.11572 .25795 m .11647 .25484 L .11853 .25691 L 0 .025 .123 r
F
.11572 .25795 m .11366 .25588 L .11647 .25484 L F
.15129 .25859 m .1521 .2555 L .15411 .25759 L 0 .026 .125 r
F
.15129 .25859 m .14927 .2565 L .1521 .2555 L F
.40799 .26267 m .4092 .25954 L .41096 .26162 L 0 .034 .135 r
F
.40799 .26267 m .40623 .26063 L .4092 .25954 L F
.55799 .26482 m .55943 .26154 L .56104 .26348 L 0 .038 .14 r
F
.55799 .26482 m .55637 .26287 L .55943 .26154 L F
.64761 .26246 m .64919 .25921 L .65071 .26129 L 0 .033 .134 r
F
.64761 .26246 m .64608 .2604 L .64919 .25921 L F
.57343 .26398 m .5749 .26074 L .5765 .26295 L 0 .036 .138 r
F
.57343 .26398 m .57183 .26175 L .5749 .26074 L F
.23786 .2591 m .23879 .25612 L .24074 .25804 L 0 .027 .126 r
F
.23786 .2591 m .23591 .2572 L .23879 .25612 L F
.309 .26041 m .31005 .25732 L .31192 .25934 L 0 .029 .129 r
F
.309 .26041 m .30713 .25837 L .31005 .25732 L F
.74495 .25977 m .74668 .2565 L .74811 .25857 L 0 .028 .127 r
F
.74495 .25977 m .74352 .25769 L .74668 .2565 L F
.54255 .26579 m .54397 .26271 L .5456 .26474 L 0 .041 .143 r
F
.54255 .26579 m .54092 .26377 L .54397 .26271 L F
.65533 .26216 m .65694 .25917 L .65844 .26108 L 0 .033 .134 r
F
.65533 .26216 m .65382 .26023 L .65694 .25917 L F
.27342 .25982 m .27442 .2568 L .27632 .25881 L 0 .028 .128 r
F
.27342 .25982 m .27152 .25783 L .27442 .2568 L F
.38014 .26176 m .38131 .2585 L .3831 .26064 L 0 .032 .132 r
F
.38014 .26176 m .37835 .25962 L .38131 .2585 L F
.75268 .25942 m .75443 .25631 L .75585 .25835 L 0 .028 .127 r
F
.75268 .25942 m .75126 .25736 L .75443 .25631 L F
.20228 .25857 m .20316 .25555 L .20514 .25751 L 0 .026 .125 r
F
.20228 .25857 m .2003 .2566 L .20316 .25555 L F
.45128 .26313 m .45255 .26017 L .45427 .26217 L 0 .035 .137 r
F
.45128 .26313 m .44955 .26113 L .45255 .26017 L F
.79598 .25971 m .79778 .25642 L .79916 .2585 L 0 .028 .127 r
F
.79598 .25971 m .7946 .25762 L .79778 .25642 L F
.31671 .26014 m .31777 .25713 L .31964 .25902 L 0 .029 .129 r
F
.31671 .26014 m .31484 .25824 L .31777 .25713 L F
.8037 .25929 m .80554 .2562 L .8069 .25821 L 0 .027 .127 r
F
.8037 .25929 m .80234 .25729 L .80554 .2562 L F
.4714 .26467 m .47272 .26118 L .47441 .26346 L 0 .038 .14 r
F
.4714 .26467 m .4697 .26241 L .47272 .26118 L F
.15897 .25848 m .1598 .25531 L .16182 .25733 L 0 .026 .125 r
F
.15897 .25848 m .15695 .25647 L .1598 .25531 L F
.66306 .26191 m .66468 .25893 L .66618 .26084 L 0 .033 .134 r
F
.66306 .26191 m .66156 .26001 L .66468 .25893 L F
.1234 .25785 m .12415 .25484 L .12621 .25682 L 0 .025 .123 r
F
.1234 .25785 m .12134 .25588 L .12415 .25484 L F
.24556 .25893 m .2465 .25595 L .24844 .25791 L 0 .027 .126 r
F
.24556 .25893 m .24362 .25699 L .2465 .25595 L F
.55027 .26557 m .5517 .26222 L .55332 .26422 L 0 .04 .142 r
F
.55027 .26557 m .54865 .26359 L .5517 .26222 L F
.47912 .26432 m .48045 .26098 L .48214 .26311 L 0 .037 .139 r
F
.47912 .26432 m .47743 .26223 L .48045 .26098 L F
.34455 .26134 m .34567 .25814 L .34749 .26023 L 0 .031 .132 r
F
.34455 .26134 m .34272 .25928 L .34567 .25814 L F
.20998 .25835 m .21088 .25523 L .21285 .2572 L 0 .026 .125 r
F
.20998 .25835 m .20801 .25639 L .21088 .25523 L F
.67851 .26114 m .68015 .25805 L .68163 .25997 L 0 .031 .132 r
F
.67851 .26114 m .67702 .25923 L .68015 .25805 L F
.16668 .25815 m .16751 .25513 L .16952 .25711 L 0 .026 .124 r
F
.16668 .25815 m .16466 .25619 L .16751 .25513 L F
.4157 .26269 m .41692 .25956 L .41867 .26171 L 0 .034 .136 r
F
.4157 .26269 m .41394 .26058 L .41692 .25956 L F
.50697 .26548 m .50834 .26217 L .51 .26428 L 0 .04 .142 r
F
.50697 .26548 m .50531 .26337 L .50834 .26217 L F
.32442 .25993 m .32549 .25701 L .32734 .25895 L 0 .029 .129 r
F
.32442 .25993 m .32256 .25801 L .32549 .25701 L F
.28112 .25972 m .28213 .25661 L .28403 .25858 L 0 .028 .128 r
F
.28112 .25972 m .27922 .25774 L .28213 .25661 L F
.0878 .25738 m .08851 .25426 L .09061 .25623 L 0 .024 .122 r
F
.0878 .25738 m .0857 .25542 L .08851 .25426 L F
.76043 .25932 m .76219 .25621 L .7636 .25821 L 0 .028 .127 r
F
.76043 .25932 m .75902 .25729 L .76219 .25621 L F
.67079 .26168 m .67242 .25855 L .67391 .26046 L 0 .032 .133 r
F
.67079 .26168 m .6693 .25977 L .67242 .25855 L F
.81145 .25912 m .81329 .25604 L .81465 .25803 L 0 .027 .127 r
F
.81145 .25912 m .8101 .25714 L .81329 .25604 L F
.35227 .26105 m .35338 .25806 L .35521 .26002 L 0 .031 .132 r
F
.35227 .26105 m .35044 .25911 L .35338 .25806 L F
.48684 .26405 m .48818 .26091 L .48986 .26305 L 0 .037 .139 r
F
.48684 .26405 m .48516 .2619 L .48818 .26091 L F
.38784 .26172 m .38901 .25881 L .3908 .26078 L 0 .033 .134 r
F
.38784 .26172 m .38605 .25973 L .38901 .25881 L F
.58116 .2641 m .58264 .26075 L .58423 .26296 L 0 .037 .139 r
F
.58116 .2641 m .57957 .26188 L .58264 .26075 L F
.21768 .25813 m .21859 .25507 L .22054 .25714 L 0 .026 .124 r
F
.21768 .25813 m .21573 .25606 L .21859 .25507 L F
.68624 .26093 m .6879 .25795 L .68938 .25993 L 0 .031 .132 r
F
.68624 .26093 m .68476 .25896 L .6879 .25795 L F
.13108 .25772 m .13184 .25473 L .1339 .25667 L 0 .025 .124 r
F
.13108 .25772 m .12902 .25578 L .13184 .25473 L F
.28883 .25944 m .28986 .25628 L .29175 .25829 L 0 .028 .128 r
F
.28883 .25944 m .28694 .25744 L .28986 .25628 L F
.81918 .25881 m .82103 .25557 L .82237 .25759 L 0 .027 .126 r
F
.81918 .25881 m .81783 .2568 L .82103 .25557 L F
.0955 .25712 m .09621 .25412 L .09829 .2561 L 0 .024 .122 r
F
.0955 .25712 m .09341 .25514 L .09621 .25412 L F
.76816 .25907 m .76993 .2559 L .77133 .25793 L 0 .027 .127 r
F
.76816 .25907 m .76676 .25706 L .76993 .2559 L F
.51469 .26532 m .51607 .2618 L .51773 .2641 L 0 .04 .142 r
F
.51469 .26532 m .51304 .26305 L .51607 .2618 L F
.17437 .25806 m .17521 .25497 L .17721 .25697 L 0 .026 .124 r
F
.17437 .25806 m .17236 .25607 L .17521 .25497 L F
.82692 .25852 m .82879 .25541 L .83013 .25747 L 0 .027 .126 r
F
.82692 .25852 m .82557 .25647 L .82879 .25541 L F
.25324 .25896 m .2542 .25595 L .25612 .25799 L 0 .028 .127 r
F
.25324 .25896 m .25132 .25693 L .2542 .25595 L F
.13877 .25754 m .13956 .25447 L .1416 .25646 L 0 .025 .123 r
F
.13877 .25754 m .13673 .25557 L .13956 .25447 L F
.35997 .26099 m .3611 .25794 L .36292 .25994 L 0 .032 .132 r
F
.35997 .26099 m .35815 .259 L .3611 .25794 L F
.7759 .25886 m .77769 .25566 L .77908 .25773 L 0 .027 .127 r
F
.7759 .25886 m .77451 .25679 L .77769 .25566 L F
.70171 .26037 m .70338 .25725 L .70484 .25921 L 0 .03 .13 r
F
.70171 .26037 m .70024 .25837 L .70338 .25725 L F
.29653 .2593 m .29758 .25601 L .29945 .25819 L 0 .028 .127 r
F
.29653 .2593 m .29466 .25714 L .29758 .25601 L F
.51896 .50743 m .52039 .47974 L .52202 .50002 L .601 .729 0 r
F
.51896 .50743 m .51734 .4864 L .52039 .47974 L F
.45898 .26338 m .46027 .26025 L .46198 .26241 L 0 .037 .138 r
F
.45898 .26338 m .45727 .26121 L .46027 .26025 L F
.69399 .26083 m .69564 .25758 L .69711 .2596 L 0 .031 .131 r
F
.69399 .26083 m .69251 .25879 L .69564 .25758 L F
.58889 .26405 m .59038 .26064 L .59197 .26283 L 0 .038 .139 r
F
.58889 .26405 m .58731 .26182 L .59038 .26064 L F
.72488 .25915 m .72659 .25598 L .72802 .2579 L 0 .028 .127 r
F
.72488 .25915 m .72344 .25723 L .72659 .25598 L F
.70944 .26001 m .71112 .25691 L .71257 .25884 L 0 .03 .13 r
F
.70944 .26001 m .70798 .25806 L .71112 .25691 L F
.52242 .26517 m .52381 .26152 L .52546 .26389 L 0 .04 .142 r
F
.52242 .26517 m .52077 .26281 L .52381 .26152 L F
.71716 .25962 m .71886 .25653 L .7203 .25846 L 0 .029 .129 r
F
.71716 .25962 m .71571 .25769 L .71886 .25653 L F
.62751 .26199 m .62906 .25868 L .63061 .26077 L 0 .033 .134 r
F
.62751 .26199 m .62597 .25992 L .62906 .25868 L F
.39554 .26178 m .39673 .25885 L .39851 .26077 L 0 .034 .135 r
F
.39554 .26178 m .39376 .25982 L .39673 .25885 L F
.73261 .25878 m .73433 .25565 L .73577 .25775 L 0 .027 .127 r
F
.73261 .25878 m .73117 .25668 L .73433 .25565 L F
.10317 .25709 m .1039 .25398 L .10598 .256 L 0 .024 .123 r
F
.10317 .25709 m .10109 .25507 L .1039 .25398 L F
.18205 .25795 m .18293 .25471 L .18491 .25682 L 0 .026 .124 r
F
.18205 .25795 m .18007 .25584 L .18293 .25471 L F
.4234 .26288 m .42464 .25963 L .42638 .26178 L 0 .035 .137 r
F
.4234 .26288 m .42165 .26073 L .42464 .25963 L F
.3321 .26013 m .33319 .25704 L .33503 .25918 L 0 .03 .13 r
F
.3321 .26013 m .33026 .25799 L .33319 .25704 L F
.49456 .26422 m .49591 .26105 L .49758 .26321 L 0 .039 .14 r
F
.49456 .26422 m .49288 .26204 L .49591 .26105 L F
.53825 .52423 m .53667 .53909 L .53967 .52153 L .796 .703 0 r
F
.53967 .52153 m .53806 .52693 L .54103 .50762 L .774 .758 0 r
F
.53806 .52693 m .53943 .5123 L .54103 .50762 L .8 .694 0 r
F
.61979 .26254 m .62133 .25916 L .62288 .26123 L 0 .035 .136 r
F
.61979 .26254 m .61824 .26048 L .62133 .25916 L F
.22535 .25826 m .22628 .25513 L .22822 .25724 L 0 .026 .126 r
F
.22535 .25826 m .22341 .25615 L .22628 .25513 L F
.59662 .26383 m .59812 .2604 L .5997 .2626 L 0 .037 .139 r
F
.59662 .26383 m .59504 .2616 L .59812 .2604 L F
.56876 .26276 m .57023 .2598 L .57183 .26175 L 0 .036 .137 r
F
.56876 .26276 m .56716 .26084 L .57023 .2598 L F
.78365 .2587 m .78545 .25558 L .78684 .25767 L 0 .027 .127 r
F
.78365 .2587 m .78226 .25662 L .78545 .25558 L F
.63524 .26173 m .63681 .25859 L .63835 .26068 L 0 .033 .134 r
F
.63524 .26173 m .63371 .25968 L .63681 .25859 L F
.14645 .2575 m .14725 .2544 L .14927 .2565 L 0 .025 .124 r
F
.14645 .2575 m .14443 .25541 L .14725 .2544 L F
.36767 .26094 m .36883 .2577 L .37063 .2598 L 0 .032 .132 r
F
.36767 .26094 m .36587 .25882 L .36883 .2577 L F
.26092 .25901 m .26192 .25575 L .26382 .25787 L 0 .028 .127 r
F
.26092 .25901 m .25902 .2569 L .26192 .25575 L F
.53014 .26504 m .53154 .26165 L .53319 .26393 L 0 .04 .142 r
F
.53014 .26504 m .5285 .26273 L .53154 .26165 L F
.18975 .25779 m .19063 .25454 L .19261 .25666 L 0 .026 .124 r
F
.18975 .25779 m .18777 .25568 L .19063 .25454 L F
.43111 .26272 m .43237 .25945 L .43411 .26153 L 0 .035 .137 r
F
.43111 .26272 m .42937 .26061 L .43237 .25945 L F
.11085 .25697 m .1116 .25381 L .11366 .25588 L 0 .024 .123 r
F
.11085 .25697 m .10879 .25489 L .1116 .25381 L F
.30422 .25936 m .30527 .25621 L .30713 .25837 L 0 .029 .129 r
F
.30422 .25936 m .30236 .2572 L .30527 .25621 L F
.40325 .26172 m .40445 .25865 L .40623 .26063 L 0 .034 .135 r
F
.40325 .26172 m .40148 .25977 L .40445 .25865 L F
.60435 .26365 m .60587 .26038 L .60744 .26251 L 0 .038 .139 r
F
.60435 .26365 m .60278 .26149 L .60587 .26038 L F
.43884 .26237 m .4401 .25912 L .44183 .26115 L 0 .035 .136 r
F
.43884 .26237 m .4371 .26033 L .4401 .25912 L F
.61208 .26323 m .6136 .25982 L .61516 .26186 L 0 .036 .138 r
F
.61208 .26323 m .61052 .26121 L .6136 .25982 L F
.56104 .26348 m .56249 .26022 L .5641 .26215 L 0 .037 .139 r
F
.56104 .26348 m .55943 .26154 L .56249 .26022 L F
.74037 .25881 m .74209 .2556 L .74352 .25769 L 0 .028 .127 r
F
.74037 .25881 m .73893 .25672 L .74209 .2556 L F
.64298 .2616 m .64455 .25825 L .64608 .2604 L 0 .033 .134 r
F
.64298 .2616 m .64145 .25949 L .64455 .25825 L F
.53787 .26484 m .53928 .26175 L .54092 .26377 L 0 .041 .143 r
F
.53787 .26484 m .53623 .26282 L .53928 .26175 L F
.37538 .26079 m .37656 .25746 L .37835 .25962 L 0 .032 .132 r
F
.37538 .26079 m .37359 .25864 L .37656 .25746 L F
.44656 .26208 m .44783 .25912 L .44955 .26113 L 0 .035 .136 r
F
.44656 .26208 m .44483 .26007 L .44783 .25912 L F
.26862 .25887 m .26962 .25567 L .27152 .25783 L 0 .028 .128 r
F
.26862 .25887 m .26673 .25673 L .26962 .25567 L F
.52609 .53507 m .52751 .55759 L .52914 .54133 L .868 .495 0 r
F
.52609 .53507 m .52444 .55063 L .52751 .55759 L F
.23303 .25826 m .23397 .25512 L .23591 .2572 L 0 .027 .126 r
F
.23303 .25826 m .2311 .25618 L .23397 .25512 L F
.46669 .26363 m .468 .26013 L .4697 .26241 L 0 .037 .139 r
F
.46669 .26363 m .46499 .26137 L .468 .26013 L F
.19744 .25764 m .19833 .25452 L .2003 .2566 L 0 .026 .125 r
F
.19744 .25764 m .19547 .25556 L .19833 .25452 L F
.65071 .26129 m .6523 .25816 L .65382 .26023 L 0 .033 .134 r
F
.65071 .26129 m .64919 .25921 L .6523 .25816 L F
.79141 .25873 m .79322 .25552 L .7946 .25762 L 0 .028 .127 r
F
.79141 .25873 m .79003 .25663 L .79322 .25552 L F
.74811 .25857 m .74984 .25531 L .75126 .25736 L 0 .027 .127 r
F
.74811 .25857 m .74668 .2565 L .74984 .25531 L F
.50228 .26439 m .50364 .26125 L .50531 .26337 L 0 .04 .142 r
F
.50228 .26439 m .50061 .26223 L .50364 .26125 L F
.41096 .26162 m .41218 .25846 L .41394 .26058 L 0 .034 .135 r
F
.41096 .26162 m .4092 .25954 L .41218 .25846 L F
.11853 .25691 m .11929 .2538 L .12134 .25588 L 0 .025 .123 r
F
.11853 .25691 m .11647 .25484 L .11929 .2538 L F
.33979 .26036 m .3409 .25713 L .34272 .25928 L 0 .031 .132 r
F
.33979 .26036 m .33796 .25822 L .3409 .25713 L F
.55332 .26422 m .55476 .26086 L .55637 .26287 L 0 .039 .141 r
F
.55332 .26422 m .5517 .26222 L .55476 .26086 L F
.15411 .25759 m .15494 .25437 L .15695 .25647 L 0 .026 .125 r
F
.15411 .25759 m .1521 .2555 L .15494 .25437 L F
.5765 .26295 m .57797 .25968 L .57957 .26188 L 0 .037 .138 r
F
.5765 .26295 m .5749 .26074 L .57797 .25968 L F
.24074 .25804 m .24168 .25504 L .24362 .25699 L 0 .027 .126 r
F
.24074 .25804 m .23879 .25612 L .24168 .25504 L F
.31192 .25934 m .31298 .25623 L .31484 .25824 L 0 .029 .129 r
F
.31192 .25934 m .31005 .25732 L .31298 .25623 L F
.3831 .26064 m .38427 .25757 L .38605 .25973 L 0 .032 .133 r
F
.3831 .26064 m .38131 .2585 L .38427 .25757 L F
.79916 .2585 m .80097 .25522 L .80234 .25729 L 0 .027 .127 r
F
.79916 .2585 m .79778 .25642 L .80097 .25522 L F
.53523 .53231 m .53667 .53909 L .53825 .52423 L .84 .582 0 r
F
.65844 .26108 m .66005 .25809 L .66156 .26001 L 0 .033 .134 r
F
.65844 .26108 m .65694 .25917 L .66005 .25809 L F
.5456 .26474 m .54702 .26154 L .54865 .26359 L 0 .041 .143 r
F
.5456 .26474 m .54397 .26271 L .54702 .26154 L F
.47441 .26346 m .47574 .25994 L .47743 .26223 L 0 .037 .139 r
F
.47441 .26346 m .47272 .26118 L .47574 .25994 L F
.75585 .25835 m .75761 .25526 L .75902 .25729 L 0 .028 .127 r
F
.75585 .25835 m .75443 .25631 L .75761 .25526 L F
.20514 .25751 m .20603 .25442 L .20801 .25639 L 0 .026 .125 r
F
.20514 .25751 m .20316 .25555 L .20603 .25442 L F
.31964 .25902 m .3207 .2561 L .32256 .25801 L 0 .029 .129 r
F
.31964 .25902 m .31777 .25713 L .3207 .2561 L F
.27632 .25881 m .27732 .25573 L .27922 .25774 L 0 .029 .128 r
F
.27632 .25881 m .27442 .2568 L .27732 .25573 L F
.48214 .26311 m .48347 .25975 L .48516 .2619 L 0 .037 .139 r
F
.48214 .26311 m .48045 .26098 L .48347 .25975 L F
.16182 .25733 m .16265 .25417 L .16466 .25619 L 0 .026 .124 r
F
.16182 .25733 m .1598 .25531 L .16265 .25417 L F
.8069 .25821 m .80874 .25514 L .8101 .25714 L 0 .027 .127 r
F
.8069 .25821 m .80554 .2562 L .80874 .25514 L F
.68163 .25997 m .68328 .25702 L .68476 .25896 L 0 .031 .132 r
F
.68163 .25997 m .68015 .25805 L .68328 .25702 L F
.66618 .26084 m .6678 .25785 L .6693 .25977 L 0 .033 .134 r
F
.66618 .26084 m .66468 .25893 L .6678 .25785 L F
.21285 .2572 m .21376 .25409 L .21573 .25606 L 0 .026 .124 r
F
.21285 .2572 m .21088 .25523 L .21376 .25409 L F
.51 .26428 m .51138 .26092 L .51304 .26305 L 0 .04 .142 r
F
.51 .26428 m .50834 .26217 L .51138 .26092 L F
.34749 .26023 m .34862 .25701 L .35044 .25911 L 0 .031 .132 r
F
.34749 .26023 m .34567 .25814 L .34862 .25701 L F
.45427 .26217 m .45555 .25921 L .45727 .26121 L 0 .036 .137 r
F
.45427 .26217 m .45255 .26017 L .45555 .25921 L F
.12621 .25682 m .12697 .2538 L .12902 .25578 L 0 .025 .124 r
F
.12621 .25682 m .12415 .25484 L .12697 .2538 L F
.67391 .26046 m .67554 .25731 L .67702 .25923 L 0 .032 .133 r
F
.67391 .26046 m .67242 .25855 L .67554 .25731 L F
.24844 .25791 m .24939 .25495 L .25132 .25693 L 0 .027 .127 r
F
.24844 .25791 m .2465 .25595 L .24939 .25495 L F
.28403 .25858 m .28505 .25546 L .28694 .25744 L 0 .028 .128 r
F
.28403 .25858 m .28213 .25661 L .28505 .25546 L F
.09061 .25623 m .09132 .25317 L .09341 .25514 L 0 .024 .122 r
F
.09061 .25623 m .08851 .25426 L .09132 .25317 L F
.51147 .5167 m .50988 .49734 L .51289 .50284 L .774 .758 0 r
F
.16952 .25711 m .17035 .25407 L .17236 .25607 L 0 .026 .124 r
F
.16952 .25711 m .16751 .25513 L .17035 .25407 L F
.7636 .25821 m .76536 .25507 L .76676 .25706 L 0 .028 .127 r
F
.7636 .25821 m .76219 .25621 L .76536 .25507 L F
.82237 .25759 m .82423 .25443 L .82557 .25647 L 0 .026 .126 r
F
.82237 .25759 m .82103 .25557 L .82423 .25443 L F
.81465 .25803 m .81648 .25479 L .81783 .2568 L 0 .027 .126 r
F
.81465 .25803 m .81329 .25604 L .81648 .25479 L F
.58423 .26296 m .58572 .25962 L .58731 .26182 L 0 .037 .139 r
F
.58423 .26296 m .58264 .26075 L .58572 .25962 L F
.41867 .26171 m .4199 .25854 L .42165 .26073 L 0 .035 .136 r
F
.41867 .26171 m .41692 .25956 L .4199 .25854 L F
.29175 .25829 m .29278 .25511 L .29466 .25714 L 0 .028 .127 r
F
.29175 .25829 m .28986 .25628 L .29278 .25511 L F
.35521 .26002 m .35633 .257 L .35815 .259 L 0 .032 .132 r
F
.35521 .26002 m .35338 .25806 L .35633 .257 L F
.32734 .25895 m .32841 .25602 L .33026 .25799 L 0 .03 .13 r
F
.32734 .25895 m .32549 .25701 L .32841 .25602 L F
.51773 .2641 m .51912 .26051 L .52077 .26281 L 0 .039 .141 r
F
.51773 .2641 m .51607 .2618 L .51912 .26051 L F
.48986 .26305 m .4912 .25991 L .49288 .26204 L 0 .038 .139 r
F
.48986 .26305 m .48818 .26091 L .4912 .25991 L F
.77133 .25793 m .77311 .25475 L .77451 .25679 L 0 .027 .127 r
F
.77133 .25793 m .76993 .2559 L .77311 .25475 L F
.1339 .25667 m .13468 .25361 L .13673 .25557 L 0 .025 .124 r
F
.1339 .25667 m .13184 .25473 L .13468 .25361 L F
.22054 .25714 m .22146 .25407 L .22341 .25615 L 0 .026 .125 r
F
.22054 .25714 m .21859 .25507 L .22146 .25407 L F
.3908 .26078 m .39198 .25787 L .39376 .25982 L 0 .033 .134 r
F
.3908 .26078 m .38901 .25881 L .39198 .25787 L F
.68938 .25993 m .69103 .2568 L .69251 .25879 L 0 .031 .132 r
F
.68938 .25993 m .6879 .25795 L .69103 .2568 L F
.09829 .2561 m .09901 .25309 L .10109 .25507 L 0 .024 .122 r
F
.09829 .2561 m .09621 .25412 L .09901 .25309 L F
.17721 .25697 m .17807 .25384 L .18007 .25584 L 0 .026 .124 r
F
.17721 .25697 m .17521 .25497 L .17807 .25384 L F
.69711 .2596 m .69877 .25637 L .70024 .25837 L 0 .031 .131 r
F
.69711 .2596 m .69564 .25758 L .69877 .25637 L F
.52546 .26389 m .52685 .26037 L .5285 .26273 L 0 .039 .141 r
F
.52546 .26389 m .52381 .26152 L .52685 .26037 L F
.72802 .2579 m .72974 .25477 L .73117 .25668 L 0 .027 .127 r
F
.72802 .2579 m .72659 .25598 L .72974 .25477 L F
.83013 .25747 m .832 .25434 L .83334 .25643 L 0 .027 .126 r
F
.83013 .25747 m .82879 .25541 L .832 .25434 L F
.59197 .26283 m .59346 .25945 L .59504 .2616 L 0 .037 .139 r
F
.59197 .26283 m .59038 .26064 L .59346 .25945 L F
.70484 .25921 m .70652 .25613 L .70798 .25806 L 0 .03 .13 r
F
.70484 .25921 m .70338 .25725 L .70652 .25613 L F
.77908 .25773 m .78087 .25453 L .78226 .25662 L 0 .027 .126 r
F
.77908 .25773 m .77769 .25566 L .78087 .25453 L F
.1416 .25646 m .14239 .2534 L .14443 .25541 L 0 .025 .123 r
F
.1416 .25646 m .13956 .25447 L .14239 .2534 L F
.29945 .25819 m .30049 .25503 L .30236 .2572 L 0 .028 .128 r
F
.29945 .25819 m .29758 .25601 L .30049 .25503 L F
.63061 .26077 m .63216 .25756 L .63371 .25968 L 0 .033 .134 r
F
.63061 .26077 m .62906 .25868 L .63216 .25756 L F
.71257 .25884 m .71426 .25576 L .71571 .25769 L 0 .029 .129 r
F
.71257 .25884 m .71112 .25691 L .71426 .25576 L F
.25612 .25799 m .2571 .25485 L .25902 .2569 L 0 .028 .127 r
F
.25612 .25799 m .2542 .25595 L .2571 .25485 L F
.36292 .25994 m .36406 .25684 L .36587 .25882 L 0 .032 .132 r
F
.36292 .25994 m .3611 .25794 L .36406 .25684 L F
.62288 .26123 m .62442 .25784 L .62597 .25992 L 0 .034 .135 r
F
.62288 .26123 m .62133 .25916 L .62442 .25784 L F
.7203 .25846 m .722 .2553 L .72344 .25723 L 0 .029 .128 r
F
.7203 .25846 m .71886 .25653 L .722 .2553 L F
.5997 .2626 m .60121 .25933 L .60278 .26149 L 0 .037 .139 r
F
.5997 .2626 m .59812 .2604 L .60121 .25933 L F
.18491 .25682 m .18579 .25357 L .18777 .25568 L 0 .025 .124 r
F
.18491 .25682 m .18293 .25471 L .18579 .25357 L F
.46198 .26241 m .46328 .25921 L .46499 .26137 L 0 .037 .138 r
F
.46198 .26241 m .46027 .26025 L .46328 .25921 L F
.42638 .26178 m .42763 .2585 L .42937 .26061 L 0 .035 .137 r
F
.42638 .26178 m .42464 .25963 L .42763 .2585 L F
.10598 .256 m .10672 .25289 L .10879 .25489 L 0 .024 .122 r
F
.10598 .256 m .1039 .25398 L .10672 .25289 L F
.73577 .25775 m .7375 .25462 L .73893 .25672 L 0 .027 .127 r
F
.73577 .25775 m .73433 .25565 L .7375 .25462 L F
.39851 .26077 m .3997 .25787 L .40148 .25977 L 0 .034 .135 r
F
.39851 .26077 m .39673 .25885 L .3997 .25787 L F
.51591 .50837 m .51431 .48735 L .51734 .4864 L .648 .74 0 r
F
.51289 .50284 m .51431 .48735 L .51591 .50837 L .601 .729 0 r
F
.61516 .26186 m .61669 .25842 L .61824 .26048 L 0 .035 .137 r
F
.61516 .26186 m .6136 .25982 L .61669 .25842 L F
.49758 .26321 m .49894 .26008 L .50061 .26223 L 0 .039 .141 r
F
.49758 .26321 m .49591 .26105 L .49894 .26008 L F
.5641 .26215 m .56556 .25891 L .56716 .26084 L 0 .036 .138 r
F
.5641 .26215 m .56249 .26022 L .56556 .25891 L F
.26382 .25787 m .26482 .25459 L .26673 .25673 L 0 .028 .127 r
F
.26382 .25787 m .26192 .25575 L .26482 .25459 L F
.37063 .2598 m .37179 .25654 L .37359 .25864 L 0 .031 .132 r
F
.37063 .2598 m .36883 .2577 L .37179 .25654 L F
.22822 .25724 m .22915 .25408 L .2311 .25618 L 0 .027 .126 r
F
.22822 .25724 m .22628 .25513 L .22915 .25408 L F
.78684 .25767 m .78864 .25454 L .79003 .25663 L 0 .027 .127 r
F
.78684 .25767 m .78545 .25558 L .78864 .25454 L F
.43411 .26153 m .43536 .25826 L .4371 .26033 L 0 .035 .136 r
F
.43411 .26153 m .43237 .25945 L .43536 .25826 L F
.63835 .26068 m .63991 .25737 L .64145 .25949 L 0 .033 .134 r
F
.63835 .26068 m .63681 .25859 L .63991 .25737 L F
.33503 .25918 m .33612 .25608 L .33796 .25822 L 0 .031 .131 r
F
.33503 .25918 m .33319 .25704 L .33612 .25608 L F
.57183 .26175 m .5733 .25876 L .5749 .26074 L 0 .036 .137 r
F
.57183 .26175 m .57023 .2598 L .5733 .25876 L F
.53319 .26393 m .53459 .26058 L .53623 .26282 L 0 .04 .142 r
F
.53319 .26393 m .53154 .26165 L .53459 .26058 L F
.44183 .26115 m .4431 .25803 L .44483 .26007 L 0 .035 .136 r
F
.44183 .26115 m .4401 .25912 L .4431 .25803 L F
.19261 .25666 m .1935 .25344 L .19547 .25556 L 0 .026 .124 r
F
.19261 .25666 m .19063 .25454 L .1935 .25344 L F
.14927 .2565 m .15008 .2534 L .1521 .2555 L 0 .025 .124 r
F
.14927 .2565 m .14725 .2544 L .15008 .2534 L F
.60744 .26251 m .60895 .25912 L .61052 .26121 L 0 .037 .139 r
F
.60744 .26251 m .60587 .26038 L .60895 .25912 L F
.11366 .25588 m .11442 .25276 L .11647 .25484 L 0 .024 .123 r
F
.11366 .25588 m .1116 .25381 L .11442 .25276 L F
.64608 .2604 m .64766 .25704 L .64919 .25921 L 0 .033 .134 r
F
.64608 .2604 m .64455 .25825 L .64766 .25704 L F
.40623 .26063 m .40744 .25753 L .4092 .25954 L 0 .034 .135 r
F
.40623 .26063 m .40445 .25865 L .40744 .25753 L F
.74352 .25769 m .74525 .25443 L .74668 .2565 L 0 .028 .127 r
F
.74352 .25769 m .74209 .2556 L .74525 .25443 L F
.37835 .25962 m .37952 .25634 L .38131 .2585 L 0 .031 .132 r
F
.37835 .25962 m .37656 .25746 L .37952 .25634 L F
.4697 .26241 m .47102 .25889 L .47272 .26118 L 0 .037 .138 r
F
.4697 .26241 m .468 .26013 L .47102 .25889 L F
.55637 .26287 m .55782 .25953 L .55943 .26154 L 0 .038 .14 r
F
.55637 .26287 m .55476 .26086 L .55782 .25953 L F
.30713 .25837 m .30819 .25517 L .31005 .25732 L 0 .029 .129 r
F
.30713 .25837 m .30527 .25621 L .30819 .25517 L F
.54092 .26377 m .54234 .26067 L .54397 .26271 L 0 .041 .143 r
F
.54092 .26377 m .53928 .26175 L .54234 .26067 L F
.75126 .25736 m .75301 .25427 L .75443 .25631 L 0 .027 .127 r
F
.75126 .25736 m .74984 .25531 L .75301 .25427 L F
.7946 .25762 m .7964 .25433 L .79778 .25642 L 0 .028 .127 r
F
.7946 .25762 m .79322 .25552 L .7964 .25433 L F
.27152 .25783 m .27253 .25462 L .27442 .2568 L 0 .028 .128 r
F
.27152 .25783 m .26962 .25567 L .27253 .25462 L F
.23591 .2572 m .23686 .25404 L .23879 .25612 L 0 .027 .126 r
F
.23591 .2572 m .23397 .25512 L .23686 .25404 L F
.65382 .26023 m .65542 .25711 L .65694 .25917 L 0 .033 .134 r
F
.65382 .26023 m .6523 .25816 L .65542 .25711 L F
.2003 .2566 m .20119 .25348 L .20316 .25555 L 0 .026 .125 r
F
.2003 .2566 m .19833 .25452 L .20119 .25348 L F
.44955 .26113 m .45083 .25817 L .45255 .26017 L 0 .035 .137 r
F
.44955 .26113 m .44783 .25912 L .45083 .25817 L F
.80234 .25729 m .80417 .25415 L .80554 .2562 L 0 .027 .127 r
F
.80234 .25729 m .80097 .25522 L .80417 .25415 L F
.47743 .26223 m .47876 .25869 L .48045 .26098 L 0 .037 .138 r
F
.47743 .26223 m .47574 .25994 L .47876 .25869 L F
.15695 .25647 m .15779 .25321 L .1598 .25531 L 0 .026 .124 r
F
.15695 .25647 m .15494 .25437 L .15779 .25321 L F
.34272 .25928 m .34385 .25597 L .34567 .25814 L 0 .031 .131 r
F
.34272 .25928 m .3409 .25713 L .34385 .25597 L F
.50531 .26337 m .50667 .26005 L .50834 .26217 L 0 .04 .142 r
F
.50531 .26337 m .50364 .26125 L .50667 .26005 L F
.41394 .26058 m .41517 .25741 L .41692 .25956 L 0 .034 .135 r
F
.41394 .26058 m .41218 .25846 L .41517 .25741 L F
.54865 .26359 m .55008 .26017 L .5517 .26222 L 0 .04 .142 r
F
.54865 .26359 m .54702 .26154 L .55008 .26017 L F
.12134 .25588 m .1221 .25276 L .12415 .25484 L 0 .025 .123 r
F
.12134 .25588 m .11929 .2538 L .1221 .25276 L F
.57957 .26188 m .58105 .25855 L .58264 .26075 L 0 .036 .138 r
F
.57957 .26188 m .57797 .25968 L .58105 .25855 L F
.31484 .25824 m .31591 .25514 L .31777 .25713 L 0 .029 .129 r
F
.31484 .25824 m .31298 .25623 L .31591 .25514 L F
.48516 .2619 m .48649 .25876 L .48818 .26091 L 0 .037 .138 r
F
.48516 .2619 m .48347 .25975 L .48649 .25876 L F
.24362 .25699 m .24457 .25398 L .2465 .25595 L 0 .027 .126 r
F
.24362 .25699 m .24168 .25504 L .24457 .25398 L F
.66156 .26001 m .66318 .25701 L .66468 .25893 L 0 .033 .134 r
F
.66156 .26001 m .66005 .25809 L .66318 .25701 L F
.20801 .25639 m .20891 .25326 L .21088 .25523 L 0 .026 .125 r
F
.20801 .25639 m .20603 .25442 L .20891 .25326 L F
.51304 .26305 m .51442 .25967 L .51607 .2618 L 0 .039 .141 r
F
.51304 .26305 m .51138 .26092 L .51442 .25967 L F
.16466 .25619 m .16549 .25309 L .16751 .25513 L 0 .026 .124 r
F
.16466 .25619 m .16265 .25417 L .16549 .25309 L F
.75902 .25729 m .76078 .25419 L .76219 .25621 L 0 .028 .127 r
F
.75902 .25729 m .75761 .25526 L .76078 .25419 L F
.67702 .25923 m .67866 .25612 L .68015 .25805 L 0 .032 .132 r
F
.67702 .25923 m .67554 .25731 L .67866 .25612 L F
.27922 .25774 m .28024 .25459 L .28213 .25661 L 0 .028 .128 r
F
.27922 .25774 m .27732 .25573 L .28024 .25459 L F
.21573 .25606 m .21663 .25308 L .21859 .25507 L 0 .026 .124 r
F
.21573 .25606 m .21376 .25409 L .21663 .25308 L F
.8101 .25714 m .81194 .25403 L .81329 .25604 L 0 .027 .127 r
F
.8101 .25714 m .80874 .25514 L .81194 .25403 L F
.38605 .25973 m .38723 .25664 L .38901 .25881 L 0 .033 .133 r
F
.38605 .25973 m .38427 .25757 L .38723 .25664 L F
.32256 .25801 m .32363 .25507 L .32549 .25701 L 0 .029 .129 r
F
.32256 .25801 m .3207 .2561 L .32363 .25507 L F
.35044 .25911 m .35157 .25592 L .35338 .25806 L 0 .031 .132 r
F
.35044 .25911 m .34862 .25701 L .35157 .25592 L F
.6693 .25977 m .67092 .25661 L .67242 .25855 L 0 .033 .133 r
F
.6693 .25977 m .6678 .25785 L .67092 .25661 L F
.28694 .25744 m .28797 .25429 L .28986 .25628 L 0 .028 .128 r
F
.28694 .25744 m .28505 .25546 L .28797 .25429 L F
.81783 .2568 m .81968 .25354 L .82103 .25557 L 0 .027 .126 r
F
.81783 .2568 m .81648 .25479 L .81968 .25354 L F
.52077 .26281 m .52216 .25921 L .52381 .26152 L 0 .038 .14 r
F
.52077 .26281 m .51912 .26051 L .52216 .25921 L F
.68476 .25896 m .68642 .25599 L .6879 .25795 L 0 .031 .132 r
F
.68476 .25896 m .68328 .25702 L .68642 .25599 L F
.76676 .25706 m .76854 .25393 L .76993 .2559 L 0 .027 .127 r
F
.76676 .25706 m .76536 .25507 L .76854 .25393 L F
.12902 .25578 m .12979 .25275 L .13184 .25473 L 0 .025 .124 r
F
.12902 .25578 m .12697 .2538 L .12979 .25275 L F
.09341 .25514 m .09411 .25214 L .09621 .25412 L 0 .024 .122 r
F
.09341 .25514 m .09132 .25317 L .09411 .25214 L F
.58731 .26182 m .58879 .25848 L .59038 .26064 L 0 .037 .138 r
F
.58731 .26182 m .58572 .25962 L .58879 .25848 L F
.82557 .25647 m .82744 .25334 L .82879 .25541 L 0 .026 .125 r
F
.82557 .25647 m .82423 .25443 L .82744 .25334 L F
.45727 .26121 m .45856 .25826 L .46027 .26025 L 0 .036 .138 r
F
.45727 .26121 m .45555 .25921 L .45856 .25826 L F
.17236 .25607 m .1732 .25296 L .17521 .25497 L 0 .026 .125 r
F
.17236 .25607 m .17035 .25407 L .1732 .25296 L F
.29466 .25714 m .2957 .25397 L .29758 .25601 L 0 .028 .127 r
F
.29466 .25714 m .29278 .25511 L .2957 .25397 L F
.25132 .25693 m .25227 .25395 L .2542 .25595 L F
.25132 .25693 m .24939 .25495 L .25227 .25395 L F
.77451 .25679 m .77629 .25361 L .77769 .25566 L 0 .027 .126 r
F
.77451 .25679 m .77311 .25475 L .77629 .25361 L F
.35815 .259 m .35929 .25593 L .3611 .25794 L 0 .032 .132 r
F
.35815 .259 m .35633 .257 L .35929 .25593 L F
.13673 .25557 m .13751 .25249 L .13956 .25447 L 0 .025 .124 r
F
.13673 .25557 m .13468 .25361 L .13751 .25249 L F
.69251 .25879 m .69416 .25557 L .69564 .25758 L 0 .031 .131 r
F
.69251 .25879 m .69103 .2568 L .69416 .25557 L F
.42165 .26073 m .42289 .25746 L .42464 .25963 L 0 .035 .136 r
F
.42165 .26073 m .4199 .25854 L .42289 .25746 L F
.70024 .25837 m .70191 .25529 L .70338 .25725 L 0 .03 .131 r
F
.70024 .25837 m .69877 .25637 L .70191 .25529 L F
.59504 .2616 m .59654 .25829 L .59812 .2604 L 0 .037 .138 r
F
.59504 .2616 m .59346 .25945 L .59654 .25829 L F
.49288 .26204 m .49423 .25892 L .49591 .26105 L 0 .038 .14 r
F
.49288 .26204 m .4912 .25991 L .49423 .25892 L F
.73117 .25668 m .7329 .25373 L .73433 .25565 L 0 .027 .127 r
F
.73117 .25668 m .72974 .25477 L .7329 .25373 L F
.18007 .25584 m .18093 .25271 L .18293 .25471 L 0 .025 .124 r
F
.18007 .25584 m .17807 .25384 L .18093 .25271 L F
.33026 .25799 m .33134 .25506 L .33319 .25704 L 0 .03 .13 r
F
.33026 .25799 m .32841 .25602 L .33134 .25506 L F
.62597 .25992 m .62752 .25658 L .62906 .25868 L 0 .033 .134 r
F
.62597 .25992 m .62442 .25784 L .62752 .25658 L F
.5285 .26273 m .5299 .25933 L .53154 .26165 L 0 .039 .141 r
F
.5285 .26273 m .52685 .26037 L .5299 .25933 L F
.70798 .25806 m .70967 .255 L .71112 .25691 L 0 .03 .13 r
F
.70798 .25806 m .70652 .25613 L .70967 .255 L F
.22341 .25615 m .22433 .25305 L .22628 .25513 L 0 .026 .125 r
F
.22341 .25615 m .22146 .25407 L .22433 .25305 L F
.10109 .25507 m .10182 .25201 L .1039 .25398 L 0 .024 .123 r
F
.10109 .25507 m .09901 .25309 L .10182 .25201 L F
.72344 .25723 m .72515 .25406 L .72659 .25598 L 0 .028 .128 r
F
.72344 .25723 m .722 .2553 L .72515 .25406 L F
.39376 .25982 m .39494 .25692 L .39673 .25885 L 0 .034 .135 r
F
.39376 .25982 m .39198 .25787 L .39494 .25692 L F
.71571 .25769 m .71741 .25461 L .71886 .25653 L 0 .029 .129 r
F
.71571 .25769 m .71426 .25576 L .71741 .25461 L F
.78226 .25662 m .78406 .25348 L .78545 .25558 L 0 .027 .126 r
F
.78226 .25662 m .78087 .25453 L .78406 .25348 L F
.61824 .26048 m .61978 .25711 L .62133 .25916 L 0 .034 .136 r
F
.61824 .26048 m .61669 .25842 L .61978 .25711 L F
.36587 .25882 m .36702 .25574 L .36883 .2577 L 0 .032 .132 r
F
.36587 .25882 m .36406 .25684 L .36702 .25574 L F
.63371 .25968 m .63527 .25644 L .63681 .25859 L 0 .033 .134 r
F
.63371 .25968 m .63216 .25756 L .63527 .25644 L F
.25902 .2569 m .26 .25368 L .26192 .25575 L 0 .028 .127 r
F
.25902 .2569 m .2571 .25485 L .26 .25368 L F
.14443 .25541 m .14522 .25237 L .14725 .2544 L 0 .025 .124 r
F
.14443 .25541 m .14239 .2534 L .14522 .25237 L F
.42937 .26061 m .43063 .25735 L .43237 .25945 L 0 .035 .136 r
F
.42937 .26061 m .42763 .2585 L .43063 .25735 L F
.18777 .25568 m .18865 .25243 L .19063 .25454 L 0 .025 .124 r
F
.18777 .25568 m .18579 .25357 L .18865 .25243 L F
.56716 .26084 m .56863 .25784 L .57023 .2598 L 0 .036 .137 r
F
.56716 .26084 m .56556 .25891 L .56863 .25784 L F
.30236 .2572 m .30341 .25404 L .30527 .25621 L 0 .028 .128 r
F
.30236 .2572 m .30049 .25503 L .30341 .25404 L F
.60278 .26149 m .6043 .25825 L .60587 .26038 L 0 .037 .139 r
F
.60278 .26149 m .60121 .25933 L .6043 .25825 L F
.51671 .53346 m .51804 .55597 L .51972 .54982 L .868 .496 0 r
F
.51671 .53346 m .51503 .5389 L .51804 .55597 L F
.10879 .25489 m .10953 .2518 L .1116 .25381 L 0 .024 .122 r
F
.10879 .25489 m .10672 .25289 L .10953 .2518 L F
.46499 .26137 m .4663 .25796 L .468 .26013 L 0 .037 .138 r
F
.46499 .26137 m .46328 .25921 L .4663 .25796 L F
.4371 .26033 m .43836 .25708 L .4401 .25912 L 0 .035 .136 r
F
.4371 .26033 m .43536 .25826 L .43836 .25708 L F
.64145 .25949 m .64302 .2561 L .64455 .25825 L 0 .033 .134 r
F
.64145 .25949 m .63991 .25737 L .64302 .2561 L F
.51591 .50837 m .51734 .4864 L .51896 .50743 L .648 .74 0 r
F
.37359 .25864 m .37476 .25537 L .37656 .25746 L 0 .031 .132 r
F
.37359 .25864 m .37179 .25654 L .37476 .25537 L F
.61052 .26121 m .61204 .25775 L .6136 .25982 L 0 .036 .138 r
F
.61052 .26121 m .60895 .25912 L .61204 .25775 L F
.73893 .25672 m .74066 .25352 L .74209 .2556 L 0 .028 .127 r
F
.73893 .25672 m .7375 .25462 L .74066 .25352 L F
.26673 .25673 m .26773 .25351 L .26962 .25567 L F
.26673 .25673 m .26482 .25459 L .26773 .25351 L F
.40148 .25977 m .40268 .25673 L .40445 .25865 L 0 .034 .135 r
F
.40148 .25977 m .3997 .25787 L .40268 .25673 L F
.53623 .26282 m .53765 .25951 L .53928 .26175 L 0 .04 .142 r
F
.53623 .26282 m .53459 .26058 L .53765 .25951 L F
.55943 .26154 m .56088 .25822 L .56249 .26022 L 0 .037 .139 r
F
.55943 .26154 m .55782 .25953 L .56088 .25822 L F
.2311 .25618 m .23203 .25303 L .23397 .25512 L 0 .027 .126 r
F
.2311 .25618 m .22915 .25408 L .23203 .25303 L F
.79003 .25663 m .79184 .25343 L .79322 .25552 L 0 .028 .127 r
F
.79003 .25663 m .78864 .25454 L .79184 .25343 L F
.19547 .25556 m .19635 .25241 L .19833 .25452 L 0 .026 .124 r
F
.19547 .25556 m .1935 .25344 L .19635 .25241 L F
.44483 .26007 m .4461 .25707 L .44783 .25912 L 0 .035 .136 r
F
.44483 .26007 m .4431 .25803 L .4461 .25707 L F
.64919 .25921 m .65077 .25599 L .6523 .25816 L 0 .033 .133 r
F
.64919 .25921 m .64766 .25704 L .65077 .25599 L F
.50061 .26223 m .50197 .25912 L .50364 .26125 L 0 .039 .141 r
F
.50061 .26223 m .49894 .26008 L .50197 .25912 L F
.5749 .26074 m .57637 .25765 L .57797 .25968 L 0 .036 .138 r
F
.5749 .26074 m .5733 .25876 L .57637 .25765 L F
.47272 .26118 m .47404 .25765 L .47574 .25994 L F
.47272 .26118 m .47102 .25889 L .47404 .25765 L F
.74668 .2565 m .74842 .25326 L .74984 .25531 L 0 .027 .127 r
F
.74668 .2565 m .74525 .25443 L .74842 .25326 L F
.33796 .25822 m .33907 .25498 L .3409 .25713 L 0 .031 .131 r
F
.33796 .25822 m .33612 .25608 L .33907 .25498 L F
.4092 .25954 m .41042 .25642 L .41218 .25846 L 0 .034 .135 r
F
.4092 .25954 m .40744 .25753 L .41042 .25642 L F
.11647 .25484 m .11723 .25171 L .11929 .2538 L 0 .024 .123 r
F
.11647 .25484 m .11442 .25276 L .11723 .25171 L F
.38131 .2585 m .38248 .25539 L .38427 .25757 L 0 .032 .132 r
F
.38131 .2585 m .37952 .25634 L .38248 .25539 L F
.1521 .2555 m .15292 .25227 L .15494 .25437 L 0 .026 .124 r
F
.1521 .2555 m .15008 .2534 L .15292 .25227 L F
.79778 .25642 m .79959 .25314 L .80097 .25522 L 0 .027 .127 r
F
.79778 .25642 m .7964 .25433 L .79959 .25314 L F
.5517 .26222 m .55314 .25879 L .55476 .26086 L 0 .039 .141 r
F
.5517 .26222 m .55008 .26017 L .55314 .25879 L F
.31005 .25732 m .31112 .2541 L .31298 .25623 L 0 .029 .129 r
F
.31005 .25732 m .30819 .25517 L .31112 .2541 L F
.48045 .26098 m .48178 .25745 L .48347 .25975 L 0 .036 .138 r
F
.48045 .26098 m .47876 .25869 L .48178 .25745 L F
.54397 .26271 m .54539 .2595 L .54702 .26154 L 0 .041 .143 r
F
.54397 .26271 m .54234 .26067 L .54539 .2595 L F
.75443 .25631 m .75619 .25324 L .75761 .25526 L 0 .027 .127 r
F
.75443 .25631 m .75301 .25427 L .75619 .25324 L F
.23879 .25612 m .23975 .25294 L .24168 .25504 L 0 .027 .126 r
F
.23879 .25612 m .23686 .25404 L .23975 .25294 L F
.27442 .2568 m .27543 .25354 L .27732 .25573 L 0 .028 .128 r
F
.27442 .2568 m .27253 .25462 L .27543 .25354 L F
.50834 .26217 m .50971 .25879 L .51138 .26092 L 0 .039 .141 r
F
.50834 .26217 m .50667 .26005 L .50971 .25879 L F
.65694 .25917 m .65854 .25603 L .66005 .25809 L 0 .033 .134 r
F
.65694 .25917 m .65542 .25711 L .65854 .25603 L F
.1598 .25531 m .16064 .25207 L .16265 .25417 L 0 .025 .124 r
F
.1598 .25531 m .15779 .25321 L .16064 .25207 L F
.20316 .25555 m .20406 .25236 L .20603 .25442 L 0 .026 .125 r
F
.20316 .25555 m .20119 .25348 L .20406 .25236 L F
.80554 .2562 m .80737 .2531 L .80874 .25514 L 0 .027 .127 r
F
.80554 .2562 m .80417 .25415 L .80737 .2531 L F
.34567 .25814 m .3468 .25481 L .34862 .25701 L 0 .031 .131 r
F
.34567 .25814 m .34385 .25597 L .3468 .25481 L F
.51607 .2618 m .51746 .25838 L .51912 .26051 L 0 .038 .14 r
F
.51607 .2618 m .51442 .25967 L .51746 .25838 L F
.58264 .26075 m .58412 .25741 L .58572 .25962 L 0 .036 .138 r
F
.58264 .26075 m .58105 .25855 L .58412 .25741 L F
.31777 .25713 m .31884 .25409 L .3207 .2561 L 0 .029 .129 r
F
.31777 .25713 m .31591 .25514 L .31884 .25409 L F
.21088 .25523 m .21179 .25212 L .21376 .25409 L 0 .026 .124 r
F
.21088 .25523 m .20891 .25326 L .21179 .25212 L F
.45255 .26017 m .45383 .25722 L .45555 .25921 L 0 .036 .137 r
F
.45255 .26017 m .45083 .25817 L .45383 .25722 L F
.68015 .25805 m .68179 .25507 L .68328 .25702 L 0 .031 .132 r
F
.68015 .25805 m .67866 .25612 L .68179 .25507 L F
.12415 .25484 m .12492 .25173 L .12697 .2538 L 0 .025 .124 r
F
.12415 .25484 m .1221 .25276 L .12492 .25173 L F
.41692 .25956 m .41815 .25635 L .4199 .25854 L 0 .034 .135 r
F
.41692 .25956 m .41517 .25741 L .41815 .25635 L F
.66468 .25893 m .6663 .25592 L .6678 .25785 L 0 .033 .134 r
F
.66468 .25893 m .66318 .25701 L .6663 .25592 L F
.2465 .25595 m .24745 .25296 L .24939 .25495 L 0 .027 .127 r
F
.2465 .25595 m .24457 .25398 L .24745 .25296 L F
.52381 .26152 m .5252 .25807 L .52685 .26037 L 0 .038 .14 r
F
.52381 .26152 m .52216 .25921 L .5252 .25807 L F
.28213 .25661 m .28315 .25346 L .28505 .25546 L 0 .028 .128 r
F
.28213 .25661 m .28024 .25459 L .28315 .25346 L F
.48818 .26091 m .48952 .25777 L .4912 .25991 L 0 .037 .139 r
F
.48818 .26091 m .48649 .25876 L .48952 .25777 L F
.67242 .25855 m .67404 .25535 L .67554 .25731 L 0 .032 .133 r
F
.67242 .25855 m .67092 .25661 L .67404 .25535 L F
.16751 .25513 m .16834 .25201 L .17035 .25407 L 0 .026 .124 r
F
.16751 .25513 m .16549 .25309 L .16834 .25201 L F
.76219 .25621 m .76396 .25307 L .76536 .25507 L 0 .028 .127 r
F
.76219 .25621 m .76078 .25419 L .76396 .25307 L F
.82103 .25557 m .82288 .25238 L .82423 .25443 L 0 .026 .125 r
F
.82103 .25557 m .81968 .25354 L .82288 .25238 L F
.81329 .25604 m .81513 .25278 L .81648 .25479 L 0 .027 .126 r
F
.81329 .25604 m .81194 .25403 L .81513 .25278 L F
.28986 .25628 m .29089 .25311 L .29278 .25511 L 0 .028 .127 r
F
.28986 .25628 m .28797 .25429 L .29089 .25311 L F
.76993 .2559 m .77172 .2528 L .77311 .25475 L 0 .027 .127 r
F
.76993 .2559 m .76854 .25393 L .77172 .2528 L F
.35338 .25806 m .35452 .25484 L .35633 .257 L 0 .031 .132 r
F
.35338 .25806 m .35157 .25592 L .35452 .25484 L F
.59038 .26064 m .59188 .25734 L .59346 .25945 L 0 .037 .138 r
F
.59038 .26064 m .58879 .25848 L .59188 .25734 L F
.21859 .25507 m .2195 .25206 L .22146 .25407 L 0 .026 .125 r
F
.21859 .25507 m .21663 .25308 L .2195 .25206 L F
.32549 .25701 m .32656 .25405 L .32841 .25602 L 0 .03 .13 r
F
.32549 .25701 m .32363 .25507 L .32656 .25405 L F
.29758 .25601 m .29862 .25298 L .30049 .25503 L 0 .028 .127 r
F
.29758 .25601 m .2957 .25397 L .29862 .25298 L F
.13184 .25473 m .13262 .25162 L .13468 .25361 L 0 .025 .124 r
F
.13184 .25473 m .12979 .25275 L .13262 .25162 L F
.38901 .25881 m .3902 .2557 L .39198 .25787 L 0 .033 .134 r
F
.38901 .25881 m .38723 .25664 L .3902 .2557 L F
.6879 .25795 m .68955 .25481 L .69103 .2568 L 0 .031 .132 r
F
.6879 .25795 m .68642 .25599 L .68955 .25481 L F
.17521 .25497 m .17606 .25183 L .17807 .25384 L 0 .026 .124 r
F
.17521 .25497 m .1732 .25296 L .17606 .25183 L F
.09621 .25412 m .09692 .25111 L .09901 .25309 L 0 .024 .123 r
F
.09621 .25412 m .09411 .25214 L .09692 .25111 L F
.82879 .25541 m .83066 .25225 L .832 .25434 L 0 .026 .125 r
F
.82879 .25541 m .82744 .25334 L .83066 .25225 L F
.69564 .25758 m .6973 .25435 L .69877 .25637 L 0 .031 .131 r
F
.69564 .25758 m .69416 .25557 L .6973 .25435 L F
.77769 .25566 m .77947 .25248 L .78087 .25453 L 0 .027 .126 r
F
.77769 .25566 m .77629 .25361 L .77947 .25248 L F
.62906 .25868 m .63062 .25543 L .63216 .25756 L 0 .033 .134 r
F
.62906 .25868 m .62752 .25658 L .63062 .25543 L F
.59812 .2604 m .59963 .25726 L .60121 .25933 L 0 .037 .138 r
F
.59812 .2604 m .59654 .25829 L .59963 .25726 L F
.62133 .25916 m .62287 .25579 L .62442 .25784 L 0 .034 .135 r
F
.62133 .25916 m .61978 .25711 L .62287 .25579 L F
.2542 .25595 m .25517 .25284 L .2571 .25485 L 0 .028 .127 r
F
.2542 .25595 m .25227 .25395 L .25517 .25284 L F
.46027 .26025 m .46157 .25722 L .46328 .25921 L 0 .037 .138 r
F
.46027 .26025 m .45856 .25826 L .46157 .25722 L F
.70338 .25725 m .70506 .2542 L .70652 .25613 L 0 .03 .13 r
F
.70338 .25725 m .70191 .25529 L .70506 .2542 L F
.13956 .25447 m .14034 .2514 L .14239 .2534 L 0 .025 .124 r
F
.13956 .25447 m .13751 .25249 L .14034 .2514 L F
.72659 .25598 m .7283 .25286 L .72974 .25477 L 0 .028 .127 r
F
.72659 .25598 m .72515 .25406 L .7283 .25286 L F
.42464 .25963 m .42588 .25634 L .42763 .2585 L 0 .035 .136 r
F
.42464 .25963 m .42289 .25746 L .42588 .25634 L F
.18293 .25471 m .18379 .25155 L .18579 .25357 L 0 .025 .124 r
F
.18293 .25471 m .18093 .25271 L .18379 .25155 L F
.3611 .25794 m .36224 .25486 L .36406 .25684 L 0 .032 .132 r
F
.3611 .25794 m .35929 .25593 L .36224 .25486 L F
.71112 .25691 m .71281 .25384 L .71426 .25576 L 0 .03 .13 r
F
.71112 .25691 m .70967 .255 L .71281 .25384 L F
.53154 .26165 m .53295 .25828 L .53459 .26058 L 0 .039 .141 r
F
.53154 .26165 m .5299 .25933 L .53295 .25828 L F
.73433 .25565 m .73607 .2527 L .7375 .25462 L 0 .027 .127 r
F
.73433 .25565 m .7329 .25373 L .73607 .2527 L F
.71886 .25653 m .72056 .25338 L .722 .2553 L 0 .029 .129 r
F
.71886 .25653 m .71741 .25461 L .72056 .25338 L F
.49591 .26105 m .49726 .25795 L .49894 .26008 L 0 .038 .14 r
F
.49591 .26105 m .49423 .25892 L .49726 .25795 L F
.1039 .25398 m .10463 .25091 L .10672 .25289 L 0 .024 .123 r
F
.1039 .25398 m .10182 .25201 L .10463 .25091 L F
.6136 .25982 m .61513 .25638 L .61669 .25842 L 0 .035 .136 r
F
.6136 .25982 m .61204 .25775 L .61513 .25638 L F
.26192 .25575 m .26291 .25251 L .26482 .25459 L 0 .027 .127 r
F
.26192 .25575 m .26 .25368 L .26291 .25251 L F
.33319 .25704 m .33428 .2541 L .33612 .25608 L 0 .03 .131 r
F
.33319 .25704 m .33134 .25506 L .33428 .2541 L F
.36883 .2577 m .36998 .2546 L .37179 .25654 L 0 .031 .132 r
F
.36883 .2577 m .36702 .25574 L .36998 .2546 L F
.22628 .25513 m .22721 .25201 L .22915 .25408 L 0 .026 .125 r
F
.22628 .25513 m .22433 .25305 L .22721 .25201 L F
.78545 .25558 m .78725 .25244 L .78864 .25454 L 0 .027 .127 r
F
.78545 .25558 m .78406 .25348 L .78725 .25244 L F
.43237 .25945 m .43362 .25619 L .43536 .25826 L 0 .035 .136 r
F
.43237 .25945 m .43063 .25735 L .43362 .25619 L F
.63681 .25859 m .63837 .2552 L .63991 .25737 L 0 .033 .134 r
F
.63681 .25859 m .63527 .25644 L .63837 .2552 L F
.19063 .25454 m .19152 .25132 L .1935 .25344 L 0 .025 .124 r
F
.19063 .25454 m .18865 .25243 L .19152 .25132 L F
.468 .26013 m .46932 .25672 L .47102 .25889 L 0 .036 .137 r
F
.468 .26013 m .4663 .25796 L .46932 .25672 L F
.39673 .25885 m .39791 .25597 L .3997 .25787 L 0 .034 .135 r
F
.39673 .25885 m .39494 .25692 L .39791 .25597 L F
.60587 .26038 m .60739 .25702 L .60895 .25912 L 0 .037 .138 r
F
.60587 .26038 m .6043 .25825 L .60739 .25702 L F
.64455 .25825 m .64613 .25486 L .64766 .25704 L 0 .032 .133 r
F
.64455 .25825 m .64302 .2561 L .64613 .25486 L F
.4401 .25912 m .44137 .25599 L .4431 .25803 L 0 .034 .136 r
F
.4401 .25912 m .43836 .25708 L .44137 .25599 L F
.14725 .2544 m .14805 .25135 L .15008 .2534 L 0 .025 .124 r
F
.14725 .2544 m .14522 .25237 L .14805 .25135 L F
.56249 .26022 m .56395 .25692 L .56556 .25891 L 0 .037 .138 r
F
.56249 .26022 m .56088 .25822 L .56395 .25692 L F
.57023 .2598 m .5717 .25676 L .5733 .25876 L 0 .036 .138 r
F
.57023 .2598 m .56863 .25784 L .5717 .25676 L F
.1116 .25381 m .11235 .25073 L .11442 .25276 L 0 .024 .123 r
F
.1116 .25381 m .10953 .2518 L .11235 .25073 L F
.37656 .25746 m .37773 .25424 L .37952 .25634 L 0 .031 .131 r
F
.37656 .25746 m .37476 .25537 L .37773 .25424 L F
.30527 .25621 m .30633 .25302 L .30819 .25517 L 0 .029 .128 r
F
.30527 .25621 m .30341 .25404 L .30633 .25302 L F
.74209 .2556 m .74382 .25237 L .74525 .25443 L 0 .027 .127 r
F
.74209 .2556 m .74066 .25352 L .74382 .25237 L F
.47574 .25994 m .47706 .25639 L .47876 .25869 L 0 .036 .137 r
F
.47574 .25994 m .47404 .25765 L .47706 .25639 L F
.40445 .25865 m .40566 .25558 L .40744 .25753 L 0 .034 .135 r
F
.40445 .25865 m .40268 .25673 L .40566 .25558 L F
.26962 .25567 m .27063 .25243 L .27253 .25462 L 0 .028 .127 r
F
.26962 .25567 m .26773 .25351 L .27063 .25243 L F
.55476 .26086 m .5562 .25746 L .55782 .25953 L 0 .038 .14 r
F
.55476 .26086 m .55314 .25879 L .5562 .25746 L F
.53928 .26175 m .5407 .25845 L .54234 .26067 L 0 .04 .142 r
F
.53928 .26175 m .53765 .25951 L .5407 .25845 L F
.74984 .25531 m .75159 .25224 L .75301 .25427 L 0 .027 .127 r
F
.74984 .25531 m .74842 .25326 L .75159 .25224 L F
.79322 .25552 m .79502 .25225 L .7964 .25433 L F
.79322 .25552 m .79184 .25343 L .79502 .25225 L F
.23397 .25512 m .23492 .25194 L .23686 .25404 L 0 .027 .126 r
F
.23397 .25512 m .23203 .25303 L .23492 .25194 L F
.6523 .25816 m .65389 .25493 L .65542 .25711 L 0 .033 .134 r
F
.6523 .25816 m .65077 .25599 L .65389 .25493 L F
.19833 .25452 m .19921 .25137 L .20119 .25348 L 0 .026 .125 r
F
.19833 .25452 m .19635 .25241 L .19921 .25137 L F
.57797 .25968 m .57945 .25647 L .58105 .25855 L 0 .036 .137 r
F
.57797 .25968 m .57637 .25765 L .57945 .25647 L F
.3409 .25713 m .34202 .2538 L .34385 .25597 L 0 .031 .131 r
F
.3409 .25713 m .33907 .25498 L .34202 .2538 L F
.80097 .25522 m .8028 .25209 L .80417 .25415 L 0 .027 .126 r
F
.80097 .25522 m .79959 .25314 L .8028 .25209 L F
.15494 .25437 m .15577 .25111 L .15779 .25321 L 0 .025 .124 r
F
.15494 .25437 m .15292 .25227 L .15577 .25111 L F
.50364 .26125 m .50501 .25791 L .50667 .26005 L 0 .039 .141 r
F
.50364 .26125 m .50197 .25912 L .50501 .25791 L F
.48347 .25975 m .48481 .25646 L .48649 .25876 L 0 .036 .138 r
F
.48347 .25975 m .48178 .25745 L .48481 .25646 L F
.41218 .25846 m .4134 .25533 L .41517 .25741 L 0 .034 .135 r
F
.41218 .25846 m .41042 .25642 L .4134 .25533 L F
.44783 .25912 m .4491 .2561 L .45083 .25817 L 0 .035 .137 r
F
.44783 .25912 m .4461 .25707 L .4491 .2561 L F
.11929 .2538 m .12005 .25068 L .1221 .25276 L 0 .025 .123 r
F
.11929 .2538 m .11723 .25171 L .12005 .25068 L F
.54702 .26154 m .54845 .25811 L .55008 .26017 L 0 .04 .142 r
F
.54702 .26154 m .54539 .2595 L .54845 .25811 L F
.51138 .26092 m .51275 .25753 L .51442 .25967 L 0 .039 .14 r
F
.51138 .26092 m .50971 .25879 L .51275 .25753 L F
.51912 .26051 m .5205 .25709 L .52216 .25921 L 0 .038 .139 r
F
.51912 .26051 m .51746 .25838 L .5205 .25709 L F
.31298 .25623 m .31405 .25303 L .31591 .25514 L 0 .029 .129 r
F
.31298 .25623 m .31112 .2541 L .31405 .25303 L F
.53667 .53909 m .53806 .52693 L .53967 .52153 L .84 .582 0 r
F
.38427 .25757 m .38545 .25444 L .38723 .25664 L 0 .032 .133 r
F
.38427 .25757 m .38248 .25539 L .38545 .25444 L F
.53523 .53231 m .53363 .54786 L .53667 .53909 L .84 .582 0 r
F
.53219 .54041 m .53363 .54786 L .53523 .53231 L .868 .495 0 r
F
.16265 .25417 m .16349 .25098 L .16549 .25309 L 0 .025 .124 r
F
.16265 .25417 m .16064 .25207 L .16349 .25098 L F
.24168 .25504 m .24264 .25187 L .24457 .25398 L 0 .027 .126 r
F
.24168 .25504 m .23975 .25294 L .24264 .25187 L F
.75761 .25526 m .75937 .25219 L .76078 .25419 L 0 .028 .127 r
F
.75761 .25526 m .75619 .25324 L .75937 .25219 L F
.20603 .25442 m .20694 .25122 L .20891 .25326 L 0 .026 .125 r
F
.20603 .25442 m .20406 .25236 L .20694 .25122 L F
.34862 .25701 m .34975 .2537 L .35157 .25592 L 0 .031 .131 r
F
.34862 .25701 m .3468 .25481 L .34975 .2537 L F
.27732 .25573 m .27835 .25243 L .28024 .25459 L 0 .028 .128 r
F
.27732 .25573 m .27543 .25354 L .27835 .25243 L F
.66005 .25809 m .66166 .25494 L .66318 .25701 L 0 .033 .134 r
F
.66005 .25809 m .65854 .25603 L .66166 .25494 L F
.58572 .25962 m .58721 .25632 L .58879 .25848 L 0 .036 .138 r
F
.58572 .25962 m .58412 .25741 L .58721 .25632 L F
.80874 .25514 m .81058 .252 L .81194 .25403 L 0 .027 .127 r
F
.80874 .25514 m .80737 .2531 L .81058 .252 L F
.67554 .25731 m .67717 .25414 L .67866 .25612 L 0 .032 .132 r
F
.67554 .25731 m .67404 .25535 L .67717 .25414 L F
.21376 .25409 m .21466 .25108 L .21663 .25308 L 0 .026 .125 r
F
.21376 .25409 m .21179 .25212 L .21466 .25108 L F
.81648 .25479 m .81833 .25153 L .81968 .25354 L 0 .027 .126 r
F
.81648 .25479 m .81513 .25278 L .81833 .25153 L F
.52685 .26037 m .52825 .25705 L .5299 .25933 L 0 .038 .14 r
F
.52685 .26037 m .5252 .25807 L .52825 .25705 L F
.3207 .2561 m .32177 .25303 L .32363 .25507 L 0 .03 .13 r
F
.3207 .2561 m .31884 .25409 L .32177 .25303 L F
.28505 .25546 m .28607 .25228 L .28797 .25429 L 0 .028 .128 r
F
.28505 .25546 m .28315 .25346 L .28607 .25228 L F
.6678 .25785 m .66942 .25467 L .67092 .25661 L 0 .033 .134 r
F
.6678 .25785 m .6663 .25592 L .66942 .25467 L F
.76536 .25507 m .76714 .25195 L .76854 .25393 L 0 .027 .127 r
F
.76536 .25507 m .76396 .25307 L .76714 .25195 L F
.82423 .25443 m .82609 .25127 L .82744 .25334 L 0 .026 .125 r
F
.82423 .25443 m .82288 .25238 L .82609 .25127 L F
.12697 .2538 m .12774 .25069 L .12979 .25275 L 0 .025 .124 r
F
.12697 .2538 m .12492 .25173 L .12774 .25069 L F
.68328 .25702 m .68493 .25402 L .68642 .25599 L 0 .032 .132 r
F
.68328 .25702 m .68179 .25507 L .68493 .25402 L F
.4199 .25854 m .42114 .25527 L .42289 .25746 L 0 .034 .135 r
F
.4199 .25854 m .41815 .25635 L .42114 .25527 L F
.29278 .25511 m .29382 .25196 L .2957 .25397 L 0 .028 .127 r
F
.29278 .25511 m .29089 .25311 L .29382 .25196 L F
.45555 .25921 m .45684 .25626 L .45856 .25826 L 0 .036 .138 r
F
.45555 .25921 m .45383 .25722 L .45684 .25626 L F
.17035 .25407 m .1712 .25091 L .1732 .25296 L 0 .026 .124 r
F
.17035 .25407 m .16834 .25201 L .1712 .25091 L F
.59346 .25945 m .59496 .25623 L .59654 .25829 L 0 .036 .138 r
F
.59346 .25945 m .59188 .25734 L .59496 .25623 L F
.24939 .25495 m .25034 .25194 L .25227 .25395 L 0 .028 .127 r
F
.24939 .25495 m .24745 .25296 L .25034 .25194 L F
.77311 .25475 m .7749 .25167 L .77629 .25361 L 0 .027 .126 r
F
.77311 .25475 m .77172 .2528 L .7749 .25167 L F
.4912 .25991 m .49255 .25679 L .49423 .25892 L 0 .038 .139 r
F
.4912 .25991 m .48952 .25777 L .49255 .25679 L F
.62442 .25784 m .62597 .25453 L .62752 .25658 L 0 .033 .134 r
F
.62442 .25784 m .62287 .25579 L .62597 .25453 L F
.35633 .257 m .35747 .25377 L .35929 .25593 L 0 .031 .132 r
F
.35633 .257 m .35452 .25484 L .35747 .25377 L F
.69103 .2568 m .69268 .25356 L .69416 .25557 L 0 .031 .131 r
F
.69103 .2568 m .68955 .25481 L .69268 .25356 L F
.69877 .25637 m .70044 .25325 L .70191 .25529 L 0 .03 .131 r
F
.69877 .25637 m .6973 .25435 L .70044 .25325 L F
.13468 .25361 m .13546 .25048 L .13751 .25249 L 0 .025 .124 r
F
.13468 .25361 m .13262 .25162 L .13546 .25048 L F
.17807 .25384 m .17892 .25069 L .18093 .25271 L F
.17807 .25384 m .17606 .25183 L .17892 .25069 L F
.22146 .25407 m .22237 .25104 L .22433 .25305 L 0 .026 .125 r
F
.22146 .25407 m .2195 .25206 L .22237 .25104 L F
.32841 .25602 m .32949 .25308 L .33134 .25506 L 0 .03 .13 r
F
.32841 .25602 m .32656 .25405 L .32949 .25308 L F
.78087 .25453 m .78267 .25143 L .78406 .25348 L 0 .027 .126 r
F
.78087 .25453 m .77947 .25248 L .78267 .25143 L F
.63216 .25756 m .63372 .25427 L .63527 .25644 L 0 .033 .133 r
F
.63216 .25756 m .63062 .25543 L .63372 .25427 L F
.72974 .25477 m .73147 .25181 L .7329 .25373 L 0 .028 .127 r
F
.72974 .25477 m .7283 .25286 L .73147 .25181 L F
.61669 .25842 m .61822 .2551 L .61978 .25711 L 0 .034 .135 r
F
.61669 .25842 m .61513 .25638 L .61822 .2551 L F
.09901 .25309 m .09973 .25003 L .10182 .25201 L 0 .024 .123 r
F
.09901 .25309 m .09692 .25111 L .09973 .25003 L F
.30049 .25503 m .30153 .25199 L .30341 .25404 L 0 .028 .128 r
F
.30049 .25503 m .29862 .25298 L .30153 .25199 L F
.60121 .25933 m .60272 .25622 L .6043 .25825 L 0 .037 .138 r
F
.60121 .25933 m .59963 .25726 L .60272 .25622 L F
.70652 .25613 m .70821 .25308 L .70967 .255 L 0 .03 .13 r
F
.70652 .25613 m .70506 .2542 L .70821 .25308 L F
.42763 .2585 m .42888 .25523 L .43063 .25735 L 0 .035 .136 r
F
.42763 .2585 m .42588 .25634 L .42888 .25523 L F
.2571 .25485 m .25808 .25166 L .26 .25368 L 0 .027 .127 r
F
.2571 .25485 m .25517 .25284 L .25808 .25166 L F
.18579 .25357 m .18666 .25039 L .18865 .25243 L 0 .025 .124 r
F
.18579 .25357 m .18379 .25155 L .18666 .25039 L F
.39198 .25787 m .39316 .25475 L .39494 .25692 L 0 .034 .135 r
F
.39198 .25787 m .3902 .2557 L .39316 .25475 L F
.722 .2553 m .72371 .25214 L .72515 .25406 L 0 .028 .128 r
F
.722 .2553 m .72056 .25338 L .72371 .25214 L F
.71426 .25576 m .71596 .25269 L .71741 .25461 L 0 .029 .129 r
F
.71426 .25576 m .71281 .25384 L .71596 .25269 L F
.14239 .2534 m .14318 .25035 L .14522 .25237 L 0 .025 .124 r
F
.14239 .2534 m .14034 .2514 L .14318 .25035 L F
.36406 .25684 m .3652 .25378 L .36702 .25574 L 0 .032 .132 r
F
.36406 .25684 m .36224 .25486 L .3652 .25378 L F
.46328 .25921 m .46459 .25597 L .4663 .25796 L 0 .036 .138 r
F
.46328 .25921 m .46157 .25722 L .46459 .25597 L F
.53459 .26058 m .53601 .25724 L .53765 .25951 L 0 .039 .141 r
F
.53459 .26058 m .53295 .25828 L .53601 .25724 L F
.63991 .25737 m .64148 .25392 L .64302 .2561 L 0 .032 .133 r
F
.63991 .25737 m .63837 .2552 L .64148 .25392 L F
.26482 .25459 m .26582 .25141 L .26773 .25351 L 0 .027 .127 r
F
.26482 .25459 m .26291 .25251 L .26582 .25141 L F
.47102 .25889 m .47234 .25546 L .47404 .25765 L 0 .035 .137 r
F
.47102 .25889 m .46932 .25672 L .47234 .25546 L F
.10672 .25289 m .10745 .24982 L .10953 .2518 L 0 .024 .123 r
F
.10672 .25289 m .10463 .25091 L .10745 .24982 L F
.37179 .25654 m .37295 .25344 L .37476 .25537 L 0 .031 .132 r
F
.37179 .25654 m .36998 .2546 L .37295 .25344 L F
.60895 .25912 m .61047 .25568 L .61204 .25775 L 0 .036 .137 r
F
.60895 .25912 m .60739 .25702 L .61047 .25568 L F
.43536 .25826 m .43663 .25502 L .43836 .25708 L 0 .034 .136 r
F
.43536 .25826 m .43362 .25619 L .43663 .25502 L F
.56556 .25891 m .56702 .25581 L .56863 .25784 L 0 .036 .138 r
F
.56556 .25891 m .56395 .25692 L .56702 .25581 L F
.7375 .25462 m .73923 .25158 L .74066 .25352 L 0 .028 .127 r
F
.7375 .25462 m .73607 .2527 L .73923 .25158 L F
.64766 .25704 m .64924 .25381 L .65077 .25599 L 0 .032 .133 r
F
.64766 .25704 m .64613 .25486 L .64924 .25381 L F
.49894 .26008 m .50029 .25697 L .50197 .25912 L 0 .039 .141 r
F
.49894 .26008 m .49726 .25795 L .50029 .25697 L F
.22915 .25408 m .23009 .25097 L .23203 .25303 L 0 .026 .126 r
F
.22915 .25408 m .22721 .25201 L .23009 .25097 L F
.1935 .25344 m .19438 .2503 L .19635 .25241 L 0 .025 .124 r
F
.1935 .25344 m .19152 .25132 L .19438 .2503 L F
.53312 .52169 m .53447 .49414 L .53613 .50233 L .774 .758 0 r
F
.53312 .52169 m .53145 .51277 L .53447 .49414 L F
.78864 .25454 m .79045 .25133 L .79184 .25343 L 0 .027 .127 r
F
.78864 .25454 m .78725 .25244 L .79045 .25133 L F
.33612 .25608 m .33722 .25298 L .33907 .25498 L 0 .031 .131 r
F
.33612 .25608 m .33428 .2541 L .33722 .25298 L F
.55782 .25953 m .55926 .25615 L .56088 .25822 L 0 .037 .139 r
F
.55782 .25953 m .5562 .25746 L .55926 .25615 L F
.4431 .25803 m .44437 .25499 L .4461 .25707 L 0 .035 .136 r
F
.4431 .25803 m .44137 .25599 L .44437 .25499 L F
.47876 .25869 m .48009 .25515 L .48178 .25745 L F
.47876 .25869 m .47706 .25639 L .48009 .25515 L F
.37952 .25634 m .38069 .25327 L .38248 .25539 L 0 .031 .132 r
F
.37952 .25634 m .37773 .25424 L .38069 .25327 L F
.74525 .25443 m .74699 .25121 L .74842 .25326 L 0 .027 .126 r
F
.74525 .25443 m .74382 .25237 L .74699 .25121 L F
.3997 .25787 m .4009 .2548 L .40268 .25673 L 0 .034 .135 r
F
.3997 .25787 m .39791 .25597 L .4009 .2548 L F
.5733 .25876 m .57477 .25562 L .57637 .25765 L 0 .036 .138 r
F
.5733 .25876 m .5717 .25676 L .57477 .25562 L F
.15008 .2534 m .15089 .25022 L .15292 .25227 L 0 .025 .124 r
F
.15008 .2534 m .14805 .25135 L .15089 .25022 L F
.11442 .25276 m .11516 .24967 L .11723 .25171 L 0 .024 .123 r
F
.11442 .25276 m .11235 .25073 L .11516 .24967 L F
.40744 .25753 m .40865 .25444 L .41042 .25642 L 0 .034 .135 r
F
.40744 .25753 m .40566 .25558 L .40865 .25444 L F
.30819 .25517 m .30926 .25196 L .31112 .2541 L 0 .029 .128 r
F
.30819 .25517 m .30633 .25302 L .30926 .25196 L F
.7964 .25433 m .79822 .25107 L .79959 .25314 L 0 .027 .126 r
F
.7964 .25433 m .79502 .25225 L .79822 .25107 L F
.55008 .26017 m .55151 .25671 L .55314 .25879 L 0 .039 .141 r
F
.55008 .26017 m .54845 .25811 L .55151 .25671 L F
.27253 .25462 m .27354 .25135 L .27543 .25354 L 0 .028 .127 r
F
.27253 .25462 m .27063 .25243 L .27354 .25135 L F
.54234 .26067 m .54376 .25729 L .54539 .2595 L 0 .04 .142 r
F
.54234 .26067 m .5407 .25845 L .54376 .25729 L F
.23686 .25404 m .23781 .25084 L .23975 .25294 L 0 .027 .126 r
F
.23686 .25404 m .23492 .25194 L .23781 .25084 L F
.34385 .25597 m .34497 .25262 L .3468 .25481 L 0 .03 .13 r
F
.34385 .25597 m .34202 .2538 L .34497 .25262 L F
.58105 .25855 m .58253 .2553 L .58412 .25741 L 0 .036 .137 r
F
.58105 .25855 m .57945 .25647 L .58253 .2553 L F
.50667 .26005 m .50805 .25664 L .50971 .25879 L 0 .039 .141 r
F
.50667 .26005 m .50501 .25791 L .50805 .25664 L F
.52216 .25921 m .52355 .25597 L .5252 .25807 L 0 .037 .139 r
F
.52216 .25921 m .5205 .25709 L .52355 .25597 L F
.75301 .25427 m .75478 .25123 L .75619 .25324 L 0 .027 .127 r
F
.75301 .25427 m .75159 .25224 L .75478 .25123 L F
.15779 .25321 m .15862 .24996 L .16064 .25207 L 0 .025 .124 r
F
.15779 .25321 m .15577 .25111 L .15862 .24996 L F
.51442 .25967 m .5158 .25625 L .51746 .25838 L 0 .038 .14 r
F
.51442 .25967 m .51275 .25753 L .5158 .25625 L F
.65542 .25711 m .65702 .25385 L .65854 .25603 L 0 .033 .134 r
F
.65542 .25711 m .65389 .25493 L .65702 .25385 L F
.20119 .25348 m .20209 .25027 L .20406 .25236 L 0 .026 .125 r
F
.20119 .25348 m .19921 .25137 L .20209 .25027 L F
.80417 .25415 m .80601 .25105 L .80737 .2531 L 0 .027 .127 r
F
.80417 .25415 m .8028 .25209 L .80601 .25105 L F
.41517 .25741 m .41639 .25424 L .41815 .25635 L 0 .034 .135 r
F
.41517 .25741 m .4134 .25533 L .41639 .25424 L F
.48649 .25876 m .48783 .25547 L .48952 .25777 L 0 .036 .138 r
F
.48649 .25876 m .48481 .25646 L .48783 .25547 L F
.1221 .25276 m .12286 .24965 L .12492 .25173 L 0 .025 .123 r
F
.1221 .25276 m .12005 .25068 L .12286 .24965 L F
.31591 .25514 m .31698 .25196 L .31884 .25409 L 0 .029 .129 r
F
.31591 .25514 m .31405 .25303 L .31698 .25196 L F
.45083 .25817 m .45211 .25512 L .45383 .25722 L 0 .036 .137 r
F
.45083 .25817 m .4491 .2561 L .45211 .25512 L F
.20891 .25326 m .20981 .25008 L .21179 .25212 L 0 .026 .124 r
F
.20891 .25326 m .20694 .25122 L .20981 .25008 L F
.28024 .25459 m .28126 .25132 L .28315 .25346 L 0 .028 .128 r
F
.28024 .25459 m .27835 .25243 L .28126 .25132 L F
.16549 .25309 m .16634 .24989 L .16834 .25201 L 0 .025 .124 r
F
.16549 .25309 m .16349 .25098 L .16634 .24989 L F
.81968 .25354 m .82153 .25036 L .82288 .25238 L 0 .026 .125 r
F
.81968 .25354 m .81833 .25153 L .82153 .25036 L F
.58879 .25848 m .59029 .25522 L .59188 .25734 L 0 .036 .137 r
F
.58879 .25848 m .58721 .25632 L .59029 .25522 L F
.67866 .25612 m .6803 .25307 L .68179 .25507 L 0 .032 .132 r
F
.67866 .25612 m .67717 .25414 L .6803 .25307 L F
.24457 .25398 m .24552 .25085 L .24745 .25296 L 0 .027 .127 r
F
.24457 .25398 m .24264 .25187 L .24552 .25085 L F
.76078 .25419 m .76255 .25109 L .76396 .25307 L 0 .028 .127 r
F
.76078 .25419 m .75937 .25219 L .76255 .25109 L F
.35157 .25592 m .3527 .25259 L .35452 .25484 L 0 .031 .131 r
F
.35157 .25592 m .34975 .2537 L .3527 .25259 L F
.66318 .25701 m .66479 .25385 L .6663 .25592 L 0 .033 .134 r
F
.66318 .25701 m .66166 .25494 L .66479 .25385 L F
.81194 .25403 m .81378 .25077 L .81513 .25278 L 0 .027 .126 r
F
.81194 .25403 m .81058 .252 L .81378 .25077 L F
.67092 .25661 m .67254 .25339 L .67404 .25535 L 0 .032 .133 r
F
.67092 .25661 m .66942 .25467 L .67254 .25339 L F
.38723 .25664 m .38841 .25349 L .3902 .2557 L 0 .033 .133 r
F
.38723 .25664 m .38545 .25444 L .38841 .25349 L F
.28797 .25429 m .289 .25109 L .29089 .25311 L 0 .028 .127 r
F
.28797 .25429 m .28607 .25228 L .289 .25109 L F
.76854 .25393 m .77032 .25083 L .77172 .2528 L 0 .027 .127 r
F
.76854 .25393 m .76714 .25195 L .77032 .25083 L F
.21663 .25308 m .21753 .25005 L .2195 .25206 L 0 .026 .125 r
F
.21663 .25308 m .21466 .25108 L .21753 .25005 L F
.5299 .25933 m .53131 .25604 L .53295 .25828 L 0 .038 .14 r
F
.5299 .25933 m .52825 .25705 L .53131 .25604 L F
.2957 .25397 m .29673 .25096 L .29862 .25298 L 0 .028 .127 r
F
.2957 .25397 m .29382 .25196 L .29673 .25096 L F
.82744 .25334 m .82931 .25016 L .83066 .25225 L 0 .026 .125 r
F
.82744 .25334 m .82609 .25127 L .82931 .25016 L F
.32363 .25507 m .32471 .252 L .32656 .25405 L 0 .03 .13 r
F
.32363 .25507 m .32177 .25303 L .32471 .252 L F
.59654 .25829 m .59806 .25523 L .59963 .25726 L 0 .036 .138 r
F
.59654 .25829 m .59496 .25623 L .59806 .25523 L F
.62752 .25658 m .62907 .25335 L .63062 .25543 L 0 .033 .133 r
F
.62752 .25658 m .62597 .25453 L .62907 .25335 L F
.42289 .25746 m .42414 .25419 L .42588 .25634 L 0 .034 .135 r
F
.42289 .25746 m .42114 .25527 L .42414 .25419 L F
.1732 .25296 m .17405 .24978 L .17606 .25183 L 0 .026 .124 r
F
.1732 .25296 m .1712 .25091 L .17405 .24978 L F
.77629 .25361 m .77809 .25054 L .77947 .25248 L 0 .027 .126 r
F
.77629 .25361 m .7749 .25167 L .77809 .25054 L F
.12979 .25275 m .13058 .24955 L .13262 .25162 L 0 .025 .124 r
F
.12979 .25275 m .12774 .25069 L .13058 .24955 L F
.68642 .25599 m .68807 .25281 L .68955 .25481 L 0 .031 .132 r
F
.68642 .25599 m .68493 .25402 L .68807 .25281 L F
.69416 .25557 m .69582 .25231 L .6973 .25435 L 0 .03 .131 r
F
.69416 .25557 m .69268 .25356 L .69582 .25231 L F
.61978 .25711 m .62132 .25382 L .62287 .25579 L 0 .034 .135 r
F
.61978 .25711 m .61822 .2551 L .62132 .25382 L F
.25227 .25395 m .25324 .25082 L .25517 .25284 L 0 .028 .127 r
F
.25227 .25395 m .25034 .25194 L .25324 .25082 L F
.45856 .25826 m .45985 .25523 L .46157 .25722 L 0 .037 .138 r
F
.45856 .25826 m .45684 .25626 L .45985 .25523 L F
.49423 .25892 m .49558 .25581 L .49726 .25795 L 0 .038 .14 r
F
.49423 .25892 m .49255 .25679 L .49558 .25581 L F
.13751 .25249 m .1383 .24938 L .14034 .2514 L 0 .025 .124 r
F
.13751 .25249 m .13546 .25048 L .1383 .24938 L F
.18093 .25271 m .18179 .24952 L .18379 .25155 L F
.18093 .25271 m .17892 .25069 L .18179 .24952 L F
.70191 .25529 m .70359 .25214 L .70506 .2542 L 0 .03 .13 r
F
.70191 .25529 m .70044 .25325 L .70359 .25214 L F
.35929 .25593 m .36043 .25271 L .36224 .25486 L 0 .031 .132 r
F
.35929 .25593 m .35747 .25377 L .36043 .25271 L F
.72515 .25406 m .72686 .25094 L .7283 .25286 L 0 .028 .128 r
F
.72515 .25406 m .72371 .25214 L .72686 .25094 L F
.63527 .25644 m .63683 .25302 L .63837 .2552 L 0 .032 .133 r
F
.63527 .25644 m .63372 .25427 L .63683 .25302 L F
.4663 .25796 m .46761 .25473 L .46932 .25672 L 0 .036 .137 r
F
.4663 .25796 m .46459 .25597 L .46761 .25473 L F
.61204 .25775 m .61357 .25434 L .61513 .25638 L 0 .035 .136 r
F
.61204 .25775 m .61047 .25568 L .61357 .25434 L F
.26 .25368 m .26099 .25049 L .26291 .25251 L 0 .027 .127 r
F
.26 .25368 m .25808 .25166 L .26099 .25049 L F
.22433 .25305 m .22525 .25 L .22721 .25201 L 0 .026 .125 r
F
.22433 .25305 m .22237 .25104 L .22525 .25 L F
.78406 .25348 m .78587 .25038 L .78725 .25244 L 0 .027 .126 r
F
.78406 .25348 m .78267 .25143 L .78587 .25038 L F
.43063 .25735 m .43188 .25409 L .43362 .25619 L 0 .034 .136 r
F
.43063 .25735 m .42888 .25523 L .43188 .25409 L F
.70967 .255 m .71136 .25193 L .71281 .25384 L 0 .03 .13 r
F
.70967 .255 m .70821 .25308 L .71136 .25193 L F
.18865 .25243 m .18953 .24927 L .19152 .25132 L 0 .025 .124 r
F
.18865 .25243 m .18666 .25039 L .18953 .24927 L F
.10182 .25201 m .10254 .24894 L .10463 .25091 L 0 .024 .123 r
F
.10182 .25201 m .09973 .25003 L .10254 .24894 L F
.7329 .25373 m .73464 .25076 L .73607 .2527 L 0 .028 .127 r
F
.7329 .25373 m .73147 .25181 L .73464 .25076 L F
.64302 .2561 m .64459 .25268 L .64613 .25486 L 0 .032 .132 r
F
.64302 .2561 m .64148 .25392 L .64459 .25268 L F
.6043 .25825 m .60582 .25501 L .60739 .25702 L 0 .036 .138 r
F
.6043 .25825 m .60272 .25622 L .60582 .25501 L F
.71741 .25461 m .71911 .25147 L .72056 .25338 L 0 .029 .129 r
F
.71741 .25461 m .71596 .25269 L .71911 .25147 L F
.33134 .25506 m .33243 .25211 L .33428 .2541 L 0 .03 .131 r
F
.33134 .25506 m .32949 .25308 L .33243 .25211 L F
.47404 .25765 m .47537 .25421 L .47706 .25639 L 0 .035 .136 r
F
.47404 .25765 m .47234 .25546 L .47537 .25421 L F
.36702 .25574 m .36817 .25265 L .36998 .2546 L 0 .032 .132 r
F
.36702 .25574 m .3652 .25378 L .36817 .25265 L F
.30341 .25404 m .30446 .25097 L .30633 .25302 L 0 .028 .128 r
F
.30341 .25404 m .30153 .25199 L .30446 .25097 L F
.43836 .25708 m .43963 .25393 L .44137 .25599 L 0 .034 .135 r
F
.43836 .25708 m .43663 .25502 L .43963 .25393 L F
.37476 .25537 m .37592 .25232 L .37773 .25424 L 0 .031 .131 r
F
.37476 .25537 m .37295 .25344 L .37592 .25232 L F
.14522 .25237 m .14601 .24931 L .14805 .25135 L 0 .025 .124 r
F
.14522 .25237 m .14318 .25035 L .14601 .24931 L F
.39494 .25692 m .39614 .2538 L .39791 .25597 L 0 .034 .135 r
F
.39494 .25692 m .39316 .25475 L .39614 .2538 L F
.56088 .25822 m .56233 .25485 L .56395 .25692 L 0 .036 .138 r
F
.56088 .25822 m .55926 .25615 L .56233 .25485 L F
.53765 .25951 m .53906 .25619 L .5407 .25845 L 0 .039 .141 r
F
.53765 .25951 m .53601 .25724 L .53906 .25619 L F
.26773 .25351 m .26873 .2503 L .27063 .25243 L 0 .027 .127 r
F
.26773 .25351 m .26582 .25141 L .26873 .2503 L F
.10953 .2518 m .11027 .24873 L .11235 .25073 L 0 .024 .123 r
F
.10953 .2518 m .10745 .24982 L .11027 .24873 L F
.74066 .25352 m .7424 .2504 L .74382 .25237 L 0 .027 .127 r
F
.74066 .25352 m .73923 .25158 L .7424 .2504 L F
.56863 .25784 m .57009 .25469 L .5717 .25676 L 0 .036 .138 r
F
.56863 .25784 m .56702 .25581 L .57009 .25469 L F
.48178 .25745 m .48312 .25416 L .48481 .25646 L 0 .035 .136 r
F
.48178 .25745 m .48009 .25515 L .48312 .25416 L F
.65077 .25599 m .65237 .25275 L .65389 .25493 L 0 .032 .133 r
F
.65077 .25599 m .64924 .25381 L .65237 .25275 L F
.55314 .25879 m .55458 .25538 L .5562 .25746 L 0 .038 .139 r
F
.55314 .25879 m .55151 .25671 L .55458 .25538 L F
.79184 .25343 m .79364 .25016 L .79502 .25225 L 0 .027 .126 r
F
.79184 .25343 m .79045 .25133 L .79364 .25016 L F
.23203 .25303 m .23298 .24986 L .23492 .25194 L F
.23203 .25303 m .23009 .25097 L .23298 .24986 L F
.33907 .25498 m .34018 .25179 L .34202 .2538 L 0 .03 .131 r
F
.33907 .25498 m .33722 .25298 L .34018 .25179 L F
.74842 .25326 m .75017 .25021 L .75159 .25224 L 0 .027 .126 r
F
.74842 .25326 m .74699 .25121 L .75017 .25021 L F
.19635 .25241 m .19724 .24927 L .19921 .25137 L 0 .025 .124 r
F
.19635 .25241 m .19438 .2503 L .19724 .24927 L F
.40268 .25673 m .40388 .25362 L .40566 .25558 L 0 .034 .135 r
F
.40268 .25673 m .4009 .2548 L .40388 .25362 L F
.50197 .25912 m .50333 .25576 L .50501 .25791 L 0 .039 .141 r
F
.50197 .25912 m .50029 .25697 L .50333 .25576 L F
.15292 .25227 m .15375 .24906 L .15577 .25111 L 0 .025 .124 r
F
.15292 .25227 m .15089 .25022 L .15375 .24906 L F
.57637 .25765 m .57785 .2544 L .57945 .25647 L 0 .036 .137 r
F
.57637 .25765 m .57477 .25562 L .57785 .2544 L F
.79959 .25314 m .80143 .25003 L .8028 .25209 L 0 .027 .126 r
F
.79959 .25314 m .79822 .25107 L .80143 .25003 L F
.41042 .25642 m .41164 .25332 L .4134 .25533 L 0 .034 .135 r
F
.41042 .25642 m .40865 .25444 L .41164 .25332 L F
.4461 .25707 m .44737 .254 L .4491 .2561 L 0 .035 .136 r
F
.4461 .25707 m .44437 .25499 L .44737 .254 L F
.50971 .25879 m .51109 .25537 L .51275 .25753 L 0 .038 .14 r
F
.50971 .25879 m .50805 .25664 L .51109 .25537 L F
.11723 .25171 m .11798 .24862 L .12005 .25068 L 0 .024 .123 r
F
.11723 .25171 m .11516 .24967 L .11798 .24862 L F
.51746 .25838 m .51885 .25497 L .5205 .25709 L 0 .037 .139 r
F
.51746 .25838 m .5158 .25625 L .51885 .25497 L F
.38248 .25539 m .38366 .2523 L .38545 .25444 L 0 .032 .132 r
F
.38248 .25539 m .38069 .25327 L .38366 .2523 L F
.31112 .2541 m .31219 .25091 L .31405 .25303 L 0 .029 .129 r
F
.31112 .2541 m .30926 .25196 L .31219 .25091 L F
.54539 .2595 m .54682 .25593 L .54845 .25811 L 0 .039 .141 r
F
.54539 .2595 m .54376 .25729 L .54682 .25593 L F
.3468 .25481 m .34793 .25148 L .34975 .2537 L 0 .03 .13 r
F
.3468 .25481 m .34497 .25262 L .34793 .25148 L F
.27543 .25354 m .27645 .25026 L .27835 .25243 L 0 .028 .127 r
F
.27543 .25354 m .27354 .25135 L .27645 .25026 L F
.58412 .25741 m .58561 .25419 L .58721 .25632 L 0 .036 .137 r
F
.58412 .25741 m .58253 .2553 L .58561 .25419 L F
.5252 .25807 m .5266 .25498 L .52825 .25705 L 0 .037 .139 r
F
.5252 .25807 m .52355 .25597 L .5266 .25498 L F
.16064 .25207 m .16147 .24886 L .16349 .25098 L 0 .025 .124 r
F
.16064 .25207 m .15862 .24996 L .16147 .24886 L F
.23975 .25294 m .2407 .24975 L .24264 .25187 L 0 .027 .126 r
F
.23975 .25294 m .23781 .25084 L .2407 .24975 L F
.51449 .52295 m .51289 .50284 L .51591 .50837 L .8 .693 0 r
F
.51147 .5167 m .51289 .50284 L .51449 .52295 L .774 .758 0 r
F
.52914 .54133 m .53058 .55667 L .53219 .54041 L .882 .449 0 r
F
.52914 .54133 m .52751 .55759 L .53058 .55667 L F
.20406 .25236 m .20496 .24914 L .20694 .25122 L 0 .026 .125 r
F
.20406 .25236 m .20209 .25027 L .20496 .24914 L F
.65854 .25603 m .66014 .25275 L .66166 .25494 L 0 .033 .134 r
F
.65854 .25603 m .65702 .25385 L .66014 .25275 L F
.75619 .25324 m .75796 .25019 L .75937 .25219 L 0 .028 .127 r
F
.75619 .25324 m .75478 .25123 L .75796 .25019 L F
.80737 .2531 m .80922 .24998 L .81058 .252 L 0 .027 .127 r
F
.80737 .2531 m .80601 .25105 L .80922 .24998 L F
.41815 .25635 m .41938 .25317 L .42114 .25527 L 0 .034 .135 r
F
.41815 .25635 m .41639 .25424 L .41938 .25317 L F
.21179 .25212 m .21269 .24904 L .21466 .25108 L 0 .026 .125 r
F
.21179 .25212 m .20981 .25008 L .21269 .24904 L F
.67404 .25535 m .67567 .25216 L .67717 .25414 L 0 .032 .132 r
F
.67404 .25535 m .67254 .25339 L .67567 .25216 L F
.81513 .25278 m .81697 .24953 L .81833 .25153 L 0 .027 .126 r
F
.81513 .25278 m .81378 .25077 L .81697 .24953 L F
.31884 .25409 m .31992 .25088 L .32177 .25303 L 0 .029 .129 r
F
.31884 .25409 m .31698 .25196 L .31992 .25088 L F
.12492 .25173 m .12569 .24862 L .12774 .25069 L 0 .025 .124 r
F
.12492 .25173 m .12286 .24965 L .12569 .24862 L F
.82288 .25238 m .82475 .24925 L .82609 .25127 L 0 .026 .125 r
F
.82288 .25238 m .82153 .25036 L .82475 .24925 L F
.28315 .25346 m .28418 .25016 L .28607 .25228 L 0 .028 .127 r
F
.28315 .25346 m .28126 .25132 L .28418 .25016 L F
.59188 .25734 m .59338 .25416 L .59496 .25623 L 0 .036 .137 r
F
.59188 .25734 m .59029 .25522 L .59338 .25416 L F
.48952 .25777 m .49086 .25448 L .49255 .25679 L 0 .037 .138 r
F
.48952 .25777 m .48783 .25547 L .49086 .25448 L F
.76396 .25307 m .76574 .24999 L .76714 .25195 L 0 .028 .127 r
F
.76396 .25307 m .76255 .25109 L .76574 .24999 L F
.16834 .25201 m .16919 .24879 L .1712 .25091 L 0 .025 .124 r
F
.16834 .25201 m .16634 .24989 L .16919 .24879 L F
.29089 .25311 m .29193 .24993 L .29382 .25196 L 0 .028 .127 r
F
.29089 .25311 m .289 .25109 L .29193 .24993 L F
.35452 .25484 m .35566 .25151 L .35747 .25377 L 0 .031 .131 r
F
.35452 .25484 m .3527 .25259 L .35566 .25151 L F
.6663 .25592 m .66791 .2526 L .66942 .25467 L 0 .033 .134 r
F
.6663 .25592 m .66479 .25385 L .66791 .2526 L F
.45383 .25722 m .45512 .25415 L .45684 .25626 L 0 .036 .138 r
F
.45383 .25722 m .45211 .25512 L .45512 .25415 L F
.68179 .25507 m .68344 .25199 L .68493 .25402 L 0 .032 .132 r
F
.68179 .25507 m .6803 .25307 L .68344 .25199 L F
.53806 .52693 m .53644 .53237 L .53943 .5123 L .8 .694 0 r
F
.53644 .53237 m .53779 .51054 L .53943 .5123 L .813 .66 0 r
F
.24745 .25296 m .24842 .24983 L .25034 .25194 L 0 .027 .127 r
F
.24745 .25296 m .24552 .25085 L .24842 .24983 L F
.62287 .25579 m .62442 .25259 L .62597 .25453 L 0 .033 .134 r
F
.62287 .25579 m .62132 .25382 L .62442 .25259 L F
.77172 .2528 m .77351 .24971 L .7749 .25167 L 0 .027 .127 r
F
.77172 .2528 m .77032 .25083 L .77351 .24971 L F
.6973 .25435 m .69896 .25118 L .70044 .25325 L 0 .03 .13 r
F
.6973 .25435 m .69582 .25231 L .69896 .25118 L F
.63062 .25543 m .63218 .25218 L .63372 .25427 L 0 .032 .133 r
F
.63062 .25543 m .62907 .25335 L .63218 .25218 L F
.68955 .25481 m .6912 .25153 L .69268 .25356 L 0 .031 .131 r
F
.68955 .25481 m .68807 .25281 L .6912 .25153 L F
.3902 .2557 m .39138 .25255 L .39316 .25475 L 0 .033 .134 r
F
.3902 .2557 m .38841 .25349 L .39138 .25255 L F
.17606 .25183 m .17692 .24865 L .17892 .25069 L 0 .025 .124 r
F
.17606 .25183 m .17405 .24978 L .17692 .24865 L F
.51173 .52825 m .51009 .51936 L .51307 .53505 L .84 .583 0 r
F
.51009 .51936 m .51147 .5167 L .51307 .53505 L .796 .704 0 r
F
.42588 .25634 m .42713 .25309 L .42888 .25523 L 0 .034 .135 r
F
.42588 .25634 m .42414 .25419 L .42713 .25309 L F
.13262 .25162 m .13342 .24841 L .13546 .25048 L 0 .025 .124 r
F
.13262 .25162 m .13058 .24955 L .13342 .24841 L F
.77947 .25248 m .78129 .24949 L .78267 .25143 L 0 .027 .126 r
F
.77947 .25248 m .77809 .25054 L .78129 .24949 L F
.53295 .25828 m .53436 .25501 L .53601 .25724 L 0 .038 .14 r
F
.53295 .25828 m .53131 .25604 L .53436 .25501 L F
.2195 .25206 m .22041 .24902 L .22237 .25104 L 0 .026 .125 r
F
.2195 .25206 m .21753 .25005 L .22041 .24902 L F
.61513 .25638 m .61666 .25309 L .61822 .2551 L 0 .034 .135 r
F
.61513 .25638 m .61357 .25434 L .61666 .25309 L F
.59963 .25726 m .60115 .25423 L .60272 .25622 L 0 .037 .138 r
F
.59963 .25726 m .59806 .25523 L .60115 .25423 L F
.32656 .25405 m .32764 .25102 L .32949 .25308 L 0 .03 .13 r
F
.32656 .25405 m .32471 .252 L .32764 .25102 L F
.29862 .25298 m .29965 .24997 L .30153 .25199 L 0 .028 .127 r
F
.29862 .25298 m .29673 .25096 L .29965 .24997 L F
.63837 .2552 m .63994 .25174 L .64148 .25392 L 0 .032 .132 r
F
.63837 .2552 m .63683 .25302 L .63994 .25174 L F
.25517 .25284 m .25615 .24964 L .25808 .25166 L 0 .027 .127 r
F
.25517 .25284 m .25324 .25082 L .25615 .24964 L F
.18379 .25155 m .18466 .24835 L .18666 .25039 L 0 .025 .124 r
F
.18379 .25155 m .18179 .24952 L .18466 .24835 L F
.53479 .53062 m .53613 .50233 L .53779 .51054 L .8 .694 0 r
F
.53479 .53062 m .53312 .52169 L .53613 .50233 L F
.46932 .25672 m .47063 .25348 L .47234 .25546 L 0 .035 .136 r
F
.46932 .25672 m .46761 .25473 L .47063 .25348 L F
.7283 .25286 m .73003 .24988 L .73147 .25181 L 0 .028 .127 r
F
.7283 .25286 m .72686 .25094 L .73003 .24988 L F
.14034 .2514 m .14113 .24832 L .14318 .25035 L 0 .025 .124 r
F
.14034 .2514 m .1383 .24938 L .14113 .24832 L F
.70506 .2542 m .70674 .25102 L .70821 .25308 L 0 .03 .13 r
F
.70506 .2542 m .70359 .25214 L .70674 .25102 L F
.36224 .25486 m .36339 .25165 L .3652 .25378 L 0 .032 .132 r
F
.36224 .25486 m .36043 .25271 L .36339 .25165 L F
.46157 .25722 m .46287 .25398 L .46459 .25597 L 0 .036 .138 r
F
.46157 .25722 m .45985 .25523 L .46287 .25398 L F
.64613 .25486 m .64771 .25164 L .64924 .25381 L 0 .032 .132 r
F
.64613 .25486 m .64459 .25268 L .64771 .25164 L F
.60739 .25702 m .60891 .25369 L .61047 .25568 L 0 .036 .137 r
F
.60739 .25702 m .60582 .25501 L .60891 .25369 L F
.26291 .25251 m .2639 .24935 L .26582 .25141 L 0 .027 .126 r
F
.26291 .25251 m .26099 .25049 L .2639 .24935 L F
.72056 .25338 m .72226 .25022 L .72371 .25214 L 0 .029 .128 r
F
.72056 .25338 m .71911 .25147 L .72226 .25022 L F
.47706 .25639 m .47839 .25297 L .48009 .25515 L 0 .034 .135 r
F
.47706 .25639 m .47537 .25421 L .47839 .25297 L F
.43362 .25619 m .43488 .25295 L .43663 .25502 L F
.43362 .25619 m .43188 .25409 L .43488 .25295 L F
.71281 .25384 m .71451 .25077 L .71596 .25269 L 0 .03 .13 r
F
.71281 .25384 m .71136 .25193 L .71451 .25077 L F
.49726 .25795 m .49862 .25482 L .50029 .25697 L 0 .038 .14 r
F
.49726 .25795 m .49558 .25581 L .49862 .25482 L F
.52367 .52014 m .52508 .49262 L .52674 .51202 L .774 .757 0 r
F
.52367 .52014 m .52202 .50002 L .52508 .49262 L F
.19152 .25132 m .19239 .24824 L .19438 .2503 L 0 .025 .124 r
F
.19152 .25132 m .18953 .24927 L .19239 .24824 L F
.56395 .25692 m .56541 .25369 L .56702 .25581 L 0 .036 .137 r
F
.56395 .25692 m .56233 .25485 L .56541 .25369 L F
.10463 .25091 m .10536 .24784 L .10745 .24982 L 0 .024 .123 r
F
.10463 .25091 m .10254 .24894 L .10536 .24784 L F
.78725 .25244 m .78906 .24927 L .79045 .25133 L 0 .027 .126 r
F
.78725 .25244 m .78587 .25038 L .78906 .24927 L F
.22721 .25201 m .22813 .24897 L .23009 .25097 L 0 .026 .125 r
F
.22721 .25201 m .22525 .25 L .22813 .24897 L F
.36998 .2546 m .37113 .25151 L .37295 .25344 L 0 .031 .132 r
F
.36998 .2546 m .36817 .25265 L .37113 .25151 L F
.73607 .2527 m .7378 .24963 L .73923 .25158 L 0 .028 .127 r
F
.73607 .2527 m .73464 .25076 L .7378 .24963 L F
.5562 .25746 m .55764 .25407 L .55926 .25615 L 0 .037 .139 r
F
.5562 .25746 m .55458 .25538 L .55764 .25407 L F
.37773 .25424 m .37888 .25132 L .38069 .25327 L 0 .031 .131 r
F
.37773 .25424 m .37592 .25232 L .37888 .25132 L F
.44137 .25599 m .44263 .25291 L .44437 .25499 L 0 .034 .136 r
F
.44137 .25599 m .43963 .25393 L .44263 .25291 L F
.74382 .25237 m .74557 .24921 L .74699 .25121 L 0 .027 .126 r
F
.74382 .25237 m .7424 .2504 L .74557 .24921 L F
.30633 .25302 m .30738 .24992 L .30926 .25196 L 0 .028 .128 r
F
.30633 .25302 m .30446 .25097 L .30738 .24992 L F
.33428 .2541 m .33538 .25098 L .33722 .25298 L 0 .031 .131 r
F
.33428 .2541 m .33243 .25211 L .33538 .25098 L F
.14805 .25135 m .14886 .24817 L .15089 .25022 L 0 .025 .124 r
F
.14805 .25135 m .14601 .24931 L .14886 .24817 L F
.27063 .25243 m .27164 .2492 L .27354 .25135 L 0 .027 .127 r
F
.27063 .25243 m .26873 .2503 L .27164 .2492 L F
.5407 .25845 m .54213 .25506 L .54376 .25729 L 0 .039 .141 r
F
.5407 .25845 m .53906 .25619 L .54213 .25506 L F
.11235 .25073 m .11309 .24764 L .11516 .24967 L 0 .024 .123 r
F
.11235 .25073 m .11027 .24873 L .11309 .24764 L F
.79502 .25225 m .79684 .24899 L .79822 .25107 L 0 .027 .126 r
F
.79502 .25225 m .79364 .25016 L .79684 .24899 L F
.5717 .25676 m .57317 .25351 L .57477 .25562 L 0 .036 .137 r
F
.5717 .25676 m .57009 .25469 L .57317 .25351 L F
.34202 .2538 m .34313 .25061 L .34497 .25262 L 0 .03 .13 r
F
.34202 .2538 m .34018 .25179 L .34313 .25061 L F
.54845 .25811 m .54989 .25456 L .55151 .25671 L 0 .038 .14 r
F
.54845 .25811 m .54682 .25593 L .54989 .25456 L F
.39791 .25597 m .39912 .25262 L .4009 .2548 L 0 .034 .135 r
F
.39791 .25597 m .39614 .2538 L .39912 .25262 L F
.50501 .25791 m .50638 .25447 L .50805 .25664 L 0 .038 .14 r
F
.50501 .25791 m .50333 .25576 L .50638 .25447 L F
.40566 .25558 m .40687 .25245 L .40865 .25444 L 0 .034 .135 r
F
.40566 .25558 m .40388 .25362 L .40687 .25245 L F
.65389 .25493 m .65549 .25167 L .65702 .25385 L 0 .032 .133 r
F
.65389 .25493 m .65237 .25275 L .65549 .25167 L F
.5205 .25709 m .5219 .25386 L .52355 .25597 L 0 .037 .138 r
F
.5205 .25709 m .51885 .25497 L .5219 .25386 L F
.23492 .25194 m .23587 .24874 L .23781 .25084 L 0 .026 .126 r
F
.23492 .25194 m .23298 .24986 L .23587 .24874 L F
.51275 .25753 m .51414 .2541 L .5158 .25625 L 0 .037 .139 r
F
.51275 .25753 m .51109 .25537 L .51414 .2541 L F
.48481 .25646 m .48614 .25316 L .48783 .25547 L 0 .035 .137 r
F
.48481 .25646 m .48312 .25416 L .48614 .25316 L F
.57945 .25647 m .58093 .25317 L .58253 .2553 L F
.57945 .25647 m .57785 .2544 L .58093 .25317 L F
.15577 .25111 m .1566 .2479 L .15862 .24996 L 0 .025 .124 r
F
.15577 .25111 m .15375 .24906 L .1566 .2479 L F
.19921 .25137 m .20011 .24818 L .20209 .25027 L 0 .026 .124 r
F
.19921 .25137 m .19724 .24927 L .20011 .24818 L F
.75159 .25224 m .75336 .24921 L .75478 .25123 L 0 .027 .127 r
F
.75159 .25224 m .75017 .25021 L .75336 .24921 L F
.8028 .25209 m .80464 .24902 L .80601 .25105 L 0 .027 .126 r
F
.8028 .25209 m .80143 .25003 L .80464 .24902 L F
.4134 .25533 m .41463 .2522 L .41639 .25424 L 0 .034 .134 r
F
.4134 .25533 m .41164 .25332 L .41463 .2522 L F
.31405 .25303 m .31512 .24982 L .31698 .25196 L 0 .029 .129 r
F
.31405 .25303 m .31219 .25091 L .31512 .24982 L F
.12005 .25068 m .1208 .2476 L .12286 .24965 L 0 .025 .123 r
F
.12005 .25068 m .11798 .24862 L .1208 .2476 L F
.34975 .2537 m .35089 .25035 L .3527 .25259 L 0 .03 .13 r
F
.34975 .2537 m .34793 .25148 L .35089 .25035 L F
.27835 .25243 m .27937 .24918 L .28126 .25132 L 0 .028 .127 r
F
.27835 .25243 m .27645 .25026 L .27937 .24918 L F
.4491 .2561 m .45038 .25299 L .45211 .25512 L 0 .035 .137 r
F
.4491 .2561 m .44737 .254 L .45038 .25299 L F
.58721 .25632 m .5887 .25309 L .59029 .25522 L 0 .036 .137 r
F
.58721 .25632 m .58561 .25419 L .5887 .25309 L F
.16349 .25098 m .16433 .24776 L .16634 .24989 L 0 .025 .124 r
F
.16349 .25098 m .16147 .24886 L .16433 .24776 L F
.38545 .25444 m .38662 .25135 L .38841 .25349 L 0 .032 .133 r
F
.38545 .25444 m .38366 .2523 L .38662 .25135 L F
.20694 .25122 m .20784 .24802 L .20981 .25008 L 0 .026 .124 r
F
.20694 .25122 m .20496 .24914 L .20784 .24802 L F
.24264 .25187 m .24359 .24874 L .24552 .25085 L 0 .027 .126 r
F
.24264 .25187 m .2407 .24975 L .24359 .24874 L F
.52825 .25705 m .52966 .25398 L .53131 .25604 L 0 .038 .139 r
F
.52825 .25705 m .5266 .25498 L .52966 .25398 L F
.53219 .54041 m .53058 .55667 L .53363 .54786 L .868 .495 0 r
F
.66166 .25494 m .66327 .25165 L .66479 .25385 L 0 .033 .134 r
F
.66166 .25494 m .66014 .25275 L .66327 .25165 L F
.52841 .53038 m .52978 .49594 L .53145 .51277 L .796 .703 0 r
F
.52841 .53038 m .52674 .51202 L .52978 .49594 L F
.81833 .25153 m .82019 .24838 L .82153 .25036 L 0 .026 .125 r
F
.81833 .25153 m .81697 .24953 L .82019 .24838 L F
.75937 .25219 m .76115 .24911 L .76255 .25109 L 0 .028 .127 r
F
.75937 .25219 m .75796 .25019 L .76115 .24911 L F
.52139 .5437 m .52278 .55705 L .52444 .55063 L .887 .435 0 r
F
.52139 .5437 m .51972 .54982 L .52278 .55705 L F
.67717 .25414 m .67881 .25106 L .6803 .25307 L 0 .032 .132 r
F
.67717 .25414 m .67567 .25216 L .67881 .25106 L F
.81058 .252 m .81242 .24875 L .81378 .25077 L 0 .027 .126 r
F
.81058 .252 m .80922 .24998 L .81242 .24875 L F
.42114 .25527 m .42238 .25211 L .42414 .25419 L 0 .034 .135 r
F
.42114 .25527 m .41938 .25317 L .42238 .25211 L F
.28607 .25228 m .28711 .24898 L .289 .25109 L 0 .028 .127 r
F
.28607 .25228 m .28418 .25016 L .28711 .24898 L F
.66942 .25467 m .67104 .25133 L .67254 .25339 L 0 .032 .133 r
F
.66942 .25467 m .66791 .2526 L .67104 .25133 L F
.82609 .25127 m .82797 .24814 L .82931 .25016 L 0 .026 .125 r
F
.82609 .25127 m .82475 .24925 L .82797 .24814 L F
.59496 .25623 m .59648 .25319 L .59806 .25523 L 0 .036 .138 r
F
.59496 .25623 m .59338 .25416 L .59648 .25319 L F
.21466 .25108 m .21556 .248 L .21753 .25005 L 0 .026 .125 r
F
.21466 .25108 m .21269 .24904 L .21556 .248 L F
.62597 .25453 m .62753 .25141 L .62907 .25335 L 0 .033 .133 r
F
.62597 .25453 m .62442 .25259 L .62753 .25141 L F
.76714 .25195 m .76892 .24888 L .77032 .25083 L 0 .027 .127 r
F
.76714 .25195 m .76574 .24999 L .76892 .24888 L F
.32177 .25303 m .32286 .24983 L .32471 .252 L 0 .029 .129 r
F
.32177 .25303 m .31992 .25088 L .32286 .24983 L F
.29382 .25196 m .29485 .24893 L .29673 .25096 L 0 .028 .127 r
F
.29382 .25196 m .29193 .24993 L .29485 .24893 L F
.12774 .25069 m .12852 .24747 L .13058 .24955 L 0 .025 .124 r
F
.12774 .25069 m .12569 .24862 L .12852 .24747 L F
.1712 .25091 m .17205 .24768 L .17405 .24978 L F
.1712 .25091 m .16919 .24879 L .17205 .24768 L F
.35747 .25377 m .35862 .25047 L .36043 .25271 L 0 .031 .131 r
F
.35747 .25377 m .35566 .25151 L .35862 .25047 L F
.69268 .25356 m .69434 .25025 L .69582 .25231 L 0 .03 .131 r
F
.69268 .25356 m .6912 .25153 L .69434 .25025 L F
.49255 .25679 m .4939 .25349 L .49558 .25581 L 0 .037 .139 r
F
.49255 .25679 m .49086 .25448 L .4939 .25349 L F
.68493 .25402 m .68658 .25076 L .68807 .25281 L 0 .031 .132 r
F
.68493 .25402 m .68344 .25199 L .68658 .25076 L F
.61822 .2551 m .61976 .25185 L .62132 .25382 L 0 .034 .135 r
F
.61822 .2551 m .61666 .25309 L .61976 .25185 L F
.7749 .25167 m .7767 .2486 L .77809 .25054 L 0 .027 .126 r
F
.7749 .25167 m .77351 .24971 L .7767 .2486 L F
.63372 .25427 m .63529 .25092 L .63683 .25302 L 0 .032 .132 r
F
.63372 .25427 m .63218 .25218 L .63529 .25092 L F
.25034 .25194 m .25132 .24872 L .25324 .25082 L 0 .027 .127 r
F
.25034 .25194 m .24842 .24983 L .25132 .24872 L F
.70044 .25325 m .70211 .25006 L .70359 .25214 L 0 .03 .13 r
F
.70044 .25325 m .69896 .25118 L .70211 .25006 L F
.45684 .25626 m .45813 .2531 L .45985 .25523 L 0 .036 .138 r
F
.45684 .25626 m .45512 .25415 L .45813 .2531 L F
.17892 .25069 m .17979 .24747 L .18179 .24952 L 0 .025 .124 r
F
.17892 .25069 m .17692 .24865 L .17979 .24747 L F
.13546 .25048 m .13625 .2473 L .1383 .24938 L 0 .025 .123 r
F
.13546 .25048 m .13342 .24841 L .13625 .2473 L F
.64148 .25392 m .64305 .25049 L .64459 .25268 L 0 .031 .132 r
F
.64148 .25392 m .63994 .25174 L .64305 .25049 L F
.42888 .25523 m .43013 .25198 L .43188 .25409 L 0 .034 .135 r
F
.42888 .25523 m .42713 .25309 L .43013 .25198 L F
.61047 .25568 m .612 .25236 L .61357 .25434 L 0 .035 .136 r
F
.61047 .25568 m .60891 .25369 L .612 .25236 L F
.47234 .25546 m .47366 .25223 L .47537 .25421 L F
.47234 .25546 m .47063 .25348 L .47366 .25223 L F
.78267 .25143 m .78449 .24844 L .78587 .25038 L 0 .027 .126 r
F
.78267 .25143 m .78129 .24949 L .78449 .24844 L F
.53601 .25724 m .53742 .25397 L .53906 .25619 L 0 .039 .14 r
F
.53601 .25724 m .53436 .25501 L .53742 .25397 L F
.25808 .25166 m .25907 .24845 L .26099 .25049 L 0 .027 .126 r
F
.25808 .25166 m .25615 .24964 L .25907 .24845 L F
.46459 .25597 m .46589 .25273 L .46761 .25473 L 0 .036 .137 r
F
.46459 .25597 m .46287 .25398 L .46589 .25273 L F
.18666 .25039 m .18753 .24722 L .18953 .24927 L 0 .025 .123 r
F
.18666 .25039 m .18466 .24835 L .18753 .24722 L F
.22237 .25104 m .22328 .24799 L .22525 .25 L 0 .026 .125 r
F
.22237 .25104 m .22041 .24902 L .22328 .24799 L F
.48009 .25515 m .48142 .25197 L .48312 .25416 L 0 .034 .135 r
F
.48009 .25515 m .47839 .25297 L .48142 .25197 L F
.60272 .25622 m .60425 .25304 L .60582 .25501 L 0 .037 .138 r
F
.60272 .25622 m .60115 .25423 L .60425 .25304 L F
.72371 .25214 m .72542 .24901 L .72686 .25094 L 0 .028 .128 r
F
.72371 .25214 m .72226 .25022 L .72542 .24901 L F
.39316 .25475 m .39436 .2516 L .39614 .2538 L 0 .034 .134 r
F
.39316 .25475 m .39138 .25255 L .39436 .2516 L F
.30153 .25199 m .30258 .24895 L .30446 .25097 L 0 .028 .128 r
F
.30153 .25199 m .29965 .24997 L .30258 .24895 L F
.70821 .25308 m .70989 .24985 L .71136 .25193 L 0 .03 .13 r
F
.70821 .25308 m .70674 .25102 L .70989 .24985 L F
.32949 .25308 m .33058 .25003 L .33243 .25211 L 0 .03 .131 r
F
.32949 .25308 m .32764 .25102 L .33058 .25003 L F
.43663 .25502 m .43789 .25185 L .43963 .25393 L 0 .034 .135 r
F
.43663 .25502 m .43488 .25295 L .43789 .25185 L F
.73147 .25181 m .7332 .24882 L .73464 .25076 L 0 .028 .128 r
F
.73147 .25181 m .73003 .24988 L .7332 .24882 L F
.71596 .25269 m .71766 .24955 L .71911 .25147 L 0 .029 .129 r
F
.71596 .25269 m .71451 .25077 L .71766 .24955 L F
.26582 .25141 m .26682 .24821 L .26873 .2503 L 0 .027 .126 r
F
.26582 .25141 m .2639 .24935 L .26682 .24821 L F
.3652 .25378 m .36636 .25054 L .36817 .25265 L 0 .031 .132 r
F
.3652 .25378 m .36339 .25165 L .36636 .25054 L F
.55926 .25615 m .56072 .25277 L .56233 .25485 L 0 .036 .138 r
F
.55926 .25615 m .55764 .25407 L .56072 .25277 L F
.14318 .25035 m .14397 .24725 L .14601 .24931 L 0 .025 .124 r
F
.14318 .25035 m .14113 .24832 L .14397 .24725 L F
.64924 .25381 m .65084 .25059 L .65237 .25275 L 0 .032 .132 r
F
.64924 .25381 m .64771 .25164 L .65084 .25059 L F
.37295 .25344 m .37411 .25039 L .37592 .25232 L 0 .031 .132 r
F
.37295 .25344 m .37113 .25151 L .37411 .25039 L F
.56702 .25581 m .56848 .25253 L .57009 .25469 L 0 .036 .137 r
F
.56702 .25581 m .56541 .25369 L .56848 .25253 L F
.10745 .24982 m .10819 .24672 L .11027 .24873 L 0 .024 .123 r
F
.10745 .24982 m .10536 .24784 L .10819 .24672 L F
.79045 .25133 m .79226 .24811 L .79364 .25016 L 0 .027 .126 r
F
.79045 .25133 m .78906 .24927 L .79226 .24811 L F
.55151 .25671 m .55295 .25327 L .55458 .25538 L 0 .037 .139 r
F
.55151 .25671 m .54989 .25456 L .55295 .25327 L F
.73923 .25158 m .74097 .24842 L .7424 .2504 L 0 .028 .127 r
F
.73923 .25158 m .7378 .24963 L .74097 .24842 L F
.19438 .2503 m .19525 .24721 L .19724 .24927 L 0 .025 .124 r
F
.19438 .2503 m .19239 .24824 L .19525 .24721 L F
.50029 .25697 m .50166 .2536 L .50333 .25576 L 0 .038 .14 r
F
.50029 .25697 m .49862 .25482 L .50166 .2536 L F
.23009 .25097 m .23102 .24783 L .23298 .24986 L 0 .026 .126 r
F
.23009 .25097 m .22813 .24897 L .23102 .24783 L F
.74699 .25121 m .74875 .24819 L .75017 .25021 L 0 .027 .126 r
F
.74699 .25121 m .74557 .24921 L .74875 .24819 L F
.33722 .25298 m .33833 .24978 L .34018 .25179 L 0 .03 .131 r
F
.33722 .25298 m .33538 .25098 L .33833 .24978 L F
.50805 .25664 m .50942 .25319 L .51109 .25537 L 0 .038 .139 r
F
.50805 .25664 m .50638 .25447 L .50942 .25319 L F
.54376 .25729 m .54519 .25373 L .54682 .25593 L 0 .039 .141 r
F
.54376 .25729 m .54213 .25506 L .54519 .25373 L F
.79822 .25107 m .80005 .24797 L .80143 .25003 L 0 .027 .126 r
F
.79822 .25107 m .79684 .24899 L .80005 .24797 L F
.15089 .25022 m .15171 .247 L .15375 .24906 L 0 .025 .124 r
F
.15089 .25022 m .14886 .24817 L .15171 .247 L F
.5158 .25625 m .51719 .25282 L .51885 .25497 L 0 .037 .138 r
F
.5158 .25625 m .51414 .2541 L .51719 .25282 L F
.57477 .25562 m .57625 .25225 L .57785 .2544 L 0 .036 .137 r
F
.57477 .25562 m .57317 .25351 L .57625 .25225 L F
.30926 .25196 m .31032 .24888 L .31219 .25091 L 0 .029 .128 r
F
.30926 .25196 m .30738 .24992 L .31032 .24888 L F
.34497 .25262 m .34609 .24944 L .34793 .25148 L 0 .03 .13 r
F
.34497 .25262 m .34313 .25061 L .34609 .24944 L F
.38069 .25327 m .38185 .25033 L .38366 .2523 L 0 .031 .132 r
F
.38069 .25327 m .37888 .25132 L .38185 .25033 L F
.44437 .25499 m .44564 .25189 L .44737 .254 L 0 .035 .136 r
F
.44437 .25499 m .44263 .25291 L .44564 .25189 L F
.27354 .25135 m .27455 .24813 L .27645 .25026 L 0 .027 .127 r
F
.27354 .25135 m .27164 .2492 L .27455 .24813 L F
.4009 .2548 m .40211 .25142 L .40388 .25362 L 0 .034 .135 r
F
.4009 .2548 m .39912 .25262 L .40211 .25142 L F
.11516 .24967 m .11591 .24659 L .11798 .24862 L 0 .024 .123 r
F
.11516 .24967 m .11309 .24764 L .11591 .24659 L F
.58253 .2553 m .58402 .25206 L .58561 .25419 L 0 .035 .137 r
F
.58253 .2553 m .58093 .25317 L .58402 .25206 L F
.40865 .25444 m .40987 .2513 L .41164 .25332 L 0 .034 .135 r
F
.40865 .25444 m .40687 .25245 L .40987 .2513 L F
.52355 .25597 m .52495 .25289 L .5266 .25498 L 0 .037 .139 r
F
.52355 .25597 m .5219 .25386 L .52495 .25289 L F
.15862 .24996 m .15945 .24678 L .16147 .24886 L 0 .025 .123 r
F
.15862 .24996 m .1566 .2479 L .15945 .24678 L F
.23781 .25084 m .23877 .24765 L .2407 .24975 L 0 .026 .126 r
F
.23781 .25084 m .23587 .24874 L .23877 .24765 L F
.65702 .25385 m .65862 .25056 L .66014 .25275 L 0 .032 .133 r
F
.65702 .25385 m .65549 .25167 L .65862 .25056 L F
.20209 .25027 m .20299 .24707 L .20496 .24914 L 0 .025 .124 r
F
.20209 .25027 m .20011 .24818 L .20299 .24707 L F
.48783 .25547 m .48918 .25217 L .49086 .25448 L 0 .036 .137 r
F
.48783 .25547 m .48614 .25316 L .48918 .25217 L F
.41639 .25424 m .41762 .25114 L .41938 .25317 L 0 .034 .135 r
F
.41639 .25424 m .41463 .2522 L .41762 .25114 L F
.75478 .25123 m .75655 .24819 L .75796 .25019 L 0 .028 .127 r
F
.75478 .25123 m .75336 .24921 L .75655 .24819 L F
.80601 .25105 m .80785 .24795 L .80922 .24998 L 0 .027 .127 r
F
.80601 .25105 m .80464 .24902 L .80785 .24795 L F
.3527 .25259 m .35384 .24926 L .35566 .25151 L 0 .03 .13 r
F
.3527 .25259 m .35089 .25035 L .35384 .24926 L F
.31698 .25196 m .31806 .24873 L .31992 .25088 L 0 .029 .129 r
F
.31698 .25196 m .31512 .24982 L .31806 .24873 L F
.28126 .25132 m .28229 .24803 L .28418 .25016 L 0 .028 .127 r
F
.28126 .25132 m .27937 .24918 L .28229 .24803 L F
.59029 .25522 m .59179 .25202 L .59338 .25416 L 0 .036 .137 r
F
.59029 .25522 m .5887 .25309 L .59179 .25202 L F
.12286 .24965 m .12363 .24656 L .12569 .24862 L 0 .025 .123 r
F
.12286 .24965 m .1208 .2476 L .12363 .24656 L F
.20981 .25008 m .21072 .24698 L .21269 .24904 L 0 .026 .124 r
F
.20981 .25008 m .20784 .24802 L .21072 .24698 L F
.16634 .24989 m .16718 .24667 L .16919 .24879 L 0 .025 .124 r
F
.16634 .24989 m .16433 .24776 L .16718 .24667 L F
.81378 .25077 m .81562 .24753 L .81697 .24953 L 0 .027 .126 r
F
.81378 .25077 m .81242 .24875 L .81562 .24753 L F
.82153 .25036 m .82341 .24729 L .82475 .24925 L 0 .026 .125 r
F
.82153 .25036 m .82019 .24838 L .82341 .24729 L F
.67254 .25339 m .67417 .25012 L .67567 .25216 L 0 .032 .132 r
F
.67254 .25339 m .67104 .25133 L .67417 .25012 L F
.45211 .25512 m .45339 .25199 L .45512 .25415 L 0 .036 .137 r
F
.45211 .25512 m .45038 .25299 L .45339 .25199 L F
.66479 .25385 m .6664 .25043 L .66791 .2526 L 0 .033 .133 r
F
.66479 .25385 m .66327 .25165 L .6664 .25043 L F
.24552 .25085 m .24649 .24772 L .24842 .24983 L 0 .027 .126 r
F
.24552 .25085 m .24359 .24874 L .24649 .24772 L F
.76255 .25109 m .76433 .24802 L .76574 .24999 L 0 .028 .127 r
F
.76255 .25109 m .76115 .24911 L .76433 .24802 L F
.289 .25109 m .29004 .24783 L .29193 .24993 L 0 .027 .127 r
F
.289 .25109 m .28711 .24898 L .29004 .24783 L F
.53131 .25604 m .53272 .25295 L .53436 .25501 L 0 .038 .14 r
F
.53131 .25604 m .52966 .25398 L .53272 .25295 L F
.38841 .25349 m .3896 .25039 L .39138 .25255 L 0 .032 .133 r
F
.38841 .25349 m .38662 .25135 L .3896 .25039 L F
.6803 .25307 m .68195 .24996 L .68344 .25199 L 0 .032 .132 r
F
.6803 .25307 m .67881 .25106 L .68195 .24996 L F
.53644 .53237 m .53479 .53062 L .53779 .51054 L .813 .66 0 r
F
.42414 .25419 m .42538 .25104 L .42713 .25309 L 0 .034 .135 r
F
.42414 .25419 m .42238 .25211 L .42538 .25104 L F
.62907 .25335 m .63064 .25024 L .63218 .25218 L 0 .032 .133 r
F
.62907 .25335 m .62753 .25141 L .63064 .25024 L F
.69582 .25231 m .69748 .24911 L .69896 .25118 L 0 .03 .13 r
F
.69582 .25231 m .69434 .25025 L .69748 .24911 L F
.62132 .25382 m .62287 .25064 L .62442 .25259 L 0 .033 .134 r
F
.62132 .25382 m .61976 .25185 L .62287 .25064 L F
.77032 .25083 m .77211 .24777 L .77351 .24971 L 0 .027 .127 r
F
.77032 .25083 m .76892 .24888 L .77211 .24777 L F
.13058 .24955 m .13137 .24633 L .13342 .24841 L 0 .025 .123 r
F
.13058 .24955 m .12852 .24747 L .13137 .24633 L F
.17405 .24978 m .17491 .24657 L .17692 .24865 L 0 .025 .124 r
F
.17405 .24978 m .17205 .24768 L .17491 .24657 L F
.63683 .25302 m .6384 .24963 L .63994 .25174 L 0 .031 .132 r
F
.63683 .25302 m .63529 .25092 L .6384 .24963 L F
.68807 .25281 m .68971 .24945 L .6912 .25153 L 0 .031 .131 r
F
.68807 .25281 m .68658 .25076 L .68971 .24945 L F
.61357 .25434 m .6151 .25115 L .61666 .25309 L 0 .034 .135 r
F
.61357 .25434 m .612 .25236 L .6151 .25115 L F
.21753 .25005 m .21844 .24697 L .22041 .24902 L 0 .026 .125 r
F
.21753 .25005 m .21556 .248 L .21844 .24697 L F
.32471 .252 m .32579 .24883 L .32764 .25102 L 0 .03 .13 r
F
.32471 .252 m .32286 .24983 L .32579 .24883 L F
.59806 .25523 m .59957 .25222 L .60115 .25423 L 0 .037 .138 r
F
.59806 .25523 m .59648 .25319 L .59957 .25222 L F
.64459 .25268 m .64618 .24946 L .64771 .25164 L 0 .031 .131 r
F
.64459 .25268 m .64305 .25049 L .64618 .24946 L F
.29673 .25096 m .29777 .24793 L .29965 .24997 L 0 .028 .127 r
F
.29673 .25096 m .29485 .24893 L .29777 .24793 L F
.77809 .25054 m .7799 .24755 L .78129 .24949 L 0 .027 .126 r
F
.77809 .25054 m .7767 .2486 L .7799 .24755 L F
.47537 .25421 m .47669 .251 L .47839 .25297 L 0 .034 .135 r
F
.47537 .25421 m .47366 .25223 L .47669 .251 L F
.36043 .25271 m .36158 .24944 L .36339 .25165 L 0 .031 .131 r
F
.36043 .25271 m .35862 .25047 L .36158 .24944 L F
.18179 .24952 m .18266 .24629 L .18466 .24835 L 0 .025 .124 r
F
.18179 .24952 m .17979 .24747 L .18266 .24629 L F
.25324 .25082 m .25423 .24754 L .25615 .24964 L 0 .027 .127 r
F
.25324 .25082 m .25132 .24872 L .25423 .24754 L F
.70359 .25214 m .70527 .24891 L .70674 .25102 L 0 .03 .13 r
F
.70359 .25214 m .70211 .25006 L .70527 .24891 L F
.46761 .25473 m .46892 .25149 L .47063 .25348 L 0 .035 .137 r
F
.46761 .25473 m .46589 .25273 L .46892 .25149 L F
.49558 .25581 m .49694 .2525 L .49862 .25482 L 0 .038 .139 r
F
.49558 .25581 m .4939 .25349 L .49694 .2525 L F
.43188 .25409 m .43314 .25087 L .43488 .25295 L 0 .034 .135 r
F
.43188 .25409 m .43013 .25198 L .43314 .25087 L F
.1383 .24938 m .13909 .24624 L .14113 .24832 L 0 .025 .123 r
F
.1383 .24938 m .13625 .2473 L .13909 .24624 L F
.26099 .25049 m .26198 .24729 L .2639 .24935 L 0 .027 .126 r
F
.26099 .25049 m .25907 .24845 L .26198 .24729 L F
.45985 .25523 m .46115 .25187 L .46287 .25398 L 0 .036 .138 r
F
.45985 .25523 m .45813 .2531 L .46115 .25187 L F
.60582 .25501 m .60734 .25173 L .60891 .25369 L 0 .036 .137 r
F
.60582 .25501 m .60425 .25304 L .60734 .25173 L F
.72686 .25094 m .72859 .24793 L .73003 .24988 L 0 .028 .128 r
F
.72686 .25094 m .72542 .24901 L .72859 .24793 L F
.51337 .53717 m .51173 .52825 L .51472 .54464 L .868 .496 0 r
F
.51503 .5389 m .51337 .53717 L .51637 .55425 L .882 .45 0 r
F
.51173 .52825 m .51307 .53505 L .51472 .54464 L .84 .583 0 r
F
.56233 .25485 m .56379 .25157 L .56541 .25369 L 0 .036 .137 r
F
.56233 .25485 m .56072 .25277 L .56379 .25157 L F
.18953 .24927 m .19039 .24618 L .19239 .24824 L 0 .025 .123 r
F
.18953 .24927 m .18753 .24722 L .19039 .24618 L F
.78587 .25038 m .78769 .24733 L .78906 .24927 L 0 .027 .126 r
F
.78587 .25038 m .78449 .24844 L .78769 .24733 L F
.53906 .25619 m .54049 .25286 L .54213 .25506 L 0 .039 .14 r
F
.53906 .25619 m .53742 .25397 L .54049 .25286 L F
.71911 .25147 m .72082 .2483 L .72226 .25022 L 0 .029 .129 r
F
.71911 .25147 m .71766 .24955 L .72082 .2483 L F
.71136 .25193 m .71305 .24869 L .71451 .25077 L 0 .03 .13 r
F
.71136 .25193 m .70989 .24985 L .71305 .24869 L F
.55458 .25538 m .55602 .252 L .55764 .25407 L 0 .037 .138 r
F
.55458 .25538 m .55295 .25327 L .55602 .252 L F
.22525 .25 m .22617 .24696 L .22813 .24897 L 0 .026 .126 r
F
.22525 .25 m .22328 .24799 L .22617 .24696 L F
.43963 .25393 m .4409 .2508 L .44263 .25291 L 0 .034 .135 r
F
.43963 .25393 m .43789 .25185 L .4409 .2508 L F
.36817 .25265 m .36932 .24942 L .37113 .25151 L 0 .031 .132 r
F
.36817 .25265 m .36636 .25054 L .36932 .24942 L F
.48312 .25416 m .48445 .25097 L .48614 .25316 L 0 .035 .136 r
F
.48312 .25416 m .48142 .25197 L .48445 .25097 L F
.26873 .2503 m .26973 .2471 L .27164 .2492 L 0 .027 .126 r
F
.26873 .2503 m .26682 .24821 L .26973 .2471 L F
.30446 .25097 m .30551 .24791 L .30738 .24992 L 0 .028 .128 r
F
.30446 .25097 m .30258 .24895 L .30551 .24791 L F
.73464 .25076 m .73637 .24766 L .7378 .24963 L F
.73464 .25076 m .7332 .24882 L .73637 .24766 L F
.54682 .25593 m .54825 .2524 L .54989 .25456 L 0 .038 .14 r
F
.54682 .25593 m .54519 .25373 L .54825 .2524 L F
.39614 .2538 m .39735 .2504 L .39912 .25262 L 0 .034 .135 r
F
.39614 .2538 m .39436 .2516 L .39735 .2504 L F
.79364 .25016 m .79546 .24694 L .79684 .24899 L 0 .027 .126 r
F
.79364 .25016 m .79226 .24811 L .79546 .24694 L F
.50333 .25576 m .5047 .2523 L .50638 .25447 L 0 .038 .139 r
F
.50333 .25576 m .50166 .2536 L .5047 .2523 L F
.37592 .25232 m .37708 .24937 L .37888 .25132 L 0 .031 .132 r
F
.37592 .25232 m .37411 .25039 L .37708 .24937 L F
.14601 .24931 m .14682 .24611 L .14886 .24817 L 0 .025 .124 r
F
.14601 .24931 m .14397 .24725 L .14682 .24611 L F
.65237 .25275 m .65396 .24952 L .65549 .25167 L 0 .032 .132 r
F
.65237 .25275 m .65084 .25059 L .65396 .24952 L F
.57009 .25469 m .57156 .25131 L .57317 .25351 L 0 .036 .137 r
F
.57009 .25469 m .56848 .25253 L .57156 .25131 L F
.33243 .25211 m .33353 .2489 L .33538 .25098 L 0 .03 .131 r
F
.33243 .25211 m .33058 .25003 L .33353 .2489 L F
.51503 .5389 m .51637 .55425 L .51804 .55597 L .882 .45 0 r
F
.7424 .2504 m .74414 .24722 L .74557 .24921 L 0 .027 .127 r
F
.7424 .2504 m .74097 .24842 L .74414 .24722 L F
.51109 .25537 m .51247 .25192 L .51414 .2541 L 0 .037 .138 r
F
.51109 .25537 m .50942 .25319 L .51247 .25192 L F
.11027 .24873 m .11101 .24561 L .11309 .24764 L 0 .024 .123 r
F
.11027 .24873 m .10819 .24672 L .11101 .24561 L F
.51885 .25497 m .52024 .25171 L .5219 .25386 L 0 .036 .138 r
F
.51885 .25497 m .51719 .25282 L .52024 .25171 L F
.34018 .25179 m .34129 .24859 L .34313 .25061 L 0 .03 .13 r
F
.34018 .25179 m .33833 .24978 L .34129 .24859 L F
.23298 .24986 m .23392 .24669 L .23587 .24874 L 0 .026 .125 r
F
.23298 .24986 m .23102 .24783 L .23392 .24669 L F
.57785 .2544 m .57933 .25099 L .58093 .25317 L 0 .035 .136 r
F
.57785 .2544 m .57625 .25225 L .57933 .25099 L F
.19724 .24927 m .19812 .24612 L .20011 .24818 L 0 .025 .124 r
F
.19724 .24927 m .19525 .24721 L .19812 .24612 L F
.15375 .24906 m .15457 .24584 L .1566 .2479 L 0 .025 .123 r
F
.15375 .24906 m .15171 .247 L .15457 .24584 L F
.40388 .25362 m .4051 .25024 L .40687 .25245 L 0 .034 .135 r
F
.40388 .25362 m .40211 .25142 L .4051 .25024 L F
.34793 .25148 m .34906 .24827 L .35089 .25035 L 0 .03 .13 r
F
.34793 .25148 m .34609 .24944 L .34906 .24827 L F
.75017 .25021 m .75194 .24718 L .75336 .24921 L 0 .027 .127 r
F
.75017 .25021 m .74875 .24819 L .75194 .24718 L F
.80143 .25003 m .80327 .24697 L .80464 .24902 L 0 .027 .126 r
F
.80143 .25003 m .80005 .24797 L .80327 .24697 L F
.27645 .25026 m .27747 .24706 L .27937 .24918 L 0 .027 .127 r
F
.27645 .25026 m .27455 .24813 L .27747 .24706 L F
.31219 .25091 m .31326 .24776 L .31512 .24982 L 0 .029 .128 r
F
.31219 .25091 m .31032 .24888 L .31326 .24776 L F
.41164 .25332 m .41286 .25015 L .41463 .2522 L 0 .034 .134 r
F
.41164 .25332 m .40987 .2513 L .41286 .25015 L F
.58561 .25419 m .58711 .25096 L .5887 .25309 L 0 .035 .136 r
F
.58561 .25419 m .58402 .25206 L .58711 .25096 L F
.44737 .254 m .44865 .25086 L .45038 .25299 L F
.44737 .254 m .44564 .25189 L .44865 .25086 L F
.11798 .24862 m .11873 .24555 L .1208 .2476 L 0 .025 .123 r
F
.11798 .24862 m .11591 .24659 L .11873 .24555 L F
.38366 .2523 m .38483 .24935 L .38662 .25135 L 0 .032 .132 r
F
.38366 .2523 m .38185 .25033 L .38483 .24935 L F
.16147 .24886 m .16231 .24566 L .16433 .24776 L 0 .025 .123 r
F
.16147 .24886 m .15945 .24678 L .16231 .24566 L F
.66014 .25275 m .66175 .24944 L .66327 .25165 L 0 .032 .133 r
F
.66014 .25275 m .65862 .25056 L .66175 .24944 L F
.2407 .24975 m .24166 .24662 L .24359 .24874 L 0 .027 .126 r
F
.2407 .24975 m .23877 .24765 L .24166 .24662 L F
.20496 .24914 m .20586 .24596 L .20784 .24802 L 0 .025 .124 r
F
.20496 .24914 m .20299 .24707 L .20586 .24596 L F
.5266 .25498 m .52801 .25192 L .52966 .25398 L 0 .037 .139 r
F
.5266 .25498 m .52495 .25289 L .52801 .25192 L F
.41938 .25317 m .42062 .2501 L .42238 .25211 L 0 .034 .135 r
F
.41938 .25317 m .41762 .25114 L .42062 .2501 L F
.28418 .25016 m .28522 .24687 L .28711 .24898 L 0 .027 .127 r
F
.28418 .25016 m .28229 .24803 L .28522 .24687 L F
.49086 .25448 m .49221 .25117 L .4939 .25349 L 0 .036 .137 r
F
.49086 .25448 m .48918 .25217 L .49221 .25117 L F
.81697 .24953 m .81884 .2464 L .82019 .24838 L 0 .026 .125 r
F
.81697 .24953 m .81562 .24753 L .81884 .2464 L F
.80922 .24998 m .81106 .24675 L .81242 .24875 L 0 .027 .126 r
F
.80922 .24998 m .80785 .24795 L .81106 .24675 L F
.75796 .25019 m .75973 .24712 L .76115 .24911 L 0 .028 .127 r
F
.75796 .25019 m .75655 .24819 L .75973 .24712 L F
.35566 .25151 m .3568 .24824 L .35862 .25047 L 0 .03 .13 r
F
.35566 .25151 m .35384 .24926 L .3568 .24824 L F
.67567 .25216 m .67731 .24902 L .67881 .25106 L 0 .032 .132 r
F
.67567 .25216 m .67417 .25012 L .67731 .24902 L F
.66791 .2526 m .66953 .2492 L .67104 .25133 L 0 .032 .133 r
F
.66791 .2526 m .6664 .25043 L .66953 .2492 L F
.31992 .25088 m .321 .24766 L .32286 .24983 L 0 .029 .129 r
F
.31992 .25088 m .31806 .24873 L .321 .24766 L F
.59338 .25416 m .59489 .25102 L .59648 .25319 L 0 .036 .137 r
F
.59338 .25416 m .59179 .25202 L .59489 .25102 L F
.16919 .24879 m .17004 .24558 L .17205 .24768 L 0 .025 .124 r
F
.16919 .24879 m .16718 .24667 L .17004 .24558 L F
.82475 .24925 m .82663 .2462 L .82797 .24814 L 0 .026 .125 r
F
.82475 .24925 m .82341 .24729 L .82663 .2462 L F
.21269 .24904 m .21359 .24593 L .21556 .248 L F
.21269 .24904 m .21072 .24698 L .21359 .24593 L F
.12569 .24862 m .12647 .24541 L .12852 .24747 L 0 .025 .123 r
F
.12569 .24862 m .12363 .24656 L .12647 .24541 L F
.29193 .24993 m .29296 .24683 L .29485 .24893 L 0 .027 .127 r
F
.29193 .24993 m .29004 .24783 L .29296 .24683 L F
.5206 .52829 m .52202 .50002 L .52367 .52014 L .8 .693 0 r
F
.5206 .52829 m .51896 .50743 L .52202 .50002 L F
.76574 .24999 m .76752 .24692 L .76892 .24888 L 0 .028 .127 r
F
.76574 .24999 m .76433 .24802 L .76752 .24692 L F
.62442 .25259 m .62598 .24947 L .62753 .25141 L 0 .033 .134 r
F
.62442 .25259 m .62287 .25064 L .62598 .24947 L F
.63994 .25174 m .64151 .24838 L .64305 .25049 L 0 .031 .131 r
F
.63994 .25174 m .6384 .24963 L .64151 .24838 L F
.63218 .25218 m .63375 .24898 L .63529 .25092 L 0 .032 .132 r
F
.63218 .25218 m .63064 .25024 L .63375 .24898 L F
.6912 .25153 m .69285 .24815 L .69434 .25025 L 0 .03 .13 r
F
.6912 .25153 m .68971 .24945 L .69285 .24815 L F
.24842 .24983 m .24939 .2466 L .25132 .24872 L 0 .027 .127 r
F
.24842 .24983 m .24649 .24772 L .24939 .2466 L F
.68344 .25199 m .68509 .2487 L .68658 .25076 L 0 .031 .132 r
F
.68344 .25199 m .68195 .24996 L .68509 .2487 L F
.45512 .25415 m .45641 .25093 L .45813 .2531 L 0 .036 .137 r
F
.45512 .25415 m .45339 .25199 L .45641 .25093 L F
.53436 .25501 m .53578 .2519 L .53742 .25397 L 0 .038 .14 r
F
.53436 .25501 m .53272 .25295 L .53578 .2519 L F
.42713 .25309 m .42838 .24996 L .43013 .25198 L 0 .034 .135 r
F
.42713 .25309 m .42538 .25104 L .42838 .24996 L F
.61666 .25309 m .61821 .24993 L .61976 .25185 L F
.61666 .25309 m .6151 .25115 L .61821 .24993 L F
.69896 .25118 m .70064 .24796 L .70211 .25006 L 0 .03 .13 r
F
.69896 .25118 m .69748 .24911 L .70064 .24796 L F
.13342 .24841 m .13421 .24522 L .13625 .2473 L 0 .025 .123 r
F
.13342 .24841 m .13137 .24633 L .13421 .24522 L F
.77351 .24971 m .77531 .24666 L .7767 .2486 L 0 .027 .127 r
F
.77351 .24971 m .77211 .24777 L .77531 .24666 L F
.17692 .24865 m .17778 .2454 L .17979 .24747 L 0 .025 .124 r
F
.17692 .24865 m .17491 .24657 L .17778 .2454 L F
.47839 .25297 m .47972 .24999 L .48142 .25197 L 0 .034 .135 r
F
.47839 .25297 m .47669 .251 L .47972 .24999 L F
.39138 .25255 m .39257 .24944 L .39436 .2516 L 0 .033 .134 r
F
.39138 .25255 m .3896 .25039 L .39257 .24944 L F
.60891 .25369 m .61044 .25042 L .612 .25236 L 0 .035 .136 r
F
.60891 .25369 m .60734 .25173 L .61044 .25042 L F
.47063 .25348 m .47195 .25025 L .47366 .25223 L F
.47063 .25348 m .46892 .25149 L .47195 .25025 L F
.51307 .53505 m .51147 .5167 L .51449 .52295 L .84 .582 0 r
F
.18466 .24835 m .18553 .24516 L .18753 .24722 L 0 .025 .123 r
F
.18466 .24835 m .18266 .24629 L .18553 .24516 L F
.25615 .24964 m .25714 .24637 L .25907 .24845 L 0 .027 .126 r
F
.25615 .24964 m .25423 .24754 L .25714 .24637 L F
.22041 .24902 m .22132 .24594 L .22328 .24799 L 0 .026 .125 r
F
.22041 .24902 m .21844 .24697 L .22132 .24594 L F
.46287 .25398 m .46418 .25064 L .46589 .25273 L 0 .036 .137 r
F
.46287 .25398 m .46115 .25187 L .46418 .25064 L F
.64771 .25164 m .6493 .24843 L .65084 .25059 L 0 .031 .132 r
F
.64771 .25164 m .64618 .24946 L .6493 .24843 L F
.78129 .24949 m .7831 .2465 L .78449 .24844 L 0 .027 .127 r
F
.78129 .24949 m .7799 .24755 L .7831 .2465 L F
.36339 .25165 m .36455 .24835 L .36636 .25054 L 0 .031 .131 r
F
.36339 .25165 m .36158 .24944 L .36455 .24835 L F
.60115 .25423 m .60267 .25105 L .60425 .25304 L 0 .037 .138 r
F
.60115 .25423 m .59957 .25222 L .60267 .25105 L F
.43488 .25295 m .43614 .24977 L .43789 .25185 L 0 .034 .135 r
F
.43488 .25295 m .43314 .25087 L .43614 .24977 L F
.70674 .25102 m .70842 .24773 L .70989 .24985 L 0 .03 .13 r
F
.70674 .25102 m .70527 .24891 L .70842 .24773 L F
.32764 .25102 m .32874 .24783 L .33058 .25003 L F
.32764 .25102 m .32579 .24883 L .32874 .24783 L F
.29965 .24997 m .30069 .24691 L .30258 .24895 L 0 .028 .128 r
F
.29965 .24997 m .29777 .24793 L .30069 .24691 L F
.55764 .25407 m .5591 .25074 L .56072 .25277 L 0 .036 .137 r
F
.55764 .25407 m .55602 .252 L .5591 .25074 L F
.2639 .24935 m .2649 .24612 L .26682 .24821 L 0 .027 .126 r
F
.2639 .24935 m .26198 .24729 L .2649 .24612 L F
.72226 .25022 m .72398 .24709 L .72542 .24901 L 0 .029 .128 r
F
.72226 .25022 m .72082 .2483 L .72398 .24709 L F
.56541 .25369 m .56687 .25036 L .56848 .25253 L 0 .035 .137 r
F
.56541 .25369 m .56379 .25157 L .56687 .25036 L F
.14113 .24832 m .14193 .24518 L .14397 .24725 L 0 .025 .124 r
F
.14113 .24832 m .13909 .24624 L .14193 .24518 L F
.54989 .25456 m .55132 .25115 L .55295 .25327 L 0 .037 .139 r
F
.54989 .25456 m .54825 .2524 L .55132 .25115 L F
.49862 .25482 m .49998 .25128 L .50166 .2536 L F
.49862 .25482 m .49694 .2525 L .49998 .25128 L F
.73003 .24988 m .73176 .24685 L .7332 .24882 L 0 .028 .128 r
F
.73003 .24988 m .72859 .24793 L .73176 .24685 L F
.54213 .25506 m .54355 .25156 L .54519 .25373 L 0 .038 .14 r
F
.54213 .25506 m .54049 .25286 L .54355 .25156 L F
.71451 .25077 m .7162 .24746 L .71766 .24955 L 0 .03 .13 r
F
.71451 .25077 m .71305 .24869 L .7162 .24746 L F
.78906 .24927 m .79088 .24616 L .79226 .24811 L 0 .027 .126 r
F
.78906 .24927 m .78769 .24733 L .79088 .24616 L F
.50638 .25447 m .50775 .25101 L .50942 .25319 L 0 .037 .139 r
F
.50638 .25447 m .5047 .2523 L .50775 .25101 L F
.19239 .24824 m .19326 .24514 L .19525 .24721 L 0 .025 .124 r
F
.19239 .24824 m .19039 .24618 L .19326 .24514 L F
.37113 .25151 m .3723 .24831 L .37411 .25039 L 0 .031 .132 r
F
.37113 .25151 m .36932 .24942 L .3723 .24831 L F
.51414 .2541 m .51552 .25066 L .51719 .25282 L 0 .036 .138 r
F
.51414 .2541 m .51247 .25192 L .51552 .25066 L F
.39912 .25262 m .40034 .2492 L .40211 .25142 L 0 .033 .134 r
F
.39912 .25262 m .39735 .2504 L .40034 .2492 L F
.22813 .24897 m .22907 .2458 L .23102 .24783 L 0 .026 .126 r
F
.22813 .24897 m .22617 .24696 L .22907 .2458 L F
.7378 .24963 m .73954 .24643 L .74097 .24842 L 0 .028 .127 r
F
.7378 .24963 m .73637 .24766 L .73954 .24643 L F
.27164 .2492 m .27264 .24604 L .27455 .24813 L 0 .027 .126 r
F
.27164 .2492 m .26973 .2471 L .27264 .24604 L F
.57317 .25351 m .57464 .25003 L .57625 .25225 L 0 .035 .136 r
F
.57317 .25351 m .57156 .25131 L .57464 .25003 L F
.79684 .24899 m .79867 .24593 L .80005 .24797 L 0 .027 .126 r
F
.79684 .24899 m .79546 .24694 L .79867 .24593 L F
.74557 .24921 m .74732 .24617 L .74875 .24819 L F
.74557 .24921 m .74414 .24722 L .74732 .24617 L F
.14886 .24817 m .14968 .24495 L .15171 .247 L 0 .025 .124 r
F
.14886 .24817 m .14682 .24611 L .14968 .24495 L F
.44263 .25291 m .44391 .24975 L .44564 .25189 L 0 .034 .136 r
F
.44263 .25291 m .4409 .2508 L .44391 .24975 L F
.33538 .25098 m .33649 .24771 L .33833 .24978 L 0 .03 .13 r
F
.33538 .25098 m .33353 .2489 L .33649 .24771 L F
.30738 .24992 m .30844 .24686 L .31032 .24888 L 0 .029 .128 r
F
.30738 .24992 m .30551 .24791 L .30844 .24686 L F
.48614 .25316 m .48749 .24997 L .48918 .25217 L 0 .035 .136 r
F
.48614 .25316 m .48445 .25097 L .48749 .24997 L F
.65549 .25167 m .65709 .24841 L .65862 .25056 L 0 .032 .132 r
F
.65549 .25167 m .65396 .24952 L .65709 .24841 L F
.58093 .25317 m .58242 .24987 L .58402 .25206 L 0 .035 .136 r
F
.58093 .25317 m .57933 .25099 L .58242 .24987 L F
.34313 .25061 m .34425 .24739 L .34609 .24944 L 0 .03 .13 r
F
.34313 .25061 m .34129 .24859 L .34425 .24739 L F
.5219 .25386 m .52329 .25073 L .52495 .25289 L 0 .037 .138 r
F
.5219 .25386 m .52024 .25171 L .52329 .25073 L F
.11309 .24764 m .11384 .24454 L .11591 .24659 L 0 .024 .123 r
F
.11309 .24764 m .11101 .24561 L .11384 .24454 L F
.37888 .25132 m .38005 .24835 L .38185 .25033 L 0 .032 .132 r
F
.37888 .25132 m .37708 .24937 L .38005 .24835 L F
.23587 .24874 m .23682 .24556 L .23877 .24765 L 0 .026 .125 r
F
.23587 .24874 m .23392 .24669 L .23682 .24556 L F
.1566 .2479 m .15743 .2447 L .15945 .24678 L 0 .025 .123 r
F
.1566 .2479 m .15457 .24584 L .15743 .2447 L F
.40687 .25245 m .4081 .24907 L .40987 .2513 L 0 .033 .134 r
F
.40687 .25245 m .4051 .25024 L .4081 .24907 L F
.20011 .24818 m .201 .24501 L .20299 .24707 L 0 .025 .124 r
F
.20011 .24818 m .19812 .24612 L .201 .24501 L F
.35089 .25035 m .35202 .24717 L .35384 .24926 L 0 .029 .129 r
F
.35089 .25035 m .34906 .24827 L .35202 .24717 L F
.27937 .24918 m .28039 .24593 L .28229 .24803 L 0 .027 .127 r
F
.27937 .24918 m .27747 .24706 L .28039 .24593 L F
.31512 .24982 m .3162 .24664 L .31806 .24873 L 0 .029 .128 r
F
.31512 .24982 m .31326 .24776 L .3162 .24664 L F
.41463 .2522 m .41586 .24911 L .41762 .25114 L 0 .033 .134 r
F
.41463 .2522 m .41286 .25015 L .41586 .24911 L F
.75336 .24921 m .75512 .24614 L .75655 .24819 L 0 .028 .127 r
F
.75336 .24921 m .75194 .24718 L .75512 .24614 L F
.5887 .25309 m .5902 .24987 L .59179 .25202 L 0 .035 .136 r
F
.5887 .25309 m .58711 .25096 L .5902 .24987 L F
.80464 .24902 m .80649 .24593 L .80785 .24795 L 0 .027 .127 r
F
.80464 .24902 m .80327 .24697 L .80649 .24593 L F
.16433 .24776 m .16517 .24456 L .16718 .24667 L 0 .025 .123 r
F
.16433 .24776 m .16231 .24566 L .16517 .24456 L F
.66327 .25165 m .66488 .24826 L .6664 .25043 L 0 .032 .133 r
F
.66327 .25165 m .66175 .24944 L .66488 .24826 L F
.20784 .24802 m .20874 .2449 L .21072 .24698 L 0 .025 .124 r
F
.20784 .24802 m .20586 .24596 L .20874 .2449 L F
.1208 .2476 m .12156 .24451 L .12363 .24656 L 0 .025 .123 r
F
.1208 .2476 m .11873 .24555 L .12156 .24451 L F
.45038 .25299 m .45167 .24983 L .45339 .25199 L 0 .035 .137 r
F
.45038 .25299 m .44865 .25086 L .45167 .24983 L F
.24359 .24874 m .24455 .24559 L .24649 .24772 L 0 .027 .126 r
F
.24359 .24874 m .24166 .24662 L .24455 .24559 L F
.67104 .25133 m .67266 .24802 L .67417 .25012 L 0 .032 .132 r
F
.67104 .25133 m .66953 .2492 L .67266 .24802 L F
.81242 .24875 m .81427 .24554 L .81562 .24753 L 0 .027 .126 r
F
.81242 .24875 m .81106 .24675 L .81427 .24554 L F
.38662 .25135 m .3878 .24838 L .3896 .25039 L 0 .032 .133 r
F
.38662 .25135 m .38483 .24935 L .3878 .24838 L F
.53363 .54786 m .53505 .5452 L .53667 .53909 L .887 .434 0 r
F
.53667 .53909 m .53505 .5452 L .53806 .52693 L .84 .582 0 r
F
.53505 .5452 m .53644 .53237 L .53806 .52693 L .868 .496 0 r
F
.28711 .24898 m .28815 .24573 L .29004 .24783 L 0 .027 .126 r
F
.28711 .24898 m .28522 .24687 L .28815 .24573 L F
.82019 .24838 m .82206 .24532 L .82341 .24729 L 0 .026 .125 r
F
.82019 .24838 m .81884 .2464 L .82206 .24532 L F
.52966 .25398 m .53107 .25088 L .53272 .25295 L 0 .038 .139 r
F
.52966 .25398 m .52801 .25192 L .53107 .25088 L F
.42238 .25211 m .42362 .24906 L .42538 .25104 L 0 .034 .135 r
F
.42238 .25211 m .42062 .2501 L .42362 .24906 L F
.76115 .24911 m .76293 .24605 L .76433 .24802 L 0 .028 .127 r
F
.76115 .24911 m .75973 .24712 L .76293 .24605 L F
.67881 .25106 m .68045 .24792 L .68195 .24996 L 0 .032 .132 r
F
.67881 .25106 m .67731 .24902 L .68045 .24792 L F
.69434 .25025 m .696 .24699 L .69748 .24911 L 0 .03 .13 r
F
.69434 .25025 m .69285 .24815 L .696 .24699 L F
.4939 .25349 m .49525 .25016 L .49694 .2525 L 0 .036 .138 r
F
.4939 .25349 m .49221 .25117 L .49525 .25016 L F
.35862 .25047 m .35976 .24722 L .36158 .24944 L 0 .03 .13 r
F
.35862 .25047 m .3568 .24824 L .35976 .24722 L F
.32286 .24983 m .32394 .24664 L .32579 .24883 L 0 .029 .129 r
F
.32286 .24983 m .321 .24766 L .32394 .24664 L F
.17205 .24768 m .1729 .24449 L .17491 .24657 L 0 .025 .124 r
F
.17205 .24768 m .17004 .24558 L .1729 .24449 L F
.63529 .25092 m .63686 .24769 L .6384 .24963 L 0 .031 .132 r
F
.63529 .25092 m .63375 .24898 L .63686 .24769 L F
.12852 .24747 m .12931 .24425 L .13137 .24633 L 0 .025 .123 r
F
.12852 .24747 m .12647 .24541 L .12931 .24425 L F
.64305 .25049 m .64464 .24735 L .64618 .24946 L 0 .031 .131 r
F
.64305 .25049 m .64151 .24838 L .64464 .24735 L F
.68658 .25076 m .68822 .24737 L .68971 .24945 L F
.68658 .25076 m .68509 .2487 L .68822 .24737 L F
.62753 .25141 m .62909 .2483 L .63064 .25024 L 0 .033 .133 r
F
.62753 .25141 m .62598 .24947 L .62909 .2483 L F
.61976 .25185 m .62132 .24872 L .62287 .25064 L 0 .033 .134 r
F
.61976 .25185 m .61821 .24993 L .62132 .24872 L F
.21556 .248 m .21647 .24489 L .21844 .24697 L 0 .026 .125 r
F
.21556 .248 m .21359 .24593 L .21647 .24489 L F
.76892 .24888 m .77072 .24582 L .77211 .24777 L 0 .028 .127 r
F
.76892 .24888 m .76752 .24692 L .77072 .24582 L F
.59648 .25319 m .59799 .25002 L .59957 .25222 L 0 .036 .138 r
F
.59648 .25319 m .59489 .25102 L .59799 .25002 L F
.612 .25236 m .61354 .24922 L .6151 .25115 L 0 .035 .136 r
F
.612 .25236 m .61044 .25042 L .61354 .24922 L F
.29485 .24893 m .29588 .24582 L .29777 .24793 L 0 .028 .127 r
F
.29485 .24893 m .29296 .24683 L .29588 .24582 L F
.25132 .24872 m .2523 .24544 L .25423 .24754 L 0 .027 .126 r
F
.25132 .24872 m .24939 .2466 L .2523 .24544 L F
.43013 .25198 m .43139 .24887 L .43314 .25087 L 0 .034 .135 r
F
.43013 .25198 m .42838 .24996 L .43139 .24887 L F
.70211 .25006 m .70379 .24679 L .70527 .24891 L 0 .03 .13 r
F
.70211 .25006 m .70064 .24796 L .70379 .24679 L F
.17979 .24747 m .18066 .24423 L .18266 .24629 L 0 .025 .123 r
F
.17979 .24747 m .17778 .2454 L .18066 .24423 L F
.47366 .25223 m .47498 .24902 L .47669 .251 L 0 .034 .135 r
F
.47366 .25223 m .47195 .25025 L .47498 .24902 L F
.45813 .2531 m .45943 .24972 L .46115 .25187 L 0 .036 .137 r
F
.45813 .2531 m .45641 .25093 L .45943 .24972 L F
.53742 .25397 m .53885 .25079 L .54049 .25286 L 0 .038 .14 r
F
.53742 .25397 m .53578 .2519 L .53885 .25079 L F
.13625 .2473 m .13704 .24417 L .13909 .24624 L 0 .025 .123 r
F
.13625 .2473 m .13421 .24522 L .13704 .24417 L F
.7767 .2486 m .77851 .24561 L .7799 .24755 L 0 .027 .127 r
F
.7767 .2486 m .77531 .24666 L .77851 .24561 L F
.46589 .25273 m .46721 .24941 L .46892 .25149 L 0 .035 .136 r
F
.46589 .25273 m .46418 .25064 L .46721 .24941 L F
.25907 .24845 m .26006 .2452 L .26198 .24729 L 0 .027 .126 r
F
.25907 .24845 m .25714 .24637 L .26006 .2452 L F
.56072 .25277 m .56217 .24953 L .56379 .25157 L 0 .036 .137 r
F
.56072 .25277 m .5591 .25074 L .56217 .24953 L F
.18753 .24722 m .1884 .24413 L .19039 .24618 L 0 .025 .123 r
F
.18753 .24722 m .18553 .24516 L .1884 .24413 L F
.60425 .25304 m .60577 .24975 L .60734 .25173 L 0 .036 .137 r
F
.60425 .25304 m .60267 .25105 L .60577 .24975 L F
.48142 .25197 m .48275 .24898 L .48445 .25097 L 0 .034 .135 r
F
.48142 .25197 m .47972 .24999 L .48275 .24898 L F
.55295 .25327 m .5544 .24993 L .55602 .252 L 0 .036 .138 r
F
.55295 .25327 m .55132 .25115 L .5544 .24993 L F
.70989 .24985 m .71158 .24655 L .71305 .24869 L 0 .03 .13 r
F
.70989 .24985 m .70842 .24773 L .71158 .24655 L F
.54519 .25373 m .54662 .25027 L .54825 .2524 L 0 .037 .139 r
F
.54519 .25373 m .54355 .25156 L .54662 .25027 L F
.72542 .24901 m .72715 .24599 L .72859 .24793 L 0 .028 .128 r
F
.72542 .24901 m .72398 .24709 L .72715 .24599 L F
.39436 .2516 m .39556 .24824 L .39735 .2504 L 0 .033 .134 r
F
.39436 .2516 m .39257 .24944 L .39556 .24824 L F
.36636 .25054 m .36752 .24725 L .36932 .24942 L 0 .031 .131 r
F
.36636 .25054 m .36455 .24835 L .36752 .24725 L F
.43789 .25185 m .43915 .24869 L .4409 .2508 L 0 .034 .135 r
F
.43789 .25185 m .43614 .24977 L .43915 .24869 L F
.22328 .24799 m .22421 .24492 L .22617 .24696 L 0 .026 .126 r
F
.22328 .24799 m .22132 .24594 L .22421 .24492 L F
.50166 .2536 m .50303 .25 L .5047 .2523 L 0 .037 .138 r
F
.50166 .2536 m .49998 .25128 L .50303 .25 L F
.26682 .24821 m .26782 .245 L .26973 .2471 L 0 .027 .126 r
F
.26682 .24821 m .2649 .24612 L .26782 .245 L F
.65084 .25059 m .65243 .24736 L .65396 .24952 L 0 .031 .132 r
F
.65084 .25059 m .6493 .24843 L .65243 .24736 L F
.56848 .25253 m .56995 .24911 L .57156 .25131 L 0 .035 .136 r
F
.56848 .25253 m .56687 .25036 L .56995 .24911 L F
.78449 .24844 m .78631 .24539 L .78769 .24733 L 0 .027 .127 r
F
.78449 .24844 m .7831 .2465 L .78631 .24539 L F
.50942 .25319 m .5108 .24975 L .51247 .25192 L 0 .036 .138 r
F
.50942 .25319 m .50775 .25101 L .5108 .24975 L F
.71766 .24955 m .71936 .24622 L .72082 .2483 L 0 .029 .129 r
F
.71766 .24955 m .7162 .24746 L .71936 .24622 L F
.30258 .24895 m .30362 .24587 L .30551 .24791 L 0 .028 .128 r
F
.30258 .24895 m .30069 .24691 L .30362 .24587 L F
.51719 .25282 m .51858 .24953 L .52024 .25171 L 0 .036 .137 r
F
.51719 .25282 m .51552 .25066 L .51858 .24953 L F
.33058 .25003 m .33169 .24671 L .33353 .2489 L 0 .03 .13 r
F
.33058 .25003 m .32874 .24783 L .33169 .24671 L F
.79226 .24811 m .79408 .24498 L .79546 .24694 L 0 .027 .126 r
F
.79226 .24811 m .79088 .24616 L .79408 .24498 L F
.14397 .24725 m .14478 .24405 L .14682 .24611 L 0 .025 .124 r
F
.14397 .24725 m .14193 .24518 L .14478 .24405 L F
.51337 .53717 m .51472 .54464 L .51637 .55425 L .868 .496 0 r
F
.57625 .25225 m .57773 .24874 L .57933 .25099 L 0 .034 .136 r
F
.57625 .25225 m .57464 .25003 L .57773 .24874 L F
.7332 .24882 m .73493 .24568 L .73637 .24766 L 0 .028 .128 r
F
.7332 .24882 m .73176 .24685 L .73493 .24568 L F
.40211 .25142 m .40333 .248 L .4051 .25024 L 0 .033 .134 r
F
.40211 .25142 m .40034 .2492 L .40333 .248 L F
.74097 .24842 m .74271 .2452 L .74414 .24722 L 0 .027 .127 r
F
.74097 .24842 m .73954 .24643 L .74271 .2452 L F
.37411 .25039 m .37527 .24727 L .37708 .24937 L 0 .031 .132 r
F
.37411 .25039 m .3723 .24831 L .37527 .24727 L F
.23102 .24783 m .23197 .24462 L .23392 .24669 L 0 .026 .125 r
F
.23102 .24783 m .22907 .2458 L .23197 .24462 L F
.33833 .24978 m .33945 .24651 L .34129 .24859 L 0 .03 .13 r
F
.33833 .24978 m .33649 .24771 L .33945 .24651 L F
.19525 .24721 m .19614 .24405 L .19812 .24612 L 0 .025 .124 r
F
.19525 .24721 m .19326 .24514 L .19614 .24405 L F
.15171 .247 m .15254 .24378 L .15457 .24584 L 0 .025 .123 r
F
.15171 .247 m .14968 .24495 L .15254 .24378 L F
.27455 .24813 m .27556 .24497 L .27747 .24706 L 0 .027 .126 r
F
.27455 .24813 m .27264 .24604 L .27556 .24497 L F
.34609 .24944 m .34722 .24619 L .34906 .24827 L 0 .029 .129 r
F
.34609 .24944 m .34425 .24739 L .34722 .24619 L F
.58402 .25206 m .58551 .24877 L .58711 .25096 L 0 .035 .136 r
F
.58402 .25206 m .58242 .24987 L .58551 .24877 L F
.80005 .24797 m .8019 .24494 L .80327 .24697 L 0 .027 .126 r
F
.80005 .24797 m .79867 .24593 L .8019 .24494 L F
.65862 .25056 m .66023 .2473 L .66175 .24944 L 0 .032 .132 r
F
.65862 .25056 m .65709 .24841 L .66023 .2473 L F
.51753 .52922 m .51591 .50837 L .51896 .50743 L .813 .659 0 r
F
.51449 .52295 m .51591 .50837 L .51753 .52922 L .8 .693 0 r
F
.74875 .24819 m .75051 .24514 L .75194 .24718 L 0 .027 .127 r
F
.74875 .24819 m .74732 .24617 L .75051 .24514 L F
.44564 .25189 m .44692 .24869 L .44865 .25086 L 0 .035 .136 r
F
.44564 .25189 m .44391 .24975 L .44692 .24869 L F
.31032 .24888 m .31138 .24572 L .31326 .24776 L 0 .029 .128 r
F
.31032 .24888 m .30844 .24686 L .31138 .24572 L F
.40987 .2513 m .4111 .2479 L .41286 .25015 L 0 .033 .134 r
F
.40987 .2513 m .4081 .24907 L .4111 .2479 L F
.15945 .24678 m .16029 .24356 L .16231 .24566 L 0 .025 .123 r
F
.15945 .24678 m .15743 .2447 L .16029 .24356 L F
.48918 .25217 m .49052 .24895 L .49221 .25117 L 0 .035 .136 r
F
.48918 .25217 m .48749 .24997 L .49052 .24895 L F
.23877 .24765 m .23972 .2445 L .24166 .24662 L 0 .026 .125 r
F
.23877 .24765 m .23682 .24556 L .23972 .2445 L F
.11591 .24659 m .11666 .2435 L .11873 .24555 L 0 .024 .123 r
F
.11591 .24659 m .11384 .24454 L .11666 .2435 L F
.20299 .24707 m .20388 .2439 L .20586 .24596 L 0 .025 .124 r
F
.20299 .24707 m .201 .24501 L .20388 .2439 L F
.52495 .25289 m .52635 .24974 L .52801 .25192 L 0 .037 .139 r
F
.52495 .25289 m .52329 .25073 L .52635 .24974 L F
.38185 .25033 m .38302 .24735 L .38483 .24935 L 0 .032 .133 r
F
.38185 .25033 m .38005 .24835 L .38302 .24735 L F
.35384 .24926 m .35498 .24617 L .3568 .24824 L 0 .03 .13 r
F
.35384 .24926 m .35202 .24717 L .35498 .24617 L F
.28229 .24803 m .28332 .24478 L .28522 .24687 L 0 .027 .126 r
F
.28229 .24803 m .28039 .24593 L .28332 .24478 L F
.6664 .25043 m .66801 .24707 L .66953 .2492 L 0 .032 .132 r
F
.6664 .25043 m .66488 .24826 L .66801 .24707 L F
.31806 .24873 m .31914 .24555 L .321 .24766 L 0 .029 .128 r
F
.31806 .24873 m .3162 .24664 L .31914 .24555 L F
.41762 .25114 m .41885 .24809 L .42062 .2501 L 0 .034 .135 r
F
.41762 .25114 m .41586 .24911 L .41885 .24809 L F
.59179 .25202 m .5933 .24884 L .59489 .25102 L 0 .035 .137 r
F
.59179 .25202 m .5902 .24987 L .5933 .24884 L F
.80785 .24795 m .8097 .24474 L .81106 .24675 L 0 .027 .126 r
F
.80785 .24795 m .80649 .24593 L .8097 .24474 L F
.16718 .24667 m .16803 .24348 L .17004 .24558 L 0 .025 .123 r
F
.16718 .24667 m .16517 .24456 L .16803 .24348 L F
.67417 .25012 m .67581 .24695 L .67731 .24902 L 0 .031 .132 r
F
.67417 .25012 m .67266 .24802 L .67581 .24695 L F
.81562 .24753 m .81749 .24442 L .81884 .2464 L 0 .027 .126 r
F
.81562 .24753 m .81427 .24554 L .81749 .24442 L F
.75655 .24819 m .75831 .24504 L .75973 .24712 L 0 .028 .127 r
F
.75655 .24819 m .75512 .24614 L .75831 .24504 L F
.29004 .24783 m .29107 .24472 L .29296 .24683 L 0 .027 .127 r
F
.29004 .24783 m .28815 .24573 L .29107 .24472 L F
.21072 .24698 m .21162 .24385 L .21359 .24593 L 0 .026 .124 r
F
.21072 .24698 m .20874 .2449 L .21162 .24385 L F
.12363 .24656 m .12441 .24334 L .12647 .24541 L 0 .025 .123 r
F
.12363 .24656 m .12156 .24451 L .12441 .24334 L F
.45339 .25199 m .45469 .24875 L .45641 .25093 L 0 .035 .137 r
F
.45339 .25199 m .45167 .24983 L .45469 .24875 L F
.6384 .24963 m .63998 .24643 L .64151 .24838 L 0 .031 .131 r
F
.6384 .24963 m .63686 .24769 L .63998 .24643 L F
.24649 .24772 m .24746 .24448 L .24939 .2466 L 0 .027 .126 r
F
.24649 .24772 m .24455 .24559 L .24746 .24448 L F
.82341 .24729 m .82529 .24425 L .82663 .2462 L 0 .026 .125 r
F
.82341 .24729 m .82206 .24532 L .82529 .24425 L F
.68971 .24945 m .69136 .24605 L .69285 .24815 L 0 .03 .13 r
F
.68971 .24945 m .68822 .24737 L .69136 .24605 L F
.53272 .25295 m .53413 .24983 L .53578 .2519 L 0 .038 .14 r
F
.53272 .25295 m .53107 .25088 L .53413 .24983 L F
.68195 .24996 m .68359 .24667 L .68509 .2487 L 0 .031 .132 r
F
.68195 .24996 m .68045 .24792 L .68359 .24667 L F
.76433 .24802 m .76612 .24496 L .76752 .24692 L 0 .028 .127 r
F
.76433 .24802 m .76293 .24605 L .76612 .24496 L F
.3896 .25039 m .39078 .2474 L .39257 .24944 L 0 .033 .133 r
F
.3896 .25039 m .3878 .24838 L .39078 .2474 L F
.42538 .25104 m .42662 .24801 L .42838 .24996 L 0 .034 .135 r
F
.42538 .25104 m .42362 .24906 L .42662 .24801 L F
.69748 .24911 m .69915 .24583 L .70064 .24796 L 0 .03 .13 r
F
.69748 .24911 m .696 .24699 L .69915 .24583 L F
.62287 .25064 m .62443 .24754 L .62598 .24947 L 0 .033 .134 r
F
.62287 .25064 m .62132 .24872 L .62443 .24754 L F
.13137 .24633 m .13216 .24313 L .13421 .24522 L 0 .025 .123 r
F
.13137 .24633 m .12931 .24425 L .13216 .24313 L F
.17491 .24657 m .17577 .24333 L .17778 .2454 L F
.17491 .24657 m .1729 .24449 L .17577 .24333 L F
.63064 .25024 m .6322 .24703 L .63375 .24898 L 0 .032 .133 r
F
.63064 .25024 m .62909 .2483 L .6322 .24703 L F
.6151 .25115 m .61665 .24802 L .61821 .24993 L 0 .034 .135 r
F
.6151 .25115 m .61354 .24922 L .61665 .24802 L F
.36158 .24944 m .36273 .24616 L .36455 .24835 L 0 .03 .131 r
F
.36158 .24944 m .35976 .24722 L .36273 .24616 L F
.64618 .24946 m .64777 .24633 L .6493 .24843 L 0 .031 .131 r
F
.64618 .24946 m .64464 .24735 L .64777 .24633 L F
.32579 .24883 m .32689 .24562 L .32874 .24783 L 0 .029 .129 r
F
.32579 .24883 m .32394 .24664 L .32689 .24562 L F
.49694 .2525 m .4983 .24896 L .49998 .25128 L 0 .036 .138 r
F
.49694 .2525 m .49525 .25016 L .4983 .24896 L F
.25423 .24754 m .25522 .24427 L .25714 .24637 L 0 .027 .126 r
F
.25423 .24754 m .2523 .24544 L .25522 .24427 L F
.47669 .251 m .47801 .248 L .47972 .24999 L 0 .034 .135 r
F
.47669 .251 m .47498 .24902 L .47801 .248 L F
.77211 .24777 m .77391 .24472 L .77531 .24666 L 0 .028 .127 r
F
.77211 .24777 m .77072 .24582 L .77391 .24472 L F
.46115 .25187 m .46246 .24851 L .46418 .25064 L 0 .035 .137 r
F
.46115 .25187 m .45943 .24972 L .46246 .24851 L F
.18266 .24629 m .18353 .24311 L .18553 .24516 L 0 .025 .123 r
F
.18266 .24629 m .18066 .24423 L .18353 .24311 L F
.21844 .24697 m .21936 .24388 L .22132 .24594 L 0 .026 .125 r
F
.21844 .24697 m .21647 .24489 L .21936 .24388 L F
.46892 .25149 m .47024 .2482 L .47195 .25025 L 0 .035 .136 r
F
.46892 .25149 m .46721 .24941 L .47024 .2482 L F
.70527 .24891 m .70694 .24561 L .70842 .24773 L 0 .03 .13 r
F
.70527 .24891 m .70379 .24679 L .70694 .24561 L F
.43314 .25087 m .43439 .24777 L .43614 .24977 L 0 .034 .135 r
F
.43314 .25087 m .43139 .24887 L .43439 .24777 L F
.60734 .25173 m .60887 .24845 L .61044 .25042 L 0 .035 .137 r
F
.60734 .25173 m .60577 .24975 L .60887 .24845 L F
.54825 .2524 m .54969 .24906 L .55132 .25115 L 0 .037 .138 r
F
.54825 .2524 m .54662 .25027 L .54969 .24906 L F
.54049 .25286 m .54191 .24953 L .54355 .25156 L 0 .038 .139 r
F
.54049 .25286 m .53885 .25079 L .54191 .24953 L F
.56379 .25157 m .56525 .24832 L .56687 .25036 L 0 .035 .136 r
F
.56379 .25157 m .56217 .24953 L .56525 .24832 L F
.55602 .252 m .55747 .24872 L .5591 .25074 L 0 .036 .137 r
F
.55602 .252 m .5544 .24993 L .55747 .24872 L F
.59957 .25222 m .60109 .24884 L .60267 .25105 L 0 .036 .138 r
F
.59957 .25222 m .59799 .25002 L .60109 .24884 L F
.29777 .24793 m .29881 .24481 L .30069 .24691 L 0 .028 .128 r
F
.29777 .24793 m .29588 .24582 L .29881 .24481 L F
.26198 .24729 m .26298 .24403 L .2649 .24612 L 0 .027 .126 r
F
.26198 .24729 m .26006 .2452 L .26298 .24403 L F
.13909 .24624 m .13988 .24311 L .14193 .24518 L 0 .025 .123 r
F
.13909 .24624 m .13704 .24417 L .13988 .24311 L F
.7799 .24755 m .78172 .24456 L .7831 .2465 L 0 .028 .127 r
F
.7799 .24755 m .77851 .24561 L .78172 .24456 L F
.5047 .2523 m .50608 .24873 L .50775 .25101 L 0 .036 .138 r
F
.5047 .2523 m .50303 .25 L .50608 .24873 L F
.39735 .2504 m .39856 .24703 L .40034 .2492 L 0 .033 .133 r
F
.39735 .2504 m .39556 .24824 L .39856 .24703 L F
.71305 .24869 m .71473 .24533 L .7162 .24746 L 0 .029 .129 r
F
.71305 .24869 m .71158 .24655 L .71473 .24533 L F
.51247 .25192 m .51385 .24848 L .51552 .25066 L 0 .036 .137 r
F
.51247 .25192 m .5108 .24975 L .51385 .24848 L F
.57156 .25131 m .57303 .2478 L .57464 .25003 L 0 .034 .136 r
F
.57156 .25131 m .56995 .24911 L .57303 .2478 L F
.72082 .2483 m .72252 .245 L .72398 .24709 L 0 .029 .128 r
F
.72082 .2483 m .71936 .24622 L .72252 .245 L F
.19039 .24618 m .19126 .24309 L .19326 .24514 L 0 .025 .124 r
F
.19039 .24618 m .1884 .24413 L .19126 .24309 L F
.36932 .24942 m .37049 .24616 L .3723 .24831 L 0 .031 .131 r
F
.36932 .24942 m .36752 .24725 L .37049 .24616 L F
.72859 .24793 m .73032 .24489 L .73176 .24685 L 0 .028 .128 r
F
.72859 .24793 m .72715 .24599 L .73032 .24489 L F
.48445 .25097 m .48579 .24796 L .48749 .24997 L 0 .035 .136 r
F
.48445 .25097 m .48275 .24898 L .48579 .24796 L F
.26973 .2471 m .27073 .24393 L .27264 .24604 L 0 .027 .126 r
F
.26973 .2471 m .26782 .245 L .27073 .24393 L F
.57933 .25099 m .58082 .24762 L .58242 .24987 L 0 .034 .135 r
F
.57933 .25099 m .57773 .24874 L .58082 .24762 L F
.78769 .24733 m .7895 .2442 L .79088 .24616 L 0 .027 .127 r
F
.78769 .24733 m .78631 .24539 L .7895 .2442 L F
.4409 .2508 m .44217 .2476 L .44391 .24975 L 0 .034 .135 r
F
.4409 .2508 m .43915 .24869 L .44217 .2476 L F
.65396 .24952 m .65557 .24626 L .65709 .24841 L 0 .031 .132 r
F
.65396 .24952 m .65243 .24736 L .65557 .24626 L F
.79546 .24694 m .7973 .24394 L .79867 .24593 L 0 .027 .126 r
F
.79546 .24694 m .79408 .24498 L .7973 .24394 L F
.22617 .24696 m .22711 .24376 L .22907 .2458 L 0 .026 .126 r
F
.22617 .24696 m .22421 .24492 L .22711 .24376 L F
.33353 .2489 m .33465 .24553 L .33649 .24771 L 0 .03 .13 r
F
.33353 .2489 m .33169 .24671 L .33465 .24553 L F
.52024 .25171 m .52163 .24851 L .52329 .25073 L 0 .036 .137 r
F
.52024 .25171 m .51858 .24953 L .52163 .24851 L F
.14682 .24611 m .14764 .24289 L .14968 .24495 L 0 .025 .123 r
F
.14682 .24611 m .14478 .24405 L .14764 .24289 L F
.74414 .24722 m .74589 .24414 L .74732 .24617 L 0 .027 .127 r
F
.74414 .24722 m .74271 .2452 L .74589 .24414 L F
.4051 .25024 m .40633 .24681 L .4081 .24907 L 0 .033 .133 r
F
.4051 .25024 m .40333 .248 L .40633 .24681 L F
.73637 .24766 m .7381 .24442 L .73954 .24643 L 0 .028 .127 r
F
.73637 .24766 m .73493 .24568 L .7381 .24442 L F
.30551 .24791 m .30656 .24484 L .30844 .24686 L 0 .029 .128 r
F
.30551 .24791 m .30362 .24587 L .30656 .24484 L F
.34129 .24859 m .34241 .2453 L .34425 .24739 L 0 .03 .13 r
F
.34129 .24859 m .33945 .24651 L .34241 .2453 L F
.23392 .24669 m .23487 .24347 L .23682 .24556 L 0 .026 .125 r
F
.23392 .24669 m .23197 .24462 L .23487 .24347 L F
.15457 .24584 m .1554 .24263 L .15743 .2447 L 0 .025 .123 r
F
.15457 .24584 m .15254 .24378 L .1554 .24263 L F
.34906 .24827 m .35018 .24508 L .35202 .24717 L 0 .029 .129 r
F
.34906 .24827 m .34722 .24619 L .35018 .24508 L F
.19812 .24612 m .19901 .24294 L .201 .24501 L 0 .025 .124 r
F
.19812 .24612 m .19614 .24405 L .19901 .24294 L F
.37708 .24937 m .37825 .24622 L .38005 .24835 L 0 .032 .132 r
F
.37708 .24937 m .37527 .24727 L .37825 .24622 L F
.27747 .24706 m .27849 .24384 L .28039 .24593 L 0 .027 .126 r
F
.27747 .24706 m .27556 .24497 L .27849 .24384 L F
.66175 .24944 m .66336 .24616 L .66488 .24826 L 0 .032 .132 r
F
.66175 .24944 m .66023 .2473 L .66336 .24616 L F
.58711 .25096 m .58861 .24768 L .5902 .24987 L 0 .035 .136 r
F
.58711 .25096 m .58551 .24877 L .58861 .24768 L F
.51753 .52922 m .51896 .50743 L .5206 .52829 L .813 .659 0 r
F
.31326 .24776 m .31433 .24457 L .3162 .24664 L 0 .028 .128 r
F
.31326 .24776 m .31138 .24572 L .31433 .24457 L F
.41286 .25015 m .41409 .24685 L .41586 .24911 L 0 .033 .134 r
F
.41286 .25015 m .4111 .2479 L .41409 .24685 L F
.16231 .24566 m .16315 .24245 L .16517 .24456 L 0 .025 .123 r
F
.16231 .24566 m .16029 .24356 L .16315 .24245 L F
.75194 .24718 m .7537 .24408 L .75512 .24614 L 0 .028 .127 r
F
.75194 .24718 m .75051 .24514 L .7537 .24408 L F
.80327 .24697 m .80512 .2439 L .80649 .24593 L 0 .027 .127 r
F
.80327 .24697 m .8019 .24494 L .80512 .2439 L F
.44865 .25086 m .44994 .24763 L .45167 .24983 L 0 .035 .136 r
F
.44865 .25086 m .44692 .24869 L .44994 .24763 L F
.20586 .24596 m .20676 .24282 L .20874 .2449 L 0 .025 .124 r
F
.20586 .24596 m .20388 .2439 L .20676 .24282 L F
.66953 .2492 m .67115 .24591 L .67266 .24802 L 0 .031 .132 r
F
.66953 .2492 m .66801 .24707 L .67115 .24591 L F
.24166 .24662 m .24262 .24344 L .24455 .24559 L 0 .026 .126 r
F
.24166 .24662 m .23972 .2445 L .24262 .24344 L F
.11873 .24555 m .11949 .24246 L .12156 .24451 L 0 .025 .123 r
F
.11873 .24555 m .11666 .2435 L .11949 .24246 L F
.49221 .25117 m .49357 .24793 L .49525 .25016 L 0 .036 .137 r
F
.49221 .25117 m .49052 .24895 L .49357 .24793 L F
.28522 .24687 m .28625 .24365 L .28815 .24573 L 0 .027 .126 r
F
.28522 .24687 m .28332 .24478 L .28625 .24365 L F
.3568 .24824 m .35794 .24515 L .35976 .24722 L 0 .03 .13 r
F
.3568 .24824 m .35498 .24617 L .35794 .24515 L F
.52801 .25192 m .52942 .24867 L .53107 .25088 L 0 .037 .139 r
F
.52801 .25192 m .52635 .24974 L .52942 .24867 L F
.81106 .24675 m .81291 .24354 L .81427 .24554 L 0 .027 .126 r
F
.81106 .24675 m .8097 .24474 L .81291 .24354 L F
.38483 .24935 m .386 .24636 L .3878 .24838 L 0 .032 .133 r
F
.38483 .24935 m .38302 .24735 L .386 .24636 L F
.321 .24766 m .32209 .2445 L .32394 .24664 L 0 .029 .129 r
F
.321 .24766 m .31914 .24555 L .32209 .2445 L F
.81884 .2464 m .82071 .24336 L .82206 .24532 L 0 .027 .126 r
F
.81884 .2464 m .81749 .24442 L .82071 .24336 L F
.69285 .24815 m .69451 .24488 L .696 .24699 L 0 .03 .13 r
F
.69285 .24815 m .69136 .24605 L .69451 .24488 L F
.67731 .24902 m .67895 .24587 L .68045 .24792 L 0 .031 .132 r
F
.67731 .24902 m .67581 .24695 L .67895 .24587 L F
.64151 .24838 m .64311 .24539 L .64464 .24735 L 0 .03 .131 r
F
.64151 .24838 m .63998 .24643 L .64311 .24539 L F
.42062 .2501 m .42185 .24708 L .42362 .24906 L 0 .034 .135 r
F
.42062 .2501 m .41885 .24809 L .42185 .24708 L F
.17004 .24558 m .17089 .24239 L .1729 .24449 L 0 .025 .123 r
F
.17004 .24558 m .16803 .24348 L .17089 .24239 L F
.75973 .24712 m .76151 .24394 L .76293 .24605 L 0 .028 .127 r
F
.75973 .24712 m .75831 .24504 L .76151 .24394 L F
.12647 .24541 m .12725 .24217 L .12931 .24425 L 0 .024 .123 r
F
.12647 .24541 m .12441 .24334 L .12725 .24217 L F
.59489 .25102 m .5964 .24781 L .59799 .25002 L 0 .036 .137 r
F
.59489 .25102 m .5933 .24884 L .5964 .24781 L F
.68509 .2487 m .68673 .24534 L .68822 .24737 L 0 .031 .131 r
F
.68509 .2487 m .68359 .24667 L .68673 .24534 L F
.21359 .24593 m .2145 .24281 L .21647 .24489 L 0 .026 .125 r
F
.21359 .24593 m .21162 .24385 L .2145 .24281 L F
.24939 .2466 m .25037 .24332 L .2523 .24544 L 0 .027 .126 r
F
.24939 .2466 m .24746 .24448 L .25037 .24332 L F
.63375 .24898 m .63532 .24574 L .63686 .24769 L 0 .031 .132 r
F
.63375 .24898 m .6322 .24703 L .63532 .24574 L F
.29296 .24683 m .294 .24371 L .29588 .24582 L 0 .027 .127 r
F
.29296 .24683 m .29107 .24472 L .294 .24371 L F
.45641 .25093 m .45771 .24756 L .45943 .24972 L 0 .035 .137 r
F
.45641 .25093 m .45469 .24875 L .45771 .24756 L F
.70064 .24796 m .70231 .24466 L .70379 .24679 L 0 .029 .129 r
F
.70064 .24796 m .69915 .24583 L .70231 .24466 L F
.62598 .24947 m .62754 .24635 L .62909 .2483 L 0 .033 .134 r
F
.62598 .24947 m .62443 .24754 L .62754 .24635 L F
.61821 .24993 m .61976 .24682 L .62132 .24872 L 0 .034 .135 r
F
.61821 .24993 m .61665 .24802 L .61976 .24682 L F
.17778 .2454 m .17865 .24217 L .18066 .24423 L 0 .025 .123 r
F
.17778 .2454 m .17577 .24333 L .17865 .24217 L F
.76752 .24692 m .76932 .24386 L .77072 .24582 L 0 .028 .127 r
F
.76752 .24692 m .76612 .24496 L .76932 .24386 L F
.42838 .24996 m .42963 .24695 L .43139 .24887 L 0 .034 .135 r
F
.42838 .24996 m .42662 .24801 L .42963 .24695 L F
.53578 .2519 m .5372 .24873 L .53885 .25079 L 0 .038 .14 r
F
.53578 .2519 m .53413 .24983 L .5372 .24873 L F
.13421 .24522 m .135 .24206 L .13704 .24417 L 0 .025 .123 r
F
.13421 .24522 m .13216 .24313 L .135 .24206 L F
.49998 .25128 m .50135 .2477 L .50303 .25 L 0 .036 .137 r
F
.49998 .25128 m .4983 .24896 L .50135 .2477 L F
.61044 .25042 m .61198 .24727 L .61354 .24922 L 0 .035 .136 r
F
.61044 .25042 m .60887 .24845 L .61198 .24727 L F
.46418 .25064 m .46549 .24731 L .46721 .24941 L F
.46418 .25064 m .46246 .24851 L .46549 .24731 L F
.25714 .24637 m .25814 .2431 L .26006 .2452 L 0 .027 .126 r
F
.25714 .24637 m .25522 .24427 L .25814 .2431 L F
.47195 .25025 m .47327 .24698 L .47498 .24902 L 0 .034 .135 r
F
.47195 .25025 m .47024 .2482 L .47327 .24698 L F
.54355 .25156 m .54498 .24827 L .54662 .25027 L 0 .037 .139 r
F
.54355 .25156 m .54191 .24953 L .54498 .24827 L F
.55132 .25115 m .55277 .24789 L .5544 .24993 L 0 .036 .138 r
F
.55132 .25115 m .54969 .24906 L .55277 .24789 L F
.36455 .24835 m .3657 .24508 L .36752 .24725 L 0 .03 .131 r
F
.36455 .24835 m .36273 .24616 L .3657 .24508 L F
.39257 .24944 m .39377 .24621 L .39556 .24824 L 0 .033 .134 r
F
.39257 .24944 m .39078 .2474 L .39377 .24621 L F
.5591 .25074 m .56055 .2475 L .56217 .24953 L 0 .035 .137 r
F
.5591 .25074 m .55747 .24872 L .56055 .2475 L F
.70842 .24773 m .7101 .24442 L .71158 .24655 L 0 .029 .129 r
F
.70842 .24773 m .70694 .24561 L .7101 .24442 L F
.77531 .24666 m .77712 .24367 L .77851 .24561 L 0 .028 .127 r
F
.77531 .24666 m .77391 .24472 L .77712 .24367 L F
.18553 .24516 m .18639 .24208 L .1884 .24413 L 0 .025 .123 r
F
.18553 .24516 m .18353 .24311 L .18639 .24208 L F
.50775 .25101 m .50913 .2475 L .5108 .24975 L 0 .036 .137 r
F
.50775 .25101 m .50608 .24873 L .50913 .2475 L F
.56687 .25036 m .56834 .24706 L .56995 .24911 L 0 .035 .136 r
F
.56687 .25036 m .56525 .24832 L .56834 .24706 L F
.6493 .24843 m .6509 .24526 L .65243 .24736 L 0 .031 .131 r
F
.6493 .24843 m .64777 .24633 L .6509 .24526 L F
.60267 .25105 m .60419 .24753 L .60577 .24975 L 0 .036 .137 r
F
.60267 .25105 m .60109 .24884 L .60419 .24753 L F
.32874 .24783 m .32984 .24451 L .33169 .24671 L 0 .03 .13 r
F
.32874 .24783 m .32689 .24562 L .32984 .24451 L F
.43614 .24977 m .43741 .24666 L .43915 .24869 L 0 .034 .135 r
F
.43614 .24977 m .43439 .24777 L .43741 .24666 L F
.47972 .24999 m .48105 .24698 L .48275 .24898 L 0 .034 .136 r
F
.47972 .24999 m .47801 .248 L .48105 .24698 L F
.2649 .24612 m .2659 .24291 L .26782 .245 L 0 .026 .126 r
F
.2649 .24612 m .26298 .24403 L .2659 .24291 L F
.51552 .25066 m .51691 .24734 L .51858 .24953 L 0 .035 .137 r
F
.51552 .25066 m .51385 .24848 L .51691 .24734 L F
.57464 .25003 m .57612 .24649 L .57773 .24874 L 0 .034 .135 r
F
.57464 .25003 m .57303 .2478 L .57612 .24649 L F
.22132 .24594 m .22224 .24286 L .22421 .24492 L 0 .026 .125 r
F
.22132 .24594 m .21936 .24388 L .22224 .24286 L F
.7162 .24746 m .71789 .24409 L .71936 .24622 L 0 .029 .129 r
F
.7162 .24746 m .71473 .24533 L .71789 .24409 L F
.40034 .2492 m .40156 .24582 L .40333 .248 L 0 .032 .133 r
F
.40034 .2492 m .39856 .24703 L .40156 .24582 L F
.72398 .24709 m .72569 .24391 L .72715 .24599 L 0 .028 .128 r
F
.72398 .24709 m .72252 .245 L .72569 .24391 L F
.14193 .24518 m .14274 .24198 L .14478 .24405 L 0 .025 .123 r
F
.14193 .24518 m .13988 .24311 L .14274 .24198 L F
.30069 .24691 m .30174 .24379 L .30362 .24587 L 0 .028 .128 r
F
.30069 .24691 m .29881 .24481 L .30174 .24379 L F
.7831 .2465 m .78492 .24344 L .78631 .24539 L 0 .028 .127 r
F
.7831 .2465 m .78172 .24456 L .78492 .24344 L F
.79088 .24616 m .79271 .24301 L .79408 .24498 L 0 .027 .126 r
F
.79088 .24616 m .7895 .2442 L .79271 .24301 L F
.3723 .24831 m .37346 .24509 L .37527 .24727 L 0 .031 .131 r
F
.3723 .24831 m .37049 .24616 L .37346 .24509 L F
.33649 .24771 m .33761 .24435 L .33945 .24651 L 0 .03 .13 r
F
.33649 .24771 m .33465 .24553 L .33761 .24435 L F
.58242 .24987 m .58391 .24652 L .58551 .24877 L 0 .034 .135 r
F
.58242 .24987 m .58082 .24762 L .58391 .24652 L F
.73176 .24685 m .73349 .24369 L .73493 .24568 L 0 .028 .128 r
F
.73176 .24685 m .73032 .24489 L .73349 .24369 L F
.52444 .55063 m .52585 .56433 L .52751 .55759 L .917 .331 0 r
F
.52444 .55063 m .52278 .55705 L .52585 .56433 L F
.73954 .24643 m .74127 .24317 L .74271 .2452 L 0 .027 .127 r
F
.73954 .24643 m .7381 .24442 L .74127 .24317 L F
.19326 .24514 m .19414 .24201 L .19614 .24405 L 0 .025 .124 r
F
.19326 .24514 m .19126 .24309 L .19414 .24201 L F
.22907 .2458 m .23001 .24257 L .23197 .24462 L 0 .026 .125 r
F
.22907 .2458 m .22711 .24376 L .23001 .24257 L F
.14968 .24495 m .1505 .24174 L .15254 .24378 L 0 .025 .123 r
F
.14968 .24495 m .14764 .24289 L .1505 .24174 L F
.27264 .24604 m .27365 .24287 L .27556 .24497 L 0 .027 .126 r
F
.27264 .24604 m .27073 .24393 L .27365 .24287 L F
.65709 .24841 m .6587 .24516 L .66023 .2473 L 0 .031 .132 r
F
.65709 .24841 m .65557 .24626 L .6587 .24516 L F
.4081 .24907 m .40933 .24561 L .4111 .2479 L 0 .032 .133 r
F
.4081 .24907 m .40633 .24681 L .40933 .24561 L F
.44391 .24975 m .44518 .24652 L .44692 .24869 L 0 .034 .135 r
F
.44391 .24975 m .44217 .2476 L .44518 .24652 L F
.48749 .24997 m .48883 .24692 L .49052 .24895 L 0 .035 .136 r
F
.48749 .24997 m .48579 .24796 L .48883 .24692 L F
.34425 .24739 m .34538 .24409 L .34722 .24619 L 0 .029 .129 r
F
.34425 .24739 m .34241 .2453 L .34538 .24409 L F
.79867 .24593 m .80052 .24293 L .8019 .24494 L 0 .027 .126 r
F
.79867 .24593 m .7973 .24394 L .80052 .24293 L F
.74732 .24617 m .74908 .24309 L .75051 .24514 L 0 .027 .127 r
F
.74732 .24617 m .74589 .24414 L .74908 .24309 L F
.52329 .25073 m .5247 .24749 L .52635 .24974 L 0 .036 .138 r
F
.52329 .25073 m .52163 .24851 L .5247 .24749 L F
.23682 .24556 m .23777 .24238 L .23972 .2445 L 0 .026 .125 r
F
.23682 .24556 m .23487 .24347 L .23777 .24238 L F
.15743 .2447 m .15826 .24147 L .16029 .24356 L 0 .024 .123 r
F
.15743 .2447 m .1554 .24263 L .15826 .24147 L F
.30844 .24686 m .3095 .24368 L .31138 .24572 L 0 .029 .128 r
F
.30844 .24686 m .30656 .24484 L .3095 .24368 L F
.201 .24501 m .2019 .24183 L .20388 .2439 L 0 .025 .124 r
F
.201 .24501 m .19901 .24294 L .2019 .24183 L F
.35202 .24717 m .35314 .24408 L .35498 .24617 L 0 .029 .129 r
F
.35202 .24717 m .35018 .24508 L .35314 .24408 L F
.66488 .24826 m .6665 .245 L .66801 .24707 L 0 .031 .132 r
F
.66488 .24826 m .66336 .24616 L .6665 .245 L F
.28039 .24593 m .28142 .2427 L .28332 .24478 L 0 .027 .126 r
F
.28039 .24593 m .27849 .24384 L .28142 .2427 L F
.38005 .24835 m .38122 .2452 L .38302 .24735 L 0 .032 .132 r
F
.38005 .24835 m .37825 .24622 L .38122 .2452 L F
.5902 .24987 m .59171 .24662 L .5933 .24884 L 0 .035 .136 r
F
.5902 .24987 m .58861 .24768 L .59171 .24662 L F
.3162 .24664 m .31728 .24345 L .31914 .24555 L 0 .028 .128 r
F
.3162 .24664 m .31433 .24457 L .31728 .24345 L F
.16517 .24456 m .16601 .24137 L .16803 .24348 L 0 .025 .123 r
F
.16517 .24456 m .16315 .24245 L .16601 .24137 L F
.67266 .24802 m .6743 .24487 L .67581 .24695 L 0 .031 .132 r
F
.67266 .24802 m .67115 .24591 L .6743 .24487 L F
.41586 .24911 m .41709 .24586 L .41885 .24809 L 0 .033 .134 r
F
.41586 .24911 m .41409 .24685 L .41709 .24586 L F
.75512 .24614 m .75689 .24296 L .75831 .24504 L 0 .028 .127 r
F
.75512 .24614 m .7537 .24408 L .75689 .24296 L F
.80649 .24593 m .80833 .24271 L .8097 .24474 L 0 .027 .126 r
F
.80649 .24593 m .80512 .2439 L .80833 .24271 L F
.45167 .24983 m .45296 .24654 L .45469 .24875 L 0 .035 .136 r
F
.45167 .24983 m .44994 .24763 L .45296 .24654 L F
.28815 .24573 m .28918 .24262 L .29107 .24472 L 0 .027 .126 r
F
.28815 .24573 m .28625 .24365 L .28918 .24262 L F
.81427 .24554 m .81613 .24244 L .81749 .24442 L F
.81427 .24554 m .81291 .24354 L .81613 .24244 L F
.20874 .2449 m .20965 .24175 L .21162 .24385 L 0 .025 .124 r
F
.20874 .2449 m .20676 .24282 L .20965 .24175 L F
.24455 .24559 m .24552 .24233 L .24746 .24448 L 0 .027 .126 r
F
.24455 .24559 m .24262 .24344 L .24552 .24233 L F
.12156 .24451 m .12234 .24127 L .12441 .24334 L 0 .025 .123 r
F
.12156 .24451 m .11949 .24246 L .12234 .24127 L F
.49525 .25016 m .49661 .24674 L .4983 .24896 L 0 .035 .137 r
F
.49525 .25016 m .49357 .24793 L .49661 .24674 L F
.68822 .24737 m .68987 .24401 L .69136 .24605 L 0 .03 .13 r
F
.68822 .24737 m .68673 .24534 L .68987 .24401 L F
.696 .24699 m .69767 .24371 L .69915 .24583 L 0 .029 .129 r
F
.696 .24699 m .69451 .24488 L .69767 .24371 L F
.53107 .25088 m .53248 .2476 L .53413 .24983 L 0 .037 .139 r
F
.53107 .25088 m .52942 .24867 L .53248 .2476 L F
.35976 .24722 m .36091 .24411 L .36273 .24616 L 0 .03 .13 r
F
.35976 .24722 m .35794 .24515 L .36091 .24411 L F
.63686 .24769 m .63844 .24447 L .63998 .24643 L 0 .031 .131 r
F
.63686 .24769 m .63532 .24574 L .63844 .24447 L F
.82206 .24532 m .82395 .2423 L .82529 .24425 L 0 .027 .126 r
F
.82206 .24532 m .82071 .24336 L .82395 .2423 L F
.12931 .24425 m .1301 .24103 L .13216 .24313 L 0 .024 .123 r
F
.12931 .24425 m .12725 .24217 L .1301 .24103 L F
.68045 .24792 m .6821 .24465 L .68359 .24667 L 0 .031 .132 r
F
.68045 .24792 m .67895 .24587 L .6821 .24465 L F
.32394 .24664 m .32503 .24346 L .32689 .24562 L 0 .029 .129 r
F
.32394 .24664 m .32209 .2445 L .32503 .24346 L F
.1729 .24449 m .17376 .24124 L .17577 .24333 L 0 .025 .123 r
F
.1729 .24449 m .17089 .24239 L .17376 .24124 L F
.3878 .24838 m .38898 .24537 L .39078 .2474 L 0 .033 .133 r
F
.3878 .24838 m .386 .24636 L .38898 .24537 L F
.42362 .24906 m .42486 .24605 L .42662 .24801 L 0 .034 .135 r
F
.42362 .24906 m .42185 .24708 L .42486 .24605 L F
.76293 .24605 m .7647 .24284 L .76612 .24496 L 0 .028 .127 r
F
.76293 .24605 m .76151 .24394 L .7647 .24284 L F
.45943 .24972 m .46074 .24637 L .46246 .24851 L 0 .035 .136 r
F
.45943 .24972 m .45771 .24756 L .46074 .24637 L F
.64464 .24735 m .64624 .24435 L .64777 .24633 L 0 .031 .131 r
F
.64464 .24735 m .64311 .24539 L .64624 .24435 L F
.2523 .24544 m .25329 .24216 L .25522 .24427 L 0 .027 .126 r
F
.2523 .24544 m .25037 .24332 L .25329 .24216 L F
.50303 .25 m .5044 .24645 L .50608 .24873 L 0 .035 .137 r
F
.50303 .25 m .50135 .2477 L .5044 .24645 L F
.62132 .24872 m .62287 .24561 L .62443 .24754 L 0 .033 .134 r
F
.62132 .24872 m .61976 .24682 L .62287 .24561 L F
.59799 .25002 m .5995 .24661 L .60109 .24884 L 0 .036 .137 r
F
.59799 .25002 m .5964 .24781 L .5995 .24661 L F
.62909 .2483 m .63066 .24507 L .6322 .24703 L 0 .032 .133 r
F
.62909 .2483 m .62754 .24635 L .63066 .24507 L F
.70379 .24679 m .70546 .24347 L .70694 .24561 L 0 .029 .129 r
F
.70379 .24679 m .70231 .24466 L .70546 .24347 L F
.54662 .25027 m .54806 .2471 L .54969 .24906 L 0 .037 .138 r
F
.54662 .25027 m .54498 .24827 L .54806 .2471 L F
.18066 .24423 m .18152 .24105 L .18353 .24311 L 0 .025 .123 r
F
.18066 .24423 m .17865 .24217 L .18152 .24105 L F
.46721 .24941 m .46852 .24611 L .47024 .2482 L 0 .035 .136 r
F
.46721 .24941 m .46549 .24731 L .46852 .24611 L F
.21647 .24489 m .21739 .2418 L .21936 .24388 L 0 .026 .125 r
F
.21647 .24489 m .2145 .24281 L .21739 .2418 L F
.61354 .24922 m .61509 .24609 L .61665 .24802 L 0 .034 .136 r
F
.61354 .24922 m .61198 .24727 L .61509 .24609 L F
.47498 .24902 m .47631 .24593 L .47801 .248 L 0 .034 .135 r
F
.47498 .24902 m .47327 .24698 L .47631 .24593 L F
.77072 .24582 m .77252 .24277 L .77391 .24472 L 0 .028 .127 r
F
.77072 .24582 m .76932 .24386 L .77252 .24277 L F
.29588 .24582 m .29692 .24271 L .29881 .24481 L F
.29588 .24582 m .294 .24371 L .29692 .24271 L F
.53885 .25079 m .54027 .2475 L .54191 .24953 L 0 .038 .139 r
F
.53885 .25079 m .5372 .24873 L .54027 .2475 L F
.5544 .24993 m .55585 .24672 L .55747 .24872 L 0 .036 .137 r
F
.5544 .24993 m .55277 .24789 L .55585 .24672 L F
.26006 .2452 m .26106 .24194 L .26298 .24403 L 0 .026 .125 r
F
.26006 .2452 m .25814 .2431 L .26106 .24194 L F
.43139 .24887 m .43264 .24585 L .43439 .24777 L 0 .034 .135 r
F
.43139 .24887 m .42963 .24695 L .43264 .24585 L F
.56217 .24953 m .56364 .24629 L .56525 .24832 L 0 .035 .136 r
F
.56217 .24953 m .56055 .2475 L .56364 .24629 L F
.39556 .24824 m .39677 .24501 L .39856 .24703 L 0 .032 .133 r
F
.39556 .24824 m .39377 .24621 L .39677 .24501 L F
.5108 .24975 m .51218 .24627 L .51385 .24848 L 0 .035 .136 r
F
.5108 .24975 m .50913 .2475 L .51218 .24627 L F
.60577 .24975 m .60729 .24623 L .60887 .24845 L F
.60577 .24975 m .60419 .24753 L .60729 .24623 L F
.56995 .24911 m .57142 .24575 L .57303 .2478 L 0 .034 .135 r
F
.56995 .24911 m .56834 .24706 L .57142 .24575 L F
.13704 .24417 m .13784 .24099 L .13988 .24311 L 0 .025 .123 r
F
.13704 .24417 m .135 .24206 L .13784 .24099 L F
.71158 .24655 m .71326 .24319 L .71473 .24533 L 0 .029 .129 r
F
.71158 .24655 m .7101 .24442 L .71326 .24319 L F
.57773 .24874 m .57921 .24536 L .58082 .24762 L 0 .033 .134 r
F
.57773 .24874 m .57612 .24649 L .57921 .24536 L F
.36752 .24725 m .36868 .244 L .37049 .24616 L 0 .03 .131 r
F
.36752 .24725 m .3657 .24508 L .36868 .244 L F
.71936 .24622 m .72106 .24288 L .72252 .245 L 0 .028 .128 r
F
.71936 .24622 m .71789 .24409 L .72106 .24288 L F
.77851 .24561 m .78033 .24261 L .78172 .24456 L 0 .028 .127 r
F
.77851 .24561 m .77712 .24367 L .78033 .24261 L F
.40333 .248 m .40455 .24461 L .40633 .24681 L 0 .032 .133 r
F
.40333 .248 m .40156 .24582 L .40455 .24461 L F
.33169 .24671 m .3328 .24336 L .33465 .24553 L 0 .029 .129 r
F
.33169 .24671 m .32984 .24451 L .3328 .24336 L F
.1884 .24413 m .18926 .24105 L .19126 .24309 L 0 .025 .124 r
F
.1884 .24413 m .18639 .24208 L .18926 .24105 L F
.65243 .24736 m .65404 .24415 L .65557 .24626 L 0 .031 .131 r
F
.65243 .24736 m .6509 .24526 L .65404 .24415 L F
.51858 .24953 m .51997 .24628 L .52163 .24851 L 0 .035 .137 r
F
.51858 .24953 m .51691 .24734 L .51997 .24628 L F
.26782 .245 m .26882 .24186 L .27073 .24393 L 0 .026 .126 r
F
.26782 .245 m .2659 .24291 L .26882 .24186 L F
.43915 .24869 m .44042 .24554 L .44217 .2476 L 0 .034 .135 r
F
.43915 .24869 m .43741 .24666 L .44042 .24554 L F
.51972 .54982 m .5211 .56352 L .52278 .55705 L .917 .331 0 r
F
.51972 .54982 m .51804 .55597 L .5211 .56352 L F
.48275 .24898 m .48409 .24595 L .48579 .24796 L 0 .035 .136 r
F
.48275 .24898 m .48105 .24698 L .48409 .24595 L F
.72715 .24599 m .72887 .24281 L .73032 .24489 L 0 .028 .128 r
F
.72715 .24599 m .72569 .24391 L .72887 .24281 L F
.14478 .24405 m .14559 .24083 L .14764 .24289 L 0 .025 .123 r
F
.14478 .24405 m .14274 .24198 L .14559 .24083 L F
.22421 .24492 m .22514 .2417 L .22711 .24376 L 0 .026 .125 r
F
.22421 .24492 m .22224 .24286 L .22514 .2417 L F
.78631 .24539 m .78812 .24223 L .7895 .2442 L 0 .027 .127 r
F
.78631 .24539 m .78492 .24344 L .78812 .24223 L F
.79408 .24498 m .79592 .24195 L .7973 .24394 L 0 .027 .126 r
F
.79408 .24498 m .79271 .24301 L .79592 .24195 L F
.74271 .2452 m .74446 .24209 L .74589 .24414 L F
.74271 .2452 m .74127 .24317 L .74446 .24209 L F
.33945 .24651 m .34057 .24315 L .34241 .2453 L 0 .029 .129 r
F
.33945 .24651 m .33761 .24435 L .34057 .24315 L F
.30362 .24587 m .30468 .24277 L .30656 .24484 L 0 .028 .128 r
F
.30362 .24587 m .30174 .24379 L .30468 .24277 L F
.73493 .24568 m .73666 .24241 L .7381 .24442 L 0 .028 .127 r
F
.73493 .24568 m .73349 .24369 L .73666 .24241 L F
.23197 .24462 m .23292 .24141 L .23487 .24347 L 0 .026 .125 r
F
.23197 .24462 m .23001 .24257 L .23292 .24141 L F
.15254 .24378 m .15336 .24058 L .1554 .24263 L 0 .024 .123 r
F
.15254 .24378 m .1505 .24174 L .15336 .24058 L F
.4111 .2479 m .41233 .24457 L .41409 .24685 L 0 .032 .133 r
F
.4111 .2479 m .40933 .24561 L .41233 .24457 L F
.58551 .24877 m .58701 .24543 L .58861 .24768 L 0 .034 .135 r
F
.58551 .24877 m .58391 .24652 L .58701 .24543 L F
.37527 .24727 m .37644 .24401 L .37825 .24622 L 0 .031 .132 r
F
.37527 .24727 m .37346 .24509 L .37644 .24401 L F
.34722 .24619 m .34835 .24297 L .35018 .24508 L 0 .029 .129 r
F
.34722 .24619 m .34538 .24409 L .34835 .24297 L F
.19614 .24405 m .19702 .24091 L .19901 .24294 L 0 .025 .124 r
F
.19614 .24405 m .19414 .24201 L .19702 .24091 L F
.66023 .2473 m .66184 .24405 L .66336 .24616 L 0 .031 .132 r
F
.66023 .2473 m .6587 .24516 L .66184 .24405 L F
.27556 .24497 m .27658 .24176 L .27849 .24384 L 0 .027 .126 r
F
.27556 .24497 m .27365 .24287 L .27658 .24176 L F
.44692 .24869 m .4482 .24543 L .44994 .24763 L 0 .034 .135 r
F
.44692 .24869 m .44518 .24652 L .4482 .24543 L F
.53008 .53999 m .53145 .51277 L .53312 .52169 L .84 .582 0 r
F
.53008 .53999 m .52841 .53038 L .53145 .51277 L F
.49052 .24895 m .49187 .24588 L .49357 .24793 L 0 .035 .136 r
F
.49052 .24895 m .48883 .24692 L .49187 .24588 L F
.16029 .24356 m .16112 .24036 L .16315 .24245 L 0 .024 .123 r
F
.16029 .24356 m .15826 .24147 L .16112 .24036 L F
.31138 .24572 m .31245 .2425 L .31433 .24457 L 0 .028 .128 r
F
.31138 .24572 m .3095 .24368 L .31245 .2425 L F
.66801 .24707 m .66964 .24389 L .67115 .24591 L 0 .031 .132 r
F
.66801 .24707 m .6665 .245 L .66964 .24389 L F
.75051 .24514 m .75227 .242 L .7537 .24408 L 0 .027 .127 r
F
.75051 .24514 m .74908 .24309 L .75227 .242 L F
.23972 .2445 m .24068 .2413 L .24262 .24344 L 0 .026 .125 r
F
.23972 .2445 m .23777 .24238 L .24068 .2413 L F
.8019 .24494 m .80375 .24187 L .80512 .2439 L 0 .027 .127 r
F
.8019 .24494 m .80052 .24293 L .80375 .24187 L F
.20388 .2439 m .20478 .24074 L .20676 .24282 L 0 .025 .124 r
F
.20388 .2439 m .2019 .24183 L .20478 .24074 L F
.52635 .24974 m .52776 .24638 L .52942 .24867 L 0 .037 .138 r
F
.52635 .24974 m .5247 .24749 L .52776 .24638 L F
.28332 .24478 m .28435 .24158 L .28625 .24365 L 0 .027 .126 r
F
.28332 .24478 m .28142 .2427 L .28435 .24158 L F
.35498 .24617 m .35611 .24308 L .35794 .24515 L 0 .03 .13 r
F
.35498 .24617 m .35314 .24408 L .35611 .24308 L F
.31914 .24555 m .32022 .24237 L .32209 .2445 L 0 .028 .128 r
F
.31914 .24555 m .31728 .24345 L .32022 .24237 L F
.8097 .24474 m .81154 .24153 L .81291 .24354 L 0 .027 .126 r
F
.8097 .24474 m .80833 .24271 L .81154 .24153 L F
.5933 .24884 m .59481 .24557 L .5964 .24781 L 0 .035 .136 r
F
.5933 .24884 m .59171 .24662 L .59481 .24557 L F
.69136 .24605 m .69303 .24285 L .69451 .24488 L 0 .029 .129 r
F
.69136 .24605 m .68987 .24401 L .69303 .24285 L F
.38302 .24735 m .3842 .24419 L .386 .24636 L 0 .032 .133 r
F
.38302 .24735 m .38122 .2452 L .3842 .24419 L F
.16803 .24348 m .16887 .24028 L .17089 .24239 L 0 .025 .123 r
F
.16803 .24348 m .16601 .24137 L .16887 .24028 L F
.67581 .24695 m .67745 .24382 L .67895 .24587 L 0 .031 .132 r
F
.67581 .24695 m .6743 .24487 L .67745 .24382 L F
.75831 .24504 m .76008 .24183 L .76151 .24394 L 0 .028 .127 r
F
.75831 .24504 m .75689 .24296 L .76008 .24183 L F
.12441 .24334 m .12519 .24009 L .12725 .24217 L 0 .024 .123 r
F
.12441 .24334 m .12234 .24127 L .12519 .24009 L F
.81749 .24442 m .81936 .2414 L .82071 .24336 L 0 .027 .126 r
F
.81749 .24442 m .81613 .24244 L .81936 .2414 L F
.41885 .24809 m .42009 .24486 L .42185 .24708 L 0 .034 .135 r
F
.41885 .24809 m .41709 .24586 L .42009 .24486 L F
.4983 .24896 m .49966 .2455 L .50135 .2477 L 0 .035 .136 r
F
.4983 .24896 m .49661 .24674 L .49966 .2455 L F
.45469 .24875 m .45598 .24539 L .45771 .24756 L F
.45469 .24875 m .45296 .24654 L .45598 .24539 L F
.24746 .24448 m .24844 .24118 L .25037 .24332 L 0 .026 .126 r
F
.24746 .24448 m .24552 .24233 L .24844 .24118 L F
.63998 .24643 m .64157 .24342 L .64311 .24539 L 0 .031 .131 r
F
.63998 .24643 m .63844 .24447 L .64157 .24342 L F
.21162 .24385 m .21253 .2407 L .2145 .24281 L 0 .026 .124 r
F
.21162 .24385 m .20965 .24175 L .21253 .2407 L F
.29107 .24472 m .2921 .24159 L .294 .24371 L 0 .027 .127 r
F
.29107 .24472 m .28918 .24262 L .2921 .24159 L F
.68359 .24667 m .68524 .24334 L .68673 .24534 L 0 .031 .131 r
F
.68359 .24667 m .6821 .24465 L .68524 .24334 L F
.69915 .24583 m .70082 .24252 L .70231 .24466 L 0 .029 .129 r
F
.69915 .24583 m .69767 .24371 L .70082 .24252 L F
.46246 .24851 m .46377 .2452 L .46549 .24731 L 0 .035 .136 r
F
.46246 .24851 m .46074 .24637 L .46377 .2452 L F
.17577 .24333 m .17664 .24008 L .17865 .24217 L 0 .025 .123 r
F
.17577 .24333 m .17376 .24124 L .17664 .24008 L F
.50608 .24873 m .50745 .24525 L .50913 .2475 L 0 .035 .136 r
F
.50608 .24873 m .5044 .24645 L .50745 .24525 L F
.13216 .24313 m .13294 .23994 L .135 .24206 L 0 .024 .123 r
F
.13216 .24313 m .1301 .24103 L .13294 .23994 L F
.36273 .24616 m .36388 .24305 L .3657 .24508 L 0 .03 .13 r
F
.36273 .24616 m .36091 .24411 L .36388 .24305 L F
.53413 .24983 m .53555 .24649 L .5372 .24873 L 0 .037 .139 r
F
.53413 .24983 m .53248 .2476 L .53555 .24649 L F
.6322 .24703 m .63377 .24375 L .63532 .24574 L 0 .032 .132 r
F
.6322 .24703 m .63066 .24507 L .63377 .24375 L F
.25522 .24427 m .25621 .24099 L .25814 .2431 L 0 .026 .125 r
F
.25522 .24427 m .25329 .24216 L .25621 .24099 L F
.62443 .24754 m .62599 .2444 L .62754 .24635 L 0 .033 .134 r
F
.62443 .24754 m .62287 .24561 L .62599 .2444 L F
.60109 .24884 m .6026 .24531 L .60419 .24753 L 0 .035 .136 r
F
.60109 .24884 m .5995 .24661 L .6026 .24531 L F
.70694 .24561 m .70863 .24228 L .7101 .24442 L 0 .029 .129 r
F
.70694 .24561 m .70546 .24347 L .70863 .24228 L F
.47024 .2482 m .47156 .24492 L .47327 .24698 L 0 .034 .135 r
F
.47024 .2482 m .46852 .24611 L .47156 .24492 L F
.76612 .24496 m .7679 .24174 L .76932 .24386 L 0 .028 .127 r
F
.76612 .24496 m .7647 .24284 L .7679 .24174 L F
.54969 .24906 m .55114 .24597 L .55277 .24789 L 0 .036 .138 r
F
.54969 .24906 m .54806 .2471 L .55114 .24597 L F
.32689 .24562 m .32799 .24234 L .32984 .24451 L 0 .029 .129 r
F
.32689 .24562 m .32503 .24346 L .32799 .24234 L F
.42662 .24801 m .42787 .24502 L .42963 .24695 L 0 .034 .135 r
F
.42662 .24801 m .42486 .24605 L .42787 .24502 L F
.57303 .2478 m .57451 .24443 L .57612 .24649 L 0 .033 .134 r
F
.57303 .2478 m .57142 .24575 L .57451 .24443 L F
.60887 .24845 m .6104 .24507 L .61198 .24727 L 0 .035 .136 r
F
.60887 .24845 m .60729 .24623 L .6104 .24507 L F
.61665 .24802 m .6182 .24489 L .61976 .24682 L 0 .034 .135 r
F
.61665 .24802 m .61509 .24609 L .6182 .24489 L F
.54191 .24953 m .54334 .24627 L .54498 .24827 L 0 .037 .139 r
F
.54191 .24953 m .54027 .2475 L .54334 .24627 L F
.39078 .2474 m .39198 .24418 L .39377 .24621 L 0 .033 .134 r
F
.39078 .2474 m .38898 .24537 L .39198 .24418 L F
.51385 .24848 m .51524 .24512 L .51691 .24734 L 0 .035 .136 r
F
.51385 .24848 m .51218 .24627 L .51524 .24512 L F
.64777 .24633 m .64937 .24326 L .6509 .24526 L 0 .031 .131 r
F
.64777 .24633 m .64624 .24435 L .64937 .24326 L F
.55747 .24872 m .55893 .2455 L .56055 .2475 L 0 .036 .137 r
F
.55747 .24872 m .55585 .24672 L .55893 .2455 L F
.18353 .24311 m .18439 .24003 L .18639 .24208 L 0 .025 .123 r
F
.18353 .24311 m .18152 .24105 L .18439 .24003 L F
.56525 .24832 m .56672 .24503 L .56834 .24706 L 0 .035 .136 r
F
.56525 .24832 m .56364 .24629 L .56672 .24503 L F
.39856 .24703 m .39977 .2438 L .40156 .24582 L 0 .032 .133 r
F
.39856 .24703 m .39677 .24501 L .39977 .2438 L F
.26298 .24403 m .26398 .24082 L .2659 .24291 L 0 .026 .125 r
F
.26298 .24403 m .26106 .24194 L .26398 .24082 L F
.71473 .24533 m .71642 .24196 L .71789 .24409 L 0 .028 .128 r
F
.71473 .24533 m .71326 .24319 L .71642 .24196 L F
.77391 .24472 m .77573 .24171 L .77712 .24367 L 0 .028 .127 r
F
.77391 .24472 m .77252 .24277 L .77573 .24171 L F
.21936 .24388 m .22027 .24079 L .22224 .24286 L 0 .026 .125 r
F
.21936 .24388 m .21739 .2418 L .22027 .24079 L F
.43439 .24777 m .43565 .2447 L .43741 .24666 L 0 .034 .135 r
F
.43439 .24777 m .43264 .24585 L .43565 .2447 L F
.47801 .248 m .47934 .24488 L .48105 .24698 L 0 .034 .136 r
F
.47801 .248 m .47631 .24593 L .47934 .24488 L F
.72252 .245 m .72423 .24179 L .72569 .24391 L 0 .028 .128 r
F
.72252 .245 m .72106 .24288 L .72423 .24179 L F
.29881 .24481 m .29985 .24171 L .30174 .24379 L F
.29881 .24481 m .29692 .24271 L .29985 .24171 L F
.58082 .24762 m .58231 .24427 L .58391 .24652 L 0 .033 .134 r
F
.58082 .24762 m .57921 .24536 L .58231 .24427 L F
.13988 .24311 m .14069 .23987 L .14274 .24198 L 0 .025 .123 r
F
.13988 .24311 m .13784 .24099 L .14069 .23987 L F
.37049 .24616 m .37166 .2429 L .37346 .24509 L 0 .031 .131 r
F
.37049 .24616 m .36868 .244 L .37166 .2429 L F
.40633 .24681 m .40756 .2434 L .40933 .24561 L 0 .032 .132 r
F
.40633 .24681 m .40455 .24461 L .40756 .2434 L F
.33465 .24553 m .33576 .2422 L .33761 .24435 L 0 .029 .129 r
F
.33465 .24553 m .3328 .24336 L .33576 .2422 L F
.65557 .24626 m .65717 .24304 L .6587 .24516 L 0 .031 .131 r
F
.65557 .24626 m .65404 .24415 L .65717 .24304 L F
.51611 .54199 m .51449 .52295 L .51753 .52922 L .868 .496 0 r
F
.51307 .53505 m .51449 .52295 L .51611 .54199 L .84 .582 0 r
F
.78172 .24456 m .78353 .24148 L .78492 .24344 L 0 .028 .127 r
F
.78172 .24456 m .78033 .24261 L .78353 .24148 L F
.27073 .24393 m .27173 .24082 L .27365 .24287 L 0 .027 .126 r
F
.27073 .24393 m .26882 .24186 L .27173 .24082 L F
.44217 .2476 m .44344 .24442 L .44518 .24652 L 0 .034 .135 r
F
.44217 .2476 m .44042 .24554 L .44344 .24442 L F
.19126 .24309 m .19214 .23998 L .19414 .24201 L 0 .025 .124 r
F
.19126 .24309 m .18926 .24105 L .19214 .23998 L F
.14764 .24289 m .14845 .23969 L .1505 .24174 L 0 .025 .123 r
F
.14764 .24289 m .14559 .24083 L .14845 .23969 L F
.22711 .24376 m .22805 .24053 L .23001 .24257 L 0 .026 .125 r
F
.22711 .24376 m .22514 .2417 L .22805 .24053 L F
.52163 .24851 m .52303 .24523 L .5247 .24749 L 0 .036 .137 r
F
.52163 .24851 m .51997 .24628 L .52303 .24523 L F
.7895 .2442 m .79133 .24102 L .79271 .24301 L 0 .027 .126 r
F
.7895 .2442 m .78812 .24223 L .79133 .24102 L F
.7381 .24442 m .73983 .24113 L .74127 .24317 L 0 .027 .127 r
F
.7381 .24442 m .73666 .24241 L .73983 .24113 L F
.34241 .2453 m .34354 .24195 L .34538 .24409 L 0 .029 .129 r
F
.34241 .2453 m .34057 .24315 L .34354 .24195 L F
.73032 .24489 m .73204 .24162 L .73349 .24369 L 0 .028 .128 r
F
.73032 .24489 m .72887 .24281 L .73204 .24162 L F
.48579 .24796 m .48713 .24489 L .48883 .24692 L 0 .035 .136 r
F
.48579 .24796 m .48409 .24595 L .48713 .24489 L F
.23487 .24347 m .23582 .24031 L .23777 .24238 L 0 .026 .125 r
F
.23487 .24347 m .23292 .24141 L .23582 .24031 L F
.1554 .24263 m .15623 .23942 L .15826 .24147 L 0 .024 .123 r
F
.1554 .24263 m .15336 .24058 L .15623 .23942 L F
.74589 .24414 m .74765 .24101 L .74908 .24309 L 0 .027 .127 r
F
.74589 .24414 m .74446 .24209 L .74765 .24101 L F
.7973 .24394 m .79915 .24092 L .80052 .24293 L 0 .027 .126 r
F
.7973 .24394 m .79592 .24195 L .79915 .24092 L F
.52534 .5392 m .52674 .51202 L .52841 .53038 L .84 .582 0 r
F
.52534 .5392 m .52367 .52014 L .52674 .51202 L F
.30656 .24484 m .30762 .24161 L .3095 .24368 L 0 .028 .128 r
F
.30656 .24484 m .30468 .24277 L .30762 .24161 L F
.66336 .24616 m .66498 .24294 L .6665 .245 L 0 .031 .132 r
F
.66336 .24616 m .66184 .24405 L .66498 .24294 L F
.35018 .24508 m .35131 .24198 L .35314 .24408 L 0 .029 .129 r
F
.35018 .24508 m .34835 .24297 L .35131 .24198 L F
.58861 .24768 m .59011 .24436 L .59171 .24662 L 0 .034 .135 r
F
.58861 .24768 m .58701 .24543 L .59011 .24436 L F
.19901 .24294 m .1999 .2398 L .2019 .24183 L 0 .025 .124 r
F
.19901 .24294 m .19702 .24091 L .1999 .2398 L F
.41409 .24685 m .41533 .24359 L .41709 .24586 L 0 .033 .133 r
F
.41409 .24685 m .41233 .24457 L .41533 .24359 L F
.27849 .24384 m .27951 .24063 L .28142 .2427 L 0 .027 .126 r
F
.27849 .24384 m .27658 .24176 L .27951 .24063 L F
.37825 .24622 m .37942 .24297 L .38122 .2452 L 0 .031 .132 r
F
.37825 .24622 m .37644 .24401 L .37942 .24297 L F
.31433 .24457 m .31541 .24135 L .31728 .24345 L 0 .028 .128 r
F
.31433 .24457 m .31245 .2425 L .31541 .24135 L F
.44994 .24763 m .45123 .24433 L .45296 .24654 L 0 .034 .135 r
F
.44994 .24763 m .4482 .24543 L .45123 .24433 L F
.16315 .24245 m .16399 .23928 L .16601 .24137 L 0 .024 .123 r
F
.16315 .24245 m .16112 .24036 L .16399 .23928 L F
.67115 .24591 m .67279 .24286 L .6743 .24487 L 0 .031 .132 r
F
.67115 .24591 m .66964 .24389 L .67279 .24286 L F
.49357 .24793 m .49492 .2447 L .49661 .24674 L 0 .035 .136 r
F
.49357 .24793 m .49187 .24588 L .49492 .2447 L F
.28625 .24365 m .28728 .24052 L .28918 .24262 L 0 .027 .126 r
F
.28625 .24365 m .28435 .24158 L .28728 .24052 L F
.7537 .24408 m .75546 .24086 L .75689 .24296 L 0 .027 .127 r
F
.7537 .24408 m .75227 .242 L .75546 .24086 L F
.24262 .24344 m .24359 .24018 L .24552 .24233 L 0 .026 .125 r
F
.24262 .24344 m .24068 .2413 L .24359 .24018 L F
.20676 .24282 m .20767 .23964 L .20965 .24175 L 0 .025 .124 r
F
.20676 .24282 m .20478 .24074 L .20767 .23964 L F
.80512 .2439 m .80696 .24067 L .80833 .24271 L 0 .027 .126 r
F
.80512 .2439 m .80375 .24187 L .80696 .24067 L F
.52942 .24867 m .53083 .24527 L .53248 .2476 L 0 .037 .138 r
F
.52942 .24867 m .52776 .24638 L .53083 .24527 L F
.81291 .24354 m .81477 .24043 L .81613 .24244 L 0 .027 .126 r
F
.81291 .24354 m .81154 .24153 L .81477 .24043 L F
.69451 .24488 m .69618 .24169 L .69767 .24371 L 0 .029 .129 r
F
.69451 .24488 m .69303 .24285 L .69618 .24169 L F
.50135 .2477 m .50272 .24427 L .5044 .24645 L 0 .035 .136 r
F
.50135 .2477 m .49966 .2455 L .50272 .24427 L F
.68673 .24534 m .68838 .24204 L .68987 .24401 L 0 .03 .13 r
F
.68673 .24534 m .68524 .24334 L .68838 .24204 L F
.32209 .2445 m .32317 .2413 L .32503 .24346 L 0 .029 .128 r
F
.32209 .2445 m .32022 .24237 L .32317 .2413 L F
.35794 .24515 m .35908 .24205 L .36091 .24411 L 0 .03 .13 r
F
.35794 .24515 m .35611 .24308 L .35908 .24205 L F
.45771 .24756 m .45901 .24423 L .46074 .24637 L 0 .035 .136 r
F
.45771 .24756 m .45598 .24539 L .45901 .24423 L F
.12725 .24217 m .12804 .23893 L .1301 .24103 L 0 .024 .122 r
F
.12725 .24217 m .12519 .24009 L .12804 .23893 L F
.17089 .24239 m .17175 .23914 L .17376 .24124 L 0 .025 .123 r
F
.17089 .24239 m .16887 .24028 L .17175 .23914 L F
.5964 .24781 m .59791 .24438 L .5995 .24661 L 0 .035 .136 r
F
.5964 .24781 m .59481 .24557 L .59791 .24438 L F
.67895 .24587 m .6806 .24262 L .6821 .24465 L 0 .031 .132 r
F
.67895 .24587 m .67745 .24382 L .6806 .24262 L F
.76151 .24394 m .76328 .24072 L .7647 .24284 L 0 .028 .127 r
F
.76151 .24394 m .76008 .24183 L .76328 .24072 L F
.25037 .24332 m .25136 .24003 L .25329 .24216 L 0 .026 .125 r
F
.25037 .24332 m .24844 .24118 L .25136 .24003 L F
.386 .24636 m .38719 .24318 L .38898 .24537 L 0 .032 .133 r
F
.386 .24636 m .3842 .24419 L .38719 .24318 L F
.63532 .24574 m .6369 .24247 L .63844 .24447 L 0 .031 .131 r
F
.63532 .24574 m .63377 .24375 L .6369 .24247 L F
.82071 .24336 m .8226 .24036 L .82395 .2423 L 0 .027 .126 r
F
.82071 .24336 m .81936 .2414 L .8226 .24036 L F
.70231 .24466 m .70398 .24133 L .70546 .24347 L 0 .029 .129 r
F
.70231 .24466 m .70082 .24252 L .70398 .24133 L F
.50913 .2475 m .51051 .24405 L .51218 .24627 L 0 .034 .135 r
F
.50913 .2475 m .50745 .24525 L .51051 .24405 L F
.42185 .24708 m .4231 .24385 L .42486 .24605 L F
.42185 .24708 m .42009 .24486 L .4231 .24385 L F
.46549 .24731 m .46681 .24402 L .46852 .24611 L F
.46549 .24731 m .46377 .2452 L .46681 .24402 L F
.60419 .24753 m .60571 .24401 L .60729 .24623 L 0 .034 .136 r
F
.60419 .24753 m .6026 .24531 L .60571 .24401 L F
.64311 .24539 m .6447 .24237 L .64624 .24435 L 0 .031 .131 r
F
.64311 .24539 m .64157 .24342 L .6447 .24237 L F
.2145 .24281 m .21542 .23967 L .21739 .2418 L 0 .026 .125 r
F
.2145 .24281 m .21253 .2407 L .21542 .23967 L F
.17865 .24217 m .17951 .23897 L .18152 .24105 L 0 .024 .123 r
F
.17865 .24217 m .17664 .24008 L .17951 .23897 L F
.57612 .24649 m .5776 .24331 L .57921 .24536 L 0 .033 .134 r
F
.57612 .24649 m .57451 .24443 L .5776 .24331 L F
.294 .24371 m .29503 .24058 L .29692 .24271 L 0 .027 .127 r
F
.294 .24371 m .2921 .24159 L .29503 .24058 L F
.54498 .24827 m .54642 .24513 L .54806 .2471 L 0 .037 .138 r
F
.54498 .24827 m .54334 .24627 L .54642 .24513 L F
.47327 .24698 m .4746 .24383 L .47631 .24593 L 0 .034 .135 r
F
.47327 .24698 m .47156 .24492 L .4746 .24383 L F
.25814 .2431 m .25913 .23982 L .26106 .24194 L 0 .026 .125 r
F
.25814 .2431 m .25621 .24099 L .25913 .23982 L F
.62754 .24635 m .62911 .24309 L .63066 .24507 L 0 .033 .133 r
F
.62754 .24635 m .62599 .2444 L .62911 .24309 L F
.5372 .24873 m .53862 .24529 L .54027 .2475 L 0 .037 .139 r
F
.5372 .24873 m .53555 .24649 L .53862 .24529 L F
.7101 .24442 m .71179 .24107 L .71326 .24319 L 0 .029 .128 r
F
.7101 .24442 m .70863 .24228 L .71179 .24107 L F
.3657 .24508 m .36685 .24198 L .36868 .244 L 0 .03 .13 r
F
.3657 .24508 m .36388 .24305 L .36685 .24198 L F
.135 .24206 m .13579 .23885 L .13784 .24099 L 0 .024 .123 r
F
.135 .24206 m .13294 .23994 L .13579 .23885 L F
.55277 .24789 m .55422 .24482 L .55585 .24672 L 0 .036 .138 r
F
.55277 .24789 m .55114 .24597 L .55422 .24482 L F
.61976 .24682 m .62132 .24365 L .62287 .24561 L 0 .034 .135 r
F
.61976 .24682 m .6182 .24489 L .62132 .24365 L F
.61198 .24727 m .61351 .24391 L .61509 .24609 L F
.61198 .24727 m .6104 .24507 L .61351 .24391 L F
.56834 .24706 m .56981 .24372 L .57142 .24575 L F
.56834 .24706 m .56672 .24503 L .56981 .24372 L F
.56055 .2475 m .56201 .24427 L .56364 .24629 L 0 .035 .136 r
F
.56055 .2475 m .55893 .2455 L .56201 .24427 L F
.39377 .24621 m .39497 .24298 L .39677 .24501 L 0 .032 .133 r
F
.39377 .24621 m .39198 .24418 L .39497 .24298 L F
.76932 .24386 m .7711 .24064 L .77252 .24277 L 0 .028 .127 r
F
.76932 .24386 m .7679 .24174 L .7711 .24064 L F
.32984 .24451 m .33095 .2412 L .3328 .24336 L 0 .029 .129 r
F
.32984 .24451 m .32799 .24234 L .33095 .2412 L F
.71789 .24409 m .71959 .24075 L .72106 .24288 L 0 .028 .128 r
F
.71789 .24409 m .71642 .24196 L .71959 .24075 L F
.40156 .24582 m .40277 .24259 L .40455 .24461 L 0 .032 .132 r
F
.40156 .24582 m .39977 .2438 L .40277 .24259 L F
.51691 .24734 m .51831 .24405 L .51997 .24628 L 0 .035 .136 r
F
.51691 .24734 m .51524 .24512 L .51831 .24405 L F
.42963 .24695 m .43088 .24392 L .43264 .24585 L 0 .034 .136 r
F
.42963 .24695 m .42787 .24502 L .43088 .24392 L F
.6509 .24526 m .65251 .24213 L .65404 .24415 L 0 .031 .131 r
F
.6509 .24526 m .64937 .24326 L .65251 .24213 L F
.2659 .24291 m .26689 .23979 L .26882 .24186 L 0 .026 .125 r
F
.2659 .24291 m .26398 .24082 L .26689 .23979 L F
.18639 .24208 m .18726 .239 L .18926 .24105 L 0 .025 .123 r
F
.18639 .24208 m .18439 .24003 L .18726 .239 L F
.43741 .24666 m .43867 .24355 L .44042 .24554 L 0 .034 .135 r
F
.43741 .24666 m .43565 .2447 L .43867 .24355 L F
.77712 .24367 m .77894 .24066 L .78033 .24261 L 0 .028 .128 r
F
.77712 .24367 m .77573 .24171 L .77894 .24066 L F
.40933 .24561 m .41056 .24236 L .41233 .24457 L 0 .032 .132 r
F
.40933 .24561 m .40756 .2434 L .41056 .24236 L F
.72569 .24391 m .72741 .2407 L .72887 .24281 L 0 .028 .128 r
F
.72569 .24391 m .72423 .24179 L .72741 .2407 L F
.33761 .24435 m .33873 .241 L .34057 .24315 L 0 .029 .129 r
F
.33761 .24435 m .33576 .2422 L .33873 .241 L F
.14274 .24198 m .14355 .23873 L .14559 .24083 L 0 .025 .123 r
F
.14274 .24198 m .14069 .23987 L .14355 .23873 L F
.58391 .24652 m .58541 .24318 L .58701 .24543 L 0 .033 .134 r
F
.58391 .24652 m .58231 .24427 L .58541 .24318 L F
.22224 .24286 m .22317 .23964 L .22514 .2417 L 0 .026 .125 r
F
.22224 .24286 m .22027 .24079 L .22317 .23964 L F
.48105 .24698 m .48239 .24381 L .48409 .24595 L 0 .035 .136 r
F
.48105 .24698 m .47934 .24488 L .48239 .24381 L F
.37346 .24509 m .37464 .24181 L .37644 .24401 L 0 .031 .131 r
F
.37346 .24509 m .37166 .2429 L .37464 .24181 L F
.30174 .24379 m .30279 .2407 L .30468 .24277 L 0 .028 .128 r
F
.30174 .24379 m .29985 .24171 L .30279 .2407 L F
.74127 .24317 m .74302 .24003 L .74446 .24209 L 0 .027 .126 r
F
.74127 .24317 m .73983 .24113 L .74302 .24003 L F
.6587 .24516 m .66032 .24196 L .66184 .24405 L 0 .031 .131 r
F
.6587 .24516 m .65717 .24304 L .66032 .24196 L F
.78492 .24344 m .78674 .24026 L .78812 .24223 L 0 .028 .127 r
F
.78492 .24344 m .78353 .24148 L .78674 .24026 L F
.23001 .24257 m .23096 .23937 L .23292 .24141 L 0 .026 .125 r
F
.23001 .24257 m .22805 .24053 L .23096 .23937 L F
.79271 .24301 m .79454 .23995 L .79592 .24195 L 0 .027 .126 r
F
.79271 .24301 m .79133 .24102 L .79454 .23995 L F
.34538 .24409 m .34651 .24084 L .34835 .24297 L 0 .029 .129 r
F
.34538 .24409 m .34354 .24195 L .34651 .24084 L F
.1505 .24174 m .15132 .23853 L .15336 .24058 L 0 .024 .123 r
F
.1505 .24174 m .14845 .23969 L .15132 .23853 L F
.73349 .24369 m .73521 .24035 L .73666 .24241 L 0 .028 .127 r
F
.73349 .24369 m .73204 .24162 L .73521 .24035 L F
.44518 .24652 m .44647 .2433 L .4482 .24543 L 0 .034 .135 r
F
.44518 .24652 m .44344 .24442 L .44647 .2433 L F
.19414 .24201 m .19502 .2389 L .19702 .24091 L 0 .025 .124 r
F
.19414 .24201 m .19214 .23998 L .19502 .2389 L F
.27365 .24287 m .27466 .23972 L .27658 .24176 L 0 .027 .126 r
F
.27365 .24287 m .27173 .24082 L .27466 .23972 L F
.5247 .24749 m .5261 .24408 L .52776 .24638 L 0 .036 .137 r
F
.5247 .24749 m .52303 .24523 L .5261 .24408 L F
.15826 .24147 m .15909 .23832 L .16112 .24036 L 0 .024 .123 r
F
.15826 .24147 m .15623 .23942 L .15909 .23832 L F
.3095 .24368 m .31058 .24043 L .31245 .2425 L 0 .028 .128 r
F
.3095 .24368 m .30762 .24161 L .31058 .24043 L F
.23777 .24238 m .23873 .23921 L .24068 .2413 L 0 .026 .125 r
F
.23777 .24238 m .23582 .24031 L .23873 .23921 L F
.48883 .24692 m .49018 .24382 L .49187 .24588 L 0 .035 .136 r
F
.48883 .24692 m .48713 .24489 L .49018 .24382 L F
.6665 .245 m .66813 .24186 L .66964 .24389 L 0 .031 .131 r
F
.6665 .245 m .66498 .24294 L .66813 .24186 L F
.74908 .24309 m .75084 .23991 L .75227 .242 L 0 .027 .127 r
F
.74908 .24309 m .74765 .24101 L .75084 .23991 L F
.2019 .24183 m .20279 .23869 L .20478 .24074 L 0 .025 .124 r
F
.2019 .24183 m .1999 .2398 L .20279 .23869 L F
.28142 .2427 m .28244 .2395 L .28435 .24158 L 0 .027 .126 r
F
.28142 .2427 m .27951 .24063 L .28244 .2395 L F
.80052 .24293 m .80237 .23984 L .80375 .24187 L 0 .027 .127 r
F
.80052 .24293 m .79915 .24092 L .80237 .23984 L F
.53363 .54786 m .532 .55428 L .53505 .5452 L .887 .434 0 r
F
.53058 .55667 m .532 .55428 L .53363 .54786 L .917 .331 0 r
F
.59171 .24662 m .59321 .2433 L .59481 .24557 L 0 .034 .135 r
F
.59171 .24662 m .59011 .24436 L .59321 .2433 L F
.35314 .24408 m .35428 .24098 L .35611 .24308 L 0 .03 .13 r
F
.35314 .24408 m .35131 .24198 L .35428 .24098 L F
.31728 .24345 m .31836 .24025 L .32022 .24237 L 0 .028 .128 r
F
.31728 .24345 m .31541 .24135 L .31836 .24025 L F
.38122 .2452 m .38241 .24194 L .3842 .24419 L 0 .032 .132 r
F
.38122 .2452 m .37942 .24297 L .38241 .24194 L F
.41709 .24586 m .41833 .2426 L .42009 .24486 L 0 .033 .134 r
F
.41709 .24586 m .41533 .24359 L .41833 .2426 L F
.49661 .24674 m .49798 .24348 L .49966 .2455 L 0 .035 .136 r
F
.49661 .24674 m .49492 .2447 L .49798 .24348 L F
.45296 .24654 m .45426 .2432 L .45598 .24539 L 0 .034 .135 r
F
.45296 .24654 m .45123 .24433 L .45426 .2432 L F
.53176 .54961 m .53312 .52169 L .53479 .53062 L .868 .496 0 r
F
.53176 .54961 m .53008 .53999 L .53312 .52169 L F
.16601 .24137 m .16685 .2382 L .16887 .24028 L 0 .024 .123 r
F
.16601 .24137 m .16399 .23928 L .16685 .2382 L F
.6743 .24487 m .67595 .24183 L .67745 .24382 L 0 .031 .132 r
F
.6743 .24487 m .67279 .24286 L .67595 .24183 L F
.80833 .24271 m .81018 .23946 L .81154 .24153 L 0 .027 .126 r
F
.80833 .24271 m .80696 .24067 L .81018 .23946 L F
.68987 .24401 m .69154 .2409 L .69303 .24285 L 0 .03 .13 r
F
.68987 .24401 m .68838 .24204 L .69154 .2409 L F
.75689 .24296 m .75866 .23971 L .76008 .24183 L 0 .027 .127 r
F
.75689 .24296 m .75546 .24086 L .75866 .23971 L F
.24552 .24233 m .2465 .23904 L .24844 .24118 L 0 .026 .125 r
F
.24552 .24233 m .24359 .24018 L .2465 .23904 L F
.5044 .24645 m .50577 .2431 L .50745 .24525 L 0 .034 .135 r
F
.5044 .24645 m .50272 .24427 L .50577 .2431 L F
.20965 .24175 m .21056 .23858 L .21253 .2407 L 0 .025 .124 r
F
.20965 .24175 m .20767 .23964 L .21056 .23858 L F
.28918 .24262 m .29021 .23946 L .2921 .24159 L 0 .027 .126 r
F
.28918 .24262 m .28728 .24052 L .29021 .23946 L F
.69767 .24371 m .69934 .24051 L .70082 .24252 L 0 .029 .129 r
F
.69767 .24371 m .69618 .24169 L .69934 .24051 L F
.53248 .2476 m .5339 .24414 L .53555 .24649 L 0 .037 .138 r
F
.53248 .2476 m .53083 .24527 L .5339 .24414 L F
.81613 .24244 m .81801 .2394 L .81936 .2414 L 0 .027 .126 r
F
.81613 .24244 m .81477 .24043 L .81801 .2394 L F
.46074 .24637 m .46205 .24308 L .46377 .2452 L 0 .034 .135 r
F
.46074 .24637 m .45901 .24423 L .46205 .24308 L F
.6821 .24465 m .68374 .24134 L .68524 .24334 L 0 .031 .131 r
F
.6821 .24465 m .6806 .24262 L .68374 .24134 L F
.5995 .24661 m .60102 .24309 L .6026 .24531 L 0 .034 .136 r
F
.5995 .24661 m .59791 .24438 L .60102 .24309 L F
.532 .55428 m .53342 .55135 L .53505 .5452 L .917 .331 0 r
F
.53505 .5452 m .53342 .55135 L .53644 .53237 L .868 .496 0 r
F
.53342 .55135 m .53479 .53062 L .53644 .53237 L .882 .45 0 r
F
.63844 .24447 m .64003 .2414 L .64157 .24342 L 0 .031 .131 r
F
.63844 .24447 m .6369 .24247 L .64003 .2414 L F
.17376 .24124 m .17462 .23799 L .17664 .24008 L 0 .024 .123 r
F
.17376 .24124 m .17175 .23914 L .17462 .23799 L F
.1301 .24103 m .13089 .23782 L .13294 .23994 L 0 .024 .122 r
F
.1301 .24103 m .12804 .23893 L .13089 .23782 L F
.60729 .24623 m .60882 .24287 L .6104 .24507 L 0 .034 .135 r
F
.60729 .24623 m .60571 .24401 L .60882 .24287 L F
.32503 .24346 m .32613 .24018 L .32799 .24234 L 0 .029 .128 r
F
.32503 .24346 m .32317 .2413 L .32613 .24018 L F
.36091 .24411 m .36205 .24102 L .36388 .24305 L 0 .03 .13 r
F
.36091 .24411 m .35908 .24205 L .36205 .24102 L F
.51218 .24627 m .51357 .24291 L .51524 .24512 L 0 .034 .135 r
F
.51218 .24627 m .51051 .24405 L .51357 .24291 L F
.25329 .24216 m .25428 .23885 L .25621 .24099 L 0 .026 .125 r
F
.25329 .24216 m .25136 .24003 L .25428 .23885 L F
.70546 .24347 m .70715 .24014 L .70863 .24228 L 0 .029 .128 r
F
.70546 .24347 m .70398 .24133 L .70715 .24014 L F
.7647 .24284 m .76648 .23961 L .7679 .24174 L 0 .028 .127 r
F
.7647 .24284 m .76328 .24072 L .76648 .23961 L F
.46852 .24611 m .46984 .24285 L .47156 .24492 L 0 .034 .135 r
F
.46852 .24611 m .46681 .24402 L .46984 .24285 L F
.63066 .24507 m .63223 .24175 L .63377 .24375 L 0 .032 .132 r
F
.63066 .24507 m .62911 .24309 L .63223 .24175 L F
.57142 .24575 m .5729 .2424 L .57451 .24443 L 0 .033 .134 r
F
.57142 .24575 m .56981 .24372 L .5729 .2424 L F
.54027 .2475 m .5417 .24409 L .54334 .24627 L 0 .037 .138 r
F
.54027 .2475 m .53862 .24529 L .5417 .24409 L F
.71326 .24319 m .71495 .23985 L .71642 .24196 L 0 .028 .128 r
F
.71326 .24319 m .71179 .24107 L .71495 .23985 L F
.57921 .24536 m .5807 .24223 L .58231 .24427 L 0 .033 .134 r
F
.57921 .24536 m .5776 .24331 L .5807 .24223 L F
.38898 .24537 m .39018 .242 L .39198 .24418 L 0 .032 .133 r
F
.38898 .24537 m .38719 .24318 L .39018 .242 L F
.54806 .2471 m .5495 .24403 L .55114 .24597 L 0 .037 .138 r
F
.54806 .2471 m .54642 .24513 L .5495 .24403 L F
.18152 .24105 m .18238 .23793 L .18439 .24003 L 0 .025 .123 r
F
.18152 .24105 m .17951 .23897 L .18238 .23793 L F
.62287 .24561 m .62443 .24242 L .62599 .2444 L 0 .033 .134 r
F
.62287 .24561 m .62132 .24365 L .62443 .24242 L F
.26106 .24194 m .26205 .23871 L .26398 .24082 L 0 .026 .125 r
F
.26106 .24194 m .25913 .23982 L .26205 .23871 L F
.42486 .24605 m .42611 .24283 L .42787 .24502 L 0 .034 .135 r
F
.42486 .24605 m .4231 .24385 L .42611 .24283 L F
.55585 .24672 m .5573 .24356 L .55893 .2455 L 0 .036 .137 r
F
.55585 .24672 m .55422 .24482 L .5573 .24356 L F
.56364 .24629 m .5651 .24301 L .56672 .24503 L 0 .035 .136 r
F
.56364 .24629 m .56201 .24427 L .5651 .24301 L F
.64624 .24435 m .64784 .24127 L .64937 .24326 L 0 .031 .131 r
F
.64624 .24435 m .6447 .24237 L .64784 .24127 L F
.39677 .24501 m .39798 .24178 L .39977 .2438 L 0 .032 .133 r
F
.39677 .24501 m .39497 .24298 L .39798 .24178 L F
.61509 .24609 m .61663 .24272 L .6182 .24489 L 0 .034 .135 r
F
.61509 .24609 m .61351 .24391 L .61663 .24272 L F
.72106 .24288 m .72277 .23968 L .72423 .24179 L 0 .028 .127 r
F
.72106 .24288 m .71959 .24075 L .72277 .23968 L F
.21739 .2418 m .21831 .23865 L .22027 .24079 L 0 .026 .125 r
F
.21739 .2418 m .21542 .23967 L .21831 .23865 L F
.40455 .24461 m .40577 .24138 L .40756 .2434 L 0 .031 .132 r
F
.40455 .24461 m .40277 .24259 L .40577 .24138 L F
.47631 .24593 m .47764 .24274 L .47934 .24488 L 0 .034 .135 r
F
.47631 .24593 m .4746 .24383 L .47764 .24274 L F
.36868 .244 m .36984 .24084 L .37166 .2429 L 0 .03 .131 r
F
.36868 .244 m .36685 .24198 L .36984 .24084 L F
.29692 .24271 m .29797 .23958 L .29985 .24171 L 0 .028 .127 r
F
.29692 .24271 m .29503 .24058 L .29797 .23958 L F
.3328 .24336 m .33391 .24005 L .33576 .2422 L 0 .029 .129 r
F
.3328 .24336 m .33095 .2412 L .33391 .24005 L F
.13784 .24099 m .13865 .23773 L .14069 .23987 L 0 .024 .123 r
F
.13784 .24099 m .13579 .23885 L .13865 .23773 L F
.77252 .24277 m .77431 .23958 L .77573 .24171 L 0 .028 .127 r
F
.77252 .24277 m .7711 .24064 L .77431 .23958 L F
.43264 .24585 m .4339 .24274 L .43565 .2447 L 0 .034 .135 r
F
.43264 .24585 m .43088 .24392 L .4339 .24274 L F
.51997 .24628 m .52137 .24298 L .52303 .24523 L 0 .035 .136 r
F
.51997 .24628 m .51831 .24405 L .52137 .24298 L F
.65404 .24415 m .65565 .24099 L .65717 .24304 L 0 .031 .131 r
F
.65404 .24415 m .65251 .24213 L .65565 .24099 L F
.34057 .24315 m .3417 .23981 L .34354 .24195 L 0 .029 .128 r
F
.34057 .24315 m .33873 .241 L .3417 .23981 L F
.26882 .24186 m .26981 .23876 L .27173 .24082 L 0 .027 .126 r
F
.26882 .24186 m .26689 .23979 L .26981 .23876 L F
.44042 .24554 m .4417 .2424 L .44344 .24442 L 0 .034 .135 r
F
.44042 .24554 m .43867 .24355 L .4417 .2424 L F
.18926 .24105 m .19013 .23795 L .19214 .23998 L 0 .025 .124 r
F
.18926 .24105 m .18726 .239 L .19013 .23795 L F
.14559 .24083 m .14641 .23759 L .14845 .23969 L 0 .024 .123 r
F
.14559 .24083 m .14355 .23873 L .14641 .23759 L F
.22514 .2417 m .22608 .23847 L .22805 .24053 L 0 .026 .125 r
F
.22514 .2417 m .22317 .23964 L .22608 .23847 L F
.72887 .24281 m .73059 .23952 L .73204 .24162 L 0 .028 .128 r
F
.72887 .24281 m .72741 .2407 L .73059 .23952 L F
.78033 .24261 m .78214 .23952 L .78353 .24148 L F
.78033 .24261 m .77894 .24066 L .78214 .23952 L F
.58701 .24543 m .58851 .2421 L .59011 .24436 L 0 .033 .134 r
F
.58701 .24543 m .58541 .24318 L .58851 .2421 L F
.73666 .24241 m .73839 .23908 L .73983 .24113 L 0 .027 .127 r
F
.73666 .24241 m .73521 .24035 L .73839 .23908 L F
.41233 .24457 m .41356 .24138 L .41533 .24359 L 0 .032 .132 r
F
.41233 .24457 m .41056 .24236 L .41356 .24138 L F
.78812 .24223 m .78994 .23903 L .79133 .24102 L 0 .027 .127 r
F
.78812 .24223 m .78674 .24026 L .78994 .23903 L F
.48409 .24595 m .48543 .24271 L .48713 .24489 L 0 .035 .136 r
F
.48409 .24595 m .48239 .24381 L .48543 .24271 L F
.23292 .24141 m .23386 .23826 L .23582 .24031 L 0 .026 .125 r
F
.23292 .24141 m .23096 .23937 L .23386 .23826 L F
.37644 .24401 m .37762 .24074 L .37942 .24297 L 0 .031 .131 r
F
.37644 .24401 m .37464 .24181 L .37762 .24074 L F
.74446 .24209 m .74621 .23894 L .74765 .24101 L 0 .027 .126 r
F
.74446 .24209 m .74302 .24003 L .74621 .23894 L F
.15336 .24058 m .15419 .23737 L .15623 .23942 L 0 .024 .123 r
F
.15336 .24058 m .15132 .23853 L .15419 .23737 L F
.66184 .24405 m .66346 .24087 L .66498 .24294 L 0 .031 .131 r
F
.66184 .24405 m .66032 .24196 L .66346 .24087 L F
.34835 .24297 m .34947 .23985 L .35131 .24198 L 0 .029 .129 r
F
.34835 .24297 m .34651 .24084 L .34947 .23985 L F
.30468 .24277 m .30574 .23953 L .30762 .24161 L 0 .028 .128 r
F
.30468 .24277 m .30279 .2407 L .30574 .23953 L F
.79592 .24195 m .79777 .23889 L .79915 .24092 L 0 .027 .126 r
F
.79592 .24195 m .79454 .23995 L .79777 .23889 L F
.4482 .24543 m .44949 .24219 L .45123 .24433 L 0 .034 .135 r
F
.4482 .24543 m .44647 .2433 L .44949 .24219 L F
.27658 .24176 m .27759 .23861 L .27951 .24063 L 0 .027 .126 r
F
.27658 .24176 m .27466 .23972 L .27759 .23861 L F
.19702 .24091 m .1979 .23782 L .1999 .2398 L 0 .025 .124 r
F
.19702 .24091 m .19502 .2389 L .1979 .23782 L F
.52776 .24638 m .52917 .24293 L .53083 .24527 L 0 .036 .137 r
F
.52776 .24638 m .5261 .24408 L .52917 .24293 L F
.31245 .2425 m .31353 .23926 L .31541 .24135 L 0 .028 .128 r
F
.31245 .2425 m .31058 .24043 L .31353 .23926 L F
.16112 .24036 m .16195 .23725 L .16399 .23928 L 0 .024 .123 r
F
.16112 .24036 m .15909 .23832 L .16195 .23725 L F
.66964 .24389 m .67128 .24085 L .67279 .24286 L 0 .031 .132 r
F
.66964 .24389 m .66813 .24186 L .67128 .24085 L F
.24068 .2413 m .24164 .2381 L .24359 .24018 L 0 .026 .125 r
F
.24068 .2413 m .23873 .23921 L .24164 .2381 L F
.49187 .24588 m .49323 .24265 L .49492 .2447 L 0 .035 .136 r
F
.49187 .24588 m .49018 .24382 L .49323 .24265 L F
.75227 .242 m .75403 .23874 L .75546 .24086 L 0 .027 .127 r
F
.75227 .242 m .75084 .23991 L .75403 .23874 L F
.28435 .24158 m .28537 .23842 L .28728 .24052 L 0 .027 .126 r
F
.28435 .24158 m .28244 .2395 L .28537 .23842 L F
.20478 .24074 m .20568 .23758 L .20767 .23964 L 0 .025 .124 r
F
.20478 .24074 m .20279 .23869 L .20568 .23758 L F
.49966 .2455 m .50103 .24227 L .50272 .24427 L 0 .034 .135 r
F
.49966 .2455 m .49798 .24348 L .50103 .24227 L F
.51472 .54464 m .51307 .53505 L .51611 .54199 L .887 .435 0 r
F
.80375 .24187 m .80559 .23862 L .80696 .24067 L 0 .027 .126 r
F
.80375 .24187 m .80237 .23984 L .80559 .23862 L F
.59481 .24557 m .59632 .24212 L .59791 .24438 L 0 .034 .135 r
F
.59481 .24557 m .59321 .2433 L .59632 .24212 L F
.45598 .24539 m .45729 .24208 L .45901 .24423 L F
.45598 .24539 m .45426 .2432 L .45729 .24208 L F
.32022 .24237 m .32131 .23914 L .32317 .2413 L 0 .028 .128 r
F
.32022 .24237 m .31836 .24025 L .32131 .23914 L F
.81154 .24153 m .8134 .23835 L .81477 .24043 L 0 .027 .126 r
F
.81154 .24153 m .81018 .23946 L .8134 .23835 L F
.69303 .24285 m .6947 .23975 L .69618 .24169 L 0 .029 .129 r
F
.69303 .24285 m .69154 .2409 L .6947 .23975 L F
.35611 .24308 m .35725 .23997 L .35908 .24205 L 0 .03 .13 r
F
.35611 .24308 m .35428 .24098 L .35725 .23997 L F
.50745 .24525 m .50883 .24192 L .51051 .24405 L 0 .034 .135 r
F
.50745 .24525 m .50577 .2431 L .50883 .24192 L F
.16887 .24028 m .16972 .23706 L .17175 .23914 L 0 .024 .123 r
F
.16887 .24028 m .16685 .2382 L .16972 .23706 L F
.3842 .24419 m .38539 .24091 L .38719 .24318 L 0 .032 .132 r
F
.3842 .24419 m .38241 .24194 L .38539 .24091 L F
.68524 .24334 m .68689 .24006 L .68838 .24204 L 0 .03 .13 r
F
.68524 .24334 m .68374 .24134 L .68689 .24006 L F
.24844 .24118 m .24942 .2379 L .25136 .24003 L 0 .026 .125 r
F
.24844 .24118 m .2465 .23904 L .24942 .2379 L F
.42009 .24486 m .42134 .2416 L .4231 .24385 L 0 .033 .134 r
F
.42009 .24486 m .41833 .2426 L .42134 .2416 L F
.76008 .24183 m .76186 .23859 L .76328 .24072 L 0 .027 .127 r
F
.76008 .24183 m .75866 .23971 L .76186 .23859 L F
.6026 .24531 m .60413 .2418 L .60571 .24401 L 0 .034 .135 r
F
.6026 .24531 m .60102 .24309 L .60413 .2418 L F
.70082 .24252 m .7025 .2393 L .70398 .24133 L 0 .029 .128 r
F
.70082 .24252 m .69934 .24051 L .7025 .2393 L F
.67745 .24382 m .6791 .24064 L .6806 .24262 L 0 .031 .132 r
F
.67745 .24382 m .67595 .24183 L .6791 .24064 L F
.53555 .24649 m .53697 .24297 L .53862 .24529 L 0 .036 .138 r
F
.53555 .24649 m .5339 .24414 L .53697 .24297 L F
.46377 .2452 m .46508 .24195 L .46681 .24402 L 0 .034 .135 r
F
.46377 .2452 m .46205 .24308 L .46508 .24195 L F
.21253 .2407 m .21344 .23754 L .21542 .23967 L 0 .025 .124 r
F
.21253 .2407 m .21056 .23858 L .21344 .23754 L F
.63377 .24375 m .63535 .24044 L .6369 .24247 L 0 .031 .132 r
F
.63377 .24375 m .63223 .24175 L .63535 .24044 L F
.2921 .24159 m .29314 .23843 L .29503 .24058 L 0 .027 .127 r
F
.2921 .24159 m .29021 .23946 L .29314 .23843 L F
.17664 .24008 m .1775 .23687 L .17951 .23897 L 0 .024 .123 r
F
.17664 .24008 m .17462 .23799 L .1775 .23687 L F
.6104 .24507 m .61194 .24172 L .61351 .24391 L 0 .034 .135 r
F
.6104 .24507 m .60882 .24287 L .61194 .24172 L F
.81936 .2414 m .82125 .23836 L .8226 .24036 L 0 .027 .126 r
F
.81936 .2414 m .81801 .2394 L .82125 .23836 L F
.57451 .24443 m .576 .2413 L .5776 .24331 L 0 .033 .134 r
F
.57451 .24443 m .5729 .2424 L .576 .2413 L F
.70863 .24228 m .71031 .23893 L .71179 .24107 L 0 .028 .128 r
F
.70863 .24228 m .70715 .24014 L .71031 .23893 L F
.25621 .24099 m .2572 .23767 L .25913 .23982 L 0 .026 .125 r
F
.25621 .24099 m .25428 .23885 L .2572 .23767 L F
.51524 .24512 m .51664 .24182 L .51831 .24405 L 0 .034 .135 r
F
.51524 .24512 m .51357 .24291 L .51664 .24182 L F
.13294 .23994 m .13374 .2367 L .13579 .23885 L 0 .024 .122 r
F
.13294 .23994 m .13089 .23782 L .13374 .2367 L F
.47156 .24492 m .47288 .24173 L .4746 .24383 L 0 .034 .135 r
F
.47156 .24492 m .46984 .24285 L .47288 .24173 L F
.64157 .24342 m .64316 .24033 L .6447 .24237 L 0 .031 .131 r
F
.64157 .24342 m .64003 .2414 L .64316 .24033 L F
.32799 .24234 m .32909 .23904 L .33095 .2412 L 0 .029 .128 r
F
.32799 .24234 m .32613 .24018 L .32909 .23904 L F
.54334 .24627 m .54478 .24298 L .54642 .24513 L 0 .037 .138 r
F
.54334 .24627 m .5417 .24409 L .54478 .24298 L F
.7679 .24174 m .76969 .2385 L .7711 .24064 L 0 .028 .127 r
F
.7679 .24174 m .76648 .23961 L .76969 .2385 L F
.71642 .24196 m .71812 .23865 L .71959 .24075 L F
.71642 .24196 m .71495 .23985 L .71812 .23865 L F
.36388 .24305 m .36503 .23995 L .36685 .24198 L 0 .03 .131 r
F
.36388 .24305 m .36205 .24102 L .36503 .23995 L F
.56672 .24503 m .56819 .24169 L .56981 .24372 L 0 .034 .135 r
F
.56672 .24503 m .5651 .24301 L .56819 .24169 L F
.39198 .24418 m .39318 .24082 L .39497 .24298 L 0 .032 .133 r
F
.39198 .24418 m .39018 .242 L .39318 .24082 L F
.62599 .2444 m .62755 .24109 L .62911 .24309 L 0 .033 .134 r
F
.62599 .2444 m .62443 .24242 L .62755 .24109 L F
.55893 .2455 m .56039 .24231 L .56201 .24427 L 0 .035 .137 r
F
.55893 .2455 m .5573 .24356 L .56039 .24231 L F
.39977 .2438 m .40098 .24057 L .40277 .24259 L 0 .032 .132 r
F
.39977 .2438 m .39798 .24178 L .40098 .24057 L F
.55114 .24597 m .55259 .24292 L .55422 .24482 L 0 .037 .138 r
F
.55114 .24597 m .5495 .24403 L .55259 .24292 L F
.6182 .24489 m .61975 .24148 L .62132 .24365 L 0 .034 .135 r
F
.6182 .24489 m .61663 .24272 L .61975 .24148 L F
.40756 .2434 m .40878 .24034 L .41056 .24236 L 0 .031 .132 r
F
.40756 .2434 m .40577 .24138 L .40878 .24034 L F
.58231 .24427 m .5838 .24115 L .58541 .24318 L 0 .033 .134 r
F
.58231 .24427 m .5807 .24223 L .5838 .24115 L F
.26398 .24082 m .26497 .23769 L .26689 .23979 L 0 .026 .125 r
F
.26398 .24082 m .26205 .23871 L .26497 .23769 L F
.64937 .24326 m .65098 .2401 L .65251 .24213 L 0 .031 .131 r
F
.64937 .24326 m .64784 .24127 L .65098 .2401 L F
.18439 .24003 m .18525 .23689 L .18726 .239 L 0 .025 .123 r
F
.18439 .24003 m .18238 .23793 L .18525 .23689 L F
.33576 .2422 m .33688 .23886 L .33873 .241 L 0 .029 .128 r
F
.33576 .2422 m .33391 .24005 L .33688 .23886 L F
.42787 .24502 m .42912 .24173 L .43088 .24392 L 0 .034 .135 r
F
.42787 .24502 m .42611 .24283 L .42912 .24173 L F
.72423 .24179 m .72595 .2386 L .72741 .2407 L 0 .028 .128 r
F
.72423 .24179 m .72277 .23968 L .72595 .2386 L F
.14069 .23987 m .1415 .2366 L .14355 .23873 L 0 .024 .123 r
F
.14069 .23987 m .13865 .23773 L .1415 .2366 L F
.37166 .2429 m .37282 .23971 L .37464 .24181 L 0 .03 .13 r
F
.37166 .2429 m .36984 .24084 L .37282 .23971 L F
.47934 .24488 m .48068 .24163 L .48239 .24381 L 0 .034 .135 r
F
.47934 .24488 m .47764 .24274 L .48068 .24163 L F
.22027 .24079 m .22121 .2375 L .22317 .23964 L 0 .026 .125 r
F
.22027 .24079 m .21831 .23865 L .22121 .2375 L F
.43565 .2447 m .43692 .24156 L .43867 .24355 L 0 .034 .135 r
F
.43565 .2447 m .4339 .24274 L .43692 .24156 L F
.29985 .24171 m .3009 .23857 L .30279 .2407 L 0 .028 .128 r
F
.29985 .24171 m .29797 .23958 L .3009 .23857 L F
.77573 .24171 m .77753 .23852 L .77894 .24066 L F
.77573 .24171 m .77431 .23958 L .77753 .23852 L F
.34354 .24195 m .34467 .23871 L .34651 .24084 L F
.34354 .24195 m .3417 .23981 L .34467 .23871 L F
.65717 .24304 m .65879 .23988 L .66032 .24196 L 0 .031 .131 r
F
.65717 .24304 m .65565 .24099 L .65879 .23988 L F
.52303 .24523 m .52444 .24183 L .5261 .24408 L 0 .035 .136 r
F
.52303 .24523 m .52137 .24298 L .52444 .24183 L F
.73983 .24113 m .74158 .23798 L .74302 .24003 L 0 .027 .126 r
F
.73983 .24113 m .73839 .23908 L .74158 .23798 L F
.22805 .24053 m .22899 .23731 L .23096 .23937 L 0 .026 .125 r
F
.22805 .24053 m .22608 .23847 L .22899 .23731 L F
.44344 .24442 m .44472 .24125 L .44647 .2433 L 0 .034 .135 r
F
.44344 .24442 m .4417 .2424 L .44472 .24125 L F
.73204 .24162 m .73377 .23827 L .73521 .24035 L 0 .028 .127 r
F
.73204 .24162 m .73059 .23952 L .73377 .23827 L F
.14845 .23969 m .14928 .23643 L .15132 .23853 L 0 .024 .123 r
F
.14845 .23969 m .14641 .23759 L .14928 .23643 L F
.79133 .24102 m .79316 .23794 L .79454 .23995 L 0 .027 .126 r
F
.79133 .24102 m .78994 .23903 L .79316 .23794 L F
.27173 .24082 m .27274 .23768 L .27466 .23972 L F
.27173 .24082 m .26981 .23876 L .27274 .23768 L F
.78353 .24148 m .78535 .23828 L .78674 .24026 L 0 .028 .127 r
F
.78353 .24148 m .78214 .23952 L .78535 .23828 L F
.19214 .23998 m .19301 .2369 L .19502 .2389 L 0 .025 .124 r
F
.19214 .23998 m .19013 .23795 L .19301 .2369 L F
.59011 .24436 m .59162 .24102 L .59321 .2433 L 0 .033 .134 r
F
.59011 .24436 m .58851 .2421 L .59162 .24102 L F
.15623 .23942 m .15705 .23628 L .15909 .23832 L 0 .024 .122 r
F
.15623 .23942 m .15419 .23737 L .15705 .23628 L F
.30762 .24161 m .30869 .23835 L .31058 .24043 L 0 .028 .128 r
F
.30762 .24161 m .30574 .23953 L .30869 .23835 L F
.23582 .24031 m .23677 .23716 L .23873 .23921 L 0 .026 .125 r
F
.23582 .24031 m .23386 .23826 L .23677 .23716 L F
.41533 .24359 m .41656 .2404 L .41833 .2426 L 0 .032 .133 r
F
.41533 .24359 m .41356 .24138 L .41656 .2404 L F
.48713 .24489 m .48848 .24161 L .49018 .24382 L 0 .035 .136 r
F
.48713 .24489 m .48543 .24271 L .48848 .24161 L F
.66498 .24294 m .66661 .2398 L .66813 .24186 L 0 .031 .131 r
F
.66498 .24294 m .66346 .24087 L .66661 .2398 L F
.74765 .24101 m .7494 .23781 L .75084 .23991 L 0 .027 .126 r
F
.74765 .24101 m .74621 .23894 L .7494 .23781 L F
.37942 .24297 m .38061 .23969 L .38241 .24194 L 0 .031 .131 r
F
.37942 .24297 m .37762 .24074 L .38061 .23969 L F
.27951 .24063 m .28052 .2375 L .28244 .2395 L 0 .027 .126 r
F
.27951 .24063 m .27759 .23861 L .28052 .2375 L F
.52225 .54804 m .52367 .52014 L .52534 .5392 L .868 .495 0 r
F
.52225 .54804 m .5206 .52829 L .52367 .52014 L F
.45123 .24433 m .45252 .24109 L .45426 .2432 L 0 .034 .135 r
F
.45123 .24433 m .44949 .24219 L .45252 .24109 L F
.1999 .2398 m .20079 .2367 L .20279 .23869 L 0 .025 .124 r
F
.1999 .2398 m .1979 .23782 L .20079 .2367 L F
.35131 .24198 m .35244 .23885 L .35428 .24098 L 0 .029 .129 r
F
.35131 .24198 m .34947 .23985 L .35244 .23885 L F
.31541 .24135 m .31648 .23815 L .31836 .24025 L 0 .028 .128 r
F
.31541 .24135 m .31353 .23926 L .31648 .23815 L F
.79915 .24092 m .80099 .23779 L .80237 .23984 L 0 .027 .127 r
F
.79915 .24092 m .79777 .23889 L .80099 .23779 L F
.53083 .24527 m .53224 .24179 L .5339 .24414 L 0 .035 .137 r
F
.53083 .24527 m .52917 .24293 L .53224 .24179 L F
.16399 .23928 m .16481 .23619 L .16685 .2382 L 0 .024 .123 r
F
.16399 .23928 m .16195 .23725 L .16481 .23619 L F
.49492 .2447 m .49628 .24145 L .49798 .24348 L 0 .035 .136 r
F
.49492 .2447 m .49323 .24265 L .49628 .24145 L F
.50272 .24427 m .50409 .24112 L .50577 .2431 L 0 .034 .135 r
F
.50272 .24427 m .50103 .24227 L .50409 .24112 L F
.24359 .24018 m .24455 .23697 L .2465 .23904 L 0 .026 .125 r
F
.24359 .24018 m .24164 .2381 L .24455 .23697 L F
.75546 .24086 m .75723 .23757 L .75866 .23971 L 0 .027 .126 r
F
.75546 .24086 m .75403 .23874 L .75723 .23757 L F
.80696 .24067 m .8088 .23739 L .81018 .23946 L F
.80696 .24067 m .80559 .23862 L .8088 .23739 L F
.67279 .24286 m .67444 .23984 L .67595 .24183 L 0 .031 .132 r
F
.67279 .24286 m .67128 .24085 L .67444 .23984 L F
.59791 .24438 m .59943 .24086 L .60102 .24309 L 0 .034 .135 r
F
.59791 .24438 m .59632 .24212 L .59943 .24086 L F
.20767 .23964 m .20857 .23651 L .21056 .23858 L 0 .025 .124 r
F
.20767 .23964 m .20568 .23758 L .20857 .23651 L F
.28728 .24052 m .28831 .23733 L .29021 .23946 L 0 .027 .126 r
F
.28728 .24052 m .28537 .23842 L .28831 .23733 L F
.68838 .24204 m .69005 .23894 L .69154 .2409 L 0 .03 .13 r
F
.68838 .24204 m .68689 .24006 L .69005 .23894 L F
.60571 .24401 m .60724 .24068 L .60882 .24287 L 0 .033 .134 r
F
.60571 .24401 m .60413 .2418 L .60724 .24068 L F
.45901 .24423 m .46032 .24097 L .46205 .24308 L 0 .034 .135 r
F
.45901 .24423 m .45729 .24208 L .46032 .24097 L F
.51051 .24405 m .5119 .24078 L .51357 .24291 L F
.51051 .24405 m .50883 .24192 L .5119 .24078 L F
.69618 .24169 m .69787 .23858 L .69934 .24051 L 0 .029 .129 r
F
.69618 .24169 m .6947 .23975 L .69787 .23858 L F
.81477 .24043 m .81664 .23729 L .81801 .2394 L 0 .027 .126 r
F
.81477 .24043 m .8134 .23835 L .81664 .23729 L F
.32317 .2413 m .32427 .23803 L .32613 .24018 L 0 .028 .128 r
F
.32317 .2413 m .32131 .23914 L .32427 .23803 L F
.17175 .23914 m .1726 .23591 L .17462 .23799 L 0 .024 .123 r
F
.17175 .23914 m .16972 .23706 L .1726 .23591 L F
.6806 .24262 m .68225 .23937 L .68374 .24134 L 0 .031 .131 r
F
.6806 .24262 m .6791 .24064 L .68225 .23937 L F
.25136 .24003 m .25234 .23671 L .25428 .23885 L 0 .026 .125 r
F
.25136 .24003 m .24942 .2379 L .25234 .23671 L F
.70398 .24133 m .70567 .2381 L .70715 .24014 L 0 .028 .128 r
F
.70398 .24133 m .7025 .2393 L .70567 .2381 L F
.53342 .55135 m .53176 .54961 L .53479 .53062 L .882 .45 0 r
F
.76328 .24072 m .76506 .23748 L .76648 .23961 L 0 .027 .127 r
F
.76328 .24072 m .76186 .23859 L .76506 .23748 L F
.6369 .24247 m .63848 .23935 L .64003 .2414 L 0 .031 .131 r
F
.6369 .24247 m .63535 .24044 L .63848 .23935 L F
.53862 .24529 m .54005 .2418 L .5417 .24409 L 0 .036 .137 r
F
.53862 .24529 m .53697 .24297 L .54005 .2418 L F
.35908 .24205 m .36022 .23895 L .36205 .24102 L 0 .03 .13 r
F
.35908 .24205 m .35725 .23997 L .36022 .23895 L F
.46681 .24402 m .46812 .24081 L .46984 .24285 L 0 .034 .135 r
F
.46681 .24402 m .46508 .24195 L .46812 .24081 L F
.38719 .24318 m .38839 .23975 L .39018 .242 L 0 .032 .132 r
F
.38719 .24318 m .38539 .24091 L .38839 .23975 L F
.4231 .24385 m .42435 .24061 L .42611 .24283 L 0 .034 .135 r
F
.4231 .24385 m .42134 .2416 L .42435 .24061 L F
.52751 .55759 m .52893 .56341 L .53058 .55667 L .932 .276 0 r
F
.52751 .55759 m .52585 .56433 L .52893 .56341 L F
.71179 .24107 m .71348 .23773 L .71495 .23985 L 0 .028 .127 r
F
.71179 .24107 m .71031 .23893 L .71348 .23773 L F
.61351 .24391 m .61506 .24054 L .61663 .24272 L 0 .034 .135 r
F
.61351 .24391 m .61194 .24172 L .61506 .24054 L F
.25913 .23982 m .26013 .23655 L .26205 .23871 L 0 .026 .125 r
F
.25913 .23982 m .2572 .23767 L .26013 .23655 L F
.56981 .24372 m .57128 .24038 L .5729 .2424 L 0 .033 .134 r
F
.56981 .24372 m .56819 .24169 L .57128 .24038 L F
.17951 .23897 m .18037 .23581 L .18238 .23793 L 0 .024 .123 r
F
.17951 .23897 m .1775 .23687 L .18037 .23581 L F
.62911 .24309 m .63067 .23973 L .63223 .24175 L 0 .032 .133 r
F
.62911 .24309 m .62755 .24109 L .63067 .23973 L F
.5776 .24331 m .5791 .24024 L .5807 .24223 L 0 .033 .134 r
F
.5776 .24331 m .576 .2413 L .5791 .24024 L F
.71959 .24075 m .72131 .23759 L .72277 .23968 L 0 .028 .127 r
F
.71959 .24075 m .71812 .23865 L .72131 .23759 L F
.21542 .23967 m .21634 .23651 L .21831 .23865 L 0 .026 .125 r
F
.21542 .23967 m .21344 .23754 L .21634 .23651 L F
.33095 .2412 m .33206 .2379 L .33391 .24005 L 0 .028 .128 r
F
.33095 .2412 m .32909 .23904 L .33206 .2379 L F
.29503 .24058 m .29608 .23741 L .29797 .23958 L 0 .027 .127 r
F
.29503 .24058 m .29314 .23843 L .29608 .23741 L F
.13579 .23885 m .1366 .23559 L .13865 .23773 L 0 .024 .122 r
F
.13579 .23885 m .13374 .2367 L .1366 .23559 L F
.4746 .24383 m .47593 .2406 L .47764 .24274 L 0 .034 .135 r
F
.4746 .24383 m .47288 .24173 L .47593 .2406 L F
.54642 .24513 m .54786 .2419 L .5495 .24403 L 0 .037 .138 r
F
.54642 .24513 m .54478 .24298 L .54786 .2419 L F
.51831 .24405 m .5197 .24073 L .52137 .24298 L 0 .034 .135 r
F
.51831 .24405 m .51664 .24182 L .5197 .24073 L F
.56201 .24427 m .56348 .24102 L .5651 .24301 L 0 .035 .136 r
F
.56201 .24427 m .56039 .24231 L .56348 .24102 L F
.39497 .24298 m .39618 .23963 L .39798 .24178 L 0 .032 .132 r
F
.39497 .24298 m .39318 .24082 L .39618 .23963 L F
.62132 .24365 m .62287 .24024 L .62443 .24242 L 0 .033 .134 r
F
.62132 .24365 m .61975 .24148 L .62287 .24024 L F
.7711 .24064 m .7729 .23744 L .77431 .23958 L 0 .028 .127 r
F
.7711 .24064 m .76969 .2385 L .7729 .23744 L F
.6447 .24237 m .6463 .2392 L .64784 .24127 L 0 .031 .131 r
F
.6447 .24237 m .64316 .24033 L .6463 .2392 L F
.40277 .24259 m .40399 .23936 L .40577 .24138 L 0 .031 .132 r
F
.40277 .24259 m .40098 .24057 L .40399 .23936 L F
.36685 .24198 m .36801 .23878 L .36984 .24084 L 0 .03 .13 r
F
.36685 .24198 m .36503 .23995 L .36801 .23878 L F
.55422 .24482 m .55567 .24163 L .5573 .24356 L 0 .036 .138 r
F
.55422 .24482 m .55259 .24292 L .55567 .24163 L F
.33873 .241 m .33985 .23768 L .3417 .23981 L 0 .028 .128 r
F
.33873 .241 m .33688 .23886 L .33985 .23768 L F
.58541 .24318 m .58691 .24006 L .58851 .2421 L 0 .033 .134 r
F
.58541 .24318 m .5838 .24115 L .58691 .24006 L F
.65251 .24213 m .65412 .23893 L .65565 .24099 L 0 .031 .131 r
F
.65251 .24213 m .65098 .2401 L .65412 .23893 L F
.41056 .24236 m .41178 .23935 L .41356 .24138 L 0 .032 .132 r
F
.41056 .24236 m .40878 .24034 L .41178 .23935 L F
.26689 .23979 m .26789 .23667 L .26981 .23876 L 0 .026 .125 r
F
.26689 .23979 m .26497 .23769 L .26789 .23667 L F
.43088 .24392 m .43214 .24053 L .4339 .24274 L 0 .034 .135 r
F
.43088 .24392 m .42912 .24173 L .43214 .24053 L F
.14355 .23873 m .14437 .23547 L .14641 .23759 L 0 .024 .123 r
F
.14355 .23873 m .1415 .2366 L .14437 .23547 L F
.72741 .2407 m .72913 .23743 L .73059 .23952 L 0 .028 .127 r
F
.72741 .2407 m .72595 .2386 L .72913 .23743 L F
.22317 .23964 m .22412 .23632 L .22608 .23847 L 0 .026 .125 r
F
.22317 .23964 m .22121 .2375 L .22412 .23632 L F
.37464 .24181 m .37581 .2386 L .37762 .24074 L 0 .03 .13 r
F
.37464 .24181 m .37282 .23971 L .37581 .2386 L F
.18726 .239 m .18813 .23584 L .19013 .23795 L 0 .025 .124 r
F
.18726 .239 m .18525 .23689 L .18813 .23584 L F
.43867 .24355 m .43995 .24038 L .4417 .2424 L 0 .034 .135 r
F
.43867 .24355 m .43692 .24156 L .43995 .24038 L F
.73521 .24035 m .73694 .23702 L .73839 .23908 L 0 .027 .127 r
F
.73521 .24035 m .73377 .23827 L .73694 .23702 L F
.48239 .24381 m .48373 .24049 L .48543 .24271 L 0 .034 .135 r
F
.48239 .24381 m .48068 .24163 L .48373 .24049 L F
.5261 .24408 m .52751 .24067 L .52917 .24293 L 0 .035 .136 r
F
.5261 .24408 m .52444 .24183 L .52751 .24067 L F
.34651 .24084 m .34763 .23771 L .34947 .23985 L 0 .029 .128 r
F
.34651 .24084 m .34467 .23871 L .34763 .23771 L F
.66032 .24196 m .66194 .23877 L .66346 .24087 L 0 .031 .131 r
F
.66032 .24196 m .65879 .23988 L .66194 .23877 L F
.77894 .24066 m .78074 .23738 L .78214 .23952 L 0 .028 .128 r
F
.77894 .24066 m .77753 .23852 L .78074 .23738 L F
.23096 .23937 m .2319 .2362 L .23386 .23826 L 0 .026 .125 r
F
.23096 .23937 m .22899 .23731 L .2319 .2362 L F
.74302 .24003 m .74478 .2369 L .74621 .23894 L 0 .027 .126 r
F
.74302 .24003 m .74158 .23798 L .74478 .2369 L F
.78674 .24026 m .78855 .23703 L .78994 .23903 L 0 .027 .127 r
F
.78674 .24026 m .78535 .23828 L .78855 .23703 L F
.15132 .23853 m .15215 .23527 L .15419 .23737 L 0 .024 .122 r
F
.15132 .23853 m .14928 .23643 L .15215 .23527 L F
.30279 .2407 m .30386 .2374 L .30574 .23953 L 0 .028 .128 r
F
.30279 .2407 m .3009 .23857 L .30386 .2374 L F
.44647 .2433 m .44775 .24012 L .44949 .24219 L 0 .034 .135 r
F
.44647 .2433 m .44472 .24125 L .44775 .24012 L F
.27466 .23972 m .27567 .23659 L .27759 .23861 L 0 .027 .126 r
F
.27466 .23972 m .27274 .23768 L .27567 .23659 L F
.79454 .23995 m .79639 .23686 L .79777 .23889 L 0 .027 .127 r
F
.79454 .23995 m .79316 .23794 L .79639 .23686 L F
.19502 .2389 m .19589 .23583 L .1979 .23782 L 0 .025 .124 r
F
.19502 .2389 m .19301 .2369 L .19589 .23583 L F
.31058 .24043 m .31165 .23718 L .31353 .23926 L 0 .028 .127 r
F
.31058 .24043 m .30869 .23835 L .31165 .23718 L F
.15909 .23832 m .15991 .23522 L .16195 .23725 L 0 .024 .123 r
F
.15909 .23832 m .15705 .23628 L .15991 .23522 L F
.59321 .2433 m .59472 .23985 L .59632 .24212 L 0 .033 .134 r
F
.59321 .2433 m .59162 .24102 L .59472 .23985 L F
.23873 .23921 m .23968 .23605 L .24164 .2381 L 0 .026 .125 r
F
.23873 .23921 m .23677 .23716 L .23968 .23605 L F
.75084 .23991 m .7526 .23662 L .75403 .23874 L 0 .027 .126 r
F
.75084 .23991 m .7494 .23781 L .7526 .23662 L F
.66813 .24186 m .66977 .23879 L .67128 .24085 L 0 .031 .132 r
F
.66813 .24186 m .66661 .2398 L .66977 .23879 L F
.49018 .24382 m .49153 .24045 L .49323 .24265 L 0 .035 .136 r
F
.49018 .24382 m .48848 .24161 L .49153 .24045 L F
.28244 .2395 m .28346 .2364 L .28537 .23842 L 0 .027 .126 r
F
.28244 .2395 m .28052 .2375 L .28346 .2364 L F
.45426 .2432 m .45555 .24 L .45729 .24208 L 0 .034 .135 r
F
.45426 .2432 m .45252 .24109 L .45555 .24 L F
.20279 .23869 m .20368 .23558 L .20568 .23758 L 0 .025 .124 r
F
.20279 .23869 m .20079 .2367 L .20368 .23558 L F
.38241 .24194 m .3836 .23864 L .38539 .24091 L 0 .031 .131 r
F
.38241 .24194 m .38061 .23969 L .3836 .23864 L F
.41833 .2426 m .41957 .23942 L .42134 .2416 L 0 .033 .133 r
F
.41833 .2426 m .41656 .2404 L .41957 .23942 L F
.49798 .24348 m .49934 .24027 L .50103 .24227 L 0 .034 .135 r
F
.49798 .24348 m .49628 .24145 L .49934 .24027 L F
.5339 .24414 m .53532 .24064 L .53697 .24297 L 0 .035 .137 r
F
.5339 .24414 m .53224 .24179 L .53532 .24064 L F
.31836 .24025 m .31944 .23703 L .32131 .23914 L 0 .028 .127 r
F
.31836 .24025 m .31648 .23815 L .31944 .23703 L F
.80237 .23984 m .80421 .23655 L .80559 .23862 L 0 .027 .126 r
F
.80237 .23984 m .80099 .23779 L .80421 .23655 L F
.60102 .24309 m .60254 .23961 L .60413 .2418 L 0 .033 .134 r
F
.60102 .24309 m .59943 .24086 L .60254 .23961 L F
.50577 .2431 m .50715 .23997 L .50883 .24192 L 0 .034 .135 r
F
.50577 .2431 m .50409 .24112 L .50715 .23997 L F
.81018 .23946 m .81203 .23626 L .8134 .23835 L 0 .027 .126 r
F
.81018 .23946 m .8088 .23739 L .81203 .23626 L F
.35428 .24098 m .35541 .23784 L .35725 .23997 L 0 .03 .13 r
F
.35428 .24098 m .35244 .23885 L .35541 .23784 L F
.2465 .23904 m .24747 .23585 L .24942 .2379 L 0 .026 .125 r
F
.2465 .23904 m .24455 .23697 L .24747 .23585 L F
.75866 .23971 m .76043 .23645 L .76186 .23859 L 0 .027 .126 r
F
.75866 .23971 m .75723 .23757 L .76043 .23645 L F
.16685 .2382 m .16769 .23506 L .16972 .23706 L 0 .024 .123 r
F
.16685 .2382 m .16481 .23619 L .16769 .23506 L F
.69154 .2409 m .69322 .23782 L .6947 .23975 L 0 .03 .13 r
F
.69154 .2409 m .69005 .23894 L .69322 .23782 L F
.68374 .24134 m .6854 .23811 L .68689 .24006 L 0 .03 .131 r
F
.68374 .24134 m .68225 .23937 L .6854 .23811 L F
.60882 .24287 m .61036 .23957 L .61194 .24172 L 0 .033 .134 r
F
.60882 .24287 m .60724 .24068 L .61036 .23957 L F
.46205 .24308 m .46336 .23986 L .46508 .24195 L 0 .034 .135 r
F
.46205 .24308 m .46032 .24097 L .46336 .23986 L F
.69934 .24051 m .70103 .23736 L .7025 .2393 L 0 .029 .129 r
F
.69934 .24051 m .69787 .23858 L .70103 .23736 L F
.21056 .23858 m .21146 .23547 L .21344 .23754 L 0 .025 .124 r
F
.21056 .23858 m .20857 .23651 L .21146 .23547 L F
.51357 .24291 m .51496 .23967 L .51664 .24182 L 0 .034 .135 r
F
.51357 .24291 m .5119 .24078 L .51496 .23967 L F
.67595 .24183 m .67759 .23866 L .6791 .24064 L 0 .031 .132 r
F
.67595 .24183 m .67444 .23984 L .67759 .23866 L F
.29021 .23946 m .29125 .23627 L .29314 .23843 L 0 .027 .126 r
F
.29021 .23946 m .28831 .23733 L .29125 .23627 L F
.70715 .24014 m .70884 .2369 L .71031 .23893 L 0 .028 .128 r
F
.70715 .24014 m .70567 .2381 L .70884 .2369 L F
.17462 .23799 m .17548 .23479 L .1775 .23687 L 0 .024 .122 r
F
.17462 .23799 m .1726 .23591 L .17548 .23479 L F
.25428 .23885 m .25527 .23552 L .2572 .23767 L 0 .026 .124 r
F
.25428 .23885 m .25234 .23671 L .25527 .23552 L F
.32613 .24018 m .32723 .2369 L .32909 .23904 L 0 .028 .128 r
F
.32613 .24018 m .32427 .23803 L .32723 .2369 L F
.5417 .24409 m .54313 .2407 L .54478 .24298 L 0 .036 .137 r
F
.5417 .24409 m .54005 .2418 L .54313 .2407 L F
.63223 .24175 m .6338 .2384 L .63535 .24044 L 0 .031 .132 r
F
.63223 .24175 m .63067 .23973 L .6338 .2384 L F
.5729 .2424 m .57438 .23928 L .576 .2413 L 0 .033 .134 r
F
.5729 .2424 m .57128 .24038 L .57438 .23928 L F
.46984 .24285 m .47116 .23966 L .47288 .24173 L 0 .034 .135 r
F
.46984 .24285 m .46812 .24081 L .47116 .23966 L F
.76648 .23961 m .76827 .23637 L .76969 .2385 L 0 .027 .127 r
F
.76648 .23961 m .76506 .23748 L .76827 .23637 L F
.81801 .2394 m .81988 .23623 L .82125 .23836 L 0 .027 .126 r
F
.81801 .2394 m .81664 .23729 L .81988 .23623 L F
.39018 .242 m .39139 .23859 L .39318 .24082 L 0 .032 .132 r
F
.39018 .242 m .38839 .23975 L .39139 .23859 L F
.71495 .23985 m .71666 .23655 L .71812 .23865 L 0 .028 .127 r
F
.71495 .23985 m .71348 .23773 L .71666 .23655 L F
.64003 .2414 m .64162 .23826 L .64316 .24033 L 0 .031 .131 r
F
.64003 .2414 m .63848 .23935 L .64162 .23826 L F
.61663 .24272 m .61818 .2393 L .61975 .24148 L 0 .033 .134 r
F
.61663 .24272 m .61506 .24054 L .61818 .2393 L F
.52278 .55705 m .52418 .57111 L .52585 .56433 L .947 .216 0 r
F
.52278 .55705 m .5211 .56352 L .52418 .57111 L F
.36205 .24102 m .3632 .23789 L .36503 .23995 L 0 .03 .13 r
F
.36205 .24102 m .36022 .23895 L .3632 .23789 L F
.53058 .55667 m .52893 .56341 L .532 .55428 L .917 .331 0 r
F
.5651 .24301 m .56657 .23968 L .56819 .24169 L 0 .034 .135 r
F
.5651 .24301 m .56348 .24102 L .56657 .23968 L F
.26205 .23871 m .26305 .23553 L .26497 .23769 L 0 .026 .125 r
F
.26205 .23871 m .26013 .23655 L .26305 .23553 L F
.42611 .24283 m .42737 .2395 L .42912 .24173 L 0 .034 .135 r
F
.42611 .24283 m .42435 .24061 L .42737 .2395 L F
.62443 .24242 m .62599 .23893 L .62755 .24109 L 0 .033 .133 r
F
.62443 .24242 m .62287 .24024 L .62599 .23893 L F
.33391 .24005 m .33503 .23672 L .33688 .23886 L 0 .028 .128 r
F
.33391 .24005 m .33206 .2379 L .33503 .23672 L F
.39798 .24178 m .39919 .23844 L .40098 .24057 L 0 .032 .132 r
F
.39798 .24178 m .39618 .23963 L .39919 .23844 L F
.5807 .24223 m .5822 .23917 L .5838 .24115 L 0 .033 .134 r
F
.5807 .24223 m .5791 .24024 L .5822 .23917 L F
.40577 .24138 m .40699 .23831 L .40878 .24034 L 0 .031 .132 r
F
.40577 .24138 m .40399 .23936 L .40699 .23831 L F
.18238 .23793 m .18325 .23476 L .18525 .23689 L 0 .025 .123 r
F
.18238 .23793 m .18037 .23581 L .18325 .23476 L F
.5573 .24356 m .55876 .24034 L .56039 .24231 L 0 .036 .137 r
F
.5573 .24356 m .55567 .24163 L .55876 .24034 L F
.72277 .23968 m .72449 .23653 L .72595 .2386 L 0 .028 .127 r
F
.72277 .23968 m .72131 .23759 L .72449 .23653 L F
.13865 .23773 m .13945 .23447 L .1415 .2366 L 0 .024 .122 r
F
.13865 .23773 m .1366 .23559 L .13945 .23447 L F
.5495 .24403 m .55095 .2408 L .55259 .24292 L 0 .037 .138 r
F
.5495 .24403 m .54786 .2419 L .55095 .2408 L F
.47764 .24274 m .47897 .23945 L .48068 .24163 L 0 .034 .135 r
F
.47764 .24274 m .47593 .2406 L .47897 .23945 L F
.21831 .23865 m .21924 .23535 L .22121 .2375 L 0 .026 .125 r
F
.21831 .23865 m .21634 .23651 L .21924 .23535 L F
.52137 .24298 m .52277 .23957 L .52444 .24183 L 0 .034 .135 r
F
.52137 .24298 m .5197 .24073 L .52277 .23957 L F
.64784 .24127 m .64944 .238 L .65098 .2401 L 0 .031 .131 r
F
.64784 .24127 m .6463 .2392 L .64944 .238 L F
.36984 .24084 m .371 .23761 L .37282 .23971 L 0 .03 .13 r
F
.36984 .24084 m .36801 .23878 L .371 .23761 L F
.51637 .55425 m .51472 .54464 L .51777 .55188 L .917 .331 0 r
F
.51472 .54464 m .51611 .54199 L .51777 .55188 L .887 .435 0 r
F
.29797 .23958 m .29902 .23639 L .3009 .23857 L 0 .028 .127 r
F
.29797 .23958 m .29608 .23741 L .29902 .23639 L F
.77431 .23958 m .77611 .23637 L .77753 .23852 L F
.77431 .23958 m .7729 .23744 L .77611 .23637 L F
.3417 .23981 m .34282 .23657 L .34467 .23871 L 0 .028 .128 r
F
.3417 .23981 m .33985 .23768 L .34282 .23657 L F
.65565 .24099 m .65726 .2378 L .65879 .23988 L 0 .031 .131 r
F
.65565 .24099 m .65412 .23893 L .65726 .2378 L F
.4339 .24274 m .43517 .23933 L .43692 .24156 L 0 .034 .135 r
F
.4339 .24274 m .43214 .24053 L .43517 .23933 L F
.58851 .2421 m .59002 .23896 L .59162 .24102 L 0 .033 .134 r
F
.58851 .2421 m .58691 .24006 L .59002 .23896 L F
.73839 .23908 m .74014 .23594 L .74158 .23798 L 0 .027 .126 r
F
.73839 .23908 m .73694 .23702 L .74014 .23594 L F
.73059 .23952 m .73231 .2362 L .73377 .23827 L 0 .028 .127 r
F
.73059 .23952 m .72913 .23743 L .73231 .2362 L F
.14641 .23759 m .14723 .2343 L .14928 .23643 L 0 .024 .122 r
F
.14641 .23759 m .14437 .23547 L .14723 .2343 L F
.22608 .23847 m .22703 .23516 L .22899 .23731 L 0 .026 .125 r
F
.22608 .23847 m .22412 .23632 L .22703 .23516 L F
.4417 .2424 m .44297 .2392 L .44472 .24125 L 0 .034 .135 r
F
.4417 .2424 m .43995 .24038 L .44297 .2392 L F
.26981 .23876 m .27082 .23561 L .27274 .23768 L 0 .027 .126 r
F
.26981 .23876 m .26789 .23667 L .27082 .23561 L F
.41356 .24138 m .41479 .23836 L .41656 .2404 L 0 .032 .133 r
F
.41356 .24138 m .41178 .23935 L .41479 .23836 L F
.37762 .24074 m .3788 .23752 L .38061 .23969 L 0 .03 .131 r
F
.37762 .24074 m .37581 .2386 L .3788 .23752 L F
.78994 .23903 m .79178 .23592 L .79316 .23794 L 0 .027 .127 r
F
.78994 .23903 m .78855 .23703 L .79178 .23592 L F
.48543 .24271 m .48678 .23935 L .48848 .24161 L 0 .034 .135 r
F
.48543 .24271 m .48373 .24049 L .48678 .23935 L F
.19013 .23795 m .19101 .23479 L .19301 .2369 L 0 .025 .124 r
F
.19013 .23795 m .18813 .23584 L .19101 .23479 L F
.52917 .24293 m .53059 .23952 L .53224 .24179 L 0 .035 .136 r
F
.52917 .24293 m .52751 .24067 L .53059 .23952 L F
.78214 .23952 m .78395 .23616 L .78535 .23828 L 0 .028 .127 r
F
.78214 .23952 m .78074 .23738 L .78395 .23616 L F
.30574 .23953 m .30681 .23621 L .30869 .23835 L F
.30574 .23953 m .30386 .2374 L .30681 .23621 L F
.15419 .23737 m .15501 .23417 L .15705 .23628 L 0 .024 .122 r
F
.15419 .23737 m .15215 .23527 L .15501 .23417 L F
.23386 .23826 m .23481 .23508 L .23677 .23716 L 0 .026 .125 r
F
.23386 .23826 m .2319 .2362 L .23481 .23508 L F
.66346 .24087 m .66509 .23768 L .66661 .2398 L 0 .031 .131 r
F
.66346 .24087 m .66194 .23877 L .66509 .23768 L F
.74621 .23894 m .74797 .23578 L .7494 .23781 L 0 .027 .126 r
F
.74621 .23894 m .74478 .2369 L .74797 .23578 L F
.44949 .24219 m .45078 .23905 L .45252 .24109 L 0 .034 .135 r
F
.44949 .24219 m .44775 .24012 L .45078 .23905 L F
.34947 .23985 m .3506 .23671 L .35244 .23885 L 0 .029 .129 r
F
.34947 .23985 m .34763 .23771 L .3506 .23671 L F
.51917 .54897 m .51753 .52922 L .5206 .52829 L .882 .45 0 r
F
.51611 .54199 m .51753 .52922 L .51917 .54897 L .868 .496 0 r
F
.27759 .23861 m .2786 .23549 L .28052 .2375 L 0 .027 .126 r
F
.27759 .23861 m .27567 .23659 L .2786 .23549 L F
.31353 .23926 m .31461 .23604 L .31648 .23815 L 0 .028 .127 r
F
.31353 .23926 m .31165 .23718 L .31461 .23604 L F
.59632 .24212 m .59784 .23864 L .59943 .24086 L 0 .033 .134 r
F
.59632 .24212 m .59472 .23985 L .59784 .23864 L F
.79777 .23889 m .79961 .23574 L .80099 .23779 L 0 .027 .127 r
F
.79777 .23889 m .79639 .23686 L .79961 .23574 L F
.1979 .23782 m .19879 .2347 L .20079 .2367 L 0 .025 .124 r
F
.1979 .23782 m .19589 .23583 L .19879 .2347 L F
.75403 .23874 m .75579 .23543 L .75723 .23757 L 0 .027 .126 r
F
.75403 .23874 m .7526 .23662 L .75579 .23543 L F
.24164 .2381 m .2426 .23494 L .24455 .23697 L 0 .026 .125 r
F
.24164 .2381 m .23968 .23605 L .2426 .23494 L F
.49323 .24265 m .49459 .23928 L .49628 .24145 L 0 .034 .136 r
F
.49323 .24265 m .49153 .24045 L .49459 .23928 L F
.16195 .23725 m .16277 .23417 L .16481 .23619 L 0 .024 .123 r
F
.16195 .23725 m .15991 .23522 L .16277 .23417 L F
.60413 .2418 m .60566 .23853 L .60724 .24068 L 0 .033 .134 r
F
.60413 .2418 m .60254 .23961 L .60566 .23853 L F
.50103 .24227 m .5024 .23914 L .50409 .24112 L 0 .034 .135 r
F
.50103 .24227 m .49934 .24027 L .5024 .23914 L F
.80559 .23862 m .80743 .23531 L .8088 .23739 L 0 .027 .126 r
F
.80559 .23862 m .80421 .23655 L .80743 .23531 L F
.45729 .24208 m .45859 .23892 L .46032 .24097 L 0 .034 .135 r
F
.45729 .24208 m .45555 .24 L .45859 .23892 L F
.28537 .23842 m .2864 .23531 L .28831 .23733 L 0 .027 .126 r
F
.28537 .23842 m .28346 .2364 L .2864 .23531 L F
.53697 .24297 m .5384 .23949 L .54005 .2418 L 0 .035 .136 r
F
.53697 .24297 m .53532 .24064 L .5384 .23949 L F
.20568 .23758 m .20658 .23449 L .20857 .23651 L 0 .025 .124 r
F
.20568 .23758 m .20368 .23558 L .20658 .23449 L F
.50883 .24192 m .51022 .23882 L .5119 .24078 L 0 .034 .135 r
F
.50883 .24192 m .50715 .23997 L .51022 .23882 L F
.67128 .24085 m .67293 .23779 L .67444 .23984 L 0 .031 .132 r
F
.67128 .24085 m .66977 .23879 L .67293 .23779 L F
.51804 .55597 m .51943 .5618 L .5211 .56352 L .931 .277 0 r
F
.51804 .55597 m .51637 .55425 L .51943 .5618 L F
.32131 .23914 m .3224 .23592 L .32427 .23803 L 0 .028 .127 r
F
.32131 .23914 m .31944 .23703 L .3224 .23592 L F
.38539 .24091 m .38659 .2375 L .38839 .23975 L 0 .031 .132 r
F
.38539 .24091 m .3836 .23864 L .38659 .2375 L F
.68689 .24006 m .68856 .23699 L .69005 .23894 L 0 .03 .13 r
F
.68689 .24006 m .6854 .23811 L .68856 .23699 L F
.24942 .2379 m .2504 .23466 L .25234 .23671 L 0 .026 .124 r
F
.24942 .2379 m .24747 .23585 L .2504 .23466 L F
.8134 .23835 m .81527 .23518 L .81664 .23729 L 0 .027 .126 r
F
.8134 .23835 m .81203 .23626 L .81527 .23518 L F
.16972 .23706 m .17057 .23392 L .1726 .23591 L 0 .024 .123 r
F
.16972 .23706 m .16769 .23506 L .17057 .23392 L F
.42134 .2416 m .42258 .23843 L .42435 .24061 L 0 .033 .134 r
F
.42134 .2416 m .41957 .23942 L .42258 .23843 L F
.76186 .23859 m .76363 .23534 L .76506 .23748 L 0 .027 .126 r
F
.76186 .23859 m .76043 .23645 L .76363 .23534 L F
.7025 .2393 m .7042 .23614 L .70567 .2381 L 0 .029 .128 r
F
.7025 .2393 m .70103 .23736 L .7042 .23614 L F
.35725 .23997 m .35839 .23683 L .36022 .23895 L 0 .03 .13 r
F
.35725 .23997 m .35541 .23784 L .35839 .23683 L F
.6947 .23975 m .69638 .23665 L .69787 .23858 L F
.6947 .23975 m .69322 .23782 L .69638 .23665 L F
.61194 .24172 m .61348 .2384 L .61506 .24054 L 0 .033 .134 r
F
.61194 .24172 m .61036 .23957 L .61348 .2384 L F
.6791 .24064 m .68075 .23741 L .68225 .23937 L 0 .031 .131 r
F
.6791 .24064 m .67759 .23866 L .68075 .23741 L F
.46508 .24195 m .4664 .23876 L .46812 .24081 L 0 .034 .135 r
F
.46508 .24195 m .46336 .23986 L .4664 .23876 L F
.63535 .24044 m .63693 .23729 L .63848 .23935 L 0 .031 .131 r
F
.63535 .24044 m .6338 .2384 L .63693 .23729 L F
.71031 .23893 m .71201 .23569 L .71348 .23773 L 0 .028 .127 r
F
.71031 .23893 m .70884 .2369 L .71201 .23569 L F
.2572 .23767 m .2582 .23439 L .26013 .23655 L 0 .025 .124 r
F
.2572 .23767 m .25527 .23552 L .2582 .23439 L F
.51664 .24182 m .51803 .23856 L .5197 .24073 L 0 .034 .135 r
F
.51664 .24182 m .51496 .23967 L .51803 .23856 L F
.1775 .23687 m .17835 .23373 L .18037 .23581 L 0 .024 .123 r
F
.1775 .23687 m .17548 .23479 L .17835 .23373 L F
.32909 .23904 m .3302 .23577 L .33206 .2379 L 0 .028 .128 r
F
.32909 .23904 m .32723 .2369 L .3302 .23577 L F
.21344 .23754 m .21435 .23443 L .21634 .23651 L 0 .026 .124 r
F
.21344 .23754 m .21146 .23547 L .21435 .23443 L F
.29314 .23843 m .29419 .23524 L .29608 .23741 L 0 .027 .126 r
F
.29314 .23843 m .29125 .23627 L .29419 .23524 L F
.54478 .24298 m .54622 .23964 L .54786 .2419 L 0 .036 .137 r
F
.54478 .24298 m .54313 .2407 L .54622 .23964 L F
.71812 .23865 m .71984 .2355 L .72131 .23759 L 0 .028 .127 r
F
.71812 .23865 m .71666 .23655 L .71984 .2355 L F
.39318 .24082 m .39439 .23742 L .39618 .23963 L 0 .031 .132 r
F
.39318 .24082 m .39139 .23859 L .39439 .23742 L F
.56819 .24169 m .56967 .23835 L .57128 .24038 L 0 .033 .134 r
F
.56819 .24169 m .56657 .23968 L .56967 .23835 L F
.61975 .24148 m .6213 .23805 L .62287 .24024 L 0 .033 .133 r
F
.61975 .24148 m .61818 .2393 L .6213 .23805 L F
.47288 .24173 m .47421 .23851 L .47593 .2406 L 0 .034 .135 r
F
.47288 .24173 m .47116 .23966 L .47421 .23851 L F
.576 .2413 m .57749 .23823 L .5791 .24024 L 0 .033 .134 r
F
.576 .2413 m .57438 .23928 L .57749 .23823 L F
.62755 .24109 m .62911 .2376 L .63067 .23973 L 0 .032 .132 r
F
.62755 .24109 m .62599 .23893 L .62911 .2376 L F
.76969 .2385 m .77148 .2353 L .7729 .23744 L 0 .027 .127 r
F
.76969 .2385 m .76827 .23637 L .77148 .2353 L F
.64316 .24033 m .64476 .23709 L .6463 .2392 L 0 .031 .131 r
F
.64316 .24033 m .64162 .23826 L .64476 .23709 L F
.40098 .24057 m .4022 .23723 L .40399 .23936 L 0 .031 .132 r
F
.40098 .24057 m .39919 .23844 L .4022 .23723 L F
.56039 .24231 m .56185 .23902 L .56348 .24102 L 0 .035 .136 r
F
.56039 .24231 m .55876 .24034 L .56185 .23902 L F
.33688 .23886 m .338 .23553 L .33985 .23768 L 0 .028 .128 r
F
.33688 .23886 m .33503 .23672 L .338 .23553 L F
.36503 .23995 m .36619 .2367 L .36801 .23878 L 0 .03 .13 r
F
.36503 .23995 m .3632 .23789 L .36619 .2367 L F
.42912 .24173 m .43039 .23828 L .43214 .24053 L 0 .034 .134 r
F
.42912 .24173 m .42737 .2395 L .43039 .23828 L F
.1415 .2366 m .14232 .23334 L .14437 .23547 L 0 .024 .122 r
F
.1415 .2366 m .13945 .23447 L .14232 .23334 L F
.5838 .24115 m .58531 .23806 L .58691 .24006 L 0 .033 .134 r
F
.5838 .24115 m .5822 .23917 L .58531 .23806 L F
.26497 .23769 m .26597 .23451 L .26789 .23667 L 0 .026 .125 r
F
.26497 .23769 m .26305 .23553 L .26597 .23451 L F
.22121 .2375 m .22215 .23417 L .22412 .23632 L 0 .026 .124 r
F
.22121 .2375 m .21924 .23535 L .22215 .23417 L F
.52444 .24183 m .52585 .2384 L .52751 .24067 L 0 .034 .135 r
F
.52444 .24183 m .52277 .23957 L .52585 .2384 L F
.65098 .2401 m .65258 .2368 L .65412 .23893 L 0 .031 .131 r
F
.65098 .2401 m .64944 .238 L .65258 .2368 L F
.55259 .24292 m .55404 .2395 L .55567 .24163 L 0 .036 .138 r
F
.55259 .24292 m .55095 .2408 L .55404 .2395 L F
.72595 .2386 m .72768 .23538 L .72913 .23743 L 0 .028 .127 r
F
.72595 .2386 m .72449 .23653 L .72768 .23538 L F
.48068 .24163 m .48202 .23827 L .48373 .24049 L 0 .034 .135 r
F
.48068 .24163 m .47897 .23945 L .48202 .23827 L F
.40878 .24034 m .41 .23731 L .41178 .23935 L 0 .032 .132 r
F
.40878 .24034 m .40699 .23831 L .41 .23731 L F
.18525 .23689 m .18613 .23371 L .18813 .23584 L 0 .025 .123 r
F
.18525 .23689 m .18325 .23476 L .18613 .23371 L F
.37282 .23971 m .37399 .23646 L .37581 .2386 L 0 .03 .13 r
F
.37282 .23971 m .371 .23761 L .37399 .23646 L F
.73377 .23827 m .7355 .23496 L .73694 .23702 L 0 .027 .126 r
F
.73377 .23827 m .73231 .2362 L .7355 .23496 L F
.34467 .23871 m .34579 .23556 L .34763 .23771 L 0 .028 .128 r
F
.34467 .23871 m .34282 .23657 L .34579 .23556 L F
.77753 .23852 m .77933 .23524 L .78074 .23738 L 0 .028 .127 r
F
.77753 .23852 m .77611 .23637 L .77933 .23524 L F
.43692 .24156 m .4382 .23813 L .43995 .24038 L 0 .034 .135 r
F
.43692 .24156 m .43517 .23933 L .4382 .23813 L F
.3009 .23857 m .30197 .23522 L .30386 .2374 L 0 .028 .127 r
F
.3009 .23857 m .29902 .23639 L .30197 .23522 L F
.65879 .23988 m .66041 .23667 L .66194 .23877 L 0 .031 .131 r
F
.65879 .23988 m .65726 .2378 L .66041 .23667 L F
.14928 .23643 m .15011 .23313 L .15215 .23527 L 0 .024 .122 r
F
.14928 .23643 m .14723 .2343 L .15011 .23313 L F
.22899 .23731 m .22994 .23403 L .2319 .2362 L 0 .026 .124 r
F
.22899 .23731 m .22703 .23516 L .22994 .23403 L F
.74158 .23798 m .74334 .23488 L .74478 .2369 L 0 .027 .126 r
F
.74158 .23798 m .74014 .23594 L .74334 .23488 L F
.59162 .24102 m .59313 .2378 L .59472 .23985 L 0 .033 .134 r
F
.59162 .24102 m .59002 .23896 L .59313 .2378 L F
.44472 .24125 m .44601 .23805 L .44775 .24012 L F
.44472 .24125 m .44297 .2392 L .44601 .23805 L F
.78535 .23828 m .78716 .23493 L .78855 .23703 L 0 .027 .127 r
F
.78535 .23828 m .78395 .23616 L .78716 .23493 L F
.53224 .24179 m .53367 .23842 L .53532 .24064 L 0 .034 .136 r
F
.53224 .24179 m .53059 .23952 L .53367 .23842 L F
.27274 .23768 m .27375 .23453 L .27567 .23659 L 0 .027 .126 r
F
.27274 .23768 m .27082 .23561 L .27375 .23453 L F
.30869 .23835 m .30977 .23503 L .31165 .23718 L 0 .028 .127 r
F
.30869 .23835 m .30681 .23621 L .30977 .23503 L F
.48848 .24161 m .48984 .2382 L .49153 .24045 L 0 .034 .135 r
F
.48848 .24161 m .48678 .23935 L .48984 .2382 L F
.79316 .23794 m .795 .23482 L .79639 .23686 L 0 .027 .127 r
F
.79316 .23794 m .79178 .23592 L .795 .23482 L F
.38061 .23969 m .38179 .23643 L .3836 .23864 L 0 .03 .131 r
F
.38061 .23969 m .3788 .23752 L .38179 .23643 L F
.19301 .2369 m .19389 .23373 L .19589 .23583 L 0 .025 .124 r
F
.19301 .2369 m .19101 .23479 L .19389 .23373 L F
.15705 .23628 m .15787 .23313 L .15991 .23522 L 0 .024 .123 r
F
.15705 .23628 m .15501 .23417 L .15787 .23313 L F
.41656 .2404 m .4178 .23737 L .41957 .23942 L 0 .032 .133 r
F
.41656 .2404 m .41479 .23836 L .4178 .23737 L F
.23677 .23716 m .23772 .23398 L .23968 .23605 L 0 .026 .125 r
F
.23677 .23716 m .23481 .23508 L .23772 .23398 L F
.7494 .23781 m .75117 .2346 L .7526 .23662 L 0 .027 .126 r
F
.7494 .23781 m .74797 .23578 L .75117 .2346 L F
.59943 .24086 m .60095 .23742 L .60254 .23961 L 0 .033 .133 r
F
.59943 .24086 m .59784 .23864 L .60095 .23742 L F
.45252 .24109 m .45381 .23798 L .45555 .24 L 0 .034 .135 r
F
.45252 .24109 m .45078 .23905 L .45381 .23798 L F
.66661 .2398 m .66825 .23665 L .66977 .23879 L 0 .031 .131 r
F
.66661 .2398 m .66509 .23768 L .66825 .23665 L F
.31648 .23815 m .31757 .23491 L .31944 .23703 L 0 .028 .127 r
F
.31648 .23815 m .31461 .23604 L .31757 .23491 L F
.28052 .2375 m .28154 .23439 L .28346 .2364 L 0 .027 .126 r
F
.28052 .2375 m .2786 .23549 L .28154 .23439 L F
.51917 .54897 m .5206 .52829 L .52225 .54804 L .882 .45 0 r
F
.35244 .23885 m .35358 .23572 L .35541 .23784 L 0 .029 .129 r
F
.35244 .23885 m .3506 .23671 L .35358 .23572 L F
.49628 .24145 m .49765 .23811 L .49934 .24027 L 0 .034 .135 r
F
.49628 .24145 m .49459 .23928 L .49765 .23811 L F
.20079 .2367 m .20168 .23357 L .20368 .23558 L 0 .025 .124 r
F
.20079 .2367 m .19879 .2347 L .20168 .23357 L F
.75723 .23757 m .759 .2343 L .76043 .23645 L 0 .027 .126 r
F
.75723 .23757 m .75579 .23543 L .759 .2343 L F
.80099 .23779 m .80283 .23448 L .80421 .23655 L F
.80099 .23779 m .79961 .23574 L .80283 .23448 L F
.8088 .23739 m .81066 .23416 L .81203 .23626 L 0 .026 .126 r
F
.8088 .23739 m .80743 .23531 L .81066 .23416 L F
.24455 .23697 m .24552 .23383 L .24747 .23585 L 0 .026 .125 r
F
.24455 .23697 m .2426 .23494 L .24552 .23383 L F
.60724 .24068 m .60878 .23744 L .61036 .23957 L 0 .033 .134 r
F
.60724 .24068 m .60566 .23853 L .60878 .23744 L F
.50409 .24112 m .50547 .23801 L .50715 .23997 L 0 .034 .135 r
F
.50409 .24112 m .5024 .23914 L .50547 .23801 L F
.54005 .2418 m .54149 .23842 L .54313 .2407 L 0 .035 .136 r
F
.54005 .2418 m .5384 .23949 L .54149 .23842 L F
.16481 .23619 m .16565 .23305 L .16769 .23506 L 0 .024 .123 r
F
.16481 .23619 m .16277 .23417 L .16565 .23305 L F
.46032 .24097 m .46163 .23784 L .46336 .23986 L 0 .034 .135 r
F
.46032 .24097 m .45859 .23892 L .46163 .23784 L F
.5119 .24078 m .51329 .23766 L .51496 .23967 L 0 .034 .134 r
F
.5119 .24078 m .51022 .23882 L .51329 .23766 L F
.28831 .23733 m .28934 .23425 L .29125 .23627 L 0 .027 .126 r
F
.28831 .23733 m .2864 .23531 L .28934 .23425 L F
.25234 .23671 m .25333 .23348 L .25527 .23552 L 0 .025 .124 r
F
.25234 .23671 m .2504 .23466 L .25333 .23348 L F
.38839 .23975 m .38959 .23636 L .39139 .23859 L 0 .031 .131 r
F
.38839 .23975 m .38659 .2375 L .38959 .23636 L F
.20857 .23651 m .20947 .23345 L .21146 .23547 L 0 .025 .124 r
F
.20857 .23651 m .20658 .23449 L .20947 .23345 L F
.32427 .23803 m .32536 .23483 L .32723 .2369 L 0 .028 .127 r
F
.32427 .23803 m .3224 .23592 L .32536 .23483 L F
.69005 .23894 m .69173 .23588 L .69322 .23782 L 0 .03 .13 r
F
.69005 .23894 m .68856 .23699 L .69173 .23588 L F
.68225 .23937 m .6839 .23616 L .6854 .23811 L 0 .031 .131 r
F
.68225 .23937 m .68075 .23741 L .6839 .23616 L F
.1726 .23591 m .17345 .23281 L .17548 .23479 L 0 .024 .123 r
F
.1726 .23591 m .17057 .23392 L .17345 .23281 L F
.70567 .2381 m .70737 .23493 L .70884 .2369 L 0 .028 .128 r
F
.70567 .2381 m .7042 .23614 L .70737 .23493 L F
.67444 .23984 m .67609 .23662 L .67759 .23866 L 0 .032 .132 r
F
.67444 .23984 m .67293 .23779 L .67609 .23662 L F
.76506 .23748 m .76684 .23423 L .76827 .23637 L 0 .027 .126 r
F
.76506 .23748 m .76363 .23534 L .76684 .23423 L F
.69787 .23858 m .69955 .23542 L .70103 .23736 L 0 .029 .129 r
F
.69787 .23858 m .69638 .23665 L .69955 .23542 L F
.81664 .23729 m .81851 .2341 L .81988 .23623 L 0 .027 .126 r
F
.81664 .23729 m .81527 .23518 L .81851 .2341 L F
.61506 .24054 m .6166 .23716 L .61818 .2393 L 0 .033 .134 r
F
.61506 .24054 m .61348 .2384 L .6166 .23716 L F
.71348 .23773 m .71519 .23451 L .71666 .23655 L 0 .028 .127 r
F
.71348 .23773 m .71201 .23569 L .71519 .23451 L F
.46812 .24081 m .46944 .23759 L .47116 .23966 L 0 .034 .135 r
F
.46812 .24081 m .4664 .23876 L .46944 .23759 L F
.57128 .24038 m .57277 .23724 L .57438 .23928 L 0 .033 .134 r
F
.57128 .24038 m .56967 .23835 L .57277 .23724 L F
.63067 .23973 m .63224 .2363 L .6338 .2384 L 0 .031 .132 r
F
.63067 .23973 m .62911 .2376 L .63224 .2363 L F
.42435 .24061 m .4256 .23732 L .42737 .2395 L 0 .033 .134 r
F
.42435 .24061 m .42258 .23843 L .4256 .23732 L F
.63848 .23935 m .64007 .23618 L .64162 .23826 L 0 .031 .131 r
F
.63848 .23935 m .63693 .23729 L .64007 .23618 L F
.26013 .23655 m .26112 .23337 L .26305 .23553 L 0 .025 .124 r
F
.26013 .23655 m .2582 .23439 L .26112 .23337 L F
.62287 .24024 m .62442 .23676 L .62599 .23893 L 0 .032 .133 r
F
.62287 .24024 m .6213 .23805 L .62442 .23676 L F
.36022 .23895 m .36137 .23578 L .3632 .23789 L 0 .03 .13 r
F
.36022 .23895 m .35839 .23683 L .36137 .23578 L F
.39618 .23963 m .3974 .23623 L .39919 .23844 L 0 .031 .132 r
F
.39618 .23963 m .39439 .23742 L .3974 .23623 L F
.33206 .2379 m .33317 .23459 L .33503 .23672 L 0 .028 .127 r
F
.33206 .2379 m .3302 .23577 L .33317 .23459 L F
.5197 .24073 m .52111 .23737 L .52277 .23957 L 0 .033 .134 r
F
.5197 .24073 m .51803 .23856 L .52111 .23737 L F
.18037 .23581 m .18123 .23266 L .18325 .23476 L 0 .024 .123 r
F
.18037 .23581 m .17835 .23373 L .18123 .23266 L F
.56348 .24102 m .56495 .23767 L .56657 .23968 L 0 .034 .135 r
F
.56348 .24102 m .56185 .23902 L .56495 .23767 L F
.47593 .2406 m .47726 .23734 L .47897 .23945 L 0 .033 .134 r
F
.47593 .2406 m .47421 .23851 L .47726 .23734 L F
.54786 .2419 m .54931 .23855 L .55095 .2408 L 0 .036 .137 r
F
.54786 .2419 m .54622 .23964 L .54931 .23855 L F
.72131 .23759 m .72303 .23445 L .72449 .23653 L 0 .028 .127 r
F
.72131 .23759 m .71984 .2355 L .72303 .23445 L F
.21634 .23651 m .21726 .23327 L .21924 .23535 L 0 .026 .124 r
F
.21634 .23651 m .21435 .23443 L .21726 .23327 L F
.29608 .23741 m .29713 .23421 L .29902 .23639 L 0 .027 .127 r
F
.29608 .23741 m .29419 .23524 L .29713 .23421 L F
.40399 .23936 m .40521 .23617 L .40699 .23831 L 0 .031 .132 r
F
.40399 .23936 m .4022 .23723 L .40521 .23617 L F
.5791 .24024 m .58059 .23716 L .5822 .23917 L 0 .033 .134 r
F
.5791 .24024 m .57749 .23823 L .58059 .23716 L F
.7729 .23744 m .7747 .23423 L .77611 .23637 L 0 .027 .127 r
F
.7729 .23744 m .77148 .2353 L .7747 .23423 L F
.33985 .23768 m .34098 .23442 L .34282 .23657 L 0 .028 .127 r
F
.33985 .23768 m .338 .23553 L .34098 .23442 L F
.6463 .2392 m .6479 .23586 L .64944 .238 L 0 .031 .131 r
F
.6463 .2392 m .64476 .23709 L .6479 .23586 L F
.36801 .23878 m .36918 .2355 L .371 .23761 L 0 .03 .13 r
F
.36801 .23878 m .36619 .2367 L .36918 .2355 L F
.43214 .24053 m .43342 .23706 L .43517 .23933 L 0 .033 .134 r
F
.43214 .24053 m .43039 .23828 L .43342 .23706 L F
.55567 .24163 m .55713 .2382 L .55876 .24034 L 0 .036 .137 r
F
.55567 .24163 m .55404 .2395 L .55713 .2382 L F
.22412 .23632 m .22507 .233 L .22703 .23516 L 0 .025 .124 r
F
.22412 .23632 m .22215 .23417 L .22507 .233 L F
.14437 .23547 m .14519 .23216 L .14723 .2343 L 0 .024 .122 r
F
.14437 .23547 m .14232 .23334 L .14519 .23216 L F
.65412 .23893 m .65573 .23565 L .65726 .2378 L 0 .03 .131 r
F
.65412 .23893 m .65258 .2368 L .65573 .23565 L F
.52751 .24067 m .52893 .23726 L .53059 .23952 L 0 .034 .135 r
F
.52751 .24067 m .52585 .2384 L .52893 .23726 L F
.72913 .23743 m .73086 .23416 L .73231 .2362 L 0 .028 .127 r
F
.72913 .23743 m .72768 .23538 L .73086 .23416 L F
.73694 .23702 m .7387 .2339 L .74014 .23594 L 0 .027 .126 r
F
.73694 .23702 m .7355 .23496 L .7387 .2339 L F
.48373 .24049 m .48508 .23709 L .48678 .23935 L 0 .033 .134 r
F
.48373 .24049 m .48202 .23827 L .48508 .23709 L F
.58691 .24006 m .58842 .23695 L .59002 .23896 L F
.58691 .24006 m .58531 .23806 L .58842 .23695 L F
.37581 .2386 m .37699 .23534 L .3788 .23752 L 0 .03 .13 r
F
.37581 .2386 m .37399 .23646 L .37699 .23534 L F
.26789 .23667 m .2689 .23346 L .27082 .23561 L 0 .026 .125 r
F
.26789 .23667 m .26597 .23451 L .2689 .23346 L F
.43995 .24038 m .44123 .23692 L .44297 .2392 L 0 .033 .134 r
F
.43995 .24038 m .4382 .23813 L .44123 .23692 L F
.18813 .23584 m .18901 .23266 L .19101 .23479 L 0 .025 .123 r
F
.18813 .23584 m .18613 .23371 L .18901 .23266 L F
.78074 .23738 m .78254 .23404 L .78395 .23616 L 0 .028 .127 r
F
.78074 .23738 m .77933 .23524 L .78254 .23404 L F
.41178 .23935 m .41301 .23631 L .41479 .23836 L 0 .032 .133 r
F
.41178 .23935 m .41 .23731 L .41301 .23631 L F
.30386 .2374 m .30493 .23403 L .30681 .23621 L 0 .028 .127 r
F
.30386 .2374 m .30197 .23522 L .30493 .23403 L F
.15215 .23527 m .15297 .23204 L .15501 .23417 L 0 .024 .122 r
F
.15215 .23527 m .15011 .23313 L .15297 .23204 L F
.78855 .23703 m .79038 .23383 L .79178 .23592 L 0 .027 .127 r
F
.78855 .23703 m .78716 .23493 L .79038 .23383 L F
.66194 .23877 m .66356 .23556 L .66509 .23768 L 0 .031 .131 r
F
.66194 .23877 m .66041 .23667 L .66356 .23556 L F
.59472 .23985 m .59624 .23658 L .59784 .23864 L 0 .033 .133 r
F
.59472 .23985 m .59313 .2378 L .59624 .23658 L F
.34763 .23771 m .34876 .23454 L .3506 .23671 L 0 .029 .128 r
F
.34763 .23771 m .34579 .23556 L .34876 .23454 L F
.2319 .2362 m .23286 .2329 L .23481 .23508 L 0 .026 .124 r
F
.2319 .2362 m .22994 .23403 L .23286 .2329 L F
.44775 .24012 m .44904 .23701 L .45078 .23905 L 0 .034 .134 r
F
.44775 .24012 m .44601 .23805 L .44904 .23701 L F
.74478 .2369 m .74654 .23377 L .74797 .23578 L 0 .027 .126 r
F
.74478 .2369 m .74334 .23488 L .74654 .23377 L F
.53532 .24064 m .53675 .23731 L .5384 .23949 L 0 .034 .135 r
F
.53532 .24064 m .53367 .23842 L .53675 .23731 L F
.31165 .23718 m .31273 .23388 L .31461 .23604 L 0 .028 .127 r
F
.31165 .23718 m .30977 .23503 L .31273 .23388 L F
.49153 .24045 m .49289 .23704 L .49459 .23928 L 0 .034 .135 r
F
.49153 .24045 m .48984 .2382 L .49289 .23704 L F
.60254 .23961 m .60407 .23637 L .60566 .23853 L 0 .032 .133 r
F
.60254 .23961 m .60095 .23742 L .60407 .23637 L F
.27567 .23659 m .27668 .23345 L .2786 .23549 L 0 .027 .126 r
F
.27567 .23659 m .27375 .23453 L .27668 .23345 L F
.7526 .23662 m .75437 .23341 L .75579 .23543 L F
.7526 .23662 m .75117 .2346 L .75437 .23341 L F
.79639 .23686 m .79823 .23368 L .79961 .23574 L 0 .027 .127 r
F
.79639 .23686 m .795 .23482 L .79823 .23368 L F
.3836 .23864 m .38479 .23531 L .38659 .2375 L 0 .03 .131 r
F
.3836 .23864 m .38179 .23643 L .38479 .23531 L F
.23968 .23605 m .24064 .23289 L .2426 .23494 L 0 .026 .125 r
F
.23968 .23605 m .23772 .23398 L .24064 .23289 L F
.19589 .23583 m .19679 .23259 L .19879 .2347 L 0 .025 .124 r
F
.19589 .23583 m .19389 .23373 L .19679 .23259 L F
.15991 .23522 m .16074 .23208 L .16277 .23417 L 0 .024 .123 r
F
.15991 .23522 m .15787 .23313 L .16074 .23208 L F
.45555 .24 m .45685 .23692 L .45859 .23892 L 0 .034 .135 r
F
.45555 .24 m .45381 .23798 L .45685 .23692 L F
.80421 .23655 m .80605 .23322 L .80743 .23531 L 0 .027 .126 r
F
.80421 .23655 m .80283 .23448 L .80605 .23322 L F
.49934 .24027 m .50071 .237 L .5024 .23914 L 0 .034 .135 r
F
.49934 .24027 m .49765 .23811 L .50071 .237 L F
.31944 .23703 m .32053 .23381 L .3224 .23592 L 0 .028 .127 r
F
.31944 .23703 m .31757 .23491 L .32053 .23381 L F
.41957 .23942 m .42081 .23638 L .42258 .23843 L 0 .033 .134 r
F
.41957 .23942 m .4178 .23737 L .42081 .23638 L F
.28346 .2364 m .28448 .23329 L .2864 .23531 L 0 .027 .126 r
F
.28346 .2364 m .28154 .23439 L .28448 .23329 L F
.66977 .23879 m .67141 .23562 L .67293 .23779 L 0 .031 .132 r
F
.66977 .23879 m .66825 .23665 L .67141 .23562 L F
.51637 .55425 m .51777 .55188 L .51943 .5618 L .917 .331 0 r
F
.20368 .23558 m .20458 .23248 L .20658 .23449 L 0 .025 .124 r
F
.20368 .23558 m .20168 .23357 L .20458 .23248 L F
.76043 .23645 m .76221 .23319 L .76363 .23534 L 0 .027 .126 r
F
.76043 .23645 m .759 .2343 L .76221 .23319 L F
.81203 .23626 m .8139 .23307 L .81527 .23518 L 0 .026 .126 r
F
.81203 .23626 m .81066 .23416 L .8139 .23307 L F
.24747 .23585 m .24844 .23266 L .2504 .23466 L 0 .026 .125 r
F
.24747 .23585 m .24552 .23383 L .24844 .23266 L F
.50715 .23997 m .50853 .23685 L .51022 .23882 L 0 .034 .135 r
F
.50715 .23997 m .50547 .23801 L .50853 .23685 L F
.61036 .23957 m .6119 .23631 L .61348 .2384 L 0 .033 .134 r
F
.61036 .23957 m .60878 .23744 L .6119 .23631 L F
.35541 .23784 m .35655 .23472 L .35839 .23683 L 0 .03 .13 r
F
.35541 .23784 m .35358 .23572 L .35655 .23472 L F
.16769 .23506 m .16853 .23192 L .17057 .23392 L 0 .024 .123 r
F
.16769 .23506 m .16565 .23305 L .16853 .23192 L F
.54313 .2407 m .54457 .23737 L .54622 .23964 L 0 .035 .136 r
F
.54313 .2407 m .54149 .23842 L .54457 .23737 L F
.6854 .23811 m .68707 .23505 L .68856 .23699 L 0 .03 .131 r
F
.6854 .23811 m .6839 .23616 L .68707 .23505 L F
.25527 .23552 m .25625 .23236 L .2582 .23439 L 0 .025 .124 r
F
.25527 .23552 m .25333 .23348 L .25625 .23236 L F
.46336 .23986 m .46467 .23676 L .4664 .23876 L 0 .034 .135 r
F
.46336 .23986 m .46163 .23784 L .46467 .23676 L F
.51496 .23967 m .51636 .23651 L .51803 .23856 L 0 .033 .134 r
F
.51496 .23967 m .51329 .23766 L .51636 .23651 L F
.39139 .23859 m .3926 .2352 L .39439 .23742 L 0 .031 .131 r
F
.39139 .23859 m .38959 .23636 L .3926 .2352 L F
.6338 .2384 m .63538 .2352 L .63693 .23729 L F
.6338 .2384 m .63224 .2363 L .63538 .2352 L F
.70884 .2369 m .71054 .23372 L .71201 .23569 L 0 .028 .127 r
F
.70884 .2369 m .70737 .23493 L .71054 .23372 L F
.32723 .2369 m .32833 .23372 L .3302 .23577 L F
.32723 .2369 m .32536 .23483 L .32833 .23372 L F
.61818 .2393 m .61973 .23591 L .6213 .23805 L 0 .032 .133 r
F
.61818 .2393 m .6166 .23716 L .61973 .23591 L F
.29125 .23627 m .29228 .23321 L .29419 .23524 L 0 .027 .126 r
F
.29125 .23627 m .28934 .23425 L .29228 .23321 L F
.70103 .23736 m .70272 .23419 L .7042 .23614 L 0 .029 .129 r
F
.70103 .23736 m .69955 .23542 L .70272 .23419 L F
.67759 .23866 m .67924 .23537 L .68075 .23741 L 0 .031 .132 r
F
.67759 .23866 m .67609 .23662 L .67924 .23537 L F
.69322 .23782 m .6949 .23471 L .69638 .23665 L 0 .03 .13 r
F
.69322 .23782 m .69173 .23588 L .6949 .23471 L F
.17548 .23479 m .17632 .23174 L .17835 .23373 L 0 .024 .123 r
F
.17548 .23479 m .17345 .23281 L .17632 .23174 L F
.62599 .23893 m .62755 .23546 L .62911 .2376 L 0 .031 .132 r
F
.62599 .23893 m .62442 .23676 L .62755 .23546 L F
.71666 .23655 m .71838 .23345 L .71984 .2355 L 0 .027 .127 r
F
.71666 .23655 m .71519 .23451 L .71838 .23345 L F
.21146 .23547 m .21236 .23241 L .21435 .23443 L 0 .026 .124 r
F
.21146 .23547 m .20947 .23345 L .21236 .23241 L F
.76827 .23637 m .77006 .23316 L .77148 .2353 L 0 .027 .126 r
F
.76827 .23637 m .76684 .23423 L .77006 .23316 L F
.47116 .23966 m .47249 .23641 L .47421 .23851 L 0 .034 .134 r
F
.47116 .23966 m .46944 .23759 L .47249 .23641 L F
.56657 .23968 m .56805 .23632 L .56967 .23835 L 0 .033 .134 r
F
.56657 .23968 m .56495 .23767 L .56805 .23632 L F
.57438 .23928 m .57587 .23617 L .57749 .23823 L F
.57438 .23928 m .57277 .23724 L .57587 .23617 L F
.42737 .2395 m .42863 .23609 L .43039 .23828 L F
.42737 .2395 m .4256 .23732 L .42863 .23609 L F
.39919 .23844 m .40041 .23505 L .4022 .23723 L 0 .031 .131 r
F
.39919 .23844 m .3974 .23623 L .40041 .23505 L F
.33503 .23672 m .33615 .23342 L .338 .23553 L 0 .028 .127 r
F
.33503 .23672 m .33317 .23459 L .33615 .23342 L F
.64162 .23826 m .64321 .23499 L .64476 .23709 L 0 .031 .131 r
F
.64162 .23826 m .64007 .23618 L .64321 .23499 L F
.52277 .23957 m .52418 .23618 L .52585 .2384 L 0 .033 .134 r
F
.52277 .23957 m .52111 .23737 L .52418 .23618 L F
.52701 .5491 m .52841 .53038 L .53008 .53999 L .887 .435 0 r
F
.52701 .5491 m .52534 .5392 L .52841 .53038 L F
.3632 .23789 m .36436 .23459 L .36619 .2367 L 0 .03 .13 r
F
.3632 .23789 m .36137 .23578 L .36436 .23459 L F
.26305 .23553 m .26404 .23234 L .26597 .23451 L 0 .026 .125 r
F
.26305 .23553 m .26112 .23337 L .26404 .23234 L F
.47897 .23945 m .48031 .23614 L .48202 .23827 L 0 .033 .134 r
F
.47897 .23945 m .47726 .23734 L .48031 .23614 L F
.21924 .23535 m .22018 .23209 L .22215 .23417 L 0 .025 .124 r
F
.21924 .23535 m .21726 .23327 L .22018 .23209 L F
.55876 .24034 m .56022 .23688 L .56185 .23902 L 0 .035 .136 r
F
.55876 .24034 m .55713 .2382 L .56022 .23688 L F
.55095 .2408 m .5524 .23725 L .55404 .2395 L 0 .036 .137 r
F
.55095 .2408 m .54931 .23855 L .5524 .23725 L F
.64944 .238 m .65104 .23463 L .65258 .2368 L 0 .03 .131 r
F
.64944 .238 m .6479 .23586 L .65104 .23463 L F
.18325 .23476 m .18411 .23161 L .18613 .23371 L 0 .025 .123 r
F
.18325 .23476 m .18123 .23266 L .18411 .23161 L F
.43517 .23933 m .43645 .23584 L .4382 .23813 L 0 .033 .134 r
F
.43517 .23933 m .43342 .23706 L .43645 .23584 L F
.371 .23761 m .37218 .23433 L .37399 .23646 L 0 .03 .13 r
F
.371 .23761 m .36918 .2355 L .37218 .23433 L F
.72449 .23653 m .72622 .23332 L .72768 .23538 L 0 .028 .127 r
F
.72449 .23653 m .72303 .23445 L .72622 .23332 L F
.5822 .23917 m .5837 .23603 L .58531 .23806 L 0 .033 .134 r
F
.5822 .23917 m .58059 .23716 L .5837 .23603 L F
.34282 .23657 m .34395 .23339 L .34579 .23556 L 0 .028 .128 r
F
.34282 .23657 m .34098 .23442 L .34395 .23339 L F
.40699 .23831 m .40821 .23516 L .41 .23731 L 0 .031 .132 r
F
.40699 .23831 m .40521 .23617 L .40821 .23516 L F
.77611 .23637 m .77792 .23311 L .77933 .23524 L 0 .027 .127 r
F
.77611 .23637 m .7747 .23423 L .77792 .23311 L F
.532 .55428 m .53035 .56075 L .53342 .55135 L .917 .331 0 r
F
.52893 .56341 m .53035 .56075 L .532 .55428 L .948 .215 0 r
F
.29902 .23639 m .30008 .23303 L .30197 .23522 L 0 .027 .127 r
F
.29902 .23639 m .29713 .23421 L .30008 .23303 L F
.73231 .2362 m .73405 .23294 L .7355 .23496 L 0 .027 .126 r
F
.73231 .2362 m .73086 .23416 L .73405 .23294 L F
.51777 .55188 m .51611 .54199 L .51917 .54897 L .917 .331 0 r
F
.22703 .23516 m .22798 .23186 L .22994 .23403 L 0 .025 .124 r
F
.22703 .23516 m .22507 .233 L .22798 .23186 L F
.14723 .2343 m .14806 .23099 L .15011 .23313 L 0 .024 .122 r
F
.14723 .2343 m .14519 .23216 L .14806 .23099 L F
.53059 .23952 m .53201 .23619 L .53367 .23842 L 0 .034 .135 r
F
.53059 .23952 m .52893 .23726 L .53201 .23619 L F
.65726 .2378 m .65888 .23451 L .66041 .23667 L 0 .03 .131 r
F
.65726 .2378 m .65573 .23565 L .65888 .23451 L F
.48678 .23935 m .48813 .23595 L .48984 .2382 L 0 .033 .134 r
F
.48678 .23935 m .48508 .23709 L .48813 .23595 L F
.59002 .23896 m .59153 .23577 L .59313 .2378 L F
.59002 .23896 m .58842 .23695 L .59153 .23577 L F
.78395 .23616 m .78575 .23283 L .78716 .23493 L 0 .027 .127 r
F
.78395 .23616 m .78254 .23404 L .78575 .23283 L F
.74014 .23594 m .7419 .23285 L .74334 .23488 L 0 .027 .126 r
F
.74014 .23594 m .7387 .2339 L .7419 .23285 L F
.44297 .2392 m .44426 .23577 L .44601 .23805 L 0 .033 .134 r
F
.44297 .2392 m .44123 .23692 L .44426 .23577 L F
.30681 .23621 m .30789 .23285 L .30977 .23503 L 0 .027 .127 r
F
.30681 .23621 m .30493 .23403 L .30789 .23285 L F
.3788 .23752 m .37999 .23421 L .38179 .23643 L 0 .03 .13 r
F
.3788 .23752 m .37699 .23534 L .37999 .23421 L F
.59784 .23864 m .59936 .23537 L .60095 .23742 L 0 .032 .133 r
F
.59784 .23864 m .59624 .23658 L .59936 .23537 L F
.27082 .23561 m .27183 .2324 L .27375 .23453 L 0 .026 .126 r
F
.27082 .23561 m .2689 .23346 L .27183 .2324 L F
.19101 .23479 m .19189 .2316 L .19389 .23373 L 0 .025 .124 r
F
.19101 .23479 m .18901 .23266 L .19189 .2316 L F
.15501 .23417 m .15583 .23099 L .15787 .23313 L 0 .024 .122 r
F
.15501 .23417 m .15297 .23204 L .15583 .23099 L F
.79178 .23592 m .79361 .23275 L .795 .23482 L 0 .027 .127 r
F
.79178 .23592 m .79038 .23383 L .79361 .23275 L F
.23481 .23508 m .23577 .23181 L .23772 .23398 L 0 .026 .124 r
F
.23481 .23508 m .23286 .2329 L .23577 .23181 L F
.66509 .23768 m .66672 .23451 L .66825 .23665 L 0 .031 .131 r
F
.66509 .23768 m .66356 .23556 L .66672 .23451 L F
.41479 .23836 m .41602 .23532 L .4178 .23737 L 0 .032 .133 r
F
.41479 .23836 m .41301 .23631 L .41602 .23532 L F
.74797 .23578 m .74974 .2326 L .75117 .2346 L 0 .027 .126 r
F
.74797 .23578 m .74654 .23377 L .74974 .2326 L F
.45078 .23905 m .45207 .23596 L .45381 .23798 L 0 .034 .135 r
F
.45078 .23905 m .44904 .23701 L .45207 .23596 L F
.49459 .23928 m .49596 .2359 L .49765 .23811 L F
.49459 .23928 m .49289 .23704 L .49596 .2359 L F
.5384 .23949 m .53983 .23626 L .54149 .23842 L F
.5384 .23949 m .53675 .23731 L .53983 .23626 L F
.31461 .23604 m .3157 .23273 L .31757 .23491 L 0 .027 .127 r
F
.31461 .23604 m .31273 .23388 L .3157 .23273 L F
.3506 .23671 m .35174 .23354 L .35358 .23572 L 0 .029 .129 r
F
.3506 .23671 m .34876 .23454 L .35174 .23354 L F
.75579 .23543 m .75757 .23228 L .759 .2343 L 0 .027 .126 r
F
.75579 .23543 m .75437 .23341 L .75757 .23228 L F
.60566 .23853 m .6072 .23532 L .60878 .23744 L 0 .033 .133 r
F
.60566 .23853 m .60407 .23637 L .6072 .23532 L F
.2786 .23549 m .27962 .23234 L .28154 .23439 L 0 .027 .126 r
F
.2786 .23549 m .27668 .23345 L .27962 .23234 L F
.79961 .23574 m .80145 .2324 L .80283 .23448 L F
.79961 .23574 m .79823 .23368 L .80145 .2324 L F
.80743 .23531 m .80928 .23205 L .81066 .23416 L 0 .026 .125 r
F
.80743 .23531 m .80605 .23322 L .80928 .23205 L F
.38659 .2375 m .38779 .23419 L .38959 .23636 L 0 .03 .131 r
F
.38659 .2375 m .38479 .23531 L .38779 .23419 L F
.19879 .2347 m .19969 .23145 L .20168 .23357 L 0 .025 .124 r
F
.19879 .2347 m .19679 .23259 L .19969 .23145 L F
.2426 .23494 m .24356 .2318 L .24552 .23383 L 0 .026 .125 r
F
.2426 .23494 m .24064 .23289 L .24356 .2318 L F
.45859 .23892 m .45989 .23587 L .46163 .23784 L 0 .034 .135 r
F
.45859 .23892 m .45685 .23692 L .45989 .23587 L F
.5024 .23914 m .50378 .23589 L .50547 .23801 L F
.5024 .23914 m .50071 .237 L .50378 .23589 L F
.16277 .23417 m .16361 .23097 L .16565 .23305 L 0 .024 .123 r
F
.16277 .23417 m .16074 .23208 L .16361 .23097 L F
.3224 .23592 m .32349 .23274 L .32536 .23483 L 0 .028 .127 r
F
.3224 .23592 m .32053 .23381 L .32349 .23274 L F
.2864 .23531 m .28742 .23222 L .28934 .23425 L 0 .027 .126 r
F
.2864 .23531 m .28448 .23329 L .28742 .23222 L F
.2504 .23466 m .25137 .23149 L .25333 .23348 L 0 .025 .124 r
F
.2504 .23466 m .24844 .23266 L .25137 .23149 L F
.76363 .23534 m .76542 .23208 L .76684 .23423 L 0 .027 .126 r
F
.76363 .23534 m .76221 .23319 L .76542 .23208 L F
.51022 .23882 m .51161 .23565 L .51329 .23766 L 0 .034 .135 r
F
.51022 .23882 m .50853 .23685 L .51161 .23565 L F
.20658 .23449 m .20747 .23143 L .20947 .23345 L 0 .025 .124 r
F
.20658 .23449 m .20458 .23248 L .20747 .23143 L F
.61348 .2384 m .61503 .23508 L .6166 .23716 L 0 .033 .133 r
F
.61348 .2384 m .6119 .23631 L .61503 .23508 L F
.42258 .23843 m .42383 .23527 L .4256 .23732 L 0 .033 .134 r
F
.42258 .23843 m .42081 .23638 L .42383 .23527 L F
.81527 .23518 m .81714 .23197 L .81851 .2341 L 0 .027 .126 r
F
.81527 .23518 m .8139 .23307 L .81714 .23197 L F
.67293 .23779 m .67457 .23445 L .67609 .23662 L 0 .031 .132 r
F
.67293 .23779 m .67141 .23562 L .67457 .23445 L F
.62911 .2376 m .63068 .23419 L .63224 .2363 L 0 .031 .131 r
F
.62911 .2376 m .62755 .23546 L .63068 .23419 L F
.17057 .23392 m .17141 .23081 L .17345 .23281 L 0 .024 .123 r
F
.17057 .23392 m .16853 .23192 L .17141 .23081 L F
.6213 .23805 m .62286 .23465 L .62442 .23676 L 0 .032 .132 r
F
.6213 .23805 m .61973 .23591 L .62286 .23465 L F
.68075 .23741 m .6824 .23413 L .6839 .23616 L 0 .031 .131 r
F
.68075 .23741 m .67924 .23537 L .6824 .23413 L F
.39439 .23742 m .39561 .23403 L .3974 .23623 L F
.39439 .23742 m .3926 .2352 L .39561 .23403 L F
.2582 .23439 m .25918 .23133 L .26112 .23337 L 0 .025 .124 r
F
.2582 .23439 m .25625 .23236 L .25918 .23133 L F
.71201 .23569 m .71372 .23253 L .71519 .23451 L 0 .028 .127 r
F
.71201 .23569 m .71054 .23372 L .71372 .23253 L F
.68856 .23699 m .69024 .23394 L .69173 .23588 L 0 .03 .131 r
F
.68856 .23699 m .68707 .23505 L .69024 .23394 L F
.7042 .23614 m .70589 .23296 L .70737 .23493 L 0 .028 .128 r
F
.7042 .23614 m .70272 .23419 L .70589 .23296 L F
.4664 .23876 m .46772 .23556 L .46944 .23759 L 0 .034 .135 r
F
.4664 .23876 m .46467 .23676 L .46772 .23556 L F
.54622 .23964 m .54766 .2363 L .54931 .23855 L 0 .035 .137 r
F
.54622 .23964 m .54457 .23737 L .54766 .2363 L F
.51803 .23856 m .51943 .23529 L .52111 .23737 L 0 .033 .134 r
F
.51803 .23856 m .51636 .23651 L .51943 .23529 L F
.56967 .23835 m .57115 .23519 L .57277 .23724 L F
.56967 .23835 m .56805 .23632 L .57115 .23519 L F
.35839 .23683 m .35953 .23367 L .36137 .23578 L 0 .03 .13 r
F
.35839 .23683 m .35655 .23472 L .35953 .23367 L F
.63693 .23729 m .63852 .23409 L .64007 .23618 L 0 .031 .131 r
F
.63693 .23729 m .63538 .2352 L .63852 .23409 L F
.3302 .23577 m .3313 .23257 L .33317 .23459 L 0 .028 .127 r
F
.3302 .23577 m .32833 .23372 L .3313 .23257 L F
.69638 .23665 m .69807 .23345 L .69955 .23542 L 0 .03 .13 r
F
.69638 .23665 m .6949 .23471 L .69807 .23345 L F
.29419 .23524 m .29522 .23218 L .29713 .23421 L 0 .027 .126 r
F
.29419 .23524 m .29228 .23321 L .29522 .23218 L F
.17835 .23373 m .1792 .23067 L .18123 .23266 L 0 .024 .123 r
F
.17835 .23373 m .17632 .23174 L .1792 .23067 L F
.43039 .23828 m .43166 .23486 L .43342 .23706 L 0 .033 .133 r
F
.43039 .23828 m .42863 .23609 L .43166 .23486 L F
.47421 .23851 m .47554 .23523 L .47726 .23734 L 0 .033 .134 r
F
.47421 .23851 m .47249 .23641 L .47554 .23523 L F
.4022 .23723 m .40342 .23397 L .40521 .23617 L 0 .031 .131 r
F
.4022 .23723 m .40041 .23505 L .40342 .23397 L F
.71984 .2355 m .72157 .2324 L .72303 .23445 L 0 .028 .127 r
F
.71984 .2355 m .71838 .23345 L .72157 .2324 L F
.21435 .23443 m .21527 .23126 L .21726 .23327 L 0 .026 .124 r
F
.21435 .23443 m .21236 .23241 L .21527 .23126 L F
.77148 .2353 m .77328 .23209 L .7747 .23423 L 0 .027 .126 r
F
.77148 .2353 m .77006 .23316 L .77328 .23209 L F
.338 .23553 m .33912 .2323 L .34098 .23442 L 0 .028 .127 r
F
.338 .23553 m .33615 .23342 L .33912 .2323 L F
.56185 .23902 m .56332 .23554 L .56495 .23767 L 0 .034 .135 r
F
.56185 .23902 m .56022 .23688 L .56332 .23554 L F
.64476 .23709 m .64635 .23373 L .6479 .23586 L 0 .03 .131 r
F
.64476 .23709 m .64321 .23499 L .64635 .23373 L F
.52585 .2384 m .52726 .23504 L .52893 .23726 L 0 .033 .134 r
F
.52585 .2384 m .52418 .23618 L .52726 .23504 L F
.55404 .2395 m .55549 .23595 L .55713 .2382 L 0 .035 .136 r
F
.55404 .2395 m .5524 .23725 L .55549 .23595 L F
.36619 .2367 m .36735 .23339 L .36918 .2355 L 0 .03 .13 r
F
.36619 .2367 m .36436 .23459 L .36735 .23339 L F
.57749 .23823 m .57898 .23507 L .58059 .23716 L 0 .033 .134 r
F
.57749 .23823 m .57587 .23617 L .57898 .23507 L F
.48202 .23827 m .48337 .23495 L .48508 .23709 L F
.48202 .23827 m .48031 .23614 L .48337 .23495 L F
.22215 .23417 m .22309 .23091 L .22507 .233 L 0 .025 .124 r
F
.22215 .23417 m .22018 .23209 L .22309 .23091 L F
.65258 .2368 m .65419 .23347 L .65573 .23565 L 0 .03 .13 r
F
.65258 .2368 m .65104 .23463 L .65419 .23347 L F
.4382 .23813 m .43948 .23462 L .44123 .23692 L 0 .032 .133 r
F
.4382 .23813 m .43645 .23584 L .43948 .23462 L F
.26597 .23451 m .26697 .2313 L .2689 .23346 L 0 .026 .125 r
F
.26597 .23451 m .26404 .23234 L .26697 .2313 L F
.72768 .23538 m .72941 .23211 L .73086 .23416 L 0 .028 .127 r
F
.72768 .23538 m .72622 .23332 L .72941 .23211 L F
.37399 .23646 m .37517 .23317 L .37699 .23534 L 0 .03 .13 r
F
.37399 .23646 m .37218 .23433 L .37517 .23317 L F
.7355 .23496 m .73725 .23189 L .7387 .2339 L 0 .027 .126 r
F
.7355 .23496 m .73405 .23294 L .73725 .23189 L F
.30197 .23522 m .30304 .23185 L .30493 .23403 L F
.30197 .23522 m .30008 .23303 L .30304 .23185 L F
.18613 .23371 m .187 .23056 L .18901 .23266 L 0 .025 .123 r
F
.18613 .23371 m .18411 .23161 L .187 .23056 L F
.58531 .23806 m .58682 .2349 L .58842 .23695 L 0 .033 .134 r
F
.58531 .23806 m .5837 .23603 L .58682 .2349 L F
.77933 .23524 m .78113 .23192 L .78254 .23404 L 0 .027 .127 r
F
.77933 .23524 m .77792 .23311 L .78113 .23192 L F
.15011 .23313 m .15093 .22989 L .15297 .23204 L 0 .024 .122 r
F
.15011 .23313 m .14806 .23099 L .15093 .22989 L F
.22994 .23403 m .2309 .23072 L .23286 .2329 L 0 .025 .124 r
F
.22994 .23403 m .22798 .23186 L .2309 .23072 L F
.34579 .23556 m .34692 .23236 L .34876 .23454 L 0 .028 .128 r
F
.34579 .23556 m .34395 .23339 L .34692 .23236 L F
.41 .23731 m .41123 .23415 L .41301 .23631 L 0 .032 .132 r
F
.41 .23731 m .40821 .23516 L .41123 .23415 L F
.78716 .23493 m .78898 .23175 L .79038 .23383 L 0 .027 .126 r
F
.78716 .23493 m .78575 .23283 L .78898 .23175 L F
.66041 .23667 m .66203 .23339 L .66356 .23556 L 0 .03 .13 r
F
.66041 .23667 m .65888 .23451 L .66203 .23339 L F
.48984 .2382 m .49119 .23483 L .49289 .23704 L 0 .033 .134 r
F
.48984 .2382 m .48813 .23595 L .49119 .23483 L F
.53367 .23842 m .53509 .23512 L .53675 .23731 L 0 .034 .135 r
F
.53367 .23842 m .53201 .23619 L .53509 .23512 L F
.59313 .2378 m .59465 .23456 L .59624 .23658 L 0 .033 .133 r
F
.59313 .2378 m .59153 .23577 L .59465 .23456 L F
.44601 .23805 m .4473 .23474 L .44904 .23701 L 0 .033 .134 r
F
.44601 .23805 m .44426 .23577 L .4473 .23474 L F
.60095 .23742 m .60248 .23431 L .60407 .23637 L 0 .032 .133 r
F
.60095 .23742 m .59936 .23537 L .60248 .23431 L F
.30977 .23503 m .31085 .23168 L .31273 .23388 L 0 .027 .126 r
F
.30977 .23503 m .30789 .23285 L .31085 .23168 L F
.74334 .23488 m .7451 .23177 L .74654 .23377 L 0 .027 .127 r
F
.74334 .23488 m .7419 .23285 L .7451 .23177 L F
.38179 .23643 m .38298 .23312 L .38479 .23531 L 0 .03 .13 r
F
.38179 .23643 m .37999 .23421 L .38298 .23312 L F
.27375 .23453 m .27476 .23132 L .27668 .23345 L 0 .027 .126 r
F
.27375 .23453 m .27183 .2324 L .27476 .23132 L F
.19389 .23373 m .19479 .23045 L .19679 .23259 L 0 .025 .124 r
F
.19389 .23373 m .19189 .2316 L .19479 .23045 L F
.75117 .2346 m .75294 .23142 L .75437 .23341 L 0 .027 .126 r
F
.75117 .2346 m .74974 .2326 L .75294 .23142 L F
.795 .23482 m .79684 .23163 L .79823 .23368 L 0 .027 .127 r
F
.795 .23482 m .79361 .23275 L .79684 .23163 L F
.23772 .23398 m .23869 .23073 L .24064 .23289 L 0 .026 .124 r
F
.23772 .23398 m .23577 .23181 L .23869 .23073 L F
.49765 .23811 m .49902 .23481 L .50071 .237 L 0 .034 .135 r
F
.49765 .23811 m .49596 .2359 L .49902 .23481 L F
.15787 .23313 m .1587 .22995 L .16074 .23208 L 0 .024 .123 r
F
.15787 .23313 m .15583 .23099 L .1587 .22995 L F
.31757 .23491 m .31866 .23165 L .32053 .23381 L 0 .027 .127 r
F
.31757 .23491 m .3157 .23273 L .31866 .23165 L F
.80283 .23448 m .80467 .23112 L .80605 .23322 L 0 .026 .126 r
F
.80283 .23448 m .80145 .2324 L .80467 .23112 L F
.66825 .23665 m .66989 .23345 L .67141 .23562 L 0 .031 .131 r
F
.66825 .23665 m .66672 .23451 L .66989 .23345 L F
.45381 .23798 m .45511 .23493 L .45685 .23692 L 0 .034 .135 r
F
.45381 .23798 m .45207 .23596 L .45511 .23493 L F
.54149 .23842 m .54292 .23523 L .54457 .23737 L 0 .035 .136 r
F
.54149 .23842 m .53983 .23626 L .54292 .23523 L F
.759 .2343 m .76078 .23117 L .76221 .23319 L 0 .027 .126 r
F
.759 .2343 m .75757 .23228 L .76078 .23117 L F
.4178 .23737 m .41903 .23432 L .42081 .23638 L 0 .033 .133 r
F
.4178 .23737 m .41602 .23532 L .41903 .23432 L F
.81066 .23416 m .81252 .23094 L .8139 .23307 L 0 .026 .125 r
F
.81066 .23416 m .80928 .23205 L .81252 .23094 L F
.28154 .23439 m .28257 .23122 L .28448 .23329 L 0 .027 .126 r
F
.28154 .23439 m .27962 .23234 L .28257 .23122 L F
.38959 .23636 m .3908 .23306 L .3926 .2352 L 0 .03 .131 r
F
.38959 .23636 m .38779 .23419 L .3908 .23306 L F
.60878 .23744 m .61032 .2342 L .6119 .23631 L 0 .033 .133 r
F
.60878 .23744 m .6072 .23532 L .61032 .2342 L F
.35358 .23572 m .35472 .23254 L .35655 .23472 L 0 .029 .129 r
F
.35358 .23572 m .35174 .23354 L .35472 .23254 L F
.20168 .23357 m .20258 .23035 L .20458 .23248 L 0 .025 .124 r
F
.20168 .23357 m .19969 .23145 L .20258 .23035 L F
.24552 .23383 m .24648 .23064 L .24844 .23266 L 0 .026 .125 r
F
.24552 .23383 m .24356 .2318 L .24648 .23064 L F
.50547 .23801 m .50685 .23472 L .50853 .23685 L 0 .034 .135 r
F
.50547 .23801 m .50378 .23589 L .50685 .23472 L F
.6166 .23716 m .61816 .23384 L .61973 .23591 L 0 .032 .133 r
F
.6166 .23716 m .61503 .23508 L .61816 .23384 L F
.63224 .2363 m .63382 .2331 L .63538 .2352 L 0 .031 .131 r
F
.63224 .2363 m .63068 .23419 L .63382 .2331 L F
.25333 .23348 m .2543 .23037 L .25625 .23236 L 0 .025 .124 r
F
.25333 .23348 m .25137 .23149 L .2543 .23037 L F
.16565 .23305 m .16649 .22986 L .16853 .23192 L 0 .024 .123 r
F
.16565 .23305 m .16361 .23097 L .16649 .22986 L F
.46163 .23784 m .46294 .23481 L .46467 .23676 L 0 .034 .135 r
F
.46163 .23784 m .45989 .23587 L .46294 .23481 L F
.62442 .23676 m .62599 .23338 L .62755 .23546 L 0 .031 .132 r
F
.62442 .23676 m .62286 .23465 L .62599 .23338 L F
.32536 .23483 m .32646 .23167 L .32833 .23372 L 0 .028 .127 r
F
.32536 .23483 m .32349 .23274 L .32646 .23167 L F
.51329 .23766 m .51468 .23446 L .51636 .23651 L 0 .033 .134 r
F
.51329 .23766 m .51161 .23565 L .51468 .23446 L F
.6839 .23616 m .68557 .23303 L .68707 .23505 L 0 .031 .131 r
F
.6839 .23616 m .6824 .23413 L .68557 .23303 L F
.76684 .23423 m .76864 .23102 L .77006 .23316 L 0 .027 .126 r
F
.76684 .23423 m .76542 .23208 L .76864 .23102 L F
.67609 .23662 m .67773 .23319 L .67924 .23537 L 0 .031 .131 r
F
.67609 .23662 m .67457 .23445 L .67773 .23319 L F
.28934 .23425 m .29037 .23119 L .29228 .23321 L 0 .027 .126 r
F
.28934 .23425 m .28742 .23222 L .29037 .23119 L F
.70737 .23493 m .70907 .23174 L .71054 .23372 L 0 .028 .128 r
F
.70737 .23493 m .70589 .23296 L .70907 .23174 L F
.3974 .23623 m .39862 .23286 L .40041 .23505 L 0 .03 .131 r
F
.3974 .23623 m .39561 .23403 L .39862 .23286 L F
.4256 .23732 m .42686 .23404 L .42863 .23609 L 0 .033 .134 r
F
.4256 .23732 m .42383 .23527 L .42686 .23404 L F
.71519 .23451 m .71691 .23144 L .71838 .23345 L 0 .028 .127 r
F
.71519 .23451 m .71372 .23253 L .71691 .23144 L F
.20947 .23345 m .21037 .23039 L .21236 .23241 L 0 .026 .124 r
F
.20947 .23345 m .20747 .23143 L .21037 .23039 L F
.17345 .23281 m .17429 .22974 L .17632 .23174 L 0 .024 .123 r
F
.17345 .23281 m .17141 .23081 L .17429 .22974 L F
.46944 .23759 m .47077 .23437 L .47249 .23641 L 0 .033 .134 r
F
.46944 .23759 m .46772 .23556 L .47077 .23437 L F
.52111 .23737 m .52251 .23406 L .52418 .23618 L F
.52111 .23737 m .51943 .23529 L .52251 .23406 L F
.69955 .23542 m .70124 .23219 L .70272 .23419 L 0 .029 .129 r
F
.69955 .23542 m .69807 .23345 L .70124 .23219 L F
.69173 .23588 m .69341 .23275 L .6949 .23471 L 0 .03 .13 r
F
.69173 .23588 m .69024 .23394 L .69341 .23275 L F
.33317 .23459 m .33428 .23142 L .33615 .23342 L 0 .028 .127 r
F
.33317 .23459 m .3313 .23257 L .33428 .23142 L F
.56495 .23767 m .56642 .2342 L .56805 .23632 L 0 .033 .134 r
F
.56495 .23767 m .56332 .23554 L .56642 .2342 L F
.57277 .23724 m .57426 .2341 L .57587 .23617 L F
.57277 .23724 m .57115 .23519 L .57426 .2341 L F
.54931 .23855 m .55076 .235 L .5524 .23725 L 0 .035 .136 r
F
.54931 .23855 m .54766 .2363 L .55076 .235 L F
.64007 .23618 m .64166 .23292 L .64321 .23499 L 0 .031 .131 r
F
.64007 .23618 m .63852 .23409 L .64166 .23292 L F
.26112 .23337 m .2621 .2303 L .26404 .23234 L 0 .026 .124 r
F
.26112 .23337 m .25918 .23133 L .2621 .2303 L F
.43342 .23706 m .43469 .23363 L .43645 .23584 L 0 .032 .133 r
F
.43342 .23706 m .43166 .23486 L .43469 .23363 L F
.36137 .23578 m .36253 .23247 L .36436 .23459 L 0 .03 .13 r
F
.36137 .23578 m .35953 .23367 L .36253 .23247 L F
.55713 .2382 m .55859 .23465 L .56022 .23688 L 0 .034 .135 r
F
.55713 .2382 m .55549 .23595 L .55859 .23465 L F
.47726 .23734 m .4786 .23401 L .48031 .23614 L 0 .033 .134 r
F
.47726 .23734 m .47554 .23523 L .4786 .23401 L F
.6479 .23586 m .6495 .23247 L .65104 .23463 L 0 .03 .13 r
F
.6479 .23586 m .64635 .23373 L .6495 .23247 L F
.21726 .23327 m .21819 .23008 L .22018 .23209 L 0 .025 .124 r
F
.21726 .23327 m .21527 .23126 L .21819 .23008 L F
.18123 .23266 m .18208 .22962 L .18411 .23161 L 0 .025 .123 r
F
.18123 .23266 m .1792 .23067 L .18208 .22962 L F
.36918 .2355 m .37035 .2322 L .37218 .23433 L 0 .03 .13 r
F
.36918 .2355 m .36735 .23339 L .37035 .2322 L F
.34098 .23442 m .34209 .23125 L .34395 .23339 L 0 .028 .127 r
F
.34098 .23442 m .33912 .2323 L .34209 .23125 L F
.29713 .23421 m .29818 .23101 L .30008 .23303 L 0 .027 .127 r
F
.29713 .23421 m .29522 .23218 L .29818 .23101 L F
.52893 .23726 m .53034 .23399 L .53201 .23619 L 0 .033 .134 r
F
.52893 .23726 m .52726 .23504 L .53034 .23399 L F
.40521 .23617 m .40643 .23295 L .40821 .23516 L 0 .031 .131 r
F
.40521 .23617 m .40342 .23397 L .40643 .23295 L F
.7747 .23423 m .7765 .23098 L .77792 .23311 L 0 .027 .127 r
F
.7747 .23423 m .77328 .23209 L .7765 .23098 L F
.72303 .23445 m .72476 .23125 L .72622 .23332 L 0 .028 .127 r
F
.72303 .23445 m .72157 .2324 L .72476 .23125 L F
.48508 .23709 m .48643 .23383 L .48813 .23595 L 0 .033 .134 r
F
.48508 .23709 m .48337 .23495 L .48643 .23383 L F
.22507 .233 m .22601 .22977 L .22798 .23186 L 0 .025 .124 r
F
.22507 .233 m .22309 .23091 L .22601 .22977 L F
.44123 .23692 m .44252 .23346 L .44426 .23577 L 0 .032 .133 r
F
.44123 .23692 m .43948 .23462 L .44252 .23346 L F
.58059 .23716 m .58209 .2339 L .5837 .23603 L 0 .033 .134 r
F
.58059 .23716 m .57898 .23507 L .58209 .2339 L F
.65573 .23565 m .65734 .23232 L .65888 .23451 L 0 .03 .13 r
F
.65573 .23565 m .65419 .23347 L .65734 .23232 L F
.73086 .23416 m .7326 .23091 L .73405 .23294 L 0 .027 .127 r
F
.73086 .23416 m .72941 .23211 L .7326 .23091 L F
.30493 .23403 m .30601 .23066 L .30789 .23285 L 0 .027 .126 r
F
.30493 .23403 m .30304 .23185 L .30601 .23066 L F
.37699 .23534 m .37817 .23202 L .37999 .23421 L 0 .03 .13 r
F
.37699 .23534 m .37517 .23317 L .37817 .23202 L F
.78254 .23404 m .78435 .23073 L .78575 .23283 L 0 .027 .126 r
F
.78254 .23404 m .78113 .23192 L .78435 .23073 L F
.2689 .23346 m .2699 .23026 L .27183 .2324 L 0 .026 .125 r
F
.2689 .23346 m .26697 .2313 L .2699 .23026 L F
.7387 .2339 m .74046 .23086 L .7419 .23285 L 0 .027 .127 r
F
.7387 .2339 m .73725 .23189 L .74046 .23086 L F
.58842 .23695 m .58993 .23371 L .59153 .23577 L 0 .033 .134 r
F
.58842 .23695 m .58682 .2349 L .58993 .23371 L F
.18901 .23266 m .18988 .2295 L .19189 .2316 L 0 .025 .123 r
F
.18901 .23266 m .187 .23056 L .18988 .2295 L F
.59624 .23658 m .59777 .23334 L .59936 .23537 L 0 .032 .133 r
F
.59624 .23658 m .59465 .23456 L .59777 .23334 L F
.15297 .23204 m .15379 .22885 L .15583 .23099 L 0 .024 .122 r
F
.15297 .23204 m .15093 .22989 L .15379 .22885 L F
.23286 .2329 m .23381 .22963 L .23577 .23181 L 0 .025 .124 r
F
.23286 .2329 m .2309 .23072 L .23381 .22963 L F
.49289 .23704 m .49426 .23371 L .49596 .2359 L 0 .033 .134 r
F
.49289 .23704 m .49119 .23483 L .49426 .23371 L F
.66356 .23556 m .66519 .23232 L .66672 .23451 L 0 .03 .131 r
F
.66356 .23556 m .66203 .23339 L .66519 .23232 L F
.79038 .23383 m .79222 .23069 L .79361 .23275 L 0 .027 .126 r
F
.79038 .23383 m .78898 .23175 L .79222 .23069 L F
.53675 .23731 m .53818 .23409 L .53983 .23626 L 0 .034 .135 r
F
.53675 .23731 m .53509 .23512 L .53818 .23409 L F
.31273 .23388 m .31382 .23052 L .3157 .23273 L 0 .027 .126 r
F
.31273 .23388 m .31085 .23168 L .31382 .23052 L F
.34876 .23454 m .3499 .23135 L .35174 .23354 L 0 .029 .128 r
F
.34876 .23454 m .34692 .23236 L .3499 .23135 L F
.41301 .23631 m .41424 .23314 L .41602 .23532 L 0 .032 .133 r
F
.41301 .23631 m .41123 .23415 L .41424 .23314 L F
.44904 .23701 m .45033 .23371 L .45207 .23596 L 0 .033 .134 r
F
.44904 .23701 m .4473 .23474 L .45033 .23371 L F
.60407 .23637 m .60561 .23326 L .6072 .23532 L 0 .032 .133 r
F
.60407 .23637 m .60248 .23431 L .60561 .23326 L F
.74654 .23377 m .7483 .2306 L .74974 .2326 L 0 .027 .127 r
F
.74654 .23377 m .7451 .23177 L .7483 .2306 L F
.38479 .23531 m .38599 .23202 L .38779 .23419 L 0 .03 .13 r
F
.38479 .23531 m .38298 .23312 L .38599 .23202 L F
.75437 .23341 m .75615 .2303 L .75757 .23228 L 0 .027 .126 r
F
.75437 .23341 m .75294 .23142 L .75615 .2303 L F
.52868 .55902 m .53008 .53999 L .53176 .54961 L .917 .331 0 r
F
.52868 .55902 m .52701 .5491 L .53008 .53999 L F
.80605 .23322 m .8079 .22994 L .80928 .23205 L 0 .026 .125 r
F
.80605 .23322 m .80467 .23112 L .8079 .22994 L F
.27668 .23345 m .27771 .23019 L .27962 .23234 L 0 .027 .126 r
F
.27668 .23345 m .27476 .23132 L .27771 .23019 L F
.19679 .23259 m .19769 .22931 L .19969 .23145 L 0 .025 .124 r
F
.19679 .23259 m .19479 .23045 L .19769 .22931 L F
.79823 .23368 m .80006 .23037 L .80145 .2324 L 0 .027 .126 r
F
.79823 .23368 m .79684 .23163 L .80006 .23037 L F
.50071 .237 m .50209 .23372 L .50378 .23589 L 0 .034 .135 r
F
.50071 .237 m .49902 .23481 L .50209 .23372 L F
.24064 .23289 m .24161 .22964 L .24356 .2318 L 0 .026 .125 r
F
.24064 .23289 m .23869 .23073 L .24161 .22964 L F
.32053 .23381 m .32162 .23059 L .32349 .23274 L 0 .028 .127 r
F
.32053 .23381 m .31866 .23165 L .32162 .23059 L F
.16074 .23208 m .16158 .22886 L .16361 .23097 L 0 .024 .123 r
F
.16074 .23208 m .1587 .22995 L .16158 .22886 L F
.76221 .23319 m .764 .23007 L .76542 .23208 L 0 .027 .126 r
F
.76221 .23319 m .76078 .23117 L .764 .23007 L F
.52585 .56433 m .52727 .57019 L .52893 .56341 L .963 .155 0 r
F
.52585 .56433 m .52418 .57111 L .52727 .57019 L F
.45685 .23692 m .45815 .2339 L .45989 .23587 L 0 .034 .135 r
F
.45685 .23692 m .45511 .23493 L .45815 .2339 L F
.67141 .23562 m .67305 .23226 L .67457 .23445 L 0 .031 .131 r
F
.67141 .23562 m .66989 .23345 L .67305 .23226 L F
.54457 .23737 m .54602 .23418 L .54766 .2363 L 0 .035 .136 r
F
.54457 .23737 m .54292 .23523 L .54602 .23418 L F
.3926 .2352 m .39381 .23192 L .39561 .23403 L 0 .03 .13 r
F
.3926 .2352 m .3908 .23306 L .39381 .23192 L F
.6119 .23631 m .61345 .23299 L .61503 .23508 L 0 .032 .133 r
F
.6119 .23631 m .61032 .2342 L .61345 .23299 L F
.8139 .23307 m .81576 .22983 L .81714 .23197 L 0 .026 .125 r
F
.8139 .23307 m .81252 .23094 L .81576 .22983 L F
.28448 .23329 m .28551 .23014 L .28742 .23222 L 0 .027 .126 r
F
.28448 .23329 m .28257 .23122 L .28551 .23014 L F
.62755 .23546 m .62912 .23214 L .63068 .23419 L 0 .031 .131 r
F
.62755 .23546 m .62599 .23338 L .62912 .23214 L F
.61973 .23591 m .62129 .23261 L .62286 .23465 L 0 .032 .132 r
F
.61973 .23591 m .61816 .23384 L .62129 .23261 L F
.24844 .23266 m .24942 .22948 L .25137 .23149 L 0 .026 .124 r
F
.24844 .23266 m .24648 .23064 L .24942 .22948 L F
.42081 .23638 m .42206 .23321 L .42383 .23527 L 0 .033 .134 r
F
.42081 .23638 m .41903 .23432 L .42206 .23321 L F
.20458 .23248 m .20548 .22929 L .20747 .23143 L 0 .025 .124 r
F
.20458 .23248 m .20258 .23035 L .20548 .22929 L F
.50853 .23685 m .50992 .23349 L .51161 .23565 L 0 .034 .135 r
F
.50853 .23685 m .50685 .23472 L .50992 .23349 L F
.35655 .23472 m .3577 .23149 L .35953 .23367 L 0 .03 .13 r
F
.35655 .23472 m .35472 .23254 L .3577 .23149 L F
.67924 .23537 m .68089 .23194 L .6824 .23413 L 0 .031 .131 r
F
.67924 .23537 m .67773 .23319 L .68089 .23194 L F
.25625 .23236 m .25723 .22934 L .25918 .23133 L 0 .025 .124 r
F
.25625 .23236 m .2543 .23037 L .25723 .22934 L F
.16853 .23192 m .16937 .22876 L .17141 .23081 L 0 .024 .123 r
F
.16853 .23192 m .16649 .22986 L .16937 .22876 L F
.63538 .2352 m .63697 .23201 L .63852 .23409 L 0 .031 .131 r
F
.63538 .2352 m .63382 .2331 L .63697 .23201 L F
.51636 .23651 m .51776 .2332 L .51943 .23529 L 0 .033 .134 r
F
.51636 .23651 m .51468 .23446 L .51776 .2332 L F
.42863 .23609 m .42989 .23281 L .43166 .23486 L 0 .032 .133 r
F
.42863 .23609 m .42686 .23404 L .42989 .23281 L F
.56805 .23632 m .56953 .23307 L .57115 .23519 L 0 .033 .134 r
F
.56805 .23632 m .56642 .2342 L .56953 .23307 L F
.71054 .23372 m .71225 .23053 L .71372 .23253 L 0 .028 .127 r
F
.71054 .23372 m .70907 .23174 L .71225 .23053 L F
.46467 .23676 m .46599 .23359 L .46772 .23556 L 0 .034 .135 r
F
.46467 .23676 m .46294 .23481 L .46599 .23359 L F
.32833 .23372 m .32943 .23054 L .3313 .23257 L 0 .028 .127 r
F
.32833 .23372 m .32646 .23167 L .32943 .23054 L F
.40041 .23505 m .40163 .23178 L .40342 .23397 L 0 .03 .131 r
F
.40041 .23505 m .39862 .23286 L .40163 .23178 L F
.68707 .23505 m .68875 .23192 L .69024 .23394 L 0 .031 .131 r
F
.68707 .23505 m .68557 .23303 L .68875 .23192 L F
.70272 .23419 m .70441 .23095 L .70589 .23296 L 0 .029 .128 r
F
.70272 .23419 m .70124 .23219 L .70441 .23095 L F
.51943 .5618 m .51777 .55188 L .52083 .55917 L .947 .216 0 r
F
.51777 .55188 m .51917 .54897 L .52083 .55917 L .917 .331 0 r
F
.5524 .23725 m .55385 .2337 L .55549 .23595 L 0 .034 .135 r
F
.5524 .23725 m .55076 .235 L .55385 .2337 L F
.52418 .23618 m .52559 .23289 L .52726 .23504 L 0 .033 .133 r
F
.52418 .23618 m .52251 .23406 L .52559 .23289 L F
.47249 .23641 m .47382 .23315 L .47554 .23523 L 0 .033 .134 r
F
.47249 .23641 m .47077 .23437 L .47382 .23315 L F
.77006 .23316 m .77186 .22995 L .77328 .23209 L 0 .027 .126 r
F
.77006 .23316 m .76864 .23102 L .77186 .22995 L F
.6949 .23471 m .69658 .23147 L .69807 .23345 L 0 .03 .13 r
F
.6949 .23471 m .69341 .23275 L .69658 .23147 L F
.56022 .23688 m .56169 .23334 L .56332 .23554 L 0 .034 .135 r
F
.56022 .23688 m .55859 .23465 L .56169 .23334 L F
.33615 .23342 m .33725 .2303 L .33912 .2323 L 0 .028 .127 r
F
.33615 .23342 m .33428 .23142 L .33725 .2303 L F
.29228 .23321 m .29331 .23015 L .29522 .23218 L 0 .027 .127 r
F
.29228 .23321 m .29037 .23119 L .29331 .23015 L F
.71838 .23345 m .7201 .23035 L .72157 .2324 L 0 .028 .127 r
F
.71838 .23345 m .71691 .23144 L .7201 .23035 L F
.43645 .23584 m .43773 .23239 L .43948 .23462 L 0 .032 .132 r
F
.43645 .23584 m .43469 .23363 L .43773 .23239 L F
.64321 .23499 m .64481 .23166 L .64635 .23373 L 0 .03 .131 r
F
.64321 .23499 m .64166 .23292 L .64481 .23166 L F
.17632 .23174 m .17717 .22867 L .1792 .23067 L 0 .025 .123 r
F
.17632 .23174 m .17429 .22974 L .17717 .22867 L F
.21236 .23241 m .21328 .22924 L .21527 .23126 L 0 .026 .124 r
F
.21236 .23241 m .21037 .23039 L .21328 .22924 L F
.36436 .23459 m .36553 .23127 L .36735 .23339 L 0 .03 .13 r
F
.36436 .23459 m .36253 .23247 L .36553 .23127 L F
.48031 .23614 m .48166 .2328 L .48337 .23495 L 0 .033 .133 r
F
.48031 .23614 m .4786 .23401 L .48166 .2328 L F
.65104 .23463 m .65265 .2313 L .65419 .23347 L 0 .03 .13 r
F
.65104 .23463 m .6495 .23247 L .65265 .2313 L F
.57587 .23617 m .57737 .23299 L .57898 .23507 L 0 .033 .134 r
F
.57587 .23617 m .57426 .2341 L .57737 .23299 L F
.22018 .23209 m .2211 .22891 L .22309 .23091 L 0 .025 .124 r
F
.22018 .23209 m .21819 .23008 L .2211 .22891 L F
.53035 .56075 m .53176 .54961 L .53342 .55135 L .932 .276 0 r
F
.26404 .23234 m .26503 .22926 L .26697 .2313 L 0 .026 .125 r
F
.26404 .23234 m .2621 .2303 L .26503 .22926 L F
.37218 .23433 m .37335 .23103 L .37517 .23317 L 0 .029 .129 r
F
.37218 .23433 m .37035 .2322 L .37335 .23103 L F
.30008 .23303 m .30114 .22982 L .30304 .23185 L 0 .027 .126 r
F
.30008 .23303 m .29818 .23101 L .30114 .22982 L F
.72622 .23332 m .72795 .23004 L .72941 .23211 L 0 .028 .127 r
F
.72622 .23332 m .72476 .23125 L .72795 .23004 L F
.77792 .23311 m .77972 .22981 L .78113 .23192 L 0 .027 .126 r
F
.77792 .23311 m .7765 .23098 L .77972 .22981 L F
.18411 .23161 m .18497 .22858 L .187 .23056 L 0 .025 .123 r
F
.18411 .23161 m .18208 .22962 L .18497 .22858 L F
.48813 .23595 m .48949 .23273 L .49119 .23483 L 0 .033 .134 r
F
.48813 .23595 m .48643 .23383 L .48949 .23273 L F
.53201 .23619 m .53343 .23295 L .53509 .23512 L F
.53201 .23619 m .53034 .23399 L .53343 .23295 L F
.73405 .23294 m .7358 .22988 L .73725 .23189 L 0 .027 .127 r
F
.73405 .23294 m .7326 .23091 L .7358 .22988 L F
.44426 .23577 m .44555 .23244 L .4473 .23474 L 0 .032 .133 r
F
.44426 .23577 m .44252 .23346 L .44555 .23244 L F
.22798 .23186 m .22893 .22861 L .2309 .23072 L 0 .025 .123 r
F
.22798 .23186 m .22601 .22977 L .22893 .22861 L F
.34395 .23339 m .34507 .2302 L .34692 .23236 L 0 .028 .127 r
F
.34395 .23339 m .34209 .23125 L .34507 .2302 L F
.40821 .23516 m .40944 .23192 L .41123 .23415 L 0 .031 .132 r
F
.40821 .23516 m .40643 .23295 L .40944 .23192 L F
.5837 .23603 m .58521 .23273 L .58682 .2349 L 0 .033 .134 r
F
.5837 .23603 m .58209 .2339 L .58521 .23273 L F
.65888 .23451 m .6605 .2312 L .66203 .23339 L 0 .03 .13 r
F
.65888 .23451 m .65734 .23232 L .6605 .2312 L F
.78575 .23283 m .78758 .22967 L .78898 .23175 L 0 .027 .126 r
F
.78575 .23283 m .78435 .23073 L .78758 .22967 L F
.30789 .23285 m .30897 .22948 L .31085 .23168 L F
.30789 .23285 m .30601 .23066 L .30897 .22948 L F
.37999 .23421 m .38117 .23094 L .38298 .23312 L 0 .03 .13 r
F
.37999 .23421 m .37817 .23202 L .38117 .23094 L F
.59153 .23577 m .59305 .2325 L .59465 .23456 L 0 .033 .133 r
F
.59153 .23577 m .58993 .23371 L .59305 .2325 L F
.59936 .23537 m .60089 .23228 L .60248 .23431 L 0 .032 .133 r
F
.59936 .23537 m .59777 .23334 L .60089 .23228 L F
.27183 .2324 m .27284 .22919 L .27476 .23132 L 0 .026 .125 r
F
.27183 .2324 m .2699 .23026 L .27284 .22919 L F
.7419 .23285 m .74366 .22978 L .7451 .23177 L 0 .027 .127 r
F
.7419 .23285 m .74046 .23086 L .74366 .22978 L F
.49596 .2359 m .49732 .23263 L .49902 .23481 L 0 .033 .134 r
F
.49596 .2359 m .49426 .23371 L .49732 .23263 L F
.23577 .23181 m .23673 .22856 L .23869 .23073 L 0 .025 .124 r
F
.23577 .23181 m .23381 .22963 L .23673 .22856 L F
.19189 .2316 m .19278 .22835 L .19479 .23045 L 0 .025 .123 r
F
.19189 .2316 m .18988 .2295 L .19278 .22835 L F
.52392 .55824 m .52534 .5392 L .52701 .5491 L .917 .331 0 r
F
.52392 .55824 m .52225 .54804 L .52534 .5392 L F
.15583 .23099 m .15666 .22781 L .1587 .22995 L 0 .024 .122 r
F
.15583 .23099 m .15379 .22885 L .15666 .22781 L F
.3157 .23273 m .31678 .22943 L .31866 .23165 L 0 .027 .126 r
F
.3157 .23273 m .31382 .23052 L .31678 .22943 L F
.79361 .23275 m .79545 .22958 L .79684 .23163 L 0 .027 .127 r
F
.79361 .23275 m .79222 .23069 L .79545 .22958 L F
.66672 .23451 m .66836 .23126 L .66989 .23345 L 0 .031 .131 r
F
.66672 .23451 m .66519 .23232 L .66836 .23126 L F
.53983 .23626 m .54127 .23309 L .54292 .23523 L 0 .034 .135 r
F
.53983 .23626 m .53818 .23409 L .54127 .23309 L F
.74974 .2326 m .75151 .22943 L .75294 .23142 L 0 .027 .126 r
F
.74974 .2326 m .7483 .2306 L .75151 .22943 L F
.80145 .2324 m .80329 .2291 L .80467 .23112 L 0 .026 .126 r
F
.80145 .2324 m .80006 .23037 L .80329 .2291 L F
.35174 .23354 m .35288 .23034 L .35472 .23254 L 0 .029 .129 r
F
.35174 .23354 m .3499 .23135 L .35288 .23034 L F
.38779 .23419 m .38899 .23092 L .3908 .23306 L 0 .03 .13 r
F
.38779 .23419 m .38599 .23202 L .38899 .23092 L F
.5211 .56352 m .5225 .56939 L .52418 .57111 L .963 .155 0 r
F
.5211 .56352 m .51943 .5618 L .5225 .56939 L F
.80928 .23205 m .81114 .22882 L .81252 .23094 L 0 .026 .125 r
F
.80928 .23205 m .8079 .22994 L .81114 .22882 L F
.45207 .23596 m .45337 .23269 L .45511 .23493 L 0 .034 .135 r
F
.45207 .23596 m .45033 .23371 L .45337 .23269 L F
.6072 .23532 m .60874 .23214 L .61032 .2342 L 0 .032 .133 r
F
.6072 .23532 m .60561 .23326 L .60874 .23214 L F
.41602 .23532 m .41726 .23213 L .41903 .23432 L F
.41602 .23532 m .41424 .23314 L .41726 .23213 L F
.75757 .23228 m .75936 .22919 L .76078 .23117 L 0 .027 .126 r
F
.75757 .23228 m .75615 .2303 L .75936 .22919 L F
.19969 .23145 m .20059 .2282 L .20258 .23035 L 0 .025 .124 r
F
.19969 .23145 m .19769 .22931 L .20059 .2282 L F
.27962 .23234 m .28065 .22905 L .28257 .23122 L 0 .027 .126 r
F
.27962 .23234 m .27771 .23019 L .28065 .22905 L F
.50378 .23589 m .50516 .23253 L .50685 .23472 L 0 .034 .134 r
F
.50378 .23589 m .50209 .23372 L .50516 .23253 L F
.63068 .23419 m .63227 .23105 L .63382 .2331 L 0 .031 .131 r
F
.63068 .23419 m .62912 .23214 L .63227 .23105 L F
.24356 .2318 m .24453 .2285 L .24648 .23064 L 0 .026 .125 r
F
.24356 .2318 m .24161 .22964 L .24453 .2285 L F
.61503 .23508 m .61658 .23177 L .61816 .23384 L 0 .032 .133 r
F
.61503 .23508 m .61345 .23299 L .61658 .23177 L F
.62286 .23465 m .62442 .23137 L .62599 .23338 L 0 .031 .132 r
F
.62286 .23465 m .62129 .23261 L .62442 .23137 L F
.67457 .23445 m .67621 .23101 L .67773 .23319 L 0 .031 .131 r
F
.67457 .23445 m .67305 .23226 L .67621 .23101 L F
.16361 .23097 m .16445 .22776 L .16649 .22986 L 0 .024 .123 r
F
.16361 .23097 m .16158 .22886 L .16445 .22776 L F
.39561 .23403 m .39682 .23077 L .39862 .23286 L 0 .03 .13 r
F
.39561 .23403 m .39381 .23192 L .39682 .23077 L F
.76542 .23208 m .76722 .22899 L .76864 .23102 L 0 .027 .126 r
F
.76542 .23208 m .764 .23007 L .76722 .22899 L F
.32349 .23274 m .32459 .22953 L .32646 .23167 L 0 .028 .127 r
F
.32349 .23274 m .32162 .23059 L .32459 .22953 L F
.52893 .56341 m .52727 .57019 L .53035 .56075 L .948 .215 0 r
F
.25137 .23149 m .25235 .22837 L .2543 .23037 L 0 .026 .124 r
F
.25137 .23149 m .24942 .22948 L .25235 .22837 L F
.54766 .2363 m .54911 .2329 L .55076 .235 L 0 .035 .136 r
F
.54766 .2363 m .54602 .23418 L .54911 .2329 L F
.6824 .23413 m .68406 .23085 L .68557 .23303 L 0 .03 .131 r
F
.6824 .23413 m .68089 .23194 L .68406 .23085 L F
.45989 .23587 m .4612 .23286 L .46294 .23481 L 0 .034 .135 r
F
.45989 .23587 m .45815 .2339 L .4612 .23286 L F
.51161 .23565 m .513 .23226 L .51468 .23446 L 0 .033 .134 r
F
.51161 .23565 m .50992 .23349 L .513 .23226 L F
.28742 .23222 m .28846 .2291 L .29037 .23119 L 0 .027 .126 r
F
.28742 .23222 m .28551 .23014 L .28846 .2291 L F
.42383 .23527 m .42509 .23198 L .42686 .23404 L 0 .033 .133 r
F
.42383 .23527 m .42206 .23321 L .42509 .23198 L F
.51943 .23529 m .52084 .23194 L .52251 .23406 L F
.51943 .23529 m .51776 .2332 L .52084 .23194 L F
.43166 .23486 m .43293 .23158 L .43469 .23363 L 0 .032 .133 r
F
.43166 .23486 m .42989 .23281 L .43293 .23158 L F
.55549 .23595 m .55695 .23241 L .55859 .23465 L 0 .034 .135 r
F
.55549 .23595 m .55385 .2337 L .55695 .23241 L F
.56332 .23554 m .56479 .23203 L .56642 .2342 L 0 .033 .134 r
F
.56332 .23554 m .56169 .23334 L .56479 .23203 L F
.20747 .23143 m .20838 .22823 L .21037 .23039 L 0 .026 .124 r
F
.20747 .23143 m .20548 .22929 L .20838 .22823 L F
.46772 .23556 m .46904 .23236 L .47077 .23437 L 0 .034 .135 r
F
.46772 .23556 m .46599 .23359 L .46904 .23236 L F
.71372 .23253 m .71544 .22942 L .71691 .23144 L 0 .028 .127 r
F
.71372 .23253 m .71225 .23053 L .71544 .22942 L F
.70589 .23296 m .70759 .22971 L .70907 .23174 L 0 .028 .128 r
F
.70589 .23296 m .70441 .23095 L .70759 .22971 L F
.17141 .23081 m .17225 .22768 L .17429 .22974 L 0 .025 .123 r
F
.17141 .23081 m .16937 .22876 L .17225 .22768 L F
.3313 .23257 m .33241 .22941 L .33428 .23142 L 0 .028 .127 r
F
.3313 .23257 m .32943 .23054 L .33241 .22941 L F
.63852 .23409 m .64011 .23084 L .64166 .23292 L 0 .031 .131 r
F
.63852 .23409 m .63697 .23201 L .64011 .23084 L F
.69807 .23345 m .69975 .23019 L .70124 .23219 L 0 .029 .129 r
F
.69807 .23345 m .69658 .23147 L .69975 .23019 L F
.57115 .23519 m .57264 .23198 L .57426 .2341 L 0 .033 .134 r
F
.57115 .23519 m .56953 .23307 L .57264 .23198 L F
.35953 .23367 m .3607 .23028 L .36253 .23247 L 0 .03 .13 r
F
.35953 .23367 m .3577 .23149 L .3607 .23028 L F
.47554 .23523 m .47688 .23192 L .4786 .23401 L 0 .033 .134 r
F
.47554 .23523 m .47382 .23315 L .47688 .23192 L F
.25918 .23133 m .26015 .2283 L .2621 .2303 L 0 .026 .125 r
F
.25918 .23133 m .25723 .22934 L .26015 .2283 L F
.69024 .23394 m .69192 .23073 L .69341 .23275 L 0 .03 .131 r
F
.69024 .23394 m .68875 .23192 L .69192 .23073 L F
.64635 .23373 m .64795 .23041 L .6495 .23247 L 0 .03 .13 r
F
.64635 .23373 m .64481 .23166 L .64795 .23041 L F
.52726 .23504 m .52868 .23185 L .53034 .23399 L 0 .033 .133 r
F
.52726 .23504 m .52559 .23289 L .52868 .23185 L F
.43948 .23462 m .44077 .23122 L .44252 .23346 L 0 .032 .132 r
F
.43948 .23462 m .43773 .23239 L .44077 .23122 L F
.40342 .23397 m .40464 .23073 L .40643 .23295 L 0 .03 .131 r
F
.40342 .23397 m .40163 .23178 L .40464 .23073 L F
.33912 .2323 m .34023 .22924 L .34209 .23125 L 0 .028 .127 r
F
.33912 .2323 m .33725 .2303 L .34023 .22924 L F
.36735 .23339 m .36852 .23007 L .37035 .2322 L 0 .029 .129 r
F
.36735 .23339 m .36553 .23127 L .36852 .23007 L F
.77328 .23209 m .77509 .22885 L .7765 .23098 L 0 .027 .126 r
F
.77328 .23209 m .77186 .22995 L .77509 .22885 L F
.21527 .23126 m .21619 .22808 L .21819 .23008 L 0 .026 .124 r
F
.21527 .23126 m .21328 .22924 L .21619 .22808 L F
.48337 .23495 m .48472 .2317 L .48643 .23383 L 0 .033 .133 r
F
.48337 .23495 m .48166 .2328 L .48472 .2317 L F
.65419 .23347 m .6558 .23015 L .65734 .23232 L 0 .03 .13 r
F
.65419 .23347 m .65265 .2313 L .6558 .23015 L F
.29522 .23218 m .29627 .22899 L .29818 .23101 L 0 .027 .127 r
F
.29522 .23218 m .29331 .23015 L .29627 .22899 L F
.72157 .2324 m .72329 .22918 L .72476 .23125 L 0 .028 .127 r
F
.72157 .2324 m .7201 .23035 L .72329 .22918 L F
.1792 .23067 m .18005 .22763 L .18208 .22962 L 0 .025 .123 r
F
.1792 .23067 m .17717 .22867 L .18005 .22763 L F
.22309 .23091 m .22402 .22775 L .22601 .22977 L 0 .025 .124 r
F
.22309 .23091 m .2211 .22891 L .22402 .22775 L F
.57898 .23507 m .58048 .23177 L .58209 .2339 L 0 .033 .134 r
F
.57898 .23507 m .57737 .23299 L .58048 .23177 L F
.30304 .23185 m .30411 .22864 L .30601 .23066 L 0 .027 .126 r
F
.30304 .23185 m .30114 .22982 L .30411 .22864 L F
.37517 .23317 m .37635 .22986 L .37817 .23202 L 0 .029 .129 r
F
.37517 .23317 m .37335 .23103 L .37635 .22986 L F
.72941 .23211 m .73114 .22883 L .7326 .23091 L 0 .027 .127 r
F
.72941 .23211 m .72795 .23004 L .73114 .22883 L F
.78113 .23192 m .78295 .22865 L .78435 .23073 L 0 .027 .126 r
F
.78113 .23192 m .77972 .22981 L .78295 .22865 L F
.26697 .2313 m .26796 .22823 L .2699 .23026 L 0 .026 .125 r
F
.26697 .2313 m .26503 .22926 L .26796 .22823 L F
.49119 .23483 m .49256 .23164 L .49426 .23371 L 0 .033 .134 r
F
.49119 .23483 m .48949 .23273 L .49256 .23164 L F
.2309 .23072 m .23185 .22752 L .23381 .22963 L 0 .025 .123 r
F
.2309 .23072 m .22893 .22861 L .23185 .22752 L F
.58682 .2349 m .58833 .23153 L .58993 .23371 L 0 .033 .134 r
F
.58682 .2349 m .58521 .23273 L .58833 .23153 L F
.53509 .23512 m .53652 .23193 L .53818 .23409 L 0 .034 .134 r
F
.53509 .23512 m .53343 .23295 L .53652 .23193 L F
.187 .23056 m .18785 .22753 L .18988 .2295 L 0 .025 .123 r
F
.187 .23056 m .18497 .22858 L .18785 .22753 L F
.66203 .23339 m .66366 .23012 L .66519 .23232 L 0 .03 .13 r
F
.66203 .23339 m .6605 .2312 L .66366 .23012 L F
.73725 .23189 m .73901 .22886 L .74046 .23086 L 0 .027 .127 r
F
.73725 .23189 m .7358 .22988 L .73901 .22886 L F
.31085 .23168 m .31194 .2283 L .31382 .23052 L 0 .027 .126 r
F
.31085 .23168 m .30897 .22948 L .31194 .2283 L F
.4473 .23474 m .44859 .23143 L .45033 .23371 L 0 .033 .133 r
F
.4473 .23474 m .44555 .23244 L .44859 .23143 L F
.34692 .23236 m .34805 .22918 L .3499 .23135 L 0 .028 .128 r
F
.34692 .23236 m .34507 .2302 L .34805 .22918 L F
.59465 .23456 m .59617 .23128 L .59777 .23334 L 0 .032 .133 r
F
.59465 .23456 m .59305 .2325 L .59617 .23128 L F
.78898 .23175 m .79082 .22862 L .79222 .23069 L 0 .027 .126 r
F
.78898 .23175 m .78758 .22967 L .79082 .22862 L F
.41123 .23415 m .41246 .2309 L .41424 .23314 L 0 .032 .132 r
F
.41123 .23415 m .40944 .23192 L .41246 .2309 L F
.38298 .23312 m .38417 .22987 L .38599 .23202 L 0 .03 .13 r
F
.38298 .23312 m .38117 .23094 L .38417 .22987 L F
.60248 .23431 m .60402 .23121 L .60561 .23326 L 0 .032 .133 r
F
.60248 .23431 m .60089 .23228 L .60402 .23121 L F
.27476 .23132 m .27579 .22804 L .27771 .23019 L 0 .026 .125 r
F
.27476 .23132 m .27284 .22919 L .27579 .22804 L F
.19479 .23045 m .19569 .2272 L .19769 .22931 L 0 .025 .123 r
F
.19479 .23045 m .19278 .22835 L .19569 .2272 L F
.7451 .23177 m .74687 .22861 L .7483 .2306 L 0 .027 .127 r
F
.7451 .23177 m .74366 .22978 L .74687 .22861 L F
.49902 .23481 m .50039 .23156 L .50209 .23372 L 0 .033 .134 r
F
.49902 .23481 m .49732 .23263 L .50039 .23156 L F
.80467 .23112 m .80653 .22794 L .8079 .22994 L 0 .026 .125 r
F
.80467 .23112 m .80329 .2291 L .80653 .22794 L F
.23869 .23073 m .23965 .22748 L .24161 .22964 L 0 .025 .124 r
F
.23869 .23073 m .23673 .22856 L .23965 .22748 L F
.79684 .23163 m .79868 .22833 L .80006 .23037 L 0 .027 .126 r
F
.79684 .23163 m .79545 .22958 L .79868 .22833 L F
.75294 .23142 m .75472 .22831 L .75615 .2303 L F
.75294 .23142 m .75151 .22943 L .75472 .22831 L F
.31866 .23165 m .31975 .22838 L .32162 .23059 L F
.31866 .23165 m .31678 .22943 L .31975 .22838 L F
.1587 .22995 m .15953 .22673 L .16158 .22886 L 0 .024 .122 r
F
.1587 .22995 m .15666 .22781 L .15953 .22673 L F
.66989 .23345 m .67152 .23007 L .67305 .23226 L 0 .031 .131 r
F
.66989 .23345 m .66836 .23126 L .67152 .23007 L F
.54292 .23523 m .54437 .23206 L .54602 .23418 L 0 .035 .136 r
F
.54292 .23523 m .54127 .23309 L .54437 .23206 L F
.3908 .23306 m .392 .2298 L .39381 .23192 L 0 .03 .13 r
F
.3908 .23306 m .38899 .23092 L .392 .2298 L F
.81252 .23094 m .81439 .2277 L .81576 .22983 L 0 .026 .125 r
F
.81252 .23094 m .81114 .22882 L .81439 .2277 L F
.61032 .2342 m .61187 .23089 L .61345 .23299 L 0 .032 .133 r
F
.61032 .2342 m .60874 .23214 L .61187 .23089 L F
.76078 .23117 m .76258 .22808 L .764 .23007 L 0 .027 .126 r
F
.76078 .23117 m .75936 .22919 L .76258 .22808 L F
.62599 .23338 m .62756 .23015 L .62912 .23214 L 0 .031 .131 r
F
.62599 .23338 m .62442 .23137 L .62756 .23015 L F
.20258 .23035 m .20349 .22713 L .20548 .22929 L 0 .025 .124 r
F
.20258 .23035 m .20059 .2282 L .20349 .22713 L F
.28257 .23122 m .2836 .22796 L .28551 .23014 L 0 .027 .126 r
F
.28257 .23122 m .28065 .22905 L .2836 .22796 L F
.35472 .23254 m .35586 .22929 L .3577 .23149 L 0 .029 .129 r
F
.35472 .23254 m .35288 .23034 L .35586 .22929 L F
.45511 .23493 m .45642 .23167 L .45815 .2339 L 0 .034 .135 r
F
.45511 .23493 m .45337 .23269 L .45642 .23167 L F
.61816 .23384 m .61972 .23056 L .62129 .23261 L 0 .032 .132 r
F
.61816 .23384 m .61658 .23177 L .61972 .23056 L F
.67773 .23319 m .67937 .22975 L .68089 .23194 L 0 .03 .13 r
F
.67773 .23319 m .67621 .23101 L .67937 .22975 L F
.50685 .23472 m .50824 .23127 L .50992 .23349 L 0 .033 .134 r
F
.50685 .23472 m .50516 .23253 L .50824 .23127 L F
.41903 .23432 m .42028 .23102 L .42206 .23321 L 0 .033 .133 r
F
.41903 .23432 m .41726 .23213 L .42028 .23102 L F
.24648 .23064 m .24747 .22735 L .24942 .22948 L 0 .026 .124 r
F
.24648 .23064 m .24453 .2285 L .24747 .22735 L F
.55076 .235 m .55221 .23162 L .55385 .2337 L 0 .034 .135 r
F
.55076 .235 m .54911 .2329 L .55221 .23162 L F
.39862 .23286 m .39983 .22967 L .40163 .23178 L 0 .03 .13 r
F
.39862 .23286 m .39682 .23077 L .39983 .22967 L F
.63382 .2331 m .63541 .22997 L .63697 .23201 L 0 .031 .131 r
F
.63382 .2331 m .63227 .23105 L .63541 .22997 L F
.56642 .2342 m .5679 .23091 L .56953 .23307 L 0 .033 .133 r
F
.56642 .2342 m .56479 .23203 L .5679 .23091 L F
.16649 .22986 m .16734 .22666 L .16937 .22876 L 0 .024 .123 r
F
.16649 .22986 m .16445 .22776 L .16734 .22666 L F
.55859 .23465 m .56005 .23113 L .56169 .23334 L 0 .033 .134 r
F
.55859 .23465 m .55695 .23241 L .56005 .23113 L F
.51468 .23446 m .51608 .23099 L .51776 .2332 L F
.51468 .23446 m .513 .23226 L .51608 .23099 L F
.42686 .23404 m .42812 .23076 L .42989 .23281 L 0 .032 .133 r
F
.42686 .23404 m .42509 .23198 L .42812 .23076 L F
.76864 .23102 m .77045 .22792 L .77186 .22995 L 0 .027 .126 r
F
.76864 .23102 m .76722 .22899 L .77045 .22792 L F
.32646 .23167 m .32756 .22843 L .32943 .23054 L 0 .028 .127 r
F
.32646 .23167 m .32459 .22953 L .32756 .22843 L F
.43469 .23363 m .43597 .23035 L .43773 .23239 L 0 .032 .132 r
F
.43469 .23363 m .43293 .23158 L .43597 .23035 L F
.52251 .23406 m .52392 .23075 L .52559 .23289 L 0 .032 .133 r
F
.52251 .23406 m .52084 .23194 L .52392 .23075 L F
.2543 .23037 m .25527 .22733 L .25723 .22934 L 0 .026 .124 r
F
.2543 .23037 m .25235 .22837 L .25527 .22733 L F
.68557 .23303 m .68724 .22975 L .68875 .23192 L 0 .03 .131 r
F
.68557 .23303 m .68406 .23085 L .68724 .22975 L F
.70907 .23174 m .71077 .22849 L .71225 .23053 L 0 .028 .128 r
F
.70907 .23174 m .70759 .22971 L .71077 .22849 L F
.70124 .23219 m .70293 .22893 L .70441 .23095 L 0 .029 .129 r
F
.70124 .23219 m .69975 .23019 L .70293 .22893 L F
.47077 .23437 m .4721 .23112 L .47382 .23315 L 0 .033 .134 r
F
.47077 .23437 m .46904 .23236 L .4721 .23112 L F
.46294 .23481 m .46425 .23161 L .46599 .23359 L 0 .034 .135 r
F
.46294 .23481 m .4612 .23286 L .46425 .23161 L F
.6495 .23247 m .65111 .22927 L .65265 .2313 L 0 .03 .13 r
F
.6495 .23247 m .64795 .23041 L .65111 .22927 L F
.36253 .23247 m .3637 .22907 L .36553 .23127 L 0 .029 .129 r
F
.36253 .23247 m .3607 .23028 L .3637 .22907 L F
.64166 .23292 m .64326 .22959 L .64481 .23166 L 0 .03 .13 r
F
.64166 .23292 m .64011 .23084 L .64326 .22959 L F
.29037 .23119 m .2914 .22806 L .29331 .23015 L 0 .027 .127 r
F
.29037 .23119 m .28846 .2291 L .2914 .22806 L F
.4786 .23401 m .47994 .23069 L .48166 .2328 L 0 .032 .133 r
F
.4786 .23401 m .47688 .23192 L .47994 .23069 L F
.33428 .23142 m .33538 .22831 L .33725 .2303 L 0 .028 .127 r
F
.33428 .23142 m .33241 .22941 L .33538 .22831 L F
.71691 .23144 m .71863 .2283 L .7201 .23035 L F
.71691 .23144 m .71544 .22942 L .71863 .2283 L F
.69341 .23275 m .69509 .22944 L .69658 .23147 L 0 .03 .13 r
F
.69341 .23275 m .69192 .23073 L .69509 .22944 L F
.21037 .23039 m .21129 .2271 L .21328 .22924 L 0 .026 .124 r
F
.21037 .23039 m .20838 .22823 L .21129 .2271 L F
.17429 .22974 m .17514 .2266 L .17717 .22867 L 0 .025 .123 r
F
.17429 .22974 m .17225 .22768 L .17514 .2266 L F
.57426 .2341 m .57575 .23085 L .57737 .23299 L 0 .033 .134 r
F
.57426 .2341 m .57264 .23198 L .57575 .23085 L F
.44252 .23346 m .4438 .23021 L .44555 .23244 L 0 .032 .132 r
F
.44252 .23346 m .44077 .23122 L .4438 .23021 L F
.37035 .2322 m .37153 .22889 L .37335 .23103 L 0 .029 .129 r
F
.37035 .2322 m .36852 .23007 L .37153 .22889 L F
.53035 .56075 m .52868 .55902 L .53176 .54961 L .932 .276 0 r
F
.2621 .2303 m .26308 .22727 L .26503 .22926 L 0 .026 .125 r
F
.2621 .2303 m .26015 .2283 L .26308 .22727 L F
.53034 .23399 m .53177 .23081 L .53343 .23295 L 0 .033 .134 r
F
.53034 .23399 m .52868 .23185 L .53177 .23081 L F
.21819 .23008 m .21911 .22691 L .2211 .22891 L 0 .025 .124 r
F
.21819 .23008 m .21619 .22808 L .21911 .22691 L F
.7765 .23098 m .77831 .2277 L .77972 .22981 L 0 .027 .126 r
F
.7765 .23098 m .77509 .22885 L .77831 .2277 L F
.40643 .23295 m .40766 .22968 L .40944 .23192 L 0 .031 .131 r
F
.40643 .23295 m .40464 .23073 L .40766 .22968 L F
.48643 .23383 m .48778 .23063 L .48949 .23273 L 0 .033 .133 r
F
.48643 .23383 m .48472 .2317 L .48778 .23063 L F
.29818 .23101 m .29923 .22781 L .30114 .22982 L 0 .027 .126 r
F
.29818 .23101 m .29627 .22899 L .29923 .22781 L F
.65734 .23232 m .65896 .22901 L .6605 .2312 L 0 .029 .129 r
F
.65734 .23232 m .6558 .23015 L .65896 .22901 L F
.34209 .23125 m .34321 .22817 L .34507 .2302 L 0 .028 .127 r
F
.34209 .23125 m .34023 .22924 L .34321 .22817 L F
.72476 .23125 m .72648 .22795 L .72795 .23004 L 0 .027 .127 r
F
.72476 .23125 m .72329 .22918 L .72648 .22795 L F
.22601 .22977 m .22695 .22659 L .22893 .22861 L 0 .025 .123 r
F
.22601 .22977 m .22402 .22775 L .22695 .22659 L F
.58209 .2339 m .5836 .23056 L .58521 .23273 L 0 .033 .133 r
F
.58209 .2339 m .58048 .23177 L .5836 .23056 L F
.30601 .23066 m .30707 .22745 L .30897 .22948 L 0 .027 .126 r
F
.30601 .23066 m .30411 .22864 L .30707 .22745 L F
.7326 .23091 m .73435 .2278 L .7358 .22988 L 0 .027 .127 r
F
.7326 .23091 m .73114 .22883 L .73435 .2278 L F
.18208 .22962 m .18293 .22659 L .18497 .22858 L 0 .025 .124 r
F
.18208 .22962 m .18005 .22763 L .18293 .22659 L F
.37817 .23202 m .37935 .22881 L .38117 .23094 L 0 .029 .129 r
F
.37817 .23202 m .37635 .22986 L .37935 .22881 L F
.78435 .23073 m .78618 .2276 L .78758 .22967 L 0 .027 .126 r
F
.78435 .23073 m .78295 .22865 L .78618 .2276 L F
.49426 .23371 m .49562 .23058 L .49732 .23263 L 0 .033 .134 r
F
.49426 .23371 m .49256 .23164 L .49562 .23058 L F
.58993 .23371 m .59145 .23032 L .59305 .2325 L 0 .032 .133 r
F
.58993 .23371 m .58833 .23153 L .59145 .23032 L F
.2699 .23026 m .2709 .22717 L .27284 .22919 L 0 .026 .125 r
F
.2699 .23026 m .26796 .22823 L .2709 .22717 L F
.23381 .22963 m .23476 .22646 L .23673 .22856 L 0 .025 .124 r
F
.23381 .22963 m .23185 .22752 L .23476 .22646 L F
.31382 .23052 m .31491 .22721 L .31678 .22943 L 0 .026 .126 r
F
.31382 .23052 m .31194 .2283 L .31491 .22721 L F
.59777 .23334 m .5993 .2302 L .60089 .23228 L 0 .032 .133 r
F
.59777 .23334 m .59617 .23128 L .5993 .2302 L F
.66519 .23232 m .66683 .22905 L .66836 .23126 L 0 .03 .13 r
F
.66519 .23232 m .66366 .23012 L .66683 .22905 L F
.18988 .2295 m .19076 .22636 L .19278 .22835 L 0 .025 .124 r
F
.18988 .2295 m .18785 .22753 L .19076 .22636 L F
.53818 .23409 m .53962 .23094 L .54127 .23309 L 0 .034 .135 r
F
.53818 .23409 m .53652 .23193 L .53962 .23094 L F
.74046 .23086 m .74222 .22779 L .74366 .22978 L 0 .028 .127 r
F
.74046 .23086 m .73901 .22886 L .74222 .22779 L F
.45033 .23371 m .45163 .23042 L .45337 .23269 L 0 .033 .134 r
F
.45033 .23371 m .44859 .23143 L .45163 .23042 L F
.79222 .23069 m .79406 .22753 L .79545 .22958 L 0 .027 .127 r
F
.79222 .23069 m .79082 .22862 L .79406 .22753 L F
.3499 .23135 m .35103 .22817 L .35288 .23034 L 0 .028 .128 r
F
.3499 .23135 m .34805 .22918 L .35103 .22817 L F
.38599 .23202 m .38718 .22879 L .38899 .23092 L 0 .03 .13 r
F
.38599 .23202 m .38417 .22987 L .38718 .22879 L F
.41424 .23314 m .41548 .22988 L .41726 .23213 L 0 .032 .133 r
F
.41424 .23314 m .41246 .2309 L .41548 .22988 L F
.80006 .23037 m .80191 .22708 L .80329 .2291 L 0 .027 .126 r
F
.80006 .23037 m .79868 .22833 L .80191 .22708 L F
.8079 .22994 m .80977 .22683 L .81114 .22882 L 0 .026 .125 r
F
.8079 .22994 m .80653 .22794 L .80977 .22683 L F
.7483 .2306 m .75008 .22744 L .75151 .22943 L 0 .027 .127 r
F
.7483 .2306 m .74687 .22861 L .75008 .22744 L F
.19769 .22931 m .19859 .22608 L .20059 .2282 L 0 .025 .123 r
F
.19769 .22931 m .19569 .2272 L .19859 .22608 L F
.27771 .23019 m .27874 .22688 L .28065 .22905 L 0 .026 .125 r
F
.27771 .23019 m .27579 .22804 L .27874 .22688 L F
.51943 .5618 m .52083 .55917 L .5225 .56939 L .947 .216 0 r
F
.60561 .23326 m .60716 .23007 L .60874 .23214 L 0 .032 .133 r
F
.60561 .23326 m .60402 .23121 L .60716 .23007 L F
.50209 .23372 m .50347 .23036 L .50516 .23253 L 0 .033 .134 r
F
.50209 .23372 m .50039 .23156 L .50347 .23036 L F
.24161 .22964 m .24258 .22635 L .24453 .2285 L 0 .025 .124 r
F
.24161 .22964 m .23965 .22748 L .24258 .22635 L F
.75615 .2303 m .75794 .2272 L .75936 .22919 L 0 .027 .126 r
F
.75615 .2303 m .75472 .22831 L .75794 .2272 L F
.67305 .23226 m .67469 .22882 L .67621 .23101 L 0 .03 .13 r
F
.67305 .23226 m .67152 .23007 L .67469 .22882 L F
.32162 .23059 m .32272 .22733 L .32459 .22953 L 0 .027 .127 r
F
.32162 .23059 m .31975 .22838 L .32272 .22733 L F
.16158 .22886 m .16241 .22565 L .16445 .22776 L 0 .024 .122 r
F
.16158 .22886 m .15953 .22673 L .16241 .22565 L F
.61345 .23299 m .615 .22965 L .61658 .23177 L 0 .032 .132 r
F
.61345 .23299 m .61187 .23089 L .615 .22965 L F
.39381 .23192 m .39501 .22868 L .39682 .23077 L 0 .03 .13 r
F
.39381 .23192 m .392 .2298 L .39501 .22868 L F
.62912 .23214 m .63071 .22907 L .63227 .23105 L 0 .031 .131 r
F
.62912 .23214 m .62756 .23015 L .63071 .22907 L F
.68089 .23194 m .68255 .22866 L .68406 .23085 L 0 .03 .13 r
F
.68089 .23194 m .67937 .22975 L .68255 .22866 L F
.62129 .23261 m .62285 .22936 L .62442 .23137 L 0 .031 .132 r
F
.62129 .23261 m .61972 .23056 L .62285 .22936 L F
.55385 .2337 m .55531 .23035 L .55695 .23241 L 0 .033 .134 r
F
.55385 .2337 m .55221 .23162 L .55531 .23035 L F
.50992 .23349 m .51132 .23001 L .513 .23226 L F
.50992 .23349 m .50824 .23127 L .51132 .23001 L F
.54602 .23418 m .54746 .2308 L .54911 .2329 L 0 .034 .135 r
F
.54602 .23418 m .54437 .23206 L .54746 .2308 L F
.764 .23007 m .76581 .227 L .76722 .22899 L 0 .027 .126 r
F
.764 .23007 m .76258 .22808 L .76581 .227 L F
.56169 .23334 m .56316 .22986 L .56479 .23203 L 0 .032 .133 r
F
.56169 .23334 m .56005 .23113 L .56316 .22986 L F
.24942 .22948 m .2504 .22624 L .25235 .22837 L 0 .025 .124 r
F
.24942 .22948 m .24747 .22735 L .2504 .22624 L F
.52083 .55917 m .51917 .54897 L .52225 .54804 L .932 .276 0 r
F
.28551 .23014 m .28655 .2269 L .28846 .2291 L 0 .027 .126 r
F
.28551 .23014 m .2836 .22796 L .28655 .2269 L F
.51776 .2332 m .51916 .22971 L .52084 .23194 L 0 .032 .133 r
F
.51776 .2332 m .51608 .23099 L .51916 .22971 L F
.20548 .22929 m .20639 .22606 L .20838 .22823 L 0 .025 .124 r
F
.20548 .22929 m .20349 .22713 L .20639 .22606 L F
.42206 .23321 m .42332 .2298 L .42509 .23198 L 0 .032 .133 r
F
.42206 .23321 m .42028 .23102 L .42332 .2298 L F
.3577 .23149 m .35886 .22807 L .3607 .23028 L 0 .029 .129 r
F
.3577 .23149 m .35586 .22929 L .35886 .22807 L F
.42989 .23281 m .43116 .22953 L .43293 .23158 L 0 .032 .133 r
F
.42989 .23281 m .42812 .23076 L .43116 .22953 L F
.45815 .2339 m .45946 .23064 L .4612 .23286 L 0 .034 .135 r
F
.45815 .2339 m .45642 .23167 L .45946 .23064 L F
.43773 .23239 m .43901 .22918 L .44077 .23122 L 0 .031 .132 r
F
.43773 .23239 m .43597 .23035 L .43901 .22918 L F
.56953 .23307 m .57101 .22981 L .57264 .23198 L 0 .033 .133 r
F
.56953 .23307 m .5679 .23091 L .57101 .22981 L F
.40163 .23178 m .40285 .22859 L .40464 .23073 L 0 .03 .13 r
F
.40163 .23178 m .39983 .22967 L .40285 .22859 L F
.63697 .23201 m .63856 .2288 L .64011 .23084 L 0 .031 .131 r
F
.63697 .23201 m .63541 .22997 L .63856 .2288 L F
.16937 .22876 m .17022 .22557 L .17225 .22768 L 0 .024 .123 r
F
.16937 .22876 m .16734 .22666 L .17022 .22557 L F
.52559 .23289 m .52701 .22971 L .52868 .23185 L 0 .032 .133 r
F
.52559 .23289 m .52392 .23075 L .52701 .22971 L F
.70441 .23095 m .70611 .22768 L .70759 .22971 L 0 .028 .128 r
F
.70441 .23095 m .70293 .22893 L .70611 .22768 L F
.71225 .23053 m .71396 .22734 L .71544 .22942 L 0 .028 .127 r
F
.71225 .23053 m .71077 .22849 L .71396 .22734 L F
.32943 .23054 m .33054 .22732 L .33241 .22941 L F
.32943 .23054 m .32756 .22843 L .33054 .22732 L F
.46599 .23359 m .46731 .23035 L .46904 .23236 L 0 .034 .135 r
F
.46599 .23359 m .46425 .23161 L .46731 .23035 L F
.47382 .23315 m .47516 .22987 L .47688 .23192 L 0 .033 .134 r
F
.47382 .23315 m .4721 .23112 L .47516 .22987 L F
.64481 .23166 m .64641 .22835 L .64795 .23041 L 0 .03 .13 r
F
.64481 .23166 m .64326 .22959 L .64641 .22835 L F
.77186 .22995 m .77367 .22681 L .77509 .22885 L 0 .027 .126 r
F
.77186 .22995 m .77045 .22792 L .77367 .22681 L F
.69658 .23147 m .69826 .22814 L .69975 .23019 L 0 .029 .129 r
F
.69658 .23147 m .69509 .22944 L .69826 .22814 L F
.36553 .23127 m .3667 .22787 L .36852 .23007 L F
.36553 .23127 m .3637 .22907 L .3667 .22787 L F
.68875 .23192 m .69041 .22857 L .69192 .23073 L 0 .03 .131 r
F
.68875 .23192 m .68724 .22975 L .69041 .22857 L F
.48166 .2328 m .483 .2296 L .48472 .2317 L 0 .032 .133 r
F
.48166 .2328 m .47994 .23069 L .483 .2296 L F
.25723 .22934 m .2582 .22629 L .26015 .2283 L 0 .026 .125 r
F
.25723 .22934 m .25527 .22733 L .2582 .22629 L F
.65265 .2313 m .65427 .22814 L .6558 .23015 L 0 .029 .129 r
F
.65265 .2313 m .65111 .22927 L .65427 .22814 L F
.33725 .2303 m .33836 .22722 L .34023 .22924 L 0 .028 .127 r
F
.33725 .2303 m .33538 .22831 L .33836 .22722 L F
.21328 .22924 m .21421 .22595 L .21619 .22808 L 0 .025 .124 r
F
.21328 .22924 m .21129 .2271 L .21421 .22595 L F
.7201 .23035 m .72182 .2271 L .72329 .22918 L 0 .028 .127 r
F
.7201 .23035 m .71863 .2283 L .72182 .2271 L F
.29331 .23015 m .29436 .2269 L .29627 .22899 L 0 .027 .127 r
F
.29331 .23015 m .2914 .22806 L .29436 .2269 L F
.57737 .23299 m .57886 .22962 L .58048 .23177 L 0 .033 .133 r
F
.57737 .23299 m .57575 .23085 L .57886 .22962 L F
.37335 .23103 m .37453 .22771 L .37635 .22986 L 0 .029 .129 r
F
.37335 .23103 m .37153 .22889 L .37453 .22771 L F
.17717 .22867 m .17802 .22555 L .18005 .22763 L 0 .025 .123 r
F
.17717 .22867 m .17514 .2266 L .17802 .22555 L F
.5256 .56847 m .52701 .5491 L .52868 .55902 L .947 .216 0 r
F
.5256 .56847 m .52392 .55824 L .52701 .5491 L F
.2211 .22891 m .22203 .22573 L .22402 .22775 L 0 .025 .124 r
F
.2211 .22891 m .21911 .22691 L .22203 .22573 L F
.77972 .22981 m .78154 .22656 L .78295 .22865 L 0 .027 .126 r
F
.77972 .22981 m .77831 .2277 L .78154 .22656 L F
.30114 .22982 m .3022 .22663 L .30411 .22864 L F
.30114 .22982 m .29923 .22781 L .3022 .22663 L F
.72795 .23004 m .72968 .22672 L .73114 .22883 L F
.72795 .23004 m .72648 .22795 L .72968 .22672 L F
.44555 .23244 m .44684 .22921 L .44859 .23143 L 0 .032 .133 r
F
.44555 .23244 m .4438 .23021 L .44684 .22921 L F
.6605 .2312 m .66213 .22794 L .66366 .23012 L 0 .03 .13 r
F
.6605 .2312 m .65896 .22901 L .66213 .22794 L F
.53343 .23295 m .53486 .22978 L .53652 .23193 L 0 .033 .134 r
F
.53343 .23295 m .53177 .23081 L .53486 .22978 L F
.58521 .23273 m .58672 .22935 L .58833 .23153 L 0 .032 .133 r
F
.58521 .23273 m .5836 .23056 L .58672 .22935 L F
.48949 .23273 m .49085 .22957 L .49256 .23164 L 0 .033 .133 r
F
.48949 .23273 m .48778 .23063 L .49085 .22957 L F
.30897 .22948 m .31005 .22627 L .31194 .2283 L 0 .026 .125 r
F
.30897 .22948 m .30707 .22745 L .31005 .22627 L F
.26503 .22926 m .26602 .22624 L .26796 .22823 L F
.26503 .22926 m .26308 .22727 L .26602 .22624 L F
.22893 .22861 m .22986 .2255 L .23185 .22752 L 0 .025 .123 r
F
.22893 .22861 m .22695 .22659 L .22986 .2255 L F
.40944 .23192 m .41068 .22865 L .41246 .2309 L 0 .031 .131 r
F
.40944 .23192 m .40766 .22968 L .41068 .22865 L F
.34507 .2302 m .34619 .22714 L .34805 .22918 L 0 .028 .128 r
F
.34507 .2302 m .34321 .22817 L .34619 .22714 L F
.38117 .23094 m .38236 .22775 L .38417 .22987 L 0 .029 .129 r
F
.38117 .23094 m .37935 .22881 L .38236 .22775 L F
.7358 .22988 m .73756 .22677 L .73901 .22886 L 0 .027 .127 r
F
.7358 .22988 m .73435 .2278 L .73756 .22677 L F
.18497 .22858 m .18582 .22554 L .18785 .22753 L 0 .025 .124 r
F
.18497 .22858 m .18293 .22659 L .18582 .22554 L F
.78758 .22967 m .78943 .22657 L .79082 .22862 L 0 .027 .126 r
F
.78758 .22967 m .78618 .2276 L .78943 .22657 L F
.59305 .2325 m .59457 .2291 L .59617 .23128 L 0 .032 .133 r
F
.59305 .2325 m .59145 .23032 L .59457 .2291 L F
.49732 .23263 m .4987 .22953 L .50039 .23156 L 0 .033 .134 r
F
.49732 .23263 m .49562 .23058 L .4987 .22953 L F
.27284 .22919 m .27385 .226 L .27579 .22804 L 0 .026 .125 r
F
.27284 .22919 m .2709 .22717 L .27385 .226 L F
.23673 .22856 m .23768 .2254 L .23965 .22748 L 0 .025 .124 r
F
.23673 .22856 m .23476 .22646 L .23768 .2254 L F
.31678 .22943 m .31787 .22617 L .31975 .22838 L 0 .027 .126 r
F
.31678 .22943 m .31491 .22721 L .31787 .22617 L F
.19278 .22835 m .19366 .2252 L .19569 .2272 L 0 .025 .123 r
F
.19278 .22835 m .19076 .22636 L .19366 .2252 L F
.60089 .23228 m .60243 .22913 L .60402 .23121 L 0 .032 .133 r
F
.60089 .23228 m .5993 .2302 L .60243 .22913 L F
.66836 .23126 m .66999 .22787 L .67152 .23007 L 0 .03 .13 r
F
.66836 .23126 m .66683 .22905 L .66999 .22787 L F
.80329 .2291 m .80515 .22593 L .80653 .22794 L 0 .026 .125 r
F
.80329 .2291 m .80191 .22708 L .80515 .22593 L F
.74366 .22978 m .74543 .22662 L .74687 .22861 L 0 .028 .127 r
F
.74366 .22978 m .74222 .22779 L .74543 .22662 L F
.79545 .22958 m .79729 .2263 L .79868 .22833 L 0 .027 .126 r
F
.79545 .22958 m .79406 .22753 L .79729 .2263 L F
.54127 .23309 m .54271 .22992 L .54437 .23206 L 0 .034 .135 r
F
.54127 .23309 m .53962 .23094 L .54271 .22992 L F
.38899 .23092 m .39019 .2277 L .392 .2298 L 0 .03 .13 r
F
.38899 .23092 m .38718 .22879 L .39019 .2277 L F
.45337 .23269 m .45468 .22941 L .45642 .23167 L 0 .033 .134 r
F
.45337 .23269 m .45163 .23042 L .45468 .22941 L F
.75151 .22943 m .75329 .22631 L .75472 .22831 L 0 .027 .126 r
F
.75151 .22943 m .75008 .22744 L .75329 .22631 L F
.35288 .23034 m .35402 .22711 L .35586 .22929 L 0 .029 .129 r
F
.35288 .23034 m .35103 .22817 L .35402 .22711 L F
.81114 .22882 m .81302 .22572 L .81439 .2277 L 0 .026 .125 r
F
.81114 .22882 m .80977 .22683 L .81302 .22572 L F
.67621 .23101 m .67785 .22757 L .67937 .22975 L 0 .03 .13 r
F
.67621 .23101 m .67469 .22882 L .67785 .22757 L F
.28065 .22905 m .28169 .22577 L .2836 .22796 L 0 .026 .125 r
F
.28065 .22905 m .27874 .22688 L .28169 .22577 L F
.50516 .23253 m .50655 .22908 L .50824 .23127 L 0 .033 .134 r
F
.50516 .23253 m .50347 .23036 L .50655 .22908 L F
.20059 .2282 m .20149 .22499 L .20349 .22713 L 0 .025 .123 r
F
.20059 .2282 m .19859 .22608 L .20149 .22499 L F
.41726 .23213 m .41851 .22876 L .42028 .23102 L 0 .032 .133 r
F
.41726 .23213 m .41548 .22988 L .41851 .22876 L F
.60874 .23214 m .61029 .2288 L .61187 .23089 L F
.60874 .23214 m .60716 .23007 L .61029 .2288 L F
.55695 .23241 m .55842 .22911 L .56005 .23113 L 0 .033 .134 r
F
.55695 .23241 m .55531 .23035 L .55842 .22911 L F
.24453 .2285 m .24551 .22521 L .24747 .22735 L 0 .025 .124 r
F
.24453 .2285 m .24258 .22635 L .24551 .22521 L F
.61658 .23177 m .61814 .22843 L .61972 .23056 L 0 .032 .132 r
F
.61658 .23177 m .615 .22965 L .61814 .22843 L F
.75936 .22919 m .76116 .22609 L .76258 .22808 L 0 .027 .126 r
F
.75936 .22919 m .75794 .2272 L .76116 .22609 L F
.62442 .23137 m .626 .22817 L .62756 .23015 L 0 .031 .131 r
F
.62442 .23137 m .62285 .22936 L .626 .22817 L F
.54911 .2329 m .55057 .22954 L .55221 .23162 L 0 .034 .135 r
F
.54911 .2329 m .54746 .2308 L .55057 .22954 L F
.56479 .23203 m .56627 .22874 L .5679 .23091 L 0 .032 .133 r
F
.56479 .23203 m .56316 .22986 L .56627 .22874 L F
.513 .23226 m .5144 .22873 L .51608 .23099 L F
.513 .23226 m .51132 .23001 L .5144 .22873 L F
.39682 .23077 m .39803 .22756 L .39983 .22967 L 0 .03 .13 r
F
.39682 .23077 m .39501 .22868 L .39803 .22756 L F
.16445 .22776 m .1653 .22456 L .16734 .22666 L 0 .024 .123 r
F
.16445 .22776 m .16241 .22565 L .1653 .22456 L F
.63227 .23105 m .63386 .22798 L .63541 .22997 L 0 .031 .131 r
F
.63227 .23105 m .63071 .22907 L .63386 .22798 L F
.32459 .22953 m .32569 .22624 L .32756 .22843 L 0 .027 .127 r
F
.32459 .22953 m .32272 .22733 L .32569 .22624 L F
.68406 .23085 m .68573 .22757 L .68724 .22975 L 0 .03 .13 r
F
.68406 .23085 m .68255 .22866 L .68573 .22757 L F
.52084 .23194 m .52225 .22851 L .52392 .23075 L 0 .032 .133 r
F
.52084 .23194 m .51916 .22971 L .52225 .22851 L F
.52727 .57019 m .52868 .55902 L .53035 .56075 L .963 .155 0 r
F
.42509 .23198 m .42635 .22858 L .42812 .23076 L 0 .032 .133 r
F
.42509 .23198 m .42332 .2298 L .42635 .22858 L F
.43293 .23158 m .4342 .2283 L .43597 .23035 L 0 .032 .132 r
F
.43293 .23158 m .43116 .22953 L .4342 .2283 L F
.3607 .23028 m .36186 .22686 L .3637 .22907 L 0 .029 .129 r
F
.3607 .23028 m .35886 .22807 L .36186 .22686 L F
.76722 .22899 m .76903 .22591 L .77045 .22792 L 0 .027 .126 r
F
.76722 .22899 m .76581 .227 L .76903 .22591 L F
.25235 .22837 m .25333 .22519 L .25527 .22733 L 0 .026 .124 r
F
.25235 .22837 m .2504 .22624 L .25333 .22519 L F
.52083 .55917 m .52225 .54804 L .52392 .55824 L .932 .276 0 r
F
.44077 .23122 m .44204 .22817 L .4438 .23021 L 0 .031 .132 r
F
.44077 .23122 m .43901 .22918 L .44204 .22817 L F
.70759 .22971 m .70929 .22644 L .71077 .22849 L 0 .028 .128 r
F
.70759 .22971 m .70611 .22768 L .70929 .22644 L F
.47688 .23192 m .47822 .22861 L .47994 .23069 L 0 .032 .133 r
F
.47688 .23192 m .47516 .22987 L .47822 .22861 L F
.46904 .23236 m .47037 .22909 L .4721 .23112 L 0 .033 .134 r
F
.46904 .23236 m .46731 .23035 L .47037 .22909 L F
.64011 .23084 m .64171 .22755 L .64326 .22959 L 0 .03 .13 r
F
.64011 .23084 m .63856 .2288 L .64171 .22755 L F
.28846 .2291 m .2895 .22583 L .2914 .22806 L 0 .027 .126 r
F
.28846 .2291 m .28655 .2269 L .2895 .22583 L F
.69975 .23019 m .70144 .22688 L .70293 .22893 L 0 .029 .129 r
F
.69975 .23019 m .69826 .22814 L .70144 .22688 L F
.20838 .22823 m .2093 .22493 L .21129 .2271 L 0 .025 .124 r
F
.20838 .22823 m .20639 .22606 L .2093 .22493 L F
.64795 .23041 m .64957 .22723 L .65111 .22927 L 0 .03 .13 r
F
.64795 .23041 m .64641 .22835 L .64957 .22723 L F
.57264 .23198 m .57413 .22869 L .57575 .23085 L 0 .033 .133 r
F
.57264 .23198 m .57101 .22981 L .57413 .22869 L F
.4612 .23286 m .46252 .22939 L .46425 .23161 L 0 .034 .135 r
F
.4612 .23286 m .45946 .23064 L .46252 .22939 L F
.33241 .22941 m .33352 .22621 L .33538 .22831 L 0 .028 .127 r
F
.33241 .22941 m .33054 .22732 L .33352 .22621 L F
.71544 .22942 m .71716 .22619 L .71863 .2283 L F
.71544 .22942 m .71396 .22734 L .71716 .22619 L F
.17225 .22768 m .17311 .22447 L .17514 .2266 L 0 .025 .123 r
F
.17225 .22768 m .17022 .22557 L .17311 .22447 L F
.36852 .23007 m .3697 .22668 L .37153 .22889 L 0 .029 .129 r
F
.36852 .23007 m .3667 .22787 L .3697 .22668 L F
.40464 .23073 m .40587 .22751 L .40766 .22968 L 0 .03 .131 r
F
.40464 .23073 m .40285 .22859 L .40587 .22751 L F
.69192 .23073 m .69359 .22729 L .69509 .22944 L 0 .03 .13 r
F
.69192 .23073 m .69041 .22857 L .69359 .22729 L F
.52868 .23185 m .5301 .22867 L .53177 .23081 L 0 .033 .133 r
F
.52868 .23185 m .52701 .22971 L .5301 .22867 L F
.6558 .23015 m .65743 .22702 L .65896 .22901 L 0 .029 .129 r
F
.6558 .23015 m .65427 .22814 L .65743 .22702 L F
.77509 .22885 m .7769 .22565 L .77831 .2277 L 0 .027 .126 r
F
.77509 .22885 m .77367 .22681 L .7769 .22565 L F
.48472 .2317 m .48607 .22855 L .48778 .23063 L 0 .032 .133 r
F
.48472 .2317 m .483 .2296 L .48607 .22855 L F
.21619 .22808 m .21713 .22479 L .21911 .22691 L 0 .025 .124 r
F
.21619 .22808 m .21421 .22595 L .21713 .22479 L F
.58048 .23177 m .58198 .2284 L .5836 .23056 L 0 .032 .133 r
F
.58048 .23177 m .57886 .22962 L .58198 .2284 L F
.26015 .2283 m .26113 .22526 L .26308 .22727 L 0 .026 .125 r
F
.26015 .2283 m .2582 .22629 L .26113 .22526 L F
.72329 .22918 m .72502 .22585 L .72648 .22795 L 0 .027 .127 r
F
.72329 .22918 m .72182 .2271 L .72502 .22585 L F
.29627 .22899 m .29733 .22574 L .29923 .22781 L 0 .027 .126 r
F
.29627 .22899 m .29436 .2269 L .29733 .22574 L F
.37635 .22986 m .37753 .22667 L .37935 .22881 L 0 .029 .129 r
F
.37635 .22986 m .37453 .22771 L .37753 .22667 L F
.34023 .22924 m .34135 .22614 L .34321 .22817 L 0 .028 .127 r
F
.34023 .22924 m .33836 .22722 L .34135 .22614 L F
.73114 .22883 m .73289 .22567 L .73435 .2278 L 0 .027 .126 r
F
.73114 .22883 m .72968 .22672 L .73289 .22567 L F
.22402 .22775 m .22496 .22456 L .22695 .22659 L 0 .025 .124 r
F
.22402 .22775 m .22203 .22573 L .22496 .22456 L F
.30411 .22864 m .30517 .22544 L .30707 .22745 L 0 .027 .126 r
F
.30411 .22864 m .3022 .22663 L .30517 .22544 L F
.78295 .22865 m .78478 .22553 L .78618 .2276 L F
.78295 .22865 m .78154 .22656 L .78478 .22553 L F
.58833 .23153 m .58984 .22813 L .59145 .23032 L 0 .032 .133 r
F
.58833 .23153 m .58672 .22935 L .58984 .22813 L F
.18005 .22763 m .18091 .22452 L .18293 .22659 L 0 .025 .124 r
F
.18005 .22763 m .17802 .22555 L .18091 .22452 L F
.31194 .2283 m .31301 .22518 L .31491 .22721 L 0 .026 .125 r
F
.31194 .2283 m .31005 .22627 L .31301 .22518 L F
.49256 .23164 m .49392 .22853 L .49562 .23058 L 0 .033 .134 r
F
.49256 .23164 m .49085 .22957 L .49392 .22853 L F
.66366 .23012 m .6653 .22686 L .66683 .22905 L 0 .03 .13 r
F
.66366 .23012 m .66213 .22794 L .6653 .22686 L F
.44859 .23143 m .44989 .2282 L .45163 .23042 L 0 .032 .133 r
F
.44859 .23143 m .44684 .22921 L .44989 .2282 L F
.23185 .22752 m .23278 .22445 L .23476 .22646 L 0 .025 .124 r
F
.23185 .22752 m .22986 .2255 L .23278 .22445 L F
.26796 .22823 m .26896 .22519 L .2709 .22717 L 0 .026 .126 r
F
.26796 .22823 m .26602 .22624 L .26896 .22519 L F
.59617 .23128 m .5977 .22802 L .5993 .2302 L 0 .032 .133 r
F
.59617 .23128 m .59457 .2291 L .5977 .22802 L F
.53652 .23193 m .53796 .22876 L .53962 .23094 L 0 .034 .134 r
F
.53652 .23193 m .53486 .22978 L .53796 .22876 L F
.41246 .2309 m .4137 .22762 L .41548 .22988 L 0 .031 .132 r
F
.41246 .2309 m .41068 .22865 L .4137 .22762 L F
.34805 .22918 m .34918 .22611 L .35103 .22817 L 0 .028 .128 r
F
.34805 .22918 m .34619 .22714 L .34918 .22611 L F
.38417 .22987 m .38537 .22669 L .38718 .22879 L 0 .029 .129 r
F
.38417 .22987 m .38236 .22775 L .38537 .22669 L F
.18785 .22753 m .18873 .22437 L .19076 .22636 L 0 .025 .124 r
F
.18785 .22753 m .18582 .22554 L .18873 .22437 L F
.79082 .22862 m .79267 .2255 L .79406 .22753 L 0 .027 .127 r
F
.79082 .22862 m .78943 .22657 L .79267 .2255 L F
.73901 .22886 m .74077 .2257 L .74222 .22779 L 0 .028 .127 r
F
.73901 .22886 m .73756 .22677 L .74077 .2257 L F
.27579 .22804 m .27681 .22483 L .27874 .22688 L 0 .026 .125 r
F
.27579 .22804 m .27385 .226 L .27681 .22483 L F
.19569 .2272 m .19657 .22407 L .19859 .22608 L 0 .025 .123 r
F
.19569 .2272 m .19366 .2252 L .19657 .22407 L F
.50039 .23156 m .50177 .22834 L .50347 .23036 L 0 .033 .134 r
F
.50039 .23156 m .4987 .22953 L .50177 .22834 L F
.79868 .22833 m .80053 .22506 L .80191 .22708 L 0 .027 .126 r
F
.79868 .22833 m .79729 .2263 L .80053 .22506 L F
.67152 .23007 m .67316 .22663 L .67469 .22882 L 0 .03 .13 r
F
.67152 .23007 m .66999 .22787 L .67316 .22663 L F
.23965 .22748 m .24061 .22427 L .24258 .22635 L 0 .025 .124 r
F
.23965 .22748 m .23768 .2254 L .24061 .22427 L F
.80653 .22794 m .8084 .22483 L .80977 .22683 L 0 .026 .125 r
F
.80653 .22794 m .80515 .22593 L .8084 .22483 L F
.31975 .22838 m .32084 .22513 L .32272 .22733 L 0 .027 .126 r
F
.31975 .22838 m .31787 .22617 L .32084 .22513 L F
.60402 .23121 m .60557 .22797 L .60716 .23007 L 0 .032 .133 r
F
.60402 .23121 m .60243 .22913 L .60557 .22797 L F
.74687 .22861 m .74864 .22545 L .75008 .22744 L 0 .027 .127 r
F
.74687 .22861 m .74543 .22662 L .74864 .22545 L F
.50824 .23127 m .50963 .22779 L .51132 .23001 L 0 .032 .133 r
F
.50824 .23127 m .50655 .22908 L .50963 .22779 L F
.67937 .22975 m .68103 .22651 L .68255 .22866 L 0 .03 .13 r
F
.67937 .22975 m .67785 .22757 L .68103 .22651 L F
.392 .2298 m .39321 .2266 L .39501 .22868 L F
.392 .2298 m .39019 .2277 L .39321 .2266 L F
.61187 .23089 m .61342 .22752 L .615 .22965 L 0 .032 .132 r
F
.61187 .23089 m .61029 .2288 L .61342 .22752 L F
.56005 .23113 m .56153 .22786 L .56316 .22986 L 0 .032 .133 r
F
.56005 .23113 m .55842 .22911 L .56153 .22786 L F
.75472 .22831 m .75651 .2252 L .75794 .2272 L 0 .027 .126 r
F
.75472 .22831 m .75329 .22631 L .75651 .2252 L F
.55221 .23162 m .55367 .2283 L .55531 .23035 L 0 .033 .134 r
F
.55221 .23162 m .55057 .22954 L .55367 .2283 L F
.54437 .23206 m .54581 .22866 L .54746 .2308 L 0 .034 .135 r
F
.54437 .23206 m .54271 .22992 L .54581 .22866 L F
.51608 .23099 m .51748 .22745 L .51916 .22971 L 0 .032 .132 r
F
.51608 .23099 m .5144 .22873 L .51748 .22745 L F
.61972 .23056 m .62128 .22723 L .62285 .22936 L 0 .031 .132 r
F
.61972 .23056 m .61814 .22843 L .62128 .22723 L F
.2836 .22796 m .28464 .22469 L .28655 .2269 L 0 .026 .125 r
F
.2836 .22796 m .28169 .22577 L .28464 .22469 L F
.45642 .23167 m .45773 .22839 L .45946 .23064 L 0 .034 .135 r
F
.45642 .23167 m .45468 .22941 L .45773 .22839 L F
.42028 .23102 m .42154 .22755 L .42332 .2298 L 0 .032 .133 r
F
.42028 .23102 m .41851 .22876 L .42154 .22755 L F
.62756 .23015 m .62915 .22707 L .63071 .22907 L 0 .031 .131 r
F
.62756 .23015 m .626 .22817 L .62915 .22707 L F
.35586 .22929 m .35702 .22589 L .35886 .22807 L 0 .029 .128 r
F
.35586 .22929 m .35402 .22711 L .35702 .22589 L F
.24747 .22735 m .24844 .2241 L .2504 .22624 L 0 .025 .124 r
F
.24747 .22735 m .24551 .22521 L .24844 .2241 L F
.20349 .22713 m .2044 .22391 L .20639 .22606 L F
.20349 .22713 m .20149 .22499 L .2044 .22391 L F
.5679 .23091 m .56938 .22764 L .57101 .22981 L 0 .032 .133 r
F
.5679 .23091 m .56627 .22874 L .56938 .22764 L F
.76258 .22808 m .76439 .225 L .76581 .227 L 0 .027 .126 r
F
.76258 .22808 m .76116 .22609 L .76439 .225 L F
.52392 .23075 m .52534 .22747 L .52701 .22971 L 0 .032 .133 r
F
.52392 .23075 m .52225 .22851 L .52534 .22747 L F
.42812 .23076 m .42939 .22737 L .43116 .22953 L 0 .032 .132 r
F
.42812 .23076 m .42635 .22858 L .42939 .22737 L F
.39983 .22967 m .40105 .22644 L .40285 .22859 L 0 .03 .13 r
F
.39983 .22967 m .39803 .22756 L .40105 .22644 L F
.43597 .23035 m .43724 .22713 L .43901 .22918 L 0 .031 .132 r
F
.43597 .23035 m .4342 .2283 L .43724 .22713 L F
.16734 .22666 m .16818 .22345 L .17022 .22557 L 0 .024 .123 r
F
.16734 .22666 m .1653 .22456 L .16818 .22345 L F
.3637 .22907 m .36487 .22565 L .3667 .22787 L 0 .028 .128 r
F
.3637 .22907 m .36186 .22686 L .36487 .22565 L F
.32756 .22843 m .32867 .22515 L .33054 .22732 L 0 .027 .127 r
F
.32756 .22843 m .32569 .22624 L .32867 .22515 L F
.68724 .22975 m .6889 .22641 L .69041 .22857 L 0 .03 .13 r
F
.68724 .22975 m .68573 .22757 L .6889 .22641 L F
.63541 .22997 m .63701 .2268 L .63856 .2288 L 0 .031 .131 r
F
.63541 .22997 m .63386 .22798 L .63701 .2268 L F
.71077 .22849 m .71248 .22526 L .71396 .22734 L 0 .028 .127 r
F
.71077 .22849 m .70929 .22644 L .71248 .22526 L F
.70293 .22893 m .70462 .22563 L .70611 .22768 L 0 .029 .128 r
F
.70293 .22893 m .70144 .22688 L .70462 .22563 L F
.64326 .22959 m .64486 .22631 L .64641 .22835 L 0 .03 .13 r
F
.64326 .22959 m .64171 .22755 L .64486 .22631 L F
.4721 .23112 m .47343 .22781 L .47516 .22987 L 0 .033 .134 r
F
.4721 .23112 m .47037 .22909 L .47343 .22781 L F
.47994 .23069 m .48129 .22752 L .483 .2296 L 0 .032 .133 r
F
.47994 .23069 m .47822 .22861 L .48129 .22752 L F
.46425 .23161 m .46558 .22812 L .46731 .23035 L 0 .034 .135 r
F
.46425 .23161 m .46252 .22939 L .46558 .22812 L F
.69509 .22944 m .69676 .22601 L .69826 .22814 L 0 .029 .129 r
F
.69509 .22944 m .69359 .22729 L .69676 .22601 L F
.77045 .22792 m .77226 .22479 L .77367 .22681 L 0 .027 .126 r
F
.77045 .22792 m .76903 .22591 L .77226 .22479 L F
.65111 .22927 m .65273 .22612 L .65427 .22814 L 0 .03 .13 r
F
.65111 .22927 m .64957 .22723 L .65273 .22612 L F
.21129 .2271 m .21222 .2238 L .21421 .22595 L 0 .025 .124 r
F
.21129 .2271 m .2093 .22493 L .21222 .2238 L F
.25527 .22733 m .25626 .22414 L .2582 .22629 L 0 .026 .125 r
F
.25527 .22733 m .25333 .22519 L .25626 .22414 L F
.37153 .22889 m .37271 .22548 L .37453 .22771 L 0 .028 .128 r
F
.37153 .22889 m .3697 .22668 L .37271 .22548 L F
.57575 .23085 m .57724 .22746 L .57886 .22962 L 0 .032 .133 r
F
.57575 .23085 m .57413 .22869 L .57724 .22746 L F
.4438 .23021 m .44509 .22716 L .44684 .22921 L 0 .032 .132 r
F
.4438 .23021 m .44204 .22817 L .44509 .22716 L F
.2914 .22806 m .29246 .22469 L .29436 .2269 L 0 .027 .126 r
F
.2914 .22806 m .2895 .22583 L .29246 .22469 L F
.71863 .2283 m .72035 .22498 L .72182 .2271 L 0 .028 .127 r
F
.71863 .2283 m .71716 .22619 L .72035 .22498 L F
.33538 .22831 m .3365 .22511 L .33836 .22722 L F
.33538 .22831 m .33352 .22621 L .3365 .22511 L F
.17514 .2266 m .17599 .22343 L .17802 .22555 L 0 .025 .123 r
F
.17514 .2266 m .17311 .22447 L .17599 .22343 L F
.77831 .2277 m .78013 .2245 L .78154 .22656 L 0 .027 .126 r
F
.77831 .2277 m .7769 .22565 L .78013 .2245 L F
.65896 .22901 m .6606 .22593 L .66213 .22794 L 0 .029 .129 r
F
.65896 .22901 m .65743 .22702 L .6606 .22593 L F
.40766 .22968 m .40889 .22644 L .41068 .22865 L 0 .031 .131 r
F
.40766 .22968 m .40587 .22751 L .40889 .22644 L F
.72648 .22795 m .72821 .2246 L .72968 .22672 L 0 .027 .126 r
F
.72648 .22795 m .72502 .22585 L .72821 .2246 L F
.5836 .23056 m .5851 .22719 L .58672 .22935 L 0 .032 .133 r
F
.5836 .23056 m .58198 .2284 L .5851 .22719 L F
.53177 .23081 m .5332 .22763 L .53486 .22978 L 0 .033 .134 r
F
.53177 .23081 m .5301 .22867 L .5332 .22763 L F
.21911 .22691 m .22005 .22362 L .22203 .22573 L 0 .025 .124 r
F
.21911 .22691 m .21713 .22479 L .22005 .22362 L F
.48778 .23063 m .48914 .2275 L .49085 .22957 L 0 .033 .133 r
F
.48778 .23063 m .48607 .22855 L .48914 .2275 L F
.29923 .22781 m .3003 .22456 L .3022 .22663 L 0 .027 .126 r
F
.29923 .22781 m .29733 .22574 L .3003 .22456 L F
.30707 .22745 m .30815 .22424 L .31005 .22627 L 0 .026 .126 r
F
.30707 .22745 m .30517 .22544 L .30815 .22424 L F
.22695 .22659 m .22788 .22347 L .22986 .2255 L 0 .025 .124 r
F
.22695 .22659 m .22496 .22456 L .22788 .22347 L F
.59145 .23032 m .59297 .22691 L .59457 .2291 L 0 .032 .132 r
F
.59145 .23032 m .58984 .22813 L .59297 .22691 L F
.26308 .22727 m .26407 .22424 L .26602 .22624 L 0 .026 .126 r
F
.26308 .22727 m .26113 .22526 L .26407 .22424 L F
.37935 .22881 m .38054 .22563 L .38236 .22775 L 0 .029 .129 r
F
.37935 .22881 m .37753 .22667 L .38054 .22563 L F
.34321 .22817 m .34433 .22509 L .34619 .22714 L 0 .028 .128 r
F
.34321 .22817 m .34135 .22614 L .34433 .22509 L F
.73435 .2278 m .7361 .22462 L .73756 .22677 L 0 .027 .127 r
F
.73435 .2278 m .73289 .22567 L .7361 .22462 L F
.78618 .2276 m .78803 .22452 L .78943 .22657 L 0 .027 .126 r
F
.78618 .2276 m .78478 .22553 L .78803 .22452 L F
.31491 .22721 m .31598 .22415 L .31787 .22617 L 0 .026 .126 r
F
.31491 .22721 m .31301 .22518 L .31598 .22415 L F
.18293 .22659 m .1838 .22348 L .18582 .22554 L 0 .025 .124 r
F
.18293 .22659 m .18091 .22452 L .1838 .22348 L F
.66683 .22905 m .66846 .22568 L .66999 .22787 L 0 .03 .13 r
F
.66683 .22905 m .6653 .22686 L .66846 .22568 L F
.49562 .23058 m .49699 .22749 L .4987 .22953 L 0 .033 .134 r
F
.49562 .23058 m .49392 .22853 L .49699 .22749 L F
.23476 .22646 m .2357 .22339 L .23768 .2254 L 0 .025 .124 r
F
.23476 .22646 m .23278 .22445 L .2357 .22339 L F
.45163 .23042 m .45293 .2272 L .45468 .22941 L 0 .033 .133 r
F
.45163 .23042 m .44989 .2282 L .45293 .2272 L F
.5993 .2302 m .60083 .22693 L .60243 .22913 L 0 .032 .133 r
F
.5993 .2302 m .5977 .22802 L .60083 .22693 L F
.2709 .22717 m .27191 .22401 L .27385 .226 L 0 .026 .126 r
F
.2709 .22717 m .26896 .22519 L .27191 .22401 L F
.19076 .22636 m .19164 .22319 L .19366 .2252 L 0 .025 .124 r
F
.19076 .22636 m .18873 .22437 L .19164 .22319 L F
.53962 .23094 m .54106 .22772 L .54271 .22992 L 0 .034 .135 r
F
.53962 .23094 m .53796 .22876 L .54106 .22772 L F
.41548 .22988 m .41673 .2265 L .41851 .22876 L 0 .031 .132 r
F
.41548 .22988 m .4137 .22762 L .41673 .2265 L F
.38718 .22879 m .38838 .22561 L .39019 .2277 L 0 .03 .13 r
F
.38718 .22879 m .38537 .22669 L .38838 .22561 L F
.35103 .22817 m .35217 .22505 L .35402 .22711 L 0 .029 .128 r
F
.35103 .22817 m .34918 .22611 L .35217 .22505 L F
.67469 .22882 m .67633 .2254 L .67785 .22757 L 0 .029 .129 r
F
.67469 .22882 m .67316 .22663 L .67633 .2254 L F
.80191 .22708 m .80377 .22392 L .80515 .22593 L 0 .026 .126 r
F
.80191 .22708 m .80053 .22506 L .80377 .22392 L F
.27874 .22688 m .27976 .2237 L .28169 .22577 L 0 .026 .125 r
F
.27874 .22688 m .27681 .22483 L .27976 .2237 L F
.50347 .23036 m .50485 .22706 L .50655 .22908 L 0 .033 .133 r
F
.50347 .23036 m .50177 .22834 L .50485 .22706 L F
.79406 .22753 m .7959 .22428 L .79729 .2263 L 0 .027 .126 r
F
.79406 .22753 m .79267 .2255 L .7959 .22428 L F
.74222 .22779 m .74398 .22453 L .74543 .22662 L 0 .028 .127 r
F
.74222 .22779 m .74077 .2257 L .74398 .22453 L F
.19859 .22608 m .19948 .22296 L .20149 .22499 L 0 .025 .123 r
F
.19859 .22608 m .19657 .22407 L .19948 .22296 L F
.51132 .23001 m .51271 .2265 L .5144 .22873 L 0 .032 .132 r
F
.51132 .23001 m .50963 .22779 L .51271 .2265 L F
.24258 .22635 m .24355 .22314 L .24551 .22521 L 0 .025 .124 r
F
.24258 .22635 m .24061 .22427 L .24355 .22314 L F
.75008 .22744 m .75186 .22432 L .75329 .22631 L 0 .027 .127 r
F
.75008 .22744 m .74864 .22545 L .75186 .22432 L F
.60716 .23007 m .6087 .22667 L .61029 .2288 L 0 .032 .133 r
F
.60716 .23007 m .60557 .22797 L .6087 .22667 L F
.5225 .56939 m .52083 .55917 L .52392 .55824 L .963 .155 0 r
F
.56316 .22986 m .56464 .22674 L .56627 .22874 L 0 .032 .133 r
F
.56316 .22986 m .56153 .22786 L .56464 .22674 L F
.615 .22965 m .61656 .22629 L .61814 .22843 L 0 .031 .132 r
F
.615 .22965 m .61342 .22752 L .61656 .22629 L F
.80977 .22683 m .81165 .22374 L .81302 .22572 L 0 .026 .125 r
F
.80977 .22683 m .8084 .22483 L .81165 .22374 L F
.55531 .23035 m .55678 .22708 L .55842 .22911 L 0 .033 .134 r
F
.55531 .23035 m .55367 .2283 L .55678 .22708 L F
.54746 .2308 m .54892 .22741 L .55057 .22954 L 0 .034 .135 r
F
.54746 .2308 m .54581 .22866 L .54892 .22741 L F
.51916 .22971 m .52057 .22624 L .52225 .22851 L 0 .031 .132 r
F
.51916 .22971 m .51748 .22745 L .52057 .22624 L F
.32272 .22733 m .32382 .22405 L .32569 .22624 L 0 .027 .126 r
F
.32272 .22733 m .32084 .22513 L .32382 .22405 L F
.68255 .22866 m .68421 .22544 L .68573 .22757 L 0 .03 .13 r
F
.68255 .22866 m .68103 .22651 L .68421 .22544 L F
.39501 .22868 m .39623 .22546 L .39803 .22756 L F
.39501 .22868 m .39321 .2266 L .39623 .22546 L F
.62285 .22936 m .62442 .22603 L .626 .22817 L 0 .031 .131 r
F
.62285 .22936 m .62128 .22723 L .62442 .22603 L F
.42332 .2298 m .42458 .22634 L .42635 .22858 L 0 .032 .132 r
F
.42332 .2298 m .42154 .22755 L .42458 .22634 L F
.75794 .2272 m .75974 .22408 L .76116 .22609 L 0 .027 .126 r
F
.75794 .2272 m .75651 .2252 L .75974 .22408 L F
.35886 .22807 m .36002 .22467 L .36186 .22686 L 0 .028 .128 r
F
.35886 .22807 m .35702 .22589 L .36002 .22467 L F
.52727 .57019 m .5256 .56847 L .52868 .55902 L .963 .155 0 r
F
.63071 .22907 m .6323 .22598 L .63386 .22798 L 0 .031 .131 r
F
.63071 .22907 m .62915 .22707 L .6323 .22598 L F
.2504 .22624 m .25138 .22305 L .25333 .22519 L 0 .025 .124 r
F
.2504 .22624 m .24844 .2241 L .25138 .22305 L F
.28655 .2269 m .28759 .2236 L .2895 .22583 L 0 .026 .126 r
F
.28655 .2269 m .28464 .22469 L .28759 .2236 L F
.43116 .22953 m .43243 .22615 L .4342 .2283 L 0 .031 .132 r
F
.43116 .22953 m .42939 .22737 L .43243 .22615 L F
.20639 .22606 m .20731 .22279 L .2093 .22493 L 0 .025 .124 r
F
.20639 .22606 m .2044 .22391 L .20731 .22279 L F
.45946 .23064 m .46078 .22713 L .46252 .22939 L 0 .034 .134 r
F
.45946 .23064 m .45773 .22839 L .46078 .22713 L F
.57101 .22981 m .5725 .22651 L .57413 .22869 L 0 .032 .133 r
F
.57101 .22981 m .56938 .22764 L .5725 .22651 L F
.76581 .227 m .76762 .2239 L .76903 .22591 L 0 .027 .126 r
F
.76581 .227 m .76439 .225 L .76762 .2239 L F
.43901 .22918 m .44028 .22612 L .44204 .22817 L 0 .031 .132 r
F
.43901 .22918 m .43724 .22713 L .44028 .22612 L F
.3667 .22787 m .36787 .22444 L .3697 .22668 L 0 .028 .128 r
F
.3667 .22787 m .36487 .22565 L .36787 .22444 L F
.70611 .22768 m .70781 .22438 L .70929 .22644 L F
.70611 .22768 m .70462 .22563 L .70781 .22438 L F
.47516 .22987 m .4765 .22653 L .47822 .22861 L 0 .032 .133 r
F
.47516 .22987 m .47343 .22781 L .4765 .22653 L F
.64641 .22835 m .64802 .2252 L .64957 .22723 L 0 .03 .13 r
F
.64641 .22835 m .64486 .22631 L .64802 .2252 L F
.69041 .22857 m .69208 .22514 L .69359 .22729 L F
.69041 .22857 m .6889 .22641 L .69208 .22514 L F
.69826 .22814 m .69995 .22477 L .70144 .22688 L 0 .029 .129 r
F
.69826 .22814 m .69676 .22601 L .69995 .22477 L F
.63856 .2288 m .64016 .22555 L .64171 .22755 L 0 .03 .131 r
F
.63856 .2288 m .63701 .2268 L .64016 .22555 L F
.40285 .22859 m .40407 .22533 L .40587 .22751 L 0 .03 .13 r
F
.40285 .22859 m .40105 .22644 L .40407 .22533 L F
.46731 .23035 m .46864 .22686 L .47037 .22909 L 0 .033 .134 r
F
.46731 .23035 m .46558 .22812 L .46864 .22686 L F
.17022 .22557 m .17107 .22235 L .17311 .22447 L 0 .024 .123 r
F
.17022 .22557 m .16818 .22345 L .17107 .22235 L F
.52701 .22971 m .52843 .22642 L .5301 .22867 L 0 .032 .133 r
F
.52701 .22971 m .52534 .22747 L .52843 .22642 L F
.33054 .22732 m .33165 .22405 L .33352 .22621 L 0 .028 .127 r
F
.33054 .22732 m .32867 .22515 L .33165 .22405 L F
.71396 .22734 m .71568 .22408 L .71716 .22619 L F
.71396 .22734 m .71248 .22526 L .71568 .22408 L F
.483 .2296 m .48435 .22648 L .48607 .22855 L 0 .032 .133 r
F
.483 .2296 m .48129 .22752 L .48435 .22648 L F
.57886 .22962 m .58036 .22623 L .58198 .2284 L F
.57886 .22962 m .57724 .22746 L .58036 .22623 L F
.77367 .22681 m .77549 .22361 L .7769 .22565 L 0 .027 .126 r
F
.77367 .22681 m .77226 .22479 L .77549 .22361 L F
.21421 .22595 m .21514 .22266 L .21713 .22479 L 0 .025 .124 r
F
.21421 .22595 m .21222 .2238 L .21514 .22266 L F
.65427 .22814 m .6559 .22502 L .65743 .22702 L 0 .03 .13 r
F
.65427 .22814 m .65273 .22612 L .6559 .22502 L F
.37453 .22771 m .37571 .22445 L .37753 .22667 L 0 .029 .128 r
F
.37453 .22771 m .37271 .22548 L .37571 .22445 L F
.72182 .2271 m .72354 .22371 L .72502 .22585 L 0 .027 .127 r
F
.72182 .2271 m .72035 .22498 L .72354 .22371 L F
.29436 .2269 m .29543 .22355 L .29733 .22574 L 0 .027 .126 r
F
.29436 .2269 m .29246 .22469 L .29543 .22355 L F
.72968 .22672 m .73142 .22353 L .73289 .22567 L F
.72968 .22672 m .72821 .2246 L .73142 .22353 L F
.2582 .22629 m .25919 .22312 L .26113 .22526 L 0 .026 .125 r
F
.2582 .22629 m .25626 .22414 L .25919 .22312 L F
.58672 .22935 m .58823 .226 L .58984 .22813 L 0 .032 .132 r
F
.58672 .22935 m .5851 .22719 L .58823 .226 L F
.78154 .22656 m .78337 .22346 L .78478 .22553 L 0 .027 .126 r
F
.78154 .22656 m .78013 .2245 L .78337 .22346 L F
.33836 .22722 m .33949 .22401 L .34135 .22614 L 0 .028 .127 r
F
.33836 .22722 m .3365 .22511 L .33949 .22401 L F
.44684 .22921 m .44813 .22614 L .44989 .2282 L 0 .032 .133 r
F
.44684 .22921 m .44509 .22716 L .44813 .22614 L F
.22203 .22573 m .22298 .22245 L .22496 .22456 L 0 .025 .124 r
F
.22203 .22573 m .22005 .22362 L .22298 .22245 L F
.3022 .22663 m .30327 .22337 L .30517 .22544 L 0 .027 .126 r
F
.3022 .22663 m .3003 .22456 L .30327 .22337 L F
.66213 .22794 m .66377 .22484 L .6653 .22686 L 0 .03 .13 r
F
.66213 .22794 m .6606 .22593 L .66377 .22484 L F
.17802 .22555 m .17888 .2224 L .18091 .22452 L 0 .025 .124 r
F
.17802 .22555 m .17599 .22343 L .17888 .2224 L F
.41068 .22865 m .41192 .22537 L .4137 .22762 L 0 .031 .131 r
F
.41068 .22865 m .40889 .22644 L .41192 .22537 L F
.31005 .22627 m .31111 .22316 L .31301 .22518 L 0 .026 .125 r
F
.31005 .22627 m .30815 .22424 L .31111 .22316 L F
.59457 .2291 m .5961 .22582 L .5977 .22802 L 0 .032 .132 r
F
.59457 .2291 m .59297 .22691 L .5961 .22582 L F
.53486 .22978 m .53629 .22659 L .53796 .22876 L 0 .033 .134 r
F
.53486 .22978 m .5332 .22763 L .53629 .22659 L F
.49085 .22957 m .49221 .22647 L .49392 .22853 L F
.49085 .22957 m .48914 .2275 L .49221 .22647 L F
.22986 .2255 m .2308 .22243 L .23278 .22445 L 0 .025 .124 r
F
.22986 .2255 m .22788 .22347 L .2308 .22243 L F
.38236 .22775 m .38355 .22458 L .38537 .22669 L 0 .029 .129 r
F
.38236 .22775 m .38054 .22563 L .38355 .22458 L F
.26602 .22624 m .26701 .22319 L .26896 .22519 L 0 .027 .126 r
F
.26602 .22624 m .26407 .22424 L .26701 .22319 L F
.34619 .22714 m .34732 .22405 L .34918 .22611 L 0 .028 .128 r
F
.34619 .22714 m .34433 .22509 L .34732 .22405 L F
.73756 .22677 m .73932 .22353 L .74077 .2257 L 0 .028 .127 r
F
.73756 .22677 m .7361 .22462 L .73932 .22353 L F
.66999 .22787 m .67163 .22446 L .67316 .22663 L 0 .029 .129 r
F
.66999 .22787 m .66846 .22568 L .67163 .22446 L F
.78943 .22657 m .79128 .22346 L .79267 .2255 L 0 .027 .127 r
F
.78943 .22657 m .78803 .22452 L .79128 .22346 L F
.31787 .22617 m .31895 .22311 L .32084 .22513 L 0 .027 .126 r
F
.31787 .22617 m .31598 .22415 L .31895 .22311 L F
.52418 .57111 m .5256 .56847 L .52727 .57019 L .979 .091 0 r
F
.52418 .57111 m .5225 .56939 L .5256 .56847 L F
.18582 .22554 m .1867 .2223 L .18873 .22437 L 0 .025 .124 r
F
.18582 .22554 m .1838 .22348 L .1867 .2223 L F
.27385 .226 m .27487 .22283 L .27681 .22483 L 0 .026 .125 r
F
.27385 .226 m .27191 .22401 L .27487 .22283 L F
.50655 .22908 m .50794 .22577 L .50963 .22779 L 0 .032 .133 r
F
.50655 .22908 m .50485 .22706 L .50794 .22577 L F
.4987 .22953 m .50007 .22632 L .50177 .22834 L 0 .033 .134 r
F
.4987 .22953 m .49699 .22749 L .50007 .22632 L F
.23768 .2254 m .23863 .22228 L .24061 .22427 L 0 .025 .124 r
F
.23768 .2254 m .2357 .22339 L .23863 .22228 L F
.67785 .22757 m .67951 .22436 L .68103 .22651 L 0 .029 .129 r
F
.67785 .22757 m .67633 .2254 L .67951 .22436 L F
.19366 .2252 m .19455 .22205 L .19657 .22407 L 0 .025 .124 r
F
.19366 .2252 m .19164 .22319 L .19455 .22205 L F
.79729 .2263 m .79914 .22305 L .80053 .22506 L 0 .027 .126 r
F
.79729 .2263 m .7959 .22428 L .79914 .22305 L F
.60243 .22913 m .60397 .22577 L .60557 .22797 L 0 .032 .133 r
F
.60243 .22913 m .60083 .22693 L .60397 .22577 L F
.5144 .22873 m .5158 .22521 L .51748 .22745 L 0 .031 .132 r
F
.5144 .22873 m .51271 .2265 L .5158 .22521 L F
.45468 .22941 m .45598 .22619 L .45773 .22839 L 0 .033 .134 r
F
.45468 .22941 m .45293 .2272 L .45598 .22619 L F
.80515 .22593 m .80703 .22284 L .8084 .22483 L 0 .026 .126 r
F
.80515 .22593 m .80377 .22392 L .80703 .22284 L F
.41851 .22876 m .41977 .2253 L .42154 .22755 L 0 .031 .132 r
F
.41851 .22876 m .41673 .2265 L .41977 .2253 L F
.39019 .2277 m .39139 .22453 L .39321 .2266 L 0 .03 .13 r
F
.39019 .2277 m .38838 .22561 L .39139 .22453 L F
.61029 .2288 m .61183 .22537 L .61342 .22752 L 0 .032 .132 r
F
.61029 .2288 m .6087 .22667 L .61183 .22537 L F
.74543 .22662 m .7472 .22335 L .74864 .22545 L 0 .028 .127 r
F
.74543 .22662 m .74398 .22453 L .7472 .22335 L F
.28169 .22577 m .28271 .2226 L .28464 .22469 L 0 .026 .125 r
F
.28169 .22577 m .27976 .2237 L .28271 .2226 L F
.54271 .22992 m .54416 .22646 L .54581 .22866 L 0 .034 .135 r
F
.54271 .22992 m .54106 .22772 L .54416 .22646 L F
.35402 .22711 m .35517 .22384 L .35702 .22589 L 0 .029 .128 r
F
.35402 .22711 m .35217 .22505 L .35517 .22384 L F
.61814 .22843 m .6197 .22507 L .62128 .22723 L 0 .031 .131 r
F
.61814 .22843 m .61656 .22629 L .6197 .22507 L F
.55057 .22954 m .55202 .22618 L .55367 .2283 L 0 .033 .134 r
F
.55057 .22954 m .54892 .22741 L .55202 .22618 L F
.55842 .22911 m .55989 .22587 L .56153 .22786 L 0 .033 .133 r
F
.55842 .22911 m .55678 .22708 L .55989 .22587 L F
.24551 .22521 m .24648 .22204 L .24844 .2241 L 0 .025 .124 r
F
.24551 .22521 m .24355 .22314 L .24648 .22204 L F
.20149 .22499 m .20238 .22186 L .2044 .22391 L 0 .025 .123 r
F
.20149 .22499 m .19948 .22296 L .20238 .22186 L F
.75329 .22631 m .75508 .22319 L .75651 .2252 L 0 .027 .127 r
F
.75329 .22631 m .75186 .22432 L .75508 .22319 L F
.52225 .22851 m .52366 .22519 L .52534 .22747 L 0 .031 .132 r
F
.52225 .22851 m .52057 .22624 L .52366 .22519 L F
.56627 .22874 m .56775 .22563 L .56938 .22764 L 0 .032 .133 r
F
.56627 .22874 m .56464 .22674 L .56775 .22563 L F
.5225 .56939 m .52392 .55824 L .5256 .56847 L .963 .155 0 r
F
.42635 .22858 m .42762 .22514 L .42939 .22737 L 0 .031 .132 r
F
.42635 .22858 m .42458 .22634 L .42762 .22514 L F
.36186 .22686 m .36303 .22346 L .36487 .22565 L 0 .028 .128 r
F
.36186 .22686 m .36002 .22467 L .36303 .22346 L F
.626 .22817 m .62757 .22492 L .62915 .22707 L 0 .031 .131 r
F
.626 .22817 m .62442 .22603 L .62757 .22492 L F
.32569 .22624 m .32679 .22298 L .32867 .22515 L 0 .027 .126 r
F
.32569 .22624 m .32382 .22405 L .32679 .22298 L F
.39803 .22756 m .39925 .22432 L .40105 .22644 L 0 .03 .13 r
F
.39803 .22756 m .39623 .22546 L .39925 .22432 L F
.68573 .22757 m .6874 .22429 L .6889 .22641 L F
.68573 .22757 m .68421 .22544 L .6874 .22429 L F
.76116 .22609 m .76296 .22297 L .76439 .225 L 0 .027 .127 r
F
.76116 .22609 m .75974 .22408 L .76296 .22297 L F
.46252 .22939 m .46384 .22587 L .46558 .22812 L 0 .033 .134 r
F
.46252 .22939 m .46078 .22713 L .46384 .22587 L F
.4342 .2283 m .43548 .22498 L .43724 .22713 L 0 .031 .132 r
F
.4342 .2283 m .43243 .22615 L .43548 .22498 L F
.69359 .22729 m .69526 .22387 L .69676 .22601 L 0 .029 .129 r
F
.69359 .22729 m .69208 .22514 L .69526 .22387 L F
.47822 .22861 m .47957 .22544 L .48129 .22752 L 0 .032 .133 r
F
.47822 .22861 m .4765 .22653 L .47957 .22544 L F
.70929 .22644 m .711 .22319 L .71248 .22526 L 0 .028 .127 r
F
.70929 .22644 m .70781 .22438 L .711 .22319 L F
.70144 .22688 m .70313 .22354 L .70462 .22563 L 0 .028 .128 r
F
.70144 .22688 m .69995 .22477 L .70313 .22354 L F
.63386 .22798 m .63545 .2248 L .63701 .2268 L 0 .031 .131 r
F
.63386 .22798 m .6323 .22598 L .63545 .2248 L F
.2093 .22493 m .21022 .22167 L .21222 .2238 L 0 .025 .124 r
F
.2093 .22493 m .20731 .22279 L .21022 .22167 L F
.3697 .22668 m .37088 .22323 L .37271 .22548 L 0 .028 .128 r
F
.3697 .22668 m .36787 .22444 L .37088 .22323 L F
.64171 .22755 m .64331 .2243 L .64486 .22631 L 0 .03 .13 r
F
.64171 .22755 m .64016 .22555 L .64331 .2243 L F
.47037 .22909 m .47171 .22559 L .47343 .22781 L 0 .033 .133 r
F
.47037 .22909 m .46864 .22686 L .47171 .22559 L F
.2895 .22583 m .29055 .22248 L .29246 .22469 L 0 .027 .126 r
F
.2895 .22583 m .28759 .2236 L .29055 .22248 L F
.25333 .22519 m .25431 .222 L .25626 .22414 L 0 .026 .124 r
F
.25333 .22519 m .25138 .22305 L .25431 .222 L F
.57413 .22869 m .57562 .22529 L .57724 .22746 L 0 .032 .133 r
F
.57413 .22869 m .5725 .22651 L .57562 .22529 L F
.76903 .22591 m .77085 .22276 L .77226 .22479 L 0 .027 .126 r
F
.76903 .22591 m .76762 .2239 L .77085 .22276 L F
.64957 .22723 m .65119 .22411 L .65273 .22612 L 0 .03 .13 r
F
.64957 .22723 m .64802 .2252 L .65119 .22411 L F
.71716 .22619 m .71887 .22284 L .72035 .22498 L 0 .027 .127 r
F
.71716 .22619 m .71568 .22408 L .71887 .22284 L F
.40587 .22751 m .4071 .22423 L .40889 .22644 L 0 .03 .13 r
F
.40587 .22751 m .40407 .22533 L .4071 .22423 L F
.44204 .22817 m .44333 .2251 L .44509 .22716 L 0 .032 .132 r
F
.44204 .22817 m .44028 .22612 L .44333 .2251 L F
.33352 .22621 m .33463 .22292 L .3365 .22511 L 0 .028 .127 r
F
.33352 .22621 m .33165 .22405 L .33463 .22292 L F
.17311 .22447 m .17396 .2213 L .17599 .22343 L 0 .025 .123 r
F
.17311 .22447 m .17107 .22235 L .17396 .2213 L F
.58198 .2284 m .58349 .22505 L .5851 .22719 L 0 .032 .132 r
F
.58198 .2284 m .58036 .22623 L .58349 .22505 L F
.5301 .22867 m .53153 .22537 L .5332 .22763 L 0 .032 .133 r
F
.5301 .22867 m .52843 .22642 L .53153 .22537 L F
.72502 .22585 m .72674 .22245 L .72821 .2246 L 0 .027 .126 r
F
.72502 .22585 m .72354 .22371 L .72674 .22245 L F
.7769 .22565 m .77872 .22244 L .78013 .2245 L F
.7769 .22565 m .77549 .22361 L .77872 .22244 L F
.21713 .22479 m .21806 .22149 L .22005 .22362 L 0 .025 .124 r
F
.21713 .22479 m .21514 .22266 L .21806 .22149 L F
.65743 .22702 m .65906 .22392 L .6606 .22593 L 0 .03 .13 r
F
.65743 .22702 m .6559 .22502 L .65906 .22392 L F
.48607 .22855 m .48743 .22544 L .48914 .2275 L 0 .033 .133 r
F
.48607 .22855 m .48435 .22648 L .48743 .22544 L F
.58984 .22813 m .59136 .2248 L .59297 .22691 L 0 .031 .132 r
F
.58984 .22813 m .58823 .226 L .59136 .2248 L F
.29733 .22574 m .29839 .22239 L .3003 .22456 L 0 .027 .126 r
F
.29733 .22574 m .29543 .22355 L .29839 .22239 L F
.37753 .22667 m .37872 .22341 L .38054 .22563 L 0 .029 .129 r
F
.37753 .22667 m .37571 .22445 L .37872 .22341 L F
.22496 .22456 m .2259 .22136 L .22788 .22347 L 0 .025 .124 r
F
.22496 .22456 m .22298 .22245 L .2259 .22136 L F
.30517 .22544 m .30624 .22217 L .30815 .22424 L 0 .027 .126 r
F
.30517 .22544 m .30327 .22337 L .30624 .22217 L F
.73289 .22567 m .73464 .22247 L .7361 .22462 L F
.73289 .22567 m .73142 .22353 L .73464 .22247 L F
.26113 .22526 m .26213 .2221 L .26407 .22424 L 0 .026 .125 r
F
.26113 .22526 m .25919 .22312 L .26213 .2221 L F
.34135 .22614 m .34247 .22294 L .34433 .22509 L 0 .028 .128 r
F
.34135 .22614 m .33949 .22401 L .34247 .22294 L F
.78478 .22553 m .78662 .22243 L .78803 .22452 L 0 .027 .126 r
F
.78478 .22553 m .78337 .22346 L .78662 .22243 L F
.6653 .22686 m .66694 .22366 L .66846 .22568 L 0 .029 .129 r
F
.6653 .22686 m .66377 .22484 L .66694 .22366 L F
.44989 .2282 m .45118 .22513 L .45293 .2272 L 0 .032 .133 r
F
.44989 .2282 m .44813 .22614 L .45118 .22513 L F
.18091 .22452 m .18177 .22136 L .1838 .22348 L 0 .025 .124 r
F
.18091 .22452 m .17888 .2224 L .18177 .22136 L F
.5977 .22802 m .59923 .22473 L .60083 .22693 L 0 .032 .132 r
F
.5977 .22802 m .5961 .22582 L .59923 .22473 L F
.31301 .22518 m .31408 .22214 L .31598 .22415 L 0 .027 .126 r
F
.31301 .22518 m .31111 .22316 L .31408 .22214 L F
.4137 .22762 m .41495 .22425 L .41673 .2265 L 0 .031 .131 r
F
.4137 .22762 m .41192 .22537 L .41495 .22425 L F
.49392 .22853 m .49529 .22544 L .49699 .22749 L 0 .033 .134 r
F
.49392 .22853 m .49221 .22647 L .49529 .22544 L F
.53796 .22876 m .5394 .22553 L .54106 .22772 L F
.53796 .22876 m .53629 .22659 L .5394 .22553 L F
.23278 .22445 m .23372 .22138 L .2357 .22339 L 0 .025 .124 r
F
.23278 .22445 m .2308 .22243 L .23372 .22138 L F
.67316 .22663 m .67481 .22324 L .67633 .2254 L 0 .029 .129 r
F
.67316 .22663 m .67163 .22446 L .67481 .22324 L F
.38537 .22669 m .38656 .22352 L .38838 .22561 L 0 .03 .13 r
F
.38537 .22669 m .38355 .22458 L .38656 .22352 L F
.50963 .22779 m .51102 .22449 L .51271 .2265 L 0 .032 .132 r
F
.50963 .22779 m .50794 .22577 L .51102 .22449 L F
.26896 .22519 m .26997 .222 L .27191 .22401 L 0 .027 .126 r
F
.26896 .22519 m .26701 .22319 L .26997 .222 L F
.34918 .22611 m .35031 .22298 L .35217 .22505 L 0 .029 .128 r
F
.34918 .22611 m .34732 .22405 L .35031 .22298 L F
.18873 .22437 m .18961 .22113 L .19164 .22319 L 0 .025 .124 r
F
.18873 .22437 m .1867 .2223 L .18961 .22113 L F
.74077 .2257 m .74253 .22235 L .74398 .22453 L 0 .027 .127 r
F
.74077 .2257 m .73932 .22353 L .74253 .22235 L F
.27681 .22483 m .27782 .22168 L .27976 .2237 L 0 .026 .125 r
F
.27681 .22483 m .27487 .22283 L .27782 .22168 L F
.51748 .22745 m .51889 .224 L .52057 .22624 L 0 .031 .131 r
F
.51748 .22745 m .5158 .22521 L .51889 .224 L F
.80053 .22506 m .80239 .22192 L .80377 .22392 L 0 .027 .126 r
F
.80053 .22506 m .79914 .22305 L .80239 .22192 L F
.79267 .2255 m .79451 .22225 L .7959 .22428 L 0 .027 .127 r
F
.79267 .2255 m .79128 .22346 L .79451 .22225 L F
.50177 .22834 m .50315 .22503 L .50485 .22706 L 0 .033 .134 r
F
.50177 .22834 m .50007 .22632 L .50315 .22503 L F
.61342 .22752 m .61497 .22413 L .61656 .22629 L 0 .031 .131 r
F
.61342 .22752 m .61183 .22537 L .61497 .22413 L F
.32084 .22513 m .32193 .22206 L .32382 .22405 L 0 .027 .126 r
F
.32084 .22513 m .31895 .22311 L .32193 .22206 L F
.60557 .22797 m .6071 .22446 L .6087 .22667 L 0 .032 .132 r
F
.60557 .22797 m .60397 .22577 L .6071 .22446 L F
.24061 .22427 m .24157 .22117 L .24355 .22314 L 0 .025 .124 r
F
.24061 .22427 m .23863 .22228 L .24157 .22117 L F
.19657 .22407 m .19746 .22093 L .19948 .22296 L 0 .025 .123 r
F
.19657 .22407 m .19455 .22205 L .19746 .22093 L F
.42154 .22755 m .42281 .2241 L .42458 .22634 L 0 .031 .131 r
F
.42154 .22755 m .41977 .2253 L .42281 .2241 L F
.54581 .22866 m .54726 .2252 L .54892 .22741 L 0 .033 .134 r
F
.54581 .22866 m .54416 .22646 L .54726 .2252 L F
.68103 .22651 m .6827 .22332 L .68421 .22544 L 0 .029 .129 r
F
.68103 .22651 m .67951 .22436 L .6827 .22332 L F
.74864 .22545 m .75042 .22222 L .75186 .22432 L 0 .027 .127 r
F
.74864 .22545 m .7472 .22335 L .75042 .22222 L F
.35702 .22589 m .35817 .22264 L .36002 .22467 L 0 .028 .128 r
F
.35702 .22589 m .35517 .22384 L .35817 .22264 L F
.55367 .2283 m .55513 .22499 L .55678 .22708 L 0 .033 .134 r
F
.55367 .2283 m .55202 .22618 L .55513 .22499 L F
.56153 .22786 m .563 .22474 L .56464 .22674 L 0 .032 .133 r
F
.56153 .22786 m .55989 .22587 L .563 .22474 L F
.62128 .22723 m .62285 .22386 L .62442 .22603 L 0 .031 .131 r
F
.62128 .22723 m .6197 .22507 L .62285 .22386 L F
.8084 .22483 m .81028 .22175 L .81165 .22374 L 0 .027 .126 r
F
.8084 .22483 m .80703 .22284 L .81028 .22175 L F
.39321 .2266 m .39442 .22339 L .39623 .22546 L 0 .03 .13 r
F
.39321 .2266 m .39139 .22453 L .39442 .22339 L F
.28464 .22469 m .28567 .2215 L .28759 .2236 L 0 .026 .125 r
F
.28464 .22469 m .28271 .2226 L .28567 .2215 L F
.45773 .22839 m .45904 .22493 L .46078 .22713 L 0 .033 .134 r
F
.45773 .22839 m .45598 .22619 L .45904 .22493 L F
.42939 .22737 m .43066 .22393 L .43243 .22615 L 0 .031 .131 r
F
.42939 .22737 m .42762 .22514 L .43066 .22393 L F
.24844 .2241 m .24941 .22097 L .25138 .22305 L 0 .025 .124 r
F
.24844 .2241 m .24648 .22204 L .24941 .22097 L F
.75651 .2252 m .75831 .22207 L .75974 .22408 L 0 .027 .127 r
F
.75651 .2252 m .75508 .22319 L .75831 .22207 L F
.36487 .22565 m .36604 .22224 L .36787 .22444 L 0 .028 .127 r
F
.36487 .22565 m .36303 .22346 L .36604 .22224 L F
.2044 .22391 m .2053 .22075 L .20731 .22279 L 0 .025 .123 r
F
.2044 .22391 m .20238 .22186 L .2053 .22075 L F
.56938 .22764 m .57087 .2245 L .5725 .22651 L 0 .032 .133 r
F
.56938 .22764 m .56775 .22563 L .57087 .2245 L F
.52534 .22747 m .52676 .22414 L .52843 .22642 L 0 .032 .132 r
F
.52534 .22747 m .52366 .22519 L .52676 .22414 L F
.46558 .22812 m .46691 .2246 L .46864 .22686 L 0 .033 .133 r
F
.46558 .22812 m .46384 .22587 L .46691 .2246 L F
.6889 .22641 m .69058 .22303 L .69208 .22514 L 0 .029 .129 r
F
.6889 .22641 m .6874 .22429 L .69058 .22303 L F
.62915 .22707 m .63073 .2238 L .6323 .22598 L 0 .031 .131 r
F
.62915 .22707 m .62757 .22492 L .63073 .2238 L F
.69676 .22601 m .69845 .22265 L .69995 .22477 L 0 .029 .128 r
F
.69676 .22601 m .69526 .22387 L .69845 .22265 L F
.40105 .22644 m .40227 .22317 L .40407 .22533 L 0 .03 .13 r
F
.40105 .22644 m .39925 .22432 L .40227 .22317 L F
.32867 .22515 m .32978 .22188 L .33165 .22405 L 0 .027 .127 r
F
.32867 .22515 m .32679 .22298 L .32978 .22188 L F
.43724 .22713 m .43852 .22394 L .44028 .22612 L 0 .031 .132 r
F
.43724 .22713 m .43548 .22498 L .43852 .22394 L F
.47343 .22781 m .47477 .22431 L .4765 .22653 L 0 .032 .133 r
F
.47343 .22781 m .47171 .22559 L .47477 .22431 L F
.70462 .22563 m .70632 .22232 L .70781 .22438 L 0 .028 .128 r
F
.70462 .22563 m .70313 .22354 L .70632 .22232 L F
.76439 .225 m .76619 .22186 L .76762 .2239 L 0 .027 .127 r
F
.76439 .225 m .76296 .22297 L .76619 .22186 L F
.64486 .22631 m .64648 .22319 L .64802 .2252 L 0 .03 .13 r
F
.64486 .22631 m .64331 .2243 L .64648 .22319 L F
.71248 .22526 m .7142 .22199 L .71568 .22408 L 0 .028 .127 r
F
.71248 .22526 m .711 .22319 L .7142 .22199 L F
.37271 .22548 m .37389 .2222 L .37571 .22445 L 0 .028 .128 r
F
.37271 .22548 m .37088 .22323 L .37389 .2222 L F
.63701 .2268 m .6386 .22355 L .64016 .22555 L 0 .031 .131 r
F
.63701 .2268 m .63545 .2248 L .6386 .22355 L F
.57724 .22746 m .57874 .22406 L .58036 .22623 L 0 .032 .132 r
F
.57724 .22746 m .57562 .22529 L .57874 .22406 L F
.21222 .2238 m .21314 .22054 L .21514 .22266 L 0 .025 .124 r
F
.21222 .2238 m .21022 .22167 L .21314 .22054 L F
.48129 .22752 m .48264 .22441 L .48435 .22648 L 0 .032 .133 r
F
.48129 .22752 m .47957 .22544 L .48264 .22441 L F
.29246 .22469 m .29352 .22135 L .29543 .22355 L 0 .026 .126 r
F
.29246 .22469 m .29055 .22248 L .29352 .22135 L F
.72035 .22498 m .72207 .22157 L .72354 .22371 L 0 .027 .126 r
F
.72035 .22498 m .71887 .22284 L .72207 .22157 L F
.77226 .22479 m .77407 .22156 L .77549 .22361 L F
.77226 .22479 m .77085 .22276 L .77407 .22156 L F
.5851 .22719 m .58662 .2239 L .58823 .226 L 0 .031 .132 r
F
.5851 .22719 m .58349 .22505 L .58662 .2239 L F
.25626 .22414 m .25724 .22097 L .25919 .22312 L 0 .026 .125 r
F
.25626 .22414 m .25431 .222 L .25724 .22097 L F
.72821 .2246 m .72995 .22137 L .73142 .22353 L 0 .027 .126 r
F
.72821 .2246 m .72674 .22245 L .72995 .22137 L F
.65273 .22612 m .65436 .22301 L .6559 .22502 L 0 .03 .13 r
F
.65273 .22612 m .65119 .22411 L .65436 .22301 L F
.3365 .22511 m .33762 .2218 L .33949 .22401 L 0 .028 .127 r
F
.3365 .22511 m .33463 .22292 L .33762 .2218 L F
.40889 .22644 m .41013 .22313 L .41192 .22537 L 0 .03 .13 r
F
.40889 .22644 m .4071 .22423 L .41013 .22313 L F
.22005 .22362 m .22099 .22033 L .22298 .22245 L 0 .025 .123 r
F
.22005 .22362 m .21806 .22149 L .22099 .22033 L F
.78013 .2245 m .78197 .22137 L .78337 .22346 L 0 .027 .126 r
F
.78013 .2245 m .77872 .22244 L .78197 .22137 L F
.59297 .22691 m .59449 .22372 L .5961 .22582 L 0 .031 .132 r
F
.59297 .22691 m .59136 .2248 L .59449 .22372 L F
.17599 .22343 m .17685 .22028 L .17888 .2224 L 0 .025 .123 r
F
.17599 .22343 m .17396 .2213 L .17685 .22028 L F
.44509 .22716 m .44637 .22407 L .44813 .22614 L 0 .032 .133 r
F
.44509 .22716 m .44333 .2251 L .44637 .22407 L F
.3003 .22456 m .30137 .2212 L .30327 .22337 L 0 .027 .126 r
F
.3003 .22456 m .29839 .22239 L .30137 .2212 L F
.5332 .22763 m .53463 .2243 L .53629 .22659 L 0 .033 .133 r
F
.5332 .22763 m .53153 .22537 L .53463 .2243 L F
.6606 .22593 m .66224 .22282 L .66377 .22484 L 0 .03 .13 r
F
.6606 .22593 m .65906 .22392 L .66224 .22282 L F
.48914 .2275 m .4905 .2244 L .49221 .22647 L 0 .033 .134 r
F
.48914 .2275 m .48743 .22544 L .4905 .2244 L F
.30815 .22424 m .30921 .2211 L .31111 .22316 L 0 .026 .126 r
F
.30815 .22424 m .30624 .22217 L .30921 .2211 L F
.38054 .22563 m .38173 .22237 L .38355 .22458 L 0 .029 .129 r
F
.38054 .22563 m .37872 .22341 L .38173 .22237 L F
.22788 .22347 m .22882 .22033 L .2308 .22243 L 0 .025 .124 r
F
.22788 .22347 m .2259 .22136 L .22882 .22033 L F
.66846 .22568 m .67011 .22244 L .67163 .22446 L 0 .029 .129 r
F
.66846 .22568 m .66694 .22366 L .67011 .22244 L F
.7361 .22462 m .73785 .22136 L .73932 .22353 L 0 .027 .127 r
F
.7361 .22462 m .73464 .22247 L .73785 .22136 L F
.34433 .22509 m .34546 .22188 L .34732 .22405 L 0 .028 .128 r
F
.34433 .22509 m .34247 .22294 L .34546 .22188 L F
.26407 .22424 m .26507 .22105 L .26701 .22319 L 0 .027 .126 r
F
.26407 .22424 m .26213 .2221 L .26507 .22105 L F
.78803 .22452 m .78987 .22136 L .79128 .22346 L 0 .027 .127 r
F
.78803 .22452 m .78662 .22243 L .78987 .22136 L F
.67633 .2254 m .67799 .22222 L .67951 .22436 L 0 .029 .129 r
F
.67633 .2254 m .67481 .22324 L .67799 .22222 L F
.60083 .22693 m .60237 .22356 L .60397 .22577 L 0 .032 .132 r
F
.60083 .22693 m .59923 .22473 L .60237 .22356 L F
.41673 .2265 m .41798 .22309 L .41977 .2253 L 0 .031 .131 r
F
.41673 .2265 m .41495 .22425 L .41798 .22309 L F
.51271 .2265 m .51411 .22321 L .5158 .22521 L F
.51271 .2265 m .51102 .22449 L .51411 .22321 L F
.1838 .22348 m .18468 .22019 L .1867 .2223 L 0 .025 .124 r
F
.1838 .22348 m .18177 .22136 L .18468 .22019 L F
.45293 .2272 m .45423 .2241 L .45598 .22619 L 0 .033 .134 r
F
.45293 .2272 m .45118 .22513 L .45423 .2241 L F
.31598 .22415 m .31705 .22111 L .31895 .22311 L 0 .027 .126 r
F
.31598 .22415 m .31408 .22214 L .31705 .22111 L F
.50485 .22706 m .50624 .22374 L .50794 .22577 L 0 .032 .133 r
F
.50485 .22706 m .50315 .22503 L .50624 .22374 L F
.49699 .22749 m .49837 .22426 L .50007 .22632 L 0 .033 .134 r
F
.49699 .22749 m .49529 .22544 L .49837 .22426 L F
.27191 .22401 m .27293 .22082 L .27487 .22283 L 0 .026 .126 r
F
.27191 .22401 m .26997 .222 L .27293 .22082 L F
.54106 .22772 m .5425 .22425 L .54416 .22646 L 0 .033 .134 r
F
.54106 .22772 m .5394 .22553 L .5425 .22425 L F
.2357 .22339 m .23665 .22029 L .23863 .22228 L 0 .026 .124 r
F
.2357 .22339 m .23372 .22138 L .23665 .22029 L F
.6087 .22667 m .61024 .22314 L .61183 .22537 L 0 .031 .132 r
F
.6087 .22667 m .6071 .22446 L .61024 .22314 L F
.52057 .22624 m .52198 .22294 L .52366 .22519 L 0 .031 .131 r
F
.52057 .22624 m .51889 .224 L .52198 .22294 L F
.7959 .22428 m .79775 .22104 L .79914 .22305 L 0 .027 .126 r
F
.7959 .22428 m .79451 .22225 L .79775 .22104 L F
.19164 .22319 m .19253 .21997 L .19455 .22205 L 0 .025 .124 r
F
.19164 .22319 m .18961 .22113 L .19253 .21997 L F
.38838 .22561 m .38958 .22246 L .39139 .22453 L 0 .03 .13 r
F
.38838 .22561 m .38656 .22352 L .38958 .22246 L F
.74398 .22453 m .74574 .22116 L .7472 .22335 L 0 .027 .127 r
F
.74398 .22453 m .74253 .22235 L .74574 .22116 L F
.61656 .22629 m .61812 .2229 L .6197 .22507 L 0 .031 .131 r
F
.61656 .22629 m .61497 .22413 L .61812 .2229 L F
.54892 .22741 m .55037 .22397 L .55202 .22618 L 0 .033 .134 r
F
.54892 .22741 m .54726 .2252 L .55037 .22397 L F
.27976 .2237 m .28078 .22056 L .28271 .2226 L 0 .026 .125 r
F
.27976 .2237 m .27782 .22168 L .28078 .22056 L F
.80377 .22392 m .80565 .22085 L .80703 .22284 L 0 .027 .126 r
F
.80377 .22392 m .80239 .22192 L .80565 .22085 L F
.42458 .22634 m .42585 .22291 L .42762 .22514 L 0 .031 .131 r
F
.42458 .22634 m .42281 .2241 L .42585 .22291 L F
.35217 .22505 m .35331 .22179 L .35517 .22384 L 0 .029 .128 r
F
.35217 .22505 m .35031 .22298 L .35331 .22179 L F
.24355 .22314 m .2445 .22007 L .24648 .22204 L 0 .025 .124 r
F
.24355 .22314 m .24157 .22117 L .2445 .22007 L F
.36002 .22467 m .36118 .22143 L .36303 .22346 L 0 .028 .127 r
F
.36002 .22467 m .35817 .22264 L .36118 .22143 L F
.55678 .22708 m .55825 .2238 L .55989 .22587 L 0 .033 .133 r
F
.55678 .22708 m .55513 .22499 L .55825 .2238 L F
.32382 .22405 m .3249 .221 L .32679 .22298 L 0 .027 .126 r
F
.32382 .22405 m .32193 .22206 L .3249 .221 L F
.19948 .22296 m .20037 .21981 L .20238 .22186 L 0 .025 .124 r
F
.19948 .22296 m .19746 .22093 L .20037 .21981 L F
.62442 .22603 m .626 .22273 L .62757 .22492 L 0 .031 .131 r
F
.62442 .22603 m .62285 .22386 L .626 .22273 L F
.46078 .22713 m .46211 .22367 L .46384 .22587 L 0 .032 .133 r
F
.46078 .22713 m .45904 .22493 L .46211 .22367 L F
.75186 .22432 m .75364 .2211 L .75508 .22319 L 0 .027 .127 r
F
.75186 .22432 m .75042 .22222 L .75364 .2211 L F
.56464 .22674 m .56612 .22362 L .56775 .22563 L 0 .032 .133 r
F
.56464 .22674 m .563 .22474 L .56612 .22362 L F
.68421 .22544 m .68589 .22219 L .6874 .22429 L 0 .03 .13 r
F
.68421 .22544 m .6827 .22332 L .68589 .22219 L F
.39623 .22546 m .39744 .22222 L .39925 .22432 L F
.39623 .22546 m .39442 .22339 L .39744 .22222 L F
.43243 .22615 m .43371 .22276 L .43548 .22498 L 0 .031 .131 r
F
.43243 .22615 m .43066 .22393 L .43371 .22276 L F
.36787 .22444 m .36905 .22103 L .37088 .22323 L 0 .027 .127 r
F
.36787 .22444 m .36604 .22224 L .36905 .22103 L F
.46864 .22686 m .46998 .22334 L .47171 .22559 L 0 .032 .133 r
F
.46864 .22686 m .46691 .2246 L .46998 .22334 L F
.28759 .2236 m .28863 .22039 L .29055 .22248 L 0 .026 .125 r
F
.28759 .2236 m .28567 .2215 L .28863 .22039 L F
.69208 .22514 m .69376 .22178 L .69526 .22387 L 0 .029 .129 r
F
.69208 .22514 m .69058 .22303 L .69376 .22178 L F
.75974 .22408 m .76154 .22095 L .76296 .22297 L 0 .027 .127 r
F
.75974 .22408 m .75831 .22207 L .76154 .22095 L F
.20731 .22279 m .20821 .21964 L .21022 .22167 L 0 .025 .124 r
F
.20731 .22279 m .2053 .22075 L .20821 .21964 L F
.69995 .22477 m .70164 .22145 L .70313 .22354 L 0 .028 .128 r
F
.69995 .22477 m .69845 .22265 L .70164 .22145 L F
.5725 .22651 m .574 .22326 L .57562 .22529 L 0 .032 .133 r
F
.5725 .22651 m .57087 .2245 L .574 .22326 L F
.4765 .22653 m .47784 .22323 L .47957 .22544 L 0 .032 .132 r
F
.4765 .22653 m .47477 .22431 L .47784 .22323 L F
.25138 .22305 m .25235 .21991 L .25431 .222 L 0 .025 .124 r
F
.25138 .22305 m .24941 .22097 L .25235 .21991 L F
.70781 .22438 m .70952 .22113 L .711 .22319 L 0 .028 .127 r
F
.70781 .22438 m .70632 .22232 L .70952 .22113 L F
.40407 .22533 m .4053 .22204 L .4071 .22423 L 0 .03 .13 r
F
.40407 .22533 m .40227 .22317 L .4053 .22204 L F
.6323 .22598 m .63388 .22261 L .63545 .2248 L 0 .031 .131 r
F
.6323 .22598 m .63073 .2238 L .63388 .22261 L F
.52843 .22642 m .52986 .22307 L .53153 .22537 L 0 .032 .132 r
F
.52843 .22642 m .52676 .22414 L .52986 .22307 L F
.64016 .22555 m .64176 .22229 L .64331 .2243 L 0 .03 .13 r
F
.64016 .22555 m .6386 .22355 L .64176 .22229 L F
.33165 .22405 m .33277 .22073 L .33463 .22292 L 0 .027 .127 r
F
.33165 .22405 m .32978 .22188 L .33277 .22073 L F
.58036 .22623 m .58187 .2229 L .58349 .22505 L 0 .031 .132 r
F
.58036 .22623 m .57874 .22406 L .58187 .2229 L F
.71568 .22408 m .7174 .22074 L .71887 .22284 L 0 .027 .127 r
F
.71568 .22408 m .7142 .22199 L .7174 .22074 L F
.64802 .2252 m .64964 .22209 L .65119 .22411 L 0 .03 .13 r
F
.64802 .2252 m .64648 .22319 L .64964 .22209 L F
.76762 .2239 m .76942 .2207 L .77085 .22276 L 0 .027 .127 r
F
.76762 .2239 m .76619 .22186 L .76942 .2207 L F
.72354 .22371 m .72527 .22029 L .72674 .22245 L 0 .027 .126 r
F
.72354 .22371 m .72207 .22157 L .72527 .22029 L F
.44028 .22612 m .44157 .22291 L .44333 .2251 L 0 .032 .132 r
F
.44028 .22612 m .43852 .22394 L .44157 .22291 L F
.21514 .22266 m .21607 .21938 L .21806 .22149 L 0 .025 .123 r
F
.21514 .22266 m .21314 .22054 L .21607 .21938 L F
.29543 .22355 m .29649 .22021 L .29839 .22239 L 0 .026 .126 r
F
.29543 .22355 m .29352 .22135 L .29649 .22021 L F
.37571 .22445 m .3769 .22117 L .37872 .22341 L 0 .028 .128 r
F
.37571 .22445 m .37389 .2222 L .3769 .22117 L F
.58823 .226 m .58975 .22274 L .59136 .2248 L 0 .031 .132 r
F
.58823 .226 m .58662 .2239 L .58975 .22274 L F
.77549 .22361 m .77731 .22037 L .77872 .22244 L 0 .027 .126 r
F
.77549 .22361 m .77407 .22156 L .77731 .22037 L F
.48435 .22648 m .48571 .22337 L .48743 .22544 L 0 .033 .133 r
F
.48435 .22648 m .48264 .22441 L .48571 .22337 L F
.6559 .22502 m .65753 .22189 L .65906 .22392 L 0 .03 .13 r
F
.6559 .22502 m .65436 .22301 L .65753 .22189 L F
.73142 .22353 m .73317 .2203 L .73464 .22247 L 0 .027 .126 r
F
.73142 .22353 m .72995 .22137 L .73317 .2203 L F
.22298 .22245 m .22391 .21924 L .2259 .22136 L 0 .025 .123 r
F
.22298 .22245 m .22099 .22033 L .22391 .21924 L F
.25919 .22312 m .26018 .21995 L .26213 .2221 L 0 .026 .125 r
F
.25919 .22312 m .25724 .22097 L .26018 .21995 L F
.33949 .22401 m .34061 .22071 L .34247 .22294 L 0 .028 .127 r
F
.33949 .22401 m .33762 .2218 L .34061 .22071 L F
.30327 .22337 m .30434 .22001 L .30624 .22217 L 0 .026 .125 r
F
.30327 .22337 m .30137 .2212 L .30434 .22001 L F
.41192 .22537 m .41316 .22201 L .41495 .22425 L 0 .03 .13 r
F
.41192 .22537 m .41013 .22313 L .41316 .22201 L F
.5961 .22582 m .59763 .22263 L .59923 .22473 L 0 .031 .132 r
F
.5961 .22582 m .59449 .22372 L .59763 .22263 L F
.78337 .22346 m .78522 .22033 L .78662 .22243 L 0 .027 .126 r
F
.78337 .22346 m .78197 .22137 L .78522 .22033 L F
.17888 .2224 m .17974 .21924 L .18177 .22136 L 0 .025 .124 r
F
.17888 .2224 m .17685 .22028 L .17974 .21924 L F
.44813 .22614 m .44943 .22305 L .45118 .22513 L 0 .032 .133 r
F
.44813 .22614 m .44637 .22407 L .44943 .22305 L F
.66377 .22484 m .66541 .22164 L .66694 .22366 L 0 .03 .13 r
F
.66377 .22484 m .66224 .22282 L .66541 .22164 L F
.53629 .22659 m .53773 .22323 L .5394 .22553 L 0 .033 .134 r
F
.53629 .22659 m .53463 .2243 L .53773 .22323 L F
.67163 .22446 m .67329 .22122 L .67481 .22324 L 0 .029 .129 r
F
.67163 .22446 m .67011 .22244 L .67329 .22122 L F
.31111 .22316 m .31218 .22007 L .31408 .22214 L 0 .027 .126 r
F
.31111 .22316 m .30921 .2211 L .31218 .22007 L F
.49221 .22647 m .49358 .22336 L .49529 .22544 L 0 .033 .134 r
F
.49221 .22647 m .4905 .2244 L .49358 .22336 L F
.5158 .22521 m .51721 .222 L .51889 .224 L 0 .031 .131 r
F
.5158 .22521 m .51411 .22321 L .51721 .222 L F
.38355 .22458 m .38474 .22132 L .38656 .22352 L 0 .029 .129 r
F
.38355 .22458 m .38173 .22237 L .38474 .22132 L F
.2308 .22243 m .23174 .21929 L .23372 .22138 L 0 .025 .124 r
F
.2308 .22243 m .22882 .22033 L .23174 .21929 L F
.73932 .22353 m .74107 .22016 L .74253 .22235 L 0 .027 .126 r
F
.73932 .22353 m .73785 .22136 L .74107 .22016 L F
.41977 .2253 m .42102 .22192 L .42281 .2241 L 0 .031 .131 r
F
.41977 .2253 m .41798 .22309 L .42102 .22192 L F
.60397 .22577 m .60551 .22223 L .6071 .22446 L 0 .031 .132 r
F
.60397 .22577 m .60237 .22356 L .60551 .22223 L F
.50794 .22577 m .50933 .22247 L .51102 .22449 L 0 .032 .132 r
F
.50794 .22577 m .50624 .22374 L .50933 .22247 L F
.1867 .2223 m .18759 .21902 L .18961 .22113 L 0 .025 .124 r
F
.1867 .2223 m .18468 .22019 L .18759 .21902 L F
.34732 .22405 m .34846 .2208 L .35031 .22298 L 0 .028 .128 r
F
.34732 .22405 m .34546 .22188 L .34846 .2208 L F
.61183 .22537 m .61339 .22191 L .61497 .22413 L 0 .031 .131 r
F
.61183 .22537 m .61024 .22314 L .61339 .22191 L F
.26701 .22319 m .26803 .21987 L .26997 .222 L 0 .027 .126 r
F
.26701 .22319 m .26507 .22105 L .26803 .21987 L F
.54416 .22646 m .54561 .22298 L .54726 .2252 L 0 .033 .134 r
F
.54416 .22646 m .5425 .22425 L .54561 .22298 L F
.79128 .22346 m .79311 .22014 L .79451 .22225 L 0 .027 .127 r
F
.79128 .22346 m .78987 .22136 L .79311 .22014 L F
.50007 .22632 m .50145 .22297 L .50315 .22503 L 0 .033 .134 r
F
.50007 .22632 m .49837 .22426 L .50145 .22297 L F
.27487 .22283 m .27589 .21965 L .27782 .22168 L 0 .026 .125 r
F
.27487 .22283 m .27293 .22082 L .27589 .21965 L F
.67951 .22436 m .68118 .2212 L .6827 .22332 L 0 .029 .129 r
F
.67951 .22436 m .67799 .22222 L .68118 .2212 L F
.79914 .22305 m .80101 .21992 L .80239 .22192 L 0 .027 .126 r
F
.79914 .22305 m .79775 .22104 L .80101 .21992 L F
.6197 .22507 m .62127 .22169 L .62285 .22386 L 0 .03 .131 r
F
.6197 .22507 m .61812 .2229 L .62127 .22169 L F
.31895 .22311 m .32003 .22006 L .32193 .22206 L 0 .027 .126 r
F
.31895 .22311 m .31705 .22111 L .32003 .22006 L F
.55202 .22618 m .55348 .2228 L .55513 .22499 L 0 .033 .133 r
F
.55202 .22618 m .55037 .22397 L .55348 .2228 L F
.7472 .22335 m .74896 .22003 L .75042 .22222 L 0 .027 .127 r
F
.7472 .22335 m .74574 .22116 L .74896 .22003 L F
.45598 .22619 m .4573 .22286 L .45904 .22493 L 0 .033 .133 r
F
.45598 .22619 m .45423 .2241 L .4573 .22286 L F
.19455 .22205 m .19544 .21884 L .19746 .22093 L 0 .025 .124 r
F
.19455 .22205 m .19253 .21997 L .19544 .21884 L F
.23863 .22228 m .23959 .21919 L .24157 .22117 L 0 .026 .124 r
F
.23863 .22228 m .23665 .22029 L .23959 .21919 L F
.42762 .22514 m .42889 .22171 L .43066 .22393 L 0 .031 .131 r
F
.42762 .22514 m .42585 .22291 L .42889 .22171 L F
.35517 .22384 m .35632 .2206 L .35817 .22264 L 0 .028 .128 r
F
.35517 .22384 m .35331 .22179 L .35632 .2206 L F
.39139 .22453 m .3926 .22131 L .39442 .22339 L 0 .03 .13 r
F
.39139 .22453 m .38958 .22246 L .3926 .22131 L F
.52366 .22519 m .52508 .22189 L .52676 .22414 L 0 .031 .131 r
F
.52366 .22519 m .52198 .22294 L .52508 .22189 L F
.36303 .22346 m .36419 .22022 L .36604 .22224 L 0 .028 .127 r
F
.36303 .22346 m .36118 .22143 L .36419 .22022 L F
.46384 .22587 m .46517 .22241 L .46691 .2246 L 0 .032 .133 r
F
.46384 .22587 m .46211 .22367 L .46517 .22241 L F
.55989 .22587 m .56136 .22266 L .563 .22474 L F
.55989 .22587 m .55825 .2238 L .56136 .22266 L F
.28271 .2226 m .28374 .21944 L .28567 .2215 L 0 .026 .125 r
F
.28271 .2226 m .28078 .22056 L .28374 .21944 L F
.80703 .22284 m .80891 .21977 L .81028 .22175 L 0 .027 .126 r
F
.80703 .22284 m .80565 .22085 L .80891 .21977 L F
.24648 .22204 m .24744 .21897 L .24941 .22097 L 0 .025 .124 r
F
.24648 .22204 m .2445 .22007 L .24744 .21897 L F
.20238 .22186 m .20328 .2187 L .2053 .22075 L F
.20238 .22186 m .20037 .21981 L .20328 .2187 L F
.62757 .22492 m .62916 .22159 L .63073 .2238 L 0 .031 .131 r
F
.62757 .22492 m .626 .22273 L .62916 .22159 L F
.47171 .22559 m .47305 .22208 L .47477 .22431 L 0 .032 .132 r
F
.47171 .22559 m .46998 .22334 L .47305 .22208 L F
.75508 .22319 m .75687 .21997 L .75831 .22207 L 0 .027 .127 r
F
.75508 .22319 m .75364 .2211 L .75687 .21997 L F
.6874 .22429 m .68907 .22095 L .69058 .22303 L 0 .029 .129 r
F
.6874 .22429 m .68589 .22219 L .68907 .22095 L F
.32679 .22298 m .32789 .21989 L .32978 .22188 L 0 .027 .127 r
F
.32679 .22298 m .3249 .221 L .32789 .21989 L F
.69526 .22387 m .69695 .22058 L .69845 .22265 L 0 .029 .128 r
F
.69526 .22387 m .69376 .22178 L .69695 .22058 L F
.39925 .22432 m .40047 .22106 L .40227 .22317 L 0 .03 .13 r
F
.39925 .22432 m .39744 .22222 L .40047 .22106 L F
.43548 .22498 m .43676 .22171 L .43852 .22394 L 0 .031 .131 r
F
.43548 .22498 m .43371 .22276 L .43676 .22171 L F
.56775 .22563 m .56924 .22248 L .57087 .2245 L 0 .032 .133 r
F
.56775 .22563 m .56612 .22362 L .56924 .22248 L F
.37088 .22323 m .37206 .22 L .37389 .2222 L 0 .027 .127 r
F
.37088 .22323 m .36905 .22103 L .37206 .22 L F
.70313 .22354 m .70483 .22025 L .70632 .22232 L 0 .028 .128 r
F
.70313 .22354 m .70164 .22145 L .70483 .22025 L F
.57562 .22529 m .57712 .22202 L .57874 .22406 L 0 .032 .132 r
F
.57562 .22529 m .574 .22326 L .57712 .22202 L F
.29055 .22248 m .2916 .21927 L .29352 .22135 L 0 .026 .125 r
F
.29055 .22248 m .28863 .22039 L .2916 .21927 L F
.711 .22319 m .71272 .21995 L .7142 .22199 L 0 .028 .127 r
F
.711 .22319 m .70952 .22113 L .71272 .21995 L F
.76296 .22297 m .76477 .21982 L .76619 .22186 L 0 .027 .127 r
F
.76296 .22297 m .76154 .22095 L .76477 .21982 L F
.21022 .22167 m .21114 .21851 L .21314 .22054 L 0 .025 .124 r
F
.21022 .22167 m .20821 .21964 L .21114 .21851 L F
.64331 .2243 m .64493 .22118 L .64648 .22319 L 0 .03 .13 r
F
.64331 .2243 m .64176 .22229 L .64493 .22118 L F
.47957 .22544 m .48091 .22219 L .48264 .22441 L 0 .032 .133 r
F
.47957 .22544 m .47784 .22323 L .48091 .22219 L F
.63545 .2248 m .63704 .22135 L .6386 .22355 L 0 .031 .131 r
F
.63545 .2248 m .63388 .22261 L .63704 .22135 L F
.71887 .22284 m .72059 .21946 L .72207 .22157 L 0 .027 .126 r
F
.71887 .22284 m .7174 .22074 L .72059 .21946 L F
.58349 .22505 m .585 .22179 L .58662 .2239 L 0 .031 .132 r
F
.58349 .22505 m .58187 .2229 L .585 .22179 L F
.25431 .222 m .25529 .21887 L .25724 .22097 L 0 .026 .125 r
F
.25431 .222 m .25235 .21991 L .25529 .21887 L F
.72674 .22245 m .72848 .2192 L .72995 .22137 L F
.72674 .22245 m .72527 .22029 L .72848 .2192 L F
.4071 .22423 m .40834 .22092 L .41013 .22313 L 0 .03 .13 r
F
.4071 .22423 m .4053 .22204 L .40834 .22092 L F
.33463 .22292 m .33576 .21959 L .33762 .2218 L 0 .027 .127 r
F
.33463 .22292 m .33277 .22073 L .33576 .21959 L F
.53153 .22537 m .53296 .22198 L .53463 .2243 L 0 .032 .133 r
F
.53153 .22537 m .52986 .22307 L .53296 .22198 L F
.77085 .22276 m .77265 .21948 L .77407 .22156 L 0 .027 .126 r
F
.77085 .22276 m .76942 .2207 L .77265 .21948 L F
.65119 .22411 m .65281 .22098 L .65436 .22301 L 0 .03 .13 r
F
.65119 .22411 m .64964 .22209 L .65281 .22098 L F
.21806 .22149 m .219 .21822 L .22099 .22033 L 0 .025 .123 r
F
.21806 .22149 m .21607 .21938 L .219 .21822 L F
.29839 .22239 m .29946 .21903 L .30137 .2212 L 0 .026 .125 r
F
.29839 .22239 m .29649 .22021 L .29946 .21903 L F
.59136 .2248 m .59289 .22166 L .59449 .22372 L 0 .031 .132 r
F
.59136 .2248 m .58975 .22274 L .59289 .22166 L F
.77872 .22244 m .78055 .21928 L .78197 .22137 L 0 .027 .126 r
F
.77872 .22244 m .77731 .22037 L .78055 .21928 L F
.44333 .2251 m .44462 .22187 L .44637 .22407 L 0 .032 .132 r
F
.44333 .2251 m .44157 .22291 L .44462 .22187 L F
.37872 .22341 m .37991 .22014 L .38173 .22237 L 0 .029 .128 r
F
.37872 .22341 m .3769 .22117 L .37991 .22014 L F
.48743 .22544 m .48879 .22233 L .4905 .2244 L 0 .033 .134 r
F
.48743 .22544 m .48571 .22337 L .48879 .22233 L F
.30624 .22217 m .30732 .21894 L .30921 .2211 L 0 .026 .125 r
F
.30624 .22217 m .30434 .22001 L .30732 .21894 L F
.65906 .22392 m .6607 .22077 L .66224 .22282 L 0 .03 .13 r
F
.65906 .22392 m .65753 .22189 L .6607 .22077 L F
.2259 .22136 m .22683 .21821 L .22882 .22033 L 0 .025 .124 r
F
.2259 .22136 m .22391 .21924 L .22683 .21821 L F
.73464 .22247 m .73639 .21918 L .73785 .22136 L 0 .027 .126 r
F
.73464 .22247 m .73317 .2203 L .73639 .21918 L F
.34247 .22294 m .34361 .21963 L .34546 .22188 L 0 .028 .127 r
F
.34247 .22294 m .34061 .22071 L .34361 .21963 L F
.41495 .22425 m .4162 .22087 L .41798 .22309 L 0 .03 .13 r
F
.41495 .22425 m .41316 .22201 L .4162 .22087 L F
.26213 .2221 m .26313 .21891 L .26507 .22105 L 0 .026 .126 r
F
.26213 .2221 m .26018 .21995 L .26313 .21891 L F
.59923 .22473 m .60077 .22145 L .60237 .22356 L 0 .031 .132 r
F
.59923 .22473 m .59763 .22263 L .60077 .22145 L F
.66694 .22366 m .66859 .22041 L .67011 .22244 L 0 .029 .129 r
F
.66694 .22366 m .66541 .22164 L .66859 .22041 L F
.67481 .22324 m .67648 .22018 L .67799 .22222 L F
.67481 .22324 m .67329 .22122 L .67648 .22018 L F
.78662 .22243 m .78847 .21924 L .78987 .22136 L 0 .027 .127 r
F
.78662 .22243 m .78522 .22033 L .78847 .21924 L F
.18177 .22136 m .18265 .21807 L .18468 .22019 L 0 .025 .124 r
F
.18177 .22136 m .17974 .21924 L .18265 .21807 L F
.51889 .224 m .5203 .22093 L .52198 .22294 L 0 .031 .131 r
F
.51889 .224 m .51721 .222 L .5203 .22093 L F
.5394 .22553 m .54084 .22198 L .5425 .22425 L 0 .033 .134 r
F
.5394 .22553 m .53773 .22323 L .54084 .22198 L F
.6071 .22446 m .60865 .22091 L .61024 .22314 L 0 .031 .131 r
F
.6071 .22446 m .60551 .22223 L .60865 .22091 L F
.45118 .22513 m .45248 .22202 L .45423 .2241 L 0 .033 .134 r
F
.45118 .22513 m .44943 .22305 L .45248 .22202 L F
.51102 .22449 m .51242 .2212 L .51411 .22321 L 0 .031 .132 r
F
.51102 .22449 m .50933 .22247 L .51242 .2212 L F
.74253 .22235 m .74428 .21896 L .74574 .22116 L 0 .027 .126 r
F
.74253 .22235 m .74107 .22016 L .74428 .21896 L F
.31408 .22214 m .31516 .21905 L .31705 .22111 L F
.31408 .22214 m .31218 .22007 L .31516 .21905 L F
.42281 .2241 m .42407 .22075 L .42585 .22291 L 0 .03 .131 r
F
.42281 .2241 m .42102 .22192 L .42407 .22075 L F
.54726 .2252 m .54872 .22176 L .55037 .22397 L 0 .032 .133 r
F
.54726 .2252 m .54561 .22298 L .54872 .22176 L F
.61497 .22413 m .61653 .22071 L .61812 .2229 L 0 .03 .131 r
F
.61497 .22413 m .61339 .22191 L .61653 .22071 L F
.49529 .22544 m .49666 .22218 L .49837 .22426 L 0 .033 .134 r
F
.49529 .22544 m .49358 .22336 L .49666 .22218 L F
.50315 .22503 m .50454 .22168 L .50624 .22374 L 0 .032 .133 r
F
.50315 .22503 m .50145 .22297 L .50454 .22168 L F
.38656 .22352 m .38776 .22028 L .38958 .22246 L 0 .029 .129 r
F
.38656 .22352 m .38474 .22132 L .38776 .22028 L F
.18961 .22113 m .1905 .21786 L .19253 .21997 L 0 .025 .124 r
F
.18961 .22113 m .18759 .21902 L .1905 .21786 L F
.26997 .222 m .27099 .21868 L .27293 .22082 L 0 .027 .126 r
F
.26997 .222 m .26803 .21987 L .27099 .21868 L F
.79451 .22225 m .79636 .21892 L .79775 .22104 L F
.79451 .22225 m .79311 .22014 L .79636 .21892 L F
.23372 .22138 m .23467 .21821 L .23665 .22029 L 0 .026 .124 r
F
.23372 .22138 m .23174 .21929 L .23467 .21821 L F
.45904 .22493 m .46036 .22162 L .46211 .22367 L 0 .032 .133 r
F
.45904 .22493 m .4573 .22286 L .46036 .22162 L F
.35031 .22298 m .35146 .21963 L .35331 .22179 L 0 .028 .128 r
F
.35031 .22298 m .34846 .2208 L .35146 .21963 L F
.62285 .22386 m .62442 .22054 L .626 .22273 L 0 .03 .13 r
F
.62285 .22386 m .62127 .22169 L .62442 .22054 L F
.27782 .22168 m .27885 .21851 L .28078 .22056 L 0 .026 .125 r
F
.27782 .22168 m .27589 .21965 L .27885 .21851 L F
.80239 .22192 m .80427 .21885 L .80565 .22085 L 0 .027 .126 r
F
.80239 .22192 m .80101 .21992 L .80427 .21885 L F
.55513 .22499 m .5566 .22162 L .55825 .2238 L 0 .032 .133 r
F
.55513 .22499 m .55348 .2228 L .5566 .22162 L F
.43066 .22393 m .43194 .22055 L .43371 .22276 L 0 .03 .131 r
F
.43066 .22393 m .42889 .22171 L .43194 .22055 L F
.46691 .2246 m .46824 .22116 L .46998 .22334 L 0 .032 .132 r
F
.46691 .2246 m .46517 .22241 L .46824 .22116 L F
.35817 .22264 m .35933 .2194 L .36118 .22143 L 0 .028 .128 r
F
.35817 .22264 m .35632 .2206 L .35933 .2194 L F
.75042 .22222 m .75219 .21892 L .75364 .2211 L 0 .027 .127 r
F
.75042 .22222 m .74896 .22003 L .75219 .21892 L F
.6827 .22332 m .68437 .22009 L .68589 .22219 L 0 .029 .129 r
F
.6827 .22332 m .68118 .2212 L .68437 .22009 L F
.19746 .22093 m .19835 .21771 L .20037 .21981 L 0 .025 .124 r
F
.19746 .22093 m .19544 .21884 L .19835 .21771 L F
.36604 .22224 m .36721 .21901 L .36905 .22103 L 0 .027 .127 r
F
.36604 .22224 m .36419 .22022 L .36721 .21901 L F
.24157 .22117 m .24252 .21809 L .2445 .22007 L 0 .026 .124 r
F
.24157 .22117 m .23959 .21919 L .24252 .21809 L F
.32193 .22206 m .32301 .21902 L .3249 .221 L 0 .027 .127 r
F
.32193 .22206 m .32003 .22006 L .32301 .21902 L F
.39442 .22339 m .39563 .22012 L .39744 .22222 L 0 .03 .13 r
F
.39442 .22339 m .3926 .22131 L .39563 .22012 L F
.563 .22474 m .56449 .22153 L .56612 .22362 L 0 .032 .133 r
F
.563 .22474 m .56136 .22266 L .56449 .22153 L F
.47477 .22431 m .47612 .22099 L .47784 .22323 L 0 .031 .132 r
F
.47477 .22431 m .47305 .22208 L .47612 .22099 L F
.28567 .2215 m .28671 .21834 L .28863 .22039 L 0 .026 .125 r
F
.28567 .2215 m .28374 .21944 L .28671 .21834 L F
.69058 .22303 m .69226 .21971 L .69376 .22178 L 0 .029 .129 r
F
.69058 .22303 m .68907 .22095 L .69226 .21971 L F
.52676 .22414 m .52818 .2208 L .52986 .22307 L 0 .031 .131 r
F
.52676 .22414 m .52508 .22189 L .52818 .2208 L F
.69845 .22265 m .70015 .2194 L .70164 .22145 L 0 .028 .128 r
F
.69845 .22265 m .69695 .22058 L .70015 .2194 L F
.63073 .2238 m .63231 .22038 L .63388 .22261 L 0 .03 .131 r
F
.63073 .2238 m .62916 .22159 L .63231 .22038 L F
.2053 .22075 m .2062 .21759 L .20821 .21964 L 0 .025 .124 r
F
.2053 .22075 m .20328 .2187 L .2062 .21759 L F
.24941 .22097 m .25038 .21788 L .25235 .21991 L 0 .026 .124 r
F
.24941 .22097 m .24744 .21897 L .25038 .21788 L F
.75831 .22207 m .7601 .21884 L .76154 .22095 L 0 .027 .127 r
F
.75831 .22207 m .75687 .21997 L .7601 .21884 L F
.40227 .22317 m .4035 .21991 L .4053 .22204 L 0 .029 .129 r
F
.40227 .22317 m .40047 .22106 L .4035 .21991 L F
.32978 .22188 m .33088 .21873 L .33277 .22073 L 0 .027 .127 r
F
.32978 .22188 m .32789 .21989 L .33088 .21873 L F
.57087 .2245 m .57237 .22123 L .574 .22326 L 0 .032 .133 r
F
.57087 .2245 m .56924 .22248 L .57237 .22123 L F
.57874 .22406 m .58025 .22086 L .58187 .2229 L 0 .031 .132 r
F
.57874 .22406 m .57712 .22202 L .58025 .22086 L F
.70632 .22232 m .70803 .21907 L .70952 .22113 L 0 .028 .127 r
F
.70632 .22232 m .70483 .22025 L .70803 .21907 L F
.43852 .22394 m .4398 .22066 L .44157 .22291 L 0 .031 .132 r
F
.43852 .22394 m .43676 .22171 L .4398 .22066 L F
.37389 .2222 m .37507 .21897 L .3769 .22117 L 0 .028 .127 r
F
.37389 .2222 m .37206 .22 L .37507 .21897 L F
.7142 .22199 m .71592 .21871 L .7174 .22074 L 0 .027 .127 r
F
.7142 .22199 m .71272 .21995 L .71592 .21871 L F
.72207 .22157 m .72379 .21818 L .72527 .22029 L 0 .026 .125 r
F
.72207 .22157 m .72059 .21946 L .72379 .21818 L F
.29352 .22135 m .29457 .21814 L .29649 .22021 L F
.29352 .22135 m .2916 .21927 L .29457 .21814 L F
.6386 .22355 m .6402 .22008 L .64176 .22229 L 0 .03 .13 r
F
.6386 .22355 m .63704 .22135 L .6402 .22008 L F
.21314 .22054 m .21406 .21734 L .21607 .21938 L 0 .025 .123 r
F
.21314 .22054 m .21114 .21851 L .21406 .21734 L F
.76619 .22186 m .768 .21864 L .76942 .2207 L 0 .027 .127 r
F
.76619 .22186 m .76477 .21982 L .768 .21864 L F
.64648 .22319 m .6481 .22007 L .64964 .22209 L 0 .03 .13 r
F
.64648 .22319 m .64493 .22118 L .6481 .22007 L F
.58662 .2239 m .58814 .22068 L .58975 .22274 L 0 .031 .132 r
F
.58662 .2239 m .585 .22179 L .58814 .22068 L F
.77407 .22156 m .77589 .21827 L .77731 .22037 L 0 .027 .126 r
F
.77407 .22156 m .77265 .21948 L .77589 .21827 L F
.48264 .22441 m .48399 .22115 L .48571 .22337 L 0 .032 .133 r
F
.48264 .22441 m .48091 .22219 L .48399 .22115 L F
.33762 .2218 m .33875 .21847 L .34061 .22071 L 0 .027 .127 r
F
.33762 .2218 m .33576 .21959 L .33875 .21847 L F
.72995 .22137 m .7317 .21812 L .73317 .2203 L 0 .027 .126 r
F
.72995 .22137 m .72848 .2192 L .7317 .21812 L F
.41013 .22313 m .41137 .21979 L .41316 .22201 L 0 .03 .13 r
F
.41013 .22313 m .40834 .22092 L .41137 .21979 L F
.25724 .22097 m .25823 .21785 L .26018 .21995 L 0 .026 .125 r
F
.25724 .22097 m .25529 .21887 L .25823 .21785 L F
.22099 .22033 m .22192 .21714 L .22391 .21924 L 0 .025 .123 r
F
.22099 .22033 m .219 .21822 L .22192 .21714 L F
.30137 .2212 m .30244 .21785 L .30434 .22001 L 0 .026 .125 r
F
.30137 .2212 m .29946 .21903 L .30244 .21785 L F
.53463 .2243 m .53606 .22089 L .53773 .22323 L 0 .032 .133 r
F
.53463 .2243 m .53296 .22198 L .53606 .22089 L F
.65436 .22301 m .65599 .21983 L .65753 .22189 L 0 .03 .13 r
F
.65436 .22301 m .65281 .22098 L .65599 .21983 L F
.59449 .22372 m .59603 .22058 L .59763 .22263 L 0 .031 .132 r
F
.59449 .22372 m .59289 .22166 L .59603 .22058 L F
.78197 .22137 m .7838 .21822 L .78522 .22033 L 0 .027 .126 r
F
.78197 .22137 m .78055 .21928 L .7838 .21822 L F
.44637 .22407 m .44767 .22083 L .44943 .22305 L 0 .032 .133 r
F
.44637 .22407 m .44462 .22187 L .44767 .22083 L F
.38173 .22237 m .38292 .2191 L .38474 .22132 L 0 .029 .129 r
F
.38173 .22237 m .37991 .22014 L .38292 .2191 L F
.66224 .22282 m .66388 .21958 L .66541 .22164 L 0 .03 .13 r
F
.66224 .22282 m .6607 .22077 L .66388 .21958 L F
.30921 .2211 m .31029 .21791 L .31218 .22007 L 0 .027 .126 r
F
.30921 .2211 m .30732 .21894 L .31029 .21791 L F
.41798 .22309 m .41924 .21973 L .42102 .22192 L 0 .03 .13 r
F
.41798 .22309 m .4162 .22087 L .41924 .21973 L F
.67011 .22244 m .67176 .21919 L .67329 .22122 L 0 .029 .129 r
F
.67011 .22244 m .66859 .22041 L .67176 .21919 L F
.4905 .2244 m .49187 .22128 L .49358 .22336 L 0 .033 .134 r
F
.4905 .2244 m .48879 .22233 L .49187 .22128 L F
.73785 .22136 m .73961 .21798 L .74107 .22016 L 0 .027 .126 r
F
.73785 .22136 m .73639 .21918 L .73961 .21798 L F
.60237 .22356 m .60391 .22014 L .60551 .22223 L 0 .031 .131 r
F
.60237 .22356 m .60077 .22145 L .60391 .22014 L F
.61024 .22314 m .61179 .2197 L .61339 .22191 L 0 .03 .13 r
F
.61024 .22314 m .60865 .22091 L .61179 .2197 L F
.5425 .22425 m .54395 .22073 L .54561 .22298 L 0 .032 .133 r
F
.5425 .22425 m .54084 .22198 L .54395 .22073 L F
.22882 .22033 m .22976 .21717 L .23174 .21929 L 0 .025 .124 r
F
.22882 .22033 m .22683 .21821 L .22976 .21717 L F
.34546 .22188 m .34661 .21853 L .34846 .2208 L 0 .028 .128 r
F
.34546 .22188 m .34361 .21963 L .34661 .21853 L F
.51411 .22321 m .51552 .21999 L .51721 .222 L 0 .031 .131 r
F
.51411 .22321 m .51242 .2212 L .51552 .21999 L F
.26507 .22105 m .26609 .21773 L .26803 .21987 L 0 .027 .126 r
F
.26507 .22105 m .26313 .21891 L .26609 .21773 L F
.18468 .22019 m .18556 .2169 L .18759 .21902 L 0 .025 .124 r
F
.18468 .22019 m .18265 .21807 L .18556 .2169 L F
.50624 .22374 m .50763 .22041 L .50933 .22247 L 0 .032 .132 r
F
.50624 .22374 m .50454 .22168 L .50763 .22041 L F
.67799 .22222 m .67967 .21914 L .68118 .2212 L 0 .029 .129 r
F
.67799 .22222 m .67648 .22018 L .67967 .21914 L F
.55037 .22397 m .55183 .22059 L .55348 .2228 L 0 .032 .133 r
F
.55037 .22397 m .54872 .22176 L .55183 .22059 L F
.78987 .22136 m .79171 .218 L .79311 .22014 L 0 .027 .126 r
F
.78987 .22136 m .78847 .21924 L .79171 .218 L F
.61812 .2229 m .61969 .21952 L .62127 .22169 L 0 .03 .13 r
F
.61812 .2229 m .61653 .22071 L .61969 .21952 L F
.74574 .22116 m .74751 .21783 L .74896 .22003 L 0 .027 .126 r
F
.74574 .22116 m .74428 .21896 L .74751 .21783 L F
.42585 .22291 m .42711 .21958 L .42889 .22171 L 0 .03 .13 r
F
.42585 .22291 m .42407 .22075 L .42711 .21958 L F
.52198 .22294 m .5234 .21987 L .52508 .22189 L 0 .031 .131 r
F
.52198 .22294 m .5203 .22093 L .5234 .21987 L F
.49837 .22426 m .49975 .22088 L .50145 .22297 L 0 .033 .134 r
F
.49837 .22426 m .49666 .22218 L .49975 .22088 L F
.27293 .22082 m .27395 .21752 L .27589 .21965 L 0 .026 .125 r
F
.27293 .22082 m .27099 .21868 L .27395 .21752 L F
.79775 .22104 m .79961 .21779 L .80101 .21992 L 0 .027 .126 r
F
.79775 .22104 m .79636 .21892 L .79961 .21779 L F
.46211 .22367 m .46343 .22038 L .46517 .22241 L 0 .032 .132 r
F
.46211 .22367 m .46036 .22162 L .46343 .22038 L F
.45423 .2241 m .45555 .22079 L .4573 .22286 L 0 .033 .133 r
F
.45423 .2241 m .45248 .22202 L .45555 .22079 L F
.19253 .21997 m .19342 .21672 L .19544 .21884 L 0 .025 .123 r
F
.19253 .21997 m .1905 .21786 L .19342 .21672 L F
.31705 .22111 m .31813 .21801 L .32003 .22006 L 0 .027 .127 r
F
.31705 .22111 m .31516 .21905 L .31813 .21801 L F
.35331 .22179 m .35447 .21846 L .35632 .2206 L 0 .028 .128 r
F
.35331 .22179 m .35146 .21963 L .35447 .21846 L F
.38958 .22246 m .39079 .21912 L .3926 .22131 L 0 .03 .13 r
F
.38958 .22246 m .38776 .22028 L .39079 .21912 L F
.46998 .22334 m .47131 .21991 L .47305 .22208 L 0 .031 .132 r
F
.46998 .22334 m .46824 .22116 L .47131 .21991 L F
.23665 .22029 m .23761 .21713 L .23959 .21919 L 0 .026 .125 r
F
.23665 .22029 m .23467 .21821 L .23761 .21713 L F
.55825 .2238 m .55972 .22045 L .56136 .22266 L 0 .032 .133 r
F
.55825 .2238 m .5566 .22162 L .55972 .22045 L F
.626 .22273 m .62758 .21938 L .62916 .22159 L 0 .03 .13 r
F
.626 .22273 m .62442 .22054 L .62758 .21938 L F
.36118 .22143 m .36234 .21819 L .36419 .22022 L 0 .028 .127 r
F
.36118 .22143 m .35933 .2194 L .36234 .21819 L F
.28078 .22056 m .28181 .21737 L .28374 .21944 L 0 .026 .125 r
F
.28078 .22056 m .27885 .21851 L .28181 .21737 L F
.43371 .22276 m .43499 .21948 L .43676 .22171 L 0 .03 .131 r
F
.43371 .22276 m .43194 .22055 L .43499 .21948 L F
.36905 .22103 m .37022 .21797 L .37206 .22 L 0 .027 .127 r
F
.36905 .22103 m .36721 .21901 L .37022 .21797 L F
.80565 .22085 m .80753 .21778 L .80891 .21977 L 0 .027 .126 r
F
.80565 .22085 m .80427 .21885 L .80753 .21778 L F
.75364 .2211 m .75542 .21781 L .75687 .21997 L 0 .027 .127 r
F
.75364 .2211 m .75219 .21892 L .75542 .21781 L F
.68589 .22219 m .68756 .21886 L .68907 .22095 L 0 .029 .129 r
F
.68589 .22219 m .68437 .22009 L .68756 .21886 L F
.69376 .22178 m .69545 .21853 L .69695 .22058 L 0 .029 .128 r
F
.69376 .22178 m .69226 .21971 L .69545 .21853 L F
.20037 .21981 m .20127 .21661 L .20328 .2187 L 0 .025 .124 r
F
.20037 .21981 m .19835 .21771 L .20127 .21661 L F
.39744 .22222 m .39866 .21894 L .40047 .22106 L 0 .029 .129 r
F
.39744 .22222 m .39563 .22012 L .39866 .21894 L F
.2445 .22007 m .24547 .21697 L .24744 .21897 L 0 .026 .125 r
F
.2445 .22007 m .24252 .21809 L .24547 .21697 L F
.3249 .221 m .326 .21791 L .32789 .21989 L 0 .028 .127 r
F
.3249 .221 m .32301 .21902 L .326 .21791 L F
.56612 .22362 m .56761 .22036 L .56924 .22248 L 0 .032 .133 r
F
.56612 .22362 m .56449 .22153 L .56761 .22036 L F
.70164 .22145 m .70334 .21822 L .70483 .22025 L 0 .028 .128 r
F
.70164 .22145 m .70015 .2194 L .70334 .21822 L F
.47784 .22323 m .47919 .21995 L .48091 .22219 L 0 .032 .132 r
F
.47784 .22323 m .47612 .22099 L .47919 .21995 L F
.28863 .22039 m .28967 .21724 L .2916 .21927 L 0 .026 .125 r
F
.28863 .22039 m .28671 .21834 L .28967 .21724 L F
.574 .22326 m .5755 .21998 L .57712 .22202 L 0 .032 .132 r
F
.574 .22326 m .57237 .22123 L .5755 .21998 L F
.63388 .22261 m .63547 .21911 L .63704 .22135 L 0 .03 .13 r
F
.63388 .22261 m .63231 .22038 L .63547 .21911 L F
.52986 .22307 m .53129 .21969 L .53296 .22198 L 0 .031 .132 r
F
.52986 .22307 m .52818 .2208 L .53129 .21969 L F
.70952 .22113 m .71124 .2179 L .71272 .21995 L 0 .028 .127 r
F
.70952 .22113 m .70803 .21907 L .71124 .2179 L F
.58187 .2229 m .58339 .21976 L .585 .22179 L 0 .031 .132 r
F
.58187 .2229 m .58025 .22086 L .58339 .21976 L F
.76154 .22095 m .76334 .21771 L .76477 .21982 L 0 .027 .127 r
F
.76154 .22095 m .7601 .21884 L .76334 .21771 L F
.20821 .21964 m .20912 .21647 L .21114 .21851 L 0 .025 .124 r
F
.20821 .21964 m .2062 .21759 L .20912 .21647 L F
.72527 .22029 m .72701 .21708 L .72848 .2192 L 0 .026 .125 r
F
.72527 .22029 m .72379 .21818 L .72701 .21708 L F
.33277 .22073 m .33388 .21756 L .33576 .21959 L 0 .027 .126 r
F
.33277 .22073 m .33088 .21873 L .33388 .21756 L F
.4053 .22204 m .40654 .21876 L .40834 .22092 L 0 .029 .129 r
F
.4053 .22204 m .4035 .21991 L .40654 .21876 L F
.7174 .22074 m .71912 .21744 L .72059 .21946 L 0 .027 .126 r
F
.7174 .22074 m .71592 .21871 L .71912 .21744 L F
.64176 .22229 m .64337 .21898 L .64493 .22118 L 0 .03 .13 r
F
.64176 .22229 m .6402 .22008 L .64337 .21898 L F
.25235 .21991 m .25332 .21683 L .25529 .21887 L 0 .026 .125 r
F
.25235 .21991 m .25038 .21788 L .25332 .21683 L F
.29649 .22021 m .29755 .21697 L .29946 .21903 L F
.29649 .22021 m .29457 .21814 L .29755 .21697 L F
.21607 .21938 m .217 .21617 L .219 .21822 L 0 .025 .123 r
F
.21607 .21938 m .21406 .21734 L .217 .21617 L F
.76942 .2207 m .77123 .2174 L .77265 .21948 L 0 .027 .126 r
F
.76942 .2207 m .768 .21864 L .77123 .2174 L F
.44157 .22291 m .44286 .2196 L .44462 .22187 L 0 .031 .132 r
F
.44157 .22291 m .4398 .22066 L .44286 .2196 L F
.3769 .22117 m .37808 .21794 L .37991 .22014 L 0 .028 .128 r
F
.3769 .22117 m .37507 .21897 L .37808 .21794 L F
.58975 .22274 m .59128 .21961 L .59289 .22166 L 0 .031 .132 r
F
.58975 .22274 m .58814 .22068 L .59128 .21961 L F
.64964 .22209 m .65127 .21895 L .65281 .22098 L 0 .03 .13 r
F
.64964 .22209 m .6481 .22007 L .65127 .21895 L F
.77731 .22037 m .77913 .21716 L .78055 .21928 L 0 .027 .126 r
F
.77731 .22037 m .77589 .21827 L .77913 .21716 L F
.30434 .22001 m .30541 .21677 L .30732 .21894 L 0 .026 .125 r
F
.30434 .22001 m .30244 .21785 L .30541 .21677 L F
.41316 .22201 m .41441 .21868 L .4162 .22087 L 0 .03 .13 r
F
.41316 .22201 m .41137 .21979 L .41441 .21868 L F
.34061 .22071 m .34175 .21737 L .34361 .21963 L 0 .027 .127 r
F
.34061 .22071 m .33875 .21847 L .34175 .21737 L F
.73317 .2203 m .73492 .217 L .73639 .21918 L 0 .027 .126 r
F
.73317 .2203 m .7317 .21812 L .73492 .217 L F
.48571 .22337 m .48707 .22009 L .48879 .22233 L 0 .033 .133 r
F
.48571 .22337 m .48399 .22115 L .48707 .22009 L F
.22391 .21924 m .22485 .2161 L .22683 .21821 L 0 .025 .124 r
F
.22391 .21924 m .22192 .21714 L .22485 .2161 L F
.65753 .22189 m .65916 .21868 L .6607 .22077 L 0 .03 .13 r
F
.65753 .22189 m .65599 .21983 L .65916 .21868 L F
.53773 .22323 m .53917 .21967 L .54084 .22198 L 0 .032 .133 r
F
.53773 .22323 m .53606 .22089 L .53917 .21967 L F
.26018 .21995 m .26118 .2168 L .26313 .21891 L 0 .026 .125 r
F
.26018 .21995 m .25823 .21785 L .26118 .2168 L F
.59763 .22263 m .59917 .21942 L .60077 .22145 L 0 .031 .132 r
F
.59763 .22263 m .59603 .22058 L .59917 .21942 L F
.60551 .22223 m .60705 .21882 L .60865 .22091 L 0 .03 .131 r
F
.60551 .22223 m .60391 .22014 L .60705 .21882 L F
.66541 .22164 m .66706 .21835 L .66859 .22041 L 0 .029 .129 r
F
.66541 .22164 m .66388 .21958 L .66706 .21835 L F
.78522 .22033 m .78705 .21711 L .78847 .21924 L 0 .027 .126 r
F
.78522 .22033 m .7838 .21822 L .78705 .21711 L F
.67329 .22122 m .67495 .21813 L .67648 .22018 L 0 .029 .129 r
F
.67329 .22122 m .67176 .21919 L .67495 .21813 L F
.54561 .22298 m .54706 .21953 L .54872 .22176 L 0 .032 .132 r
F
.54561 .22298 m .54395 .22073 L .54706 .21953 L F
.74107 .22016 m .74282 .21678 L .74428 .21896 L 0 .027 .126 r
F
.74107 .22016 m .73961 .21798 L .74282 .21678 L F
.61339 .22191 m .61494 .21852 L .61653 .22071 L 0 .03 .13 r
F
.61339 .22191 m .61179 .2197 L .61494 .21852 L F
.42102 .22192 m .42228 .21859 L .42407 .22075 L F
.42102 .22192 m .41924 .21973 L .42228 .21859 L F
.44943 .22305 m .45073 .21978 L .45248 .22202 L 0 .032 .133 r
F
.44943 .22305 m .44767 .22083 L .45073 .21978 L F
.38474 .22132 m .38594 .21806 L .38776 .22028 L 0 .029 .129 r
F
.38474 .22132 m .38292 .2191 L .38594 .21806 L F
.51721 .222 m .51861 .21892 L .5203 .22093 L 0 .031 .131 r
F
.51721 .222 m .51552 .21999 L .51861 .21892 L F
.50933 .22247 m .51073 .21915 L .51242 .2212 L 0 .031 .132 r
F
.50933 .22247 m .50763 .22041 L .51073 .21915 L F
.31218 .22007 m .31326 .21688 L .31516 .21905 L 0 .027 .126 r
F
.31218 .22007 m .31029 .21791 L .31326 .21688 L F
.26803 .21987 m .26905 .21654 L .27099 .21868 L 0 .026 .125 r
F
.26803 .21987 m .26609 .21773 L .26905 .21654 L F
.49358 .22336 m .49495 .22009 L .49666 .22218 L 0 .033 .134 r
F
.49358 .22336 m .49187 .22128 L .49495 .22009 L F
.18759 .21902 m .18848 .21574 L .1905 .21786 L 0 .025 .123 r
F
.18759 .21902 m .18556 .2169 L .18848 .21574 L F
.50145 .22297 m .50284 .21957 L .50454 .22168 L 0 .032 .133 r
F
.50145 .22297 m .49975 .22088 L .50284 .21957 L F
.79311 .22014 m .79495 .21677 L .79636 .21892 L 0 .027 .126 r
F
.79311 .22014 m .79171 .218 L .79495 .21677 L F
.34846 .2208 m .34961 .21738 L .35146 .21963 L 0 .028 .128 r
F
.34846 .2208 m .34661 .21853 L .34961 .21738 L F
.62127 .22169 m .62284 .21835 L .62442 .22054 L 0 .03 .13 r
F
.62127 .22169 m .61969 .21952 L .62284 .21835 L F
.23174 .21929 m .23269 .21611 L .23467 .21821 L 0 .026 .124 r
F
.23174 .21929 m .22976 .21717 L .23269 .21611 L F
.55348 .2228 m .55495 .21943 L .5566 .22162 L 0 .032 .133 r
F
.55348 .2228 m .55183 .22059 L .55495 .21943 L F
.42889 .22171 m .43016 .21843 L .43194 .22055 L 0 .03 .13 r
F
.42889 .22171 m .42711 .21958 L .43016 .21843 L F
.46517 .22241 m .4665 .21915 L .46824 .22116 L 0 .031 .132 r
F
.46517 .22241 m .46343 .22038 L .4665 .21915 L F
.4573 .22286 m .45861 .21956 L .46036 .22162 L 0 .032 .133 r
F
.4573 .22286 m .45555 .22079 L .45861 .21956 L F
.74896 .22003 m .75074 .21674 L .75219 .21892 L 0 .027 .126 r
F
.74896 .22003 m .74751 .21783 L .75074 .21674 L F
.27589 .21965 m .27691 .21637 L .27885 .21851 L 0 .026 .125 r
F
.27589 .21965 m .27395 .21752 L .27691 .21637 L F
.68118 .2212 m .68286 .21801 L .68437 .22009 L 0 .029 .129 r
F
.68118 .2212 m .67967 .21914 L .68286 .21801 L F
.47305 .22208 m .47439 .21882 L .47612 .22099 L 0 .031 .131 r
F
.47305 .22208 m .47131 .21991 L .47439 .21882 L F
.80101 .21992 m .80287 .21672 L .80427 .21885 L 0 .027 .126 r
F
.80101 .21992 m .79961 .21779 L .80287 .21672 L F
.52508 .22189 m .5265 .21876 L .52818 .2208 L 0 .031 .131 r
F
.52508 .22189 m .5234 .21987 L .5265 .21876 L F
.19544 .21884 m .19634 .21558 L .19835 .21771 L 0 .025 .123 r
F
.19544 .21884 m .19342 .21672 L .19634 .21558 L F
.35632 .2206 m .35748 .21727 L .35933 .2194 L 0 .028 .128 r
F
.35632 .2206 m .35447 .21846 L .35748 .21727 L F
.3926 .22131 m .39382 .21792 L .39563 .22012 L 0 .029 .129 r
F
.3926 .22131 m .39079 .21912 L .39382 .21792 L F
.36419 .22022 m .36536 .21698 L .36721 .21901 L 0 .028 .127 r
F
.36419 .22022 m .36234 .21819 L .36536 .21698 L F
.56136 .22266 m .56284 .21928 L .56449 .22153 L 0 .032 .133 r
F
.56136 .22266 m .55972 .22045 L .56284 .21928 L F
.62916 .22159 m .63074 .21816 L .63231 .22038 L 0 .03 .13 r
F
.62916 .22159 m .62758 .21938 L .63074 .21816 L F
.32003 .22006 m .32112 .21698 L .32301 .21902 L 0 .028 .127 r
F
.32003 .22006 m .31813 .21801 L .32112 .21698 L F
.23959 .21919 m .24055 .21603 L .24252 .21809 L 0 .026 .125 r
F
.23959 .21919 m .23761 .21713 L .24055 .21603 L F
.68907 .22095 m .69075 .21763 L .69226 .21971 L 0 .029 .129 r
F
.68907 .22095 m .68756 .21886 L .69075 .21763 L F
.28374 .21944 m .28478 .21628 L .28671 .21834 L 0 .026 .125 r
F
.28374 .21944 m .28181 .21737 L .28478 .21628 L F
.69695 .22058 m .69865 .21738 L .70015 .2194 L 0 .028 .128 r
F
.69695 .22058 m .69545 .21853 L .69865 .21738 L F
.43676 .22171 m .43804 .2184 L .4398 .22066 L 0 .031 .131 r
F
.43676 .22171 m .43499 .21948 L .43804 .2184 L F
.40047 .22106 m .4017 .21777 L .4035 .21991 L 0 .029 .129 r
F
.40047 .22106 m .39866 .21894 L .4017 .21777 L F
.75687 .21997 m .75866 .21668 L .7601 .21884 L 0 .027 .127 r
F
.75687 .21997 m .75542 .21781 L .75866 .21668 L F
.37206 .22 m .37323 .21694 L .37507 .21897 L 0 .028 .127 r
F
.37206 .22 m .37022 .21797 L .37323 .21694 L F
.20328 .2187 m .20419 .21552 L .2062 .21759 L 0 .025 .124 r
F
.20328 .2187 m .20127 .21661 L .20419 .21552 L F
.70483 .22025 m .70655 .21705 L .70803 .21907 L 0 .028 .128 r
F
.70483 .22025 m .70334 .21822 L .70655 .21705 L F
.63704 .22135 m .63863 .21784 L .6402 .22008 L 0 .03 .13 r
F
.63704 .22135 m .63547 .21911 L .63863 .21784 L F
.57712 .22202 m .57863 .21882 L .58025 .22086 L 0 .031 .132 r
F
.57712 .22202 m .5755 .21998 L .57863 .21882 L F
.24744 .21897 m .24841 .21585 L .25038 .21788 L 0 .026 .125 r
F
.24744 .21897 m .24547 .21697 L .24841 .21585 L F
.56924 .22248 m .57074 .2191 L .57237 .22123 L 0 .032 .133 r
F
.56924 .22248 m .56761 .22036 L .57074 .2191 L F
.32789 .21989 m .32899 .21673 L .33088 .21873 L 0 .027 .127 r
F
.32789 .21989 m .326 .21791 L .32899 .21673 L F
.72059 .21946 m .72232 .21616 L .72379 .21818 L 0 .026 .126 r
F
.72059 .21946 m .71912 .21744 L .72232 .21616 L F
.2916 .21927 m .29264 .21612 L .29457 .21814 L 0 .026 .125 r
F
.2916 .21927 m .28967 .21724 L .29264 .21612 L F
.71272 .21995 m .71444 .21667 L .71592 .21871 L 0 .027 .127 r
F
.71272 .21995 m .71124 .2179 L .71444 .21667 L F
.48091 .22219 m .48227 .2189 L .48399 .22115 L 0 .032 .132 r
F
.48091 .22219 m .47919 .21995 L .48227 .2189 L F
.53296 .22198 m .53439 .21858 L .53606 .22089 L 0 .031 .132 r
F
.53296 .22198 m .53129 .21969 L .53439 .21858 L F
.33576 .21959 m .33687 .21643 L .33875 .21847 L 0 .027 .126 r
F
.33576 .21959 m .33388 .21756 L .33687 .21643 L F
.21114 .21851 m .21205 .2153 L .21406 .21734 L 0 .025 .124 r
F
.21114 .21851 m .20912 .21647 L .21205 .2153 L F
.76477 .21982 m .76657 .21653 L .768 .21864 L 0 .027 .127 r
F
.76477 .21982 m .76334 .21771 L .76657 .21653 L F
.40834 .22092 m .40957 .21763 L .41137 .21979 L 0 .029 .129 r
F
.40834 .22092 m .40654 .21876 L .40957 .21763 L F
.585 .22179 m .58652 .21865 L .58814 .22068 L 0 .031 .132 r
F
.585 .22179 m .58339 .21976 L .58652 .21865 L F
.72848 .2192 m .73023 .21599 L .7317 .21812 L 0 .026 .125 r
F
.72848 .2192 m .72701 .21708 L .73023 .21599 L F
.64493 .22118 m .64654 .21789 L .6481 .22007 L 0 .03 .13 r
F
.64493 .22118 m .64337 .21898 L .64654 .21789 L F
.29946 .21903 m .30052 .2158 L .30244 .21785 L 0 .026 .125 r
F
.29946 .21903 m .29755 .21697 L .30052 .2158 L F
.77265 .21948 m .77447 .21616 L .77589 .21827 L 0 .027 .126 r
F
.77265 .21948 m .77123 .2174 L .77447 .21616 L F
.25529 .21887 m .25627 .21579 L .25823 .21785 L 0 .026 .125 r
F
.25529 .21887 m .25332 .21683 L .25627 .21579 L F
.219 .21822 m .21992 .21508 L .22192 .21714 L 0 .025 .123 r
F
.219 .21822 m .217 .21617 L .21992 .21508 L F
.65281 .22098 m .65444 .21778 L .65599 .21983 L 0 .03 .13 r
F
.65281 .22098 m .65127 .21895 L .65444 .21778 L F
.44462 .22187 m .44591 .21853 L .44767 .22083 L 0 .032 .132 r
F
.44462 .22187 m .44286 .2196 L .44591 .21853 L F
.59289 .22166 m .59442 .21854 L .59603 .22058 L F
.59289 .22166 m .59128 .21961 L .59442 .21854 L F
.37991 .22014 m .3811 .21691 L .38292 .2191 L 0 .028 .128 r
F
.37991 .22014 m .37808 .21794 L .3811 .21691 L F
.78055 .21928 m .78239 .21608 L .7838 .21822 L 0 .027 .126 r
F
.78055 .21928 m .77913 .21716 L .78239 .21608 L F
.4162 .22087 m .41745 .21756 L .41924 .21973 L 0 .03 .13 r
F
.4162 .22087 m .41441 .21868 L .41745 .21756 L F
.54084 .22198 m .54228 .21845 L .54395 .22073 L 0 .032 .132 r
F
.54084 .22198 m .53917 .21967 L .54228 .21845 L F
.30732 .21894 m .30839 .21574 L .31029 .21791 L 0 .026 .125 r
F
.30732 .21894 m .30541 .21677 L .30839 .21574 L F
.60865 .22091 m .6102 .21761 L .61179 .2197 L 0 .03 .13 r
F
.60865 .22091 m .60705 .21882 L .6102 .21761 L F
.73639 .21918 m .73814 .2158 L .73961 .21798 L 0 .027 .126 r
F
.73639 .21918 m .73492 .217 L .73814 .2158 L F
.34361 .21963 m .34475 .21626 L .34661 .21853 L 0 .027 .127 r
F
.34361 .21963 m .34175 .21737 L .34475 .21626 L F
.6607 .22077 m .66234 .21748 L .66388 .21958 L 0 .03 .13 r
F
.6607 .22077 m .65916 .21868 L .66234 .21748 L F
.48879 .22233 m .49015 .21903 L .49187 .22128 L 0 .033 .134 r
F
.48879 .22233 m .48707 .22009 L .49015 .21903 L F
.60077 .22145 m .60231 .21811 L .60391 .22014 L 0 .031 .131 r
F
.60077 .22145 m .59917 .21942 L .60231 .21811 L F
.22683 .21821 m .22777 .21507 L .22976 .21717 L 0 .025 .124 r
F
.22683 .21821 m .22485 .2161 L .22777 .21507 L F
.66859 .22041 m .67024 .21712 L .67176 .21919 L 0 .029 .129 r
F
.66859 .22041 m .66706 .21835 L .67024 .21712 L F
.26313 .21891 m .26414 .21562 L .26609 .21773 L 0 .026 .125 r
F
.26313 .21891 m .26118 .2168 L .26414 .21562 L F
.54872 .22176 m .55018 .21839 L .55183 .22059 L 0 .032 .132 r
F
.54872 .22176 m .54706 .21953 L .55018 .21839 L F
.74428 .21896 m .74605 .21567 L .74751 .21783 L 0 .027 .126 r
F
.74428 .21896 m .74282 .21678 L .74605 .21567 L F
.61653 .22071 m .6181 .21734 L .61969 .21952 L 0 .03 .13 r
F
.61653 .22071 m .61494 .21852 L .6181 .21734 L F
.42407 .22075 m .42533 .21745 L .42711 .21958 L F
.42407 .22075 m .42228 .21859 L .42533 .21745 L F
.51242 .2212 m .51383 .21793 L .51552 .21999 L 0 .031 .131 r
F
.51242 .2212 m .51073 .21915 L .51383 .21793 L F
.78847 .21924 m .7903 .21586 L .79171 .218 L 0 .027 .126 r
F
.78847 .21924 m .78705 .21711 L .7903 .21586 L F
.50454 .22168 m .50593 .21831 L .50763 .22041 L 0 .032 .132 r
F
.50454 .22168 m .50284 .21957 L .50593 .21831 L F
.67648 .22018 m .67815 .21707 L .67967 .21914 L 0 .029 .129 r
F
.67648 .22018 m .67495 .21813 L .67815 .21707 L F
.27099 .21868 m .27201 .21537 L .27395 .21752 L 0 .026 .125 r
F
.27099 .21868 m .26905 .21654 L .27201 .21537 L F
.49666 .22218 m .49804 .21878 L .49975 .22088 L 0 .033 .134 r
F
.49666 .22218 m .49495 .22009 L .49804 .21878 L F
.79636 .21892 m .79821 .21563 L .79961 .21779 L 0 .027 .126 r
F
.79636 .21892 m .79495 .21677 L .79821 .21563 L F
.1905 .21786 m .1914 .2146 L .19342 .21672 L 0 .025 .123 r
F
.1905 .21786 m .18848 .21574 L .1914 .2146 L F
.45248 .22202 m .45379 .21857 L .45555 .22079 L 0 .032 .133 r
F
.45248 .22202 m .45073 .21978 L .45379 .21857 L F
.38776 .22028 m .38897 .21689 L .39079 .21912 L 0 .029 .129 r
F
.38776 .22028 m .38594 .21806 L .38897 .21689 L F
.5203 .22093 m .52172 .21784 L .5234 .21987 L 0 .031 .131 r
F
.5203 .22093 m .51861 .21892 L .52172 .21784 L F
.46824 .22116 m .46957 .21792 L .47131 .21991 L 0 .031 .132 r
F
.46824 .22116 m .4665 .21915 L .46957 .21792 L F
.35146 .21963 m .35262 .21623 L .35447 .21846 L 0 .028 .127 r
F
.35146 .21963 m .34961 .21738 L .35262 .21623 L F
.46036 .22162 m .46168 .21834 L .46343 .22038 L 0 .032 .133 r
F
.46036 .22162 m .45861 .21956 L .46168 .21834 L F
.5566 .22162 m .55807 .21824 L .55972 .22045 L 0 .032 .132 r
F
.5566 .22162 m .55495 .21943 L .55807 .21824 L F
.62442 .22054 m .626 .21719 L .62758 .21938 L 0 .03 .13 r
F
.62442 .22054 m .62284 .21835 L .626 .21719 L F
.43194 .22055 m .43321 .21733 L .43499 .21948 L F
.43194 .22055 m .43016 .21843 L .43321 .21733 L F
.31516 .21905 m .31624 .21586 L .31813 .21801 L 0 .027 .127 r
F
.31516 .21905 m .31326 .21688 L .31624 .21586 L F
.23467 .21821 m .23562 .21504 L .23761 .21713 L 0 .026 .125 r
F
.23467 .21821 m .23269 .21611 L .23562 .21504 L F
.75219 .21892 m .75398 .21564 L .75542 .21781 L 0 .027 .126 r
F
.75219 .21892 m .75074 .21674 L .75398 .21564 L F
.27885 .21851 m .27988 .21522 L .28181 .21737 L 0 .026 .125 r
F
.27885 .21851 m .27691 .21637 L .27988 .21522 L F
.35933 .2194 m .36049 .21607 L .36234 .21819 L 0 .028 .127 r
F
.35933 .2194 m .35748 .21727 L .36049 .21607 L F
.68437 .22009 m .68605 .21675 L .68756 .21886 L 0 .029 .129 r
F
.68437 .22009 m .68286 .21801 L .68605 .21675 L F
.36721 .21901 m .36837 .21594 L .37022 .21797 L 0 .028 .127 r
F
.36721 .21901 m .36536 .21698 L .36837 .21594 L F
.47612 .22099 m .47746 .21777 L .47919 .21995 L 0 .031 .132 r
F
.47612 .22099 m .47439 .21882 L .47746 .21777 L F
.19835 .21771 m .19925 .2145 L .20127 .21661 L 0 .025 .124 r
F
.19835 .21771 m .19634 .21558 L .19925 .2145 L F
.39563 .22012 m .39685 .21672 L .39866 .21894 L 0 .029 .129 r
F
.39563 .22012 m .39382 .21792 L .39685 .21672 L F
.69226 .21971 m .69395 .21648 L .69545 .21853 L 0 .029 .128 r
F
.69226 .21971 m .69075 .21763 L .69395 .21648 L F
.52818 .2208 m .52961 .21763 L .53129 .21969 L 0 .031 .131 r
F
.52818 .2208 m .5265 .21876 L .52961 .21763 L F
.80427 .21885 m .80614 .21564 L .80753 .21778 L 0 .027 .126 r
F
.80427 .21885 m .80287 .21672 L .80614 .21564 L F
.63231 .22038 m .6339 .21689 L .63547 .21911 L 0 .03 .13 r
F
.63231 .22038 m .63074 .21816 L .6339 .21689 L F
.56449 .22153 m .56597 .21809 L .56761 .22036 L 0 .032 .133 r
F
.56449 .22153 m .56284 .21928 L .56597 .21809 L F
.24252 .21809 m .24349 .2149 L .24547 .21697 L 0 .026 .125 r
F
.24252 .21809 m .24055 .21603 L .24349 .2149 L F
.70015 .2194 m .70185 .21622 L .70334 .21822 L 0 .028 .128 r
F
.70015 .2194 m .69865 .21738 L .70185 .21622 L F
.6402 .22008 m .6418 .21674 L .64337 .21898 L 0 .029 .129 r
F
.6402 .22008 m .63863 .21784 L .6418 .21674 L F
.28671 .21834 m .28774 .21519 L .28967 .21724 L 0 .026 .125 r
F
.28671 .21834 m .28478 .21628 L .28774 .21519 L F
.32301 .21902 m .3241 .21587 L .326 .21791 L 0 .028 .127 r
F
.32301 .21902 m .32112 .21698 L .3241 .21587 L F
.4035 .21991 m .40473 .21659 L .40654 .21876 L 0 .029 .129 r
F
.4035 .21991 m .4017 .21777 L .40473 .21659 L F
.57237 .22123 m .57387 .21784 L .5755 .21998 L 0 .032 .132 r
F
.57237 .22123 m .57074 .2191 L .57387 .21784 L F
.72379 .21818 m .72554 .21507 L .72701 .21708 L 0 .026 .125 r
F
.72379 .21818 m .72232 .21616 L .72554 .21507 L F
.7601 .21884 m .7619 .21556 L .76334 .21771 L 0 .027 .127 r
F
.7601 .21884 m .75866 .21668 L .7619 .21556 L F
.70803 .21907 m .70975 .21588 L .71124 .2179 L 0 .028 .127 r
F
.70803 .21907 m .70655 .21705 L .70975 .21588 L F
.58025 .22086 m .58177 .21772 L .58339 .21976 L 0 .031 .132 r
F
.58025 .22086 m .57863 .21882 L .58177 .21772 L F
.2062 .21759 m .20711 .2144 L .20912 .21647 L 0 .025 .124 r
F
.2062 .21759 m .20419 .21552 L .20711 .2144 L F
.4398 .22066 m .4411 .21732 L .44286 .2196 L 0 .031 .131 r
F
.4398 .22066 m .43804 .2184 L .4411 .21732 L F
.71592 .21871 m .71764 .21541 L .71912 .21744 L 0 .027 .126 r
F
.71592 .21871 m .71444 .21667 L .71764 .21541 L F
.33088 .21873 m .33199 .21554 L .33388 .21756 L 0 .027 .127 r
F
.33088 .21873 m .32899 .21673 L .33199 .21554 L F
.37507 .21897 m .37625 .21591 L .37808 .21794 L 0 .028 .128 r
F
.37507 .21897 m .37323 .21694 L .37625 .21591 L F
.25038 .21788 m .25136 .21478 L .25332 .21683 L 0 .026 .125 r
F
.25038 .21788 m .24841 .21585 L .25136 .21478 L F
.29457 .21814 m .29562 .21496 L .29755 .21697 L F
.29457 .21814 m .29264 .21612 L .29562 .21496 L F
.768 .21864 m .76981 .2153 L .77123 .2174 L 0 .027 .126 r
F
.768 .21864 m .76657 .21653 L .76981 .2153 L F
.21406 .21734 m .21499 .21412 L .217 .21617 L 0 .025 .123 r
F
.21406 .21734 m .21205 .2153 L .21499 .21412 L F
.33875 .21847 m .33987 .2153 L .34175 .21737 L 0 .027 .126 r
F
.33875 .21847 m .33687 .21643 L .33987 .2153 L F
.41137 .21979 m .41261 .21653 L .41441 .21868 L 0 .029 .129 r
F
.41137 .21979 m .40957 .21763 L .41261 .21653 L F
.53606 .22089 m .5375 .21739 L .53917 .21967 L 0 .031 .132 r
F
.53606 .22089 m .53439 .21858 L .5375 .21739 L F
.77589 .21827 m .77771 .21504 L .77913 .21716 L 0 .027 .126 r
F
.77589 .21827 m .77447 .21616 L .77771 .21504 L F
.58814 .22068 m .58967 .21756 L .59128 .21961 L 0 .031 .132 r
F
.58814 .22068 m .58652 .21865 L .58967 .21756 L F
.30244 .21785 m .3035 .21472 L .30541 .21677 L 0 .026 .125 r
F
.30244 .21785 m .30052 .2158 L .3035 .21472 L F
.48399 .22115 m .48535 .21783 L .48707 .22009 L 0 .032 .133 r
F
.48399 .22115 m .48227 .2189 L .48535 .21783 L F
.6481 .22007 m .64971 .21677 L .65127 .21895 L 0 .03 .13 r
F
.6481 .22007 m .64654 .21789 L .64971 .21677 L F
.7317 .21812 m .73345 .21487 L .73492 .217 L 0 .026 .125 r
F
.7317 .21812 m .73023 .21599 L .73345 .21487 L F
.22192 .21714 m .22285 .21404 L .22485 .2161 L 0 .025 .124 r
F
.22192 .21714 m .21992 .21508 L .22285 .21404 L F
.25823 .21785 m .25922 .21473 L .26118 .2168 L 0 .026 .125 r
F
.25823 .21785 m .25627 .21579 L .25922 .21473 L F
.65599 .21983 m .65762 .2166 L .65916 .21868 L 0 .03 .13 r
F
.65599 .21983 m .65444 .21778 L .65762 .2166 L F
.54395 .22073 m .5454 .21729 L .54706 .21953 L 0 .031 .132 r
F
.54395 .22073 m .54228 .21845 L .5454 .21729 L F
.61179 .2197 m .61336 .21645 L .61494 .21852 L 0 .03 .13 r
F
.61179 .2197 m .6102 .21761 L .61336 .21645 L F
.60391 .22014 m .60546 .21681 L .60705 .21882 L 0 .03 .131 r
F
.60391 .22014 m .60231 .21811 L .60546 .21681 L F
.59603 .22058 m .59757 .21738 L .59917 .21942 L 0 .032 .132 r
F
.59603 .22058 m .59442 .21854 L .59757 .21738 L F
.41924 .21973 m .4205 .21645 L .42228 .21859 L 0 .03 .13 r
F
.41924 .21973 m .41745 .21756 L .4205 .21645 L F
.73961 .21798 m .74136 .2146 L .74282 .21678 L 0 .026 .125 r
F
.73961 .21798 m .73814 .2158 L .74136 .2146 L F
.44767 .22083 m .44897 .21746 L .45073 .21978 L 0 .032 .132 r
F
.44767 .22083 m .44591 .21853 L .44897 .21746 L F
.7838 .21822 m .78564 .21495 L .78705 .21711 L 0 .027 .126 r
F
.7838 .21822 m .78239 .21608 L .78564 .21495 L F
.38292 .2191 m .38412 .21587 L .38594 .21806 L 0 .029 .128 r
F
.38292 .2191 m .3811 .21691 L .38412 .21587 L F
.66388 .21958 m .66552 .21624 L .66706 .21835 L 0 .029 .129 r
F
.66388 .21958 m .66234 .21748 L .66552 .21624 L F
.34661 .21853 m .34775 .21513 L .34961 .21738 L 0 .027 .127 r
F
.34661 .21853 m .34475 .21626 L .34775 .21513 L F
.67176 .21919 m .67343 .21604 L .67495 .21813 L 0 .029 .129 r
F
.67176 .21919 m .67024 .21712 L .67343 .21604 L F
.31029 .21791 m .31137 .21471 L .31326 .21688 L 0 .027 .126 r
F
.31029 .21791 m .30839 .21574 L .31137 .21471 L F
.26609 .21773 m .2671 .21444 L .26905 .21654 L 0 .026 .125 r
F
.26609 .21773 m .26414 .21562 L .2671 .21444 L F
.55183 .22059 m .5533 .21726 L .55495 .21943 L 0 .032 .132 r
F
.55183 .22059 m .55018 .21839 L .5533 .21726 L F
.61969 .21952 m .62126 .21617 L .62284 .21835 L 0 .03 .13 r
F
.61969 .21952 m .6181 .21734 L .62126 .21617 L F
.49187 .22128 m .49324 .21785 L .49495 .22009 L 0 .033 .134 r
F
.49187 .22128 m .49015 .21903 L .49324 .21785 L F
.79171 .218 m .79354 .21461 L .79495 .21677 L 0 .027 .126 r
F
.79171 .218 m .7903 .21586 L .79354 .21461 L F
.50763 .22041 m .50903 .21705 L .51073 .21915 L 0 .031 .132 r
F
.50763 .22041 m .50593 .21831 L .50903 .21705 L F
.51552 .21999 m .51693 .21684 L .51861 .21892 L 0 .031 .131 r
F
.51552 .21999 m .51383 .21793 L .51693 .21684 L F
.49975 .22088 m .50113 .21747 L .50284 .21957 L 0 .032 .133 r
F
.49975 .22088 m .49804 .21878 L .50113 .21747 L F
.22976 .21717 m .2307 .21401 L .23269 .21611 L 0 .025 .124 r
F
.22976 .21717 m .22777 .21507 L .2307 .21401 L F
.74751 .21783 m .74929 .21459 L .75074 .21674 L 0 .027 .126 r
F
.74751 .21783 m .74605 .21567 L .74929 .21459 L F
.42711 .21958 m .42838 .21632 L .43016 .21843 L 0 .03 .13 r
F
.42711 .21958 m .42533 .21745 L .42838 .21632 L F
.47131 .21991 m .47265 .21681 L .47439 .21882 L 0 .031 .131 r
F
.47131 .21991 m .46957 .21792 L .47265 .21681 L F
.45555 .22079 m .45686 .21735 L .45861 .21956 L 0 .032 .133 r
F
.45555 .22079 m .45379 .21857 L .45686 .21735 L F
.27395 .21752 m .27498 .21422 L .27691 .21637 L 0 .026 .125 r
F
.27395 .21752 m .27201 .21537 L .27498 .21422 L F
.46343 .22038 m .46475 .21713 L .4665 .21915 L 0 .032 .132 r
F
.46343 .22038 m .46168 .21834 L .46475 .21713 L F
.79961 .21779 m .80147 .21455 L .80287 .21672 L 0 .027 .126 r
F
.79961 .21779 m .79821 .21563 L .80147 .21455 L F
.35447 .21846 m .35563 .21506 L .35748 .21727 L 0 .028 .127 r
F
.35447 .21846 m .35262 .21623 L .35563 .21506 L F
.39079 .21912 m .39201 .21568 L .39382 .21792 L 0 .029 .129 r
F
.39079 .21912 m .38897 .21689 L .39201 .21568 L F
.19342 .21672 m .19432 .21344 L .19634 .21558 L 0 .025 .123 r
F
.19342 .21672 m .1914 .2146 L .19432 .21344 L F
.67967 .21914 m .68134 .21592 L .68286 .21801 L 0 .029 .129 r
F
.67967 .21914 m .67815 .21707 L .68134 .21592 L F
.55972 .22045 m .5612 .21704 L .56284 .21928 L 0 .032 .132 r
F
.55972 .22045 m .55807 .21824 L .5612 .21704 L F
.62758 .21938 m .62916 .21598 L .63074 .21816 L 0 .03 .13 r
F
.62758 .21938 m .626 .21719 L .62916 .21598 L F
.5234 .21987 m .52482 .21671 L .5265 .21876 L 0 .031 .131 r
F
.5234 .21987 m .52172 .21784 L .52482 .21671 L F
.43499 .21948 m .43627 .21623 L .43804 .2184 L 0 .03 .13 r
F
.43499 .21948 m .43321 .21733 L .43627 .21623 L F
.36234 .21819 m .36351 .21487 L .36536 .21698 L 0 .028 .127 r
F
.36234 .21819 m .36049 .21607 L .36351 .21487 L F
.68756 .21886 m .68924 .2155 L .69075 .21763 L 0 .029 .129 r
F
.68756 .21886 m .68605 .21675 L .68924 .2155 L F
.23761 .21713 m .23856 .21395 L .24055 .21603 L 0 .026 .125 r
F
.23761 .21713 m .23562 .21504 L .23856 .21395 L F
.31813 .21801 m .31922 .21483 L .32112 .21698 L 0 .028 .127 r
F
.31813 .21801 m .31624 .21586 L .31922 .21483 L F
.63547 .21911 m .63706 .21561 L .63863 .21784 L 0 .029 .129 r
F
.63547 .21911 m .6339 .21689 L .63706 .21561 L F
.28181 .21737 m .28285 .21414 L .28478 .21628 L 0 .026 .125 r
F
.28181 .21737 m .27988 .21522 L .28285 .21414 L F
.75542 .21781 m .75721 .21452 L .75866 .21668 L 0 .027 .126 r
F
.75542 .21781 m .75398 .21564 L .75721 .21452 L F
.39866 .21894 m .39989 .21553 L .4017 .21777 L 0 .029 .129 r
F
.39866 .21894 m .39685 .21672 L .39989 .21553 L F
.69545 .21853 m .69715 .21534 L .69865 .21738 L 0 .029 .128 r
F
.69545 .21853 m .69395 .21648 L .69715 .21534 L F
.20127 .21661 m .20217 .21342 L .20419 .21552 L 0 .025 .124 r
F
.20127 .21661 m .19925 .2145 L .20217 .21342 L F
.53129 .21969 m .53272 .2165 L .53439 .21858 L 0 .031 .131 r
F
.53129 .21969 m .52961 .21763 L .53272 .2165 L F
.56761 .22036 m .5691 .21682 L .57074 .2191 L 0 .032 .132 r
F
.56761 .22036 m .56597 .21809 L .5691 .21682 L F
.37022 .21797 m .37139 .2149 L .37323 .21694 L 0 .028 .127 r
F
.37022 .21797 m .36837 .21594 L .37139 .2149 L F
.47919 .21995 m .48054 .21671 L .48227 .2189 L 0 .031 .132 r
F
.47919 .21995 m .47746 .21777 L .48054 .21671 L F
.70334 .21822 m .70506 .21505 L .70655 .21705 L 0 .028 .128 r
F
.70334 .21822 m .70185 .21622 L .70506 .21505 L F
.5755 .21998 m .577 .21669 L .57863 .21882 L 0 .031 .132 r
F
.5755 .21998 m .57387 .21784 L .577 .21669 L F
.24547 .21697 m .24644 .21377 L .24841 .21585 L 0 .026 .125 r
F
.24547 .21697 m .24349 .2149 L .24644 .21377 L F
.71912 .21744 m .72085 .21415 L .72232 .21616 L 0 .027 .126 r
F
.71912 .21744 m .71764 .21541 L .72085 .21415 L F
.40654 .21876 m .40777 .21547 L .40957 .21763 L 0 .029 .129 r
F
.40654 .21876 m .40473 .21659 L .40777 .21547 L F
.64337 .21898 m .64498 .21566 L .64654 .21789 L 0 .03 .13 r
F
.64337 .21898 m .6418 .21674 L .64498 .21566 L F
.28967 .21724 m .29071 .21408 L .29264 .21612 L 0 .026 .126 r
F
.28967 .21724 m .28774 .21519 L .29071 .21408 L F
.71124 .2179 m .71296 .21466 L .71444 .21667 L 0 .028 .127 r
F
.71124 .2179 m .70975 .21588 L .71296 .21466 L F
.326 .21791 m .3271 .21468 L .32899 .21673 L F
.326 .21791 m .3241 .21587 L .3271 .21468 L F
.76334 .21771 m .76514 .21439 L .76657 .21653 L 0 .027 .126 r
F
.76334 .21771 m .7619 .21556 L .76514 .21439 L F
.72701 .21708 m .72877 .21398 L .73023 .21599 L 0 .026 .125 r
F
.72701 .21708 m .72554 .21507 L .72877 .21398 L F
.33388 .21756 m .33499 .21439 L .33687 .21643 L 0 .027 .127 r
F
.33388 .21756 m .33199 .21554 L .33499 .21439 L F
.20912 .21647 m .21004 .21324 L .21205 .2153 L 0 .025 .124 r
F
.20912 .21647 m .20711 .2144 L .21004 .21324 L F
.58339 .21976 m .58491 .21662 L .58652 .21865 L 0 .032 .132 r
F
.58339 .21976 m .58177 .21772 L .58491 .21662 L F
.77123 .2174 m .77304 .21406 L .77447 .21616 L 0 .027 .126 r
F
.77123 .2174 m .76981 .2153 L .77304 .21406 L F
.44286 .2196 m .44415 .21624 L .44591 .21853 L 0 .031 .131 r
F
.44286 .2196 m .4411 .21732 L .44415 .21624 L F
.29755 .21697 m .2986 .2138 L .30052 .2158 L 0 .026 .125 r
F
.29755 .21697 m .29562 .21496 L .2986 .2138 L F
.53917 .21967 m .54062 .21621 L .54228 .21845 L 0 .031 .131 r
F
.53917 .21967 m .5375 .21739 L .54062 .21621 L F
.217 .21617 m .21792 .21302 L .21992 .21508 L 0 .025 .123 r
F
.217 .21617 m .21499 .21412 L .21792 .21302 L F
.25332 .21683 m .2543 .21373 L .25627 .21579 L 0 .026 .125 r
F
.25332 .21683 m .25136 .21478 L .2543 .21373 L F
.37808 .21794 m .37926 .21488 L .3811 .21691 L 0 .028 .128 r
F
.37808 .21794 m .37625 .21591 L .37926 .21488 L F
.41441 .21868 m .41566 .21543 L .41745 .21756 L 0 .03 .13 r
F
.41441 .21868 m .41261 .21653 L .41566 .21543 L F
.34175 .21737 m .34288 .21418 L .34475 .21626 L 0 .027 .126 r
F
.34175 .21737 m .33987 .2153 L .34288 .21418 L F
.77913 .21716 m .78097 .21394 L .78239 .21608 L F
.77913 .21716 m .77771 .21504 L .78097 .21394 L F
.59128 .21961 m .59281 .21647 L .59442 .21854 L 0 .032 .132 r
F
.59128 .21961 m .58967 .21756 L .59281 .21647 L F
.65127 .21895 m .65289 .21559 L .65444 .21778 L 0 .03 .13 r
F
.65127 .21895 m .64971 .21677 L .65289 .21559 L F
.30541 .21677 m .30648 .21367 L .30839 .21574 L 0 .026 .125 r
F
.30541 .21677 m .3035 .21472 L .30648 .21367 L F
.73492 .217 m .73668 .21366 L .73814 .2158 L F
.73492 .217 m .73345 .21487 L .73668 .21366 L F
.48707 .22009 m .48843 .21676 L .49015 .21903 L 0 .032 .133 r
F
.48707 .22009 m .48535 .21783 L .48843 .21676 L F
.60705 .21882 m .60861 .21561 L .6102 .21761 L 0 .03 .13 r
F
.60705 .21882 m .60546 .21681 L .60861 .21561 L F
.54706 .21953 m .54852 .21619 L .55018 .21839 L 0 .031 .132 r
F
.54706 .21953 m .5454 .21729 L .54852 .21619 L F
.65916 .21868 m .6608 .21537 L .66234 .21748 L 0 .03 .13 r
F
.65916 .21868 m .65762 .2166 L .6608 .21537 L F
.22485 .2161 m .22578 .21299 L .22777 .21507 L 0 .025 .124 r
F
.22485 .2161 m .22285 .21404 L .22578 .21299 L F
.61494 .21852 m .61651 .21528 L .6181 .21734 L 0 .03 .13 r
F
.61494 .21852 m .61336 .21645 L .61651 .21528 L F
.74282 .21678 m .74459 .2135 L .74605 .21567 L 0 .026 .125 r
F
.74282 .21678 m .74136 .2146 L .74459 .2135 L F
.59917 .21942 m .60071 .21609 L .60231 .21811 L 0 .031 .132 r
F
.59917 .21942 m .59757 .21738 L .60071 .21609 L F
.26118 .2168 m .26218 .21355 L .26414 .21562 L 0 .026 .125 r
F
.26118 .2168 m .25922 .21473 L .26218 .21355 L F
.66706 .21835 m .6687 .215 L .67024 .21712 L 0 .029 .129 r
F
.66706 .21835 m .66552 .21624 L .6687 .215 L F
.42228 .21859 m .42355 .21534 L .42533 .21745 L 0 .03 .13 r
F
.42228 .21859 m .4205 .21645 L .42355 .21534 L F
.78705 .21711 m .78888 .2137 L .7903 .21586 L 0 .027 .126 r
F
.78705 .21711 m .78564 .21495 L .78888 .2137 L F
.45073 .21978 m .45204 .21627 L .45379 .21857 L 0 .032 .132 r
F
.45073 .21978 m .44897 .21746 L .45204 .21627 L F
.34961 .21738 m .35076 .214 L .35262 .21623 L 0 .027 .127 r
F
.34961 .21738 m .34775 .21513 L .35076 .214 L F
.50284 .21957 m .50423 .2162 L .50593 .21831 L 0 .032 .132 r
F
.50284 .21957 m .50113 .21747 L .50423 .2162 L F
.51073 .21915 m .51213 .21583 L .51383 .21793 L 0 .031 .131 r
F
.51073 .21915 m .50903 .21705 L .51213 .21583 L F
.38594 .21806 m .38715 .2147 L .38897 .21689 L 0 .029 .129 r
F
.38594 .21806 m .38412 .21587 L .38715 .2147 L F
.26905 .21654 m .27007 .21326 L .27201 .21537 L 0 .026 .125 r
F
.26905 .21654 m .2671 .21444 L .27007 .21326 L F
.79495 .21677 m .7968 .21346 L .79821 .21563 L 0 .026 .126 r
F
.79495 .21677 m .79354 .21461 L .7968 .21346 L F
.55495 .21943 m .55642 .21606 L .55807 .21824 L 0 .032 .132 r
F
.55495 .21943 m .5533 .21726 L .55642 .21606 L F
.49495 .22009 m .49633 .21657 L .49804 .21878 L 0 .033 .133 r
F
.49495 .22009 m .49324 .21785 L .49633 .21657 L F
.67495 .21813 m .67662 .21496 L .67815 .21707 L 0 .029 .129 r
F
.67495 .21813 m .67343 .21604 L .67662 .21496 L F
.62284 .21835 m .62442 .215 L .626 .21719 L F
.62284 .21835 m .62126 .21617 L .62442 .215 L F
.31326 .21688 m .31435 .2137 L .31624 .21586 L 0 .027 .126 r
F
.31326 .21688 m .31137 .21471 L .31435 .2137 L F
.43016 .21843 m .43144 .21518 L .43321 .21733 L 0 .03 .13 r
F
.43016 .21843 m .42838 .21632 L .43144 .21518 L F
.45861 .21956 m .45993 .21615 L .46168 .21834 L 0 .032 .132 r
F
.45861 .21956 m .45686 .21735 L .45993 .21615 L F
.51861 .21892 m .52003 .21574 L .52172 .21784 L 0 .031 .131 r
F
.51861 .21892 m .51693 .21684 L .52003 .21574 L F
.75074 .21674 m .75253 .21351 L .75398 .21564 L 0 .027 .126 r
F
.75074 .21674 m .74929 .21459 L .75253 .21351 L F
.4665 .21915 m .46783 .21592 L .46957 .21792 L 0 .031 .132 r
F
.4665 .21915 m .46475 .21713 L .46783 .21592 L F
.23269 .21611 m .23364 .21296 L .23562 .21504 L 0 .026 .125 r
F
.23269 .21611 m .2307 .21401 L .23364 .21296 L F
.27691 .21637 m .27795 .21306 L .27988 .21522 L F
.27691 .21637 m .27498 .21422 L .27795 .21306 L F
.39382 .21792 m .39504 .21446 L .39685 .21672 L 0 .029 .129 r
F
.39382 .21792 m .39201 .21568 L .39504 .21446 L F
.35748 .21727 m .35864 .21388 L .36049 .21607 L 0 .028 .127 r
F
.35748 .21727 m .35563 .21506 L .35864 .21388 L F
.47439 .21882 m .47573 .21574 L .47746 .21777 L 0 .031 .132 r
F
.47439 .21882 m .47265 .21681 L .47573 .21574 L F
.63074 .21816 m .63232 .21471 L .6339 .21689 L 0 .029 .129 r
F
.63074 .21816 m .62916 .21598 L .63232 .21471 L F
.56284 .21928 m .56433 .21582 L .56597 .21809 L 0 .031 .132 r
F
.56284 .21928 m .5612 .21704 L .56433 .21582 L F
.19634 .21558 m .19723 .21238 L .19925 .2145 L 0 .025 .123 r
F
.19634 .21558 m .19432 .21344 L .19723 .21238 L F
.68286 .21801 m .68453 .21464 L .68605 .21675 L 0 .029 .129 r
F
.68286 .21801 m .68134 .21592 L .68453 .21464 L F
.80287 .21672 m .80474 .21346 L .80614 .21564 L 0 .027 .126 r
F
.80287 .21672 m .80147 .21455 L .80474 .21346 L F
.63863 .21784 m .64023 .21452 L .6418 .21674 L 0 .029 .129 r
F
.63863 .21784 m .63706 .21561 L .64023 .21452 L F
.69075 .21763 m .69244 .21434 L .69395 .21648 L 0 .029 .128 r
F
.69075 .21763 m .68924 .2155 L .69244 .21434 L F
.36536 .21698 m .36653 .21382 L .36837 .21594 L 0 .028 .127 r
F
.36536 .21698 m .36351 .21487 L .36653 .21382 L F
.5265 .21876 m .52793 .21556 L .52961 .21763 L 0 .031 .131 r
F
.5265 .21876 m .52482 .21671 L .52793 .21556 L F
.43804 .2184 m .43933 .21512 L .4411 .21732 L 0 .03 .13 r
F
.43804 .2184 m .43627 .21623 L .43933 .21512 L F
.4017 .21777 m .40293 .21434 L .40473 .21659 L 0 .029 .129 r
F
.4017 .21777 m .39989 .21553 L .40293 .21434 L F
.24055 .21603 m .24151 .21282 L .24349 .2149 L 0 .026 .125 r
F
.24055 .21603 m .23856 .21395 L .24151 .21282 L F
.75866 .21668 m .76045 .2134 L .7619 .21556 L 0 .027 .126 r
F
.75866 .21668 m .75721 .21452 L .76045 .2134 L F
.57074 .2191 m .57223 .21555 L .57387 .21784 L 0 .031 .132 r
F
.57074 .2191 m .5691 .21682 L .57223 .21555 L F
.28478 .21628 m .28581 .21306 L .28774 .21519 L 0 .026 .125 r
F
.28478 .21628 m .28285 .21414 L .28581 .21306 L F
.69865 .21738 m .70036 .2142 L .70185 .21622 L 0 .029 .128 r
F
.69865 .21738 m .69715 .21534 L .70036 .2142 L F
.32112 .21698 m .32221 .21373 L .3241 .21587 L 0 .028 .127 r
F
.32112 .21698 m .31922 .21483 L .32221 .21373 L F
.72232 .21616 m .72407 .21305 L .72554 .21507 L 0 .026 .126 r
F
.72232 .21616 m .72085 .21415 L .72407 .21305 L F
.53439 .21858 m .53583 .21532 L .5375 .21739 L 0 .031 .131 r
F
.53439 .21858 m .53272 .2165 L .53583 .21532 L F
.20419 .21552 m .20509 .21233 L .20711 .2144 L 0 .025 .124 r
F
.20419 .21552 m .20217 .21342 L .20509 .21233 L F
.70655 .21705 m .70827 .21388 L .70975 .21588 L 0 .028 .128 r
F
.70655 .21705 m .70506 .21505 L .70827 .21388 L F
.57863 .21882 m .58014 .21559 L .58177 .21772 L 0 .031 .132 r
F
.57863 .21882 m .577 .21669 L .58014 .21559 L F
.71444 .21667 m .71617 .21339 L .71764 .21541 L 0 .027 .127 r
F
.71444 .21667 m .71296 .21466 L .71617 .21339 L F
.48227 .2189 m .48363 .21562 L .48535 .21783 L 0 .032 .132 r
F
.48227 .2189 m .48054 .21671 L .48363 .21562 L F
.37323 .21694 m .3744 .21387 L .37625 .21591 L 0 .028 .128 r
F
.37323 .21694 m .37139 .2149 L .3744 .21387 L F
.24841 .21585 m .24939 .21269 L .25136 .21478 L 0 .026 .125 r
F
.24841 .21585 m .24644 .21377 L .24939 .21269 L F
.32899 .21673 m .3301 .21348 L .33199 .21554 L 0 .027 .127 r
F
.32899 .21673 m .3271 .21468 L .3301 .21348 L F
.76657 .21653 m .76837 .21318 L .76981 .2153 L 0 .027 .126 r
F
.76657 .21653 m .76514 .21439 L .76837 .21318 L F
.40957 .21763 m .41081 .21438 L .41261 .21653 L 0 .029 .129 r
F
.40957 .21763 m .40777 .21547 L .41081 .21438 L F
.29264 .21612 m .29369 .21294 L .29562 .21496 L 0 .026 .126 r
F
.29264 .21612 m .29071 .21408 L .29369 .21294 L F
.64654 .21789 m .64816 .21456 L .64971 .21677 L 0 .03 .13 r
F
.64654 .21789 m .64498 .21566 L .64816 .21456 L F
.77447 .21616 m .77629 .21294 L .77771 .21504 L 0 .027 .126 r
F
.77447 .21616 m .77304 .21406 L .77629 .21294 L F
.21205 .2153 m .21298 .21207 L .21499 .21412 L 0 .025 .124 r
F
.21205 .2153 m .21004 .21324 L .21298 .21207 L F
.33687 .21643 m .338 .21324 L .33987 .2153 L 0 .027 .127 r
F
.33687 .21643 m .33499 .21439 L .338 .21324 L F
.73023 .21599 m .73199 .21285 L .73345 .21487 L 0 .026 .126 r
F
.73023 .21599 m .72877 .21398 L .73199 .21285 L F
.58652 .21865 m .58805 .21551 L .58967 .21756 L 0 .032 .132 r
F
.58652 .21865 m .58491 .21662 L .58805 .21551 L F
.30052 .2158 m .30158 .2127 L .3035 .21472 L 0 .026 .125 r
F
.30052 .2158 m .2986 .2138 L .30158 .2127 L F
.54228 .21845 m .54374 .21507 L .5454 .21729 L 0 .031 .131 r
F
.54228 .21845 m .54062 .21621 L .54374 .21507 L F
.44591 .21853 m .44722 .21515 L .44897 .21746 L 0 .031 .132 r
F
.44591 .21853 m .44415 .21624 L .44722 .21515 L F
.21992 .21508 m .22085 .21197 L .22285 .21404 L 0 .025 .124 r
F
.21992 .21508 m .21792 .21302 L .22085 .21197 L F
.25627 .21579 m .25725 .21266 L .25922 .21473 L 0 .026 .125 r
F
.25627 .21579 m .2543 .21373 L .25725 .21266 L F
.73814 .2158 m .7399 .21246 L .74136 .2146 L F
.73814 .2158 m .73668 .21366 L .7399 .21246 L F
.65444 .21778 m .65607 .21442 L .65762 .2166 L 0 .03 .13 r
F
.65444 .21778 m .65289 .21559 L .65607 .21442 L F
.41745 .21756 m .4187 .21434 L .4205 .21645 L F
.41745 .21756 m .41566 .21543 L .4187 .21434 L F
.3811 .21691 m .38229 .21384 L .38412 .21587 L 0 .029 .128 r
F
.3811 .21691 m .37926 .21488 L .38229 .21384 L F
.34475 .21626 m .34588 .21306 L .34775 .21513 L 0 .027 .127 r
F
.34475 .21626 m .34288 .21418 L .34588 .21306 L F
.78239 .21608 m .78422 .2128 L .78564 .21495 L 0 .027 .126 r
F
.78239 .21608 m .78097 .21394 L .78422 .2128 L F
.6102 .21761 m .61177 .21445 L .61336 .21645 L 0 .03 .13 r
F
.6102 .21761 m .60861 .21561 L .61177 .21445 L F
.59442 .21854 m .59596 .2153 L .59757 .21738 L 0 .032 .132 r
F
.59442 .21854 m .59281 .21647 L .59596 .2153 L F
.60231 .21811 m .60386 .2148 L .60546 .21681 L 0 .031 .131 r
F
.60231 .21811 m .60071 .21609 L .60386 .2148 L F
.66234 .21748 m .66398 .21412 L .66552 .21624 L 0 .029 .129 r
F
.66234 .21748 m .6608 .21537 L .66398 .21412 L F
.30839 .21574 m .30946 .21262 L .31137 .21471 L 0 .027 .126 r
F
.30839 .21574 m .30648 .21367 L .30946 .21262 L F
.49015 .21903 m .49152 .21559 L .49324 .21785 L 0 .032 .133 r
F
.49015 .21903 m .48843 .21676 L .49152 .21559 L F
.55018 .21839 m .55164 .21509 L .5533 .21726 L 0 .031 .132 r
F
.55018 .21839 m .54852 .21619 L .55164 .21509 L F
.6181 .21734 m .61967 .21409 L .62126 .21617 L 0 .029 .129 r
F
.6181 .21734 m .61651 .21528 L .61967 .21409 L F
.67024 .21712 m .67189 .2139 L .67343 .21604 L F
.67024 .21712 m .6687 .215 L .67189 .2139 L F
.26414 .21562 m .26514 .21236 L .2671 .21444 L 0 .026 .125 r
F
.26414 .21562 m .26218 .21355 L .26514 .21236 L F
.7903 .21586 m .79213 .21244 L .79354 .21461 L 0 .026 .126 r
F
.7903 .21586 m .78888 .2137 L .79213 .21244 L F
.74605 .21567 m .74783 .21244 L .74929 .21459 L 0 .026 .125 r
F
.74605 .21567 m .74459 .2135 L .74783 .21244 L F
.50593 .21831 m .50733 .21494 L .50903 .21705 L 0 .031 .132 r
F
.50593 .21831 m .50423 .2162 L .50733 .21494 L F
.42533 .21745 m .4266 .21421 L .42838 .21632 L 0 .03 .13 r
F
.42533 .21745 m .42355 .21534 L .4266 .21421 L F
.49804 .21878 m .49943 .21529 L .50113 .21747 L 0 .032 .133 r
F
.49804 .21878 m .49633 .21657 L .49943 .21529 L F
.22777 .21507 m .22871 .21194 L .2307 .21401 L 0 .026 .124 r
F
.22777 .21507 m .22578 .21299 L .22871 .21194 L F
.45379 .21857 m .45511 .21507 L .45686 .21735 L 0 .032 .132 r
F
.45379 .21857 m .45204 .21627 L .45511 .21507 L F
.51383 .21793 m .51523 .2147 L .51693 .21684 L 0 .031 .131 r
F
.51383 .21793 m .51213 .21583 L .51523 .2147 L F
.35262 .21623 m .35377 .21285 L .35563 .21506 L 0 .027 .127 r
F
.35262 .21623 m .35076 .214 L .35377 .21285 L F
.38897 .21689 m .39019 .21347 L .39201 .21568 L 0 .029 .128 r
F
.38897 .21689 m .38715 .2147 L .39019 .21347 L F
.27201 .21537 m .27303 .21209 L .27498 .21422 L 0 .026 .125 r
F
.27201 .21537 m .27007 .21326 L .27303 .21209 L F
.55807 .21824 m .55955 .21485 L .5612 .21704 L 0 .031 .132 r
F
.55807 .21824 m .55642 .21606 L .55955 .21485 L F
.79821 .21563 m .80007 .21237 L .80147 .21455 L 0 .026 .126 r
F
.79821 .21563 m .7968 .21346 L .80007 .21237 L F
.626 .21719 m .62758 .21379 L .62916 .21598 L 0 .029 .129 r
F
.626 .21719 m .62442 .215 L .62758 .21379 L F
.46168 .21834 m .46301 .21496 L .46475 .21713 L 0 .032 .132 r
F
.46168 .21834 m .45993 .21615 L .46301 .21496 L F
.46957 .21792 m .47091 .21481 L .47265 .21681 L 0 .031 .132 r
F
.46957 .21792 m .46783 .21592 L .47091 .21481 L F
.67815 .21707 m .67982 .21379 L .68134 .21592 L 0 .029 .129 r
F
.67815 .21707 m .67662 .21496 L .67982 .21379 L F
.6339 .21689 m .63549 .21345 L .63706 .21561 L F
.6339 .21689 m .63232 .21471 L .63549 .21345 L F
.43321 .21733 m .43449 .21405 L .43627 .21623 L 0 .03 .13 r
F
.43321 .21733 m .43144 .21518 L .43449 .21405 L F
.39685 .21672 m .39808 .21326 L .39989 .21553 L 0 .028 .128 r
F
.39685 .21672 m .39504 .21446 L .39808 .21326 L F
.36049 .21607 m .36166 .2127 L .36351 .21487 L 0 .027 .127 r
F
.36049 .21607 m .35864 .21388 L .36166 .2127 L F
.31624 .21586 m .31733 .21268 L .31922 .21483 L F
.31624 .21586 m .31435 .2137 L .31733 .21268 L F
.75398 .21564 m .75577 .21239 L .75721 .21452 L 0 .027 .126 r
F
.75398 .21564 m .75253 .21351 L .75577 .21239 L F
.52172 .21784 m .52314 .21459 L .52482 .21671 L 0 .031 .131 r
F
.52172 .21784 m .52003 .21574 L .52314 .21459 L F
.27988 .21522 m .28091 .212 L .28285 .21414 L 0 .026 .125 r
F
.27988 .21522 m .27795 .21306 L .28091 .212 L F
.68605 .21675 m .68772 .21337 L .68924 .2155 L 0 .029 .129 r
F
.68605 .21675 m .68453 .21464 L .68772 .21337 L F
.56597 .21809 m .56746 .21454 L .5691 .21682 L 0 .031 .131 r
F
.56597 .21809 m .56433 .21582 L .56746 .21454 L F
.23562 .21504 m .23658 .21187 L .23856 .21395 L 0 .026 .125 r
F
.23562 .21504 m .23364 .21296 L .23658 .21187 L F
.47746 .21777 m .47881 .21467 L .48054 .21671 L 0 .031 .132 r
F
.47746 .21777 m .47573 .21574 L .47881 .21467 L F
.19925 .2145 m .20015 .21132 L .20217 .21342 L 0 .025 .124 r
F
.19925 .2145 m .19723 .21238 L .20015 .21132 L F
.69395 .21648 m .69564 .21319 L .69715 .21534 L 0 .029 .128 r
F
.69395 .21648 m .69244 .21434 L .69564 .21319 L F
.6418 .21674 m .64341 .21346 L .64498 .21566 L 0 .029 .129 r
F
.6418 .21674 m .64023 .21452 L .64341 .21346 L F
.57387 .21784 m .57537 .21439 L .577 .21669 L 0 .031 .131 r
F
.57387 .21784 m .57223 .21555 L .57537 .21439 L F
.52961 .21763 m .53104 .21441 L .53272 .2165 L F
.52961 .21763 m .52793 .21556 L .53104 .21441 L F
.40473 .21659 m .40597 .2132 L .40777 .21547 L 0 .029 .129 r
F
.40473 .21659 m .40293 .21434 L .40597 .2132 L F
.36837 .21594 m .36954 .21277 L .37139 .2149 L 0 .028 .127 r
F
.36837 .21594 m .36653 .21382 L .36954 .21277 L F
.24349 .2149 m .24446 .21168 L .24644 .21377 L 0 .026 .125 r
F
.24349 .2149 m .24151 .21282 L .24446 .21168 L F
.7619 .21556 m .7637 .21225 L .76514 .21439 L 0 .027 .126 r
F
.7619 .21556 m .76045 .2134 L .7637 .21225 L F
.70185 .21622 m .70356 .21303 L .70506 .21505 L 0 .028 .128 r
F
.70185 .21622 m .70036 .2142 L .70356 .21303 L F
.4411 .21732 m .44239 .214 L .44415 .21624 L 0 .03 .131 r
F
.4411 .21732 m .43933 .21512 L .44239 .214 L F
.28774 .21519 m .28879 .21197 L .29071 .21408 L 0 .027 .126 r
F
.28774 .21519 m .28581 .21306 L .28879 .21197 L F
.71764 .21541 m .71938 .21213 L .72085 .21415 L F
.71764 .21541 m .71617 .21339 L .71938 .21213 L F
.5375 .21739 m .53895 .21414 L .54062 .21621 L 0 .031 .131 r
F
.5375 .21739 m .53583 .21532 L .53895 .21414 L F
.3241 .21587 m .32522 .21253 L .3271 .21468 L 0 .028 .127 r
F
.3241 .21587 m .32221 .21373 L .32522 .21253 L F
.70975 .21588 m .71148 .21265 L .71296 .21466 L F
.70975 .21588 m .70827 .21388 L .71148 .21265 L F
.20711 .2144 m .20802 .21118 L .21004 .21324 L 0 .025 .124 r
F
.20711 .2144 m .20509 .21233 L .20802 .21118 L F
.72554 .21507 m .7273 .21196 L .72877 .21398 L 0 .027 .126 r
F
.72554 .21507 m .72407 .21305 L .7273 .21196 L F
.76981 .2153 m .77162 .21197 L .77304 .21406 L F
.76981 .2153 m .76837 .21318 L .77162 .21197 L F
.58177 .21772 m .58328 .2145 L .58491 .21662 L 0 .032 .132 r
F
.58177 .21772 m .58014 .21559 L .58328 .2145 L F
.33199 .21554 m .33311 .21231 L .33499 .21439 L 0 .027 .127 r
F
.33199 .21554 m .3301 .21348 L .33311 .21231 L F
.29562 .21496 m .29667 .21179 L .2986 .2138 L 0 .026 .126 r
F
.29562 .21496 m .29369 .21294 L .29667 .21179 L F
.48535 .21783 m .48671 .21453 L .48843 .21676 L 0 .032 .132 r
F
.48535 .21783 m .48363 .21562 L .48671 .21453 L F
.21499 .21412 m .21591 .21097 L .21792 .21302 L 0 .025 .124 r
F
.21499 .21412 m .21298 .21207 L .21591 .21097 L F
.41261 .21653 m .41386 .2133 L .41566 .21543 L 0 .029 .129 r
F
.41261 .21653 m .41081 .21438 L .41386 .2133 L F
.25136 .21478 m .25233 .21163 L .2543 .21373 L 0 .026 .125 r
F
.25136 .21478 m .24939 .21269 L .25233 .21163 L F
.64971 .21677 m .65133 .21339 L .65289 .21559 L 0 .03 .13 r
F
.64971 .21677 m .64816 .21456 L .65133 .21339 L F
.37625 .21591 m .37742 .21284 L .37926 .21488 L 0 .028 .128 r
F
.37625 .21591 m .3744 .21387 L .37742 .21284 L F
.77771 .21504 m .77955 .21184 L .78097 .21394 L 0 .027 .126 r
F
.77771 .21504 m .77629 .21294 L .77955 .21184 L F
.33987 .2153 m .341 .2121 L .34288 .21418 L 0 .027 .127 r
F
.33987 .2153 m .338 .21324 L .341 .2121 L F
.73345 .21487 m .73522 .21163 L .73668 .21366 L 0 .026 .125 r
F
.73345 .21487 m .73199 .21285 L .73522 .21163 L F
.5454 .21729 m .54686 .214 L .54852 .21619 L 0 .031 .131 r
F
.5454 .21729 m .54374 .21507 L .54686 .214 L F
.58967 .21756 m .5912 .2144 L .59281 .21647 L 0 .032 .132 r
F
.58967 .21756 m .58805 .21551 L .5912 .2144 L F
.3035 .21472 m .30456 .21163 L .30648 .21367 L 0 .026 .125 r
F
.3035 .21472 m .30158 .2127 L .30456 .21163 L F
.74136 .2146 m .74314 .21136 L .74459 .2135 L F
.74136 .2146 m .7399 .21246 L .74314 .21136 L F
.44897 .21746 m .45029 .21396 L .45204 .21627 L 0 .031 .132 r
F
.44897 .21746 m .44722 .21515 L .45029 .21396 L F
.60546 .21681 m .60702 .21361 L .60861 .21561 L 0 .03 .131 r
F
.60546 .21681 m .60386 .2148 L .60702 .21361 L F
.65762 .2166 m .65925 .21321 L .6608 .21537 L 0 .03 .13 r
F
.65762 .2166 m .65607 .21442 L .65925 .21321 L F
.34775 .21513 m .34889 .21195 L .35076 .214 L 0 .027 .127 r
F
.34775 .21513 m .34588 .21306 L .34889 .21195 L F
.61336 .21645 m .61493 .21329 L .61651 .21528 L 0 .03 .13 r
F
.61336 .21645 m .61177 .21445 L .61493 .21329 L F
.22285 .21404 m .22378 .21092 L .22578 .21299 L 0 .025 .124 r
F
.22285 .21404 m .22085 .21197 L .22378 .21092 L F
.4205 .21645 m .42175 .21324 L .42355 .21534 L 0 .03 .13 r
F
.4205 .21645 m .4187 .21434 L .42175 .21324 L F
.66552 .21624 m .66717 .21288 L .6687 .215 L 0 .029 .129 r
F
.66552 .21624 m .66398 .21412 L .66717 .21288 L F
.25922 .21473 m .26022 .21147 L .26218 .21355 L 0 .026 .125 r
F
.25922 .21473 m .25725 .21266 L .26022 .21147 L F
.78564 .21495 m .78747 .21153 L .78888 .2137 L 0 .027 .126 r
F
.78564 .21495 m .78422 .2128 L .78747 .21153 L F
.59757 .21738 m .59911 .214 L .60071 .21609 L 0 .031 .132 r
F
.59757 .21738 m .59596 .2153 L .59911 .214 L F
.38412 .21587 m .38532 .21267 L .38715 .2147 L 0 .029 .128 r
F
.38412 .21587 m .38229 .21384 L .38532 .21267 L F
.49324 .21785 m .49462 .21435 L .49633 .21657 L 0 .032 .133 r
F
.49324 .21785 m .49152 .21559 L .49462 .21435 L F
.79354 .21461 m .79539 .21129 L .7968 .21346 L 0 .026 .125 r
F
.79354 .21461 m .79213 .21244 L .79539 .21129 L F
.50113 .21747 m .50252 .21406 L .50423 .2162 L 0 .032 .132 r
F
.50113 .21747 m .49943 .21529 L .50252 .21406 L F
.5533 .21726 m .55477 .21389 L .55642 .21606 L 0 .031 .132 r
F
.5533 .21726 m .55164 .21509 L .55477 .21389 L F
.62126 .21617 m .62284 .21289 L .62442 .215 L 0 .029 .129 r
F
.62126 .21617 m .61967 .21409 L .62284 .21289 L F
.50903 .21705 m .51043 .21371 L .51213 .21583 L 0 .031 .131 r
F
.50903 .21705 m .50733 .21494 L .51043 .21371 L F
.2671 .21444 m .26811 .21118 L .27007 .21326 L 0 .026 .125 r
F
.2671 .21444 m .26514 .21236 L .26811 .21118 L F
.31137 .21471 m .31244 .2116 L .31435 .2137 L 0 .027 .126 r
F
.31137 .21471 m .30946 .21262 L .31244 .2116 L F
.45686 .21735 m .45818 .21388 L .45993 .21615 L 0 .031 .132 r
F
.45686 .21735 m .45511 .21507 L .45818 .21388 L F
.67343 .21604 m .67509 .21279 L .67662 .21496 L 0 .029 .129 r
F
.67343 .21604 m .67189 .2139 L .67509 .21279 L F
.42838 .21632 m .42965 .21305 L .43144 .21518 L 0 .03 .13 r
F
.42838 .21632 m .4266 .21421 L .42965 .21305 L F
.39201 .21568 m .39323 .21224 L .39504 .21446 L 0 .028 .128 r
F
.39201 .21568 m .39019 .21347 L .39323 .21224 L F
.74929 .21459 m .75108 .21138 L .75253 .21351 L 0 .027 .126 r
F
.74929 .21459 m .74783 .21244 L .75108 .21138 L F
.35563 .21506 m .35679 .21169 L .35864 .21388 L 0 .027 .127 r
F
.35563 .21506 m .35377 .21285 L .35679 .21169 L F
.5612 .21704 m .56268 .21362 L .56433 .21582 L 0 .031 .131 r
F
.5612 .21704 m .55955 .21485 L .56268 .21362 L F
.51693 .21684 m .51834 .21357 L .52003 .21574 L F
.51693 .21684 m .51523 .2147 L .51834 .21357 L F
.27498 .21422 m .27601 .21092 L .27795 .21306 L 0 .026 .125 r
F
.27498 .21422 m .27303 .21209 L .27601 .21092 L F
.62916 .21598 m .63075 .21254 L .63232 .21471 L 0 .029 .129 r
F
.62916 .21598 m .62758 .21379 L .63075 .21254 L F
.2307 .21401 m .23165 .21089 L .23364 .21296 L 0 .026 .125 r
F
.2307 .21401 m .22871 .21194 L .23165 .21089 L F
.46475 .21713 m .46609 .21377 L .46783 .21592 L 0 .031 .132 r
F
.46475 .21713 m .46301 .21496 L .46609 .21377 L F
.63706 .21561 m .63867 .21238 L .64023 .21452 L 0 .029 .128 r
F
.63706 .21561 m .63549 .21345 L .63867 .21238 L F
.80147 .21455 m .80334 .21128 L .80474 .21346 L 0 .027 .126 r
F
.80147 .21455 m .80007 .21237 L .80334 .21128 L F
.68134 .21592 m .68301 .2125 L .68453 .21464 L 0 .029 .129 r
F
.68134 .21592 m .67982 .21379 L .68301 .2125 L F
.47265 .21681 m .47399 .21372 L .47573 .21574 L 0 .031 .132 r
F
.47265 .21681 m .47091 .21481 L .47399 .21372 L F
.68924 .2155 m .69092 .21219 L .69244 .21434 L 0 .028 .128 r
F
.68924 .2155 m .68772 .21337 L .69092 .21219 L F
.5691 .21682 m .57059 .21325 L .57223 .21555 L 0 .031 .131 r
F
.5691 .21682 m .56746 .21454 L .57059 .21325 L F
.39989 .21553 m .40113 .21205 L .40293 .21434 L 0 .028 .128 r
F
.39989 .21553 m .39808 .21326 L .40113 .21205 L F
.36351 .21487 m .36468 .21163 L .36653 .21382 L 0 .027 .127 r
F
.36351 .21487 m .36166 .2127 L .36468 .21163 L F
.43627 .21623 m .43756 .21291 L .43933 .21512 L 0 .03 .13 r
F
.43627 .21623 m .43449 .21405 L .43756 .21291 L F
.75721 .21452 m .75901 .21128 L .76045 .2134 L 0 .027 .126 r
F
.75721 .21452 m .75577 .21239 L .75901 .21128 L F
.52482 .21671 m .52625 .21341 L .52793 .21556 L 0 .031 .131 r
F
.52482 .21671 m .52314 .21459 L .52625 .21341 L F
.28285 .21414 m .28388 .21094 L .28581 .21306 L 0 .026 .125 r
F
.28285 .21414 m .28091 .212 L .28388 .21094 L F
.23856 .21395 m .23953 .21073 L .24151 .21282 L F
.23856 .21395 m .23658 .21187 L .23953 .21073 L F
.31922 .21483 m .32032 .21158 L .32221 .21373 L 0 .028 .127 r
F
.31922 .21483 m .31733 .21268 L .32032 .21158 L F
.69715 .21534 m .69885 .21204 L .70036 .2142 L 0 .029 .128 r
F
.69715 .21534 m .69564 .21319 L .69885 .21204 L F
.577 .21669 m .57851 .21332 L .58014 .21559 L 0 .031 .131 r
F
.577 .21669 m .57537 .21439 L .57851 .21332 L F
.20217 .21342 m .20307 .21024 L .20509 .21233 L 0 .025 .124 r
F
.20217 .21342 m .20015 .21132 L .20307 .21024 L F
.48054 .21671 m .4819 .21355 L .48363 .21562 L 0 .032 .132 r
F
.48054 .21671 m .47881 .21467 L .4819 .21355 L F
.53272 .2165 m .53416 .21324 L .53583 .21532 L 0 .031 .131 r
F
.53272 .2165 m .53104 .21441 L .53416 .21324 L F
.64498 .21566 m .64659 .21237 L .64816 .21456 L 0 .029 .129 r
F
.64498 .21566 m .64341 .21346 L .64659 .21237 L F
.72085 .21415 m .7226 .21102 L .72407 .21305 L 0 .027 .126 r
F
.72085 .21415 m .71938 .21213 L .7226 .21102 L F
.40777 .21547 m .40902 .21213 L .41081 .21438 L 0 .029 .129 r
F
.40777 .21547 m .40597 .2132 L .40902 .21213 L F
.76514 .21439 m .76694 .21107 L .76837 .21318 L 0 .027 .126 r
F
.76514 .21439 m .7637 .21225 L .76694 .21107 L F
.70506 .21505 m .70678 .21186 L .70827 .21388 L 0 .028 .128 r
F
.70506 .21505 m .70356 .21303 L .70678 .21186 L F
.24644 .21377 m .24741 .21059 L .24939 .21269 L 0 .026 .125 r
F
.24644 .21377 m .24446 .21168 L .24741 .21059 L F
.71296 .21466 m .71468 .21138 L .71617 .21339 L 0 .028 .127 r
F
.71296 .21466 m .71148 .21265 L .71468 .21138 L F
.54062 .21621 m .54207 .21301 L .54374 .21507 L 0 .031 .131 r
F
.54062 .21621 m .53895 .21414 L .54207 .21301 L F
.3271 .21468 m .32822 .21132 L .3301 .21348 L 0 .027 .127 r
F
.3271 .21468 m .32522 .21253 L .32822 .21132 L F
.37139 .2149 m .37256 .21172 L .3744 .21387 L 0 .028 .128 r
F
.37139 .2149 m .36954 .21277 L .37256 .21172 L F
.44415 .21624 m .44545 .21288 L .44722 .21515 L 0 .03 .131 r
F
.44415 .21624 m .44239 .214 L .44545 .21288 L F
.77304 .21406 m .77487 .21087 L .77629 .21294 L 0 .027 .126 r
F
.77304 .21406 m .77162 .21197 L .77487 .21087 L F
.29071 .21408 m .29176 .21084 L .29369 .21294 L F
.29071 .21408 m .28879 .21197 L .29176 .21084 L F
.21004 .21324 m .21096 .21003 L .21298 .21207 L 0 .025 .124 r
F
.21004 .21324 m .20802 .21118 L .21096 .21003 L F
.33499 .21439 m .33611 .21114 L .338 .21324 L 0 .027 .127 r
F
.33499 .21439 m .33311 .21231 L .33611 .21114 L F
.72877 .21398 m .73053 .21083 L .73199 .21285 L 0 .027 .126 r
F
.72877 .21398 m .7273 .21196 L .73053 .21083 L F
.58491 .21662 m .58643 .21338 L .58805 .21551 L 0 .032 .132 r
F
.58491 .21662 m .58328 .2145 L .58643 .21338 L F
.2986 .2138 m .29965 .21068 L .30158 .2127 L 0 .026 .126 r
F
.2986 .2138 m .29667 .21179 L .29965 .21068 L F
.65289 .21559 m .65452 .21221 L .65607 .21442 L 0 .029 .129 r
F
.65289 .21559 m .65133 .21339 L .65452 .21221 L F
.73668 .21366 m .73844 .21041 L .7399 .21246 L 0 .026 .125 r
F
.73668 .21366 m .73522 .21163 L .73844 .21041 L F
.41566 .21543 m .41691 .21222 L .4187 .21434 L 0 .029 .129 r
F
.41566 .21543 m .41386 .2133 L .41691 .21222 L F
.21792 .21302 m .21884 .20991 L .22085 .21197 L 0 .025 .124 r
F
.21792 .21302 m .21591 .21097 L .21884 .20991 L F
.48843 .21676 m .4898 .21338 L .49152 .21559 L 0 .032 .132 r
F
.48843 .21676 m .48671 .21453 L .4898 .21338 L F
.78097 .21394 m .78281 .2107 L .78422 .2128 L 0 .027 .126 r
F
.78097 .21394 m .77955 .21184 L .78281 .2107 L F
.2543 .21373 m .25529 .21054 L .25725 .21266 L 0 .026 .125 r
F
.2543 .21373 m .25233 .21163 L .25529 .21054 L F
.34288 .21418 m .34401 .211 L .34588 .21306 L 0 .027 .127 r
F
.34288 .21418 m .341 .2121 L .34401 .211 L F
.54852 .21619 m .54999 .21293 L .55164 .21509 L 0 .031 .131 r
F
.54852 .21619 m .54686 .214 L .54999 .21293 L F
.37926 .21488 m .38045 .21181 L .38229 .21384 L 0 .029 .129 r
F
.37926 .21488 m .37742 .21284 L .38045 .21181 L F
.6608 .21537 m .66244 .21199 L .66398 .21412 L F
.6608 .21537 m .65925 .21321 L .66244 .21199 L F
.59281 .21647 m .59435 .21322 L .59596 .2153 L 0 .032 .132 r
F
.59281 .21647 m .5912 .2144 L .59435 .21322 L F
.45204 .21627 m .45336 .21278 L .45511 .21507 L 0 .031 .131 r
F
.45204 .21627 m .45029 .21396 L .45336 .21278 L F
.60861 .21561 m .61017 .21246 L .61177 .21445 L 0 .03 .13 r
F
.60861 .21561 m .60702 .21361 L .61017 .21246 L F
.30648 .21367 m .30754 .21056 L .30946 .21262 L 0 .027 .126 r
F
.30648 .21367 m .30456 .21163 L .30754 .21056 L F
.60071 .21609 m .60226 .2127 L .60386 .2148 L 0 .031 .131 r
F
.60071 .21609 m .59911 .214 L .60226 .2127 L F
.6687 .215 m .67036 .21175 L .67189 .2139 L 0 .029 .129 r
F
.6687 .215 m .66717 .21288 L .67036 .21175 L F
.78888 .2137 m .79072 .21027 L .79213 .21244 L 0 .026 .125 r
F
.78888 .2137 m .78747 .21153 L .79072 .21027 L F
.74459 .2135 m .74638 .21031 L .74783 .21244 L F
.74459 .2135 m .74314 .21136 L .74638 .21031 L F
.49633 .21657 m .49771 .2131 L .49943 .21529 L 0 .032 .132 r
F
.49633 .21657 m .49462 .21435 L .49771 .2131 L F
.61651 .21528 m .61809 .21207 L .61967 .21409 L 0 .03 .13 r
F
.61651 .21528 m .61493 .21329 L .61809 .21207 L F
.26218 .21355 m .26319 .21029 L .26514 .21236 L 0 .026 .125 r
F
.26218 .21355 m .26022 .21147 L .26319 .21029 L F
.35076 .214 m .35191 .21082 L .35377 .21285 L 0 .027 .127 r
F
.35076 .214 m .34889 .21195 L .35191 .21082 L F
.50423 .2162 m .50562 .21284 L .50733 .21494 L 0 .031 .132 r
F
.50423 .2162 m .50252 .21406 L .50562 .21284 L F
.42355 .21534 m .42481 .21212 L .4266 .21421 L 0 .03 .13 r
F
.42355 .21534 m .42175 .21324 L .42481 .21212 L F
.38715 .2147 m .38836 .21144 L .39019 .21347 L 0 .028 .128 r
F
.38715 .2147 m .38532 .21267 L .38836 .21144 L F
.51213 .21583 m .51354 .21256 L .51523 .2147 L 0 .031 .131 r
F
.51213 .21583 m .51043 .21371 L .51354 .21256 L F
.55642 .21606 m .5579 .21267 L .55955 .21485 L F
.55642 .21606 m .55477 .21389 L .5579 .21267 L F
.22578 .21299 m .22671 .20987 L .22871 .21194 L 0 .026 .124 r
F
.22578 .21299 m .22378 .21092 L .22671 .20987 L F
.7968 .21346 m .79866 .2102 L .80007 .21237 L 0 .026 .125 r
F
.7968 .21346 m .79539 .21129 L .79866 .2102 L F
.62442 .215 m .626 .21167 L .62758 .21379 L 0 .029 .129 r
F
.62442 .215 m .62284 .21289 L .626 .21167 L F
.27007 .21326 m .27109 .20999 L .27303 .21209 L 0 .026 .125 r
F
.27007 .21326 m .26811 .21118 L .27109 .20999 L F
.45993 .21615 m .46126 .21271 L .46301 .21496 L 0 .031 .132 r
F
.45993 .21615 m .45818 .21388 L .46126 .21271 L F
.39504 .21446 m .39627 .21102 L .39808 .21326 L 0 .028 .128 r
F
.39504 .21446 m .39323 .21224 L .39627 .21102 L F
.63232 .21471 m .63392 .21129 L .63549 .21345 L 0 .029 .128 r
F
.63232 .21471 m .63075 .21254 L .63392 .21129 L F
.56433 .21582 m .56581 .21235 L .56746 .21454 L 0 .031 .131 r
F
.56433 .21582 m .56268 .21362 L .56581 .21235 L F
.67662 .21496 m .67829 .2116 L .67982 .21379 L 0 .029 .129 r
F
.67662 .21496 m .67509 .21279 L .67829 .2116 L F
.43144 .21518 m .43272 .21189 L .43449 .21405 L 0 .03 .13 r
F
.43144 .21518 m .42965 .21305 L .43272 .21189 L F
.35864 .21388 m .35981 .21053 L .36166 .2127 L 0 .027 .126 r
F
.35864 .21388 m .35679 .21169 L .35981 .21053 L F
.31435 .2137 m .31543 .21057 L .31733 .21268 L 0 .027 .127 r
F
.31435 .2137 m .31244 .2116 L .31543 .21057 L F
.27795 .21306 m .27897 .20986 L .28091 .212 L 0 .026 .125 r
F
.27795 .21306 m .27601 .21092 L .27897 .20986 L F
.75253 .21351 m .75432 .21027 L .75577 .21239 L 0 .027 .126 r
F
.75253 .21351 m .75108 .21138 L .75432 .21027 L F
.46783 .21592 m .46917 .21264 L .47091 .21481 L 0 .031 .132 r
F
.46783 .21592 m .46609 .21377 L .46917 .21264 L F
.68453 .21464 m .6862 .2112 L .68772 .21337 L 0 .029 .128 r
F
.68453 .21464 m .68301 .2125 L .6862 .2112 L F
.52003 .21574 m .52145 .21239 L .52314 .21459 L 0 .031 .131 r
F
.52003 .21574 m .51834 .21357 L .52145 .21239 L F
.57223 .21555 m .57373 .2121 L .57537 .21439 L 0 .03 .131 r
F
.57223 .21555 m .57059 .21325 L .57373 .2121 L F
.23364 .21296 m .23459 .20979 L .23658 .21187 L 0 .026 .125 r
F
.23364 .21296 m .23165 .21089 L .23459 .20979 L F
.64023 .21452 m .64185 .21134 L .64341 .21346 L 0 .029 .129 r
F
.64023 .21452 m .63867 .21238 L .64185 .21134 L F
.40293 .21434 m .40417 .21092 L .40597 .2132 L 0 .028 .128 r
F
.40293 .21434 m .40113 .21205 L .40417 .21092 L F
.69244 .21434 m .69413 .21104 L .69564 .21319 L F
.69244 .21434 m .69092 .21219 L .69413 .21104 L F
.47573 .21574 m .47707 .21262 L .47881 .21467 L 0 .032 .132 r
F
.47573 .21574 m .47399 .21372 L .47707 .21262 L F
.43933 .21512 m .44062 .21176 L .44239 .214 L 0 .03 .13 r
F
.43933 .21512 m .43756 .21291 L .44062 .21176 L F
.52793 .21556 m .52936 .21223 L .53104 .21441 L 0 .031 .131 r
F
.52793 .21556 m .52625 .21341 L .52936 .21223 L F
.36653 .21382 m .3677 .21056 L .36954 .21277 L 0 .028 .127 r
F
.36653 .21382 m .36468 .21163 L .3677 .21056 L F
.76045 .2134 m .76226 .21014 L .7637 .21225 L 0 .027 .126 r
F
.76045 .2134 m .75901 .21128 L .76226 .21014 L F
.24151 .21282 m .24248 .20958 L .24446 .21168 L 0 .026 .125 r
F
.24151 .21282 m .23953 .21073 L .24248 .20958 L F
.28581 .21306 m .28685 .20986 L .28879 .21197 L 0 .026 .126 r
F
.28581 .21306 m .28388 .21094 L .28685 .20986 L F
.32221 .21373 m .32332 .21037 L .32522 .21253 L 0 .027 .127 r
F
.32221 .21373 m .32032 .21158 L .32332 .21037 L F
.70036 .2142 m .70206 .21085 L .70356 .21303 L 0 .028 .128 r
F
.70036 .2142 m .69885 .21204 L .70206 .21085 L F
.53583 .21532 m .53728 .21207 L .53895 .21414 L 0 .031 .131 r
F
.53583 .21532 m .53416 .21324 L .53728 .21207 L F
.71617 .21339 m .7179 .2101 L .71938 .21213 L 0 .027 .126 r
F
.71617 .21339 m .71468 .21138 L .7179 .2101 L F
.58014 .21559 m .58165 .21224 L .58328 .2145 L 0 .031 .132 r
F
.58014 .21559 m .57851 .21332 L .58165 .21224 L F
.76837 .21318 m .77019 .20988 L .77162 .21197 L 0 .027 .126 r
F
.76837 .21318 m .76694 .21107 L .77019 .20988 L F
.20509 .21233 m .206 .20911 L .20802 .21118 L 0 .025 .124 r
F
.20509 .21233 m .20307 .21024 L .206 .20911 L F
.48363 .21562 m .48499 .21244 L .48671 .21453 L 0 .032 .132 r
F
.48363 .21562 m .4819 .21355 L .48499 .21244 L F
.70827 .21388 m .70999 .21062 L .71148 .21265 L 0 .028 .128 r
F
.70827 .21388 m .70678 .21186 L .70999 .21062 L F
.64816 .21456 m .64978 .2112 L .65133 .21339 L 0 .029 .129 r
F
.64816 .21456 m .64659 .21237 L .64978 .2112 L F
.3301 .21348 m .33123 .21013 L .33311 .21231 L 0 .027 .127 r
F
.3301 .21348 m .32822 .21132 L .33123 .21013 L F
.72407 .21305 m .72583 .20992 L .7273 .21196 L 0 .027 .126 r
F
.72407 .21305 m .7226 .21102 L .72583 .20992 L F
.41081 .21438 m .41206 .21106 L .41386 .2133 L 0 .029 .129 r
F
.41081 .21438 m .40902 .21213 L .41206 .21106 L F
.54374 .21507 m .5452 .21194 L .54686 .214 L 0 .031 .131 r
F
.54374 .21507 m .54207 .21301 L .5452 .21194 L F
.24939 .21269 m .25036 .20951 L .25233 .21163 L 0 .026 .125 r
F
.24939 .21269 m .24741 .21059 L .25036 .20951 L F
.29369 .21294 m .29475 .20971 L .29667 .21179 L 0 .027 .126 r
F
.29369 .21294 m .29176 .21084 L .29475 .20971 L F
.77629 .21294 m .77813 .20978 L .77955 .21184 L F
.77629 .21294 m .77487 .21087 L .77813 .20978 L F
.21298 .21207 m .21389 .20893 L .21591 .21097 L 0 .025 .124 r
F
.21298 .21207 m .21096 .21003 L .21389 .20893 L F
.44722 .21515 m .44852 .21173 L .45029 .21396 L 0 .03 .131 r
F
.44722 .21515 m .44545 .21288 L .44852 .21173 L F
.3744 .21387 m .37559 .21069 L .37742 .21284 L 0 .028 .128 r
F
.3744 .21387 m .37256 .21172 L .37559 .21069 L F
.338 .21324 m .33912 .20999 L .341 .2121 L 0 .027 .127 r
F
.338 .21324 m .33611 .21114 L .33912 .20999 L F
.73199 .21285 m .73375 .20959 L .73522 .21163 L 0 .027 .126 r
F
.73199 .21285 m .73053 .21083 L .73375 .20959 L F
.58805 .21551 m .58958 .21226 L .5912 .2144 L 0 .032 .132 r
F
.58805 .21551 m .58643 .21338 L .58958 .21226 L F
.65607 .21442 m .6577 .21103 L .65925 .21321 L 0 .029 .129 r
F
.65607 .21442 m .65452 .21221 L .6577 .21103 L F
.7399 .21246 m .74168 .2093 L .74314 .21136 L 0 .026 .125 r
F
.7399 .21246 m .73844 .21041 L .74168 .2093 L F
.30158 .2127 m .30264 .20959 L .30456 .21163 L 0 .027 .126 r
F
.30158 .2127 m .29965 .21068 L .30264 .20959 L F
.49152 .21559 m .4929 .21216 L .49462 .21435 L 0 .032 .132 r
F
.49152 .21559 m .4898 .21338 L .4929 .21216 L F
.78422 .2128 m .78606 .20943 L .78747 .21153 L 0 .026 .126 r
F
.78422 .2128 m .78281 .2107 L .78606 .20943 L F
.4187 .21434 m .41996 .21114 L .42175 .21324 L 0 .03 .13 r
F
.4187 .21434 m .41691 .21222 L .41996 .21114 L F
.66398 .21412 m .66563 .21076 L .66717 .21288 L 0 .029 .129 r
F
.66398 .21412 m .66244 .21199 L .66563 .21076 L F
.60386 .2148 m .60541 .21151 L .60702 .21361 L 0 .03 .131 r
F
.60386 .2148 m .60226 .2127 L .60541 .21151 L F
.34588 .21306 m .34702 .2099 L .34889 .21195 L 0 .027 .127 r
F
.34588 .21306 m .34401 .211 L .34702 .2099 L F
.22085 .21197 m .22177 .20885 L .22378 .21092 L 0 .025 .124 r
F
.22085 .21197 m .21884 .20991 L .22177 .20885 L F
.25725 .21266 m .25825 .20937 L .26022 .21147 L 0 .026 .125 r
F
.25725 .21266 m .25529 .21054 L .25825 .20937 L F
.45511 .21507 m .45643 .21161 L .45818 .21388 L 0 .031 .131 r
F
.45511 .21507 m .45336 .21278 L .45643 .21161 L F
.49943 .21529 m .50081 .21192 L .50252 .21406 L 0 .031 .132 r
F
.49943 .21529 m .49771 .2131 L .50081 .21192 L F
.79213 .21244 m .79398 .20911 L .79539 .21129 L 0 .026 .125 r
F
.79213 .21244 m .79072 .21027 L .79398 .20911 L F
.59596 .2153 m .5975 .21191 L .59911 .214 L 0 .031 .132 r
F
.59596 .2153 m .59435 .21322 L .5975 .21191 L F
.55164 .21509 m .55311 .21173 L .55477 .21389 L 0 .031 .131 r
F
.55164 .21509 m .54999 .21293 L .55311 .21173 L F
.61177 .21445 m .61334 .21129 L .61493 .21329 L 0 .03 .13 r
F
.61177 .21445 m .61017 .21246 L .61334 .21129 L F
.38229 .21384 m .38348 .21063 L .38532 .21267 L 0 .029 .129 r
F
.38229 .21384 m .38045 .21181 L .38348 .21063 L F
.50733 .21494 m .50873 .21163 L .51043 .21371 L 0 .031 .131 r
F
.50733 .21494 m .50562 .21284 L .50873 .21163 L F
.61967 .21409 m .62125 .21085 L .62284 .21289 L 0 .029 .129 r
F
.61967 .21409 m .61809 .21207 L .62125 .21085 L F
.67189 .2139 m .67356 .21061 L .67509 .21279 L F
.67189 .2139 m .67036 .21175 L .67356 .21061 L F
.26514 .21236 m .26616 .20909 L .26811 .21118 L 0 .026 .125 r
F
.26514 .21236 m .26319 .21029 L .26616 .20909 L F
.39019 .21347 m .3914 .2102 L .39323 .21224 L 0 .028 .128 r
F
.39019 .21347 m .38836 .21144 L .3914 .2102 L F
.30946 .21262 m .31053 .20952 L .31244 .2116 L 0 .027 .126 r
F
.30946 .21262 m .30754 .21056 L .31053 .20952 L F
.35377 .21285 m .35492 .20967 L .35679 .21169 L F
.35377 .21285 m .35191 .21082 L .35492 .20967 L F
.55955 .21485 m .56103 .21144 L .56268 .21362 L 0 .031 .131 r
F
.55955 .21485 m .5579 .21267 L .56103 .21144 L F
.74783 .21244 m .74962 .20925 L .75108 .21138 L 0 .026 .126 r
F
.74783 .21244 m .74638 .21031 L .74962 .20925 L F
.4266 .21421 m .42787 .21094 L .42965 .21305 L 0 .03 .13 r
F
.4266 .21421 m .42481 .21212 L .42787 .21094 L F
.62758 .21379 m .62917 .21042 L .63075 .21254 L 0 .029 .129 r
F
.62758 .21379 m .626 .21167 L .62917 .21042 L F
.51523 .2147 m .51665 .2114 L .51834 .21357 L 0 .031 .131 r
F
.51523 .2147 m .51354 .21256 L .51665 .2114 L F
.27303 .21209 m .27406 .2088 L .27601 .21092 L 0 .026 .125 r
F
.27303 .21209 m .27109 .20999 L .27406 .2088 L F
.46301 .21496 m .46434 .21154 L .46609 .21377 L 0 .031 .131 r
F
.46301 .21496 m .46126 .21271 L .46434 .21154 L F
.56746 .21454 m .56895 .21107 L .57059 .21325 L 0 .03 .13 r
F
.56746 .21454 m .56581 .21235 L .56895 .21107 L F
.63549 .21345 m .6371 .21024 L .63867 .21238 L 0 .028 .128 r
F
.63549 .21345 m .63392 .21129 L .6371 .21024 L F
.80007 .21237 m .80194 .20911 L .80334 .21128 L 0 .026 .125 r
F
.80007 .21237 m .79866 .2102 L .80194 .20911 L F
.39808 .21326 m .39932 .2098 L .40113 .21205 L 0 .028 .127 r
F
.39808 .21326 m .39627 .21102 L .39932 .2098 L F
.22871 .21194 m .22965 .20882 L .23165 .21089 L 0 .026 .125 r
F
.22871 .21194 m .22671 .20987 L .22965 .20882 L F
.67982 .21379 m .68148 .2103 L .68301 .2125 L 0 .029 .129 r
F
.67982 .21379 m .67829 .2116 L .68148 .2103 L F
.36166 .2127 m .36283 .20944 L .36468 .21163 L 0 .027 .126 r
F
.36166 .2127 m .35981 .21053 L .36283 .20944 L F
.68772 .21337 m .68941 .21002 L .69092 .21219 L 0 .028 .128 r
F
.68772 .21337 m .6862 .2112 L .68941 .21002 L F
.43449 .21405 m .43578 .21072 L .43756 .21291 L 0 .03 .13 r
F
.43449 .21405 m .43272 .21189 L .43578 .21072 L F
.75577 .21239 m .75757 .20916 L .75901 .21128 L 0 .027 .126 r
F
.75577 .21239 m .75432 .21027 L .75757 .20916 L F
.47091 .21481 m .47225 .21153 L .47399 .21372 L 0 .031 .132 r
F
.47091 .21481 m .46917 .21264 L .47225 .21153 L F
.52314 .21459 m .52456 .21118 L .52625 .21341 L 0 .031 .131 r
F
.52314 .21459 m .52145 .21239 L .52456 .21118 L F
.57537 .21439 m .57687 .21103 L .57851 .21332 L 0 .03 .131 r
F
.57537 .21439 m .57373 .2121 L .57687 .21103 L F
.28091 .212 m .28194 .20881 L .28388 .21094 L 0 .026 .125 r
F
.28091 .212 m .27897 .20986 L .28194 .20881 L F
.31733 .21268 m .31842 .20947 L .32032 .21158 L 0 .027 .127 r
F
.31733 .21268 m .31543 .21057 L .31842 .20947 L F
.23658 .21187 m .23754 .20863 L .23953 .21073 L 0 .026 .125 r
F
.23658 .21187 m .23459 .20979 L .23754 .20863 L F
.69564 .21319 m .69734 .20988 L .69885 .21204 L 0 .028 .128 r
F
.69564 .21319 m .69413 .21104 L .69734 .20988 L F
.40597 .2132 m .40721 .20986 L .40902 .21213 L F
.40597 .2132 m .40417 .21092 L .40721 .20986 L F
.64341 .21346 m .64503 .21026 L .64659 .21237 L 0 .029 .129 r
F
.64341 .21346 m .64185 .21134 L .64503 .21026 L F
.53104 .21441 m .53248 .21107 L .53416 .21324 L 0 .031 .131 r
F
.53104 .21441 m .52936 .21223 L .53248 .21107 L F
.44239 .214 m .44369 .21061 L .44545 .21288 L 0 .03 .13 r
F
.44239 .214 m .44062 .21176 L .44369 .21061 L F
.7637 .21225 m .76551 .20899 L .76694 .21107 L 0 .027 .126 r
F
.7637 .21225 m .76226 .21014 L .76551 .20899 L F
.47881 .21467 m .48016 .21148 L .4819 .21355 L 0 .032 .132 r
F
.47881 .21467 m .47707 .21262 L .48016 .21148 L F
.32522 .21253 m .32633 .20916 L .32822 .21132 L 0 .027 .127 r
F
.32522 .21253 m .32332 .21037 L .32633 .20916 L F
.36954 .21277 m .37072 .20949 L .37256 .21172 L 0 .028 .127 r
F
.36954 .21277 m .3677 .21056 L .37072 .20949 L F
.24446 .21168 m .24544 .20848 L .24741 .21059 L 0 .026 .125 r
F
.24446 .21168 m .24248 .20958 L .24544 .20848 L F
.71938 .21213 m .72112 .20899 L .7226 .21102 L 0 .027 .126 r
F
.71938 .21213 m .7179 .2101 L .72112 .20899 L F
.70356 .21303 m .70527 .20966 L .70678 .21186 L 0 .028 .128 r
F
.70356 .21303 m .70206 .21085 L .70527 .20966 L F
.53895 .21414 m .5404 .21095 L .54207 .21301 L 0 .031 .131 r
F
.53895 .21414 m .53728 .21207 L .5404 .21095 L F
.28879 .21197 m .28983 .20875 L .29176 .21084 L 0 .027 .126 r
F
.28879 .21197 m .28685 .20986 L .28983 .20875 L F
.77162 .21197 m .77345 .20879 L .77487 .21087 L F
.77162 .21197 m .77019 .20988 L .77345 .20879 L F
.71148 .21265 m .7132 .20935 L .71468 .21138 L 0 .028 .127 r
F
.71148 .21265 m .70999 .21062 L .7132 .20935 L F
.20802 .21118 m .20894 .20798 L .21096 .21003 L 0 .025 .124 r
F
.20802 .21118 m .206 .20911 L .20894 .20798 L F
.65133 .21339 m .65296 .21003 L .65452 .21221 L 0 .029 .129 r
F
.65133 .21339 m .64978 .2112 L .65296 .21003 L F
.33311 .21231 m .33423 .20895 L .33611 .21114 L 0 .027 .126 r
F
.33311 .21231 m .33123 .21013 L .33423 .20895 L F
.58328 .2145 m .5848 .21111 L .58643 .21338 L 0 .031 .132 r
F
.58328 .2145 m .58165 .21224 L .5848 .21111 L F
.48671 .21453 m .48808 .21128 L .4898 .21338 L 0 .032 .132 r
F
.48671 .21453 m .48499 .21244 L .48808 .21128 L F
.7273 .21196 m .72906 .20878 L .73053 .21083 L 0 .027 .126 r
F
.7273 .21196 m .72583 .20992 L .72906 .20878 L F
.41386 .2133 m .41511 .20999 L .41691 .21222 L 0 .029 .129 r
F
.41386 .2133 m .41206 .21106 L .41511 .20999 L F
.45029 .21396 m .4516 .21059 L .45336 .21278 L 0 .03 .131 r
F
.45029 .21396 m .44852 .21173 L .4516 .21059 L F
.29667 .21179 m .29773 .2086 L .29965 .21068 L 0 .027 .126 r
F
.29667 .21179 m .29475 .20971 L .29773 .2086 L F
.54686 .214 m .54832 .21086 L .54999 .21293 L 0 .031 .131 r
F
.54686 .214 m .5452 .21194 L .54832 .21086 L F
.77955 .21184 m .78139 .20865 L .78281 .2107 L 0 .027 .126 r
F
.77955 .21184 m .77813 .20978 L .78139 .20865 L F
.25233 .21163 m .25332 .20842 L .25529 .21054 L 0 .026 .125 r
F
.25233 .21163 m .25036 .20951 L .25332 .20842 L F
.73522 .21163 m .73698 .20836 L .73844 .21041 L F
.73522 .21163 m .73375 .20959 L .73698 .20836 L F
.21591 .21097 m .21683 .20786 L .21884 .20991 L 0 .025 .124 r
F
.21591 .21097 m .21389 .20893 L .21683 .20786 L F
.341 .2121 m .34213 .2089 L .34401 .211 L 0 .027 .127 r
F
.341 .2121 m .33912 .20999 L .34213 .2089 L F
.65925 .21321 m .66089 .20984 L .66244 .21199 L 0 .029 .129 r
F
.65925 .21321 m .6577 .21103 L .66089 .20984 L F
.49462 .21435 m .496 .21095 L .49771 .2131 L 0 .031 .132 r
F
.49462 .21435 m .4929 .21216 L .496 .21095 L F
.37742 .21284 m .37861 .20965 L .38045 .21181 L 0 .029 .129 r
F
.37742 .21284 m .37559 .21069 L .37861 .20965 L F
.78747 .21153 m .78931 .20817 L .79072 .21027 L 0 .026 .125 r
F
.78747 .21153 m .78606 .20943 L .78931 .20817 L F
.5912 .2144 m .59273 .21107 L .59435 .21322 L 0 .032 .132 r
F
.5912 .2144 m .58958 .21226 L .59273 .21107 L F
.66717 .21288 m .66882 .20965 L .67036 .21175 L 0 .029 .129 r
F
.66717 .21288 m .66563 .21076 L .66882 .20965 L F
.74314 .21136 m .74492 .20823 L .74638 .21031 L 0 .026 .125 r
F
.74314 .21136 m .74168 .2093 L .74492 .20823 L F
.59911 .214 m .60065 .21061 L .60226 .2127 L 0 .031 .131 r
F
.59911 .214 m .5975 .21191 L .60065 .21061 L F
.30456 .21163 m .30563 .20849 L .30754 .21056 L 0 .027 .126 r
F
.30456 .21163 m .30264 .20959 L .30563 .20849 L F
.60702 .21361 m .60858 .21034 L .61017 .21246 L 0 .03 .131 r
F
.60702 .21361 m .60541 .21151 L .60858 .21034 L F
.50252 .21406 m .50392 .21073 L .50562 .21284 L 0 .031 .131 r
F
.50252 .21406 m .50081 .21192 L .50392 .21073 L F
.45818 .21388 m .45951 .21046 L .46126 .21271 L F
.45818 .21388 m .45643 .21161 L .45951 .21046 L F
.26022 .21147 m .26122 .2082 L .26319 .21029 L 0 .026 .125 r
F
.26022 .21147 m .25825 .20937 L .26122 .2082 L F
.55477 .21389 m .55624 .21049 L .5579 .21267 L 0 .031 .131 r
F
.55477 .21389 m .55311 .21173 L .55624 .21049 L F
.42175 .21324 m .42302 .21002 L .42481 .21212 L 0 .03 .13 r
F
.42175 .21324 m .41996 .21114 L .42302 .21002 L F
.79539 .21129 m .79726 .20802 L .79866 .2102 L 0 .026 .125 r
F
.79539 .21129 m .79398 .20911 L .79726 .20802 L F
.34889 .21195 m .35003 .20878 L .35191 .21082 L 0 .027 .127 r
F
.34889 .21195 m .34702 .2099 L .35003 .20878 L F
.51043 .21371 m .51184 .21045 L .51354 .21256 L 0 .031 .131 r
F
.51043 .21371 m .50873 .21163 L .51184 .21045 L F
.61493 .21329 m .6165 .21004 L .61809 .21207 L 0 .03 .13 r
F
.61493 .21329 m .61334 .21129 L .6165 .21004 L F
.38532 .21267 m .38652 .2094 L .38836 .21144 L 0 .029 .128 r
F
.38532 .21267 m .38348 .21063 L .38652 .2094 L F
.22378 .21092 m .22471 .2078 L .22671 .20987 L 0 .026 .124 r
F
.22378 .21092 m .22177 .20885 L .22471 .2078 L F
.62284 .21289 m .62442 .2096 L .626 .21167 L 0 .029 .129 r
F
.62284 .21289 m .62125 .21085 L .62442 .2096 L F
.39323 .21224 m .39445 .20898 L .39627 .21102 L 0 .028 .127 r
F
.39323 .21224 m .3914 .2102 L .39445 .20898 L F
.26811 .21118 m .26913 .20788 L .27109 .20999 L 0 .026 .125 r
F
.26811 .21118 m .26616 .20909 L .26913 .20788 L F
.56268 .21362 m .56417 .21018 L .56581 .21235 L 0 .03 .131 r
F
.56268 .21362 m .56103 .21144 L .56417 .21018 L F
.63075 .21254 m .63234 .20917 L .63392 .21129 L 0 .028 .128 r
F
.63075 .21254 m .62917 .21042 L .63234 .20917 L F
.67509 .21279 m .67675 .2094 L .67829 .2116 L 0 .029 .129 r
F
.67509 .21279 m .67356 .21061 L .67675 .2094 L F
.35679 .21169 m .35794 .20852 L .35981 .21053 L 0 .027 .126 r
F
.35679 .21169 m .35492 .20967 L .35794 .20852 L F
.57059 .21325 m .57209 .20993 L .57373 .2121 L 0 .03 .13 r
F
.57059 .21325 m .56895 .21107 L .57209 .20993 L F
.42965 .21305 m .43093 .20975 L .43272 .21189 L F
.42965 .21305 m .42787 .21094 L .43093 .20975 L F
.46609 .21377 m .46742 .21039 L .46917 .21264 L 0 .031 .131 r
F
.46609 .21377 m .46434 .21154 L .46742 .21039 L F
.27601 .21092 m .27703 .20774 L .27897 .20986 L 0 .026 .125 r
F
.27601 .21092 m .27406 .2088 L .27703 .20774 L F
.75108 .21138 m .75287 .20814 L .75432 .21027 L 0 .027 .126 r
F
.75108 .21138 m .74962 .20925 L .75287 .20814 L F
.31244 .2116 m .31352 .20848 L .31543 .21057 L 0 .027 .127 r
F
.31244 .2116 m .31053 .20952 L .31352 .20848 L F
.51834 .21357 m .51976 .21019 L .52145 .21239 L 0 .031 .131 r
F
.51834 .21357 m .51665 .2114 L .51976 .21019 L F
.40113 .21205 m .40236 .20867 L .40417 .21092 L 0 .028 .127 r
F
.40113 .21205 m .39932 .2098 L .40236 .20867 L F
.68301 .2125 m .68468 .209 L .6862 .2112 L 0 .028 .128 r
F
.68301 .2125 m .68148 .2103 L .68468 .209 L F
.63867 .21238 m .64028 .20921 L .64185 .21134 L 0 .029 .129 r
F
.63867 .21238 m .6371 .21024 L .64028 .20921 L F
.69092 .21219 m .69262 .20887 L .69413 .21104 L 0 .028 .128 r
F
.69092 .21219 m .68941 .21002 L .69262 .20887 L F
.23165 .21089 m .2326 .20771 L .23459 .20979 L 0 .026 .125 r
F
.23165 .21089 m .22965 .20882 L .2326 .20771 L F
.43756 .21291 m .43885 .20954 L .44062 .21176 L 0 .03 .13 r
F
.43756 .21291 m .43578 .21072 L .43885 .20954 L F
.36468 .21163 m .36585 .20834 L .3677 .21056 L 0 .027 .127 r
F
.36468 .21163 m .36283 .20944 L .36585 .20834 L F
.52625 .21341 m .52768 .20997 L .52936 .21223 L 0 .031 .131 r
F
.52625 .21341 m .52456 .21118 L .52768 .20997 L F
.75901 .21128 m .76082 .20804 L .76226 .21014 L 0 .027 .126 r
F
.75901 .21128 m .75757 .20916 L .76082 .20804 L F
.47399 .21372 m .47534 .2104 L .47707 .21262 L 0 .031 .132 r
F
.47399 .21372 m .47225 .21153 L .47534 .2104 L F
.57851 .21332 m .58002 .20997 L .58165 .21224 L 0 .031 .131 r
F
.57851 .21332 m .57687 .21103 L .58002 .20997 L F
.32032 .21158 m .32143 .20826 L .32332 .21037 L 0 .027 .127 r
F
.32032 .21158 m .31842 .20947 L .32143 .20826 L F
.28388 .21094 m .28492 .20775 L .28685 .20986 L 0 .026 .125 r
F
.28388 .21094 m .28194 .20881 L .28492 .20775 L F
.69885 .21204 m .70055 .20867 L .70206 .21085 L 0 .028 .128 r
F
.69885 .21204 m .69734 .20988 L .70055 .20867 L F
.23953 .21073 m .2405 .20746 L .24248 .20958 L 0 .026 .125 r
F
.23953 .21073 m .23754 .20863 L .2405 .20746 L F
.40902 .21213 m .41026 .20879 L .41206 .21106 L 0 .029 .128 r
F
.40902 .21213 m .40721 .20986 L .41026 .20879 L F
.53416 .21324 m .5356 .20991 L .53728 .21207 L 0 .031 .131 r
F
.53416 .21324 m .53248 .21107 L .5356 .20991 L F
.64659 .21237 m .64822 .20909 L .64978 .2112 L 0 .029 .129 r
F
.64659 .21237 m .64503 .21026 L .64822 .20909 L F
.76694 .21107 m .76876 .20783 L .77019 .20988 L 0 .027 .126 r
F
.76694 .21107 m .76551 .20899 L .76876 .20783 L F
.32822 .21132 m .32934 .20796 L .33123 .21013 L F
.32822 .21132 m .32633 .20916 L .32934 .20796 L F
.44545 .21288 m .44676 .2095 L .44852 .21173 L 0 .03 .13 r
F
.44545 .21288 m .44369 .21061 L .44676 .2095 L F
.4819 .21355 m .48325 .21034 L .48499 .21244 L 0 .032 .132 r
F
.4819 .21355 m .48016 .21148 L .48325 .21034 L F
.71468 .21138 m .71641 .20807 L .7179 .2101 L 0 .027 .127 r
F
.71468 .21138 m .7132 .20935 L .71641 .20807 L F
.70678 .21186 m .70849 .20842 L .70999 .21062 L 0 .028 .128 r
F
.70678 .21186 m .70527 .20966 L .70849 .20842 L F
.7226 .21102 m .72436 .20788 L .72583 .20992 L 0 .027 .126 r
F
.7226 .21102 m .72112 .20899 L .72436 .20788 L F
.24741 .21059 m .24839 .20738 L .25036 .20951 L 0 .026 .125 r
F
.24741 .21059 m .24544 .20848 L .24839 .20738 L F
.54207 .21301 m .54353 .20987 L .5452 .21194 L 0 .031 .131 r
F
.54207 .21301 m .5404 .21095 L .54353 .20987 L F
.29176 .21084 m .29281 .20763 L .29475 .20971 L 0 .027 .126 r
F
.29176 .21084 m .28983 .20875 L .29281 .20763 L F
.37256 .21172 m .37375 .20844 L .37559 .21069 L 0 .028 .128 r
F
.37256 .21172 m .37072 .20949 L .37375 .20844 L F
.77487 .21087 m .77671 .20771 L .77813 .20978 L 0 .027 .126 r
F
.77487 .21087 m .77345 .20879 L .77671 .20771 L F
.65452 .21221 m .65615 .20887 L .6577 .21103 L 0 .029 .129 r
F
.65452 .21221 m .65296 .21003 L .65615 .20887 L F
.21096 .21003 m .21187 .20688 L .21389 .20893 L 0 .025 .124 r
F
.21096 .21003 m .20894 .20798 L .21187 .20688 L F
.33611 .21114 m .33725 .20779 L .33912 .20999 L 0 .027 .126 r
F
.33611 .21114 m .33423 .20895 L .33725 .20779 L F
.4898 .21338 m .49118 .2101 L .4929 .21216 L 0 .031 .132 r
F
.4898 .21338 m .48808 .21128 L .49118 .2101 L F
.58643 .21338 m .58795 .20999 L .58958 .21226 L F
.58643 .21338 m .5848 .21111 L .58795 .20999 L F
.45336 .21278 m .45467 .20945 L .45643 .21161 L 0 .03 .131 r
F
.45336 .21278 m .4516 .21059 L .45467 .20945 L F
.73053 .21083 m .73229 .20753 L .73375 .20959 L 0 .027 .126 r
F
.73053 .21083 m .72906 .20878 L .73229 .20753 L F
.73844 .21041 m .74022 .20724 L .74168 .2093 L 0 .026 .125 r
F
.73844 .21041 m .73698 .20836 L .74022 .20724 L F
.66244 .21199 m .66408 .20865 L .66563 .21076 L 0 .029 .129 r
F
.66244 .21199 m .66089 .20984 L .66408 .20865 L F
.29965 .21068 m .30072 .2075 L .30264 .20959 L 0 .027 .126 r
F
.29965 .21068 m .29773 .2086 L .30072 .2075 L F
.41691 .21222 m .41816 .20892 L .41996 .21114 L 0 .029 .129 r
F
.41691 .21222 m .41511 .20999 L .41816 .20892 L F
.49771 .2131 m .4991 .2098 L .50081 .21192 L 0 .031 .132 r
F
.49771 .2131 m .496 .21095 L .4991 .2098 L F
.78281 .2107 m .78465 .20739 L .78606 .20943 L 0 .027 .126 r
F
.78281 .2107 m .78139 .20865 L .78465 .20739 L F
.79072 .21027 m .79258 .20701 L .79398 .20911 L 0 .026 .125 r
F
.79072 .21027 m .78931 .20817 L .79258 .20701 L F
.60226 .2127 m .60381 .2094 L .60541 .21151 L 0 .03 .131 r
F
.60226 .2127 m .60065 .21061 L .60381 .2094 L F
.54999 .21293 m .55145 .20964 L .55311 .21173 L 0 .031 .131 r
F
.54999 .21293 m .54832 .21086 L .55145 .20964 L F
.25529 .21054 m .25629 .20727 L .25825 .20937 L 0 .026 .125 r
F
.25529 .21054 m .25332 .20842 L .25629 .20727 L F
.34401 .211 m .34514 .20782 L .34702 .2099 L 0 .027 .127 r
F
.34401 .211 m .34213 .2089 L .34514 .20782 L F
.21884 .20991 m .21976 .20678 L .22177 .20885 L 0 .026 .124 r
F
.21884 .20991 m .21683 .20786 L .21976 .20678 L F
.59435 .21322 m .59588 .20977 L .5975 .21191 L 0 .031 .132 r
F
.59435 .21322 m .59273 .21107 L .59588 .20977 L F
.50562 .21284 m .50702 .20955 L .50873 .21163 L 0 .031 .131 r
F
.50562 .21284 m .50392 .21073 L .50702 .20955 L F
.67036 .21175 m .67202 .20852 L .67356 .21061 L 0 .029 .129 r
F
.67036 .21175 m .66882 .20965 L .67202 .20852 L F
.5579 .21267 m .55938 .20926 L .56103 .21144 L 0 .03 .131 r
F
.5579 .21267 m .55624 .21049 L .55938 .20926 L F
.61017 .21246 m .61174 .20916 L .61334 .21129 L 0 .03 .13 r
F
.61017 .21246 m .60858 .21034 L .61174 .20916 L F
.38045 .21181 m .38165 .20847 L .38348 .21063 L 0 .029 .129 r
F
.38045 .21181 m .37861 .20965 L .38165 .20847 L F
.26319 .21029 m .26419 .20702 L .26616 .20909 L 0 .026 .125 r
F
.26319 .21029 m .26122 .2082 L .26419 .20702 L F
.46126 .21271 m .46259 .20931 L .46434 .21154 L 0 .031 .131 r
F
.46126 .21271 m .45951 .21046 L .46259 .20931 L F
.61809 .21207 m .61967 .2088 L .62125 .21085 L 0 .03 .13 r
F
.61809 .21207 m .6165 .21004 L .61967 .2088 L F
.74638 .21031 m .74817 .20716 L .74962 .20925 L 0 .026 .126 r
F
.74638 .21031 m .74492 .20823 L .74817 .20716 L F
.38836 .21144 m .38957 .20816 L .3914 .2102 L 0 .028 .128 r
F
.38836 .21144 m .38652 .2094 L .38957 .20816 L F
.30754 .21056 m .30861 .20744 L .31053 .20952 L 0 .027 .126 r
F
.30754 .21056 m .30563 .20849 L .30861 .20744 L F
.626 .21167 m .62759 .20834 L .62917 .21042 L 0 .029 .129 r
F
.626 .21167 m .62442 .2096 L .62759 .20834 L F
.42481 .21212 m .42608 .20882 L .42787 .21094 L 0 .03 .13 r
F
.42481 .21212 m .42302 .21002 L .42608 .20882 L F
.51354 .21256 m .51495 .20928 L .51665 .2114 L 0 .031 .131 r
F
.51354 .21256 m .51184 .21045 L .51495 .20928 L F
.39627 .21102 m .39749 .20775 L .39932 .2098 L 0 .028 .127 r
F
.39627 .21102 m .39445 .20898 L .39749 .20775 L F
.56581 .21235 m .56731 .20893 L .56895 .21107 L 0 .03 .13 r
F
.56581 .21235 m .56417 .21018 L .56731 .20893 L F
.35191 .21082 m .35305 .20765 L .35492 .20967 L 0 .027 .127 r
F
.35191 .21082 m .35003 .20878 L .35305 .20765 L F
.63392 .21129 m .63552 .20811 L .6371 .21024 L 0 .028 .128 r
F
.63392 .21129 m .63234 .20917 L .63552 .20811 L F
.79866 .2102 m .80053 .20693 L .80194 .20911 L 0 .026 .125 r
F
.79866 .2102 m .79726 .20802 L .80053 .20693 L F
.27109 .20999 m .27211 .20668 L .27406 .2088 L F
.27109 .20999 m .26913 .20788 L .27211 .20668 L F
.67829 .2116 m .67995 .2081 L .68148 .2103 L 0 .029 .128 r
F
.67829 .2116 m .67675 .2094 L .67995 .2081 L F
.22671 .20987 m .22765 .20676 L .22965 .20882 L 0 .026 .125 r
F
.22671 .20987 m .22471 .2078 L .22765 .20676 L F
.35981 .21053 m .36097 .20741 L .36283 .20944 L 0 .027 .126 r
F
.35981 .21053 m .35794 .20852 L .36097 .20741 L F
.6862 .2112 m .68788 .20782 L .68941 .21002 L 0 .028 .128 r
F
.6862 .2112 m .68468 .209 L .68788 .20782 L F
.57373 .2121 m .57524 .20887 L .57687 .21103 L 0 .03 .13 r
F
.57373 .2121 m .57209 .20993 L .57524 .20887 L F
.43272 .21189 m .434 .20856 L .43578 .21072 L 0 .029 .129 r
F
.43272 .21189 m .43093 .20975 L .434 .20856 L F
.52145 .21239 m .52287 .20894 L .52456 .21118 L 0 .03 .131 r
F
.52145 .21239 m .51976 .21019 L .52287 .20894 L F
.46917 .21264 m .47051 .20925 L .47225 .21153 L 0 .031 .131 r
F
.46917 .21264 m .46742 .21039 L .47051 .20925 L F
.40417 .21092 m .40541 .20761 L .40721 .20986 L 0 .028 .127 r
F
.40417 .21092 m .40236 .20867 L .40541 .20761 L F
.75432 .21027 m .75612 .20703 L .75757 .20916 L 0 .027 .126 r
F
.75432 .21027 m .75287 .20814 L .75612 .20703 L F
.27897 .20986 m .28 .20669 L .28194 .20881 L 0 .026 .125 r
F
.27897 .20986 m .27703 .20774 L .28 .20669 L F
.31543 .21057 m .31651 .20737 L .31842 .20947 L 0 .027 .127 r
F
.31543 .21057 m .31352 .20848 L .31651 .20737 L F
.69413 .21104 m .69583 .2077 L .69734 .20988 L 0 .028 .128 r
F
.69413 .21104 m .69262 .20887 L .69583 .2077 L F
.44062 .21176 m .44192 .20837 L .44369 .21061 L 0 .03 .13 r
F
.44062 .21176 m .43885 .20954 L .44192 .20837 L F
.23459 .20979 m .23555 .20652 L .23754 .20863 L 0 .026 .125 r
F
.23459 .20979 m .2326 .20771 L .23555 .20652 L F
.64185 .21134 m .64347 .20815 L .64503 .21026 L 0 .029 .129 r
F
.64185 .21134 m .64028 .20921 L .64347 .20815 L F
.52936 .21223 m .5308 .20882 L .53248 .21107 L 0 .03 .131 r
F
.52936 .21223 m .52768 .20997 L .5308 .20882 L F
.3677 .21056 m .36888 .20726 L .37072 .20949 L 0 .028 .127 r
F
.3677 .21056 m .36585 .20834 L .36888 .20726 L F
.76226 .21014 m .76407 .20691 L .76551 .20899 L 0 .027 .126 r
F
.76226 .21014 m .76082 .20804 L .76407 .20691 L F
.32332 .21037 m .32443 .20705 L .32633 .20916 L F
.32332 .21037 m .32143 .20826 L .32443 .20705 L F
.70206 .21085 m .70377 .20745 L .70527 .20966 L 0 .028 .128 r
F
.70206 .21085 m .70055 .20867 L .70377 .20745 L F
.47707 .21262 m .47843 .20924 L .48016 .21148 L 0 .031 .132 r
F
.47707 .21262 m .47534 .2104 L .47843 .20924 L F
.24248 .20958 m .24346 .20633 L .24544 .20848 L 0 .026 .125 r
F
.24248 .20958 m .2405 .20746 L .24346 .20633 L F
.58165 .21224 m .58317 .20884 L .5848 .21111 L 0 .031 .131 r
F
.58165 .21224 m .58002 .20997 L .58317 .20884 L F
.28685 .20986 m .2879 .20665 L .28983 .20875 L 0 .027 .126 r
F
.28685 .20986 m .28492 .20775 L .2879 .20665 L F
.53728 .21207 m .53873 .20879 L .5404 .21095 L 0 .031 .131 r
F
.53728 .21207 m .5356 .20991 L .53873 .20879 L F
.64978 .2112 m .65141 .20792 L .65296 .21003 L 0 .029 .129 r
F
.64978 .2112 m .64822 .20909 L .65141 .20792 L F
.77019 .20988 m .77202 .20674 L .77345 .20879 L 0 .027 .126 r
F
.77019 .20988 m .76876 .20783 L .77202 .20674 L F
.7179 .2101 m .71964 .20694 L .72112 .20899 L F
.7179 .2101 m .71641 .20807 L .71964 .20694 L F
.33123 .21013 m .33235 .20676 L .33423 .20895 L F
.33123 .21013 m .32934 .20796 L .33235 .20676 L F
.41206 .21106 m .41331 .20773 L .41511 .20999 L 0 .029 .129 r
F
.41206 .21106 m .41026 .20879 L .41331 .20773 L F
.70999 .21062 m .7117 .20716 L .7132 .20935 L 0 .028 .127 r
F
.70999 .21062 m .70849 .20842 L .7117 .20716 L F
.44852 .21173 m .44983 .20839 L .4516 .21059 L 0 .03 .13 r
F
.44852 .21173 m .44676 .2095 L .44983 .20839 L F
.48499 .21244 m .48635 .20919 L .48808 .21128 L 0 .032 .132 r
F
.48499 .21244 m .48325 .21034 L .48635 .20919 L F
.72583 .20992 m .72759 .20672 L .72906 .20878 L 0 .027 .126 r
F
.72583 .20992 m .72436 .20788 L .72759 .20672 L F
.29475 .20971 m .2958 .20652 L .29773 .2086 L F
.29475 .20971 m .29281 .20763 L .2958 .20652 L F
.6577 .21103 m .65934 .20771 L .66089 .20984 L 0 .029 .129 r
F
.6577 .21103 m .65615 .20887 L .65934 .20771 L F
.25036 .20951 m .25135 .20628 L .25332 .20842 L 0 .026 .125 r
F
.25036 .20951 m .24839 .20738 L .25135 .20628 L F
.5452 .21194 m .54666 .20879 L .54832 .21086 L 0 .031 .131 r
F
.5452 .21194 m .54353 .20987 L .54666 .20879 L F
.4929 .21216 m .49428 .20891 L .496 .21095 L 0 .031 .132 r
F
.4929 .21216 m .49118 .2101 L .49428 .20891 L F
.33912 .20999 m .34025 .20673 L .34213 .2089 L 0 .027 .126 r
F
.33912 .20999 m .33725 .20779 L .34025 .20673 L F
.77813 .20978 m .77997 .20659 L .78139 .20865 L F
.77813 .20978 m .77671 .20771 L .77997 .20659 L F
.21389 .20893 m .21481 .2058 L .21683 .20786 L 0 .025 .124 r
F
.21389 .20893 m .21187 .20688 L .21481 .2058 L F
.37559 .21069 m .37678 .20738 L .37861 .20965 L 0 .028 .128 r
F
.37559 .21069 m .37375 .20844 L .37678 .20738 L F
.73375 .20959 m .73551 .20627 L .73698 .20836 L 0 .026 .125 r
F
.73375 .20959 m .73229 .20753 L .73551 .20627 L F
.58958 .21226 m .59111 .20881 L .59273 .21107 L 0 .031 .132 r
F
.58958 .21226 m .58795 .20999 L .59111 .20881 L F
.45643 .21161 m .45775 .20834 L .45951 .21046 L 0 .03 .13 r
F
.45643 .21161 m .45467 .20945 L .45775 .20834 L F
.78606 .20943 m .7879 .20613 L .78931 .20817 L 0 .026 .125 r
F
.78606 .20943 m .78465 .20739 L .7879 .20613 L F
.66563 .21076 m .66728 .20755 L .66882 .20965 L 0 .029 .129 r
F
.66563 .21076 m .66408 .20865 L .66728 .20755 L F
.5975 .21191 m .59904 .20847 L .60065 .21061 L 0 .031 .131 r
F
.5975 .21191 m .59588 .20977 L .59904 .20847 L F
.50081 .21192 m .5022 .20865 L .50392 .21073 L F
.50081 .21192 m .4991 .2098 L .5022 .20865 L F
.74168 .2093 m .74347 .20615 L .74492 .20823 L 0 .026 .125 r
F
.74168 .2093 m .74022 .20724 L .74347 .20615 L F
.55311 .21173 m .55459 .20838 L .55624 .21049 L 0 .031 .131 r
F
.55311 .21173 m .55145 .20964 L .55459 .20838 L F
.60541 .21151 m .60697 .20822 L .60858 .21034 L 0 .03 .13 r
F
.60541 .21151 m .60381 .2094 L .60697 .20822 L F
.79398 .20911 m .79585 .20592 L .79726 .20802 L 0 .026 .125 r
F
.79398 .20911 m .79258 .20701 L .79585 .20592 L F
.30264 .20959 m .30371 .2064 L .30563 .20849 L 0 .027 .126 r
F
.30264 .20959 m .30072 .2075 L .30371 .2064 L F
.25825 .20937 m .25925 .20612 L .26122 .2082 L 0 .026 .125 r
F
.25825 .20937 m .25629 .20727 L .25925 .20612 L F
.41996 .21114 m .42122 .20781 L .42302 .21002 L 0 .03 .13 r
F
.41996 .21114 m .41816 .20892 L .42122 .20781 L F
.50873 .21163 m .51013 .20835 L .51184 .21045 L 0 .031 .131 r
F
.50873 .21163 m .50702 .20955 L .51013 .20835 L F
.56103 .21144 m .56252 .20802 L .56417 .21018 L 0 .03 .13 r
F
.56103 .21144 m .55938 .20926 L .56252 .20802 L F
.34702 .2099 m .34816 .20672 L .35003 .20878 L 0 .028 .127 r
F
.34702 .2099 m .34514 .20782 L .34816 .20672 L F
.22177 .20885 m .2227 .20575 L .22471 .2078 L 0 .026 .125 r
F
.22177 .20885 m .21976 .20678 L .2227 .20575 L F
.67356 .21061 m .67522 .20733 L .67675 .2094 L 0 .029 .129 r
F
.67356 .21061 m .67202 .20852 L .67522 .20733 L F
.26616 .20909 m .26717 .20582 L .26913 .20788 L 0 .026 .125 r
F
.26616 .20909 m .26419 .20702 L .26717 .20582 L F
.62125 .21085 m .62284 .20753 L .62442 .2096 L 0 .029 .129 r
F
.62125 .21085 m .61967 .2088 L .62284 .20753 L F
.38348 .21063 m .38469 .20724 L .38652 .2094 L 0 .029 .128 r
F
.38348 .21063 m .38165 .20847 L .38469 .20724 L F
.56895 .21107 m .57045 .2078 L .57209 .20993 L 0 .03 .13 r
F
.56895 .21107 m .56731 .20893 L .57045 .2078 L F
.61334 .21129 m .6149 .20789 L .6165 .21004 L F
.61334 .21129 m .61174 .20916 L .6149 .20789 L F
.62917 .21042 m .63077 .20707 L .63234 .20917 L 0 .028 .128 r
F
.62917 .21042 m .62759 .20834 L .63077 .20707 L F
.3914 .2102 m .39262 .20692 L .39445 .20898 L F
.3914 .2102 m .38957 .20816 L .39262 .20692 L F
.46434 .21154 m .46568 .20815 L .46742 .21039 L 0 .03 .131 r
F
.46434 .21154 m .46259 .20931 L .46568 .20815 L F
.39932 .2098 m .40054 .20661 L .40236 .20867 L 0 .027 .127 r
F
.39932 .2098 m .39749 .20775 L .40054 .20661 L F
.42787 .21094 m .42914 .20761 L .43093 .20975 L 0 .029 .129 r
F
.42787 .21094 m .42608 .20882 L .42914 .20761 L F
.68148 .2103 m .68315 .20679 L .68468 .209 L 0 .028 .128 r
F
.68148 .2103 m .67995 .2081 L .68315 .20679 L F
.51665 .2114 m .51806 .20805 L .51976 .21019 L 0 .03 .131 r
F
.51665 .2114 m .51495 .20928 L .51806 .20805 L F
.35492 .20967 m .35607 .20652 L .35794 .20852 L 0 .027 .127 r
F
.35492 .20967 m .35305 .20765 L .35607 .20652 L F
.27406 .2088 m .27508 .20562 L .27703 .20774 L 0 .026 .125 r
F
.27406 .2088 m .27211 .20668 L .27508 .20562 L F
.74962 .20925 m .75142 .20603 L .75287 .20814 L 0 .027 .126 r
F
.74962 .20925 m .74817 .20716 L .75142 .20603 L F
.31053 .20952 m .31161 .20639 L .31352 .20848 L 0 .027 .127 r
F
.31053 .20952 m .30861 .20744 L .31161 .20639 L F
.6371 .21024 m .63871 .20707 L .64028 .20921 L 0 .029 .128 r
F
.6371 .21024 m .63552 .20811 L .63871 .20707 L F
.68941 .21002 m .6911 .20667 L .69262 .20887 L 0 .028 .127 r
F
.68941 .21002 m .68788 .20782 L .6911 .20667 L F
.43578 .21072 m .43707 .20736 L .43885 .20954 L 0 .029 .129 r
F
.43578 .21072 m .434 .20856 L .43707 .20736 L F
.52456 .21118 m .52599 .2077 L .52768 .20997 L 0 .03 .13 r
F
.52456 .21118 m .52287 .20894 L .52599 .2077 L F
.36283 .20944 m .36399 .20629 L .36585 .20834 L 0 .027 .127 r
F
.36283 .20944 m .36097 .20741 L .36399 .20629 L F
.22965 .20882 m .23059 .20565 L .2326 .20771 L 0 .026 .125 r
F
.22965 .20882 m .22765 .20676 L .23059 .20565 L F
.57687 .21103 m .57839 .20782 L .58002 .20997 L 0 .03 .13 r
F
.57687 .21103 m .57524 .20887 L .57839 .20782 L F
.47225 .21153 m .4736 .2081 L .47534 .2104 L 0 .031 .131 r
F
.47225 .21153 m .47051 .20925 L .4736 .2081 L F
.75757 .20916 m .75937 .20592 L .76082 .20804 L 0 .027 .126 r
F
.75757 .20916 m .75612 .20703 L .75937 .20592 L F
.40721 .20986 m .40846 .20656 L .41026 .20879 L 0 .028 .128 r
F
.40721 .20986 m .40541 .20761 L .40846 .20656 L F
.69734 .20988 m .69904 .20648 L .70055 .20867 L F
.69734 .20988 m .69583 .2077 L .69904 .20648 L F
.31842 .20947 m .31952 .20616 L .32143 .20826 L 0 .027 .127 r
F
.31842 .20947 m .31651 .20737 L .31952 .20616 L F
.28194 .20881 m .28298 .20563 L .28492 .20775 L 0 .026 .125 r
F
.28194 .20881 m .28 .20669 L .28298 .20563 L F
.23754 .20863 m .23851 .20533 L .2405 .20746 L F
.23754 .20863 m .23555 .20652 L .23851 .20533 L F
.44369 .21061 m .44499 .20728 L .44676 .2095 L 0 .03 .13 r
F
.44369 .21061 m .44192 .20837 L .44499 .20728 L F
.53248 .21107 m .53392 .20766 L .5356 .20991 L 0 .03 .131 r
F
.53248 .21107 m .5308 .20882 L .53392 .20766 L F
.32633 .20916 m .32744 .20584 L .32934 .20796 L 0 .027 .126 r
F
.32633 .20916 m .32443 .20705 L .32744 .20584 L F
.64503 .21026 m .64666 .20698 L .64822 .20909 L 0 .029 .129 r
F
.64503 .21026 m .64347 .20815 L .64666 .20698 L F
.76551 .20899 m .76733 .20577 L .76876 .20783 L 0 .027 .126 r
F
.76551 .20899 m .76407 .20691 L .76733 .20577 L F
.70527 .20966 m .70698 .20622 L .70849 .20842 L 0 .028 .127 r
F
.70527 .20966 m .70377 .20745 L .70698 .20622 L F
.37072 .20949 m .37191 .20619 L .37375 .20844 L F
.37072 .20949 m .36888 .20726 L .37191 .20619 L F
.48016 .21148 m .48152 .20808 L .48325 .21034 L 0 .031 .132 r
F
.48016 .21148 m .47843 .20924 L .48152 .20808 L F
.7132 .20935 m .71492 .20589 L .71641 .20807 L 0 .027 .127 r
F
.7132 .20935 m .7117 .20716 L .71492 .20589 L F
.5848 .21111 m .58633 .20771 L .58795 .20999 L 0 .031 .131 r
F
.5848 .21111 m .58317 .20884 L .58633 .20771 L F
.24544 .20848 m .24642 .20521 L .24839 .20738 L 0 .026 .125 r
F
.24544 .20848 m .24346 .20633 L .24642 .20521 L F
.65296 .21003 m .6546 .20677 L .65615 .20887 L 0 .029 .129 r
F
.65296 .21003 m .65141 .20792 L .6546 .20677 L F
.33423 .20895 m .33536 .20559 L .33725 .20779 L 0 .027 .126 r
F
.33423 .20895 m .33235 .20676 L .33536 .20559 L F
.28983 .20875 m .29088 .20555 L .29281 .20763 L F
.28983 .20875 m .2879 .20665 L .29088 .20555 L F
.5404 .21095 m .54186 .20771 L .54353 .20987 L 0 .031 .131 r
F
.5404 .21095 m .53873 .20879 L .54186 .20771 L F
.72112 .20899 m .72288 .20582 L .72436 .20788 L 0 .027 .127 r
F
.72112 .20899 m .71964 .20694 L .72288 .20582 L F
.77345 .20879 m .77529 .20566 L .77671 .20771 L 0 .027 .126 r
F
.77345 .20879 m .77202 .20674 L .77529 .20566 L F
.4516 .21059 m .45291 .20728 L .45467 .20945 L 0 .03 .13 r
F
.4516 .21059 m .44983 .20839 L .45291 .20728 L F
.48808 .21128 m .48945 .20802 L .49118 .2101 L 0 .032 .132 r
F
.48808 .21128 m .48635 .20919 L .48945 .20802 L F
.41511 .20999 m .41637 .20667 L .41816 .20892 L 0 .029 .129 r
F
.41511 .20999 m .41331 .20773 L .41637 .20667 L F
.66089 .20984 m .66254 .20655 L .66408 .20865 L F
.66089 .20984 m .65934 .20771 L .66254 .20655 L F
.496 .21095 m .49738 .20777 L .4991 .2098 L 0 .031 .132 r
F
.496 .21095 m .49428 .20891 L .49738 .20777 L F
.72906 .20878 m .73081 .20544 L .73229 .20753 L 0 .027 .126 r
F
.72906 .20878 m .72759 .20672 L .73081 .20544 L F
.73698 .20836 m .73875 .20513 L .74022 .20724 L 0 .026 .125 r
F
.73698 .20836 m .73551 .20627 L .73875 .20513 L F
.29773 .2086 m .29879 .2054 L .30072 .2075 L 0 .027 .126 r
F
.29773 .2086 m .2958 .20652 L .29879 .2054 L F
.78931 .20817 m .79117 .20498 L .79258 .20701 L 0 .026 .125 r
F
.78931 .20817 m .7879 .20613 L .79117 .20498 L F
.60065 .21061 m .6022 .20727 L .60381 .2094 L 0 .03 .131 r
F
.60065 .21061 m .59904 .20847 L .6022 .20727 L F
.25332 .20842 m .25432 .20515 L .25629 .20727 L 0 .026 .125 r
F
.25332 .20842 m .25135 .20628 L .25432 .20515 L F
.78139 .20865 m .78323 .20534 L .78465 .20739 L 0 .027 .126 r
F
.78139 .20865 m .77997 .20659 L .78323 .20534 L F
.59273 .21107 m .59426 .20755 L .59588 .20977 L 0 .031 .131 r
F
.59273 .21107 m .59111 .20881 L .59426 .20755 L F
.54832 .21086 m .54979 .20755 L .55145 .20964 L F
.54832 .21086 m .54666 .20879 L .54979 .20755 L F
.34213 .2089 m .34327 .20566 L .34514 .20782 L 0 .027 .127 r
F
.34213 .2089 m .34025 .20673 L .34327 .20566 L F
.45951 .21046 m .46083 .20722 L .46259 .20931 L 0 .03 .131 r
F
.45951 .21046 m .45775 .20834 L .46083 .20722 L F
.21683 .20786 m .21775 .20472 L .21976 .20678 L 0 .026 .124 r
F
.21683 .20786 m .21481 .2058 L .21775 .20472 L F
.55624 .21049 m .55772 .20713 L .55938 .20926 L 0 .03 .13 r
F
.55624 .21049 m .55459 .20838 L .55772 .20713 L F
.50392 .21073 m .50531 .20748 L .50702 .20955 L 0 .031 .131 r
F
.50392 .21073 m .5022 .20865 L .50531 .20748 L F
.66882 .20965 m .67049 .20645 L .67202 .20852 L 0 .029 .129 r
F
.66882 .20965 m .66728 .20755 L .67049 .20645 L F
.37861 .20965 m .37982 .20621 L .38165 .20847 L 0 .029 .128 r
F
.37861 .20965 m .37678 .20738 L .37982 .20621 L F
.60858 .21034 m .61014 .20703 L .61174 .20916 L 0 .03 .13 r
F
.60858 .21034 m .60697 .20822 L .61014 .20703 L F
.26122 .2082 m .26223 .20494 L .26419 .20702 L 0 .026 .125 r
F
.26122 .2082 m .25925 .20612 L .26223 .20494 L F
.56417 .21018 m .56566 .20678 L .56731 .20893 L 0 .03 .13 r
F
.56417 .21018 m .56252 .20802 L .56566 .20678 L F
.74492 .20823 m .74671 .20506 L .74817 .20716 L 0 .026 .126 r
F
.74492 .20823 m .74347 .20615 L .74671 .20506 L F
.79726 .20802 m .79913 .20484 L .80053 .20693 L 0 .026 .125 r
F
.79726 .20802 m .79585 .20592 L .79913 .20484 L F
.51184 .21045 m .51325 .20715 L .51495 .20928 L 0 .031 .131 r
F
.51184 .21045 m .51013 .20835 L .51325 .20715 L F
.42302 .21002 m .42429 .20659 L .42608 .20882 L 0 .029 .129 r
F
.42302 .21002 m .42122 .20781 L .42429 .20659 L F
.30563 .20849 m .3067 .20533 L .30861 .20744 L 0 .027 .126 r
F
.30563 .20849 m .30371 .2064 L .3067 .20533 L F
.62442 .2096 m .62601 .20625 L .62759 .20834 L 0 .029 .129 r
F
.62442 .2096 m .62284 .20753 L .62601 .20625 L F
.6165 .21004 m .61807 .20662 L .61967 .2088 L 0 .03 .13 r
F
.6165 .21004 m .6149 .20789 L .61807 .20662 L F
.63234 .20917 m .63395 .20598 L .63552 .20811 L 0 .028 .128 r
F
.63234 .20917 m .63077 .20707 L .63395 .20598 L F
.38652 .2094 m .38774 .20601 L .38957 .20816 L F
.38652 .2094 m .38469 .20724 L .38774 .20601 L F
.67675 .2094 m .67842 .20603 L .67995 .2081 L F
.67675 .2094 m .67522 .20733 L .67842 .20603 L F
.39445 .20898 m .39567 .20569 L .39749 .20775 L 0 .028 .127 r
F
.39445 .20898 m .39262 .20692 L .39567 .20569 L F
.26913 .20788 m .27015 .20461 L .27211 .20668 L 0 .026 .125 r
F
.26913 .20788 m .26717 .20582 L .27015 .20461 L F
.68468 .209 m .68636 .20561 L .68788 .20782 L 0 .028 .127 r
F
.68468 .209 m .68315 .20679 L .68636 .20561 L F
.35003 .20878 m .35118 .2056 L .35305 .20765 L F
.35003 .20878 m .34816 .20672 L .35118 .2056 L F
.57209 .20993 m .5736 .20675 L .57524 .20887 L 0 .03 .13 r
F
.57209 .20993 m .57045 .2078 L .5736 .20675 L F
.46742 .21039 m .46876 .20698 L .47051 .20925 L 0 .03 .131 r
F
.46742 .21039 m .46568 .20815 L .46876 .20698 L F
.51976 .21019 m .52118 .20679 L .52287 .20894 L 0 .03 .13 r
F
.51976 .21019 m .51806 .20805 L .52118 .20679 L F
.43093 .20975 m .43221 .2064 L .434 .20856 L 0 .029 .129 r
F
.43093 .20975 m .42914 .20761 L .43221 .2064 L F
.40236 .20867 m .40359 .20556 L .40541 .20761 L 0 .028 .127 r
F
.40236 .20867 m .40054 .20661 L .40359 .20556 L F
.22471 .2078 m .22564 .20471 L .22765 .20676 L 0 .026 .125 r
F
.22471 .2078 m .2227 .20575 L .22564 .20471 L F
.35794 .20852 m .3591 .20538 L .36097 .20741 L 0 .027 .127 r
F
.35794 .20852 m .35607 .20652 L .3591 .20538 L F
.75287 .20814 m .75467 .20489 L .75612 .20703 L 0 .027 .126 r
F
.75287 .20814 m .75142 .20603 L .75467 .20489 L F
.27703 .20774 m .27805 .20457 L .28 .20669 L 0 .026 .125 r
F
.27703 .20774 m .27508 .20562 L .27805 .20457 L F
.69262 .20887 m .69431 .2055 L .69583 .2077 L 0 .028 .127 r
F
.69262 .20887 m .6911 .20667 L .69431 .2055 L F
.52768 .20997 m .52911 .20656 L .5308 .20882 L 0 .03 .13 r
F
.52768 .20997 m .52599 .2077 L .52911 .20656 L F
.43885 .20954 m .44014 .20617 L .44192 .20837 L 0 .029 .129 r
F
.43885 .20954 m .43707 .20736 L .44014 .20617 L F
.31352 .20848 m .3146 .20527 L .31651 .20737 L 0 .027 .127 r
F
.31352 .20848 m .31161 .20639 L .3146 .20527 L F
.64028 .20921 m .6419 .20599 L .64347 .20815 L 0 .029 .129 r
F
.64028 .20921 m .63871 .20707 L .6419 .20599 L F
.36585 .20834 m .36702 .20519 L .36888 .20726 L 0 .027 .127 r
F
.36585 .20834 m .36399 .20629 L .36702 .20519 L F
.2326 .20771 m .23356 .20445 L .23555 .20652 L 0 .026 .125 r
F
.2326 .20771 m .23059 .20565 L .23356 .20445 L F
.47534 .2104 m .47669 .20691 L .47843 .20924 L 0 .031 .131 r
F
.47534 .2104 m .4736 .2081 L .47669 .20691 L F
.58002 .20997 m .58154 .20668 L .58317 .20884 L 0 .03 .131 r
F
.58002 .20997 m .57839 .20782 L .58154 .20668 L F
.70055 .20867 m .70226 .20525 L .70377 .20745 L 0 .028 .127 r
F
.70055 .20867 m .69904 .20648 L .70226 .20525 L F
.32143 .20826 m .32253 .20495 L .32443 .20705 L 0 .027 .126 r
F
.32143 .20826 m .31952 .20616 L .32253 .20495 L F
.76082 .20804 m .76263 .20479 L .76407 .20691 L F
.76082 .20804 m .75937 .20592 L .76263 .20479 L F
.2405 .20746 m .24148 .20418 L .24346 .20633 L 0 .026 .125 r
F
.2405 .20746 m .23851 .20533 L .24148 .20418 L F
.41026 .20879 m .41151 .20551 L .41331 .20773 L 0 .028 .128 r
F
.41026 .20879 m .40846 .20656 L .41151 .20551 L F
.5356 .20991 m .53705 .20654 L .53873 .20879 L 0 .03 .131 r
F
.5356 .20991 m .53392 .20766 L .53705 .20654 L F
.32934 .20796 m .33046 .20463 L .33235 .20676 L 0 .027 .126 r
F
.32934 .20796 m .32744 .20584 L .33046 .20463 L F
.44676 .2095 m .44807 .20619 L .44983 .20839 L 0 .03 .13 r
F
.44676 .2095 m .44499 .20728 L .44807 .20619 L F
.28492 .20775 m .28596 .20455 L .2879 .20665 L 0 .027 .126 r
F
.28492 .20775 m .28298 .20563 L .28596 .20455 L F
.70849 .20842 m .7102 .20496 L .7117 .20716 L 0 .027 .127 r
F
.70849 .20842 m .70698 .20622 L .7102 .20496 L F
.64822 .20909 m .64985 .20581 L .65141 .20792 L 0 .029 .129 r
F
.64822 .20909 m .64666 .20698 L .64985 .20581 L F
.76876 .20783 m .77059 .20469 L .77202 .20674 L 0 .027 .126 r
F
.76876 .20783 m .76733 .20577 L .77059 .20469 L F
.71641 .20807 m .71815 .20476 L .71964 .20694 L F
.71641 .20807 m .71492 .20589 L .71815 .20476 L F
.48325 .21034 m .48462 .20692 L .48635 .20919 L 0 .031 .132 r
F
.48325 .21034 m .48152 .20808 L .48462 .20692 L F
.65615 .20887 m .65779 .20564 L .65934 .20771 L 0 .029 .129 r
F
.65615 .20887 m .6546 .20677 L .65779 .20564 L F
.37375 .20844 m .37494 .20511 L .37678 .20738 L 0 .028 .128 r
F
.37375 .20844 m .37191 .20619 L .37494 .20511 L F
.58795 .20999 m .58948 .20654 L .59111 .20881 L 0 .031 .131 r
F
.58795 .20999 m .58633 .20771 L .58948 .20654 L F
.33725 .20779 m .33837 .20454 L .34025 .20673 L 0 .027 .126 r
F
.33725 .20779 m .33536 .20559 L .33837 .20454 L F
.24839 .20738 m .24938 .20409 L .25135 .20628 L 0 .026 .125 r
F
.24839 .20738 m .24642 .20521 L .24938 .20409 L F
.29281 .20763 m .29387 .20442 L .2958 .20652 L 0 .027 .126 r
F
.29281 .20763 m .29088 .20555 L .29387 .20442 L F
.72436 .20788 m .72611 .20464 L .72759 .20672 L F
.72436 .20788 m .72288 .20582 L .72611 .20464 L F
.54353 .20987 m .54499 .20663 L .54666 .20879 L 0 .031 .131 r
F
.54353 .20987 m .54186 .20771 L .54499 .20663 L F
.49118 .2101 m .49255 .20686 L .49428 .20891 L 0 .031 .132 r
F
.49118 .2101 m .48945 .20802 L .49255 .20686 L F
.45467 .20945 m .45599 .2062 L .45775 .20834 L 0 .03 .13 r
F
.45467 .20945 m .45291 .20728 L .45599 .2062 L F
.77671 .20771 m .77856 .20455 L .77997 .20659 L 0 .027 .126 r
F
.77671 .20771 m .77529 .20566 L .77856 .20455 L F
.73229 .20753 m .73404 .20416 L .73551 .20627 L 0 .026 .126 r
F
.73229 .20753 m .73081 .20544 L .73404 .20416 L F
.66408 .20865 m .66574 .20547 L .66728 .20755 L 0 .029 .129 r
F
.66408 .20865 m .66254 .20655 L .66574 .20547 L F
.59588 .20977 m .59742 .20629 L .59904 .20847 L 0 .031 .131 r
F
.59588 .20977 m .59426 .20755 L .59742 .20629 L F
.4991 .2098 m .50049 .20664 L .5022 .20865 L 0 .031 .132 r
F
.4991 .2098 m .49738 .20777 L .50049 .20664 L F
.41816 .20892 m .41943 .20557 L .42122 .20781 L 0 .029 .129 r
F
.41816 .20892 m .41637 .20667 L .41943 .20557 L F
.78465 .20739 m .78649 .20409 L .7879 .20613 L 0 .026 .125 r
F
.78465 .20739 m .78323 .20534 L .78649 .20409 L F
.60381 .2094 m .60537 .2061 L .60697 .20822 L 0 .03 .13 r
F
.60381 .2094 m .6022 .20727 L .60537 .2061 L F
.55145 .20964 m .55293 .20627 L .55459 .20838 L 0 .031 .131 r
F
.55145 .20964 m .54979 .20755 L .55293 .20627 L F
.79258 .20701 m .79445 .20389 L .79585 .20592 L 0 .026 .125 r
F
.79258 .20701 m .79117 .20498 L .79445 .20389 L F
.74022 .20724 m .742 .20402 L .74347 .20615 L F
.74022 .20724 m .73875 .20513 L .742 .20402 L F
.25629 .20727 m .25728 .20401 L .25925 .20612 L F
.25629 .20727 m .25432 .20515 L .25728 .20401 L F
.30072 .2075 m .30178 .20429 L .30371 .2064 L 0 .027 .126 r
F
.30072 .2075 m .29879 .2054 L .30178 .20429 L F
.55938 .20926 m .56087 .20588 L .56252 .20802 L 0 .03 .13 r
F
.55938 .20926 m .55772 .20713 L .56087 .20588 L F
.46259 .20931 m .46392 .20604 L .46568 .20815 L F
.46259 .20931 m .46083 .20722 L .46392 .20604 L F
.50702 .20955 m .50843 .20627 L .51013 .20835 L 0 .031 .131 r
F
.50702 .20955 m .50531 .20748 L .50843 .20627 L F
.38165 .20847 m .38286 .205 L .38469 .20724 L 0 .028 .128 r
F
.38165 .20847 m .37982 .20621 L .38286 .205 L F
.34514 .20782 m .34628 .20458 L .34816 .20672 L 0 .027 .127 r
F
.34514 .20782 m .34327 .20566 L .34628 .20458 L F
.56731 .20893 m .56881 .20566 L .57045 .2078 L 0 .03 .13 r
F
.56731 .20893 m .56566 .20678 L .56881 .20566 L F
.61174 .20916 m .61331 .20573 L .6149 .20789 L F
.61174 .20916 m .61014 .20703 L .61331 .20573 L F
.67202 .20852 m .67369 .20527 L .67522 .20733 L 0 .029 .129 r
F
.67202 .20852 m .67049 .20645 L .67369 .20527 L F
.67995 .2081 m .68163 .20473 L .68315 .20679 L 0 .028 .127 r
F
.67995 .2081 m .67842 .20603 L .68163 .20473 L F
.21976 .20678 m .22068 .20369 L .2227 .20575 L 0 .026 .125 r
F
.21976 .20678 m .21775 .20472 L .22068 .20369 L F
.26419 .20702 m .26521 .20375 L .26717 .20582 L F
.26419 .20702 m .26223 .20494 L .26521 .20375 L F
.62759 .20834 m .62919 .20497 L .63077 .20707 L 0 .028 .128 r
F
.62759 .20834 m .62601 .20625 L .62919 .20497 L F
.61967 .2088 m .62124 .20534 L .62284 .20753 L 0 .029 .129 r
F
.61967 .2088 m .61807 .20662 L .62124 .20534 L F
.42608 .20882 m .42736 .20537 L .42914 .20761 L F
.42608 .20882 m .42429 .20659 L .42736 .20537 L F
.38957 .20816 m .39079 .20478 L .39262 .20692 L 0 .028 .128 r
F
.38957 .20816 m .38774 .20601 L .39079 .20478 L F
.51495 .20928 m .51636 .20591 L .51806 .20805 L 0 .03 .13 r
F
.51495 .20928 m .51325 .20715 L .51636 .20591 L F
.39749 .20775 m .39872 .20454 L .40054 .20661 L 0 .028 .127 r
F
.39749 .20775 m .39567 .20569 L .39872 .20454 L F
.27211 .20668 m .27312 .20355 L .27508 .20562 L 0 .026 .125 r
F
.27211 .20668 m .27015 .20461 L .27312 .20355 L F
.74817 .20716 m .74996 .2039 L .75142 .20603 L 0 .027 .126 r
F
.74817 .20716 m .74671 .20506 L .74996 .2039 L F
.68788 .20782 m .68957 .20446 L .6911 .20667 L 0 .028 .127 r
F
.68788 .20782 m .68636 .20561 L .68957 .20446 L F
.52287 .20894 m .5243 .20554 L .52599 .2077 L 0 .03 .13 r
F
.52287 .20894 m .52118 .20679 L .5243 .20554 L F
.35305 .20765 m .3542 .20448 L .35607 .20652 L 0 .028 .127 r
F
.35305 .20765 m .35118 .2056 L .3542 .20448 L F
.30861 .20744 m .30969 .20427 L .31161 .20639 L 0 .027 .127 r
F
.30861 .20744 m .3067 .20533 L .30969 .20427 L F
.63552 .20811 m .63714 .20491 L .63871 .20707 L 0 .029 .128 r
F
.63552 .20811 m .63395 .20598 L .63714 .20491 L F
.434 .20856 m .43529 .20518 L .43707 .20736 L 0 .029 .129 r
F
.434 .20856 m .43221 .2064 L .43529 .20518 L F
.47051 .20925 m .47186 .2058 L .4736 .2081 L 0 .03 .131 r
F
.47051 .20925 m .46876 .20698 L .47186 .2058 L F
.57524 .20887 m .57675 .2057 L .57839 .20782 L 0 .03 .13 r
F
.57524 .20887 m .5736 .20675 L .57675 .2057 L F
.40541 .20761 m .40664 .20451 L .40846 .20656 L 0 .028 .127 r
F
.40541 .20761 m .40359 .20556 L .40664 .20451 L F
.36097 .20741 m .36213 .20425 L .36399 .20629 L 0 .027 .127 r
F
.36097 .20741 m .3591 .20538 L .36213 .20425 L F
.22765 .20676 m .22859 .2036 L .23059 .20565 L 0 .026 .125 r
F
.22765 .20676 m .22564 .20471 L .22859 .2036 L F
.75612 .20703 m .75792 .20376 L .75937 .20592 L 0 .027 .126 r
F
.75612 .20703 m .75467 .20489 L .75792 .20376 L F
.69583 .2077 m .69753 .20428 L .69904 .20648 L 0 .028 .127 r
F
.69583 .2077 m .69431 .2055 L .69753 .20428 L F
.44192 .20837 m .44322 .20509 L .44499 .20728 L 0 .029 .129 r
F
.44192 .20837 m .44014 .20617 L .44322 .20509 L F
.5308 .20882 m .53224 .20541 L .53392 .20766 L 0 .03 .13 r
F
.5308 .20882 m .52911 .20656 L .53224 .20541 L F
.28 .20669 m .28103 .20351 L .28298 .20563 L 0 .026 .125 r
F
.28 .20669 m .27805 .20457 L .28103 .20351 L F
.31651 .20737 m .31761 .20406 L .31952 .20616 L 0 .027 .127 r
F
.31651 .20737 m .3146 .20527 L .31761 .20406 L F
.23555 .20652 m .23652 .20325 L .23851 .20533 L 0 .026 .125 r
F
.23555 .20652 m .23356 .20445 L .23652 .20325 L F
.70377 .20745 m .70548 .20402 L .70698 .20622 L 0 .027 .127 r
F
.70377 .20745 m .70226 .20525 L .70548 .20402 L F
.36888 .20726 m .37005 .2041 L .37191 .20619 L 0 .028 .127 r
F
.36888 .20726 m .36702 .20519 L .37005 .2041 L F
.47843 .20924 m .47979 .20572 L .48152 .20808 L 0 .031 .131 r
F
.47843 .20924 m .47669 .20691 L .47979 .20572 L F
.32443 .20705 m .32555 .20374 L .32744 .20584 L 0 .027 .126 r
F
.32443 .20705 m .32253 .20495 L .32555 .20374 L F
.64347 .20815 m .64509 .2048 L .64666 .20698 L 0 .029 .129 r
F
.64347 .20815 m .6419 .20599 L .64509 .2048 L F
.58317 .20884 m .5847 .20554 L .58633 .20771 L 0 .03 .131 r
F
.58317 .20884 m .58154 .20668 L .5847 .20554 L F
.76407 .20691 m .76589 .20367 L .76733 .20577 L 0 .027 .126 r
F
.76407 .20691 m .76263 .20479 L .76589 .20367 L F
.7117 .20716 m .71342 .2037 L .71492 .20589 L F
.7117 .20716 m .7102 .20496 L .71342 .2037 L F
.33235 .20676 m .33348 .20345 L .33536 .20559 L F
.33235 .20676 m .33046 .20463 L .33348 .20345 L F
.24346 .20633 m .24444 .20304 L .24642 .20521 L 0 .026 .125 r
F
.24346 .20633 m .24148 .20418 L .24444 .20304 L F
.53873 .20879 m .54018 .20546 L .54186 .20771 L 0 .03 .131 r
F
.53873 .20879 m .53705 .20654 L .54018 .20546 L F
.65141 .20792 m .65304 .20468 L .6546 .20677 L 0 .029 .129 r
F
.65141 .20792 m .64985 .20581 L .65304 .20468 L F
.44983 .20839 m .45114 .20511 L .45291 .20728 L 0 .03 .13 r
F
.44983 .20839 m .44807 .20619 L .45114 .20511 L F
.41331 .20773 m .41457 .20446 L .41637 .20667 L 0 .029 .128 r
F
.41331 .20773 m .41151 .20551 L .41457 .20446 L F
.2879 .20665 m .28894 .20346 L .29088 .20555 L 0 .027 .126 r
F
.2879 .20665 m .28596 .20455 L .28894 .20346 L F
.71964 .20694 m .72139 .20364 L .72288 .20582 L F
.71964 .20694 m .71815 .20476 L .72139 .20364 L F
.77202 .20674 m .77386 .20361 L .77529 .20566 L F
.77202 .20674 m .77059 .20469 L .77386 .20361 L F
.48635 .20919 m .48772 .20579 L .48945 .20802 L 0 .031 .132 r
F
.48635 .20919 m .48462 .20692 L .48772 .20579 L F
.65934 .20771 m .66099 .20451 L .66254 .20655 L 0 .029 .129 r
F
.65934 .20771 m .65779 .20564 L .66099 .20451 L F
.59111 .20881 m .59264 .20532 L .59426 .20755 L 0 .031 .131 r
F
.59111 .20881 m .58948 .20654 L .59264 .20532 L F
.49428 .20891 m .49566 .20574 L .49738 .20777 L 0 .031 .132 r
F
.49428 .20891 m .49255 .20686 L .49566 .20574 L F
.73551 .20627 m .73729 .203 L .73875 .20513 L 0 .026 .125 r
F
.73551 .20627 m .73404 .20416 L .73729 .203 L F
.59904 .20847 m .60059 .20512 L .6022 .20727 L 0 .03 .13 r
F
.59904 .20847 m .59742 .20629 L .60059 .20512 L F
.72759 .20672 m .72934 .20334 L .73081 .20544 L 0 .027 .126 r
F
.72759 .20672 m .72611 .20464 L .72934 .20334 L F
.37678 .20738 m .37798 .20395 L .37982 .20621 L 0 .028 .128 r
F
.37678 .20738 m .37494 .20511 L .37798 .20395 L F
.25135 .20628 m .25235 .20296 L .25432 .20515 L 0 .026 .125 r
F
.25135 .20628 m .24938 .20409 L .25235 .20296 L F
.34025 .20673 m .34139 .2035 L .34327 .20566 L 0 .027 .126 r
F
.34025 .20673 m .33837 .20454 L .34139 .2035 L F
.2958 .20652 m .29686 .20329 L .29879 .2054 L F
.2958 .20652 m .29387 .20442 L .29686 .20329 L F
.7879 .20613 m .78976 .20294 L .79117 .20498 L 0 .026 .125 r
F
.7879 .20613 m .78649 .20409 L .78976 .20294 L F
.45775 .20834 m .45907 .20512 L .46083 .20722 L 0 .03 .13 r
F
.45775 .20834 m .45599 .2062 L .45907 .20512 L F
.77997 .20659 m .78182 .2033 L .78323 .20534 L 0 .027 .126 r
F
.77997 .20659 m .77856 .20455 L .78182 .2033 L F
.54666 .20879 m .54812 .20537 L .54979 .20755 L 0 .031 .131 r
F
.54666 .20879 m .54499 .20663 L .54812 .20537 L F
.55459 .20838 m .55607 .20499 L .55772 .20713 L 0 .03 .13 r
F
.55459 .20838 m .55293 .20627 L .55607 .20499 L F
.66728 .20755 m .66895 .20438 L .67049 .20645 L 0 .029 .129 r
F
.66728 .20755 m .66574 .20547 L .66895 .20438 L F
.5022 .20865 m .5036 .20548 L .50531 .20748 L 0 .031 .132 r
F
.5022 .20865 m .50049 .20664 L .5036 .20548 L F
.60697 .20822 m .60854 .20491 L .61014 .20703 L 0 .03 .13 r
F
.60697 .20822 m .60537 .2061 L .60854 .20491 L F
.56252 .20802 m .56401 .20463 L .56566 .20678 L F
.56252 .20802 m .56087 .20588 L .56401 .20463 L F
.42122 .20781 m .42249 .20434 L .42429 .20659 L 0 .029 .129 r
F
.42122 .20781 m .41943 .20557 L .42249 .20434 L F
.25925 .20612 m .26026 .20284 L .26223 .20494 L 0 .026 .125 r
F
.25925 .20612 m .25728 .20401 L .26026 .20284 L F
.6149 .20789 m .61648 .20443 L .61807 .20662 L 0 .029 .129 r
F
.6149 .20789 m .61331 .20573 L .61648 .20443 L F
.68315 .20679 m .68484 .20356 L .68636 .20561 L 0 .028 .127 r
F
.68315 .20679 m .68163 .20473 L .68484 .20356 L F
.38469 .20724 m .38591 .20378 L .38774 .20601 L 0 .028 .128 r
F
.38469 .20724 m .38286 .205 L .38591 .20378 L F
.79585 .20592 m .79773 .2028 L .79913 .20484 L 0 .026 .125 r
F
.79585 .20592 m .79445 .20389 L .79773 .2028 L F
.74347 .20615 m .74525 .20291 L .74671 .20506 L 0 .026 .126 r
F
.74347 .20615 m .742 .20402 L .74525 .20291 L F
.51013 .20835 m .51154 .20505 L .51325 .20715 L 0 .031 .131 r
F
.51013 .20835 m .50843 .20627 L .51154 .20505 L F
.46568 .20815 m .46701 .20485 L .46876 .20698 L 0 .03 .13 r
F
.46568 .20815 m .46392 .20604 L .46701 .20485 L F
.30371 .2064 m .30477 .20322 L .3067 .20533 L 0 .027 .126 r
F
.30371 .2064 m .30178 .20429 L .30477 .20322 L F
.63077 .20707 m .63237 .20385 L .63395 .20598 L 0 .028 .128 r
F
.63077 .20707 m .62919 .20497 L .63237 .20385 L F
.62284 .20753 m .62442 .20405 L .62601 .20625 L 0 .029 .129 r
F
.62284 .20753 m .62124 .20534 L .62442 .20405 L F
.67522 .20733 m .6769 .20398 L .67842 .20603 L 0 .029 .128 r
F
.67522 .20733 m .67369 .20527 L .6769 .20398 L F
.26717 .20582 m .26819 .20256 L .27015 .20461 L 0 .026 .125 r
F
.26717 .20582 m .26521 .20375 L .26819 .20256 L F
.57045 .2078 m .57196 .20462 L .5736 .20675 L 0 .03 .13 r
F
.57045 .2078 m .56881 .20566 L .57196 .20462 L F
.39262 .20692 m .39384 .20355 L .39567 .20569 L 0 .028 .127 r
F
.39262 .20692 m .39079 .20478 L .39384 .20355 L F
.34816 .20672 m .3493 .20348 L .35118 .2056 L F
.34816 .20672 m .34628 .20458 L .3493 .20348 L F
.51806 .20805 m .51948 .20464 L .52118 .20679 L 0 .03 .13 r
F
.51806 .20805 m .51636 .20591 L .51948 .20464 L F
.42914 .20761 m .43043 .20414 L .43221 .2064 L 0 .029 .129 r
F
.42914 .20761 m .42736 .20537 L .43043 .20414 L F
.52599 .2077 m .52743 .20442 L .52911 .20656 L 0 .03 .13 r
F
.52599 .2077 m .5243 .20554 L .52743 .20442 L F
.40054 .20661 m .40177 .20349 L .40359 .20556 L 0 .028 .127 r
F
.40054 .20661 m .39872 .20454 L .40177 .20349 L F
.2227 .20575 m .22363 .20265 L .22564 .20471 L 0 .026 .125 r
F
.2227 .20575 m .22068 .20369 L .22363 .20265 L F
.6911 .20667 m .69279 .2033 L .69431 .2055 L 0 .028 .127 r
F
.6911 .20667 m .68957 .20446 L .69279 .2033 L F
.75142 .20603 m .75322 .20275 L .75467 .20489 L 0 .027 .126 r
F
.75142 .20603 m .74996 .2039 L .75322 .20275 L F
.43707 .20736 m .43836 .20396 L .44014 .20617 L 0 .029 .129 r
F
.43707 .20736 m .43529 .20518 L .43836 .20396 L F
.27508 .20562 m .2761 .2025 L .27805 .20457 L 0 .026 .125 r
F
.27508 .20562 m .27312 .20355 L .2761 .2025 L F
.35607 .20652 m .35723 .20333 L .3591 .20538 L 0 .028 .127 r
F
.35607 .20652 m .3542 .20448 L .35723 .20333 L F
.4736 .2081 m .47495 .20459 L .47669 .20691 L 0 .03 .13 r
F
.4736 .2081 m .47186 .2058 L .47495 .20459 L F
.31161 .20639 m .31269 .20315 L .3146 .20527 L 0 .027 .127 r
F
.31161 .20639 m .30969 .20427 L .31269 .20315 L F
.63871 .20707 m .64033 .2038 L .6419 .20599 L 0 .029 .129 r
F
.63871 .20707 m .63714 .20491 L .64033 .2038 L F
.69904 .20648 m .70075 .20306 L .70226 .20525 L 0 .027 .127 r
F
.69904 .20648 m .69753 .20428 L .70075 .20306 L F
.57839 .20782 m .57991 .20455 L .58154 .20668 L 0 .03 .13 r
F
.57839 .20782 m .57675 .2057 L .57991 .20455 L F
.36399 .20629 m .36516 .20312 L .36702 .20519 L 0 .028 .127 r
F
.36399 .20629 m .36213 .20425 L .36516 .20312 L F
.23059 .20565 m .23155 .2024 L .23356 .20445 L 0 .026 .125 r
F
.23059 .20565 m .22859 .2036 L .23155 .2024 L F
.40846 .20656 m .40969 .20346 L .41151 .20551 L 0 .028 .128 r
F
.40846 .20656 m .40664 .20451 L .40969 .20346 L F
.53392 .20766 m .53537 .20429 L .53705 .20654 L 0 .03 .13 r
F
.53392 .20766 m .53224 .20541 L .53537 .20429 L F
.75937 .20592 m .76118 .20262 L .76263 .20479 L 0 .027 .126 r
F
.75937 .20592 m .75792 .20376 L .76118 .20262 L F
.31952 .20616 m .32063 .20285 L .32253 .20495 L F
.31952 .20616 m .31761 .20406 L .32063 .20285 L F
.44499 .20728 m .44629 .204 L .44807 .20619 L 0 .029 .129 r
F
.44499 .20728 m .44322 .20509 L .44629 .204 L F
.23851 .20533 m .23948 .20208 L .24148 .20418 L 0 .026 .125 r
F
.23851 .20533 m .23652 .20325 L .23948 .20208 L F
.70698 .20622 m .7087 .20278 L .7102 .20496 L 0 .027 .126 r
F
.70698 .20622 m .70548 .20402 L .7087 .20278 L F
.32744 .20584 m .32856 .20252 L .33046 .20463 L F
.32744 .20584 m .32555 .20374 L .32856 .20252 L F
.28298 .20563 m .28401 .20244 L .28596 .20455 L F
.28298 .20563 m .28103 .20351 L .28401 .20244 L F
.48152 .20808 m .48289 .20457 L .48462 .20692 L 0 .031 .131 r
F
.48152 .20808 m .47979 .20572 L .48289 .20457 L F
.64666 .20698 m .64828 .20362 L .64985 .20581 L 0 .029 .129 r
F
.64666 .20698 m .64509 .2048 L .64828 .20362 L F
.71492 .20589 m .71666 .20257 L .71815 .20476 L 0 .027 .126 r
F
.71492 .20589 m .71342 .2037 L .71666 .20257 L F
.58633 .20771 m .58786 .20438 L .58948 .20654 L 0 .03 .131 r
F
.58633 .20771 m .5847 .20554 L .58786 .20438 L F
.37191 .20619 m .37309 .203 L .37494 .20511 L 0 .028 .127 r
F
.37191 .20619 m .37005 .2041 L .37309 .203 L F
.76733 .20577 m .76916 .20259 L .77059 .20469 L 0 .027 .126 r
F
.76733 .20577 m .76589 .20367 L .76916 .20259 L F
.33536 .20559 m .33649 .20241 L .33837 .20454 L F
.33536 .20559 m .33348 .20345 L .33649 .20241 L F
.24642 .20521 m .2474 .2019 L .24938 .20409 L 0 .026 .125 r
F
.24642 .20521 m .24444 .20304 L .2474 .2019 L F
.6546 .20677 m .65624 .20357 L .65779 .20564 L 0 .029 .129 r
F
.6546 .20677 m .65304 .20468 L .65624 .20357 L F
.54186 .20771 m .54332 .20438 L .54499 .20663 L 0 .031 .131 r
F
.54186 .20771 m .54018 .20546 L .54332 .20438 L F
.45291 .20728 m .45423 .20405 L .45599 .2062 L 0 .03 .13 r
F
.45291 .20728 m .45114 .20511 L .45423 .20405 L F
.29088 .20555 m .29193 .20232 L .29387 .20442 L 0 .027 .126 r
F
.29088 .20555 m .28894 .20346 L .29193 .20232 L F
.59426 .20755 m .5958 .2041 L .59742 .20629 L 0 .03 .13 r
F
.59426 .20755 m .59264 .20532 L .5958 .2041 L F
.41637 .20667 m .41763 .20336 L .41943 .20557 L 0 .029 .129 r
F
.41637 .20667 m .41457 .20446 L .41763 .20336 L F
.72288 .20582 m .72462 .20246 L .72611 .20464 L 0 .027 .126 r
F
.72288 .20582 m .72139 .20364 L .72462 .20246 L F
.48945 .20802 m .49083 .20464 L .49255 .20686 L 0 .031 .132 r
F
.48945 .20802 m .48772 .20579 L .49083 .20464 L F
.73081 .20544 m .73257 .20205 L .73404 .20416 L 0 .026 .126 r
F
.73081 .20544 m .72934 .20334 L .73257 .20205 L F
.77529 .20566 m .77713 .2025 L .77856 .20455 L 0 .027 .127 r
F
.77529 .20566 m .77386 .20361 L .77713 .2025 L F
.66254 .20655 m .6642 .20342 L .66574 .20547 L 0 .029 .129 r
F
.66254 .20655 m .66099 .20451 L .6642 .20342 L F
.6022 .20727 m .60376 .20399 L .60537 .2061 L 0 .03 .13 r
F
.6022 .20727 m .60059 .20512 L .60376 .20399 L F
.37982 .20621 m .38102 .20275 L .38286 .205 L 0 .028 .127 r
F
.37982 .20621 m .37798 .20395 L .38102 .20275 L F
.78323 .20534 m .78508 .20205 L .78649 .20409 L 0 .027 .126 r
F
.78323 .20534 m .78182 .2033 L .78508 .20205 L F
.54979 .20755 m .55126 .20408 L .55293 .20627 L 0 .03 .131 r
F
.54979 .20755 m .54812 .20537 L .55126 .20408 L F
.73875 .20513 m .74053 .20188 L .742 .20402 L 0 .026 .125 r
F
.73875 .20513 m .73729 .203 L .74053 .20188 L F
.49738 .20777 m .49877 .20463 L .50049 .20664 L 0 .031 .132 r
F
.49738 .20777 m .49566 .20574 L .49877 .20463 L F
.25432 .20515 m .25532 .20183 L .25728 .20401 L 0 .026 .125 r
F
.25432 .20515 m .25235 .20296 L .25532 .20183 L F
.55772 .20713 m .55921 .20374 L .56087 .20588 L 0 .03 .13 r
F
.55772 .20713 m .55607 .20499 L .55921 .20374 L F
.29879 .2054 m .29986 .20216 L .30178 .20429 L 0 .027 .126 r
F
.29879 .2054 m .29686 .20329 L .29986 .20216 L F
.79117 .20498 m .79305 .20185 L .79445 .20389 L 0 .026 .125 r
F
.79117 .20498 m .78976 .20294 L .79305 .20185 L F
.34327 .20566 m .3444 .20243 L .34628 .20458 L 0 .027 .127 r
F
.34327 .20566 m .34139 .2035 L .3444 .20243 L F
.46083 .20722 m .46216 .20393 L .46392 .20604 L 0 .03 .131 r
F
.46083 .20722 m .45907 .20512 L .46216 .20393 L F
.56566 .20678 m .56716 .20349 L .56881 .20566 L 0 .029 .129 r
F
.56566 .20678 m .56401 .20463 L .56716 .20349 L F
.61014 .20703 m .6117 .2036 L .61331 .20573 L 0 .03 .13 r
F
.61014 .20703 m .60854 .20491 L .6117 .2036 L F
.42429 .20659 m .42557 .2031 L .42736 .20537 L 0 .029 .129 r
F
.42429 .20659 m .42249 .20434 L .42557 .2031 L F
.50531 .20748 m .50671 .20424 L .50843 .20627 L 0 .031 .131 r
F
.50531 .20748 m .5036 .20548 L .50671 .20424 L F
.61807 .20662 m .61965 .20314 L .62124 .20534 L 0 .029 .129 r
F
.61807 .20662 m .61648 .20443 L .61965 .20314 L F
.67049 .20645 m .67216 .20321 L .67369 .20527 L F
.67049 .20645 m .66895 .20438 L .67216 .20321 L F
.38774 .20601 m .38896 .20256 L .39079 .20478 L 0 .028 .127 r
F
.38774 .20601 m .38591 .20378 L .38896 .20256 L F
.62601 .20625 m .6276 .20276 L .62919 .20497 L 0 .028 .128 r
F
.62601 .20625 m .62442 .20405 L .6276 .20276 L F
.67842 .20603 m .6801 .20269 L .68163 .20473 L F
.67842 .20603 m .6769 .20398 L .6801 .20269 L F
.26223 .20494 m .26324 .20166 L .26521 .20375 L 0 .026 .125 r
F
.26223 .20494 m .26026 .20284 L .26324 .20166 L F
.51325 .20715 m .51466 .20379 L .51636 .20591 L 0 .03 .13 r
F
.51325 .20715 m .51154 .20505 L .51466 .20379 L F
.68636 .20561 m .68806 .20242 L .68957 .20446 L 0 .028 .127 r
F
.68636 .20561 m .68484 .20356 L .68806 .20242 L F
.46876 .20698 m .47011 .20365 L .47186 .2058 L 0 .03 .13 r
F
.46876 .20698 m .46701 .20485 L .47011 .20365 L F
.39567 .20569 m .39689 .2024 L .39872 .20454 L 0 .028 .127 r
F
.39567 .20569 m .39384 .20355 L .39689 .2024 L F
.52118 .20679 m .52261 .20339 L .5243 .20554 L 0 .03 .13 r
F
.52118 .20679 m .51948 .20464 L .52261 .20339 L F
.27015 .20461 m .27116 .20149 L .27312 .20355 L 0 .026 .125 r
F
.27015 .20461 m .26819 .20256 L .27116 .20149 L F
.74671 .20506 m .7485 .20174 L .74996 .2039 L 0 .026 .126 r
F
.74671 .20506 m .74525 .20291 L .7485 .20174 L F
.43221 .2064 m .4335 .20291 L .43529 .20518 L 0 .029 .129 r
F
.43221 .2064 m .43043 .20414 L .4335 .20291 L F
.63395 .20598 m .63556 .20275 L .63714 .20491 L 0 .028 .128 r
F
.63395 .20598 m .63237 .20385 L .63556 .20275 L F
.3067 .20533 m .30777 .20215 L .30969 .20427 L 0 .027 .127 r
F
.3067 .20533 m .30477 .20322 L .30777 .20215 L F
.35118 .2056 m .35233 .20239 L .3542 .20448 L 0 .028 .127 r
F
.35118 .2056 m .3493 .20348 L .35233 .20239 L F
.5736 .20675 m .57511 .20357 L .57675 .2057 L 0 .03 .13 r
F
.5736 .20675 m .57196 .20462 L .57511 .20357 L F
.52911 .20656 m .53055 .2033 L .53224 .20541 L F
.52911 .20656 m .52743 .20442 L .53055 .2033 L F
.69431 .2055 m .69601 .20208 L .69753 .20428 L 0 .027 .127 r
F
.69431 .2055 m .69279 .2033 L .69601 .20208 L F
.44014 .20617 m .44144 .20289 L .44322 .20509 L 0 .029 .129 r
F
.44014 .20617 m .43836 .20396 L .44144 .20289 L F
.75467 .20489 m .75647 .2016 L .75792 .20376 L 0 .027 .126 r
F
.75467 .20489 m .75322 .20275 L .75647 .2016 L F
.40359 .20556 m .40482 .20245 L .40664 .20451 L 0 .028 .128 r
F
.40359 .20556 m .40177 .20349 L .40482 .20245 L F
.22564 .20471 m .22658 .20155 L .22859 .2036 L 0 .026 .126 r
F
.22564 .20471 m .22363 .20265 L .22658 .20155 L F
.47669 .20691 m .47805 .20338 L .47979 .20572 L 0 .03 .13 r
F
.47669 .20691 m .47495 .20459 L .47805 .20338 L F
.3591 .20538 m .36026 .20217 L .36213 .20425 L 0 .028 .127 r
F
.3591 .20538 m .35723 .20333 L .36026 .20217 L F
.27805 .20457 m .27908 .20144 L .28103 .20351 L 0 .026 .125 r
F
.27805 .20457 m .2761 .2025 L .27908 .20144 L F
.70226 .20525 m .70397 .20184 L .70548 .20402 L 0 .027 .127 r
F
.70226 .20525 m .70075 .20306 L .70397 .20184 L F
.3146 .20527 m .3157 .20196 L .31761 .20406 L F
.3146 .20527 m .31269 .20315 L .3157 .20196 L F
.6419 .20599 m .64352 .20259 L .64509 .2048 L 0 .029 .129 r
F
.6419 .20599 m .64033 .2038 L .64352 .20259 L F
.23356 .20445 m .23452 .20119 L .23652 .20325 L 0 .026 .125 r
F
.23356 .20445 m .23155 .2024 L .23452 .20119 L F
.58154 .20668 m .58307 .2034 L .5847 .20554 L 0 .03 .13 r
F
.58154 .20668 m .57991 .20455 L .58307 .2034 L F
.32253 .20495 m .32364 .20163 L .32555 .20374 L 0 .027 .126 r
F
.32253 .20495 m .32063 .20285 L .32364 .20163 L F
.7102 .20496 m .71192 .20154 L .71342 .2037 L F
.7102 .20496 m .7087 .20278 L .71192 .20154 L F
.36702 .20519 m .3682 .20201 L .37005 .2041 L 0 .028 .127 r
F
.36702 .20519 m .36516 .20312 L .3682 .20201 L F
.53705 .20654 m .5385 .20321 L .54018 .20546 L 0 .03 .13 r
F
.53705 .20654 m .53537 .20429 L .5385 .20321 L F
.76263 .20479 m .76445 .20148 L .76589 .20367 L 0 .027 .126 r
F
.76263 .20479 m .76118 .20262 L .76445 .20148 L F
.24148 .20418 m .24245 .20092 L .24444 .20304 L 0 .026 .125 r
F
.24148 .20418 m .23948 .20208 L .24245 .20092 L F
.33046 .20463 m .33158 .20134 L .33348 .20345 L 0 .027 .126 r
F
.33046 .20463 m .32856 .20252 L .33158 .20134 L F
.41151 .20551 m .41275 .20241 L .41457 .20446 L 0 .028 .128 r
F
.41151 .20551 m .40969 .20346 L .41275 .20241 L F
.44807 .20619 m .44937 .20293 L .45114 .20511 L 0 .03 .13 r
F
.44807 .20619 m .44629 .204 L .44937 .20293 L F
.64985 .20581 m .65148 .20249 L .65304 .20468 L 0 .029 .129 r
F
.64985 .20581 m .64828 .20362 L .65148 .20249 L F
.48462 .20692 m .48599 .20346 L .48772 .20579 L 0 .031 .131 r
F
.48462 .20692 m .48289 .20457 L .48599 .20346 L F
.71815 .20476 m .71989 .20145 L .72139 .20364 L 0 .027 .126 r
F
.71815 .20476 m .71666 .20257 L .71989 .20145 L F
.28596 .20455 m .287 .20137 L .28894 .20346 L F
.28596 .20455 m .28401 .20244 L .287 .20137 L F
.58948 .20654 m .59102 .20319 L .59264 .20532 L 0 .03 .13 r
F
.58948 .20654 m .58786 .20438 L .59102 .20319 L F
.37494 .20511 m .37613 .20184 L .37798 .20395 L 0 .028 .127 r
F
.37494 .20511 m .37309 .203 L .37613 .20184 L F
.77059 .20469 m .77243 .20151 L .77386 .20361 L 0 .027 .126 r
F
.77059 .20469 m .76916 .20259 L .77243 .20151 L F
.59742 .20629 m .59897 .20297 L .60059 .20512 L 0 .03 .13 r
F
.59742 .20629 m .5958 .2041 L .59897 .20297 L F
.24938 .20409 m .25037 .20078 L .25235 .20296 L 0 .026 .125 r
F
.24938 .20409 m .2474 .2019 L .25037 .20078 L F
.65779 .20564 m .65945 .20246 L .66099 .20451 L 0 .029 .129 r
F
.65779 .20564 m .65624 .20357 L .65945 .20246 L F
.33837 .20454 m .3395 .20136 L .34139 .2035 L 0 .027 .126 r
F
.33837 .20454 m .33649 .20241 L .3395 .20136 L F
.73404 .20416 m .73581 .20087 L .73729 .203 L 0 .026 .125 r
F
.73404 .20416 m .73257 .20205 L .73581 .20087 L F
.72611 .20464 m .72785 .20118 L .72934 .20334 L 0 .027 .126 r
F
.72611 .20464 m .72462 .20246 L .72785 .20118 L F
.29387 .20442 m .29493 .20116 L .29686 .20329 L F
.29387 .20442 m .29193 .20232 L .29493 .20116 L F
.54499 .20663 m .54645 .20311 L .54812 .20537 L 0 .031 .131 r
F
.54499 .20663 m .54332 .20438 L .54645 .20311 L F
.49255 .20686 m .49394 .20355 L .49566 .20574 L 0 .031 .132 r
F
.49255 .20686 m .49083 .20464 L .49394 .20355 L F
.45599 .2062 m .45731 .20299 L .45907 .20512 L 0 .03 .13 r
F
.45599 .2062 m .45423 .20405 L .45731 .20299 L F
.41943 .20557 m .4207 .20211 L .42249 .20434 L 0 .029 .128 r
F
.41943 .20557 m .41763 .20336 L .4207 .20211 L F
.55293 .20627 m .5544 .20279 L .55607 .20499 L 0 .03 .13 r
F
.55293 .20627 m .55126 .20408 L .5544 .20279 L F
.78649 .20409 m .78835 .20089 L .78976 .20294 L 0 .026 .125 r
F
.78649 .20409 m .78508 .20205 L .78835 .20089 L F
.77856 .20455 m .7804 .20125 L .78182 .2033 L 0 .027 .126 r
F
.77856 .20455 m .77713 .2025 L .7804 .20125 L F
.38286 .205 m .38407 .20155 L .38591 .20378 L 0 .028 .127 r
F
.38286 .205 m .38102 .20275 L .38407 .20155 L F
.56087 .20588 m .56236 .20248 L .56401 .20463 L 0 .029 .129 r
F
.56087 .20588 m .55921 .20374 L .56236 .20248 L F
.60537 .2061 m .60693 .20283 L .60854 .20491 L 0 .03 .13 r
F
.60537 .2061 m .60376 .20399 L .60693 .20283 L F
.66574 .20547 m .66741 .20234 L .66895 .20438 L 0 .029 .129 r
F
.66574 .20547 m .6642 .20342 L .66741 .20234 L F
.61331 .20573 m .61488 .20229 L .61648 .20443 L F
.61331 .20573 m .6117 .2036 L .61488 .20229 L F
.50049 .20664 m .50188 .20347 L .5036 .20548 L 0 .031 .132 r
F
.50049 .20664 m .49877 .20463 L .50188 .20347 L F
.25728 .20401 m .25829 .20067 L .26026 .20284 L 0 .026 .125 r
F
.25728 .20401 m .25532 .20183 L .25829 .20067 L F
.62124 .20534 m .62283 .20185 L .62442 .20405 L 0 .028 .128 r
F
.62124 .20534 m .61965 .20314 L .62283 .20185 L F
.742 .20402 m .74379 .20075 L .74525 .20291 L 0 .026 .125 r
F
.742 .20402 m .74053 .20188 L .74379 .20075 L F
.42736 .20537 m .42864 .20186 L .43043 .20414 L 0 .029 .128 r
F
.42736 .20537 m .42557 .2031 L .42864 .20186 L F
.46392 .20604 m .46526 .20272 L .46701 .20485 L 0 .03 .13 r
F
.46392 .20604 m .46216 .20393 L .46526 .20272 L F
.50843 .20627 m .50983 .203 L .51154 .20505 L 0 .031 .131 r
F
.50843 .20627 m .50671 .20424 L .50983 .203 L F
.30178 .20429 m .30285 .20107 L .30477 .20322 L 0 .027 .126 r
F
.30178 .20429 m .29986 .20216 L .30285 .20107 L F
.68163 .20473 m .68332 .20153 L .68484 .20356 L 0 .028 .127 r
F
.68163 .20473 m .6801 .20269 L .68332 .20153 L F
.62919 .20497 m .63078 .20163 L .63237 .20385 L 0 .028 .128 r
F
.62919 .20497 m .6276 .20276 L .63078 .20163 L F
.79445 .20389 m .79633 .20076 L .79773 .2028 L 0 .026 .125 r
F
.79445 .20389 m .79305 .20185 L .79633 .20076 L F
.39079 .20478 m .39201 .20134 L .39384 .20355 L 0 .028 .127 r
F
.39079 .20478 m .38896 .20256 L .39201 .20134 L F
.56881 .20566 m .57031 .20242 L .57196 .20462 L 0 .03 .13 r
F
.56881 .20566 m .56716 .20349 L .57031 .20242 L F
.34628 .20458 m .34742 .20136 L .3493 .20348 L 0 .028 .127 r
F
.34628 .20458 m .3444 .20243 L .34742 .20136 L F
.51636 .20591 m .51778 .20251 L .51948 .20464 L 0 .03 .13 r
F
.51636 .20591 m .51466 .20379 L .51778 .20251 L F
.67369 .20527 m .67536 .20193 L .6769 .20398 L 0 .029 .129 r
F
.67369 .20527 m .67216 .20321 L .67536 .20193 L F
.26521 .20375 m .26622 .20047 L .26819 .20256 L 0 .026 .125 r
F
.26521 .20375 m .26324 .20166 L .26622 .20047 L F
.5243 .20554 m .52573 .20229 L .52743 .20442 L 0 .029 .129 r
F
.5243 .20554 m .52261 .20339 L .52573 .20229 L F
.68957 .20446 m .69128 .20125 L .69279 .2033 L 0 .028 .127 r
F
.68957 .20446 m .68806 .20242 L .69128 .20125 L F
.47186 .2058 m .47321 .20242 L .47495 .20459 L 0 .03 .13 r
F
.47186 .2058 m .47011 .20365 L .47321 .20242 L F
.43529 .20518 m .43658 .20169 L .43836 .20396 L 0 .028 .128 r
F
.43529 .20518 m .4335 .20291 L .43658 .20169 L F
.39872 .20454 m .39994 .20134 L .40177 .20349 L 0 .028 .127 r
F
.39872 .20454 m .39689 .2024 L .39994 .20134 L F
.74996 .2039 m .75176 .20057 L .75322 .20275 L 0 .026 .126 r
F
.74996 .2039 m .7485 .20174 L .75176 .20057 L F
.27312 .20355 m .27414 .20044 L .2761 .2025 L 0 .026 .125 r
F
.27312 .20355 m .27116 .20149 L .27414 .20044 L F
.63714 .20491 m .63875 .20161 L .64033 .2038 L 0 .029 .128 r
F
.63714 .20491 m .63556 .20275 L .63875 .20161 L F
.3542 .20448 m .35536 .20121 L .35723 .20333 L 0 .028 .127 r
F
.3542 .20448 m .35233 .20239 L .35536 .20121 L F
.30969 .20427 m .31077 .20103 L .31269 .20315 L 0 .027 .127 r
F
.30969 .20427 m .30777 .20215 L .31077 .20103 L F
.69753 .20428 m .69923 .20086 L .70075 .20306 L 0 .027 .126 r
F
.69753 .20428 m .69601 .20208 L .69923 .20086 L F
.53224 .20541 m .53369 .20219 L .53537 .20429 L 0 .03 .13 r
F
.53224 .20541 m .53055 .2033 L .53369 .20219 L F
.57675 .2057 m .57827 .20241 L .57991 .20455 L F
.57675 .2057 m .57511 .20357 L .57827 .20241 L F
.47979 .20572 m .48115 .20223 L .48289 .20457 L F
.47979 .20572 m .47805 .20338 L .48115 .20223 L F
.75792 .20376 m .75973 .20044 L .76118 .20262 L 0 .027 .126 r
F
.75792 .20376 m .75647 .2016 L .75973 .20044 L F
.44322 .20509 m .44452 .20181 L .44629 .204 L 0 .029 .129 r
F
.44322 .20509 m .44144 .20289 L .44452 .20181 L F
.70548 .20402 m .70719 .20063 L .7087 .20278 L 0 .027 .126 r
F
.70548 .20402 m .70397 .20184 L .70719 .20063 L F
.36213 .20425 m .3633 .20102 L .36516 .20312 L 0 .028 .127 r
F
.36213 .20425 m .36026 .20217 L .3633 .20102 L F
.22859 .2036 m .22954 .20034 L .23155 .2024 L 0 .026 .126 r
F
.22859 .2036 m .22658 .20155 L .22954 .20034 L F
.31761 .20406 m .31871 .20076 L .32063 .20285 L 0 .027 .127 r
F
.31761 .20406 m .3157 .20196 L .31871 .20076 L F
.40664 .20451 m .40788 .2014 L .40969 .20346 L 0 .028 .128 r
F
.40664 .20451 m .40482 .20245 L .40788 .2014 L F
.23652 .20325 m .23748 .20001 L .23948 .20208 L 0 .026 .125 r
F
.23652 .20325 m .23452 .20119 L .23748 .20001 L F
.71342 .2037 m .71516 .20041 L .71666 .20257 L 0 .027 .126 r
F
.71342 .2037 m .71192 .20154 L .71516 .20041 L F
.64509 .2048 m .64671 .20138 L .64828 .20362 L 0 .029 .128 r
F
.64509 .2048 m .64352 .20259 L .64671 .20138 L F
.28103 .20351 m .28206 .20038 L .28401 .20244 L 0 .027 .126 r
F
.28103 .20351 m .27908 .20144 L .28206 .20038 L F
.32555 .20374 m .32666 .20041 L .32856 .20252 L F
.32555 .20374 m .32364 .20163 L .32666 .20041 L F
.5847 .20554 m .58623 .20225 L .58786 .20438 L 0 .03 .13 r
F
.5847 .20554 m .58307 .2034 L .58623 .20225 L F
.37005 .2041 m .37123 .2009 L .37309 .203 L 0 .028 .127 r
F
.37005 .2041 m .3682 .20201 L .37123 .2009 L F
.76589 .20367 m .76771 .20039 L .76916 .20259 L 0 .027 .126 r
F
.76589 .20367 m .76445 .20148 L .76771 .20039 L F
.33348 .20345 m .33459 .20029 L .33649 .20241 L F
.33348 .20345 m .33158 .20134 L .33459 .20029 L F
.54018 .20546 m .54164 .20212 L .54332 .20438 L 0 .03 .13 r
F
.54018 .20546 m .5385 .20321 L .54164 .20212 L F
.24444 .20304 m .24542 .19976 L .2474 .2019 L 0 .026 .125 r
F
.24444 .20304 m .24245 .20092 L .24542 .19976 L F
.59264 .20532 m .59418 .202 L .5958 .2041 L 0 .03 .13 r
F
.59264 .20532 m .59102 .20319 L .59418 .202 L F
.45114 .20511 m .45246 .20187 L .45423 .20405 L F
.45114 .20511 m .44937 .20293 L .45246 .20187 L F
.65304 .20468 m .65468 .20139 L .65624 .20357 L 0 .029 .129 r
F
.65304 .20468 m .65148 .20249 L .65468 .20139 L F
.41457 .20446 m .41582 .2013 L .41763 .20336 L 0 .029 .128 r
F
.41457 .20446 m .41275 .20241 L .41582 .2013 L F
.48772 .20579 m .4891 .20234 L .49083 .20464 L 0 .031 .131 r
F
.48772 .20579 m .48599 .20346 L .4891 .20234 L F
.72139 .20364 m .72313 .20028 L .72462 .20246 L 0 .027 .126 r
F
.72139 .20364 m .71989 .20145 L .72313 .20028 L F
.28894 .20346 m .28999 .20021 L .29193 .20232 L F
.28894 .20346 m .287 .20137 L .28999 .20021 L F
.37798 .20395 m .37918 .20066 L .38102 .20275 L 0 .028 .127 r
F
.37798 .20395 m .37613 .20184 L .37918 .20066 L F
.72934 .20334 m .73109 .19989 L .73257 .20205 L 0 .026 .125 r
F
.72934 .20334 m .72785 .20118 L .73109 .19989 L F
.60059 .20512 m .60215 .20187 L .60376 .20399 L 0 .03 .13 r
F
.60059 .20512 m .59897 .20297 L .60215 .20187 L F
.54812 .20537 m .54959 .20181 L .55126 .20408 L F
.54812 .20537 m .54645 .20311 L .54959 .20181 L F
.77386 .20361 m .7757 .20039 L .77713 .2025 L 0 .027 .127 r
F
.77386 .20361 m .77243 .20151 L .7757 .20039 L F
.25235 .20296 m .25334 .19965 L .25532 .20183 L 0 .026 .125 r
F
.25235 .20296 m .25037 .20078 L .25334 .19965 L F
.66099 .20451 m .66266 .20137 L .6642 .20342 L 0 .029 .129 r
F
.66099 .20451 m .65945 .20246 L .66266 .20137 L F
.73729 .203 m .73906 .19973 L .74053 .20188 L 0 .026 .125 r
F
.73729 .203 m .73581 .20087 L .73906 .19973 L F
.55607 .20499 m .55755 .20153 L .55921 .20374 L 0 .03 .13 r
F
.55607 .20499 m .5544 .20279 L .55755 .20153 L F
.42249 .20434 m .42377 .20087 L .42557 .2031 L 0 .028 .128 r
F
.42249 .20434 m .4207 .20211 L .42377 .20087 L F
.34139 .2035 m .34252 .2003 L .3444 .20243 L 0 .027 .127 r
F
.34139 .2035 m .3395 .20136 L .34252 .2003 L F
.29686 .20329 m .29793 .2 L .29986 .20216 L 0 .027 .126 r
F
.29686 .20329 m .29493 .20116 L .29793 .2 L F
.78182 .2033 m .78366 .2 L .78508 .20205 L F
.78182 .2033 m .7804 .20125 L .78366 .2 L F
.56401 .20463 m .56551 .20131 L .56716 .20349 L 0 .029 .129 r
F
.56401 .20463 m .56236 .20248 L .56551 .20131 L F
.49566 .20574 m .49705 .20245 L .49877 .20463 L 0 .031 .132 r
F
.49566 .20574 m .49394 .20355 L .49705 .20245 L F
.61648 .20443 m .61805 .20099 L .61965 .20314 L 0 .029 .129 r
F
.61648 .20443 m .61488 .20229 L .61805 .20099 L F
.38591 .20378 m .38713 .20034 L .38896 .20256 L 0 .028 .127 r
F
.38591 .20378 m .38407 .20155 L .38713 .20034 L F
.45907 .20512 m .4604 .20179 L .46216 .20393 L 0 .03 .13 r
F
.45907 .20512 m .45731 .20299 L .4604 .20179 L F
.60854 .20491 m .6101 .20152 L .6117 .2036 L F
.60854 .20491 m .60693 .20283 L .6101 .20152 L F
.78976 .20294 m .79164 .19979 L .79305 .20185 L 0 .026 .126 r
F
.78976 .20294 m .78835 .20089 L .79164 .19979 L F
.62442 .20405 m .62601 .20055 L .6276 .20276 L 0 .028 .128 r
F
.62442 .20405 m .62283 .20185 L .62601 .20055 L F
.43043 .20414 m .43172 .20062 L .4335 .20291 L F
.43043 .20414 m .42864 .20186 L .43172 .20062 L F
.5036 .20548 m .505 .2022 L .50671 .20424 L 0 .031 .132 r
F
.5036 .20548 m .50188 .20347 L .505 .2022 L F
.66895 .20438 m .67062 .20117 L .67216 .20321 L 0 .029 .129 r
F
.66895 .20438 m .66741 .20234 L .67062 .20117 L F
.26026 .20284 m .26127 .19949 L .26324 .20166 L 0 .026 .125 r
F
.26026 .20284 m .25829 .20067 L .26127 .19949 L F
.51154 .20505 m .51295 .20172 L .51466 .20379 L 0 .03 .131 r
F
.51154 .20505 m .50983 .203 L .51295 .20172 L F
.46701 .20485 m .46836 .20149 L .47011 .20365 L 0 .03 .13 r
F
.46701 .20485 m .46526 .20272 L .46836 .20149 L F
.51948 .20464 m .52091 .20125 L .52261 .20339 L 0 .029 .129 r
F
.51948 .20464 m .51778 .20251 L .52091 .20125 L F
.6769 .20398 m .67857 .20065 L .6801 .20269 L 0 .028 .128 r
F
.6769 .20398 m .67536 .20193 L .67857 .20065 L F
.39384 .20355 m .39507 .20019 L .39689 .2024 L 0 .027 .127 r
F
.39384 .20355 m .39201 .20134 L .39507 .20019 L F
.68484 .20356 m .68654 .20039 L .68806 .20242 L 0 .028 .127 r
F
.68484 .20356 m .68332 .20153 L .68654 .20039 L F
.74525 .20291 m .74704 .19956 L .7485 .20174 L 0 .026 .125 r
F
.74525 .20291 m .74379 .20075 L .74704 .19956 L F
.63237 .20385 m .63398 .20051 L .63556 .20275 L 0 .028 .128 r
F
.63237 .20385 m .63078 .20163 L .63398 .20051 L F
.26819 .20256 m .2692 .1994 L .27116 .20149 L 0 .026 .125 r
F
.26819 .20256 m .26622 .20047 L .2692 .1994 L F
.30477 .20322 m .30585 .19998 L .30777 .20215 L 0 .027 .127 r
F
.30477 .20322 m .30285 .20107 L .30585 .19998 L F
.3493 .20348 m .35045 .20029 L .35233 .20239 L 0 .028 .127 r
F
.3493 .20348 m .34742 .20136 L .35045 .20029 L F
.47495 .20459 m .47631 .20119 L .47805 .20338 L 0 .03 .13 r
F
.47495 .20459 m .47321 .20242 L .47631 .20119 L F
.57196 .20462 m .57347 .20134 L .57511 .20357 L F
.57196 .20462 m .57031 .20242 L .57347 .20134 L F
.69279 .2033 m .6945 .20002 L .69601 .20208 L 0 .027 .127 r
F
.69279 .2033 m .69128 .20125 L .6945 .20002 L F
.43836 .20396 m .43966 .20062 L .44144 .20289 L 0 .028 .128 r
F
.43836 .20396 m .43658 .20169 L .43966 .20062 L F
.52743 .20442 m .52886 .20119 L .53055 .2033 L 0 .03 .13 r
F
.52743 .20442 m .52573 .20229 L .52886 .20119 L F
.75322 .20275 m .75501 .1994 L .75647 .2016 L 0 .026 .125 r
F
.75322 .20275 m .75176 .20057 L .75501 .1994 L F
.40177 .20349 m .403 .20028 L .40482 .20245 L 0 .028 .128 r
F
.40177 .20349 m .39994 .20134 L .403 .20028 L F
.70075 .20306 m .70246 .19966 L .70397 .20184 L 0 .027 .126 r
F
.70075 .20306 m .69923 .20086 L .70246 .19966 L F
.35723 .20333 m .35839 .20003 L .36026 .20217 L 0 .028 .127 r
F
.35723 .20333 m .35536 .20121 L .35839 .20003 L F
.64033 .2038 m .64194 .20037 L .64352 .20259 L 0 .028 .128 r
F
.64033 .2038 m .63875 .20161 L .64194 .20037 L F
.31269 .20315 m .31379 .19985 L .3157 .20196 L 0 .027 .127 r
F
.31269 .20315 m .31077 .20103 L .31379 .19985 L F
.2761 .2025 m .27712 .19938 L .27908 .20144 L 0 .026 .126 r
F
.2761 .2025 m .27414 .20044 L .27712 .19938 L F
.53537 .20429 m .53682 .2011 L .5385 .20321 L 0 .03 .13 r
F
.53537 .20429 m .53369 .20219 L .53682 .2011 L F
.7087 .20278 m .71042 .19941 L .71192 .20154 L 0 .027 .126 r
F
.7087 .20278 m .70719 .20063 L .71042 .19941 L F
.57991 .20455 m .58143 .20124 L .58307 .2034 L 0 .03 .13 r
F
.57991 .20455 m .57827 .20241 L .58143 .20124 L F
.48289 .20457 m .48426 .20113 L .48599 .20346 L F
.48289 .20457 m .48115 .20223 L .48426 .20113 L F
.23155 .2024 m .23251 .19913 L .23452 .20119 L 0 .026 .125 r
F
.23155 .2024 m .22954 .20034 L .23251 .19913 L F
.76118 .20262 m .763 .19928 L .76445 .20148 L 0 .027 .126 r
F
.76118 .20262 m .75973 .20044 L .763 .19928 L F
.32063 .20285 m .32173 .19954 L .32364 .20163 L F
.32063 .20285 m .31871 .20076 L .32173 .19954 L F
.36516 .20312 m .36633 .19989 L .3682 .20201 L 0 .028 .127 r
F
.36516 .20312 m .3633 .20102 L .36633 .19989 L F
.44629 .204 m .4476 .20074 L .44937 .20293 L 0 .029 .129 r
F
.44629 .204 m .44452 .20181 L .4476 .20074 L F
.64828 .20362 m .64991 .20024 L .65148 .20249 L 0 .028 .128 r
F
.64828 .20362 m .64671 .20138 L .64991 .20024 L F
.23948 .20208 m .24045 .19883 L .24245 .20092 L 0 .026 .125 r
F
.23948 .20208 m .23748 .20001 L .24045 .19883 L F
.32856 .20252 m .32968 .19922 L .33158 .20134 L 0 .027 .126 r
F
.32856 .20252 m .32666 .20041 L .32968 .19922 L F
.71666 .20257 m .7184 .19929 L .71989 .20145 L F
.71666 .20257 m .71516 .20041 L .7184 .19929 L F
.40969 .20346 m .41094 .20035 L .41275 .20241 L 0 .029 .128 r
F
.40969 .20346 m .40788 .2014 L .41094 .20035 L F
.58786 .20438 m .58939 .20109 L .59102 .20319 L 0 .03 .13 r
F
.58786 .20438 m .58623 .20225 L .58939 .20109 L F
.28401 .20244 m .28505 .19931 L .287 .20137 L 0 .027 .126 r
F
.28401 .20244 m .28206 .20038 L .28505 .19931 L F
.5958 .2041 m .59736 .20089 L .59897 .20297 L 0 .03 .13 r
F
.5958 .2041 m .59418 .202 L .59736 .20089 L F
.37309 .203 m .37428 .19974 L .37613 .20184 L 0 .028 .127 r
F
.37309 .203 m .37123 .2009 L .37428 .19974 L F
.2474 .2019 m .24839 .19865 L .25037 .20078 L 0 .026 .125 r
F
.2474 .2019 m .24542 .19976 L .24839 .19865 L F
.76916 .20259 m .77099 .1993 L .77243 .20151 L 0 .027 .126 r
F
.76916 .20259 m .76771 .20039 L .77099 .1993 L F
.54332 .20438 m .54478 .20085 L .54645 .20311 L 0 .03 .13 r
F
.54332 .20438 m .54164 .20212 L .54478 .20085 L F
.33649 .20241 m .33761 .19923 L .3395 .20136 L 0 .027 .126 r
F
.33649 .20241 m .33459 .20029 L .33761 .19923 L F
.49083 .20464 m .49221 .20126 L .49394 .20355 L 0 .031 .131 r
F
.49083 .20464 m .4891 .20234 L .49221 .20126 L F
.72462 .20246 m .72637 .19901 L .72785 .20118 L 0 .027 .126 r
F
.72462 .20246 m .72313 .20028 L .72637 .19901 L F
.65624 .20357 m .65789 .20028 L .65945 .20246 L 0 .029 .129 r
F
.65624 .20357 m .65468 .20139 L .65789 .20028 L F
.41763 .20336 m .41889 .20005 L .4207 .20211 L 0 .029 .128 r
F
.41763 .20336 m .41582 .2013 L .41889 .20005 L F
.73257 .20205 m .73434 .19873 L .73581 .20087 L 0 .026 .125 r
F
.73257 .20205 m .73109 .19989 L .73434 .19873 L F
.45423 .20405 m .45555 .20081 L .45731 .20299 L 0 .03 .13 r
F
.45423 .20405 m .45246 .20187 L .45555 .20081 L F
.38102 .20275 m .38223 .19947 L .38407 .20155 L 0 .028 .127 r
F
.38102 .20275 m .37918 .20066 L .38223 .19947 L F
.55126 .20408 m .55274 .20052 L .5544 .20279 L 0 .03 .13 r
F
.55126 .20408 m .54959 .20181 L .55274 .20052 L F
.29193 .20232 m .29299 .19902 L .29493 .20116 L 0 .027 .126 r
F
.29193 .20232 m .28999 .20021 L .29299 .19902 L F
.55921 .20374 m .5607 .20028 L .56236 .20248 L 0 .029 .129 r
F
.55921 .20374 m .55755 .20153 L .5607 .20028 L F
.42557 .2031 m .42685 .19962 L .42864 .20186 L 0 .028 .128 r
F
.42557 .2031 m .42377 .20087 L .42685 .19962 L F
.60376 .20399 m .60532 .20074 L .60693 .20283 L 0 .03 .13 r
F
.60376 .20399 m .60215 .20187 L .60532 .20074 L F
.61965 .20314 m .62123 .1997 L .62283 .20185 L 0 .028 .128 r
F
.61965 .20314 m .61805 .20099 L .62123 .1997 L F
.25532 .20183 m .25632 .19849 L .25829 .20067 L 0 .026 .125 r
F
.25532 .20183 m .25334 .19965 L .25632 .19849 L F
.78508 .20205 m .78694 .19884 L .78835 .20089 L 0 .027 .126 r
F
.78508 .20205 m .78366 .2 L .78694 .19884 L F
.77713 .2025 m .77897 .19915 L .7804 .20125 L 0 .027 .127 r
F
.77713 .2025 m .7757 .20039 L .77897 .19915 L F
.6117 .2036 m .61328 .20021 L .61488 .20229 L 0 .029 .129 r
F
.6117 .2036 m .6101 .20152 L .61328 .20021 L F
.74053 .20188 m .74232 .19859 L .74379 .20075 L 0 .026 .125 r
F
.74053 .20188 m .73906 .19973 L .74232 .19859 L F
.6642 .20342 m .66587 .20029 L .66741 .20234 L 0 .029 .129 r
F
.6642 .20342 m .66266 .20137 L .66587 .20029 L F
.6276 .20276 m .6292 .1994 L .63078 .20163 L 0 .028 .127 r
F
.6276 .20276 m .62601 .20055 L .6292 .1994 L F
.38896 .20256 m .39018 .19913 L .39201 .20134 L 0 .027 .127 r
F
.38896 .20256 m .38713 .20034 L .39018 .19913 L F
.29986 .20216 m .30093 .19888 L .30285 .20107 L 0 .027 .126 r
F
.29986 .20216 m .29793 .2 L .30093 .19888 L F
.56716 .20349 m .56866 .20021 L .57031 .20242 L 0 .029 .129 r
F
.56716 .20349 m .56551 .20131 L .56866 .20021 L F
.46216 .20393 m .4635 .20055 L .46526 .20272 L 0 .03 .13 r
F
.46216 .20393 m .4604 .20179 L .4635 .20055 L F
.49877 .20463 m .50016 .20129 L .50188 .20347 L 0 .032 .132 r
F
.49877 .20463 m .49705 .20245 L .50016 .20129 L F
.3444 .20243 m .34554 .19924 L .34742 .20136 L 0 .028 .127 r
F
.3444 .20243 m .34252 .2003 L .34554 .19924 L F
.51466 .20379 m .51608 .20044 L .51778 .20251 L 0 .03 .13 r
F
.51466 .20379 m .51295 .20172 L .51608 .20044 L F
.4335 .20291 m .4348 .19939 L .43658 .20169 L 0 .028 .128 r
F
.4335 .20291 m .43172 .20062 L .4348 .19939 L F
.6801 .20269 m .68179 .19949 L .68332 .20153 L F
.6801 .20269 m .67857 .20065 L .68179 .19949 L F
.50671 .20424 m .50812 .20094 L .50983 .203 L 0 .031 .131 r
F
.50671 .20424 m .505 .2022 L .50812 .20094 L F
.52261 .20339 m .52404 .20017 L .52573 .20229 L 0 .029 .129 r
F
.52261 .20339 m .52091 .20125 L .52404 .20017 L F
.79305 .20185 m .79493 .19868 L .79633 .20076 L 0 .027 .126 r
F
.79305 .20185 m .79164 .19979 L .79493 .19868 L F
.26324 .20166 m .26426 .1983 L .26622 .20047 L 0 .026 .125 r
F
.26324 .20166 m .26127 .19949 L .26426 .1983 L F
.47011 .20365 m .47146 .20025 L .47321 .20242 L 0 .03 .13 r
F
.47011 .20365 m .46836 .20149 L .47146 .20025 L F
.67216 .20321 m .67383 .19988 L .67536 .20193 L 0 .029 .129 r
F
.67216 .20321 m .67062 .20117 L .67383 .19988 L F
.39689 .2024 m .39812 .19912 L .39994 .20134 L 0 .028 .127 r
F
.39689 .2024 m .39507 .20019 L .39812 .19912 L F
.7485 .20174 m .75029 .19837 L .75176 .20057 L 0 .026 .125 r
F
.7485 .20174 m .74704 .19956 L .75029 .19837 L F
.68806 .20242 m .68976 .19923 L .69128 .20125 L 0 .028 .127 r
F
.68806 .20242 m .68654 .20039 L .68976 .19923 L F
.47805 .20338 m .47941 .20005 L .48115 .20223 L 0 .029 .129 r
F
.47805 .20338 m .47631 .20119 L .47941 .20005 L F
.69601 .20208 m .69772 .19878 L .69923 .20086 L 0 .027 .126 r
F
.69601 .20208 m .6945 .20002 L .69772 .19878 L F
.63556 .20275 m .63717 .19936 L .63875 .20161 L 0 .028 .128 r
F
.63556 .20275 m .63398 .20051 L .63717 .19936 L F
.27116 .20149 m .27218 .19834 L .27414 .20044 L 0 .026 .125 r
F
.27116 .20149 m .2692 .1994 L .27218 .19834 L F
.30777 .20215 m .30886 .19886 L .31077 .20103 L 0 .027 .127 r
F
.30777 .20215 m .30585 .19998 L .30886 .19886 L F
.35233 .20239 m .35348 .19909 L .35536 .20121 L 0 .028 .127 r
F
.35233 .20239 m .35045 .20029 L .35348 .19909 L F
.53055 .2033 m .532 .2001 L .53369 .20219 L 0 .03 .13 r
F
.53055 .2033 m .52886 .20119 L .532 .2001 L F
.44144 .20289 m .44274 .19955 L .44452 .20181 L 0 .029 .129 r
F
.44144 .20289 m .43966 .20062 L .44274 .19955 L F
.57511 .20357 m .57663 .20015 L .57827 .20241 L 0 .03 .13 r
F
.57511 .20357 m .57347 .20134 L .57663 .20015 L F
.75647 .2016 m .75828 .19824 L .75973 .20044 L 0 .026 .125 r
F
.75647 .2016 m .75501 .1994 L .75828 .19824 L F
.70397 .20184 m .70569 .19846 L .70719 .20063 L 0 .027 .126 r
F
.70397 .20184 m .70246 .19966 L .70569 .19846 L F
.64352 .20259 m .64514 .19913 L .64671 .20138 L 0 .028 .128 r
F
.64352 .20259 m .64194 .20037 L .64514 .19913 L F
.36026 .20217 m .36143 .19886 L .3633 .20102 L 0 .028 .127 r
F
.36026 .20217 m .35839 .20003 L .36143 .19886 L F
.3157 .20196 m .3168 .19866 L .31871 .20076 L 0 .027 .127 r
F
.3157 .20196 m .31379 .19985 L .3168 .19866 L F
.71192 .20154 m .71366 .19829 L .71516 .20041 L 0 .027 .126 r
F
.71192 .20154 m .71042 .19941 L .71366 .19829 L F
.40482 .20245 m .40606 .19922 L .40788 .2014 L 0 .028 .128 r
F
.40482 .20245 m .403 .20028 L .40606 .19922 L F
.23452 .20119 m .23548 .19793 L .23748 .20001 L 0 .026 .125 r
F
.23452 .20119 m .23251 .19913 L .23548 .19793 L F
.32364 .20163 m .32475 .19833 L .32666 .20041 L 0 .027 .126 r
F
.32364 .20163 m .32173 .19954 L .32475 .19833 L F
.58307 .2034 m .58459 .20009 L .58623 .20225 L 0 .03 .13 r
F
.58307 .2034 m .58143 .20124 L .58459 .20009 L F
.5385 .20321 m .53996 .20002 L .54164 .20212 L F
.5385 .20321 m .53682 .2011 L .53996 .20002 L F
.27908 .20144 m .2801 .19832 L .28206 .20038 L 0 .027 .126 r
F
.27908 .20144 m .27712 .19938 L .2801 .19832 L F
.48599 .20346 m .48737 .20003 L .4891 .20234 L 0 .03 .13 r
F
.48599 .20346 m .48426 .20113 L .48737 .20003 L F
.76445 .20148 m .76627 .19818 L .76771 .20039 L 0 .027 .126 r
F
.76445 .20148 m .763 .19928 L .76627 .19818 L F
.33158 .20134 m .3327 .19817 L .33459 .20029 L F
.33158 .20134 m .32968 .19922 L .3327 .19817 L F
.3682 .20201 m .36938 .19876 L .37123 .2009 L 0 .028 .127 r
F
.3682 .20201 m .36633 .19989 L .36938 .19876 L F
.24245 .20092 m .24343 .19766 L .24542 .19976 L 0 .026 .125 r
F
.24245 .20092 m .24045 .19883 L .24343 .19766 L F
.65148 .20249 m .65312 .19913 L .65468 .20139 L 0 .029 .128 r
F
.65148 .20249 m .64991 .20024 L .65312 .19913 L F
.44937 .20293 m .45069 .19968 L .45246 .20187 L 0 .03 .13 r
F
.44937 .20293 m .4476 .20074 L .45069 .19968 L F
.59102 .20319 m .59256 .19994 L .59418 .202 L F
.59102 .20319 m .58939 .20109 L .59256 .19994 L F
.71989 .20145 m .72164 .19813 L .72313 .20028 L 0 .027 .126 r
F
.71989 .20145 m .7184 .19929 L .72164 .19813 L F
.41275 .20241 m .414 .19924 L .41582 .2013 L 0 .029 .129 r
F
.41275 .20241 m .41094 .20035 L .414 .19924 L F
.54645 .20311 m .54792 .19954 L .54959 .20181 L 0 .03 .13 r
F
.54645 .20311 m .54478 .20085 L .54792 .19954 L F
.287 .20137 m .28804 .19815 L .28999 .20021 L 0 .027 .126 r
F
.287 .20137 m .28505 .19931 L .28804 .19815 L F
.72785 .20118 m .72961 .19774 L .73109 .19989 L 0 .026 .125 r
F
.72785 .20118 m .72637 .19901 L .72961 .19774 L F
.37613 .20184 m .37733 .19857 L .37918 .20066 L 0 .028 .127 r
F
.37613 .20184 m .37428 .19974 L .37733 .19857 L F
.59897 .20297 m .60053 .1998 L .60215 .20187 L 0 .03 .13 r
F
.59897 .20297 m .59736 .20089 L .60053 .1998 L F
.25037 .20078 m .25136 .19754 L .25334 .19965 L 0 .026 .125 r
F
.25037 .20078 m .24839 .19865 L .25136 .19754 L F
.4207 .20211 m .42197 .1988 L .42377 .20087 L 0 .028 .128 r
F
.4207 .20211 m .41889 .20005 L .42197 .1988 L F
.5544 .20279 m .55589 .19928 L .55755 .20153 L 0 .029 .129 r
F
.5544 .20279 m .55274 .20052 L .55589 .19928 L F
.77243 .20151 m .77426 .19817 L .7757 .20039 L 0 .027 .127 r
F
.77243 .20151 m .77099 .1993 L .77426 .19817 L F
.73581 .20087 m .73759 .19761 L .73906 .19973 L 0 .026 .125 r
F
.73581 .20087 m .73434 .19873 L .73759 .19761 L F
.38407 .20155 m .38528 .19828 L .38713 .20034 L 0 .027 .127 r
F
.38407 .20155 m .38223 .19947 L .38528 .19828 L F
.49394 .20355 m .49532 .20018 L .49705 .20245 L 0 .031 .131 r
F
.49394 .20355 m .49221 .20126 L .49532 .20018 L F
.65945 .20246 m .6611 .19919 L .66266 .20137 L 0 .029 .129 r
F
.65945 .20246 m .65789 .20028 L .6611 .19919 L F
.3395 .20136 m .34063 .19818 L .34252 .2003 L 0 .027 .127 r
F
.3395 .20136 m .33761 .19923 L .34063 .19818 L F
.56236 .20248 m .56385 .1991 L .56551 .20131 L 0 .029 .129 r
F
.56236 .20248 m .5607 .20028 L .56385 .1991 L F
.29493 .20116 m .296 .19783 L .29793 .2 L 0 .027 .126 r
F
.29493 .20116 m .29299 .19902 L .296 .19783 L F
.61488 .20229 m .61646 .19892 L .61805 .20099 L 0 .029 .129 r
F
.61488 .20229 m .61328 .20021 L .61646 .19892 L F
.62283 .20185 m .62442 .19841 L .62601 .20055 L 0 .028 .127 r
F
.62283 .20185 m .62123 .1997 L .62442 .19841 L F
.42864 .20186 m .42993 .19837 L .43172 .20062 L F
.42864 .20186 m .42685 .19962 L .42993 .19837 L F
.45731 .20299 m .45864 .1996 L .4604 .20179 L 0 .03 .13 r
F
.45731 .20299 m .45555 .20081 L .45864 .1996 L F
.7804 .20125 m .78224 .1979 L .78366 .2 L 0 .027 .126 r
F
.7804 .20125 m .77897 .19915 L .78224 .1979 L F
.60693 .20283 m .6085 .19943 L .6101 .20152 L 0 .03 .13 r
F
.60693 .20283 m .60532 .20074 L .6085 .19943 L F
.25829 .20067 m .2593 .19731 L .26127 .19949 L 0 .026 .125 r
F
.25829 .20067 m .25632 .19849 L .2593 .19731 L F
.78835 .20089 m .79023 .19772 L .79164 .19979 L 0 .027 .126 r
F
.78835 .20089 m .78694 .19884 L .79023 .19772 L F
.39201 .20134 m .39324 .19798 L .39507 .20019 L 0 .027 .127 r
F
.39201 .20134 m .39018 .19913 L .39324 .19798 L F
.46526 .20272 m .4666 .19931 L .46836 .20149 L 0 .03 .13 r
F
.46526 .20272 m .4635 .20055 L .4666 .19931 L F
.63078 .20163 m .63239 .19827 L .63398 .20051 L 0 .028 .127 r
F
.63078 .20163 m .6292 .1994 L .63239 .19827 L F
.51778 .20251 m .51921 .19916 L .52091 .20125 L 0 .03 .13 r
F
.51778 .20251 m .51608 .20044 L .51921 .19916 L F
.74379 .20075 m .74557 .19738 L .74704 .19956 L 0 .026 .125 r
F
.74379 .20075 m .74232 .19859 L .74557 .19738 L F
.50983 .203 m .51124 .19965 L .51295 .20172 L 0 .031 .131 r
F
.50983 .203 m .50812 .20094 L .51124 .19965 L F
.66741 .20234 m .66908 .19911 L .67062 .20117 L 0 .029 .129 r
F
.66741 .20234 m .66587 .20029 L .66908 .19911 L F
.43658 .20169 m .43788 .19833 L .43966 .20062 L 0 .028 .128 r
F
.43658 .20169 m .4348 .19939 L .43788 .19833 L F
.50188 .20347 m .50328 .20002 L .505 .2022 L 0 .031 .132 r
F
.50188 .20347 m .50016 .20129 L .50328 .20002 L F
.67536 .20193 m .67704 .19859 L .67857 .20065 L 0 .029 .128 r
F
.67536 .20193 m .67383 .19988 L .67704 .19859 L F
.30285 .20107 m .30393 .19776 L .30585 .19998 L 0 .027 .126 r
F
.30285 .20107 m .30093 .19888 L .30393 .19776 L F
.68332 .20153 m .68501 .19836 L .68654 .20039 L 0 .028 .128 r
F
.68332 .20153 m .68179 .19949 L .68501 .19836 L F
.57031 .20242 m .57182 .1991 L .57347 .20134 L 0 .03 .13 r
F
.57031 .20242 m .56866 .20021 L .57182 .1991 L F
.47321 .20242 m .47456 .19901 L .47631 .20119 L 0 .029 .129 r
F
.47321 .20242 m .47146 .20025 L .47456 .19901 L F
.26622 .20047 m .26724 .19721 L .2692 .1994 L 0 .026 .125 r
F
.26622 .20047 m .26426 .1983 L .26724 .19721 L F
.34742 .20136 m .34857 .19818 L .35045 .20029 L 0 .028 .127 r
F
.34742 .20136 m .34554 .19924 L .34857 .19818 L F
.52573 .20229 m .52717 .19909 L .52886 .20119 L 0 .03 .13 r
F
.52573 .20229 m .52404 .20017 L .52717 .19909 L F
.75176 .20057 m .75355 .19719 L .75501 .1994 L 0 .026 .125 r
F
.75176 .20057 m .75029 .19837 L .75355 .19719 L F
.69128 .20125 m .69298 .19798 L .6945 .20002 L 0 .028 .127 r
F
.69128 .20125 m .68976 .19923 L .69298 .19798 L F
.69923 .20086 m .70095 .19757 L .70246 .19966 L 0 .027 .126 r
F
.69923 .20086 m .69772 .19878 L .70095 .19757 L F
.39994 .20134 m .40118 .19804 L .403 .20028 L 0 .028 .127 r
F
.39994 .20134 m .39812 .19912 L .40118 .19804 L F
.48115 .20223 m .48252 .19898 L .48426 .20113 L 0 .03 .13 r
F
.48115 .20223 m .47941 .20005 L .48252 .19898 L F
.63875 .20161 m .64036 .19812 L .64194 .20037 L 0 .028 .128 r
F
.63875 .20161 m .63717 .19936 L .64036 .19812 L F
.35536 .20121 m .35652 .19789 L .35839 .20003 L 0 .028 .127 r
F
.35536 .20121 m .35348 .19909 L .35652 .19789 L F
.31077 .20103 m .31187 .19769 L .31379 .19985 L 0 .027 .127 r
F
.31077 .20103 m .30886 .19886 L .31187 .19769 L F
.70719 .20063 m .70892 .19727 L .71042 .19941 L 0 .027 .126 r
F
.70719 .20063 m .70569 .19846 L .70892 .19727 L F
.57827 .20241 m .57979 .19896 L .58143 .20124 L 0 .03 .13 r
F
.57827 .20241 m .57663 .20015 L .57979 .19896 L F
.53369 .20219 m .53514 .19901 L .53682 .2011 L F
.53369 .20219 m .532 .2001 L .53514 .19901 L F
.27414 .20044 m .27516 .19727 L .27712 .19938 L 0 .027 .126 r
F
.27414 .20044 m .27218 .19834 L .27516 .19727 L F
.75973 .20044 m .76154 .19707 L .763 .19928 L 0 .026 .125 r
F
.75973 .20044 m .75828 .19824 L .76154 .19707 L F
.44452 .20181 m .44583 .19848 L .4476 .20074 L 0 .029 .129 r
F
.44452 .20181 m .44274 .19955 L .44583 .19848 L F
.64671 .20138 m .64834 .19798 L .64991 .20024 L 0 .028 .128 r
F
.64671 .20138 m .64514 .19913 L .64834 .19798 L F
.31871 .20076 m .31982 .19745 L .32173 .19954 L 0 .027 .126 r
F
.31871 .20076 m .3168 .19866 L .31982 .19745 L F
.3633 .20102 m .36447 .19771 L .36633 .19989 L 0 .028 .127 r
F
.3633 .20102 m .36143 .19886 L .36447 .19771 L F
.32666 .20041 m .32778 .19714 L .32968 .19922 L 0 .027 .126 r
F
.32666 .20041 m .32475 .19833 L .32778 .19714 L F
.71516 .20041 m .71691 .19717 L .7184 .19929 L F
.71516 .20041 m .71366 .19829 L .71691 .19717 L F
.23748 .20001 m .23846 .19673 L .24045 .19883 L 0 .026 .125 r
F
.23748 .20001 m .23548 .19793 L .23846 .19673 L F
.58623 .20225 m .58776 .19897 L .58939 .20109 L 0 .03 .13 r
F
.58623 .20225 m .58459 .20009 L .58776 .19897 L F
.40788 .2014 m .40912 .19816 L .41094 .20035 L 0 .029 .128 r
F
.40788 .2014 m .40606 .19922 L .40912 .19816 L F
.4891 .20234 m .49048 .19897 L .49221 .20126 L 0 .03 .131 r
F
.4891 .20234 m .48737 .20003 L .49048 .19897 L F
.54164 .20212 m .5431 .19875 L .54478 .20085 L 0 .03 .13 r
F
.54164 .20212 m .53996 .20002 L .5431 .19875 L F
.28206 .20038 m .28309 .19726 L .28505 .19931 L 0 .027 .126 r
F
.28206 .20038 m .2801 .19832 L .28309 .19726 L F
.76771 .20039 m .76954 .19708 L .77099 .1993 L F
.76771 .20039 m .76627 .19818 L .76954 .19708 L F
.24542 .19976 m .2464 .19657 L .24839 .19865 L 0 .026 .125 r
F
.24542 .19976 m .24343 .19766 L .2464 .19657 L F
.37123 .2009 m .37242 .19761 L .37428 .19974 L 0 .028 .127 r
F
.37123 .2009 m .36938 .19876 L .37242 .19761 L F
.59418 .202 m .59574 .19884 L .59736 .20089 L 0 .03 .13 r
F
.59418 .202 m .59256 .19994 L .59574 .19884 L F
.54959 .20181 m .55107 .19825 L .55274 .20052 L 0 .029 .129 r
F
.54959 .20181 m .54792 .19954 L .55107 .19825 L F
.72313 .20028 m .72488 .19687 L .72637 .19901 L 0 .027 .126 r
F
.72313 .20028 m .72164 .19813 L .72488 .19687 L F
.65468 .20139 m .65633 .19802 L .65789 .20028 L 0 .029 .128 r
F
.65468 .20139 m .65312 .19913 L .65633 .19802 L F
.33459 .20029 m .33572 .19711 L .33761 .19923 L 0 .027 .126 r
F
.33459 .20029 m .3327 .19817 L .33572 .19711 L F
.45246 .20187 m .45378 .19862 L .45555 .20081 L 0 .03 .13 r
F
.45246 .20187 m .45069 .19968 L .45378 .19862 L F
.73109 .19989 m .73286 .19659 L .73434 .19873 L 0 .026 .125 r
F
.73109 .19989 m .72961 .19774 L .73286 .19659 L F
.41582 .2013 m .41708 .19799 L .41889 .20005 L 0 .029 .129 r
F
.41582 .2013 m .414 .19924 L .41708 .19799 L F
.42377 .20087 m .42504 .19755 L .42685 .19962 L 0 .028 .128 r
F
.42377 .20087 m .42197 .1988 L .42504 .19755 L F
.55755 .20153 m .55904 .19804 L .5607 .20028 L 0 .029 .129 r
F
.55755 .20153 m .55589 .19928 L .55904 .19804 L F
.28999 .20021 m .29105 .19695 L .29299 .19902 L 0 .027 .126 r
F
.28999 .20021 m .28804 .19815 L .29105 .19695 L F
.37918 .20066 m .38038 .1974 L .38223 .19947 L 0 .028 .127 r
F
.37918 .20066 m .37733 .19857 L .38038 .1974 L F
.25334 .19965 m .25434 .19639 L .25632 .19849 L 0 .026 .125 r
F
.25334 .19965 m .25136 .19754 L .25434 .19639 L F
.60215 .20187 m .60371 .19869 L .60532 .20074 L 0 .03 .13 r
F
.60215 .20187 m .60053 .1998 L .60371 .19869 L F
.61805 .20099 m .61964 .19766 L .62123 .1997 L 0 .028 .128 r
F
.61805 .20099 m .61646 .19892 L .61964 .19766 L F
.62601 .20055 m .62761 .19725 L .6292 .1994 L 0 .028 .127 r
F
.62601 .20055 m .62442 .19841 L .62761 .19725 L F
.38713 .20034 m .38834 .19708 L .39018 .19913 L 0 .027 .127 r
F
.38713 .20034 m .38528 .19828 L .38834 .19708 L F
.7757 .20039 m .77753 .19693 L .77897 .19915 L 0 .027 .126 r
F
.7757 .20039 m .77426 .19817 L .77753 .19693 L F
.73906 .19973 m .74085 .19648 L .74232 .19859 L 0 .026 .125 r
F
.73906 .19973 m .73759 .19761 L .74085 .19648 L F
.43172 .20062 m .43301 .19713 L .4348 .19939 L 0 .027 .127 r
F
.43172 .20062 m .42993 .19837 L .43301 .19713 L F
.6101 .20152 m .61167 .19813 L .61328 .20021 L 0 .029 .129 r
F
.6101 .20152 m .6085 .19943 L .61167 .19813 L F
.56551 .20131 m .56701 .19798 L .56866 .20021 L F
.56551 .20131 m .56385 .1991 L .56701 .19798 L F
.29793 .2 m .299 .19668 L .30093 .19888 L 0 .027 .126 r
F
.29793 .2 m .296 .19783 L .299 .19668 L F
.78366 .2 m .78552 .19673 L .78694 .19884 L F
.78366 .2 m .78224 .1979 L .78552 .19673 L F
.49705 .20245 m .49844 .19903 L .50016 .20129 L 0 .031 .132 r
F
.49705 .20245 m .49532 .20018 L .49844 .19903 L F
.4604 .20179 m .46174 .19835 L .4635 .20055 L 0 .03 .13 r
F
.4604 .20179 m .45864 .1996 L .46174 .19835 L F
.66266 .20137 m .66432 .1981 L .66587 .20029 L 0 .029 .129 r
F
.66266 .20137 m .6611 .19919 L .66432 .1981 L F
.34252 .2003 m .34365 .19712 L .34554 .19924 L 0 .028 .127 r
F
.34252 .2003 m .34063 .19818 L .34365 .19712 L F
.26127 .19949 m .26229 .19613 L .26426 .1983 L 0 .026 .125 r
F
.26127 .19949 m .2593 .19731 L .26229 .19613 L F
.52091 .20125 m .52234 .19807 L .52404 .20017 L 0 .029 .129 r
F
.52091 .20125 m .51921 .19916 L .52234 .19807 L F
.46836 .20149 m .4697 .19806 L .47146 .20025 L 0 .03 .129 r
F
.46836 .20149 m .4666 .19931 L .4697 .19806 L F
.51295 .20172 m .51437 .19835 L .51608 .20044 L 0 .03 .13 r
F
.51295 .20172 m .51124 .19965 L .51437 .19835 L F
.39507 .20019 m .39629 .19689 L .39812 .19912 L 0 .027 .127 r
F
.39507 .20019 m .39324 .19798 L .39629 .19689 L F
.67857 .20065 m .68026 .19742 L .68179 .19949 L 0 .028 .128 r
F
.67857 .20065 m .67704 .19859 L .68026 .19742 L F
.505 .2022 m .50641 .19874 L .50812 .20094 L 0 .031 .131 r
F
.505 .2022 m .50328 .20002 L .50641 .19874 L F
.74704 .19956 m .74883 .19618 L .75029 .19837 L 0 .026 .125 r
F
.74704 .19956 m .74557 .19738 L .74883 .19618 L F
.79164 .19979 m .79352 .1966 L .79493 .19868 L 0 .027 .126 r
F
.79164 .19979 m .79023 .19772 L .79352 .1966 L F
.67062 .20117 m .67229 .19782 L .67383 .19988 L 0 .029 .129 r
F
.67062 .20117 m .66908 .19911 L .67229 .19782 L F
.63398 .20051 m .63558 .1971 L .63717 .19936 L 0 .028 .127 r
F
.63398 .20051 m .63239 .19827 L .63558 .1971 L F
.47631 .20119 m .47767 .19787 L .47941 .20005 L 0 .029 .129 r
F
.47631 .20119 m .47456 .19901 L .47767 .19787 L F
.68654 .20039 m .68824 .1972 L .68976 .19923 L 0 .028 .128 r
F
.68654 .20039 m .68501 .19836 L .68824 .1972 L F
.43966 .20062 m .44096 .19726 L .44274 .19955 L F
.43966 .20062 m .43788 .19833 L .44096 .19726 L F
.30585 .19998 m .30694 .19662 L .30886 .19886 L 0 .027 .126 r
F
.30585 .19998 m .30393 .19776 L .30694 .19662 L F
.57347 .20134 m .57498 .19789 L .57663 .20015 L 0 .03 .13 r
F
.57347 .20134 m .57182 .1991 L .57498 .19789 L F
.6945 .20002 m .69621 .19672 L .69772 .19878 L 0 .027 .127 r
F
.6945 .20002 m .69298 .19798 L .69621 .19672 L F
.2692 .1994 m .27022 .19613 L .27218 .19834 L 0 .026 .125 r
F
.2692 .1994 m .26724 .19721 L .27022 .19613 L F
.75501 .1994 m .75682 .19602 L .75828 .19824 L F
.75501 .1994 m .75355 .19719 L .75682 .19602 L F
.35045 .20029 m .35161 .19697 L .35348 .19909 L 0 .028 .127 r
F
.35045 .20029 m .34857 .19818 L .35161 .19697 L F
.52886 .20119 m .53031 .198 L .532 .2001 L 0 .03 .13 r
F
.52886 .20119 m .52717 .19909 L .53031 .198 L F
.70246 .19966 m .70418 .19636 L .70569 .19846 L 0 .027 .126 r
F
.70246 .19966 m .70095 .19757 L .70418 .19636 L F
.64194 .20037 m .64356 .19688 L .64514 .19913 L 0 .028 .127 r
F
.64194 .20037 m .64036 .19812 L .64356 .19688 L F
.48426 .20113 m .48563 .1979 L .48737 .20003 L 0 .03 .13 r
F
.48426 .20113 m .48252 .19898 L .48563 .1979 L F
.35839 .20003 m .35956 .1967 L .36143 .19886 L 0 .028 .127 r
F
.35839 .20003 m .35652 .19789 L .35956 .1967 L F
.403 .20028 m .40424 .19696 L .40606 .19922 L 0 .028 .128 r
F
.403 .20028 m .40118 .19804 L .40424 .19696 L F
.31379 .19985 m .31488 .19651 L .3168 .19866 L 0 .027 .127 r
F
.31379 .19985 m .31187 .19769 L .31488 .19651 L F
.71042 .19941 m .71216 .19615 L .71366 .19829 L 0 .027 .126 r
F
.71042 .19941 m .70892 .19727 L .71216 .19615 L F
.58143 .20124 m .58296 .19779 L .58459 .20009 L 0 .03 .13 r
F
.58143 .20124 m .57979 .19896 L .58296 .19779 L F
.763 .19928 m .76481 .19596 L .76627 .19818 L 0 .026 .125 r
F
.763 .19928 m .76154 .19707 L .76481 .19596 L F
.32173 .19954 m .32284 .19624 L .32475 .19833 L 0 .027 .126 r
F
.32173 .19954 m .31982 .19745 L .32284 .19624 L F
.53682 .2011 m .53828 .19793 L .53996 .20002 L 0 .03 .13 r
F
.53682 .2011 m .53514 .19901 L .53828 .19793 L F
.64991 .20024 m .65155 .19687 L .65312 .19913 L 0 .028 .128 r
F
.64991 .20024 m .64834 .19798 L .65155 .19687 L F
.27712 .19938 m .27814 .19622 L .2801 .19832 L 0 .027 .126 r
F
.27712 .19938 m .27516 .19727 L .27814 .19622 L F
.4476 .20074 m .44891 .19743 L .45069 .19968 L 0 .029 .129 r
F
.4476 .20074 m .44583 .19848 L .44891 .19743 L F
.32968 .19922 m .33079 .19608 L .3327 .19817 L 0 .027 .126 r
F
.32968 .19922 m .32778 .19714 L .33079 .19608 L F
.36633 .19989 m .36752 .19655 L .36938 .19876 L 0 .028 .127 r
F
.36633 .19989 m .36447 .19771 L .36752 .19655 L F
.24045 .19883 m .24143 .19555 L .24343 .19766 L 0 .026 .125 r
F
.24045 .19883 m .23846 .19673 L .24143 .19555 L F
.7184 .19929 m .72015 .19601 L .72164 .19813 L 0 .027 .126 r
F
.7184 .19929 m .71691 .19717 L .72015 .19601 L F
.54478 .20085 m .54625 .19745 L .54792 .19954 L 0 .029 .129 r
F
.54478 .20085 m .5431 .19875 L .54625 .19745 L F
.58939 .20109 m .59093 .19784 L .59256 .19994 L 0 .03 .13 r
F
.58939 .20109 m .58776 .19897 L .59093 .19784 L F
.55274 .20052 m .55422 .19702 L .55589 .19928 L 0 .029 .129 r
F
.55274 .20052 m .55107 .19825 L .55422 .19702 L F
.72637 .19901 m .72813 .19561 L .72961 .19774 L 0 .026 .125 r
F
.72637 .19901 m .72488 .19687 L .72813 .19561 L F
.41094 .20035 m .41219 .19705 L .414 .19924 L 0 .029 .129 r
F
.41094 .20035 m .40912 .19816 L .41219 .19705 L F
.49221 .20126 m .49359 .19791 L .49532 .20018 L 0 .031 .131 r
F
.49221 .20126 m .49048 .19897 L .49359 .19791 L F
.77099 .1993 m .77282 .19595 L .77426 .19817 L 0 .027 .126 r
F
.77099 .1993 m .76954 .19708 L .77282 .19595 L F
.37428 .19974 m .37547 .19645 L .37733 .19857 L 0 .028 .127 r
F
.37428 .19974 m .37242 .19761 L .37547 .19645 L F
.24839 .19865 m .24937 .19547 L .25136 .19754 L 0 .026 .125 r
F
.24839 .19865 m .2464 .19657 L .24937 .19547 L F
.28505 .19931 m .28609 .1961 L .28804 .19815 L 0 .027 .126 r
F
.28505 .19931 m .28309 .19726 L .28609 .1961 L F
.59736 .20089 m .59891 .19776 L .60053 .1998 L 0 .03 .131 r
F
.59736 .20089 m .59574 .19884 L .59891 .19776 L F
.41889 .20005 m .42016 .19673 L .42197 .1988 L 0 .028 .128 r
F
.41889 .20005 m .41708 .19799 L .42016 .19673 L F
.73434 .19873 m .73612 .19549 L .73759 .19761 L 0 .026 .125 r
F
.73434 .19873 m .73286 .19659 L .73612 .19549 L F
.5607 .20028 m .56219 .19686 L .56385 .1991 L 0 .029 .129 r
F
.5607 .20028 m .55904 .19804 L .56219 .19686 L F
.42685 .19962 m .42813 .1963 L .42993 .19837 L 0 .028 .127 r
F
.42685 .19962 m .42504 .19755 L .42813 .1963 L F
.65789 .20028 m .65954 .19692 L .6611 .19919 L 0 .029 .129 r
F
.65789 .20028 m .65633 .19802 L .65954 .19692 L F
.33761 .19923 m .33874 .19605 L .34063 .19818 L 0 .027 .127 r
F
.33761 .19923 m .33572 .19711 L .33874 .19605 L F
.29299 .19902 m .29405 .19575 L .296 .19783 L 0 .027 .126 r
F
.29299 .19902 m .29105 .19695 L .29405 .19575 L F
.38223 .19947 m .38343 .19622 L .38528 .19828 L 0 .028 .127 r
F
.38223 .19947 m .38038 .1974 L .38343 .19622 L F
.62123 .1997 m .62283 .19639 L .62442 .19841 L F
.62123 .1997 m .61964 .19766 L .62283 .19639 L F
.45555 .20081 m .45687 .1974 L .45864 .1996 L 0 .03 .13 r
F
.45555 .20081 m .45378 .19862 L .45687 .1974 L F
.61328 .20021 m .61486 .19685 L .61646 .19892 L 0 .029 .129 r
F
.61328 .20021 m .61167 .19813 L .61486 .19685 L F
.39018 .19913 m .3914 .19593 L .39324 .19798 L 0 .027 .126 r
F
.39018 .19913 m .38834 .19708 L .3914 .19593 L F
.77897 .19915 m .78081 .19569 L .78224 .1979 L F
.77897 .19915 m .77753 .19693 L .78081 .19569 L F
.25632 .19849 m .25732 .19522 L .2593 .19731 L 0 .026 .125 r
F
.25632 .19849 m .25434 .19639 L .25732 .19522 L F
.4348 .19939 m .43609 .19607 L .43788 .19833 L 0 .027 .127 r
F
.4348 .19939 m .43301 .19713 L .43609 .19607 L F
.6292 .1994 m .6308 .1961 L .63239 .19827 L 0 .028 .127 r
F
.6292 .1994 m .62761 .19725 L .6308 .1961 L F
.60532 .20074 m .60689 .19738 L .6085 .19943 L 0 .03 .13 r
F
.60532 .20074 m .60371 .19869 L .60689 .19738 L F
.4635 .20055 m .46484 .19709 L .4666 .19931 L F
.4635 .20055 m .46174 .19835 L .46484 .19709 L F
.74232 .19859 m .74411 .19528 L .74557 .19738 L 0 .026 .125 r
F
.74232 .19859 m .74085 .19648 L .74411 .19528 L F
.78694 .19884 m .78881 .19561 L .79023 .19772 L 0 .027 .126 r
F
.78694 .19884 m .78552 .19673 L .78881 .19561 L F
.50016 .20129 m .50156 .19775 L .50328 .20002 L 0 .031 .131 r
F
.50016 .20129 m .49844 .19903 L .50156 .19775 L F
.30093 .19888 m .30201 .19552 L .30393 .19776 L 0 .027 .126 r
F
.30093 .19888 m .299 .19668 L .30201 .19552 L F
.56866 .20021 m .57017 .19685 L .57182 .1991 L 0 .029 .129 r
F
.56866 .20021 m .56701 .19798 L .57017 .19685 L F
.51608 .20044 m .5175 .19707 L .51921 .19916 L 0 .03 .13 r
F
.51608 .20044 m .51437 .19835 L .5175 .19707 L F
.47146 .20025 m .47281 .1968 L .47456 .19901 L 0 .029 .129 r
F
.47146 .20025 m .4697 .19806 L .47281 .1968 L F
.50812 .20094 m .50953 .19745 L .51124 .19965 L 0 .03 .131 r
F
.50812 .20094 m .50641 .19874 L .50953 .19745 L F
.26426 .1983 m .26527 .19502 L .26724 .19721 L 0 .026 .125 r
F
.26426 .1983 m .26229 .19613 L .26527 .19502 L F
.66587 .20029 m .66753 .19692 L .66908 .19911 L 0 .029 .129 r
F
.66587 .20029 m .66432 .1981 L .66753 .19692 L F
.67383 .19988 m .6755 .19652 L .67704 .19859 L 0 .029 .128 r
F
.67383 .19988 m .67229 .19782 L .6755 .19652 L F
.34554 .19924 m .34668 .19606 L .34857 .19818 L 0 .028 .127 r
F
.34554 .19924 m .34365 .19712 L .34668 .19606 L F
.75029 .19837 m .75209 .19498 L .75355 .19719 L 0 .026 .125 r
F
.75029 .19837 m .74883 .19618 L .75209 .19498 L F
.68179 .19949 m .68349 .19628 L .68501 .19836 L 0 .028 .128 r
F
.68179 .19949 m .68026 .19742 L .68349 .19628 L F
.52404 .20017 m .52548 .19697 L .52717 .19909 L 0 .03 .13 r
F
.52404 .20017 m .52234 .19807 L .52548 .19697 L F
.39812 .19912 m .39936 .19579 L .40118 .19804 L 0 .027 .127 r
F
.39812 .19912 m .39629 .19689 L .39936 .19579 L F
.63717 .19936 m .63878 .19586 L .64036 .19812 L 0 .028 .127 r
F
.63717 .19936 m .63558 .1971 L .63878 .19586 L F
.47941 .20005 m .48078 .19682 L .48252 .19898 L 0 .029 .129 r
F
.47941 .20005 m .47767 .19787 L .48078 .19682 L F
.69772 .19878 m .69944 .19549 L .70095 .19757 L 0 .027 .126 r
F
.69772 .19878 m .69621 .19672 L .69944 .19549 L F
.68976 .19923 m .69146 .19592 L .69298 .19798 L 0 .028 .127 r
F
.68976 .19923 m .68824 .1972 L .69146 .19592 L F
.57663 .20015 m .57814 .19668 L .57979 .19896 L 0 .029 .129 r
F
.57663 .20015 m .57498 .19789 L .57814 .19668 L F
.30886 .19886 m .30995 .19546 L .31187 .19769 L 0 .027 .126 r
F
.30886 .19886 m .30694 .19662 L .30995 .19546 L F
.35348 .19909 m .35465 .19575 L .35652 .19789 L 0 .028 .127 r
F
.35348 .19909 m .35161 .19697 L .35465 .19575 L F
.44274 .19955 m .44405 .1962 L .44583 .19848 L 0 .029 .128 r
F
.44274 .19955 m .44096 .19726 L .44405 .1962 L F
.75828 .19824 m .76008 .19485 L .76154 .19707 L 0 .026 .125 r
F
.75828 .19824 m .75682 .19602 L .76008 .19485 L F
.70569 .19846 m .70742 .19516 L .70892 .19727 L 0 .027 .126 r
F
.70569 .19846 m .70418 .19636 L .70742 .19516 L F
.64514 .19913 m .64677 .19573 L .64834 .19798 L 0 .028 .127 r
F
.64514 .19913 m .64356 .19688 L .64677 .19573 L F
.532 .2001 m .53345 .1969 L .53514 .19901 L 0 .03 .13 r
F
.532 .2001 m .53031 .198 L .53345 .1969 L F
.27218 .19834 m .2732 .19506 L .27516 .19727 L 0 .027 .126 r
F
.27218 .19834 m .27022 .19613 L .2732 .19506 L F
.36143 .19886 m .36261 .19552 L .36447 .19771 L 0 .027 .127 r
F
.36143 .19886 m .35956 .1967 L .36261 .19552 L F
.3168 .19866 m .3179 .19531 L .31982 .19745 L 0 .027 .126 r
F
.3168 .19866 m .31488 .19651 L .3179 .19531 L F
.48737 .20003 m .48874 .19685 L .49048 .19897 L 0 .03 .13 r
F
.48737 .20003 m .48563 .1979 L .48874 .19685 L F
.71366 .19829 m .71541 .19504 L .71691 .19717 L 0 .027 .126 r
F
.71366 .19829 m .71216 .19615 L .71541 .19504 L F
.58459 .20009 m .58613 .19667 L .58776 .19897 L 0 .03 .13 r
F
.58459 .20009 m .58296 .19779 L .58613 .19667 L F
.32475 .19833 m .32587 .19505 L .32778 .19714 L 0 .027 .126 r
F
.32475 .19833 m .32284 .19624 L .32587 .19505 L F
.40606 .19922 m .40731 .19588 L .40912 .19816 L 0 .028 .128 r
F
.40606 .19922 m .40424 .19696 L .40731 .19588 L F
.76627 .19818 m .76809 .19486 L .76954 .19708 L 0 .026 .126 r
F
.76627 .19818 m .76481 .19596 L .76809 .19486 L F
.54792 .19954 m .5494 .19617 L .55107 .19825 L 0 .029 .129 r
F
.54792 .19954 m .54625 .19745 L .5494 .19617 L F
.65312 .19913 m .65476 .19576 L .65633 .19802 L 0 .028 .128 r
F
.65312 .19913 m .65155 .19687 L .65476 .19576 L F
.53996 .20002 m .54142 .19667 L .5431 .19875 L 0 .03 .13 r
F
.53996 .20002 m .53828 .19793 L .54142 .19667 L F
.36938 .19876 m .37057 .19541 L .37242 .19761 L 0 .028 .127 r
F
.36938 .19876 m .36752 .19655 L .37057 .19541 L F
.2801 .19832 m .28113 .19516 L .28309 .19726 L 0 .027 .127 r
F
.2801 .19832 m .27814 .19622 L .28113 .19516 L F
.24343 .19766 m .2444 .19447 L .2464 .19657 L 0 .026 .125 r
F
.24343 .19766 m .24143 .19555 L .2444 .19447 L F
.72164 .19813 m .7234 .19477 L .72488 .19687 L 0 .027 .126 r
F
.72164 .19813 m .72015 .19601 L .7234 .19477 L F
.45069 .19968 m .45201 .19637 L .45378 .19862 L 0 .03 .13 r
F
.45069 .19968 m .44891 .19743 L .45201 .19637 L F
.3327 .19817 m .33381 .19502 L .33572 .19711 L 0 .027 .126 r
F
.3327 .19817 m .33079 .19608 L .33381 .19502 L F
.59256 .19994 m .59411 .19675 L .59574 .19884 L 0 .03 .13 r
F
.59256 .19994 m .59093 .19784 L .59411 .19675 L F
.55589 .19928 m .55737 .19579 L .55904 .19804 L 0 .029 .128 r
F
.55589 .19928 m .55422 .19702 L .55737 .19579 L F
.72961 .19774 m .73138 .19447 L .73286 .19659 L 0 .026 .125 r
F
.72961 .19774 m .72813 .19561 L .73138 .19447 L F
.37733 .19857 m .37852 .1953 L .38038 .1974 L 0 .028 .127 r
F
.37733 .19857 m .37547 .19645 L .37852 .1953 L F
.414 .19924 m .41527 .1958 L .41708 .19799 L 0 .029 .129 r
F
.414 .19924 m .41219 .19705 L .41527 .1958 L F
.42197 .1988 m .42324 .19548 L .42504 .19755 L 0 .028 .128 r
F
.42197 .1988 m .42016 .19673 L .42324 .19548 L F
.42993 .19837 m .43121 .19506 L .43301 .19713 L 0 .027 .127 r
F
.42993 .19837 m .42813 .1963 L .43121 .19506 L F
.28804 .19815 m .28909 .19489 L .29105 .19695 L 0 .027 .126 r
F
.28804 .19815 m .28609 .1961 L .28909 .19489 L F
.77426 .19817 m .77609 .19471 L .77753 .19693 L F
.77426 .19817 m .77282 .19595 L .77609 .19471 L F
.49532 .20018 m .49671 .19677 L .49844 .19903 L 0 .031 .131 r
F
.49532 .20018 m .49359 .19791 L .49671 .19677 L F
.62442 .19841 m .62602 .19521 L .62761 .19725 L 0 .028 .127 r
F
.62442 .19841 m .62283 .19639 L .62602 .19521 L F
.25136 .19754 m .25235 .19434 L .25434 .19639 L 0 .026 .125 r
F
.25136 .19754 m .24937 .19547 L .25235 .19434 L F
.56385 .1991 m .56535 .19572 L .56701 .19798 L 0 .029 .129 r
F
.56385 .1991 m .56219 .19686 L .56535 .19572 L F
.60053 .1998 m .60209 .19664 L .60371 .19869 L 0 .03 .131 r
F
.60053 .1998 m .59891 .19776 L .60209 .19664 L F
.61646 .19892 m .61804 .19561 L .61964 .19766 L 0 .029 .128 r
F
.61646 .19892 m .61486 .19685 L .61804 .19561 L F
.296 .19783 m .29706 .19458 L .299 .19668 L 0 .027 .126 r
F
.296 .19783 m .29405 .19575 L .29706 .19458 L F
.45864 .1996 m .45998 .19614 L .46174 .19835 L 0 .03 .13 r
F
.45864 .1996 m .45687 .1974 L .45998 .19614 L F
.73759 .19761 m .73938 .19438 L .74085 .19648 L 0 .026 .125 r
F
.73759 .19761 m .73612 .19549 L .73938 .19438 L F
.38528 .19828 m .38649 .19503 L .38834 .19708 L 0 .027 .127 r
F
.38528 .19828 m .38343 .19622 L .38649 .19503 L F
.6611 .19919 m .66276 .19581 L .66432 .1981 L 0 .029 .129 r
F
.6611 .19919 m .65954 .19692 L .66276 .19581 L F
.6085 .19943 m .61007 .19606 L .61167 .19813 L 0 .03 .13 r
F
.6085 .19943 m .60689 .19738 L .61007 .19606 L F
.78224 .1979 m .78409 .19453 L .78552 .19673 L 0 .027 .126 r
F
.78224 .1979 m .78081 .19569 L .78409 .19453 L F
.34063 .19818 m .34176 .19499 L .34365 .19712 L 0 .028 .127 r
F
.34063 .19818 m .33874 .19605 L .34176 .19499 L F
.2593 .19731 m .26031 .19405 L .26229 .19613 L 0 .026 .125 r
F
.2593 .19731 m .25732 .19522 L .26031 .19405 L F
.39324 .19798 m .39446 .19481 L .39629 .19689 L 0 .027 .127 r
F
.39324 .19798 m .3914 .19593 L .39446 .19481 L F
.4666 .19931 m .46795 .19584 L .4697 .19806 L 0 .029 .129 r
F
.4666 .19931 m .46484 .19709 L .46795 .19584 L F
.50328 .20002 m .50469 .19647 L .50641 .19874 L 0 .031 .131 r
F
.50328 .20002 m .50156 .19775 L .50469 .19647 L F
.74557 .19738 m .74736 .19407 L .74883 .19618 L 0 .026 .125 r
F
.74557 .19738 m .74411 .19528 L .74736 .19407 L F
.63239 .19827 m .634 .19492 L .63558 .1971 L 0 .028 .127 r
F
.63239 .19827 m .6308 .1961 L .634 .19492 L F
.51921 .19916 m .52064 .19596 L .52234 .19807 L 0 .03 .129 r
F
.51921 .19916 m .5175 .19707 L .52064 .19596 L F
.51124 .19965 m .51266 .19616 L .51437 .19835 L 0 .03 .13 r
F
.51124 .19965 m .50953 .19745 L .51266 .19616 L F
.43788 .19833 m .43918 .19501 L .44096 .19726 L 0 .028 .127 r
F
.43788 .19833 m .43609 .19607 L .43918 .19501 L F
.47456 .19901 m .47592 .19566 L .47767 .19787 L 0 .029 .129 r
F
.47456 .19901 m .47281 .1968 L .47592 .19566 L F
.67704 .19859 m .67873 .19535 L .68026 .19742 L 0 .028 .128 r
F
.67704 .19859 m .6755 .19652 L .67873 .19535 L F
.79023 .19772 m .7921 .19449 L .79352 .1966 L 0 .027 .126 r
F
.79023 .19772 m .78881 .19561 L .7921 .19449 L F
.30393 .19776 m .30502 .19438 L .30694 .19662 L F
.30393 .19776 m .30201 .19552 L .30502 .19438 L F
.57182 .1991 m .57333 .19562 L .57498 .19789 L 0 .029 .129 r
F
.57182 .1991 m .57017 .19685 L .57333 .19562 L F
.66908 .19911 m .67074 .19564 L .67229 .19782 L F
.66908 .19911 m .66753 .19692 L .67074 .19564 L F
.75355 .19719 m .75535 .19381 L .75682 .19602 L 0 .026 .125 r
F
.75355 .19719 m .75209 .19498 L .75535 .19381 L F
.26724 .19721 m .26826 .19393 L .27022 .19613 L F
.26724 .19721 m .26527 .19502 L .26826 .19393 L F
.64036 .19812 m .64198 .19462 L .64356 .19688 L 0 .027 .127 r
F
.64036 .19812 m .63878 .19586 L .64198 .19462 L F
.68501 .19836 m .68672 .19511 L .68824 .1972 L 0 .028 .128 r
F
.68501 .19836 m .68349 .19628 L .68672 .19511 L F
.34857 .19818 m .34972 .19483 L .35161 .19697 L 0 .028 .127 r
F
.34857 .19818 m .34668 .19606 L .34972 .19483 L F
.69298 .19798 m .69469 .19464 L .69621 .19672 L F
.69298 .19798 m .69146 .19592 L .69469 .19464 L F
.52717 .19909 m .52861 .19587 L .53031 .198 L 0 .03 .13 r
F
.52717 .19909 m .52548 .19697 L .52861 .19587 L F
.70095 .19757 m .70267 .19427 L .70418 .19636 L 0 .027 .126 r
F
.70095 .19757 m .69944 .19549 L .70267 .19427 L F
.40118 .19804 m .40242 .19469 L .40424 .19696 L 0 .028 .127 r
F
.40118 .19804 m .39936 .19579 L .40242 .19469 L F
.57979 .19896 m .58131 .19549 L .58296 .19779 L 0 .029 .129 r
F
.57979 .19896 m .57814 .19668 L .58131 .19549 L F
.48252 .19898 m .48389 .19577 L .48563 .1979 L 0 .03 .13 r
F
.48252 .19898 m .48078 .19682 L .48389 .19577 L F
.35652 .19789 m .35769 .19454 L .35956 .1967 L 0 .027 .127 r
F
.35652 .19789 m .35465 .19575 L .35769 .19454 L F
.31187 .19769 m .31297 .19431 L .31488 .19651 L 0 .027 .126 r
F
.31187 .19769 m .30995 .19546 L .31297 .19431 L F
.70892 .19727 m .71066 .19403 L .71216 .19615 L F
.70892 .19727 m .70742 .19516 L .71066 .19403 L F
.76154 .19707 m .76336 .19374 L .76481 .19596 L 0 .026 .125 r
F
.76154 .19707 m .76008 .19485 L .76336 .19374 L F
.64834 .19798 m .64998 .19463 L .65155 .19687 L 0 .028 .127 r
F
.64834 .19798 m .64677 .19573 L .64998 .19463 L F
.44583 .19848 m .44714 .19514 L .44891 .19743 L 0 .029 .129 r
F
.44583 .19848 m .44405 .1962 L .44714 .19514 L F
.31982 .19745 m .32093 .19411 L .32284 .19624 L 0 .027 .126 r
F
.31982 .19745 m .3179 .19531 L .32093 .19411 L F
.53514 .19901 m .53659 .19581 L .53828 .19793 L 0 .03 .13 r
F
.53514 .19901 m .53345 .1969 L .53659 .19581 L F
.36447 .19771 m .36566 .19433 L .36752 .19655 L 0 .027 .127 r
F
.36447 .19771 m .36261 .19552 L .36566 .19433 L F
.27516 .19727 m .27619 .194 L .27814 .19622 L 0 .027 .126 r
F
.27516 .19727 m .2732 .19506 L .27619 .194 L F
.32778 .19714 m .32889 .19399 L .33079 .19608 L F
.32778 .19714 m .32587 .19505 L .32889 .19399 L F
.55107 .19825 m .55255 .19496 L .55422 .19702 L 0 .029 .128 r
F
.55107 .19825 m .5494 .19617 L .55255 .19496 L F
.71691 .19717 m .71866 .19389 L .72015 .19601 L 0 .027 .126 r
F
.71691 .19717 m .71541 .19504 L .71866 .19389 L F
.58776 .19897 m .5893 .19555 L .59093 .19784 L 0 .03 .13 r
F
.58776 .19897 m .58613 .19667 L .5893 .19555 L F
.49048 .19897 m .49186 .19579 L .49359 .19791 L 0 .03 .131 r
F
.49048 .19897 m .48874 .19685 L .49186 .19579 L F
.5431 .19875 m .54457 .19538 L .54625 .19745 L 0 .03 .13 r
F
.5431 .19875 m .54142 .19667 L .54457 .19538 L F
.40912 .19816 m .41038 .19476 L .41219 .19705 L 0 .029 .128 r
F
.40912 .19816 m .40731 .19588 L .41038 .19476 L F
.76954 .19708 m .77137 .19373 L .77282 .19595 L 0 .027 .126 r
F
.76954 .19708 m .76809 .19486 L .77137 .19373 L F
.72488 .19687 m .72664 .19353 L .72813 .19561 L 0 .026 .125 r
F
.72488 .19687 m .7234 .19477 L .72664 .19353 L F
.65633 .19802 m .65797 .19464 L .65954 .19692 L 0 .028 .128 r
F
.65633 .19802 m .65476 .19576 L .65797 .19464 L F
.55904 .19804 m .56053 .19461 L .56219 .19686 L F
.55904 .19804 m .55737 .19579 L .56053 .19461 L F
.37242 .19761 m .37362 .19428 L .37547 .19645 L 0 .028 .127 r
F
.37242 .19761 m .37057 .19541 L .37362 .19428 L F
.2464 .19657 m .24737 .1934 L .24937 .19547 L 0 .026 .125 r
F
.2464 .19657 m .2444 .19447 L .24737 .1934 L F
.73286 .19659 m .73464 .19338 L .73612 .19549 L F
.73286 .19659 m .73138 .19447 L .73464 .19338 L F
.28309 .19726 m .28413 .194 L .28609 .1961 L 0 .027 .127 r
F
.28309 .19726 m .28113 .19516 L .28413 .194 L F
.59574 .19884 m .59729 .19567 L .59891 .19776 L 0 .03 .131 r
F
.59574 .19884 m .59411 .19675 L .59729 .19567 L F
.45378 .19862 m .4551 .19515 L .45687 .1974 L 0 .03 .13 r
F
.45378 .19862 m .45201 .19637 L .4551 .19515 L F
.41708 .19799 m .41835 .19455 L .42016 .19673 L 0 .028 .128 r
F
.41708 .19799 m .41527 .1958 L .41835 .19455 L F
.33572 .19711 m .33684 .19396 L .33874 .19605 L 0 .027 .127 r
F
.33572 .19711 m .33381 .19502 L .33684 .19396 L F
.42504 .19755 m .42632 .19423 L .42813 .1963 L 0 .028 .127 r
F
.42504 .19755 m .42324 .19548 L .42632 .19423 L F
.43301 .19713 m .4343 .19399 L .43609 .19607 L 0 .027 .127 r
F
.43301 .19713 m .43121 .19506 L .4343 .19399 L F
.77753 .19693 m .77937 .19347 L .78081 .19569 L 0 .027 .126 r
F
.77753 .19693 m .77609 .19471 L .77937 .19347 L F
.29105 .19695 m .2921 .19368 L .29405 .19575 L F
.29105 .19695 m .28909 .19489 L .2921 .19368 L F
.38038 .1974 m .38158 .19413 L .38343 .19622 L 0 .028 .127 r
F
.38038 .1974 m .37852 .1953 L .38158 .19413 L F
.61964 .19766 m .62123 .19436 L .62283 .19639 L 0 .028 .128 r
F
.61964 .19766 m .61804 .19561 L .62123 .19436 L F
.46174 .19835 m .46308 .19487 L .46484 .19709 L 0 .029 .129 r
F
.46174 .19835 m .45998 .19614 L .46308 .19487 L F
.61167 .19813 m .61325 .19479 L .61486 .19685 L F
.61167 .19813 m .61007 .19606 L .61325 .19479 L F
.62761 .19725 m .62922 .19405 L .6308 .1961 L 0 .028 .127 r
F
.62761 .19725 m .62602 .19521 L .62922 .19405 L F
.49844 .19903 m .49984 .19549 L .50156 .19775 L 0 .031 .131 r
F
.49844 .19903 m .49671 .19677 L .49984 .19549 L F
.25434 .19639 m .25533 .19319 L .25732 .19522 L 0 .026 .125 r
F
.25434 .19639 m .25235 .19434 L .25533 .19319 L F
.38834 .19708 m .38955 .19388 L .3914 .19593 L 0 .027 .127 r
F
.38834 .19708 m .38649 .19503 L .38955 .19388 L F
.56701 .19798 m .56851 .19459 L .57017 .19685 L 0 .029 .129 r
F
.56701 .19798 m .56535 .19572 L .56851 .19459 L F
.299 .19668 m .30007 .1934 L .30201 .19552 L 0 .027 .126 r
F
.299 .19668 m .29706 .19458 L .30007 .1934 L F
.60371 .19869 m .60527 .19532 L .60689 .19738 L 0 .03 .13 r
F
.60371 .19869 m .60209 .19664 L .60527 .19532 L F
.74085 .19648 m .74264 .19317 L .74411 .19528 L 0 .026 .125 r
F
.74085 .19648 m .73938 .19438 L .74264 .19317 L F
.4697 .19806 m .47106 .19457 L .47281 .1968 L 0 .029 .129 r
F
.4697 .19806 m .46795 .19584 L .47106 .19457 L F
.78552 .19673 m .78738 .19342 L .78881 .19561 L 0 .027 .126 r
F
.78552 .19673 m .78409 .19453 L .78738 .19342 L F
.50641 .19874 m .50782 .19518 L .50953 .19745 L 0 .03 .13 r
F
.50641 .19874 m .50469 .19647 L .50782 .19518 L F
.66432 .1981 m .66597 .19464 L .66753 .19692 L 0 .029 .129 r
F
.66432 .1981 m .66276 .19581 L .66597 .19464 L F
.26229 .19613 m .26329 .19293 L .26527 .19502 L 0 .026 .125 r
F
.26229 .19613 m .26031 .19405 L .26329 .19293 L F
.51437 .19835 m .5158 .19488 L .5175 .19707 L 0 .03 .13 r
F
.51437 .19835 m .51266 .19616 L .5158 .19488 L F
.74883 .19618 m .75063 .19289 L .75209 .19498 L 0 .026 .125 r
F
.74883 .19618 m .74736 .19407 L .75063 .19289 L F
.63558 .1971 m .6372 .19367 L .63878 .19586 L 0 .027 .127 r
F
.63558 .1971 m .634 .19492 L .6372 .19367 L F
.39629 .19689 m .39752 .1937 L .39936 .19579 L F
.39629 .19689 m .39446 .19481 L .39752 .1937 L F
.34365 .19712 m .34479 .19393 L .34668 .19606 L 0 .028 .127 r
F
.34365 .19712 m .34176 .19499 L .34479 .19393 L F
.67229 .19782 m .67396 .19435 L .6755 .19652 L 0 .029 .129 r
F
.67229 .19782 m .67074 .19564 L .67396 .19435 L F
.52234 .19807 m .52377 .19486 L .52548 .19697 L 0 .03 .13 r
F
.52234 .19807 m .52064 .19596 L .52377 .19486 L F
.68026 .19742 m .68196 .1942 L .68349 .19628 L 0 .028 .128 r
F
.68026 .19742 m .67873 .19535 L .68196 .1942 L F
.47767 .19787 m .47903 .19462 L .48078 .19682 L 0 .029 .129 r
F
.47767 .19787 m .47592 .19566 L .47903 .19462 L F
.57498 .19789 m .5765 .19439 L .57814 .19668 L F
.57498 .19789 m .57333 .19562 L .5765 .19439 L F
.44096 .19726 m .44226 .19395 L .44405 .1962 L 0 .028 .128 r
F
.44096 .19726 m .43918 .19501 L .44226 .19395 L F
.30694 .19662 m .30803 .19324 L .30995 .19546 L 0 .027 .126 r
F
.30694 .19662 m .30502 .19438 L .30803 .19324 L F
.64356 .19688 m .64519 .19348 L .64677 .19573 L 0 .027 .127 r
F
.64356 .19688 m .64198 .19462 L .64519 .19348 L F
.75682 .19602 m .75862 .19263 L .76008 .19485 L 0 .026 .125 r
F
.75682 .19602 m .75535 .19381 L .75862 .19263 L F
.69621 .19672 m .69792 .19339 L .69944 .19549 L 0 .027 .127 r
F
.69621 .19672 m .69469 .19464 L .69792 .19339 L F
.35161 .19697 m .35277 .1936 L .35465 .19575 L 0 .028 .127 r
F
.35161 .19697 m .34972 .19483 L .35277 .1936 L F
.68824 .1972 m .68994 .19381 L .69146 .19592 L 0 .028 .128 r
F
.68824 .1972 m .68672 .19511 L .68994 .19381 L F
.27022 .19613 m .27125 .19284 L .2732 .19506 L 0 .026 .125 r
F
.27022 .19613 m .26826 .19393 L .27125 .19284 L F
.70418 .19636 m .70591 .19305 L .70742 .19516 L 0 .027 .126 r
F
.70418 .19636 m .70267 .19427 L .70591 .19305 L F
.53031 .198 m .53176 .19474 L .53345 .1969 L 0 .03 .13 r
F
.53031 .198 m .52861 .19587 L .53176 .19474 L F
.58296 .19779 m .58449 .19437 L .58613 .19667 L 0 .029 .129 r
F
.58296 .19779 m .58131 .19549 L .58449 .19437 L F
.35956 .1967 m .36074 .19334 L .36261 .19552 L 0 .027 .127 r
F
.35956 .1967 m .35769 .19454 L .36074 .19334 L F
.31488 .19651 m .31599 .19312 L .3179 .19531 L 0 .027 .126 r
F
.31488 .19651 m .31297 .19431 L .31599 .19312 L F
.40424 .19696 m .40549 .19359 L .40731 .19588 L 0 .028 .127 r
F
.40424 .19696 m .40242 .19469 L .40549 .19359 L F
.48563 .1979 m .487 .19472 L .48874 .19685 L 0 .03 .13 r
F
.48563 .1979 m .48389 .19577 L .487 .19472 L F
.71216 .19615 m .71391 .19289 L .71541 .19504 L 0 .027 .126 r
F
.71216 .19615 m .71066 .19403 L .71391 .19289 L F
.76481 .19596 m .76664 .19264 L .76809 .19486 L 0 .026 .125 r
F
.76481 .19596 m .76336 .19374 L .76664 .19264 L F
.65155 .19687 m .65319 .19353 L .65476 .19576 L 0 .028 .127 r
F
.65155 .19687 m .64998 .19463 L .65319 .19353 L F
.32284 .19624 m .32395 .19293 L .32587 .19505 L 0 .027 .126 r
F
.32284 .19624 m .32093 .19411 L .32395 .19293 L F
.44891 .19743 m .45023 .19409 L .45201 .19637 L 0 .029 .129 r
F
.44891 .19743 m .44714 .19514 L .45023 .19409 L F
.36752 .19655 m .36871 .19321 L .37057 .19541 L 0 .027 .127 r
F
.36752 .19655 m .36566 .19433 L .36871 .19321 L F
.54625 .19745 m .54772 .19412 L .5494 .19617 L 0 .029 .129 r
F
.54625 .19745 m .54457 .19538 L .54772 .19412 L F
.55422 .19702 m .55571 .19375 L .55737 .19579 L 0 .028 .128 r
F
.55422 .19702 m .55255 .19496 L .55571 .19375 L F
.53828 .19793 m .53974 .19456 L .54142 .19667 L 0 .03 .13 r
F
.53828 .19793 m .53659 .19581 L .53974 .19456 L F
.27814 .19622 m .27918 .19293 L .28113 .19516 L 0 .027 .126 r
F
.27814 .19622 m .27619 .194 L .27918 .19293 L F
.72015 .19601 m .7219 .19266 L .7234 .19477 L F
.72015 .19601 m .71866 .19389 L .7219 .19266 L F
.72813 .19561 m .7299 .19239 L .73138 .19447 L 0 .026 .125 r
F
.72813 .19561 m .72664 .19353 L .7299 .19239 L F
.59093 .19784 m .59248 .19445 L .59411 .19675 L 0 .03 .13 r
F
.59093 .19784 m .5893 .19555 L .59248 .19445 L F
.33079 .19608 m .33191 .19293 L .33381 .19502 L 0 .027 .126 r
F
.33079 .19608 m .32889 .19399 L .33191 .19293 L F
.49359 .19791 m .49498 .19466 L .49671 .19677 L 0 .031 .131 r
F
.49359 .19791 m .49186 .19579 L .49498 .19466 L F
.41219 .19705 m .41346 .19353 L .41527 .1958 L 0 .028 .128 r
F
.41219 .19705 m .41038 .19476 L .41346 .19353 L F
.77282 .19595 m .77465 .1925 L .77609 .19471 L 0 .027 .126 r
F
.77282 .19595 m .77137 .19373 L .77465 .1925 L F
.56219 .19686 m .56369 .19346 L .56535 .19572 L 0 .028 .128 r
F
.56219 .19686 m .56053 .19461 L .56369 .19346 L F
.37547 .19645 m .37667 .19314 L .37852 .1953 L 0 .028 .127 r
F
.37547 .19645 m .37362 .19428 L .37667 .19314 L F
.65954 .19692 m .66119 .19352 L .66276 .19581 L 0 .029 .128 r
F
.65954 .19692 m .65797 .19464 L .66119 .19352 L F
.42016 .19673 m .42143 .19331 L .42324 .19548 L 0 .028 .128 r
F
.42016 .19673 m .41835 .19455 L .42143 .19331 L F
.45687 .1974 m .45821 .19388 L .45998 .19614 L 0 .029 .129 r
F
.45687 .1974 m .4551 .19515 L .45821 .19388 L F
.42813 .1963 m .42941 .19298 L .43121 .19506 L 0 .028 .127 r
F
.42813 .1963 m .42632 .19423 L .42941 .19298 L F
.28609 .1961 m .28714 .19278 L .28909 .19489 L 0 .027 .127 r
F
.28609 .1961 m .28413 .194 L .28714 .19278 L F
.78081 .19569 m .78265 .19232 L .78409 .19453 L 0 .026 .125 r
F
.78081 .19569 m .77937 .19347 L .78265 .19232 L F
.24937 .19547 m .25035 .19229 L .25235 .19434 L F
.24937 .19547 m .24737 .1934 L .25035 .19229 L F
.73612 .19549 m .73791 .19228 L .73938 .19438 L F
.73612 .19549 m .73464 .19338 L .73791 .19228 L F
.62283 .19639 m .62443 .19318 L .62602 .19521 L 0 .028 .128 r
F
.62283 .19639 m .62123 .19436 L .62443 .19318 L F
.61486 .19685 m .61644 .19355 L .61804 .19561 L 0 .029 .129 r
F
.61486 .19685 m .61325 .19479 L .61644 .19355 L F
.29405 .19575 m .29511 .19249 L .29706 .19458 L 0 .027 .126 r
F
.29405 .19575 m .2921 .19368 L .29511 .19249 L F
.50156 .19775 m .50297 .1942 L .50469 .19647 L 0 .03 .13 r
F
.50156 .19775 m .49984 .19549 L .50297 .1942 L F
.59891 .19776 m .60048 .19456 L .60209 .19664 L 0 .031 .131 r
F
.59891 .19776 m .59729 .19567 L .60048 .19456 L F
.46484 .19709 m .46619 .19361 L .46795 .19584 L 0 .029 .129 r
F
.46484 .19709 m .46308 .19487 L .46619 .19361 L F
.38343 .19622 m .38464 .19296 L .38649 .19503 L 0 .028 .127 r
F
.38343 .19622 m .38158 .19413 L .38464 .19296 L F
.60689 .19738 m .60846 .194 L .61007 .19606 L 0 .03 .13 r
F
.60689 .19738 m .60527 .19532 L .60846 .194 L F
.33874 .19605 m .33987 .19291 L .34176 .19499 L 0 .028 .127 r
F
.33874 .19605 m .33684 .19396 L .33987 .19291 L F
.43609 .19607 m .43738 .19292 L .43918 .19501 L F
.43609 .19607 m .4343 .19399 L .43738 .19292 L F
.6308 .1961 m .63242 .19286 L .634 .19492 L F
.6308 .1961 m .62922 .19405 L .63242 .19286 L F
.25732 .19522 m .25832 .19204 L .26031 .19405 L 0 .026 .125 r
F
.25732 .19522 m .25533 .19319 L .25832 .19204 L F
.50953 .19745 m .51095 .1939 L .51266 .19616 L 0 .03 .13 r
F
.50953 .19745 m .50782 .19518 L .51095 .1939 L F
.47281 .1968 m .47417 .19343 L .47592 .19566 L 0 .029 .129 r
F
.47281 .1968 m .47106 .19457 L .47417 .19343 L F
.3914 .19593 m .39261 .19274 L .39446 .19481 L 0 .027 .127 r
F
.3914 .19593 m .38955 .19388 L .39261 .19274 L F
.74411 .19528 m .7459 .19197 L .74736 .19407 L 0 .026 .125 r
F
.74411 .19528 m .74264 .19317 L .7459 .19197 L F
.5175 .19707 m .51893 .19377 L .52064 .19596 L 0 .029 .129 r
F
.5175 .19707 m .5158 .19488 L .51893 .19377 L F
.30201 .19552 m .30308 .19225 L .30502 .19438 L 0 .027 .126 r
F
.30201 .19552 m .30007 .1934 L .30308 .19225 L F
.57017 .19685 m .57168 .19335 L .57333 .19562 L 0 .029 .129 r
F
.57017 .19685 m .56851 .19459 L .57168 .19335 L F
.66753 .19692 m .66919 .19338 L .67074 .19564 L F
.66753 .19692 m .66597 .19464 L .66919 .19338 L F
.78881 .19561 m .79068 .1923 L .7921 .19449 L 0 .027 .126 r
F
.78881 .19561 m .78738 .19342 L .79068 .1923 L F
.6755 .19652 m .67719 .19319 L .67873 .19535 L 0 .028 .128 r
F
.6755 .19652 m .67396 .19435 L .67719 .19319 L F
.63878 .19586 m .6404 .19241 L .64198 .19462 L 0 .027 .126 r
F
.63878 .19586 m .6372 .19367 L .6404 .19241 L F
.75209 .19498 m .7539 .19173 L .75535 .19381 L 0 .026 .125 r
F
.75209 .19498 m .75063 .19289 L .7539 .19173 L F
.26527 .19502 m .26628 .19181 L .26826 .19393 L F
.26527 .19502 m .26329 .19293 L .26628 .19181 L F
.39936 .19579 m .40059 .19258 L .40242 .19469 L 0 .028 .127 r
F
.39936 .19579 m .39752 .1937 L .40059 .19258 L F
.57814 .19668 m .57967 .19321 L .58131 .19549 L 0 .029 .129 r
F
.57814 .19668 m .5765 .19439 L .57967 .19321 L F
.34668 .19606 m .34784 .1927 L .34972 .19483 L 0 .028 .127 r
F
.34668 .19606 m .34479 .19393 L .34784 .1927 L F
.68349 .19628 m .68519 .19302 L .68672 .19511 L 0 .028 .128 r
F
.68349 .19628 m .68196 .1942 L .68519 .19302 L F
.52548 .19697 m .52692 .19373 L .52861 .19587 L 0 .03 .13 r
F
.52548 .19697 m .52377 .19486 L .52692 .19373 L F
.30995 .19546 m .31105 .1921 L .31297 .19431 L 0 .027 .126 r
F
.30995 .19546 m .30803 .19324 L .31105 .1921 L F
.69146 .19592 m .69317 .1925 L .69469 .19464 L 0 .028 .127 r
F
.69146 .19592 m .68994 .19381 L .69317 .1925 L F
.69944 .19549 m .70116 .19216 L .70267 .19427 L 0 .027 .126 r
F
.69944 .19549 m .69792 .19339 L .70116 .19216 L F
.48078 .19682 m .48214 .19358 L .48389 .19577 L 0 .03 .13 r
F
.48078 .19682 m .47903 .19462 L .48214 .19358 L F
.64677 .19573 m .6484 .19239 L .64998 .19463 L 0 .027 .127 r
F
.64677 .19573 m .64519 .19348 L .6484 .19239 L F
.76008 .19485 m .7619 .19152 L .76336 .19374 L 0 .026 .125 r
F
.76008 .19485 m .75862 .19263 L .7619 .19152 L F
.35465 .19575 m .35582 .19238 L .35769 .19454 L 0 .027 .127 r
F
.35465 .19575 m .35277 .1936 L .35582 .19238 L F
.44405 .1962 m .44536 .19289 L .44714 .19514 L 0 .028 .128 r
F
.44405 .1962 m .44226 .19395 L .44536 .19289 L F
.70742 .19516 m .70915 .19189 L .71066 .19403 L 0 .027 .126 r
F
.70742 .19516 m .70591 .19305 L .70915 .19189 L F
.2732 .19506 m .27423 .19177 L .27619 .194 L F
.2732 .19506 m .27125 .19284 L .27423 .19177 L F
.36261 .19552 m .36379 .19214 L .36566 .19433 L 0 .027 .127 r
F
.36261 .19552 m .36074 .19334 L .36379 .19214 L F
.3179 .19531 m .31901 .19193 L .32093 .19411 L 0 .027 .126 r
F
.3179 .19531 m .31599 .19312 L .31901 .19193 L F
.58613 .19667 m .58766 .19325 L .5893 .19555 L 0 .029 .129 r
F
.58613 .19667 m .58449 .19437 L .58766 .19325 L F
.53345 .1969 m .5349 .19362 L .53659 .19581 L 0 .03 .13 r
F
.53345 .1969 m .53176 .19474 L .5349 .19362 L F
.40731 .19588 m .40856 .19246 L .41038 .19476 L 0 .028 .128 r
F
.40731 .19588 m .40549 .19359 L .40856 .19246 L F
.71541 .19504 m .71716 .19172 L .71866 .19389 L 0 .027 .126 r
F
.71541 .19504 m .71391 .19289 L .71716 .19172 L F
.32587 .19505 m .32698 .19185 L .32889 .19399 L F
.32587 .19505 m .32395 .19293 L .32698 .19185 L F
.5494 .19617 m .55088 .19293 L .55255 .19496 L 0 .029 .129 r
F
.5494 .19617 m .54772 .19412 L .55088 .19293 L F
.48874 .19685 m .49012 .19367 L .49186 .19579 L 0 .03 .131 r
F
.48874 .19685 m .487 .19472 L .49012 .19367 L F
.76809 .19486 m .76992 .19151 L .77137 .19373 L 0 .026 .125 r
F
.76809 .19486 m .76664 .19264 L .76992 .19151 L F
.65476 .19576 m .65641 .19242 L .65797 .19464 L 0 .028 .128 r
F
.65476 .19576 m .65319 .19353 L .65641 .19242 L F
.54142 .19667 m .54289 .19328 L .54457 .19538 L 0 .03 .13 r
F
.54142 .19667 m .53974 .19456 L .54289 .19328 L F
.55737 .19579 m .55887 .19256 L .56053 .19461 L 0 .028 .128 r
F
.55737 .19579 m .55571 .19375 L .55887 .19256 L F
.37057 .19541 m .37176 .19209 L .37362 .19428 L 0 .028 .127 r
F
.37057 .19541 m .36871 .19321 L .37176 .19209 L F
.7234 .19477 m .72516 .19143 L .72664 .19353 L 0 .026 .125 r
F
.7234 .19477 m .7219 .19266 L .72516 .19143 L F
.45201 .19637 m .45333 .19287 L .4551 .19515 L 0 .029 .129 r
F
.45201 .19637 m .45023 .19409 L .45333 .19287 L F
.73138 .19447 m .73316 .19131 L .73464 .19338 L 0 .026 .125 r
F
.73138 .19447 m .7299 .19239 L .73316 .19131 L F
.41527 .1958 m .41654 .19229 L .41835 .19455 L 0 .028 .128 r
F
.41527 .1958 m .41346 .19353 L .41654 .19229 L F
.77609 .19471 m .77793 .19127 L .77937 .19347 L 0 .026 .125 r
F
.77609 .19471 m .77465 .1925 L .77793 .19127 L F
.28113 .19516 m .28219 .19176 L .28413 .194 L 0 .027 .127 r
F
.28113 .19516 m .27918 .19293 L .28219 .19176 L F
.59411 .19675 m .59566 .19337 L .59729 .19567 L 0 .03 .13 r
F
.59411 .19675 m .59248 .19445 L .59566 .19337 L F
.49671 .19677 m .49811 .19338 L .49984 .19549 L 0 .03 .131 r
F
.49671 .19677 m .49498 .19466 L .49811 .19338 L F
.33381 .19502 m .33494 .19187 L .33684 .19396 L 0 .027 .127 r
F
.33381 .19502 m .33191 .19293 L .33494 .19187 L F
.45998 .19614 m .46132 .19262 L .46308 .19487 L 0 .029 .129 r
F
.45998 .19614 m .45821 .19388 L .46132 .19262 L F
.42324 .19548 m .42452 .19207 L .42632 .19423 L 0 .028 .127 r
F
.42324 .19548 m .42143 .19331 L .42452 .19207 L F
.43121 .19506 m .4325 .19191 L .4343 .19399 L F
.43121 .19506 m .42941 .19298 L .4325 .19191 L F
.56535 .19572 m .56686 .19231 L .56851 .19459 L 0 .028 .128 r
F
.56535 .19572 m .56369 .19346 L .56686 .19231 L F
.37852 .1953 m .37973 .192 L .38158 .19413 L 0 .028 .127 r
F
.37852 .1953 m .37667 .19314 L .37973 .192 L F
.28909 .19489 m .29015 .19156 L .2921 .19368 L 0 .027 .126 r
F
.28909 .19489 m .28714 .19278 L .29015 .19156 L F
.50469 .19647 m .5061 .19292 L .50782 .19518 L 0 .03 .13 r
F
.50469 .19647 m .50297 .1942 L .5061 .19292 L F
.66276 .19581 m .66441 .19235 L .66597 .19464 L 0 .029 .128 r
F
.66276 .19581 m .66119 .19352 L .66441 .19235 L F
.61804 .19561 m .61963 .19232 L .62123 .19436 L 0 .028 .128 r
F
.61804 .19561 m .61644 .19355 L .61963 .19232 L F
.46795 .19584 m .4693 .19234 L .47106 .19457 L 0 .029 .128 r
F
.46795 .19584 m .46619 .19361 L .4693 .19234 L F
.61007 .19606 m .61164 .19273 L .61325 .19479 L 0 .029 .129 r
F
.61007 .19606 m .60846 .194 L .61164 .19273 L F
.78409 .19453 m .78595 .19122 L .78738 .19342 L 0 .026 .126 r
F
.78409 .19453 m .78265 .19232 L .78595 .19122 L F
.62602 .19521 m .62763 .192 L .62922 .19405 L 0 .028 .127 r
F
.62602 .19521 m .62443 .19318 L .62763 .192 L F
.25235 .19434 m .25333 .19115 L .25533 .19319 L 0 .026 .125 r
F
.25235 .19434 m .25035 .19229 L .25333 .19115 L F
.29706 .19458 m .29813 .1913 L .30007 .1934 L 0 .027 .126 r
F
.29706 .19458 m .29511 .19249 L .29813 .1913 L F
.38649 .19503 m .3877 .1918 L .38955 .19388 L 0 .028 .127 r
F
.38649 .19503 m .38464 .19296 L .3877 .1918 L F
.73938 .19438 m .74117 .19108 L .74264 .19317 L 0 .026 .125 r
F
.73938 .19438 m .73791 .19228 L .74117 .19108 L F
.51266 .19616 m .51408 .19263 L .5158 .19488 L 0 .029 .129 r
F
.51266 .19616 m .51095 .1939 L .51408 .19263 L F
.60209 .19664 m .60366 .19324 L .60527 .19532 L 0 .03 .131 r
F
.60209 .19664 m .60048 .19456 L .60366 .19324 L F
.634 .19492 m .63562 .19159 L .6372 .19367 L 0 .027 .127 r
F
.634 .19492 m .63242 .19286 L .63562 .19159 L F
.26031 .19405 m .26131 .1909 L .26329 .19293 L 0 .026 .125 r
F
.26031 .19405 m .25832 .19204 L .26131 .1909 L F
.74736 .19407 m .74917 .19079 L .75063 .19289 L F
.74736 .19407 m .7459 .19197 L .74917 .19079 L F
.57333 .19562 m .57485 .19211 L .5765 .19439 L 0 .028 .128 r
F
.57333 .19562 m .57168 .19335 L .57485 .19211 L F
.67074 .19564 m .67241 .19212 L .67396 .19435 L F
.67074 .19564 m .66919 .19338 L .67241 .19212 L F
.34176 .19499 m .3429 .19185 L .34479 .19393 L 0 .028 .127 r
F
.34176 .19499 m .33987 .19291 L .3429 .19185 L F
.47592 .19566 m .47728 .19237 L .47903 .19462 L 0 .029 .129 r
F
.47592 .19566 m .47417 .19343 L .47728 .19237 L F
.43918 .19501 m .44047 .19185 L .44226 .19395 L 0 .028 .127 r
F
.43918 .19501 m .43738 .19292 L .44047 .19185 L F
.39446 .19481 m .39568 .19161 L .39752 .1937 L F
.39446 .19481 m .39261 .19274 L .39568 .19161 L F
.30502 .19438 m .3061 .19113 L .30803 .19324 L 0 .027 .126 r
F
.30502 .19438 m .30308 .19225 L .3061 .19113 L F
.64198 .19462 m .64361 .19128 L .64519 .19348 L F
.64198 .19462 m .6404 .19241 L .64361 .19128 L F
.52064 .19596 m .52207 .19266 L .52377 .19486 L 0 .03 .13 r
F
.52064 .19596 m .51893 .19377 L .52207 .19266 L F
.67873 .19535 m .68042 .19205 L .68196 .1942 L 0 .028 .128 r
F
.67873 .19535 m .67719 .19319 L .68042 .19205 L F
.75535 .19381 m .75717 .19056 L .75862 .19263 L 0 .026 .125 r
F
.75535 .19381 m .7539 .19173 L .75717 .19056 L F
.26826 .19393 m .26927 .19071 L .27125 .19284 L F
.26826 .19393 m .26628 .19181 L .26927 .19071 L F
.58131 .19549 m .58284 .1921 L .58449 .19437 L 0 .029 .129 r
F
.58131 .19549 m .57967 .19321 L .58284 .1921 L F
.34972 .19483 m .35088 .19146 L .35277 .1936 L 0 .028 .127 r
F
.34972 .19483 m .34784 .1927 L .35088 .19146 L F
.69469 .19464 m .6964 .19123 L .69792 .19339 L 0 .027 .127 r
F
.69469 .19464 m .69317 .1925 L .6964 .19123 L F
.68672 .19511 m .68841 .19169 L .68994 .19381 L 0 .028 .128 r
F
.68672 .19511 m .68519 .19302 L .68841 .19169 L F
.40242 .19469 m .40366 .19147 L .40549 .19359 L 0 .028 .127 r
F
.40242 .19469 m .40059 .19258 L .40366 .19147 L F
.70267 .19427 m .7044 .19092 L .70591 .19305 L 0 .027 .126 r
F
.70267 .19427 m .70116 .19216 L .7044 .19092 L F
.31297 .19431 m .31407 .19093 L .31599 .19312 L F
.31297 .19431 m .31105 .1921 L .31407 .19093 L F
.35769 .19454 m .35887 .19116 L .36074 .19334 L 0 .027 .127 r
F
.35769 .19454 m .35582 .19238 L .35887 .19116 L F
.52861 .19587 m .53006 .19258 L .53176 .19474 L 0 .03 .13 r
F
.52861 .19587 m .52692 .19373 L .53006 .19258 L F
.76336 .19374 m .76519 .19042 L .76664 .19264 L 0 .026 .125 r
F
.76336 .19374 m .7619 .19152 L .76519 .19042 L F
.64998 .19463 m .65162 .1913 L .65319 .19353 L 0 .028 .127 r
F
.64998 .19463 m .6484 .19239 L .65162 .1913 L F
.48389 .19577 m .48526 .19252 L .487 .19472 L 0 .03 .13 r
F
.48389 .19577 m .48214 .19358 L .48526 .19252 L F
.71066 .19403 m .7124 .19074 L .71391 .19289 L 0 .027 .126 r
F
.71066 .19403 m .70915 .19189 L .7124 .19074 L F
.44714 .19514 m .44845 .19183 L .45023 .19409 L 0 .029 .128 r
F
.44714 .19514 m .44536 .19289 L .44845 .19183 L F
.32093 .19411 m .32204 .19076 L .32395 .19293 L 0 .027 .126 r
F
.32093 .19411 m .31901 .19193 L .32204 .19076 L F
.36566 .19433 m .36684 .19101 L .36871 .19321 L 0 .027 .127 r
F
.36566 .19433 m .36379 .19214 L .36684 .19101 L F
.5893 .19555 m .59084 .19215 L .59248 .19445 L 0 .03 .13 r
F
.5893 .19555 m .58766 .19325 L .59084 .19215 L F
.27619 .194 m .27723 .1907 L .27918 .19293 L 0 .027 .126 r
F
.27619 .194 m .27423 .19177 L .27723 .1907 L F
.53659 .19581 m .53805 .19237 L .53974 .19456 L 0 .03 .13 r
F
.53659 .19581 m .5349 .19362 L .53805 .19237 L F
.54457 .19538 m .54604 .19202 L .54772 .19412 L 0 .029 .129 r
F
.54457 .19538 m .54289 .19328 L .54604 .19202 L F
.55255 .19496 m .55404 .19173 L .55571 .19375 L F
.55255 .19496 m .55088 .19293 L .55404 .19173 L F
.41038 .19476 m .41164 .19124 L .41346 .19353 L 0 .028 .128 r
F
.41038 .19476 m .40856 .19246 L .41164 .19124 L F
.71866 .19389 m .72041 .19048 L .7219 .19266 L 0 .027 .126 r
F
.71866 .19389 m .71716 .19172 L .72041 .19048 L F
.56053 .19461 m .56203 .19138 L .56369 .19346 L 0 .028 .128 r
F
.56053 .19461 m .55887 .19256 L .56203 .19138 L F
.77137 .19373 m .7732 .1903 L .77465 .1925 L 0 .026 .125 r
F
.77137 .19373 m .76992 .19151 L .7732 .1903 L F
.72664 .19353 m .72842 .19031 L .7299 .19239 L F
.72664 .19353 m .72516 .19143 L .72842 .19031 L F
.65797 .19464 m .65963 .1913 L .66119 .19352 L 0 .028 .128 r
F
.65797 .19464 m .65641 .19242 L .65963 .1913 L F
.32889 .19399 m .33 .19077 L .33191 .19293 L 0 .027 .126 r
F
.32889 .19399 m .32698 .19185 L .33 .19077 L F
.49186 .19579 m .49325 .19255 L .49498 .19466 L 0 .031 .131 r
F
.49186 .19579 m .49012 .19367 L .49325 .19255 L F
.4551 .19515 m .45644 .19161 L .45821 .19388 L 0 .029 .129 r
F
.4551 .19515 m .45333 .19287 L .45644 .19161 L F
.37362 .19428 m .37481 .19098 L .37667 .19314 L 0 .028 .127 r
F
.37362 .19428 m .37176 .19209 L .37481 .19098 L F
.41835 .19455 m .41962 .19106 L .42143 .19331 L F
.41835 .19455 m .41654 .19229 L .41962 .19106 L F
.77937 .19347 m .78122 .19013 L .78265 .19232 L 0 .026 .125 r
F
.77937 .19347 m .77793 .19127 L .78122 .19013 L F
.49984 .19549 m .50124 .1921 L .50297 .1942 L 0 .03 .13 r
F
.49984 .19549 m .49811 .19338 L .50124 .1921 L F
.46308 .19487 m .46443 .19136 L .46619 .19361 L 0 .029 .128 r
F
.46308 .19487 m .46132 .19262 L .46443 .19136 L F
.28413 .194 m .2852 .19054 L .28714 .19278 L 0 .027 .126 r
F
.28413 .194 m .28219 .19176 L .2852 .19054 L F
.42632 .19423 m .42761 .19083 L .42941 .19298 L 0 .028 .127 r
F
.42632 .19423 m .42452 .19207 L .42761 .19083 L F
.73464 .19338 m .73643 .19021 L .73791 .19228 L 0 .026 .126 r
F
.73464 .19338 m .73316 .19131 L .73643 .19021 L F
.50782 .19518 m .50923 .19165 L .51095 .1939 L 0 .029 .129 r
F
.50782 .19518 m .5061 .19292 L .50923 .19165 L F
.2921 .19368 m .29317 .19036 L .29511 .19249 L 0 .027 .126 r
F
.2921 .19368 m .29015 .19156 L .29317 .19036 L F
.59729 .19567 m .59885 .19226 L .60048 .19456 L 0 .03 .131 r
F
.59729 .19567 m .59566 .19337 L .59885 .19226 L F
.61325 .19479 m .61484 .1915 L .61644 .19355 L 0 .029 .129 r
F
.61325 .19479 m .61164 .19273 L .61484 .1915 L F
.38158 .19413 m .38279 .19085 L .38464 .19296 L 0 .028 .127 r
F
.38158 .19413 m .37973 .192 L .38279 .19085 L F
.47106 .19457 m .47241 .19118 L .47417 .19343 L 0 .028 .128 r
F
.47106 .19457 m .4693 .19234 L .47241 .19118 L F
.62123 .19436 m .62283 .19111 L .62443 .19318 L F
.62123 .19436 m .61963 .19232 L .62283 .19111 L F
.56851 .19459 m .57002 .19107 L .57168 .19335 L F
.56851 .19459 m .56686 .19231 L .57002 .19107 L F
.33684 .19396 m .33796 .19081 L .33987 .19291 L 0 .028 .127 r
F
.33684 .19396 m .33494 .19187 L .33796 .19081 L F
.66597 .19464 m .66763 .19111 L .66919 .19338 L 0 .028 .128 r
F
.66597 .19464 m .66441 .19235 L .66763 .19111 L F
.4343 .19399 m .43559 .19083 L .43738 .19292 L 0 .028 .127 r
F
.4343 .19399 m .4325 .19191 L .43559 .19083 L F
.5158 .19488 m .51722 .19152 L .51893 .19377 L 0 .029 .129 r
F
.5158 .19488 m .51408 .19263 L .51722 .19152 L F
.60527 .19532 m .60684 .19191 L .60846 .194 L 0 .03 .13 r
F
.60527 .19532 m .60366 .19324 L .60684 .19191 L F
.62922 .19405 m .63083 .19079 L .63242 .19286 L 0 .028 .127 r
F
.62922 .19405 m .62763 .192 L .63083 .19079 L F
.74264 .19317 m .74443 .18987 L .7459 .19197 L 0 .026 .125 r
F
.74264 .19317 m .74117 .19108 L .74443 .18987 L F
.30007 .1934 m .30114 .19015 L .30308 .19225 L 0 .027 .126 r
F
.30007 .1934 m .29813 .1913 L .30114 .19015 L F
.25533 .19319 m .25632 .19002 L .25832 .19204 L 0 .026 .125 r
F
.25533 .19319 m .25333 .19115 L .25632 .19002 L F
.78738 .19342 m .78925 .19011 L .79068 .1923 L 0 .027 .126 r
F
.78738 .19342 m .78595 .19122 L .78925 .19011 L F
.38955 .19388 m .39077 .19065 L .39261 .19274 L 0 .028 .127 r
F
.38955 .19388 m .3877 .1918 L .39077 .19065 L F
.6372 .19367 m .63882 .19032 L .6404 .19241 L 0 .027 .126 r
F
.6372 .19367 m .63562 .19159 L .63882 .19032 L F
.67396 .19435 m .67564 .19097 L .67719 .19319 L 0 .028 .128 r
F
.67396 .19435 m .67241 .19212 L .67564 .19097 L F
.5765 .19439 m .57802 .19093 L .57967 .19321 L F
.5765 .19439 m .57485 .19211 L .57802 .19093 L F
.75063 .19289 m .75244 .18964 L .7539 .19173 L 0 .026 .125 r
F
.75063 .19289 m .74917 .19079 L .75244 .18964 L F
.26329 .19293 m .2643 .18976 L .26628 .19181 L F
.26329 .19293 m .26131 .1909 L .2643 .18976 L F
.30803 .19324 m .30912 .19001 L .31105 .1921 L 0 .027 .126 r
F
.30803 .19324 m .3061 .19113 L .30912 .19001 L F
.64519 .19348 m .64683 .19019 L .6484 .19239 L F
.64519 .19348 m .64361 .19128 L .64683 .19019 L F
.39752 .1937 m .39875 .19048 L .40059 .19258 L 0 .028 .127 r
F
.39752 .1937 m .39568 .19161 L .39875 .19048 L F
.34479 .19393 m .34594 .19061 L .34784 .1927 L F
.34479 .19393 m .3429 .19185 L .34594 .19061 L F
.44226 .19395 m .44357 .19077 L .44536 .19289 L 0 .028 .128 r
F
.44226 .19395 m .44047 .19185 L .44357 .19077 L F
.47903 .19462 m .4804 .19131 L .48214 .19358 L 0 .029 .129 r
F
.47903 .19462 m .47728 .19237 L .4804 .19131 L F
.75862 .19263 m .76045 .18944 L .7619 .19152 L 0 .026 .125 r
F
.75862 .19263 m .75717 .19056 L .76045 .18944 L F
.52377 .19486 m .52521 .19152 L .52692 .19373 L 0 .03 .13 r
F
.52377 .19486 m .52207 .19266 L .52521 .19152 L F
.68196 .1942 m .68365 .19088 L .68519 .19302 L 0 .028 .128 r
F
.68196 .1942 m .68042 .19205 L .68365 .19088 L F
.68994 .19381 m .69164 .19035 L .69317 .1925 L 0 .028 .127 r
F
.68994 .19381 m .68841 .19169 L .69164 .19035 L F
.35277 .1936 m .35393 .19022 L .35582 .19238 L 0 .027 .127 r
F
.35277 .1936 m .35088 .19146 L .35393 .19022 L F
.69792 .19339 m .69964 .18999 L .70116 .19216 L 0 .027 .126 r
F
.69792 .19339 m .6964 .19123 L .69964 .18999 L F
.58449 .19437 m .58602 .19099 L .58766 .19325 L 0 .029 .129 r
F
.58449 .19437 m .58284 .1921 L .58602 .19099 L F
.70591 .19305 m .70765 .18974 L .70915 .19189 L 0 .027 .126 r
F
.70591 .19305 m .7044 .19092 L .70765 .18974 L F
.27125 .19284 m .27227 .18963 L .27423 .19177 L 0 .026 .125 r
F
.27125 .19284 m .26927 .19071 L .27227 .18963 L F
.36074 .19334 m .36192 .18994 L .36379 .19214 L 0 .027 .126 r
F
.36074 .19334 m .35887 .19116 L .36192 .18994 L F
.31599 .19312 m .3171 .18976 L .31901 .19193 L F
.31599 .19312 m .31407 .19093 L .3171 .18976 L F
.40549 .19359 m .40673 .19033 L .40856 .19246 L 0 .028 .127 r
F
.40549 .19359 m .40366 .19147 L .40673 .19033 L F
.53176 .19474 m .53321 .19143 L .5349 .19362 L 0 .03 .13 r
F
.53176 .19474 m .53006 .19258 L .53321 .19143 L F
.76664 .19264 m .76847 .1893 L .76992 .19151 L 0 .026 .125 r
F
.76664 .19264 m .76519 .19042 L .76847 .1893 L F
.65319 .19353 m .65484 .19019 L .65641 .19242 L 0 .028 .127 r
F
.65319 .19353 m .65162 .1913 L .65484 .19019 L F
.71391 .19289 m .71566 .18954 L .71716 .19172 L 0 .027 .126 r
F
.71391 .19289 m .7124 .19074 L .71566 .18954 L F
.32395 .19293 m .32507 .18966 L .32698 .19185 L F
.32395 .19293 m .32204 .19076 L .32507 .18966 L F
.487 .19472 m .48838 .19147 L .49012 .19367 L 0 .03 .13 r
F
.487 .19472 m .48526 .19252 L .48838 .19147 L F
.45023 .19409 m .45156 .19062 L .45333 .19287 L 0 .029 .129 r
F
.45023 .19409 m .44845 .19183 L .45156 .19062 L F
.36871 .19321 m .36989 .18991 L .37176 .19209 L 0 .027 .127 r
F
.36871 .19321 m .36684 .19101 L .36989 .18991 L F
.53974 .19456 m .5412 .1911 L .54289 .19328 L 0 .03 .13 r
F
.53974 .19456 m .53805 .19237 L .5412 .1911 L F
.54772 .19412 m .5492 .19085 L .55088 .19293 L 0 .029 .129 r
F
.54772 .19412 m .54604 .19202 L .5492 .19085 L F
.41346 .19353 m .41472 .19002 L .41654 .19229 L 0 .028 .127 r
F
.41346 .19353 m .41164 .19124 L .41472 .19002 L F
.55571 .19375 m .5572 .19053 L .55887 .19256 L 0 .029 .128 r
F
.55571 .19375 m .55404 .19173 L .5572 .19053 L F
.7219 .19266 m .72366 .18924 L .72516 .19143 L 0 .026 .125 r
F
.7219 .19266 m .72041 .19048 L .72366 .18924 L F
.59248 .19445 m .59403 .19106 L .59566 .19337 L 0 .03 .13 r
F
.59248 .19445 m .59084 .19215 L .59403 .19106 L F
.27918 .19293 m .28023 .18952 L .28219 .19176 L 0 .027 .126 r
F
.27918 .19293 m .27723 .1907 L .28023 .18952 L F
.77465 .1925 m .77649 .18908 L .77793 .19127 L 0 .026 .125 r
F
.77465 .1925 m .7732 .1903 L .77649 .18908 L F
.45821 .19388 m .45955 .19035 L .46132 .19262 L 0 .029 .128 r
F
.45821 .19388 m .45644 .19161 L .45955 .19035 L F
.56369 .19346 m .5652 .1902 L .56686 .19231 L 0 .028 .128 r
F
.56369 .19346 m .56203 .19138 L .5652 .1902 L F
.7299 .19239 m .73168 .18923 L .73316 .19131 L 0 .026 .126 r
F
.7299 .19239 m .72842 .19031 L .73168 .18923 L F
.66119 .19352 m .66285 .19015 L .66441 .19235 L 0 .028 .128 r
F
.66119 .19352 m .65963 .1913 L .66285 .19015 L F
.42143 .19331 m .42271 .18983 L .42452 .19207 L 0 .028 .127 r
F
.42143 .19331 m .41962 .19106 L .42271 .18983 L F
.50297 .1942 m .50437 .19085 L .5061 .19292 L 0 .03 .13 r
F
.50297 .1942 m .50124 .1921 L .50437 .19085 L F
.49498 .19466 m .49638 .19128 L .49811 .19338 L 0 .03 .131 r
F
.49498 .19466 m .49325 .19255 L .49638 .19128 L F
.37667 .19314 m .37787 .18986 L .37973 .192 L 0 .028 .127 r
F
.37667 .19314 m .37481 .19098 L .37787 .18986 L F
.33191 .19293 m .33303 .1897 L .33494 .19187 L 0 .027 .127 r
F
.33191 .19293 m .33 .19077 L .33303 .1897 L F
.46619 .19361 m .46754 .1901 L .4693 .19234 L 0 .028 .128 r
F
.46619 .19361 m .46443 .19136 L .46754 .1901 L F
.78265 .19232 m .78452 .18905 L .78595 .19122 L 0 .026 .125 r
F
.78265 .19232 m .78122 .19013 L .78452 .18905 L F
.42941 .19298 m .4307 .18973 L .4325 .19191 L 0 .028 .127 r
F
.42941 .19298 m .42761 .19083 L .4307 .18973 L F
.28714 .19278 m .28821 .18931 L .29015 .19156 L 0 .027 .126 r
F
.28714 .19278 m .2852 .19054 L .28821 .18931 L F
.51095 .1939 m .51237 .19039 L .51408 .19263 L 0 .029 .129 r
F
.51095 .1939 m .50923 .19165 L .51237 .19039 L F
.61644 .19355 m .61803 .19026 L .61963 .19232 L F
.61644 .19355 m .61484 .1915 L .61803 .19026 L F
.60846 .194 m .61003 .19064 L .61164 .19273 L F
.60846 .194 m .60684 .19191 L .61003 .19064 L F
.57168 .19335 m .57319 .18983 L .57485 .19211 L 0 .028 .128 r
F
.57168 .19335 m .57002 .19107 L .57319 .18983 L F
.29511 .19249 m .29619 .18916 L .29813 .1913 L 0 .027 .126 r
F
.29511 .19249 m .29317 .19036 L .29619 .18916 L F
.66919 .19338 m .67086 .18988 L .67241 .19212 L 0 .028 .128 r
F
.66919 .19338 m .66763 .19111 L .67086 .18988 L F
.73791 .19228 m .7397 .189 L .74117 .19108 L 0 .026 .126 r
F
.73791 .19228 m .73643 .19021 L .7397 .189 L F
.62443 .19318 m .62603 .1899 L .62763 .192 L 0 .028 .128 r
F
.62443 .19318 m .62283 .19111 L .62603 .1899 L F
.38464 .19296 m .38585 .18969 L .3877 .1918 L 0 .028 .127 r
F
.38464 .19296 m .38279 .19085 L .38585 .18969 L F
.47417 .19343 m .47553 .19011 L .47728 .19237 L 0 .029 .128 r
F
.47417 .19343 m .47241 .19118 L .47553 .19011 L F
.60048 .19456 m .60203 .19095 L .60366 .19324 L 0 .03 .131 r
F
.60048 .19456 m .59885 .19226 L .60203 .19095 L F
.7459 .19197 m .7477 .18869 L .74917 .19079 L 0 .026 .125 r
F
.7459 .19197 m .74443 .18987 L .7477 .18869 L F
.63242 .19286 m .63403 .1895 L .63562 .19159 L 0 .028 .127 r
F
.63242 .19286 m .63083 .19079 L .63403 .1895 L F
.6404 .19241 m .64203 .18917 L .64361 .19128 L 0 .027 .126 r
F
.6404 .19241 m .63882 .19032 L .64203 .18917 L F
.51893 .19377 m .52036 .19042 L .52207 .19266 L 0 .029 .129 r
F
.51893 .19377 m .51722 .19152 L .52036 .19042 L F
.33987 .19291 m .341 .18976 L .3429 .19185 L 0 .028 .128 r
F
.33987 .19291 m .33796 .19081 L .341 .18976 L F
.30308 .19225 m .30416 .18904 L .3061 .19113 L 0 .027 .126 r
F
.30308 .19225 m .30114 .19015 L .30416 .18904 L F
.43738 .19292 m .43868 .18974 L .44047 .19185 L 0 .028 .128 r
F
.43738 .19292 m .43559 .19083 L .43868 .18974 L F
.25832 .19204 m .25931 .18886 L .26131 .1909 L 0 .026 .126 r
F
.25832 .19204 m .25632 .19002 L .25931 .18886 L F
.67719 .19319 m .67887 .18985 L .68042 .19205 L 0 .028 .128 r
F
.67719 .19319 m .67564 .19097 L .67887 .18985 L F
.39261 .19274 m .39384 .1895 L .39568 .19161 L 0 .028 .127 r
F
.39261 .19274 m .39077 .19065 L .39384 .1895 L F
.57967 .19321 m .5812 .18985 L .58284 .1921 L 0 .028 .128 r
F
.57967 .19321 m .57802 .19093 L .5812 .18985 L F
.7539 .19173 m .75572 .18849 L .75717 .19056 L 0 .026 .125 r
F
.7539 .19173 m .75244 .18964 L .75572 .18849 L F
.34784 .1927 m .34899 .18937 L .35088 .19146 L 0 .028 .127 r
F
.34784 .1927 m .34594 .19061 L .34899 .18937 L F
.26628 .19181 m .26729 .18863 L .26927 .19071 L 0 .026 .125 r
F
.26628 .19181 m .2643 .18976 L .26729 .18863 L F
.69317 .1925 m .69488 .18906 L .6964 .19123 L 0 .027 .126 r
F
.69317 .1925 m .69164 .19035 L .69488 .18906 L F
.31105 .1921 m .31214 .18885 L .31407 .19093 L F
.31105 .1921 m .30912 .19001 L .31214 .18885 L F
.68519 .19302 m .68688 .18954 L .68841 .19169 L 0 .028 .128 r
F
.68519 .19302 m .68365 .19088 L .68688 .18954 L F
.40059 .19258 m .40183 .18934 L .40366 .19147 L 0 .028 .127 r
F
.40059 .19258 m .39875 .19048 L .40183 .18934 L F
.35582 .19238 m .35699 .18899 L .35887 .19116 L 0 .027 .126 r
F
.35582 .19238 m .35393 .19022 L .35699 .18899 L F
.70116 .19216 m .70288 .18874 L .7044 .19092 L F
.70116 .19216 m .69964 .18999 L .70288 .18874 L F
.6484 .19239 m .65005 .18911 L .65162 .1913 L 0 .027 .127 r
F
.6484 .19239 m .64683 .19019 L .65005 .18911 L F
.52692 .19373 m .52836 .19036 L .53006 .19258 L 0 .03 .13 r
F
.52692 .19373 m .52521 .19152 L .52836 .19036 L F
.7619 .19152 m .76374 .18833 L .76519 .19042 L 0 .026 .125 r
F
.7619 .19152 m .76045 .18944 L .76374 .18833 L F
.44536 .19289 m .44667 .1897 L .44845 .19183 L 0 .029 .128 r
F
.44536 .19289 m .44357 .19077 L .44667 .1897 L F
.48214 .19358 m .48352 .19023 L .48526 .19252 L 0 .03 .13 r
F
.48214 .19358 m .4804 .19131 L .48352 .19023 L F
.70915 .19189 m .7109 .18856 L .7124 .19074 L 0 .027 .126 r
F
.70915 .19189 m .70765 .18974 L .7109 .18856 L F
.36379 .19214 m .36497 .18882 L .36684 .19101 L F
.36379 .19214 m .36192 .18994 L .36497 .18882 L F
.58766 .19325 m .58921 .1899 L .59084 .19215 L 0 .029 .129 r
F
.58766 .19325 m .58602 .19099 L .58921 .1899 L F
.31901 .19193 m .32012 .18859 L .32204 .19076 L 0 .027 .126 r
F
.31901 .19193 m .3171 .18976 L .32012 .18859 L F
.27423 .19177 m .27526 .18855 L .27723 .1907 L F
.27423 .19177 m .27227 .18963 L .27526 .18855 L F
.40856 .19246 m .40982 .18912 L .41164 .19124 L 0 .028 .127 r
F
.40856 .19246 m .40673 .19033 L .40982 .18912 L F
.5349 .19362 m .53636 .19018 L .53805 .19237 L 0 .03 .13 r
F
.5349 .19362 m .53321 .19143 L .53636 .19018 L F
.71716 .19172 m .71891 .18828 L .72041 .19048 L 0 .026 .126 r
F
.71716 .19172 m .71566 .18954 L .71891 .18828 L F
.54289 .19328 m .54436 .18984 L .54604 .19202 L 0 .029 .129 r
F
.54289 .19328 m .5412 .1911 L .54436 .18984 L F
.76992 .19151 m .77176 .18809 L .7732 .1903 L 0 .026 .125 r
F
.76992 .19151 m .76847 .1893 L .77176 .18809 L F
.65641 .19242 m .65806 .18908 L .65963 .1913 L 0 .028 .127 r
F
.65641 .19242 m .65484 .19019 L .65806 .18908 L F
.45333 .19287 m .45466 .18936 L .45644 .19161 L 0 .028 .128 r
F
.45333 .19287 m .45156 .19062 L .45466 .18936 L F
.55088 .19293 m .55236 .18967 L .55404 .19173 L 0 .029 .129 r
F
.55088 .19293 m .5492 .19085 L .55236 .18967 L F
.41654 .19229 m .41781 .1888 L .41962 .19106 L 0 .028 .127 r
F
.41654 .19229 m .41472 .19002 L .41781 .1888 L F
.32698 .19185 m .3281 .18855 L .33 .19077 L 0 .027 .126 r
F
.32698 .19185 m .32507 .18966 L .3281 .18855 L F
.37176 .19209 m .37295 .18881 L .37481 .19098 L 0 .028 .127 r
F
.37176 .19209 m .36989 .18991 L .37295 .18881 L F
.72516 .19143 m .72692 .18811 L .72842 .19031 L 0 .026 .125 r
F
.72516 .19143 m .72366 .18924 L .72692 .18811 L F
.55887 .19256 m .56036 .18932 L .56203 .19138 L 0 .029 .128 r
F
.55887 .19256 m .5572 .19053 L .56036 .18932 L F
.49012 .19367 m .49151 .19035 L .49325 .19255 L 0 .03 .131 r
F
.49012 .19367 m .48838 .19147 L .49151 .19035 L F
.77793 .19127 m .77978 .18795 L .78122 .19013 L 0 .026 .125 r
F
.77793 .19127 m .77649 .18908 L .77978 .18795 L F
.46132 .19262 m .46266 .1891 L .46443 .19136 L 0 .028 .128 r
F
.46132 .19262 m .45955 .19035 L .46266 .1891 L F
.28219 .19176 m .28325 .18829 L .2852 .19054 L 0 .027 .126 r
F
.28219 .19176 m .28023 .18952 L .28325 .18829 L F
.5061 .19292 m .50751 .1896 L .50923 .19165 L 0 .029 .129 r
F
.5061 .19292 m .50437 .19085 L .50751 .1896 L F
.59566 .19337 m .59722 .18995 L .59885 .19226 L 0 .03 .13 r
F
.59566 .19337 m .59403 .19106 L .59722 .18995 L F
.49811 .19338 m .49951 .19001 L .50124 .1921 L F
.49811 .19338 m .49638 .19128 L .49951 .19001 L F
.42452 .19207 m .4258 .1886 L .42761 .19083 L 0 .027 .127 r
F
.42452 .19207 m .42271 .18983 L .4258 .1886 L F
.56686 .19231 m .56837 .18894 L .57002 .19107 L 0 .028 .128 r
F
.56686 .19231 m .5652 .1902 L .56837 .18894 L F
.4693 .19234 m .47065 .18894 L .47241 .19118 L F
.4693 .19234 m .46754 .1901 L .47065 .18894 L F
.66441 .19235 m .66608 .18894 L .66763 .19111 L F
.66441 .19235 m .66285 .19015 L .66608 .18894 L F
.51408 .19263 m .51551 .18928 L .51722 .19152 L 0 .029 .129 r
F
.51408 .19263 m .51237 .19039 L .51551 .18928 L F
.73316 .19131 m .73496 .18813 L .73643 .19021 L 0 .027 .126 r
F
.73316 .19131 m .73168 .18923 L .73496 .18813 L F
.37973 .192 m .38093 .18873 L .38279 .19085 L 0 .028 .127 r
F
.37973 .192 m .37787 .18986 L .38093 .18873 L F
.29015 .19156 m .29123 .1881 L .29317 .19036 L 0 .027 .126 r
F
.29015 .19156 m .28821 .18931 L .29123 .1881 L F
.61164 .19273 m .61323 .18942 L .61484 .1915 L 0 .029 .129 r
F
.61164 .19273 m .61003 .19064 L .61323 .18942 L F
.33494 .19187 m .33606 .18864 L .33796 .19081 L 0 .028 .127 r
F
.33494 .19187 m .33303 .1897 L .33606 .18864 L F
.61963 .19232 m .62123 .18902 L .62283 .19111 L 0 .029 .128 r
F
.61963 .19232 m .61803 .19026 L .62123 .18902 L F
.78595 .19122 m .78782 .18796 L .78925 .19011 L 0 .026 .126 r
F
.78595 .19122 m .78452 .18905 L .78782 .18796 L F
.57485 .19211 m .57637 .18865 L .57802 .19093 L 0 .028 .127 r
F
.57485 .19211 m .57319 .18983 L .57637 .18865 L F
.67241 .19212 m .67409 .18875 L .67564 .19097 L 0 .028 .128 r
F
.67241 .19212 m .67086 .18988 L .67409 .18875 L F
.4325 .19191 m .43379 .18864 L .43559 .19083 L 0 .028 .127 r
F
.4325 .19191 m .4307 .18973 L .43379 .18864 L F
.60366 .19324 m .60522 .18964 L .60684 .19191 L 0 .03 .13 r
F
.60366 .19324 m .60203 .19095 L .60522 .18964 L F
.74117 .19108 m .74296 .18778 L .74443 .18987 L 0 .026 .125 r
F
.74117 .19108 m .7397 .189 L .74296 .18778 L F
.29813 .1913 m .2992 .188 L .30114 .19015 L 0 .027 .126 r
F
.29813 .1913 m .29619 .18916 L .2992 .188 L F
.62763 .192 m .62924 .18866 L .63083 .19079 L 0 .028 .128 r
F
.62763 .192 m .62603 .1899 L .62924 .18866 L F
.3877 .1918 m .38892 .18851 L .39077 .19065 L 0 .028 .127 r
F
.3877 .1918 m .38585 .18969 L .38892 .18851 L F
.63562 .19159 m .63724 .18822 L .63882 .19032 L 0 .027 .127 r
F
.63562 .19159 m .63403 .1895 L .63724 .18822 L F
.74917 .19079 m .75098 .18754 L .75244 .18964 L 0 .026 .125 r
F
.74917 .19079 m .7477 .18869 L .75098 .18754 L F
.47728 .19237 m .47865 .18904 L .4804 .19131 L 0 .029 .129 r
F
.47728 .19237 m .47553 .19011 L .47865 .18904 L F
.64361 .19128 m .64525 .18808 L .64683 .19019 L 0 .027 .126 r
F
.64361 .19128 m .64203 .18917 L .64525 .18808 L F
.52207 .19266 m .52351 .18928 L .52521 .19152 L 0 .029 .129 r
F
.52207 .19266 m .52036 .19042 L .52351 .18928 L F
.26131 .1909 m .26231 .18769 L .2643 .18976 L 0 .026 .126 r
F
.26131 .1909 m .25931 .18886 L .26231 .18769 L F
.3061 .19113 m .30718 .18793 L .30912 .19001 L 0 .027 .126 r
F
.3061 .19113 m .30416 .18904 L .30718 .18793 L F
.68042 .19205 m .68211 .18869 L .68365 .19088 L 0 .028 .128 r
F
.68042 .19205 m .67887 .18985 L .68211 .18869 L F
.39568 .19161 m .39691 .18834 L .39875 .19048 L 0 .028 .127 r
F
.39568 .19161 m .39384 .1895 L .39691 .18834 L F
.3429 .19185 m .34405 .18852 L .34594 .19061 L 0 .028 .128 r
F
.3429 .19185 m .341 .18976 L .34405 .18852 L F
.44047 .19185 m .44178 .18865 L .44357 .19077 L F
.44047 .19185 m .43868 .18974 L .44178 .18865 L F
.58284 .1921 m .58438 .18876 L .58602 .19099 L 0 .029 .128 r
F
.58284 .1921 m .5812 .18985 L .58438 .18876 L F
.75717 .19056 m .759 .18736 L .76045 .18944 L 0 .026 .125 r
F
.75717 .19056 m .75572 .18849 L .759 .18736 L F
.6964 .19123 m .69812 .18781 L .69964 .18999 L 0 .027 .126 r
F
.6964 .19123 m .69488 .18906 L .69812 .18781 L F
.35088 .19146 m .35205 .18812 L .35393 .19022 L 0 .027 .127 r
F
.35088 .19146 m .34899 .18937 L .35205 .18812 L F
.68841 .19169 m .69011 .1882 L .69164 .19035 L 0 .028 .127 r
F
.68841 .19169 m .68688 .18954 L .69011 .1882 L F
.7044 .19092 m .70613 .18754 L .70765 .18974 L 0 .027 .126 r
F
.7044 .19092 m .70288 .18874 L .70613 .18754 L F
.26927 .19071 m .27029 .18754 L .27227 .18963 L 0 .026 .126 r
F
.26927 .19071 m .26729 .18863 L .27029 .18754 L F
.31407 .19093 m .31517 .18769 L .3171 .18976 L 0 .027 .126 r
F
.31407 .19093 m .31214 .18885 L .31517 .18769 L F
.35887 .19116 m .36004 .18775 L .36192 .18994 L F
.35887 .19116 m .35699 .18899 L .36004 .18775 L F
.40366 .19147 m .4049 .1882 L .40673 .19033 L 0 .028 .127 r
F
.40366 .19147 m .40183 .18934 L .4049 .1882 L F
.53006 .19258 m .53151 .18919 L .53321 .19143 L 0 .03 .13 r
F
.53006 .19258 m .52836 .19036 L .53151 .18919 L F
.65162 .1913 m .65327 .18799 L .65484 .19019 L 0 .028 .127 r
F
.65162 .1913 m .65005 .18911 L .65327 .18799 L F
.76519 .19042 m .76703 .18719 L .76847 .1893 L 0 .026 .125 r
F
.76519 .19042 m .76374 .18833 L .76703 .18719 L F
.44845 .19183 m .44977 .18849 L .45156 .19062 L 0 .029 .128 r
F
.44845 .19183 m .44667 .1897 L .44977 .18849 L F
.7124 .19074 m .71415 .18735 L .71566 .18954 L 0 .026 .126 r
F
.7124 .19074 m .7109 .18856 L .71415 .18735 L F
.48526 .19252 m .48664 .18915 L .48838 .19147 L 0 .03 .13 r
F
.48526 .19252 m .48352 .19023 L .48664 .18915 L F
.32204 .19076 m .32315 .18746 L .32507 .18966 L 0 .027 .126 r
F
.32204 .19076 m .32012 .18859 L .32315 .18746 L F
.36684 .19101 m .36803 .18773 L .36989 .18991 L 0 .027 .127 r
F
.36684 .19101 m .36497 .18882 L .36803 .18773 L F
.41164 .19124 m .4129 .18792 L .41472 .19002 L 0 .028 .127 r
F
.41164 .19124 m .40982 .18912 L .4129 .18792 L F
.53805 .19237 m .53952 .18891 L .5412 .1911 L 0 .03 .13 r
F
.53805 .19237 m .53636 .19018 L .53952 .18891 L F
.59084 .19215 m .59239 .18881 L .59403 .19106 L 0 .029 .129 r
F
.59084 .19215 m .58921 .1899 L .59239 .18881 L F
.54604 .19202 m .54752 .18866 L .5492 .19085 L F
.54604 .19202 m .54436 .18984 L .54752 .18866 L F
.27723 .1907 m .27827 .18737 L .28023 .18952 L 0 .027 .126 r
F
.27723 .1907 m .27526 .18855 L .27827 .18737 L F
.72041 .19048 m .72216 .18702 L .72366 .18924 L 0 .026 .125 r
F
.72041 .19048 m .71891 .18828 L .72216 .18702 L F
.45644 .19161 m .45777 .18811 L .45955 .19035 L 0 .028 .128 r
F
.45644 .19161 m .45466 .18936 L .45777 .18811 L F
.7732 .1903 m .77504 .18688 L .77649 .18908 L 0 .026 .125 r
F
.7732 .1903 m .77176 .18809 L .77504 .18688 L F
.41962 .19106 m .4209 .18759 L .42271 .18983 L 0 .027 .127 r
F
.41962 .19106 m .41781 .1888 L .4209 .18759 L F
.55404 .19173 m .55553 .18845 L .5572 .19053 L 0 .029 .129 r
F
.55404 .19173 m .55236 .18967 L .55553 .18845 L F
.65963 .1913 m .66129 .18794 L .66285 .19015 L 0 .028 .128 r
F
.65963 .1913 m .65806 .18908 L .66129 .18794 L F
.46443 .19136 m .46577 .18786 L .46754 .1901 L F
.46443 .19136 m .46266 .1891 L .46577 .18786 L F
.56203 .19138 m .56353 .18811 L .5652 .1902 L F
.56203 .19138 m .56036 .18932 L .56353 .18811 L F
.72842 .19031 m .73019 .18701 L .73168 .18923 L 0 .026 .125 r
F
.72842 .19031 m .72692 .18811 L .73019 .18701 L F
.37481 .19098 m .37601 .1877 L .37787 .18986 L 0 .028 .127 r
F
.37481 .19098 m .37295 .18881 L .37601 .1877 L F
.2852 .19054 m .28626 .18706 L .28821 .18931 L 0 .027 .126 r
F
.2852 .19054 m .28325 .18829 L .28626 .18706 L F
.50923 .19165 m .51065 .18836 L .51237 .19039 L 0 .029 .129 r
F
.50923 .19165 m .50751 .1896 L .51065 .18836 L F
.33 .19077 m .33113 .18746 L .33303 .1897 L 0 .027 .127 r
F
.33 .19077 m .3281 .18855 L .33113 .18746 L F
.50124 .1921 m .50264 .18877 L .50437 .19085 L 0 .03 .13 r
F
.50124 .1921 m .49951 .19001 L .50264 .18877 L F
.49325 .19255 m .49464 .18909 L .49638 .19128 L 0 .03 .131 r
F
.49325 .19255 m .49151 .19035 L .49464 .18909 L F
.78122 .19013 m .78309 .18689 L .78452 .18905 L 0 .026 .125 r
F
.78122 .19013 m .77978 .18795 L .78309 .18689 L F
.42761 .19083 m .42889 .18749 L .4307 .18973 L 0 .027 .127 r
F
.42761 .19083 m .4258 .1886 L .42889 .18749 L F
.57002 .19107 m .57154 .18768 L .57319 .18983 L 0 .028 .127 r
F
.57002 .19107 m .56837 .18894 L .57154 .18768 L F
.66763 .19111 m .66931 .18773 L .67086 .18988 L F
.66763 .19111 m .66608 .18894 L .66931 .18773 L F
.59885 .19226 m .6004 .18866 L .60203 .19095 L 0 .03 .13 r
F
.59885 .19226 m .59722 .18995 L .6004 .18866 L F
.47241 .19118 m .47377 .18786 L .47553 .19011 L 0 .028 .128 r
F
.47241 .19118 m .47065 .18894 L .47377 .18786 L F
.29317 .19036 m .29425 .18688 L .29619 .18916 L 0 .027 .126 r
F
.29317 .19036 m .29123 .1881 L .29425 .18688 L F
.60684 .19191 m .60841 .18839 L .61003 .19064 L 0 .029 .129 r
F
.60684 .19191 m .60522 .18964 L .60841 .18839 L F
.61484 .1915 m .61643 .18819 L .61803 .19026 L F
.61484 .1915 m .61323 .18942 L .61643 .18819 L F
.38279 .19085 m .384 .18757 L .38585 .18969 L 0 .028 .127 r
F
.38279 .19085 m .38093 .18873 L .384 .18757 L F
.51722 .19152 m .51865 .18817 L .52036 .19042 L 0 .029 .129 r
F
.51722 .19152 m .51551 .18928 L .51865 .18817 L F
.73643 .19021 m .73822 .18691 L .7397 .189 L 0 .027 .126 r
F
.73643 .19021 m .73496 .18813 L .73822 .18691 L F
.62283 .19111 m .62443 .18778 L .62603 .1899 L 0 .028 .128 r
F
.62283 .19111 m .62123 .18902 L .62443 .18778 L F
.57802 .19093 m .57955 .18759 L .5812 .18985 L F
.57802 .19093 m .57637 .18865 L .57955 .18759 L F
.67564 .19097 m .67733 .18764 L .67887 .18985 L F
.67564 .19097 m .67409 .18875 L .67733 .18764 L F
.74443 .18987 m .74624 .1866 L .7477 .18869 L 0 .026 .125 r
F
.74443 .18987 m .74296 .18778 L .74624 .1866 L F
.63882 .19032 m .64045 .18705 L .64203 .18917 L 0 .027 .126 r
F
.63882 .19032 m .63724 .18822 L .64045 .18705 L F
.63083 .19079 m .63244 .18736 L .63403 .1895 L 0 .028 .127 r
F
.63083 .19079 m .62924 .18866 L .63244 .18736 L F
.33796 .19081 m .3391 .18757 L .341 .18976 L 0 .028 .128 r
F
.33796 .19081 m .33606 .18864 L .3391 .18757 L F
.30114 .19015 m .30222 .1869 L .30416 .18904 L 0 .027 .126 r
F
.30114 .19015 m .2992 .188 L .30222 .1869 L F
.43559 .19083 m .43688 .18753 L .43868 .18974 L 0 .028 .128 r
F
.43559 .19083 m .43379 .18864 L .43688 .18753 L F
.39077 .19065 m .392 .18733 L .39384 .1895 L 0 .028 .127 r
F
.39077 .19065 m .38892 .18851 L .392 .18733 L F
.75244 .18964 m .75426 .1864 L .75572 .18849 L 0 .026 .125 r
F
.75244 .18964 m .75098 .18754 L .75426 .1864 L F
.69164 .19035 m .69335 .18692 L .69488 .18906 L 0 .027 .126 r
F
.69164 .19035 m .69011 .1882 L .69335 .18692 L F
.34594 .19061 m .3471 .18727 L .34899 .18937 L 0 .028 .127 r
F
.34594 .19061 m .34405 .18852 L .3471 .18727 L F
.52521 .19152 m .52666 .1881 L .52836 .19036 L 0 .029 .129 r
F
.52521 .19152 m .52351 .18928 L .52666 .1881 L F
.64683 .19019 m .64847 .18698 L .65005 .18911 L 0 .027 .127 r
F
.64683 .19019 m .64525 .18808 L .64847 .18698 L F
.4804 .19131 m .48177 .18794 L .48352 .19023 L 0 .029 .129 r
F
.4804 .19131 m .47865 .18904 L .48177 .18794 L F
.2643 .18976 m .26531 .18655 L .26729 .18863 L 0 .027 .126 r
F
.2643 .18976 m .26231 .18769 L .26531 .18655 L F
.69964 .18999 m .70136 .18656 L .70288 .18874 L F
.69964 .18999 m .69812 .18781 L .70136 .18656 L F
.68365 .19088 m .68534 .18737 L .68688 .18954 L 0 .028 .128 r
F
.68365 .19088 m .68211 .18869 L .68534 .18737 L F
.35393 .19022 m .3551 .18688 L .35699 .18899 L 0 .027 .126 r
F
.35393 .19022 m .35205 .18812 L .3551 .18688 L F
.30912 .19001 m .3102 .18679 L .31214 .18885 L F
.30912 .19001 m .30718 .18793 L .3102 .18679 L F
.39875 .19048 m .39999 .18719 L .40183 .18934 L 0 .028 .127 r
F
.39875 .19048 m .39691 .18834 L .39999 .18719 L F
.58602 .19099 m .58757 .18768 L .58921 .1899 L 0 .029 .129 r
F
.58602 .19099 m .58438 .18876 L .58757 .18768 L F
.76045 .18944 m .76229 .18623 L .76374 .18833 L 0 .026 .125 r
F
.76045 .18944 m .759 .18736 L .76229 .18623 L F
.44357 .19077 m .44488 .18756 L .44667 .1897 L 0 .029 .128 r
F
.44357 .19077 m .44178 .18865 L .44488 .18756 L F
.36192 .18994 m .3631 .18663 L .36497 .18882 L 0 .027 .126 r
F
.36192 .18994 m .36004 .18775 L .3631 .18663 L F
.70765 .18974 m .70938 .18634 L .7109 .18856 L 0 .026 .126 r
F
.70765 .18974 m .70613 .18754 L .70938 .18634 L F
.3171 .18976 m .3182 .18654 L .32012 .18859 L 0 .027 .126 r
F
.3171 .18976 m .31517 .18769 L .3182 .18654 L F
.27227 .18963 m .27329 .18644 L .27526 .18855 L F
.27227 .18963 m .27029 .18754 L .27329 .18644 L F
.53321 .19143 m .53467 .18795 L .53636 .19018 L 0 .03 .13 r
F
.53321 .19143 m .53151 .18919 L .53467 .18795 L F
.40673 .19033 m .40799 .18701 L .40982 .18912 L 0 .028 .127 r
F
.40673 .19033 m .4049 .1882 L .40799 .18701 L F
.45156 .19062 m .45288 .18724 L .45466 .18936 L 0 .028 .128 r
F
.45156 .19062 m .44977 .18849 L .45288 .18724 L F
.76847 .1893 m .77031 .18598 L .77176 .18809 L 0 .026 .125 r
F
.76847 .1893 m .76703 .18719 L .77031 .18598 L F
.65484 .19019 m .65649 .18688 L .65806 .18908 L 0 .028 .127 r
F
.65484 .19019 m .65327 .18799 L .65649 .18688 L F
.5412 .1911 m .54267 .18765 L .54436 .18984 L 0 .029 .129 r
F
.5412 .1911 m .53952 .18891 L .54267 .18765 L F
.71566 .18954 m .7174 .18607 L .71891 .18828 L 0 .026 .125 r
F
.71566 .18954 m .71415 .18735 L .7174 .18607 L F
.41472 .19002 m .41599 .18671 L .41781 .1888 L 0 .027 .127 r
F
.41472 .19002 m .4129 .18792 L .41599 .18671 L F
.32507 .18966 m .32619 .18632 L .3281 .18855 L 0 .027 .126 r
F
.32507 .18966 m .32315 .18746 L .32619 .18632 L F
.72366 .18924 m .72542 .18587 L .72692 .18811 L 0 .026 .125 r
F
.72366 .18924 m .72216 .18702 L .72542 .18587 L F
.45955 .19035 m .46089 .18687 L .46266 .1891 L 0 .028 .127 r
F
.45955 .19035 m .45777 .18811 L .46089 .18687 L F
.36989 .18991 m .37108 .18664 L .37295 .18881 L 0 .027 .127 r
F
.36989 .18991 m .36803 .18773 L .37108 .18664 L F
.48838 .19147 m .48977 .18802 L .49151 .19035 L 0 .03 .13 r
F
.48838 .19147 m .48664 .18915 L .48977 .18802 L F
.59403 .19106 m .59558 .1877 L .59722 .18995 L 0 .029 .129 r
F
.59403 .19106 m .59239 .18881 L .59558 .1877 L F
.5492 .19085 m .55068 .18748 L .55236 .18967 L F
.5492 .19085 m .54752 .18866 L .55068 .18748 L F
.77649 .18908 m .77834 .18578 L .77978 .18795 L 0 .026 .125 r
F
.77649 .18908 m .77504 .18688 L .77834 .18578 L F
.28023 .18952 m .28129 .18614 L .28325 .18829 L 0 .027 .126 r
F
.28023 .18952 m .27827 .18737 L .28129 .18614 L F
.42271 .18983 m .42399 .18638 L .4258 .1886 L F
.42271 .18983 m .4209 .18759 L .42399 .18638 L F
.5572 .19053 m .5587 .18721 L .56036 .18932 L 0 .029 .129 r
F
.5572 .19053 m .55553 .18845 L .5587 .18721 L F
.46754 .1901 m .46889 .1867 L .47065 .18894 L 0 .028 .127 r
F
.46754 .1901 m .46577 .18786 L .46889 .1867 L F
.66285 .19015 m .66452 .18676 L .66608 .18894 L 0 .028 .128 r
F
.66285 .19015 m .66129 .18794 L .66452 .18676 L F
.51237 .19039 m .51379 .18723 L .51551 .18928 L 0 .029 .129 r
F
.51237 .19039 m .51065 .18836 L .51379 .18723 L F
.49638 .19128 m .49778 .18782 L .49951 .19001 L 0 .03 .13 r
F
.49638 .19128 m .49464 .18909 L .49778 .18782 L F
.50437 .19085 m .50578 .18754 L .50751 .1896 L 0 .029 .129 r
F
.50437 .19085 m .50264 .18877 L .50578 .18754 L F
.28821 .18931 m .28928 .18583 L .29123 .1881 L 0 .026 .125 r
F
.28821 .18931 m .28626 .18706 L .28928 .18583 L F
.5652 .1902 m .5667 .18683 L .56837 .18894 L 0 .028 .128 r
F
.5652 .1902 m .56353 .18811 L .5667 .18683 L F
.57319 .18983 m .57472 .18649 L .57637 .18865 L 0 .028 .127 r
F
.57319 .18983 m .57154 .18768 L .57472 .18649 L F
.60203 .19095 m .6036 .18737 L .60522 .18964 L 0 .029 .129 r
F
.60203 .19095 m .6004 .18866 L .6036 .18737 L F
.37787 .18986 m .37907 .18659 L .38093 .18873 L 0 .028 .127 r
F
.37787 .18986 m .37601 .1877 L .37907 .18659 L F
.67086 .18988 m .67254 .18662 L .67409 .18875 L F
.67086 .18988 m .66931 .18773 L .67254 .18662 L F
.73168 .18923 m .73347 .18591 L .73496 .18813 L 0 .027 .126 r
F
.73168 .18923 m .73019 .18701 L .73347 .18591 L F
.33303 .1897 m .33416 .18637 L .33606 .18864 L 0 .028 .127 r
F
.33303 .1897 m .33113 .18746 L .33416 .18637 L F
.78452 .18905 m .78639 .18582 L .78782 .18796 L 0 .026 .126 r
F
.78452 .18905 m .78309 .18689 L .78639 .18582 L F
.4307 .18973 m .43199 .18637 L .43379 .18864 L 0 .028 .127 r
F
.4307 .18973 m .42889 .18749 L .43199 .18637 L F
.61003 .19064 m .61161 .18719 L .61323 .18942 L 0 .029 .129 r
F
.61003 .19064 m .60841 .18839 L .61161 .18719 L F
.61803 .19026 m .61963 .18692 L .62123 .18902 L 0 .029 .128 r
F
.61803 .19026 m .61643 .18819 L .61963 .18692 L F
.29619 .18916 m .29727 .18572 L .2992 .188 L 0 .026 .126 r
F
.29619 .18916 m .29425 .18688 L .29727 .18572 L F
.7397 .189 m .74149 .18569 L .74296 .18778 L F
.7397 .189 m .73822 .18691 L .74149 .18569 L F
.47553 .19011 m .47689 .18678 L .47865 .18904 L 0 .029 .128 r
F
.47553 .19011 m .47377 .18786 L .47689 .18678 L F
.62603 .1899 m .62764 .18651 L .62924 .18866 L 0 .028 .128 r
F
.62603 .1899 m .62443 .18778 L .62764 .18651 L F
.38585 .18969 m .38707 .18636 L .38892 .18851 L 0 .028 .127 r
F
.38585 .18969 m .384 .18757 L .38707 .18636 L F
.63403 .1895 m .63565 .18605 L .63724 .18822 L 0 .027 .127 r
F
.63403 .1895 m .63244 .18736 L .63565 .18605 L F
.52036 .19042 m .5218 .18703 L .52351 .18928 L 0 .029 .129 r
F
.52036 .19042 m .51865 .18817 L .5218 .18703 L F
.7477 .18869 m .74952 .18545 L .75098 .18754 L 0 .026 .125 r
F
.7477 .18869 m .74624 .1866 L .74952 .18545 L F
.64203 .18917 m .64367 .18596 L .64525 .18808 L 0 .027 .126 r
F
.64203 .18917 m .64045 .18705 L .64367 .18596 L F
.5812 .18985 m .58273 .18653 L .58438 .18876 L 0 .028 .128 r
F
.5812 .18985 m .57955 .18759 L .58273 .18653 L F
.67887 .18985 m .68057 .1865 L .68211 .18869 L F
.67887 .18985 m .67733 .18764 L .68057 .1865 L F
.30416 .18904 m .30524 .1858 L .30718 .18793 L 0 .027 .126 r
F
.30416 .18904 m .30222 .1869 L .30524 .1858 L F
.39384 .1895 m .39507 .18615 L .39691 .18834 L 0 .028 .127 r
F
.39384 .1895 m .392 .18733 L .39507 .18615 L F
.69488 .18906 m .69659 .18568 L .69812 .18781 L 0 .027 .126 r
F
.69488 .18906 m .69335 .18692 L .69659 .18568 L F
.43868 .18974 m .43998 .18642 L .44178 .18865 L 0 .028 .128 r
F
.43868 .18974 m .43688 .18753 L .43998 .18642 L F
.341 .18976 m .34215 .18634 L .34405 .18852 L F
.341 .18976 m .3391 .18757 L .34215 .18634 L F
.68688 .18954 m .68858 .18606 L .69011 .1882 L 0 .028 .127 r
F
.68688 .18954 m .68534 .18737 L .68858 .18606 L F
.34899 .18937 m .35015 .18602 L .35205 .18812 L F
.34899 .18937 m .3471 .18727 L .35015 .18602 L F
.75572 .18849 m .75755 .18525 L .759 .18736 L 0 .026 .125 r
F
.75572 .18849 m .75426 .1864 L .75755 .18525 L F
.70288 .18874 m .70461 .18534 L .70613 .18754 L F
.70288 .18874 m .70136 .18656 L .70461 .18534 L F
.35699 .18899 m .35816 .18564 L .36004 .18775 L 0 .027 .126 r
F
.35699 .18899 m .3551 .18688 L .35816 .18564 L F
.52836 .19036 m .52981 .18693 L .53151 .18919 L 0 .029 .129 r
F
.52836 .19036 m .52666 .1881 L .52981 .18693 L F
.26729 .18863 m .26831 .18544 L .27029 .18754 L 0 .027 .126 r
F
.26729 .18863 m .26531 .18655 L .26831 .18544 L F
.31214 .18885 m .31323 .18565 L .31517 .18769 L F
.31214 .18885 m .3102 .18679 L .31323 .18565 L F
.65005 .18911 m .6517 .18584 L .65327 .18799 L 0 .027 .127 r
F
.65005 .18911 m .64847 .18698 L .6517 .18584 L F
.40183 .18934 m .40307 .18603 L .4049 .1882 L 0 .028 .127 r
F
.40183 .18934 m .39999 .18719 L .40307 .18603 L F
.48352 .19023 m .4849 .18683 L .48664 .18915 L 0 .029 .129 r
F
.48352 .19023 m .48177 .18794 L .4849 .18683 L F
.76374 .18833 m .76558 .18508 L .76703 .18719 L 0 .026 .125 r
F
.76374 .18833 m .76229 .18623 L .76558 .18508 L F
.7109 .18856 m .71264 .18512 L .71415 .18735 L F
.7109 .18856 m .70938 .18634 L .71264 .18512 L F
.58921 .1899 m .59076 .1866 L .59239 .18881 L 0 .029 .129 r
F
.58921 .1899 m .58757 .18768 L .59076 .1866 L F
.32012 .18859 m .32123 .18538 L .32315 .18746 L 0 .027 .126 r
F
.32012 .18859 m .3182 .18654 L .32123 .18538 L F
.44667 .1897 m .44799 .18635 L .44977 .18849 L 0 .029 .128 r
F
.44667 .1897 m .44488 .18756 L .44799 .18635 L F
.36497 .18882 m .36615 .18555 L .36803 .18773 L 0 .027 .126 r
F
.36497 .18882 m .3631 .18663 L .36615 .18555 L F
.53636 .19018 m .53782 .18671 L .53952 .18891 L 0 .029 .129 r
F
.53636 .19018 m .53467 .18795 L .53782 .18671 L F
.40982 .18912 m .41107 .18581 L .4129 .18792 L 0 .028 .127 r
F
.40982 .18912 m .40799 .18701 L .41107 .18581 L F
.45466 .18936 m .456 .18599 L .45777 .18811 L 0 .028 .128 r
F
.45466 .18936 m .45288 .18724 L .456 .18599 L F
.71891 .18828 m .72066 .1848 L .72216 .18702 L 0 .026 .125 r
F
.71891 .18828 m .7174 .18607 L .72066 .1848 L F
.54436 .18984 m .54584 .18647 L .54752 .18866 L 0 .029 .129 r
F
.54436 .18984 m .54267 .18765 L .54584 .18647 L F
.77176 .18809 m .7736 .18476 L .77504 .18688 L 0 .026 .125 r
F
.77176 .18809 m .77031 .18598 L .7736 .18476 L F
.27526 .18855 m .2763 .18526 L .27827 .18737 L 0 .027 .126 r
F
.27526 .18855 m .27329 .18644 L .2763 .18526 L F
.41781 .1888 m .41908 .18552 L .4209 .18759 L 0 .027 .127 r
F
.41781 .1888 m .41599 .18671 L .41908 .18552 L F
.65806 .18908 m .65972 .18574 L .66129 .18794 L 0 .028 .127 r
F
.65806 .18908 m .65649 .18688 L .65972 .18574 L F
.46266 .1891 m .46401 .18564 L .46577 .18786 L F
.46266 .1891 m .46089 .18687 L .46401 .18564 L F
.28325 .18829 m .2843 .1849 L .28626 .18706 L 0 .026 .125 r
F
.28325 .18829 m .28129 .18614 L .2843 .1849 L F
.72692 .18811 m .7287 .18477 L .73019 .18701 L F
.72692 .18811 m .72542 .18587 L .7287 .18477 L F
.3281 .18855 m .32922 .18521 L .33113 .18746 L 0 .027 .126 r
F
.3281 .18855 m .32619 .18632 L .32922 .18521 L F
.55236 .18967 m .55385 .18625 L .55553 .18845 L 0 .029 .129 r
F
.55236 .18967 m .55068 .18748 L .55385 .18625 L F
.49151 .19035 m .4929 .18677 L .49464 .18909 L 0 .03 .13 r
F
.49151 .19035 m .48977 .18802 L .4929 .18677 L F
.37295 .18881 m .37414 .18554 L .37601 .1877 L 0 .028 .127 r
F
.37295 .18881 m .37108 .18664 L .37414 .18554 L F
.4258 .1886 m .42709 .18524 L .42889 .18749 L 0 .027 .126 r
F
.4258 .1886 m .42399 .18638 L .42709 .18524 L F
.59722 .18995 m .59878 .18643 L .6004 .18866 L 0 .029 .129 r
F
.59722 .18995 m .59558 .1877 L .59878 .18643 L F
.77978 .18795 m .78165 .18473 L .78309 .18689 L 0 .026 .125 r
F
.77978 .18795 m .77834 .18578 L .78165 .18473 L F
.56036 .18932 m .56187 .18597 L .56353 .18811 L 0 .029 .128 r
F
.56036 .18932 m .5587 .18721 L .56187 .18597 L F
.49951 .19001 m .50091 .1866 L .50264 .18877 L 0 .03 .13 r
F
.49951 .19001 m .49778 .18782 L .50091 .1866 L F
.50751 .1896 m .50893 .18632 L .51065 .18836 L 0 .029 .129 r
F
.50751 .1896 m .50578 .18754 L .50893 .18632 L F
.66608 .18894 m .66775 .18558 L .66931 .18773 L 0 .028 .127 r
F
.66608 .18894 m .66452 .18676 L .66775 .18558 L F
.47065 .18894 m .47201 .18561 L .47377 .18786 L F
.47065 .18894 m .46889 .1867 L .47201 .18561 L F
.56837 .18894 m .56988 .18555 L .57154 .18768 L F
.56837 .18894 m .5667 .18683 L .56988 .18555 L F
.60522 .18964 m .60679 .18614 L .60841 .18839 L 0 .029 .129 r
F
.60522 .18964 m .6036 .18737 L .60679 .18614 L F
.29123 .1881 m .29231 .18459 L .29425 .18688 L 0 .026 .125 r
F
.29123 .1881 m .28928 .18583 L .29231 .18459 L F
.51551 .18928 m .51694 .1861 L .51865 .18817 L 0 .029 .129 r
F
.51551 .18928 m .51379 .18723 L .51694 .1861 L F
.57637 .18865 m .5779 .18542 L .57955 .18759 L 0 .028 .127 r
F
.57637 .18865 m .57472 .18649 L .5779 .18542 L F
.38093 .18873 m .38214 .18542 L .384 .18757 L F
.38093 .18873 m .37907 .18659 L .38214 .18542 L F
.67409 .18875 m .67578 .18553 L .67733 .18764 L 0 .028 .128 r
F
.67409 .18875 m .67254 .18662 L .67578 .18553 L F
.61323 .18942 m .61481 .18599 L .61643 .18819 L 0 .029 .129 r
F
.61323 .18942 m .61161 .18719 L .61481 .18599 L F
.73496 .18813 m .73673 .18468 L .73822 .18691 L 0 .027 .126 r
F
.73496 .18813 m .73347 .18591 L .73673 .18468 L F
.62123 .18902 m .62283 .18565 L .62443 .18778 L 0 .028 .128 r
F
.62123 .18902 m .61963 .18692 L .62283 .18565 L F
.43379 .18864 m .43509 .18524 L .43688 .18753 L 0 .028 .127 r
F
.43379 .18864 m .43199 .18637 L .43509 .18524 L F
.33606 .18864 m .3372 .18529 L .3391 .18757 L F
.33606 .18864 m .33416 .18637 L .3372 .18529 L F
.63724 .18822 m .63886 .18487 L .64045 .18705 L 0 .027 .126 r
F
.63724 .18822 m .63565 .18605 L .63886 .18487 L F
.62924 .18866 m .63085 .18519 L .63244 .18736 L 0 .028 .127 r
F
.62924 .18866 m .62764 .18651 L .63085 .18519 L F
.2992 .188 m .30028 .18462 L .30222 .1869 L 0 .027 .126 r
F
.2992 .188 m .29727 .18572 L .30028 .18462 L F
.74296 .18778 m .74477 .1845 L .74624 .1866 L 0 .026 .125 r
F
.74296 .18778 m .74149 .18569 L .74477 .1845 L F
.38892 .18851 m .39015 .18516 L .392 .18733 L 0 .028 .127 r
F
.38892 .18851 m .38707 .18636 L .39015 .18516 L F
.47865 .18904 m .48002 .18566 L .48177 .18794 L 0 .029 .129 r
F
.47865 .18904 m .47689 .18678 L .48002 .18566 L F
.52351 .18928 m .52495 .18585 L .52666 .1881 L F
.52351 .18928 m .5218 .18703 L .52495 .18585 L F
.69011 .1882 m .69182 .1848 L .69335 .18692 L 0 .027 .126 r
F
.69011 .1882 m .68858 .18606 L .69182 .1848 L F
.75098 .18754 m .7528 .18429 L .75426 .1864 L 0 .026 .125 r
F
.75098 .18754 m .74952 .18545 L .7528 .18429 L F
.68211 .18869 m .6838 .1852 L .68534 .18737 L 0 .028 .128 r
F
.68211 .18869 m .68057 .1865 L .6838 .1852 L F
.69812 .18781 m .69984 .18444 L .70136 .18656 L 0 .027 .126 r
F
.69812 .18781 m .69659 .18568 L .69984 .18444 L F
.34405 .18852 m .3452 .18509 L .3471 .18727 L 0 .028 .127 r
F
.34405 .18852 m .34215 .18634 L .3452 .18509 L F
.64525 .18808 m .6469 .18485 L .64847 .18698 L 0 .027 .127 r
F
.64525 .18808 m .64367 .18596 L .6469 .18485 L F
.58438 .18876 m .58592 .18546 L .58757 .18768 L 0 .029 .128 r
F
.58438 .18876 m .58273 .18653 L .58592 .18546 L F
.39691 .18834 m .39815 .18497 L .39999 .18719 L 0 .028 .127 r
F
.39691 .18834 m .39507 .18615 L .39815 .18497 L F
.35205 .18812 m .35321 .18477 L .3551 .18688 L 0 .027 .127 r
F
.35205 .18812 m .35015 .18602 L .35321 .18477 L F
.30718 .18793 m .30826 .18468 L .3102 .18679 L 0 .027 .126 r
F
.30718 .18793 m .30524 .1858 L .30826 .18468 L F
.36004 .18775 m .36122 .18452 L .3631 .18663 L F
.36004 .18775 m .35816 .18564 L .36122 .18452 L F
.44178 .18865 m .44309 .1853 L .44488 .18756 L 0 .028 .128 r
F
.44178 .18865 m .43998 .18642 L .44309 .1853 L F
.70613 .18754 m .70786 .18412 L .70938 .18634 L 0 .026 .125 r
F
.70613 .18754 m .70461 .18534 L .70786 .18412 L F
.759 .18736 m .76084 .18411 L .76229 .18623 L F
.759 .18736 m .75755 .18525 L .76084 .18411 L F
.53151 .18919 m .53297 .18572 L .53467 .18795 L 0 .029 .129 r
F
.53151 .18919 m .52981 .18693 L .53297 .18572 L F
.31517 .18769 m .31626 .1845 L .3182 .18654 L 0 .027 .126 r
F
.31517 .18769 m .31323 .18565 L .31626 .1845 L F
.4049 .1882 m .40615 .18485 L .40799 .18701 L 0 .028 .127 r
F
.4049 .1882 m .40307 .18603 L .40615 .18485 L F
.27029 .18754 m .27131 .18433 L .27329 .18644 L 0 .027 .126 r
F
.27029 .18754 m .26831 .18544 L .27131 .18433 L F
.65327 .18799 m .65492 .18469 L .65649 .18688 L 0 .028 .127 r
F
.65327 .18799 m .6517 .18584 L .65492 .18469 L F
.71415 .18735 m .71589 .18384 L .7174 .18607 L 0 .026 .125 r
F
.71415 .18735 m .71264 .18512 L .71589 .18384 L F
.53952 .18891 m .54098 .18548 L .54267 .18765 L 0 .029 .129 r
F
.53952 .18891 m .53782 .18671 L .54098 .18548 L F
.44977 .18849 m .4511 .18511 L .45288 .18724 L 0 .028 .128 r
F
.44977 .18849 m .44799 .18635 L .4511 .18511 L F
.48664 .18915 m .48803 .18569 L .48977 .18802 L 0 .03 .13 r
F
.48664 .18915 m .4849 .18683 L .48803 .18569 L F
.76703 .18719 m .76887 .18386 L .77031 .18598 L 0 .026 .125 r
F
.76703 .18719 m .76558 .18508 L .76887 .18386 L F
.45777 .18811 m .45911 .18477 L .46089 .18687 L 0 .028 .127 r
F
.45777 .18811 m .456 .18599 L .45911 .18477 L F
.32315 .18746 m .32427 .18423 L .32619 .18632 L 0 .027 .126 r
F
.32315 .18746 m .32123 .18538 L .32427 .18423 L F
.72216 .18702 m .72392 .18364 L .72542 .18587 L 0 .026 .125 r
F
.72216 .18702 m .72066 .1848 L .72392 .18364 L F
.4129 .18792 m .41416 .18463 L .41599 .18671 L 0 .028 .127 r
F
.4129 .18792 m .41107 .18581 L .41416 .18463 L F
.59239 .18881 m .59395 .1855 L .59558 .1877 L 0 .029 .129 r
F
.59239 .18881 m .59076 .1866 L .59395 .1855 L F
.36803 .18773 m .36921 .18446 L .37108 .18664 L 0 .027 .127 r
F
.36803 .18773 m .36615 .18555 L .36921 .18446 L F
.77504 .18688 m .7769 .18364 L .77834 .18578 L 0 .026 .125 r
F
.77504 .18688 m .7736 .18476 L .7769 .18364 L F
.54752 .18866 m .549 .18529 L .55068 .18748 L 0 .029 .129 r
F
.54752 .18866 m .54584 .18647 L .549 .18529 L F
.27827 .18737 m .27931 .18404 L .28129 .18614 L 0 .027 .126 r
F
.27827 .18737 m .2763 .18526 L .27931 .18404 L F
.4209 .18759 m .42217 .18432 L .42399 .18638 L F
.4209 .18759 m .41908 .18552 L .42217 .18432 L F
.46577 .18786 m .46712 .18448 L .46889 .1867 L 0 .028 .127 r
F
.46577 .18786 m .46401 .18564 L .46712 .18448 L F
.28626 .18706 m .28733 .18366 L .28928 .18583 L 0 .026 .125 r
F
.28626 .18706 m .2843 .1849 L .28733 .18366 L F
.66129 .18794 m .66296 .18457 L .66452 .18676 L 0 .028 .127 r
F
.66129 .18794 m .65972 .18574 L .66296 .18457 L F
.49464 .18909 m .49604 .18552 L .49778 .18782 L 0 .03 .13 r
F
.49464 .18909 m .4929 .18677 L .49604 .18552 L F
.6004 .18866 m .60197 .18516 L .6036 .18737 L 0 .029 .129 r
F
.6004 .18866 m .59878 .18643 L .60197 .18516 L F
.55553 .18845 m .55702 .18498 L .5587 .18721 L F
.55553 .18845 m .55385 .18625 L .55702 .18498 L F
.50264 .18877 m .50405 .18539 L .50578 .18754 L 0 .03 .13 r
F
.50264 .18877 m .50091 .1866 L .50405 .18539 L F
.56353 .18811 m .56504 .18468 L .5667 .18683 L 0 .028 .128 r
F
.56353 .18811 m .56187 .18597 L .56504 .18468 L F
.73019 .18701 m .73197 .18366 L .73347 .18591 L 0 .026 .125 r
F
.73019 .18701 m .7287 .18477 L .73197 .18366 L F
.33113 .18746 m .33226 .1841 L .33416 .18637 L 0 .027 .127 r
F
.33113 .18746 m .32922 .18521 L .33226 .1841 L F
.57154 .18768 m .57306 .18434 L .57472 .18649 L 0 .028 .127 r
F
.57154 .18768 m .56988 .18555 L .57306 .18434 L F
.51065 .18836 m .51207 .18517 L .51379 .18723 L 0 .029 .129 r
F
.51065 .18836 m .50893 .18632 L .51207 .18517 L F
.37601 .1877 m .37721 .18444 L .37907 .18659 L 0 .028 .127 r
F
.37601 .1877 m .37414 .18554 L .37721 .18444 L F
.42889 .18749 m .43018 .18409 L .43199 .18637 L 0 .027 .127 r
F
.42889 .18749 m .42709 .18524 L .43018 .18409 L F
.60841 .18839 m .60999 .18496 L .61161 .18719 L 0 .029 .129 r
F
.60841 .18839 m .60679 .18614 L .60999 .18496 L F
.66931 .18773 m .67099 .18449 L .67254 .18662 L 0 .028 .127 r
F
.66931 .18773 m .66775 .18558 L .67099 .18449 L F
.29425 .18688 m .29533 .18343 L .29727 .18572 L 0 .026 .125 r
F
.29425 .18688 m .29231 .18459 L .29533 .18343 L F
.78309 .18689 m .78496 .18368 L .78639 .18582 L 0 .026 .126 r
F
.78309 .18689 m .78165 .18473 L .78496 .18368 L F
.47377 .18786 m .47513 .18451 L .47689 .18678 L 0 .028 .128 r
F
.47377 .18786 m .47201 .18561 L .47513 .18451 L F
.51865 .18817 m .52009 .18493 L .5218 .18703 L 0 .029 .129 r
F
.51865 .18817 m .51694 .1861 L .52009 .18493 L F
.61643 .18819 m .61802 .18473 L .61963 .18692 L F
.61643 .18819 m .61481 .18599 L .61802 .18473 L F
.62443 .18778 m .62604 .18435 L .62764 .18651 L 0 .028 .128 r
F
.62443 .18778 m .62283 .18565 L .62604 .18435 L F
.384 .18757 m .38522 .1842 L .38707 .18636 L 0 .028 .127 r
F
.384 .18757 m .38214 .18542 L .38522 .1842 L F
.73822 .18691 m .74001 .18346 L .74149 .18569 L 0 .026 .126 r
F
.73822 .18691 m .73673 .18468 L .74001 .18346 L F
.63244 .18736 m .63406 .18387 L .63565 .18605 L 0 .027 .127 r
F
.63244 .18736 m .63085 .18519 L .63406 .18387 L F
.57955 .18759 m .58109 .18435 L .58273 .18653 L 0 .028 .128 r
F
.57955 .18759 m .5779 .18542 L .58109 .18435 L F
.67733 .18764 m .67903 .1844 L .68057 .1865 L F
.67733 .18764 m .67578 .18553 L .67903 .1844 L F
.74624 .1866 m .74805 .18334 L .74952 .18545 L 0 .026 .125 r
F
.74624 .1866 m .74477 .1845 L .74805 .18334 L F
.64045 .18705 m .64209 .18376 L .64367 .18596 L 0 .027 .126 r
F
.64045 .18705 m .63886 .18487 L .64209 .18376 L F
.43688 .18753 m .43819 .1841 L .43998 .18642 L 0 .028 .127 r
F
.43688 .18753 m .43509 .18524 L .43819 .1841 L F
.392 .18733 m .39323 .18395 L .39507 .18615 L F
.392 .18733 m .39015 .18516 L .39323 .18395 L F
.30222 .1869 m .30331 .18353 L .30524 .1858 L 0 .027 .126 r
F
.30222 .1869 m .30028 .18462 L .30331 .18353 L F
.3391 .18757 m .34025 .18406 L .34215 .18634 L 0 .028 .127 r
F
.3391 .18757 m .3372 .18529 L .34025 .18406 L F
.69335 .18692 m .69507 .18358 L .69659 .18568 L 0 .027 .126 r
F
.69335 .18692 m .69182 .1848 L .69507 .18358 L F
.68534 .18737 m .68704 .1839 L .68858 .18606 L 0 .028 .127 r
F
.68534 .18737 m .6838 .1852 L .68704 .1839 L F
.52666 .1881 m .52811 .18466 L .52981 .18693 L 0 .029 .129 r
F
.52666 .1881 m .52495 .18585 L .52811 .18466 L F
.70136 .18656 m .70309 .18321 L .70461 .18534 L 0 .026 .125 r
F
.70136 .18656 m .69984 .18444 L .70309 .18321 L F
.3471 .18727 m .34826 .18385 L .35015 .18602 L 0 .028 .127 r
F
.3471 .18727 m .3452 .18509 L .34826 .18385 L F
.48177 .18794 m .48315 .18454 L .4849 .18683 L 0 .029 .129 r
F
.48177 .18794 m .48002 .18566 L .48315 .18454 L F
.75426 .1864 m .75609 .18313 L .75755 .18525 L 0 .026 .125 r
F
.75426 .1864 m .7528 .18429 L .75609 .18313 L F
.3551 .18688 m .35627 .18352 L .35816 .18564 L 0 .027 .126 r
F
.3551 .18688 m .35321 .18477 L .35627 .18352 L F
.39999 .18719 m .40123 .18379 L .40307 .18603 L 0 .028 .127 r
F
.39999 .18719 m .39815 .18497 L .40123 .18379 L F
.64847 .18698 m .65012 .18367 L .6517 .18584 L 0 .027 .127 r
F
.64847 .18698 m .6469 .18485 L .65012 .18367 L F
.70938 .18634 m .71112 .18288 L .71264 .18512 L 0 .026 .125 r
F
.70938 .18634 m .70786 .18412 L .71112 .18288 L F
.58757 .18768 m .58912 .18438 L .59076 .1866 L 0 .029 .129 r
F
.58757 .18768 m .58592 .18546 L .58912 .18438 L F
.3102 .18679 m .31129 .18355 L .31323 .18565 L 0 .027 .127 r
F
.3102 .18679 m .30826 .18468 L .31129 .18355 L F
.53467 .18795 m .53613 .1845 L .53782 .18671 L 0 .029 .129 r
F
.53467 .18795 m .53297 .18572 L .53613 .1845 L F
.3631 .18663 m .36427 .18344 L .36615 .18555 L 0 .027 .126 r
F
.3631 .18663 m .36122 .18452 L .36427 .18344 L F
.44488 .18756 m .4462 .1841 L .44799 .18635 L 0 .028 .128 r
F
.44488 .18756 m .44309 .1853 L .4462 .1841 L F
.76229 .18623 m .76413 .18294 L .76558 .18508 L 0 .026 .125 r
F
.76229 .18623 m .76084 .18411 L .76413 .18294 L F
.7174 .18607 m .71915 .18256 L .72066 .1848 L F
.7174 .18607 m .71589 .18384 L .71915 .18256 L F
.3182 .18654 m .3193 .18333 L .32123 .18538 L 0 .027 .126 r
F
.3182 .18654 m .31626 .1845 L .3193 .18333 L F
.54267 .18765 m .54415 .18431 L .54584 .18647 L 0 .029 .129 r
F
.54267 .18765 m .54098 .18548 L .54415 .18431 L F
.40799 .18701 m .40924 .18368 L .41107 .18581 L 0 .028 .127 r
F
.40799 .18701 m .40615 .18485 L .40924 .18368 L F
.45288 .18724 m .45421 .18387 L .456 .18599 L 0 .028 .128 r
F
.45288 .18724 m .4511 .18511 L .45421 .18387 L F
.77031 .18598 m .77216 .18264 L .7736 .18476 L 0 .026 .125 r
F
.77031 .18598 m .76887 .18386 L .77216 .18264 L F
.46089 .18687 m .46223 .18355 L .46401 .18564 L 0 .028 .127 r
F
.46089 .18687 m .45911 .18477 L .46223 .18355 L F
.65649 .18688 m .65815 .18353 L .65972 .18574 L F
.65649 .18688 m .65492 .18469 L .65815 .18353 L F
.27329 .18644 m .27432 .18315 L .2763 .18526 L 0 .027 .126 r
F
.27329 .18644 m .27131 .18433 L .27432 .18315 L F
.48977 .18802 m .49116 .18445 L .4929 .18677 L 0 .029 .129 r
F
.48977 .18802 m .48803 .18569 L .49116 .18445 L F
.41599 .18671 m .41726 .18345 L .41908 .18552 L 0 .027 .127 r
F
.41599 .18671 m .41416 .18463 L .41726 .18345 L F
.72542 .18587 m .7272 .18253 L .7287 .18477 L 0 .026 .125 r
F
.72542 .18587 m .72392 .18364 L .7272 .18253 L F
.32619 .18632 m .3273 .18309 L .32922 .18521 L 0 .027 .126 r
F
.32619 .18632 m .32427 .18423 L .3273 .18309 L F
.28129 .18614 m .28233 .18281 L .2843 .1849 L 0 .026 .126 r
F
.28129 .18614 m .27931 .18404 L .28233 .18281 L F
.59558 .1877 m .59714 .18425 L .59878 .18643 L 0 .029 .129 r
F
.59558 .1877 m .59395 .1855 L .59714 .18425 L F
.55068 .18748 m .55217 .18404 L .55385 .18625 L F
.55068 .18748 m .549 .18529 L .55217 .18404 L F
.42399 .18638 m .42527 .18316 L .42709 .18524 L 0 .027 .126 r
F
.42399 .18638 m .42217 .18432 L .42527 .18316 L F
.37108 .18664 m .37227 .18337 L .37414 .18554 L 0 .028 .127 r
F
.37108 .18664 m .36921 .18446 L .37227 .18337 L F
.77834 .18578 m .78021 .18256 L .78165 .18473 L 0 .026 .125 r
F
.77834 .18578 m .7769 .18364 L .78021 .18256 L F
.46889 .1867 m .47025 .18337 L .47201 .18561 L 0 .028 .127 r
F
.46889 .1867 m .46712 .18448 L .47025 .18337 L F
.6036 .18737 m .60517 .18395 L .60679 .18614 L 0 .029 .129 r
F
.6036 .18737 m .60197 .18516 L .60517 .18395 L F
.49778 .18782 m .49918 .18431 L .50091 .1866 L F
.49778 .18782 m .49604 .18552 L .49918 .18431 L F
.28928 .18583 m .29035 .18242 L .29231 .18459 L 0 .026 .125 r
F
.28928 .18583 m .28733 .18366 L .29035 .18242 L F
.66452 .18676 m .66619 .1834 L .66775 .18558 L 0 .028 .127 r
F
.66452 .18676 m .66296 .18457 L .66619 .1834 L F
.5587 .18721 m .56019 .18372 L .56187 .18597 L 0 .028 .128 r
F
.5587 .18721 m .55702 .18498 L .56019 .18372 L F
.5667 .18683 m .56822 .18338 L .56988 .18555 L 0 .028 .127 r
F
.5667 .18683 m .56504 .18468 L .56822 .18338 L F
.50578 .18754 m .5072 .18419 L .50893 .18632 L 0 .029 .129 r
F
.50578 .18754 m .50405 .18539 L .5072 .18419 L F
.57472 .18649 m .57625 .18325 L .5779 .18542 L 0 .028 .127 r
F
.57472 .18649 m .57306 .18434 L .57625 .18325 L F
.61161 .18719 m .6132 .18378 L .61481 .18599 L 0 .029 .129 r
F
.61161 .18719 m .60999 .18496 L .6132 .18378 L F
.51379 .18723 m .51522 .18402 L .51694 .1861 L F
.51379 .18723 m .51207 .18517 L .51522 .18402 L F
.73347 .18591 m .73524 .18243 L .73673 .18468 L 0 .026 .125 r
F
.73347 .18591 m .73197 .18366 L .73524 .18243 L F
.43199 .18637 m .43329 .18294 L .43509 .18524 L 0 .027 .127 r
F
.43199 .18637 m .43018 .18409 L .43329 .18294 L F
.37907 .18659 m .38028 .18327 L .38214 .18542 L 0 .028 .127 r
F
.37907 .18659 m .37721 .18444 L .38028 .18327 L F
.33416 .18637 m .3353 .183 L .3372 .18529 L 0 .027 .127 r
F
.33416 .18637 m .33226 .1841 L .3353 .183 L F
.29727 .18572 m .29835 .18234 L .30028 .18462 L 0 .026 .125 r
F
.29727 .18572 m .29533 .18343 L .29835 .18234 L F
.67254 .18662 m .67424 .18341 L .67578 .18553 L 0 .028 .128 r
F
.67254 .18662 m .67099 .18449 L .67424 .18341 L F
.61963 .18692 m .62122 .18346 L .62283 .18565 L F
.61963 .18692 m .61802 .18473 L .62122 .18346 L F
.63565 .18605 m .63727 .18267 L .63886 .18487 L 0 .027 .126 r
F
.63565 .18605 m .63406 .18387 L .63727 .18267 L F
.62764 .18651 m .62925 .18302 L .63085 .18519 L 0 .028 .127 r
F
.62764 .18651 m .62604 .18435 L .62925 .18302 L F
.47689 .18678 m .47826 .18339 L .48002 .18566 L 0 .028 .128 r
F
.47689 .18678 m .47513 .18451 L .47826 .18339 L F
.74149 .18569 m .74328 .18227 L .74477 .1845 L 0 .026 .125 r
F
.74149 .18569 m .74001 .18346 L .74328 .18227 L F
.38707 .18636 m .3883 .18298 L .39015 .18516 L 0 .028 .127 r
F
.38707 .18636 m .38522 .1842 L .3883 .18298 L F
.5218 .18703 m .52324 .18372 L .52495 .18585 L 0 .029 .129 r
F
.5218 .18703 m .52009 .18493 L .52324 .18372 L F
.68858 .18606 m .69029 .18267 L .69182 .1848 L 0 .027 .127 r
F
.68858 .18606 m .68704 .1839 L .69029 .18267 L F
.68057 .1865 m .68227 .18311 L .6838 .1852 L 0 .028 .128 r
F
.68057 .1865 m .67903 .1844 L .68227 .18311 L F
.58273 .18653 m .58428 .18325 L .58592 .18546 L F
.58273 .18653 m .58109 .18435 L .58428 .18325 L F
.74952 .18545 m .75133 .18218 L .7528 .18429 L 0 .026 .125 r
F
.74952 .18545 m .74805 .18334 L .75133 .18218 L F
.34215 .18634 m .34331 .18283 L .3452 .18509 L 0 .028 .127 r
F
.34215 .18634 m .34025 .18406 L .34331 .18283 L F
.69659 .18568 m .69832 .18236 L .69984 .18444 L 0 .027 .126 r
F
.69659 .18568 m .69507 .18358 L .69832 .18236 L F
.39507 .18615 m .39631 .18274 L .39815 .18497 L 0 .028 .127 r
F
.39507 .18615 m .39323 .18395 L .39631 .18274 L F
.64367 .18596 m .64531 .18264 L .6469 .18485 L 0 .027 .127 r
F
.64367 .18596 m .64209 .18376 L .64531 .18264 L F
.43998 .18642 m .4413 .18296 L .44309 .1853 L 0 .028 .128 r
F
.43998 .18642 m .43819 .1841 L .4413 .18296 L F
.70461 .18534 m .70635 .18198 L .70786 .18412 L 0 .026 .125 r
F
.70461 .18534 m .70309 .18321 L .70635 .18198 L F
.35015 .18602 m .35132 .1826 L .35321 .18477 L 0 .027 .127 r
F
.35015 .18602 m .34826 .18385 L .35132 .1826 L F
.30524 .1858 m .30633 .18241 L .30826 .18468 L 0 .027 .126 r
F
.30524 .1858 m .30331 .18353 L .30633 .18241 L F
.52981 .18693 m .53127 .18348 L .53297 .18572 L 0 .029 .129 r
F
.52981 .18693 m .52811 .18466 L .53127 .18348 L F
.35816 .18564 m .35933 .1824 L .36122 .18452 L 0 .027 .126 r
F
.35816 .18564 m .35627 .18352 L .35933 .1824 L F
.75755 .18525 m .75938 .18196 L .76084 .18411 L 0 .026 .125 r
F
.75755 .18525 m .75609 .18313 L .75938 .18196 L F
.4849 .18683 m .48628 .1834 L .48803 .18569 L 0 .029 .129 r
F
.4849 .18683 m .48315 .18454 L .48628 .1834 L F
.71264 .18512 m .71438 .18159 L .71589 .18384 L 0 .026 .125 r
F
.71264 .18512 m .71112 .18288 L .71438 .18159 L F
.40307 .18603 m .40432 .18264 L .40615 .18485 L 0 .028 .127 r
F
.40307 .18603 m .40123 .18379 L .40432 .18264 L F
.53782 .18671 m .53929 .1833 L .54098 .18548 L 0 .029 .129 r
F
.53782 .18671 m .53613 .1845 L .53929 .1833 L F
.6517 .18584 m .65335 .18249 L .65492 .18469 L 0 .027 .127 r
F
.6517 .18584 m .65012 .18367 L .65335 .18249 L F
.31323 .18565 m .31432 .18241 L .31626 .1845 L F
.31323 .18565 m .31129 .18355 L .31432 .18241 L F
.44799 .18635 m .44931 .18287 L .4511 .18511 L 0 .028 .128 r
F
.44799 .18635 m .4462 .1841 L .44931 .18287 L F
.72066 .1848 m .72242 .1814 L .72392 .18364 L 0 .026 .124 r
F
.72066 .1848 m .71915 .18256 L .72242 .1814 L F
.59076 .1866 m .59231 .18329 L .59395 .1855 L 0 .029 .129 r
F
.59076 .1866 m .58912 .18438 L .59231 .18329 L F
.76558 .18508 m .76742 .18171 L .76887 .18386 L 0 .026 .125 r
F
.76558 .18508 m .76413 .18294 L .76742 .18171 L F
.456 .18599 m .45733 .18266 L .45911 .18477 L 0 .028 .127 r
F
.456 .18599 m .45421 .18387 L .45733 .18266 L F
.36615 .18555 m .36733 .18236 L .36921 .18446 L 0 .027 .127 r
F
.36615 .18555 m .36427 .18344 L .36733 .18236 L F
.54584 .18647 m .54732 .18315 L .549 .18529 L 0 .029 .129 r
F
.54584 .18647 m .54415 .18431 L .54732 .18315 L F
.41107 .18581 m .41233 .18251 L .41416 .18463 L 0 .028 .127 r
F
.41107 .18581 m .40924 .18368 L .41233 .18251 L F
.32123 .18538 m .32234 .18215 L .32427 .18423 L 0 .027 .126 r
F
.32123 .18538 m .3193 .18333 L .32234 .18215 L F
.46401 .18564 m .46535 .18238 L .46712 .18448 L 0 .028 .127 r
F
.46401 .18564 m .46223 .18355 L .46535 .18238 L F
.7736 .18476 m .77546 .18149 L .7769 .18364 L 0 .026 .125 r
F
.7736 .18476 m .77216 .18264 L .77546 .18149 L F
.4929 .18677 m .4943 .18321 L .49604 .18552 L 0 .029 .129 r
F
.4929 .18677 m .49116 .18445 L .4943 .18321 L F
.2763 .18526 m .27734 .18193 L .27931 .18404 L 0 .027 .126 r
F
.2763 .18526 m .27432 .18315 L .27734 .18193 L F
.65972 .18574 m .66139 .18235 L .66296 .18457 L 0 .028 .127 r
F
.65972 .18574 m .65815 .18353 L .66139 .18235 L F
.41908 .18552 m .42035 .18227 L .42217 .18432 L 0 .027 .127 r
F
.41908 .18552 m .41726 .18345 L .42035 .18227 L F
.59878 .18643 m .60034 .183 L .60197 .18516 L 0 .029 .129 r
F
.59878 .18643 m .59714 .18425 L .60034 .183 L F
.2843 .1849 m .28536 .18157 L .28733 .18366 L 0 .026 .125 r
F
.2843 .1849 m .28233 .18281 L .28536 .18157 L F
.55385 .18625 m .55534 .18275 L .55702 .18498 L 0 .029 .128 r
F
.55385 .18625 m .55217 .18404 L .55534 .18275 L F
.32922 .18521 m .33035 .18196 L .33226 .1841 L 0 .027 .126 r
F
.32922 .18521 m .3273 .18309 L .33035 .18196 L F
.7287 .18477 m .73047 .18141 L .73197 .18366 L 0 .026 .125 r
F
.7287 .18477 m .7272 .18253 L .73047 .18141 L F
.42709 .18524 m .42837 .182 L .43018 .18409 L 0 .027 .126 r
F
.42709 .18524 m .42527 .18316 L .42837 .182 L F
.60679 .18614 m .60837 .1828 L .60999 .18496 L 0 .029 .128 r
F
.60679 .18614 m .60517 .18395 L .60837 .1828 L F
.29231 .18459 m .29338 .18125 L .29533 .18343 L 0 .026 .125 r
F
.29231 .18459 m .29035 .18242 L .29338 .18125 L F
.50091 .1866 m .50232 .18311 L .50405 .18539 L 0 .029 .129 r
F
.50091 .1866 m .49918 .18431 L .50232 .18311 L F
.56187 .18597 m .56337 .18242 L .56504 .18468 L 0 .028 .128 r
F
.56187 .18597 m .56019 .18372 L .56337 .18242 L F
.37414 .18554 m .37534 .18229 L .37721 .18444 L 0 .028 .127 r
F
.37414 .18554 m .37227 .18337 L .37534 .18229 L F
.56988 .18555 m .5714 .18216 L .57306 .18434 L F
.56988 .18555 m .56822 .18338 L .5714 .18216 L F
.66775 .18558 m .66943 .18231 L .67099 .18449 L F
.66775 .18558 m .66619 .1834 L .66943 .18231 L F
.47201 .18561 m .47337 .18227 L .47513 .18451 L F
.47201 .18561 m .47025 .18337 L .47337 .18227 L F
.78165 .18473 m .78352 .18149 L .78496 .18368 L 0 .026 .126 r
F
.78165 .18473 m .78021 .18256 L .78352 .18149 L F
.50893 .18632 m .51035 .18302 L .51207 .18517 L 0 .029 .129 r
F
.50893 .18632 m .5072 .18419 L .51035 .18302 L F
.61481 .18599 m .6164 .18253 L .61802 .18473 L 0 .029 .128 r
F
.61481 .18599 m .6132 .18378 L .6164 .18253 L F
.73673 .18468 m .73852 .18119 L .74001 .18346 L 0 .026 .125 r
F
.73673 .18468 m .73524 .18243 L .73852 .18119 L F
.63085 .18519 m .63246 .18168 L .63406 .18387 L 0 .027 .126 r
F
.63085 .18519 m .62925 .18302 L .63246 .18168 L F
.5779 .18542 m .57943 .18217 L .58109 .18435 L 0 .028 .128 r
F
.5779 .18542 m .57625 .18325 L .57943 .18217 L F
.62283 .18565 m .62443 .18217 L .62604 .18435 L F
.62283 .18565 m .62122 .18346 L .62443 .18217 L F
.38214 .18542 m .38336 .18203 L .38522 .1842 L 0 .028 .127 r
F
.38214 .18542 m .38028 .18327 L .38336 .18203 L F
.51694 .1861 m .51837 .18283 L .52009 .18493 L 0 .029 .129 r
F
.51694 .1861 m .51522 .18402 L .51837 .18283 L F
.43509 .18524 m .43639 .18178 L .43819 .1841 L 0 .027 .127 r
F
.43509 .18524 m .43329 .18294 L .43639 .18178 L F
.30028 .18462 m .30137 .18125 L .30331 .18353 L 0 .026 .125 r
F
.30028 .18462 m .29835 .18234 L .30137 .18125 L F
.3372 .18529 m .33836 .18178 L .34025 .18406 L 0 .027 .127 r
F
.3372 .18529 m .3353 .183 L .33836 .18178 L F
.67578 .18553 m .67748 .1823 L .67903 .1844 L 0 .028 .128 r
F
.67578 .18553 m .67424 .18341 L .67748 .1823 L F
.63886 .18487 m .6405 .18153 L .64209 .18376 L 0 .027 .126 r
F
.63886 .18487 m .63727 .18267 L .6405 .18153 L F
.39015 .18516 m .39138 .18175 L .39323 .18395 L 0 .027 .127 r
F
.39015 .18516 m .3883 .18298 L .39138 .18175 L F
.74477 .1845 m .74657 .18112 L .74805 .18334 L 0 .026 .125 r
F
.74477 .1845 m .74328 .18227 L .74657 .18112 L F
.52495 .18585 m .5264 .18251 L .52811 .18466 L 0 .029 .129 r
F
.52495 .18585 m .52324 .18372 L .5264 .18251 L F
.6838 .1852 m .68551 .18182 L .68704 .1839 L 0 .028 .127 r
F
.6838 .1852 m .68227 .18311 L .68551 .18182 L F
.48002 .18566 m .48139 .18226 L .48315 .18454 L 0 .029 .128 r
F
.48002 .18566 m .47826 .18339 L .48139 .18226 L F
.69182 .1848 m .69354 .18147 L .69507 .18358 L 0 .027 .126 r
F
.69182 .1848 m .69029 .18267 L .69354 .18147 L F
.3452 .18509 m .34637 .1816 L .34826 .18385 L 0 .027 .127 r
F
.3452 .18509 m .34331 .18283 L .34637 .1816 L F
.69984 .18444 m .70158 .18113 L .70309 .18321 L 0 .027 .126 r
F
.69984 .18444 m .69832 .18236 L .70158 .18113 L F
.7528 .18429 m .75462 .181 L .75609 .18313 L 0 .026 .125 r
F
.7528 .18429 m .75133 .18218 L .75462 .181 L F
.39815 .18497 m .3994 .18155 L .40123 .18379 L 0 .027 .127 r
F
.39815 .18497 m .39631 .18274 L .3994 .18155 L F
.35321 .18477 m .35438 .18135 L .35627 .18352 L 0 .027 .126 r
F
.35321 .18477 m .35132 .1826 L .35438 .18135 L F
.70786 .18412 m .70961 .18073 L .71112 .18288 L 0 .026 .125 r
F
.70786 .18412 m .70635 .18198 L .70961 .18073 L F
.58592 .18546 m .58747 .18215 L .58912 .18438 L 0 .029 .128 r
F
.58592 .18546 m .58428 .18325 L .58747 .18215 L F
.53297 .18572 m .53443 .1823 L .53613 .1845 L 0 .029 .129 r
F
.53297 .18572 m .53127 .18348 L .53443 .1823 L F
.6469 .18485 m .64854 .18143 L .65012 .18367 L 0 .027 .127 r
F
.6469 .18485 m .64531 .18264 L .64854 .18143 L F
.44309 .1853 m .44441 .18176 L .4462 .1841 L 0 .028 .128 r
F
.44309 .1853 m .4413 .18296 L .44441 .18176 L F
.30826 .18468 m .30936 .1813 L .31129 .18355 L 0 .027 .126 r
F
.30826 .18468 m .30633 .18241 L .30936 .1813 L F
.71589 .18384 m .71764 .18031 L .71915 .18256 L 0 .025 .124 r
F
.71589 .18384 m .71438 .18159 L .71764 .18031 L F
.36122 .18452 m .36239 .18133 L .36427 .18344 L 0 .027 .127 r
F
.36122 .18452 m .35933 .1824 L .36239 .18133 L F
.76084 .18411 m .76267 .18078 L .76413 .18294 L 0 .026 .125 r
F
.76084 .18411 m .75938 .18196 L .76267 .18078 L F
.48803 .18569 m .48942 .18218 L .49116 .18445 L 0 .029 .129 r
F
.48803 .18569 m .48628 .1834 L .48942 .18218 L F
.54098 .18548 m .54246 .18217 L .54415 .18431 L F
.54098 .18548 m .53929 .1833 L .54246 .18217 L F
.40615 .18485 m .40741 .18148 L .40924 .18368 L 0 .028 .127 r
F
.40615 .18485 m .40432 .18264 L .40741 .18148 L F
.4511 .18511 m .45243 .18165 L .45421 .18387 L 0 .028 .128 r
F
.4511 .18511 m .44931 .18287 L .45243 .18165 L F
.65492 .18469 m .65658 .18131 L .65815 .18353 L 0 .027 .127 r
F
.65492 .18469 m .65335 .18249 L .65658 .18131 L F
.31626 .1845 m .31736 .18122 L .3193 .18333 L F
.31626 .1845 m .31432 .18241 L .31736 .18122 L F
.76887 .18386 m .77071 .18048 L .77216 .18264 L 0 .026 .125 r
F
.76887 .18386 m .76742 .18171 L .77071 .18048 L F
.72392 .18364 m .72569 .18029 L .7272 .18253 L 0 .026 .124 r
F
.72392 .18364 m .72242 .1814 L .72569 .18029 L F
.45911 .18477 m .46045 .18145 L .46223 .18355 L 0 .028 .127 r
F
.45911 .18477 m .45733 .18266 L .46045 .18145 L F
.59395 .1855 m .59551 .18207 L .59714 .18425 L 0 .029 .129 r
F
.59395 .1855 m .59231 .18329 L .59551 .18207 L F
.549 .18529 m .55049 .1819 L .55217 .18404 L F
.549 .18529 m .54732 .18315 L .55049 .1819 L F
.49604 .18552 m .49744 .18201 L .49918 .18431 L F
.49604 .18552 m .4943 .18321 L .49744 .18201 L F
.41416 .18463 m .41543 .18135 L .41726 .18345 L 0 .028 .127 r
F
.41416 .18463 m .41233 .18251 L .41543 .18135 L F
.32427 .18423 m .32538 .18099 L .3273 .18309 L 0 .027 .126 r
F
.32427 .18423 m .32234 .18215 L .32538 .18099 L F
.36921 .18446 m .3704 .18128 L .37227 .18337 L 0 .028 .127 r
F
.36921 .18446 m .36733 .18236 L .3704 .18128 L F
.46712 .18448 m .46848 .18124 L .47025 .18337 L F
.46712 .18448 m .46535 .18238 L .46848 .18124 L F
.27931 .18404 m .28036 .18071 L .28233 .18281 L 0 .027 .126 r
F
.27931 .18404 m .27734 .18193 L .28036 .18071 L F
.60197 .18516 m .60354 .18182 L .60517 .18395 L 0 .029 .128 r
F
.60197 .18516 m .60034 .183 L .60354 .18182 L F
.7769 .18364 m .77877 .1804 L .78021 .18256 L 0 .026 .125 r
F
.7769 .18364 m .77546 .18149 L .77877 .1804 L F
.55702 .18498 m .55852 .18146 L .56019 .18372 L 0 .028 .128 r
F
.55702 .18498 m .55534 .18275 L .55852 .18146 L F
.42217 .18432 m .42345 .18109 L .42527 .18316 L 0 .027 .127 r
F
.42217 .18432 m .42035 .18227 L .42345 .18109 L F
.28733 .18366 m .28839 .18032 L .29035 .18242 L 0 .026 .125 r
F
.28733 .18366 m .28536 .18157 L .28839 .18032 L F
.66296 .18457 m .66463 .18118 L .66619 .1834 L 0 .028 .127 r
F
.66296 .18457 m .66139 .18235 L .66463 .18118 L F
.56504 .18468 m .56655 .18112 L .56822 .18338 L F
.56504 .18468 m .56337 .18242 L .56655 .18112 L F
.50405 .18539 m .50547 .18192 L .5072 .18419 L 0 .029 .129 r
F
.50405 .18539 m .50232 .18311 L .50547 .18192 L F
.60999 .18496 m .61158 .18165 L .6132 .18378 L 0 .029 .128 r
F
.60999 .18496 m .60837 .1828 L .61158 .18165 L F
.43018 .18409 m .43148 .18082 L .43329 .18294 L 0 .027 .127 r
F
.43018 .18409 m .42837 .182 L .43148 .18082 L F
.29533 .18343 m .2964 .18016 L .29835 .18234 L 0 .026 .125 r
F
.29533 .18343 m .29338 .18125 L .2964 .18016 L F
.73197 .18366 m .73375 .18017 L .73524 .18243 L F
.73197 .18366 m .73047 .18141 L .73375 .18017 L F
.33226 .1841 m .33339 .18084 L .3353 .183 L 0 .027 .127 r
F
.33226 .1841 m .33035 .18196 L .33339 .18084 L F
.57306 .18434 m .57459 .18105 L .57625 .18325 L 0 .028 .127 r
F
.57306 .18434 m .5714 .18216 L .57459 .18105 L F
.37721 .18444 m .37842 .18112 L .38028 .18327 L F
.37721 .18444 m .37534 .18229 L .37842 .18112 L F
.67099 .18449 m .67268 .18124 L .67424 .18341 L 0 .028 .128 r
F
.67099 .18449 m .66943 .18231 L .67268 .18124 L F
.51207 .18517 m .5135 .18184 L .51522 .18402 L 0 .029 .129 r
F
.51207 .18517 m .51035 .18302 L .5135 .18184 L F
.61802 .18473 m .61961 .18126 L .62122 .18346 L 0 .028 .128 r
F
.61802 .18473 m .6164 .18253 L .61961 .18126 L F
.47513 .18451 m .4765 .18113 L .47826 .18339 L F
.47513 .18451 m .47337 .18227 L .4765 .18113 L F
.63406 .18387 m .63568 .18047 L .63727 .18267 L 0 .027 .126 r
F
.63406 .18387 m .63246 .18168 L .63568 .18047 L F
.74001 .18346 m .7418 .18 L .74328 .18227 L 0 .026 .125 r
F
.74001 .18346 m .73852 .18119 L .7418 .18 L F
.62604 .18435 m .62765 .18085 L .62925 .18302 L 0 .028 .127 r
F
.62604 .18435 m .62443 .18217 L .62765 .18085 L F
.38522 .1842 m .38644 .18079 L .3883 .18298 L F
.38522 .1842 m .38336 .18203 L .38644 .18079 L F
.52009 .18493 m .52153 .18159 L .52324 .18372 L 0 .029 .129 r
F
.52009 .18493 m .51837 .18283 L .52153 .18159 L F
.34025 .18406 m .34141 .18056 L .34331 .18283 L 0 .027 .127 r
F
.34025 .18406 m .33836 .18178 L .34141 .18056 L F
.43819 .1841 m .4395 .18061 L .4413 .18296 L F
.43819 .1841 m .43639 .18178 L .4395 .18061 L F
.58109 .18435 m .58263 .18104 L .58428 .18325 L 0 .028 .128 r
F
.58109 .18435 m .57943 .18217 L .58263 .18104 L F
.68704 .1839 m .68876 .18059 L .69029 .18267 L 0 .027 .127 r
F
.68704 .1839 m .68551 .18182 L .68876 .18059 L F
.39323 .18395 m .39446 .18053 L .39631 .18274 L F
.39323 .18395 m .39138 .18175 L .39446 .18053 L F
.67903 .1844 m .68072 .18102 L .68227 .18311 L 0 .028 .128 r
F
.67903 .1844 m .67748 .1823 L .68072 .18102 L F
.30331 .18353 m .3044 .18014 L .30633 .18241 L 0 .027 .126 r
F
.30331 .18353 m .30137 .18125 L .3044 .18014 L F
.64209 .18376 m .64373 .18039 L .64531 .18264 L F
.64209 .18376 m .6405 .18153 L .64373 .18039 L F
.52811 .18466 m .52956 .18134 L .53127 .18348 L 0 .029 .129 r
F
.52811 .18466 m .5264 .18251 L .52956 .18134 L F
.74805 .18334 m .74986 .17997 L .75133 .18218 L 0 .026 .125 r
F
.74805 .18334 m .74657 .18112 L .74986 .17997 L F
.69507 .18358 m .6968 .18028 L .69832 .18236 L 0 .027 .126 r
F
.69507 .18358 m .69354 .18147 L .6968 .18028 L F
.34826 .18385 m .34943 .18035 L .35132 .1826 L F
.34826 .18385 m .34637 .1816 L .34943 .18035 L F
.70309 .18321 m .70483 .17989 L .70635 .18198 L 0 .026 .125 r
F
.70309 .18321 m .70158 .18113 L .70483 .17989 L F
.48315 .18454 m .48453 .18111 L .48628 .1834 L 0 .029 .128 r
F
.48315 .18454 m .48139 .18226 L .48453 .18111 L F
.35627 .18352 m .35744 .18022 L .35933 .1824 L 0 .027 .126 r
F
.35627 .18352 m .35438 .18135 L .35744 .18022 L F
.71112 .18288 m .71287 .17945 L .71438 .18159 L 0 .026 .125 r
F
.71112 .18288 m .70961 .18073 L .71287 .17945 L F
.40123 .18379 m .40248 .18042 L .40432 .18264 L 0 .027 .127 r
F
.40123 .18379 m .3994 .18155 L .40248 .18042 L F
.75609 .18313 m .75791 .17981 L .75938 .18196 L 0 .026 .125 r
F
.75609 .18313 m .75462 .181 L .75791 .17981 L F
.53613 .1845 m .53759 .18113 L .53929 .1833 L 0 .029 .129 r
F
.53613 .1845 m .53443 .1823 L .53759 .18113 L F
.4462 .1841 m .44752 .18056 L .44931 .18287 L 0 .028 .127 r
F
.4462 .1841 m .44441 .18176 L .44752 .18056 L F
.71915 .18256 m .72091 .17916 L .72242 .1814 L 0 .025 .124 r
F
.71915 .18256 m .71764 .18031 L .72091 .17916 L F
.65012 .18367 m .65177 .18022 L .65335 .18249 L 0 .027 .127 r
F
.65012 .18367 m .64854 .18143 L .65177 .18022 L F
.58912 .18438 m .59067 .18103 L .59231 .18329 L 0 .029 .129 r
F
.58912 .18438 m .58747 .18215 L .59067 .18103 L F
.31129 .18355 m .3124 .18016 L .31432 .18241 L 0 .027 .127 r
F
.31129 .18355 m .30936 .1813 L .3124 .18016 L F
.49116 .18445 m .49256 .18096 L .4943 .18321 L 0 .029 .129 r
F
.49116 .18445 m .48942 .18218 L .49256 .18096 L F
.76413 .18294 m .76596 .17954 L .76742 .18171 L 0 .026 .125 r
F
.76413 .18294 m .76267 .18078 L .76596 .17954 L F
.54415 .18431 m .54563 .18103 L .54732 .18315 L 0 .029 .129 r
F
.54415 .18431 m .54246 .18217 L .54563 .18103 L F
.45421 .18387 m .45555 .18046 L .45733 .18266 L 0 .028 .127 r
F
.45421 .18387 m .45243 .18165 L .45555 .18046 L F
.36427 .18344 m .36545 .18025 L .36733 .18236 L 0 .027 .127 r
F
.36427 .18344 m .36239 .18133 L .36545 .18025 L F
.40924 .18368 m .4105 .18033 L .41233 .18251 L 0 .028 .127 r
F
.40924 .18368 m .40741 .18148 L .4105 .18033 L F
.77216 .18264 m .77401 .17932 L .77546 .18149 L 0 .026 .125 r
F
.77216 .18264 m .77071 .18048 L .77401 .17932 L F
.65815 .18353 m .65982 .18013 L .66139 .18235 L 0 .027 .127 r
F
.65815 .18353 m .65658 .18131 L .65982 .18013 L F
.46223 .18355 m .46358 .18027 L .46535 .18238 L 0 .028 .127 r
F
.46223 .18355 m .46045 .18145 L .46358 .18027 L F
.3193 .18333 m .32041 .18002 L .32234 .18215 L 0 .027 .127 r
F
.3193 .18333 m .31736 .18122 L .32041 .18002 L F
.59714 .18425 m .59871 .18085 L .60034 .183 L 0 .029 .129 r
F
.59714 .18425 m .59551 .18207 L .59871 .18085 L F
.55217 .18404 m .55366 .1806 L .55534 .18275 L 0 .028 .128 r
F
.55217 .18404 m .55049 .1819 L .55366 .1806 L F
.49918 .18431 m .50059 .18083 L .50232 .18311 L 0 .029 .129 r
F
.49918 .18431 m .49744 .18201 L .50059 .18083 L F
.7272 .18253 m .72897 .17917 L .73047 .18141 L 0 .026 .125 r
F
.7272 .18253 m .72569 .18029 L .72897 .17917 L F
.41726 .18345 m .41853 .18018 L .42035 .18227 L 0 .028 .127 r
F
.41726 .18345 m .41543 .18135 L .41853 .18018 L F
.28233 .18281 m .28339 .17947 L .28536 .18157 L 0 .026 .126 r
F
.28233 .18281 m .28036 .18071 L .28339 .17947 L F
.56019 .18372 m .5617 .18016 L .56337 .18242 L 0 .028 .127 r
F
.56019 .18372 m .55852 .18146 L .5617 .18016 L F
.60517 .18395 m .60675 .1807 L .60837 .1828 L 0 .029 .128 r
F
.60517 .18395 m .60354 .18182 L .60675 .1807 L F
.3273 .18309 m .32842 .17984 L .33035 .18196 L 0 .027 .126 r
F
.3273 .18309 m .32538 .18099 L .32842 .17984 L F
.29035 .18242 m .29141 .17914 L .29338 .18125 L 0 .026 .125 r
F
.29035 .18242 m .28839 .18032 L .29141 .17914 L F
.47025 .18337 m .4716 .18011 L .47337 .18227 L 0 .028 .127 r
F
.47025 .18337 m .46848 .18124 L .4716 .18011 L F
.37227 .18337 m .37347 .18019 L .37534 .18229 L F
.37227 .18337 m .3704 .18128 L .37347 .18019 L F
.56822 .18338 m .56974 .17989 L .5714 .18216 L 0 .027 .127 r
F
.56822 .18338 m .56655 .18112 L .56974 .17989 L F
.42527 .18316 m .42655 .1799 L .42837 .182 L F
.42527 .18316 m .42345 .18109 L .42655 .1799 L F
.66619 .1834 m .66787 .18007 L .66943 .18231 L 0 .028 .127 r
F
.66619 .1834 m .66463 .18118 L .66787 .18007 L F
.78021 .18256 m .78208 .1793 L .78352 .18149 L 0 .026 .125 r
F
.78021 .18256 m .77877 .1804 L .78208 .1793 L F
.5072 .18419 m .50862 .18073 L .51035 .18302 L 0 .029 .129 r
F
.5072 .18419 m .50547 .18192 L .50862 .18073 L F
.73524 .18243 m .73702 .17893 L .73852 .18119 L 0 .026 .125 r
F
.73524 .18243 m .73375 .18017 L .73702 .17893 L F
.6132 .18378 m .61479 .18039 L .6164 .18253 L 0 .029 .128 r
F
.6132 .18378 m .61158 .18165 L .61479 .18039 L F
.43329 .18294 m .43458 .17964 L .43639 .18178 L 0 .027 .127 r
F
.43329 .18294 m .43148 .18082 L .43458 .17964 L F
.3353 .183 m .33644 .17964 L .33836 .18178 L F
.3353 .183 m .33339 .18084 L .33644 .17964 L F
.29835 .18234 m .29942 .17907 L .30137 .18125 L 0 .026 .125 r
F
.29835 .18234 m .2964 .18016 L .29942 .17907 L F
.62122 .18346 m .62283 .17999 L .62443 .18217 L 0 .028 .127 r
F
.62122 .18346 m .61961 .18126 L .62283 .17999 L F
.62925 .18302 m .63086 .17954 L .63246 .18168 L 0 .027 .126 r
F
.62925 .18302 m .62765 .18085 L .63086 .17954 L F
.57625 .18325 m .57778 .17995 L .57943 .18217 L 0 .028 .127 r
F
.57625 .18325 m .57459 .18105 L .57778 .17995 L F
.38028 .18327 m .3815 .17986 L .38336 .18203 L F
.38028 .18327 m .37842 .18112 L .3815 .17986 L F
.63727 .18267 m .63891 .17932 L .6405 .18153 L 0 .027 .126 r
F
.63727 .18267 m .63568 .18047 L .63891 .17932 L F
.51522 .18402 m .51665 .18063 L .51837 .18283 L 0 .029 .129 r
F
.51522 .18402 m .5135 .18184 L .51665 .18063 L F
.74328 .18227 m .74509 .17886 L .74657 .18112 L 0 .026 .125 r
F
.74328 .18227 m .7418 .18 L .74509 .17886 L F
.47826 .18339 m .47964 .17998 L .48139 .18226 L 0 .028 .128 r
F
.47826 .18339 m .4765 .18113 L .47964 .17998 L F
.67424 .18341 m .67593 .18013 L .67748 .1823 L F
.67424 .18341 m .67268 .18124 L .67593 .18013 L F
.3883 .18298 m .38953 .17955 L .39138 .18175 L 0 .027 .127 r
F
.3883 .18298 m .38644 .18079 L .38953 .17955 L F
.34331 .18283 m .34447 .17934 L .34637 .1816 L 0 .027 .126 r
F
.34331 .18283 m .34141 .18056 L .34447 .17934 L F
.52324 .18372 m .52469 .18036 L .5264 .18251 L 0 .029 .129 r
F
.52324 .18372 m .52153 .18159 L .52469 .18036 L F
.69029 .18267 m .69201 .1794 L .69354 .18147 L 0 .027 .127 r
F
.69029 .18267 m .68876 .18059 L .69201 .1794 L F
.68227 .18311 m .68397 .17974 L .68551 .18182 L 0 .028 .127 r
F
.68227 .18311 m .68072 .18102 L .68397 .17974 L F
.4413 .18296 m .44261 .17943 L .44441 .18176 L 0 .027 .127 r
F
.4413 .18296 m .4395 .18061 L .44261 .17943 L F
.39631 .18274 m .39755 .17933 L .3994 .18155 L F
.39631 .18274 m .39446 .18053 L .39755 .17933 L F
.69832 .18236 m .70005 .17904 L .70158 .18113 L 0 .027 .126 r
F
.69832 .18236 m .6968 .18028 L .70005 .17904 L F
.58428 .18325 m .58582 .1799 L .58747 .18215 L 0 .028 .128 r
F
.58428 .18325 m .58263 .18104 L .58582 .1799 L F
.53127 .18348 m .53273 .18018 L .53443 .1823 L 0 .029 .129 r
F
.53127 .18348 m .52956 .18134 L .53273 .18018 L F
.35132 .1826 m .35249 .17911 L .35438 .18135 L 0 .027 .126 r
F
.35132 .1826 m .34943 .18035 L .35249 .17911 L F
.75133 .18218 m .75315 .17879 L .75462 .181 L 0 .026 .125 r
F
.75133 .18218 m .74986 .17997 L .75315 .17879 L F
.30633 .18241 m .30743 .17904 L .30936 .1813 L 0 .027 .126 r
F
.30633 .18241 m .3044 .18014 L .30743 .17904 L F
.64531 .18264 m .64695 .17916 L .64854 .18143 L F
.64531 .18264 m .64373 .18039 L .64695 .17916 L F
.70635 .18198 m .70809 .17864 L .70961 .18073 L 0 .026 .125 r
F
.70635 .18198 m .70483 .17989 L .70809 .17864 L F
.71438 .18159 m .71613 .17817 L .71764 .18031 L 0 .025 .124 r
F
.71438 .18159 m .71287 .17945 L .71613 .17817 L F
.48628 .1834 m .48767 .17992 L .48942 .18218 L 0 .029 .128 r
F
.48628 .1834 m .48453 .18111 L .48767 .17992 L F
.35933 .1824 m .36051 .17914 L .36239 .18133 L 0 .027 .127 r
F
.35933 .1824 m .35744 .18022 L .36051 .17914 L F
.75938 .18196 m .76121 .17861 L .76267 .18078 L 0 .026 .125 r
F
.75938 .18196 m .75791 .17981 L .76121 .17861 L F
.53929 .1833 m .54076 .18002 L .54246 .18217 L 0 .029 .129 r
F
.53929 .1833 m .53759 .18113 L .54076 .18002 L F
.40432 .18264 m .40557 .17928 L .40741 .18148 L 0 .028 .127 r
F
.40432 .18264 m .40248 .18042 L .40557 .17928 L F
.44931 .18287 m .45064 .17935 L .45243 .18165 L F
.44931 .18287 m .44752 .18056 L .45064 .17935 L F
.65335 .18249 m .655 .17903 L .65658 .18131 L 0 .027 .127 r
F
.65335 .18249 m .65177 .18022 L .655 .17903 L F
.72242 .1814 m .72419 .17805 L .72569 .18029 L 0 .025 .124 r
F
.72242 .1814 m .72091 .17916 L .72419 .17805 L F
.4943 .18321 m .4957 .17979 L .49744 .18201 L 0 .029 .128 r
F
.4943 .18321 m .49256 .18096 L .4957 .17979 L F
.76742 .18171 m .76926 .17829 L .77071 .18048 L 0 .026 .125 r
F
.76742 .18171 m .76596 .17954 L .76926 .17829 L F
.59231 .18329 m .59387 .17981 L .59551 .18207 L 0 .029 .129 r
F
.59231 .18329 m .59067 .18103 L .59387 .17981 L F
.31432 .18241 m .31544 .17895 L .31736 .18122 L 0 .027 .127 r
F
.31432 .18241 m .3124 .18016 L .31544 .17895 L F
.45733 .18266 m .45867 .17926 L .46045 .18145 L 0 .028 .127 r
F
.45733 .18266 m .45555 .18046 L .45867 .17926 L F
.54732 .18315 m .5488 .17979 L .55049 .1819 L 0 .029 .129 r
F
.54732 .18315 m .54563 .18103 L .5488 .17979 L F
.41233 .18251 m .4136 .17919 L .41543 .18135 L 0 .028 .127 r
F
.41233 .18251 m .4105 .18033 L .4136 .17919 L F
.55534 .18275 m .55684 .1793 L .55852 .18146 L 0 .028 .128 r
F
.55534 .18275 m .55366 .1806 L .55684 .1793 L F
.60034 .183 m .60191 .17969 L .60354 .18182 L 0 .029 .129 r
F
.60034 .183 m .59871 .18085 L .60191 .17969 L F
.66139 .18235 m .66306 .17895 L .66463 .18118 L 0 .027 .127 r
F
.66139 .18235 m .65982 .18013 L .66306 .17895 L F
.36733 .18236 m .36852 .17917 L .3704 .18128 L 0 .028 .127 r
F
.36733 .18236 m .36545 .18025 L .36852 .17917 L F
.32234 .18215 m .32345 .17884 L .32538 .18099 L 0 .027 .127 r
F
.32234 .18215 m .32041 .18002 L .32345 .17884 L F
.46535 .18238 m .4667 .17911 L .46848 .18124 L 0 .028 .127 r
F
.46535 .18238 m .46358 .18027 L .4667 .17911 L F
.77546 .18149 m .77732 .1782 L .77877 .1804 L 0 .026 .125 r
F
.77546 .18149 m .77401 .17932 L .77732 .1782 L F
.56337 .18242 m .56488 .17886 L .56655 .18112 L 0 .027 .127 r
F
.56337 .18242 m .5617 .18016 L .56488 .17886 L F
.50232 .18311 m .50374 .17965 L .50547 .18192 L 0 .029 .129 r
F
.50232 .18311 m .50059 .18083 L .50374 .17965 L F
.28536 .18157 m .28642 .17822 L .28839 .18032 L 0 .026 .125 r
F
.28536 .18157 m .28339 .17947 L .28642 .17822 L F
.42035 .18227 m .42163 .17898 L .42345 .18109 L 0 .028 .127 r
F
.42035 .18227 m .41853 .18018 L .42163 .17898 L F
.73047 .18141 m .73225 .17794 L .73375 .18017 L 0 .026 .125 r
F
.73047 .18141 m .72897 .17917 L .73225 .17794 L F
.60837 .1828 m .60996 .17957 L .61158 .18165 L 0 .029 .129 r
F
.60837 .1828 m .60675 .1807 L .60996 .17957 L F
.29338 .18125 m .29444 .17805 L .2964 .18016 L 0 .026 .125 r
F
.29338 .18125 m .29141 .17914 L .29444 .17805 L F
.5714 .18216 m .57292 .17877 L .57459 .18105 L 0 .027 .127 r
F
.5714 .18216 m .56974 .17989 L .57292 .17877 L F
.33035 .18196 m .33147 .17869 L .33339 .18084 L F
.33035 .18196 m .32842 .17984 L .33147 .17869 L F
.42837 .182 m .42966 .17871 L .43148 .18082 L F
.42837 .182 m .42655 .1799 L .42966 .17871 L F
.47337 .18227 m .47474 .17893 L .4765 .18113 L 0 .028 .127 r
F
.47337 .18227 m .4716 .18011 L .47474 .17893 L F
.37534 .18229 m .37654 .17902 L .37842 .18112 L 0 .028 .128 r
F
.37534 .18229 m .37347 .18019 L .37654 .17902 L F
.73852 .18119 m .74031 .17774 L .7418 .18 L 0 .026 .125 r
F
.73852 .18119 m .73702 .17893 L .74031 .17774 L F
.6164 .18253 m .618 .17912 L .61961 .18126 L 0 .028 .128 r
F
.6164 .18253 m .61479 .18039 L .618 .17912 L F
.66943 .18231 m .67112 .17899 L .67268 .18124 L F
.66943 .18231 m .66787 .18007 L .67112 .17899 L F
.51035 .18302 m .51177 .17954 L .5135 .18184 L 0 .029 .129 r
F
.51035 .18302 m .50862 .18073 L .51177 .17954 L F
.63246 .18168 m .63408 .17833 L .63568 .18047 L 0 .027 .126 r
F
.63246 .18168 m .63086 .17954 L .63408 .17833 L F
.62443 .18217 m .62604 .17869 L .62765 .18085 L 0 .028 .127 r
F
.62443 .18217 m .62283 .17999 L .62604 .17869 L F
.43639 .18178 m .4377 .17845 L .4395 .18061 L 0 .027 .126 r
F
.43639 .18178 m .43458 .17964 L .4377 .17845 L F
.33836 .18178 m .3395 .17843 L .34141 .18056 L F
.33836 .18178 m .33644 .17964 L .3395 .17843 L F
.38336 .18203 m .38458 .17861 L .38644 .18079 L 0 .028 .127 r
F
.38336 .18203 m .3815 .17986 L .38458 .17861 L F
.30137 .18125 m .30245 .17797 L .3044 .18014 L 0 .026 .126 r
F
.30137 .18125 m .29942 .17907 L .30245 .17797 L F
.51837 .18283 m .51981 .17938 L .52153 .18159 L 0 .029 .129 r
F
.51837 .18283 m .51665 .18063 L .51981 .17938 L F
.57943 .18217 m .58097 .1788 L .58263 .18104 L 0 .028 .128 r
F
.57943 .18217 m .57778 .17995 L .58097 .1788 L F
.39138 .18175 m .39261 .17831 L .39446 .18053 L 0 .027 .127 r
F
.39138 .18175 m .38953 .17955 L .39261 .17831 L F
.6405 .18153 m .64214 .17816 L .64373 .18039 L 0 .027 .126 r
F
.6405 .18153 m .63891 .17932 L .64214 .17816 L F
.74657 .18112 m .74838 .17773 L .74986 .17997 L 0 .026 .125 r
F
.74657 .18112 m .74509 .17886 L .74838 .17773 L F
.48139 .18226 m .48277 .17883 L .48453 .18111 L 0 .028 .128 r
F
.48139 .18226 m .47964 .17998 L .48277 .17883 L F
.34637 .1816 m .34753 .1781 L .34943 .18035 L 0 .027 .126 r
F
.34637 .1816 m .34447 .17934 L .34753 .1781 L F
.68551 .18182 m .68722 .17851 L .68876 .18059 L 0 .028 .127 r
F
.68551 .18182 m .68397 .17974 L .68722 .17851 L F
.5264 .18251 m .52785 .1792 L .52956 .18134 L 0 .029 .129 r
F
.5264 .18251 m .52469 .18036 L .52785 .1792 L F
.67748 .1823 m .67918 .17886 L .68072 .18102 L 0 .028 .128 r
F
.67748 .1823 m .67593 .18013 L .67918 .17886 L F
.69354 .18147 m .69527 .17821 L .6968 .18028 L 0 .027 .126 r
F
.69354 .18147 m .69201 .1794 L .69527 .17821 L F
.44441 .18176 m .44573 .17823 L .44752 .18056 L 0 .027 .127 r
F
.44441 .18176 m .44261 .17943 L .44573 .17823 L F
.3994 .18155 m .40064 .1782 L .40248 .18042 L F
.3994 .18155 m .39755 .17933 L .40064 .1782 L F
.35438 .18135 m .35556 .17798 L .35744 .18022 L 0 .027 .126 r
F
.35438 .18135 m .35249 .17911 L .35556 .17798 L F
.70158 .18113 m .70332 .1778 L .70483 .17989 L F
.70158 .18113 m .70005 .17904 L .70332 .1778 L F
.70961 .18073 m .71136 .17736 L .71287 .17945 L 0 .026 .125 r
F
.70961 .18073 m .70809 .17864 L .71136 .17736 L F
.53443 .1823 m .53589 .17902 L .53759 .18113 L 0 .029 .129 r
F
.53443 .1823 m .53273 .18018 L .53589 .17902 L F
.71764 .18031 m .7194 .177 L .72091 .17916 L 0 .025 .124 r
F
.71764 .18031 m .71613 .17817 L .7194 .177 L F
.64854 .18143 m .65018 .17793 L .65177 .18022 L 0 .027 .126 r
F
.64854 .18143 m .64695 .17916 L .65018 .17793 L F
.75462 .181 m .75644 .1776 L .75791 .17981 L 0 .026 .125 r
F
.75462 .181 m .75315 .17879 L .75644 .1776 L F
.58747 .18215 m .58902 .17875 L .59067 .18103 L 0 .029 .128 r
F
.58747 .18215 m .58582 .1799 L .58902 .17875 L F
.48942 .18218 m .49081 .17872 L .49256 .18096 L 0 .028 .128 r
F
.48942 .18218 m .48767 .17992 L .49081 .17872 L F
.30936 .1813 m .31046 .1779 L .3124 .18016 L 0 .027 .126 r
F
.30936 .1813 m .30743 .17904 L .31046 .1779 L F
.45243 .18165 m .45376 .17817 L .45555 .18046 L 0 .028 .127 r
F
.45243 .18165 m .45064 .17935 L .45376 .17817 L F
.76267 .18078 m .7645 .17735 L .76596 .17954 L 0 .026 .125 r
F
.76267 .18078 m .76121 .17861 L .7645 .17735 L F
.40741 .18148 m .40867 .17815 L .4105 .18033 L 0 .028 .127 r
F
.40741 .18148 m .40557 .17928 L .40867 .17815 L F
.54246 .18217 m .54394 .17891 L .54563 .18103 L 0 .029 .129 r
F
.54246 .18217 m .54076 .18002 L .54394 .17891 L F
.65658 .18131 m .65824 .17785 L .65982 .18013 L 0 .027 .126 r
F
.65658 .18131 m .655 .17903 L .65824 .17785 L F
.36239 .18133 m .36357 .17806 L .36545 .18025 L 0 .028 .127 r
F
.36239 .18133 m .36051 .17914 L .36357 .17806 L F
.49744 .18201 m .49885 .17863 L .50059 .18083 L 0 .029 .128 r
F
.49744 .18201 m .4957 .17979 L .49885 .17863 L F
.77071 .18048 m .77256 .17711 L .77401 .17932 L 0 .026 .125 r
F
.77071 .18048 m .76926 .17829 L .77256 .17711 L F
.59551 .18207 m .59707 .17859 L .59871 .18085 L 0 .029 .128 r
F
.59551 .18207 m .59387 .17981 L .59707 .17859 L F
.72569 .18029 m .72747 .17693 L .72897 .17917 L 0 .026 .124 r
F
.72569 .18029 m .72419 .17805 L .72747 .17693 L F
.31736 .18122 m .31848 .17773 L .32041 .18002 L 0 .027 .126 r
F
.31736 .18122 m .31544 .17895 L .31848 .17773 L F
.46045 .18145 m .4618 .17807 L .46358 .18027 L 0 .028 .127 r
F
.46045 .18145 m .45867 .17926 L .4618 .17807 L F
.55049 .1819 m .55198 .17849 L .55366 .1806 L 0 .029 .128 r
F
.55049 .1819 m .5488 .17979 L .55198 .17849 L F
.55852 .18146 m .56002 .178 L .5617 .18016 L 0 .028 .127 r
F
.55852 .18146 m .55684 .1793 L .56002 .178 L F
.56655 .18112 m .56807 .17762 L .56974 .17989 L 0 .027 .126 r
F
.56655 .18112 m .56488 .17886 L .56807 .17762 L F
.41543 .18135 m .4167 .17804 L .41853 .18018 L 0 .028 .127 r
F
.41543 .18135 m .4136 .17919 L .4167 .17804 L F
.60354 .18182 m .60513 .17859 L .60675 .1807 L 0 .029 .129 r
F
.60354 .18182 m .60191 .17969 L .60513 .17859 L F
.66463 .18118 m .6663 .17783 L .66787 .18007 L 0 .028 .127 r
F
.66463 .18118 m .66306 .17895 L .6663 .17783 L F
.28839 .18032 m .28945 .17703 L .29141 .17914 L 0 .026 .125 r
F
.28839 .18032 m .28642 .17822 L .28945 .17703 L F
.32538 .18099 m .3265 .17767 L .32842 .17984 L 0 .027 .127 r
F
.32538 .18099 m .32345 .17884 L .3265 .17767 L F
.46848 .18124 m .46983 .17794 L .4716 .18011 L 0 .028 .127 r
F
.46848 .18124 m .4667 .17911 L .46983 .17794 L F
.50547 .18192 m .50689 .17844 L .50862 .18073 L 0 .029 .129 r
F
.50547 .18192 m .50374 .17965 L .50689 .17844 L F
.3704 .18128 m .37159 .17809 L .37347 .18019 L 0 .028 .128 r
F
.3704 .18128 m .36852 .17917 L .37159 .17809 L F
.73375 .18017 m .73553 .1767 L .73702 .17893 L 0 .026 .124 r
F
.73375 .18017 m .73225 .17794 L .73553 .1767 L F
.77877 .1804 m .78064 .17708 L .78208 .1793 L 0 .026 .125 r
F
.77877 .1804 m .77732 .1782 L .78064 .17708 L F
.42345 .18109 m .42473 .17778 L .42655 .1799 L 0 .028 .127 r
F
.42345 .18109 m .42163 .17898 L .42473 .17778 L F
.61158 .18165 m .61317 .17831 L .61479 .18039 L 0 .029 .128 r
F
.61158 .18165 m .60996 .17957 L .61317 .17831 L F
.61961 .18126 m .62122 .17785 L .62283 .17999 L 0 .028 .127 r
F
.61961 .18126 m .618 .17912 L .62122 .17785 L F
.43148 .18082 m .43277 .17751 L .43458 .17964 L 0 .027 .127 r
F
.43148 .18082 m .42966 .17871 L .43277 .17751 L F
.2964 .18016 m .29746 .17696 L .29942 .17907 L 0 .026 .125 r
F
.2964 .18016 m .29444 .17805 L .29746 .17696 L F
.57459 .18105 m .57612 .17765 L .57778 .17995 L 0 .028 .127 r
F
.57459 .18105 m .57292 .17877 L .57612 .17765 L F
.33339 .18084 m .33453 .17751 L .33644 .17964 L 0 .027 .127 r
F
.33339 .18084 m .33147 .17869 L .33453 .17751 L F
.62765 .18085 m .62926 .17739 L .63086 .17954 L 0 .027 .126 r
F
.62765 .18085 m .62604 .17869 L .62926 .17739 L F
.7418 .18 m .7436 .17662 L .74509 .17886 L 0 .026 .125 r
F
.7418 .18 m .74031 .17774 L .7436 .17662 L F
.37842 .18112 m .37963 .17776 L .3815 .17986 L 0 .028 .127 r
F
.37842 .18112 m .37654 .17902 L .37963 .17776 L F
.4765 .18113 m .47787 .17775 L .47964 .17998 L F
.4765 .18113 m .47474 .17893 L .47787 .17775 L F
.63568 .18047 m .63731 .17718 L .63891 .17932 L 0 .027 .126 r
F
.63568 .18047 m .63408 .17833 L .63731 .17718 L F
.5135 .18184 m .51493 .17831 L .51665 .18063 L 0 .029 .129 r
F
.5135 .18184 m .51177 .17954 L .51493 .17831 L F
.34141 .18056 m .34256 .17722 L .34447 .17934 L 0 .027 .126 r
F
.34141 .18056 m .3395 .17843 L .34256 .17722 L F
.38644 .18079 m .38767 .17736 L .38953 .17955 L 0 .027 .127 r
F
.38644 .18079 m .38458 .17861 L .38767 .17736 L F
.67268 .18124 m .67437 .17786 L .67593 .18013 L 0 .028 .128 r
F
.67268 .18124 m .67112 .17899 L .67437 .17786 L F
.4395 .18061 m .44081 .17728 L .44261 .17943 L 0 .027 .126 r
F
.4395 .18061 m .4377 .17845 L .44081 .17728 L F
.52153 .18159 m .52297 .17812 L .52469 .18036 L 0 .029 .129 r
F
.52153 .18159 m .51981 .17938 L .52297 .17812 L F
.39446 .18053 m .39571 .17711 L .39755 .17933 L 0 .027 .126 r
F
.39446 .18053 m .39261 .17831 L .39571 .17711 L F
.68072 .18102 m .68243 .17758 L .68397 .17974 L 0 .028 .128 r
F
.68072 .18102 m .67918 .17886 L .68243 .17758 L F
.34943 .18035 m .3506 .17687 L .35249 .17911 L 0 .027 .126 r
F
.34943 .18035 m .34753 .1781 L .3506 .17687 L F
.68876 .18059 m .69048 .17732 L .69201 .1794 L 0 .027 .127 r
F
.68876 .18059 m .68722 .17851 L .69048 .17732 L F
.3044 .18014 m .30548 .17687 L .30743 .17904 L 0 .027 .126 r
F
.3044 .18014 m .30245 .17797 L .30548 .17687 L F
.58263 .18104 m .58417 .17763 L .58582 .1799 L 0 .028 .128 r
F
.58263 .18104 m .58097 .1788 L .58417 .17763 L F
.64373 .18039 m .64536 .1769 L .64695 .17916 L 0 .027 .126 r
F
.64373 .18039 m .64214 .17816 L .64536 .1769 L F
.74986 .17997 m .75167 .17656 L .75315 .17879 L 0 .026 .125 r
F
.74986 .17997 m .74838 .17773 L .75167 .17656 L F
.48453 .18111 m .48591 .17766 L .48767 .17992 L 0 .028 .128 r
F
.48453 .18111 m .48277 .17883 L .48591 .17766 L F
.52956 .18134 m .53102 .17805 L .53273 .18018 L 0 .029 .129 r
F
.52956 .18134 m .52785 .1792 L .53102 .17805 L F
.6968 .18028 m .69853 .17695 L .70005 .17904 L 0 .027 .126 r
F
.6968 .18028 m .69527 .17821 L .69853 .17695 L F
.44752 .18056 m .44885 .17705 L .45064 .17935 L 0 .027 .127 r
F
.44752 .18056 m .44573 .17823 L .44885 .17705 L F
.70483 .17989 m .70658 .17655 L .70809 .17864 L 0 .026 .125 r
F
.70483 .17989 m .70332 .1778 L .70658 .17655 L F
.71287 .17945 m .71462 .17608 L .71613 .17817 L 0 .025 .124 r
F
.71287 .17945 m .71136 .17736 L .71462 .17608 L F
.40248 .18042 m .40373 .17708 L .40557 .17928 L 0 .027 .127 r
F
.40248 .18042 m .40064 .1782 L .40373 .17708 L F
.35744 .18022 m .35862 .17688 L .36051 .17914 L 0 .027 .126 r
F
.35744 .18022 m .35556 .17798 L .35862 .17688 L F
.65177 .18022 m .65342 .17672 L .655 .17903 L F
.65177 .18022 m .65018 .17793 L .65342 .17672 L F
.53759 .18113 m .53907 .17791 L .54076 .18002 L 0 .029 .129 r
F
.53759 .18113 m .53589 .17902 L .53907 .17791 L F
.75791 .17981 m .75974 .1764 L .76121 .17861 L 0 .026 .125 r
F
.75791 .17981 m .75644 .1776 L .75974 .1764 L F
.72091 .17916 m .72269 .17589 L .72419 .17805 L 0 .025 .124 r
F
.72091 .17916 m .7194 .177 L .72269 .17589 L F
.49256 .18096 m .49395 .17758 L .4957 .17979 L 0 .028 .128 r
F
.49256 .18096 m .49081 .17872 L .49395 .17758 L F
.59067 .18103 m .59222 .17754 L .59387 .17981 L F
.59067 .18103 m .58902 .17875 L .59222 .17754 L F
.3124 .18016 m .31351 .17667 L .31544 .17895 L 0 .027 .126 r
F
.3124 .18016 m .31046 .1779 L .31351 .17667 L F
.76596 .17954 m .7678 .1761 L .76926 .17829 L 0 .026 .125 r
F
.76596 .17954 m .7645 .17735 L .7678 .1761 L F
.45555 .18046 m .45689 .177 L .45867 .17926 L 0 .028 .127 r
F
.45555 .18046 m .45376 .17817 L .45689 .177 L F
.4105 .18033 m .41176 .17702 L .4136 .17919 L F
.4105 .18033 m .40867 .17815 L .41176 .17702 L F
.65982 .18013 m .66149 .17667 L .66306 .17895 L 0 .027 .126 r
F
.65982 .18013 m .65824 .17785 L .66149 .17667 L F
.54563 .18103 m .54712 .17768 L .5488 .17979 L 0 .029 .129 r
F
.54563 .18103 m .54394 .17891 L .54712 .17768 L F
.55366 .1806 m .55516 .17718 L .55684 .1793 L 0 .028 .128 r
F
.55366 .1806 m .55198 .17849 L .55516 .17718 L F
.5617 .18016 m .56321 .17671 L .56488 .17886 L 0 .027 .127 r
F
.5617 .18016 m .56002 .178 L .56321 .17671 L F
.50059 .18083 m .502 .17747 L .50374 .17965 L 0 .029 .128 r
F
.50059 .18083 m .49885 .17863 L .502 .17747 L F
.59871 .18085 m .60028 .17744 L .60191 .17969 L F
.59871 .18085 m .59707 .17859 L .60028 .17744 L F
.77401 .17932 m .77587 .17597 L .77732 .1782 L 0 .026 .125 r
F
.77401 .17932 m .77256 .17711 L .77587 .17597 L F
.32041 .18002 m .32153 .17653 L .32345 .17884 L 0 .027 .126 r
F
.32041 .18002 m .31848 .17773 L .32153 .17653 L F
.36545 .18025 m .36664 .17698 L .36852 .17917 L 0 .028 .127 r
F
.36545 .18025 m .36357 .17806 L .36664 .17698 L F
.46358 .18027 m .46493 .17688 L .4667 .17911 L F
.46358 .18027 m .4618 .17807 L .46493 .17688 L F
.72897 .17917 m .73075 .1757 L .73225 .17794 L 0 .026 .124 r
F
.72897 .17917 m .72747 .17693 L .73075 .1757 L F
.56974 .17989 m .57126 .17648 L .57292 .17877 L 0 .027 .126 r
F
.56974 .17989 m .56807 .17762 L .57126 .17648 L F
.41853 .18018 m .4198 .17681 L .42163 .17898 L 0 .028 .127 r
F
.41853 .18018 m .4167 .17804 L .4198 .17681 L F
.60675 .1807 m .60834 .1775 L .60996 .17957 L 0 .029 .129 r
F
.60675 .1807 m .60513 .17859 L .60834 .1775 L F
.29141 .17914 m .29247 .17594 L .29444 .17805 L 0 .026 .125 r
F
.29141 .17914 m .28945 .17703 L .29247 .17594 L F
.73702 .17893 m .73882 .17552 L .74031 .17774 L 0 .025 .124 r
F
.73702 .17893 m .73553 .1767 L .73882 .17552 L F
.50862 .18073 m .51004 .17722 L .51177 .17954 L 0 .029 .128 r
F
.50862 .18073 m .50689 .17844 L .51004 .17722 L F
.32842 .17984 m .32955 .1765 L .33147 .17869 L 0 .027 .127 r
F
.32842 .17984 m .3265 .17767 L .32955 .1765 L F
.66787 .18007 m .66956 .17673 L .67112 .17899 L 0 .028 .127 r
F
.66787 .18007 m .6663 .17783 L .66956 .17673 L F
.4716 .18011 m .47297 .17673 L .47474 .17893 L F
.4716 .18011 m .46983 .17794 L .47297 .17673 L F
.42655 .1799 m .42785 .17656 L .42966 .17871 L 0 .027 .127 r
F
.42655 .1799 m .42473 .17778 L .42785 .17656 L F
.61479 .18039 m .61639 .17704 L .618 .17912 L 0 .028 .128 r
F
.61479 .18039 m .61317 .17831 L .61639 .17704 L F
.37347 .18019 m .37467 .17692 L .37654 .17902 L F
.37347 .18019 m .37159 .17809 L .37467 .17692 L F
.63086 .17954 m .63249 .17619 L .63408 .17833 L 0 .027 .126 r
F
.63086 .17954 m .62926 .17739 L .63249 .17619 L F
.62283 .17999 m .62444 .17656 L .62604 .17869 L 0 .028 .127 r
F
.62283 .17999 m .62122 .17785 L .62444 .17656 L F
.33644 .17964 m .33759 .17632 L .3395 .17843 L 0 .027 .127 r
F
.33644 .17964 m .33453 .17751 L .33759 .17632 L F
.43458 .17964 m .43589 .1763 L .4377 .17845 L F
.43458 .17964 m .43277 .17751 L .43589 .1763 L F
.3815 .17986 m .38271 .17649 L .38458 .17861 L 0 .028 .127 r
F
.3815 .17986 m .37963 .17776 L .38271 .17649 L F
.57778 .17995 m .57931 .17648 L .58097 .1788 L F
.57778 .17995 m .57612 .17765 L .57931 .17648 L F
.29942 .17907 m .30049 .17586 L .30245 .17797 L 0 .026 .126 r
F
.29942 .17907 m .29746 .17696 L .30049 .17586 L F
.51665 .18063 m .51809 .17705 L .51981 .17938 L 0 .029 .129 r
F
.51665 .18063 m .51493 .17831 L .51809 .17705 L F
.74509 .17886 m .7469 .1755 L .74838 .17773 L 0 .026 .125 r
F
.74509 .17886 m .7436 .17662 L .7469 .1755 L F
.47964 .17998 m .48101 .17658 L .48277 .17883 L 0 .028 .127 r
F
.47964 .17998 m .47787 .17775 L .48101 .17658 L F
.63891 .17932 m .64055 .17603 L .64214 .17816 L 0 .027 .126 r
F
.63891 .17932 m .63731 .17718 L .64055 .17603 L F
.38953 .17955 m .39076 .1761 L .39261 .17831 L F
.38953 .17955 m .38767 .17736 L .39076 .1761 L F
.34447 .17934 m .34563 .176 L .34753 .1781 L F
.34447 .17934 m .34256 .17722 L .34563 .176 L F
.44261 .17943 m .44393 .1761 L .44573 .17823 L F
.44261 .17943 m .44081 .17728 L .44393 .1761 L F
.67593 .18013 m .67762 .17658 L .67918 .17886 L 0 .028 .128 r
F
.67593 .18013 m .67437 .17786 L .67762 .17658 L F
.52469 .18036 m .52614 .17697 L .52785 .1792 L 0 .029 .129 r
F
.52469 .18036 m .52297 .17812 L .52614 .17697 L F
.68397 .17974 m .68568 .17635 L .68722 .17851 L 0 .028 .127 r
F
.68397 .17974 m .68243 .17758 L .68568 .17635 L F
.39755 .17933 m .3988 .17599 L .40064 .1782 L 0 .027 .126 r
F
.39755 .17933 m .39571 .17711 L .3988 .17599 L F
.35249 .17911 m .35367 .17572 L .35556 .17798 L F
.35249 .17911 m .3506 .17687 L .35367 .17572 L F
.64695 .17916 m .6486 .17565 L .65018 .17793 L F
.64695 .17916 m .64536 .1769 L .6486 .17565 L F
.69201 .1794 m .69374 .17613 L .69527 .17821 L 0 .027 .127 r
F
.69201 .1794 m .69048 .17732 L .69374 .17613 L F
.58582 .1799 m .58737 .17646 L .58902 .17875 L 0 .028 .128 r
F
.58582 .1799 m .58417 .17763 L .58737 .17646 L F
.75315 .17879 m .75497 .17538 L .75644 .1776 L 0 .026 .125 r
F
.75315 .17879 m .75167 .17656 L .75497 .17538 L F
.48767 .17992 m .48906 .17649 L .49081 .17872 L 0 .028 .128 r
F
.48767 .17992 m .48591 .17766 L .48906 .17649 L F
.30743 .17904 m .30852 .17574 L .31046 .1779 L 0 .027 .126 r
F
.30743 .17904 m .30548 .17687 L .30852 .17574 L F
.70005 .17904 m .70179 .1757 L .70332 .1778 L F
.70005 .17904 m .69853 .17695 L .70179 .1757 L F
.71613 .17817 m .7179 .17491 L .7194 .177 L 0 .025 .124 r
F
.71613 .17817 m .71462 .17608 L .7179 .17491 L F
.53273 .18018 m .53419 .17692 L .53589 .17902 L 0 .029 .129 r
F
.53273 .18018 m .53102 .17805 L .53419 .17692 L F
.70809 .17864 m .70984 .17527 L .71136 .17736 L 0 .026 .125 r
F
.70809 .17864 m .70658 .17655 L .70984 .17527 L F
.45064 .17935 m .45197 .17589 L .45376 .17817 L 0 .027 .127 r
F
.45064 .17935 m .44885 .17705 L .45197 .17589 L F
.655 .17903 m .65666 .17555 L .65824 .17785 L 0 .027 .126 r
F
.655 .17903 m .65342 .17672 L .65666 .17555 L F
.76121 .17861 m .76304 .17516 L .7645 .17735 L 0 .026 .125 r
F
.76121 .17861 m .75974 .1764 L .76304 .17516 L F
.40557 .17928 m .40683 .17596 L .40867 .17815 L 0 .028 .127 r
F
.40557 .17928 m .40373 .17708 L .40683 .17596 L F
.4957 .17979 m .4971 .17645 L .49885 .17863 L 0 .029 .128 r
F
.4957 .17979 m .49395 .17758 L .4971 .17645 L F
.54076 .18002 m .54224 .1768 L .54394 .17891 L 0 .029 .129 r
F
.54076 .18002 m .53907 .17791 L .54224 .1768 L F
.36051 .17914 m .36169 .17578 L .36357 .17806 L 0 .027 .127 r
F
.36051 .17914 m .35862 .17688 L .36169 .17578 L F
.59387 .17981 m .59543 .17633 L .59707 .17859 L 0 .028 .128 r
F
.59387 .17981 m .59222 .17754 L .59543 .17633 L F
.72419 .17805 m .72597 .17476 L .72747 .17693 L 0 .025 .124 r
F
.72419 .17805 m .72269 .17589 L .72597 .17476 L F
.31544 .17895 m .31656 .17544 L .31848 .17773 L 0 .027 .126 r
F
.31544 .17895 m .31351 .17667 L .31656 .17544 L F
.76926 .17829 m .7711 .1749 L .77256 .17711 L 0 .026 .125 r
F
.76926 .17829 m .7678 .1761 L .7711 .1749 L F
.45867 .17926 m .46002 .1758 L .4618 .17807 L 0 .028 .127 r
F
.45867 .17926 m .45689 .177 L .46002 .1758 L F
.55684 .1793 m .55835 .1759 L .56002 .178 L F
.55684 .1793 m .55516 .17718 L .55835 .1759 L F
.56488 .17886 m .5664 .17546 L .56807 .17762 L 0 .027 .126 r
F
.56488 .17886 m .56321 .17671 L .5664 .17546 L F
.5488 .17979 m .5503 .17637 L .55198 .17849 L 0 .029 .128 r
F
.5488 .17979 m .54712 .17768 L .5503 .17637 L F
.66306 .17895 m .66473 .17555 L .6663 .17783 L 0 .027 .127 r
F
.66306 .17895 m .66149 .17667 L .66473 .17555 L F
.4136 .17919 m .41487 .17589 L .4167 .17804 L 0 .028 .127 r
F
.4136 .17919 m .41176 .17702 L .41487 .17589 L F
.50374 .17965 m .50515 .17625 L .50689 .17844 L 0 .029 .128 r
F
.50374 .17965 m .502 .17747 L .50515 .17625 L F
.60191 .17969 m .60349 .17634 L .60513 .17859 L 0 .029 .129 r
F
.60191 .17969 m .60028 .17744 L .60349 .17634 L F
.73225 .17794 m .73403 .17446 L .73553 .1767 L 0 .025 .124 r
F
.73225 .17794 m .73075 .1757 L .73403 .17446 L F
.32345 .17884 m .32459 .17534 L .3265 .17767 L 0 .027 .126 r
F
.32345 .17884 m .32153 .17653 L .32459 .17534 L F
.77732 .1782 m .77919 .17483 L .78064 .17708 L 0 .026 .125 r
F
.77732 .1782 m .77587 .17597 L .77919 .17483 L F
.4667 .17911 m .46806 .17569 L .46983 .17794 L 0 .028 .127 r
F
.4667 .17911 m .46493 .17688 L .46806 .17569 L F
.36852 .17917 m .36971 .1759 L .37159 .17809 L 0 .028 .128 r
F
.36852 .17917 m .36664 .17698 L .36971 .1759 L F
.42163 .17898 m .42291 .17558 L .42473 .17778 L 0 .028 .127 r
F
.42163 .17898 m .4198 .17681 L .42291 .17558 L F
.57292 .17877 m .57445 .17535 L .57612 .17765 L 0 .027 .127 r
F
.57292 .17877 m .57126 .17648 L .57445 .17535 L F
.74031 .17774 m .74211 .17442 L .7436 .17662 L 0 .026 .124 r
F
.74031 .17774 m .73882 .17552 L .74211 .17442 L F
.51177 .17954 m .5132 .17598 L .51493 .17831 L 0 .029 .128 r
F
.51177 .17954 m .51004 .17722 L .5132 .17598 L F
.618 .17912 m .61961 .17576 L .62122 .17785 L 0 .028 .128 r
F
.618 .17912 m .61639 .17704 L .61961 .17576 L F
.60996 .17957 m .61155 .17623 L .61317 .17831 L 0 .029 .129 r
F
.60996 .17957 m .60834 .1775 L .61155 .17623 L F
.62604 .17869 m .62766 .17527 L .62926 .17739 L 0 .027 .127 r
F
.62604 .17869 m .62444 .17656 L .62766 .17527 L F
.33147 .17869 m .33261 .17533 L .33453 .17751 L F
.33147 .17869 m .32955 .1765 L .33261 .17533 L F
.47474 .17893 m .47611 .17552 L .47787 .17775 L 0 .028 .127 r
F
.47474 .17893 m .47297 .17673 L .47611 .17552 L F
.42966 .17871 m .43096 .17534 L .43277 .17751 L 0 .027 .127 r
F
.42966 .17871 m .42785 .17656 L .43096 .17534 L F
.29444 .17805 m .2955 .17484 L .29746 .17696 L 0 .026 .125 r
F
.29444 .17805 m .29247 .17594 L .2955 .17484 L F
.67112 .17899 m .67281 .17559 L .67437 .17786 L 0 .028 .127 r
F
.67112 .17899 m .66956 .17673 L .67281 .17559 L F
.63408 .17833 m .63572 .17505 L .63731 .17718 L 0 .027 .126 r
F
.63408 .17833 m .63249 .17619 L .63572 .17505 L F
.37654 .17902 m .37775 .17565 L .37963 .17776 L 0 .028 .128 r
F
.37654 .17902 m .37467 .17692 L .37775 .17565 L F
.38458 .17861 m .38581 .17523 L .38767 .17736 L 0 .027 .127 r
F
.38458 .17861 m .38271 .17649 L .38581 .17523 L F
.3395 .17843 m .34065 .17513 L .34256 .17722 L 0 .027 .126 r
F
.3395 .17843 m .33759 .17632 L .34065 .17513 L F
.4377 .17845 m .439 .17514 L .44081 .17728 L 0 .027 .127 r
F
.4377 .17845 m .43589 .1763 L .439 .17514 L F
.51981 .17938 m .52126 .17578 L .52297 .17812 L 0 .029 .128 r
F
.51981 .17938 m .51809 .17705 L .52126 .17578 L F
.39261 .17831 m .39385 .17489 L .39571 .17711 L 0 .027 .126 r
F
.39261 .17831 m .39076 .1761 L .39385 .17489 L F
.34753 .1781 m .34869 .17478 L .3506 .17687 L F
.34753 .1781 m .34563 .176 L .34869 .17478 L F
.58097 .1788 m .58251 .1753 L .58417 .17763 L 0 .028 .127 r
F
.58097 .1788 m .57931 .17648 L .58251 .1753 L F
.48277 .17883 m .48416 .17542 L .48591 .17766 L 0 .028 .128 r
F
.48277 .17883 m .48101 .17658 L .48416 .17542 L F
.64214 .17816 m .64378 .17477 L .64536 .1769 L 0 .027 .126 r
F
.64214 .17816 m .64055 .17603 L .64378 .17477 L F
.74838 .17773 m .75019 .17433 L .75167 .17656 L 0 .026 .125 r
F
.74838 .17773 m .7469 .1755 L .75019 .17433 L F
.67918 .17886 m .68087 .1753 L .68243 .17758 L 0 .028 .127 r
F
.67918 .17886 m .67762 .17658 L .68087 .1753 L F
.30245 .17797 m .30353 .17477 L .30548 .17687 L 0 .027 .126 r
F
.30245 .17797 m .30049 .17586 L .30353 .17477 L F
.44573 .17823 m .44705 .17493 L .44885 .17705 L F
.44573 .17823 m .44393 .1761 L .44705 .17493 L F
.68722 .17851 m .68894 .17517 L .69048 .17732 L 0 .028 .127 r
F
.68722 .17851 m .68568 .17635 L .68894 .17517 L F
.52785 .1792 m .52931 .17584 L .53102 .17805 L 0 .029 .129 r
F
.52785 .1792 m .52614 .17697 L .52931 .17584 L F
.65018 .17793 m .65184 .17443 L .65342 .17672 L 0 .026 .126 r
F
.65018 .17793 m .6486 .17565 L .65184 .17443 L F
.35556 .17798 m .35673 .17461 L .35862 .17688 L 0 .027 .126 r
F
.35556 .17798 m .35367 .17572 L .35673 .17461 L F
.40064 .1782 m .40189 .17488 L .40373 .17708 L 0 .027 .127 r
F
.40064 .1782 m .3988 .17599 L .40189 .17488 L F
.69527 .17821 m .697 .17486 L .69853 .17695 L F
.69527 .17821 m .69374 .17613 L .697 .17486 L F
.70332 .1778 m .70506 .17443 L .70658 .17655 L 0 .027 .126 r
F
.70332 .1778 m .70179 .1757 L .70506 .17443 L F
.71136 .17736 m .71311 .17399 L .71462 .17608 L 0 .026 .125 r
F
.71136 .17736 m .70984 .17527 L .71311 .17399 L F
.75644 .1776 m .75827 .17419 L .75974 .1764 L F
.75644 .1776 m .75497 .17538 L .75827 .17419 L F
.49081 .17872 m .49221 .17536 L .49395 .17758 L 0 .028 .128 r
F
.49081 .17872 m .48906 .17649 L .49221 .17536 L F
.58902 .17875 m .59058 .17525 L .59222 .17754 L F
.58902 .17875 m .58737 .17646 L .59058 .17525 L F
.7194 .177 m .72118 .17378 L .72269 .17589 L 0 .025 .124 r
F
.7194 .177 m .7179 .17491 L .72118 .17378 L F
.31046 .1779 m .31157 .1745 L .31351 .17667 L 0 .027 .126 r
F
.31046 .1779 m .30852 .17574 L .31157 .1745 L F
.53589 .17902 m .53737 .17581 L .53907 .17791 L 0 .029 .129 r
F
.53589 .17902 m .53419 .17692 L .53737 .17581 L F
.45376 .17817 m .4551 .17473 L .45689 .177 L 0 .027 .127 r
F
.45376 .17817 m .45197 .17589 L .4551 .17473 L F
.7645 .17735 m .76634 .17392 L .7678 .1761 L 0 .026 .125 r
F
.7645 .17735 m .76304 .17516 L .76634 .17392 L F
.65824 .17785 m .65991 .17438 L .66149 .17667 L 0 .027 .126 r
F
.65824 .17785 m .65666 .17555 L .65991 .17438 L F
.40867 .17815 m .40993 .17484 L .41176 .17702 L 0 .028 .127 r
F
.40867 .17815 m .40683 .17596 L .40993 .17484 L F
.59707 .17859 m .59864 .17517 L .60028 .17744 L 0 .028 .128 r
F
.59707 .17859 m .59543 .17633 L .59864 .17517 L F
.31848 .17773 m .31961 .17422 L .32153 .17653 L 0 .027 .126 r
F
.31848 .17773 m .31656 .17544 L .31961 .17422 L F
.49885 .17863 m .50026 .17531 L .502 .17747 L 0 .029 .128 r
F
.49885 .17863 m .4971 .17645 L .50026 .17531 L F
.56002 .178 m .56153 .17461 L .56321 .17671 L 0 .027 .127 r
F
.56002 .178 m .55835 .1759 L .56153 .17461 L F
.77256 .17711 m .77442 .17374 L .77587 .17597 L 0 .026 .125 r
F
.77256 .17711 m .7711 .1749 L .77442 .17374 L F
.54394 .17891 m .54542 .17556 L .54712 .17768 L 0 .029 .129 r
F
.54394 .17891 m .54224 .1768 L .54542 .17556 L F
.55198 .17849 m .55348 .17506 L .55516 .17718 L 0 .028 .128 r
F
.55198 .17849 m .5503 .17637 L .55348 .17506 L F
.72747 .17693 m .72925 .17352 L .73075 .1757 L 0 .025 .124 r
F
.72747 .17693 m .72597 .17476 L .72925 .17352 L F
.36357 .17806 m .36476 .17469 L .36664 .17698 L 0 .028 .127 r
F
.36357 .17806 m .36169 .17578 L .36476 .17469 L F
.56807 .17762 m .56959 .17432 L .57126 .17648 L 0 .027 .126 r
F
.56807 .17762 m .5664 .17546 L .56959 .17432 L F
.4618 .17807 m .46315 .17459 L .46493 .17688 L 0 .027 .127 r
F
.4618 .17807 m .46002 .1758 L .46315 .17459 L F
.50689 .17844 m .50831 .17502 L .51004 .17722 L 0 .028 .128 r
F
.50689 .17844 m .50515 .17625 L .50831 .17502 L F
.73553 .1767 m .73732 .1733 L .73882 .17552 L 0 .025 .124 r
F
.73553 .1767 m .73403 .17446 L .73732 .1733 L F
.4167 .17804 m .41798 .17463 L .4198 .17681 L 0 .028 .127 r
F
.4167 .17804 m .41487 .17589 L .41798 .17463 L F
.6663 .17783 m .66799 .17444 L .66956 .17673 L 0 .027 .127 r
F
.6663 .17783 m .66473 .17555 L .66799 .17444 L F
.3265 .17767 m .32764 .17415 L .32955 .1765 L 0 .027 .126 r
F
.3265 .17767 m .32459 .17534 L .32764 .17415 L F
.60513 .17859 m .60671 .17524 L .60834 .1775 L 0 .029 .129 r
F
.60513 .17859 m .60349 .17634 L .60671 .17524 L F
.46983 .17794 m .4712 .17446 L .47297 .17673 L 0 .028 .127 r
F
.46983 .17794 m .46806 .17569 L .4712 .17446 L F
.42473 .17778 m .42603 .17434 L .42785 .17656 L 0 .027 .127 r
F
.42473 .17778 m .42291 .17558 L .42603 .17434 L F
.62926 .17739 m .63089 .17407 L .63249 .17619 L 0 .027 .126 r
F
.62926 .17739 m .62766 .17527 L .63089 .17407 L F
.62122 .17785 m .62283 .17447 L .62444 .17656 L 0 .028 .127 r
F
.62122 .17785 m .61961 .17576 L .62283 .17447 L F
.51493 .17831 m .51637 .17471 L .51809 .17705 L 0 .028 .128 r
F
.51493 .17831 m .5132 .17598 L .51637 .17471 L F
.61317 .17831 m .61477 .17495 L .61639 .17704 L 0 .029 .128 r
F
.61317 .17831 m .61155 .17623 L .61477 .17495 L F
.37159 .17809 m .37279 .17472 L .37467 .17692 L 0 .028 .128 r
F
.37159 .17809 m .36971 .1759 L .37279 .17472 L F
.57612 .17765 m .57765 .17416 L .57931 .17648 L 0 .027 .127 r
F
.57612 .17765 m .57445 .17535 L .57765 .17416 L F
.33453 .17751 m .33567 .17416 L .33759 .17632 L F
.33453 .17751 m .33261 .17533 L .33567 .17416 L F
.43277 .17751 m .43408 .17411 L .43589 .1763 L F
.43277 .17751 m .43096 .17534 L .43408 .17411 L F
.7436 .17662 m .74541 .17332 L .7469 .1755 L 0 .026 .125 r
F
.7436 .17662 m .74211 .17442 L .74541 .17332 L F
.47787 .17775 m .47925 .17433 L .48101 .17658 L 0 .028 .127 r
F
.47787 .17775 m .47611 .17552 L .47925 .17433 L F
.37963 .17776 m .38084 .17437 L .38271 .17649 L F
.37963 .17776 m .37775 .17565 L .38084 .17437 L F
.38767 .17736 m .3889 .17397 L .39076 .1761 L 0 .027 .126 r
F
.38767 .17736 m .38581 .17523 L .3889 .17397 L F
.29746 .17696 m .29853 .17375 L .30049 .17586 L F
.29746 .17696 m .2955 .17484 L .29853 .17375 L F
.63731 .17718 m .63895 .1739 L .64055 .17603 L F
.63731 .17718 m .63572 .17505 L .63895 .1739 L F
.67437 .17786 m .67606 .1743 L .67762 .17658 L 0 .028 .127 r
F
.67437 .17786 m .67281 .17559 L .67606 .1743 L F
.34256 .17722 m .34371 .17392 L .34563 .176 L 0 .027 .126 r
F
.34256 .17722 m .34065 .17513 L .34371 .17392 L F
.52297 .17812 m .52442 .17464 L .52614 .17697 L 0 .028 .128 r
F
.52297 .17812 m .52126 .17578 L .52442 .17464 L F
.44081 .17728 m .44213 .17398 L .44393 .1761 L 0 .027 .127 r
F
.44081 .17728 m .439 .17514 L .44213 .17398 L F
.3506 .17687 m .35176 .17363 L .35367 .17572 L 0 .027 .126 r
F
.3506 .17687 m .34869 .17478 L .35176 .17363 L F
.39571 .17711 m .39695 .17379 L .3988 .17599 L F
.39571 .17711 m .39385 .17489 L .39695 .17379 L F
.64536 .1769 m .64701 .17352 L .6486 .17565 L F
.64536 .1769 m .64378 .17477 L .64701 .17352 L F
.68243 .17758 m .68413 .17408 L .68568 .17635 L 0 .028 .127 r
F
.68243 .17758 m .68087 .1753 L .68413 .17408 L F
.58417 .17763 m .58572 .17411 L .58737 .17646 L F
.58417 .17763 m .58251 .1753 L .58572 .17411 L F
.48591 .17766 m .4873 .17427 L .48906 .17649 L 0 .028 .128 r
F
.48591 .17766 m .48416 .17542 L .4873 .17427 L F
.75167 .17656 m .75349 .17316 L .75497 .17538 L 0 .026 .125 r
F
.75167 .17656 m .75019 .17433 L .75349 .17316 L F
.44885 .17705 m .45018 .17379 L .45197 .17589 L 0 .027 .126 r
F
.44885 .17705 m .44705 .17493 L .45018 .17379 L F
.69048 .17732 m .69221 .17399 L .69374 .17613 L 0 .028 .127 r
F
.69048 .17732 m .68894 .17517 L .69221 .17399 L F
.30548 .17687 m .30657 .17364 L .30852 .17574 L 0 .027 .126 r
F
.30548 .17687 m .30353 .17477 L .30657 .17364 L F
.53102 .17805 m .53248 .17472 L .53419 .17692 L 0 .029 .129 r
F
.53102 .17805 m .52931 .17584 L .53248 .17472 L F
.65342 .17672 m .65508 .17327 L .65666 .17555 L 0 .026 .125 r
F
.65342 .17672 m .65184 .17443 L .65508 .17327 L F
.69853 .17695 m .70027 .17359 L .70179 .1757 L 0 .027 .126 r
F
.69853 .17695 m .697 .17486 L .70027 .17359 L F
.71462 .17608 m .71639 .17281 L .7179 .17491 L 0 .026 .124 r
F
.71462 .17608 m .71311 .17399 L .71639 .17281 L F
.70658 .17655 m .70833 .17314 L .70984 .17527 L 0 .026 .125 r
F
.70658 .17655 m .70506 .17443 L .70833 .17314 L F
.75974 .1764 m .76157 .17297 L .76304 .17516 L F
.75974 .1764 m .75827 .17419 L .76157 .17297 L F
.40373 .17708 m .40499 .17377 L .40683 .17596 L 0 .027 .127 r
F
.40373 .17708 m .40189 .17488 L .40499 .17377 L F
.59222 .17754 m .59378 .17405 L .59543 .17633 L 0 .028 .128 r
F
.59222 .17754 m .59058 .17525 L .59378 .17405 L F
.35862 .17688 m .3598 .1735 L .36169 .17578 L 0 .027 .126 r
F
.35862 .17688 m .35673 .17461 L .3598 .1735 L F
.31351 .17667 m .31462 .17325 L .31656 .17544 L F
.31351 .17667 m .31157 .1745 L .31462 .17325 L F
.49395 .17758 m .49536 .17426 L .4971 .17645 L 0 .028 .128 r
F
.49395 .17758 m .49221 .17536 L .49536 .17426 L F
.7678 .1761 m .76965 .17274 L .7711 .1749 L 0 .026 .125 r
F
.7678 .1761 m .76634 .17392 L .76965 .17274 L F
.45689 .177 m .45823 .17353 L .46002 .1758 L 0 .027 .127 r
F
.45689 .177 m .4551 .17473 L .45823 .17353 L F
.72269 .17589 m .72447 .17263 L .72597 .17476 L 0 .026 .124 r
F
.72269 .17589 m .72118 .17378 L .72447 .17263 L F
.53907 .17791 m .54054 .17469 L .54224 .1768 L 0 .029 .129 r
F
.53907 .17791 m .53737 .17581 L .54054 .17469 L F
.66149 .17667 m .66316 .17326 L .66473 .17555 L 0 .027 .126 r
F
.66149 .17667 m .65991 .17438 L .66316 .17326 L F
.56321 .17671 m .56473 .17337 L .5664 .17546 L F
.56321 .17671 m .56153 .17461 L .56473 .17337 L F
.55516 .17718 m .55666 .17378 L .55835 .1759 L 0 .028 .127 r
F
.55516 .17718 m .55348 .17506 L .55666 .17378 L F
.32153 .17653 m .32267 .17301 L .32459 .17534 L 0 .027 .126 r
F
.32153 .17653 m .31961 .17422 L .32267 .17301 L F
.60028 .17744 m .60186 .17406 L .60349 .17634 L 0 .028 .128 r
F
.60028 .17744 m .59864 .17517 L .60186 .17406 L F
.54712 .17768 m .5486 .17424 L .5503 .17637 L 0 .029 .129 r
F
.54712 .17768 m .54542 .17556 L .5486 .17424 L F
.41176 .17702 m .41303 .17372 L .41487 .17589 L 0 .028 .127 r
F
.41176 .17702 m .40993 .17484 L .41303 .17372 L F
.502 .17747 m .50341 .17408 L .50515 .17625 L 0 .029 .128 r
F
.502 .17747 m .50026 .17531 L .50341 .17408 L F
.73075 .1757 m .73254 .17227 L .73403 .17446 L 0 .025 .124 r
F
.73075 .1757 m .72925 .17352 L .73254 .17227 L F
.77587 .17597 m .77773 .17258 L .77919 .17483 L 0 .026 .125 r
F
.77587 .17597 m .77442 .17374 L .77773 .17258 L F
.46493 .17688 m .46629 .17338 L .46806 .17569 L 0 .027 .127 r
F
.46493 .17688 m .46315 .17459 L .46629 .17338 L F
.57126 .17648 m .57279 .17317 L .57445 .17535 L 0 .027 .126 r
F
.57126 .17648 m .56959 .17432 L .57279 .17317 L F
.36664 .17698 m .36783 .17359 L .36971 .1759 L 0 .028 .127 r
F
.36664 .17698 m .36476 .17469 L .36783 .17359 L F
.51004 .17722 m .51147 .17377 L .5132 .17598 L 0 .028 .128 r
F
.51004 .17722 m .50831 .17502 L .51147 .17377 L F
.4198 .17681 m .42109 .17337 L .42291 .17558 L 0 .028 .127 r
F
.4198 .17681 m .41798 .17463 L .42109 .17337 L F
.73882 .17552 m .74062 .17222 L .74211 .17442 L 0 .025 .124 r
F
.73882 .17552 m .73732 .1733 L .74062 .17222 L F
.32955 .1765 m .3307 .173 L .33261 .17533 L 0 .027 .126 r
F
.32955 .1765 m .32764 .17415 L .3307 .173 L F
.66956 .17673 m .67124 .1733 L .67281 .17559 L 0 .028 .127 r
F
.66956 .17673 m .66799 .17444 L .67124 .1733 L F
.47297 .17673 m .47434 .17323 L .47611 .17552 L 0 .027 .127 r
F
.47297 .17673 m .4712 .17446 L .47434 .17323 L F
.62444 .17656 m .62605 .17318 L .62766 .17527 L F
.62444 .17656 m .62283 .17447 L .62605 .17318 L F
.42785 .17656 m .42914 .17309 L .43096 .17534 L F
.42785 .17656 m .42603 .17434 L .42914 .17309 L F
.61639 .17704 m .61799 .17366 L .61961 .17576 L 0 .028 .128 r
F
.61639 .17704 m .61477 .17495 L .61799 .17366 L F
.51809 .17705 m .51953 .17343 L .52126 .17578 L F
.51809 .17705 m .51637 .17471 L .51953 .17343 L F
.60834 .1775 m .60993 .17397 L .61155 .17623 L 0 .029 .129 r
F
.60834 .1775 m .60671 .17524 L .60993 .17397 L F
.63249 .17619 m .63412 .17292 L .63572 .17505 L 0 .027 .126 r
F
.63249 .17619 m .63089 .17407 L .63412 .17292 L F
.37467 .17692 m .37588 .17345 L .37775 .17565 L 0 .028 .128 r
F
.37467 .17692 m .37279 .17472 L .37588 .17345 L F
.57931 .17648 m .58085 .17296 L .58251 .1753 L 0 .027 .127 r
F
.57931 .17648 m .57765 .17416 L .58085 .17296 L F
.38271 .17649 m .38394 .1731 L .38581 .17523 L F
.38271 .17649 m .38084 .17437 L .38394 .1731 L F
.43589 .1763 m .4372 .17295 L .439 .17514 L F
.43589 .1763 m .43408 .17411 L .4372 .17295 L F
.33759 .17632 m .33873 .17298 L .34065 .17513 L F
.33759 .17632 m .33567 .17416 L .33873 .17298 L F
.39076 .1761 m .39199 .17275 L .39385 .17489 L 0 .027 .126 r
F
.39076 .1761 m .3889 .17397 L .39199 .17275 L F
.67762 .17658 m .67931 .17301 L .68087 .1753 L 0 .027 .127 r
F
.67762 .17658 m .67606 .1743 L .67931 .17301 L F
.48101 .17658 m .4824 .17319 L .48416 .17542 L 0 .028 .127 r
F
.48101 .17658 m .47925 .17433 L .4824 .17319 L F
.7469 .1755 m .74872 .17216 L .75019 .17433 L 0 .026 .125 r
F
.7469 .1755 m .74541 .17332 L .74872 .17216 L F
.34563 .176 m .34678 .17272 L .34869 .17478 L 0 .027 .126 r
F
.34563 .176 m .34371 .17392 L .34678 .17272 L F
.64055 .17603 m .64219 .17264 L .64378 .17477 L F
.64055 .17603 m .63895 .1739 L .64219 .17264 L F
.52614 .17697 m .5276 .17352 L .52931 .17584 L 0 .029 .128 r
F
.52614 .17697 m .52442 .17464 L .5276 .17352 L F
.30049 .17586 m .30157 .17266 L .30353 .17477 L 0 .027 .126 r
F
.30049 .17586 m .29853 .17375 L .30157 .17266 L F
.6486 .17565 m .65026 .1723 L .65184 .17443 L 0 .026 .125 r
F
.6486 .17565 m .64701 .17352 L .65026 .1723 L F
.44393 .1761 m .44525 .17282 L .44705 .17493 L 0 .027 .127 r
F
.44393 .1761 m .44213 .17398 L .44525 .17282 L F
.68568 .17635 m .68739 .17291 L .68894 .17517 L 0 .028 .127 r
F
.68568 .17635 m .68413 .17408 L .68739 .17291 L F
.35367 .17572 m .35483 .17249 L .35673 .17461 L 0 .027 .126 r
F
.35367 .17572 m .35176 .17363 L .35483 .17249 L F
.3988 .17599 m .40004 .17268 L .40189 .17488 L F
.3988 .17599 m .39695 .17379 L .40004 .17268 L F
.58737 .17646 m .58892 .17293 L .59058 .17525 L 0 .028 .127 r
F
.58737 .17646 m .58572 .17411 L .58892 .17293 L F
.48906 .17649 m .49045 .17315 L .49221 .17536 L 0 .028 .128 r
F
.48906 .17649 m .4873 .17427 L .49045 .17315 L F
.75497 .17538 m .7568 .17199 L .75827 .17419 L 0 .026 .125 r
F
.75497 .17538 m .75349 .17316 L .7568 .17199 L F
.45197 .17589 m .45331 .17264 L .4551 .17473 L 0 .027 .127 r
F
.45197 .17589 m .45018 .17379 L .45331 .17264 L F
.69374 .17613 m .69547 .17271 L .697 .17486 L F
.69374 .17613 m .69221 .17399 L .69547 .17271 L F
.70179 .1757 m .70354 .17231 L .70506 .17443 L 0 .027 .126 r
F
.70179 .1757 m .70027 .17359 L .70354 .17231 L F
.70984 .17527 m .7116 .17185 L .71311 .17399 L 0 .026 .125 r
F
.70984 .17527 m .70833 .17314 L .7116 .17185 L F
.30852 .17574 m .30962 .17238 L .31157 .1745 L 0 .027 .126 r
F
.30852 .17574 m .30657 .17364 L .30962 .17238 L F
.65666 .17555 m .65833 .17211 L .65991 .17438 L 0 .026 .126 r
F
.65666 .17555 m .65508 .17327 L .65833 .17211 L F
.53419 .17692 m .53566 .17361 L .53737 .17581 L 0 .029 .129 r
F
.53419 .17692 m .53248 .17472 L .53566 .17361 L F
.7179 .17491 m .71968 .17166 L .72118 .17378 L 0 .026 .124 r
F
.7179 .17491 m .71639 .17281 L .71968 .17166 L F
.76304 .17516 m .76488 .17175 L .76634 .17392 L 0 .026 .125 r
F
.76304 .17516 m .76157 .17297 L .76488 .17175 L F
.59543 .17633 m .597 .17289 L .59864 .17517 L 0 .028 .128 r
F
.59543 .17633 m .59378 .17405 L .597 .17289 L F
.31656 .17544 m .31768 .17201 L .31961 .17422 L 0 .026 .126 r
F
.31656 .17544 m .31462 .17325 L .31768 .17201 L F
.40683 .17596 m .40809 .17266 L .40993 .17484 L 0 .028 .127 r
F
.40683 .17596 m .40499 .17377 L .40809 .17266 L F
.4971 .17645 m .49851 .17314 L .50026 .17531 L 0 .029 .128 r
F
.4971 .17645 m .49536 .17426 L .49851 .17314 L F
.36169 .17578 m .36288 .17239 L .36476 .17469 L 0 .027 .127 r
F
.36169 .17578 m .3598 .1735 L .36288 .17239 L F
.7711 .1749 m .77297 .17159 L .77442 .17374 L 0 .026 .125 r
F
.7711 .1749 m .76965 .17274 L .77297 .17159 L F
.46002 .1758 m .46137 .1723 L .46315 .17459 L 0 .027 .126 r
F
.46002 .1758 m .45823 .17353 L .46137 .1723 L F
.72597 .17476 m .72775 .17137 L .72925 .17352 L 0 .026 .124 r
F
.72597 .17476 m .72447 .17263 L .72775 .17137 L F
.55835 .1759 m .55985 .1725 L .56153 .17461 L 0 .028 .127 r
F
.55835 .1759 m .55666 .17378 L .55985 .1725 L F
.54224 .1768 m .54373 .17345 L .54542 .17556 L 0 .029 .129 r
F
.54224 .1768 m .54054 .17469 L .54373 .17345 L F
.5664 .17546 m .56792 .17222 L .56959 .17432 L 0 .027 .126 r
F
.5664 .17546 m .56473 .17337 L .56792 .17222 L F
.5503 .17637 m .55179 .17292 L .55348 .17506 L 0 .028 .128 r
F
.5503 .17637 m .5486 .17424 L .55179 .17292 L F
.66473 .17555 m .66642 .17214 L .66799 .17444 L 0 .027 .126 r
F
.66473 .17555 m .66316 .17326 L .66642 .17214 L F
.32459 .17534 m .32572 .1718 L .32764 .17415 L F
.32459 .17534 m .32267 .17301 L .32572 .1718 L F
.50515 .17625 m .50658 .17284 L .50831 .17502 L 0 .028 .128 r
F
.50515 .17625 m .50341 .17408 L .50658 .17284 L F
.73403 .17446 m .73583 .1711 L .73732 .1733 L 0 .025 .124 r
F
.73403 .17446 m .73254 .17227 L .73583 .1711 L F
.41487 .17589 m .41614 .17245 L .41798 .17463 L 0 .028 .127 r
F
.41487 .17589 m .41303 .17372 L .41614 .17245 L F
.60349 .17634 m .60507 .17295 L .60671 .17524 L 0 .029 .128 r
F
.60349 .17634 m .60186 .17406 L .60507 .17295 L F
.46806 .17569 m .46943 .17214 L .4712 .17446 L 0 .027 .127 r
F
.46806 .17569 m .46629 .17338 L .46943 .17214 L F
.5132 .17598 m .51464 .17249 L .51637 .17471 L 0 .028 .128 r
F
.5132 .17598 m .51147 .17377 L .51464 .17249 L F
.57445 .17535 m .57599 .17197 L .57765 .17416 L 0 .027 .126 r
F
.57445 .17535 m .57279 .17317 L .57599 .17197 L F
.42291 .17558 m .4242 .17211 L .42603 .17434 L 0 .027 .127 r
F
.42291 .17558 m .42109 .17337 L .4242 .17211 L F
.36971 .1759 m .37092 .17241 L .37279 .17472 L 0 .028 .128 r
F
.36971 .1759 m .36783 .17359 L .37092 .17241 L F
.62766 .17527 m .62928 .17198 L .63089 .17407 L 0 .027 .127 r
F
.62766 .17527 m .62605 .17318 L .62928 .17198 L F
.47611 .17552 m .47749 .17203 L .47925 .17433 L F
.47611 .17552 m .47434 .17323 L .47749 .17203 L F
.61961 .17576 m .62122 .17238 L .62283 .17447 L 0 .028 .128 r
F
.61961 .17576 m .61799 .17366 L .62122 .17238 L F
.74211 .17442 m .74393 .17113 L .74541 .17332 L 0 .026 .125 r
F
.74211 .17442 m .74062 .17222 L .74393 .17113 L F
.33261 .17533 m .33376 .17184 L .33567 .17416 L 0 .027 .126 r
F
.33261 .17533 m .3307 .173 L .33376 .17184 L F
.52126 .17578 m .52271 .1723 L .52442 .17464 L 0 .028 .127 r
F
.52126 .17578 m .51953 .17343 L .52271 .1723 L F
.43096 .17534 m .43226 .17184 L .43408 .17411 L 0 .027 .126 r
F
.43096 .17534 m .42914 .17309 L .43226 .17184 L F
.61155 .17623 m .61314 .17267 L .61477 .17495 L 0 .029 .128 r
F
.61155 .17623 m .60993 .17397 L .61314 .17267 L F
.67281 .17559 m .6745 .17202 L .67606 .1743 L 0 .027 .127 r
F
.67281 .17559 m .67124 .1733 L .6745 .17202 L F
.37775 .17565 m .37897 .17218 L .38084 .17437 L 0 .028 .127 r
F
.37775 .17565 m .37588 .17345 L .37897 .17218 L F
.38581 .17523 m .38703 .17183 L .3889 .17397 L 0 .027 .127 r
F
.38581 .17523 m .38394 .1731 L .38703 .17183 L F
.63572 .17505 m .63736 .17177 L .63895 .1739 L 0 .027 .126 r
F
.63572 .17505 m .63412 .17292 L .63736 .17177 L F
.68087 .1753 m .68257 .1718 L .68413 .17408 L 0 .027 .127 r
F
.68087 .1753 m .67931 .17301 L .68257 .1718 L F
.58251 .1753 m .58406 .17176 L .58572 .17411 L F
.58251 .1753 m .58085 .17296 L .58406 .17176 L F
.39385 .17489 m .39509 .17165 L .39695 .17379 L 0 .027 .126 r
F
.39385 .17489 m .39199 .17275 L .39509 .17165 L F
.34065 .17513 m .3418 .17179 L .34371 .17392 L 0 .027 .127 r
F
.34065 .17513 m .33873 .17298 L .3418 .17179 L F
.439 .17514 m .44032 .17181 L .44213 .17398 L F
.439 .17514 m .4372 .17295 L .44032 .17181 L F
.48416 .17542 m .48554 .17204 L .4873 .17427 L 0 .028 .127 r
F
.48416 .17542 m .4824 .17319 L .48554 .17204 L F
.64378 .17477 m .64543 .17138 L .64701 .17352 L 0 .027 .126 r
F
.64378 .17477 m .64219 .17264 L .64543 .17138 L F
.75019 .17433 m .75202 .17099 L .75349 .17316 L 0 .026 .125 r
F
.75019 .17433 m .74872 .17216 L .75202 .17099 L F
.34869 .17478 m .34985 .17155 L .35176 .17363 L 0 .027 .126 r
F
.34869 .17478 m .34678 .17272 L .34985 .17155 L F
.65184 .17443 m .6535 .17115 L .65508 .17327 L 0 .026 .125 r
F
.65184 .17443 m .65026 .1723 L .6535 .17115 L F
.44705 .17493 m .44838 .17169 L .45018 .17379 L 0 .027 .127 r
F
.44705 .17493 m .44525 .17282 L .44838 .17169 L F
.68894 .17517 m .69066 .17174 L .69221 .17399 L 0 .028 .127 r
F
.68894 .17517 m .68739 .17291 L .69066 .17174 L F
.52931 .17584 m .53077 .1724 L .53248 .17472 L 0 .029 .129 r
F
.52931 .17584 m .5276 .17352 L .53077 .1724 L F
.30353 .17477 m .30461 .17154 L .30657 .17364 L 0 .027 .126 r
F
.30353 .17477 m .30157 .17266 L .30461 .17154 L F
.59058 .17525 m .59214 .17174 L .59378 .17405 L 0 .028 .127 r
F
.59058 .17525 m .58892 .17293 L .59214 .17174 L F
.35673 .17461 m .35791 .17136 L .3598 .1735 L 0 .027 .126 r
F
.35673 .17461 m .35483 .17249 L .35791 .17136 L F
.75827 .17419 m .76011 .17078 L .76157 .17297 L 0 .026 .125 r
F
.75827 .17419 m .7568 .17199 L .76011 .17078 L F
.697 .17486 m .69874 .17143 L .70027 .17359 L 0 .027 .126 r
F
.697 .17486 m .69547 .17271 L .69874 .17143 L F
.70506 .17443 m .70681 .17101 L .70833 .17314 L 0 .026 .125 r
F
.70506 .17443 m .70354 .17231 L .70681 .17101 L F
.40189 .17488 m .40314 .17158 L .40499 .17377 L 0 .027 .127 r
F
.40189 .17488 m .40004 .17268 L .40314 .17158 L F
.71311 .17399 m .71488 .17064 L .71639 .17281 L 0 .026 .125 r
F
.71311 .17399 m .7116 .17185 L .71488 .17064 L F
.49221 .17536 m .49361 .17204 L .49536 .17426 L 0 .028 .128 r
F
.49221 .17536 m .49045 .17315 L .49361 .17204 L F
.31157 .1745 m .31267 .17112 L .31462 .17325 L 0 .027 .126 r
F
.31157 .1745 m .30962 .17238 L .31267 .17112 L F
.4551 .17473 m .45644 .17144 L .45823 .17353 L 0 .027 .127 r
F
.4551 .17473 m .45331 .17264 L .45644 .17144 L F
.76634 .17392 m .76819 .17058 L .76965 .17274 L 0 .026 .125 r
F
.76634 .17392 m .76488 .17175 L .76819 .17058 L F
.65991 .17438 m .66158 .17098 L .66316 .17326 L 0 .027 .126 r
F
.65991 .17438 m .65833 .17211 L .66158 .17098 L F
.72118 .17378 m .72297 .17049 L .72447 .17263 L 0 .026 .125 r
F
.72118 .17378 m .71968 .17166 L .72297 .17049 L F
.31961 .17422 m .32073 .17078 L .32267 .17301 L F
.31961 .17422 m .31768 .17201 L .32073 .17078 L F
.53737 .17581 m .53884 .17249 L .54054 .17469 L 0 .029 .129 r
F
.53737 .17581 m .53566 .17361 L .53884 .17249 L F
.59864 .17517 m .60022 .17178 L .60186 .17406 L 0 .028 .128 r
F
.59864 .17517 m .597 .17289 L .60022 .17178 L F
.46315 .17459 m .46451 .17106 L .46629 .17338 L 0 .027 .126 r
F
.46315 .17459 m .46137 .1723 L .46451 .17106 L F
.56153 .17461 m .56305 .17127 L .56473 .17337 L 0 .027 .127 r
F
.56153 .17461 m .55985 .1725 L .56305 .17127 L F
.55348 .17506 m .55498 .17164 L .55666 .17378 L 0 .028 .128 r
F
.55348 .17506 m .55179 .17292 L .55498 .17164 L F
.40993 .17484 m .41119 .17155 L .41303 .17372 L 0 .028 .127 r
F
.40993 .17484 m .40809 .17266 L .41119 .17155 L F
.72925 .17352 m .73104 .17011 L .73254 .17227 L 0 .025 .124 r
F
.72925 .17352 m .72775 .17137 L .73104 .17011 L F
.77442 .17374 m .77629 .17043 L .77773 .17258 L 0 .026 .125 r
F
.77442 .17374 m .77297 .17159 L .77629 .17043 L F
.50026 .17531 m .50167 .17189 L .50341 .17408 L 0 .029 .128 r
F
.50026 .17531 m .49851 .17314 L .50167 .17189 L F
.54542 .17556 m .54691 .17211 L .5486 .17424 L 0 .029 .129 r
F
.54542 .17556 m .54373 .17345 L .54691 .17211 L F
.36476 .17469 m .36595 .17129 L .36783 .17359 L 0 .027 .127 r
F
.36476 .17469 m .36288 .17239 L .36595 .17129 L F
.56959 .17432 m .57112 .17106 L .57279 .17317 L 0 .027 .126 r
F
.56959 .17432 m .56792 .17222 L .57112 .17106 L F
.50831 .17502 m .50974 .17158 L .51147 .17377 L 0 .028 .128 r
F
.50831 .17502 m .50658 .17284 L .50974 .17158 L F
.32764 .17415 m .32878 .17066 L .3307 .173 L 0 .027 .126 r
F
.32764 .17415 m .32572 .1718 L .32878 .17066 L F
.41798 .17463 m .41926 .17118 L .42109 .17337 L 0 .028 .127 r
F
.41798 .17463 m .41614 .17245 L .41926 .17118 L F
.73732 .1733 m .73913 .17001 L .74062 .17222 L 0 .025 .124 r
F
.73732 .1733 m .73583 .1711 L .73913 .17001 L F
.66799 .17444 m .66967 .17099 L .67124 .1733 L 0 .027 .127 r
F
.66799 .17444 m .66642 .17214 L .66967 .17099 L F
.4712 .17446 m .47257 .17089 L .47434 .17323 L 0 .027 .126 r
F
.4712 .17446 m .46943 .17214 L .47257 .17089 L F
.51637 .17471 m .51781 .17122 L .51953 .17343 L 0 .028 .127 r
F
.51637 .17471 m .51464 .17249 L .51781 .17122 L F
.42603 .17434 m .42732 .17084 L .42914 .17309 L 0 .027 .126 r
F
.42603 .17434 m .4242 .17211 L .42732 .17084 L F
.60671 .17524 m .60829 .17168 L .60993 .17397 L 0 .029 .128 r
F
.60671 .17524 m .60507 .17295 L .60829 .17168 L F
.57765 .17416 m .57919 .17075 L .58085 .17296 L 0 .027 .126 r
F
.57765 .17416 m .57599 .17197 L .57919 .17075 L F
.62283 .17447 m .62444 .17109 L .62605 .17318 L 0 .028 .127 r
F
.62283 .17447 m .62122 .17238 L .62444 .17109 L F
.37279 .17472 m .37401 .17115 L .37588 .17345 L F
.37279 .17472 m .37092 .17241 L .37401 .17115 L F
.61477 .17495 m .61637 .17139 L .61799 .17366 L 0 .028 .128 r
F
.61477 .17495 m .61314 .17267 L .61637 .17139 L F
.63089 .17407 m .63252 .17082 L .63412 .17292 L 0 .027 .127 r
F
.63089 .17407 m .62928 .17198 L .63252 .17082 L F
.67606 .1743 m .67775 .17075 L .67931 .17301 L 0 .027 .126 r
F
.67606 .1743 m .6745 .17202 L .67775 .17075 L F
.47925 .17433 m .48063 .17089 L .4824 .17319 L 0 .027 .127 r
F
.47925 .17433 m .47749 .17203 L .48063 .17089 L F
.43408 .17411 m .43538 .17068 L .4372 .17295 L 0 .027 .126 r
F
.43408 .17411 m .43226 .17184 L .43538 .17068 L F
.38084 .17437 m .38207 .1709 L .38394 .1731 L 0 .028 .127 r
F
.38084 .17437 m .37897 .17218 L .38207 .1709 L F
.33567 .17416 m .33682 .17067 L .33873 .17298 L 0 .027 .126 r
F
.33567 .17416 m .33376 .17184 L .33682 .17067 L F
.52442 .17464 m .52588 .17118 L .5276 .17352 L 0 .028 .128 r
F
.52442 .17464 m .52271 .1723 L .52588 .17118 L F
.3889 .17397 m .39013 .1706 L .39199 .17275 L 0 .027 .126 r
F
.3889 .17397 m .38703 .17183 L .39013 .1706 L F
.74541 .17332 m .74723 .16998 L .74872 .17216 L 0 .026 .125 r
F
.74541 .17332 m .74393 .17113 L .74723 .16998 L F
.68413 .17408 m .68584 .17065 L .68739 .17291 L 0 .027 .127 r
F
.68413 .17408 m .68257 .1718 L .68584 .17065 L F
.58572 .17411 m .58727 .1706 L .58892 .17293 L F
.58572 .17411 m .58406 .17176 L .58727 .1706 L F
.63895 .1739 m .64059 .1705 L .64219 .17264 L 0 .027 .126 r
F
.63895 .1739 m .63736 .17177 L .64059 .1705 L F
.34371 .17392 m .34487 .1706 L .34678 .17272 L 0 .027 .127 r
F
.34371 .17392 m .3418 .17179 L .34487 .1706 L F
.64701 .17352 m .64867 .17016 L .65026 .1723 L 0 .026 .126 r
F
.64701 .17352 m .64543 .17138 L .64867 .17016 L F
.44213 .17398 m .44344 .17067 L .44525 .17282 L 0 .027 .127 r
F
.44213 .17398 m .44032 .17181 L .44344 .17067 L F
.39695 .17379 m .39819 .17055 L .40004 .17268 L F
.39695 .17379 m .39509 .17165 L .39819 .17055 L F
.4873 .17427 m .4887 .17092 L .49045 .17315 L 0 .028 .128 r
F
.4873 .17427 m .48554 .17204 L .4887 .17092 L F
.75349 .17316 m .75533 .16982 L .7568 .17199 L 0 .026 .125 r
F
.75349 .17316 m .75202 .17099 L .75533 .16982 L F
.35176 .17363 m .35293 .1704 L .35483 .17249 L 0 .027 .126 r
F
.35176 .17363 m .34985 .17155 L .35293 .1704 L F
.65508 .17327 m .65675 .16999 L .65833 .17211 L 0 .026 .125 r
F
.65508 .17327 m .6535 .17115 L .65675 .16999 L F
.69221 .17399 m .69393 .17047 L .69547 .17271 L 0 .027 .127 r
F
.69221 .17399 m .69066 .17174 L .69393 .17047 L F
.45018 .17379 m .45151 .17056 L .45331 .17264 L F
.45018 .17379 m .44838 .17169 L .45151 .17056 L F
.70833 .17314 m .71008 .1697 L .7116 .17185 L 0 .026 .125 r
F
.70833 .17314 m .70681 .17101 L .71008 .1697 L F
.70027 .17359 m .70201 .17014 L .70354 .17231 L 0 .027 .126 r
F
.70027 .17359 m .69874 .17143 L .70201 .17014 L F
.59378 .17405 m .59535 .1706 L .597 .17289 L 0 .028 .127 r
F
.59378 .17405 m .59214 .17174 L .59535 .1706 L F
.53248 .17472 m .53395 .17128 L .53566 .17361 L 0 .029 .129 r
F
.53248 .17472 m .53077 .1724 L .53395 .17128 L F
.76157 .17297 m .76342 .16958 L .76488 .17175 L 0 .026 .125 r
F
.76157 .17297 m .76011 .17078 L .76342 .16958 L F
.30657 .17364 m .30766 .17026 L .30962 .17238 L 0 .027 .126 r
F
.30657 .17364 m .30461 .17154 L .30766 .17026 L F
.31462 .17325 m .31573 .16987 L .31768 .17201 L 0 .026 .126 r
F
.31462 .17325 m .31267 .17112 L .31573 .16987 L F
.71639 .17281 m .71817 .16947 L .71968 .17166 L 0 .026 .125 r
F
.71639 .17281 m .71488 .17064 L .71817 .16947 L F
.3598 .1735 m .36098 .17023 L .36288 .17239 L 0 .027 .126 r
F
.3598 .1735 m .35791 .17136 L .36098 .17023 L F
.45823 .17353 m .45958 .17019 L .46137 .1723 L F
.45823 .17353 m .45644 .17144 L .45958 .17019 L F
.40499 .17377 m .40624 .17048 L .40809 .17266 L 0 .028 .127 r
F
.40499 .17377 m .40314 .17158 L .40624 .17048 L F
.49536 .17426 m .49676 .17092 L .49851 .17314 L 0 .028 .128 r
F
.49536 .17426 m .49361 .17204 L .49676 .17092 L F
.76965 .17274 m .77151 .16944 L .77297 .17159 L 0 .026 .125 r
F
.76965 .17274 m .76819 .17058 L .77151 .16944 L F
.32267 .17301 m .3238 .16955 L .32572 .1718 L F
.32267 .17301 m .32073 .17078 L .3238 .16955 L F
.66316 .17326 m .66484 .16985 L .66642 .17214 L 0 .027 .126 r
F
.66316 .17326 m .66158 .17098 L .66484 .16985 L F
.72447 .17263 m .72625 .16922 L .72775 .17137 L 0 .026 .124 r
F
.72447 .17263 m .72297 .17049 L .72625 .16922 L F
.55666 .17378 m .55817 .17037 L .55985 .1725 L 0 .028 .127 r
F
.55666 .17378 m .55498 .17164 L .55817 .17037 L F
.5486 .17424 m .5501 .17077 L .55179 .17292 L 0 .029 .128 r
F
.5486 .17424 m .54691 .17211 L .5501 .17077 L F
.54054 .17469 m .54203 .17124 L .54373 .17345 L 0 .029 .129 r
F
.54054 .17469 m .53884 .17249 L .54203 .17124 L F
.56473 .17337 m .56625 .17011 L .56792 .17222 L 0 .027 .127 r
F
.56473 .17337 m .56305 .17127 L .56625 .17011 L F
.46629 .17338 m .46765 .16981 L .46943 .17214 L 0 .027 .126 r
F
.46629 .17338 m .46451 .17106 L .46765 .16981 L F
.73254 .17227 m .73433 .16892 L .73583 .1711 L 0 .025 .124 r
F
.73254 .17227 m .73104 .17011 L .73433 .16892 L F
.60186 .17406 m .60344 .17067 L .60507 .17295 L 0 .028 .128 r
F
.60186 .17406 m .60022 .17178 L .60344 .17067 L F
.50341 .17408 m .50484 .17064 L .50658 .17284 L F
.50341 .17408 m .50167 .17189 L .50484 .17064 L F
.41303 .17372 m .41431 .17027 L .41614 .17245 L 0 .028 .127 r
F
.41303 .17372 m .41119 .17155 L .41431 .17027 L F
.51147 .17377 m .51291 .17031 L .51464 .17249 L F
.51147 .17377 m .50974 .17158 L .51291 .17031 L F
.36783 .17359 m .36904 .17011 L .37092 .17241 L F
.36783 .17359 m .36595 .17129 L .36904 .17011 L F
.42109 .17337 m .42238 .16991 L .4242 .17211 L 0 .027 .127 r
F
.42109 .17337 m .41926 .17118 L .42238 .16991 L F
.57279 .17317 m .57432 .16984 L .57599 .17197 L 0 .027 .126 r
F
.57279 .17317 m .57112 .17106 L .57432 .16984 L F
.51953 .17343 m .52098 .17009 L .52271 .1723 L 0 .028 .127 r
F
.51953 .17343 m .51781 .17122 L .52098 .17009 L F
.3307 .173 m .33184 .16951 L .33376 .17184 L 0 .027 .126 r
F
.3307 .173 m .32878 .17066 L .33184 .16951 L F
.47434 .17323 m .47572 .16968 L .47749 .17203 L F
.47434 .17323 m .47257 .17089 L .47572 .16968 L F
.60993 .17397 m .61151 .17037 L .61314 .17267 L 0 .028 .128 r
F
.60993 .17397 m .60829 .17168 L .61151 .17037 L F
.67124 .1733 m .67293 .16974 L .6745 .17202 L 0 .027 .126 r
F
.67124 .1733 m .66967 .17099 L .67293 .16974 L F
.42914 .17309 m .43045 .16956 L .43226 .17184 L F
.42914 .17309 m .42732 .17084 L .43045 .16956 L F
.74062 .17222 m .74244 .16893 L .74393 .17113 L 0 .026 .124 r
F
.74062 .17222 m .73913 .17001 L .74244 .16893 L F
.62605 .17318 m .62768 .16988 L .62928 .17198 L 0 .027 .127 r
F
.62605 .17318 m .62444 .17109 L .62768 .16988 L F
.58085 .17296 m .5824 .16954 L .58406 .17176 L 0 .027 .126 r
F
.58085 .17296 m .57919 .17075 L .5824 .16954 L F
.61799 .17366 m .61959 .17012 L .62122 .17238 L 0 .028 .128 r
F
.61799 .17366 m .61637 .17139 L .61959 .17012 L F
.37588 .17345 m .3771 .16989 L .37897 .17218 L 0 .028 .127 r
F
.37588 .17345 m .37401 .17115 L .3771 .16989 L F
.67931 .17301 m .68102 .16956 L .68257 .1718 L 0 .027 .126 r
F
.67931 .17301 m .67775 .17075 L .68102 .16956 L F
.38394 .1731 m .38517 .16963 L .38703 .17183 L 0 .027 .127 r
F
.38394 .1731 m .38207 .1709 L .38517 .16963 L F
.63412 .17292 m .63576 .16965 L .63736 .17177 L F
.63412 .17292 m .63252 .17082 L .63576 .16965 L F
.4372 .17295 m .43851 .16955 L .44032 .17181 L 0 .027 .126 r
F
.4372 .17295 m .43538 .17068 L .43851 .16955 L F
.4824 .17319 m .48378 .16976 L .48554 .17204 L 0 .028 .127 r
F
.4824 .17319 m .48063 .17089 L .48378 .16976 L F
.39199 .17275 m .39323 .16951 L .39509 .17165 L 0 .027 .126 r
F
.39199 .17275 m .39013 .1706 L .39323 .16951 L F
.33873 .17298 m .33989 .1695 L .3418 .17179 L F
.33873 .17298 m .33682 .17067 L .33989 .1695 L F
.74872 .17216 m .75054 .16881 L .75202 .17099 L 0 .026 .125 r
F
.74872 .17216 m .74723 .16998 L .75054 .16881 L F
.5276 .17352 m .52906 .17007 L .53077 .1724 L 0 .028 .128 r
F
.5276 .17352 m .52588 .17118 L .52906 .17007 L F
.64219 .17264 m .64384 .16922 L .64543 .17138 L 0 .027 .126 r
F
.64219 .17264 m .64059 .1705 L .64384 .16922 L F
.68739 .17291 m .68911 .16949 L .69066 .17174 L 0 .027 .127 r
F
.68739 .17291 m .68584 .17065 L .68911 .16949 L F
.58892 .17293 m .59048 .16943 L .59214 .17174 L F
.58892 .17293 m .58727 .1706 L .59048 .16943 L F
.34678 .17272 m .34794 .16942 L .34985 .17155 L 0 .027 .126 r
F
.34678 .17272 m .34487 .1706 L .34794 .16942 L F
.65026 .1723 m .65192 .16902 L .6535 .17115 L 0 .026 .126 r
F
.65026 .1723 m .64867 .17016 L .65192 .16902 L F
.44525 .17282 m .44657 .16955 L .44838 .17169 L 0 .028 .127 r
F
.44525 .17282 m .44344 .17067 L .44657 .16955 L F
.7568 .17199 m .75864 .16863 L .76011 .17078 L 0 .026 .125 r
F
.7568 .17199 m .75533 .16982 L .75864 .16863 L F
.40004 .17268 m .40129 .16945 L .40314 .17158 L 0 .027 .127 r
F
.40004 .17268 m .39819 .17055 L .40129 .16945 L F
.49045 .17315 m .49185 .16982 L .49361 .17204 L 0 .028 .128 r
F
.49045 .17315 m .4887 .17092 L .49185 .16982 L F
.69547 .17271 m .6972 .16918 L .69874 .17143 L 0 .027 .126 r
F
.69547 .17271 m .69393 .17047 L .6972 .16918 L F
.35483 .17249 m .356 .16924 L .35791 .17136 L F
.35483 .17249 m .35293 .1704 L .356 .16924 L F
.7116 .17185 m .71336 .16848 L .71488 .17064 L 0 .026 .125 r
F
.7116 .17185 m .71008 .1697 L .71336 .16848 L F
.70354 .17231 m .70528 .16884 L .70681 .17101 L 0 .026 .126 r
F
.70354 .17231 m .70201 .17014 L .70528 .16884 L F
.65833 .17211 m .66001 .16885 L .66158 .17098 L F
.65833 .17211 m .65675 .16999 L .66001 .16885 L F
.30962 .17238 m .31072 .16899 L .31267 .17112 L 0 .027 .126 r
F
.30962 .17238 m .30766 .17026 L .31072 .16899 L F
.76488 .17175 m .76673 .16842 L .76819 .17058 L 0 .026 .125 r
F
.76488 .17175 m .76342 .16958 L .76673 .16842 L F
.45331 .17264 m .45464 .16936 L .45644 .17144 L 0 .028 .127 r
F
.45331 .17264 m .45151 .17056 L .45464 .16936 L F
.597 .17289 m .59857 .16949 L .60022 .17178 L F
.597 .17289 m .59535 .1706 L .59857 .16949 L F
.31768 .17201 m .31879 .16862 L .32073 .17078 L 0 .026 .125 r
F
.31768 .17201 m .31573 .16987 L .31879 .16862 L F
.53566 .17361 m .53713 .17016 L .53884 .17249 L 0 .029 .129 r
F
.53566 .17361 m .53395 .17128 L .53713 .17016 L F
.46137 .1723 m .46272 .16894 L .46451 .17106 L 0 .027 .126 r
F
.46137 .1723 m .45958 .17019 L .46272 .16894 L F
.71968 .17166 m .72145 .16829 L .72297 .17049 L 0 .026 .125 r
F
.71968 .17166 m .71817 .16947 L .72145 .16829 L F
.36288 .17239 m .36406 .16911 L .36595 .17129 L 0 .027 .127 r
F
.36288 .17239 m .36098 .17023 L .36406 .16911 L F
.40809 .17266 m .40935 .16938 L .41119 .17155 L 0 .028 .127 r
F
.40809 .17266 m .40624 .17048 L .40935 .16938 L F
.49851 .17314 m .49993 .16965 L .50167 .17189 L 0 .028 .128 r
F
.49851 .17314 m .49676 .17092 L .49993 .16965 L F
.55179 .17292 m .55329 .1695 L .55498 .17164 L F
.55179 .17292 m .5501 .17077 L .55329 .1695 L F
.32572 .1718 m .32685 .16842 L .32878 .17066 L 0 .026 .125 r
F
.32572 .1718 m .3238 .16955 L .32685 .16842 L F
.77297 .17159 m .77484 .1683 L .77629 .17043 L F
.77297 .17159 m .77151 .16944 L .77484 .1683 L F
.72775 .17137 m .72954 .16794 L .73104 .17011 L 0 .025 .124 r
F
.72775 .17137 m .72625 .16922 L .72954 .16794 L F
.55985 .1725 m .56137 .16912 L .56305 .17127 L 0 .027 .127 r
F
.55985 .1725 m .55817 .17037 L .56137 .16912 L F
.54373 .17345 m .54521 .16991 L .54691 .17211 L 0 .029 .129 r
F
.54373 .17345 m .54203 .17124 L .54521 .16991 L F
.46943 .17214 m .4708 .16855 L .47257 .17089 L 0 .027 .126 r
F
.46943 .17214 m .46765 .16981 L .4708 .16855 L F
.66642 .17214 m .6681 .16871 L .66967 .17099 L F
.66642 .17214 m .66484 .16985 L .6681 .16871 L F
.50658 .17284 m .508 .16938 L .50974 .17158 L 0 .028 .128 r
F
.50658 .17284 m .50484 .17064 L .508 .16938 L F
.56792 .17222 m .56945 .16894 L .57112 .17106 L 0 .027 .127 r
F
.56792 .17222 m .56625 .17011 L .56945 .16894 L F
.73583 .1711 m .73764 .16781 L .73913 .17001 L 0 .025 .124 r
F
.73583 .1711 m .73433 .16892 L .73764 .16781 L F
.41614 .17245 m .41742 .169 L .41926 .17118 L 0 .028 .127 r
F
.41614 .17245 m .41431 .17027 L .41742 .169 L F
.51464 .17249 m .51608 .16903 L .51781 .17122 L F
.51464 .17249 m .51291 .17031 L .51608 .16903 L F
.60507 .17295 m .60666 .16939 L .60829 .17168 L 0 .028 .128 r
F
.60507 .17295 m .60344 .17067 L .60666 .16939 L F
.4242 .17211 m .4255 .16863 L .42732 .17084 L 0 .027 .126 r
F
.4242 .17211 m .42238 .16991 L .4255 .16863 L F
.37092 .17241 m .37213 .16885 L .37401 .17115 L 0 .027 .127 r
F
.37092 .17241 m .36904 .17011 L .37213 .16885 L F
.57599 .17197 m .57753 .1686 L .57919 .17075 L 0 .027 .126 r
F
.57599 .17197 m .57432 .16984 L .57753 .1686 L F
.61314 .17267 m .61474 .16909 L .61637 .17139 L 0 .028 .128 r
F
.61314 .17267 m .61151 .17037 L .61474 .16909 L F
.6745 .17202 m .67619 .16849 L .67775 .17075 L 0 .027 .126 r
F
.6745 .17202 m .67293 .16974 L .67619 .16849 L F
.47749 .17203 m .47887 .16856 L .48063 .17089 L F
.47749 .17203 m .47572 .16968 L .47887 .16856 L F
.33376 .17184 m .33491 .16836 L .33682 .17067 L F
.33376 .17184 m .33184 .16951 L .33491 .16836 L F
.43226 .17184 m .43357 .16841 L .43538 .17068 L F
.43226 .17184 m .43045 .16956 L .43357 .16841 L F
.52271 .1723 m .52416 .16899 L .52588 .17118 L 0 .028 .127 r
F
.52271 .1723 m .52098 .17009 L .52416 .16899 L F
.62122 .17238 m .62283 .16885 L .62444 .17109 L F
.62122 .17238 m .61959 .17012 L .62283 .16885 L F
.37897 .17218 m .3802 .16863 L .38207 .1709 L 0 .027 .127 r
F
.37897 .17218 m .3771 .16989 L .3802 .16863 L F
.62928 .17198 m .63091 .1687 L .63252 .17082 L F
.62928 .17198 m .62768 .16988 L .63091 .1687 L F
.58406 .17176 m .58561 .16838 L .58727 .1706 L 0 .027 .126 r
F
.58406 .17176 m .5824 .16954 L .58561 .16838 L F
.68257 .1718 m .68429 .16842 L .68584 .17065 L F
.68257 .1718 m .68102 .16956 L .68429 .16842 L F
.74393 .17113 m .74575 .16776 L .74723 .16998 L 0 .026 .125 r
F
.74393 .17113 m .74244 .16893 L .74575 .16776 L F
.38703 .17183 m .38827 .1684 L .39013 .1706 L 0 .027 .126 r
F
.38703 .17183 m .38517 .16963 L .38827 .1684 L F
.63736 .17177 m .639 .16835 L .64059 .1705 L F
.63736 .17177 m .63576 .16965 L .639 .16835 L F
.3418 .17179 m .34296 .16832 L .34487 .1706 L F
.3418 .17179 m .33989 .1695 L .34296 .16832 L F
.44032 .17181 m .44164 .16842 L .44344 .17067 L 0 .027 .127 r
F
.44032 .17181 m .43851 .16955 L .44164 .16842 L F
.48554 .17204 m .48694 .16864 L .4887 .17092 L 0 .028 .127 r
F
.48554 .17204 m .48378 .16976 L .48694 .16864 L F
.64543 .17138 m .64708 .168 L .64867 .17016 L 0 .027 .126 r
F
.64543 .17138 m .64384 .16922 L .64708 .168 L F
.39509 .17165 m .39633 .1684 L .39819 .17055 L 0 .027 .127 r
F
.39509 .17165 m .39323 .16951 L .39633 .1684 L F
.75202 .17099 m .75385 .16765 L .75533 .16982 L 0 .026 .125 r
F
.75202 .17099 m .75054 .16881 L .75385 .16765 L F
.53077 .1724 m .53224 .16895 L .53395 .17128 L 0 .028 .128 r
F
.53077 .1724 m .52906 .17007 L .53224 .16895 L F
.59214 .17174 m .5937 .1683 L .59535 .1706 L 0 .027 .127 r
F
.59214 .17174 m .59048 .16943 L .5937 .1683 L F
.69066 .17174 m .69238 .16821 L .69393 .17047 L 0 .027 .126 r
F
.69066 .17174 m .68911 .16949 L .69238 .16821 L F
.34985 .17155 m .35102 .16825 L .35293 .1704 L 0 .027 .127 r
F
.34985 .17155 m .34794 .16942 L .35102 .16825 L F
.6535 .17115 m .65518 .16787 L .65675 .16999 L 0 .027 .126 r
F
.6535 .17115 m .65192 .16902 L .65518 .16787 L F
.69874 .17143 m .70047 .1679 L .70201 .17014 L F
.69874 .17143 m .6972 .16918 L .70047 .1679 L F
.76011 .17078 m .76195 .16745 L .76342 .16958 L 0 .026 .125 r
F
.76011 .17078 m .75864 .16863 L .76195 .16745 L F
.70681 .17101 m .70856 .16753 L .71008 .1697 L F
.70681 .17101 m .70528 .16884 L .70856 .16753 L F
.44838 .17169 m .4497 .16843 L .45151 .17056 L 0 .028 .127 r
F
.44838 .17169 m .44657 .16955 L .4497 .16843 L F
.71488 .17064 m .71665 .16728 L .71817 .16947 L 0 .026 .125 r
F
.71488 .17064 m .71336 .16848 L .71665 .16728 L F
.31267 .17112 m .31378 .16771 L .31573 .16987 L 0 .027 .126 r
F
.31267 .17112 m .31072 .16899 L .31378 .16771 L F
.40314 .17158 m .40439 .16834 L .40624 .17048 L 0 .028 .127 r
F
.40314 .17158 m .40129 .16945 L .40439 .16834 L F
.35791 .17136 m .35908 .1681 L .36098 .17023 L 0 .027 .127 r
F
.35791 .17136 m .356 .16924 L .35908 .1681 L F
.49361 .17204 m .49501 .1687 L .49676 .17092 L 0 .028 .128 r
F
.49361 .17204 m .49185 .16982 L .49501 .1687 L F
.66158 .17098 m .66327 .16771 L .66484 .16985 L 0 .027 .126 r
F
.66158 .17098 m .66001 .16885 L .66327 .16771 L F
.45644 .17144 m .45778 .16809 L .45958 .17019 L 0 .027 .127 r
F
.45644 .17144 m .45464 .16936 L .45778 .16809 L F
.32073 .17078 m .32186 .16736 L .3238 .16955 L 0 .026 .125 r
F
.32073 .17078 m .31879 .16862 L .32186 .16736 L F
.76819 .17058 m .77006 .1673 L .77151 .16944 L F
.76819 .17058 m .76673 .16842 L .77006 .1673 L F
.46451 .17106 m .46586 .16767 L .46765 .16981 L 0 .027 .126 r
F
.46451 .17106 m .46272 .16894 L .46586 .16767 L F
.60022 .17178 m .6018 .16839 L .60344 .17067 L 0 .028 .128 r
F
.60022 .17178 m .59857 .16949 L .6018 .16839 L F
.53884 .17249 m .54032 .16893 L .54203 .17124 L 0 .029 .129 r
F
.53884 .17249 m .53713 .17016 L .54032 .16893 L F
.72297 .17049 m .72474 .16699 L .72625 .16922 L 0 .026 .124 r
F
.72297 .17049 m .72145 .16829 L .72474 .16699 L F
.55498 .17164 m .55649 .16823 L .55817 .17037 L 0 .028 .127 r
F
.55498 .17164 m .55329 .1695 L .55649 .16823 L F
.54691 .17211 m .5484 .16857 L .5501 .17077 L 0 .029 .128 r
F
.54691 .17211 m .54521 .16991 L .5484 .16857 L F
.50167 .17189 m .50309 .16838 L .50484 .17064 L 0 .028 .128 r
F
.50167 .17189 m .49993 .16965 L .50309 .16838 L F
.73104 .17011 m .73284 .16673 L .73433 .16892 L 0 .025 .124 r
F
.73104 .17011 m .72954 .16794 L .73284 .16673 L F
.56305 .17127 m .56457 .16793 L .56625 .17011 L 0 .027 .127 r
F
.56305 .17127 m .56137 .16912 L .56457 .16793 L F
.36595 .17129 m .36715 .16793 L .36904 .17011 L F
.36595 .17129 m .36406 .16911 L .36715 .16793 L F
.41119 .17155 m .41247 .16809 L .41431 .17027 L 0 .028 .127 r
F
.41119 .17155 m .40935 .16938 L .41247 .16809 L F
.32878 .17066 m .32992 .16729 L .33184 .16951 L 0 .026 .125 r
F
.32878 .17066 m .32685 .16842 L .32992 .16729 L F
.47257 .17089 m .47394 .16734 L .47572 .16968 L 0 .026 .126 r
F
.47257 .17089 m .4708 .16855 L .47394 .16734 L F
.50974 .17158 m .51117 .16811 L .51291 .17031 L 0 .028 .127 r
F
.50974 .17158 m .508 .16938 L .51117 .16811 L F
.41926 .17118 m .42055 .16772 L .42238 .16991 L 0 .027 .127 r
F
.41926 .17118 m .41742 .169 L .42055 .16772 L F
.51781 .17122 m .51926 .16791 L .52098 .17009 L 0 .028 .127 r
F
.51781 .17122 m .51608 .16903 L .51926 .16791 L F
.66967 .17099 m .67136 .16748 L .67293 .16974 L 0 .027 .126 r
F
.66967 .17099 m .6681 .16871 L .67136 .16748 L F
.60829 .17168 m .60988 .16809 L .61151 .17037 L 0 .028 .128 r
F
.60829 .17168 m .60666 .16939 L .60988 .16809 L F
.42732 .17084 m .42862 .16735 L .43045 .16956 L 0 .027 .126 r
F
.42732 .17084 m .4255 .16863 L .42862 .16735 L F
.57112 .17106 m .57266 .16771 L .57432 .16984 L 0 .027 .127 r
F
.57112 .17106 m .56945 .16894 L .57266 .16771 L F
.73913 .17001 m .74095 .1667 L .74244 .16893 L 0 .026 .124 r
F
.73913 .17001 m .73764 .16781 L .74095 .1667 L F
.37401 .17115 m .37523 .1676 L .3771 .16989 L 0 .027 .127 r
F
.37401 .17115 m .37213 .16885 L .37523 .1676 L F
.61637 .17139 m .61797 .16784 L .61959 .17012 L 0 .028 .127 r
F
.61637 .17139 m .61474 .16909 L .61797 .16784 L F
.67775 .17075 m .67946 .16732 L .68102 .16956 L 0 .027 .126 r
F
.67775 .17075 m .67619 .16849 L .67946 .16732 L F
.57919 .17075 m .58074 .16737 L .5824 .16954 L F
.57919 .17075 m .57753 .1686 L .58074 .16737 L F
.62444 .17109 m .62606 .16763 L .62768 .16988 L 0 .028 .127 r
F
.62444 .17109 m .62283 .16885 L .62606 .16763 L F
.48063 .17089 m .48202 .16743 L .48378 .16976 L 0 .027 .126 r
F
.48063 .17089 m .47887 .16856 L .48202 .16743 L F
.33682 .17067 m .33798 .1672 L .33989 .1695 L F
.33682 .17067 m .33491 .16836 L .33798 .1672 L F
.38207 .1709 m .3833 .16736 L .38517 .16963 L F
.38207 .1709 m .3802 .16863 L .3833 .16736 L F
.43538 .17068 m .4367 .16729 L .43851 .16955 L F
.43538 .17068 m .43357 .16841 L .4367 .16729 L F
.52588 .17118 m .52734 .16788 L .52906 .17007 L 0 .028 .128 r
F
.52588 .17118 m .52416 .16899 L .52734 .16788 L F
.63252 .17082 m .63416 .16752 L .63576 .16965 L 0 .027 .127 r
F
.63252 .17082 m .63091 .1687 L .63416 .16752 L F
.58727 .1706 m .58883 .16722 L .59048 .16943 L 0 .027 .126 r
F
.58727 .1706 m .58561 .16838 L .58883 .16722 L F
.39013 .1706 m .39136 .1673 L .39323 .16951 L F
.39013 .1706 m .38827 .1684 L .39136 .1673 L F
.68584 .17065 m .68756 .16729 L .68911 .16949 L F
.68584 .17065 m .68429 .16842 L .68756 .16729 L F
.74723 .16998 m .74906 .16659 L .75054 .16881 L 0 .026 .125 r
F
.74723 .16998 m .74575 .16776 L .74906 .16659 L F
.64059 .1705 m .64224 .16705 L .64384 .16922 L 0 .027 .126 r
F
.64059 .1705 m .639 .16835 L .64224 .16705 L F
.34487 .1706 m .34604 .16713 L .34794 .16942 L F
.34487 .1706 m .34296 .16832 L .34604 .16713 L F
.64867 .17016 m .65033 .16685 L .65192 .16902 L F
.64867 .17016 m .64708 .168 L .65033 .16685 L F
.44344 .17067 m .44477 .1673 L .44657 .16955 L 0 .027 .127 r
F
.44344 .17067 m .44164 .16842 L .44477 .1673 L F
.69393 .17047 m .69565 .16693 L .6972 .16918 L 0 .027 .126 r
F
.69393 .17047 m .69238 .16821 L .69565 .16693 L F
.4887 .17092 m .4901 .16754 L .49185 .16982 L 0 .028 .128 r
F
.4887 .17092 m .48694 .16864 L .4901 .16754 L F
.75533 .16982 m .75717 .16648 L .75864 .16863 L 0 .026 .125 r
F
.75533 .16982 m .75385 .16765 L .75717 .16648 L F
.39819 .17055 m .39943 .1673 L .40129 .16945 L 0 .028 .127 r
F
.39819 .17055 m .39633 .1684 L .39943 .1673 L F
.70201 .17014 m .70375 .16662 L .70528 .16884 L 0 .026 .126 r
F
.70201 .17014 m .70047 .1679 L .70375 .16662 L F
.59535 .1706 m .59692 .1672 L .59857 .16949 L 0 .027 .127 r
F
.59535 .1706 m .5937 .1683 L .59692 .1672 L F
.71008 .1697 m .71184 .1663 L .71336 .16848 L 0 .026 .125 r
F
.71008 .1697 m .70856 .16753 L .71184 .1663 L F
.53395 .17128 m .53542 .16783 L .53713 .17016 L 0 .029 .128 r
F
.53395 .17128 m .53224 .16895 L .53542 .16783 L F
.35293 .1704 m .3541 .16707 L .356 .16924 L 0 .027 .127 r
F
.35293 .1704 m .35102 .16825 L .3541 .16707 L F
.65675 .16999 m .65843 .16672 L .66001 .16885 L 0 .027 .126 r
F
.65675 .16999 m .65518 .16787 L .65843 .16672 L F
.76342 .16958 m .76527 .16629 L .76673 .16842 L 0 .026 .125 r
F
.76342 .16958 m .76195 .16745 L .76527 .16629 L F
.31573 .16987 m .31685 .16644 L .31879 .16862 L F
.31573 .16987 m .31378 .16771 L .31685 .16644 L F
.45151 .17056 m .45284 .16722 L .45464 .16936 L 0 .028 .127 r
F
.45151 .17056 m .4497 .16843 L .45284 .16722 L F
.71817 .16947 m .71994 .16607 L .72145 .16829 L 0 .026 .125 r
F
.71817 .16947 m .71665 .16728 L .71994 .16607 L F
.45958 .17019 m .46093 .16682 L .46272 .16894 L 0 .027 .126 r
F
.45958 .17019 m .45778 .16809 L .46093 .16682 L F
.3238 .16955 m .32492 .16624 L .32685 .16842 L 0 .026 .125 r
F
.3238 .16955 m .32186 .16736 L .32492 .16624 L F
.36098 .17023 m .36217 .16695 L .36406 .16911 L 0 .027 .127 r
F
.36098 .17023 m .35908 .1681 L .36217 .16695 L F
.49676 .17092 m .49818 .16741 L .49993 .16965 L 0 .028 .128 r
F
.49676 .17092 m .49501 .1687 L .49818 .16741 L F
.46765 .16981 m .46901 .1664 L .4708 .16855 L 0 .026 .126 r
F
.46765 .16981 m .46586 .16767 L .46901 .1664 L F
.40624 .17048 m .4075 .16724 L .40935 .16938 L 0 .028 .127 r
F
.40624 .17048 m .40439 .16834 L .4075 .16724 L F
.66484 .16985 m .66653 .16655 L .6681 .16871 L 0 .027 .126 r
F
.66484 .16985 m .66327 .16771 L .66653 .16655 L F
.5501 .17077 m .5516 .16731 L .55329 .1695 L 0 .028 .128 r
F
.5501 .17077 m .5484 .16857 L .5516 .16731 L F
.77151 .16944 m .77339 .16617 L .77484 .1683 L 0 .026 .125 r
F
.77151 .16944 m .77006 .1673 L .77339 .16617 L F
.72625 .16922 m .72803 .1657 L .72954 .16794 L 0 .025 .124 r
F
.72625 .16922 m .72474 .16699 L .72803 .1657 L F
.54203 .17124 m .54351 .16762 L .54521 .16991 L 0 .029 .129 r
F
.54203 .17124 m .54032 .16893 L .54351 .16762 L F
.55817 .17037 m .55968 .16697 L .56137 .16912 L 0 .028 .127 r
F
.55817 .17037 m .55649 .16823 L .55968 .16697 L F
.50484 .17064 m .50626 .16711 L .508 .16938 L 0 .028 .128 r
F
.50484 .17064 m .50309 .16838 L .50626 .16711 L F
.60344 .17067 m .60502 .16712 L .60666 .16939 L F
.60344 .17067 m .6018 .16839 L .60502 .16712 L F
.73433 .16892 m .73614 .1656 L .73764 .16781 L 0 .025 .124 r
F
.73433 .16892 m .73284 .16673 L .73614 .1656 L F
.41431 .17027 m .41559 .16681 L .41742 .169 L 0 .028 .127 r
F
.41431 .17027 m .41247 .16809 L .41559 .16681 L F
.51291 .17031 m .51435 .16683 L .51608 .16903 L F
.51291 .17031 m .51117 .16811 L .51435 .16683 L F
.36904 .17011 m .37024 .16669 L .37213 .16885 L 0 .027 .127 r
F
.36904 .17011 m .36715 .16793 L .37024 .16669 L F
.56625 .17011 m .56777 .16673 L .56945 .16894 L F
.56625 .17011 m .56457 .16793 L .56777 .16673 L F
.47572 .16968 m .4771 .16622 L .47887 .16856 L 0 .027 .126 r
F
.47572 .16968 m .47394 .16734 L .4771 .16622 L F
.42238 .16991 m .42367 .16644 L .4255 .16863 L F
.42238 .16991 m .42055 .16772 L .42367 .16644 L F
.61151 .17037 m .61311 .1668 L .61474 .16909 L 0 .028 .127 r
F
.61151 .17037 m .60988 .16809 L .61311 .1668 L F
.33184 .16951 m .33298 .16615 L .33491 .16836 L 0 .026 .126 r
F
.33184 .16951 m .32992 .16729 L .33298 .16615 L F
.67293 .16974 m .67463 .16624 L .67619 .16849 L 0 .027 .126 r
F
.67293 .16974 m .67136 .16748 L .67463 .16624 L F
.43045 .16956 m .43175 .1662 L .43357 .16841 L F
.43045 .16956 m .42862 .16735 L .43175 .1662 L F
.57432 .16984 m .57586 .16645 L .57753 .1686 L F
.57432 .16984 m .57266 .16771 L .57586 .16645 L F
.52098 .17009 m .52243 .16682 L .52416 .16899 L 0 .028 .127 r
F
.52098 .17009 m .51926 .16791 L .52243 .16682 L F
.3771 .16989 m .37832 .16634 L .3802 .16863 L 0 .027 .126 r
F
.3771 .16989 m .37523 .1676 L .37832 .16634 L F
.61959 .17012 m .6212 .16658 L .62283 .16885 L 0 .027 .127 r
F
.61959 .17012 m .61797 .16784 L .6212 .16658 L F
.5824 .16954 m .58396 .16622 L .58561 .16838 L 0 .027 .126 r
F
.5824 .16954 m .58074 .16737 L .58396 .16622 L F
.68102 .16956 m .68273 .16621 L .68429 .16842 L F
.68102 .16956 m .67946 .16732 L .68273 .16621 L F
.74244 .16893 m .74426 .16552 L .74575 .16776 L 0 .026 .125 r
F
.74244 .16893 m .74095 .1667 L .74426 .16552 L F
.38517 .16963 m .3864 .16613 L .38827 .1684 L 0 .027 .126 r
F
.38517 .16963 m .3833 .16736 L .3864 .16613 L F
.62768 .16988 m .6293 .16644 L .63091 .1687 L 0 .027 .127 r
F
.62768 .16988 m .62606 .16763 L .6293 .16644 L F
.33989 .1695 m .34105 .16604 L .34296 .16832 L 0 .027 .126 r
F
.33989 .1695 m .33798 .1672 L .34105 .16604 L F
.48378 .16976 m .48517 .16632 L .48694 .16864 L 0 .027 .127 r
F
.48378 .16976 m .48202 .16743 L .48517 .16632 L F
.43851 .16955 m .43983 .16616 L .44164 .16842 L 0 .027 .126 r
F
.43851 .16955 m .4367 .16729 L .43983 .16616 L F
.52906 .17007 m .53052 .16675 L .53224 .16895 L 0 .028 .128 r
F
.52906 .17007 m .52734 .16788 L .53052 .16675 L F
.63576 .16965 m .6374 .1662 L .639 .16835 L 0 .027 .127 r
F
.63576 .16965 m .63416 .16752 L .6374 .1662 L F
.59048 .16943 m .59205 .16609 L .5937 .1683 L 0 .027 .126 r
F
.59048 .16943 m .58883 .16722 L .59205 .16609 L F
.64384 .16922 m .64549 .16581 L .64708 .168 L F
.64384 .16922 m .64224 .16705 L .64549 .16581 L F
.75054 .16881 m .75237 .16541 L .75385 .16765 L 0 .026 .125 r
F
.75054 .16881 m .74906 .16659 L .75237 .16541 L F
.68911 .16949 m .69084 .16601 L .69238 .16821 L 0 .027 .126 r
F
.68911 .16949 m .68756 .16729 L .69084 .16601 L F
.39323 .16951 m .39447 .16619 L .39633 .1684 L 0 .027 .127 r
F
.39323 .16951 m .39136 .1673 L .39447 .16619 L F
.6972 .16918 m .69893 .16565 L .70047 .1679 L 0 .027 .126 r
F
.6972 .16918 m .69565 .16693 L .69893 .16565 L F
.34794 .16942 m .34912 .16594 L .35102 .16825 L F
.34794 .16942 m .34604 .16713 L .34912 .16594 L F
.65192 .16902 m .65359 .1657 L .65518 .16787 L F
.65192 .16902 m .65033 .16685 L .65359 .1657 L F
.70528 .16884 m .70703 .16533 L .70856 .16753 L 0 .026 .125 r
F
.70528 .16884 m .70375 .16662 L .70703 .16533 L F
.75864 .16863 m .76048 .16531 L .76195 .16745 L F
.75864 .16863 m .75717 .16648 L .76048 .16531 L F
.44657 .16955 m .4479 .16618 L .4497 .16843 L 0 .028 .127 r
F
.44657 .16955 m .44477 .1673 L .4479 .16618 L F
.49185 .16982 m .49326 .16642 L .49501 .1687 L 0 .028 .128 r
F
.49185 .16982 m .4901 .16754 L .49326 .16642 L F
.71336 .16848 m .71513 .16509 L .71665 .16728 L 0 .026 .125 r
F
.71336 .16848 m .71184 .1663 L .71513 .16509 L F
.40129 .16945 m .40254 .1662 L .40439 .16834 L 0 .028 .127 r
F
.40129 .16945 m .39943 .1673 L .40254 .1662 L F
.356 .16924 m .35718 .16591 L .35908 .1681 L 0 .027 .127 r
F
.356 .16924 m .3541 .16707 L .35718 .16591 L F
.53713 .17016 m .53861 .16661 L .54032 .16893 L 0 .029 .128 r
F
.53713 .17016 m .53542 .16783 L .53861 .16661 L F
.59857 .16949 m .60015 .1661 L .6018 .16839 L 0 .028 .127 r
F
.59857 .16949 m .59692 .1672 L .60015 .1661 L F
.31879 .16862 m .31992 .16517 L .32186 .16736 L 0 .026 .125 r
F
.31879 .16862 m .31685 .16644 L .31992 .16517 L F
.66001 .16885 m .6617 .16556 L .66327 .16771 L 0 .027 .126 r
F
.66001 .16885 m .65843 .16672 L .6617 .16556 L F
.76673 .16842 m .7686 .16517 L .77006 .1673 L 0 .026 .125 r
F
.76673 .16842 m .76527 .16629 L .7686 .16517 L F
.45464 .16936 m .45599 .16593 L .45778 .16809 L 0 .028 .127 r
F
.45464 .16936 m .45284 .16722 L .45599 .16593 L F
.46272 .16894 m .46408 .16554 L .46586 .16767 L 0 .027 .126 r
F
.46272 .16894 m .46093 .16682 L .46408 .16554 L F
.72145 .16829 m .72323 .16477 L .72474 .16699 L 0 .026 .124 r
F
.72145 .16829 m .71994 .16607 L .72323 .16477 L F
.49993 .16965 m .50135 .16612 L .50309 .16838 L 0 .028 .128 r
F
.49993 .16965 m .49818 .16741 L .50135 .16612 L F
.4708 .16855 m .47217 .16518 L .47394 .16734 L 0 .026 .125 r
F
.4708 .16855 m .46901 .1664 L .47217 .16518 L F
.54521 .16991 m .5467 .16631 L .5484 .16857 L 0 .028 .128 r
F
.54521 .16991 m .54351 .16762 L .5467 .16631 L F
.55329 .1695 m .5548 .16606 L .55649 .16823 L F
.55329 .1695 m .5516 .16731 L .5548 .16606 L F
.72954 .16794 m .73133 .16448 L .73284 .16673 L 0 .025 .124 r
F
.72954 .16794 m .72803 .1657 L .73133 .16448 L F
.32685 .16842 m .32798 .16512 L .32992 .16729 L 0 .026 .125 r
F
.32685 .16842 m .32492 .16624 L .32798 .16512 L F
.36406 .16911 m .36526 .16576 L .36715 .16793 L 0 .027 .127 r
F
.36406 .16911 m .36217 .16695 L .36526 .16576 L F
.56137 .16912 m .56289 .16575 L .56457 .16793 L F
.56137 .16912 m .55968 .16697 L .56289 .16575 L F
.40935 .16938 m .41062 .16595 L .41247 .16809 L 0 .028 .127 r
F
.40935 .16938 m .4075 .16724 L .41062 .16595 L F
.6681 .16871 m .6698 .16531 L .67136 .16748 L 0 .027 .126 r
F
.6681 .16871 m .66653 .16655 L .6698 .16531 L F
.508 .16938 m .50944 .16583 L .51117 .16811 L 0 .028 .127 r
F
.508 .16938 m .50626 .16711 L .50944 .16583 L F
.60666 .16939 m .60825 .16584 L .60988 .16809 L F
.60666 .16939 m .60502 .16712 L .60825 .16584 L F
.41742 .169 m .41871 .16553 L .42055 .16772 L 0 .027 .127 r
F
.41742 .169 m .41559 .16681 L .41871 .16553 L F
.51608 .16903 m .51752 .16571 L .51926 .16791 L 0 .028 .127 r
F
.51608 .16903 m .51435 .16683 L .51752 .16571 L F
.37213 .16885 m .37334 .16545 L .37523 .1676 L 0 .027 .126 r
F
.37213 .16885 m .37024 .16669 L .37334 .16545 L F
.4255 .16863 m .4268 .16516 L .42862 .16735 L F
.4255 .16863 m .42367 .16644 L .4268 .16516 L F
.61474 .16909 m .61634 .16557 L .61797 .16784 L 0 .027 .127 r
F
.61474 .16909 m .61311 .1668 L .61634 .16557 L F
.73764 .16781 m .73945 .16448 L .74095 .1667 L 0 .025 .124 r
F
.73764 .16781 m .73614 .1656 L .73945 .16448 L F
.67619 .16849 m .6779 .16509 L .67946 .16732 L 0 .027 .126 r
F
.67619 .16849 m .67463 .16624 L .6779 .16509 L F
.56945 .16894 m .57098 .16547 L .57266 .16771 L 0 .027 .127 r
F
.56945 .16894 m .56777 .16673 L .57098 .16547 L F
.47887 .16856 m .48025 .1651 L .48202 .16743 L 0 .027 .126 r
F
.47887 .16856 m .4771 .16622 L .48025 .1651 L F
.33491 .16836 m .33605 .16501 L .33798 .1672 L F
.33491 .16836 m .33298 .16615 L .33605 .16501 L F
.57753 .1686 m .57908 .1652 L .58074 .16737 L F
.57753 .1686 m .57586 .16645 L .57908 .1652 L F
.62283 .16885 m .62444 .16537 L .62606 .16763 L 0 .027 .127 r
F
.62283 .16885 m .6212 .16658 L .62444 .16537 L F
.3802 .16863 m .38143 .16509 L .3833 .16736 L 0 .027 .126 r
F
.3802 .16863 m .37832 .16634 L .38143 .16509 L F
.43357 .16841 m .43488 .16508 L .4367 .16729 L F
.43357 .16841 m .43175 .1662 L .43488 .16508 L F
.52416 .16899 m .52562 .16571 L .52734 .16788 L 0 .028 .128 r
F
.52416 .16899 m .52243 .16682 L .52562 .16571 L F
.58561 .16838 m .58717 .16506 L .58883 .16722 L 0 .027 .126 r
F
.58561 .16838 m .58396 .16622 L .58717 .16506 L F
.38827 .1684 m .3895 .16502 L .39136 .1673 L F
.38827 .1684 m .3864 .16613 L .3895 .16502 L F
.68429 .16842 m .68601 .16509 L .68756 .16729 L F
.68429 .16842 m .68273 .16621 L .68601 .16509 L F
.74575 .16776 m .74757 .16432 L .74906 .16659 L 0 .026 .125 r
F
.74575 .16776 m .74426 .16552 L .74757 .16432 L F
.63091 .1687 m .63255 .16525 L .63416 .16752 L 0 .027 .127 r
F
.63091 .1687 m .6293 .16644 L .63255 .16525 L F
.34296 .16832 m .34413 .16484 L .34604 .16713 L 0 .027 .126 r
F
.34296 .16832 m .34105 .16604 L .34413 .16484 L F
.639 .16835 m .64064 .16488 L .64224 .16705 L F
.639 .16835 m .6374 .1662 L .64064 .16488 L F
.44164 .16842 m .44296 .16505 L .44477 .1673 L 0 .027 .127 r
F
.44164 .16842 m .43983 .16616 L .44296 .16505 L F
.48694 .16864 m .48834 .16521 L .4901 .16754 L 0 .028 .127 r
F
.48694 .16864 m .48517 .16632 L .48834 .16521 L F
.69238 .16821 m .69411 .16473 L .69565 .16693 L 0 .027 .126 r
F
.69238 .16821 m .69084 .16601 L .69411 .16473 L F
.64708 .168 m .64874 .16465 L .65033 .16685 L F
.64708 .168 m .64549 .16581 L .64874 .16465 L F
.53224 .16895 m .53371 .16562 L .53542 .16783 L 0 .028 .128 r
F
.53224 .16895 m .53052 .16675 L .53371 .16562 L F
.5937 .1683 m .59528 .16498 L .59692 .1672 L 0 .027 .127 r
F
.5937 .1683 m .59205 .16609 L .59528 .16498 L F
.75385 .16765 m .75569 .16424 L .75717 .16648 L 0 .026 .125 r
F
.75385 .16765 m .75237 .16541 L .75569 .16424 L F
.70047 .1679 m .70221 .16439 L .70375 .16662 L F
.70047 .1679 m .69893 .16565 L .70221 .16439 L F
.39633 .1684 m .39757 .16508 L .39943 .1673 L 0 .028 .127 r
F
.39633 .1684 m .39447 .16619 L .39757 .16508 L F
.70856 .16753 m .71031 .16411 L .71184 .1663 L 0 .026 .125 r
F
.70856 .16753 m .70703 .16533 L .71031 .16411 L F
.35102 .16825 m .3522 .16474 L .3541 .16707 L 0 .027 .126 r
F
.35102 .16825 m .34912 .16594 L .3522 .16474 L F
.65518 .16787 m .65685 .16453 L .65843 .16672 L F
.65518 .16787 m .65359 .1657 L .65685 .16453 L F
.76195 .16745 m .76381 .16416 L .76527 .16629 L 0 .026 .125 r
F
.76195 .16745 m .76048 .16531 L .76381 .16416 L F
.71665 .16728 m .71842 .16387 L .71994 .16607 L F
.71665 .16728 m .71513 .16509 L .71842 .16387 L F
.4497 .16843 m .45104 .16496 L .45284 .16722 L 0 .028 .127 r
F
.4497 .16843 m .4479 .16618 L .45104 .16496 L F
.49501 .1687 m .49642 .16513 L .49818 .16741 L 0 .028 .128 r
F
.49501 .1687 m .49326 .16642 L .49642 .16513 L F
.54032 .16893 m .5418 .16532 L .54351 .16762 L F
.54032 .16893 m .53861 .16661 L .5418 .16532 L F
.32186 .16736 m .32298 .16406 L .32492 .16624 L 0 .026 .125 r
F
.32186 .16736 m .31992 .16517 L .32298 .16406 L F
.45778 .16809 m .45913 .16465 L .46093 .16682 L 0 .027 .127 r
F
.45778 .16809 m .45599 .16593 L .45913 .16465 L F
.35908 .1681 m .36027 .16474 L .36217 .16695 L F
.35908 .1681 m .35718 .16591 L .36027 .16474 L F
.72474 .16699 m .72652 .16346 L .72803 .1657 L 0 .025 .124 r
F
.72474 .16699 m .72323 .16477 L .72652 .16346 L F
.46586 .16767 m .46723 .16426 L .46901 .1664 L 0 .027 .126 r
F
.46586 .16767 m .46408 .16554 L .46723 .16426 L F
.40439 .16834 m .40565 .16509 L .4075 .16724 L 0 .028 .128 r
F
.40439 .16834 m .40254 .1662 L .40565 .16509 L F
.5484 .16857 m .5499 .16507 L .5516 .16731 L F
.5484 .16857 m .5467 .16631 L .5499 .16507 L F
.66327 .16771 m .66496 .16439 L .66653 .16655 L 0 .027 .126 r
F
.66327 .16771 m .6617 .16556 L .66496 .16439 L F
.50309 .16838 m .50452 .16484 L .50626 .16711 L 0 .028 .127 r
F
.50309 .16838 m .50135 .16612 L .50452 .16484 L F
.6018 .16839 m .60338 .16485 L .60502 .16712 L F
.6018 .16839 m .60015 .1661 L .60338 .16485 L F
.77006 .1673 m .77193 .16404 L .77339 .16617 L 0 .026 .125 r
F
.77006 .1673 m .7686 .16517 L .77193 .16404 L F
.55649 .16823 m .558 .1648 L .55968 .16697 L 0 .028 .127 r
F
.55649 .16823 m .5548 .16606 L .558 .1648 L F
.47394 .16734 m .47532 .16406 L .4771 .16622 L 0 .026 .125 r
F
.47394 .16734 m .47217 .16518 L .47532 .16406 L F
.73284 .16673 m .73464 .16334 L .73614 .1656 L 0 .025 .124 r
F
.73284 .16673 m .73133 .16448 L .73464 .16334 L F
.60988 .16809 m .61148 .16458 L .61311 .1668 L 0 .027 .127 r
F
.60988 .16809 m .60825 .16584 L .61148 .16458 L F
.41247 .16809 m .41374 .16466 L .41559 .16681 L 0 .028 .127 r
F
.41247 .16809 m .41062 .16595 L .41374 .16466 L F
.51117 .16811 m .51261 .16456 L .51435 .16683 L 0 .027 .127 r
F
.51117 .16811 m .50944 .16583 L .51261 .16456 L F
.67136 .16748 m .67306 .16407 L .67463 .16624 L 0 .027 .126 r
F
.67136 .16748 m .6698 .16531 L .67306 .16407 L F
.36715 .16793 m .36835 .16454 L .37024 .16669 L 0 .027 .127 r
F
.36715 .16793 m .36526 .16576 L .36835 .16454 L F
.56457 .16793 m .56609 .16452 L .56777 .16673 L F
.56457 .16793 m .56289 .16575 L .56609 .16452 L F
.42055 .16772 m .42184 .16425 L .42367 .16644 L 0 .027 .126 r
F
.42055 .16772 m .41871 .16553 L .42184 .16425 L F
.32992 .16729 m .33105 .164 L .33298 .16615 L 0 .026 .126 r
F
.32992 .16729 m .32798 .16512 L .33105 .164 L F
.42862 .16735 m .42993 .16401 L .43175 .1662 L 0 .027 .126 r
F
.42862 .16735 m .4268 .16516 L .42993 .16401 L F
.37523 .1676 m .37644 .16421 L .37832 .16634 L F
.37523 .1676 m .37334 .16545 L .37644 .16421 L F
.61797 .16784 m .61958 .16434 L .6212 .16658 L 0 .027 .127 r
F
.61797 .16784 m .61634 .16557 L .61958 .16434 L F
.51926 .16791 m .52071 .16462 L .52243 .16682 L 0 .028 .127 r
F
.51926 .16791 m .51752 .16571 L .52071 .16462 L F
.57266 .16771 m .57419 .16418 L .57586 .16645 L 0 .027 .126 r
F
.57266 .16771 m .57098 .16547 L .57419 .16418 L F
.67946 .16732 m .68118 .16399 L .68273 .16621 L F
.67946 .16732 m .6779 .16509 L .68118 .16399 L F
.3833 .16736 m .38453 .16386 L .3864 .16613 L F
.3833 .16736 m .38143 .16509 L .38453 .16386 L F
.58074 .16737 m .58229 .16405 L .58396 .16622 L F
.58074 .16737 m .57908 .1652 L .58229 .16405 L F
.74095 .1667 m .74276 .16327 L .74426 .16552 L 0 .026 .124 r
F
.74095 .1667 m .73945 .16448 L .74276 .16327 L F
.62606 .16763 m .62768 .16416 L .6293 .16644 L 0 .027 .127 r
F
.62606 .16763 m .62444 .16537 L .62768 .16416 L F
.33798 .1672 m .33913 .16386 L .34105 .16604 L 0 .027 .126 r
F
.33798 .1672 m .33605 .16501 L .33913 .16386 L F
.48202 .16743 m .48341 .16398 L .48517 .16632 L F
.48202 .16743 m .48025 .1651 L .48341 .16398 L F
.4367 .16729 m .43801 .16396 L .43983 .16616 L F
.4367 .16729 m .43488 .16508 L .43801 .16396 L F
.52734 .16788 m .5288 .16458 L .53052 .16675 L 0 .028 .128 r
F
.52734 .16788 m .52562 .16571 L .5288 .16458 L F
.58883 .16722 m .5904 .16393 L .59205 .16609 L 0 .027 .126 r
F
.58883 .16722 m .58717 .16506 L .5904 .16393 L F
.74906 .16659 m .75088 .16313 L .75237 .16541 L 0 .026 .125 r
F
.74906 .16659 m .74757 .16432 L .75088 .16313 L F
.64224 .16705 m .64389 .16362 L .64549 .16581 L 0 .027 .126 r
F
.64224 .16705 m .64064 .16488 L .64389 .16362 L F
.68756 .16729 m .68929 .16383 L .69084 .16601 L F
.68756 .16729 m .68601 .16509 L .68929 .16383 L F
.63416 .16752 m .63579 .16393 L .6374 .1662 L 0 .027 .127 r
F
.63416 .16752 m .63255 .16525 L .63579 .16393 L F
.39136 .1673 m .39261 .1639 L .39447 .16619 L 0 .027 .126 r
F
.39136 .1673 m .3895 .16502 L .39261 .1639 L F
.34604 .16713 m .34721 .16363 L .34912 .16594 L F
.34604 .16713 m .34413 .16484 L .34721 .16363 L F
.69565 .16693 m .69739 .16346 L .69893 .16565 L 0 .026 .126 r
F
.69565 .16693 m .69411 .16473 L .69739 .16346 L F
.70375 .16662 m .7055 .16313 L .70703 .16533 L 0 .026 .125 r
F
.70375 .16662 m .70221 .16439 L .7055 .16313 L F
.65033 .16685 m .652 .16349 L .65359 .1657 L 0 .027 .126 r
F
.65033 .16685 m .64874 .16465 L .652 .16349 L F
.44477 .1673 m .4461 .16393 L .4479 .16618 L 0 .027 .127 r
F
.44477 .1673 m .44296 .16505 L .4461 .16393 L F
.4901 .16754 m .4915 .16408 L .49326 .16642 L 0 .028 .127 r
F
.4901 .16754 m .48834 .16521 L .4915 .16408 L F
.75717 .16648 m .75901 .16308 L .76048 .16531 L 0 .026 .125 r
F
.75717 .16648 m .75569 .16424 L .75901 .16308 L F
.53542 .16783 m .5369 .16441 L .53861 .16661 L 0 .028 .128 r
F
.53542 .16783 m .53371 .16562 L .5369 .16441 L F
.71184 .1663 m .71361 .1629 L .71513 .16509 L 0 .026 .125 r
F
.71184 .1663 m .71031 .16411 L .71361 .1629 L F
.59692 .1672 m .59851 .16388 L .60015 .1661 L 0 .028 .127 r
F
.59692 .1672 m .59528 .16498 L .59851 .16388 L F
.3541 .16707 m .35528 .16356 L .35718 .16591 L 0 .027 .126 r
F
.3541 .16707 m .3522 .16474 L .35528 .16356 L F
.39943 .1673 m .40068 .16397 L .40254 .1662 L 0 .028 .127 r
F
.39943 .1673 m .39757 .16508 L .40068 .16397 L F
.65843 .16672 m .66012 .16336 L .6617 .16556 L 0 .027 .126 r
F
.65843 .16672 m .65685 .16453 L .66012 .16336 L F
.54351 .16762 m .545 .16403 L .5467 .16631 L 0 .028 .128 r
F
.54351 .16762 m .5418 .16532 L .545 .16403 L F
.49818 .16741 m .4996 .16384 L .50135 .16612 L 0 .028 .127 r
F
.49818 .16741 m .49642 .16513 L .4996 .16384 L F
.76527 .16629 m .76714 .16303 L .7686 .16517 L 0 .026 .125 r
F
.76527 .16629 m .76381 .16416 L .76714 .16303 L F
.71994 .16607 m .72171 .16255 L .72323 .16477 L 0 .025 .124 r
F
.71994 .16607 m .71842 .16387 L .72171 .16255 L F
.45284 .16722 m .45419 .16367 L .45599 .16593 L 0 .028 .127 r
F
.45284 .16722 m .45104 .16496 L .45419 .16367 L F
.46093 .16682 m .46228 .16336 L .46408 .16554 L 0 .027 .126 r
F
.46093 .16682 m .45913 .16465 L .46228 .16336 L F
.72803 .1657 m .72982 .16222 L .73133 .16448 L 0 .025 .124 r
F
.72803 .1657 m .72652 .16346 L .72982 .16222 L F
.46901 .1664 m .47038 .16302 L .47217 .16518 L 0 .026 .125 r
F
.46901 .1664 m .46723 .16426 L .47038 .16302 L F
.5516 .16731 m .5531 .16384 L .5548 .16606 L 0 .028 .127 r
F
.5516 .16731 m .5499 .16507 L .5531 .16384 L F
.50626 .16711 m .50769 .16356 L .50944 .16583 L 0 .027 .127 r
F
.50626 .16711 m .50452 .16484 L .50769 .16356 L F
.60502 .16712 m .60661 .16359 L .60825 .16584 L 0 .028 .127 r
F
.60502 .16712 m .60338 .16485 L .60661 .16359 L F
.32492 .16624 m .32604 .16295 L .32798 .16512 L 0 .026 .125 r
F
.32492 .16624 m .32298 .16406 L .32604 .16295 L F
.36217 .16695 m .36336 .16355 L .36526 .16576 L 0 .027 .127 r
F
.36217 .16695 m .36027 .16474 L .36336 .16355 L F
.55968 .16697 m .5612 .16355 L .56289 .16575 L 0 .028 .127 r
F
.55968 .16697 m .558 .1648 L .5612 .16355 L F
.66653 .16655 m .66823 .16314 L .6698 .16531 L 0 .027 .126 r
F
.66653 .16655 m .66496 .16439 L .66823 .16314 L F
.4075 .16724 m .40877 .1638 L .41062 .16595 L 0 .028 .128 r
F
.4075 .16724 m .40565 .16509 L .40877 .1638 L F
.61311 .1668 m .61471 .16338 L .61634 .16557 L 0 .027 .127 r
F
.61311 .1668 m .61148 .16458 L .61471 .16338 L F
.41559 .16681 m .41687 .16338 L .41871 .16553 L F
.41559 .16681 m .41374 .16466 L .41687 .16338 L F
.51435 .16683 m .51579 .16342 L .51752 .16571 L F
.51435 .16683 m .51261 .16456 L .51579 .16342 L F
.42367 .16644 m .42497 .16297 L .4268 .16516 L 0 .027 .126 r
F
.42367 .16644 m .42184 .16425 L .42497 .16297 L F
.4771 .16622 m .47848 .16294 L .48025 .1651 L F
.4771 .16622 m .47532 .16406 L .47848 .16294 L F
.37024 .16669 m .37145 .16332 L .37334 .16545 L 0 .027 .127 r
F
.37024 .16669 m .36835 .16454 L .37145 .16332 L F
.67463 .16624 m .67634 .1629 L .6779 .16509 L 0 .027 .126 r
F
.67463 .16624 m .67306 .16407 L .67634 .1629 L F
.73614 .1656 m .73795 .1622 L .73945 .16448 L 0 .025 .124 r
F
.73614 .1656 m .73464 .16334 L .73795 .1622 L F
.56777 .16673 m .5693 .16323 L .57098 .16547 L 0 .027 .127 r
F
.56777 .16673 m .56609 .16452 L .5693 .16323 L F
.37832 .16634 m .37954 .16297 L .38143 .16509 L 0 .027 .126 r
F
.37832 .16634 m .37644 .16421 L .37954 .16297 L F
.6212 .16658 m .62282 .16313 L .62444 .16537 L F
.6212 .16658 m .61958 .16434 L .62282 .16313 L F
.33298 .16615 m .33412 .16287 L .33605 .16501 L F
.33298 .16615 m .33105 .164 L .33412 .16287 L F
.43175 .1662 m .43305 .16289 L .43488 .16508 L F
.43175 .1662 m .42993 .16401 L .43305 .16289 L F
.57586 .16645 m .57741 .16291 L .57908 .1652 L F
.57586 .16645 m .57419 .16418 L .57741 .16291 L F
.3864 .16613 m .38763 .16273 L .3895 .16502 L F
.3864 .16613 m .38453 .16386 L .38763 .16273 L F
.52243 .16682 m .52389 .16352 L .52562 .16571 L 0 .028 .128 r
F
.52243 .16682 m .52071 .16462 L .52389 .16352 L F
.74426 .16552 m .74607 .16206 L .74757 .16432 L 0 .026 .124 r
F
.74426 .16552 m .74276 .16327 L .74607 .16206 L F
.68273 .16621 m .68446 .1629 L .68601 .16509 L 0 .027 .126 r
F
.68273 .16621 m .68118 .16399 L .68446 .1629 L F
.6293 .16644 m .63093 .16296 L .63255 .16525 L 0 .027 .127 r
F
.6293 .16644 m .62768 .16416 L .63093 .16296 L F
.58396 .16622 m .58552 .1629 L .58717 .16506 L 0 .027 .126 r
F
.58396 .16622 m .58229 .16405 L .58552 .1629 L F
.34105 .16604 m .34221 .16265 L .34413 .16484 L F
.34105 .16604 m .33913 .16386 L .34221 .16265 L F
.48517 .16632 m .48657 .16287 L .48834 .16521 L F
.48517 .16632 m .48341 .16398 L .48657 .16287 L F
.43983 .16616 m .44114 .16284 L .44296 .16505 L F
.43983 .16616 m .43801 .16396 L .44114 .16284 L F
.6374 .1662 m .63904 .16261 L .64064 .16488 L F
.6374 .1662 m .63579 .16393 L .63904 .16261 L F
.69084 .16601 m .69257 .16255 L .69411 .16473 L F
.69084 .16601 m .68929 .16383 L .69257 .16255 L F
.64549 .16581 m .64715 .16245 L .64874 .16465 L F
.64549 .16581 m .64389 .16362 L .64715 .16245 L F
.53052 .16675 m .53199 .16345 L .53371 .16562 L 0 .028 .128 r
F
.53052 .16675 m .5288 .16458 L .53199 .16345 L F
.75237 .16541 m .7542 .16196 L .75569 .16424 L 0 .026 .125 r
F
.75237 .16541 m .75088 .16313 L .7542 .16196 L F
.59205 .16609 m .59363 .16281 L .59528 .16498 L 0 .027 .127 r
F
.59205 .16609 m .5904 .16393 L .59363 .16281 L F
.69893 .16565 m .70068 .16223 L .70221 .16439 L 0 .026 .125 r
F
.69893 .16565 m .69739 .16346 L .70068 .16223 L F
.34912 .16594 m .3503 .16241 L .3522 .16474 L 0 .027 .126 r
F
.34912 .16594 m .34721 .16363 L .3503 .16241 L F
.39447 .16619 m .39571 .16277 L .39757 .16508 L 0 .027 .127 r
F
.39447 .16619 m .39261 .1639 L .39571 .16277 L F
.70703 .16533 m .70879 .16191 L .71031 .16411 L 0 .026 .125 r
F
.70703 .16533 m .7055 .16313 L .70879 .16191 L F
.65359 .1657 m .65526 .16231 L .65685 .16453 L 0 .027 .126 r
F
.65359 .1657 m .652 .16349 L .65526 .16231 L F
.53861 .16661 m .5401 .16314 L .5418 .16532 L 0 .028 .128 r
F
.53861 .16661 m .5369 .16441 L .5401 .16314 L F
.4479 .16618 m .44924 .16271 L .45104 .16496 L 0 .028 .127 r
F
.4479 .16618 m .4461 .16393 L .44924 .16271 L F
.49326 .16642 m .49467 .1628 L .49642 .16513 L F
.49326 .16642 m .4915 .16408 L .49467 .1628 L F
.76048 .16531 m .76234 .16193 L .76381 .16416 L 0 .026 .125 r
F
.76048 .16531 m .75901 .16308 L .76234 .16193 L F
.71513 .16509 m .7169 .16168 L .71842 .16387 L F
.71513 .16509 m .71361 .1629 L .7169 .16168 L F
.5467 .16631 m .5482 .16283 L .5499 .16507 L 0 .028 .127 r
F
.5467 .16631 m .545 .16403 L .5482 .16283 L F
.60015 .1661 m .60173 .16263 L .60338 .16485 L F
.60015 .1661 m .59851 .16388 L .60173 .16263 L F
.72323 .16477 m .72501 .16124 L .72652 .16346 L 0 .025 .124 r
F
.72323 .16477 m .72171 .16255 L .72501 .16124 L F
.50135 .16612 m .50277 .16255 L .50452 .16484 L 0 .027 .127 r
F
.50135 .16612 m .4996 .16384 L .50277 .16255 L F
.35718 .16591 m .35837 .16237 L .36027 .16474 L 0 .027 .126 r
F
.35718 .16591 m .35528 .16356 L .35837 .16237 L F
.45599 .16593 m .45734 .16237 L .45913 .16465 L 0 .027 .127 r
F
.45599 .16593 m .45419 .16367 L .45734 .16237 L F
.40254 .1662 m .40379 .16286 L .40565 .16509 L 0 .028 .128 r
F
.40254 .1662 m .40068 .16397 L .40379 .16286 L F
.46408 .16554 m .46544 .16206 L .46723 .16426 L 0 .027 .126 r
F
.46408 .16554 m .46228 .16336 L .46544 .16206 L F
.6617 .16556 m .66338 .16218 L .66496 .16439 L F
.6617 .16556 m .66012 .16336 L .66338 .16218 L F
.73133 .16448 m .73313 .16107 L .73464 .16334 L 0 .025 .124 r
F
.73133 .16448 m .72982 .16222 L .73313 .16107 L F
.5548 .16606 m .55631 .1626 L .558 .1648 L 0 .028 .127 r
F
.5548 .16606 m .5531 .16384 L .55631 .1626 L F
.50944 .16583 m .51087 .16228 L .51261 .16456 L 0 .027 .127 r
F
.50944 .16583 m .50769 .16356 L .51087 .16228 L F
.7686 .16517 m .77047 .1619 L .77193 .16404 L 0 .026 .126 r
F
.7686 .16517 m .76714 .16303 L .77047 .1619 L F
.60825 .16584 m .60984 .16235 L .61148 .16458 L 0 .027 .127 r
F
.60825 .16584 m .60661 .16359 L .60984 .16235 L F
.47217 .16518 m .47354 .16191 L .47532 .16406 L 0 .026 .126 r
F
.47217 .16518 m .47038 .16302 L .47354 .16191 L F
.41062 .16595 m .41189 .16251 L .41374 .16466 L 0 .028 .127 r
F
.41062 .16595 m .40877 .1638 L .41189 .16251 L F
.56289 .16575 m .56441 .16231 L .56609 .16452 L 0 .027 .127 r
F
.56289 .16575 m .5612 .16355 L .56441 .16231 L F
.41871 .16553 m .42 .16209 L .42184 .16425 L 0 .027 .126 r
F
.41871 .16553 m .41687 .16338 L .42 .16209 L F
.6698 .16531 m .67149 .16189 L .67306 .16407 L F
.6698 .16531 m .66823 .16314 L .67149 .16189 L F
.36526 .16576 m .36646 .16234 L .36835 .16454 L 0 .027 .127 r
F
.36526 .16576 m .36336 .16355 L .36646 .16234 L F
.32798 .16512 m .32911 .16184 L .33105 .164 L 0 .027 .126 r
F
.32798 .16512 m .32604 .16295 L .32911 .16184 L F
.61634 .16557 m .61795 .16217 L .61958 .16434 L F
.61634 .16557 m .61471 .16338 L .61795 .16217 L F
.4268 .16516 m .4281 .16181 L .42993 .16401 L F
.4268 .16516 m .42497 .16297 L .4281 .16181 L F
.37334 .16545 m .37455 .1621 L .37644 .16421 L F
.37334 .16545 m .37145 .16332 L .37455 .1621 L F
.57098 .16547 m .57252 .16191 L .57419 .16418 L F
.57098 .16547 m .5693 .16323 L .57252 .16191 L F
.51752 .16571 m .51897 .16231 L .52071 .16462 L 0 .028 .127 r
F
.51752 .16571 m .51579 .16342 L .51897 .16231 L F
.6779 .16509 m .67962 .16179 L .68118 .16399 L 0 .027 .126 r
F
.6779 .16509 m .67634 .1629 L .67962 .16179 L F
.38143 .16509 m .38265 .16175 L .38453 .16386 L F
.38143 .16509 m .37954 .16297 L .38265 .16175 L F
.48025 .1651 m .48164 .16182 L .48341 .16398 L F
.48025 .1651 m .47848 .16294 L .48164 .16182 L F
.62444 .16537 m .62607 .16191 L .62768 .16416 L F
.62444 .16537 m .62282 .16313 L .62607 .16191 L F
.73945 .16448 m .74126 .16099 L .74276 .16327 L 0 .025 .124 r
F
.73945 .16448 m .73795 .1622 L .74126 .16099 L F
.57908 .1652 m .58063 .16176 L .58229 .16405 L 0 .027 .126 r
F
.57908 .1652 m .57741 .16291 L .58063 .16176 L F
.33605 .16501 m .33719 .16174 L .33913 .16386 L F
.33605 .16501 m .33412 .16287 L .33719 .16174 L F
.43488 .16508 m .43619 .16177 L .43801 .16396 L F
.43488 .16508 m .43305 .16289 L .43619 .16177 L F
.74757 .16432 m .74939 .16085 L .75088 .16313 L 0 .026 .124 r
F
.74757 .16432 m .74607 .16206 L .74939 .16085 L F
.3895 .16502 m .39074 .1616 L .39261 .1639 L 0 .027 .126 r
F
.3895 .16502 m .38763 .16273 L .39074 .1616 L F
.63255 .16525 m .63418 .16165 L .63579 .16393 L F
.63255 .16525 m .63093 .16296 L .63418 .16165 L F
.52562 .16571 m .52708 .16238 L .5288 .16458 L 0 .028 .128 r
F
.52562 .16571 m .52389 .16352 L .52708 .16238 L F
.58717 .16506 m .58874 .16176 L .5904 .16393 L 0 .027 .126 r
F
.58717 .16506 m .58552 .1629 L .58874 .16176 L F
.34413 .16484 m .34529 .16141 L .34721 .16363 L F
.34413 .16484 m .34221 .16265 L .34529 .16141 L F
.68601 .16509 m .68774 .16164 L .68929 .16383 L F
.68601 .16509 m .68446 .1629 L .68774 .16164 L F
.64064 .16488 m .64229 .16136 L .64389 .16362 L F
.64064 .16488 m .63904 .16261 L .64229 .16136 L F
.69411 .16473 m .69585 .1613 L .69739 .16346 L F
.69411 .16473 m .69257 .16255 L .69585 .1613 L F
.48834 .16521 m .48974 .16174 L .4915 .16408 L 0 .027 .127 r
F
.48834 .16521 m .48657 .16287 L .48974 .16174 L F
.44296 .16505 m .44428 .16172 L .4461 .16393 L F
.44296 .16505 m .44114 .16284 L .44428 .16172 L F
.70221 .16439 m .70397 .16099 L .7055 .16313 L 0 .026 .125 r
F
.70221 .16439 m .70068 .16223 L .70397 .16099 L F
.64874 .16465 m .65041 .16128 L .652 .16349 L 0 .027 .126 r
F
.64874 .16465 m .64715 .16245 L .65041 .16128 L F
.75569 .16424 m .75752 .16079 L .75901 .16308 L 0 .026 .125 r
F
.75569 .16424 m .7542 .16196 L .75752 .16079 L F
.53371 .16562 m .53519 .16225 L .5369 .16441 L 0 .029 .128 r
F
.53371 .16562 m .53199 .16345 L .53519 .16225 L F
.3522 .16474 m .35338 .16121 L .35528 .16356 L 0 .027 .126 r
F
.3522 .16474 m .3503 .16241 L .35338 .16121 L F
.59528 .16498 m .59686 .16169 L .59851 .16388 L 0 .028 .127 r
F
.59528 .16498 m .59363 .16281 L .59686 .16169 L F
.71031 .16411 m .71208 .16071 L .71361 .1629 L 0 .026 .125 r
F
.71031 .16411 m .70879 .16191 L .71208 .16071 L F
.39757 .16508 m .39883 .16165 L .40068 .16397 L 0 .028 .127 r
F
.39757 .16508 m .39571 .16277 L .39883 .16165 L F
.5418 .16532 m .54329 .16187 L .545 .16403 L 0 .028 .128 r
F
.5418 .16532 m .5401 .16314 L .54329 .16187 L F
.49642 .16513 m .49784 .16153 L .4996 .16384 L 0 .027 .127 r
F
.49642 .16513 m .49467 .1628 L .49784 .16153 L F
.45104 .16496 m .45239 .1614 L .45419 .16367 L F
.45104 .16496 m .44924 .16271 L .45239 .1614 L F
.65685 .16453 m .65853 .16111 L .66012 .16336 L 0 .027 .126 r
F
.65685 .16453 m .65526 .16231 L .65853 .16111 L F
.71842 .16387 m .7202 .16038 L .72171 .16255 L 0 .025 .124 r
F
.71842 .16387 m .7169 .16168 L .7202 .16038 L F
.72652 .16346 m .72831 .16 L .72982 .16222 L 0 .025 .123 r
F
.72652 .16346 m .72501 .16124 L .72831 .16 L F
.76381 .16416 m .76567 .16079 L .76714 .16303 L 0 .026 .125 r
F
.76381 .16416 m .76234 .16193 L .76567 .16079 L F
.50452 .16484 m .50595 .16129 L .50769 .16356 L 0 .027 .127 r
F
.50452 .16484 m .50277 .16255 L .50595 .16129 L F
.5499 .16507 m .5514 .16163 L .5531 .16384 L 0 .028 .127 r
F
.5499 .16507 m .5482 .16283 L .5514 .16163 L F
.60338 .16485 m .60497 .16136 L .60661 .16359 L 0 .027 .127 r
F
.60338 .16485 m .60173 .16263 L .60497 .16136 L F
.45913 .16465 m .46049 .16107 L .46228 .16336 L 0 .027 .126 r
F
.45913 .16465 m .45734 .16237 L .46049 .16107 L F
.46723 .16426 m .4686 .16082 L .47038 .16302 L 0 .026 .126 r
F
.46723 .16426 m .46544 .16206 L .4686 .16082 L F
.36027 .16474 m .36147 .16118 L .36336 .16355 L 0 .027 .127 r
F
.36027 .16474 m .35837 .16237 L .36147 .16118 L F
.51261 .16456 m .51405 .16113 L .51579 .16342 L 0 .027 .126 r
F
.51261 .16456 m .51087 .16228 L .51405 .16113 L F
.558 .1648 m .55951 .16135 L .5612 .16355 L 0 .028 .127 r
F
.558 .1648 m .55631 .1626 L .55951 .16135 L F
.61148 .16458 m .61308 .16117 L .61471 .16338 L 0 .027 .127 r
F
.61148 .16458 m .60984 .16235 L .61308 .16117 L F
.66496 .16439 m .66665 .16092 L .66823 .16314 L 0 .027 .126 r
F
.66496 .16439 m .66338 .16218 L .66665 .16092 L F
.40565 .16509 m .40692 .16157 L .40877 .1638 L 0 .028 .128 r
F
.40565 .16509 m .40379 .16286 L .40692 .16157 L F
.41374 .16466 m .41502 .16122 L .41687 .16338 L 0 .027 .127 r
F
.41374 .16466 m .41189 .16251 L .41502 .16122 L F
.73464 .16334 m .73644 .15991 L .73795 .1622 L 0 .025 .124 r
F
.73464 .16334 m .73313 .16107 L .73644 .15991 L F
.42184 .16425 m .42313 .16081 L .42497 .16297 L 0 .027 .126 r
F
.42184 .16425 m .42 .16209 L .42313 .16081 L F
.47532 .16406 m .4767 .16079 L .47848 .16294 L F
.47532 .16406 m .47354 .16191 L .4767 .16079 L F
.67306 .16407 m .67477 .16071 L .67634 .1629 L F
.67306 .16407 m .67149 .16189 L .67477 .16071 L F
.56609 .16452 m .56762 .161 L .5693 .16323 L F
.56609 .16452 m .56441 .16231 L .56762 .161 L F
.36835 .16454 m .36955 .16114 L .37145 .16332 L 0 .027 .127 r
F
.36835 .16454 m .36646 .16234 L .36955 .16114 L F
.61958 .16434 m .6212 .16096 L .62282 .16313 L 0 .027 .126 r
F
.61958 .16434 m .61795 .16217 L .6212 .16096 L F
.57419 .16418 m .57573 .16062 L .57741 .16291 L F
.57419 .16418 m .57252 .16191 L .57573 .16062 L F
.37644 .16421 m .37765 .16087 L .37954 .16297 L F
.37644 .16421 m .37455 .1621 L .37765 .16087 L F
.33105 .164 m .33218 .16073 L .33412 .16287 L F
.33105 .164 m .32911 .16184 L .33218 .16073 L F
.42993 .16401 m .43123 .16069 L .43305 .16289 L F
.42993 .16401 m .4281 .16181 L .43123 .16069 L F
.38453 .16386 m .38576 .1606 L .38763 .16273 L F
.38453 .16386 m .38265 .16175 L .38576 .1606 L F
.62768 .16416 m .62931 .1607 L .63093 .16296 L F
.62768 .16416 m .62607 .16191 L .62931 .1607 L F
.52071 .16462 m .52216 .16118 L .52389 .16352 L 0 .028 .127 r
F
.52071 .16462 m .51897 .16231 L .52216 .16118 L F
.74276 .16327 m .74457 .15976 L .74607 .16206 L 0 .025 .124 r
F
.74276 .16327 m .74126 .16099 L .74457 .15976 L F
.48341 .16398 m .4848 .1607 L .48657 .16287 L 0 .027 .126 r
F
.48341 .16398 m .48164 .16182 L .4848 .1607 L F
.68118 .16399 m .6829 .16068 L .68446 .1629 L F
.68118 .16399 m .67962 .16179 L .6829 .16068 L F
.58229 .16405 m .58385 .1606 L .58552 .1629 L F
.58229 .16405 m .58063 .16176 L .58385 .1606 L F
.33913 .16386 m .34028 .16052 L .34221 .16265 L F
.33913 .16386 m .33719 .16174 L .34028 .16052 L F
.63579 .16393 m .63743 .16034 L .63904 .16261 L F
.63579 .16393 m .63418 .16165 L .63743 .16034 L F
.43801 .16396 m .43933 .16064 L .44114 .16284 L F
.43801 .16396 m .43619 .16177 L .43933 .16064 L F
.75088 .16313 m .75271 .15967 L .7542 .16196 L 0 .026 .124 r
F
.75088 .16313 m .74939 .16085 L .75271 .15967 L F
.68929 .16383 m .69102 .16036 L .69257 .16255 L 0 .027 .126 r
F
.68929 .16383 m .68774 .16164 L .69102 .16036 L F
.64389 .16362 m .64555 .16021 L .64715 .16245 L F
.64389 .16362 m .64229 .16136 L .64555 .16021 L F
.34721 .16363 m .34838 .16018 L .3503 .16241 L 0 .026 .126 r
F
.34721 .16363 m .34529 .16141 L .34838 .16018 L F
.39261 .1639 m .39385 .16046 L .39571 .16277 L 0 .027 .126 r
F
.39261 .1639 m .39074 .1616 L .39385 .16046 L F
.5288 .16458 m .53027 .16124 L .53199 .16345 L 0 .028 .128 r
F
.5288 .16458 m .52708 .16238 L .53027 .16124 L F
.69739 .16346 m .69914 .16009 L .70068 .16223 L 0 .026 .125 r
F
.69739 .16346 m .69585 .1613 L .69914 .16009 L F
.5904 .16393 m .59197 .16062 L .59363 .16281 L 0 .027 .127 r
F
.5904 .16393 m .58874 .16176 L .59197 .16062 L F
.7055 .16313 m .70726 .15977 L .70879 .16191 L 0 .026 .125 r
F
.7055 .16313 m .70397 .16099 L .70726 .15977 L F
.4915 .16408 m .49291 .16048 L .49467 .1628 L 0 .027 .127 r
F
.4915 .16408 m .48974 .16174 L .49291 .16048 L F
.4461 .16393 m .44743 .1605 L .44924 .16271 L F
.4461 .16393 m .44428 .16172 L .44743 .1605 L F
.652 .16349 m .65367 .16007 L .65526 .16231 L 0 .027 .126 r
F
.652 .16349 m .65041 .16128 L .65367 .16007 L F
.5369 .16441 m .53838 .16099 L .5401 .16314 L 0 .028 .128 r
F
.5369 .16441 m .53519 .16225 L .53838 .16099 L F
.75901 .16308 m .76085 .15963 L .76234 .16193 L 0 .026 .125 r
F
.75901 .16308 m .75752 .16079 L .76085 .15963 L F
.35528 .16356 m .35648 .16 L .35837 .16237 L 0 .027 .126 r
F
.35528 .16356 m .35338 .16121 L .35648 .16 L F
.71361 .1629 m .71538 .15949 L .7169 .16168 L 0 .026 .125 r
F
.71361 .1629 m .71208 .16071 L .71538 .15949 L F
.545 .16403 m .5465 .16068 L .5482 .16283 L 0 .028 .127 r
F
.545 .16403 m .54329 .16187 L .5465 .16068 L F
.4996 .16384 m .50102 .16026 L .50277 .16255 L 0 .027 .127 r
F
.4996 .16384 m .49784 .16153 L .50102 .16026 L F
.59851 .16388 m .60009 .16043 L .60173 .16263 L 0 .028 .127 r
F
.59851 .16388 m .59686 .16169 L .60009 .16043 L F
.45419 .16367 m .45554 .16008 L .45734 .16237 L 0 .027 .126 r
F
.45419 .16367 m .45239 .1614 L .45554 .16008 L F
.72171 .16255 m .72349 .15907 L .72501 .16124 L 0 .025 .124 r
F
.72171 .16255 m .7202 .16038 L .72349 .15907 L F
.40068 .16397 m .40194 .16052 L .40379 .16286 L 0 .028 .127 r
F
.40068 .16397 m .39883 .16165 L .40194 .16052 L F
.50769 .16356 m .50913 .16002 L .51087 .16228 L 0 .027 .126 r
F
.50769 .16356 m .50595 .16129 L .50913 .16002 L F
.72982 .16222 m .73162 .15883 L .73313 .16107 L 0 .025 .123 r
F
.72982 .16222 m .72831 .16 L .73162 .15883 L F
.46228 .16336 m .46365 .15978 L .46544 .16206 L 0 .027 .126 r
F
.46228 .16336 m .46049 .16107 L .46365 .15978 L F
.66012 .16336 m .6618 .15991 L .66338 .16218 L F
.66012 .16336 m .65853 .16111 L .6618 .15991 L F
.60661 .16359 m .6082 .16012 L .60984 .16235 L 0 .027 .127 r
F
.60661 .16359 m .60497 .16136 L .6082 .16012 L F
.5531 .16384 m .55461 .1604 L .55631 .1626 L 0 .028 .127 r
F
.5531 .16384 m .5514 .16163 L .55461 .1604 L F
.47038 .16302 m .47175 .1597 L .47354 .16191 L 0 .027 .126 r
F
.47038 .16302 m .4686 .16082 L .47175 .1597 L F
.76714 .16303 m .769 .15966 L .77047 .1619 L 0 .026 .126 r
F
.76714 .16303 m .76567 .16079 L .769 .15966 L F
.36336 .16355 m .36456 .15999 L .36646 .16234 L 0 .027 .127 r
F
.36336 .16355 m .36147 .16118 L .36456 .15999 L F
.5612 .16355 m .56272 .1601 L .56441 .16231 L F
.5612 .16355 m .55951 .16135 L .56272 .1601 L F
.40877 .1638 m .41005 .16028 L .41189 .16251 L 0 .028 .127 r
F
.40877 .1638 m .40692 .16157 L .41005 .16028 L F
.66823 .16314 m .66992 .15966 L .67149 .16189 L 0 .027 .126 r
F
.66823 .16314 m .66665 .16092 L .66992 .15966 L F
.41687 .16338 m .41815 .15993 L .42 .16209 L F
.41687 .16338 m .41502 .16122 L .41815 .15993 L F
.61471 .16338 m .61633 .16 L .61795 .16217 L 0 .027 .127 r
F
.61471 .16338 m .61308 .16117 L .61633 .16 L F
.42497 .16297 m .42626 .15964 L .4281 .16181 L 0 .027 .126 r
F
.42497 .16297 m .42313 .16081 L .42626 .15964 L F
.51579 .16342 m .51724 .15999 L .51897 .16231 L 0 .027 .127 r
F
.51579 .16342 m .51405 .16113 L .51724 .15999 L F
.5693 .16323 m .57084 .15967 L .57252 .16191 L 0 .027 .126 r
F
.5693 .16323 m .56762 .161 L .57084 .15967 L F
.37145 .16332 m .37266 .15993 L .37455 .1621 L 0 .027 .127 r
F
.37145 .16332 m .36955 .16114 L .37266 .15993 L F
.73795 .1622 m .73976 .15869 L .74126 .16099 L 0 .025 .124 r
F
.73795 .1622 m .73644 .15991 L .73976 .15869 L F
.67634 .1629 m .67805 .15958 L .67962 .16179 L 0 .027 .126 r
F
.67634 .1629 m .67477 .16071 L .67805 .15958 L F
.62282 .16313 m .62445 .15974 L .62607 .16191 L F
.62282 .16313 m .6212 .16096 L .62445 .15974 L F
.57741 .16291 m .57896 .15946 L .58063 .16176 L F
.57741 .16291 m .57573 .16062 L .57896 .15946 L F
.47848 .16294 m .47986 .15966 L .48164 .16182 L F
.47848 .16294 m .4767 .16079 L .47986 .15966 L F
.37954 .16297 m .38076 .15966 L .38265 .16175 L F
.37954 .16297 m .37765 .16087 L .38076 .15966 L F
.33412 .16287 m .33526 .15962 L .33719 .16174 L F
.33412 .16287 m .33218 .16073 L .33526 .15962 L F
.43305 .16289 m .43436 .15957 L .43619 .16177 L F
.43305 .16289 m .43123 .16069 L .43436 .15957 L F
.74607 .16206 m .74789 .15855 L .74939 .16085 L 0 .025 .124 r
F
.74607 .16206 m .74457 .15976 L .74789 .15855 L F
.63093 .16296 m .63256 .1594 L .63418 .16165 L 0 .027 .126 r
F
.63093 .16296 m .62931 .1607 L .63256 .1594 L F
.38763 .16273 m .38887 .15944 L .39074 .1616 L F
.38763 .16273 m .38576 .1606 L .38887 .15944 L F
.63904 .16261 m .64068 .1591 L .64229 .16136 L 0 .026 .125 r
F
.63904 .16261 m .63743 .16034 L .64068 .1591 L F
.52389 .16352 m .52535 .16002 L .52708 .16238 L 0 .028 .128 r
F
.52389 .16352 m .52216 .16118 L .52535 .16002 L F
.48657 .16287 m .48797 .15956 L .48974 .16174 L 0 .027 .127 r
F
.48657 .16287 m .4848 .1607 L .48797 .15956 L F
.34221 .16265 m .34337 .15926 L .34529 .16141 L 0 .027 .126 r
F
.34221 .16265 m .34028 .16052 L .34337 .15926 L F
.68446 .1629 m .68618 .1594 L .68774 .16164 L F
.68446 .1629 m .6829 .16068 L .68618 .1594 L F
.58552 .1629 m .58708 .15945 L .58874 .16176 L F
.58552 .1629 m .58385 .1606 L .58708 .15945 L F
.69257 .16255 m .69431 .15912 L .69585 .1613 L F
.69257 .16255 m .69102 .16036 L .69431 .15912 L F
.44114 .16284 m .44247 .15952 L .44428 .16172 L 0 .027 .127 r
F
.44114 .16284 m .43933 .16064 L .44247 .15952 L F
.7542 .16196 m .75604 .15849 L .75752 .16079 L 0 .026 .124 r
F
.7542 .16196 m .75271 .15967 L .75604 .15849 L F
.3503 .16241 m .35147 .15895 L .35338 .16121 L 0 .026 .125 r
F
.3503 .16241 m .34838 .16018 L .35147 .15895 L F
.64715 .16245 m .64881 .15905 L .65041 .16128 L 0 .027 .126 r
F
.64715 .16245 m .64555 .16021 L .64881 .15905 L F
.70068 .16223 m .70243 .15887 L .70397 .16099 L 0 .026 .125 r
F
.70068 .16223 m .69914 .16009 L .70243 .15887 L F
.39571 .16277 m .39697 .15932 L .39883 .16165 L 0 .027 .127 r
F
.39571 .16277 m .39385 .16046 L .39697 .15932 L F
.53199 .16345 m .53347 .16003 L .53519 .16225 L 0 .029 .128 r
F
.53199 .16345 m .53027 .16124 L .53347 .16003 L F
.49467 .1628 m .49608 .15921 L .49784 .16153 L 0 .027 .126 r
F
.49467 .1628 m .49291 .16048 L .49608 .15921 L F
.59363 .16281 m .5952 .15949 L .59686 .16169 L 0 .028 .127 r
F
.59363 .16281 m .59197 .16062 L .5952 .15949 L F
.70879 .16191 m .71056 .15856 L .71208 .16071 L 0 .026 .125 r
F
.70879 .16191 m .70726 .15977 L .71056 .15856 L F
.5401 .16314 m .54158 .15973 L .54329 .16187 L 0 .028 .128 r
F
.5401 .16314 m .53838 .16099 L .54158 .15973 L F
.44924 .16271 m .45058 .15919 L .45239 .1614 L 0 .027 .127 r
F
.44924 .16271 m .44743 .1605 L .45058 .15919 L F
.65526 .16231 m .65694 .15886 L .65853 .16111 L 0 .027 .126 r
F
.65526 .16231 m .65367 .16007 L .65694 .15886 L F
.50277 .16255 m .5042 .15902 L .50595 .16129 L F
.50277 .16255 m .50102 .16026 L .5042 .15902 L F
.7169 .16168 m .71868 .15819 L .7202 .16038 L 0 .026 .124 r
F
.7169 .16168 m .71538 .15949 L .71868 .15819 L F
.72501 .16124 m .7268 .15783 L .72831 .16 L 0 .025 .123 r
F
.72501 .16124 m .72349 .15907 L .7268 .15783 L F
.45734 .16237 m .45869 .15879 L .46049 .16107 L 0 .027 .126 r
F
.45734 .16237 m .45554 .16008 L .45869 .15879 L F
.35837 .16237 m .35957 .15881 L .36147 .16118 L F
.35837 .16237 m .35648 .16 L .35957 .15881 L F
.76234 .16193 m .76419 .15848 L .76567 .16079 L 0 .026 .125 r
F
.76234 .16193 m .76085 .15963 L .76419 .15848 L F
.5482 .16283 m .5497 .1595 L .5514 .16163 L 0 .028 .127 r
F
.5482 .16283 m .5465 .16068 L .5497 .1595 L F
.60173 .16263 m .60332 .15915 L .60497 .16136 L 0 .027 .127 r
F
.60173 .16263 m .60009 .16043 L .60332 .15915 L F
.51087 .16228 m .51231 .15885 L .51405 .16113 L 0 .027 .126 r
F
.51087 .16228 m .50913 .16002 L .51231 .15885 L F
.46544 .16206 m .46681 .15854 L .4686 .16082 L 0 .026 .125 r
F
.46544 .16206 m .46365 .15978 L .46681 .15854 L F
.60984 .16235 m .61145 .15895 L .61308 .16117 L 0 .027 .126 r
F
.60984 .16235 m .6082 .16012 L .61145 .15895 L F
.55631 .1626 m .55782 .15914 L .55951 .16135 L 0 .028 .127 r
F
.55631 .1626 m .55461 .1604 L .55782 .15914 L F
.66338 .16218 m .66507 .15864 L .66665 .16092 L 0 .027 .126 r
F
.66338 .16218 m .6618 .15991 L .66507 .15864 L F
.40379 .16286 m .40507 .15925 L .40692 .16157 L 0 .028 .127 r
F
.40379 .16286 m .40194 .16052 L .40507 .15925 L F
.73313 .16107 m .73494 .15767 L .73644 .15991 L 0 .025 .124 r
F
.73313 .16107 m .73162 .15883 L .73494 .15767 L F
.41189 .16251 m .41318 .159 L .41502 .16122 L 0 .027 .127 r
F
.41189 .16251 m .41005 .16028 L .41318 .159 L F
.56441 .16231 m .56594 .15879 L .56762 .161 L 0 .027 .126 r
F
.56441 .16231 m .56272 .1601 L .56594 .15879 L F
.42 .16209 m .42129 .15864 L .42313 .16081 L F
.42 .16209 m .41815 .15993 L .42129 .15864 L F
.67149 .16189 m .6732 .15847 L .67477 .16071 L F
.67149 .16189 m .66992 .15966 L .6732 .15847 L F
.36646 .16234 m .36766 .1588 L .36955 .16114 L F
.36646 .16234 m .36456 .15999 L .36766 .1588 L F
.47354 .16191 m .47492 .15858 L .4767 .16079 L F
.47354 .16191 m .47175 .1597 L .47492 .15858 L F
.57252 .16191 m .57406 .15836 L .57573 .16062 L 0 .026 .126 r
F
.57252 .16191 m .57084 .15967 L .57406 .15836 L F
.61795 .16217 m .61957 .15879 L .6212 .16096 L 0 .027 .127 r
F
.61795 .16217 m .61633 .16 L .61957 .15879 L F
.4281 .16181 m .4294 .15852 L .43123 .16069 L 0 .027 .126 r
F
.4281 .16181 m .42626 .15964 L .4294 .15852 L F
.51897 .16231 m .52043 .15885 L .52216 .16118 L 0 .028 .127 r
F
.51897 .16231 m .51724 .15999 L .52043 .15885 L F
.37455 .1621 m .37576 .15872 L .37765 .16087 L 0 .027 .127 r
F
.37455 .1621 m .37266 .15993 L .37576 .15872 L F
.74126 .16099 m .74307 .15746 L .74457 .15976 L 0 .025 .124 r
F
.74126 .16099 m .73976 .15869 L .74307 .15746 L F
.62607 .16191 m .6277 .15852 L .62931 .1607 L 0 .027 .126 r
F
.62607 .16191 m .62445 .15974 L .6277 .15852 L F
.38265 .16175 m .38387 .15849 L .38576 .1606 L F
.38265 .16175 m .38076 .15966 L .38387 .15849 L F
.58063 .16176 m .58218 .1583 L .58385 .1606 L F
.58063 .16176 m .57896 .15946 L .58218 .1583 L F
.67962 .16179 m .68134 .15845 L .6829 .16068 L F
.67962 .16179 m .67805 .15958 L .68134 .15845 L F
.48164 .16182 m .48303 .15852 L .4848 .1607 L F
.48164 .16182 m .47986 .15966 L .48303 .15852 L F
.63418 .16165 m .63582 .15809 L .63743 .16034 L 0 .026 .126 r
F
.63418 .16165 m .63256 .1594 L .63582 .15809 L F
.33719 .16174 m .33835 .15838 L .34028 .16052 L 0 .027 .126 r
F
.33719 .16174 m .33526 .15962 L .33835 .15838 L F
.74939 .16085 m .75122 .15738 L .75271 .15967 L 0 .025 .124 r
F
.74939 .16085 m .74789 .15855 L .75122 .15738 L F
.43619 .16177 m .4375 .15844 L .43933 .16064 L 0 .027 .126 r
F
.43619 .16177 m .43436 .15957 L .4375 .15844 L F
.64229 .16136 m .64395 .15795 L .64555 .16021 L 0 .026 .125 r
F
.64229 .16136 m .64068 .1591 L .64395 .15795 L F
.39074 .1616 m .39198 .15829 L .39385 .16046 L 0 .027 .126 r
F
.39074 .1616 m .38887 .15944 L .39198 .15829 L F
.68774 .16164 m .68946 .15811 L .69102 .16036 L F
.68774 .16164 m .68618 .1594 L .68946 .15811 L F
.34529 .16141 m .34646 .158 L .34838 .16018 L F
.34529 .16141 m .34337 .15926 L .34646 .158 L F
.52708 .16238 m .52855 .15885 L .53027 .16124 L 0 .028 .128 r
F
.52708 .16238 m .52535 .16002 L .52855 .15885 L F
.48974 .16174 m .49114 .15829 L .49291 .16048 L 0 .027 .126 r
F
.48974 .16174 m .48797 .15956 L .49114 .15829 L F
.69585 .1613 m .6976 .15792 L .69914 .16009 L 0 .026 .126 r
F
.69585 .1613 m .69431 .15912 L .6976 .15792 L F
.58874 .16176 m .59031 .15829 L .59197 .16062 L 0 .027 .127 r
F
.58874 .16176 m .58708 .15945 L .59031 .15829 L F
.35338 .16121 m .35457 .15772 L .35648 .16 L 0 .026 .125 r
F
.35338 .16121 m .35147 .15895 L .35457 .15772 L F
.70397 .16099 m .70573 .15765 L .70726 .15977 L F
.70397 .16099 m .70243 .15887 L .70573 .15765 L F
.75752 .16079 m .75937 .15733 L .76085 .15963 L 0 .026 .124 r
F
.75752 .16079 m .75604 .15849 L .75937 .15733 L F
.44428 .16172 m .44562 .1583 L .44743 .1605 L 0 .027 .127 r
F
.44428 .16172 m .44247 .15952 L .44562 .1583 L F
.65041 .16128 m .65208 .15784 L .65367 .16007 L 0 .027 .126 r
F
.65041 .16128 m .64881 .15905 L .65208 .15784 L F
.49784 .16153 m .49926 .15796 L .50102 .16026 L F
.49784 .16153 m .49608 .15921 L .49926 .15796 L F
.53519 .16225 m .53667 .1588 L .53838 .16099 L 0 .028 .128 r
F
.53519 .16225 m .53347 .16003 L .53667 .1588 L F
.71208 .16071 m .71386 .15734 L .71538 .15949 L 0 .026 .125 r
F
.71208 .16071 m .71056 .15856 L .71386 .15734 L F
.45239 .1614 m .45373 .15788 L .45554 .16008 L 0 .027 .126 r
F
.45239 .1614 m .45058 .15919 L .45373 .15788 L F
.54329 .16187 m .54479 .15856 L .5465 .16068 L 0 .028 .128 r
F
.54329 .16187 m .54158 .15973 L .54479 .15856 L F
.39883 .16165 m .40008 .15818 L .40194 .16052 L 0 .027 .127 r
F
.39883 .16165 m .39697 .15932 L .40008 .15818 L F
.59686 .16169 m .59844 .15822 L .60009 .16043 L 0 .028 .127 r
F
.59686 .16169 m .5952 .15949 L .59844 .15822 L F
.7202 .16038 m .72198 .15689 L .72349 .15907 L 0 .025 .124 r
F
.7202 .16038 m .71868 .15819 L .72198 .15689 L F
.50595 .16129 m .50738 .15777 L .50913 .16002 L 0 .027 .126 r
F
.50595 .16129 m .5042 .15902 L .50738 .15777 L F
.46049 .16107 m .46185 .15749 L .46365 .15978 L 0 .026 .125 r
F
.46049 .16107 m .45869 .15879 L .46185 .15749 L F
.65853 .16111 m .66021 .15763 L .6618 .15991 L 0 .027 .126 r
F
.65853 .16111 m .65694 .15886 L .66021 .15763 L F
.72831 .16 m .73012 .15668 L .73162 .15883 L 0 .025 .123 r
F
.72831 .16 m .7268 .15783 L .73012 .15668 L F
.60497 .16136 m .60656 .1579 L .6082 .16012 L 0 .027 .126 r
F
.60497 .16136 m .60332 .15915 L .60656 .1579 L F
.5514 .16163 m .55291 .15828 L .55461 .1604 L 0 .028 .127 r
F
.5514 .16163 m .5497 .1595 L .55291 .15828 L F
.36147 .16118 m .36267 .15763 L .36456 .15999 L 0 .027 .126 r
F
.36147 .16118 m .35957 .15881 L .36267 .15763 L F
.76567 .16079 m .76753 .15734 L .769 .15966 L 0 .026 .125 r
F
.76567 .16079 m .76419 .15848 L .76753 .15734 L F
.4686 .16082 m .46997 .1574 L .47175 .1597 L F
.4686 .16082 m .46681 .15854 L .46997 .1574 L F
.40692 .16157 m .4082 .15798 L .41005 .16028 L 0 .028 .127 r
F
.40692 .16157 m .40507 .15925 L .4082 .15798 L F
.55951 .16135 m .56103 .15788 L .56272 .1601 L 0 .027 .127 r
F
.55951 .16135 m .55782 .15914 L .56103 .15788 L F
.51405 .16113 m .5155 .15771 L .51724 .15999 L 0 .027 .126 r
F
.51405 .16113 m .51231 .15885 L .5155 .15771 L F
.66665 .16092 m .66834 .15737 L .66992 .15966 L 0 .026 .126 r
F
.66665 .16092 m .66507 .15864 L .66834 .15737 L F
.61308 .16117 m .61469 .15778 L .61633 .16 L 0 .027 .127 r
F
.61308 .16117 m .61145 .15895 L .61469 .15778 L F
.41502 .16122 m .41631 .15772 L .41815 .15993 L 0 .027 .126 r
F
.41502 .16122 m .41318 .159 L .41631 .15772 L F
.56762 .161 m .56916 .15747 L .57084 .15967 L F
.56762 .161 m .56594 .15879 L .56916 .15747 L F
.42313 .16081 m .42442 .15747 L .42626 .15964 L F
.42313 .16081 m .42129 .15864 L .42442 .15747 L F
.73644 .15991 m .73825 .15644 L .73976 .15869 L 0 .025 .124 r
F
.73644 .15991 m .73494 .15767 L .73825 .15644 L F
.57573 .16062 m .57728 .15721 L .57896 .15946 L 0 .026 .125 r
F
.57573 .16062 m .57406 .15836 L .57728 .15721 L F
.36955 .16114 m .37077 .1576 L .37266 .15993 L 0 .027 .126 r
F
.36955 .16114 m .36766 .1588 L .37077 .1576 L F
.67477 .16071 m .67648 .15733 L .67805 .15958 L F
.67477 .16071 m .6732 .15847 L .67648 .15733 L F
.6212 .16096 m .62282 .15757 L .62445 .15974 L F
.6212 .16096 m .61957 .15879 L .62282 .15757 L F
.4767 .16079 m .47808 .15744 L .47986 .15966 L F
.4767 .16079 m .47492 .15858 L .47808 .15744 L F
.37765 .16087 m .37887 .15752 L .38076 .15966 L 0 .027 .127 r
F
.37765 .16087 m .37576 .15872 L .37887 .15752 L F
.74457 .15976 m .74639 .15625 L .74789 .15855 L 0 .025 .124 r
F
.74457 .15976 m .74307 .15746 L .74639 .15625 L F
.43123 .16069 m .43254 .15738 L .43436 .15957 L 0 .027 .126 r
F
.43123 .16069 m .4294 .15852 L .43254 .15738 L F
.62931 .1607 m .63095 .15723 L .63256 .1594 L F
.62931 .1607 m .6277 .15852 L .63095 .15723 L F
.52216 .16118 m .52362 .15765 L .52535 .16002 L 0 .028 .127 r
F
.52216 .16118 m .52043 .15885 L .52362 .15765 L F
.63743 .16034 m .63908 .15686 L .64068 .1591 L 0 .026 .125 r
F
.63743 .16034 m .63582 .15809 L .63908 .15686 L F
.38576 .1606 m .38698 .15731 L .38887 .15944 L 0 .027 .126 r
F
.38576 .1606 m .38387 .15849 L .38698 .15731 L F
.58385 .1606 m .58541 .15714 L .58708 .15945 L F
.58385 .1606 m .58218 .1583 L .58541 .15714 L F
.6829 .16068 m .68462 .15716 L .68618 .1594 L F
.6829 .16068 m .68134 .15845 L .68462 .15716 L F
.4848 .1607 m .4862 .15738 L .48797 .15956 L 0 .027 .127 r
F
.4848 .1607 m .48303 .15852 L .4862 .15738 L F
.34028 .16052 m .34144 .1571 L .34337 .15926 L 0 .027 .126 r
F
.34028 .16052 m .33835 .15838 L .34144 .1571 L F
.75271 .15967 m .75455 .1562 L .75604 .15849 L 0 .025 .124 r
F
.75271 .15967 m .75122 .15738 L .75455 .1562 L F
.69102 .16036 m .69275 .15685 L .69431 .15912 L 0 .027 .126 r
F
.69102 .16036 m .68946 .15811 L .69275 .15685 L F
.34838 .16018 m .34956 .15675 L .35147 .15895 L 0 .026 .125 r
F
.34838 .16018 m .34646 .158 L .34956 .15675 L F
.43933 .16064 m .44065 .15731 L .44247 .15952 L 0 .027 .127 r
F
.43933 .16064 m .4375 .15844 L .44065 .15731 L F
.64555 .16021 m .64721 .15681 L .64881 .15905 L 0 .026 .126 r
F
.64555 .16021 m .64395 .15795 L .64721 .15681 L F
.39385 .16046 m .3951 .15713 L .39697 .15932 L 0 .027 .126 r
F
.39385 .16046 m .39198 .15829 L .3951 .15713 L F
.49291 .16048 m .49432 .15702 L .49608 .15921 L F
.49291 .16048 m .49114 .15829 L .49432 .15702 L F
.69914 .16009 m .7009 .15673 L .70243 .15887 L 0 .026 .126 r
F
.69914 .16009 m .6976 .15792 L .7009 .15673 L F
.53027 .16124 m .53175 .15764 L .53347 .16003 L 0 .028 .128 r
F
.53027 .16124 m .52855 .15885 L .53175 .15764 L F
.59197 .16062 m .59354 .15714 L .5952 .15949 L 0 .027 .127 r
F
.59197 .16062 m .59031 .15829 L .59354 .15714 L F
.70726 .15977 m .70903 .15643 L .71056 .15856 L 0 .026 .125 r
F
.70726 .15977 m .70573 .15765 L .70903 .15643 L F
.35648 .16 m .35767 .15653 L .35957 .15881 L F
.35648 .16 m .35457 .15772 L .35767 .15653 L F
.50102 .16026 m .50244 .15674 L .5042 .15902 L 0 .027 .126 r
F
.50102 .16026 m .49926 .15796 L .50244 .15674 L F
.44743 .1605 m .44877 .157 L .45058 .15919 L 0 .027 .127 r
F
.44743 .1605 m .44562 .1583 L .44877 .157 L F
.65367 .16007 m .65535 .15662 L .65694 .15886 L 0 .027 .126 r
F
.65367 .16007 m .65208 .15784 L .65535 .15662 L F
.76085 .15963 m .7627 .15617 L .76419 .15848 L 0 .026 .125 r
F
.76085 .15963 m .75937 .15733 L .7627 .15617 L F
.45554 .16008 m .45689 .1566 L .45869 .15879 L 0 .027 .126 r
F
.45554 .16008 m .45373 .15788 L .45689 .1566 L F
.53838 .16099 m .53987 .15755 L .54158 .15973 L 0 .028 .128 r
F
.53838 .16099 m .53667 .1588 L .53987 .15755 L F
.71538 .15949 m .71716 .15604 L .71868 .15819 L 0 .026 .124 r
F
.71538 .15949 m .71386 .15734 L .71716 .15604 L F
.72349 .15907 m .72529 .15566 L .7268 .15783 L 0 .025 .124 r
F
.72349 .15907 m .72198 .15689 L .72529 .15566 L F
.60009 .16043 m .60168 .15692 L .60332 .15915 L 0 .027 .127 r
F
.60009 .16043 m .59844 .15822 L .60168 .15692 L F
.46365 .15978 m .46501 .15624 L .46681 .15854 L 0 .026 .125 r
F
.46365 .15978 m .46185 .15749 L .46501 .15624 L F
.5465 .16068 m .548 .15739 L .5497 .1595 L 0 .028 .128 r
F
.5465 .16068 m .54479 .15856 L .548 .15739 L F
.50913 .16002 m .51057 .1566 L .51231 .15885 L 0 .027 .126 r
F
.50913 .16002 m .50738 .15777 L .51057 .1566 L F
.40194 .16052 m .40321 .15692 L .40507 .15925 L 0 .027 .127 r
F
.40194 .16052 m .40008 .15818 L .40321 .15692 L F
.6082 .16012 m .60981 .15672 L .61145 .15895 L 0 .027 .126 r
F
.6082 .16012 m .60656 .1579 L .60981 .15672 L F
.6618 .15991 m .66348 .15636 L .66507 .15864 L 0 .026 .126 r
F
.6618 .15991 m .66021 .15763 L .66348 .15636 L F
.55461 .1604 m .55612 .157 L .55782 .15914 L 0 .028 .127 r
F
.55461 .1604 m .55291 .15828 L .55612 .157 L F
.73162 .15883 m .73344 .15552 L .73494 .15767 L 0 .025 .124 r
F
.73162 .15883 m .73012 .15668 L .73344 .15552 L F
.36456 .15999 m .36577 .15645 L .36766 .1588 L 0 .027 .126 r
F
.36456 .15999 m .36267 .15763 L .36577 .15645 L F
.41005 .16028 m .41133 .15671 L .41318 .159 L 0 .027 .127 r
F
.41005 .16028 m .4082 .15798 L .41133 .15671 L F
.56272 .1601 m .56425 .15658 L .56594 .15879 L 0 .027 .126 r
F
.56272 .1601 m .56103 .15788 L .56425 .15658 L F
.66992 .15966 m .67162 .15617 L .6732 .15847 L 0 .026 .125 r
F
.66992 .15966 m .66834 .15737 L .67162 .15617 L F
.57084 .15967 m .57238 .15617 L .57406 .15836 L F
.57084 .15967 m .56916 .15747 L .57238 .15617 L F
.47175 .1597 m .47313 .15626 L .47492 .15858 L 0 .027 .126 r
F
.47175 .1597 m .46997 .1574 L .47313 .15626 L F
.41815 .15993 m .41945 .15644 L .42129 .15864 L F
.41815 .15993 m .41631 .15772 L .41945 .15644 L F
.51724 .15999 m .51869 .15654 L .52043 .15885 L 0 .027 .127 r
F
.51724 .15999 m .5155 .15771 L .51869 .15654 L F
.61633 .16 m .61794 .15657 L .61957 .15879 L F
.61633 .16 m .61469 .15778 L .61794 .15657 L F
.73976 .15869 m .74157 .15521 L .74307 .15746 L 0 .025 .123 r
F
.73976 .15869 m .73825 .15644 L .74157 .15521 L F
.42626 .15964 m .42756 .15633 L .4294 .15852 L 0 .027 .126 r
F
.42626 .15964 m .42442 .15747 L .42756 .15633 L F
.57896 .15946 m .58051 .15605 L .58218 .1583 L 0 .026 .126 r
F
.57896 .15946 m .57728 .15721 L .58051 .15605 L F
.37266 .15993 m .37388 .15641 L .37576 .15872 L 0 .027 .126 r
F
.37266 .15993 m .37077 .1576 L .37388 .15641 L F
.62445 .15974 m .62608 .15635 L .6277 .15852 L F
.62445 .15974 m .62282 .15757 L .62608 .15635 L F
.67805 .15958 m .67977 .15618 L .68134 .15845 L F
.67805 .15958 m .67648 .15733 L .67977 .15618 L F
.63256 .1594 m .63421 .15594 L .63582 .15809 L 0 .026 .126 r
F
.63256 .1594 m .63095 .15723 L .63421 .15594 L F
.47986 .15966 m .48125 .15629 L .48303 .15852 L 0 .027 .126 r
F
.47986 .15966 m .47808 .15744 L .48125 .15629 L F
.38076 .15966 m .38199 .15632 L .38387 .15849 L 0 .027 .127 r
F
.38076 .15966 m .37887 .15752 L .38199 .15632 L F
.74789 .15855 m .74972 .15508 L .75122 .15738 L 0 .025 .124 r
F
.74789 .15855 m .74639 .15625 L .74972 .15508 L F
.64068 .1591 m .64234 .15573 L .64395 .15795 L 0 .026 .125 r
F
.64068 .1591 m .63908 .15686 L .64234 .15573 L F
.52535 .16002 m .52682 .15645 L .52855 .15885 L 0 .028 .127 r
F
.52535 .16002 m .52362 .15765 L .52682 .15645 L F
.43436 .15957 m .43568 .15624 L .4375 .15844 L 0 .027 .127 r
F
.43436 .15957 m .43254 .15738 L .43568 .15624 L F
.68618 .1594 m .68791 .15586 L .68946 .15811 L 0 .027 .126 r
F
.68618 .1594 m .68462 .15716 L .68791 .15586 L F
.38887 .15944 m .3901 .15613 L .39198 .15829 L F
.38887 .15944 m .38698 .15731 L .3901 .15613 L F
.58708 .15945 m .58864 .15596 L .59031 .15829 L F
.58708 .15945 m .58541 .15714 L .58864 .15596 L F
.34337 .15926 m .34453 .15582 L .34646 .158 L F
.34337 .15926 m .34144 .1571 L .34453 .15582 L F
.48797 .15956 m .48938 .15611 L .49114 .15829 L 0 .027 .127 r
F
.48797 .15956 m .4862 .15738 L .48938 .15611 L F
.69431 .15912 m .69605 .15565 L .6976 .15792 L 0 .026 .126 r
F
.69431 .15912 m .69275 .15685 L .69605 .15565 L F
.75604 .15849 m .75788 .15504 L .75937 .15733 L 0 .025 .124 r
F
.75604 .15849 m .75455 .1562 L .75788 .15504 L F
.35147 .15895 m .35266 .1555 L .35457 .15772 L 0 .026 .125 r
F
.35147 .15895 m .34956 .15675 L .35266 .1555 L F
.49608 .15921 m .4975 .15578 L .49926 .15796 L 0 .027 .126 r
F
.49608 .15921 m .49432 .15702 L .4975 .15578 L F
.64881 .15905 m .65048 .1556 L .65208 .15784 L F
.64881 .15905 m .64721 .15681 L .65048 .1556 L F
.44247 .15952 m .4438 .1561 L .44562 .1583 L 0 .027 .127 r
F
.44247 .15952 m .44065 .15731 L .4438 .1561 L F
.39697 .15932 m .39822 .15596 L .40008 .15818 L F
.39697 .15932 m .3951 .15713 L .39822 .15596 L F
.70243 .15887 m .7042 .15551 L .70573 .15765 L 0 .026 .125 r
F
.70243 .15887 m .7009 .15673 L .7042 .15551 L F
.53347 .16003 m .53495 .15642 L .53667 .1588 L 0 .028 .128 r
F
.53347 .16003 m .53175 .15764 L .53495 .15642 L F
.45058 .15919 m .45192 .15571 L .45373 .15788 L 0 .027 .126 r
F
.45058 .15919 m .44877 .157 L .45192 .15571 L F
.71056 .15856 m .71233 .1552 L .71386 .15734 L 0 .026 .125 r
F
.71056 .15856 m .70903 .15643 L .71233 .1552 L F
.45869 .15879 m .46005 .15531 L .46185 .15749 L F
.45869 .15879 m .45689 .1566 L .46005 .15531 L F
.5042 .15902 m .50563 .15552 L .50738 .15777 L 0 .027 .126 r
F
.5042 .15902 m .50244 .15674 L .50563 .15552 L F
.35957 .15881 m .36077 .15536 L .36267 .15763 L 0 .026 .125 r
F
.35957 .15881 m .35767 .15653 L .36077 .15536 L F
.5952 .15949 m .59678 .15587 L .59844 .15822 L 0 .027 .127 r
F
.5952 .15949 m .59354 .15714 L .59678 .15587 L F
.54158 .15973 m .54308 .15639 L .54479 .15856 L 0 .028 .128 r
F
.54158 .15973 m .53987 .15755 L .54308 .15639 L F
.65694 .15886 m .65862 .15539 L .66021 .15763 L 0 .026 .126 r
F
.65694 .15886 m .65535 .15662 L .65862 .15539 L F
.71868 .15819 m .72046 .15474 L .72198 .15689 L 0 .025 .124 r
F
.71868 .15819 m .71716 .15604 L .72046 .15474 L F
.60332 .15915 m .60492 .15566 L .60656 .1579 L 0 .027 .126 r
F
.60332 .15915 m .60168 .15692 L .60492 .15566 L F
.76419 .15848 m .76604 .15501 L .76753 .15734 L 0 .026 .125 r
F
.76419 .15848 m .7627 .15617 L .76604 .15501 L F
.7268 .15783 m .72861 .15451 L .73012 .15668 L 0 .025 .124 r
F
.7268 .15783 m .72529 .15566 L .72861 .15451 L F
.46681 .15854 m .46818 .15509 L .46997 .1574 L 0 .026 .125 r
F
.46681 .15854 m .46501 .15624 L .46818 .15509 L F
.40507 .15925 m .40634 .15567 L .4082 .15798 L 0 .027 .127 r
F
.40507 .15925 m .40321 .15692 L .40634 .15567 L F
.5497 .1595 m .55121 .15617 L .55291 .15828 L 0 .028 .128 r
F
.5497 .1595 m .548 .15739 L .55121 .15617 L F
.51231 .15885 m .51376 .15544 L .5155 .15771 L 0 .027 .126 r
F
.51231 .15885 m .51057 .1566 L .51376 .15544 L F
.66507 .15864 m .66676 .15508 L .66834 .15737 L 0 .026 .125 r
F
.66507 .15864 m .66348 .15636 L .66676 .15508 L F
.55782 .15914 m .55934 .15573 L .56103 .15788 L 0 .027 .127 r
F
.55782 .15914 m .55612 .157 L .55934 .15573 L F
.61145 .15895 m .61306 .15555 L .61469 .15778 L 0 .027 .126 r
F
.61145 .15895 m .60981 .15672 L .61306 .15555 L F
.41318 .159 m .41446 .15545 L .41631 .15772 L F
.41318 .159 m .41133 .15671 L .41446 .15545 L F
.56594 .15879 m .56747 .15527 L .56916 .15747 L F
.56594 .15879 m .56425 .15658 L .56747 .15527 L F
.36766 .1588 m .36888 .15527 L .37077 .1576 L F
.36766 .1588 m .36577 .15645 L .36888 .15527 L F
.73494 .15767 m .73675 .15428 L .73825 .15644 L 0 .025 .124 r
F
.73494 .15767 m .73344 .15552 L .73675 .15428 L F
.57406 .15836 m .57561 .15502 L .57728 .15721 L 0 .026 .125 r
F
.57406 .15836 m .57238 .15617 L .57561 .15502 L F
.42129 .15864 m .42258 .15526 L .42442 .15747 L 0 .027 .126 r
F
.42129 .15864 m .41945 .15644 L .42258 .15526 L F
.6732 .15847 m .67491 .15502 L .67648 .15733 L 0 .026 .126 r
F
.6732 .15847 m .67162 .15617 L .67491 .15502 L F
.61957 .15879 m .62119 .15533 L .62282 .15757 L 0 .027 .126 r
F
.61957 .15879 m .61794 .15657 L .62119 .15533 L F
.47492 .15858 m .4763 .1551 L .47808 .15744 L F
.47492 .15858 m .47313 .15626 L .4763 .1551 L F
.74307 .15746 m .7449 .15399 L .74639 .15625 L 0 .025 .123 r
F
.74307 .15746 m .74157 .15521 L .7449 .15399 L F
.52043 .15885 m .52189 .15533 L .52362 .15765 L 0 .027 .127 r
F
.52043 .15885 m .51869 .15654 L .52189 .15533 L F
.37576 .15872 m .37699 .15521 L .37887 .15752 L 0 .027 .126 r
F
.37576 .15872 m .37388 .15641 L .37699 .15521 L F
.4294 .15852 m .4307 .15519 L .43254 .15738 L F
.4294 .15852 m .42756 .15633 L .4307 .15519 L F
.6277 .15852 m .62933 .15507 L .63095 .15723 L F
.6277 .15852 m .62608 .15635 L .62933 .15507 L F
.58218 .1583 m .58374 .15488 L .58541 .15714 L F
.58218 .1583 m .58051 .15605 L .58374 .15488 L F
.63582 .15809 m .63747 .15471 L .63908 .15686 L 0 .026 .125 r
F
.63582 .15809 m .63421 .15594 L .63747 .15471 L F
.68134 .15845 m .68306 .15488 L .68462 .15716 L 0 .027 .126 r
F
.68134 .15845 m .67977 .15618 L .68306 .15488 L F
.38387 .15849 m .3851 .15513 L .38698 .15731 L 0 .027 .127 r
F
.38387 .15849 m .38199 .15632 L .3851 .15513 L F
.75122 .15738 m .75305 .15391 L .75455 .1562 L 0 .025 .124 r
F
.75122 .15738 m .74972 .15508 L .75305 .15391 L F
.48303 .15852 m .48442 .15513 L .4862 .15738 L 0 .027 .127 r
F
.48303 .15852 m .48125 .15629 L .48442 .15513 L F
.68946 .15811 m .6912 .15458 L .69275 .15685 L 0 .026 .125 r
F
.68946 .15811 m .68791 .15586 L .6912 .15458 L F
.52855 .15885 m .53002 .15525 L .53175 .15764 L 0 .028 .127 r
F
.52855 .15885 m .52682 .15645 L .53002 .15525 L F
.64395 .15795 m .64561 .15459 L .64721 .15681 L 0 .026 .125 r
F
.64395 .15795 m .64234 .15573 L .64561 .15459 L F
.4375 .15844 m .43882 .15509 L .44065 .15731 L 0 .027 .127 r
F
.4375 .15844 m .43568 .15624 L .43882 .15509 L F
.34646 .158 m .34763 .15455 L .34956 .15675 L 0 .026 .126 r
F
.34646 .158 m .34453 .15582 L .34763 .15455 L F
.39198 .15829 m .39322 .15495 L .3951 .15713 L 0 .027 .127 r
F
.39198 .15829 m .3901 .15613 L .39322 .15495 L F
.49114 .15829 m .49256 .15484 L .49432 .15702 L 0 .027 .126 r
F
.49114 .15829 m .48938 .15611 L .49256 .15484 L F
.59031 .15829 m .59188 .15479 L .59354 .15714 L F
.59031 .15829 m .58864 .15596 L .59188 .15479 L F
.6976 .15792 m .69935 .15445 L .7009 .15673 L 0 .026 .126 r
F
.6976 .15792 m .69605 .15565 L .69935 .15445 L F
.35457 .15772 m .35575 .1543 L .35767 .15653 L 0 .026 .125 r
F
.35457 .15772 m .35266 .1555 L .35575 .1543 L F
.49926 .15796 m .50069 .15456 L .50244 .15674 L 0 .027 .126 r
F
.49926 .15796 m .4975 .15578 L .50069 .15456 L F
.75937 .15733 m .76122 .15389 L .7627 .15617 L 0 .026 .124 r
F
.75937 .15733 m .75788 .15504 L .76122 .15389 L F
.65208 .15784 m .65376 .15438 L .65535 .15662 L 0 .026 .126 r
F
.65208 .15784 m .65048 .1556 L .65376 .15438 L F
.44562 .1583 m .44695 .15481 L .44877 .157 L 0 .027 .127 r
F
.44562 .1583 m .4438 .1561 L .44695 .15481 L F
.70573 .15765 m .7075 .15428 L .70903 .15643 L 0 .026 .125 r
F
.70573 .15765 m .7042 .15551 L .7075 .15428 L F
.45373 .15788 m .45508 .15444 L .45689 .1566 L 0 .027 .126 r
F
.45373 .15788 m .45192 .15571 L .45508 .15444 L F
.53667 .1588 m .53815 .1552 L .53987 .15755 L 0 .028 .128 r
F
.53667 .1588 m .53495 .15642 L .53815 .1552 L F
.46185 .15749 m .46322 .15407 L .46501 .15624 L 0 .026 .125 r
F
.46185 .15749 m .46005 .15531 L .46322 .15407 L F
.40008 .15818 m .40135 .15473 L .40321 .15692 L 0 .027 .127 r
F
.40008 .15818 m .39822 .15596 L .40135 .15473 L F
.59844 .15822 m .60002 .15459 L .60168 .15692 L 0 .027 .126 r
F
.59844 .15822 m .59678 .15587 L .60002 .15459 L F
.50738 .15777 m .50882 .15434 L .51057 .1566 L F
.50738 .15777 m .50563 .15552 L .50882 .15434 L F
.72198 .15689 m .72377 .1535 L .72529 .15566 L 0 .025 .124 r
F
.72198 .15689 m .72046 .15474 L .72377 .1535 L F
.71386 .15734 m .71564 .1539 L .71716 .15604 L 0 .026 .125 r
F
.71386 .15734 m .71233 .1552 L .71564 .1539 L F
.36267 .15763 m .36387 .1542 L .36577 .15645 L 0 .026 .126 r
F
.36267 .15763 m .36077 .15536 L .36387 .1542 L F
.66021 .15763 m .6619 .15414 L .66348 .15636 L 0 .026 .125 r
F
.66021 .15763 m .65862 .15539 L .6619 .15414 L F
.54479 .15856 m .54629 .15523 L .548 .15739 L 0 .028 .128 r
F
.54479 .15856 m .54308 .15639 L .54629 .15523 L F
.60656 .1579 m .60816 .15448 L .60981 .15672 L 0 .027 .126 r
F
.60656 .1579 m .60492 .15566 L .60816 .15448 L F
.4082 .15798 m .40947 .15442 L .41133 .15671 L F
.4082 .15798 m .40634 .15567 L .40947 .15442 L F
.73012 .15668 m .73193 .15336 L .73344 .15552 L 0 .025 .124 r
F
.73012 .15668 m .72861 .15451 L .73193 .15336 L F
.66834 .15737 m .67004 .15387 L .67162 .15617 L 0 .026 .125 r
F
.66834 .15737 m .66676 .15508 L .67004 .15387 L F
.55291 .15828 m .55443 .15488 L .55612 .157 L 0 .028 .127 r
F
.55291 .15828 m .55121 .15617 L .55443 .15488 L F
.46997 .1574 m .47134 .15394 L .47313 .15626 L 0 .026 .125 r
F
.46997 .1574 m .46818 .15509 L .47134 .15394 L F
.56103 .15788 m .56256 .15442 L .56425 .15658 L 0 .027 .126 r
F
.56103 .15788 m .55934 .15573 L .56256 .15442 L F
.56916 .15747 m .5707 .15398 L .57238 .15617 L 0 .026 .126 r
F
.56916 .15747 m .56747 .15527 L .5707 .15398 L F
.5155 .15771 m .51695 .15426 L .51869 .15654 L 0 .027 .126 r
F
.5155 .15771 m .51376 .15544 L .51695 .15426 L F
.41631 .15772 m .4176 .15419 L .41945 .15644 L F
.41631 .15772 m .41446 .15545 L .4176 .15419 L F
.61469 .15778 m .61631 .15432 L .61794 .15657 L F
.61469 .15778 m .61306 .15555 L .61631 .15432 L F
.73825 .15644 m .74007 .15303 L .74157 .15521 L 0 .025 .123 r
F
.73825 .15644 m .73675 .15428 L .74007 .15303 L F
.37077 .1576 m .37199 .15409 L .37388 .15641 L 0 .027 .126 r
F
.37077 .1576 m .36888 .15527 L .37199 .15409 L F
.57728 .15721 m .57884 .15387 L .58051 .15605 L 0 .026 .126 r
F
.57728 .15721 m .57561 .15502 L .57884 .15387 L F
.42442 .15747 m .42572 .15411 L .42756 .15633 L 0 .027 .126 r
F
.42442 .15747 m .42258 .15526 L .42572 .15411 L F
.67648 .15733 m .6782 .15388 L .67977 .15618 L F
.67648 .15733 m .67491 .15502 L .6782 .15388 L F
.62282 .15757 m .62445 .15409 L .62608 .15635 L F
.62282 .15757 m .62119 .15533 L .62445 .15409 L F
.74639 .15625 m .74823 .15282 L .74972 .15508 L 0 .025 .123 r
F
.74639 .15625 m .7449 .15399 L .74823 .15282 L F
.52362 .15765 m .52509 .15411 L .52682 .15645 L 0 .027 .127 r
F
.52362 .15765 m .52189 .15533 L .52509 .15411 L F
.47808 .15744 m .47947 .15393 L .48125 .15629 L 0 .027 .126 r
F
.47808 .15744 m .4763 .1551 L .47947 .15393 L F
.63095 .15723 m .63259 .15379 L .63421 .15594 L F
.63095 .15723 m .62933 .15507 L .63259 .15379 L F
.37887 .15752 m .3801 .154 L .38199 .15632 L F
.37887 .15752 m .37699 .15521 L .3801 .154 L F
.63908 .15686 m .64074 .15358 L .64234 .15573 L 0 .026 .125 r
F
.63908 .15686 m .63747 .15471 L .64074 .15358 L F
.58541 .15714 m .58698 .15369 L .58864 .15596 L 0 .027 .126 r
F
.58541 .15714 m .58374 .15488 L .58698 .15369 L F
.68462 .15716 m .68634 .15357 L .68791 .15586 L 0 .026 .126 r
F
.68462 .15716 m .68306 .15488 L .68634 .15357 L F
.43254 .15738 m .43385 .15403 L .43568 .15624 L 0 .027 .127 r
F
.43254 .15738 m .4307 .15519 L .43385 .15403 L F
.69275 .15685 m .69449 .15337 L .69605 .15565 L 0 .026 .125 r
F
.69275 .15685 m .6912 .15458 L .69449 .15337 L F
.38698 .15731 m .38822 .15392 L .3901 .15613 L 0 .027 .127 r
F
.38698 .15731 m .3851 .15513 L .38822 .15392 L F
.75455 .1562 m .75639 .15275 L .75788 .15504 L 0 .025 .124 r
F
.75455 .1562 m .75305 .15391 L .75639 .15275 L F
.4862 .15738 m .4876 .15386 L .48938 .15611 L 0 .027 .127 r
F
.4862 .15738 m .48442 .15513 L .4876 .15386 L F
.53175 .15764 m .53322 .15405 L .53495 .15642 L 0 .028 .127 r
F
.53175 .15764 m .53002 .15525 L .53322 .15405 L F
.34956 .15675 m .35074 .15327 L .35266 .1555 L 0 .026 .125 r
F
.34956 .15675 m .34763 .15455 L .35074 .15327 L F
.49432 .15702 m .49574 .15359 L .4975 .15578 L 0 .027 .126 r
F
.49432 .15702 m .49256 .15484 L .49574 .15359 L F
.64721 .15681 m .64888 .15338 L .65048 .1556 L 0 .026 .126 r
F
.64721 .15681 m .64561 .15459 L .64888 .15338 L F
.44065 .15731 m .44198 .15388 L .4438 .1561 L 0 .027 .127 r
F
.44065 .15731 m .43882 .15509 L .44198 .15388 L F
.3951 .15713 m .39635 .15376 L .39822 .15596 L F
.3951 .15713 m .39322 .15495 L .39635 .15376 L F
.59354 .15714 m .59512 .15352 L .59678 .15587 L 0 .027 .126 r
F
.59354 .15714 m .59188 .15479 L .59512 .15352 L F
.7009 .15673 m .70265 .15322 L .7042 .15551 L 0 .026 .125 r
F
.7009 .15673 m .69935 .15445 L .70265 .15322 L F
.50244 .15674 m .50387 .15334 L .50563 .15552 L 0 .027 .126 r
F
.50244 .15674 m .50069 .15456 L .50387 .15334 L F
.35767 .15653 m .35886 .15316 L .36077 .15536 L 0 .026 .125 r
F
.35767 .15653 m .35575 .1543 L .35886 .15316 L F
.44877 .157 m .45011 .15353 L .45192 .15571 L 0 .027 .126 r
F
.44877 .157 m .44695 .15481 L .45011 .15353 L F
.45689 .1566 m .45825 .15317 L .46005 .15531 L 0 .026 .125 r
F
.45689 .1566 m .45508 .15444 L .45825 .15317 L F
.7627 .15617 m .76456 .15274 L .76604 .15501 L 0 .026 .124 r
F
.7627 .15617 m .76122 .15389 L .76456 .15274 L F
.65535 .15662 m .65703 .15315 L .65862 .15539 L 0 .026 .125 r
F
.65535 .15662 m .65376 .15438 L .65703 .15315 L F
.53987 .15755 m .54136 .15405 L .54308 .15639 L 0 .028 .128 r
F
.53987 .15755 m .53815 .1552 L .54136 .15405 L F
.70903 .15643 m .7108 .15303 L .71233 .1552 L 0 .026 .125 r
F
.70903 .15643 m .7075 .15428 L .7108 .15303 L F
.46501 .15624 m .46638 .1529 L .46818 .15509 L F
.46501 .15624 m .46322 .15407 L .46638 .1529 L F
.60168 .15692 m .60327 .15333 L .60492 .15566 L 0 .027 .126 r
F
.60168 .15692 m .60002 .15459 L .60327 .15333 L F
.40321 .15692 m .40448 .15349 L .40634 .15567 L F
.40321 .15692 m .40135 .15473 L .40448 .15349 L F
.71716 .15604 m .71894 .15259 L .72046 .15474 L 0 .026 .124 r
F
.71716 .15604 m .71564 .1539 L .71894 .15259 L F
.72529 .15566 m .7271 .15235 L .72861 .15451 L 0 .025 .124 r
F
.72529 .15566 m .72377 .1535 L .7271 .15235 L F
.66348 .15636 m .66518 .15288 L .66676 .15508 L 0 .026 .125 r
F
.66348 .15636 m .6619 .15414 L .66518 .15288 L F
.51057 .1566 m .51201 .15316 L .51376 .15544 L 0 .027 .126 r
F
.51057 .1566 m .50882 .15434 L .51201 .15316 L F
.36577 .15645 m .36698 .15304 L .36888 .15527 L F
.36577 .15645 m .36387 .1542 L .36698 .15304 L F
.41133 .15671 m .41261 .15318 L .41446 .15545 L F
.41133 .15671 m .40947 .15442 L .41261 .15318 L F
.548 .15739 m .5495 .15402 L .55121 .15617 L 0 .028 .128 r
F
.548 .15739 m .54629 .15523 L .5495 .15402 L F
.60981 .15672 m .61142 .1533 L .61306 .15555 L 0 .027 .126 r
F
.60981 .15672 m .60816 .15448 L .61142 .1533 L F
.55612 .157 m .55764 .15359 L .55934 .15573 L 0 .028 .127 r
F
.55612 .157 m .55443 .15488 L .55764 .15359 L F
.56425 .15658 m .56578 .1531 L .56747 .15527 L 0 .027 .126 r
F
.56425 .15658 m .56256 .15442 L .56578 .1531 L F
.67162 .15617 m .67333 .15272 L .67491 .15502 L 0 .026 .125 r
F
.67162 .15617 m .67004 .15387 L .67333 .15272 L F
.57238 .15617 m .57393 .15283 L .57561 .15502 L F
.57238 .15617 m .5707 .15398 L .57393 .15283 L F
.73344 .15552 m .73525 .15212 L .73675 .15428 L 0 .025 .124 r
F
.73344 .15552 m .73193 .15336 L .73525 .15212 L F
.41945 .15644 m .42074 .153 L .42258 .15526 L 0 .027 .126 r
F
.41945 .15644 m .4176 .15419 L .42074 .153 L F
.47313 .15626 m .47452 .15276 L .4763 .1551 L 0 .026 .125 r
F
.47313 .15626 m .47134 .15394 L .47452 .15276 L F
.51869 .15654 m .52015 .15303 L .52189 .15533 L 0 .027 .126 r
F
.51869 .15654 m .51695 .15426 L .52015 .15303 L F
.74157 .15521 m .7434 .1518 L .7449 .15399 L 0 .025 .123 r
F
.74157 .15521 m .74007 .15303 L .7434 .1518 L F
.61794 .15657 m .61956 .15305 L .62119 .15533 L 0 .027 .126 r
F
.61794 .15657 m .61631 .15432 L .61956 .15305 L F
.37388 .15641 m .3751 .1529 L .37699 .15521 L F
.37388 .15641 m .37199 .15409 L .3751 .1529 L F
.58051 .15605 m .58207 .1527 L .58374 .15488 L F
.58051 .15605 m .57884 .15387 L .58207 .1527 L F
.42756 .15633 m .42887 .15295 L .4307 .15519 L F
.42756 .15633 m .42572 .15411 L .42887 .15295 L F
.62608 .15635 m .62771 .15281 L .62933 .15507 L F
.62608 .15635 m .62445 .15409 L .62771 .15281 L F
.63421 .15594 m .63586 .15256 L .63747 .15471 L 0 .026 .126 r
F
.63421 .15594 m .63259 .15379 L .63586 .15256 L F
.67977 .15618 m .68149 .15257 L .68306 .15488 L 0 .027 .126 r
F
.67977 .15618 m .6782 .15388 L .68149 .15257 L F
.74972 .15508 m .75156 .15165 L .75305 .15391 L 0 .025 .123 r
F
.74972 .15508 m .74823 .15282 L .75156 .15165 L F
.52682 .15645 m .52829 .15291 L .53002 .15525 L 0 .027 .127 r
F
.52682 .15645 m .52509 .15411 L .52829 .15291 L F
.48125 .15629 m .48265 .15275 L .48442 .15513 L 0 .027 .126 r
F
.48125 .15629 m .47947 .15393 L .48265 .15275 L F
.68791 .15586 m .68964 .15229 L .6912 .15458 L 0 .026 .125 r
F
.68791 .15586 m .68634 .15357 L .68964 .15229 L F
.38199 .15632 m .38322 .15278 L .3851 .15513 L 0 .027 .126 r
F
.38199 .15632 m .3801 .154 L .38322 .15278 L F
.64234 .15573 m .64401 .15243 L .64561 .15459 L 0 .026 .126 r
F
.64234 .15573 m .64074 .15358 L .64401 .15243 L F
.58864 .15596 m .59022 .1525 L .59188 .15479 L 0 .027 .126 r
F
.58864 .15596 m .58698 .15369 L .59022 .1525 L F
.43568 .15624 m .437 .15287 L .43882 .15509 L 0 .027 .127 r
F
.43568 .15624 m .43385 .15403 L .437 .15287 L F
.69605 .15565 m .6978 .15216 L .69935 .15445 L 0 .026 .125 r
F
.69605 .15565 m .69449 .15337 L .6978 .15216 L F
.48938 .15611 m .49079 .1526 L .49256 .15484 L 0 .027 .126 r
F
.48938 .15611 m .4876 .15386 L .49079 .1526 L F
.3901 .15613 m .39135 .15272 L .39322 .15495 L 0 .027 .127 r
F
.3901 .15613 m .38822 .15392 L .39135 .15272 L F
.75788 .15504 m .75974 .15161 L .76122 .15389 L 0 .025 .124 r
F
.75788 .15504 m .75639 .15275 L .75974 .15161 L F
.35266 .1555 m .35384 .15207 L .35575 .1543 L 0 .026 .125 r
F
.35266 .1555 m .35074 .15327 L .35384 .15207 L F
.53495 .15642 m .53643 .15284 L .53815 .1552 L 0 .028 .127 r
F
.53495 .15642 m .53322 .15405 L .53643 .15284 L F
.4975 .15578 m .49893 .15238 L .50069 .15456 L 0 .027 .126 r
F
.4975 .15578 m .49574 .15359 L .49893 .15238 L F
.65048 .1556 m .65216 .15215 L .65376 .15438 L 0 .026 .126 r
F
.65048 .1556 m .64888 .15338 L .65216 .15215 L F
.4438 .1561 m .44513 .1526 L .44695 .15481 L 0 .027 .127 r
F
.4438 .1561 m .44198 .15388 L .44513 .1526 L F
.59678 .15587 m .59836 .15225 L .60002 .15459 L 0 .027 .126 r
F
.59678 .15587 m .59512 .15352 L .59836 .15225 L F
.45192 .15571 m .45327 .15228 L .45508 .15444 L F
.45192 .15571 m .45011 .15353 L .45327 .15228 L F
.7042 .15551 m .70595 .15197 L .7075 .15428 L 0 .026 .125 r
F
.7042 .15551 m .70265 .15322 L .70595 .15197 L F
.39822 .15596 m .39948 .15255 L .40135 .15473 L 0 .027 .127 r
F
.39822 .15596 m .39635 .15376 L .39948 .15255 L F
.50563 .15552 m .50707 .15214 L .50882 .15434 L 0 .027 .126 r
F
.50563 .15552 m .50387 .15334 L .50707 .15214 L F
.46005 .15531 m .46141 .15193 L .46322 .15407 L 0 .026 .125 r
F
.46005 .15531 m .45825 .15317 L .46141 .15193 L F
.36077 .15536 m .36196 .15201 L .36387 .1542 L F
.36077 .15536 m .35886 .15316 L .36196 .15201 L F
.65862 .15539 m .66031 .15193 L .6619 .15414 L F
.65862 .15539 m .65703 .15315 L .66031 .15193 L F
.72046 .15474 m .72226 .15135 L .72377 .1535 L 0 .025 .124 r
F
.72046 .15474 m .71894 .15259 L .72226 .15135 L F
.71233 .1552 m .71411 .15173 L .71564 .1539 L 0 .026 .125 r
F
.71233 .1552 m .7108 .15303 L .71411 .15173 L F
.60492 .15566 m .60652 .15217 L .60816 .15448 L 0 .027 .126 r
F
.60492 .15566 m .60327 .15333 L .60652 .15217 L F
.40634 .15567 m .40761 .15226 L .40947 .15442 L F
.40634 .15567 m .40448 .15349 L .40761 .15226 L F
.54308 .15639 m .54458 .1529 L .54629 .15523 L 0 .028 .128 r
F
.54308 .15639 m .54136 .15405 L .54458 .1529 L F
.66676 .15508 m .66846 .15169 L .67004 .15387 L 0 .026 .125 r
F
.66676 .15508 m .66518 .15288 L .66846 .15169 L F
.46818 .15509 m .46955 .15173 L .47134 .15394 L F
.46818 .15509 m .46638 .1529 L .46955 .15173 L F
.72861 .15451 m .73042 .15119 L .73193 .15336 L 0 .025 .124 r
F
.72861 .15451 m .7271 .15235 L .73042 .15119 L F
.51376 .15544 m .51521 .15197 L .51695 .15426 L 0 .027 .126 r
F
.51376 .15544 m .51201 .15316 L .51521 .15197 L F
.41446 .15545 m .41575 .15194 L .4176 .15419 L F
.41446 .15545 m .41261 .15318 L .41575 .15194 L F
.55121 .15617 m .55272 .15271 L .55443 .15488 L 0 .028 .128 r
F
.55121 .15617 m .5495 .15402 L .55272 .15271 L F
.56747 .15527 m .56901 .1518 L .5707 .15398 L 0 .027 .126 r
F
.56747 .15527 m .56578 .1531 L .56901 .1518 L F
.36888 .15527 m .37009 .15188 L .37199 .15409 L F
.36888 .15527 m .36698 .15304 L .37009 .15188 L F
.55934 .15573 m .56087 .15227 L .56256 .15442 L 0 .027 .127 r
F
.55934 .15573 m .55764 .15359 L .56087 .15227 L F
.61306 .15555 m .61467 .15206 L .61631 .15432 L 0 .027 .126 r
F
.61306 .15555 m .61142 .1533 L .61467 .15206 L F
.73675 .15428 m .73857 .15085 L .74007 .15303 L 0 .025 .124 r
F
.73675 .15428 m .73525 .15212 L .73857 .15085 L F
.57561 .15502 m .57716 .15169 L .57884 .15387 L 0 .027 .126 r
F
.57561 .15502 m .57393 .15283 L .57716 .15169 L F
.67491 .15502 m .67662 .15157 L .6782 .15388 L 0 .026 .125 r
F
.67491 .15502 m .67333 .15272 L .67662 .15157 L F
.42258 .15526 m .42388 .15183 L .42572 .15411 L 0 .027 .126 r
F
.42258 .15526 m .42074 .153 L .42388 .15183 L F
.52189 .15533 m .52335 .15181 L .52509 .15411 L F
.52189 .15533 m .52015 .15303 L .52335 .15181 L F
.4763 .1551 m .47769 .15157 L .47947 .15393 L 0 .026 .126 r
F
.4763 .1551 m .47452 .15276 L .47769 .15157 L F
.62119 .15533 m .62282 .15179 L .62445 .15409 L 0 .027 .126 r
F
.62119 .15533 m .61956 .15305 L .62282 .15179 L F
.7449 .15399 m .74673 .15064 L .74823 .15282 L 0 .025 .123 r
F
.7449 .15399 m .7434 .1518 L .74673 .15064 L F
.37699 .15521 m .37822 .15166 L .3801 .154 L 0 .027 .126 r
F
.37699 .15521 m .3751 .1529 L .37822 .15166 L F
.62933 .15507 m .63097 .15153 L .63259 .15379 L F
.62933 .15507 m .62771 .15281 L .63097 .15153 L F
.58374 .15488 m .58531 .1515 L .58698 .15369 L F
.58374 .15488 m .58207 .1527 L .58531 .1515 L F
.68306 .15488 m .68478 .15126 L .68634 .15357 L 0 .026 .125 r
F
.68306 .15488 m .68149 .15257 L .68478 .15126 L F
.63747 .15471 m .63913 .15142 L .64074 .15358 L 0 .026 .126 r
F
.63747 .15471 m .63586 .15256 L .63913 .15142 L F
.4307 .15519 m .43201 .15177 L .43385 .15403 L 0 .027 .127 r
F
.4307 .15519 m .42887 .15295 L .43201 .15177 L F
.53002 .15525 m .5315 .15173 L .53322 .15405 L F
.53002 .15525 m .52829 .15291 L .5315 .15173 L F
.6912 .15458 m .69294 .15109 L .69449 .15337 L 0 .026 .125 r
F
.6912 .15458 m .68964 .15229 L .69294 .15109 L F
.75305 .15391 m .7549 .1505 L .75639 .15275 L 0 .025 .124 r
F
.75305 .15391 m .75156 .15165 L .7549 .1505 L F
.3851 .15513 m .38635 .15156 L .38822 .15392 L 0 .027 .126 r
F
.3851 .15513 m .38322 .15278 L .38635 .15156 L F
.48442 .15513 m .48583 .1515 L .4876 .15386 L F
.48442 .15513 m .48265 .15275 L .48583 .1515 L F
.59188 .15479 m .59346 .15124 L .59512 .15352 L F
.59188 .15479 m .59022 .1525 L .59346 .15124 L F
.64561 .15459 m .64728 .15121 L .64888 .15338 L F
.64561 .15459 m .64401 .15243 L .64728 .15121 L F
.49256 .15484 m .49397 .15135 L .49574 .15359 L F
.49256 .15484 m .49079 .1526 L .49397 .15135 L F
.43882 .15509 m .44015 .15165 L .44198 .15388 L 0 .027 .127 r
F
.43882 .15509 m .437 .15287 L .44015 .15165 L F
.69935 .15445 m .7011 .15092 L .70265 .15322 L 0 .026 .125 r
F
.69935 .15445 m .6978 .15216 L .7011 .15092 L F
.39322 .15495 m .39447 .15152 L .39635 .15376 L 0 .027 .127 r
F
.39322 .15495 m .39135 .15272 L .39447 .15152 L F
.53815 .1552 m .53964 .15171 L .54136 .15405 L 0 .028 .127 r
F
.53815 .1552 m .53643 .15284 L .53964 .15171 L F
.35575 .1543 m .35694 .15094 L .35886 .15316 L 0 .026 .125 r
F
.35575 .1543 m .35384 .15207 L .35694 .15094 L F
.50069 .15456 m .50212 .15116 L .50387 .15334 L 0 .027 .126 r
F
.50069 .15456 m .49893 .15238 L .50212 .15116 L F
.76122 .15389 m .76308 .15046 L .76456 .15274 L 0 .025 .124 r
F
.76122 .15389 m .75974 .15161 L .76308 .15046 L F
.60002 .15459 m .60161 .151 L .60327 .15333 L 0 .026 .126 r
F
.60002 .15459 m .59836 .15225 L .60161 .151 L F
.44695 .15481 m .44829 .15131 L .45011 .15353 L 0 .027 .126 r
F
.44695 .15481 m .44513 .1526 L .44829 .15131 L F
.65376 .15438 m .65544 .15092 L .65703 .15315 L 0 .026 .125 r
F
.65376 .15438 m .65216 .15215 L .65544 .15092 L F
.45508 .15444 m .45644 .15102 L .45825 .15317 L 0 .027 .126 r
F
.45508 .15444 m .45327 .15228 L .45644 .15102 L F
.40135 .15473 m .40261 .15133 L .40448 .15349 L 0 .027 .127 r
F
.40135 .15473 m .39948 .15255 L .40261 .15133 L F
.7075 .15428 m .70926 .15072 L .7108 .15303 L 0 .026 .125 r
F
.7075 .15428 m .70595 .15197 L .70926 .15072 L F
.46322 .15407 m .46458 .15075 L .46638 .1529 L F
.46322 .15407 m .46141 .15193 L .46458 .15075 L F
.50882 .15434 m .51026 .15094 L .51201 .15316 L 0 .027 .126 r
F
.50882 .15434 m .50707 .15214 L .51026 .15094 L F
.71564 .1539 m .71742 .15042 L .71894 .15259 L 0 .026 .125 r
F
.71564 .1539 m .71411 .15173 L .71742 .15042 L F
.6619 .15414 m .66359 .1507 L .66518 .15288 L F
.6619 .15414 m .66031 .15193 L .66359 .1507 L F
.72377 .1535 m .72558 .15018 L .7271 .15235 L 0 .025 .124 r
F
.72377 .1535 m .72226 .15135 L .72558 .15018 L F
.40947 .15442 m .41075 .15104 L .41261 .15318 L 0 .027 .126 r
F
.40947 .15442 m .40761 .15226 L .41075 .15104 L F
.36387 .1542 m .36507 .15087 L .36698 .15304 L F
.36387 .1542 m .36196 .15201 L .36507 .15087 L F
.60816 .15448 m .60977 .151 L .61142 .1533 L F
.60816 .15448 m .60652 .15217 L .60977 .151 L F
.67004 .15387 m .67176 .15053 L .67333 .15272 L 0 .026 .125 r
F
.67004 .15387 m .66846 .15169 L .67176 .15053 L F
.54629 .15523 m .54779 .15169 L .5495 .15402 L 0 .028 .128 r
F
.54629 .15523 m .54458 .1529 L .54779 .15169 L F
.47134 .15394 m .47272 .15053 L .47452 .15276 L 0 .026 .125 r
F
.47134 .15394 m .46955 .15173 L .47272 .15053 L F
.4176 .15419 m .41889 .15074 L .42074 .153 L 0 .027 .126 r
F
.4176 .15419 m .41575 .15194 L .41889 .15074 L F
.56256 .15442 m .56409 .15094 L .56578 .1531 L F
.56256 .15442 m .56087 .15227 L .56409 .15094 L F
.55443 .15488 m .55594 .15141 L .55764 .15359 L 0 .028 .127 r
F
.55443 .15488 m .55272 .15271 L .55594 .15141 L F
.5707 .15398 m .57224 .15065 L .57393 .15283 L 0 .026 .126 r
F
.5707 .15398 m .56901 .1518 L .57224 .15065 L F
.51695 .15426 m .51841 .15073 L .52015 .15303 L 0 .027 .126 r
F
.51695 .15426 m .51521 .15197 L .51841 .15073 L F
.73193 .15336 m .73374 .14993 L .73525 .15212 L 0 .025 .124 r
F
.73193 .15336 m .73042 .15119 L .73374 .14993 L F
.61631 .15432 m .61792 .15077 L .61956 .15305 L 0 .027 .126 r
F
.61631 .15432 m .61467 .15206 L .61792 .15077 L F
.37199 .15409 m .3732 .15069 L .3751 .1529 L F
.37199 .15409 m .37009 .15188 L .3732 .15069 L F
.74007 .15303 m .7419 .14961 L .7434 .1518 L 0 .025 .123 r
F
.74007 .15303 m .73857 .15085 L .7419 .14961 L F
.62445 .15409 m .62608 .1505 L .62771 .15281 L 0 .027 .126 r
F
.62445 .15409 m .62282 .15179 L .62608 .1505 L F
.57884 .15387 m .5804 .15051 L .58207 .1527 L F
.57884 .15387 m .57716 .15169 L .5804 .15051 L F
.6782 .15388 m .67991 .15026 L .68149 .15257 L 0 .026 .125 r
F
.6782 .15388 m .67662 .15157 L .67991 .15026 L F
.42572 .15411 m .42703 .15065 L .42887 .15295 L 0 .027 .126 r
F
.42572 .15411 m .42388 .15183 L .42703 .15065 L F
.52509 .15411 m .52656 .15062 L .52829 .15291 L F
.52509 .15411 m .52335 .15181 L .52656 .15062 L F
.47947 .15393 m .48087 .15037 L .48265 .15275 L F
.47947 .15393 m .47769 .15157 L .48087 .15037 L F
.74823 .15282 m .75007 .14947 L .75156 .15165 L 0 .025 .123 r
F
.74823 .15282 m .74673 .15064 L .75007 .14947 L F
.3801 .154 m .38134 .15043 L .38322 .15278 L 0 .027 .126 r
F
.3801 .154 m .37822 .15166 L .38134 .15043 L F
.63259 .15379 m .63424 .1503 L .63586 .15256 L 0 .026 .126 r
F
.63259 .15379 m .63097 .15153 L .63424 .1503 L F
.68634 .15357 m .68807 .14999 L .68964 .15229 L 0 .026 .125 r
F
.68634 .15357 m .68478 .15126 L .68807 .14999 L F
.58698 .15369 m .58855 .1503 L .59022 .1525 L 0 .027 .126 r
F
.58698 .15369 m .58531 .1515 L .58855 .1503 L F
.64074 .15358 m .6424 .15027 L .64401 .15243 L F
.64074 .15358 m .63913 .15142 L .6424 .15027 L F
.43385 .15403 m .43517 .15059 L .437 .15287 L 0 .027 .127 r
F
.43385 .15403 m .43201 .15177 L .43517 .15059 L F
.53322 .15405 m .53471 .15055 L .53643 .15284 L F
.53322 .15405 m .5315 .15173 L .53471 .15055 L F
.69449 .15337 m .69624 .14988 L .6978 .15216 L 0 .026 .125 r
F
.69449 .15337 m .69294 .15109 L .69624 .14988 L F
.4876 .15386 m .48901 .15024 L .49079 .1526 L 0 .027 .126 r
F
.4876 .15386 m .48583 .1515 L .48901 .15024 L F
.75639 .15275 m .75825 .14935 L .75974 .15161 L 0 .025 .124 r
F
.75639 .15275 m .7549 .1505 L .75825 .14935 L F
.38822 .15392 m .38947 .15034 L .39135 .15272 L 0 .027 .126 r
F
.38822 .15392 m .38635 .15156 L .38947 .15034 L F
.59512 .15352 m .5967 .14997 L .59836 .15225 L 0 .026 .125 r
F
.59512 .15352 m .59346 .15124 L .5967 .14997 L F
.49574 .15359 m .49716 .15015 L .49893 .15238 L 0 .027 .126 r
F
.49574 .15359 m .49397 .15135 L .49716 .15015 L F
.64888 .15338 m .65056 .14997 L .65216 .15215 L 0 .026 .126 r
F
.64888 .15338 m .64728 .15121 L .65056 .14997 L F
.44198 .15388 m .44331 .15037 L .44513 .1526 L 0 .027 .127 r
F
.44198 .15388 m .44015 .15165 L .44331 .15037 L F
.70265 .15322 m .70441 .14967 L .70595 .15197 L 0 .026 .125 r
F
.70265 .15322 m .7011 .15092 L .70441 .14967 L F
.45011 .15353 m .45146 .15007 L .45327 .15228 L 0 .027 .126 r
F
.45011 .15353 m .44829 .15131 L .45146 .15007 L F
.39635 .15376 m .3976 .15031 L .39948 .15255 L 0 .027 .127 r
F
.39635 .15376 m .39447 .15152 L .3976 .15031 L F
.60327 .15333 m .60486 .14985 L .60652 .15217 L 0 .026 .126 r
F
.60327 .15333 m .60161 .151 L .60486 .14985 L F
.50387 .15334 m .50531 .14994 L .50707 .15214 L 0 .027 .126 r
F
.50387 .15334 m .50212 .15116 L .50531 .14994 L F
.54136 .15405 m .54286 .15057 L .54458 .1529 L 0 .028 .127 r
F
.54136 .15405 m .53964 .15171 L .54286 .15057 L F
.65703 .15315 m .65872 .14972 L .66031 .15193 L 0 .026 .125 r
F
.65703 .15315 m .65544 .15092 L .65872 .14972 L F
.35886 .15316 m .36004 .14981 L .36196 .15201 L 0 .026 .126 r
F
.35886 .15316 m .35694 .15094 L .36004 .14981 L F
.45825 .15317 m .45961 .14979 L .46141 .15193 L F
.45825 .15317 m .45644 .15102 L .45961 .14979 L F
.7108 .15303 m .71257 .14942 L .71411 .15173 L 0 .026 .125 r
F
.7108 .15303 m .70926 .15072 L .71257 .14942 L F
.40448 .15349 m .40575 .15011 L .40761 .15226 L 0 .027 .126 r
F
.40448 .15349 m .40261 .15133 L .40575 .15011 L F
.71894 .15259 m .72074 .14918 L .72226 .15135 L 0 .025 .124 r
F
.71894 .15259 m .71742 .15042 L .72074 .14918 L F
.66518 .15288 m .66688 .14951 L .66846 .15169 L 0 .026 .125 r
F
.66518 .15288 m .66359 .1507 L .66688 .14951 L F
.46638 .1529 m .46775 .14957 L .46955 .15173 L F
.46638 .1529 m .46458 .15075 L .46775 .14957 L F
.51201 .15316 m .51346 .14972 L .51521 .15197 L 0 .027 .126 r
F
.51201 .15316 m .51026 .15094 L .51346 .14972 L F
.41261 .15318 m .41389 .14981 L .41575 .15194 L F
.41261 .15318 m .41075 .15104 L .41389 .14981 L F
.7271 .15235 m .72891 .14901 L .73042 .15119 L 0 .025 .124 r
F
.7271 .15235 m .72558 .15018 L .72891 .14901 L F
.36698 .15304 m .36818 .14972 L .37009 .15188 L 0 .027 .126 r
F
.36698 .15304 m .36507 .15087 L .36818 .14972 L F
.61142 .1533 m .61303 .14975 L .61467 .15206 L F
.61142 .1533 m .60977 .151 L .61303 .14975 L F
.56578 .1531 m .56732 .14963 L .56901 .1518 L F
.56578 .1531 m .56409 .15094 L .56732 .14963 L F
.5495 .15402 m .55101 .15038 L .55272 .15271 L 0 .028 .128 r
F
.5495 .15402 m .54779 .15169 L .55101 .15038 L F
.55764 .15359 m .55917 .15008 L .56087 .15227 L 0 .028 .127 r
F
.55764 .15359 m .55594 .15141 L .55917 .15008 L F
.67333 .15272 m .67505 .14938 L .67662 .15157 L 0 .026 .125 r
F
.67333 .15272 m .67176 .15053 L .67505 .14938 L F
.47452 .15276 m .4759 .14932 L .47769 .15157 L F
.47452 .15276 m .47272 .15053 L .4759 .14932 L F
.42074 .153 m .42204 .14955 L .42388 .15183 L 0 .027 .126 r
F
.42074 .153 m .41889 .15074 L .42204 .14955 L F
.73525 .15212 m .73707 .14864 L .73857 .15085 L 0 .025 .124 r
F
.73525 .15212 m .73374 .14993 L .73707 .14864 L F
.52015 .15303 m .52161 .1495 L .52335 .15181 L 0 .027 .126 r
F
.52015 .15303 m .51841 .15073 L .52161 .1495 L F
.61956 .15305 m .62118 .14949 L .62282 .15179 L F
.61956 .15305 m .61792 .15077 L .62118 .14949 L F
.57393 .15283 m .57548 .1495 L .57716 .15169 L F
.57393 .15283 m .57224 .15065 L .57548 .1495 L F
.3751 .1529 m .37632 .14944 L .37822 .15166 L F
.3751 .1529 m .3732 .15069 L .37632 .14944 L F
.7434 .1518 m .74524 .14845 L .74673 .15064 L 0 .025 .123 r
F
.7434 .1518 m .7419 .14961 L .74524 .14845 L F
.68149 .15257 m .68321 .14894 L .68478 .15126 L 0 .026 .125 r
F
.68149 .15257 m .67991 .15026 L .68321 .14894 L F
.62771 .15281 m .62934 .14921 L .63097 .15153 L 0 .026 .126 r
F
.62771 .15281 m .62608 .1505 L .62934 .14921 L F
.52829 .15291 m .52977 .14946 L .5315 .15173 L 0 .027 .126 r
F
.52829 .15291 m .52656 .15062 L .52977 .14946 L F
.58207 .1527 m .58364 .1493 L .58531 .1515 L F
.58207 .1527 m .5804 .15051 L .58364 .1493 L F
.42887 .15295 m .43018 .14945 L .43201 .15177 L F
.42887 .15295 m .42703 .15065 L .43018 .14945 L F
.68964 .15229 m .69138 .14879 L .69294 .15109 L 0 .026 .125 r
F
.68964 .15229 m .68807 .14999 L .69138 .14879 L F
.48265 .15275 m .48405 .14913 L .48583 .1515 L 0 .026 .126 r
F
.48265 .15275 m .48087 .15037 L .48405 .14913 L F
.38322 .15278 m .38447 .14919 L .38635 .15156 L 0 .027 .126 r
F
.38322 .15278 m .38134 .15043 L .38447 .14919 L F
.75156 .15165 m .75342 .1483 L .7549 .1505 L 0 .025 .124 r
F
.75156 .15165 m .75007 .14947 L .75342 .1483 L F
.63586 .15256 m .63751 .14915 L .63913 .15142 L 0 .027 .126 r
F
.63586 .15256 m .63424 .1503 L .63751 .14915 L F
.59022 .1525 m .5918 .14905 L .59346 .15124 L F
.59022 .1525 m .58855 .1503 L .5918 .14905 L F
.49079 .1526 m .4922 .14902 L .49397 .15135 L F
.49079 .1526 m .48901 .15024 L .4922 .14902 L F
.6978 .15216 m .69955 .14864 L .7011 .15092 L 0 .026 .125 r
F
.6978 .15216 m .69624 .14988 L .69955 .14864 L F
.53643 .15284 m .53792 .14942 L .53964 .15171 L 0 .027 .127 r
F
.53643 .15284 m .53471 .15055 L .53792 .14942 L F
.437 .15287 m .43832 .14937 L .44015 .15165 L F
.437 .15287 m .43517 .15059 L .43832 .14937 L F
.64401 .15243 m .64568 .14904 L .64728 .15121 L 0 .027 .126 r
F
.64401 .15243 m .6424 .15027 L .64568 .14904 L F
.59836 .15225 m .59995 .14874 L .60161 .151 L 0 .026 .125 r
F
.59836 .15225 m .5967 .14997 L .59995 .14874 L F
.39135 .15272 m .3926 .14912 L .39447 .15152 L 0 .027 .126 r
F
.39135 .15272 m .38947 .15034 L .3926 .14912 L F
.75974 .15161 m .7616 .14819 L .76308 .15046 L 0 .025 .124 r
F
.75974 .15161 m .75825 .14935 L .7616 .14819 L F
.44513 .1526 m .44647 .1491 L .44829 .15131 L 0 .027 .126 r
F
.44513 .1526 m .44331 .15037 L .44647 .1491 L F
.65216 .15215 m .65384 .14874 L .65544 .15092 L 0 .026 .125 r
F
.65216 .15215 m .65056 .14997 L .65384 .14874 L F
.49893 .15238 m .50035 .14894 L .50212 .15116 L 0 .027 .126 r
F
.49893 .15238 m .49716 .15015 L .50035 .14894 L F
.70595 .15197 m .70772 .14841 L .70926 .15072 L 0 .026 .125 r
F
.70595 .15197 m .70441 .14967 L .70772 .14841 L F
.45327 .15228 m .45462 .14882 L .45644 .15102 L 0 .027 .126 r
F
.45327 .15228 m .45146 .15007 L .45462 .14882 L F
.39948 .15255 m .40074 .14911 L .40261 .15133 L 0 .027 .127 r
F
.39948 .15255 m .3976 .15031 L .40074 .14911 L F
.50707 .15214 m .50851 .14871 L .51026 .15094 L 0 .027 .126 r
F
.50707 .15214 m .50531 .14994 L .50851 .14871 L F
.66031 .15193 m .66201 .14851 L .66359 .1507 L 0 .026 .125 r
F
.66031 .15193 m .65872 .14972 L .66201 .14851 L F
.46141 .15193 m .46278 .14859 L .46458 .15075 L F
.46141 .15193 m .45961 .14979 L .46278 .14859 L F
.60652 .15217 m .60812 .1487 L .60977 .151 L 0 .027 .126 r
F
.60652 .15217 m .60486 .14985 L .60812 .1487 L F
.71411 .15173 m .71588 .14812 L .71742 .15042 L 0 .026 .125 r
F
.71411 .15173 m .71257 .14942 L .71588 .14812 L F
.54458 .1529 m .54608 .14936 L .54779 .15169 L 0 .028 .128 r
F
.54458 .1529 m .54286 .15057 L .54608 .14936 L F
.36196 .15201 m .36315 .14869 L .36507 .15087 L 0 .027 .126 r
F
.36196 .15201 m .36004 .14981 L .36315 .14869 L F
.72226 .15135 m .72406 .14799 L .72558 .15018 L 0 .025 .124 r
F
.72226 .15135 m .72074 .14918 L .72406 .14799 L F
.40761 .15226 m .40889 .14891 L .41075 .15104 L 0 .027 .126 r
F
.40761 .15226 m .40575 .15011 L .40889 .14891 L F
.66846 .15169 m .67018 .14836 L .67176 .15053 L 0 .026 .125 r
F
.66846 .15169 m .66688 .14951 L .67018 .14836 L F
.41575 .15194 m .41704 .1486 L .41889 .15074 L 0 .027 .126 r
F
.41575 .15194 m .41389 .14981 L .41704 .1486 L F
.46955 .15173 m .47093 .14835 L .47272 .15053 L 0 .026 .125 r
F
.46955 .15173 m .46775 .14957 L .47093 .14835 L F
.51521 .15197 m .51666 .14847 L .51841 .15073 L 0 .027 .126 r
F
.51521 .15197 m .51346 .14972 L .51666 .14847 L F
.56901 .1518 m .57056 .14846 L .57224 .15065 L F
.56901 .1518 m .56732 .14963 L .57056 .14846 L F
.55272 .15271 m .55424 .14907 L .55594 .15141 L 0 .028 .127 r
F
.55272 .15271 m .55101 .15038 L .55424 .14907 L F
.56087 .15227 m .5624 .14875 L .56409 .15094 L 0 .027 .126 r
F
.56087 .15227 m .55917 .15008 L .5624 .14875 L F
.61467 .15206 m .61628 .14846 L .61792 .15077 L F
.61467 .15206 m .61303 .14975 L .61628 .14846 L F
.73042 .15119 m .73223 .14773 L .73374 .14993 L 0 .025 .124 r
F
.73042 .15119 m .72891 .14901 L .73223 .14773 L F
.37009 .15188 m .37129 .14854 L .3732 .15069 L 0 .027 .126 r
F
.37009 .15188 m .36818 .14972 L .37129 .14854 L F
.73857 .15085 m .7404 .14739 L .7419 .14961 L 0 .025 .124 r
F
.73857 .15085 m .73707 .14864 L .7404 .14739 L F
.62282 .15179 m .62445 .14819 L .62608 .1505 L 0 .026 .126 r
F
.62282 .15179 m .62118 .14949 L .62445 .14819 L F
.67662 .15157 m .67834 .14808 L .67991 .15026 L 0 .026 .125 r
F
.67662 .15157 m .67505 .14938 L .67834 .14808 L F
.47769 .15157 m .47908 .14811 L .48087 .15037 L F
.47769 .15157 m .4759 .14932 L .47908 .14811 L F
.52335 .15181 m .52482 .14832 L .52656 .15062 L 0 .027 .126 r
F
.52335 .15181 m .52161 .1495 L .52482 .14832 L F
.42388 .15183 m .42519 .14835 L .42703 .15065 L F
.42388 .15183 m .42204 .14955 L .42519 .14835 L F
.37822 .15166 m .37945 .14818 L .38134 .15043 L F
.37822 .15166 m .37632 .14944 L .37945 .14818 L F
.57716 .15169 m .57872 .1483 L .5804 .15051 L F
.57716 .15169 m .57548 .1495 L .57872 .1483 L F
.68478 .15126 m .68651 .14767 L .68807 .14999 L 0 .026 .125 r
F
.68478 .15126 m .68321 .14894 L .68651 .14767 L F
.63097 .15153 m .63261 .14798 L .63424 .1503 L F
.63097 .15153 m .62934 .14921 L .63261 .14798 L F
.74673 .15064 m .74858 .14728 L .75007 .14947 L 0 .025 .124 r
F
.74673 .15064 m .74524 .14845 L .74858 .14728 L F
.58531 .1515 m .58688 .14809 L .58855 .1503 L 0 .027 .126 r
F
.58531 .1515 m .58364 .1493 L .58688 .14809 L F
.48583 .1515 m .48724 .14789 L .48901 .15024 L 0 .026 .125 r
F
.48583 .1515 m .48405 .14913 L .48724 .14789 L F
.5315 .15173 m .53298 .1483 L .53471 .15055 L 0 .027 .126 r
F
.5315 .15173 m .52977 .14946 L .53298 .1483 L F
.69294 .15109 m .69468 .1476 L .69624 .14988 L 0 .026 .125 r
F
.69294 .15109 m .69138 .14879 L .69468 .1476 L F
.43201 .15177 m .43333 .14825 L .43517 .15059 L 0 .027 .126 r
F
.43201 .15177 m .43018 .14945 L .43333 .14825 L F
.38635 .15156 m .3876 .14795 L .38947 .15034 L F
.38635 .15156 m .38447 .14919 L .3876 .14795 L F
.7549 .1505 m .75676 .14713 L .75825 .14935 L 0 .025 .124 r
F
.7549 .1505 m .75342 .1483 L .75676 .14713 L F
.63913 .15142 m .64079 .14799 L .6424 .15027 L 0 .027 .126 r
F
.63913 .15142 m .63751 .14915 L .64079 .14799 L F
.59346 .15124 m .59504 .1478 L .5967 .14997 L 0 .026 .125 r
F
.59346 .15124 m .5918 .14905 L .59504 .1478 L F
.49397 .15135 m .49539 .14783 L .49716 .15015 L 0 .027 .126 r
F
.49397 .15135 m .4922 .14902 L .49539 .14783 L F
.7011 .15092 m .70286 .14738 L .70441 .14967 L 0 .026 .125 r
F
.7011 .15092 m .69955 .14864 L .70286 .14738 L F
.44015 .15165 m .44148 .14811 L .44331 .15037 L 0 .027 .127 r
F
.44015 .15165 m .43832 .14937 L .44148 .14811 L F
.64728 .15121 m .64896 .14779 L .65056 .14997 L 0 .027 .126 r
F
.64728 .15121 m .64568 .14904 L .64896 .14779 L F
.60161 .151 m .60321 .14759 L .60486 .14985 L 0 .026 .125 r
F
.60161 .151 m .59995 .14874 L .60321 .14759 L F
.53964 .15171 m .54114 .14829 L .54286 .15057 L 0 .028 .127 r
F
.53964 .15171 m .53792 .14942 L .54114 .14829 L F
.39447 .15152 m .39574 .14793 L .3976 .15031 L 0 .027 .126 r
F
.39447 .15152 m .3926 .14912 L .39574 .14793 L F
.44829 .15131 m .44964 .14785 L .45146 .15007 L F
.44829 .15131 m .44647 .1491 L .44964 .14785 L F
.65544 .15092 m .65713 .14753 L .65872 .14972 L 0 .026 .125 r
F
.65544 .15092 m .65384 .14874 L .65713 .14753 L F
.50212 .15116 m .50355 .1477 L .50531 .14994 L 0 .027 .126 r
F
.50212 .15116 m .50035 .14894 L .50355 .1477 L F
.70926 .15072 m .71103 .14711 L .71257 .14942 L 0 .026 .125 r
F
.70926 .15072 m .70772 .14841 L .71103 .14711 L F
.45644 .15102 m .4578 .14758 L .45961 .14979 L 0 .027 .126 r
F
.45644 .15102 m .45462 .14882 L .4578 .14758 L F
.40261 .15133 m .40388 .14791 L .40575 .15011 L 0 .027 .127 r
F
.40261 .15133 m .40074 .14911 L .40388 .14791 L F
.71742 .15042 m .7192 .14688 L .72074 .14918 L 0 .025 .124 r
F
.71742 .15042 m .71588 .14812 L .7192 .14688 L F
.66359 .1507 m .6653 .14733 L .66688 .14951 L 0 .026 .125 r
F
.66359 .1507 m .66201 .14851 L .6653 .14733 L F
.51026 .15094 m .51171 .14748 L .51346 .14972 L 0 .027 .126 r
F
.51026 .15094 m .50851 .14871 L .51171 .14748 L F
.46458 .15075 m .46595 .14739 L .46775 .14957 L 0 .026 .126 r
F
.46458 .15075 m .46278 .14859 L .46595 .14739 L F
.60977 .151 m .61138 .14745 L .61303 .14975 L 0 .027 .126 r
F
.60977 .151 m .60812 .1487 L .61138 .14745 L F
.54779 .15169 m .5493 .14805 L .55101 .15038 L 0 .028 .127 r
F
.54779 .15169 m .54608 .14936 L .5493 .14805 L F
.41075 .15104 m .41203 .1477 L .41389 .14981 L 0 .027 .126 r
F
.41075 .15104 m .40889 .14891 L .41203 .1477 L F
.72558 .15018 m .72739 .14681 L .72891 .14901 L 0 .026 .124 r
F
.72558 .15018 m .72406 .14799 L .72739 .14681 L F
.36507 .15087 m .36627 .14756 L .36818 .14972 L 0 .027 .126 r
F
.36507 .15087 m .36315 .14869 L .36627 .14756 L F
.56409 .15094 m .56563 .14743 L .56732 .14963 L F
.56409 .15094 m .5624 .14875 L .56563 .14743 L F
.55594 .15141 m .55746 .14776 L .55917 .15008 L 0 .027 .127 r
F
.55594 .15141 m .55424 .14907 L .55746 .14776 L F
.51841 .15073 m .51987 .14721 L .52161 .1495 L 0 .026 .126 r
F
.51841 .15073 m .51666 .14847 L .51987 .14721 L F
.41889 .15074 m .42019 .14738 L .42204 .14955 L 0 .027 .126 r
F
.41889 .15074 m .41704 .1486 L .42019 .14738 L F
.47272 .15053 m .47411 .14712 L .4759 .14932 L 0 .026 .125 r
F
.47272 .15053 m .47093 .14835 L .47411 .14712 L F
.67176 .15053 m .67348 .14721 L .67505 .14938 L F
.67176 .15053 m .67018 .14836 L .67348 .14721 L F
.61792 .15077 m .61955 .14717 L .62118 .14949 L 0 .026 .126 r
F
.61792 .15077 m .61628 .14846 L .61955 .14717 L F
.73374 .14993 m .73556 .14642 L .73707 .14864 L 0 .025 .124 r
F
.73374 .14993 m .73223 .14773 L .73556 .14642 L F
.57224 .15065 m .57379 .1473 L .57548 .1495 L 0 .027 .126 r
F
.57224 .15065 m .57056 .14846 L .57379 .1473 L F
.3732 .15069 m .37442 .14727 L .37632 .14944 L F
.3732 .15069 m .37129 .14854 L .37442 .14727 L F
.67991 .15026 m .68164 .14676 L .68321 .14894 L 0 .026 .125 r
F
.67991 .15026 m .67834 .14808 L .68164 .14676 L F
.62608 .1505 m .62771 .14689 L .62934 .14921 L F
.62608 .1505 m .62445 .14819 L .62771 .14689 L F
.7419 .14961 m .74374 .14621 L .74524 .14845 L 0 .025 .124 r
F
.7419 .14961 m .7404 .14739 L .74374 .14621 L F
.48087 .15037 m .48227 .14688 L .48405 .14913 L 0 .026 .125 r
F
.48087 .15037 m .47908 .14811 L .48227 .14688 L F
.52656 .15062 m .52803 .14719 L .52977 .14946 L 0 .027 .126 r
F
.52656 .15062 m .52482 .14832 L .52803 .14719 L F
.42703 .15065 m .42834 .14713 L .43018 .14945 L F
.42703 .15065 m .42519 .14835 L .42834 .14713 L F
.38134 .15043 m .38258 .14693 L .38447 .14919 L 0 .026 .125 r
F
.38134 .15043 m .37945 .14818 L .38258 .14693 L F
.68807 .14999 m .68981 .14649 L .69138 .14879 L 0 .026 .124 r
F
.68807 .14999 m .68651 .14767 L .68981 .14649 L F
.5804 .15051 m .58196 .14707 L .58364 .1493 L 0 .027 .126 r
F
.5804 .15051 m .57872 .1483 L .58196 .14707 L F
.63424 .1503 m .63589 .14681 L .63751 .14915 L 0 .026 .125 r
F
.63424 .1503 m .63261 .14798 L .63589 .14681 L F
.75007 .14947 m .75192 .1461 L .75342 .1483 L 0 .025 .124 r
F
.75007 .14947 m .74858 .14728 L .75192 .1461 L F
.48901 .15024 m .49043 .14667 L .4922 .14902 L 0 .026 .125 r
F
.48901 .15024 m .48724 .14789 L .49043 .14667 L F
.58855 .1503 m .59013 .14686 L .5918 .14905 L 0 .027 .126 r
F
.58855 .1503 m .58688 .14809 L .59013 .14686 L F
.53471 .15055 m .5362 .14718 L .53792 .14942 L 0 .027 .127 r
F
.53471 .15055 m .53298 .1483 L .5362 .14718 L F
.69624 .14988 m .69799 .14636 L .69955 .14864 L 0 .026 .125 r
F
.69624 .14988 m .69468 .1476 L .69799 .14636 L F
.38947 .15034 m .39073 .14671 L .3926 .14912 L 0 .027 .126 r
F
.38947 .15034 m .3876 .14795 L .39073 .14671 L F
.43517 .15059 m .43649 .14703 L .43832 .14937 L F
.43517 .15059 m .43333 .14825 L .43649 .14703 L F
.5967 .14997 m .5983 .14658 L .59995 .14874 L 0 .026 .125 r
F
.5967 .14997 m .59504 .1478 L .5983 .14658 L F
.75825 .14935 m .76011 .14595 L .7616 .14819 L 0 .025 .124 r
F
.75825 .14935 m .75676 .14713 L .76011 .14595 L F
.6424 .15027 m .64407 .14675 L .64568 .14904 L 0 .027 .126 r
F
.6424 .15027 m .64079 .14799 L .64407 .14675 L F
.70441 .14967 m .70617 .14612 L .70772 .14841 L 0 .026 .125 r
F
.70441 .14967 m .70286 .14738 L .70617 .14612 L F
.44331 .15037 m .44465 .14685 L .44647 .1491 L 0 .027 .126 r
F
.44331 .15037 m .44148 .14811 L .44465 .14685 L F
.49716 .15015 m .49859 .14663 L .50035 .14894 L F
.49716 .15015 m .49539 .14783 L .49859 .14663 L F
.65056 .14997 m .65224 .14654 L .65384 .14874 L F
.65056 .14997 m .64896 .14779 L .65224 .14654 L F
.45146 .15007 m .45281 .14661 L .45462 .14882 L F
.45146 .15007 m .44964 .14785 L .45281 .14661 L F
.60486 .14985 m .60647 .14644 L .60812 .1487 L 0 .026 .126 r
F
.60486 .14985 m .60321 .14759 L .60647 .14644 L F
.3976 .15031 m .39887 .14674 L .40074 .14911 L 0 .027 .126 r
F
.3976 .15031 m .39574 .14793 L .39887 .14674 L F
.71257 .14942 m .71434 .14582 L .71588 .14812 L 0 .025 .124 r
F
.71257 .14942 m .71103 .14711 L .71434 .14582 L F
.54286 .15057 m .54436 .14709 L .54608 .14936 L 0 .028 .127 r
F
.54286 .15057 m .54114 .14829 L .54436 .14709 L F
.50531 .14994 m .50675 .14645 L .50851 .14871 L 0 .027 .126 r
F
.50531 .14994 m .50355 .1477 L .50675 .14645 L F
.65872 .14972 m .66042 .14632 L .66201 .14851 L 0 .026 .125 r
F
.65872 .14972 m .65713 .14753 L .66042 .14632 L F
.45961 .14979 m .46097 .14636 L .46278 .14859 L 0 .027 .126 r
F
.45961 .14979 m .4578 .14758 L .46097 .14636 L F
.72074 .14918 m .72253 .1457 L .72406 .14799 L 0 .025 .124 r
F
.72074 .14918 m .7192 .14688 L .72253 .1457 L F
.40575 .15011 m .40702 .14672 L .40889 .14891 L 0 .027 .127 r
F
.40575 .15011 m .40388 .14791 L .40702 .14672 L F
.55101 .15038 m .55253 .14673 L .55424 .14907 L F
.55101 .15038 m .5493 .14805 L .55253 .14673 L F
.51346 .14972 m .51491 .1462 L .51666 .14847 L 0 .026 .126 r
F
.51346 .14972 m .51171 .14748 L .51491 .1462 L F
.66688 .14951 m .6686 .14617 L .67018 .14836 L 0 .026 .125 r
F
.66688 .14951 m .6653 .14733 L .6686 .14617 L F
.61303 .14975 m .61464 .14615 L .61628 .14846 L 0 .026 .126 r
F
.61303 .14975 m .61138 .14745 L .61464 .14615 L F
.46775 .14957 m .46913 .14616 L .47093 .14835 L F
.46775 .14957 m .46595 .14739 L .46913 .14616 L F
.41389 .14981 m .41518 .14647 L .41704 .1486 L 0 .027 .126 r
F
.41389 .14981 m .41203 .1477 L .41518 .14647 L F
.55917 .15008 m .5607 .14644 L .5624 .14875 L F
.55917 .15008 m .55746 .14776 L .5607 .14644 L F
.56732 .14963 m .56886 .14625 L .57056 .14846 L F
.56732 .14963 m .56563 .14743 L .56886 .14625 L F
.72891 .14901 m .73071 .14551 L .73223 .14773 L 0 .025 .124 r
F
.72891 .14901 m .72739 .14681 L .73071 .14551 L F
.62118 .14949 m .62281 .1459 L .62445 .14819 L 0 .026 .125 r
F
.62118 .14949 m .61955 .14717 L .62281 .1459 L F
.36818 .14972 m .36938 .14639 L .37129 .14854 L 0 .027 .126 r
F
.36818 .14972 m .36627 .14756 L .36938 .14639 L F
.52161 .1495 m .52308 .14602 L .52482 .14832 L 0 .026 .126 r
F
.52161 .1495 m .51987 .14721 L .52308 .14602 L F
.4759 .14932 m .47729 .14589 L .47908 .14811 L 0 .026 .125 r
F
.4759 .14932 m .47411 .14712 L .47729 .14589 L F
.42204 .14955 m .42334 .14616 L .42519 .14835 L 0 .027 .126 r
F
.42204 .14955 m .42019 .14738 L .42334 .14616 L F
.73707 .14864 m .73889 .14515 L .7404 .14739 L 0 .025 .124 r
F
.73707 .14864 m .73556 .14642 L .73889 .14515 L F
.67505 .14938 m .67677 .1459 L .67834 .14808 L 0 .026 .125 r
F
.67505 .14938 m .67348 .14721 L .67677 .1459 L F
.68321 .14894 m .68494 .14549 L .68651 .14767 L 0 .026 .124 r
F
.68321 .14894 m .68164 .14676 L .68494 .14549 L F
.37632 .14944 m .37755 .14599 L .37945 .14818 L 0 .027 .126 r
F
.37632 .14944 m .37442 .14727 L .37755 .14599 L F
.62934 .14921 m .63099 .14565 L .63261 .14798 L 0 .026 .125 r
F
.62934 .14921 m .62771 .14689 L .63099 .14565 L F
.57548 .1495 m .57704 .14609 L .57872 .1483 L 0 .027 .126 r
F
.57548 .1495 m .57379 .1473 L .57704 .14609 L F
.74524 .14845 m .74708 .14504 L .74858 .14728 L 0 .025 .124 r
F
.74524 .14845 m .74374 .14621 L .74708 .14504 L F
.48405 .14913 m .48546 .14565 L .48724 .14789 L 0 .026 .125 r
F
.48405 .14913 m .48227 .14688 L .48546 .14565 L F
.38447 .14919 m .38571 .14567 L .3876 .14795 L F
.38447 .14919 m .38258 .14693 L .38571 .14567 L F
.43018 .14945 m .4315 .1459 L .43333 .14825 L 0 .027 .126 r
F
.43018 .14945 m .42834 .14713 L .4315 .1459 L F
.52977 .14946 m .53125 .14605 L .53298 .1483 L F
.52977 .14946 m .52803 .14719 L .53125 .14605 L F
.69138 .14879 m .69312 .14531 L .69468 .1476 L 0 .026 .125 r
F
.69138 .14879 m .68981 .14649 L .69312 .14531 L F
.58364 .1493 m .58521 .14585 L .58688 .14809 L 0 .027 .126 r
F
.58364 .1493 m .58196 .14707 L .58521 .14585 L F
.63751 .14915 m .63917 .14565 L .64079 .14799 L 0 .026 .126 r
F
.63751 .14915 m .63589 .14681 L .63917 .14565 L F
.75342 .1483 m .75527 .1449 L .75676 .14713 L 0 .025 .124 r
F
.75342 .1483 m .75192 .1461 L .75527 .1449 L F
.4922 .14902 m .49362 .1455 L .49539 .14783 L 0 .026 .125 r
F
.4922 .14902 m .49043 .14667 L .49362 .1455 L F
.5918 .14905 m .59338 .14562 L .59504 .1478 L 0 .027 .126 r
F
.5918 .14905 m .59013 .14686 L .59338 .14562 L F
.69955 .14864 m .70131 .1451 L .70286 .14738 L 0 .026 .125 r
F
.69955 .14864 m .69799 .14636 L .70131 .1451 L F
.3926 .14912 m .39386 .14554 L .39574 .14793 L 0 .027 .126 r
F
.3926 .14912 m .39073 .14671 L .39386 .14554 L F
.43832 .14937 m .43966 .1458 L .44148 .14811 L F
.43832 .14937 m .43649 .14703 L .43966 .1458 L F
.53792 .14942 m .53942 .14605 L .54114 .14829 L 0 .027 .127 r
F
.53792 .14942 m .5362 .14718 L .53942 .14605 L F
.59995 .14874 m .60156 .14543 L .60321 .14759 L 0 .026 .125 r
F
.59995 .14874 m .5983 .14658 L .60156 .14543 L F
.64568 .14904 m .64735 .14549 L .64896 .14779 L 0 .027 .126 r
F
.64568 .14904 m .64407 .14675 L .64735 .14549 L F
.70772 .14841 m .70949 .14483 L .71103 .14711 L 0 .025 .124 r
F
.70772 .14841 m .70617 .14612 L .70949 .14483 L F
.44647 .1491 m .44782 .14562 L .44964 .14785 L 0 .027 .126 r
F
.44647 .1491 m .44465 .14685 L .44782 .14562 L F
.50035 .14894 m .50179 .14538 L .50355 .1477 L F
.50035 .14894 m .49859 .14663 L .50179 .14538 L F
.65384 .14874 m .65553 .14533 L .65713 .14753 L 0 .026 .126 r
F
.65384 .14874 m .65224 .14654 L .65553 .14533 L F
.71588 .14812 m .71767 .14458 L .7192 .14688 L 0 .025 .124 r
F
.71588 .14812 m .71434 .14582 L .71767 .14458 L F
.45462 .14882 m .45598 .14537 L .4578 .14758 L 0 .027 .126 r
F
.45462 .14882 m .45281 .14661 L .45598 .14537 L F
.40074 .14911 m .40201 .14555 L .40388 .14791 L F
.40074 .14911 m .39887 .14674 L .40201 .14555 L F
.54608 .14936 m .54759 .14578 L .5493 .14805 L 0 .028 .127 r
F
.54608 .14936 m .54436 .14709 L .54759 .14578 L F
.60812 .1487 m .60973 .14519 L .61138 .14745 L 0 .026 .126 r
F
.60812 .1487 m .60647 .14644 L .60973 .14519 L F
.50851 .14871 m .50995 .14519 L .51171 .14748 L 0 .027 .126 r
F
.50851 .14871 m .50675 .14645 L .50995 .14519 L F
.66201 .14851 m .66371 .14513 L .6653 .14733 L 0 .026 .125 r
F
.66201 .14851 m .66042 .14632 L .66371 .14513 L F
.46278 .14859 m .46415 .14514 L .46595 .14739 L 0 .027 .126 r
F
.46278 .14859 m .46097 .14636 L .46415 .14514 L F
.55424 .14907 m .55576 .14543 L .55746 .14776 L F
.55424 .14907 m .55253 .14673 L .55576 .14543 L F
.72406 .14799 m .72586 .14451 L .72739 .14681 L 0 .026 .124 r
F
.72406 .14799 m .72253 .1457 L .72586 .14451 L F
.40889 .14891 m .41016 .14553 L .41203 .1477 L 0 .027 .127 r
F
.40889 .14891 m .40702 .14672 L .41016 .14553 L F
.61628 .14846 m .6179 .14486 L .61955 .14717 L 0 .026 .125 r
F
.61628 .14846 m .61464 .14615 L .6179 .14486 L F
.51666 .14847 m .51812 .14492 L .51987 .14721 L F
.51666 .14847 m .51491 .1462 L .51812 .14492 L F
.5624 .14875 m .56393 .14515 L .56563 .14743 L 0 .027 .126 r
F
.5624 .14875 m .5607 .14644 L .56393 .14515 L F
.47093 .14835 m .47231 .14491 L .47411 .14712 L 0 .026 .125 r
F
.47093 .14835 m .46913 .14616 L .47231 .14491 L F
.67018 .14836 m .6719 .14501 L .67348 .14721 L 0 .027 .126 r
F
.67018 .14836 m .6686 .14617 L .6719 .14501 L F
.41704 .1486 m .41833 .14523 L .42019 .14738 L F
.41704 .1486 m .41518 .14647 L .41833 .14523 L F
.73223 .14773 m .73404 .14419 L .73556 .14642 L 0 .025 .124 r
F
.73223 .14773 m .73071 .14551 L .73404 .14419 L F
.62445 .14819 m .62608 .14462 L .62771 .14689 L 0 .026 .125 r
F
.62445 .14819 m .62281 .1459 L .62608 .14462 L F
.57056 .14846 m .57211 .14507 L .57379 .1473 L 0 .027 .126 r
F
.57056 .14846 m .56886 .14625 L .57211 .14507 L F
.7404 .14739 m .74223 .14396 L .74374 .14621 L 0 .025 .123 r
F
.7404 .14739 m .73889 .14515 L .74223 .14396 L F
.67834 .14808 m .68007 .14459 L .68164 .14676 L 0 .026 .125 r
F
.67834 .14808 m .67677 .1459 L .68007 .14459 L F
.37129 .14854 m .37251 .1451 L .37442 .14727 L 0 .027 .126 r
F
.37129 .14854 m .36938 .14639 L .37251 .1451 L F
.52482 .14832 m .52629 .14489 L .52803 .14719 L F
.52482 .14832 m .52308 .14602 L .52629 .14489 L F
.47908 .14811 m .48048 .14468 L .48227 .14688 L 0 .026 .125 r
F
.47908 .14811 m .47729 .14589 L .48048 .14468 L F
.42519 .14835 m .42649 .14492 L .42834 .14713 L 0 .027 .126 r
F
.42519 .14835 m .42334 .14616 L .42649 .14492 L F
.68651 .14767 m .68825 .14431 L .68981 .14649 L 0 .026 .124 r
F
.68651 .14767 m .68494 .14549 L .68825 .14431 L F
.37945 .14818 m .38068 .14472 L .38258 .14693 L 0 .026 .125 r
F
.37945 .14818 m .37755 .14599 L .38068 .14472 L F
.63261 .14798 m .63426 .14448 L .63589 .14681 L F
.63261 .14798 m .63099 .14565 L .63426 .14448 L F
.57872 .1483 m .58028 .14483 L .58196 .14707 L 0 .027 .126 r
F
.57872 .1483 m .57704 .14609 L .58028 .14483 L F
.48724 .14789 m .48865 .14446 L .49043 .14667 L 0 .026 .125 r
F
.48724 .14789 m .48546 .14565 L .48865 .14446 L F
.3876 .14795 m .38885 .14441 L .39073 .14671 L F
.3876 .14795 m .38571 .14567 L .38885 .14441 L F
.74858 .14728 m .75043 .14384 L .75192 .1461 L 0 .025 .124 r
F
.74858 .14728 m .74708 .14504 L .75043 .14384 L F
.43333 .14825 m .43466 .14469 L .43649 .14703 L 0 .027 .126 r
F
.43333 .14825 m .4315 .1459 L .43466 .14469 L F
.69468 .1476 m .69644 .14408 L .69799 .14636 L 0 .026 .124 r
F
.69468 .1476 m .69312 .14531 L .69644 .14408 L F
.53298 .1483 m .53447 .14493 L .5362 .14718 L 0 .027 .127 r
F
.53298 .1483 m .53125 .14605 L .53447 .14493 L F
.58688 .14809 m .58846 .14461 L .59013 .14686 L 0 .027 .126 r
F
.58688 .14809 m .58521 .14585 L .58846 .14461 L F
.64079 .14799 m .64245 .1444 L .64407 .14675 L 0 .026 .126 r
F
.64079 .14799 m .63917 .14565 L .64245 .1444 L F
.59504 .1478 m .59664 .14441 L .5983 .14658 L F
.59504 .1478 m .59338 .14562 L .59664 .14441 L F
.75676 .14713 m .75862 .14371 L .76011 .14595 L 0 .025 .124 r
F
.75676 .14713 m .75527 .1449 L .75862 .14371 L F
.49539 .14783 m .49682 .14432 L .49859 .14663 L 0 .026 .125 r
F
.49539 .14783 m .49362 .1455 L .49682 .14432 L F
.70286 .14738 m .70462 .14384 L .70617 .14612 L 0 .026 .124 r
F
.70286 .14738 m .70131 .1451 L .70462 .14384 L F
.44148 .14811 m .44282 .14456 L .44465 .14685 L 0 .027 .126 r
F
.44148 .14811 m .43966 .1458 L .44282 .14456 L F
.39574 .14793 m .397 .14436 L .39887 .14674 L F
.39574 .14793 m .39386 .14554 L .397 .14436 L F
.64896 .14779 m .65063 .14423 L .65224 .14654 L 0 .026 .126 r
F
.64896 .14779 m .64735 .14549 L .65063 .14423 L F
.71103 .14711 m .7128 .14355 L .71434 .14582 L 0 .025 .124 r
F
.71103 .14711 m .70949 .14483 L .7128 .14355 L F
.60321 .14759 m .60482 .14427 L .60647 .14644 L 0 .027 .126 r
F
.60321 .14759 m .60156 .14543 L .60482 .14427 L F
.54114 .14829 m .54264 .14486 L .54436 .14709 L 0 .028 .127 r
F
.54114 .14829 m .53942 .14605 L .54264 .14486 L F
.44964 .14785 m .45099 .14439 L .45281 .14661 L 0 .027 .126 r
F
.44964 .14785 m .44782 .14562 L .45099 .14439 L F
.50355 .1477 m .50499 .14411 L .50675 .14645 L 0 .026 .126 r
F
.50355 .1477 m .50179 .14538 L .50499 .14411 L F
.65713 .14753 m .65882 .14413 L .66042 .14632 L F
.65713 .14753 m .65553 .14533 L .65882 .14413 L F
.7192 .14688 m .721 .14339 L .72253 .1457 L 0 .025 .124 r
F
.7192 .14688 m .71767 .14458 L .721 .14339 L F
.4578 .14758 m .45916 .14413 L .46097 .14636 L 0 .027 .126 r
F
.4578 .14758 m .45598 .14537 L .45916 .14413 L F
.5493 .14805 m .55082 .14447 L .55253 .14673 L 0 .027 .127 r
F
.5493 .14805 m .54759 .14578 L .55082 .14447 L F
.61138 .14745 m .61299 .14389 L .61464 .14615 L 0 .026 .125 r
F
.61138 .14745 m .60973 .14519 L .61299 .14389 L F
.40388 .14791 m .40515 .14438 L .40702 .14672 L 0 .027 .126 r
F
.40388 .14791 m .40201 .14555 L .40515 .14438 L F
.51171 .14748 m .51316 .1439 L .51491 .1462 L 0 .026 .125 r
F
.51171 .14748 m .50995 .14519 L .51316 .1439 L F
.55746 .14776 m .55899 .14414 L .5607 .14644 L 0 .027 .126 r
F
.55746 .14776 m .55576 .14543 L .55899 .14414 L F
.6653 .14733 m .66701 .14395 L .6686 .14617 L 0 .026 .126 r
F
.6653 .14733 m .66371 .14513 L .66701 .14395 L F
.46595 .14739 m .46733 .14389 L .46913 .14616 L F
.46595 .14739 m .46415 .14514 L .46733 .14389 L F
.61955 .14717 m .62117 .1436 L .62281 .1459 L 0 .026 .125 r
F
.61955 .14717 m .6179 .14486 L .62117 .1436 L F
.56563 .14743 m .56717 .14396 L .56886 .14625 L 0 .027 .126 r
F
.56563 .14743 m .56393 .14515 L .56717 .14396 L F
.51987 .14721 m .52134 .14372 L .52308 .14602 L 0 .026 .125 r
F
.51987 .14721 m .51812 .14492 L .52134 .14372 L F
.41203 .1477 m .41331 .14429 L .41518 .14647 L 0 .027 .127 r
F
.41203 .1477 m .41016 .14553 L .41331 .14429 L F
.72739 .14681 m .72919 .14322 L .73071 .14551 L 0 .025 .124 r
F
.72739 .14681 m .72586 .14451 L .72919 .14322 L F
.73556 .14642 m .73738 .1429 L .73889 .14515 L F
.73556 .14642 m .73404 .14419 L .73738 .1429 L F
.62771 .14689 m .62936 .14339 L .63099 .14565 L 0 .026 .125 r
F
.62771 .14689 m .62608 .14462 L .62936 .14339 L F
.47411 .14712 m .4755 .14366 L .47729 .14589 L F
.47411 .14712 m .47231 .14491 L .4755 .14366 L F
.42019 .14738 m .42148 .14399 L .42334 .14616 L 0 .027 .126 r
F
.42019 .14738 m .41833 .14523 L .42148 .14399 L F
.67348 .14721 m .6752 .14371 L .67677 .1459 L 0 .026 .126 r
F
.67348 .14721 m .6719 .14501 L .6752 .14371 L F
.68164 .14676 m .68338 .14332 L .68494 .14549 L 0 .026 .125 r
F
.68164 .14676 m .68007 .14459 L .68338 .14332 L F
.37442 .14727 m .37564 .1438 L .37755 .14599 L 0 .027 .126 r
F
.37442 .14727 m .37251 .1451 L .37564 .1438 L F
.57379 .1473 m .57535 .14385 L .57704 .14609 L F
.57379 .1473 m .57211 .14507 L .57535 .14385 L F
.48227 .14688 m .48367 .14347 L .48546 .14565 L 0 .026 .125 r
F
.48227 .14688 m .48048 .14468 L .48367 .14347 L F
.74374 .14621 m .74558 .14278 L .74708 .14504 L 0 .025 .124 r
F
.74374 .14621 m .74223 .14396 L .74558 .14278 L F
.42834 .14713 m .42966 .14368 L .4315 .1459 L 0 .027 .126 r
F
.42834 .14713 m .42649 .14492 L .42966 .14368 L F
.38258 .14693 m .38382 .14344 L .38571 .14567 L 0 .026 .125 r
F
.38258 .14693 m .38068 .14472 L .38382 .14344 L F
.68981 .14649 m .69157 .14313 L .69312 .14531 L 0 .026 .124 r
F
.68981 .14649 m .68825 .14431 L .69157 .14313 L F
.52803 .14719 m .52951 .14375 L .53125 .14605 L 0 .027 .126 r
F
.52803 .14719 m .52629 .14489 L .52951 .14375 L F
.63589 .14681 m .63755 .14331 L .63917 .14565 L 0 .026 .125 r
F
.63589 .14681 m .63426 .14448 L .63755 .14331 L F
.58196 .14707 m .58353 .14358 L .58521 .14585 L 0 .027 .126 r
F
.58196 .14707 m .58028 .14483 L .58353 .14358 L F
.49043 .14667 m .49184 .14329 L .49362 .1455 L 0 .026 .125 r
F
.49043 .14667 m .48865 .14446 L .49184 .14329 L F
.39073 .14671 m .39198 .14325 L .39386 .14554 L F
.39073 .14671 m .38885 .14441 L .39198 .14325 L F
.75192 .1461 m .75377 .14262 L .75527 .1449 L 0 .025 .124 r
F
.75192 .1461 m .75043 .14384 L .75377 .14262 L F
.43649 .14703 m .43782 .14348 L .43966 .1458 L 0 .027 .126 r
F
.43649 .14703 m .43466 .14469 L .43782 .14348 L F
.69799 .14636 m .69975 .14282 L .70131 .1451 L 0 .026 .124 r
F
.69799 .14636 m .69644 .14408 L .69975 .14282 L F
.59013 .14686 m .59171 .14337 L .59338 .14562 L 0 .027 .126 r
F
.59013 .14686 m .58846 .14461 L .59171 .14337 L F
.5362 .14718 m .53769 .14381 L .53942 .14605 L 0 .027 .127 r
F
.5362 .14718 m .53447 .14493 L .53769 .14381 L F
.64407 .14675 m .64573 .14312 L .64735 .14549 L 0 .026 .125 r
F
.64407 .14675 m .64245 .1444 L .64573 .14312 L F
.70617 .14612 m .70794 .14257 L .70949 .14483 L 0 .025 .124 r
F
.70617 .14612 m .70462 .14384 L .70794 .14257 L F
.5983 .14658 m .5999 .14325 L .60156 .14543 L 0 .027 .126 r
F
.5983 .14658 m .59664 .14441 L .5999 .14325 L F
.44465 .14685 m .44599 .14336 L .44782 .14562 L F
.44465 .14685 m .44282 .14456 L .44599 .14336 L F
.49859 .14663 m .50002 .14305 L .50179 .14538 L 0 .026 .125 r
F
.49859 .14663 m .49682 .14432 L .50002 .14305 L F
.71434 .14582 m .71613 .14231 L .71767 .14458 L 0 .025 .124 r
F
.71434 .14582 m .7128 .14355 L .71613 .14231 L F
.39887 .14674 m .40014 .14319 L .40201 .14555 L 0 .027 .126 r
F
.39887 .14674 m .397 .14436 L .40014 .14319 L F
.65224 .14654 m .65393 .14304 L .65553 .14533 L 0 .026 .126 r
F
.65224 .14654 m .65063 .14423 L .65393 .14304 L F
.45281 .14661 m .45416 .14315 L .45598 .14537 L 0 .027 .126 r
F
.45281 .14661 m .45099 .14439 L .45416 .14315 L F
.54436 .14709 m .54587 .14356 L .54759 .14578 L 0 .028 .127 r
F
.54436 .14709 m .54264 .14486 L .54587 .14356 L F
.60647 .14644 m .60808 .14302 L .60973 .14519 L 0 .027 .126 r
F
.60647 .14644 m .60482 .14427 L .60808 .14302 L F
.50675 .14645 m .5082 .14284 L .50995 .14519 L 0 .026 .125 r
F
.50675 .14645 m .50499 .14411 L .5082 .14284 L F
.55253 .14673 m .55405 .14318 L .55576 .14543 L 0 .027 .126 r
F
.55253 .14673 m .55082 .14447 L .55405 .14318 L F
.66042 .14632 m .66212 .14292 L .66371 .14513 L F
.66042 .14632 m .65882 .14413 L .66212 .14292 L F
.46097 .14636 m .46234 .14288 L .46415 .14514 L F
.46097 .14636 m .45916 .14413 L .46234 .14288 L F
.72253 .1457 m .72433 .14221 L .72586 .14451 L 0 .025 .124 r
F
.72253 .1457 m .721 .14339 L .72433 .14221 L F
.61464 .14615 m .61626 .14259 L .6179 .14486 L 0 .026 .125 r
F
.61464 .14615 m .61299 .14389 L .61626 .14259 L F
.51491 .1462 m .51637 .1426 L .51812 .14492 L F
.51491 .1462 m .51316 .1439 L .51637 .1426 L F
.5607 .14644 m .56223 .14286 L .56393 .14515 L 0 .027 .126 r
F
.5607 .14644 m .55899 .14414 L .56223 .14286 L F
.40702 .14672 m .4083 .1432 L .41016 .14553 L 0 .027 .127 r
F
.40702 .14672 m .40515 .14438 L .4083 .1432 L F
.62281 .1459 m .62445 .14235 L .62608 .14462 L 0 .026 .125 r
F
.62281 .1459 m .62117 .1436 L .62445 .14235 L F
.46913 .14616 m .47051 .14262 L .47231 .14491 L F
.46913 .14616 m .46733 .14389 L .47051 .14262 L F
.6686 .14617 m .67031 .14277 L .6719 .14501 L 0 .027 .126 r
F
.6686 .14617 m .66701 .14395 L .67031 .14277 L F
.73071 .14551 m .73252 .14191 L .73404 .14419 L 0 .025 .124 r
F
.73071 .14551 m .72919 .14322 L .73252 .14191 L F
.41518 .14647 m .41647 .14303 L .41833 .14523 L 0 .027 .127 r
F
.41518 .14647 m .41331 .14429 L .41647 .14303 L F
.52308 .14602 m .52455 .14258 L .52629 .14489 L 0 .026 .125 r
F
.52308 .14602 m .52134 .14372 L .52455 .14258 L F
.56886 .14625 m .57041 .14277 L .57211 .14507 L 0 .027 .126 r
F
.56886 .14625 m .56717 .14396 L .57041 .14277 L F
.73889 .14515 m .74072 .14171 L .74223 .14396 L 0 .025 .123 r
F
.73889 .14515 m .73738 .1429 L .74072 .14171 L F
.63099 .14565 m .63264 .14222 L .63426 .14448 L 0 .026 .125 r
F
.63099 .14565 m .62936 .14339 L .63264 .14222 L F
.47729 .14589 m .47869 .14247 L .48048 .14468 L F
.47729 .14589 m .4755 .14366 L .47869 .14247 L F
.67677 .1459 m .6785 .14239 L .68007 .14459 L F
.67677 .1459 m .6752 .14371 L .6785 .14239 L F
.42334 .14616 m .42464 .14273 L .42649 .14492 L 0 .027 .126 r
F
.42334 .14616 m .42148 .14399 L .42464 .14273 L F
.68494 .14549 m .68669 .14214 L .68825 .14431 L 0 .026 .125 r
F
.68494 .14549 m .68338 .14332 L .68669 .14214 L F
.37755 .14599 m .37878 .14251 L .38068 .14472 L 0 .027 .126 r
F
.37755 .14599 m .37564 .1438 L .37878 .14251 L F
.57704 .14609 m .5786 .14258 L .58028 .14483 L F
.57704 .14609 m .57535 .14385 L .5786 .14258 L F
.48546 .14565 m .48687 .14228 L .48865 .14446 L 0 .026 .125 r
F
.48546 .14565 m .48367 .14347 L .48687 .14228 L F
.38571 .14567 m .38695 .14217 L .38885 .14441 L F
.38571 .14567 m .38382 .14344 L .38695 .14217 L F
.4315 .1459 m .43282 .14246 L .43466 .14469 L 0 .027 .126 r
F
.4315 .1459 m .42966 .14368 L .43282 .14246 L F
.74708 .14504 m .74892 .14156 L .75043 .14384 L 0 .025 .124 r
F
.74708 .14504 m .74558 .14278 L .74892 .14156 L F
.69312 .14531 m .69488 .14188 L .69644 .14408 L 0 .026 .124 r
F
.69312 .14531 m .69157 .14313 L .69488 .14188 L F
.53125 .14605 m .53273 .14261 L .53447 .14493 L 0 .027 .126 r
F
.53125 .14605 m .52951 .14375 L .53273 .14261 L F
.58521 .14585 m .58678 .14234 L .58846 .14461 L F
.58521 .14585 m .58353 .14358 L .58678 .14234 L F
.63917 .14565 m .64083 .14205 L .64245 .1444 L 0 .026 .125 r
F
.63917 .14565 m .63755 .14331 L .64083 .14205 L F
.49362 .1455 m .49504 .14212 L .49682 .14432 L F
.49362 .1455 m .49184 .14329 L .49504 .14212 L F
.39386 .14554 m .39512 .14209 L .397 .14436 L F
.39386 .14554 m .39198 .14325 L .39512 .14209 L F
.70131 .1451 m .70307 .14157 L .70462 .14384 L 0 .025 .124 r
F
.70131 .1451 m .69975 .14282 L .70307 .14157 L F
.43966 .1458 m .44099 .14227 L .44282 .14456 L 0 .027 .126 r
F
.43966 .1458 m .43782 .14348 L .44099 .14227 L F
.75527 .1449 m .75713 .1414 L .75862 .14371 L 0 .025 .124 r
F
.75527 .1449 m .75377 .14262 L .75713 .1414 L F
.59338 .14562 m .59497 .14215 L .59664 .14441 L 0 .027 .126 r
F
.59338 .14562 m .59171 .14337 L .59497 .14215 L F
.64735 .14549 m .64902 .14187 L .65063 .14423 L 0 .026 .125 r
F
.64735 .14549 m .64573 .14312 L .64902 .14187 L F
.70949 .14483 m .71126 .1413 L .7128 .14355 L 0 .025 .124 r
F
.70949 .14483 m .70794 .14257 L .71126 .1413 L F
.53942 .14605 m .54092 .14263 L .54264 .14486 L 0 .028 .127 r
F
.53942 .14605 m .53769 .14381 L .54092 .14263 L F
.50179 .14538 m .50322 .14177 L .50499 .14411 L 0 .026 .125 r
F
.50179 .14538 m .50002 .14305 L .50322 .14177 L F
.44782 .14562 m .44916 .14216 L .45099 .14439 L 0 .027 .126 r
F
.44782 .14562 m .44599 .14336 L .44916 .14216 L F
.60156 .14543 m .60316 .1421 L .60482 .14427 L F
.60156 .14543 m .5999 .14325 L .60316 .1421 L F
.71767 .14458 m .71946 .14113 L .721 .14339 L 0 .025 .124 r
F
.71767 .14458 m .71613 .14231 L .71946 .14113 L F
.54759 .14578 m .5491 .14226 L .55082 .14447 L 0 .027 .127 r
F
.54759 .14578 m .54587 .14356 L .5491 .14226 L F
.40201 .14555 m .40328 .14203 L .40515 .14438 L 0 .027 .126 r
F
.40201 .14555 m .40014 .14319 L .40328 .14203 L F
.65553 .14533 m .65722 .14184 L .65882 .14413 L 0 .026 .126 r
F
.65553 .14533 m .65393 .14304 L .65722 .14184 L F
.45598 .14537 m .45734 .14189 L .45916 .14413 L 0 .027 .126 r
F
.45598 .14537 m .45416 .14315 L .45734 .14189 L F
.50995 .14519 m .51141 .14154 L .51316 .1439 L 0 .026 .125 r
F
.50995 .14519 m .5082 .14284 L .51141 .14154 L F
.60973 .14519 m .61135 .1417 L .61299 .14389 L F
.60973 .14519 m .60808 .14302 L .61135 .1417 L F
.55576 .14543 m .55728 .14191 L .55899 .14414 L 0 .027 .126 r
F
.55576 .14543 m .55405 .14318 L .55728 .14191 L F
.6179 .14486 m .61953 .14135 L .62117 .1436 L 0 .026 .125 r
F
.6179 .14486 m .61626 .14259 L .61953 .14135 L F
.66371 .14513 m .66542 .14173 L .66701 .14395 L 0 .027 .126 r
F
.66371 .14513 m .66212 .14292 L .66542 .14173 L F
.46415 .14514 m .46552 .14161 L .46733 .14389 L 0 .026 .125 r
F
.46415 .14514 m .46234 .14288 L .46552 .14161 L F
.51812 .14492 m .51959 .14139 L .52134 .14372 L F
.51812 .14492 m .51637 .1426 L .51959 .14139 L F
.56393 .14515 m .56547 .14166 L .56717 .14396 L 0 .026 .126 r
F
.56393 .14515 m .56223 .14286 L .56547 .14166 L F
.72586 .14451 m .72766 .14093 L .72919 .14322 L 0 .025 .124 r
F
.72586 .14451 m .72433 .14221 L .72766 .14093 L F
.62608 .14462 m .62772 .14113 L .62936 .14339 L 0 .026 .125 r
F
.62608 .14462 m .62445 .14235 L .62772 .14113 L F
.41016 .14553 m .41145 .14195 L .41331 .14429 L 0 .027 .127 r
F
.41016 .14553 m .4083 .1432 L .41145 .14195 L F
.73404 .14419 m .73586 .14063 L .73738 .1429 L 0 .025 .123 r
F
.73404 .14419 m .73252 .14191 L .73586 .14063 L F
.47231 .14491 m .4737 .14136 L .4755 .14366 L 0 .026 .125 r
F
.47231 .14491 m .47051 .14262 L .4737 .14136 L F
.41833 .14523 m .41963 .14177 L .42148 .14399 L 0 .027 .126 r
F
.41833 .14523 m .41647 .14303 L .41963 .14177 L F
.6719 .14501 m .67361 .14146 L .6752 .14371 L F
.6719 .14501 m .67031 .14277 L .67361 .14146 L F
.68007 .14459 m .68181 .14112 L .68338 .14332 L 0 .026 .125 r
F
.68007 .14459 m .6785 .14239 L .68181 .14112 L F
.57211 .14507 m .57366 .14154 L .57535 .14385 L 0 .027 .126 r
F
.57211 .14507 m .57041 .14277 L .57366 .14154 L F
.74223 .14396 m .74407 .14051 L .74558 .14278 L 0 .025 .124 r
F
.74223 .14396 m .74072 .14171 L .74407 .14051 L F
.52629 .14489 m .52777 .14143 L .52951 .14375 L 0 .027 .126 r
F
.52629 .14489 m .52455 .14258 L .52777 .14143 L F
.48048 .14468 m .48188 .14127 L .48367 .14347 L 0 .026 .125 r
F
.48048 .14468 m .47869 .14247 L .48188 .14127 L F
.42649 .14492 m .42781 .14147 L .42966 .14368 L 0 .027 .126 r
F
.42649 .14492 m .42464 .14273 L .42781 .14147 L F
.63426 .14448 m .63592 .14104 L .63755 .14331 L 0 .026 .125 r
F
.63426 .14448 m .63264 .14222 L .63592 .14104 L F
.38068 .14472 m .38192 .14121 L .38382 .14344 L F
.38068 .14472 m .37878 .14251 L .38192 .14121 L F
.68825 .14431 m .69001 .14095 L .69157 .14313 L F
.68825 .14431 m .68669 .14214 L .69001 .14095 L F
.58028 .14483 m .58185 .1413 L .58353 .14358 L 0 .027 .126 r
F
.58028 .14483 m .5786 .14258 L .58185 .1413 L F
.38885 .14441 m .39009 .14102 L .39198 .14325 L 0 .026 .125 r
F
.38885 .14441 m .38695 .14217 L .39009 .14102 L F
.48865 .14446 m .49006 .14112 L .49184 .14329 L F
.48865 .14446 m .48687 .14228 L .49006 .14112 L F
.43466 .14469 m .43598 .14127 L .43782 .14348 L 0 .027 .126 r
F
.43466 .14469 m .43282 .14246 L .43598 .14127 L F
.75043 .14384 m .75227 .14032 L .75377 .14262 L 0 .025 .124 r
F
.75043 .14384 m .74892 .14156 L .75227 .14032 L F
.69644 .14408 m .6982 .14061 L .69975 .14282 L 0 .026 .124 r
F
.69644 .14408 m .69488 .14188 L .6982 .14061 L F
.58846 .14461 m .59004 .14109 L .59171 .14337 L 0 .027 .126 r
F
.58846 .14461 m .58678 .14234 L .59004 .14109 L F
.64245 .1444 m .64411 .14076 L .64573 .14312 L 0 .026 .125 r
F
.64245 .1444 m .64083 .14205 L .64411 .14076 L F
.53447 .14493 m .53596 .14148 L .53769 .14381 L 0 .027 .127 r
F
.53447 .14493 m .53273 .14261 L .53596 .14148 L F
.70462 .14384 m .70639 .14031 L .70794 .14257 L 0 .025 .124 r
F
.70462 .14384 m .70307 .14157 L .70639 .14031 L F
.49682 .14432 m .49825 .14084 L .50002 .14305 L 0 .026 .125 r
F
.49682 .14432 m .49504 .14212 L .49825 .14084 L F
.44282 .14456 m .44416 .1411 L .44599 .14336 L 0 .027 .126 r
F
.44282 .14456 m .44099 .14227 L .44416 .1411 L F
.397 .14436 m .39826 .14093 L .40014 .14319 L 0 .026 .126 r
F
.397 .14436 m .39512 .14209 L .39826 .14093 L F
.59664 .14441 m .59823 .14099 L .5999 .14325 L 0 .027 .126 r
F
.59664 .14441 m .59497 .14215 L .59823 .14099 L F
.7128 .14355 m .71459 .14008 L .71613 .14231 L 0 .025 .124 r
F
.7128 .14355 m .71126 .1413 L .71459 .14008 L F
.65063 .14423 m .65232 .14068 L .65393 .14304 L 0 .026 .125 r
F
.65063 .14423 m .64902 .14187 L .65232 .14068 L F
.50499 .14411 m .50643 .14048 L .5082 .14284 L F
.50499 .14411 m .50322 .14177 L .50643 .14048 L F
.45099 .14439 m .45234 .14093 L .45416 .14315 L 0 .027 .126 r
F
.45099 .14439 m .44916 .14216 L .45234 .14093 L F
.54264 .14486 m .54415 .14135 L .54587 .14356 L 0 .028 .127 r
F
.54264 .14486 m .54092 .14263 L .54415 .14135 L F
.55082 .14447 m .55234 .141 L .55405 .14318 L 0 .027 .126 r
F
.55082 .14447 m .5491 .14226 L .55234 .141 L F
.60482 .14427 m .60643 .14083 L .60808 .14302 L F
.60482 .14427 m .60316 .1421 L .60643 .14083 L F
.721 .14339 m .7228 .13995 L .72433 .14221 L 0 .025 .124 r
F
.721 .14339 m .71946 .14113 L .7228 .13995 L F
.61299 .14389 m .61462 .14039 L .61626 .14259 L 0 .026 .125 r
F
.61299 .14389 m .61135 .1417 L .61462 .14039 L F
.51316 .1439 m .51462 .14024 L .51637 .1426 L F
.51316 .1439 m .51141 .14154 L .51462 .14024 L F
.65882 .14413 m .66052 .14064 L .66212 .14292 L 0 .027 .126 r
F
.65882 .14413 m .65722 .14184 L .66052 .14064 L F
.45916 .14413 m .46053 .14063 L .46234 .14288 L F
.45916 .14413 m .45734 .14189 L .46053 .14063 L F
.55899 .14414 m .56052 .14065 L .56223 .14286 L F
.55899 .14414 m .55728 .14191 L .56052 .14065 L F
.40515 .14438 m .40643 .14087 L .4083 .1432 L F
.40515 .14438 m .40328 .14203 L .40643 .14087 L F
.62117 .1436 m .62281 .1401 L .62445 .14235 L 0 .026 .125 r
F
.62117 .1436 m .61953 .14135 L .62281 .1401 L F
.46733 .14389 m .46871 .14032 L .47051 .14262 L F
.46733 .14389 m .46552 .14161 L .46871 .14032 L F
.72919 .14322 m .731 .13962 L .73252 .14191 L 0 .025 .124 r
F
.72919 .14322 m .72766 .14093 L .731 .13962 L F
.52134 .14372 m .52281 .14025 L .52455 .14258 L 0 .026 .125 r
F
.52134 .14372 m .51959 .14139 L .52281 .14025 L F
.66701 .14395 m .66873 .14053 L .67031 .14277 L 0 .027 .126 r
F
.66701 .14395 m .66542 .14173 L .66873 .14053 L F
.56717 .14396 m .56872 .14046 L .57041 .14277 L F
.56717 .14396 m .56547 .14166 L .56872 .14046 L F
.73738 .1429 m .73921 .13944 L .74072 .14171 L 0 .025 .123 r
F
.73738 .1429 m .73586 .14063 L .73921 .13944 L F
.41331 .14429 m .41461 .14068 L .41647 .14303 L 0 .027 .126 r
F
.41331 .14429 m .41145 .14195 L .41461 .14068 L F
.62936 .14339 m .63101 .13995 L .63264 .14222 L 0 .026 .125 r
F
.62936 .14339 m .62772 .14113 L .63101 .13995 L F
.4755 .14366 m .47689 .14016 L .47869 .14247 L F
.4755 .14366 m .4737 .14136 L .47689 .14016 L F
.6752 .14371 m .67692 .14014 L .6785 .14239 L F
.6752 .14371 m .67361 .14146 L .67692 .14014 L F
.42148 .14399 m .42279 .1405 L .42464 .14273 L 0 .027 .126 r
F
.42148 .14399 m .41963 .14177 L .42279 .1405 L F
.68338 .14332 m .68512 .13993 L .68669 .14214 L 0 .026 .125 r
F
.68338 .14332 m .68181 .14112 L .68512 .13993 L F
.57535 .14385 m .57691 .14026 L .5786 .14258 L 0 .027 .126 r
F
.57535 .14385 m .57366 .14154 L .57691 .14026 L F
.38382 .14344 m .38506 .13992 L .38695 .14217 L 0 .026 .125 r
F
.38382 .14344 m .38192 .14121 L .38506 .13992 L F
.42966 .14368 m .43097 .14025 L .43282 .14246 L 0 .027 .126 r
F
.42966 .14368 m .42781 .14147 L .43097 .14025 L F
.74558 .14278 m .74742 .13928 L .74892 .14156 L 0 .025 .124 r
F
.74558 .14278 m .74407 .14051 L .74742 .13928 L F
.48367 .14347 m .48508 .1401 L .48687 .14228 L 0 .026 .125 r
F
.48367 .14347 m .48188 .14127 L .48508 .1401 L F
.52951 .14375 m .531 .14029 L .53273 .14261 L 0 .027 .126 r
F
.52951 .14375 m .52777 .14143 L .531 .14029 L F
.63755 .14331 m .63921 .13978 L .64083 .14205 L 0 .026 .125 r
F
.63755 .14331 m .63592 .14104 L .63921 .13978 L F
.69157 .14313 m .69332 .13969 L .69488 .14188 L F
.69157 .14313 m .69001 .14095 L .69332 .13969 L F
.58353 .14358 m .5851 .14006 L .58678 .14234 L 0 .026 .126 r
F
.58353 .14358 m .58185 .1413 L .5851 .14006 L F
.39198 .14325 m .39323 .13987 L .39512 .14209 L 0 .026 .125 r
F
.39198 .14325 m .39009 .14102 L .39323 .13987 L F
.43782 .14348 m .43915 .14007 L .44099 .14227 L 0 .027 .126 r
F
.43782 .14348 m .43598 .14127 L .43915 .14007 L F
.69975 .14282 m .70152 .13933 L .70307 .14157 L 0 .025 .124 r
F
.69975 .14282 m .6982 .14061 L .70152 .13933 L F
.49184 .14329 m .49326 .13996 L .49504 .14212 L 0 .026 .126 r
F
.49184 .14329 m .49006 .14112 L .49326 .13996 L F
.75377 .14262 m .75563 .13907 L .75713 .1414 L 0 .025 .124 r
F
.75377 .14262 m .75227 .14032 L .75563 .13907 L F
.64573 .14312 m .64741 .1395 L .64902 .14187 L 0 .026 .125 r
F
.64573 .14312 m .64411 .14076 L .64741 .1395 L F
.59171 .14337 m .5933 .13987 L .59497 .14215 L 0 .026 .126 r
F
.59171 .14337 m .59004 .14109 L .5933 .13987 L F
.70794 .14257 m .70972 .13906 L .71126 .1413 L 0 .025 .124 r
F
.70794 .14257 m .70639 .14031 L .70972 .13906 L F
.50002 .14305 m .50146 .13954 L .50322 .14177 L 0 .026 .125 r
F
.50002 .14305 m .49825 .14084 L .50146 .13954 L F
.53769 .14381 m .53919 .14029 L .54092 .14263 L 0 .028 .127 r
F
.53769 .14381 m .53596 .14148 L .53919 .14029 L F
.44599 .14336 m .44734 .13992 L .44916 .14216 L 0 .027 .126 r
F
.44599 .14336 m .44416 .1411 L .44734 .13992 L F
.40014 .14319 m .40141 .13978 L .40328 .14203 L F
.40014 .14319 m .39826 .14093 L .40141 .13978 L F
.71613 .14231 m .71793 .1389 L .71946 .14113 L 0 .025 .124 r
F
.71613 .14231 m .71459 .14008 L .71793 .1389 L F
.5999 .14325 m .6015 .13982 L .60316 .1421 L 0 .027 .126 r
F
.5999 .14325 m .59823 .14099 L .6015 .13982 L F
.65393 .14304 m .65562 .1395 L .65722 .14184 L 0 .026 .125 r
F
.65393 .14304 m .65232 .14068 L .65562 .1395 L F
.5082 .14284 m .50965 .13918 L .51141 .14154 L F
.5082 .14284 m .50643 .14048 L .50965 .13918 L F
.54587 .14356 m .54738 .14006 L .5491 .14226 L 0 .027 .127 r
F
.54587 .14356 m .54415 .14135 L .54738 .14006 L F
.45416 .14315 m .45552 .13965 L .45734 .14189 L 0 .027 .126 r
F
.45416 .14315 m .45234 .14093 L .45552 .13965 L F
.55405 .14318 m .55557 .13975 L .55728 .14191 L F
.55405 .14318 m .55234 .141 L .55557 .13975 L F
.60808 .14302 m .6097 .13951 L .61135 .1417 L F
.60808 .14302 m .60643 .14083 L .6097 .13951 L F
.61626 .14259 m .61789 .13914 L .61953 .14135 L 0 .026 .125 r
F
.61626 .14259 m .61462 .14039 L .61789 .13914 L F
.51637 .1426 m .51784 .13903 L .51959 .14139 L F
.51637 .1426 m .51462 .14024 L .51784 .13903 L F
.56223 .14286 m .56377 .13944 L .56547 .14166 L 0 .026 .126 r
F
.56223 .14286 m .56052 .14065 L .56377 .13944 L F
.46234 .14288 m .46371 .13934 L .46552 .14161 L 0 .026 .125 r
F
.46234 .14288 m .46053 .14063 L .46371 .13934 L F
.72433 .14221 m .72614 .13867 L .72766 .14093 L 0 .025 .124 r
F
.72433 .14221 m .7228 .13995 L .72614 .13867 L F
.66212 .14292 m .66383 .13944 L .66542 .14173 L 0 .027 .126 r
F
.66212 .14292 m .66052 .14064 L .66383 .13944 L F
.4083 .1432 m .40959 .13961 L .41145 .14195 L F
.4083 .1432 m .40643 .14087 L .40959 .13961 L F
.62445 .14235 m .62609 .13888 L .62772 .14113 L 0 .026 .125 r
F
.62445 .14235 m .62281 .1401 L .62609 .13888 L F
.73252 .14191 m .73434 .13835 L .73586 .14063 L 0 .025 .123 r
F
.73252 .14191 m .731 .13962 L .73434 .13835 L F
.47051 .14262 m .4719 .13904 L .4737 .14136 L 0 .026 .125 r
F
.47051 .14262 m .46871 .14032 L .4719 .13904 L F
.57041 .14277 m .57196 .13922 L .57366 .14154 L 0 .027 .126 r
F
.57041 .14277 m .56872 .14046 L .57196 .13922 L F
.67031 .14277 m .67203 .13921 L .67361 .14146 L F
.67031 .14277 m .66873 .14053 L .67203 .13921 L F
.52455 .14258 m .52603 .1391 L .52777 .14143 L 0 .026 .125 r
F
.52455 .14258 m .52281 .14025 L .52603 .1391 L F
.41647 .14303 m .41777 .1394 L .41963 .14177 L 0 .027 .126 r
F
.41647 .14303 m .41461 .14068 L .41777 .1394 L F
.74072 .14171 m .74256 .13826 L .74407 .14051 L 0 .025 .123 r
F
.74072 .14171 m .73921 .13944 L .74256 .13826 L F
.6785 .14239 m .68023 .13886 L .68181 .14112 L 0 .026 .125 r
F
.6785 .14239 m .67692 .14014 L .68023 .13886 L F
.63264 .14222 m .6343 .13877 L .63592 .14104 L F
.63264 .14222 m .63101 .13995 L .6343 .13877 L F
.47869 .14247 m .48009 .13897 L .48188 .14127 L F
.47869 .14247 m .47689 .14016 L .48009 .13897 L F
.42464 .14273 m .42596 .13922 L .42781 .14147 L 0 .027 .126 r
F
.42464 .14273 m .42279 .1405 L .42596 .13922 L F
.5786 .14258 m .58016 .13897 L .58185 .1413 L 0 .026 .126 r
F
.5786 .14258 m .57691 .14026 L .58016 .13897 L F
.68669 .14214 m .68844 .13874 L .69001 .14095 L 0 .026 .125 r
F
.68669 .14214 m .68512 .13993 L .68844 .13874 L F
.38695 .14217 m .3882 .13879 L .39009 .14102 L F
.38695 .14217 m .38506 .13992 L .3882 .13879 L F
.74892 .14156 m .75077 .13802 L .75227 .14032 L 0 .025 .123 r
F
.74892 .14156 m .74742 .13928 L .75077 .13802 L F
.43282 .14246 m .43414 .13907 L .43598 .14127 L 0 .027 .126 r
F
.43282 .14246 m .43097 .14025 L .43414 .13907 L F
.64083 .14205 m .6425 .13849 L .64411 .14076 L 0 .026 .125 r
F
.64083 .14205 m .63921 .13978 L .6425 .13849 L F
.48687 .14228 m .48828 .13894 L .49006 .14112 L 0 .027 .126 r
F
.48687 .14228 m .48508 .1401 L .48828 .13894 L F
.69488 .14188 m .69664 .13839 L .6982 .14061 L 0 .026 .124 r
F
.69488 .14188 m .69332 .13969 L .69664 .13839 L F
.58678 .14234 m .58836 .13881 L .59004 .14109 L 0 .026 .125 r
F
.58678 .14234 m .5851 .14006 L .58836 .13881 L F
.53273 .14261 m .53422 .13914 L .53596 .14148 L 0 .027 .126 r
F
.53273 .14261 m .531 .14029 L .53422 .13914 L F
.70307 .14157 m .70484 .13807 L .70639 .14031 L 0 .025 .124 r
F
.70307 .14157 m .70152 .13933 L .70484 .13807 L F
.44099 .14227 m .44233 .1389 L .44416 .1411 L 0 .027 .126 r
F
.44099 .14227 m .43915 .14007 L .44233 .1389 L F
.39512 .14209 m .39638 .13873 L .39826 .14093 L 0 .026 .126 r
F
.39512 .14209 m .39323 .13987 L .39638 .13873 L F
.64902 .14187 m .6507 .13833 L .65232 .14068 L 0 .026 .125 r
F
.64902 .14187 m .64741 .1395 L .6507 .13833 L F
.49504 .14212 m .49647 .13867 L .49825 .14084 L 0 .026 .126 r
F
.49504 .14212 m .49326 .13996 L .49647 .13867 L F
.59497 .14215 m .59656 .13869 L .59823 .14099 L 0 .027 .126 r
F
.59497 .14215 m .5933 .13987 L .59656 .13869 L F
.71126 .1413 m .71305 .13784 L .71459 .14008 L 0 .025 .124 r
F
.71126 .1413 m .70972 .13906 L .71305 .13784 L F
.50322 .14177 m .50467 .13824 L .50643 .14048 L 0 .026 .125 r
F
.50322 .14177 m .50146 .13954 L .50467 .13824 L F
.44916 .14216 m .45052 .13871 L .45234 .14093 L 0 .027 .126 r
F
.44916 .14216 m .44734 .13992 L .45052 .13871 L F
.54092 .14263 m .54242 .139 L .54415 .14135 L 0 .027 .127 r
F
.54092 .14263 m .53919 .14029 L .54242 .139 L F
.51141 .14154 m .51286 .13787 L .51462 .14024 L 0 .025 .124 r
F
.51141 .14154 m .50965 .13918 L .51286 .13787 L F
.40328 .14203 m .40456 .13863 L .40643 .14087 L 0 .027 .126 r
F
.40328 .14203 m .40141 .13978 L .40456 .13863 L F
.5491 .14226 m .55062 .13881 L .55234 .141 L F
.5491 .14226 m .54738 .14006 L .55062 .13881 L F
.71946 .14113 m .72127 .13773 L .7228 .13995 L 0 .025 .124 r
F
.71946 .14113 m .71793 .1389 L .72127 .13773 L F
.65722 .14184 m .65892 .13831 L .66052 .14064 L 0 .026 .125 r
F
.65722 .14184 m .65562 .1395 L .65892 .13831 L F
.60316 .1421 m .60477 .13854 L .60643 .14083 L 0 .027 .126 r
F
.60316 .1421 m .6015 .13982 L .60477 .13854 L F
.45734 .14189 m .45871 .13837 L .46053 .14063 L F
.45734 .14189 m .45552 .13965 L .45871 .13837 L F
.55728 .14191 m .55882 .1385 L .56052 .14065 L F
.55728 .14191 m .55557 .13975 L .55882 .1385 L F
.61135 .1417 m .61297 .13818 L .61462 .14039 L 0 .026 .125 r
F
.61135 .1417 m .6097 .13951 L .61297 .13818 L F
.61953 .14135 m .62117 .13789 L .62281 .1401 L F
.61953 .14135 m .61789 .13914 L .62117 .13789 L F
.72766 .14093 m .72947 .13737 L .731 .13962 L 0 .025 .124 r
F
.72766 .14093 m .72614 .13867 L .72947 .13737 L F
.46552 .14161 m .4669 .13804 L .46871 .14032 L 0 .026 .125 r
F
.46552 .14161 m .46371 .13934 L .4669 .13804 L F
.51959 .14139 m .52106 .13789 L .52281 .14025 L F
.51959 .14139 m .51784 .13903 L .52106 .13789 L F
.56547 .14166 m .56702 .13823 L .56872 .14046 L 0 .026 .126 r
F
.56547 .14166 m .56377 .13944 L .56702 .13823 L F
.41145 .14195 m .41275 .13832 L .41461 .14068 L 0 .027 .126 r
F
.41145 .14195 m .40959 .13961 L .41275 .13832 L F
.66542 .14173 m .66713 .13824 L .66873 .14053 L F
.66542 .14173 m .66383 .13944 L .66713 .13824 L F
.73586 .14063 m .73769 .13718 L .73921 .13944 L 0 .025 .123 r
F
.73586 .14063 m .73434 .13835 L .73769 .13718 L F
.62772 .14113 m .62938 .13769 L .63101 .13995 L 0 .026 .125 r
F
.62772 .14113 m .62609 .13888 L .62938 .13769 L F
.4737 .14136 m .4751 .13785 L .47689 .14016 L F
.4737 .14136 m .4719 .13904 L .4751 .13785 L F
.67361 .14146 m .67534 .13788 L .67692 .14014 L F
.67361 .14146 m .67203 .13921 L .67534 .13788 L F
.57366 .14154 m .57522 .13793 L .57691 .14026 L 0 .026 .126 r
F
.57366 .14154 m .57196 .13922 L .57522 .13793 L F
.41963 .14177 m .42094 .13812 L .42279 .1405 L 0 .027 .126 r
F
.41963 .14177 m .41777 .1394 L .42094 .13812 L F
.68181 .14112 m .68355 .13766 L .68512 .13993 L 0 .026 .125 r
F
.68181 .14112 m .68023 .13886 L .68355 .13766 L F
.74407 .14051 m .74591 .13703 L .74742 .13928 L 0 .025 .124 r
F
.74407 .14051 m .74256 .13826 L .74591 .13703 L F
.52777 .14143 m .52925 .13794 L .531 .14029 L 0 .027 .126 r
F
.52777 .14143 m .52603 .1391 L .52925 .13794 L F
.42781 .14147 m .42912 .138 L .43097 .14025 L F
.42781 .14147 m .42596 .13922 L .42912 .138 L F
.63592 .14104 m .63758 .1375 L .63921 .13978 L 0 .026 .125 r
F
.63592 .14104 m .6343 .13877 L .63758 .1375 L F
.48188 .14127 m .48329 .13779 L .48508 .1401 L F
.48188 .14127 m .48009 .13897 L .48329 .13779 L F
.58185 .1413 m .58342 .13775 L .5851 .14006 L F
.58185 .1413 m .58016 .13897 L .58342 .13775 L F
.69001 .14095 m .69176 .13746 L .69332 .13969 L F
.69001 .14095 m .68844 .13874 L .69176 .13746 L F
.64411 .14076 m .64579 .13723 L .64741 .1395 L 0 .026 .124 r
F
.64411 .14076 m .6425 .13849 L .64579 .13723 L F
.75227 .14032 m .75412 .13676 L .75563 .13907 L 0 .025 .123 r
F
.75227 .14032 m .75077 .13802 L .75412 .13676 L F
.39009 .14102 m .39134 .13765 L .39323 .13987 L 0 .026 .125 r
F
.39009 .14102 m .3882 .13879 L .39134 .13765 L F
.43598 .14127 m .43731 .13789 L .43915 .14007 L 0 .027 .126 r
F
.43598 .14127 m .43414 .13907 L .43731 .13789 L F
.6982 .14061 m .69996 .1371 L .70152 .13933 L 0 .025 .124 r
F
.6982 .14061 m .69664 .13839 L .69996 .1371 L F
.59004 .14109 m .59162 .13759 L .5933 .13987 L 0 .026 .125 r
F
.59004 .14109 m .58836 .13881 L .59162 .13759 L F
.49006 .14112 m .49148 .13778 L .49326 .13996 L 0 .027 .126 r
F
.49006 .14112 m .48828 .13894 L .49148 .13778 L F
.70639 .14031 m .70817 .13681 L .70972 .13906 L 0 .025 .124 r
F
.70639 .14031 m .70484 .13807 L .70817 .13681 L F
.53596 .14148 m .53746 .13794 L .53919 .14029 L 0 .027 .127 r
F
.53596 .14148 m .53422 .13914 L .53746 .13794 L F
.49825 .14084 m .49968 .13736 L .50146 .13954 L 0 .026 .125 r
F
.49825 .14084 m .49647 .13867 L .49968 .13736 L F
.44416 .1411 m .4455 .13774 L .44734 .13992 L 0 .027 .126 r
F
.44416 .1411 m .44233 .1389 L .4455 .13774 L F
.65232 .14068 m .65401 .13716 L .65562 .1395 L 0 .026 .125 r
F
.65232 .14068 m .6507 .13833 L .65401 .13716 L F
.39826 .14093 m .39952 .13759 L .40141 .13978 L 0 .027 .126 r
F
.39826 .14093 m .39638 .13873 L .39952 .13759 L F
.50643 .14048 m .50788 .13694 L .50965 .13918 L 0 .026 .124 r
F
.50643 .14048 m .50467 .13824 L .50788 .13694 L F
.71459 .14008 m .71639 .13667 L .71793 .1389 L 0 .025 .124 r
F
.71459 .14008 m .71305 .13784 L .71639 .13667 L F
.59823 .14099 m .59983 .13752 L .6015 .13982 L 0 .027 .126 r
F
.59823 .14099 m .59656 .13869 L .59983 .13752 L F
.54415 .14135 m .54566 .13771 L .54738 .14006 L 0 .027 .127 r
F
.54415 .14135 m .54242 .139 L .54566 .13771 L F
.51462 .14024 m .51608 .13667 L .51784 .13903 L 0 .025 .124 r
F
.51462 .14024 m .51286 .13787 L .51608 .13667 L F
.45234 .14093 m .4537 .13741 L .45552 .13965 L 0 .027 .126 r
F
.45234 .14093 m .45052 .13871 L .4537 .13741 L F
.55234 .141 m .55386 .13758 L .55557 .13975 L F
.55234 .141 m .55062 .13881 L .55386 .13758 L F
.60643 .14083 m .60804 .13721 L .6097 .13951 L F
.60643 .14083 m .60477 .13854 L .60804 .13721 L F
.61462 .14039 m .61625 .13693 L .61789 .13914 L 0 .026 .125 r
F
.61462 .14039 m .61297 .13818 L .61625 .13693 L F
.46053 .14063 m .4619 .13708 L .46371 .13934 L F
.46053 .14063 m .45871 .13837 L .4619 .13708 L F
.7228 .13995 m .72461 .13645 L .72614 .13867 L 0 .025 .124 r
F
.7228 .13995 m .72127 .13773 L .72461 .13645 L F
.40643 .14087 m .40772 .13736 L .40959 .13961 L 0 .027 .126 r
F
.40643 .14087 m .40456 .13863 L .40772 .13736 L F
.66052 .14064 m .66222 .13711 L .66383 .13944 L 0 .026 .125 r
F
.66052 .14064 m .65892 .13831 L .66222 .13711 L F
.56052 .14065 m .56206 .13728 L .56377 .13944 L 0 .027 .126 r
F
.56052 .14065 m .55882 .1385 L .56206 .13728 L F
.731 .13962 m .73282 .1361 L .73434 .13835 L 0 .025 .123 r
F
.731 .13962 m .72947 .13737 L .73282 .1361 L F
.46871 .14032 m .4701 .13675 L .4719 .13904 L 0 .026 .125 r
F
.46871 .14032 m .4669 .13804 L .4701 .13675 L F
.62281 .1401 m .62445 .13665 L .62609 .13888 L F
.62281 .1401 m .62117 .13789 L .62445 .13665 L F
.41461 .14068 m .41591 .13703 L .41777 .1394 L 0 .027 .126 r
F
.41461 .14068 m .41275 .13832 L .41591 .13703 L F
.56872 .14046 m .57027 .13697 L .57196 .13922 L 0 .026 .126 r
F
.56872 .14046 m .56702 .13823 L .57027 .13697 L F
.52281 .14025 m .52428 .13675 L .52603 .1391 L 0 .026 .125 r
F
.52281 .14025 m .52106 .13789 L .52428 .13675 L F
.66873 .14053 m .67044 .13693 L .67203 .13921 L 0 .026 .126 r
F
.66873 .14053 m .66713 .13824 L .67044 .13693 L F
.73921 .13944 m .74105 .13601 L .74256 .13826 L 0 .025 .123 r
F
.73921 .13944 m .73769 .13718 L .74105 .13601 L F
.67692 .14014 m .67865 .13659 L .68023 .13886 L 0 .026 .125 r
F
.67692 .14014 m .67534 .13788 L .67865 .13659 L F
.47689 .14016 m .47829 .13666 L .48009 .13897 L F
.47689 .14016 m .4751 .13785 L .47829 .13666 L F
.63101 .13995 m .63267 .13649 L .6343 .13877 L F
.63101 .13995 m .62938 .13769 L .63267 .13649 L F
.57691 .14026 m .57847 .13664 L .58016 .13897 L F
.57691 .14026 m .57522 .13793 L .57847 .13664 L F
.42279 .1405 m .42411 .13683 L .42596 .13922 L 0 .027 .126 r
F
.42279 .1405 m .42094 .13812 L .42411 .13683 L F
.68512 .13993 m .68687 .13645 L .68844 .13874 L 0 .026 .125 r
F
.68512 .13993 m .68355 .13766 L .68687 .13645 L F
.74742 .13928 m .74927 .13578 L .75077 .13802 L 0 .025 .123 r
F
.74742 .13928 m .74591 .13703 L .74927 .13578 L F
.63921 .13978 m .64087 .13622 L .6425 .13849 L 0 .026 .125 r
F
.63921 .13978 m .63758 .1375 L .64087 .13622 L F
.43097 .14025 m .43229 .13682 L .43414 .13907 L 0 .027 .126 r
F
.43097 .14025 m .42912 .138 L .43229 .13682 L F
.5851 .14006 m .58668 .13654 L .58836 .13881 L 0 .026 .125 r
F
.5851 .14006 m .58342 .13775 L .58668 .13654 L F
.531 .14029 m .53249 .13678 L .53422 .13914 L 0 .027 .126 r
F
.531 .14029 m .52925 .13794 L .53249 .13678 L F
.48508 .1401 m .48649 .13663 L .48828 .13894 L F
.48508 .1401 m .48329 .13779 L .48649 .13663 L F
.69332 .13969 m .69508 .13615 L .69664 .13839 L 0 .026 .125 r
F
.69332 .13969 m .69176 .13746 L .69508 .13615 L F
.64741 .1395 m .64909 .13608 L .6507 .13833 L 0 .026 .124 r
F
.64741 .1395 m .64579 .13723 L .64909 .13608 L F
.70152 .13933 m .70329 .13583 L .70484 .13807 L 0 .025 .124 r
F
.70152 .13933 m .69996 .1371 L .70329 .13583 L F
.43915 .14007 m .44049 .13672 L .44233 .1389 L 0 .027 .126 r
F
.43915 .14007 m .43731 .13789 L .44049 .13672 L F
.5933 .13987 m .59489 .1364 L .59656 .13869 L 0 .026 .125 r
F
.5933 .13987 m .59162 .13759 L .59489 .1364 L F
.39323 .13987 m .39449 .13652 L .39638 .13873 L 0 .027 .126 r
F
.39323 .13987 m .39134 .13765 L .39449 .13652 L F
.49326 .13996 m .49469 .13649 L .49647 .13867 L F
.49326 .13996 m .49148 .13778 L .49469 .13649 L F
.70972 .13906 m .71151 .13558 L .71305 .13784 L 0 .025 .124 r
F
.70972 .13906 m .70817 .13681 L .71151 .13558 L F
.50146 .13954 m .5029 .13606 L .50467 .13824 L 0 .026 .125 r
F
.50146 .13954 m .49968 .13736 L .5029 .13606 L F
.53919 .14029 m .54069 .13665 L .54242 .139 L 0 .027 .126 r
F
.53919 .14029 m .53746 .13794 L .54069 .13665 L F
.50965 .13918 m .5111 .13563 L .51286 .13787 L 0 .025 .124 r
F
.50965 .13918 m .50788 .13694 L .5111 .13563 L F
.44734 .13992 m .44869 .13652 L .45052 .13871 L 0 .027 .126 r
F
.44734 .13992 m .4455 .13774 L .44869 .13652 L F
.65562 .1395 m .65731 .13598 L .65892 .13831 L 0 .026 .125 r
F
.65562 .1395 m .65401 .13716 L .65731 .13598 L F
.40141 .13978 m .40268 .13645 L .40456 .13863 L 0 .027 .126 r
F
.40141 .13978 m .39952 .13759 L .40268 .13645 L F
.71793 .1389 m .71974 .1355 L .72127 .13773 L 0 .025 .124 r
F
.71793 .1389 m .71639 .13667 L .71974 .1355 L F
.6015 .13982 m .6031 .13623 L .60477 .13854 L 0 .027 .126 r
F
.6015 .13982 m .59983 .13752 L .6031 .13623 L F
.54738 .14006 m .5489 .13647 L .55062 .13881 L F
.54738 .14006 m .54566 .13771 L .5489 .13647 L F
.45552 .13965 m .45689 .13612 L .45871 .13837 L F
.45552 .13965 m .4537 .13741 L .45689 .13612 L F
.51784 .13903 m .5193 .13553 L .52106 .13789 L 0 .026 .124 r
F
.51784 .13903 m .51608 .13667 L .5193 .13553 L F
.6097 .13951 m .61131 .13588 L .61297 .13818 L 0 .026 .125 r
F
.6097 .13951 m .60804 .13721 L .61131 .13588 L F
.55557 .13975 m .55711 .13635 L .55882 .1385 L 0 .027 .126 r
F
.55557 .13975 m .55386 .13758 L .55711 .13635 L F
.46371 .13934 m .46509 .13577 L .4669 .13804 L 0 .026 .125 r
F
.46371 .13934 m .4619 .13708 L .46509 .13577 L F
.72614 .13867 m .72795 .13515 L .72947 .13737 L 0 .025 .124 r
F
.72614 .13867 m .72461 .13645 L .72795 .13515 L F
.61789 .13914 m .61953 .13568 L .62117 .13789 L 0 .026 .125 r
F
.61789 .13914 m .61625 .13693 L .61953 .13568 L F
.40959 .13961 m .41088 .13606 L .41275 .13832 L 0 .027 .126 r
F
.40959 .13961 m .40772 .13736 L .41088 .13606 L F
.66383 .13944 m .66554 .13592 L .66713 .13824 L 0 .026 .126 r
F
.66383 .13944 m .66222 .13711 L .66554 .13592 L F
.56377 .13944 m .56531 .13605 L .56702 .13823 L 0 .027 .126 r
F
.56377 .13944 m .56206 .13728 L .56531 .13605 L F
.73434 .13835 m .73617 .13494 L .73769 .13718 L 0 .025 .123 r
F
.73434 .13835 m .73282 .1361 L .73617 .13494 L F
.4719 .13904 m .47329 .13556 L .4751 .13785 L 0 .026 .125 r
F
.4719 .13904 m .4701 .13675 L .47329 .13556 L F
.62609 .13888 m .62774 .13544 L .62938 .13769 L F
.62609 .13888 m .62445 .13665 L .62774 .13544 L F
.41777 .1394 m .41908 .13573 L .42094 .13812 L F
.41777 .1394 m .41591 .13703 L .41908 .13573 L F
.67203 .13921 m .67375 .13561 L .67534 .13788 L F
.67203 .13921 m .67044 .13693 L .67375 .13561 L F
.57196 .13922 m .57352 .13568 L .57522 .13793 L F
.57196 .13922 m .57027 .13697 L .57352 .13568 L F
.68023 .13886 m .68197 .13537 L .68355 .13766 L F
.68023 .13886 m .67865 .13659 L .68197 .13537 L F
.52603 .1391 m .52751 .13558 L .52925 .13794 L F
.52603 .1391 m .52428 .13675 L .52751 .13558 L F
.74256 .13826 m .7444 .13479 L .74591 .13703 L 0 .025 .124 r
F
.74256 .13826 m .74105 .13601 L .7444 .13479 L F
.48009 .13897 m .48149 .13548 L .48329 .13779 L 0 .026 .125 r
F
.48009 .13897 m .47829 .13666 L .48149 .13548 L F
.58016 .13897 m .58173 .13544 L .58342 .13775 L F
.58016 .13897 m .57847 .13664 L .58173 .13544 L F
.42596 .13922 m .42727 .13561 L .42912 .138 L 0 .026 .126 r
F
.42596 .13922 m .42411 .13683 L .42727 .13561 L F
.6343 .13877 m .63596 .13522 L .63758 .1375 L 0 .026 .125 r
F
.6343 .13877 m .63267 .13649 L .63596 .13522 L F
.75077 .13802 m .75262 .13452 L .75412 .13676 L 0 .025 .123 r
F
.75077 .13802 m .74927 .13578 L .75262 .13452 L F
.6425 .13849 m .64417 .13496 L .64579 .13723 L 0 .026 .124 r
F
.6425 .13849 m .64087 .13622 L .64417 .13496 L F
.68844 .13874 m .69019 .13516 L .69176 .13746 L 0 .026 .125 r
F
.68844 .13874 m .68687 .13645 L .69019 .13516 L F
.58836 .13881 m .58995 .13533 L .59162 .13759 L F
.58836 .13881 m .58668 .13654 L .58995 .13533 L F
.43414 .13907 m .43547 .13565 L .43731 .13789 L 0 .027 .126 r
F
.43414 .13907 m .43229 .13682 L .43547 .13565 L F
.69664 .13839 m .6984 .13483 L .69996 .1371 L 0 .025 .124 r
F
.69664 .13839 m .69508 .13615 L .6984 .13483 L F
.53422 .13914 m .53572 .13558 L .53746 .13794 L 0 .027 .126 r
F
.53422 .13914 m .53249 .13678 L .53572 .13558 L F
.48828 .13894 m .4897 .13546 L .49148 .13778 L F
.48828 .13894 m .48649 .13663 L .4897 .13546 L F
.70484 .13807 m .70662 .13456 L .70817 .13681 L 0 .025 .124 r
F
.70484 .13807 m .70329 .13583 L .70662 .13456 L F
.6507 .13833 m .6524 .13493 L .65401 .13716 L 0 .026 .125 r
F
.6507 .13833 m .64909 .13608 L .6524 .13493 L F
.49647 .13867 m .4979 .13517 L .49968 .13736 L 0 .026 .126 r
F
.49647 .13867 m .49469 .13649 L .4979 .13517 L F
.44233 .1389 m .44367 .13555 L .4455 .13774 L 0 .027 .126 r
F
.44233 .1389 m .44049 .13672 L .44367 .13555 L F
.59656 .13869 m .59816 .13522 L .59983 .13752 L F
.59656 .13869 m .59489 .1364 L .59816 .13522 L F
.50467 .13824 m .50611 .13475 L .50788 .13694 L 0 .026 .125 r
F
.50467 .13824 m .5029 .13606 L .50611 .13475 L F
.39638 .13873 m .39764 .13539 L .39952 .13759 L 0 .027 .126 r
F
.39638 .13873 m .39449 .13652 L .39764 .13539 L F
.71305 .13784 m .71485 .13439 L .71639 .13667 L 0 .025 .124 r
F
.71305 .13784 m .71151 .13558 L .71485 .13439 L F
.54242 .139 m .54393 .13535 L .54566 .13771 L 0 .027 .126 r
F
.54242 .139 m .54069 .13665 L .54393 .13535 L F
.51286 .13787 m .51432 .13442 L .51608 .13667 L 0 .025 .124 r
F
.51286 .13787 m .5111 .13563 L .51432 .13442 L F
.45052 .13871 m .45187 .13521 L .4537 .13741 L 0 .027 .126 r
F
.45052 .13871 m .44869 .13652 L .45187 .13521 L F
.65892 .13831 m .66062 .13479 L .66222 .13711 L 0 .026 .125 r
F
.65892 .13831 m .65731 .13598 L .66062 .13479 L F
.60477 .13854 m .60638 .13488 L .60804 .13721 L F
.60477 .13854 m .6031 .13623 L .60638 .13488 L F
.55062 .13881 m .55214 .13525 L .55386 .13758 L 0 .027 .126 r
F
.55062 .13881 m .5489 .13647 L .55214 .13525 L F
.45871 .13837 m .46008 .13481 L .4619 .13708 L 0 .026 .125 r
F
.45871 .13837 m .45689 .13612 L .46008 .13481 L F
.40456 .13863 m .40584 .13517 L .40772 .13736 L 0 .027 .126 r
F
.40456 .13863 m .40268 .13645 L .40584 .13517 L F
.72127 .13773 m .72308 .13422 L .72461 .13645 L 0 .025 .124 r
F
.72127 .13773 m .71974 .1355 L .72308 .13422 L F
.61297 .13818 m .61459 .13462 L .61625 .13693 L 0 .026 .125 r
F
.61297 .13818 m .61131 .13588 L .61459 .13462 L F
.4669 .13804 m .46829 .13447 L .4701 .13675 L F
.4669 .13804 m .46509 .13577 L .46829 .13447 L F
.55882 .1385 m .56036 .13511 L .56206 .13728 L 0 .027 .126 r
F
.55882 .1385 m .55711 .13635 L .56036 .13511 L F
.72947 .13737 m .7313 .13388 L .73282 .1361 L 0 .025 .123 r
F
.72947 .13737 m .72795 .13515 L .7313 .13388 L F
.41275 .13832 m .41404 .13476 L .41591 .13703 L 0 .026 .125 r
F
.41275 .13832 m .41088 .13606 L .41404 .13476 L F
.52106 .13789 m .52253 .13439 L .52428 .13675 L F
.52106 .13789 m .5193 .13553 L .52253 .13439 L F
.62117 .13789 m .62281 .13442 L .62445 .13665 L F
.62117 .13789 m .61953 .13568 L .62281 .13442 L F
.56702 .13823 m .56857 .13478 L .57027 .13697 L 0 .027 .126 r
F
.56702 .13823 m .56531 .13605 L .56857 .13478 L F
.66713 .13824 m .66885 .13463 L .67044 .13693 L 0 .026 .125 r
F
.66713 .13824 m .66554 .13592 L .66885 .13463 L F
.4751 .13785 m .47649 .13437 L .47829 .13666 L F
.4751 .13785 m .47329 .13556 L .47649 .13437 L F
.73769 .13718 m .73953 .13377 L .74105 .13601 L 0 .025 .123 r
F
.73769 .13718 m .73617 .13494 L .73953 .13377 L F
.67534 .13788 m .67706 .13433 L .67865 .13659 L 0 .026 .125 r
F
.67534 .13788 m .67375 .13561 L .67706 .13433 L F
.42094 .13812 m .42225 .13443 L .42411 .13683 L F
.42094 .13812 m .41908 .13573 L .42225 .13443 L F
.62938 .13769 m .63103 .13422 L .63267 .13649 L F
.62938 .13769 m .62774 .13544 L .63103 .13422 L F
.57522 .13793 m .57678 .13438 L .57847 .13664 L F
.57522 .13793 m .57352 .13568 L .57678 .13438 L F
.68355 .13766 m .68529 .13415 L .68687 .13645 L F
.68355 .13766 m .68197 .13537 L .68529 .13415 L F
.52925 .13794 m .53074 .1344 L .53249 .13678 L 0 .026 .126 r
F
.52925 .13794 m .52751 .13558 L .53074 .1344 L F
.74591 .13703 m .74776 .13354 L .74927 .13578 L 0 .025 .123 r
F
.74591 .13703 m .7444 .13479 L .74776 .13354 L F
.63758 .1375 m .63925 .13393 L .64087 .13622 L 0 .026 .124 r
F
.63758 .1375 m .63596 .13522 L .63925 .13393 L F
.58342 .13775 m .585 .13425 L .58668 .13654 L 0 .026 .125 r
F
.58342 .13775 m .58173 .13544 L .585 .13425 L F
.42912 .138 m .43045 .13444 L .43229 .13682 L 0 .027 .126 r
F
.42912 .138 m .42727 .13561 L .43045 .13444 L F
.48329 .13779 m .4847 .13431 L .48649 .13663 L 0 .026 .125 r
F
.48329 .13779 m .48149 .13548 L .4847 .13431 L F
.64579 .13723 m .64748 .13383 L .64909 .13608 L 0 .026 .124 r
F
.64579 .13723 m .64417 .13496 L .64748 .13383 L F
.69176 .13746 m .69351 .13383 L .69508 .13615 L 0 .026 .125 r
F
.69176 .13746 m .69019 .13516 L .69351 .13383 L F
.69996 .1371 m .70173 .13356 L .70329 .13583 L 0 .025 .124 r
F
.69996 .1371 m .6984 .13483 L .70173 .13356 L F
.59162 .13759 m .59322 .13415 L .59489 .1364 L 0 .026 .125 r
F
.59162 .13759 m .58995 .13533 L .59322 .13415 L F
.43731 .13789 m .43864 .13448 L .44049 .13672 L 0 .027 .126 r
F
.43731 .13789 m .43547 .13565 L .43864 .13448 L F
.53746 .13794 m .53896 .13429 L .54069 .13665 L F
.53746 .13794 m .53572 .13558 L .53896 .13429 L F
.70817 .13681 m .70996 .13332 L .71151 .13558 L 0 .025 .124 r
F
.70817 .13681 m .70662 .13456 L .70996 .13332 L F
.49148 .13778 m .49291 .13416 L .49469 .13649 L 0 .027 .126 r
F
.49148 .13778 m .4897 .13546 L .49291 .13416 L F
.49968 .13736 m .50112 .13385 L .5029 .13606 L 0 .026 .125 r
F
.49968 .13736 m .4979 .13517 L .50112 .13385 L F
.65401 .13716 m .65571 .13375 L .65731 .13598 L F
.65401 .13716 m .6524 .13493 L .65571 .13375 L F
.50788 .13694 m .50933 .13345 L .5111 .13563 L 0 .025 .124 r
F
.50788 .13694 m .50611 .13475 L .50933 .13345 L F
.54566 .13771 m .54717 .13412 L .5489 .13647 L 0 .027 .126 r
F
.54566 .13771 m .54393 .13535 L .54717 .13412 L F
.4455 .13774 m .44685 .13433 L .44869 .13652 L F
.4455 .13774 m .44367 .13555 L .44685 .13433 L F
.59983 .13752 m .60144 .13392 L .6031 .13623 L 0 .026 .126 r
F
.59983 .13752 m .59816 .13522 L .60144 .13392 L F
.51608 .13667 m .51755 .13327 L .5193 .13553 L 0 .025 .124 r
F
.51608 .13667 m .51432 .13442 L .51755 .13327 L F
.71639 .13667 m .7182 .1332 L .71974 .1355 L F
.71639 .13667 m .71485 .13439 L .7182 .1332 L F
.39952 .13759 m .40079 .13426 L .40268 .13645 L 0 .027 .126 r
F
.39952 .13759 m .39764 .13539 L .40079 .13426 L F
.4537 .13741 m .45506 .1339 L .45689 .13612 L F
.4537 .13741 m .45187 .13521 L .45506 .1339 L F
.60804 .13721 m .60965 .13354 L .61131 .13588 L 0 .026 .125 r
F
.60804 .13721 m .60638 .13488 L .60965 .13354 L F
.4619 .13708 m .46328 .13349 L .46509 .13577 L F
.4619 .13708 m .46008 .13481 L .46328 .13349 L F
.66222 .13711 m .66393 .1336 L .66554 .13592 L F
.66222 .13711 m .66062 .13479 L .66393 .1336 L F
.55386 .13758 m .55539 .13402 L .55711 .13635 L 0 .027 .126 r
F
.55386 .13758 m .55214 .13525 L .55539 .13402 L F
.72461 .13645 m .72642 .13292 L .72795 .13515 L 0 .025 .124 r
F
.72461 .13645 m .72308 .13422 L .72642 .13292 L F
.40772 .13736 m .409 .13387 L .41088 .13606 L 0 .027 .126 r
F
.40772 .13736 m .40584 .13517 L .409 .13387 L F
.61625 .13693 m .61788 .13337 L .61953 .13568 L 0 .026 .125 r
F
.61625 .13693 m .61459 .13462 L .61788 .13337 L F
.4701 .13675 m .47149 .13329 L .47329 .13556 L F
.4701 .13675 m .46829 .13447 L .47149 .13329 L F
.73282 .1361 m .73466 .13273 L .73617 .13494 L 0 .025 .123 r
F
.73282 .1361 m .7313 .13388 L .73466 .13273 L F
.41591 .13703 m .41721 .13346 L .41908 .13573 L 0 .026 .125 r
F
.41591 .13703 m .41404 .13476 L .41721 .13346 L F
.56206 .13728 m .56361 .13386 L .56531 .13605 L 0 .027 .126 r
F
.56206 .13728 m .56036 .13511 L .56361 .13386 L F
.62445 .13665 m .6261 .13318 L .62774 .13544 L 0 .026 .125 r
F
.62445 .13665 m .62281 .13442 L .6261 .13318 L F
.67044 .13693 m .67216 .13333 L .67375 .13561 L F
.67044 .13693 m .66885 .13463 L .67216 .13333 L F
.57027 .13697 m .57182 .13348 L .57352 .13568 L F
.57027 .13697 m .56857 .13478 L .57182 .13348 L F
.52428 .13675 m .52576 .13321 L .52751 .13558 L F
.52428 .13675 m .52253 .13439 L .52576 .13321 L F
.67865 .13659 m .68039 .13312 L .68197 .13537 L F
.67865 .13659 m .67706 .13433 L .68039 .13312 L F
.42411 .13683 m .42542 .13321 L .42727 .13561 L F
.42411 .13683 m .42225 .13443 L .42542 .13321 L F
.57847 .13664 m .58004 .13319 L .58173 .13544 L F
.57847 .13664 m .57678 .13438 L .58004 .13319 L F
.47829 .13666 m .4797 .13319 L .48149 .13548 L F
.47829 .13666 m .47649 .13437 L .4797 .13319 L F
.74105 .13601 m .74289 .13256 L .7444 .13479 L 0 .025 .124 r
F
.74105 .13601 m .73953 .13377 L .74289 .13256 L F
.63267 .13649 m .63432 .13293 L .63596 .13522 L 0 .026 .125 r
F
.63267 .13649 m .63103 .13422 L .63432 .13293 L F
.64087 .13622 m .64255 .13267 L .64417 .13496 L 0 .025 .124 r
F
.64087 .13622 m .63925 .13393 L .64255 .13267 L F
.68687 .13645 m .68861 .13285 L .69019 .13516 L 0 .026 .125 r
F
.68687 .13645 m .68529 .13415 L .68861 .13285 L F
.74927 .13578 m .75112 .13228 L .75262 .13452 L 0 .025 .123 r
F
.74927 .13578 m .74776 .13354 L .75112 .13228 L F
.58668 .13654 m .58827 .13307 L .58995 .13533 L 0 .026 .125 r
F
.58668 .13654 m .585 .13425 L .58827 .13307 L F
.53249 .13678 m .53398 .1332 L .53572 .13558 L 0 .027 .126 r
F
.53249 .13678 m .53074 .1344 L .53398 .1332 L F
.43229 .13682 m .43362 .13327 L .43547 .13565 L F
.43229 .13682 m .43045 .13444 L .43362 .13327 L F
.69508 .13615 m .69684 .13251 L .6984 .13483 L 0 .025 .124 r
F
.69508 .13615 m .69351 .13383 L .69684 .13251 L F
.48649 .13663 m .48791 .13314 L .4897 .13546 L 0 .027 .126 r
F
.48649 .13663 m .4847 .13431 L .48791 .13314 L F
.70329 .13583 m .70507 .13229 L .70662 .13456 L 0 .025 .124 r
F
.70329 .13583 m .70173 .13356 L .70507 .13229 L F
.64909 .13608 m .65079 .13269 L .6524 .13493 L 0 .026 .125 r
F
.64909 .13608 m .64748 .13383 L .65079 .13269 L F
.59489 .1364 m .59649 .13296 L .59816 .13522 L 0 .026 .126 r
F
.59489 .1364 m .59322 .13415 L .59649 .13296 L F
.54069 .13665 m .5422 .133 L .54393 .13535 L 0 .027 .126 r
F
.54069 .13665 m .53896 .13429 L .5422 .133 L F
.49469 .13649 m .49612 .13283 L .4979 .13517 L 0 .026 .125 r
F
.49469 .13649 m .49291 .13416 L .49612 .13283 L F
.44049 .13672 m .44183 .13332 L .44367 .13555 L 0 .027 .127 r
F
.44049 .13672 m .43864 .13448 L .44183 .13332 L F
.71151 .13558 m .7133 .1321 L .71485 .13439 L 0 .025 .124 r
F
.71151 .13558 m .70996 .13332 L .7133 .1321 L F
.5029 .13606 m .50434 .13255 L .50611 .13475 L 0 .026 .125 r
F
.5029 .13606 m .50112 .13385 L .50434 .13255 L F
.5111 .13563 m .51256 .13222 L .51432 .13442 L 0 .025 .124 r
F
.5111 .13563 m .50933 .13345 L .51256 .13222 L F
.65731 .13598 m .65902 .13255 L .66062 .13479 L 0 .026 .125 r
F
.65731 .13598 m .65571 .13375 L .65902 .13255 L F
.6031 .13623 m .60471 .13257 L .60638 .13488 L F
.6031 .13623 m .60144 .13392 L .60471 .13257 L F
.5489 .13647 m .55042 .1329 L .55214 .13525 L 0 .027 .126 r
F
.5489 .13647 m .54717 .13412 L .55042 .1329 L F
.44869 .13652 m .45004 .13302 L .45187 .13521 L F
.44869 .13652 m .44685 .13433 L .45004 .13302 L F
.61131 .13588 m .61294 .13229 L .61459 .13462 L 0 .026 .125 r
F
.61131 .13588 m .60965 .13354 L .61294 .13229 L F
.45689 .13612 m .45826 .13259 L .46008 .13481 L F
.45689 .13612 m .45506 .1339 L .45826 .13259 L F
.71974 .1355 m .72154 .13191 L .72308 .13422 L 0 .025 .124 r
F
.71974 .1355 m .7182 .1332 L .72154 .13191 L F
.5193 .13553 m .52078 .13212 L .52253 .13439 L 0 .026 .124 r
F
.5193 .13553 m .51755 .13327 L .52078 .13212 L F
.40268 .13645 m .40395 .13298 L .40584 .13517 L 0 .027 .126 r
F
.40268 .13645 m .40079 .13426 L .40395 .13298 L F
.46509 .13577 m .46648 .13218 L .46829 .13447 L 0 .026 .125 r
F
.46509 .13577 m .46328 .13349 L .46648 .13218 L F
.72795 .13515 m .72977 .13166 L .7313 .13388 L 0 .025 .123 r
F
.72795 .13515 m .72642 .13292 L .72977 .13166 L F
.41088 .13606 m .41217 .13256 L .41404 .13476 L 0 .026 .126 r
F
.41088 .13606 m .409 .13387 L .41217 .13256 L F
.55711 .13635 m .55864 .13276 L .56036 .13511 L 0 .027 .126 r
F
.55711 .13635 m .55539 .13402 L .55864 .13276 L F
.61953 .13568 m .62116 .13211 L .62281 .13442 L 0 .026 .125 r
F
.61953 .13568 m .61788 .13337 L .62116 .13211 L F
.66554 .13592 m .66725 .13232 L .66885 .13463 L F
.66554 .13592 m .66393 .1336 L .66725 .13232 L F
.41908 .13573 m .42039 .13215 L .42225 .13443 L F
.41908 .13573 m .41721 .13346 L .42039 .13215 L F
.47329 .13556 m .47469 .13212 L .47649 .13437 L F
.47329 .13556 m .47149 .13329 L .47469 .13212 L F
.56531 .13605 m .56686 .13258 L .56857 .13478 L 0 .027 .126 r
F
.56531 .13605 m .56361 .13386 L .56686 .13258 L F
.67375 .13561 m .67548 .13207 L .67706 .13433 L 0 .026 .125 r
F
.67375 .13561 m .67216 .13333 L .67548 .13207 L F
.73617 .13494 m .73802 .13157 L .73953 .13377 L 0 .025 .124 r
F
.73617 .13494 m .73466 .13273 L .73802 .13157 L F
.62774 .13544 m .62939 .13193 L .63103 .13422 L 0 .026 .125 r
F
.62774 .13544 m .6261 .13318 L .62939 .13193 L F
.57352 .13568 m .57509 .13217 L .57678 .13438 L F
.57352 .13568 m .57182 .13348 L .57509 .13217 L F
.52751 .13558 m .529 .13202 L .53074 .1344 L F
.52751 .13558 m .52576 .13321 L .529 .13202 L F
.68197 .13537 m .68371 .13191 L .68529 .13415 L F
.68197 .13537 m .68039 .13312 L .68371 .13191 L F
.42727 .13561 m .4286 .13205 L .43045 .13444 L F
.42727 .13561 m .42542 .13321 L .4286 .13205 L F
.58173 .13544 m .58331 .13201 L .585 .13425 L F
.58173 .13544 m .58004 .13319 L .58331 .13201 L F
.63596 .13522 m .63762 .13163 L .63925 .13393 L 0 .026 .124 r
F
.63596 .13522 m .63432 .13293 L .63762 .13163 L F
.7444 .13479 m .74625 .1313 L .74776 .13354 L 0 .025 .124 r
F
.7444 .13479 m .74289 .13256 L .74625 .1313 L F
.48149 .13548 m .4829 .13202 L .4847 .13431 L 0 .026 .125 r
F
.48149 .13548 m .4797 .13319 L .4829 .13202 L F
.69019 .13516 m .69194 .13151 L .69351 .13383 L 0 .026 .124 r
F
.69019 .13516 m .68861 .13285 L .69194 .13151 L F
.64417 .13496 m .64586 .13154 L .64748 .13383 L F
.64417 .13496 m .64255 .13267 L .64586 .13154 L F
.6984 .13483 m .70017 .13124 L .70173 .13356 L 0 .025 .124 r
F
.6984 .13483 m .69684 .13251 L .70017 .13124 L F
.58995 .13533 m .59154 .13189 L .59322 .13415 L 0 .026 .125 r
F
.58995 .13533 m .58827 .13307 L .59154 .13189 L F
.53572 .13558 m .53722 .13194 L .53896 .13429 L 0 .027 .126 r
F
.53572 .13558 m .53398 .1332 L .53722 .13194 L F
.43547 .13565 m .4368 .13211 L .43864 .13448 L F
.43547 .13565 m .43362 .13327 L .4368 .13211 L F
.4897 .13546 m .49112 .13183 L .49291 .13416 L 0 .026 .126 r
F
.4897 .13546 m .48791 .13314 L .49112 .13183 L F
.70662 .13456 m .70841 .13103 L .70996 .13332 L 0 .025 .124 r
F
.70662 .13456 m .70507 .13229 L .70841 .13103 L F
.54393 .13535 m .54544 .13178 L .54717 .13412 L 0 .027 .126 r
F
.54393 .13535 m .5422 .133 L .54544 .13178 L F
.6524 .13493 m .6541 .13152 L .65571 .13375 L 0 .026 .125 r
F
.6524 .13493 m .65079 .13269 L .6541 .13152 L F
.4979 .13517 m .49934 .13151 L .50112 .13385 L F
.4979 .13517 m .49612 .13283 L .49934 .13151 L F
.50611 .13475 m .50756 .13124 L .50933 .13345 L 0 .026 .124 r
F
.50611 .13475 m .50434 .13255 L .50756 .13124 L F
.59816 .13522 m .59977 .13168 L .60144 .13392 L 0 .026 .126 r
F
.59816 .13522 m .59649 .13296 L .59977 .13168 L F
.71485 .13439 m .71665 .13088 L .7182 .1332 L 0 .025 .124 r
F
.71485 .13439 m .7133 .1321 L .71665 .13088 L F
.44367 .13555 m .44501 .1321 L .44685 .13433 L 0 .027 .127 r
F
.44367 .13555 m .44183 .13332 L .44501 .1321 L F
.51432 .13442 m .51579 .13105 L .51755 .13327 L 0 .025 .124 r
F
.51432 .13442 m .51256 .13222 L .51579 .13105 L F
.60638 .13488 m .60799 .13123 L .60965 .13354 L 0 .026 .125 r
F
.60638 .13488 m .60471 .13257 L .60799 .13123 L F
.45187 .13521 m .45323 .1317 L .45506 .1339 L 0 .027 .126 r
F
.45187 .13521 m .45004 .13302 L .45323 .1317 L F
.66062 .13479 m .66233 .13135 L .66393 .1336 L 0 .026 .125 r
F
.66062 .13479 m .65902 .13255 L .66233 .13135 L F
.55214 .13525 m .55367 .13167 L .55539 .13402 L 0 .027 .126 r
F
.55214 .13525 m .55042 .1329 L .55367 .13167 L F
.46008 .13481 m .46146 .13127 L .46328 .13349 L 0 .026 .125 r
F
.46008 .13481 m .45826 .13259 L .46146 .13127 L F
.61459 .13462 m .61622 .13103 L .61788 .13337 L F
.61459 .13462 m .61294 .13229 L .61622 .13103 L F
.72308 .13422 m .72488 .1306 L .72642 .13292 L 0 .025 .124 r
F
.72308 .13422 m .72154 .13191 L .72488 .1306 L F
.46829 .13447 m .46968 .13102 L .47149 .13329 L 0 .026 .125 r
F
.46829 .13447 m .46648 .13218 L .46968 .13102 L F
.40584 .13517 m .40712 .13166 L .409 .13387 L 0 .027 .126 r
F
.40584 .13517 m .40395 .13298 L .40712 .13166 L F
.41404 .13476 m .41534 .13125 L .41721 .13346 L 0 .026 .125 r
F
.41404 .13476 m .41217 .13256 L .41534 .13125 L F
.7313 .13388 m .73313 .13051 L .73466 .13273 L 0 .025 .124 r
F
.7313 .13388 m .72977 .13166 L .73313 .13051 L F
.52253 .13439 m .52401 .13092 L .52576 .13321 L 0 .026 .125 r
F
.52253 .13439 m .52078 .13212 L .52401 .13092 L F
.66885 .13463 m .67056 .13105 L .67216 .13333 L F
.66885 .13463 m .66725 .13232 L .67056 .13105 L F
.56036 .13511 m .5619 .1315 L .56361 .13386 L 0 .027 .126 r
F
.56036 .13511 m .55864 .13276 L .5619 .1315 L F
.62281 .13442 m .62446 .13085 L .6261 .13318 L 0 .026 .125 r
F
.62281 .13442 m .62116 .13211 L .62446 .13085 L F
.42225 .13443 m .42356 .13093 L .42542 .13321 L F
.42225 .13443 m .42039 .13215 L .42356 .13093 L F
.56857 .13478 m .57012 .13127 L .57182 .13348 L 0 .027 .126 r
F
.56857 .13478 m .56686 .13258 L .57012 .13127 L F
.67706 .13433 m .6788 .13088 L .68039 .13312 L 0 .026 .125 r
F
.67706 .13433 m .67548 .13207 L .6788 .13088 L F
.47649 .13437 m .47789 .13094 L .4797 .13319 L F
.47649 .13437 m .47469 .13212 L .47789 .13094 L F
.57678 .13438 m .57835 .13098 L .58004 .13319 L F
.57678 .13438 m .57509 .13217 L .57835 .13098 L F
.63103 .13422 m .63269 .13063 L .63432 .13293 L 0 .026 .124 r
F
.63103 .13422 m .62939 .13193 L .63269 .13063 L F
.73953 .13377 m .74138 .13035 L .74289 .13256 L 0 .025 .124 r
F
.73953 .13377 m .73802 .13157 L .74138 .13035 L F
.68529 .13415 m .68704 .1306 L .68861 .13285 L 0 .026 .125 r
F
.68529 .13415 m .68371 .13191 L .68704 .1306 L F
.63925 .13393 m .64092 .13035 L .64255 .13267 L 0 .025 .124 r
F
.63925 .13393 m .63762 .13163 L .64092 .13035 L F
.53074 .1344 m .53224 .13082 L .53398 .1332 L 0 .026 .125 r
F
.53074 .1344 m .529 .13202 L .53224 .13082 L F
.43045 .13444 m .43177 .13089 L .43362 .13327 L F
.43045 .13444 m .4286 .13205 L .43177 .13089 L F
.74776 .13354 m .74962 .13005 L .75112 .13228 L 0 .025 .123 r
F
.74776 .13354 m .74625 .1313 L .74962 .13005 L F
.585 .13425 m .58658 .13083 L .58827 .13307 L 0 .026 .125 r
F
.585 .13425 m .58331 .13201 L .58658 .13083 L F
.69351 .13383 m .69527 .13018 L .69684 .13251 L 0 .025 .124 r
F
.69351 .13383 m .69194 .13151 L .69527 .13018 L F
.4847 .13431 m .48612 .13085 L .48791 .13314 L 0 .026 .125 r
F
.4847 .13431 m .4829 .13202 L .48612 .13085 L F
.70173 .13356 m .70351 .12996 L .70507 .13229 L 0 .025 .124 r
F
.70173 .13356 m .70017 .13124 L .70351 .12996 L F
.64748 .13383 m .64917 .13041 L .65079 .13269 L 0 .026 .125 r
F
.64748 .13383 m .64586 .13154 L .64917 .13041 L F
.53896 .13429 m .54046 .13067 L .5422 .133 L F
.53896 .13429 m .53722 .13194 L .54046 .13067 L F
.59322 .13415 m .59482 .13071 L .59649 .13296 L 0 .026 .126 r
F
.59322 .13415 m .59154 .13189 L .59482 .13071 L F
.49291 .13416 m .49434 .13049 L .49612 .13283 L 0 .026 .125 r
F
.49291 .13416 m .49112 .13183 L .49434 .13049 L F
.70996 .13332 m .71175 .1298 L .7133 .1321 L 0 .025 .124 r
F
.70996 .13332 m .70841 .13103 L .71175 .1298 L F
.43864 .13448 m .43998 .13095 L .44183 .13332 L 0 .027 .126 r
F
.43864 .13448 m .4368 .13211 L .43998 .13095 L F
.50112 .13385 m .50257 .13021 L .50434 .13255 L 0 .026 .125 r
F
.50112 .13385 m .49934 .13151 L .50257 .13021 L F
.54717 .13412 m .54869 .13057 L .55042 .1329 L 0 .027 .126 r
F
.54717 .13412 m .54544 .13178 L .54869 .13057 L F
.50933 .13345 m .51079 .13001 L .51256 .13222 L 0 .026 .124 r
F
.50933 .13345 m .50756 .13124 L .51079 .13001 L F
.60144 .13392 m .60305 .13035 L .60471 .13257 L 0 .026 .125 r
F
.60144 .13392 m .59977 .13168 L .60305 .13035 L F
.65571 .13375 m .65741 .13031 L .65902 .13255 L F
.65571 .13375 m .6541 .13152 L .65741 .13031 L F
.60965 .13354 m .61128 .12998 L .61294 .13229 L 0 .026 .124 r
F
.60965 .13354 m .60799 .13123 L .61128 .12998 L F
.44685 .13433 m .4482 .13078 L .45004 .13302 L 0 .027 .127 r
F
.44685 .13433 m .44501 .1321 L .4482 .13078 L F
.7182 .1332 m .71999 .12958 L .72154 .13191 L 0 .025 .124 r
F
.7182 .1332 m .71665 .13088 L .71999 .12958 L F
.45506 .1339 m .45643 .13038 L .45826 .13259 L 0 .026 .126 r
F
.45506 .1339 m .45323 .1317 L .45643 .13038 L F
.46328 .13349 m .46466 .12996 L .46648 .13218 L 0 .026 .125 r
F
.46328 .13349 m .46146 .13127 L .46466 .12996 L F
.51755 .13327 m .51902 .12988 L .52078 .13212 L 0 .026 .124 r
F
.51755 .13327 m .51579 .13105 L .51902 .12988 L F
.55539 .13402 m .55692 .1304 L .55864 .13276 L 0 .027 .126 r
F
.55539 .13402 m .55367 .13167 L .55692 .1304 L F
.61788 .13337 m .61951 .12977 L .62116 .13211 L 0 .026 .124 r
F
.61788 .13337 m .61622 .13103 L .61951 .12977 L F
.66393 .1336 m .66565 .13009 L .66725 .13232 L 0 .026 .125 r
F
.66393 .1336 m .66233 .13135 L .66565 .13009 L F
.72642 .13292 m .72824 .12933 L .72977 .13166 L 0 .025 .123 r
F
.72642 .13292 m .72488 .1306 L .72824 .12933 L F
.409 .13387 m .41029 .13035 L .41217 .13256 L 0 .027 .126 r
F
.409 .13387 m .40712 .13166 L .41029 .13035 L F
.41721 .13346 m .41852 .12994 L .42039 .13215 L 0 .026 .125 r
F
.41721 .13346 m .41534 .13125 L .41852 .12994 L F
.47149 .13329 m .47288 .12986 L .47469 .13212 L F
.47149 .13329 m .46968 .13102 L .47288 .12986 L F
.67216 .13333 m .67389 .1298 L .67548 .13207 L F
.67216 .13333 m .67056 .13105 L .67389 .1298 L F
.56361 .13386 m .56515 .13021 L .56686 .13258 L 0 .027 .126 r
F
.56361 .13386 m .5619 .1315 L .56515 .13021 L F
.6261 .13318 m .62775 .12959 L .62939 .13193 L 0 .026 .124 r
F
.6261 .13318 m .62446 .13085 L .62775 .12959 L F
.73466 .13273 m .7365 .12936 L .73802 .13157 L 0 .025 .124 r
F
.73466 .13273 m .73313 .13051 L .7365 .12936 L F
.52576 .13321 m .52725 .12971 L .529 .13202 L 0 .026 .125 r
F
.52576 .13321 m .52401 .13092 L .52725 .12971 L F
.42542 .13321 m .42674 .12977 L .4286 .13205 L F
.42542 .13321 m .42356 .13093 L .42674 .12977 L F
.57182 .13348 m .57339 .12995 L .57509 .13217 L F
.57182 .13348 m .57012 .13127 L .57339 .12995 L F
.68039 .13312 m .68213 .12968 L .68371 .13191 L F
.68039 .13312 m .6788 .13088 L .68213 .12968 L F
.63432 .13293 m .63599 .12932 L .63762 .13163 L 0 .025 .124 r
F
.63432 .13293 m .63269 .13063 L .63599 .12932 L F
.58004 .13319 m .58162 .1298 L .58331 .13201 L 0 .026 .125 r
F
.58004 .13319 m .57835 .13098 L .58162 .1298 L F
.4797 .13319 m .4811 .12977 L .4829 .13202 L F
.4797 .13319 m .47789 .13094 L .4811 .12977 L F
.74289 .13256 m .74474 .12908 L .74625 .1313 L 0 .025 .124 r
F
.74289 .13256 m .74138 .13035 L .74474 .12908 L F
.68861 .13285 m .69037 .12926 L .69194 .13151 L F
.68861 .13285 m .68704 .1306 L .69037 .12926 L F
.64255 .13267 m .64423 .1292 L .64586 .13154 L F
.64255 .13267 m .64092 .13035 L .64423 .1292 L F
.69684 .13251 m .6986 .12891 L .70017 .13124 L F
.69684 .13251 m .69527 .13018 L .6986 .12891 L F
.53398 .1332 m .53548 .12958 L .53722 .13194 L 0 .026 .125 r
F
.53398 .1332 m .53224 .13082 L .53548 .12958 L F
.43362 .13327 m .43496 .12974 L .4368 .13211 L 0 .027 .126 r
F
.43362 .13327 m .43177 .13089 L .43496 .12974 L F
.58827 .13307 m .58986 .12964 L .59154 .13189 L 0 .026 .125 r
F
.58827 .13307 m .58658 .13083 L .58986 .12964 L F
.48791 .13314 m .48933 .12954 L .49112 .13183 L F
.48791 .13314 m .48612 .13085 L .48933 .12954 L F
.70507 .13229 m .70685 .1287 L .70841 .13103 L 0 .025 .124 r
F
.70507 .13229 m .70351 .12996 L .70685 .1287 L F
.5422 .133 m .54371 .12947 L .54544 .13178 L 0 .026 .125 r
F
.5422 .133 m .54046 .13067 L .54371 .12947 L F
.49612 .13283 m .49756 .12917 L .49934 .13151 L F
.49612 .13283 m .49434 .13049 L .49756 .12917 L F
.65079 .13269 m .65248 .12922 L .6541 .13152 L F
.65079 .13269 m .64917 .13041 L .65248 .12922 L F
.59649 .13296 m .5981 .12943 L .59977 .13168 L 0 .026 .126 r
F
.59649 .13296 m .59482 .13071 L .5981 .12943 L F
.50434 .13255 m .50579 .1289 L .50756 .13124 L 0 .026 .124 r
F
.50434 .13255 m .50257 .13021 L .50579 .1289 L F
.7133 .1321 m .7151 .12856 L .71665 .13088 L 0 .025 .124 r
F
.7133 .1321 m .71175 .1298 L .7151 .12856 L F
.60471 .13257 m .60633 .12901 L .60799 .13123 L 0 .026 .125 r
F
.60471 .13257 m .60305 .13035 L .60633 .12901 L F
.44183 .13332 m .44317 .12974 L .44501 .1321 L 0 .027 .127 r
F
.44183 .13332 m .43998 .13095 L .44317 .12974 L F
.55042 .1329 m .55195 .12935 L .55367 .13167 L 0 .027 .126 r
F
.55042 .1329 m .54869 .13057 L .55195 .12935 L F
.51256 .13222 m .51402 .12882 L .51579 .13105 L 0 .026 .124 r
F
.51256 .13222 m .51079 .13001 L .51402 .12882 L F
.61294 .13229 m .61457 .12872 L .61622 .13103 L F
.61294 .13229 m .61128 .12998 L .61457 .12872 L F
.65902 .13255 m .66073 .1291 L .66233 .13135 L 0 .026 .125 r
F
.65902 .13255 m .65741 .13031 L .66073 .1291 L F
.45004 .13302 m .4514 .12945 L .45323 .1317 L 0 .027 .126 r
F
.45004 .13302 m .4482 .13078 L .4514 .12945 L F
.45826 .13259 m .45963 .12906 L .46146 .13127 L 0 .026 .125 r
F
.45826 .13259 m .45643 .13038 L .45963 .12906 L F
.72154 .13191 m .72334 .12827 L .72488 .1306 L 0 .025 .123 r
F
.72154 .13191 m .71999 .12958 L .72334 .12827 L F
.46648 .13218 m .46786 .12879 L .46968 .13102 L 0 .026 .125 r
F
.46648 .13218 m .46466 .12996 L .46786 .12879 L F
.55864 .13276 m .56018 .12913 L .5619 .1315 L 0 .027 .126 r
F
.55864 .13276 m .55692 .1304 L .56018 .12913 L F
.66725 .13232 m .66897 .12883 L .67056 .13105 L 0 .026 .125 r
F
.66725 .13232 m .66565 .13009 L .66897 .12883 L F
.41217 .13256 m .41347 .12904 L .41534 .13125 L F
.41217 .13256 m .41029 .13035 L .41347 .12904 L F
.62116 .13211 m .62281 .1285 L .62446 .13085 L 0 .026 .124 r
F
.62116 .13211 m .61951 .12977 L .62281 .1285 L F
.72977 .13166 m .7316 .12817 L .73313 .13051 L 0 .025 .123 r
F
.72977 .13166 m .72824 .12933 L .7316 .12817 L F
.52078 .13212 m .52225 .12866 L .52401 .13092 L 0 .026 .125 r
F
.52078 .13212 m .51902 .12988 L .52225 .12866 L F
.42039 .13215 m .4217 .12872 L .42356 .13093 L F
.42039 .13215 m .41852 .12994 L .4217 .12872 L F
.67548 .13207 m .67722 .12863 L .6788 .13088 L F
.67548 .13207 m .67389 .1298 L .67722 .12863 L F
.47469 .13212 m .47609 .12869 L .47789 .13094 L F
.47469 .13212 m .47288 .12986 L .47609 .12869 L F
.56686 .13258 m .56842 .12889 L .57012 .13127 L 0 .027 .126 r
F
.56686 .13258 m .56515 .13021 L .56842 .12889 L F
.62939 .13193 m .63105 .12829 L .63269 .13063 L 0 .025 .124 r
F
.62939 .13193 m .62775 .12959 L .63105 .12829 L F
.57509 .13217 m .57666 .12876 L .57835 .13098 L 0 .026 .125 r
F
.57509 .13217 m .57339 .12995 L .57666 .12876 L F
.529 .13202 m .53049 .1285 L .53224 .13082 L F
.529 .13202 m .52725 .12971 L .53049 .1285 L F
.73802 .13157 m .73986 .12813 L .74138 .13035 L 0 .025 .124 r
F
.73802 .13157 m .7365 .12936 L .73986 .12813 L F
.4286 .13205 m .42992 .12862 L .43177 .13089 L 0 .026 .125 r
F
.4286 .13205 m .42674 .12977 L .42992 .12862 L F
.63762 .13163 m .63929 .12803 L .64092 .13035 L 0 .025 .124 r
F
.63762 .13163 m .63599 .12932 L .63929 .12803 L F
.68371 .13191 m .68546 .12839 L .68704 .1306 L 0 .026 .125 r
F
.68371 .13191 m .68213 .12968 L .68546 .12839 L F
.69194 .13151 m .6937 .12792 L .69527 .13018 L 0 .025 .124 r
F
.69194 .13151 m .69037 .12926 L .6937 .12792 L F
.74625 .1313 m .74811 .12782 L .74962 .13005 L F
.74625 .1313 m .74474 .12908 L .74811 .12782 L F
.58331 .13201 m .5849 .12861 L .58658 .13083 L 0 .026 .125 r
F
.58331 .13201 m .58162 .1298 L .5849 .12861 L F
.4829 .13202 m .48432 .12859 L .48612 .13085 L F
.4829 .13202 m .4811 .12977 L .48432 .12859 L F
.70017 .13124 m .70194 .12763 L .70351 .12996 L 0 .025 .123 r
F
.70017 .13124 m .6986 .12891 L .70194 .12763 L F
.53722 .13194 m .53872 .12834 L .54046 .13067 L 0 .026 .125 r
F
.53722 .13194 m .53548 .12958 L .53872 .12834 L F
.64586 .13154 m .64754 .12805 L .64917 .13041 L F
.64586 .13154 m .64423 .1292 L .64754 .12805 L F
.49112 .13183 m .49255 .1282 L .49434 .13049 L F
.49112 .13183 m .48933 .12954 L .49255 .1282 L F
.4368 .13211 m .43814 .12858 L .43998 .13095 L 0 .027 .126 r
F
.4368 .13211 m .43496 .12974 L .43814 .12858 L F
.59154 .13189 m .59314 .12845 L .59482 .13071 L F
.59154 .13189 m .58986 .12964 L .59314 .12845 L F
.70841 .13103 m .7102 .12746 L .71175 .1298 L 0 .025 .123 r
F
.70841 .13103 m .70685 .1287 L .7102 .12746 L F
.49934 .13151 m .50079 .12786 L .50257 .13021 L 0 .026 .124 r
F
.49934 .13151 m .49756 .12917 L .50079 .12786 L F
.54544 .13178 m .54696 .12829 L .54869 .13057 L 0 .026 .125 r
F
.54544 .13178 m .54371 .12947 L .54696 .12829 L F
.59977 .13168 m .60138 .12811 L .60305 .13035 L F
.59977 .13168 m .5981 .12943 L .60138 .12811 L F
.60799 .13123 m .60962 .12778 L .61128 .12998 L 0 .026 .124 r
F
.60799 .13123 m .60633 .12901 L .60962 .12778 L F
.50756 .13124 m .50902 .12766 L .51079 .13001 L 0 .025 .124 r
F
.50756 .13124 m .50579 .1289 L .50902 .12766 L F
.6541 .13152 m .6558 .128 L .65741 .13031 L 0 .026 .125 r
F
.6541 .13152 m .65248 .12922 L .6558 .128 L F
.71665 .13088 m .71845 .12725 L .71999 .12958 L 0 .025 .123 r
F
.71665 .13088 m .7151 .12856 L .71845 .12725 L F
.44501 .1321 m .44637 .12842 L .4482 .13078 L 0 .027 .126 r
F
.44501 .1321 m .44317 .12974 L .44637 .12842 L F
.55367 .13167 m .5552 .12807 L .55692 .1304 L 0 .026 .126 r
F
.55367 .13167 m .55195 .12935 L .5552 .12807 L F
.45323 .1317 m .4546 .12813 L .45643 .13038 L 0 .027 .126 r
F
.45323 .1317 m .4514 .12945 L .4546 .12813 L F
.61622 .13103 m .61786 .12746 L .61951 .12977 L 0 .025 .124 r
F
.61622 .13103 m .61457 .12872 L .61786 .12746 L F
.46146 .13127 m .46284 .12774 L .46466 .12996 L 0 .026 .125 r
F
.46146 .13127 m .45963 .12906 L .46284 .12774 L F
.51579 .13105 m .51726 .12763 L .51902 .12988 L F
.51579 .13105 m .51402 .12882 L .51726 .12763 L F
.72488 .1306 m .7267 .12699 L .72824 .12933 L 0 .025 .123 r
F
.72488 .1306 m .72334 .12827 L .7267 .12699 L F
.66233 .13135 m .66405 .12785 L .66565 .13009 L 0 .026 .125 r
F
.66233 .13135 m .66073 .1291 L .66405 .12785 L F
.46968 .13102 m .47107 .12762 L .47288 .12986 L F
.46968 .13102 m .46786 .12879 L .47107 .12762 L F
.41534 .13125 m .41665 .12773 L .41852 .12994 L F
.41534 .13125 m .41347 .12904 L .41665 .12773 L F
.5619 .1315 m .56344 .12783 L .56515 .13021 L 0 .026 .126 r
F
.5619 .1315 m .56018 .12913 L .56344 .12783 L F
.67056 .13105 m .6723 .1276 L .67389 .1298 L 0 .026 .125 r
F
.67056 .13105 m .66897 .12883 L .6723 .1276 L F
.62446 .13085 m .6261 .12723 L .62775 .12959 L 0 .025 .124 r
F
.62446 .13085 m .62281 .1285 L .6261 .12723 L F
.52401 .13092 m .52549 .12743 L .52725 .12971 L 0 .026 .125 r
F
.52401 .13092 m .52225 .12866 L .52549 .12743 L F
.42356 .13093 m .42487 .12756 L .42674 .12977 L F
.42356 .13093 m .4217 .12872 L .42487 .12756 L F
.73313 .13051 m .73497 .12701 L .7365 .12936 L 0 .025 .124 r
F
.73313 .13051 m .7316 .12817 L .73497 .12701 L F
.57012 .13127 m .57168 .12757 L .57339 .12995 L 0 .026 .125 r
F
.57012 .13127 m .56842 .12889 L .57168 .12757 L F
.63269 .13063 m .63435 .12697 L .63599 .12932 L 0 .025 .124 r
F
.63269 .13063 m .63105 .12829 L .63435 .12697 L F
.6788 .13088 m .68055 .12746 L .68213 .12968 L 0 .026 .125 r
F
.6788 .13088 m .67722 .12863 L .68055 .12746 L F
.47789 .13094 m .4793 .12751 L .4811 .12977 L F
.47789 .13094 m .47609 .12869 L .4793 .12751 L F
.57835 .13098 m .57993 .12758 L .58162 .1298 L F
.57835 .13098 m .57666 .12876 L .57993 .12758 L F
.74138 .13035 m .74323 .12686 L .74474 .12908 L 0 .025 .124 r
F
.74138 .13035 m .73986 .12813 L .74323 .12686 L F
.64092 .13035 m .6426 .12686 L .64423 .1292 L F
.64092 .13035 m .63929 .12803 L .6426 .12686 L F
.53224 .13082 m .53373 .12727 L .53548 .12958 L 0 .026 .125 r
F
.53224 .13082 m .53049 .1285 L .53373 .12727 L F
.68704 .1306 m .68879 .12705 L .69037 .12926 L 0 .026 .124 r
F
.68704 .1306 m .68546 .12839 L .68879 .12705 L F
.69527 .13018 m .69704 .12666 L .6986 .12891 L 0 .025 .124 r
F
.69527 .13018 m .6937 .12792 L .69704 .12666 L F
.43177 .13089 m .4331 .12746 L .43496 .12974 L 0 .026 .125 r
F
.43177 .13089 m .42992 .12862 L .4331 .12746 L F
.58658 .13083 m .58817 .1274 L .58986 .12964 L 0 .026 .126 r
F
.58658 .13083 m .5849 .12861 L .58817 .1274 L F
.48612 .13085 m .48754 .12729 L .48933 .12954 L 0 .026 .125 r
F
.48612 .13085 m .48432 .12859 L .48754 .12729 L F
.70351 .12996 m .70529 .12637 L .70685 .1287 L 0 .025 .123 r
F
.70351 .12996 m .70194 .12763 L .70529 .12637 L F
.54046 .13067 m .54198 .12716 L .54371 .12947 L 0 .026 .125 r
F
.54046 .13067 m .53872 .12834 L .54198 .12716 L F
.49434 .13049 m .49578 .12688 L .49756 .12917 L F
.49434 .13049 m .49255 .1282 L .49578 .12688 L F
.64917 .13041 m .65086 .12685 L .65248 .12922 L F
.64917 .13041 m .64754 .12805 L .65086 .12685 L F
.50257 .13021 m .50402 .12656 L .50579 .1289 L 0 .025 .124 r
F
.50257 .13021 m .50079 .12786 L .50402 .12656 L F
.59482 .13071 m .59642 .12718 L .5981 .12943 L 0 .027 .126 r
F
.59482 .13071 m .59314 .12845 L .59642 .12718 L F
.71175 .1298 m .71355 .12621 L .7151 .12856 L 0 .025 .123 r
F
.71175 .1298 m .7102 .12746 L .71355 .12621 L F
.43998 .13095 m .44133 .12737 L .44317 .12974 L 0 .027 .126 r
F
.43998 .13095 m .43814 .12858 L .44133 .12737 L F
.54869 .13057 m .55022 .1271 L .55195 .12935 L 0 .026 .126 r
F
.54869 .13057 m .54696 .12829 L .55022 .1271 L F
.60305 .13035 m .60466 .1268 L .60633 .12901 L 0 .026 .125 r
F
.60305 .13035 m .60138 .12811 L .60466 .1268 L F
.61128 .12998 m .61291 .12655 L .61457 .12872 L 0 .026 .124 r
F
.61128 .12998 m .60962 .12778 L .61291 .12655 L F
.51079 .13001 m .51225 .12645 L .51402 .12882 L F
.51079 .13001 m .50902 .12766 L .51225 .12645 L F
.71999 .12958 m .7218 .12594 L .72334 .12827 L 0 .025 .123 r
F
.71999 .12958 m .71845 .12725 L .7218 .12594 L F
.65741 .13031 m .65912 .12678 L .66073 .1291 L 0 .026 .125 r
F
.65741 .13031 m .6558 .128 L .65912 .12678 L F
.4482 .13078 m .44957 .12709 L .4514 .12945 L 0 .027 .126 r
F
.4482 .13078 m .44637 .12842 L .44957 .12709 L F
.45643 .13038 m .4578 .12681 L .45963 .12906 L 0 .026 .125 r
F
.45643 .13038 m .4546 .12813 L .4578 .12681 L F
.55692 .1304 m .55846 .12678 L .56018 .12913 L F
.55692 .1304 m .5552 .12807 L .55846 .12678 L F
.46466 .12996 m .46604 .12656 L .46786 .12879 L F
.46466 .12996 m .46284 .12774 L .46604 .12656 L F
.61951 .12977 m .62116 .12618 L .62281 .1285 L 0 .025 .124 r
F
.61951 .12977 m .61786 .12746 L .62116 .12618 L F
.72824 .12933 m .73006 .12582 L .7316 .12817 L 0 .025 .123 r
F
.72824 .12933 m .7267 .12699 L .73006 .12582 L F
.66565 .13009 m .66737 .12661 L .66897 .12883 L 0 .026 .125 r
F
.66565 .13009 m .66405 .12785 L .66737 .12661 L F
.51902 .12988 m .5205 .12638 L .52225 .12866 L F
.51902 .12988 m .51726 .12763 L .5205 .12638 L F
.41852 .12994 m .41982 .1265 L .4217 .12872 L F
.41852 .12994 m .41665 .12773 L .41982 .1265 L F
.56515 .13021 m .56671 .12651 L .56842 .12889 L F
.56515 .13021 m .56344 .12783 L .56671 .12651 L F
.67389 .1298 m .67563 .12642 L .67722 .12863 L F
.67389 .1298 m .6723 .1276 L .67563 .12642 L F
.62775 .12959 m .6294 .12592 L .63105 .12829 L 0 .025 .124 r
F
.62775 .12959 m .6261 .12723 L .6294 .12592 L F
.47288 .12986 m .47428 .12643 L .47609 .12869 L 0 .026 .125 r
F
.47288 .12986 m .47107 .12762 L .47428 .12643 L F
.52725 .12971 m .52874 .1262 L .53049 .1285 L F
.52725 .12971 m .52549 .12743 L .52874 .1262 L F
.57339 .12995 m .57495 .12638 L .57666 .12876 L F
.57339 .12995 m .57168 .12757 L .57495 .12638 L F
.63599 .12932 m .63765 .12568 L .63929 .12803 L 0 .025 .124 r
F
.63599 .12932 m .63435 .12697 L .63765 .12568 L F
.42674 .12977 m .42806 .1264 L .42992 .12862 L 0 .026 .125 r
F
.42674 .12977 m .42487 .12756 L .42806 .1264 L F
.7365 .12936 m .73834 .12578 L .73986 .12813 L 0 .025 .124 r
F
.7365 .12936 m .73497 .12701 L .73834 .12578 L F
.68213 .12968 m .68388 .12617 L .68546 .12839 L 0 .026 .125 r
F
.68213 .12968 m .68055 .12746 L .68388 .12617 L F
.69037 .12926 m .69213 .12571 L .6937 .12792 L 0 .025 .124 r
F
.69037 .12926 m .68879 .12705 L .69213 .12571 L F
.74474 .12908 m .7466 .12558 L .74811 .12782 L F
.74474 .12908 m .74323 .12686 L .7466 .12558 L F
.4811 .12977 m .48252 .12633 L .48432 .12859 L 0 .026 .125 r
F
.4811 .12977 m .4793 .12751 L .48252 .12633 L F
.58162 .1298 m .58321 .12639 L .5849 .12861 L 0 .027 .126 r
F
.58162 .1298 m .57993 .12758 L .58321 .12639 L F
.53548 .12958 m .53698 .12604 L .53872 .12834 L 0 .026 .125 r
F
.53548 .12958 m .53373 .12727 L .53698 .12604 L F
.6986 .12891 m .70038 .12539 L .70194 .12763 L 0 .025 .123 r
F
.6986 .12891 m .69704 .12666 L .70038 .12539 L F
.64423 .1292 m .64592 .12569 L .64754 .12805 L 0 .025 .124 r
F
.64423 .1292 m .6426 .12686 L .64592 .12569 L F
.43496 .12974 m .43629 .12629 L .43814 .12858 L 0 .027 .126 r
F
.43496 .12974 m .4331 .12746 L .43629 .12629 L F
.48933 .12954 m .49076 .12597 L .49255 .1282 L 0 .026 .125 r
F
.48933 .12954 m .48754 .12729 L .49076 .12597 L F
.70685 .1287 m .70864 .12511 L .7102 .12746 L 0 .025 .123 r
F
.70685 .1287 m .70529 .12637 L .70864 .12511 L F
.49756 .12917 m .499 .12558 L .50079 .12786 L 0 .026 .124 r
F
.49756 .12917 m .49578 .12688 L .499 .12558 L F
.58986 .12964 m .59146 .12619 L .59314 .12845 L 0 .027 .126 r
F
.58986 .12964 m .58817 .1274 L .59146 .12619 L F
.54371 .12947 m .54523 .12601 L .54696 .12829 L 0 .026 .125 r
F
.54371 .12947 m .54198 .12716 L .54523 .12601 L F
.50579 .1289 m .50725 .1253 L .50902 .12766 L 0 .025 .124 r
F
.50579 .1289 m .50402 .12656 L .50725 .1253 L F
.5981 .12943 m .5997 .12587 L .60138 .12811 L 0 .026 .125 r
F
.5981 .12943 m .59642 .12718 L .5997 .12587 L F
.65248 .12922 m .65418 .12562 L .6558 .128 L F
.65248 .12922 m .65086 .12685 L .65418 .12562 L F
.7151 .12856 m .7169 .12491 L .71845 .12725 L 0 .025 .123 r
F
.7151 .12856 m .71355 .12621 L .7169 .12491 L F
.60633 .12901 m .60796 .12558 L .60962 .12778 L 0 .026 .125 r
F
.60633 .12901 m .60466 .1268 L .60796 .12558 L F
.44317 .12974 m .44453 .12605 L .44637 .12842 L 0 .027 .126 r
F
.44317 .12974 m .44133 .12737 L .44453 .12605 L F
.55195 .12935 m .55348 .1258 L .5552 .12807 L 0 .026 .125 r
F
.55195 .12935 m .55022 .1271 L .55348 .1258 L F
.61457 .12872 m .61621 .12528 L .61786 .12746 L 0 .026 .124 r
F
.61457 .12872 m .61291 .12655 L .61621 .12528 L F
.72334 .12827 m .72516 .12465 L .7267 .12699 L 0 .024 .123 r
F
.72334 .12827 m .7218 .12594 L .72516 .12465 L F
.4514 .12945 m .45277 .12578 L .4546 .12813 L 0 .027 .126 r
F
.4514 .12945 m .44957 .12709 L .45277 .12578 L F
.51402 .12882 m .51549 .12525 L .51726 .12763 L 0 .026 .124 r
F
.51402 .12882 m .51225 .12645 L .51549 .12525 L F
.45963 .12906 m .46101 .1255 L .46284 .12774 L 0 .026 .125 r
F
.45963 .12906 m .4578 .12681 L .46101 .1255 L F
.66073 .1291 m .66244 .12555 L .66405 .12785 L F
.66073 .1291 m .65912 .12678 L .66244 .12555 L F
.56018 .12913 m .56173 .12548 L .56344 .12783 L F
.56018 .12913 m .55846 .12678 L .56173 .12548 L F
.62281 .1285 m .62445 .12489 L .6261 .12723 L 0 .025 .124 r
F
.62281 .1285 m .62116 .12618 L .62445 .12489 L F
.46786 .12879 m .46925 .12537 L .47107 .12762 L 0 .026 .125 r
F
.46786 .12879 m .46604 .12656 L .46925 .12537 L F
.66897 .12883 m .6707 .12538 L .6723 .1276 L F
.66897 .12883 m .66737 .12661 L .6707 .12538 L F
.7316 .12817 m .73343 .12465 L .73497 .12701 L 0 .025 .123 r
F
.7316 .12817 m .73006 .12582 L .73343 .12465 L F
.52225 .12866 m .52374 .12513 L .52549 .12743 L 0 .026 .125 r
F
.52225 .12866 m .5205 .12638 L .52374 .12513 L F
.56842 .12889 m .56997 .12518 L .57168 .12757 L F
.56842 .12889 m .56671 .12651 L .56997 .12518 L F
.4217 .12872 m .42301 .12534 L .42487 .12756 L F
.4217 .12872 m .41982 .1265 L .42301 .12534 L F
.63105 .12829 m .63271 .12461 L .63435 .12697 L 0 .025 .124 r
F
.63105 .12829 m .6294 .12592 L .63271 .12461 L F
.67722 .12863 m .67897 .12525 L .68055 .12746 L 0 .026 .125 r
F
.67722 .12863 m .67563 .12642 L .67897 .12525 L F
.47609 .12869 m .47749 .12523 L .4793 .12751 L F
.47609 .12869 m .47428 .12643 L .47749 .12523 L F
.63929 .12803 m .64097 .12451 L .6426 .12686 L 0 .025 .124 r
F
.63929 .12803 m .63765 .12568 L .64097 .12451 L F
.53049 .1285 m .53199 .12497 L .53373 .12727 L 0 .026 .125 r
F
.53049 .1285 m .52874 .1262 L .53199 .12497 L F
.57666 .12876 m .57823 .1252 L .57993 .12758 L F
.57666 .12876 m .57495 .12638 L .57823 .1252 L F
.73986 .12813 m .7417 .1245 L .74323 .12686 L 0 .025 .124 r
F
.73986 .12813 m .73834 .12578 L .7417 .1245 L F
.6937 .12792 m .69547 .12446 L .69704 .12666 L F
.6937 .12792 m .69213 .12571 L .69547 .12446 L F
.68546 .12839 m .68722 .12483 L .68879 .12705 L 0 .026 .125 r
F
.68546 .12839 m .68388 .12617 L .68722 .12483 L F
.42992 .12862 m .43124 .12523 L .4331 .12746 L 0 .026 .126 r
F
.42992 .12862 m .42806 .1264 L .43124 .12523 L F
.70194 .12763 m .70373 .12413 L .70529 .12637 L 0 .025 .123 r
F
.70194 .12763 m .70038 .12539 L .70373 .12413 L F
.53872 .12834 m .54024 .12486 L .54198 .12716 L 0 .026 .125 r
F
.53872 .12834 m .53698 .12604 L .54024 .12486 L F
.48432 .12859 m .48574 .12504 L .48754 .12729 L F
.48432 .12859 m .48252 .12633 L .48574 .12504 L F
.5849 .12861 m .58649 .12516 L .58817 .1274 L 0 .027 .126 r
F
.5849 .12861 m .58321 .12639 L .58649 .12516 L F
.49255 .1282 m .49399 .12466 L .49578 .12688 L 0 .026 .125 r
F
.49255 .1282 m .49076 .12597 L .49399 .12466 L F
.64754 .12805 m .64924 .12448 L .65086 .12685 L 0 .026 .124 r
F
.64754 .12805 m .64592 .12569 L .64924 .12448 L F
.50079 .12786 m .50223 .12429 L .50402 .12656 L 0 .025 .124 r
F
.50079 .12786 m .499 .12558 L .50223 .12429 L F
.43814 .12858 m .43948 .12508 L .44133 .12737 L 0 .027 .126 r
F
.43814 .12858 m .43629 .12629 L .43948 .12508 L F
.7102 .12746 m .71199 .12385 L .71355 .12621 L 0 .025 .123 r
F
.7102 .12746 m .70864 .12511 L .71199 .12385 L F
.59314 .12845 m .59474 .12492 L .59642 .12718 L 0 .027 .126 r
F
.59314 .12845 m .59146 .12619 L .59474 .12492 L F
.54696 .12829 m .54849 .12483 L .55022 .1271 L 0 .026 .126 r
F
.54696 .12829 m .54523 .12601 L .54849 .12483 L F
.60138 .12811 m .60299 .12456 L .60466 .1268 L 0 .026 .125 r
F
.60138 .12811 m .5997 .12587 L .60299 .12456 L F
.50902 .12766 m .51048 .12409 L .51225 .12645 L 0 .025 .124 r
F
.50902 .12766 m .50725 .1253 L .51048 .12409 L F
.71845 .12725 m .72025 .1236 L .7218 .12594 L 0 .025 .123 r
F
.71845 .12725 m .7169 .12491 L .72025 .1236 L F
.44637 .12842 m .44773 .12473 L .44957 .12709 L 0 .027 .126 r
F
.44637 .12842 m .44453 .12605 L .44773 .12473 L F
.6558 .128 m .6575 .12438 L .65912 .12678 L 0 .026 .125 r
F
.6558 .128 m .65418 .12562 L .6575 .12438 L F
.60962 .12778 m .61125 .12436 L .61291 .12655 L F
.60962 .12778 m .60796 .12558 L .61125 .12436 L F
.5552 .12807 m .55674 .12451 L .55846 .12678 L F
.5552 .12807 m .55348 .1258 L .55674 .12451 L F
.4546 .12813 m .45597 .12447 L .4578 .12681 L F
.4546 .12813 m .45277 .12578 L .45597 .12447 L F
.7267 .12699 m .72852 .12347 L .73006 .12582 L 0 .025 .123 r
F
.7267 .12699 m .72516 .12465 L .72852 .12347 L F
.61786 .12746 m .6195 .12398 L .62116 .12618 L 0 .025 .124 r
F
.61786 .12746 m .61621 .12528 L .6195 .12398 L F
.46284 .12774 m .46422 .1243 L .46604 .12656 L 0 .026 .125 r
F
.46284 .12774 m .46101 .1255 L .46422 .1243 L F
.56344 .12783 m .56499 .12416 L .56671 .12651 L F
.56344 .12783 m .56173 .12548 L .56499 .12416 L F
.66405 .12785 m .66577 .12431 L .66737 .12661 L F
.66405 .12785 m .66244 .12555 L .66577 .12431 L F
.51726 .12763 m .51873 .12399 L .5205 .12638 L 0 .026 .124 r
F
.51726 .12763 m .51549 .12525 L .51873 .12399 L F
.6261 .12723 m .62776 .12358 L .6294 .12592 L 0 .025 .124 r
F
.6261 .12723 m .62445 .12489 L .62776 .12358 L F
.57168 .12757 m .57325 .12399 L .57495 .12638 L 0 .026 .125 r
F
.57168 .12757 m .56997 .12518 L .57325 .12399 L F
.6723 .1276 m .67404 .12421 L .67563 .12642 L F
.6723 .1276 m .6707 .12538 L .67404 .12421 L F
.47107 .12762 m .47246 .12417 L .47428 .12643 L F
.47107 .12762 m .46925 .12537 L .47246 .12417 L F
.63435 .12697 m .63602 .12332 L .63765 .12568 L 0 .025 .123 r
F
.63435 .12697 m .63271 .12461 L .63602 .12332 L F
.52549 .12743 m .52698 .12389 L .52874 .1262 L 0 .026 .125 r
F
.52549 .12743 m .52374 .12513 L .52698 .12389 L F
.73497 .12701 m .7368 .12341 L .73834 .12578 L 0 .025 .124 r
F
.73497 .12701 m .73343 .12465 L .7368 .12341 L F
.42487 .12756 m .42619 .12418 L .42806 .1264 L 0 .026 .125 r
F
.42487 .12756 m .42301 .12534 L .42619 .12418 L F
.68055 .12746 m .6823 .12395 L .68388 .12617 L F
.68055 .12746 m .67897 .12525 L .6823 .12395 L F
.53373 .12727 m .53524 .12374 L .53698 .12604 L F
.53373 .12727 m .53199 .12497 L .53524 .12374 L F
.68879 .12705 m .69056 .12349 L .69213 .12571 L 0 .025 .124 r
F
.68879 .12705 m .68722 .12483 L .69056 .12349 L F
.4793 .12751 m .48071 .12403 L .48252 .12633 L 0 .026 .125 r
F
.4793 .12751 m .47749 .12523 L .48071 .12403 L F
.74323 .12686 m .74508 .12322 L .7466 .12558 L 0 .025 .124 r
F
.74323 .12686 m .7417 .1245 L .74508 .12322 L F
.6426 .12686 m .64429 .12334 L .64592 .12569 L F
.6426 .12686 m .64097 .12451 L .64429 .12334 L F
.69704 .12666 m .69882 .1232 L .70038 .12539 L F
.69704 .12666 m .69547 .12446 L .69882 .1232 L F
.57993 .12758 m .58151 .12401 L .58321 .12639 L 0 .026 .126 r
F
.57993 .12758 m .57823 .1252 L .58151 .12401 L F
.4331 .12746 m .43443 .12405 L .43629 .12629 L 0 .027 .126 r
F
.4331 .12746 m .43124 .12523 L .43443 .12405 L F
.70529 .12637 m .70708 .12286 L .70864 .12511 L 0 .025 .123 r
F
.70529 .12637 m .70373 .12413 L .70708 .12286 L F
.48754 .12729 m .48896 .12373 L .49076 .12597 L 0 .026 .125 r
F
.48754 .12729 m .48574 .12504 L .48896 .12373 L F
.49578 .12688 m .49722 .12338 L .499 .12558 L 0 .026 .124 r
F
.49578 .12688 m .49399 .12466 L .49722 .12338 L F
.54198 .12716 m .54349 .12371 L .54523 .12601 L 0 .026 .125 r
F
.54198 .12716 m .54024 .12486 L .54349 .12371 L F
.58817 .1274 m .58977 .12393 L .59146 .12619 L 0 .027 .126 r
F
.58817 .1274 m .58649 .12516 L .58977 .12393 L F
.50402 .12656 m .50547 .12303 L .50725 .1253 L 0 .025 .124 r
F
.50402 .12656 m .50223 .12429 L .50547 .12303 L F
.65086 .12685 m .65256 .12322 L .65418 .12562 L 0 .026 .124 r
F
.65086 .12685 m .64924 .12448 L .65256 .12322 L F
.71355 .12621 m .71534 .12256 L .7169 .12491 L 0 .025 .123 r
F
.71355 .12621 m .71199 .12385 L .71534 .12256 L F
.44133 .12737 m .44268 .12377 L .44453 .12605 L 0 .027 .126 r
F
.44133 .12737 m .43948 .12508 L .44268 .12377 L F
.59642 .12718 m .59803 .12361 L .5997 .12587 L 0 .026 .125 r
F
.59642 .12718 m .59474 .12492 L .59803 .12361 L F
.60466 .1268 m .60629 .12334 L .60796 .12558 L F
.60466 .1268 m .60299 .12456 L .60629 .12334 L F
.7218 .12594 m .72361 .12233 L .72516 .12465 L 0 .024 .123 r
F
.7218 .12594 m .72025 .1236 L .72361 .12233 L F
.44957 .12709 m .45093 .12342 L .45277 .12578 L 0 .026 .125 r
F
.44957 .12709 m .44773 .12473 L .45093 .12342 L F
.55022 .1271 m .55175 .12353 L .55348 .1258 L 0 .026 .126 r
F
.55022 .1271 m .54849 .12483 L .55175 .12353 L F
.51225 .12645 m .51372 .12287 L .51549 .12525 L 0 .025 .124 r
F
.51225 .12645 m .51048 .12409 L .51372 .12287 L F
.61291 .12655 m .61455 .1231 L .61621 .12528 L 0 .026 .125 r
F
.61291 .12655 m .61125 .12436 L .61455 .1231 L F
.65912 .12678 m .66083 .12315 L .66244 .12555 L F
.65912 .12678 m .6575 .12438 L .66083 .12315 L F
.55846 .12678 m .56001 .1232 L .56173 .12548 L F
.55846 .12678 m .55674 .12451 L .56001 .1232 L F
.4578 .12681 m .45918 .12317 L .46101 .1255 L F
.4578 .12681 m .45597 .12447 L .45918 .12317 L F
.62116 .12618 m .62281 .12268 L .62445 .12489 L 0 .025 .124 r
F
.62116 .12618 m .6195 .12398 L .62281 .12268 L F
.56671 .12651 m .56826 .12283 L .56997 .12518 L 0 .026 .124 r
F
.56671 .12651 m .56499 .12416 L .56826 .12283 L F
.73006 .12582 m .7319 .12229 L .73343 .12465 L 0 .025 .123 r
F
.73006 .12582 m .72852 .12347 L .7319 .12229 L F
.46604 .12656 m .46743 .1231 L .46925 .12537 L 0 .026 .125 r
F
.46604 .12656 m .46422 .1243 L .46743 .1231 L F
.66737 .12661 m .6691 .1231 L .6707 .12538 L F
.66737 .12661 m .66577 .12431 L .6691 .1231 L F
.6294 .12592 m .63106 .12227 L .63271 .12461 L 0 .025 .123 r
F
.6294 .12592 m .62776 .12358 L .63106 .12227 L F
.5205 .12638 m .52198 .12272 L .52374 .12513 L 0 .026 .124 r
F
.5205 .12638 m .51873 .12399 L .52198 .12272 L F
.63765 .12568 m .63933 .12215 L .64097 .12451 L 0 .025 .123 r
F
.63765 .12568 m .63602 .12332 L .63933 .12215 L F
.57495 .12638 m .57653 .12281 L .57823 .1252 L 0 .026 .125 r
F
.57495 .12638 m .57325 .12399 L .57653 .12281 L F
.67563 .12642 m .67738 .12303 L .67897 .12525 L F
.67563 .12642 m .67404 .12421 L .67738 .12303 L F
.52874 .1262 m .53023 .12267 L .53199 .12497 L F
.52874 .1262 m .52698 .12389 L .53023 .12267 L F
.47428 .12643 m .47568 .12295 L .47749 .12523 L F
.47428 .12643 m .47246 .12417 L .47568 .12295 L F
.73834 .12578 m .74017 .12212 L .7417 .1245 L 0 .025 .123 r
F
.73834 .12578 m .7368 .12341 L .74017 .12212 L F
.68388 .12617 m .68564 .12259 L .68722 .12483 L 0 .026 .125 r
F
.68388 .12617 m .6823 .12395 L .68564 .12259 L F
.69213 .12571 m .6939 .12224 L .69547 .12446 L 0 .025 .124 r
F
.69213 .12571 m .69056 .12349 L .6939 .12224 L F
.42806 .1264 m .42938 .123 L .43124 .12523 L 0 .027 .126 r
F
.42806 .1264 m .42619 .12418 L .42938 .123 L F
.53698 .12604 m .53849 .12256 L .54024 .12486 L 0 .026 .125 r
F
.53698 .12604 m .53524 .12374 L .53849 .12256 L F
.70038 .12539 m .70217 .12193 L .70373 .12413 L 0 .025 .123 r
F
.70038 .12539 m .69882 .1232 L .70217 .12193 L F
.48252 .12633 m .48394 .12275 L .48574 .12504 L 0 .026 .125 r
F
.48252 .12633 m .48071 .12403 L .48394 .12275 L F
.64592 .12569 m .64761 .12212 L .64924 .12448 L 0 .025 .124 r
F
.64592 .12569 m .64429 .12334 L .64761 .12212 L F
.58321 .12639 m .58479 .12277 L .58649 .12516 L 0 .027 .126 r
F
.58321 .12639 m .58151 .12401 L .58479 .12277 L F
.49076 .12597 m .49219 .12243 L .49399 .12466 L 0 .026 .125 r
F
.49076 .12597 m .48896 .12373 L .49219 .12243 L F
.70864 .12511 m .71043 .12159 L .71199 .12385 L 0 .025 .123 r
F
.70864 .12511 m .70708 .12286 L .71043 .12159 L F
.499 .12558 m .50045 .12211 L .50223 .12429 L 0 .025 .124 r
F
.499 .12558 m .49722 .12338 L .50045 .12211 L F
.43629 .12629 m .43763 .12284 L .43948 .12508 L 0 .027 .126 r
F
.43629 .12629 m .43443 .12405 L .43763 .12284 L F
.59146 .12619 m .59306 .12265 L .59474 .12492 L F
.59146 .12619 m .58977 .12393 L .59306 .12265 L F
.50725 .1253 m .50871 .12179 L .51048 .12409 L 0 .025 .124 r
F
.50725 .1253 m .50547 .12303 L .50871 .12179 L F
.54523 .12601 m .54675 .12253 L .54849 .12483 L 0 .026 .126 r
F
.54523 .12601 m .54349 .12371 L .54675 .12253 L F
.44453 .12605 m .44588 .12245 L .44773 .12473 L 0 .026 .125 r
F
.44453 .12605 m .44268 .12377 L .44588 .12245 L F
.7169 .12491 m .7187 .12127 L .72025 .1236 L 0 .024 .123 r
F
.7169 .12491 m .71534 .12256 L .7187 .12127 L F
.65418 .12562 m .65588 .12197 L .6575 .12438 L 0 .026 .124 r
F
.65418 .12562 m .65256 .12322 L .65588 .12197 L F
.5997 .12587 m .60132 .1223 L .60299 .12456 L 0 .026 .125 r
F
.5997 .12587 m .59803 .12361 L .60132 .1223 L F
.45277 .12578 m .45414 .12212 L .45597 .12447 L F
.45277 .12578 m .45093 .12342 L .45414 .12212 L F
.72516 .12465 m .72698 .12115 L .72852 .12347 L 0 .024 .123 r
F
.72516 .12465 m .72361 .12233 L .72698 .12115 L F
.55348 .1258 m .55501 .12223 L .55674 .12451 L 0 .026 .125 r
F
.55348 .1258 m .55175 .12353 L .55501 .12223 L F
.60796 .12558 m .60959 .12213 L .61125 .12436 L F
.60796 .12558 m .60629 .12334 L .60959 .12213 L F
.56173 .12548 m .56328 .12189 L .56499 .12416 L F
.56173 .12548 m .56001 .1232 L .56328 .12189 L F
.51549 .12525 m .51697 .12159 L .51873 .12399 L 0 .025 .124 r
F
.51549 .12525 m .51372 .12287 L .51697 .12159 L F
.46101 .1255 m .46239 .12196 L .46422 .1243 L 0 .026 .125 r
F
.46101 .1255 m .45918 .12317 L .46239 .12196 L F
.61621 .12528 m .61785 .12179 L .6195 .12398 L F
.61621 .12528 m .61455 .1231 L .61785 .12179 L F
.66244 .12555 m .66416 .12192 L .66577 .12431 L F
.66244 .12555 m .66083 .12315 L .66416 .12192 L F
.62445 .12489 m .62611 .12137 L .62776 .12358 L 0 .025 .124 r
F
.62445 .12489 m .62281 .12268 L .62611 .12137 L F
.56997 .12518 m .57154 .12164 L .57325 .12399 L 0 .026 .124 r
F
.56997 .12518 m .56826 .12283 L .57154 .12164 L F
.63271 .12461 m .63437 .12098 L .63602 .12332 L 0 .025 .123 r
F
.63271 .12461 m .63106 .12227 L .63437 .12098 L F
.73343 .12465 m .73527 .12105 L .7368 .12341 L F
.73343 .12465 m .7319 .12229 L .73527 .12105 L F
.52374 .12513 m .52523 .12148 L .52698 .12389 L 0 .026 .124 r
F
.52374 .12513 m .52198 .12272 L .52523 .12148 L F
.46925 .12537 m .47065 .12188 L .47246 .12417 L 0 .026 .125 r
F
.46925 .12537 m .46743 .1231 L .47065 .12188 L F
.6707 .12538 m .67244 .12192 L .67404 .12421 L F
.6707 .12538 m .6691 .1231 L .67244 .12192 L F
.7417 .1245 m .74355 .12083 L .74508 .12322 L 0 .025 .123 r
F
.7417 .1245 m .74017 .12212 L .74355 .12083 L F
.64097 .12451 m .64265 .12098 L .64429 .12334 L 0 .025 .124 r
F
.64097 .12451 m .63933 .12215 L .64265 .12098 L F
.53199 .12497 m .53349 .12144 L .53524 .12374 L 0 .026 .125 r
F
.53199 .12497 m .53023 .12267 L .53349 .12144 L F
.57823 .1252 m .57981 .12162 L .58151 .12401 L F
.57823 .1252 m .57653 .12281 L .57981 .12162 L F
.47749 .12523 m .4789 .12173 L .48071 .12403 L F
.47749 .12523 m .47568 .12295 L .4789 .12173 L F
.67897 .12525 m .68072 .12172 L .6823 .12395 L F
.67897 .12525 m .67738 .12303 L .68072 .12172 L F
.68722 .12483 m .68898 .12125 L .69056 .12349 L 0 .026 .124 r
F
.68722 .12483 m .68564 .12259 L .68898 .12125 L F
.69547 .12446 m .69725 .121 L .69882 .1232 L 0 .025 .124 r
F
.69547 .12446 m .6939 .12224 L .69725 .121 L F
.43124 .12523 m .43257 .12181 L .43443 .12405 L 0 .027 .126 r
F
.43124 .12523 m .42938 .123 L .43257 .12181 L F
.48574 .12504 m .48716 .12145 L .48896 .12373 L 0 .026 .125 r
F
.48574 .12504 m .48394 .12275 L .48716 .12145 L F
.70373 .12413 m .70552 .12065 L .70708 .12286 L 0 .025 .123 r
F
.70373 .12413 m .70217 .12193 L .70552 .12065 L F
.54024 .12486 m .54175 .1214 L .54349 .12371 L 0 .026 .125 r
F
.54024 .12486 m .53849 .12256 L .54175 .1214 L F
.49399 .12466 m .49542 .12118 L .49722 .12338 L F
.49399 .12466 m .49219 .12243 L .49542 .12118 L F
.58649 .12516 m .58808 .12154 L .58977 .12393 L 0 .027 .126 r
F
.58649 .12516 m .58479 .12277 L .58808 .12154 L F
.64924 .12448 m .65093 .12086 L .65256 .12322 L 0 .025 .124 r
F
.64924 .12448 m .64761 .12212 L .65093 .12086 L F
.50223 .12429 m .50369 .12085 L .50547 .12303 L F
.50223 .12429 m .50045 .12211 L .50369 .12085 L F
.71199 .12385 m .71379 .12029 L .71534 .12256 L 0 .024 .123 r
F
.71199 .12385 m .71043 .12159 L .71379 .12029 L F
.43948 .12508 m .44083 .12154 L .44268 .12377 L 0 .027 .126 r
F
.43948 .12508 m .43763 .12284 L .44083 .12154 L F
.59474 .12492 m .59635 .12134 L .59803 .12361 L 0 .026 .126 r
F
.59474 .12492 m .59306 .12265 L .59635 .12134 L F
.44773 .12473 m .44909 .12116 L .45093 .12342 L 0 .026 .125 r
F
.44773 .12473 m .44588 .12245 L .44909 .12116 L F
.72025 .1236 m .72207 .12 L .72361 .12233 L 0 .024 .123 r
F
.72025 .1236 m .7187 .12127 L .72207 .12 L F
.51048 .12409 m .51195 .12056 L .51372 .12287 L 0 .025 .124 r
F
.51048 .12409 m .50871 .12179 L .51195 .12056 L F
.60299 .12456 m .60462 .12108 L .60629 .12334 L 0 .026 .125 r
F
.60299 .12456 m .60132 .1223 L .60462 .12108 L F
.54849 .12483 m .55002 .12122 L .55175 .12353 L 0 .026 .126 r
F
.54849 .12483 m .54675 .12253 L .55002 .12122 L F
.6575 .12438 m .65921 .12074 L .66083 .12315 L 0 .026 .124 r
F
.6575 .12438 m .65588 .12197 L .65921 .12074 L F
.45597 .12447 m .45735 .12083 L .45918 .12317 L 0 .026 .125 r
F
.45597 .12447 m .45414 .12212 L .45735 .12083 L F
.55674 .12451 m .55828 .12092 L .56001 .1232 L F
.55674 .12451 m .55501 .12223 L .55828 .12092 L F
.61125 .12436 m .61289 .12086 L .61455 .1231 L F
.61125 .12436 m .60959 .12213 L .61289 .12086 L F
.56499 .12416 m .56655 .12058 L .56826 .12283 L 0 .026 .124 r
F
.56499 .12416 m .56328 .12189 L .56655 .12058 L F
.72852 .12347 m .73036 .11997 L .7319 .12229 L 0 .025 .123 r
F
.72852 .12347 m .72698 .12115 L .73036 .11997 L F
.6195 .12398 m .62115 .12047 L .62281 .12268 L 0 .025 .124 r
F
.6195 .12398 m .61785 .12179 L .62115 .12047 L F
.51873 .12399 m .52021 .12031 L .52198 .12272 L F
.51873 .12399 m .51697 .12159 L .52021 .12031 L F
.62776 .12358 m .62942 .12005 L .63106 .12227 L 0 .025 .123 r
F
.62776 .12358 m .62611 .12137 L .62942 .12005 L F
.46422 .1243 m .46561 .12075 L .46743 .1231 L 0 .026 .125 r
F
.46422 .1243 m .46239 .12196 L .46561 .12075 L F
.66577 .12431 m .66749 .1207 L .6691 .1231 L F
.66577 .12431 m .66416 .12192 L .66749 .1207 L F
.57325 .12399 m .57482 .12047 L .57653 .12281 L F
.57325 .12399 m .57154 .12164 L .57482 .12047 L F
.63602 .12332 m .63769 .1198 L .63933 .12215 L 0 .025 .123 r
F
.63602 .12332 m .63437 .12098 L .63769 .1198 L F
.7368 .12341 m .73864 .11975 L .74017 .12212 L F
.7368 .12341 m .73527 .12105 L .73864 .11975 L F
.52698 .12389 m .52848 .12026 L .53023 .12267 L 0 .026 .124 r
F
.52698 .12389 m .52523 .12148 L .52848 .12026 L F
.47246 .12417 m .47387 .12064 L .47568 .12295 L 0 .026 .125 r
F
.47246 .12417 m .47065 .12188 L .47387 .12064 L F
.67404 .12421 m .67578 .12074 L .67738 .12303 L 0 .026 .126 r
F
.67404 .12421 m .67244 .12192 L .67578 .12074 L F
.6823 .12395 m .68405 .12036 L .68564 .12259 L 0 .026 .125 r
F
.6823 .12395 m .68072 .12172 L .68405 .12036 L F
.69056 .12349 m .69233 .12 L .6939 .12224 L 0 .025 .124 r
F
.69056 .12349 m .68898 .12125 L .69233 .12 L F
.53524 .12374 m .53675 .12025 L .53849 .12256 L 0 .026 .125 r
F
.53524 .12374 m .53349 .12144 L .53675 .12025 L F
.58151 .12401 m .58309 .12038 L .58479 .12277 L F
.58151 .12401 m .57981 .12162 L .58309 .12038 L F
.64429 .12334 m .64598 .11976 L .64761 .12212 L 0 .025 .124 r
F
.64429 .12334 m .64265 .12098 L .64598 .11976 L F
.48071 .12403 m .48213 .12044 L .48394 .12275 L 0 .026 .125 r
F
.48071 .12403 m .4789 .12173 L .48213 .12044 L F
.69882 .1232 m .7006 .11972 L .70217 .12193 L 0 .025 .124 r
F
.69882 .1232 m .69725 .121 L .7006 .11972 L F
.48896 .12373 m .49039 .12015 L .49219 .12243 L 0 .026 .125 r
F
.48896 .12373 m .48716 .12145 L .49039 .12015 L F
.70708 .12286 m .70888 .11936 L .71043 .12159 L 0 .025 .123 r
F
.70708 .12286 m .70552 .12065 L .70888 .11936 L F
.43443 .12405 m .43577 .12059 L .43763 .12284 L 0 .027 .126 r
F
.43443 .12405 m .43257 .12181 L .43577 .12059 L F
.49722 .12338 m .49866 .11992 L .50045 .12211 L 0 .026 .125 r
F
.49722 .12338 m .49542 .12118 L .49866 .11992 L F
.65256 .12322 m .65426 .1196 L .65588 .12197 L 0 .025 .124 r
F
.65256 .12322 m .65093 .12086 L .65426 .1196 L F
.58977 .12393 m .59137 .12027 L .59306 .12265 L 0 .026 .126 r
F
.58977 .12393 m .58808 .12154 L .59137 .12027 L F
.54349 .12371 m .54502 .12021 L .54675 .12253 L 0 .026 .125 r
F
.54349 .12371 m .54175 .1214 L .54502 .12021 L F
.71534 .12256 m .71715 .11899 L .7187 .12127 L 0 .024 .123 r
F
.71534 .12256 m .71379 .12029 L .71715 .11899 L F
.50547 .12303 m .50693 .11959 L .50871 .12179 L 0 .025 .124 r
F
.50547 .12303 m .50369 .12085 L .50693 .11959 L F
.44268 .12377 m .44403 .12023 L .44588 .12245 L 0 .026 .126 r
F
.44268 .12377 m .44083 .12154 L .44403 .12023 L F
.59803 .12361 m .59964 .12004 L .60132 .1223 L 0 .026 .125 r
F
.59803 .12361 m .59635 .12134 L .59964 .12004 L F
.45093 .12342 m .4523 .11988 L .45414 .12212 L F
.45093 .12342 m .44909 .12116 L .4523 .11988 L F
.72361 .12233 m .72544 .11882 L .72698 .12115 L 0 .024 .123 r
F
.72361 .12233 m .72207 .12 L .72544 .11882 L F
.55175 .12353 m .55328 .1199 L .55501 .12223 L 0 .026 .125 r
F
.55175 .12353 m .55002 .12122 L .55328 .1199 L F
.51372 .12287 m .51519 .11926 L .51697 .12159 L 0 .025 .124 r
F
.51372 .12287 m .51195 .12056 L .51519 .11926 L F
.60629 .12334 m .60792 .11985 L .60959 .12213 L 0 .026 .125 r
F
.60629 .12334 m .60462 .12108 L .60792 .11985 L F
.66083 .12315 m .66254 .11952 L .66416 .12192 L 0 .026 .124 r
F
.66083 .12315 m .65921 .12074 L .66254 .11952 L F
.45918 .12317 m .46056 .11962 L .46239 .12196 L 0 .026 .125 r
F
.45918 .12317 m .45735 .12083 L .46056 .11962 L F
.56001 .1232 m .56156 .11962 L .56328 .12189 L F
.56001 .1232 m .55828 .12092 L .56156 .11962 L F
.56826 .12283 m .56983 .11939 L .57154 .12164 L 0 .026 .124 r
F
.56826 .12283 m .56655 .12058 L .56983 .11939 L F
.61455 .1231 m .61619 .11953 L .61785 .12179 L 0 .026 .125 r
F
.61455 .1231 m .61289 .12086 L .61619 .11953 L F
.62281 .12268 m .62446 .11915 L .62611 .12137 L 0 .025 .124 r
F
.62281 .12268 m .62115 .12047 L .62446 .11915 L F
.52198 .12272 m .52346 .11905 L .52523 .12148 L F
.52198 .12272 m .52021 .12031 L .52346 .11905 L F
.63106 .12227 m .63273 .11876 L .63437 .12098 L 0 .025 .123 r
F
.63106 .12227 m .62942 .12005 L .63273 .11876 L F
.7319 .12229 m .73373 .11872 L .73527 .12105 L F
.7319 .12229 m .73036 .11997 L .73373 .11872 L F
.6691 .1231 m .67083 .11952 L .67244 .12192 L 0 .026 .125 r
F
.6691 .1231 m .66749 .1207 L .67083 .11952 L F
.46743 .1231 m .46883 .11953 L .47065 .12188 L F
.46743 .1231 m .46561 .12075 L .46883 .11953 L F
.74017 .12212 m .74202 .11846 L .74355 .12083 L 0 .025 .123 r
F
.74017 .12212 m .73864 .11975 L .74202 .11846 L F
.57653 .12281 m .5781 .11927 L .57981 .12162 L 0 .026 .125 r
F
.57653 .12281 m .57482 .12047 L .5781 .11927 L F
.63933 .12215 m .64102 .11863 L .64265 .12098 L 0 .025 .123 r
F
.63933 .12215 m .63769 .1198 L .64102 .11863 L F
.53023 .12267 m .53173 .11904 L .53349 .12144 L 0 .026 .124 r
F
.53023 .12267 m .52848 .12026 L .53173 .11904 L F
.47568 .12295 m .47709 .1194 L .4789 .12173 L 0 .026 .125 r
F
.47568 .12295 m .47387 .12064 L .47709 .1194 L F
.67738 .12303 m .67912 .11943 L .68072 .12172 L 0 .026 .126 r
F
.67738 .12303 m .67578 .12074 L .67912 .11943 L F
.68564 .12259 m .6874 .119 L .68898 .12125 L 0 .026 .125 r
F
.68564 .12259 m .68405 .12036 L .6874 .119 L F
.6939 .12224 m .69568 .11875 L .69725 .121 L 0 .025 .124 r
F
.6939 .12224 m .69233 .12 L .69568 .11875 L F
.48394 .12275 m .48536 .11915 L .48716 .12145 L 0 .026 .125 r
F
.48394 .12275 m .48213 .12044 L .48536 .11915 L F
.58479 .12277 m .58638 .11914 L .58808 .12154 L F
.58479 .12277 m .58309 .12038 L .58638 .11914 L F
.53849 .12256 m .54001 .11907 L .54175 .1214 L F
.53849 .12256 m .53675 .12025 L .54001 .11907 L F
.64761 .12212 m .6493 .1185 L .65093 .12086 L 0 .025 .124 r
F
.64761 .12212 m .64598 .11976 L .6493 .1185 L F
.70217 .12193 m .70396 .11843 L .70552 .12065 L F
.70217 .12193 m .7006 .11972 L .70396 .11843 L F
.49219 .12243 m .49363 .1189 L .49542 .12118 L 0 .026 .125 r
F
.49219 .12243 m .49039 .12015 L .49363 .1189 L F
.71043 .12159 m .71224 .11805 L .71379 .12029 L 0 .025 .123 r
F
.71043 .12159 m .70888 .11936 L .71224 .11805 L F
.50045 .12211 m .5019 .11866 L .50369 .12085 L 0 .026 .124 r
F
.50045 .12211 m .49866 .11992 L .5019 .11866 L F
.43763 .12284 m .43897 .1193 L .44083 .12154 L 0 .027 .126 r
F
.43763 .12284 m .43577 .12059 L .43897 .1193 L F
.7187 .12127 m .72052 .11772 L .72207 .12 L 0 .024 .122 r
F
.7187 .12127 m .71715 .11899 L .72052 .11772 L F
.59306 .12265 m .59466 .11898 L .59635 .12134 L 0 .026 .125 r
F
.59306 .12265 m .59137 .12027 L .59466 .11898 L F
.65588 .12197 m .65759 .11839 L .65921 .12074 L 0 .025 .124 r
F
.65588 .12197 m .65426 .1196 L .65759 .11839 L F
.44588 .12245 m .44724 .11895 L .44909 .12116 L 0 .026 .125 r
F
.44588 .12245 m .44403 .12023 L .44724 .11895 L F
.50871 .12179 m .51017 .11833 L .51195 .12056 L 0 .025 .124 r
F
.50871 .12179 m .50693 .11959 L .51017 .11833 L F
.60132 .1223 m .60294 .11881 L .60462 .12108 L 0 .026 .125 r
F
.60132 .1223 m .59964 .12004 L .60294 .11881 L F
.54675 .12253 m .54828 .11889 L .55002 .12122 L F
.54675 .12253 m .54502 .12021 L .54828 .11889 L F
.45414 .12212 m .45551 .11859 L .45735 .12083 L F
.45414 .12212 m .4523 .11988 L .45551 .11859 L F
.55501 .12223 m .55656 .1186 L .55828 .12092 L F
.55501 .12223 m .55328 .1199 L .55656 .1186 L F
.51697 .12159 m .51844 .11797 L .52021 .12031 L 0 .025 .124 r
F
.51697 .12159 m .51519 .11926 L .51844 .11797 L F
.72698 .12115 m .72882 .11764 L .73036 .11997 L 0 .024 .123 r
F
.72698 .12115 m .72544 .11882 L .72882 .11764 L F
.56328 .12189 m .56483 .11832 L .56655 .12058 L 0 .026 .124 r
F
.56328 .12189 m .56156 .11962 L .56483 .11832 L F
.60959 .12213 m .61122 .11858 L .61289 .12086 L 0 .026 .125 r
F
.60959 .12213 m .60792 .11985 L .61122 .11858 L F
.66416 .12192 m .66588 .11831 L .66749 .1207 L F
.66416 .12192 m .66254 .11952 L .66588 .11831 L F
.46239 .12196 m .46378 .1184 L .46561 .12075 L F
.46239 .12196 m .46056 .11962 L .46378 .1184 L F
.61785 .12179 m .6195 .11819 L .62115 .12047 L 0 .026 .124 r
F
.61785 .12179 m .61619 .11953 L .6195 .11819 L F
.62611 .12137 m .62777 .11783 L .62942 .12005 L 0 .025 .124 r
F
.62611 .12137 m .62446 .11915 L .62777 .11783 L F
.57154 .12164 m .57311 .11821 L .57482 .12047 L 0 .026 .125 r
F
.57154 .12164 m .56983 .11939 L .57311 .11821 L F
.63437 .12098 m .63606 .11756 L .63769 .1198 L 0 .025 .123 r
F
.63437 .12098 m .63273 .11876 L .63606 .11756 L F
.52523 .12148 m .52672 .11784 L .52848 .12026 L 0 .025 .124 r
F
.52523 .12148 m .52346 .11905 L .52672 .11784 L F
.73527 .12105 m .73711 .11744 L .73864 .11975 L 0 .025 .123 r
F
.73527 .12105 m .73373 .11872 L .73711 .11744 L F
.47065 .12188 m .47205 .11828 L .47387 .12064 L 0 .026 .125 r
F
.47065 .12188 m .46883 .11953 L .47205 .11828 L F
.67244 .12192 m .67418 .11834 L .67578 .12074 L F
.67244 .12192 m .67083 .11952 L .67418 .11834 L F
.57981 .12162 m .58139 .11802 L .58309 .12038 L F
.57981 .12162 m .5781 .11927 L .58139 .11802 L F
.64265 .12098 m .64434 .11741 L .64598 .11976 L 0 .025 .124 r
F
.64265 .12098 m .64102 .11863 L .64434 .11741 L F
.53349 .12144 m .53499 .11785 L .53675 .12025 L 0 .026 .125 r
F
.53349 .12144 m .53173 .11904 L .53499 .11785 L F
.68898 .12125 m .69075 .11775 L .69233 .12 L 0 .026 .124 r
F
.68898 .12125 m .6874 .119 L .69075 .11775 L F
.68072 .12172 m .68246 .11807 L .68405 .12036 L 0 .026 .125 r
F
.68072 .12172 m .67912 .11943 L .68246 .11807 L F
.4789 .12173 m .48032 .11812 L .48213 .12044 L F
.4789 .12173 m .47709 .1194 L .48032 .11812 L F
.48716 .12145 m .48859 .11786 L .49039 .12015 L F
.48716 .12145 m .48536 .11915 L .48859 .11786 L F
.69725 .121 m .69903 .11747 L .7006 .11972 L 0 .025 .124 r
F
.69725 .121 m .69568 .11875 L .69903 .11747 L F
.58808 .12154 m .58967 .11788 L .59137 .12027 L 0 .026 .125 r
F
.58808 .12154 m .58638 .11914 L .58967 .11788 L F
.65093 .12086 m .65263 .11724 L .65426 .1196 L 0 .025 .124 r
F
.65093 .12086 m .6493 .1185 L .65263 .11724 L F
.70552 .12065 m .70732 .11713 L .70888 .11936 L 0 .025 .123 r
F
.70552 .12065 m .70396 .11843 L .70732 .11713 L F
.54175 .1214 m .54327 .11788 L .54502 .12021 L 0 .026 .125 r
F
.54175 .1214 m .54001 .11907 L .54327 .11788 L F
.49542 .12118 m .49687 .11765 L .49866 .11992 L F
.49542 .12118 m .49363 .1189 L .49687 .11765 L F
.71379 .12029 m .7156 .11674 L .71715 .11899 L 0 .024 .123 r
F
.71379 .12029 m .71224 .11805 L .7156 .11674 L F
.50369 .12085 m .50514 .11738 L .50693 .11959 L 0 .026 .124 r
F
.50369 .12085 m .5019 .11866 L .50514 .11738 L F
.44083 .12154 m .44218 .118 L .44403 .12023 L 0 .027 .126 r
F
.44083 .12154 m .43897 .1193 L .44218 .118 L F
.59635 .12134 m .59796 .1177 L .59964 .12004 L 0 .026 .125 r
F
.59635 .12134 m .59466 .11898 L .59796 .1177 L F
.72207 .12 m .72389 .11653 L .72544 .11882 L 0 .024 .122 r
F
.72207 .12 m .72052 .11772 L .72389 .11653 L F
.44909 .12116 m .45045 .11769 L .4523 .11988 L 0 .026 .125 r
F
.44909 .12116 m .44724 .11895 L .45045 .11769 L F
.65921 .12074 m .66093 .11718 L .66254 .11952 L 0 .025 .124 r
F
.65921 .12074 m .65759 .11839 L .66093 .11718 L F
.55002 .12122 m .55155 .11756 L .55328 .1199 L 0 .026 .125 r
F
.55002 .12122 m .54828 .11889 L .55155 .11756 L F
.51195 .12056 m .51342 .11702 L .51519 .11926 L 0 .025 .124 r
F
.51195 .12056 m .51017 .11833 L .51342 .11702 L F
.45735 .12083 m .45873 .11736 L .46056 .11962 L 0 .026 .125 r
F
.45735 .12083 m .45551 .11859 L .45873 .11736 L F
.60462 .12108 m .60624 .11757 L .60792 .11985 L F
.60462 .12108 m .60294 .11881 L .60624 .11757 L F
.55828 .12092 m .55983 .1173 L .56156 .11962 L F
.55828 .12092 m .55656 .1186 L .55983 .1173 L F
.52021 .12031 m .5217 .11671 L .52346 .11905 L 0 .025 .123 r
F
.52021 .12031 m .51844 .11797 L .5217 .11671 L F
.56655 .12058 m .56811 .11713 L .56983 .11939 L 0 .026 .124 r
F
.56655 .12058 m .56483 .11832 L .56811 .11713 L F
.61289 .12086 m .61453 .11722 L .61619 .11953 L 0 .026 .125 r
F
.61289 .12086 m .61122 .11858 L .61453 .11722 L F
.73036 .11997 m .7322 .1164 L .73373 .11872 L 0 .024 .123 r
F
.73036 .11997 m .72882 .11764 L .7322 .1164 L F
.62115 .12047 m .62281 .11687 L .62446 .11915 L 0 .025 .124 r
F
.62115 .12047 m .6195 .11819 L .62281 .11687 L F
.66749 .1207 m .66922 .11712 L .67083 .11952 L 0 .026 .125 r
F
.66749 .1207 m .66588 .11831 L .66922 .11712 L F
.62942 .12005 m .63109 .11653 L .63273 .11876 L 0 .025 .123 r
F
.62942 .12005 m .62777 .11783 L .63109 .11653 L F
.46561 .12075 m .467 .11717 L .46883 .11953 L 0 .026 .125 r
F
.46561 .12075 m .46378 .1184 L .467 .11717 L F
.73864 .11975 m .74049 .11615 L .74202 .11846 L 0 .024 .123 r
F
.73864 .11975 m .73711 .11744 L .74049 .11615 L F
.57482 .12047 m .5764 .11701 L .5781 .11927 L 0 .026 .125 r
F
.57482 .12047 m .57311 .11821 L .5764 .11701 L F
.52848 .12026 m .52998 .11663 L .53173 .11904 L 0 .025 .124 r
F
.52848 .12026 m .52672 .11784 L .52998 .11663 L F
.63769 .1198 m .63938 .11637 L .64102 .11863 L 0 .025 .123 r
F
.63769 .1198 m .63606 .11756 L .63938 .11637 L F
.47387 .12064 m .47528 .11703 L .47709 .1194 L 0 .026 .125 r
F
.47387 .12064 m .47205 .11828 L .47528 .11703 L F
.67578 .12074 m .67752 .11704 L .67912 .11943 L F
.67578 .12074 m .67418 .11834 L .67752 .11704 L F
.68405 .12036 m .68581 .11671 L .6874 .119 L F
.68405 .12036 m .68246 .11807 L .68581 .11671 L F
.58309 .12038 m .58468 .11677 L .58638 .11914 L F
.58309 .12038 m .58139 .11802 L .58468 .11677 L F
.64598 .11976 m .64767 .11614 L .6493 .1185 L 0 .025 .124 r
F
.64598 .11976 m .64434 .11741 L .64767 .11614 L F
.48213 .12044 m .48355 .11684 L .48536 .11915 L 0 .026 .125 r
F
.48213 .12044 m .48032 .11812 L .48355 .11684 L F
.69233 .12 m .6941 .1165 L .69568 .11875 L 0 .026 .124 r
F
.69233 .12 m .69075 .11775 L .6941 .1165 L F
.53675 .12025 m .53826 .11667 L .54001 .11907 L 0 .026 .125 r
F
.53675 .12025 m .53499 .11785 L .53826 .11667 L F
.49039 .12015 m .49183 .11662 L .49363 .1189 L F
.49039 .12015 m .48859 .11786 L .49183 .11662 L F
.7006 .11972 m .70239 .11614 L .70396 .11843 L 0 .025 .124 r
F
.7006 .11972 m .69903 .11747 L .70239 .11614 L F
.59137 .12027 m .59297 .11661 L .59466 .11898 L 0 .026 .125 r
F
.59137 .12027 m .58967 .11788 L .59297 .11661 L F
.70888 .11936 m .71068 .11581 L .71224 .11805 L 0 .025 .123 r
F
.70888 .11936 m .70732 .11713 L .71068 .11581 L F
.65426 .1196 m .65597 .11604 L .65759 .11839 L 0 .025 .124 r
F
.65426 .1196 m .65263 .11724 L .65597 .11604 L F
.71715 .11899 m .71897 .11546 L .72052 .11772 L 0 .024 .123 r
F
.71715 .11899 m .7156 .11674 L .71897 .11546 L F
.49866 .11992 m .50011 .11638 L .5019 .11866 L 0 .026 .125 r
F
.49866 .11992 m .49687 .11765 L .50011 .11638 L F
.54502 .12021 m .54654 .11654 L .54828 .11889 L F
.54502 .12021 m .54327 .11788 L .54654 .11654 L F
.44403 .12023 m .44539 .11674 L .44724 .11895 L 0 .027 .126 r
F
.44403 .12023 m .44218 .118 L .44539 .11674 L F
.59964 .12004 m .60126 .11648 L .60294 .11881 L 0 .026 .125 r
F
.59964 .12004 m .59796 .1177 L .60126 .11648 L F
.50693 .11959 m .50839 .1161 L .51017 .11833 L 0 .025 .124 r
F
.50693 .11959 m .50514 .11738 L .50839 .1161 L F
.4523 .11988 m .45367 .11642 L .45551 .11859 L 0 .026 .125 r
F
.4523 .11988 m .45045 .11769 L .45367 .11642 L F
.55328 .1199 m .55483 .11625 L .55656 .1186 L F
.55328 .1199 m .55155 .11756 L .55483 .11625 L F
.51519 .11926 m .51667 .11571 L .51844 .11797 L 0 .025 .124 r
F
.51519 .11926 m .51342 .11702 L .51667 .11571 L F
.72544 .11882 m .72727 .11533 L .72882 .11764 L 0 .024 .123 r
F
.72544 .11882 m .72389 .11653 L .72727 .11533 L F
.66254 .11952 m .66427 .11598 L .66588 .11831 L 0 .025 .124 r
F
.66254 .11952 m .66093 .11718 L .66427 .11598 L F
.46056 .11962 m .46195 .11613 L .46378 .1184 L 0 .026 .125 r
F
.46056 .11962 m .45873 .11736 L .46195 .11613 L F
.56156 .11962 m .56311 .11601 L .56483 .11832 L F
.56156 .11962 m .55983 .1173 L .56311 .11601 L F
.60792 .11985 m .60955 .11628 L .61122 .11858 L F
.60792 .11985 m .60624 .11757 L .60955 .11628 L F
.52346 .11905 m .52495 .1155 L .52672 .11784 L 0 .025 .123 r
F
.52346 .11905 m .5217 .11671 L .52495 .1155 L F
.61619 .11953 m .61783 .11587 L .6195 .11819 L 0 .026 .124 r
F
.61619 .11953 m .61453 .11722 L .61783 .11587 L F
.62446 .11915 m .62612 .11555 L .62777 .11783 L 0 .025 .124 r
F
.62446 .11915 m .62281 .11687 L .62612 .11555 L F
.56983 .11939 m .5714 .11595 L .57311 .11821 L 0 .026 .125 r
F
.56983 .11939 m .56811 .11713 L .5714 .11595 L F
.73373 .11872 m .73558 .11512 L .73711 .11744 L 0 .024 .123 r
F
.73373 .11872 m .7322 .1164 L .73558 .11512 L F
.63273 .11876 m .63441 .11532 L .63606 .11756 L 0 .025 .123 r
F
.63273 .11876 m .63109 .11653 L .63441 .11532 L F
.67083 .11952 m .67257 .11593 L .67418 .11834 L 0 .026 .125 r
F
.67083 .11952 m .66922 .11712 L .67257 .11593 L F
.46883 .11953 m .47023 .11591 L .47205 .11828 L F
.46883 .11953 m .467 .11717 L .47023 .11591 L F
.53173 .11904 m .53324 .11544 L .53499 .11785 L 0 .025 .124 r
F
.53173 .11904 m .52998 .11663 L .53324 .11544 L F
.5781 .11927 m .57969 .11575 L .58139 .11802 L 0 .026 .125 r
F
.5781 .11927 m .5764 .11701 L .57969 .11575 L F
.64102 .11863 m .64271 .11512 L .64434 .11741 L 0 .025 .123 r
F
.64102 .11863 m .63938 .11637 L .64271 .11512 L F
.47709 .1194 m .47851 .11576 L .48032 .11812 L 0 .026 .125 r
F
.47709 .1194 m .47528 .11703 L .47851 .11576 L F
.67912 .11943 m .68087 .1157 L .68246 .11807 L F
.67912 .11943 m .67752 .11704 L .68087 .1157 L F
.6874 .119 m .68916 .11546 L .69075 .11775 L 0 .026 .124 r
F
.6874 .119 m .68581 .11671 L .68916 .11546 L F
.58638 .11914 m .58798 .11552 L .58967 .11788 L 0 .026 .125 r
F
.58638 .11914 m .58468 .11677 L .58798 .11552 L F
.48536 .11915 m .48679 .11556 L .48859 .11786 L F
.48536 .11915 m .48355 .11684 L .48679 .11556 L F
.6493 .1185 m .651 .11488 L .65263 .11724 L 0 .025 .123 r
F
.6493 .1185 m .64767 .11614 L .651 .11488 L F
.69568 .11875 m .69746 .1152 L .69903 .11747 L 0 .025 .124 r
F
.69568 .11875 m .6941 .1165 L .69746 .1152 L F
.54001 .11907 m .54153 .11548 L .54327 .11788 L 0 .026 .125 r
F
.54001 .11907 m .53826 .11667 L .54153 .11548 L F
.70396 .11843 m .70575 .11482 L .70732 .11713 L 0 .025 .124 r
F
.70396 .11843 m .70239 .11614 L .70575 .11482 L F
.49363 .1189 m .49507 .11537 L .49687 .11765 L 0 .026 .125 r
F
.49363 .1189 m .49183 .11662 L .49507 .11537 L F
.71224 .11805 m .71405 .11449 L .7156 .11674 L 0 .025 .123 r
F
.71224 .11805 m .71068 .11581 L .71405 .11449 L F
.59466 .11898 m .59627 .11535 L .59796 .1177 L 0 .026 .125 r
F
.59466 .11898 m .59297 .11661 L .59627 .11535 L F
.65759 .11839 m .65931 .11485 L .66093 .11718 L 0 .025 .124 r
F
.65759 .11839 m .65597 .11604 L .65931 .11485 L F
.72052 .11772 m .72235 .11425 L .72389 .11653 L 0 .024 .123 r
F
.72052 .11772 m .71897 .11546 L .72235 .11425 L F
.5019 .11866 m .50336 .11508 L .50514 .11738 L 0 .026 .125 r
F
.5019 .11866 m .50011 .11638 L .50336 .11508 L F
.54828 .11889 m .54981 .11521 L .55155 .11756 L F
.54828 .11889 m .54654 .11654 L .54981 .11521 L F
.44724 .11895 m .4486 .11549 L .45045 .11769 L 0 .026 .126 r
F
.44724 .11895 m .44539 .11674 L .4486 .11549 L F
.51017 .11833 m .51164 .11478 L .51342 .11702 L 0 .025 .124 r
F
.51017 .11833 m .50839 .1161 L .51164 .11478 L F
.60294 .11881 m .60457 .11526 L .60624 .11757 L 0 .026 .125 r
F
.60294 .11881 m .60126 .11648 L .60457 .11526 L F
.45551 .11859 m .45689 .11517 L .45873 .11736 L F
.45551 .11859 m .45367 .11642 L .45689 .11517 L F
.55656 .1186 m .5581 .11496 L .55983 .1173 L F
.55656 .1186 m .55483 .11625 L .5581 .11496 L F
.51844 .11797 m .51993 .11444 L .5217 .11671 L 0 .025 .123 r
F
.51844 .11797 m .51667 .11571 L .51993 .11444 L F
.66588 .11831 m .66761 .1148 L .66922 .11712 L 0 .026 .124 r
F
.66588 .11831 m .66427 .11598 L .66761 .1148 L F
.56483 .11832 m .56639 .1148 L .56811 .11713 L F
.56483 .11832 m .56311 .11601 L .56639 .1148 L F
.72882 .11764 m .73066 .11408 L .7322 .1164 L 0 .024 .123 r
F
.72882 .11764 m .72727 .11533 L .73066 .11408 L F
.61122 .11858 m .61286 .11492 L .61453 .11722 L 0 .026 .125 r
F
.61122 .11858 m .60955 .11628 L .61286 .11492 L F
.46378 .1184 m .46517 .11488 L .467 .11717 L F
.46378 .1184 m .46195 .11613 L .46517 .11488 L F
.6195 .11819 m .62115 .11454 L .62281 .11687 L 0 .025 .124 r
F
.6195 .11819 m .61783 .11587 L .62115 .11454 L F
.62777 .11783 m .62944 .11424 L .63109 .11653 L F
.62777 .11783 m .62612 .11555 L .62944 .11424 L F
.52672 .11784 m .52822 .11429 L .52998 .11663 L F
.52672 .11784 m .52495 .1155 L .52822 .11429 L F
.73711 .11744 m .73896 .11384 L .74049 .11615 L 0 .024 .123 r
F
.73711 .11744 m .73558 .11512 L .73896 .11384 L F
.57311 .11821 m .57469 .11475 L .5764 .11701 L 0 .026 .125 r
F
.57311 .11821 m .5714 .11595 L .57469 .11475 L F
.63606 .11756 m .63774 .1141 L .63938 .11637 L 0 .025 .123 r
F
.63606 .11756 m .63441 .11532 L .63774 .1141 L F
.47205 .11828 m .47346 .11464 L .47528 .11703 L 0 .026 .125 r
F
.47205 .11828 m .47023 .11591 L .47346 .11464 L F
.67418 .11834 m .67592 .11465 L .67752 .11704 L F
.67418 .11834 m .67257 .11593 L .67592 .11465 L F
.58139 .11802 m .58298 .11448 L .58468 .11677 L F
.58139 .11802 m .57969 .11575 L .58298 .11448 L F
.68246 .11807 m .68422 .11436 L .68581 .11671 L F
.68246 .11807 m .68087 .1157 L .68422 .11436 L F
.53499 .11785 m .53651 .11427 L .53826 .11667 L 0 .026 .124 r
F
.53499 .11785 m .53324 .11544 L .53651 .11427 L F
.64434 .11741 m .64604 .11384 L .64767 .11614 L 0 .025 .123 r
F
.64434 .11741 m .64271 .11512 L .64604 .11384 L F
.48032 .11812 m .48174 .11449 L .48355 .11684 L 0 .026 .125 r
F
.48032 .11812 m .47851 .11576 L .48174 .11449 L F
.69075 .11775 m .69252 .11422 L .6941 .1165 L 0 .026 .124 r
F
.69075 .11775 m .68916 .11546 L .69252 .11422 L F
.48859 .11786 m .49003 .11432 L .49183 .11662 L 0 .026 .125 r
F
.48859 .11786 m .48679 .11556 L .49003 .11432 L F
.58967 .11788 m .59128 .11428 L .59297 .11661 L F
.58967 .11788 m .58798 .11552 L .59128 .11428 L F
.69903 .11747 m .70082 .11385 L .70239 .11614 L 0 .025 .124 r
F
.69903 .11747 m .69746 .1152 L .70082 .11385 L F
.65263 .11724 m .65434 .11369 L .65597 .11604 L F
.65263 .11724 m .651 .11488 L .65434 .11369 L F
.70732 .11713 m .70912 .11349 L .71068 .11581 L 0 .025 .123 r
F
.70732 .11713 m .70575 .11482 L .70912 .11349 L F
.54327 .11788 m .5448 .11415 L .54654 .11654 L 0 .026 .125 r
F
.54327 .11788 m .54153 .11548 L .5448 .11415 L F
.49687 .11765 m .49831 .11408 L .50011 .11638 L F
.49687 .11765 m .49507 .11537 L .49831 .11408 L F
.7156 .11674 m .71742 .11319 L .71897 .11546 L 0 .024 .123 r
F
.7156 .11674 m .71405 .11449 L .71742 .11319 L F
.59796 .1177 m .59958 .11415 L .60126 .11648 L 0 .026 .125 r
F
.59796 .1177 m .59627 .11535 L .59958 .11415 L F
.55155 .11756 m .55309 .1139 L .55483 .11625 L F
.55155 .11756 m .54981 .11521 L .55309 .1139 L F
.50514 .11738 m .5066 .11378 L .50839 .1161 L 0 .026 .124 r
F
.50514 .11738 m .50336 .11508 L .5066 .11378 L F
.66093 .11718 m .66265 .11366 L .66427 .11598 L 0 .025 .124 r
F
.66093 .11718 m .65931 .11485 L .66265 .11366 L F
.72389 .11653 m .72573 .11304 L .72727 .11533 L 0 .024 .123 r
F
.72389 .11653 m .72235 .11425 L .72573 .11304 L F
.45045 .11769 m .45182 .11424 L .45367 .11642 L 0 .026 .126 r
F
.45045 .11769 m .4486 .11549 L .45182 .11424 L F
.51342 .11702 m .5149 .11345 L .51667 .11571 L 0 .025 .124 r
F
.51342 .11702 m .51164 .11478 L .5149 .11345 L F
.55983 .1173 m .56138 .11366 L .56311 .11601 L 0 .026 .124 r
F
.55983 .1173 m .5581 .11496 L .56138 .11366 L F
.60624 .11757 m .60788 .11398 L .60955 .11628 L 0 .026 .125 r
F
.60624 .11757 m .60457 .11526 L .60788 .11398 L F
.45873 .11736 m .46011 .11391 L .46195 .11613 L F
.45873 .11736 m .45689 .11517 L .46011 .11391 L F
.5217 .11671 m .52319 .11324 L .52495 .1155 L 0 .025 .123 r
F
.5217 .11671 m .51993 .11444 L .52319 .11324 L F
.61453 .11722 m .61617 .11355 L .61783 .11587 L 0 .026 .124 r
F
.61453 .11722 m .61286 .11492 L .61617 .11355 L F
.7322 .1164 m .73404 .1128 L .73558 .11512 L 0 .024 .123 r
F
.7322 .1164 m .73066 .11408 L .73404 .1128 L F
.62281 .11687 m .62446 .11322 L .62612 .11555 L 0 .025 .124 r
F
.62281 .11687 m .62115 .11454 L .62446 .11322 L F
.66922 .11712 m .67097 .11361 L .67257 .11593 L 0 .026 .125 r
F
.66922 .11712 m .66761 .1148 L .67097 .11361 L F
.56811 .11713 m .56968 .1136 L .5714 .11595 L F
.56811 .11713 m .56639 .1148 L .56968 .1136 L F
.467 .11717 m .4684 .1136 L .47023 .11591 L F
.467 .11717 m .46517 .11488 L .4684 .1136 L F
.63109 .11653 m .63277 .11301 L .63441 .11532 L 0 .025 .123 r
F
.63109 .11653 m .62944 .11424 L .63277 .11301 L F
.52998 .11663 m .53148 .11311 L .53324 .11544 L 0 .025 .124 r
F
.52998 .11663 m .52822 .11429 L .53148 .11311 L F
.5764 .11701 m .57798 .11347 L .57969 .11575 L 0 .026 .125 r
F
.5764 .11701 m .57469 .11475 L .57798 .11347 L F
.47528 .11703 m .47669 .11339 L .47851 .11576 L F
.47528 .11703 m .47346 .11464 L .47669 .11339 L F
.67752 .11704 m .67927 .11332 L .68087 .1157 L F
.67752 .11704 m .67592 .11465 L .67927 .11332 L F
.63938 .11637 m .64107 .11283 L .64271 .11512 L 0 .025 .124 r
F
.63938 .11637 m .63774 .1141 L .64107 .11283 L F
.68581 .11671 m .68758 .11313 L .68916 .11546 L 0 .026 .124 r
F
.68581 .11671 m .68422 .11436 L .68758 .11313 L F
.58468 .11677 m .58628 .11324 L .58798 .11552 L 0 .026 .125 r
F
.58468 .11677 m .58298 .11448 L .58628 .11324 L F
.64767 .11614 m .64937 .11255 L .651 .11488 L 0 .025 .123 r
F
.64767 .11614 m .64604 .11384 L .64937 .11255 L F
.48355 .11684 m .48498 .11324 L .48679 .11556 L 0 .026 .125 r
F
.48355 .11684 m .48174 .11449 L .48498 .11324 L F
.53826 .11667 m .53978 .11307 L .54153 .11548 L F
.53826 .11667 m .53651 .11427 L .53978 .11307 L F
.6941 .1165 m .69588 .11292 L .69746 .1152 L 0 .026 .124 r
F
.6941 .1165 m .69252 .11422 L .69588 .11292 L F
.70239 .11614 m .70418 .1125 L .70575 .11482 L 0 .025 .124 r
F
.70239 .11614 m .70082 .11385 L .70418 .1125 L F
.59297 .11661 m .59458 .11303 L .59627 .11535 L 0 .026 .125 r
F
.59297 .11661 m .59128 .11428 L .59458 .11303 L F
.49183 .11662 m .49327 .11308 L .49507 .11537 L F
.49183 .11662 m .49003 .11432 L .49327 .11308 L F
.71068 .11581 m .71248 .11216 L .71405 .11449 L 0 .025 .123 r
F
.71068 .11581 m .70912 .11349 L .71248 .11216 L F
.65597 .11604 m .65769 .11251 L .65931 .11485 L 0 .025 .124 r
F
.65597 .11604 m .65434 .11369 L .65769 .11251 L F
.54654 .11654 m .54807 .11282 L .54981 .11521 L 0 .026 .125 r
F
.54654 .11654 m .5448 .11415 L .54807 .11282 L F
.71897 .11546 m .7208 .11197 L .72235 .11425 L 0 .024 .123 r
F
.71897 .11546 m .71742 .11319 L .7208 .11197 L F
.50011 .11638 m .50156 .11276 L .50336 .11508 L 0 .026 .125 r
F
.50011 .11638 m .49831 .11408 L .50156 .11276 L F
.60126 .11648 m .60289 .11295 L .60457 .11526 L F
.60126 .11648 m .59958 .11415 L .60289 .11295 L F
.55483 .11625 m .55637 .11261 L .5581 .11496 L 0 .026 .124 r
F
.55483 .11625 m .55309 .1139 L .55637 .11261 L F
.50839 .1161 m .50986 .11245 L .51164 .11478 L 0 .025 .124 r
F
.50839 .1161 m .5066 .11378 L .50986 .11245 L F
.51667 .11571 m .51815 .11217 L .51993 .11444 L F
.51667 .11571 m .5149 .11345 L .51815 .11217 L F
.45367 .11642 m .45504 .11296 L .45689 .11517 L 0 .026 .125 r
F
.45367 .11642 m .45182 .11424 L .45504 .11296 L F
.66427 .11598 m .666 .11248 L .66761 .1148 L 0 .026 .124 r
F
.66427 .11598 m .66265 .11366 L .666 .11248 L F
.56311 .11601 m .56467 .11243 L .56639 .1148 L F
.56311 .11601 m .56138 .11366 L .56467 .11243 L F
.72727 .11533 m .72911 .11177 L .73066 .11408 L 0 .024 .123 r
F
.72727 .11533 m .72573 .11304 L .72911 .11177 L F
.60955 .11628 m .61119 .11262 L .61286 .11492 L 0 .026 .125 r
F
.60955 .11628 m .60788 .11398 L .61119 .11262 L F
.61783 .11587 m .61948 .11221 L .62115 .11454 L 0 .025 .124 r
F
.61783 .11587 m .61617 .11355 L .61948 .11221 L F
.46195 .11613 m .46334 .11263 L .46517 .11488 L 0 .026 .125 r
F
.46195 .11613 m .46011 .11391 L .46334 .11263 L F
.52495 .1155 m .52645 .11204 L .52822 .11429 L 0 .025 .124 r
F
.52495 .1155 m .52319 .11324 L .52645 .11204 L F
.62612 .11555 m .62779 .11191 L .62944 .11424 L 0 .025 .123 r
F
.62612 .11555 m .62446 .11322 L .62779 .11191 L F
.73558 .11512 m .73742 .11151 L .73896 .11384 L 0 .024 .123 r
F
.73558 .11512 m .73404 .1128 L .73742 .11151 L F
.47023 .11591 m .47163 .11232 L .47346 .11464 L 0 .026 .125 r
F
.47023 .11591 m .4684 .1136 L .47163 .11232 L F
.67257 .11593 m .67432 .11234 L .67592 .11465 L F
.67257 .11593 m .67097 .11361 L .67432 .11234 L F
.5714 .11595 m .57297 .11238 L .57469 .11475 L F
.5714 .11595 m .56968 .1136 L .57297 .11238 L F
.63441 .11532 m .6361 .11177 L .63774 .1141 L 0 .025 .124 r
F
.63441 .11532 m .63277 .11301 L .6361 .11177 L F
.53324 .11544 m .53475 .11193 L .53651 .11427 L F
.53324 .11544 m .53148 .11311 L .53475 .11193 L F
.68087 .1157 m .68262 .112 L .68422 .11436 L 0 .026 .124 r
F
.68087 .1157 m .67927 .11332 L .68262 .112 L F
.57969 .11575 m .58128 .11219 L .58298 .11448 L 0 .026 .125 r
F
.57969 .11575 m .57798 .11347 L .58128 .11219 L F
.47851 .11576 m .47992 .11215 L .48174 .11449 L F
.47851 .11576 m .47669 .11339 L .47992 .11215 L F
.64271 .11512 m .6444 .11152 L .64604 .11384 L 0 .025 .123 r
F
.64271 .11512 m .64107 .11283 L .6444 .11152 L F
.68916 .11546 m .69094 .11189 L .69252 .11422 L 0 .026 .124 r
F
.68916 .11546 m .68758 .11313 L .69094 .11189 L F
.58798 .11552 m .58958 .11201 L .59128 .11428 L 0 .026 .125 r
F
.58798 .11552 m .58628 .11324 L .58958 .11201 L F
.48679 .11556 m .48822 .11201 L .49003 .11432 L F
.48679 .11556 m .48498 .11324 L .48822 .11201 L F
.651 .11488 m .65271 .11135 L .65434 .11369 L 0 .025 .123 r
F
.651 .11488 m .64937 .11255 L .65271 .11135 L F
.69746 .1152 m .69924 .11156 L .70082 .11385 L 0 .025 .124 r
F
.69746 .1152 m .69588 .11292 L .69924 .11156 L F
.54153 .11548 m .54305 .11175 L .5448 .11415 L 0 .026 .125 r
F
.54153 .11548 m .53978 .11307 L .54305 .11175 L F
.70575 .11482 m .70755 .11117 L .70912 .11349 L 0 .025 .123 r
F
.70575 .11482 m .70418 .1125 L .70755 .11117 L F
.59627 .11535 m .59789 .11184 L .59958 .11415 L 0 .026 .125 r
F
.59627 .11535 m .59458 .11303 L .59789 .11184 L F
.49507 .11537 m .49652 .11178 L .49831 .11408 L F
.49507 .11537 m .49327 .11308 L .49652 .11178 L F
.71405 .11449 m .71586 .11085 L .71742 .11319 L 0 .024 .123 r
F
.71405 .11449 m .71248 .11216 L .71586 .11085 L F
.54981 .11521 m .55135 .11152 L .55309 .1139 L 0 .026 .124 r
F
.54981 .11521 m .54807 .11282 L .55135 .11152 L F
.65931 .11485 m .66103 .11133 L .66265 .11366 L 0 .025 .124 r
F
.65931 .11485 m .65769 .11251 L .66103 .11133 L F
.50336 .11508 m .50482 .11144 L .5066 .11378 L 0 .026 .124 r
F
.50336 .11508 m .50156 .11276 L .50482 .11144 L F
.72235 .11425 m .72418 .11074 L .72573 .11304 L 0 .024 .123 r
F
.72235 .11425 m .7208 .11197 L .72418 .11074 L F
.5581 .11496 m .55965 .11131 L .56138 .11366 L 0 .025 .124 r
F
.5581 .11496 m .55637 .11261 L .55965 .11131 L F
.51164 .11478 m .51312 .11111 L .5149 .11345 L F
.51164 .11478 m .50986 .11245 L .51312 .11111 L F
.60457 .11526 m .6062 .11168 L .60788 .11398 L 0 .026 .125 r
F
.60457 .11526 m .60289 .11295 L .6062 .11168 L F
.51993 .11444 m .52142 .11098 L .52319 .11324 L 0 .025 .124 r
F
.51993 .11444 m .51815 .11217 L .52142 .11098 L F
.61286 .11492 m .6145 .11126 L .61617 .11355 L 0 .026 .124 r
F
.61286 .11492 m .61119 .11262 L .6145 .11126 L F
.45689 .11517 m .45827 .11168 L .46011 .11391 L 0 .026 .125 r
F
.45689 .11517 m .45504 .11296 L .45827 .11168 L F
.73066 .11408 m .7325 .11047 L .73404 .1128 L 0 .024 .123 r
F
.73066 .11408 m .72911 .11177 L .7325 .11047 L F
.62115 .11454 m .6228 .11089 L .62446 .11322 L 0 .025 .124 r
F
.62115 .11454 m .61948 .11221 L .6228 .11089 L F
.66761 .1148 m .66936 .11131 L .67097 .11361 L 0 .026 .125 r
F
.66761 .1148 m .666 .11248 L .66936 .11131 L F
.56639 .1148 m .56796 .11122 L .56968 .1136 L 0 .026 .124 r
F
.56639 .1148 m .56467 .11243 L .56796 .11122 L F
.46517 .11488 m .46657 .11133 L .4684 .1136 L 0 .026 .125 r
F
.46517 .11488 m .46334 .11263 L .46657 .11133 L F
.62944 .11424 m .63111 .11065 L .63277 .11301 L 0 .025 .123 r
F
.62944 .11424 m .62779 .11191 L .63111 .11065 L F
.52822 .11429 m .52972 .11085 L .53148 .11311 L 0 .025 .124 r
F
.52822 .11429 m .52645 .11204 L .52972 .11085 L F
.47346 .11464 m .47487 .11108 L .47669 .11339 L 0 .026 .125 r
F
.47346 .11464 m .47163 .11232 L .47487 .11108 L F
.67592 .11465 m .67767 .11102 L .67927 .11332 L F
.67592 .11465 m .67432 .11234 L .67767 .11102 L F
.57469 .11475 m .57627 .11109 L .57798 .11347 L F
.57469 .11475 m .57297 .11238 L .57627 .11109 L F
.63774 .1141 m .63943 .11049 L .64107 .11283 L 0 .025 .124 r
F
.63774 .1141 m .6361 .11177 L .63943 .11049 L F
.68422 .11436 m .68598 .11078 L .68758 .11313 L F
.68422 .11436 m .68262 .112 L .68598 .11078 L F
.58298 .11448 m .58458 .11095 L .58628 .11324 L 0 .026 .125 r
F
.58298 .11448 m .58128 .11219 L .58458 .11095 L F
.48174 .11449 m .48317 .11091 L .48498 .11324 L F
.48174 .11449 m .47992 .11215 L .48317 .11091 L F
.53651 .11427 m .53802 .11073 L .53978 .11307 L 0 .026 .124 r
F
.53651 .11427 m .53475 .11193 L .53802 .11073 L F
.64604 .11384 m .64774 .11021 L .64937 .11255 L 0 .025 .123 r
F
.64604 .11384 m .6444 .11152 L .64774 .11021 L F
.69252 .11422 m .6943 .1106 L .69588 .11292 L 0 .026 .124 r
F
.69252 .11422 m .69094 .11189 L .6943 .1106 L F
.59128 .11428 m .59289 .11078 L .59458 .11303 L 0 .026 .125 r
F
.59128 .11428 m .58958 .11201 L .59289 .11078 L F
.70082 .11385 m .70261 .11019 L .70418 .1125 L 0 .025 .124 r
F
.70082 .11385 m .69924 .11156 L .70261 .11019 L F
.49003 .11432 m .49146 .11079 L .49327 .11308 L 0 .026 .125 r
F
.49003 .11432 m .48822 .11201 L .49146 .11079 L F
.65434 .11369 m .65606 .11017 L .65769 .11251 L 0 .025 .124 r
F
.65434 .11369 m .65271 .11135 L .65606 .11017 L F
.5448 .11415 m .54633 .11043 L .54807 .11282 L F
.5448 .11415 m .54305 .11175 L .54633 .11043 L F
.70912 .11349 m .71092 .10983 L .71248 .11216 L 0 .024 .123 r
F
.70912 .11349 m .70755 .11117 L .71092 .10983 L F
.49831 .11408 m .49977 .11045 L .50156 .11276 L 0 .026 .125 r
F
.49831 .11408 m .49652 .11178 L .49977 .11045 L F
.71742 .11319 m .71924 .10961 L .7208 .11197 L 0 .024 .123 r
F
.71742 .11319 m .71586 .11085 L .71924 .10961 L F
.55309 .1139 m .55463 .11024 L .55637 .11261 L 0 .025 .124 r
F
.55309 .1139 m .55135 .11152 L .55463 .11024 L F
.59958 .11415 m .6012 .11065 L .60289 .11295 L 0 .026 .125 r
F
.59958 .11415 m .59789 .11184 L .6012 .11065 L F
.5066 .11378 m .50807 .1101 L .50986 .11245 L 0 .025 .124 r
F
.5066 .11378 m .50482 .11144 L .50807 .1101 L F
.66265 .11366 m .66439 .11016 L .666 .11248 L F
.66265 .11366 m .66103 .11133 L .66439 .11016 L F
.56138 .11366 m .56294 .11007 L .56467 .11243 L F
.56138 .11366 m .55965 .11131 L .56294 .11007 L F
.5149 .11345 m .51638 .10982 L .51815 .11217 L F
.5149 .11345 m .51312 .11111 L .51638 .10982 L F
.72573 .11304 m .72757 .10946 L .72911 .11177 L 0 .024 .123 r
F
.72573 .11304 m .72418 .11074 L .72757 .10946 L F
.60788 .11398 m .60951 .11032 L .61119 .11262 L 0 .026 .125 r
F
.60788 .11398 m .6062 .11168 L .60951 .11032 L F
.61617 .11355 m .61782 .10994 L .61948 .11221 L 0 .025 .124 r
F
.61617 .11355 m .6145 .11126 L .61782 .10994 L F
.46011 .11391 m .4615 .11038 L .46334 .11263 L 0 .026 .125 r
F
.46011 .11391 m .45827 .11168 L .4615 .11038 L F
.62446 .11322 m .62613 .10957 L .62779 .11191 L 0 .025 .123 r
F
.62446 .11322 m .6228 .11089 L .62613 .10957 L F
.52319 .11324 m .52468 .10979 L .52645 .11204 L 0 .025 .124 r
F
.52319 .11324 m .52142 .11098 L .52468 .10979 L F
.73404 .1128 m .73588 .10916 L .73742 .11151 L 0 .024 .122 r
F
.73404 .1128 m .7325 .11047 L .73588 .10916 L F
.4684 .1136 m .4698 .11003 L .47163 .11232 L 0 .026 .125 r
F
.4684 .1136 m .46657 .11133 L .4698 .11003 L F
.56968 .1136 m .57125 .10997 L .57297 .11238 L F
.56968 .1136 m .56796 .11122 L .57125 .10997 L F
.67097 .11361 m .67271 .11004 L .67432 .11234 L F
.67097 .11361 m .66936 .11131 L .67271 .11004 L F
.63277 .11301 m .63444 .1094 L .6361 .11177 L 0 .025 .123 r
F
.63277 .11301 m .63111 .11065 L .63444 .1094 L F
.67927 .11332 m .68102 .10972 L .68262 .112 L 0 .025 .124 r
F
.67927 .11332 m .67767 .11102 L .68102 .10972 L F
.53148 .11311 m .53299 .10966 L .53475 .11193 L F
.53148 .11311 m .52972 .11085 L .53299 .10966 L F
.47669 .11339 m .4781 .10985 L .47992 .11215 L 0 .026 .125 r
F
.47669 .11339 m .47487 .11108 L .4781 .10985 L F
.57798 .11347 m .57957 .1098 L .58128 .11219 L F
.57798 .11347 m .57627 .11109 L .57957 .1098 L F
.64107 .11283 m .64276 .10916 L .6444 .11152 L 0 .025 .123 r
F
.64107 .11283 m .63943 .11049 L .64276 .10916 L F
.68758 .11313 m .68935 .10956 L .69094 .11189 L 0 .026 .124 r
F
.68758 .11313 m .68598 .11078 L .68935 .10956 L F
.48498 .11324 m .48641 .1097 L .48822 .11201 L 0 .026 .125 r
F
.48498 .11324 m .48317 .11091 L .48641 .1097 L F
.64937 .11255 m .65108 .10901 L .65271 .11135 L 0 .025 .123 r
F
.64937 .11255 m .64774 .11021 L .65108 .10901 L F
.58628 .11324 m .58788 .10974 L .58958 .11201 L 0 .026 .125 r
F
.58628 .11324 m .58458 .11095 L .58788 .10974 L F
.53978 .11307 m .5413 .10941 L .54305 .11175 L 0 .026 .124 r
F
.53978 .11307 m .53802 .11073 L .5413 .10941 L F
.69588 .11292 m .69767 .10925 L .69924 .11156 L 0 .025 .124 r
F
.69588 .11292 m .6943 .1106 L .69767 .10925 L F
.70418 .1125 m .70598 .10886 L .70755 .11117 L 0 .025 .123 r
F
.70418 .1125 m .70261 .11019 L .70598 .10886 L F
.59458 .11303 m .5962 .10959 L .59789 .11184 L 0 .026 .125 r
F
.59458 .11303 m .59289 .11078 L .5962 .10959 L F
.54807 .11282 m .54961 .10914 L .55135 .11152 L 0 .025 .124 r
F
.54807 .11282 m .54633 .11043 L .54961 .10914 L F
.49327 .11308 m .49471 .10949 L .49652 .11178 L 0 .026 .125 r
F
.49327 .11308 m .49146 .11079 L .49471 .10949 L F
.71248 .11216 m .71429 .10851 L .71586 .11085 L 0 .024 .123 r
F
.71248 .11216 m .71092 .10983 L .71429 .10851 L F
.65769 .11251 m .65941 .10897 L .66103 .11133 L 0 .025 .124 r
F
.65769 .11251 m .65606 .11017 L .65941 .10897 L F
.50156 .11276 m .50302 .10911 L .50482 .11144 L F
.50156 .11276 m .49977 .11045 L .50302 .10911 L F
.55637 .11261 m .55792 .10896 L .55965 .11131 L F
.55637 .11261 m .55463 .11024 L .55792 .10896 L F
.7208 .11197 m .72263 .10837 L .72418 .11074 L 0 .024 .123 r
F
.7208 .11197 m .71924 .10961 L .72263 .10837 L F
.50986 .11245 m .51133 .10876 L .51312 .11111 L 0 .025 .124 r
F
.50986 .11245 m .50807 .1101 L .51133 .10876 L F
.60289 .11295 m .60452 .10939 L .6062 .11168 L 0 .026 .125 r
F
.60289 .11295 m .6012 .11065 L .60452 .10939 L F
.61119 .11262 m .61283 .10896 L .6145 .11126 L 0 .026 .124 r
F
.61119 .11262 m .60951 .11032 L .61283 .10896 L F
.51815 .11217 m .51964 .10862 L .52142 .11098 L 0 .025 .124 r
F
.51815 .11217 m .51638 .10982 L .51964 .10862 L F
.56467 .11243 m .56624 .10883 L .56796 .11122 L F
.56467 .11243 m .56294 .11007 L .56624 .10883 L F
.61948 .11221 m .62114 .10863 L .6228 .11089 L F
.61948 .11221 m .61782 .10994 L .62114 .10863 L F
.72911 .11177 m .73095 .10813 L .7325 .11047 L 0 .024 .123 r
F
.72911 .11177 m .72757 .10946 L .73095 .10813 L F
.666 .11248 m .66774 .10898 L .66936 .11131 L 0 .026 .125 r
F
.666 .11248 m .66439 .11016 L .66774 .10898 L F
.62779 .11191 m .62946 .10829 L .63111 .11065 L 0 .025 .123 r
F
.62779 .11191 m .62613 .10957 L .62946 .10829 L F
.46334 .11263 m .46473 .10906 L .46657 .11133 L 0 .026 .125 r
F
.46334 .11263 m .4615 .11038 L .46473 .10906 L F
.52645 .11204 m .52795 .10858 L .52972 .11085 L 0 .025 .124 r
F
.52645 .11204 m .52468 .10979 L .52795 .10858 L F
.47163 .11232 m .47304 .1088 L .47487 .11108 L 0 .026 .125 r
F
.47163 .11232 m .4698 .11003 L .47304 .1088 L F
.67432 .11234 m .67607 .10874 L .67767 .11102 L F
.67432 .11234 m .67271 .11004 L .67607 .10874 L F
.57297 .11238 m .57455 .10867 L .57627 .11109 L F
.57297 .11238 m .57125 .10997 L .57455 .10867 L F
.68262 .112 m .68439 .10851 L .68598 .11078 L 0 .025 .124 r
F
.68262 .112 m .68102 .10972 L .68439 .10851 L F
.6361 .11177 m .63778 .1081 L .63943 .11049 L 0 .025 .123 r
F
.6361 .11177 m .63444 .1094 L .63778 .1081 L F
.47992 .11215 m .48135 .10862 L .48317 .11091 L 0 .026 .125 r
F
.47992 .11215 m .4781 .10985 L .48135 .10862 L F
.53475 .11193 m .53627 .10845 L .53802 .11073 L 0 .026 .124 r
F
.53475 .11193 m .53299 .10966 L .53627 .10845 L F
.58128 .11219 m .58287 .10856 L .58458 .11095 L 0 .026 .125 r
F
.58128 .11219 m .57957 .1098 L .58287 .10856 L F
.6444 .11152 m .6461 .10784 L .64774 .11021 L 0 .025 .123 r
F
.6444 .11152 m .64276 .10916 L .6461 .10784 L F
.69094 .11189 m .69272 .10829 L .6943 .1106 L 0 .026 .124 r
F
.69094 .11189 m .68935 .10956 L .69272 .10829 L F
.54305 .11175 m .54458 .10809 L .54633 .11043 L 0 .025 .124 r
F
.54305 .11175 m .5413 .10941 L .54458 .10809 L F
.58958 .11201 m .59119 .10853 L .59289 .11078 L 0 .026 .125 r
F
.58958 .11201 m .58788 .10974 L .59119 .10853 L F
.48822 .11201 m .48966 .10849 L .49146 .11079 L F
.48822 .11201 m .48641 .1097 L .48966 .10849 L F
.69924 .11156 m .70103 .1079 L .70261 .11019 L 0 .025 .124 r
F
.69924 .11156 m .69767 .10925 L .70103 .1079 L F
.65271 .11135 m .65443 .10782 L .65606 .11017 L 0 .025 .123 r
F
.65271 .11135 m .65108 .10901 L .65443 .10782 L F
.70755 .11117 m .70935 .10752 L .71092 .10983 L 0 .024 .123 r
F
.70755 .11117 m .70598 .10886 L .70935 .10752 L F
.55135 .11152 m .5529 .10787 L .55463 .11024 L 0 .025 .124 r
F
.55135 .11152 m .54961 .10914 L .5529 .10787 L F
.71586 .11085 m .71768 .10726 L .71924 .10961 L 0 .024 .123 r
F
.71586 .11085 m .71429 .10851 L .71768 .10726 L F
.49652 .11178 m .49797 .10815 L .49977 .11045 L 0 .026 .125 r
F
.49652 .11178 m .49471 .10949 L .49797 .10815 L F
.59789 .11184 m .59951 .1084 L .6012 .11065 L F
.59789 .11184 m .5962 .10959 L .59951 .1084 L F
.50482 .11144 m .50628 .10776 L .50807 .1101 L 0 .025 .124 r
F
.50482 .11144 m .50302 .10911 L .50628 .10776 L F
.55965 .11131 m .56121 .10771 L .56294 .11007 L F
.55965 .11131 m .55792 .10896 L .56121 .10771 L F
.66103 .11133 m .66276 .10777 L .66439 .11016 L F
.66103 .11133 m .65941 .10897 L .66276 .10777 L F
.51312 .11111 m .5146 .10746 L .51638 .10982 L 0 .025 .123 r
F
.51312 .11111 m .51133 .10876 L .5146 .10746 L F
.72418 .11074 m .72601 .10707 L .72757 .10946 L 0 .024 .123 r
F
.72418 .11074 m .72263 .10837 L .72601 .10707 L F
.6062 .11168 m .60783 .10804 L .60951 .11032 L 0 .026 .125 r
F
.6062 .11168 m .60452 .10939 L .60783 .10804 L F
.6145 .11126 m .61615 .10766 L .61782 .10994 L 0 .025 .124 r
F
.6145 .11126 m .61283 .10896 L .61615 .10766 L F
.6228 .11089 m .62447 .10732 L .62613 .10957 L 0 .025 .123 r
F
.6228 .11089 m .62114 .10863 L .62447 .10732 L F
.7325 .11047 m .73434 .1068 L .73588 .10916 L 0 .024 .122 r
F
.7325 .11047 m .73095 .10813 L .73434 .1068 L F
.52142 .11098 m .52291 .10742 L .52468 .10979 L 0 .025 .124 r
F
.52142 .11098 m .51964 .10862 L .52291 .10742 L F
.56796 .11122 m .56953 .10756 L .57125 .10997 L F
.56796 .11122 m .56624 .10883 L .56953 .10756 L F
.66936 .11131 m .6711 .10773 L .67271 .11004 L 0 .026 .125 r
F
.66936 .11131 m .66774 .10898 L .6711 .10773 L F
.46657 .11133 m .46797 .10773 L .4698 .11003 L F
.46657 .11133 m .46473 .10906 L .46797 .10773 L F
.63111 .11065 m .63279 .10701 L .63444 .1094 L 0 .025 .123 r
F
.63111 .11065 m .62946 .10829 L .63279 .10701 L F
.67767 .11102 m .67943 .10745 L .68102 .10972 L 0 .026 .124 r
F
.67767 .11102 m .67607 .10874 L .67943 .10745 L F
.52972 .11085 m .53123 .10738 L .53299 .10966 L F
.52972 .11085 m .52795 .10858 L .53123 .10738 L F
.47487 .11108 m .47628 .10757 L .4781 .10985 L 0 .026 .125 r
F
.47487 .11108 m .47304 .1088 L .47628 .10757 L F
.57627 .11109 m .57785 .10736 L .57957 .1098 L 0 .026 .124 r
F
.57627 .11109 m .57455 .10867 L .57785 .10736 L F
.63943 .11049 m .64112 .10677 L .64276 .10916 L 0 .025 .123 r
F
.63943 .11049 m .63778 .1081 L .64112 .10677 L F
.68598 .11078 m .68776 .1073 L .68935 .10956 L 0 .026 .124 r
F
.68598 .11078 m .68439 .10851 L .68776 .1073 L F
.64774 .11021 m .64945 .10663 L .65108 .10901 L 0 .025 .123 r
F
.64774 .11021 m .6461 .10784 L .64945 .10663 L F
.48317 .11091 m .48459 .10742 L .48641 .1097 L 0 .026 .125 r
F
.48317 .11091 m .48135 .10862 L .48459 .10742 L F
.58458 .11095 m .58618 .10735 L .58788 .10974 L F
.58458 .11095 m .58287 .10856 L .58618 .10735 L F
.53802 .11073 m .53955 .10713 L .5413 .10941 L 0 .026 .124 r
F
.53802 .11073 m .53627 .10845 L .53955 .10713 L F
.6943 .1106 m .69608 .10694 L .69767 .10925 L 0 .025 .124 r
F
.6943 .1106 m .69272 .10829 L .69608 .10694 L F
.70261 .11019 m .70441 .10657 L .70598 .10886 L 0 .025 .123 r
F
.70261 .11019 m .70103 .1079 L .70441 .10657 L F
.54633 .11043 m .54786 .1068 L .54961 .10914 L 0 .025 .124 r
F
.54633 .11043 m .54458 .10809 L .54786 .1068 L F
.71092 .10983 m .71273 .10621 L .71429 .10851 L 0 .024 .123 r
F
.71092 .10983 m .70935 .10752 L .71273 .10621 L F
.59289 .11078 m .59451 .10734 L .5962 .10959 L 0 .026 .125 r
F
.59289 .11078 m .59119 .10853 L .59451 .10734 L F
.49146 .11079 m .49291 .1072 L .49471 .10949 L F
.49146 .11079 m .48966 .10849 L .49291 .1072 L F
.65606 .11017 m .65778 .10661 L .65941 .10897 L 0 .025 .124 r
F
.65606 .11017 m .65443 .10782 L .65778 .10661 L F
.49977 .11045 m .50123 .10681 L .50302 .10911 L F
.49977 .11045 m .49797 .10815 L .50123 .10681 L F
.55463 .11024 m .55618 .10661 L .55792 .10896 L F
.55463 .11024 m .5529 .10787 L .55618 .10661 L F
.71924 .10961 m .72107 .106 L .72263 .10837 L 0 .024 .123 r
F
.71924 .10961 m .71768 .10726 L .72107 .106 L F
.50807 .1101 m .50954 .10641 L .51133 .10876 L 0 .025 .124 r
F
.50807 .1101 m .50628 .10776 L .50954 .10641 L F
.6012 .11065 m .60283 .10714 L .60452 .10939 L 0 .026 .125 r
F
.6012 .11065 m .59951 .1084 L .60283 .10714 L F
.51638 .10982 m .51786 .10624 L .51964 .10862 L 0 .025 .123 r
F
.51638 .10982 m .5146 .10746 L .51786 .10624 L F
.56294 .11007 m .56451 .10647 L .56624 .10883 L 0 .025 .124 r
F
.56294 .11007 m .56121 .10771 L .56451 .10647 L F
.60951 .11032 m .61115 .10668 L .61283 .10896 L 0 .026 .125 r
F
.60951 .11032 m .60783 .10804 L .61115 .10668 L F
.72757 .10946 m .7294 .10574 L .73095 .10813 L 0 .024 .122 r
F
.72757 .10946 m .72601 .10707 L .7294 .10574 L F
.66439 .11016 m .66612 .10658 L .66774 .10898 L 0 .026 .124 r
F
.66439 .11016 m .66276 .10777 L .66612 .10658 L F
.61782 .10994 m .61948 .10636 L .62114 .10863 L 0 .025 .124 r
F
.61782 .10994 m .61615 .10766 L .61948 .10636 L F
.62613 .10957 m .6278 .10603 L .62946 .10829 L 0 .025 .123 r
F
.62613 .10957 m .62447 .10732 L .6278 .10603 L F
.57125 .10997 m .57283 .10625 L .57455 .10867 L 0 .025 .124 r
F
.57125 .10997 m .56953 .10756 L .57283 .10625 L F
.52468 .10979 m .52618 .1062 L .52795 .10858 L F
.52468 .10979 m .52291 .10742 L .52618 .1062 L F
.4698 .11003 m .47121 .10651 L .47304 .1088 L 0 .026 .125 r
F
.4698 .11003 m .46797 .10773 L .47121 .10651 L F
.67271 .11004 m .67446 .10643 L .67607 .10874 L F
.67271 .11004 m .6711 .10773 L .67446 .10643 L F
.63444 .1094 m .63613 .1057 L .63778 .1081 L 0 .025 .123 r
F
.63444 .1094 m .63279 .10701 L .63613 .1057 L F
.68102 .10972 m .68279 .10625 L .68439 .10851 L 0 .026 .124 r
F
.68102 .10972 m .67943 .10745 L .68279 .10625 L F
.57957 .1098 m .58116 .10612 L .58287 .10856 L F
.57957 .1098 m .57785 .10736 L .58116 .10612 L F
.4781 .10985 m .47953 .10636 L .48135 .10862 L 0 .026 .125 r
F
.4781 .10985 m .47628 .10757 L .47953 .10636 L F
.64276 .10916 m .64446 .10543 L .6461 .10784 L 0 .024 .123 r
F
.64276 .10916 m .64112 .10677 L .64446 .10543 L F
.53299 .10966 m .53451 .10616 L .53627 .10845 L 0 .026 .124 r
F
.53299 .10966 m .53123 .10738 L .53451 .10616 L F
.68935 .10956 m .69113 .10603 L .69272 .10829 L F
.68935 .10956 m .68776 .1073 L .69113 .10603 L F
.5413 .10941 m .54283 .1058 L .54458 .10809 L 0 .025 .124 r
F
.5413 .10941 m .53955 .10713 L .54283 .1058 L F
.48641 .1097 m .48784 .10622 L .48966 .10849 L 0 .026 .125 r
F
.48641 .1097 m .48459 .10742 L .48784 .10622 L F
.65108 .10901 m .6528 .10543 L .65443 .10782 L 0 .025 .123 r
F
.65108 .10901 m .64945 .10663 L .6528 .10543 L F
.69767 .10925 m .69945 .10559 L .70103 .1079 L 0 .025 .124 r
F
.69767 .10925 m .69608 .10694 L .69945 .10559 L F
.58788 .10974 m .58949 .10615 L .59119 .10853 L 0 .026 .125 r
F
.58788 .10974 m .58618 .10735 L .58949 .10615 L F
.70598 .10886 m .70778 .10525 L .70935 .10752 L 0 .025 .123 r
F
.70598 .10886 m .70441 .10657 L .70778 .10525 L F
.54961 .10914 m .55115 .10555 L .5529 .10787 L 0 .025 .124 r
F
.54961 .10914 m .54786 .1068 L .55115 .10555 L F
.71429 .10851 m .71612 .10494 L .71768 .10726 L 0 .024 .122 r
F
.71429 .10851 m .71273 .10621 L .71612 .10494 L F
.49471 .10949 m .49616 .10586 L .49797 .10815 L 0 .026 .125 r
F
.49471 .10949 m .49291 .1072 L .49616 .10586 L F
.50302 .10911 m .50449 .10547 L .50628 .10776 L 0 .025 .124 r
F
.50302 .10911 m .50123 .10681 L .50449 .10547 L F
.5962 .10959 m .59782 .10615 L .59951 .1084 L 0 .026 .125 r
F
.5962 .10959 m .59451 .10734 L .59782 .10615 L F
.55792 .10896 m .55948 .10536 L .56121 .10771 L 0 .025 .124 r
F
.55792 .10896 m .55618 .10661 L .55948 .10536 L F
.65941 .10897 m .66114 .10539 L .66276 .10777 L F
.65941 .10897 m .65778 .10661 L .66114 .10539 L F
.51133 .10876 m .51281 .10511 L .5146 .10746 L 0 .025 .123 r
F
.51133 .10876 m .50954 .10641 L .51281 .10511 L F
.72263 .10837 m .72445 .10469 L .72601 .10707 L 0 .024 .122 r
F
.72263 .10837 m .72107 .106 L .72445 .10469 L F
.60452 .10939 m .60615 .10578 L .60783 .10804 L 0 .026 .125 r
F
.60452 .10939 m .60283 .10714 L .60615 .10578 L F
.61283 .10896 m .61448 .10538 L .61615 .10766 L 0 .025 .124 r
F
.61283 .10896 m .61115 .10668 L .61448 .10538 L F
.73095 .10813 m .73279 .1044 L .73434 .1068 L 0 .024 .122 r
F
.73095 .10813 m .7294 .10574 L .73279 .1044 L F
.56624 .10883 m .56781 .1052 L .56953 .10756 L 0 .025 .124 r
F
.56624 .10883 m .56451 .10647 L .56781 .1052 L F
.51964 .10862 m .52113 .10503 L .52291 .10742 L F
.51964 .10862 m .51786 .10624 L .52113 .10503 L F
.62114 .10863 m .62281 .10507 L .62447 .10732 L F
.62114 .10863 m .61948 .10636 L .62281 .10507 L F
.66774 .10898 m .66948 .10531 L .6711 .10773 L 0 .026 .125 r
F
.66774 .10898 m .66612 .10658 L .66948 .10531 L F
.62946 .10829 m .63114 .10475 L .63279 .10701 L 0 .025 .123 r
F
.62946 .10829 m .6278 .10603 L .63114 .10475 L F
.57455 .10867 m .57613 .10493 L .57785 .10736 L 0 .025 .124 r
F
.57455 .10867 m .57283 .10625 L .57613 .10493 L F
.67607 .10874 m .67782 .10515 L .67943 .10745 L 0 .026 .124 r
F
.67607 .10874 m .67446 .10643 L .67782 .10515 L F
.63778 .1081 m .63947 .10436 L .64112 .10677 L 0 .024 .123 r
F
.63778 .1081 m .63613 .1057 L .63947 .10436 L F
.47304 .1088 m .47445 .1053 L .47628 .10757 L 0 .026 .125 r
F
.47304 .1088 m .47121 .10651 L .47445 .1053 L F
.52795 .10858 m .52946 .10498 L .53123 .10738 L 0 .025 .124 r
F
.52795 .10858 m .52618 .1062 L .52946 .10498 L F
.68439 .10851 m .68617 .10505 L .68776 .1073 L 0 .026 .125 r
F
.68439 .10851 m .68279 .10625 L .68617 .10505 L F
.6461 .10784 m .6478 .10422 L .64945 .10663 L 0 .024 .123 r
F
.6461 .10784 m .64446 .10543 L .6478 .10422 L F
.58287 .10856 m .58447 .10492 L .58618 .10735 L 0 .026 .124 r
F
.58287 .10856 m .58116 .10612 L .58447 .10492 L F
.48135 .10862 m .48277 .10516 L .48459 .10742 L 0 .026 .125 r
F
.48135 .10862 m .47953 .10636 L .48277 .10516 L F
.53627 .10845 m .53779 .10484 L .53955 .10713 L 0 .026 .124 r
F
.53627 .10845 m .53451 .10616 L .53779 .10484 L F
.69272 .10829 m .6945 .10468 L .69608 .10694 L 0 .025 .124 r
F
.69272 .10829 m .69113 .10603 L .6945 .10468 L F
.54458 .10809 m .54611 .10452 L .54786 .1068 L F
.54458 .10809 m .54283 .1058 L .54611 .10452 L F
.70103 .1079 m .70283 .10428 L .70441 .10657 L 0 .025 .123 r
F
.70103 .1079 m .69945 .10559 L .70283 .10428 L F
.70935 .10752 m .71117 .10395 L .71273 .10621 L 0 .024 .123 r
F
.70935 .10752 m .70778 .10525 L .71117 .10395 L F
.48966 .10849 m .4911 .10493 L .49291 .1072 L 0 .026 .125 r
F
.48966 .10849 m .48784 .10622 L .4911 .10493 L F
.65443 .10782 m .65615 .10422 L .65778 .10661 L 0 .025 .123 r
F
.65443 .10782 m .6528 .10543 L .65615 .10422 L F
.59119 .10853 m .59281 .10495 L .59451 .10734 L 0 .026 .125 r
F
.59119 .10853 m .58949 .10615 L .59281 .10495 L F
.5529 .10787 m .55444 .10429 L .55618 .10661 L 0 .025 .124 r
F
.5529 .10787 m .55115 .10555 L .55444 .10429 L F
.49797 .10815 m .49943 .10451 L .50123 .10681 L 0 .026 .124 r
F
.49797 .10815 m .49616 .10586 L .49943 .10451 L F
.71768 .10726 m .71951 .10366 L .72107 .106 L 0 .024 .122 r
F
.71768 .10726 m .71612 .10494 L .71951 .10366 L F
.50628 .10776 m .50775 .10412 L .50954 .10641 L 0 .025 .124 r
F
.50628 .10776 m .50449 .10547 L .50775 .10412 L F
.5146 .10746 m .51608 .10388 L .51786 .10624 L 0 .025 .123 r
F
.5146 .10746 m .51281 .10511 L .51608 .10388 L F
.59951 .1084 m .60114 .10488 L .60283 .10714 L 0 .026 .126 r
F
.59951 .1084 m .59782 .10615 L .60114 .10488 L F
.56121 .10771 m .56278 .10411 L .56451 .10647 L 0 .025 .124 r
F
.56121 .10771 m .55948 .10536 L .56278 .10411 L F
.72601 .10707 m .72784 .10334 L .7294 .10574 L 0 .024 .122 r
F
.72601 .10707 m .72445 .10469 L .72784 .10334 L F
.66276 .10777 m .6645 .10416 L .66612 .10658 L 0 .025 .124 r
F
.66276 .10777 m .66114 .10539 L .6645 .10416 L F
.60783 .10804 m .60947 .10442 L .61115 .10668 L 0 .026 .125 r
F
.60783 .10804 m .60615 .10578 L .60947 .10442 L F
.61615 .10766 m .61781 .1041 L .61948 .10636 L 0 .025 .124 r
F
.61615 .10766 m .61448 .10538 L .61781 .1041 L F
.62447 .10732 m .62614 .10378 L .6278 .10603 L F
.62447 .10732 m .62281 .10507 L .62614 .10378 L F
.56953 .10756 m .57111 .10389 L .57283 .10625 L F
.56953 .10756 m .56781 .1052 L .57111 .10389 L F
.52291 .10742 m .52441 .10379 L .52618 .1062 L F
.52291 .10742 m .52113 .10503 L .52441 .10379 L F
.63279 .10701 m .63448 .10343 L .63613 .1057 L 0 .025 .123 r
F
.63279 .10701 m .63114 .10475 L .63448 .10343 L F
.6711 .10773 m .67284 .10402 L .67446 .10643 L 0 .026 .124 r
F
.6711 .10773 m .66948 .10531 L .67284 .10402 L F
.57785 .10736 m .57944 .10369 L .58116 .10612 L 0 .025 .124 r
F
.57785 .10736 m .57613 .10493 L .57944 .10369 L F
.67943 .10745 m .68119 .10396 L .68279 .10625 L 0 .026 .125 r
F
.67943 .10745 m .67782 .10515 L .68119 .10396 L F
.64112 .10677 m .64281 .10303 L .64446 .10543 L 0 .024 .122 r
F
.64112 .10677 m .63947 .10436 L .64281 .10303 L F
.47628 .10757 m .4777 .10409 L .47953 .10636 L 0 .026 .125 r
F
.47628 .10757 m .47445 .1053 L .4777 .10409 L F
.53123 .10738 m .53274 .10374 L .53451 .10616 L 0 .026 .124 r
F
.53123 .10738 m .52946 .10498 L .53274 .10374 L F
.68776 .1073 m .68954 .10378 L .69113 .10603 L 0 .026 .125 r
F
.68776 .1073 m .68617 .10505 L .68954 .10378 L F
.64945 .10663 m .65116 .10302 L .6528 .10543 L 0 .025 .123 r
F
.64945 .10663 m .6478 .10422 L .65116 .10302 L F
.58618 .10735 m .58778 .10371 L .58949 .10615 L 0 .026 .125 r
F
.58618 .10735 m .58447 .10492 L .58778 .10371 L F
.53955 .10713 m .54107 .10352 L .54283 .1058 L 0 .025 .124 r
F
.53955 .10713 m .53779 .10484 L .54107 .10352 L F
.69608 .10694 m .69787 .10333 L .69945 .10559 L F
.69608 .10694 m .6945 .10468 L .69787 .10333 L F
.48459 .10742 m .48603 .10396 L .48784 .10622 L 0 .026 .125 r
F
.48459 .10742 m .48277 .10516 L .48603 .10396 L F
.54786 .1068 m .54941 .10327 L .55115 .10555 L 0 .025 .124 r
F
.54786 .1068 m .54611 .10452 L .54941 .10327 L F
.70441 .10657 m .70621 .10298 L .70778 .10525 L 0 .025 .123 r
F
.70441 .10657 m .70283 .10428 L .70621 .10298 L F
.71273 .10621 m .71455 .10267 L .71612 .10494 L 0 .024 .123 r
F
.71273 .10621 m .71117 .10395 L .71455 .10267 L F
.49291 .1072 m .49436 .10357 L .49616 .10586 L 0 .026 .125 r
F
.49291 .1072 m .4911 .10493 L .49436 .10357 L F
.50123 .10681 m .50269 .10317 L .50449 .10547 L 0 .025 .124 r
F
.50123 .10681 m .49943 .10451 L .50269 .10317 L F
.55618 .10661 m .55774 .10303 L .55948 .10536 L F
.55618 .10661 m .55444 .10429 L .55774 .10303 L F
.65778 .10661 m .65951 .10298 L .66114 .10539 L F
.65778 .10661 m .65615 .10422 L .65951 .10298 L F
.50954 .10641 m .51102 .10282 L .51281 .10511 L 0 .025 .123 r
F
.50954 .10641 m .50775 .10412 L .51102 .10282 L F
.59451 .10734 m .59613 .10375 L .59782 .10615 L 0 .026 .125 r
F
.59451 .10734 m .59281 .10495 L .59613 .10375 L F
.72107 .106 m .7229 .10235 L .72445 .10469 L 0 .024 .122 r
F
.72107 .106 m .71951 .10366 L .7229 .10235 L F
.7294 .10574 m .73124 .102 L .73279 .1044 L F
.7294 .10574 m .72784 .10334 L .73124 .102 L F
.60283 .10714 m .60447 .10352 L .60615 .10578 L 0 .026 .125 r
F
.60283 .10714 m .60114 .10488 L .60447 .10352 L F
.61115 .10668 m .6128 .10312 L .61448 .10538 L 0 .026 .124 r
F
.61115 .10668 m .60947 .10442 L .6128 .10312 L F
.56451 .10647 m .56608 .10284 L .56781 .1052 L 0 .025 .124 r
F
.56451 .10647 m .56278 .10411 L .56608 .10284 L F
.51786 .10624 m .51935 .10266 L .52113 .10503 L 0 .025 .123 r
F
.51786 .10624 m .51608 .10388 L .51935 .10266 L F
.66612 .10658 m .66786 .10289 L .66948 .10531 L 0 .025 .124 r
F
.66612 .10658 m .6645 .10416 L .66786 .10289 L F
.61948 .10636 m .62114 .10281 L .62281 .10507 L F
.61948 .10636 m .61781 .1041 L .62114 .10281 L F
.57283 .10625 m .57441 .10257 L .57613 .10493 L F
.57283 .10625 m .57111 .10389 L .57441 .10257 L F
.6278 .10603 m .62948 .10248 L .63114 .10475 L 0 .025 .123 r
F
.6278 .10603 m .62614 .10378 L .62948 .10248 L F
.63613 .1057 m .63782 .10209 L .63947 .10436 L 0 .024 .123 r
F
.63613 .1057 m .63448 .10343 L .63782 .10209 L F
.52618 .1062 m .52769 .10255 L .52946 .10498 L 0 .025 .124 r
F
.52618 .1062 m .52441 .10379 L .52769 .10255 L F
.67446 .10643 m .67621 .10274 L .67782 .10515 L 0 .026 .124 r
F
.67446 .10643 m .67284 .10402 L .67621 .10274 L F
.58116 .10612 m .58276 .10249 L .58447 .10492 L 0 .025 .124 r
F
.58116 .10612 m .57944 .10369 L .58276 .10249 L F
.64446 .10543 m .64616 .10181 L .6478 .10422 L 0 .024 .122 r
F
.64446 .10543 m .64281 .10303 L .64616 .10181 L F
.68279 .10625 m .68457 .10277 L .68617 .10505 L 0 .026 .125 r
F
.68279 .10625 m .68119 .10396 L .68457 .10277 L F
.47953 .10636 m .48095 .10289 L .48277 .10516 L F
.47953 .10636 m .4777 .10409 L .48095 .10289 L F
.53451 .10616 m .53602 .10242 L .53779 .10484 L 0 .026 .124 r
F
.53451 .10616 m .53274 .10374 L .53602 .10242 L F
.69113 .10603 m .69291 .10243 L .6945 .10468 L F
.69113 .10603 m .68954 .10378 L .69291 .10243 L F
.54283 .1058 m .54436 .10223 L .54611 .10452 L 0 .025 .124 r
F
.54283 .1058 m .54107 .10352 L .54436 .10223 L F
.69945 .10559 m .70125 .10202 L .70283 .10428 L F
.69945 .10559 m .69787 .10333 L .70125 .10202 L F
.6528 .10543 m .65451 .10179 L .65615 .10422 L 0 .025 .123 r
F
.6528 .10543 m .65116 .10302 L .65451 .10179 L F
.58949 .10615 m .5911 .1025 L .59281 .10495 L 0 .026 .125 r
F
.58949 .10615 m .58778 .10371 L .5911 .1025 L F
.70778 .10525 m .7096 .10168 L .71117 .10395 L 0 .025 .123 r
F
.70778 .10525 m .70621 .10298 L .7096 .10168 L F
.48784 .10622 m .48928 .10266 L .4911 .10493 L 0 .026 .125 r
F
.48784 .10622 m .48603 .10396 L .48928 .10266 L F
.55115 .10555 m .5527 .10202 L .55444 .10429 L 0 .025 .124 r
F
.55115 .10555 m .54941 .10327 L .5527 .10202 L F
.49616 .10586 m .49762 .10222 L .49943 .10451 L 0 .026 .124 r
F
.49616 .10586 m .49436 .10357 L .49762 .10222 L F
.71612 .10494 m .71795 .10139 L .71951 .10366 L 0 .024 .123 r
F
.71612 .10494 m .71455 .10267 L .71795 .10139 L F
.50449 .10547 m .50596 .10183 L .50775 .10412 L 0 .025 .124 r
F
.50449 .10547 m .50269 .10317 L .50596 .10183 L F
.51281 .10511 m .51429 .1016 L .51608 .10388 L 0 .025 .123 r
F
.51281 .10511 m .51102 .10282 L .51429 .1016 L F
.55948 .10536 m .56104 .10176 L .56278 .10411 L 0 .025 .124 r
F
.55948 .10536 m .55774 .10303 L .56104 .10176 L F
.72445 .10469 m .72629 .101 L .72784 .10334 L 0 .024 .122 r
F
.72445 .10469 m .7229 .10235 L .72629 .101 L F
.66114 .10539 m .66287 .10174 L .6645 .10416 L 0 .025 .124 r
F
.66114 .10539 m .65951 .10298 L .66287 .10174 L F
.59782 .10615 m .59945 .10249 L .60114 .10488 L 0 .026 .126 r
F
.59782 .10615 m .59613 .10375 L .59945 .10249 L F
.60615 .10578 m .60779 .10215 L .60947 .10442 L 0 .026 .125 r
F
.60615 .10578 m .60447 .10352 L .60779 .10215 L F
.61448 .10538 m .61613 .10185 L .61781 .1041 L 0 .026 .124 r
F
.61448 .10538 m .6128 .10312 L .61613 .10185 L F
.56781 .1052 m .56938 .10152 L .57111 .10389 L 0 .025 .124 r
F
.56781 .1052 m .56608 .10284 L .56938 .10152 L F
.52113 .10503 m .52263 .10141 L .52441 .10379 L F
.52113 .10503 m .51935 .10266 L .52263 .10141 L F
.62281 .10507 m .62448 .10151 L .62614 .10378 L F
.62281 .10507 m .62114 .10281 L .62448 .10151 L F
.66948 .10531 m .67122 .10161 L .67284 .10402 L F
.66948 .10531 m .66786 .10289 L .67122 .10161 L F
.57613 .10493 m .57773 .10133 L .57944 .10369 L F
.57613 .10493 m .57441 .10257 L .57773 .10133 L F
.63114 .10475 m .63282 .10116 L .63448 .10343 L 0 .025 .123 r
F
.63114 .10475 m .62948 .10248 L .63282 .10116 L F
.63947 .10436 m .64116 .10074 L .64281 .10303 L 0 .024 .122 r
F
.63947 .10436 m .63782 .10209 L .64116 .10074 L F
.67782 .10515 m .67958 .10155 L .68119 .10396 L 0 .026 .124 r
F
.67782 .10515 m .67621 .10274 L .67958 .10155 L F
.52946 .10498 m .53097 .10129 L .53274 .10374 L 0 .025 .124 r
F
.52946 .10498 m .52769 .10255 L .53097 .10129 L F
.6478 .10422 m .64952 .1006 L .65116 .10302 L 0 .024 .123 r
F
.6478 .10422 m .64616 .10181 L .64952 .1006 L F
.58447 .10492 m .58607 .10128 L .58778 .10371 L 0 .025 .124 r
F
.58447 .10492 m .58276 .10249 L .58607 .10128 L F
.68617 .10505 m .68795 .1015 L .68954 .10378 L 0 .026 .125 r
F
.68617 .10505 m .68457 .10277 L .68795 .1015 L F
.53779 .10484 m .53931 .10111 L .54107 .10352 L 0 .025 .124 r
F
.53779 .10484 m .53602 .10242 L .53931 .10111 L F
.6945 .10468 m .69629 .10107 L .69787 .10333 L F
.6945 .10468 m .69291 .10243 L .69629 .10107 L F
.48277 .10516 m .4842 .10169 L .48603 .10396 L 0 .026 .126 r
F
.48277 .10516 m .48095 .10289 L .4842 .10169 L F
.70283 .10428 m .70464 .10072 L .70621 .10298 L 0 .025 .123 r
F
.70283 .10428 m .70125 .10202 L .70464 .10072 L F
.54611 .10452 m .54766 .10099 L .54941 .10327 L 0 .025 .124 r
F
.54611 .10452 m .54436 .10223 L .54766 .10099 L F
.71117 .10395 m .71299 .1004 L .71455 .10267 L 0 .024 .123 r
F
.71117 .10395 m .7096 .10168 L .71299 .1004 L F
.65615 .10422 m .65787 .10055 L .65951 .10298 L 0 .025 .123 r
F
.65615 .10422 m .65451 .10179 L .65787 .10055 L F
.4911 .10493 m .49255 .1013 L .49436 .10357 L 0 .026 .125 r
F
.4911 .10493 m .48928 .10266 L .49255 .1013 L F
.59281 .10495 m .59442 .1013 L .59613 .10375 L F
.59281 .10495 m .5911 .1025 L .59442 .1013 L F
.49943 .10451 m .50089 .10088 L .50269 .10317 L 0 .025 .124 r
F
.49943 .10451 m .49762 .10222 L .50089 .10088 L F
.55444 .10429 m .556 .10073 L .55774 .10303 L F
.55444 .10429 m .5527 .10202 L .556 .10073 L F
.50775 .10412 m .50923 .10053 L .51102 .10282 L 0 .025 .123 r
F
.50775 .10412 m .50596 .10183 L .50923 .10053 L F
.71951 .10366 m .72134 .10007 L .7229 .10235 L 0 .024 .122 r
F
.71951 .10366 m .71795 .10139 L .72134 .10007 L F
.72784 .10334 m .72969 .09965 L .73124 .102 L F
.72784 .10334 m .72629 .101 L .72969 .09965 L F
.56278 .10411 m .56434 .10048 L .56608 .10284 L 0 .025 .124 r
F
.56278 .10411 m .56104 .10176 L .56434 .10048 L F
.51608 .10388 m .51757 .10037 L .51935 .10266 L 0 .025 .123 r
F
.51608 .10388 m .51429 .1016 L .51757 .10037 L F
.6645 .10416 m .66624 .10047 L .66786 .10289 L 0 .025 .124 r
F
.6645 .10416 m .66287 .10174 L .66624 .10047 L F
.60947 .10442 m .61112 .10086 L .6128 .10312 L 0 .026 .125 r
F
.60947 .10442 m .60779 .10215 L .61112 .10086 L F
.60114 .10488 m .60277 .10113 L .60447 .10352 L F
.60114 .10488 m .59945 .10249 L .60277 .10113 L F
.61781 .1041 m .61947 .10056 L .62114 .10281 L 0 .025 .124 r
F
.61781 .1041 m .61613 .10185 L .61947 .10056 L F
.57111 .10389 m .57269 .1002 L .57441 .10257 L 0 .025 .123 r
F
.57111 .10389 m .56938 .10152 L .57269 .1002 L F
.62614 .10378 m .62782 .10021 L .62948 .10248 L 0 .025 .124 r
F
.62614 .10378 m .62448 .10151 L .62782 .10021 L F
.52441 .10379 m .52591 .10014 L .52769 .10255 L F
.52441 .10379 m .52263 .10141 L .52591 .10014 L F
.67284 .10402 m .67459 .10033 L .67621 .10274 L F
.67284 .10402 m .67122 .10161 L .67459 .10033 L F
.63448 .10343 m .63617 .09981 L .63782 .10209 L 0 .025 .123 r
F
.63448 .10343 m .63282 .10116 L .63617 .09981 L F
.57944 .10369 m .58104 .10014 L .58276 .10249 L 0 .025 .124 r
F
.57944 .10369 m .57773 .10133 L .58104 .10014 L F
.64281 .10303 m .64452 .09952 L .64616 .10181 L 0 .024 .122 r
F
.64281 .10303 m .64116 .10074 L .64452 .09952 L F
.68119 .10396 m .68296 .10035 L .68457 .10277 L 0 .026 .125 r
F
.68119 .10396 m .67958 .10155 L .68296 .10035 L F
.53274 .10374 m .53426 .09999 L .53602 .10242 L 0 .025 .124 r
F
.53274 .10374 m .53097 .10129 L .53426 .09999 L F
.65116 .10302 m .65287 .09937 L .65451 .10179 L 0 .024 .123 r
F
.65116 .10302 m .64952 .1006 L .65287 .09937 L F
.58778 .10371 m .58939 .10006 L .5911 .1025 L 0 .026 .124 r
F
.58778 .10371 m .58607 .10128 L .58939 .10006 L F
.54107 .10352 m .5426 .09983 L .54436 .10223 L 0 .025 .124 r
F
.54107 .10352 m .53931 .10111 L .5426 .09983 L F
.68954 .10378 m .69132 .10014 L .69291 .10243 L 0 .026 .125 r
F
.68954 .10378 m .68795 .1015 L .69132 .10014 L F
.69787 .10333 m .69967 .09976 L .70125 .10202 L 0 .025 .124 r
F
.69787 .10333 m .69629 .10107 L .69967 .09976 L F
.70621 .10298 m .70803 .09941 L .7096 .10168 L 0 .025 .123 r
F
.70621 .10298 m .70464 .10072 L .70803 .09941 L F
.48603 .10396 m .48746 .10039 L .48928 .10266 L 0 .026 .126 r
F
.48603 .10396 m .4842 .10169 L .48746 .10039 L F
.54941 .10327 m .55095 .09975 L .5527 .10202 L 0 .025 .124 r
F
.54941 .10327 m .54766 .10099 L .55095 .09975 L F
.49436 .10357 m .49581 .09993 L .49762 .10222 L 0 .026 .125 r
F
.49436 .10357 m .49255 .1013 L .49581 .09993 L F
.71455 .10267 m .71639 .09912 L .71795 .10139 L 0 .024 .123 r
F
.71455 .10267 m .71299 .1004 L .71639 .09912 L F
.50269 .10317 m .50416 .09954 L .50596 .10183 L 0 .025 .124 r
F
.50269 .10317 m .50089 .10088 L .50416 .09954 L F
.65951 .10298 m .66124 .09929 L .66287 .10174 L 0 .025 .123 r
F
.65951 .10298 m .65787 .10055 L .66124 .09929 L F
.55774 .10303 m .5593 .09944 L .56104 .10176 L 0 .025 .124 r
F
.55774 .10303 m .556 .10073 L .5593 .09944 L F
.7229 .10235 m .72474 .09872 L .72629 .101 L 0 .024 .122 r
F
.7229 .10235 m .72134 .10007 L .72474 .09872 L F
.51102 .10282 m .5125 .0993 L .51429 .1016 L 0 .025 .123 r
F
.51102 .10282 m .50923 .10053 L .5125 .0993 L F
.59613 .10375 m .59775 .10003 L .59945 .10249 L 0 .026 .125 r
F
.59613 .10375 m .59442 .1013 L .59775 .10003 L F
.60447 .10352 m .6061 .09978 L .60779 .10215 L F
.60447 .10352 m .60277 .10113 L .6061 .09978 L F
.56608 .10284 m .56765 .09916 L .56938 .10152 L 0 .025 .124 r
F
.56608 .10284 m .56434 .10048 L .56765 .09916 L F
.51935 .10266 m .52085 .09911 L .52263 .10141 L 0 .025 .123 r
F
.51935 .10266 m .51757 .10037 L .52085 .09911 L F
.6128 .10312 m .61446 .09959 L .61613 .10185 L 0 .026 .125 r
F
.6128 .10312 m .61112 .10086 L .61446 .09959 L F
.66786 .10289 m .6696 .09919 L .67122 .10161 L 0 .025 .124 r
F
.66786 .10289 m .66624 .10047 L .6696 .09919 L F
.57441 .10257 m .576 .09897 L .57773 .10133 L 0 .025 .123 r
F
.57441 .10257 m .57269 .1002 L .576 .09897 L F
.62114 .10281 m .62281 .09923 L .62448 .10151 L 0 .025 .124 r
F
.62114 .10281 m .61947 .10056 L .62281 .09923 L F
.62948 .10248 m .63116 .09887 L .63282 .10116 L 0 .025 .123 r
F
.62948 .10248 m .62782 .10021 L .63116 .09887 L F
.67621 .10274 m .67797 .09913 L .67958 .10155 L 0 .025 .124 r
F
.67621 .10274 m .67459 .10033 L .67797 .09913 L F
.52769 .10255 m .5292 .09887 L .53097 .10129 L F
.52769 .10255 m .52591 .10014 L .5292 .09887 L F
.63782 .10209 m .63951 .09846 L .64116 .10074 L 0 .024 .123 r
F
.63782 .10209 m .63617 .09981 L .63951 .09846 L F
.58276 .10249 m .58436 .09894 L .58607 .10128 L 0 .025 .124 r
F
.58276 .10249 m .58104 .10014 L .58436 .09894 L F
.64616 .10181 m .64788 .09831 L .64952 .1006 L 0 .024 .123 r
F
.64616 .10181 m .64452 .09952 L .64788 .09831 L F
.53602 .10242 m .53755 .09868 L .53931 .10111 L 0 .025 .124 r
F
.53602 .10242 m .53426 .09999 L .53755 .09868 L F
.68457 .10277 m .68634 .09908 L .68795 .1015 L 0 .026 .125 r
F
.68457 .10277 m .68296 .10035 L .68634 .09908 L F
.69291 .10243 m .6947 .09878 L .69629 .10107 L 0 .026 .124 r
F
.69291 .10243 m .69132 .10014 L .6947 .09878 L F
.54436 .10223 m .5459 .09859 L .54766 .10099 L 0 .025 .124 r
F
.54436 .10223 m .5426 .09983 L .5459 .09859 L F
.70125 .10202 m .70306 .09845 L .70464 .10072 L F
.70125 .10202 m .69967 .09976 L .70306 .09845 L F
.65451 .10179 m .65624 .09811 L .65787 .10055 L 0 .024 .123 r
F
.65451 .10179 m .65287 .09937 L .65624 .09811 L F
.5911 .1025 m .59272 .09884 L .59442 .1013 L 0 .026 .125 r
F
.5911 .1025 m .58939 .10006 L .59272 .09884 L F
.7096 .10168 m .71142 .09812 L .71299 .1004 L 0 .025 .123 r
F
.7096 .10168 m .70803 .09941 L .71142 .09812 L F
.48928 .10266 m .49073 .09901 L .49255 .1013 L 0 .026 .125 r
F
.48928 .10266 m .48746 .10039 L .49073 .09901 L F
.49762 .10222 m .49908 .09859 L .50089 .10088 L 0 .026 .124 r
F
.49762 .10222 m .49581 .09993 L .49908 .09859 L F
.5527 .10202 m .55425 .09843 L .556 .10073 L 0 .025 .124 r
F
.5527 .10202 m .55095 .09975 L .55425 .09843 L F
.50596 .10183 m .50743 .09824 L .50923 .10053 L F
.50596 .10183 m .50416 .09954 L .50743 .09824 L F
.71795 .10139 m .71978 .0978 L .72134 .10007 L 0 .024 .123 r
F
.71795 .10139 m .71639 .09912 L .71978 .0978 L F
.72629 .101 m .72814 .09737 L .72969 .09965 L 0 .024 .122 r
F
.72629 .101 m .72474 .09872 L .72814 .09737 L F
.66287 .10174 m .66461 .09804 L .66624 .10047 L 0 .025 .123 r
F
.66287 .10174 m .66124 .09929 L .66461 .09804 L F
.56104 .10176 m .56261 .09814 L .56434 .10048 L 0 .025 .124 r
F
.56104 .10176 m .5593 .09944 L .56261 .09814 L F
.59945 .10249 m .60108 .09869 L .60277 .10113 L 0 .026 .125 r
F
.59945 .10249 m .59775 .10003 L .60108 .09869 L F
.51429 .1016 m .51578 .09808 L .51757 .10037 L 0 .025 .124 r
F
.51429 .1016 m .5125 .0993 L .51578 .09808 L F
.60779 .10215 m .60944 .0985 L .61112 .10086 L 0 .026 .125 r
F
.60779 .10215 m .6061 .09978 L .60944 .0985 L F
.56938 .10152 m .57096 .09783 L .57269 .1002 L 0 .025 .123 r
F
.56938 .10152 m .56765 .09916 L .57096 .09783 L F
.67122 .10161 m .67298 .09792 L .67459 .10033 L 0 .025 .124 r
F
.67122 .10161 m .6696 .09919 L .67298 .09792 L F
.61613 .10185 m .6178 .0983 L .61947 .10056 L 0 .026 .125 r
F
.61613 .10185 m .61446 .09959 L .6178 .0983 L F
.52263 .10141 m .52413 .09784 L .52591 .10014 L 0 .025 .123 r
F
.52263 .10141 m .52085 .09911 L .52413 .09784 L F
.62448 .10151 m .62615 .0979 L .62782 .10021 L 0 .025 .124 r
F
.62448 .10151 m .62281 .09923 L .62615 .0979 L F
.57773 .10133 m .57932 .09779 L .58104 .10014 L F
.57773 .10133 m .576 .09897 L .57932 .09779 L F
.63282 .10116 m .63451 .09751 L .63617 .09981 L 0 .025 .123 r
F
.63282 .10116 m .63116 .09887 L .63451 .09751 L F
.64116 .10074 m .64287 .09724 L .64452 .09952 L 0 .024 .123 r
F
.64116 .10074 m .63951 .09846 L .64287 .09724 L F
.53097 .10129 m .53249 .09758 L .53426 .09999 L 0 .025 .124 r
F
.53097 .10129 m .5292 .09887 L .53249 .09758 L F
.67958 .10155 m .68135 .09793 L .68296 .10035 L 0 .026 .124 r
F
.67958 .10155 m .67797 .09913 L .68135 .09793 L F
.58607 .10128 m .58768 .09773 L .58939 .10006 L 0 .025 .124 r
F
.58607 .10128 m .58436 .09894 L .58768 .09773 L F
.64952 .1006 m .65124 .09707 L .65287 .09937 L 0 .024 .123 r
F
.64952 .1006 m .64788 .09831 L .65124 .09707 L F
.53931 .10111 m .54084 .09741 L .5426 .09983 L 0 .025 .124 r
F
.53931 .10111 m .53755 .09868 L .54084 .09741 L F
.68795 .1015 m .68972 .09772 L .69132 .10014 L 0 .026 .125 r
F
.68795 .1015 m .68634 .09908 L .68972 .09772 L F
.69629 .10107 m .69809 .09747 L .69967 .09976 L 0 .025 .124 r
F
.69629 .10107 m .6947 .09878 L .69809 .09747 L F
.70464 .10072 m .70645 .09714 L .70803 .09941 L 0 .025 .123 r
F
.70464 .10072 m .70306 .09845 L .70645 .09714 L F
.54766 .10099 m .5492 .09735 L .55095 .09975 L 0 .025 .124 r
F
.54766 .10099 m .5459 .09859 L .5492 .09735 L F
.65787 .10055 m .6596 .09685 L .66124 .09929 L 0 .024 .123 r
F
.65787 .10055 m .65624 .09811 L .6596 .09685 L F
.49255 .1013 m .494 .09763 L .49581 .09993 L 0 .026 .125 r
F
.49255 .1013 m .49073 .09901 L .494 .09763 L F
.59442 .1013 m .59605 .09758 L .59775 .10003 L F
.59442 .1013 m .59272 .09884 L .59605 .09758 L F
.71299 .1004 m .71482 .09683 L .71639 .09912 L 0 .025 .123 r
F
.71299 .1004 m .71142 .09812 L .71482 .09683 L F
.50089 .10088 m .50235 .09725 L .50416 .09954 L 0 .025 .124 r
F
.50089 .10088 m .49908 .09859 L .50235 .09725 L F
.556 .10073 m .55756 .09712 L .5593 .09944 L F
.556 .10073 m .55425 .09843 L .55756 .09712 L F
.50923 .10053 m .51071 .097 L .5125 .0993 L F
.50923 .10053 m .50743 .09824 L .51071 .097 L F
.72134 .10007 m .72318 .09645 L .72474 .09872 L 0 .024 .122 r
F
.72134 .10007 m .71978 .0978 L .72318 .09645 L F
.60277 .10113 m .60441 .09736 L .6061 .09978 L 0 .026 .125 r
F
.60277 .10113 m .60108 .09869 L .60441 .09736 L F
.66624 .10047 m .66798 .09678 L .6696 .09919 L 0 .025 .123 r
F
.66624 .10047 m .66461 .09804 L .66798 .09678 L F
.56434 .10048 m .56592 .0968 L .56765 .09916 L F
.56434 .10048 m .56261 .09814 L .56592 .0968 L F
.51757 .10037 m .51906 .09681 L .52085 .09911 L 0 .025 .124 r
F
.51757 .10037 m .51578 .09808 L .51906 .09681 L F
.61112 .10086 m .61278 .09724 L .61446 .09959 L 0 .026 .125 r
F
.61112 .10086 m .60944 .0985 L .61278 .09724 L F
.57269 .1002 m .57428 .0966 L .576 .09897 L 0 .025 .123 r
F
.57269 .1002 m .57096 .09783 L .57428 .0966 L F
.67459 .10033 m .67636 .09672 L .67797 .09913 L 0 .025 .124 r
F
.67459 .10033 m .67298 .09792 L .67636 .09672 L F
.61947 .10056 m .62114 .09694 L .62281 .09923 L 0 .026 .124 r
F
.61947 .10056 m .6178 .0983 L .62114 .09694 L F
.52591 .10014 m .52742 .09656 L .5292 .09887 L 0 .025 .123 r
F
.52591 .10014 m .52413 .09784 L .52742 .09656 L F
.62782 .10021 m .6295 .09655 L .63116 .09887 L 0 .025 .124 r
F
.62782 .10021 m .62615 .0979 L .6295 .09655 L F
.63617 .09981 m .63786 .09615 L .63951 .09846 L 0 .024 .123 r
F
.63617 .09981 m .63451 .09751 L .63786 .09615 L F
.58104 .10014 m .58265 .0966 L .58436 .09894 L 0 .025 .124 r
F
.58104 .10014 m .57932 .09779 L .58265 .0966 L F
.64452 .09952 m .64623 .09602 L .64788 .09831 L 0 .024 .123 r
F
.64452 .09952 m .64287 .09724 L .64623 .09602 L F
.53426 .09999 m .53578 .09628 L .53755 .09868 L 0 .025 .123 r
F
.53426 .09999 m .53249 .09758 L .53578 .09628 L F
.68296 .10035 m .68474 .09665 L .68634 .09908 L 0 .026 .124 r
F
.68296 .10035 m .68135 .09793 L .68474 .09665 L F
.65287 .09937 m .6546 .0958 L .65624 .09811 L 0 .024 .123 r
F
.65287 .09937 m .65124 .09707 L .6546 .0958 L F
.58939 .10006 m .59101 .09651 L .59272 .09884 L 0 .026 .124 r
F
.58939 .10006 m .58768 .09773 L .59101 .09651 L F
.5426 .09983 m .54414 .09617 L .5459 .09859 L 0 .025 .124 r
F
.5426 .09983 m .54084 .09741 L .54414 .09617 L F
.69132 .10014 m .6931 .09636 L .6947 .09878 L F
.69132 .10014 m .68972 .09772 L .6931 .09636 L F
.69967 .09976 m .70148 .09616 L .70306 .09845 L F
.69967 .09976 m .69809 .09747 L .70148 .09616 L F
.70803 .09941 m .70985 .09583 L .71142 .09812 L 0 .025 .123 r
F
.70803 .09941 m .70645 .09714 L .70985 .09583 L F
.49581 .09993 m .49727 .0963 L .49908 .09859 L 0 .026 .124 r
F
.49581 .09993 m .494 .09763 L .49727 .0963 L F
.55095 .09975 m .5525 .09603 L .55425 .09843 L 0 .025 .124 r
F
.55095 .09975 m .5492 .09735 L .5525 .09603 L F
.66124 .09929 m .66297 .0956 L .66461 .09804 L 0 .025 .123 r
F
.66124 .09929 m .6596 .09685 L .66297 .0956 L F
.50416 .09954 m .50563 .09595 L .50743 .09824 L 0 .025 .124 r
F
.50416 .09954 m .50235 .09725 L .50563 .09595 L F
.59775 .10003 m .59938 .09626 L .60108 .09869 L 0 .026 .125 r
F
.59775 .10003 m .59605 .09758 L .59938 .09626 L F
.71639 .09912 m .71822 .09549 L .71978 .0978 L 0 .024 .123 r
F
.71639 .09912 m .71482 .09683 L .71822 .09549 L F
.72474 .09872 m .72658 .0951 L .72814 .09737 L 0 .024 .122 r
F
.72474 .09872 m .72318 .09645 L .72658 .0951 L F
.5593 .09944 m .56087 .09579 L .56261 .09814 L 0 .025 .124 r
F
.5593 .09944 m .55756 .09712 L .56087 .09579 L F
.5125 .0993 m .51399 .09576 L .51578 .09808 L F
.5125 .0993 m .51071 .097 L .51399 .09576 L F
.6061 .09978 m .60775 .09609 L .60944 .0985 L 0 .026 .125 r
F
.6061 .09978 m .60441 .09736 L .60775 .09609 L F
.56765 .09916 m .56923 .09547 L .57096 .09783 L 0 .025 .123 r
F
.56765 .09916 m .56592 .0968 L .56923 .09547 L F
.6696 .09919 m .67135 .09552 L .67298 .09792 L F
.6696 .09919 m .66798 .09678 L .67135 .09552 L F
.52085 .09911 m .52235 .09553 L .52413 .09784 L 0 .025 .124 r
F
.52085 .09911 m .51906 .09681 L .52235 .09553 L F
.61446 .09959 m .61612 .09596 L .6178 .0983 L 0 .026 .125 r
F
.61446 .09959 m .61278 .09724 L .61612 .09596 L F
.576 .09897 m .5776 .09542 L .57932 .09779 L 0 .025 .124 r
F
.576 .09897 m .57428 .0966 L .5776 .09542 L F
.62281 .09923 m .62448 .09559 L .62615 .0979 L F
.62281 .09923 m .62114 .09694 L .62448 .09559 L F
.63116 .09887 m .63285 .09518 L .63451 .09751 L 0 .025 .123 r
F
.63116 .09887 m .6295 .09655 L .63285 .09518 L F
.5292 .09887 m .53071 .09528 L .53249 .09758 L F
.5292 .09887 m .52742 .09656 L .53071 .09528 L F
.67797 .09913 m .67974 .09552 L .68135 .09793 L 0 .025 .124 r
F
.67797 .09913 m .67636 .09672 L .67974 .09552 L F
.63951 .09846 m .64122 .09492 L .64287 .09724 L 0 .024 .123 r
F
.63951 .09846 m .63786 .09615 L .64122 .09492 L F
.53755 .09868 m .53908 .09501 L .54084 .09741 L 0 .025 .123 r
F
.53755 .09868 m .53578 .09628 L .53908 .09501 L F
.58436 .09894 m .58597 .09538 L .58768 .09773 L 0 .025 .124 r
F
.58436 .09894 m .58265 .0966 L .58597 .09538 L F
.64788 .09831 m .6496 .09478 L .65124 .09707 L 0 .024 .123 r
F
.64788 .09831 m .64623 .09602 L .6496 .09478 L F
.68634 .09908 m .68812 .09529 L .68972 .09772 L 0 .025 .124 r
F
.68634 .09908 m .68474 .09665 L .68812 .09529 L F
.6947 .09878 m .69649 .09506 L .69809 .09747 L F
.6947 .09878 m .6931 .09636 L .69649 .09506 L F
.65624 .09811 m .65797 .09452 L .6596 .09685 L 0 .024 .123 r
F
.65624 .09811 m .6546 .0958 L .65797 .09452 L F
.5459 .09859 m .54744 .09493 L .5492 .09735 L 0 .025 .124 r
F
.5459 .09859 m .54414 .09617 L .54744 .09493 L F
.59272 .09884 m .59434 .09525 L .59605 .09758 L 0 .026 .124 r
F
.59272 .09884 m .59101 .09651 L .59434 .09525 L F
.70306 .09845 m .70487 .09485 L .70645 .09714 L 0 .025 .124 r
F
.70306 .09845 m .70148 .09616 L .70487 .09485 L F
.71142 .09812 m .71325 .09453 L .71482 .09683 L 0 .025 .123 r
F
.71142 .09812 m .70985 .09583 L .71325 .09453 L F
.49908 .09859 m .50054 .09496 L .50235 .09725 L 0 .025 .124 r
F
.49908 .09859 m .49727 .0963 L .50054 .09496 L F
.55425 .09843 m .55581 .0947 L .55756 .09712 L F
.55425 .09843 m .5525 .09603 L .55581 .0947 L F
.60108 .09869 m .60271 .09494 L .60441 .09736 L 0 .026 .124 r
F
.60108 .09869 m .59938 .09626 L .60271 .09494 L F
.50743 .09824 m .50891 .09469 L .51071 .097 L 0 .025 .124 r
F
.50743 .09824 m .50563 .09595 L .50891 .09469 L F
.71978 .0978 m .72162 .09413 L .72318 .09645 L 0 .024 .123 r
F
.71978 .0978 m .71822 .09549 L .72162 .09413 L F
.66461 .09804 m .66635 .09436 L .66798 .09678 L 0 .025 .123 r
F
.66461 .09804 m .66297 .0956 L .66635 .09436 L F
.56261 .09814 m .56418 .09444 L .56592 .0968 L F
.56261 .09814 m .56087 .09579 L .56418 .09444 L F
.60944 .0985 m .61109 .09484 L .61278 .09724 L 0 .026 .125 r
F
.60944 .0985 m .60775 .09609 L .61109 .09484 L F
.57096 .09783 m .57255 .09422 L .57428 .0966 L 0 .025 .123 r
F
.57096 .09783 m .56923 .09547 L .57255 .09422 L F
.51578 .09808 m .51727 .09447 L .51906 .09681 L 0 .025 .124 r
F
.51578 .09808 m .51399 .09576 L .51727 .09447 L F
.67298 .09792 m .67474 .09433 L .67636 .09672 L F
.67298 .09792 m .67135 .09552 L .67474 .09433 L F
.6178 .0983 m .61946 .09459 L .62114 .09694 L 0 .026 .124 r
F
.6178 .0983 m .61612 .09596 L .61946 .09459 L F
.52413 .09784 m .52564 .09424 L .52742 .09656 L 0 .025 .124 r
F
.52413 .09784 m .52235 .09553 L .52564 .09424 L F
.62615 .0979 m .62783 .09422 L .6295 .09655 L F
.62615 .0979 m .62448 .09559 L .62783 .09422 L F
.63451 .09751 m .6362 .09381 L .63786 .09615 L 0 .024 .123 r
F
.63451 .09751 m .63285 .09518 L .6362 .09381 L F
.57932 .09779 m .58093 .09423 L .58265 .0966 L 0 .025 .124 r
F
.57932 .09779 m .5776 .09542 L .58093 .09423 L F
.53249 .09758 m .53401 .09399 L .53578 .09628 L 0 .025 .123 r
F
.53249 .09758 m .53071 .09528 L .53401 .09399 L F
.68135 .09793 m .68313 .09425 L .68474 .09665 L 0 .025 .124 r
F
.68135 .09793 m .67974 .09552 L .68313 .09425 L F
.64287 .09724 m .64458 .0937 L .64623 .09602 L 0 .024 .123 r
F
.64287 .09724 m .64122 .09492 L .64458 .0937 L F
.54084 .09741 m .54238 .09378 L .54414 .09617 L 0 .025 .123 r
F
.54084 .09741 m .53908 .09501 L .54238 .09378 L F
.68972 .09772 m .6915 .09393 L .6931 .09636 L 0 .025 .124 r
F
.68972 .09772 m .68812 .09529 L .6915 .09393 L F
.58768 .09773 m .5893 .09416 L .59101 .09651 L 0 .026 .124 r
F
.58768 .09773 m .58597 .09538 L .5893 .09416 L F
.65124 .09707 m .65296 .09349 L .6546 .0958 L 0 .024 .123 r
F
.65124 .09707 m .6496 .09478 L .65296 .09349 L F
.69809 .09747 m .69989 .09377 L .70148 .09616 L 0 .025 .124 r
F
.69809 .09747 m .69649 .09506 L .69989 .09377 L F
.6596 .09685 m .66134 .09327 L .66297 .0956 L 0 .024 .123 r
F
.6596 .09685 m .65797 .09452 L .66134 .09327 L F
.5492 .09735 m .55075 .0936 L .5525 .09603 L 0 .025 .124 r
F
.5492 .09735 m .54744 .09493 L .55075 .0936 L F
.59605 .09758 m .59768 .09394 L .59938 .09626 L 0 .026 .124 r
F
.59605 .09758 m .59434 .09525 L .59768 .09394 L F
.70645 .09714 m .70827 .09353 L .70985 .09583 L 0 .025 .124 r
F
.70645 .09714 m .70487 .09485 L .70827 .09353 L F
.50235 .09725 m .50382 .09365 L .50563 .09595 L F
.50235 .09725 m .50054 .09496 L .50382 .09365 L F
.71482 .09683 m .71665 .09318 L .71822 .09549 L 0 .025 .123 r
F
.71482 .09683 m .71325 .09453 L .71665 .09318 L F
.55756 .09712 m .55912 .09337 L .56087 .09579 L 0 .025 .124 r
F
.55756 .09712 m .55581 .0947 L .55912 .09337 L F
.60441 .09736 m .60605 .09369 L .60775 .09609 L F
.60441 .09736 m .60271 .09494 L .60605 .09369 L F
.72318 .09645 m .72502 .09277 L .72658 .0951 L 0 .024 .122 r
F
.72318 .09645 m .72162 .09413 L .72502 .09277 L F
.51071 .097 m .51219 .09342 L .51399 .09576 L 0 .025 .124 r
F
.51071 .097 m .50891 .09469 L .51219 .09342 L F
.66798 .09678 m .66973 .09312 L .67135 .09552 L 0 .025 .123 r
F
.66798 .09678 m .66635 .09436 L .66973 .09312 L F
.56592 .0968 m .5675 .09309 L .56923 .09547 L F
.56592 .0968 m .56418 .09444 L .5675 .09309 L F
.61278 .09724 m .61443 .09357 L .61612 .09596 L 0 .026 .125 r
F
.61278 .09724 m .61109 .09484 L .61443 .09357 L F
.51906 .09681 m .52056 .09317 L .52235 .09553 L 0 .025 .124 r
F
.51906 .09681 m .51727 .09447 L .52056 .09317 L F
.57428 .0966 m .57587 .09302 L .5776 .09542 L 0 .025 .123 r
F
.57428 .0966 m .57255 .09422 L .57587 .09302 L F
.62114 .09694 m .62281 .09323 L .62448 .09559 L 0 .025 .124 r
F
.62114 .09694 m .61946 .09459 L .62281 .09323 L F
.67636 .09672 m .67813 .09313 L .67974 .09552 L F
.67636 .09672 m .67474 .09433 L .67813 .09313 L F
.6295 .09655 m .63118 .09284 L .63285 .09518 L 0 .025 .123 r
F
.6295 .09655 m .62783 .09422 L .63118 .09284 L F
.52742 .09656 m .52894 .09297 L .53071 .09528 L 0 .025 .124 r
F
.52742 .09656 m .52564 .09424 L .52894 .09297 L F
.63786 .09615 m .63956 .09256 L .64122 .09492 L 0 .024 .123 r
F
.63786 .09615 m .6362 .09381 L .63956 .09256 L F
.53578 .09628 m .53731 .09273 L .53908 .09501 L 0 .025 .123 r
F
.53578 .09628 m .53401 .09399 L .53731 .09273 L F
.58265 .0966 m .58425 .09299 L .58597 .09538 L 0 .025 .124 r
F
.58265 .0966 m .58093 .09423 L .58425 .09299 L F
.68474 .09665 m .68651 .0929 L .68812 .09529 L F
.68474 .09665 m .68313 .09425 L .68651 .0929 L F
.64623 .09602 m .64795 .09245 L .6496 .09478 L 0 .025 .123 r
F
.64623 .09602 m .64458 .0937 L .64795 .09245 L F
.6931 .09636 m .6949 .09265 L .69649 .09506 L 0 .025 .124 r
F
.6931 .09636 m .6915 .09393 L .6949 .09265 L F
.54414 .09617 m .54568 .09254 L .54744 .09493 L 0 .025 .123 r
F
.54414 .09617 m .54238 .09378 L .54568 .09254 L F
.6546 .0958 m .65633 .0922 L .65797 .09452 L 0 .024 .123 r
F
.6546 .0958 m .65296 .09349 L .65633 .0922 L F
.59101 .09651 m .59264 .09291 L .59434 .09525 L 0 .026 .125 r
F
.59101 .09651 m .5893 .09416 L .59264 .09291 L F
.70148 .09616 m .70329 .09247 L .70487 .09485 L 0 .025 .124 r
F
.70148 .09616 m .69989 .09377 L .70329 .09247 L F
.5525 .09603 m .55406 .09227 L .55581 .0947 L 0 .025 .123 r
F
.5525 .09603 m .55075 .0936 L .55406 .09227 L F
.59938 .09626 m .60101 .09264 L .60271 .09494 L 0 .025 .124 r
F
.59938 .09626 m .59768 .09394 L .60101 .09264 L F
.66297 .0956 m .66472 .09202 L .66635 .09436 L 0 .024 .123 r
F
.66297 .0956 m .66134 .09327 L .66472 .09202 L F
.70985 .09583 m .71167 .09221 L .71325 .09453 L 0 .025 .123 r
F
.70985 .09583 m .70827 .09353 L .71167 .09221 L F
.50563 .09595 m .50711 .09237 L .50891 .09469 L 0 .025 .124 r
F
.50563 .09595 m .50382 .09365 L .50711 .09237 L F
.71822 .09549 m .72005 .0918 L .72162 .09413 L 0 .024 .123 r
F
.71822 .09549 m .71665 .09318 L .72005 .0918 L F
.56087 .09579 m .56244 .09203 L .56418 .09444 L 0 .025 .123 r
F
.56087 .09579 m .55912 .09337 L .56244 .09203 L F
.60775 .09609 m .6094 .09246 L .61109 .09484 L 0 .026 .124 r
F
.60775 .09609 m .60605 .09369 L .6094 .09246 L F
.56923 .09547 m .57082 .09183 L .57255 .09422 L 0 .025 .123 r
F
.56923 .09547 m .5675 .09309 L .57082 .09183 L F
.67135 .09552 m .67312 .09192 L .67474 .09433 L F
.67135 .09552 m .66973 .09312 L .67312 .09192 L F
.51399 .09576 m .51548 .09211 L .51727 .09447 L 0 .025 .124 r
F
.51399 .09576 m .51219 .09342 L .51548 .09211 L F
.61612 .09596 m .61778 .09222 L .61946 .09459 L 0 .026 .124 r
F
.61612 .09596 m .61443 .09357 L .61778 .09222 L F
.52235 .09553 m .52386 .09187 L .52564 .09424 L 0 .025 .124 r
F
.52235 .09553 m .52056 .09317 L .52386 .09187 L F
.62448 .09559 m .62616 .09187 L .62783 .09422 L F
.62448 .09559 m .62281 .09323 L .62616 .09187 L F
.63285 .09518 m .63454 .09145 L .6362 .09381 L 0 .024 .123 r
F
.63285 .09518 m .63118 .09284 L .63454 .09145 L F
.5776 .09542 m .5792 .09182 L .58093 .09423 L 0 .025 .124 r
F
.5776 .09542 m .57587 .09302 L .5792 .09182 L F
.53071 .09528 m .53223 .09169 L .53401 .09399 L F
.53071 .09528 m .52894 .09297 L .53223 .09169 L F
.67974 .09552 m .68151 .09187 L .68313 .09425 L F
.67974 .09552 m .67813 .09313 L .68151 .09187 L F
.64122 .09492 m .64293 .09132 L .64458 .0937 L 0 .024 .123 r
F
.64122 .09492 m .63956 .09256 L .64293 .09132 L F
.53908 .09501 m .54061 .0915 L .54238 .09378 L 0 .025 .123 r
F
.53908 .09501 m .53731 .09273 L .54061 .0915 L F
.68812 .09529 m .6899 .09155 L .6915 .09393 L 0 .025 .124 r
F
.68812 .09529 m .68651 .0929 L .6899 .09155 L F
.58597 .09538 m .58759 .09176 L .5893 .09416 L 0 .026 .124 r
F
.58597 .09538 m .58425 .09299 L .58759 .09176 L F
.6496 .09478 m .65132 .09114 L .65296 .09349 L 0 .025 .123 r
F
.6496 .09478 m .64795 .09245 L .65132 .09114 L F
.69649 .09506 m .69829 .09138 L .69989 .09377 L 0 .025 .124 r
F
.69649 .09506 m .6949 .09265 L .69829 .09138 L F
.54744 .09493 m .54899 .09121 L .55075 .0936 L 0 .025 .123 r
F
.54744 .09493 m .54568 .09254 L .54899 .09121 L F
.65797 .09452 m .65971 .09093 L .66134 .09327 L 0 .024 .123 r
F
.65797 .09452 m .65633 .0922 L .65971 .09093 L F
.59434 .09525 m .59597 .09162 L .59768 .09394 L 0 .026 .124 r
F
.59434 .09525 m .59264 .09291 L .59597 .09162 L F
.70487 .09485 m .70669 .09115 L .70827 .09353 L 0 .025 .124 r
F
.70487 .09485 m .70329 .09247 L .70669 .09115 L F
.55581 .0947 m .55737 .09093 L .55912 .09337 L 0 .025 .123 r
F
.55581 .0947 m .55406 .09227 L .55737 .09093 L F
.60271 .09494 m .60436 .0914 L .60605 .09369 L 0 .025 .124 r
F
.60271 .09494 m .60101 .09264 L .60436 .0914 L F
.71325 .09453 m .71508 .09084 L .71665 .09318 L 0 .025 .123 r
F
.71325 .09453 m .71167 .09221 L .71508 .09084 L F
.66635 .09436 m .6681 .09077 L .66973 .09312 L F
.66635 .09436 m .66472 .09202 L .6681 .09077 L F
.72162 .09413 m .72346 .09042 L .72502 .09277 L 0 .024 .122 r
F
.72162 .09413 m .72005 .0918 L .72346 .09042 L F
.56418 .09444 m .56576 .09069 L .5675 .09309 L 0 .025 .123 r
F
.56418 .09444 m .56244 .09203 L .56576 .09069 L F
.50891 .09469 m .51039 .09108 L .51219 .09342 L 0 .025 .124 r
F
.50891 .09469 m .50711 .09237 L .51039 .09108 L F
.61109 .09484 m .61275 .0912 L .61443 .09357 L 0 .026 .124 r
F
.61109 .09484 m .6094 .09246 L .61275 .0912 L F
.57255 .09422 m .57414 .09062 L .57587 .09302 L 0 .025 .123 r
F
.57255 .09422 m .57082 .09183 L .57414 .09062 L F
.51727 .09447 m .51877 .09079 L .52056 .09317 L 0 .025 .124 r
F
.51727 .09447 m .51548 .09211 L .51877 .09079 L F
.67474 .09433 m .67651 .09073 L .67813 .09313 L F
.67474 .09433 m .67312 .09192 L .67651 .09073 L F
.61946 .09459 m .62113 .09086 L .62281 .09323 L F
.61946 .09459 m .61778 .09222 L .62113 .09086 L F
.62783 .09422 m .62952 .09049 L .63118 .09284 L 0 .025 .123 r
F
.62783 .09422 m .62616 .09187 L .62952 .09049 L F
.52564 .09424 m .52715 .09061 L .52894 .09297 L 0 .025 .124 r
F
.52564 .09424 m .52386 .09187 L .52715 .09061 L F
.6362 .09381 m .6379 .09019 L .63956 .09256 L 0 .024 .123 r
F
.6362 .09381 m .63454 .09145 L .6379 .09019 L F
.53401 .09399 m .53554 .09044 L .53731 .09273 L 0 .025 .124 r
F
.53401 .09399 m .53223 .09169 L .53554 .09044 L F
.58093 .09423 m .58253 .09056 L .58425 .09299 L F
.58093 .09423 m .5792 .09182 L .58253 .09056 L F
.68313 .09425 m .6849 .09053 L .68651 .0929 L F
.68313 .09425 m .68151 .09187 L .6849 .09053 L F
.64458 .0937 m .6463 .09005 L .64795 .09245 L 0 .025 .123 r
F
.64458 .0937 m .64293 .09132 L .6463 .09005 L F
.6915 .09393 m .6933 .09028 L .6949 .09265 L F
.6915 .09393 m .6899 .09155 L .6933 .09028 L F
.54238 .09378 m .54392 .09027 L .54568 .09254 L 0 .025 .124 r
F
.54238 .09378 m .54061 .0915 L .54392 .09027 L F
.5893 .09416 m .59092 .09051 L .59264 .09291 L 0 .026 .124 r
F
.5893 .09416 m .58759 .09176 L .59092 .09051 L F
.65296 .09349 m .65469 .08983 L .65633 .0922 L 0 .024 .123 r
F
.65296 .09349 m .65132 .09114 L .65469 .08983 L F
.69989 .09377 m .7017 .09009 L .70329 .09247 L 0 .025 .124 r
F
.69989 .09377 m .69829 .09138 L .7017 .09009 L F
.55075 .0936 m .55231 .08986 L .55406 .09227 L 0 .025 .123 r
F
.55075 .0936 m .54899 .09121 L .55231 .08986 L F
.59768 .09394 m .59931 .09032 L .60101 .09264 L 0 .026 .124 r
F
.59768 .09394 m .59597 .09162 L .59931 .09032 L F
.66134 .09327 m .66309 .08968 L .66472 .09202 L 0 .025 .123 r
F
.66134 .09327 m .65971 .09093 L .66309 .08968 L F
.70827 .09353 m .71009 .08982 L .71167 .09221 L F
.70827 .09353 m .70669 .09115 L .71009 .08982 L F
.55912 .09337 m .56069 .0896 L .56244 .09203 L F
.55912 .09337 m .55737 .09093 L .56069 .0896 L F
.71665 .09318 m .71848 .08946 L .72005 .0918 L 0 .024 .123 r
F
.71665 .09318 m .71508 .09084 L .71848 .08946 L F
.60605 .09369 m .60771 .09017 L .6094 .09246 L 0 .026 .124 r
F
.60605 .09369 m .60436 .0914 L .60771 .09017 L F
.5675 .09309 m .56908 .08942 L .57082 .09183 L 0 .024 .123 r
F
.5675 .09309 m .56576 .09069 L .56908 .08942 L F
.66973 .09312 m .67149 .08957 L .67312 .09192 L 0 .025 .123 r
F
.66973 .09312 m .6681 .09077 L .67149 .08957 L F
.51219 .09342 m .51368 .08975 L .51548 .09211 L 0 .025 .124 r
F
.51219 .09342 m .51039 .09108 L .51368 .08975 L F
.61443 .09357 m .6161 .08984 L .61778 .09222 L F
.61443 .09357 m .61275 .0912 L .6161 .08984 L F
.52056 .09317 m .52207 .08947 L .52386 .09187 L F
.52056 .09317 m .51877 .09079 L .52207 .08947 L F
.62281 .09323 m .62449 .0895 L .62616 .09187 L F
.62281 .09323 m .62113 .09086 L .62449 .0895 L F
.57587 .09302 m .57747 .0894 L .5792 .09182 L 0 .025 .123 r
F
.57587 .09302 m .57414 .09062 L .57747 .0894 L F
.63118 .09284 m .63287 .08912 L .63454 .09145 L 0 .024 .123 r
F
.63118 .09284 m .62952 .09049 L .63287 .08912 L F
.67813 .09313 m .6799 .08947 L .68151 .09187 L 0 .025 .124 r
F
.67813 .09313 m .67651 .09073 L .6799 .08947 L F
.52894 .09297 m .53046 .08934 L .53223 .09169 L F
.52894 .09297 m .52715 .09061 L .53046 .08934 L F
.63956 .09256 m .64127 .08894 L .64293 .09132 L 0 .024 .123 r
F
.63956 .09256 m .6379 .09019 L .64127 .08894 L F
.68651 .0929 m .68829 .0892 L .6899 .09155 L 0 .025 .124 r
F
.68651 .0929 m .6849 .09053 L .68829 .0892 L F
.53731 .09273 m .53884 .08922 L .54061 .0915 L F
.53731 .09273 m .53554 .09044 L .53884 .08922 L F
.58425 .09299 m .58587 .0893 L .58759 .09176 L F
.58425 .09299 m .58253 .09056 L .58587 .0893 L F
.6949 .09265 m .6967 .08903 L .69829 .09138 L F
.6949 .09265 m .6933 .09028 L .6967 .08903 L F
.64795 .09245 m .64967 .08872 L .65132 .09114 L 0 .025 .123 r
F
.64795 .09245 m .6463 .09005 L .64967 .08872 L F
.54568 .09254 m .54723 .08893 L .54899 .09121 L 0 .025 .124 r
F
.54568 .09254 m .54392 .09027 L .54723 .08893 L F
.65633 .0922 m .65807 .08856 L .65971 .09093 L 0 .024 .123 r
F
.65633 .0922 m .65469 .08983 L .65807 .08856 L F
.59264 .09291 m .59426 .08923 L .59597 .09162 L 0 .026 .124 r
F
.59264 .09291 m .59092 .09051 L .59426 .08923 L F
.70329 .09247 m .7051 .08876 L .70669 .09115 L 0 .025 .123 r
F
.70329 .09247 m .7017 .09009 L .7051 .08876 L F
.55406 .09227 m .55562 .08853 L .55737 .09093 L F
.55406 .09227 m .55231 .08986 L .55562 .08853 L F
.60101 .09264 m .60266 .08909 L .60436 .0914 L 0 .026 .124 r
F
.60101 .09264 m .59931 .09032 L .60266 .08909 L F
.71167 .09221 m .7135 .08846 L .71508 .09084 L 0 .025 .123 r
F
.71167 .09221 m .71009 .08982 L .7135 .08846 L F
.66472 .09202 m .66648 .08843 L .6681 .09077 L F
.66472 .09202 m .66309 .08968 L .66648 .08843 L F
.56244 .09203 m .56401 .08827 L .56576 .09069 L 0 .024 .123 r
F
.56244 .09203 m .56069 .0896 L .56401 .08827 L F
.72005 .0918 m .72189 .08807 L .72346 .09042 L 0 .024 .122 r
F
.72005 .0918 m .71848 .08946 L .72189 .08807 L F
.6094 .09246 m .61106 .08892 L .61275 .0912 L 0 .026 .124 r
F
.6094 .09246 m .60771 .09017 L .61106 .08892 L F
.57082 .09183 m .57241 .0882 L .57414 .09062 L 0 .025 .123 r
F
.57082 .09183 m .56908 .08942 L .57241 .0882 L F
.51548 .09211 m .51698 .0884 L .51877 .09079 L 0 .025 .124 r
F
.51548 .09211 m .51368 .08975 L .51698 .0884 L F
.67312 .09192 m .67489 .08836 L .67651 .09073 L 0 .025 .123 r
F
.67312 .09192 m .67149 .08957 L .67489 .08836 L F
.61778 .09222 m .61945 .08848 L .62113 .09086 L 0 .025 .124 r
F
.61778 .09222 m .6161 .08984 L .61945 .08848 L F
.62616 .09187 m .62784 .08814 L .62952 .09049 L 0 .025 .123 r
F
.62616 .09187 m .62449 .0895 L .62784 .08814 L F
.52386 .09187 m .52537 .08821 L .52715 .09061 L F
.52386 .09187 m .52207 .08947 L .52537 .08821 L F
.63454 .09145 m .63624 .08785 L .6379 .09019 L 0 .024 .123 r
F
.63454 .09145 m .63287 .08912 L .63624 .08785 L F
.5792 .09182 m .58081 .08812 L .58253 .09056 L 0 .025 .124 r
F
.5792 .09182 m .57747 .0894 L .58081 .08812 L F
.68151 .09187 m .68329 .08816 L .6849 .09053 L F
.68151 .09187 m .6799 .08947 L .68329 .08816 L F
.53223 .09169 m .53376 .08809 L .53554 .09044 L F
.53223 .09169 m .53046 .08934 L .53376 .08809 L F
.6899 .09155 m .6917 .08795 L .6933 .09028 L 0 .025 .123 r
F
.6899 .09155 m .68829 .0892 L .6917 .08795 L F
.64293 .09132 m .64464 .08765 L .6463 .09005 L 0 .024 .123 r
F
.64293 .09132 m .64127 .08894 L .64464 .08765 L F
.54061 .0915 m .54215 .08799 L .54392 .09027 L 0 .025 .124 r
F
.54061 .0915 m .53884 .08922 L .54215 .08799 L F
.58759 .09176 m .5892 .08804 L .59092 .09051 L F
.58759 .09176 m .58587 .0893 L .5892 .08804 L F
.65132 .09114 m .65304 .08739 L .65469 .08983 L 0 .024 .123 r
F
.65132 .09114 m .64967 .08872 L .65304 .08739 L F
.69829 .09138 m .7001 .08775 L .7017 .09009 L 0 .025 .124 r
F
.69829 .09138 m .6967 .08903 L .7001 .08775 L F
.54899 .09121 m .55055 .08757 L .55231 .08986 L 0 .025 .123 r
F
.54899 .09121 m .54723 .08893 L .55055 .08757 L F
.70669 .09115 m .70851 .08742 L .71009 .08982 L F
.70669 .09115 m .7051 .08876 L .70851 .08742 L F
.59597 .09162 m .59761 .08794 L .59931 .09032 L 0 .026 .124 r
F
.59597 .09162 m .59426 .08923 L .59761 .08794 L F
.65971 .09093 m .66145 .0873 L .66309 .08968 L 0 .025 .123 r
F
.65971 .09093 m .65807 .08856 L .66145 .0873 L F
.55737 .09093 m .55894 .0872 L .56069 .0896 L 0 .024 .123 r
F
.55737 .09093 m .55562 .08853 L .55894 .0872 L F
.71508 .09084 m .71691 .08709 L .71848 .08946 L F
.71508 .09084 m .7135 .08846 L .71691 .08709 L F
.56576 .09069 m .56734 .087 L .56908 .08942 L F
.56576 .09069 m .56401 .08827 L .56734 .087 L F
.60436 .0914 m .60601 .08788 L .60771 .09017 L 0 .026 .125 r
F
.60436 .0914 m .60266 .08909 L .60601 .08788 L F
.6681 .09077 m .66987 .08721 L .67149 .08957 L 0 .025 .123 r
F
.6681 .09077 m .66648 .08843 L .66987 .08721 L F
.61275 .0912 m .61441 .08756 L .6161 .08984 L 0 .026 .124 r
F
.61275 .0912 m .61106 .08892 L .61441 .08756 L F
.51877 .09079 m .52028 .08706 L .52207 .08947 L 0 .025 .123 r
F
.51877 .09079 m .51698 .0884 L .52028 .08706 L F
.57414 .09062 m .57574 .08697 L .57747 .0894 L F
.57414 .09062 m .57241 .0882 L .57574 .08697 L F
.62113 .09086 m .62281 .08714 L .62449 .0895 L 0 .025 .124 r
F
.62113 .09086 m .61945 .08848 L .62281 .08714 L F
.62952 .09049 m .63121 .08679 L .63287 .08912 L 0 .025 .123 r
F
.62952 .09049 m .62784 .08814 L .63121 .08679 L F
.67651 .09073 m .67828 .08709 L .6799 .08947 L 0 .025 .124 r
F
.67651 .09073 m .67489 .08836 L .67828 .08709 L F
.52715 .09061 m .52867 .08694 L .53046 .08934 L F
.52715 .09061 m .52537 .08821 L .52867 .08694 L F
.6379 .09019 m .63961 .08659 L .64127 .08894 L 0 .024 .123 r
F
.6379 .09019 m .63624 .08785 L .63961 .08659 L F
.6849 .09053 m .68669 .08685 L .68829 .0892 L 0 .025 .124 r
F
.6849 .09053 m .68329 .08816 L .68669 .08685 L F
.58253 .09056 m .58414 .08684 L .58587 .0893 L F
.58253 .09056 m .58081 .08812 L .58414 .08684 L F
.53554 .09044 m .53707 .08686 L .53884 .08922 L F
.53554 .09044 m .53376 .08809 L .53707 .08686 L F
.6933 .09028 m .6951 .0867 L .6967 .08903 L F
.6933 .09028 m .6917 .08795 L .6951 .0867 L F
.6463 .09005 m .64802 .0863 L .64967 .08872 L 0 .024 .123 r
F
.6463 .09005 m .64464 .08765 L .64802 .0863 L F
.54392 .09027 m .54547 .08664 L .54723 .08893 L 0 .025 .124 r
F
.54392 .09027 m .54215 .08799 L .54547 .08664 L F
.59092 .09051 m .59255 .08676 L .59426 .08923 L F
.59092 .09051 m .5892 .08804 L .59255 .08676 L F
.65469 .08983 m .65642 .08611 L .65807 .08856 L 0 .024 .123 r
F
.65469 .08983 m .65304 .08739 L .65642 .08611 L F
.7017 .09009 m .70351 .08641 L .7051 .08876 L 0 .025 .123 r
F
.7017 .09009 m .7001 .08775 L .70351 .08641 L F
.55231 .08986 m .55387 .08623 L .55562 .08853 L F
.55231 .08986 m .55055 .08757 L .55387 .08623 L F
.71009 .08982 m .71192 .08608 L .7135 .08846 L F
.71009 .08982 m .70851 .08742 L .71192 .08608 L F
.56069 .0896 m .56227 .08588 L .56401 .08827 L 0 .024 .123 r
F
.56069 .0896 m .55894 .0872 L .56227 .08588 L F
.59931 .09032 m .60096 .08672 L .60266 .08909 L 0 .026 .124 r
F
.59931 .09032 m .59761 .08794 L .60096 .08672 L F
.66309 .08968 m .66484 .08605 L .66648 .08843 L 0 .025 .123 r
F
.66309 .08968 m .66145 .0873 L .66484 .08605 L F
.71848 .08946 m .72032 .08572 L .72189 .08807 L 0 .024 .122 r
F
.71848 .08946 m .71691 .08709 L .72032 .08572 L F
.56908 .08942 m .57067 .08577 L .57241 .0882 L 0 .024 .123 r
F
.56908 .08942 m .56734 .087 L .57067 .08577 L F
.60771 .09017 m .60937 .08664 L .61106 .08892 L 0 .026 .125 r
F
.60771 .09017 m .60601 .08788 L .60937 .08664 L F
.67149 .08957 m .67326 .08599 L .67489 .08836 L 0 .025 .123 r
F
.67149 .08957 m .66987 .08721 L .67326 .08599 L F
.6161 .08984 m .61777 .0862 L .61945 .08848 L 0 .025 .124 r
F
.6161 .08984 m .61441 .08756 L .61777 .0862 L F
.52207 .08947 m .52358 .0858 L .52537 .08821 L 0 .025 .123 r
F
.52207 .08947 m .52028 .08706 L .52358 .0858 L F
.62449 .0895 m .62617 .0858 L .62784 .08814 L F
.62449 .0895 m .62281 .08714 L .62617 .0858 L F
.63287 .08912 m .63458 .08551 L .63624 .08785 L 0 .024 .123 r
F
.63287 .08912 m .63121 .08679 L .63458 .08551 L F
.57747 .0894 m .57908 .08568 L .58081 .08812 L 0 .025 .123 r
F
.57747 .0894 m .57574 .08697 L .57908 .08568 L F
.6799 .08947 m .68167 .08577 L .68329 .08816 L 0 .025 .124 r
F
.6799 .08947 m .67828 .08709 L .68167 .08577 L F
.53046 .08934 m .53198 .08569 L .53376 .08809 L F
.53046 .08934 m .52867 .08694 L .53198 .08569 L F
.64127 .08894 m .64299 .08529 L .64464 .08765 L 0 .024 .123 r
F
.64127 .08894 m .63961 .08659 L .64299 .08529 L F
.68829 .0892 m .69009 .08561 L .6917 .08795 L 0 .025 .124 r
F
.68829 .0892 m .68669 .08685 L .69009 .08561 L F
.58587 .0893 m .58748 .08556 L .5892 .08804 L F
.58587 .0893 m .58414 .08684 L .58748 .08556 L F
.64967 .08872 m .65139 .08494 L .65304 .08739 L 0 .024 .122 r
F
.64967 .08872 m .64802 .0863 L .65139 .08494 L F
.53884 .08922 m .54038 .08563 L .54215 .08799 L 0 .025 .124 r
F
.53884 .08922 m .53707 .08686 L .54038 .08563 L F
.6967 .08903 m .69851 .08544 L .7001 .08775 L F
.6967 .08903 m .6951 .0867 L .69851 .08544 L F
.54723 .08893 m .54879 .08528 L .55055 .08757 L F
.54723 .08893 m .54547 .08664 L .54879 .08528 L F
.7051 .08876 m .70692 .08507 L .70851 .08742 L 0 .025 .123 r
F
.7051 .08876 m .70351 .08641 L .70692 .08507 L F
.55562 .08853 m .55719 .0849 L .55894 .0872 L 0 .024 .123 r
F
.55562 .08853 m .55387 .08623 L .55719 .0849 L F
.59426 .08923 m .59589 .08548 L .59761 .08794 L 0 .025 .124 r
F
.59426 .08923 m .59255 .08676 L .59589 .08548 L F
.65807 .08856 m .65981 .08486 L .66145 .0873 L 0 .024 .123 r
F
.65807 .08856 m .65642 .08611 L .65981 .08486 L F
.7135 .08846 m .71533 .08472 L .71691 .08709 L F
.7135 .08846 m .71192 .08608 L .71533 .08472 L F
.56401 .08827 m .56559 .08461 L .56734 .087 L 0 .024 .122 r
F
.56401 .08827 m .56227 .08588 L .56559 .08461 L F
.60266 .08909 m .60431 .08551 L .60601 .08788 L 0 .026 .125 r
F
.60266 .08909 m .60096 .08672 L .60431 .08551 L F
.66648 .08843 m .66823 .08481 L .66987 .08721 L 0 .025 .123 r
F
.66648 .08843 m .66484 .08605 L .66823 .08481 L F
.57241 .0882 m .574 .08453 L .57574 .08697 L F
.57241 .0882 m .57067 .08577 L .574 .08453 L F
.61106 .08892 m .61272 .08527 L .61441 .08756 L 0 .026 .125 r
F
.61106 .08892 m .60937 .08664 L .61272 .08527 L F
.61945 .08848 m .62113 .08484 L .62281 .08714 L 0 .025 .124 r
F
.61945 .08848 m .61777 .0862 L .62113 .08484 L F
.67489 .08836 m .67666 .08471 L .67828 .08709 L F
.67489 .08836 m .67326 .08599 L .67666 .08471 L F
.62784 .08814 m .62953 .08445 L .63121 .08679 L 0 .025 .123 r
F
.62784 .08814 m .62617 .0858 L .62953 .08445 L F
.52537 .08821 m .52688 .08454 L .52867 .08694 L F
.52537 .08821 m .52358 .0858 L .52688 .08454 L F
.63624 .08785 m .63795 .08425 L .63961 .08659 L 0 .024 .123 r
F
.63624 .08785 m .63458 .08551 L .63795 .08425 L F
.58081 .08812 m .58241 .08438 L .58414 .08684 L 0 .025 .123 r
F
.58081 .08812 m .57908 .08568 L .58241 .08438 L F
.68329 .08816 m .68507 .08444 L .68669 .08685 L F
.68329 .08816 m .68167 .08577 L .68507 .08444 L F
.53376 .08809 m .53529 .08445 L .53707 .08686 L 0 .025 .124 r
F
.53376 .08809 m .53198 .08569 L .53529 .08445 L F
.64464 .08765 m .64636 .08393 L .64802 .0863 L 0 .024 .123 r
F
.64464 .08765 m .64299 .08529 L .64636 .08393 L F
.6917 .08795 m .6935 .08438 L .6951 .0867 L 0 .025 .124 r
F
.6917 .08795 m .69009 .08561 L .6935 .08438 L F
.5892 .08804 m .59083 .08429 L .59255 .08676 L F
.5892 .08804 m .58748 .08556 L .59083 .08429 L F
.65304 .08739 m .65478 .08366 L .65642 .08611 L 0 .024 .122 r
F
.65304 .08739 m .65139 .08494 L .65478 .08366 L F
.7001 .08775 m .70192 .0841 L .70351 .08641 L 0 .025 .124 r
F
.7001 .08775 m .69851 .08544 L .70192 .0841 L F
.54215 .08799 m .5437 .08428 L .54547 .08664 L F
.54215 .08799 m .54038 .08563 L .5437 .08428 L F
.55055 .08757 m .55211 .08392 L .55387 .08623 L 0 .025 .123 r
F
.55055 .08757 m .54879 .08528 L .55211 .08392 L F
.70851 .08742 m .71033 .08374 L .71192 .08608 L F
.70851 .08742 m .70692 .08507 L .71033 .08374 L F
.55894 .0872 m .56052 .08357 L .56227 .08588 L 0 .024 .123 r
F
.55894 .0872 m .55719 .0849 L .56052 .08357 L F
.59761 .08794 m .59925 .08426 L .60096 .08672 L 0 .025 .124 r
F
.59761 .08794 m .59589 .08548 L .59925 .08426 L F
.66145 .0873 m .6632 .0836 L .66484 .08605 L 0 .024 .123 r
F
.66145 .0873 m .65981 .08486 L .6632 .0836 L F
.71691 .08709 m .71875 .08337 L .72032 .08572 L 0 .024 .122 r
F
.71691 .08709 m .71533 .08472 L .71875 .08337 L F
.56734 .087 m .56893 .08336 L .57067 .08577 L 0 .024 .123 r
F
.56734 .087 m .56559 .08461 L .56893 .08336 L F
.60601 .08788 m .60767 .08427 L .60937 .08664 L 0 .026 .125 r
F
.60601 .08788 m .60431 .08551 L .60767 .08427 L F
.66987 .08721 m .67163 .08358 L .67326 .08599 L 0 .025 .123 r
F
.66987 .08721 m .66823 .08481 L .67163 .08358 L F
.61441 .08756 m .61608 .0839 L .61777 .0862 L 0 .026 .124 r
F
.61441 .08756 m .61272 .08527 L .61608 .0839 L F
.62281 .08714 m .62449 .0835 L .62617 .0858 L 0 .025 .123 r
F
.62281 .08714 m .62113 .08484 L .62449 .0835 L F
.57574 .08697 m .57734 .08323 L .57908 .08568 L F
.57574 .08697 m .574 .08453 L .57734 .08323 L F
.63121 .08679 m .63291 .08318 L .63458 .08551 L F
.63121 .08679 m .62953 .08445 L .63291 .08318 L F
.67828 .08709 m .68005 .08337 L .68167 .08577 L 0 .025 .124 r
F
.67828 .08709 m .67666 .08471 L .68005 .08337 L F
.52867 .08694 m .53019 .08329 L .53198 .08569 L 0 .025 .123 r
F
.52867 .08694 m .52688 .08454 L .53019 .08329 L F
.63961 .08659 m .64133 .08295 L .64299 .08529 L 0 .024 .123 r
F
.63961 .08659 m .63795 .08425 L .64133 .08295 L F
.58414 .08684 m .58576 .08311 L .58748 .08556 L 0 .025 .123 r
F
.58414 .08684 m .58241 .08438 L .58576 .08311 L F
.68669 .08685 m .68848 .0832 L .69009 .08561 L F
.68669 .08685 m .68507 .08444 L .68848 .0832 L F
.64802 .0863 m .64974 .08257 L .65139 .08494 L 0 .024 .122 r
F
.64802 .0863 m .64636 .08393 L .64974 .08257 L F
.53707 .08686 m .53861 .08322 L .54038 .08563 L 0 .025 .124 r
F
.53707 .08686 m .53529 .08445 L .53861 .08322 L F
.6951 .0867 m .69691 .08312 L .69851 .08544 L F
.6951 .0867 m .6935 .08438 L .69691 .08312 L F
.59255 .08676 m .59418 .08302 L .59589 .08548 L F
.59255 .08676 m .59083 .08429 L .59418 .08302 L F
.65642 .08611 m .65816 .08241 L .65981 .08486 L 0 .024 .122 r
F
.65642 .08611 m .65478 .08366 L .65816 .08241 L F
.54547 .08664 m .54702 .0829 L .54879 .08528 L 0 .025 .124 r
F
.54547 .08664 m .5437 .08428 L .54702 .0829 L F
.70351 .08641 m .70533 .08276 L .70692 .08507 L 0 .025 .123 r
F
.70351 .08641 m .70192 .0841 L .70533 .08276 L F
.55387 .08623 m .55543 .08259 L .55719 .0849 L F
.55387 .08623 m .55211 .08392 L .55543 .08259 L F
.71192 .08608 m .71375 .08239 L .71533 .08472 L 0 .024 .123 r
F
.71192 .08608 m .71033 .08374 L .71375 .08239 L F
.56227 .08588 m .56385 .08229 L .56559 .08461 L 0 .024 .122 r
F
.56227 .08588 m .56052 .08357 L .56385 .08229 L F
.60096 .08672 m .6026 .08304 L .60431 .08551 L 0 .026 .124 r
F
.60096 .08672 m .59925 .08426 L .6026 .08304 L F
.66484 .08605 m .6666 .08235 L .66823 .08481 L 0 .025 .123 r
F
.66484 .08605 m .6632 .0836 L .6666 .08235 L F
.57067 .08577 m .57226 .08211 L .574 .08453 L 0 .024 .123 r
F
.57067 .08577 m .56893 .08336 L .57226 .08211 L F
.60937 .08664 m .61103 .0829 L .61272 .08527 L 0 .026 .125 r
F
.60937 .08664 m .60767 .08427 L .61103 .0829 L F
.61777 .0862 m .61944 .08255 L .62113 .08484 L 0 .025 .124 r
F
.61777 .0862 m .61608 .0839 L .61944 .08255 L F
.67326 .08599 m .67503 .08229 L .67666 .08471 L F
.67326 .08599 m .67163 .08358 L .67503 .08229 L F
.62617 .0858 m .62786 .08216 L .62953 .08445 L 0 .025 .123 r
F
.62617 .0858 m .62449 .0835 L .62786 .08216 L F
.57908 .08568 m .58068 .08193 L .58241 .08438 L F
.57908 .08568 m .57734 .08323 L .58068 .08193 L F
.63458 .08551 m .63628 .0819 L .63795 .08425 L F
.63458 .08551 m .63291 .08318 L .63628 .0819 L F
.68167 .08577 m .68346 .08204 L .68507 .08444 L F
.68167 .08577 m .68005 .08337 L .68346 .08204 L F
.53198 .08569 m .53351 .08204 L .53529 .08445 L 0 .025 .124 r
F
.53198 .08569 m .53019 .08329 L .53351 .08204 L F
.64299 .08529 m .6447 .08159 L .64636 .08393 L 0 .024 .123 r
F
.64299 .08529 m .64133 .08295 L .6447 .08159 L F
.58748 .08556 m .58911 .08185 L .59083 .08429 L 0 .025 .123 r
F
.58748 .08556 m .58576 .08311 L .58911 .08185 L F
.69009 .08561 m .69189 .08197 L .6935 .08438 L 0 .025 .124 r
F
.69009 .08561 m .68848 .0832 L .69189 .08197 L F
.65139 .08494 m .65313 .08129 L .65478 .08366 L 0 .024 .122 r
F
.65139 .08494 m .64974 .08257 L .65313 .08129 L F
.54038 .08563 m .54193 .08185 L .5437 .08428 L 0 .025 .124 r
F
.54038 .08563 m .53861 .08322 L .54193 .08185 L F
.69851 .08544 m .70033 .08178 L .70192 .0841 L F
.69851 .08544 m .69691 .08312 L .70033 .08178 L F
.59589 .08548 m .59753 .08179 L .59925 .08426 L F
.59589 .08548 m .59418 .08302 L .59753 .08179 L F
.54879 .08528 m .55034 .08154 L .55211 .08392 L 0 .025 .123 r
F
.54879 .08528 m .54702 .0829 L .55034 .08154 L F
.70692 .08507 m .70875 .08143 L .71033 .08374 L F
.70692 .08507 m .70533 .08276 L .70875 .08143 L F
.65981 .08486 m .66156 .08115 L .6632 .0836 L 0 .024 .122 r
F
.65981 .08486 m .65816 .08241 L .66156 .08115 L F
.55719 .0849 m .55876 .08126 L .56052 .08357 L 0 .024 .123 r
F
.55719 .0849 m .55543 .08259 L .55876 .08126 L F
.71533 .08472 m .71717 .08105 L .71875 .08337 L 0 .024 .122 r
F
.71533 .08472 m .71375 .08239 L .71717 .08105 L F
.56559 .08461 m .56718 .08103 L .56893 .08336 L 0 .024 .123 r
F
.56559 .08461 m .56385 .08229 L .56718 .08103 L F
.60431 .08551 m .60596 .0818 L .60767 .08427 L 0 .026 .125 r
F
.60431 .08551 m .6026 .08304 L .60596 .0818 L F
.66823 .08481 m .67 .08111 L .67163 .08358 L 0 .025 .123 r
F
.66823 .08481 m .6666 .08235 L .67 .08111 L F
.574 .08453 m .57561 .0808 L .57734 .08323 L 0 .024 .123 r
F
.574 .08453 m .57226 .08211 L .57561 .0808 L F
.61272 .08527 m .61439 .08152 L .61608 .0839 L 0 .026 .124 r
F
.61272 .08527 m .61103 .0829 L .61439 .08152 L F
.62113 .08484 m .62281 .08121 L .62449 .0835 L 0 .025 .124 r
F
.62113 .08484 m .61944 .08255 L .62281 .08121 L F
.62953 .08445 m .63123 .08087 L .63291 .08318 L 0 .025 .123 r
F
.62953 .08445 m .62786 .08216 L .63123 .08087 L F
.67666 .08471 m .67843 .08095 L .68005 .08337 L F
.67666 .08471 m .67503 .08229 L .67843 .08095 L F
.58241 .08438 m .58403 .08066 L .58576 .08311 L F
.58241 .08438 m .58068 .08193 L .58403 .08066 L F
.68507 .08444 m .68687 .08078 L .68848 .0832 L F
.68507 .08444 m .68346 .08204 L .68687 .08078 L F
.63795 .08425 m .63966 .0806 L .64133 .08295 L F
.63795 .08425 m .63628 .0819 L .63966 .0806 L F
.64636 .08393 m .64809 .08023 L .64974 .08257 L 0 .024 .122 r
F
.64636 .08393 m .6447 .08159 L .64809 .08023 L F
.53529 .08445 m .53683 .0808 L .53861 .08322 L 0 .025 .124 r
F
.53529 .08445 m .53351 .08204 L .53683 .0808 L F
.59083 .08429 m .59246 .0806 L .59418 .08302 L 0 .025 .123 r
F
.59083 .08429 m .58911 .08185 L .59246 .0806 L F
.65478 .08366 m .65652 .08004 L .65816 .08241 L 0 .024 .122 r
F
.65478 .08366 m .65313 .08129 L .65652 .08004 L F
.6935 .08438 m .69531 .0807 L .69691 .08312 L 0 .025 .124 r
F
.6935 .08438 m .69189 .08197 L .69531 .0807 L F
.5437 .08428 m .54525 .08047 L .54702 .0829 L F
.5437 .08428 m .54193 .08185 L .54525 .08047 L F
.70192 .0841 m .70374 .08044 L .70533 .08276 L F
.70192 .0841 m .70033 .08178 L .70374 .08044 L F
.55211 .08392 m .55367 .08021 L .55543 .08259 L 0 .025 .123 r
F
.55211 .08392 m .55034 .08154 L .55367 .08021 L F
.71033 .08374 m .71217 .08009 L .71375 .08239 L 0 .024 .123 r
F
.71033 .08374 m .70875 .08143 L .71217 .08009 L F
.59925 .08426 m .60089 .08057 L .6026 .08304 L 0 .025 .124 r
F
.59925 .08426 m .59753 .08179 L .60089 .08057 L F
.56052 .08357 m .5621 .07997 L .56385 .08229 L 0 .024 .123 r
F
.56052 .08357 m .55876 .08126 L .5621 .07997 L F
.6632 .0836 m .66495 .07989 L .6666 .08235 L F
.6632 .0836 m .66156 .08115 L .66495 .07989 L F
.56893 .08336 m .57052 .07976 L .57226 .08211 L F
.56893 .08336 m .56718 .08103 L .57052 .07976 L F
.60767 .08427 m .60932 .08043 L .61103 .0829 L 0 .026 .125 r
F
.60767 .08427 m .60596 .0818 L .60932 .08043 L F
.67163 .08358 m .6734 .07982 L .67503 .08229 L 0 .025 .123 r
F
.67163 .08358 m .67 .08111 L .6734 .07982 L F
.61608 .0839 m .61775 .08017 L .61944 .08255 L 0 .025 .124 r
F
.61608 .0839 m .61439 .08152 L .61775 .08017 L F
.57734 .08323 m .57895 .07949 L .58068 .08193 L 0 .024 .123 r
F
.57734 .08323 m .57561 .0808 L .57895 .07949 L F
.62449 .0835 m .62618 .07986 L .62786 .08216 L 0 .025 .124 r
F
.62449 .0835 m .62281 .08121 L .62618 .07986 L F
.68005 .08337 m .68183 .07961 L .68346 .08204 L 0 .025 .123 r
F
.68005 .08337 m .67843 .08095 L .68183 .07961 L F
.63291 .08318 m .63461 .07958 L .63628 .0819 L F
.63291 .08318 m .63123 .08087 L .63461 .07958 L F
.58576 .08311 m .58738 .07942 L .58911 .08185 L F
.58576 .08311 m .58403 .08066 L .58738 .07942 L F
.64133 .08295 m .64304 .07924 L .6447 .08159 L 0 .024 .123 r
F
.64133 .08295 m .63966 .0806 L .64304 .07924 L F
.68848 .0832 m .69028 .07954 L .69189 .08197 L 0 .025 .123 r
F
.68848 .0832 m .68687 .08078 L .69028 .07954 L F
.64974 .08257 m .65148 .07895 L .65313 .08129 L 0 .024 .122 r
F
.64974 .08257 m .64809 .08023 L .65148 .07895 L F
.53861 .08322 m .54015 .07942 L .54193 .08185 L 0 .025 .124 r
F
.53861 .08322 m .53683 .0808 L .54015 .07942 L F
.59418 .08302 m .59582 .07937 L .59753 .08179 L F
.59418 .08302 m .59246 .0806 L .59582 .07937 L F
.65816 .08241 m .65991 .07878 L .66156 .08115 L 0 .024 .122 r
F
.65816 .08241 m .65652 .08004 L .65991 .07878 L F
.69691 .08312 m .69872 .07935 L .70033 .08178 L 0 .025 .124 r
F
.69691 .08312 m .69531 .0807 L .69872 .07935 L F
.54702 .0829 m .54858 .07911 L .55034 .08154 L 0 .025 .123 r
F
.54702 .0829 m .54525 .08047 L .54858 .07911 L F
.70533 .08276 m .70716 .07911 L .70875 .08143 L F
.70533 .08276 m .70374 .08044 L .70716 .07911 L F
.55543 .08259 m .557 .07889 L .55876 .08126 L F
.55543 .08259 m .55367 .08021 L .557 .07889 L F
.71375 .08239 m .7156 .07876 L .71717 .08105 L 0 .024 .123 r
F
.71375 .08239 m .71217 .08009 L .7156 .07876 L F
.56385 .08229 m .56543 .07869 L .56718 .08103 L F
.56385 .08229 m .5621 .07997 L .56543 .07869 L F
.6026 .08304 m .60425 .07932 L .60596 .0818 L 0 .026 .124 r
F
.6026 .08304 m .60089 .08057 L .60425 .07932 L F
.6666 .08235 m .66836 .07863 L .67 .08111 L 0 .024 .123 r
F
.6666 .08235 m .66495 .07989 L .66836 .07863 L F
.57226 .08211 m .57387 .07844 L .57561 .0808 L F
.57226 .08211 m .57052 .07976 L .57387 .07844 L F
.61103 .0829 m .61269 .07905 L .61439 .08152 L 0 .026 .124 r
F
.61103 .0829 m .60932 .08043 L .61269 .07905 L F
.67503 .08229 m .6768 .07848 L .67843 .08095 L 0 .025 .123 r
F
.67503 .08229 m .6734 .07982 L .6768 .07848 L F
.61944 .08255 m .62112 .07884 L .62281 .08121 L 0 .025 .124 r
F
.61944 .08255 m .61775 .08017 L .62112 .07884 L F
.62786 .08216 m .62956 .07856 L .63123 .08087 L 0 .025 .123 r
F
.62786 .08216 m .62618 .07986 L .62956 .07856 L F
.58068 .08193 m .5823 .07822 L .58403 .08066 L 0 .024 .123 r
F
.58068 .08193 m .57895 .07949 L .5823 .07822 L F
.68346 .08204 m .68525 .07835 L .68687 .08078 L 0 .025 .123 r
F
.68346 .08204 m .68183 .07961 L .68525 .07835 L F
.63628 .0819 m .63799 .07827 L .63966 .0806 L F
.63628 .0819 m .63461 .07958 L .63799 .07827 L F
.6447 .08159 m .64643 .07788 L .64809 .08023 L 0 .024 .122 r
F
.6447 .08159 m .64304 .07924 L .64643 .07788 L F
.58911 .08185 m .59074 .07818 L .59246 .0806 L 0 .025 .123 r
F
.58911 .08185 m .58738 .07942 L .59074 .07818 L F
.69189 .08197 m .6937 .07827 L .69531 .0807 L 0 .025 .124 r
F
.69189 .08197 m .69028 .07954 L .6937 .07827 L F
.65313 .08129 m .65487 .0777 L .65652 .08004 L 0 .024 .122 r
F
.65313 .08129 m .65148 .07895 L .65487 .0777 L F
.54193 .08185 m .54347 .07803 L .54525 .08047 L 0 .025 .123 r
F
.54193 .08185 m .54015 .07942 L .54347 .07803 L F
.55034 .08154 m .55191 .07779 L .55367 .08021 L F
.55034 .08154 m .54858 .07911 L .55191 .07779 L F
.70033 .08178 m .70214 .078 L .70374 .08044 L 0 .025 .124 r
F
.70033 .08178 m .69872 .07935 L .70214 .078 L F
.59753 .08179 m .59918 .07815 L .60089 .08057 L F
.59753 .08179 m .59582 .07937 L .59918 .07815 L F
.66156 .08115 m .66331 .07751 L .66495 .07989 L 0 .024 .122 r
F
.66156 .08115 m .65991 .07878 L .66331 .07751 L F
.70875 .08143 m .71059 .07779 L .71217 .08009 L 0 .025 .123 r
F
.70875 .08143 m .70716 .07911 L .71059 .07779 L F
.55876 .08126 m .56034 .07758 L .5621 .07997 L 0 .024 .123 r
F
.55876 .08126 m .557 .07889 L .56034 .07758 L F
.56718 .08103 m .56878 .07741 L .57052 .07976 L F
.56718 .08103 m .56543 .07869 L .56878 .07741 L F
.60596 .0818 m .60762 .07795 L .60932 .08043 L 0 .025 .124 r
F
.60596 .0818 m .60425 .07932 L .60762 .07795 L F
.67 .08111 m .67176 .07734 L .6734 .07982 L 0 .024 .123 r
F
.67 .08111 m .66836 .07863 L .67176 .07734 L F
.57561 .0808 m .57721 .07711 L .57895 .07949 L F
.57561 .0808 m .57387 .07844 L .57721 .07711 L F
.61439 .08152 m .61606 .07771 L .61775 .08017 L 0 .025 .124 r
F
.61439 .08152 m .61269 .07905 L .61606 .07771 L F
.67843 .08095 m .68021 .07715 L .68183 .07961 L 0 .024 .123 r
F
.67843 .08095 m .6768 .07848 L .68021 .07715 L F
.62281 .08121 m .6245 .0775 L .62618 .07986 L 0 .025 .124 r
F
.62281 .08121 m .62112 .07884 L .6245 .0775 L F
.63123 .08087 m .63294 .07726 L .63461 .07958 L 0 .025 .123 r
F
.63123 .08087 m .62956 .07856 L .63294 .07726 L F
.58403 .08066 m .58565 .07699 L .58738 .07942 L 0 .024 .123 r
F
.58403 .08066 m .5823 .07822 L .58565 .07699 L F
.68687 .08078 m .68867 .07711 L .69028 .07954 L 0 .025 .123 r
F
.68687 .08078 m .68525 .07835 L .68867 .07711 L F
.63966 .0806 m .64138 .07689 L .64304 .07924 L 0 .024 .123 r
F
.63966 .0806 m .63799 .07827 L .64138 .07689 L F
.64809 .08023 m .64982 .0766 L .65148 .07895 L 0 .024 .122 r
F
.64809 .08023 m .64643 .07788 L .64982 .0766 L F
.59246 .0806 m .5941 .07695 L .59582 .07937 L 0 .025 .123 r
F
.59246 .0806 m .59074 .07818 L .5941 .07695 L F
.69531 .0807 m .69712 .07691 L .69872 .07935 L 0 .025 .124 r
F
.69531 .0807 m .6937 .07827 L .69712 .07691 L F
.54525 .08047 m .5468 .07667 L .54858 .07911 L 0 .025 .123 r
F
.54525 .08047 m .54347 .07803 L .5468 .07667 L F
.65652 .08004 m .65827 .07645 L .65991 .07878 L 0 .024 .122 r
F
.65652 .08004 m .65487 .0777 L .65827 .07645 L F
.70374 .08044 m .70556 .07667 L .70716 .07911 L 0 .025 .123 r
F
.70374 .08044 m .70214 .078 L .70556 .07667 L F
.55367 .08021 m .55524 .07647 L .557 .07889 L 0 .024 .123 r
F
.55367 .08021 m .55191 .07779 L .55524 .07647 L F
.71217 .08009 m .71402 .07646 L .7156 .07876 L 0 .025 .123 r
F
.71217 .08009 m .71059 .07779 L .71402 .07646 L F
.60089 .08057 m .60254 .0769 L .60425 .07932 L 0 .025 .124 r
F
.60089 .08057 m .59918 .07815 L .60254 .0769 L F
.66495 .07989 m .66672 .07624 L .66836 .07863 L 0 .024 .123 r
F
.66495 .07989 m .66331 .07751 L .66672 .07624 L F
.5621 .07997 m .56368 .07629 L .56543 .07869 L F
.5621 .07997 m .56034 .07758 L .56368 .07629 L F
.60932 .08043 m .61098 .07658 L .61269 .07905 L 0 .025 .124 r
F
.60932 .08043 m .60762 .07795 L .61098 .07658 L F
.57052 .07976 m .57212 .07607 L .57387 .07844 L 0 .024 .123 r
F
.57052 .07976 m .56878 .07741 L .57212 .07607 L F
.6734 .07982 m .67517 .07601 L .6768 .07848 L F
.6734 .07982 m .67176 .07734 L .67517 .07601 L F
.61775 .08017 m .61943 .0764 L .62112 .07884 L 0 .025 .124 r
F
.61775 .08017 m .61606 .07771 L .61943 .0764 L F
.57895 .07949 m .58056 .07582 L .5823 .07822 L 0 .024 .123 r
F
.57895 .07949 m .57721 .07711 L .58056 .07582 L F
.68183 .07961 m .68362 .0759 L .68525 .07835 L F
.68183 .07961 m .68021 .07715 L .68362 .0759 L F
.62618 .07986 m .62788 .07619 L .62956 .07856 L 0 .025 .124 r
F
.62618 .07986 m .6245 .0775 L .62788 .07619 L F
.63461 .07958 m .63632 .07593 L .63799 .07827 L 0 .025 .123 r
F
.63461 .07958 m .63294 .07726 L .63632 .07593 L F
.58738 .07942 m .58901 .07575 L .59074 .07818 L F
.58738 .07942 m .58565 .07699 L .58901 .07575 L F
.64304 .07924 m .64477 .07552 L .64643 .07788 L 0 .024 .123 r
F
.64304 .07924 m .64138 .07689 L .64477 .07552 L F
.69028 .07954 m .69209 .07584 L .6937 .07827 L 0 .025 .123 r
F
.69028 .07954 m .68867 .07711 L .69209 .07584 L F
.65148 .07895 m .65322 .07536 L .65487 .0777 L 0 .024 .122 r
F
.65148 .07895 m .64982 .0766 L .65322 .07536 L F
.54858 .07911 m .55014 .07535 L .55191 .07779 L 0 .024 .123 r
F
.54858 .07911 m .5468 .07667 L .55014 .07535 L F
.69872 .07935 m .70054 .07555 L .70214 .078 L 0 .025 .123 r
F
.69872 .07935 m .69712 .07691 L .70054 .07555 L F
.59582 .07937 m .59746 .07573 L .59918 .07815 L 0 .025 .124 r
F
.59582 .07937 m .5941 .07695 L .59746 .07573 L F
.65991 .07878 m .66167 .07517 L .66331 .07751 L 0 .024 .123 r
F
.65991 .07878 m .65827 .07645 L .66167 .07517 L F
.70716 .07911 m .70899 .07535 L .71059 .07779 L 0 .025 .123 r
F
.70716 .07911 m .70556 .07667 L .70899 .07535 L F
.557 .07889 m .55858 .07515 L .56034 .07758 L 0 .024 .123 r
F
.557 .07889 m .55524 .07647 L .55858 .07515 L F
.60425 .07932 m .60591 .07555 L .60762 .07795 L 0 .025 .124 r
F
.60425 .07932 m .60254 .0769 L .60591 .07555 L F
.66836 .07863 m .67012 .07495 L .67176 .07734 L 0 .024 .123 r
F
.66836 .07863 m .66672 .07624 L .67012 .07495 L F
.56543 .07869 m .56703 .07499 L .56878 .07741 L F
.56543 .07869 m .56368 .07629 L .56703 .07499 L F
.61269 .07905 m .61436 .07525 L .61606 .07771 L 0 .025 .124 r
F
.61269 .07905 m .61098 .07658 L .61436 .07525 L F
.57387 .07844 m .57547 .07472 L .57721 .07711 L 0 .024 .123 r
F
.57387 .07844 m .57212 .07607 L .57547 .07472 L F
.6768 .07848 m .67858 .07468 L .68021 .07715 L F
.6768 .07848 m .67517 .07601 L .67858 .07468 L F
.62112 .07884 m .62281 .07508 L .6245 .0775 L 0 .025 .124 r
F
.62112 .07884 m .61943 .0764 L .62281 .07508 L F
.5823 .07822 m .58392 .07458 L .58565 .07699 L 0 .024 .123 r
F
.5823 .07822 m .58056 .07582 L .58392 .07458 L F
.62956 .07856 m .63126 .07488 L .63294 .07726 L 0 .025 .124 r
F
.62956 .07856 m .62788 .07619 L .63126 .07488 L F
.68525 .07835 m .68705 .07467 L .68867 .07711 L 0 .025 .123 r
F
.68525 .07835 m .68362 .0759 L .68705 .07467 L F
.63799 .07827 m .63971 .07454 L .64138 .07689 L F
.63799 .07827 m .63632 .07593 L .63971 .07454 L F
.64643 .07788 m .64816 .07423 L .64982 .0766 L 0 .024 .122 r
F
.64643 .07788 m .64477 .07552 L .64816 .07423 L F
.59074 .07818 m .59237 .07453 L .5941 .07695 L 0 .025 .123 r
F
.59074 .07818 m .58901 .07575 L .59237 .07453 L F
.6937 .07827 m .6955 .07447 L .69712 .07691 L F
.6937 .07827 m .69209 .07584 L .6955 .07447 L F
.65487 .0777 m .65662 .0741 L .65827 .07645 L 0 .024 .123 r
F
.65487 .0777 m .65322 .07536 L .65662 .0741 L F
.70214 .078 m .70396 .07421 L .70556 .07667 L 0 .025 .123 r
F
.70214 .078 m .70054 .07555 L .70396 .07421 L F
.55191 .07779 m .55348 .07404 L .55524 .07647 L 0 .024 .123 r
F
.55191 .07779 m .55014 .07535 L .55348 .07404 L F
.59918 .07815 m .60083 .07448 L .60254 .0769 L 0 .025 .124 r
F
.59918 .07815 m .59746 .07573 L .60083 .07448 L F
.66331 .07751 m .66508 .07389 L .66672 .07624 L 0 .024 .123 r
F
.66331 .07751 m .66167 .07517 L .66508 .07389 L F
.71059 .07779 m .71242 .07402 L .71402 .07646 L 0 .025 .123 r
F
.71059 .07779 m .70899 .07535 L .71242 .07402 L F
.56034 .07758 m .56192 .07383 L .56368 .07629 L 0 .024 .123 r
F
.56034 .07758 m .55858 .07515 L .56192 .07383 L F
.60762 .07795 m .60928 .07419 L .61098 .07658 L 0 .025 .124 r
F
.60762 .07795 m .60591 .07555 L .60928 .07419 L F
.67176 .07734 m .67353 .07362 L .67517 .07601 L 0 .024 .123 r
F
.67176 .07734 m .67012 .07495 L .67353 .07362 L F
.56878 .07741 m .57037 .07363 L .57212 .07607 L F
.56878 .07741 m .56703 .07499 L .57037 .07363 L F
.61606 .07771 m .61773 .07395 L .61943 .0764 L 0 .025 .124 r
F
.61606 .07771 m .61436 .07525 L .61773 .07395 L F
.57721 .07711 m .57883 .07342 L .58056 .07582 L 0 .024 .122 r
F
.57721 .07711 m .57547 .07472 L .57883 .07342 L F
.68021 .07715 m .682 .07344 L .68362 .0759 L 0 .024 .123 r
F
.68021 .07715 m .67858 .07468 L .682 .07344 L F
.6245 .0775 m .62619 .07376 L .62788 .07619 L 0 .025 .124 r
F
.6245 .0775 m .62281 .07508 L .62619 .07376 L F
.58565 .07699 m .58728 .07335 L .58901 .07575 L 0 .024 .123 r
F
.58565 .07699 m .58392 .07458 L .58728 .07335 L F
.63294 .07726 m .63465 .07354 L .63632 .07593 L 0 .025 .123 r
F
.63294 .07726 m .63126 .07488 L .63465 .07354 L F
.68867 .07711 m .69047 .07341 L .69209 .07584 L F
.68867 .07711 m .68705 .07467 L .69047 .07341 L F
.64138 .07689 m .6431 .07315 L .64477 .07552 L 0 .024 .123 r
F
.64138 .07689 m .63971 .07454 L .6431 .07315 L F
.64982 .0766 m .65156 .07297 L .65322 .07536 L F
.64982 .0766 m .64816 .07423 L .65156 .07297 L F
.69712 .07691 m .69893 .0731 L .70054 .07555 L 0 .025 .123 r
F
.69712 .07691 m .6955 .07447 L .69893 .0731 L F
.5941 .07695 m .59574 .0733 L .59746 .07573 L 0 .025 .124 r
F
.5941 .07695 m .59237 .07453 L .59574 .0733 L F
.70556 .07667 m .70739 .07289 L .70899 .07535 L 0 .025 .123 r
F
.70556 .07667 m .70396 .07421 L .70739 .07289 L F
.65827 .07645 m .66003 .07282 L .66167 .07517 L 0 .024 .123 r
F
.65827 .07645 m .65662 .0741 L .66003 .07282 L F
.55524 .07647 m .55682 .07271 L .55858 .07515 L F
.55524 .07647 m .55348 .07404 L .55682 .07271 L F
.60254 .0769 m .6042 .07314 L .60591 .07555 L 0 .025 .124 r
F
.60254 .0769 m .60083 .07448 L .6042 .07314 L F
.66672 .07624 m .66849 .07259 L .67012 .07495 L 0 .024 .123 r
F
.66672 .07624 m .66508 .07389 L .66849 .07259 L F
.56368 .07629 m .56527 .07252 L .56703 .07499 L F
.56368 .07629 m .56192 .07383 L .56527 .07252 L F
.61098 .07658 m .61266 .07287 L .61436 .07525 L 0 .025 .123 r
F
.61098 .07658 m .60928 .07419 L .61266 .07287 L F
.67517 .07601 m .67695 .0723 L .67858 .07468 L 0 .024 .122 r
F
.67517 .07601 m .67353 .07362 L .67695 .0723 L F
.57212 .07607 m .57373 .07227 L .57547 .07472 L F
.57212 .07607 m .57037 .07363 L .57373 .07227 L F
.61943 .0764 m .62112 .07265 L .62281 .07508 L 0 .025 .123 r
F
.61943 .0764 m .61773 .07395 L .62112 .07265 L F
.58056 .07582 m .58219 .07217 L .58392 .07458 L 0 .024 .123 r
F
.58056 .07582 m .57883 .07342 L .58219 .07217 L F
.68362 .0759 m .68542 .07222 L .68705 .07467 L F
.68362 .0759 m .682 .07344 L .68542 .07222 L F
.62788 .07619 m .62958 .07243 L .63126 .07488 L 0 .025 .123 r
F
.62788 .07619 m .62619 .07376 L .62958 .07243 L F
.63632 .07593 m .63804 .07214 L .63971 .07454 L F
.63632 .07593 m .63465 .07354 L .63804 .07214 L F
.64477 .07552 m .6465 .07185 L .64816 .07423 L 0 .024 .123 r
F
.64477 .07552 m .6431 .07315 L .6465 .07185 L F
.58901 .07575 m .59065 .07211 L .59237 .07453 L 0 .025 .123 r
F
.58901 .07575 m .58728 .07335 L .59065 .07211 L F
.69209 .07584 m .69389 .07204 L .6955 .07447 L F
.69209 .07584 m .69047 .07341 L .69389 .07204 L F
.70054 .07555 m .70236 .07177 L .70396 .07421 L 0 .024 .123 r
F
.70054 .07555 m .69893 .0731 L .70236 .07177 L F
.65322 .07536 m .65497 .07171 L .65662 .0741 L F
.65322 .07536 m .65156 .07297 L .65497 .07171 L F
.59746 .07573 m .59911 .07205 L .60083 .07448 L 0 .025 .124 r
F
.59746 .07573 m .59574 .0733 L .59911 .07205 L F
.70899 .07535 m .71083 .07157 L .71242 .07402 L 0 .024 .123 r
F
.70899 .07535 m .70739 .07289 L .71083 .07157 L F
.55858 .07515 m .56016 .07138 L .56192 .07383 L 0 .024 .122 r
F
.55858 .07515 m .55682 .07271 L .56016 .07138 L F
.66167 .07517 m .66343 .07152 L .66508 .07389 L 0 .024 .123 r
F
.66167 .07517 m .66003 .07282 L .66343 .07152 L F
.60591 .07555 m .60757 .0718 L .60928 .07419 L 0 .025 .124 r
F
.60591 .07555 m .6042 .07314 L .60757 .0718 L F
.67012 .07495 m .6719 .07127 L .67353 .07362 L 0 .024 .123 r
F
.67012 .07495 m .66849 .07259 L .6719 .07127 L F
.56703 .07499 m .56862 .07115 L .57037 .07363 L 0 .024 .122 r
F
.56703 .07499 m .56527 .07252 L .56862 .07115 L F
.61436 .07525 m .61604 .07159 L .61773 .07395 L 0 .025 .123 r
F
.61436 .07525 m .61266 .07287 L .61604 .07159 L F
.67858 .07468 m .68037 .07106 L .682 .07344 L 0 .024 .122 r
F
.67858 .07468 m .67695 .0723 L .68037 .07106 L F
.57547 .07472 m .57708 .07096 L .57883 .07342 L F
.57547 .07472 m .57373 .07227 L .57708 .07096 L F
.62281 .07508 m .6245 .07132 L .62619 .07376 L 0 .025 .123 r
F
.62281 .07508 m .62112 .07265 L .6245 .07132 L F
.58392 .07458 m .58555 .07093 L .58728 .07335 L 0 .024 .123 r
F
.58392 .07458 m .58219 .07217 L .58555 .07093 L F
.63126 .07488 m .63297 .07109 L .63465 .07354 L 0 .025 .123 r
F
.63126 .07488 m .62958 .07243 L .63297 .07109 L F
.68705 .07467 m .68885 .07096 L .69047 .07341 L F
.68705 .07467 m .68542 .07222 L .68885 .07096 L F
.63971 .07454 m .64143 .07075 L .6431 .07315 L 0 .024 .123 r
F
.63971 .07454 m .63804 .07214 L .64143 .07075 L F
.64816 .07423 m .6499 .07058 L .65156 .07297 L F
.64816 .07423 m .6465 .07185 L .6499 .07058 L F
.6955 .07447 m .69732 .07067 L .69893 .0731 L F
.6955 .07447 m .69389 .07204 L .69732 .07067 L F
.59237 .07453 m .59402 .07087 L .59574 .0733 L 0 .025 .123 r
F
.59237 .07453 m .59065 .07211 L .59402 .07087 L F
.70396 .07421 m .70579 .07045 L .70739 .07289 L 0 .024 .123 r
F
.70396 .07421 m .70236 .07177 L .70579 .07045 L F
.65662 .0741 m .65837 .07041 L .66003 .07282 L F
.65662 .0741 m .65497 .07171 L .65837 .07041 L F
.60083 .07448 m .60248 .07073 L .6042 .07314 L 0 .025 .124 r
F
.60083 .07448 m .59911 .07205 L .60248 .07073 L F
.56192 .07383 m .56351 .07004 L .56527 .07252 L 0 .024 .122 r
F
.56192 .07383 m .56016 .07138 L .56351 .07004 L F
.66508 .07389 m .66685 .07022 L .66849 .07259 L 0 .024 .123 r
F
.66508 .07389 m .66343 .07152 L .66685 .07022 L F
.60928 .07419 m .61095 .0705 L .61266 .07287 L 0 .025 .124 r
F
.60928 .07419 m .60757 .0718 L .61095 .0705 L F
.67353 .07362 m .67532 .06995 L .67695 .0723 L 0 .024 .123 r
F
.67353 .07362 m .6719 .07127 L .67532 .06995 L F
.57037 .07363 m .57198 .06978 L .57373 .07227 L 0 .024 .122 r
F
.57037 .07363 m .56862 .07115 L .57198 .06978 L F
.61773 .07395 m .61942 .0703 L .62112 .07265 L 0 .025 .123 r
F
.61773 .07395 m .61604 .07159 L .61942 .0703 L F
.57883 .07342 m .58044 .06972 L .58219 .07217 L 0 .024 .122 r
F
.57883 .07342 m .57708 .07096 L .58044 .06972 L F
.682 .07344 m .6838 .06983 L .68542 .07222 L 0 .024 .123 r
F
.682 .07344 m .68037 .07106 L .6838 .06983 L F
.62619 .07376 m .62789 .06998 L .62958 .07243 L 0 .025 .123 r
F
.62619 .07376 m .6245 .07132 L .62789 .06998 L F
.63465 .07354 m .63636 .0697 L .63804 .07214 L F
.63465 .07354 m .63297 .07109 L .63636 .0697 L F
.58728 .07335 m .58892 .06968 L .59065 .07211 L F
.58728 .07335 m .58555 .07093 L .58892 .06968 L F
.6431 .07315 m .64483 .06944 L .6465 .07185 L 0 .024 .123 r
F
.6431 .07315 m .64143 .07075 L .64483 .06944 L F
.69047 .07341 m .69227 .0696 L .69389 .07204 L 0 .025 .123 r
F
.69047 .07341 m .68885 .07096 L .69227 .0696 L F
.69893 .0731 m .70075 .06935 L .70236 .07177 L 0 .024 .123 r
F
.69893 .0731 m .69732 .07067 L .70075 .06935 L F
.65156 .07297 m .65331 .06931 L .65497 .07171 L F
.65156 .07297 m .6499 .07058 L .65331 .06931 L F
.59574 .0733 m .59739 .06961 L .59911 .07205 L 0 .025 .124 r
F
.59574 .0733 m .59402 .07087 L .59739 .06961 L F
.70739 .07289 m .70923 .06914 L .71083 .07157 L 0 .024 .123 r
F
.70739 .07289 m .70579 .07045 L .70923 .06914 L F
.66003 .07282 m .66178 .0691 L .66343 .07152 L F
.66003 .07282 m .65837 .07041 L .66178 .0691 L F
.6042 .07314 m .60586 .0694 L .60757 .0718 L 0 .025 .124 r
F
.6042 .07314 m .60248 .07073 L .60586 .0694 L F
.56527 .07252 m .56687 .06866 L .56862 .07115 L 0 .024 .122 r
F
.56527 .07252 m .56351 .07004 L .56687 .06866 L F
.66849 .07259 m .67026 .0689 L .6719 .07127 L 0 .024 .123 r
F
.66849 .07259 m .66685 .07022 L .67026 .0689 L F
.61266 .07287 m .61434 .06923 L .61604 .07159 L 0 .025 .124 r
F
.61266 .07287 m .61095 .0705 L .61434 .06923 L F
.57373 .07227 m .57534 .06847 L .57708 .07096 L 0 .024 .122 r
F
.57373 .07227 m .57198 .06978 L .57534 .06847 L F
.67695 .0723 m .67874 .0687 L .68037 .07106 L 0 .024 .123 r
F
.67695 .0723 m .67532 .06995 L .67874 .0687 L F
.62112 .07265 m .62281 .06896 L .6245 .07132 L 0 .025 .123 r
F
.62112 .07265 m .61942 .0703 L .62281 .06896 L F
.58219 .07217 m .58381 .06847 L .58555 .07093 L 0 .024 .123 r
F
.58219 .07217 m .58044 .06972 L .58381 .06847 L F
.62958 .07243 m .63128 .06863 L .63297 .07109 L 0 .025 .123 r
F
.62958 .07243 m .62789 .06998 L .63128 .06863 L F
.68542 .07222 m .68723 .06857 L .68885 .07096 L F
.68542 .07222 m .6838 .06983 L .68723 .06857 L F
.63804 .07214 m .63975 .06831 L .64143 .07075 L 0 .024 .123 r
F
.63804 .07214 m .63636 .0697 L .63975 .06831 L F
.69389 .07204 m .6957 .06823 L .69732 .07067 L F
.69389 .07204 m .69227 .0696 L .6957 .06823 L F
.6465 .07185 m .64823 .06817 L .6499 .07058 L F
.6465 .07185 m .64483 .06944 L .64823 .06817 L F
.59065 .07211 m .59229 .06842 L .59402 .07087 L 0 .025 .123 r
F
.59065 .07211 m .58892 .06968 L .59229 .06842 L F
.70236 .07177 m .70419 .06806 L .70579 .07045 L 0 .024 .123 r
F
.70236 .07177 m .70075 .06935 L .70419 .06806 L F
.65497 .07171 m .65672 .06799 L .65837 .07041 L F
.65497 .07171 m .65331 .06931 L .65672 .06799 L F
.59911 .07205 m .60076 .06827 L .60248 .07073 L 0 .025 .124 r
F
.59911 .07205 m .59739 .06961 L .60076 .06827 L F
.66343 .07152 m .6652 .06778 L .66685 .07022 L 0 .024 .123 r
F
.66343 .07152 m .66178 .0691 L .6652 .06778 L F
.60757 .0718 m .60924 .06811 L .61095 .0705 L 0 .025 .124 r
F
.60757 .0718 m .60586 .0694 L .60924 .06811 L F
.56862 .07115 m .57022 .06729 L .57198 .06978 L 0 .024 .122 r
F
.56862 .07115 m .56687 .06866 L .57022 .06729 L F
.6719 .07127 m .67368 .06759 L .67532 .06995 L 0 .024 .123 r
F
.6719 .07127 m .67026 .0689 L .67368 .06759 L F
.61604 .07159 m .61772 .06796 L .61942 .0703 L 0 .025 .124 r
F
.61604 .07159 m .61434 .06923 L .61772 .06796 L F
.57708 .07096 m .5787 .06722 L .58044 .06972 L 0 .024 .122 r
F
.57708 .07096 m .57534 .06847 L .5787 .06722 L F
.68037 .07106 m .68217 .06746 L .6838 .06983 L 0 .024 .123 r
F
.68037 .07106 m .67874 .0687 L .68217 .06746 L F
.6245 .07132 m .6262 .06762 L .62789 .06998 L 0 .025 .123 r
F
.6245 .07132 m .62281 .06896 L .6262 .06762 L F
.63297 .07109 m .63467 .06725 L .63636 .0697 L 0 .024 .123 r
F
.63297 .07109 m .63128 .06863 L .63467 .06725 L F
.58555 .07093 m .58718 .06721 L .58892 .06968 L F
.58555 .07093 m .58381 .06847 L .58718 .06721 L F
.68885 .07096 m .69066 .0672 L .69227 .0696 L F
.68885 .07096 m .68723 .06857 L .69066 .0672 L F
.64143 .07075 m .64316 .06701 L .64483 .06944 L 0 .024 .122 r
F
.64143 .07075 m .63975 .06831 L .64316 .06701 L F
.69732 .07067 m .69914 .06692 L .70075 .06935 L 0 .024 .123 r
F
.69732 .07067 m .6957 .06823 L .69914 .06692 L F
.6499 .07058 m .65164 .0669 L .65331 .06931 L F
.6499 .07058 m .64823 .06817 L .65164 .0669 L F
.59402 .07087 m .59566 .06715 L .59739 .06961 L 0 .025 .123 r
F
.59402 .07087 m .59229 .06842 L .59566 .06715 L F
.70579 .07045 m .70763 .06676 L .70923 .06914 L 0 .024 .123 r
F
.70579 .07045 m .70419 .06806 L .70763 .06676 L F
.65837 .07041 m .66013 .06667 L .66178 .0691 L F
.65837 .07041 m .65672 .06799 L .66013 .06667 L F
.60248 .07073 m .60414 .06694 L .60586 .0694 L 0 .025 .124 r
F
.60248 .07073 m .60076 .06827 L .60414 .06694 L F
.66685 .07022 m .66862 .06646 L .67026 .0689 L 0 .024 .123 r
F
.66685 .07022 m .6652 .06778 L .66862 .06646 L F
.57198 .06978 m .57358 .06597 L .57534 .06847 L 0 .024 .122 r
F
.57198 .06978 m .57022 .06729 L .57358 .06597 L F
.61095 .0705 m .61263 .06685 L .61434 .06923 L 0 .025 .124 r
F
.61095 .0705 m .60924 .06811 L .61263 .06685 L F
.67532 .06995 m .67711 .06632 L .67874 .0687 L 0 .024 .123 r
F
.67532 .06995 m .67368 .06759 L .67711 .06632 L F
.61942 .0703 m .62111 .06662 L .62281 .06896 L 0 .025 .124 r
F
.61942 .0703 m .61772 .06796 L .62111 .06662 L F
.58044 .06972 m .58207 .06598 L .58381 .06847 L 0 .024 .122 r
F
.58044 .06972 m .5787 .06722 L .58207 .06598 L F
.62789 .06998 m .62959 .06626 L .63128 .06863 L 0 .025 .123 r
F
.62789 .06998 m .6262 .06762 L .62959 .06626 L F
.6838 .06983 m .6856 .06618 L .68723 .06857 L F
.6838 .06983 m .68217 .06746 L .6856 .06618 L F
.63636 .0697 m .63807 .06587 L .63975 .06831 L 0 .024 .122 r
F
.63636 .0697 m .63467 .06725 L .63807 .06587 L F
.69227 .0696 m .69409 .06583 L .6957 .06823 L 0 .024 .123 r
F
.69227 .0696 m .69066 .0672 L .69409 .06583 L F
.64483 .06944 m .64657 .06574 L .64823 .06817 L F
.64483 .06944 m .64316 .06701 L .64657 .06574 L F
.58892 .06968 m .59055 .06594 L .59229 .06842 L 0 .025 .123 r
F
.58892 .06968 m .58718 .06721 L .59055 .06594 L F
.70075 .06935 m .70258 .06565 L .70419 .06806 L 0 .024 .123 r
F
.70075 .06935 m .69914 .06692 L .70258 .06565 L F
.65331 .06931 m .65506 .06557 L .65672 .06799 L F
.65331 .06931 m .65164 .0669 L .65506 .06557 L F
.59739 .06961 m .59904 .06581 L .60076 .06827 L 0 .025 .123 r
F
.59739 .06961 m .59566 .06715 L .59904 .06581 L F
.66178 .0691 m .66355 .06534 L .6652 .06778 L 0 .024 .123 r
F
.66178 .0691 m .66013 .06667 L .66355 .06534 L F
.60586 .0694 m .60753 .06564 L .60924 .06811 L 0 .025 .123 r
F
.60586 .0694 m .60414 .06694 L .60753 .06564 L F
.67026 .0689 m .67204 .06513 L .67368 .06759 L 0 .024 .123 r
F
.67026 .0689 m .66862 .06646 L .67204 .06513 L F
.57534 .06847 m .57695 .06472 L .5787 .06722 L 0 .024 .122 r
F
.57534 .06847 m .57358 .06597 L .57695 .06472 L F
.61434 .06923 m .61602 .06559 L .61772 .06796 L 0 .025 .124 r
F
.61434 .06923 m .61263 .06685 L .61602 .06559 L F
.67874 .0687 m .68054 .06507 L .68217 .06746 L 0 .025 .123 r
F
.67874 .0687 m .67711 .06632 L .68054 .06507 L F
.62281 .06896 m .62451 .06527 L .6262 .06762 L F
.62281 .06896 m .62111 .06662 L .62451 .06527 L F
.63128 .06863 m .63299 .06489 L .63467 .06725 L 0 .024 .123 r
F
.63128 .06863 m .62959 .06626 L .63299 .06489 L F
.58381 .06847 m .58544 .0647 L .58718 .06721 L F
.58381 .06847 m .58207 .06598 L .58544 .0647 L F
.63975 .06831 m .64148 .06457 L .64316 .06701 L 0 .024 .122 r
F
.63975 .06831 m .63807 .06587 L .64148 .06457 L F
.68723 .06857 m .68903 .06481 L .69066 .0672 L 0 .025 .123 r
F
.68723 .06857 m .6856 .06618 L .68903 .06481 L F
.6957 .06823 m .69753 .06452 L .69914 .06692 L 0 .024 .122 r
F
.6957 .06823 m .69409 .06583 L .69753 .06452 L F
.64823 .06817 m .64998 .06447 L .65164 .0669 L 0 .024 .123 r
F
.64823 .06817 m .64657 .06574 L .64998 .06447 L F
.59229 .06842 m .59393 .06466 L .59566 .06715 L 0 .025 .123 r
F
.59229 .06842 m .59055 .06594 L .59393 .06466 L F
.70419 .06806 m .70603 .06438 L .70763 .06676 L 0 .024 .123 r
F
.70419 .06806 m .70258 .06565 L .70603 .06438 L F
.65672 .06799 m .65847 .06423 L .66013 .06667 L F
.65672 .06799 m .65506 .06557 L .65847 .06423 L F
.60076 .06827 m .60242 .06447 L .60414 .06694 L 0 .025 .123 r
F
.60076 .06827 m .59904 .06581 L .60242 .06447 L F
.6652 .06778 m .66697 .06401 L .66862 .06646 L 0 .024 .123 r
F
.6652 .06778 m .66355 .06534 L .66697 .06401 L F
.60924 .06811 m .61092 .06438 L .61263 .06685 L 0 .025 .124 r
F
.60924 .06811 m .60753 .06564 L .61092 .06438 L F
.67368 .06759 m .67547 .06386 L .67711 .06632 L 0 .024 .123 r
F
.67368 .06759 m .67204 .06513 L .67547 .06386 L F
.5787 .06722 m .58032 .06348 L .58207 .06598 L 0 .024 .122 r
F
.5787 .06722 m .57695 .06472 L .58032 .06348 L F
.61772 .06796 m .61941 .06424 L .62111 .06662 L 0 .025 .124 r
F
.61772 .06796 m .61602 .06559 L .61941 .06424 L F
.6262 .06762 m .62791 .06391 L .62959 .06626 L 0 .025 .123 r
F
.6262 .06762 m .62451 .06527 L .62791 .06391 L F
.68217 .06746 m .68398 .06379 L .6856 .06618 L F
.68217 .06746 m .68054 .06507 L .68398 .06379 L F
.63467 .06725 m .63639 .06352 L .63807 .06587 L 0 .024 .123 r
F
.63467 .06725 m .63299 .06489 L .63639 .06352 L F
.69066 .0672 m .69247 .06343 L .69409 .06583 L F
.69066 .0672 m .68903 .06481 L .69247 .06343 L F
.58718 .06721 m .58882 .06342 L .59055 .06594 L F
.58718 .06721 m .58544 .0647 L .58882 .06342 L F
.64316 .06701 m .64489 .06331 L .64657 .06574 L 0 .024 .122 r
F
.64316 .06701 m .64148 .06457 L .64489 .06331 L F
.69914 .06692 m .70097 .06324 L .70258 .06565 L 0 .024 .123 r
F
.69914 .06692 m .69753 .06452 L .70097 .06324 L F
.65164 .0669 m .65339 .06313 L .65506 .06557 L F
.65164 .0669 m .64998 .06447 L .65339 .06313 L F
.59566 .06715 m .59731 .06332 L .59904 .06581 L 0 .025 .123 r
F
.59566 .06715 m .59393 .06466 L .59731 .06332 L F
.66013 .06667 m .66189 .0629 L .66355 .06534 L 0 .024 .123 r
F
.66013 .06667 m .65847 .06423 L .66189 .0629 L F
.60414 .06694 m .60581 .06317 L .60753 .06564 L 0 .025 .123 r
F
.60414 .06694 m .60242 .06447 L .60581 .06317 L F
.66862 .06646 m .67039 .06267 L .67204 .06513 L 0 .024 .122 r
F
.66862 .06646 m .66697 .06401 L .67039 .06267 L F
.61263 .06685 m .61431 .06312 L .61602 .06559 L 0 .025 .124 r
F
.61263 .06685 m .61092 .06438 L .61431 .06312 L F
.67711 .06632 m .6789 .0626 L .68054 .06507 L 0 .024 .123 r
F
.67711 .06632 m .67547 .06386 L .6789 .0626 L F
.62111 .06662 m .62281 .06288 L .62451 .06527 L 0 .025 .124 r
F
.62111 .06662 m .61941 .06424 L .62281 .06288 L F
.58207 .06598 m .5837 .06219 L .58544 .0647 L 0 .024 .122 r
F
.58207 .06598 m .58032 .06348 L .5837 .06219 L F
.62959 .06626 m .63131 .06255 L .63299 .06489 L 0 .025 .123 r
F
.62959 .06626 m .62791 .06391 L .63131 .06255 L F
.63807 .06587 m .6398 .06221 L .64148 .06457 L 0 .024 .122 r
F
.63807 .06587 m .63639 .06352 L .6398 .06221 L F
.6856 .06618 m .68741 .0624 L .68903 .06481 L 0 .025 .123 r
F
.6856 .06618 m .68398 .06379 L .68741 .0624 L F
.69409 .06583 m .69591 .06211 L .69753 .06452 L 0 .024 .123 r
F
.69409 .06583 m .69247 .06343 L .69591 .06211 L F
.59055 .06594 m .5922 .06213 L .59393 .06466 L F
.59055 .06594 m .58882 .06342 L .5922 .06213 L F
.64657 .06574 m .64831 .06204 L .64998 .06447 L F
.64657 .06574 m .64489 .06331 L .64831 .06204 L F
.70258 .06565 m .70442 .06196 L .70603 .06438 L F
.70258 .06565 m .70097 .06324 L .70442 .06196 L F
.65506 .06557 m .65681 .06179 L .65847 .06423 L F
.65506 .06557 m .65339 .06313 L .65681 .06179 L F
.59904 .06581 m .6007 .06199 L .60242 .06447 L 0 .025 .123 r
F
.59904 .06581 m .59731 .06332 L .6007 .06199 L F
.66355 .06534 m .66532 .06157 L .66697 .06401 L 0 .024 .122 r
F
.66355 .06534 m .66189 .0629 L .66532 .06157 L F
.60753 .06564 m .6092 .06191 L .61092 .06438 L 0 .025 .123 r
F
.60753 .06564 m .60581 .06317 L .6092 .06191 L F
.67204 .06513 m .67382 .06139 L .67547 .06386 L 0 .024 .123 r
F
.67204 .06513 m .67039 .06267 L .67382 .06139 L F
.61602 .06559 m .61771 .06176 L .61941 .06424 L 0 .025 .124 r
F
.61602 .06559 m .61431 .06312 L .61771 .06176 L F
.62451 .06527 m .62621 .06152 L .62791 .06391 L 0 .025 .123 r
F
.62451 .06527 m .62281 .06288 L .62621 .06152 L F
.68054 .06507 m .68234 .06131 L .68398 .06379 L F
.68054 .06507 m .6789 .0626 L .68234 .06131 L F
.63299 .06489 m .63471 .06118 L .63639 .06352 L 0 .024 .123 r
F
.63299 .06489 m .63131 .06255 L .63471 .06118 L F
.58544 .0647 m .58708 .0609 L .58882 .06342 L 0 .024 .122 r
F
.58544 .0647 m .5837 .06219 L .58708 .0609 L F
.64148 .06457 m .64322 .06094 L .64489 .06331 L 0 .024 .123 r
F
.64148 .06457 m .6398 .06221 L .64322 .06094 L F
.68903 .06481 m .69085 .06102 L .69247 .06343 L F
.68903 .06481 m .68741 .0624 L .69085 .06102 L F
.69753 .06452 m .69936 .06082 L .70097 .06324 L F
.69753 .06452 m .69591 .06211 L .69936 .06082 L F
.59393 .06466 m .59558 .06081 L .59731 .06332 L F
.59393 .06466 m .5922 .06213 L .59558 .06081 L F
.64998 .06447 m .65172 .06069 L .65339 .06313 L F
.64998 .06447 m .64831 .06204 L .65172 .06069 L F
.65847 .06423 m .66023 .06046 L .66189 .0629 L 0 .024 .122 r
F
.65847 .06423 m .65681 .06179 L .66023 .06046 L F
.60242 .06447 m .60409 .0607 L .60581 .06317 L 0 .025 .123 r
F
.60242 .06447 m .6007 .06199 L .60409 .0607 L F
.66697 .06401 m .66874 .06024 L .67039 .06267 L 0 .024 .122 r
F
.66697 .06401 m .66532 .06157 L .66874 .06024 L F
.61092 .06438 m .6126 .06065 L .61431 .06312 L 0 .025 .124 r
F
.61092 .06438 m .6092 .06191 L .6126 .06065 L F
.67547 .06386 m .67726 .06012 L .6789 .0626 L 0 .024 .123 r
F
.67547 .06386 m .67382 .06139 L .67726 .06012 L F
.61941 .06424 m .62111 .06039 L .62281 .06288 L 0 .025 .124 r
F
.61941 .06424 m .61771 .06176 L .62111 .06039 L F
.62791 .06391 m .62962 .06016 L .63131 .06255 L 0 .025 .123 r
F
.62791 .06391 m .62621 .06152 L .62962 .06016 L F
.63639 .06352 m .63812 .05987 L .6398 .06221 L 0 .024 .123 r
F
.63639 .06352 m .63471 .06118 L .63812 .05987 L F
.68398 .06379 m .68578 .05992 L .68741 .0624 L F
.68398 .06379 m .68234 .06131 L .68578 .05992 L F
.58882 .06342 m .59046 .0596 L .5922 .06213 L 0 .024 .122 r
F
.58882 .06342 m .58708 .0609 L .59046 .0596 L F
.69247 .06343 m .69429 .05969 L .69591 .06211 L 0 .024 .123 r
F
.69247 .06343 m .69085 .06102 L .69429 .05969 L F
.64489 .06331 m .64664 .05966 L .64831 .06204 L F
.64489 .06331 m .64322 .06094 L .64664 .05966 L F
.70097 .06324 m .70281 .05954 L .70442 .06196 L F
.70097 .06324 m .69936 .06082 L .70281 .05954 L F
.59731 .06332 m .59897 .0595 L .6007 .06199 L F
.59731 .06332 m .59558 .06081 L .59897 .0595 L F
.65339 .06313 m .65515 .05934 L .65681 .06179 L 0 .024 .122 r
F
.65339 .06313 m .65172 .06069 L .65515 .05934 L F
.66189 .0629 m .66366 .05915 L .66532 .06157 L F
.66189 .0629 m .66023 .06046 L .66366 .05915 L F
.60581 .06317 m .60748 .05944 L .6092 .06191 L 0 .025 .123 r
F
.60581 .06317 m .60409 .0607 L .60748 .05944 L F
.67039 .06267 m .67218 .05896 L .67382 .06139 L 0 .024 .122 r
F
.67039 .06267 m .66874 .06024 L .67218 .05896 L F
.61431 .06312 m .616 .05927 L .61771 .06176 L 0 .025 .124 r
F
.61431 .06312 m .6126 .06065 L .616 .05927 L F
.6789 .0626 m .6807 .05882 L .68234 .06131 L 0 .024 .123 r
F
.6789 .0626 m .67726 .06012 L .6807 .05882 L F
.62281 .06288 m .62451 .05902 L .62621 .06152 L 0 .025 .123 r
F
.62281 .06288 m .62111 .06039 L .62451 .05902 L F
.63131 .06255 m .63302 .0588 L .63471 .06118 L F
.63131 .06255 m .62962 .06016 L .63302 .0588 L F
.68741 .0624 m .68922 .05853 L .69085 .06102 L 0 .024 .123 r
F
.68741 .0624 m .68578 .05992 L .68922 .05853 L F
.6398 .06221 m .64154 .05858 L .64322 .06094 L F
.6398 .06221 m .63812 .05987 L .64154 .05858 L F
.69591 .06211 m .69774 .0584 L .69936 .06082 L F
.69591 .06211 m .69429 .05969 L .69774 .0584 L F
.5922 .06213 m .59385 .0583 L .59558 .06081 L 0 .024 .122 r
F
.5922 .06213 m .59046 .0596 L .59385 .0583 L F
.64831 .06204 m .65006 .0583 L .65172 .06069 L 0 .024 .123 r
F
.64831 .06204 m .64664 .05966 L .65006 .0583 L F
.6007 .06199 m .60236 .05822 L .60409 .0607 L F
.6007 .06199 m .59897 .0595 L .60236 .05822 L F
.65681 .06179 m .65857 .05802 L .66023 .06046 L 0 .024 .122 r
F
.65681 .06179 m .65515 .05934 L .65857 .05802 L F
.66532 .06157 m .66709 .05784 L .66874 .06024 L F
.66532 .06157 m .66366 .05915 L .66709 .05784 L F
.6092 .06191 m .61088 .05818 L .6126 .06065 L 0 .025 .123 r
F
.6092 .06191 m .60748 .05944 L .61088 .05818 L F
.67382 .06139 m .67562 .05768 L .67726 .06012 L 0 .024 .123 r
F
.67382 .06139 m .67218 .05896 L .67562 .05768 L F
.61771 .06176 m .6194 .05789 L .62111 .06039 L 0 .025 .123 r
F
.61771 .06176 m .616 .05927 L .6194 .05789 L F
.62621 .06152 m .62792 .05766 L .62962 .06016 L F
.62621 .06152 m .62451 .05902 L .62792 .05766 L F
.68234 .06131 m .68414 .05743 L .68578 .05992 L 0 .024 .123 r
F
.68234 .06131 m .6807 .05882 L .68414 .05743 L F
.63471 .06118 m .63644 .05748 L .63812 .05987 L F
.63471 .06118 m .63302 .0588 L .63644 .05748 L F
.69085 .06102 m .69266 .0572 L .69429 .05969 L 0 .024 .122 r
F
.69085 .06102 m .68922 .05853 L .69266 .0572 L F
.64322 .06094 m .64496 .05729 L .64664 .05966 L 0 .024 .123 r
F
.64322 .06094 m .64154 .05858 L .64496 .05729 L F
.59558 .06081 m .59724 .057 L .59897 .0595 L 0 .024 .122 r
F
.59558 .06081 m .59385 .0583 L .59724 .057 L F
.69936 .06082 m .7012 .0571 L .70281 .05954 L 0 .024 .123 r
F
.69936 .06082 m .69774 .0584 L .7012 .0571 L F
.65172 .06069 m .65348 .05694 L .65515 .05934 L 0 .024 .122 r
F
.65172 .06069 m .65006 .0583 L .65348 .05694 L F
.66023 .06046 m .662 .05673 L .66366 .05915 L F
.66023 .06046 m .65857 .05802 L .662 .05673 L F
.60409 .0607 m .60576 .05697 L .60748 .05944 L 0 .025 .123 r
F
.60409 .0607 m .60236 .05822 L .60576 .05697 L F
.66874 .06024 m .67053 .05656 L .67218 .05896 L 0 .024 .122 r
F
.66874 .06024 m .66709 .05784 L .67053 .05656 L F
.6126 .06065 m .61428 .05681 L .616 .05927 L 0 .025 .123 r
F
.6126 .06065 m .61088 .05818 L .61428 .05681 L F
.67726 .06012 m .67906 .05637 L .6807 .05882 L 0 .024 .123 r
F
.67726 .06012 m .67562 .05768 L .67906 .05637 L F
.62111 .06039 m .6228 .05652 L .62451 .05902 L 0 .025 .123 r
F
.62111 .06039 m .6194 .05789 L .6228 .05652 L F
.68578 .05992 m .68758 .05603 L .68922 .05853 L 0 .024 .122 r
F
.68578 .05992 m .68414 .05743 L .68758 .05603 L F
.62962 .06016 m .63133 .0563 L .63302 .0588 L 0 .025 .123 r
F
.62962 .06016 m .62792 .05766 L .63133 .0563 L F
.63812 .05987 m .63986 .05619 L .64154 .05858 L F
.63812 .05987 m .63644 .05748 L .63986 .05619 L F
.69429 .05969 m .69612 .0559 L .69774 .0584 L 0 .024 .122 r
F
.69429 .05969 m .69266 .0572 L .69612 .0559 L F
.64664 .05966 m .64838 .05592 L .65006 .0583 L 0 .024 .123 r
F
.64664 .05966 m .64496 .05729 L .64838 .05592 L F
.59897 .0595 m .60063 .05574 L .60236 .05822 L F
.59897 .0595 m .59724 .057 L .60063 .05574 L F
.65515 .05934 m .65691 .05562 L .65857 .05802 L 0 .024 .122 r
F
.65515 .05934 m .65348 .05694 L .65691 .05562 L F
.66366 .05915 m .66544 .05544 L .66709 .05784 L F
.66366 .05915 m .662 .05673 L .66544 .05544 L F
.60748 .05944 m .60916 .05573 L .61088 .05818 L 0 .025 .123 r
F
.60748 .05944 m .60576 .05697 L .60916 .05573 L F
.67218 .05896 m .67397 .05528 L .67562 .05768 L 0 .024 .123 r
F
.67218 .05896 m .67053 .05656 L .67397 .05528 L F
.616 .05927 m .61769 .05543 L .6194 .05789 L 0 .025 .123 r
F
.616 .05927 m .61428 .05681 L .61769 .05543 L F
.62451 .05902 m .62621 .05516 L .62792 .05766 L 0 .024 .123 r
F
.62451 .05902 m .6228 .05652 L .62621 .05516 L F
.6807 .05882 m .6825 .05498 L .68414 .05743 L 0 .024 .122 r
F
.6807 .05882 m .67906 .05637 L .6825 .05498 L F
.68922 .05853 m .69103 .0547 L .69266 .0572 L F
.68922 .05853 m .68758 .05603 L .69103 .0547 L F
.63302 .0588 m .63475 .05498 L .63644 .05748 L 0 .024 .123 r
F
.63302 .0588 m .63133 .0563 L .63475 .05498 L F
.64154 .05858 m .64328 .05488 L .64496 .05729 L 0 .025 .123 r
F
.64154 .05858 m .63986 .05619 L .64328 .05488 L F
.69774 .0584 m .69958 .05461 L .7012 .0571 L 0 .024 .123 r
F
.69774 .0584 m .69612 .0559 L .69958 .05461 L F
.65006 .0583 m .65181 .05455 L .65348 .05694 L F
.65006 .0583 m .64838 .05592 L .65181 .05455 L F
.60236 .05822 m .60404 .0545 L .60576 .05697 L F
.60236 .05822 m .60063 .05574 L .60404 .0545 L F
.65857 .05802 m .66034 .05433 L .662 .05673 L 0 .024 .122 r
F
.65857 .05802 m .65691 .05562 L .66034 .05433 L F
.66709 .05784 m .66888 .05415 L .67053 .05656 L 0 .024 .123 r
F
.66709 .05784 m .66544 .05544 L .66888 .05415 L F
.61088 .05818 m .61257 .05435 L .61428 .05681 L 0 .025 .123 r
F
.61088 .05818 m .60916 .05573 L .61257 .05435 L F
.6194 .05789 m .6211 .05405 L .6228 .05652 L 0 .024 .123 r
F
.6194 .05789 m .61769 .05543 L .6211 .05405 L F
.67562 .05768 m .67742 .05397 L .67906 .05637 L F
.67562 .05768 m .67397 .05528 L .67742 .05397 L F
.68414 .05743 m .68595 .05359 L .68758 .05603 L 0 .024 .122 r
F
.68414 .05743 m .6825 .05498 L .68595 .05359 L F
.62792 .05766 m .62963 .0538 L .63133 .0563 L 0 .024 .123 r
F
.62792 .05766 m .62621 .05516 L .62963 .0538 L F
.69266 .0572 m .69449 .05341 L .69612 .0559 L 0 .024 .122 r
F
.69266 .0572 m .69103 .0547 L .69449 .05341 L F
.63644 .05748 m .63817 .05368 L .63986 .05619 L 0 .024 .123 r
F
.63644 .05748 m .63475 .05498 L .63817 .05368 L F
.64496 .05729 m .64671 .05351 L .64838 .05592 L 0 .025 .123 r
F
.64496 .05729 m .64328 .05488 L .64671 .05351 L F
.65348 .05694 m .65524 .05322 L .65691 .05562 L 0 .024 .123 r
F
.65348 .05694 m .65181 .05455 L .65524 .05322 L F
.662 .05673 m .66378 .05303 L .66544 .05544 L F
.662 .05673 m .66034 .05433 L .66378 .05303 L F
.60576 .05697 m .60744 .05327 L .60916 .05573 L 0 .025 .123 r
F
.60576 .05697 m .60404 .0545 L .60744 .05327 L F
.67053 .05656 m .67233 .05287 L .67397 .05528 L 0 .024 .123 r
F
.67053 .05656 m .66888 .05415 L .67233 .05287 L F
.61428 .05681 m .61597 .05297 L .61769 .05543 L 0 .025 .123 r
F
.61428 .05681 m .61257 .05435 L .61597 .05297 L F
.6228 .05652 m .62451 .05271 L .62621 .05516 L 0 .024 .123 r
F
.6228 .05652 m .6211 .05405 L .62451 .05271 L F
.67906 .05637 m .68087 .05259 L .6825 .05498 L F
.67906 .05637 m .67742 .05397 L .68087 .05259 L F
.68758 .05603 m .6894 .05226 L .69103 .0547 L 0 .024 .122 r
F
.68758 .05603 m .68595 .05359 L .6894 .05226 L F
.63133 .0563 m .63305 .05247 L .63475 .05498 L 0 .024 .123 r
F
.63133 .0563 m .62963 .0538 L .63305 .05247 L F
.69612 .0559 m .69795 .05211 L .69958 .05461 L 0 .024 .122 r
F
.69612 .0559 m .69449 .05341 L .69795 .05211 L F
.63986 .05619 m .64159 .05237 L .64328 .05488 L 0 .025 .123 r
F
.63986 .05619 m .63817 .05368 L .64159 .05237 L F
.64838 .05592 m .65013 .05213 L .65181 .05455 L 0 .024 .123 r
F
.64838 .05592 m .64671 .05351 L .65013 .05213 L F
.65691 .05562 m .65868 .05192 L .66034 .05433 L F
.65691 .05562 m .65524 .05322 L .65868 .05192 L F
.66544 .05544 m .66723 .05174 L .66888 .05415 L F
.66544 .05544 m .66378 .05303 L .66723 .05174 L F
.60916 .05573 m .61085 .05189 L .61257 .05435 L 0 .025 .123 r
F
.60916 .05573 m .60744 .05327 L .61085 .05189 L F
.61769 .05543 m .61939 .05161 L .6211 .05405 L 0 .024 .123 r
F
.61769 .05543 m .61597 .05297 L .61939 .05161 L F
.67397 .05528 m .67577 .05157 L .67742 .05397 L F
.67397 .05528 m .67233 .05287 L .67577 .05157 L F
.62621 .05516 m .62793 .05136 L .62963 .0538 L F
.62621 .05516 m .62451 .05271 L .62793 .05136 L F
.6825 .05498 m .68431 .0512 L .68595 .05359 L 0 .024 .122 r
F
.6825 .05498 m .68087 .05259 L .68431 .0512 L F
.69103 .0547 m .69286 .05097 L .69449 .05341 L F
.69103 .0547 m .6894 .05226 L .69286 .05097 L F
.63475 .05498 m .63647 .05117 L .63817 .05368 L 0 .024 .123 r
F
.63475 .05498 m .63305 .05247 L .63647 .05117 L F
.64328 .05488 m .64502 .05099 L .64671 .05351 L F
.64328 .05488 m .64159 .05237 L .64502 .05099 L F
.65181 .05455 m .65357 .05079 L .65524 .05322 L F
.65181 .05455 m .65013 .05213 L .65357 .05079 L F
.66034 .05433 m .66212 .05063 L .66378 .05303 L F
.66034 .05433 m .65868 .05192 L .66212 .05063 L F
.61257 .05435 m .61426 .05051 L .61597 .05297 L F
.61257 .05435 m .61085 .05189 L .61426 .05051 L F
.66888 .05415 m .67067 .05044 L .67233 .05287 L F
.66888 .05415 m .66723 .05174 L .67067 .05044 L F
.6211 .05405 m .6228 .05028 L .62451 .05271 L F
.6211 .05405 m .61939 .05161 L .6228 .05028 L F
.67742 .05397 m .67922 .05019 L .68087 .05259 L F
.67742 .05397 m .67577 .05157 L .67922 .05019 L F
.62963 .0538 m .63135 .05003 L .63305 .05247 L 0 .024 .122 r
F
.62963 .0538 m .62793 .05136 L .63135 .05003 L F
.68595 .05359 m .68777 .04988 L .6894 .05226 L F
.68595 .05359 m .68431 .0512 L .68777 .04988 L F
.69449 .05341 m .69633 .04967 L .69795 .05211 L F
.69449 .05341 m .69286 .05097 L .69633 .04967 L F
.63817 .05368 m .6399 .04985 L .64159 .05237 L 0 .024 .123 r
F
.63817 .05368 m .63647 .05117 L .6399 .04985 L F
.64671 .05351 m .64845 .0496 L .65013 .05213 L F
.64671 .05351 m .64502 .05099 L .64845 .0496 L F
.65524 .05322 m .65701 .04949 L .65868 .05192 L F
.65524 .05322 m .65357 .05079 L .65701 .04949 L F
.66378 .05303 m .66557 .04932 L .66723 .05174 L F
.66378 .05303 m .66212 .05063 L .66557 .04932 L F
.61597 .05297 m .61767 .04916 L .61939 .05161 L F
.61597 .05297 m .61426 .05051 L .61767 .04916 L F
.67233 .05287 m .67412 .04912 L .67577 .05157 L F
.67233 .05287 m .67067 .05044 L .67412 .04912 L F
.62451 .05271 m .62622 .04895 L .62793 .05136 L F
.62451 .05271 m .6228 .05028 L .62622 .04895 L F
.68087 .05259 m .68268 .04881 L .68431 .0512 L 0 .024 .122 r
F
.68087 .05259 m .67922 .05019 L .68268 .04881 L F
.63305 .05247 m .63478 .04871 L .63647 .05117 L F
.63305 .05247 m .63135 .05003 L .63478 .04871 L F
.6894 .05226 m .69124 .04859 L .69286 .05097 L F
.6894 .05226 m .68777 .04988 L .69124 .04859 L F
.64159 .05237 m .64333 .04846 L .64502 .05099 L 0 .024 .123 r
F
.64159 .05237 m .6399 .04985 L .64333 .04846 L F
.65013 .05213 m .65189 .04826 L .65357 .05079 L 0 .024 .122 r
F
.65013 .05213 m .64845 .0496 L .65189 .04826 L F
.65868 .05192 m .66045 .04819 L .66212 .05063 L 0 .024 .123 r
F
.65868 .05192 m .65701 .04949 L .66045 .04819 L F
.66723 .05174 m .66902 .048 L .67067 .05044 L F
.66723 .05174 m .66557 .04932 L .66902 .048 L F
.61939 .05161 m .62109 .04785 L .6228 .05028 L F
.61939 .05161 m .61767 .04916 L .62109 .04785 L F
.67577 .05157 m .67758 .04774 L .67922 .05019 L F
.67577 .05157 m .67412 .04912 L .67758 .04774 L F
.62793 .05136 m .62965 .04762 L .63135 .05003 L F
.62793 .05136 m .62622 .04895 L .62965 .04762 L F
.68431 .0512 m .68614 .04749 L .68777 .04988 L 0 .024 .122 r
F
.68431 .0512 m .68268 .04881 L .68614 .04749 L F
.63647 .05117 m .63821 .04739 L .6399 .04985 L F
.63647 .05117 m .63478 .04871 L .63821 .04739 L F
.69286 .05097 m .6947 .0473 L .69633 .04967 L F
.69286 .05097 m .69124 .04859 L .6947 .0473 L F
.64502 .05099 m .64677 .04707 L .64845 .0496 L F
.64502 .05099 m .64333 .04846 L .64677 .04707 L F
.65357 .05079 m .65533 .04697 L .65701 .04949 L 0 .024 .123 r
F
.65357 .05079 m .65189 .04826 L .65533 .04697 L F
.66212 .05063 m .6639 .04687 L .66557 .04932 L F
.66212 .05063 m .66045 .04819 L .6639 .04687 L F
.67067 .05044 m .67247 .04667 L .67412 .04912 L F
.67067 .05044 m .66902 .048 L .67247 .04667 L F
.6228 .05028 m .62452 .04654 L .62622 .04895 L F
.6228 .05028 m .62109 .04785 L .62452 .04654 L F
.67922 .05019 m .68103 .04636 L .68268 .04881 L F
.67922 .05019 m .67758 .04774 L .68103 .04636 L F
.63135 .05003 m .63308 .0463 L .63478 .04871 L F
.63135 .05003 m .62965 .04762 L .63308 .0463 L F
.68777 .04988 m .6896 .04621 L .69124 .04859 L 0 .024 .122 r
F
.68777 .04988 m .68614 .04749 L .6896 .04621 L F
.6399 .04985 m .64164 .046 L .64333 .04846 L F
.6399 .04985 m .63821 .04739 L .64164 .046 L F
.64845 .0496 m .65021 .04573 L .65189 .04826 L F
.64845 .0496 m .64677 .04707 L .65021 .04573 L F
.65701 .04949 m .65878 .04568 L .66045 .04819 L 0 .024 .123 r
F
.65701 .04949 m .65533 .04697 L .65878 .04568 L F
.66557 .04932 m .66735 .04554 L .66902 .048 L F
.66557 .04932 m .6639 .04687 L .66735 .04554 L F
.67412 .04912 m .67592 .04529 L .67758 .04774 L F
.67412 .04912 m .67247 .04667 L .67592 .04529 L F
.62622 .04895 m .62795 .04521 L .62965 .04762 L F
.62622 .04895 m .62452 .04654 L .62795 .04521 L F
.68268 .04881 m .6845 .04504 L .68614 .04749 L 0 .024 .122 r
F
.68268 .04881 m .68103 .04636 L .6845 .04504 L F
.63478 .04871 m .63651 .04496 L .63821 .04739 L 0 .024 .123 r
F
.63478 .04871 m .63308 .0463 L .63651 .04496 L F
.69124 .04859 m .69308 .04492 L .6947 .0473 L F
.69124 .04859 m .6896 .04621 L .69308 .04492 L F
.64333 .04846 m .64508 .0446 L .64677 .04707 L 0 .024 .122 r
F
.64333 .04846 m .64164 .046 L .64508 .0446 L F
.65189 .04826 m .65365 .04445 L .65533 .04697 L F
.65189 .04826 m .65021 .04573 L .65365 .04445 L F
.66045 .04819 m .66223 .04436 L .6639 .04687 L 0 .024 .123 r
F
.66045 .04819 m .65878 .04568 L .66223 .04436 L F
.66902 .048 m .67081 .0442 L .67247 .04667 L F
.66902 .048 m .66735 .04554 L .67081 .0442 L F
.67758 .04774 m .67938 .04391 L .68103 .04636 L F
.67758 .04774 m .67592 .04529 L .67938 .04391 L F
.62965 .04762 m .63138 .04387 L .63308 .0463 L F
.62965 .04762 m .62795 .04521 L .63138 .04387 L F
.68614 .04749 m .68797 .04374 L .6896 .04621 L F
.68614 .04749 m .6845 .04504 L .68797 .04374 L F
.63821 .04739 m .63995 .04357 L .64164 .046 L 0 .024 .122 r
F
.63821 .04739 m .63651 .04496 L .63995 .04357 L F
.64677 .04707 m .64852 .04327 L .65021 .04573 L F
.64677 .04707 m .64508 .0446 L .64852 .04327 L F
.65533 .04697 m .6571 .04317 L .65878 .04568 L F
.65533 .04697 m .65365 .04445 L .6571 .04317 L F
.6639 .04687 m .66569 .04303 L .66735 .04554 L 0 .024 .123 r
F
.6639 .04687 m .66223 .04436 L .66569 .04303 L F
.67247 .04667 m .67427 .04282 L .67592 .04529 L F
.67247 .04667 m .67081 .0442 L .67427 .04282 L F
.68103 .04636 m .68285 .04257 L .6845 .04504 L 0 .024 .122 r
F
.68103 .04636 m .67938 .04391 L .68285 .04257 L F
.63308 .0463 m .63482 .04253 L .63651 .04496 L 0 .024 .123 r
F
.63308 .0463 m .63138 .04387 L .63482 .04253 L F
.6896 .04621 m .69144 .04244 L .69308 .04492 L F
.6896 .04621 m .68797 .04374 L .69144 .04244 L F
.64164 .046 m .64339 .04218 L .64508 .0446 L 0 .024 .122 r
F
.64164 .046 m .63995 .04357 L .64339 .04218 L F
.65021 .04573 m .65197 .04199 L .65365 .04445 L F
.65021 .04573 m .64852 .04327 L .65197 .04199 L F
.65878 .04568 m .66056 .04185 L .66223 .04436 L F
.65878 .04568 m .6571 .04317 L .66056 .04185 L F
.66735 .04554 m .66915 .04169 L .67081 .0442 L 0 .024 .123 r
F
.66735 .04554 m .66569 .04303 L .66915 .04169 L F
.67592 .04529 m .67773 .04144 L .67938 .04391 L F
.67592 .04529 m .67427 .04282 L .67773 .04144 L F
.6845 .04504 m .68632 .04126 L .68797 .04374 L 0 .024 .122 r
F
.6845 .04504 m .68285 .04257 L .68632 .04126 L F
.63651 .04496 m .63825 .04114 L .63995 .04357 L F
.63651 .04496 m .63482 .04253 L .63825 .04114 L F
.64508 .0446 m .64684 .04084 L .64852 .04327 L F
.64508 .0446 m .64339 .04218 L .64684 .04084 L F
.65365 .04445 m .65543 .04071 L .6571 .04317 L F
.65365 .04445 m .65197 .04199 L .65543 .04071 L F
.66223 .04436 m .66402 .04052 L .66569 .04303 L 0 .024 .123 r
F
.66223 .04436 m .66056 .04185 L .66402 .04052 L F
.67081 .0442 m .67261 .04033 L .67427 .04282 L F
.67081 .0442 m .66915 .04169 L .67261 .04033 L F
.67938 .04391 m .6812 .0401 L .68285 .04257 L 0 .024 .122 r
F
.67938 .04391 m .67773 .04144 L .6812 .0401 L F
.68797 .04374 m .6898 .03995 L .69144 .04244 L 0 .024 .123 r
F
.68797 .04374 m .68632 .04126 L .6898 .03995 L F
.63995 .04357 m .6417 .03974 L .64339 .04218 L 0 .024 .122 r
F
.63995 .04357 m .63825 .04114 L .6417 .03974 L F
.64852 .04327 m .65029 .03957 L .65197 .04199 L F
.64852 .04327 m .64684 .04084 L .65029 .03957 L F
.6571 .04317 m .65888 .03938 L .66056 .04185 L F
.6571 .04317 m .65543 .04071 L .65888 .03938 L F
.66569 .04303 m .66748 .03918 L .66915 .04169 L 0 .024 .123 r
F
.66569 .04303 m .66402 .04052 L .66748 .03918 L F
.67427 .04282 m .67607 .03896 L .67773 .04144 L 0 .024 .122 r
F
.67427 .04282 m .67261 .04033 L .67607 .03896 L F
.68285 .04257 m .68467 .03878 L .68632 .04126 L F
.68285 .04257 m .6812 .0401 L .68467 .03878 L F
.64339 .04218 m .64515 .03841 L .64684 .04084 L F
.64339 .04218 m .6417 .03974 L .64515 .03841 L F
.65197 .04199 m .65375 .03829 L .65543 .04071 L F
.65197 .04199 m .65029 .03957 L .65375 .03829 L F
.66056 .04185 m .66234 .03804 L .66402 .04052 L F
.66056 .04185 m .65888 .03938 L .66234 .03804 L F
.66915 .04169 m .67094 .03783 L .67261 .04033 L F
.66915 .04169 m .66748 .03918 L .67094 .03783 L F
.67773 .04144 m .67955 .03763 L .6812 .0401 L F
.67773 .04144 m .67607 .03896 L .67955 .03763 L F
.68632 .04126 m .68815 .03746 L .6898 .03995 L 0 .024 .123 r
F
.68632 .04126 m .68467 .03878 L .68815 .03746 L F
.64684 .04084 m .6486 .03714 L .65029 .03957 L 0 .024 .122 r
F
.64684 .04084 m .64515 .03841 L .6486 .03714 L F
.65543 .04071 m .65721 .03695 L .65888 .03938 L F
.65543 .04071 m .65375 .03829 L .65721 .03695 L F
.66402 .04052 m .66581 .0367 L .66748 .03918 L F
.66402 .04052 m .66234 .03804 L .66581 .0367 L F
.67261 .04033 m .67441 .03647 L .67607 .03896 L F
.67261 .04033 m .67094 .03783 L .67441 .03647 L F
.6812 .0401 m .68302 .03632 L .68467 .03878 L F
.6812 .0401 m .67955 .03763 L .68302 .03632 L F
.65029 .03957 m .65206 .03587 L .65375 .03829 L 0 .024 .123 r
F
.65029 .03957 m .6486 .03714 L .65206 .03587 L F
.65888 .03938 m .66067 .0356 L .66234 .03804 L 0 .024 .122 r
F
.65888 .03938 m .65721 .03695 L .66067 .0356 L F
.66748 .03918 m .66928 .03536 L .67094 .03783 L F
.66748 .03918 m .66581 .0367 L .66928 .03536 L F
.67607 .03896 m .67789 .03515 L .67955 .03763 L F
.67607 .03896 m .67441 .03647 L .67789 .03515 L F
.68467 .03878 m .68651 .03501 L .68815 .03746 L 0 .024 .123 r
F
.68467 .03878 m .68302 .03632 L .68651 .03501 L F
.65375 .03829 m .65553 .03451 L .65721 .03695 L F
.65375 .03829 m .65206 .03587 L .65553 .03451 L F
.66234 .03804 m .66414 .03425 L .66581 .0367 L 0 .024 .122 r
F
.66234 .03804 m .66067 .0356 L .66414 .03425 L F
.67094 .03783 m .67275 .03402 L .67441 .03647 L F
.67094 .03783 m .66928 .03536 L .67275 .03402 L F
.67955 .03763 m .68137 .03386 L .68302 .03632 L F
.67955 .03763 m .67789 .03515 L .68137 .03386 L F
.65721 .03695 m .65899 .03315 L .66067 .0356 L 0 .024 .123 r
F
.65721 .03695 m .65553 .03451 L .65899 .03315 L F
.66581 .0367 m .66761 .03291 L .66928 .03536 L 0 .024 .122 r
F
.66581 .0367 m .66414 .03425 L .66761 .03291 L F
.67441 .03647 m .67623 .0327 L .67789 .03515 L F
.67441 .03647 m .67275 .03402 L .67623 .0327 L F
.68302 .03632 m .68486 .03256 L .68651 .03501 L 0 .024 .123 r
F
.68302 .03632 m .68137 .03386 L .68486 .03256 L F
.66067 .0356 m .66246 .03179 L .66414 .03425 L F
.66067 .0356 m .65899 .03315 L .66246 .03179 L F
.66928 .03536 m .67109 .03158 L .67275 .03402 L 0 .024 .122 r
F
.66928 .03536 m .66761 .03291 L .67109 .03158 L F
.67789 .03515 m .67972 .0314 L .68137 .03386 L 0 .024 .123 r
F
.67789 .03515 m .67623 .0327 L .67972 .0314 L F
.66414 .03425 m .66594 .03046 L .66761 .03291 L F
.66414 .03425 m .66246 .03179 L .66594 .03046 L F
.67275 .03402 m .67457 .03026 L .67623 .0327 L F
.67275 .03402 m .67109 .03158 L .67457 .03026 L F
.68137 .03386 m .68321 .03011 L .68486 .03256 L F
.68137 .03386 m .67972 .0314 L .68321 .03011 L F
.66761 .03291 m .66942 .02914 L .67109 .03158 L F
.66761 .03291 m .66594 .03046 L .66942 .02914 L F
.67623 .0327 m .67806 .02896 L .67972 .0314 L F
.67623 .0327 m .67457 .03026 L .67806 .02896 L F
.67109 .03158 m .6729 .02782 L .67457 .03026 L F
.67109 .03158 m .66942 .02914 L .6729 .02782 L F
.67972 .0314 m .68155 .02765 L .68321 .03011 L F
.67972 .0314 m .67806 .02896 L .68155 .02765 L F
.67457 .03026 m .67639 .02651 L .67806 .02896 L F
.67457 .03026 m .6729 .02782 L .67639 .02651 L F
.67806 .02896 m .67989 .02519 L .68155 .02765 L 0 .025 .123 r
F
.67806 .02896 m .67639 .02651 L .67989 .02519 L F
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.1089 .22705 m
.11358 .23164 L
s
[(-0.05)] .09953 .21786 1 .9808 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.59985 .03481 m
.60363 .04017 L
s
[(0.05)] .59229 .02408 .70489 1 Mshowa
.125 Mabswid
.15407 .20936 m
.15683 .21216 L
s
.20005 .19136 m
.20277 .1942 L
s
.24686 .17303 m
.24953 .17592 L
s
.29452 .15436 m
.29714 .1573 L
s
.39251 .11599 m
.39503 .11902 L
s
.44289 .09627 m
.44534 .09934 L
s
.49421 .07617 m
.49661 .07929 L
s
.54652 .05569 m
.54886 .05886 L
s
.06452 .24443 m
.06737 .24714 L
s
.65421 .01352 m
.65641 .01679 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[46]:=",
  ImageSize->{506.688, 411},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007j0001Vb000`400?l00000o`00003ooooooook
ooooo`00oooooookooooo`00oooooookooooo`00oooooookooooo`00oooooookooooo`00oooooook
ooooo`00oooooookooooo`00oooooookooooo`00oooooookooooo`00oooooomVooooo`;o0000Tooo
ool00?ooooooHoooool3o`000003ooooool0003ooooo09;ooooo003oooooof7ooooo0_l00004oooo
o`;o0000T_ooool00?oooooo:?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?o
oooo0ol0000Rooooo`?o00001_ooool00ol0003oooooo`00002Aooooo`00oooooolWooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
oooo01gooooo0_l00009ooooo`03o`000?oooooo0000097ooooo003oooooobOooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01[ooooo0ol0
000;ooooo`04o`000?ooooooooooo`00093ooooo003oooooobOooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01Oooooo0ol0000>ooooo`05
o`000?ooooooooooooooool00000Soooool00?oooooo9oooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooo`000?ooool01?l0000Hooooo`;o000000?oooooo`000?ooool03_ooool0
1Ol0003ooooooooooooooooo000008oooooo003oooooobOooooo00Co0000oooooooooooo00002?oo
ool01_l0003oooooooooool0003oooooo`0001Sooooo0ol00004ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2<ooooo`00oooooolXooooo`;o0000
2_ooool2o`0000;ooooo1Ol0000Booooo`;o00005oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo08_ooooo003oooooodcooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0Roooool00?ooooooB_ooool2o`0001cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2:ooooo`00oooooom7ooooo`?o00007_ooool00ol0003oooooooooo`03oooo
o`;o0000Roooool00?ooooooAOooool2o`0001_ooooo0_l01Ql4ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool00000Roooool00?oooooo@_ooool3o`0001[ooooo1Ol01Ql4ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0R?ooool00?oooooo@?ooool2o`0001[ooooo2Ol0
1Ql3ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0R?ooool00?oooooo?Oooool3
o`0001[ooooo2ol01Ql3ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Qoooool0
0?oooooo>_ooool3o`000003ooooool0003ooooo01Oooooo3ol01Ql2ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Q_ooool00?oooooo>?ooool2o`0000Gooooo00?o0000oooooooo
ool04ooooolBo`067`03ooooool0003ooooo00Sooooo00?o0000ooooooooool0Q_ooool00?oooooo
=Oooool3o`0000Oooooo00?o0000ooooooooool04?oooolEo`067`03ooooool0003ooooo00Wooooo
00?o0000ooooooooool0QOooool00?oooooo<oooool2o`0001[ooooo6Ol01Ql00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo08Cooooo003ooooooc3ooooo0ol0000Joooooa_o00HO00?o0000
ooooooooool02Oooool00ol0003oooooooooo`24ooooo`00ooooool^ooooo`;o00006_oooolNo`06
7`03o`000?l01Qoooooo00[ooooo00?o0000ooooooooool0Poooool00?oooooo:oooool3o`0001[o
oooo8?l01Ql00ol0003o00HOooooo`0;ooooo`03o`000?oooooooooo00oooooo0_l00004ooooo`03
o`000?oooooooooo00?ooooo0_l00003ooooo`?o0000Goooool00?oooooo:Oooool2o`0001[ooooo
8ol01Ql00ol0003o00HOo`067`0;ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0G?ooool0
0?oooooo9_ooool3o`0001Wooooo9_l01Ql00ol0003o00HOo`067`0<ooooo`03o`000?oooooooooo
00Kooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`1Looooo`00oooooolTooooo`;o00006_oooolYo`067`03o`000?l01Qoo
00HO00cooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0G?ooool00?oooooo8Oooool3o`000003ooooool0
003ooooo01Kooooo;?l01Ql01?l0003o00HOo`067ol01Ql;ooooo`03o`000?oooooooooo00cooooo
00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co0000Goooool00?oo
oooo7_ooool3o`0000Gooooo00?o0000ooooooooool04Oooool_o`067`04o`000?l01Qoo00HOo`06
7`cooooo00?o0000ooooooooool02oooool01?l0003oooooooooool00008ooooo`06o`000?oooooo
ooooo`000?oooooo0000H_ooool00?oooooo7?ooool2o`0001_ooooo<?l01Ql00ol0003o00HOo`06
7`02o`067`cooooo00?o0000ooooooooool02oooool2o`0000[ooooo0_l00002ooooo`Go0000G_oo
ool00?oooooo6Oooool3o`0001Wooooo=?l01Ql00ol0003o00HOo`067`03o`067`[ooooo0_l00020
ooooo`00oooooolGooooo`;o00006Ooooolgo`067`03o`000?l01Qoo00HO00Co00HO1oooool2o`00
00;ooooo00?o0000ooooooooool0OOooool00?oooooo5?ooool3o`0001[ooooo>?l01Ql00ol0003o
00HOo`067`04o`067`cooooo00?o0000ooooooooool0O?ooool00?oooooo4_ooool2o`0001[ooooo
>ol01Ql00ol0003o00HOo`067`04o`067`cooooo00?o0000ooooooooool0O?ooool00?oooooo3ooo
ool3o`0001Wooooo?_l01Ql00ol0003o00HOo`067`05o`067`cooooo00?o0000ooooooooool0Nooo
ool00?oooooo3Oooool2o`0001[ooooo@?l01Ql00ol0003o00HOo`067`06o`067`cooooo00?o0000
ooooooooool0N_ooool00?oooooo2_ooool3o`0001Wooooo@ol01Ql00ol0003o00HOo`067`07o`06
7`_ooooo00?o0000ooooooooool0N_ooool00?oooooo2?ooool2o`0000?ooooo00?o0000oooooooo
ool05?oooom5o`067`03o`000?l01Qoo00HO00Oo00HO3?ooool00ol0003oooooooooo`1iooooo`00
ooooool5ooooo`?o00006Ooooom8o`067`03o`000?l01Qoo00HO00So00HO3?ooool00ol0003ooooo
ooooo`1hooooo`00ooooool2ooooo`?o00006Ooooom;o`067`03o`000?l01Qoo00HO00Wo00HO2ooo
ool00ol0003oooooooooo`1hooooo`00ooooool2o`0001_oooooC?l01Ql00ol0003o00HOo`067`0:
o`067`_ooooo00?o0000ooooooooool0Moooool00?cooooo0ol0000Ioooooe3o00HO00?o0000o`06
7ol01Ql02_l01Ql<ooooo`03o`000?oooooooooo07Kooooo003jooooo`;o00006OoooomDo`067`03
o`000?l01Qoo00HO00[o00HO2oooool00ol0003oooooooooo`1fooooo`00moooool3o`0001[ooooo
EOl01Ql00ol0003o00HOo`067`0;o`067`_ooooo00?o0000ooooooooool0MOooool00?Gooooo0_l0
000JoooooeSo00HO00?o0000o`067ol01Ql02ol01Ql;ooooo`03o`000?oooooooooo07Gooooo003b
ooooo`?o00006OoooomKo`067`03o`000?l01Qoo00HO00co00HO2oooool00ol0003oooooooooo`1d
ooooo`00l?ooool2o`0000?ooooo00?o0000ooooooooool05?oooomMo`067`03o`000?l01Qoo00HO
00co00HO3?ooool00ol0003oooooooooo`1cooooo`00kOooool3o`0001WoooooH?l01Ql00ol0003o
00HOo`067`0=o`067`_ooooo0_l0001dooooo`00joooool2o`0001_ooooo00?o00HPo`067ol01Ql0
G_l01Ql00ol0003o00HOo`067`0>o`067`Wooooo00?o0000ooooool00000M?ooool00>Sooooo0ol0
000Jooooo`04o`067ol01R3o00HPo`0683?o00HO00?o00HPo`067ol01Ql0:_l01Ql00ol0003o00HO
o`067`0>o`067`cooooo00?o0000ooooooooool0LOooool00>Gooooo0ol0000Joooooc[o00HO0_l0
1R0[o`067`03o`000?l01Qoo00HO00oo00HO2oooool00ol0003oooooooooo`1aooooo`00_Oooool2
o`0002Cooooo0_l0000Jooooocgo00HO00?o00HPo`067ol01Ql0:_l01Ql00ol0003o00HOo`067`0@
o`067`_ooooo00?o0000ooooooooool0L?ooool00;cooooo00Co0000oooooooooooo00008?ooool3
o`0001[oooooK?l01Ql00ol0003o00HOo`067`0Ao`067`_ooooo00?o0000ooooooooool0Koooool0
0;cooooo00Co0000oooooooooooo00007_ooool2o`0001[oooooKol01Ql00ol0003o00HOo`067`0A
o`067`_ooooo00?o0000ooooooooool0Koooool00;cooooo00Co0000oooooooooooo00006oooool3
o`0001Wooooo00?o00HPo`067ol01Ql0Kol01Ql00ol0003o00HOo`067`0Bo`067`_ooooo00?o0000
ooooooooool0K_ooool00;cooooo00Co0000oooooooooooo00006Oooool2o`000003ooooool0003o
oooo01Sooooo0_l01R1ao`067`03o`000?l01Qoo00HO01?o00HO2oooool00ol0003oooooooooo`1]
ooooo`00_?ooool01?l0003oooooooooool0000Fooooo`?o00001?ooool00ol0003oooooooooo`0C
ooooo`?o00HPLol01Ql00ol0003o00HOo`067`0Co`067`_ooooo00?o0000ooooooooool0KOooool0
0;gooooo0_l0000Eooooo`;o00006_ooool5o`0684?o00HO00?o00HPo`067ol01Ql09?l01Ql3o`06
80Oo00HO00?o0000o`067ol01Ql04ol01Ql<ooooo`03o`000?oooooooooo06cooooo003Aooooo`?o
00006_ooool6o`0682oo00HO0ol01R0?o`067`Oo00HP8ol01Ql3o`0680So00HO00?o0000o`067ol0
1Ql04ol01Ql<ooooo`03o`000?oooooooooo06_ooooo003>ooooo`?o00006_ooool2o`067`Oo00HP
00?o00HOo`068?l01R00;?l01Ql4o`0680co00HO2?l01R0_o`067`03o`000?l01Qoo00HO01Co00HO
2oooool00ol0003oooooooooo`1[ooooo`00c?ooool2o`0001[ooooo1Ol01Ql<o`0682_o00HO0_l0
1R0=o`067`So00HP;ol01Ql00ol0003o00HOo`067`0Eo`067`_ooooo00?o0000ooooooooool0J_oo
ool00<Wooooo0ol0000Iooooo`_o00HO2_l01R0[o`067`Co00HP00Co00HOo`068?l01R3o00HO0_l0
1R05o`067`03o`068?l01Qoo00HP00Go00HP;_l01Ql00ol0003o00HOo`067`0Eo`067`cooooo00?o
0000ooooooooool0JOooool00<Oooooo0_l0000Kooooo`03o`068?l01Qoo00HO00So00HO3?l01R0Y
o`067`_o00HP2_l01Ql4o`0682go00HO00?o0000o`067ol01Ql05_l01Ql;ooooo`03o`000?oooooo
oooo06Wooooo0034ooooo`?o00006_ooool5o`0680Wo00HO2ol01R0>o`067`?o00HP4_l01Ql3o`06
8003o`067ol01R3o00HP00co00HP2_l01Ql4o`0682go00HO00?o0000o`067ol01Ql05ol01Ql;oooo
o`03o`000?oooooooooo06Sooooo0032ooooo`;o000000?oooooo`000?ooool05oooool8o`0680Ko
00HO3_l01R0>o`067`Co00HP00?o00HOo`068?l01Ql03Ol01QlCo`0680_o00HO1?l01R0/o`067`03
o`000?l01Qoo00HO01Oo00HO2oooool2o`0006Wooooo002oooooo`?o00001?ooool00ol0003ooooo
ooooo`0Booooo`03o`067ol01R3o00HP00Oo00HP00?o00HOo`068?l01R000_l01QlAo`0680co00HO
1_l01R0>o`067aGo00HP2ol01Ql4o`068003o`067ol01R3o00HO01So00HO0_l01R000ol01Qoo00HP
o`067`0;o`067`03o`000?l01Qoo00HO01So00HO2Oooool00ol0003oooooo`00001Yooooo`00_Ooo
ool2o`0000Sooooo00?o0000ooooooooool03_ooool5o`067aoo00HP3?l01Ql5o`0680ko00HO5ol0
1R001?l01Qoo00HPo`067ol01R03o`067`Wo00HP6?l01Ql5o`0680_o00HO00?o0000o`067ol01Ql0
6Ol01Ql;ooooo`03o`000?oooooooooo06Kooooo002jooooo`?o00006_ooool7o`067aoo00HP3Ol0
1Ql00ol01R3o00HOo`067`0=o`067`Ko00HP00?o00LPo`068?l01b004ol01R000ol01Qoo00HPo`06
8008o`0681Ko00HO2Ol01R0:o`067`03o`000?l01Qoo00HO01Wo00HO3?ooool00ol0003ooooooooo
o`1Uooooo`00^?ooool2o`0001[ooooo0_l01R08o`067aoo00HP00?o00HOo`068?l01R004?l01Ql0
0ol01R3o00HOo`067`07o`067`Ko00HP1?l01b0Mo`0681?o00HO3?l01R0:o`067`03o`000?l01Qoo
00HO01[o00HO2oooool00ol0003oooooooooo`1Uooooo`00]Oooool3o`0001Wooooo1Ol01R06o`06
7bGo00HP3Ol01Ql6o`068004o`067ol01R3o00HOo`067`Wo00HP1?l01b0Fo`0680?o00HO1?l01R00
0ol01Qoo00HPo`067`09o`067`?o00HP00?o00HOo`068?l01R001?l01R03o`067`03o`068?l01Qoo
00HP00;o00HP2_l01Ql00ol0003o00HOo`067`0Ko`067`_ooooo00?o0000ooooooooool0I?ooool0
0;;ooooo0ol0000Iooooo`Wo00HP0_l01QlSo`0680;o00HO0_l01R0;o`067aKo00HP1Ol01b0Do`06
80Go00HO1ol01R000ol01Qoo00HPo`068005o`067`Oo00HP5Ol01Ql00ol0003o00HOo`067`0Lo`06
7`_ooooo00?o0000ooooooooool0Hoooool00;3ooooo0_l0000Joooooc3o00HP2Ol01Ql2o`068003
o`067ol01R3o00HP01Oo00HP1ol01b000ol01R3o00LPo`06800?o`0680Co00HO3Ol01R000ol01Qoo
00HPo`068007o`0681Go00HO00?o0000o`067ol01Ql07?l01Ql;ooooo`03o`000?oooooooooo06?o
oooo002]ooooo`?o00006_ooool2o`067`03o`068?l01Qoo00HO02go00HP1ol01QlLo`0680_o00LP
1_l01R000ol01Qoo00HPo`068007o`068003o`067ol01R3o00HP01Wo00HP3?l01Ql00ol01R3o00HO
o`067`05o`067`03o`000?l01Qoo00HO01go00HO2oooool00ol0003oooooooooo`1Rooooo`00Zooo
ool2o`0000?ooooo00?o0000ooooooooool05?ooool00ol01R3o00HOo`067`04o`067bco00HP2Ol0
1QlJo`0680go00LP1_l01R02o`067aco00HP0_l01Ql00ol01R3o00HOo`067`03o`0680Wo00HO1ol0
1R04o`067`03o`000?l01R3o00HO01ko00HO2_ooool00ol0003oooooooooo`1Rooooo`00Z?ooool3
o`0001Wooooo1?l01R06o`067bgo00HP1_l01QlIo`0680oo00LP1_l01R04o`067a[o00HP1Ol01Ql7
o`068003o`067ol01R3o00HO00?o00HO1ol01R001_l01Qoo00HPo`068?l01R3o0000o`0681oo00HO
2oooool00ol0003oooooooooo`1Qooooo`00Y_ooool2o`0001[ooooo1Ol01R05o`067aGo00HP0ol0
1b0Ho`0680Go00HO5_l01R0Co`0780Go00HP00?o00HOo`068?l01Ql02?l01R03o`07817o00HP1?l0
1Ql;o`068003o`067ol01R3o00HP00_o00HP00?o0000o`067ol01Ql07Ol01Ql<ooooo`03o`000?oo
oooooooo063ooooo002Sooooo`?o00006Oooool9o`068003o`067ol01R3o00HP01Go00HP1Ol01b0I
o`068003o`067ol01R3o00HP01Ko00HP5?l01b0?o`0680?o00LP4_l01R000ol01Qoo00HPo`06800H
o`068003o`067ol0003o00HO01go00HO0_l01R0;ooooo`03o`000?oooooooooo063ooooo002Qoooo
o`;o00006_ooool00ol01Qoo00HPo`06800No`0680So00LP4?l01R001?l01b3o00HPo`078?l01b06
o`068003o`067ol01R3o00HP00So00HP00?o00LPo`068?l01R002?l01R0Eo`0780oo00HP1?l01b00
0ol01R3o00LPo`06800Zo`068003o`000?l01Qoo00HO01go00HO0_l01R0;ooooo`03o`000?oooooo
oooo05oooooo002Nooooo`?o00006Oooool5o`067aoo00HP2Ol01b0?o`0680Co00LP1_l01R03o`06
7`Go00HP1ol01b000ol01R3o00LPo`068004o`0681Go00LP4?l01R05o`0782_o00HP00?o0000o`06
7ol01Ql07ol01Ql<ooooo`03o`000?oooooooooo05kooooo002Looooo`;o00006Oooool00ol01R3o
00HOo`067`06o`067ako00HP2_l01b0=o`0680Go00LP1_l01R000ol01Qoo00HPo`068005o`0680_o
00LP00?o00HPo`078?l01b003?l01b000ol01b7o00LPo`078006o`07817o00HP1Ol01b000ol01R3o
00LPo`068002o`0780;o00HP0_l01b0Qo`068003o`000?l01R3o00HP023o00HO2oooool00ol0003o
ooooooooo`1Nooooo`00VOooool3o`0001Wooooo1?l01R06o`067aGo00HP0_l01b09o`068003o`07
8?l01R3o00LP00Ko00LP3Ol01R05o`0780co00HP6Ol01b05o`078@Ko00LP4Ol01R0>o`0780ko00HP
00?o00HOo`068?l01R004Ol01R000ol0003o00HPo`06800Qo`067`[ooooo0_l0001Oooooo`00U_oo
ool3o`0001[ooooo1ol01R02o`067aGo00HP00?o00LPo`068?l01b001?l01b0:o`0680Oo00LP3?l0
1R001?l01b3o00HPo`068?l01b0=o`0681Oo00LP2?l01b45o`0780ko00HP4Ol01b0;o`0680?o00HO
3ol01R02o`0780?o00HP00?o0000o`068?l01R008Ol01Ql9ooooo`04o`000?ooooooooooo`0005ko
oooo002Dooooo`;o00000oooool00ol0003oooooooooo`0Dooooob3o00HP1ol01b0<o`0680Oo00LP
5_l01R001?l01b3o00HPo`068?l01R0Ho`0780Wo00LQ1_l01b0:o`0680co00LP00?o00LQo`078?l0
1b001?l01b0;o`068004o`067ol01R3o00HOo`067`Go00HP0ol01b001?l01R3o00LPo`068?l01R05
o`0780?o00HP00?o0000o`068?l01R008_l01Ql;ooooo`03o`000?oooooooooo05cooooo002Aoooo
o`?o00006Oooool3o`067aoo00HP2Ol01b0:o`0680Wo00LP4?l01R001?l01b3o00HPo`068?l01R02
o`078003o`068?l01b3o00LP01Oo00LP2_l01b45o`0780So00HP3?l01b05o`078@Ko00LP3?l01R00
0ol01Qoo00HPo`068005o`0680_o00LP0ol01R000ol0003o00HPo`06800So`067`_ooooo00?o0000
ooooooooool0Foooool008oooooo0_l0000Iooooo`Oo00HO7Ol01R0;o`0780Wo00HP2_l01b0<o`06
81Wo00LP00Co00LQo`078?l01b3o00LP0_l01b400ol01b3o00LQo`078@0;o`078@Ko00LP1Ol01R0>
o`0780Co00LQ1ol01b0Bo`0680_o00LP1Ol01R000ol0003o00HPo`067`0So`067`cooooo00?o0000
ooooooooool0F_ooool008cooooo0ol0000Hooooo`?o00HP2?l01QlLo`068003o`078?l01R3o00LP
00Wo00LP1ol01R0:o`0780[o00HP5Ol01b001?l01b7o00LPo`078?l01b0Ho`078@Ko00LP1Ol01R08
o`0780;o00LQ00Co00LPo`078Ol01b7o00LQ0_l01b000ol01b7o00LPo`078006o`07817o00HP2_l0
1b06o`068003o`000?l01R3o00HO02Co00HO2oooool00ol0003oooooooooo`1Jooooo`00R_ooool2
o`0001[ooooo1?l01R08o`067a?o00HP00?o00LPo`068?l01R002Ol01R0:o`0780;o00HP0_l01b02
o`0680So00LP2Ol01R0Go`0780;o00LQ00?o00LPo`078Ol01b406?l01b48o`078003o`068?l01b3o
00LP00Oo00LP1_l01b4=o`0780ko00HP3?l01b06o`068003o`000?l01R3o00HO02?o00HO0_l01R0;
ooooo`03o`000?oooooooooo05Wooooo0027ooooo`?o00006Oooool6o`0680So00HO4_l01R05o`07
80[o00HP5Ol01b08o`0681Oo00LP8Ol01b400ol01b3o00LQo`07800=o`0780Wo00LQ00Ko00LPo`07
8Ol01b7o00LQo`078?l01b46o`0780[o00HP4?l01b05o`068003o`000?l01Qoo00HO00ko00HO0ol0
1R0Co`067`03o`068?oooooooooo00[ooooo00?o0000ooooooooool0F?ooool008Gooooo0_l0000I
ooooo`Wo00HP00?o00HOo`068?l01Ql00_l01QlBo`0680Wo00LP2_l01R0Co`0780So00HP5_l01b0V
o`078@go00LP3_l01b47o`0780Wo00HP4_l01b04o`068007o`000?l01R3o00HOo`067ol01R3o00HO
o`068008o`067`Go00HP5?l01Ql00ol01R3oooooooooo`09ooooo`03o`000?oooooooooo05Sooooo
0022ooooo`?o00006Oooool3o`0680;o00HO7Ol01R09o`0780Wo00HP5?l01b000ol01R3o00LPo`07
8005o`0681Ko00LP9_l01b4<o`0780oo00LQ2?l01b08o`0681;o00LP1?l01R000ol0003o00HPo`06
8007o`0680Co00HO1Ol01R0Eo`067`;o00HP2oooool00ol0003oooooooooo`1Gooooo`00P?ooool2
o`000003ooooool0003ooooo01Kooooo0ol01Ql00ol01R3o00HOo`067`04o`067aco00HP2?l01b09
o`0681Wo00LP00?o00HPo`078?l01b002Ol01b000ol01b7o00LPo`078@09o`0782Go00LQ3_l01b0@
o`078@Oo00LP1ol01R0Do`0780?o00HP00?o0000o`068?l01R001ol01R04o`067`03o`068?l01Qoo
00HP00;o00HP5Ol01Ql2o`0680cooooo00?o0000ooooooooool0E_ooool007gooooo0ol00004oooo
o`03o`000?oooooooooo017ooooo3?l01QlNo`0680So00LP2?l01R0:o`078003o`068?l01b3o00HP
01So00LP1?l01b401?l01b3o00LQo`078?l01b43o`0782Ko00LQ1ol01b001?l01b7o00LPo`078?l0
1b0Bo`078@Oo00LP2?l01R08o`0780;o00LQ2ol01b03o`068003o`000?l01R3o00HP00Oo00HP5_l0
1Ql3o`068003o`067ol01R3o00HO00Co00HP2oooool00ol0003oooooooooo`1Fooooo`00N_ooool3
o`0001Sooooo3ol01QlOo`0680So00LP1_l01R08o`0780Oo00HP1_l01b000ol01b7o00LPo`078005
o`0780;o00HP1Ol01b0ao`078@Ko00LP6Ol01b48o`078003o`068?l01b3o00HP00;o00HP1ol01b07
o`078@Wo00LP0ol01R000ol0003o00HPo`068008o`0681;o00HO3_l01R0;ooooo`03o`000?oooooo
oooo05Gooooo001hooooo`;o00006?oooolBo`067b3o00HP2_l01b000ol01R3o00LPo`078008o`07
80Oo00HP1Ol01b03o`078@Go00LP1?l01R04o`07837o00LQ00?o00LPo`078Ol01b006ol01b4Do`07
80Oo00LQ2_l01b03o`068003o`000?l01R3o00HP00So00HP4ol01Ql=o`0680cooooo00?o0000oooo
ooooool0E?ooool003kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o
00008oooool3o`0001Wooooo5?l01QlPo`0681?o00LP1_l01R07o`0780?o00LQ1_l01b000ol01R3o
00LPo`078002o`0785;o00LQ4_l01b09o`078@So00LP1?l01R000ol0003o00HPo`068009o`06813o
00HO4?l01R0;ooooo`03o`000?oooooooooo05Cooooo000mooooo`04o`000?ooooooooooo`0000So
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo01kooooo0_l0000I
ooooo`?o00HP5Ol01Ql00ol01R3o00HOo`06800Mo`0681Co00LP00Co00HPo`078?l01b3o00HP5Ol0
1b0Ko`078@03o`088Ol01b7o00LQ03Go00LQ4?l01b0:o`078@So00LP1?l01R000ol0003o00HPo`06
800:o`068003o`067ol01R3o00HO00Go00HO0ol01R000ol01Qoo00HPo`06800<o`0680;o00HO00Co
00HPo`067ol01Qoo00HO2oooool00ol0003oooooooooo`1Cooooo`00=_ooool5o`0000;ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01_o
oooo0ol0000Iooooo`;o00HO00?o00HPo`067ol01Ql06?l01QlNo`0680Ko00LP0_l01R0Ho`0780;o
00LQ00Co00LPo`078Ol01b7o00LP0ol01b400ol01b3o00LQo`078@0Jo`078@03o`088Ol01b7o00LQ
03Oo00LQ00?o00LPo`078Ol01b001Ol01b03o`078@03o`078?l01b7o00LQ00_o00LQ2Ol01b001?l0
1R3o00LPo`068?l0000?o`0680?o00HO5?l01R06o`067`[ooooo0ol0001Dooooo`00?Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool06Ooo
ool2o`0001Wooooo8Ol01QlMo`0680Co00LP1_l01R0>o`0780;o00HP1_l01b1Ro`078@Ko00LP4Ol0
1b4<o`078003o`000?l01R3o00LP00co00HP1Ol01QlCo`0680Oo00HO2oooool00ol0003ooooooooo
o`1Booooo`00?Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool0
1?l0000Iooooo`?o00006?oooolUo`067aco00HP00?o00LPo`068?l01R001_l01R07o`078003o`07
8Ol01b3o00LP00Go00LP00?o00HPo`078?l01b000_l01b0Uo`078@03o`088Ol01b7o00LQ03ko00LQ
1Ol01b0Ao`078@co00LP00?o0000o`078?l01b000_l01b0:o`0680Ko00HO4_l01R08o`067`_ooooo
00?o0000ooooooooool0DOooool003gooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0001[ooooo0_l00003ooooo`03o`000?oooooooooo01;ooooo9ol01QlVo`06
80Go00LP1?l01b4<o`07827o00LQ1?l02251o`078@Co00LP4_l01b400ol01b3o00LQo`078008o`07
8003o`000?l01b3o00LP00?o00LP2_l01R05o`067a?o00HP1ol01Ql<ooooo`03o`000?oooooooooo
053ooooo000nooooo`;o00002_ooool2o`0000;ooooo1Ol0000Cooooo`?o00006?oooolZo`067`Ko
00HP0ol01Ql6o`068004o`078?l01R3o00LPo`0781;o00HP1_l01b02o`078@_o00LP8?l01b46o`08
8@05o`078Ol0227o00PQo`078Ol02240:Ol01b43o`088A;o00LQ0ol01b0Eo`078@So00LP00?o0000
o`078?l01b001?l01b08o`0680Oo00HO4ol01R001?l01Qoo00HPo`067ol01Ql3o`0680_ooooo00?o
0000ooooooooool0D?ooool006Cooooo0_l0000Hooooobko00HO0_l01R07o`067`Co00HP1Ol01b0<
o`0680?o00LP00?o00HPo`078?l01b002Ol01b001Ol01b7o00LPo`078?l01b3o00LQ00;o00LP6Ol0
1b400ol0227o00LQo`078@02o`088@Go00LQ00?o00PQo`078Ol022401Ol022401Ol022;o00PQo`08
8_l022;o00PQ02Co00LQ1ol0224Co`078@03o`078?l01b7o00LQ01Go00LQ1_l01b000ol0003o00LP
o`078003o`0780Go00HP0_l01Ql00ol01R3o00HOo`067`06o`067a_o00HP2oooool00ol0003ooooo
ooooo`1?ooooo`00HOooool3o`0001Oooooo>ol01Ql3o`0680Go00LP2_l01R0Ao`0781go00LQ1?l0
22401?l022;o00PQo`088Ol02248o`078@;o00PQ1ol02282o`088AGo00LQ0ol022400ol01b7o00PQ
o`078@02o`078@03o`088Ol01b7o00LQ00?o00LQ2?l0224[o`078@Go00LP00?o0000o`078?l01b00
0_l01b05o`0680Go00HO0ol01R000ol01Qoo00HPo`06800Lo`0680_ooooo00?o0000ooooooooool0
Coooool005kooooo0ol0000HooooobKo00HO0ol01R000ol01Qoo00HPo`067`0@o`067`Go00HP00Co
00LPo`068?l01R3o00LP2?l01R0:o`0780;o00HP1Ol01b0Lo`078@Go00PQ1Ol022800ol0227o00LQ
o`078@05o`078@;o00PQ2Ol02282o`088@oo00LQ0_l022401Ol01b7o00PQo`088Ol0227o00PR00?o
00PQ0ol022800ol0227o00PRo`088@04o`078@04o`088Ol01b7o00LQo`078@?o00PQ;?l01b44o`07
8003o`000?l01b3o00LP00;o00LP1?l01R04o`067bGo00HP2oooool00ol0003oooooooooo`1>oooo
o`00G?ooool2o`0001Sooooo:Ol01Ql6o`0680Wo00HO0_l01R000ol01Qoo00HPo`067`02o`067`ko
00HP3Ol01b03o`0680Co00LP7Ol01b400ol0227o00PRo`088P05o`088P;o00PQ00?o00LQo`088Ol0
1b400ol01b42o`088@_o00PR00?o00PQo`078Ol01b402_l01b43o`088P03o`088Ol022;o00PQ00go
00PR00?o00PQo`078Ol01b40=?l01b44o`078003o`000?l01b3o00LP00?o00LP1_l01R000ol01Qoo
00HPo`06800To`0680_ooooo00?o0000ooooooooool0COooool005Wooooo0ol0000Gooooobgo00HO
1Ol01R06o`067`_o00HP00?o00HOo`068?l01R002?l01R0@o`078004o`068?l01b3o00LPo`0781go
00LQ0ol0224:o`088P04o`088Ol022;o00PQo`078@;o00PQ3Ol022800ol0227o00LQo`078@07o`07
8@03o`088Ol022;o00PR01;o00PR0_l0224:o`078@03o`088Ol01b7o00LQ02[o00LQ0_l01b000ol0
003o00LPo`078003o`0780_o00HP00Go00LPo`068?l01R3o00HPo`07800Mo`068003o`067ooooooo
oooo00Sooooo00?o0000ooooooooool02Oooool2o`0004;ooooo001Gooooo`;o00006?ooool_o`06
7`Co00HP1ol01Ql;o`0680;o00HO1ol01R0Fo`0781go00LQ0_l0224?o`088P03o`088Ol022;o00PR
00go00PR00?o00PQo`078Ol01b401?l01b42o`088AKo00PR00Ko00PQo`078Ol0227o00PQo`078Ol0
2242o`078@Co00PQ00Go00PRo`088Ol0227o00LQo`088@0Yo`078@03o`000?l01b3o00LP00Co00LP
00?o00HPo`078?l01R001ol01R04o`0781_o00HP1?l01Ql;ooooo`03o`000?oooooooooo00Oooooo
00Co0000oooooooooooo0000@Oooool005Cooooo0ol00002ooooo`03o`000?oooooooooo01;ooooo
=?l01Ql00ol01R3o00HOo`067`04o`067`co00HP0_l01Ql8o`0680_o00LP00?o00LQo`078?l01b40
0_l01b401?l01b3o00LQo`078Ol01b0Fo`078@05o`088_l0227o00PQo`078Ol022401_l01b400ol0
227o00PRo`088P0Lo`088P;o00PQ00Co00LQo`088Ol01b7o00LQ6ol022800ol0227o00PRo`088@02
o`088P;o00PQ1_l02283o`088BSo00LQ00?o0000o`078?l01b001ol01b07o`0680Co00LP6_l01R06
o`067`_ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00011ooooo`00D_ooool2
o`0000Kooooo00?o0000ooooooooool03_oooolko`067aKo00HP3Ol01b0Mo`078@Oo00PR00Co00PQ
o`088_l0227o00PQ0_l01b42o`088B7o00PR00?o00PQo`088_l02280:Ol02284o`088BOo00LQ00?o
0000o`078?l01b001ol01b000ol01R3o00LPo`068004o`068003o`078?l01R3o00HP01_o00HP1_l0
1Ql:ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000@Oooool004oooooo0ol0
000Foooooc_o00HO5ol01R0?o`0781co00LQ00?o00PQo`088_l022802?l02284o`088Doo00PR00Co
00PQo`088_l0227o00PQ9Ol01b400ol01b3o0000o`07800;o`0782?o00HP1?l01Ql00ol01R3ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000@Oooool004gooooo
0_l0000Gooooocgo00HO4?l01R000ol01b3o00HPo`068002o`0780;o00HP3_l01b0Lo`078@;o00PQ
2_l022800ol0227o00PRo`088P1Co`088P;o00PQ9Ol01b400ol0003o00LPo`078003o`078003o`06
8?l01b3o00LP00Co00LP5ol01R000ol01b3o00HPo`068009o`068003o`067ol01R3o00HP00?o00HP
2oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00047ooooo001:ooooo`?o0000
5_oooom0o`067`go00HP6?l01b0Lo`078@03o`088Ol022;o00PR03go00PR00?o00PSo`088_l02280
8?l022800ol0227o00PRo`078@0Fo`078@03o`088Ol01b7o00LQ00[o00LQ00?o0000o`078?l01b00
2ol01b0Co`0680Go00LP4Ol01R09ooooo`;o00001oooool2o`0004;ooooo0018ooooo`;o00005ooo
oom2o`067`go00HP6?l01b0Co`078@05o`088Ol01b7o00LQo`078Ol022401?l01b400ol0227o00PR
o`088P0mo`088P05o`088ol02B?o00TSo`088_l02B<08?l02282o`088ACo00LQ00?o00PQo`078Ol0
1b402_l01b400ol01b3o0000o`07800=o`0780oo00HP2Ol01b0@o`0680Oooooo0_l00002ooooo`03
o`000?oooooooooo04Sooooo0015ooooo`?o00005ooooom3o`067`go00HP4Ol01b02o`078@04o`07
8?l01b7o00LPo`0781;o00LQ1?l022400ol022;o00PQo`088@02o`088@?o00LQ0_l0224ho`088P04
o`088ol022;o00PRo`088PSo00TS8_l0228Po`078@03o`078?l0003o00LP00go00LP3?l01R0<o`07
817o00HP2oooool00ol0003oooooooooo`17ooooo`00@_ooool3o`0001Sooooo>_l01Ql3o`068004
o`067ol01R3o00HOo`0680?o00HO3_l01R0?o`0781Wo00LQ0_l02246o`088P?o00PQ0_l01b43o`08
8CCo00PR00Co00TSo`088ol022?o00PS2ol02B<00ol022?o00PRo`088P0No`088P03o`088Ol01b7o
00LQ01oo00LQ00Go0000o`078?l01b7o00LPo`078@0;o`0780So00HP3ol01b0Bo`0680[ooooo00?o
0000ooooooooool0Aoooool0043ooooo0_l00003ooooo`03o`000?oooooooooo01;ooooo<ol01Ql3
o`0680Ko00HO6Ol01R0<o`0781_o00LQ0_l02248o`088P03o`088Ol022;o00PQ00;o00PQ<ol0228A
o`098`03o`088ol022;o00PR023o00PR00?o00PQo`078Ol01b407Ol01b42o`0000Ko00LQ2_l01b05
o`06813o00LP4Ol01R02o`067`_ooooo00?o0000ooooooooool0A_ooool003gooooo0ol0000Goooo
ocKo00HO1?l01R04o`067a[o00HP3?l01b0Jo`078@;o00PQ=Ol022801Ol022?o00PRo`088_l022;o
00PS00Go00PR0_l022<Bo`098`03o`088ol022;o00PR00oo00PR00?o00TSo`088_l02B<03Ol0228<
o`078@?o00PQ00?o00LQo`088Ol01b402ol01b43o`000003o`078Ol0003o00LQ00Ko00LQ2Ol01b06
o`0680[o00LP0_l01R000ol01b3o00HPo`06800?o`0680Go00HO2oooool00ol0003oooooooooo`15
ooooo`00>oooool2o`0001Sooooo>Ol01Ql01Ol01R3o00HOo`068?l01R3o00HO01Co00HP0ol01b00
1?l01R3o00LPo`068?l01R0;o`0781go00LQ00?o00PQo`088_l022408?l02282o`088`03o`088_l0
22?o00PR00co00PR0_l02B<01?l022?o00TSo`098ol022<3o`098`03o`088_l02B?o00PS01Co00TS
00?o00PSo`098ol022803?l022800ol022?o00TSo`098`03o`098`03o`088_l022?o00PR00[o00PR
00?o00PQo`078Ol01b401_l01b44o`088@?o00PR00Co00PQo`088_l0227o00LQ0ol02243o`078@?o
00001Ol01b400ol0003o00LQo`078@05o`078@Wo00LP1_l01R06o`0781Oo00HP1Ol01Ql;ooooo`03
o`000?oooooooooo04Gooooo000hooooo`?o00005ooooolno`067`_o00HP00?o00LPo`068?l01R00
1_l01R0Bo`0781So00LQ00?o00PQo`078Ol01b401ol01b400ol0227o00PRo`088P0Lo`088P;o00PS
0ol02B<01?l022?o00TSo`088_l022<:o`088R?o00TS00?o00PSo`088_l02B<02Ol022800ol022?o
00TSo`098`05o`098`_o00PR0_l022401?l01b7o00PQo`078Ol01b44o`088@So00PR1Ol02243o`00
00Wo00LQ00?o0000o`078Ol01b400ol01b49o`0780Oo00HP1Ol01b0Io`0680Go00HO2oooool00ol0
003oooooooooo`14ooooo`00=oooool2o`0001Kooooo@Ol01Ql9o`0680Co00LP00?o00HPo`078?l0
1R000_l01R0Do`0781So00LQ1?l02245o`078@;o00PQ7_l022800ol022?o00TSo`098`05o`098`03
o`088ol022;o00PR00Go00PR00?o00PSo`098ol02B<06Ol02B<00ol02BCo00TSo`098`0<o`098`05
o`088_l022?o00PSo`088ol022802_l02B<;o`088P03o`088Ol022;o00PQ00;o00PR0_l0224<o`08
8P05o`088Ol0003o0000o`000?l022403?l01b400ol0003o00LQo`078@02o`078@Go00LP0ol01R02
o`0780Oo00HP1?l01b0;o`0680;o00LP3Ol01R05o`067`_ooooo00?o0000ooooooooool0@oooool0
03Oooooo0ol0000Coooood7o00HO3?l01R0Jo`0781So00LQ1Ol02246o`078@03o`088Ol022;o00PR
01co00PR00?o00PSo`098ol02B<01ol02B<00ol022;o00PSo`088P04o`088P03o`088ol02B?o00TS
00Go00TS00?o00TTo`098ol02B<03ol02B<4o`0990ko00TS00?o00PSo`098ol02B<03?l02B<Ko`08
8P?o00000_l022400ol01b7o00PQo`078@0;o`078@03o`000?l01b7o00LQ00;o00LQ0ol01b05o`06
80Co00LP1Ol01R04o`0780_o00HP1?l01b0=o`068003o`067ol01R3o00HP00_ooooo00?o0000oooo
ooooool0@oooool003Kooooo0_l00002ooooo`03o`000?oooooooooo00goooooA?l01Ql=o`0681So
00LP6?l01b47o`088@;o00LQ00Co00PQo`078Ol01b7o00PQ7_l02282o`088`Wo00TS00Co00PSo`09
8ol02B?o00PR2Ol02B<5o`0990_o00TS1?l02B@00ol02RCo00TTo`0:9002o`0991co00TS5ol02283
o`0000?o00PR00?o00PQo`078Ol01b403_l01b401?l0003o00LQo`078Ol01b44o`0780;o00HP1ol0
1b000ol01R3o00LPo`078006o`0780So00HP1_l01b000ol01R3o00LPo`06800>o`0680_ooooo00?o
0000ooooooooool0@_ooool003Oooooo00Go0000ooooooooooooooooo`00000<ooooodKo00HO3_l0
1R0Eo`0781?o00LQ0_l02247o`078@Co00PQ0_l02282o`088@03o`088_l0227o00PQ01?o00PR0_l0
22<00ol022;o00PSo`088P02o`088`Go00PR0_l022<Do`098`Co00TT00?o00XTo`099?l02B<00_l0
2B@4o`098`Go00TT1ol02R@2o`0991co00TS00?o00PSo`088_l022804?l02283o`0000Ko00PR00?o
00PQo`078Ol01b403ol01b401?l0003o00LQo`078Ol01b4Fo`078004o`068?l01b3o00LPo`0680_o
00LP4?l01R0;ooooo`03o`000?oooooooooo047ooooo000]ooooo`;o00001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Kooooo=?l01Ql2o`0680go00HO0_l01R05o`067`go00HP
4?l01b03o`078@03o`078?l01b7o00LQ01[o00LQ0ol0224Jo`088P;o00PS0ol02B<01?l022?o00TS
o`088ol022<5o`088P03o`088ol02B?o00TS01?o00TS00?o00TTo`0:9?l02R@01?l02R@01_l02BCo
00XTo`099?l02BCo00TSo`0:90;o00TT2ol02R@00ol02BCo00TSo`098`0Mo`098`go00PR0ol00008
o`088P03o`088Ol01b7o00LQ00Co00LQ0ol02249o`078@03o`000?l01b7o00LQ00;o00LQ9?l01b0A
o`0680[ooooo00?o0000ooooooooool0@Oooool002cooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo>?l01Ql00ol01R3o00HOo`067`09
o`067`Go00HP1Ol01Ql00ol01R3o00HOo`068008o`0680oo00LP8_l01b400ol0227o00PRo`088P0J
o`088P03o`088ol02B?o00TS00Go00TS0_l022<4o`088P03o`088ol02B?o00TS00Ko00TS0_l02B@9
o`098`?o00TT6_l02R@00ol02BCo00TSo`098`0<o`098`05o`099?l02B?o00TSo`098ol02B@02ol0
2B<:o`088P?o00002ol022802Ol0227o00PRo`088Ol0227o00LQo`088Ol01b7o00PQo`088P02o`08
8@Wo00LQ00?o0000o`078Ol01b400ol01b400ol01b3o00LQo`078005o`078003o`078Ol01b3o00LP
01Oo00LP4Ol01R0;ooooo`03o`000?oooooooooo043ooooo000/ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool01Oooool01?l0003ooooooooooooooom2o`067`Ko00HP1ol01Ql:
o`068003o`078?l01R3o00LP00[o00LP9?l01b400ol0227o00PRo`088P0Io`088P03o`088ol02B?o
00TS00Oo00TS00Co00PSo`098ol022?o00PR2Ol02B<3o`0990?o00TS00?o00TTo`098ol02B<01?l0
2B@Lo`0:90;o00TT2_l02B<4o`0990;o00XT0ol02B@:o`098`03o`088ol022;o00PR00Go00PR0_l0
000Bo`088P04o`088Ol022;o00PQo`088@?o00PR00?o00LQo`088Ol022401ol01b400ol0003o00LQ
o`078@05o`078@?o00LP0ol01b45o`078003o`068?l01b3o00LP00ko00LP00?o00HPo`078?l01R00
3Ol01R03o`067`03o`068?l01Qoooooo00[ooooo00?o0000ooooooooool0?oooool002cooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`06ooooo`04o`000?oooooooooooooood7o
00HO1_l01R07o`067`oo00HP2Ol01b0To`078Aco00PR00?o00PSo`098ol02B<04Ol02B<9o`099003
o`0:9?l02BCo00TT00Oo00XT00Co00XUo`0:9?l02RCo00XT0_l02bD01?l02RCo00/Uo`0;9Ol02RD?
o`0:90;o00TT00Co00TSo`099?l02B?o00TT0_l02B<4o`0990Ko00XT0_l02B@:o`098`;o00PS0ol0
2283o`0001co00PR0_l02248o`078@03o`000?l01b7o00LQ00Co00LQ2_l01b05o`0680[o00LP4ol0
1R06o`067`Sooooo0ol00011ooooo`00;?ooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_ooooloo`067`03o`068?l01Qoo00HP00?o00HP1ol0
1Ql@o`0680Wo00LP8_l01b400ol0227o00PRo`088P0Jo`088P03o`088ol022;o00TS013o00TS1ol0
2B@:o`0:90?o00/U00?o00XUo`0;9Ol02bD01_l02bD2o`0:9@03o`0:9?l02RGo00XT00go00XT00?o
00TTo`0:9?l02B@00_l02R@2o`0990[o00XT0_l02B@9o`098`03o`088ol02B?o000000;o00008?l0
2282o`088@Oo00LQ00?o0000o`078Ol01b401Ol01b49o`0780Ko00HP1_l01b0Go`0680Go00HO2ooo
ool00ol0003oooooooooo`0nooooo`00;?ooool01?l0003oooooooooool00006ooooo`;o00002Ooo
ool00ol0003oooooooooo`02oooood7o00HO1?l01R06o`067`Wo00HP00?o00HOo`068?l01R001Ol0
1R09o`078003o`078Ol01b3o00LQ01oo00LQ0_l0224Ko`088Q7o00TS1Ol02B@<o`0:913o00/U00Oo
00XUo`0;9Ol02bGo00XTo`0;9Ol02RCo00XU00?o00XT00?o00XUo`0:9?l02R@05?l02R@2o`0990Oo
00TS0ol00003o`098b3o00PR00?o00PQo`078Ol01b401ol01b400ol0003o00LQo`078@03o`078@[o
00LP1Ol01R07o`0781Oo00HP1_l01Ql;ooooo`03o`000?oooooooooo03gooooo000]ooooo`;o0000
1_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo@Ol01Ql4o`0680Co00HO
2_l01R03o`067`Ko00HP2ol01b0Po`078@;o00PQ6_l02288o`098`;o00TT1_l02B<3o`0990co00XT
6Ol02bD01Ol02RGo00/Uo`0;9Ol02bGo00XU00;o00/U00?o00XTo`0;9Ol02R@04_l02R@00ol02BCo
00TSo`098`02o`098`?o00001_l02B<00ol022;o00TSo`088P02o`088a_o00PR0_l02249o`078@03
o`000?l01b7o00LQ00?o00LQ2_l01b04o`0680Ko00LP2ol01R02o`0780co00HP0ol01Ql2o`0680_o
oooo00?o0000ooooooooool0?Oooool003Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02oooood7o00HO1?l01R000ol01Qoo00HPo`06800;o`0680;o00HO2?l01R001Ol01b3o00HP
o`068?l01b3o00HP00Go00LP8?l01b42o`088AWo00PR1ol02B<5o`099004o`098ol02BCo00TTo`09
90_o00XT2Ol02bD00ol02bKo00/Uo`0;9@0Mo`0;9@04o`0:9?l02bGo00XTo`0:9@go00XT00Co00TT
o`000?l0003o00003?l02B<2o`088aWo00PR0ol0224;o`078@04o`000?l01b7o00LQo`078@Go00LP
00?o00HPo`078?l01b001?l01b001?l01R3o00LPo`068?l01R05o`0780[o00HP1Ol01b0@o`0680_o
oooo00?o0000ooooooooool0??ooool003Gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`02oooood7o00HO4_l01R000ol01Qoo00HPo`06800<o`0680Go00LP7ol01b43o`088ACo00PR
00?o00PSo`088_l022801_l02B<9o`0990So00XT00?o00/Uo`0:9?l02bD02?l02bD00ol02bKo00`V
o`0;9P02o`0<9Poo00/U00?o00/Vo`0;9Ol02bD03_l02bD00ol02RGo00/Uo`0;9@0:o`0:90?o0000
00Go00XTo`098ol02BCo00TSo`09900;o`098`03o`088ol022;o00PR01Ko00PR00?o00PQo`078Ol0
1b403?l01b401?l0003o00LQo`078Ol01b4Fo`0780So00HP1_l01b0Ao`0680[ooooo00?o0000oooo
ooooool0??ooool003Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooood7o
00HO2?l01R000ol01Qoo00HPo`06800Fo`0680?o00LP8Ol01b400ol0227o00PRo`088P0<o`088P;o
00PS00?o00TSo`088_l02B<00_l02B<00ol022?o00TSo`098`06o`098`Ko00TT2?l02R@>o`0;9@03
o`0;9_l032Ko00`V00Co00`V00Co00/Uo`0<9_l02bGo00`V1_l02bD4o`0;9P;o00`V00?o00/Uo`0<
9_l02bD03_l02bD2o`0:9@03o`0:9?l02bGo00XT00;o00XT0ol00005o`0:9007o`099?l02RCo00TT
o`0:9?l02BCo00TSo`099008o`098aSo00PR0_l02242o`078@03o`088Ol01b7o00LQ00Wo00LQ00Ko
0000o`078Ol01b7o00LQo`078?l01b4Do`078004o`068?l01b3o00LPo`0680[o00LP4?l01R0;oooo
o`03o`000?oooooooooo03_ooooo000eooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooooloo`067`Ko00HP1Ol01QlFo`0680Go00LP0_l01b401Ol01b3o00LQo`078Ol01b7o00LP
01Wo00LQ00?o00PQo`088_l022803?l022800ol022?o00TSo`098`0=o`098`?o00TT2Ol02R@?o`0;
9@03o`0;9_l032Ko00`V00[o00`V00?o00/Vo`0;9Ol032H00ol02bH8o`0<9P03o`0;9Ol032Ko00/U
00oo00/U0ol000000ol02RGo00XTo`0;9@02o`0:9@Wo00XT0_l02B@7o`098`03o`088ol022;o00PR
01Go00PR2?l022400ol01b7o00PQo`078@06o`078@03o`000?l01b7o00LQ00;o00LQ2Ol01b000ol0
1b7o00LPo`07800Fo`07817o00HP2oooool00ol0003oooooooooo`0jooooo`00=Oooool00ol0003o
ooooooooo`0?ooooo`;o00000oooooloo`067`Go00HP0ol01QlHo`0680co00LP5?l01b42o`088@03
o`078Ol022;o00PR00ko00PR00?o00PSo`098ol02B<03Ol02B<00ol02BCo00XTo`0:9007o`0:90Oo
00/U00?o00`Vo`0;9Ol02bD00_l02bH6o`0;9@Oo00`V00?o00dWo`0<9_l032H05Ol032H00ol02bGo
00/Vo`0;9P08o`0;9@?o00000ol02bD00ol02RGo00/Uo`0;9@02o`0;9@03o`0:9?l02bGo00/U00Oo
00XT0_l02B@6o`098`03o`088ol022;o00PR01Ko00PR00Go00PQo`088_l022;o00PRo`088@02o`08
8P;o00PQ1ol01b400ol0003o00LQo`078@03o`078@03o`078?l01b7o00LP00?o00LP0_l01b46o`07
8003o`068?l01b3o00LP00oo00LP4_l01R000ol01Qooooooooooo`08ooooo`03o`000?oooooooooo
03[ooooo000dooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo@?l01Ql;o`06
80;o00LP3?l01R02o`078003o`068?l01b3o00LP00_o00LP4_l01b42o`088P03o`088Ol022;o00PR
013o00PR00?o00PSo`098ol02B<03Ol02B<00ol02BCo00XTo`0:9007o`0:90Go00/U1_l032H01Ol0
2bKo00`Vo`0;9_l02bKo00/U00;o00/V1Ol032H6o`0=9`03o`0<9_l032Oo00`V01?o00`V00Oo00/V
o`0<9_l02bKo00/Vo`0;9Ol032Ko00/V00?o00000_l02bH<o`0;9@Ko00XT0_l02B@7o`098b7o00PR
00?o00PQo`088_l01b401_l01b400ol0003o00LQo`078@05o`078@Wo00LP1Ol01R0:o`0781Co00HP
1Ol01Ql:ooooo`03o`000?oooooooooo03Wooooo000dooooo`;o00005?ooool01?l0003ooooooooo
oooooom0o`067`[o00HP0ol01b08o`06813o00LP4_l01b400ol0227o00PRo`088P0Eo`088PKo00TS
0_l02B@00ol02B?o00TTo`098`02o`098`?o00TT1ol02R@8o`0;9@_o00`V00Co00/Vo`0<9_l032Ko
00`V2_l03BL01?l032Oo00dWo`0<9_l032L:o`0<9P04o`0=9ol032Oo00`Vo`0=9`So00`V0_l00003
o`0<9P;o00/V3Ol02bD00ol02RCo00XUo`0:9003o`0:90;o00TT1ol02B<00ol022;o00TSo`088P05
o`088P05o`098ol022?o00PSo`088_l022<05Ol022800ol0227o00LQo`078@05o`078@03o`000?l0
1b7o00LQ00Co00LQ2_l01b05o`0680Ko00LP5Ol01R07o`067`_ooooo00?o0000ooooooooool0>?oo
ool003Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooocko00HO2_l01R04
o`0780Go00HP4?l01b0Do`078@03o`088Ol022;o00PR01?o00PR00?o00PSo`098ol02B<01Ol02B<4
o`099004o`0:9?l02BCo00TTo`0990Oo00XT2?l02bD00ol02bKo00`Vo`0<9P0;o`0<9P?o00`W3Ol0
3BL01Ol032Oo00dWo`0<9_l032Ko00`W00?o00`V2Ol03BL00ol032Ko00dWo`0=9`03o`0000Ko00`V
0_l02bH=o`0;9@03o`0:9Ol02bGo00XT00;o00XT0ol02B@9o`098`03o`088ol022;o00TS00Ko00TS
00?o00PSo`088_l022804ol022800ol0227o00LQo`078@06o`078@03o`000?l01b7o00LQ00Co00LQ
2?l01b07o`0680;o00LP6Ol01R07o`067`[ooooo00?o0000ooooooooool0>?ooool003Cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`02ooooocgo00HO2ol01R04o`078003o`068?l0
1b3o00LP017o00LP4_l01b43o`088A;o00PR0_l02B<2o`088`Ko00TS0_l02B@;o`0:90_o00/U00?o
00/Vo`0<9_l032H00ol032H00ol032Oo00`Vo`0=9`02o`0=9`04o`0<9_l03BOo00dWo`0<9`Wo00dW
00?o00dXo`0=9ol03BP01ol03BL00ol032Oo00dWo`0=9`07o`0=9`03o`0=:?l03BOo00hX00?o0000
00?o00`Wo`0=9ol032H01ol032H2o`0;9Poo00/U0ol02R@2o`0991?o00TS00?o00PSo`088_l02280
4Ol02282o`088@So00LQ00?o0000o`078Ol01b400ol01b46o`078003o`068?l01b3o00LP02;o00HP
1ol01Ql;ooooo`03o`000?oooooooooo03Oooooo000dooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool00_oooolko`067`go00HP2_l01b03o`078@03o`078?l01b7o00LP00Go00LP4_l0
1b43o`088A;o00PR3Ol02B<00ol02BCo00XTo`0:9006o`0:90go00/U0_l02bH4o`0<9Pko00dW00?o
00hXo`0=:?l03BP00_l03BP2o`0>:003o`0=:?l03RSo00dW00So00dW00Co00dXo`0=9ol03BOo00dW
0_l03RP01_l03BSo0000o`000?l0003o00hXo`0=:0Co00dW1ol032H2o`0;9P03o`0;9Ol032Ko00`V
00co00/U1?l02R@2o`099003o`098ol02BCo00TS00ko00TS00?o00PSo`088_l022804Ol02282o`08
8@[o00LQ00?o0000o`078Ol01b400_l01b43o`0780Go00HP1?l01b0Po`0680Co00HO0ol01R0;oooo
o`03o`000?oooooooooo03Kooooo000dooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00_ooooljo`067`go00HP2_l01b07o`078@03o`078?l01b7o00LQ01;o00LQ0ol0224@o`088P?o
00PS3?l02B<2o`0990Go00XT0_l02RD7o`0;9@03o`0;9_l02bGo00/U00?o00/U0_l02bH4o`0<9POo
00dW00?o00dXo`0=9ol03BL00_l03BP00ol03BOo00hXo`0>:002o`0>:003o`0=:?l03RSo00hX00Ko
00hX00Co00dWo`0>:?l03RSo00dW0ol03RP01?l03BSo00hXo`0>:?l03RP3o`0000Ko00hX1?l03BL7
o`0<9P03o`0;9_l032Ko00`V00?o00`V00?o00/Uo`0<9_l02bD02?l02bD4o`0:9004o`099?l02RCo
00TTo`0990;o00TS00?o00TTo`098ol02B<02Ol02B<00ol022?o00PRo`088P0@o`088P?o00PQ2ol0
1b400ol0003o00LQo`078@05o`0780;o00HP1_l01b0Qo`068003o`067ol01R3o00HO00Co00HP2?oo
ool3o`0003Sooooo000cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooooli
o`067`co00HP1_l01b03o`078@;o00LP6ol01b43o`088A7o00PR00?o00PSo`098ol02B<03?l02B<0
0ol02BCo00XTo`0:9004o`0:9003o`0:9Ol02bGo00/U00?o00/U00Ko00/Vo`0<9_l032Ko00/Vo`0<
9_l02bH2o`0<9P03o`0;9_l032Ko00`V00?o00`V1Ol03BL3o`0>:004o`0=:?l03RSo00hXo`0=:1Co
00hX00?o00lYo`0>:?l03RP00ol000001_l03RSo00lYo`0?:Ol03bWo00hXo`0?:@?o00hX1Ol03BL@
o`0<9P03o`0;9Ol032Ko00/V00Go00/U1Ol02R@6o`0990So00TS00?o00PSo`088_l022804?l02283
o`088@ko00LQ00?o0000o`078Ol01b403Ol01b0Wo`0680_ooooo00?o0000ooooooooool0=Oooool0
03?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooocCo00HO00?o00HPo`06
7ol01R003Ol01R05o`0780Go00LQ0_l01b0Jo`078@03o`088Ol022;o00PR00co00PR00?o00PSo`08
8_l022804Ol02B<00ol02BCo00XTo`0:9003o`0:90So00/U2ol032H01?l032Oo00dWo`0=9ol03BL2
o`0=:0go00hX00Co00lYo`0>:?l03RSo00lY0_l03RT01?l03RSo00lYo`0?:Ol03RP3o`0?:@03o`0>
:?l03bWo000000;o00002_l03bT3o`0>:005o`0=9ol03BSo00dWo`0=9ol032H00_l03BL2o`0<9P03
o`0<9ol032Ko00`V00;o00`W2Ol032H2o`0;9P?o00/U1_l02R@6o`0990Go00TS00?o00PSo`088_l0
22804ol02282o`088@?o00LQ0_l02249o`078@04o`000?l01b7o00LQo`078@co00LP:?l01R0;oooo
o`03o`000?oooooooooo03Cooooo000cooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool00_oooolao`067a;o00HP1_l01b03o`078@Co00LP6?l01b400ol0227o00PRo`088P0<o`088P03
o`088ol02B?o00TS013o00TS00?o00TTo`0:9?l02R@00_l02R@00ol02RGo00/Uo`0;9@07o`0;9@Wo
00`V00?o00dWo`0<9ol032L01?l03BL00ol03BSo00hXo`0>:009o`0>:0[o00lY0_l03bX2o`0?:@05
o`0@:_l0003o0000o`000?l042X00_l03bT00ol042[o00lYo`0?:@07o`0?:@06o`0>:?l03bWo00hX
o`0>:?l03BSo00hX1_l03BL01?l032Oo00dWo`0=9ol032L3o`0=9`03o`0<9_l03BOo00`V00Co00`V
00?o00/Vo`0;9Ol02bD00ol02bD6o`0:90Co00TT1_l02B<Go`088P05o`088Ol022;o00PQo`088Ol0
22800_l022400ol01b7o00PQo`078@06o`078@03o`000?l01b7o00LQ00?o00LQ2ol01b0Ro`068003
o`067ol01R3o00HP00;o00HP2_ooool00ol0003oooooooooo`0dooooo`00<oooool2o`0001gooooo
00?o0000ooooooooool00_ooool_o`067`Oo00HP0_l01Ql8o`0680[o00LP00?o00LQo`078?l01b00
6_l01b400ol0227o00PRo`088P0<o`088Q3o00TS1?l02B@4o`0:9003o`0:9Ol02bGo00/U00Oo00/U
1_l032H8o`0=9`;o00dX2Ol03RP7o`0?:@?o010Z00Go00lYo`0@:_l042[o00lZo`0@:P03o`0000?o
010Z00[o010[o`0@:_l042[o010Zo`0@:ol042[o00lYo`0@:_l03bWo010Z1_l03bT4o`0>:003o`0=
9ol03RSo00dW00co00dW1?l032H00ol02bKo00/Uo`0;9@04o`0;9@Go00XT0ol02B@7o`098ako00PR
0ol02247o`078@03o`000?l01b7o00LQ00;o00LQ00?o00LPo`078Ol01b002?l01b06o`0680?o00LP
00?o00HPo`078?l01R005_l01R04o`067`;o00HP2_ooool00ol0003oooooooooo`0cooooo`00<_oo
ool2o`0001oooooo00?o0000ooooooooool00_oooolKo`067`?o00HP3Ol01Ql:o`0680Co00HO1?l0
1R001Ol01b3o00HPo`078?l01R3o00LP00;o00HP1ol01b0Go`078@04o`088Ol01b7o00LQo`078@;o
00PQ3?l0228?o`098`?o00TT1_l02R@00ol02RGo00/Uo`0;9@08o`0;9@?o00`V2ol03BL8o`0>:0Wo
00lY00Co010[o`0@:_l042[o014[0_l042X3o`0000Go010Z00?o014[o`0@:ol042X00_l04B/3o`0@
:`08o`0@:_l042_o010Zo`0@:_l03bWo010Zo`0?:Ol042X3o`0?:@Go00hX00Go00dWo`0>:?l03BOo
00dWo`0=:007o`0=9`Co00`V2?l02bD6o`0:9003o`099?l02B?o00TS00Ko00TS0_l02283o`088`05
o`088_l02B?o00PSo`098ol022<05Ol022800ol0227o00LQo`078@05o`078@03o`000?l01b7o00LQ
00Go00LQ2Ol01b05o`0680?o00LP6?l01R05o`067`;o00HP2oooool00ol0003oooooooooo`0boooo
o`00<oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo6_l01Ql00ol01R3o
00HOo`067`08o`067`;o00HP00?o00HOo`068?l01R001Ol01R000ol01Qoo00HPo`068004o`0680;o
00HO1?l01R02o`0780Go00HP1_l01b0Eo`078@Go00PQ0ol01b42o`088@co00PR2ol02B<3o`0990[o
00XT2Ol02bD4o`0<9PSo00dW00?o00dXo`0>:?l03RP01_l03RP8o`0?:@03o`0@:_l042_o010[00Co
014[0_l00004o`0A:`03o`0@:_l04B_o014[00Go014[00[o018/o`0A:ol04B_o010[o`0A:ol042_o
014[o`0@:ol042[o010[0ol042X01Ol03bWo010Zo`0?:Ol03RSo00lY00Ko00hX00?o00dXo`0>:?l0
3BP01_l03BL3o`0<9P03o`0;9_l02bGo00/U00Ko00/U00?o00XUo`0:9?l02R@00ol02R@00ol02BCo
00TSo`098`07o`098`03o`088ol02B?o00TS00Go00TS00?o00PSo`088_l022804_l02282o`088@Oo
00LQ00?o0000o`078Ol01b401?l01b4:o`0780Go00HP0_l01b0Ho`0680So00HO2_ooool00ol0003o
ooooooooo`0booooo`00<_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo
9?l01Ql7o`0680Go00HO4ol01R05o`0781Co00LQ1Ol02245o`078@03o`088Ol022;o00PR00_o00PR
00?o00PSo`098ol02B<02?l02B<00ol02BCo00XTo`0:9008o`0:90;o00XU2?l02bD4o`0<9PGo00dW
1?l03BP5o`0>:0Oo00lY1Ol042X3o`0A:`?o000000Go014[o`0B;?l04Rco014[o`0B;003o`0A:`03
o`0B;?l04B_o014[00Ko018/00[o014[o`0B;?l04Rco014[o`0B;?l04B_o010[o`0A:ol042[o010[
0_l042X4o`0?:@03o`0>:?l03bWo00hX00Go00hX00?o00dXo`0=9ol03BL00ol03BL00ol032Oo00`V
o`0<9P02o`0;9P03o`0;9Ol02bKo00/U00Ko00/U1?l02R@2o`09913o00TS0_l022<Co`088P03o`08
8Ol01b7o00LQ00Oo00LQ00?o0000o`078Ol01b400ol01b4:o`0780[o00HP1Ol01Ql9o`0680?o00HO
00?o00HPo`067ol01Ql02Ol01Ql;ooooo`03o`000?oooooooooo037ooooo000booooo`03o`000?oo
oooooooo027ooooo0_l00003ooooob?o00HO1_l01R07o`067a?o00HP1Ol01b000ol01b7o00LPo`07
8@0@o`078@Co00PQ1_l01b400ol0227o00PRo`088P0=o`088PSo00TS00?o00TTo`0:9?l02R@02Ol0
2R@9o`0;9@;o00/V0_l032H00ol032Oo00dWo`0=9`02o`0=9`;o00dX1Ol03RP7o`0?:@Go010Z0ol0
4B/3o`0000;o018/0_l04b`;o`0B;0?o01<]0_l04R`00ol04bgo018/o`0C;@04o`0B;0;o014[00?o
010[o`0A:ol042X00ol042X4o`0?:@Go00hX0ol03BP3o`0=9`;o00`W1?l032H00ol02bKo00`Vo`0;
9P06o`0;9@Co00XT0_l02B@?o`098`03o`088ol022;o00PR00oo00PR00?o00PQo`088_l022800_l0
2249o`078@04o`000?l01b7o00LQo`078@Ko00LP00Co00HPo`078?l01b3o00LP2ol01R07o`067`Co
00HP4ol01Ql;ooooo`03o`000?oooooooooo033ooooo000booooo`03o`000?oooooooooo02?ooooo
00Co0000oooooooooooooooo9?l01Ql3o`0680Oo00HO5Ol01R0:o`0780ko00LQ1?l02244o`078@03
o`088Ol022;o00PR013o00PR1_l02B<2o`0990[o00XT2?l02bD00ol02bKo00`Vo`0<9P03o`0<9P?o
00dW0_l03BP5o`0>:0Go00lY0ol042/2o`0@:P?o014[0ol00003o`0B;0;o01<]00Ko01</o`0C;Ol0
4bgo01<]o`0B;?l04bd2o`0B;004o`0C;Ol04Rco018/o`0B;0?o01<]00Go01@]o`0C;Ol04bgo01<]
o`0D;@02o`0C;@Co018/1?l04B/3o`0@:PCo00lY00?o00hXo`0?:Ol03bT00ol03RP00ol03BSo00hX
o`0=9`03o`0=9`03o`0<9ol03BOo00`V00Ko00`V00?o00/Uo`0;9_l02bD00ol02bD4o`0:90?o00TT
00?o00TSo`099?l02B<02Ol02B<Bo`088P04o`088Ol01b7o00LQo`088@_o00LQ00Co0000o`078Ol0
1b7o00LQ1Ol01b000ol01R3o00LPo`078003o`0780Co00HP0_l01Ql2o`0680So00HO1?l01R0Eo`06
7`[ooooo00?o0000ooooooooool0<?ooool003;ooooo00?o0000ooooooooool09?ooool01?l0003o
oooooooooooooolTo`067`;o00HP1ol01QlFo`0680[o00LP3_l01b400ol0227o00LQo`078@04o`07
8@03o`088Ol022;o00PR013o00PR00?o00PSo`098ol02B<01?l02B<2o`0990So00XT1_l02bD4o`0;
9PCo00`V0_l032L3o`0=9`Go00hX1?l03bT4o`0@:`?o014[0ol00004o`0B;003o`0C;?l04bgo01<]
00;o01@]00Go01<]o`0D;Ol052go01<]o`0D;P03o`0C;@03o`0D;Ol04bgo01<]00?o01@^00Co01@]
o`0D;_l052ko01@]0_l052h00ol04bgo01@]o`0C;@02o`0B;0Co014[00Ko010Zo`0A:ol04B_o010Z
o`0?:Ol042X4o`0?:@Ko00hX1_l03BL00ol032Ko00dWo`0<9P04o`0<9P03o`0;9_l032Ko00/U00?o
00/U0ol02R@6o`0990Ko00TS5Ol022800ol0227o00LQo`078@0=o`078@03o`000?l01b7o00LP00co
00LP0ol01R05o`067`03o`068?l01Qoo00HO01ko00HO2_ooool00ol0003oooooooooo`0_ooooo`00
<_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo:ol01Ql:o`0680;o00HO
2ol01R0:o`0781;o00LQ0ol0224Ao`088P03o`088ol02B?o00TS00Ko00TS0_l02B@7o`0:9003o`0:
9Ol02bGo00/U00;o00/U0_l02bH8o`0<9PCo00dW1Ol03RP2o`0?:@?o010Z00?o010[o`0A:ol04B/0
0ol00007o`0B;0Co01<]00Go01@]o`0D;_l052ko01@]o`0E;P02o`0D;P03o`0C;Ol052ko01@]00Go
01@^0_l05Bh01_l052ko01D^o`0D;_l05Bko01@]o`0D;P?o01<]00?o018/o`0A:ol04R`01?l04B/2
o`0@:`;o010Z00Go00lYo`0@:_l03bWo00lYo`0>:@05o`0>:003o`0=:?l03BOo00dW00Co00dW1_l0
32H01Ol02bKo00/Uo`0;9Ol02bGo00XU00Co00XT1_l02B@4o`098`03o`088ol022;o00PR01;o00PR
0_l0224@o`078@03o`000?l01b3o00LP00[o00LP0ol01R05o`067`Co00HP7_l01Ql;ooooo`03o`00
0?oooooooooo02kooooo000booooo`;o00009oooool00ol0003oooooooooo`02ooooobOo00HO00?o
00HPo`067ol01R002?l01R04o`067`ko00HP2?l01b0?o`078@;o00PQ5?l0228:o`098`;o00TT1Ol0
2R@5o`0;9@_o00`V0_l03BL00ol03BSo00hXo`0>:006o`0?:@?o014[0ol00006o`0B;0;o01</0_l0
4bd5o`0D;P04o`0F;ol05Boo01D_o`0E;P;o01D_00Wo01@^o`0F;ol05Bko01D^o`0D;_l05Roo01D_
o`0E;_l05Rl00_l05Bl01?l05Bko01D_o`0E;_l05Bh2o`0D;P;o01<]1?l04R`00ol04B_o018/o`0A
:`02o`0A:`03o`0@:_l04B_o014[00;o010Z0ol03bT6o`0>:0;o00dX1?l03BL00ol032Oo00`Vo`0<
9P03o`0<9P?o00/U00?o00XUo`0:9?l02R@00ol02R@3o`0990Ko00TS5Ol022800ol0227o00LQo`08
8@03o`078@;o00PQ2ol01b400ol0003o00LPo`078@09o`0780go00HP7_l01Ql:ooooo`03o`000?oo
oooooooo02kooooo000aooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_oooolS
o`067b7o00HP1ol01b0>o`078@;o00PQ5?l0228<o`098`03o`099?l02RCo00XT00;o00XT00?o00XU
o`0;9Ol02bD00ol02bD9o`0<9P03o`0<9ol03BOo00dW00Go00hX0_l03bT00ol03b[o010Zo`0@:P03
o`0000Co018/00?o01<]o`0C;?l04R`00ol04bd00ol04bco01@]o`0D;@03o`0D;P?o01H_00Ko01D_
o`0G<?l05c3o01H_o`0E;ol05bl;o`0F;`04o`0E;ol05Roo01D^o`0E;`;o01@^00?o01<]o`0D;Ol0
4bd01Ol04R`00ol04Bco014[o`0A:`02o`0A:`;o010Z1Ol03bT7o`0>:0Co00dW1?l032H00ol02bKo
00/Uo`0;9@02o`0;9@Ko00XT00?o00TTo`098ol02B<01Ol02B<Do`088P03o`088Ol022;o00PR00;o
00PQ0_l01b43o`088@[o00LQ00Ko0000o`078Ol01b7o00LQo`078?l01b47o`0780ko00HP7?l01Ql;
ooooo`03o`000?oooooooooo02gooooo000aooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool00_oooolRo`067b3o00HP2?l01b0>o`078@03o`088Ol022;o00PR01?o00PR2ol02B<2o`09
90?o00XT1_l02bD:o`0<9PCo00dW00?o00hXo`0?:Ol03bT00_l03bT01?l042[o0000o`000?l00003
o`0A:`03o`0B;?l04bco01<]00Go01<]0ol052d3o`0E;P04o`0E;ol05Roo01H_o`0F;`?o01L`00[o
01Pao`0G<?l05c3o01L_o`0H<?l05c3o01H_o`0G<?l05Roo01L`0_l05bl00ol05Roo01L`o`0F;`02
o`0F;`06o`0E;ol05Roo01H_o`0D;_l05Bko01@]0_l04bd01?l04Rco01<]o`0B;?l04bd2o`0B;004
o`0A:ol04Rco014[o`0A:`;o010Z1?l03bT7o`0>:0Co00dW0ol032H2o`0;9PGo00/U1_l02R@7o`09
8aOo00PR00?o00PQo`088_l022401?l0224;o`078@03o`000?l01b7o00LQ00?o00LQ1ol01b000ol0
1R3o00LPo`068009o`0680So00HO00?o00HPo`067ol01Ql04_l01Ql00ol01R3oooooooooo`06oooo
o`Co0000;_ooool0037ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`02ooooob7o
00HO5_l01R02o`078003o`068?l01b3o00HP00Go00HP2_l01b0=o`078A?o00PR0_l022<;o`098`03
o`099?l02RCo00XT00;o00XT1ol02bD6o`0<9P?o00dW00?o00dXo`0>:?l03RP00ol03RP01?l03bWo
0000o`000?l00004o`0A:`;o018/0ol04bd00ol052go01<]o`0D;P03o`0D;P03o`0D;Ol05Bko01D^
00;o01D^1_l05c001_l06C7o01Pao`0G<?l06C7o01P`o`0I<P;o01Pa00?o01L`o`0H<Ol05c001Ol0
5c000ol05boo01H_o`0F;`02o`0F;`08o`0E;_l05Roo01@^o`0D;_l04bgo01@^o`0C;Ol052d2o`0C
;@Co018/0_l04B/2o`0@:PCo00lY1ol03RP00ol03BSo00dWo`0=9`03o`0<9P03o`0;9_l02bGo00/U
00Go00/U1?l02R@00ol02BCo00TSo`098`06o`098`03o`088ol022;o00PR01Ko00PR1Ol0224;o`07
8@03o`000?l01b7o00LQ00;o00LQ2ol01b09o`0680Go00HO1Ol01R0Bo`067`;o00HP2_ooool00ol0
003oooooooooo`0/ooooo`00<Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;o
oooo8Ol01Ql<o`068004o`078?l01R3o00LPo`0780;o00HP4?l01b02o`078@Ko00LP3?l01b42o`08
8@ko00PR00?o00PSo`088_l022803Ol02B<00ol02BCo00XTo`0:9002o`0:90Oo00/U00Co00/Vo`0<
9_l032Ko00`W1Ol03BL2o`0=:0;o00hX00?o00lYo`000?l000001?l042X2o`0A:`?o018/0_l04bd5
o`0D;P04o`0F;ol05Boo01D_o`0E;PKo01L`1?l06C42o`0J<P06o`0I<Ol06C;o01Tbo`0I<_l0637o
01Xb0ol063401?l05c3o01Tao`0G<?l06342o`0G<005o`0F;ol05c3o01H_o`0G<?l05Rl00ol05Bh0
1?l052ko01D^o`0D;Ol052h3o`0C;@;o018/0_l04B/3o`0@:PCo00lY1Ol03RP01?l03BSo00dWo`0=
9ol03BL2o`0<9P;o00/V2?l02bD4o`0:9003o`099?l02B?o00TS00Oo00TS6?l02282o`088@03o`07
8Ol0227o00LQ00[o00LQ00?o0000o`078Ol01b400ol01b4:o`0780Wo00HP1Ol01Ql5o`0681Go00HO
2_ooool00ol0003oooooooooo`0[ooooo`00<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00;ooooo7ol01Ql=o`0681Ko00LP0ol01b400ol01b3o00LQo`078002o`0780_o00LQ0_l0
224<o`088P;o00TS00?o00PSo`098ol02B<03?l02B<3o`0990?o00XT1ol02bD01?l02bKo00`Vo`0<
9_l032H5o`0=9`?o00hX0ol000000ol03bWo010Zo`0@:P05o`0A:`;o018/0_l04bd01?l052go01@^
o`0D;_l052h3o`0F;`Go01L`1_l06C401?l06c?o01Xbo`0J<_l06S82o`0K<`04o`0I<_l06c?o01Xb
o`0L<`;o01Xb00Co01Pao`0J<_l06C7o01Xb1?l063400ol05c3o01Pao`0G<002o`0G;`04o`0E;_l0
5Roo01D^o`0E;`;o01@^1?l04bd3o`0B;0;o014[0_l042X3o`0?:@Ko00hX0ol03BL01Ol032Oo00`V
o`0<9_l02bKo00`V00Oo00/U1?l02R@2o`0990Wo00TS0_l022<Eo`088P03o`088Ol01b7o00LQ00go
00LQ00Co0000o`078Ol01b7o00LQ3?l01b0:o`0680Co00HO00?o00HPo`067ol01Ql05_l01Ql;oooo
o`03o`000?oooooooooo02[ooooo000aooooo`03o`000?oooooooooo02gooooo00Co0000oooooooo
oooooooo7Ol01Ql00ol01R3o00HOo`06800<o`0681Co00LP2?l01b400ol01b3o00LQo`078@0;o`07
8@03o`088Ol022;o00PR00[o00PR3ol02B<3o`0990Go00XT1ol02bD01Ol02bKo00`Vo`0<9_l032Ko
00dW00;o00dX0_l03RP3o`0000;o00lY0ol042X01?l042_o014[o`0A:ol04B`4o`0B;0?o01@^00?o
01D^o`0E;ol05Rl01Ol05c06o`0I<@Co01/c00Oo01Xbo`0M=?l073Co01`do`0K<ol07CCo01/c00;o
01`c00?o01Xbo`0L=?l073@01Ol06S801?l0637o01Xbo`0H<Ol06C82o`0H<006o`0G;ol05c3o01H_
o`0G<?l05Boo01H_0_l052h2o`0C;@?o018/00Co014/o`0A:ol04B_o014[0_l042X3o`0?:@Co00hX
00Co00dXo`0=9ol03BOo00dW0_l032L4o`0<9P03o`0;9_l02bGo00/V00Co00/U1?l02R@2o`0990Wo
00TS00?o00PSo`088_l022804_l02282o`088@Ko00LQ00?o00PQo`078Ol01b401ol01b401?l0003o
00LQo`078Ol01b4:o`0780_o00HP7_l01Ql:ooooo`03o`000?oooooooooo02[ooooo000`ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool00_oooolLo`067`03o`068?l01Qoo00HO00Wo
00HP4?l01b03o`078@03o`078?l01b7o00LQ01Oo00LQ00?o00PQo`088_l022802?l0228=o`098`?o
00TT1ol02R@00ol02RGo00/Uo`0;9@05o`0;9@03o`0;9_l032Ko00`V00?o00dW0ol000000ol03RSo
00lYo`0?:@02o`0?:@;o010Z1?l04B/01?l04Bco018/o`0B;?l04R`2o`0C;@04o`0D;_l05Boo01H_
o`0F;`?o01L`1Ol06C44o`0L<`?o01/c00Go01heo`0M=?l07CCo01`do`0O=P02o`0M=0;o01he00?o
01`co`0L=?l073@00ol073@01Ol06S;o01`do`0J<_l073?o01Xb00;o01Tb0_l06C400ol05c3o01Pa
o`0H<@02o`0G<0;o01H_0_l052h2o`0C;@;o018/00Co014/o`0A:ol04B_o014[0_l042X4o`0?:@Co
00hX1Ol03BL6o`0<9P;o00/V1?l02bD4o`0:90?o00TT2?l02B<Do`088P03o`088Ol01b7o00LQ00Co
00LQ0_l0224:o`078@03o`000?l01b7o00LQ00Wo00LP3?l01R0No`067`_ooooo00?o0000oooooooo
ool0:Oooool0033ooooo00Co0000ooooool0003o0000;oooool00ol0003oooooooooo`02oooooaoo
00HO2?l01R0>o`07823o00LQ00?o00PQo`088_l022801ol022800ol022?o00TSo`098`09o`098`;o
00TT2Ol02R@00ol02RGo00/Uo`0;9@04o`0;9@04o`0;9_l032Ko00`Vo`0=9`?o00000ol03RP4o`0?
:@;o010Z00?o010[o`0A:ol04R`01?l04R`2o`0C;@;o01@]00Go01@^o`0E;ol05Roo01L`o`0H<@05
o`0I<@03o`0K<ol073?o01`c00?o01`c0_l083H2o`0O=P03o`0N=Ol07CCo01lf00;o01lf00?o01dd
o`0Q=ol07SD00_l083H01?l073Co020fo`0L=?l083H2o`0L=0;o01`c0_l06c<01_l06C;o01/co`0I
<Ol06S;o01Pao`0I<@;o01L`00Oo01H_o`0E;ol05Bko01@^o`0D;Ol04bgo01</00;o018/00Co014[
o`0A;?l04B_o014[0_l042X4o`0?:@Co00hX1Ol03BL6o`0<9P;o00/V1?l02bD3o`0:9004o`099?l0
2RCo00TTo`0990Ko00TS4_l02282o`088ACo00LQ00Co0000o`078Ol01b7o00LQ2?l01b0;o`06823o
00HO2_ooool00ol0003oooooooooo`0Yooooo`00<?ooool2o`0003;ooooo00?o0000ooooooooool0
0_oooolOo`067`Go00HP0ol01b000ol01R3o00LPo`078009o`07823o00LQ00?o00PQo`088_l02280
2ol02288o`098`;o00TT2ol02R@01Ol02RGo00/Uo`0;9Ol02bGo00/V00;o00`V0ol00002o`0=9`03
o`0=:?l03RSo00hX00Go00lY00Co010Zo`0@:ol04B_o014[0_l04R`5o`0C;@06o`0D;_l05Bko01H_
o`0F;ol05boo01L`0_l063400ol06C7o01/co`0K<`03o`0K<`03o`0L<ol08COo024g00;o020g00Co
020fo`0O=_l07cKo01he0_l08CL01_l07cKo02@io`0Q=ol08COo01heo`0T>@Go020f00Wo01`do`0P
=_l083Ko01`co`0N=Ol06c?o01ddo`0K<ol073@00_l06S82o`0I<@?o01L`0_l05Bh01?l052go01<]
o`0C;?l04bd4o`0B;0;o014[0_l042X3o`0?:@04o`0>:Ol03RSo00hXo`0=:0Oo00dW1?l032H6o`0;
9@03o`0:9Ol02RCo00XT00?o00XT00?o00TTo`098ol02B<01Ol02B<=o`088P03o`078Ol0227o00PQ
01So00LQ00?o0000o`078Ol01b001ol01b0<o`06827o00HO2_ooool00ol0003oooooooooo`0Xoooo
o`003Oooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool00_oooolMo`067`go00HP2_l01b0Oo`078@03
o`088Ol022;o00PR00_o00PR2?l02B<00ol02BCo00XTo`0:9008o`0:9003o`0:9Ol02bGo00/U00;o
00/U0ol00002o`0<9P03o`0<9ol03BOo00dW00?o00hX1Ol03bT00ol042[o010[o`0A:`03o`0B;003
o`0C;Ol052ko01@^00?o01@^00Ko01H_o`0G<?l05c3o01L`o`0H<Ol06C43o`0J<P;o01/c00Co01lf
o`0P=_l083Oo020g0_l08CL01?l083Oo020fo`0U>Ol09CT2o`0S>005o`0Q=ol093Wo02@io`0Q=ol0
:3/00_l093T01?l083Ko02Dio`0P=_l09CT4o`0P=P;o01he00?o01ddo`0O=_l073@00_l07C@01?l0
6S;o01/co`0I<Ol06C43o`0G<0;o01D^00Co01<]o`0D;Ol04bgo01<]0ol04R`2o`0A:`;o010Z0ol0
3bT01?l03RWo00hXo`0>:?l03RP2o`0=:0Go00dW1?l032H5o`0;9@03o`0:9Ol02RCo00XT00?o00XT
0_l02B@6o`098`co00PR0_l0224Lo`078@03o`000?l01b7o00LP00Ko00LP2ol01R0So`067`[ooooo
00?o0000ooooooooool09oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0<oooool2o`0000?ooooo7Ol0
1Ql00ol01R3o00HOo`06800:o`0680[o00LP7ol01b400ol022;o00PQo`088P0:o`088PWo00TS00?o
00TTo`0:9?l02R@01ol02R@2o`0;9@?o00001_l032H3o`0=9`Co00hX0_l03bT2o`0@:P03o`0@:ol0
4Rco01<]00?o01<]00Co01@]o`0D;_l05Boo01D_0ol05Rl01?l05c3o01Pao`0J<_l06c<2o`0L=004
o`0M=?l07SGo01lfo`0O=P;o020f00Co020go`0Q=ol08COo020g0_l09SX00ol09CWo02<ho`0Z?@02
o`0W>`05o`0T>Ol0:3_o02Pko`0T>Ol0:S`01_l09CT01?l083Ko02@io`0N=Ol08CL2o`0O=P?o01dd
0_l06c<3o`0I<@06o`0G<?l05boo01D^o`0E;_l052go01@^0ol04bd00ol04Rco01<]o`0B;002o`0A
:`?o010Z0_l03bT3o`0>:0;o00dX1Ol03BL3o`0<9PSo00/U1?l02R@00ol02BCo00TSo`098`04o`09
8`;o00PS2ol022800ol0227o00LQo`078@0Lo`078@03o`000?l01b3o00LP00Oo00LP2?l01R0To`06
7`[ooooo00?o0000ooooooooool09oooool0013ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo
oooo7ol01Ql;o`0680co00LP7Ol01b42o`088@[o00PR00?o00PSo`098ol02B<01_l02B<2o`0990Oo
00XT0ol00002o`0;9@03o`0;9_l032Ko00`V00Go00`V0ol03BL2o`0>:0?o00lY00Ko010Zo`0@:ol0
4B_o014[o`0B;?l04bd2o`0D;P?o01D^00Ko01D_o`0F;ol05Roo01H_o`0G<?l06342o`0J<P08o`0K
<ol073Co01ddo`0M=?l07SGo01lfo`0P=_l09SX5o`0W>`03o`0V>_l09CWo02Xm00;o02Xm00Co02Lk
o`0T>Ol0;Cko02Pk0ol0:S`01Ol09CWo02`mo`0U>Ol0;3go02Di00;o02@i0_l08CL01_l093Wo01lf
o`0Q=ol07CCo01heo`0O=P?o01/c0_l06C401?l05boo01L`o`0E;_l05Bh2o`0D;PCo01<]0_l04R`2
o`0A:`05o`0@:_l03bWo00lYo`0?:Ol03RT00ol03RP00ol03BSo00dWo`0=9`02o`0=9`?o00`V2Ol0
2bD4o`0:9003o`099?l02B?o00TS00Co00TS0_l022<:o`088P03o`088Ol01b7o00LQ01go00LQ00?o
0000o`078?l01b002?l01b000ol01R3o00LPo`068004o`0682Go00HO2_ooool00ol0003ooooooooo
o`0Vooooo`004?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooob;o00HO00?o00HPo`06
7ol01R000ol01R0=o`0781go00LQ00?o00PQo`088_l022802Ol02289o`098`;o00TT0ol02R@3o`00
0003o`0:9?l02bGo00/U00?o00/U00?o00/Vo`0<9_l032H01Ol032H01?l03BOo00dXo`0=:?l03RP2
o`0?:@05o`0@:_l042_o010[o`0A:ol04R`00_l04bd00ol052go01@^o`0E;P02o`0E;`;o01H_00So
01L_o`0G<?l0637o01Pao`0J<_l06c?o01ddo`0O=P;o024g00?o02<ho`0U>Ol09SX00_l09SX4o`0W
>`03o`0V>_l0;Sko02Xm00;o02Xm00Go02Lko`0]?_l0;Cko02Pko`0`@002o`0Z?0Co02`m00Co02Di
o`0Z??l093Wo02Pk0_l093T01_l09c_o024go`0S>?l07SGo01lfo`0P=P?o01/c0_l06C42o`0G<004
o`0E;_l05Roo01@^o`0D;P?o01<]0_l04R`2o`0A:`04o`0@:_l03bWo00lYo`0>:@?o00hX00Co00dX
o`0=9ol03BOo00dW0_l032L3o`0<9PWo00/U0ol02R@00ol02BCo00TSo`098`06o`098`03o`088ol0
2B?o00PR00So00PR0_l0224Oo`078@03o`000?l01b3o00LP00[o00LP1_l01R000ol01Qoo00HPo`06
7`0Po`067`_ooooo00?o0000ooooooooool09Oooool000cooooo1?l00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0>?ooool01?l0003ooooooooooooooolU
o`067`Co00HP00?o00LPo`068?l01b002_l01b0No`078@03o`088Ol022;o00PR00So00PR2_l02B<0
0ol02BCo0000o`000004o`0:90Ko00/U00?o00/Vo`0<9_l032H01Ol032H01?l03BOo00hXo`0>:?l0
3RP2o`0?:@05o`0@:_l04B_o014[o`0A;?l04R`00_l04bd00ol052ko01D^o`0E;`02o`0F;`;o01L`
0_l063400ol06S;o01`co`0N=@02o`0Q=`05o`0O=_l08COo02<ho`0S>?l09CT00_l09SX2o`0W>`;o
035100?o0310o`0^?_l0;Sh00_l0:Sd2o`0b@@05o`0]?_l0<43o0310o`0Z??l0=4801?l0;3d2o`0Z
?0;o02Pk00?o02dno`0T>Ol09c/00_l08cP00ol09CWo01lfo`0P=P03o`0K<`;o01Ta0_l05c03o`0F
;`;o01@^0_l04bd01Ol04Rco014/o`0A:ol042_o010Z00Co00lY0_l03RP4o`0=9`Co00`V2Ol02bD5
o`0:90_o00TS2?l022801?l0227o00PRo`078Ol0224No`078@03o`000?l01b7o00LP00Wo00LP2ol0
1R0Oo`067`[ooooo00?o0000ooooooooool09Oooool000cooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo03Wooooo00Co0000oooo
oooooooooooo8_l01Ql9o`068003o`078?l01R3o00LP00Ko00LP8?l01b4:o`088P03o`098ol022?o
00TS00Go00TS0ol00003o`0:90?o00XU1_l02bD00ol02bKo00`Vo`0<9P04o`0<9P?o00dW00Oo00hX
o`0?:Ol03bWo00lYo`0@:_l042_o014[00;o018/00Go01<]o`0D;Ol05Bko01D^o`0E;`02o`0F;`?o
01L`00So01Pao`0L=?l073?o01`co`0N=Ol08COo02@io`0W>`;o02Xm00Go02dno`0`?ol0<3oo0351
o`0b@@02o`0a@@;o031000?o02hno`0Z?Ol0=d@00_l0<T400ol0;Cko0310o`0`@002o`0d@PCo02`m
00Go03A2o`0Z??l0<D3o02Pko`0]?P02o`0W>`03o`0Z?Ol08cSo02Di00;o020f00Co020go`0K<ol0
6c?o01/c0_l06C43o`0G<00:o`0F;ol05Boo01@^o`0D;Ol04bgo018/o`0A;?l04B_o010[o`0@:P?o
00lY0_l03RP3o`0=9`03o`0<9ol032Ko00`V00;o00`V00?o00/Vo`0;9Ol02bD01Ol02bD2o`0:9@Co
00XT0_l02B@9o`098`03o`088ol022;o00PR00Wo00PR0_l0224Mo`078@03o`000?l01b7o00LQ00[o
00LP3?l01R0No`067`Sooooo0ol0000Vooooo`003?ooool5o`0000?ooooo0_l00004ooooo`;o0000
1?ooool2o`0000Cooooo0_l00007ooooo`;o0000>oooool01?l0003ooooooooooooooolQo`067`co
00HP1ol01b0Oo`078@03o`088Ol022;o00PR00So00PR0_l022<2o`098`?o00000_l02B<01Ol02BCo
00XTo`0:9?l02RCo00XU00Wo00/U1_l032H2o`0=9`?o00hX00?o00lYo`0@:_l042X00ol04B/01ol0
4Rco01<]o`0C;Ol052ko01D^o`0E;ol05Rl00_l05bl01?l05c3o01Tao`0I<Ol06S82o`0P=P07o`0T
>Ol08COo02@io`0T>Ol09c_o02Xmo`0]?P02o`0`?`04o`0a@Ol0<T7o0391o`0a@@;o031000?o02hn
o`0gA?l0=d@00_l0<T42o`0hA006o`0`@?l0=4;o03A2o`0/?Ol0=T?o02`m0_l0=482o`0a@0;o02dn
00So02Lko`0Z?Ol0:Sgo02Dio`0V>_l09c_o020fo`0P=`;o020f0_l06c<2o`0I<@?o01L`00Go01D_
o`0E;_l052go01<]o`0B;002o`0A:`?o010Z0_l03bT3o`0>:0;o00dW1Ol032H2o`0;9PKo00/U1ol0
2R@2o`0990So00TS00?o00PSo`088_l022802_l022800ol0227o00PRo`078@0Lo`078@04o`000?l0
1b7o00LPo`078@Wo00LP2ol01R0Oo`067`[ooooo00?o0000ooooooooool08oooool002oooooo00?o
0000ooooooooool0>oooool01?l0003ooooooooooooooolPo`067`co00HP2?l01b0Lo`078@;o00PQ
3?l02283o`0000Go00TS00Co00TTo`0:9?l02RCo00XT2_l02bD4o`0<9P;o00`W0_l03BL00ol03BSo
00hXo`0?:@02o`0?:@;o010Z0ol04B/00ol04Rco01<]o`0D;P02o`0D;P07o`0E;ol05Roo01L`o`0G
<?l0637o01Xbo`0L=003o`0P=P04o`0X>ol0;Cko02dno`0W>`;o02Xm00Wo02dno`0`?ol0<D7o0351
o`0b@Ol0<D7o0310o`11B?l0?4H00_l0=d@01?l0<T7o03m8o`0hA?l0>4@2o`0mAP03o`0d@_l0=T?o
03I300?o03A20_l0<D000ol0;Cko0391o`0Z?@02o`0Z?@05o`0`?ol09S[o02Lko`0W>ol083L00_l0
83H2o`0K<`08o`0J<_l06C7o01Pao`0G<?l05Roo01D^o`0D;_l04bd2o`0B;0;o014[0ol042X2o`0?
:@;o00hX0_l03BL7o`0<9P;o00/V1Ol02bD7o`0:90;o00TT2Ol02B<=o`088P03o`088Ol01b7o00LQ
01co00LQ00?o0000o`078Ol01b402ol01b000ol01R3o00LPo`078006o`0681oo00HO2_ooool00ol0
003oooooooooo`0Sooooo`00;oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00;o
oooo7Ol01Ql=o`0680Oo00LP6_l01b44o`088@[o00PR0ol00008o`098`04o`099?l02RCo00XTo`0:
90Wo00/U1?l032H00ol032Oo00dWo`0=9`03o`0=9`;o00hX0_l03bT3o`0@:P05o`0A:ol04Rco018/
o`0B;?l04bd00_l05Bh2o`0F;`04o`0G<?l0637o01Xbo`0L=0;o020f0_l09CT01?l093Wo02Pko`0]
?_l0<T42o`0gA006o`0]?_l0<3oo0351o`0a@Ol0<T7o03510_l0@DP2o`0lAP03o`0gA?l0?dSo03m8
00;o03Q40_l0?DH03_l0=4;o0458o`0f@ol0@DSo03A2o`0mAol0<D3o03Q4o`0]?_l0<T7o03M4o`0Z
?Ol0;Cko030o1?l09c/01?l083Ko01lfo`0N=Ol06c<2o`0J<P05o`0H<Ol05c3o01L_o`0E;_l052h0
0_l04bd2o`0B;0;o014[0_l042X2o`0?:@;o00hX0_l03BL8o`0<9P03o`0;9_l02bGo00/U00?o00/U
2?l02R@2o`0990Wo00TS3Ol022800ol0227o00LQo`078@0Lo`078@03o`000?l01b3o00LP00ko00LP
1Ol01R0Po`067`[ooooo00?o0000ooooooooool08_ooool002kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`02oooooago00HO2ol01R09o`0781Oo00LQ0ol0224:o`088P?o00000ol0
2287o`098`03o`099?l02RCo00XT00Co00XT1ol02bD4o`0<9P03o`0<9ol03BOo00dW00;o00dW0ol0
3RP2o`0?:@;o010Z0ol04B/01Ol04Rco01<]o`0C;Ol052go01D^00;o01L`00Ko01Pao`0J<_l073?o
01`co`0L=?l083H2o`0U>@04o`0Z??l0<43o02dno`0]?P;o03M400Ko03a6o`11B?l0@dWo04=9o`15
B_l0A4T2o`11B0;o03a600Go03M4o`0oB?l0?dSo03Q4o`18C002o`0mAPCo045800Co03A2o`0mAol0
>4Co03Q40_l0<T401Ol0=dCo02dno`0]?_l0<3oo035100?o02Lk00co02Dio`0O=_l07SGo01ddo`0J
<_l06C7o01P`o`0G;ol05Roo01@^o`0D;Ol04bd2o`0B;0?o014[0_l042X2o`0?:@;o00hX00?o00dX
o`0=9ol03BL01ol032H5o`0;9@[o00XT0_l02B@8o`098`co00PR00?o00PQo`078Ol01b406ol01b42
o`078003o`000?l01b3o00LP00_o00LP3Ol01R0Lo`067`[ooooo00?o0000ooooooooool08Oooool0
02kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`02oooooaSo00HO00?o00HPo`06
7ol01Ql00_l01Ql:o`0680[o00LP3Ol01b400ol0227o00LQo`078@04o`078@03o`088Ol022;o00PR
00Wo00PR0ol00007o`088PCo00TS0ol02B@5o`0:90;o00XU1_l02bD3o`0<9PGo00dW00Co00dXo`0>
:?l03RSo00hX0_l03bT01?l03b[o010Zo`0@:ol04B/3o`0B;005o`0C;Ol052ko01@^o`0F;ol05c00
0_l063400ol06S;o01`co`0P=P02o`0U>@03o`0/?Ol0:Sco02Xl00;o03Q400Co0391o`0gA?l0?4Ko
04580_l0@dT01?l0AD[o04A9o`14BOl0@DP2o`0lAP;o04Q<00Go03m8o`18C?l0B4co04Q<o`0mAP04
o`11B0;o03e700?o04Q<o`0hA?l0?dP00_l0=d@00ol0?4Ko030oo`0`?`02o`0a@@0=o`0W>ol09S[o
02Dio`0S>?l07CCo01`do`0K<ol06C;o01P`o`0G<?l05Roo01D^o`0D;P02o`0C;@;o018/0_l04B/2
o`0@:P;o00lY0_l03RP01?l03BSo00dWo`0=9ol03BL7o`0<9P?o00/U00?o00XUo`0:9?l02R@02Ol0
2R@00ol02BCo00TSo`098`08o`098`03o`088ol022;o00PR00Oo00PR0_l0224=o`078@03o`078?l0
1b7o00LQ00Ko00LQ2Ol01b000ol0003o00LPo`078008o`0780oo00HP7?l01Ql:ooooo`03o`000?oo
oooooooo027ooooo000^ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00_oooolE
o`067`Co00HP1?l01Ql9o`0680_o00LP4ol01b400ol0227o00PRo`088P06o`088P?o00002_l02284
o`098`Co00TT00?o00XTo`099?l02R@00_l02R@6o`0;9@?o00`V1Ol03BL00ol03BSo00hXo`0>:002
o`0>:007o`0>:Ol03bWo010Zo`0@:_l042_o014[o`0A;002o`0B;006o`0C;Ol052ko01D^o`0E;_l0
5boo01P`0_l06C801Ol06c?o02@io`0P=_l0;3go02Di00;o03A20_l0>4@01?l0?dSo03M4o`0lA_l0
?4H2o`13B@;o04E:00Co04A9o`11B?l0?4Ko04m>0_l0B4`01?l0?dSo04Q<o`18C?l0B4`2o`1?CP?o
04580_l0?DL00ol0B4co03m8o`0oB002o`0gA003o`0lA_l0@DSo035100;o035100_o0310o`0U>Ol0
9CWo024go`0O=_l07CCo01/co`0I<_l05c3o01H_o`0E;`02o`0D;P;o01<]0_l04R`3o`0A:`;o010Z
0_l03bT2o`0>:0Co00dW1?l032H00ol02bKo00/Uo`0;9@02o`0;9@[o00XT00?o00TTo`098ol02B<0
2_l02B<;o`088P;o00PQ2ol01b43o`078004o`078Ol01b3o00LQo`078@go00LP00?o0000o`078?l0
1b001ol01b0<o`06823o00HO2_ooool00ol0003oooooooooo`0Pooooo`00;_ooool00ol0003ooooo
ooooo`11ooooo`05o`000?ooooooooooooooool01Ql00_l01R0@o`067`Ko00HP1Ol01Ql8o`0680co
00LP4_l01b400ol0227o00PRo`088P03o`088P?o00003?l022800ol022?o00TSo`098`05o`098`03
o`099?l02B?o00TT00Co00XT0ol02bD2o`0;9PCo00`V1Ol03BL00ol03BSo00hXo`0>:002o`0>:0;o
00lY0_l042X2o`0A:`06o`0B;?l04bgo01@]o`0D;Ol05Bko01H_0_l05c001_l06C7o01/co`0M=?l0
8COo02@io`0U>@;o02`m00Go03A2o`0`@?l0>4Co03m8o`18B`02o`0lAP06o`11B?l0@dWo04E:o`15
B_l0A4Wo04580ol0Cdh00ol0B4co055=o`18C002o`18C0;o04m>00Co0458o`1@C_l0@DSo04m>0_l0
B4`2o`0oB00Ao`18C?l0?4Ko03a6o`11B?l0<D7o0391o`0a@Ol0<43o02hno`0W>ol093Wo01ddo`0K
<ol06S;o01Pao`0G<?l05Rl00_l05Bl2o`0D;P;o01<]0_l04R`00ol04B_o010[o`0@:P02o`0?:@Co
00hX0_l03BL01?l032Oo00`Vo`0<9_l032H6o`0;9@03o`0:9Ol02RCo00XT00Co00XT1?l02B@<o`09
8`_o00PR0_l0224;o`078@go00LP00?o00HPo`078?l01b001?l01b000ol0003o00LPo`078005o`06
8003o`078?l01R3o00HP00_o00HP8?l01Ql;ooooo`03o`000?oooooooooo00Sooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00000oooool002kooooo00?o0000oooooooo
ool0@_ooool01Ol0003ooooooooooooooooo00HP01;o00HO00?o00HPo`067ol01R000_l01R05o`06
7`Wo00HP00?o00LPo`068?l01b001ol01b0Bo`078@?o00PQ00Co00PRo`000?l0003o00004?l02280
0ol022?o00PRo`098`07o`098`03o`099?l02RCo00XT00;o00XT0_l02bD2o`0;9PGo00`V1Ol03BL2
o`0=:0;o00hX0_l03bT00ol042[o014[o`0A:`03o`0B;006o`0C;Ol052ko01D_o`0E;ol05c3o01Pa
0_l06S82o`0O=P09o`0T>Ol0:Sco02`mo`0f@ol0=4;o03e7o`0hA?l0?dSo04Q;00;o04m>00Ko0458
o`13BOl0AD[o04E:o`14BOl0DTd3o`1?CP03o`18C?l0DDgo055=00;o04Q<0_l0Cdh2o`1@CP;o04m>
0_l0B4`00ol0DDgo03m8o`18C002o`0lAP0=o`11B?l0AD[o0351o`0a@Ol0<43o02hno`0W>ol093Wo
01heo`0J<_l0637o01L`o`0G;`02o`0F;`;o01D^00Go01@]o`0C;Ol04Rco018/o`0A:`02o`0@:`04
o`0@:_l03bWo00lYo`0?:@?o00hX00?o00dXo`0=9ol03BL00_l032H00ol02bKo00/Uo`0;9@04o`0;
9@Go00XT0ol02B@;o`098`03o`088ol02B?o00TS00co00PR00?o00PQo`078Ol01b402ol01b49o`07
80So00HP00Co00LPo`068?l01R3o00004ol01R0So`067`Wooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool1o`00007o
oooo0Oooool002kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`02oooooa_o00HO
3Ol01R07o`07813o00LQ0_l02243o`0001Ko00PR2?l02B<01?l02BCo00XTo`0:9?l02R@4o`0;9@03
o`0;9_l032Ko00/V00?o00`V00Go00dWo`0<9ol03BOo00dWo`0=:003o`0>:005o`0>:Ol03bWo010Z
o`0@:_l04B/00_l04R`3o`0C;@0?o`0D;_l05Roo01L`o`0G<?l06C7o01Xbo`0M=?l07cKo02@io`0Z
??l0;3go03I3o`0d@_l0?DOo04Q<00;o03m80_l0Cdh00ol0DTgo04=9o`15BP02o`1DC0;o059=0_l0
Cdh01Ol0ET_o055=o`1ACOl0B4co05I;00;o04m>0_l0D4h2o`1?CP;o04Q<00_o055=o`18C?l0B4co
04m>o`11B?l0@dWo04E:o`13BOl0<43o02hno`0W>`02o`0T>@05o`0L=?l06S;o01Pao`0G<?l05bl0
0_l05Rl00ol05Boo01D^o`0D;P02o`0C;@04o`0B;?l04B_o010[o`0@:PCo00lY0_l03RP00ol03BSo
00dWo`0=9`03o`0<9POo00/U0ol02R@00ol02BCo00TSo`098`0:o`098`;o00PR00?o00PSo`088_l0
22803_l0228>o`078@So00LP3?l01R000ol0003o00HPo`06800@o`0682?o00HO2_ooool00ol0003o
ooooooooo`06ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool1
o`00007ooooo0Oooool002gooooo0ol00015ooooo`;o00000ooooolKo`067`ko00HP2?l01b0=o`07
8@;o000000Go00PQo`078Ol0227o00LQo`088@0Do`088P;o00PS1ol02B<2o`0990;o00XT1Ol02bD0
0ol02bKo00/Uo`0<9P02o`0<9P;o00`W0ol03BL3o`0>:0;o00lY00Go010Zo`0@:ol04B_o014[o`0B
;003o`0C;@08o`0D;_l05Roo01L`o`0G<?l06C7o01/co`0N=Ol09c/2o`0a@009o`0f@ol0@TSo03e7
o`18C?l0DDgo03m8o`18Bol0Cdko059=00Co05A<0_l0DTd2o`1?CP;o05I;00?o055=o`18C?l0ET/0
0_l0Cdh2o`1@CP;o04m>00?o05I;o`1ACOl0DDd00_l0B4`03?l0Cdko0458o`13BOl0AD[o04=9o`11
B?l0=dCo0391o`0X>ol083Ko01`do`0J<P;o01L`0_l05Rl01_l05Boo01D^o`0E;_l052ko01<]o`0B
;0;o014[00?o010[o`0@:_l03bT00ol03bT3o`0>:0;o00dW0ol032H6o`0;9@Co00XT00?o00TTo`09
8ol02B<01ol02B<00ol022?o00PRo`088P0Bo`088P03o`088Ol01b7o00LQ00_o00LQ2?l01b0>o`06
8004o`000?l01Qoo00HPo`067`So00HP0_l01Ql00ol01R3o00HOo`067`0Uo`067`[ooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo
0Ol00001ooooo`7ooooo000]ooooo`03o`000?oooooooooo04Oooooo00Co0000oooooooooooooooo
7Ol01Ql4o`0680;o00HO1_l01R08o`078003o`078Ol01b3o00LQ00Ko00LQ0ol000000ol01b7o00PQ
o`088@04o`078@03o`088Ol022;o00PQ01Co00PR1_l02B<00ol02BCo00XTo`0:9002o`0:90Oo00/U
0_l02bH00ol032Ko00`Wo`0=9`02o`0=9`03o`0=:?l03RSo00hX00Co00lY00Go010Zo`0A:ol04Rco
018/o`0C;002o`0C;@0=o`0D;_l05Bko01D^o`0G<?l06C7o01/co`0S>?l09c_o0350o`12B?l0=T?o
04m>o`0mA`02o`1AC@03o`18Bol0Cdko059=00Go05A<00?o059=o`1?C_l0FdL00_l0ET/01_l0DDgo
05I;o`1FBol0Cdko05M:o`1@CP;o05M:00Go04m>o`1FBol0DDgo055=o`1FB`02o`1?CP0;o`11B?l0
@dWo04E:o`13BOl0@DSo03M4o`0b@Ol09CWo01`do`0J<_l063400_l05c02o`0F;`04o`0E;ol05Bko
01@^o`0C;@;o018/0_l04B/01?l042[o00lYo`0?:Ol03bT3o`0>:003o`0=:?l03BOo00dW00?o00`V
1ol02bD3o`0:9003o`099?l02B?o00TS00Wo00TS5?l022800ol0227o00LQo`078@0<o`078@So00LP
00?o00HPo`078?l01R002_l01R000ol0003o00HOo`068009o`0682[o00HO2_ooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`00
00?ooooo000]ooooo`03o`000?oooooooooo04Sooooo00Co0000oooooooooooooooo5ol01Ql00ol0
1R3o00HOo`067`03o`067`04o`068?l01Qoo00HPo`0680;o00HO1?l01R0=o`0780;o00LQ0ol00005
o`078@03o`088Ol01b7o00LQ00Co00LQ00?o00PQo`088_l022804_l02286o`098`;o00TT1Ol02R@5
o`0;9@04o`0;9_l032Ko00`Vo`0<9P;o00dW00?o00dXo`0>:?l03RP00_l03RP4o`0?:@03o`0@:_l0
4B_o018/00?o018/00?o01<]o`0D;Ol05Bh00_l05c02o`0K<`04o`0W>ol0>4Co0350o`12B0;o04m>
0_l0DDd01?l0ET_o04m>o`1BCOl0DTd4o`1DC003o`1BCOl0FdOo05]700;o05I;00?o055=o`1FBol0
ET/00_l0EdX00ol0D4ko05M:o`1GBP02o`1FB`03o`1ACOl0ET_o05I;00;o04m>00_o04=9o`15B_l0
@dWo04=9o`0mA_l0=dCo0310o`0U>Ol073Co01Pao`0G<002o`0F;`05o`0E;ol05Bko01@^o`0D;Ol0
4bd00_l04R`00ol04B_o010[o`0@:P02o`0?:@03o`0>:Ol03RSo00hX00;o00hX0_l03BL01?l032Oo
00`Vo`0<9_l032H6o`0;9@?o00XT00?o00TTo`098ol02B<02Ol02B<Bo`088P?o00PQ3_l01b4;o`07
80co00HP00?o0000o`068?l01R001ol01R07o`067`;o00HP8ol01Ql:ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Kooooo
000]ooooo`03o`000?oooooooooo04Wooooo00Co0000oooooooooooooooo4ol01Ql5o`0680Oo00HO
2?l01R0;o`0780?o00003_l01b400ol0227o00PRo`088P0Co`088P03o`088ol02B?o00TS00Co00TS
0_l02B@4o`0:90Ko00/U1?l032H2o`0=9`03o`0=:?l03RSo00hX00?o00hX0_l03bT2o`0@:P?o014[
00Go018/o`0C;?l04bco01<]o`0E;P02o`0G;`04o`0I<Ol083Ko0391o`0hA0;o049800Go04m>o`18
C?l0DDgo05I;o`1KA`02o`1BC@Co05A<00?o059=o`1KAol0FdL00_l0ET/2o`1LAP03o`1FBol0Ed[o
05M:00?o05M:0_l0ET/04?l0DDgo05I;o`1FBol0Cdko059=o`1DC?l0AD[o04=9o`11B?l0=dCo03Q4
o`0/?Ol083Ko01Xbo`0H<Ol05c02o`0F;`;o01@^0_l04bd2o`0B;0;o014[0_l042X2o`0?:@;o00hX
1?l03BL4o`0<9PGo00/U1Ol02R@2o`0990[o00TS4?l022800ol0227o00LQo`078@0@o`078@03o`07
8?l01b7o00LP00Wo00LP3?l01R000ol0003o00HPo`068006o`0680Oo00HO0ol01R0So`067`Sooooo
0ol00006ooooo`;o00002_ooool2o`0000;ooooo1Ol00002ooooo`00;Oooool00ol0003ooooooooo
o`1:ooooo`04o`000?oooooooooooooooa;o00HO1_l01R05o`067`[o00HP1ol01b03o`00017o00LQ
00?o00PQo`088_l022804?l022800ol022?o00PRo`088`05o`098`Co00TT1Ol02R@3o`0;9@;o00/V
0ol032H3o`0=9`03o`0=:?l03RSo00hX00?o00hX0ol03bT2o`0@:P05o`0A:ol04Rco018/o`0B;?l0
4bd00_l052d2o`0E;P;o01Ta00Wo02Hjo`0hA?l0@TSo051>o`1?C_l0ET_o055=o`1FBol0FdL00_l0
GTD3o`1DC004o`1Q@_l0GTGo05]7o`1KA`;o05I;0_l0G4H00ol0ET_o05M:o`1GBP03o`1GBP03o`1F
Bol0G4Ko055=00;o05I;00?o04m>o`1BCOl0E4`00_l0E4`02ol0@DSo04Q<o`0d@_l07SGo01Tbo`0H
<Ol05c3o01H_o`0E;_l052go01<]00;o018/00Go014/o`0A:ol04B_o010[o`0@:P02o`0?:@;o00hX
00?o00dXo`0=9ol03BL02?l032H4o`0;9@Go00XT0_l02B@8o`098`03o`088ol022;o00PR00ko00PR
0_l02244o`078@;o00PQ3ol01b4:o`0780co00HP00?o0000o`068?l01R001?l01R07o`067`Go00HP
8_l01Ql6ooooo`;o00000_ooool00ol0003oooooooooo`0Kooooo`00;Oooool00ol0003ooooooooo
o`1;ooooo`04o`000?ooooooooooooooo`_o00HO00?o00HPo`067ol01Ql02_l01R03o`067`_o00HP
1?l01b03o`0000?o00LP3Ol01b45o`088A;o00PR00?o00PSo`098ol02B<01_l02B<4o`0990Co00XT
00Co00XUo`0;9Ol02bGo00/U1Ol032H2o`0=9`Oo00hX1?l03bT00ol042[o014[o`0B;002o`0B;0;o
01<]00go01@^o`0F;ol05c3o01Tao`0K<ol0=dCo04Q<o`1@C_l0Cdko05I;o`1ACOl0ET_o05]700;o
05i500Go0652o`1R@Ol0HD;o0652o`1NA@02o`1KA`;o05I;0_l0G4H2o`1P@`06o`1GB_l0HD;o05M:
o`1P@ol0ET_o05a60_l0ET/00ol0FdOo059=o`1DC003o`1DC008o`1?C_l0B4co02`mo`0K<ol06C;o
01P`o`0G;ol05Rl2o`0C;@;o018/0_l04B/2o`0@:P?o00lY0_l03RP2o`0=9`03o`0<9ol032Ko00`V
00Ko00`V0ol02bD00ol02RGo00XTo`0:9006o`0:9003o`099?l02B?o00TS00Ko00TS4?l02282o`08
8@Co00LQ1?l0224Ao`078@Oo00LP2ol01R000ol0003o00HPo`068005o`068004o`067ol01R3o00HO
o`067`Oo00HP8ol01Ql:ooooo`03o`000?oooooooooo01[ooooo000]ooooo`03o`000?oooooooooo
04cooooo00Ko0000ooooooooooooooooo`067ol01R06o`067aKo00HP0_l01b000ol01R3o00LPo`06
8003o`0680?o00001Ol01b0?o`078@;o00PQ4_l022800ol022?o00TSo`098`08o`098`Go00TT0ol0
2R@4o`0;9@03o`0;9_l032Ko00`V00?o00`V0ol03BL6o`0>:0?o00lY0_l042X01?l04B_o018/o`0B
;?l04R`2o`0C;@0:o`0D;_l05Roo01L`o`0G<?l0=dCo04Q<o`1@C_l0Ed[o05I;o`1AC@;o05I;0_l0
GTD01?l0HD;o0691o`1Q@_l0HD82o`1NA@03o`1KAol0ET_o06=100;o05a60_l0H4<2o`1Q@P04o`1G
B_l0H4?o05I;o`1LAP;o05I;00?o05]7o`1NAOl0E4`00ol0E4`02Ol0Cdko04Q<o`0J<_l06C7o01L`
o`0F;ol05Boo01@^o`0C;@02o`0B;0;o014[0ol042X2o`0?:@;o00hX0_l03BL9o`0<9P03o`0;9_l0
2bGo00/U00;o00/U2?l02R@2o`0990Oo00TS3ol022800ol0227o00LQo`078@04o`078@Co00PQ4ol0
1b45o`0780_o00HP00?o00HOo`000?l01Ql03Ol01R000ol01Qoo00HPo`067`09o`067`03o`068?l0
1Qoo00HO01Oo00HO2oooool00ol0003oooooooooo`0Iooooo`00;?ooool00ol0003oooooooooo`1>
ooooo`04o`000?ooooooooooooooo`;o00HP1?l01QlGo`0680Co00LP00Co00HPo`000?l0003o0000
2Ol01b0?o`078A?o00PR00?o00PSo`098ol02B<03?l02B<2o`0990?o00XT0ol02bD6o`0<9PCo00dW
00?o00dXo`0>:?l03RP00ol03RP3o`0?:@04o`0@:_l04B_o014[o`0B;0?o01<]0_l052h01?l05Roo
01L`o`0I<Ol0B4`2o`1@CP04o`1FBol0G4Ko05I;o`1FB`;o05i500?o0652o`1R@Ol0HD800_l0HD80
1?l0GTGo05]7o`1S@Ol0Hd42o`1LAP;o06130_l0HD802?l0Ed[o0613o`1LA_l0G4Ko06=1o`1FBol0
FdOo05i50ol0E4`02Ol0DTgo055=o`0d@_l06C7o01Pao`0E;ol05Bko01@]o`0C;@02o`0B;003o`0A
:ol042_o010Z00;o00lY00?o00hYo`0>:?l03RP01?l03BL5o`0<9P?o00/V1Ol02bD:o`0:9003o`09
9?l02B?o00TS00Ko00TS00?o00PRo`088ol022802ol02282o`088@?o00LQ1Ol0224Co`078@Oo00LP
00?o00HPo`078?l01R002?l01R000ol01Qoo0000o`067`08o`0680ko00HO0ol01R0Jo`067`[ooooo
00?o0000ooooooooool06Oooool002cooooo0ol0001?ooooo`03o`000?oooooooooo00;ooooo00Co
00HPo`067ol01R3o00HO5_l01R000ol01b3o00HPo`078003o`0000Co00HP2Ol01b0=o`078@03o`08
8Ol022;o00PR017o00PR0_l022<>o`098`;o00TT0ol02R@3o`0;9@03o`0;9_l02bGo00`V00Go00`V
1Ol03BL3o`0>:0?o00lY00Co010Zo`0A:ol04Rco018/0_l04b`02?l04bgo01@^o`0E;ol05Boo01L`
o`18C?l0Ed[o051>0_l0ET/01_l0Hd7o05I;o`1KAol0GTGo0652o`1R@@?o065200Ko05i5o`1KAol0
Hd7o06=1o`1LA_l0J3/2o`1P@`;o06520_l0H4<2o`1LAP05o`1S@Ol0FdOo05]7o`1NAOl0HD800_l0
E4`00ol0Cdko055=o`0G<002o`0F;`;o01@^0_l04bd2o`0B;003o`0A:ol042_o010Z00;o00lY00?o
00hYo`0>:?l03RP00ol03BL01?l032Oo00`Vo`0<9_l032H2o`0;9PSo00/U2Ol02R@2o`0990[o00TS
3Ol022800ol0227o00LQo`078@02o`078@03o`088Ol01b7o00LQ01?o00LQ0ol01b000ol01b7o00LP
o`078006o`0780Oo00HP00?o00HOo`000?l01R001Ol01R0_o`067`[ooooo00?o0000ooooooooool0
6?ooool002cooooo00?o0000ooooooooool0D?ooool01?l0003ooooooooooooooolJo`0680?o0000
2Ol01R08o`078003o`078Ol01b3o00LQ00[o00LQ00?o00PQo`088_l022801Ol022800ol0227o00PR
o`088P09o`088P03o`088ol02B?o00PS00?o00TS0_l022<00ol022;o00PSo`098`06o`098`04o`09
9?l02RCo00XTo`0:90Go00/U00?o00/Vo`0<9_l02bD01?l032H01?l032Oo00dWo`0=9ol03BL3o`0>
:003o`0>:Ol03RSo00lY00;o010Z0_l04B/4o`0B;007o`0C;Ol052ko04m>o`18C?l0Ed[o0613o`1F
B`02o`1S@@05o`1KAol0GTGo0652o`1Q@_l0HT400_l0HD801Ol0GTGo06Tio`1S@Ol0Hd7o05a600;o
06Pk00?o0613o`1Q@_l0HD800_l0H4<01?l0J3_o05a6o`1S@Ol0FdL2o`1NA@05o`1Q@_l0E4co05A<
o`1KAol0B4`00_l052h01Ol04bgo01@]o`0C;Ol04bco018/00;o014[00?o010Zo`0?:Ol03bT01?l0
3RP00ol03BSo00dWo`0=9`02o`0=9`?o00`V00?o00/Vo`0;9Ol02bD01Ol02bD00ol02RGo00XTo`0:
9008o`0:90;o00TT2ol02B<=o`088P03o`088Ol01b7o00LQ01Ko00LQ00?o00LPo`078Ol01b400_l0
1b46o`0780_o00HP00?o0000o`068?l01R000_l01R0ao`067`[ooooo00?o0000ooooooooool05ooo
ool002cooooo00?o0000ooooooooool0DOooool01?l0003ooooooooooooooolGo`0680;o00003Ol0
1R0;o`0780[o00LQ00Co00PQo`078Ol0227o00PR1Ol0224>o`088P03o`088ol022;o00PR00Co00PR
1_l02B<2o`0990?o00XT2?l02bD2o`0;9P03o`0<9_l032Oo00`W00?o00dW00?o00dXo`0>:?l03RP0
0_l03RP2o`0?:@;o010Z0ol04B/01_l04Rco014[o`0B;?l04bgo055=o`1GBP;o06130_l0Hd401Ol0
FdOo05i5o`1Q@_l0HD;o069100;o065200Co05i5o`1Y>Ol0JCWo06=10ol0J3/01_l0H4?o0652o`1Q
@_l0JcOo0613o`1X>`;o06=100?o06Tio`1NAOl0GTD00_l0HD801_l0GTGo05]7o`1?C_l04bgo01</
o`0C;@;o018/0_l04B/3o`0@:P;o00lY1?l03RP01Ol03BSo00dWo`0=9ol03BOo00`W00?o00`V2Ol0
2bD6o`0:90?o00TT3Ol02B<=o`088P03o`088Ol01b7o00LQ01Ko00LQ00?o00LPo`078Ol01b401?l0
1b44o`0780co00HP00?o00HOo`000?l01Ql0<ol01Ql:ooooo`03o`000?oooooooooo01Oooooo000/
ooooo`03o`000?oooooooooo05;ooooo00Co0000oooooooooooooooo1?l01R001?l01Qoo00HPo`06
7ol01Ql;o`0680?o00003ol01R08o`078004o`068?l01b3o00LPo`0780co00LQ00?o00PQo`078Ol0
1b400ol01b4Do`088P;o00PS1Ol02B<3o`0990Go00XT1_l02bD00ol02bKo00`Vo`0<9P05o`0=9`05
o`0=:?l03RSo00hXo`0>:?l03RT00_l03RP01Ol03bWo010Zo`0@:_l04B_o010Z00;o014[00Wo018/
o`1ACOl0Ed[o05M:o`1P@ol0G4Ko06=1o`1Y>Ol0GTD00_l0HD801?l0HT7o0652o`1Q@_l0KS<2o`1Y
>@04o`1S@Ol0J3_o06Pko`1X>`;o06/g00Co0652o`1[=ol0J3_o06Pk0_l0Hd400ol0JCWo05i5o`1Q
@P02o`1Q@P03o`1NAOl0DDgo018/00?o018/0_l04B/2o`0@:P?o00lY0ol03RP3o`0=:0Go00dW0ol0
32H8o`0;9@04o`0:9Ol02RCo00XTo`0:90Co00TT3_l02B<00ol022?o00PRo`088P0;o`088Q_o00LQ
00?o00LPo`078Ol01b401_l01b0<o`0680;o00HO00?o0000o`067ol01Ql0<_l01Ql:ooooo`03o`00
0?oooooooooo01Kooooo000/ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool00_oo
ool00ol01R3o00HOo`067`03o`067`So00HP0ol0000Co`0680Ko00LP0ol01R03o`07817o00LQ00?o
00PQo`088_l022804?l02282o`088`Ko00TS1?l02B@5o`0:90Go00/U00Co00/Vo`0<9_l032Ko00`V
1Ol03BL2o`0=:0Co00hX0ol03bT3o`0@:P?o014[00Oo05M:o`1Q@_l0H4?o06Pko`1S@Ol0JCWo06hc
00;o065200Co0691o`1Q@_l0LBoo06hc0_l0JCT01?l0Hd7o06Pko`1X>ol0J3/4o`1[=`;o06Pk0_l0
Hd401ol0JCWo05i5o`1Q@_l0HT7o0652o`1NAOl0DDd00ol04B/2o`0@:PCo00lY1Ol03RP00ol03BSo
00dWo`0=9`04o`0=9`?o00`V2Ol02bD4o`0:90oo00TS3_l02282o`088A?o00LQ00?o00LPo`078Ol0
1b401?l01b4;o`0780_o00HP0ol01Ql00ol0003o00HOo`067`0co`067`Wooooo00?o0000oooooooo
ool05_ooool002_ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`02ooooo`Ko00HO
1?l01R03o`00017o00HP0_l01b06o`0680?o00LP00?o00HPo`078?l01b000ol01b0?o`078@?o00PQ
4_l022800ol022?o00TSo`098`05o`098`Go00TT1?l02R@5o`0;9@03o`0;9_l032Ko00`V00;o00`V
1_l03BL01?l03BSo00dWo`0=9ol03BL3o`0>:0?o00lY00[o010Zo`0A:ol042[o05a6o`1Q@_l0H4?o
06Pko`1S@Ol0JCWo06hc0_l0LBl00ol0HT7o074_o`1a;`02o`1^<`03o`1Y>Ol0L33o070`00;o06Pk
1?l0JcL2o`1X>`0:o`1S@Ol0JCWo06Tio`1^<ol0HD;o0691o`1Q@_l0GTGo04m>o`0@:PKo00lY1Ol0
3RP7o`0=9`Go00`V2?l02bD3o`0:9003o`099?l02B?o00TS00[o00TS0_l022<?o`088P?o00PQ3ol0
1b48o`078003o`078Ol01b3o00LP00[o00LP2ol01R05o`067`03o`000?l01Qoo00HO03;o00HO2_oo
ool00ol0003oooooooooo`0Eooooo`00:oooool00ol0003oooooooooo`1Fooooo`04o`000?oooooo
ooooooooo`Oo00HO0ol0000Do`0680;o00LP1ol01R08o`0780ko00LQ0_l0224Bo`088P03o`088ol0
2B?o00TS00So00TS0_l02B@00ol02B?o00TTo`099005o`0:90?o00/U0_l02bH4o`0<9P_o00dW0ol0
3RP3o`0?:@08o`0@:_l0G4Ko0652o`1P@ol0J3_o06=1o`1Y>Ol0KS<2o`1a;`03o`1b;?l0LBoo074_
00;o06hc00Go06Tio`1`<?l0L33o06Pko`1e:004o`1[=`;o06Pk00Co070`o`1Y>Ol0JCWo06hc0_l0
HD800ol0GTGo05I;o`0?:@04o`0?:@Go00hX00Go00dXo`0=9ol03BOo00dWo`0<9`03o`0=9`Ko00`V
00?o00/Vo`0;9Ol02bD00ol02bD6o`0:9003o`099?l02B?o00TS00[o00TS00?o00PSo`088_l02280
3?l02283o`088@oo00LQ4Ol01b03o`0680Co00LP2_l01R06o`067`03o`000?l01Qoo00HO03;o00HO
2_ooool00ol0003oooooooooo`0Dooooo`00:oooool00ol0003oooooooooo`1Gooooo`;o00000_oo
ool3o`067`?o000000?o00HOo`068?l01R004_l01R05o`0780Go00HP2Ol01b0=o`078@;o00PQ4_l0
2282o`088a3o00TS00?o00TTo`0:9?l02R@00_l02R@2o`0;9@;o00/V2?l032H01Ol032Oo00`Vo`0<
9_l032Ko00`W00;o00`V00?o00dWo`0<9_l03BL00ol03RP02?l03bWo06=1o`1Q@_l0JcOo06Pko`1`
<?l0JCWo06hc0_l0LBl00ol0LRco074_o`1a;`02o`1^<`05o`1Y>Ol0L33o070`o`1X>ol0MBP01?l0
JcL00ol0MBSo06Pko`1`<002o`1Y>@06o`1^<ol0HD;o0652o`1NAOl0Hd7o00lY2Ol03RP3o`0=9`03
o`0<9ol032Ko00`V00Oo00`V0_l02bH4o`0;9@03o`0:9Ol02RCo00XT00?o00XT00?o00TTo`098ol0
2B<01_l02B<00ol022?o00TSo`088P0@o`088P03o`088Ol01b7o00LQ00go00LQ00?o00LPo`078Ol0
1b003Ol01b09o`0680;o00LP2Ol01R08o`067`03o`000?l01Qoo00HO03;o00HO2Oooool2o`0001Go
oooo000[ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooool000000_l000001?l01Qoo00HP
o`067ol01Ql@o`0680_o00LP1?l01R05o`078003o`078Ol01b3o00LP00ko00LQ00?o00PQo`088_l0
22804Ol022800ol022?o00TSo`098`06o`098`03o`088ol02B?o00TS00Ko00TS00Co00TTo`0:9?l0
2RCo00XT2?l02bD00ol032Ko00/Uo`0<9P0;o`0<9P03o`0=9ol03BSo00hX00;o00hX00Co06/go`1Q
@_l0J3_o070`0_l0JCT2o`1a;`03o`1b;?l0LBoo074_00;o06hc00Ko07PSo`1`<?l0L33o06Pko`1e
:?l0JcL2o`1g9@04o`1[=ol0MBSo070`o`1`<0;o06Ti00Go06hco`1R@Ol0HD;o05i5o`1S@@08o`0>
:003o`0=:?l03BOo00dW00Go00`V00Ko00/Uo`0;9_l02bKo00`Vo`0;9Ol02bH5o`0;9@So00XT0_l0
2B@5o`098`03o`088ol022;o00PR017o00PR00?o00PQo`078Ol01b403?l01b4<o`078004o`068?l0
1b3o00LPo`0780_o00HP0_l01b05o`068006o`067ol01R3o00HPo`068?l01Qoo00HP1_l01Ql00ol0
003o00HOo`067`0bo`067`Sooooo00?o0000ooooool000005Oooool002_ooooo0_l0001Iooooo`?o
00000ooooolAo`0681Go00LP0ol01b44o`078003o`078Ol01b3o00LQ00[o00LQ5?l022800ol022?o
00TSo`088`02o`098`03o`088ol022;o00PR00;o00PR00?o00TSo`088_l02B<01Ol02B<2o`0990;o
00XT3Ol02bD00ol032Ko00/Vo`0<9P05o`0<9PCo00dW00?o00hXo`1LA_l0HD800_l0J3/2o`1Y>@05
o`1^<ol0LBoo078/o`1b;?l0LBl00_l0KS<2o`1h8`04o`1`<?l0MBSo07DXo`1[=`;o07LU0_l0MBP2
o`1`<006o`1Y>Ol0KS?o074_o`1b;Ol0LBoo06hc1?l03RP00ol03BSo00hXo`0>:004o`0=9`Co00`V
00?o00/Vo`0;9Ol02bD01ol02bD6o`0:9003o`099?l02RCo00TT00?o00TT1Ol02B<=o`088P03o`08
8Ol022;o00PR00?o00PQ00?o00PRo`078Ol01b403_l01b4;o`0781Co00HP1Ol01Ql5o`0680Ko00HO
00?o0000o`067ol01Ql0<_l01Ql:ooooo`03o`000?oooooooooo01;ooooo000[ooooo`03o`000?oo
oooooooo05Gooooo0ol00003ooooo`04o`000?ooooooooooooooo`oo00HP2ol01b000ol01R3o00LP
o`078009o`078003o`078Ol01b3o00LP00Ko00LP2ol01b42o`088@;o00PR0_l022400ol022;o00PQ
o`088P0Fo`088POo00TS00?o00TTo`0:9?l02R@00_l02R@00ol02RGo00/Uo`0;9@09o`0;9@;o00/V
1ol032H2o`0=9`08o`0>:?l0Hd7o06/go`1e:?l0J3_o07PSo`1Y>Ol0KS<2o`1a;`04o`1b;?l0LBoo
06hco`1n60;o07PS00Co070`o`1e:?l0MBSo06/g0_l0MbD2o`1e:0;o070`00Oo07PSo`1^<ol0LBoo
078]o`1a;ol0KS?o00dX00Wo00dW1?l032H00ol02bKo00/Uo`0;9@06o`0;9@Co00XT0ol02B@2o`09
8`03o`099?l02B?o00TT00;o00TT1?l02B<00ol022?o00PRo`088P09o`088P05o`088Ol01b7o00LQ
o`078Ol022404ol01b401_l01b3o00LQo`078Ol01b7o00LPo`078@Go00LP5_l01R02o`067`Oo00HP
1ol01Ql00ol0003o00HOo`067`0ao`067`[ooooo00?o0000ooooooooool04_ooool002[ooooo00?o
0000ooooooooool0Doooool3o`0000Oooooo00?o0000ooooooooool04?l01R07o`0780Ko00HP4_l0
1b000ol01b7o00LPo`078@0;o`078@03o`088Ol01b7o00LQ00?o00LQ5_l022800ol022?o00TSo`09
8`04o`098`;o00TT1Ol02R@<o`0;9@03o`0;9_l032Ko00`V00Go00`V00Ko00`Wo`0=9ol0Hd7o06/g
o`1e:?l0J3/2o`1h8`05o`1^<ol0LBoo074_o`1b;?l0LBl00_l0OQP2o`1h8`03o`1`<?l0MBSo07DX
00?o07LU0_l0MBP02ol0L33o07PSo`1h8ol0KS?o074_o`1b;Ol0LBoo06hco`0=9ol032Oo00dW00;o
00`V00Co00dWo`0<9_l032Ko00`W1?l032H6o`0;9@Ko00XT0_l02B@=o`098`03o`088ol022;o00PR
00[o00PR00?o00PQo`078Ol01b406ol01b45o`0781oo00HP1ol01Ql00ol0003o00HOo`067`0bo`06
7`[ooooo00?o0000ooooooooool04Oooool002[ooooo00?o0000ooooooooool0DOooool2o`0000_o
oooo00Co0000oooooooooooooooo0_l01R03o`067`[o00HP1Ol01b09o`0680ko00LP00Co00HPo`07
8?l01b3o00LP4_l01b400ol0227o00PRo`088P0Do`088PGo00TS0ol02B@6o`0:90_o00/U0_l02bH9
o`0<9P;o06/g00Co07DXo`1h8ol0N2?o07hH0_l0LBl01?l0LRco074_o`1n6?l0OQP2o`1h8`03o`1o
5_l0MBSo07DX00?o07LU0_l0MBP02?l0L33o07PSo`1h8ol0KS?o074_o`1b;Ol0LBoo06=13Ol032H4
o`0;9@Ko00XT0ol02B@=o`098`03o`088ol022;o00PR00[o00PR00?o00PQo`078Ol01b407Ol01b45
o`078003o`068?l01b3o00HP00Oo00HP1?l01Ql<o`068004o`067ol01R3o00HPo`0680So00HO00?o
0000o`067ol01Ql0<_l01Ql:ooooo`03o`000?oooooooooo013ooooo000Zooooo`03o`000?oooooo
oooo04kooooo0ol0000>ooooo`05o`000?ooooooooooooooool01R001?l01Ql;o`068003o`078?l0
1R3o00HP00Wo00HP1_l01b03o`0680Co00LP00?o00HPo`078?l01b000ol01b0?o`078@?o00PQ5_l0
2285o`098`?o00TT00?o00XTo`099?l02R@01Ol02R@00ol02bGo00XTo`0:9@03o`0:90Oo00/U00go
00`Vo`0;9Ol02bGo00/Uo`0;9_l02bGo00`Vo`1e:?l0MbGo07DXo`1`<?l0N2?o07hH00;o088A00Co
078/o`224Ol0OQSo07hH0_l0N2<2o`1o5P07o`1e:?l0MbGo07LUo`1g9Ol0MBSo07lFo`1`<002o`1h
8`;o074_00?o078]o`1a;ol0L3000_l032H2o`0;9@05o`0;9_l02bGo00/Vo`0<9_l02bD00_l032H4
o`0;9@Ko00XT0ol02B@7o`098`04o`088_l022?o00PSo`098`;o00PR00?o00PSo`088_l022803Ol0
228Po`078@Oo00LP2?l01R03o`067`Wo00HP1Ol01Ql3o`0680So00HO00?o0000o`067ol01Ql0<Ol0
1Ql:ooooo`03o`000?oooooooooo013ooooo000Zooooo`03o`000?oooooooooo04_ooooo0ol0000B
ooooo`04o`000?ooooooooooooooo`Go00HO5Ol01R06o`0780Ko00HP2Ol01b0>o`078@03o`088Ol0
22;o00PR01Ko00PR00?o00PSo`098ol02B<02?l02B<00ol02BCo00TSo`099008o`0:9003o`0;9Ol0
2RCo00/U00_o00/U00Ko070`o`1[=ol0MBSo070`o`1h8ol0OQP2o`224@04o`233Ol0PQ7o07hHo`1n
60;o07PS0_l0OaH01_l0MBSo08<>o`1g9Ol0P`ko07DXo`1o5P?o07PS00Ko074_o`1b;Ol0LBoo06hc
o`0<9_l02bH<o`0;9@Go00XT1_l02B@6o`098aOo00PR0_l0224Oo`078@Wo00LP4Ol01R06o`067`?o
00HP2?l01Ql00ol0003o00HOo`067`0ao`067`[ooooo00?o0000ooooooooool03oooool002[ooooo
00?o0000ooooooooool0B?ooool3o`0001Kooooo00Co0000oooooooooooooooo1Ol01QlCo`0680So
00LP1Ol01R08o`0780ko00LQ00?o00PQo`088_l022806?l022800ol022?o00PRo`098`0<o`098`03
o`099?l02RCo00XT00Wo00XT00?o00/Uo`0:9Ol02bD01Ol02bD01_l0L33o06/go`1e:?l0OaKo07PS
o`1n60;o088A00Ko08<=o`224Ol0PQ7o07hHo`1h8ol0R082o`1o5P;o08<>00Co07LUo`233_l0MBSo
07lF0_l0N2<01Ol0OAWo084Ao`1b;Ol0LBoo06Ti00So00/U00?o00XTo`0;9Ol02R@01?l02R@3o`09
9003o`098ol02BCo00TT00Co00TT1?l02B<00ol022?o00PRo`088P0Go`088P;o00PQ8?l01b49o`07
80ko00HP1_l01Ql6o`0680Ko00HO00?o0000o`067ol01Ql0<_l01Ql8ooooo`?o00004?ooool002[o
oooo00?o0000ooooooooool0AOooool3o`0001[ooooo00Co0000oooooooooooooooo1Ol01Ql=o`06
8003o`078?l01R3o00HP00_o00LP00Co00HPo`078?l01R3o00HP2?l01b0>o`078@03o`088Ol022;o
00PR01co00PR3?l02B<00ol02BCo00XTo`0:900;o`0:9003o`0;9Ol02RCo00/U00;o00/U00Ko070`
o`1e:?l0MBSo07lFo`1h8ol0OQP2o`224@06o`233Ol0PQ7o088Ao`1n6?l0N2?o08P20_l0OaH2o`23
3P04o`1g9Ol0P`ko07lFo`1o5P;o07PS00Go07dIo`214Ol0LRgo074_o`1h8`04o`0;9@Wo00XT0ol0
2B@=o`098`03o`088ol022;o00PR01So00PR0_l0224Po`078@So00LP3Ol01R07o`067`Go00HP2?l0
1Ql00ol0003o00HOo`067`0bo`067`Cooooo0ol00002ooooo`03o`000?oooooooooo00kooooo000Y
ooooo`04o`000?oooooo0000o`0004;ooooo0ol0000Nooooo`04o`000?oooooooooooooooa3o00HP
5ol01b02o`078@Co00LP3Ol01b42o`088Ako00PR00?o00TSo`088ol02B<01ol02B<2o`0991;o00XT
0_l0MBP01_l0OaKo07PSo`1n6?l0OQSo088Ao`233@;o088A00Go07hHo`1h8ol0R0;o08P2o`1o5P04
o`233P;o07lF00So08P2o`1h8ol0OAWo084Ao`233Ol0PA7o07PSo`0;9@Wo00XT0ol02B@Ao`098`03
o`088ol022;o00PR01So00PR00?o00PQo`078Ol01b407_l01b4<o`0780Wo00HP00?o00HOo`068?l0
1Ql00ol01Ql4o`0680Wo00HO0_l01R000ol0003o00HOo`067`0_o`067`?ooooo0ol00005ooooo`03
o`000?oooooooooo00kooooo000Yooooo`;o0000@Oooool3o`0002;ooooo00Co0000oooooooooooo
oooo3ol01R0Ho`0780;o00LQ1Ol01b000ol01b7o00LPo`078@0;o`078@08o`088_l0227o00PRo`08
8Ol01b7o00PQo`088_l0224Go`088P03o`088ol02B?o00TS00Ko00TS0_l02B@8o`0:90?o00TT00Co
00TSo`099?l02RCo00TT0_l02R@01?l0MBSo08<>o`1o5_l0R082o`1n6005o`224Ol0P`go08<=o`22
4Ol0OQP00ol0R0800ol0OaKo08<>o`233P02o`233P;o07lF00Ko08P2o`1h8ol0OAWo084Ao`233Ol0
PA47o`0:90Oo00TT1ol02B<00ol022?o00TSo`098`08o`098aWo00PR00?o00PQo`078Ol01b407ol0
1b4;o`0780co00HP4Ol01Ql3o`068003o`000?l01Qoo00HO02[o00HO0oooool4o`0000Sooooo00?o
0000ooooooooool03_ooool00004ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o00001?oo
ool2o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`0mooooo`?o00009_oo
ool00ol0003oooooooooo`02ooooo`ko00HP2Ol01b03o`068003o`078?l01R3o00LP01;o00LP2ol0
1b44o`088@Go00LQ00?o00PQo`088_l022805?l0228:o`098`03o`099?l02RCo00XT00;o00XT0ol0
2B@8o`098`05o`099?l0MBSo07LUo`1o5_l0R0800_l0OQP01Ol0PQ7o08<=o`233Ol0PQ7o07hH00?o
08P200?o07lFo`233_l0P`h00_l0P`h2o`1o5P07o`280_l0OAWo084Ao`214Ol0P`go084Ao`0:9002
o`099003o`0:9?l02B?o00TT00?o00TS1?l02B@5o`098`04o`088ol022;o00PSo`088P;o00PS1ol0
2B<00ol022?o00PRo`088P0Go`088P03o`088Ol01b7o00LQ01Ko00LQ0ol01b001?l01b7o00LPo`07
8?l01b4=o`0780go00HP4ol01Ql00ol0003o00HOo`067`0Wo`067`?ooooo0ol0000<ooooo`03o`00
0?oooooooooo00kooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo03[ooooo0ol0
000Zooooo`04o`000?ooooooooooooooo`Go00HP00?o00HOo`068?l01R001Ol01R000ol01b3o00HP
o`078005o`0780Oo00HP3ol01b03o`0680;o00LP4_l01b42o`088AKo00PR00?o00TSo`088ol02B<0
1ol02B<01Ol02BCo00TSo`098ol02B?o00TT00co00TS00Co07PSo`233_l0OaKo08P20_l>S`001Ol0
PQ7o08<=o`233Ol0PQ7o3Xl000?o08P20_l<S`03o`233P04o`b?0?l0R0;o08P2o`1m6@?o084A00?o
07hIo`098ol02B<01ol02B<00ol02BCo00TSo`098`06o`098`03o`088ol022;o00PR00;o00PR00?o
00PSo`088_l02B<01Ol02B<00ol022?o00PRo`088P0>o`088P03o`088Ol022;o00PR00;o00PR1Ol0
2246o`078@03o`088Ol01b7o00LQ00ko00LQ5Ol01b0<o`0681Go00HO00?o0000o`067ol01Ql08ol0
1Ql3ooooo`?o00004?ooool00ol0003oooooooooo`0=ooooo`000_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`0gooooo`?o0000;_ooool2o`0000;ooooo00?o00HPo`067ol01Ql00ol01Ql9
o`068004o`078?l01R3o00LPo`0780Wo00HP1_l01b03o`068003o`078?l01R3o00LP00;o00LP0_l0
1R04o`0781;o00LQ00?o00PQo`088_l022805_l022800ol022?o00TSo`098`0Fo`098`04o`1h8ol0
P`ko07lFo`1o5P;o3Xl000Go088Ao`233Ol0P`go088Ao`j?0003o`280P;o38l000Co08<>oa6A0?l0
P`ko38l00_l0R0801Ol>S`3o084Ao`214Ol0PA7o07PS017o00TS0_l022<7o`088P04o`088ol022;o
00PSo`088a7o00PR00?o00PQo`078Ol022400ol01b46o`088ACo00LQ4_l01b000ol01R3o00LPo`07
8003o`0780Wo00HP6?l01Ql00ol0003o00HOo`067`0No`067`?ooooo1?l0000Cooooo`03o`000?oo
oooooooo00gooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo03Gooooo0_l0000c
ooooo`04o`000?ooooooooooooooo`Co00HO5_l01R05o`0780Oo00HP1ol01b0Co`078@03o`088Ol0
22;o00PR00_o00PR00?o00PQo`088_l022802_l0228Ho`098`03o`233_l<S`3o07lF00;o3Xl000Co
6Y@0o`233OlPUP3o6Y@00_l>S`02o`280P;o38l00_lAT@02o`b?00;o08P200Go3Xl0o`214Ol0P`go
084Ao`1h8`06o`098`04o`088_l02B?o00TSo`088`Wo00TS00?o00PSo`088_l022806?l022800ol0
227o00LQo`078@04o`078@?o00PQ5ol01b4@o`0780Co00HP00Co00LPo`068?l01b3o00LP2Ol01R0H
o`067`03o`000?l01Qoo00HO01_o00HO0oooool3o`0001Oooooo00?o0000ooooooooool03Oooool0
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0<oooool3o`0003Kooooo00Co0000oooo
oooooooooooo1Ol01QlCo`0680Oo00LP1Ol01R08o`07813o00LQ1Ol02249o`088P;o00PQ0_l01b40
1?l0227o00LQo`088Ol02249o`088P_o00TS00?o00PRo`088ol02B<02Ol02B<00ol0P`ko38l0o`1o
5P02o`j?0004oaZD0?lPUP3o89H0oaZD00;o3Xl00_l0R082o`b?00;o4I400_l<S`02o`280P05o`j?
0?lIU03o08<=o`214Ol0R0800ol02B<00ol022?o00PRo`088P05o`088POo00TS00?o00PSo`088_l0
22806Ol02282o`088@Co00LQ00?o00PQo`078Ol01b405Ol01b49o`078003o`068?l01b3o00HP00?o
00LP2_l01R02o`0780Ko00HP00Co00HOo`068?l01R3o00HP6?l01Ql00ol0003o00HOo`067`0Fo`06
7`Cooooo0ol0000Jooooo`03o`000?oooooooooo00gooooo00000ooooooo0000o`000004ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`0`ooooo`?o0000>_ooool00ol0003oooooooooo`05o`067`oo00HP00?o00LPo`068?l0
1R002Ol01b05o`0680So00LP4?l01b43o`088@04o`078Ol0227o00PRo`088@;o00PR1?l02247o`07
8@03o`088Ol022;o00PR00So00PR2?l02B<5o`088P05o`098ol022;o00TSo`098ol022<01?l02B<2
o`233P04o`b?0?l0R0;o3Xl0oaZD00;o89H000Go6Y@0o`j?0?l>S`3o08P2ob^J0002o`b?00;o4I40
0_l<S`02o`280P04o`j?0?lIU03o08<=o`1n6@Co00TS1ol022800ol022?o00PRo`098`05o`098`03
o`088ol022;o00PR01[o00PR0_l0224Ho`078@_o00LP5_l01R04o`067`Co00HP6?l01Ql00ol0003o
00HOo`067`0Bo`067`?ooooo1?l0000Mooooo`03o`000?oooooooooo00gooooo0002ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o0000
1_ooool00ol0003oooooooooo`0]ooooo`?o0000?_ooool01?l0003oooooooooooooool@o`0680ko
00LP1_l01R08o`0781Go00LQ00Co00PQo`078Ol0227o00PQ2_l01b400ol0227o00PRo`088P08o`08
8P03o`088ol02B?o00TS00?o00TS00?o00PSo`088_l022802_l02283o`098`06o`b?0?lAT@3o38l0
o`280_l>S`3o6Y@00_lPUP02oaZD0003o`j?0?l0R0;o:iX000;o38l00_lAT@02o`b?0006o`280_l>
S`3o3Xl0oaVD0?l0PA7o3Xl00_l02B<<o`088P04o`088ol02B?o00PSo`088ako00PR0_l0224Go`07
8@_o00LP3Ol01R02o`067`03o`068?l01Qoo00HP00Co00HP1_l01Ql00ol01R3o00HOo`067`0Io`06
7`03o`000?l01Qoo00HO00oo00HO0_ooool3o`00027ooooo00?o0000ooooooooool03Oooool002So
oooo0ol0000Zooooo`?o0000@_ooool01?l0003oooooooooooooool?o`0680co00LP2Ol01R0;o`07
8003o`078Ol01b3o00LQ01co00LQ0_l0224=o`088P03o`098ol022;o00PR00go00PR0_l02B<01?l0
R0;o08<>o`b?0?l0R082o`j?00;o89H00_lJU0000ol>S`3o08P2ob^J0002o`b?00;o4I400_l<S`00
0ol[VP3o3Xl0o`j?0002oaVD0003o`j?0?l022;o00PR02;o00PR0_l022400ol022;o00PQo`088P06
o`088P03o`088Ol01b7o00LQ00ko00LQ00?o00LPo`078Ol01b401?l01b4<o`0780co00HP;Ol01Ql0
0ol0003o00HOo`067`0;o`067`?ooooo0ol0000Tooooo`03o`000?oooooooooo00gooooo000Xoooo
o`03o`000?oooooooooo02Oooooo0ol00016ooooo`04o`000?ooooooooooooooo`oo00HP1ol01b0>
o`0680ko00LP7?l01b400ol0227o00PRo`088P0Ko`088P06o`088ol02B?o08P2o`233_l<S`3o:iX0
0_l>S`02ob2F00;o6Y@000Go3Xl0ob^J0?l[VP3o38l0ocNN0002oa6A00;o38l000?o:iX0o`j?0?l>
S`000_lIU0000ol>S`3o00PRo`088P0Po`088P;o00PQ0ol01b400ol0227o00PRo`088@03o`088P;o
00PQ3_l01b4Eo`0780co00HP;ol01Ql00ol0003o00HOo`067`07o`067`;ooooo1?l0000Xooooo`03
o`000?oooooooooo00cooooo000Xooooo`03o`000?oooooooooo02Cooooo0ol0001:ooooo`04o`00
0?ooooooooooooooo`?o00HP0_l01Ql9o`0680Go00LP4Ol01R0=o`0780[o00LQ00?o00PQo`078Ol0
1b404?l01b42o`088Aco00PR0_l02B<2o`b?0005ob^J0?l>S`3o3Xl0oaZD0?lPUP000_lJU0001?l>
S`3o:iX0ob^J0?l<S`02ocNN0009oa6A0?lgWP3o:iX0ob^J0?l>S`3o6I@0oanF0?lIU03o3Xl002?o
00PR00?o00PQo`078Ol01b400_l01b401?l0227o00LQo`078Ol0224Ao`078AGo00LP3?l01R0`o`06
7`03o`000?l01Qoo00HO00;o00HO0oooool3o`0002cooooo00?o0000ooooooooool03?ooool002Oo
oooo00?o0000ooooooooool08_ooool3o`0004kooooo00Go0000ooooooooooooooooo`068004o`06
7aoo00HP2ol01b0Oo`078@03o`088Ol01b7o00PQ01[o00PR00Wo00TSo`088_l<S`3o=ih0o`b?0?m3
XP3o3Xl0oaZD0?lPUP000_lJU0001?m3XP3o:iX0ob^J0?l<S`04ocNN00;o:iX000Co3Xl0oaVD0?lO
UP3o6I@09?l022800ol0227o00LQo`078@0Fo`078@go00LP4ol01R0co`067`04o`000?oooooooooo
ooooo`?o0000;oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003oooooooooo`0Ooooo
o`?o0000D_ooool01?l0003oooooooooooooool5o`067aoo00HP00?o00LPo`068?l01b002?l01b0Q
o`078@03o`088Ol022;o00PR01Wo00PR00?o38l0ocNN0?l<S`000_m3XP001OlJU03o89H0oaZD0?lJ
U03o@j8000;o:iX01OlgWP02ob^J0004od>R0?lIU03o7iH0o`j?01So00PR0_l02249o`088P03o`08
8Ol01b7o00LQ01Oo00LQ2ol01b0Co`0683;o00HO0oooool4o`0003;ooooo00?o0000ooooooooool0
3?ooool002Oooooo00?o0000ooooooooool07?ooool3o`0005Kooooo00Co0000oooooooooooooooo
1Ol01QlGo`0680Go00LP1Ol01R07o`0782?o00LQ0ol0224Ho`088P03o`b?0?lgWP3o38l000;o@j80
00Go6Y@0ob2F0?lJU03o6Y@0od>R0002ob^J00Go=ih00_l[VP001?m3XP3o6I@0oanF0?l>S`0Fo`08
8P03o`088Ol01b7o00LQ00;o00PQ2?l022800ol0227o00LQo`078@0?o`078@03o`078?l01b7o00LQ
00?o00LQ3?l01b05o`0680;o00HO2Ol01R0co`067`?ooooo0ol000000ooooooo0000ooooo`0coooo
o`03o`000?oooooooooo00cooooo000Wooooo`03o`000?oooooooooo01Wooooo0ol0001Jooooo`06
o`000?ooooooooooooooool01Qoo00HP0_l01QlGo`0680Co00LP1ol01R000ol01b3o00HPo`078005
o`0782?o00LQ00?o00PQo`078Ol022801Ol02282o`088@03o`088_l0227o00PR00co00PR00?o3Xl0
oa6A0?lgWP000_m3XP001?mDY`3o89H0oaZD0?mDY`02od>R0003ob^J0?lgWP3o=ih000?o=ih000?o
:iX0od>R0?m3XP000_lIU0000ol>S`3o00PRo`088P0Co`088P;o00PQ0ol01b401_l0227o00LQo`08
8Ol01b7o00PQo`088Q7o00LQ4ol01b08o`0680;o00HO2Ol01R05o`067`?o00HP9ol01Ql4ooooo`?o
00001Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`00
0?oooooooooo01Oooooo0_l0001Nooooo`04o`000?oooooooooooooooaco00HP00?o00LPo`068?l0
1R000ol01R000ol01Qoo00HPo`068002o`0680Wo00LP8ol01b401?l0227o00PRo`088Ol02246o`07
8@03o`088Ol01b7o00PQ00[o00PR0_lgWP02od>R0004oeBW0?mMZP3oE:L0oeBW00;o@j8000?o:iX0
ocNN0?lgWP000olgWP001_l[VP3o@j80od>R0?lOUP3o6I@0o`j?01Ko00PR0_l0224Ho`078@?o00LP
0ol01R0<o`0780co00HP0_l01Ql01?l01R3o00HOo`067ol01R07o`067`Ko00HP8ol01Ql2ooooo`Co
00002?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo000Wooooo`03o`00
0?oooooooooo01Cooooo0ol0001Qooooo`03o`000?oooooooooo00;ooooo7ol01R04o`067`?o00HP
2?l01b0_o`078@;o00PQ2Ol02282ocNN0004ob^J0?m3XP3oE:L0oefZ00;oE:L00_m3XP000ol[VP3o
=ih0ocNN0002ocNN0007of6[0?l[VP3o@j80od>R0?lOUP3o6I@0od>R0008o`088P07o`088Ol01b7o
00PQo`078Ol0227o00PRo`088@07o`088Q[o00LQ1?l01b03o`0680Wo00LP2?l01R000ol01b3o00HP
o`068002o`0680oo00HO00Co00HPo`067ol01R3o00HP8Ol01Ql2ooooo`?o00003Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00cooooo000Vooooo`?o00004_ooool3o`0006Gooooo
00Co0000oooooooooooooooo1Ol01R000ol01Qoo00HPo`06800Bo`0680;o00HO00?o00HPo`067ol0
1R000ol01Ql4o`0680Wo00LP9_l01b43o`088@Ko00LQ0_l02244o`088P;o00PQ00So00PRo`088Olg
WP3o=ih0ob^J0?m3XP3oE:L0oefZ00?oE:L000go@j80of6[0?mQZ`3o=ih0ofR]0?lgWP3oHJ/0ob^J
0?m3XP3oE:L0oebZ0?lIU03o@j8000Oo00PR00?o00PQo`078Ol01b400_l01b42o`088@Ko00PR0_l0
224Ho`078@Oo00LP00?o00HPo`078?l01b001?l01b09o`0680?o00LP1Ol01R07o`067`03o`068?l0
1Qoo00HO02Ko00HO0oooool3o`00017ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0;ooooo`009_ooool00ol0003oooooooooo`0?ooooo`?o0000JOooool2o`0000;ooooo0ol01R04
o`067a3o00HP1ol01Ql7o`0680co00LP4ol01b400ol01b3o00LQo`078@0>o`078@Ko00PQ1Ol01b40
1ol0227o00LQo`088Ol0227o00LQo`088Ol01b400_lgWP001?mQZ`3o@j80oeBW0?mMZP03oeBW000<
od>R0?mQZ`3oHJ/0ocNN0?mX[@3o=ih0of6[0?l[VP3o@j80oeBW0?mLZP3oE:L01Ol02284o`088@Go
00LQ0ol022400ol022;o00PQo`088@0Bo`078@03o`078?l01b7o00LP00Co00LP00?o00LQo`078?l0
1b001ol01b02o`068003o`078?l01R3o00HP00[o00HP1?l01b05o`0680;o00HO00?o00HPo`067ol0
1R000ol01R0To`067`;ooooo1?l0000Eooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool02oooool002Kooooo00?o0000ooooooooool03?ooool3o`0006kooooo00Co0000oooooooooooo
oooo1_l01Ql@o`0680Go00HO2?l01R0=o`0781;o00LQ1?l01b0>o`078@Co00PQ3Ol01b42ocNN0004
of6[0?m3XP3oE:L0oefZ00?oE:L000Oo@j80of6[0?mQZ`3o=ih0ofR]0?lgWP3oHJ/000;o@j8000Ko
E:L0oebZ0?mDY`3o00LQo`088Ol02287o`088Aco00LQ2Ol01b03o`078@Co00LP8?l01R0Qo`067`?o
oooo0ol0000Iooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02oooool002Kooooo
00?o0000ooooooooool02Oooool3o`0007;ooooo00Co0000oooooooooooooooo1_l01QlAo`0680Co
00HO2?l01R0>o`07813o00LQ1?l01b0>o`078@03o`088Ol01b7o00LQ00ko00LQ00CoHJ/0ocNN0?mQ
Z`3o@j800_mDY`001?mMZP3oE:L0oeBW0?m3XP02of6[00;oJ:d00_mQZ`02od>R0003oeBW0?mLZP3o
E:L000?o00LQ2?l0224Ho`078@Go00LP00?o00HPo`078?l01b001?l01b03o`078@Co00LP1_l01R00
0ol01b3o00HPo`06800Go`0681oo00HO0_ooool3o`0001gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`06ooooo`?o0000M_ooool00ol0
003oooooooooo`07o`067a3o00HP1?l01Ql<o`068003o`078?l01R3o00LP00Wo00LP3ol01b44o`07
8003o`078Ol01b3o00LQ01co00LQ00?o=ih0of6[0?m3XP000_mDY`001?mMZP3oE:L0oeBW0?n2]002
of6[00;oJ:d00_mQZ`001On2]03o@j80oeBW0?mLZP3oE:L000Co00LQ00?o00PQo`078Ol01b406ol0
1b4Co`078004o`068?l01b3o00HPo`0680Co00LP6ol01R0Io`067`;ooooo1?l0000Qooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool00ooo
ool3o`0007[ooooo00Co0000oooooooooooooooo1?l01Ql=o`0680;o00HO00?o00HPo`067ol01Ql0
1?l01QlAo`0680Go00LP3?l01b400ol01b3o00LQo`078@08o`078003o`078Ol01b3o00LQ01Wo00LQ
00?o=ih0of6[0?n2]0000_mDY`001?mMZP3oE:L0oeBW0?n2]002of6[00;oJ:d00_mQZ`001On2]03o
E:L0oeBW0?mLZP3o@j8001So00LQ0_l01b001?l01b7o00LPo`078?l01b43o`078003o`078Ol01b3o
00LP00Ko00LP00Co00HPo`078?l01b3o00HP4?l01b0Jo`068003o`067ol01R3o00HO017o00HO0_l0
1R02ooooo`?o00009_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo000U
ooooo`04o`000?ooooooooooooooo`?o0000O_ooool01?l0003oooooooooooooool<o`0680oo00HO
3_l01R07o`0780Oo00LQ4?l01b0Ko`078@;oHJ/000CoP[@0oiVj0?mDY`3oGJX00_mDY`02oh:d0003
of6[0?mX[@3oJ:d000;oHJ/000KoP[@0oeBW0?mLZP3oE:L0of6[0?l0224Eo`078@Go00LP00?o00HP
o`078?l01b000ol01b02o`078@Ko00LP1_l01R0@o`0781co00HP4Ol01Ql01?oooooo0000o`000?l0
000Yooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02oooool002Gooooo1?l00022
ooooo`03o`000?oooooooooo00co00HP4Ol01Ql<o`0680So00LP1_l01b46o`078003o`068?l01b3o
00LP00So00LP5_l01b42o`078005o`078Ol01b3oHJ/0of6[0?n2]0000_nI^P000omMZP3oE:L0oiVj
0002oh:d0009of6[0?mX[@3oJ:d0oink0?mQZ`3oP[@0oeBW0?mLZP3oE:L001Oo00LQ0ol01b03o`06
80Go00LP0ol01b44o`0780Ko00HP1ol01b000ol01R3o00LPo`078008o`0781_o00HP3Ol01Ql00ooo
oooo0000o`000002o`0002gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0:oooo
o`009Oooool2o`0008Gooooo00Co0000oooooooooooooooo0ol01R03o`067`03o`068?l01Qoo00HO
00go00HO00?o00HPo`067ol01Ql00_l01Ql<o`0680Wo00LP0_l01b47o`0780Ko00HP1_l01b0Ao`07
8@03o`078?l01b7o00LQ00Oo00LP00?oHJ/0oink0?mQZ`000_nI^P000onU_@3oVKX0oiVj0002oh:d
00;oWk/000OoJ:d0oink0?n2]03oP[@0oiVj0?mLZP3oE:L000go00LQ00?o00LPo`078Ol01b401Ol0
1b46o`0780;o00HP3?l01b001?l01R3o00LPo`068?l01R07o`0780Oo00HP1_l01b0Ko`0680Wo00HO
0_ooool3o`0003;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`009ooo
ool00ol0003oooooooooo`23ooooo`04o`000?ooooooooooooooo`;o00HP4_l01Ql4o`0680Co00HO
2ol01R0@o`0780Ko00HP1ol01b0?o`078@_o00LP00Co00LQof6[0?nO^`3oHJ/00_nI^P000onU_@3o
VKX0oiVj0002oh:d00CoWk/00_n2]0000onI^P3oG:X0oeBW000:o`078@So00LP00?o00LQo`078?l0
1b002Ol01b001?l01R3o00LPo`078?l01R0Ao`0780Wo00HP1ol01b0Jo`0680;o00HO0_l01R000ol0
1Qooooooooooo`03o`0003Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:oooo
o`00:?ooool00ol0003oooooooooo`23ooooo`04o`000?ooooooooooooooo`;o00HP4?l01Ql5o`06
80Ko00HO00?o00HPo`067ol01R000_l01Ql5o`0680oo00LP1ol01R06o`0780go00LQ3?l01b02o`07
8@06of6[0?nO^`3oHJ/0oh:d0?nI^P3oYKd00_nI^P02oh:d00CoWk/00_n2]0000onI^P3oYKd0oiVj
000:o`078A?o00LP1_l01R0@o`0780Wo00HP1ol01b0@o`0680;o00HO2Ol01R02ooooo`Co0000>Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooo
oooo08?ooooo00Go0000ooooooooooooooooo`06800Ao`067`03o`068?l01Qoo00HO00go00HO1Ol0
1R0=o`0780Wo00HP1Ol01b0=o`078@go00LP0_l01b42oink0003oh:d0?nI^P3oYKd000;oVKX00_n2
]004oink0005oh:d0?nI^P3oVKX0ojFm0?nI^P002Ol01b4Bo`0780Oo00HP4_l01b08o`0680Ko00LP
3_l01R06o`067`Ko00HP00Coooooo`000?l0003o0000?_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00[ooooo000Zooooo`;o0000Q?ooool01?l0003ooooooooooooooolPo`067`Ko
00HP2_l01b0=o`0680_o00LP1Ol01b47o`078003o`068?l01b3o00LP00Go00LP00Ko00LQoink0?nO
^`3oP[@0oiVj0?nU_@02oiVj00;oP[@01?nO^`001On2]03oVKX0oiVj0?nU_@3oP[@000Ko00LQ4Ol0
1b0:o`0680Go00LP1Ol01R000ol01b3o00HPo`078007o`0781_o00HP1_l01Ql2o`0680;ooooo0ol0
0012ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool002cooooo00?o0000
ooooooooool0P_ooool01?l0003ooooooooooooooolOo`067`Ko00HP2?l01b0@o`0680Go00LP1?l0
1b44o`078003o`078Ol01b3o00LP00Go00LP1Ol01R04o`078005o`078OnO^`3oWk/0oh:d0?nI^P00
0_nU_@000onI^P3oP[@0olK10004oink0005olK20?nI^P3oVKX0oiVj0?l01b405?l01b0:o`0680Oo
00LP2Ol01R09o`0781Wo00HP1Ol01Ql00ooooooo0000o`000002o`0004Gooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0:ooooo`00;Oooool00ol0003oooooooooo`22ooooo`04o`00
0?oooooooooooooooago00HO1_l01R05o`078004o`068?l01b3o00LPo`0780Go00HP00?o00HOo`06
8?l01Ql02Ol01R05o`0780Co00LQ2?l01b09o`0680Co00LP0_nO^`001Oo6`P3oVKX0ojFm0?nU_@3o
VKX000;oa/401?nO^`001?o6`P3oVKX0oiVj0?nI^P0<o`078003o`068?l01b3o00LP017o00HP1_l0
1b0:o`0680So00LP6_l01R02ooooo`?o0000B_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00[ooooo000^ooooo`03o`000?oooooooooo08;ooooo0_l00003oooooaco00HO1Ol01R00
0ol01b3o00HPo`06800;o`0680?o00HO2Ol01R05o`078003o`078Ol01b3o00LP00Oo00LP2_l01R05
o`0780;oWk/000Goa/80oiVj0?nU_@3oYKd0oiVj0003olK100?oWk/000Coa/80oiVj0?nU_@3oVKX0
2Ol01b0Ho`0680Ko00LP2Ol01R07o`0780oo00HP0ol01Ql7o`068004ooooool0003o0000o`0004ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`00;oooool00ol0003ooooo
ooooo`23ooooo`03o`000?oooooooooo01_o00HO7?l01R001?l01b3o00HPo`068?l01R0;o`0780ko
00HP1Ol01b02oink0005olK20?o</@3oYKd0ojFm0?nI^P000oo6`@001onO^`3obk<0olK20?o6`P3o
VKX0ojFm0?nI^P002?l01b0<o`0680;o00LP2ol01R07o`078003o`068?l01b3o00HP00Ko00HP00Co
00LPo`068?l01b3o00LP3_l01R07o`067`;o00HP00?oooooo`000?l000000_l0001Booooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool02Oooool0033ooooo0_l00024ooooo`04o`000?oo
oooooooooooooaco00HO6_l01R02o`0780Go00HP00?o00LPo`068?l01b001?l01b0>o`0680Ko00LP
00?oWk/0olK20?o</@000_nU_@001?o</@3oa/40olK10?o6`@02ol^c00;oa/8000?oc;40ojFm0?o6
`P001ol01b04o`0680?o00HO1?l01R05o`0780_o00HP2?l01b0<o`068003o`078?l01R3o00HP00_o
00HP1?l01Ql2ooooo`?o0000E_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wo
oooo000booooo`03o`000?oooooooooo08;ooooo00Go0000ooooooooooooooooo`06800Lo`067bCo
00HP0_l01b0>o`0680Ko00LP00?obk@0olK20?o</@000_o@Z002olba00;oa/400_o;/`002?o6`P3o
c;40olba0?nI^P3oa/80o`068?l01b3o00HP0ol01b05o`0680?o00HO1ol01R000ol01b3o00HPo`06
800;o`0680Oo00LP3?l01R000ol01b3o00HPo`06800<o`068003o`067ooooooo000000;o0000F_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo000cooooo`03o`000?oooooo
oooo08;ooooo00Co0000oooooooooooo00HP6_l01Ql=o`068003o`067ol01R3o00HP00Ko00HP0ol0
1Ql>o`068003o`078?l01R3o00LP00Ko00HP00?o00HOo`068?l01R001?l01R05o`078003oink0?o6
`P3oc;4000;od:P00_o</@02olK100;obk<000Goa/80olba0?o</@3oVKX0olK2000=o`0680;o00HO
00?o00HPo`067ol01R004_l01R04o`0781;o00HP00?o00HOo`068?l01R001Ol01R000ooooooo0000
o`000002o`0005kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`09ooooo`00=?oo
ool00ol0003oooooooooo`22ooooo`04o`000?oooooooooooooooaWo00HO0_l01R000ol01Qoo00HP
o`067`05o`0680Co00HO00?o00HPo`067ol01R001Ol01R04o`067aKo00HP0_l01Ql6o`0680Co00LP
00?oWk/0olK20?o6`P000_o@Z002olba00;oa/400_o;/`001?o6`P3oc;40olba0?o</@0>o`0680Go
00HO9Ol01R04o`067`Co00HP00Coooooo`000?l0003o0000H_ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Wooooo000eooooo`;o0000Poooool01?l0003ooooooooooooooolPo`06
7`;o00HP2Ol01Ql4o`068003o`067ol01R3o00HP01Oo00HP00?o00HOo`068?l01R000ol01R06o`07
80;oa/800_o@Z002olba00;oa/400_o;/`001?o6`P3oc;40olba0?o</@0<o`0680Oo00HO9?l01R05
o`067`;ooooo0ol0001Vooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool0
03Oooooo00?o0000ooooooooool0POooool01?l0003ooooooooooooooolYo`067`Wo00HP00?o00HO
o`068?l01R002?l01R04o`067`go00HP1_l01b02olK200?od:P000?oc;40olK10?oGU0000_o;/`00
1?o6`P3oc;40om2X0?o</@07o`068003o`067ol01R3o00HP00Go00HO00?o00HPo`067ol01Ql09ol0
1R02ooooo`?o0000J_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo000h
ooooo`03o`000?oooooooooo087ooooo00Co0000oooooooooooooooo8_l01Ql00ol01R3o00HOo`06
7`02o`067`So00HP1ol01Ql6o`0680Co00HO4?l01R03o`078003omND0?o6`P3oc;4000;od:P000Go
c;40omND0?oGU03obk<0omND0002olba0003om2X0?o6`P3o00HP00?o00HP2_l01QlOo`0680;o00HO
1ol01R000ooooooo0000o`000002o`0006kooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`08ooooo`00>Oooool00ol0003oooooooooo`21ooooo`04o`000?oooooooooooooooaoo00HO
2_l01R0@o`067aSo00HP00Co00LPomND0?oGU03oc;400_o@Z0001Oo</@3oei@0omND0?o;/`3oei@0
00;oc;4000?od:P0olK20?l01Ql03_l01QlKo`0680Ko00HO0_l01R02ooooo`?o0000L_ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo000jooooo`;o0000P_ooool01?l0003o
oooooooooooooolPo`067`Go00HP4_l01Ql7o`0680?o00HO00?o00HPo`067ol01R003?l01R001?l0
1b3oei@0omND0?o</@02om2X0005olba0?oGU03oei@0ol^c0?oGU0000oo</@000oo6`P3o00HOo`06
7`03o`067`?o00HP2Ol01QlJo`0680Co00HO0_ooool3o`0007Kooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`08ooooo`00??ooool00ol0003oooooooooo`20ooooo`03o`000?oooooo
oooo00;ooooo7ol01Ql3o`0681Co00HO00?o00HPo`067ol01R000_l01R09o`067`_o00HP00?oc;40
omND0?oNOP000_o@Z0001_oNOP3oei@0omND0?o;/`3oei@0omin00;oc;4000?oei@0o`067ol01Ql0
0_l01Ql4o`0680[o00HO3_l01R000ol01Qoo00HPo`068008o`068003o`067ooooooo000000?o0000
N_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo000mooooo`03o`000?oo
oooooooo083ooooo00Co0000oooooooooooooooo>Ol01Ql3o`0680So00HO3?l01R001?oGU03ogWh0
om2X0?oQL`02omin00?oei@000?ogWh0om2X0?o</@001_l01Ql3o`0680_o00HO2_l01R06o`067`Go
00HP0_ooool3o`0007oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`00
?_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00;ooooo>?l01Ql3o`0680So00HO
2Ol01R02o`067`04omND0?oNOP3ohG<0on5c00;ogWh00ooGU0000ooNOP3ohG<0olba000Co`067`[o
00HP1ol01Ql2o`0680;ooooo0ol00022ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool02?ooool003oooooo0_l00021ooooo`03o`000?oooooooooo00;ooooo>?l01Ql7o`0680Wo00HO
0ol01R02o`067`;oei@00_oQL`02omin00;oei@00_oNOP000ooQL`3ogWh0o`067`0Do`067`Wo00HP
1Ol01Ql00ooooooo0000o`000002o`0008Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`08ooooo`00@Oooool00ol0003oooooooooo`1oooooo`;o00000_oooolho`067`Ko00HP2ol0
1Ql3o`068003o`067ooGU03oei@000;ohG<00_oNOP001_oGU03ohfl0omin0?oNOP3ohG<0omND01So
00HO2?l01R001?oooooo0000o`000?l0002;ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01oooool004;ooooo00?o0000ooooooooool0P?ooool01?l0003ooooooooooooooolGo`06
7`;o00HP7ol01Ql00ol01R3o00HOo`067`0@o`067`04on=_0?oGU03ohG<0on5c00;ogWh00_oSK`02
omin0003on5c0?l01Qoo00HO01Oo00HO1?l01R02ooooo`?o0000S_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Oooooo0013ooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool0Bol01Ql01?oQL`3oei@0omin0?oQL`02omin00;ohfl00_oNOP000ooQL`3o00HOo`067`0E
o`067`?o00HP00?oooooo`000?l000000_l0002Booooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01oooool004Cooooo00?o0000ooooooooool0P?ooool01?l0003ooooooooooooooom:
o`067`03on=_0?oNOP3ohG<000;ogWh00_oSK`000ooNOP3ohG<0on5c000Fo`067`03o`068?oooooo
000000;o0000Uoooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo0015oooo
o`;o0000POooool01?l0003ooooooooooooooom9o`067`04on=_0?oNOP3ohG<0omin00;ojU@000Co
hfl0omin0?oQL`3ohfl04ol01Ql2ooooo`?o0000Voooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Oooooo0017ooooo`03o`000?oooooooooo07oooooo00Co0000oooooooooooooooo
<Ol01Ql00ol01R3o00HOo`067`0Do`067`04on=_0?oZE03ohG<0omin00;ojU@000?ohfl0onYD0?oQ
L`004?l01Ql2ooooo`Co0000W_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oo
oooo0018ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool00_ooool_o`067`03o`06
8?l01Qoo00HO01Co00HO0_oZE0000ooQL`3ojU@0onYD0003onYD0003on5c0?l01Qoo00HO00Wo00HO
00Co00HPo`067ol01Qoooooo0ol0002Sooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01oooool004Wooooo00?o0000ooooooooool0Ooooool01?l0003ooooooooooooooom7o`067`03
onYD0?o^AP3ojU@000CojU@000?okTH0o`067ol01Ql01ol01Ql00ol01R3oooooooooo`03o`000:Oo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`06ooooo`00B_ooool2o`00083ooooo
00Co0000ooooooooooooooooA_l01Ql00ooZE03okTH0oni60004onYD0003oni60?l01Qoo00HO00Go
00HO00?oooooo`000?l000000_l0002[ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01_ooool004cooooo00?o0000ooooooooool0O_ooool01?l0003ooooooooooooooom5o`067`06
oo8g0?oZE03okTH0onYD0?ob=`3ojU@00_o^AP03o`067`;ooooo0ol0002_ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01_ooool004gooooo00?o0000ooooooooool0O_ooool01?l0
003ooooooooooooooom4o`067`;ojU@000KokTH0onYD0?ob=`3ojU@0oni60?l01Ql2ooooo`?o0000
/oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo001>ooooo`03o`000?oo
oooooooo07kooooo00?o0000ooooooooool00_oooom3o`067`06oo8g0?o^AP3olSL0oo8g0?oZE03o
kTH00ol0002gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool004oooooo
0_l0001oooooo`04o`000?oooooooooooooood?o00HO00GolSL0ooHW0?ob=`3olSL0ooHW002koooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool0057ooooo00?o0000oooooooo
ool0OOooool00ol0003oooooooooo`02ooooocko00HO0_ooool01_l0003olSL0ooHW0?of9`3olSL0
ooHW0;cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`00D_ooool00ol0
003oooooooooo`1mooooo`;o00000_ooooljo`067`;ooooo1?l00002ooooo`04oo8g0?of9`3olSL0
ooHW0;gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`00Doooool00ol0
003oooooooooo`1nooooo`04o`000?ooooooooooooooocGo00HO0_ooool3o`0000Oooooo0_of9`00
0oob=`3oooooooooo`2looooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool0
05Cooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0ao`067`?ooooo0ol0000:oooo
o`;onQL0_oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo001Eooooo`;o
0000Ooooool01?l0003oooooooooooooool/o`067`;ooooo1?l0003?ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01Oooool005Oooooo00?o0000ooooooooool0OOooool01?l0003o
oooooooooooooolWo`067`?ooooo0ol0003Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01Oooool005Sooooo00?o0000ooooooooool0OOooool01?l0003ooooooooooooooolTo`06
7`;ooooo0ol0003Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool005Wo
oooo00?o0000ooooooooool0OOooool01?l0003ooooooooooooooolOo`067`;ooooo1?l0003Koooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool005[ooooo0_l0001nooooo`04
o`000?oooooooooooooooa_o00HO0_ooool3o`000>3ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`05ooooo`00G?ooool00ol0003oooooooooo`1looooo`04o`000?oooooooooooooo
oaKo00HO0oooool3o`000>Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04oooo
o`00GOooool00ol0003oooooooooo`1looooo`04o`000?oooooooooooooooa;o00HO0_ooool4o`00
0>Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`00G_ooool00ol0003o
ooooooooo`1looooo`04o`000?ooooooooooooooo`go00HO0oooool3o`000>cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`04ooooo`00Goooool2o`0007gooooo00Co0000oooooooo
oooooooo2_l01Ql2ooooo`?o0000l?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Cooooo001Qooooo`03o`000?oooooooooo07_ooooo00Co0000oooooooooooooooo1_l01Ql00ooo
oooo0000o`000002o`000?Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04oooo
o`00H_ooool00ol0003oooooooooo`1kooooo`05o`000?ooooooooooooooool01Ql00_ooool3o`00
0?Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`00Hoooool00ol0003o
ooooooooo`1kooooo`03o`000?oooooooooo00?o0000o?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo001Tooooo`;o0000O?ooool2o`000?oooooo0Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo001Vooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool0ooooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo001W
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00oooool006Sooooo00?o0000ooooooooool0Moooool00ol0
003oooooooooo`3oooooo`;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03oooo
o`00JOooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo0?oooooo0oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo001Zooooo`;o0000M_ooool00ol0003ooooo
ooooo`3oooooo`?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`00K?oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo0?oooooo1?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00?ooooo001]ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0ooooool5ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool0
06kooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`3oooooo`Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`00Koooool2o`00077ooooo00?o0000oooooooo
ool0ooooool6ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool0077ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`00L_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo0?oooooo2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo001c
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0ooooool8ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool007Cooooo0_l0001[ooooo`03o`000?oooooooooo
0?oooooo2_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo001fooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool0ooooool;ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool007Oooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`3oooooo`cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`00N?oo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo0?oooooo3?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo007ooooo001iooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool0ooooool=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00Oooool0
07[ooooo0_l0001Uooooo`03o`000?oooooooooo0?oooooo3_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo007ooooo001looooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0ooooool?ooooo`05o`000?ooooooooooooooool000000oooool007gooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`3oooooo`oooooo00Go0000ooooooooooooooooo`000003oooo
o`00O_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo0?oooooo4?ooool01?l0003o
ooooooooool00003ooooo`00Ooooool2o`00063ooooo00?o0000ooooooooool0oooooolAooooo`03
o`000?oooooo000000?ooooo0021ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
oooooolAooooo`04o`000?ooooooooooo`0000;ooooo0022ooooo`03o`000?oooooooooo05cooooo
00?o0000ooooooooool0oooooolBooooo`03o`000?oooooo000000;ooooo0023ooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool0oooooolCooooo`;o00000_ooool008Cooooo0_l0001K
ooooo`03o`000?oooooooooo0?oooooo4_ooool3o`0000;ooooo0026ooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool0ooooool>ooooo`Co00001Oooool008Oooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`3oooooo`[ooooo1?l00009ooooo`00R?ooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo0?oooooo1oooool3o`0000gooooo0029ooooo`;o0000E_oo
ool00ol0003oooooooooo`3oooooo`?ooooo1?l0000@ooooo`00Roooool00ol0003oooooooooo`1C
ooooo`03o`000?oooooooooo0?kooooo1?l0000Dooooo`00S?ooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo0?[ooooo1?l0000Hooooo`00SOooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo0?Kooooo1?l0000Looooo`00S_ooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo0?;ooooo1?l0000Pooooo`00Soooool2o`00053ooooo00?o0000ooooooooool0k_oo
ool4o`0002Cooooo002Aooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0joooool3
o`0002Sooooo002Booooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0ioooool4o`00
02_ooooo002Cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0i?ooool4o`0002oo
oooo002Dooooo`;o0000B_ooool00ol0003oooooooooo`3Pooooo`Co0000<oooool009Kooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`3Looooo`Co0000=oooool009Oooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`3Hooooo`Co0000>oooool009Sooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`3Dooooo`Co0000?oooool009Wooooo0_l00015ooooo`03
o`000?oooooooooo0=7ooooo0ol00013ooooo`00Voooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo0<gooooo1?l00016ooooo`00W?ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo0<Wooooo1?l0001:ooooo`00WOooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo0<Gooooo1?l0001>ooooo`00W_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
0<7ooooo1?l0001Booooo`00Woooool2o`0003oooooo00?o0000ooooooooool0_Oooool4o`0005Ko
oooo002Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0^_ooool3o`0005[ooooo
002Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0]_ooool4o`0005gooooo002S
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0/_ooool4o`00067ooooo002Toooo
o`;o0000>_ooool00ol0003oooooooooo`2^ooooo`Co0000IOooool00:Kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`2Zooooo`Co0000JOooool00:Oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`2Vooooo`Co0000KOooool00:Sooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`2Rooooo`Co0000LOooool00:Wooooo0_l0000eooooo`03o`000?oooooo
oooo09oooooo0ol0001eooooo`00Zoooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
09_ooooo1?l0001hooooo`00[?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09Oo
oooo1?l0001looooo`00[Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo
1?l00020ooooo`00[_ooool2o`00033ooooo00?o0000ooooooooool0Soooool4o`0008Cooooo002`
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Roooool4o`0008Sooooo002aoooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Qoooool4o`0008cooooo002booooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0QOooool3o`00093ooooo002cooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0POooool4o`0009?ooooo002dooooo`;o0000:Ooo
ool00ol0003oooooooooo`1mooooo`Co0000Uoooool00;Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1iooooo`Co0000Voooool00;Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1eooooo`Co0000Woooool00;Sooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1aooooo`Co0000Xoooool00;Wooooo0_l0000Tooooo`03o`000?oooooooooo06kooooo
0ol0002Wooooo`00^oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06[ooooo1?l0
002Zooooo`00_?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Kooooo1?l0002^
ooooo`00_Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06;ooooo1?l0002boooo
o`00__ooool2o`0001oooooo00?o0000ooooooooool0G_ooool4o`000;Kooooo0030ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0F_ooool4o`000;[ooooo0031ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0E_ooool4o`000;kooooo0032ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Doooool3o`000<;ooooo0033ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0Coooool4o`000<Gooooo0034ooooo`;o00006Oooool00ol0003o
ooooooooo`1;ooooo`Co0000bOooool00<Kooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`17ooooo`Co0000cOooool00<Oooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`13ooooo`Co0000dOooool00<Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0o
ooooo`Co0000eOooool00<Wooooo0_l0000Dooooo`03o`000?oooooooooo03cooooo0ol0003Ioooo
o`00boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo1?l0003Looooo`00
c?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Cooooo1?l0003Pooooo`00cOoo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo1?l0003Tooooo`00c_ooool2
o`0000oooooo00?o0000ooooooooool0;?ooool4o`000>Sooooo003@ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0:?ooool4o`000>cooooo003Aooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool09Oooool4o`000?3ooooo003Booooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool08_ooool3o`000?Cooooo003Cooooo`;o00002Oooool00ol0003ooooooooo
o`0Nooooo`Co0000moooool00=Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0J
ooooo`Co0000noooool00=Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Foooo
o`Co0000ooooool00=Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co
0000ooooool4ooooo`00f?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo
1?l0003oooooo`Sooooo003Iooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000oooo
ool<ooooo`00foooool01?l0003oooooooooool00009ooooo`?o0000ooooool@ooooo`00g?ooool0
0ol0003oooooo`000005ooooo`Co0000oooooolCooooo`00gOooool2o`000003ooooool0003o0000
00;o0000oooooolGooooo`00g_ooool2o`000?oooooo6oooool00?oooooonoooool00?oooooonooo
ool00?oooooonoooool00?oooooonoooool00?oooooonoooool00?oooooonoooool00=_ooooo0ol0
001Aooooo`?o0000b?ooool00=cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`37
ooooo`00/Oooool3o`0000Cooooo0ol00002ooooo`Go000000Goooooo`000?l0003o0000ooooo`02
o`0000;ooooo0_l00009ooooo`?o00000oooool3o`0000;ooooo0ol00004ooooo`?o00000oooool4
o`0000;ooooo1?l00007ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l0
0003ooooo`?o00000_ooool3o`000003ooooool0003o000000Co00000_ooool5o`0000?ooooo0_l0
0004ooooo`03o`000?oooooooooo00Oooooo0ol00005ooooo`;o000000?oooooo`000?l000000_l0
00001?oooooo0000o`000?ooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000;ooooo
0ol000000ooooooo0000o`00002?ooooo`00/_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04o`000?oo
ooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool0002@ooooo`00/_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool03?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo1Ol00002ooooo`?o00000_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go00000_oo
ool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool0S_ooool00;;ooooo0ol00002ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool02_ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0003o
ooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Wooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0S_ooool00;;ooooo00Co
0000oooooooooooo00000_ooool3o`0000;ooooo0ol00003ooooo`Co00000_ooool4o`0000Wooooo
00?o0000ooooooooool00_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o0000
0oooool2o`0000Cooooo0ol0000:ooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`0000?o
oooo0ol00002ooooo`Co00000oooool4o`000004ooooool0003o0000o`0000?ooooo1?l00002oooo
o`;o000000?oooooo`000?l000002?ooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`00
0?l0003ooooo1?l00003ooooo`?o00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000_ooool4
o`00097ooooo002booooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooool0000Looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000
5?ooool00ol0003oooooooooo`2Sooooo`00/Oooool4o`0000[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0:ooooo`?o00006oooool2o`0000Sooooo1Ol00008ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`Go00005?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09cooooo003ooooooo_ooooo003ooooo
oo_ooooo003ooooooo_ooooo003ooooooo_ooooo003ooooooo_ooooo003ooooooo_ooooo003ooooo
oo_ooooo003ooooooo_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 505.688}, {410, 0}} -> {-0.077164, 0.046874, \
0.00204568, 0.00204568}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 5\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] {0.1261948886085015`, 
            0.12624689038504655`}\), ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FindPupils \[Rule] True\), ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrequencyCutoff \[Rule] {304.0619384331368`, 
            303.93423730280796`}\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {207.28232192993164`, 0, 0}\), 
        ",", \(ImageSampleSize \[Rule] {0.0016604590606381776`, 
            0.001661143294540086`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", \(Mesh \[Rule] False\), 
        ",", \(NumberOfPoints \[Rule] 128\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 112.44620808978891`\), 
        ",", \(OpticalLengthFunction \[Rule] OpticalLengthFunction\), 
        ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(CompiledFunction[
              If[#1 == 0 && #2 == 0, 
                0.000022271117373179214`, \(-6.853627285348719`\) - 
                  3.532109641994116`*^-9\ Cos[
                      2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                  1.9515319104050795`*^-10\ Cos[
                      4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                  10.310895376241149`\ \((\(-1\) + 
                        0.013990424917235709`\ \((#1\^2 + #2\^2)\))\) - 
                  5.251099192578527`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.020985637375853565`\)\ \
\((#1\^2 + #2\^2)\) + 0.0001957319893648098`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  3.4781206500308235`\ \((1 - 
                        0.04197127475170713`\ \((#1\^2 + #2\^2)\) + 
                        0.0002935979840472147`\ \((#1\^2 + #2\^2)\)\^2)\) + 
                  4.27139394586925`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((\(-0.00024466498670601227`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 2.0537802758321623`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  3.396256590938641`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((0.04197127475170713`\ \((#1\^2 + \
#2\^2)\) - 0.000978659946824049`\ \((#1\^2 + #2\^2)\)\^2 + 
                        5.134450689580406`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  0.02108223618211115`\ \((\(-1\) + 
                        0.08394254950341426`\ \((#1\^2 + #2\^2)\) - 
                        0.0014679899202360734`\ \((#1\^2 + #2\^2)\)\^2 + 
                        6.845934252773875`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  7.380096153526266`*^-8\ Cos[
                      6\ ArcTan[#1, #2]]\ \((\(-2.396076988470856`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 1.9155505830353006`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  3.180054365542885`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((0.0007339949601180367`\ \((#1\^2 \
+ #2\^2)\)\^2 - 0.000014376461930825136`\ \((#1\^2 + #2\^2)\)\^3 + 
                        6.704427040623552`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  1.291385970907799`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.06995212458617854`\)\ \((#1\
\^2 + #2\^2)\) + 0.0029359798404721468`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00003594115482706284`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.3408854081247104`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.0002074059263440704`\ \((1 - 
                        0.13990424917235708`\ \((#1\^2 + #2\^2)\) + 
                        0.00440396976070822`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00004792153976941712`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.6761067601558881`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
              "-CompiledCode-"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {112.43537240553266`, 
            112.44620808978891`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics3D  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.10460892082020519`\), 
                  0.10626937988084338`}, {\(-0.10465202755602541`\), 
                  0.1063131708505655`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] False\), 
        ",", \(PlotPoints \[Rule] 200\), ",", \(PlotRange \[Rule] All\), ",", 
        
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.10460892082020519`\), 
                  0.10626937988084338`}, {\(-0.10465202755602541`\), 
                  0.1063131708505655`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(RayBoundary \[Rule] {{\(-8.4562214163056`\), 
              8.4562214163056`}, {\(-8.452646568455712`\), 
              8.452646568455712`}}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), 
        ",", \(ResidualFitError \[Rule] 7.313862904893167`*^-7\), 
        ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
              82.9255011275954`, Astigmatism \[Rule] 0.0000417323567305451`, 
            FieldCurvature \[Rule] \(-0.24683256227325023`\), 
            Distortion \[Rule] \(-3.777962952267033`*^-13\), 
            Coma \[Rule] 1.3460273542456333`*^-12}\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 584\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.015686737510906584`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-11.347295107870586`\), 
                  11.347295107870586`}, {\(-11.343720260020696`\), 
                  11.343720260020696`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[46]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
PSF[offaxis3D, NumberOfPoints->1024, NumberOfRays->32, Plot2D->False, \
FocalFraction->0, PlotPoints->100, ColorFunction->Automatic, Mesh->False]\
\>", "Input",
  CellLabel->"In[58]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.14478 .20005 -11.9289 -9 ]
[.14478 .20005 .07109 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.53881 .04509 -5.20895 -9 ]
[.53881 .04509 .79105 0 ]
[.76813 .09808 0 -6.16085 ]
[.76813 .09808 12 2.83915 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93425 .35246 0 -5.92044 ]
[.93425 .35246 6 3.07956 ]
[.02244 .27559 -18 -2.75116 ]
[.02244 .27559 0 6.24884 ]
[.0116 .34356 -18 -2.8087 ]
[.0116 .34356 0 6.1913 ]
[.00026 .4146 -18 -2.8691 ]
[.00026 .4146 0 6.1309 ]
[-0.01159 .4889 -18 -2.93257 ]
[-0.01159 .4889 0 6.06743 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15401 .20938 m
.15862 .21405 L
s
[(-5)] .14478 .20005 .98815 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54659 .05566 m
.55048 .06094 L
s
[(5)] .53881 .04509 .73632 1 Mshowa
.125 Mabswid
.19074 .195 m
.19347 .19784 L
s
.22799 .18041 m
.23069 .18328 L
s
.26579 .16561 m
.26845 .16852 L
s
.30415 .15059 m
.30676 .15354 L
s
.38256 .11989 m
.38509 .12291 L
s
.42265 .10419 m
.42513 .10725 L
s
.46334 .08826 m
.46577 .09135 L
s
.50465 .07208 m
.50703 .07521 L
s
.1178 .22356 m
.1206 .22633 L
s
.0821 .23754 m
.08493 .24027 L
s
.04689 .25133 m
.04976 .25402 L
s
.58918 .03898 m
.59146 .04219 L
s
.63243 .02205 m
.63466 .02529 L
s
.67636 .00485 m
.67853 .00813 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75582 .10262 m
.74967 .10489 L
s
[(-5)] .76813 .09808 -1 .36908 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92174 .35641 m
.91548 .35839 L
s
[(5)] .93425 .35246 -1 .31565 Mshowa
.125 Mabswid
.77442 .13107 m
.77072 .13241 L
s
.79253 .15877 m
.78882 .16009 L
s
.81016 .18574 m
.80645 .18704 L
s
.82734 .21201 m
.82362 .2133 L
s
.86039 .26257 m
.85666 .26382 L
s
.8763 .28691 m
.87256 .28814 L
s
.89182 .31064 m
.88807 .31186 L
s
.90696 .33381 m
.90321 .33501 L
s
.73671 .07338 m
.73302 .07476 L
s
.71706 .04332 m
.71338 .04473 L
s
.69685 .01241 m
.69318 .01384 L
s
.93616 .37848 m
.93241 .37965 L
s
.95025 .40003 m
.94649 .40119 L
s
.96402 .42108 m
.96025 .42222 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03467 .27083 m
.04079 .26846 L
s
[(0.1)] .02244 .27559 1 -0.38863 Mshowa
.02388 .33895 m
.03002 .33664 L
s
[(0.2)] .0116 .34356 1 -0.37584 Mshowa
.0126 .41013 m
.01877 .40789 L
s
[(0.3)] .00026 .4146 1 -0.36242 Mshowa
.0008 .48459 m
.007 .48243 L
s
[(0.4)] -0.01159 .4889 1 -0.34832 Mshowa
.125 Mabswid
.03255 .28422 m
.03622 .2828 L
s
.03041 .29772 m
.03409 .29631 L
s
.02825 .31134 m
.03193 .30994 L
s
.02608 .32508 m
.02976 .32369 L
s
.02166 .35293 m
.02535 .35155 L
s
.01943 .36704 m
.02312 .36567 L
s
.01717 .38127 m
.02087 .37991 L
s
.0149 .39564 m
.01859 .39428 L
s
.01028 .42475 m
.01399 .42342 L
s
.00794 .4395 m
.01165 .43818 L
s
.00558 .45439 m
.00929 .45308 L
s
.0032 .46942 m
.00692 .46812 L
s
.03678 .25756 m
.04044 .25613 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.786 .469 .451 r
.40026 .65047 .40371 .64406 .40853 .65473 .40505 .66248 Mtetra
.761 .449 .457 r
.40505 .66248 .40853 .65473 .41343 .66438 .40992 .67337 Mtetra
.717 .407 .453 r
.40992 .67337 .41343 .66438 .41845 .67144 .41492 .68142 Mtetra
.677 .372 .449 r
.41492 .68142 .41845 .67144 .42357 .67653 .42004 .68729 Mtetra
.648 .346 .446 r
.42004 .68729 .42357 .67653 .42875 .68031 .42522 .69172 Mtetra
.591 .292 .431 r
.42522 .69172 .42875 .68031 .43402 .68162 .43051 .69342 Mtetra
.573 .278 .429 r
.43051 .69342 .43402 .68162 .43933 .68227 .43584 .69438 Mtetra
.549 .257 .423 r
.43584 .69438 .43933 .68227 .44467 .68203 .4412 .69437 Mtetra
.53 .24 .418 r
.4412 .69437 .44467 .68203 .45005 .68113 .4466 .69362 Mtetra
.524 .235 .418 r
.4466 .69362 .45005 .68113 .45544 .68001 .45202 .69263 Mtetra
.517 .229 .416 r
.45202 .69263 .45544 .68001 .46085 .67863 .45746 .69135 Mtetra
.515 .228 .417 r
.45746 .69135 .46085 .67863 .46627 .67717 .4629 .68999 Mtetra
.514 .228 .417 r
.4629 .68999 .46627 .67717 .4717 .67565 .46837 .68856 Mtetra
.513 .228 .418 r
.46837 .68856 .4717 .67565 .47714 .6741 .47384 .6871 Mtetra
.514 .228 .419 r
.47384 .6871 .47714 .6741 .48259 .67253 .47932 .68562 Mtetra
.514 .229 .42 r
.47932 .68562 .48259 .67253 .48806 .67094 .48482 .68412 Mtetra
.514 .23 .421 r
.48482 .68412 .48806 .67094 .49354 .66934 .49033 .68261 Mtetra
.514 .231 .422 r
.49033 .68261 .49354 .66934 .49902 .66773 .49585 .6811 Mtetra
.515 .231 .422 r
.49585 .6811 .49902 .66773 .50452 .66611 .50138 .67958 Mtetra
.515 .232 .423 r
.50138 .67958 .50452 .66611 .51003 .66448 .50692 .67804 Mtetra
.515 .233 .424 r
.50692 .67804 .51003 .66448 .51555 .66284 .51247 .67651 Mtetra
.515 .234 .425 r
.51247 .67651 .51555 .66284 .52108 .66119 .51803 .67495 Mtetra
.516 .235 .426 r
.51803 .67495 .52108 .66119 .52662 .65953 .52361 .67339 Mtetra
.516 .236 .427 r
.52361 .67339 .52662 .65953 .53217 .65786 .52919 .67182 Mtetra
.516 .236 .428 r
.52919 .67182 .53217 .65786 .53773 .65617 .53479 .67024 Mtetra
.517 .237 .429 r
.53479 .67024 .53773 .65617 .54331 .65447 .5404 .66865 Mtetra
.517 .238 .43 r
.5404 .66865 .54331 .65447 .54889 .65277 .54602 .66705 Mtetra
.517 .239 .431 r
.54602 .66705 .54889 .65277 .55449 .65105 .55165 .66544 Mtetra
.518 .24 .432 r
.55165 .66544 .55449 .65105 .5601 .64932 .5573 .66382 Mtetra
.518 .241 .433 r
.5573 .66382 .5601 .64932 .56571 .64758 .56295 .66219 Mtetra
.518 .241 .434 r
.56295 .66219 .56571 .64758 .57134 .64582 .56862 .66054 Mtetra
.518 .242 .435 r
.56862 .66054 .57134 .64582 .57698 .64405 .57429 .65889 Mtetra
.519 .243 .436 r
.57429 .65889 .57698 .64405 .58263 .64227 .57998 .65723 Mtetra
.519 .244 .437 r
.57998 .65723 .58263 .64227 .58829 .64048 .58568 .65555 Mtetra
.519 .245 .438 r
.58568 .65555 .58829 .64048 .59396 .63868 .59139 .65387 Mtetra
.52 .245 .439 r
.59139 .65387 .59396 .63868 .59964 .63686 .59712 .65217 Mtetra
.52 .246 .44 r
.59712 .65217 .59964 .63686 .60533 .63503 .60285 .65046 Mtetra
.52 .247 .441 r
.60285 .65046 .60533 .63503 .61104 .63319 .60859 .64874 Mtetra
.52 .248 .442 r
.60859 .64874 .61104 .63319 .61675 .63133 .61435 .64701 Mtetra
.521 .249 .443 r
.61435 .64701 .61675 .63133 .62248 .62946 .62012 .64526 Mtetra
.521 .249 .444 r
.62012 .64526 .62248 .62946 .62821 .62757 .6259 .6435 Mtetra
.521 .25 .445 r
.6259 .6435 .62821 .62757 .63396 .62567 .63169 .64173 Mtetra
.522 .251 .446 r
.63169 .64173 .63396 .62567 .63971 .62376 .63749 .63995 Mtetra
.522 .252 .446 r
.63749 .63995 .63971 .62376 .64548 .62183 .6433 .63815 Mtetra
.522 .253 .447 r
.6433 .63815 .64548 .62183 .65126 .61989 .64912 .63634 Mtetra
.522 .253 .448 r
.64912 .63634 .65126 .61989 .65705 .61793 .65496 .63451 Mtetra
.523 .254 .449 r
.65496 .63451 .65705 .61793 .66284 .61595 .66081 .63267 Mtetra
.523 .255 .45 r
.66081 .63267 .66284 .61595 .66865 .61396 .66666 .63082 Mtetra
.523 .256 .451 r
.66666 .63082 .66865 .61396 .67447 .61196 .67253 .62895 Mtetra
.523 .256 .452 r
.67253 .62895 .67447 .61196 .6803 .60993 .67841 .62707 Mtetra
.524 .257 .453 r
.67841 .62707 .6803 .60993 .68614 .6079 .6843 .62518 Mtetra
.524 .258 .454 r
.6843 .62518 .68614 .6079 .69199 .60584 .6902 .62326 Mtetra
.524 .259 .455 r
.6902 .62326 .69199 .60584 .69785 .60377 .69611 .62133 Mtetra
.524 .259 .456 r
.69611 .62133 .69785 .60377 .70372 .60168 .70203 .61939 Mtetra
.524 .26 .456 r
.70203 .61939 .70372 .60168 .7096 .59957 .70797 .61742 Mtetra
.525 .261 .457 r
.70797 .61742 .7096 .59957 .71549 .59745 .71391 .61545 Mtetra
.525 .261 .458 r
.71391 .61545 .71549 .59745 .72139 .59531 .71987 .61345 Mtetra
.525 .262 .459 r
.71987 .61345 .72139 .59531 .7273 .59314 .72583 .61144 Mtetra
.525 .263 .46 r
.72583 .61144 .7273 .59314 .73322 .59097 .73181 .60941 Mtetra
.525 .263 .461 r
.73181 .60941 .73322 .59097 .73915 .58877 .73779 .60736 Mtetra
.526 .264 .461 r
.73779 .60736 .73915 .58877 .74509 .58655 .74379 .60529 Mtetra
.526 .265 .462 r
.74379 .60529 .74509 .58655 .75104 .58431 .7498 .60321 Mtetra
.526 .265 .463 r
.7498 .60321 .75104 .58431 .75699 .58205 .75582 .6011 Mtetra
.526 .266 .464 r
.75582 .6011 .75699 .58205 .76296 .57978 .76185 .59898 Mtetra
.526 .267 .465 r
.76185 .59898 .76296 .57978 .76894 .57748 .76788 .59683 Mtetra
.76788 .59683 .76894 .57748 .77492 .57516 .77393 .59466 Mtetra
.527 .268 .466 r
.77393 .59466 .77492 .57516 .78092 .57282 .77999 .59248 Mtetra
.527 .268 .467 r
.77999 .59248 .78092 .57282 .78692 .57045 .78606 .59027 Mtetra
.527 .269 .468 r
.78606 .59027 .78692 .57045 .79294 .56807 .79213 .58804 Mtetra
.527 .27 .468 r
.79213 .58804 .79294 .56807 .79896 .56566 .79822 .58579 Mtetra
.527 .27 .469 r
.79822 .58579 .79896 .56566 .80499 .56323 .80432 .58351 Mtetra
.527 .271 .47 r
.80432 .58351 .80499 .56323 .81103 .56078 .81042 .58121 Mtetra
.527 .271 .471 r
.81042 .58121 .81103 .56078 .81708 .5583 .81654 .57889 Mtetra
.527 .272 .471 r
.81654 .57889 .81708 .5583 .82313 .5558 .82267 .57654 Mtetra
.527 .272 .472 r
.82267 .57654 .82313 .5558 .8292 .55328 .8288 .57417 Mtetra
.527 .273 .473 r
.8288 .57417 .8292 .55328 .83527 .55073 .83494 .57177 Mtetra
.528 .273 .473 r
.83494 .57177 .83527 .55073 .84135 .54815 .84109 .56935 Mtetra
.528 .274 .474 r
.84109 .56935 .84135 .54815 .84744 .54555 .84725 .5669 Mtetra
.528 .274 .475 r
.84725 .5669 .84744 .54555 .85354 .54293 .85342 .56442 Mtetra
.528 .275 .475 r
.85342 .56442 .85354 .54293 .85965 .54028 .8596 .56192 Mtetra
.528 .275 .476 r
.8596 .56192 .85965 .54028 .86576 .53759 .86578 .55938 Mtetra
.528 .276 .476 r
.86578 .55938 .86576 .53759 .87188 .53489 .87198 .55682 Mtetra
.528 .276 .477 r
.87198 .55682 .87188 .53489 .878 .53216 .87818 .55424 Mtetra
.528 .276 .478 r
.87818 .55424 .878 .53216 .88414 .52939 .88439 .55161 Mtetra
.528 .277 .478 r
.88439 .55161 .88414 .52939 .89028 .52659 .8906 .54895 Mtetra
.528 .277 .479 r
.8906 .54895 .89028 .52659 .89643 .52378 .89683 .54626 Mtetra
.527 .277 .479 r
.89683 .54626 .89643 .52378 .90258 .52089 .90305 .54351 Mtetra
.527 .277 .48 r
.90305 .54351 .90258 .52089 .90873 .51797 .90928 .5407 Mtetra
.526 .277 .48 r
.90928 .5407 .90873 .51797 .91489 .51497 .91551 .5378 Mtetra
.523 .275 .48 r
.91551 .5378 .91489 .51497 .92103 .51179 .92172 .53467 Mtetra
.521 .274 .48 r
.92172 .53467 .92103 .51179 .92717 .50847 .92792 .53137 Mtetra
.514 .268 .48 r
.92792 .53137 .92717 .50847 .93326 .50472 .93407 .52752 Mtetra
.505 .261 .479 r
.93407 .52752 .93326 .50472 .93929 .50042 .94013 .52296 Mtetra
.497 .255 .477 r
.94013 .52296 .93929 .50042 .94526 .49569 .94613 .51787 Mtetra
.467 .232 .473 r
.94613 .51787 .94526 .49569 .95105 .48942 .95187 .51077 Mtetra
.446 .214 .467 r
.95187 .51077 .95105 .48942 .95671 .48228 .95746 .50257 Mtetra
.41 .184 .458 r
.95746 .50257 .95671 .48228 .9622 .47385 .96282 .4927 Mtetra
.35 .136 .442 r
.96282 .4927 .9622 .47385 .96744 .46367 .96786 .48055 Mtetra
.298 .09 .42 r
.96786 .48055 .96744 .46367 .97256 .45274 .97274 .46745 Mtetra
.81 .488 .444 r
.39683 .65573 .40026 .65047 .40505 .66248 .40158 .66894 Mtetra
.786 .467 .449 r
.40158 .66894 .40505 .66248 .40992 .67337 .40642 .68093 Mtetra
.741 .423 .443 r
.40642 .68093 .40992 .67337 .41492 .68142 .41141 .68987 Mtetra
.699 .383 .437 r
.41141 .68987 .41492 .68142 .42004 .68729 .41652 .69645 Mtetra
.667 .353 .432 r
.41652 .69645 .42004 .68729 .42522 .69172 .4217 .70146 Mtetra
.6 .288 .412 r
.4217 .70146 .42522 .69172 .43051 .69342 .427 .70352 Mtetra
.579 .27 .408 r
.427 .70352 .43051 .69342 .43584 .69438 .43235 .70477 Mtetra
.55 .243 .4 r
.43235 .70477 .43584 .69438 .4412 .69437 .43774 .70497 Mtetra
.525 .221 .393 r
.43774 .70497 .4412 .69437 .4466 .69362 .44316 .70436 Mtetra
.518 .215 .392 r
.44316 .70436 .4466 .69362 .45202 .69263 .4486 .7035 Mtetra
.509 .208 .39 r
.4486 .7035 .45202 .69263 .45746 .69135 .45406 .70233 Mtetra
.506 .206 .391 r
.45406 .70233 .45746 .69135 .4629 .68999 .45954 .70106 Mtetra
.505 .206 .392 r
.45954 .70106 .4629 .68999 .46837 .68856 .46502 .69973 Mtetra
.505 .206 .393 r
.46502 .69973 .46837 .68856 .47384 .6871 .47052 .69836 Mtetra
.505 .207 .394 r
.47052 .69836 .47384 .6871 .47932 .68562 .47604 .69697 Mtetra
.505 .208 .395 r
.47604 .69697 .47932 .68562 .48482 .68412 .48156 .69557 Mtetra
.506 .209 .397 r
.48156 .69557 .48482 .68412 .49033 .68261 .4871 .69417 Mtetra
.506 .21 .398 r
.4871 .69417 .49033 .68261 .49585 .6811 .49264 .69275 Mtetra
.507 .211 .399 r
.49264 .69275 .49585 .6811 .50138 .67958 .4982 .69133 Mtetra
.507 .212 .401 r
.4982 .69133 .50138 .67958 .50692 .67804 .50377 .6899 Mtetra
.508 .214 .402 r
.50377 .6899 .50692 .67804 .51247 .67651 .50936 .68846 Mtetra
.508 .215 .403 r
.50936 .68846 .51247 .67651 .51803 .67495 .51495 .68701 Mtetra
.509 .216 .405 r
.51495 .68701 .51803 .67495 .52361 .67339 .52056 .68556 Mtetra
.509 .217 .406 r
.52056 .68556 .52361 .67339 .52919 .67182 .52618 .6841 Mtetra
.509 .218 .408 r
.52618 .6841 .52919 .67182 .53479 .67024 .53181 .68263 Mtetra
.51 .22 .409 r
.53181 .68263 .53479 .67024 .5404 .66865 .53745 .68115 Mtetra
.511 .221 .41 r
.53745 .68115 .5404 .66865 .54602 .66705 .5431 .67967 Mtetra
.511 .222 .412 r
.5431 .67967 .54602 .66705 .55165 .66544 .54877 .67817 Mtetra
.511 .223 .413 r
.54877 .67817 .55165 .66544 .5573 .66382 .55444 .67667 Mtetra
.512 .225 .414 r
.55444 .67667 .5573 .66382 .56295 .66219 .56013 .67516 Mtetra
.512 .226 .416 r
.56013 .67516 .56295 .66219 .56862 .66054 .56583 .67364 Mtetra
.513 .227 .417 r
.56583 .67364 .56862 .66054 .57429 .65889 .57155 .67211 Mtetra
.513 .228 .419 r
.57155 .67211 .57429 .65889 .57998 .65723 .57727 .67058 Mtetra
.514 .229 .42 r
.57727 .67058 .57998 .65723 .58568 .65555 .58301 .66903 Mtetra
.514 .23 .421 r
.58301 .66903 .58568 .65555 .59139 .65387 .58876 .66747 Mtetra
.515 .232 .423 r
.58876 .66747 .59139 .65387 .59712 .65217 .59452 .66591 Mtetra
.515 .233 .424 r
.59452 .66591 .59712 .65217 .60285 .65046 .60029 .66434 Mtetra
.516 .234 .425 r
.60029 .66434 .60285 .65046 .60859 .64874 .60607 .66275 Mtetra
.516 .235 .427 r
.60607 .66275 .60859 .64874 .61435 .64701 .61187 .66115 Mtetra
.517 .236 .428 r
.61187 .66115 .61435 .64701 .62012 .64526 .61768 .65955 Mtetra
.517 .237 .429 r
.61768 .65955 .62012 .64526 .6259 .6435 .6235 .65793 Mtetra
.518 .239 .43 r
.6235 .65793 .6259 .6435 .63169 .64173 .62933 .65631 Mtetra
.518 .24 .432 r
.62933 .65631 .63169 .64173 .63749 .63995 .63518 .65467 Mtetra
.518 .241 .433 r
.63518 .65467 .63749 .63995 .6433 .63815 .64103 .65302 Mtetra
.519 .242 .434 r
.64103 .65302 .6433 .63815 .64912 .63634 .6469 .65136 Mtetra
.519 .243 .436 r
.6469 .65136 .64912 .63634 .65496 .63451 .65278 .64969 Mtetra
.52 .244 .437 r
.65278 .64969 .65496 .63451 .66081 .63267 .65867 .648 Mtetra
.52 .245 .438 r
.65867 .648 .66081 .63267 .66666 .63082 .66458 .64631 Mtetra
.52 .246 .439 r
.66458 .64631 .66666 .63082 .67253 .62895 .67049 .6446 Mtetra
.521 .247 .441 r
.67049 .6446 .67253 .62895 .67841 .62707 .67642 .64288 Mtetra
.521 .249 .442 r
.67642 .64288 .67841 .62707 .6843 .62518 .68236 .64115 Mtetra
.522 .25 .443 r
.68236 .64115 .6843 .62518 .6902 .62326 .68831 .6394 Mtetra
.522 .251 .444 r
.68831 .6394 .6902 .62326 .69611 .62133 .69427 .63764 Mtetra
.522 .252 .446 r
.69427 .63764 .69611 .62133 .70203 .61939 .70025 .63586 Mtetra
.523 .253 .447 r
.70025 .63586 .70203 .61939 .70797 .61742 .70623 .63407 Mtetra
.523 .254 .448 r
.70623 .63407 .70797 .61742 .71391 .61545 .71223 .63227 Mtetra
.523 .255 .449 r
.71223 .63227 .71391 .61545 .71987 .61345 .71824 .63045 Mtetra
.524 .256 .45 r
.71824 .63045 .71987 .61345 .72583 .61144 .72426 .62861 Mtetra
.524 .257 .451 r
.72426 .62861 .72583 .61144 .73181 .60941 .73029 .62676 Mtetra
.524 .258 .453 r
.73029 .62676 .73181 .60941 .73779 .60736 .73634 .62489 Mtetra
.525 .259 .454 r
.73634 .62489 .73779 .60736 .74379 .60529 .74239 .62301 Mtetra
.525 .26 .455 r
.74239 .62301 .74379 .60529 .7498 .60321 .74846 .62111 Mtetra
.525 .26 .456 r
.74846 .62111 .7498 .60321 .75582 .6011 .75453 .61919 Mtetra
.526 .261 .457 r
.75453 .61919 .75582 .6011 .76185 .59898 .76062 .61726 Mtetra
.526 .262 .458 r
.76062 .61726 .76185 .59898 .76788 .59683 .76672 .6153 Mtetra
.526 .263 .459 r
.76672 .6153 .76788 .59683 .77393 .59466 .77283 .61333 Mtetra
.527 .264 .46 r
.77283 .61333 .77393 .59466 .77999 .59248 .77896 .61134 Mtetra
.527 .265 .461 r
.77896 .61134 .77999 .59248 .78606 .59027 .78509 .60932 Mtetra
.527 .266 .462 r
.78509 .60932 .78606 .59027 .79213 .58804 .79123 .60729 Mtetra
.527 .267 .463 r
.79123 .60729 .79213 .58804 .79822 .58579 .79739 .60524 Mtetra
.527 .267 .464 r
.79739 .60524 .79822 .58579 .80432 .58351 .80355 .60316 Mtetra
.528 .268 .465 r
.80355 .60316 .80432 .58351 .81042 .58121 .80973 .60107 Mtetra
.528 .269 .466 r
.80973 .60107 .81042 .58121 .81654 .57889 .81592 .59895 Mtetra
.528 .27 .467 r
.81592 .59895 .81654 .57889 .82267 .57654 .82211 .5968 Mtetra
.528 .271 .468 r
.82211 .5968 .82267 .57654 .8288 .57417 .82832 .59464 Mtetra
.529 .271 .469 r
.82832 .59464 .8288 .57417 .83494 .57177 .83454 .59245 Mtetra
.529 .272 .47 r
.83454 .59245 .83494 .57177 .84109 .56935 .84076 .59023 Mtetra
.529 .273 .471 r
.84076 .59023 .84109 .56935 .84725 .5669 .847 .58799 Mtetra
.529 .274 .472 r
.847 .58799 .84725 .5669 .85342 .56442 .85324 .58572 Mtetra
.529 .274 .473 r
.85324 .58572 .85342 .56442 .8596 .56192 .8595 .58342 Mtetra
.529 .275 .474 r
.8595 .58342 .8596 .56192 .86578 .55938 .86576 .5811 Mtetra
.529 .276 .475 r
.86576 .5811 .86578 .55938 .87198 .55682 .87204 .57874 Mtetra
.53 .276 .476 r
.87204 .57874 .87198 .55682 .87818 .55424 .87832 .57636 Mtetra
.53 .277 .476 r
.87832 .57636 .87818 .55424 .88439 .55161 .88461 .57394 Mtetra
.53 .277 .477 r
.88461 .57394 .88439 .55161 .8906 .54895 .89091 .57149 Mtetra
.53 .278 .478 r
.89091 .57149 .8906 .54895 .89683 .54626 .89721 .56901 Mtetra
.529 .278 .479 r
.89721 .56901 .89683 .54626 .90305 .54351 .90352 .56645 Mtetra
.90352 .56645 .90305 .54351 .90928 .5407 .90984 .56382 Mtetra
.528 .278 .48 r
.90984 .56382 .90928 .5407 .91551 .5378 .91615 .5611 Mtetra
.525 .276 .48 r
.91615 .5611 .91551 .5378 .92172 .53467 .92244 .5581 Mtetra
.523 .275 .481 r
.92244 .5581 .92172 .53467 .92792 .53137 .92872 .55488 Mtetra
.515 .269 .48 r
.92872 .55488 .92792 .53137 .93407 .52752 .93492 .55101 Mtetra
.504 .261 .479 r
.93492 .55101 .93407 .52752 .94013 .52296 .94103 .54626 Mtetra
.494 .253 .478 r
.94103 .54626 .94013 .52296 .94613 .51787 .94705 .54084 Mtetra
.459 .226 .473 r
.94705 .54084 .94613 .51787 .95187 .51077 .95276 .53295 Mtetra
.433 .206 .467 r
.95276 .53295 .95187 .51077 .95746 .50257 .95828 .52368 Mtetra
.39 .171 .457 r
.95828 .52368 .95746 .50257 .96282 .4927 .96351 .51235 Mtetra
.319 .115 .439 r
.96351 .51235 .96282 .4927 .96786 .48055 .96834 .49819 Mtetra
.257 .063 .415 r
.96834 .49819 .96786 .48055 .97274 .46745 .97298 .48284 Mtetra
.855 .514 .408 r
.39348 .65804 .39683 .65573 .40158 .66894 .3982 .67202 Mtetra
.835 .494 .409 r
.3982 .67202 .40158 .66894 .40642 .68093 .40302 .68476 Mtetra
.794 .443 .393 r
.40302 .68476 .40642 .68093 .41141 .68987 .408 .69429 Mtetra
.75 .392 .376 r
.408 .69429 .41141 .68987 .41652 .69645 .4131 .70135 Mtetra
.711 .35 .363 r
.4131 .70135 .41652 .69645 .4217 .70146 .41829 .70676 Mtetra
.615 .243 .314 r
.41829 .70676 .4217 .70146 .427 .70352 .42359 .70907 Mtetra
.58 .209 .302 r
.42359 .70907 .427 .70352 .43235 .70477 .42895 .71053 Mtetra
.528 .156 .279 r
.42895 .71053 .43235 .70477 .43774 .70497 .43435 .71088 Mtetra
.483 .112 .259 r
.43435 .71088 .43774 .70497 .44316 .70436 .43979 .71038 Mtetra
.468 .099 .255 r
.43979 .71038 .44316 .70436 .4486 .7035 .44525 .70962 Mtetra
.451 .083 .249 r
.44525 .70962 .4486 .7035 .45406 .70233 .45073 .70853 Mtetra
.446 .08 .249 r
.45073 .70853 .45406 .70233 .45954 .70106 .45622 .70734 Mtetra
.444 .08 .252 r
.45622 .70734 .45954 .70106 .46502 .69973 .46173 .70609 Mtetra
.444 .081 .254 r
.46173 .70609 .46502 .69973 .47052 .69836 .46725 .7048 Mtetra
.445 .084 .258 r
.46725 .7048 .47052 .69836 .47604 .69697 .47278 .70349 Mtetra
.446 .087 .261 r
.47278 .70349 .47604 .69697 .48156 .69557 .47833 .70217 Mtetra
.448 .09 .265 r
.47833 .70217 .48156 .69557 .4871 .69417 .48389 .70085 Mtetra
.449 .093 .268 r
.48389 .70085 .4871 .69417 .49264 .69275 .48945 .69952 Mtetra
.451 .097 .272 r
.48945 .69952 .49264 .69275 .4982 .69133 .49504 .69818 Mtetra
.453 .1 .276 r
.49504 .69818 .4982 .69133 .50377 .6899 .50063 .69684 Mtetra
.454 .103 .279 r
.50063 .69684 .50377 .6899 .50936 .68846 .50623 .69549 Mtetra
.456 .106 .283 r
.50623 .69549 .50936 .68846 .51495 .68701 .51185 .69413 Mtetra
.457 .109 .287 r
.51185 .69413 .51495 .68701 .52056 .68556 .51748 .69277 Mtetra
.459 .113 .29 r
.51748 .69277 .52056 .68556 .52618 .6841 .52312 .69141 Mtetra
.46 .116 .294 r
.52312 .69141 .52618 .6841 .53181 .68263 .52878 .69004 Mtetra
.462 .119 .297 r
.52878 .69004 .53181 .68263 .53745 .68115 .53444 .68866 Mtetra
.464 .122 .301 r
.53444 .68866 .53745 .68115 .5431 .67967 .54012 .68728 Mtetra
.465 .125 .305 r
.54012 .68728 .5431 .67967 .54877 .67817 .54581 .68589 Mtetra
.467 .128 .308 r
.54581 .68589 .54877 .67817 .55444 .67667 .55151 .68449 Mtetra
.468 .132 .312 r
.55151 .68449 .55444 .67667 .56013 .67516 .55723 .68309 Mtetra
.47 .135 .315 r
.55723 .68309 .56013 .67516 .56583 .67364 .56296 .68168 Mtetra
.471 .138 .319 r
.56296 .68168 .56583 .67364 .57155 .67211 .5687 .68027 Mtetra
.473 .141 .322 r
.5687 .68027 .57155 .67211 .57727 .67058 .57445 .67885 Mtetra
.474 .144 .325 r
.57445 .67885 .57727 .67058 .58301 .66903 .58022 .67742 Mtetra
.475 .147 .329 r
.58022 .67742 .58301 .66903 .58876 .66747 .58599 .67598 Mtetra
.477 .15 .332 r
.58599 .67598 .58876 .66747 .59452 .66591 .59178 .67454 Mtetra
.479 .153 .336 r
.59178 .67454 .59452 .66591 .60029 .66434 .59759 .6731 Mtetra
.48 .156 .339 r
.59759 .6731 .60029 .66434 .60607 .66275 .6034 .67164 Mtetra
.481 .159 .342 r
.6034 .67164 .60607 .66275 .61187 .66115 .60923 .67018 Mtetra
.483 .162 .345 r
.60923 .67018 .61187 .66115 .61768 .65955 .61507 .66871 Mtetra
.484 .164 .349 r
.61507 .66871 .61768 .65955 .6235 .65793 .62092 .66723 Mtetra
.485 .167 .352 r
.62092 .66723 .6235 .65793 .62933 .65631 .62679 .66574 Mtetra
.487 .17 .355 r
.62679 .66574 .62933 .65631 .63518 .65467 .63267 .66425 Mtetra
.488 .173 .358 r
.63267 .66425 .63518 .65467 .64103 .65302 .63856 .66274 Mtetra
.489 .176 .361 r
.63856 .66274 .64103 .65302 .6469 .65136 .64446 .66123 Mtetra
.49 .178 .364 r
.64446 .66123 .6469 .65136 .65278 .64969 .65038 .65971 Mtetra
.492 .181 .367 r
.65038 .65971 .65278 .64969 .65867 .648 .6563 .65818 Mtetra
.493 .184 .37 r
.6563 .65818 .65867 .648 .66458 .64631 .66225 .65665 Mtetra
.494 .186 .373 r
.66225 .65665 .66458 .64631 .67049 .6446 .6682 .6551 Mtetra
.495 .189 .376 r
.6682 .6551 .67049 .6446 .67642 .64288 .67417 .65354 Mtetra
.496 .192 .379 r
.67417 .65354 .67642 .64288 .68236 .64115 .68015 .65198 Mtetra
.497 .194 .382 r
.68015 .65198 .68236 .64115 .68831 .6394 .68614 .6504 Mtetra
.499 .197 .385 r
.68614 .6504 .68831 .6394 .69427 .63764 .69214 .64882 Mtetra
.5 .199 .388 r
.69214 .64882 .69427 .63764 .70025 .63586 .69816 .64722 Mtetra
.501 .202 .39 r
.69816 .64722 .70025 .63586 .70623 .63407 .70419 .64561 Mtetra
.502 .204 .393 r
.70419 .64561 .70623 .63407 .71223 .63227 .71023 .64399 Mtetra
.503 .207 .396 r
.71023 .64399 .71223 .63227 .71824 .63045 .71629 .64237 Mtetra
.504 .209 .399 r
.71629 .64237 .71824 .63045 .72426 .62861 .72236 .64072 Mtetra
.505 .211 .401 r
.72236 .64072 .72426 .62861 .73029 .62676 .72844 .63907 Mtetra
.506 .214 .404 r
.72844 .63907 .73029 .62676 .73634 .62489 .73453 .6374 Mtetra
.507 .216 .406 r
.73453 .6374 .73634 .62489 .74239 .62301 .74064 .63573 Mtetra
.508 .218 .409 r
.74064 .63573 .74239 .62301 .74846 .62111 .74675 .63404 Mtetra
.509 .22 .411 r
.74675 .63404 .74846 .62111 .75453 .61919 .75288 .63233 Mtetra
.51 .223 .414 r
.75288 .63233 .75453 .61919 .76062 .61726 .75903 .63061 Mtetra
.51 .225 .416 r
.75903 .63061 .76062 .61726 .76672 .6153 .76518 .62888 Mtetra
.511 .227 .419 r
.76518 .62888 .76672 .6153 .77283 .61333 .77135 .62713 Mtetra
.512 .229 .421 r
.77135 .62713 .77283 .61333 .77896 .61134 .77753 .62537 Mtetra
.513 .231 .424 r
.77753 .62537 .77896 .61134 .78509 .60932 .78372 .62359 Mtetra
.514 .233 .426 r
.78372 .62359 .78509 .60932 .79123 .60729 .78993 .6218 Mtetra
.515 .235 .428 r
.78993 .6218 .79123 .60729 .79739 .60524 .79614 .61999 Mtetra
.515 .237 .43 r
.79614 .61999 .79739 .60524 .80355 .60316 .80237 .61816 Mtetra
.516 .239 .433 r
.80237 .61816 .80355 .60316 .80973 .60107 .80861 .61632 Mtetra
.517 .241 .435 r
.80861 .61632 .80973 .60107 .81592 .59895 .81487 .61445 Mtetra
.518 .243 .437 r
.81487 .61445 .81592 .59895 .82211 .5968 .82113 .61257 Mtetra
.518 .245 .439 r
.82113 .61257 .82211 .5968 .82832 .59464 .82741 .61067 Mtetra
.519 .246 .441 r
.82741 .61067 .82832 .59464 .83454 .59245 .83369 .60875 Mtetra
.52 .248 .443 r
.83369 .60875 .83454 .59245 .84076 .59023 .83999 .60681 Mtetra
.52 .25 .445 r
.83999 .60681 .84076 .59023 .847 .58799 .8463 .60484 Mtetra
.521 .252 .447 r
.8463 .60484 .847 .58799 .85324 .58572 .85263 .60286 Mtetra
.522 .253 .449 r
.85263 .60286 .85324 .58572 .8595 .58342 .85896 .60085 Mtetra
.522 .255 .451 r
.85896 .60085 .8595 .58342 .86576 .5811 .8653 .59882 Mtetra
.523 .257 .453 r
.8653 .59882 .86576 .5811 .87204 .57874 .87166 .59676 Mtetra
.523 .258 .455 r
.87166 .59676 .87204 .57874 .87832 .57636 .87802 .59468 Mtetra
.524 .26 .456 r
.87802 .59468 .87832 .57636 .88461 .57394 .8844 .59257 Mtetra
.524 .261 .458 r
.8844 .59257 .88461 .57394 .89091 .57149 .89078 .59042 Mtetra
.525 .263 .46 r
.89078 .59042 .89091 .57149 .89721 .56901 .89718 .58826 Mtetra
.525 .263 .461 r
.89718 .58826 .89721 .56901 .90352 .56645 .90358 .58601 Mtetra
.524 .264 .463 r
.90358 .58601 .90352 .56645 .90984 .56382 .90998 .5837 Mtetra
.524 .265 .464 r
.90998 .5837 .90984 .56382 .91615 .5611 .91639 .58127 Mtetra
.52 .263 .466 r
.91639 .58127 .91615 .5611 .92244 .5581 .92277 .57854 Mtetra
.517 .262 .467 r
.92277 .57854 .92244 .5581 .92872 .55488 .92913 .57556 Mtetra
.507 .255 .467 r
.92913 .57556 .92872 .55488 .93492 .55101 .93541 .57181 Mtetra
.492 .244 .466 r
.93541 .57181 .93492 .55101 .94103 .54626 .94157 .56703 Mtetra
.481 .235 .465 r
.94157 .56703 .94103 .54626 .94705 .54084 .94764 .56148 Mtetra
.433 .199 .458 r
.94764 .56148 .94705 .54084 .95276 .53295 .95334 .55299 Mtetra
.4 .173 .451 r
.95334 .55299 .95276 .53295 .95828 .52368 .95881 .54288 Mtetra
.342 .129 .438 r
.95881 .54288 .95828 .52368 .96351 .51235 .96394 .53032 Mtetra
.246 .055 .412 r
.96394 .53032 .96351 .51235 .96834 .49819 .9686 .51437 Mtetra
.164 0 .381 r
.9686 .51437 .96834 .49819 .97298 .48284 .97302 .497 Mtetra
.874 .528 .392 r
.39015 .65924 .39348 .65804 .3982 .67202 .39485 .67386 Mtetra
.858 .509 .39 r
.39485 .67386 .3982 .67202 .40302 .68476 .39964 .68719 Mtetra
.821 .457 .366 r
.39964 .68719 .40302 .68476 .408 .69429 .40461 .69721 Mtetra
.778 .4 .34 r
.40461 .69721 .408 .69429 .4131 .70135 .40971 .70466 Mtetra
.737 .351 .319 r
.40971 .70466 .4131 .70135 .41829 .70676 .41489 .7104 Mtetra
.625 .213 .242 r
.41489 .7104 .41829 .70676 .42359 .70907 .42021 .71291 Mtetra
.58 .165 .219 r
.42021 .71291 .42359 .70907 .42895 .71053 .42557 .71454 Mtetra
.508 .088 .178 r
.42557 .71454 .42895 .71053 .43435 .71088 .43099 .71502 Mtetra
.442 .019 .14 r
.43099 .71502 .43435 .71088 .43979 .71038 .43644 .71462 Mtetra
.421 0 .132 r
.43644 .71462 .43979 .71038 .44525 .70962 .44191 .71393 Mtetra
.394 0 .12 r
.44191 .71393 .44525 .70962 .45073 .70853 .44741 .71292 Mtetra
.387 0 .12 r
.44741 .71292 .45073 .70853 .45622 .70734 .45292 .7118 Mtetra
.385 0 .123 r
.45292 .7118 .45622 .70734 .46173 .70609 .45845 .71061 Mtetra
.384 0 .127 r
.45845 .71061 .46173 .70609 .46725 .7048 .46398 .70939 Mtetra
.387 0 .133 r
.46398 .70939 .46725 .7048 .47278 .70349 .46953 .70815 Mtetra
.389 0 .138 r
.46953 .70815 .47278 .70349 .47833 .70217 .4751 .7069 Mtetra
.392 0 .144 r
.4751 .7069 .47833 .70217 .48389 .70085 .48067 .70564 Mtetra
.395 0 .15 r
.48067 .70564 .48389 .70085 .48945 .69952 .48626 .70438 Mtetra
.398 0 .156 r
.48626 .70438 .48945 .69952 .49504 .69818 .49186 .70312 Mtetra
.401 .002 .162 r
.49186 .70312 .49504 .69818 .50063 .69684 .49747 .70185 Mtetra
.404 .007 .168 r
.49747 .70185 .50063 .69684 .50623 .69549 .50309 .70059 Mtetra
.406 .012 .174 r
.50309 .70059 .50623 .69549 .51185 .69413 .50873 .69931 Mtetra
.409 .017 .18 r
.50873 .69931 .51185 .69413 .51748 .69277 .51438 .69803 Mtetra
.412 .022 .186 r
.51438 .69803 .51748 .69277 .52312 .69141 .52004 .69675 Mtetra
.415 .027 .191 r
.52004 .69675 .52312 .69141 .52878 .69004 .52572 .69546 Mtetra
.418 .032 .197 r
.52572 .69546 .52878 .69004 .53444 .68866 .5314 .69417 Mtetra
.421 .037 .203 r
.5314 .69417 .53444 .68866 .54012 .68728 .5371 .69288 Mtetra
.423 .042 .209 r
.5371 .69288 .54012 .68728 .54581 .68589 .54281 .69158 Mtetra
.426 .047 .214 r
.54281 .69158 .54581 .68589 .55151 .68449 .54854 .69027 Mtetra
.429 .052 .22 r
.54854 .69027 .55151 .68449 .55723 .68309 .55428 .68897 Mtetra
.431 .057 .225 r
.55428 .68897 .55723 .68309 .56296 .68168 .56003 .68766 Mtetra
.434 .061 .231 r
.56003 .68766 .56296 .68168 .5687 .68027 .56579 .68634 Mtetra
.437 .067 .236 r
.56579 .68634 .5687 .68027 .57445 .67885 .57157 .68503 Mtetra
.439 .071 .242 r
.57157 .68503 .57445 .67885 .58022 .67742 .57736 .6837 Mtetra
.441 .076 .247 r
.57736 .6837 .58022 .67742 .58599 .67598 .58316 .68237 Mtetra
.444 .081 .252 r
.58316 .68237 .58599 .67598 .59178 .67454 .58898 .68104 Mtetra
.446 .085 .258 r
.58898 .68104 .59178 .67454 .59759 .6731 .59481 .67971 Mtetra
.449 .09 .263 r
.59481 .67971 .59759 .6731 .6034 .67164 .60065 .67837 Mtetra
.451 .094 .268 r
.60065 .67837 .6034 .67164 .60923 .67018 .6065 .67702 Mtetra
.453 .099 .273 r
.6065 .67702 .60923 .67018 .61507 .66871 .61237 .67567 Mtetra
.456 .103 .278 r
.61237 .67567 .61507 .66871 .62092 .66723 .61825 .67431 Mtetra
.458 .108 .283 r
.61825 .67431 .62092 .66723 .62679 .66574 .62415 .67295 Mtetra
.46 .112 .288 r
.62415 .67295 .62679 .66574 .63267 .66425 .63006 .67159 Mtetra
.462 .116 .293 r
.63006 .67159 .63267 .66425 .63856 .66274 .63598 .67021 Mtetra
.464 .12 .297 r
.63598 .67021 .63856 .66274 .64446 .66123 .64191 .66884 Mtetra
.466 .125 .302 r
.64191 .66884 .64446 .66123 .65038 .65971 .64786 .66746 Mtetra
.468 .129 .307 r
.64786 .66746 .65038 .65971 .6563 .65818 .65382 .66607 Mtetra
.47 .133 .311 r
.65382 .66607 .6563 .65818 .66225 .65665 .6598 .66468 Mtetra
.472 .137 .316 r
.6598 .66468 .66225 .65665 .6682 .6551 .66578 .66327 Mtetra
.474 .141 .32 r
.66578 .66327 .6682 .6551 .67417 .65354 .67178 .66187 Mtetra
.476 .145 .325 r
.67178 .66187 .67417 .65354 .68015 .65198 .6778 .66046 Mtetra
.478 .149 .329 r
.6778 .66046 .68015 .65198 .68614 .6504 .68383 .65904 Mtetra
.48 .152 .333 r
.68383 .65904 .68614 .6504 .69214 .64882 .68987 .65761 Mtetra
.482 .156 .338 r
.68987 .65761 .69214 .64882 .69816 .64722 .69593 .65618 Mtetra
.483 .16 .342 r
.69593 .65618 .69816 .64722 .70419 .64561 .70199 .65474 Mtetra
.485 .164 .346 r
.70199 .65474 .70419 .64561 .71023 .64399 .70808 .6533 Mtetra
.487 .167 .35 r
.70808 .6533 .71023 .64399 .71629 .64237 .71417 .65185 Mtetra
.488 .171 .354 r
.71417 .65185 .71629 .64237 .72236 .64072 .72028 .65038 Mtetra
.49 .174 .358 r
.72028 .65038 .72236 .64072 .72844 .63907 .72641 .64892 Mtetra
.492 .178 .362 r
.72641 .64892 .72844 .63907 .73453 .6374 .73254 .64744 Mtetra
.493 .181 .365 r
.73254 .64744 .73453 .6374 .74064 .63573 .73869 .64595 Mtetra
.495 .184 .369 r
.73869 .64595 .74064 .63573 .74675 .63404 .74486 .64446 Mtetra
.496 .188 .373 r
.74486 .64446 .74675 .63404 .75288 .63233 .75104 .64296 Mtetra
.498 .191 .376 r
.75104 .64296 .75288 .63233 .75903 .63061 .75723 .64145 Mtetra
.499 .194 .38 r
.75723 .64145 .75903 .63061 .76518 .62888 .76343 .63992 Mtetra
.5 .197 .384 r
.76343 .63992 .76518 .62888 .77135 .62713 .76965 .63839 Mtetra
.502 .2 .387 r
.76965 .63839 .77135 .62713 .77753 .62537 .77588 .63685 Mtetra
.503 .203 .39 r
.77588 .63685 .77753 .62537 .78372 .62359 .78213 .6353 Mtetra
.504 .206 .394 r
.78213 .6353 .78372 .62359 .78993 .6218 .78839 .63373 Mtetra
.506 .209 .397 r
.78839 .63373 .78993 .6218 .79614 .61999 .79466 .63216 Mtetra
.507 .212 .4 r
.79466 .63216 .79614 .61999 .80237 .61816 .80095 .63057 Mtetra
.508 .215 .403 r
.80095 .63057 .80237 .61816 .80861 .61632 .80725 .62897 Mtetra
.509 .218 .406 r
.80725 .62897 .80861 .61632 .81487 .61445 .81356 .62736 Mtetra
.51 .22 .409 r
.81356 .62736 .81487 .61445 .82113 .61257 .81989 .62573 Mtetra
.511 .223 .412 r
.81989 .62573 .82113 .61257 .82741 .61067 .82623 .6241 Mtetra
.513 .226 .415 r
.82623 .6241 .82741 .61067 .83369 .60875 .83258 .62245 Mtetra
.514 .228 .418 r
.83258 .62245 .83369 .60875 .83999 .60681 .83895 .62078 Mtetra
.515 .23 .421 r
.83895 .62078 .83999 .60681 .8463 .60484 .84533 .61909 Mtetra
.516 .233 .424 r
.84533 .61909 .8463 .60484 .85263 .60286 .85172 .61739 Mtetra
.517 .235 .427 r
.85172 .61739 .85263 .60286 .85896 .60085 .85813 .61568 Mtetra
.517 .238 .429 r
.85813 .61568 .85896 .60085 .8653 .59882 .86455 .61394 Mtetra
.518 .24 .432 r
.86455 .61394 .8653 .59882 .87166 .59676 .87098 .61219 Mtetra
.519 .242 .435 r
.87098 .61219 .87166 .59676 .87802 .59468 .87742 .61042 Mtetra
.52 .244 .437 r
.87742 .61042 .87802 .59468 .8844 .59257 .88388 .60862 Mtetra
.521 .247 .439 r
.88388 .60862 .8844 .59257 .89078 .59042 .89035 .6068 Mtetra
.522 .249 .442 r
.89035 .6068 .89078 .59042 .89718 .58826 .89683 .60496 Mtetra
.521 .25 .444 r
.89683 .60496 .89718 .58826 .90358 .58601 .90332 .60304 Mtetra
.521 .251 .446 r
.90332 .60304 .90358 .58601 .90998 .5837 .90981 .60106 Mtetra
.521 .252 .448 r
.90981 .60106 .90998 .5837 .91639 .58127 .91631 .59896 Mtetra
.516 .25 .45 r
.91631 .59896 .91639 .58127 .92277 .57854 .92277 .59653 Mtetra
.513 .248 .451 r
.92277 .59653 .92277 .57854 .92913 .57556 .92922 .59381 Mtetra
.499 .239 .451 r
.92922 .59381 .92913 .57556 .93541 .57181 .93558 .59024 Mtetra
.481 .226 .45 r
.93558 .59024 .93541 .57181 .94157 .56703 .9418 .5855 Mtetra
.465 .215 .449 r
.9418 .5855 .94157 .56703 .94764 .56148 .94792 .57987 Mtetra
.402 .167 .44 r
.94792 .57987 .94764 .56148 .95334 .55299 .95361 .5709 Mtetra
.358 .133 .43 r
.95361 .5709 .95334 .55299 .95881 .54288 .95905 .56007 Mtetra
.282 .075 .411 r
.95905 .56007 .95881 .54288 .96394 .53032 .9641 .54642 Mtetra
.152 0 .373 r
.9641 .54642 .96394 .53032 .9686 .51437 .96861 .52888 Mtetra
.044 0 .331 r
.96861 .52888 .9686 .51437 .97302 .497 .97284 .50969 Mtetra
.896 .542 .365 r
.38686 .65908 .39015 .65924 .39485 .67386 .39153 .67414 Mtetra
.884 .523 .358 r
.39153 .67414 .39485 .67386 .39964 .68719 .39631 .68789 Mtetra
.853 .469 .318 r
.39631 .68789 .39964 .68719 .40461 .69721 .40126 .69825 Mtetra
.813 .403 .271 r
.40126 .69825 .40461 .69721 .40971 .70466 .40636 .70598 Mtetra
.771 .34 .228 r
.40636 .70598 .40971 .70466 .41489 .7104 .41154 .71196 Mtetra
.622 .133 .071 r
.41154 .71196 .41489 .7104 .42021 .71291 .41686 .71462 Mtetra
.552 .049 .014 r
.41686 .71462 .42021 .71291 .42557 .71454 .42223 .71638 Mtetra
.425 0 0 r
.42223 .71638 .42557 .71454 .43099 .71502 .42766 .71695 Mtetra
.297 0 0 r
.42766 .71695 .43099 .71502 .43644 .71462 .43312 .71661 Mtetra
.255 0 0 r
.43312 .71661 .43644 .71462 .44191 .71393 .43861 .71599 Mtetra
.202 0 0 r
.43861 .71599 .44191 .71393 .44741 .71292 .44412 .71504 Mtetra
.189 0 0 r
.44412 .71504 .44741 .71292 .45292 .7118 .44964 .71397 Mtetra
.186 0 0 r
.44964 .71397 .45292 .7118 .45845 .71061 .45518 .71283 Mtetra
.45518 .71283 .45845 .71061 .46398 .70939 .46073 .71166 Mtetra
.192 0 0 r
.46073 .71166 .46398 .70939 .46953 .70815 .46629 .71047 Mtetra
.199 0 0 r
.46629 .71047 .46953 .70815 .4751 .7069 .47187 .70927 Mtetra
.207 0 0 r
.47187 .70927 .4751 .7069 .48067 .70564 .47746 .70808 Mtetra
.215 0 0 r
.47746 .70808 .48067 .70564 .48626 .70438 .48306 .70687 Mtetra
.222 0 0 r
.48306 .70687 .48626 .70438 .49186 .70312 .48868 .70567 Mtetra
.23 0 0 r
.48868 .70567 .49186 .70312 .49747 .70185 .4943 .70446 Mtetra
.238 0 0 r
.4943 .70446 .49747 .70185 .50309 .70059 .49994 .70325 Mtetra
.245 0 0 r
.49994 .70325 .50309 .70059 .50873 .69931 .5056 .70204 Mtetra
.253 0 0 r
.5056 .70204 .50873 .69931 .51438 .69803 .51126 .70082 Mtetra
.26 0 0 r
.51126 .70082 .51438 .69803 .52004 .69675 .51694 .69961 Mtetra
.267 0 0 r
.51694 .69961 .52004 .69675 .52572 .69546 .52263 .69839 Mtetra
.275 0 0 r
.52263 .69839 .52572 .69546 .5314 .69417 .52833 .69717 Mtetra
.282 0 0 r
.52833 .69717 .5314 .69417 .5371 .69288 .53405 .69595 Mtetra
.289 0 0 r
.53405 .69595 .5371 .69288 .54281 .69158 .53978 .69472 Mtetra
.296 0 0 r
.53978 .69472 .54281 .69158 .54854 .69027 .54553 .6935 Mtetra
.303 0 0 r
.54553 .6935 .54854 .69027 .55428 .68897 .55128 .69227 Mtetra
.309 0 0 r
.55128 .69227 .55428 .68897 .56003 .68766 .55705 .69104 Mtetra
.316 0 0 r
.55705 .69104 .56003 .68766 .56579 .68634 .56283 .6898 Mtetra
.323 0 .005 r
.56283 .6898 .56579 .68634 .57157 .68503 .56863 .68857 Mtetra
.329 0 .017 r
.56863 .68857 .57157 .68503 .57736 .6837 .57444 .68733 Mtetra
.335 0 .028 r
.57444 .68733 .57736 .6837 .58316 .68237 .58026 .68609 Mtetra
.342 0 .04 r
.58026 .68609 .58316 .68237 .58898 .68104 .5861 .68485 Mtetra
.348 0 .051 r
.5861 .68485 .58898 .68104 .59481 .67971 .59195 .68361 Mtetra
.354 0 .062 r
.59195 .68361 .59481 .67971 .60065 .67837 .59781 .68236 Mtetra
.36 0 .073 r
.59781 .68236 .60065 .67837 .6065 .67702 .60369 .68112 Mtetra
.365 0 .084 r
.60369 .68112 .6065 .67702 .61237 .67567 .60958 .67987 Mtetra
.371 0 .095 r
.60958 .67987 .61237 .67567 .61825 .67431 .61549 .67861 Mtetra
.376 0 .105 r
.61549 .67861 .61825 .67431 .62415 .67295 .6214 .67736 Mtetra
.381 0 .115 r
.6214 .67736 .62415 .67295 .63006 .67159 .62734 .6761 Mtetra
.387 0 .126 r
.62734 .6761 .63006 .67159 .63598 .67021 .63328 .67484 Mtetra
.392 0 .136 r
.63328 .67484 .63598 .67021 .64191 .66884 .63924 .67358 Mtetra
.397 0 .146 r
.63924 .67358 .64191 .66884 .64786 .66746 .64522 .67231 Mtetra
.402 0 .155 r
.64522 .67231 .64786 .66746 .65382 .66607 .6512 .67105 Mtetra
.406 .007 .165 r
.6512 .67105 .65382 .66607 .6598 .66468 .65721 .66978 Mtetra
.411 .015 .174 r
.65721 .66978 .6598 .66468 .66578 .66327 .66322 .66851 Mtetra
.415 .023 .183 r
.66322 .66851 .66578 .66327 .67178 .66187 .66925 .66723 Mtetra
.42 .031 .192 r
.66925 .66723 .67178 .66187 .6778 .66046 .6753 .66596 Mtetra
.424 .038 .201 r
.6753 .66596 .6778 .66046 .68383 .65904 .68135 .66468 Mtetra
.428 .046 .21 r
.68135 .66468 .68383 .65904 .68987 .65761 .68743 .66339 Mtetra
.432 .054 .218 r
.68743 .66339 .68987 .65761 .69593 .65618 .69351 .66211 Mtetra
.436 .061 .226 r
.69351 .66211 .69593 .65618 .70199 .65474 .69962 .66082 Mtetra
.44 .068 .235 r
.69962 .66082 .70199 .65474 .70808 .6533 .70573 .65952 Mtetra
.444 .075 .243 r
.70573 .65952 .70808 .6533 .71417 .65185 .71186 .65823 Mtetra
.447 .082 .25 r
.71186 .65823 .71417 .65185 .72028 .65038 .71801 .65693 Mtetra
.451 .088 .258 r
.71801 .65693 .72028 .65038 .72641 .64892 .72417 .65563 Mtetra
.454 .095 .265 r
.72417 .65563 .72641 .64892 .73254 .64744 .73034 .65432 Mtetra
.457 .102 .273 r
.73034 .65432 .73254 .64744 .73869 .64595 .73653 .65301 Mtetra
.461 .108 .28 r
.73653 .65301 .73869 .64595 .74486 .64446 .74273 .6517 Mtetra
.464 .114 .287 r
.74273 .6517 .74486 .64446 .75104 .64296 .74895 .65038 Mtetra
.467 .12 .294 r
.74895 .65038 .75104 .64296 .75723 .64145 .75518 .64906 Mtetra
.47 .126 .3 r
.75518 .64906 .75723 .64145 .76343 .63992 .76143 .64773 Mtetra
.473 .132 .307 r
.76143 .64773 .76343 .63992 .76965 .63839 .76769 .6464 Mtetra
.475 .137 .313 r
.76769 .6464 .76965 .63839 .77588 .63685 .77397 .64507 Mtetra
.478 .143 .319 r
.77397 .64507 .77588 .63685 .78213 .6353 .78026 .64372 Mtetra
.481 .148 .325 r
.78026 .64372 .78213 .6353 .78839 .63373 .78657 .64238 Mtetra
.483 .154 .331 r
.78657 .64238 .78839 .63373 .79466 .63216 .79289 .64103 Mtetra
.485 .159 .337 r
.79289 .64103 .79466 .63216 .80095 .63057 .79923 .63967 Mtetra
.488 .164 .343 r
.79923 .63967 .80095 .63057 .80725 .62897 .80558 .63831 Mtetra
.49 .169 .348 r
.80558 .63831 .80725 .62897 .81356 .62736 .81195 .63694 Mtetra
.492 .173 .354 r
.81195 .63694 .81356 .62736 .81989 .62573 .81833 .63556 Mtetra
.495 .178 .359 r
.81833 .63556 .81989 .62573 .82623 .6241 .82473 .63418 Mtetra
.497 .183 .364 r
.82473 .63418 .82623 .6241 .83258 .62245 .83114 .63279 Mtetra
.499 .187 .369 r
.83114 .63279 .83258 .62245 .83895 .62078 .83757 .63139 Mtetra
.5 .191 .374 r
.83757 .63139 .83895 .62078 .84533 .61909 .84401 .62998 Mtetra
.502 .196 .379 r
.84401 .62998 .84533 .61909 .85172 .61739 .85047 .62857 Mtetra
.504 .2 .384 r
.85047 .62857 .85172 .61739 .85813 .61568 .85694 .62714 Mtetra
.506 .204 .388 r
.85694 .62714 .85813 .61568 .86455 .61394 .86343 .6257 Mtetra
.508 .208 .393 r
.86343 .6257 .86455 .61394 .87098 .61219 .86993 .62426 Mtetra
.509 .212 .397 r
.86993 .62426 .87098 .61219 .87742 .61042 .87645 .62281 Mtetra
.511 .215 .401 r
.87645 .62281 .87742 .61042 .88388 .60862 .88298 .62133 Mtetra
.512 .219 .405 r
.88298 .62133 .88388 .60862 .89035 .6068 .88953 .61985 Mtetra
.514 .222 .409 r
.88953 .61985 .89035 .6068 .89683 .60496 .89609 .61835 Mtetra
.514 .225 .413 r
.89609 .61835 .89683 .60496 .90332 .60304 .90266 .61678 Mtetra
.514 .227 .416 r
.90266 .61678 .90332 .60304 .90981 .60106 .90924 .61514 Mtetra
.513 .229 .42 r
.90924 .61514 .90981 .60106 .91631 .59896 .91582 .6134 Mtetra
.508 .227 .422 r
.91582 .6134 .91631 .59896 .92277 .59653 .92237 .61129 Mtetra
.503 .225 .425 r
.92237 .61129 .92277 .59653 .92922 .59381 .9289 .60888 Mtetra
.486 .213 .425 r
.9289 .60888 .92922 .59381 .93558 .59024 .93534 .60554 Mtetra
.461 .195 .424 r
.93534 .60554 .93558 .59024 .9418 .5855 .94163 .60091 Mtetra
.441 .181 .422 r
.94163 .60091 .9418 .5855 .94792 .57987 .9478 .59531 Mtetra
.354 .116 .408 r
.9478 .59531 .94792 .57987 .95361 .5709 .9535 .586 Mtetra
.294 .069 .393 r
.9535 .586 .95361 .5709 .95905 .56007 .95892 .57461 Mtetra
.188 0 .364 r
.95892 .57461 .95905 .56007 .9641 .54642 .96392 .56008 Mtetra
.009 0 .307 r
.96392 .56008 .9641 .54642 .96861 .52888 .9683 .54119 Mtetra
0 0 .246 r
.9683 .54119 .96861 .52888 .97284 .50969 .97238 .52046 Mtetra
.915 .553 .329 r
.3836 .65754 .38686 .65908 .39153 .67414 .38826 .67284 Mtetra
.907 .535 .313 r
.38826 .67284 .39153 .67414 .39631 .68789 .39302 .68683 Mtetra
.881 .474 .243 r
.39302 .68683 .39631 .68789 .40126 .69825 .39797 .69738 Mtetra
.84 .392 .152 r
.39797 .69738 .40126 .69825 .40636 .70598 .40305 .70527 Mtetra
.788 .302 .058 r
.40305 .70527 .40636 .70598 .41154 .71196 .40824 .71139 Mtetra
.52 0 0 r
.40824 .71139 .41154 .71196 .41686 .71462 .41356 .71414 Mtetra
.366 0 0 r
.41356 .71414 .41686 .71462 .42223 .71638 .41894 .71598 Mtetra
0 .511 .709 r
.41894 .71598 .42223 .71638 .42766 .71695 .42437 .7166 Mtetra
.177 .706 .854 r
.42437 .7166 .42766 .71695 .43312 .71661 .42984 .71631 Mtetra
.248 .753 .882 r
.42984 .71631 .43312 .71661 .43861 .71599 .43534 .71573 Mtetra
.33 .805 .91 r
.43534 .71573 .43861 .71599 .44412 .71504 .44086 .7148 Mtetra
.351 .817 .914 r
.44086 .7148 .44412 .71504 .44964 .71397 .44639 .71376 Mtetra
.358 .823 .913 r
.44639 .71376 .44964 .71397 .45518 .71283 .45194 .71266 Mtetra
.361 .825 .911 r
.45194 .71266 .45518 .71283 .46073 .71166 .4575 .71151 Mtetra
.355 .823 .905 r
.4575 .71151 .46073 .71166 .46629 .71047 .46308 .71035 Mtetra
.349 .82 .899 r
.46308 .71035 .46629 .71047 .47187 .70927 .46866 .70919 Mtetra
.341 .816 .892 r
.46866 .70919 .47187 .70927 .47746 .70808 .47426 .70802 Mtetra
.332 .812 .885 r
.47426 .70802 .47746 .70808 .48306 .70687 .47988 .70685 Mtetra
.324 .807 .878 r
.47988 .70685 .48306 .70687 .48868 .70567 .4855 .70568 Mtetra
.313 .802 .869 r
.4855 .70568 .48868 .70567 .4943 .70446 .49114 .70451 Mtetra
.303 .796 .86 r
.49114 .70451 .4943 .70446 .49994 .70325 .49679 .70334 Mtetra
.294 .791 .851 r
.49679 .70334 .49994 .70325 .5056 .70204 .50246 .70216 Mtetra
.283 .784 .841 r
.50246 .70216 .5056 .70204 .51126 .70082 .50813 .70099 Mtetra
.271 .777 .831 r
.50813 .70099 .51126 .70082 .51694 .69961 .51382 .69981 Mtetra
.261 .77 .82 r
.51382 .69981 .51694 .69961 .52263 .69839 .51953 .69863 Mtetra
.249 .762 .808 r
.51953 .69863 .52263 .69839 .52833 .69717 .52524 .69745 Mtetra
.235 .753 .795 r
.52524 .69745 .52833 .69717 .53405 .69595 .53097 .69628 Mtetra
.224 .745 .783 r
.53097 .69628 .53405 .69595 .53978 .69472 .53672 .6951 Mtetra
.211 .736 .77 r
.53672 .6951 .53978 .69472 .54553 .6935 .54247 .69391 Mtetra
.196 .725 .754 r
.54247 .69391 .54553 .6935 .55128 .69227 .54824 .69274 Mtetra
.183 .715 .74 r
.54824 .69274 .55128 .69227 .55705 .69104 .55403 .69155 Mtetra
.17 .704 .725 r
.55403 .69155 .55705 .69104 .56283 .6898 .55982 .69037 Mtetra
.153 .691 .707 r
.55982 .69037 .56283 .6898 .56863 .68857 .56564 .68919 Mtetra
0 0 0 r
.56564 .68919 .56863 .68857 .57444 .68733 .57146 .688 Mtetra
.57146 .688 .57444 .68733 .58026 .68609 .5773 .68681 Mtetra
.5773 .68681 .58026 .68609 .5861 .68485 .58315 .68563 Mtetra
.58315 .68563 .5861 .68485 .59195 .68361 .58901 .68445 Mtetra
.58901 .68445 .59195 .68361 .59781 .68236 .59489 .68327 Mtetra
.59489 .68327 .59781 .68236 .60369 .68112 .60079 .68208 Mtetra
.60079 .68208 .60369 .68112 .60958 .67987 .60669 .68089 Mtetra
.60669 .68089 .60958 .67987 .61549 .67861 .61261 .67971 Mtetra
.61261 .67971 .61549 .67861 .6214 .67736 .61855 .67852 Mtetra
.008 0 0 r
.61855 .67852 .6214 .67736 .62734 .6761 .6245 .67733 Mtetra
.026 0 0 r
.6245 .67733 .62734 .6761 .63328 .67484 .63046 .67615 Mtetra
.043 0 0 r
.63046 .67615 .63328 .67484 .63924 .67358 .63644 .67496 Mtetra
.059 0 0 r
.63644 .67496 .63924 .67358 .64522 .67231 .64243 .67377 Mtetra
.077 0 0 r
.64243 .67377 .64522 .67231 .6512 .67105 .64844 .67259 Mtetra
.093 0 0 r
.64844 .67259 .6512 .67105 .65721 .66978 .65446 .6714 Mtetra
.11 0 0 r
.65446 .6714 .65721 .66978 .66322 .66851 .6605 .67022 Mtetra
.126 0 0 r
.6605 .67022 .66322 .66851 .66925 .66723 .66655 .66903 Mtetra
.142 0 0 r
.66655 .66903 .66925 .66723 .6753 .66596 .67261 .66784 Mtetra
.158 0 0 r
.67261 .66784 .6753 .66596 .68135 .66468 .67869 .66666 Mtetra
.174 0 0 r
.67869 .66666 .68135 .66468 .68743 .66339 .68479 .66547 Mtetra
.189 0 0 r
.68479 .66547 .68743 .66339 .69351 .66211 .6909 .66428 Mtetra
.204 0 0 r
.6909 .66428 .69351 .66211 .69962 .66082 .69702 .6631 Mtetra
.218 0 0 r
.69702 .6631 .69962 .66082 .70573 .65952 .70316 .66191 Mtetra
.233 0 0 r
.70316 .66191 .70573 .65952 .71186 .65823 .70932 .66072 Mtetra
.246 0 0 r
.70932 .66072 .71186 .65823 .71801 .65693 .71549 .65954 Mtetra
.259 0 0 r
.71549 .65954 .71801 .65693 .72417 .65563 .72168 .65835 Mtetra
.273 0 0 r
.72168 .65835 .72417 .65563 .73034 .65432 .72788 .65717 Mtetra
.285 0 0 r
.72788 .65717 .73034 .65432 .73653 .65301 .73409 .65598 Mtetra
.297 0 0 r
.73409 .65598 .73653 .65301 .74273 .6517 .74032 .6548 Mtetra
.309 0 0 r
.74032 .6548 .74273 .6517 .74895 .65038 .74657 .65361 Mtetra
.32 0 0 r
.74657 .65361 .74895 .65038 .75518 .64906 .75284 .65243 Mtetra
.33 0 0 r
.75284 .65243 .75518 .64906 .76143 .64773 .75911 .65124 Mtetra
.341 0 .019 r
.75911 .65124 .76143 .64773 .76769 .6464 .76541 .65006 Mtetra
.351 0 .038 r
.76541 .65006 .76769 .6464 .77397 .64507 .77172 .64887 Mtetra
.36 0 .056 r
.77172 .64887 .77397 .64507 .78026 .64372 .77805 .64769 Mtetra
.369 0 .074 r
.77805 .64769 .78026 .64372 .78657 .64238 .78439 .6465 Mtetra
.378 0 .091 r
.78439 .6465 .78657 .64238 .79289 .64103 .79075 .64532 Mtetra
.387 0 .107 r
.79075 .64532 .79289 .64103 .79923 .63967 .79712 .64413 Mtetra
.394 0 .123 r
.79712 .64413 .79923 .63967 .80558 .63831 .80351 .64295 Mtetra
.402 0 .139 r
.80351 .64295 .80558 .63831 .81195 .63694 .80992 .64176 Mtetra
.409 .003 .153 r
.80992 .64176 .81195 .63694 .81833 .63556 .81635 .64058 Mtetra
.416 .015 .168 r
.81635 .64058 .81833 .63556 .82473 .63418 .82279 .63939 Mtetra
.423 .028 .182 r
.82279 .63939 .82473 .63418 .83114 .63279 .82924 .63821 Mtetra
.429 .039 .195 r
.82924 .63821 .83114 .63279 .83757 .63139 .83572 .63702 Mtetra
.435 .05 .208 r
.83572 .63702 .83757 .63139 .84401 .62998 .84221 .63582 Mtetra
.441 .061 .221 r
.84221 .63582 .84401 .62998 .85047 .62857 .84871 .63464 Mtetra
.447 .072 .233 r
.84871 .63464 .85047 .62857 .85694 .62714 .85524 .63345 Mtetra
.452 .082 .245 r
.85524 .63345 .85694 .62714 .86343 .6257 .86178 .63225 Mtetra
.457 .092 .256 r
.86178 .63225 .86343 .6257 .86993 .62426 .86833 .63105 Mtetra
.462 .101 .267 r
.86833 .63105 .86993 .62426 .87645 .62281 .87491 .62986 Mtetra
.466 .11 .277 r
.87491 .62986 .87645 .62281 .88298 .62133 .8815 .62865 Mtetra
.47 .119 .287 r
.8815 .62865 .88298 .62133 .88953 .61985 .8881 .62744 Mtetra
.474 .127 .297 r
.8881 .62744 .88953 .61985 .89609 .61835 .89473 .62622 Mtetra
.476 .134 .306 r
.89473 .62622 .89609 .61835 .90266 .61678 .90136 .62495 Mtetra
.478 .14 .314 r
.90136 .62495 .90266 .61678 .90924 .61514 .90801 .62361 Mtetra
.478 .145 .322 r
.90801 .62361 .90924 .61514 .91582 .6134 .91466 .62217 Mtetra
.469 .142 .328 r
.91466 .62217 .91582 .6134 .92237 .61129 .92128 .62036 Mtetra
.463 .14 .333 r
.92128 .62036 .92237 .61129 .9289 .60888 .92788 .61824 Mtetra
.433 .12 .334 r
.92788 .61824 .9289 .60888 .93534 .60554 .93439 .61513 Mtetra
.389 .089 .33 r
.93439 .61513 .93534 .60554 .94163 .60091 .94073 .61067 Mtetra
.354 .064 .326 r
.94073 .61067 .94163 .60091 .9478 .59531 .94695 .60516 Mtetra
.193 0 .29 r
.94695 .60516 .9478 .59531 .9535 .586 .95268 .59571 Mtetra
.083 0 .257 r
.95268 .59571 .9535 .586 .95892 .57461 .95811 .58401 Mtetra
0 0 .194 r
.95811 .58401 .95892 .57461 .96392 .56008 .96308 .56895 Mtetra
0 0 .087 r
.96308 .56895 .96392 .56008 .9683 .54119 .96739 .54917 Mtetra
0 0 .002 r
.96739 .54917 .9683 .54119 .97238 .52046 .97138 .5274 Mtetra
.921 .557 .316 r
.38035 .65554 .3836 .65754 .38826 .67284 .38499 .67103 Mtetra
.914 .539 .296 r
.38499 .67103 .38826 .67284 .39302 .68683 .38974 .68519 Mtetra
.889 .476 .214 r
.38974 .68519 .39302 .68683 .39797 .69738 .39468 .69589 Mtetra
.844 .385 .102 r
.39468 .69589 .39797 .69738 .40305 .70527 .39976 .70391 Mtetra
.783 .281 0 r
.39976 .70391 .40305 .70527 .40824 .71139 .40494 .71013 Mtetra
.427 0 0 r
.40494 .71013 .40824 .71139 .41356 .71414 .41027 .71295 Mtetra
0 .359 .676 r
.41027 .71295 .41356 .71414 .41894 .71598 .41565 .71484 Mtetra
.103 .621 .885 r
.41565 .71484 .41894 .71598 .42437 .7166 .42109 .71551 Mtetra
.341 .769 .972 r
.42109 .71551 .42437 .7166 .42984 .71631 .42657 .71525 Mtetra
.403 .802 .984 r
.42657 .71525 .42984 .71631 .43534 .71573 .43207 .71469 Mtetra
.47 .835 .993 r
.43207 .71469 .43534 .71573 .44086 .7148 .4376 .71379 Mtetra
.488 .844 .994 r
.4376 .71379 .44086 .7148 .44639 .71376 .44314 .71277 Mtetra
.496 .849 .993 r
.44314 .71277 .44639 .71376 .45194 .71266 .4487 .71169 Mtetra
.5 .852 .993 r
.4487 .71169 .45194 .71266 .4575 .71151 .45427 .71056 Mtetra
.498 .853 .992 r
.45427 .71056 .4575 .71151 .46308 .71035 .45986 .70943 Mtetra
.495 .854 .991 r
.45986 .70943 .46308 .71035 .46866 .70919 .46545 .70828 Mtetra
.491 .854 .99 r
.46545 .70828 .46866 .70919 .47426 .70802 .47106 .70714 Mtetra
.487 .854 .988 r
.47106 .70714 .47426 .70802 .47988 .70685 .47669 .706 Mtetra
.483 .854 .987 r
.47669 .706 .47988 .70685 .4855 .70568 .48232 .70485 Mtetra
.478 .853 .985 r
.48232 .70485 .4855 .70568 .49114 .70451 .48797 .7037 Mtetra
.473 .853 .983 r
.48797 .7037 .49114 .70451 .49679 .70334 .49363 .70256 Mtetra
.468 .853 .981 r
.49363 .70256 .49679 .70334 .50246 .70216 .49931 .70141 Mtetra
.462 .852 .978 r
.49931 .70141 .50246 .70216 .50813 .70099 .50499 .70026 Mtetra
.456 .851 .976 r
.50499 .70026 .50813 .70099 .51382 .69981 .5107 .69912 Mtetra
.45 .851 .973 r
.5107 .69912 .51382 .69981 .51953 .69863 .51641 .69797 Mtetra
.444 .849 .97 r
.51641 .69797 .51953 .69863 .52524 .69745 .52214 .69682 Mtetra
.436 .847 .966 r
.52214 .69682 .52524 .69745 .53097 .69628 .52788 .69568 Mtetra
.43 .846 .962 r
.52788 .69568 .53097 .69628 .53672 .6951 .53363 .69453 Mtetra
.423 .845 .958 r
.53363 .69453 .53672 .6951 .54247 .69391 .5394 .69338 Mtetra
.413 .842 .953 r
.5394 .69338 .54247 .69391 .54824 .69274 .54518 .69224 Mtetra
.406 .84 .948 r
.54518 .69224 .54824 .69274 .55403 .69155 .55098 .69109 Mtetra
.398 .837 .943 r
.55098 .69109 .55403 .69155 .55982 .69037 .55679 .68994 Mtetra
.386 .833 .936 r
.55679 .68994 .55982 .69037 .56564 .68919 .56261 .6888 Mtetra
.378 .83 .93 r
.56261 .6888 .56564 .68919 .57146 .688 .56845 .68766 Mtetra
.368 .826 .923 r
.56845 .68766 .57146 .688 .5773 .68681 .5743 .68651 Mtetra
.356 .821 .914 r
.5743 .68651 .5773 .68681 .58315 .68563 .58016 .68538 Mtetra
.345 .816 .906 r
.58016 .68538 .58315 .68563 .58901 .68445 .58604 .68424 Mtetra
.333 .81 .897 r
.58604 .68424 .58901 .68445 .59489 .68327 .59193 .6831 Mtetra
.321 .804 .886 r
.59193 .6831 .59489 .68327 .60079 .68208 .59784 .68196 Mtetra
.308 .797 .876 r
.59784 .68196 .60079 .68208 .60669 .68089 .60376 .68082 Mtetra
.293 .789 .864 r
.60376 .68082 .60669 .68089 .61261 .67971 .6097 .67969 Mtetra
.28 .781 .851 r
.6097 .67969 .61261 .67971 .61855 .67852 .61565 .67856 Mtetra
.265 .772 .837 r
.61565 .67856 .61855 .67852 .6245 .67733 .62161 .67742 Mtetra
.248 .762 .822 r
.62161 .67742 .6245 .67733 .63046 .67615 .62759 .6763 Mtetra
.232 .751 .806 r
.62759 .6763 .63046 .67615 .63644 .67496 .63359 .67517 Mtetra
.216 .74 .79 r
.63359 .67517 .63644 .67496 .64243 .67377 .63959 .67404 Mtetra
.198 .727 .772 r
.63959 .67404 .64243 .67377 .64844 .67259 .64562 .67292 Mtetra
.18 .714 .753 r
.64562 .67292 .64844 .67259 .65446 .6714 .65166 .6718 Mtetra
.161 .699 .733 r
.65166 .6718 .65446 .6714 .6605 .67022 .65771 .67068 Mtetra
.142 .684 .711 r
.65771 .67068 .6605 .67022 .66655 .66903 .66378 .66956 Mtetra
0 0 0 r
.66378 .66956 .66655 .66903 .67261 .66784 .66986 .66844 Mtetra
.66986 .66844 .67261 .66784 .67869 .66666 .67596 .66733 Mtetra
.67596 .66733 .67869 .66666 .68479 .66547 .68207 .66622 Mtetra
.68207 .66622 .68479 .66547 .6909 .66428 .6882 .66511 Mtetra
.6882 .66511 .6909 .66428 .69702 .6631 .69435 .66401 Mtetra
.69435 .66401 .69702 .6631 .70316 .66191 .70051 .66291 Mtetra
.004 0 0 r
.70051 .66291 .70316 .66191 .70932 .66072 .70668 .66181 Mtetra
.025 0 0 r
.70668 .66181 .70932 .66072 .71549 .65954 .71288 .66072 Mtetra
.046 0 0 r
.71288 .66072 .71549 .65954 .72168 .65835 .71908 .65962 Mtetra
.069 0 0 r
.71908 .65962 .72168 .65835 .72788 .65717 .72531 .65854 Mtetra
.089 0 0 r
.72531 .65854 .72788 .65717 .73409 .65598 .73155 .65745 Mtetra
.11 0 0 r
.73155 .65745 .73409 .65598 .74032 .6548 .7378 .65637 Mtetra
.131 0 0 r
.7378 .65637 .74032 .6548 .74657 .65361 .74408 .6553 Mtetra
.151 0 0 r
.74408 .6553 .74657 .65361 .75284 .65243 .75037 .65422 Mtetra
.17 0 0 r
.75037 .65422 .75284 .65243 .75911 .65124 .75667 .65315 Mtetra
.19 0 0 r
.75667 .65315 .75911 .65124 .76541 .65006 .76299 .65209 Mtetra
.208 0 0 r
.76299 .65209 .76541 .65006 .77172 .64887 .76933 .65103 Mtetra
.226 0 0 r
.76933 .65103 .77172 .64887 .77805 .64769 .77569 .64998 Mtetra
.243 0 0 r
.77569 .64998 .77805 .64769 .78439 .6465 .78206 .64892 Mtetra
.26 0 0 r
.78206 .64892 .78439 .6465 .79075 .64532 .78845 .64788 Mtetra
.276 0 0 r
.78845 .64788 .79075 .64532 .79712 .64413 .79486 .64684 Mtetra
.291 0 0 r
.79486 .64684 .79712 .64413 .80351 .64295 .80128 .6458 Mtetra
.305 0 0 r
.80128 .6458 .80351 .64295 .80992 .64176 .80772 .64477 Mtetra
.319 0 0 r
.80772 .64477 .80992 .64176 .81635 .64058 .81418 .64374 Mtetra
.333 0 0 r
.81418 .64374 .81635 .64058 .82279 .63939 .82066 .64272 Mtetra
.346 0 .002 r
.82066 .64272 .82279 .63939 .82924 .63821 .82715 .64171 Mtetra
.357 0 .024 r
.82715 .64171 .82924 .63821 .83572 .63702 .83367 .6407 Mtetra
.368 0 .046 r
.83367 .6407 .83572 .63702 .84221 .63582 .8402 .63969 Mtetra
.38 0 .067 r
.8402 .63969 .84221 .63582 .84871 .63464 .84674 .6387 Mtetra
.39 0 .088 r
.84674 .6387 .84871 .63464 .85524 .63345 .85331 .63771 Mtetra
.399 0 .107 r
.85331 .63771 .85524 .63345 .86178 .63225 .8599 .63672 Mtetra
.409 0 .126 r
.8599 .63672 .86178 .63225 .86833 .63105 .8665 .63574 Mtetra
.418 .004 .144 r
.8665 .63574 .86833 .63105 .87491 .62986 .87312 .63477 Mtetra
.425 .018 .161 r
.87312 .63477 .87491 .62986 .8815 .62865 .87976 .63379 Mtetra
.433 .032 .178 r
.87976 .63379 .8815 .62865 .8881 .62744 .88642 .63282 Mtetra
.44 .046 .194 r
.88642 .63282 .8881 .62744 .89473 .62622 .8931 .63185 Mtetra
.444 .056 .208 r
.8931 .63185 .89473 .62622 .90136 .62495 .89979 .63084 Mtetra
.448 .066 .222 r
.89979 .63084 .90136 .62495 .90801 .62361 .9065 .62976 Mtetra
.449 .074 .234 r
.9065 .62976 .90801 .62361 .91466 .62217 .91321 .62859 Mtetra
.438 .071 .242 r
.91321 .62859 .91466 .62217 .92128 .62036 .91989 .62705 Mtetra
.429 .07 .251 r
.91989 .62705 .92128 .62036 .92788 .61824 .92656 .62519 Mtetra
.389 .041 .25 r
.92656 .62519 .92788 .61824 .93439 .61513 .93312 .62232 Mtetra
.325 0 .243 r
.93312 .62232 .93439 .61513 .94073 .61067 .93952 .61802 Mtetra
.276 0 .236 r
.93952 .61802 .94073 .61067 .94695 .60516 .9458 .61264 Mtetra
.042 0 .174 r
.9458 .61264 .94695 .60516 .95268 .59571 .95155 .6031 Mtetra
0 0 .125 r
.95155 .6031 .95268 .59571 .95811 .58401 .957 .5912 Mtetra
0 0 .04 r
.957 .5912 .95811 .58401 .96308 .56895 .96196 .57574 Mtetra
0 0 0 r
.96196 .57574 .96308 .56895 .96739 .54917 .96622 .55526 Mtetra
.73 .691 .149 r
.96622 .55526 .96739 .54917 .97138 .5274 .97014 .53265 Mtetra
.928 .56 .297 r
.37712 .65294 .38035 .65554 .38499 .67103 .38174 .66853 Mtetra
.921 .542 .27 r
.38174 .66853 .38499 .67103 .38974 .68519 .38648 .68278 Mtetra
.893 .473 .165 r
.38648 .68278 .38974 .68519 .39468 .69589 .39141 .69356 Mtetra
.835 .365 .016 r
.39141 .69356 .39468 .69589 .39976 .70391 .39649 .70165 Mtetra
.747 .234 0 r
.39649 .70165 .39976 .70391 .40494 .71013 .40167 .70793 Mtetra
0 .3 .721 r
.40167 .70793 .40494 .71013 .41027 .71295 .40699 .71079 Mtetra
.003 .483 .867 r
.40699 .71079 .41027 .71295 .41565 .71484 .41238 .71272 Mtetra
.302 .67 .974 r
.41238 .71272 .41565 .71484 .42109 .71551 .41782 .71341 Mtetra
.476 .754 .991 r
.41782 .71341 .42109 .71551 .42657 .71525 .42331 .71316 Mtetra
.52 .772 .989 r
.42331 .71316 .42657 .71525 .43207 .71469 .42882 .71262 Mtetra
.566 .79 .983 r
.42882 .71262 .43207 .71469 .4376 .71379 .43435 .71172 Mtetra
.579 .795 .981 r
.43435 .71172 .4376 .71379 .44314 .71277 .43991 .71071 Mtetra
.586 .798 .98 r
.43991 .71071 .44314 .71277 .4487 .71169 .44547 .70964 Mtetra
.59 .8 .98 r
.44547 .70964 .4487 .71169 .45427 .71056 .45105 .70853 Mtetra
.59 .802 .98 r
.45105 .70853 .45427 .71056 .45986 .70943 .45664 .7074 Mtetra
.59 .803 .981 r
.45664 .7074 .45986 .70943 .46545 .70828 .46225 .70627 Mtetra
.589 .804 .982 r
.46225 .70627 .46545 .70828 .47106 .70714 .46786 .70513 Mtetra
.588 .804 .982 r
.46786 .70513 .47106 .70714 .47669 .706 .4735 .704 Mtetra
.587 .805 .983 r
.4735 .704 .47669 .706 .48232 .70485 .47914 .70286 Mtetra
.586 .806 .984 r
.47914 .70286 .48232 .70485 .48797 .7037 .4848 .70173 Mtetra
.584 .807 .984 r
.4848 .70173 .48797 .7037 .49363 .70256 .49047 .70059 Mtetra
.584 .808 .985 r
.49047 .70059 .49363 .70256 .49931 .70141 .49615 .69946 Mtetra
.582 .809 .986 r
.49615 .69946 .49931 .70141 .50499 .70026 .50185 .69832 Mtetra
.58 .81 .987 r
.50185 .69832 .50499 .70026 .5107 .69912 .50756 .69719 Mtetra
.579 .811 .987 r
.50756 .69719 .5107 .69912 .51641 .69797 .51328 .69606 Mtetra
.578 .812 .988 r
.51328 .69606 .51641 .69797 .52214 .69682 .51902 .69492 Mtetra
.576 .813 .989 r
.51902 .69492 .52214 .69682 .52788 .69568 .52477 .69379 Mtetra
.575 .814 .989 r
.52477 .69379 .52788 .69568 .53363 .69453 .53053 .69266 Mtetra
.573 .815 .99 r
.53053 .69266 .53363 .69453 .5394 .69338 .53631 .69153 Mtetra
.57 .816 .991 r
.53631 .69153 .5394 .69338 .54518 .69224 .5421 .6904 Mtetra
.569 .817 .992 r
.5421 .6904 .54518 .69224 .55098 .69109 .5479 .68928 Mtetra
.568 .819 .992 r
.5479 .68928 .55098 .69109 .55679 .68994 .55372 .68814 Mtetra
.564 .819 .993 r
.55372 .68814 .55679 .68994 .56261 .6888 .55956 .68703 Mtetra
.563 .821 .994 r
.55956 .68703 .56261 .6888 .56845 .68766 .5654 .6859 Mtetra
.561 .822 .995 r
.5654 .6859 .56845 .68766 .5743 .68651 .57126 .68478 Mtetra
.557 .823 .995 r
.57126 .68478 .5743 .68651 .58016 .68538 .57714 .68366 Mtetra
.555 .824 .996 r
.57714 .68366 .58016 .68538 .58604 .68424 .58303 .68255 Mtetra
.552 .826 .997 r
.58303 .68255 .58604 .68424 .59193 .6831 .58893 .68143 Mtetra
.549 .827 .997 r
.58893 .68143 .59193 .6831 .59784 .68196 .59485 .68032 Mtetra
.547 .828 .998 r
.59485 .68032 .59784 .68196 .60376 .68082 .60078 .67921 Mtetra
.543 .829 .998 r
.60078 .67921 .60376 .68082 .6097 .67969 .60673 .6781 Mtetra
.54 .83 .999 r
.60673 .6781 .6097 .67969 .61565 .67856 .61269 .67699 Mtetra
.536 .832 .999 r
.61269 .67699 .61565 .67856 .62161 .67742 .61867 .67589 Mtetra
.532 .832 .999 r
.61867 .67589 .62161 .67742 .62759 .6763 .62466 .67479 Mtetra
.528 .834 .999 r
.62466 .67479 .62759 .6763 .63359 .67517 .63066 .6737 Mtetra
.524 .835 .999 r
.63066 .6737 .63359 .67517 .63959 .67404 .63668 .6726 Mtetra
.518 .836 .999 r
.63668 .6726 .63959 .67404 .64562 .67292 .64272 .67151 Mtetra
.513 .837 .999 r
.64272 .67151 .64562 .67292 .65166 .6718 .64877 .67043 Mtetra
.508 .837 .999 r
.64877 .67043 .65166 .6718 .65771 .67068 .65484 .66934 Mtetra
.502 .838 .998 r
.65484 .66934 .65771 .67068 .66378 .66956 .66092 .66826 Mtetra
.496 .839 .997 r
.66092 .66826 .66378 .66956 .66986 .66844 .66701 .66719 Mtetra
.489 .839 .996 r
.66701 .66719 .66986 .66844 .67596 .66733 .67313 .66612 Mtetra
.482 .839 .994 r
.67313 .66612 .67596 .66733 .68207 .66622 .67925 .66505 Mtetra
.474 .839 .992 r
.67925 .66505 .68207 .66622 .6882 .66511 .6854 .66399 Mtetra
.466 .839 .99 r
.6854 .66399 .6882 .66511 .69435 .66401 .69156 .66293 Mtetra
.458 .838 .987 r
.69156 .66293 .69435 .66401 .70051 .66291 .69773 .66188 Mtetra
.448 .837 .984 r
.69773 .66188 .70051 .66291 .70668 .66181 .70393 .66083 Mtetra
.438 .836 .98 r
.70393 .66083 .70668 .66181 .71288 .66072 .71013 .65979 Mtetra
.428 .834 .975 r
.71013 .65979 .71288 .66072 .71908 .65962 .71636 .65875 Mtetra
.415 .831 .969 r
.71636 .65875 .71908 .65962 .72531 .65854 .7226 .65773 Mtetra
.403 .828 .963 r
.7226 .65773 .72531 .65854 .73155 .65745 .72885 .6567 Mtetra
.39 .825 .956 r
.72885 .6567 .73155 .65745 .7378 .65637 .73513 .65568 Mtetra
.375 .819 .947 r
.73513 .65568 .7378 .65637 .74408 .6553 .74142 .65467 Mtetra
.36 .814 .937 r
.74142 .65467 .74408 .6553 .75037 .65422 .74773 .65367 Mtetra
.343 .808 .926 r
.74773 .65367 .75037 .65422 .75667 .65315 .75405 .65267 Mtetra
.325 .8 .914 r
.75405 .65267 .75667 .65315 .76299 .65209 .76039 .65168 Mtetra
.306 .791 .899 r
.76039 .65168 .76299 .65209 .76933 .65103 .76675 .65069 Mtetra
.285 .78 .883 r
.76675 .65069 .76933 .65103 .77569 .64998 .77313 .64972 Mtetra
.264 .769 .865 r
.77313 .64972 .77569 .64998 .78206 .64892 .77952 .64875 Mtetra
.241 .755 .845 r
.77952 .64875 .78206 .64892 .78845 .64788 .78593 .64779 Mtetra
.216 .739 .823 r
.78593 .64779 .78845 .64788 .79486 .64684 .79236 .64685 Mtetra
.191 .722 .798 r
.79236 .64685 .79486 .64684 .80128 .6458 .79881 .6459 Mtetra
.163 .703 .771 r
.79881 .6459 .80128 .6458 .80772 .64477 .80528 .64497 Mtetra
.135 .682 .741 r
.80528 .64497 .80772 .64477 .81418 .64374 .81176 .64405 Mtetra
.107 .659 .71 r
.81176 .64405 .81418 .64374 .82066 .64272 .81826 .64314 Mtetra
0 0 0 r
.81826 .64314 .82066 .64272 .82715 .64171 .82479 .64224 Mtetra
.82479 .64224 .82715 .64171 .83367 .6407 .83133 .64135 Mtetra
.83133 .64135 .83367 .6407 .8402 .63969 .83789 .64046 Mtetra
.018 0 0 r
.83789 .64046 .8402 .63969 .84674 .6387 .84447 .6396 Mtetra
.048 0 0 r
.84447 .6396 .84674 .6387 .85331 .63771 .85106 .63875 Mtetra
.078 0 0 r
.85106 .63875 .85331 .63771 .8599 .63672 .85768 .63789 Mtetra
.11 0 0 r
.85768 .63789 .8599 .63672 .8665 .63574 .86432 .63707 Mtetra
.139 0 0 r
.86432 .63707 .8665 .63574 .87312 .63477 .87098 .63625 Mtetra
.167 0 0 r
.87098 .63625 .87312 .63477 .87976 .63379 .87766 .63543 Mtetra
.194 0 0 r
.87766 .63543 .87976 .63379 .88642 .63282 .88435 .63463 Mtetra
.22 0 0 r
.88435 .63463 .88642 .63282 .8931 .63185 .89107 .63384 Mtetra
.239 0 0 r
.89107 .63384 .8931 .63185 .89979 .63084 .8978 .63301 Mtetra
.256 0 0 r
.8978 .63301 .89979 .63084 .9065 .62976 .90455 .63213 Mtetra
.267 0 0 r
.90455 .63213 .9065 .62976 .91321 .62859 .91131 .63116 Mtetra
.249 0 0 r
.91131 .63116 .91321 .62859 .91989 .62705 .91804 .62982 Mtetra
.238 0 0 r
.91804 .62982 .91989 .62705 .92656 .62519 .92475 .62816 Mtetra
.151 0 0 r
.92475 .62816 .92656 .62519 .93312 .62232 .93136 .62548 Mtetra
.013 0 0 r
.93136 .62548 .93312 .62232 .93952 .61802 .93781 .62134 Mtetra
0 0 0 r
.93781 .62134 .93952 .61802 .9458 .61264 .94413 .6161 Mtetra
.94413 .6161 .9458 .61264 .95155 .6031 .94992 .60659 Mtetra
.654 .773 .304 r
.94992 .60659 .95155 .6031 .957 .5912 .95539 .59463 Mtetra
.808 .817 .336 r
.95539 .59463 .957 .5912 .96196 .57574 .96036 .57899 Mtetra
.911 .82 .354 r
.96036 .57899 .96196 .57574 .96622 .55526 .96461 .55814 Mtetra
.943 .818 .368 r
.96461 .55814 .96622 .55526 .97014 .53265 .96851 .53505 Mtetra
.93 .561 .288 r
.37388 .65009 .37712 .65294 .38174 .66853 .37849 .66573 Mtetra
.924 .543 .258 r
.37849 .66573 .38174 .66853 .38648 .68278 .38322 .68004 Mtetra
.893 .47 .144 r
.38322 .68004 .38648 .68278 .39141 .69356 .38814 .69088 Mtetra
.827 .354 0 r
.38814 .69088 .39141 .69356 .39649 .70165 .39321 .69901 Mtetra
.721 .209 0 r
.39321 .69901 .39649 .70165 .40167 .70793 .39839 .70534 Mtetra
0 .343 .785 r
.39839 .70534 .40167 .70793 .40699 .71079 .40372 .70822 Mtetra
.088 .508 .903 r
.40372 .70822 .40699 .71079 .41238 .71272 .40911 .71017 Mtetra
.357 .664 .973 r
.40911 .71017 .41238 .71272 .41782 .71341 .41455 .71087 Mtetra
.507 .732 .975 r
.41455 .71087 .41782 .71341 .42331 .71316 .42005 .71063 Mtetra
.545 .747 .97 r
.42005 .71063 .42331 .71316 .42882 .71262 .42557 .7101 Mtetra
.585 .762 .963 r
.42557 .7101 .42882 .71262 .43435 .71172 .43111 .70921 Mtetra
.596 .766 .96 r
.43111 .70921 .43435 .71172 .43991 .71071 .43666 .7082 Mtetra
.602 .768 .959 r
.43666 .7082 .43991 .71071 .44547 .70964 .44224 .70713 Mtetra
.606 .77 .958 r
.44224 .70713 .44547 .70964 .45105 .70853 .44782 .70602 Mtetra
.607 .771 .959 r
.44782 .70602 .45105 .70853 .45664 .7074 .45342 .70489 Mtetra
.45342 .70489 .45664 .7074 .46225 .70627 .45903 .70376 Mtetra
.606 .772 .959 r
.45903 .70376 .46225 .70627 .46786 .70513 .46466 .70263 Mtetra
.606 .772 .96 r
.46466 .70263 .46786 .70513 .4735 .704 .4703 .7015 Mtetra
.606 .773 .96 r
.4703 .7015 .4735 .704 .47914 .70286 .47595 .70037 Mtetra
.605 .773 .961 r
.47595 .70037 .47914 .70286 .4848 .70173 .48162 .69924 Mtetra
.604 .774 .961 r
.48162 .69924 .4848 .70173 .49047 .70059 .48729 .69811 Mtetra
.604 .774 .962 r
.48729 .69811 .49047 .70059 .49615 .69946 .49298 .69697 Mtetra
.603 .775 .962 r
.49298 .69697 .49615 .69946 .50185 .69832 .49869 .69584 Mtetra
.602 .775 .963 r
.49869 .69584 .50185 .69832 .50756 .69719 .50441 .69472 Mtetra
.602 .776 .963 r
.50441 .69472 .50756 .69719 .51328 .69606 .51014 .69359 Mtetra
.601 .776 .964 r
.51014 .69359 .51328 .69606 .51902 .69492 .51588 .69246 Mtetra
.6 .777 .965 r
.51588 .69246 .51902 .69492 .52477 .69379 .52164 .69134 Mtetra
.6 .778 .965 r
.52164 .69134 .52477 .69379 .53053 .69266 .52741 .69021 Mtetra
.599 .778 .966 r
.52741 .69021 .53053 .69266 .53631 .69153 .5332 .68908 Mtetra
.598 .779 .967 r
.5332 .68908 .53631 .69153 .5421 .6904 .539 .68797 Mtetra
.597 .779 .967 r
.539 .68797 .5421 .6904 .5479 .68928 .54481 .68685 Mtetra
.597 .78 .968 r
.54481 .68685 .5479 .68928 .55372 .68814 .55064 .68572 Mtetra
.595 .781 .969 r
.55064 .68572 .55372 .68814 .55956 .68703 .55648 .68461 Mtetra
.594 .781 .97 r
.55648 .68461 .55956 .68703 .5654 .6859 .56234 .6835 Mtetra
.594 .782 .97 r
.56234 .6835 .5654 .6859 .57126 .68478 .56821 .68238 Mtetra
.592 .783 .971 r
.56821 .68238 .57126 .68478 .57714 .68366 .57409 .68128 Mtetra
.591 .784 .972 r
.57409 .68128 .57714 .68366 .58303 .68255 .57999 .68017 Mtetra
.59 .784 .973 r
.57999 .68017 .58303 .68255 .58893 .68143 .5859 .67907 Mtetra
.589 .785 .974 r
.5859 .67907 .58893 .68143 .59485 .68032 .59183 .67797 Mtetra
.588 .786 .975 r
.59183 .67797 .59485 .68032 .60078 .67921 .59777 .67686 Mtetra
.586 .787 .976 r
.59777 .67686 .60078 .67921 .60673 .6781 .60373 .67577 Mtetra
.585 .788 .976 r
.60373 .67577 .60673 .6781 .61269 .67699 .6097 .67468 Mtetra
.584 .789 .977 r
.6097 .67468 .61269 .67699 .61867 .67589 .61568 .67359 Mtetra
.581 .79 .978 r
.61568 .67359 .61867 .67589 .62466 .67479 .62169 .6725 Mtetra
.58 .791 .979 r
.62169 .6725 .62466 .67479 .63066 .6737 .6277 .67142 Mtetra
.578 .792 .98 r
.6277 .67142 .63066 .6737 .63668 .6726 .63373 .67035 Mtetra
.576 .793 .981 r
.63373 .67035 .63668 .6726 .64272 .67151 .63978 .66927 Mtetra
.574 .794 .982 r
.63978 .66927 .64272 .67151 .64877 .67043 .64584 .66821 Mtetra
.572 .795 .983 r
.64584 .66821 .64877 .67043 .65484 .66934 .65192 .66714 Mtetra
.57 .796 .985 r
.65192 .66714 .65484 .66934 .66092 .66826 .65801 .66608 Mtetra
.568 .798 .986 r
.65801 .66608 .66092 .66826 .66701 .66719 .66412 .66503 Mtetra
.566 .799 .987 r
.66412 .66503 .66701 .66719 .67313 .66612 .67024 .66398 Mtetra
.563 .8 .988 r
.67024 .66398 .67313 .66612 .67925 .66505 .67638 .66294 Mtetra
.56 .801 .989 r
.67638 .66294 .67925 .66505 .6854 .66399 .68254 .6619 Mtetra
.558 .803 .99 r
.68254 .6619 .6854 .66399 .69156 .66293 .68871 .66087 Mtetra
.555 .804 .991 r
.68871 .66087 .69156 .66293 .69773 .66188 .6949 .65984 Mtetra
.551 .805 .992 r
.6949 .65984 .69773 .66188 .70393 .66083 .7011 .65882 Mtetra
.548 .806 .993 r
.7011 .65882 .70393 .66083 .71013 .65979 .70732 .65781 Mtetra
.545 .808 .994 r
.70732 .65781 .71013 .65979 .71636 .65875 .71356 .6568 Mtetra
.54 .809 .996 r
.71356 .6568 .71636 .65875 .7226 .65773 .71981 .65581 Mtetra
.537 .811 .996 r
.71981 .65581 .7226 .65773 .72885 .6567 .72608 .65482 Mtetra
.532 .812 .997 r
.72608 .65482 .72885 .6567 .73513 .65568 .73237 .65383 Mtetra
.527 .813 .998 r
.73237 .65383 .73513 .65568 .74142 .65467 .73867 .65286 Mtetra
.522 .814 .999 r
.73867 .65286 .74142 .65467 .74773 .65367 .745 .6519 Mtetra
.517 .816 .999 r
.745 .6519 .74773 .65367 .75405 .65267 .75133 .65094 Mtetra
.511 .817 1 r
.75133 .65094 .75405 .65267 .76039 .65168 .75769 .64999 Mtetra
.505 .818 1 r
.75769 .64999 .76039 .65168 .76675 .65069 .76407 .64905 Mtetra
.497 .818 1 r
.76407 .64905 .76675 .65069 .77313 .64972 .77046 .64813 Mtetra
.49 .819 1 r
.77046 .64813 .77313 .64972 .77952 .64875 .77687 .64721 Mtetra
.482 .82 .999 r
.77687 .64721 .77952 .64875 .78593 .64779 .7833 .6463 Mtetra
.473 .82 .998 r
.7833 .6463 .78593 .64779 .79236 .64685 .78974 .64541 Mtetra
.464 .82 .996 r
.78974 .64541 .79236 .64685 .79881 .6459 .79621 .64452 Mtetra
.454 .82 .994 r
.79621 .64452 .79881 .6459 .80528 .64497 .80269 .64365 Mtetra
.442 .819 .991 r
.80269 .64365 .80528 .64497 .81176 .64405 .8092 .64279 Mtetra
.431 .818 .988 r
.8092 .64279 .81176 .64405 .81826 .64314 .81572 .64195 Mtetra
.416 .815 .983 r
.81572 .64195 .81826 .64314 .82479 .64224 .82226 .64112 Mtetra
.402 .813 .978 r
.82226 .64112 .82479 .64224 .83133 .64135 .82882 .6403 Mtetra
.387 .809 .971 r
.82882 .6403 .83133 .64135 .83789 .64046 .8354 .63949 Mtetra
.368 .803 .962 r
.8354 .63949 .83789 .64046 .84447 .6396 .84201 .63871 Mtetra
.35 .798 .953 r
.84201 .63871 .84447 .6396 .85106 .63875 .84863 .63794 Mtetra
.331 .791 .941 r
.84863 .63794 .85106 .63875 .85768 .63789 .85527 .63718 Mtetra
.306 .781 .926 r
.85527 .63718 .85768 .63789 .86432 .63707 .86193 .63644 Mtetra
.283 .771 .91 r
.86193 .63644 .86432 .63707 .87098 .63625 .86862 .63572 Mtetra
.258 .758 .891 r
.86862 .63572 .87098 .63625 .87766 .63543 .87532 .63502 Mtetra
.23 .743 .869 r
.87532 .63502 .87766 .63543 .88435 .63463 .88205 .63432 Mtetra
.201 .726 .843 r
.88205 .63432 .88435 .63463 .89107 .63384 .88879 .63364 Mtetra
.177 .712 .818 r
.88879 .63364 .89107 .63384 .8978 .63301 .89556 .63294 Mtetra
.155 .697 .79 r
.89556 .63294 .8978 .63301 .90455 .63213 .90234 .63218 Mtetra
.14 .686 .762 r
.90234 .63218 .90455 .63213 .91131 .63116 .90912 .63135 Mtetra
.171 .708 .751 r
.90912 .63135 .91131 .63116 .91804 .62982 .91589 .63015 Mtetra
.192 .72 .732 r
.91589 .63015 .91804 .62982 .92475 .62816 .92264 .62863 Mtetra
.331 .808 .747 r
.92264 .62863 .92475 .62816 .93136 .62548 .92929 .6261 Mtetra
.517 .904 .752 r
.92929 .6261 .93136 .62548 .93781 .62134 .93577 .62209 Mtetra
.622 .941 .729 r
.93577 .62209 .93781 .62134 .94413 .6161 .94213 .61698 Mtetra
.881 .968 .647 r
.94213 .61698 .94413 .6161 .94992 .60659 .94795 .60754 Mtetra
.934 .94 .593 r
.94795 .60754 .94992 .60659 .95539 .59463 .95345 .5956 Mtetra
.971 .896 .534 r
.95345 .5956 .95539 .59463 .96036 .57899 .95845 .57991 Mtetra
.99 .847 .48 r
.95845 .57991 .96036 .57899 .96461 .55814 .96271 .55888 Mtetra
.994 .83 .466 r
.96271 .55888 .96461 .55814 .96851 .53505 .9666 .53554 Mtetra
.931 .562 .284 r
.37063 .6471 .37388 .65009 .37849 .66573 .37523 .66278 Mtetra
.925 .543 .252 r
.37523 .66278 .37849 .66573 .38322 .68004 .37995 .67713 Mtetra
.893 .469 .133 r
.37995 .67713 .38322 .68004 .38814 .69088 .38486 .68801 Mtetra
.822 .349 0 r
.38486 .68801 .38814 .69088 .39321 .69901 .38993 .69618 Mtetra
.707 .197 0 r
.38993 .69618 .39321 .69901 .39839 .70534 .39511 .70254 Mtetra
0 .359 .807 r
.39511 .70254 .39839 .70534 .40372 .70822 .40044 .70544 Mtetra
.123 .515 .912 r
.40044 .70544 .40372 .70822 .40911 .71017 .40583 .7074 Mtetra
.378 .658 .967 r
.40583 .7074 .40911 .71017 .41455 .71087 .41128 .70812 Mtetra
.519 .721 .965 r
.41128 .70812 .41455 .71087 .42005 .71063 .41678 .70788 Mtetra
.554 .734 .96 r
.41678 .70788 .42005 .71063 .42557 .7101 .4223 .70735 Mtetra
.591 .748 .952 r
.4223 .70735 .42557 .7101 .43111 .70921 .42785 .70646 Mtetra
.602 .751 .949 r
.42785 .70646 .43111 .70921 .43666 .7082 .43342 .70545 Mtetra
.608 .753 .947 r
.43342 .70545 .43666 .7082 .44224 .70713 .439 .70438 Mtetra
.612 .755 .947 r
.439 .70438 .44224 .70713 .44782 .70602 .44459 .70327 Mtetra
.44459 .70327 .44782 .70602 .45342 .70489 .4502 .70214 Mtetra
.613 .756 .947 r
.4502 .70214 .45342 .70489 .45903 .70376 .45581 .70101 Mtetra
.612 .756 .947 r
.45581 .70101 .45903 .70376 .46466 .70263 .46145 .69988 Mtetra
.46145 .69988 .46466 .70263 .4703 .7015 .46709 .69875 Mtetra
.612 .757 .948 r
.46709 .69875 .4703 .7015 .47595 .70037 .47275 .69761 Mtetra
.611 .757 .948 r
.47275 .69761 .47595 .70037 .48162 .69924 .47842 .69648 Mtetra
.47842 .69648 .48162 .69924 .48729 .69811 .48411 .69535 Mtetra
.611 .757 .949 r
.48411 .69535 .48729 .69811 .49298 .69697 .48981 .69422 Mtetra
.61 .758 .949 r
.48981 .69422 .49298 .69697 .49869 .69584 .49552 .69309 Mtetra
.609 .758 .95 r
.49552 .69309 .49869 .69584 .50441 .69472 .50125 .69197 Mtetra
.50125 .69197 .50441 .69472 .51014 .69359 .50699 .69084 Mtetra
.50699 .69084 .51014 .69359 .51588 .69246 .51274 .68971 Mtetra
.608 .759 .951 r
.51274 .68971 .51588 .69246 .52164 .69134 .5185 .68859 Mtetra
.607 .759 .951 r
.5185 .68859 .52164 .69134 .52741 .69021 .52428 .68746 Mtetra
.607 .759 .952 r
.52428 .68746 .52741 .69021 .5332 .68908 .53008 .68634 Mtetra
.606 .759 .952 r
.53008 .68634 .5332 .68908 .539 .68797 .53589 .68522 Mtetra
.606 .76 .953 r
.53589 .68522 .539 .68797 .54481 .68685 .54171 .6841 Mtetra
.605 .76 .953 r
.54171 .6841 .54481 .68685 .55064 .68572 .54754 .68298 Mtetra
.604 .76 .954 r
.54754 .68298 .55064 .68572 .55648 .68461 .55339 .68187 Mtetra
.603 .761 .954 r
.55339 .68187 .55648 .68461 .56234 .6835 .55926 .68076 Mtetra
.603 .761 .955 r
.55926 .68076 .56234 .6835 .56821 .68238 .56513 .67965 Mtetra
.602 .762 .955 r
.56513 .67965 .56821 .68238 .57409 .68128 .57103 .67855 Mtetra
.601 .762 .956 r
.57103 .67855 .57409 .68128 .57999 .68017 .57693 .67744 Mtetra
.6 .762 .957 r
.57693 .67744 .57999 .68017 .5859 .67907 .58285 .67635 Mtetra
.6 .763 .957 r
.58285 .67635 .5859 .67907 .59183 .67797 .58879 .67525 Mtetra
.599 .764 .958 r
.58879 .67525 .59183 .67797 .59777 .67686 .59474 .67415 Mtetra
.598 .764 .959 r
.59474 .67415 .59777 .67686 .60373 .67577 .60071 .67307 Mtetra
.597 .764 .959 r
.60071 .67307 .60373 .67577 .6097 .67468 .60669 .67198 Mtetra
.597 .765 .96 r
.60669 .67198 .6097 .67468 .61568 .67359 .61268 .67089 Mtetra
.595 .765 .961 r
.61268 .67089 .61568 .67359 .62169 .6725 .61869 .66982 Mtetra
.594 .766 .961 r
.61869 .66982 .62169 .6725 .6277 .67142 .62472 .66875 Mtetra
.593 .767 .962 r
.62472 .66875 .6277 .67142 .63373 .67035 .63076 .66767 Mtetra
.592 .767 .963 r
.63076 .66767 .63373 .67035 .63978 .66927 .63681 .66661 Mtetra
.59 .768 .964 r
.63681 .66661 .63978 .66927 .64584 .66821 .64288 .66555 Mtetra
.589 .768 .965 r
.64288 .66555 .64584 .66821 .65192 .66714 .64897 .6645 Mtetra
.588 .769 .966 r
.64897 .6645 .65192 .66714 .65801 .66608 .65507 .66345 Mtetra
.587 .77 .967 r
.65507 .66345 .65801 .66608 .66412 .66503 .66119 .66241 Mtetra
.585 .77 .968 r
.66119 .66241 .66412 .66503 .67024 .66398 .66732 .66137 Mtetra
.584 .771 .968 r
.66732 .66137 .67024 .66398 .67638 .66294 .67347 .66034 Mtetra
.582 .772 .97 r
.67347 .66034 .67638 .66294 .68254 .6619 .67964 .65931 Mtetra
.58 .773 .971 r
.67964 .65931 .68254 .6619 .68871 .66087 .68582 .6583 Mtetra
.579 .774 .972 r
.68582 .6583 .68871 .66087 .6949 .65984 .69202 .65728 Mtetra
.576 .774 .973 r
.69202 .65728 .6949 .65984 .7011 .65882 .69824 .65628 Mtetra
.575 .775 .974 r
.69824 .65628 .7011 .65882 .70732 .65781 .70447 .65529 Mtetra
.573 .776 .975 r
.70447 .65529 .70732 .65781 .71356 .6568 .71072 .6543 Mtetra
.57 .777 .976 r
.71072 .6543 .71356 .6568 .71981 .65581 .71698 .65332 Mtetra
.568 .778 .978 r
.71698 .65332 .71981 .65581 .72608 .65482 .72326 .65235 Mtetra
.566 .779 .979 r
.72326 .65235 .72608 .65482 .73237 .65383 .72956 .65139 Mtetra
.563 .78 .98 r
.72956 .65139 .73237 .65383 .73867 .65286 .73588 .65044 Mtetra
.561 .782 .982 r
.73588 .65044 .73867 .65286 .745 .6519 .74221 .6495 Mtetra
.558 .783 .983 r
.74221 .6495 .745 .6519 .75133 .65094 .74857 .64856 Mtetra
.554 .784 .984 r
.74857 .64856 .75133 .65094 .75769 .64999 .75493 .64765 Mtetra
.551 .785 .986 r
.75493 .64765 .75769 .64999 .76407 .64905 .76132 .64673 Mtetra
.547 .786 .987 r
.76132 .64673 .76407 .64905 .77046 .64813 .76773 .64584 Mtetra
.544 .788 .989 r
.76773 .64584 .77046 .64813 .77687 .64721 .77415 .64495 Mtetra
.54 .789 .99 r
.77415 .64495 .77687 .64721 .7833 .6463 .7806 .64408 Mtetra
.535 .79 .991 r
.7806 .64408 .7833 .6463 .78974 .64541 .78706 .64322 Mtetra
.531 .791 .993 r
.78706 .64322 .78974 .64541 .79621 .64452 .79354 .64237 Mtetra
.526 .792 .994 r
.79354 .64237 .79621 .64452 .80269 .64365 .80004 .64154 Mtetra
.52 .794 .995 r
.80004 .64154 .80269 .64365 .8092 .64279 .80656 .64073 Mtetra
.515 .795 .996 r
.80656 .64073 .8092 .64279 .81572 .64195 .81309 .63992 Mtetra
.508 .796 .997 r
.81309 .63992 .81572 .64195 .82226 .64112 .81965 .63914 Mtetra
.501 .797 .998 r
.81965 .63914 .82226 .64112 .82882 .6403 .82623 .63837 Mtetra
.495 .798 .999 r
.82623 .63837 .82882 .6403 .8354 .63949 .83283 .63762 Mtetra
.485 .798 .999 r
.83283 .63762 .8354 .63949 .84201 .63871 .83945 .63689 Mtetra
.477 .799 1 r
.83945 .63689 .84201 .63871 .84863 .63794 .84609 .63617 Mtetra
.468 .8 .999 r
.84609 .63617 .84863 .63794 .85527 .63718 .85275 .63548 Mtetra
.456 .799 .999 r
.85275 .63548 .85527 .63718 .86193 .63644 .85943 .63481 Mtetra
.445 .799 .997 r
.85943 .63481 .86193 .63644 .86862 .63572 .86614 .63415 Mtetra
.433 .798 .995 r
.86614 .63415 .86862 .63572 .87532 .63502 .87286 .63352 Mtetra
.42 .797 .992 r
.87286 .63352 .87532 .63502 .88205 .63432 .87961 .6329 Mtetra
.405 .796 .988 r
.87961 .6329 .88205 .63432 .88879 .63364 .88638 .6323 Mtetra
.395 .796 .984 r
.88638 .6323 .88879 .63364 .89556 .63294 .89317 .63168 Mtetra
.387 .798 .979 r
.89317 .63168 .89556 .63294 .90234 .63218 .89997 .63102 Mtetra
.383 .803 .974 r
.89997 .63102 .90234 .63218 .90912 .63135 .90679 .63028 Mtetra
.42 .83 .974 r
.90679 .63028 .90912 .63135 .91589 .63015 .91359 .62919 Mtetra
.448 .852 .97 r
.91359 .62919 .91589 .63015 .92264 .62863 .92036 .62779 Mtetra
.57 .916 .965 r
.92036 .62779 .92264 .62863 .92929 .6261 .92704 .62537 Mtetra
.711 .97 .931 r
.92704 .62537 .92929 .6261 .93577 .62209 .93356 .62149 Mtetra
.787 .988 .891 r
.93356 .62149 .93577 .62209 .94213 .61698 .93995 .61649 Mtetra
.942 .959 .739 r
.93995 .61649 .94213 .61698 .94795 .60754 .94581 .60714 Mtetra
.972 .927 .669 r
.94581 .60714 .94795 .60754 .95345 .5956 .95134 .59526 Mtetra
.992 .884 .593 r
.95134 .59526 .95345 .5956 .95845 .57991 .95636 .5796 Mtetra
.999 .838 .524 r
.95636 .5796 .95845 .57991 .96271 .55888 .96064 .55848 Mtetra
1 .821 .502 r
.96064 .55848 .96271 .55888 .9666 .53554 .96455 .53501 Mtetra
.932 .563 .28 r
.36737 .644 .37063 .6471 .37523 .66278 .37196 .6597 Mtetra
.926 .544 .247 r
.37196 .6597 .37523 .66278 .37995 .67713 .37667 .67408 Mtetra
.892 .468 .123 r
.37667 .67408 .37995 .67713 .38486 .68801 .38158 .68498 Mtetra
.816 .343 0 r
.38158 .68498 .38486 .68801 .38993 .69618 .38664 .69317 Mtetra
.692 .185 0 r
.38664 .69317 .38993 .69618 .39511 .70254 .39182 .69955 Mtetra
0 .372 .824 r
.39182 .69955 .39511 .70254 .40044 .70544 .39715 .70247 Mtetra
.154 .52 .917 r
.39715 .70247 .40044 .70544 .40583 .7074 .40254 .70444 Mtetra
.395 .652 .961 r
.40254 .70444 .40583 .7074 .41128 .70812 .408 .70516 Mtetra
.528 .71 .955 r
.408 .70516 .41128 .70812 .41678 .70788 .41351 .70493 Mtetra
.561 .723 .949 r
.41351 .70493 .41678 .70788 .4223 .70735 .41904 .70439 Mtetra
.596 .735 .941 r
.41904 .70439 .4223 .70735 .42785 .70646 .42459 .7035 Mtetra
.607 .739 .938 r
.42459 .7035 .42785 .70646 .43342 .70545 .43016 .70249 Mtetra
.612 .74 .937 r
.43016 .70249 .43342 .70545 .439 .70438 .43575 .70141 Mtetra
.616 .742 .936 r
.43575 .70141 .439 .70438 .44459 .70327 .44135 .7003 Mtetra
.44135 .7003 .44459 .70327 .4502 .70214 .44696 .69917 Mtetra
.617 .742 .936 r
.44696 .69917 .4502 .70214 .45581 .70101 .45259 .69803 Mtetra
.616 .742 .936 r
.45259 .69803 .45581 .70101 .46145 .69988 .45823 .6969 Mtetra
.45823 .6969 .46145 .69988 .46709 .69875 .46388 .69576 Mtetra
.46388 .69576 .46709 .69875 .47275 .69761 .46954 .69462 Mtetra
.46954 .69462 .47275 .69761 .47842 .69648 .47522 .69349 Mtetra
.615 .742 .936 r
.47522 .69349 .47842 .69648 .48411 .69535 .48092 .69235 Mtetra
.48092 .69235 .48411 .69535 .48981 .69422 .48662 .69121 Mtetra
.615 .742 .937 r
.48662 .69121 .48981 .69422 .49552 .69309 .49234 .69008 Mtetra
.614 .742 .937 r
.49234 .69008 .49552 .69309 .50125 .69197 .49807 .68895 Mtetra
.49807 .68895 .50125 .69197 .50699 .69084 .50382 .68782 Mtetra
.50382 .68782 .50699 .69084 .51274 .68971 .50958 .68668 Mtetra
.613 .742 .937 r
.50958 .68668 .51274 .68971 .5185 .68859 .51535 .68556 Mtetra
.51535 .68556 .5185 .68859 .52428 .68746 .52114 .68443 Mtetra
.52114 .68443 .52428 .68746 .53008 .68634 .52694 .6833 Mtetra
.612 .742 .938 r
.52694 .6833 .53008 .68634 .53589 .68522 .53276 .68218 Mtetra
.53276 .68218 .53589 .68522 .54171 .6841 .53859 .68106 Mtetra
.53859 .68106 .54171 .6841 .54754 .68298 .54443 .67993 Mtetra
.61 .742 .938 r
.54443 .67993 .54754 .68298 .55339 .68187 .55029 .67882 Mtetra
.61 .742 .939 r
.55029 .67882 .55339 .68187 .55926 .68076 .55616 .67771 Mtetra
.55616 .67771 .55926 .68076 .56513 .67965 .56205 .67659 Mtetra
.609 .742 .939 r
.56205 .67659 .56513 .67965 .57103 .67855 .56795 .67548 Mtetra
.56795 .67548 .57103 .67855 .57693 .67744 .57386 .67438 Mtetra
.608 .742 .94 r
.57386 .67438 .57693 .67744 .58285 .67635 .57979 .67328 Mtetra
.57979 .67328 .58285 .67635 .58879 .67525 .58573 .67218 Mtetra
.58573 .67218 .58879 .67525 .59474 .67415 .59169 .67107 Mtetra
.606 .741 .94 r
.59169 .67107 .59474 .67415 .60071 .67307 .59766 .66999 Mtetra
.606 .742 .941 r
.59766 .66999 .60071 .67307 .60669 .67198 .60365 .6689 Mtetra
.60365 .6689 .60669 .67198 .61268 .67089 .60966 .6678 Mtetra
.604 .741 .941 r
.60966 .6678 .61268 .67089 .61869 .66982 .61567 .66673 Mtetra
.604 .741 .942 r
.61567 .66673 .61869 .66982 .62472 .66875 .62171 .66565 Mtetra
.604 .742 .942 r
.62171 .66565 .62472 .66875 .63076 .66767 .62776 .66458 Mtetra
.603 .741 .942 r
.62776 .66458 .63076 .66767 .63681 .66661 .63382 .66351 Mtetra
.602 .741 .943 r
.63382 .66351 .63681 .66661 .64288 .66555 .6399 .66245 Mtetra
.601 .741 .943 r
.6399 .66245 .64288 .66555 .64897 .6645 .646 .6614 Mtetra
.6 .741 .943 r
.646 .6614 .64897 .6645 .65507 .66345 .65211 .66035 Mtetra
.599 .741 .944 r
.65211 .66035 .65507 .66345 .66119 .66241 .65823 .6593 Mtetra
.65823 .6593 .66119 .66241 .66732 .66137 .66438 .65826 Mtetra
.598 .741 .945 r
.66438 .65826 .66732 .66137 .67347 .66034 .67053 .65723 Mtetra
.597 .741 .945 r
.67053 .65723 .67347 .66034 .67964 .65931 .67671 .65621 Mtetra
.596 .741 .946 r
.67671 .65621 .67964 .65931 .68582 .6583 .6829 .65519 Mtetra
.595 .742 .946 r
.6829 .65519 .68582 .6583 .69202 .65728 .68911 .65418 Mtetra
.594 .741 .947 r
.68911 .65418 .69202 .65728 .69824 .65628 .69533 .65318 Mtetra
.593 .742 .947 r
.69533 .65318 .69824 .65628 .70447 .65529 .70157 .65218 Mtetra
.592 .742 .948 r
.70157 .65218 .70447 .65529 .71072 .6543 .70783 .65119 Mtetra
.59 .741 .948 r
.70783 .65119 .71072 .6543 .71698 .65332 .7141 .65022 Mtetra
.589 .742 .949 r
.7141 .65022 .71698 .65332 .72326 .65235 .7204 .64925 Mtetra
.588 .742 .949 r
.7204 .64925 .72326 .65235 .72956 .65139 .72671 .64829 Mtetra
.586 .742 .95 r
.72671 .64829 .72956 .65139 .73588 .65044 .73303 .64735 Mtetra
.586 .742 .951 r
.73303 .64735 .73588 .65044 .74221 .6495 .73938 .64641 Mtetra
.584 .742 .951 r
.73938 .64641 .74221 .6495 .74857 .64856 .74574 .64548 Mtetra
.582 .742 .952 r
.74574 .64548 .74857 .64856 .75493 .64765 .75212 .64456 Mtetra
.581 .742 .953 r
.75212 .64456 .75493 .64765 .76132 .64673 .75852 .64366 Mtetra
.579 .742 .954 r
.75852 .64366 .76132 .64673 .76773 .64584 .76493 .64277 Mtetra
.578 .742 .954 r
.76493 .64277 .76773 .64584 .77415 .64495 .77137 .64189 Mtetra
.576 .743 .955 r
.77137 .64189 .77415 .64495 .7806 .64408 .77782 .64102 Mtetra
.574 .743 .956 r
.77782 .64102 .7806 .64408 .78706 .64322 .78429 .64017 Mtetra
.572 .743 .957 r
.78429 .64017 .78706 .64322 .79354 .64237 .79078 .63933 Mtetra
.57 .743 .958 r
.79078 .63933 .79354 .64237 .80004 .64154 .79729 .63851 Mtetra
.568 .743 .959 r
.79729 .63851 .80004 .64154 .80656 .64073 .80383 .63771 Mtetra
.566 .744 .96 r
.80383 .63771 .80656 .64073 .81309 .63992 .81038 .63691 Mtetra
.563 .744 .961 r
.81038 .63691 .81309 .63992 .81965 .63914 .81695 .63614 Mtetra
.561 .744 .962 r
.81695 .63614 .81965 .63914 .82623 .63837 .82354 .63539 Mtetra
.558 .744 .964 r
.82354 .63539 .82623 .63837 .83283 .63762 .83015 .63465 Mtetra
.554 .744 .965 r
.83015 .63465 .83283 .63762 .83945 .63689 .83678 .63394 Mtetra
.552 .745 .966 r
.83678 .63394 .83945 .63689 .84609 .63617 .84343 .63324 Mtetra
.549 .745 .968 r
.84343 .63324 .84609 .63617 .85275 .63548 .85011 .63257 Mtetra
.545 .745 .969 r
.85011 .63257 .85275 .63548 .85943 .63481 .8568 .63192 Mtetra
.542 .746 .971 r
.8568 .63192 .85943 .63481 .86614 .63415 .86352 .63129 Mtetra
.538 .746 .972 r
.86352 .63129 .86614 .63415 .87286 .63352 .87026 .63068 Mtetra
.534 .747 .974 r
.87026 .63068 .87286 .63352 .87961 .6329 .87702 .63009 Mtetra
.531 .748 .975 r
.87702 .63009 .87961 .6329 .88638 .6323 .88381 .62952 Mtetra
.53 .75 .977 r
.88381 .62952 .88638 .6323 .89317 .63168 .89061 .62894 Mtetra
.532 .754 .978 r
.89061 .62894 .89317 .63168 .89997 .63102 .89743 .62832 Mtetra
.537 .76 .979 r
.89743 .62832 .89997 .63102 .90679 .63028 .90427 .62762 Mtetra
.567 .778 .978 r
.90427 .62762 .90679 .63028 .91359 .62919 .91108 .62657 Mtetra
.592 .793 .976 r
.91108 .62657 .91359 .62919 .92036 .62779 .91788 .62523 Mtetra
.671 .829 .96 r
.91788 .62523 .92036 .62779 .92704 .62537 .92458 .62288 Mtetra
.761 .862 .924 r
.92458 .62288 .92704 .62537 .93356 .62149 .93112 .61908 Mtetra
.813 .878 .893 r
.93112 .61908 .93356 .62149 .93995 .61649 .93754 .61418 Mtetra
.926 .875 .767 r
.93754 .61418 .93995 .61649 .94581 .60714 .94343 .60494 Mtetra
.956 .864 .707 r
.94343 .60494 .94581 .60714 .95134 .59526 .949 .59317 Mtetra
.979 .842 .636 r
.949 .59317 .95134 .59526 .95636 .5796 .95406 .5776 Mtetra
.992 .812 .564 r
.95406 .5776 .95636 .5796 .96064 .55848 .95837 .55654 Mtetra
.994 .802 .538 r
.95837 .55654 .96064 .55848 .96455 .53501 .96231 .53309 Mtetra
.932 .563 .279 r
.36411 .64087 .36737 .644 .37196 .6597 .36869 .65659 Mtetra
.926 .544 .246 r
.36869 .65659 .37196 .6597 .37667 .67408 .37338 .67099 Mtetra
.892 .468 .122 r
.37338 .67099 .37667 .67408 .38158 .68498 .37828 .68192 Mtetra
.815 .343 0 r
.37828 .68192 .38158 .68498 .38664 .69317 .38334 .69013 Mtetra
.69 .184 0 r
.38334 .69013 .38664 .69317 .39182 .69955 .38852 .69653 Mtetra
0 .373 .825 r
.38852 .69653 .39182 .69955 .39715 .70247 .39385 .69946 Mtetra
.157 .519 .917 r
.39385 .69946 .39715 .70247 .40254 .70444 .39925 .70144 Mtetra
.397 .651 .96 r
.39925 .70144 .40254 .70444 .408 .70516 .40471 .70216 Mtetra
.529 .708 .953 r
.40471 .70216 .408 .70516 .41351 .70493 .41022 .70193 Mtetra
.562 .721 .948 r
.41022 .70193 .41351 .70493 .41904 .70439 .41576 .70139 Mtetra
.597 .733 .939 r
.41576 .70139 .41904 .70439 .42459 .7035 .42132 .70049 Mtetra
.607 .736 .936 r
.42132 .70049 .42459 .7035 .43016 .70249 .42689 .69948 Mtetra
.613 .738 .935 r
.42689 .69948 .43016 .70249 .43575 .70141 .43249 .6984 Mtetra
.616 .739 .934 r
.43249 .6984 .43575 .70141 .44135 .7003 .43809 .69728 Mtetra
.617 .74 .934 r
.43809 .69728 .44135 .7003 .44696 .69917 .44371 .69614 Mtetra
.44371 .69614 .44696 .69917 .45259 .69803 .44935 .695 Mtetra
.44935 .695 .45259 .69803 .45823 .6969 .45499 .69386 Mtetra
.45499 .69386 .45823 .6969 .46388 .69576 .46065 .69272 Mtetra
.46065 .69272 .46388 .69576 .46954 .69462 .46633 .69157 Mtetra
.616 .739 .934 r
.46633 .69157 .46954 .69462 .47522 .69349 .47201 .69043 Mtetra
.47201 .69043 .47522 .69349 .48092 .69235 .47771 .68929 Mtetra
.47771 .68929 .48092 .69235 .48662 .69121 .48342 .68815 Mtetra
.48342 .68815 .48662 .69121 .49234 .69008 .48915 .68701 Mtetra
.615 .739 .934 r
.48915 .68701 .49234 .69008 .49807 .68895 .49489 .68588 Mtetra
.49489 .68588 .49807 .68895 .50382 .68782 .50064 .68474 Mtetra
.615 .739 .935 r
.50064 .68474 .50382 .68782 .50958 .68668 .50641 .6836 Mtetra
.614 .739 .935 r
.50641 .6836 .50958 .68668 .51535 .68556 .51219 .68247 Mtetra
.51219 .68247 .51535 .68556 .52114 .68443 .51799 .68133 Mtetra
.51799 .68133 .52114 .68443 .52694 .6833 .5238 .6802 Mtetra
.613 .739 .935 r
.5238 .6802 .52694 .6833 .53276 .68218 .52962 .67907 Mtetra
.52962 .67907 .53276 .68218 .53859 .68106 .53546 .67795 Mtetra
.53546 .67795 .53859 .68106 .54443 .67993 .54131 .67681 Mtetra
.611 .738 .936 r
.54131 .67681 .54443 .67993 .55029 .67882 .54717 .6757 Mtetra
.54717 .6757 .55029 .67882 .55616 .67771 .55305 .67458 Mtetra
.55305 .67458 .55616 .67771 .56205 .67659 .55894 .67346 Mtetra
.61 .738 .936 r
.55894 .67346 .56205 .67659 .56795 .67548 .56485 .67234 Mtetra
.56485 .67234 .56795 .67548 .57386 .67438 .57077 .67123 Mtetra
.609 .738 .936 r
.57077 .67123 .57386 .67438 .57979 .67328 .57671 .67013 Mtetra
.57671 .67013 .57979 .67328 .58573 .67218 .58266 .66902 Mtetra
.609 .738 .937 r
.58266 .66902 .58573 .67218 .59169 .67107 .58863 .66791 Mtetra
.608 .737 .937 r
.58863 .66791 .59169 .67107 .59766 .66999 .59461 .66682 Mtetra
.607 .737 .937 r
.59461 .66682 .59766 .66999 .60365 .6689 .60061 .66573 Mtetra
.60061 .66573 .60365 .6689 .60966 .6678 .60662 .66463 Mtetra
.606 .737 .938 r
.60662 .66463 .60966 .6678 .61567 .66673 .61264 .66355 Mtetra
.605 .737 .938 r
.61264 .66355 .61567 .66673 .62171 .66565 .61868 .66247 Mtetra
.61868 .66247 .62171 .66565 .62776 .66458 .62474 .66139 Mtetra
.604 .736 .938 r
.62474 .66139 .62776 .66458 .63382 .66351 .63081 .66032 Mtetra
.603 .736 .938 r
.63081 .66032 .63382 .66351 .6399 .66245 .6369 .65926 Mtetra
.603 .736 .939 r
.6369 .65926 .6399 .66245 .646 .6614 .64301 .65819 Mtetra
.602 .736 .939 r
.64301 .65819 .646 .6614 .65211 .66035 .64912 .65714 Mtetra
.601 .736 .939 r
.64912 .65714 .65211 .66035 .65823 .6593 .65526 .65609 Mtetra
.65526 .65609 .65823 .6593 .66438 .65826 .66141 .65505 Mtetra
.6 .736 .94 r
.66141 .65505 .66438 .65826 .67053 .65723 .66758 .65401 Mtetra
.599 .735 .94 r
.66758 .65401 .67053 .65723 .67671 .65621 .67376 .65299 Mtetra
.598 .735 .94 r
.67376 .65299 .67671 .65621 .6829 .65519 .67996 .65197 Mtetra
.597 .735 .941 r
.67996 .65197 .6829 .65519 .68911 .65418 .68618 .65095 Mtetra
.596 .735 .941 r
.68618 .65095 .68911 .65418 .69533 .65318 .69241 .64995 Mtetra
.595 .735 .941 r
.69241 .64995 .69533 .65318 .70157 .65218 .69866 .64895 Mtetra
.595 .735 .942 r
.69866 .64895 .70157 .65218 .70783 .65119 .70493 .64795 Mtetra
.593 .734 .942 r
.70493 .64795 .70783 .65119 .7141 .65022 .71121 .64698 Mtetra
.592 .734 .942 r
.71121 .64698 .7141 .65022 .7204 .64925 .71751 .64601 Mtetra
.591 .734 .943 r
.71751 .64601 .7204 .64925 .72671 .64829 .72383 .64505 Mtetra
.59 .734 .943 r
.72383 .64505 .72671 .64829 .73303 .64735 .73016 .6441 Mtetra
.589 .734 .944 r
.73016 .6441 .73303 .64735 .73938 .64641 .73652 .64316 Mtetra
.588 .733 .944 r
.73652 .64316 .73938 .64641 .74574 .64548 .74289 .64223 Mtetra
.586 .733 .945 r
.74289 .64223 .74574 .64548 .75212 .64456 .74928 .64131 Mtetra
.585 .733 .945 r
.74928 .64131 .75212 .64456 .75852 .64366 .75569 .64041 Mtetra
.583 .733 .946 r
.75569 .64041 .75852 .64366 .76493 .64277 .76211 .63952 Mtetra
.582 .733 .946 r
.76211 .63952 .76493 .64277 .77137 .64189 .76856 .63864 Mtetra
.581 .733 .947 r
.76856 .63864 .77137 .64189 .77782 .64102 .77502 .63777 Mtetra
.578 .732 .948 r
.77502 .63777 .77782 .64102 .78429 .64017 .7815 .63692 Mtetra
.577 .732 .948 r
.7815 .63692 .78429 .64017 .79078 .63933 .788 .63609 Mtetra
.575 .732 .949 r
.788 .63609 .79078 .63933 .79729 .63851 .79453 .63527 Mtetra
.573 .732 .95 r
.79453 .63527 .79729 .63851 .80383 .63771 .80107 .63446 Mtetra
.572 .732 .95 r
.80107 .63446 .80383 .63771 .81038 .63691 .80763 .63368 Mtetra
.569 .731 .951 r
.80763 .63368 .81038 .63691 .81695 .63614 .81421 .63291 Mtetra
.568 .731 .952 r
.81421 .63291 .81695 .63614 .82354 .63539 .82081 .63216 Mtetra
.566 .731 .953 r
.82081 .63216 .82354 .63539 .83015 .63465 .82743 .63143 Mtetra
.562 .73 .954 r
.82743 .63143 .83015 .63465 .83678 .63394 .83408 .63073 Mtetra
.561 .73 .954 r
.83408 .63073 .83678 .63394 .84343 .63324 .84074 .63004 Mtetra
.558 .73 .955 r
.84074 .63004 .84343 .63324 .85011 .63257 .84743 .62937 Mtetra
.555 .73 .956 r
.84743 .62937 .85011 .63257 .8568 .63192 .85413 .62873 Mtetra
.553 .73 .957 r
.85413 .62873 .8568 .63192 .86352 .63129 .86086 .62811 Mtetra
.549 .73 .958 r
.86086 .62811 .86352 .63129 .87026 .63068 .86762 .62751 Mtetra
.547 .73 .959 r
.86762 .62751 .87026 .63068 .87702 .63009 .87439 .62694 Mtetra
.544 .73 .961 r
.87439 .62694 .87702 .63009 .88381 .62952 .88119 .62638 Mtetra
.544 .731 .961 r
.88119 .62638 .88381 .62952 .89061 .62894 .88801 .62582 Mtetra
.546 .734 .962 r
.88801 .62582 .89061 .62894 .89743 .62832 .89484 .62522 Mtetra
.551 .738 .963 r
.89484 .62522 .89743 .62832 .90427 .62762 .90169 .62454 Mtetra
.579 .753 .96 r
.90169 .62454 .90427 .62762 .91108 .62657 .90852 .62353 Mtetra
.602 .766 .958 r
.90852 .62353 .91108 .62657 .91788 .62523 .91533 .62222 Mtetra
.672 .798 .942 r
.91533 .62222 .91788 .62523 .92458 .62288 .92205 .61993 Mtetra
.754 .829 .91 r
.92205 .61993 .92458 .62288 .93112 .61908 .92862 .61621 Mtetra
.803 .845 .882 r
.92862 .61621 .93112 .61908 .93754 .61418 .93506 .61139 Mtetra
.913 .852 .768 r
.93506 .61139 .93754 .61418 .94343 .60494 .94099 .60225 Mtetra
.946 .846 .712 r
.94099 .60225 .94343 .60494 .949 .59317 .94658 .59059 Mtetra
.971 .829 .644 r
.94658 .59059 .949 .59317 .95406 .5776 .95168 .57513 Mtetra
.987 .805 .573 r
.95168 .57513 .95406 .5776 .95837 .55654 .95603 .55415 Mtetra
.991 .796 .547 r
.95603 .55415 .95837 .55654 .96231 .53309 .96001 .53077 Mtetra
.932 .563 .279 r
.36083 .63771 .36411 .64087 .36869 .65659 .3654 .65345 Mtetra
.926 .544 .246 r
.3654 .65345 .36869 .65659 .37338 .67099 .37008 .66787 Mtetra
.893 .469 .121 r
.37008 .66787 .37338 .67099 .37828 .68192 .37498 .67882 Mtetra
.815 .343 0 r
.37498 .67882 .37828 .68192 .38334 .69013 .38003 .68705 Mtetra
.689 .184 0 r
.38003 .68705 .38334 .69013 .38852 .69653 .3852 .69347 Mtetra
0 .373 .826 r
.3852 .69347 .38852 .69653 .39385 .69946 .39054 .6964 Mtetra
.159 .519 .917 r
.39054 .6964 .39385 .69946 .39925 .70144 .39594 .69839 Mtetra
.399 .649 .959 r
.39594 .69839 .39925 .70144 .40471 .70216 .40141 .69912 Mtetra
.53 .706 .952 r
.40141 .69912 .40471 .70216 .41022 .70193 .40692 .69889 Mtetra
.563 .719 .946 r
.40692 .69889 .41022 .70193 .41576 .70139 .41247 .69835 Mtetra
.597 .731 .938 r
.41247 .69835 .41576 .70139 .42132 .70049 .41803 .69744 Mtetra
.608 .734 .935 r
.41803 .69744 .42132 .70049 .42689 .69948 .42362 .69642 Mtetra
.613 .736 .933 r
.42362 .69642 .42689 .69948 .43249 .6984 .42922 .69534 Mtetra
.617 .737 .932 r
.42922 .69534 .43249 .6984 .43809 .69728 .43483 .69421 Mtetra
.43483 .69421 .43809 .69728 .44371 .69614 .44046 .69307 Mtetra
.618 .738 .932 r
.44046 .69307 .44371 .69614 .44935 .695 .4461 .69192 Mtetra
.618 .737 .932 r
.4461 .69192 .44935 .695 .45499 .69386 .45175 .69078 Mtetra
.45175 .69078 .45499 .69386 .46065 .69272 .45742 .68963 Mtetra
.45742 .68963 .46065 .69272 .46633 .69157 .4631 .68848 Mtetra
.617 .737 .932 r
.4631 .68848 .46633 .69157 .47201 .69043 .46879 .68733 Mtetra
.46879 .68733 .47201 .69043 .47771 .68929 .4745 .68618 Mtetra
.4745 .68618 .47771 .68929 .48342 .68815 .48022 .68504 Mtetra
.616 .737 .932 r
.48022 .68504 .48342 .68815 .48915 .68701 .48595 .68389 Mtetra
.48595 .68389 .48915 .68701 .49489 .68588 .4917 .68275 Mtetra
.4917 .68275 .49489 .68588 .50064 .68474 .49746 .6816 Mtetra
.615 .736 .932 r
.49746 .6816 .50064 .68474 .50641 .6836 .50323 .68046 Mtetra
.50323 .68046 .50641 .6836 .51219 .68247 .50902 .67932 Mtetra
.50902 .67932 .51219 .68247 .51799 .68133 .51482 .67818 Mtetra
.51482 .67818 .51799 .68133 .5238 .6802 .52064 .67704 Mtetra
.614 .736 .933 r
.52064 .67704 .5238 .6802 .52962 .67907 .52647 .67591 Mtetra
.52647 .67591 .52962 .67907 .53546 .67795 .53231 .67477 Mtetra
.53231 .67477 .53546 .67795 .54131 .67681 .53817 .67364 Mtetra
.612 .735 .933 r
.53817 .67364 .54131 .67681 .54717 .6757 .54404 .67251 Mtetra
.54404 .67251 .54717 .6757 .55305 .67458 .54993 .67138 Mtetra
.54993 .67138 .55305 .67458 .55894 .67346 .55583 .67026 Mtetra
.55583 .67026 .55894 .67346 .56485 .67234 .56174 .66914 Mtetra
.611 .735 .933 r
.56174 .66914 .56485 .67234 .57077 .67123 .56767 .66802 Mtetra
.61 .734 .933 r
.56767 .66802 .57077 .67123 .57671 .67013 .57362 .66691 Mtetra
.57362 .66691 .57671 .67013 .58266 .66902 .57958 .66579 Mtetra
.57958 .66579 .58266 .66902 .58863 .66791 .58555 .66468 Mtetra
.609 .733 .934 r
.58555 .66468 .58863 .66791 .59461 .66682 .59154 .66358 Mtetra
.59154 .66358 .59461 .66682 .60061 .66573 .59755 .66248 Mtetra
.59755 .66248 .60061 .66573 .60662 .66463 .60356 .66138 Mtetra
.607 .733 .934 r
.60356 .66138 .60662 .66463 .61264 .66355 .6096 .66029 Mtetra
.6096 .66029 .61264 .66355 .61868 .66247 .61565 .6592 Mtetra
.61565 .6592 .61868 .66247 .62474 .66139 .62171 .65811 Mtetra
.605 .732 .934 r
.62171 .65811 .62474 .66139 .63081 .66032 .62779 .65704 Mtetra
.605 .732 .935 r
.62779 .65704 .63081 .66032 .6369 .65926 .63389 .65597 Mtetra
.63389 .65597 .6369 .65926 .64301 .65819 .64 .6549 Mtetra
.604 .731 .935 r
.64 .6549 .64301 .65819 .64912 .65714 .64613 .65384 Mtetra
.603 .731 .935 r
.64613 .65384 .64912 .65714 .65526 .65609 .65227 .65278 Mtetra
.602 .731 .935 r
.65227 .65278 .65526 .65609 .66141 .65505 .65843 .65174 Mtetra
.602 .73 .935 r
.65843 .65174 .66141 .65505 .66758 .65401 .66461 .65069 Mtetra
.601 .73 .935 r
.66461 .65069 .66758 .65401 .67376 .65299 .6708 .64966 Mtetra
.6 .73 .936 r
.6708 .64966 .67376 .65299 .67996 .65197 .67701 .64863 Mtetra
.67701 .64863 .67996 .65197 .68618 .65095 .68323 .64761 Mtetra
.598 .729 .936 r
.68323 .64761 .68618 .65095 .69241 .64995 .68947 .6466 Mtetra
.597 .729 .936 r
.68947 .6466 .69241 .64995 .69866 .64895 .69573 .64559 Mtetra
.69573 .64559 .69866 .64895 .70493 .64795 .70201 .64459 Mtetra
.595 .728 .937 r
.70201 .64459 .70493 .64795 .71121 .64698 .7083 .64361 Mtetra
.7083 .64361 .71121 .64698 .71751 .64601 .71461 .64264 Mtetra
.594 .727 .937 r
.71461 .64264 .71751 .64601 .72383 .64505 .72093 .64167 Mtetra
.592 .727 .937 r
.72093 .64167 .72383 .64505 .73016 .6441 .72728 .64071 Mtetra
.592 .726 .937 r
.72728 .64071 .73016 .6441 .73652 .64316 .73364 .63977 Mtetra
.591 .726 .938 r
.73364 .63977 .73652 .64316 .74289 .64223 .74002 .63883 Mtetra
.589 .725 .938 r
.74002 .63883 .74289 .64223 .74928 .64131 .74642 .63791 Mtetra
.588 .725 .938 r
.74642 .63791 .74928 .64131 .75569 .64041 .75284 .637 Mtetra
.587 .724 .939 r
.75284 .637 .75569 .64041 .76211 .63952 .75927 .6361 Mtetra
.586 .724 .939 r
.75927 .6361 .76211 .63952 .76856 .63864 .76573 .63522 Mtetra
.584 .724 .939 r
.76573 .63522 .76856 .63864 .77502 .63777 .7722 .63435 Mtetra
.582 .723 .94 r
.7722 .63435 .77502 .63777 .7815 .63692 .77869 .6335 Mtetra
.581 .723 .94 r
.77869 .6335 .7815 .63692 .788 .63609 .7852 .63266 Mtetra
.58 .722 .94 r
.7852 .63266 .788 .63609 .79453 .63527 .79173 .63183 Mtetra
.578 .722 .941 r
.79173 .63183 .79453 .63527 .80107 .63446 .79828 .63102 Mtetra
.577 .721 .941 r
.79828 .63102 .80107 .63446 .80763 .63368 .80485 .63023 Mtetra
.575 .72 .942 r
.80485 .63023 .80763 .63368 .81421 .63291 .81144 .62946 Mtetra
.573 .72 .942 r
.81144 .62946 .81421 .63291 .82081 .63216 .81805 .62871 Mtetra
.571 .719 .942 r
.81805 .62871 .82081 .63216 .82743 .63143 .82469 .62797 Mtetra
.569 .718 .943 r
.82469 .62797 .82743 .63143 .83408 .63073 .83134 .62727 Mtetra
.567 .718 .943 r
.83134 .62727 .83408 .63073 .84074 .63004 .83801 .62658 Mtetra
.565 .717 .944 r
.83801 .62658 .84074 .63004 .84743 .62937 .84471 .62591 Mtetra
.563 .716 .944 r
.84471 .62591 .84743 .62937 .85413 .62873 .85143 .62527 Mtetra
.561 .716 .945 r
.85143 .62527 .85413 .62873 .86086 .62811 .85817 .62464 Mtetra
.558 .715 .945 r
.85817 .62464 .86086 .62811 .86762 .62751 .86493 .62405 Mtetra
.556 .714 .946 r
.86493 .62405 .86762 .62751 .87439 .62694 .87172 .62347 Mtetra
.554 .714 .946 r
.87172 .62347 .87439 .62694 .88119 .62638 .87853 .62292 Mtetra
.554 .714 .947 r
.87853 .62292 .88119 .62638 .88801 .62582 .88535 .62236 Mtetra
.557 .716 .947 r
.88535 .62236 .88801 .62582 .89484 .62522 .8922 .62176 Mtetra
.562 .719 .947 r
.8922 .62176 .89484 .62522 .90169 .62454 .89906 .62109 Mtetra
.587 .732 .944 r
.89906 .62109 .90169 .62454 .90852 .62353 .9059 .6201 Mtetra
.608 .743 .941 r
.9059 .6201 .90852 .62353 .91533 .62222 .91273 .61882 Mtetra
.672 .772 .925 r
.91273 .61882 .91533 .62222 .92205 .61993 .91947 .61657 Mtetra
.747 .801 .895 r
.91947 .61657 .92205 .61993 .92862 .61621 .92606 .6129 Mtetra
.793 .817 .871 r
.92606 .6129 .92862 .61621 .93506 .61139 .93252 .60815 Mtetra
.901 .831 .768 r
.93252 .60815 .93506 .61139 .94099 .60225 .93848 .59913 Mtetra
.935 .829 .716 r
.93848 .59913 .94099 .60225 .94658 .59059 .94411 .58758 Mtetra
.963 .817 .651 r
.94411 .58758 .94658 .59059 .95168 .57513 .94924 .57225 Mtetra
.982 .797 .58 r
.94924 .57225 .95168 .57513 .95603 .55415 .95363 .55138 Mtetra
.987 .79 .554 r
.95363 .55138 .95603 .55415 .96001 .53077 .95765 .52808 Mtetra
.932 .563 .279 r
.35755 .63455 .36083 .63771 .3654 .65345 .3621 .6503 Mtetra
.926 .544 .246 r
.3621 .6503 .3654 .65345 .37008 .66787 .36677 .66474 Mtetra
.893 .469 .122 r
.36677 .66474 .37008 .66787 .37498 .67882 .37166 .67571 Mtetra
.816 .344 0 r
.37166 .67571 .37498 .67882 .38003 .68705 .37671 .68396 Mtetra
.69 .185 0 r
.37671 .68396 .38003 .68705 .3852 .69347 .38188 .69039 Mtetra
0 .371 .825 r
.38188 .69039 .3852 .69347 .39054 .6964 .38722 .69334 Mtetra
.158 .518 .916 r
.38722 .69334 .39054 .6964 .39594 .69839 .39262 .69533 Mtetra
.398 .649 .959 r
.39262 .69533 .39594 .69839 .40141 .69912 .39809 .69606 Mtetra
.529 .706 .952 r
.39809 .69606 .40141 .69912 .40692 .69889 .40361 .69583 Mtetra
.563 .718 .946 r
.40361 .69583 .40692 .69889 .41247 .69835 .40916 .69528 Mtetra
.598 .731 .937 r
.40916 .69528 .41247 .69835 .41803 .69744 .41474 .69438 Mtetra
.608 .734 .934 r
.41474 .69438 .41803 .69744 .42362 .69642 .42033 .69335 Mtetra
.613 .736 .933 r
.42033 .69335 .42362 .69642 .42922 .69534 .42593 .69226 Mtetra
.617 .737 .932 r
.42593 .69226 .42922 .69534 .43483 .69421 .43155 .69113 Mtetra
.618 .737 .932 r
.43155 .69113 .43483 .69421 .44046 .69307 .43719 .68998 Mtetra
.618 .737 .931 r
.43719 .68998 .44046 .69307 .4461 .69192 .44283 .68883 Mtetra
.44283 .68883 .4461 .69192 .45175 .69078 .44849 .68767 Mtetra
.44849 .68767 .45175 .69078 .45742 .68963 .45417 .68652 Mtetra
.45417 .68652 .45742 .68963 .4631 .68848 .45985 .68536 Mtetra
.617 .737 .931 r
.45985 .68536 .4631 .68848 .46879 .68733 .46555 .68421 Mtetra
.617 .736 .931 r
.46555 .68421 .46879 .68733 .4745 .68618 .47127 .68305 Mtetra
.47127 .68305 .4745 .68618 .48022 .68504 .47699 .6819 Mtetra
.616 .736 .932 r
.47699 .6819 .48022 .68504 .48595 .68389 .48273 .68075 Mtetra
.48273 .68075 .48595 .68389 .4917 .68275 .48849 .6796 Mtetra
.48849 .6796 .4917 .68275 .49746 .6816 .49426 .67844 Mtetra
.49426 .67844 .49746 .6816 .50323 .68046 .50004 .67729 Mtetra
.615 .735 .932 r
.50004 .67729 .50323 .68046 .50902 .67932 .50583 .67615 Mtetra
.50583 .67615 .50902 .67932 .51482 .67818 .51164 .675 Mtetra
.51164 .675 .51482 .67818 .52064 .67704 .51747 .67385 Mtetra
.614 .735 .932 r
.51747 .67385 .52064 .67704 .52647 .67591 .5233 .67271 Mtetra
.5233 .67271 .52647 .67591 .53231 .67477 .52915 .67157 Mtetra
.52915 .67157 .53231 .67477 .53817 .67364 .53502 .67043 Mtetra
.613 .734 .932 r
.53502 .67043 .53817 .67364 .54404 .67251 .5409 .66929 Mtetra
.5409 .66929 .54404 .67251 .54993 .67138 .54679 .66816 Mtetra
.612 .734 .932 r
.54679 .66816 .54993 .67138 .55583 .67026 .5527 .66703 Mtetra
.5527 .66703 .55583 .67026 .56174 .66914 .55863 .6659 Mtetra
.612 .733 .932 r
.55863 .6659 .56174 .66914 .56767 .66802 .56456 .66477 Mtetra
.611 .733 .932 r
.56456 .66477 .56767 .66802 .57362 .66691 .57052 .66365 Mtetra
.57052 .66365 .57362 .66691 .57958 .66579 .57648 .66253 Mtetra
.57648 .66253 .57958 .66579 .58555 .66468 .58246 .66141 Mtetra
.609 .732 .933 r
.58246 .66141 .58555 .66468 .59154 .66358 .58846 .6603 Mtetra
.609 .732 .932 r
.58846 .6603 .59154 .66358 .59755 .66248 .59447 .65919 Mtetra
.59447 .65919 .59755 .66248 .60356 .66138 .6005 .65808 Mtetra
.608 .731 .933 r
.6005 .65808 .60356 .66138 .6096 .66029 .60654 .65699 Mtetra
.607 .731 .933 r
.60654 .65699 .6096 .66029 .61565 .6592 .6126 .65589 Mtetra
.6126 .65589 .61565 .6592 .62171 .65811 .61867 .6548 Mtetra
.606 .73 .933 r
.61867 .6548 .62171 .65811 .62779 .65704 .62476 .65371 Mtetra
.62476 .65371 .62779 .65704 .63389 .65597 .63086 .65263 Mtetra
.605 .73 .933 r
.63086 .65263 .63389 .65597 .64 .6549 .63698 .65156 Mtetra
.605 .729 .933 r
.63698 .65156 .64 .6549 .64613 .65384 .64312 .65049 Mtetra
.604 .729 .933 r
.64312 .65049 .64613 .65384 .65227 .65278 .64927 .64943 Mtetra
.603 .729 .933 r
.64927 .64943 .65227 .65278 .65843 .65174 .65544 .64837 Mtetra
.603 .728 .933 r
.65544 .64837 .65843 .65174 .66461 .65069 .66162 .64732 Mtetra
.602 .728 .933 r
.66162 .64732 .66461 .65069 .6708 .64966 .66782 .64627 Mtetra
.601 .727 .933 r
.66782 .64627 .6708 .64966 .67701 .64863 .67404 .64524 Mtetra
.67404 .64524 .67701 .64863 .68323 .64761 .68027 .6442 Mtetra
.599 .726 .934 r
.68027 .6442 .68323 .64761 .68947 .6466 .68652 .64319 Mtetra
.68652 .64319 .68947 .6466 .69573 .64559 .69279 .64218 Mtetra
.598 .726 .934 r
.69279 .64218 .69573 .64559 .70201 .64459 .69907 .64117 Mtetra
.597 .725 .934 r
.69907 .64117 .70201 .64459 .7083 .64361 .70537 .64018 Mtetra
.596 .724 .934 r
.70537 .64018 .7083 .64361 .71461 .64264 .71169 .63919 Mtetra
.595 .724 .934 r
.71169 .63919 .71461 .64264 .72093 .64167 .71802 .63821 Mtetra
.594 .723 .934 r
.71802 .63821 .72093 .64167 .72728 .64071 .72438 .63725 Mtetra
.593 .723 .934 r
.72438 .63725 .72728 .64071 .73364 .63977 .73075 .63629 Mtetra
.592 .722 .934 r
.73075 .63629 .73364 .63977 .74002 .63883 .73714 .63535 Mtetra
.591 .721 .934 r
.73714 .63535 .74002 .63883 .74642 .63791 .74354 .63442 Mtetra
.59 .721 .934 r
.74354 .63442 .74642 .63791 .75284 .637 .74997 .6335 Mtetra
.589 .72 .935 r
.74997 .6335 .75284 .637 .75927 .6361 .75641 .63259 Mtetra
.588 .72 .935 r
.75641 .63259 .75927 .6361 .76573 .63522 .76288 .6317 Mtetra
.587 .719 .935 r
.76288 .6317 .76573 .63522 .7722 .63435 .76936 .63082 Mtetra
.585 .718 .935 r
.76936 .63082 .7722 .63435 .77869 .6335 .77586 .62996 Mtetra
.584 .717 .935 r
.77586 .62996 .77869 .6335 .7852 .63266 .78238 .6291 Mtetra
.583 .717 .935 r
.78238 .6291 .7852 .63266 .79173 .63183 .78892 .62827 Mtetra
.581 .715 .935 r
.78892 .62827 .79173 .63183 .79828 .63102 .79548 .62745 Mtetra
.58 .715 .935 r
.79548 .62745 .79828 .63102 .80485 .63023 .80205 .62665 Mtetra
.578 .714 .935 r
.80205 .62665 .80485 .63023 .81144 .62946 .80865 .62587 Mtetra
.577 .713 .935 r
.80865 .62587 .81144 .62946 .81805 .62871 .81527 .62511 Mtetra
.575 .712 .935 r
.81527 .62511 .81805 .62871 .82469 .62797 .82192 .62436 Mtetra
.573 .711 .936 r
.82192 .62436 .82469 .62797 .83134 .62727 .82858 .62365 Mtetra
.572 .71 .936 r
.82858 .62365 .83134 .62727 .83801 .62658 .83526 .62294 Mtetra
.57 .709 .936 r
.83526 .62294 .83801 .62658 .84471 .62591 .84197 .62226 Mtetra
.567 .708 .936 r
.84197 .62226 .84471 .62591 .85143 .62527 .84869 .62161 Mtetra
.566 .707 .936 r
.84869 .62161 .85143 .62527 .85817 .62464 .85544 .62098 Mtetra
.564 .705 .936 r
.85544 .62098 .85817 .62464 .86493 .62405 .86222 .62037 Mtetra
.562 .704 .936 r
.86222 .62037 .86493 .62405 .87172 .62347 .86901 .61979 Mtetra
.561 .704 .936 r
.86901 .61979 .87172 .62347 .87853 .62292 .87583 .61922 Mtetra
.561 .703 .936 r
.87583 .61922 .87853 .62292 .88535 .62236 .88267 .61866 Mtetra
.563 .705 .936 r
.88267 .61866 .88535 .62236 .8922 .62176 .88952 .61805 Mtetra
.568 .707 .935 r
.88952 .61805 .8922 .62176 .89906 .62109 .89639 .61738 Mtetra
.592 .718 .931 r
.89639 .61738 .89906 .62109 .9059 .6201 .90325 .61639 Mtetra
.611 .728 .928 r
.90325 .61639 .9059 .6201 .91273 .61882 .91009 .61512 Mtetra
.67 .754 .913 r
.91009 .61512 .91273 .61882 .91947 .61657 .91684 .61289 Mtetra
.741 .782 .885 r
.91684 .61289 .91947 .61657 .92606 .6129 .92345 .60927 Mtetra
.785 .797 .863 r
.92345 .60927 .92606 .6129 .93252 .60815 .92993 .60458 Mtetra
.891 .816 .767 r
.92993 .60458 .93252 .60815 .93848 .59913 .93592 .59566 Mtetra
.926 .816 .718 r
.93592 .59566 .93848 .59913 .94411 .58758 .94158 .58422 Mtetra
.957 .808 .655 r
.94158 .58422 .94411 .58758 .94924 .57225 .94675 .56902 Mtetra
.977 .791 .586 r
.94675 .56902 .94924 .57225 .95363 .55138 .95118 .54828 Mtetra
.983 .785 .559 r
.95118 .54828 .95363 .55138 .95765 .52808 .95524 .5251 Mtetra
.932 .563 .279 r
.35425 .63138 .35755 .63455 .3621 .6503 .35879 .64714 Mtetra
.926 .544 .246 r
.35879 .64714 .3621 .6503 .36677 .66474 .36345 .6616 Mtetra
.893 .469 .123 r
.36345 .6616 .36677 .66474 .37166 .67571 .36833 .67259 Mtetra
.817 .345 0 r
.36833 .67259 .37166 .67571 .37671 .68396 .37338 .68086 Mtetra
.692 .187 0 r
.37338 .68086 .37671 .68396 .38188 .69039 .37855 .68731 Mtetra
0 .369 .824 r
.37855 .68731 .38188 .69039 .38722 .69334 .38389 .69026 Mtetra
.156 .516 .916 r
.38389 .69026 .38722 .69334 .39262 .69533 .38929 .69226 Mtetra
.397 .648 .958 r
.38929 .69226 .39262 .69533 .39809 .69606 .39477 .693 Mtetra
.529 .706 .952 r
.39477 .693 .39809 .69606 .40361 .69583 .40029 .69276 Mtetra
.562 .718 .946 r
.40029 .69276 .40361 .69583 .40916 .69528 .40585 .69221 Mtetra
.597 .731 .937 r
.40585 .69221 .40916 .69528 .41474 .69438 .41143 .6913 Mtetra
.608 .734 .935 r
.41143 .6913 .41474 .69438 .42033 .69335 .41702 .69027 Mtetra
.613 .736 .933 r
.41702 .69027 .42033 .69335 .42593 .69226 .42264 .68917 Mtetra
.617 .737 .932 r
.42264 .68917 .42593 .69226 .43155 .69113 .42826 .68803 Mtetra
.618 .737 .932 r
.42826 .68803 .43155 .69113 .43719 .68998 .4339 .68688 Mtetra
.618 .737 .931 r
.4339 .68688 .43719 .68998 .44283 .68883 .43956 .68572 Mtetra
.43956 .68572 .44283 .68883 .44849 .68767 .44522 .68456 Mtetra
.44522 .68456 .44849 .68767 .45417 .68652 .45091 .6834 Mtetra
.45091 .6834 .45417 .68652 .45985 .68536 .4566 .68223 Mtetra
.617 .737 .931 r
.4566 .68223 .45985 .68536 .46555 .68421 .46231 .68107 Mtetra
.617 .736 .931 r
.46231 .68107 .46555 .68421 .47127 .68305 .46803 .67991 Mtetra
.46803 .67991 .47127 .68305 .47699 .6819 .47376 .67875 Mtetra
.617 .736 .932 r
.47376 .67875 .47699 .6819 .48273 .68075 .47951 .67759 Mtetra
.616 .736 .932 r
.47951 .67759 .48273 .68075 .48849 .6796 .48527 .67643 Mtetra
.48527 .67643 .48849 .6796 .49426 .67844 .49104 .67527 Mtetra
.49104 .67527 .49426 .67844 .50004 .67729 .49683 .67412 Mtetra
.615 .735 .932 r
.49683 .67412 .50004 .67729 .50583 .67615 .50264 .67296 Mtetra
.50264 .67296 .50583 .67615 .51164 .675 .50845 .67181 Mtetra
.50845 .67181 .51164 .675 .51747 .67385 .51428 .67065 Mtetra
.614 .735 .932 r
.51428 .67065 .51747 .67385 .5233 .67271 .52013 .66951 Mtetra
.52013 .66951 .5233 .67271 .52915 .67157 .52599 .66836 Mtetra
.52599 .66836 .52915 .67157 .53502 .67043 .53186 .6672 Mtetra
.613 .734 .932 r
.53186 .6672 .53502 .67043 .5409 .66929 .53775 .66606 Mtetra
.53775 .66606 .5409 .66929 .54679 .66816 .54365 .66492 Mtetra
.612 .734 .932 r
.54365 .66492 .54679 .66816 .5527 .66703 .54956 .66379 Mtetra
.54956 .66379 .5527 .66703 .55863 .6659 .55549 .66265 Mtetra
.612 .733 .932 r
.55549 .66265 .55863 .6659 .56456 .66477 .56144 .66151 Mtetra
.611 .733 .932 r
.56144 .66151 .56456 .66477 .57052 .66365 .5674 .66038 Mtetra
.5674 .66038 .57052 .66365 .57648 .66253 .57337 .65926 Mtetra
.57337 .65926 .57648 .66253 .58246 .66141 .57936 .65813 Mtetra
.609 .732 .932 r
.57936 .65813 .58246 .66141 .58846 .6603 .58537 .65701 Mtetra
.58537 .65701 .58846 .6603 .59447 .65919 .59139 .65589 Mtetra
.59139 .65589 .59447 .65919 .6005 .65808 .59742 .65477 Mtetra
.608 .731 .933 r
.59742 .65477 .6005 .65808 .60654 .65699 .60347 .65367 Mtetra
.60347 .65367 .60654 .65699 .6126 .65589 .60954 .65257 Mtetra
.608 .731 .932 r
.60954 .65257 .6126 .65589 .61867 .6548 .61562 .65146 Mtetra
.606 .73 .933 r
.61562 .65146 .61867 .6548 .62476 .65371 .62171 .65037 Mtetra
.62171 .65037 .62476 .65371 .63086 .65263 .62783 .64929 Mtetra
.62783 .64929 .63086 .65263 .63698 .65156 .63395 .6482 Mtetra
.605 .729 .933 r
.63395 .6482 .63698 .65156 .64312 .65049 .6401 .64712 Mtetra
.604 .729 .933 r
.6401 .64712 .64312 .65049 .64927 .64943 .64626 .64605 Mtetra
.603 .728 .933 r
.64626 .64605 .64927 .64943 .65544 .64837 .65243 .64498 Mtetra
.65243 .64498 .65544 .64837 .66162 .64732 .65862 .64392 Mtetra
.602 .727 .933 r
.65862 .64392 .66162 .64732 .66782 .64627 .66483 .64287 Mtetra
.601 .727 .933 r
.66483 .64287 .66782 .64627 .67404 .64524 .67106 .64183 Mtetra
.67106 .64183 .67404 .64524 .68027 .6442 .6773 .64078 Mtetra
.599 .726 .933 r
.6773 .64078 .68027 .6442 .68652 .64319 .68356 .63976 Mtetra
.68356 .63976 .68652 .64319 .69279 .64218 .68983 .63874 Mtetra
.599 .725 .933 r
.68983 .63874 .69279 .64218 .69907 .64117 .69612 .63772 Mtetra
.597 .725 .934 r
.69612 .63772 .69907 .64117 .70537 .64018 .70243 .63672 Mtetra
.596 .724 .934 r
.70243 .63672 .70537 .64018 .71169 .63919 .70876 .63572 Mtetra
.70876 .63572 .71169 .63919 .71802 .63821 .7151 .63473 Mtetra
.594 .723 .934 r
.7151 .63473 .71802 .63821 .72438 .63725 .72146 .63376 Mtetra
.594 .722 .934 r
.72146 .63376 .72438 .63725 .73075 .63629 .72784 .6328 Mtetra
.593 .722 .934 r
.72784 .6328 .73075 .63629 .73714 .63535 .73424 .63184 Mtetra
.591 .721 .934 r
.73424 .63184 .73714 .63535 .74354 .63442 .74066 .6309 Mtetra
.74066 .6309 .74354 .63442 .74997 .6335 .74709 .62997 Mtetra
.589 .72 .934 r
.74709 .62997 .74997 .6335 .75641 .63259 .75354 .62906 Mtetra
.588 .719 .934 r
.75354 .62906 .75641 .63259 .76288 .6317 .76001 .62815 Mtetra
.587 .719 .934 r
.76001 .62815 .76288 .6317 .76936 .63082 .7665 .62726 Mtetra
.585 .717 .934 r
.7665 .62726 .76936 .63082 .77586 .62996 .77301 .62639 Mtetra
.77301 .62639 .77586 .62996 .78238 .6291 .77954 .62553 Mtetra
.583 .716 .934 r
.77954 .62553 .78238 .6291 .78892 .62827 .78609 .62468 Mtetra
.582 .715 .934 r
.78609 .62468 .78892 .62827 .79548 .62745 .79266 .62385 Mtetra
.581 .714 .934 r
.79266 .62385 .79548 .62745 .80205 .62665 .79925 .62304 Mtetra
.579 .713 .935 r
.79925 .62304 .80205 .62665 .80865 .62587 .80585 .62225 Mtetra
.577 .712 .935 r
.80585 .62225 .80865 .62587 .81527 .62511 .81248 .62147 Mtetra
.576 .711 .935 r
.81248 .62147 .81527 .62511 .82192 .62436 .81913 .62072 Mtetra
.574 .71 .935 r
.81913 .62072 .82192 .62436 .82858 .62365 .8258 .61999 Mtetra
.573 .709 .935 r
.8258 .61999 .82858 .62365 .83526 .62294 .8325 .61928 Mtetra
.571 .708 .935 r
.8325 .61928 .83526 .62294 .84197 .62226 .83921 .61859 Mtetra
.568 .707 .935 r
.83921 .61859 .84197 .62226 .84869 .62161 .84595 .61792 Mtetra
.567 .706 .935 r
.84595 .61792 .84869 .62161 .85544 .62098 .85271 .61728 Mtetra
.565 .704 .935 r
.85271 .61728 .85544 .62098 .86222 .62037 .85949 .61666 Mtetra
.563 .703 .935 r
.85949 .61666 .86222 .62037 .86901 .61979 .86629 .61607 Mtetra
.562 .702 .935 r
.86629 .61607 .86901 .61979 .87583 .61922 .87312 .61549 Mtetra
.87312 .61549 .87583 .61922 .88267 .61866 .87997 .61491 Mtetra
.564 .703 .934 r
.87997 .61491 .88267 .61866 .88952 .61805 .88683 .6143 Mtetra
.569 .705 .934 r
.88683 .6143 .88952 .61805 .89639 .61738 .89371 .61362 Mtetra
.592 .716 .93 r
.89371 .61362 .89639 .61738 .90325 .61639 .90058 .61263 Mtetra
.611 .725 .926 r
.90058 .61263 .90325 .61639 .91009 .61512 .90743 .61136 Mtetra
.669 .751 .912 r
.90743 .61136 .91009 .61512 .91684 .61289 .9142 .60916 Mtetra
.739 .778 .885 r
.9142 .60916 .91684 .61289 .92345 .60927 .92082 .60558 Mtetra
.782 .794 .863 r
.92082 .60558 .92345 .60927 .92993 .60458 .92733 .60095 Mtetra
.888 .813 .769 r
.92733 .60095 .92993 .60458 .93592 .59566 .93334 .59212 Mtetra
.924 .815 .72 r
.93334 .59212 .93592 .59566 .94158 .58422 .93903 .5808 Mtetra
.955 .807 .658 r
.93903 .5808 .94158 .58422 .94675 .56902 .94424 .56572 Mtetra
.976 .791 .588 r
.94424 .56572 .94675 .56902 .95118 .54828 .94871 .54511 Mtetra
.983 .785 .562 r
.94871 .54511 .95118 .54828 .95524 .5251 .95281 .52204 Mtetra
.932 .563 .28 r
.35093 .6282 .35425 .63138 .35879 .64714 .35546 .64398 Mtetra
.926 .544 .247 r
.35546 .64398 .35879 .64714 .36345 .6616 .36012 .65845 Mtetra
.893 .47 .124 r
.36012 .65845 .36345 .6616 .36833 .67259 .36499 .66946 Mtetra
.817 .346 0 r
.36499 .66946 .36833 .67259 .37338 .68086 .37003 .67775 Mtetra
.694 .189 0 r
.37003 .67775 .37338 .68086 .37855 .68731 .3752 .68421 Mtetra
0 .367 .822 r
.3752 .68421 .37855 .68731 .38389 .69026 .38054 .68718 Mtetra
.154 .515 .915 r
.38054 .68718 .38389 .69026 .38929 .69226 .38595 .68918 Mtetra
.396 .648 .959 r
.38595 .68918 .38929 .69226 .39477 .693 .39143 .68992 Mtetra
.529 .706 .952 r
.39143 .68992 .39477 .693 .40029 .69276 .39696 .68968 Mtetra
.562 .718 .946 r
.39696 .68968 .40029 .69276 .40585 .69221 .40252 .68913 Mtetra
.597 .731 .938 r
.40252 .68913 .40585 .69221 .41143 .6913 .40811 .68821 Mtetra
.608 .734 .935 r
.40811 .68821 .41143 .6913 .41702 .69027 .41371 .68718 Mtetra
.613 .736 .933 r
.41371 .68718 .41702 .69027 .42264 .68917 .41933 .68607 Mtetra
.617 .737 .932 r
.41933 .68607 .42264 .68917 .42826 .68803 .42496 .68492 Mtetra
.618 .737 .932 r
.42496 .68492 .42826 .68803 .4339 .68688 .43061 .68377 Mtetra
.618 .737 .931 r
.43061 .68377 .4339 .68688 .43956 .68572 .43627 .6826 Mtetra
.43627 .6826 .43956 .68572 .44522 .68456 .44194 .68143 Mtetra
.44194 .68143 .44522 .68456 .45091 .6834 .44763 .68026 Mtetra
.44763 .68026 .45091 .6834 .4566 .68223 .45333 .67909 Mtetra
.617 .737 .931 r
.45333 .67909 .4566 .68223 .46231 .68107 .45905 .67792 Mtetra
.45905 .67792 .46231 .68107 .46803 .67991 .46477 .67676 Mtetra
.46477 .67676 .46803 .67991 .47376 .67875 .47051 .67559 Mtetra
.617 .736 .932 r
.47051 .67559 .47376 .67875 .47951 .67759 .47627 .67442 Mtetra
.616 .736 .932 r
.47627 .67442 .47951 .67759 .48527 .67643 .48204 .67326 Mtetra
.48204 .67326 .48527 .67643 .49104 .67527 .48782 .67209 Mtetra
.48782 .67209 .49104 .67527 .49683 .67412 .49362 .67093 Mtetra
.615 .736 .932 r
.49362 .67093 .49683 .67412 .50264 .67296 .49943 .66977 Mtetra
.615 .735 .932 r
.49943 .66977 .50264 .67296 .50845 .67181 .50525 .6686 Mtetra
.50525 .6686 .50845 .67181 .51428 .67065 .51109 .66744 Mtetra
.614 .735 .932 r
.51109 .66744 .51428 .67065 .52013 .66951 .51694 .66629 Mtetra
.51694 .66629 .52013 .66951 .52599 .66836 .52281 .66513 Mtetra
.52281 .66513 .52599 .66836 .53186 .6672 .52869 .66397 Mtetra
.613 .734 .932 r
.52869 .66397 .53186 .6672 .53775 .66606 .53458 .66282 Mtetra
.53458 .66282 .53775 .66606 .54365 .66492 .54049 .66167 Mtetra
.612 .734 .932 r
.54049 .66167 .54365 .66492 .54956 .66379 .54641 .66053 Mtetra
.54641 .66053 .54956 .66379 .55549 .66265 .55235 .65938 Mtetra
.55235 .65938 .55549 .66265 .56144 .66151 .5583 .65824 Mtetra
.611 .733 .932 r
.5583 .65824 .56144 .66151 .5674 .66038 .56427 .6571 Mtetra
.56427 .6571 .5674 .66038 .57337 .65926 .57025 .65597 Mtetra
.57025 .65597 .57337 .65926 .57936 .65813 .57625 .65483 Mtetra
.609 .732 .932 r
.57625 .65483 .57936 .65813 .58537 .65701 .58226 .65371 Mtetra
.58226 .65371 .58537 .65701 .59139 .65589 .58829 .65258 Mtetra
.61 .732 .932 r
.58829 .65258 .59139 .65589 .59742 .65477 .59433 .65145 Mtetra
.608 .731 .933 r
.59433 .65145 .59742 .65477 .60347 .65367 .60039 .65034 Mtetra
.608 .731 .932 r
.60039 .65034 .60347 .65367 .60954 .65257 .60646 .64923 Mtetra
.60646 .64923 .60954 .65257 .61562 .65146 .61255 .64812 Mtetra
.607 .73 .933 r
.61255 .64812 .61562 .65146 .62171 .65037 .61866 .64702 Mtetra
.606 .73 .933 r
.61866 .64702 .62171 .65037 .62783 .64929 .62478 .64592 Mtetra
.62478 .64592 .62783 .64929 .63395 .6482 .63091 .64482 Mtetra
.605 .729 .933 r
.63091 .64482 .63395 .6482 .6401 .64712 .63706 .64374 Mtetra
.604 .729 .933 r
.63706 .64374 .6401 .64712 .64626 .64605 .64323 .64266 Mtetra
.604 .728 .933 r
.64323 .64266 .64626 .64605 .65243 .64498 .64942 .64158 Mtetra
.603 .728 .933 r
.64942 .64158 .65243 .64498 .65862 .64392 .65562 .64051 Mtetra
.602 .727 .933 r
.65562 .64051 .65862 .64392 .66483 .64287 .66183 .63945 Mtetra
.66183 .63945 .66483 .64287 .67106 .64183 .66806 .6384 Mtetra
.601 .727 .933 r
.66806 .6384 .67106 .64183 .6773 .64078 .67431 .63735 Mtetra
.6 .726 .933 r
.67431 .63735 .6773 .64078 .68356 .63976 .68058 .63631 Mtetra
.599 .726 .933 r
.68058 .63631 .68356 .63976 .68983 .63874 .68686 .63528 Mtetra
.599 .725 .933 r
.68686 .63528 .68983 .63874 .69612 .63772 .69316 .63425 Mtetra
.597 .724 .933 r
.69316 .63425 .69612 .63772 .70243 .63672 .69948 .63324 Mtetra
.69948 .63324 .70243 .63672 .70876 .63572 .70582 .63224 Mtetra
.596 .724 .933 r
.70582 .63224 .70876 .63572 .7151 .63473 .71217 .63124 Mtetra
.595 .723 .933 r
.71217 .63124 .7151 .63473 .72146 .63376 .71854 .63026 Mtetra
.594 .722 .933 r
.71854 .63026 .72146 .63376 .72784 .6328 .72493 .62928 Mtetra
.593 .722 .933 r
.72493 .62928 .72784 .6328 .73424 .63184 .73133 .62832 Mtetra
.592 .721 .934 r
.73133 .62832 .73424 .63184 .74066 .6309 .73776 .62737 Mtetra
.591 .72 .934 r
.73776 .62737 .74066 .6309 .74709 .62997 .7442 .62642 Mtetra
.589 .719 .934 r
.7442 .62642 .74709 .62997 .75354 .62906 .75066 .6255 Mtetra
.75066 .6255 .75354 .62906 .76001 .62815 .75714 .62459 Mtetra
.588 .718 .934 r
.75714 .62459 .76001 .62815 .7665 .62726 .76364 .62368 Mtetra
.586 .717 .934 r
.76364 .62368 .7665 .62726 .77301 .62639 .77016 .6228 Mtetra
.585 .717 .934 r
.77016 .6228 .77301 .62639 .77954 .62553 .77669 .62193 Mtetra
.584 .716 .934 r
.77669 .62193 .77954 .62553 .78609 .62468 .78325 .62107 Mtetra
.582 .715 .934 r
.78325 .62107 .78609 .62468 .79266 .62385 .78983 .62023 Mtetra
.581 .714 .934 r
.78983 .62023 .79266 .62385 .79925 .62304 .79642 .61941 Mtetra
.579 .713 .934 r
.79642 .61941 .79925 .62304 .80585 .62225 .80304 .6186 Mtetra
.578 .712 .934 r
.80304 .6186 .80585 .62225 .81248 .62147 .80968 .61782 Mtetra
.576 .711 .934 r
.80968 .61782 .81248 .62147 .81913 .62072 .81634 .61705 Mtetra
.574 .71 .934 r
.81634 .61705 .81913 .62072 .8258 .61999 .82302 .61631 Mtetra
.573 .709 .934 r
.82302 .61631 .8258 .61999 .8325 .61928 .82972 .61558 Mtetra
.571 .708 .934 r
.82972 .61558 .8325 .61928 .83921 .61859 .83644 .61488 Mtetra
.569 .706 .934 r
.83644 .61488 .83921 .61859 .84595 .61792 .84319 .6142 Mtetra
.568 .705 .934 r
.84319 .6142 .84595 .61792 .85271 .61728 .84996 .61354 Mtetra
.566 .704 .934 r
.84996 .61354 .85271 .61728 .85949 .61666 .85675 .61291 Mtetra
.564 .703 .934 r
.85675 .61291 .85949 .61666 .86629 .61607 .86356 .61231 Mtetra
.563 .702 .934 r
.86356 .61231 .86629 .61607 .87312 .61549 .8704 .61171 Mtetra
.563 .701 .934 r
.8704 .61171 .87312 .61549 .87997 .61491 .87725 .61112 Mtetra
.565 .702 .933 r
.87725 .61112 .87997 .61491 .88683 .6143 .88413 .6105 Mtetra
.57 .704 .932 r
.88413 .6105 .88683 .6143 .89371 .61362 .89101 .60981 Mtetra
.592 .714 .928 r
.89101 .60981 .89371 .61362 .90058 .61263 .89789 .60882 Mtetra
.611 .723 .925 r
.89789 .60882 .90058 .61263 .90743 .61136 .90476 .60755 Mtetra
.667 .748 .91 r
.90476 .60755 .90743 .61136 .9142 .60916 .91154 .60537 Mtetra
.736 .775 .884 r
.91154 .60537 .9142 .60916 .92082 .60558 .91818 .60182 Mtetra
.778 .79 .862 r
.91818 .60182 .92082 .60558 .92733 .60095 .9247 .59724 Mtetra
.885 .811 .77 r
.9247 .59724 .92733 .60095 .93334 .59212 .93074 .5885 Mtetra
.921 .812 .722 r
.93074 .5885 .93334 .59212 .93903 .5808 .93647 .57729 Mtetra
.953 .806 .66 r
.93647 .57729 .93903 .5808 .94424 .56572 .94171 .56234 Mtetra
.975 .79 .591 r
.94171 .56234 .94424 .56572 .94871 .54511 .94623 .54185 Mtetra
.982 .784 .564 r
.94623 .54185 .94871 .54511 .95281 .52204 .95036 .5189 Mtetra
.932 .563 .28 r
.34761 .62502 .35093 .6282 .35546 .64398 .35213 .64081 Mtetra
.926 .545 .248 r
.35213 .64081 .35546 .64398 .36012 .65845 .35677 .6553 Mtetra
.894 .471 .125 r
.35677 .6553 .36012 .65845 .36499 .66946 .36164 .66633 Mtetra
.818 .348 0 r
.36164 .66633 .36499 .66946 .37003 .67775 .36667 .67464 Mtetra
.696 .191 0 r
.36667 .67464 .37003 .67775 .3752 .68421 .37184 .68112 Mtetra
0 .365 .82 r
.37184 .68112 .3752 .68421 .38054 .68718 .37718 .68409 Mtetra
.151 .514 .914 r
.37718 .68409 .38054 .68718 .38595 .68918 .38259 .6861 Mtetra
.394 .648 .959 r
.38259 .6861 .38595 .68918 .39143 .68992 .38807 .68684 Mtetra
.528 .706 .952 r
.38807 .68684 .39143 .68992 .39696 .68968 .39361 .68659 Mtetra
.562 .719 .947 r
.39361 .68659 .39696 .68968 .40252 .68913 .39918 .68604 Mtetra
.597 .731 .938 r
.39918 .68604 .40252 .68913 .40811 .68821 .40477 .68512 Mtetra
.608 .735 .935 r
.40477 .68512 .40811 .68821 .41371 .68718 .41038 .68408 Mtetra
.613 .736 .933 r
.41038 .68408 .41371 .68718 .41933 .68607 .41601 .68297 Mtetra
.617 .737 .932 r
.41601 .68297 .41933 .68607 .42496 .68492 .42165 .68181 Mtetra
.618 .738 .932 r
.42165 .68181 .42496 .68492 .43061 .68377 .4273 .68065 Mtetra
.4273 .68065 .43061 .68377 .43627 .6826 .43297 .67947 Mtetra
.43297 .67947 .43627 .6826 .44194 .68143 .43865 .6783 Mtetra
.43865 .6783 .44194 .68143 .44763 .68026 .44434 .67713 Mtetra
.618 .737 .932 r
.44434 .67713 .44763 .68026 .45333 .67909 .45005 .67595 Mtetra
.617 .737 .932 r
.45005 .67595 .45333 .67909 .45905 .67792 .45577 .67477 Mtetra
.45577 .67477 .45905 .67792 .46477 .67676 .46151 .6736 Mtetra
.46151 .6736 .46477 .67676 .47051 .67559 .46726 .67242 Mtetra
.46726 .67242 .47051 .67559 .47627 .67442 .47302 .67125 Mtetra
.616 .737 .932 r
.47302 .67125 .47627 .67442 .48204 .67326 .47879 .67008 Mtetra
.47879 .67008 .48204 .67326 .48782 .67209 .48458 .6689 Mtetra
.616 .736 .932 r
.48458 .6689 .48782 .67209 .49362 .67093 .49039 .66773 Mtetra
.615 .736 .932 r
.49039 .66773 .49362 .67093 .49943 .66977 .4962 .66657 Mtetra
.4962 .66657 .49943 .66977 .50525 .6686 .50203 .6654 Mtetra
.50203 .6654 .50525 .6686 .51109 .66744 .50788 .66423 Mtetra
.614 .735 .932 r
.50788 .66423 .51109 .66744 .51694 .66629 .51374 .66306 Mtetra
.51374 .66306 .51694 .66629 .52281 .66513 .51961 .6619 Mtetra
.51961 .6619 .52281 .66513 .52869 .66397 .5255 .66073 Mtetra
.613 .735 .932 r
.5255 .66073 .52869 .66397 .53458 .66282 .5314 .65958 Mtetra
.5314 .65958 .53458 .66282 .54049 .66167 .53732 .65842 Mtetra
.612 .734 .932 r
.53732 .65842 .54049 .66167 .54641 .66053 .54325 .65727 Mtetra
.54325 .65727 .54641 .66053 .55235 .65938 .5492 .65611 Mtetra
.5492 .65611 .55235 .65938 .5583 .65824 .55516 .65496 Mtetra
.611 .733 .933 r
.55516 .65496 .5583 .65824 .56427 .6571 .56113 .65382 Mtetra
.611 .733 .932 r
.56113 .65382 .56427 .6571 .57025 .65597 .56712 .65267 Mtetra
.56712 .65267 .57025 .65597 .57625 .65483 .57313 .65153 Mtetra
.609 .733 .933 r
.57313 .65153 .57625 .65483 .58226 .65371 .57915 .6504 Mtetra
.609 .732 .933 r
.57915 .6504 .58226 .65371 .58829 .65258 .58518 .64926 Mtetra
.61 .732 .933 r
.58518 .64926 .58829 .65258 .59433 .65145 .59123 .64813 Mtetra
.608 .732 .933 r
.59123 .64813 .59433 .65145 .60039 .65034 .5973 .64701 Mtetra
.608 .731 .933 r
.5973 .64701 .60039 .65034 .60646 .64923 .60338 .64589 Mtetra
.60338 .64589 .60646 .64923 .61255 .64812 .60948 .64476 Mtetra
.607 .731 .933 r
.60948 .64476 .61255 .64812 .61866 .64702 .61559 .64365 Mtetra
.606 .73 .933 r
.61559 .64365 .61866 .64702 .62478 .64592 .62172 .64255 Mtetra
.62172 .64255 .62478 .64592 .63091 .64482 .62786 .64145 Mtetra
.605 .73 .933 r
.62786 .64145 .63091 .64482 .63706 .64374 .63402 .64035 Mtetra
.604 .729 .933 r
.63402 .64035 .63706 .64374 .64323 .64266 .6402 .63926 Mtetra
.6402 .63926 .64323 .64266 .64942 .64158 .64639 .63818 Mtetra
.603 .729 .933 r
.64639 .63818 .64942 .64158 .65562 .64051 .6526 .6371 Mtetra
.602 .728 .933 r
.6526 .6371 .65562 .64051 .66183 .63945 .65882 .63603 Mtetra
.65882 .63603 .66183 .63945 .66806 .6384 .66506 .63496 Mtetra
.601 .727 .933 r
.66506 .63496 .66806 .6384 .67431 .63735 .67132 .6339 Mtetra
.6 .726 .933 r
.67132 .6339 .67431 .63735 .68058 .63631 .67759 .63286 Mtetra
.599 .726 .933 r
.67759 .63286 .68058 .63631 .68686 .63528 .68389 .63182 Mtetra
.68389 .63182 .68686 .63528 .69316 .63425 .69019 .63078 Mtetra
.597 .725 .934 r
.69019 .63078 .69316 .63425 .69948 .63324 .69652 .62976 Mtetra
.69652 .62976 .69948 .63324 .70582 .63224 .70286 .62875 Mtetra
.596 .724 .934 r
.70286 .62875 .70582 .63224 .71217 .63124 .70922 .62774 Mtetra
.595 .723 .934 r
.70922 .62774 .71217 .63124 .71854 .63026 .7156 .62675 Mtetra
.594 .723 .934 r
.7156 .62675 .71854 .63026 .72493 .62928 .722 .62576 Mtetra
.593 .722 .934 r
.722 .62576 .72493 .62928 .73133 .62832 .72841 .62479 Mtetra
.592 .722 .934 r
.72841 .62479 .73133 .62832 .73776 .62737 .73485 .62383 Mtetra
.591 .721 .934 r
.73485 .62383 .73776 .62737 .7442 .62642 .7413 .62287 Mtetra
.589 .72 .934 r
.7413 .62287 .7442 .62642 .75066 .6255 .74777 .62194 Mtetra
.589 .719 .934 r
.74777 .62194 .75066 .6255 .75714 .62459 .75426 .62101 Mtetra
.588 .719 .934 r
.75426 .62101 .75714 .62459 .76364 .62368 .76076 .6201 Mtetra
.586 .718 .934 r
.76076 .6201 .76364 .62368 .77016 .6228 .76729 .61921 Mtetra
.585 .717 .934 r
.76729 .61921 .77016 .6228 .77669 .62193 .77384 .61832 Mtetra
.584 .716 .934 r
.77384 .61832 .77669 .62193 .78325 .62107 .7804 .61745 Mtetra
.582 .715 .934 r
.7804 .61745 .78325 .62107 .78983 .62023 .78699 .6166 Mtetra
.581 .714 .934 r
.78699 .6166 .78983 .62023 .79642 .61941 .79359 .61577 Mtetra
.58 .713 .934 r
.79359 .61577 .79642 .61941 .80304 .6186 .80022 .61495 Mtetra
.578 .712 .934 r
.80022 .61495 .80304 .6186 .80968 .61782 .80686 .61415 Mtetra
.577 .711 .934 r
.80686 .61415 .80968 .61782 .81634 .61705 .81353 .61337 Mtetra
.575 .71 .934 r
.81353 .61337 .81634 .61705 .82302 .61631 .82022 .61261 Mtetra
.574 .709 .934 r
.82022 .61261 .82302 .61631 .82972 .61558 .82693 .61187 Mtetra
.572 .708 .934 r
.82693 .61187 .82972 .61558 .83644 .61488 .83366 .61116 Mtetra
.57 .706 .934 r
.83366 .61116 .83644 .61488 .84319 .6142 .84042 .61047 Mtetra
.569 .706 .934 r
.84042 .61047 .84319 .6142 .84996 .61354 .84719 .60979 Mtetra
.566 .704 .934 r
.84719 .60979 .84996 .61354 .85675 .61291 .85399 .60915 Mtetra
.565 .703 .934 r
.85399 .60915 .85675 .61291 .86356 .61231 .86082 .60853 Mtetra
.564 .702 .934 r
.86082 .60853 .86356 .61231 .8704 .61171 .86766 .60792 Mtetra
.563 .701 .933 r
.86766 .60792 .8704 .61171 .87725 .61112 .87453 .60731 Mtetra
.566 .702 .933 r
.87453 .60731 .87725 .61112 .88413 .6105 .88141 .60668 Mtetra
.571 .704 .932 r
.88141 .60668 .88413 .6105 .89101 .60981 .88831 .60598 Mtetra
.592 .714 .928 r
.88831 .60598 .89101 .60981 .89789 .60882 .89519 .60498 Mtetra
.61 .722 .925 r
.89519 .60498 .89789 .60882 .90476 .60755 .90207 .60371 Mtetra
.666 .747 .91 r
.90207 .60371 .90476 .60755 .91154 .60537 .90886 .60155 Mtetra
.734 .773 .885 r
.90886 .60155 .91154 .60537 .91818 .60182 .91552 .59803 Mtetra
.776 .789 .863 r
.91552 .59803 .91818 .60182 .9247 .59724 .92207 .5935 Mtetra
.883 .81 .772 r
.92207 .5935 .9247 .59724 .93074 .5885 .92813 .58485 Mtetra
.919 .812 .724 r
.92813 .58485 .93074 .5885 .93647 .57729 .93389 .57373 Mtetra
.951 .805 .662 r
.93389 .57373 .93647 .57729 .94171 .56234 .93917 .5589 Mtetra
.974 .79 .593 r
.93917 .5589 .94171 .56234 .94623 .54185 .94372 .53854 Mtetra
.981 .784 .566 r
.94372 .53854 .94623 .54185 .95036 .5189 .9479 .51569 Mtetra
.932 .563 .28 r
.34427 .62183 .34761 .62502 .35213 .64081 .34878 .63764 Mtetra
.926 .545 .248 r
.34878 .63764 .35213 .64081 .35677 .6553 .35341 .65215 Mtetra
.894 .471 .126 r
.35341 .65215 .35677 .6553 .36164 .66633 .35827 .6632 Mtetra
.819 .349 0 r
.35827 .6632 .36164 .66633 .36667 .67464 .3633 .67152 Mtetra
.698 .193 0 r
.3633 .67152 .36667 .67464 .37184 .68112 .36846 .67801 Mtetra
0 .363 .818 r
.36846 .67801 .37184 .68112 .37718 .68409 .37381 .68099 Mtetra
.148 .513 .914 r
.37381 .68099 .37718 .68409 .38259 .6861 .37922 .68301 Mtetra
.393 .647 .959 r
.37922 .68301 .38259 .6861 .38807 .68684 .38471 .68375 Mtetra
.527 .706 .953 r
.38471 .68375 .38807 .68684 .39361 .68659 .39025 .6835 Mtetra
.561 .719 .947 r
.39025 .6835 .39361 .68659 .39918 .68604 .39582 .68295 Mtetra
.597 .731 .938 r
.39582 .68295 .39918 .68604 .40477 .68512 .40142 .68202 Mtetra
.608 .735 .935 r
.40142 .68202 .40477 .68512 .41038 .68408 .40704 .68097 Mtetra
.613 .737 .934 r
.40704 .68097 .41038 .68408 .41601 .68297 .41267 .67986 Mtetra
.617 .738 .932 r
.41267 .67986 .41601 .68297 .42165 .68181 .41832 .67869 Mtetra
.618 .738 .932 r
.41832 .67869 .42165 .68181 .4273 .68065 .42398 .67752 Mtetra
.42398 .67752 .4273 .68065 .43297 .67947 .42966 .67634 Mtetra
.42966 .67634 .43297 .67947 .43865 .6783 .43534 .67516 Mtetra
.43534 .67516 .43865 .6783 .44434 .67713 .44104 .67398 Mtetra
.44104 .67398 .44434 .67713 .45005 .67595 .44676 .6728 Mtetra
.617 .737 .932 r
.44676 .6728 .45005 .67595 .45577 .67477 .45249 .67161 Mtetra
.45249 .67161 .45577 .67477 .46151 .6736 .45823 .67043 Mtetra
.45823 .67043 .46151 .6736 .46726 .67242 .46399 .66925 Mtetra
.46399 .66925 .46726 .67242 .47302 .67125 .46975 .66807 Mtetra
.616 .737 .932 r
.46975 .66807 .47302 .67125 .47879 .67008 .47554 .66689 Mtetra
.47554 .66689 .47879 .67008 .48458 .6689 .48133 .66571 Mtetra
.48133 .66571 .48458 .6689 .49039 .66773 .48714 .66453 Mtetra
.615 .736 .932 r
.48714 .66453 .49039 .66773 .4962 .66657 .49297 .66336 Mtetra
.49297 .66336 .4962 .66657 .50203 .6654 .49881 .66218 Mtetra
.49881 .66218 .50203 .6654 .50788 .66423 .50466 .661 Mtetra
.614 .736 .932 r
.50466 .661 .50788 .66423 .51374 .66306 .51053 .65983 Mtetra
.51053 .65983 .51374 .66306 .51961 .6619 .51641 .65866 Mtetra
.51641 .65866 .51961 .6619 .5255 .66073 .5223 .65749 Mtetra
.613 .735 .932 r
.5223 .65749 .5255 .66073 .5314 .65958 .52821 .65632 Mtetra
.613 .735 .933 r
.52821 .65632 .5314 .65958 .53732 .65842 .53414 .65516 Mtetra
.612 .735 .933 r
.53414 .65516 .53732 .65842 .54325 .65727 .54008 .654 Mtetra
.54008 .654 .54325 .65727 .5492 .65611 .54603 .65283 Mtetra
.612 .734 .933 r
.54603 .65283 .5492 .65611 .55516 .65496 .552 .65167 Mtetra
.611 .734 .933 r
.552 .65167 .55516 .65496 .56113 .65382 .55798 .65052 Mtetra
.55798 .65052 .56113 .65382 .56712 .65267 .56398 .64937 Mtetra
.56398 .64937 .56712 .65267 .57313 .65153 .56999 .64822 Mtetra
.609 .733 .933 r
.56999 .64822 .57313 .65153 .57915 .6504 .57602 .64708 Mtetra
.61 .733 .933 r
.57602 .64708 .57915 .6504 .58518 .64926 .58206 .64594 Mtetra
.58206 .64594 .58518 .64926 .59123 .64813 .58812 .64479 Mtetra
.608 .732 .933 r
.58812 .64479 .59123 .64813 .5973 .64701 .59419 .64366 Mtetra
.59419 .64366 .5973 .64701 .60338 .64589 .60028 .64253 Mtetra
.60028 .64253 .60338 .64589 .60948 .64476 .60639 .6414 Mtetra
.607 .731 .933 r
.60639 .6414 .60948 .64476 .61559 .64365 .61251 .64028 Mtetra
.606 .731 .933 r
.61251 .64028 .61559 .64365 .62172 .64255 .61864 .63917 Mtetra
.61864 .63917 .62172 .64255 .62786 .64145 .6248 .63806 Mtetra
.605 .73 .933 r
.6248 .63806 .62786 .64145 .63402 .64035 .63096 .63695 Mtetra
.604 .73 .933 r
.63096 .63695 .63402 .64035 .6402 .63926 .63715 .63586 Mtetra
.604 .729 .933 r
.63715 .63586 .6402 .63926 .64639 .63818 .64335 .63476 Mtetra
.603 .729 .933 r
.64335 .63476 .64639 .63818 .6526 .6371 .64956 .63367 Mtetra
.602 .728 .933 r
.64956 .63367 .6526 .6371 .65882 .63603 .6558 .6326 Mtetra
.6558 .6326 .65882 .63603 .66506 .63496 .66205 .63152 Mtetra
.601 .728 .933 r
.66205 .63152 .66506 .63496 .67132 .6339 .66831 .63045 Mtetra
.6 .727 .934 r
.66831 .63045 .67132 .6339 .67759 .63286 .6746 .6294 Mtetra
.599 .726 .934 r
.6746 .6294 .67759 .63286 .68389 .63182 .6809 .62835 Mtetra
.6809 .62835 .68389 .63182 .69019 .63078 .68721 .6273 Mtetra
.597 .725 .934 r
.68721 .6273 .69019 .63078 .69652 .62976 .69355 .62627 Mtetra
.69355 .62627 .69652 .62976 .70286 .62875 .6999 .62525 Mtetra
.596 .724 .934 r
.6999 .62525 .70286 .62875 .70922 .62774 .70627 .62423 Mtetra
.595 .724 .934 r
.70627 .62423 .70922 .62774 .7156 .62675 .71265 .62323 Mtetra
.594 .723 .934 r
.71265 .62323 .7156 .62675 .722 .62576 .71906 .62223 Mtetra
.593 .723 .934 r
.71906 .62223 .722 .62576 .72841 .62479 .72548 .62125 Mtetra
.592 .722 .934 r
.72548 .62125 .72841 .62479 .73485 .62383 .73192 .62028 Mtetra
.591 .721 .934 r
.73192 .62028 .73485 .62383 .7413 .62287 .73838 .61931 Mtetra
.59 .72 .934 r
.73838 .61931 .7413 .62287 .74777 .62194 .74486 .61837 Mtetra
.589 .72 .934 r
.74486 .61837 .74777 .62194 .75426 .62101 .75136 .61743 Mtetra
.588 .719 .934 r
.75136 .61743 .75426 .62101 .76076 .6201 .75788 .6165 Mtetra
.586 .718 .934 r
.75788 .6165 .76076 .6201 .76729 .61921 .76441 .6156 Mtetra
.76441 .6156 .76729 .61921 .77384 .61832 .77097 .6147 Mtetra
.584 .717 .934 r
.77097 .6147 .77384 .61832 .7804 .61745 .77754 .61382 Mtetra
.583 .716 .934 r
.77754 .61382 .7804 .61745 .78699 .6166 .78414 .61296 Mtetra
.582 .715 .934 r
.78414 .61296 .78699 .6166 .79359 .61577 .79075 .61211 Mtetra
.58 .714 .934 r
.79075 .61211 .79359 .61577 .80022 .61495 .79738 .61128 Mtetra
.579 .713 .934 r
.79738 .61128 .80022 .61495 .80686 .61415 .80404 .61047 Mtetra
.577 .712 .934 r
.80404 .61047 .80686 .61415 .81353 .61337 .81072 .60968 Mtetra
.575 .711 .934 r
.81072 .60968 .81353 .61337 .82022 .61261 .81741 .60891 Mtetra
.574 .71 .934 r
.81741 .60891 .82022 .61261 .82693 .61187 .82413 .60815 Mtetra
.572 .708 .934 r
.82413 .60815 .82693 .61187 .83366 .61116 .83087 .60742 Mtetra
.57 .707 .934 r
.83087 .60742 .83366 .61116 .84042 .61047 .83764 .60672 Mtetra
.569 .706 .934 r
.83764 .60672 .84042 .61047 .84719 .60979 .84442 .60603 Mtetra
.567 .704 .934 r
.84442 .60603 .84719 .60979 .85399 .60915 .85123 .60538 Mtetra
.565 .703 .934 r
.85123 .60538 .85399 .60915 .86082 .60853 .85806 .60474 Mtetra
.564 .702 .934 r
.85806 .60474 .86082 .60853 .86766 .60792 .86491 .60411 Mtetra
.86491 .60411 .86766 .60792 .87453 .60731 .87179 .6035 Mtetra
.566 .702 .933 r
.87179 .6035 .87453 .60731 .88141 .60668 .87868 .60285 Mtetra
.571 .704 .932 r
.87868 .60285 .88141 .60668 .88831 .60598 .88559 .60213 Mtetra
.592 .714 .928 r
.88559 .60213 .88831 .60598 .89519 .60498 .89249 .60113 Mtetra
.61 .722 .925 r
.89249 .60113 .89519 .60498 .90207 .60371 .89937 .59986 Mtetra
.665 .746 .911 r
.89937 .59986 .90207 .60371 .90886 .60155 .90618 .59771 Mtetra
.732 .773 .885 r
.90618 .59771 .90886 .60155 .91552 .59803 .91285 .59423 Mtetra
.774 .788 .865 r
.91285 .59423 .91552 .59803 .92207 .5935 .91942 .58974 Mtetra
.881 .81 .774 r
.91942 .58974 .92207 .5935 .92813 .58485 .92551 .58118 Mtetra
.918 .812 .726 r
.92551 .58118 .92813 .58485 .93389 .57373 .9313 .57015 Mtetra
.95 .805 .664 r
.9313 .57015 .93389 .57373 .93917 .5589 .93661 .55544 Mtetra
.974 .79 .594 r
.93661 .55544 .93917 .5589 .94372 .53854 .9412 .53519 Mtetra
.981 .784 .567 r
.9412 .53519 .94372 .53854 .9479 .51569 .94542 .51246 Mtetra
.932 .563 .281 r
.34092 .61864 .34427 .62183 .34878 .63764 .34541 .63446 Mtetra
.926 .545 .249 r
.34541 .63446 .34878 .63764 .35341 .65215 .35004 .64899 Mtetra
.894 .471 .127 r
.35004 .64899 .35341 .65215 .35827 .6632 .35489 .66006 Mtetra
.82 .35 0 r
.35489 .66006 .35827 .6632 .3633 .67152 .35992 .66839 Mtetra
.7 .195 0 r
.35992 .66839 .3633 .67152 .36846 .67801 .36508 .6749 Mtetra
0 .361 .817 r
.36508 .6749 .36846 .67801 .37381 .68099 .37042 .67789 Mtetra
.145 .511 .913 r
.37042 .67789 .37381 .68099 .37922 .68301 .37584 .67991 Mtetra
.391 .647 .959 r
.37584 .67991 .37922 .68301 .38471 .68375 .38133 .68065 Mtetra
.527 .706 .953 r
.38133 .68065 .38471 .68375 .39025 .6835 .38688 .6804 Mtetra
.561 .719 .947 r
.38688 .6804 .39025 .6835 .39582 .68295 .39246 .67985 Mtetra
.597 .732 .939 r
.39246 .67985 .39582 .68295 .40142 .68202 .39806 .67892 Mtetra
.608 .735 .936 r
.39806 .67892 .40142 .68202 .40704 .68097 .40369 .67786 Mtetra
.613 .737 .934 r
.40369 .67786 .40704 .68097 .41267 .67986 .40933 .67674 Mtetra
.617 .738 .933 r
.40933 .67674 .41267 .67986 .41832 .67869 .41498 .67557 Mtetra
.618 .738 .932 r
.41498 .67557 .41832 .67869 .42398 .67752 .42065 .67439 Mtetra
.42065 .67439 .42398 .67752 .42966 .67634 .42633 .67321 Mtetra
.42633 .67321 .42966 .67634 .43534 .67516 .43202 .67202 Mtetra
.43202 .67202 .43534 .67516 .44104 .67398 .43773 .67083 Mtetra
.43773 .67083 .44104 .67398 .44676 .6728 .44345 .66964 Mtetra
.617 .738 .932 r
.44345 .66964 .44676 .6728 .45249 .67161 .44919 .66845 Mtetra
.44919 .66845 .45249 .67161 .45823 .67043 .45494 .66726 Mtetra
.45494 .66726 .45823 .67043 .46399 .66925 .4607 .66607 Mtetra
.4607 .66607 .46399 .66925 .46975 .66807 .46648 .66488 Mtetra
.616 .737 .933 r
.46648 .66488 .46975 .66807 .47554 .66689 .47227 .6637 Mtetra
.616 .737 .932 r
.47227 .6637 .47554 .66689 .48133 .66571 .47807 .66251 Mtetra
.616 .737 .933 r
.47807 .66251 .48133 .66571 .48714 .66453 .48389 .66132 Mtetra
.615 .737 .933 r
.48389 .66132 .48714 .66453 .49297 .66336 .48972 .66014 Mtetra
.48972 .66014 .49297 .66336 .49881 .66218 .49557 .65896 Mtetra
.49557 .65896 .49881 .66218 .50466 .661 .50143 .65777 Mtetra
.614 .736 .933 r
.50143 .65777 .50466 .661 .51053 .65983 .5073 .6566 Mtetra
.5073 .6566 .51053 .65983 .51641 .65866 .51319 .65542 Mtetra
.51319 .65542 .51641 .65866 .5223 .65749 .51909 .65423 Mtetra
.613 .736 .933 r
.51909 .65423 .5223 .65749 .52821 .65632 .52501 .65306 Mtetra
.613 .735 .933 r
.52501 .65306 .52821 .65632 .53414 .65516 .53094 .65189 Mtetra
.612 .735 .933 r
.53094 .65189 .53414 .65516 .54008 .654 .53689 .65072 Mtetra
.53689 .65072 .54008 .654 .54603 .65283 .54285 .64955 Mtetra
.54285 .64955 .54603 .65283 .552 .65167 .54883 .64838 Mtetra
.611 .734 .933 r
.54883 .64838 .552 .65167 .55798 .65052 .55482 .64723 Mtetra
.55482 .64723 .55798 .65052 .56398 .64937 .56082 .64607 Mtetra
.56082 .64607 .56398 .64937 .56999 .64822 .56684 .6449 Mtetra
.609 .734 .933 r
.56684 .6449 .56999 .64822 .57602 .64708 .57288 .64376 Mtetra
.61 .733 .933 r
.57288 .64376 .57602 .64708 .58206 .64594 .57893 .64261 Mtetra
.57893 .64261 .58206 .64594 .58812 .64479 .58499 .64145 Mtetra
.608 .733 .934 r
.58499 .64145 .58812 .64479 .59419 .64366 .59108 .64032 Mtetra
.59108 .64032 .59419 .64366 .60028 .64253 .59717 .63918 Mtetra
.608 .732 .933 r
.59717 .63918 .60028 .64253 .60639 .6414 .60329 .63804 Mtetra
.607 .732 .934 r
.60329 .63804 .60639 .6414 .61251 .64028 .60941 .63691 Mtetra
.606 .732 .934 r
.60941 .63691 .61251 .64028 .61864 .63917 .61556 .63579 Mtetra
.606 .731 .934 r
.61556 .63579 .61864 .63917 .6248 .63806 .62172 .63467 Mtetra
.605 .731 .934 r
.62172 .63467 .6248 .63806 .63096 .63695 .62789 .63355 Mtetra
.604 .73 .934 r
.62789 .63355 .63096 .63695 .63715 .63586 .63409 .63245 Mtetra
.63409 .63245 .63715 .63586 .64335 .63476 .6403 .63135 Mtetra
.603 .73 .934 r
.6403 .63135 .64335 .63476 .64956 .63367 .64652 .63025 Mtetra
.602 .729 .934 r
.64652 .63025 .64956 .63367 .6558 .6326 .65276 .62916 Mtetra
.65276 .62916 .6558 .6326 .66205 .63152 .65902 .62808 Mtetra
.601 .729 .934 r
.65902 .62808 .66205 .63152 .66831 .63045 .66529 .627 Mtetra
.6 .728 .934 r
.66529 .627 .66831 .63045 .6746 .6294 .67159 .62594 Mtetra
.599 .727 .934 r
.67159 .62594 .6746 .6294 .6809 .62835 .67789 .62488 Mtetra
.67789 .62488 .6809 .62835 .68721 .6273 .68422 .62382 Mtetra
.597 .726 .934 r
.68422 .62382 .68721 .6273 .69355 .62627 .69056 .62278 Mtetra
.69056 .62278 .69355 .62627 .6999 .62525 .69692 .62175 Mtetra
.596 .725 .934 r
.69692 .62175 .6999 .62525 .70627 .62423 .7033 .62072 Mtetra
.595 .724 .934 r
.7033 .62072 .70627 .62423 .71265 .62323 .7097 .61971 Mtetra
.594 .724 .934 r
.7097 .61971 .71265 .62323 .71906 .62223 .71611 .6187 Mtetra
.593 .723 .934 r
.71611 .6187 .71906 .62223 .72548 .62125 .72254 .61771 Mtetra
.592 .723 .935 r
.72254 .61771 .72548 .62125 .73192 .62028 .72899 .61672 Mtetra
.592 .722 .935 r
.72899 .61672 .73192 .62028 .73838 .61931 .73546 .61575 Mtetra
.59 .721 .935 r
.73546 .61575 .73838 .61931 .74486 .61837 .74195 .61479 Mtetra
.589 .721 .935 r
.74195 .61479 .74486 .61837 .75136 .61743 .74845 .61385 Mtetra
.588 .72 .935 r
.74845 .61385 .75136 .61743 .75788 .6165 .75498 .61291 Mtetra
.586 .719 .935 r
.75498 .61291 .75788 .6165 .76441 .6156 .76152 .61199 Mtetra
.586 .718 .935 r
.76152 .61199 .76441 .6156 .77097 .6147 .76809 .61108 Mtetra
.585 .717 .935 r
.76809 .61108 .77097 .6147 .77754 .61382 .77467 .61019 Mtetra
.583 .716 .935 r
.77467 .61019 .77754 .61382 .78414 .61296 .78127 .60932 Mtetra
.582 .716 .935 r
.78127 .60932 .78414 .61296 .79075 .61211 .7879 .60846 Mtetra
.58 .715 .935 r
.7879 .60846 .79075 .61211 .79738 .61128 .79454 .60761 Mtetra
.579 .714 .935 r
.79454 .60761 .79738 .61128 .80404 .61047 .8012 .60679 Mtetra
.577 .713 .935 r
.8012 .60679 .80404 .61047 .81072 .60968 .80789 .60599 Mtetra
.575 .712 .935 r
.80789 .60599 .81072 .60968 .81741 .60891 .8146 .60521 Mtetra
.574 .711 .935 r
.8146 .60521 .81741 .60891 .82413 .60815 .82132 .60444 Mtetra
.572 .709 .935 r
.82132 .60444 .82413 .60815 .83087 .60742 .82807 .60369 Mtetra
.57 .708 .935 r
.82807 .60369 .83087 .60742 .83764 .60672 .83485 .60298 Mtetra
.569 .707 .935 r
.83485 .60298 .83764 .60672 .84442 .60603 .84164 .60227 Mtetra
.567 .706 .935 r
.84164 .60227 .84442 .60603 .85123 .60538 .84846 .60161 Mtetra
.565 .705 .935 r
.84846 .60161 .85123 .60538 .85806 .60474 .8553 .60095 Mtetra
.564 .704 .935 r
.8553 .60095 .85806 .60474 .86491 .60411 .86216 .60032 Mtetra
.564 .703 .934 r
.86216 .60032 .86491 .60411 .87179 .6035 .86904 .59968 Mtetra
.566 .704 .934 r
.86904 .59968 .87179 .6035 .87868 .60285 .87595 .59902 Mtetra
.571 .705 .933 r
.87595 .59902 .87868 .60285 .88559 .60213 .88286 .5983 Mtetra
.591 .715 .929 r
.88286 .5983 .88559 .60213 .89249 .60113 .88977 .59729 Mtetra
.609 .723 .926 r
.88977 .59729 .89249 .60113 .89937 .59986 .89667 .59602 Mtetra
.663 .747 .912 r
.89667 .59602 .89937 .59986 .90618 .59771 .90349 .59388 Mtetra
.731 .773 .887 r
.90349 .59388 .90618 .59771 .91285 .59423 .91018 .59043 Mtetra
.772 .789 .866 r
.91018 .59043 .91285 .59423 .91942 .58974 .91676 .58598 Mtetra
.88 .81 .776 r
.91676 .58598 .91942 .58974 .92551 .58118 .92288 .57749 Mtetra
.917 .812 .728 r
.92288 .57749 .92551 .58118 .9313 .57015 .9287 .56656 Mtetra
.95 .806 .666 r
.9287 .56656 .9313 .57015 .93661 .55544 .93404 .55196 Mtetra
.973 .79 .596 r
.93404 .55196 .93661 .55544 .9412 .53519 .93867 .53182 Mtetra
.98 .784 .568 r
.93867 .53182 .9412 .53519 .94542 .51246 .94293 .50919 Mtetra
.932 .563 .281 r
.33756 .61545 .34092 .61864 .34541 .63446 .34204 .63128 Mtetra
.926 .545 .249 r
.34204 .63128 .34541 .63446 .35004 .64899 .34665 .64582 Mtetra
.894 .472 .128 r
.34665 .64582 .35004 .64899 .35489 .66006 .35149 .65691 Mtetra
.821 .351 0 r
.35149 .65691 .35489 .66006 .35992 .66839 .35652 .66526 Mtetra
.702 .197 0 r
.35652 .66526 .35992 .66839 .36508 .6749 .36168 .67179 Mtetra
0 .358 .815 r
.36168 .67179 .36508 .6749 .37042 .67789 .36703 .67478 Mtetra
.142 .51 .912 r
.36703 .67478 .37042 .67789 .37584 .67991 .37245 .67681 Mtetra
.39 .647 .959 r
.37245 .67681 .37584 .67991 .38133 .68065 .37794 .67755 Mtetra
.526 .707 .953 r
.37794 .67755 .38133 .68065 .38688 .6804 .3835 .6773 Mtetra
.56 .72 .947 r
.3835 .6773 .38688 .6804 .39246 .67985 .38908 .67674 Mtetra
.597 .732 .939 r
.38908 .67674 .39246 .67985 .39806 .67892 .39469 .6758 Mtetra
.608 .736 .936 r
.39469 .6758 .39806 .67892 .40369 .67786 .40032 .67474 Mtetra
.613 .737 .934 r
.40032 .67474 .40369 .67786 .40933 .67674 .40597 .67362 Mtetra
.617 .739 .933 r
.40597 .67362 .40933 .67674 .41498 .67557 .41163 .67244 Mtetra
.41163 .67244 .41498 .67557 .42065 .67439 .4173 .67126 Mtetra
.618 .739 .932 r
.4173 .67126 .42065 .67439 .42633 .67321 .42299 .67006 Mtetra
.618 .739 .933 r
.42299 .67006 .42633 .67321 .43202 .67202 .42869 .66887 Mtetra
.42869 .66887 .43202 .67202 .43773 .67083 .43441 .66767 Mtetra
.618 .739 .932 r
.43441 .66767 .43773 .67083 .44345 .66964 .44014 .66647 Mtetra
.617 .738 .933 r
.44014 .66647 .44345 .66964 .44919 .66845 .44588 .66528 Mtetra
.44588 .66528 .44919 .66845 .45494 .66726 .45164 .66408 Mtetra
.45164 .66408 .45494 .66726 .4607 .66607 .4574 .66289 Mtetra
.4574 .66289 .4607 .66607 .46648 .66488 .46319 .66169 Mtetra
.616 .738 .933 r
.46319 .66169 .46648 .66488 .47227 .6637 .46899 .6605 Mtetra
.46899 .6605 .47227 .6637 .47807 .66251 .4748 .6593 Mtetra
.616 .737 .933 r
.4748 .6593 .47807 .66251 .48389 .66132 .48062 .65811 Mtetra
.615 .737 .933 r
.48062 .65811 .48389 .66132 .48972 .66014 .48646 .65692 Mtetra
.48646 .65692 .48972 .66014 .49557 .65896 .49231 .65573 Mtetra
.49231 .65573 .49557 .65896 .50143 .65777 .49818 .65454 Mtetra
.614 .737 .933 r
.49818 .65454 .50143 .65777 .5073 .6566 .50406 .65335 Mtetra
.50406 .65335 .5073 .6566 .51319 .65542 .50996 .65217 Mtetra
.614 .736 .933 r
.50996 .65217 .51319 .65542 .51909 .65423 .51587 .65098 Mtetra
.613 .736 .933 r
.51587 .65098 .51909 .65423 .52501 .65306 .5218 .6498 Mtetra
.5218 .6498 .52501 .65306 .53094 .65189 .52773 .64862 Mtetra
.612 .736 .933 r
.52773 .64862 .53094 .65189 .53689 .65072 .53369 .64744 Mtetra
.53369 .64744 .53689 .65072 .54285 .64955 .53966 .64626 Mtetra
.612 .735 .933 r
.53966 .64626 .54285 .64955 .54883 .64838 .54564 .64509 Mtetra
.611 .735 .933 r
.54564 .64509 .54883 .64838 .55482 .64723 .55164 .64392 Mtetra
.55164 .64392 .55482 .64723 .56082 .64607 .55765 .64275 Mtetra
.55765 .64275 .56082 .64607 .56684 .6449 .56368 .64158 Mtetra
.609 .734 .934 r
.56368 .64158 .56684 .6449 .57288 .64376 .56972 .64043 Mtetra
.61 .734 .934 r
.56972 .64043 .57288 .64376 .57893 .64261 .57578 .63927 Mtetra
.61 .734 .933 r
.57578 .63927 .57893 .64261 .58499 .64145 .58186 .63811 Mtetra
.608 .733 .934 r
.58186 .63811 .58499 .64145 .59108 .64032 .58795 .63696 Mtetra
.58795 .63696 .59108 .64032 .59717 .63918 .59405 .63582 Mtetra
.59405 .63582 .59717 .63918 .60329 .63804 .60017 .63467 Mtetra
.607 .732 .934 r
.60017 .63467 .60329 .63804 .60941 .63691 .60631 .63353 Mtetra
.606 .732 .934 r
.60631 .63353 .60941 .63691 .61556 .63579 .61246 .6324 Mtetra
.61246 .6324 .61556 .63579 .62172 .63467 .61863 .63127 Mtetra
.605 .731 .934 r
.61863 .63127 .62172 .63467 .62789 .63355 .62481 .63015 Mtetra
.604 .731 .934 r
.62481 .63015 .62789 .63355 .63409 .63245 .63101 .62904 Mtetra
.63101 .62904 .63409 .63245 .6403 .63135 .63723 .62792 Mtetra
.603 .73 .934 r
.63723 .62792 .6403 .63135 .64652 .63025 .64346 .62681 Mtetra
.602 .729 .934 r
.64346 .62681 .64652 .63025 .65276 .62916 .64971 .62572 Mtetra
.64971 .62572 .65276 .62916 .65902 .62808 .65598 .62463 Mtetra
.65598 .62463 .65902 .62808 .66529 .627 .66226 .62354 Mtetra
.6 .728 .934 r
.66226 .62354 .66529 .627 .67159 .62594 .66856 .62247 Mtetra
.66856 .62247 .67159 .62594 .67789 .62488 .67488 .6214 Mtetra
.599 .727 .934 r
.67488 .6214 .67789 .62488 .68422 .62382 .68121 .62033 Mtetra
.598 .727 .935 r
.68121 .62033 .68422 .62382 .69056 .62278 .68757 .61928 Mtetra
.597 .726 .935 r
.68757 .61928 .69056 .62278 .69692 .62175 .69393 .61824 Mtetra
.69393 .61824 .69692 .62175 .7033 .62072 .70032 .6172 Mtetra
.595 .725 .935 r
.70032 .6172 .7033 .62072 .7097 .61971 .70673 .61618 Mtetra
.594 .725 .935 r
.70673 .61618 .7097 .61971 .71611 .6187 .71315 .61516 Mtetra
.593 .724 .935 r
.71315 .61516 .71611 .6187 .72254 .61771 .71959 .61416 Mtetra
.592 .723 .935 r
.71959 .61416 .72254 .61771 .72899 .61672 .72605 .61316 Mtetra
.72605 .61316 .72899 .61672 .73546 .61575 .73252 .61218 Mtetra
.59 .722 .935 r
.73252 .61218 .73546 .61575 .74195 .61479 .73902 .61121 Mtetra
.589 .721 .935 r
.73902 .61121 .74195 .61479 .74845 .61385 .74554 .61026 Mtetra
.588 .721 .935 r
.74554 .61026 .74845 .61385 .75498 .61291 .75207 .60931 Mtetra
.586 .72 .935 r
.75207 .60931 .75498 .61291 .76152 .61199 .75862 .60838 Mtetra
.586 .719 .935 r
.75862 .60838 .76152 .61199 .76809 .61108 .7652 .60746 Mtetra
.585 .718 .935 r
.7652 .60746 .76809 .61108 .77467 .61019 .77179 .60656 Mtetra
.583 .717 .935 r
.77179 .60656 .77467 .61019 .78127 .60932 .7784 .60567 Mtetra
.582 .717 .935 r
.7784 .60567 .78127 .60932 .7879 .60846 .78503 .6048 Mtetra
.58 .716 .935 r
.78503 .6048 .7879 .60846 .79454 .60761 .79168 .60395 Mtetra
.579 .715 .936 r
.79168 .60395 .79454 .60761 .8012 .60679 .79836 .60311 Mtetra
.577 .714 .936 r
.79836 .60311 .8012 .60679 .80789 .60599 .80505 .60229 Mtetra
.576 .712 .936 r
.80505 .60229 .80789 .60599 .8146 .60521 .81177 .6015 Mtetra
.574 .712 .936 r
.81177 .6015 .8146 .60521 .82132 .60444 .81851 .60072 Mtetra
.572 .71 .936 r
.81851 .60072 .82132 .60444 .82807 .60369 .82526 .59996 Mtetra
.57 .709 .936 r
.82526 .59996 .82807 .60369 .83485 .60298 .83205 .59923 Mtetra
.569 .708 .936 r
.83205 .59923 .83485 .60298 .84164 .60227 .83885 .59852 Mtetra
.567 .707 .936 r
.83885 .59852 .84164 .60227 .84846 .60161 .84568 .59783 Mtetra
.566 .706 .936 r
.84568 .59783 .84846 .60161 .8553 .60095 .85252 .59717 Mtetra
.564 .705 .935 r
.85252 .59717 .8553 .60095 .86216 .60032 .8594 .59651 Mtetra
.564 .704 .935 r
.8594 .59651 .86216 .60032 .86904 .59968 .86629 .59587 Mtetra
.566 .705 .934 r
.86629 .59587 .86904 .59968 .87595 .59902 .8732 .59519 Mtetra
.571 .706 .934 r
.8732 .59519 .87595 .59902 .88286 .5983 .88013 .59446 Mtetra
.591 .715 .93 r
.88013 .59446 .88286 .5983 .88977 .59729 .88704 .59344 Mtetra
.608 .724 .927 r
.88704 .59344 .88977 .59729 .89667 .59602 .89395 .59217 Mtetra
.662 .747 .913 r
.89395 .59217 .89667 .59602 .90349 .59388 .90079 .59004 Mtetra
.729 .773 .888 r
.90079 .59004 .90349 .59388 .91018 .59043 .90749 .58662 Mtetra
.771 .789 .868 r
.90749 .58662 .91018 .59043 .91676 .58598 .9141 .58221 Mtetra
.878 .81 .778 r
.9141 .58221 .91676 .58598 .92288 .57749 .92024 .57379 Mtetra
.916 .812 .73 r
.92024 .57379 .92288 .57749 .9287 .56656 .92608 .56295 Mtetra
.949 .806 .668 r
.92608 .56295 .9287 .56656 .93404 .55196 .93146 .54845 Mtetra
.973 .79 .597 r
.93146 .54845 .93404 .55196 .93867 .53182 .93613 .52841 Mtetra
.98 .784 .57 r
.93613 .52841 .93867 .53182 .94293 .50919 .94042 .50588 Mtetra
.932 .563 .281 r
.33419 .61225 .33756 .61545 .34204 .63128 .33865 .6281 Mtetra
.926 .545 .25 r
.33865 .6281 .34204 .63128 .34665 .64582 .34325 .64265 Mtetra
.895 .472 .129 r
.34325 .64265 .34665 .64582 .35149 .65691 .34809 .65376 Mtetra
.822 .352 0 r
.34809 .65376 .35149 .65691 .35652 .66526 .35311 .66213 Mtetra
.703 .199 0 r
.35311 .66213 .35652 .66526 .36168 .67179 .35826 .66867 Mtetra
0 .356 .813 r
.35826 .66867 .36168 .67179 .36703 .67478 .36362 .67167 Mtetra
.14 .509 .912 r
.36362 .67167 .36703 .67478 .37245 .67681 .36904 .6737 Mtetra
.389 .647 .959 r
.36904 .6737 .37245 .67681 .37794 .67755 .37454 .67444 Mtetra
.526 .707 .954 r
.37454 .67444 .37794 .67755 .3835 .6773 .3801 .67419 Mtetra
.56 .72 .948 r
.3801 .67419 .3835 .6773 .38908 .67674 .38569 .67363 Mtetra
.597 .732 .939 r
.38569 .67363 .38908 .67674 .39469 .6758 .3913 .67268 Mtetra
.607 .736 .936 r
.3913 .67268 .39469 .6758 .40032 .67474 .39694 .67162 Mtetra
.613 .738 .934 r
.39694 .67162 .40032 .67474 .40597 .67362 .40259 .67049 Mtetra
.617 .739 .933 r
.40259 .67049 .40597 .67362 .41163 .67244 .40826 .6693 Mtetra
.40826 .6693 .41163 .67244 .4173 .67126 .41394 .66811 Mtetra
.618 .739 .933 r
.41394 .66811 .4173 .67126 .42299 .67006 .41964 .66691 Mtetra
.41964 .66691 .42299 .67006 .42869 .66887 .42535 .66571 Mtetra
.42535 .66571 .42869 .66887 .43441 .66767 .43107 .66451 Mtetra
.43107 .66451 .43441 .66767 .44014 .66647 .43681 .6633 Mtetra
.617 .739 .933 r
.43681 .6633 .44014 .66647 .44588 .66528 .44256 .6621 Mtetra
.617 .738 .933 r
.44256 .6621 .44588 .66528 .45164 .66408 .44832 .6609 Mtetra
.44832 .6609 .45164 .66408 .4574 .66289 .4541 .65969 Mtetra
.4541 .65969 .4574 .66289 .46319 .66169 .45989 .65849 Mtetra
.616 .738 .933 r
.45989 .65849 .46319 .66169 .46899 .6605 .46569 .65729 Mtetra
.46569 .65729 .46899 .6605 .4748 .6593 .47151 .65609 Mtetra
.47151 .65609 .4748 .6593 .48062 .65811 .47734 .65489 Mtetra
.615 .737 .933 r
.47734 .65489 .48062 .65811 .48646 .65692 .48319 .65369 Mtetra
.48319 .65369 .48646 .65692 .49231 .65573 .48905 .65249 Mtetra
.48905 .65249 .49231 .65573 .49818 .65454 .49492 .65129 Mtetra
.614 .737 .933 r
.49492 .65129 .49818 .65454 .50406 .65335 .50081 .6501 Mtetra
.50081 .6501 .50406 .65335 .50996 .65217 .50672 .64891 Mtetra
.50672 .64891 .50996 .65217 .51587 .65098 .51264 .64771 Mtetra
.613 .736 .933 r
.51264 .64771 .51587 .65098 .5218 .6498 .51857 .64652 Mtetra
.51857 .64652 .5218 .6498 .52773 .64862 .52451 .64533 Mtetra
.612 .736 .933 r
.52451 .64533 .52773 .64862 .53369 .64744 .53048 .64415 Mtetra
.613 .736 .933 r
.53048 .64415 .53369 .64744 .53966 .64626 .53645 .64297 Mtetra
.612 .736 .933 r
.53645 .64297 .53966 .64626 .54564 .64509 .54244 .64178 Mtetra
.611 .735 .934 r
.54244 .64178 .54564 .64509 .55164 .64392 .54845 .64061 Mtetra
.54845 .64061 .55164 .64392 .55765 .64275 .55447 .63943 Mtetra
.611 .735 .933 r
.55447 .63943 .55765 .64275 .56368 .64158 .56051 .63825 Mtetra
.61 .734 .934 r
.56051 .63825 .56368 .64158 .56972 .64043 .56656 .63709 Mtetra
.56656 .63709 .56972 .64043 .57578 .63927 .57263 .63592 Mtetra
.57263 .63592 .57578 .63927 .58186 .63811 .57871 .63475 Mtetra
.608 .733 .934 r
.57871 .63475 .58186 .63811 .58795 .63696 .58481 .6336 Mtetra
.58481 .6336 .58795 .63696 .59405 .63582 .59092 .63245 Mtetra
.59092 .63245 .59405 .63582 .60017 .63467 .59705 .63129 Mtetra
.607 .732 .934 r
.59705 .63129 .60017 .63467 .60631 .63353 .60319 .63015 Mtetra
.606 .732 .934 r
.60319 .63015 .60631 .63353 .61246 .6324 .60935 .62901 Mtetra
.60935 .62901 .61246 .6324 .61863 .63127 .61553 .62787 Mtetra
.605 .732 .934 r
.61553 .62787 .61863 .63127 .62481 .63015 .62172 .62673 Mtetra
.604 .731 .934 r
.62172 .62673 .62481 .63015 .63101 .62904 .62793 .62561 Mtetra
.62793 .62561 .63101 .62904 .63723 .62792 .63416 .62449 Mtetra
.604 .73 .934 r
.63416 .62449 .63723 .62792 .64346 .62681 .6404 .62337 Mtetra
.602 .73 .934 r
.6404 .62337 .64346 .62681 .64971 .62572 .64665 .62227 Mtetra
.64665 .62227 .64971 .62572 .65598 .62463 .65293 .62117 Mtetra
.602 .729 .934 r
.65293 .62117 .65598 .62463 .66226 .62354 .65922 .62007 Mtetra
.6 .728 .935 r
.65922 .62007 .66226 .62354 .66856 .62247 .66553 .61899 Mtetra
.66553 .61899 .66856 .62247 .67488 .6214 .67186 .61791 Mtetra
.599 .728 .935 r
.67186 .61791 .67488 .6214 .68121 .62033 .6782 .61683 Mtetra
.598 .727 .935 r
.6782 .61683 .68121 .62033 .68757 .61928 .68456 .61578 Mtetra
.597 .727 .935 r
.68456 .61578 .68757 .61928 .69393 .61824 .69094 .61472 Mtetra
.597 .726 .935 r
.69094 .61472 .69393 .61824 .70032 .6172 .69733 .61367 Mtetra
.595 .725 .935 r
.69733 .61367 .70032 .6172 .70673 .61618 .70374 .61264 Mtetra
.594 .725 .935 r
.70374 .61264 .70673 .61618 .71315 .61516 .71017 .61162 Mtetra
.593 .724 .935 r
.71017 .61162 .71315 .61516 .71959 .61416 .71662 .6106 Mtetra
.592 .724 .935 r
.71662 .6106 .71959 .61416 .72605 .61316 .72309 .6096 Mtetra
.592 .723 .935 r
.72309 .6096 .72605 .61316 .73252 .61218 .72958 .6086 Mtetra
.59 .722 .935 r
.72958 .6086 .73252 .61218 .73902 .61121 .73608 .60763 Mtetra
.589 .722 .935 r
.73608 .60763 .73902 .61121 .74554 .61026 .74261 .60666 Mtetra
.589 .721 .935 r
.74261 .60666 .74554 .61026 .75207 .60931 .74915 .6057 Mtetra
.587 .72 .936 r
.74915 .6057 .75207 .60931 .75862 .60838 .75571 .60476 Mtetra
.586 .72 .936 r
.75571 .60476 .75862 .60838 .7652 .60746 .76229 .60383 Mtetra
.585 .719 .936 r
.76229 .60383 .7652 .60746 .77179 .60656 .76889 .60292 Mtetra
.583 .718 .936 r
.76889 .60292 .77179 .60656 .7784 .60567 .77552 .60202 Mtetra
.582 .717 .936 r
.77552 .60202 .7784 .60567 .78503 .6048 .78216 .60114 Mtetra
.581 .716 .936 r
.78216 .60114 .78503 .6048 .79168 .60395 .78882 .60027 Mtetra
.579 .715 .936 r
.78882 .60027 .79168 .60395 .79836 .60311 .7955 .59942 Mtetra
.577 .714 .936 r
.7955 .59942 .79836 .60311 .80505 .60229 .8022 .5986 Mtetra
.576 .713 .936 r
.8022 .5986 .80505 .60229 .81177 .6015 .80893 .59779 Mtetra
.575 .712 .936 r
.80893 .59779 .81177 .6015 .81851 .60072 .81568 .59699 Mtetra
.573 .711 .936 r
.81568 .59699 .81851 .60072 .82526 .59996 .82244 .59623 Mtetra
.571 .71 .936 r
.82244 .59623 .82526 .59996 .83205 .59923 .82923 .59548 Mtetra
.57 .709 .936 r
.82923 .59548 .83205 .59923 .83885 .59852 .83605 .59475 Mtetra
.567 .707 .936 r
.83605 .59475 .83885 .59852 .84568 .59783 .84288 .59406 Mtetra
.566 .706 .936 r
.84288 .59406 .84568 .59783 .85252 .59717 .84974 .59337 Mtetra
.565 .705 .936 r
.84974 .59337 .85252 .59717 .8594 .59651 .85662 .59271 Mtetra
.564 .705 .935 r
.85662 .59271 .8594 .59651 .86629 .59587 .86352 .59205 Mtetra
.567 .705 .935 r
.86352 .59205 .86629 .59587 .8732 .59519 .87044 .59136 Mtetra
.571 .707 .934 r
.87044 .59136 .8732 .59519 .88013 .59446 .87738 .59061 Mtetra
.591 .716 .931 r
.87738 .59061 .88013 .59446 .88704 .59344 .88431 .58959 Mtetra
.608 .724 .927 r
.88431 .58959 .88704 .59344 .89395 .59217 .89123 .58832 Mtetra
.661 .747 .914 r
.89123 .58832 .89395 .59217 .90079 .59004 .89808 .5862 Mtetra
.728 .773 .889 r
.89808 .5862 .90079 .59004 .90749 .58662 .9048 .5828 Mtetra
.769 .788 .869 r
.9048 .5828 .90749 .58662 .9141 .58221 .91142 .57842 Mtetra
.877 .811 .78 r
.91142 .57842 .9141 .58221 .92024 .57379 .91758 .57008 Mtetra
.915 .813 .732 r
.91758 .57008 .92024 .57379 .92608 .56295 .92346 .55931 Mtetra
.948 .806 .67 r
.92346 .55931 .92608 .56295 .93146 .54845 .92887 .54491 Mtetra
.972 .791 .599 r
.92887 .54491 .93146 .54845 .93613 .52841 .93357 .52499 Mtetra
.98 .785 .571 r
.93357 .52499 .93613 .52841 .94042 .50588 .93791 .50255 Mtetra
.932 .563 .282 r
.3308 .60905 .33419 .61225 .33865 .6281 .33525 .62491 Mtetra
.926 .545 .25 r
.33525 .62491 .33865 .6281 .34325 .64265 .33984 .63948 Mtetra
.895 .473 .131 r
.33984 .63948 .34325 .64265 .34809 .65376 .34467 .65061 Mtetra
.823 .353 0 r
.34467 .65061 .34809 .65376 .35311 .66213 .34969 .65899 Mtetra
.705 .201 0 r
.34969 .65899 .35311 .66213 .35826 .66867 .35484 .66554 Mtetra
0 .354 .811 r
.35484 .66554 .35826 .66867 .36362 .67167 .36019 .66855 Mtetra
.137 .508 .911 r
.36019 .66855 .36362 .67167 .36904 .6737 .36562 .67059 Mtetra
.387 .647 .96 r
.36562 .67059 .36904 .6737 .37454 .67444 .37112 .67133 Mtetra
.525 .707 .954 r
.37112 .67133 .37454 .67444 .3801 .67419 .37669 .67108 Mtetra
.56 .72 .948 r
.37669 .67108 .3801 .67419 .38569 .67363 .38228 .67051 Mtetra
.596 .733 .939 r
.38228 .67051 .38569 .67363 .3913 .67268 .38791 .66956 Mtetra
.607 .736 .936 r
.38791 .66956 .3913 .67268 .39694 .67162 .39355 .66849 Mtetra
.613 .738 .935 r
.39355 .66849 .39694 .67162 .40259 .67049 .39921 .66735 Mtetra
.617 .739 .933 r
.39921 .66735 .40259 .67049 .40826 .6693 .40488 .66616 Mtetra
.40488 .66616 .40826 .6693 .41394 .66811 .41057 .66496 Mtetra
.618 .74 .933 r
.41057 .66496 .41394 .66811 .41964 .66691 .41627 .66376 Mtetra
.618 .739 .933 r
.41627 .66376 .41964 .66691 .42535 .66571 .42199 .66255 Mtetra
.42199 .66255 .42535 .66571 .43107 .66451 .42772 .66134 Mtetra
.42772 .66134 .43107 .66451 .43681 .6633 .43346 .66013 Mtetra
.617 .739 .933 r
.43346 .66013 .43681 .6633 .44256 .6621 .43922 .65892 Mtetra
.43922 .65892 .44256 .6621 .44832 .6609 .44499 .65771 Mtetra
.44499 .65771 .44832 .6609 .4541 .65969 .45077 .6565 Mtetra
.45077 .6565 .4541 .65969 .45989 .65849 .45657 .65529 Mtetra
.616 .739 .933 r
.45657 .65529 .45989 .65849 .46569 .65729 .46238 .65408 Mtetra
.616 .738 .933 r
.46238 .65408 .46569 .65729 .47151 .65609 .46821 .65287 Mtetra
.46821 .65287 .47151 .65609 .47734 .65489 .47405 .65166 Mtetra
.615 .738 .934 r
.47405 .65166 .47734 .65489 .48319 .65369 .4799 .65046 Mtetra
.615 .738 .933 r
.4799 .65046 .48319 .65369 .48905 .65249 .48577 .64925 Mtetra
.48577 .64925 .48905 .65249 .49492 .65129 .49165 .64805 Mtetra
.614 .738 .934 r
.49165 .64805 .49492 .65129 .50081 .6501 .49755 .64684 Mtetra
.614 .737 .934 r
.49755 .64684 .50081 .6501 .50672 .64891 .50346 .64564 Mtetra
.50346 .64564 .50672 .64891 .51264 .64771 .50939 .64444 Mtetra
.613 .737 .934 r
.50939 .64444 .51264 .64771 .51857 .64652 .51533 .64324 Mtetra
.51533 .64324 .51857 .64652 .52451 .64533 .52128 .64205 Mtetra
.612 .736 .934 r
.52128 .64205 .52451 .64533 .53048 .64415 .52725 .64086 Mtetra
.52725 .64086 .53048 .64415 .53645 .64297 .53324 .63967 Mtetra
.53324 .63967 .53645 .64297 .54244 .64178 .53923 .63847 Mtetra
.611 .736 .934 r
.53923 .63847 .54244 .64178 .54845 .64061 .54525 .63729 Mtetra
.54525 .63729 .54845 .64061 .55447 .63943 .55128 .63611 Mtetra
.55128 .63611 .55447 .63943 .56051 .63825 .55732 .63492 Mtetra
.61 .735 .934 r
.55732 .63492 .56051 .63825 .56656 .63709 .56338 .63375 Mtetra
.56338 .63375 .56656 .63709 .57263 .63592 .56946 .63257 Mtetra
.56946 .63257 .57263 .63592 .57871 .63475 .57555 .6314 Mtetra
.608 .734 .934 r
.57555 .6314 .57871 .63475 .58481 .6336 .58165 .63024 Mtetra
.58165 .63024 .58481 .6336 .59092 .63245 .58777 .62907 Mtetra
.58777 .62907 .59092 .63245 .59705 .63129 .59391 .62791 Mtetra
.607 .733 .935 r
.59391 .62791 .59705 .63129 .60319 .63015 .60006 .62676 Mtetra
.606 .733 .935 r
.60006 .62676 .60319 .63015 .60935 .62901 .60623 .62561 Mtetra
.60623 .62561 .60935 .62901 .61553 .62787 .61242 .62446 Mtetra
.605 .732 .935 r
.61242 .62446 .61553 .62787 .62172 .62673 .61862 .62332 Mtetra
.604 .732 .935 r
.61862 .62332 .62172 .62673 .62793 .62561 .62483 .62219 Mtetra
.62483 .62219 .62793 .62561 .63416 .62449 .63107 .62106 Mtetra
.604 .731 .935 r
.63107 .62106 .63416 .62449 .6404 .62337 .63732 .61993 Mtetra
.602 .731 .935 r
.63732 .61993 .6404 .62337 .64665 .62227 .64358 .61882 Mtetra
.64358 .61882 .64665 .62227 .65293 .62117 .64987 .61771 Mtetra
.602 .73 .935 r
.64987 .61771 .65293 .62117 .65922 .62007 .65617 .6166 Mtetra
.6 .729 .935 r
.65617 .6166 .65922 .62007 .66553 .61899 .66248 .61551 Mtetra
.66248 .61551 .66553 .61899 .67186 .61791 .66882 .61442 Mtetra
.599 .729 .935 r
.66882 .61442 .67186 .61791 .6782 .61683 .67517 .61334 Mtetra
.598 .728 .936 r
.67517 .61334 .6782 .61683 .68456 .61578 .68154 .61227 Mtetra
.597 .728 .936 r
.68154 .61227 .68456 .61578 .69094 .61472 .68792 .61121 Mtetra
.597 .727 .936 r
.68792 .61121 .69094 .61472 .69733 .61367 .69433 .61015 Mtetra
.595 .726 .936 r
.69433 .61015 .69733 .61367 .70374 .61264 .70075 .60911 Mtetra
.594 .726 .936 r
.70075 .60911 .70374 .61264 .71017 .61162 .70719 .60807 Mtetra
.593 .725 .936 r
.70719 .60807 .71017 .61162 .71662 .6106 .71365 .60705 Mtetra
.592 .725 .936 r
.71365 .60705 .71662 .6106 .72309 .6096 .72013 .60603 Mtetra
.592 .724 .936 r
.72013 .60603 .72309 .6096 .72958 .6086 .72662 .60503 Mtetra
.59 .723 .936 r
.72662 .60503 .72958 .6086 .73608 .60763 .73313 .60404 Mtetra
.589 .723 .936 r
.73313 .60404 .73608 .60763 .74261 .60666 .73967 .60306 Mtetra
.589 .722 .936 r
.73967 .60306 .74261 .60666 .74915 .6057 .74622 .60209 Mtetra
.587 .721 .936 r
.74622 .60209 .74915 .6057 .75571 .60476 .75279 .60114 Mtetra
.586 .72 .936 r
.75279 .60114 .75571 .60476 .76229 .60383 .75938 .6002 Mtetra
.585 .72 .936 r
.75938 .6002 .76229 .60383 .76889 .60292 .76599 .59927 Mtetra
.583 .719 .936 r
.76599 .59927 .76889 .60292 .77552 .60202 .77262 .59837 Mtetra
.582 .718 .936 r
.77262 .59837 .77552 .60202 .78216 .60114 .77927 .59747 Mtetra
.581 .717 .936 r
.77927 .59747 .78216 .60114 .78882 .60027 .78594 .5966 Mtetra
.579 .716 .936 r
.78594 .5966 .78882 .60027 .7955 .59942 .79263 .59574 Mtetra
.578 .715 .936 r
.79263 .59574 .7955 .59942 .8022 .5986 .79935 .59489 Mtetra
.576 .714 .937 r
.79935 .59489 .8022 .5986 .80893 .59779 .80608 .59407 Mtetra
.575 .713 .936 r
.80608 .59407 .80893 .59779 .81568 .59699 .81284 .59327 Mtetra
.573 .712 .937 r
.81284 .59327 .81568 .59699 .82244 .59623 .81961 .59249 Mtetra
.571 .711 .937 r
.81961 .59249 .82244 .59623 .82923 .59548 .82641 .59173 Mtetra
.57 .71 .937 r
.82641 .59173 .82923 .59548 .83605 .59475 .83323 .59099 Mtetra
.567 .708 .937 r
.83323 .59099 .83605 .59475 .84288 .59406 .84008 .59028 Mtetra
.566 .707 .937 r
.84008 .59028 .84288 .59406 .84974 .59337 .84695 .58959 Mtetra
.565 .707 .937 r
.84695 .58959 .84974 .59337 .85662 .59271 .85384 .58891 Mtetra
.564 .706 .936 r
.85384 .58891 .85662 .59271 .86352 .59205 .86075 .58823 Mtetra
.566 .707 .936 r
.86075 .58823 .86352 .59205 .87044 .59136 .86768 .58753 Mtetra
.571 .708 .935 r
.86768 .58753 .87044 .59136 .87738 .59061 .87462 .58677 Mtetra
.59 .717 .932 r
.87462 .58677 .87738 .59061 .88431 .58959 .88156 .58575 Mtetra
.607 .725 .929 r
.88156 .58575 .88431 .58959 .89123 .58832 .88849 .58447 Mtetra
.66 .748 .915 r
.88849 .58447 .89123 .58832 .89808 .5862 .89536 .58236 Mtetra
.726 .774 .891 r
.89536 .58236 .89808 .5862 .9048 .5828 .90209 .57898 Mtetra
.768 .789 .871 r
.90209 .57898 .9048 .5828 .91142 .57842 .90873 .57464 Mtetra
.876 .811 .782 r
.90873 .57464 .91142 .57842 .91758 .57008 .91492 .56636 Mtetra
.914 .813 .734 r
.91492 .56636 .91758 .57008 .92346 .55931 .92082 .55568 Mtetra
.948 .807 .672 r
.92082 .55568 .92346 .55931 .92887 .54491 .92627 .54137 Mtetra
.972 .791 .6 r
.92627 .54137 .92887 .54491 .93357 .52499 .93101 .52153 Mtetra
.979 .785 .572 r
.93101 .52153 .93357 .52499 .93791 .50255 .93538 .49919 Mtetra
.932 .563 .282 r
.3274 .60584 .3308 .60905 .33525 .62491 .33184 .62172 Mtetra
.926 .545 .251 r
.33184 .62172 .33525 .62491 .33984 .63948 .33642 .63631 Mtetra
.895 .473 .132 r
.33642 .63631 .33984 .63948 .34467 .65061 .34124 .64745 Mtetra
.823 .354 0 r
.34124 .64745 .34467 .65061 .34969 .65899 .34625 .65585 Mtetra
.707 .202 0 r
.34625 .65585 .34969 .65899 .35484 .66554 .3514 .66241 Mtetra
0 .352 .81 r
.3514 .66241 .35484 .66554 .36019 .66855 .35675 .66543 Mtetra
.135 .507 .91 r
.35675 .66543 .36019 .66855 .36562 .67059 .36218 .66747 Mtetra
.386 .646 .96 r
.36218 .66747 .36562 .67059 .37112 .67133 .36769 .66821 Mtetra
.525 .707 .954 r
.36769 .66821 .37112 .67133 .37669 .67108 .37326 .66795 Mtetra
.559 .72 .948 r
.37326 .66795 .37669 .67108 .38228 .67051 .37886 .66738 Mtetra
.596 .733 .94 r
.37886 .66738 .38228 .67051 .38791 .66956 .38449 .66643 Mtetra
.607 .736 .937 r
.38449 .66643 .38791 .66956 .39355 .66849 .39014 .66535 Mtetra
.613 .738 .935 r
.39014 .66535 .39355 .66849 .39921 .66735 .39581 .66421 Mtetra
.617 .739 .934 r
.39581 .66421 .39921 .66735 .40488 .66616 .40149 .66301 Mtetra
.617 .74 .933 r
.40149 .66301 .40488 .66616 .41057 .66496 .40719 .66181 Mtetra
.618 .74 .933 r
.40719 .66181 .41057 .66496 .41627 .66376 .4129 .66059 Mtetra
.4129 .66059 .41627 .66376 .42199 .66255 .41862 .65938 Mtetra
.41862 .65938 .42199 .66255 .42772 .66134 .42436 .65816 Mtetra
.42436 .65816 .42772 .66134 .43346 .66013 .43011 .65694 Mtetra
.617 .739 .933 r
.43011 .65694 .43346 .66013 .43922 .65892 .43587 .65573 Mtetra
.43587 .65573 .43922 .65892 .44499 .65771 .44165 .65451 Mtetra
.44165 .65451 .44499 .65771 .45077 .6565 .44744 .65329 Mtetra
.44744 .65329 .45077 .6565 .45657 .65529 .45324 .65208 Mtetra
.616 .739 .934 r
.45324 .65208 .45657 .65529 .46238 .65408 .45906 .65086 Mtetra
.616 .739 .933 r
.45906 .65086 .46238 .65408 .46821 .65287 .4649 .64965 Mtetra
.616 .739 .934 r
.4649 .64965 .46821 .65287 .47405 .65166 .47074 .64843 Mtetra
.615 .738 .934 r
.47074 .64843 .47405 .65166 .4799 .65046 .4766 .64722 Mtetra
.4766 .64722 .4799 .65046 .48577 .64925 .48248 .646 Mtetra
.48248 .646 .48577 .64925 .49165 .64805 .48837 .64479 Mtetra
.614 .738 .934 r
.48837 .64479 .49165 .64805 .49755 .64684 .49427 .64358 Mtetra
.49427 .64358 .49755 .64684 .50346 .64564 .50019 .64237 Mtetra
.614 .737 .934 r
.50019 .64237 .50346 .64564 .50939 .64444 .50613 .64116 Mtetra
.613 .737 .934 r
.50613 .64116 .50939 .64444 .51533 .64324 .51207 .63996 Mtetra
.51207 .63996 .51533 .64324 .52128 .64205 .51804 .63876 Mtetra
.612 .737 .934 r
.51804 .63876 .52128 .64205 .52725 .64086 .52401 .63756 Mtetra
.52401 .63756 .52725 .64086 .53324 .63967 .53001 .63636 Mtetra
.612 .736 .934 r
.53001 .63636 .53324 .63967 .53923 .63847 .53601 .63516 Mtetra
.611 .736 .934 r
.53601 .63516 .53923 .63847 .54525 .63729 .54203 .63397 Mtetra
.54203 .63397 .54525 .63729 .55128 .63611 .54807 .63277 Mtetra
.54807 .63277 .55128 .63611 .55732 .63492 .55412 .63158 Mtetra
.61 .735 .934 r
.55412 .63158 .55732 .63492 .56338 .63375 .56019 .6304 Mtetra
.56019 .6304 .56338 .63375 .56946 .63257 .56627 .62922 Mtetra
.56627 .62922 .56946 .63257 .57555 .6314 .57237 .62803 Mtetra
.608 .734 .935 r
.57237 .62803 .57555 .6314 .58165 .63024 .57849 .62686 Mtetra
.57849 .62686 .58165 .63024 .58777 .62907 .58462 .62569 Mtetra
.58462 .62569 .58777 .62907 .59391 .62791 .59076 .62452 Mtetra
.607 .734 .935 r
.59076 .62452 .59391 .62791 .60006 .62676 .59692 .62336 Mtetra
.606 .733 .935 r
.59692 .62336 .60006 .62676 .60623 .62561 .6031 .6222 Mtetra
.6031 .6222 .60623 .62561 .61242 .62446 .60929 .62104 Mtetra
.605 .733 .935 r
.60929 .62104 .61242 .62446 .61862 .62332 .6155 .6199 Mtetra
.604 .732 .935 r
.6155 .6199 .61862 .62332 .62483 .62219 .62173 .61876 Mtetra
.62173 .61876 .62483 .62219 .63107 .62106 .62797 .61762 Mtetra
.62797 .61762 .63107 .62106 .63732 .61993 .63423 .61648 Mtetra
.602 .731 .935 r
.63423 .61648 .63732 .61993 .64358 .61882 .6405 .61536 Mtetra
.6405 .61536 .64358 .61882 .64987 .61771 .64679 .61424 Mtetra
.64679 .61424 .64987 .61771 .65617 .6166 .6531 .61312 Mtetra
.6 .73 .936 r
.6531 .61312 .65617 .6166 .66248 .61551 .65943 .61203 Mtetra
.6 .729 .936 r
.65943 .61203 .66248 .61551 .66882 .61442 .66577 .61093 Mtetra
.599 .729 .935 r
.66577 .61093 .66882 .61442 .67517 .61334 .67213 .60983 Mtetra
.598 .728 .936 r
.67213 .60983 .67517 .61334 .68154 .61227 .67851 .60876 Mtetra
.597 .728 .936 r
.67851 .60876 .68154 .61227 .68792 .61121 .6849 .60768 Mtetra
.6849 .60768 .68792 .61121 .69433 .61015 .69131 .60661 Mtetra
.595 .727 .936 r
.69131 .60661 .69433 .61015 .70075 .60911 .69775 .60556 Mtetra
.595 .726 .936 r
.69775 .60556 .70075 .60911 .70719 .60807 .70419 .60452 Mtetra
.593 .726 .936 r
.70419 .60452 .70719 .60807 .71365 .60705 .71066 .60348 Mtetra
.593 .725 .936 r
.71066 .60348 .71365 .60705 .72013 .60603 .71715 .60246 Mtetra
.592 .725 .936 r
.71715 .60246 .72013 .60603 .72662 .60503 .72365 .60144 Mtetra
.59 .724 .936 r
.72365 .60144 .72662 .60503 .73313 .60404 .73017 .60045 Mtetra
.59 .723 .936 r
.73017 .60045 .73313 .60404 .73967 .60306 .73672 .59946 Mtetra
.589 .723 .936 r
.73672 .59946 .73967 .60306 .74622 .60209 .74328 .59847 Mtetra
.587 .722 .937 r
.74328 .59847 .74622 .60209 .75279 .60114 .74986 .59752 Mtetra
.586 .721 .936 r
.74986 .59752 .75279 .60114 .75938 .6002 .75646 .59657 Mtetra
.585 .72 .937 r
.75646 .59657 .75938 .6002 .76599 .59927 .76307 .59563 Mtetra
.583 .719 .937 r
.76307 .59563 .76599 .59927 .77262 .59837 .76971 .59471 Mtetra
.582 .719 .937 r
.76971 .59471 .77262 .59837 .77927 .59747 .77637 .5938 Mtetra
.581 .718 .937 r
.77637 .5938 .77927 .59747 .78594 .5966 .78305 .59291 Mtetra
.579 .717 .937 r
.78305 .59291 .78594 .5966 .79263 .59574 .78975 .59204 Mtetra
.578 .716 .937 r
.78975 .59204 .79263 .59574 .79935 .59489 .79648 .59119 Mtetra
.576 .715 .937 r
.79648 .59119 .79935 .59489 .80608 .59407 .80322 .59036 Mtetra
.575 .714 .937 r
.80322 .59036 .80608 .59407 .81284 .59327 .80998 .58954 Mtetra
.573 .713 .937 r
.80998 .58954 .81284 .59327 .81961 .59249 .81677 .58875 Mtetra
.571 .711 .937 r
.81677 .58875 .81961 .59249 .82641 .59173 .82358 .58798 Mtetra
.57 .711 .937 r
.82358 .58798 .82641 .59173 .83323 .59099 .83041 .58722 Mtetra
.567 .709 .937 r
.83041 .58722 .83323 .59099 .84008 .59028 .83727 .5865 Mtetra
.566 .708 .937 r
.83727 .5865 .84008 .59028 .84695 .58959 .84414 .58579 Mtetra
.565 .707 .937 r
.84414 .58579 .84695 .58959 .85384 .58891 .85104 .5851 Mtetra
.564 .707 .937 r
.85104 .5851 .85384 .58891 .86075 .58823 .85796 .58442 Mtetra
.566 .707 .936 r
.85796 .58442 .86075 .58823 .86768 .58753 .8649 .5837 Mtetra
.571 .709 .936 r
.8649 .5837 .86768 .58753 .87462 .58677 .87186 .58293 Mtetra
.59 .718 .932 r
.87186 .58293 .87462 .58677 .88156 .58575 .87881 .5819 Mtetra
.607 .726 .929 r
.87881 .5819 .88156 .58575 .88849 .58447 .88575 .58062 Mtetra
.659 .748 .916 r
.88575 .58062 .88849 .58447 .89536 .58236 .89262 .57852 Mtetra
.725 .774 .892 r
.89262 .57852 .89536 .58236 .90209 .57898 .89938 .57516 Mtetra
.766 .789 .872 r
.89938 .57516 .90209 .57898 .90873 .57464 .90603 .57085 Mtetra
.875 .812 .784 r
.90603 .57085 .90873 .57464 .91492 .56636 .91225 .56263 Mtetra
.913 .814 .735 r
.91225 .56263 .91492 .56636 .92082 .55568 .91817 .55202 Mtetra
.947 .807 .673 r
.91817 .55202 .92082 .55568 .92627 .54137 .92365 .5378 Mtetra
.972 .791 .601 r
.92365 .5378 .92627 .54137 .93101 .52153 .92843 .51806 Mtetra
.979 .785 .573 r
.92843 .51806 .93101 .52153 .93538 .49919 .93283 .49579 Mtetra
.932 .563 .283 r
.32399 .60263 .3274 .60584 .33184 .62172 .32842 .61852 Mtetra
.926 .545 .251 r
.32842 .61852 .33184 .62172 .33642 .63631 .33298 .63312 Mtetra
.895 .474 .133 r
.33298 .63312 .33642 .63631 .34124 .64745 .33779 .64428 Mtetra
.824 .355 0 r
.33779 .64428 .34124 .64745 .34625 .65585 .3428 .65269 Mtetra
.708 .204 0 r
.3428 .65269 .34625 .65585 .3514 .66241 .34794 .65927 Mtetra
0 .351 .808 r
.34794 .65927 .3514 .66241 .35675 .66543 .3533 .6623 Mtetra
.133 .506 .91 r
.3533 .6623 .35675 .66543 .36218 .66747 .35873 .66434 Mtetra
.385 .646 .96 r
.35873 .66434 .36218 .66747 .36769 .66821 .36424 .66508 Mtetra
.524 .707 .955 r
.36424 .66508 .36769 .66821 .37326 .66795 .36982 .66482 Mtetra
.559 .72 .949 r
.36982 .66482 .37326 .66795 .37886 .66738 .37543 .66425 Mtetra
.596 .733 .94 r
.37543 .66425 .37886 .66738 .38449 .66643 .38107 .66329 Mtetra
.607 .737 .937 r
.38107 .66329 .38449 .66643 .39014 .66535 .38672 .66221 Mtetra
.613 .739 .935 r
.38672 .66221 .39014 .66535 .39581 .66421 .3924 .66105 Mtetra
.617 .74 .934 r
.3924 .66105 .39581 .66421 .40149 .66301 .39809 .65985 Mtetra
.39809 .65985 .40149 .66301 .40719 .66181 .40379 .65864 Mtetra
.618 .74 .933 r
.40379 .65864 .40719 .66181 .4129 .66059 .4095 .65742 Mtetra
.4095 .65742 .4129 .66059 .41862 .65938 .41523 .6562 Mtetra
.41523 .6562 .41862 .65938 .42436 .65816 .42098 .65498 Mtetra
.42098 .65498 .42436 .65816 .43011 .65694 .42674 .65375 Mtetra
.617 .74 .934 r
.42674 .65375 .43011 .65694 .43587 .65573 .43251 .65253 Mtetra
.43251 .65253 .43587 .65573 .44165 .65451 .43829 .6513 Mtetra
.617 .739 .934 r
.43829 .6513 .44165 .65451 .44744 .65329 .44409 .65008 Mtetra
.44409 .65008 .44744 .65329 .45324 .65208 .4499 .64886 Mtetra
.616 .739 .934 r
.4499 .64886 .45324 .65208 .45906 .65086 .45573 .64763 Mtetra
.45573 .64763 .45906 .65086 .4649 .64965 .46157 .64641 Mtetra
.46157 .64641 .4649 .64965 .47074 .64843 .46742 .64519 Mtetra
.615 .739 .934 r
.46742 .64519 .47074 .64843 .4766 .64722 .47329 .64397 Mtetra
.47329 .64397 .4766 .64722 .48248 .646 .47918 .64275 Mtetra
.615 .738 .934 r
.47918 .64275 .48248 .646 .48837 .64479 .48507 .64153 Mtetra
.48507 .64153 .48837 .64479 .49427 .64358 .49099 .64031 Mtetra
.614 .738 .934 r
.49099 .64031 .49427 .64358 .50019 .64237 .49691 .63909 Mtetra
.49691 .63909 .50019 .64237 .50613 .64116 .50285 .63787 Mtetra
.613 .738 .934 r
.50285 .63787 .50613 .64116 .51207 .63996 .50881 .63666 Mtetra
.613 .737 .934 r
.50881 .63666 .51207 .63996 .51804 .63876 .51478 .63545 Mtetra
.612 .737 .934 r
.51478 .63545 .51804 .63876 .52401 .63756 .52076 .63425 Mtetra
.613 .737 .934 r
.52076 .63425 .52401 .63756 .53001 .63636 .52676 .63304 Mtetra
.612 .737 .934 r
.52676 .63304 .53001 .63636 .53601 .63516 .53278 .63183 Mtetra
.611 .736 .934 r
.53278 .63183 .53601 .63516 .54203 .63397 .53881 .63063 Mtetra
.53881 .63063 .54203 .63397 .54807 .63277 .54485 .62943 Mtetra
.54485 .62943 .54807 .63277 .55412 .63158 .55091 .62823 Mtetra
.61 .736 .935 r
.55091 .62823 .55412 .63158 .56019 .6304 .55699 .62704 Mtetra
.61 .735 .935 r
.55699 .62704 .56019 .6304 .56627 .62922 .56308 .62585 Mtetra
.56308 .62585 .56627 .62922 .57237 .62803 .56919 .62466 Mtetra
.608 .735 .935 r
.56919 .62466 .57237 .62803 .57849 .62686 .57531 .62348 Mtetra
.57531 .62348 .57849 .62686 .58462 .62569 .58145 .6223 Mtetra
.608 .734 .935 r
.58145 .6223 .58462 .62569 .59076 .62452 .5876 .62112 Mtetra
.607 .734 .935 r
.5876 .62112 .59076 .62452 .59692 .62336 .59377 .61995 Mtetra
.606 .734 .935 r
.59377 .61995 .59692 .62336 .6031 .6222 .59995 .61879 Mtetra
.606 .733 .935 r
.59995 .61879 .6031 .6222 .60929 .62104 .60615 .61762 Mtetra
.605 .733 .935 r
.60615 .61762 .60929 .62104 .6155 .6199 .61237 .61646 Mtetra
.604 .732 .935 r
.61237 .61646 .6155 .6199 .62173 .61876 .61861 .61532 Mtetra
.61861 .61532 .62173 .61876 .62797 .61762 .62486 .61417 Mtetra
.62486 .61417 .62797 .61762 .63423 .61648 .63112 .61302 Mtetra
.602 .731 .936 r
.63112 .61302 .63423 .61648 .6405 .61536 .63741 .61189 Mtetra
.602 .731 .935 r
.63741 .61189 .6405 .61536 .64679 .61424 .64371 .61076 Mtetra
.64371 .61076 .64679 .61424 .6531 .61312 .65002 .60963 Mtetra
.6 .73 .936 r
.65002 .60963 .6531 .61312 .65943 .61203 .65636 .60853 Mtetra
.65636 .60853 .65943 .61203 .66577 .61093 .66271 .60742 Mtetra
.6 .729 .936 r
.66271 .60742 .66577 .61093 .67213 .60983 .66908 .60632 Mtetra
.598 .729 .936 r
.66908 .60632 .67213 .60983 .67851 .60876 .67546 .60523 Mtetra
.597 .728 .936 r
.67546 .60523 .67851 .60876 .6849 .60768 .68187 .60415 Mtetra
.68187 .60415 .6849 .60768 .69131 .60661 .68829 .60307 Mtetra
.595 .727 .936 r
.68829 .60307 .69131 .60661 .69775 .60556 .69473 .60201 Mtetra
.69473 .60201 .69775 .60556 .70419 .60452 .70119 .60096 Mtetra
.594 .726 .936 r
.70119 .60096 .70419 .60452 .71066 .60348 .70766 .59991 Mtetra
.593 .726 .936 r
.70766 .59991 .71066 .60348 .71715 .60246 .71416 .59888 Mtetra
.592 .725 .936 r
.71416 .59888 .71715 .60246 .72365 .60144 .72067 .59785 Mtetra
.59 .724 .937 r
.72067 .59785 .72365 .60144 .73017 .60045 .7272 .59685 Mtetra
.7272 .59685 .73017 .60045 .73672 .59946 .73375 .59585 Mtetra
.589 .723 .937 r
.73375 .59585 .73672 .59946 .74328 .59847 .74032 .59485 Mtetra
.587 .722 .937 r
.74032 .59485 .74328 .59847 .74986 .59752 .74691 .59389 Mtetra
.586 .722 .937 r
.74691 .59389 .74986 .59752 .75646 .59657 .75352 .59292 Mtetra
.585 .721 .937 r
.75352 .59292 .75646 .59657 .76307 .59563 .76015 .59198 Mtetra
.583 .72 .937 r
.76015 .59198 .76307 .59563 .76971 .59471 .7668 .59105 Mtetra
.582 .719 .937 r
.7668 .59105 .76971 .59471 .77637 .5938 .77347 .59013 Mtetra
.581 .719 .937 r
.77347 .59013 .77637 .5938 .78305 .59291 .78016 .58923 Mtetra
.579 .718 .937 r
.78016 .58923 .78305 .59291 .78975 .59204 .78687 .58835 Mtetra
.578 .717 .937 r
.78687 .58835 .78975 .59204 .79648 .59119 .7936 .58748 Mtetra
.576 .716 .938 r
.7936 .58748 .79648 .59119 .80322 .59036 .80035 .58664 Mtetra
.575 .715 .938 r
.80035 .58664 .80322 .59036 .80998 .58954 .80712 .58581 Mtetra
.573 .713 .938 r
.80712 .58581 .80998 .58954 .81677 .58875 .81392 .585 Mtetra
.571 .712 .938 r
.81392 .585 .81677 .58875 .82358 .58798 .82074 .58422 Mtetra
.57 .712 .938 r
.82074 .58422 .82358 .58798 .83041 .58722 .82758 .58346 Mtetra
.567 .71 .938 r
.82758 .58346 .83041 .58722 .83727 .5865 .83444 .58272 Mtetra
.566 .709 .938 r
.83444 .58272 .83727 .5865 .84414 .58579 .84133 .582 Mtetra
.565 .708 .938 r
.84133 .582 .84414 .58579 .85104 .5851 .84824 .58129 Mtetra
.564 .708 .938 r
.84824 .58129 .85104 .5851 .85796 .58442 .85517 .5806 Mtetra
.567 .708 .937 r
.85517 .5806 .85796 .58442 .8649 .5837 .86212 .57987 Mtetra
.571 .71 .936 r
.86212 .57987 .8649 .5837 .87186 .58293 .86908 .57909 Mtetra
.59 .718 .933 r
.86908 .57909 .87186 .58293 .87881 .5819 .87604 .57805 Mtetra
.606 .726 .93 r
.87604 .57805 .87881 .5819 .88575 .58062 .883 .57677 Mtetra
.658 .749 .917 r
.883 .57677 .88575 .58062 .89262 .57852 .88988 .57467 Mtetra
.724 .775 .893 r
.88988 .57467 .89262 .57852 .89938 .57516 .89665 .57133 Mtetra
.765 .789 .873 r
.89665 .57133 .89938 .57516 .90603 .57085 .90332 .56705 Mtetra
.874 .812 .785 r
.90332 .56705 .90603 .57085 .91225 .56263 .90956 .55889 Mtetra
.912 .814 .737 r
.90956 .55889 .91225 .56263 .91817 .55202 .91551 .54834 Mtetra
.946 .808 .675 r
.91551 .54834 .91817 .55202 .92365 .5378 .92102 .53421 Mtetra
.971 .792 .603 r
.92102 .53421 .92365 .5378 .92843 .51806 .92583 .51455 Mtetra
.979 .785 .575 r
.92583 .51455 .92843 .51806 .93283 .49579 .93027 .49237 Mtetra
.932 .563 .283 r
.32056 .59941 .32399 .60263 .32842 .61852 .32498 .61531 Mtetra
.926 .545 .252 r
.32498 .61531 .32842 .61852 .33298 .63312 .32953 .62994 Mtetra
.895 .474 .134 r
.32953 .62994 .33298 .63312 .33779 .64428 .33433 .64111 Mtetra
.825 .356 0 r
.33433 .64111 .33779 .64428 .3428 .65269 .33934 .64954 Mtetra
.71 .206 0 r
.33934 .64954 .3428 .65269 .34794 .65927 .34448 .65613 Mtetra
0 .349 .806 r
.34448 .65613 .34794 .65927 .3533 .6623 .34984 .65916 Mtetra
.13 .505 .909 r
.34984 .65916 .3533 .6623 .35873 .66434 .35527 .66121 Mtetra
.384 .646 .96 r
.35527 .66121 .35873 .66434 .36424 .66508 .36079 .66195 Mtetra
.524 .708 .955 r
.36079 .66195 .36424 .66508 .36982 .66482 .36637 .66169 Mtetra
.559 .721 .949 r
.36637 .66169 .36982 .66482 .37543 .66425 .37198 .66111 Mtetra
.596 .734 .94 r
.37198 .66111 .37543 .66425 .38107 .66329 .37763 .66014 Mtetra
.607 .737 .937 r
.37763 .66014 .38107 .66329 .38672 .66221 .38329 .65906 Mtetra
.613 .739 .935 r
.38329 .65906 .38672 .66221 .3924 .66105 .38897 .6579 Mtetra
.617 .74 .934 r
.38897 .6579 .3924 .66105 .39809 .65985 .39467 .65669 Mtetra
.39467 .65669 .39809 .65985 .40379 .65864 .40038 .65547 Mtetra
.618 .74 .934 r
.40038 .65547 .40379 .65864 .4095 .65742 .4061 .65424 Mtetra
.4061 .65424 .4095 .65742 .41523 .6562 .41184 .65302 Mtetra
.41184 .65302 .41523 .6562 .42098 .65498 .41759 .65179 Mtetra
.41759 .65179 .42098 .65498 .42674 .65375 .42335 .65055 Mtetra
.617 .74 .934 r
.42335 .65055 .42674 .65375 .43251 .65253 .42913 .64932 Mtetra
.42913 .64932 .43251 .65253 .43829 .6513 .43492 .64809 Mtetra
.43492 .64809 .43829 .6513 .44409 .65008 .44073 .64686 Mtetra
.44073 .64686 .44409 .65008 .4499 .64886 .44655 .64563 Mtetra
.616 .74 .934 r
.44655 .64563 .4499 .64886 .45573 .64763 .45238 .6444 Mtetra
.616 .739 .934 r
.45238 .6444 .45573 .64763 .46157 .64641 .45823 .64317 Mtetra
.45823 .64317 .46157 .64641 .46742 .64519 .46409 .64194 Mtetra
.615 .739 .934 r
.46409 .64194 .46742 .64519 .47329 .64397 .46997 .64071 Mtetra
.46997 .64071 .47329 .64397 .47918 .64275 .47586 .63949 Mtetra
.47586 .63949 .47918 .64275 .48507 .64153 .48176 .63826 Mtetra
.614 .739 .934 r
.48176 .63826 .48507 .64153 .49099 .64031 .48768 .63703 Mtetra
.614 .738 .934 r
.48768 .63703 .49099 .64031 .49691 .63909 .49362 .63581 Mtetra
.49362 .63581 .49691 .63909 .50285 .63787 .49957 .63458 Mtetra
.613 .738 .934 r
.49957 .63458 .50285 .63787 .50881 .63666 .50553 .63336 Mtetra
.613 .738 .935 r
.50553 .63336 .50881 .63666 .51478 .63545 .51151 .63215 Mtetra
.612 .738 .935 r
.51151 .63215 .51478 .63545 .52076 .63425 .5175 .63093 Mtetra
.5175 .63093 .52076 .63425 .52676 .63304 .52351 .62972 Mtetra
.612 .737 .935 r
.52351 .62972 .52676 .63304 .53278 .63183 .52953 .6285 Mtetra
.611 .737 .935 r
.52953 .6285 .53278 .63183 .53881 .63063 .53557 .6273 Mtetra
.53557 .6273 .53881 .63063 .54485 .62943 .54162 .62609 Mtetra
.54162 .62609 .54485 .62943 .55091 .62823 .54769 .62488 Mtetra
.61 .736 .935 r
.54769 .62488 .55091 .62823 .55699 .62704 .55377 .62368 Mtetra
.55377 .62368 .55699 .62704 .56308 .62585 .55987 .62248 Mtetra
.55987 .62248 .56308 .62585 .56919 .62466 .56599 .62128 Mtetra
.608 .735 .935 r
.56599 .62128 .56919 .62466 .57531 .62348 .57212 .62009 Mtetra
.57212 .62009 .57531 .62348 .58145 .6223 .57826 .61891 Mtetra
.57826 .61891 .58145 .6223 .5876 .62112 .58442 .61772 Mtetra
.607 .735 .935 r
.58442 .61772 .5876 .62112 .59377 .61995 .5906 .61654 Mtetra
.606 .734 .936 r
.5906 .61654 .59377 .61995 .59995 .61879 .59679 .61537 Mtetra
.606 .734 .935 r
.59679 .61537 .59995 .61879 .60615 .61762 .603 .61419 Mtetra
.605 .734 .936 r
.603 .61419 .60615 .61762 .61237 .61646 .60923 .61303 Mtetra
.604 .733 .936 r
.60923 .61303 .61237 .61646 .61861 .61532 .61547 .61187 Mtetra
.61547 .61187 .61861 .61532 .62486 .61417 .62173 .61071 Mtetra
.62173 .61071 .62486 .61417 .63112 .61302 .62801 .60956 Mtetra
.602 .732 .936 r
.62801 .60956 .63112 .61302 .63741 .61189 .6343 .60842 Mtetra
.6343 .60842 .63741 .61189 .64371 .61076 .64061 .60728 Mtetra
.64061 .60728 .64371 .61076 .65002 .60963 .64693 .60615 Mtetra
.6 .731 .936 r
.64693 .60615 .65002 .60963 .65636 .60853 .65328 .60503 Mtetra
.65328 .60503 .65636 .60853 .66271 .60742 .65964 .60392 Mtetra
.6 .73 .936 r
.65964 .60392 .66271 .60742 .66908 .60632 .66601 .6028 Mtetra
.598 .729 .937 r
.66601 .6028 .66908 .60632 .67546 .60523 .67241 .60171 Mtetra
.597 .729 .937 r
.67241 .60171 .67546 .60523 .68187 .60415 .67882 .60062 Mtetra
.67882 .60062 .68187 .60415 .68829 .60307 .68525 .59953 Mtetra
.595 .728 .937 r
.68525 .59953 .68829 .60307 .69473 .60201 .6917 .59846 Mtetra
.6917 .59846 .69473 .60201 .70119 .60096 .69817 .59739 Mtetra
.593 .727 .937 r
.69817 .59739 .70119 .60096 .70766 .59991 .70465 .59634 Mtetra
.70465 .59634 .70766 .59991 .71416 .59888 .71116 .5953 Mtetra
.592 .726 .937 r
.71116 .5953 .71416 .59888 .72067 .59785 .71768 .59426 Mtetra
.59 .725 .937 r
.71768 .59426 .72067 .59785 .7272 .59685 .72422 .59324 Mtetra
.72422 .59324 .7272 .59685 .73375 .59585 .73078 .59223 Mtetra
.589 .724 .937 r
.73078 .59223 .73375 .59585 .74032 .59485 .73736 .59123 Mtetra
.587 .723 .937 r
.73736 .59123 .74032 .59485 .74691 .59389 .74396 .59025 Mtetra
.586 .722 .937 r
.74396 .59025 .74691 .59389 .75352 .59292 .75057 .58928 Mtetra
.585 .722 .937 r
.75057 .58928 .75352 .59292 .76015 .59198 .75721 .58832 Mtetra
.583 .721 .938 r
.75721 .58832 .76015 .59198 .7668 .59105 .76387 .58738 Mtetra
.582 .72 .938 r
.76387 .58738 .7668 .59105 .77347 .59013 .77055 .58645 Mtetra
.581 .719 .938 r
.77055 .58645 .77347 .59013 .78016 .58923 .77725 .58554 Mtetra
.58 .718 .938 r
.77725 .58554 .78016 .58923 .78687 .58835 .78397 .58465 Mtetra
.578 .717 .938 r
.78397 .58465 .78687 .58835 .7936 .58748 .79071 .58377 Mtetra
.576 .716 .938 r
.79071 .58377 .7936 .58748 .80035 .58664 .79747 .58291 Mtetra
.575 .716 .938 r
.79747 .58291 .80035 .58664 .80712 .58581 .80425 .58207 Mtetra
.573 .714 .938 r
.80425 .58207 .80712 .58581 .81392 .585 .81106 .58126 Mtetra
.571 .713 .938 r
.81106 .58126 .81392 .585 .82074 .58422 .81788 .58046 Mtetra
.57 .712 .938 r
.81788 .58046 .82074 .58422 .82758 .58346 .82473 .57968 Mtetra
.568 .711 .938 r
.82473 .57968 .82758 .58346 .83444 .58272 .83161 .57893 Mtetra
.566 .71 .938 r
.83161 .57893 .83444 .58272 .84133 .582 .8385 .5782 Mtetra
.565 .709 .938 r
.8385 .5782 .84133 .582 .84824 .58129 .84542 .57748 Mtetra
.564 .708 .938 r
.84542 .57748 .84824 .58129 .85517 .5806 .85236 .57677 Mtetra
.567 .709 .937 r
.85236 .57677 .85517 .5806 .86212 .57987 .85932 .57603 Mtetra
.571 .711 .937 r
.85932 .57603 .86212 .57987 .86908 .57909 .8663 .57524 Mtetra
.589 .719 .934 r
.8663 .57524 .86908 .57909 .87604 .57805 .87327 .5742 Mtetra
.606 .727 .93 r
.87327 .5742 .87604 .57805 .883 .57677 .88023 .57291 Mtetra
.657 .749 .918 r
.88023 .57291 .883 .57677 .88988 .57467 .88713 .57082 Mtetra
.722 .775 .894 r
.88713 .57082 .88988 .57467 .89665 .57133 .89391 .5675 Mtetra
.763 .79 .875 r
.89391 .5675 .89665 .57133 .90332 .56705 .9006 .56325 Mtetra
.873 .812 .787 r
.9006 .56325 .90332 .56705 .90956 .55889 .90686 .55514 Mtetra
.911 .814 .739 r
.90686 .55514 .90956 .55889 .91551 .54834 .91284 .54466 Mtetra
.946 .808 .677 r
.91284 .54466 .91551 .54834 .92102 .53421 .91838 .5306 Mtetra
.971 .792 .604 r
.91838 .5306 .92102 .53421 .92583 .51455 .92323 .51102 Mtetra
.978 .785 .576 r
.92323 .51102 .92583 .51455 .93027 .49237 .9277 .48892 Mtetra
.932 .563 .283 r
.31712 .59619 .32056 .59941 .32498 .61531 .32152 .6121 Mtetra
.926 .545 .252 r
.32152 .6121 .32498 .61531 .32953 .62994 .32607 .62674 Mtetra
.896 .474 .135 r
.32607 .62674 .32953 .62994 .33433 .64111 .33086 .63793 Mtetra
.825 .357 0 r
.33086 .63793 .33433 .64111 .33934 .64954 .33586 .64637 Mtetra
.711 .207 0 r
.33586 .64637 .33934 .64954 .34448 .65613 .341 .65298 Mtetra
0 .347 .805 r
.341 .65298 .34448 .65613 .34984 .65916 .34636 .65601 Mtetra
.128 .504 .908 r
.34636 .65601 .34984 .65916 .35527 .66121 .35179 .65807 Mtetra
.383 .646 .96 r
.35179 .65807 .35527 .66121 .36079 .66195 .35732 .65881 Mtetra
.523 .708 .955 r
.35732 .65881 .36079 .66195 .36637 .66169 .3629 .65854 Mtetra
.559 .721 .949 r
.3629 .65854 .36637 .66169 .37198 .66111 .36852 .65796 Mtetra
.596 .734 .94 r
.36852 .65796 .37198 .66111 .37763 .66014 .37417 .65699 Mtetra
.607 .737 .937 r
.37417 .65699 .37763 .66014 .38329 .65906 .37985 .6559 Mtetra
.613 .739 .936 r
.37985 .6559 .38329 .65906 .38897 .6579 .38553 .65473 Mtetra
.617 .74 .934 r
.38553 .65473 .38897 .6579 .39467 .65669 .39123 .65352 Mtetra
.617 .741 .934 r
.39123 .65352 .39467 .65669 .40038 .65547 .39695 .65229 Mtetra
.618 .741 .934 r
.39695 .65229 .40038 .65547 .4061 .65424 .40268 .65106 Mtetra
.40268 .65106 .4061 .65424 .41184 .65302 .40843 .64982 Mtetra
.40843 .64982 .41184 .65302 .41759 .65179 .41418 .64858 Mtetra
.618 .74 .934 r
.41418 .64858 .41759 .65179 .42335 .65055 .41996 .64734 Mtetra
.617 .74 .934 r
.41996 .64734 .42335 .65055 .42913 .64932 .42574 .64611 Mtetra
.42574 .64611 .42913 .64932 .43492 .64809 .43154 .64487 Mtetra
.43154 .64487 .43492 .64809 .44073 .64686 .43735 .64363 Mtetra
.43735 .64363 .44073 .64686 .44655 .64563 .44318 .64239 Mtetra
.616 .74 .934 r
.44318 .64239 .44655 .64563 .45238 .6444 .44902 .64116 Mtetra
.44902 .64116 .45238 .6444 .45823 .64317 .45488 .63992 Mtetra
.45488 .63992 .45823 .64317 .46409 .64194 .46075 .63868 Mtetra
.615 .739 .934 r
.46075 .63868 .46409 .64194 .46997 .64071 .46663 .63745 Mtetra
.46663 .63745 .46997 .64071 .47586 .63949 .47253 .63621 Mtetra
.47253 .63621 .47586 .63949 .48176 .63826 .47844 .63498 Mtetra
.47844 .63498 .48176 .63826 .48768 .63703 .48437 .63374 Mtetra
.614 .739 .934 r
.48437 .63374 .48768 .63703 .49362 .63581 .49031 .63251 Mtetra
.614 .739 .935 r
.49031 .63251 .49362 .63581 .49957 .63458 .49627 .63128 Mtetra
.613 .738 .935 r
.49627 .63128 .49957 .63458 .50553 .63336 .50224 .63005 Mtetra
.50224 .63005 .50553 .63336 .51151 .63215 .50822 .62883 Mtetra
.612 .738 .935 r
.50822 .62883 .51151 .63215 .5175 .63093 .51422 .62761 Mtetra
.613 .738 .935 r
.51422 .62761 .5175 .63093 .52351 .62972 .52024 .62639 Mtetra
.612 .738 .935 r
.52024 .62639 .52351 .62972 .52953 .6285 .52627 .62516 Mtetra
.611 .737 .935 r
.52627 .62516 .52953 .6285 .53557 .6273 .53232 .62395 Mtetra
.53232 .62395 .53557 .6273 .54162 .62609 .53838 .62273 Mtetra
.53838 .62273 .54162 .62609 .54769 .62488 .54445 .62151 Mtetra
.61 .736 .935 r
.54445 .62151 .54769 .62488 .55377 .62368 .55054 .62031 Mtetra
.55054 .62031 .55377 .62368 .55987 .62248 .55665 .6191 Mtetra
.55665 .6191 .55987 .62248 .56599 .62128 .56277 .61789 Mtetra
.608 .736 .935 r
.56277 .61789 .56599 .62128 .57212 .62009 .56891 .6167 Mtetra
.608 .735 .935 r
.56891 .6167 .57212 .62009 .57826 .61891 .57507 .61551 Mtetra
.57507 .61551 .57826 .61891 .58442 .61772 .58124 .61431 Mtetra
.607 .735 .936 r
.58124 .61431 .58442 .61772 .5906 .61654 .58742 .61312 Mtetra
.606 .735 .936 r
.58742 .61312 .5906 .61654 .59679 .61537 .59362 .61194 Mtetra
.606 .734 .936 r
.59362 .61194 .59679 .61537 .603 .61419 .59984 .61076 Mtetra
.605 .734 .936 r
.59984 .61076 .603 .61419 .60923 .61303 .60608 .60958 Mtetra
.604 .734 .936 r
.60608 .60958 .60923 .61303 .61547 .61187 .61233 .60842 Mtetra
.604 .733 .936 r
.61233 .60842 .61547 .61187 .62173 .61071 .61859 .60725 Mtetra
.61859 .60725 .62173 .61071 .62801 .60956 .62488 .60609 Mtetra
.602 .732 .936 r
.62488 .60609 .62801 .60956 .6343 .60842 .63118 .60494 Mtetra
.63118 .60494 .6343 .60842 .64061 .60728 .6375 .6038 Mtetra
.6375 .6038 .64061 .60728 .64693 .60615 .64383 .60265 Mtetra
.6 .731 .937 r
.64383 .60265 .64693 .60615 .65328 .60503 .65018 .60153 Mtetra
.65018 .60153 .65328 .60503 .65964 .60392 .65655 .6004 Mtetra
.6 .731 .936 r
.65655 .6004 .65964 .60392 .66601 .6028 .66294 .59928 Mtetra
.598 .73 .937 r
.66294 .59928 .66601 .6028 .67241 .60171 .66934 .59818 Mtetra
.597 .73 .937 r
.66934 .59818 .67241 .60171 .67882 .60062 .67576 .59707 Mtetra
.597 .729 .937 r
.67576 .59707 .67882 .60062 .68525 .59953 .6822 .59598 Mtetra
.595 .728 .937 r
.6822 .59598 .68525 .59953 .6917 .59846 .68866 .5949 Mtetra
.68866 .5949 .6917 .59846 .69817 .59739 .69514 .59382 Mtetra
.594 .727 .937 r
.69514 .59382 .69817 .59739 .70465 .59634 .70163 .59276 Mtetra
.593 .727 .937 r
.70163 .59276 .70465 .59634 .71116 .5953 .70814 .59171 Mtetra
.592 .726 .937 r
.70814 .59171 .71116 .5953 .71768 .59426 .71467 .59066 Mtetra
.59 .725 .937 r
.71467 .59066 .71768 .59426 .72422 .59324 .72122 .58963 Mtetra
.72122 .58963 .72422 .59324 .73078 .59223 .72779 .58861 Mtetra
.589 .724 .937 r
.72779 .58861 .73078 .59223 .73736 .59123 .73438 .5876 Mtetra
.587 .723 .938 r
.73438 .5876 .73736 .59123 .74396 .59025 .74099 .58661 Mtetra
.586 .723 .938 r
.74099 .58661 .74396 .59025 .75057 .58928 .74761 .58563 Mtetra
.585 .722 .938 r
.74761 .58563 .75057 .58928 .75721 .58832 .75426 .58465 Mtetra
.584 .721 .938 r
.75426 .58465 .75721 .58832 .76387 .58738 .76093 .5837 Mtetra
.583 .721 .938 r
.76093 .5837 .76387 .58738 .77055 .58645 .76762 .58276 Mtetra
.581 .72 .938 r
.76762 .58276 .77055 .58645 .77725 .58554 .77432 .58184 Mtetra
.58 .719 .938 r
.77432 .58184 .77725 .58554 .78397 .58465 .78105 .58094 Mtetra
.578 .718 .938 r
.78105 .58094 .78397 .58465 .79071 .58377 .7878 .58005 Mtetra
.577 .717 .938 r
.7878 .58005 .79071 .58377 .79747 .58291 .79457 .57918 Mtetra
.575 .716 .938 r
.79457 .57918 .79747 .58291 .80425 .58207 .80137 .57833 Mtetra
.573 .715 .938 r
.80137 .57833 .80425 .58207 .81106 .58126 .80818 .5775 Mtetra
.571 .714 .939 r
.80818 .5775 .81106 .58126 .81788 .58046 .81502 .5767 Mtetra
.57 .713 .938 r
.81502 .5767 .81788 .58046 .82473 .57968 .82188 .5759 Mtetra
.568 .711 .939 r
.82188 .5759 .82473 .57968 .83161 .57893 .82876 .57514 Mtetra
.567 .711 .939 r
.82876 .57514 .83161 .57893 .8385 .5782 .83567 .5744 Mtetra
.565 .71 .939 r
.83567 .5744 .8385 .5782 .84542 .57748 .84259 .57366 Mtetra
.565 .709 .938 r
.84259 .57366 .84542 .57748 .85236 .57677 .84955 .57294 Mtetra
.567 .71 .938 r
.84955 .57294 .85236 .57677 .85932 .57603 .85651 .57219 Mtetra
.571 .711 .937 r
.85651 .57219 .85932 .57603 .8663 .57524 .8635 .57139 Mtetra
.589 .72 .934 r
.8635 .57139 .8663 .57524 .87327 .5742 .87048 .57034 Mtetra
.605 .727 .931 r
.87048 .57034 .87327 .5742 .88023 .57291 .87746 .56905 Mtetra
.656 .749 .919 r
.87746 .56905 .88023 .57291 .88713 .57082 .88437 .56696 Mtetra
.721 .775 .895 r
.88437 .56696 .88713 .57082 .89391 .5675 .89117 .56366 Mtetra
.762 .79 .876 r
.89117 .56366 .89391 .5675 .9006 .56325 .89787 .55944 Mtetra
.872 .813 .789 r
.89787 .55944 .9006 .56325 .90686 .55514 .90416 .55138 Mtetra
.91 .815 .74 r
.90416 .55138 .90686 .55514 .91284 .54466 .91016 .54096 Mtetra
.945 .808 .678 r
.91016 .54096 .91284 .54466 .91838 .5306 .91573 .52697 Mtetra
.971 .792 .605 r
.91573 .52697 .91838 .5306 .92323 .51102 .92061 .50748 Mtetra
.978 .786 .577 r
.92061 .50748 .92323 .51102 .9277 .48892 .92512 .48544 Mtetra
.932 .563 .284 r
.31367 .59296 .31712 .59619 .32152 .6121 .31806 .60889 Mtetra
.926 .545 .252 r
.31806 .60889 .32152 .6121 .32607 .62674 .32259 .62354 Mtetra
.896 .475 .136 r
.32259 .62354 .32607 .62674 .33086 .63793 .32738 .63475 Mtetra
.826 .357 0 r
.32738 .63475 .33086 .63793 .33586 .64637 .33237 .64321 Mtetra
.713 .209 0 r
.33237 .64321 .33586 .64637 .341 .65298 .33751 .64982 Mtetra
0 .345 .803 r
.33751 .64982 .341 .65298 .34636 .65601 .34287 .65286 Mtetra
.126 .503 .908 r
.34287 .65286 .34636 .65601 .35179 .65807 .34831 .65492 Mtetra
.382 .646 .96 r
.34831 .65492 .35179 .65807 .35732 .65881 .35383 .65566 Mtetra
.523 .708 .955 r
.35383 .65566 .35732 .65881 .3629 .65854 .35943 .65539 Mtetra
.558 .721 .95 r
.35943 .65539 .3629 .65854 .36852 .65796 .36505 .6548 Mtetra
.596 .734 .941 r
.36505 .6548 .36852 .65796 .37417 .65699 .37071 .65383 Mtetra
.607 .738 .938 r
.37071 .65383 .37417 .65699 .37985 .6559 .37639 .65273 Mtetra
.613 .74 .936 r
.37639 .65273 .37985 .6559 .38553 .65473 .38208 .65156 Mtetra
.617 .741 .935 r
.38208 .65156 .38553 .65473 .39123 .65352 .38779 .65034 Mtetra
.617 .741 .934 r
.38779 .65034 .39123 .65352 .39695 .65229 .39351 .64911 Mtetra
.618 .741 .934 r
.39351 .64911 .39695 .65229 .40268 .65106 .39925 .64786 Mtetra
.39925 .64786 .40268 .65106 .40843 .64982 .405 .64662 Mtetra
.405 .64662 .40843 .64982 .41418 .64858 .41077 .64538 Mtetra
.41077 .64538 .41418 .64858 .41996 .64734 .41654 .64413 Mtetra
.617 .741 .934 r
.41654 .64413 .41996 .64734 .42574 .64611 .42234 .64289 Mtetra
.42234 .64289 .42574 .64611 .43154 .64487 .42814 .64164 Mtetra
.617 .74 .934 r
.42814 .64164 .43154 .64487 .43735 .64363 .43396 .6404 Mtetra
.43396 .6404 .43735 .64363 .44318 .64239 .4398 .63915 Mtetra
.616 .74 .934 r
.4398 .63915 .44318 .64239 .44902 .64116 .44565 .63791 Mtetra
.44565 .63791 .44902 .64116 .45488 .63992 .45151 .63666 Mtetra
.45151 .63666 .45488 .63992 .46075 .63868 .45739 .63542 Mtetra
.615 .74 .935 r
.45739 .63542 .46075 .63868 .46663 .63745 .46328 .63418 Mtetra
.46328 .63418 .46663 .63745 .47253 .63621 .46919 .63294 Mtetra
.615 .739 .935 r
.46919 .63294 .47253 .63621 .47844 .63498 .47511 .63169 Mtetra
.47511 .63169 .47844 .63498 .48437 .63374 .48104 .63045 Mtetra
.614 .739 .935 r
.48104 .63045 .48437 .63374 .49031 .63251 .48699 .62921 Mtetra
.48699 .62921 .49031 .63251 .49627 .63128 .49295 .62797 Mtetra
.613 .739 .935 r
.49295 .62797 .49627 .63128 .50224 .63005 .49893 .62674 Mtetra
.613 .738 .935 r
.49893 .62674 .50224 .63005 .50822 .62883 .50493 .62551 Mtetra
.612 .738 .935 r
.50493 .62551 .50822 .62883 .51422 .62761 .51093 .62428 Mtetra
.613 .738 .935 r
.51093 .62428 .51422 .62761 .52024 .62639 .51696 .62305 Mtetra
.612 .738 .935 r
.51696 .62305 .52024 .62639 .52627 .62516 .523 .62181 Mtetra
.611 .738 .935 r
.523 .62181 .52627 .62516 .53232 .62395 .52905 .62059 Mtetra
.611 .737 .935 r
.52905 .62059 .53232 .62395 .53838 .62273 .53512 .61937 Mtetra
.53512 .61937 .53838 .62273 .54445 .62151 .5412 .61814 Mtetra
.61 .737 .936 r
.5412 .61814 .54445 .62151 .55054 .62031 .5473 .61693 Mtetra
.61 .737 .935 r
.5473 .61693 .55054 .62031 .55665 .6191 .55342 .61572 Mtetra
.55342 .61572 .55665 .6191 .56277 .61789 .55955 .6145 Mtetra
.608 .736 .936 r
.55955 .6145 .56277 .61789 .56891 .6167 .5657 .6133 Mtetra
.5657 .6133 .56891 .6167 .57507 .61551 .57186 .61209 Mtetra
.57186 .61209 .57507 .61551 .58124 .61431 .57804 .61089 Mtetra
.607 .735 .936 r
.57804 .61089 .58124 .61431 .58742 .61312 .58423 .60969 Mtetra
.606 .735 .936 r
.58423 .60969 .58742 .61312 .59362 .61194 .59044 .60851 Mtetra
.59044 .60851 .59362 .61194 .59984 .61076 .59667 .60731 Mtetra
.605 .734 .936 r
.59667 .60731 .59984 .61076 .60608 .60958 .60291 .60613 Mtetra
.604 .734 .936 r
.60291 .60613 .60608 .60958 .61233 .60842 .60917 .60496 Mtetra
.60917 .60496 .61233 .60842 .61859 .60725 .61544 .60378 Mtetra
.604 .733 .936 r
.61544 .60378 .61859 .60725 .62488 .60609 .62174 .60261 Mtetra
.602 .733 .937 r
.62174 .60261 .62488 .60609 .63118 .60494 .62805 .60146 Mtetra
.602 .733 .936 r
.62805 .60146 .63118 .60494 .6375 .6038 .63437 .6003 Mtetra
.602 .732 .936 r
.63437 .6003 .6375 .6038 .64383 .60265 .64072 .59914 Mtetra
.6 .731 .937 r
.64072 .59914 .64383 .60265 .65018 .60153 .64708 .59801 Mtetra
.64708 .59801 .65018 .60153 .65655 .6004 .65345 .59688 Mtetra
.65345 .59688 .65655 .6004 .66294 .59928 .65985 .59574 Mtetra
.598 .73 .937 r
.65985 .59574 .66294 .59928 .66934 .59818 .66626 .59463 Mtetra
.597 .73 .937 r
.66626 .59463 .66934 .59818 .67576 .59707 .67269 .59352 Mtetra
.67269 .59352 .67576 .59707 .6822 .59598 .67914 .59242 Mtetra
.595 .729 .937 r
.67914 .59242 .6822 .59598 .68866 .5949 .68561 .59133 Mtetra
.595 .728 .937 r
.68561 .59133 .68866 .5949 .69514 .59382 .69209 .59024 Mtetra
.594 .728 .937 r
.69209 .59024 .69514 .59382 .70163 .59276 .69859 .58917 Mtetra
.593 .727 .938 r
.69859 .58917 .70163 .59276 .70814 .59171 .70512 .58811 Mtetra
.592 .727 .938 r
.70512 .58811 .70814 .59171 .71467 .59066 .71166 .58705 Mtetra
.59 .726 .938 r
.71166 .58705 .71467 .59066 .72122 .58963 .71822 .58602 Mtetra
.71822 .58602 .72122 .58963 .72779 .58861 .72479 .58499 Mtetra
.589 .725 .938 r
.72479 .58499 .72779 .58861 .73438 .5876 .73139 .58396 Mtetra
.587 .724 .938 r
.73139 .58396 .73438 .5876 .74099 .58661 .73801 .58296 Mtetra
.586 .724 .938 r
.73801 .58296 .74099 .58661 .74761 .58563 .74464 .58197 Mtetra
.585 .723 .938 r
.74464 .58197 .74761 .58563 .75426 .58465 .7513 .58099 Mtetra
.583 .722 .939 r
.7513 .58099 .75426 .58465 .76093 .5837 .75798 .58003 Mtetra
.582 .721 .939 r
.75798 .58003 .76093 .5837 .76762 .58276 .76467 .57908 Mtetra
.581 .721 .939 r
.76467 .57908 .76762 .58276 .77432 .58184 .77139 .57815 Mtetra
.58 .72 .939 r
.77139 .57815 .77432 .58184 .78105 .58094 .77813 .57723 Mtetra
.578 .719 .939 r
.77813 .57723 .78105 .58094 .7878 .58005 .78489 .57633 Mtetra
.576 .718 .939 r
.78489 .57633 .7878 .58005 .79457 .57918 .79167 .57545 Mtetra
.575 .717 .939 r
.79167 .57545 .79457 .57918 .80137 .57833 .79847 .57458 Mtetra
.573 .716 .939 r
.79847 .57458 .80137 .57833 .80818 .5775 .8053 .57375 Mtetra
.571 .715 .939 r
.8053 .57375 .80818 .5775 .81502 .5767 .81214 .57293 Mtetra
.57 .714 .939 r
.81214 .57293 .81502 .5767 .82188 .5759 .81901 .57213 Mtetra
.568 .713 .939 r
.81901 .57213 .82188 .5759 .82876 .57514 .82591 .57135 Mtetra
.566 .712 .939 r
.82591 .57135 .82876 .57514 .83567 .5744 .83282 .5706 Mtetra
.565 .711 .939 r
.83282 .5706 .83567 .5744 .84259 .57366 .83976 .56985 Mtetra
.564 .71 .939 r
.83976 .56985 .84259 .57366 .84955 .57294 .84672 .56912 Mtetra
.567 .711 .939 r
.84672 .56912 .84955 .57294 .85651 .57219 .8537 .56836 Mtetra
.57 .712 .938 r
.8537 .56836 .85651 .57219 .8635 .57139 .86069 .56754 Mtetra
.588 .721 .935 r
.86069 .56754 .8635 .57139 .87048 .57034 .86768 .56648 Mtetra
.605 .728 .932 r
.86768 .56648 .87048 .57034 .87746 .56905 .87467 .56519 Mtetra
.655 .75 .92 r
.87467 .56519 .87746 .56905 .88437 .56696 .8816 .56311 Mtetra
.72 .776 .896 r
.8816 .56311 .88437 .56696 .89117 .56366 .88841 .55982 Mtetra
.761 .79 .877 r
.88841 .55982 .89117 .56366 .89787 .55944 .89513 .55562 Mtetra
.871 .813 .79 r
.89513 .55562 .89787 .55944 .90416 .55138 .90144 .54761 Mtetra
.909 .815 .742 r
.90144 .54761 .90416 .55138 .91016 .54096 .90747 .53724 Mtetra
.944 .809 .679 r
.90747 .53724 .91016 .54096 .91573 .52697 .91306 .52333 Mtetra
.971 .793 .606 r
.91306 .52333 .91573 .52697 .92061 .50748 .91798 .5039 Mtetra
.978 .786 .578 r
.91798 .5039 .92061 .50748 .92512 .48544 .92252 .48193 Mtetra
.932 .563 .284 r
.31021 .58973 .31367 .59296 .31806 .60889 .31458 .60567 Mtetra
.926 .546 .253 r
.31458 .60567 .31806 .60889 .32259 .62354 .3191 .62034 Mtetra
.896 .475 .136 r
.3191 .62034 .32259 .62354 .32738 .63475 .32388 .63156 Mtetra
.827 .358 0 r
.32388 .63156 .32738 .63475 .33237 .64321 .32887 .64003 Mtetra
.714 .21 0 r
.32887 .64003 .33237 .64321 .33751 .64982 .334 .64666 Mtetra
0 .343 .802 r
.334 .64666 .33751 .64982 .34287 .65286 .33936 .6497 Mtetra
.123 .502 .907 r
.33936 .6497 .34287 .65286 .34831 .65492 .3448 .65176 Mtetra
.38 .645 .96 r
.3448 .65176 .34831 .65492 .35383 .65566 .35033 .65251 Mtetra
.522 .708 .956 r
.35033 .65251 .35383 .65566 .35943 .65539 .35593 .65223 Mtetra
.558 .721 .95 r
.35593 .65223 .35943 .65539 .36505 .6548 .36156 .65164 Mtetra
.596 .734 .941 r
.36156 .65164 .36505 .6548 .37071 .65383 .36723 .65066 Mtetra
.607 .738 .938 r
.36723 .65066 .37071 .65383 .37639 .65273 .37291 .64955 Mtetra
.613 .74 .936 r
.37291 .64955 .37639 .65273 .38208 .65156 .37861 .64838 Mtetra
.617 .741 .935 r
.37861 .64838 .38208 .65156 .38779 .65034 .38433 .64715 Mtetra
.38433 .64715 .38779 .65034 .39351 .64911 .39006 .64591 Mtetra
.618 .741 .934 r
.39006 .64591 .39351 .64911 .39925 .64786 .3958 .64466 Mtetra
.3958 .64466 .39925 .64786 .405 .64662 .40156 .64341 Mtetra
.40156 .64341 .405 .64662 .41077 .64538 .40734 .64216 Mtetra
.40734 .64216 .41077 .64538 .41654 .64413 .41312 .64091 Mtetra
.617 .741 .935 r
.41312 .64091 .41654 .64413 .42234 .64289 .41892 .63966 Mtetra
.41892 .63966 .42234 .64289 .42814 .64164 .42474 .63841 Mtetra
.42474 .63841 .42814 .64164 .43396 .6404 .43056 .63715 Mtetra
.616 .741 .935 r
.43056 .63715 .43396 .6404 .4398 .63915 .43641 .6359 Mtetra
.616 .74 .935 r
.43641 .6359 .4398 .63915 .44565 .63791 .44226 .63465 Mtetra
.44226 .63465 .44565 .63791 .45151 .63666 .44813 .6334 Mtetra
.44813 .6334 .45151 .63666 .45739 .63542 .45402 .63215 Mtetra
.615 .74 .935 r
.45402 .63215 .45739 .63542 .46328 .63418 .45992 .6309 Mtetra
.45992 .6309 .46328 .63418 .46919 .63294 .46583 .62965 Mtetra
.46583 .62965 .46919 .63294 .47511 .63169 .47176 .6284 Mtetra
.47176 .6284 .47511 .63169 .48104 .63045 .4777 .62715 Mtetra
.614 .739 .935 r
.4777 .62715 .48104 .63045 .48699 .62921 .48366 .6259 Mtetra
.48366 .6259 .48699 .62921 .49295 .62797 .48963 .62466 Mtetra
.613 .739 .935 r
.48963 .62466 .49295 .62797 .49893 .62674 .49561 .62342 Mtetra
.49561 .62342 .49893 .62674 .50493 .62551 .50162 .62218 Mtetra
.612 .739 .935 r
.50162 .62218 .50493 .62551 .51093 .62428 .50763 .62094 Mtetra
.50763 .62094 .51093 .62428 .51696 .62305 .51366 .6197 Mtetra
.612 .738 .935 r
.51366 .6197 .51696 .62305 .523 .62181 .51971 .61846 Mtetra
.611 .738 .936 r
.51971 .61846 .523 .62181 .52905 .62059 .52577 .61723 Mtetra
.52577 .61723 .52905 .62059 .53512 .61937 .53185 .616 Mtetra
.611 .738 .935 r
.53185 .616 .53512 .61937 .5412 .61814 .53794 .61477 Mtetra
.61 .737 .936 r
.53794 .61477 .5412 .61814 .5473 .61693 .54405 .61355 Mtetra
.54405 .61355 .5473 .61693 .55342 .61572 .55017 .61232 Mtetra
.55017 .61232 .55342 .61572 .55955 .6145 .55631 .6111 Mtetra
.608 .737 .936 r
.55631 .6111 .55955 .6145 .5657 .6133 .56247 .60989 Mtetra
.608 .736 .936 r
.56247 .60989 .5657 .6133 .57186 .61209 .56864 .60868 Mtetra
.56864 .60868 .57186 .61209 .57804 .61089 .57482 .60746 Mtetra
.607 .736 .936 r
.57482 .60746 .57804 .61089 .58423 .60969 .58103 .60626 Mtetra
.606 .735 .936 r
.58103 .60626 .58423 .60969 .59044 .60851 .58724 .60506 Mtetra
.58724 .60506 .59044 .60851 .59667 .60731 .59348 .60386 Mtetra
.605 .735 .936 r
.59348 .60386 .59667 .60731 .60291 .60613 .59973 .60267 Mtetra
.604 .734 .937 r
.59973 .60267 .60291 .60613 .60917 .60496 .606 .60149 Mtetra
.606 .60149 .60917 .60496 .61544 .60378 .61228 .60031 Mtetra
.61228 .60031 .61544 .60378 .62174 .60261 .61858 .59913 Mtetra
.602 .733 .937 r
.61858 .59913 .62174 .60261 .62805 .60146 .6249 .59796 Mtetra
.6249 .59796 .62805 .60146 .63437 .6003 .63124 .5968 Mtetra
.63124 .5968 .63437 .6003 .64072 .59914 .63759 .59563 Mtetra
.6 .732 .937 r
.63759 .59563 .64072 .59914 .64708 .59801 .64396 .59449 Mtetra
.64396 .59449 .64708 .59801 .65345 .59688 .65034 .59335 Mtetra
.65034 .59335 .65345 .59688 .65985 .59574 .65675 .59221 Mtetra
.598 .731 .937 r
.65675 .59221 .65985 .59574 .66626 .59463 .66317 .59109 Mtetra
.597 .731 .938 r
.66317 .59109 .66626 .59463 .67269 .59352 .66961 .58997 Mtetra
.597 .73 .938 r
.66961 .58997 .67269 .59352 .67914 .59242 .67607 .58885 Mtetra
.595 .73 .938 r
.67607 .58885 .67914 .59242 .68561 .59133 .68254 .58775 Mtetra
.595 .729 .938 r
.68254 .58775 .68561 .59133 .69209 .59024 .68904 .58666 Mtetra
.594 .728 .938 r
.68904 .58666 .69209 .59024 .69859 .58917 .69555 .58558 Mtetra
.593 .728 .938 r
.69555 .58558 .69859 .58917 .70512 .58811 .70208 .58451 Mtetra
.592 .728 .938 r
.70208 .58451 .70512 .58811 .71166 .58705 .70863 .58344 Mtetra
.59 .727 .938 r
.70863 .58344 .71166 .58705 .71822 .58602 .7152 .58239 Mtetra
.59 .726 .938 r
.7152 .58239 .71822 .58602 .72479 .58499 .72178 .58135 Mtetra
.589 .726 .938 r
.72178 .58135 .72479 .58499 .73139 .58396 .72839 .58032 Mtetra
.587 .725 .939 r
.72839 .58032 .73139 .58396 .73801 .58296 .73502 .57931 Mtetra
.586 .724 .939 r
.73502 .57931 .73801 .58296 .74464 .58197 .74166 .57831 Mtetra
.585 .724 .939 r
.74166 .57831 .74464 .58197 .7513 .58099 .74833 .57732 Mtetra
.584 .723 .939 r
.74833 .57732 .7513 .58099 .75798 .58003 .75501 .57634 Mtetra
.583 .722 .939 r
.75501 .57634 .75798 .58003 .76467 .57908 .76172 .57538 Mtetra
.581 .721 .939 r
.76172 .57538 .76467 .57908 .77139 .57815 .76845 .57444 Mtetra
.58 .72 .939 r
.76845 .57444 .77139 .57815 .77813 .57723 .7752 .57351 Mtetra
.578 .719 .939 r
.7752 .57351 .77813 .57723 .78489 .57633 .78196 .5726 Mtetra
.577 .718 .939 r
.78196 .5726 .78489 .57633 .79167 .57545 .78876 .57171 Mtetra
.575 .718 .939 r
.78876 .57171 .79167 .57545 .79847 .57458 .79557 .57083 Mtetra
.573 .716 .94 r
.79557 .57083 .79847 .57458 .8053 .57375 .8024 .56999 Mtetra
.571 .715 .94 r
.8024 .56999 .8053 .57375 .81214 .57293 .80926 .56916 Mtetra
.57 .715 .94 r
.80926 .56916 .81214 .57293 .81901 .57213 .81614 .56834 Mtetra
.568 .713 .94 r
.81614 .56834 .81901 .57213 .82591 .57135 .82304 .56756 Mtetra
.567 .712 .94 r
.82304 .56756 .82591 .57135 .83282 .5706 .82996 .56679 Mtetra
.566 .712 .94 r
.82996 .56679 .83282 .5706 .83976 .56985 .83691 .56603 Mtetra
.565 .711 .94 r
.83691 .56603 .83976 .56985 .84672 .56912 .84388 .56529 Mtetra
.567 .711 .939 r
.84388 .56529 .84672 .56912 .8537 .56836 .85087 .56451 Mtetra
.57 .713 .938 r
.85087 .56451 .8537 .56836 .86069 .56754 .85788 .56369 Mtetra
.588 .721 .935 r
.85788 .56369 .86069 .56754 .86768 .56648 .86488 .56262 Mtetra
.604 .729 .932 r
.86488 .56262 .86768 .56648 .87467 .56519 .87188 .56132 Mtetra
.655 .75 .92 r
.87188 .56132 .87467 .56519 .8816 .56311 .87882 .55925 Mtetra
.719 .776 .897 r
.87882 .55925 .8816 .56311 .88841 .55982 .88564 .55597 Mtetra
.76 .79 .878 r
.88564 .55597 .88841 .55982 .89513 .55562 .89238 .55179 Mtetra
.87 .814 .792 r
.89238 .55179 .89513 .55562 .90144 .54761 .89871 .54383 Mtetra
.909 .815 .743 r
.89871 .54383 .90144 .54761 .90747 .53724 .90476 .53351 Mtetra
.944 .809 .681 r
.90476 .53351 .90747 .53724 .91306 .52333 .91039 .51966 Mtetra
.97 .793 .607 r
.91039 .51966 .91306 .52333 .91798 .5039 .91533 .5003 Mtetra
.977 .786 .579 r
.91533 .5003 .91798 .5039 .92252 .48193 .91991 .47839 Mtetra
.932 .563 .284 r
.30673 .58649 .31021 .58973 .31458 .60567 .31109 .60245 Mtetra
.926 .546 .253 r
.31109 .60245 .31458 .60567 .3191 .62034 .31559 .61713 Mtetra
.896 .475 .137 r
.31559 .61713 .3191 .62034 .32388 .63156 .32036 .62837 Mtetra
.827 .359 0 r
.32036 .62837 .32388 .63156 .32887 .64003 .32535 .63685 Mtetra
.715 .211 0 r
.32535 .63685 .32887 .64003 .334 .64666 .33048 .64349 Mtetra
0 .342 .8 r
.33048 .64349 .334 .64666 .33936 .6497 .33584 .64654 Mtetra
.122 .501 .907 r
.33584 .64654 .33936 .6497 .3448 .65176 .34129 .6486 Mtetra
.38 .645 .96 r
.34129 .6486 .3448 .65176 .35033 .65251 .34682 .64934 Mtetra
.522 .708 .956 r
.34682 .64934 .35033 .65251 .35593 .65223 .35243 .64907 Mtetra
.558 .722 .95 r
.35243 .64907 .35593 .65223 .36156 .65164 .35806 .64847 Mtetra
.596 .735 .941 r
.35806 .64847 .36156 .65164 .36723 .65066 .36373 .64748 Mtetra
.607 .738 .938 r
.36373 .64748 .36723 .65066 .37291 .64955 .36943 .64637 Mtetra
.613 .74 .936 r
.36943 .64637 .37291 .64955 .37861 .64838 .37513 .64519 Mtetra
.617 .741 .935 r
.37513 .64519 .37861 .64838 .38433 .64715 .38086 .64395 Mtetra
.38086 .64395 .38433 .64715 .39006 .64591 .38659 .64271 Mtetra
.618 .742 .935 r
.38659 .64271 .39006 .64591 .3958 .64466 .39235 .64145 Mtetra
.618 .741 .935 r
.39235 .64145 .3958 .64466 .40156 .64341 .39811 .6402 Mtetra
.39811 .6402 .40156 .64341 .40734 .64216 .40389 .63894 Mtetra
.40389 .63894 .40734 .64216 .41312 .64091 .40968 .63768 Mtetra
.617 .741 .935 r
.40968 .63768 .41312 .64091 .41892 .63966 .41549 .63642 Mtetra
.41549 .63642 .41892 .63966 .42474 .63841 .42131 .63516 Mtetra
.42131 .63516 .42474 .63841 .43056 .63715 .42715 .6339 Mtetra
.616 .741 .935 r
.42715 .6339 .43056 .63715 .43641 .6359 .433 .63264 Mtetra
.433 .63264 .43641 .6359 .44226 .63465 .43886 .63139 Mtetra
.43886 .63139 .44226 .63465 .44813 .6334 .44474 .63013 Mtetra
.616 .74 .935 r
.44474 .63013 .44813 .6334 .45402 .63215 .45063 .62887 Mtetra
.615 .74 .935 r
.45063 .62887 .45402 .63215 .45992 .6309 .45654 .62761 Mtetra
.45654 .62761 .45992 .6309 .46583 .62965 .46246 .62635 Mtetra
.46246 .62635 .46583 .62965 .47176 .6284 .46839 .6251 Mtetra
.46839 .6251 .47176 .6284 .4777 .62715 .47434 .62384 Mtetra
.614 .74 .935 r
.47434 .62384 .4777 .62715 .48366 .6259 .48031 .62259 Mtetra
.48031 .62259 .48366 .6259 .48963 .62466 .48629 .62133 Mtetra
.613 .739 .935 r
.48629 .62133 .48963 .62466 .49561 .62342 .49228 .62008 Mtetra
.49228 .62008 .49561 .62342 .50162 .62218 .49829 .61884 Mtetra
.612 .739 .936 r
.49829 .61884 .50162 .62218 .50763 .62094 .50432 .61759 Mtetra
.613 .739 .935 r
.50432 .61759 .50763 .62094 .51366 .6197 .51036 .61635 Mtetra
.612 .739 .936 r
.51036 .61635 .51366 .6197 .51971 .61846 .51641 .6151 Mtetra
.611 .738 .936 r
.51641 .6151 .51971 .61846 .52577 .61723 .52248 .61386 Mtetra
.52248 .61386 .52577 .61723 .53185 .616 .52857 .61262 Mtetra
.52857 .61262 .53185 .616 .53794 .61477 .53467 .61138 Mtetra
.61 .737 .936 r
.53467 .61138 .53794 .61477 .54405 .61355 .54078 .61015 Mtetra
.54078 .61015 .54405 .61355 .55017 .61232 .54691 .60892 Mtetra
.54691 .60892 .55017 .61232 .55631 .6111 .55306 .60769 Mtetra
.608 .737 .936 r
.55306 .60769 .55631 .6111 .56247 .60989 .55922 .60647 Mtetra
.55922 .60647 .56247 .60989 .56864 .60868 .5654 .60525 Mtetra
.5654 .60525 .56864 .60868 .57482 .60746 .5716 .60403 Mtetra
.607 .736 .936 r
.5716 .60403 .57482 .60746 .58103 .60626 .57781 .60282 Mtetra
.606 .736 .937 r
.57781 .60282 .58103 .60626 .58724 .60506 .58404 .60161 Mtetra
.606 .736 .936 r
.58404 .60161 .58724 .60506 .59348 .60386 .59028 .6004 Mtetra
.605 .735 .937 r
.59028 .6004 .59348 .60386 .59973 .60267 .59654 .5992 Mtetra
.604 .735 .937 r
.59654 .5992 .59973 .60267 .606 .60149 .60281 .59802 Mtetra
.60281 .59802 .606 .60149 .61228 .60031 .60911 .59682 Mtetra
.604 .734 .937 r
.60911 .59682 .61228 .60031 .61858 .59913 .61542 .59563 Mtetra
.602 .734 .937 r
.61542 .59563 .61858 .59913 .6249 .59796 .62174 .59446 Mtetra
.62174 .59446 .6249 .59796 .63124 .5968 .62809 .59329 Mtetra
.602 .733 .937 r
.62809 .59329 .63124 .5968 .63759 .59563 .63445 .59212 Mtetra
.6 .732 .938 r
.63445 .59212 .63759 .59563 .64396 .59449 .64083 .59097 Mtetra
.6 .732 .937 r
.64083 .59097 .64396 .59449 .65034 .59335 .64722 .58981 Mtetra
.64722 .58981 .65034 .59335 .65675 .59221 .65363 .58866 Mtetra
.598 .731 .938 r
.65363 .58866 .65675 .59221 .66317 .59109 .66007 .58753 Mtetra
.597 .731 .938 r
.66007 .58753 .66317 .59109 .66961 .58997 .66651 .58641 Mtetra
.66651 .58641 .66961 .58997 .67607 .58885 .67298 .58528 Mtetra
.596 .73 .938 r
.67298 .58528 .67607 .58885 .68254 .58775 .67946 .58417 Mtetra
.595 .73 .938 r
.67946 .58417 .68254 .58775 .68904 .58666 .68597 .58307 Mtetra
.594 .729 .938 r
.68597 .58307 .68904 .58666 .69555 .58558 .69249 .58198 Mtetra
.593 .728 .938 r
.69249 .58198 .69555 .58558 .70208 .58451 .69903 .5809 Mtetra
.592 .728 .938 r
.69903 .5809 .70208 .58451 .70863 .58344 .70559 .57982 Mtetra
.59 .727 .939 r
.70559 .57982 .70863 .58344 .7152 .58239 .71216 .57876 Mtetra
.71216 .57876 .7152 .58239 .72178 .58135 .71876 .57771 Mtetra
.589 .726 .939 r
.71876 .57771 .72178 .58135 .72839 .58032 .72538 .57667 Mtetra
.587 .725 .939 r
.72538 .57667 .72839 .58032 .73502 .57931 .73201 .57565 Mtetra
.586 .725 .939 r
.73201 .57565 .73502 .57931 .74166 .57831 .73867 .57464 Mtetra
.585 .724 .939 r
.73867 .57464 .74166 .57831 .74833 .57732 .74534 .57363 Mtetra
.584 .723 .939 r
.74534 .57363 .74833 .57732 .75501 .57634 .75204 .57265 Mtetra
.583 .722 .939 r
.75204 .57265 .75501 .57634 .76172 .57538 .75876 .57168 Mtetra
.581 .722 .939 r
.75876 .57168 .76172 .57538 .76845 .57444 .76549 .57073 Mtetra
.58 .721 .939 r
.76549 .57073 .76845 .57444 .7752 .57351 .77225 .56979 Mtetra
.578 .72 .939 r
.77225 .56979 .7752 .57351 .78196 .5726 .77903 .56887 Mtetra
.577 .719 .94 r
.77903 .56887 .78196 .5726 .78876 .57171 .78583 .56796 Mtetra
.576 .718 .94 r
.78583 .56796 .78876 .57171 .79557 .57083 .79265 .56708 Mtetra
.573 .717 .94 r
.79265 .56708 .79557 .57083 .8024 .56999 .79949 .56622 Mtetra
.572 .716 .94 r
.79949 .56622 .8024 .56999 .80926 .56916 .80636 .56538 Mtetra
.571 .715 .94 r
.80636 .56538 .80926 .56916 .81614 .56834 .81325 .56455 Mtetra
.568 .714 .94 r
.81325 .56455 .81614 .56834 .82304 .56756 .82016 .56375 Mtetra
.567 .713 .94 r
.82016 .56375 .82304 .56756 .82996 .56679 .8271 .56297 Mtetra
.566 .712 .94 r
.8271 .56297 .82996 .56679 .83691 .56603 .83405 .5622 Mtetra
.565 .711 .94 r
.83405 .5622 .83691 .56603 .84388 .56529 .84103 .56144 Mtetra
.567 .712 .939 r
.84103 .56144 .84388 .56529 .85087 .56451 .84803 .56066 Mtetra
.571 .713 .939 r
.84803 .56066 .85087 .56451 .85788 .56369 .85505 .55982 Mtetra
.588 .721 .936 r
.85505 .55982 .85788 .56369 .86488 .56262 .86206 .55875 Mtetra
.604 .729 .933 r
.86206 .55875 .86488 .56262 .87188 .56132 .86907 .55745 Mtetra
.654 .751 .921 r
.86907 .55745 .87188 .56132 .87882 .55925 .87602 .55537 Mtetra
.718 .776 .898 r
.87602 .55537 .87882 .55925 .88564 .55597 .88286 .55211 Mtetra
.758 .79 .879 r
.88286 .55211 .88564 .55597 .89238 .55179 .88962 .54795 Mtetra
.869 .814 .793 r
.88962 .54795 .89238 .55179 .89871 .54383 .89597 .54003 Mtetra
.908 .815 .744 r
.89597 .54003 .89871 .54383 .90476 .53351 .90204 .52976 Mtetra
.943 .809 .682 r
.90204 .52976 .90476 .53351 .91039 .51966 .9077 .51597 Mtetra
.97 .793 .608 r
.9077 .51597 .91039 .51966 .91533 .5003 .91268 .49668 Mtetra
.977 .786 .58 r
.91268 .49668 .91533 .5003 .91991 .47839 .91729 .47483 Mtetra
.932 .563 .284 r
.30323 .58325 .30673 .58649 .31109 .60245 .30758 .59922 Mtetra
.926 .546 .254 r
.30758 .59922 .31109 .60245 .31559 .61713 .31207 .61391 Mtetra
.896 .476 .138 r
.31207 .61391 .31559 .61713 .32036 .62837 .31684 .62517 Mtetra
.828 .36 0 r
.31684 .62517 .32036 .62837 .32535 .63685 .32182 .63366 Mtetra
.717 .213 0 r
.32182 .63366 .32535 .63685 .33048 .64349 .32694 .64031 Mtetra
0 .34 .799 r
.32694 .64031 .33048 .64349 .33584 .64654 .33231 .64337 Mtetra
.119 .5 .906 r
.33231 .64337 .33584 .64654 .34129 .6486 .33776 .64543 Mtetra
.378 .645 .961 r
.33776 .64543 .34129 .6486 .34682 .64934 .3433 .64617 Mtetra
.522 .708 .956 r
.3433 .64617 .34682 .64934 .35243 .64907 .34891 .64589 Mtetra
.557 .722 .95 r
.34891 .64589 .35243 .64907 .35806 .64847 .35455 .64529 Mtetra
.595 .735 .941 r
.35455 .64529 .35806 .64847 .36373 .64748 .36023 .6443 Mtetra
.607 .739 .938 r
.36023 .6443 .36373 .64748 .36943 .64637 .36592 .64318 Mtetra
.613 .74 .937 r
.36592 .64318 .36943 .64637 .37513 .64519 .37164 .64199 Mtetra
.617 .742 .935 r
.37164 .64199 .37513 .64519 .38086 .64395 .37737 .64075 Mtetra
.37737 .64075 .38086 .64395 .38659 .64271 .38311 .6395 Mtetra
.618 .742 .935 r
.38311 .6395 .38659 .64271 .39235 .64145 .38887 .63824 Mtetra
.38887 .63824 .39235 .64145 .39811 .6402 .39465 .63697 Mtetra
.39465 .63697 .39811 .6402 .40389 .63894 .40043 .63571 Mtetra
.40043 .63571 .40389 .63894 .40968 .63768 .40623 .63444 Mtetra
.617 .742 .935 r
.40623 .63444 .40968 .63768 .41549 .63642 .41205 .63318 Mtetra
.617 .741 .935 r
.41205 .63318 .41549 .63642 .42131 .63516 .41788 .63191 Mtetra
.41788 .63191 .42131 .63516 .42715 .6339 .42372 .63064 Mtetra
.616 .741 .935 r
.42372 .63064 .42715 .6339 .433 .63264 .42958 .62938 Mtetra
.42958 .62938 .433 .63264 .43886 .63139 .43545 .62811 Mtetra
.43545 .62811 .43886 .63139 .44474 .63013 .44133 .62685 Mtetra
.44133 .62685 .44474 .63013 .45063 .62887 .44723 .62558 Mtetra
.615 .741 .935 r
.44723 .62558 .45063 .62887 .45654 .62761 .45315 .62432 Mtetra
.45315 .62432 .45654 .62761 .46246 .62635 .45907 .62305 Mtetra
.615 .74 .935 r
.45907 .62305 .46246 .62635 .46839 .6251 .46502 .62179 Mtetra
.46502 .62179 .46839 .6251 .47434 .62384 .47098 .62052 Mtetra
.614 .74 .936 r
.47098 .62052 .47434 .62384 .48031 .62259 .47695 .61926 Mtetra
.47695 .61926 .48031 .62259 .48629 .62133 .48294 .618 Mtetra
.613 .74 .936 r
.48294 .618 .48629 .62133 .49228 .62008 .48894 .61674 Mtetra
.48894 .61674 .49228 .62008 .49829 .61884 .49496 .61549 Mtetra
.612 .739 .936 r
.49496 .61549 .49829 .61884 .50432 .61759 .50099 .61424 Mtetra
.50099 .61424 .50432 .61759 .51036 .61635 .50703 .61298 Mtetra
.50703 .61298 .51036 .61635 .51641 .6151 .5131 .61173 Mtetra
.611 .739 .936 r
.5131 .61173 .51641 .6151 .52248 .61386 .51917 .61048 Mtetra
.51917 .61048 .52248 .61386 .52857 .61262 .52527 .60924 Mtetra
.52527 .60924 .52857 .61262 .53467 .61138 .53138 .60799 Mtetra
.61 .738 .936 r
.53138 .60799 .53467 .61138 .54078 .61015 .5375 .60675 Mtetra
.5375 .60675 .54078 .61015 .54691 .60892 .54364 .60551 Mtetra
.54364 .60551 .54691 .60892 .55306 .60769 .5498 .60427 Mtetra
.608 .737 .937 r
.5498 .60427 .55306 .60769 .55922 .60647 .55597 .60304 Mtetra
.55597 .60304 .55922 .60647 .5654 .60525 .56215 .60182 Mtetra
.608 .737 .936 r
.56215 .60182 .5654 .60525 .5716 .60403 .56836 .60059 Mtetra
.607 .736 .937 r
.56836 .60059 .5716 .60403 .57781 .60282 .57458 .59937 Mtetra
.606 .736 .937 r
.57458 .59937 .57781 .60282 .58404 .60161 .58081 .59816 Mtetra
.58081 .59816 .58404 .60161 .59028 .6004 .58707 .59694 Mtetra
.605 .736 .937 r
.58707 .59694 .59028 .6004 .59654 .5992 .59333 .59573 Mtetra
.604 .735 .937 r
.59333 .59573 .59654 .5992 .60281 .59802 .59962 .59453 Mtetra
.605 .735 .937 r
.59962 .59453 .60281 .59802 .60911 .59682 .60592 .59333 Mtetra
.604 .735 .937 r
.60592 .59333 .60911 .59682 .61542 .59563 .61224 .59213 Mtetra
.602 .734 .937 r
.61224 .59213 .61542 .59563 .62174 .59446 .61857 .59095 Mtetra
.61857 .59095 .62174 .59446 .62809 .59329 .62493 .58977 Mtetra
.62493 .58977 .62809 .59329 .63445 .59212 .6313 .58859 Mtetra
.6 .733 .938 r
.6313 .58859 .63445 .59212 .64083 .59097 .63768 .58743 Mtetra
.63768 .58743 .64083 .59097 .64722 .58981 .64409 .58627 Mtetra
.64409 .58627 .64722 .58981 .65363 .58866 .65051 .58511 Mtetra
.598 .732 .938 r
.65051 .58511 .65363 .58866 .66007 .58753 .65695 .58397 Mtetra
.597 .731 .938 r
.65695 .58397 .66007 .58753 .66651 .58641 .66341 .58283 Mtetra
.66341 .58283 .66651 .58641 .67298 .58528 .66988 .5817 Mtetra
.596 .73 .938 r
.66988 .5817 .67298 .58528 .67946 .58417 .67637 .58058 Mtetra
.595 .73 .938 r
.67637 .58058 .67946 .58417 .68597 .58307 .68289 .57947 Mtetra
.594 .729 .939 r
.68289 .57947 .68597 .58307 .69249 .58198 .68942 .57837 Mtetra
.593 .729 .939 r
.68942 .57837 .69249 .58198 .69903 .5809 .69597 .57728 Mtetra
.592 .729 .939 r
.69597 .57728 .69903 .5809 .70559 .57982 .70253 .57619 Mtetra
.59 .728 .939 r
.70253 .57619 .70559 .57982 .71216 .57876 .70912 .57513 Mtetra
.59 .727 .939 r
.70912 .57513 .71216 .57876 .71876 .57771 .71573 .57407 Mtetra
.589 .727 .939 r
.71573 .57407 .71876 .57771 .72538 .57667 .72235 .57301 Mtetra
.587 .726 .939 r
.72235 .57301 .72538 .57667 .73201 .57565 .729 .57198 Mtetra
.586 .725 .939 r
.729 .57198 .73201 .57565 .73867 .57464 .73566 .57096 Mtetra
.585 .725 .939 r
.73566 .57096 .73867 .57464 .74534 .57363 .74235 .56995 Mtetra
.584 .724 .94 r
.74235 .56995 .74534 .57363 .75204 .57265 .74905 .56896 Mtetra
.583 .723 .94 r
.74905 .56896 .75204 .57265 .75876 .57168 .75578 .56798 Mtetra
.581 .723 .94 r
.75578 .56798 .75876 .57168 .76549 .57073 .76252 .56701 Mtetra
.58 .722 .94 r
.76252 .56701 .76549 .57073 .77225 .56979 .76929 .56606 Mtetra
.578 .721 .94 r
.76929 .56606 .77225 .56979 .77903 .56887 .77608 .56513 Mtetra
.577 .72 .94 r
.77608 .56513 .77903 .56887 .78583 .56796 .78289 .56422 Mtetra
.575 .719 .94 r
.78289 .56422 .78583 .56796 .79265 .56708 .78972 .56332 Mtetra
.573 .718 .941 r
.78972 .56332 .79265 .56708 .79949 .56622 .79658 .56245 Mtetra
.571 .717 .941 r
.79658 .56245 .79949 .56622 .80636 .56538 .80345 .5616 Mtetra
.57 .716 .941 r
.80345 .5616 .80636 .56538 .81325 .56455 .81035 .56076 Mtetra
.568 .715 .941 r
.81035 .56076 .81325 .56455 .82016 .56375 .81727 .55995 Mtetra
.567 .714 .941 r
.81727 .55995 .82016 .56375 .8271 .56297 .82422 .55916 Mtetra
.566 .713 .941 r
.82422 .55916 .8271 .56297 .83405 .5622 .83118 .55838 Mtetra
.565 .713 .941 r
.83118 .55838 .83405 .5622 .84103 .56144 .83817 .55761 Mtetra
.566 .713 .941 r
.83817 .55761 .84103 .56144 .84803 .56066 .84518 .55681 Mtetra
.57 .715 .94 r
.84518 .55681 .84803 .56066 .85505 .55982 .85221 .55597 Mtetra
.588 .723 .937 r
.85221 .55597 .85505 .55982 .86206 .55875 .85923 .55489 Mtetra
.603 .73 .934 r
.85923 .55489 .86206 .55875 .86907 .55745 .86626 .55358 Mtetra
.653 .752 .922 r
.86626 .55358 .86907 .55745 .87602 .55537 .87322 .55151 Mtetra
.717 .777 .899 r
.87322 .55151 .87602 .55537 .88286 .55211 .88008 .54826 Mtetra
.758 .791 .88 r
.88008 .54826 .88286 .55211 .88962 .54795 .88685 .54411 Mtetra
.868 .815 .794 r
.88685 .54411 .88962 .54795 .89597 .54003 .89322 .53623 Mtetra
.907 .816 .746 r
.89322 .53623 .89597 .54003 .90204 .52976 .89932 .526 Mtetra
.943 .81 .683 r
.89932 .526 .90204 .52976 .9077 .51597 .905 .51227 Mtetra
.97 .793 .609 r
.905 .51227 .9077 .51597 .91268 .49668 .91001 .49303 Mtetra
.977 .786 .58 r
.91001 .49303 .91268 .49668 .91729 .47483 .91466 .47123 Mtetra
.932 .563 .285 r
.29973 .58 .30323 .58325 .30758 .59922 .30406 .59598 Mtetra
.926 .546 .254 r
.30406 .59598 .30758 .59922 .31207 .61391 .30854 .61069 Mtetra
.896 .476 .139 r
.30854 .61069 .31207 .61391 .31684 .62517 .3133 .62196 Mtetra
.828 .36 0 r
.3133 .62196 .31684 .62517 .32182 .63366 .31827 .63047 Mtetra
.718 .214 0 r
.31827 .63047 .32182 .63366 .32694 .64031 .3234 .63713 Mtetra
0 .339 .797 r
.3234 .63713 .32694 .64031 .33231 .64337 .32876 .64019 Mtetra
.117 .499 .906 r
.32876 .64019 .33231 .64337 .33776 .64543 .33421 .64225 Mtetra
.377 .645 .961 r
.33421 .64225 .33776 .64543 .3433 .64617 .33976 .64299 Mtetra
.521 .708 .956 r
.33976 .64299 .3433 .64617 .34891 .64589 .34537 .64271 Mtetra
.557 .722 .95 r
.34537 .64271 .34891 .64589 .35455 .64529 .35102 .64211 Mtetra
.595 .735 .942 r
.35102 .64211 .35455 .64529 .36023 .6443 .3567 .64111 Mtetra
.607 .739 .938 r
.3567 .64111 .36023 .6443 .36592 .64318 .36241 .63998 Mtetra
.613 .741 .937 r
.36241 .63998 .36592 .64318 .37164 .64199 .36813 .63879 Mtetra
.617 .742 .935 r
.36813 .63879 .37164 .64199 .37737 .64075 .37387 .63754 Mtetra
.37387 .63754 .37737 .64075 .38311 .6395 .37962 .63628 Mtetra
.618 .742 .935 r
.37962 .63628 .38311 .6395 .38887 .63824 .38539 .63501 Mtetra
.38539 .63501 .38887 .63824 .39465 .63697 .39117 .63374 Mtetra
.39117 .63374 .39465 .63697 .40043 .63571 .39696 .63247 Mtetra
.39696 .63247 .40043 .63571 .40623 .63444 .40277 .6312 Mtetra
.617 .742 .935 r
.40277 .6312 .40623 .63444 .41205 .63318 .40859 .62992 Mtetra
.40859 .62992 .41205 .63318 .41788 .63191 .41443 .62865 Mtetra
.41443 .62865 .41788 .63191 .42372 .63064 .42028 .62738 Mtetra
.616 .741 .935 r
.42028 .62738 .42372 .63064 .42958 .62938 .42614 .6261 Mtetra
.42614 .6261 .42958 .62938 .43545 .62811 .43202 .62483 Mtetra
.43202 .62483 .43545 .62811 .44133 .62685 .43791 .62356 Mtetra
.43791 .62356 .44133 .62685 .44723 .62558 .44382 .62228 Mtetra
.615 .741 .935 r
.44382 .62228 .44723 .62558 .45315 .62432 .44974 .62101 Mtetra
.44974 .62101 .45315 .62432 .45907 .62305 .45568 .61974 Mtetra
.615 .741 .936 r
.45568 .61974 .45907 .62305 .46502 .62179 .46163 .61847 Mtetra
.46163 .61847 .46502 .62179 .47098 .62052 .46759 .6172 Mtetra
.614 .74 .936 r
.46759 .6172 .47098 .62052 .47695 .61926 .47357 .61593 Mtetra
.47357 .61593 .47695 .61926 .48294 .618 .47957 .61466 Mtetra
.613 .74 .936 r
.47957 .61466 .48294 .618 .48894 .61674 .48558 .6134 Mtetra
.48558 .6134 .48894 .61674 .49496 .61549 .4916 .61213 Mtetra
.612 .74 .936 r
.4916 .61213 .49496 .61549 .50099 .61424 .49764 .61088 Mtetra
.49764 .61088 .50099 .61424 .50703 .61298 .5037 .60961 Mtetra
.612 .739 .936 r
.5037 .60961 .50703 .61298 .5131 .61173 .50977 .60835 Mtetra
.611 .739 .936 r
.50977 .60835 .5131 .61173 .51917 .61048 .51586 .6071 Mtetra
.51586 .6071 .51917 .61048 .52527 .60924 .52196 .60584 Mtetra
.52196 .60584 .52527 .60924 .53138 .60799 .52807 .60459 Mtetra
.61 .738 .937 r
.52807 .60459 .53138 .60799 .5375 .60675 .53421 .60334 Mtetra
.53421 .60334 .5375 .60675 .54364 .60551 .54036 .6021 Mtetra
.61 .738 .936 r
.54036 .6021 .54364 .60551 .5498 .60427 .54652 .60085 Mtetra
.608 .738 .937 r
.54652 .60085 .5498 .60427 .55597 .60304 .5527 .59961 Mtetra
.608 .737 .937 r
.5527 .59961 .55597 .60304 .56215 .60182 .55889 .59838 Mtetra
.55889 .59838 .56215 .60182 .56836 .60059 .56511 .59714 Mtetra
.607 .737 .937 r
.56511 .59714 .56836 .60059 .57458 .59937 .57133 .59591 Mtetra
.606 .737 .937 r
.57133 .59591 .57458 .59937 .58081 .59816 .57758 .59469 Mtetra
.57758 .59469 .58081 .59816 .58707 .59694 .58384 .59346 Mtetra
.605 .736 .937 r
.58384 .59346 .58707 .59694 .59333 .59573 .59012 .59225 Mtetra
.604 .736 .937 r
.59012 .59225 .59333 .59573 .59962 .59453 .59641 .59104 Mtetra
.605 .736 .937 r
.59641 .59104 .59962 .59453 .60592 .59333 .60272 .58983 Mtetra
.604 .735 .937 r
.60272 .58983 .60592 .59333 .61224 .59213 .60905 .58863 Mtetra
.602 .735 .938 r
.60905 .58863 .61224 .59213 .61857 .59095 .61539 .58744 Mtetra
.602 .734 .938 r
.61539 .58744 .61857 .59095 .62493 .58977 .62175 .58625 Mtetra
.62175 .58625 .62493 .58977 .6313 .58859 .62813 .58506 Mtetra
.6 .733 .938 r
.62813 .58506 .6313 .58859 .63768 .58743 .63453 .58389 Mtetra
.63453 .58389 .63768 .58743 .64409 .58627 .64094 .58272 Mtetra
.64094 .58272 .64409 .58627 .65051 .58511 .64737 .58155 Mtetra
.598 .732 .938 r
.64737 .58155 .65051 .58511 .65695 .58397 .65382 .5804 Mtetra
.597 .732 .938 r
.65382 .5804 .65695 .58397 .66341 .58283 .66029 .57926 Mtetra
.66029 .57926 .66341 .58283 .66988 .5817 .66677 .57812 Mtetra
.596 .731 .939 r
.66677 .57812 .66988 .5817 .67637 .58058 .67327 .57699 Mtetra
.595 .731 .939 r
.67327 .57699 .67637 .58058 .68289 .57947 .67979 .57587 Mtetra
.594 .73 .939 r
.67979 .57587 .68289 .57947 .68942 .57837 .68633 .57476 Mtetra
.593 .73 .939 r
.68633 .57476 .68942 .57837 .69597 .57728 .69289 .57366 Mtetra
.592 .729 .939 r
.69289 .57366 .69597 .57728 .70253 .57619 .69947 .57256 Mtetra
.59 .728 .939 r
.69947 .57256 .70253 .57619 .70912 .57513 .70607 .57148 Mtetra
.70607 .57148 .70912 .57513 .71573 .57407 .71268 .57041 Mtetra
.589 .727 .939 r
.71268 .57041 .71573 .57407 .72235 .57301 .71932 .56935 Mtetra
.587 .726 .94 r
.71932 .56935 .72235 .57301 .729 .57198 .72597 .56831 Mtetra
.586 .726 .94 r
.72597 .56831 .729 .57198 .73566 .57096 .73265 .56728 Mtetra
.585 .725 .94 r
.73265 .56728 .73566 .57096 .74235 .56995 .73934 .56626 Mtetra
.584 .724 .94 r
.73934 .56626 .74235 .56995 .74905 .56896 .74605 .56526 Mtetra
.583 .724 .94 r
.74605 .56526 .74905 .56896 .75578 .56798 .75279 .56427 Mtetra
.581 .723 .94 r
.75279 .56427 .75578 .56798 .76252 .56701 .75955 .56329 Mtetra
.58 .722 .94 r
.75955 .56329 .76252 .56701 .76929 .56606 .76632 .56233 Mtetra
.578 .721 .94 r
.76632 .56233 .76929 .56606 .77608 .56513 .77312 .56139 Mtetra
.577 .72 .941 r
.77312 .56139 .77608 .56513 .78289 .56422 .77994 .56047 Mtetra
.576 .72 .941 r
.77994 .56047 .78289 .56422 .78972 .56332 .78678 .55956 Mtetra
.573 .718 .941 r
.78678 .55956 .78972 .56332 .79658 .56245 .79365 .55867 Mtetra
.572 .717 .941 r
.79365 .55867 .79658 .56245 .80345 .5616 .80053 .55781 Mtetra
.571 .717 .941 r
.80053 .55781 .80345 .5616 .81035 .56076 .80744 .55696 Mtetra
.568 .715 .941 r
.80744 .55696 .81035 .56076 .81727 .55995 .81437 .55614 Mtetra
.567 .715 .941 r
.81437 .55614 .81727 .55995 .82422 .55916 .82133 .55534 Mtetra
.566 .714 .941 r
.82133 .55534 .82422 .55916 .83118 .55838 .8283 .55455 Mtetra
.565 .713 .941 r
.8283 .55455 .83118 .55838 .83817 .55761 .8353 .55377 Mtetra
.567 .714 .941 r
.8353 .55377 .83817 .55761 .84518 .55681 .84232 .55296 Mtetra
.57 .715 .94 r
.84232 .55296 .84518 .55681 .85221 .55597 .84936 .5521 Mtetra
.587 .723 .937 r
.84936 .5521 .85221 .55597 .85923 .55489 .85639 .55101 Mtetra
.603 .73 .934 r
.85639 .55101 .85923 .55489 .86626 .55358 .86343 .5497 Mtetra
.653 .752 .923 r
.86343 .5497 .86626 .55358 .87322 .55151 .8704 .54763 Mtetra
.716 .777 .9 r
.8704 .54763 .87322 .55151 .88008 .54826 .87727 .54439 Mtetra
.756 .791 .881 r
.87727 .54439 .88008 .54826 .88685 .54411 .88406 .54026 Mtetra
.867 .815 .795 r
.88406 .54026 .88685 .54411 .89322 .53623 .89045 .53241 Mtetra
.907 .816 .747 r
.89045 .53241 .89322 .53623 .89932 .526 .89658 .52223 Mtetra
.942 .81 .684 r
.89658 .52223 .89932 .526 .905 .51227 .90228 .50854 Mtetra
.969 .793 .61 r
.90228 .50854 .905 .51227 .91001 .49303 .90732 .48936 Mtetra
.977 .786 .581 r
.90732 .48936 .91001 .49303 .91466 .47123 .91201 .46761 Mtetra
.932 .563 .285 r
.29621 .57675 .29973 .58 .30406 .59598 .30053 .59274 Mtetra
.926 .546 .254 r
.30053 .59274 .30406 .59598 .30854 .61069 .305 .60746 Mtetra
.897 .476 .14 r
.305 .60746 .30854 .61069 .3133 .62196 .30974 .61875 Mtetra
.829 .361 0 r
.30974 .61875 .3133 .62196 .31827 .63047 .31471 .62726 Mtetra
.719 .215 0 r
.31471 .62726 .31827 .63047 .3234 .63713 .31983 .63393 Mtetra
0 .337 .796 r
.31983 .63393 .3234 .63713 .32876 .64019 .3252 .637 Mtetra
.116 .498 .905 r
.3252 .637 .32876 .64019 .33421 .64225 .33065 .63906 Mtetra
.377 .645 .961 r
.33065 .63906 .33421 .64225 .33976 .64299 .3362 .6398 Mtetra
.521 .709 .957 r
.3362 .6398 .33976 .64299 .34537 .64271 .34182 .63952 Mtetra
.557 .722 .951 r
.34182 .63952 .34537 .64271 .35102 .64211 .34748 .63891 Mtetra
.595 .735 .942 r
.34748 .63891 .35102 .64211 .3567 .64111 .35317 .63791 Mtetra
.607 .739 .939 r
.35317 .63791 .3567 .64111 .36241 .63998 .35888 .63678 Mtetra
.613 .741 .937 r
.35888 .63678 .36241 .63998 .36813 .63879 .36461 .63557 Mtetra
.617 .742 .936 r
.36461 .63557 .36813 .63879 .37387 .63754 .37035 .63432 Mtetra
.617 .742 .935 r
.37035 .63432 .37387 .63754 .37962 .63628 .37611 .63305 Mtetra
.618 .742 .935 r
.37611 .63305 .37962 .63628 .38539 .63501 .38189 .63178 Mtetra
.38189 .63178 .38539 .63501 .39117 .63374 .38767 .6305 Mtetra
.38767 .6305 .39117 .63374 .39696 .63247 .39347 .62922 Mtetra
.39347 .62922 .39696 .63247 .40277 .6312 .39929 .62794 Mtetra
.617 .742 .935 r
.39929 .62794 .40277 .6312 .40859 .62992 .40512 .62666 Mtetra
.40512 .62666 .40859 .62992 .41443 .62865 .41096 .62538 Mtetra
.41096 .62538 .41443 .62865 .42028 .62738 .41682 .6241 Mtetra
.616 .742 .935 r
.41682 .6241 .42028 .62738 .42614 .6261 .42269 .62282 Mtetra
.616 .742 .936 r
.42269 .62282 .42614 .6261 .43202 .62483 .42858 .62154 Mtetra
.616 .742 .935 r
.42858 .62154 .43202 .62483 .43791 .62356 .43448 .62026 Mtetra
.616 .741 .936 r
.43448 .62026 .43791 .62356 .44382 .62228 .44039 .61898 Mtetra
.615 .741 .936 r
.44039 .61898 .44382 .62228 .44974 .62101 .44632 .6177 Mtetra
.44632 .6177 .44974 .62101 .45568 .61974 .45227 .61642 Mtetra
.45227 .61642 .45568 .61974 .46163 .61847 .45822 .61514 Mtetra
.45822 .61514 .46163 .61847 .46759 .6172 .4642 .61386 Mtetra
.614 .741 .936 r
.4642 .61386 .46759 .6172 .47357 .61593 .47019 .61259 Mtetra
.47019 .61259 .47357 .61593 .47957 .61466 .47619 .61131 Mtetra
.613 .74 .936 r
.47619 .61131 .47957 .61466 .48558 .6134 .48221 .61004 Mtetra
.48221 .61004 .48558 .6134 .4916 .61213 .48824 .60877 Mtetra
.612 .74 .936 r
.48824 .60877 .4916 .61213 .49764 .61088 .49429 .6075 Mtetra
.49429 .6075 .49764 .61088 .5037 .60961 .50035 .60623 Mtetra
.50035 .60623 .5037 .60961 .50977 .60835 .50643 .60496 Mtetra
.611 .739 .937 r
.50643 .60496 .50977 .60835 .51586 .6071 .51252 .6037 Mtetra
.611 .739 .936 r
.51252 .6037 .51586 .6071 .52196 .60584 .51863 .60244 Mtetra
.51863 .60244 .52196 .60584 .52807 .60459 .52476 .60117 Mtetra
.61 .739 .937 r
.52476 .60117 .52807 .60459 .53421 .60334 .5309 .59992 Mtetra
.5309 .59992 .53421 .60334 .54036 .6021 .53706 .59867 Mtetra
.61 .738 .937 r
.53706 .59867 .54036 .6021 .54652 .60085 .54323 .59741 Mtetra
.608 .738 .937 r
.54323 .59741 .54652 .60085 .5527 .59961 .54942 .59617 Mtetra
.54942 .59617 .5527 .59961 .55889 .59838 .55562 .59493 Mtetra
.55562 .59493 .55889 .59838 .56511 .59714 .56184 .59368 Mtetra
.607 .737 .937 r
.56184 .59368 .56511 .59714 .57133 .59591 .56808 .59245 Mtetra
.606 .737 .937 r
.56808 .59245 .57133 .59591 .57758 .59469 .57433 .59122 Mtetra
.57433 .59122 .57758 .59469 .58384 .59346 .5806 .58998 Mtetra
.605 .736 .937 r
.5806 .58998 .58384 .59346 .59012 .59225 .58688 .58876 Mtetra
.604 .736 .938 r
.58688 .58876 .59012 .59225 .59641 .59104 .59319 .58754 Mtetra
.59319 .58754 .59641 .59104 .60272 .58983 .59951 .58632 Mtetra
.59951 .58632 .60272 .58983 .60905 .58863 .60584 .58511 Mtetra
.602 .735 .938 r
.60584 .58511 .60905 .58863 .61539 .58744 .61219 .58391 Mtetra
.61219 .58391 .61539 .58744 .62175 .58625 .61856 .58271 Mtetra
.61856 .58271 .62175 .58625 .62813 .58506 .62495 .58151 Mtetra
.6 .734 .938 r
.62495 .58151 .62813 .58506 .63453 .58389 .63136 .58034 Mtetra
.63136 .58034 .63453 .58389 .64094 .58272 .63778 .57916 Mtetra
.63778 .57916 .64094 .58272 .64737 .58155 .64422 .57798 Mtetra
.598 .733 .939 r
.64422 .57798 .64737 .58155 .65382 .5804 .65068 .57682 Mtetra
.597 .732 .939 r
.65068 .57682 .65382 .5804 .66029 .57926 .65715 .57567 Mtetra
.65715 .57567 .66029 .57926 .66677 .57812 .66365 .57452 Mtetra
.596 .732 .939 r
.66365 .57452 .66677 .57812 .67327 .57699 .67016 .57339 Mtetra
.595 .731 .939 r
.67016 .57339 .67327 .57699 .67979 .57587 .67669 .57225 Mtetra
.594 .73 .939 r
.67669 .57225 .67979 .57587 .68633 .57476 .68324 .57114 Mtetra
.593 .73 .939 r
.68324 .57114 .68633 .57476 .69289 .57366 .68981 .57003 Mtetra
.592 .73 .939 r
.68981 .57003 .69289 .57366 .69947 .57256 .69639 .56892 Mtetra
.59 .729 .94 r
.69639 .56892 .69947 .57256 .70607 .57148 .703 .56783 Mtetra
.59 .728 .94 r
.703 .56783 .70607 .57148 .71268 .57041 .70962 .56676 Mtetra
.589 .728 .94 r
.70962 .56676 .71268 .57041 .71932 .56935 .71627 .56568 Mtetra
.587 .727 .94 r
.71627 .56568 .71932 .56935 .72597 .56831 .72293 .56463 Mtetra
.586 .726 .94 r
.72293 .56463 .72597 .56831 .73265 .56728 .72962 .56359 Mtetra
.585 .726 .94 r
.72962 .56359 .73265 .56728 .73934 .56626 .73632 .56256 Mtetra
.584 .725 .94 r
.73632 .56256 .73934 .56626 .74605 .56526 .74304 .56155 Mtetra
.583 .724 .94 r
.74304 .56155 .74605 .56526 .75279 .56427 .74979 .56054 Mtetra
.581 .723 .94 r
.74979 .56054 .75279 .56427 .75955 .56329 .75655 .55956 Mtetra
.58 .723 .941 r
.75655 .55956 .75955 .56329 .76632 .56233 .76334 .55859 Mtetra
.578 .722 .941 r
.76334 .55859 .76632 .56233 .77312 .56139 .77015 .55764 Mtetra
.577 .721 .941 r
.77015 .55764 .77312 .56139 .77994 .56047 .77698 .5567 Mtetra
.576 .72 .941 r
.77698 .5567 .77994 .56047 .78678 .55956 .78383 .55578 Mtetra
.573 .719 .941 r
.78383 .55578 .78678 .55956 .79365 .55867 .7907 .55489 Mtetra
.572 .718 .941 r
.7907 .55489 .79365 .55867 .80053 .55781 .7976 .55402 Mtetra
.571 .717 .941 r
.7976 .55402 .80053 .55781 .80744 .55696 .80452 .55315 Mtetra
.568 .716 .941 r
.80452 .55315 .80744 .55696 .81437 .55614 .81146 .55232 Mtetra
.567 .715 .941 r
.81146 .55232 .81437 .55614 .82133 .55534 .81842 .55151 Mtetra
.566 .714 .941 r
.81842 .55151 .82133 .55534 .8283 .55455 .82541 .5507 Mtetra
.565 .714 .941 r
.82541 .5507 .8283 .55455 .8353 .55377 .83242 .54991 Mtetra
.567 .714 .941 r
.83242 .54991 .8353 .55377 .84232 .55296 .83945 .54909 Mtetra
.57 .716 .94 r
.83945 .54909 .84232 .55296 .84936 .5521 .8465 .54823 Mtetra
.587 .723 .938 r
.8465 .54823 .84936 .5521 .85639 .55101 .85354 .54713 Mtetra
.603 .731 .935 r
.85354 .54713 .85639 .55101 .86343 .5497 .86059 .54581 Mtetra
.652 .752 .923 r
.86059 .54581 .86343 .5497 .8704 .54763 .86758 .54374 Mtetra
.715 .777 .901 r
.86758 .54374 .8704 .54763 .87727 .54439 .87446 .54051 Mtetra
.755 .791 .882 r
.87446 .54051 .87727 .54439 .88406 .54026 .88127 .5364 Mtetra
.866 .815 .797 r
.88127 .5364 .88406 .54026 .89045 .53241 .88768 .52857 Mtetra
.906 .816 .748 r
.88768 .52857 .89045 .53241 .89658 .52223 .89382 .51843 Mtetra
.942 .81 .685 r
.89382 .51843 .89658 .52223 .90228 .50854 .89956 .5048 Mtetra
.969 .794 .611 r
.89956 .5048 .90228 .50854 .90732 .48936 .90463 .48566 Mtetra
.977 .786 .582 r
.90463 .48566 .90732 .48936 .91201 .46761 .90934 .46396 Mtetra
.932 .563 .285 r
.29268 .57349 .29621 .57675 .30053 .59274 .29698 .5895 Mtetra
.926 .546 .255 r
.29698 .5895 .30053 .59274 .305 .60746 .30144 .60423 Mtetra
.897 .477 .141 r
.30144 .60423 .305 .60746 .30974 .61875 .30617 .61553 Mtetra
.829 .362 0 r
.30617 .61553 .30974 .61875 .31471 .62726 .31114 .62406 Mtetra
.72 .216 0 r
.31114 .62406 .31471 .62726 .31983 .63393 .31626 .63074 Mtetra
0 .336 .795 r
.31626 .63074 .31983 .63393 .3252 .637 .32163 .6338 Mtetra
.114 .497 .904 r
.32163 .6338 .3252 .637 .33065 .63906 .32708 .63587 Mtetra
.375 .645 .961 r
.32708 .63587 .33065 .63906 .3362 .6398 .33263 .63661 Mtetra
.52 .709 .957 r
.33263 .63661 .3362 .6398 .34182 .63952 .33826 .63632 Mtetra
.557 .722 .951 r
.33826 .63632 .34182 .63952 .34748 .63891 .34392 .63571 Mtetra
.595 .736 .942 r
.34392 .63571 .34748 .63891 .35317 .63791 .34962 .6347 Mtetra
.606 .739 .939 r
.34962 .6347 .35317 .63791 .35888 .63678 .35534 .63356 Mtetra
.612 .741 .937 r
.35534 .63356 .35888 .63678 .36461 .63557 .36107 .63235 Mtetra
.617 .742 .936 r
.36107 .63235 .36461 .63557 .37035 .63432 .36682 .63109 Mtetra
.617 .743 .936 r
.36682 .63109 .37035 .63432 .37611 .63305 .37259 .62982 Mtetra
.618 .743 .935 r
.37259 .62982 .37611 .63305 .38189 .63178 .37837 .62854 Mtetra
.618 .743 .936 r
.37837 .62854 .38189 .63178 .38767 .6305 .38417 .62725 Mtetra
.618 .743 .935 r
.38417 .62725 .38767 .6305 .39347 .62922 .38997 .62597 Mtetra
.38997 .62597 .39347 .62922 .39929 .62794 .3958 .62468 Mtetra
.617 .742 .936 r
.3958 .62468 .39929 .62794 .40512 .62666 .40163 .62339 Mtetra
.40163 .62339 .40512 .62666 .41096 .62538 .40748 .62211 Mtetra
.40748 .62211 .41096 .62538 .41682 .6241 .41335 .62082 Mtetra
.616 .742 .936 r
.41335 .62082 .41682 .6241 .42269 .62282 .41923 .61953 Mtetra
.41923 .61953 .42269 .62282 .42858 .62154 .42512 .61824 Mtetra
.42512 .61824 .42858 .62154 .43448 .62026 .43103 .61696 Mtetra
.43103 .61696 .43448 .62026 .44039 .61898 .43695 .61567 Mtetra
.615 .742 .936 r
.43695 .61567 .44039 .61898 .44632 .6177 .44289 .61438 Mtetra
.615 .741 .936 r
.44289 .61438 .44632 .6177 .45227 .61642 .44884 .61309 Mtetra
.44884 .61309 .45227 .61642 .45822 .61514 .45481 .61181 Mtetra
.614 .741 .936 r
.45481 .61181 .45822 .61514 .4642 .61386 .46079 .61052 Mtetra
.46079 .61052 .4642 .61386 .47019 .61259 .46678 .60924 Mtetra
.46678 .60924 .47019 .61259 .47619 .61131 .4728 .60796 Mtetra
.613 .741 .936 r
.4728 .60796 .47619 .61131 .48221 .61004 .47882 .60668 Mtetra
.47882 .60668 .48221 .61004 .48824 .60877 .48486 .6054 Mtetra
.612 .74 .937 r
.48486 .6054 .48824 .60877 .49429 .6075 .49092 .60412 Mtetra
.612 .74 .936 r
.49092 .60412 .49429 .6075 .50035 .60623 .49699 .60285 Mtetra
.612 .74 .937 r
.49699 .60285 .50035 .60623 .50643 .60496 .50308 .60157 Mtetra
.611 .74 .937 r
.50308 .60157 .50643 .60496 .51252 .6037 .50918 .6003 Mtetra
.50918 .6003 .51252 .6037 .51863 .60244 .5153 .59903 Mtetra
.5153 .59903 .51863 .60244 .52476 .60117 .52143 .59776 Mtetra
.61 .739 .937 r
.52143 .59776 .52476 .60117 .5309 .59992 .52758 .5965 Mtetra
.52758 .5965 .5309 .59992 .53706 .59867 .53374 .59524 Mtetra
.53374 .59524 .53706 .59867 .54323 .59741 .53992 .59397 Mtetra
.608 .738 .937 r
.53992 .59397 .54323 .59741 .54942 .59617 .54612 .59272 Mtetra
.54612 .59272 .54942 .59617 .55562 .59493 .55233 .59147 Mtetra
.55233 .59147 .55562 .59493 .56184 .59368 .55856 .59021 Mtetra
.607 .738 .938 r
.55856 .59021 .56184 .59368 .56808 .59245 .56481 .58897 Mtetra
.606 .737 .938 r
.56481 .58897 .56808 .59245 .57433 .59122 .57107 .58773 Mtetra
.57107 .58773 .57433 .59122 .5806 .58998 .57735 .58649 Mtetra
.605 .737 .938 r
.57735 .58649 .5806 .58998 .58688 .58876 .58364 .58526 Mtetra
.604 .736 .938 r
.58364 .58526 .58688 .58876 .59319 .58754 .58995 .58404 Mtetra
.58995 .58404 .59319 .58754 .59951 .58632 .59628 .58281 Mtetra
.59628 .58281 .59951 .58632 .60584 .58511 .60262 .58159 Mtetra
.602 .735 .938 r
.60262 .58159 .60584 .58511 .61219 .58391 .60899 .58038 Mtetra
.60899 .58038 .61219 .58391 .61856 .58271 .61536 .57917 Mtetra
.61536 .57917 .61856 .58271 .62495 .58151 .62176 .57797 Mtetra
.6 .734 .939 r
.62176 .57797 .62495 .58151 .63136 .58034 .62817 .57678 Mtetra
.62817 .57678 .63136 .58034 .63778 .57916 .63461 .57559 Mtetra
.63461 .57559 .63778 .57916 .64422 .57798 .64105 .5744 Mtetra
.598 .733 .939 r
.64105 .5744 .64422 .57798 .65068 .57682 .64752 .57324 Mtetra
.597 .733 .939 r
.64752 .57324 .65068 .57682 .65715 .57567 .65401 .57208 Mtetra
.597 .732 .939 r
.65401 .57208 .65715 .57567 .66365 .57452 .66051 .57092 Mtetra
.596 .732 .939 r
.66051 .57092 .66365 .57452 .67016 .57339 .66703 .56978 Mtetra
.595 .732 .939 r
.66703 .56978 .67016 .57339 .67669 .57225 .67357 .56863 Mtetra
.594 .731 .94 r
.67357 .56863 .67669 .57225 .68324 .57114 .68013 .56751 Mtetra
.593 .73 .94 r
.68013 .56751 .68324 .57114 .68981 .57003 .68671 .56639 Mtetra
.592 .73 .94 r
.68671 .56639 .68981 .57003 .69639 .56892 .6933 .56527 Mtetra
.59 .729 .94 r
.6933 .56527 .69639 .56892 .703 .56783 .69992 .56418 Mtetra
.69992 .56418 .703 .56783 .70962 .56676 .70655 .56309 Mtetra
.589 .728 .94 r
.70655 .56309 .70962 .56676 .71627 .56568 .71321 .56201 Mtetra
.587 .727 .94 r
.71321 .56201 .71627 .56568 .72293 .56463 .71988 .56095 Mtetra
.586 .727 .94 r
.71988 .56095 .72293 .56463 .72962 .56359 .72657 .5599 Mtetra
.585 .726 .941 r
.72657 .5599 .72962 .56359 .73632 .56256 .73329 .55885 Mtetra
.584 .726 .941 r
.73329 .55885 .73632 .56256 .74304 .56155 .74002 .55783 Mtetra
.583 .725 .941 r
.74002 .55783 .74304 .56155 .74979 .56054 .74678 .55682 Mtetra
.581 .724 .941 r
.74678 .55682 .74979 .56054 .75655 .55956 .75355 .55583 Mtetra
.58 .724 .941 r
.75355 .55583 .75655 .55956 .76334 .55859 .76035 .55485 Mtetra
.578 .723 .941 r
.76035 .55485 .76334 .55859 .77015 .55764 .76717 .55389 Mtetra
.577 .722 .942 r
.76717 .55389 .77015 .55764 .77698 .5567 .77401 .55294 Mtetra
.576 .721 .942 r
.77401 .55294 .77698 .5567 .78383 .55578 .78087 .55201 Mtetra
.573 .72 .942 r
.78087 .55201 .78383 .55578 .7907 .55489 .78775 .55111 Mtetra
.571 .719 .942 r
.78775 .55111 .7907 .55489 .7976 .55402 .79466 .55022 Mtetra
.57 .718 .942 r
.79466 .55022 .7976 .55402 .80452 .55315 .80158 .54935 Mtetra
.568 .717 .942 r
.80158 .54935 .80452 .55315 .81146 .55232 .80854 .54851 Mtetra
.567 .716 .942 r
.80854 .54851 .81146 .55232 .81842 .55151 .81551 .54768 Mtetra
.566 .716 .942 r
.81551 .54768 .81842 .55151 .82541 .5507 .82251 .54687 Mtetra
.565 .715 .942 r
.82251 .54687 .82541 .5507 .83242 .54991 .82953 .54606 Mtetra
.566 .715 .942 r
.82953 .54606 .83242 .54991 .83945 .54909 .83657 .54524 Mtetra
.57 .717 .941 r
.83657 .54524 .83945 .54909 .8465 .54823 .84363 .54436 Mtetra
.587 .725 .939 r
.84363 .54436 .8465 .54823 .85354 .54713 .85068 .54325 Mtetra
.602 .732 .936 r
.85068 .54325 .85354 .54713 .86059 .54581 .85774 .54193 Mtetra
.651 .753 .924 r
.85774 .54193 .86059 .54581 .86758 .54374 .86474 .53986 Mtetra
.715 .778 .902 r
.86474 .53986 .86758 .54374 .87446 .54051 .87164 .53664 Mtetra
.755 .792 .883 r
.87164 .53664 .87446 .54051 .88127 .5364 .87846 .53254 Mtetra
.866 .816 .798 r
.87846 .53254 .88127 .5364 .88768 .52857 .88489 .52474 Mtetra
.906 .817 .749 r
.88489 .52474 .88768 .52857 .89382 .51843 .89106 .51463 Mtetra
.942 .81 .686 r
.89106 .51463 .89382 .51843 .89956 .5048 .89682 .50104 Mtetra
.969 .794 .612 r
.89682 .50104 .89956 .5048 .90463 .48566 .90192 .48195 Mtetra
.976 .786 .583 r
.90192 .48195 .90463 .48566 .90934 .46396 .90667 .46028 Mtetra
.932 .563 .286 r
.28913 .57022 .29268 .57349 .29698 .5895 .29342 .58624 Mtetra
.926 .546 .255 r
.29342 .58624 .29698 .5895 .30144 .60423 .29786 .60099 Mtetra
.897 .477 .141 r
.29786 .60099 .30144 .60423 .30617 .61553 .30259 .6123 Mtetra
.83 .362 0 r
.30259 .6123 .30617 .61553 .31114 .62406 .30755 .62084 Mtetra
.721 .217 0 r
.30755 .62084 .31114 .62406 .31626 .63074 .31266 .62753 Mtetra
0 .335 .794 r
.31266 .62753 .31626 .63074 .32163 .6338 .31804 .6306 Mtetra
.112 .497 .904 r
.31804 .6306 .32163 .6338 .32708 .63587 .32349 .63267 Mtetra
.375 .645 .961 r
.32349 .63267 .32708 .63587 .33263 .63661 .32905 .63341 Mtetra
.52 .709 .957 r
.32905 .63341 .33263 .63661 .33826 .63632 .33468 .63312 Mtetra
.556 .723 .951 r
.33468 .63312 .33826 .63632 .34392 .63571 .34035 .6325 Mtetra
.595 .736 .942 r
.34035 .6325 .34392 .63571 .34962 .6347 .34606 .63148 Mtetra
.606 .739 .939 r
.34606 .63148 .34962 .6347 .35534 .63356 .35178 .63034 Mtetra
.612 .741 .937 r
.35178 .63034 .35534 .63356 .36107 .63235 .35752 .62912 Mtetra
.617 .743 .936 r
.35752 .62912 .36107 .63235 .36682 .63109 .36328 .62785 Mtetra
.36328 .62785 .36682 .63109 .37259 .62982 .36905 .62657 Mtetra
.618 .743 .936 r
.36905 .62657 .37259 .62982 .37837 .62854 .37484 .62528 Mtetra
.37484 .62528 .37837 .62854 .38417 .62725 .38064 .624 Mtetra
.38064 .624 .38417 .62725 .38997 .62597 .38646 .6227 Mtetra
.38646 .6227 .38997 .62597 .3958 .62468 .39229 .62141 Mtetra
.617 .743 .936 r
.39229 .62141 .3958 .62468 .40163 .62339 .39813 .62011 Mtetra
.39813 .62011 .40163 .62339 .40748 .62211 .40399 .61882 Mtetra
.617 .742 .936 r
.40399 .61882 .40748 .62211 .41335 .62082 .40986 .61752 Mtetra
.616 .742 .936 r
.40986 .61752 .41335 .62082 .41923 .61953 .41575 .61623 Mtetra
.41575 .61623 .41923 .61953 .42512 .61824 .42165 .61494 Mtetra
.42165 .61494 .42512 .61824 .43103 .61696 .42757 .61364 Mtetra
.42757 .61364 .43103 .61696 .43695 .61567 .4335 .61234 Mtetra
.615 .742 .936 r
.4335 .61234 .43695 .61567 .44289 .61438 .43944 .61105 Mtetra
.43944 .61105 .44289 .61438 .44884 .61309 .4454 .60976 Mtetra
.4454 .60976 .44884 .61309 .45481 .61181 .45138 .60846 Mtetra
.614 .741 .936 r
.45138 .60846 .45481 .61181 .46079 .61052 .45737 .60717 Mtetra
.45737 .60717 .46079 .61052 .46678 .60924 .46337 .60588 Mtetra
.46337 .60588 .46678 .60924 .4728 .60796 .46939 .60459 Mtetra
.613 .741 .937 r
.46939 .60459 .4728 .60796 .47882 .60668 .47542 .6033 Mtetra
.47542 .6033 .47882 .60668 .48486 .6054 .48147 .60202 Mtetra
.612 .74 .937 r
.48147 .60202 .48486 .6054 .49092 .60412 .48754 .60074 Mtetra
.48754 .60074 .49092 .60412 .49699 .60285 .49361 .59945 Mtetra
.49361 .59945 .49699 .60285 .50308 .60157 .49971 .59816 Mtetra
.611 .74 .937 r
.49971 .59816 .50308 .60157 .50918 .6003 .50582 .59689 Mtetra
.50582 .59689 .50918 .6003 .5153 .59903 .51195 .59561 Mtetra
.51195 .59561 .5153 .59903 .52143 .59776 .51809 .59433 Mtetra
.61 .739 .937 r
.51809 .59433 .52143 .59776 .52758 .5965 .52424 .59306 Mtetra
.52424 .59306 .52758 .5965 .53374 .59524 .53042 .59179 Mtetra
.53042 .59179 .53374 .59524 .53992 .59397 .53661 .59052 Mtetra
.608 .739 .937 r
.53661 .59052 .53992 .59397 .54612 .59272 .54281 .58926 Mtetra
.608 .738 .938 r
.54281 .58926 .54612 .59272 .55233 .59147 .54903 .588 Mtetra
.608 .738 .937 r
.54903 .588 .55233 .59147 .55856 .59021 .55527 .58674 Mtetra
.607 .738 .938 r
.55527 .58674 .55856 .59021 .56481 .58897 .56152 .58549 Mtetra
.606 .738 .938 r
.56152 .58549 .56481 .58897 .57107 .58773 .56779 .58424 Mtetra
.56779 .58424 .57107 .58773 .57735 .58649 .57408 .58299 Mtetra
.605 .737 .938 r
.57408 .58299 .57735 .58649 .58364 .58526 .58038 .58175 Mtetra
.604 .737 .938 r
.58038 .58175 .58364 .58526 .58995 .58404 .5867 .58052 Mtetra
.5867 .58052 .58995 .58404 .59628 .58281 .59304 .57928 Mtetra
.604 .736 .938 r
.59304 .57928 .59628 .58281 .60262 .58159 .59939 .57805 Mtetra
.602 .736 .939 r
.59939 .57805 .60262 .58159 .60899 .58038 .60576 .57684 Mtetra
.602 .736 .938 r
.60576 .57684 .60899 .58038 .61536 .57917 .61215 .57562 Mtetra
.602 .735 .938 r
.61215 .57562 .61536 .57917 .62176 .57797 .61856 .57441 Mtetra
.6 .735 .939 r
.61856 .57441 .62176 .57797 .62817 .57678 .62498 .57321 Mtetra
.6 .734 .939 r
.62498 .57321 .62817 .57678 .63461 .57559 .63142 .57202 Mtetra
.63142 .57202 .63461 .57559 .64105 .5744 .63788 .57082 Mtetra
.598 .733 .939 r
.63788 .57082 .64105 .5744 .64752 .57324 .64435 .56965 Mtetra
.597 .733 .939 r
.64435 .56965 .64752 .57324 .65401 .57208 .65085 .56848 Mtetra
.65085 .56848 .65401 .57208 .66051 .57092 .65736 .56731 Mtetra
.596 .732 .94 r
.65736 .56731 .66051 .57092 .66703 .56978 .66389 .56616 Mtetra
.595 .732 .94 r
.66389 .56616 .66703 .56978 .67357 .56863 .67044 .56501 Mtetra
.594 .731 .94 r
.67044 .56501 .67357 .56863 .68013 .56751 .67701 .56387 Mtetra
.593 .731 .94 r
.67701 .56387 .68013 .56751 .68671 .56639 .68359 .56274 Mtetra
.592 .731 .94 r
.68359 .56274 .68671 .56639 .6933 .56527 .6902 .56161 Mtetra
.59 .73 .94 r
.6902 .56161 .6933 .56527 .69992 .56418 .69682 .56051 Mtetra
.59 .729 .94 r
.69682 .56051 .69992 .56418 .70655 .56309 .70347 .55941 Mtetra
.589 .729 .94 r
.70347 .55941 .70655 .56309 .71321 .56201 .71013 .55832 Mtetra
.587 .728 .941 r
.71013 .55832 .71321 .56201 .71988 .56095 .71681 .55725 Mtetra
.586 .727 .941 r
.71681 .55725 .71988 .56095 .72657 .5599 .72352 .55619 Mtetra
.585 .727 .941 r
.72352 .55619 .72657 .5599 .73329 .55885 .73024 .55514 Mtetra
.584 .726 .941 r
.73024 .55514 .73329 .55885 .74002 .55783 .73699 .55411 Mtetra
.583 .725 .941 r
.73699 .55411 .74002 .55783 .74678 .55682 .74375 .55309 Mtetra
.581 .725 .941 r
.74375 .55309 .74678 .55682 .75355 .55583 .75054 .55208 Mtetra
.58 .724 .942 r
.75054 .55208 .75355 .55583 .76035 .55485 .75734 .55109 Mtetra
.578 .723 .942 r
.75734 .55109 .76035 .55485 .76717 .55389 .76417 .55012 Mtetra
.577 .722 .942 r
.76417 .55012 .76717 .55389 .77401 .55294 .77102 .54917 Mtetra
.576 .722 .942 r
.77102 .54917 .77401 .55294 .78087 .55201 .77789 .54823 Mtetra
.573 .72 .942 r
.77789 .54823 .78087 .55201 .78775 .55111 .78478 .54731 Mtetra
.572 .719 .942 r
.78478 .54731 .78775 .55111 .79466 .55022 .7917 .54642 Mtetra
.571 .719 .942 r
.7917 .54642 .79466 .55022 .80158 .54935 .79864 .54554 Mtetra
.568 .717 .943 r
.79864 .54554 .80158 .54935 .80854 .54851 .8056 .54468 Mtetra
.567 .717 .943 r
.8056 .54468 .80854 .54851 .81551 .54768 .81259 .54385 Mtetra
.566 .716 .943 r
.81259 .54385 .81551 .54768 .82251 .54687 .81959 .54302 Mtetra
.565 .715 .943 r
.81959 .54302 .82251 .54687 .82953 .54606 .82663 .54221 Mtetra
.566 .716 .942 r
.82663 .54221 .82953 .54606 .83657 .54524 .83368 .54137 Mtetra
.57 .717 .942 r
.83368 .54137 .83657 .54524 .84363 .54436 .84074 .54048 Mtetra
.587 .725 .939 r
.84074 .54048 .84363 .54436 .85068 .54325 .84781 .53937 Mtetra
.602 .732 .936 r
.84781 .53937 .85068 .54325 .85774 .54193 .85488 .53804 Mtetra
.651 .753 .925 r
.85488 .53804 .85774 .54193 .86474 .53986 .86189 .53597 Mtetra
.714 .778 .903 r
.86189 .53597 .86474 .53986 .87164 .53664 .86881 .53275 Mtetra
.754 .792 .884 r
.86881 .53275 .87164 .53664 .87846 .53254 .87564 .52866 Mtetra
.865 .816 .799 r
.87564 .52866 .87846 .53254 .88489 .52474 .88209 .52089 Mtetra
.905 .817 .75 r
.88209 .52089 .88489 .52474 .89106 .51463 .88828 .51081 Mtetra
.941 .811 .687 r
.88828 .51081 .89106 .51463 .89682 .50104 .89407 .49726 Mtetra
.969 .794 .612 r
.89407 .49726 .89682 .50104 .90192 .48195 .8992 .4782 Mtetra
.976 .787 .583 r
.8992 .4782 .90192 .48195 .90667 .46028 .90398 .45658 Mtetra
.932 .563 .286 r
.28557 .56695 .28913 .57022 .29342 .58624 .28984 .58298 Mtetra
.926 .546 .256 r
.28984 .58298 .29342 .58624 .29786 .60099 .29427 .59775 Mtetra
.897 .477 .142 r
.29427 .59775 .29786 .60099 .30259 .6123 .29899 .60907 Mtetra
.83 .363 0 r
.29899 .60907 .30259 .6123 .30755 .62084 .30395 .61762 Mtetra
.722 .218 0 r
.30395 .61762 .30755 .62084 .31266 .62753 .30906 .62431 Mtetra
0 .333 .792 r
.30906 .62431 .31266 .62753 .31804 .6306 .31443 .62739 Mtetra
.11 .496 .904 r
.31443 .62739 .31804 .6306 .32349 .63267 .31989 .62946 Mtetra
.374 .644 .961 r
.31989 .62946 .32349 .63267 .32905 .63341 .32545 .6302 Mtetra
.52 .709 .957 r
.32545 .6302 .32905 .63341 .33468 .63312 .33109 .6299 Mtetra
.556 .723 .951 r
.33109 .6299 .33468 .63312 .34035 .6325 .33677 .62928 Mtetra
.595 .736 .942 r
.33677 .62928 .34035 .6325 .34606 .63148 .34248 .62826 Mtetra
.606 .74 .939 r
.34248 .62826 .34606 .63148 .35178 .63034 .34821 .62711 Mtetra
.612 .742 .937 r
.34821 .62711 .35178 .63034 .35752 .62912 .35396 .62588 Mtetra
.616 .743 .936 r
.35396 .62588 .35752 .62912 .36328 .62785 .35972 .62461 Mtetra
.617 .743 .936 r
.35972 .62461 .36328 .62785 .36905 .62657 .3655 .62332 Mtetra
.618 .743 .936 r
.3655 .62332 .36905 .62657 .37484 .62528 .3713 .62203 Mtetra
.3713 .62203 .37484 .62528 .38064 .624 .37711 .62073 Mtetra
.37711 .62073 .38064 .624 .38646 .6227 .38293 .61943 Mtetra
.38293 .61943 .38646 .6227 .39229 .62141 .38877 .61813 Mtetra
.617 .743 .936 r
.38877 .61813 .39229 .62141 .39813 .62011 .39462 .61683 Mtetra
.39462 .61683 .39813 .62011 .40399 .61882 .40049 .61553 Mtetra
.40049 .61553 .40399 .61882 .40986 .61752 .40637 .61422 Mtetra
.616 .743 .936 r
.40637 .61422 .40986 .61752 .41575 .61623 .41226 .61292 Mtetra
.616 .742 .936 r
.41226 .61292 .41575 .61623 .42165 .61494 .41817 .61162 Mtetra
.41817 .61162 .42165 .61494 .42757 .61364 .42409 .61032 Mtetra
.42409 .61032 .42757 .61364 .4335 .61234 .43003 .60901 Mtetra
.615 .742 .936 r
.43003 .60901 .4335 .61234 .43944 .61105 .43598 .60771 Mtetra
.43598 .60771 .43944 .61105 .4454 .60976 .44195 .60641 Mtetra
.44195 .60641 .4454 .60976 .45138 .60846 .44793 .60511 Mtetra
.614 .742 .936 r
.44793 .60511 .45138 .60846 .45737 .60717 .45393 .60381 Mtetra
.614 .742 .937 r
.45393 .60381 .45737 .60717 .46337 .60588 .45994 .60251 Mtetra
.614 .741 .937 r
.45994 .60251 .46337 .60588 .46939 .60459 .46597 .60121 Mtetra
.613 .741 .937 r
.46597 .60121 .46939 .60459 .47542 .6033 .47201 .59992 Mtetra
.47201 .59992 .47542 .6033 .48147 .60202 .47807 .59863 Mtetra
.612 .741 .937 r
.47807 .59863 .48147 .60202 .48754 .60074 .48414 .59734 Mtetra
.48414 .59734 .48754 .60074 .49361 .59945 .49023 .59605 Mtetra
.49023 .59605 .49361 .59945 .49971 .59816 .49633 .59475 Mtetra
.611 .74 .937 r
.49633 .59475 .49971 .59816 .50582 .59689 .50245 .59347 Mtetra
.50245 .59347 .50582 .59689 .51195 .59561 .50858 .59218 Mtetra
.50858 .59218 .51195 .59561 .51809 .59433 .51473 .59089 Mtetra
.61 .74 .938 r
.51473 .59089 .51809 .59433 .52424 .59306 .5209 .58962 Mtetra
.61 .74 .937 r
.5209 .58962 .52424 .59306 .53042 .59179 .52708 .58834 Mtetra
.52708 .58834 .53042 .59179 .53661 .59052 .53328 .58706 Mtetra
.608 .739 .938 r
.53328 .58706 .53661 .59052 .54281 .58926 .53949 .58579 Mtetra
.53949 .58579 .54281 .58926 .54903 .588 .54572 .58453 Mtetra
.54572 .58453 .54903 .588 .55527 .58674 .55196 .58326 Mtetra
.607 .738 .938 r
.55196 .58326 .55527 .58674 .56152 .58549 .55823 .582 Mtetra
.606 .738 .938 r
.55823 .582 .56152 .58549 .56779 .58424 .5645 .58074 Mtetra
.5645 .58074 .56779 .58424 .57408 .58299 .5708 .57949 Mtetra
.605 .738 .938 r
.5708 .57949 .57408 .58299 .58038 .58175 .57711 .57824 Mtetra
.604 .737 .939 r
.57711 .57824 .58038 .58175 .5867 .58052 .58344 .577 Mtetra
.604 .737 .938 r
.58344 .577 .5867 .58052 .59304 .57928 .58979 .57575 Mtetra
.604 .737 .939 r
.58979 .57575 .59304 .57928 .59939 .57805 .59615 .57452 Mtetra
.602 .736 .939 r
.59615 .57452 .59939 .57805 .60576 .57684 .60253 .57329 Mtetra
.60253 .57329 .60576 .57684 .61215 .57562 .60892 .57207 Mtetra
.60892 .57207 .61215 .57562 .61856 .57441 .61534 .57084 Mtetra
.6 .735 .939 r
.61534 .57084 .61856 .57441 .62498 .57321 .62177 .56964 Mtetra
.62177 .56964 .62498 .57321 .63142 .57202 .62822 .56844 Mtetra
.62822 .56844 .63142 .57202 .63788 .57082 .63469 .56723 Mtetra
.597 .734 .94 r
.63469 .56723 .63788 .57082 .64435 .56965 .64117 .56605 Mtetra
.64117 .56605 .64435 .56965 .65085 .56848 .64768 .56487 Mtetra
.597 .733 .94 r
.64768 .56487 .65085 .56848 .65736 .56731 .6542 .5637 Mtetra
.596 .733 .94 r
.6542 .5637 .65736 .56731 .66389 .56616 .66074 .56253 Mtetra
.595 .733 .94 r
.66074 .56253 .66389 .56616 .67044 .56501 .6673 .56137 Mtetra
.594 .732 .94 r
.6673 .56137 .67044 .56501 .67701 .56387 .67387 .56023 Mtetra
.593 .732 .94 r
.67387 .56023 .67701 .56387 .68359 .56274 .68047 .55909 Mtetra
.592 .731 .94 r
.68047 .55909 .68359 .56274 .6902 .56161 .68708 .55795 Mtetra
.59 .73 .941 r
.68708 .55795 .6902 .56161 .69682 .56051 .69372 .55684 Mtetra
.69372 .55684 .69682 .56051 .70347 .55941 .70037 .55573 Mtetra
.589 .73 .941 r
.70037 .55573 .70347 .55941 .71013 .55832 .70704 .55463 Mtetra
.587 .729 .941 r
.70704 .55463 .71013 .55832 .71681 .55725 .71374 .55356 Mtetra
.586 .728 .941 r
.71374 .55356 .71681 .55725 .72352 .55619 .72045 .55248 Mtetra
.585 .728 .941 r
.72045 .55248 .72352 .55619 .73024 .55514 .72718 .55142 Mtetra
.584 .727 .942 r
.72718 .55142 .73024 .55514 .73699 .55411 .73394 .55038 Mtetra
.583 .726 .942 r
.73394 .55038 .73699 .55411 .74375 .55309 .74071 .54935 Mtetra
.581 .725 .942 r
.74071 .54935 .74375 .55309 .75054 .55208 .74751 .54833 Mtetra
.58 .724 .942 r
.74751 .54833 .75054 .55208 .75734 .55109 .75432 .54733 Mtetra
.578 .724 .942 r
.75432 .54733 .75734 .55109 .76417 .55012 .76116 .54635 Mtetra
.577 .723 .942 r
.76116 .54635 .76417 .55012 .77102 .54917 .76802 .54539 Mtetra
.576 .722 .942 r
.76802 .54539 .77102 .54917 .77789 .54823 .7749 .54443 Mtetra
.573 .721 .942 r
.7749 .54443 .77789 .54823 .78478 .54731 .78181 .54351 Mtetra
.572 .72 .943 r
.78181 .54351 .78478 .54731 .7917 .54642 .78873 .54261 Mtetra
.571 .719 .943 r
.78873 .54261 .7917 .54642 .79864 .54554 .79568 .54171 Mtetra
.568 .718 .943 r
.79568 .54171 .79864 .54554 .8056 .54468 .80265 .54085 Mtetra
.567 .717 .943 r
.80265 .54085 .8056 .54468 .81259 .54385 .80965 .54 Mtetra
.566 .716 .943 r
.80965 .54 .81259 .54385 .81959 .54302 .81667 .53916 Mtetra
.565 .716 .943 r
.81667 .53916 .81959 .54302 .82663 .54221 .82371 .53834 Mtetra
.566 .716 .943 r
.82371 .53834 .82663 .54221 .83368 .54137 .83077 .53749 Mtetra
.57 .718 .942 r
.83077 .53749 .83368 .54137 .84074 .54048 .83785 .53659 Mtetra
.587 .725 .939 r
.83785 .53659 .84074 .54048 .84781 .53937 .84493 .53547 Mtetra
.602 .732 .937 r
.84493 .53547 .84781 .53937 .85488 .53804 .85201 .53414 Mtetra
.65 .753 .925 r
.85201 .53414 .85488 .53804 .86189 .53597 .85903 .53206 Mtetra
.713 .778 .903 r
.85903 .53206 .86189 .53597 .86881 .53275 .86596 .52885 Mtetra
.753 .792 .885 r
.86596 .52885 .86881 .53275 .87564 .52866 .87281 .52477 Mtetra
.864 .816 .8 r
.87281 .52477 .87564 .52866 .88209 .52089 .87928 .51702 Mtetra
.904 .817 .751 r
.87928 .51702 .88209 .52089 .88828 .51081 .8855 .50697 Mtetra
.941 .811 .688 r
.8855 .50697 .88828 .51081 .89407 .49726 .89131 .49345 Mtetra
.968 .794 .613 r
.89131 .49345 .89407 .49726 .8992 .4782 .89647 .47444 Mtetra
.976 .787 .584 r
.89647 .47444 .8992 .4782 .90398 .45658 .90127 .45284 Mtetra
.932 .563 .286 r
.28199 .56367 .28557 .56695 .28984 .58298 .28625 .57972 Mtetra
.926 .546 .256 r
.28625 .57972 .28984 .58298 .29427 .59775 .29067 .5945 Mtetra
.897 .477 .143 r
.29067 .5945 .29427 .59775 .29899 .60907 .29538 .60583 Mtetra
.831 .364 0 r
.29538 .60583 .29899 .60907 .30395 .61762 .30033 .61439 Mtetra
.723 .219 0 r
.30033 .61439 .30395 .61762 .30906 .62431 .30544 .62109 Mtetra
0 .332 .791 r
.30544 .62109 .30906 .62431 .31443 .62739 .31081 .62417 Mtetra
.109 .495 .903 r
.31081 .62417 .31443 .62739 .31989 .62946 .31628 .62624 Mtetra
.373 .644 .961 r
.31628 .62624 .31989 .62946 .32545 .6302 .32184 .62698 Mtetra
.519 .709 .958 r
.32184 .62698 .32545 .6302 .33109 .6299 .32749 .62668 Mtetra
.556 .723 .952 r
.32749 .62668 .33109 .6299 .33677 .62928 .33317 .62605 Mtetra
.595 .736 .943 r
.33317 .62605 .33677 .62928 .34248 .62826 .33888 .62502 Mtetra
.606 .74 .94 r
.33888 .62502 .34248 .62826 .34821 .62711 .34462 .62386 Mtetra
.612 .742 .938 r
.34462 .62386 .34821 .62711 .35396 .62588 .35038 .62264 Mtetra
.616 .743 .936 r
.35038 .62264 .35396 .62588 .35972 .62461 .35615 .62135 Mtetra
.617 .743 .936 r
.35615 .62135 .35972 .62461 .3655 .62332 .36194 .62006 Mtetra
.618 .744 .936 r
.36194 .62006 .3655 .62332 .3713 .62203 .36774 .61876 Mtetra
.617 .743 .936 r
.36774 .61876 .3713 .62203 .37711 .62073 .37356 .61745 Mtetra
.37356 .61745 .37711 .62073 .38293 .61943 .37939 .61615 Mtetra
.37939 .61615 .38293 .61943 .38877 .61813 .38523 .61484 Mtetra
.38523 .61484 .38877 .61813 .39462 .61683 .39109 .61353 Mtetra
.39109 .61353 .39462 .61683 .40049 .61553 .39697 .61222 Mtetra
.39697 .61222 .40049 .61553 .40637 .61422 .40285 .61091 Mtetra
.616 .743 .936 r
.40285 .61091 .40637 .61422 .41226 .61292 .40875 .6096 Mtetra
.40875 .6096 .41226 .61292 .41817 .61162 .41467 .6083 Mtetra
.41467 .6083 .41817 .61162 .42409 .61032 .4206 .60699 Mtetra
.4206 .60699 .42409 .61032 .43003 .60901 .42655 .60567 Mtetra
.615 .743 .936 r
.42655 .60567 .43003 .60901 .43598 .60771 .43251 .60436 Mtetra
.615 .742 .937 r
.43251 .60436 .43598 .60771 .44195 .60641 .43848 .60306 Mtetra
.43848 .60306 .44195 .60641 .44793 .60511 .44447 .60175 Mtetra
.614 .742 .937 r
.44447 .60175 .44793 .60511 .45393 .60381 .45048 .60044 Mtetra
.45048 .60044 .45393 .60381 .45994 .60251 .4565 .59914 Mtetra
.4565 .59914 .45994 .60251 .46597 .60121 .46253 .59783 Mtetra
.613 .742 .937 r
.46253 .59783 .46597 .60121 .47201 .59992 .46858 .59653 Mtetra
.613 .741 .937 r
.46858 .59653 .47201 .59992 .47807 .59863 .47465 .59523 Mtetra
.612 .741 .937 r
.47465 .59523 .47807 .59863 .48414 .59734 .48073 .59393 Mtetra
.48073 .59393 .48414 .59734 .49023 .59605 .48682 .59263 Mtetra
.48682 .59263 .49023 .59605 .49633 .59475 .49293 .59133 Mtetra
.611 .741 .937 r
.49293 .59133 .49633 .59475 .50245 .59347 .49906 .59004 Mtetra
.49906 .59004 .50245 .59347 .50858 .59218 .5052 .58875 Mtetra
.5052 .58875 .50858 .59218 .51473 .59089 .51136 .58745 Mtetra
.61 .74 .938 r
.51136 .58745 .51473 .59089 .5209 .58962 .51753 .58617 Mtetra
.51753 .58617 .5209 .58962 .52708 .58834 .52372 .58488 Mtetra
.52372 .58488 .52708 .58834 .53328 .58706 .52993 .58359 Mtetra
.608 .739 .938 r
.52993 .58359 .53328 .58706 .53949 .58579 .53615 .58232 Mtetra
.53615 .58232 .53949 .58579 .54572 .58453 .54239 .58104 Mtetra
.54239 .58104 .54572 .58453 .55196 .58326 .54864 .57977 Mtetra
.607 .739 .938 r
.54864 .57977 .55196 .58326 .55823 .582 .55492 .5785 Mtetra
.606 .738 .938 r
.55492 .5785 .55823 .582 .5645 .58074 .5612 .57724 Mtetra
.5612 .57724 .5645 .58074 .5708 .57949 .56751 .57597 Mtetra
.605 .738 .939 r
.56751 .57597 .5708 .57949 .57711 .57824 .57383 .57471 Mtetra
.604 .738 .939 r
.57383 .57471 .57711 .57824 .58344 .577 .58016 .57346 Mtetra
.604 .737 .939 r
.58016 .57346 .58344 .577 .58979 .57575 .58652 .57221 Mtetra
.58652 .57221 .58979 .57575 .59615 .57452 .59289 .57097 Mtetra
.602 .737 .939 r
.59289 .57097 .59615 .57452 .60253 .57329 .59928 .56974 Mtetra
.602 .736 .939 r
.59928 .56974 .60253 .57329 .60892 .57207 .60568 .5685 Mtetra
.60568 .5685 .60892 .57207 .61534 .57084 .61211 .56727 Mtetra
.6 .735 .94 r
.61211 .56727 .61534 .57084 .62177 .56964 .61855 .56606 Mtetra
.6 .735 .939 r
.61855 .56606 .62177 .56964 .62822 .56844 .62501 .56485 Mtetra
.62501 .56485 .62822 .56844 .63469 .56723 .63148 .56363 Mtetra
.597 .734 .94 r
.63148 .56363 .63469 .56723 .64117 .56605 .63798 .56244 Mtetra
.63798 .56244 .64117 .56605 .64768 .56487 .64449 .56125 Mtetra
.64449 .56125 .64768 .56487 .6542 .5637 .65102 .56007 Mtetra
.596 .733 .94 r
.65102 .56007 .6542 .5637 .66074 .56253 .65757 .5589 Mtetra
.595 .733 .94 r
.65757 .5589 .66074 .56253 .6673 .56137 .66414 .55773 Mtetra
.594 .732 .941 r
.66414 .55773 .6673 .56137 .67387 .56023 .67073 .55657 Mtetra
.593 .732 .941 r
.67073 .55657 .67387 .56023 .68047 .55909 .67733 .55543 Mtetra
.592 .732 .941 r
.67733 .55543 .68047 .55909 .68708 .55795 .68396 .55428 Mtetra
.59 .731 .941 r
.68396 .55428 .68708 .55795 .69372 .55684 .6906 .55316 Mtetra
.59 .73 .941 r
.6906 .55316 .69372 .55684 .70037 .55573 .69726 .55205 Mtetra
.589 .73 .941 r
.69726 .55205 .70037 .55573 .70704 .55463 .70395 .55094 Mtetra
.587 .729 .941 r
.70395 .55094 .70704 .55463 .71374 .55356 .71065 .54985 Mtetra
.586 .729 .941 r
.71065 .54985 .71374 .55356 .72045 .55248 .71737 .54877 Mtetra
.585 .728 .942 r
.71737 .54877 .72045 .55248 .72718 .55142 .72411 .5477 Mtetra
.584 .727 .942 r
.72411 .5477 .72718 .55142 .73394 .55038 .73088 .54665 Mtetra
.583 .727 .942 r
.73088 .54665 .73394 .55038 .74071 .54935 .73766 .5456 Mtetra
.581 .726 .942 r
.73766 .5456 .74071 .54935 .74751 .54833 .74447 .54458 Mtetra
.58 .725 .942 r
.74447 .54458 .74751 .54833 .75432 .54733 .75129 .54357 Mtetra
.578 .724 .943 r
.75129 .54357 .75432 .54733 .76116 .54635 .75814 .54258 Mtetra
.577 .723 .943 r
.75814 .54258 .76116 .54635 .76802 .54539 .76501 .5416 Mtetra
.576 .723 .943 r
.76501 .5416 .76802 .54539 .7749 .54443 .7719 .54064 Mtetra
.573 .722 .943 r
.7719 .54064 .7749 .54443 .78181 .54351 .77882 .53971 Mtetra
.571 .721 .943 r
.77882 .53971 .78181 .54351 .78873 .54261 .78575 .53879 Mtetra
.57 .72 .943 r
.78575 .53879 .78873 .54261 .79568 .54171 .79271 .53789 Mtetra
.568 .719 .944 r
.79271 .53789 .79568 .54171 .80265 .54085 .7997 .53702 Mtetra
.567 .718 .944 r
.7997 .53702 .80265 .54085 .80965 .54 .8067 .53616 Mtetra
.566 .717 .944 r
.8067 .53616 .80965 .54 .81667 .53916 .81373 .53531 Mtetra
.564 .717 .944 r
.81373 .53531 .81667 .53916 .82371 .53834 .82078 .53447 Mtetra
.566 .717 .943 r
.82078 .53447 .82371 .53834 .83077 .53749 .82785 .53362 Mtetra
.57 .719 .943 r
.82785 .53362 .83077 .53749 .83785 .53659 .83494 .53271 Mtetra
.586 .726 .94 r
.83494 .53271 .83785 .53659 .84493 .53547 .84203 .53158 Mtetra
.601 .733 .937 r
.84203 .53158 .84493 .53547 .85201 .53414 .84913 .53024 Mtetra
.65 .754 .926 r
.84913 .53024 .85201 .53414 .85903 .53206 .85616 .52816 Mtetra
.713 .779 .904 r
.85616 .52816 .85903 .53206 .86596 .52885 .86311 .52495 Mtetra
.752 .793 .886 r
.86311 .52495 .86596 .52885 .87281 .52477 .86997 .52088 Mtetra
.864 .817 .801 r
.86997 .52088 .87281 .52477 .87928 .51702 .87646 .51315 Mtetra
.904 .818 .752 r
.87646 .51315 .87928 .51702 .8855 .50697 .8827 .50313 Mtetra
.94 .811 .689 r
.8827 .50313 .8855 .50697 .89131 .49345 .88853 .48963 Mtetra
.968 .794 .614 r
.88853 .48963 .89131 .49345 .89647 .47444 .89372 .47065 Mtetra
.976 .787 .585 r
.89372 .47065 .89647 .47444 .90127 .45284 .89856 .44908 Mtetra
.931 .563 .286 r
.2784 .56039 .28199 .56367 .28625 .57972 .28265 .57645 Mtetra
.926 .546 .256 r
.28265 .57645 .28625 .57972 .29067 .5945 .28705 .59124 Mtetra
.897 .477 .143 r
.28705 .59124 .29067 .5945 .29538 .60583 .29176 .60259 Mtetra
.831 .364 0 r
.29176 .60259 .29538 .60583 .30033 .61439 .2967 .61115 Mtetra
.724 .22 0 r
.2967 .61115 .30033 .61439 .30544 .62109 .30181 .61786 Mtetra
0 .331 .79 r
.30181 .61786 .30544 .62109 .31081 .62417 .30718 .62094 Mtetra
.107 .495 .903 r
.30718 .62094 .31081 .62417 .31628 .62624 .31265 .62301 Mtetra
.372 .644 .961 r
.31265 .62301 .31628 .62624 .32184 .62698 .31822 .62375 Mtetra
.519 .709 .958 r
.31822 .62375 .32184 .62698 .32749 .62668 .32387 .62344 Mtetra
.556 .723 .952 r
.32387 .62344 .32749 .62668 .33317 .62605 .32955 .62281 Mtetra
.595 .736 .943 r
.32955 .62281 .33317 .62605 .33888 .62502 .33528 .62178 Mtetra
.606 .74 .94 r
.33528 .62178 .33888 .62502 .34462 .62386 .34102 .62061 Mtetra
.612 .742 .938 r
.34102 .62061 .34462 .62386 .35038 .62264 .34679 .61938 Mtetra
.616 .743 .937 r
.34679 .61938 .35038 .62264 .35615 .62135 .35257 .61809 Mtetra
.617 .744 .936 r
.35257 .61809 .35615 .62135 .36194 .62006 .35836 .61679 Mtetra
.618 .744 .936 r
.35836 .61679 .36194 .62006 .36774 .61876 .36417 .61548 Mtetra
.617 .744 .936 r
.36417 .61548 .36774 .61876 .37356 .61745 .36999 .61417 Mtetra
.36999 .61417 .37356 .61745 .37939 .61615 .37583 .61286 Mtetra
.37583 .61286 .37939 .61615 .38523 .61484 .38168 .61154 Mtetra
.617 .743 .936 r
.38168 .61154 .38523 .61484 .39109 .61353 .38755 .61023 Mtetra
.38755 .61023 .39109 .61353 .39697 .61222 .39343 .60891 Mtetra
.39343 .60891 .39697 .61222 .40285 .61091 .39933 .60759 Mtetra
.616 .743 .936 r
.39933 .60759 .40285 .61091 .40875 .6096 .40523 .60628 Mtetra
.616 .743 .937 r
.40523 .60628 .40875 .6096 .41467 .6083 .41116 .60496 Mtetra
.616 .743 .936 r
.41116 .60496 .41467 .6083 .4206 .60699 .4171 .60364 Mtetra
.616 .743 .937 r
.4171 .60364 .4206 .60699 .42655 .60567 .42305 .60233 Mtetra
.615 .743 .937 r
.42305 .60233 .42655 .60567 .43251 .60436 .42902 .60101 Mtetra
.615 .742 .937 r
.42902 .60101 .43251 .60436 .43848 .60306 .435 .59969 Mtetra
.435 .59969 .43848 .60306 .44447 .60175 .441 .59838 Mtetra
.614 .742 .937 r
.441 .59838 .44447 .60175 .45048 .60044 .44701 .59706 Mtetra
.44701 .59706 .45048 .60044 .4565 .59914 .45304 .59575 Mtetra
.45304 .59575 .4565 .59914 .46253 .59783 .45908 .59444 Mtetra
.613 .742 .937 r
.45908 .59444 .46253 .59783 .46858 .59653 .46514 .59313 Mtetra
.46514 .59313 .46858 .59653 .47465 .59523 .47121 .59182 Mtetra
.612 .741 .937 r
.47121 .59182 .47465 .59523 .48073 .59393 .4773 .59052 Mtetra
.4773 .59052 .48073 .59393 .48682 .59263 .48341 .58921 Mtetra
.48341 .58921 .48682 .59263 .49293 .59133 .48952 .5879 Mtetra
.611 .741 .938 r
.48952 .5879 .49293 .59133 .49906 .59004 .49566 .5866 Mtetra
.49566 .5866 .49906 .59004 .5052 .58875 .50181 .5853 Mtetra
.50181 .5853 .5052 .58875 .51136 .58745 .50798 .584 Mtetra
.61 .74 .938 r
.50798 .584 .51136 .58745 .51753 .58617 .51416 .58271 Mtetra
.51416 .58271 .51753 .58617 .52372 .58488 .52036 .58141 Mtetra
.52036 .58141 .52372 .58488 .52993 .58359 .52657 .58012 Mtetra
.608 .74 .938 r
.52657 .58012 .52993 .58359 .53615 .58232 .5328 .57883 Mtetra
.608 .739 .938 r
.5328 .57883 .53615 .58232 .54239 .58104 .53905 .57755 Mtetra
.53905 .57755 .54239 .58104 .54864 .57977 .54531 .57626 Mtetra
.607 .739 .938 r
.54531 .57626 .54864 .57977 .55492 .5785 .55159 .57499 Mtetra
.606 .739 .939 r
.55159 .57499 .55492 .5785 .5612 .57724 .55789 .57372 Mtetra
.606 .739 .938 r
.55789 .57372 .5612 .57724 .56751 .57597 .5642 .57244 Mtetra
.605 .738 .939 r
.5642 .57244 .56751 .57597 .57383 .57471 .57053 .57118 Mtetra
.604 .738 .939 r
.57053 .57118 .57383 .57471 .58016 .57346 .57687 .56992 Mtetra
.57687 .56992 .58016 .57346 .58652 .57221 .58324 .56866 Mtetra
.604 .737 .939 r
.58324 .56866 .58652 .57221 .59289 .57097 .58962 .56741 Mtetra
.602 .737 .939 r
.58962 .56741 .59289 .57097 .59928 .56974 .59602 .56617 Mtetra
.59602 .56617 .59928 .56974 .60568 .5685 .60243 .56493 Mtetra
.60243 .56493 .60568 .5685 .61211 .56727 .60886 .56368 Mtetra
.6 .736 .94 r
.60886 .56368 .61211 .56727 .61855 .56606 .61531 .56247 Mtetra
.61531 .56247 .61855 .56606 .62501 .56485 .62178 .56124 Mtetra
.62178 .56124 .62501 .56485 .63148 .56363 .62827 .56002 Mtetra
.597 .734 .94 r
.62827 .56002 .63148 .56363 .63798 .56244 .63477 .55882 Mtetra
.63477 .55882 .63798 .56244 .64449 .56125 .64129 .55763 Mtetra
.64129 .55763 .64449 .56125 .65102 .56007 .64783 .55643 Mtetra
.596 .734 .94 r
.64783 .55643 .65102 .56007 .65757 .5589 .65439 .55525 Mtetra
.595 .733 .94 r
.65439 .55525 .65757 .5589 .66414 .55773 .66097 .55407 Mtetra
.594 .733 .941 r
.66097 .55407 .66414 .55773 .67073 .55657 .66756 .55291 Mtetra
.593 .732 .941 r
.66756 .55291 .67073 .55657 .67733 .55543 .67418 .55175 Mtetra
.592 .732 .941 r
.67418 .55175 .67733 .55543 .68396 .55428 .68081 .5506 Mtetra
.59 .731 .941 r
.68081 .5506 .68396 .55428 .6906 .55316 .68747 .54947 Mtetra
.68747 .54947 .6906 .55316 .69726 .55205 .69414 .54835 Mtetra
.589 .73 .941 r
.69414 .54835 .69726 .55205 .70395 .55094 .70083 .54723 Mtetra
.587 .729 .942 r
.70083 .54723 .70395 .55094 .71065 .54985 .70755 .54613 Mtetra
.586 .729 .942 r
.70755 .54613 .71065 .54985 .71737 .54877 .71428 .54504 Mtetra
.585 .728 .942 r
.71428 .54504 .71737 .54877 .72411 .5477 .72103 .54396 Mtetra
.584 .727 .942 r
.72103 .54396 .72411 .5477 .73088 .54665 .72781 .5429 Mtetra
.583 .727 .942 r
.72781 .5429 .73088 .54665 .73766 .5456 .7346 .54185 Mtetra
.581 .726 .942 r
.7346 .54185 .73766 .5456 .74447 .54458 .74142 .54081 Mtetra
.58 .725 .943 r
.74142 .54081 .74447 .54458 .75129 .54357 .74825 .5398 Mtetra
.578 .725 .943 r
.74825 .5398 .75129 .54357 .75814 .54258 .75511 .5388 Mtetra
.577 .724 .943 r
.75511 .5388 .75814 .54258 .76501 .5416 .76199 .53781 Mtetra
.576 .723 .943 r
.76199 .53781 .76501 .5416 .7719 .54064 .76889 .53684 Mtetra
.573 .722 .943 r
.76889 .53684 .7719 .54064 .77882 .53971 .77582 .5359 Mtetra
.571 .721 .944 r
.77582 .5359 .77882 .53971 .78575 .53879 .78276 .53497 Mtetra
.57 .721 .944 r
.78276 .53497 .78575 .53879 .79271 .53789 .78973 .53406 Mtetra
.568 .719 .944 r
.78973 .53406 .79271 .53789 .7997 .53702 .79673 .53317 Mtetra
.567 .719 .944 r
.79673 .53317 .7997 .53702 .8067 .53616 .80374 .5323 Mtetra
.566 .718 .944 r
.80374 .5323 .8067 .53616 .81373 .53531 .81078 .53145 Mtetra
.564 .717 .944 r
.81078 .53145 .81373 .53531 .82078 .53447 .81784 .5306 Mtetra
.566 .718 .944 r
.81784 .5306 .82078 .53447 .82785 .53362 .82493 .52973 Mtetra
.57 .719 .943 r
.82493 .52973 .82785 .53362 .83494 .53271 .83203 .52882 Mtetra
.586 .727 .941 r
.83203 .52882 .83494 .53271 .84203 .53158 .83913 .52768 Mtetra
.601 .734 .938 r
.83913 .52768 .84203 .53158 .84913 .53024 .84623 .52633 Mtetra
.649 .755 .926 r
.84623 .52633 .84913 .53024 .85616 .52816 .85328 .52425 Mtetra
.712 .779 .905 r
.85328 .52425 .85616 .52816 .86311 .52495 .86024 .52104 Mtetra
.752 .793 .886 r
.86024 .52104 .86311 .52495 .86997 .52088 .86712 .51698 Mtetra
.864 .817 .802 r
.86712 .51698 .86997 .52088 .87646 .51315 .87363 .50927 Mtetra
.904 .818 .753 r
.87363 .50927 .87646 .51315 .8827 .50313 .87988 .49926 Mtetra
.94 .811 .69 r
.87988 .49926 .8827 .50313 .88853 .48963 .88575 .4858 Mtetra
.968 .794 .614 r
.88575 .4858 .88853 .48963 .89372 .47065 .89096 .46684 Mtetra
.976 .787 .585 r
.89096 .46684 .89372 .47065 .89856 .44908 .89583 .4453 Mtetra
.931 .563 .287 r
.2748 .5571 .2784 .56039 .28265 .57645 .27903 .57317 Mtetra
.926 .546 .257 r
.27903 .57317 .28265 .57645 .28705 .59124 .28342 .58798 Mtetra
.897 .478 .144 r
.28342 .58798 .28705 .59124 .29176 .60259 .28812 .59933 Mtetra
.831 .365 0 r
.28812 .59933 .29176 .60259 .2967 .61115 .29305 .60791 Mtetra
.725 .221 0 r
.29305 .60791 .2967 .61115 .30181 .61786 .29816 .61463 Mtetra
0 .33 .789 r
.29816 .61463 .30181 .61786 .30718 .62094 .30353 .61771 Mtetra
.106 .494 .902 r
.30353 .61771 .30718 .62094 .31265 .62301 .309 .61978 Mtetra
.371 .644 .962 r
.309 .61978 .31265 .62301 .31822 .62375 .31457 .62051 Mtetra
.519 .71 .958 r
.31457 .62051 .31822 .62375 .32387 .62344 .32023 .6202 Mtetra
.556 .723 .952 r
.32023 .6202 .32387 .62344 .32955 .62281 .32592 .61956 Mtetra
.595 .737 .943 r
.32592 .61956 .32955 .62281 .33528 .62178 .33165 .61853 Mtetra
.606 .741 .94 r
.33165 .61853 .33528 .62178 .34102 .62061 .33741 .61736 Mtetra
.612 .742 .938 r
.33741 .61736 .34102 .62061 .34679 .61938 .34318 .61611 Mtetra
.616 .744 .937 r
.34318 .61611 .34679 .61938 .35257 .61809 .34896 .61482 Mtetra
.617 .744 .937 r
.34896 .61482 .35257 .61809 .35836 .61679 .35477 .61351 Mtetra
.618 .744 .936 r
.35477 .61351 .35836 .61679 .36417 .61548 .36058 .61219 Mtetra
.617 .744 .936 r
.36058 .61219 .36417 .61548 .36999 .61417 .36641 .61088 Mtetra
.36641 .61088 .36999 .61417 .37583 .61286 .37226 .60956 Mtetra
.37226 .60956 .37583 .61286 .38168 .61154 .37812 .60823 Mtetra
.617 .744 .937 r
.37812 .60823 .38168 .61154 .38755 .61023 .38399 .60691 Mtetra
.38399 .60691 .38755 .61023 .39343 .60891 .38988 .60559 Mtetra
.38988 .60559 .39343 .60891 .39933 .60759 .39578 .60427 Mtetra
.616 .743 .937 r
.39578 .60427 .39933 .60759 .40523 .60628 .4017 .60294 Mtetra
.4017 .60294 .40523 .60628 .41116 .60496 .40763 .60162 Mtetra
.40763 .60162 .41116 .60496 .4171 .60364 .41358 .6003 Mtetra
.41358 .6003 .4171 .60364 .42305 .60233 .41954 .59897 Mtetra
.615 .743 .937 r
.41954 .59897 .42305 .60233 .42902 .60101 .42552 .59764 Mtetra
.42552 .59764 .42902 .60101 .435 .59969 .43151 .59632 Mtetra
.43151 .59632 .435 .59969 .441 .59838 .43751 .595 Mtetra
.614 .743 .937 r
.43751 .595 .441 .59838 .44701 .59706 .44353 .59368 Mtetra
.44353 .59368 .44701 .59706 .45304 .59575 .44957 .59236 Mtetra
.614 .742 .937 r
.44957 .59236 .45304 .59575 .45908 .59444 .45562 .59104 Mtetra
.613 .742 .937 r
.45562 .59104 .45908 .59444 .46514 .59313 .46168 .58972 Mtetra
.613 .742 .938 r
.46168 .58972 .46514 .59313 .47121 .59182 .46777 .58841 Mtetra
.612 .742 .938 r
.46777 .58841 .47121 .59182 .4773 .59052 .47386 .58709 Mtetra
.47386 .58709 .4773 .59052 .48341 .58921 .47997 .58578 Mtetra
.47997 .58578 .48341 .58921 .48952 .5879 .4861 .58446 Mtetra
.611 .741 .938 r
.4861 .58446 .48952 .5879 .49566 .5866 .49224 .58316 Mtetra
.49224 .58316 .49566 .5866 .50181 .5853 .4984 .58185 Mtetra
.4984 .58185 .50181 .5853 .50798 .584 .50458 .58053 Mtetra
.609 .741 .938 r
.50458 .58053 .50798 .584 .51416 .58271 .51077 .57924 Mtetra
.61 .741 .938 r
.51077 .57924 .51416 .58271 .52036 .58141 .51698 .57794 Mtetra
.51698 .57794 .52036 .58141 .52657 .58012 .5232 .57663 Mtetra
.608 .74 .939 r
.5232 .57663 .52657 .58012 .5328 .57883 .52944 .57534 Mtetra
.52944 .57534 .5328 .57883 .53905 .57755 .53569 .57405 Mtetra
.53569 .57405 .53905 .57755 .54531 .57626 .54196 .57275 Mtetra
.607 .739 .939 r
.54196 .57275 .54531 .57626 .55159 .57499 .54825 .57147 Mtetra
.606 .739 .939 r
.54825 .57147 .55159 .57499 .55789 .57372 .55456 .57019 Mtetra
.55456 .57019 .55789 .57372 .5642 .57244 .56088 .56891 Mtetra
.605 .739 .939 r
.56088 .56891 .5642 .57244 .57053 .57118 .56722 .56764 Mtetra
.604 .738 .939 r
.56722 .56764 .57053 .57118 .57687 .56992 .57357 .56637 Mtetra
.57357 .56637 .57687 .56992 .58324 .56866 .57994 .56511 Mtetra
.57994 .56511 .58324 .56866 .58962 .56741 .58633 .56384 Mtetra
.602 .737 .94 r
.58633 .56384 .58962 .56741 .59602 .56617 .59274 .5626 Mtetra
.59274 .5626 .59602 .56617 .60243 .56493 .59916 .56134 Mtetra
.59916 .56134 .60243 .56493 .60886 .56368 .60561 .56009 Mtetra
.6 .736 .94 r
.60561 .56009 .60886 .56368 .61531 .56247 .61206 .55887 Mtetra
.61206 .55887 .61531 .56247 .62178 .56124 .61854 .55764 Mtetra
.61854 .55764 .62178 .56124 .62827 .56002 .62504 .5564 Mtetra
.597 .735 .941 r
.62504 .5564 .62827 .56002 .63477 .55882 .63155 .5552 Mtetra
.63155 .5552 .63477 .55882 .64129 .55763 .63808 .55399 Mtetra
.596 .735 .941 r
.63808 .55399 .64129 .55763 .64783 .55643 .64463 .5528 Mtetra
.596 .734 .941 r
.64463 .5528 .64783 .55643 .65439 .55525 .6512 .5516 Mtetra
.595 .734 .941 r
.6512 .5516 .65439 .55525 .66097 .55407 .65779 .55042 Mtetra
.593 .733 .941 r
.65779 .55042 .66097 .55407 .66756 .55291 .66439 .54925 Mtetra
.66439 .54925 .66756 .55291 .67418 .55175 .67102 .54808 Mtetra
.592 .733 .941 r
.67102 .54808 .67418 .55175 .68081 .5506 .67766 .54692 Mtetra
.59 .732 .942 r
.67766 .54692 .68081 .5506 .68747 .54947 .68432 .54578 Mtetra
.59 .731 .942 r
.68432 .54578 .68747 .54947 .69414 .54835 .69101 .54464 Mtetra
.589 .731 .942 r
.69101 .54464 .69414 .54835 .70083 .54723 .69771 .54352 Mtetra
.587 .73 .942 r
.69771 .54352 .70083 .54723 .70755 .54613 .70443 .54241 Mtetra
.586 .73 .942 r
.70443 .54241 .70755 .54613 .71428 .54504 .71117 .54131 Mtetra
.585 .729 .942 r
.71117 .54131 .71428 .54504 .72103 .54396 .71794 .54022 Mtetra
.583 .728 .943 r
.71794 .54022 .72103 .54396 .72781 .5429 .72472 .53915 Mtetra
.72472 .53915 .72781 .5429 .7346 .54185 .73152 .53809 Mtetra
.581 .727 .943 r
.73152 .53809 .7346 .54185 .74142 .54081 .73835 .53705 Mtetra
.58 .726 .943 r
.73835 .53705 .74142 .54081 .74825 .5398 .7452 .53602 Mtetra
.578 .725 .943 r
.7452 .53602 .74825 .5398 .75511 .5388 .75207 .53501 Mtetra
.577 .725 .943 r
.75207 .53501 .75511 .5388 .76199 .53781 .75896 .53401 Mtetra
.575 .724 .944 r
.75896 .53401 .76199 .53781 .76889 .53684 .76587 .53303 Mtetra
.573 .723 .944 r
.76587 .53303 .76889 .53684 .77582 .5359 .7728 .53208 Mtetra
.571 .722 .944 r
.7728 .53208 .77582 .5359 .78276 .53497 .77976 .53114 Mtetra
.57 .721 .944 r
.77976 .53114 .78276 .53497 .78973 .53406 .78674 .53022 Mtetra
.568 .72 .944 r
.78674 .53022 .78973 .53406 .79673 .53317 .79374 .52932 Mtetra
.567 .719 .944 r
.79374 .52932 .79673 .53317 .80374 .5323 .80077 .52844 Mtetra
.566 .718 .944 r
.80077 .52844 .80374 .5323 .81078 .53145 .80782 .52757 Mtetra
.564 .718 .945 r
.80782 .52757 .81078 .53145 .81784 .5306 .81489 .52672 Mtetra
.566 .718 .944 r
.81489 .52672 .81784 .5306 .82493 .52973 .82199 .52584 Mtetra
.57 .72 .944 r
.82199 .52584 .82493 .52973 .83203 .52882 .8291 .52491 Mtetra
.586 .727 .941 r
.8291 .52491 .83203 .52882 .83913 .52768 .83621 .52377 Mtetra
.601 .734 .938 r
.83621 .52377 .83913 .52768 .84623 .52633 .84332 .52241 Mtetra
.649 .755 .927 r
.84332 .52241 .84623 .52633 .85328 .52425 .85039 .52033 Mtetra
.712 .779 .905 r
.85039 .52033 .85328 .52425 .86024 .52104 .85736 .51712 Mtetra
.751 .793 .887 r
.85736 .51712 .86024 .52104 .86712 .51698 .86425 .51306 Mtetra
.863 .817 .802 r
.86425 .51306 .86712 .51698 .87363 .50927 .87078 .50537 Mtetra
.903 .818 .753 r
.87078 .50537 .87363 .50927 .87988 .49926 .87706 .49538 Mtetra
.94 .811 .691 r
.87706 .49538 .87988 .49926 .88575 .4858 .88294 .48194 Mtetra
.968 .794 .615 r
.88294 .48194 .88575 .4858 .89096 .46684 .88819 .463 Mtetra
.975 .787 .586 r
.88819 .463 .89096 .46684 .89583 .4453 .89309 .44147 Mtetra
.931 .563 .287 r
.27118 .55381 .2748 .5571 .27903 .57317 .2754 .56989 Mtetra
.926 .546 .257 r
.2754 .56989 .27903 .57317 .28342 .58798 .27978 .5847 Mtetra
.897 .478 .145 r
.27978 .5847 .28342 .58798 .28812 .59933 .28446 .59607 Mtetra
.832 .365 0 r
.28446 .59607 .28812 .59933 .29305 .60791 .28939 .60466 Mtetra
.725 .222 0 r
.28939 .60466 .29305 .60791 .29816 .61463 .29449 .61138 Mtetra
0 .329 .788 r
.29449 .61138 .29816 .61463 .30353 .61771 .29987 .61447 Mtetra
.104 .494 .902 r
.29987 .61447 .30353 .61771 .309 .61978 .30534 .61654 Mtetra
.371 .644 .962 r
.30534 .61654 .309 .61978 .31457 .62051 .31092 .61727 Mtetra
.518 .71 .958 r
.31092 .61727 .31457 .62051 .32023 .6202 .31658 .61695 Mtetra
.555 .724 .952 r
.31658 .61695 .32023 .6202 .32592 .61956 .32228 .61631 Mtetra
.594 .737 .943 r
.32228 .61631 .32592 .61956 .33165 .61853 .32802 .61526 Mtetra
.606 .741 .94 r
.32802 .61526 .33165 .61853 .33741 .61736 .33378 .61409 Mtetra
.612 .743 .938 r
.33378 .61409 .33741 .61736 .34318 .61611 .33955 .61284 Mtetra
.616 .744 .937 r
.33955 .61284 .34318 .61611 .34896 .61482 .34535 .61154 Mtetra
.617 .744 .937 r
.34535 .61154 .34896 .61482 .35477 .61351 .35116 .61022 Mtetra
.618 .744 .937 r
.35116 .61022 .35477 .61351 .36058 .61219 .35698 .6089 Mtetra
.617 .744 .937 r
.35698 .6089 .36058 .61219 .36641 .61088 .36282 .60758 Mtetra
.36282 .60758 .36641 .61088 .37226 .60956 .36867 .60625 Mtetra
.36867 .60625 .37226 .60956 .37812 .60823 .37454 .60492 Mtetra
.37454 .60492 .37812 .60823 .38399 .60691 .38042 .60359 Mtetra
.38042 .60359 .38399 .60691 .38988 .60559 .38632 .60226 Mtetra
.38632 .60226 .38988 .60559 .39578 .60427 .39223 .60093 Mtetra
.616 .744 .937 r
.39223 .60093 .39578 .60427 .4017 .60294 .39815 .5996 Mtetra
.39815 .5996 .4017 .60294 .40763 .60162 .40409 .59827 Mtetra
.40409 .59827 .40763 .60162 .41358 .6003 .41005 .59694 Mtetra
.616 .743 .937 r
.41005 .59694 .41358 .6003 .41954 .59897 .41601 .5956 Mtetra
.615 .743 .937 r
.41601 .5956 .41954 .59897 .42552 .59764 .422 .59427 Mtetra
.422 .59427 .42552 .59764 .43151 .59632 .428 .59294 Mtetra
.428 .59294 .43151 .59632 .43751 .595 .43401 .59161 Mtetra
.614 .743 .937 r
.43401 .59161 .43751 .595 .44353 .59368 .44004 .59028 Mtetra
.44004 .59028 .44353 .59368 .44957 .59236 .44608 .58896 Mtetra
.44608 .58896 .44957 .59236 .45562 .59104 .45214 .58763 Mtetra
.613 .742 .938 r
.45214 .58763 .45562 .59104 .46168 .58972 .45821 .5863 Mtetra
.45821 .5863 .46168 .58972 .46777 .58841 .4643 .58498 Mtetra
.612 .742 .938 r
.4643 .58498 .46777 .58841 .47386 .58709 .47041 .58366 Mtetra
.47041 .58366 .47386 .58709 .47997 .58578 .47653 .58234 Mtetra
.47653 .58234 .47997 .58578 .4861 .58446 .48266 .58101 Mtetra
.611 .741 .938 r
.48266 .58101 .4861 .58446 .49224 .58316 .48882 .5797 Mtetra
.48882 .5797 .49224 .58316 .4984 .58185 .49498 .57838 Mtetra
.49498 .57838 .4984 .58185 .50458 .58053 .50117 .57706 Mtetra
.609 .741 .938 r
.50117 .57706 .50458 .58053 .51077 .57924 .50737 .57576 Mtetra
.61 .741 .938 r
.50737 .57576 .51077 .57924 .51698 .57794 .51358 .57445 Mtetra
.51358 .57445 .51698 .57794 .5232 .57663 .51981 .57314 Mtetra
.608 .74 .939 r
.51981 .57314 .5232 .57663 .52944 .57534 .52606 .57184 Mtetra
.52606 .57184 .52944 .57534 .53569 .57405 .53232 .57054 Mtetra
.53232 .57054 .53569 .57405 .54196 .57275 .5386 .56924 Mtetra
.607 .74 .939 r
.5386 .56924 .54196 .57275 .54825 .57147 .5449 .56795 Mtetra
.606 .739 .939 r
.5449 .56795 .54825 .57147 .55456 .57019 .55121 .56666 Mtetra
.55121 .56666 .55456 .57019 .56088 .56891 .55754 .56537 Mtetra
.605 .739 .939 r
.55754 .56537 .56088 .56891 .56722 .56764 .56389 .56409 Mtetra
.604 .739 .94 r
.56389 .56409 .56722 .56764 .57357 .56637 .57026 .56281 Mtetra
.604 .739 .939 r
.57026 .56281 .57357 .56637 .57994 .56511 .57664 .56154 Mtetra
.604 .738 .94 r
.57664 .56154 .57994 .56511 .58633 .56384 .58303 .56027 Mtetra
.602 .738 .94 r
.58303 .56027 .58633 .56384 .59274 .5626 .58945 .55901 Mtetra
.58945 .55901 .59274 .5626 .59916 .56134 .59588 .55775 Mtetra
.602 .737 .94 r
.59588 .55775 .59916 .56134 .60561 .56009 .60233 .55649 Mtetra
.6 .737 .94 r
.60233 .55649 .60561 .56009 .61206 .55887 .6088 .55526 Mtetra
.6088 .55526 .61206 .55887 .61854 .55764 .61529 .55402 Mtetra
.61529 .55402 .61854 .55764 .62504 .5564 .62179 .55278 Mtetra
.597 .735 .941 r
.62179 .55278 .62504 .5564 .63155 .5552 .62832 .55156 Mtetra
.62832 .55156 .63155 .5552 .63808 .55399 .63486 .55035 Mtetra
.596 .735 .941 r
.63486 .55035 .63808 .55399 .64463 .5528 .64142 .54914 Mtetra
.64142 .54914 .64463 .5528 .6512 .5516 .64799 .54794 Mtetra
.595 .734 .941 r
.64799 .54794 .6512 .5516 .65779 .55042 .65459 .54675 Mtetra
.593 .734 .941 r
.65459 .54675 .65779 .55042 .66439 .54925 .6612 .54557 Mtetra
.593 .733 .942 r
.6612 .54557 .66439 .54925 .67102 .54808 .66784 .54439 Mtetra
.592 .733 .942 r
.66784 .54439 .67102 .54808 .67766 .54692 .67449 .54322 Mtetra
.59 .732 .942 r
.67449 .54322 .67766 .54692 .68432 .54578 .68117 .54208 Mtetra
.68117 .54208 .68432 .54578 .69101 .54464 .68786 .54093 Mtetra
.589 .731 .942 r
.68786 .54093 .69101 .54464 .69771 .54352 .69457 .53979 Mtetra
.587 .73 .942 r
.69457 .53979 .69771 .54352 .70443 .54241 .7013 .53868 Mtetra
.586 .73 .943 r
.7013 .53868 .70443 .54241 .71117 .54131 .70806 .53757 Mtetra
.585 .729 .943 r
.70806 .53757 .71117 .54131 .71794 .54022 .71483 .53647 Mtetra
.584 .729 .943 r
.71483 .53647 .71794 .54022 .72472 .53915 .72162 .53539 Mtetra
.583 .728 .943 r
.72162 .53539 .72472 .53915 .73152 .53809 .72844 .53432 Mtetra
.581 .727 .943 r
.72844 .53432 .73152 .53809 .73835 .53705 .73527 .53327 Mtetra
.58 .727 .943 r
.73527 .53327 .73835 .53705 .7452 .53602 .74213 .53223 Mtetra
.578 .726 .944 r
.74213 .53223 .7452 .53602 .75207 .53501 .74901 .53121 Mtetra
.577 .725 .944 r
.74901 .53121 .75207 .53501 .75896 .53401 .75591 .53021 Mtetra
.575 .724 .944 r
.75591 .53021 .75896 .53401 .76587 .53303 .76283 .52921 Mtetra
.573 .723 .944 r
.76283 .52921 .76587 .53303 .7728 .53208 .76978 .52825 Mtetra
.571 .722 .944 r
.76978 .52825 .7728 .53208 .77976 .53114 .77674 .52731 Mtetra
.57 .722 .945 r
.77674 .52731 .77976 .53114 .78674 .53022 .78373 .52637 Mtetra
.568 .721 .945 r
.78373 .52637 .78674 .53022 .79374 .52932 .79075 .52547 Mtetra
.567 .72 .945 r
.79075 .52547 .79374 .52932 .80077 .52844 .79779 .52458 Mtetra
.565 .719 .945 r
.79779 .52458 .80077 .52844 .80782 .52757 .80485 .5237 Mtetra
.564 .719 .945 r
.80485 .5237 .80782 .52757 .81489 .52672 .81193 .52284 Mtetra
.566 .719 .945 r
.81193 .52284 .81489 .52672 .82199 .52584 .81903 .52195 Mtetra
.569 .721 .944 r
.81903 .52195 .82199 .52584 .8291 .52491 .82616 .52101 Mtetra
.586 .728 .942 r
.82616 .52101 .8291 .52491 .83621 .52377 .83328 .51986 Mtetra
.601 .735 .939 r
.83328 .51986 .83621 .52377 .84332 .52241 .84041 .51849 Mtetra
.648 .756 .928 r
.84041 .51849 .84332 .52241 .85039 .52033 .84748 .51641 Mtetra
.711 .78 .906 r
.84748 .51641 .85039 .52033 .85736 .51712 .85447 .5132 Mtetra
.751 .794 .888 r
.85447 .5132 .85736 .51712 .86425 .51306 .86138 .50914 Mtetra
.863 .818 .803 r
.86138 .50914 .86425 .51306 .87078 .50537 .86792 .50146 Mtetra
.903 .819 .754 r
.86792 .50146 .87078 .50537 .87706 .49538 .87422 .49148 Mtetra
.94 .812 .691 r
.87422 .49148 .87706 .49538 .88294 .48194 .88013 .47806 Mtetra
.968 .795 .615 r
.88013 .47806 .88294 .48194 .88819 .463 .8854 .45914 Mtetra
.975 .787 .586 r
.8854 .45914 .88819 .463 .89309 .44147 .89033 .43763 Mtetra
.931 .563 .287 r
.26755 .5505 .27118 .55381 .2754 .56989 .27175 .5666 Mtetra
.926 .546 .257 r
.27175 .5666 .2754 .56989 .27978 .5847 .27612 .58143 Mtetra
.897 .478 .145 r
.27612 .58143 .27978 .5847 .28446 .59607 .28079 .59281 Mtetra
.832 .365 0 r
.28079 .59281 .28446 .59607 .28939 .60466 .28572 .6014 Mtetra
.726 .223 0 r
.28572 .6014 .28939 .60466 .29449 .61138 .29081 .60813 Mtetra
0 .328 .787 r
.29081 .60813 .29449 .61138 .29987 .61447 .29619 .61121 Mtetra
.103 .493 .902 r
.29619 .61121 .29987 .61447 .30534 .61654 .30167 .61328 Mtetra
.37 .644 .962 r
.30167 .61328 .30534 .61654 .31092 .61727 .30725 .61401 Mtetra
.518 .71 .958 r
.30725 .61401 .31092 .61727 .31658 .61695 .31292 .61369 Mtetra
.555 .724 .952 r
.31292 .61369 .31658 .61695 .32228 .61631 .31862 .61304 Mtetra
.594 .737 .943 r
.31862 .61304 .32228 .61631 .32802 .61526 .32437 .61199 Mtetra
.606 .741 .94 r
.32437 .61199 .32802 .61526 .33378 .61409 .33013 .61081 Mtetra
.612 .743 .938 r
.33013 .61081 .33378 .61409 .33955 .61284 .33592 .60955 Mtetra
.616 .744 .937 r
.33592 .60955 .33955 .61284 .34535 .61154 .34172 .60824 Mtetra
.617 .744 .937 r
.34172 .60824 .34535 .61154 .35116 .61022 .34754 .60693 Mtetra
.618 .744 .937 r
.34754 .60693 .35116 .61022 .35698 .6089 .35337 .60559 Mtetra
.617 .744 .937 r
.35337 .60559 .35698 .6089 .36282 .60758 .35921 .60426 Mtetra
.35921 .60426 .36282 .60758 .36867 .60625 .36507 .60293 Mtetra
.36507 .60293 .36867 .60625 .37454 .60492 .37095 .60159 Mtetra
.37095 .60159 .37454 .60492 .38042 .60359 .37684 .60025 Mtetra
.37684 .60025 .38042 .60359 .38632 .60226 .38274 .59892 Mtetra
.38274 .59892 .38632 .60226 .39223 .60093 .38866 .59758 Mtetra
.616 .744 .937 r
.38866 .59758 .39223 .60093 .39815 .5996 .39459 .59624 Mtetra
.39459 .59624 .39815 .5996 .40409 .59827 .40054 .59491 Mtetra
.40054 .59491 .40409 .59827 .41005 .59694 .4065 .59357 Mtetra
.4065 .59357 .41005 .59694 .41601 .5956 .41247 .59223 Mtetra
.615 .743 .937 r
.41247 .59223 .41601 .5956 .422 .59427 .41847 .59089 Mtetra
.41847 .59089 .422 .59427 .428 .59294 .42447 .58955 Mtetra
.42447 .58955 .428 .59294 .43401 .59161 .43049 .58821 Mtetra
.614 .743 .937 r
.43049 .58821 .43401 .59161 .44004 .59028 .43653 .58688 Mtetra
.614 .743 .938 r
.43653 .58688 .44004 .59028 .44608 .58896 .44258 .58554 Mtetra
.44258 .58554 .44608 .58896 .45214 .58763 .44865 .5842 Mtetra
.613 .743 .938 r
.44865 .5842 .45214 .58763 .45821 .5863 .45473 .58287 Mtetra
.613 .742 .938 r
.45473 .58287 .45821 .5863 .4643 .58498 .46083 .58154 Mtetra
.612 .742 .938 r
.46083 .58154 .4643 .58498 .47041 .58366 .46694 .58022 Mtetra
.46694 .58022 .47041 .58366 .47653 .58234 .47307 .57888 Mtetra
.47307 .57888 .47653 .58234 .48266 .58101 .47921 .57755 Mtetra
.611 .742 .938 r
.47921 .57755 .48266 .58101 .48882 .5797 .48537 .57623 Mtetra
.48537 .57623 .48882 .5797 .49498 .57838 .49155 .57491 Mtetra
.49155 .57491 .49498 .57838 .50117 .57706 .49774 .57358 Mtetra
.609 .741 .939 r
.49774 .57358 .50117 .57706 .50737 .57576 .50395 .57227 Mtetra
.61 .741 .939 r
.50395 .57227 .50737 .57576 .51358 .57445 .51017 .57095 Mtetra
.61 .741 .938 r
.51017 .57095 .51358 .57445 .51981 .57314 .51641 .56963 Mtetra
.608 .74 .939 r
.51641 .56963 .51981 .57314 .52606 .57184 .52267 .56832 Mtetra
.52267 .56832 .52606 .57184 .53232 .57054 .52894 .56702 Mtetra
.52894 .56702 .53232 .57054 .5386 .56924 .53523 .56571 Mtetra
.607 .74 .939 r
.53523 .56571 .5386 .56924 .5449 .56795 .54153 .56441 Mtetra
.606 .74 .939 r
.54153 .56441 .5449 .56795 .55121 .56666 .54786 .56311 Mtetra
.54786 .56311 .55121 .56666 .55754 .56537 .5542 .56181 Mtetra
.605 .739 .939 r
.5542 .56181 .55754 .56537 .56389 .56409 .56055 .56052 Mtetra
.604 .739 .94 r
.56055 .56052 .56389 .56409 .57026 .56281 .56692 .55924 Mtetra
.56692 .55924 .57026 .56281 .57664 .56154 .57331 .55796 Mtetra
.604 .738 .94 r
.57331 .55796 .57664 .56154 .58303 .56027 .57972 .55668 Mtetra
.602 .738 .94 r
.57972 .55668 .58303 .56027 .58945 .55901 .58615 .55542 Mtetra
.58615 .55542 .58945 .55901 .59588 .55775 .59259 .55415 Mtetra
.59259 .55415 .59588 .55775 .60233 .55649 .59905 .55288 Mtetra
.6 .737 .941 r
.59905 .55288 .60233 .55649 .6088 .55526 .60553 .55164 Mtetra
.6 .737 .94 r
.60553 .55164 .6088 .55526 .61529 .55402 .61202 .55039 Mtetra
.61202 .55039 .61529 .55402 .62179 .55278 .61854 .54914 Mtetra
.597 .736 .941 r
.61854 .54914 .62179 .55278 .62832 .55156 .62507 .54792 Mtetra
.597 .735 .941 r
.62507 .54792 .62832 .55156 .63486 .55035 .63162 .5467 Mtetra
.596 .735 .941 r
.63162 .5467 .63486 .55035 .64142 .54914 .63819 .54548 Mtetra
.63819 .54548 .64142 .54914 .64799 .54794 .64477 .54427 Mtetra
.595 .734 .941 r
.64477 .54427 .64799 .54794 .65459 .54675 .65138 .54307 Mtetra
.594 .734 .942 r
.65138 .54307 .65459 .54675 .6612 .54557 .658 .54188 Mtetra
.593 .733 .942 r
.658 .54188 .6612 .54557 .66784 .54439 .66465 .5407 Mtetra
.592 .733 .942 r
.66465 .5407 .66784 .54439 .67449 .54322 .67131 .53952 Mtetra
.59 .732 .942 r
.67131 .53952 .67449 .54322 .68117 .54208 .67799 .53836 Mtetra
.67799 .53836 .68117 .54208 .68786 .54093 .6847 .53721 Mtetra
.589 .732 .942 r
.6847 .53721 .68786 .54093 .69457 .53979 .69142 .53606 Mtetra
.587 .731 .943 r
.69142 .53606 .69457 .53979 .7013 .53868 .69816 .53494 Mtetra
.586 .73 .943 r
.69816 .53494 .7013 .53868 .70806 .53757 .70492 .53382 Mtetra
.585 .73 .943 r
.70492 .53382 .70806 .53757 .71483 .53647 .71171 .53271 Mtetra
.584 .729 .943 r
.71171 .53271 .71483 .53647 .72162 .53539 .71851 .53162 Mtetra
.583 .728 .943 r
.71851 .53162 .72162 .53539 .72844 .53432 .72534 .53054 Mtetra
.581 .728 .943 r
.72534 .53054 .72844 .53432 .73527 .53327 .73218 .52948 Mtetra
.58 .727 .944 r
.73218 .52948 .73527 .53327 .74213 .53223 .73905 .52843 Mtetra
.578 .726 .944 r
.73905 .52843 .74213 .53223 .74901 .53121 .74594 .5274 Mtetra
.577 .725 .944 r
.74594 .5274 .74901 .53121 .75591 .53021 .75285 .52639 Mtetra
.575 .725 .944 r
.75285 .52639 .75591 .53021 .76283 .52921 .75978 .52539 Mtetra
.573 .724 .945 r
.75978 .52539 .76283 .52921 .76978 .52825 .76674 .52442 Mtetra
.571 .723 .945 r
.76674 .52442 .76978 .52825 .77674 .52731 .77372 .52346 Mtetra
.57 .722 .945 r
.77372 .52346 .77674 .52731 .78373 .52637 .78072 .52252 Mtetra
.568 .721 .945 r
.78072 .52252 .78373 .52637 .79075 .52547 .78774 .52161 Mtetra
.566 .72 .945 r
.78774 .52161 .79075 .52547 .79779 .52458 .79479 .52071 Mtetra
.565 .72 .945 r
.79479 .52071 .79779 .52458 .80485 .5237 .80186 .51982 Mtetra
.564 .719 .945 r
.80186 .51982 .80485 .5237 .81193 .52284 .80895 .51894 Mtetra
.566 .72 .945 r
.80895 .51894 .81193 .52284 .81903 .52195 .81607 .51804 Mtetra
.569 .721 .945 r
.81607 .51804 .81903 .52195 .82616 .52101 .8232 .5171 Mtetra
.585 .729 .942 r
.8232 .5171 .82616 .52101 .83328 .51986 .83034 .51594 Mtetra
.6 .735 .939 r
.83034 .51594 .83328 .51986 .84041 .51849 .83748 .51457 Mtetra
.648 .756 .928 r
.83748 .51457 .84041 .51849 .84748 .51641 .84457 .51248 Mtetra
.711 .781 .907 r
.84457 .51248 .84748 .51641 .85447 .5132 .85156 .50927 Mtetra
.75 .794 .888 r
.85156 .50927 .85447 .5132 .86138 .50914 .85849 .50521 Mtetra
.862 .818 .804 r
.85849 .50521 .86138 .50914 .86792 .50146 .86505 .49754 Mtetra
.903 .819 .755 r
.86505 .49754 .86792 .50146 .87422 .49148 .87137 .48758 Mtetra
.939 .812 .692 r
.87137 .48758 .87422 .49148 .88013 .47806 .8773 .47417 Mtetra
.968 .795 .616 r
.8773 .47417 .88013 .47806 .8854 .45914 .88261 .45526 Mtetra
.975 .787 .587 r
.88261 .45526 .8854 .45914 .89033 .43763 .88756 .43376 Mtetra
.931 .563 .287 r
.2639 .5472 .26755 .5505 .27175 .5666 .26809 .5633 Mtetra
.926 .546 .258 r
.26809 .5633 .27175 .5666 .27612 .58143 .27244 .57814 Mtetra
.897 .478 .146 r
.27244 .57814 .27612 .58143 .28079 .59281 .27711 .58953 Mtetra
.832 .366 0 r
.27711 .58953 .28079 .59281 .28572 .6014 .28203 .59813 Mtetra
.727 .224 0 r
.28203 .59813 .28572 .6014 .29081 .60813 .28712 .60487 Mtetra
0 .327 .786 r
.28712 .60487 .29081 .60813 .29619 .61121 .2925 .60795 Mtetra
.101 .493 .901 r
.2925 .60795 .29619 .61121 .30167 .61328 .29798 .61003 Mtetra
.369 .644 .962 r
.29798 .61003 .30167 .61328 .30725 .61401 .30356 .61075 Mtetra
.518 .71 .959 r
.30356 .61075 .30725 .61401 .31292 .61369 .30924 .61043 Mtetra
.555 .724 .953 r
.30924 .61043 .31292 .61369 .31862 .61304 .31495 .60977 Mtetra
.594 .738 .944 r
.31495 .60977 .31862 .61304 .32437 .61199 .3207 .60871 Mtetra
.606 .741 .941 r
.3207 .60871 .32437 .61199 .33013 .61081 .32647 .60753 Mtetra
.612 .743 .939 r
.32647 .60753 .33013 .61081 .33592 .60955 .33226 .60626 Mtetra
.616 .744 .937 r
.33226 .60626 .33592 .60955 .34172 .60824 .33807 .60495 Mtetra
.617 .745 .937 r
.33807 .60495 .34172 .60824 .34754 .60693 .3439 .60362 Mtetra
.618 .745 .937 r
.3439 .60362 .34754 .60693 .35337 .60559 .34974 .60228 Mtetra
.617 .745 .937 r
.34974 .60228 .35337 .60559 .35921 .60426 .35559 .60094 Mtetra
.35559 .60094 .35921 .60426 .36507 .60293 .36146 .5996 Mtetra
.36146 .5996 .36507 .60293 .37095 .60159 .36734 .59826 Mtetra
.36734 .59826 .37095 .60159 .37684 .60025 .37323 .59691 Mtetra
.617 .744 .937 r
.37323 .59691 .37684 .60025 .38274 .59892 .37915 .59557 Mtetra
.37915 .59557 .38274 .59892 .38866 .59758 .38507 .59422 Mtetra
.616 .744 .937 r
.38507 .59422 .38866 .59758 .39459 .59624 .39101 .59288 Mtetra
.39101 .59288 .39459 .59624 .40054 .59491 .39697 .59154 Mtetra
.39697 .59154 .40054 .59491 .4065 .59357 .40293 .59019 Mtetra
.40293 .59019 .4065 .59357 .41247 .59223 .40892 .58884 Mtetra
.615 .744 .938 r
.40892 .58884 .41247 .59223 .41847 .59089 .41492 .58749 Mtetra
.41492 .58749 .41847 .59089 .42447 .58955 .42093 .58615 Mtetra
.42093 .58615 .42447 .58955 .43049 .58821 .42696 .58481 Mtetra
.614 .744 .938 r
.42696 .58481 .43049 .58821 .43653 .58688 .43301 .58346 Mtetra
.614 .743 .938 r
.43301 .58346 .43653 .58688 .44258 .58554 .43907 .58212 Mtetra
.43907 .58212 .44258 .58554 .44865 .5842 .44514 .58078 Mtetra
.613 .743 .938 r
.44514 .58078 .44865 .5842 .45473 .58287 .45123 .57944 Mtetra
.45123 .57944 .45473 .58287 .46083 .58154 .45734 .5781 Mtetra
.612 .743 .938 r
.45734 .5781 .46083 .58154 .46694 .58022 .46346 .57677 Mtetra
.46346 .57677 .46694 .58022 .47307 .57888 .46959 .57543 Mtetra
.46959 .57543 .47307 .57888 .47921 .57755 .47575 .57409 Mtetra
.611 .742 .939 r
.47575 .57409 .47921 .57755 .48537 .57623 .48192 .57276 Mtetra
.48192 .57276 .48537 .57623 .49155 .57491 .4881 .57143 Mtetra
.4881 .57143 .49155 .57491 .49774 .57358 .4943 .57009 Mtetra
.609 .742 .939 r
.4943 .57009 .49774 .57358 .50395 .57227 .50052 .56877 Mtetra
.50052 .56877 .50395 .57227 .51017 .57095 .50675 .56745 Mtetra
.50675 .56745 .51017 .57095 .51641 .56963 .513 .56612 Mtetra
.608 .741 .939 r
.513 .56612 .51641 .56963 .52267 .56832 .51926 .5648 Mtetra
.51926 .5648 .52267 .56832 .52894 .56702 .52554 .56349 Mtetra
.52554 .56349 .52894 .56702 .53523 .56571 .53184 .56217 Mtetra
.607 .74 .94 r
.53184 .56217 .53523 .56571 .54153 .56441 .53815 .56086 Mtetra
.606 .74 .94 r
.53815 .56086 .54153 .56441 .54786 .56311 .54449 .55956 Mtetra
.54449 .55956 .54786 .56311 .5542 .56181 .55083 .55826 Mtetra
.605 .74 .94 r
.55083 .55826 .5542 .56181 .56055 .56052 .5572 .55696 Mtetra
.604 .739 .94 r
.5572 .55696 .56055 .56052 .56692 .55924 .56358 .55567 Mtetra
.56358 .55567 .56692 .55924 .57331 .55796 .56998 .55438 Mtetra
.56998 .55438 .57331 .55796 .57972 .55668 .5764 .55309 Mtetra
.602 .738 .941 r
.5764 .55309 .57972 .55668 .58615 .55542 .58283 .55182 Mtetra
.58283 .55182 .58615 .55542 .59259 .55415 .58928 .55054 Mtetra
.58928 .55054 .59259 .55415 .59905 .55288 .59575 .54927 Mtetra
.6 .737 .941 r
.59575 .54927 .59905 .55288 .60553 .55164 .60224 .54802 Mtetra
.60224 .54802 .60553 .55164 .61202 .55039 .60874 .54676 Mtetra
.60874 .54676 .61202 .55039 .61854 .54914 .61526 .5455 Mtetra
.597 .736 .942 r
.61526 .5455 .61854 .54914 .62507 .54792 .62181 .54427 Mtetra
.62181 .54427 .62507 .54792 .63162 .5467 .62837 .54304 Mtetra
.596 .736 .942 r
.62837 .54304 .63162 .5467 .63819 .54548 .63494 .54182 Mtetra
.595 .736 .942 r
.63494 .54182 .63819 .54548 .64477 .54427 .64154 .5406 Mtetra
.595 .735 .942 r
.64154 .5406 .64477 .54427 .65138 .54307 .64816 .53939 Mtetra
.593 .735 .942 r
.64816 .53939 .65138 .54307 .658 .54188 .65479 .53819 Mtetra
.593 .734 .942 r
.65479 .53819 .658 .54188 .66465 .5407 .66144 .537 Mtetra
.592 .734 .942 r
.66144 .537 .66465 .5407 .67131 .53952 .66812 .53581 Mtetra
.59 .733 .943 r
.66812 .53581 .67131 .53952 .67799 .53836 .67481 .53464 Mtetra
.67481 .53464 .67799 .53836 .6847 .53721 .68152 .53348 Mtetra
.589 .732 .943 r
.68152 .53348 .6847 .53721 .69142 .53606 .68825 .53233 Mtetra
.587 .732 .943 r
.68825 .53233 .69142 .53606 .69816 .53494 .69501 .53119 Mtetra
.586 .731 .943 r
.69501 .53119 .69816 .53494 .70492 .53382 .70178 .53007 Mtetra
.585 .731 .944 r
.70178 .53007 .70492 .53382 .71171 .53271 .70857 .52895 Mtetra
.583 .73 .944 r
.70857 .52895 .71171 .53271 .71851 .53162 .71539 .52785 Mtetra
.582 .729 .944 r
.71539 .52785 .71851 .53162 .72534 .53054 .72222 .52676 Mtetra
.581 .729 .944 r
.72222 .52676 .72534 .53054 .73218 .52948 .72908 .52569 Mtetra
.579 .728 .944 r
.72908 .52569 .73218 .52948 .73905 .52843 .73596 .52464 Mtetra
.578 .727 .945 r
.73596 .52464 .73905 .52843 .74594 .5274 .74286 .5236 Mtetra
.576 .726 .945 r
.74286 .5236 .74594 .5274 .75285 .52639 .74978 .52257 Mtetra
.575 .726 .945 r
.74978 .52257 .75285 .52639 .75978 .52539 .75672 .52156 Mtetra
.573 .725 .945 r
.75672 .52156 .75978 .52539 .76674 .52442 .76369 .52058 Mtetra
.571 .724 .945 r
.76369 .52058 .76674 .52442 .77372 .52346 .77067 .51962 Mtetra
.57 .723 .945 r
.77067 .51962 .77372 .52346 .78072 .52252 .77769 .51866 Mtetra
.568 .722 .946 r
.77769 .51866 .78072 .52252 .78774 .52161 .78472 .51774 Mtetra
.566 .721 .946 r
.78472 .51774 .78774 .52161 .79479 .52071 .79178 .51683 Mtetra
.565 .72 .946 r
.79178 .51683 .79479 .52071 .80186 .51982 .79886 .51593 Mtetra
.564 .72 .946 r
.79886 .51593 .80186 .51982 .80895 .51894 .80597 .51505 Mtetra
.566 .72 .946 r
.80597 .51505 .80895 .51894 .81607 .51804 .81309 .51414 Mtetra
.569 .722 .945 r
.81309 .51414 .81607 .51804 .8232 .5171 .82024 .51318 Mtetra
.585 .729 .943 r
.82024 .51318 .8232 .5171 .83034 .51594 .82738 .51201 Mtetra
.6 .736 .94 r
.82738 .51201 .83034 .51594 .83748 .51457 .83453 .51063 Mtetra
.648 .757 .929 r
.83453 .51063 .83748 .51457 .84457 .51248 .84164 .50854 Mtetra
.71 .781 .907 r
.84164 .50854 .84457 .51248 .85156 .50927 .84865 .50533 Mtetra
.75 .794 .889 r
.84865 .50533 .85156 .50927 .85849 .50521 .85559 .50127 Mtetra
.862 .818 .804 r
.85559 .50127 .85849 .50521 .86505 .49754 .86217 .4936 Mtetra
.902 .819 .755 r
.86217 .4936 .86505 .49754 .87137 .48758 .86851 .48365 Mtetra
.939 .812 .692 r
.86851 .48365 .87137 .48758 .8773 .47417 .87447 .47025 Mtetra
.967 .795 .616 r
.87447 .47025 .8773 .47417 .88261 .45526 .87979 .45135 Mtetra
.975 .787 .587 r
.87979 .45135 .88261 .45526 .88756 .43376 .88477 .42986 Mtetra
.931 .563 .288 r
.26024 .54388 .2639 .5472 .26809 .5633 .26441 .56 Mtetra
.926 .546 .258 r
.26441 .56 .26809 .5633 .27244 .57814 .26875 .57485 Mtetra
.897 .478 .146 r
.26875 .57485 .27244 .57814 .27711 .58953 .27341 .58625 Mtetra
.833 .366 0 r
.27341 .58625 .27711 .58953 .28203 .59813 .27832 .59486 Mtetra
.727 .224 0 r
.27832 .59486 .28203 .59813 .28712 .60487 .28341 .6016 Mtetra
0 .326 .785 r
.28341 .6016 .28712 .60487 .2925 .60795 .28879 .60469 Mtetra
.101 .492 .901 r
.28879 .60469 .2925 .60795 .29798 .61003 .29427 .60676 Mtetra
.369 .644 .962 r
.29427 .60676 .29798 .61003 .30356 .61075 .29986 .60748 Mtetra
.518 .71 .959 r
.29986 .60748 .30356 .61075 .30924 .61043 .30554 .60715 Mtetra
.555 .724 .953 r
.30554 .60715 .30924 .61043 .31495 .60977 .31126 .60649 Mtetra
.594 .738 .944 r
.31126 .60649 .31495 .60977 .3207 .60871 .31702 .60543 Mtetra
.606 .741 .941 r
.31702 .60543 .3207 .60871 .32647 .60753 .3228 .60423 Mtetra
.612 .743 .939 r
.3228 .60423 .32647 .60753 .33226 .60626 .3286 .60296 Mtetra
.616 .745 .937 r
.3286 .60296 .33226 .60626 .33807 .60495 .33441 .60164 Mtetra
.617 .745 .937 r
.33441 .60164 .33807 .60495 .3439 .60362 .34024 .6003 Mtetra
.618 .745 .937 r
.34024 .6003 .3439 .60362 .34974 .60228 .34609 .59896 Mtetra
.617 .745 .937 r
.34609 .59896 .34974 .60228 .35559 .60094 .35195 .59761 Mtetra
.35195 .59761 .35559 .60094 .36146 .5996 .35783 .59626 Mtetra
.35783 .59626 .36146 .5996 .36734 .59826 .36372 .59491 Mtetra
.36372 .59491 .36734 .59826 .37323 .59691 .36962 .59356 Mtetra
.36962 .59356 .37323 .59691 .37915 .59557 .37554 .59221 Mtetra
.37554 .59221 .37915 .59557 .38507 .59422 .38147 .59086 Mtetra
.616 .744 .937 r
.38147 .59086 .38507 .59422 .39101 .59288 .38742 .58951 Mtetra
.616 .744 .938 r
.38742 .58951 .39101 .59288 .39697 .59154 .39338 .58816 Mtetra
.39338 .58816 .39697 .59154 .40293 .59019 .39936 .5868 Mtetra
.39936 .5868 .40293 .59019 .40892 .58884 .40535 .58545 Mtetra
.615 .744 .938 r
.40535 .58545 .40892 .58884 .41492 .58749 .41136 .58409 Mtetra
.41136 .58409 .41492 .58749 .42093 .58615 .41738 .58274 Mtetra
.614 .744 .938 r
.41738 .58274 .42093 .58615 .42696 .58481 .42342 .58139 Mtetra
.42342 .58139 .42696 .58481 .43301 .58346 .42947 .58004 Mtetra
.42947 .58004 .43301 .58346 .43907 .58212 .43554 .57869 Mtetra
.614 .743 .938 r
.43554 .57869 .43907 .58212 .44514 .58078 .44162 .57734 Mtetra
.613 .743 .938 r
.44162 .57734 .44514 .58078 .45123 .57944 .44772 .57599 Mtetra
.44772 .57599 .45123 .57944 .45734 .5781 .45383 .57465 Mtetra
.612 .743 .938 r
.45383 .57465 .45734 .5781 .46346 .57677 .45996 .5733 Mtetra
.45996 .5733 .46346 .57677 .46959 .57543 .46611 .57196 Mtetra
.46611 .57196 .46959 .57543 .47575 .57409 .47227 .57061 Mtetra
.611 .742 .939 r
.47227 .57061 .47575 .57409 .48192 .57276 .47844 .56928 Mtetra
.47844 .56928 .48192 .57276 .4881 .57143 .48464 .56794 Mtetra
.48464 .56794 .4881 .57143 .4943 .57009 .49084 .56659 Mtetra
.609 .742 .939 r
.49084 .56659 .4943 .57009 .50052 .56877 .49707 .56526 Mtetra
.49707 .56526 .50052 .56877 .50675 .56745 .50331 .56393 Mtetra
.50331 .56393 .50675 .56745 .513 .56612 .50957 .5626 Mtetra
.608 .741 .939 r
.50957 .5626 .513 .56612 .51926 .5648 .51584 .56127 Mtetra
.51584 .56127 .51926 .5648 .52554 .56349 .52213 .55995 Mtetra
.52213 .55995 .52554 .56349 .53184 .56217 .52844 .55862 Mtetra
.607 .741 .94 r
.52844 .55862 .53184 .56217 .53815 .56086 .53476 .55731 Mtetra
.606 .74 .94 r
.53476 .55731 .53815 .56086 .54449 .55956 .5411 .556 Mtetra
.5411 .556 .54449 .55956 .55083 .55826 .54746 .55468 Mtetra
.605 .74 .94 r
.54746 .55468 .55083 .55826 .5572 .55696 .55383 .55338 Mtetra
.604 .74 .94 r
.55383 .55338 .5572 .55696 .56358 .55567 .56022 .55208 Mtetra
.56022 .55208 .56358 .55567 .56998 .55438 .56663 .55078 Mtetra
.604 .739 .94 r
.56663 .55078 .56998 .55438 .5764 .55309 .57305 .54949 Mtetra
.602 .739 .941 r
.57305 .54949 .5764 .55309 .58283 .55182 .5795 .54821 Mtetra
.5795 .54821 .58283 .55182 .58928 .55054 .58596 .54692 Mtetra
.58596 .54692 .58928 .55054 .59575 .54927 .59244 .54564 Mtetra
.6 .738 .941 r
.59244 .54564 .59575 .54927 .60224 .54802 .59893 .54438 Mtetra
.59893 .54438 .60224 .54802 .60874 .54676 .60545 .54312 Mtetra
.60545 .54312 .60874 .54676 .61526 .5455 .61198 .54185 Mtetra
.597 .737 .942 r
.61198 .54185 .61526 .5455 .62181 .54427 .61853 .54061 Mtetra
.597 .736 .942 r
.61853 .54061 .62181 .54427 .62837 .54304 .6251 .53937 Mtetra
.596 .736 .942 r
.6251 .53937 .62837 .54304 .63494 .54182 .63169 .53814 Mtetra
.595 .736 .942 r
.63169 .53814 .63494 .54182 .64154 .5406 .63829 .53691 Mtetra
.595 .735 .942 r
.63829 .53691 .64154 .5406 .64816 .53939 .64492 .53569 Mtetra
.593 .735 .942 r
.64492 .53569 .64816 .53939 .65479 .53819 .65156 .53448 Mtetra
.593 .734 .942 r
.65156 .53448 .65479 .53819 .66144 .537 .65823 .53328 Mtetra
.592 .734 .943 r
.65823 .53328 .66144 .537 .66812 .53581 .66491 .53209 Mtetra
.59 .733 .943 r
.66491 .53209 .66812 .53581 .67481 .53464 .67161 .53091 Mtetra
.67161 .53091 .67481 .53464 .68152 .53348 .67834 .52974 Mtetra
.589 .733 .943 r
.67834 .52974 .68152 .53348 .68825 .53233 .68508 .52858 Mtetra
.587 .732 .943 r
.68508 .52858 .68825 .53233 .69501 .53119 .69184 .52744 Mtetra
.586 .731 .944 r
.69184 .52744 .69501 .53119 .70178 .53007 .69862 .5263 Mtetra
.585 .731 .944 r
.69862 .5263 .70178 .53007 .70857 .52895 .70543 .52518 Mtetra
.583 .73 .944 r
.70543 .52518 .70857 .52895 .71539 .52785 .71225 .52407 Mtetra
.582 .73 .944 r
.71225 .52407 .71539 .52785 .72222 .52676 .7191 .52297 Mtetra
.581 .729 .944 r
.7191 .52297 .72222 .52676 .72908 .52569 .72596 .52189 Mtetra
.579 .728 .945 r
.72596 .52189 .72908 .52569 .73596 .52464 .73285 .52083 Mtetra
.578 .727 .945 r
.73285 .52083 .73596 .52464 .74286 .5236 .73976 .51978 Mtetra
.576 .727 .945 r
.73976 .51978 .74286 .5236 .74978 .52257 .74669 .51874 Mtetra
.575 .726 .945 r
.74669 .51874 .74978 .52257 .75672 .52156 .75364 .51772 Mtetra
.573 .725 .945 r
.75364 .51772 .75672 .52156 .76369 .52058 .76062 .51673 Mtetra
.571 .724 .946 r
.76062 .51673 .76369 .52058 .77067 .51962 .76762 .51576 Mtetra
.57 .723 .946 r
.76762 .51576 .77067 .51962 .77769 .51866 .77464 .51479 Mtetra
.568 .722 .946 r
.77464 .51479 .77769 .51866 .78472 .51774 .78169 .51386 Mtetra
.566 .721 .946 r
.78169 .51386 .78472 .51774 .79178 .51683 .78876 .51294 Mtetra
.565 .721 .946 r
.78876 .51294 .79178 .51683 .79886 .51593 .79585 .51203 Mtetra
.564 .72 .946 r
.79585 .51203 .79886 .51593 .80597 .51505 .80297 .51114 Mtetra
.566 .721 .946 r
.80297 .51114 .80597 .51505 .81309 .51414 .8101 .51022 Mtetra
.569 .722 .946 r
.8101 .51022 .81309 .51414 .82024 .51318 .81726 .50926 Mtetra
.585 .73 .943 r
.81726 .50926 .82024 .51318 .82738 .51201 .82442 .50808 Mtetra
.6 .737 .94 r
.82442 .50808 .82738 .51201 .83453 .51063 .83158 .50669 Mtetra
.647 .757 .929 r
.83158 .50669 .83453 .51063 .84164 .50854 .83869 .50459 Mtetra
.71 .781 .908 r
.83869 .50459 .84164 .50854 .84865 .50533 .84572 .50138 Mtetra
.75 .795 .889 r
.84572 .50138 .84865 .50533 .85559 .50127 .85268 .49732 Mtetra
.862 .819 .805 r
.85268 .49732 .85559 .50127 .86217 .4936 .85928 .48966 Mtetra
.902 .819 .756 r
.85928 .48966 .86217 .4936 .86851 .48365 .86563 .47971 Mtetra
.939 .812 .693 r
.86563 .47971 .86851 .48365 .87447 .47025 .87161 .46631 Mtetra
.967 .795 .617 r
.87161 .46631 .87447 .47025 .87979 .45135 .87697 .44742 Mtetra
.975 .787 .588 r
.87697 .44742 .87979 .45135 .88477 .42986 .88198 .42593 Mtetra
.931 .563 .288 r
.25657 .54056 .26024 .54388 .26441 .56 .26072 .55669 Mtetra
.926 .546 .258 r
.26072 .55669 .26441 .56 .26875 .57485 .26505 .57155 Mtetra
.897 .478 .147 r
.26505 .57155 .26875 .57485 .27341 .58625 .26969 .58296 Mtetra
.833 .366 0 r
.26969 .58296 .27341 .58625 .27832 .59486 .2746 .59158 Mtetra
.728 .225 0 r
.2746 .59158 .27832 .59486 .28341 .6016 .27969 .59832 Mtetra
0 .325 .785 r
.27969 .59832 .28341 .6016 .28879 .60469 .28507 .60141 Mtetra
.099 .492 .901 r
.28507 .60141 .28879 .60469 .29427 .60676 .29055 .60348 Mtetra
.368 .644 .962 r
.29055 .60348 .29427 .60676 .29986 .60748 .29615 .60419 Mtetra
.517 .71 .959 r
.29615 .60419 .29986 .60748 .30554 .60715 .30183 .60386 Mtetra
.555 .724 .953 r
.30183 .60386 .30554 .60715 .31126 .60649 .30756 .6032 Mtetra
.594 .738 .944 r
.30756 .6032 .31126 .60649 .31702 .60543 .31332 .60213 Mtetra
.606 .742 .941 r
.31332 .60213 .31702 .60543 .3228 .60423 .31911 .60092 Mtetra
.612 .743 .939 r
.31911 .60092 .3228 .60423 .3286 .60296 .32491 .59965 Mtetra
.616 .745 .938 r
.32491 .59965 .3286 .60296 .33441 .60164 .33074 .59832 Mtetra
.617 .745 .937 r
.33074 .59832 .33441 .60164 .34024 .6003 .33658 .59698 Mtetra
.33658 .59698 .34024 .6003 .34609 .59896 .34243 .59563 Mtetra
.34243 .59563 .34609 .59896 .35195 .59761 .3483 .59427 Mtetra
.3483 .59427 .35195 .59761 .35783 .59626 .35418 .59292 Mtetra
.35418 .59292 .35783 .59626 .36372 .59491 .36008 .59156 Mtetra
.36008 .59156 .36372 .59491 .36962 .59356 .36599 .5902 Mtetra
.36599 .5902 .36962 .59356 .37554 .59221 .37191 .58884 Mtetra
.37191 .58884 .37554 .59221 .38147 .59086 .37786 .58748 Mtetra
.616 .745 .938 r
.37786 .58748 .38147 .59086 .38742 .58951 .38381 .58612 Mtetra
.38381 .58612 .38742 .58951 .39338 .58816 .38978 .58477 Mtetra
.38978 .58477 .39338 .58816 .39936 .5868 .39577 .5834 Mtetra
.616 .744 .938 r
.39577 .5834 .39936 .5868 .40535 .58545 .40177 .58204 Mtetra
.615 .744 .938 r
.40177 .58204 .40535 .58545 .41136 .58409 .40778 .58068 Mtetra
.40778 .58068 .41136 .58409 .41738 .58274 .41381 .57932 Mtetra
.614 .744 .938 r
.41381 .57932 .41738 .58274 .42342 .58139 .41986 .57796 Mtetra
.41986 .57796 .42342 .58139 .42947 .58004 .42592 .5766 Mtetra
.42592 .5766 .42947 .58004 .43554 .57869 .43199 .57525 Mtetra
.43199 .57525 .43554 .57869 .44162 .57734 .43808 .57389 Mtetra
.613 .743 .938 r
.43808 .57389 .44162 .57734 .44772 .57599 .44419 .57253 Mtetra
.44419 .57253 .44772 .57599 .45383 .57465 .45031 .57118 Mtetra
.612 .743 .939 r
.45031 .57118 .45383 .57465 .45996 .5733 .45645 .56983 Mtetra
.45645 .56983 .45996 .5733 .46611 .57196 .4626 .56848 Mtetra
.4626 .56848 .46611 .57196 .47227 .57061 .46877 .56712 Mtetra
.611 .743 .939 r
.46877 .56712 .47227 .57061 .47844 .56928 .47496 .56578 Mtetra
.47496 .56578 .47844 .56928 .48464 .56794 .48116 .56443 Mtetra
.48116 .56443 .48464 .56794 .49084 .56659 .48737 .56308 Mtetra
.609 .742 .939 r
.48737 .56308 .49084 .56659 .49707 .56526 .49361 .56175 Mtetra
.49361 .56175 .49707 .56526 .50331 .56393 .49986 .56041 Mtetra
.49986 .56041 .50331 .56393 .50957 .5626 .50612 .55906 Mtetra
.608 .741 .94 r
.50612 .55906 .50957 .5626 .51584 .56127 .5124 .55773 Mtetra
.5124 .55773 .51584 .56127 .52213 .55995 .5187 .5564 Mtetra
.5187 .5564 .52213 .55995 .52844 .55862 .52502 .55507 Mtetra
.607 .741 .94 r
.52502 .55507 .52844 .55862 .53476 .55731 .53135 .55374 Mtetra
.606 .741 .94 r
.53135 .55374 .53476 .55731 .5411 .556 .5377 .55243 Mtetra
.5377 .55243 .5411 .556 .54746 .55468 .54407 .5511 Mtetra
.605 .74 .94 r
.54407 .5511 .54746 .55468 .55383 .55338 .55045 .54979 Mtetra
.604 .74 .94 r
.55045 .54979 .55383 .55338 .56022 .55208 .55685 .54848 Mtetra
.55685 .54848 .56022 .55208 .56663 .55078 .56327 .54718 Mtetra
.603 .74 .941 r
.56327 .54718 .56663 .55078 .57305 .54949 .5697 .54587 Mtetra
.602 .739 .941 r
.5697 .54587 .57305 .54949 .5795 .54821 .57615 .54458 Mtetra
.57615 .54458 .5795 .54821 .58596 .54692 .58262 .54329 Mtetra
.58262 .54329 .58596 .54692 .59244 .54564 .58911 .542 Mtetra
.6 .738 .941 r
.58911 .542 .59244 .54564 .59893 .54438 .59562 .54073 Mtetra
.59562 .54073 .59893 .54438 .60545 .54312 .60214 .53946 Mtetra
.60214 .53946 .60545 .54312 .61198 .54185 .60868 .53818 Mtetra
.597 .737 .942 r
.60868 .53818 .61198 .54185 .61853 .54061 .61524 .53694 Mtetra
.61524 .53694 .61853 .54061 .6251 .53937 .62182 .53569 Mtetra
.596 .736 .942 r
.62182 .53569 .6251 .53937 .63169 .53814 .62842 .53445 Mtetra
.595 .736 .942 r
.62842 .53445 .63169 .53814 .63829 .53691 .63503 .53321 Mtetra
.63503 .53321 .63829 .53691 .64492 .53569 .64167 .53198 Mtetra
.593 .735 .943 r
.64167 .53198 .64492 .53569 .65156 .53448 .64832 .53077 Mtetra
.64832 .53077 .65156 .53448 .65823 .53328 .655 .52956 Mtetra
.592 .734 .943 r
.655 .52956 .65823 .53328 .66491 .53209 .66169 .52836 Mtetra
.59 .734 .943 r
.66169 .52836 .66491 .53209 .67161 .53091 .6684 .52717 Mtetra
.589 .733 .943 r
.6684 .52717 .67161 .53091 .67834 .52974 .67513 .52599 Mtetra
.67513 .52599 .67834 .52974 .68508 .52858 .68189 .52482 Mtetra
.587 .732 .944 r
.68189 .52482 .68508 .52858 .69184 .52744 .68866 .52367 Mtetra
.586 .732 .944 r
.68866 .52367 .69184 .52744 .69862 .5263 .69545 .52253 Mtetra
.585 .731 .944 r
.69545 .52253 .69862 .5263 .70543 .52518 .70226 .52139 Mtetra
.583 .73 .944 r
.70226 .52139 .70543 .52518 .71225 .52407 .7091 .52028 Mtetra
.582 .73 .944 r
.7091 .52028 .71225 .52407 .7191 .52297 .71595 .51917 Mtetra
.581 .729 .945 r
.71595 .51917 .7191 .52297 .72596 .52189 .72283 .51808 Mtetra
.579 .729 .945 r
.72283 .51808 .72596 .52189 .73285 .52083 .72973 .51701 Mtetra
.578 .728 .945 r
.72973 .51701 .73285 .52083 .73976 .51978 .73665 .51595 Mtetra
.576 .727 .945 r
.73665 .51595 .73976 .51978 .74669 .51874 .74359 .51491 Mtetra
.575 .726 .945 r
.74359 .51491 .74669 .51874 .75364 .51772 .75056 .51388 Mtetra
.573 .725 .946 r
.75056 .51388 .75364 .51772 .76062 .51673 .75754 .51287 Mtetra
.571 .724 .946 r
.75754 .51287 .76062 .51673 .76762 .51576 .76455 .51189 Mtetra
.57 .724 .946 r
.76455 .51189 .76762 .51576 .77464 .51479 .77159 .51092 Mtetra
.567 .723 .946 r
.77159 .51092 .77464 .51479 .78169 .51386 .77864 .50998 Mtetra
.566 .722 .947 r
.77864 .50998 .78169 .51386 .78876 .51294 .78572 .50905 Mtetra
.565 .721 .947 r
.78572 .50905 .78876 .51294 .79585 .51203 .79283 .50813 Mtetra
.564 .721 .947 r
.79283 .50813 .79585 .51203 .80297 .51114 .79996 .50723 Mtetra
.565 .721 .947 r
.79996 .50723 .80297 .51114 .8101 .51022 .8071 .5063 Mtetra
.569 .723 .946 r
.8071 .5063 .8101 .51022 .81726 .50926 .81427 .50533 Mtetra
.585 .73 .944 r
.81427 .50533 .81726 .50926 .82442 .50808 .82144 .50414 Mtetra
.6 .737 .941 r
.82144 .50414 .82442 .50808 .83158 .50669 .82861 .50275 Mtetra
.647 .758 .93 r
.82861 .50275 .83158 .50669 .83869 .50459 .83574 .50064 Mtetra
.71 .782 .908 r
.83574 .50064 .83869 .50459 .84572 .50138 .84278 .49743 Mtetra
.749 .796 .89 r
.84278 .49743 .84572 .50138 .85268 .49732 .84975 .49337 Mtetra
.862 .819 .805 r
.84975 .49337 .85268 .49732 .85928 .48966 .85637 .4857 Mtetra
.902 .82 .756 r
.85637 .4857 .85928 .48966 .86563 .47971 .86275 .47575 Mtetra
.939 .812 .693 r
.86275 .47575 .86563 .47971 .87161 .46631 .86875 .46237 Mtetra
.967 .795 .617 r
.86875 .46237 .87161 .46631 .87697 .44742 .87413 .44347 Mtetra
.975 .787 .588 r
.87413 .44347 .87697 .44742 .88198 .42593 .87917 .42198 Mtetra
.931 .563 .288 r
.25287 .53724 .25657 .54056 .26072 .55669 .25702 .55338 Mtetra
.926 .546 .258 r
.25702 .55338 .26072 .55669 .26505 .57155 .26132 .56825 Mtetra
.898 .479 .147 r
.26132 .56825 .26505 .57155 .26969 .58296 .26596 .57967 Mtetra
.833 .367 0 r
.26596 .57967 .26969 .58296 .2746 .59158 .27086 .58829 Mtetra
.729 .225 0 r
.27086 .58829 .2746 .59158 .27969 .59832 .27595 .59504 Mtetra
0 .325 .784 r
.27595 .59504 .27969 .59832 .28507 .60141 .28133 .59812 Mtetra
.098 .491 .9 r
.28133 .59812 .28507 .60141 .29055 .60348 .28682 .60019 Mtetra
.368 .644 .962 r
.28682 .60019 .29055 .60348 .29615 .60419 .29242 .60091 Mtetra
.517 .711 .959 r
.29242 .60091 .29615 .60419 .30183 .60386 .29811 .60057 Mtetra
.554 .725 .953 r
.29811 .60057 .30183 .60386 .30756 .6032 .30384 .5999 Mtetra
.594 .738 .944 r
.30384 .5999 .30756 .6032 .31332 .60213 .30961 .59882 Mtetra
.606 .742 .941 r
.30961 .59882 .31332 .60213 .31911 .60092 .3154 .59761 Mtetra
.612 .744 .939 r
.3154 .59761 .31911 .60092 .32491 .59965 .32122 .59633 Mtetra
.616 .745 .938 r
.32122 .59633 .32491 .59965 .33074 .59832 .32705 .59499 Mtetra
.617 .745 .938 r
.32705 .59499 .33074 .59832 .33658 .59698 .33289 .59364 Mtetra
.617 .746 .938 r
.33289 .59364 .33658 .59698 .34243 .59563 .33875 .59228 Mtetra
.617 .745 .938 r
.33875 .59228 .34243 .59563 .3483 .59427 .34463 .59092 Mtetra
.34463 .59092 .3483 .59427 .35418 .59292 .35052 .58956 Mtetra
.35052 .58956 .35418 .59292 .36008 .59156 .35642 .5882 Mtetra
.35642 .5882 .36008 .59156 .36599 .5902 .36234 .58683 Mtetra
.616 .745 .938 r
.36234 .58683 .36599 .5902 .37191 .58884 .36828 .58547 Mtetra
.617 .745 .938 r
.36828 .58547 .37191 .58884 .37786 .58748 .37422 .5841 Mtetra
.616 .745 .938 r
.37422 .5841 .37786 .58748 .38381 .58612 .38019 .58273 Mtetra
.38019 .58273 .38381 .58612 .38978 .58477 .38617 .58137 Mtetra
.38617 .58137 .38978 .58477 .39577 .5834 .39216 .58 Mtetra
.39216 .58 .39577 .5834 .40177 .58204 .39817 .57863 Mtetra
.615 .745 .938 r
.39817 .57863 .40177 .58204 .40778 .58068 .40419 .57726 Mtetra
.615 .744 .938 r
.40419 .57726 .40778 .58068 .41381 .57932 .41023 .57589 Mtetra
.614 .744 .938 r
.41023 .57589 .41381 .57932 .41986 .57796 .41628 .57453 Mtetra
.41628 .57453 .41986 .57796 .42592 .5766 .42235 .57316 Mtetra
.42235 .57316 .42592 .5766 .43199 .57525 .42843 .5718 Mtetra
.614 .744 .939 r
.42843 .5718 .43199 .57525 .43808 .57389 .43453 .57043 Mtetra
.613 .744 .939 r
.43453 .57043 .43808 .57389 .44419 .57253 .44065 .56907 Mtetra
.44065 .56907 .44419 .57253 .45031 .57118 .44678 .56771 Mtetra
.612 .744 .939 r
.44678 .56771 .45031 .57118 .45645 .56983 .45292 .56635 Mtetra
.45292 .56635 .45645 .56983 .4626 .56848 .45908 .56499 Mtetra
.612 .743 .939 r
.45908 .56499 .4626 .56848 .46877 .56712 .46526 .56363 Mtetra
.611 .743 .939 r
.46526 .56363 .46877 .56712 .47496 .56578 .47145 .56228 Mtetra
.47145 .56228 .47496 .56578 .48116 .56443 .47766 .56092 Mtetra
.47766 .56092 .48116 .56443 .48737 .56308 .48389 .55956 Mtetra
.609 .742 .94 r
.48389 .55956 .48737 .56308 .49361 .56175 .49013 .55822 Mtetra
.49013 .55822 .49361 .56175 .49986 .56041 .49639 .55687 Mtetra
.49639 .55687 .49986 .56041 .50612 .55906 .50266 .55552 Mtetra
.608 .742 .94 r
.50266 .55552 .50612 .55906 .5124 .55773 .50895 .55418 Mtetra
.50895 .55418 .5124 .55773 .5187 .5564 .51526 .55284 Mtetra
.51526 .55284 .5187 .5564 .52502 .55507 .52159 .5515 Mtetra
.607 .741 .94 r
.52159 .5515 .52502 .55507 .53135 .55374 .52793 .55017 Mtetra
.606 .741 .94 r
.52793 .55017 .53135 .55374 .5377 .55243 .53429 .54885 Mtetra
.53429 .54885 .5377 .55243 .54407 .5511 .54066 .54751 Mtetra
.605 .741 .941 r
.54066 .54751 .54407 .5511 .55045 .54979 .54705 .54619 Mtetra
.604 .74 .941 r
.54705 .54619 .55045 .54979 .55685 .54848 .55346 .54488 Mtetra
.55346 .54488 .55685 .54848 .56327 .54718 .55989 .54356 Mtetra
.603 .74 .941 r
.55989 .54356 .56327 .54718 .5697 .54587 .56633 .54225 Mtetra
.602 .739 .941 r
.56633 .54225 .5697 .54587 .57615 .54458 .57279 .54096 Mtetra
.57279 .54096 .57615 .54458 .58262 .54329 .57927 .53966 Mtetra
.57927 .53966 .58262 .54329 .58911 .542 .58577 .53836 Mtetra
.599 .738 .942 r
.58577 .53836 .58911 .542 .59562 .54073 .59228 .53708 Mtetra
.6 .738 .942 r
.59228 .53708 .59562 .54073 .60214 .53946 .59882 .5358 Mtetra
.6 .739 .942 r
.59882 .5358 .60214 .53946 .60868 .53818 .60537 .53451 Mtetra
.597 .737 .942 r
.60537 .53451 .60868 .53818 .61524 .53694 .61194 .53326 Mtetra
.61194 .53326 .61524 .53694 .62182 .53569 .61853 .53201 Mtetra
.596 .737 .943 r
.61853 .53201 .62182 .53569 .62842 .53445 .62513 .53076 Mtetra
.595 .737 .943 r
.62513 .53076 .62842 .53445 .63503 .53321 .63176 .52951 Mtetra
.595 .736 .943 r
.63176 .52951 .63503 .53321 .64167 .53198 .6384 .52827 Mtetra
.593 .736 .943 r
.6384 .52827 .64167 .53198 .64832 .53077 .64507 .52705 Mtetra
.592 .735 .943 r
.64507 .52705 .64832 .53077 .655 .52956 .65175 .52583 Mtetra
.65175 .52583 .655 .52956 .66169 .52836 .65845 .52462 Mtetra
.59 .734 .944 r
.65845 .52462 .66169 .52836 .6684 .52717 .66518 .52343 Mtetra
.589 .734 .944 r
.66518 .52343 .6684 .52717 .67513 .52599 .67192 .52224 Mtetra
.67192 .52224 .67513 .52599 .68189 .52482 .67868 .52106 Mtetra
.587 .733 .944 r
.67868 .52106 .68189 .52482 .68866 .52367 .68546 .5199 Mtetra
.586 .732 .944 r
.68546 .5199 .68866 .52367 .69545 .52253 .69227 .51875 Mtetra
.585 .732 .945 r
.69227 .51875 .69545 .52253 .70226 .52139 .69909 .5176 Mtetra
.583 .731 .945 r
.69909 .5176 .70226 .52139 .7091 .52028 .70594 .51648 Mtetra
.582 .731 .945 r
.70594 .51648 .7091 .52028 .71595 .51917 .7128 .51537 Mtetra
.581 .73 .945 r
.7128 .51537 .71595 .51917 .72283 .51808 .71969 .51427 Mtetra
.579 .729 .945 r
.71969 .51427 .72283 .51808 .72973 .51701 .7266 .51318 Mtetra
.578 .729 .946 r
.7266 .51318 .72973 .51701 .73665 .51595 .73353 .51212 Mtetra
.576 .728 .946 r
.73353 .51212 .73665 .51595 .74359 .51491 .74048 .51107 Mtetra
.575 .727 .946 r
.74048 .51107 .74359 .51491 .75056 .51388 .74746 .51003 Mtetra
.572 .726 .946 r
.74746 .51003 .75056 .51388 .75754 .51287 .75445 .50902 Mtetra
.571 .725 .947 r
.75445 .50902 .75754 .51287 .76455 .51189 .76148 .50802 Mtetra
.57 .725 .947 r
.76148 .50802 .76455 .51189 .77159 .51092 .76852 .50704 Mtetra
.567 .723 .947 r
.76852 .50704 .77159 .51092 .77864 .50998 .77559 .50609 Mtetra
.566 .723 .947 r
.77559 .50609 .77864 .50998 .78572 .50905 .78268 .50515 Mtetra
.565 .722 .947 r
.78268 .50515 .78572 .50905 .79283 .50813 .78979 .50423 Mtetra
.564 .722 .947 r
.78979 .50423 .79283 .50813 .79996 .50723 .79693 .50331 Mtetra
.565 .722 .947 r
.79693 .50331 .79996 .50723 .8071 .5063 .80409 .50238 Mtetra
.568 .724 .947 r
.80409 .50238 .8071 .5063 .81427 .50533 .81127 .5014 Mtetra
.584 .731 .944 r
.81127 .5014 .81427 .50533 .82144 .50414 .81845 .5002 Mtetra
.599 .738 .941 r
.81845 .5002 .82144 .50414 .82861 .50275 .82564 .4988 Mtetra
.647 .758 .93 r
.82564 .4988 .82861 .50275 .83574 .50064 .83278 .49668 Mtetra
.71 .783 .909 r
.83278 .49668 .83574 .50064 .84278 .49743 .83983 .49346 Mtetra
.749 .796 .89 r
.83983 .49346 .84278 .49743 .84975 .49337 .84681 .4894 Mtetra
.862 .819 .806 r
.84681 .4894 .84975 .49337 .85637 .4857 .85345 .48173 Mtetra
.902 .82 .757 r
.85345 .48173 .85637 .4857 .86275 .47575 .85985 .47178 Mtetra
.939 .812 .693 r
.85985 .47178 .86275 .47575 .86875 .46237 .86587 .45839 Mtetra
.967 .795 .617 r
.86587 .45839 .86875 .46237 .87413 .44347 .87127 .43949 Mtetra
.974 .787 .588 r
.87127 .43949 .87413 .44347 .87917 .42198 .87634 .41799 Mtetra
.931 .563 .288 r
.24917 .5339 .25287 .53724 .25702 .55338 .25329 .55005 Mtetra
.926 .546 .259 r
.25329 .55005 .25702 .55338 .26132 .56825 .25759 .56494 Mtetra
.898 .479 .148 r
.25759 .56494 .26132 .56825 .26596 .57967 .26222 .57636 Mtetra
.833 .367 0 r
.26222 .57636 .26596 .57967 .27086 .58829 .26711 .58499 Mtetra
.729 .226 0 r
.26711 .58499 .27086 .58829 .27595 .59504 .27219 .59174 Mtetra
0 .324 .783 r
.27219 .59174 .27595 .59504 .28133 .59812 .27758 .59483 Mtetra
.097 .491 .9 r
.27758 .59483 .28133 .59812 .28682 .60019 .28307 .59689 Mtetra
.367 .644 .962 r
.28307 .59689 .28682 .60019 .29242 .60091 .28867 .5976 Mtetra
.517 .711 .959 r
.28867 .5976 .29242 .60091 .29811 .60057 .29437 .59726 Mtetra
.554 .725 .953 r
.29437 .59726 .29811 .60057 .30384 .5999 .3001 .59658 Mtetra
.594 .738 .944 r
.3001 .59658 .30384 .5999 .30961 .59882 .30588 .5955 Mtetra
.606 .742 .941 r
.30588 .5955 .30961 .59882 .3154 .59761 .31168 .59429 Mtetra
.612 .744 .939 r
.31168 .59429 .3154 .59761 .32122 .59633 .3175 .593 Mtetra
.616 .745 .938 r
.3175 .593 .32122 .59633 .32705 .59499 .32334 .59165 Mtetra
.617 .745 .938 r
.32334 .59165 .32705 .59499 .33289 .59364 .3292 .5903 Mtetra
.617 .746 .938 r
.3292 .5903 .33289 .59364 .33875 .59228 .33506 .58893 Mtetra
.33506 .58893 .33875 .59228 .34463 .59092 .34095 .58757 Mtetra
.34095 .58757 .34463 .59092 .35052 .58956 .34684 .5862 Mtetra
.34684 .5862 .35052 .58956 .35642 .5882 .35276 .58482 Mtetra
.617 .745 .938 r
.35276 .58482 .35642 .5882 .36234 .58683 .35868 .58345 Mtetra
.616 .745 .938 r
.35868 .58345 .36234 .58683 .36828 .58547 .36462 .58208 Mtetra
.617 .745 .938 r
.36462 .58208 .36828 .58547 .37422 .5841 .37058 .5807 Mtetra
.616 .745 .938 r
.37058 .5807 .37422 .5841 .38019 .58273 .37655 .57933 Mtetra
.37655 .57933 .38019 .58273 .38617 .58137 .38254 .57796 Mtetra
.38254 .57796 .38617 .58137 .39216 .58 .38854 .57658 Mtetra
.38854 .57658 .39216 .58 .39817 .57863 .39455 .5752 Mtetra
.615 .745 .938 r
.39455 .5752 .39817 .57863 .40419 .57726 .40058 .57383 Mtetra
.40058 .57383 .40419 .57726 .41023 .57589 .40663 .57246 Mtetra
.614 .745 .938 r
.40663 .57246 .41023 .57589 .41628 .57453 .41269 .57108 Mtetra
.614 .744 .939 r
.41269 .57108 .41628 .57453 .42235 .57316 .41877 .56971 Mtetra
.41877 .56971 .42235 .57316 .42843 .5718 .42486 .56834 Mtetra
.42486 .56834 .42843 .5718 .43453 .57043 .43097 .56696 Mtetra
.613 .744 .939 r
.43097 .56696 .43453 .57043 .44065 .56907 .43709 .56559 Mtetra
.612 .744 .939 r
.43709 .56559 .44065 .56907 .44678 .56771 .44323 .56423 Mtetra
.44323 .56423 .44678 .56771 .45292 .56635 .44938 .56286 Mtetra
.44938 .56286 .45292 .56635 .45908 .56499 .45555 .56149 Mtetra
.45555 .56149 .45908 .56499 .46526 .56363 .46174 .56012 Mtetra
.611 .743 .939 r
.46174 .56012 .46526 .56363 .47145 .56228 .46794 .55876 Mtetra
.46794 .55876 .47145 .56228 .47766 .56092 .47416 .5574 Mtetra
.47416 .5574 .47766 .56092 .48389 .55956 .48039 .55603 Mtetra
.609 .743 .94 r
.48039 .55603 .48389 .55956 .49013 .55822 .48664 .55468 Mtetra
.48664 .55468 .49013 .55822 .49639 .55687 .49291 .55333 Mtetra
.49291 .55333 .49639 .55687 .50266 .55552 .49919 .55197 Mtetra
.608 .742 .94 r
.49919 .55197 .50266 .55552 .50895 .55418 .50549 .55062 Mtetra
.50549 .55062 .50895 .55418 .51526 .55284 .51181 .54928 Mtetra
.51181 .54928 .51526 .55284 .52159 .5515 .51814 .54793 Mtetra
.606 .742 .94 r
.51814 .54793 .52159 .5515 .52793 .55017 .52449 .54659 Mtetra
.606 .741 .941 r
.52449 .54659 .52793 .55017 .53429 .54885 .53086 .54525 Mtetra
.53086 .54525 .53429 .54885 .54066 .54751 .53724 .54392 Mtetra
.605 .741 .941 r
.53724 .54392 .54066 .54751 .54705 .54619 .54364 .54259 Mtetra
.604 .741 .941 r
.54364 .54259 .54705 .54619 .55346 .54488 .55006 .54127 Mtetra
.55006 .54127 .55346 .54488 .55989 .54356 .55649 .53994 Mtetra
.603 .74 .941 r
.55649 .53994 .55989 .54356 .56633 .54225 .56295 .53862 Mtetra
.602 .74 .941 r
.56295 .53862 .56633 .54225 .57279 .54096 .56942 .53732 Mtetra
.56942 .53732 .57279 .54096 .57927 .53966 .57591 .53601 Mtetra
.602 .74 .942 r
.57591 .53601 .57927 .53966 .58577 .53836 .58241 .5347 Mtetra
.599 .739 .942 r
.58241 .5347 .58577 .53836 .59228 .53708 .58894 .53342 Mtetra
.6 .739 .942 r
.58894 .53342 .59228 .53708 .59882 .5358 .59548 .53213 Mtetra
.59548 .53213 .59882 .5358 .60537 .53451 .60204 .53083 Mtetra
.597 .738 .943 r
.60204 .53083 .60537 .53451 .61194 .53326 .60862 .52957 Mtetra
.597 .737 .943 r
.60862 .52957 .61194 .53326 .61853 .53201 .61522 .52831 Mtetra
.596 .737 .943 r
.61522 .52831 .61853 .53201 .62513 .53076 .62184 .52705 Mtetra
.595 .737 .943 r
.62184 .52705 .62513 .53076 .63176 .52951 .62847 .5258 Mtetra
.62847 .5258 .63176 .52951 .6384 .52827 .63513 .52455 Mtetra
.593 .736 .943 r
.63513 .52455 .6384 .52827 .64507 .52705 .6418 .52332 Mtetra
.592 .736 .943 r
.6418 .52332 .64507 .52705 .65175 .52583 .64849 .5221 Mtetra
.592 .735 .943 r
.64849 .5221 .65175 .52583 .65845 .52462 .65521 .52087 Mtetra
.59 .735 .944 r
.65521 .52087 .65845 .52462 .66518 .52343 .66194 .51967 Mtetra
.589 .734 .944 r
.66194 .51967 .66518 .52343 .67192 .52224 .66869 .51848 Mtetra
.588 .734 .944 r
.66869 .51848 .67192 .52224 .67868 .52106 .67546 .51729 Mtetra
.587 .733 .944 r
.67546 .51729 .67868 .52106 .68546 .5199 .68226 .51612 Mtetra
.586 .733 .945 r
.68226 .51612 .68546 .5199 .69227 .51875 .68907 .51496 Mtetra
.585 .732 .945 r
.68907 .51496 .69227 .51875 .69909 .5176 .6959 .51381 Mtetra
.583 .731 .945 r
.6959 .51381 .69909 .5176 .70594 .51648 .70276 .51267 Mtetra
.582 .731 .945 r
.70276 .51267 .70594 .51648 .7128 .51537 .70963 .51155 Mtetra
.58 .73 .945 r
.70963 .51155 .7128 .51537 .71969 .51427 .71653 .51044 Mtetra
.579 .73 .946 r
.71653 .51044 .71969 .51427 .7266 .51318 .72345 .50935 Mtetra
.578 .729 .946 r
.72345 .50935 .7266 .51318 .73353 .51212 .73039 .50827 Mtetra
.576 .728 .946 r
.73039 .50827 .73353 .51212 .74048 .51107 .73736 .50721 Mtetra
.575 .728 .946 r
.73736 .50721 .74048 .51107 .74746 .51003 .74434 .50617 Mtetra
.572 .726 .947 r
.74434 .50617 .74746 .51003 .75445 .50902 .75135 .50515 Mtetra
.571 .726 .947 r
.75135 .50515 .75445 .50902 .76148 .50802 .75838 .50415 Mtetra
.57 .725 .947 r
.75838 .50415 .76148 .50802 .76852 .50704 .76544 .50315 Mtetra
.567 .724 .947 r
.76544 .50315 .76852 .50704 .77559 .50609 .77252 .50219 Mtetra
.566 .723 .947 r
.77252 .50219 .77559 .50609 .78268 .50515 .77962 .50125 Mtetra
.565 .723 .948 r
.77962 .50125 .78268 .50515 .78979 .50423 .78674 .50031 Mtetra
.563 .722 .948 r
.78674 .50031 .78979 .50423 .79693 .50331 .79389 .49939 Mtetra
.565 .723 .947 r
.79389 .49939 .79693 .50331 .80409 .50238 .80106 .49844 Mtetra
.568 .724 .947 r
.80106 .49844 .80409 .50238 .81127 .5014 .80825 .49745 Mtetra
.584 .731 .944 r
.80825 .49745 .81127 .5014 .81845 .5002 .81545 .49625 Mtetra
.599 .738 .942 r
.81545 .49625 .81845 .5002 .82564 .4988 .82264 .49484 Mtetra
.647 .759 .931 r
.82264 .49484 .82564 .4988 .83278 .49668 .8298 .49271 Mtetra
.709 .783 .909 r
.8298 .49271 .83278 .49668 .83983 .49346 .83686 .48948 Mtetra
.749 .796 .891 r
.83686 .48948 .83983 .49346 .84681 .4894 .84386 .48541 Mtetra
.861 .82 .806 r
.84386 .48541 .84681 .4894 .85345 .48173 .85052 .47774 Mtetra
.902 .82 .757 r
.85052 .47774 .85345 .48173 .85985 .47178 .85693 .46779 Mtetra
.939 .813 .694 r
.85693 .46779 .85985 .47178 .86587 .45839 .86298 .4544 Mtetra
.967 .795 .618 r
.86298 .4544 .86587 .45839 .87127 .43949 .86841 .43549 Mtetra
.974 .787 .588 r
.86841 .43549 .87127 .43949 .87634 .41799 .8735 .41398 Mtetra
.931 .563 .288 r
.24545 .53056 .24917 .5339 .25329 .55005 .24956 .54672 Mtetra
.926 .546 .259 r
.24956 .54672 .25329 .55005 .25759 .56494 .25384 .56162 Mtetra
.898 .479 .148 r
.25384 .56162 .25759 .56494 .26222 .57636 .25846 .57305 Mtetra
.834 .367 0 r
.25846 .57305 .26222 .57636 .26711 .58499 .26335 .58168 Mtetra
.73 .226 0 r
.26335 .58168 .26711 .58499 .27219 .59174 .26842 .58844 Mtetra
0 .323 .782 r
.26842 .58844 .27219 .59174 .27758 .59483 .27381 .59153 Mtetra
.096 .491 .9 r
.27381 .59153 .27758 .59483 .28307 .59689 .2793 .59359 Mtetra
.367 .644 .962 r
.2793 .59359 .28307 .59689 .28867 .5976 .28491 .5943 Mtetra
.517 .711 .96 r
.28491 .5943 .28867 .5976 .29437 .59726 .29061 .59395 Mtetra
.554 .725 .954 r
.29061 .59395 .29437 .59726 .3001 .59658 .29635 .59326 Mtetra
.594 .739 .945 r
.29635 .59326 .3001 .59658 .30588 .5955 .30214 .59218 Mtetra
.606 .742 .941 r
.30214 .59218 .30588 .5955 .31168 .59429 .30795 .59095 Mtetra
.612 .744 .94 r
.30795 .59095 .31168 .59429 .3175 .593 .31378 .58966 Mtetra
.616 .746 .938 r
.31378 .58966 .3175 .593 .32334 .59165 .31962 .5883 Mtetra
.617 .746 .938 r
.31962 .5883 .32334 .59165 .3292 .5903 .32548 .58694 Mtetra
.32548 .58694 .3292 .5903 .33506 .58893 .33136 .58557 Mtetra
.33136 .58557 .33506 .58893 .34095 .58757 .33725 .5842 Mtetra
.33725 .5842 .34095 .58757 .34684 .5862 .34315 .58282 Mtetra
.34315 .58282 .34684 .5862 .35276 .58482 .34907 .58144 Mtetra
.34907 .58144 .35276 .58482 .35868 .58345 .35501 .58006 Mtetra
.616 .746 .938 r
.35501 .58006 .35868 .58345 .36462 .58208 .36095 .57868 Mtetra
.36095 .57868 .36462 .58208 .37058 .5807 .36692 .5773 Mtetra
.616 .745 .938 r
.36692 .5773 .37058 .5807 .37655 .57933 .3729 .57592 Mtetra
.3729 .57592 .37655 .57933 .38254 .57796 .37889 .57454 Mtetra
.37889 .57454 .38254 .57796 .38854 .57658 .3849 .57316 Mtetra
.615 .745 .938 r
.3849 .57316 .38854 .57658 .39455 .5752 .39092 .57177 Mtetra
.39092 .57177 .39455 .5752 .40058 .57383 .39696 .57039 Mtetra
.615 .745 .939 r
.39696 .57039 .40058 .57383 .40663 .57246 .40302 .56901 Mtetra
.614 .745 .939 r
.40302 .56901 .40663 .57246 .41269 .57108 .40908 .56763 Mtetra
.40908 .56763 .41269 .57108 .41877 .56971 .41517 .56624 Mtetra
.41517 .56624 .41877 .56971 .42486 .56834 .42127 .56486 Mtetra
.613 .745 .939 r
.42127 .56486 .42486 .56834 .43097 .56696 .42738 .56348 Mtetra
.613 .744 .939 r
.42738 .56348 .43097 .56696 .43709 .56559 .43352 .56211 Mtetra
.612 .744 .939 r
.43352 .56211 .43709 .56559 .44323 .56423 .43966 .56073 Mtetra
.43966 .56073 .44323 .56423 .44938 .56286 .44582 .55936 Mtetra
.44582 .55936 .44938 .56286 .45555 .56149 .452 .55798 Mtetra
.452 .55798 .45555 .56149 .46174 .56012 .4582 .55661 Mtetra
.611 .743 .94 r
.4582 .55661 .46174 .56012 .46794 .55876 .46441 .55524 Mtetra
.46441 .55524 .46794 .55876 .47416 .5574 .47063 .55387 Mtetra
.47063 .55387 .47416 .5574 .48039 .55603 .47688 .55249 Mtetra
.609 .743 .94 r
.47688 .55249 .48039 .55603 .48664 .55468 .48314 .55114 Mtetra
.48314 .55114 .48664 .55468 .49291 .55333 .48941 .54977 Mtetra
.48941 .54977 .49291 .55333 .49919 .55197 .4957 .5484 Mtetra
.608 .742 .94 r
.4957 .5484 .49919 .55197 .50549 .55062 .50201 .54705 Mtetra
.50201 .54705 .50549 .55062 .51181 .54928 .50834 .5457 Mtetra
.50834 .5457 .51181 .54928 .51814 .54793 .51468 .54434 Mtetra
.606 .742 .941 r
.51468 .54434 .51814 .54793 .52449 .54659 .52104 .54299 Mtetra
.52104 .54299 .52449 .54659 .53086 .54525 .52741 .54165 Mtetra
.52741 .54165 .53086 .54525 .53724 .54392 .53381 .54031 Mtetra
.605 .741 .941 r
.53381 .54031 .53724 .54392 .54364 .54259 .54022 .53897 Mtetra
.604 .741 .941 r
.54022 .53897 .54364 .54259 .55006 .54127 .54664 .53764 Mtetra
.54664 .53764 .55006 .54127 .55649 .53994 .55309 .53631 Mtetra
.603 .741 .941 r
.55309 .53631 .55649 .53994 .56295 .53862 .55955 .53498 Mtetra
.602 .74 .942 r
.55955 .53498 .56295 .53862 .56942 .53732 .56603 .53367 Mtetra
.56603 .53367 .56942 .53732 .57591 .53601 .57253 .53235 Mtetra
.57253 .53235 .57591 .53601 .58241 .5347 .57904 .53103 Mtetra
.599 .739 .942 r
.57904 .53103 .58241 .5347 .58894 .53342 .58558 .52974 Mtetra
.58558 .52974 .58894 .53342 .59548 .53213 .59213 .52844 Mtetra
.6 .739 .942 r
.59213 .52844 .59548 .53213 .60204 .53083 .5987 .52714 Mtetra
.597 .738 .943 r
.5987 .52714 .60204 .53083 .60862 .52957 .60529 .52587 Mtetra
.596 .738 .943 r
.60529 .52587 .60862 .52957 .61522 .52831 .6119 .5246 Mtetra
.6119 .5246 .61522 .52831 .62184 .52705 .61852 .52334 Mtetra
.595 .737 .943 r
.61852 .52334 .62184 .52705 .62847 .5258 .62517 .52208 Mtetra
.62517 .52208 .62847 .5258 .63513 .52455 .63183 .52082 Mtetra
.593 .736 .944 r
.63183 .52082 .63513 .52455 .6418 .52332 .63852 .51958 Mtetra
.592 .736 .944 r
.63852 .51958 .6418 .52332 .64849 .5221 .64522 .51835 Mtetra
.64522 .51835 .64849 .5221 .65521 .52087 .65194 .51712 Mtetra
.59 .735 .944 r
.65194 .51712 .65521 .52087 .66194 .51967 .65869 .51591 Mtetra
.589 .735 .944 r
.65869 .51591 .66194 .51967 .66869 .51848 .66545 .5147 Mtetra
.588 .734 .944 r
.66545 .5147 .66869 .51848 .67546 .51729 .67223 .5135 Mtetra
.586 .733 .945 r
.67223 .5135 .67546 .51729 .68226 .51612 .67903 .51233 Mtetra
.67903 .51233 .68226 .51612 .68907 .51496 .68586 .51116 Mtetra
.585 .733 .945 r
.68586 .51116 .68907 .51496 .6959 .51381 .6927 .51 Mtetra
.583 .732 .945 r
.6927 .51 .6959 .51381 .70276 .51267 .69957 .50886 Mtetra
.582 .731 .946 r
.69957 .50886 .70276 .51267 .70963 .51155 .70645 .50772 Mtetra
.58 .731 .946 r
.70645 .50772 .70963 .51155 .71653 .51044 .71336 .50661 Mtetra
.579 .73 .946 r
.71336 .50661 .71653 .51044 .72345 .50935 .72029 .50551 Mtetra
.577 .729 .946 r
.72029 .50551 .72345 .50935 .73039 .50827 .72724 .50442 Mtetra
.576 .729 .946 r
.72724 .50442 .73039 .50827 .73736 .50721 .73422 .50335 Mtetra
.575 .728 .947 r
.73422 .50335 .73736 .50721 .74434 .50617 .74121 .5023 Mtetra
.572 .727 .947 r
.74121 .5023 .74434 .50617 .75135 .50515 .74823 .50127 Mtetra
.571 .726 .947 r
.74823 .50127 .75135 .50515 .75838 .50415 .75528 .50026 Mtetra
.57 .726 .947 r
.75528 .50026 .75838 .50415 .76544 .50315 .76234 .49926 Mtetra
.567 .724 .948 r
.76234 .49926 .76544 .50315 .77252 .50219 .76943 .49829 Mtetra
.566 .724 .948 r
.76943 .49829 .77252 .50219 .77962 .50125 .77655 .49733 Mtetra
.564 .723 .948 r
.77655 .49733 .77962 .50125 .78674 .50031 .78368 .49639 Mtetra
.563 .722 .948 r
.78368 .49639 .78674 .50031 .79389 .49939 .79084 .49546 Mtetra
.565 .723 .948 r
.79084 .49546 .79389 .49939 .80106 .49844 .79803 .4945 Mtetra
.568 .725 .948 r
.79803 .4945 .80106 .49844 .80825 .49745 .80523 .4935 Mtetra
.584 .732 .945 r
.80523 .4935 .80825 .49745 .81545 .49625 .81243 .49229 Mtetra
.599 .739 .942 r
.81243 .49229 .81545 .49625 .82264 .49484 .81964 .49087 Mtetra
.646 .76 .931 r
.81964 .49087 .82264 .49484 .8298 .49271 .82681 .48874 Mtetra
.709 .784 .91 r
.82681 .48874 .8298 .49271 .83686 .48948 .83389 .48551 Mtetra
.749 .797 .891 r
.83389 .48551 .83686 .48948 .84386 .48541 .8409 .48143 Mtetra
.862 .82 .807 r
.8409 .48143 .84386 .48541 .85052 .47774 .84757 .47375 Mtetra
.902 .821 .757 r
.84757 .47375 .85052 .47774 .85693 .46779 .85401 .46379 Mtetra
.939 .813 .694 r
.85401 .46379 .85693 .46779 .86298 .4544 .86007 .45039 Mtetra
.967 .795 .618 r
.86007 .45039 .86298 .4544 .86841 .43549 .86553 .43147 Mtetra
.974 .787 .589 r
.86553 .43147 .86841 .43549 .8735 .41398 .87065 .40994 Mtetra
.931 .563 .289 r
.24171 .52721 .24545 .53056 .24956 .54672 .24581 .54339 Mtetra
.926 .546 .259 r
.24581 .54339 .24956 .54672 .25384 .56162 .25007 .55829 Mtetra
.898 .479 .149 r
.25007 .55829 .25384 .56162 .25846 .57305 .25468 .56974 Mtetra
.834 .368 0 r
.25468 .56974 .25846 .57305 .26335 .58168 .25956 .57837 Mtetra
.73 .227 0 r
.25956 .57837 .26335 .58168 .26842 .58844 .26464 .58513 Mtetra
0 .323 .782 r
.26464 .58513 .26842 .58844 .27381 .59153 .27003 .58821 Mtetra
.095 .49 .899 r
.27003 .58821 .27381 .59153 .2793 .59359 .27552 .59028 Mtetra
.366 .644 .962 r
.27552 .59028 .2793 .59359 .28491 .5943 .28113 .59098 Mtetra
.516 .711 .96 r
.28113 .59098 .28491 .5943 .29061 .59395 .28684 .59062 Mtetra
.554 .725 .954 r
.28684 .59062 .29061 .59395 .29635 .59326 .29259 .58993 Mtetra
.594 .739 .945 r
.29259 .58993 .29635 .59326 .30214 .59218 .29838 .58884 Mtetra
.606 .743 .942 r
.29838 .58884 .30214 .59218 .30795 .59095 .3042 .58761 Mtetra
.612 .744 .94 r
.3042 .58761 .30795 .59095 .31378 .58966 .31003 .58631 Mtetra
.616 .746 .938 r
.31003 .58631 .31378 .58966 .31962 .5883 .31588 .58495 Mtetra
.617 .746 .938 r
.31588 .58495 .31962 .5883 .32548 .58694 .32175 .58358 Mtetra
.32175 .58358 .32548 .58694 .33136 .58557 .32764 .5822 Mtetra
.32764 .5822 .33136 .58557 .33725 .5842 .33353 .58082 Mtetra
.33353 .58082 .33725 .5842 .34315 .58282 .33945 .57943 Mtetra
.33945 .57943 .34315 .58282 .34907 .58144 .34537 .57805 Mtetra
.34537 .57805 .34907 .58144 .35501 .58006 .35131 .57666 Mtetra
.616 .746 .938 r
.35131 .57666 .35501 .58006 .36095 .57868 .35727 .57527 Mtetra
.35727 .57527 .36095 .57868 .36692 .5773 .36324 .57388 Mtetra
.36324 .57388 .36692 .5773 .3729 .57592 .36923 .5725 Mtetra
.616 .746 .939 r
.36923 .5725 .3729 .57592 .37889 .57454 .37523 .57111 Mtetra
.37523 .57111 .37889 .57454 .3849 .57316 .38125 .56972 Mtetra
.615 .746 .939 r
.38125 .56972 .3849 .57316 .39092 .57177 .38728 .56833 Mtetra
.615 .745 .939 r
.38728 .56833 .39092 .57177 .39696 .57039 .39332 .56694 Mtetra
.614 .745 .939 r
.39332 .56694 .39696 .57039 .40302 .56901 .39939 .56555 Mtetra
.39939 .56555 .40302 .56901 .40908 .56763 .40546 .56416 Mtetra
.40546 .56416 .40908 .56763 .41517 .56624 .41156 .56277 Mtetra
.41156 .56277 .41517 .56624 .42127 .56486 .41766 .56138 Mtetra
.613 .745 .939 r
.41766 .56138 .42127 .56486 .42738 .56348 .42379 .56 Mtetra
.42379 .56 .42738 .56348 .43352 .56211 .42993 .55861 Mtetra
.612 .744 .939 r
.42993 .55861 .43352 .56211 .43966 .56073 .43608 .55723 Mtetra
.612 .744 .94 r
.43608 .55723 .43966 .56073 .44582 .55936 .44225 .55585 Mtetra
.44225 .55585 .44582 .55936 .452 .55798 .44844 .55447 Mtetra
.44844 .55447 .452 .55798 .4582 .55661 .45464 .55308 Mtetra
.611 .744 .94 r
.45464 .55308 .4582 .55661 .46441 .55524 .46086 .55171 Mtetra
.46086 .55171 .46441 .55524 .47063 .55387 .4671 .55033 Mtetra
.4671 .55033 .47063 .55387 .47688 .55249 .47335 .54895 Mtetra
.609 .743 .94 r
.47335 .54895 .47688 .55249 .48314 .55114 .47962 .54758 Mtetra
.47962 .54758 .48314 .55114 .48941 .54977 .4859 .54621 Mtetra
.4859 .54621 .48941 .54977 .4957 .5484 .4922 .54483 Mtetra
.608 .743 .941 r
.4922 .54483 .4957 .5484 .50201 .54705 .49852 .54347 Mtetra
.49852 .54347 .50201 .54705 .50834 .5457 .50485 .54211 Mtetra
.50485 .54211 .50834 .5457 .51468 .54434 .5112 .54075 Mtetra
.606 .742 .941 r
.5112 .54075 .51468 .54434 .52104 .54299 .51757 .53939 Mtetra
.51757 .53939 .52104 .54299 .52741 .54165 .52395 .53804 Mtetra
.52395 .53804 .52741 .54165 .53381 .54031 .53036 .53669 Mtetra
.605 .742 .941 r
.53036 .53669 .53381 .54031 .54022 .53897 .53678 .53534 Mtetra
.604 .741 .942 r
.53678 .53534 .54022 .53897 .54664 .53764 .54321 .53401 Mtetra
.54321 .53401 .54664 .53764 .55309 .53631 .54967 .53266 Mtetra
.603 .741 .942 r
.54967 .53266 .55309 .53631 .55955 .53498 .55614 .53133 Mtetra
.602 .74 .942 r
.55614 .53133 .55955 .53498 .56603 .53367 .56263 .53001 Mtetra
.56263 .53001 .56603 .53367 .57253 .53235 .56913 .52868 Mtetra
.601 .74 .942 r
.56913 .52868 .57253 .53235 .57904 .53103 .57566 .52736 Mtetra
.599 .739 .943 r
.57566 .52736 .57904 .53103 .58558 .52974 .5822 .52606 Mtetra
.5822 .52606 .58558 .52974 .59213 .52844 .58876 .52475 Mtetra
.599 .74 .943 r
.58876 .52475 .59213 .52844 .5987 .52714 .59534 .52344 Mtetra
.597 .738 .943 r
.59534 .52344 .5987 .52714 .60529 .52587 .60194 .52217 Mtetra
.596 .738 .943 r
.60194 .52217 .60529 .52587 .6119 .5246 .60856 .52089 Mtetra
.60856 .52089 .6119 .5246 .61852 .52334 .6152 .51961 Mtetra
.595 .738 .944 r
.6152 .51961 .61852 .52334 .62517 .52208 .62185 .51834 Mtetra
.594 .737 .944 r
.62185 .51834 .62517 .52208 .63183 .52082 .62853 .51708 Mtetra
.593 .737 .944 r
.62853 .51708 .63183 .52082 .63852 .51958 .63522 .51583 Mtetra
.592 .736 .944 r
.63522 .51583 .63852 .51958 .64522 .51835 .64193 .51459 Mtetra
.64193 .51459 .64522 .51835 .65194 .51712 .64867 .51335 Mtetra
.59 .735 .945 r
.64867 .51335 .65194 .51712 .65869 .51591 .65542 .51213 Mtetra
.589 .735 .945 r
.65542 .51213 .65869 .51591 .66545 .5147 .66219 .51092 Mtetra
.588 .735 .945 r
.66219 .51092 .66545 .5147 .67223 .5135 .66898 .50972 Mtetra
.586 .734 .945 r
.66898 .50972 .67223 .5135 .67903 .51233 .6758 .50853 Mtetra
.6758 .50853 .67903 .51233 .68586 .51116 .68263 .50735 Mtetra
.584 .733 .946 r
.68263 .50735 .68586 .51116 .6927 .51 .68949 .50618 Mtetra
.583 .732 .946 r
.68949 .50618 .6927 .51 .69957 .50886 .69636 .50503 Mtetra
.582 .732 .946 r
.69636 .50503 .69957 .50886 .70645 .50772 .70326 .50389 Mtetra
.58 .731 .946 r
.70326 .50389 .70645 .50772 .71336 .50661 .71018 .50277 Mtetra
.579 .731 .946 r
.71018 .50277 .71336 .50661 .72029 .50551 .71712 .50166 Mtetra
.577 .73 .947 r
.71712 .50166 .72029 .50551 .72724 .50442 .72408 .50056 Mtetra
.576 .729 .947 r
.72408 .50056 .72724 .50442 .73422 .50335 .73107 .49949 Mtetra
.574 .729 .947 r
.73107 .49949 .73422 .50335 .74121 .5023 .73807 .49842 Mtetra
.572 .728 .948 r
.73807 .49842 .74121 .5023 .74823 .50127 .7451 .49738 Mtetra
.57 .727 .948 r
.7451 .49738 .74823 .50127 .75528 .50026 .75216 .49637 Mtetra
.569 .726 .948 r
.75216 .49637 .75528 .50026 .76234 .49926 .75923 .49536 Mtetra
.567 .725 .948 r
.75923 .49536 .76234 .49926 .76943 .49829 .76634 .49438 Mtetra
.565 .724 .948 r
.76634 .49438 .76943 .49829 .77655 .49733 .77346 .49341 Mtetra
.564 .724 .949 r
.77346 .49341 .77655 .49733 .78368 .49639 .78061 .49246 Mtetra
.563 .723 .949 r
.78061 .49246 .78368 .49639 .79084 .49546 .78778 .49152 Mtetra
.565 .724 .948 r
.78778 .49152 .79084 .49546 .79803 .4945 .79497 .49056 Mtetra
.568 .725 .948 r
.79497 .49056 .79803 .4945 .80523 .4935 .80219 .48955 Mtetra
.584 .733 .946 r
.80219 .48955 .80523 .4935 .81243 .49229 .8094 .48833 Mtetra
.599 .74 .943 r
.8094 .48833 .81243 .49229 .81964 .49087 .81662 .4869 Mtetra
.646 .76 .932 r
.81662 .4869 .81964 .49087 .82681 .48874 .8238 .48476 Mtetra
.709 .784 .91 r
.8238 .48476 .82681 .48874 .83389 .48551 .8309 .48152 Mtetra
.749 .797 .892 r
.8309 .48152 .83389 .48551 .8409 .48143 .83792 .47743 Mtetra
.862 .821 .807 r
.83792 .47743 .8409 .48143 .84757 .47375 .84461 .46974 Mtetra
.902 .821 .757 r
.84461 .46974 .84757 .47375 .85401 .46379 .85107 .45977 Mtetra
.938 .813 .694 r
.85107 .45977 .85401 .46379 .86007 .45039 .85715 .44635 Mtetra
.967 .795 .618 r
.85715 .44635 .86007 .45039 .86553 .43147 .86264 .42742 Mtetra
.974 .787 .589 r
.86264 .42742 .86553 .43147 .87065 .40994 .86778 .40587 Mtetra
.931 .563 .289 r
.23796 .52386 .24171 .52721 .24581 .54339 .24204 .54004 Mtetra
.926 .546 .259 r
.24204 .54004 .24581 .54339 .25007 .55829 .24629 .55496 Mtetra
.898 .479 .149 r
.24629 .55496 .25007 .55829 .25468 .56974 .25089 .56641 Mtetra
.834 .368 0 r
.25089 .56641 .25468 .56974 .25956 .57837 .25577 .57505 Mtetra
.731 .227 0 r
.25577 .57505 .25956 .57837 .26464 .58513 .26084 .58181 Mtetra
0 .322 .781 r
.26084 .58181 .26464 .58513 .27003 .58821 .26623 .58489 Mtetra
.095 .49 .899 r
.26623 .58489 .27003 .58821 .27552 .59028 .27172 .58695 Mtetra
.366 .644 .963 r
.27172 .58695 .27552 .59028 .28113 .59098 .27734 .58765 Mtetra
.516 .711 .96 r
.27734 .58765 .28113 .59098 .28684 .59062 .28305 .58729 Mtetra
.554 .725 .954 r
.28305 .58729 .28684 .59062 .29259 .58993 .28881 .58659 Mtetra
.594 .739 .945 r
.28881 .58659 .29259 .58993 .29838 .58884 .29461 .58549 Mtetra
.606 .743 .942 r
.29461 .58549 .29838 .58884 .3042 .58761 .30043 .58426 Mtetra
.612 .745 .94 r
.30043 .58426 .3042 .58761 .31003 .58631 .30627 .58294 Mtetra
.616 .746 .939 r
.30627 .58294 .31003 .58631 .31588 .58495 .31213 .58158 Mtetra
.617 .746 .938 r
.31213 .58158 .31588 .58495 .32175 .58358 .31801 .5802 Mtetra
.31801 .5802 .32175 .58358 .32764 .5822 .3239 .57882 Mtetra
.3239 .57882 .32764 .5822 .33353 .58082 .3298 .57743 Mtetra
.3298 .57743 .33353 .58082 .33945 .57943 .33572 .57604 Mtetra
.33572 .57604 .33945 .57943 .34537 .57805 .34166 .57464 Mtetra
.34166 .57464 .34537 .57805 .35131 .57666 .34761 .57325 Mtetra
.616 .746 .938 r
.34761 .57325 .35131 .57666 .35727 .57527 .35357 .57186 Mtetra
.35357 .57186 .35727 .57527 .36324 .57388 .35955 .57046 Mtetra
.616 .746 .939 r
.35955 .57046 .36324 .57388 .36923 .5725 .36554 .56906 Mtetra
.36554 .56906 .36923 .5725 .37523 .57111 .37155 .56767 Mtetra
.37155 .56767 .37523 .57111 .38125 .56972 .37758 .56627 Mtetra
.615 .746 .939 r
.37758 .56627 .38125 .56972 .38728 .56833 .38362 .56487 Mtetra
.38362 .56487 .38728 .56833 .39332 .56694 .38967 .56347 Mtetra
.614 .745 .939 r
.38967 .56347 .39332 .56694 .39939 .56555 .39574 .56208 Mtetra
.39574 .56208 .39939 .56555 .40546 .56416 .40183 .56068 Mtetra
.40183 .56068 .40546 .56416 .41156 .56277 .40793 .55929 Mtetra
.40793 .55929 .41156 .56277 .41766 .56138 .41404 .55789 Mtetra
.613 .745 .939 r
.41404 .55789 .41766 .56138 .42379 .56 .42018 .5565 Mtetra
.42018 .5565 .42379 .56 .42993 .55861 .42632 .55511 Mtetra
.612 .745 .94 r
.42632 .55511 .42993 .55861 .43608 .55723 .43249 .55372 Mtetra
.612 .744 .94 r
.43249 .55372 .43608 .55723 .44225 .55585 .43867 .55233 Mtetra
.612 .745 .94 r
.43867 .55233 .44225 .55585 .44844 .55447 .44486 .55094 Mtetra
.612 .744 .94 r
.44486 .55094 .44844 .55447 .45464 .55308 .45107 .54954 Mtetra
.61 .744 .94 r
.45107 .54954 .45464 .55308 .46086 .55171 .4573 .54816 Mtetra
.611 .744 .94 r
.4573 .54816 .46086 .55171 .4671 .55033 .46354 .54678 Mtetra
.46354 .54678 .4671 .55033 .47335 .54895 .4698 .54539 Mtetra
.609 .743 .94 r
.4698 .54539 .47335 .54895 .47962 .54758 .47608 .54401 Mtetra
.609 .744 .94 r
.47608 .54401 .47962 .54758 .4859 .54621 .48237 .54263 Mtetra
.48237 .54263 .4859 .54621 .4922 .54483 .48868 .54125 Mtetra
.608 .743 .941 r
.48868 .54125 .4922 .54483 .49852 .54347 .49501 .53988 Mtetra
.607 .743 .941 r
.49501 .53988 .49852 .54347 .50485 .54211 .50135 .53851 Mtetra
.608 .743 .941 r
.50135 .53851 .50485 .54211 .5112 .54075 .50771 .53714 Mtetra
.606 .742 .941 r
.50771 .53714 .5112 .54075 .51757 .53939 .51409 .53578 Mtetra
.51409 .53578 .51757 .53939 .52395 .53804 .52048 .53442 Mtetra
.52048 .53442 .52395 .53804 .53036 .53669 .52689 .53306 Mtetra
.605 .742 .942 r
.52689 .53306 .53036 .53669 .53678 .53534 .53332 .5317 Mtetra
.604 .741 .942 r
.53332 .5317 .53678 .53534 .54321 .53401 .53977 .53036 Mtetra
.604 .742 .942 r
.53977 .53036 .54321 .53401 .54967 .53266 .54623 .52901 Mtetra
.603 .741 .942 r
.54623 .52901 .54967 .53266 .55614 .53133 .55271 .52767 Mtetra
.602 .741 .942 r
.55271 .52767 .55614 .53133 .56263 .53001 .55921 .52634 Mtetra
.55921 .52634 .56263 .53001 .56913 .52868 .56573 .52501 Mtetra
.601 .741 .942 r
.56573 .52501 .56913 .52868 .57566 .52736 .57226 .52367 Mtetra
.599 .74 .943 r
.57226 .52367 .57566 .52736 .5822 .52606 .57881 .52237 Mtetra
.57881 .52237 .5822 .52606 .58876 .52475 .58538 .52105 Mtetra
.58538 .52105 .58876 .52475 .59534 .52344 .59197 .51973 Mtetra
.597 .739 .943 r
.59197 .51973 .59534 .52344 .60194 .52217 .59858 .51845 Mtetra
.596 .739 .943 r
.59858 .51845 .60194 .52217 .60856 .52089 .60521 .51716 Mtetra
.596 .738 .944 r
.60521 .51716 .60856 .52089 .6152 .51961 .61186 .51588 Mtetra
.595 .738 .944 r
.61186 .51588 .6152 .51961 .62185 .51834 .61852 .5146 Mtetra
.594 .738 .944 r
.61852 .5146 .62185 .51834 .62853 .51708 .62521 .51333 Mtetra
.593 .737 .944 r
.62521 .51333 .62853 .51708 .63522 .51583 .63191 .51207 Mtetra
.592 .737 .944 r
.63191 .51207 .63522 .51583 .64193 .51459 .63863 .51082 Mtetra
.63863 .51082 .64193 .51459 .64867 .51335 .64537 .50958 Mtetra
.589 .736 .945 r
.64537 .50958 .64867 .51335 .65542 .51213 .65214 .50835 Mtetra
.589 .735 .945 r
.65214 .50835 .65542 .51213 .66219 .51092 .65892 .50713 Mtetra
.588 .735 .945 r
.65892 .50713 .66219 .51092 .66898 .50972 .66572 .50591 Mtetra
.586 .734 .945 r
.66572 .50591 .66898 .50972 .6758 .50853 .67255 .50472 Mtetra
.585 .734 .946 r
.67255 .50472 .6758 .50853 .68263 .50735 .67939 .50353 Mtetra
.584 .733 .946 r
.67939 .50353 .68263 .50735 .68949 .50618 .68626 .50236 Mtetra
.583 .733 .946 r
.68626 .50236 .68949 .50618 .69636 .50503 .69314 .5012 Mtetra
.582 .732 .946 r
.69314 .5012 .69636 .50503 .70326 .50389 .70005 .50005 Mtetra
.58 .732 .947 r
.70005 .50005 .70326 .50389 .71018 .50277 .70698 .49892 Mtetra
.579 .731 .947 r
.70698 .49892 .71018 .50277 .71712 .50166 .71393 .4978 Mtetra
.577 .73 .947 r
.71393 .4978 .71712 .50166 .72408 .50056 .72091 .4967 Mtetra
.576 .73 .947 r
.72091 .4967 .72408 .50056 .73107 .49949 .7279 .49561 Mtetra
.574 .729 .947 r
.7279 .49561 .73107 .49949 .73807 .49842 .73492 .49454 Mtetra
.572 .728 .948 r
.73492 .49454 .73807 .49842 .7451 .49738 .74196 .49349 Mtetra
.57 .727 .948 r
.74196 .49349 .7451 .49738 .75216 .49637 .74903 .49246 Mtetra
.569 .727 .948 r
.74903 .49246 .75216 .49637 .75923 .49536 .75611 .49144 Mtetra
.567 .725 .949 r
.75611 .49144 .75923 .49536 .76634 .49438 .76323 .49046 Mtetra
.565 .725 .949 r
.76323 .49046 .76634 .49438 .77346 .49341 .77036 .48948 Mtetra
.564 .724 .949 r
.77036 .48948 .77346 .49341 .78061 .49246 .77752 .48852 Mtetra
.563 .724 .949 r
.77752 .48852 .78061 .49246 .78778 .49152 .7847 .48757 Mtetra
.564 .724 .949 r
.7847 .48757 .78778 .49152 .79497 .49056 .79191 .4866 Mtetra
.568 .726 .948 r
.79191 .4866 .79497 .49056 .80219 .48955 .79913 .48558 Mtetra
.584 .733 .946 r
.79913 .48558 .80219 .48955 .8094 .48833 .80636 .48435 Mtetra
.599 .74 .943 r
.80636 .48435 .8094 .48833 .81662 .4869 .81359 .48291 Mtetra
.646 .76 .932 r
.81359 .48291 .81662 .4869 .8238 .48476 .82079 .48077 Mtetra
.709 .784 .911 r
.82079 .48077 .8238 .48476 .8309 .48152 .82789 .47751 Mtetra
.749 .798 .892 r
.82789 .47751 .8309 .48152 .83792 .47743 .83494 .47342 Mtetra
.862 .821 .807 r
.83494 .47342 .83792 .47743 .84461 .46974 .84164 .46572 Mtetra
.902 .821 .758 r
.84164 .46572 .84461 .46974 .85107 .45977 .84811 .45573 Mtetra
.938 .813 .694 r
.84811 .45573 .85107 .45977 .85715 .44635 .85422 .4423 Mtetra
.967 .795 .618 r
.85422 .4423 .85715 .44635 .86264 .42742 .85973 .42334 Mtetra
.974 .786 .589 r
.85973 .42334 .86264 .42742 .86778 .40587 .8649 .40178 Mtetra
.931 .563 .289 r
.23419 .5205 .23796 .52386 .24204 .54004 .23825 .53669 Mtetra
.926 .546 .26 r
.23825 .53669 .24204 .54004 .24629 .55496 .24249 .55162 Mtetra
.898 .479 .149 r
.24249 .55162 .24629 .55496 .25089 .56641 .24708 .56307 Mtetra
.834 .368 0 r
.24708 .56307 .25089 .56641 .25577 .57505 .25195 .57172 Mtetra
.731 .227 0 r
.25195 .57172 .25577 .57505 .26084 .58181 .25702 .57848 Mtetra
0 .322 .781 r
.25702 .57848 .26084 .58181 .26623 .58489 .26241 .58156 Mtetra
.095 .49 .899 r
.26241 .58156 .26623 .58489 .27172 .58695 .26791 .58361 Mtetra
.366 .644 .963 r
.26791 .58361 .27172 .58695 .27734 .58765 .27353 .58431 Mtetra
.516 .711 .96 r
.27353 .58431 .27734 .58765 .28305 .58729 .27925 .58394 Mtetra
.554 .725 .954 r
.27925 .58394 .28305 .58729 .28881 .58659 .28501 .58324 Mtetra
.594 .739 .945 r
.28501 .58324 .28881 .58659 .29461 .58549 .29082 .58213 Mtetra
.605 .743 .942 r
.29082 .58213 .29461 .58549 .30043 .58426 .29665 .58089 Mtetra
.612 .745 .94 r
.29665 .58089 .30043 .58426 .30627 .58294 .3025 .57957 Mtetra
.616 .746 .939 r
.3025 .57957 .30627 .58294 .31213 .58158 .30836 .5782 Mtetra
.617 .746 .938 r
.30836 .5782 .31213 .58158 .31801 .5802 .31425 .57682 Mtetra
.617 .747 .938 r
.31425 .57682 .31801 .5802 .3239 .57882 .32014 .57542 Mtetra
.617 .746 .938 r
.32014 .57542 .3239 .57882 .3298 .57743 .32606 .57403 Mtetra
.32606 .57403 .3298 .57743 .33572 .57604 .33199 .57263 Mtetra
.617 .747 .938 r
.33199 .57263 .33572 .57604 .34166 .57464 .33793 .57123 Mtetra
.616 .746 .939 r
.33793 .57123 .34166 .57464 .34761 .57325 .34388 .56983 Mtetra
.34388 .56983 .34761 .57325 .35357 .57186 .34986 .56843 Mtetra
.34986 .56843 .35357 .57186 .35955 .57046 .35584 .56703 Mtetra
.35584 .56703 .35955 .57046 .36554 .56906 .36185 .56562 Mtetra
.615 .746 .939 r
.36185 .56562 .36554 .56906 .37155 .56767 .36786 .56422 Mtetra
.616 .746 .939 r
.36786 .56422 .37155 .56767 .37758 .56627 .37389 .56282 Mtetra
.615 .746 .939 r
.37389 .56282 .37758 .56627 .38362 .56487 .37994 .56141 Mtetra
.37994 .56141 .38362 .56487 .38967 .56347 .386 .56 Mtetra
.614 .746 .939 r
.386 .56 .38967 .56347 .39574 .56208 .39208 .5586 Mtetra
.39208 .5586 .39574 .56208 .40183 .56068 .39818 .5572 Mtetra
.39818 .5572 .40183 .56068 .40793 .55929 .40428 .55579 Mtetra
.614 .745 .939 r
.40428 .55579 .40793 .55929 .41404 .55789 .41041 .55439 Mtetra
.613 .745 .94 r
.41041 .55439 .41404 .55789 .42018 .5565 .41655 .55299 Mtetra
.41655 .55299 .42018 .5565 .42632 .55511 .42271 .55159 Mtetra
.612 .745 .94 r
.42271 .55159 .42632 .55511 .43249 .55372 .42888 .55019 Mtetra
.42888 .55019 .43249 .55372 .43867 .55233 .43506 .5488 Mtetra
.43506 .5488 .43867 .55233 .44486 .55094 .44127 .5474 Mtetra
.44127 .5474 .44486 .55094 .45107 .54954 .44749 .546 Mtetra
.61 .744 .94 r
.44749 .546 .45107 .54954 .4573 .54816 .45372 .54461 Mtetra
.45372 .54461 .4573 .54816 .46354 .54678 .45998 .54322 Mtetra
.45998 .54322 .46354 .54678 .4698 .54539 .46624 .54182 Mtetra
.609 .744 .941 r
.46624 .54182 .4698 .54539 .47608 .54401 .47253 .54044 Mtetra
.47253 .54044 .47608 .54401 .48237 .54263 .47883 .53905 Mtetra
.47883 .53905 .48237 .54263 .48868 .54125 .48515 .53766 Mtetra
.608 .743 .941 r
.48515 .53766 .48868 .54125 .49501 .53988 .49148 .53628 Mtetra
.607 .743 .941 r
.49148 .53628 .49501 .53988 .50135 .53851 .49784 .53491 Mtetra
.49784 .53491 .50135 .53851 .50771 .53714 .5042 .53352 Mtetra
.606 .743 .941 r
.5042 .53352 .50771 .53714 .51409 .53578 .51059 .53215 Mtetra
.606 .743 .942 r
.51059 .53215 .51409 .53578 .52048 .53442 .51699 .53079 Mtetra
.51699 .53079 .52048 .53442 .52689 .53306 .52341 .52942 Mtetra
.605 .742 .942 r
.52341 .52942 .52689 .53306 .53332 .5317 .52985 .52806 Mtetra
.604 .742 .942 r
.52985 .52806 .53332 .5317 .53977 .53036 .53631 .52671 Mtetra
.53631 .52671 .53977 .53036 .54623 .52901 .54278 .52535 Mtetra
.603 .742 .942 r
.54278 .52535 .54623 .52901 .55271 .52767 .54927 .524 Mtetra
.601 .741 .943 r
.54927 .524 .55271 .52767 .55921 .52634 .55578 .52266 Mtetra
.602 .741 .943 r
.55578 .52266 .55921 .52634 .56573 .52501 .5623 .52132 Mtetra
.601 .741 .943 r
.5623 .52132 .56573 .52501 .57226 .52367 .56885 .51998 Mtetra
.599 .74 .943 r
.56885 .51998 .57226 .52367 .57881 .52237 .57541 .51866 Mtetra
.57541 .51866 .57881 .52237 .58538 .52105 .58199 .51734 Mtetra
.58199 .51734 .58538 .52105 .59197 .51973 .58859 .51602 Mtetra
.597 .739 .944 r
.58859 .51602 .59197 .51973 .59858 .51845 .59521 .51472 Mtetra
.596 .739 .944 r
.59521 .51472 .59858 .51845 .60521 .51716 .60184 .51343 Mtetra
.60184 .51343 .60521 .51716 .61186 .51588 .6085 .51214 Mtetra
.595 .738 .944 r
.6085 .51214 .61186 .51588 .61852 .5146 .61518 .51085 Mtetra
.594 .738 .944 r
.61518 .51085 .61852 .5146 .62521 .51333 .62187 .50957 Mtetra
.593 .738 .945 r
.62187 .50957 .62521 .51333 .63191 .51207 .62858 .50831 Mtetra
.592 .737 .945 r
.62858 .50831 .63191 .51207 .63863 .51082 .63532 .50705 Mtetra
.591 .737 .945 r
.63532 .50705 .63863 .51082 .64537 .50958 .64207 .50579 Mtetra
.589 .736 .945 r
.64207 .50579 .64537 .50958 .65214 .50835 .64884 .50456 Mtetra
.64884 .50456 .65214 .50835 .65892 .50713 .65564 .50333 Mtetra
.588 .736 .945 r
.65564 .50333 .65892 .50713 .66572 .50591 .66245 .50211 Mtetra
.586 .735 .946 r
.66245 .50211 .66572 .50591 .67255 .50472 .66928 .5009 Mtetra
.585 .734 .946 r
.66928 .5009 .67255 .50472 .67939 .50353 .67614 .49971 Mtetra
.584 .734 .946 r
.67614 .49971 .67939 .50353 .68626 .50236 .68301 .49852 Mtetra
.582 .733 .946 r
.68301 .49852 .68626 .50236 .69314 .5012 .68991 .49736 Mtetra
.581 .733 .947 r
.68991 .49736 .69314 .5012 .70005 .50005 .69683 .4962 Mtetra
.58 .732 .947 r
.69683 .4962 .70005 .50005 .70698 .49892 .70377 .49506 Mtetra
.578 .731 .947 r
.70377 .49506 .70698 .49892 .71393 .4978 .71073 .49393 Mtetra
.577 .731 .947 r
.71073 .49393 .71393 .4978 .72091 .4967 .71772 .49282 Mtetra
.575 .73 .948 r
.71772 .49282 .72091 .4967 .7279 .49561 .72472 .49173 Mtetra
.574 .73 .948 r
.72472 .49173 .7279 .49561 .73492 .49454 .73175 .49064 Mtetra
.572 .728 .948 r
.73175 .49064 .73492 .49454 .74196 .49349 .7388 .48959 Mtetra
.57 .728 .949 r
.7388 .48959 .74196 .49349 .74903 .49246 .74588 .48855 Mtetra
.569 .727 .949 r
.74588 .48855 .74903 .49246 .75611 .49144 .75298 .48753 Mtetra
.566 .726 .949 r
.75298 .48753 .75611 .49144 .76323 .49046 .7601 .48653 Mtetra
.565 .725 .949 r
.7601 .48653 .76323 .49046 .77036 .48948 .76725 .48555 Mtetra
.564 .725 .949 r
.76725 .48555 .77036 .48948 .77752 .48852 .77442 .48458 Mtetra
.563 .724 .95 r
.77442 .48458 .77752 .48852 .7847 .48757 .78161 .48362 Mtetra
.564 .725 .949 r
.78161 .48362 .7847 .48757 .79191 .4866 .78883 .48264 Mtetra
.567 .726 .949 r
.78883 .48264 .79191 .4866 .79913 .48558 .79607 .48161 Mtetra
.583 .734 .946 r
.79607 .48161 .79913 .48558 .80636 .48435 .80331 .48038 Mtetra
.598 .741 .944 r
.80331 .48038 .80636 .48435 .81359 .48291 .81055 .47893 Mtetra
.646 .761 .933 r
.81055 .47893 .81359 .48291 .82079 .48077 .81776 .47677 Mtetra
.709 .785 .911 r
.81776 .47677 .82079 .48077 .82789 .47751 .82488 .47351 Mtetra
.749 .798 .893 r
.82488 .47351 .82789 .47751 .83494 .47342 .83193 .4694 Mtetra
.862 .821 .807 r
.83193 .4694 .83494 .47342 .84164 .46572 .83866 .46168 Mtetra
.902 .821 .758 r
.83866 .46168 .84164 .46572 .84811 .45573 .84515 .45168 Mtetra
.939 .813 .694 r
.84515 .45168 .84811 .45573 .85422 .4423 .85128 .43823 Mtetra
.967 .795 .618 r
.85128 .43823 .85422 .4423 .85973 .42334 .85681 .41925 Mtetra
.974 .786 .589 r
.85681 .41925 .85973 .42334 .8649 .40178 .862 .39765 Mtetra
.931 .563 .289 r
.23041 .51713 .23419 .5205 .23825 .53669 .23446 .53333 Mtetra
.925 .546 .26 r
.23446 .53333 .23825 .53669 .24249 .55162 .23868 .54827 Mtetra
.898 .479 .15 r
.23868 .54827 .24249 .55162 .24708 .56307 .24326 .55973 Mtetra
.834 .368 0 r
.24326 .55973 .24708 .56307 .25195 .57172 .24812 .56838 Mtetra
.731 .228 0 r
.24812 .56838 .25195 .57172 .25702 .57848 .25319 .57514 Mtetra
0 .322 .78 r
.25319 .57514 .25702 .57848 .26241 .58156 .25858 .57822 Mtetra
.093 .49 .899 r
.25858 .57822 .26241 .58156 .26791 .58361 .26408 .58027 Mtetra
.365 .645 .963 r
.26408 .58027 .26791 .58361 .27353 .58431 .26971 .58096 Mtetra
.516 .712 .96 r
.26971 .58096 .27353 .58431 .27925 .58394 .27543 .58059 Mtetra
.554 .726 .954 r
.27543 .58059 .27925 .58394 .28501 .58324 .2812 .57988 Mtetra
.593 .739 .945 r
.2812 .57988 .28501 .58324 .29082 .58213 .28701 .57877 Mtetra
.605 .743 .942 r
.28701 .57877 .29082 .58213 .29665 .58089 .29285 .57752 Mtetra
.612 .745 .94 r
.29285 .57752 .29665 .58089 .3025 .57957 .29871 .57619 Mtetra
.616 .746 .939 r
.29871 .57619 .3025 .57957 .30836 .5782 .30458 .57481 Mtetra
.616 .747 .939 r
.30458 .57481 .30836 .5782 .31425 .57682 .31047 .57342 Mtetra
.617 .747 .939 r
.31047 .57342 .31425 .57682 .32014 .57542 .31638 .57202 Mtetra
.31638 .57202 .32014 .57542 .32606 .57403 .3223 .57062 Mtetra
.3223 .57062 .32606 .57403 .33199 .57263 .32823 .56922 Mtetra
.32823 .56922 .33199 .57263 .33793 .57123 .33418 .56781 Mtetra
.616 .747 .939 r
.33418 .56781 .33793 .57123 .34388 .56983 .34015 .5664 Mtetra
.34015 .5664 .34388 .56983 .34986 .56843 .34613 .56499 Mtetra
.34613 .56499 .34986 .56843 .35584 .56703 .35212 .56358 Mtetra
.616 .746 .939 r
.35212 .56358 .35584 .56703 .36185 .56562 .35813 .56217 Mtetra
.615 .746 .939 r
.35813 .56217 .36185 .56562 .36786 .56422 .36415 .56076 Mtetra
.36415 .56076 .36786 .56422 .37389 .56282 .3702 .55935 Mtetra
.3702 .55935 .37389 .56282 .37994 .56141 .37625 .55794 Mtetra
.37625 .55794 .37994 .56141 .386 .56 .38232 .55652 Mtetra
.614 .746 .939 r
.38232 .55652 .386 .56 .39208 .5586 .38841 .55511 Mtetra
.38841 .55511 .39208 .5586 .39818 .5572 .39451 .5537 Mtetra
.614 .746 .94 r
.39451 .5537 .39818 .5572 .40428 .55579 .40063 .55229 Mtetra
.613 .746 .94 r
.40063 .55229 .40428 .55579 .41041 .55439 .40676 .55088 Mtetra
.40676 .55088 .41041 .55439 .41655 .55299 .41291 .54947 Mtetra
.613 .745 .94 r
.41291 .54947 .41655 .55299 .42271 .55159 .41907 .54806 Mtetra
.612 .745 .94 r
.41907 .54806 .42271 .55159 .42888 .55019 .42525 .54666 Mtetra
.42525 .54666 .42888 .55019 .43506 .5488 .43145 .54526 Mtetra
.43145 .54526 .43506 .5488 .44127 .5474 .43766 .54385 Mtetra
.611 .745 .94 r
.43766 .54385 .44127 .5474 .44749 .546 .44389 .54244 Mtetra
.61 .745 .941 r
.44389 .54244 .44749 .546 .45372 .54461 .45013 .54105 Mtetra
.61 .745 .94 r
.45013 .54105 .45372 .54461 .45998 .54322 .45639 .53964 Mtetra
.61 .745 .941 r
.45639 .53964 .45998 .54322 .46624 .54182 .46267 .53824 Mtetra
.609 .744 .941 r
.46267 .53824 .46624 .54182 .47253 .54044 .46896 .53685 Mtetra
.46896 .53685 .47253 .54044 .47883 .53905 .47527 .53546 Mtetra
.47527 .53546 .47883 .53905 .48515 .53766 .4816 .53406 Mtetra
.608 .744 .941 r
.4816 .53406 .48515 .53766 .49148 .53628 .48794 .53267 Mtetra
.607 .744 .941 r
.48794 .53267 .49148 .53628 .49784 .53491 .49431 .53129 Mtetra
.49431 .53129 .49784 .53491 .5042 .53352 .50068 .5299 Mtetra
.606 .743 .942 r
.50068 .5299 .5042 .53352 .51059 .53215 .50708 .52852 Mtetra
.50708 .52852 .51059 .53215 .51699 .53079 .51349 .52715 Mtetra
.51349 .52715 .51699 .53079 .52341 .52942 .51992 .52577 Mtetra
.605 .743 .942 r
.51992 .52577 .52341 .52942 .52985 .52806 .52637 .5244 Mtetra
.604 .742 .942 r
.52637 .5244 .52985 .52806 .53631 .52671 .53283 .52304 Mtetra
.53283 .52304 .53631 .52671 .54278 .52535 .53931 .52168 Mtetra
.603 .742 .942 r
.53931 .52168 .54278 .52535 .54927 .524 .54581 .52032 Mtetra
.601 .741 .943 r
.54581 .52032 .54927 .524 .55578 .52266 .55233 .51897 Mtetra
.55233 .51897 .55578 .52266 .5623 .52132 .55886 .51762 Mtetra
.55886 .51762 .5623 .52132 .56885 .51998 .56542 .51628 Mtetra
.599 .74 .943 r
.56542 .51628 .56885 .51998 .57541 .51866 .57199 .51495 Mtetra
.57199 .51495 .57541 .51866 .58199 .51734 .57858 .51362 Mtetra
.57858 .51362 .58199 .51734 .58859 .51602 .58519 .51229 Mtetra
.596 .739 .944 r
.58519 .51229 .58859 .51602 .59521 .51472 .59182 .51098 Mtetra
.59182 .51098 .59521 .51472 .60184 .51343 .59846 .50968 Mtetra
.59846 .50968 .60184 .51343 .6085 .51214 .60513 .50838 Mtetra
.595 .739 .944 r
.60513 .50838 .6085 .51214 .61518 .51085 .61182 .50709 Mtetra
.594 .738 .944 r
.61182 .50709 .61518 .51085 .62187 .50957 .61852 .5058 Mtetra
.593 .738 .945 r
.61852 .5058 .62187 .50957 .62858 .50831 .62524 .50453 Mtetra
.592 .738 .945 r
.62524 .50453 .62858 .50831 .63532 .50705 .63199 .50326 Mtetra
.591 .737 .945 r
.63199 .50326 .63532 .50705 .64207 .50579 .63875 .502 Mtetra
.589 .737 .945 r
.63875 .502 .64207 .50579 .64884 .50456 .64553 .50076 Mtetra
.589 .736 .946 r
.64553 .50076 .64884 .50456 .65564 .50333 .65234 .49952 Mtetra
.588 .736 .946 r
.65234 .49952 .65564 .50333 .66245 .50211 .65916 .49829 Mtetra
.586 .735 .946 r
.65916 .49829 .66245 .50211 .66928 .5009 .66601 .49708 Mtetra
.585 .735 .946 r
.66601 .49708 .66928 .5009 .67614 .49971 .67287 .49587 Mtetra
.584 .734 .946 r
.67287 .49587 .67614 .49971 .68301 .49852 .67976 .49468 Mtetra
.582 .734 .947 r
.67976 .49468 .68301 .49852 .68991 .49736 .68666 .4935 Mtetra
.581 .733 .947 r
.68666 .4935 .68991 .49736 .69683 .4962 .69359 .49234 Mtetra
.58 .733 .947 r
.69359 .49234 .69683 .4962 .70377 .49506 .70054 .49119 Mtetra
.578 .732 .948 r
.70054 .49119 .70377 .49506 .71073 .49393 .70752 .49005 Mtetra
.577 .731 .948 r
.70752 .49005 .71073 .49393 .71772 .49282 .71451 .48894 Mtetra
.575 .731 .948 r
.71451 .48894 .71772 .49282 .72472 .49173 .72153 .48783 Mtetra
.574 .73 .948 r
.72153 .48783 .72472 .49173 .73175 .49064 .72857 .48674 Mtetra
.571 .729 .949 r
.72857 .48674 .73175 .49064 .7388 .48959 .73563 .48568 Mtetra
.57 .728 .949 r
.73563 .48568 .7388 .48959 .74588 .48855 .74272 .48464 Mtetra
.569 .728 .949 r
.74272 .48464 .74588 .48855 .75298 .48753 .74983 .4836 Mtetra
.566 .726 .949 r
.74983 .4836 .75298 .48753 .7601 .48653 .75697 .4826 Mtetra
.565 .726 .95 r
.75697 .4826 .7601 .48653 .76725 .48555 .76412 .48161 Mtetra
.564 .725 .95 r
.76412 .48161 .76725 .48555 .77442 .48458 .77131 .48063 Mtetra
.562 .725 .95 r
.77131 .48063 .77442 .48458 .78161 .48362 .77851 .47966 Mtetra
.564 .725 .95 r
.77851 .47966 .78161 .48362 .78883 .48264 .78574 .47867 Mtetra
.567 .727 .949 r
.78574 .47867 .78883 .48264 .79607 .48161 .79299 .47764 Mtetra
.583 .734 .947 r
.79299 .47764 .79607 .48161 .80331 .48038 .80024 .47639 Mtetra
.598 .741 .944 r
.80024 .47639 .80331 .48038 .81055 .47893 .8075 .47493 Mtetra
.646 .762 .933 r
.8075 .47493 .81055 .47893 .81776 .47677 .81471 .47277 Mtetra
.709 .786 .912 r
.81471 .47277 .81776 .47677 .82488 .47351 .82185 .46949 Mtetra
.749 .799 .893 r
.82185 .46949 .82488 .47351 .83193 .4694 .82892 .46537 Mtetra
.862 .822 .807 r
.82892 .46537 .83193 .4694 .83866 .46168 .83566 .45764 Mtetra
.902 .821 .758 r
.83566 .45764 .83866 .46168 .84515 .45168 .84217 .44761 Mtetra
.939 .813 .694 r
.84217 .44761 .84515 .45168 .85128 .43823 .84832 .43414 Mtetra
.967 .795 .618 r
.84832 .43414 .85128 .43823 .85681 .41925 .85387 .41513 Mtetra
.974 .786 .589 r
.85387 .41513 .85681 .41925 .862 .39765 .85909 .3935 Mtetra
.931 .563 .289 r
.22661 .51376 .23041 .51713 .23446 .53333 .23064 .52997 Mtetra
.925 .546 .26 r
.23064 .52997 .23446 .53333 .23868 .54827 .23485 .54492 Mtetra
.898 .479 .15 r
.23485 .54492 .23868 .54827 .24326 .55973 .23942 .55639 Mtetra
.834 .368 0 r
.23942 .55639 .24326 .55973 .24812 .56838 .24428 .56504 Mtetra
.732 .228 0 r
.24428 .56504 .24812 .56838 .25319 .57514 .24934 .5718 Mtetra
0 .321 .779 r
.24934 .5718 .25319 .57514 .25858 .57822 .25473 .57488 Mtetra
.092 .49 .899 r
.25473 .57488 .25858 .57822 .26408 .58027 .26023 .57692 Mtetra
.364 .645 .963 r
.26023 .57692 .26408 .58027 .26971 .58096 .26586 .57761 Mtetra
.516 .712 .961 r
.26586 .57761 .26971 .58096 .27543 .58059 .2716 .57723 Mtetra
.553 .726 .955 r
.2716 .57723 .27543 .58059 .2812 .57988 .27737 .57651 Mtetra
.593 .74 .946 r
.27737 .57651 .2812 .57988 .28701 .57877 .28319 .57539 Mtetra
.605 .744 .942 r
.28319 .57539 .28701 .57877 .29285 .57752 .28903 .57414 Mtetra
.611 .745 .941 r
.28903 .57414 .29285 .57752 .29871 .57619 .2949 .5728 Mtetra
.616 .747 .939 r
.2949 .5728 .29871 .57619 .30458 .57481 .30078 .57142 Mtetra
.30078 .57142 .30458 .57481 .31047 .57342 .30668 .57002 Mtetra
.617 .747 .939 r
.30668 .57002 .31047 .57342 .31638 .57202 .31259 .56861 Mtetra
.31259 .56861 .31638 .57202 .3223 .57062 .31852 .5672 Mtetra
.31852 .5672 .3223 .57062 .32823 .56922 .32446 .56579 Mtetra
.32446 .56579 .32823 .56922 .33418 .56781 .33042 .56437 Mtetra
.616 .747 .939 r
.33042 .56437 .33418 .56781 .34015 .5664 .33639 .56296 Mtetra
.33639 .56296 .34015 .5664 .34613 .56499 .34238 .56154 Mtetra
.34238 .56154 .34613 .56499 .35212 .56358 .34838 .56012 Mtetra
.34838 .56012 .35212 .56358 .35813 .56217 .3544 .55871 Mtetra
.615 .746 .939 r
.3544 .55871 .35813 .56217 .36415 .56076 .36043 .55729 Mtetra
.615 .747 .939 r
.36043 .55729 .36415 .56076 .3702 .55935 .36648 .55587 Mtetra
.615 .746 .939 r
.36648 .55587 .3702 .55935 .37625 .55794 .37254 .55445 Mtetra
.37254 .55445 .37625 .55794 .38232 .55652 .37862 .55303 Mtetra
.614 .746 .94 r
.37862 .55303 .38232 .55652 .38841 .55511 .38472 .55161 Mtetra
.38472 .55161 .38841 .55511 .39451 .5537 .39083 .55019 Mtetra
.39083 .55019 .39451 .5537 .40063 .55229 .39695 .54878 Mtetra
.613 .746 .94 r
.39695 .54878 .40063 .55229 .40676 .55088 .40309 .54736 Mtetra
.40309 .54736 .40676 .55088 .41291 .54947 .40925 .54594 Mtetra
.40925 .54594 .41291 .54947 .41907 .54806 .41542 .54453 Mtetra
.612 .745 .94 r
.41542 .54453 .41907 .54806 .42525 .54666 .42161 .54311 Mtetra
.42161 .54311 .42525 .54666 .43145 .54526 .42781 .5417 Mtetra
.42781 .5417 .43145 .54526 .43766 .54385 .43404 .54029 Mtetra
.611 .745 .94 r
.43404 .54029 .43766 .54385 .44389 .54244 .44027 .53888 Mtetra
.61 .745 .941 r
.44027 .53888 .44389 .54244 .45013 .54105 .44652 .53747 Mtetra
.44652 .53747 .45013 .54105 .45639 .53964 .45279 .53606 Mtetra
.45279 .53606 .45639 .53964 .46267 .53824 .45908 .53465 Mtetra
.609 .744 .941 r
.45908 .53465 .46267 .53824 .46896 .53685 .46538 .53325 Mtetra
.46538 .53325 .46896 .53685 .47527 .53546 .4717 .53185 Mtetra
.4717 .53185 .47527 .53546 .4816 .53406 .47804 .53044 Mtetra
.607 .744 .941 r
.47804 .53044 .4816 .53406 .48794 .53267 .48439 .52905 Mtetra
.607 .744 .942 r
.48439 .52905 .48794 .53267 .49431 .53129 .49076 .52766 Mtetra
.49076 .52766 .49431 .53129 .50068 .5299 .49715 .52626 Mtetra
.606 .743 .942 r
.49715 .52626 .50068 .5299 .50708 .52852 .50355 .52488 Mtetra
.605 .743 .942 r
.50355 .52488 .50708 .52852 .51349 .52715 .50997 .5235 Mtetra
.606 .743 .942 r
.50997 .5235 .51349 .52715 .51992 .52577 .51641 .52211 Mtetra
.604 .743 .942 r
.51641 .52211 .51992 .52577 .52637 .5244 .52287 .52073 Mtetra
.603 .742 .943 r
.52287 .52073 .52637 .5244 .53283 .52304 .52934 .51937 Mtetra
.604 .742 .943 r
.52934 .51937 .53283 .52304 .53931 .52168 .53583 .51799 Mtetra
.603 .742 .943 r
.53583 .51799 .53931 .52168 .54581 .52032 .54234 .51663 Mtetra
.601 .742 .943 r
.54234 .51663 .54581 .52032 .55233 .51897 .54887 .51527 Mtetra
.54887 .51527 .55233 .51897 .55886 .51762 .55541 .51392 Mtetra
.55541 .51392 .55886 .51762 .56542 .51628 .56197 .51256 Mtetra
.599 .741 .944 r
.56197 .51256 .56542 .51628 .57199 .51495 .56856 .51123 Mtetra
.56856 .51123 .57199 .51495 .57858 .51362 .57516 .50989 Mtetra
.57516 .50989 .57858 .51362 .58519 .51229 .58178 .50855 Mtetra
.596 .74 .944 r
.58178 .50855 .58519 .51229 .59182 .51098 .58841 .50724 Mtetra
.58841 .50724 .59182 .51098 .59846 .50968 .59507 .50593 Mtetra
.595 .739 .944 r
.59507 .50593 .59846 .50968 .60513 .50838 .60175 .50462 Mtetra
.595 .739 .945 r
.60175 .50462 .60513 .50838 .61182 .50709 .60844 .50332 Mtetra
.594 .739 .945 r
.60844 .50332 .61182 .50709 .61852 .5058 .61515 .50202 Mtetra
.592 .738 .945 r
.61515 .50202 .61852 .5058 .62524 .50453 .62189 .50074 Mtetra
.62189 .50074 .62524 .50453 .63199 .50326 .62864 .49947 Mtetra
.591 .738 .945 r
.62864 .49947 .63199 .50326 .63875 .502 .63542 .49819 Mtetra
.589 .737 .946 r
.63542 .49819 .63875 .502 .64553 .50076 .64221 .49695 Mtetra
.588 .737 .946 r
.64221 .49695 .64553 .50076 .65234 .49952 .64902 .4957 Mtetra
.588 .736 .946 r
.64902 .4957 .65234 .49952 .65916 .49829 .65586 .49446 Mtetra
.586 .736 .946 r
.65586 .49446 .65916 .49829 .66601 .49708 .66271 .49324 Mtetra
.585 .735 .947 r
.66271 .49324 .66601 .49708 .67287 .49587 .66959 .49203 Mtetra
.584 .735 .947 r
.66959 .49203 .67287 .49587 .67976 .49468 .67649 .49083 Mtetra
.582 .734 .947 r
.67649 .49083 .67976 .49468 .68666 .4935 .6834 .48964 Mtetra
.581 .734 .947 r
.6834 .48964 .68666 .4935 .69359 .49234 .69034 .48847 Mtetra
.58 .733 .948 r
.69034 .48847 .69359 .49234 .70054 .49119 .69731 .48731 Mtetra
.578 .732 .948 r
.69731 .48731 .70054 .49119 .70752 .49005 .70429 .48617 Mtetra
.577 .732 .948 r
.70429 .48617 .70752 .49005 .71451 .48894 .7113 .48504 Mtetra
.575 .731 .948 r
.7113 .48504 .71451 .48894 .72153 .48783 .71832 .48393 Mtetra
.574 .73 .949 r
.71832 .48393 .72153 .48783 .72857 .48674 .72538 .48283 Mtetra
.571 .729 .949 r
.72538 .48283 .72857 .48674 .73563 .48568 .73245 .48176 Mtetra
.57 .729 .949 r
.73245 .48176 .73563 .48568 .74272 .48464 .73955 .48071 Mtetra
.569 .728 .949 r
.73955 .48071 .74272 .48464 .74983 .4836 .74667 .47967 Mtetra
.566 .727 .95 r
.74667 .47967 .74983 .4836 .75697 .4826 .75382 .47865 Mtetra
.565 .726 .95 r
.75382 .47865 .75697 .4826 .76412 .48161 .76098 .47765 Mtetra
.563 .726 .95 r
.76098 .47765 .76412 .48161 .77131 .48063 .76818 .47667 Mtetra
.562 .725 .95 r
.76818 .47667 .77131 .48063 .77851 .47966 .7754 .47569 Mtetra
.564 .726 .95 r
.7754 .47569 .77851 .47966 .78574 .47867 .78264 .4747 Mtetra
.567 .727 .95 r
.78264 .4747 .78574 .47867 .79299 .47764 .78989 .47365 Mtetra
.583 .735 .947 r
.78989 .47365 .79299 .47764 .80024 .47639 .79716 .4724 Mtetra
.598 .742 .945 r
.79716 .4724 .80024 .47639 .8075 .47493 .80443 .47093 Mtetra
.646 .762 .934 r
.80443 .47093 .8075 .47493 .81471 .47277 .81166 .46875 Mtetra
.709 .786 .912 r
.81166 .46875 .81471 .47277 .82185 .46949 .81881 .46546 Mtetra
.749 .799 .893 r
.81881 .46546 .82185 .46949 .82892 .46537 .82589 .46133 Mtetra
.862 .822 .807 r
.82589 .46133 .82892 .46537 .83566 .45764 .83265 .45357 Mtetra
.902 .822 .758 r
.83265 .45357 .83566 .45764 .84217 .44761 .83917 .44353 Mtetra
.939 .813 .694 r
.83917 .44353 .84217 .44761 .84832 .43414 .84534 .43002 Mtetra
.967 .795 .618 r
.84534 .43002 .84832 .43414 .85387 .41513 .85092 .41098 Mtetra
.974 .786 .589 r
.85092 .41098 .85387 .41513 .85909 .3935 .85617 .38932 Mtetra
.931 .563 .29 r
.2228 .51038 .22661 .51376 .23064 .52997 .22681 .5266 Mtetra
.925 .546 .26 r
.22681 .5266 .23064 .52997 .23485 .54492 .231 .54155 Mtetra
.898 .479 .15 r
.231 .54155 .23485 .54492 .23942 .55639 .23556 .55303 Mtetra
.834 .368 0 r
.23556 .55303 .23942 .55639 .24428 .56504 .24042 .56168 Mtetra
.732 .228 0 r
.24042 .56168 .24428 .56504 .24934 .5718 .24547 .56844 Mtetra
0 .321 .78 r
.24547 .56844 .24934 .5718 .25473 .57488 .25087 .57152 Mtetra
.093 .49 .899 r
.25087 .57152 .25473 .57488 .26023 .57692 .25637 .57356 Mtetra
.365 .645 .963 r
.25637 .57356 .26023 .57692 .26586 .57761 .26201 .57424 Mtetra
.516 .712 .961 r
.26201 .57424 .26586 .57761 .2716 .57723 .26775 .57385 Mtetra
.554 .726 .955 r
.26775 .57385 .2716 .57723 .27737 .57651 .27353 .57313 Mtetra
.593 .74 .946 r
.27353 .57313 .27737 .57651 .28319 .57539 .27935 .572 Mtetra
.605 .743 .942 r
.27935 .572 .28319 .57539 .28903 .57414 .2852 .57074 Mtetra
.612 .745 .94 r
.2852 .57074 .28903 .57414 .2949 .5728 .29108 .5694 Mtetra
.616 .747 .939 r
.29108 .5694 .2949 .5728 .30078 .57142 .29696 .56801 Mtetra
.29696 .56801 .30078 .57142 .30668 .57002 .30287 .5666 Mtetra
.617 .747 .939 r
.30287 .5666 .30668 .57002 .31259 .56861 .30879 .56519 Mtetra
.30879 .56519 .31259 .56861 .31852 .5672 .31473 .56377 Mtetra
.31473 .56377 .31852 .5672 .32446 .56579 .32068 .56235 Mtetra
.32068 .56235 .32446 .56579 .33042 .56437 .32664 .56093 Mtetra
.616 .747 .939 r
.32664 .56093 .33042 .56437 .33639 .56296 .33262 .55951 Mtetra
.33262 .55951 .33639 .56296 .34238 .56154 .33862 .55808 Mtetra
.33862 .55808 .34238 .56154 .34838 .56012 .34463 .55666 Mtetra
.34463 .55666 .34838 .56012 .3544 .55871 .35065 .55523 Mtetra
.615 .747 .939 r
.35065 .55523 .3544 .55871 .36043 .55729 .35669 .55381 Mtetra
.35669 .55381 .36043 .55729 .36648 .55587 .36275 .55238 Mtetra
.36275 .55238 .36648 .55587 .37254 .55445 .36882 .55096 Mtetra
.615 .747 .94 r
.36882 .55096 .37254 .55445 .37862 .55303 .37491 .54953 Mtetra
.614 .746 .94 r
.37491 .54953 .37862 .55303 .38472 .55161 .38101 .5481 Mtetra
.38101 .5481 .38472 .55161 .39083 .55019 .38713 .54668 Mtetra
.38713 .54668 .39083 .55019 .39695 .54878 .39326 .54525 Mtetra
.613 .746 .94 r
.39326 .54525 .39695 .54878 .40309 .54736 .39941 .54383 Mtetra
.39941 .54383 .40309 .54736 .40925 .54594 .40558 .5424 Mtetra
.612 .746 .94 r
.40558 .5424 .40925 .54594 .41542 .54453 .41176 .54098 Mtetra
.41176 .54098 .41542 .54453 .42161 .54311 .41795 .53956 Mtetra
.611 .746 .941 r
.41795 .53956 .42161 .54311 .42781 .5417 .42417 .53814 Mtetra
.612 .746 .941 r
.42417 .53814 .42781 .5417 .43404 .54029 .4304 .53672 Mtetra
.611 .746 .941 r
.4304 .53672 .43404 .54029 .44027 .53888 .43664 .5353 Mtetra
.61 .745 .941 r
.43664 .5353 .44027 .53888 .44652 .53747 .4429 .53389 Mtetra
.4429 .53389 .44652 .53747 .45279 .53606 .44918 .53247 Mtetra
.44918 .53247 .45279 .53606 .45908 .53465 .45548 .53105 Mtetra
.609 .745 .941 r
.45548 .53105 .45908 .53465 .46538 .53325 .46179 .52964 Mtetra
.46179 .52964 .46538 .53325 .4717 .53185 .46811 .52823 Mtetra
.46811 .52823 .4717 .53185 .47804 .53044 .47446 .52682 Mtetra
.607 .744 .942 r
.47446 .52682 .47804 .53044 .48439 .52905 .48082 .52542 Mtetra
.48082 .52542 .48439 .52905 .49076 .52766 .4872 .52402 Mtetra
.4872 .52402 .49076 .52766 .49715 .52626 .49359 .52262 Mtetra
.606 .744 .942 r
.49359 .52262 .49715 .52626 .50355 .52488 .50001 .52122 Mtetra
.605 .744 .942 r
.50001 .52122 .50355 .52488 .50997 .5235 .50644 .51983 Mtetra
.50644 .51983 .50997 .5235 .51641 .52211 .51289 .51844 Mtetra
.604 .743 .943 r
.51289 .51844 .51641 .52211 .52287 .52073 .51935 .51706 Mtetra
.603 .743 .943 r
.51935 .51706 .52287 .52073 .52934 .51937 .52583 .51568 Mtetra
.52583 .51568 .52934 .51937 .53583 .51799 .53233 .5143 Mtetra
.53233 .5143 .53583 .51799 .54234 .51663 .53885 .51292 Mtetra
.601 .742 .943 r
.53885 .51292 .54234 .51663 .54887 .51527 .54539 .51157 Mtetra
.54539 .51157 .54887 .51527 .55541 .51392 .55194 .5102 Mtetra
.55194 .5102 .55541 .51392 .56197 .51256 .55852 .50884 Mtetra
.599 .741 .944 r
.55852 .50884 .56197 .51256 .56856 .51123 .56511 .5075 Mtetra
.56511 .5075 .56856 .51123 .57516 .50989 .57172 .50615 Mtetra
.57172 .50615 .57516 .50989 .58178 .50855 .57835 .5048 Mtetra
.596 .74 .945 r
.57835 .5048 .58178 .50855 .58841 .50724 .58499 .50348 Mtetra
.58499 .50348 .58841 .50724 .59507 .50593 .59166 .50216 Mtetra
.595 .74 .945 r
.59166 .50216 .59507 .50593 .60175 .50462 .59835 .50085 Mtetra
.594 .739 .945 r
.59835 .50085 .60175 .50462 .60844 .50332 .60505 .49954 Mtetra
.60505 .49954 .60844 .50332 .61515 .50202 .61178 .49823 Mtetra
.592 .739 .945 r
.61178 .49823 .61515 .50202 .62189 .50074 .61852 .49695 Mtetra
.591 .738 .946 r
.61852 .49695 .62189 .50074 .62864 .49947 .62528 .49566 Mtetra
.62528 .49566 .62864 .49947 .63542 .49819 .63207 .49438 Mtetra
.589 .737 .946 r
.63207 .49438 .63542 .49819 .64221 .49695 .63887 .49313 Mtetra
.588 .737 .946 r
.63887 .49313 .64221 .49695 .64902 .4957 .6457 .49187 Mtetra
.6457 .49187 .64902 .4957 .65586 .49446 .65254 .49062 Mtetra
.586 .736 .947 r
.65254 .49062 .65586 .49446 .66271 .49324 .65941 .4894 Mtetra
.585 .736 .947 r
.65941 .4894 .66271 .49324 .66959 .49203 .66629 .48818 Mtetra
.584 .735 .947 r
.66629 .48818 .66959 .49203 .67649 .49083 .6732 .48697 Mtetra
.582 .734 .948 r
.6732 .48697 .67649 .49083 .6834 .48964 .68013 .48578 Mtetra
.581 .734 .948 r
.68013 .48578 .6834 .48964 .69034 .48847 .68708 .48459 Mtetra
.579 .733 .948 r
.68708 .48459 .69034 .48847 .69731 .48731 .69405 .48343 Mtetra
.578 .733 .948 r
.69405 .48343 .69731 .48731 .70429 .48617 .70105 .48228 Mtetra
.576 .732 .949 r
.70105 .48228 .70429 .48617 .7113 .48504 .70806 .48114 Mtetra
.575 .731 .949 r
.70806 .48114 .7113 .48504 .71832 .48393 .7151 .48002 Mtetra
.573 .731 .949 r
.7151 .48002 .71832 .48393 .72538 .48283 .72217 .47892 Mtetra
.571 .73 .95 r
.72217 .47892 .72538 .48283 .73245 .48176 .72925 .47784 Mtetra
.569 .729 .95 r
.72925 .47784 .73245 .48176 .73955 .48071 .73636 .47678 Mtetra
.568 .729 .95 r
.73636 .47678 .73955 .48071 .74667 .47967 .74349 .47573 Mtetra
.565 .727 .95 r
.74349 .47573 .74667 .47967 .75382 .47865 .75065 .47471 Mtetra
.564 .727 .951 r
.75065 .47471 .75382 .47865 .76098 .47765 .75783 .4737 Mtetra
.563 .726 .951 r
.75783 .4737 .76098 .47765 .76818 .47667 .76504 .4727 Mtetra
.562 .726 .951 r
.76504 .4727 .76818 .47667 .7754 .47569 .77227 .47172 Mtetra
.563 .727 .951 r
.77227 .47172 .7754 .47569 .78264 .4747 .77952 .47071 Mtetra
.567 .728 .95 r
.77952 .47071 .78264 .4747 .78989 .47365 .78679 .46966 Mtetra
.583 .736 .948 r
.78679 .46966 .78989 .47365 .79716 .4724 .79407 .4684 Mtetra
.598 .743 .945 r
.79407 .4684 .79716 .4724 .80443 .47093 .80135 .46692 Mtetra
.646 .763 .934 r
.80135 .46692 .80443 .47093 .81166 .46875 .80859 .46473 Mtetra
.71 .787 .912 r
.80859 .46473 .81166 .46875 .81881 .46546 .81575 .46143 Mtetra
.75 .8 .893 r
.81575 .46143 .81881 .46546 .82589 .46133 .82285 .45728 Mtetra
.863 .823 .807 r
.82285 .45728 .82589 .46133 .83265 .45357 .82962 .4495 Mtetra
.903 .822 .758 r
.82962 .4495 .83265 .45357 .83917 .44353 .83617 .43943 Mtetra
.939 .813 .694 r
.83617 .43943 .83917 .44353 .84534 .43002 .84236 .42589 Mtetra
.967 .795 .618 r
.84236 .42589 .84534 .43002 .85092 .41098 .84796 .40681 Mtetra
.974 .786 .589 r
.84796 .40681 .85092 .41098 .85617 .38932 .85323 .3851 Mtetra
.931 .563 .29 r
.21897 .50699 .2228 .51038 .22681 .5266 .22296 .52322 Mtetra
.925 .546 .26 r
.22296 .52322 .22681 .5266 .231 .54155 .22714 .53818 Mtetra
.898 .479 .15 r
.22714 .53818 .231 .54155 .23556 .55303 .23169 .54966 Mtetra
.835 .368 0 r
.23169 .54966 .23556 .55303 .24042 .56168 .23654 .55831 Mtetra
.732 .228 0 r
.23654 .55831 .24042 .56168 .24547 .56844 .24159 .56508 Mtetra
0 .321 .779 r
.24159 .56508 .24547 .56844 .25087 .57152 .24699 .56815 Mtetra
.092 .49 .899 r
.24699 .56815 .25087 .57152 .25637 .57356 .25249 .57019 Mtetra
.364 .645 .963 r
.25249 .57019 .25637 .57356 .26201 .57424 .25814 .57086 Mtetra
.516 .712 .961 r
.25814 .57086 .26201 .57424 .26775 .57385 .26388 .57047 Mtetra
.553 .726 .955 r
.26388 .57047 .26775 .57385 .27353 .57313 .26967 .56974 Mtetra
.593 .74 .946 r
.26967 .56974 .27353 .57313 .27935 .572 .2755 .5686 Mtetra
.605 .744 .942 r
.2755 .5686 .27935 .572 .2852 .57074 .28136 .56733 Mtetra
.611 .746 .941 r
.28136 .56733 .2852 .57074 .29108 .5694 .28724 .56599 Mtetra
.616 .747 .939 r
.28724 .56599 .29108 .5694 .29696 .56801 .29313 .56459 Mtetra
.29313 .56459 .29696 .56801 .30287 .5666 .29905 .56318 Mtetra
.617 .747 .939 r
.29905 .56318 .30287 .5666 .30879 .56519 .30497 .56175 Mtetra
.30497 .56175 .30879 .56519 .31473 .56377 .31092 .56033 Mtetra
.31092 .56033 .31473 .56377 .32068 .56235 .31687 .5589 Mtetra
.31687 .5589 .32068 .56235 .32664 .56093 .32285 .55747 Mtetra
.616 .747 .939 r
.32285 .55747 .32664 .56093 .33262 .55951 .32884 .55604 Mtetra
.32884 .55604 .33262 .55951 .33862 .55808 .33484 .55461 Mtetra
.33484 .55461 .33862 .55808 .34463 .55666 .34086 .55318 Mtetra
.34086 .55318 .34463 .55666 .35065 .55523 .34689 .55175 Mtetra
.615 .747 .94 r
.34689 .55175 .35065 .55523 .35669 .55381 .35294 .55032 Mtetra
.35294 .55032 .35669 .55381 .36275 .55238 .359 .54889 Mtetra
.359 .54889 .36275 .55238 .36882 .55096 .36508 .54745 Mtetra
.36508 .54745 .36882 .55096 .37491 .54953 .37118 .54601 Mtetra
.614 .747 .94 r
.37118 .54601 .37491 .54953 .38101 .5481 .37729 .54458 Mtetra
.37729 .54458 .38101 .5481 .38713 .54668 .38341 .54315 Mtetra
.614 .746 .94 r
.38341 .54315 .38713 .54668 .39326 .54525 .38955 .54172 Mtetra
.613 .746 .94 r
.38955 .54172 .39326 .54525 .39941 .54383 .39571 .54028 Mtetra
.39571 .54028 .39941 .54383 .40558 .5424 .40189 .53885 Mtetra
.612 .746 .94 r
.40189 .53885 .40558 .5424 .41176 .54098 .40807 .53742 Mtetra
.612 .746 .941 r
.40807 .53742 .41176 .54098 .41795 .53956 .41428 .53599 Mtetra
.611 .746 .941 r
.41428 .53599 .41795 .53956 .42417 .53814 .4205 .53457 Mtetra
.612 .746 .941 r
.4205 .53457 .42417 .53814 .4304 .53672 .42674 .53314 Mtetra
.611 .746 .941 r
.42674 .53314 .4304 .53672 .43664 .5353 .43299 .53171 Mtetra
.61 .745 .941 r
.43299 .53171 .43664 .5353 .4429 .53389 .43926 .53029 Mtetra
.43926 .53029 .4429 .53389 .44918 .53247 .44555 .52887 Mtetra
.44555 .52887 .44918 .53247 .45548 .53105 .45185 .52744 Mtetra
.609 .745 .942 r
.45185 .52744 .45548 .53105 .46179 .52964 .45817 .52603 Mtetra
.45817 .52603 .46179 .52964 .46811 .52823 .46451 .52461 Mtetra
.46451 .52461 .46811 .52823 .47446 .52682 .47086 .52319 Mtetra
.607 .744 .942 r
.47086 .52319 .47446 .52682 .48082 .52542 .47723 .52178 Mtetra
.47723 .52178 .48082 .52542 .4872 .52402 .48362 .52037 Mtetra
.48362 .52037 .4872 .52402 .49359 .52262 .49003 .51896 Mtetra
.606 .744 .942 r
.49003 .51896 .49359 .52262 .50001 .52122 .49645 .51756 Mtetra
.605 .744 .942 r
.49645 .51756 .50001 .52122 .50644 .51983 .50289 .51616 Mtetra
.50289 .51616 .50644 .51983 .51289 .51844 .50935 .51476 Mtetra
.604 .743 .943 r
.50935 .51476 .51289 .51844 .51935 .51706 .51582 .51337 Mtetra
.603 .743 .943 r
.51582 .51337 .51935 .51706 .52583 .51568 .52231 .51198 Mtetra
.52231 .51198 .52583 .51568 .53233 .5143 .52882 .5106 Mtetra
.52882 .5106 .53233 .5143 .53885 .51292 .53535 .50921 Mtetra
.601 .742 .944 r
.53535 .50921 .53885 .51292 .54539 .51157 .5419 .50784 Mtetra
.5419 .50784 .54539 .51157 .55194 .5102 .54846 .50647 Mtetra
.54846 .50647 .55194 .5102 .55852 .50884 .55504 .5051 Mtetra
.599 .741 .944 r
.55504 .5051 .55852 .50884 .56511 .5075 .56164 .50375 Mtetra
.56164 .50375 .56511 .5075 .57172 .50615 .56826 .5024 Mtetra
.56826 .5024 .57172 .50615 .57835 .5048 .5749 .50104 Mtetra
.596 .74 .945 r
.5749 .50104 .57835 .5048 .58499 .50348 .58156 .49971 Mtetra
.58156 .49971 .58499 .50348 .59166 .50216 .58824 .49839 Mtetra
.595 .74 .945 r
.58824 .49839 .59166 .50216 .59835 .50085 .59493 .49706 Mtetra
.594 .74 .945 r
.59493 .49706 .59835 .50085 .60505 .49954 .60165 .49575 Mtetra
.60165 .49575 .60505 .49954 .61178 .49823 .60838 .49443 Mtetra
.592 .739 .946 r
.60838 .49443 .61178 .49823 .61852 .49695 .61514 .49314 Mtetra
.591 .739 .946 r
.61514 .49314 .61852 .49695 .62528 .49566 .62191 .49185 Mtetra
.591 .738 .946 r
.62191 .49185 .62528 .49566 .63207 .49438 .6287 .49056 Mtetra
.589 .738 .946 r
.6287 .49056 .63207 .49438 .63887 .49313 .63552 .48929 Mtetra
.588 .737 .947 r
.63552 .48929 .63887 .49313 .6457 .49187 .64235 .48803 Mtetra
.587 .737 .947 r
.64235 .48803 .6457 .49187 .65254 .49062 .64921 .48678 Mtetra
.585 .736 .947 r
.64921 .48678 .65254 .49062 .65941 .4894 .65608 .48554 Mtetra
.65608 .48554 .65941 .4894 .66629 .48818 .66298 .48431 Mtetra
.583 .735 .947 r
.66298 .48431 .66629 .48818 .6732 .48697 .6699 .4831 Mtetra
.582 .735 .948 r
.6699 .4831 .6732 .48697 .68013 .48578 .67684 .4819 Mtetra
.581 .734 .948 r
.67684 .4819 .68013 .48578 .68708 .48459 .6838 .48071 Mtetra
.579 .734 .948 r
.6838 .48071 .68708 .48459 .69405 .48343 .69078 .47953 Mtetra
.578 .733 .949 r
.69078 .47953 .69405 .48343 .70105 .48228 .69779 .47837 Mtetra
.576 .732 .949 r
.69779 .47837 .70105 .48228 .70806 .48114 .70482 .47723 Mtetra
.575 .732 .949 r
.70482 .47723 .70806 .48114 .7151 .48002 .71187 .4761 Mtetra
.573 .731 .949 r
.71187 .4761 .7151 .48002 .72217 .47892 .71894 .47499 Mtetra
.571 .73 .95 r
.71894 .47499 .72217 .47892 .72925 .47784 .72604 .4739 Mtetra
.569 .729 .95 r
.72604 .4739 .72925 .47784 .73636 .47678 .73316 .47283 Mtetra
.568 .729 .95 r
.73316 .47283 .73636 .47678 .74349 .47573 .7403 .47177 Mtetra
.565 .728 .951 r
.7403 .47177 .74349 .47573 .75065 .47471 .74747 .47075 Mtetra
.564 .727 .951 r
.74747 .47075 .75065 .47471 .75783 .4737 .75467 .46973 Mtetra
.563 .727 .951 r
.75467 .46973 .75783 .4737 .76504 .4727 .76188 .46873 Mtetra
.561 .726 .951 r
.76188 .46873 .76504 .4727 .77227 .47172 .76912 .46774 Mtetra
.563 .727 .951 r
.76912 .46774 .77227 .47172 .77952 .47071 .77639 .46672 Mtetra
.566 .728 .951 r
.77639 .46672 .77952 .47071 .78679 .46966 .78367 .46566 Mtetra
.583 .736 .948 r
.78367 .46566 .78679 .46966 .79407 .4684 .79096 .46439 Mtetra
.598 .743 .946 r
.79096 .46439 .79407 .4684 .80135 .46692 .79825 .4629 Mtetra
.646 .764 .934 r
.79825 .4629 .80135 .46692 .80859 .46473 .80551 .4607 Mtetra
.71 .788 .912 r
.80551 .4607 .80859 .46473 .81575 .46143 .81268 .45738 Mtetra
.75 .801 .893 r
.81268 .45738 .81575 .46143 .82285 .45728 .8198 .45321 Mtetra
.863 .823 .807 r
.8198 .45321 .82285 .45728 .82962 .4495 .82658 .44541 Mtetra
.903 .822 .757 r
.82658 .44541 .82962 .4495 .83617 .43943 .83315 .43531 Mtetra
.939 .813 .694 r
.83315 .43531 .83617 .43943 .84236 .42589 .83936 .42174 Mtetra
.967 .795 .618 r
.83936 .42174 .84236 .42589 .84796 .40681 .84498 .40261 Mtetra
.974 .786 .589 r
.84498 .40261 .84796 .40681 .85323 .3851 .85028 .38086 Mtetra
.931 .563 .29 r
.21512 .50359 .21897 .50699 .22296 .52322 .2191 .51984 Mtetra
.925 .546 .261 r
.2191 .51984 .22296 .52322 .22714 .53818 .22326 .53481 Mtetra
.898 .479 .151 r
.22326 .53481 .22714 .53818 .23169 .54966 .2278 .54629 Mtetra
.835 .368 0 r
.2278 .54629 .23169 .54966 .23654 .55831 .23264 .55495 Mtetra
.733 .229 0 r
.23264 .55495 .23654 .55831 .24159 .56508 .23769 .56171 Mtetra
0 .321 .778 r
.23769 .56171 .24159 .56508 .24699 .56815 .24309 .56478 Mtetra
.09 .49 .898 r
.24309 .56478 .24699 .56815 .25249 .57019 .2486 .56681 Mtetra
.364 .645 .963 r
.2486 .56681 .25249 .57019 .25814 .57086 .25425 .56748 Mtetra
.515 .713 .961 r
.25425 .56748 .25814 .57086 .26388 .57047 .25999 .56708 Mtetra
.553 .727 .955 r
.25999 .56708 .26388 .57047 .26967 .56974 .26579 .56634 Mtetra
.593 .741 .946 r
.26579 .56634 .26967 .56974 .2755 .5686 .27163 .5652 Mtetra
.605 .744 .943 r
.27163 .5652 .2755 .5686 .28136 .56733 .27749 .56392 Mtetra
.611 .746 .941 r
.27749 .56392 .28136 .56733 .28724 .56599 .28338 .56257 Mtetra
.616 .748 .94 r
.28338 .56257 .28724 .56599 .29313 .56459 .28928 .56116 Mtetra
.28928 .56116 .29313 .56459 .29905 .56318 .2952 .55975 Mtetra
.617 .748 .939 r
.2952 .55975 .29905 .56318 .30497 .56175 .30114 .55831 Mtetra
.617 .748 .94 r
.30114 .55831 .30497 .56175 .31092 .56033 .30709 .55688 Mtetra
.30709 .55688 .31092 .56033 .31687 .5589 .31306 .55545 Mtetra
.31306 .55545 .31687 .5589 .32285 .55747 .31904 .55401 Mtetra
.616 .748 .94 r
.31904 .55401 .32285 .55747 .32884 .55604 .32503 .55257 Mtetra
.32503 .55257 .32884 .55604 .33484 .55461 .33104 .55114 Mtetra
.33104 .55114 .33484 .55461 .34086 .55318 .33707 .5497 Mtetra
.616 .747 .94 r
.33707 .5497 .34086 .55318 .34689 .55175 .34311 .54826 Mtetra
.615 .747 .94 r
.34311 .54826 .34689 .55175 .35294 .55032 .34917 .54682 Mtetra
.34917 .54682 .35294 .55032 .359 .54889 .35524 .54538 Mtetra
.35524 .54538 .359 .54889 .36508 .54745 .36133 .54393 Mtetra
.36133 .54393 .36508 .54745 .37118 .54601 .36743 .54249 Mtetra
.614 .747 .94 r
.36743 .54249 .37118 .54601 .37729 .54458 .37355 .54105 Mtetra
.37355 .54105 .37729 .54458 .38341 .54315 .37968 .53961 Mtetra
.37968 .53961 .38341 .54315 .38955 .54172 .38583 .53817 Mtetra
.613 .747 .94 r
.38583 .53817 .38955 .54172 .39571 .54028 .392 .53673 Mtetra
.613 .747 .941 r
.392 .53673 .39571 .54028 .40189 .53885 .39818 .53529 Mtetra
.612 .746 .941 r
.39818 .53529 .40189 .53885 .40807 .53742 .40438 .53385 Mtetra
.40438 .53385 .40807 .53742 .41428 .53599 .41059 .53242 Mtetra
.611 .746 .941 r
.41059 .53242 .41428 .53599 .4205 .53457 .41682 .53099 Mtetra
.41682 .53099 .4205 .53457 .42674 .53314 .42307 .52955 Mtetra
.42307 .52955 .42674 .53314 .43299 .53171 .42933 .52811 Mtetra
.61 .746 .941 r
.42933 .52811 .43299 .53171 .43926 .53029 .43561 .52668 Mtetra
.43561 .52668 .43926 .53029 .44555 .52887 .4419 .52525 Mtetra
.4419 .52525 .44555 .52887 .45185 .52744 .44822 .52382 Mtetra
.609 .745 .942 r
.44822 .52382 .45185 .52744 .45817 .52603 .45455 .5224 Mtetra
.45455 .5224 .45817 .52603 .46451 .52461 .46089 .52097 Mtetra
.46089 .52097 .46451 .52461 .47086 .52319 .46725 .51954 Mtetra
.607 .745 .942 r
.46725 .51954 .47086 .52319 .47723 .52178 .47363 .51813 Mtetra
.47363 .51813 .47723 .52178 .48362 .52037 .48003 .51671 Mtetra
.48003 .51671 .48362 .52037 .49003 .51896 .48644 .51529 Mtetra
.606 .744 .943 r
.48644 .51529 .49003 .51896 .49645 .51756 .49288 .51388 Mtetra
.605 .744 .943 r
.49288 .51388 .49645 .51756 .50289 .51616 .49932 .51248 Mtetra
.49932 .51248 .50289 .51616 .50935 .51476 .50579 .51107 Mtetra
.604 .744 .943 r
.50579 .51107 .50935 .51476 .51582 .51337 .51227 .50967 Mtetra
.603 .743 .943 r
.51227 .50967 .51582 .51337 .52231 .51198 .51878 .50828 Mtetra
.51878 .50828 .52231 .51198 .52882 .5106 .52529 .50688 Mtetra
.602 .743 .944 r
.52529 .50688 .52882 .5106 .53535 .50921 .53183 .50549 Mtetra
.601 .743 .944 r
.53183 .50549 .53535 .50921 .5419 .50784 .53839 .50412 Mtetra
.53839 .50412 .5419 .50784 .54846 .50647 .54496 .50274 Mtetra
.54496 .50274 .54846 .50647 .55504 .5051 .55155 .50136 Mtetra
.598 .742 .944 r
.55155 .50136 .55504 .5051 .56164 .50375 .55816 .5 Mtetra
.599 .742 .944 r
.55816 .5 .56164 .50375 .56826 .5024 .56479 .49864 Mtetra
.56479 .49864 .56826 .5024 .5749 .50104 .57144 .49727 Mtetra
.596 .741 .945 r
.57144 .49727 .5749 .50104 .58156 .49971 .57811 .49594 Mtetra
.57811 .49594 .58156 .49971 .58824 .49839 .5848 .4946 Mtetra
.595 .74 .945 r
.5848 .4946 .58824 .49839 .59493 .49706 .5915 .49327 Mtetra
.594 .74 .946 r
.5915 .49327 .59493 .49706 .60165 .49575 .59823 .49195 Mtetra
.593 .74 .946 r
.59823 .49195 .60165 .49575 .60838 .49443 .60497 .49063 Mtetra
.592 .739 .946 r
.60497 .49063 .60838 .49443 .61514 .49314 .61174 .48932 Mtetra
.591 .739 .946 r
.61174 .48932 .61514 .49314 .62191 .49185 .61852 .48802 Mtetra
.61852 .48802 .62191 .49185 .6287 .49056 .62532 .48673 Mtetra
.589 .738 .947 r
.62532 .48673 .6287 .49056 .63552 .48929 .63215 .48545 Mtetra
.588 .738 .947 r
.63215 .48545 .63552 .48929 .64235 .48803 .639 .48418 Mtetra
.587 .738 .947 r
.639 .48418 .64235 .48803 .64921 .48678 .64586 .48292 Mtetra
.585 .737 .948 r
.64586 .48292 .64921 .48678 .65608 .48554 .65275 .48168 Mtetra
.584 .736 .948 r
.65275 .48168 .65608 .48554 .66298 .48431 .65966 .48044 Mtetra
.583 .736 .948 r
.65966 .48044 .66298 .48431 .6699 .4831 .66658 .47922 Mtetra
.582 .735 .948 r
.66658 .47922 .6699 .4831 .67684 .4819 .67354 .47801 Mtetra
.58 .735 .948 r
.67354 .47801 .67684 .4819 .6838 .48071 .68051 .47681 Mtetra
.579 .734 .949 r
.68051 .47681 .6838 .48071 .69078 .47953 .6875 .47563 Mtetra
.577 .734 .949 r
.6875 .47563 .69078 .47953 .69779 .47837 .69452 .47446 Mtetra
.576 .733 .949 r
.69452 .47446 .69779 .47837 .70482 .47723 .70156 .47331 Mtetra
.574 .732 .95 r
.70156 .47331 .70482 .47723 .71187 .4761 .70862 .47218 Mtetra
.573 .732 .95 r
.70862 .47218 .71187 .4761 .71894 .47499 .7157 .47105 Mtetra
.57 .731 .95 r
.7157 .47105 .71894 .47499 .72604 .4739 .72281 .46996 Mtetra
.569 .73 .951 r
.72281 .46996 .72604 .4739 .73316 .47283 .72995 .46888 Mtetra
.568 .73 .951 r
.72995 .46888 .73316 .47283 .7403 .47177 .7371 .46781 Mtetra
.565 .728 .951 r
.7371 .46781 .7403 .47177 .74747 .47075 .74428 .46678 Mtetra
.564 .728 .951 r
.74428 .46678 .74747 .47075 .75467 .46973 .75149 .46576 Mtetra
.562 .727 .952 r
.75149 .46576 .75467 .46973 .76188 .46873 .75871 .46475 Mtetra
.561 .727 .952 r
.75871 .46475 .76188 .46873 .76912 .46774 .76597 .46375 Mtetra
.563 .727 .952 r
.76597 .46375 .76912 .46774 .77639 .46672 .77324 .46272 Mtetra
.566 .729 .951 r
.77324 .46272 .77639 .46672 .78367 .46566 .78054 .46166 Mtetra
.582 .737 .949 r
.78054 .46166 .78367 .46566 .79096 .46439 .78784 .46037 Mtetra
.598 .744 .946 r
.78784 .46037 .79096 .46439 .79825 .4629 .79514 .45888 Mtetra
.646 .764 .935 r
.79514 .45888 .79825 .4629 .80551 .4607 .80241 .45666 Mtetra
.71 .789 .913 r
.80241 .45666 .80551 .4607 .81268 .45738 .8096 .45333 Mtetra
.75 .801 .894 r
.8096 .45333 .81268 .45738 .8198 .45321 .81673 .44914 Mtetra
.863 .823 .807 r
.81673 .44914 .8198 .45321 .82658 .44541 .82353 .44131 Mtetra
.903 .822 .757 r
.82353 .44131 .82658 .44541 .83315 .43531 .83011 .43118 Mtetra
.939 .813 .693 r
.83011 .43118 .83315 .43531 .83936 .42174 .83634 .41757 Mtetra
.967 .795 .617 r
.83634 .41757 .83936 .42174 .84498 .40261 .84199 .39839 Mtetra
.974 .786 .589 r
.84199 .39839 .84498 .40261 .85028 .38086 .84731 .37659 Mtetra
.931 .563 .29 r
.21126 .50019 .21512 .50359 .2191 .51984 .21522 .51644 Mtetra
.925 .546 .261 r
.21522 .51644 .2191 .51984 .22326 .53481 .21937 .53142 Mtetra
.898 .479 .151 r
.21937 .53142 .22326 .53481 .2278 .54629 .2239 .54291 Mtetra
.835 .368 0 r
.2239 .54291 .2278 .54629 .23264 .55495 .22873 .55156 Mtetra
.732 .228 0 r
.22873 .55156 .23264 .55495 .23769 .56171 .23378 .55833 Mtetra
0 .321 .779 r
.23378 .55833 .23769 .56171 .24309 .56478 .23918 .56139 Mtetra
.091 .49 .899 r
.23918 .56139 .24309 .56478 .2486 .56681 .24469 .56342 Mtetra
.364 .645 .963 r
.24469 .56342 .2486 .56681 .25425 .56748 .25034 .56408 Mtetra
.516 .713 .961 r
.25034 .56408 .25425 .56748 .25999 .56708 .25609 .56367 Mtetra
.553 .727 .955 r
.25609 .56367 .25999 .56708 .26579 .56634 .26189 .56293 Mtetra
.593 .74 .946 r
.26189 .56293 .26579 .56634 .27163 .5652 .26774 .56178 Mtetra
.605 .744 .943 r
.26774 .56178 .27163 .5652 .27749 .56392 .27361 .5605 Mtetra
.611 .746 .941 r
.27361 .5605 .27749 .56392 .28338 .56257 .27951 .55914 Mtetra
.616 .747 .94 r
.27951 .55914 .28338 .56257 .28928 .56116 .28542 .55772 Mtetra
.616 .748 .94 r
.28542 .55772 .28928 .56116 .2952 .55975 .29135 .5563 Mtetra
.617 .748 .939 r
.29135 .5563 .2952 .55975 .30114 .55831 .29729 .55486 Mtetra
.29729 .55486 .30114 .55831 .30709 .55688 .30325 .55342 Mtetra
.30325 .55342 .30709 .55688 .31306 .55545 .30922 .55198 Mtetra
.30922 .55198 .31306 .55545 .31904 .55401 .31521 .55053 Mtetra
.616 .748 .94 r
.31521 .55053 .31904 .55401 .32503 .55257 .32121 .54909 Mtetra
.32121 .54909 .32503 .55257 .33104 .55114 .32723 .54765 Mtetra
.32723 .54765 .33104 .55114 .33707 .5497 .33327 .5462 Mtetra
.615 .747 .94 r
.33327 .5462 .33707 .5497 .34311 .54826 .33932 .54475 Mtetra
.33932 .54475 .34311 .54826 .34917 .54682 .34538 .54331 Mtetra
.34538 .54331 .34917 .54682 .35524 .54538 .35146 .54186 Mtetra
.35146 .54186 .35524 .54538 .36133 .54393 .35756 .54041 Mtetra
.35756 .54041 .36133 .54393 .36743 .54249 .36367 .53896 Mtetra
.614 .747 .94 r
.36367 .53896 .36743 .54249 .37355 .54105 .36979 .53751 Mtetra
.36979 .53751 .37355 .54105 .37968 .53961 .37594 .53606 Mtetra
.613 .747 .941 r
.37594 .53606 .37968 .53961 .38583 .53817 .38209 .53462 Mtetra
.38209 .53462 .38583 .53817 .392 .53673 .38827 .53317 Mtetra
.38827 .53317 .392 .53673 .39818 .53529 .39446 .53172 Mtetra
.612 .747 .941 r
.39446 .53172 .39818 .53529 .40438 .53385 .40066 .53028 Mtetra
.40066 .53028 .40438 .53385 .41059 .53242 .40689 .52883 Mtetra
.611 .746 .941 r
.40689 .52883 .41059 .53242 .41682 .53099 .41313 .52739 Mtetra
.41313 .52739 .41682 .53099 .42307 .52955 .41938 .52595 Mtetra
.41938 .52595 .42307 .52955 .42933 .52811 .42565 .5245 Mtetra
.61 .746 .942 r
.42565 .5245 .42933 .52811 .43561 .52668 .43194 .52307 Mtetra
.43194 .52307 .43561 .52668 .4419 .52525 .43824 .52163 Mtetra
.43824 .52163 .4419 .52525 .44822 .52382 .44456 .52019 Mtetra
.608 .745 .942 r
.44456 .52019 .44822 .52382 .45455 .5224 .4509 .51876 Mtetra
.608 .746 .942 r
.4509 .51876 .45455 .5224 .46089 .52097 .45726 .51733 Mtetra
.609 .746 .942 r
.45726 .51733 .46089 .52097 .46725 .51954 .46363 .51589 Mtetra
.607 .745 .942 r
.46363 .51589 .46725 .51954 .47363 .51813 .47002 .51447 Mtetra
.607 .745 .943 r
.47002 .51447 .47363 .51813 .48003 .51671 .47642 .51304 Mtetra
.47642 .51304 .48003 .51671 .48644 .51529 .48285 .51161 Mtetra
.606 .745 .943 r
.48285 .51161 .48644 .51529 .49288 .51388 .48929 .5102 Mtetra
.605 .744 .943 r
.48929 .5102 .49288 .51388 .49932 .51248 .49574 .50879 Mtetra
.49574 .50879 .49932 .51248 .50579 .51107 .50222 .50737 Mtetra
.604 .744 .943 r
.50222 .50737 .50579 .51107 .51227 .50967 .50871 .50596 Mtetra
.603 .744 .944 r
.50871 .50596 .51227 .50967 .51878 .50828 .51522 .50456 Mtetra
.51522 .50456 .51878 .50828 .52529 .50688 .52175 .50316 Mtetra
.602 .744 .944 r
.52175 .50316 .52529 .50688 .53183 .50549 .5283 .50176 Mtetra
.601 .743 .944 r
.5283 .50176 .53183 .50549 .53839 .50412 .53486 .50038 Mtetra
.53486 .50038 .53839 .50412 .54496 .50274 .54145 .49899 Mtetra
.54145 .49899 .54496 .50274 .55155 .50136 .54805 .4976 Mtetra
.598 .742 .945 r
.54805 .4976 .55155 .50136 .55816 .5 .55467 .49624 Mtetra
.55467 .49624 .55816 .5 .56479 .49864 .56131 .49487 Mtetra
.599 .742 .945 r
.56131 .49487 .56479 .49864 .57144 .49727 .56797 .49349 Mtetra
.596 .741 .945 r
.56797 .49349 .57144 .49727 .57811 .49594 .57465 .49215 Mtetra
.595 .741 .946 r
.57465 .49215 .57811 .49594 .5848 .4946 .58134 .49081 Mtetra
.58134 .49081 .5848 .4946 .5915 .49327 .58806 .48947 Mtetra
.594 .741 .946 r
.58806 .48947 .5915 .49327 .59823 .49195 .59479 .48814 Mtetra
.593 .74 .946 r
.59479 .48814 .59823 .49195 .60497 .49063 .60155 .48681 Mtetra
.592 .74 .946 r
.60155 .48681 .60497 .49063 .61174 .48932 .60832 .4855 Mtetra
.591 .739 .947 r
.60832 .4855 .61174 .48932 .61852 .48802 .61512 .48419 Mtetra
.59 .739 .947 r
.61512 .48419 .61852 .48802 .62532 .48673 .62193 .48289 Mtetra
.588 .738 .947 r
.62193 .48289 .62532 .48673 .63215 .48545 .62877 .4816 Mtetra
.62877 .4816 .63215 .48545 .639 .48418 .63562 .48033 Mtetra
.587 .738 .947 r
.63562 .48033 .639 .48418 .64586 .48292 .6425 .47905 Mtetra
.585 .737 .948 r
.6425 .47905 .64586 .48292 .65275 .48168 .6494 .4778 Mtetra
.584 .737 .948 r
.6494 .4778 .65275 .48168 .65966 .48044 .65632 .47656 Mtetra
.583 .736 .948 r
.65632 .47656 .65966 .48044 .66658 .47922 .66325 .47533 Mtetra
.581 .736 .949 r
.66325 .47533 .66658 .47922 .67354 .47801 .67022 .47411 Mtetra
.58 .735 .949 r
.67022 .47411 .67354 .47801 .68051 .47681 .6772 .47291 Mtetra
.579 .735 .949 r
.6772 .47291 .68051 .47681 .6875 .47563 .68421 .47172 Mtetra
.577 .734 .949 r
.68421 .47172 .6875 .47563 .69452 .47446 .69123 .47054 Mtetra
.576 .733 .95 r
.69123 .47054 .69452 .47446 .70156 .47331 .69828 .46938 Mtetra
.574 .733 .95 r
.69828 .46938 .70156 .47331 .70862 .47218 .70536 .46824 Mtetra
.573 .732 .95 r
.70536 .46824 .70862 .47218 .7157 .47105 .71245 .46711 Mtetra
.57 .731 .951 r
.71245 .46711 .7157 .47105 .72281 .46996 .71957 .46601 Mtetra
.568 .73 .951 r
.71957 .46601 .72281 .46996 .72995 .46888 .72672 .46492 Mtetra
.567 .73 .951 r
.72672 .46492 .72995 .46888 .7371 .46781 .73388 .46385 Mtetra
.565 .729 .952 r
.73388 .46385 .7371 .46781 .74428 .46678 .74107 .46281 Mtetra
.563 .728 .952 r
.74107 .46281 .74428 .46678 .75149 .46576 .74829 .46178 Mtetra
.562 .728 .952 r
.74829 .46178 .75149 .46576 .75871 .46475 .75553 .46076 Mtetra
.561 .727 .952 r
.75553 .46076 .75871 .46475 .76597 .46375 .7628 .45975 Mtetra
.562 .728 .952 r
.7628 .45975 .76597 .46375 .77324 .46272 .77008 .45872 Mtetra
.566 .73 .952 r
.77008 .45872 .77324 .46272 .78054 .46166 .77739 .45765 Mtetra
.582 .737 .949 r
.77739 .45765 .78054 .46166 .78784 .46037 .7847 .45635 Mtetra
.597 .744 .947 r
.7847 .45635 .78784 .46037 .79514 .45888 .79202 .45485 Mtetra
.646 .765 .935 r
.79202 .45485 .79514 .45888 .80241 .45666 .7993 .45262 Mtetra
.71 .789 .913 r
.7993 .45262 .80241 .45666 .8096 .45333 .80651 .44927 Mtetra
.751 .802 .894 r
.80651 .44927 .8096 .45333 .81673 .44914 .81365 .44506 Mtetra
.864 .824 .807 r
.81365 .44506 .81673 .44914 .82353 .44131 .82047 .4372 Mtetra
.904 .823 .757 r
.82047 .4372 .82353 .44131 .83011 .43118 .82706 .42703 Mtetra
.939 .813 .693 r
.82706 .42703 .83011 .43118 .83634 .41757 .83331 .41337 Mtetra
.967 .795 .617 r
.83331 .41337 .83634 .41757 .84199 .39839 .83898 .39415 Mtetra
.974 .785 .588 r
.83898 .39415 .84199 .39839 .84731 .37659 .84433 .37229 Mtetra
.931 .563 .29 r
.20738 .49678 .21126 .50019 .21522 .51644 .21133 .51304 Mtetra
.925 .546 .261 r
.21133 .51304 .21522 .51644 .21937 .53142 .21546 .52803 Mtetra
.898 .479 .151 r
.21546 .52803 .21937 .53142 .2239 .54291 .21998 .53952 Mtetra
.835 .368 0 r
.21998 .53952 .2239 .54291 .22873 .55156 .22481 .54817 Mtetra
.732 .228 0 r
.22481 .54817 .22873 .55156 .23378 .55833 .22985 .55493 Mtetra
0 .321 .779 r
.22985 .55493 .23378 .55833 .23918 .56139 .23525 .55799 Mtetra
.091 .49 .899 r
.23525 .55799 .23918 .56139 .24469 .56342 .24076 .56001 Mtetra
.364 .646 .963 r
.24076 .56001 .24469 .56342 .25034 .56408 .24642 .56067 Mtetra
.516 .713 .961 r
.24642 .56067 .25034 .56408 .25609 .56367 .25218 .56026 Mtetra
.553 .727 .955 r
.25218 .56026 .25609 .56367 .26189 .56293 .25798 .55951 Mtetra
.593 .741 .946 r
.25798 .55951 .26189 .56293 .26774 .56178 .26384 .55835 Mtetra
.605 .744 .943 r
.26384 .55835 .26774 .56178 .27361 .5605 .26972 .55706 Mtetra
.611 .746 .941 r
.26972 .55706 .27361 .5605 .27951 .55914 .27562 .55569 Mtetra
.616 .747 .94 r
.27562 .55569 .27951 .55914 .28542 .55772 .28154 .55427 Mtetra
.616 .748 .94 r
.28154 .55427 .28542 .55772 .29135 .5563 .28747 .55284 Mtetra
.617 .748 .939 r
.28747 .55284 .29135 .5563 .29729 .55486 .29343 .55139 Mtetra
.29343 .55139 .29729 .55486 .30325 .55342 .29939 .54995 Mtetra
.29939 .54995 .30325 .55342 .30922 .55198 .30537 .5485 Mtetra
.617 .748 .94 r
.30537 .5485 .30922 .55198 .31521 .55053 .31137 .54704 Mtetra
.616 .748 .94 r
.31137 .54704 .31521 .55053 .32121 .54909 .31738 .54559 Mtetra
.31738 .54559 .32121 .54909 .32723 .54765 .32341 .54414 Mtetra
.32341 .54414 .32723 .54765 .33327 .5462 .32945 .54269 Mtetra
.615 .748 .94 r
.32945 .54269 .33327 .5462 .33932 .54475 .3355 .54123 Mtetra
.615 .747 .94 r
.3355 .54123 .33932 .54475 .34538 .54331 .34158 .53978 Mtetra
.615 .748 .94 r
.34158 .53978 .34538 .54331 .35146 .54186 .34766 .53833 Mtetra
.34766 .53833 .35146 .54186 .35756 .54041 .35377 .53687 Mtetra
.615 .747 .94 r
.35377 .53687 .35756 .54041 .36367 .53896 .35989 .53541 Mtetra
.614 .747 .94 r
.35989 .53541 .36367 .53896 .36979 .53751 .36602 .53396 Mtetra
.614 .747 .941 r
.36602 .53396 .36979 .53751 .37594 .53606 .37217 .5325 Mtetra
.613 .747 .941 r
.37217 .5325 .37594 .53606 .38209 .53462 .37834 .53105 Mtetra
.37834 .53105 .38209 .53462 .38827 .53317 .38452 .52959 Mtetra
.38452 .52959 .38827 .53317 .39446 .53172 .39072 .52814 Mtetra
.612 .747 .941 r
.39072 .52814 .39446 .53172 .40066 .53028 .39694 .52669 Mtetra
.39694 .52669 .40066 .53028 .40689 .52883 .40317 .52524 Mtetra
.611 .746 .941 r
.40317 .52524 .40689 .52883 .41313 .52739 .40941 .52379 Mtetra
.611 .747 .941 r
.40941 .52379 .41313 .52739 .41938 .52595 .41568 .52234 Mtetra
.611 .746 .941 r
.41568 .52234 .41938 .52595 .42565 .5245 .42196 .52088 Mtetra
.61 .746 .942 r
.42196 .52088 .42565 .5245 .43194 .52307 .42825 .51944 Mtetra
.42825 .51944 .43194 .52307 .43824 .52163 .43457 .51799 Mtetra
.43457 .51799 .43824 .52163 .44456 .52019 .4409 .51654 Mtetra
.608 .746 .942 r
.4409 .51654 .44456 .52019 .4509 .51876 .44724 .51511 Mtetra
.44724 .51511 .4509 .51876 .45726 .51733 .45361 .51367 Mtetra
.45361 .51367 .45726 .51733 .46363 .51589 .45999 .51222 Mtetra
.607 .745 .943 r
.45999 .51222 .46363 .51589 .47002 .51447 .46638 .51079 Mtetra
.46638 .51079 .47002 .51447 .47642 .51304 .4728 .50936 Mtetra
.4728 .50936 .47642 .51304 .48285 .51161 .47923 .50792 Mtetra
.606 .745 .943 r
.47923 .50792 .48285 .51161 .48929 .5102 .48568 .5065 Mtetra
.605 .745 .943 r
.48568 .5065 .48929 .5102 .49574 .50879 .49215 .50508 Mtetra
.49215 .50508 .49574 .50879 .50222 .50737 .49863 .50366 Mtetra
.604 .744 .943 r
.49863 .50366 .50222 .50737 .50871 .50596 .50513 .50224 Mtetra
.603 .744 .944 r
.50513 .50224 .50871 .50596 .51522 .50456 .51166 .50083 Mtetra
.51166 .50083 .51522 .50456 .52175 .50316 .51819 .49942 Mtetra
.602 .744 .944 r
.51819 .49942 .52175 .50316 .5283 .50176 .52475 .49801 Mtetra
.601 .743 .944 r
.52475 .49801 .5283 .50176 .53486 .50038 .53132 .49662 Mtetra
.53132 .49662 .53486 .50038 .54145 .49899 .53792 .49523 Mtetra
.6 .743 .944 r
.53792 .49523 .54145 .49899 .54805 .4976 .54453 .49383 Mtetra
.598 .742 .945 r
.54453 .49383 .54805 .4976 .55467 .49624 .55116 .49246 Mtetra
.55116 .49246 .55467 .49624 .56131 .49487 .55781 .49108 Mtetra
.55781 .49108 .56131 .49487 .56797 .49349 .56448 .4897 Mtetra
.596 .741 .946 r
.56448 .4897 .56797 .49349 .57465 .49215 .57116 .48835 Mtetra
.595 .741 .946 r
.57116 .48835 .57465 .49215 .58134 .49081 .57787 .487 Mtetra
.57787 .487 .58134 .49081 .58806 .48947 .5846 .48565 Mtetra
.594 .741 .946 r
.5846 .48565 .58806 .48947 .59479 .48814 .59134 .48431 Mtetra
.593 .741 .946 r
.59134 .48431 .59479 .48814 .60155 .48681 .59811 .48298 Mtetra
.592 .74 .947 r
.59811 .48298 .60155 .48681 .60832 .4855 .60489 .48166 Mtetra
.591 .74 .947 r
.60489 .48166 .60832 .4855 .61512 .48419 .6117 .48034 Mtetra
.59 .739 .947 r
.6117 .48034 .61512 .48419 .62193 .48289 .61852 .47903 Mtetra
.588 .739 .947 r
.61852 .47903 .62193 .48289 .62877 .4816 .62537 .47774 Mtetra
.588 .738 .947 r
.62537 .47774 .62877 .4816 .63562 .48033 .63223 .47646 Mtetra
.587 .738 .948 r
.63223 .47646 .63562 .48033 .6425 .47905 .63912 .47518 Mtetra
.585 .737 .948 r
.63912 .47518 .6425 .47905 .6494 .4778 .64603 .47392 Mtetra
.584 .737 .948 r
.64603 .47392 .6494 .4778 .65632 .47656 .65296 .47267 Mtetra
.583 .737 .949 r
.65296 .47267 .65632 .47656 .66325 .47533 .65991 .47143 Mtetra
.581 .736 .949 r
.65991 .47143 .66325 .47533 .67022 .47411 .66688 .4702 Mtetra
.58 .736 .949 r
.66688 .4702 .67022 .47411 .6772 .47291 .67388 .46899 Mtetra
.578 .735 .949 r
.67388 .46899 .6772 .47291 .68421 .47172 .68089 .46779 Mtetra
.577 .734 .95 r
.68089 .46779 .68421 .47172 .69123 .47054 .68793 .46661 Mtetra
.575 .734 .95 r
.68793 .46661 .69123 .47054 .69828 .46938 .69499 .46544 Mtetra
.574 .733 .95 r
.69499 .46544 .69828 .46938 .70536 .46824 .70208 .46429 Mtetra
.572 .732 .951 r
.70208 .46429 .70536 .46824 .71245 .46711 .70919 .46315 Mtetra
.57 .731 .951 r
.70919 .46315 .71245 .46711 .71957 .46601 .71632 .46205 Mtetra
.568 .731 .951 r
.71632 .46205 .71957 .46601 .72672 .46492 .72347 .46095 Mtetra
.567 .73 .951 r
.72347 .46095 .72672 .46492 .73388 .46385 .73065 .45987 Mtetra
.564 .729 .952 r
.73065 .45987 .73388 .46385 .74107 .46281 .73785 .45882 Mtetra
.563 .729 .952 r
.73785 .45882 .74107 .46281 .74829 .46178 .74508 .45778 Mtetra
.562 .728 .952 r
.74508 .45778 .74829 .46178 .75553 .46076 .75233 .45676 Mtetra
.56 .728 .953 r
.75233 .45676 .75553 .46076 .7628 .45975 .75961 .45574 Mtetra
.562 .728 .952 r
.75961 .45574 .7628 .45975 .77008 .45872 .76691 .45471 Mtetra
.565 .73 .952 r
.76691 .45471 .77008 .45872 .77739 .45765 .77423 .45362 Mtetra
.582 .738 .95 r
.77423 .45362 .77739 .45765 .7847 .45635 .78155 .45232 Mtetra
.597 .745 .947 r
.78155 .45232 .7847 .45635 .79202 .45485 .78889 .4508 Mtetra
.646 .766 .936 r
.78889 .4508 .79202 .45485 .7993 .45262 .79618 .44856 Mtetra
.711 .79 .913 r
.79618 .44856 .7993 .45262 .80651 .44927 .8034 .44519 Mtetra
.751 .803 .894 r
.8034 .44519 .80651 .44927 .81365 .44506 .81055 .44096 Mtetra
.864 .824 .807 r
.81055 .44096 .81365 .44506 .82047 .4372 .81739 .43307 Mtetra
.904 .823 .756 r
.81739 .43307 .82047 .4372 .82706 .42703 .824 .42286 Mtetra
.94 .813 .693 r
.824 .42286 .82706 .42703 .83331 .41337 .83027 .40916 Mtetra
.967 .794 .617 r
.83027 .40916 .83331 .41337 .83898 .39415 .83596 .38988 Mtetra
.974 .785 .588 r
.83596 .38988 .83898 .39415 .84433 .37229 .84133 .36797 Mtetra
.93 .563 .291 r
.20349 .49336 .20738 .49678 .21133 .51304 .20741 .50964 Mtetra
.925 .546 .261 r
.20741 .50964 .21133 .51304 .21546 .52803 .21153 .52463 Mtetra
.897 .479 .152 r
.21153 .52463 .21546 .52803 .21998 .53952 .21604 .53612 Mtetra
.835 .368 0 r
.21604 .53612 .21998 .53952 .22481 .54817 .22086 .54478 Mtetra
.733 .229 0 r
.22086 .54478 .22481 .54817 .22985 .55493 .2259 .55154 Mtetra
0 .321 .778 r
.2259 .55154 .22985 .55493 .23525 .55799 .2313 .55459 Mtetra
.09 .49 .898 r
.2313 .55459 .23525 .55799 .24076 .56001 .23682 .55661 Mtetra
.363 .646 .964 r
.23682 .55661 .24076 .56001 .24642 .56067 .24248 .55726 Mtetra
.515 .714 .962 r
.24248 .55726 .24642 .56067 .25218 .56026 .24824 .55684 Mtetra
.553 .728 .956 r
.24824 .55684 .25218 .56026 .25798 .55951 .25406 .55608 Mtetra
.593 .741 .947 r
.25406 .55608 .25798 .55951 .26384 .55835 .25992 .55492 Mtetra
.605 .745 .944 r
.25992 .55492 .26384 .55835 .26972 .55706 .26581 .55362 Mtetra
.611 .747 .942 r
.26581 .55362 .26972 .55706 .27562 .55569 .27171 .55225 Mtetra
.615 .748 .94 r
.27171 .55225 .27562 .55569 .28154 .55427 .27764 .55082 Mtetra
.616 .749 .94 r
.27764 .55082 .28154 .55427 .28747 .55284 .28358 .54938 Mtetra
.617 .749 .94 r
.28358 .54938 .28747 .55284 .29343 .55139 .28954 .54792 Mtetra
.616 .749 .94 r
.28954 .54792 .29343 .55139 .29939 .54995 .29552 .54647 Mtetra
.29552 .54647 .29939 .54995 .30537 .5485 .3015 .54501 Mtetra
.3015 .54501 .30537 .5485 .31137 .54704 .30751 .54355 Mtetra
.30751 .54355 .31137 .54704 .31738 .54559 .31353 .5421 Mtetra
.616 .748 .94 r
.31353 .5421 .31738 .54559 .32341 .54414 .31956 .54064 Mtetra
.31956 .54064 .32341 .54414 .32945 .54269 .32561 .53917 Mtetra
.615 .748 .94 r
.32561 .53917 .32945 .54269 .3355 .54123 .33168 .53771 Mtetra
.615 .748 .941 r
.33168 .53771 .3355 .54123 .34158 .53978 .33776 .53625 Mtetra
.33776 .53625 .34158 .53978 .34766 .53833 .34385 .53479 Mtetra
.34385 .53479 .34766 .53833 .35377 .53687 .34996 .53332 Mtetra
.614 .748 .941 r
.34996 .53332 .35377 .53687 .35989 .53541 .35609 .53186 Mtetra
.35609 .53186 .35989 .53541 .36602 .53396 .36223 .5304 Mtetra
.36223 .5304 .36602 .53396 .37217 .5325 .36839 .52893 Mtetra
.613 .748 .941 r
.36839 .52893 .37217 .5325 .37834 .53105 .37457 .52747 Mtetra
.613 .747 .941 r
.37457 .52747 .37834 .53105 .38452 .52959 .38076 .52601 Mtetra
.38076 .52601 .38452 .52959 .39072 .52814 .38697 .52455 Mtetra
.612 .747 .941 r
.38697 .52455 .39072 .52814 .39694 .52669 .39319 .52309 Mtetra
.612 .747 .942 r
.39319 .52309 .39694 .52669 .40317 .52524 .39943 .52163 Mtetra
.611 .747 .942 r
.39943 .52163 .40317 .52524 .40941 .52379 .40568 .52017 Mtetra
.40568 .52017 .40941 .52379 .41568 .52234 .41196 .51871 Mtetra
.41196 .51871 .41568 .52234 .42196 .52088 .41825 .51725 Mtetra
.61 .747 .942 r
.41825 .51725 .42196 .52088 .42825 .51944 .42455 .5158 Mtetra
.42455 .5158 .42825 .51944 .43457 .51799 .43087 .51435 Mtetra
.43087 .51435 .43457 .51799 .4409 .51654 .43721 .51289 Mtetra
.608 .746 .943 r
.43721 .51289 .4409 .51654 .44724 .51511 .44357 .51145 Mtetra
.44357 .51145 .44724 .51511 .45361 .51367 .44994 .51 Mtetra
.44994 .51 .45361 .51367 .45999 .51222 .45633 .50855 Mtetra
.607 .746 .943 r
.45633 .50855 .45999 .51222 .46638 .51079 .46273 .50711 Mtetra
.46273 .50711 .46638 .51079 .4728 .50936 .46916 .50567 Mtetra
.46916 .50567 .4728 .50936 .47923 .50792 .4756 .50423 Mtetra
.605 .745 .943 r
.4756 .50423 .47923 .50792 .48568 .5065 .48206 .50279 Mtetra
.605 .745 .944 r
.48206 .50279 .48568 .5065 .49215 .50508 .48854 .50137 Mtetra
.48854 .50137 .49215 .50508 .49863 .50366 .49503 .49993 Mtetra
.604 .745 .944 r
.49503 .49993 .49863 .50366 .50513 .50224 .50154 .49851 Mtetra
.603 .744 .944 r
.50154 .49851 .50513 .50224 .51166 .50083 .50807 .4971 Mtetra
.50807 .4971 .51166 .50083 .51819 .49942 .51462 .49568 Mtetra
.602 .744 .944 r
.51462 .49568 .51819 .49942 .52475 .49801 .52119 .49426 Mtetra
.601 .744 .945 r
.52119 .49426 .52475 .49801 .53132 .49662 .52777 .49286 Mtetra
.52777 .49286 .53132 .49662 .53792 .49523 .53437 .49146 Mtetra
.6 .744 .945 r
.53437 .49146 .53792 .49523 .54453 .49383 .54099 .49006 Mtetra
.598 .743 .945 r
.54099 .49006 .54453 .49383 .55116 .49246 .54763 .48868 Mtetra
.54763 .48868 .55116 .49246 .55781 .49108 .55429 .48729 Mtetra
.55429 .48729 .55781 .49108 .56448 .4897 .56097 .4859 Mtetra
.595 .742 .946 r
.56097 .4859 .56448 .4897 .57116 .48835 .56767 .48454 Mtetra
.56767 .48454 .57116 .48835 .57787 .487 .57439 .48319 Mtetra
.594 .742 .946 r
.57439 .48319 .57787 .487 .5846 .48565 .58112 .48183 Mtetra
.594 .741 .947 r
.58112 .48183 .5846 .48565 .59134 .48431 .58788 .48048 Mtetra
.593 .741 .947 r
.58788 .48048 .59134 .48431 .59811 .48298 .59465 .47914 Mtetra
.591 .74 .947 r
.59465 .47914 .59811 .48298 .60489 .48166 .60145 .47781 Mtetra
.60145 .47781 .60489 .48166 .6117 .48034 .60826 .47649 Mtetra
.59 .74 .947 r
.60826 .47649 .6117 .48034 .61852 .47903 .6151 .47517 Mtetra
.588 .739 .948 r
.6151 .47517 .61852 .47903 .62537 .47774 .62196 .47387 Mtetra
.587 .739 .948 r
.62196 .47387 .62537 .47774 .63223 .47646 .62883 .47258 Mtetra
.62883 .47258 .63223 .47646 .63912 .47518 .63573 .47129 Mtetra
.585 .738 .949 r
.63573 .47129 .63912 .47518 .64603 .47392 .64265 .47003 Mtetra
.584 .738 .949 r
.64265 .47003 .64603 .47392 .65296 .47267 .64959 .46877 Mtetra
.583 .737 .949 r
.64959 .46877 .65296 .47267 .65991 .47143 .65655 .46752 Mtetra
.581 .736 .949 r
.65655 .46752 .65991 .47143 .66688 .4702 .66353 .46629 Mtetra
.58 .736 .95 r
.66353 .46629 .66688 .4702 .67388 .46899 .67054 .46507 Mtetra
.578 .735 .95 r
.67054 .46507 .67388 .46899 .68089 .46779 .67757 .46386 Mtetra
.577 .735 .95 r
.67757 .46386 .68089 .46779 .68793 .46661 .68462 .46267 Mtetra
.575 .734 .951 r
.68462 .46267 .68793 .46661 .69499 .46544 .69169 .4615 Mtetra
.573 .734 .951 r
.69169 .4615 .69499 .46544 .70208 .46429 .69879 .46034 Mtetra
.572 .733 .951 r
.69879 .46034 .70208 .46429 .70919 .46315 .7059 .45919 Mtetra
.57 .732 .952 r
.7059 .45919 .70919 .46315 .71632 .46205 .71305 .45808 Mtetra
.568 .731 .952 r
.71305 .45808 .71632 .46205 .72347 .46095 .72021 .45698 Mtetra
.567 .731 .952 r
.72021 .45698 .72347 .46095 .73065 .45987 .7274 .45589 Mtetra
.564 .73 .953 r
.7274 .45589 .73065 .45987 .73785 .45882 .73462 .45483 Mtetra
.563 .729 .953 r
.73462 .45483 .73785 .45882 .74508 .45778 .74186 .45379 Mtetra
.561 .729 .953 r
.74186 .45379 .74508 .45778 .75233 .45676 .74912 .45275 Mtetra
.56 .728 .953 r
.74912 .45275 .75233 .45676 .75961 .45574 .75641 .45173 Mtetra
.562 .729 .953 r
.75641 .45173 .75961 .45574 .76691 .45471 .76372 .45069 Mtetra
.565 .731 .953 r
.76372 .45069 .76691 .45471 .77423 .45362 .77105 .4496 Mtetra
.582 .738 .95 r
.77105 .4496 .77423 .45362 .78155 .45232 .77839 .44828 Mtetra
.597 .746 .948 r
.77839 .44828 .78155 .45232 .78889 .4508 .78574 .44676 Mtetra
.647 .767 .936 r
.78574 .44676 .78889 .4508 .79618 .44856 .79304 .4445 Mtetra
.711 .791 .914 r
.79304 .4445 .79618 .44856 .8034 .44519 .80027 .44111 Mtetra
.752 .803 .894 r
.80027 .44111 .8034 .44519 .81055 .44096 .80744 .43686 Mtetra
.865 .825 .807 r
.80744 .43686 .81055 .44096 .81739 .43307 .81429 .42893 Mtetra
.904 .823 .756 r
.81429 .42893 .81739 .43307 .824 .42286 .82093 .41868 Mtetra
.94 .813 .692 r
.82093 .41868 .824 .42286 .83027 .40916 .82721 .40493 Mtetra
.967 .794 .616 r
.82721 .40493 .83027 .40916 .83596 .38988 .83293 .38558 Mtetra
.974 .785 .588 r
.83293 .38558 .83596 .38988 .84133 .36797 .83832 .36361 Mtetra
.93 .563 .291 r
.19958 .48994 .20349 .49336 .20741 .50964 .20349 .50622 Mtetra
.925 .546 .261 r
.20349 .50622 .20741 .50964 .21153 .52463 .20759 .52122 Mtetra
.897 .479 .152 r
.20759 .52122 .21153 .52463 .21604 .53612 .21209 .53272 Mtetra
.835 .368 0 r
.21209 .53272 .21604 .53612 .22086 .54478 .2169 .54137 Mtetra
.733 .228 0 r
.2169 .54137 .22086 .54478 .2259 .55154 .22193 .54813 Mtetra
0 .321 .778 r
.22193 .54813 .2259 .55154 .2313 .55459 .22734 .55118 Mtetra
.09 .491 .899 r
.22734 .55118 .2313 .55459 .23682 .55661 .23286 .55319 Mtetra
.364 .646 .964 r
.23286 .55319 .23682 .55661 .24248 .55726 .23852 .55383 Mtetra
.515 .714 .962 r
.23852 .55383 .24248 .55726 .24824 .55684 .24429 .5534 Mtetra
.553 .728 .956 r
.24429 .5534 .24824 .55684 .25406 .55608 .25011 .55264 Mtetra
.593 .741 .947 r
.25011 .55264 .25406 .55608 .25992 .55492 .25598 .55147 Mtetra
.605 .745 .943 r
.25598 .55147 .25992 .55492 .26581 .55362 .26188 .55016 Mtetra
.611 .747 .942 r
.26188 .55016 .26581 .55362 .27171 .55225 .26779 .54878 Mtetra
.615 .748 .94 r
.26779 .54878 .27171 .55225 .27764 .55082 .27373 .54734 Mtetra
.616 .748 .94 r
.27373 .54734 .27764 .55082 .28358 .54938 .27968 .5459 Mtetra
.617 .749 .94 r
.27968 .5459 .28358 .54938 .28954 .54792 .28564 .54444 Mtetra
.616 .749 .94 r
.28564 .54444 .28954 .54792 .29552 .54647 .29162 .54298 Mtetra
.29162 .54298 .29552 .54647 .3015 .54501 .29762 .54151 Mtetra
.29762 .54151 .3015 .54501 .30751 .54355 .30363 .54005 Mtetra
.616 .748 .94 r
.30363 .54005 .30751 .54355 .31353 .5421 .30966 .53858 Mtetra
.30966 .53858 .31353 .5421 .31956 .54064 .3157 .53711 Mtetra
.3157 .53711 .31956 .54064 .32561 .53917 .32176 .53564 Mtetra
.615 .748 .94 r
.32176 .53564 .32561 .53917 .33168 .53771 .32783 .53418 Mtetra
.615 .748 .941 r
.32783 .53418 .33168 .53771 .33776 .53625 .33392 .53271 Mtetra
.33392 .53271 .33776 .53625 .34385 .53479 .34002 .53124 Mtetra
.34002 .53124 .34385 .53479 .34996 .53332 .34614 .52976 Mtetra
.614 .748 .941 r
.34614 .52976 .34996 .53332 .35609 .53186 .35228 .52829 Mtetra
.35228 .52829 .35609 .53186 .36223 .5304 .35843 .52682 Mtetra
.613 .748 .941 r
.35843 .52682 .36223 .5304 .36839 .52893 .3646 .52535 Mtetra
.3646 .52535 .36839 .52893 .37457 .52747 .37078 .52388 Mtetra
.37078 .52388 .37457 .52747 .38076 .52601 .37698 .52241 Mtetra
.37698 .52241 .38076 .52601 .38697 .52455 .3832 .52094 Mtetra
.612 .747 .942 r
.3832 .52094 .38697 .52455 .39319 .52309 .38943 .51948 Mtetra
.38943 .51948 .39319 .52309 .39943 .52163 .39568 .51801 Mtetra
.611 .747 .942 r
.39568 .51801 .39943 .52163 .40568 .52017 .40194 .51655 Mtetra
.40194 .51655 .40568 .52017 .41196 .51871 .40822 .51508 Mtetra
.40822 .51508 .41196 .51871 .41825 .51725 .41452 .51361 Mtetra
.61 .747 .942 r
.41452 .51361 .41825 .51725 .42455 .5158 .42083 .51215 Mtetra
.42083 .51215 .42455 .5158 .43087 .51435 .42716 .51069 Mtetra
.42716 .51069 .43087 .51435 .43721 .51289 .43351 .50923 Mtetra
.608 .746 .943 r
.43351 .50923 .43721 .51289 .44357 .51145 .43987 .50778 Mtetra
.43987 .50778 .44357 .51145 .44994 .51 .44626 .50632 Mtetra
.44626 .50632 .44994 .51 .45633 .50855 .45265 .50486 Mtetra
.607 .746 .943 r
.45265 .50486 .45633 .50855 .46273 .50711 .45907 .50341 Mtetra
.45907 .50341 .46273 .50711 .46916 .50567 .4655 .50197 Mtetra
.4655 .50197 .46916 .50567 .4756 .50423 .47195 .50052 Mtetra
.605 .745 .944 r
.47195 .50052 .4756 .50423 .48206 .50279 .47842 .49908 Mtetra
.47842 .49908 .48206 .50279 .48854 .50137 .48491 .49764 Mtetra
.48491 .49764 .48854 .50137 .49503 .49993 .49141 .4962 Mtetra
.604 .745 .944 r
.49141 .4962 .49503 .49993 .50154 .49851 .49793 .49477 Mtetra
.603 .745 .944 r
.49793 .49477 .50154 .49851 .50807 .4971 .50447 .49335 Mtetra
.50447 .49335 .50807 .4971 .51462 .49568 .51103 .49192 Mtetra
.602 .744 .945 r
.51103 .49192 .51462 .49568 .52119 .49426 .5176 .4905 Mtetra
.6 .744 .945 r
.5176 .4905 .52119 .49426 .52777 .49286 .5242 .48909 Mtetra
.5242 .48909 .52777 .49286 .53437 .49146 .53081 .48768 Mtetra
.53081 .48768 .53437 .49146 .54099 .49006 .53744 .48627 Mtetra
.598 .743 .946 r
.53744 .48627 .54099 .49006 .54763 .48868 .54409 .48488 Mtetra
.54409 .48488 .54763 .48868 .55429 .48729 .55076 .48349 Mtetra
.55076 .48349 .55429 .48729 .56097 .4859 .55745 .48209 Mtetra
.595 .742 .946 r
.55745 .48209 .56097 .4859 .56767 .48454 .56416 .48073 Mtetra
.56416 .48073 .56767 .48454 .57439 .48319 .57088 .47936 Mtetra
.594 .742 .947 r
.57088 .47936 .57439 .48319 .58112 .48183 .57763 .478 Mtetra
.593 .742 .947 r
.57763 .478 .58112 .48183 .58788 .48048 .5844 .47664 Mtetra
.593 .741 .947 r
.5844 .47664 .58788 .48048 .59465 .47914 .59118 .47529 Mtetra
.591 .741 .947 r
.59118 .47529 .59465 .47914 .60145 .47781 .59799 .47396 Mtetra
.59 .74 .947 r
.59799 .47396 .60145 .47781 .60826 .47649 .60481 .47263 Mtetra
.59 .74 .948 r
.60481 .47263 .60826 .47649 .6151 .47517 .61166 .4713 Mtetra
.588 .739 .948 r
.61166 .4713 .6151 .47517 .62196 .47387 .61853 .46999 Mtetra
.587 .739 .948 r
.61853 .46999 .62196 .47387 .62883 .47258 .62541 .46869 Mtetra
.586 .739 .948 r
.62541 .46869 .62883 .47258 .63573 .47129 .63232 .4674 Mtetra
.584 .738 .949 r
.63232 .4674 .63573 .47129 .64265 .47003 .63925 .46612 Mtetra
.63925 .46612 .64265 .47003 .64959 .46877 .6462 .46486 Mtetra
.582 .738 .949 r
.6462 .46486 .64959 .46877 .65655 .46752 .65318 .4636 Mtetra
.581 .737 .95 r
.65318 .4636 .65655 .46752 .66353 .46629 .66017 .46236 Mtetra
.579 .736 .95 r
.66017 .46236 .66353 .46629 .67054 .46507 .66719 .46113 Mtetra
.578 .736 .95 r
.66719 .46113 .67054 .46507 .67757 .46386 .67423 .45992 Mtetra
.576 .735 .951 r
.67423 .45992 .67757 .46386 .68462 .46267 .68129 .45872 Mtetra
.575 .735 .951 r
.68129 .45872 .68462 .46267 .69169 .4615 .68837 .45754 Mtetra
.573 .734 .951 r
.68837 .45754 .69169 .4615 .69879 .46034 .69548 .45638 Mtetra
.572 .733 .951 r
.69548 .45638 .69879 .46034 .7059 .45919 .70261 .45522 Mtetra
.569 .732 .952 r
.70261 .45522 .7059 .45919 .71305 .45808 .70976 .4541 Mtetra
.567 .732 .952 r
.70976 .4541 .71305 .45808 .72021 .45698 .71694 .45299 Mtetra
.566 .731 .952 r
.71694 .45299 .72021 .45698 .7274 .45589 .72414 .4519 Mtetra
.564 .73 .953 r
.72414 .4519 .7274 .45589 .73462 .45483 .73137 .45083 Mtetra
.562 .73 .953 r
.73137 .45083 .73462 .45483 .74186 .45379 .73862 .44978 Mtetra
.561 .729 .953 r
.73862 .44978 .74186 .45379 .74912 .45275 .7459 .44874 Mtetra
.56 .729 .954 r
.7459 .44874 .74912 .45275 .75641 .45173 .7532 .44771 Mtetra
.561 .729 .954 r
.7532 .44771 .75641 .45173 .76372 .45069 .76052 .44666 Mtetra
.565 .731 .953 r
.76052 .44666 .76372 .45069 .77105 .4496 .76786 .44556 Mtetra
.581 .739 .951 r
.76786 .44556 .77105 .4496 .77839 .44828 .77522 .44424 Mtetra
.597 .746 .948 r
.77522 .44424 .77839 .44828 .78574 .44676 .78257 .4427 Mtetra
.647 .767 .937 r
.78257 .4427 .78574 .44676 .79304 .4445 .78989 .44043 Mtetra
.712 .792 .914 r
.78989 .44043 .79304 .4445 .80027 .44111 .79714 .43702 Mtetra
.752 .804 .894 r
.79714 .43702 .80027 .44111 .80744 .43686 .80432 .43275 Mtetra
.866 .825 .806 r
.80432 .43275 .80744 .43686 .81429 .42893 .81119 .42478 Mtetra
.905 .823 .756 r
.81119 .42478 .81429 .42893 .82093 .41868 .81784 .41448 Mtetra
.94 .813 .692 r
.81784 .41448 .82093 .41868 .82721 .40493 .82414 .40067 Mtetra
.967 .794 .616 r
.82414 .40067 .82721 .40493 .83293 .38558 .82988 .38126 Mtetra
.974 .785 .588 r
.82988 .38126 .83293 .38558 .83832 .36361 .8353 .35922 Mtetra
.93 .563 .291 r
.19565 .4865 .19958 .48994 .20349 .50622 .19954 .50279 Mtetra
.925 .546 .261 r
.19954 .50279 .20349 .50622 .20759 .52122 .20363 .5178 Mtetra
.897 .478 .152 r
.20363 .5178 .20759 .52122 .21209 .53272 .20812 .5293 Mtetra
.835 .368 0 r
.20812 .5293 .21209 .53272 .2169 .54137 .21292 .53795 Mtetra
.732 .228 0 r
.21292 .53795 .2169 .54137 .22193 .54813 .21795 .54471 Mtetra
0 .322 .779 r
.21795 .54471 .22193 .54813 .22734 .55118 .22336 .54774 Mtetra
.091 .491 .899 r
.22336 .54774 .22734 .55118 .23286 .55319 .22888 .54975 Mtetra
.364 .646 .964 r
.22888 .54975 .23286 .55319 .23852 .55383 .23455 .55038 Mtetra
.515 .713 .962 r
.23455 .55038 .23852 .55383 .24429 .5534 .24033 .54995 Mtetra
.553 .728 .956 r
.24033 .54995 .24429 .5534 .25011 .55264 .24615 .54918 Mtetra
.593 .741 .947 r
.24615 .54918 .25011 .55264 .25598 .55147 .25203 .548 Mtetra
.605 .745 .943 r
.25203 .548 .25598 .55147 .26188 .55016 .25793 .54669 Mtetra
.611 .747 .942 r
.25793 .54669 .26188 .55016 .26779 .54878 .26385 .5453 Mtetra
.615 .748 .94 r
.26385 .5453 .26779 .54878 .27373 .54734 .2698 .54386 Mtetra
.616 .748 .94 r
.2698 .54386 .27373 .54734 .27968 .5459 .27575 .5424 Mtetra
.617 .748 .94 r
.27575 .5424 .27968 .5459 .28564 .54444 .28173 .54094 Mtetra
.616 .748 .94 r
.28173 .54094 .28564 .54444 .29162 .54298 .28772 .53947 Mtetra
.28772 .53947 .29162 .54298 .29762 .54151 .29372 .538 Mtetra
.29372 .538 .29762 .54151 .30363 .54005 .29974 .53652 Mtetra
.29974 .53652 .30363 .54005 .30966 .53858 .30577 .53505 Mtetra
.30577 .53505 .30966 .53858 .3157 .53711 .31182 .53358 Mtetra
.31182 .53358 .3157 .53711 .32176 .53564 .31789 .5321 Mtetra
.615 .748 .94 r
.31789 .5321 .32176 .53564 .32783 .53418 .32397 .53062 Mtetra
.615 .748 .941 r
.32397 .53062 .32783 .53418 .33392 .53271 .33007 .52915 Mtetra
.33007 .52915 .33392 .53271 .34002 .53124 .33618 .52767 Mtetra
.33618 .52767 .34002 .53124 .34614 .52976 .34231 .52619 Mtetra
.614 .748 .941 r
.34231 .52619 .34614 .52976 .35228 .52829 .34845 .52471 Mtetra
.34845 .52471 .35228 .52829 .35843 .52682 .35461 .52323 Mtetra
.613 .748 .941 r
.35461 .52323 .35843 .52682 .3646 .52535 .36079 .52176 Mtetra
.36079 .52176 .3646 .52535 .37078 .52388 .36698 .52028 Mtetra
.36698 .52028 .37078 .52388 .37698 .52241 .37319 .5188 Mtetra
.37319 .5188 .37698 .52241 .3832 .52094 .37941 .51733 Mtetra
.612 .747 .942 r
.37941 .51733 .3832 .52094 .38943 .51948 .38565 .51585 Mtetra
.611 .747 .942 r
.38565 .51585 .38943 .51948 .39568 .51801 .39191 .51438 Mtetra
.39191 .51438 .39568 .51801 .40194 .51655 .39818 .51291 Mtetra
.39818 .51291 .40194 .51655 .40822 .51508 .40447 .51143 Mtetra
.40447 .51143 .40822 .51508 .41452 .51361 .41077 .50996 Mtetra
.61 .747 .942 r
.41077 .50996 .41452 .51361 .42083 .51215 .4171 .50849 Mtetra
.4171 .50849 .42083 .51215 .42716 .51069 .42344 .50702 Mtetra
.42344 .50702 .42716 .51069 .43351 .50923 .42979 .50555 Mtetra
.608 .746 .943 r
.42979 .50555 .43351 .50923 .43987 .50778 .43617 .50409 Mtetra
.43617 .50409 .43987 .50778 .44626 .50632 .44256 .50263 Mtetra
.44256 .50263 .44626 .50632 .45265 .50486 .44896 .50116 Mtetra
.607 .746 .943 r
.44896 .50116 .45265 .50486 .45907 .50341 .45539 .49971 Mtetra
.606 .746 .943 r
.45539 .49971 .45907 .50341 .4655 .50197 .46183 .49825 Mtetra
.46183 .49825 .4655 .50197 .47195 .50052 .46829 .49679 Mtetra
.605 .746 .944 r
.46829 .49679 .47195 .50052 .47842 .49908 .47477 .49535 Mtetra
.605 .745 .944 r
.47477 .49535 .47842 .49908 .48491 .49764 .48126 .4939 Mtetra
.48126 .4939 .48491 .49764 .49141 .4962 .48778 .49245 Mtetra
.604 .745 .944 r
.48778 .49245 .49141 .4962 .49793 .49477 .49431 .49102 Mtetra
.603 .745 .944 r
.49431 .49102 .49793 .49477 .50447 .49335 .50086 .48959 Mtetra
.50086 .48959 .50447 .49335 .51103 .49192 .50742 .48815 Mtetra
.602 .745 .945 r
.50742 .48815 .51103 .49192 .5176 .4905 .51401 .48672 Mtetra
.6 .744 .945 r
.51401 .48672 .5176 .4905 .5242 .48909 .52061 .48531 Mtetra
.52061 .48531 .5242 .48909 .53081 .48768 .52723 .48389 Mtetra
.52723 .48389 .53081 .48768 .53744 .48627 .53388 .48247 Mtetra
.598 .743 .946 r
.53388 .48247 .53744 .48627 .54409 .48488 .54054 .48107 Mtetra
.54054 .48107 .54409 .48488 .55076 .48349 .54721 .47967 Mtetra
.54721 .47967 .55076 .48349 .55745 .48209 .55391 .47827 Mtetra
.595 .742 .946 r
.55391 .47827 .55745 .48209 .56416 .48073 .56063 .47689 Mtetra
.595 .742 .947 r
.56063 .47689 .56416 .48073 .57088 .47936 .56737 .47552 Mtetra
.594 .742 .947 r
.56737 .47552 .57088 .47936 .57763 .478 .57412 .47415 Mtetra
.593 .742 .947 r
.57412 .47415 .57763 .478 .5844 .47664 .5809 .47279 Mtetra
.5809 .47279 .5844 .47664 .59118 .47529 .5877 .47143 Mtetra
.591 .741 .947 r
.5877 .47143 .59118 .47529 .59799 .47396 .59451 .47009 Mtetra
.59 .741 .948 r
.59451 .47009 .59799 .47396 .60481 .47263 .60135 .46875 Mtetra
.60135 .46875 .60481 .47263 .61166 .4713 .6082 .46741 Mtetra
.588 .74 .948 r
.6082 .46741 .61166 .4713 .61853 .46999 .61508 .4661 Mtetra
.587 .739 .948 r
.61508 .4661 .61853 .46999 .62541 .46869 .62198 .46479 Mtetra
.586 .739 .949 r
.62198 .46479 .62541 .46869 .63232 .4674 .6289 .46349 Mtetra
.584 .738 .949 r
.6289 .46349 .63232 .4674 .63925 .46612 .63584 .46221 Mtetra
.583 .738 .949 r
.63584 .46221 .63925 .46612 .6462 .46486 .6428 .46093 Mtetra
.582 .738 .95 r
.6428 .46093 .6462 .46486 .65318 .4636 .64979 .45967 Mtetra
.58 .737 .95 r
.64979 .45967 .65318 .4636 .66017 .46236 .65679 .45842 Mtetra
.579 .737 .95 r
.65679 .45842 .66017 .46236 .66719 .46113 .66382 .45719 Mtetra
.578 .736 .951 r
.66382 .45719 .66719 .46113 .67423 .45992 .67087 .45597 Mtetra
.576 .735 .951 r
.67087 .45597 .67423 .45992 .68129 .45872 .67794 .45476 Mtetra
.574 .735 .951 r
.67794 .45476 .68129 .45872 .68837 .45754 .68504 .45357 Mtetra
.573 .734 .951 r
.68504 .45357 .68837 .45754 .69548 .45638 .69216 .4524 Mtetra
.572 .734 .952 r
.69216 .4524 .69548 .45638 .70261 .45522 .6993 .45124 Mtetra
.569 .733 .952 r
.6993 .45124 .70261 .45522 .70976 .4541 .70646 .45011 Mtetra
.567 .732 .953 r
.70646 .45011 .70976 .4541 .71694 .45299 .71365 .449 Mtetra
.566 .732 .953 r
.71365 .449 .71694 .45299 .72414 .4519 .72087 .44789 Mtetra
.563 .73 .953 r
.72087 .44789 .72414 .4519 .73137 .45083 .72811 .44682 Mtetra
.562 .73 .954 r
.72811 .44682 .73137 .45083 .73862 .44978 .73537 .44576 Mtetra
.561 .729 .954 r
.73537 .44576 .73862 .44978 .7459 .44874 .74266 .44472 Mtetra
.559 .729 .954 r
.74266 .44472 .7459 .44874 .7532 .44771 .74997 .44368 Mtetra
.561 .73 .954 r
.74997 .44368 .7532 .44771 .76052 .44666 .75731 .44262 Mtetra
.564 .732 .953 r
.75731 .44262 .76052 .44666 .76786 .44556 .76466 .44151 Mtetra
.581 .739 .951 r
.76466 .44151 .76786 .44556 .77522 .44424 .77202 .44018 Mtetra
.597 .747 .948 r
.77202 .44018 .77522 .44424 .78257 .4427 .77939 .43863 Mtetra
.647 .768 .937 r
.77939 .43863 .78257 .4427 .78989 .44043 .78673 .43635 Mtetra
.712 .792 .914 r
.78673 .43635 .78989 .44043 .79714 .43702 .79398 .43292 Mtetra
.753 .805 .894 r
.79398 .43292 .79714 .43702 .80432 .43275 .80118 .42861 Mtetra
.866 .825 .806 r
.80118 .42861 .80432 .43275 .81119 .42478 .80806 .4206 Mtetra
.905 .823 .755 r
.80806 .4206 .81119 .42478 .81784 .41448 .81473 .41026 Mtetra
.94 .813 .691 r
.81473 .41026 .81784 .41448 .82414 .40067 .82105 .39639 Mtetra
.967 .794 .616 r
.82105 .39639 .82414 .40067 .82988 .38126 .82681 .37691 Mtetra
.974 .785 .587 r
.82681 .37691 .82988 .38126 .8353 .35922 .83226 .3548 Mtetra
.93 .562 .291 r
.19171 .48307 .19565 .4865 .19954 .50279 .19558 .49937 Mtetra
.925 .545 .262 r
.19558 .49937 .19954 .50279 .20363 .5178 .19965 .51438 Mtetra
.897 .478 .152 r
.19965 .51438 .20363 .5178 .20812 .5293 .20413 .52588 Mtetra
.835 .368 0 r
.20413 .52588 .20812 .5293 .21292 .53795 .20893 .53453 Mtetra
.733 .228 0 r
.20893 .53453 .21292 .53795 .21795 .54471 .21395 .54129 Mtetra
0 .321 .778 r
.21395 .54129 .21795 .54471 .22336 .54774 .21936 .54432 Mtetra
.089 .491 .899 r
.21936 .54432 .22336 .54774 .22888 .54975 .22489 .54632 Mtetra
.363 .647 .964 r
.22489 .54632 .22888 .54975 .23455 .55038 .23056 .54694 Mtetra
.515 .714 .962 r
.23056 .54694 .23455 .55038 .24033 .54995 .23634 .54651 Mtetra
.553 .728 .956 r
.23634 .54651 .24033 .54995 .24615 .54918 .24218 .54573 Mtetra
.593 .742 .947 r
.24218 .54573 .24615 .54918 .25203 .548 .24806 .54454 Mtetra
.605 .746 .944 r
.24806 .54454 .25203 .548 .25793 .54669 .25397 .54322 Mtetra
.611 .748 .942 r
.25397 .54322 .25793 .54669 .26385 .5453 .2599 .54182 Mtetra
.615 .749 .941 r
.2599 .54182 .26385 .5453 .2698 .54386 .26585 .54037 Mtetra
.616 .749 .941 r
.26585 .54037 .2698 .54386 .27575 .5424 .27181 .53891 Mtetra
.27181 .53891 .27575 .5424 .28173 .54094 .27779 .53744 Mtetra
.27779 .53744 .28173 .54094 .28772 .53947 .28379 .53596 Mtetra
.28379 .53596 .28772 .53947 .29372 .538 .2898 .53448 Mtetra
.2898 .53448 .29372 .538 .29974 .53652 .29583 .533 Mtetra
.29583 .533 .29974 .53652 .30577 .53505 .30187 .53152 Mtetra
.615 .749 .941 r
.30187 .53152 .30577 .53505 .31182 .53358 .30793 .53004 Mtetra
.30793 .53004 .31182 .53358 .31789 .5321 .314 .52855 Mtetra
.314 .52855 .31789 .5321 .32397 .53062 .32009 .52707 Mtetra
.32009 .52707 .32397 .53062 .33007 .52915 .3262 .52559 Mtetra
.3262 .52559 .33007 .52915 .33618 .52767 .33232 .5241 Mtetra
.614 .749 .941 r
.33232 .5241 .33618 .52767 .34231 .52619 .33845 .52262 Mtetra
.33845 .52262 .34231 .52619 .34845 .52471 .34461 .52113 Mtetra
.614 .749 .942 r
.34461 .52113 .34845 .52471 .35461 .52323 .35077 .51964 Mtetra
.613 .749 .942 r
.35077 .51964 .35461 .52323 .36079 .52176 .35696 .51816 Mtetra
.613 .748 .942 r
.35696 .51816 .36079 .52176 .36698 .52028 .36316 .51667 Mtetra
.36316 .51667 .36698 .52028 .37319 .5188 .36937 .51519 Mtetra
.612 .748 .942 r
.36937 .51519 .37319 .5188 .37941 .51733 .37561 .5137 Mtetra
.37561 .5137 .37941 .51733 .38565 .51585 .38185 .51222 Mtetra
.611 .748 .942 r
.38185 .51222 .38565 .51585 .39191 .51438 .38812 .51074 Mtetra
.38812 .51074 .39191 .51438 .39818 .51291 .3944 .50926 Mtetra
.3944 .50926 .39818 .51291 .40447 .51143 .4007 .50778 Mtetra
.611 .748 .943 r
.4007 .50778 .40447 .51143 .41077 .50996 .40701 .5063 Mtetra
.609 .747 .943 r
.40701 .5063 .41077 .50996 .4171 .50849 .41334 .50482 Mtetra
.41334 .50482 .4171 .50849 .42344 .50702 .41969 .50335 Mtetra
.41969 .50335 .42344 .50702 .42979 .50555 .42606 .50187 Mtetra
.608 .747 .943 r
.42606 .50187 .42979 .50555 .43617 .50409 .43244 .5004 Mtetra
.43244 .5004 .43617 .50409 .44256 .50263 .43884 .49893 Mtetra
.43884 .49893 .44256 .50263 .44896 .50116 .44526 .49745 Mtetra
.606 .747 .944 r
.44526 .49745 .44896 .50116 .45539 .49971 .45169 .49599 Mtetra
.606 .746 .944 r
.45169 .49599 .45539 .49971 .46183 .49825 .45814 .49453 Mtetra
.606 .747 .944 r
.45814 .49453 .46183 .49825 .46829 .49679 .46461 .49306 Mtetra
.605 .746 .944 r
.46461 .49306 .46829 .49679 .47477 .49535 .4711 .49161 Mtetra
.604 .746 .944 r
.4711 .49161 .47477 .49535 .48126 .4939 .4776 .49016 Mtetra
.4776 .49016 .48126 .4939 .48778 .49245 .48412 .4887 Mtetra
.603 .746 .945 r
.48412 .4887 .48778 .49245 .49431 .49102 .49066 .48726 Mtetra
.602 .745 .945 r
.49066 .48726 .49431 .49102 .50086 .48959 .49722 .48582 Mtetra
.49722 .48582 .50086 .48959 .50742 .48815 .5038 .48438 Mtetra
.5038 .48438 .50742 .48815 .51401 .48672 .5104 .48294 Mtetra
.6 .745 .946 r
.5104 .48294 .51401 .48672 .52061 .48531 .51701 .48152 Mtetra
.51701 .48152 .52061 .48531 .52723 .48389 .52364 .48009 Mtetra
.52364 .48009 .52723 .48389 .53388 .48247 .53029 .47866 Mtetra
.598 .744 .946 r
.53029 .47866 .53388 .48247 .54054 .48107 .53696 .47726 Mtetra
.53696 .47726 .54054 .48107 .54721 .47967 .54365 .47585 Mtetra
.54365 .47585 .54721 .47967 .55391 .47827 .55036 .47444 Mtetra
.595 .743 .947 r
.55036 .47444 .55391 .47827 .56063 .47689 .55709 .47306 Mtetra
.594 .743 .947 r
.55709 .47306 .56063 .47689 .56737 .47552 .56383 .47168 Mtetra
.56383 .47168 .56737 .47552 .57412 .47415 .5706 .4703 Mtetra
.593 .742 .947 r
.5706 .4703 .57412 .47415 .5809 .47279 .57739 .46893 Mtetra
.592 .742 .948 r
.57739 .46893 .5809 .47279 .5877 .47143 .58419 .46756 Mtetra
.591 .742 .948 r
.58419 .46756 .5877 .47143 .59451 .47009 .59102 .46621 Mtetra
.59 .741 .948 r
.59102 .46621 .59451 .47009 .60135 .46875 .59787 .46487 Mtetra
.589 .741 .948 r
.59787 .46487 .60135 .46875 .6082 .46741 .60473 .46352 Mtetra
.587 .74 .949 r
.60473 .46352 .6082 .46741 .61508 .4661 .61162 .4622 Mtetra
.61162 .4622 .61508 .4661 .62198 .46479 .61853 .46089 Mtetra
.586 .74 .949 r
.61853 .46089 .62198 .46479 .6289 .46349 .62546 .45958 Mtetra
.584 .739 .95 r
.62546 .45958 .6289 .46349 .63584 .46221 .63241 .45829 Mtetra
.583 .739 .95 r
.63241 .45829 .63584 .46221 .6428 .46093 .63939 .45701 Mtetra
.582 .738 .95 r
.63939 .45701 .6428 .46093 .64979 .45967 .64638 .45573 Mtetra
.58 .738 .951 r
.64638 .45573 .64979 .45967 .65679 .45842 .6534 .45448 Mtetra
.579 .737 .951 r
.6534 .45448 .65679 .45842 .66382 .45719 .66044 .45324 Mtetra
.577 .737 .951 r
.66044 .45324 .66382 .45719 .67087 .45597 .6675 .45201 Mtetra
.576 .736 .951 r
.6675 .45201 .67087 .45597 .67794 .45476 .67458 .4508 Mtetra
.574 .735 .952 r
.67458 .4508 .67794 .45476 .68504 .45357 .68169 .4496 Mtetra
.572 .735 .952 r
.68169 .4496 .68504 .45357 .69216 .4524 .68882 .44842 Mtetra
.571 .734 .952 r
.68882 .44842 .69216 .4524 .6993 .45124 .69597 .44726 Mtetra
.568 .733 .953 r
.69597 .44726 .6993 .45124 .70646 .45011 .70315 .44612 Mtetra
.567 .733 .953 r
.70315 .44612 .70646 .45011 .71365 .449 .71035 .445 Mtetra
.566 .732 .953 r
.71035 .445 .71365 .449 .72087 .44789 .71758 .44389 Mtetra
.563 .731 .954 r
.71758 .44389 .72087 .44789 .72811 .44682 .72483 .44281 Mtetra
.561 .731 .954 r
.72483 .44281 .72811 .44682 .73537 .44576 .7321 .44174 Mtetra
.56 .73 .954 r
.7321 .44174 .73537 .44576 .74266 .44472 .7394 .44069 Mtetra
.559 .73 .955 r
.7394 .44069 .74266 .44472 .74997 .44368 .74673 .43965 Mtetra
.56 .731 .955 r
.74673 .43965 .74997 .44368 .75731 .44262 .75408 .43858 Mtetra
.564 .732 .954 r
.75408 .43858 .75731 .44262 .76466 .44151 .76144 .43747 Mtetra
.581 .74 .952 r
.76144 .43747 .76466 .44151 .77202 .44018 .76882 .43613 Mtetra
.597 .748 .949 r
.76882 .43613 .77202 .44018 .77939 .43863 .7762 .43457 Mtetra
.647 .769 .937 r
.7762 .43457 .77939 .43863 .78673 .43635 .78355 .43226 Mtetra
.713 .793 .914 r
.78355 .43226 .78673 .43635 .79398 .43292 .79082 .42881 Mtetra
.754 .806 .894 r
.79082 .42881 .79398 .43292 .80118 .42861 .79803 .42448 Mtetra
.867 .826 .805 r
.79803 .42448 .80118 .42861 .80806 .4206 .80493 .41643 Mtetra
.906 .824 .754 r
.80493 .41643 .80806 .4206 .81473 .41026 .81161 .40602 Mtetra
.941 .813 .69 r
.81161 .40602 .81473 .41026 .82105 .39639 .81795 .39209 Mtetra
.967 .794 .615 r
.81795 .39209 .82105 .39639 .82681 .37691 .82373 .37254 Mtetra
.974 .784 .587 r
.82373 .37254 .82681 .37691 .83226 .3548 .8292 .35035 Mtetra
.93 .562 .291 r
.18774 .47962 .19171 .48307 .19558 .49937 .1916 .49593 Mtetra
.925 .545 .262 r
.1916 .49593 .19558 .49937 .19965 .51438 .19565 .51095 Mtetra
.897 .478 .152 r
.19565 .51095 .19965 .51438 .20413 .52588 .20012 .52245 Mtetra
.835 .368 0 r
.20012 .52245 .20413 .52588 .20893 .53453 .20492 .5311 Mtetra
.733 .228 0 r
.20492 .5311 .20893 .53453 .21395 .54129 .20994 .53785 Mtetra
0 .322 .778 r
.20994 .53785 .21395 .54129 .21936 .54432 .21534 .54088 Mtetra
.09 .492 .899 r
.21534 .54088 .21936 .54432 .22489 .54632 .22087 .54287 Mtetra
.363 .647 .964 r
.22087 .54287 .22489 .54632 .23056 .54694 .22655 .54349 Mtetra
.515 .714 .962 r
.22655 .54349 .23056 .54694 .23634 .54651 .23234 .54304 Mtetra
.553 .728 .956 r
.23234 .54304 .23634 .54651 .24218 .54573 .23818 .54226 Mtetra
.593 .742 .947 r
.23818 .54226 .24218 .54573 .24806 .54454 .24407 .54106 Mtetra
.605 .746 .944 r
.24407 .54106 .24806 .54454 .25397 .54322 .24999 .53973 Mtetra
.611 .748 .942 r
.24999 .53973 .25397 .54322 .2599 .54182 .25592 .53833 Mtetra
.615 .749 .941 r
.25592 .53833 .2599 .54182 .26585 .54037 .26188 .53687 Mtetra
.616 .749 .941 r
.26188 .53687 .26585 .54037 .27181 .53891 .26785 .5354 Mtetra
.26785 .5354 .27181 .53891 .27779 .53744 .27384 .53392 Mtetra
.27384 .53392 .27779 .53744 .28379 .53596 .27985 .53244 Mtetra
.27985 .53244 .28379 .53596 .2898 .53448 .28587 .53095 Mtetra
.28587 .53095 .2898 .53448 .29583 .533 .2919 .52946 Mtetra
.2919 .52946 .29583 .533 .30187 .53152 .29795 .52798 Mtetra
.615 .749 .941 r
.29795 .52798 .30187 .53152 .30793 .53004 .30402 .52649 Mtetra
.30402 .52649 .30793 .53004 .314 .52855 .3101 .52499 Mtetra
.3101 .52499 .314 .52855 .32009 .52707 .3162 .5235 Mtetra
.3162 .5235 .32009 .52707 .3262 .52559 .32231 .52201 Mtetra
.32231 .52201 .3262 .52559 .33232 .5241 .32844 .52052 Mtetra
.614 .749 .941 r
.32844 .52052 .33232 .5241 .33845 .52262 .33458 .51902 Mtetra
.33458 .51902 .33845 .52262 .34461 .52113 .34074 .51753 Mtetra
.613 .749 .942 r
.34074 .51753 .34461 .52113 .35077 .51964 .34692 .51604 Mtetra
.34692 .51604 .35077 .51964 .35696 .51816 .35311 .51455 Mtetra
.613 .748 .942 r
.35311 .51455 .35696 .51816 .36316 .51667 .35932 .51305 Mtetra
.35932 .51305 .36316 .51667 .36937 .51519 .36554 .51156 Mtetra
.612 .748 .942 r
.36554 .51156 .36937 .51519 .37561 .5137 .37178 .51007 Mtetra
.37178 .51007 .37561 .5137 .38185 .51222 .37804 .50858 Mtetra
.611 .748 .942 r
.37804 .50858 .38185 .51222 .38812 .51074 .38431 .50709 Mtetra
.611 .748 .943 r
.38431 .50709 .38812 .51074 .3944 .50926 .3906 .5056 Mtetra
.3906 .5056 .3944 .50926 .4007 .50778 .39691 .50411 Mtetra
.61 .748 .943 r
.39691 .50411 .4007 .50778 .40701 .5063 .40324 .50262 Mtetra
.609 .747 .943 r
.40324 .50262 .40701 .5063 .41334 .50482 .40958 .50114 Mtetra
.609 .748 .943 r
.40958 .50114 .41334 .50482 .41969 .50335 .41593 .49966 Mtetra
.41593 .49966 .41969 .50335 .42606 .50187 .42231 .49817 Mtetra
.608 .747 .943 r
.42231 .49817 .42606 .50187 .43244 .5004 .4287 .49669 Mtetra
.4287 .49669 .43244 .5004 .43884 .49893 .43511 .49522 Mtetra
.43511 .49522 .43884 .49893 .44526 .49745 .44153 .49373 Mtetra
.606 .747 .944 r
.44153 .49373 .44526 .49745 .45169 .49599 .44798 .49226 Mtetra
.44798 .49226 .45169 .49599 .45814 .49453 .45444 .4908 Mtetra
.45444 .4908 .45814 .49453 .46461 .49306 .46092 .48932 Mtetra
.605 .746 .944 r
.46092 .48932 .46461 .49306 .4711 .49161 .46741 .48786 Mtetra
.604 .746 .945 r
.46741 .48786 .4711 .49161 .4776 .49016 .47393 .4864 Mtetra
.47393 .4864 .4776 .49016 .48412 .4887 .48046 .48494 Mtetra
.603 .746 .945 r
.48046 .48494 .48412 .4887 .49066 .48726 .48701 .48348 Mtetra
.602 .745 .945 r
.48701 .48348 .49066 .48726 .49722 .48582 .49357 .48204 Mtetra
.602 .746 .945 r
.49357 .48204 .49722 .48582 .5038 .48438 .50016 .48059 Mtetra
.602 .745 .945 r
.50016 .48059 .5038 .48438 .5104 .48294 .50677 .47914 Mtetra
.6 .745 .946 r
.50677 .47914 .5104 .48294 .51701 .48152 .51339 .47771 Mtetra
.51339 .47771 .51701 .48152 .52364 .48009 .52003 .47628 Mtetra
.52003 .47628 .52364 .48009 .53029 .47866 .52669 .47484 Mtetra
.597 .744 .946 r
.52669 .47484 .53029 .47866 .53696 .47726 .53337 .47343 Mtetra
.53337 .47343 .53696 .47726 .54365 .47585 .54007 .47202 Mtetra
.598 .744 .946 r
.54007 .47202 .54365 .47585 .55036 .47444 .54679 .4706 Mtetra
.595 .743 .947 r
.54679 .4706 .55036 .47444 .55709 .47306 .55353 .46921 Mtetra
.594 .743 .947 r
.55353 .46921 .55709 .47306 .56383 .47168 .56028 .46782 Mtetra
.56028 .46782 .56383 .47168 .5706 .4703 .56706 .46643 Mtetra
.593 .742 .948 r
.56706 .46643 .5706 .4703 .57739 .46893 .57386 .46506 Mtetra
.592 .742 .948 r
.57386 .46506 .57739 .46893 .58419 .46756 .58068 .46368 Mtetra
.591 .742 .948 r
.58068 .46368 .58419 .46756 .59102 .46621 .58751 .46232 Mtetra
.59 .741 .948 r
.58751 .46232 .59102 .46621 .59787 .46487 .59437 .46097 Mtetra
.589 .741 .949 r
.59437 .46097 .59787 .46487 .60473 .46352 .60125 .45962 Mtetra
.587 .741 .949 r
.60125 .45962 .60473 .46352 .61162 .4622 .60815 .45829 Mtetra
.586 .74 .949 r
.60815 .45829 .61162 .4622 .61853 .46089 .61507 .45697 Mtetra
.61507 .45697 .61853 .46089 .62546 .45958 .62201 .45565 Mtetra
.584 .739 .95 r
.62201 .45565 .62546 .45958 .63241 .45829 .62897 .45436 Mtetra
.583 .739 .95 r
.62897 .45436 .63241 .45829 .63939 .45701 .63595 .45307 Mtetra
.582 .739 .95 r
.63595 .45307 .63939 .45701 .64638 .45573 .64296 .45179 Mtetra
.58 .738 .951 r
.64296 .45179 .64638 .45573 .6534 .45448 .64999 .45053 Mtetra
.579 .738 .951 r
.64999 .45053 .6534 .45448 .66044 .45324 .65704 .44928 Mtetra
.577 .737 .951 r
.65704 .44928 .66044 .45324 .6675 .45201 .66411 .44804 Mtetra
.575 .736 .952 r
.66411 .44804 .6675 .45201 .67458 .4508 .67121 .44682 Mtetra
.574 .736 .952 r
.67121 .44682 .67458 .4508 .68169 .4496 .67832 .44562 Mtetra
.572 .735 .952 r
.67832 .44562 .68169 .4496 .68882 .44842 .68547 .44443 Mtetra
.571 .735 .953 r
.68547 .44443 .68882 .44842 .69597 .44726 .69263 .44326 Mtetra
.568 .734 .953 r
.69263 .44326 .69597 .44726 .70315 .44612 .69982 .44211 Mtetra
.566 .733 .953 r
.69982 .44211 .70315 .44612 .71035 .445 .70703 .44099 Mtetra
.565 .733 .954 r
.70703 .44099 .71035 .445 .71758 .44389 .71427 .43987 Mtetra
.562 .731 .954 r
.71427 .43987 .71758 .44389 .72483 .44281 .72153 .43878 Mtetra
.561 .731 .954 r
.72153 .43878 .72483 .44281 .7321 .44174 .72882 .43771 Mtetra
.56 .73 .955 r
.72882 .43771 .7321 .44174 .7394 .44069 .73613 .43665 Mtetra
.558 .73 .955 r
.73613 .43665 .7394 .44069 .74673 .43965 .74347 .4356 Mtetra
.56 .731 .955 r
.74347 .4356 .74673 .43965 .75408 .43858 .75083 .43453 Mtetra
.563 .733 .955 r
.75083 .43453 .75408 .43858 .76144 .43747 .75821 .43341 Mtetra
.581 .741 .952 r
.75821 .43341 .76144 .43747 .76882 .43613 .7656 .43206 Mtetra
.597 .748 .949 r
.7656 .43206 .76882 .43613 .7762 .43457 .773 .43049 Mtetra
.648 .77 .938 r
.773 .43049 .7762 .43457 .78355 .43226 .78035 .42817 Mtetra
.714 .794 .914 r
.78035 .42817 .78355 .43226 .79082 .42881 .78764 .42469 Mtetra
.755 .806 .894 r
.78764 .42469 .79082 .42881 .79803 .42448 .79486 .42033 Mtetra
.868 .826 .805 r
.79486 .42033 .79803 .42448 .80493 .41643 .80178 .41223 Mtetra
.907 .824 .754 r
.80178 .41223 .80493 .41643 .81161 .40602 .80848 .40177 Mtetra
.941 .813 .69 r
.80848 .40177 .81161 .40602 .81795 .39209 .81484 .38777 Mtetra
.968 .794 .615 r
.81484 .38777 .81795 .39209 .82373 .37254 .82064 .36814 Mtetra
.974 .784 .586 r
.82064 .36814 .82373 .37254 .8292 .35035 .82613 .34587 Mtetra
.93 .562 .291 r
.18377 .47616 .18774 .47962 .1916 .49593 .1876 .49248 Mtetra
.925 .545 .262 r
.1876 .49248 .1916 .49593 .19565 .51095 .19164 .50751 Mtetra
.897 .478 .152 r
.19164 .50751 .19565 .51095 .20012 .52245 .1961 .51901 Mtetra
.834 .367 0 r
.1961 .51901 .20012 .52245 .20492 .5311 .20089 .52765 Mtetra
.732 .227 0 r
.20089 .52765 .20492 .5311 .20994 .53785 .2059 .5344 Mtetra
0 .323 .779 r
.2059 .5344 .20994 .53785 .21534 .54088 .21131 .53742 Mtetra
.091 .492 .899 r
.21131 .53742 .21534 .54088 .22087 .54287 .21684 .5394 Mtetra
.364 .647 .964 r
.21684 .5394 .22087 .54287 .22655 .54349 .22253 .54001 Mtetra
.515 .714 .962 r
.22253 .54001 .22655 .54349 .23234 .54304 .22832 .53956 Mtetra
.553 .728 .956 r
.22832 .53956 .23234 .54304 .23818 .54226 .23417 .53877 Mtetra
.593 .742 .947 r
.23417 .53877 .23818 .54226 .24407 .54106 .24007 .53757 Mtetra
.605 .746 .944 r
.24007 .53757 .24407 .54106 .24999 .53973 .24599 .53623 Mtetra
.611 .747 .942 r
.24599 .53623 .24999 .53973 .25592 .53833 .25193 .53482 Mtetra
.615 .749 .941 r
.25193 .53482 .25592 .53833 .26188 .53687 .2579 .53335 Mtetra
.616 .749 .941 r
.2579 .53335 .26188 .53687 .26785 .5354 .26388 .53188 Mtetra
.616 .749 .94 r
.26388 .53188 .26785 .5354 .27384 .53392 .26988 .53039 Mtetra
.616 .749 .941 r
.26988 .53039 .27384 .53392 .27985 .53244 .27589 .5289 Mtetra
.27589 .5289 .27985 .53244 .28587 .53095 .28192 .5274 Mtetra
.28192 .5274 .28587 .53095 .2919 .52946 .28796 .52591 Mtetra
.28796 .52591 .2919 .52946 .29795 .52798 .29402 .52441 Mtetra
.615 .749 .941 r
.29402 .52441 .29795 .52798 .30402 .52649 .30009 .52292 Mtetra
.30009 .52292 .30402 .52649 .3101 .52499 .30618 .52142 Mtetra
.30618 .52142 .3101 .52499 .3162 .5235 .31228 .51992 Mtetra
.31228 .51992 .3162 .5235 .32231 .52201 .31841 .51842 Mtetra
.31841 .51842 .32231 .52201 .32844 .52052 .32454 .51692 Mtetra
.614 .749 .941 r
.32454 .51692 .32844 .52052 .33458 .51902 .33069 .51542 Mtetra
.33069 .51542 .33458 .51902 .34074 .51753 .33686 .51392 Mtetra
.613 .749 .942 r
.33686 .51392 .34074 .51753 .34692 .51604 .34305 .51242 Mtetra
.34305 .51242 .34692 .51604 .35311 .51455 .34925 .51092 Mtetra
.34925 .51092 .35311 .51455 .35932 .51305 .35546 .50942 Mtetra
.612 .748 .942 r
.35546 .50942 .35932 .51305 .36554 .51156 .3617 .50792 Mtetra
.3617 .50792 .36554 .51156 .37178 .51007 .36795 .50642 Mtetra
.36795 .50642 .37178 .51007 .37804 .50858 .37421 .50492 Mtetra
.611 .748 .942 r
.37421 .50492 .37804 .50858 .38431 .50709 .38049 .50343 Mtetra
.611 .748 .943 r
.38049 .50343 .38431 .50709 .3906 .5056 .38679 .50193 Mtetra
.38679 .50193 .3906 .5056 .39691 .50411 .39311 .50044 Mtetra
.61 .748 .943 r
.39311 .50044 .39691 .50411 .40324 .50262 .39944 .49894 Mtetra
.609 .748 .943 r
.39944 .49894 .40324 .50262 .40958 .50114 .40579 .49745 Mtetra
.40579 .49745 .40958 .50114 .41593 .49966 .41216 .49596 Mtetra
.41216 .49596 .41593 .49966 .42231 .49817 .41854 .49446 Mtetra
.608 .747 .944 r
.41854 .49446 .42231 .49817 .4287 .49669 .42494 .49298 Mtetra
.42494 .49298 .4287 .49669 .43511 .49522 .43136 .49149 Mtetra
.43136 .49149 .43511 .49522 .44153 .49373 .43779 .49 Mtetra
.606 .747 .944 r
.43779 .49 .44153 .49373 .44798 .49226 .44425 .48852 Mtetra
.44425 .48852 .44798 .49226 .45444 .4908 .45072 .48705 Mtetra
.45072 .48705 .45444 .4908 .46092 .48932 .4572 .48557 Mtetra
.605 .746 .945 r
.4572 .48557 .46092 .48932 .46741 .48786 .46371 .4841 Mtetra
.604 .746 .945 r
.46371 .4841 .46741 .48786 .47393 .4864 .47023 .48263 Mtetra
.47023 .48263 .47393 .4864 .48046 .48494 .47677 .48116 Mtetra
.603 .746 .945 r
.47677 .48116 .48046 .48494 .48701 .48348 .48333 .4797 Mtetra
.602 .746 .945 r
.48333 .4797 .48701 .48348 .49357 .48204 .48991 .47824 Mtetra
.48991 .47824 .49357 .48204 .50016 .48059 .49651 .47679 Mtetra
.601 .746 .946 r
.49651 .47679 .50016 .48059 .50677 .47914 .50312 .47533 Mtetra
.6 .745 .946 r
.50312 .47533 .50677 .47914 .51339 .47771 .50975 .4739 Mtetra
.50975 .4739 .51339 .47771 .52003 .47628 .51641 .47245 Mtetra
.599 .745 .946 r
.51641 .47245 .52003 .47628 .52669 .47484 .52308 .47101 Mtetra
.597 .744 .947 r
.52308 .47101 .52669 .47484 .53337 .47343 .52977 .46959 Mtetra
.52977 .46959 .53337 .47343 .54007 .47202 .53648 .46817 Mtetra
.53648 .46817 .54007 .47202 .54679 .4706 .5432 .46674 Mtetra
.595 .743 .947 r
.5432 .46674 .54679 .4706 .55353 .46921 .54995 .46535 Mtetra
.594 .743 .948 r
.54995 .46535 .55353 .46921 .56028 .46782 .55672 .46395 Mtetra
.55672 .46395 .56028 .46782 .56706 .46643 .56351 .46256 Mtetra
.593 .743 .948 r
.56351 .46256 .56706 .46643 .57386 .46506 .57031 .46117 Mtetra
.592 .743 .948 r
.57031 .46117 .57386 .46506 .58068 .46368 .57714 .45979 Mtetra
.59 .742 .949 r
.57714 .45979 .58068 .46368 .58751 .46232 .58399 .45842 Mtetra
.58399 .45842 .58751 .46232 .59437 .46097 .59086 .45706 Mtetra
.589 .742 .949 r
.59086 .45706 .59437 .46097 .60125 .45962 .59775 .45571 Mtetra
.587 .741 .949 r
.59775 .45571 .60125 .45962 .60815 .45829 .60466 .45437 Mtetra
.586 .741 .95 r
.60466 .45437 .60815 .45829 .61507 .45697 .61159 .45304 Mtetra
.585 .74 .95 r
.61159 .45304 .61507 .45697 .62201 .45565 .61854 .45172 Mtetra
.583 .74 .95 r
.61854 .45172 .62201 .45565 .62897 .45436 .62551 .45041 Mtetra
.582 .739 .95 r
.62551 .45041 .62897 .45436 .63595 .45307 .63251 .44912 Mtetra
.581 .739 .951 r
.63251 .44912 .63595 .45307 .64296 .45179 .63952 .44783 Mtetra
.579 .738 .951 r
.63952 .44783 .64296 .45179 .64999 .45053 .64656 .44656 Mtetra
.578 .738 .951 r
.64656 .44656 .64999 .45053 .65704 .44928 .65362 .4453 Mtetra
.577 .737 .952 r
.65362 .4453 .65704 .44928 .66411 .44804 .66071 .44406 Mtetra
.575 .737 .952 r
.66071 .44406 .66411 .44804 .67121 .44682 .66781 .44284 Mtetra
.573 .736 .952 r
.66781 .44284 .67121 .44682 .67832 .44562 .67494 .44163 Mtetra
.572 .736 .953 r
.67494 .44163 .67832 .44562 .68547 .44443 .6821 .44043 Mtetra
.57 .735 .953 r
.6821 .44043 .68547 .44443 .69263 .44326 .68927 .43925 Mtetra
.568 .734 .954 r
.68927 .43925 .69263 .44326 .69982 .44211 .69648 .4381 Mtetra
.566 .733 .954 r
.69648 .4381 .69982 .44211 .70703 .44099 .7037 .43697 Mtetra
.565 .733 .954 r
.7037 .43697 .70703 .44099 .71427 .43987 .71095 .43584 Mtetra
.562 .732 .955 r
.71095 .43584 .71427 .43987 .72153 .43878 .71823 .43475 Mtetra
.56 .731 .955 r
.71823 .43475 .72153 .43878 .72882 .43771 .72552 .43367 Mtetra
.559 .731 .955 r
.72552 .43367 .72882 .43771 .73613 .43665 .73285 .4326 Mtetra
.558 .73 .956 r
.73285 .4326 .73613 .43665 .74347 .4356 .7402 .43155 Mtetra
.56 .731 .955 r
.7402 .43155 .74347 .4356 .75083 .43453 .74757 .43047 Mtetra
.563 .733 .955 r
.74757 .43047 .75083 .43453 .75821 .43341 .75496 .42934 Mtetra
.581 .741 .953 r
.75496 .42934 .75821 .43341 .7656 .43206 .76237 .42798 Mtetra
.597 .749 .95 r
.76237 .42798 .7656 .43206 .773 .43049 .76977 .4264 Mtetra
.648 .77 .938 r
.76977 .4264 .773 .43049 .78035 .42817 .77715 .42406 Mtetra
.714 .795 .914 r
.77715 .42406 .78035 .42817 .78764 .42469 .78444 .42056 Mtetra
.755 .807 .894 r
.78444 .42056 .78764 .42469 .79486 .42033 .79168 .41617 Mtetra
.869 .827 .804 r
.79168 .41617 .79486 .42033 .80178 .41223 .79861 .40801 Mtetra
.907 .824 .753 r
.79861 .40801 .80178 .41223 .80848 .40177 .80533 .3975 Mtetra
.941 .813 .689 r
.80533 .3975 .80848 .40177 .81484 .38777 .81171 .38342 Mtetra
.968 .793 .614 r
.81171 .38342 .81484 .38777 .82064 .36814 .81753 .36371 Mtetra
.974 .784 .586 r
.81753 .36371 .82064 .36814 .82613 .34587 .82304 .34136 Mtetra
.93 .562 .291 r
.17977 .47271 .18377 .47616 .1876 .49248 .18359 .48903 Mtetra
.925 .545 .262 r
.18359 .48903 .1876 .49248 .19164 .50751 .18761 .50407 Mtetra
.897 .478 .153 r
.18761 .50407 .19164 .50751 .1961 .51901 .19206 .51556 Mtetra
.834 .367 0 r
.19206 .51556 .1961 .51901 .20089 .52765 .19684 .52421 Mtetra
.733 .227 0 r
.19684 .52421 .20089 .52765 .2059 .5344 .20185 .53095 Mtetra
0 .323 .778 r
.20185 .53095 .2059 .5344 .21131 .53742 .20726 .53396 Mtetra
.09 .492 .899 r
.20726 .53396 .21131 .53742 .21684 .5394 .2128 .53594 Mtetra
.363 .648 .965 r
.2128 .53594 .21684 .5394 .22253 .54001 .21848 .53654 Mtetra
.515 .715 .963 r
.21848 .53654 .22253 .54001 .22832 .53956 .22429 .53608 Mtetra
.553 .729 .957 r
.22429 .53608 .22832 .53956 .23417 .53877 .23014 .53528 Mtetra
.593 .743 .948 r
.23014 .53528 .23417 .53877 .24007 .53757 .23604 .53407 Mtetra
.605 .746 .945 r
.23604 .53407 .24007 .53757 .24599 .53623 .24197 .53273 Mtetra
.611 .748 .943 r
.24197 .53273 .24599 .53623 .25193 .53482 .24793 .53131 Mtetra
.615 .75 .941 r
.24793 .53131 .25193 .53482 .2579 .53335 .2539 .52983 Mtetra
.616 .75 .941 r
.2539 .52983 .2579 .53335 .26388 .53188 .25989 .52835 Mtetra
.25989 .52835 .26388 .53188 .26988 .53039 .26589 .52685 Mtetra
.26589 .52685 .26988 .53039 .27589 .5289 .27191 .52536 Mtetra
.27191 .52536 .27589 .5289 .28192 .5274 .27795 .52386 Mtetra
.27795 .52386 .28192 .5274 .28796 .52591 .284 .52235 Mtetra
.615 .75 .941 r
.284 .52235 .28796 .52591 .29402 .52441 .29006 .52085 Mtetra
.615 .75 .942 r
.29006 .52085 .29402 .52441 .30009 .52292 .29614 .51935 Mtetra
.29614 .51935 .30009 .52292 .30618 .52142 .30224 .51784 Mtetra
.30224 .51784 .30618 .52142 .31228 .51992 .30835 .51633 Mtetra
.614 .75 .942 r
.30835 .51633 .31228 .51992 .31841 .51842 .31448 .51483 Mtetra
.31448 .51483 .31841 .51842 .32454 .51692 .32063 .51332 Mtetra
.32063 .51332 .32454 .51692 .33069 .51542 .32679 .51181 Mtetra
.614 .749 .942 r
.32679 .51181 .33069 .51542 .33686 .51392 .33297 .5103 Mtetra
.613 .749 .942 r
.33297 .5103 .33686 .51392 .34305 .51242 .33916 .50879 Mtetra
.33916 .50879 .34305 .51242 .34925 .51092 .34537 .50729 Mtetra
.34537 .50729 .34925 .51092 .35546 .50942 .35159 .50578 Mtetra
.612 .749 .942 r
.35159 .50578 .35546 .50942 .3617 .50792 .35783 .50427 Mtetra
.612 .749 .943 r
.35783 .50427 .3617 .50792 .36795 .50642 .36409 .50276 Mtetra
.611 .749 .943 r
.36409 .50276 .36795 .50642 .37421 .50492 .37037 .50126 Mtetra
.37037 .50126 .37421 .50492 .38049 .50343 .37666 .49975 Mtetra
.61 .748 .943 r
.37666 .49975 .38049 .50343 .38679 .50193 .38296 .49825 Mtetra
.611 .749 .943 r
.38296 .49825 .38679 .50193 .39311 .50044 .38929 .49675 Mtetra
.61 .748 .943 r
.38929 .49675 .39311 .50044 .39944 .49894 .39563 .49524 Mtetra
.609 .748 .944 r
.39563 .49524 .39944 .49894 .40579 .49745 .40199 .49375 Mtetra
.40199 .49375 .40579 .49745 .41216 .49596 .40836 .49225 Mtetra
.40836 .49225 .41216 .49596 .41854 .49446 .41476 .49074 Mtetra
.608 .748 .944 r
.41476 .49074 .41854 .49446 .42494 .49298 .42116 .48925 Mtetra
.42116 .48925 .42494 .49298 .43136 .49149 .42759 .48776 Mtetra
.42759 .48776 .43136 .49149 .43779 .49 .43404 .48626 Mtetra
.606 .747 .944 r
.43404 .48626 .43779 .49 .44425 .48852 .4405 .48478 Mtetra
.606 .747 .945 r
.4405 .48478 .44425 .48852 .45072 .48705 .44698 .48329 Mtetra
.44698 .48329 .45072 .48705 .4572 .48557 .45347 .4818 Mtetra
.605 .747 .945 r
.45347 .4818 .4572 .48557 .46371 .4841 .45999 .48033 Mtetra
.604 .747 .945 r
.45999 .48033 .46371 .4841 .47023 .48263 .46652 .47885 Mtetra
.46652 .47885 .47023 .48263 .47677 .48116 .47307 .47737 Mtetra
.603 .746 .945 r
.47307 .47737 .47677 .48116 .48333 .4797 .47964 .4759 Mtetra
.602 .746 .946 r
.47964 .4759 .48333 .4797 .48991 .47824 .48623 .47444 Mtetra
.48623 .47444 .48991 .47824 .49651 .47679 .49283 .47298 Mtetra
.601 .746 .946 r
.49283 .47298 .49651 .47679 .50312 .47533 .49946 .47152 Mtetra
.6 .745 .946 r
.49946 .47152 .50312 .47533 .50975 .4739 .5061 .47007 Mtetra
.6 .746 .946 r
.5061 .47007 .50975 .4739 .51641 .47245 .51276 .46862 Mtetra
.599 .745 .947 r
.51276 .46862 .51641 .47245 .52308 .47101 .51944 .46717 Mtetra
.597 .745 .947 r
.51944 .46717 .52308 .47101 .52977 .46959 .52614 .46575 Mtetra
.52614 .46575 .52977 .46959 .53648 .46817 .53286 .46432 Mtetra
.53286 .46432 .53648 .46817 .5432 .46674 .5396 .46288 Mtetra
.594 .744 .948 r
.5396 .46288 .5432 .46674 .54995 .46535 .54636 .46148 Mtetra
.54636 .46148 .54995 .46535 .55672 .46395 .55314 .46007 Mtetra
.593 .744 .948 r
.55314 .46007 .55672 .46395 .56351 .46256 .55994 .45867 Mtetra
.592 .743 .948 r
.55994 .45867 .56351 .46256 .57031 .46117 .56675 .45728 Mtetra
.592 .743 .949 r
.56675 .45728 .57031 .46117 .57714 .45979 .57359 .45589 Mtetra
.59 .743 .949 r
.57359 .45589 .57714 .45979 .58399 .45842 .58045 .45452 Mtetra
.589 .742 .949 r
.58045 .45452 .58399 .45842 .59086 .45706 .58733 .45315 Mtetra
.58733 .45315 .59086 .45706 .59775 .45571 .59423 .45178 Mtetra
.586 .741 .95 r
.59423 .45178 .59775 .45571 .60466 .45437 .60115 .45044 Mtetra
.60115 .45044 .60466 .45437 .61159 .45304 .60809 .4491 Mtetra
.585 .741 .95 r
.60809 .4491 .61159 .45304 .61854 .45172 .61505 .44777 Mtetra
.583 .74 .951 r
.61505 .44777 .61854 .45172 .62551 .45041 .62204 .44646 Mtetra
.582 .74 .951 r
.62204 .44646 .62551 .45041 .63251 .44912 .62904 .44516 Mtetra
.581 .739 .951 r
.62904 .44516 .63251 .44912 .63952 .44783 .63607 .44386 Mtetra
.579 .739 .952 r
.63607 .44386 .63952 .44783 .64656 .44656 .64312 .44259 Mtetra
.578 .738 .952 r
.64312 .44259 .64656 .44656 .65362 .4453 .65019 .44132 Mtetra
.576 .738 .952 r
.65019 .44132 .65362 .4453 .66071 .44406 .65729 .44008 Mtetra
.575 .737 .953 r
.65729 .44008 .66071 .44406 .66781 .44284 .66441 .43884 Mtetra
.573 .737 .953 r
.66441 .43884 .66781 .44284 .67494 .44163 .67155 .43763 Mtetra
.571 .736 .953 r
.67155 .43763 .67494 .44163 .6821 .44043 .67871 .43643 Mtetra
.57 .736 .954 r
.67871 .43643 .6821 .44043 .68927 .43925 .6859 .43524 Mtetra
.567 .734 .954 r
.6859 .43524 .68927 .43925 .69648 .4381 .69312 .43408 Mtetra
.565 .734 .954 r
.69312 .43408 .69648 .4381 .7037 .43697 .70035 .43294 Mtetra
.564 .733 .955 r
.70035 .43294 .7037 .43697 .71095 .43584 .70761 .43181 Mtetra
.561 .732 .955 r
.70761 .43181 .71095 .43584 .71823 .43475 .7149 .43071 Mtetra
.56 .732 .956 r
.7149 .43071 .71823 .43475 .72552 .43367 .72221 .42963 Mtetra
.559 .731 .956 r
.72221 .42963 .72552 .43367 .73285 .4326 .72955 .42855 Mtetra
.557 .731 .956 r
.72955 .42855 .73285 .4326 .7402 .43155 .73691 .42749 Mtetra
.559 .732 .956 r
.73691 .42749 .7402 .43155 .74757 .43047 .7443 .4264 Mtetra
.563 .734 .956 r
.7443 .4264 .74757 .43047 .75496 .42934 .7517 .42527 Mtetra
.58 .742 .953 r
.7517 .42527 .75496 .42934 .76237 .42798 .75912 .4239 Mtetra
.597 .75 .95 r
.75912 .4239 .76237 .42798 .76977 .4264 .76654 .42231 Mtetra
.648 .771 .938 r
.76654 .42231 .76977 .4264 .77715 .42406 .77392 .41995 Mtetra
.715 .796 .915 r
.77392 .41995 .77715 .42406 .78444 .42056 .78123 .41642 Mtetra
.756 .808 .894 r
.78123 .41642 .78444 .42056 .79168 .41617 .78849 .412 Mtetra
.87 .827 .803 r
.78849 .412 .79168 .41617 .79861 .40801 .79543 .40379 Mtetra
.908 .824 .752 r
.79543 .40379 .79861 .40801 .80533 .3975 .80216 .39321 Mtetra
.942 .813 .688 r
.80216 .39321 .80533 .3975 .81171 .38342 .80856 .37906 Mtetra
.968 .793 .613 r
.80856 .37906 .81171 .38342 .81753 .36371 .81441 .35925 Mtetra
.974 .784 .586 r
.81441 .35925 .81753 .36371 .82304 .34136 .81994 .33681 Mtetra
.93 .562 .292 r
.17576 .46924 .17977 .47271 .18359 .48903 .17956 .48557 Mtetra
.925 .545 .262 r
.17956 .48557 .18359 .48903 .18761 .50407 .18356 .50061 Mtetra
.897 .478 .152 r
.18356 .50061 .18761 .50407 .19206 .51556 .188 .51211 Mtetra
.834 .367 0 r
.188 .51211 .19206 .51556 .19684 .52421 .19277 .52075 Mtetra
.732 .227 0 r
.19277 .52075 .19684 .52421 .20185 .53095 .19778 .52748 Mtetra
0 .323 .779 r
.19778 .52748 .20185 .53095 .20726 .53396 .20319 .53049 Mtetra
.09 .493 .899 r
.20319 .53049 .20726 .53396 .2128 .53594 .20873 .53246 Mtetra
.364 .648 .965 r
.20873 .53246 .2128 .53594 .21848 .53654 .21442 .53305 Mtetra
.515 .715 .963 r
.21442 .53305 .21848 .53654 .22429 .53608 .22023 .53258 Mtetra
.553 .729 .957 r
.22023 .53258 .22429 .53608 .23014 .53528 .22609 .53178 Mtetra
.593 .743 .948 r
.22609 .53178 .23014 .53528 .23604 .53407 .232 .53056 Mtetra
.605 .746 .945 r
.232 .53056 .23604 .53407 .24197 .53273 .23794 .52921 Mtetra
.611 .748 .943 r
.23794 .52921 .24197 .53273 .24793 .53131 .2439 .52778 Mtetra
.615 .75 .942 r
.2439 .52778 .24793 .53131 .2539 .52983 .24988 .5263 Mtetra
.616 .75 .941 r
.24988 .5263 .2539 .52983 .25989 .52835 .25588 .52481 Mtetra
.25588 .52481 .25989 .52835 .26589 .52685 .26189 .52331 Mtetra
.26189 .52331 .26589 .52685 .27191 .52536 .26792 .5218 Mtetra
.26792 .5218 .27191 .52536 .27795 .52386 .27396 .52029 Mtetra
.27396 .52029 .27795 .52386 .284 .52235 .28002 .51878 Mtetra
.615 .75 .942 r
.28002 .51878 .284 .52235 .29006 .52085 .28609 .51727 Mtetra
.28609 .51727 .29006 .52085 .29614 .51935 .29218 .51576 Mtetra
.29218 .51576 .29614 .51935 .30224 .51784 .29829 .51425 Mtetra
.29829 .51425 .30224 .51784 .30835 .51633 .30441 .51273 Mtetra
.614 .75 .942 r
.30441 .51273 .30835 .51633 .31448 .51483 .31054 .51122 Mtetra
.31054 .51122 .31448 .51483 .32063 .51332 .3167 .5097 Mtetra
.3167 .5097 .32063 .51332 .32679 .51181 .32287 .50819 Mtetra
.32287 .50819 .32679 .51181 .33297 .5103 .32905 .50667 Mtetra
.613 .749 .942 r
.32905 .50667 .33297 .5103 .33916 .50879 .33525 .50515 Mtetra
.33525 .50515 .33916 .50879 .34537 .50729 .34147 .50364 Mtetra
.34147 .50364 .34537 .50729 .35159 .50578 .3477 .50212 Mtetra
.612 .749 .943 r
.3477 .50212 .35159 .50578 .35783 .50427 .35395 .50061 Mtetra
.35395 .50061 .35783 .50427 .36409 .50276 .36022 .49909 Mtetra
.611 .749 .943 r
.36022 .49909 .36409 .50276 .37037 .50126 .3665 .49758 Mtetra
.3665 .49758 .37037 .50126 .37666 .49975 .3728 .49607 Mtetra
.61 .749 .943 r
.3728 .49607 .37666 .49975 .38296 .49825 .37912 .49456 Mtetra
.37912 .49456 .38296 .49825 .38929 .49675 .38545 .49305 Mtetra
.38545 .49305 .38929 .49675 .39563 .49524 .3918 .49153 Mtetra
.609 .748 .944 r
.3918 .49153 .39563 .49524 .40199 .49375 .39817 .49003 Mtetra
.39817 .49003 .40199 .49375 .40836 .49225 .40455 .48852 Mtetra
.40455 .48852 .40836 .49225 .41476 .49074 .41095 .48701 Mtetra
.607 .748 .944 r
.41095 .48701 .41476 .49074 .42116 .48925 .41737 .48551 Mtetra
.41737 .48551 .42116 .48925 .42759 .48776 .42381 .48401 Mtetra
.42381 .48401 .42759 .48776 .43404 .48626 .43026 .48251 Mtetra
.606 .747 .945 r
.43026 .48251 .43404 .48626 .4405 .48478 .43673 .48102 Mtetra
.43673 .48102 .4405 .48478 .44698 .48329 .44322 .47952 Mtetra
.606 .748 .945 r
.44322 .47952 .44698 .48329 .45347 .4818 .44973 .47803 Mtetra
.604 .747 .945 r
.44973 .47803 .45347 .4818 .45999 .48033 .45625 .47654 Mtetra
.45625 .47654 .45999 .48033 .46652 .47885 .46279 .47506 Mtetra
.46279 .47506 .46652 .47885 .47307 .47737 .46935 .47357 Mtetra
.603 .747 .946 r
.46935 .47357 .47307 .47737 .47964 .4759 .47593 .4721 Mtetra
.602 .746 .946 r
.47593 .4721 .47964 .4759 .48623 .47444 .48253 .47063 Mtetra
.48253 .47063 .48623 .47444 .49283 .47298 .48915 .46915 Mtetra
.601 .746 .946 r
.48915 .46915 .49283 .47298 .49946 .47152 .49578 .46769 Mtetra
.599 .746 .947 r
.49578 .46769 .49946 .47152 .5061 .47007 .50243 .46623 Mtetra
.50243 .46623 .5061 .47007 .51276 .46862 .5091 .46478 Mtetra
.5091 .46478 .51276 .46862 .51944 .46717 .5158 .46332 Mtetra
.597 .745 .947 r
.5158 .46332 .51944 .46717 .52614 .46575 .52251 .46189 Mtetra
.52251 .46189 .52614 .46575 .53286 .46432 .52924 .46045 Mtetra
.52924 .46045 .53286 .46432 .5396 .46288 .53598 .45901 Mtetra
.594 .744 .948 r
.53598 .45901 .5396 .46288 .54636 .46148 .54275 .45759 Mtetra
.54275 .45759 .54636 .46148 .55314 .46007 .54954 .45618 Mtetra
.593 .744 .948 r
.54954 .45618 .55314 .46007 .55994 .45867 .55635 .45477 Mtetra
.592 .743 .949 r
.55635 .45477 .55994 .45867 .56675 .45728 .56318 .45337 Mtetra
.591 .743 .949 r
.56318 .45337 .56675 .45728 .57359 .45589 .57003 .45198 Mtetra
.59 .743 .949 r
.57003 .45198 .57359 .45589 .58045 .45452 .57689 .4506 Mtetra
.589 .742 .949 r
.57689 .4506 .58045 .45452 .58733 .45315 .58378 .44922 Mtetra
.588 .742 .95 r
.58378 .44922 .58733 .45315 .59423 .45178 .59069 .44785 Mtetra
.586 .742 .95 r
.59069 .44785 .59423 .45178 .60115 .45044 .59763 .4465 Mtetra
.586 .741 .95 r
.59763 .4465 .60115 .45044 .60809 .4491 .60458 .44515 Mtetra
.585 .741 .951 r
.60458 .44515 .60809 .4491 .61505 .44777 .61155 .44382 Mtetra
.583 .74 .951 r
.61155 .44382 .61505 .44777 .62204 .44646 .61855 .4425 Mtetra
.582 .74 .951 r
.61855 .4425 .62204 .44646 .62904 .44516 .62556 .44119 Mtetra
.581 .74 .951 r
.62556 .44119 .62904 .44516 .63607 .44386 .6326 .43989 Mtetra
.579 .739 .952 r
.6326 .43989 .63607 .44386 .64312 .44259 .63967 .4386 Mtetra
.578 .739 .952 r
.63967 .4386 .64312 .44259 .65019 .44132 .64675 .43733 Mtetra
.576 .738 .953 r
.64675 .43733 .65019 .44132 .65729 .44008 .65386 .43608 Mtetra
.574 .737 .953 r
.65386 .43608 .65729 .44008 .66441 .43884 .66099 .43484 Mtetra
.573 .737 .953 r
.66099 .43484 .66441 .43884 .67155 .43763 .66814 .43361 Mtetra
.571 .736 .954 r
.66814 .43361 .67155 .43763 .67871 .43643 .67532 .43241 Mtetra
.57 .736 .954 r
.67532 .43241 .67871 .43643 .6859 .43524 .68252 .43121 Mtetra
.567 .735 .954 r
.68252 .43121 .6859 .43524 .69312 .43408 .68974 .43005 Mtetra
.565 .734 .955 r
.68974 .43005 .69312 .43408 .70035 .43294 .69699 .4289 Mtetra
.564 .734 .955 r
.69699 .4289 .70035 .43294 .70761 .43181 .70426 .42776 Mtetra
.561 .733 .956 r
.70426 .42776 .70761 .43181 .7149 .43071 .71156 .42666 Mtetra
.559 .732 .956 r
.71156 .42666 .7149 .43071 .72221 .42963 .71889 .42557 Mtetra
.558 .732 .956 r
.71889 .42557 .72221 .42963 .72955 .42855 .72624 .42449 Mtetra
.557 .731 .956 r
.72624 .42449 .72955 .42855 .73691 .42749 .73361 .42342 Mtetra
.559 .732 .956 r
.73361 .42342 .73691 .42749 .7443 .4264 .74101 .42233 Mtetra
.562 .734 .956 r
.74101 .42233 .7443 .4264 .7517 .42527 .74843 .42119 Mtetra
.58 .743 .953 r
.74843 .42119 .7517 .42527 .75912 .4239 .75585 .41981 Mtetra
.597 .75 .951 r
.75585 .41981 .75912 .4239 .76654 .42231 .76329 .4182 Mtetra
.649 .772 .939 r
.76329 .4182 .76654 .42231 .77392 .41995 .77069 .41583 Mtetra
.716 .797 .915 r
.77069 .41583 .77392 .41995 .78123 .41642 .77801 .41227 Mtetra
.757 .809 .894 r
.77801 .41227 .78123 .41642 .78849 .412 .78528 .40781 Mtetra
.871 .828 .803 r
.78528 .40781 .78849 .412 .79543 .40379 .79224 .39955 Mtetra
.909 .824 .751 r
.79224 .39955 .79543 .40379 .80216 .39321 .79899 .3889 Mtetra
.942 .813 .687 r
.79899 .3889 .80216 .39321 .80856 .37906 .8054 .37467 Mtetra
.968 .793 .613 r
.8054 .37467 .80856 .37906 .81441 .35925 .81127 .35477 Mtetra
.974 .783 .585 r
.81127 .35477 .81441 .35925 .81994 .33681 .81682 .33224 Mtetra
.93 .562 .292 r
.17173 .46576 .17576 .46924 .17956 .48557 .17551 .4821 Mtetra
.925 .545 .262 r
.17551 .4821 .17956 .48557 .18356 .50061 .1795 .49715 Mtetra
.897 .478 .152 r
.1795 .49715 .18356 .50061 .188 .51211 .18392 .50864 Mtetra
.834 .367 0 r
.18392 .50864 .188 .51211 .19277 .52075 .18869 .51728 Mtetra
.732 .226 0 r
.18869 .51728 .19277 .52075 .19778 .52748 .1937 .52401 Mtetra
0 .324 .78 r
.1937 .52401 .19778 .52748 .20319 .53049 .19911 .527 Mtetra
.092 .493 .9 r
.19911 .527 .20319 .53049 .20873 .53246 .20465 .52896 Mtetra
.364 .648 .965 r
.20465 .52896 .20873 .53246 .21442 .53305 .21035 .52955 Mtetra
.515 .715 .963 r
.21035 .52955 .21442 .53305 .22023 .53258 .21616 .52907 Mtetra
.553 .729 .957 r
.21616 .52907 .22023 .53258 .22609 .53178 .22203 .52825 Mtetra
.593 .743 .948 r
.22203 .52825 .22609 .53178 .232 .53056 .22794 .52703 Mtetra
.605 .746 .945 r
.22794 .52703 .232 .53056 .23794 .52921 .23389 .52567 Mtetra
.611 .748 .943 r
.23389 .52567 .23794 .52921 .2439 .52778 .23986 .52424 Mtetra
.615 .749 .941 r
.23986 .52424 .2439 .52778 .24988 .5263 .24585 .52275 Mtetra
.616 .75 .941 r
.24585 .52275 .24988 .5263 .25588 .52481 .25185 .52125 Mtetra
.25185 .52125 .25588 .52481 .26189 .52331 .25787 .51974 Mtetra
.25787 .51974 .26189 .52331 .26792 .5218 .2639 .51823 Mtetra
.2639 .51823 .26792 .5218 .27396 .52029 .26995 .51671 Mtetra
.26995 .51671 .27396 .52029 .28002 .51878 .27602 .51519 Mtetra
.615 .75 .941 r
.27602 .51519 .28002 .51878 .28609 .51727 .2821 .51368 Mtetra
.2821 .51368 .28609 .51727 .29218 .51576 .2882 .51216 Mtetra
.2882 .51216 .29218 .51576 .29829 .51425 .29431 .51063 Mtetra
.615 .75 .942 r
.29431 .51063 .29829 .51425 .30441 .51273 .30044 .50911 Mtetra
.614 .75 .942 r
.30044 .50911 .30441 .51273 .31054 .51122 .30659 .50759 Mtetra
.30659 .50759 .31054 .51122 .3167 .5097 .31275 .50607 Mtetra
.31275 .50607 .3167 .5097 .32287 .50819 .31893 .50455 Mtetra
.614 .749 .942 r
.31893 .50455 .32287 .50819 .32905 .50667 .32512 .50302 Mtetra
.613 .749 .942 r
.32512 .50302 .32905 .50667 .33525 .50515 .33133 .5015 Mtetra
.33133 .5015 .33525 .50515 .34147 .50364 .33756 .49998 Mtetra
.613 .749 .943 r
.33756 .49998 .34147 .50364 .3477 .50212 .3438 .49845 Mtetra
.612 .749 .943 r
.3438 .49845 .3477 .50212 .35395 .50061 .35006 .49693 Mtetra
.35006 .49693 .35395 .50061 .36022 .49909 .35633 .49541 Mtetra
.611 .749 .943 r
.35633 .49541 .36022 .49909 .3665 .49758 .36262 .49389 Mtetra
.36262 .49389 .3665 .49758 .3728 .49607 .36893 .49237 Mtetra
.61 .749 .943 r
.36893 .49237 .3728 .49607 .37912 .49456 .37526 .49086 Mtetra
.37526 .49086 .37912 .49456 .38545 .49305 .3816 .48934 Mtetra
.61 .749 .944 r
.3816 .48934 .38545 .49305 .3918 .49153 .38796 .48782 Mtetra
.609 .749 .944 r
.38796 .48782 .3918 .49153 .39817 .49003 .39433 .4863 Mtetra
.39433 .4863 .39817 .49003 .40455 .48852 .40073 .48479 Mtetra
.40073 .48479 .40455 .48852 .41095 .48701 .40714 .48327 Mtetra
.607 .748 .944 r
.40714 .48327 .41095 .48701 .41737 .48551 .41356 .48177 Mtetra
.41356 .48177 .41737 .48551 .42381 .48401 .42001 .48026 Mtetra
.42001 .48026 .42381 .48401 .43026 .48251 .42647 .47874 Mtetra
.606 .748 .945 r
.42647 .47874 .43026 .48251 .43673 .48102 .43295 .47724 Mtetra
.43295 .47724 .43673 .48102 .44322 .47952 .43945 .47574 Mtetra
.43945 .47574 .44322 .47952 .44973 .47803 .44596 .47424 Mtetra
.604 .747 .945 r
.44596 .47424 .44973 .47803 .45625 .47654 .4525 .47275 Mtetra
.604 .747 .946 r
.4525 .47275 .45625 .47654 .46279 .47506 .45905 .47126 Mtetra
.45905 .47126 .46279 .47506 .46935 .47357 .46562 .46976 Mtetra
.603 .747 .946 r
.46562 .46976 .46935 .47357 .47593 .4721 .47221 .46828 Mtetra
.602 .747 .946 r
.47221 .46828 .47593 .4721 .48253 .47063 .47882 .4668 Mtetra
.47882 .4668 .48253 .47063 .48915 .46915 .48544 .46532 Mtetra
.601 .747 .946 r
.48544 .46532 .48915 .46915 .49578 .46769 .49208 .46385 Mtetra
.599 .746 .947 r
.49208 .46385 .49578 .46769 .50243 .46623 .49875 .46239 Mtetra
.49875 .46239 .50243 .46623 .5091 .46478 .50543 .46092 Mtetra
.50543 .46092 .5091 .46478 .5158 .46332 .51213 .45946 Mtetra
.597 .745 .948 r
.51213 .45946 .5158 .46332 .52251 .46189 .51885 .45802 Mtetra
.51885 .45802 .52251 .46189 .52924 .46045 .52559 .45657 Mtetra
.52559 .45657 .52924 .46045 .53598 .45901 .53235 .45512 Mtetra
.594 .744 .948 r
.53235 .45512 .53598 .45901 .54275 .45759 .53913 .4537 Mtetra
.594 .744 .949 r
.53913 .4537 .54275 .45759 .54954 .45618 .54593 .45228 Mtetra
.593 .744 .949 r
.54593 .45228 .54954 .45618 .55635 .45477 .55274 .45087 Mtetra
.592 .744 .949 r
.55274 .45087 .55635 .45477 .56318 .45337 .55958 .44946 Mtetra
.591 .744 .949 r
.55958 .44946 .56318 .45337 .57003 .45198 .56644 .44806 Mtetra
.59 .743 .95 r
.56644 .44806 .57003 .45198 .57689 .4506 .57332 .44667 Mtetra
.589 .743 .95 r
.57332 .44667 .57689 .4506 .58378 .44922 .58022 .44529 Mtetra
.588 .743 .95 r
.58022 .44529 .58378 .44922 .59069 .44785 .58714 .44391 Mtetra
.586 .742 .951 r
.58714 .44391 .59069 .44785 .59763 .4465 .59409 .44255 Mtetra
.585 .742 .951 r
.59409 .44255 .59763 .4465 .60458 .44515 .60105 .4412 Mtetra
.584 .742 .951 r
.60105 .4412 .60458 .44515 .61155 .44382 .60803 .43985 Mtetra
.582 .741 .951 r
.60803 .43985 .61155 .44382 .61855 .4425 .61504 .43853 Mtetra
.581 .741 .952 r
.61504 .43853 .61855 .4425 .62556 .44119 .62207 .43721 Mtetra
.58 .74 .952 r
.62207 .43721 .62556 .44119 .6326 .43989 .62912 .4359 Mtetra
.578 .74 .952 r
.62912 .4359 .6326 .43989 .63967 .4386 .63619 .43461 Mtetra
.577 .739 .953 r
.63619 .43461 .63967 .4386 .64675 .43733 .64329 .43333 Mtetra
.576 .739 .953 r
.64329 .43333 .64675 .43733 .65386 .43608 .65041 .43207 Mtetra
.574 .738 .953 r
.65041 .43207 .65386 .43608 .66099 .43484 .65755 .43082 Mtetra
.572 .737 .954 r
.65755 .43082 .66099 .43484 .66814 .43361 .66471 .42959 Mtetra
.57 .737 .954 r
.66471 .42959 .66814 .43361 .67532 .43241 .6719 .42838 Mtetra
.569 .736 .954 r
.6719 .42838 .67532 .43241 .68252 .43121 .67911 .42718 Mtetra
.566 .735 .955 r
.67911 .42718 .68252 .43121 .68974 .43005 .68635 .42601 Mtetra
.564 .735 .955 r
.68635 .42601 .68974 .43005 .69699 .4289 .69361 .42486 Mtetra
.563 .734 .956 r
.69361 .42486 .69699 .4289 .70426 .42776 .7009 .42371 Mtetra
.56 .733 .956 r
.7009 .42371 .70426 .42776 .71156 .42666 .70821 .4226 Mtetra
.559 .733 .956 r
.70821 .4226 .71156 .42666 .71889 .42557 .71554 .42151 Mtetra
.557 .732 .957 r
.71554 .42151 .71889 .42557 .72624 .42449 .72291 .42042 Mtetra
.556 .732 .957 r
.72291 .42042 .72624 .42449 .73361 .42342 .73029 .41935 Mtetra
.558 .733 .957 r
.73029 .41935 .73361 .42342 .74101 .42233 .7377 .41825 Mtetra
.562 .735 .957 r
.7377 .41825 .74101 .42233 .74843 .42119 .74513 .4171 Mtetra
.58 .743 .954 r
.74513 .4171 .74843 .42119 .75585 .41981 .75257 .41571 Mtetra
.597 .751 .951 r
.75257 .41571 .75585 .41981 .76329 .4182 .76002 .41409 Mtetra
.649 .773 .939 r
.76002 .41409 .76329 .4182 .77069 .41583 .76743 .4117 Mtetra
.717 .797 .914 r
.76743 .4117 .77069 .41583 .77801 .41227 .77477 .40811 Mtetra
.758 .809 .893 r
.77477 .40811 .77801 .41227 .78528 .40781 .78205 .40361 Mtetra
.871 .828 .802 r
.78205 .40361 .78528 .40781 .79224 .39955 .78903 .39529 Mtetra
.909 .824 .75 r
.78903 .39529 .79224 .39955 .79899 .3889 .79579 .38457 Mtetra
.943 .813 .686 r
.79579 .38457 .79899 .3889 .8054 .37467 .80222 .37025 Mtetra
.968 .793 .612 r
.80222 .37025 .8054 .37467 .81127 .35477 .80811 .35026 Mtetra
.974 .783 .584 r
.80811 .35026 .81127 .35477 .81682 .33224 .81369 .32763 Mtetra
.93 .562 .292 r
.16768 .46228 .17173 .46576 .17551 .4821 .17144 .47863 Mtetra
.925 .545 .262 r
.17144 .47863 .17551 .4821 .1795 .49715 .17542 .49368 Mtetra
.897 .477 .153 r
.17542 .49368 .1795 .49715 .18392 .50864 .17983 .50517 Mtetra
.834 .367 0 r
.17983 .50517 .18392 .50864 .18869 .51728 .18459 .5138 Mtetra
.732 .226 0 r
.18459 .5138 .18869 .51728 .1937 .52401 .18959 .52052 Mtetra
0 .325 .779 r
.18959 .52052 .1937 .52401 .19911 .527 .19501 .52351 Mtetra
.091 .494 .9 r
.19501 .52351 .19911 .527 .20465 .52896 .20055 .52546 Mtetra
.364 .649 .965 r
.20055 .52546 .20465 .52896 .21035 .52955 .20625 .52604 Mtetra
.515 .716 .963 r
.20625 .52604 .21035 .52955 .21616 .52907 .21207 .52556 Mtetra
.553 .73 .957 r
.21207 .52556 .21616 .52907 .22203 .52825 .21794 .52473 Mtetra
.593 .743 .948 r
.21794 .52473 .22203 .52825 .22794 .52703 .22387 .5235 Mtetra
.604 .747 .945 r
.22387 .5235 .22794 .52703 .23389 .52567 .22982 .52213 Mtetra
.611 .749 .943 r
.22982 .52213 .23389 .52567 .23986 .52424 .2358 .52069 Mtetra
.615 .75 .942 r
.2358 .52069 .23986 .52424 .24585 .52275 .24179 .5192 Mtetra
.24179 .5192 .24585 .52275 .25185 .52125 .2478 .51769 Mtetra
.616 .751 .942 r
.2478 .51769 .25185 .52125 .25787 .51974 .25383 .51617 Mtetra
.25383 .51617 .25787 .51974 .2639 .51823 .25987 .51465 Mtetra
.25987 .51465 .2639 .51823 .26995 .51671 .26593 .51313 Mtetra
.26593 .51313 .26995 .51671 .27602 .51519 .27201 .5116 Mtetra
.615 .75 .942 r
.27201 .5116 .27602 .51519 .2821 .51368 .2781 .51008 Mtetra
.2781 .51008 .2821 .51368 .2882 .51216 .2842 .50855 Mtetra
.2842 .50855 .2882 .51216 .29431 .51063 .29032 .50702 Mtetra
.29032 .50702 .29431 .51063 .30044 .50911 .29646 .50549 Mtetra
.614 .75 .942 r
.29646 .50549 .30044 .50911 .30659 .50759 .30261 .50397 Mtetra
.30261 .50397 .30659 .50759 .31275 .50607 .30878 .50243 Mtetra
.30878 .50243 .31275 .50607 .31893 .50455 .31497 .5009 Mtetra
.613 .75 .943 r
.31497 .5009 .31893 .50455 .32512 .50302 .32117 .49937 Mtetra
.32117 .49937 .32512 .50302 .33133 .5015 .32739 .49784 Mtetra
.32739 .49784 .33133 .5015 .33756 .49998 .33362 .49631 Mtetra
.612 .75 .943 r
.33362 .49631 .33756 .49998 .3438 .49845 .33987 .49478 Mtetra
.33987 .49478 .3438 .49845 .35006 .49693 .34614 .49325 Mtetra
.34614 .49325 .35006 .49693 .35633 .49541 .35242 .49172 Mtetra
.611 .75 .943 r
.35242 .49172 .35633 .49541 .36262 .49389 .35872 .49019 Mtetra
.611 .749 .944 r
.35872 .49019 .36262 .49389 .36893 .49237 .36504 .48867 Mtetra
.61 .749 .944 r
.36504 .48867 .36893 .49237 .37526 .49086 .37138 .48714 Mtetra
.37138 .48714 .37526 .49086 .3816 .48934 .37773 .48562 Mtetra
.37773 .48562 .3816 .48934 .38796 .48782 .38409 .48409 Mtetra
.609 .749 .944 r
.38409 .48409 .38796 .48782 .39433 .4863 .39048 .48257 Mtetra
.39048 .48257 .39433 .4863 .40073 .48479 .39688 .48105 Mtetra
.39688 .48105 .40073 .48479 .40714 .48327 .4033 .47952 Mtetra
.607 .748 .945 r
.4033 .47952 .40714 .48327 .41356 .48177 .40974 .47801 Mtetra
.607 .749 .945 r
.40974 .47801 .41356 .48177 .42001 .48026 .41619 .47649 Mtetra
.41619 .47649 .42001 .48026 .42647 .47874 .42266 .47497 Mtetra
.606 .748 .945 r
.42266 .47497 .42647 .47874 .43295 .47724 .42915 .47346 Mtetra
.605 .748 .945 r
.42915 .47346 .43295 .47724 .43945 .47574 .43566 .47195 Mtetra
.43566 .47195 .43945 .47574 .44596 .47424 .44218 .47044 Mtetra
.604 .748 .946 r
.44218 .47044 .44596 .47424 .4525 .47275 .44873 .46894 Mtetra
.603 .748 .946 r
.44873 .46894 .4525 .47275 .45905 .47126 .45529 .46745 Mtetra
.45529 .46745 .45905 .47126 .46562 .46976 .46187 .46594 Mtetra
.602 .747 .946 r
.46187 .46594 .46562 .46976 .47221 .46828 .46847 .46445 Mtetra
.601 .747 .947 r
.46847 .46445 .47221 .46828 .47882 .4668 .47508 .46297 Mtetra
.47508 .46297 .47882 .4668 .48544 .46532 .48172 .46148 Mtetra
.48172 .46148 .48544 .46532 .49208 .46385 .48837 .46 Mtetra
.599 .746 .947 r
.48837 .46 .49208 .46385 .49875 .46239 .49504 .45853 Mtetra
.49504 .45853 .49875 .46239 .50543 .46092 .50174 .45706 Mtetra
.50174 .45706 .50543 .46092 .51213 .45946 .50845 .45559 Mtetra
.596 .746 .948 r
.50845 .45559 .51213 .45946 .51885 .45802 .51518 .45414 Mtetra
.51518 .45414 .51885 .45802 .52559 .45657 .52193 .45269 Mtetra
.52193 .45269 .52559 .45657 .53235 .45512 .5287 .45123 Mtetra
.594 .745 .949 r
.5287 .45123 .53235 .45512 .53913 .4537 .53549 .4498 Mtetra
.593 .745 .949 r
.53549 .4498 .53913 .4537 .54593 .45228 .5423 .44837 Mtetra
.5423 .44837 .54593 .45228 .55274 .45087 .54912 .44695 Mtetra
.592 .744 .949 r
.54912 .44695 .55274 .45087 .55958 .44946 .55597 .44553 Mtetra
.591 .744 .95 r
.55597 .44553 .55958 .44946 .56644 .44806 .56284 .44412 Mtetra
.589 .744 .95 r
.56284 .44412 .56644 .44806 .57332 .44667 .56973 .44273 Mtetra
.588 .743 .95 r
.56973 .44273 .57332 .44667 .58022 .44529 .57664 .44134 Mtetra
.57664 .44134 .58022 .44529 .58714 .44391 .58358 .43995 Mtetra
.586 .742 .951 r
.58358 .43995 .58714 .44391 .59409 .44255 .59053 .43859 Mtetra
.585 .742 .951 r
.59053 .43859 .59409 .44255 .60105 .4412 .5975 .43723 Mtetra
.584 .742 .951 r
.5975 .43723 .60105 .4412 .60803 .43985 .6045 .43588 Mtetra
.582 .741 .952 r
.6045 .43588 .60803 .43985 .61504 .43853 .61152 .43454 Mtetra
.581 .741 .952 r
.61152 .43454 .61504 .43853 .62207 .43721 .61856 .43322 Mtetra
.58 .741 .952 r
.61856 .43322 .62207 .43721 .62912 .4359 .62562 .43191 Mtetra
.578 .74 .953 r
.62562 .43191 .62912 .4359 .63619 .43461 .6327 .43061 Mtetra
.577 .739 .953 r
.6327 .43061 .63619 .43461 .64329 .43333 .63981 .42933 Mtetra
.575 .739 .953 r
.63981 .42933 .64329 .43333 .65041 .43207 .64694 .42806 Mtetra
.574 .738 .954 r
.64694 .42806 .65041 .43207 .65755 .43082 .65409 .4268 Mtetra
.572 .738 .954 r
.65409 .4268 .65755 .43082 .66471 .42959 .66127 .42557 Mtetra
.57 .737 .955 r
.66127 .42557 .66471 .42959 .6719 .42838 .66847 .42435 Mtetra
.569 .737 .955 r
.66847 .42435 .6719 .42838 .67911 .42718 .67569 .42314 Mtetra
.566 .736 .955 r
.67569 .42314 .67911 .42718 .68635 .42601 .68294 .42196 Mtetra
.564 .735 .956 r
.68294 .42196 .68635 .42601 .69361 .42486 .69022 .4208 Mtetra
.563 .735 .956 r
.69022 .4208 .69361 .42486 .7009 .42371 .69751 .41966 Mtetra
.56 .734 .957 r
.69751 .41966 .7009 .42371 .70821 .4226 .70484 .41854 Mtetra
.558 .733 .957 r
.70484 .41854 .70821 .4226 .71554 .42151 .71219 .41744 Mtetra
.557 .733 .957 r
.71219 .41744 .71554 .42151 .72291 .42042 .71956 .41635 Mtetra
.556 .732 .958 r
.71956 .41635 .72291 .42042 .73029 .41935 .72696 .41527 Mtetra
.557 .733 .958 r
.72696 .41527 .73029 .41935 .7377 .41825 .73438 .41416 Mtetra
.561 .735 .957 r
.73438 .41416 .7377 .41825 .74513 .4171 .74183 .413 Mtetra
.58 .744 .955 r
.74183 .413 .74513 .4171 .75257 .41571 .74928 .4116 Mtetra
.597 .752 .952 r
.74928 .4116 .75257 .41571 .76002 .41409 .75674 .40997 Mtetra
.65 .774 .939 r
.75674 .40997 .76002 .41409 .76743 .4117 .76417 .40756 Mtetra
.718 .799 .915 r
.76417 .40756 .76743 .4117 .77477 .40811 .77152 .40394 Mtetra
.76 .811 .893 r
.77152 .40394 .77477 .40811 .78205 .40361 .77881 .3994 Mtetra
.873 .828 .801 r
.77881 .3994 .78205 .40361 .78903 .39529 .7858 .39102 Mtetra
.91 .824 .749 r
.7858 .39102 .78903 .39529 .79579 .38457 .79258 .38023 Mtetra
.943 .813 .685 r
.79258 .38023 .79579 .38457 .80222 .37025 .79903 .36582 Mtetra
.968 .792 .611 r
.79903 .36582 .80222 .37025 .80811 .35026 .80494 .34572 Mtetra
.974 .783 .584 r
.80494 .34572 .80811 .35026 .81369 .32763 .81054 .32298 Mtetra
.93 .562 .292 r
.16362 .45878 .16768 .46228 .17144 .47863 .16736 .47514 Mtetra
.924 .545 .262 r
.16736 .47514 .17144 .47863 .17542 .49368 .17132 .4902 Mtetra
.897 .477 .153 r
.17132 .4902 .17542 .49368 .17983 .50517 .17572 .50169 Mtetra
.834 .366 0 r
.17572 .50169 .17983 .50517 .18459 .5138 .18047 .51032 Mtetra
.732 .225 0 r
.18047 .51032 .18459 .5138 .18959 .52052 .18547 .51703 Mtetra
0 .325 .779 r
.18547 .51703 .18959 .52052 .19501 .52351 .19088 .52001 Mtetra
.091 .494 .9 r
.19088 .52001 .19501 .52351 .20055 .52546 .19643 .52196 Mtetra
.364 .649 .965 r
.19643 .52196 .20055 .52546 .20625 .52604 .20214 .52253 Mtetra
.515 .716 .963 r
.20214 .52253 .20625 .52604 .21207 .52556 .20796 .52203 Mtetra
.553 .73 .957 r
.20796 .52203 .21207 .52556 .21794 .52473 .21384 .5212 Mtetra
.593 .744 .949 r
.21384 .5212 .21794 .52473 .22387 .5235 .21977 .51996 Mtetra
.604 .747 .945 r
.21977 .51996 .22387 .5235 .22982 .52213 .22573 .51859 Mtetra
.61 .749 .943 r
.22573 .51859 .22982 .52213 .2358 .52069 .23172 .51714 Mtetra
.615 .75 .942 r
.23172 .51714 .2358 .52069 .24179 .5192 .23772 .51563 Mtetra
.615 .751 .942 r
.23772 .51563 .24179 .5192 .2478 .51769 .24374 .51412 Mtetra
.616 .751 .942 r
.24374 .51412 .2478 .51769 .25383 .51617 .24977 .51259 Mtetra
.24977 .51259 .25383 .51617 .25987 .51465 .25583 .51107 Mtetra
.25583 .51107 .25987 .51465 .26593 .51313 .26189 .50954 Mtetra
.26189 .50954 .26593 .51313 .27201 .5116 .26797 .508 Mtetra
.615 .751 .942 r
.26797 .508 .27201 .5116 .2781 .51008 .27407 .50647 Mtetra
.27407 .50647 .2781 .51008 .2842 .50855 .28019 .50494 Mtetra
.28019 .50494 .2842 .50855 .29032 .50702 .28632 .5034 Mtetra
.614 .751 .942 r
.28632 .5034 .29032 .50702 .29646 .50549 .29246 .50186 Mtetra
.614 .751 .943 r
.29246 .50186 .29646 .50549 .30261 .50397 .29862 .50033 Mtetra
.29862 .50033 .30261 .50397 .30878 .50243 .3048 .49879 Mtetra
.3048 .49879 .30878 .50243 .31497 .5009 .31099 .49725 Mtetra
.613 .75 .943 r
.31099 .49725 .31497 .5009 .32117 .49937 .3172 .49571 Mtetra
.3172 .49571 .32117 .49937 .32739 .49784 .32343 .49417 Mtetra
.32343 .49417 .32739 .49784 .33362 .49631 .32967 .49263 Mtetra
.612 .75 .943 r
.32967 .49263 .33362 .49631 .33987 .49478 .33593 .49109 Mtetra
.33593 .49109 .33987 .49478 .34614 .49325 .34221 .48956 Mtetra
.34221 .48956 .34614 .49325 .35242 .49172 .3485 .48802 Mtetra
.611 .75 .944 r
.3485 .48802 .35242 .49172 .35872 .49019 .35481 .48648 Mtetra
.35481 .48648 .35872 .49019 .36504 .48867 .36113 .48495 Mtetra
.61 .749 .944 r
.36113 .48495 .36504 .48867 .37138 .48714 .36748 .48342 Mtetra
.61 .75 .944 r
.36748 .48342 .37138 .48714 .37773 .48562 .37384 .48188 Mtetra
.61 .749 .944 r
.37384 .48188 .37773 .48562 .38409 .48409 .38021 .48035 Mtetra
.609 .749 .944 r
.38021 .48035 .38409 .48409 .39048 .48257 .38661 .47882 Mtetra
.38661 .47882 .39048 .48257 .39688 .48105 .39302 .47729 Mtetra
.39302 .47729 .39688 .48105 .4033 .47952 .39945 .47575 Mtetra
.607 .749 .945 r
.39945 .47575 .4033 .47952 .40974 .47801 .40589 .47423 Mtetra
.40589 .47423 .40974 .47801 .41619 .47649 .41236 .47271 Mtetra
.41236 .47271 .41619 .47649 .42266 .47497 .41884 .47118 Mtetra
.605 .748 .945 r
.41884 .47118 .42266 .47497 .42915 .47346 .42534 .46967 Mtetra
.605 .748 .946 r
.42534 .46967 .42915 .47346 .43566 .47195 .43185 .46815 Mtetra
.43185 .46815 .43566 .47195 .44218 .47044 .43839 .46663 Mtetra
.604 .748 .946 r
.43839 .46663 .44218 .47044 .44873 .46894 .44494 .46512 Mtetra
.603 .748 .946 r
.44494 .46512 .44873 .46894 .45529 .46745 .45151 .46362 Mtetra
.45151 .46362 .45529 .46745 .46187 .46594 .4581 .46211 Mtetra
.602 .748 .946 r
.4581 .46211 .46187 .46594 .46847 .46445 .46471 .46061 Mtetra
.601 .747 .947 r
.46471 .46061 .46847 .46445 .47508 .46297 .47133 .45912 Mtetra
.47133 .45912 .47508 .46297 .48172 .46148 .47798 .45762 Mtetra
.6 .747 .947 r
.47798 .45762 .48172 .46148 .48837 .46 .48464 .45613 Mtetra
.599 .747 .947 r
.48464 .45613 .48837 .46 .49504 .45853 .49133 .45466 Mtetra
.599 .747 .948 r
.49133 .45466 .49504 .45853 .50174 .45706 .49803 .45318 Mtetra
.598 .747 .948 r
.49803 .45318 .50174 .45706 .50845 .45559 .50475 .4517 Mtetra
.596 .746 .948 r
.50475 .4517 .50845 .45559 .51518 .45414 .51149 .45024 Mtetra
.51149 .45024 .51518 .45414 .52193 .45269 .51825 .44879 Mtetra
.51825 .44879 .52193 .45269 .5287 .45123 .52503 .44732 Mtetra
.594 .745 .949 r
.52503 .44732 .5287 .45123 .53549 .4498 .53183 .44589 Mtetra
.593 .745 .949 r
.53183 .44589 .53549 .4498 .5423 .44837 .53865 .44445 Mtetra
.53865 .44445 .5423 .44837 .54912 .44695 .54549 .44302 Mtetra
.591 .744 .95 r
.54549 .44302 .54912 .44695 .55597 .44553 .55235 .4416 Mtetra
.55235 .4416 .55597 .44553 .56284 .44412 .55923 .44018 Mtetra
.589 .744 .95 r
.55923 .44018 .56284 .44412 .56973 .44273 .56613 .43878 Mtetra
.588 .743 .95 r
.56613 .43878 .56973 .44273 .57664 .44134 .57305 .43738 Mtetra
.588 .743 .951 r
.57305 .43738 .57664 .44134 .58358 .43995 .57999 .43599 Mtetra
.585 .743 .951 r
.57999 .43599 .58358 .43995 .59053 .43859 .58696 .43462 Mtetra
.585 .742 .951 r
.58696 .43462 .59053 .43859 .5975 .43723 .59394 .43325 Mtetra
.584 .742 .952 r
.59394 .43325 .5975 .43723 .6045 .43588 .60095 .43189 Mtetra
.582 .741 .952 r
.60095 .43189 .6045 .43588 .61152 .43454 .60798 .43055 Mtetra
.581 .741 .952 r
.60798 .43055 .61152 .43454 .61856 .43322 .61503 .42922 Mtetra
.58 .741 .953 r
.61503 .42922 .61856 .43322 .62562 .43191 .6221 .4279 Mtetra
.578 .74 .953 r
.6221 .4279 .62562 .43191 .6327 .43061 .6292 .42659 Mtetra
.576 .74 .953 r
.6292 .42659 .6327 .43061 .63981 .42933 .63632 .4253 Mtetra
.575 .739 .954 r
.63632 .4253 .63981 .42933 .64694 .42806 .64346 .42403 Mtetra
.573 .739 .954 r
.64346 .42403 .64694 .42806 .65409 .4268 .65062 .42277 Mtetra
.571 .738 .954 r
.65062 .42277 .65409 .4268 .66127 .42557 .65781 .42152 Mtetra
.57 .737 .955 r
.65781 .42152 .66127 .42557 .66847 .42435 .66502 .4203 Mtetra
.568 .737 .955 r
.66502 .4203 .66847 .42435 .67569 .42314 .67226 .41909 Mtetra
.565 .736 .956 r
.67226 .41909 .67569 .42314 .68294 .42196 .67952 .4179 Mtetra
.563 .735 .956 r
.67952 .4179 .68294 .42196 .69022 .4208 .68681 .41674 Mtetra
.562 .735 .956 r
.68681 .41674 .69022 .4208 .69751 .41966 .69412 .41559 Mtetra
.559 .734 .957 r
.69412 .41559 .69751 .41966 .70484 .41854 .70145 .41447 Mtetra
.558 .733 .957 r
.70145 .41447 .70484 .41854 .71219 .41744 .70881 .41336 Mtetra
.556 .733 .958 r
.70881 .41336 .71219 .41744 .71956 .41635 .7162 .41226 Mtetra
.555 .733 .958 r
.7162 .41226 .71956 .41635 .72696 .41527 .72361 .41118 Mtetra
.557 .734 .958 r
.72361 .41118 .72696 .41527 .73438 .41416 .73105 .41007 Mtetra
.561 .736 .958 r
.73105 .41007 .73438 .41416 .74183 .413 .73851 .4089 Mtetra
.579 .745 .955 r
.73851 .4089 .74183 .413 .74928 .4116 .74597 .40749 Mtetra
.597 .752 .952 r
.74597 .40749 .74928 .4116 .75674 .40997 .75344 .40585 Mtetra
.65 .775 .94 r
.75344 .40585 .75674 .40997 .76417 .40756 .76088 .40341 Mtetra
.719 .8 .915 r
.76088 .40341 .76417 .40756 .77152 .40394 .76825 .39976 Mtetra
.761 .811 .893 r
.76825 .39976 .77152 .40394 .77881 .3994 .77556 .39519 Mtetra
.874 .829 .8 r
.77556 .39519 .77881 .3994 .7858 .39102 .78256 .38673 Mtetra
.911 .824 .748 r
.78256 .38673 .7858 .39102 .79258 .38023 .78936 .37586 Mtetra
.944 .812 .684 r
.78936 .37586 .79258 .38023 .79903 .36582 .79583 .36136 Mtetra
.969 .792 .61 r
.79583 .36136 .79903 .36582 .80494 .34572 .80175 .34116 Mtetra
.974 .782 .583 r
.80175 .34116 .80494 .34572 .81054 .32298 .80738 .31831 Mtetra
.93 .562 .292 r
.15953 .45528 .16362 .45878 .16736 .47514 .16326 .47165 Mtetra
.924 .545 .262 r
.16326 .47165 .16736 .47514 .17132 .4902 .1672 .48671 Mtetra
.897 .477 .152 r
.1672 .48671 .17132 .4902 .17572 .50169 .17159 .4982 Mtetra
.834 .366 0 r
.17159 .4982 .17572 .50169 .18047 .51032 .17633 .50682 Mtetra
.731 .225 0 r
.17633 .50682 .18047 .51032 .18547 .51703 .18133 .51353 Mtetra
0 .327 .78 r
.18133 .51353 .18547 .51703 .19088 .52001 .18675 .5165 Mtetra
.093 .495 .901 r
.18675 .5165 .19088 .52001 .19643 .52196 .19229 .51843 Mtetra
.365 .65 .965 r
.19229 .51843 .19643 .52196 .20214 .52253 .198 .51899 Mtetra
.515 .716 .963 r
.198 .51899 .20214 .52253 .20796 .52203 .20384 .51849 Mtetra
.553 .73 .957 r
.20384 .51849 .20796 .52203 .21384 .5212 .20972 .51765 Mtetra
.593 .743 .948 r
.20972 .51765 .21384 .5212 .21977 .51996 .21566 .5164 Mtetra
.604 .747 .945 r
.21566 .5164 .21977 .51996 .22573 .51859 .22163 .51502 Mtetra
.611 .749 .943 r
.22163 .51502 .22573 .51859 .23172 .51714 .22762 .51356 Mtetra
.615 .75 .942 r
.22762 .51356 .23172 .51714 .23772 .51563 .23363 .51205 Mtetra
.23363 .51205 .23772 .51563 .24374 .51412 .23966 .51053 Mtetra
.616 .751 .942 r
.23966 .51053 .24374 .51412 .24977 .51259 .2457 .509 Mtetra
.2457 .509 .24977 .51259 .25583 .51107 .25176 .50746 Mtetra
.25176 .50746 .25583 .51107 .26189 .50954 .25783 .50592 Mtetra
.25783 .50592 .26189 .50954 .26797 .508 .26392 .50438 Mtetra
.615 .751 .942 r
.26392 .50438 .26797 .508 .27407 .50647 .27003 .50284 Mtetra
.615 .75 .942 r
.27003 .50284 .27407 .50647 .28019 .50494 .27615 .5013 Mtetra
.615 .751 .942 r
.27615 .5013 .28019 .50494 .28632 .5034 .28229 .49976 Mtetra
.614 .75 .942 r
.28229 .49976 .28632 .5034 .29246 .50186 .28844 .49821 Mtetra
.28844 .49821 .29246 .50186 .29862 .50033 .29461 .49667 Mtetra
.614 .75 .943 r
.29461 .49667 .29862 .50033 .3048 .49879 .3008 .49512 Mtetra
.3008 .49512 .3048 .49879 .31099 .49725 .307 .49358 Mtetra
.613 .75 .943 r
.307 .49358 .31099 .49725 .3172 .49571 .31322 .49203 Mtetra
.31322 .49203 .3172 .49571 .32343 .49417 .31945 .49049 Mtetra
.31945 .49049 .32343 .49417 .32967 .49263 .32571 .48894 Mtetra
.612 .75 .943 r
.32571 .48894 .32967 .49263 .33593 .49109 .33197 .48739 Mtetra
.33197 .48739 .33593 .49109 .34221 .48956 .33826 .48585 Mtetra
.611 .75 .944 r
.33826 .48585 .34221 .48956 .3485 .48802 .34456 .4843 Mtetra
.34456 .4843 .3485 .48802 .35481 .48648 .35088 .48276 Mtetra
.61 .75 .944 r
.35088 .48276 .35481 .48648 .36113 .48495 .35721 .48122 Mtetra
.35721 .48122 .36113 .48495 .36748 .48342 .36356 .47968 Mtetra
.36356 .47968 .36748 .48342 .37384 .48188 .36993 .47814 Mtetra
.36993 .47814 .37384 .48188 .38021 .48035 .37632 .47659 Mtetra
.608 .749 .945 r
.37632 .47659 .38021 .48035 .38661 .47882 .38272 .47506 Mtetra
.38272 .47506 .38661 .47882 .39302 .47729 .38914 .47352 Mtetra
.608 .75 .945 r
.38914 .47352 .39302 .47729 .39945 .47575 .39558 .47198 Mtetra
.607 .749 .945 r
.39558 .47198 .39945 .47575 .40589 .47423 .40203 .47045 Mtetra
.40203 .47045 .40589 .47423 .41236 .47271 .4085 .46892 Mtetra
.4085 .46892 .41236 .47271 .41884 .47118 .41499 .46738 Mtetra
.605 .749 .946 r
.41499 .46738 .41884 .47118 .42534 .46967 .4215 .46586 Mtetra
.4215 .46586 .42534 .46967 .43185 .46815 .42803 .46434 Mtetra
.42803 .46434 .43185 .46815 .43839 .46663 .43457 .46281 Mtetra
.604 .748 .946 r
.43457 .46281 .43839 .46663 .44494 .46512 .44113 .4613 Mtetra
.603 .748 .946 r
.44113 .4613 .44494 .46512 .45151 .46362 .44771 .45979 Mtetra
.44771 .45979 .45151 .46362 .4581 .46211 .45431 .45827 Mtetra
.602 .748 .947 r
.45431 .45827 .4581 .46211 .46471 .46061 .46093 .45676 Mtetra
.601 .748 .947 r
.46093 .45676 .46471 .46061 .47133 .45912 .46757 .45526 Mtetra
.46757 .45526 .47133 .45912 .47798 .45762 .47422 .45376 Mtetra
.6 .747 .947 r
.47422 .45376 .47798 .45762 .48464 .45613 .4809 .45226 Mtetra
.599 .747 .948 r
.4809 .45226 .48464 .45613 .49133 .45466 .48759 .45078 Mtetra
.48759 .45078 .49133 .45466 .49803 .45318 .4943 .44929 Mtetra
.598 .747 .948 r
.4943 .44929 .49803 .45318 .50475 .4517 .50103 .44781 Mtetra
.596 .746 .949 r
.50103 .44781 .50475 .4517 .51149 .45024 .50778 .44634 Mtetra
.50778 .44634 .51149 .45024 .51825 .44879 .51455 .44488 Mtetra
.51455 .44488 .51825 .44879 .52503 .44732 .52134 .44341 Mtetra
.593 .746 .949 r
.52134 .44341 .52503 .44732 .53183 .44589 .52815 .44196 Mtetra
.593 .745 .95 r
.52815 .44196 .53183 .44589 .53865 .44445 .53498 .44052 Mtetra
.592 .745 .95 r
.53498 .44052 .53865 .44445 .54549 .44302 .54183 .43908 Mtetra
.591 .745 .95 r
.54183 .43908 .54549 .44302 .55235 .4416 .5487 .43765 Mtetra
.59 .745 .95 r
.5487 .43765 .55235 .4416 .55923 .44018 .55559 .43623 Mtetra
.589 .744 .951 r
.55559 .43623 .55923 .44018 .56613 .43878 .56251 .43482 Mtetra
.588 .744 .951 r
.56251 .43482 .56613 .43878 .57305 .43738 .56944 .43341 Mtetra
.587 .744 .951 r
.56944 .43341 .57305 .43738 .57999 .43599 .57639 .43201 Mtetra
.585 .743 .952 r
.57639 .43201 .57999 .43599 .58696 .43462 .58337 .43064 Mtetra
.584 .743 .952 r
.58337 .43064 .58696 .43462 .59394 .43325 .59036 .42926 Mtetra
.583 .743 .952 r
.59036 .42926 .59394 .43325 .60095 .43189 .59738 .4279 Mtetra
.581 .742 .953 r
.59738 .4279 .60095 .43189 .60798 .43055 .60442 .42655 Mtetra
.58 .742 .953 r
.60442 .42655 .60798 .43055 .61503 .42922 .61148 .42521 Mtetra
.579 .741 .953 r
.61148 .42521 .61503 .42922 .6221 .4279 .61857 .42388 Mtetra
.577 .741 .954 r
.61857 .42388 .6221 .4279 .6292 .42659 .62568 .42258 Mtetra
.576 .74 .954 r
.62568 .42258 .6292 .42659 .63632 .4253 .63281 .42128 Mtetra
.574 .74 .954 r
.63281 .42128 .63632 .4253 .64346 .42403 .63996 .42 Mtetra
.573 .739 .955 r
.63996 .42 .64346 .42403 .65062 .42277 .64714 .41873 Mtetra
.571 .739 .955 r
.64714 .41873 .65062 .42277 .65781 .42152 .65434 .41748 Mtetra
.569 .738 .956 r
.65434 .41748 .65781 .42152 .66502 .4203 .66156 .41625 Mtetra
.568 .738 .956 r
.66156 .41625 .66502 .4203 .67226 .41909 .66881 .41503 Mtetra
.565 .737 .956 r
.66881 .41503 .67226 .41909 .67952 .4179 .67608 .41384 Mtetra
.563 .736 .957 r
.67608 .41384 .67952 .4179 .68681 .41674 .68338 .41267 Mtetra
.562 .736 .957 r
.68338 .41267 .68681 .41674 .69412 .41559 .6907 .41151 Mtetra
.559 .734 .958 r
.6907 .41151 .69412 .41559 .70145 .41447 .69805 .41039 Mtetra
.557 .734 .958 r
.69805 .41039 .70145 .41447 .70881 .41336 .70543 .40927 Mtetra
.556 .733 .958 r
.70543 .40927 .70881 .41336 .7162 .41226 .71282 .40817 Mtetra
.554 .733 .959 r
.71282 .40817 .7162 .41226 .72361 .41118 .72025 .40708 Mtetra
.556 .734 .958 r
.72025 .40708 .72361 .41118 .73105 .41007 .7277 .40596 Mtetra
.56 .736 .958 r
.7277 .40596 .73105 .41007 .73851 .4089 .73517 .40479 Mtetra
.579 .745 .955 r
.73517 .40479 .73851 .4089 .74597 .40749 .74265 .40337 Mtetra
.597 .753 .952 r
.74265 .40337 .74597 .40749 .75344 .40585 .75013 .40171 Mtetra
.651 .776 .94 r
.75013 .40171 .75344 .40585 .76088 .40341 .75758 .39925 Mtetra
.72 .8 .914 r
.75758 .39925 .76088 .40341 .76825 .39976 .76496 .39557 Mtetra
.762 .812 .892 r
.76496 .39557 .76825 .39976 .77556 .39519 .77229 .39095 Mtetra
.875 .829 .799 r
.77229 .39095 .77556 .39519 .78256 .38673 .77931 .38243 Mtetra
.912 .824 .747 r
.77931 .38243 .78256 .38673 .78936 .37586 .78612 .37148 Mtetra
.944 .812 .683 r
.78612 .37148 .78936 .37586 .79583 .36136 .7926 .35687 Mtetra
.969 .792 .609 r
.7926 .35687 .79583 .36136 .80175 .34116 .79855 .33655 Mtetra
.974 .782 .582 r
.79855 .33655 .80175 .34116 .80738 .31831 .8042 .3136 Mtetra
.93 .562 .292 r
.15543 .45177 .15953 .45528 .16326 .47165 .15914 .46815 Mtetra
.924 .545 .263 r
.15914 .46815 .16326 .47165 .1672 .48671 .16306 .48321 Mtetra
.896 .477 .152 r
.16306 .48321 .1672 .48671 .17159 .4982 .16744 .4947 Mtetra
.833 .366 0 r
.16744 .4947 .17159 .4982 .17633 .50682 .17218 .50332 Mtetra
.731 .224 0 r
.17218 .50332 .17633 .50682 .18133 .51353 .17717 .51001 Mtetra
0 .327 .781 r
.17717 .51001 .18133 .51353 .18675 .5165 .18259 .51297 Mtetra
.093 .496 .901 r
.18259 .51297 .18675 .5165 .19229 .51843 .18814 .5149 Mtetra
.365 .65 .966 r
.18814 .5149 .19229 .51843 .198 .51899 .19385 .51545 Mtetra
.515 .717 .963 r
.19385 .51545 .198 .51899 .20384 .51849 .19969 .51494 Mtetra
.553 .731 .958 r
.19969 .51494 .20384 .51849 .20972 .51765 .20559 .51409 Mtetra
.593 .744 .949 r
.20559 .51409 .20972 .51765 .21566 .5164 .21153 .51283 Mtetra
.604 .748 .946 r
.21153 .51283 .21566 .5164 .22163 .51502 .21751 .51144 Mtetra
.61 .749 .944 r
.21751 .51144 .22163 .51502 .22762 .51356 .22351 .50998 Mtetra
.615 .751 .942 r
.22351 .50998 .22762 .51356 .23363 .51205 .22952 .50846 Mtetra
.22952 .50846 .23363 .51205 .23966 .51053 .23556 .50693 Mtetra
.616 .751 .942 r
.23556 .50693 .23966 .51053 .2457 .509 .24161 .50539 Mtetra
.24161 .50539 .2457 .509 .25176 .50746 .24768 .50385 Mtetra
.24768 .50385 .25176 .50746 .25783 .50592 .25376 .5023 Mtetra
.25376 .5023 .25783 .50592 .26392 .50438 .25986 .50075 Mtetra
.615 .751 .942 r
.25986 .50075 .26392 .50438 .27003 .50284 .26597 .49921 Mtetra
.615 .751 .943 r
.26597 .49921 .27003 .50284 .27615 .5013 .2721 .49766 Mtetra
.2721 .49766 .27615 .5013 .28229 .49976 .27825 .49611 Mtetra
.614 .751 .943 r
.27825 .49611 .28229 .49976 .28844 .49821 .28441 .49456 Mtetra
.28441 .49456 .28844 .49821 .29461 .49667 .29059 .49301 Mtetra
.29059 .49301 .29461 .49667 .3008 .49512 .29678 .49145 Mtetra
.29678 .49145 .3008 .49512 .307 .49358 .30299 .4899 Mtetra
.613 .751 .943 r
.30299 .4899 .307 .49358 .31322 .49203 .30922 .48834 Mtetra
.30922 .48834 .31322 .49203 .31945 .49049 .31546 .48679 Mtetra
.31546 .48679 .31945 .49049 .32571 .48894 .32172 .48524 Mtetra
.612 .751 .944 r
.32172 .48524 .32571 .48894 .33197 .48739 .328 .48368 Mtetra
.612 .75 .944 r
.328 .48368 .33197 .48739 .33826 .48585 .33429 .48213 Mtetra
.611 .75 .944 r
.33429 .48213 .33826 .48585 .34456 .4843 .3406 .48058 Mtetra
.3406 .48058 .34456 .4843 .35088 .48276 .34692 .47903 Mtetra
.61 .75 .944 r
.34692 .47903 .35088 .48276 .35721 .48122 .35327 .47748 Mtetra
.35327 .47748 .35721 .48122 .36356 .47968 .35963 .47593 Mtetra
.35963 .47593 .36356 .47968 .36993 .47814 .36601 .47438 Mtetra
.609 .75 .945 r
.36601 .47438 .36993 .47814 .37632 .47659 .3724 .47283 Mtetra
.608 .75 .945 r
.3724 .47283 .37632 .47659 .38272 .47506 .37881 .47129 Mtetra
.37881 .47129 .38272 .47506 .38914 .47352 .38524 .46974 Mtetra
.38524 .46974 .38914 .47352 .39558 .47198 .39169 .46819 Mtetra
.607 .749 .945 r
.39169 .46819 .39558 .47198 .40203 .47045 .39815 .46666 Mtetra
.39815 .46666 .40203 .47045 .4085 .46892 .40463 .46512 Mtetra
.607 .749 .946 r
.40463 .46512 .4085 .46892 .41499 .46738 .41113 .46358 Mtetra
.605 .749 .946 r
.41113 .46358 .41499 .46738 .4215 .46586 .41765 .46205 Mtetra
.41765 .46205 .4215 .46586 .42803 .46434 .42419 .46052 Mtetra
.42419 .46052 .42803 .46434 .43457 .46281 .43074 .45898 Mtetra
.604 .749 .947 r
.43074 .45898 .43457 .46281 .44113 .4613 .43731 .45746 Mtetra
.603 .748 .947 r
.43731 .45746 .44113 .4613 .44771 .45979 .4439 .45594 Mtetra
.603 .749 .947 r
.4439 .45594 .44771 .45979 .45431 .45827 .45051 .45442 Mtetra
.602 .748 .947 r
.45051 .45442 .45431 .45827 .46093 .45676 .45714 .4529 Mtetra
.601 .748 .947 r
.45714 .4529 .46093 .45676 .46757 .45526 .46378 .45139 Mtetra
.46378 .45139 .46757 .45526 .47422 .45376 .47045 .44988 Mtetra
.6 .748 .948 r
.47045 .44988 .47422 .45376 .4809 .45226 .47713 .44838 Mtetra
.598 .747 .948 r
.47713 .44838 .4809 .45226 .48759 .45078 .48383 .44689 Mtetra
.48383 .44689 .48759 .45078 .4943 .44929 .49056 .44539 Mtetra
.49056 .44539 .4943 .44929 .50103 .44781 .4973 .4439 Mtetra
.596 .746 .949 r
.4973 .4439 .50103 .44781 .50778 .44634 .50406 .44243 Mtetra
.596 .747 .949 r
.50406 .44243 .50778 .44634 .51455 .44488 .51084 .44096 Mtetra
.595 .747 .949 r
.51084 .44096 .51455 .44488 .52134 .44341 .51764 .43948 Mtetra
.593 .746 .95 r
.51764 .43948 .52134 .44341 .52815 .44196 .52446 .43803 Mtetra
.52446 .43803 .52815 .44196 .53498 .44052 .5313 .43658 Mtetra
.592 .746 .95 r
.5313 .43658 .53498 .44052 .54183 .43908 .53816 .43513 Mtetra
.591 .745 .95 r
.53816 .43513 .54183 .43908 .5487 .43765 .54504 .43369 Mtetra
.59 .745 .951 r
.54504 .43369 .5487 .43765 .55559 .43623 .55194 .43226 Mtetra
.588 .744 .951 r
.55194 .43226 .55559 .43623 .56251 .43482 .55887 .43085 Mtetra
.55887 .43085 .56251 .43482 .56944 .43341 .56581 .42944 Mtetra
.587 .744 .951 r
.56581 .42944 .56944 .43341 .57639 .43201 .57277 .42803 Mtetra
.585 .743 .952 r
.57277 .42803 .57639 .43201 .58337 .43064 .57976 .42664 Mtetra
.584 .743 .952 r
.57976 .42664 .58337 .43064 .59036 .42926 .58677 .42526 Mtetra
.583 .743 .952 r
.58677 .42526 .59036 .42926 .59738 .4279 .5938 .42389 Mtetra
.581 .742 .953 r
.5938 .42389 .59738 .4279 .60442 .42655 .60085 .42254 Mtetra
.58 .742 .953 r
.60085 .42254 .60442 .42655 .61148 .42521 .60792 .42119 Mtetra
.579 .742 .954 r
.60792 .42119 .61148 .42521 .61857 .42388 .61502 .41986 Mtetra
.577 .741 .954 r
.61502 .41986 .61857 .42388 .62568 .42258 .62214 .41854 Mtetra
.576 .741 .954 r
.62214 .41854 .62568 .42258 .63281 .42128 .62928 .41724 Mtetra
.574 .74 .955 r
.62928 .41724 .63281 .42128 .63996 .42 .63645 .41595 Mtetra
.572 .74 .955 r
.63645 .41595 .63996 .42 .64714 .41873 .64363 .41468 Mtetra
.57 .739 .955 r
.64363 .41468 .64714 .41873 .65434 .41748 .65085 .41343 Mtetra
.569 .738 .956 r
.65085 .41343 .65434 .41748 .66156 .41625 .65808 .41219 Mtetra
.567 .738 .956 r
.65808 .41219 .66156 .41625 .66881 .41503 .66534 .41096 Mtetra
.564 .737 .957 r
.66534 .41096 .66881 .41503 .67608 .41384 .67263 .40977 Mtetra
.562 .736 .957 r
.67263 .40977 .67608 .41384 .68338 .41267 .67994 .40859 Mtetra
.561 .736 .958 r
.67994 .40859 .68338 .41267 .6907 .41151 .68727 .40743 Mtetra
.558 .735 .958 r
.68727 .40743 .6907 .41151 .69805 .41039 .69463 .4063 Mtetra
.556 .734 .958 r
.69463 .4063 .69805 .41039 .70543 .40927 .70202 .40518 Mtetra
.555 .734 .959 r
.70202 .40518 .70543 .40927 .71282 .40817 .70943 .40407 Mtetra
.554 .733 .959 r
.70943 .40407 .71282 .40817 .72025 .40708 .71687 .40298 Mtetra
.556 .735 .959 r
.71687 .40298 .72025 .40708 .7277 .40596 .72433 .40185 Mtetra
.56 .737 .959 r
.72433 .40185 .7277 .40596 .73517 .40479 .73181 .40067 Mtetra
.579 .746 .956 r
.73181 .40067 .73517 .40479 .74265 .40337 .73931 .39924 Mtetra
.597 .754 .953 r
.73931 .39924 .74265 .40337 .75013 .40171 .74681 .39757 Mtetra
.652 .777 .94 r
.74681 .39757 .75013 .40171 .75758 .39925 .75427 .39509 Mtetra
.721 .802 .914 r
.75427 .39509 .75758 .39925 .76496 .39557 .76166 .39137 Mtetra
.764 .813 .892 r
.76166 .39137 .76496 .39557 .77229 .39095 .769 .38671 Mtetra
.876 .83 .798 r
.769 .38671 .77229 .39095 .77931 .38243 .77603 .37811 Mtetra
.913 .824 .746 r
.77603 .37811 .77931 .38243 .78612 .37148 .78286 .36707 Mtetra
.945 .812 .682 r
.78286 .36707 .78612 .37148 .7926 .35687 .78936 .35236 Mtetra
.969 .791 .608 r
.78936 .35236 .7926 .35687 .79855 .33655 .79534 .33193 Mtetra
.974 .782 .582 r
.79534 .33193 .79855 .33655 .8042 .3136 .80101 .30885 Mtetra
.93 .562 .292 r
.15131 .44826 .15543 .45177 .15914 .46815 .155 .46464 Mtetra
.924 .545 .263 r
.155 .46464 .15914 .46815 .16306 .48321 .1589 .47971 Mtetra
.896 .477 .153 r
.1589 .47971 .16306 .48321 .16744 .4947 .16327 .4912 Mtetra
.833 .365 0 r
.16327 .4912 .16744 .4947 .17218 .50332 .16801 .49981 Mtetra
.73 .224 0 r
.16801 .49981 .17218 .50332 .17717 .51001 .17299 .5065 Mtetra
0 .328 .781 r
.17299 .5065 .17717 .51001 .18259 .51297 .17841 .50944 Mtetra
.093 .496 .901 r
.17841 .50944 .18259 .51297 .18814 .5149 .18397 .51136 Mtetra
.365 .651 .966 r
.18397 .51136 .18814 .5149 .19385 .51545 .18969 .5119 Mtetra
.515 .717 .964 r
.18969 .5119 .19385 .51545 .19969 .51494 .19553 .51138 Mtetra
.553 .731 .958 r
.19553 .51138 .19969 .51494 .20559 .51409 .20143 .51052 Mtetra
.592 .744 .949 r
.20143 .51052 .20559 .51409 .21153 .51283 .20738 .50926 Mtetra
.604 .748 .946 r
.20738 .50926 .21153 .51283 .21751 .51144 .21337 .50786 Mtetra
.61 .75 .944 r
.21337 .50786 .21751 .51144 .22351 .50998 .21937 .50639 Mtetra
.614 .751 .943 r
.21937 .50639 .22351 .50998 .22952 .50846 .2254 .50487 Mtetra
.615 .751 .943 r
.2254 .50487 .22952 .50846 .23556 .50693 .23144 .50333 Mtetra
.616 .752 .943 r
.23144 .50333 .23556 .50693 .24161 .50539 .2375 .50178 Mtetra
.615 .752 .943 r
.2375 .50178 .24161 .50539 .24768 .50385 .24357 .50023 Mtetra
.24357 .50023 .24768 .50385 .25376 .5023 .24966 .49868 Mtetra
.24966 .49868 .25376 .5023 .25986 .50075 .25577 .49712 Mtetra
.25577 .49712 .25986 .50075 .26597 .49921 .26189 .49557 Mtetra
.26189 .49557 .26597 .49921 .2721 .49766 .26803 .49401 Mtetra
.26803 .49401 .2721 .49766 .27825 .49611 .27418 .49245 Mtetra
.614 .751 .943 r
.27418 .49245 .27825 .49611 .28441 .49456 .28035 .49089 Mtetra
.28035 .49089 .28441 .49456 .29059 .49301 .28654 .48934 Mtetra
.28654 .48934 .29059 .49301 .29678 .49145 .29274 .48777 Mtetra
.613 .751 .943 r
.29274 .48777 .29678 .49145 .30299 .4899 .29896 .48621 Mtetra
.613 .751 .944 r
.29896 .48621 .30299 .4899 .30922 .48834 .3052 .48465 Mtetra
.3052 .48465 .30922 .48834 .31546 .48679 .31145 .48309 Mtetra
.612 .751 .944 r
.31145 .48309 .31546 .48679 .32172 .48524 .31772 .48153 Mtetra
.31772 .48153 .32172 .48524 .328 .48368 .324 .47997 Mtetra
.611 .751 .944 r
.324 .47997 .328 .48368 .33429 .48213 .3303 .4784 Mtetra
.3303 .4784 .33429 .48213 .3406 .48058 .33662 .47684 Mtetra
.33662 .47684 .3406 .48058 .34692 .47903 .34296 .47529 Mtetra
.61 .75 .945 r
.34296 .47529 .34692 .47903 .35327 .47748 .34931 .47373 Mtetra
.609 .75 .945 r
.34931 .47373 .35327 .47748 .35963 .47593 .35568 .47218 Mtetra
.61 .75 .945 r
.35568 .47218 .35963 .47593 .36601 .47438 .36206 .47062 Mtetra
.609 .75 .945 r
.36206 .47062 .36601 .47438 .3724 .47283 .36847 .46906 Mtetra
.608 .75 .945 r
.36847 .46906 .3724 .47283 .37881 .47129 .37489 .46751 Mtetra
.37489 .46751 .37881 .47129 .38524 .46974 .38132 .46595 Mtetra
.38132 .46595 .38524 .46974 .39169 .46819 .38778 .4644 Mtetra
.606 .75 .946 r
.38778 .4644 .39169 .46819 .39815 .46666 .39425 .46285 Mtetra
.39425 .46285 .39815 .46666 .40463 .46512 .40075 .46131 Mtetra
.607 .75 .946 r
.40075 .46131 .40463 .46512 .41113 .46358 .40725 .45976 Mtetra
.605 .749 .946 r
.40725 .45976 .41113 .46358 .41765 .46205 .41378 .45822 Mtetra
.41378 .45822 .41765 .46205 .42419 .46052 .42033 .45668 Mtetra
.42033 .45668 .42419 .46052 .43074 .45898 .42689 .45514 Mtetra
.603 .749 .947 r
.42689 .45514 .43074 .45898 .43731 .45746 .43347 .45361 Mtetra
.43347 .45361 .43731 .45746 .4439 .45594 .44007 .45208 Mtetra
.44007 .45208 .4439 .45594 .45051 .45442 .44669 .45055 Mtetra
.602 .748 .947 r
.44669 .45055 .45051 .45442 .45714 .4529 .45333 .44903 Mtetra
.6 .748 .948 r
.45333 .44903 .45714 .4529 .46378 .45139 .45998 .44751 Mtetra
.601 .748 .948 r
.45998 .44751 .46378 .45139 .47045 .44988 .46666 .446 Mtetra
.6 .748 .948 r
.46666 .446 .47045 .44988 .47713 .44838 .47335 .44448 Mtetra
.598 .747 .948 r
.47335 .44448 .47713 .44838 .48383 .44689 .48006 .44299 Mtetra
.598 .748 .948 r
.48006 .44299 .48383 .44689 .49056 .44539 .4868 .44148 Mtetra
.598 .748 .949 r
.4868 .44148 .49056 .44539 .4973 .4439 .49355 .43998 Mtetra
.595 .747 .949 r
.49355 .43998 .4973 .4439 .50406 .44243 .50032 .4385 Mtetra
.50032 .4385 .50406 .44243 .51084 .44096 .50711 .43702 Mtetra
.50711 .43702 .51084 .44096 .51764 .43948 .51392 .43554 Mtetra
.593 .746 .95 r
.51392 .43554 .51764 .43948 .52446 .43803 .52075 .43408 Mtetra
.592 .746 .95 r
.52075 .43408 .52446 .43803 .5313 .43658 .5276 .43262 Mtetra
.5276 .43262 .5313 .43658 .53816 .43513 .53447 .43117 Mtetra
.59 .745 .951 r
.53447 .43117 .53816 .43513 .54504 .43369 .54136 .42972 Mtetra
.54136 .42972 .54504 .43369 .55194 .43226 .54828 .42829 Mtetra
.588 .745 .951 r
.54828 .42829 .55194 .43226 .55887 .43085 .55521 .42686 Mtetra
.587 .745 .952 r
.55521 .42686 .55887 .43085 .56581 .42944 .56216 .42545 Mtetra
.587 .744 .952 r
.56216 .42545 .56581 .42944 .57277 .42803 .56914 .42403 Mtetra
.584 .744 .952 r
.56914 .42403 .57277 .42803 .57976 .42664 .57614 .42264 Mtetra
.584 .743 .953 r
.57614 .42264 .57976 .42664 .58677 .42526 .58316 .42125 Mtetra
.583 .743 .953 r
.58316 .42125 .58677 .42526 .5938 .42389 .5902 .41987 Mtetra
.581 .742 .953 r
.5902 .41987 .5938 .42389 .60085 .42254 .59726 .41851 Mtetra
.58 .742 .954 r
.59726 .41851 .60085 .42254 .60792 .42119 .60435 .41716 Mtetra
.578 .742 .954 r
.60435 .41716 .60792 .42119 .61502 .41986 .61145 .41582 Mtetra
.576 .741 .954 r
.61145 .41582 .61502 .41986 .62214 .41854 .61858 .4145 Mtetra
.575 .741 .955 r
.61858 .4145 .62214 .41854 .62928 .41724 .62574 .41319 Mtetra
.573 .74 .955 r
.62574 .41319 .62928 .41724 .63645 .41595 .63291 .4119 Mtetra
.572 .74 .955 r
.63291 .4119 .63645 .41595 .64363 .41468 .64011 .41062 Mtetra
.57 .739 .956 r
.64011 .41062 .64363 .41468 .65085 .41343 .64734 .40936 Mtetra
.568 .739 .956 r
.64734 .40936 .65085 .41343 .65808 .41219 .65459 .40811 Mtetra
.567 .738 .957 r
.65459 .40811 .65808 .41219 .66534 .41096 .66186 .40688 Mtetra
.564 .737 .957 r
.66186 .40688 .66534 .41096 .67263 .40977 .66916 .40569 Mtetra
.562 .736 .958 r
.66916 .40569 .67263 .40977 .67994 .40859 .67648 .40451 Mtetra
.56 .736 .958 r
.67648 .40451 .67994 .40859 .68727 .40743 .68383 .40334 Mtetra
.557 .735 .959 r
.68383 .40334 .68727 .40743 .69463 .4063 .6912 .4022 Mtetra
.556 .735 .959 r
.6912 .4022 .69463 .4063 .70202 .40518 .6986 .40108 Mtetra
.554 .734 .959 r
.6986 .40108 .70202 .40518 .70943 .40407 .70602 .39997 Mtetra
.553 .734 .96 r
.70602 .39997 .70943 .40407 .71687 .40298 .71347 .39886 Mtetra
.555 .735 .96 r
.71347 .39886 .71687 .40298 .72433 .40185 .72095 .39773 Mtetra
.559 .737 .959 r
.72095 .39773 .72433 .40185 .73181 .40067 .72845 .39655 Mtetra
.579 .747 .957 r
.72845 .39655 .73181 .40067 .73931 .39924 .73595 .39511 Mtetra
.597 .755 .954 r
.73595 .39511 .73931 .39924 .74681 .39757 .74346 .39342 Mtetra
.652 .778 .94 r
.74346 .39342 .74681 .39757 .75427 .39509 .75094 .39092 Mtetra
.722 .803 .914 r
.75094 .39092 .75427 .39509 .76166 .39137 .75835 .38716 Mtetra
.765 .814 .892 r
.75835 .38716 .76166 .39137 .769 .38671 .7657 .38245 Mtetra
.877 .83 .797 r
.7657 .38245 .769 .38671 .77603 .37811 .77275 .37378 Mtetra
.914 .825 .745 r
.77275 .37378 .77603 .37811 .78286 .36707 .77959 .36265 Mtetra
.946 .812 .68 r
.77959 .36265 .78286 .36707 .78936 .35236 .78611 .34783 Mtetra
.969 .791 .608 r
.78611 .34783 .78936 .35236 .79534 .33193 .7921 .32728 Mtetra
.975 .781 .581 r
.7921 .32728 .79534 .33193 .80101 .30885 .7978 .30408 Mtetra
.93 .562 .292 r
.14718 .44474 .15131 .44826 .155 .46464 .15084 .46113 Mtetra
.924 .544 .263 r
.15084 .46113 .155 .46464 .1589 .47971 .15473 .4762 Mtetra
.896 .476 .152 r
.15473 .4762 .1589 .47971 .16327 .4912 .15909 .48768 Mtetra
.833 .365 0 r
.15909 .48768 .16327 .4912 .16801 .49981 .16381 .49628 Mtetra
.73 .223 0 r
.16381 .49628 .16801 .49981 .17299 .5065 .1688 .50296 Mtetra
0 .329 .782 r
.1688 .50296 .17299 .5065 .17841 .50944 .17422 .5059 Mtetra
.094 .497 .901 r
.17422 .5059 .17841 .50944 .18397 .51136 .17977 .50781 Mtetra
.366 .651 .966 r
.17977 .50781 .18397 .51136 .18969 .5119 .1855 .50834 Mtetra
.516 .717 .964 r
.1855 .50834 .18969 .5119 .19553 .51138 .19135 .50781 Mtetra
.553 .731 .958 r
.19135 .50781 .19553 .51138 .20143 .51052 .19726 .50694 Mtetra
.592 .744 .949 r
.19726 .50694 .20143 .51052 .20738 .50926 .20322 .50567 Mtetra
.604 .748 .946 r
.20322 .50567 .20738 .50926 .21337 .50786 .20921 .50427 Mtetra
.61 .75 .944 r
.20921 .50427 .21337 .50786 .21937 .50639 .21522 .50279 Mtetra
.614 .751 .943 r
.21522 .50279 .21937 .50639 .2254 .50487 .22125 .50125 Mtetra
.615 .751 .943 r
.22125 .50125 .2254 .50487 .23144 .50333 .2273 .49971 Mtetra
.616 .751 .942 r
.2273 .49971 .23144 .50333 .2375 .50178 .23337 .49815 Mtetra
.615 .751 .943 r
.23337 .49815 .2375 .50178 .24357 .50023 .23945 .49659 Mtetra
.23945 .49659 .24357 .50023 .24966 .49868 .24555 .49503 Mtetra
.24555 .49503 .24966 .49868 .25577 .49712 .25167 .49347 Mtetra
.25167 .49347 .25577 .49712 .26189 .49557 .2578 .49191 Mtetra
.2578 .49191 .26189 .49557 .26803 .49401 .26394 .49034 Mtetra
.26394 .49034 .26803 .49401 .27418 .49245 .2701 .48878 Mtetra
.614 .751 .943 r
.2701 .48878 .27418 .49245 .28035 .49089 .27628 .48721 Mtetra
.27628 .48721 .28035 .49089 .28654 .48934 .28248 .48564 Mtetra
.28248 .48564 .28654 .48934 .29274 .48777 .28869 .48408 Mtetra
.613 .751 .943 r
.28869 .48408 .29274 .48777 .29896 .48621 .29491 .48251 Mtetra
.613 .751 .944 r
.29491 .48251 .29896 .48621 .3052 .48465 .30116 .48094 Mtetra
.30116 .48094 .3052 .48465 .31145 .48309 .30742 .47937 Mtetra
.612 .751 .944 r
.30742 .47937 .31145 .48309 .31772 .48153 .31369 .4778 Mtetra
.31369 .4778 .31772 .48153 .324 .47997 .31999 .47623 Mtetra
.611 .751 .944 r
.31999 .47623 .324 .47997 .3303 .4784 .3263 .47466 Mtetra
.3263 .47466 .3303 .4784 .33662 .47684 .33262 .47309 Mtetra
.61 .751 .945 r
.33262 .47309 .33662 .47684 .34296 .47529 .33897 .47153 Mtetra
.33897 .47153 .34296 .47529 .34931 .47373 .34533 .46997 Mtetra
.609 .75 .945 r
.34533 .46997 .34931 .47373 .35568 .47218 .35171 .46841 Mtetra
.609 .751 .945 r
.35171 .46841 .35568 .47218 .36206 .47062 .3581 .46684 Mtetra
.3581 .46684 .36206 .47062 .36847 .46906 .36451 .46527 Mtetra
.608 .75 .945 r
.36451 .46527 .36847 .46906 .37489 .46751 .37094 .46372 Mtetra
.37094 .46372 .37489 .46751 .38132 .46595 .37739 .46215 Mtetra
.608 .75 .946 r
.37739 .46215 .38132 .46595 .38778 .4644 .38386 .46059 Mtetra
.606 .75 .946 r
.38386 .46059 .38778 .4644 .39425 .46285 .39034 .45904 Mtetra
.39034 .45904 .39425 .46285 .40075 .46131 .39684 .45749 Mtetra
.39684 .45749 .40075 .46131 .40725 .45976 .40336 .45593 Mtetra
.605 .75 .947 r
.40336 .45593 .40725 .45976 .41378 .45822 .40989 .45438 Mtetra
.604 .75 .947 r
.40989 .45438 .41378 .45822 .42033 .45668 .41645 .45284 Mtetra
.41645 .45284 .42033 .45668 .42689 .45514 .42302 .45129 Mtetra
.603 .749 .947 r
.42302 .45129 .42689 .45514 .43347 .45361 .42961 .44975 Mtetra
.602 .749 .947 r
.42961 .44975 .43347 .45361 .44007 .45208 .43622 .44821 Mtetra
.603 .749 .947 r
.43622 .44821 .44007 .45208 .44669 .45055 .44285 .44668 Mtetra
.601 .749 .948 r
.44285 .44668 .44669 .45055 .45333 .44903 .4495 .44515 Mtetra
.6 .749 .948 r
.4495 .44515 .45333 .44903 .45998 .44751 .45616 .44362 Mtetra
.45616 .44362 .45998 .44751 .46666 .446 .46285 .4421 Mtetra
.599 .748 .948 r
.46285 .4421 .46666 .446 .47335 .44448 .46955 .44058 Mtetra
.598 .748 .949 r
.46955 .44058 .47335 .44448 .48006 .44299 .47627 .43907 Mtetra
.47627 .43907 .48006 .44299 .4868 .44148 .48302 .43757 Mtetra
.597 .748 .949 r
.48302 .43757 .4868 .44148 .49355 .43998 .48978 .43606 Mtetra
.595 .747 .95 r
.48978 .43606 .49355 .43998 .50032 .4385 .49656 .43457 Mtetra
.49656 .43457 .50032 .4385 .50711 .43702 .50336 .43308 Mtetra
.50336 .43308 .50711 .43702 .51392 .43554 .51018 .43159 Mtetra
.593 .747 .95 r
.51018 .43159 .51392 .43554 .52075 .43408 .51702 .43013 Mtetra
.592 .747 .951 r
.51702 .43013 .52075 .43408 .5276 .43262 .52388 .42866 Mtetra
.591 .746 .951 r
.52388 .42866 .5276 .43262 .53447 .43117 .53077 .4272 Mtetra
.59 .746 .951 r
.53077 .4272 .53447 .43117 .54136 .42972 .53767 .42575 Mtetra
.589 .746 .951 r
.53767 .42575 .54136 .42972 .54828 .42829 .54459 .42431 Mtetra
.588 .745 .952 r
.54459 .42431 .54828 .42829 .55521 .42686 .55154 .42287 Mtetra
.587 .745 .952 r
.55154 .42287 .55521 .42686 .56216 .42545 .5585 .42145 Mtetra
.586 .745 .952 r
.5585 .42145 .56216 .42545 .56914 .42403 .56549 .42003 Mtetra
.584 .744 .953 r
.56549 .42003 .56914 .42403 .57614 .42264 .5725 .41863 Mtetra
.583 .744 .953 r
.5725 .41863 .57614 .42264 .58316 .42125 .57953 .41724 Mtetra
.582 .744 .953 r
.57953 .41724 .58316 .42125 .5902 .41987 .58658 .41585 Mtetra
.58 .743 .954 r
.58658 .41585 .5902 .41987 .59726 .41851 .59365 .41449 Mtetra
.579 .743 .954 r
.59365 .41449 .59726 .41851 .60435 .41716 .60075 .41313 Mtetra
.578 .743 .955 r
.60075 .41313 .60435 .41716 .61145 .41582 .60787 .41178 Mtetra
.576 .742 .955 r
.60787 .41178 .61145 .41582 .61858 .4145 .61501 .41045 Mtetra
.575 .742 .955 r
.61501 .41045 .61858 .4145 .62574 .41319 .62218 .40914 Mtetra
.573 .741 .956 r
.62218 .40914 .62574 .41319 .63291 .4119 .62937 .40784 Mtetra
.571 .74 .956 r
.62937 .40784 .63291 .4119 .64011 .41062 .63658 .40655 Mtetra
.569 .74 .957 r
.63658 .40655 .64011 .41062 .64734 .40936 .64381 .40529 Mtetra
.567 .739 .957 r
.64381 .40529 .64734 .40936 .65459 .40811 .65107 .40404 Mtetra
.566 .739 .957 r
.65107 .40404 .65459 .40811 .66186 .40688 .65836 .4028 Mtetra
.563 .738 .958 r
.65836 .4028 .66186 .40688 .66916 .40569 .66567 .4016 Mtetra
.561 .737 .958 r
.66567 .4016 .66916 .40569 .67648 .40451 .673 .40041 Mtetra
.56 .737 .959 r
.673 .40041 .67648 .40451 .68383 .40334 .68036 .39924 Mtetra
.557 .736 .959 r
.68036 .39924 .68383 .40334 .6912 .4022 .68775 .3981 Mtetra
.555 .735 .959 r
.68775 .3981 .6912 .4022 .6986 .40108 .69516 .39697 Mtetra
.554 .735 .96 r
.69516 .39697 .6986 .40108 .70602 .39997 .7026 .39585 Mtetra
.552 .734 .96 r
.7026 .39585 .70602 .39997 .71347 .39886 .71006 .39475 Mtetra
.554 .736 .96 r
.71006 .39475 .71347 .39886 .72095 .39773 .71755 .39361 Mtetra
.559 .738 .96 r
.71755 .39361 .72095 .39773 .72845 .39655 .72506 .39242 Mtetra
.579 .747 .957 r
.72506 .39242 .72845 .39655 .73595 .39511 .73258 .39096 Mtetra
.597 .755 .954 r
.73258 .39096 .73595 .39511 .74346 .39342 .74011 .38927 Mtetra
.653 .779 .941 r
.74011 .38927 .74346 .39342 .75094 .39092 .7476 .38674 Mtetra
.724 .804 .914 r
.7476 .38674 .75094 .39092 .75835 .38716 .75502 .38294 Mtetra
.767 .815 .891 r
.75502 .38294 .75835 .38716 .7657 .38245 .76238 .37818 Mtetra
.879 .83 .795 r
.76238 .37818 .7657 .38245 .77275 .37378 .76945 .36943 Mtetra
.915 .824 .743 r
.76945 .36943 .77275 .37378 .77959 .36265 .77631 .35821 Mtetra
.946 .811 .679 r
.77631 .35821 .77959 .36265 .78611 .34783 .78284 .34327 Mtetra
.969 .791 .607 r
.78284 .34327 .78611 .34783 .7921 .32728 .78885 .32258 Mtetra
.975 .781 .58 r
.78885 .32258 .7921 .32728 .7978 .30408 .79457 .29926 Mtetra
.929 .562 .292 r
.14302 .4412 .14718 .44474 .15084 .46113 .14667 .4576 Mtetra
.924 .544 .263 r
.14667 .4576 .15084 .46113 .15473 .4762 .15054 .47267 Mtetra
.896 .476 .152 r
.15054 .47267 .15473 .4762 .15909 .48768 .15488 .48415 Mtetra
.833 .364 0 r
.15488 .48415 .15909 .48768 .16381 .49628 .1596 .49275 Mtetra
.729 .222 0 r
.1596 .49275 .16381 .49628 .1688 .50296 .16458 .49942 Mtetra
0 .33 .782 r
.16458 .49942 .1688 .50296 .17422 .5059 .17 .50235 Mtetra
.095 .498 .902 r
.17 .50235 .17422 .5059 .17977 .50781 .17556 .50424 Mtetra
.366 .652 .966 r
.17556 .50424 .17977 .50781 .1855 .50834 .18129 .50476 Mtetra
.516 .718 .964 r
.18129 .50476 .1855 .50834 .19135 .50781 .18715 .50422 Mtetra
.553 .731 .958 r
.18715 .50422 .19135 .50781 .19726 .50694 .19306 .50335 Mtetra
.592 .745 .949 r
.19306 .50335 .19726 .50694 .20322 .50567 .19903 .50207 Mtetra
.604 .748 .946 r
.19903 .50207 .20322 .50567 .20921 .50427 .20503 .50066 Mtetra
.61 .75 .944 r
.20503 .50066 .20921 .50427 .21522 .50279 .21105 .49917 Mtetra
.614 .751 .943 r
.21105 .49917 .21522 .50279 .22125 .50125 .21709 .49763 Mtetra
.615 .752 .943 r
.21709 .49763 .22125 .50125 .2273 .49971 .22315 .49608 Mtetra
.616 .752 .943 r
.22315 .49608 .2273 .49971 .23337 .49815 .22922 .49451 Mtetra
.615 .752 .943 r
.22922 .49451 .23337 .49815 .23945 .49659 .23531 .49295 Mtetra
.23531 .49295 .23945 .49659 .24555 .49503 .24142 .49138 Mtetra
.24142 .49138 .24555 .49503 .25167 .49347 .24754 .48981 Mtetra
.24754 .48981 .25167 .49347 .2578 .49191 .25368 .48824 Mtetra
.614 .752 .943 r
.25368 .48824 .2578 .49191 .26394 .49034 .25983 .48667 Mtetra
.25983 .48667 .26394 .49034 .2701 .48878 .266 .48509 Mtetra
.266 .48509 .2701 .48878 .27628 .48721 .27219 .48352 Mtetra
.613 .751 .943 r
.27219 .48352 .27628 .48721 .28248 .48564 .27839 .48194 Mtetra
.613 .752 .944 r
.27839 .48194 .28248 .48564 .28869 .48408 .28461 .48037 Mtetra
.613 .751 .944 r
.28461 .48037 .28869 .48408 .29491 .48251 .29085 .47879 Mtetra
.612 .751 .944 r
.29085 .47879 .29491 .48251 .30116 .48094 .2971 .47722 Mtetra
.2971 .47722 .30116 .48094 .30742 .47937 .30337 .47564 Mtetra
.30337 .47564 .30742 .47937 .31369 .4778 .30965 .47406 Mtetra
.30965 .47406 .31369 .4778 .31999 .47623 .31596 .47249 Mtetra
.611 .751 .944 r
.31596 .47249 .31999 .47623 .3263 .47466 .32227 .47091 Mtetra
.611 .751 .945 r
.32227 .47091 .3263 .47466 .33262 .47309 .32861 .46933 Mtetra
.61 .751 .945 r
.32861 .46933 .33262 .47309 .33897 .47153 .33496 .46776 Mtetra
.33496 .46776 .33897 .47153 .34533 .46997 .34133 .46619 Mtetra
.609 .751 .945 r
.34133 .46619 .34533 .46997 .35171 .46841 .34772 .46462 Mtetra
.34772 .46462 .35171 .46841 .3581 .46684 .35412 .46305 Mtetra
.35412 .46305 .3581 .46684 .36451 .46527 .36054 .46147 Mtetra
.608 .75 .946 r
.36054 .46147 .36451 .46527 .37094 .46372 .36698 .45991 Mtetra
.608 .751 .946 r
.36698 .45991 .37094 .46372 .37739 .46215 .37344 .45834 Mtetra
.37344 .45834 .37739 .46215 .38386 .46059 .37991 .45677 Mtetra
.606 .75 .946 r
.37991 .45677 .38386 .46059 .39034 .45904 .38641 .45521 Mtetra
.38641 .45521 .39034 .45904 .39684 .45749 .39292 .45365 Mtetra
.39292 .45365 .39684 .45749 .40336 .45593 .39944 .45208 Mtetra
.605 .75 .947 r
.39944 .45208 .40336 .45593 .40989 .45438 .40599 .45053 Mtetra
.604 .75 .947 r
.40599 .45053 .40989 .45438 .41645 .45284 .41255 .44898 Mtetra
.41255 .44898 .41645 .45284 .42302 .45129 .41914 .44742 Mtetra
.603 .749 .947 r
.41914 .44742 .42302 .45129 .42961 .44975 .42574 .44588 Mtetra
.602 .749 .948 r
.42574 .44588 .42961 .44975 .43622 .44821 .43236 .44433 Mtetra
.43236 .44433 .43622 .44821 .44285 .44668 .43899 .44279 Mtetra
.601 .749 .948 r
.43899 .44279 .44285 .44668 .4495 .44515 .44565 .44125 Mtetra
.6 .749 .948 r
.44565 .44125 .4495 .44515 .45616 .44362 .45233 .43972 Mtetra
.45233 .43972 .45616 .44362 .46285 .4421 .45902 .43819 Mtetra
.599 .749 .949 r
.45902 .43819 .46285 .4421 .46955 .44058 .46573 .43666 Mtetra
.598 .748 .949 r
.46573 .43666 .46955 .44058 .47627 .43907 .47247 .43515 Mtetra
.47247 .43515 .47627 .43907 .48302 .43757 .47922 .43363 Mtetra
.597 .748 .949 r
.47922 .43363 .48302 .43757 .48978 .43606 .48599 .43212 Mtetra
.595 .747 .95 r
.48599 .43212 .48978 .43606 .49656 .43457 .49278 .43063 Mtetra
.49278 .43063 .49656 .43457 .50336 .43308 .49959 .42913 Mtetra
.594 .748 .95 r
.49959 .42913 .50336 .43308 .51018 .43159 .50643 .42763 Mtetra
.592 .747 .951 r
.50643 .42763 .51018 .43159 .51702 .43013 .51328 .42616 Mtetra
.51328 .42616 .51702 .43013 .52388 .42866 .52015 .42469 Mtetra
.591 .747 .951 r
.52015 .42469 .52388 .42866 .53077 .4272 .52704 .42321 Mtetra
.59 .746 .951 r
.52704 .42321 .53077 .4272 .53767 .42575 .53396 .42176 Mtetra
.589 .746 .952 r
.53396 .42176 .53767 .42575 .54459 .42431 .54089 .42031 Mtetra
.587 .746 .952 r
.54089 .42031 .54459 .42431 .55154 .42287 .54785 .41887 Mtetra
.586 .745 .952 r
.54785 .41887 .55154 .42287 .5585 .42145 .55482 .41744 Mtetra
.586 .745 .953 r
.55482 .41744 .5585 .42145 .56549 .42003 .56182 .41601 Mtetra
.583 .744 .953 r
.56182 .41601 .56549 .42003 .5725 .41863 .56884 .41461 Mtetra
.56884 .41461 .5725 .41863 .57953 .41724 .57588 .41321 Mtetra
.582 .744 .954 r
.57588 .41321 .57953 .41724 .58658 .41585 .58294 .41181 Mtetra
.58 .743 .954 r
.58294 .41181 .58658 .41585 .59365 .41449 .59003 .41044 Mtetra
.579 .743 .954 r
.59003 .41044 .59365 .41449 .60075 .41313 .59714 .40908 Mtetra
.577 .743 .955 r
.59714 .40908 .60075 .41313 .60787 .41178 .60427 .40773 Mtetra
.575 .742 .955 r
.60427 .40773 .60787 .41178 .61501 .41045 .61142 .40639 Mtetra
.574 .742 .956 r
.61142 .40639 .61501 .41045 .62218 .40914 .6186 .40507 Mtetra
.572 .741 .956 r
.6186 .40507 .62218 .40914 .62937 .40784 .6258 .40376 Mtetra
.571 .741 .956 r
.6258 .40376 .62937 .40784 .63658 .40655 .63302 .40247 Mtetra
.569 .74 .957 r
.63302 .40247 .63658 .40655 .64381 .40529 .64027 .4012 Mtetra
.567 .739 .957 r
.64027 .4012 .64381 .40529 .65107 .40404 .64755 .39995 Mtetra
.565 .739 .958 r
.64755 .39995 .65107 .40404 .65836 .4028 .65484 .39871 Mtetra
.563 .738 .958 r
.65484 .39871 .65836 .4028 .66567 .4016 .66216 .3975 Mtetra
.56 .737 .959 r
.66216 .3975 .66567 .4016 .673 .40041 .66951 .39631 Mtetra
.559 .737 .959 r
.66951 .39631 .673 .40041 .68036 .39924 .67688 .39513 Mtetra
.556 .736 .96 r
.67688 .39513 .68036 .39924 .68775 .3981 .68428 .39398 Mtetra
.554 .735 .96 r
.68428 .39398 .68775 .3981 .69516 .39697 .69171 .39285 Mtetra
.553 .735 .96 r
.69171 .39285 .69516 .39697 .7026 .39585 .69916 .39173 Mtetra
.552 .735 .961 r
.69916 .39173 .7026 .39585 .71006 .39475 .70664 .39062 Mtetra
.554 .736 .96 r
.70664 .39062 .71006 .39475 .71755 .39361 .71414 .38947 Mtetra
.558 .738 .96 r
.71414 .38947 .71755 .39361 .72506 .39242 .72166 .38828 Mtetra
.579 .748 .957 r
.72166 .38828 .72506 .39242 .73258 .39096 .72919 .38681 Mtetra
.597 .756 .954 r
.72919 .38681 .73258 .39096 .74011 .38927 .73673 .3851 Mtetra
.654 .78 .941 r
.73673 .3851 .74011 .38927 .7476 .38674 .74424 .38254 Mtetra
.725 .805 .914 r
.74424 .38254 .7476 .38674 .75502 .38294 .75167 .37871 Mtetra
.768 .816 .89 r
.75167 .37871 .75502 .38294 .76238 .37818 .75905 .3739 Mtetra
.88 .831 .794 r
.75905 .3739 .76238 .37818 .76945 .36943 .76613 .36506 Mtetra
.916 .824 .742 r
.76613 .36506 .76945 .36943 .77631 .35821 .773 .35374 Mtetra
.947 .811 .678 r
.773 .35374 .77631 .35821 .78284 .34327 .77956 .33869 Mtetra
.97 .79 .605 r
.77956 .33869 .78284 .34327 .78885 .32258 .78559 .31787 Mtetra
.975 .78 .579 r
.78559 .31787 .78885 .32258 .79457 .29926 .79132 .29441 Mtetra
.929 .561 .293 r
.13885 .43767 .14302 .4412 .14667 .4576 .14247 .45407 Mtetra
.924 .544 .263 r
.14247 .45407 .14667 .4576 .15054 .47267 .14632 .46915 Mtetra
.896 .476 .152 r
.14632 .46915 .15054 .47267 .15488 .48415 .15066 .48062 Mtetra
.833 .364 0 r
.15066 .48062 .15488 .48415 .1596 .49275 .15537 .48921 Mtetra
.729 .222 0 r
.15537 .48921 .1596 .49275 .16458 .49942 .16035 .49587 Mtetra
0 .331 .782 r
.16035 .49587 .16458 .49942 .17 .50235 .16577 .49879 Mtetra
.094 .499 .902 r
.16577 .49879 .17 .50235 .17556 .50424 .17133 .50067 Mtetra
.366 .652 .966 r
.17133 .50067 .17556 .50424 .18129 .50476 .17707 .50119 Mtetra
.515 .718 .964 r
.17707 .50119 .18129 .50476 .18715 .50422 .18293 .50064 Mtetra
.553 .732 .959 r
.18293 .50064 .18715 .50422 .19306 .50335 .18885 .49975 Mtetra
.592 .745 .95 r
.18885 .49975 .19306 .50335 .19903 .50207 .19483 .49847 Mtetra
.604 .749 .947 r
.19483 .49847 .19903 .50207 .20503 .50066 .20083 .49704 Mtetra
.61 .751 .945 r
.20083 .49704 .20503 .50066 .21105 .49917 .20686 .49555 Mtetra
.614 .752 .944 r
.20686 .49555 .21105 .49917 .21709 .49763 .21291 .494 Mtetra
.615 .752 .943 r
.21291 .494 .21709 .49763 .22315 .49608 .21897 .49244 Mtetra
.615 .753 .943 r
.21897 .49244 .22315 .49608 .22922 .49451 .22506 .49087 Mtetra
.615 .752 .943 r
.22506 .49087 .22922 .49451 .23531 .49295 .23116 .4893 Mtetra
.23116 .4893 .23531 .49295 .24142 .49138 .23727 .48772 Mtetra
.615 .753 .943 r
.23727 .48772 .24142 .49138 .24754 .48981 .2434 .48614 Mtetra
.614 .752 .944 r
.2434 .48614 .24754 .48981 .25368 .48824 .24955 .48456 Mtetra
.24955 .48456 .25368 .48824 .25983 .48667 .25571 .48299 Mtetra
.25571 .48299 .25983 .48667 .266 .48509 .26189 .4814 Mtetra
.26189 .4814 .266 .48509 .27219 .48352 .26808 .47982 Mtetra
.613 .752 .944 r
.26808 .47982 .27219 .48352 .27839 .48194 .27429 .47824 Mtetra
.27429 .47824 .27839 .48194 .28461 .48037 .28052 .47666 Mtetra
.28052 .47666 .28461 .48037 .29085 .47879 .28676 .47507 Mtetra
.612 .752 .944 r
.28676 .47507 .29085 .47879 .2971 .47722 .29302 .47349 Mtetra
.612 .752 .945 r
.29302 .47349 .2971 .47722 .30337 .47564 .2993 .47191 Mtetra
.2993 .47191 .30337 .47564 .30965 .47406 .30559 .47032 Mtetra
.611 .752 .945 r
.30559 .47032 .30965 .47406 .31596 .47249 .3119 .46874 Mtetra
.3119 .46874 .31596 .47249 .32227 .47091 .31823 .46715 Mtetra
.31823 .46715 .32227 .47091 .32861 .46933 .32458 .46557 Mtetra
.61 .751 .945 r
.32458 .46557 .32861 .46933 .33496 .46776 .33094 .46399 Mtetra
.33094 .46399 .33496 .46776 .34133 .46619 .33732 .46241 Mtetra
.609 .751 .946 r
.33732 .46241 .34133 .46619 .34772 .46462 .34371 .46083 Mtetra
.34371 .46083 .34772 .46462 .35412 .46305 .35013 .45925 Mtetra
.35013 .45925 .35412 .46305 .36054 .46147 .35656 .45767 Mtetra
.608 .751 .946 r
.35656 .45767 .36054 .46147 .36698 .45991 .363 .4561 Mtetra
.363 .4561 .36698 .45991 .37344 .45834 .36947 .45452 Mtetra
.36947 .45452 .37344 .45834 .37991 .45677 .37595 .45294 Mtetra
.606 .75 .947 r
.37595 .45294 .37991 .45677 .38641 .45521 .38245 .45137 Mtetra
.606 .751 .947 r
.38245 .45137 .38641 .45521 .39292 .45365 .38897 .4498 Mtetra
.38897 .4498 .39292 .45365 .39944 .45208 .39551 .44823 Mtetra
.604 .75 .947 r
.39551 .44823 .39944 .45208 .40599 .45053 .40207 .44667 Mtetra
.40207 .44667 .40599 .45053 .41255 .44898 .40864 .44511 Mtetra
.40864 .44511 .41255 .44898 .41914 .44742 .41523 .44355 Mtetra
.603 .75 .948 r
.41523 .44355 .41914 .44742 .42574 .44588 .42184 .44199 Mtetra
.602 .75 .948 r
.42184 .44199 .42574 .44588 .43236 .44433 .42847 .44044 Mtetra
.42847 .44044 .43236 .44433 .43899 .44279 .43512 .43889 Mtetra
.601 .749 .948 r
.43512 .43889 .43899 .44279 .44565 .44125 .44178 .43734 Mtetra
.6 .749 .949 r
.44178 .43734 .44565 .44125 .45233 .43972 .44847 .43581 Mtetra
.44847 .43581 .45233 .43972 .45902 .43819 .45517 .43427 Mtetra
.599 .749 .949 r
.45517 .43427 .45902 .43819 .46573 .43666 .4619 .43273 Mtetra
.597 .749 .949 r
.4619 .43273 .46573 .43666 .47247 .43515 .46864 .43121 Mtetra
.597 .749 .95 r
.46864 .43121 .47247 .43515 .47922 .43363 .4754 .42969 Mtetra
.4754 .42969 .47922 .43363 .48599 .43212 .48219 .42817 Mtetra
.595 .748 .95 r
.48219 .42817 .48599 .43212 .49278 .43063 .48899 .42667 Mtetra
.594 .748 .95 r
.48899 .42667 .49278 .43063 .49959 .42913 .49581 .42517 Mtetra
.594 .748 .951 r
.49581 .42517 .49959 .42913 .50643 .42763 .50265 .42366 Mtetra
.592 .747 .951 r
.50265 .42366 .50643 .42763 .51328 .42616 .50952 .42218 Mtetra
.50952 .42218 .51328 .42616 .52015 .42469 .5164 .4207 Mtetra
.591 .747 .951 r
.5164 .4207 .52015 .42469 .52704 .42321 .5233 .41922 Mtetra
.589 .746 .952 r
.5233 .41922 .52704 .42321 .53396 .42176 .53023 .41776 Mtetra
.588 .746 .952 r
.53023 .41776 .53396 .42176 .54089 .42031 .53717 .4163 Mtetra
.587 .746 .952 r
.53717 .4163 .54089 .42031 .54785 .41887 .54414 .41486 Mtetra
.586 .746 .953 r
.54414 .41486 .54785 .41887 .55482 .41744 .55113 .41342 Mtetra
.585 .746 .953 r
.55113 .41342 .55482 .41744 .56182 .41601 .55813 .41199 Mtetra
.583 .745 .954 r
.55813 .41199 .56182 .41601 .56884 .41461 .56517 .41058 Mtetra
.582 .745 .954 r
.56517 .41058 .56884 .41461 .57588 .41321 .57222 .40917 Mtetra
.581 .744 .954 r
.57222 .40917 .57588 .41321 .58294 .41181 .57929 .40777 Mtetra
.579 .744 .955 r
.57929 .40777 .58294 .41181 .59003 .41044 .58639 .40639 Mtetra
.578 .743 .955 r
.58639 .40639 .59003 .41044 .59714 .40908 .59351 .40502 Mtetra
.577 .743 .955 r
.59351 .40502 .59714 .40908 .60427 .40773 .60065 .40366 Mtetra
.575 .742 .956 r
.60065 .40366 .60427 .40773 .61142 .40639 .60782 .40232 Mtetra
.574 .742 .956 r
.60782 .40232 .61142 .40639 .6186 .40507 .61501 .40099 Mtetra
.572 .741 .956 r
.61501 .40099 .6186 .40507 .6258 .40376 .62222 .39968 Mtetra
.57 .741 .957 r
.62222 .39968 .6258 .40376 .63302 .40247 .62945 .39839 Mtetra
.568 .74 .957 r
.62945 .39839 .63302 .40247 .64027 .4012 .63672 .39711 Mtetra
.566 .74 .958 r
.63672 .39711 .64027 .4012 .64755 .39995 .644 .39585 Mtetra
.565 .739 .958 r
.644 .39585 .64755 .39995 .65484 .39871 .65131 .39461 Mtetra
.562 .738 .959 r
.65131 .39461 .65484 .39871 .66216 .3975 .65864 .39339 Mtetra
.56 .738 .959 r
.65864 .39339 .66216 .3975 .66951 .39631 .666 .3922 Mtetra
.558 .737 .96 r
.666 .3922 .66951 .39631 .67688 .39513 .67339 .39101 Mtetra
.555 .736 .96 r
.67339 .39101 .67688 .39513 .68428 .39398 .6808 .38986 Mtetra
.554 .736 .961 r
.6808 .38986 .68428 .39398 .69171 .39285 .68824 .38873 Mtetra
.552 .736 .961 r
.68824 .38873 .69171 .39285 .69916 .39173 .6957 .3876 Mtetra
.551 .735 .961 r
.6957 .3876 .69916 .39173 .70664 .39062 .70319 .38649 Mtetra
.553 .737 .961 r
.70319 .38649 .70664 .39062 .71414 .38947 .71071 .38534 Mtetra
.557 .739 .961 r
.71071 .38534 .71414 .38947 .72166 .38828 .71824 .38413 Mtetra
.578 .749 .958 r
.71824 .38413 .72166 .38828 .72919 .38681 .72579 .38266 Mtetra
.597 .757 .955 r
.72579 .38266 .72919 .38681 .73673 .3851 .73334 .38093 Mtetra
.655 .781 .941 r
.73334 .38093 .73673 .3851 .74424 .38254 .74086 .37835 Mtetra
.727 .806 .914 r
.74086 .37835 .74424 .38254 .75167 .37871 .74831 .37447 Mtetra
.77 .817 .89 r
.74831 .37447 .75167 .37871 .75905 .3739 .7557 .36961 Mtetra
.882 .831 .793 r
.7557 .36961 .75905 .3739 .76613 .36506 .76279 .36069 Mtetra
.917 .825 .74 r
.76279 .36069 .76613 .36506 .773 .35374 .76969 .34926 Mtetra
.947 .811 .676 r
.76969 .34926 .773 .35374 .77956 .33869 .77625 .33408 Mtetra
.97 .79 .604 r
.77625 .33408 .77956 .33869 .78559 .31787 .78231 .31312 Mtetra
.975 .78 .578 r
.78231 .31312 .78559 .31787 .79132 .29441 .78807 .28953 Mtetra
.929 .561 .293 r
.13465 .43412 .13885 .43767 .14247 .45407 .13826 .45053 Mtetra
.924 .544 .263 r
.13826 .45053 .14247 .45407 .14632 .46915 .14209 .46561 Mtetra
.896 .475 .152 r
.14209 .46561 .14632 .46915 .15066 .48062 .14642 .47708 Mtetra
.832 .363 0 r
.14642 .47708 .15066 .48062 .15537 .48921 .15112 .48566 Mtetra
.728 .221 0 r
.15112 .48566 .15537 .48921 .16035 .49587 .15609 .49231 Mtetra
0 .332 .784 r
.15609 .49231 .16035 .49587 .16577 .49879 .16152 .49522 Mtetra
.096 .5 .902 r
.16152 .49522 .16577 .49879 .17133 .50067 .16709 .49709 Mtetra
.366 .653 .966 r
.16709 .49709 .17133 .50067 .17707 .50119 .17282 .49759 Mtetra
.516 .718 .964 r
.17282 .49759 .17707 .50119 .18293 .50064 .1787 .49703 Mtetra
.553 .732 .958 r
.1787 .49703 .18293 .50064 .18885 .49975 .18462 .49614 Mtetra
.592 .745 .95 r
.18462 .49614 .18885 .49975 .19483 .49847 .1906 .49484 Mtetra
.604 .749 .946 r
.1906 .49484 .19483 .49847 .20083 .49704 .19662 .49341 Mtetra
.61 .751 .945 r
.19662 .49341 .20083 .49704 .20686 .49555 .20265 .49191 Mtetra
.614 .752 .943 r
.20265 .49191 .20686 .49555 .21291 .494 .20871 .49036 Mtetra
.615 .752 .943 r
.20871 .49036 .21291 .494 .21897 .49244 .21478 .48879 Mtetra
.21478 .48879 .21897 .49244 .22506 .49087 .22087 .48721 Mtetra
.22087 .48721 .22506 .49087 .23116 .4893 .22698 .48563 Mtetra
.22698 .48563 .23116 .4893 .23727 .48772 .2331 .48405 Mtetra
.2331 .48405 .23727 .48772 .2434 .48614 .23924 .48246 Mtetra
.614 .752 .944 r
.23924 .48246 .2434 .48614 .24955 .48456 .24539 .48087 Mtetra
.24539 .48087 .24955 .48456 .25571 .48299 .25156 .47929 Mtetra
.25156 .47929 .25571 .48299 .26189 .4814 .25775 .4777 Mtetra
.25775 .4777 .26189 .4814 .26808 .47982 .26395 .47611 Mtetra
.613 .752 .944 r
.26395 .47611 .26808 .47982 .27429 .47824 .27017 .47452 Mtetra
.27017 .47452 .27429 .47824 .28052 .47666 .27641 .47293 Mtetra
.27641 .47293 .28052 .47666 .28676 .47507 .28266 .47133 Mtetra
.612 .752 .944 r
.28266 .47133 .28676 .47507 .29302 .47349 .28893 .46975 Mtetra
.28893 .46975 .29302 .47349 .2993 .47191 .29521 .46815 Mtetra
.612 .752 .945 r
.29521 .46815 .2993 .47191 .30559 .47032 .30152 .46656 Mtetra
.611 .752 .945 r
.30152 .46656 .30559 .47032 .3119 .46874 .30784 .46497 Mtetra
.30784 .46497 .3119 .46874 .31823 .46715 .31417 .46338 Mtetra
.31417 .46338 .31823 .46715 .32458 .46557 .32053 .46179 Mtetra
.61 .752 .945 r
.32053 .46179 .32458 .46557 .33094 .46399 .3269 .4602 Mtetra
.609 .752 .945 r
.3269 .4602 .33094 .46399 .33732 .46241 .33328 .45861 Mtetra
.609 .751 .946 r
.33328 .45861 .33732 .46241 .34371 .46083 .33969 .45703 Mtetra
.33969 .45703 .34371 .46083 .35013 .45925 .34611 .45544 Mtetra
.34611 .45544 .35013 .45925 .35656 .45767 .35255 .45385 Mtetra
.607 .751 .946 r
.35255 .45385 .35656 .45767 .363 .4561 .35901 .45227 Mtetra
.35901 .45227 .363 .4561 .36947 .45452 .36548 .45069 Mtetra
.36548 .45069 .36947 .45452 .37595 .45294 .37197 .4491 Mtetra
.606 .751 .947 r
.37197 .4491 .37595 .45294 .38245 .45137 .37848 .44753 Mtetra
.37848 .44753 .38245 .45137 .38897 .4498 .38501 .44595 Mtetra
.38501 .44595 .38897 .4498 .39551 .44823 .39156 .44437 Mtetra
.604 .75 .947 r
.39156 .44437 .39551 .44823 .40207 .44667 .39812 .4428 Mtetra
.604 .75 .948 r
.39812 .4428 .40207 .44667 .40864 .44511 .40471 .44123 Mtetra
.604 .751 .948 r
.40471 .44123 .40864 .44511 .41523 .44355 .41131 .43966 Mtetra
.602 .75 .948 r
.41131 .43966 .41523 .44355 .42184 .44199 .41793 .4381 Mtetra
.41793 .4381 .42184 .44199 .42847 .44044 .42457 .43654 Mtetra
.42457 .43654 .42847 .44044 .43512 .43889 .43122 .43498 Mtetra
.601 .75 .949 r
.43122 .43498 .43512 .43889 .44178 .43734 .4379 .43343 Mtetra
.599 .749 .949 r
.4379 .43343 .44178 .43734 .44847 .43581 .4446 .43189 Mtetra
.6 .75 .949 r
.4446 .43189 .44847 .43581 .45517 .43427 .45131 .43034 Mtetra
.599 .749 .949 r
.45131 .43034 .45517 .43427 .4619 .43273 .45805 .4288 Mtetra
.597 .749 .95 r
.45805 .4288 .4619 .43273 .46864 .43121 .4648 .42727 Mtetra
.4648 .42727 .46864 .43121 .4754 .42969 .47157 .42574 Mtetra
.47157 .42574 .4754 .42969 .48219 .42817 .47836 .42421 Mtetra
.594 .748 .951 r
.47836 .42421 .48219 .42817 .48899 .42667 .48518 .4227 Mtetra
.48518 .4227 .48899 .42667 .49581 .42517 .49201 .42119 Mtetra
.49201 .42119 .49581 .42517 .50265 .42366 .49886 .41968 Mtetra
.592 .748 .951 r
.49886 .41968 .50265 .42366 .50952 .42218 .50574 .41819 Mtetra
.591 .748 .952 r
.50574 .41819 .50952 .42218 .5164 .4207 .51263 .41671 Mtetra
.591 .747 .952 r
.51263 .41671 .5164 .4207 .5233 .41922 .51954 .41522 Mtetra
.589 .747 .952 r
.51954 .41522 .5233 .41922 .53023 .41776 .52648 .41375 Mtetra
.588 .747 .953 r
.52648 .41375 .53023 .41776 .53717 .4163 .53343 .41229 Mtetra
.587 .746 .953 r
.53343 .41229 .53717 .4163 .54414 .41486 .54041 .41084 Mtetra
.586 .746 .953 r
.54041 .41084 .54414 .41486 .55113 .41342 .54741 .40939 Mtetra
.585 .746 .954 r
.54741 .40939 .55113 .41342 .55813 .41199 .55443 .40795 Mtetra
.583 .745 .954 r
.55443 .40795 .55813 .41199 .56517 .41058 .56147 .40654 Mtetra
.582 .745 .954 r
.56147 .40654 .56517 .41058 .57222 .40917 .56854 .40512 Mtetra
.581 .745 .955 r
.56854 .40512 .57222 .40917 .57929 .40777 .57562 .40372 Mtetra
.579 .744 .955 r
.57562 .40372 .57929 .40777 .58639 .40639 .58273 .40233 Mtetra
.578 .744 .955 r
.58273 .40233 .58639 .40639 .59351 .40502 .58986 .40096 Mtetra
.576 .744 .956 r
.58986 .40096 .59351 .40502 .60065 .40366 .59702 .39959 Mtetra
.574 .743 .956 r
.59702 .39959 .60065 .40366 .60782 .40232 .60419 .39825 Mtetra
.573 .743 .957 r
.60419 .39825 .60782 .40232 .61501 .40099 .6114 .39691 Mtetra
.571 .742 .957 r
.6114 .39691 .61501 .40099 .62222 .39968 .61862 .3956 Mtetra
.569 .742 .957 r
.61862 .3956 .62222 .39968 .62945 .39839 .62587 .3943 Mtetra
.567 .741 .958 r
.62587 .3943 .62945 .39839 .63672 .39711 .63314 .39301 Mtetra
.565 .74 .958 r
.63314 .39301 .63672 .39711 .644 .39585 .64044 .39175 Mtetra
.564 .74 .959 r
.64044 .39175 .644 .39585 .65131 .39461 .64776 .3905 Mtetra
.561 .739 .959 r
.64776 .3905 .65131 .39461 .65864 .39339 .65511 .38928 Mtetra
.559 .738 .96 r
.65511 .38928 .65864 .39339 .666 .3922 .66248 .38808 Mtetra
.558 .738 .96 r
.66248 .38808 .666 .3922 .67339 .39101 .66988 .38689 Mtetra
.554 .737 .961 r
.66988 .38689 .67339 .39101 .6808 .38986 .6773 .38574 Mtetra
.553 .736 .961 r
.6773 .38574 .6808 .38986 .68824 .38873 .68475 .38459 Mtetra
.551 .736 .961 r
.68475 .38459 .68824 .38873 .6957 .3876 .69223 .38347 Mtetra
.55 .736 .962 r
.69223 .38347 .6957 .3876 .70319 .38649 .69973 .38235 Mtetra
.552 .737 .962 r
.69973 .38235 .70319 .38649 .71071 .38534 .70726 .3812 Mtetra
.557 .739 .961 r
.70726 .3812 .71071 .38534 .71824 .38413 .71481 .37998 Mtetra
.578 .749 .959 r
.71481 .37998 .71824 .38413 .72579 .38266 .72237 .3785 Mtetra
.597 .758 .955 r
.72237 .3785 .72579 .38266 .73334 .38093 .72993 .37675 Mtetra
.656 .782 .941 r
.72993 .37675 .73334 .38093 .74086 .37835 .73747 .37414 Mtetra
.728 .807 .913 r
.73747 .37414 .74086 .37835 .74831 .37447 .74493 .37022 Mtetra
.772 .818 .889 r
.74493 .37022 .74831 .37447 .7557 .36961 .75233 .36531 Mtetra
.883 .831 .791 r
.75233 .36531 .7557 .36961 .76279 .36069 .75944 .35629 Mtetra
.918 .825 .739 r
.75944 .35629 .76279 .36069 .76969 .34926 .76635 .34476 Mtetra
.948 .811 .675 r
.76635 .34476 .76969 .34926 .77625 .33408 .77294 .32944 Mtetra
.97 .789 .603 r
.77294 .32944 .77625 .33408 .78231 .31312 .77901 .30834 Mtetra
.975 .779 .578 r
.77901 .30834 .78231 .31312 .78807 .28953 .78479 .2846 Mtetra
.929 .561 .293 r
.13044 .43056 .13465 .43412 .13826 .45053 .13403 .44698 Mtetra
.924 .544 .263 r
.13403 .44698 .13826 .45053 .14209 .46561 .13784 .46206 Mtetra
.896 .475 .152 r
.13784 .46206 .14209 .46561 .14642 .47708 .14215 .47352 Mtetra
.832 .363 0 r
.14215 .47352 .14642 .47708 .15112 .48566 .14685 .48209 Mtetra
.728 .22 0 r
.14685 .48209 .15112 .48566 .15609 .49231 .15182 .48874 Mtetra
0 .334 .785 r
.15182 .48874 .15609 .49231 .16152 .49522 .15725 .49163 Mtetra
.097 .501 .903 r
.15725 .49163 .16152 .49522 .16709 .49709 .16282 .49349 Mtetra
.367 .653 .967 r
.16282 .49349 .16709 .49709 .17282 .49759 .16856 .49398 Mtetra
.516 .719 .964 r
.16856 .49398 .17282 .49759 .1787 .49703 .17444 .49341 Mtetra
.553 .732 .958 r
.17444 .49341 .1787 .49703 .18462 .49614 .18037 .49251 Mtetra
.592 .745 .95 r
.18037 .49251 .18462 .49614 .1906 .49484 .18636 .49121 Mtetra
.604 .749 .947 r
.18636 .49121 .1906 .49484 .19662 .49341 .19238 .48977 Mtetra
.61 .751 .945 r
.19238 .48977 .19662 .49341 .20265 .49191 .19843 .48826 Mtetra
.614 .752 .944 r
.19843 .48826 .20265 .49191 .20871 .49036 .20449 .4867 Mtetra
.615 .752 .943 r
.20449 .4867 .20871 .49036 .21478 .48879 .21057 .48512 Mtetra
.21057 .48512 .21478 .48879 .22087 .48721 .21667 .48353 Mtetra
.21667 .48353 .22087 .48721 .22698 .48563 .22278 .48195 Mtetra
.22278 .48195 .22698 .48563 .2331 .48405 .22891 .48036 Mtetra
.22891 .48036 .2331 .48405 .23924 .48246 .23506 .47876 Mtetra
.614 .752 .944 r
.23506 .47876 .23924 .48246 .24539 .48087 .24122 .47717 Mtetra
.24122 .47717 .24539 .48087 .25156 .47929 .2474 .47557 Mtetra
.2474 .47557 .25156 .47929 .25775 .4777 .25359 .47397 Mtetra
.25359 .47397 .25775 .4777 .26395 .47611 .25981 .47238 Mtetra
.613 .752 .944 r
.25981 .47238 .26395 .47611 .27017 .47452 .26603 .47078 Mtetra
.26603 .47078 .27017 .47452 .27641 .47293 .27228 .46918 Mtetra
.27228 .46918 .27641 .47293 .28266 .47133 .27854 .46758 Mtetra
.612 .752 .945 r
.27854 .46758 .28266 .47133 .28893 .46975 .28482 .46599 Mtetra
.28482 .46599 .28893 .46975 .29521 .46815 .29111 .46439 Mtetra
.29111 .46439 .29521 .46815 .30152 .46656 .29742 .46279 Mtetra
.611 .752 .945 r
.29742 .46279 .30152 .46656 .30784 .46497 .30375 .46119 Mtetra
.30375 .46119 .30784 .46497 .31417 .46338 .31009 .45959 Mtetra
.31009 .45959 .31417 .46338 .32053 .46179 .31645 .45799 Mtetra
.61 .752 .945 r
.31645 .45799 .32053 .46179 .3269 .4602 .32283 .45639 Mtetra
.609 .752 .946 r
.32283 .45639 .3269 .4602 .33328 .45861 .32923 .4548 Mtetra
.609 .751 .946 r
.32923 .4548 .33328 .45861 .33969 .45703 .33564 .45321 Mtetra
.609 .752 .946 r
.33564 .45321 .33969 .45703 .34611 .45544 .34207 .45161 Mtetra
.608 .752 .946 r
.34207 .45161 .34611 .45544 .35255 .45385 .34852 .45002 Mtetra
.607 .751 .946 r
.34852 .45002 .35255 .45385 .35901 .45227 .35499 .44843 Mtetra
.607 .751 .947 r
.35499 .44843 .35901 .45227 .36548 .45069 .36147 .44684 Mtetra
.36147 .44684 .36548 .45069 .37197 .4491 .36798 .44524 Mtetra
.605 .751 .947 r
.36798 .44524 .37197 .4491 .37848 .44753 .3745 .44366 Mtetra
.606 .751 .947 r
.3745 .44366 .37848 .44753 .38501 .44595 .38103 .44208 Mtetra
.38103 .44208 .38501 .44595 .39156 .44437 .38759 .44049 Mtetra
.604 .751 .948 r
.38759 .44049 .39156 .44437 .39812 .4428 .39416 .43891 Mtetra
.39416 .43891 .39812 .4428 .40471 .44123 .40076 .43734 Mtetra
.40076 .43734 .40471 .44123 .41131 .43966 .40737 .43576 Mtetra
.602 .75 .948 r
.40737 .43576 .41131 .43966 .41793 .4381 .414 .43419 Mtetra
.414 .43419 .41793 .4381 .42457 .43654 .42065 .43263 Mtetra
.602 .75 .949 r
.42065 .43263 .42457 .43654 .43122 .43498 .42731 .43106 Mtetra
.6 .75 .949 r
.42731 .43106 .43122 .43498 .4379 .43343 .434 .4295 Mtetra
.599 .75 .949 r
.434 .4295 .4379 .43343 .4446 .43189 .4407 .42795 Mtetra
.4407 .42795 .4446 .43189 .45131 .43034 .44743 .4264 Mtetra
.598 .75 .95 r
.44743 .4264 .45131 .43034 .45805 .4288 .45417 .42485 Mtetra
.597 .749 .95 r
.45417 .42485 .45805 .4288 .4648 .42727 .46094 .42331 Mtetra
.46094 .42331 .4648 .42727 .47157 .42574 .46772 .42178 Mtetra
.596 .749 .95 r
.46772 .42178 .47157 .42574 .47836 .42421 .47452 .42024 Mtetra
.594 .748 .951 r
.47452 .42024 .47836 .42421 .48518 .4227 .48135 .41872 Mtetra
.48135 .41872 .48518 .4227 .49201 .42119 .48819 .41721 Mtetra
.593 .748 .951 r
.48819 .41721 .49201 .42119 .49886 .41968 .49505 .41569 Mtetra
.591 .748 .952 r
.49505 .41569 .49886 .41968 .50574 .41819 .50194 .41419 Mtetra
.50194 .41419 .50574 .41819 .51263 .41671 .50884 .4127 Mtetra
.59 .748 .952 r
.50884 .4127 .51263 .41671 .51954 .41522 .51577 .41121 Mtetra
.588 .747 .953 r
.51577 .41121 .51954 .41522 .52648 .41375 .52271 .40973 Mtetra
.52271 .40973 .52648 .41375 .53343 .41229 .52968 .40826 Mtetra
.586 .747 .953 r
.52968 .40826 .53343 .41229 .54041 .41084 .53667 .4068 Mtetra
.585 .746 .954 r
.53667 .4068 .54041 .41084 .54741 .40939 .54368 .40535 Mtetra
.54368 .40535 .54741 .40939 .55443 .40795 .55071 .40391 Mtetra
.582 .745 .954 r
.55071 .40391 .55443 .40795 .56147 .40654 .55776 .40248 Mtetra
.582 .745 .955 r
.55776 .40248 .56147 .40654 .56854 .40512 .56484 .40106 Mtetra
.581 .745 .955 r
.56484 .40106 .56854 .40512 .57562 .40372 .57194 .39965 Mtetra
.578 .744 .955 r
.57194 .39965 .57562 .40372 .58273 .40233 .57906 .39826 Mtetra
.577 .744 .956 r
.57906 .39826 .58273 .40233 .58986 .40096 .5862 .39688 Mtetra
.576 .744 .956 r
.5862 .39688 .58986 .40096 .59702 .39959 .59336 .39551 Mtetra
.574 .743 .957 r
.59336 .39551 .59702 .39959 .60419 .39825 .60055 .39416 Mtetra
.573 .743 .957 r
.60055 .39416 .60419 .39825 .6114 .39691 .60777 .39282 Mtetra
.571 .742 .957 r
.60777 .39282 .6114 .39691 .61862 .3956 .615 .3915 Mtetra
.569 .742 .958 r
.615 .3915 .61862 .3956 .62587 .3943 .62226 .39019 Mtetra
.567 .741 .958 r
.62226 .39019 .62587 .3943 .63314 .39301 .62955 .3889 Mtetra
.565 .74 .959 r
.62955 .3889 .63314 .39301 .64044 .39175 .63686 .38763 Mtetra
.563 .74 .959 r
.63686 .38763 .64044 .39175 .64776 .3905 .64419 .38638 Mtetra
.561 .739 .96 r
.64419 .38638 .64776 .3905 .65511 .38928 .65155 .38515 Mtetra
.558 .738 .96 r
.65155 .38515 .65511 .38928 .66248 .38808 .65894 .38395 Mtetra
.557 .738 .96 r
.65894 .38395 .66248 .38808 .66988 .38689 .66635 .38276 Mtetra
.554 .737 .961 r
.66635 .38276 .66988 .38689 .6773 .38574 .67378 .3816 Mtetra
.552 .736 .961 r
.67378 .3816 .6773 .38574 .68475 .38459 .68125 .38045 Mtetra
.551 .736 .962 r
.68125 .38045 .68475 .38459 .69223 .38347 .68874 .37932 Mtetra
.549 .736 .962 r
.68874 .37932 .69223 .38347 .69973 .38235 .69625 .37819 Mtetra
.552 .737 .962 r
.69625 .37819 .69973 .38235 .70726 .3812 .70379 .37704 Mtetra
.556 .74 .962 r
.70379 .37704 .70726 .3812 .71481 .37998 .71136 .37582 Mtetra
.578 .75 .959 r
.71136 .37582 .71481 .37998 .72237 .3785 .71893 .37432 Mtetra
.597 .759 .956 r
.71893 .37432 .72237 .3785 .72993 .37675 .72651 .37256 Mtetra
.657 .783 .941 r
.72651 .37256 .72993 .37675 .73747 .37414 .73406 .36993 Mtetra
.73 .808 .913 r
.73406 .36993 .73747 .37414 .74493 .37022 .74153 .36596 Mtetra
.774 .819 .888 r
.74153 .36596 .74493 .37022 .75233 .36531 .74895 .36099 Mtetra
.885 .832 .789 r
.74895 .36099 .75233 .36531 .75944 .35629 .75608 .35187 Mtetra
.919 .824 .737 r
.75608 .35187 .75944 .35629 .76635 .34476 .763 .34023 Mtetra
.949 .81 .673 r
.763 .34023 .76635 .34476 .77294 .32944 .7696 .32478 Mtetra
.97 .789 .602 r
.7696 .32478 .77294 .32944 .77901 .30834 .77569 .30352 Mtetra
.975 .779 .577 r
.77569 .30352 .77901 .30834 .78479 .2846 .7815 .27964 Mtetra
.929 .561 .293 r
.12621 .427 .13044 .43056 .13403 .44698 .12977 .44343 Mtetra
.924 .544 .263 r
.12977 .44343 .13403 .44698 .13784 .46206 .13357 .45851 Mtetra
.895 .475 .152 r
.13357 .45851 .13784 .46206 .14215 .47352 .13787 .46997 Mtetra
.832 .362 0 r
.13787 .46997 .14215 .47352 .14685 .48209 .14257 .47853 Mtetra
.728 .219 0 r
.14257 .47853 .14685 .48209 .15182 .48874 .14753 .48516 Mtetra
0 .334 .784 r
.14753 .48516 .15182 .48874 .15725 .49163 .15296 .48804 Mtetra
.097 .501 .903 r
.15296 .48804 .15725 .49163 .16282 .49349 .15853 .48989 Mtetra
.367 .654 .967 r
.15853 .48989 .16282 .49349 .16856 .49398 .16428 .49037 Mtetra
.516 .719 .965 r
.16428 .49037 .16856 .49398 .17444 .49341 .17016 .4898 Mtetra
.553 .733 .959 r
.17016 .4898 .17444 .49341 .18037 .49251 .1761 .48889 Mtetra
.592 .746 .95 r
.1761 .48889 .18037 .49251 .18636 .49121 .1821 .48757 Mtetra
.604 .75 .947 r
.1821 .48757 .18636 .49121 .19238 .48977 .18813 .48613 Mtetra
.61 .752 .945 r
.18813 .48613 .19238 .48977 .19843 .48826 .19418 .48461 Mtetra
.614 .753 .944 r
.19418 .48461 .19843 .48826 .20449 .4867 .20025 .48304 Mtetra
.20025 .48304 .20449 .4867 .21057 .48512 .20634 .48145 Mtetra
.615 .753 .944 r
.20634 .48145 .21057 .48512 .21667 .48353 .21244 .47986 Mtetra
.21244 .47986 .21667 .48353 .22278 .48195 .21857 .47826 Mtetra
.21857 .47826 .22278 .48195 .22891 .48036 .2247 .47667 Mtetra
.2247 .47667 .22891 .48036 .23506 .47876 .23086 .47506 Mtetra
.614 .753 .944 r
.23086 .47506 .23506 .47876 .24122 .47717 .23703 .47346 Mtetra
.23703 .47346 .24122 .47717 .2474 .47557 .24322 .47186 Mtetra
.614 .753 .945 r
.24322 .47186 .2474 .47557 .25359 .47397 .24942 .47026 Mtetra
.613 .753 .945 r
.24942 .47026 .25359 .47397 .25981 .47238 .25564 .46865 Mtetra
.25564 .46865 .25981 .47238 .26603 .47078 .26187 .46705 Mtetra
.26187 .46705 .26603 .47078 .27228 .46918 .26813 .46544 Mtetra
.612 .753 .945 r
.26813 .46544 .27228 .46918 .27854 .46758 .2744 .46383 Mtetra
.2744 .46383 .27854 .46758 .28482 .46599 .28068 .46223 Mtetra
.28068 .46223 .28482 .46599 .29111 .46439 .28698 .46062 Mtetra
.28698 .46062 .29111 .46439 .29742 .46279 .2933 .45901 Mtetra
.611 .753 .946 r
.2933 .45901 .29742 .46279 .30375 .46119 .29964 .45741 Mtetra
.29964 .45741 .30375 .46119 .31009 .45959 .30599 .4558 Mtetra
.61 .753 .946 r
.30599 .4558 .31009 .45959 .31645 .45799 .31237 .45419 Mtetra
.61 .752 .946 r
.31237 .45419 .31645 .45799 .32283 .45639 .31875 .45259 Mtetra
.609 .752 .946 r
.31875 .45259 .32283 .45639 .32923 .4548 .32516 .45098 Mtetra
.608 .752 .946 r
.32516 .45098 .32923 .4548 .33564 .45321 .33158 .44939 Mtetra
.609 .752 .946 r
.33158 .44939 .33564 .45321 .34207 .45161 .33802 .44778 Mtetra
.608 .752 .947 r
.33802 .44778 .34207 .45161 .34852 .45002 .34448 .44618 Mtetra
.607 .752 .947 r
.34448 .44618 .34852 .45002 .35499 .44843 .35095 .44458 Mtetra
.35095 .44458 .35499 .44843 .36147 .44684 .35745 .44298 Mtetra
.35745 .44298 .36147 .44684 .36798 .44524 .36396 .44138 Mtetra
.605 .751 .948 r
.36396 .44138 .36798 .44524 .3745 .44366 .37049 .43979 Mtetra
.605 .752 .948 r
.37049 .43979 .3745 .44366 .38103 .44208 .37703 .4382 Mtetra
.37703 .4382 .38103 .44208 .38759 .44049 .3836 .4366 Mtetra
.604 .751 .948 r
.3836 .4366 .38759 .44049 .39416 .43891 .39018 .43502 Mtetra
.603 .751 .948 r
.39018 .43502 .39416 .43891 .40076 .43734 .39679 .43344 Mtetra
.39679 .43344 .40076 .43734 .40737 .43576 .40341 .43185 Mtetra
.602 .751 .949 r
.40341 .43185 .40737 .43576 .414 .43419 .41005 .43028 Mtetra
.601 .751 .949 r
.41005 .43028 .414 .43419 .42065 .43263 .41671 .42871 Mtetra
.41671 .42871 .42065 .43263 .42731 .43106 .42338 .42713 Mtetra
.6 .75 .949 r
.42338 .42713 .42731 .43106 .434 .4295 .43008 .42556 Mtetra
.599 .75 .95 r
.43008 .42556 .434 .4295 .4407 .42795 .43679 .42401 Mtetra
.43679 .42401 .4407 .42795 .44743 .4264 .44353 .42244 Mtetra
.598 .75 .95 r
.44353 .42244 .44743 .4264 .45417 .42485 .45028 .42089 Mtetra
.596 .75 .951 r
.45028 .42089 .45417 .42485 .46094 .42331 .45706 .41935 Mtetra
.45706 .41935 .46094 .42331 .46772 .42178 .46385 .4178 Mtetra
.46385 .4178 .46772 .42178 .47452 .42024 .47066 .41626 Mtetra
.594 .749 .951 r
.47066 .41626 .47452 .42024 .48135 .41872 .4775 .41474 Mtetra
.593 .749 .952 r
.4775 .41474 .48135 .41872 .48819 .41721 .48435 .41321 Mtetra
.48435 .41321 .48819 .41721 .49505 .41569 .49123 .41169 Mtetra
.591 .748 .952 r
.49123 .41169 .49505 .41569 .50194 .41419 .49812 .41019 Mtetra
.49812 .41019 .50194 .41419 .50884 .4127 .50503 .40868 Mtetra
.59 .748 .953 r
.50503 .40868 .50884 .4127 .51577 .41121 .51197 .40719 Mtetra
.588 .748 .953 r
.51197 .40719 .51577 .41121 .52271 .40973 .51893 .4057 Mtetra
.587 .747 .953 r
.51893 .4057 .52271 .40973 .52968 .40826 .52591 .40423 Mtetra
.586 .747 .954 r
.52591 .40423 .52968 .40826 .53667 .4068 .53291 .40276 Mtetra
.585 .747 .954 r
.53291 .40276 .53667 .4068 .54368 .40535 .53993 .4013 Mtetra
.584 .747 .954 r
.53993 .4013 .54368 .40535 .55071 .40391 .54697 .39985 Mtetra
.582 .746 .955 r
.54697 .39985 .55071 .40391 .55776 .40248 .55403 .39842 Mtetra
.581 .746 .955 r
.55403 .39842 .55776 .40248 .56484 .40106 .56112 .397 Mtetra
.58 .746 .955 r
.56112 .397 .56484 .40106 .57194 .39965 .56823 .39558 Mtetra
.578 .745 .956 r
.56823 .39558 .57194 .39965 .57906 .39826 .57536 .39418 Mtetra
.577 .745 .956 r
.57536 .39418 .57906 .39826 .5862 .39688 .58252 .3928 Mtetra
.575 .744 .957 r
.58252 .3928 .5862 .39688 .59336 .39551 .58969 .39142 Mtetra
.573 .744 .957 r
.58969 .39142 .59336 .39551 .60055 .39416 .5969 .39006 Mtetra
.572 .743 .958 r
.5969 .39006 .60055 .39416 .60777 .39282 .60412 .38872 Mtetra
.57 .743 .958 r
.60412 .38872 .60777 .39282 .615 .3915 .61137 .38739 Mtetra
.568 .742 .958 r
.61137 .38739 .615 .3915 .62226 .39019 .61864 .38608 Mtetra
.566 .742 .959 r
.61864 .38608 .62226 .39019 .62955 .3889 .62594 .38479 Mtetra
.564 .741 .959 r
.62594 .38479 .62955 .3889 .63686 .38763 .63326 .38352 Mtetra
.562 .741 .96 r
.63326 .38352 .63686 .38763 .64419 .38638 .64061 .38226 Mtetra
.56 .74 .96 r
.64061 .38226 .64419 .38638 .65155 .38515 .64798 .38103 Mtetra
.557 .739 .961 r
.64798 .38103 .65155 .38515 .65894 .38395 .65538 .37982 Mtetra
.556 .739 .961 r
.65538 .37982 .65894 .38395 .66635 .38276 .6628 .37862 Mtetra
.553 .738 .962 r
.6628 .37862 .66635 .38276 .67378 .3816 .67025 .37746 Mtetra
.551 .737 .962 r
.67025 .37746 .67378 .3816 .68125 .38045 .67773 .37631 Mtetra
.549 .737 .963 r
.67773 .37631 .68125 .38045 .68874 .37932 .68523 .37518 Mtetra
.548 .737 .963 r
.68523 .37518 .68874 .37932 .69625 .37819 .69276 .37405 Mtetra
.551 .738 .963 r
.69276 .37405 .69625 .37819 .70379 .37704 .70031 .37289 Mtetra
.555 .741 .963 r
.70031 .37289 .70379 .37704 .71136 .37582 .70789 .37166 Mtetra
.578 .751 .96 r
.70789 .37166 .71136 .37582 .71893 .37432 .71548 .37015 Mtetra
.597 .76 .957 r
.71548 .37015 .71893 .37432 .72651 .37256 .72307 .36838 Mtetra
.658 .785 .942 r
.72307 .36838 .72651 .37256 .73406 .36993 .73063 .36571 Mtetra
.732 .81 .913 r
.73063 .36571 .73406 .36993 .74153 .36596 .73812 .3617 Mtetra
.776 .821 .888 r
.73812 .3617 .74153 .36596 .74895 .36099 .74555 .35666 Mtetra
.886 .832 .788 r
.74555 .35666 .74895 .36099 .75608 .35187 .75269 .34745 Mtetra
.92 .825 .735 r
.75269 .34745 .75608 .35187 .763 .34023 .75963 .33568 Mtetra
.95 .81 .671 r
.75963 .33568 .763 .34023 .7696 .32478 .76625 .32009 Mtetra
.971 .789 .601 r
.76625 .32009 .7696 .32478 .77569 .30352 .77236 .29868 Mtetra
.975 .779 .576 r
.77236 .29868 .77569 .30352 .7815 .27964 .77819 .27464 Mtetra
.929 .561 .293 r
.12196 .42343 .12621 .427 .12977 .44343 .1255 .43987 Mtetra
.924 .544 .263 r
.1255 .43987 .12977 .44343 .13357 .45851 .12929 .45495 Mtetra
.895 .475 .152 r
.12929 .45495 .13357 .45851 .13787 .46997 .13357 .4664 Mtetra
.831 .362 0 r
.13357 .4664 .13787 .46997 .14257 .47853 .13826 .47495 Mtetra
.727 .218 0 r
.13826 .47495 .14257 .47853 .14753 .48516 .14322 .48157 Mtetra
0 .336 .786 r
.14322 .48157 .14753 .48516 .15296 .48804 .14865 .48444 Mtetra
.099 .502 .904 r
.14865 .48444 .15296 .48804 .15853 .48989 .15422 .48628 Mtetra
.368 .654 .967 r
.15422 .48628 .15853 .48989 .16428 .49037 .15998 .48675 Mtetra
.516 .719 .965 r
.15998 .48675 .16428 .49037 .17016 .4898 .16587 .48616 Mtetra
.553 .733 .959 r
.16587 .48616 .17016 .4898 .1761 .48889 .17181 .48524 Mtetra
.592 .746 .95 r
.17181 .48524 .1761 .48889 .1821 .48757 .17782 .48392 Mtetra
.604 .75 .947 r
.17782 .48392 .1821 .48757 .18813 .48613 .18385 .48247 Mtetra
.61 .752 .945 r
.18385 .48247 .18813 .48613 .19418 .48461 .18991 .48094 Mtetra
.614 .753 .944 r
.18991 .48094 .19418 .48461 .20025 .48304 .19599 .47936 Mtetra
.19599 .47936 .20025 .48304 .20634 .48145 .20209 .47777 Mtetra
.615 .753 .944 r
.20209 .47777 .20634 .48145 .21244 .47986 .2082 .47617 Mtetra
.2082 .47617 .21244 .47986 .21857 .47826 .21433 .47456 Mtetra
.21433 .47456 .21857 .47826 .2247 .47667 .22048 .47296 Mtetra
.22048 .47296 .2247 .47667 .23086 .47506 .22664 .47135 Mtetra
.614 .753 .944 r
.22664 .47135 .23086 .47506 .23703 .47346 .23282 .46974 Mtetra
.23282 .46974 .23703 .47346 .24322 .47186 .23901 .46813 Mtetra
.23901 .46813 .24322 .47186 .24942 .47026 .24523 .46652 Mtetra
.613 .753 .945 r
.24523 .46652 .24942 .47026 .25564 .46865 .25145 .46491 Mtetra
.25145 .46491 .25564 .46865 .26187 .46705 .2577 .46329 Mtetra
.2577 .46329 .26187 .46705 .26813 .46544 .26396 .46168 Mtetra
.612 .753 .945 r
.26396 .46168 .26813 .46544 .2744 .46383 .27024 .46006 Mtetra
.27024 .46006 .2744 .46383 .28068 .46223 .27653 .45845 Mtetra
.27653 .45845 .28068 .46223 .28698 .46062 .28284 .45684 Mtetra
.28284 .45684 .28698 .46062 .2933 .45901 .28917 .45522 Mtetra
.611 .753 .946 r
.28917 .45522 .2933 .45901 .29964 .45741 .29551 .45361 Mtetra
.61 .753 .946 r
.29551 .45361 .29964 .45741 .30599 .4558 .30188 .45199 Mtetra
.30188 .45199 .30599 .4558 .31237 .45419 .30826 .45038 Mtetra
.609 .753 .946 r
.30826 .45038 .31237 .45419 .31875 .45259 .31465 .44877 Mtetra
.609 .752 .946 r
.31465 .44877 .31875 .45259 .32516 .45098 .32107 .44715 Mtetra
.608 .752 .947 r
.32107 .44715 .32516 .45098 .33158 .44939 .3275 .44555 Mtetra
.3275 .44555 .33158 .44939 .33802 .44778 .33395 .44394 Mtetra
.33395 .44394 .33802 .44778 .34448 .44618 .34042 .44232 Mtetra
.607 .752 .947 r
.34042 .44232 .34448 .44618 .35095 .44458 .3469 .44072 Mtetra
.3469 .44072 .35095 .44458 .35745 .44298 .3534 .43912 Mtetra
.3534 .43912 .35745 .44298 .36396 .44138 .35992 .4375 Mtetra
.605 .752 .948 r
.35992 .4375 .36396 .44138 .37049 .43979 .36646 .43591 Mtetra
.36646 .43591 .37049 .43979 .37703 .4382 .37302 .43431 Mtetra
.37302 .43431 .37703 .4382 .3836 .4366 .37959 .43271 Mtetra
.603 .751 .948 r
.37959 .43271 .3836 .4366 .39018 .43502 .38619 .43112 Mtetra
.38619 .43112 .39018 .43502 .39679 .43344 .3928 .42953 Mtetra
.603 .751 .949 r
.3928 .42953 .39679 .43344 .40341 .43185 .39943 .42793 Mtetra
.602 .751 .949 r
.39943 .42793 .40341 .43185 .41005 .43028 .40608 .42635 Mtetra
.601 .751 .949 r
.40608 .42635 .41005 .43028 .41671 .42871 .41275 .42477 Mtetra
.41275 .42477 .41671 .42871 .42338 .42713 .41943 .42319 Mtetra
.6 .751 .95 r
.41943 .42319 .42338 .42713 .43008 .42556 .42614 .42161 Mtetra
.599 .75 .95 r
.42614 .42161 .43008 .42556 .43679 .42401 .43287 .42005 Mtetra
.599 .751 .95 r
.43287 .42005 .43679 .42401 .44353 .42244 .43961 .41848 Mtetra
.598 .75 .95 r
.43961 .41848 .44353 .42244 .45028 .42089 .44638 .41692 Mtetra
.596 .75 .951 r
.44638 .41692 .45028 .42089 .45706 .41935 .45316 .41537 Mtetra
.45316 .41537 .45706 .41935 .46385 .4178 .45996 .41382 Mtetra
.45996 .41382 .46385 .4178 .47066 .41626 .46679 .41227 Mtetra
.593 .749 .952 r
.46679 .41227 .47066 .41626 .4775 .41474 .47363 .41074 Mtetra
.47363 .41074 .4775 .41474 .48435 .41321 .48049 .40921 Mtetra
.48049 .40921 .48435 .41321 .49123 .41169 .48738 .40768 Mtetra
.591 .749 .953 r
.48738 .40768 .49123 .41169 .49812 .41019 .49428 .40617 Mtetra
.59 .749 .953 r
.49428 .40617 .49812 .41019 .50503 .40868 .50121 .40466 Mtetra
.589 .748 .953 r
.50121 .40466 .50503 .40868 .51197 .40719 .50816 .40315 Mtetra
.588 .748 .953 r
.50816 .40315 .51197 .40719 .51893 .4057 .51513 .40166 Mtetra
.587 .748 .954 r
.51513 .40166 .51893 .4057 .52591 .40423 .52211 .40018 Mtetra
.586 .747 .954 r
.52211 .40018 .52591 .40423 .53291 .40276 .52913 .39871 Mtetra
.584 .747 .954 r
.52913 .39871 .53291 .40276 .53993 .4013 .53616 .39724 Mtetra
.584 .747 .955 r
.53616 .39724 .53993 .4013 .54697 .39985 .54321 .39579 Mtetra
.581 .746 .955 r
.54321 .39579 .54697 .39985 .55403 .39842 .55029 .39435 Mtetra
.581 .746 .956 r
.55029 .39435 .55403 .39842 .56112 .397 .55739 .39292 Mtetra
.579 .746 .956 r
.55739 .39292 .56112 .397 .56823 .39558 .56451 .3915 Mtetra
.577 .745 .956 r
.56451 .3915 .56823 .39558 .57536 .39418 .57165 .3901 Mtetra
.576 .745 .957 r
.57165 .3901 .57536 .39418 .58252 .3928 .57882 .3887 Mtetra
.575 .745 .957 r
.57882 .3887 .58252 .3928 .58969 .39142 .58601 .38732 Mtetra
.573 .744 .958 r
.58601 .38732 .58969 .39142 .5969 .39006 .59322 .38596 Mtetra
.571 .744 .958 r
.59322 .38596 .5969 .39006 .60412 .38872 .60046 .38461 Mtetra
.569 .743 .958 r
.60046 .38461 .60412 .38872 .61137 .38739 .60772 .38328 Mtetra
.568 .743 .959 r
.60772 .38328 .61137 .38739 .61864 .38608 .615 .38196 Mtetra
.565 .742 .959 r
.615 .38196 .61864 .38608 .62594 .38479 .62231 .38066 Mtetra
.563 .741 .96 r
.62231 .38066 .62594 .38479 .63326 .38352 .62965 .37939 Mtetra
.562 .741 .96 r
.62965 .37939 .63326 .38352 .64061 .38226 .637 .37813 Mtetra
.559 .74 .961 r
.637 .37813 .64061 .38226 .64798 .38103 .64439 .37689 Mtetra
.557 .739 .961 r
.64439 .37689 .64798 .38103 .65538 .37982 .6518 .37568 Mtetra
.555 .739 .962 r
.6518 .37568 .65538 .37982 .6628 .37862 .65924 .37448 Mtetra
.552 .738 .962 r
.65924 .37448 .6628 .37862 .67025 .37746 .6667 .37331 Mtetra
.55 .737 .963 r
.6667 .37331 .67025 .37746 .67773 .37631 .67419 .37216 Mtetra
.549 .737 .963 r
.67419 .37216 .67773 .37631 .68523 .37518 .68171 .37102 Mtetra
.548 .737 .964 r
.68171 .37102 .68523 .37518 .69276 .37405 .68925 .36989 Mtetra
.55 .738 .963 r
.68925 .36989 .69276 .37405 .70031 .37289 .69682 .36872 Mtetra
.555 .741 .963 r
.69682 .36872 .70031 .37289 .70789 .37166 .70441 .36749 Mtetra
.577 .752 .96 r
.70441 .36749 .70789 .37166 .71548 .37015 .71201 .36597 Mtetra
.598 .761 .957 r
.71201 .36597 .71548 .37015 .72307 .36838 .71961 .36418 Mtetra
.659 .786 .942 r
.71961 .36418 .72307 .36838 .73063 .36571 .72719 .36148 Mtetra
.733 .811 .913 r
.72719 .36148 .73063 .36571 .73812 .3617 .73469 .35742 Mtetra
.778 .821 .887 r
.73469 .35742 .73812 .3617 .74555 .35666 .74214 .35232 Mtetra
.888 .833 .786 r
.74214 .35232 .74555 .35666 .75269 .34745 .74929 .343 Mtetra
.921 .824 .733 r
.74929 .343 .75269 .34745 .75963 .33568 .75625 .33111 Mtetra
.95 .81 .67 r
.75625 .33111 .75963 .33568 .76625 .32009 .76288 .31538 Mtetra
.971 .788 .6 r
.76288 .31538 .76625 .32009 .77236 .29868 .76902 .2938 Mtetra
.975 .778 .575 r
.76902 .2938 .77236 .29868 .77819 .27464 .77486 .26961 Mtetra
.929 .561 .293 r
.11769 .41985 .12196 .42343 .1255 .43987 .12121 .43629 Mtetra
.924 .543 .263 r
.12121 .43629 .1255 .43987 .12929 .45495 .12498 .45138 Mtetra
.895 .474 .151 r
.12498 .45138 .12929 .45495 .13357 .4664 .12925 .46282 Mtetra
.831 .361 0 r
.12925 .46282 .13357 .4664 .13826 .47495 .13393 .47136 Mtetra
.726 .217 0 r
.13393 .47136 .13826 .47495 .14322 .48157 .13889 .47797 Mtetra
0 .337 .787 r
.13889 .47797 .14322 .48157 .14865 .48444 .14432 .48082 Mtetra
.1 .503 .904 r
.14432 .48082 .14865 .48444 .15422 .48628 .1499 .48265 Mtetra
.369 .655 .967 r
.1499 .48265 .15422 .48628 .15998 .48675 .15566 .48311 Mtetra
.516 .72 .965 r
.15566 .48311 .15998 .48675 .16587 .48616 .16155 .48251 Mtetra
.553 .733 .959 r
.16155 .48251 .16587 .48616 .17181 .48524 .16751 .48158 Mtetra
.592 .746 .95 r
.16751 .48158 .17181 .48524 .17782 .48392 .17352 .48025 Mtetra
.604 .75 .947 r
.17352 .48025 .17782 .48392 .18385 .48247 .17956 .47879 Mtetra
.61 .751 .945 r
.17956 .47879 .18385 .48247 .18991 .48094 .18563 .47725 Mtetra
.614 .753 .944 r
.18563 .47725 .18991 .48094 .19599 .47936 .19171 .47567 Mtetra
.19171 .47567 .19599 .47936 .20209 .47777 .19782 .47407 Mtetra
.615 .753 .944 r
.19782 .47407 .20209 .47777 .2082 .47617 .20394 .47246 Mtetra
.20394 .47246 .2082 .47617 .21433 .47456 .21008 .47085 Mtetra
.21008 .47085 .21433 .47456 .22048 .47296 .21623 .46923 Mtetra
.21623 .46923 .22048 .47296 .22664 .47135 .2224 .46761 Mtetra
.614 .753 .944 r
.2224 .46761 .22664 .47135 .23282 .46974 .22859 .466 Mtetra
.22859 .466 .23282 .46974 .23901 .46813 .23479 .46438 Mtetra
.23479 .46438 .23901 .46813 .24523 .46652 .24101 .46276 Mtetra
.613 .753 .945 r
.24101 .46276 .24523 .46652 .25145 .46491 .24725 .46114 Mtetra
.24725 .46114 .25145 .46491 .2577 .46329 .2535 .45952 Mtetra
.2535 .45952 .2577 .46329 .26396 .46168 .25977 .4579 Mtetra
.612 .753 .945 r
.25977 .4579 .26396 .46168 .27024 .46006 .26606 .45628 Mtetra
.26606 .45628 .27024 .46006 .27653 .45845 .27236 .45466 Mtetra
.27236 .45466 .27653 .45845 .28284 .45684 .27868 .45304 Mtetra
.611 .753 .945 r
.27868 .45304 .28284 .45684 .28917 .45522 .28502 .45141 Mtetra
.61 .753 .946 r
.28502 .45141 .28917 .45522 .29551 .45361 .29137 .44979 Mtetra
.29137 .44979 .29551 .45361 .30188 .45199 .29774 .44817 Mtetra
.29774 .44817 .30188 .45199 .30826 .45038 .30413 .44655 Mtetra
.609 .753 .946 r
.30413 .44655 .30826 .45038 .31465 .44877 .31053 .44493 Mtetra
.31053 .44493 .31465 .44877 .32107 .44715 .31696 .44331 Mtetra
.608 .752 .947 r
.31696 .44331 .32107 .44715 .3275 .44555 .3234 .4417 Mtetra
.608 .753 .947 r
.3234 .4417 .3275 .44555 .33395 .44394 .32986 .44008 Mtetra
.608 .752 .947 r
.32986 .44008 .33395 .44394 .34042 .44232 .33633 .43846 Mtetra
.607 .752 .947 r
.33633 .43846 .34042 .44232 .3469 .44072 .34283 .43685 Mtetra
.34283 .43685 .3469 .44072 .3534 .43912 .34934 .43523 Mtetra
.34934 .43523 .3534 .43912 .35992 .4375 .35587 .43362 Mtetra
.605 .752 .948 r
.35587 .43362 .35992 .4375 .36646 .43591 .36242 .43201 Mtetra
.36242 .43201 .36646 .43591 .37302 .43431 .36898 .43041 Mtetra
.36898 .43041 .37302 .43431 .37959 .43271 .37557 .42879 Mtetra
.603 .752 .949 r
.37557 .42879 .37959 .43271 .38619 .43112 .38217 .4272 Mtetra
.38217 .4272 .38619 .43112 .3928 .42953 .38879 .4256 Mtetra
.38879 .4256 .3928 .42953 .39943 .42793 .39543 .424 Mtetra
.601 .751 .949 r
.39543 .424 .39943 .42793 .40608 .42635 .40209 .42241 Mtetra
.40209 .42241 .40608 .42635 .41275 .42477 .40877 .42082 Mtetra
.601 .751 .95 r
.40877 .42082 .41275 .42477 .41943 .42319 .41547 .41923 Mtetra
.6 .751 .95 r
.41547 .41923 .41943 .42319 .42614 .42161 .42218 .41765 Mtetra
.598 .751 .95 r
.42218 .41765 .42614 .42161 .43287 .42005 .42892 .41608 Mtetra
.42892 .41608 .43287 .42005 .43961 .41848 .43567 .4145 Mtetra
.598 .751 .951 r
.43567 .4145 .43961 .41848 .44638 .41692 .44245 .41293 Mtetra
.596 .75 .951 r
.44245 .41293 .44638 .41692 .45316 .41537 .44924 .41138 Mtetra
.44924 .41138 .45316 .41537 .45996 .41382 .45606 .40982 Mtetra
.595 .75 .951 r
.45606 .40982 .45996 .41382 .46679 .41227 .46289 .40826 Mtetra
.593 .75 .952 r
.46289 .40826 .46679 .41227 .47363 .41074 .46975 .40673 Mtetra
.593 .749 .952 r
.46975 .40673 .47363 .41074 .48049 .40921 .47662 .40519 Mtetra
.592 .749 .952 r
.47662 .40519 .48049 .40921 .48738 .40768 .48352 .40365 Mtetra
.59 .749 .953 r
.48352 .40365 .48738 .40768 .49428 .40617 .49043 .40214 Mtetra
.49043 .40214 .49428 .40617 .50121 .40466 .49737 .40062 Mtetra
.589 .749 .953 r
.49737 .40062 .50121 .40466 .50816 .40315 .50433 .39911 Mtetra
.587 .748 .954 r
.50433 .39911 .50816 .40315 .51513 .40166 .5113 .39761 Mtetra
.586 .748 .954 r
.5113 .39761 .51513 .40166 .52211 .40018 .5183 .39612 Mtetra
.585 .748 .954 r
.5183 .39612 .52211 .40018 .52913 .39871 .52533 .39464 Mtetra
.584 .747 .955 r
.52533 .39464 .52913 .39871 .53616 .39724 .53237 .39317 Mtetra
.583 .747 .955 r
.53237 .39317 .53616 .39724 .54321 .39579 .53944 .39171 Mtetra
.581 .747 .956 r
.53944 .39171 .54321 .39579 .55029 .39435 .54652 .39027 Mtetra
.58 .746 .956 r
.54652 .39027 .55029 .39435 .55739 .39292 .55363 .38883 Mtetra
.579 .746 .956 r
.55363 .38883 .55739 .39292 .56451 .3915 .56077 .3874 Mtetra
.577 .745 .957 r
.56077 .3874 .56451 .3915 .57165 .3901 .56792 .386 Mtetra
.576 .745 .957 r
.56792 .386 .57165 .3901 .57882 .3887 .5751 .3846 Mtetra
.574 .745 .958 r
.5751 .3846 .57882 .3887 .58601 .38732 .5823 .38321 Mtetra
.572 .744 .958 r
.5823 .38321 .58601 .38732 .59322 .38596 .58953 .38184 Mtetra
.571 .744 .958 r
.58953 .38184 .59322 .38596 .60046 .38461 .59677 .38049 Mtetra
.569 .743 .959 r
.59677 .38049 .60046 .38461 .60772 .38328 .60405 .37915 Mtetra
.567 .743 .959 r
.60405 .37915 .60772 .38328 .615 .38196 .61134 .37783 Mtetra
.565 .742 .96 r
.61134 .37783 .615 .38196 .62231 .38066 .61867 .37653 Mtetra
.563 .741 .96 r
.61867 .37653 .62231 .38066 .62965 .37939 .62601 .37525 Mtetra
.561 .741 .961 r
.62601 .37525 .62965 .37939 .637 .37813 .63338 .37398 Mtetra
.559 .74 .961 r
.63338 .37398 .637 .37813 .64439 .37689 .64078 .37274 Mtetra
.556 .739 .962 r
.64078 .37274 .64439 .37689 .6518 .37568 .64821 .37152 Mtetra
.555 .739 .962 r
.64821 .37152 .6518 .37568 .65924 .37448 .65566 .37032 Mtetra
.551 .738 .963 r
.65566 .37032 .65924 .37448 .6667 .37331 .66313 .36915 Mtetra
.549 .737 .963 r
.66313 .36915 .6667 .37331 .67419 .37216 .67063 .36799 Mtetra
.548 .737 .963 r
.67063 .36799 .67419 .37216 .68171 .37102 .67816 .36685 Mtetra
.547 .737 .964 r
.67816 .36685 .68171 .37102 .68925 .36989 .68572 .36572 Mtetra
.549 .739 .964 r
.68572 .36572 .68925 .36989 .69682 .36872 .6933 .36455 Mtetra
.554 .741 .963 r
.6933 .36455 .69682 .36872 .70441 .36749 .70091 .36331 Mtetra
.577 .752 .96 r
.70091 .36331 .70441 .36749 .71201 .36597 .70852 .36178 Mtetra
.598 .761 .957 r
.70852 .36178 .71201 .36597 .71961 .36418 .71614 .35997 Mtetra
.66 .787 .942 r
.71614 .35997 .71961 .36418 .72719 .36148 .72373 .35724 Mtetra
.735 .812 .912 r
.72373 .35724 .72719 .36148 .73469 .35742 .73125 .35313 Mtetra
.779 .822 .886 r
.73125 .35313 .73469 .35742 .74214 .35232 .73871 .34796 Mtetra
.889 .833 .784 r
.73871 .34796 .74214 .35232 .74929 .343 .74588 .33853 Mtetra
.922 .824 .731 r
.74588 .33853 .74929 .343 .75625 .33111 .75285 .32652 Mtetra
.951 .809 .668 r
.75285 .32652 .75625 .33111 .76288 .31538 .7595 .31063 Mtetra
.971 .788 .598 r
.7595 .31063 .76288 .31538 .76902 .2938 .76565 .28889 Mtetra
.975 .778 .574 r
.76565 .28889 .76902 .2938 .77486 .26961 .77152 .26453 Mtetra
.929 .561 .293 r
.1134 .41627 .11769 .41985 .12121 .43629 .1169 .43272 Mtetra
.923 .543 .263 r
.1169 .43272 .12121 .43629 .12498 .45138 .12065 .44781 Mtetra
.895 .474 .152 r
.12065 .44781 .12498 .45138 .12925 .46282 .12491 .45924 Mtetra
.831 .361 0 r
.12491 .45924 .12925 .46282 .13393 .47136 .12958 .46777 Mtetra
.726 .216 0 r
.12958 .46777 .13393 .47136 .13889 .47797 .13454 .47437 Mtetra
0 .338 .787 r
.13454 .47437 .13889 .47797 .14432 .48082 .13997 .47721 Mtetra
.099 .504 .904 r
.13997 .47721 .14432 .48082 .1499 .48265 .14555 .47902 Mtetra
.368 .656 .968 r
.14555 .47902 .1499 .48265 .15566 .48311 .15131 .47947 Mtetra
.516 .721 .966 r
.15131 .47947 .15566 .48311 .16155 .48251 .15722 .47886 Mtetra
.553 .734 .96 r
.15722 .47886 .16155 .48251 .16751 .48158 .16318 .47792 Mtetra
.592 .747 .951 r
.16318 .47792 .16751 .48158 .17352 .48025 .1692 .47658 Mtetra
.603 .751 .948 r
.1692 .47658 .17352 .48025 .17956 .47879 .17525 .47511 Mtetra
.609 .753 .946 r
.17525 .47511 .17956 .47879 .18563 .47725 .18132 .47357 Mtetra
.613 .754 .945 r
.18132 .47357 .18563 .47725 .19171 .47567 .18742 .47198 Mtetra
.614 .754 .945 r
.18742 .47198 .19171 .47567 .19782 .47407 .19353 .47037 Mtetra
.615 .754 .945 r
.19353 .47037 .19782 .47407 .20394 .47246 .19966 .46875 Mtetra
.614 .754 .945 r
.19966 .46875 .20394 .47246 .21008 .47085 .2058 .46713 Mtetra
.2058 .46713 .21008 .47085 .21623 .46923 .21197 .46551 Mtetra
.21197 .46551 .21623 .46923 .2224 .46761 .21814 .46388 Mtetra
.21814 .46388 .2224 .46761 .22859 .466 .22434 .46226 Mtetra
.613 .754 .945 r
.22434 .46226 .22859 .466 .23479 .46438 .23055 .46064 Mtetra
.23055 .46064 .23479 .46438 .24101 .46276 .23678 .45901 Mtetra
.613 .754 .946 r
.23678 .45901 .24101 .46276 .24725 .46114 .24302 .45738 Mtetra
.612 .754 .946 r
.24302 .45738 .24725 .46114 .2535 .45952 .24928 .45575 Mtetra
.24928 .45575 .2535 .45952 .25977 .4579 .25556 .45412 Mtetra
.25556 .45412 .25977 .4579 .26606 .45628 .26186 .45249 Mtetra
.611 .754 .946 r
.26186 .45249 .26606 .45628 .27236 .45466 .26817 .45087 Mtetra
.26817 .45087 .27236 .45466 .27868 .45304 .2745 .44924 Mtetra
.2745 .44924 .27868 .45304 .28502 .45141 .28084 .4476 Mtetra
.61 .753 .946 r
.28084 .4476 .28502 .45141 .29137 .44979 .2872 .44598 Mtetra
.61 .754 .947 r
.2872 .44598 .29137 .44979 .29774 .44817 .29358 .44435 Mtetra
.29358 .44435 .29774 .44817 .30413 .44655 .29998 .44271 Mtetra
.609 .753 .947 r
.29998 .44271 .30413 .44655 .31053 .44493 .3064 .44109 Mtetra
.3064 .44109 .31053 .44493 .31696 .44331 .31283 .43946 Mtetra
.608 .753 .947 r
.31283 .43946 .31696 .44331 .3234 .4417 .31928 .43784 Mtetra
.31928 .43784 .3234 .4417 .32986 .44008 .32575 .43621 Mtetra
.32575 .43621 .32986 .44008 .33633 .43846 .33223 .43458 Mtetra
.606 .753 .948 r
.33223 .43458 .33633 .43846 .34283 .43685 .33873 .43297 Mtetra
.33873 .43297 .34283 .43685 .34934 .43523 .34525 .43135 Mtetra
.34525 .43135 .34934 .43523 .35587 .43362 .35179 .42972 Mtetra
.605 .752 .948 r
.35179 .42972 .35587 .43362 .36242 .43201 .35835 .42811 Mtetra
.605 .753 .949 r
.35835 .42811 .36242 .43201 .36898 .43041 .36493 .4265 Mtetra
.36493 .4265 .36898 .43041 .37557 .42879 .37152 .42488 Mtetra
.603 .752 .949 r
.37152 .42488 .37557 .42879 .38217 .4272 .37813 .42327 Mtetra
.37813 .42327 .38217 .4272 .38879 .4256 .38476 .42167 Mtetra
.38476 .42167 .38879 .4256 .39543 .424 .39142 .42006 Mtetra
.601 .752 .95 r
.39142 .42006 .39543 .424 .40209 .42241 .39808 .41846 Mtetra
.6 .752 .95 r
.39808 .41846 .40209 .42241 .40877 .42082 .40477 .41687 Mtetra
.40477 .41687 .40877 .42082 .41547 .41923 .41148 .41527 Mtetra
.599 .752 .95 r
.41148 .41527 .41547 .41923 .42218 .41765 .41821 .41368 Mtetra
.598 .751 .951 r
.41821 .41368 .42218 .41765 .42892 .41608 .42495 .4121 Mtetra
.42495 .4121 .42892 .41608 .43567 .4145 .43172 .41052 Mtetra
.597 .751 .951 r
.43172 .41052 .43567 .4145 .44245 .41293 .4385 .40894 Mtetra
.596 .751 .952 r
.4385 .40894 .44245 .41293 .44924 .41138 .44531 .40738 Mtetra
.595 .751 .952 r
.44531 .40738 .44924 .41138 .45606 .40982 .45213 .40582 Mtetra
.45213 .40582 .45606 .40982 .46289 .40826 .45898 .40425 Mtetra
.593 .75 .953 r
.45898 .40425 .46289 .40826 .46975 .40673 .46584 .40271 Mtetra
.592 .75 .953 r
.46584 .40271 .46975 .40673 .47662 .40519 .47273 .40117 Mtetra
.47273 .40117 .47662 .40519 .48352 .40365 .47963 .39962 Mtetra
.59 .749 .953 r
.47963 .39962 .48352 .40365 .49043 .40214 .48656 .3981 Mtetra
.589 .749 .954 r
.48656 .3981 .49043 .40214 .49737 .40062 .49351 .39657 Mtetra
.49351 .39657 .49737 .40062 .50433 .39911 .50047 .39506 Mtetra
.587 .749 .954 r
.50047 .39506 .50433 .39911 .5113 .39761 .50746 .39356 Mtetra
.586 .749 .955 r
.50746 .39356 .5113 .39761 .5183 .39612 .51448 .39206 Mtetra
.585 .748 .955 r
.51448 .39206 .5183 .39612 .52533 .39464 .52151 .39057 Mtetra
.583 .748 .955 r
.52151 .39057 .52533 .39464 .53237 .39317 .52856 .3891 Mtetra
.582 .748 .956 r
.52856 .3891 .53237 .39317 .53944 .39171 .53564 .38763 Mtetra
.58 .747 .956 r
.53564 .38763 .53944 .39171 .54652 .39027 .54274 .38618 Mtetra
.579 .747 .957 r
.54274 .38618 .54652 .39027 .55363 .38883 .54986 .38474 Mtetra
.578 .747 .957 r
.54986 .38474 .55363 .38883 .56077 .3874 .55701 .3833 Mtetra
.576 .746 .957 r
.55701 .3833 .56077 .3874 .56792 .386 .56417 .38189 Mtetra
.575 .746 .958 r
.56417 .38189 .56792 .386 .5751 .3846 .57136 .38049 Mtetra
.573 .746 .958 r
.57136 .38049 .5751 .3846 .5823 .38321 .57858 .3791 Mtetra
.571 .745 .959 r
.57858 .3791 .5823 .38321 .58953 .38184 .58581 .37772 Mtetra
.57 .745 .959 r
.58581 .37772 .58953 .38184 .59677 .38049 .59307 .37636 Mtetra
.568 .744 .96 r
.59307 .37636 .59677 .38049 .60405 .37915 .60036 .37502 Mtetra
.566 .744 .96 r
.60036 .37502 .60405 .37915 .61134 .37783 .60767 .3737 Mtetra
.564 .743 .961 r
.60767 .3737 .61134 .37783 .61867 .37653 .615 .37239 Mtetra
.562 .742 .961 r
.615 .37239 .61867 .37653 .62601 .37525 .62236 .37111 Mtetra
.56 .742 .962 r
.62236 .37111 .62601 .37525 .63338 .37398 .62975 .36984 Mtetra
.557 .741 .962 r
.62975 .36984 .63338 .37398 .64078 .37274 .63716 .36859 Mtetra
.555 .74 .963 r
.63716 .36859 .64078 .37274 .64821 .37152 .64459 .36737 Mtetra
.553 .74 .963 r
.64459 .36737 .64821 .37152 .65566 .37032 .65206 .36617 Mtetra
.55 .739 .964 r
.65206 .36617 .65566 .37032 .66313 .36915 .65955 .36499 Mtetra
.548 .739 .964 r
.65955 .36499 .66313 .36915 .67063 .36799 .66706 .36384 Mtetra
.546 .738 .965 r
.66706 .36384 .67063 .36799 .67816 .36685 .67461 .36269 Mtetra
.67461 .36269 .67816 .36685 .68572 .36572 .68218 .36155 Mtetra
.548 .74 .965 r
.68218 .36155 .68572 .36572 .6933 .36455 .68977 .36038 Mtetra
.553 .743 .965 r
.68977 .36038 .6933 .36455 .70091 .36331 .69739 .35914 Mtetra
.577 .754 .962 r
.69739 .35914 .70091 .36331 .70852 .36178 .70502 .35759 Mtetra
.598 .763 .958 r
.70502 .35759 .70852 .36178 .71614 .35997 .71265 .35576 Mtetra
.661 .789 .943 r
.71265 .35576 .71614 .35997 .72373 .35724 .72025 .353 Mtetra
.737 .814 .912 r
.72025 .353 .72373 .35724 .73125 .35313 .72779 .34884 Mtetra
.782 .824 .885 r
.72779 .34884 .73125 .35313 .73871 .34796 .73526 .34361 Mtetra
.891 .833 .782 r
.73526 .34361 .73871 .34796 .74588 .33853 .74244 .33406 Mtetra
.924 .824 .729 r
.74244 .33406 .74588 .33853 .75285 .32652 .74943 .32191 Mtetra
.952 .809 .666 r
.74943 .32191 .75285 .32652 .7595 .31063 .7561 .30586 Mtetra
.971 .787 .597 r
.7561 .30586 .7595 .31063 .76565 .28889 .76227 .28394 Mtetra
.976 .777 .572 r
.76227 .28394 .76565 .28889 .77152 .26453 .76816 .25941 Mtetra
.929 .561 .293 r
.10909 .41267 .1134 .41627 .1169 .43272 .11257 .42913 Mtetra
.923 .543 .263 r
.11257 .42913 .1169 .43272 .12065 .44781 .1163 .44422 Mtetra
.895 .474 .151 r
.1163 .44422 .12065 .44781 .12491 .45924 .12055 .45565 Mtetra
.83 .36 0 r
.12055 .45565 .12491 .45924 .12958 .46777 .12522 .46417 Mtetra
.725 .215 0 r
.12522 .46417 .12958 .46777 .13454 .47437 .13016 .47075 Mtetra
0 .34 .788 r
.13016 .47075 .13454 .47437 .13997 .47721 .1356 .47358 Mtetra
.101 .505 .905 r
.1356 .47358 .13997 .47721 .14555 .47902 .14118 .47538 Mtetra
.369 .656 .968 r
.14118 .47538 .14555 .47902 .15131 .47947 .14695 .47581 Mtetra
.517 .721 .965 r
.14695 .47581 .15131 .47947 .15722 .47886 .15286 .4752 Mtetra
.553 .734 .96 r
.15286 .4752 .15722 .47886 .16318 .47792 .15883 .47425 Mtetra
.592 .747 .951 r
.15883 .47425 .16318 .47792 .1692 .47658 .16485 .4729 Mtetra
.603 .751 .948 r
.16485 .4729 .1692 .47658 .17525 .47511 .17091 .47142 Mtetra
.609 .753 .946 r
.17091 .47142 .17525 .47511 .18132 .47357 .17699 .46987 Mtetra
.613 .754 .945 r
.17699 .46987 .18132 .47357 .18742 .47198 .1831 .46827 Mtetra
.614 .754 .945 r
.1831 .46827 .18742 .47198 .19353 .47037 .18922 .46665 Mtetra
.615 .754 .945 r
.18922 .46665 .19353 .47037 .19966 .46875 .19536 .46503 Mtetra
.614 .754 .945 r
.19536 .46503 .19966 .46875 .2058 .46713 .20151 .4634 Mtetra
.20151 .4634 .2058 .46713 .21197 .46551 .20768 .46177 Mtetra
.20768 .46177 .21197 .46551 .21814 .46388 .21387 .46014 Mtetra
.21387 .46014 .21814 .46388 .22434 .46226 .22007 .45851 Mtetra
.613 .754 .945 r
.22007 .45851 .22434 .46226 .23055 .46064 .22629 .45687 Mtetra
.22629 .45687 .23055 .46064 .23678 .45901 .23253 .45524 Mtetra
.613 .754 .946 r
.23253 .45524 .23678 .45901 .24302 .45738 .23878 .4536 Mtetra
.612 .754 .946 r
.23878 .4536 .24302 .45738 .24928 .45575 .24505 .45197 Mtetra
.24505 .45197 .24928 .45575 .25556 .45412 .25133 .45033 Mtetra
.25133 .45033 .25556 .45412 .26186 .45249 .25764 .44869 Mtetra
.611 .754 .946 r
.25764 .44869 .26186 .45249 .26817 .45087 .26396 .44706 Mtetra
.26396 .44706 .26817 .45087 .2745 .44924 .27029 .44542 Mtetra
.27029 .44542 .2745 .44924 .28084 .4476 .27665 .44378 Mtetra
.61 .754 .947 r
.27665 .44378 .28084 .4476 .2872 .44598 .28302 .44215 Mtetra
.28302 .44215 .2872 .44598 .29358 .44435 .28941 .44051 Mtetra
.28941 .44051 .29358 .44435 .29998 .44271 .29581 .43887 Mtetra
.609 .753 .947 r
.29581 .43887 .29998 .44271 .3064 .44109 .30224 .43723 Mtetra
.608 .753 .947 r
.30224 .43723 .3064 .44109 .31283 .43946 .30868 .4356 Mtetra
.30868 .4356 .31283 .43946 .31928 .43784 .31514 .43397 Mtetra
.31514 .43397 .31928 .43784 .32575 .43621 .32161 .43233 Mtetra
.607 .753 .948 r
.32161 .43233 .32575 .43621 .33223 .43458 .32811 .4307 Mtetra
.606 .753 .948 r
.32811 .4307 .33223 .43458 .33873 .43297 .33462 .42907 Mtetra
.33462 .42907 .33873 .43297 .34525 .43135 .34115 .42745 Mtetra
.34115 .42745 .34525 .43135 .35179 .42972 .3477 .42581 Mtetra
.604 .753 .949 r
.3477 .42581 .35179 .42972 .35835 .42811 .35427 .4242 Mtetra
.35427 .4242 .35835 .42811 .36493 .4265 .36085 .42257 Mtetra
.36085 .42257 .36493 .4265 .37152 .42488 .36746 .42095 Mtetra
.603 .752 .949 r
.36746 .42095 .37152 .42488 .37813 .42327 .37408 .41934 Mtetra
.602 .752 .949 r
.37408 .41934 .37813 .42327 .38476 .42167 .38072 .41772 Mtetra
.602 .752 .95 r
.38072 .41772 .38476 .42167 .39142 .42006 .38738 .41611 Mtetra
.601 .752 .95 r
.38738 .41611 .39142 .42006 .39808 .41846 .39406 .4145 Mtetra
.6 .752 .95 r
.39406 .4145 .39808 .41846 .40477 .41687 .40076 .4129 Mtetra
.40076 .4129 .40477 .41687 .41148 .41527 .40747 .4113 Mtetra
.599 .752 .951 r
.40747 .4113 .41148 .41527 .41821 .41368 .41421 .4097 Mtetra
.598 .751 .951 r
.41421 .4097 .41821 .41368 .42495 .4121 .42097 .40811 Mtetra
.42097 .40811 .42495 .4121 .43172 .41052 .42774 .40653 Mtetra
.597 .751 .951 r
.42774 .40653 .43172 .41052 .4385 .40894 .43454 .40494 Mtetra
.595 .751 .952 r
.43454 .40494 .4385 .40894 .44531 .40738 .44135 .40337 Mtetra
.44135 .40337 .44531 .40738 .45213 .40582 .44819 .4018 Mtetra
.594 .751 .952 r
.44819 .4018 .45213 .40582 .45898 .40425 .45504 .40023 Mtetra
.593 .75 .953 r
.45504 .40023 .45898 .40425 .46584 .40271 .46192 .39868 Mtetra
.592 .75 .953 r
.46192 .39868 .46584 .40271 .47273 .40117 .46881 .39713 Mtetra
.46881 .39713 .47273 .40117 .47963 .39962 .47573 .39558 Mtetra
.59 .75 .954 r
.47573 .39558 .47963 .39962 .48656 .3981 .48267 .39405 Mtetra
.589 .75 .954 r
.48267 .39405 .48656 .3981 .49351 .39657 .48963 .39252 Mtetra
.588 .75 .954 r
.48963 .39252 .49351 .39657 .50047 .39506 .49661 .39099 Mtetra
.586 .749 .955 r
.49661 .39099 .50047 .39506 .50746 .39356 .50361 .38949 Mtetra
.50361 .38949 .50746 .39356 .51448 .39206 .51063 .38798 Mtetra
.584 .749 .955 r
.51063 .38798 .51448 .39206 .52151 .39057 .51767 .38649 Mtetra
.583 .748 .956 r
.51767 .38649 .52151 .39057 .52856 .3891 .52474 .38501 Mtetra
.582 .748 .956 r
.52474 .38501 .52856 .3891 .53564 .38763 .53183 .38353 Mtetra
.58 .747 .957 r
.53183 .38353 .53564 .38763 .54274 .38618 .53894 .38208 Mtetra
.579 .747 .957 r
.53894 .38208 .54274 .38618 .54986 .38474 .54607 .38063 Mtetra
.578 .747 .957 r
.54607 .38063 .54986 .38474 .55701 .3833 .55323 .37919 Mtetra
.575 .746 .958 r
.55323 .37919 .55701 .3833 .56417 .38189 .56041 .37778 Mtetra
.574 .746 .958 r
.56041 .37778 .56417 .38189 .57136 .38049 .56761 .37637 Mtetra
.573 .746 .959 r
.56761 .37637 .57136 .38049 .57858 .3791 .57483 .37497 Mtetra
.571 .745 .959 r
.57483 .37497 .57858 .3791 .58581 .37772 .58208 .37359 Mtetra
.569 .745 .959 r
.58208 .37359 .58581 .37772 .59307 .37636 .58936 .37223 Mtetra
.567 .744 .96 r
.58936 .37223 .59307 .37636 .60036 .37502 .59665 .37088 Mtetra
.565 .744 .96 r
.59665 .37088 .60036 .37502 .60767 .3737 .60398 .36955 Mtetra
.563 .743 .961 r
.60398 .36955 .60767 .3737 .615 .37239 .61132 .36824 Mtetra
.561 .742 .962 r
.61132 .36824 .615 .37239 .62236 .37111 .61869 .36696 Mtetra
.559 .742 .962 r
.61869 .36696 .62236 .37111 .62975 .36984 .62609 .36568 Mtetra
.557 .741 .963 r
.62609 .36568 .62975 .36984 .63716 .36859 .63351 .36443 Mtetra
.554 .74 .963 r
.63351 .36443 .63716 .36859 .64459 .36737 .64096 .36321 Mtetra
.552 .74 .963 r
.64096 .36321 .64459 .36737 .65206 .36617 .64844 .362 Mtetra
.549 .739 .964 r
.64844 .362 .65206 .36617 .65955 .36499 .65594 .36083 Mtetra
.547 .739 .965 r
.65594 .36083 .65955 .36499 .66706 .36384 .66347 .35967 Mtetra
.545 .738 .965 r
.66347 .35967 .66706 .36384 .67461 .36269 .67103 .35852 Mtetra
.67103 .35852 .67461 .36269 .68218 .36155 .67861 .35738 Mtetra
.547 .74 .965 r
.67861 .35738 .68218 .36155 .68977 .36038 .68622 .3562 Mtetra
.552 .743 .965 r
.68622 .3562 .68977 .36038 .69739 .35914 .69385 .35496 Mtetra
.577 .754 .962 r
.69385 .35496 .69739 .35914 .70502 .35759 .70149 .3534 Mtetra
.598 .764 .958 r
.70149 .3534 .70502 .35759 .71265 .35576 .70914 .35155 Mtetra
.662 .79 .942 r
.70914 .35155 .71265 .35576 .72025 .353 .71676 .34875 Mtetra
.739 .815 .911 r
.71676 .34875 .72025 .353 .72779 .34884 .72431 .34453 Mtetra
.784 .825 .884 r
.72431 .34453 .72779 .34884 .73526 .34361 .73179 .33923 Mtetra
.893 .833 .78 r
.73179 .33923 .73526 .34361 .74244 .33406 .73899 .32956 Mtetra
.925 .824 .727 r
.73899 .32956 .74244 .33406 .74943 .32191 .74599 .31727 Mtetra
.952 .808 .664 r
.74599 .31727 .74943 .32191 .7561 .30586 .75268 .30106 Mtetra
.972 .787 .595 r
.75268 .30106 .7561 .30586 .76227 .28394 .75887 .27896 Mtetra
.976 .776 .571 r
.75887 .27896 .76227 .28394 .76816 .25941 .76479 .25426 Mtetra
.929 .561 .293 r
.10477 .40907 .10909 .41267 .11257 .42913 .10822 .42553 Mtetra
.923 .543 .263 r
.10822 .42553 .11257 .42913 .1163 .44422 .11193 .44062 Mtetra
.895 .473 .151 r
.11193 .44062 .1163 .44422 .12055 .45565 .11617 .45204 Mtetra
.83 .359 0 r
.11617 .45204 .12055 .45565 .12522 .46417 .12083 .46055 Mtetra
.724 .214 0 r
.12083 .46055 .12522 .46417 .13016 .47075 .12577 .46711 Mtetra
0 .342 .789 r
.12577 .46711 .13016 .47075 .1356 .47358 .13121 .46993 Mtetra
.103 .507 .906 r
.13121 .46993 .1356 .47358 .14118 .47538 .1368 .47172 Mtetra
.37 .657 .968 r
.1368 .47172 .14118 .47538 .14695 .47581 .14257 .47214 Mtetra
.517 .721 .965 r
.14257 .47214 .14695 .47581 .15286 .4752 .14849 .47151 Mtetra
.554 .734 .96 r
.14849 .47151 .15286 .4752 .15883 .47425 .15446 .47055 Mtetra
.592 .747 .951 r
.15446 .47055 .15883 .47425 .16485 .4729 .16049 .4692 Mtetra
.604 .751 .948 r
.16049 .4692 .16485 .4729 .17091 .47142 .16656 .46771 Mtetra
.609 .752 .946 r
.16656 .46771 .17091 .47142 .17699 .46987 .17265 .46615 Mtetra
.613 .754 .945 r
.17265 .46615 .17699 .46987 .1831 .46827 .17876 .46454 Mtetra
.614 .754 .945 r
.17876 .46454 .1831 .46827 .18922 .46665 .18489 .46292 Mtetra
.615 .754 .945 r
.18489 .46292 .18922 .46665 .19536 .46503 .19104 .46129 Mtetra
.614 .754 .945 r
.19104 .46129 .19536 .46503 .20151 .4634 .1972 .45965 Mtetra
.1972 .45965 .20151 .4634 .20768 .46177 .20338 .45801 Mtetra
.20338 .45801 .20768 .46177 .21387 .46014 .20957 .45637 Mtetra
.613 .754 .945 r
.20957 .45637 .21387 .46014 .22007 .45851 .21578 .45473 Mtetra
.21578 .45473 .22007 .45851 .22629 .45687 .22201 .45309 Mtetra
.22201 .45309 .22629 .45687 .23253 .45524 .22825 .45145 Mtetra
.22825 .45145 .23253 .45524 .23878 .4536 .23451 .44981 Mtetra
.612 .754 .946 r
.23451 .44981 .23878 .4536 .24505 .45197 .24079 .44817 Mtetra
.24079 .44817 .24505 .45197 .25133 .45033 .24709 .44652 Mtetra
.24709 .44652 .25133 .45033 .25764 .44869 .2534 .44487 Mtetra
.611 .754 .946 r
.2534 .44487 .25764 .44869 .26396 .44706 .25973 .44323 Mtetra
.25973 .44323 .26396 .44706 .27029 .44542 .26607 .44159 Mtetra
.26607 .44159 .27029 .44542 .27665 .44378 .27244 .43994 Mtetra
.61 .754 .947 r
.27244 .43994 .27665 .44378 .28302 .44215 .27882 .4383 Mtetra
.27882 .4383 .28302 .44215 .28941 .44051 .28521 .43665 Mtetra
.28521 .43665 .28941 .44051 .29581 .43887 .29163 .435 Mtetra
.609 .754 .947 r
.29163 .435 .29581 .43887 .30224 .43723 .29806 .43336 Mtetra
.608 .754 .947 r
.29806 .43336 .30224 .43723 .30868 .4356 .30451 .43172 Mtetra
.608 .753 .948 r
.30451 .43172 .30868 .4356 .31514 .43397 .31098 .43009 Mtetra
.608 .754 .948 r
.31098 .43009 .31514 .43397 .32161 .43233 .31746 .42844 Mtetra
.607 .753 .948 r
.31746 .42844 .32161 .43233 .32811 .4307 .32397 .4268 Mtetra
.606 .753 .948 r
.32397 .4268 .32811 .4307 .33462 .42907 .33049 .42517 Mtetra
.33049 .42517 .33462 .42907 .34115 .42745 .33703 .42353 Mtetra
.33703 .42353 .34115 .42745 .3477 .42581 .34359 .42189 Mtetra
.604 .753 .949 r
.34359 .42189 .3477 .42581 .35427 .4242 .35016 .42027 Mtetra
.35016 .42027 .35427 .4242 .36085 .42257 .35676 .41864 Mtetra
.35676 .41864 .36085 .42257 .36746 .42095 .36337 .417 Mtetra
.602 .753 .95 r
.36337 .417 .36746 .42095 .37408 .41934 .37 .41538 Mtetra
.37 .41538 .37408 .41934 .38072 .41772 .37665 .41377 Mtetra
.37665 .41377 .38072 .41772 .38738 .41611 .38332 .41214 Mtetra
.601 .752 .95 r
.38332 .41214 .38738 .41611 .39406 .4145 .39001 .41053 Mtetra
.6 .752 .951 r
.39001 .41053 .39406 .4145 .40076 .4129 .39672 .40892 Mtetra
.39672 .40892 .40076 .4129 .40747 .4113 .40345 .40731 Mtetra
.599 .752 .951 r
.40345 .40731 .40747 .4113 .41421 .4097 .41019 .40571 Mtetra
.598 .752 .951 r
.41019 .40571 .41421 .4097 .42097 .40811 .41696 .40411 Mtetra
.597 .752 .952 r
.41696 .40411 .42097 .40811 .42774 .40653 .42375 .40252 Mtetra
.596 .752 .952 r
.42375 .40252 .42774 .40653 .43454 .40494 .43055 .40093 Mtetra
.595 .751 .952 r
.43055 .40093 .43454 .40494 .44135 .40337 .43738 .39935 Mtetra
.594 .751 .952 r
.43738 .39935 .44135 .40337 .44819 .4018 .44422 .39777 Mtetra
.594 .751 .953 r
.44422 .39777 .44819 .4018 .45504 .40023 .45109 .3962 Mtetra
.592 .751 .953 r
.45109 .3962 .45504 .40023 .46192 .39868 .45797 .39464 Mtetra
.45797 .39464 .46192 .39868 .46881 .39713 .46488 .39308 Mtetra
.591 .751 .954 r
.46488 .39308 .46881 .39713 .47573 .39558 .47181 .39152 Mtetra
.589 .75 .954 r
.47181 .39152 .47573 .39558 .48267 .39405 .47876 .38999 Mtetra
.47876 .38999 .48267 .39405 .48963 .39252 .48573 .38845 Mtetra
.588 .75 .955 r
.48573 .38845 .48963 .39252 .49661 .39099 .49272 .38692 Mtetra
.586 .749 .955 r
.49272 .38692 .49661 .39099 .50361 .38949 .49973 .38541 Mtetra
.585 .749 .955 r
.49973 .38541 .50361 .38949 .51063 .38798 .50676 .3839 Mtetra
.584 .749 .956 r
.50676 .3839 .51063 .38798 .51767 .38649 .51382 .3824 Mtetra
.582 .749 .956 r
.51382 .3824 .51767 .38649 .52474 .38501 .5209 .38091 Mtetra
.581 .748 .957 r
.5209 .38091 .52474 .38501 .53183 .38353 .528 .37943 Mtetra
.579 .748 .957 r
.528 .37943 .53183 .38353 .53894 .38208 .53512 .37797 Mtetra
.578 .748 .957 r
.53512 .37797 .53894 .38208 .54607 .38063 .54226 .37652 Mtetra
.577 .747 .958 r
.54226 .37652 .54607 .38063 .55323 .37919 .54943 .37507 Mtetra
.575 .747 .958 r
.54943 .37507 .55323 .37919 .56041 .37778 .55662 .37365 Mtetra
.574 .747 .959 r
.55662 .37365 .56041 .37778 .56761 .37637 .56383 .37223 Mtetra
.572 .746 .959 r
.56383 .37223 .56761 .37637 .57483 .37497 .57107 .37083 Mtetra
.57 .745 .96 r
.57107 .37083 .57483 .37497 .58208 .37359 .57833 .36945 Mtetra
.569 .745 .96 r
.57833 .36945 .58208 .37359 .58936 .37223 .58562 .36808 Mtetra
.567 .745 .96 r
.58562 .36808 .58936 .37223 .59665 .37088 .59293 .36673 Mtetra
.565 .744 .961 r
.59293 .36673 .59665 .37088 .60398 .36955 .60026 .3654 Mtetra
.563 .743 .961 r
.60026 .3654 .60398 .36955 .61132 .36824 .60762 .36408 Mtetra
.56 .743 .962 r
.60762 .36408 .61132 .36824 .61869 .36696 .61501 .36279 Mtetra
.559 .742 .962 r
.61501 .36279 .61869 .36696 .62609 .36568 .62242 .36152 Mtetra
.556 .742 .963 r
.62242 .36152 .62609 .36568 .63351 .36443 .62985 .36026 Mtetra
.553 .741 .963 r
.62985 .36026 .63351 .36443 .64096 .36321 .63732 .35904 Mtetra
.552 .74 .964 r
.63732 .35904 .64096 .36321 .64844 .362 .64481 .35783 Mtetra
.548 .739 .965 r
.64481 .35783 .64844 .362 .65594 .36083 .65232 .35665 Mtetra
.546 .739 .965 r
.65232 .35665 .65594 .36083 .66347 .35967 .65986 .35549 Mtetra
.544 .738 .965 r
.65986 .35549 .66347 .35967 .67103 .35852 .66743 .35434 Mtetra
.544 .739 .966 r
.66743 .35434 .67103 .35852 .67861 .35738 .67503 .35319 Mtetra
.546 .74 .966 r
.67503 .35319 .67861 .35738 .68622 .3562 .68265 .35201 Mtetra
.552 .743 .965 r
.68265 .35201 .68622 .3562 .69385 .35496 .6903 .35076 Mtetra
.577 .755 .962 r
.6903 .35076 .69385 .35496 .70149 .3534 .69796 .34919 Mtetra
.599 .765 .959 r
.69796 .34919 .70149 .3534 .70914 .35155 .70562 .34732 Mtetra
.664 .791 .942 r
.70562 .34732 .70914 .35155 .71676 .34875 .71325 .34449 Mtetra
.741 .816 .91 r
.71325 .34449 .71676 .34875 .72431 .34453 .72081 .34021 Mtetra
.786 .826 .883 r
.72081 .34021 .72431 .34453 .73179 .33923 .72831 .33483 Mtetra
.895 .833 .778 r
.72831 .33483 .73179 .33923 .73899 .32956 .73552 .32504 Mtetra
.926 .824 .725 r
.73552 .32504 .73899 .32956 .74599 .31727 .74254 .31261 Mtetra
.953 .808 .662 r
.74254 .31261 .74599 .31727 .75268 .30106 .74924 .29622 Mtetra
.972 .786 .594 r
.74924 .29622 .75268 .30106 .75887 .27896 .75546 .27394 Mtetra
.976 .776 .57 r
.75546 .27394 .75887 .27896 .76479 .25426 .76139 .24906 Mtetra
.929 .561 .294 r
.10042 .40546 .10477 .40907 .10822 .42553 .10385 .42193 Mtetra
.923 .543 .263 r
.10385 .42193 .10822 .42553 .11193 .44062 .10754 .43702 Mtetra
.894 .473 .151 r
.10754 .43702 .11193 .44062 .11617 .45204 .11177 .44843 Mtetra
.83 .359 0 r
.11177 .44843 .11617 .45204 .12083 .46055 .11642 .45693 Mtetra
.723 .213 0 r
.11642 .45693 .12083 .46055 .12577 .46711 .12136 .46348 Mtetra
0 .342 .789 r
.12136 .46348 .12577 .46711 .13121 .46993 .1268 .46628 Mtetra
.103 .507 .906 r
.1268 .46628 .13121 .46993 .1368 .47172 .13239 .46806 Mtetra
.37 .658 .968 r
.13239 .46806 .1368 .47172 .14257 .47214 .13817 .46847 Mtetra
.517 .722 .966 r
.13817 .46847 .14257 .47214 .14849 .47151 .14409 .46783 Mtetra
.553 .735 .96 r
.14409 .46783 .14849 .47151 .15446 .47055 .15007 .46686 Mtetra
.592 .748 .952 r
.15007 .46686 .15446 .47055 .16049 .4692 .15611 .4655 Mtetra
.603 .752 .949 r
.15611 .4655 .16049 .4692 .16656 .46771 .16219 .464 Mtetra
.609 .753 .947 r
.16219 .464 .16656 .46771 .17265 .46615 .16828 .46244 Mtetra
.613 .755 .946 r
.16828 .46244 .17265 .46615 .17876 .46454 .1744 .46082 Mtetra
.614 .755 .946 r
.1744 .46082 .17876 .46454 .18489 .46292 .18054 .45919 Mtetra
.614 .755 .945 r
.18054 .45919 .18489 .46292 .19104 .46129 .18669 .45754 Mtetra
.614 .755 .946 r
.18669 .45754 .19104 .46129 .1972 .45965 .19286 .4559 Mtetra
.19286 .4559 .1972 .45965 .20338 .45801 .19905 .45426 Mtetra
.19905 .45426 .20338 .45801 .20957 .45637 .20525 .45261 Mtetra
.613 .755 .946 r
.20525 .45261 .20957 .45637 .21578 .45473 .21147 .45096 Mtetra
.21147 .45096 .21578 .45473 .22201 .45309 .21771 .44931 Mtetra
.21771 .44931 .22201 .45309 .22825 .45145 .22396 .44766 Mtetra
.612 .755 .946 r
.22396 .44766 .22825 .45145 .23451 .44981 .23023 .44601 Mtetra
.23023 .44601 .23451 .44981 .24079 .44817 .23652 .44436 Mtetra
.23652 .44436 .24079 .44817 .24709 .44652 .24282 .44271 Mtetra
.611 .755 .947 r
.24282 .44271 .24709 .44652 .2534 .44487 .24914 .44106 Mtetra
.24914 .44106 .2534 .44487 .25973 .44323 .25548 .43941 Mtetra
.25548 .43941 .25973 .44323 .26607 .44159 .26183 .43775 Mtetra
.26183 .43775 .26607 .44159 .27244 .43994 .2682 .4361 Mtetra
.61 .754 .947 r
.2682 .4361 .27244 .43994 .27882 .4383 .27459 .43445 Mtetra
.609 .754 .947 r
.27459 .43445 .27882 .4383 .28521 .43665 .281 .43279 Mtetra
.281 .43279 .28521 .43665 .29163 .435 .28742 .43114 Mtetra
.608 .754 .948 r
.28742 .43114 .29163 .435 .29806 .43336 .29386 .42949 Mtetra
.29386 .42949 .29806 .43336 .30451 .43172 .30032 .42784 Mtetra
.607 .754 .948 r
.30032 .42784 .30451 .43172 .31098 .43009 .3068 .42619 Mtetra
.3068 .42619 .31098 .43009 .31746 .42844 .31329 .42454 Mtetra
.31329 .42454 .31746 .42844 .32397 .4268 .31981 .42289 Mtetra
.606 .754 .949 r
.31981 .42289 .32397 .4268 .33049 .42517 .32634 .42126 Mtetra
.32634 .42126 .33049 .42517 .33703 .42353 .33289 .41961 Mtetra
.33289 .41961 .33703 .42353 .34359 .42189 .33945 .41796 Mtetra
.604 .753 .949 r
.33945 .41796 .34359 .42189 .35016 .42027 .34604 .41633 Mtetra
.604 .753 .95 r
.34604 .41633 .35016 .42027 .35676 .41864 .35264 .41469 Mtetra
.604 .754 .95 r
.35264 .41469 .35676 .41864 .36337 .417 .35927 .41305 Mtetra
.602 .753 .95 r
.35927 .41305 .36337 .417 .37 .41538 .36591 .41143 Mtetra
.36591 .41143 .37 .41538 .37665 .41377 .37257 .4098 Mtetra
.37257 .4098 .37665 .41377 .38332 .41214 .37925 .40817 Mtetra
.6 .753 .951 r
.37925 .40817 .38332 .41214 .39001 .41053 .38595 .40655 Mtetra
.38595 .40655 .39001 .41053 .39672 .40892 .39267 .40494 Mtetra
.599 .753 .951 r
.39267 .40494 .39672 .40892 .40345 .40731 .3994 .40332 Mtetra
.598 .753 .952 r
.3994 .40332 .40345 .40731 .41019 .40571 .40616 .40171 Mtetra
.597 .752 .952 r
.40616 .40171 .41019 .40571 .41696 .40411 .41294 .40011 Mtetra
.41294 .40011 .41696 .40411 .42375 .40252 .41973 .3985 Mtetra
.596 .752 .952 r
.41973 .3985 .42375 .40252 .43055 .40093 .42655 .39691 Mtetra
.595 .752 .953 r
.42655 .39691 .43055 .40093 .43738 .39935 .43338 .39532 Mtetra
.594 .752 .953 r
.43338 .39532 .43738 .39935 .44422 .39777 .44024 .39374 Mtetra
.44024 .39374 .44422 .39777 .45109 .3962 .44712 .39215 Mtetra
.592 .751 .954 r
.44712 .39215 .45109 .3962 .45797 .39464 .45401 .39059 Mtetra
.591 .751 .954 r
.45401 .39059 .45797 .39464 .46488 .39308 .46093 .38902 Mtetra
.46093 .38902 .46488 .39308 .47181 .39152 .46787 .38746 Mtetra
.589 .751 .955 r
.46787 .38746 .47181 .39152 .47876 .38999 .47483 .38592 Mtetra
.588 .75 .955 r
.47483 .38592 .47876 .38999 .48573 .38845 .48181 .38438 Mtetra
.587 .75 .955 r
.48181 .38438 .48573 .38845 .49272 .38692 .48881 .38284 Mtetra
.585 .75 .956 r
.48881 .38284 .49272 .38692 .49973 .38541 .49583 .38132 Mtetra
.49583 .38132 .49973 .38541 .50676 .3839 .50288 .3798 Mtetra
.583 .749 .956 r
.50288 .3798 .50676 .3839 .51382 .3824 .50994 .3783 Mtetra
.582 .749 .957 r
.50994 .3783 .51382 .3824 .5209 .38091 .51703 .3768 Mtetra
.581 .749 .957 r
.51703 .3768 .5209 .38091 .528 .37943 .52414 .37532 Mtetra
.579 .748 .958 r
.52414 .37532 .528 .37943 .53512 .37797 .53128 .37385 Mtetra
.578 .748 .958 r
.53128 .37385 .53512 .37797 .54226 .37652 .53843 .37239 Mtetra
.577 .748 .958 r
.53843 .37239 .54226 .37652 .54943 .37507 .54561 .37094 Mtetra
.574 .747 .959 r
.54561 .37094 .54943 .37507 .55662 .37365 .55282 .36951 Mtetra
.573 .747 .959 r
.55282 .36951 .55662 .37365 .56383 .37223 .56004 .36809 Mtetra
.572 .747 .96 r
.56004 .36809 .56383 .37223 .57107 .37083 .56729 .36669 Mtetra
.569 .746 .96 r
.56729 .36669 .57107 .37083 .57833 .36945 .57457 .3653 Mtetra
.568 .746 .96 r
.57457 .3653 .57833 .36945 .58562 .36808 .58186 .36393 Mtetra
.566 .745 .961 r
.58186 .36393 .58562 .36808 .59293 .36673 .58919 .36257 Mtetra
.564 .744 .961 r
.58919 .36257 .59293 .36673 .60026 .3654 .59653 .36123 Mtetra
.562 .744 .962 r
.59653 .36123 .60026 .3654 .60762 .36408 .6039 .35991 Mtetra
.559 .743 .963 r
.6039 .35991 .60762 .36408 .61501 .36279 .6113 .35862 Mtetra
.558 .743 .963 r
.6113 .35862 .61501 .36279 .62242 .36152 .61873 .35734 Mtetra
.555 .742 .963 r
.61873 .35734 .62242 .36152 .62985 .36026 .62617 .35608 Mtetra
.552 .741 .964 r
.62617 .35608 .62985 .36026 .63732 .35904 .63365 .35486 Mtetra
.551 .741 .964 r
.63365 .35486 .63732 .35904 .64481 .35783 .64115 .35364 Mtetra
.547 .74 .965 r
.64115 .35364 .64481 .35783 .65232 .35665 .64868 .35246 Mtetra
.545 .739 .966 r
.64868 .35246 .65232 .35665 .65986 .35549 .65624 .3513 Mtetra
.543 .739 .966 r
.65624 .3513 .65986 .35549 .66743 .35434 .66382 .35015 Mtetra
.66382 .35015 .66743 .35434 .67503 .35319 .67143 .349 Mtetra
.546 .741 .966 r
.67143 .349 .67503 .35319 .68265 .35201 .67907 .34781 Mtetra
.551 .743 .966 r
.67907 .34781 .68265 .35201 .6903 .35076 .68673 .34655 Mtetra
.577 .756 .963 r
.68673 .34655 .6903 .35076 .69796 .34919 .6944 .34497 Mtetra
.599 .765 .959 r
.6944 .34497 .69796 .34919 .70562 .34732 .70208 .34308 Mtetra
.666 .792 .942 r
.70208 .34308 .70562 .34732 .71325 .34449 .70972 .34021 Mtetra
.744 .817 .909 r
.70972 .34021 .71325 .34449 .72081 .34021 .71729 .33586 Mtetra
.789 .826 .881 r
.71729 .33586 .72081 .34021 .72831 .33483 .72481 .33041 Mtetra
.896 .833 .776 r
.72481 .33041 .72831 .33483 .73552 .32504 .73204 .32048 Mtetra
.927 .823 .723 r
.73204 .32048 .73552 .32504 .74254 .31261 .73907 .3079 Mtetra
.954 .807 .66 r
.73907 .3079 .74254 .31261 .74924 .29622 .74579 .29133 Mtetra
.972 .785 .593 r
.74579 .29133 .74924 .29622 .75546 .27394 .75202 .26886 Mtetra
.976 .775 .569 r
.75202 .26886 .75546 .27394 .76139 .24906 .75798 .24379 Mtetra
.929 .561 .294 r
.09605 .40184 .10042 .40546 .10385 .42193 .09946 .41832 Mtetra
.923 .543 .263 r
.09946 .41832 .10385 .42193 .10754 .43702 .10313 .43341 Mtetra
.894 .472 .15 r
.10313 .43341 .10754 .43702 .11177 .44843 .10735 .44481 Mtetra
.829 .358 0 r
.10735 .44481 .11177 .44843 .11642 .45693 .11199 .4533 Mtetra
.723 .212 0 r
.11199 .4533 .11642 .45693 .12136 .46348 .11693 .45984 Mtetra
0 .344 .791 r
.11693 .45984 .12136 .46348 .1268 .46628 .12237 .46263 Mtetra
.104 .509 .907 r
.12237 .46263 .1268 .46628 .13239 .46806 .12796 .46439 Mtetra
.371 .658 .968 r
.12796 .46439 .13239 .46806 .13817 .46847 .13375 .46479 Mtetra
.517 .722 .966 r
.13375 .46479 .13817 .46847 .14409 .46783 .13967 .46414 Mtetra
.553 .735 .96 r
.13967 .46414 .14409 .46783 .15007 .46686 .14566 .46316 Mtetra
.592 .748 .952 r
.14566 .46316 .15007 .46686 .15611 .4655 .15171 .46179 Mtetra
.603 .752 .949 r
.15171 .46179 .15611 .4655 .16219 .464 .15779 .46028 Mtetra
.609 .754 .947 r
.15779 .46028 .16219 .464 .16828 .46244 .1639 .45871 Mtetra
.613 .755 .946 r
.1639 .45871 .16828 .46244 .1744 .46082 .17002 .45708 Mtetra
.614 .755 .946 r
.17002 .45708 .1744 .46082 .18054 .45919 .17617 .45544 Mtetra
.17617 .45544 .18054 .45919 .18669 .45754 .18233 .45379 Mtetra
.18233 .45379 .18669 .45754 .19286 .4559 .18851 .45214 Mtetra
.18851 .45214 .19286 .4559 .19905 .45426 .1947 .45049 Mtetra
.1947 .45049 .19905 .45426 .20525 .45261 .20091 .44883 Mtetra
.613 .755 .946 r
.20091 .44883 .20525 .45261 .21147 .45096 .20714 .44718 Mtetra
.20714 .44718 .21147 .45096 .21771 .44931 .21339 .44552 Mtetra
.21339 .44552 .21771 .44931 .22396 .44766 .21965 .44386 Mtetra
.612 .755 .946 r
.21965 .44386 .22396 .44766 .23023 .44601 .22592 .4422 Mtetra
.612 .755 .947 r
.22592 .4422 .23023 .44601 .23652 .44436 .23222 .44054 Mtetra
.23222 .44054 .23652 .44436 .24282 .44271 .23853 .43888 Mtetra
.611 .755 .947 r
.23853 .43888 .24282 .44271 .24914 .44106 .24486 .43722 Mtetra
.24486 .43722 .24914 .44106 .25548 .43941 .25121 .43556 Mtetra
.25121 .43556 .25548 .43941 .26183 .43775 .25757 .4339 Mtetra
.61 .755 .947 r
.25757 .4339 .26183 .43775 .2682 .4361 .26395 .43224 Mtetra
.609 .754 .947 r
.26395 .43224 .2682 .4361 .27459 .43445 .27035 .43058 Mtetra
.609 .755 .948 r
.27035 .43058 .27459 .43445 .281 .43279 .27676 .42892 Mtetra
.27676 .42892 .281 .43279 .28742 .43114 .2832 .42726 Mtetra
.608 .754 .948 r
.2832 .42726 .28742 .43114 .29386 .42949 .28965 .4256 Mtetra
.28965 .4256 .29386 .42949 .30032 .42784 .29611 .42394 Mtetra
.607 .754 .948 r
.29611 .42394 .30032 .42784 .3068 .42619 .3026 .42229 Mtetra
.3026 .42229 .3068 .42619 .31329 .42454 .3091 .42063 Mtetra
.607 .754 .949 r
.3091 .42063 .31329 .42454 .31981 .42289 .31563 .41897 Mtetra
.605 .754 .949 r
.31563 .41897 .31981 .42289 .32634 .42126 .32217 .41733 Mtetra
.32217 .41733 .32634 .42126 .33289 .41961 .32872 .41568 Mtetra
.32872 .41568 .33289 .41961 .33945 .41796 .3353 .41402 Mtetra
.604 .754 .95 r
.3353 .41402 .33945 .41796 .34604 .41633 .3419 .41238 Mtetra
.3419 .41238 .34604 .41633 .35264 .41469 .34851 .41074 Mtetra
.34851 .41074 .35264 .41469 .35927 .41305 .35514 .40909 Mtetra
.602 .753 .95 r
.35514 .40909 .35927 .41305 .36591 .41143 .36179 .40745 Mtetra
.36179 .40745 .36591 .41143 .37257 .4098 .36846 .40582 Mtetra
.601 .753 .95 r
.36846 .40582 .37257 .4098 .37925 .40817 .37515 .40418 Mtetra
.6 .753 .951 r
.37515 .40418 .37925 .40817 .38595 .40655 .38186 .40255 Mtetra
.599 .753 .951 r
.38186 .40255 .38595 .40655 .39267 .40494 .38859 .40093 Mtetra
.38859 .40093 .39267 .40494 .3994 .40332 .39534 .39931 Mtetra
.598 .753 .952 r
.39534 .39931 .3994 .40332 .40616 .40171 .4021 .39769 Mtetra
.597 .752 .952 r
.4021 .39769 .40616 .40171 .41294 .40011 .40889 .39608 Mtetra
.596 .752 .952 r
.40889 .39608 .41294 .40011 .41973 .3985 .4157 .39447 Mtetra
.4157 .39447 .41973 .3985 .42655 .39691 .42252 .39287 Mtetra
.594 .752 .953 r
.42252 .39287 .42655 .39691 .43338 .39532 .42937 .39127 Mtetra
.42937 .39127 .43338 .39532 .44024 .39374 .43624 .38968 Mtetra
.593 .752 .953 r
.43624 .38968 .44024 .39374 .44712 .39215 .44312 .38809 Mtetra
.592 .751 .954 r
.44312 .38809 .44712 .39215 .45401 .39059 .45003 .38652 Mtetra
.591 .751 .954 r
.45003 .38652 .45401 .39059 .46093 .38902 .45696 .38495 Mtetra
.59 .751 .954 r
.45696 .38495 .46093 .38902 .46787 .38746 .46391 .38338 Mtetra
.588 .751 .955 r
.46391 .38338 .46787 .38746 .47483 .38592 .47088 .38183 Mtetra
.588 .75 .955 r
.47088 .38183 .47483 .38592 .48181 .38438 .47787 .38028 Mtetra
.587 .75 .955 r
.47787 .38028 .48181 .38438 .48881 .38284 .48488 .37874 Mtetra
.585 .75 .956 r
.48488 .37874 .48881 .38284 .49583 .38132 .49192 .37721 Mtetra
.584 .75 .956 r
.49192 .37721 .49583 .38132 .50288 .3798 .49897 .37569 Mtetra
.583 .749 .956 r
.49897 .37569 .50288 .3798 .50994 .3783 .50605 .37418 Mtetra
.581 .749 .957 r
.50605 .37418 .50994 .3783 .51703 .3768 .51315 .37268 Mtetra
.58 .749 .957 r
.51315 .37268 .51703 .3768 .52414 .37532 .52027 .37119 Mtetra
.578 .748 .958 r
.52027 .37119 .52414 .37532 .53128 .37385 .52742 .36972 Mtetra
.577 .748 .958 r
.52742 .36972 .53128 .37385 .53843 .37239 .53459 .36825 Mtetra
.576 .748 .958 r
.53459 .36825 .53843 .37239 .54561 .37094 .54178 .36679 Mtetra
.574 .747 .959 r
.54178 .36679 .54561 .37094 .55282 .36951 .54899 .36536 Mtetra
.573 .747 .959 r
.54899 .36536 .55282 .36951 .56004 .36809 .55623 .36393 Mtetra
.571 .746 .96 r
.55623 .36393 .56004 .36809 .56729 .36669 .56349 .36252 Mtetra
.569 .746 .96 r
.56349 .36252 .56729 .36669 .57457 .3653 .57078 .36113 Mtetra
.568 .745 .961 r
.57078 .36113 .57457 .3653 .58186 .36393 .57809 .35975 Mtetra
.565 .745 .961 r
.57809 .35975 .58186 .36393 .58919 .36257 .58542 .35839 Mtetra
.563 .744 .962 r
.58542 .35839 .58919 .36257 .59653 .36123 .59278 .35705 Mtetra
.561 .744 .962 r
.59278 .35705 .59653 .36123 .6039 .35991 .60017 .35573 Mtetra
.559 .743 .963 r
.60017 .35573 .6039 .35991 .6113 .35862 .60758 .35443 Mtetra
.557 .742 .963 r
.60758 .35443 .6113 .35862 .61873 .35734 .61501 .35315 Mtetra
.555 .742 .964 r
.61501 .35315 .61873 .35734 .62617 .35608 .62248 .35188 Mtetra
.552 .741 .964 r
.62248 .35188 .62617 .35608 .63365 .35486 .62996 .35065 Mtetra
.55 .74 .964 r
.62996 .35065 .63365 .35486 .64115 .35364 .63748 .34943 Mtetra
.547 .739 .965 r
.63748 .34943 .64115 .35364 .64868 .35246 .64502 .34825 Mtetra
.545 .739 .966 r
.64502 .34825 .64868 .35246 .65624 .3513 .65259 .34708 Mtetra
.543 .738 .966 r
.65259 .34708 .65624 .3513 .66382 .35015 .66019 .34593 Mtetra
.66019 .34593 .66382 .35015 .67143 .349 .66782 .34478 Mtetra
.545 .74 .966 r
.66782 .34478 .67143 .349 .67907 .34781 .67547 .34358 Mtetra
.551 .743 .966 r
.67547 .34358 .67907 .34781 .68673 .34655 .68314 .34232 Mtetra
.577 .756 .962 r
.68314 .34232 .68673 .34655 .6944 .34497 .69082 .34072 Mtetra
.6 .765 .958 r
.69082 .34072 .6944 .34497 .70208 .34308 .69851 .33881 Mtetra
.667 .792 .941 r
.69851 .33881 .70208 .34308 .70972 .34021 .70617 .33589 Mtetra
.746 .817 .908 r
.70617 .33589 .70972 .34021 .71729 .33586 .71376 .33149 Mtetra
.791 .826 .879 r
.71376 .33149 .71729 .33586 .72481 .33041 .72129 .32595 Mtetra
.898 .832 .773 r
.72129 .32595 .72481 .33041 .73204 .32048 .72853 .31589 Mtetra
.928 .822 .72 r
.72853 .31589 .73204 .32048 .73907 .3079 .73558 .30315 Mtetra
.954 .806 .658 r
.73558 .30315 .73907 .3079 .74579 .29133 .74231 .2864 Mtetra
.972 .784 .591 r
.74231 .2864 .74579 .29133 .75202 .26886 .74857 .26373 Mtetra
.976 .774 .568 r
.74857 .26373 .75202 .26886 .75798 .24379 .75455 .23847 Mtetra
.929 .56 .294 r
.09166 .39821 .09605 .40184 .09946 .41832 .09505 .41469 Mtetra
.923 .543 .263 r
.09505 .41469 .09946 .41832 .10313 .43341 .0987 .42979 Mtetra
.894 .472 .15 r
.0987 .42979 .10313 .43341 .10735 .44481 .10291 .44118 Mtetra
.829 .357 0 r
.10291 .44118 .10735 .44481 .11199 .4533 .10754 .44966 Mtetra
.721 .21 0 r
.10754 .44966 .11199 .4533 .11693 .45984 .11247 .45618 Mtetra
0 .346 .792 r
.11247 .45618 .11693 .45984 .12237 .46263 .11792 .45895 Mtetra
.106 .51 .907 r
.11792 .45895 .12237 .46263 .12796 .46439 .12351 .4607 Mtetra
.372 .659 .969 r
.12351 .4607 .12796 .46439 .13375 .46479 .1293 .46108 Mtetra
.517 .722 .966 r
.1293 .46108 .13375 .46479 .13967 .46414 .13524 .46042 Mtetra
.554 .735 .96 r
.13524 .46042 .13967 .46414 .14566 .46316 .14123 .45944 Mtetra
.592 .748 .952 r
.14123 .45944 .14566 .46316 .15171 .46179 .14729 .45805 Mtetra
.603 .752 .949 r
.14729 .45805 .15171 .46179 .15779 .46028 .15338 .45654 Mtetra
.609 .753 .947 r
.15338 .45654 .15779 .46028 .1639 .45871 .15949 .45496 Mtetra
.613 .755 .946 r
.15949 .45496 .1639 .45871 .17002 .45708 .16563 .45332 Mtetra
.614 .755 .946 r
.16563 .45332 .17002 .45708 .17617 .45544 .17178 .45168 Mtetra
.17178 .45168 .17617 .45544 .18233 .45379 .17795 .45002 Mtetra
.17795 .45002 .18233 .45379 .18851 .45214 .18413 .44836 Mtetra
.18413 .44836 .18851 .45214 .1947 .45049 .19034 .4467 Mtetra
.19034 .4467 .1947 .45049 .20091 .44883 .19656 .44503 Mtetra
.613 .755 .946 r
.19656 .44503 .20091 .44883 .20714 .44718 .20279 .44337 Mtetra
.20279 .44337 .20714 .44718 .21339 .44552 .20904 .44171 Mtetra
.20904 .44171 .21339 .44552 .21965 .44386 .21531 .44004 Mtetra
.612 .755 .946 r
.21531 .44004 .21965 .44386 .22592 .4422 .2216 .43837 Mtetra
.612 .755 .947 r
.2216 .43837 .22592 .4422 .23222 .44054 .2279 .43671 Mtetra
.2279 .43671 .23222 .44054 .23853 .43888 .23422 .43504 Mtetra
.611 .755 .947 r
.23422 .43504 .23853 .43888 .24486 .43722 .24056 .43337 Mtetra
.24056 .43337 .24486 .43722 .25121 .43556 .24691 .4317 Mtetra
.24691 .4317 .25121 .43556 .25757 .4339 .25329 .43003 Mtetra
.61 .755 .947 r
.25329 .43003 .25757 .4339 .26395 .43224 .25968 .42836 Mtetra
.609 .754 .948 r
.25968 .42836 .26395 .43224 .27035 .43058 .26608 .4267 Mtetra
.609 .755 .948 r
.26608 .4267 .27035 .43058 .27676 .42892 .27251 .42503 Mtetra
.27251 .42503 .27676 .42892 .2832 .42726 .27895 .42336 Mtetra
.608 .754 .948 r
.27895 .42336 .2832 .42726 .28965 .4256 .28541 .42169 Mtetra
.28541 .42169 .28965 .4256 .29611 .42394 .29189 .42003 Mtetra
.607 .754 .948 r
.29189 .42003 .29611 .42394 .3026 .42229 .29838 .41837 Mtetra
.29838 .41837 .3026 .42229 .3091 .42063 .30489 .4167 Mtetra
.606 .754 .949 r
.30489 .4167 .3091 .42063 .31563 .41897 .31143 .41504 Mtetra
.605 .754 .949 r
.31143 .41504 .31563 .41897 .32217 .41733 .31797 .41338 Mtetra
.31797 .41338 .32217 .41733 .32872 .41568 .32454 .41172 Mtetra
.32454 .41172 .32872 .41568 .3353 .41402 .33113 .41006 Mtetra
.604 .754 .95 r
.33113 .41006 .3353 .41402 .3419 .41238 .33773 .40841 Mtetra
.603 .754 .95 r
.33773 .40841 .3419 .41238 .34851 .41074 .34436 .40676 Mtetra
.34436 .40676 .34851 .41074 .35514 .40909 .351 .4051 Mtetra
.602 .753 .95 r
.351 .4051 .35514 .40909 .36179 .40745 .35766 .40346 Mtetra
.601 .753 .95 r
.35766 .40346 .36179 .40745 .36846 .40582 .36434 .40182 Mtetra
.601 .753 .951 r
.36434 .40182 .36846 .40582 .37515 .40418 .37104 .40017 Mtetra
.6 .753 .951 r
.37104 .40017 .37515 .40418 .38186 .40255 .37776 .39854 Mtetra
.599 .753 .951 r
.37776 .39854 .38186 .40255 .38859 .40093 .3845 .39691 Mtetra
.3845 .39691 .38859 .40093 .39534 .39931 .39125 .39528 Mtetra
.598 .753 .952 r
.39125 .39528 .39534 .39931 .4021 .39769 .39803 .39365 Mtetra
.597 .752 .952 r
.39803 .39365 .4021 .39769 .40889 .39608 .40483 .39204 Mtetra
.596 .752 .952 r
.40483 .39204 .40889 .39608 .4157 .39447 .41164 .39042 Mtetra
.41164 .39042 .4157 .39447 .42252 .39287 .41848 .38881 Mtetra
.594 .752 .953 r
.41848 .38881 .42252 .39287 .42937 .39127 .42534 .38721 Mtetra
.42534 .38721 .42937 .39127 .43624 .38968 .43221 .38561 Mtetra
.593 .752 .953 r
.43221 .38561 .43624 .38968 .44312 .38809 .43911 .38401 Mtetra
.591 .751 .954 r
.43911 .38401 .44312 .38809 .45003 .38652 .44603 .38243 Mtetra
.44603 .38243 .45003 .38652 .45696 .38495 .45297 .38086 Mtetra
.59 .751 .954 r
.45297 .38086 .45696 .38495 .46391 .38338 .45993 .37928 Mtetra
.588 .75 .955 r
.45993 .37928 .46391 .38338 .47088 .38183 .46691 .37772 Mtetra
.46691 .37772 .47088 .38183 .47787 .38028 .47391 .37617 Mtetra
.587 .75 .955 r
.47391 .37617 .47787 .38028 .48488 .37874 .48094 .37462 Mtetra
.585 .75 .956 r
.48094 .37462 .48488 .37874 .49192 .37721 .48798 .37308 Mtetra
.584 .749 .956 r
.48798 .37308 .49192 .37721 .49897 .37569 .49505 .37155 Mtetra
.583 .749 .956 r
.49505 .37155 .49897 .37569 .50605 .37418 .50214 .37004 Mtetra
.581 .749 .957 r
.50214 .37004 .50605 .37418 .51315 .37268 .50925 .36853 Mtetra
.58 .748 .957 r
.50925 .36853 .51315 .37268 .52027 .37119 .51639 .36703 Mtetra
.578 .748 .958 r
.51639 .36703 .52027 .37119 .52742 .36972 .52354 .36555 Mtetra
.577 .748 .958 r
.52354 .36555 .52742 .36972 .53459 .36825 .53072 .36408 Mtetra
.576 .747 .958 r
.53072 .36408 .53459 .36825 .54178 .36679 .53793 .36262 Mtetra
.574 .747 .959 r
.53793 .36262 .54178 .36679 .54899 .36536 .54515 .36118 Mtetra
.573 .746 .959 r
.54515 .36118 .54899 .36536 .55623 .36393 .5524 .35975 Mtetra
.571 .746 .959 r
.5524 .35975 .55623 .36393 .56349 .36252 .55968 .35833 Mtetra
.569 .745 .96 r
.55968 .35833 .56349 .36252 .57078 .36113 .56697 .35693 Mtetra
.567 .745 .96 r
.56697 .35693 .57078 .36113 .57809 .35975 .5743 .35555 Mtetra
.565 .744 .961 r
.5743 .35555 .57809 .35975 .58542 .35839 .58164 .35418 Mtetra
.563 .744 .961 r
.58164 .35418 .58542 .35839 .59278 .35705 .58901 .35283 Mtetra
.561 .743 .962 r
.58901 .35283 .59278 .35705 .60017 .35573 .59641 .3515 Mtetra
.558 .742 .962 r
.59641 .3515 .60017 .35573 .60758 .35443 .60383 .3502 Mtetra
.557 .742 .963 r
.60383 .3502 .60758 .35443 .61501 .35315 .61128 .34891 Mtetra
.555 .741 .963 r
.61128 .34891 .61501 .35315 .62248 .35188 .61876 .34765 Mtetra
.552 .74 .964 r
.61876 .34765 .62248 .35188 .62996 .35065 .62626 .34641 Mtetra
.55 .739 .964 r
.62626 .34641 .62996 .35065 .63748 .34943 .63379 .34519 Mtetra
.547 .738 .965 r
.63379 .34519 .63748 .34943 .64502 .34825 .64134 .344 Mtetra
.545 .738 .965 r
.64134 .344 .64502 .34825 .65259 .34708 .64893 .34283 Mtetra
.543 .737 .965 r
.64893 .34283 .65259 .34708 .66019 .34593 .65654 .34167 Mtetra
.543 .737 .966 r
.65654 .34167 .66019 .34593 .66782 .34478 .66418 .34051 Mtetra
.546 .739 .965 r
.66418 .34051 .66782 .34478 .67547 .34358 .67184 .33931 Mtetra
.551 .742 .965 r
.67184 .33931 .67547 .34358 .68314 .34232 .67953 .33803 Mtetra
.579 .754 .961 r
.67953 .33803 .68314 .34232 .69082 .34072 .68723 .33641 Mtetra
.602 .764 .957 r
.68723 .33641 .69082 .34072 .69851 .33881 .69493 .33448 Mtetra
.669 .791 .939 r
.69493 .33448 .69851 .33881 .70617 .33589 .7026 .33152 Mtetra
.748 .816 .905 r
.7026 .33152 .70617 .33589 .71376 .33149 .71021 .32704 Mtetra
.793 .824 .877 r
.71021 .32704 .71376 .33149 .72129 .32595 .71775 .32141 Mtetra
.899 .83 .77 r
.71775 .32141 .72129 .32595 .72853 .31589 .72501 .31121 Mtetra
.928 .82 .718 r
.72501 .31121 .72853 .31589 .73558 .30315 .73207 .29831 Mtetra
.954 .804 .656 r
.73207 .29831 .73558 .30315 .74231 .2864 .73882 .28137 Mtetra
.972 .783 .59 r
.73882 .28137 .74231 .2864 .74857 .26373 .7451 .2585 Mtetra
.975 .773 .567 r
.7451 .2585 .74857 .26373 .75455 .23847 .7511 .23306 Mtetra
.928 .56 .294 r
.08725 .39458 .09166 .39821 .09505 .41469 .09062 .41106 Mtetra
.923 .542 .263 r
.09062 .41106 .09505 .41469 .0987 .42979 .09425 .42616 Mtetra
.894 .472 .149 r
.09425 .42616 .0987 .42979 .10291 .44118 .09844 .43754 Mtetra
.828 .356 0 r
.09844 .43754 .10291 .44118 .10754 .44966 .10307 .446 Mtetra
.72 .209 0 r
.10307 .446 .10754 .44966 .11247 .45618 .108 .45251 Mtetra
0 .348 .794 r
.108 .45251 .11247 .45618 .11792 .45895 .11344 .45526 Mtetra
.108 .511 .908 r
.11344 .45526 .11792 .45895 .12351 .4607 .11905 .457 Mtetra
.373 .659 .969 r
.11905 .457 .12351 .4607 .1293 .46108 .12484 .45737 Mtetra
.518 .723 .966 r
.12484 .45737 .1293 .46108 .13524 .46042 .13078 .4567 Mtetra
.554 .736 .96 r
.13078 .4567 .13524 .46042 .14123 .45944 .13678 .4557 Mtetra
.592 .748 .952 r
.13678 .4557 .14123 .45944 .14729 .45805 .14285 .45431 Mtetra
.603 .752 .949 r
.14285 .45431 .14729 .45805 .15338 .45654 .14894 .45278 Mtetra
.609 .754 .947 r
.14894 .45278 .15338 .45654 .15949 .45496 .15506 .45119 Mtetra
.613 .755 .946 r
.15506 .45119 .15949 .45496 .16563 .45332 .16121 .44955 Mtetra
.614 .755 .946 r
.16121 .44955 .16563 .45332 .17178 .45168 .16737 .44789 Mtetra
.16737 .44789 .17178 .45168 .17795 .45002 .17354 .44623 Mtetra
.17354 .44623 .17795 .45002 .18413 .44836 .17974 .44456 Mtetra
.17974 .44456 .18413 .44836 .19034 .4467 .18595 .44289 Mtetra
.18595 .44289 .19034 .4467 .19656 .44503 .19218 .44122 Mtetra
.613 .755 .946 r
.19218 .44122 .19656 .44503 .20279 .44337 .19842 .43955 Mtetra
.19842 .43955 .20279 .44337 .20904 .44171 .20468 .43788 Mtetra
.20468 .43788 .20904 .44171 .21531 .44004 .21096 .4362 Mtetra
.612 .755 .946 r
.21096 .4362 .21531 .44004 .2216 .43837 .21725 .43453 Mtetra
.612 .755 .947 r
.21725 .43453 .2216 .43837 .2279 .43671 .22357 .43285 Mtetra
.22357 .43285 .2279 .43671 .23422 .43504 .2299 .43117 Mtetra
.611 .755 .947 r
.2299 .43117 .23422 .43504 .24056 .43337 .23624 .4295 Mtetra
.61 .754 .947 r
.23624 .4295 .24056 .43337 .24691 .4317 .2426 .42782 Mtetra
.61 .755 .947 r
.2426 .42782 .24691 .4317 .25329 .43003 .24899 .42615 Mtetra
.24899 .42615 .25329 .43003 .25968 .42836 .25538 .42446 Mtetra
.609 .754 .947 r
.25538 .42446 .25968 .42836 .26608 .4267 .2618 .42279 Mtetra
.2618 .42279 .26608 .4267 .27251 .42503 .26823 .42112 Mtetra
.609 .754 .948 r
.26823 .42112 .27251 .42503 .27895 .42336 .27468 .41943 Mtetra
.608 .754 .948 r
.27468 .41943 .27895 .42336 .28541 .42169 .28115 .41776 Mtetra
.28115 .41776 .28541 .42169 .29189 .42003 .28764 .41609 Mtetra
.607 .754 .948 r
.28764 .41609 .29189 .42003 .29838 .41837 .29414 .41442 Mtetra
.29414 .41442 .29838 .41837 .30489 .4167 .30066 .41275 Mtetra
.606 .754 .948 r
.30066 .41275 .30489 .4167 .31143 .41504 .3072 .41107 Mtetra
.605 .754 .949 r
.3072 .41107 .31143 .41504 .31797 .41338 .31376 .40941 Mtetra
.31376 .40941 .31797 .41338 .32454 .41172 .32034 .40774 Mtetra
.32034 .40774 .32454 .41172 .33113 .41006 .32694 .40607 Mtetra
.604 .753 .949 r
.32694 .40607 .33113 .41006 .33773 .40841 .33355 .40442 Mtetra
.603 .753 .949 r
.33355 .40442 .33773 .40841 .34436 .40676 .34018 .40275 Mtetra
.603 .753 .95 r
.34018 .40275 .34436 .40676 .351 .4051 .34684 .40109 Mtetra
.602 .753 .95 r
.34684 .40109 .351 .4051 .35766 .40346 .35351 .39944 Mtetra
.601 .753 .95 r
.35351 .39944 .35766 .40346 .36434 .40182 .3602 .39779 Mtetra
.3602 .39779 .36434 .40182 .37104 .40017 .36691 .39614 Mtetra
.6 .752 .951 r
.36691 .39614 .37104 .40017 .37776 .39854 .37363 .3945 Mtetra
.599 .752 .951 r
.37363 .3945 .37776 .39854 .3845 .39691 .38038 .39286 Mtetra
.38038 .39286 .3845 .39691 .39125 .39528 .38715 .39122 Mtetra
.598 .752 .951 r
.38715 .39122 .39125 .39528 .39803 .39365 .39394 .38959 Mtetra
.597 .752 .952 r
.39394 .38959 .39803 .39365 .40483 .39204 .40074 .38796 Mtetra
.596 .751 .952 r
.40074 .38796 .40483 .39204 .41164 .39042 .40757 .38634 Mtetra
.40757 .38634 .41164 .39042 .41848 .38881 .41442 .38472 Mtetra
.594 .751 .952 r
.41442 .38472 .41848 .38881 .42534 .38721 .42129 .38311 Mtetra
.594 .751 .953 r
.42129 .38311 .42534 .38721 .43221 .38561 .42817 .3815 Mtetra
.593 .751 .953 r
.42817 .3815 .43221 .38561 .43911 .38401 .43508 .3799 Mtetra
.591 .75 .953 r
.43508 .3799 .43911 .38401 .44603 .38243 .44201 .37831 Mtetra
.44201 .37831 .44603 .38243 .45297 .38086 .44896 .37672 Mtetra
.59 .75 .954 r
.44896 .37672 .45297 .38086 .45993 .37928 .45593 .37514 Mtetra
.588 .749 .954 r
.45593 .37514 .45993 .37928 .46691 .37772 .46292 .37357 Mtetra
.46292 .37357 .46691 .37772 .47391 .37617 .46994 .37201 Mtetra
.587 .749 .954 r
.46994 .37201 .47391 .37617 .48094 .37462 .47697 .37045 Mtetra
.585 .748 .955 r
.47697 .37045 .48094 .37462 .48798 .37308 .48403 .36891 Mtetra
.584 .748 .955 r
.48403 .36891 .48798 .37308 .49505 .37155 .49111 .36737 Mtetra
.583 .748 .955 r
.49111 .36737 .49505 .37155 .50214 .37004 .49821 .36584 Mtetra
.582 .747 .956 r
.49821 .36584 .50214 .37004 .50925 .36853 .50533 .36433 Mtetra
.581 .747 .956 r
.50533 .36433 .50925 .36853 .51639 .36703 .51248 .36282 Mtetra
.579 .746 .956 r
.51248 .36282 .51639 .36703 .52354 .36555 .51965 .36133 Mtetra
.578 .746 .957 r
.51965 .36133 .52354 .36555 .53072 .36408 .52684 .35985 Mtetra
.576 .745 .957 r
.52684 .35985 .53072 .36408 .53793 .36262 .53405 .35838 Mtetra
.574 .745 .957 r
.53405 .35838 .53793 .36262 .54515 .36118 .54129 .35694 Mtetra
.573 .744 .958 r
.54129 .35694 .54515 .36118 .5524 .35975 .54855 .35549 Mtetra
.572 .744 .958 r
.54855 .35549 .5524 .35975 .55968 .35833 .55584 .35407 Mtetra
.569 .743 .958 r
.55584 .35407 .55968 .35833 .56697 .35693 .56315 .35266 Mtetra
.568 .742 .959 r
.56315 .35266 .56697 .35693 .5743 .35555 .57048 .35127 Mtetra
.566 .741 .959 r
.57048 .35127 .5743 .35555 .58164 .35418 .57784 .34989 Mtetra
.564 .741 .959 r
.57784 .34989 .58164 .35418 .58901 .35283 .58523 .34854 Mtetra
.562 .74 .96 r
.58523 .34854 .58901 .35283 .59641 .3515 .59263 .3472 Mtetra
.56 .739 .96 r
.59263 .3472 .59641 .3515 .60383 .3502 .60007 .34589 Mtetra
.558 .738 .96 r
.60007 .34589 .60383 .3502 .61128 .34891 .60753 .34459 Mtetra
.556 .738 .961 r
.60753 .34459 .61128 .34891 .61876 .34765 .61502 .34331 Mtetra
.553 .736 .961 r
.61502 .34331 .61876 .34765 .62626 .34641 .62253 .34207 Mtetra
.552 .736 .961 r
.62253 .34207 .62626 .34641 .63379 .34519 .63008 .34084 Mtetra
.549 .734 .962 r
.63008 .34084 .63379 .34519 .64134 .344 .63764 .33963 Mtetra
.547 .733 .962 r
.63764 .33963 .64134 .344 .64893 .34283 .64524 .33845 Mtetra
.545 .733 .962 r
.64524 .33845 .64893 .34283 .65654 .34167 .65286 .33729 Mtetra
.65286 .33729 .65654 .34167 .66418 .34051 .66052 .33611 Mtetra
.548 .734 .962 r
.66052 .33611 .66418 .34051 .67184 .33931 .66819 .3349 Mtetra
.554 .737 .961 r
.66819 .3349 .67184 .33931 .67953 .33803 .67589 .3336 Mtetra
.582 .749 .957 r
.67589 .3336 .67953 .33803 .68723 .33641 .6836 .33196 Mtetra
.605 .759 .952 r
.6836 .33196 .68723 .33641 .69493 .33448 .69132 .32999 Mtetra
.672 .785 .934 r
.69132 .32999 .69493 .33448 .7026 .33152 .69901 .32697 Mtetra
.749 .809 .9 r
.69901 .32697 .7026 .33152 .71021 .32704 .70662 .32241 Mtetra
.794 .817 .871 r
.70662 .32241 .71021 .32704 .71775 .32141 .71418 .31669 Mtetra
.898 .824 .766 r
.71418 .31669 .71775 .32141 .72501 .31121 .72145 .30634 Mtetra
.927 .814 .715 r
.72145 .30634 .72501 .31121 .73207 .29831 .72853 .29327 Mtetra
.952 .799 .654 r
.72853 .29327 .73207 .29831 .73882 .28137 .7353 .27614 Mtetra
.97 .779 .59 r
.7353 .27614 .73882 .28137 .7451 .2585 .74159 .25308 Mtetra
.974 .77 .567 r
.74159 .25308 .7451 .2585 .7511 .23306 .74762 .22746 Mtetra
.928 .56 .294 r
.08282 .39092 .08725 .39458 .09062 .41106 .08617 .40741 Mtetra
.923 .542 .263 r
.08617 .40741 .09062 .41106 .09425 .42616 .08978 .42251 Mtetra
.893 .471 .149 r
.08978 .42251 .09425 .42616 .09844 .43754 .09396 .43388 Mtetra
.828 .355 0 r
.09396 .43388 .09844 .43754 .10307 .446 .09858 .44232 Mtetra
.719 .207 0 r
.09858 .44232 .10307 .446 .108 .45251 .10351 .44882 Mtetra
0 .35 .795 r
.10351 .44882 .108 .45251 .11344 .45526 .10895 .45156 Mtetra
.111 .513 .909 r
.10895 .45156 .11344 .45526 .11905 .457 .11456 .45327 Mtetra
.374 .66 .969 r
.11456 .45327 .11905 .457 .12484 .45737 .12036 .45363 Mtetra
.518 .723 .966 r
.12036 .45363 .12484 .45737 .13078 .4567 .12631 .45295 Mtetra
.554 .736 .96 r
.12631 .45295 .13078 .4567 .13678 .4557 .13231 .45194 Mtetra
.592 .748 .952 r
.13231 .45194 .13678 .4557 .14285 .45431 .13838 .45054 Mtetra
.603 .752 .949 r
.13838 .45054 .14285 .45431 .14894 .45278 .14449 .44901 Mtetra
.609 .753 .947 r
.14449 .44901 .14894 .45278 .15506 .45119 .15062 .44741 Mtetra
.613 .755 .946 r
.15062 .44741 .15506 .45119 .16121 .44955 .15677 .44576 Mtetra
.15677 .44576 .16121 .44955 .16737 .44789 .16294 .44409 Mtetra
.614 .755 .945 r
.16294 .44409 .16737 .44789 .17354 .44623 .16912 .44242 Mtetra
.614 .755 .946 r
.16912 .44242 .17354 .44623 .17974 .44456 .17532 .44074 Mtetra
.17532 .44074 .17974 .44456 .18595 .44289 .18154 .43907 Mtetra
.18154 .43907 .18595 .44289 .19218 .44122 .18778 .43738 Mtetra
.613 .755 .946 r
.18778 .43738 .19218 .44122 .19842 .43955 .19403 .4357 Mtetra
.19403 .4357 .19842 .43955 .20468 .43788 .2003 .43402 Mtetra
.2003 .43402 .20468 .43788 .21096 .4362 .20659 .43234 Mtetra
.612 .755 .946 r
.20659 .43234 .21096 .4362 .21725 .43453 .21289 .43066 Mtetra
.612 .754 .946 r
.21289 .43066 .21725 .43453 .22357 .43285 .21921 .42897 Mtetra
.612 .755 .946 r
.21921 .42897 .22357 .43285 .2299 .43117 .22555 .42729 Mtetra
.611 .754 .947 r
.22555 .42729 .2299 .43117 .23624 .4295 .2319 .4256 Mtetra
.61 .754 .947 r
.2319 .4256 .23624 .4295 .2426 .42782 .23827 .42392 Mtetra
.23827 .42392 .2426 .42782 .24899 .42615 .24466 .42223 Mtetra
.24466 .42223 .24899 .42615 .25538 .42446 .25107 .42054 Mtetra
.609 .754 .947 r
.25107 .42054 .25538 .42446 .2618 .42279 .25749 .41886 Mtetra
.25749 .41886 .2618 .42279 .26823 .42112 .26394 .41718 Mtetra
.26394 .41718 .26823 .42112 .27468 .41943 .2704 .41549 Mtetra
.608 .754 .948 r
.2704 .41549 .27468 .41943 .28115 .41776 .27687 .41381 Mtetra
.27687 .41381 .28115 .41776 .28764 .41609 .28337 .41213 Mtetra
.607 .754 .948 r
.28337 .41213 .28764 .41609 .29414 .41442 .28988 .41045 Mtetra
.607 .753 .948 r
.28988 .41045 .29414 .41442 .30066 .41275 .29642 .40877 Mtetra
.606 .753 .948 r
.29642 .40877 .30066 .41275 .3072 .41107 .30297 .40709 Mtetra
.605 .753 .949 r
.30297 .40709 .3072 .41107 .31376 .40941 .30953 .40541 Mtetra
.30953 .40541 .31376 .40941 .32034 .40774 .31612 .40374 Mtetra
.31612 .40374 .32034 .40774 .32694 .40607 .32273 .40206 Mtetra
.604 .753 .949 r
.32273 .40206 .32694 .40607 .33355 .40442 .32935 .40039 Mtetra
.603 .753 .949 r
.32935 .40039 .33355 .40442 .34018 .40275 .33599 .39872 Mtetra
.33599 .39872 .34018 .40275 .34684 .40109 .34265 .39705 Mtetra
.602 .752 .95 r
.34265 .39705 .34684 .40109 .35351 .39944 .34933 .39539 Mtetra
.601 .752 .95 r
.34933 .39539 .35351 .39944 .3602 .39779 .35603 .39373 Mtetra
.35603 .39373 .3602 .39779 .36691 .39614 .36275 .39207 Mtetra
.6 .752 .95 r
.36275 .39207 .36691 .39614 .37363 .3945 .36949 .39042 Mtetra
.599 .752 .95 r
.36949 .39042 .37363 .3945 .38038 .39286 .37625 .38877 Mtetra
.599 .751 .951 r
.37625 .38877 .38038 .39286 .38715 .39122 .38303 .38712 Mtetra
.598 .751 .951 r
.38303 .38712 .38715 .39122 .39394 .38959 .38982 .38548 Mtetra
.597 .751 .951 r
.38982 .38548 .39394 .38959 .40074 .38796 .39664 .38385 Mtetra
.596 .751 .951 r
.39664 .38385 .40074 .38796 .40757 .38634 .40348 .38221 Mtetra
.596 .75 .951 r
.40348 .38221 .40757 .38634 .41442 .38472 .41034 .38059 Mtetra
.595 .75 .952 r
.41034 .38059 .41442 .38472 .42129 .38311 .41721 .37897 Mtetra
.594 .75 .952 r
.41721 .37897 .42129 .38311 .42817 .3815 .42411 .37735 Mtetra
.593 .75 .952 r
.42411 .37735 .42817 .3815 .43508 .3799 .43103 .37574 Mtetra
.592 .749 .952 r
.43103 .37574 .43508 .3799 .44201 .37831 .43797 .37414 Mtetra
.591 .749 .953 r
.43797 .37414 .44201 .37831 .44896 .37672 .44493 .37254 Mtetra
.59 .749 .953 r
.44493 .37254 .44896 .37672 .45593 .37514 .45191 .37095 Mtetra
.589 .748 .953 r
.45191 .37095 .45593 .37514 .46292 .37357 .45892 .36937 Mtetra
.588 .748 .953 r
.45892 .36937 .46292 .37357 .46994 .37201 .46594 .3678 Mtetra
.587 .748 .954 r
.46594 .3678 .46994 .37201 .47697 .37045 .47299 .36623 Mtetra
.585 .747 .954 r
.47299 .36623 .47697 .37045 .48403 .36891 .48005 .36468 Mtetra
.48005 .36468 .48403 .36891 .49111 .36737 .48714 .36314 Mtetra
.583 .746 .954 r
.48714 .36314 .49111 .36737 .49821 .36584 .49426 .3616 Mtetra
.582 .746 .955 r
.49426 .3616 .49821 .36584 .50533 .36433 .50139 .36007 Mtetra
.581 .745 .955 r
.50139 .36007 .50533 .36433 .51248 .36282 .50855 .35856 Mtetra
.579 .745 .955 r
.50855 .35856 .51248 .36282 .51965 .36133 .51573 .35706 Mtetra
.578 .744 .955 r
.51573 .35706 .51965 .36133 .52684 .35985 .52293 .35557 Mtetra
.577 .744 .956 r
.52293 .35557 .52684 .35985 .53405 .35838 .53016 .35409 Mtetra
.575 .743 .956 r
.53016 .35409 .53405 .35838 .54129 .35694 .53741 .35263 Mtetra
.574 .742 .956 r
.53741 .35263 .54129 .35694 .54855 .35549 .54468 .35118 Mtetra
.572 .742 .956 r
.54468 .35118 .54855 .35549 .55584 .35407 .55198 .34974 Mtetra
.57 .741 .957 r
.55198 .34974 .55584 .35407 .56315 .35266 .5593 .34832 Mtetra
.569 .74 .957 r
.5593 .34832 .56315 .35266 .57048 .35127 .56665 .34692 Mtetra
.567 .739 .957 r
.56665 .34692 .57048 .35127 .57784 .34989 .57402 .34553 Mtetra
.565 .739 .957 r
.57402 .34553 .57784 .34989 .58523 .34854 .58142 .34417 Mtetra
.564 .738 .958 r
.58142 .34417 .58523 .34854 .59263 .3472 .58884 .34281 Mtetra
.561 .736 .958 r
.58884 .34281 .59263 .3472 .60007 .34589 .59629 .34149 Mtetra
.56 .736 .958 r
.59629 .34149 .60007 .34589 .60753 .34459 .60376 .34018 Mtetra
.558 .735 .958 r
.60376 .34018 .60753 .34459 .61502 .34331 .61126 .33889 Mtetra
.555 .733 .959 r
.61126 .33889 .61502 .34331 .62253 .34207 .61879 .33763 Mtetra
.553 .732 .959 r
.61879 .33763 .62253 .34207 .63008 .34084 .62634 .33639 Mtetra
.551 .731 .959 r
.62634 .33639 .63008 .34084 .63764 .33963 .63392 .33517 Mtetra
.549 .73 .959 r
.63392 .33517 .63764 .33963 .64524 .33845 .64153 .33397 Mtetra
.547 .729 .959 r
.64153 .33397 .64524 .33845 .65286 .33729 .64917 .33279 Mtetra
.548 .729 .959 r
.64917 .33279 .65286 .33729 .66052 .33611 .65683 .3316 Mtetra
.551 .73 .958 r
.65683 .3316 .66052 .33611 .66819 .3349 .66452 .33036 Mtetra
.557 .733 .957 r
.66452 .33036 .66819 .3349 .67589 .3336 .67223 .32905 Mtetra
.585 .745 .953 r
.67223 .32905 .67589 .3336 .6836 .33196 .67996 .32737 Mtetra
.608 .754 .948 r
.67996 .32737 .6836 .33196 .69132 .32999 .68769 .32536 Mtetra
.675 .78 .929 r
.68769 .32536 .69132 .32999 .69901 .32697 .69539 .32228 Mtetra
.751 .803 .894 r
.69539 .32228 .69901 .32697 .70662 .32241 .70301 .31764 Mtetra
.795 .811 .865 r
.70301 .31764 .70662 .32241 .71418 .31669 .71058 .31181 Mtetra
.897 .819 .762 r
.71058 .31181 .71418 .31669 .72145 .30634 .71787 .30131 Mtetra
.926 .809 .712 r
.71787 .30131 .72145 .30634 .72853 .29327 .72496 .28807 Mtetra
.951 .795 .652 r
.72496 .28807 .72853 .29327 .7353 .27614 .73175 .27075 Mtetra
.969 .776 .589 r
.73175 .27075 .7353 .27614 .74159 .25308 .73807 .2475 Mtetra
.973 .768 .567 r
.73807 .2475 .74159 .25308 .74762 .22746 .74412 .22171 Mtetra
.929 .56 .293 r
.07838 .38724 .08282 .39092 .08617 .40741 .0817 .40373 Mtetra
.923 .542 .262 r
.0817 .40373 .08617 .40741 .08978 .42251 .0853 .41881 Mtetra
.893 .471 .147 r
.0853 .41881 .08978 .42251 .09396 .43388 .08946 .43017 Mtetra
.826 .354 0 r
.08946 .43017 .09396 .43388 .09858 .44232 .09408 .4386 Mtetra
.716 .204 0 r
.09408 .4386 .09858 .44232 .10351 .44882 .099 .44507 Mtetra
0 .354 .8 r
.099 .44507 .10351 .44882 .10895 .45156 .10445 .44779 Mtetra
.118 .515 .911 r
.10445 .44779 .10895 .45156 .11456 .45327 .11005 .44949 Mtetra
.378 .659 .968 r
.11005 .44949 .11456 .45327 .12036 .45363 .11586 .44984 Mtetra
.52 .721 .964 r
.11586 .44984 .12036 .45363 .12631 .45295 .12181 .44914 Mtetra
.556 .734 .958 r
.12181 .44914 .12631 .45295 .13231 .45194 .12783 .44812 Mtetra
.593 .746 .95 r
.12783 .44812 .13231 .45194 .13838 .45054 .13391 .44671 Mtetra
.604 .749 .947 r
.13391 .44671 .13838 .45054 .14449 .44901 .14002 .44517 Mtetra
.61 .751 .945 r
.14002 .44517 .14449 .44901 .15062 .44741 .14616 .44356 Mtetra
.613 .752 .944 r
.14616 .44356 .15062 .44741 .15677 .44576 .15232 .4419 Mtetra
.614 .752 .944 r
.15232 .4419 .15677 .44576 .16294 .44409 .15849 .44022 Mtetra
.615 .752 .944 r
.15849 .44022 .16294 .44409 .16912 .44242 .16469 .43854 Mtetra
.614 .752 .944 r
.16469 .43854 .16912 .44242 .17532 .44074 .1709 .43686 Mtetra
.1709 .43686 .17532 .44074 .18154 .43907 .17712 .43517 Mtetra
.17712 .43517 .18154 .43907 .18778 .43738 .18337 .43348 Mtetra
.18337 .43348 .18778 .43738 .19403 .4357 .18963 .43179 Mtetra
.613 .752 .944 r
.18963 .43179 .19403 .4357 .2003 .43402 .19591 .4301 Mtetra
.19591 .4301 .2003 .43402 .20659 .43234 .2022 .4284 Mtetra
.2022 .4284 .20659 .43234 .21289 .43066 .20851 .42671 Mtetra
.612 .751 .944 r
.20851 .42671 .21289 .43066 .21921 .42897 .21484 .42502 Mtetra
.21484 .42502 .21921 .42897 .22555 .42729 .22119 .42332 Mtetra
.22119 .42332 .22555 .42729 .2319 .4256 .22755 .42162 Mtetra
.611 .751 .944 r
.22755 .42162 .2319 .4256 .23827 .42392 .23393 .41993 Mtetra
.23393 .41993 .23827 .42392 .24466 .42223 .24033 .41824 Mtetra
.24033 .41824 .24466 .42223 .25107 .42054 .24674 .41654 Mtetra
.61 .75 .945 r
.24674 .41654 .25107 .42054 .25749 .41886 .25318 .41485 Mtetra
.25318 .41485 .25749 .41886 .26394 .41718 .25963 .41315 Mtetra
.25963 .41315 .26394 .41718 .2704 .41549 .2661 .41145 Mtetra
.609 .75 .945 r
.2661 .41145 .2704 .41549 .27687 .41381 .27258 .40976 Mtetra
.608 .75 .945 r
.27258 .40976 .27687 .41381 .28337 .41213 .27909 .40807 Mtetra
.27909 .40807 .28337 .41213 .28988 .41045 .28561 .40638 Mtetra
.608 .749 .945 r
.28561 .40638 .28988 .41045 .29642 .40877 .29215 .40468 Mtetra
.607 .749 .945 r
.29215 .40468 .29642 .40877 .30297 .40709 .29871 .40299 Mtetra
.606 .749 .945 r
.29871 .40299 .30297 .40709 .30953 .40541 .30529 .40131 Mtetra
.30529 .40131 .30953 .40541 .31612 .40374 .31188 .39962 Mtetra
.31188 .39962 .31612 .40374 .32273 .40206 .3185 .39793 Mtetra
.605 .748 .946 r
.3185 .39793 .32273 .40206 .32935 .40039 .32513 .39626 Mtetra
.32513 .39626 .32935 .40039 .33599 .39872 .33179 .39457 Mtetra
.33179 .39457 .33599 .39872 .34265 .39705 .33846 .39289 Mtetra
.603 .747 .946 r
.33846 .39289 .34265 .39705 .34933 .39539 .34515 .39122 Mtetra
.34515 .39122 .34933 .39539 .35603 .39373 .35186 .38955 Mtetra
.35186 .38955 .35603 .39373 .36275 .39207 .35859 .38788 Mtetra
.601 .746 .946 r
.35859 .38788 .36275 .39207 .36949 .39042 .36533 .38621 Mtetra
.36533 .38621 .36949 .39042 .37625 .38877 .3721 .38455 Mtetra
.6 .746 .946 r
.3721 .38455 .37625 .38877 .38303 .38712 .37889 .38289 Mtetra
.6 .745 .946 r
.37889 .38289 .38303 .38712 .38982 .38548 .3857 .38124 Mtetra
.599 .745 .946 r
.3857 .38124 .38982 .38548 .39664 .38385 .39252 .37959 Mtetra
.598 .744 .946 r
.39252 .37959 .39664 .38385 .40348 .38221 .39937 .37794 Mtetra
.39937 .37794 .40348 .38221 .41034 .38059 .40624 .3763 Mtetra
.597 .743 .947 r
.40624 .3763 .41034 .38059 .41721 .37897 .41313 .37467 Mtetra
.596 .743 .947 r
.41313 .37467 .41721 .37897 .42411 .37735 .42004 .37304 Mtetra
.595 .743 .947 r
.42004 .37304 .42411 .37735 .43103 .37574 .42697 .37141 Mtetra
.594 .742 .947 r
.42697 .37141 .43103 .37574 .43797 .37414 .43392 .3698 Mtetra
.593 .741 .947 r
.43392 .3698 .43797 .37414 .44493 .37254 .44089 .36819 Mtetra
.44089 .36819 .44493 .37254 .45191 .37095 .44788 .36658 Mtetra
.591 .74 .947 r
.44788 .36658 .45191 .37095 .45892 .36937 .45489 .36499 Mtetra
.45489 .36499 .45892 .36937 .46594 .3678 .46193 .3634 Mtetra
.59 .739 .947 r
.46193 .3634 .46594 .3678 .47299 .36623 .46899 .36181 Mtetra
.588 .738 .947 r
.46899 .36181 .47299 .36623 .48005 .36468 .47606 .36025 Mtetra
.47606 .36025 .48005 .36468 .48714 .36314 .48317 .35868 Mtetra
.587 .737 .947 r
.48317 .35868 .48714 .36314 .49426 .3616 .49029 .35713 Mtetra
.585 .736 .947 r
.49029 .35713 .49426 .3616 .50139 .36007 .49743 .35559 Mtetra
.585 .735 .947 r
.49743 .35559 .50139 .36007 .50855 .35856 .5046 .35405 Mtetra
.583 .734 .947 r
.5046 .35405 .50855 .35856 .51573 .35706 .51179 .35253 Mtetra
.582 .733 .947 r
.51179 .35253 .51573 .35706 .52293 .35557 .51901 .35102 Mtetra
.581 .732 .947 r
.51901 .35102 .52293 .35557 .53016 .35409 .52625 .34952 Mtetra
.579 .731 .947 r
.52625 .34952 .53016 .35409 .53741 .35263 .53351 .34804 Mtetra
.579 .73 .946 r
.53351 .34804 .53741 .35263 .54468 .35118 .54079 .34657 Mtetra
.577 .729 .946 r
.54079 .34657 .54468 .35118 .55198 .34974 .5481 .34511 Mtetra
.576 .728 .946 r
.5481 .34511 .55198 .34974 .5593 .34832 .55543 .34367 Mtetra
.575 .727 .946 r
.55543 .34367 .5593 .34832 .56665 .34692 .56279 .34224 Mtetra
.573 .725 .946 r
.56279 .34224 .56665 .34692 .57402 .34553 .57017 .34083 Mtetra
.572 .724 .945 r
.57017 .34083 .57402 .34553 .58142 .34417 .57758 .33944 Mtetra
.57 .723 .945 r
.57758 .33944 .58142 .34417 .58884 .34281 .58501 .33806 Mtetra
.568 .721 .945 r
.58501 .33806 .58884 .34281 .59629 .34149 .59247 .33671 Mtetra
.567 .719 .944 r
.59247 .33671 .59629 .34149 .60376 .34018 .59996 .33537 Mtetra
.566 .718 .944 r
.59996 .33537 .60376 .34018 .61126 .33889 .60747 .33405 Mtetra
.563 .716 .944 r
.60747 .33405 .61126 .33889 .61879 .33763 .61501 .33276 Mtetra
.562 .714 .943 r
.61501 .33276 .61879 .33763 .62634 .33639 .62257 .33148 Mtetra
.56 .712 .943 r
.62257 .33148 .62634 .33639 .63392 .33517 .63017 .33023 Mtetra
.559 .71 .942 r
.63017 .33023 .63392 .33517 .64153 .33397 .63779 .32899 Mtetra
.558 .709 .941 r
.63779 .32899 .64153 .33397 .64917 .33279 .64543 .32778 Mtetra
.559 .708 .94 r
.64543 .32778 .64917 .33279 .65683 .3316 .65311 .32654 Mtetra
.562 .708 .939 r
.65311 .32654 .65683 .3316 .66452 .33036 .66081 .32526 Mtetra
.569 .709 .937 r
.66081 .32526 .66452 .33036 .67223 .32905 .66853 .3239 Mtetra
.595 .72 .931 r
.66853 .3239 .67223 .32905 .67996 .32737 .67626 .32215 Mtetra
.616 .727 .925 r
.67626 .32215 .67996 .32737 .68769 .32536 .684 .32008 Mtetra
.677 .75 .906 r
.684 .32008 .68769 .32536 .69539 .32228 .69171 .31691 Mtetra
.747 .772 .873 r
.69171 .31691 .69539 .32228 .70301 .31764 .69935 .31216 Mtetra
.787 .781 .847 r
.69935 .31216 .70301 .31764 .71058 .31181 .70693 .30621 Mtetra
.886 .794 .753 r
.70693 .30621 .71058 .31181 .71787 .30131 .71423 .29555 Mtetra
.915 .789 .707 r
.71423 .29555 .71787 .30131 .72496 .28807 .72133 .28216 Mtetra
.942 .779 .651 r
.72133 .28216 .72496 .28807 .73175 .27075 .72814 .26467 Mtetra
.962 .765 .591 r
.72814 .26467 .73175 .27075 .73807 .2475 .73448 .24128 Mtetra
.967 .758 .569 r
.73448 .24128 .73807 .2475 .74412 .22171 .74056 .21537 Mtetra
.929 .56 .292 r
.07392 .38349 .07838 .38724 .0817 .40373 .07722 .39998 Mtetra
.923 .542 .26 r
.07722 .39998 .0817 .40373 .0853 .41881 .0808 .41505 Mtetra
.893 .47 .143 r
.0808 .41505 .0853 .41881 .08946 .43017 .08495 .42639 Mtetra
.824 .351 0 r
.08495 .42639 .08946 .43017 .09408 .4386 .08956 .43479 Mtetra
.71 .199 0 r
.08956 .43479 .09408 .4386 .099 .44507 .09448 .44124 Mtetra
0 .361 .808 r
.09448 .44124 .099 .44507 .10445 .44779 .09993 .44394 Mtetra
.129 .517 .913 r
.09993 .44394 .10445 .44779 .11005 .44949 .10554 .44562 Mtetra
.384 .658 .966 r
.10554 .44562 .11005 .44949 .11586 .44984 .11135 .44595 Mtetra
.523 .718 .961 r
.11135 .44595 .11586 .44984 .12181 .44914 .11731 .44524 Mtetra
.558 .73 .955 r
.11731 .44524 .12181 .44914 .12783 .44812 .12333 .44421 Mtetra
.594 .742 .947 r
.12333 .44421 .12783 .44812 .13391 .44671 .12942 .44278 Mtetra
.605 .745 .944 r
.12942 .44278 .13391 .44671 .14002 .44517 .13554 .44123 Mtetra
.611 .747 .942 r
.13554 .44123 .14002 .44517 .14616 .44356 .14168 .43961 Mtetra
.614 .748 .941 r
.14168 .43961 .14616 .44356 .15232 .4419 .14785 .43793 Mtetra
.615 .748 .94 r
.14785 .43793 .15232 .4419 .15849 .44022 .15404 .43625 Mtetra
.15404 .43625 .15849 .44022 .16469 .43854 .16024 .43456 Mtetra
.16024 .43456 .16469 .43854 .1709 .43686 .16646 .43286 Mtetra
.16646 .43286 .1709 .43686 .17712 .43517 .17269 .43116 Mtetra
.615 .747 .94 r
.17269 .43116 .17712 .43517 .18337 .43348 .17894 .42946 Mtetra
.614 .747 .94 r
.17894 .42946 .18337 .43348 .18963 .43179 .18521 .42776 Mtetra
.18521 .42776 .18963 .43179 .19591 .4301 .1915 .42605 Mtetra
.1915 .42605 .19591 .4301 .2022 .4284 .1978 .42435 Mtetra
.1978 .42435 .2022 .4284 .20851 .42671 .20412 .42264 Mtetra
.613 .746 .94 r
.20412 .42264 .20851 .42671 .21484 .42502 .21046 .42094 Mtetra
.21046 .42094 .21484 .42502 .22119 .42332 .21681 .41923 Mtetra
.21681 .41923 .22119 .42332 .22755 .42162 .22319 .41752 Mtetra
.612 .745 .94 r
.22319 .41752 .22755 .42162 .23393 .41993 .22958 .41582 Mtetra
.22958 .41582 .23393 .41993 .24033 .41824 .23598 .41411 Mtetra
.23598 .41411 .24033 .41824 .24674 .41654 .24241 .4124 Mtetra
.611 .745 .94 r
.24241 .4124 .24674 .41654 .25318 .41485 .24885 .41069 Mtetra
.611 .744 .94 r
.24885 .41069 .25318 .41485 .25963 .41315 .25531 .40898 Mtetra
.25531 .40898 .25963 .41315 .2661 .41145 .26179 .40727 Mtetra
.61 .744 .94 r
.26179 .40727 .2661 .41145 .27258 .40976 .26828 .40557 Mtetra
.61 .743 .94 r
.26828 .40557 .27258 .40976 .27909 .40807 .2748 .40386 Mtetra
.2748 .40386 .27909 .40807 .28561 .40638 .28133 .40215 Mtetra
.609 .743 .94 r
.28133 .40215 .28561 .40638 .29215 .40468 .28788 .40045 Mtetra
.609 .742 .94 r
.28788 .40045 .29215 .40468 .29871 .40299 .29445 .39875 Mtetra
.608 .742 .94 r
.29445 .39875 .29871 .40299 .30529 .40131 .30103 .39705 Mtetra
.30103 .39705 .30529 .40131 .31188 .39962 .30764 .39535 Mtetra
.608 .741 .94 r
.30764 .39535 .31188 .39962 .3185 .39793 .31426 .39364 Mtetra
.607 .741 .94 r
.31426 .39364 .3185 .39793 .32513 .39626 .32091 .39195 Mtetra
.606 .74 .94 r
.32091 .39195 .32513 .39626 .33179 .39457 .32757 .39025 Mtetra
.606 .74 .939 r
.32757 .39025 .33179 .39457 .33846 .39289 .33425 .38855 Mtetra
.605 .739 .94 r
.33425 .38855 .33846 .39289 .34515 .39122 .34095 .38686 Mtetra
.605 .739 .939 r
.34095 .38686 .34515 .39122 .35186 .38955 .34767 .38518 Mtetra
.605 .738 .939 r
.34767 .38518 .35186 .38955 .35859 .38788 .35441 .38349 Mtetra
.604 .738 .939 r
.35441 .38349 .35859 .38788 .36533 .38621 .36117 .38181 Mtetra
.603 .737 .939 r
.36117 .38181 .36533 .38621 .3721 .38455 .36794 .38013 Mtetra
.36794 .38013 .3721 .38455 .37889 .38289 .37474 .37845 Mtetra
.602 .736 .939 r
.37474 .37845 .37889 .38289 .3857 .38124 .38156 .37678 Mtetra
.601 .735 .939 r
.38156 .37678 .3857 .38124 .39252 .37959 .3884 .37511 Mtetra
.3884 .37511 .39252 .37959 .39937 .37794 .39525 .37345 Mtetra
.6 .734 .938 r
.39525 .37345 .39937 .37794 .40624 .3763 .40213 .37178 Mtetra
.599 .733 .938 r
.40213 .37178 .40624 .3763 .41313 .37467 .40903 .37013 Mtetra
.40903 .37013 .41313 .37467 .42004 .37304 .41595 .36848 Mtetra
.598 .732 .938 r
.41595 .36848 .42004 .37304 .42697 .37141 .42289 .36683 Mtetra
.597 .731 .938 r
.42289 .36683 .42697 .37141 .43392 .3698 .42985 .3652 Mtetra
.597 .73 .938 r
.42985 .3652 .43392 .3698 .44089 .36819 .43683 .36357 Mtetra
.596 .729 .937 r
.43683 .36357 .44089 .36819 .44788 .36658 .44383 .36193 Mtetra
.595 .728 .937 r
.44383 .36193 .44788 .36658 .45489 .36499 .45086 .36032 Mtetra
.594 .727 .937 r
.45086 .36032 .45489 .36499 .46193 .3634 .4579 .35871 Mtetra
.594 .727 .936 r
.4579 .35871 .46193 .3634 .46899 .36181 .46497 .3571 Mtetra
.592 .725 .936 r
.46497 .3571 .46899 .36181 .47606 .36025 .47206 .3555 Mtetra
.592 .724 .936 r
.47206 .3555 .47606 .36025 .48317 .35868 .47917 .35391 Mtetra
.591 .723 .935 r
.47917 .35391 .48317 .35868 .49029 .35713 .48631 .35233 Mtetra
.59 .722 .935 r
.48631 .35233 .49029 .35713 .49743 .35559 .49346 .35076 Mtetra
.589 .721 .935 r
.49346 .35076 .49743 .35559 .5046 .35405 .50064 .3492 Mtetra
.588 .719 .934 r
.50064 .3492 .5046 .35405 .51179 .35253 .50784 .34765 Mtetra
.587 .718 .934 r
.50784 .34765 .51179 .35253 .51901 .35102 .51507 .34611 Mtetra
.586 .717 .933 r
.51507 .34611 .51901 .35102 .52625 .34952 .52231 .34458 Mtetra
.585 .715 .933 r
.52231 .34458 .52625 .34952 .53351 .34804 .52959 .34306 Mtetra
.585 .714 .932 r
.52959 .34306 .53351 .34804 .54079 .34657 .53688 .34155 Mtetra
.583 .712 .931 r
.53688 .34155 .54079 .34657 .5481 .34511 .5442 .34006 Mtetra
.582 .71 .931 r
.5442 .34006 .5481 .34511 .55543 .34367 .55154 .33858 Mtetra
.581 .709 .93 r
.55154 .33858 .55543 .34367 .56279 .34224 .55891 .33711 Mtetra
.58 .706 .929 r
.55891 .33711 .56279 .34224 .57017 .34083 .5663 .33567 Mtetra
.579 .705 .928 r
.5663 .33567 .57017 .34083 .57758 .33944 .57372 .33423 Mtetra
.578 .703 .927 r
.57372 .33423 .57758 .33944 .58501 .33806 .58116 .33281 Mtetra
.576 .7 .927 r
.58116 .33281 .58501 .33806 .59247 .33671 .58863 .33141 Mtetra
.575 .698 .926 r
.58863 .33141 .59247 .33671 .59996 .33537 .59613 .33002 Mtetra
.574 .696 .924 r
.59613 .33002 .59996 .33537 .60747 .33405 .60365 .32865 Mtetra
.572 .693 .923 r
.60365 .32865 .60747 .33405 .61501 .33276 .6112 .32731 Mtetra
.571 .691 .922 r
.6112 .32731 .61501 .33276 .62257 .33148 .61877 .32598 Mtetra
.57 .689 .921 r
.61877 .32598 .62257 .33148 .63017 .33023 .62637 .32467 Mtetra
.569 .686 .919 r
.62637 .32467 .63017 .33023 .63779 .32899 .634 .32337 Mtetra
.568 .683 .918 r
.634 .32337 .63779 .32899 .64543 .32778 .64166 .32209 Mtetra
.57 .682 .916 r
.64166 .32209 .64543 .32778 .65311 .32654 .64934 .32079 Mtetra
.573 .681 .913 r
.64934 .32079 .65311 .32654 .66081 .32526 .65705 .31944 Mtetra
.579 .681 .91 r
.65705 .31944 .66081 .32526 .66853 .3239 .66478 .31799 Mtetra
.603 .689 .903 r
.66478 .31799 .66853 .3239 .67626 .32215 .67252 .31616 Mtetra
.622 .695 .897 r
.67252 .31616 .67626 .32215 .684 .32008 .68026 .31399 Mtetra
.677 .716 .878 r
.68026 .31399 .684 .32008 .69171 .31691 .68798 .31071 Mtetra
.74 .737 .849 r
.68798 .31071 .69171 .31691 .69935 .31216 .69562 .30584 Mtetra
.777 .746 .825 r
.69562 .30584 .69935 .31216 .70693 .30621 .70321 .29976 Mtetra
.872 .766 .742 r
.70321 .29976 .70693 .30621 .71423 .29555 .71052 .28894 Mtetra
.902 .765 .701 r
.71052 .28894 .71423 .29555 .72133 .28216 .71764 .27541 Mtetra
.931 .761 .649 r
.71764 .27541 .72133 .28216 .72814 .26467 .72446 .25778 Mtetra
.954 .753 .593 r
.72446 .25778 .72814 .26467 .73448 .24128 .73083 .23431 Mtetra
.96 .748 .572 r
.73083 .23431 .73448 .24128 .74056 .21537 .73694 .20835 Mtetra
.929 .56 .29 r
.06944 .37969 .07392 .38349 .07722 .39998 .07273 .39616 Mtetra
.923 .542 .258 r
.07273 .39616 .07722 .39998 .0808 .41505 .07629 .41121 Mtetra
.893 .469 .139 r
.07629 .41121 .0808 .41505 .08495 .42639 .08043 .42252 Mtetra
.822 .349 0 r
.08043 .42252 .08495 .42639 .08956 .43479 .08503 .4309 Mtetra
.704 .194 0 r
.08503 .4309 .08956 .43479 .09448 .44124 .08995 .43732 Mtetra
0 .367 .815 r
.08995 .43732 .09448 .44124 .09993 .44394 .0954 .44 Mtetra
.142 .52 .916 r
.0954 .44 .09993 .44394 .10554 .44562 .10101 .44166 Mtetra
.391 .656 .964 r
.10101 .44166 .10554 .44562 .11135 .44595 .10683 .44196 Mtetra
.526 .714 .958 r
.10683 .44196 .11135 .44595 .11731 .44524 .1128 .44124 Mtetra
.56 .726 .952 r
.1128 .44124 .11731 .44524 .12333 .44421 .11883 .44019 Mtetra
.596 .738 .943 r
.11883 .44019 .12333 .44421 .12942 .44278 .12492 .43875 Mtetra
.606 .741 .94 r
.12492 .43875 .12942 .44278 .13554 .44123 .13105 .43718 Mtetra
.612 .742 .938 r
.13105 .43718 .13554 .44123 .14168 .43961 .1372 .43555 Mtetra
.615 .743 .937 r
.1372 .43555 .14168 .43961 .14785 .43793 .14338 .43386 Mtetra
.616 .743 .937 r
.14338 .43386 .14785 .43793 .15404 .43625 .14957 .43217 Mtetra
.616 .743 .936 r
.14957 .43217 .15404 .43625 .16024 .43456 .15578 .43046 Mtetra
.15578 .43046 .16024 .43456 .16646 .43286 .16201 .42875 Mtetra
.16201 .42875 .16646 .43286 .17269 .43116 .16825 .42704 Mtetra
.616 .742 .936 r
.16825 .42704 .17269 .43116 .17894 .42946 .17451 .42532 Mtetra
.17451 .42532 .17894 .42946 .18521 .42776 .18079 .4236 Mtetra
.615 .742 .936 r
.18079 .4236 .18521 .42776 .1915 .42605 .18708 .42189 Mtetra
.615 .741 .936 r
.18708 .42189 .1915 .42605 .1978 .42435 .1934 .42017 Mtetra
.1934 .42017 .1978 .42435 .20412 .42264 .19972 .41845 Mtetra
.614 .741 .936 r
.19972 .41845 .20412 .42264 .21046 .42094 .20607 .41673 Mtetra
.615 .74 .936 r
.20607 .41673 .21046 .42094 .21681 .41923 .21243 .41501 Mtetra
.614 .74 .935 r
.21243 .41501 .21681 .41923 .22319 .41752 .21881 .41328 Mtetra
.21881 .41328 .22319 .41752 .22958 .41582 .22521 .41156 Mtetra
.614 .739 .935 r
.22521 .41156 .22958 .41582 .23598 .41411 .23163 .40984 Mtetra
.613 .739 .935 r
.23163 .40984 .23598 .41411 .24241 .4124 .23806 .40811 Mtetra
.613 .738 .935 r
.23806 .40811 .24241 .4124 .24885 .41069 .24451 .40639 Mtetra
.24451 .40639 .24885 .41069 .25531 .40898 .25098 .40467 Mtetra
.25098 .40467 .25531 .40898 .26179 .40727 .25747 .40294 Mtetra
.611 .737 .935 r
.25747 .40294 .26179 .40727 .26828 .40557 .26397 .40122 Mtetra
.611 .737 .934 r
.26397 .40122 .26828 .40557 .2748 .40386 .2705 .3995 Mtetra
.612 .736 .934 r
.2705 .3995 .2748 .40386 .28133 .40215 .27704 .39777 Mtetra
.611 .736 .934 r
.27704 .39777 .28133 .40215 .28788 .40045 .2836 .39605 Mtetra
.61 .735 .934 r
.2836 .39605 .28788 .40045 .29445 .39875 .29017 .39433 Mtetra
.29017 .39433 .29445 .39875 .30103 .39705 .29677 .39261 Mtetra
.61 .734 .934 r
.29677 .39261 .30103 .39705 .30764 .39535 .30339 .39089 Mtetra
.61 .734 .933 r
.30339 .39089 .30764 .39535 .31426 .39364 .31002 .38916 Mtetra
.609 .733 .933 r
.31002 .38916 .31426 .39364 .32091 .39195 .31667 .38745 Mtetra
.608 .732 .933 r
.31667 .38745 .32091 .39195 .32757 .39025 .32334 .38573 Mtetra
.32334 .38573 .32757 .39025 .33425 .38855 .33003 .38401 Mtetra
.607 .731 .933 r
.33003 .38401 .33425 .38855 .34095 .38686 .33674 .38231 Mtetra
.607 .73 .932 r
.33674 .38231 .34095 .38686 .34767 .38518 .34347 .3806 Mtetra
.34347 .3806 .34767 .38518 .35441 .38349 .35022 .37889 Mtetra
.606 .729 .932 r
.35022 .37889 .35441 .38349 .36117 .38181 .35699 .37718 Mtetra
.606 .728 .931 r
.35699 .37718 .36117 .38181 .36794 .38013 .36378 .37548 Mtetra
.605 .727 .931 r
.36378 .37548 .36794 .38013 .37474 .37845 .37058 .37378 Mtetra
.605 .726 .931 r
.37058 .37378 .37474 .37845 .38156 .37678 .37741 .37208 Mtetra
.604 .725 .93 r
.37741 .37208 .38156 .37678 .3884 .37511 .38426 .37039 Mtetra
.604 .724 .93 r
.38426 .37039 .3884 .37511 .39525 .37345 .39113 .3687 Mtetra
.603 .724 .93 r
.39113 .3687 .39525 .37345 .40213 .37178 .39801 .36701 Mtetra
.602 .722 .929 r
.39801 .36701 .40213 .37178 .40903 .37013 .40492 .36533 Mtetra
.602 .721 .929 r
.40492 .36533 .40903 .37013 .41595 .36848 .41185 .36366 Mtetra
.602 .721 .928 r
.41185 .36366 .41595 .36848 .42289 .36683 .4188 .36198 Mtetra
.6 .719 .928 r
.4188 .36198 .42289 .36683 .42985 .3652 .42577 .36032 Mtetra
.6 .718 .927 r
.42577 .36032 .42985 .3652 .43683 .36357 .43276 .35865 Mtetra
.6 .717 .927 r
.43276 .35865 .43683 .36357 .44383 .36193 .43978 .35699 Mtetra
.598 .716 .926 r
.43978 .35699 .44383 .36193 .45086 .36032 .44681 .35534 Mtetra
.598 .714 .925 r
.44681 .35534 .45086 .36032 .4579 .35871 .45387 .3537 Mtetra
.598 .713 .925 r
.45387 .3537 .4579 .35871 .46497 .3571 .46094 .35205 Mtetra
.597 .712 .924 r
.46094 .35205 .46497 .3571 .47206 .3555 .46804 .35042 Mtetra
.596 .71 .923 r
.46804 .35042 .47206 .3555 .47917 .35391 .47516 .3488 Mtetra
.595 .709 .923 r
.47516 .3488 .47917 .35391 .48631 .35233 .48231 .34718 Mtetra
.595 .707 .922 r
.48231 .34718 .48631 .35233 .49346 .35076 .48947 .34557 Mtetra
.594 .705 .921 r
.48947 .34557 .49346 .35076 .50064 .3492 .49666 .34397 Mtetra
.593 .704 .92 r
.49666 .34397 .50064 .3492 .50784 .34765 .50387 .34237 Mtetra
.592 .702 .919 r
.50387 .34237 .50784 .34765 .51507 .34611 .51111 .34079 Mtetra
.592 .7 .918 r
.51111 .34079 .51507 .34611 .52231 .34458 .51837 .33921 Mtetra
.591 .698 .917 r
.51837 .33921 .52231 .34458 .52959 .34306 .52565 .33765 Mtetra
.59 .696 .916 r
.52565 .33765 .52959 .34306 .53688 .34155 .53295 .33609 Mtetra
.589 .694 .915 r
.53295 .33609 .53688 .34155 .5442 .34006 .54028 .33455 Mtetra
.588 .692 .914 r
.54028 .33455 .5442 .34006 .55154 .33858 .54763 .33302 Mtetra
.588 .69 .912 r
.54763 .33302 .55154 .33858 .55891 .33711 .55501 .33149 Mtetra
.586 .687 .911 r
.55501 .33149 .55891 .33711 .5663 .33567 .56241 .32999 Mtetra
.586 .685 .909 r
.56241 .32999 .5663 .33567 .57372 .33423 .56984 .32849 Mtetra
.585 .682 .908 r
.56984 .32849 .57372 .33423 .58116 .33281 .57729 .327 Mtetra
.583 .679 .906 r
.57729 .327 .58116 .33281 .58863 .33141 .58477 .32554 Mtetra
.583 .677 .904 r
.58477 .32554 .58863 .33141 .59613 .33002 .59227 .32409 Mtetra
.582 .674 .903 r
.59227 .32409 .59613 .33002 .60365 .32865 .5998 .32264 Mtetra
.58 .67 .901 r
.5998 .32264 .60365 .32865 .6112 .32731 .60735 .32122 Mtetra
.58 .667 .899 r
.60735 .32122 .6112 .32731 .61877 .32598 .61493 .31981 Mtetra
.579 .664 .897 r
.61493 .31981 .61877 .32598 .62637 .32467 .62254 .31842 Mtetra
.578 .661 .894 r
.62254 .31842 .62637 .32467 .634 .32337 .63017 .31704 Mtetra
.577 .658 .892 r
.63017 .31704 .634 .32337 .64166 .32209 .63784 .31566 Mtetra
.579 .655 .889 r
.63784 .31566 .64166 .32209 .64934 .32079 .64552 .31426 Mtetra
.582 .653 .885 r
.64552 .31426 .64934 .32079 .65705 .31944 .65324 .31281 Mtetra
.588 .653 .881 r
.65324 .31281 .65705 .31944 .66478 .31799 .66097 .31126 Mtetra
.609 .659 .874 r
.66097 .31126 .66478 .31799 .67252 .31616 .66872 .30931 Mtetra
.626 .664 .867 r
.66872 .30931 .67252 .31616 .68026 .31399 .67647 .30701 Mtetra
.675 .683 .849 r
.67647 .30701 .68026 .31399 .68798 .31071 .68418 .30359 Mtetra
.732 .703 .823 r
.68418 .30359 .68798 .31071 .69562 .30584 .69183 .29857 Mtetra
.766 .712 .802 r
.69183 .29857 .69562 .30584 .70321 .29976 .69943 .29234 Mtetra
.857 .737 .731 r
.69943 .29234 .70321 .29976 .71052 .28894 .70674 .28138 Mtetra
.887 .741 .694 r
.70674 .28138 .71052 .28894 .71764 .27541 .71388 .26772 Mtetra
.918 .742 .648 r
.71388 .26772 .71764 .27541 .72446 .25778 .72071 .25 Mtetra
.944 .739 .595 r
.72071 .25 .72446 .25778 .73083 .23431 .72711 .22651 Mtetra
.952 .737 .576 r
.72711 .22651 .73083 .23431 .73694 .20835 .73326 .20059 Mtetra
.931 .562 .284 r
.06499 .37561 .06944 .37969 .07273 .39616 .06826 .39203 Mtetra
.925 .543 .249 r
.06826 .39203 .07273 .39616 .07629 .41121 .0718 .40703 Mtetra
.892 .467 .121 r
.0718 .40703 .07629 .41121 .08043 .42252 .07594 .41828 Mtetra
.812 .339 0 r
.07594 .41828 .08043 .42252 .08503 .4309 .08054 .4266 Mtetra
.676 .172 0 r
.08054 .4266 .08503 .4309 .08995 .43732 .08545 .43297 Mtetra
0 .387 .84 r
.08545 .43297 .08995 .43732 .0954 .44 .09091 .43561 Mtetra
.191 .524 .919 r
.09091 .43561 .0954 .44 .10101 .44166 .09653 .43723 Mtetra
.416 .642 .95 r
.09653 .43723 .10101 .44166 .10683 .44196 .10235 .43751 Mtetra
.538 .694 .94 r
.10235 .43751 .10683 .44196 .1128 .44124 .10833 .43676 Mtetra
.568 .704 .933 r
.10833 .43676 .1128 .44124 .11883 .44019 .11436 .43569 Mtetra
.6 .715 .925 r
.11436 .43569 .11883 .44019 .12492 .43875 .12046 .43423 Mtetra
.61 .717 .921 r
.12046 .43423 .12492 .43875 .13105 .43718 .1266 .43264 Mtetra
.615 .719 .919 r
.1266 .43264 .13105 .43718 .1372 .43555 .13276 .43099 Mtetra
.618 .719 .918 r
.13276 .43099 .1372 .43555 .14338 .43386 .13894 .42928 Mtetra
.619 .719 .917 r
.13894 .42928 .14338 .43386 .14957 .43217 .14514 .42757 Mtetra
.619 .718 .917 r
.14514 .42757 .14957 .43217 .15578 .43046 .15136 .42584 Mtetra
.619 .718 .916 r
.15136 .42584 .15578 .43046 .16201 .42875 .1576 .42411 Mtetra
.619 .717 .916 r
.1576 .42411 .16201 .42875 .16825 .42704 .16385 .42237 Mtetra
.16385 .42237 .16825 .42704 .17451 .42532 .17012 .42063 Mtetra
.619 .716 .915 r
.17012 .42063 .17451 .42532 .18079 .4236 .1764 .4189 Mtetra
.619 .715 .915 r
.1764 .4189 .18079 .4236 .18708 .42189 .18271 .41716 Mtetra
.619 .715 .914 r
.18271 .41716 .18708 .42189 .1934 .42017 .18903 .41541 Mtetra
.618 .714 .914 r
.18903 .41541 .1934 .42017 .19972 .41845 .19536 .41367 Mtetra
.618 .713 .914 r
.19536 .41367 .19972 .41845 .20607 .41673 .20172 .41193 Mtetra
.618 .712 .913 r
.20172 .41193 .20607 .41673 .21243 .41501 .20809 .41018 Mtetra
.20809 .41018 .21243 .41501 .21881 .41328 .21448 .40843 Mtetra
.617 .711 .912 r
.21448 .40843 .21881 .41328 .22521 .41156 .22089 .40669 Mtetra
.617 .71 .912 r
.22089 .40669 .22521 .41156 .23163 .40984 .22731 .40494 Mtetra
.617 .709 .911 r
.22731 .40494 .23163 .40984 .23806 .40811 .23375 .40318 Mtetra
.616 .708 .911 r
.23375 .40318 .23806 .40811 .24451 .40639 .24021 .40144 Mtetra
.616 .707 .91 r
.24021 .40144 .24451 .40639 .25098 .40467 .24669 .39968 Mtetra
.616 .707 .909 r
.24669 .39968 .25098 .40467 .25747 .40294 .25319 .39792 Mtetra
.615 .705 .909 r
.25319 .39792 .25747 .40294 .26397 .40122 .2597 .39618 Mtetra
.615 .705 .908 r
.2597 .39618 .26397 .40122 .2705 .3995 .26623 .39442 Mtetra
.616 .704 .908 r
.26623 .39442 .2705 .3995 .27704 .39777 .27278 .39267 Mtetra
.615 .702 .907 r
.27278 .39267 .27704 .39777 .2836 .39605 .27935 .39091 Mtetra
.614 .701 .906 r
.27935 .39091 .2836 .39605 .29017 .39433 .28594 .38916 Mtetra
.614 .7 .906 r
.28594 .38916 .29017 .39433 .29677 .39261 .29254 .38741 Mtetra
.614 .699 .905 r
.29254 .38741 .29677 .39261 .30339 .39089 .29917 .38566 Mtetra
.614 .698 .904 r
.29917 .38566 .30339 .39089 .31002 .38916 .30581 .3839 Mtetra
.613 .697 .903 r
.30581 .3839 .31002 .38916 .31667 .38745 .31247 .38215 Mtetra
.613 .696 .903 r
.31247 .38215 .31667 .38745 .32334 .38573 .31915 .3804 Mtetra
.613 .694 .902 r
.31915 .3804 .32334 .38573 .33003 .38401 .32585 .37864 Mtetra
.612 .693 .901 r
.32585 .37864 .33003 .38401 .33674 .38231 .33257 .37689 Mtetra
.612 .692 .9 r
.33257 .37689 .33674 .38231 .34347 .3806 .33931 .37514 Mtetra
.612 .69 .899 r
.33931 .37514 .34347 .3806 .35022 .37889 .34606 .37339 Mtetra
.611 .689 .898 r
.34606 .37339 .35022 .37889 .35699 .37718 .35284 .37165 Mtetra
.611 .687 .897 r
.35284 .37165 .35699 .37718 .36378 .37548 .35964 .3699 Mtetra
.61 .686 .896 r
.35964 .3699 .36378 .37548 .37058 .37378 .36645 .36816 Mtetra
.61 .684 .895 r
.36645 .36816 .37058 .37378 .37741 .37208 .37329 .36641 Mtetra
.609 .682 .894 r
.37329 .36641 .37741 .37208 .38426 .37039 .38015 .36467 Mtetra
.609 .681 .893 r
.38015 .36467 .38426 .37039 .39113 .3687 .38702 .36294 Mtetra
.609 .679 .891 r
.38702 .36294 .39113 .3687 .39801 .36701 .39392 .3612 Mtetra
.608 .677 .89 r
.39392 .3612 .39801 .36701 .40492 .36533 .40084 .35947 Mtetra
.608 .675 .889 r
.40084 .35947 .40492 .36533 .41185 .36366 .40777 .35774 Mtetra
.607 .673 .887 r
.40777 .35774 .41185 .36366 .4188 .36198 .41473 .35601 Mtetra
.606 .671 .886 r
.41473 .35601 .4188 .36198 .42577 .36032 .42171 .35428 Mtetra
.606 .669 .885 r
.42171 .35428 .42577 .36032 .43276 .35865 .42871 .35256 Mtetra
.606 .667 .883 r
.42871 .35256 .43276 .35865 .43978 .35699 .43573 .35084 Mtetra
.605 .665 .882 r
.43573 .35084 .43978 .35699 .44681 .35534 .44278 .34913 Mtetra
.604 .663 .88 r
.44278 .34913 .44681 .35534 .45387 .3537 .44984 .34742 Mtetra
.604 .661 .878 r
.44984 .34742 .45387 .3537 .46094 .35205 .45693 .34571 Mtetra
.603 .658 .877 r
.45693 .34571 .46094 .35205 .46804 .35042 .46403 .34401 Mtetra
.603 .656 .875 r
.46403 .34401 .46804 .35042 .47516 .3488 .47116 .34231 Mtetra
.602 .653 .873 r
.47116 .34231 .47516 .3488 .48231 .34718 .47831 .34062 Mtetra
.601 .65 .871 r
.47831 .34062 .48231 .34718 .48947 .34557 .48549 .33893 Mtetra
.601 .648 .869 r
.48549 .33893 .48947 .34557 .49666 .34397 .49268 .33725 Mtetra
.6 .645 .867 r
.49268 .33725 .49666 .34397 .50387 .34237 .4999 .33558 Mtetra
.599 .642 .865 r
.4999 .33558 .50387 .34237 .51111 .34079 .50714 .33391 Mtetra
.599 .639 .862 r
.50714 .33391 .51111 .34079 .51837 .33921 .5144 .33224 Mtetra
.598 .636 .86 r
.5144 .33224 .51837 .33921 .52565 .33765 .52169 .33059 Mtetra
.597 .633 .858 r
.52169 .33059 .52565 .33765 .53295 .33609 .529 .32893 Mtetra
.596 .63 .855 r
.529 .32893 .53295 .33609 .54028 .33455 .53634 .32729 Mtetra
.595 .627 .853 r
.53634 .32729 .54028 .33455 .54763 .33302 .54369 .32565 Mtetra
.595 .623 .85 r
.54369 .32565 .54763 .33302 .55501 .33149 .55107 .32402 Mtetra
.594 .62 .847 r
.55107 .32402 .55501 .33149 .56241 .32999 .55848 .32241 Mtetra
.593 .616 .844 r
.55848 .32241 .56241 .32999 .56984 .32849 .56591 .32079 Mtetra
.592 .613 .841 r
.56591 .32079 .56984 .32849 .57729 .327 .57337 .31918 Mtetra
.591 .609 .838 r
.57337 .31918 .57729 .327 .58477 .32554 .58084 .31759 Mtetra
.59 .605 .835 r
.58084 .31759 .58477 .32554 .59227 .32409 .58835 .31601 Mtetra
.59 .601 .832 r
.58835 .31601 .59227 .32409 .5998 .32264 .59588 .31443 Mtetra
.588 .597 .828 r
.59588 .31443 .5998 .32264 .60735 .32122 .60343 .31286 Mtetra
.587 .593 .825 r
.60343 .31286 .60735 .32122 .61493 .31981 .61101 .31131 Mtetra
.587 .589 .821 r
.61101 .31131 .61493 .31981 .62254 .31842 .61862 .30976 Mtetra
.586 .584 .818 r
.61862 .30976 .62254 .31842 .63017 .31704 .62625 .30821 Mtetra
.585 .58 .814 r
.62625 .30821 .63017 .31704 .63784 .31566 .63391 .30667 Mtetra
.586 .577 .81 r
.63391 .30667 .63784 .31566 .64552 .31426 .6416 .30509 Mtetra
.588 .574 .805 r
.6416 .30509 .64552 .31426 .65324 .31281 .6493 .30345 Mtetra
.591 .572 .8 r
.6493 .30345 .65324 .31281 .66097 .31126 .65703 .30171 Mtetra
.606 .576 .794 r
.65703 .30171 .66097 .31126 .66872 .30931 .66477 .29956 Mtetra
.618 .578 .787 r
.66477 .29956 .66872 .30931 .67647 .30701 .67252 .29706 Mtetra
.654 .593 .775 r
.67252 .29706 .67647 .30701 .68418 .30359 .68023 .29344 Mtetra
.698 .613 .758 r
.68023 .29344 .68418 .30359 .69183 .29857 .68787 .28824 Mtetra
.725 .623 .744 r
.68787 .28824 .69183 .29857 .69943 .29234 .69546 .28183 Mtetra
.807 .66 .699 r
.69546 .28183 .69943 .29234 .70674 .28138 .70278 .27078 Mtetra
.84 .672 .674 r
.70278 .27078 .70674 .28138 .71388 .26772 .70992 .25708 Mtetra
.876 .685 .641 r
.70992 .25708 .71388 .26772 .72071 .25 .71678 .23942 Mtetra
.911 .697 .6 r
.71678 .23942 .72071 .25 .72711 .22651 .72322 .21615 Mtetra
.924 .702 .583 r
.72322 .21615 .72711 .22651 .73326 .20059 .72941 .19053 Mtetra
.933 .562 .276 r
.06055 .37127 .06499 .37561 .06826 .39203 .0638 .3876 Mtetra
.927 .544 .239 r
.0638 .3876 .06826 .39203 .0718 .40703 .06734 .4025 Mtetra
.89 .464 .101 r
.06734 .4025 .0718 .40703 .07594 .41828 .07148 .41367 Mtetra
.798 .326 0 r
.07148 .41367 .07594 .41828 .08054 .4266 .07607 .42192 Mtetra
.641 .147 0 r
.07607 .42192 .08054 .4266 .08545 .43297 .08099 .42822 Mtetra
.031 .403 .856 r
.08099 .42822 .08545 .43297 .09091 .43561 .08645 .4308 Mtetra
.233 .525 .917 r
.08645 .4308 .09091 .43561 .09653 .43723 .09208 .43238 Mtetra
.436 .629 .935 r
.09208 .43238 .09653 .43723 .10235 .43751 .0979 .43262 Mtetra
.546 .675 .922 r
.0979 .43262 .10235 .43751 .10833 .43676 .10389 .43184 Mtetra
.574 .685 .916 r
.10389 .43184 .10833 .43676 .11436 .43569 .10993 .43074 Mtetra
.604 .694 .907 r
.10993 .43074 .11436 .43569 .12046 .43423 .11604 .42925 Mtetra
.612 .697 .904 r
.11604 .42925 .12046 .43423 .1266 .43264 .12219 .42764 Mtetra
.617 .698 .902 r
.12219 .42764 .1266 .43264 .13276 .43099 .12835 .42596 Mtetra
.62 .698 .9 r
.12835 .42596 .13276 .43099 .13894 .42928 .13454 .42423 Mtetra
.62 .697 .899 r
.13454 .42423 .13894 .42928 .14514 .42757 .14075 .42248 Mtetra
.621 .697 .899 r
.14075 .42248 .14514 .42757 .15136 .42584 .14698 .42073 Mtetra
.621 .696 .898 r
.14698 .42073 .15136 .42584 .1576 .42411 .15322 .41897 Mtetra
.621 .695 .898 r
.15322 .41897 .1576 .42411 .16385 .42237 .15948 .41721 Mtetra
.621 .694 .897 r
.15948 .41721 .16385 .42237 .17012 .42063 .16576 .41544 Mtetra
.62 .693 .896 r
.16576 .41544 .17012 .42063 .1764 .4189 .17205 .41367 Mtetra
.62 .692 .896 r
.17205 .41367 .1764 .4189 .18271 .41716 .17836 .41191 Mtetra
.62 .692 .895 r
.17836 .41191 .18271 .41716 .18903 .41541 .18469 .41013 Mtetra
.62 .691 .894 r
.18469 .41013 .18903 .41541 .19536 .41367 .19104 .40836 Mtetra
.619 .69 .894 r
.19104 .40836 .19536 .41367 .20172 .41193 .1974 .40658 Mtetra
.62 .689 .893 r
.1974 .40658 .20172 .41193 .20809 .41018 .20378 .4048 Mtetra
.619 .688 .892 r
.20378 .4048 .20809 .41018 .21448 .40843 .21018 .40302 Mtetra
.619 .687 .891 r
.21018 .40302 .21448 .40843 .22089 .40669 .21659 .40124 Mtetra
.619 .686 .891 r
.21659 .40124 .22089 .40669 .22731 .40494 .22303 .39946 Mtetra
.619 .684 .89 r
.22303 .39946 .22731 .40494 .23375 .40318 .22948 .39767 Mtetra
.618 .683 .889 r
.22948 .39767 .23375 .40318 .24021 .40144 .23595 .39589 Mtetra
.618 .682 .888 r
.23595 .39589 .24021 .40144 .24669 .39968 .24243 .3941 Mtetra
.618 .681 .887 r
.24243 .3941 .24669 .39968 .25319 .39792 .24894 .3923 Mtetra
.617 .679 .886 r
.24894 .3923 .25319 .39792 .2597 .39618 .25546 .39051 Mtetra
.617 .678 .885 r
.25546 .39051 .2597 .39618 .26623 .39442 .262 .38872 Mtetra
.617 .677 .884 r
.262 .38872 .26623 .39442 .27278 .39267 .26856 .38692 Mtetra
.616 .676 .884 r
.26856 .38692 .27278 .39267 .27935 .39091 .27513 .38513 Mtetra
.616 .674 .883 r
.27513 .38513 .27935 .39091 .28594 .38916 .28173 .38333 Mtetra
.616 .673 .881 r
.28173 .38333 .28594 .38916 .29254 .38741 .28834 .38154 Mtetra
.616 .671 .88 r
.28834 .38154 .29254 .38741 .29917 .38566 .29498 .37974 Mtetra
.616 .67 .879 r
.29498 .37974 .29917 .38566 .30581 .3839 .30163 .37794 Mtetra
.615 .668 .878 r
.30163 .37794 .30581 .3839 .31247 .38215 .3083 .37614 Mtetra
.615 .667 .877 r
.3083 .37614 .31247 .38215 .31915 .3804 .31499 .37434 Mtetra
.615 .665 .876 r
.31499 .37434 .31915 .3804 .32585 .37864 .32169 .37253 Mtetra
.614 .663 .874 r
.32169 .37253 .32585 .37864 .33257 .37689 .32842 .37073 Mtetra
.614 .662 .873 r
.32842 .37073 .33257 .37689 .33931 .37514 .33517 .36893 Mtetra
.613 .66 .872 r
.33517 .36893 .33931 .37514 .34606 .37339 .34193 .36712 Mtetra
.613 .658 .87 r
.34193 .36712 .34606 .37339 .35284 .37165 .34872 .36532 Mtetra
.613 .656 .869 r
.34872 .36532 .35284 .37165 .35964 .3699 .35552 .36352 Mtetra
.612 .654 .868 r
.35552 .36352 .35964 .3699 .36645 .36816 .36235 .36171 Mtetra
.612 .653 .866 r
.36235 .36171 .36645 .36816 .37329 .36641 .36919 .35991 Mtetra
.611 .651 .864 r
.36919 .35991 .37329 .36641 .38015 .36467 .37606 .35811 Mtetra
.611 .648 .863 r
.37606 .35811 .38015 .36467 .38702 .36294 .38294 .3563 Mtetra
.61 .646 .861 r
.38294 .3563 .38702 .36294 .39392 .3612 .38985 .3545 Mtetra
.61 .644 .859 r
.38985 .3545 .39392 .3612 .40084 .35947 .39677 .3527 Mtetra
.609 .642 .858 r
.39677 .3527 .40084 .35947 .40777 .35774 .40372 .3509 Mtetra
.609 .64 .856 r
.40372 .3509 .40777 .35774 .41473 .35601 .41068 .34909 Mtetra
.608 .637 .854 r
.41068 .34909 .41473 .35601 .42171 .35428 .41767 .3473 Mtetra
.608 .635 .852 r
.41767 .3473 .42171 .35428 .42871 .35256 .42468 .3455 Mtetra
.608 .633 .85 r
.42468 .3455 .42871 .35256 .43573 .35084 .4317 .34369 Mtetra
.607 .63 .848 r
.4317 .34369 .43573 .35084 .44278 .34913 .43875 .3419 Mtetra
.606 .627 .846 r
.43875 .3419 .44278 .34913 .44984 .34742 .44582 .3401 Mtetra
.606 .625 .844 r
.44582 .3401 .44984 .34742 .45693 .34571 .45292 .33831 Mtetra
.605 .622 .842 r
.45292 .33831 .45693 .34571 .46403 .34401 .46003 .33651 Mtetra
.604 .619 .839 r
.46003 .33651 .46403 .34401 .47116 .34231 .46716 .33472 Mtetra
.604 .616 .837 r
.46716 .33472 .47116 .34231 .47831 .34062 .47432 .33293 Mtetra
.603 .613 .835 r
.47432 .33293 .47831 .34062 .48549 .33893 .4815 .33114 Mtetra
.602 .61 .832 r
.4815 .33114 .48549 .33893 .49268 .33725 .4887 .32936 Mtetra
.602 .607 .83 r
.4887 .32936 .49268 .33725 .4999 .33558 .49592 .32757 Mtetra
.601 .604 .827 r
.49592 .32757 .4999 .33558 .50714 .33391 .50317 .32579 Mtetra
.6 .601 .824 r
.50317 .32579 .50714 .33391 .5144 .33224 .51044 .32401 Mtetra
.6 .598 .821 r
.51044 .32401 .5144 .33224 .52169 .33059 .51773 .32223 Mtetra
.599 .595 .819 r
.51773 .32223 .52169 .33059 .529 .32893 .52504 .32045 Mtetra
.598 .591 .816 r
.52504 .32045 .529 .32893 .53634 .32729 .53238 .31868 Mtetra
.597 .588 .813 r
.53238 .31868 .53634 .32729 .54369 .32565 .53974 .31691 Mtetra
.597 .584 .81 r
.53974 .31691 .54369 .32565 .55107 .32402 .54712 .31514 Mtetra
.595 .581 .807 r
.54712 .31514 .55107 .32402 .55848 .32241 .55452 .31338 Mtetra
.595 .577 .803 r
.55452 .31338 .55848 .32241 .56591 .32079 .56195 .31161 Mtetra
.594 .573 .8 r
.56195 .31161 .56591 .32079 .57337 .31918 .56941 .30985 Mtetra
.593 .569 .797 r
.56941 .30985 .57337 .31918 .58084 .31759 .57689 .3081 Mtetra
.592 .566 .793 r
.57689 .3081 .58084 .31759 .58835 .31601 .58439 .30634 Mtetra
.591 .562 .79 r
.58439 .30634 .58835 .31601 .59588 .31443 .59192 .30458 Mtetra
.59 .558 .786 r
.59192 .30458 .59588 .31443 .60343 .31286 .59947 .30284 Mtetra
.589 .554 .782 r
.59947 .30284 .60343 .31286 .61101 .31131 .60704 .3011 Mtetra
.589 .55 .779 r
.60704 .3011 .61101 .31131 .61862 .30976 .61464 .29935 Mtetra
.588 .546 .775 r
.61464 .29935 .61862 .30976 .62625 .30821 .62227 .2976 Mtetra
.587 .541 .771 r
.62227 .2976 .62625 .30821 .63391 .30667 .62992 .29584 Mtetra
.588 .538 .767 r
.62992 .29584 .63391 .30667 .6416 .30509 .63759 .29404 Mtetra
.589 .535 .762 r
.63759 .29404 .6416 .30509 .6493 .30345 .64529 .29217 Mtetra
.592 .533 .758 r
.64529 .29217 .6493 .30345 .65703 .30171 .65301 .29019 Mtetra
.604 .536 .752 r
.65301 .29019 .65703 .30171 .66477 .29956 .66073 .2878 Mtetra
.613 .538 .746 r
.66073 .2878 .66477 .29956 .67252 .29706 .66846 .28506 Mtetra
.643 .552 .736 r
.66846 .28506 .67252 .29706 .68023 .29344 .67616 .28121 Mtetra
.68 .57 .724 r
.67616 .28121 .68023 .29344 .68787 .28824 .6838 .27581 Mtetra
.704 .58 .714 r
.6838 .27581 .68787 .28824 .69546 .28183 .69137 .26923 Mtetra
.78 .618 .681 r
.69137 .26923 .69546 .28183 .70278 .27078 .6987 .25813 Mtetra
.811 .634 .662 r
.6987 .25813 .70278 .27078 .70992 .25708 .70585 .24447 Mtetra
.85 .652 .635 r
.70585 .24447 .70992 .25708 .71678 .23942 .71273 .22698 Mtetra
.888 .67 .601 r
.71273 .22698 .71678 .23942 .72322 .21615 .71921 .2041 Mtetra
.904 .679 .587 r
.71921 .2041 .72322 .21615 .72941 .19053 .72546 .17897 Mtetra
.935 .564 .261 r
.05616 .36643 .06055 .37127 .0638 .3876 .05942 .38259 Mtetra
.928 .544 .218 r
.05942 .38259 .0638 .3876 .06734 .4025 .06295 .39733 Mtetra
.882 .456 .06 r
.06295 .39733 .06734 .4025 .07148 .41367 .06709 .40835 Mtetra
.761 .299 0 r
.06709 .40835 .07148 .41367 .07607 .42192 .0717 .41648 Mtetra
.56 .096 0 r
.0717 .41648 .07607 .42192 .08099 .42822 .07662 .42267 Mtetra
.125 .419 .864 r
.07662 .42267 .08099 .42822 .08645 .4308 .08208 .42518 Mtetra
.296 .517 .899 r
.08208 .42518 .08645 .4308 .09208 .43238 .08772 .42669 Mtetra
.465 .601 .902 r
.08772 .42669 .09208 .43238 .0979 .43262 .09355 .42688 Mtetra
.557 .64 .889 r
.09355 .42688 .0979 .43262 .10389 .43184 .09954 .42605 Mtetra
.581 .649 .882 r
.09954 .42605 .10389 .43184 .10993 .43074 .1056 .42491 Mtetra
.606 .657 .874 r
.1056 .42491 .10993 .43074 .11604 .42925 .11171 .42338 Mtetra
.613 .659 .871 r
.11171 .42338 .11604 .42925 .12219 .42764 .11786 .42174 Mtetra
.617 .66 .869 r
.11786 .42174 .12219 .42764 .12835 .42596 .12404 .42002 Mtetra
.62 .66 .867 r
.12404 .42002 .12835 .42596 .13454 .42423 .13024 .41825 Mtetra
.62 .659 .866 r
.13024 .41825 .13454 .42423 .14075 .42248 .13646 .41647 Mtetra
.62 .658 .865 r
.13646 .41647 .14075 .42248 .14698 .42073 .14269 .41467 Mtetra
.62 .657 .864 r
.14269 .41467 .14698 .42073 .15322 .41897 .14894 .41287 Mtetra
.62 .656 .863 r
.14894 .41287 .15322 .41897 .15948 .41721 .15521 .41107 Mtetra
.62 .654 .862 r
.15521 .41107 .15948 .41721 .16576 .41544 .16149 .40926 Mtetra
.62 .653 .861 r
.16149 .40926 .16576 .41544 .17205 .41367 .16779 .40746 Mtetra
.619 .652 .86 r
.16779 .40746 .17205 .41367 .17836 .41191 .17411 .40564 Mtetra
.619 .651 .859 r
.17411 .40564 .17836 .41191 .18469 .41013 .18045 .40383 Mtetra
.619 .649 .858 r
.18045 .40383 .18469 .41013 .19104 .40836 .1868 .40201 Mtetra
.619 .648 .857 r
.1868 .40201 .19104 .40836 .1974 .40658 .19317 .40019 Mtetra
.619 .647 .856 r
.19317 .40019 .1974 .40658 .20378 .4048 .19956 .39836 Mtetra
.618 .645 .855 r
.19956 .39836 .20378 .4048 .21018 .40302 .20597 .39653 Mtetra
.618 .644 .854 r
.20597 .39653 .21018 .40302 .21659 .40124 .21239 .3947 Mtetra
.618 .642 .852 r
.21239 .3947 .21659 .40124 .22303 .39946 .21883 .39286 Mtetra
.618 .641 .851 r
.21883 .39286 .22303 .39946 .22948 .39767 .22529 .39102 Mtetra
.617 .639 .85 r
.22529 .39102 .22948 .39767 .23595 .39589 .23177 .38919 Mtetra
.617 .638 .849 r
.23177 .38919 .23595 .39589 .24243 .3941 .23826 .38734 Mtetra
.617 .636 .847 r
.23826 .38734 .24243 .3941 .24894 .3923 .24477 .38549 Mtetra
.616 .634 .846 r
.24477 .38549 .24894 .3923 .25546 .39051 .2513 .38365 Mtetra
.616 .633 .845 r
.2513 .38365 .25546 .39051 .262 .38872 .25785 .3818 Mtetra
.616 .631 .843 r
.25785 .3818 .262 .38872 .26856 .38692 .26442 .37993 Mtetra
.615 .629 .842 r
.26442 .37993 .26856 .38692 .27513 .38513 .271 .37808 Mtetra
.615 .628 .84 r
.271 .37808 .27513 .38513 .28173 .38333 .2776 .37622 Mtetra
.615 .626 .839 r
.2776 .37622 .28173 .38333 .28834 .38154 .28423 .37436 Mtetra
.614 .624 .837 r
.28423 .37436 .28834 .38154 .29498 .37974 .29087 .37249 Mtetra
.614 .622 .836 r
.29087 .37249 .29498 .37974 .30163 .37794 .29753 .37062 Mtetra
.613 .62 .834 r
.29753 .37062 .30163 .37794 .3083 .37614 .3042 .36875 Mtetra
.613 .618 .832 r
.3042 .36875 .3083 .37614 .31499 .37434 .3109 .36688 Mtetra
.613 .616 .831 r
.3109 .36688 .31499 .37434 .32169 .37253 .31761 .365 Mtetra
.612 .614 .829 r
.31761 .365 .32169 .37253 .32842 .37073 .32435 .36312 Mtetra
.612 .612 .827 r
.32435 .36312 .32842 .37073 .33517 .36893 .3311 .36124 Mtetra
.611 .61 .825 r
.3311 .36124 .33517 .36893 .34193 .36712 .33788 .35936 Mtetra
.611 .608 .823 r
.33788 .35936 .34193 .36712 .34872 .36532 .34467 .35747 Mtetra
.61 .605 .821 r
.34467 .35747 .34872 .36532 .35552 .36352 .35148 .35558 Mtetra
.61 .603 .819 r
.35148 .35558 .35552 .36352 .36235 .36171 .35831 .35369 Mtetra
.609 .601 .817 r
.35831 .35369 .36235 .36171 .36919 .35991 .36516 .3518 Mtetra
.609 .598 .815 r
.36516 .3518 .36919 .35991 .37606 .35811 .37203 .3499 Mtetra
.608 .596 .813 r
.37203 .3499 .37606 .35811 .38294 .3563 .37892 .348 Mtetra
.608 .593 .811 r
.37892 .348 .38294 .3563 .38985 .3545 .38583 .3461 Mtetra
.607 .591 .809 r
.38583 .3461 .38985 .3545 .39677 .3527 .39276 .3442 Mtetra
.607 .588 .807 r
.39276 .3442 .39677 .3527 .40372 .3509 .39971 .34229 Mtetra
.606 .586 .804 r
.39971 .34229 .40372 .3509 .41068 .34909 .40668 .34038 Mtetra
.605 .583 .802 r
.40668 .34038 .41068 .34909 .41767 .3473 .41368 .33847 Mtetra
.605 .58 .8 r
.41368 .33847 .41767 .3473 .42468 .3455 .42069 .33656 Mtetra
.604 .578 .797 r
.42069 .33656 .42468 .3455 .4317 .34369 .42772 .33464 Mtetra
.603 .575 .795 r
.42772 .33464 .4317 .34369 .43875 .3419 .43477 .33272 Mtetra
.603 .572 .792 r
.43477 .33272 .43875 .3419 .44582 .3401 .44185 .3308 Mtetra
.602 .569 .789 r
.44185 .3308 .44582 .3401 .45292 .33831 .44894 .32888 Mtetra
.601 .566 .787 r
.44894 .32888 .45292 .33831 .46003 .33651 .45606 .32695 Mtetra
.601 .563 .784 r
.45606 .32695 .46003 .33651 .46716 .33472 .4632 .32502 Mtetra
.6 .56 .781 r
.4632 .32502 .46716 .33472 .47432 .33293 .47035 .32309 Mtetra
.599 .557 .779 r
.47035 .32309 .47432 .33293 .4815 .33114 .47753 .32115 Mtetra
.599 .554 .776 r
.47753 .32115 .4815 .33114 .4887 .32936 .48474 .31921 Mtetra
.598 .551 .773 r
.48474 .31921 .4887 .32936 .49592 .32757 .49196 .31727 Mtetra
.597 .548 .77 r
.49196 .31727 .49592 .32757 .50317 .32579 .4992 .31533 Mtetra
.596 .544 .767 r
.4992 .31533 .50317 .32579 .51044 .32401 .50647 .31338 Mtetra
.595 .541 .764 r
.50647 .31338 .51044 .32401 .51773 .32223 .51376 .31143 Mtetra
.595 .538 .761 r
.51376 .31143 .51773 .32223 .52504 .32045 .52107 .30947 Mtetra
.594 .535 .758 r
.52107 .30947 .52504 .32045 .53238 .31868 .5284 .30752 Mtetra
.593 .531 .755 r
.5284 .30752 .53238 .31868 .53974 .31691 .53576 .30555 Mtetra
.592 .528 .751 r
.53576 .30555 .53974 .31691 .54712 .31514 .54314 .30359 Mtetra
.591 .524 .748 r
.54314 .30359 .54712 .31514 .55452 .31338 .55054 .30162 Mtetra
.59 .521 .745 r
.55054 .30162 .55452 .31338 .56195 .31161 .55796 .29965 Mtetra
.59 .517 .742 r
.55796 .29965 .56195 .31161 .56941 .30985 .56541 .29766 Mtetra
.588 .514 .738 r
.56541 .29766 .56941 .30985 .57689 .3081 .57288 .29568 Mtetra
.588 .51 .735 r
.57288 .29568 .57689 .3081 .58439 .30634 .58037 .29369 Mtetra
.587 .507 .731 r
.58037 .29369 .58439 .30634 .59192 .30458 .58788 .29169 Mtetra
.586 .503 .728 r
.58788 .29169 .59192 .30458 .59947 .30284 .59542 .28969 Mtetra
.585 .499 .724 r
.59542 .28969 .59947 .30284 .60704 .3011 .60298 .28769 Mtetra
.584 .496 .721 r
.60298 .28769 .60704 .3011 .61464 .29935 .61057 .28567 Mtetra
.583 .492 .717 r
.61057 .28567 .61464 .29935 .62227 .2976 .61818 .28363 Mtetra
.582 .489 .714 r
.61818 .28363 .62227 .2976 .62992 .29584 .62581 .28159 Mtetra
.583 .486 .71 r
.62581 .28159 .62992 .29584 .63759 .29404 .63346 .27949 Mtetra
.584 .483 .706 r
.63346 .27949 .63759 .29404 .64529 .29217 .64114 .27731 Mtetra
.586 .481 .702 r
.64114 .27731 .64529 .29217 .65301 .29019 .64883 .27501 Mtetra
.594 .484 .697 r
.64883 .27501 .65301 .29019 .66073 .2878 .65653 .27231 Mtetra
.601 .485 .693 r
.65653 .27231 .66073 .2878 .66846 .28506 .66424 .26926 Mtetra
.624 .496 .687 r
.66424 .26926 .66846 .28506 .67616 .28121 .67191 .26514 Mtetra
.652 .512 .679 r
.67191 .26514 .67616 .28121 .6838 .27581 .67953 .25953 Mtetra
.672 .522 .673 r
.67953 .25953 .6838 .27581 .69137 .26923 .68709 .25278 Mtetra
.737 .559 .653 r
.68709 .25278 .69137 .26923 .6987 .25813 .69441 .24173 Mtetra
.767 .577 .641 r
.69441 .24173 .6987 .25813 .70585 .24447 .70157 .22825 Mtetra
.806 .6 .624 r
.70157 .22825 .70585 .24447 .71273 .22698 .70848 .21114 Mtetra
.849 .626 .6 r
.70848 .21114 .71273 .22698 .71921 .2041 .71501 .18895 Mtetra
.869 .64 .59 r
.71501 .18895 .71921 .2041 .72546 .17897 .72132 .16466 Mtetra
.938 .566 .225 r
.05191 .36052 .05616 .36643 .05942 .38259 .05519 .37636 Mtetra
.926 .543 .167 r
.05519 .37636 .05942 .38259 .06295 .39733 .05875 .3908 Mtetra
.846 .43 0 r
.05875 .3908 .06295 .39733 .06709 .40835 .0629 .40157 Mtetra
.64 .222 0 r
.0629 .40157 .06709 .40835 .0717 .41648 .06752 .40948 Mtetra
0 .01 .579 r
.06752 .40948 .0717 .41648 .07662 .42267 .07246 .41548 Mtetra
.257 .421 .835 r
.07246 .41548 .07662 .42267 .08208 .42518 .07794 .41786 Mtetra
.378 .487 .844 r
.07794 .41786 .08208 .42518 .08772 .42669 .08358 .41927 Mtetra
.497 .548 .838 r
.08358 .41927 .08772 .42669 .09355 .42688 .08942 .41936 Mtetra
.565 .579 .827 r
.08942 .41936 .09355 .42688 .09954 .42605 .09542 .41847 Mtetra
.583 .586 .821 r
.09542 .41847 .09954 .42605 .1056 .42491 .10148 .41726 Mtetra
.602 .594 .816 r
.10148 .41726 .1056 .42491 .11171 .42338 .1076 .41568 Mtetra
.608 .595 .813 r
.1076 .41568 .11171 .42338 .11786 .42174 .11376 .41397 Mtetra
.611 .596 .811 r
.11376 .41397 .11786 .42174 .12404 .42002 .11995 .4122 Mtetra
.613 .595 .809 r
.11995 .4122 .12404 .42002 .13024 .41825 .12615 .41037 Mtetra
.613 .594 .808 r
.12615 .41037 .13024 .41825 .13646 .41647 .13237 .40854 Mtetra
.613 .593 .807 r
.13237 .40854 .13646 .41647 .14269 .41467 .13861 .40668 Mtetra
.613 .592 .805 r
.13861 .40668 .14269 .41467 .14894 .41287 .14487 .40483 Mtetra
.613 .59 .804 r
.14487 .40483 .14894 .41287 .15521 .41107 .15115 .40296 Mtetra
.612 .589 .803 r
.15115 .40296 .15521 .41107 .16149 .40926 .15744 .40109 Mtetra
.612 .588 .802 r
.15744 .40109 .16149 .40926 .16779 .40746 .16375 .39922 Mtetra
.612 .586 .8 r
.16375 .39922 .16779 .40746 .17411 .40564 .17007 .39735 Mtetra
.612 .585 .799 r
.17007 .39735 .17411 .40564 .18045 .40383 .17641 .39546 Mtetra
.611 .583 .798 r
.17641 .39546 .18045 .40383 .1868 .40201 .18277 .39358 Mtetra
.611 .582 .796 r
.18277 .39358 .1868 .40201 .19317 .40019 .18915 .39169 Mtetra
.61 .58 .795 r
.18915 .39169 .19317 .40019 .19956 .39836 .19555 .38979 Mtetra
.61 .579 .794 r
.19555 .38979 .19956 .39836 .20597 .39653 .20196 .38789 Mtetra
.61 .577 .792 r
.20196 .38789 .20597 .39653 .21239 .3947 .20839 .38598 Mtetra
.609 .575 .791 r
.20839 .38598 .21239 .3947 .21883 .39286 .21483 .38407 Mtetra
.609 .574 .789 r
.21483 .38407 .21883 .39286 .22529 .39102 .2213 .38215 Mtetra
.608 .572 .788 r
.2213 .38215 .22529 .39102 .23177 .38919 .22778 .38024 Mtetra
.608 .57 .786 r
.22778 .38024 .23177 .38919 .23826 .38734 .23428 .37831 Mtetra
.608 .569 .784 r
.23428 .37831 .23826 .38734 .24477 .38549 .2408 .37638 Mtetra
.607 .567 .783 r
.2408 .37638 .24477 .38549 .2513 .38365 .24733 .37445 Mtetra
.607 .565 .781 r
.24733 .37445 .2513 .38365 .25785 .3818 .25389 .37251 Mtetra
.607 .563 .78 r
.25389 .37251 .25785 .3818 .26442 .37993 .26046 .37056 Mtetra
.606 .561 .778 r
.26046 .37056 .26442 .37993 .271 .37808 .26705 .36861 Mtetra
.605 .559 .776 r
.26705 .36861 .271 .37808 .2776 .37622 .27366 .36666 Mtetra
.605 .557 .774 r
.27366 .36666 .2776 .37622 .28423 .37436 .28029 .3647 Mtetra
.605 .556 .773 r
.28029 .3647 .28423 .37436 .29087 .37249 .28693 .36274 Mtetra
.604 .554 .771 r
.28693 .36274 .29087 .37249 .29753 .37062 .2936 .36077 Mtetra
.604 .552 .769 r
.2936 .36077 .29753 .37062 .3042 .36875 .30028 .3588 Mtetra
.603 .55 .767 r
.30028 .3588 .3042 .36875 .3109 .36688 .30698 .35682 Mtetra
.603 .548 .765 r
.30698 .35682 .3109 .36688 .31761 .365 .3137 .35483 Mtetra
.602 .545 .763 r
.3137 .35483 .31761 .365 .32435 .36312 .32044 .35284 Mtetra
.602 .543 .761 r
.32044 .35284 .32435 .36312 .3311 .36124 .32719 .35084 Mtetra
.601 .541 .759 r
.32719 .35084 .3311 .36124 .33788 .35936 .33397 .34884 Mtetra
.601 .539 .757 r
.33397 .34884 .33788 .35936 .34467 .35747 .34077 .34684 Mtetra
.6 .537 .755 r
.34077 .34684 .34467 .35747 .35148 .35558 .34758 .34482 Mtetra
.599 .535 .753 r
.34758 .34482 .35148 .35558 .35831 .35369 .35442 .3428 Mtetra
.599 .532 .751 r
.35442 .3428 .35831 .35369 .36516 .3518 .36127 .34078 Mtetra
.598 .53 .749 r
.36127 .34078 .36516 .3518 .37203 .3499 .36814 .33875 Mtetra
.598 .528 .747 r
.36814 .33875 .37203 .3499 .37892 .348 .37503 .33672 Mtetra
.597 .526 .745 r
.37503 .33672 .37892 .348 .38583 .3461 .38195 .33467 Mtetra
.596 .523 .743 r
.38195 .33467 .38583 .3461 .39276 .3442 .38888 .33263 Mtetra
.596 .521 .74 r
.38888 .33263 .39276 .3442 .39971 .34229 .39583 .33057 Mtetra
.595 .519 .738 r
.39583 .33057 .39971 .34229 .40668 .34038 .4028 .32851 Mtetra
.595 .516 .736 r
.4028 .32851 .40668 .34038 .41368 .33847 .40979 .32644 Mtetra
.594 .514 .734 r
.40979 .32644 .41368 .33847 .42069 .33656 .4168 .32437 Mtetra
.593 .511 .731 r
.4168 .32437 .42069 .33656 .42772 .33464 .42383 .32229 Mtetra
.593 .509 .729 r
.42383 .32229 .42772 .33464 .43477 .33272 .43089 .3202 Mtetra
.592 .506 .727 r
.43089 .3202 .43477 .33272 .44185 .3308 .43796 .3181 Mtetra
.591 .504 .724 r
.43796 .3181 .44185 .3308 .44894 .32888 .44505 .316 Mtetra
.591 .501 .722 r
.44505 .316 .44894 .32888 .45606 .32695 .45216 .31389 Mtetra
.59 .499 .719 r
.45216 .31389 .45606 .32695 .4632 .32502 .45929 .31177 Mtetra
.589 .496 .717 r
.45929 .31177 .4632 .32502 .47035 .32309 .46645 .30964 Mtetra
.589 .494 .714 r
.46645 .30964 .47035 .32309 .47753 .32115 .47362 .30751 Mtetra
.588 .491 .712 r
.47362 .30751 .47753 .32115 .48474 .31921 .48082 .30537 Mtetra
.587 .488 .709 r
.48082 .30537 .48474 .31921 .49196 .31727 .48803 .30321 Mtetra
.586 .486 .707 r
.48803 .30321 .49196 .31727 .4992 .31533 .49527 .30105 Mtetra
.586 .483 .704 r
.49527 .30105 .4992 .31533 .50647 .31338 .50253 .29888 Mtetra
.585 .481 .702 r
.50253 .29888 .50647 .31338 .51376 .31143 .50981 .2967 Mtetra
.584 .478 .699 r
.50981 .2967 .51376 .31143 .52107 .30947 .51711 .29451 Mtetra
.583 .475 .696 r
.51711 .29451 .52107 .30947 .5284 .30752 .52443 .2923 Mtetra
.583 .473 .694 r
.52443 .2923 .5284 .30752 .53576 .30555 .53177 .29009 Mtetra
.582 .47 .691 r
.53177 .29009 .53576 .30555 .54314 .30359 .53913 .28787 Mtetra
.581 .467 .688 r
.53913 .28787 .54314 .30359 .55054 .30162 .54652 .28564 Mtetra
.581 .465 .686 r
.54652 .28564 .55054 .30162 .55796 .29965 .55393 .28339 Mtetra
.58 .462 .683 r
.55393 .28339 .55796 .29965 .56541 .29766 .56135 .28112 Mtetra
.579 .459 .68 r
.56135 .28112 .56541 .29766 .57288 .29568 .5688 .27885 Mtetra
.578 .457 .678 r
.5688 .27885 .57288 .29568 .58037 .29369 .57627 .27656 Mtetra
.578 .454 .675 r
.57627 .27656 .58037 .29369 .58788 .29169 .58377 .27425 Mtetra
.577 .451 .672 r
.58377 .27425 .58788 .29169 .59542 .28969 .59128 .27194 Mtetra
.576 .448 .67 r
.59128 .27194 .59542 .28969 .60298 .28769 .59882 .26961 Mtetra
.576 .446 .667 r
.59882 .26961 .60298 .28769 .61057 .28567 .60637 .26725 Mtetra
.575 .443 .664 r
.60637 .26725 .61057 .28567 .61818 .28363 .61395 .26487 Mtetra
.574 .441 .661 r
.61395 .26487 .61818 .28363 .62581 .28159 .62155 .26248 Mtetra
.574 .439 .659 r
.62155 .26248 .62581 .28159 .63346 .27949 .62917 .26001 Mtetra
.575 .437 .656 r
.62917 .26001 .63346 .27949 .64114 .27731 .63681 .25746 Mtetra
.576 .436 .653 r
.63681 .25746 .64114 .27731 .64883 .27501 .64447 .25479 Mtetra
.583 .438 .65 r
.64447 .25479 .64883 .27501 .65653 .27231 .65213 .25173 Mtetra
.587 .439 .647 r
.65213 .25173 .65653 .27231 .66424 .26926 .65979 .24833 Mtetra
.604 .448 .643 r
.65979 .24833 .66424 .26926 .67191 .26514 .66743 .24393 Mtetra
.625 .461 .639 r
.66743 .24393 .67191 .26514 .67953 .25953 .67501 .23813 Mtetra
.641 .47 .636 r
.67501 .23813 .67953 .25953 .68709 .25278 .68254 .23128 Mtetra
.694 .503 .626 r
.68254 .23128 .68709 .25278 .69441 .24173 .68986 .22044 Mtetra
.721 .521 .62 r
.68986 .22044 .69441 .24173 .70157 .22825 .69703 .20736 Mtetra
.758 .546 .61 r
.69703 .20736 .70157 .22825 .70848 .21114 .70397 .19094 Mtetra
.802 .576 .595 r
.70397 .19094 .70848 .21114 .71501 .18895 .71057 .16986 Mtetra
.825 .594 .589 r
.71057 .16986 .71501 .18895 .72132 .16466 .71697 .14685 Mtetra
.935 .563 .19 r
.04776 .35386 .05191 .36052 .05519 .37636 .05107 .36928 Mtetra
.916 .534 .119 r
.05107 .36928 .05519 .37636 .05875 .3908 .05466 .38331 Mtetra
.792 .393 0 r
.05466 .38331 .05875 .3908 .0629 .40157 .05885 .39374 Mtetra
0 0 .438 r
.05885 .39374 .0629 .40157 .06752 .40948 .06349 .40137 Mtetra
0 .086 .645 r
.06349 .40137 .06752 .40948 .07246 .41548 .06845 .40713 Mtetra
.321 .418 .805 r
.06845 .40713 .07246 .41548 .07794 .41786 .07394 .40936 Mtetra
.416 .469 .807 r
.07394 .40936 .07794 .41786 .08358 .41927 .07959 .41062 Mtetra
.512 .519 .801 r
.07959 .41062 .08358 .41927 .08942 .41936 .08545 .41061 Mtetra
.567 .547 .791 r
.08545 .41061 .08942 .41936 .09542 .41847 .09145 .40963 Mtetra
.582 .553 .787 r
.09145 .40963 .09542 .41847 .10148 .41726 .09752 .40834 Mtetra
.599 .56 .782 r
.09752 .40834 .10148 .41726 .1076 .41568 .10365 .40669 Mtetra
.604 .561 .78 r
.10365 .40669 .1076 .41568 .11376 .41397 .10981 .40492 Mtetra
.606 .562 .778 r
.10981 .40492 .11376 .41397 .11995 .4122 .116 .40308 Mtetra
.608 .561 .777 r
.116 .40308 .11995 .4122 .12615 .41037 .12221 .40119 Mtetra
.608 .56 .775 r
.12221 .40119 .12615 .41037 .13237 .40854 .12844 .39928 Mtetra
.608 .559 .774 r
.12844 .39928 .13237 .40854 .13861 .40668 .13469 .39736 Mtetra
.607 .558 .773 r
.13469 .39736 .13861 .40668 .14487 .40483 .14095 .39543 Mtetra
.607 .556 .772 r
.14095 .39543 .14487 .40483 .15115 .40296 .14723 .3935 Mtetra
.607 .555 .77 r
.14723 .3935 .15115 .40296 .15744 .40109 .15353 .39155 Mtetra
.607 .554 .769 r
.15353 .39155 .15744 .40109 .16375 .39922 .15984 .38961 Mtetra
.606 .552 .768 r
.15984 .38961 .16375 .39922 .17007 .39735 .16617 .38765 Mtetra
.606 .551 .766 r
.16617 .38765 .17007 .39735 .17641 .39546 .17252 .38569 Mtetra
.606 .549 .765 r
.17252 .38569 .17641 .39546 .18277 .39358 .17889 .38372 Mtetra
.605 .548 .764 r
.17889 .38372 .18277 .39358 .18915 .39169 .18527 .38175 Mtetra
.605 .546 .762 r
.18527 .38175 .18915 .39169 .19555 .38979 .19167 .37977 Mtetra
.605 .545 .761 r
.19167 .37977 .19555 .38979 .20196 .38789 .19809 .37778 Mtetra
.604 .543 .759 r
.19809 .37778 .20196 .38789 .20839 .38598 .20452 .37579 Mtetra
.604 .542 .758 r
.20452 .37579 .20839 .38598 .21483 .38407 .21097 .37378 Mtetra
.604 .54 .756 r
.21097 .37378 .21483 .38407 .2213 .38215 .21744 .37177 Mtetra
.603 .538 .755 r
.21744 .37177 .2213 .38215 .22778 .38024 .22393 .36976 Mtetra
.603 .537 .753 r
.22393 .36976 .22778 .38024 .23428 .37831 .23044 .36774 Mtetra
.602 .535 .751 r
.23044 .36774 .23428 .37831 .2408 .37638 .23696 .36571 Mtetra
.602 .533 .75 r
.23696 .36571 .2408 .37638 .24733 .37445 .2435 .36368 Mtetra
.601 .532 .748 r
.2435 .36368 .24733 .37445 .25389 .37251 .25006 .36163 Mtetra
.601 .53 .747 r
.25006 .36163 .25389 .37251 .26046 .37056 .25663 .35958 Mtetra
.601 .528 .745 r
.25663 .35958 .26046 .37056 .26705 .36861 .26323 .35752 Mtetra
.6 .526 .743 r
.26323 .35752 .26705 .36861 .27366 .36666 .26984 .35546 Mtetra
.6 .525 .742 r
.26984 .35546 .27366 .36666 .28029 .3647 .27647 .35339 Mtetra
.599 .523 .74 r
.27647 .35339 .28029 .3647 .28693 .36274 .28312 .35131 Mtetra
.599 .521 .738 r
.28312 .35131 .28693 .36274 .2936 .36077 .28978 .34922 Mtetra
.598 .519 .736 r
.28978 .34922 .2936 .36077 .30028 .3588 .29647 .34712 Mtetra
.598 .517 .735 r
.29647 .34712 .30028 .3588 .30698 .35682 .30317 .34502 Mtetra
.597 .515 .733 r
.30317 .34502 .30698 .35682 .3137 .35483 .3099 .3429 Mtetra
.597 .514 .731 r
.3099 .3429 .3137 .35483 .32044 .35284 .31664 .34078 Mtetra
.596 .512 .729 r
.31664 .34078 .32044 .35284 .32719 .35084 .3234 .33865 Mtetra
.596 .51 .727 r
.3234 .33865 .32719 .35084 .33397 .34884 .33017 .33652 Mtetra
.595 .508 .725 r
.33017 .33652 .33397 .34884 .34077 .34684 .33697 .33437 Mtetra
.595 .506 .723 r
.33697 .33437 .34077 .34684 .34758 .34482 .34379 .33221 Mtetra
.594 .504 .721 r
.34379 .33221 .34758 .34482 .35442 .3428 .35062 .33005 Mtetra
.594 .502 .719 r
.35062 .33005 .35442 .3428 .36127 .34078 .35747 .32787 Mtetra
.593 .5 .718 r
.35747 .32787 .36127 .34078 .36814 .33875 .36435 .32569 Mtetra
.593 .498 .716 r
.36435 .32569 .36814 .33875 .37503 .33672 .37124 .32349 Mtetra
.592 .496 .714 r
.37124 .32349 .37503 .33672 .38195 .33467 .37815 .32129 Mtetra
.592 .493 .711 r
.37815 .32129 .38195 .33467 .38888 .33263 .38508 .31907 Mtetra
.591 .491 .709 r
.38508 .31907 .38888 .33263 .39583 .33057 .39203 .31685 Mtetra
.591 .489 .707 r
.39203 .31685 .39583 .33057 .4028 .32851 .399 .31461 Mtetra
.59 .487 .705 r
.399 .31461 .4028 .32851 .40979 .32644 .40598 .31236 Mtetra
.59 .485 .703 r
.40598 .31236 .40979 .32644 .4168 .32437 .41299 .31011 Mtetra
.589 .483 .701 r
.41299 .31011 .4168 .32437 .42383 .32229 .42002 .30784 Mtetra
.588 .481 .699 r
.42002 .30784 .42383 .32229 .43089 .3202 .42706 .30555 Mtetra
.588 .479 .697 r
.42706 .30555 .43089 .3202 .43796 .3181 .43413 .30326 Mtetra
.587 .476 .695 r
.43413 .30326 .43796 .3181 .44505 .316 .44122 .30095 Mtetra
.587 .474 .692 r
.44122 .30095 .44505 .316 .45216 .31389 .44832 .29863 Mtetra
.586 .472 .69 r
.44832 .29863 .45216 .31389 .45929 .31177 .45545 .2963 Mtetra
.585 .47 .688 r
.45545 .2963 .45929 .31177 .46645 .30964 .46259 .29395 Mtetra
.585 .468 .686 r
.46259 .29395 .46645 .30964 .47362 .30751 .46976 .29159 Mtetra
.584 .465 .684 r
.46976 .29159 .47362 .30751 .48082 .30537 .47694 .28922 Mtetra
.584 .463 .681 r
.47694 .28922 .48082 .30537 .48803 .30321 .48414 .28683 Mtetra
.583 .461 .679 r
.48414 .28683 .48803 .30321 .49527 .30105 .49137 .28442 Mtetra
.582 .459 .677 r
.49137 .28442 .49527 .30105 .50253 .29888 .49861 .282 Mtetra
.582 .457 .675 r
.49861 .282 .50253 .29888 .50981 .2967 .50588 .27956 Mtetra
.581 .454 .672 r
.50588 .27956 .50981 .2967 .51711 .29451 .51316 .27711 Mtetra
.581 .452 .67 r
.51316 .27711 .51711 .29451 .52443 .2923 .52046 .27464 Mtetra
.58 .45 .668 r
.52046 .27464 .52443 .2923 .53177 .29009 .52779 .27214 Mtetra
.579 .448 .665 r
.52779 .27214 .53177 .29009 .53913 .28787 .53513 .26964 Mtetra
.579 .445 .663 r
.53513 .26964 .53913 .28787 .54652 .28564 .5425 .26711 Mtetra
.578 .443 .661 r
.5425 .26711 .54652 .28564 .55393 .28339 .54988 .26456 Mtetra
.578 .441 .659 r
.54988 .26456 .55393 .28339 .56135 .28112 .55728 .26199 Mtetra
.577 .439 .656 r
.55728 .26199 .56135 .28112 .5688 .27885 .56471 .2594 Mtetra
.576 .436 .654 r
.56471 .2594 .5688 .27885 .57627 .27656 .57215 .25679 Mtetra
.576 .434 .652 r
.57215 .25679 .57627 .27656 .58377 .27425 .57961 .25415 Mtetra
.575 .432 .649 r
.57961 .25415 .58377 .27425 .59128 .27194 .5871 .25149 Mtetra
.574 .43 .647 r
.5871 .25149 .59128 .27194 .59882 .26961 .5946 .24882 Mtetra
.574 .428 .645 r
.5946 .24882 .59882 .26961 .60637 .26725 .60212 .2461 Mtetra
.573 .426 .643 r
.60212 .2461 .60637 .26725 .61395 .26487 .60967 .24335 Mtetra
.573 .423 .64 r
.60967 .24335 .61395 .26487 .62155 .26248 .61723 .24058 Mtetra
.573 .422 .638 r
.61723 .24058 .62155 .26248 .62917 .26001 .62481 .23772 Mtetra
.574 .42 .636 r
.62481 .23772 .62917 .26001 .63681 .25746 .6324 .23479 Mtetra
.575 .419 .633 r
.6324 .23479 .63681 .25746 .64447 .25479 .64001 .23172 Mtetra
.58 .421 .631 r
.64001 .23172 .64447 .25479 .65213 .25173 .64763 .22829 Mtetra
.584 .422 .629 r
.64763 .22829 .65213 .25173 .65979 .24833 .65525 .22455 Mtetra
.597 .43 .626 r
.65525 .22455 .65979 .24833 .66743 .24393 .66284 .21987 Mtetra
.615 .441 .623 r
.66284 .21987 .66743 .24393 .67501 .23813 .67038 .21392 Mtetra
.628 .448 .621 r
.67038 .21392 .67501 .23813 .68254 .23128 .67788 .20701 Mtetra
.673 .478 .614 r
.67788 .20701 .68254 .23128 .68986 .22044 .68519 .19648 Mtetra
.697 .495 .61 r
.68519 .19648 .68986 .22044 .69703 .20736 .69237 .18393 Mtetra
.731 .519 .604 r
.69237 .18393 .69703 .20736 .70397 .19094 .69934 .16836 Mtetra
.773 .548 .594 r
.69934 .16836 .70397 .19094 .71057 .16986 .70601 .14862 Mtetra
.796 .567 .59 r
.70601 .14862 .71057 .16986 .71697 .14685 .7125 .12716 Mtetra
.903 .543 .08 r
.04392 .3451 .04776 .35386 .05107 .36928 .04731 .35979 Mtetra
.839 .487 0 r
.04731 .35979 .05107 .36928 .05466 .38331 .05097 .37314 Mtetra
0 0 .351 r
.05097 .37314 .05466 .38331 .05885 .39374 .05521 .383 Mtetra
0 .029 .588 r
.05521 .383 .05885 .39374 .06349 .40137 .0599 .39018 Mtetra
.098 .195 .678 r
.0599 .39018 .06349 .40137 .06845 .40713 .06489 .39555 Mtetra
.407 .392 .73 r
.06489 .39555 .06845 .40713 .07394 .40936 .0704 .39753 Mtetra
.464 .424 .729 r
.0704 .39753 .07394 .40936 .07959 .41062 .07607 .39858 Mtetra
.525 .459 .725 r
.07607 .39858 .07959 .41062 .08545 .41061 .08194 .39841 Mtetra
.563 .481 .72 r
.08194 .39841 .08545 .41061 .09145 .40963 .08795 .3973 Mtetra
.573 .486 .718 r
.08795 .3973 .09145 .40963 .09752 .40834 .09402 .39591 Mtetra
.585 .492 .715 r
.09402 .39591 .09752 .40834 .10365 .40669 .10016 .39416 Mtetra
.588 .493 .714 r
.10016 .39416 .10365 .40669 .10981 .40492 .10633 .39229 Mtetra
.59 .493 .713 r
.10633 .39229 .10981 .40492 .116 .40308 .11252 .39036 Mtetra
.591 .493 .711 r
.11252 .39036 .116 .40308 .12221 .40119 .11873 .38837 Mtetra
.591 .492 .71 r
.11873 .38837 .12221 .40119 .12844 .39928 .12496 .38637 Mtetra
.591 .491 .709 r
.12496 .38637 .12844 .39928 .13469 .39736 .13121 .38435 Mtetra
.591 .49 .708 r
.13121 .38435 .13469 .39736 .14095 .39543 .13748 .38232 Mtetra
.59 .489 .707 r
.13748 .38232 .14095 .39543 .14723 .3935 .14376 .38029 Mtetra
.59 .487 .706 r
.14376 .38029 .14723 .3935 .15353 .39155 .15006 .37824 Mtetra
.59 .486 .704 r
.15006 .37824 .15353 .39155 .15984 .38961 .15637 .37619 Mtetra
.589 .485 .703 r
.15637 .37619 .15984 .38961 .16617 .38765 .16271 .37413 Mtetra
.589 .484 .702 r
.16271 .37413 .16617 .38765 .17252 .38569 .16906 .37206 Mtetra
.589 .483 .701 r
.16906 .37206 .17252 .38569 .17889 .38372 .17542 .36998 Mtetra
.588 .481 .7 r
.17542 .36998 .17889 .38372 .18527 .38175 .18181 .3679 Mtetra
.588 .48 .698 r
.18181 .3679 .18527 .38175 .19167 .37977 .18821 .3658 Mtetra
.588 .479 .697 r
.18821 .3658 .19167 .37977 .19809 .37778 .19463 .36369 Mtetra
.587 .478 .696 r
.19463 .36369 .19809 .37778 .20452 .37579 .20106 .36158 Mtetra
.587 .476 .695 r
.20106 .36158 .20452 .37579 .21097 .37378 .20751 .35945 Mtetra
.587 .475 .693 r
.20751 .35945 .21097 .37378 .21744 .37177 .21398 .35732 Mtetra
.586 .474 .692 r
.21398 .35732 .21744 .37177 .22393 .36976 .22047 .35518 Mtetra
.586 .473 .691 r
.22047 .35518 .22393 .36976 .23044 .36774 .22697 .35302 Mtetra
.586 .471 .689 r
.22697 .35302 .23044 .36774 .23696 .36571 .2335 .35086 Mtetra
.585 .47 .688 r
.2335 .35086 .23696 .36571 .2435 .36368 .24004 .34869 Mtetra
.585 .469 .687 r
.24004 .34869 .2435 .36368 .25006 .36163 .24659 .34651 Mtetra
.585 .467 .685 r
.24659 .34651 .25006 .36163 .25663 .35958 .25317 .34431 Mtetra
.584 .466 .684 r
.25317 .34431 .25663 .35958 .26323 .35752 .25976 .34211 Mtetra
.584 .464 .683 r
.25976 .34211 .26323 .35752 .26984 .35546 .26637 .33991 Mtetra
.584 .463 .681 r
.26637 .33991 .26984 .35546 .27647 .35339 .273 .33768 Mtetra
.583 .462 .68 r
.273 .33768 .27647 .35339 .28312 .35131 .27965 .33545 Mtetra
.583 .46 .678 r
.27965 .33545 .28312 .35131 .28978 .34922 .28631 .3332 Mtetra
.582 .459 .677 r
.28631 .3332 .28978 .34922 .29647 .34712 .29299 .33095 Mtetra
.582 .457 .676 r
.29299 .33095 .29647 .34712 .30317 .34502 .29969 .32868 Mtetra
.582 .456 .674 r
.29969 .32868 .30317 .34502 .3099 .3429 .30641 .3264 Mtetra
.581 .455 .673 r
.30641 .3264 .3099 .3429 .31664 .34078 .31315 .32411 Mtetra
.581 .453 .671 r
.31315 .32411 .31664 .34078 .3234 .33865 .3199 .3218 Mtetra
.58 .452 .67 r
.3199 .3218 .3234 .33865 .33017 .33652 .32667 .31949 Mtetra
.58 .45 .668 r
.32667 .31949 .33017 .33652 .33697 .33437 .33347 .31716 Mtetra
.579 .449 .667 r
.33347 .31716 .33697 .33437 .34379 .33221 .34027 .31482 Mtetra
.579 .447 .665 r
.34027 .31482 .34379 .33221 .35062 .33005 .3471 .31246 Mtetra
.579 .446 .664 r
.3471 .31246 .35062 .33005 .35747 .32787 .35395 .3101 Mtetra
.578 .444 .662 r
.35395 .3101 .35747 .32787 .36435 .32569 .36081 .30772 Mtetra
.578 .443 .661 r
.36081 .30772 .36435 .32569 .37124 .32349 .36769 .30532 Mtetra
.577 .441 .659 r
.36769 .30532 .37124 .32349 .37815 .32129 .3746 .30291 Mtetra
.577 .44 .658 r
.3746 .30291 .37815 .32129 .38508 .31907 .38151 .30049 Mtetra
.577 .438 .656 r
.38151 .30049 .38508 .31907 .39203 .31685 .38845 .29805 Mtetra
.576 .437 .655 r
.38845 .29805 .39203 .31685 .399 .31461 .39541 .2956 Mtetra
.576 .435 .653 r
.39541 .2956 .399 .31461 .40598 .31236 .40239 .29313 Mtetra
.575 .434 .651 r
.40239 .29313 .40598 .31236 .41299 .31011 .40938 .29065 Mtetra
.575 .432 .65 r
.40938 .29065 .41299 .31011 .42002 .30784 .41639 .28815 Mtetra
.574 .431 .648 r
.41639 .28815 .42002 .30784 .42706 .30555 .42342 .28563 Mtetra
.574 .429 .647 r
.42342 .28563 .42706 .30555 .43413 .30326 .43047 .28309 Mtetra
.574 .428 .645 r
.43047 .28309 .43413 .30326 .44122 .30095 .43754 .28054 Mtetra
.573 .426 .644 r
.43754 .28054 .44122 .30095 .44832 .29863 .44463 .27797 Mtetra
.573 .425 .642 r
.44463 .27797 .44832 .29863 .45545 .2963 .45173 .27539 Mtetra
.572 .423 .641 r
.45173 .27539 .45545 .2963 .46259 .29395 .45886 .27278 Mtetra
.572 .422 .639 r
.45886 .27278 .46259 .29395 .46976 .29159 .466 .27015 Mtetra
.571 .42 .637 r
.466 .27015 .46976 .29159 .47694 .28922 .47316 .26751 Mtetra
.571 .419 .636 r
.47316 .26751 .47694 .28922 .48414 .28683 .48035 .26484 Mtetra
.571 .417 .634 r
.48035 .26484 .48414 .28683 .49137 .28442 .48755 .26215 Mtetra
.57 .416 .633 r
.48755 .26215 .49137 .28442 .49861 .282 .49476 .25944 Mtetra
.57 .414 .631 r
.49476 .25944 .49861 .282 .50588 .27956 .502 .25671 Mtetra
.569 .413 .63 r
.502 .25671 .50588 .27956 .51316 .27711 .50926 .25395 Mtetra
.569 .411 .628 r
.50926 .25395 .51316 .27711 .52046 .27464 .51653 .25118 Mtetra
.569 .41 .626 r
.51653 .25118 .52046 .27464 .52779 .27214 .52382 .24837 Mtetra
.568 .408 .625 r
.52382 .24837 .52779 .27214 .53513 .26964 .53113 .24555 Mtetra
.568 .407 .623 r
.53113 .24555 .53513 .26964 .5425 .26711 .53846 .2427 Mtetra
.567 .406 .622 r
.53846 .2427 .5425 .26711 .54988 .26456 .54581 .23982 Mtetra
.567 .404 .62 r
.54581 .23982 .54988 .26456 .55728 .26199 .55318 .23691 Mtetra
.567 .403 .619 r
.55318 .23691 .55728 .26199 .56471 .2594 .56056 .23398 Mtetra
.566 .401 .617 r
.56056 .23398 .56471 .2594 .57215 .25679 .56796 .23102 Mtetra
.566 .4 .615 r
.56796 .23102 .57215 .25679 .57961 .25415 .57538 .22803 Mtetra
.566 .398 .614 r
.57538 .22803 .57961 .25415 .5871 .25149 .58282 .225 Mtetra
.565 .397 .612 r
.58282 .225 .5871 .25149 .5946 .24882 .59027 .22196 Mtetra
.565 .396 .611 r
.59027 .22196 .5946 .24882 .60212 .2461 .59775 .21886 Mtetra
.565 .394 .609 r
.59775 .21886 .60212 .2461 .60967 .24335 .60524 .21574 Mtetra
.564 .393 .608 r
.60524 .21574 .60967 .24335 .61723 .24058 .61275 .21258 Mtetra
.565 .392 .606 r
.61275 .21258 .61723 .24058 .62481 .23772 .62027 .20934 Mtetra
.565 .391 .605 r
.62027 .20934 .62481 .23772 .6324 .23479 .62781 .20602 Mtetra
.566 .391 .604 r
.62781 .20602 .6324 .23479 .64001 .23172 .63536 .20257 Mtetra
.569 .392 .602 r
.63536 .20257 .64001 .23172 .64763 .22829 .64292 .19879 Mtetra
.572 .393 .601 r
.64292 .19879 .64763 .22829 .65525 .22455 .65048 .19474 Mtetra
.582 .399 .599 r
.65048 .19474 .65525 .22455 .66284 .21987 .65801 .18986 Mtetra
.595 .408 .598 r
.65801 .18986 .66284 .21987 .67038 .21392 .66551 .18387 Mtetra
.605 .414 .597 r
.66551 .18387 .67038 .21392 .67788 .20701 .67297 .17703 Mtetra
.64 .439 .594 r
.67297 .17703 .67788 .20701 .68519 .19648 .68026 .16706 Mtetra
.66 .453 .593 r
.68026 .16706 .68519 .19648 .69237 .18393 .68745 .15535 Mtetra
.689 .475 .591 r
.68745 .15535 .69237 .18393 .69934 .16836 .69446 .14102 Mtetra
.727 .503 .587 r
.69446 .14102 .69934 .16836 .70601 .14862 .70121 .12311 Mtetra
.75 .523 .586 r
.70121 .12311 .70601 .14862 .7125 .12716 .70781 .10371 Mtetra
.812 .484 0 r
.04034 .33454 .04392 .3451 .04731 .35979 .04384 .34825 Mtetra
0 0 .209 r
.04384 .34825 .04731 .35979 .05097 .37314 .04761 .36068 Mtetra
0 0 .493 r
.04761 .36068 .05097 .37314 .05521 .383 .05193 .36981 Mtetra
.07 .135 .624 r
.05193 .36981 .05521 .383 .0599 .39018 .05668 .37638 Mtetra
.242 .245 .662 r
.05668 .37638 .0599 .39018 .06489 .39555 .06173 .38125 Mtetra
.446 .378 .687 r
.06173 .38125 .06489 .39555 .0704 .39753 .06727 .3829 Mtetra
.486 .401 .685 r
.06727 .3829 .0704 .39753 .07607 .39858 .07296 .38369 Mtetra
.53 .428 .683 r
.07296 .38369 .07607 .39858 .08194 .39841 .07884 .38331 Mtetra
.559 .446 .681 r
.07884 .38331 .08194 .39841 .08795 .3973 .08485 .38207 Mtetra
.567 .45 .68 r
.08485 .38207 .08795 .3973 .09402 .39591 .09093 .38054 Mtetra
.576 .455 .678 r
.09093 .38054 .09402 .39591 .10016 .39416 .09706 .37868 Mtetra
.579 .456 .677 r
.09706 .37868 .10016 .39416 .10633 .39229 .10323 .3767 Mtetra
.58 .456 .676 r
.10323 .3767 .10633 .39229 .11252 .39036 .10942 .37466 Mtetra
.581 .456 .675 r
.10942 .37466 .11252 .39036 .11873 .38837 .11563 .37257 Mtetra
.581 .455 .674 r
.11563 .37257 .11873 .38837 .12496 .38637 .12186 .37046 Mtetra
.581 .455 .673 r
.12186 .37046 .12496 .38637 .13121 .38435 .12811 .36833 Mtetra
.581 .454 .672 r
.12811 .36833 .13121 .38435 .13748 .38232 .13437 .36619 Mtetra
.58 .453 .671 r
.13437 .36619 .13748 .38232 .14376 .38029 .14065 .36404 Mtetra
.58 .452 .67 r
.14065 .36404 .14376 .38029 .15006 .37824 .14695 .36188 Mtetra
.58 .451 .669 r
.14695 .36188 .15006 .37824 .15637 .37619 .15327 .35971 Mtetra
.58 .45 .668 r
.15327 .35971 .15637 .37619 .16271 .37413 .1596 .35754 Mtetra
.58 .449 .667 r
.1596 .35754 .16271 .37413 .16906 .37206 .16594 .35534 Mtetra
.579 .448 .666 r
.16594 .35534 .16906 .37206 .17542 .36998 .17231 .35314 Mtetra
.579 .447 .666 r
.17231 .35314 .17542 .36998 .18181 .3679 .17869 .35093 Mtetra
.579 .446 .665 r
.17869 .35093 .18181 .3679 .18821 .3658 .18509 .3487 Mtetra
.578 .445 .664 r
.18509 .3487 .18821 .3658 .19463 .36369 .1915 .34647 Mtetra
.578 .444 .663 r
.1915 .34647 .19463 .36369 .20106 .36158 .19793 .34422 Mtetra
.578 .444 .662 r
.19793 .34422 .20106 .36158 .20751 .35945 .20438 .34196 Mtetra
.578 .443 .66 r
.20438 .34196 .20751 .35945 .21398 .35732 .21085 .33969 Mtetra
.577 .442 .659 r
.21085 .33969 .21398 .35732 .22047 .35518 .21733 .33741 Mtetra
.577 .441 .658 r
.21733 .33741 .22047 .35518 .22697 .35302 .22383 .33511 Mtetra
.577 .44 .657 r
.22383 .33511 .22697 .35302 .2335 .35086 .23035 .33281 Mtetra
.577 .439 .656 r
.23035 .33281 .2335 .35086 .24004 .34869 .23688 .33049 Mtetra
.576 .438 .655 r
.23688 .33049 .24004 .34869 .24659 .34651 .24343 .32816 Mtetra
.576 .437 .654 r
.24343 .32816 .24659 .34651 .25317 .34431 .25 .32581 Mtetra
.576 .435 .653 r
.25 .32581 .25317 .34431 .25976 .34211 .25659 .32345 Mtetra
.575 .434 .652 r
.25659 .32345 .25976 .34211 .26637 .33991 .26319 .32109 Mtetra
.575 .433 .651 r
.26319 .32109 .26637 .33991 .273 .33768 .26981 .3187 Mtetra
.575 .432 .65 r
.26981 .3187 .273 .33768 .27965 .33545 .27645 .31631 Mtetra
.575 .431 .649 r
.27645 .31631 .27965 .33545 .28631 .3332 .2831 .3139 Mtetra
.574 .43 .648 r
.2831 .3139 .28631 .3332 .29299 .33095 .28978 .31147 Mtetra
.574 .429 .647 r
.28978 .31147 .29299 .33095 .29969 .32868 .29647 .30903 Mtetra
.574 .428 .646 r
.29647 .30903 .29969 .32868 .30641 .3264 .30318 .30658 Mtetra
.574 .427 .644 r
.30318 .30658 .30641 .3264 .31315 .32411 .3099 .30411 Mtetra
.573 .426 .643 r
.3099 .30411 .31315 .32411 .3199 .3218 .31664 .30162 Mtetra
.573 .425 .642 r
.31664 .30162 .3199 .3218 .32667 .31949 .32341 .29912 Mtetra
.573 .424 .641 r
.32341 .29912 .32667 .31949 .33347 .31716 .33018 .29661 Mtetra
.572 .423 .64 r
.33018 .29661 .33347 .31716 .34027 .31482 .33698 .29408 Mtetra
.572 .422 .639 r
.33698 .29408 .34027 .31482 .3471 .31246 .34379 .29153 Mtetra
.572 .421 .638 r
.34379 .29153 .3471 .31246 .35395 .3101 .35063 .28896 Mtetra
.571 .42 .636 r
.35063 .28896 .35395 .3101 .36081 .30772 .35747 .28638 Mtetra
.571 .419 .635 r
.35747 .28638 .36081 .30772 .36769 .30532 .36434 .28378 Mtetra
.571 .417 .634 r
.36434 .28378 .36769 .30532 .3746 .30291 .37123 .28117 Mtetra
.571 .416 .633 r
.37123 .28117 .3746 .30291 .38151 .30049 .37813 .27853 Mtetra
.57 .415 .632 r
.37813 .27853 .38151 .30049 .38845 .29805 .38505 .27588 Mtetra
.57 .414 .631 r
.38505 .27588 .38845 .29805 .39541 .2956 .39199 .27321 Mtetra
.57 .413 .63 r
.39199 .27321 .39541 .2956 .40239 .29313 .39894 .27052 Mtetra
.569 .412 .628 r
.39894 .27052 .40239 .29313 .40938 .29065 .40592 .26781 Mtetra
.569 .411 .627 r
.40592 .26781 .40938 .29065 .41639 .28815 .41291 .26508 Mtetra
.569 .41 .626 r
.41291 .26508 .41639 .28815 .42342 .28563 .41992 .26233 Mtetra
.569 .409 .625 r
.41992 .26233 .42342 .28563 .43047 .28309 .42694 .25956 Mtetra
.568 .408 .624 r
.42694 .25956 .43047 .28309 .43754 .28054 .43399 .25677 Mtetra
.568 .407 .623 r
.43399 .25677 .43754 .28054 .44463 .27797 .44105 .25395 Mtetra
.568 .406 .621 r
.44105 .25395 .44463 .27797 .45173 .27539 .44813 .25112 Mtetra
.568 .405 .62 r
.44813 .25112 .45173 .27539 .45886 .27278 .45523 .24826 Mtetra
.567 .404 .619 r
.45523 .24826 .45886 .27278 .466 .27015 .46234 .24538 Mtetra
.567 .402 .618 r
.46234 .24538 .466 .27015 .47316 .26751 .46948 .24248 Mtetra
.567 .401 .617 r
.46948 .24248 .47316 .26751 .48035 .26484 .47663 .23954 Mtetra
.566 .4 .616 r
.47663 .23954 .48035 .26484 .48755 .26215 .48379 .23659 Mtetra
.566 .399 .614 r
.48379 .23659 .48755 .26215 .49476 .25944 .49098 .23361 Mtetra
.566 .398 .613 r
.49098 .23361 .49476 .25944 .502 .25671 .49818 .2306 Mtetra
.566 .397 .612 r
.49818 .2306 .502 .25671 .50926 .25395 .5054 .22757 Mtetra
.565 .396 .611 r
.5054 .22757 .50926 .25395 .51653 .25118 .51264 .22451 Mtetra
.565 .395 .61 r
.51264 .22451 .51653 .25118 .52382 .24837 .51989 .22142 Mtetra
.565 .394 .609 r
.51989 .22142 .52382 .24837 .53113 .24555 .52716 .21831 Mtetra
.565 .393 .608 r
.52716 .21831 .53113 .24555 .53846 .2427 .53445 .21516 Mtetra
.564 .392 .606 r
.53445 .21516 .53846 .2427 .54581 .23982 .54175 .21198 Mtetra
.564 .391 .605 r
.54175 .21198 .54581 .23982 .55318 .23691 .54907 .20878 Mtetra
.564 .39 .604 r
.54907 .20878 .55318 .23691 .56056 .23398 .55641 .20554 Mtetra
.564 .389 .603 r
.55641 .20554 .56056 .23398 .56796 .23102 .56377 .20227 Mtetra
.564 .388 .602 r
.56377 .20227 .56796 .23102 .57538 .22803 .57114 .19896 Mtetra
.563 .387 .601 r
.57114 .19896 .57538 .22803 .58282 .225 .57852 .19562 Mtetra
.563 .386 .6 r
.57852 .19562 .58282 .225 .59027 .22196 .58593 .19226 Mtetra
.563 .385 .599 r
.58593 .19226 .59027 .22196 .59775 .21886 .59334 .18884 Mtetra
.563 .385 .598 r
.59334 .18884 .59775 .21886 .60524 .21574 .60078 .18539 Mtetra
.563 .384 .597 r
.60078 .18539 .60524 .21574 .61275 .21258 .60823 .18191 Mtetra
.563 .383 .595 r
.60823 .18191 .61275 .21258 .62027 .20934 .61569 .17834 Mtetra
.563 .383 .594 r
.61569 .17834 .62027 .20934 .62781 .20602 .62317 .1747 Mtetra
.564 .382 .593 r
.62317 .1747 .62781 .20602 .63536 .20257 .63066 .17094 Mtetra
.567 .384 .592 r
.63066 .17094 .63536 .20257 .64292 .19879 .63815 .1669 Mtetra
.57 .385 .592 r
.63815 .1669 .64292 .19879 .65048 .19474 .64565 .16262 Mtetra
.578 .39 .591 r
.64565 .16262 .65048 .19474 .65801 .18986 .65313 .15763 Mtetra
.588 .397 .59 r
.65313 .15763 .65801 .18986 .66551 .18387 .66058 .1517 Mtetra
.596 .403 .59 r
.66058 .1517 .66551 .18387 .67297 .17703 .66799 .14506 Mtetra
.625 .423 .588 r
.66799 .14506 .67297 .17703 .68026 .16706 .67528 .13579 Mtetra
.643 .436 .588 r
.67528 .13579 .68026 .16706 .68745 .15535 .68247 .12506 Mtetra
.668 .455 .588 r
.68247 .12506 .68745 .15535 .69446 .14102 .68952 .11214 Mtetra
.702 .481 .586 r
.68952 .11214 .69446 .14102 .70121 .12311 .69636 .09623 Mtetra
.723 .5 .587 r
.69636 .09623 .70121 .12311 .70781 .10371 .70308 .07907 Mtetra
0 0 .215 r
.03698 .32253 .04034 .33454 .04384 .34825 .04064 .33507 Mtetra
0 0 .361 r
.04064 .33507 .04384 .34825 .04761 .36068 .04454 .3464 Mtetra
0 .035 .561 r
.04454 .3464 .04761 .36068 .05193 .36981 .04896 .35463 Mtetra
.202 .197 .629 r
.04896 .35463 .05193 .36981 .05668 .37638 .05379 .36049 Mtetra
.322 .274 .648 r
.05379 .36049 .05668 .37638 .06173 .38125 .05889 .36476 Mtetra
.47 .371 .661 r
.05889 .36476 .06173 .38125 .06727 .3829 .06446 .36604 Mtetra
.5 .39 .66 r
.06446 .36604 .06727 .3829 .07296 .38369 .07018 .36652 Mtetra
.534 .411 .659 r
.07018 .36652 .07296 .38369 .07884 .38331 .07607 .36592 Mtetra
.557 .426 .658 r
.07607 .36592 .07884 .38331 .08485 .38207 .08209 .3645 Mtetra
.563 .429 .656 r
.08209 .3645 .08485 .38207 .09093 .38054 .08817 .36283 Mtetra
.571 .434 .655 r
.08817 .36283 .09093 .38054 .09706 .37868 .0943 .36084 Mtetra
.573 .434 .654 r
.0943 .36084 .09706 .37868 .10323 .3767 .10046 .35875 Mtetra
.574 .435 .654 r
.10046 .35875 .10323 .3767 .10942 .37466 .10665 .35659 Mtetra
.575 .434 .653 r
.10665 .35659 .10942 .37466 .11563 .37257 .11286 .35438 Mtetra
.575 .434 .652 r
.11286 .35438 .11563 .37257 .12186 .37046 .11908 .35216 Mtetra
.575 .433 .651 r
.11908 .35216 .12186 .37046 .12811 .36833 .12533 .34991 Mtetra
.575 .433 .65 r
.12533 .34991 .12811 .36833 .13437 .36619 .13159 .34765 Mtetra
.574 .432 .65 r
.13159 .34765 .13437 .36619 .14065 .36404 .13786 .34538 Mtetra
.574 .431 .649 r
.13786 .34538 .14065 .36404 .14695 .36188 .14415 .3431 Mtetra
.574 .43 .648 r
.14415 .3431 .14695 .36188 .15327 .35971 .15046 .3408 Mtetra
.574 .429 .647 r
.15046 .3408 .15327 .35971 .1596 .35754 .15679 .3385 Mtetra
.574 .429 .646 r
.15679 .3385 .1596 .35754 .16594 .35534 .16313 .33617 Mtetra
.573 .428 .646 r
.16313 .33617 .16594 .35534 .17231 .35314 .16949 .33384 Mtetra
.573 .427 .645 r
.16949 .33384 .17231 .35314 .17869 .35093 .17586 .3315 Mtetra
.573 .427 .644 r
.17586 .3315 .17869 .35093 .18509 .3487 .18225 .32913 Mtetra
.573 .426 .643 r
.18225 .32913 .18509 .3487 .1915 .34647 .18866 .32676 Mtetra
.573 .425 .642 r
.18866 .32676 .1915 .34647 .19793 .34422 .19508 .32437 Mtetra
.573 .424 .641 r
.19508 .32437 .19793 .34422 .20438 .34196 .20152 .32197 Mtetra
.572 .423 .641 r
.20152 .32197 .20438 .34196 .21085 .33969 .20798 .31955 Mtetra
.572 .422 .64 r
.20798 .31955 .21085 .33969 .21733 .33741 .21446 .31712 Mtetra
.572 .422 .639 r
.21446 .31712 .21733 .33741 .22383 .33511 .22095 .31468 Mtetra
.572 .421 .638 r
.22095 .31468 .22383 .33511 .23035 .33281 .22745 .31222 Mtetra
.571 .42 .637 r
.22745 .31222 .23035 .33281 .23688 .33049 .23398 .30975 Mtetra
.571 .419 .636 r
.23398 .30975 .23688 .33049 .24343 .32816 .24052 .30726 Mtetra
.571 .418 .635 r
.24052 .30726 .24343 .32816 .25 .32581 .24708 .30475 Mtetra
.571 .418 .634 r
.24708 .30475 .25 .32581 .25659 .32345 .25365 .30223 Mtetra
.571 .417 .633 r
.25365 .30223 .25659 .32345 .26319 .32109 .26024 .2997 Mtetra
.57 .416 .633 r
.26024 .2997 .26319 .32109 .26981 .3187 .26685 .29715 Mtetra
.57 .415 .632 r
.26685 .29715 .26981 .3187 .27645 .31631 .27348 .29458 Mtetra
.57 .414 .631 r
.27348 .29458 .27645 .31631 .2831 .3139 .28012 .292 Mtetra
.57 .413 .63 r
.28012 .292 .2831 .3139 .28978 .31147 .28678 .2894 Mtetra
.57 .413 .629 r
.28678 .2894 .28978 .31147 .29647 .30903 .29346 .28678 Mtetra
.569 .412 .628 r
.29346 .28678 .29647 .30903 .30318 .30658 .30015 .28415 Mtetra
.569 .411 .627 r
.30015 .28415 .30318 .30658 .3099 .30411 .30686 .28149 Mtetra
.569 .41 .626 r
.30686 .28149 .3099 .30411 .31664 .30162 .31359 .27882 Mtetra
.569 .409 .625 r
.31359 .27882 .31664 .30162 .32341 .29912 .32033 .27613 Mtetra
.569 .408 .624 r
.32033 .27613 .32341 .29912 .33018 .29661 .3271 .27343 Mtetra
.568 .407 .623 r
.3271 .27343 .33018 .29661 .33698 .29408 .33387 .2707 Mtetra
.568 .407 .622 r
.33387 .2707 .33698 .29408 .34379 .29153 .34067 .26796 Mtetra
.568 .406 .621 r
.34067 .26796 .34379 .29153 .35063 .28896 .34748 .26519 Mtetra
.568 .405 .62 r
.34748 .26519 .35063 .28896 .35747 .28638 .35431 .26241 Mtetra
.568 .404 .62 r
.35431 .26241 .35747 .28638 .36434 .28378 .36116 .2596 Mtetra
.567 .403 .619 r
.36116 .2596 .36434 .28378 .37123 .28117 .36802 .25678 Mtetra
.567 .402 .618 r
.36802 .25678 .37123 .28117 .37813 .27853 .3749 .25394 Mtetra
.567 .401 .617 r
.3749 .25394 .37813 .27853 .38505 .27588 .3818 .25107 Mtetra
.567 .401 .616 r
.3818 .25107 .38505 .27588 .39199 .27321 .38871 .24818 Mtetra
.566 .4 .615 r
.38871 .24818 .39199 .27321 .39894 .27052 .39564 .24527 Mtetra
.566 .399 .614 r
.39564 .24527 .39894 .27052 .40592 .26781 .40259 .24234 Mtetra
.566 .398 .613 r
.40259 .24234 .40592 .26781 .41291 .26508 .40955 .23939 Mtetra
.566 .397 .612 r
.40955 .23939 .41291 .26508 .41992 .26233 .41654 .23641 Mtetra
.566 .396 .611 r
.41654 .23641 .41992 .26233 .42694 .25956 .42353 .23341 Mtetra
.565 .396 .61 r
.42353 .23341 .42694 .25956 .43399 .25677 .43055 .23038 Mtetra
.565 .395 .609 r
.43055 .23038 .43399 .25677 .44105 .25395 .43758 .22733 Mtetra
.565 .394 .608 r
.43758 .22733 .44105 .25395 .44813 .25112 .44463 .22426 Mtetra
.565 .393 .607 r
.44463 .22426 .44813 .25112 .45523 .24826 .45169 .22116 Mtetra
.565 .392 .606 r
.45169 .22116 .45523 .24826 .46234 .24538 .45877 .21803 Mtetra
.564 .391 .605 r
.45877 .21803 .46234 .24538 .46948 .24248 .46587 .21489 Mtetra
.46587 .21489 .46948 .24248 .47663 .23954 .47298 .2117 Mtetra
.564 .39 .604 r
.47298 .2117 .47663 .23954 .48379 .23659 .48011 .20849 Mtetra
.564 .389 .603 r
.48011 .20849 .48379 .23659 .49098 .23361 .48726 .20526 Mtetra
.564 .388 .602 r
.48726 .20526 .49098 .23361 .49818 .2306 .49442 .202 Mtetra
.564 .387 .601 r
.49442 .202 .49818 .2306 .5054 .22757 .5016 .19871 Mtetra
.563 .387 .6 r
.5016 .19871 .5054 .22757 .51264 .22451 .50879 .19538 Mtetra
.563 .386 .599 r
.50879 .19538 .51264 .22451 .51989 .22142 .516 .19203 Mtetra
.563 .385 .598 r
.516 .19203 .51989 .22142 .52716 .21831 .52323 .18865 Mtetra
.563 .384 .597 r
.52323 .18865 .52716 .21831 .53445 .21516 .53047 .18524 Mtetra
.563 .384 .596 r
.53047 .18524 .53445 .21516 .54175 .21198 .53773 .18179 Mtetra
.563 .383 .595 r
.53773 .18179 .54175 .21198 .54907 .20878 .545 .17832 Mtetra
.563 .382 .595 r
.545 .17832 .54907 .20878 .55641 .20554 .55228 .1748 Mtetra
.562 .381 .594 r
.55228 .1748 .55641 .20554 .56377 .20227 .55959 .17126 Mtetra
.562 .381 .593 r
.55959 .17126 .56377 .20227 .57114 .19896 .5669 .16768 Mtetra
.562 .38 .592 r
.5669 .16768 .57114 .19896 .57852 .19562 .57423 .16406 Mtetra
.562 .379 .591 r
.57423 .16406 .57852 .19562 .58593 .19226 .58158 .16042 Mtetra
.562 .379 .59 r
.58158 .16042 .58593 .19226 .59334 .18884 .58894 .15673 Mtetra
.562 .378 .59 r
.58894 .15673 .59334 .18884 .60078 .18539 .59631 .153 Mtetra
.562 .377 .589 r
.59631 .153 .60078 .18539 .60823 .18191 .6037 .14924 Mtetra
.562 .377 .588 r
.6037 .14924 .60823 .18191 .61569 .17834 .6111 .14539 Mtetra
.562 .377 .587 r
.6111 .14539 .61569 .17834 .62317 .1747 .61852 .14149 Mtetra
.563 .376 .586 r
.61852 .14149 .62317 .1747 .63066 .17094 .62594 .13749 Mtetra
.565 .378 .586 r
.62594 .13749 .63066 .17094 .63815 .1669 .63337 .13324 Mtetra
.567 .378 .585 r
.63337 .13324 .63815 .1669 .64565 .16262 .6408 .12879 Mtetra
.574 .383 .584 r
.6408 .12879 .64565 .16262 .65313 .15763 .64823 .12377 Mtetra
.582 .388 .584 r
.64823 .12377 .65313 .15763 .66058 .1517 .65562 .11799 Mtetra
.589 .393 .584 r
.65562 .11799 .66058 .1517 .66799 .14506 .663 .11164 Mtetra
.612 .41 .583 r
.663 .11164 .66799 .14506 .67528 .13579 .67027 .10316 Mtetra
.626 .421 .584 r
.67027 .10316 .67528 .13579 .68247 .12506 .67747 .09352 Mtetra
.648 .438 .585 r
.67747 .09352 .68247 .12506 .68952 .11214 .68456 .08212 Mtetra
.677 .461 .585 r
.68456 .08212 .68952 .11214 .69636 .09623 .69149 .06833 Mtetra
.697 .479 .589 r
.69149 .06833 .69636 .09623 .70308 .07907 .69832 .05355 Mtetra
0 0 .435 r
.03413 .30732 .03698 .32253 .04064 .33507 .038 .31826 Mtetra
0 0 .511 r
.038 .31826 .04064 .33507 .04454 .3464 .04209 .32809 Mtetra
.198 .16 .587 r
.04209 .32809 .04454 .3464 .04896 .35463 .04666 .33513 Mtetra
.334 .25 .61 r
.04666 .33513 .04896 .35463 .05379 .36049 .05159 .34004 Mtetra
.402 .294 .615 r
.05159 .34004 .05379 .36049 .05889 .36476 .05678 .34353 Mtetra
.491 .355 .623 r
.05678 .34353 .05889 .36476 .06446 .36604 .06239 .34434 Mtetra
.511 .367 .622 r
.06239 .34434 .06446 .36604 .07018 .36652 .06813 .34442 Mtetra
.534 .383 .622 r
.06813 .34442 .07018 .36652 .07607 .36592 .07403 .34355 Mtetra
.55 .393 .622 r
.07403 .34355 .07607 .36592 .08209 .3645 .08005 .34195 Mtetra
.554 .396 .621 r
.08005 .34195 .08209 .3645 .08817 .36283 .08612 .34011 Mtetra
.559 .399 .621 r
.08612 .34011 .08817 .36283 .0943 .36084 .09224 .33799 Mtetra
.561 .4 .62 r
.09224 .33799 .0943 .36084 .10046 .35875 .0984 .33577 Mtetra
.562 .4 .62 r
.0984 .33577 .10046 .35875 .10665 .35659 .10457 .3335 Mtetra
.563 .4 .619 r
.10457 .3335 .10665 .35659 .11286 .35438 .11077 .33117 Mtetra
.11077 .33117 .11286 .35438 .11908 .35216 .11698 .32883 Mtetra
.563 .4 .618 r
.11698 .32883 .11908 .35216 .12533 .34991 .12321 .32647 Mtetra
.563 .399 .618 r
.12321 .32647 .12533 .34991 .13159 .34765 .12945 .32409 Mtetra
.562 .399 .617 r
.12945 .32409 .13159 .34765 .13786 .34538 .13571 .3217 Mtetra
.562 .398 .617 r
.13571 .3217 .13786 .34538 .14415 .3431 .14199 .3193 Mtetra
.562 .398 .616 r
.14199 .3193 .14415 .3431 .15046 .3408 .14828 .31688 Mtetra
.562 .397 .616 r
.14828 .31688 .15046 .3408 .15679 .3385 .15459 .31445 Mtetra
.562 .397 .615 r
.15459 .31445 .15679 .3385 .16313 .33617 .16092 .312 Mtetra
.16092 .312 .16313 .33617 .16949 .33384 .16726 .30954 Mtetra
.562 .396 .614 r
.16726 .30954 .16949 .33384 .17586 .3315 .17362 .30707 Mtetra
.17362 .30707 .17586 .3315 .18225 .32913 .17999 .30457 Mtetra
.562 .395 .613 r
.17999 .30457 .18225 .32913 .18866 .32676 .18638 .30207 Mtetra
.18638 .30207 .18866 .32676 .19508 .32437 .19279 .29955 Mtetra
.562 .394 .612 r
.19279 .29955 .19508 .32437 .20152 .32197 .19921 .29701 Mtetra
.19921 .29701 .20152 .32197 .20798 .31955 .20565 .29446 Mtetra
.561 .393 .611 r
.20565 .29446 .20798 .31955 .21446 .31712 .2121 .2919 Mtetra
.2121 .2919 .21446 .31712 .22095 .31468 .21858 .28932 Mtetra
.561 .393 .61 r
.21858 .28932 .22095 .31468 .22745 .31222 .22506 .28672 Mtetra
.561 .392 .61 r
.22506 .28672 .22745 .31222 .23398 .30975 .23157 .28411 Mtetra
.561 .392 .609 r
.23157 .28411 .23398 .30975 .24052 .30726 .23809 .28148 Mtetra
.561 .391 .608 r
.23809 .28148 .24052 .30726 .24708 .30475 .24462 .27883 Mtetra
.24462 .27883 .24708 .30475 .25365 .30223 .25118 .27616 Mtetra
.561 .39 .607 r
.25118 .27616 .25365 .30223 .26024 .2997 .25775 .27349 Mtetra
.25775 .27349 .26024 .2997 .26685 .29715 .26433 .27079 Mtetra
.561 .389 .606 r
.26433 .27079 .26685 .29715 .27348 .29458 .27093 .26807 Mtetra
.27093 .26807 .27348 .29458 .28012 .292 .27755 .26534 Mtetra
.561 .389 .605 r
.27755 .26534 .28012 .292 .28678 .2894 .28419 .26259 Mtetra
.561 .388 .605 r
.28419 .26259 .28678 .2894 .29346 .28678 .29084 .25982 Mtetra
.56 .388 .604 r
.29084 .25982 .29346 .28678 .30015 .28415 .2975 .25704 Mtetra
.56 .387 .604 r
.2975 .25704 .30015 .28415 .30686 .28149 .30419 .25423 Mtetra
.56 .387 .603 r
.30419 .25423 .30686 .28149 .31359 .27882 .31089 .25141 Mtetra
.56 .386 .603 r
.31089 .25141 .31359 .27882 .32033 .27613 .3176 .24856 Mtetra
.56 .386 .602 r
.3176 .24856 .32033 .27613 .3271 .27343 .32434 .2457 Mtetra
.56 .385 .601 r
.32434 .2457 .3271 .27343 .33387 .2707 .33109 .24282 Mtetra
.33109 .24282 .33387 .2707 .34067 .26796 .33785 .23992 Mtetra
.56 .385 .6 r
.33785 .23992 .34067 .26796 .34748 .26519 .34463 .23699 Mtetra
.56 .384 .6 r
.34463 .23699 .34748 .26519 .35431 .26241 .35143 .23405 Mtetra
.56 .384 .599 r
.35143 .23405 .35431 .26241 .36116 .2596 .35824 .23109 Mtetra
.56 .383 .599 r
.35824 .23109 .36116 .2596 .36802 .25678 .36508 .2281 Mtetra
.56 .383 .598 r
.36508 .2281 .36802 .25678 .3749 .25394 .37192 .2251 Mtetra
.56 .382 .598 r
.37192 .2251 .3749 .25394 .3818 .25107 .37878 .22207 Mtetra
.56 .382 .597 r
.37878 .22207 .3818 .25107 .38871 .24818 .38566 .21902 Mtetra
.38566 .21902 .38871 .24818 .39564 .24527 .39256 .21595 Mtetra
.56 .381 .596 r
.39256 .21595 .39564 .24527 .40259 .24234 .39947 .21285 Mtetra
.559 .381 .596 r
.39947 .21285 .40259 .24234 .40955 .23939 .40639 .20974 Mtetra
.56 .38 .595 r
.40639 .20974 .40955 .23939 .41654 .23641 .41334 .20659 Mtetra
.559 .38 .595 r
.41334 .20659 .41654 .23641 .42353 .23341 .4203 .20343 Mtetra
.559 .38 .594 r
.4203 .20343 .42353 .23341 .43055 .23038 .42727 .20024 Mtetra
.559 .379 .594 r
.42727 .20024 .43055 .23038 .43758 .22733 .43426 .19703 Mtetra
.559 .379 .593 r
.43426 .19703 .43758 .22733 .44463 .22426 .44127 .19379 Mtetra
.559 .378 .593 r
.44127 .19379 .44463 .22426 .45169 .22116 .44829 .19053 Mtetra
.559 .378 .592 r
.44829 .19053 .45169 .22116 .45877 .21803 .45532 .18724 Mtetra
.45532 .18724 .45877 .21803 .46587 .21489 .46238 .18393 Mtetra
.559 .377 .591 r
.46238 .18393 .46587 .21489 .47298 .2117 .46945 .18058 Mtetra
.46945 .18058 .47298 .2117 .48011 .20849 .47653 .17722 Mtetra
.559 .377 .59 r
.47653 .17722 .48011 .20849 .48726 .20526 .48363 .17383 Mtetra
.559 .376 .59 r
.48363 .17383 .48726 .20526 .49442 .202 .49074 .1704 Mtetra
.559 .376 .589 r
.49074 .1704 .49442 .202 .5016 .19871 .49787 .16696 Mtetra
.49787 .16696 .5016 .19871 .50879 .19538 .50501 .16348 Mtetra
.559 .375 .589 r
.50501 .16348 .50879 .19538 .516 .19203 .51217 .15997 Mtetra
.559 .375 .588 r
.51217 .15997 .516 .19203 .52323 .18865 .51935 .15645 Mtetra
.56 .375 .588 r
.51935 .15645 .52323 .18865 .53047 .18524 .52654 .15288 Mtetra
.56 .375 .587 r
.52654 .15288 .53047 .18524 .53773 .18179 .53374 .14929 Mtetra
.56 .374 .587 r
.53374 .14929 .53773 .18179 .545 .17832 .54096 .14567 Mtetra
.56 .374 .586 r
.54096 .14567 .545 .17832 .55228 .1748 .54819 .14201 Mtetra
.54819 .14201 .55228 .1748 .55959 .17126 .55543 .13833 Mtetra
.55543 .13833 .55959 .17126 .5669 .16768 .56269 .13462 Mtetra
.56 .373 .585 r
.56269 .13462 .5669 .16768 .57423 .16406 .56997 .13087 Mtetra
.56997 .13087 .57423 .16406 .58158 .16042 .57726 .1271 Mtetra
.57726 .1271 .58158 .16042 .58894 .15673 .58456 .12328 Mtetra
.56 .373 .584 r
.58456 .12328 .58894 .15673 .59631 .153 .59187 .11943 Mtetra
.59187 .11943 .59631 .153 .6037 .14924 .5992 .11556 Mtetra
.561 .373 .584 r
.5992 .11556 .6037 .14924 .6111 .14539 .60654 .11161 Mtetra
.561 .373 .583 r
.60654 .11161 .6111 .14539 .61852 .14149 .61389 .10762 Mtetra
.562 .373 .583 r
.61389 .10762 .61852 .14149 .62594 .13749 .62126 .10354 Mtetra
.564 .375 .583 r
.62126 .10354 .62594 .13749 .63337 .13324 .62863 .09928 Mtetra
.566 .376 .583 r
.62863 .09928 .63337 .13324 .6408 .12879 .636 .09485 Mtetra
.571 .379 .583 r
.636 .09485 .6408 .12879 .64823 .12377 .64337 .08998 Mtetra
.578 .385 .583 r
.64337 .08998 .64823 .12377 .65562 .11799 .65073 .08452 Mtetra
.584 .389 .584 r
.65073 .08452 .65562 .11799 .663 .11164 .65807 .07861 Mtetra
.603 .403 .584 r
.65807 .07861 .663 .11164 .67027 .10316 .66533 .07106 Mtetra
.615 .414 .586 r
.66533 .07106 .67027 .10316 .67747 .09352 .67255 .06261 Mtetra
.634 .429 .587 r
.67255 .06261 .67747 .09352 .68456 .08212 .67968 .05281 Mtetra
.659 .449 .589 r
.67968 .05281 .68456 .08212 .69149 .06833 .68669 .04116 Mtetra
.677 .467 .594 r
.68669 .04116 .69149 .06833 .69832 .05355 .69363 .02875 Mtetra
0 0 .523 r
.03145 .29118 .03413 .30732 .038 .31826 .03554 .3004 Mtetra
.1 .091 .56 r
.03554 .3004 .038 .31826 .04209 .32809 .03984 .30863 Mtetra
.288 .215 .598 r
.03984 .30863 .04209 .32809 .04666 .33513 .04457 .31442 Mtetra
.385 .278 .609 r
.04457 .31442 .04666 .33513 .05159 .34004 .04962 .31832 Mtetra
.435 .31 .611 r
.04962 .31832 .05159 .34004 .05678 .34353 .05489 .32099 Mtetra
.504 .357 .615 r
.05489 .32099 .05678 .34353 .06239 .34434 .06054 .32131 Mtetra
.519 .367 .614 r
.06054 .32131 .06239 .34434 .06813 .34442 .06631 .321 Mtetra
.537 .379 .614 r
.06631 .321 .06813 .34442 .07403 .34355 .07222 .31985 Mtetra
.55 .388 .614 r
.07222 .31985 .07403 .34355 .08005 .34195 .07824 .31806 Mtetra
.554 .39 .613 r
.07824 .31806 .08005 .34195 .08612 .34011 .0843 .31606 Mtetra
.558 .393 .613 r
.0843 .31606 .08612 .34011 .09224 .33799 .09041 .31382 Mtetra
.56 .393 .613 r
.09041 .31382 .09224 .33799 .0984 .33577 .09655 .31149 Mtetra
.56 .394 .612 r
.09655 .31149 .0984 .33577 .10457 .3335 .1027 .30911 Mtetra
.561 .394 .612 r
.1027 .30911 .10457 .3335 .11077 .33117 .10888 .30668 Mtetra
.561 .393 .612 r
.10888 .30668 .11077 .33117 .11698 .32883 .11508 .30424 Mtetra
.561 .393 .611 r
.11508 .30424 .11698 .32883 .12321 .32647 .12129 .30177 Mtetra
.12129 .30177 .12321 .32647 .12945 .32409 .12752 .29929 Mtetra
.561 .393 .61 r
.12752 .29929 .12945 .32409 .13571 .3217 .13376 .29679 Mtetra
.561 .392 .61 r
.13376 .29679 .13571 .3217 .14199 .3193 .14002 .29428 Mtetra
.14002 .29428 .14199 .3193 .14828 .31688 .14629 .29176 Mtetra
.561 .392 .609 r
.14629 .29176 .14828 .31688 .15459 .31445 .15258 .28922 Mtetra
.561 .391 .609 r
.15258 .28922 .15459 .31445 .16092 .312 .15889 .28666 Mtetra
.561 .391 .608 r
.15889 .28666 .16092 .312 .16726 .30954 .16521 .28409 Mtetra
.16521 .28409 .16726 .30954 .17362 .30707 .17155 .28151 Mtetra
.561 .39 .608 r
.17155 .28151 .17362 .30707 .17999 .30457 .1779 .2789 Mtetra
.561 .39 .607 r
.1779 .2789 .17999 .30457 .18638 .30207 .18427 .27628 Mtetra
.18427 .27628 .18638 .30207 .19279 .29955 .19065 .27365 Mtetra
.561 .389 .606 r
.19065 .27365 .19279 .29955 .19921 .29701 .19705 .271 Mtetra
.19705 .271 .19921 .29701 .20565 .29446 .20347 .26834 Mtetra
.56 .389 .606 r
.20347 .26834 .20565 .29446 .2121 .2919 .2099 .26566 Mtetra
.56 .388 .605 r
.2099 .26566 .2121 .2919 .21858 .28932 .21635 .26296 Mtetra
.21635 .26296 .21858 .28932 .22506 .28672 .22281 .26024 Mtetra
.56 .388 .604 r
.22281 .26024 .22506 .28672 .23157 .28411 .22929 .25751 Mtetra
.56 .387 .604 r
.22929 .25751 .23157 .28411 .23809 .28148 .23579 .25476 Mtetra
.56 .387 .603 r
.23579 .25476 .23809 .28148 .24462 .27883 .2423 .252 Mtetra
.2423 .252 .24462 .27883 .25118 .27616 .24883 .24921 Mtetra
.56 .386 .603 r
.24883 .24921 .25118 .27616 .25775 .27349 .25537 .24642 Mtetra
.56 .386 .602 r
.25537 .24642 .25775 .27349 .26433 .27079 .26193 .2436 Mtetra
.26193 .2436 .26433 .27079 .27093 .26807 .2685 .24076 Mtetra
.56 .385 .601 r
.2685 .24076 .27093 .26807 .27755 .26534 .27509 .23791 Mtetra
.27509 .23791 .27755 .26534 .28419 .26259 .2817 .23504 Mtetra
.2817 .23504 .28419 .26259 .29084 .25982 .28832 .23215 Mtetra
.56 .385 .6 r
.28832 .23215 .29084 .25982 .2975 .25704 .29496 .22924 Mtetra
.56 .384 .6 r
.29496 .22924 .2975 .25704 .30419 .25423 .30161 .22631 Mtetra
.56 .384 .599 r
.30161 .22631 .30419 .25423 .31089 .25141 .30828 .22336 Mtetra
.30828 .22336 .31089 .25141 .3176 .24856 .31496 .2204 Mtetra
.56 .383 .599 r
.31496 .2204 .3176 .24856 .32434 .2457 .32166 .21741 Mtetra
.56 .383 .598 r
.32166 .21741 .32434 .2457 .33109 .24282 .32838 .21441 Mtetra
.32838 .21441 .33109 .24282 .33785 .23992 .33511 .21138 Mtetra
.56 .382 .597 r
.33511 .21138 .33785 .23992 .34463 .23699 .34186 .20833 Mtetra
.34186 .20833 .34463 .23699 .35143 .23405 .34862 .20527 Mtetra
.34862 .20527 .35143 .23405 .35824 .23109 .3554 .20218 Mtetra
.56 .382 .596 r
.3554 .20218 .35824 .23109 .36508 .2281 .3622 .19908 Mtetra
.56 .381 .596 r
.3622 .19908 .36508 .2281 .37192 .2251 .36901 .19595 Mtetra
.36901 .19595 .37192 .2251 .37878 .22207 .37583 .1928 Mtetra
.56 .381 .595 r
.37583 .1928 .37878 .22207 .38566 .21902 .38267 .18963 Mtetra
.38267 .18963 .38566 .21902 .39256 .21595 .38953 .18643 Mtetra
.56 .38 .594 r
.38953 .18643 .39256 .21595 .39947 .21285 .3964 .18322 Mtetra
.3964 .18322 .39947 .21285 .40639 .20974 .40329 .17999 Mtetra
.40329 .17999 .40639 .20974 .41334 .20659 .41019 .17672 Mtetra
.56 .379 .593 r
.41019 .17672 .41334 .20659 .4203 .20343 .41711 .17344 Mtetra
.41711 .17344 .4203 .20343 .42727 .20024 .42404 .17014 Mtetra
.42404 .17014 .42727 .20024 .43426 .19703 .43099 .16681 Mtetra
.56 .379 .592 r
.43099 .16681 .43426 .19703 .44127 .19379 .43795 .16346 Mtetra
.43795 .16346 .44127 .19379 .44829 .19053 .44493 .16009 Mtetra
.56 .378 .592 r
.44493 .16009 .44829 .19053 .45532 .18724 .45192 .15669 Mtetra
.56 .378 .591 r
.45192 .15669 .45532 .18724 .46238 .18393 .45893 .15327 Mtetra
.561 .378 .591 r
.45893 .15327 .46238 .18393 .46945 .18058 .46595 .14982 Mtetra
.46595 .14982 .46945 .18058 .47653 .17722 .47299 .14635 Mtetra
.561 .378 .59 r
.47299 .14635 .47653 .17722 .48363 .17383 .48004 .14285 Mtetra
.48004 .14285 .48363 .17383 .49074 .1704 .48711 .13933 Mtetra
.561 .377 .59 r
.48711 .13933 .49074 .1704 .49787 .16696 .49419 .13578 Mtetra
.49419 .13578 .49787 .16696 .50501 .16348 .50128 .13221 Mtetra
.561 .377 .589 r
.50128 .13221 .50501 .16348 .51217 .15997 .50839 .12861 Mtetra
.50839 .12861 .51217 .15997 .51935 .15645 .51552 .12499 Mtetra
.51552 .12499 .51935 .15645 .52654 .15288 .52265 .12134 Mtetra
.561 .377 .588 r
.52265 .12134 .52654 .15288 .53374 .14929 .52981 .11767 Mtetra
.52981 .11767 .53374 .14929 .54096 .14567 .53697 .11397 Mtetra
.562 .377 .588 r
.53697 .11397 .54096 .14567 .54819 .14201 .54415 .11024 Mtetra
.562 .376 .588 r
.54415 .11024 .54819 .14201 .55543 .13833 .55134 .10649 Mtetra
.55134 .10649 .55543 .13833 .56269 .13462 .55855 .1027 Mtetra
.562 .376 .587 r
.55855 .1027 .56269 .13462 .56997 .13087 .56577 .09889 Mtetra
.56577 .09889 .56997 .13087 .57726 .1271 .57301 .09506 Mtetra
.57301 .09506 .57726 .1271 .58456 .12328 .58025 .09119 Mtetra
.58025 .09119 .58456 .12328 .59187 .11943 .58751 .08729 Mtetra
.563 .376 .587 r
.58751 .08729 .59187 .11943 .5992 .11556 .59479 .08338 Mtetra
.563 .377 .587 r
.59479 .08338 .5992 .11556 .60654 .11161 .60207 .0794 Mtetra
.60207 .0794 .60654 .11161 .61389 .10762 .60937 .07539 Mtetra
.564 .377 .587 r
.60937 .07539 .61389 .10762 .62126 .10354 .61668 .07131 Mtetra
.566 .378 .587 r
.61668 .07131 .62126 .10354 .62863 .09928 .624 .06709 Mtetra
.567 .38 .587 r
.624 .06709 .62863 .09928 .636 .09485 .63132 .06276 Mtetra
.571 .383 .587 r
.63132 .06276 .636 .09485 .64337 .08998 .63865 .05809 Mtetra
.577 .387 .587 r
.63865 .05809 .64337 .08998 .65073 .08452 .64596 .05298 Mtetra
.582 .391 .588 r
.64596 .05298 .65073 .08452 .65807 .07861 .65327 .04754 Mtetra
.597 .403 .589 r
.65327 .04754 .65807 .07861 .66533 .07106 .66053 .04089 Mtetra
.608 .412 .591 r
.66053 .04089 .66533 .07106 .67255 .06261 .66776 .03358 Mtetra
.623 .425 .593 r
.66776 .03358 .67255 .06261 .67968 .05281 .67493 .02527 Mtetra
.645 .444 .596 r
.67493 .02527 .67968 .05281 .68669 .04116 .68201 .01561 Mtetra
.661 .46 .602 r
.68201 .01561 .68669 .04116 .69363 .02875 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15401 .20938 m
.15862 .21405 L
s
[(-5)] .14478 .20005 .98815 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54659 .05566 m
.55048 .06094 L
s
[(5)] .53881 .04509 .73632 1 Mshowa
.125 Mabswid
.19074 .195 m
.19347 .19784 L
s
.22799 .18041 m
.23069 .18328 L
s
.26579 .16561 m
.26845 .16852 L
s
.30415 .15059 m
.30676 .15354 L
s
.38256 .11989 m
.38509 .12291 L
s
.42265 .10419 m
.42513 .10725 L
s
.46334 .08826 m
.46577 .09135 L
s
.50465 .07208 m
.50703 .07521 L
s
.1178 .22356 m
.1206 .22633 L
s
.0821 .23754 m
.08493 .24027 L
s
.04689 .25133 m
.04976 .25402 L
s
.58918 .03898 m
.59146 .04219 L
s
.63243 .02205 m
.63466 .02529 L
s
.67636 .00485 m
.67853 .00813 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[58]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00boooool2o`0005?ooooo0038ooooo`?o000000?oooooo`000?ooool0
D_ooool00<Kooooo0_l000001?oooooo0000ooooooooool2o`0005;ooooo0033ooooo`?o00001_oo
ool00ol0003oooooo`00001Aooooo`00X?ooool3o`0001gooooo0ol00008ooooo`04ojUeV_l0003o
0000o`00057ooooo002Oooooo`05o`000?ooooooooooooooool000006_ooool2o`0000[ooooo0_nY
MIX01?l0003oooooooooool0001@ooooo`00Xoooool00ol0003oooooooooo`0Eooooo`?o00003?oo
ool2ojUeVP05o`000?ooooooooooooooool00000Coooool00:?ooooo00?o0000ooooooooool04ooo
ool2o`0000;ooooo00?o0000ooooooooool02Oooool01?nULISoZGFJojUeV_l00003ooooo`03o`00
0?oooooooooo04gooooo002Oooooo`Co00004oooool3o`0000oooooo0onULIP00onYMI[o0000oooo
o`03ooooo`03o`000?oooooooooo04cooooo002Oooooo`03o`000?oooooooooo01;ooooo0_l0000A
ooooo`04oim/UonULISoYG6HojEaV0;oZGFJ00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1;ooooo`00Woooool5o`0000gooooo0ol0000Booooo`;oWfbG0onULIP2ojUeVP03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Boooool00:oooooo1?l0000Booooo`04oi]YUonOK9OoWfbG
oim/U`;oYG6H00?oZGFJojegV?l000001Oooool00ol0003oooooooooo`1:ooooo`00[?ooool3o`00
01Gooooo0_nKJIL3oim/U`;oYG6H0_n]MiP00ol0003oooooooooo`02ooooo`;o0000C?ooool00:Wo
oooo0ol0000Gooooo`03oiQWU_nKJIOoVfVG00?oWfbG0_nULIP2ojegV003o`000?oooooooooo00Co
oooo00?o0000ooooooooool0BOooool00:Oooooo0_l0000Hooooo`04oiATU_nHIiKoV6NFoiQWUP;o
VfVG0_nOK9L01OnULISoZ7:FojegV?n]MiSo000000Oooooo00?o0000ooooooooool0B?ooool00:Co
oooo0ol0000Iooooo`;oU6BF0onHIiH2oi]YU`;oWfbG0onXLYH00on]MiSo0000ooooo`06ooooo`03
o`000?oooooooooo04Sooooo002Rooooo`;o00000oooool00ol0003oooooooooo`0Eooooo`04oi=S
U_nDI9KoU6BFoiATUP;oV6NF0_nKJIL2oim/U`?oZ7:F00?o[GNHo`000?ooool01oooool00ol0003o
ooooooooo`17ooooo`00Woooool3o`0001_ooooo00CoTV:Foi=SU_nCHiKoTf>F0_nDI9H2oiQWUP;o
VfVG00?oWfbGoj9]U_nRKIH00_nXLYH00on]MiSo0000ok9jUP08ooooo`03o`000?oooooooooo04Ko
oooo002Mooooo`;o00007Oooool2oi9RUP?oTf>F0_nDI9H3oiQWUP04oi]YUonRKIKoXVfFoj9]UP;o
Z7:F00?o[GNHo`000?nbNYH02?ooool00ol0003oooooooooo`16ooooo`00V_ooool3o`0001gooooo
00?oT62Foi5QU_nBHYH00_nBHYH2oi=SUP;oU6BF0onHIiH01?nKJIOoXVfFoj9]U_nRKIH2ojQbUP03
ok9jU_l0003o/WZF00Wooooo00?o0000ooooooooool0AOooool009Sooooo0_l000000ooooooo0000
ooooo`0Kooooo`?oT62F0_nAHIH2oi9RUP;oTf>F0onDI9H2oiQWUP;oWFVF0_nRKIH2ojQbUP04ok9j
U_l0003o/WZFok9jUPSooooo0_l00016ooooo`00UOooool3o`0001kooooo1On@H9H2oi5QUP;oTV:F
0_nCHiH3oiATUP04oiQWU_nJIiGoWFVFoieYUP?oXVfF00?oZ7:FojefUOl000000_nbNYH9ooooo`03
o`000?oooooooooo04Cooooo002Booooo`?o00007oooool7oi1PUP;oTF6F0_nBHYH3oi=SUP;oU6BF
0_nJIiD2oieYUP?oXVfF0_n]MYD00ol0003o/WZFok9jUP0:ooooo`03o`000?oooooooooo00_ooooo
0ol0000eooooo`00T?ooool2o`00023ooooo2_n@H9H01?nAHIKoTV:Foi9RU_nBHYH2oi=SUP04oiAT
U_nEHiGoVVNEoiYWU@;oWFVF0onRKIH2ojefU@03o`000?nbNYKo/WZF00_ooooo00?o0000oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000003Cooooo002=ooooo`Co00007oooool00on?H9Ko
T62Foi1PUP09oi1PUP;oTF6F0_nBHYH01?nCHiKoTf:EoiESUOnEHiD3oiYWU@;oWFVF0_nRKIH2ojef
U@03o`000?nbNYKo^GnF00_ooooo00?o0000ooooooooool00oooool5o`0000Gooooo00?o0000oooo
ooooool0<_ooool008_ooooo0_l0000Qooooo`?oSf2F2on@H9H2oi5QUP04oi9RU_nBHIGoTf:Eoi=R
U@;oUF>E0onJIiD2oieYUP03oj9]U_nUL9Go[GJE00;o[GJE00?o0000okUoU_niOiH02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo001Zooooo`;o00007?ooool3o`0002;o
oooo1?n?H9H;oi1PUP;oTF6F0_nBHID2oi=RU@?oUF>E0_nJIiD2oieYUP;oYG2E0on]MYD00ol0003o
^GnFokUoUP0<ooooo`03o`000?oooooooooo00Oooooo1?l0000eooooo`00JOooool01?l0003ooooo
ooooool0000Iooooo`;o00009?ooool5ohmPUP_oT62F00CoTF6Foi1PUOnBHIGoTV6E0_nCHYD3oiES
U@;oVVNE0_nMJIH3ojE`U@;o[GJE00?o0000okUoU_niOiH03?ooool2o`0000Sooooo00?o0000oooo
ooooool0=_ooool006Wooooo00Co0000oooooooooooo00005_ooool3o`0002Cooooo2?n?H9H9oi1P
UP03oi1OUOn@H9GoT62E00;oTV6E0onCHYD2oiESU@;oVVNE00?oWFVFoj1[UOnUL9D00_nUL9D2ojef
U@03o`000?niOiKo^GnF00_ooooo00?o0000ooooool000002?ooool5o`0003Cooooo001Yooooo`04
o`000?ooooooooooo`0001Cooooo0_l00003ooooo`03o`000?oooooooooo01oooooo2_n?H9H7oi1P
UP03ohmOUOn@GiGoT5nE00;oT62E0onBHID2oi=RU@;oUF>E0_nJIiD2oj1[U@?oYG2E00?o[GJEok=k
U_l000000_niOiH>ooooo`03o`000?oooooooooo03kooooo001Yooooo`04o`000?ooooooooooo`00
017ooooo0ol0000Uooooo`coSf2F1On@H9H3ohmOU@;oT5nE0on@H9D2oi9QU@;oTf:E0_nEHiD00onJ
IiGoW6REoj1[U@02oj1[U@;oYG2E00?o[GJEok=kU_l000000_niOiH>ooooo`03o`000?oooooooooo
03kooooo001Yooooo`04o`000?ooooooooooo`0000kooooo0ol0000Vooooo`koSf2F0on@H9H5ohmO
U@;oT5nE0on@H9D2oi9QU@;oTf:E0_nEHiD2oiaXU@?oX6^E0_nUL9D2ok=kUP03o`000?niOiKo_hFF
00oooooo00?o0000ooooooooool0?Oooool006[ooooo0_l0000=ooooo`;o00009_oooolAohmPUP03
oi1PU_n?GiGoSenE00GoSenE0on@GiD2oi1PU@;oTV6E0_nCHYD01?nEHiGoUVBEoiaXUOnLJ9D3oj1[
U@;oYG2E0_ncNiH01?l0003o^GnFokn5U_noQIH>ooooo`03o`000?oooooooooo03gooooo001foooo
o`?o00000_ooool00ol0003oooooooooo`0Qoooooa;oSf2F2_n?GiD2oi1OU@;oT62E0_nBHID01?nC
HYGoU6>EoiITUOnFI9D3oiaXU@;oX6^E00KoYG2Eoj]dU_ncNiKo/g^Fo`000?niOiH2okn5UPoooooo
00?o0000ooooooooool0??ooool007Cooooo0_l0000Woooooa;oSf2F3?n?GiD2oi1OU@;oT62E00Co
TV6Eoi9RUOnDHiGoU6>E0_nFI9D3oiaXU@;oX6^E0_n[M9H2ok=kUP04o`000?noQIKo_hFFokn5UQ3o
oooo00?o0000ooooooooool0>oooool0077ooooo0ol0000Woooooa;oSf2F3_n?GiD2oi1OU@;oT62E
0_nBHYD2oiASU@?oUVBE0_nLJ9D2oj1[U@?oZgBF00?o/g^Fo`000?noQIH00_noQIH@ooooo`;o0000
??ooool006oooooo0_l0000Xooooo`03ohmPUon?H9KoSf2F00ooSf2F4?n?GiD2oi1OU@04oi1PUOnA
H9GoTV:Eoi9RU@;oU6>E0onFI9D2oiaXU@03oj1[UOnTKiKoZgBF00;oZgBF00?o/g^Fo`000?noQIH0
0_noQIHAooooo`03o`000?oooooooooo03[ooooo001/ooooo`?o000000?oooooo`000?ooool09Ooo
ool3ohmPU`ooSf2F00?oSenFohmOUOn?GiD03on?GiD01?n@GiGoT62Foi5PUOnAH9D2oi9RU@?oU6>E
0_nFI9D2oiaXU@;oY6nF0on[M9H01?ncNiKo0000okZ0U_noQIH2ol^AUa7ooooo00?o0000oooooooo
ool0>Oooool006Wooooo0ol00005ooooo`03o`000?oooooooooo027ooooo1On?H9L=ohmPUP?oSenF
4?n?GiD3oi1PUP;oTF2E0onBHYD2oiASU@;oUVBE0_nLJ9D3ojA_UP;oZgBF00Co/g^Fo`000?njP9Ko
_hFF0_o;TILAooooo`03o`000?oooooooooo03Wooooo001Wooooo`;o0000:_ooool7ohmPU`_oSf2F
1On?GiH>ohmOU@03ohmPU_n@H9KoT62F00;oT62F0onAH9D2oi9RU@;oU6>E0_nFI9D00onLJ9GoWfbF
ojA_UP02ojA_UP;oZgBF00Co^X2Fo`000?njP9Ko_hFF0_o;TILBooooo`03o`000?oooooooooo03So
oooo001Tooooo`?o0000:_ooool:ohmPU`WoSf2F1_n?GiH<ohmOU@?oSf2F1?n@H9H3oi5PU@;oTV:E
0_nDHiD2oiITU@;oWfbF0onTKiH2oj]dUP03okZ0U_l0003o^X2F00?obi6G4oooool00ol0003ooooo
ooooo`0gooooo`00H_ooool2o`0000;ooooo00?o0000ooooooooool09oooool;ohmPU`OoSf2F2On?
GiH9ohmOU@GoSf2F1On@H9H2oi5PU@;oTV:E0_nDHiD00onFI9GoV6NGoim/UP02oim/UP;oY6nF00Go
ZgBFok1iUon`NIOo0000okZ0UP03ol^AUa?ooooo00?o0000ooooooooool0=oooool005oooooo0ol0
000/ooooo`goSf2G1On?H9H;ohmOUPOoSenE00?oSf2GohmPU_n?H9H01?n?H9H5oi1PUP;oTF2E0_nB
HYD00onDHiGoUVFGoiQWU`02oiQWU`;oWfbF0_nTKiH01_n[M9Ko/7VGok1iUonjP9Ko0000olF<V0;o
bi6G00?odiRFooooooooool04Oooool00ol0003oooooooooo`0fooooo`00GOooool2o`0002gooooo
3on?H9L3ohmPUPgoSenF1On?GiD00on?HIOoSf2GohmPU`07ohmPUPCoT62F0_nAH9D01?nBHYGoTf>G
oiIUUonFIIL3oiQWU`;oWfbF0_nTKiH3ok1iU`03okZ0U_l0003oaHbH00;obi6G00?odiRFoooooooo
ool04?ooool00ol0003oooooo`00000gooooo`00F_ooool3o`0002gooooo00?oSf6GohmPUon?H9L0
3_n?H9L00on?H9KoSenFohmOUP0=ohmOUP?oSenE0on?HIL2ohmPU`OoSf2F1?n@H9H2oi5PU@;oTf>G
0onFIIL2oiQWU`;oWfbF0_nTKiH4ok1iU`03o`000?o5S9Sobi6G00;odiRF5?ooool00ol0003ooooo
ooooo`0eooooo`00=_ooool3o`0001oooooo0_l00002ooooo`03o`000?oooooooooo02Wooooo0on?
HIL?ohmPU`03ohmPU_n?GiKoSenF00koSenF00?oSenEohmQUon?HIL00on?HIL2ohmPU`OoSf2F1?n@
H9H00onAH9GoTF:Goi=SU`02oi=SU`;oUVFG0_nHIiL2oim/UP03ojA_U_nXLiOoZ7>G00?o/7VG00?o
0000olF<V?o5S9P00_oCV9HEooooo`03o`000?oooooooooo03Cooooo000eooooo`05o`000?oooooo
ooooooooool000006oooool3o`0002gooooo1_n?HIL=ohmPU`?oSf2F3on?GiH7ohmQU`?oSf2G1_n?
H9H3oi1PUPCoTF:G0_nCHiL2oiIUU`?oV6NG00CoWfbFojQcUonXLiOoZ7>G0on`NIL00ol0003oaHbH
olF<V002om>HUQKooooo00?o0000ooooooooool0<oooool002oooooo1Ol00005ooooo`03o`000?oo
oooooooo01Kooooo0ol0000^ooooo`SoSf6G3?n?H9L4ohmPUPgoSenF00?oSf6HohmQUon?HIL01on?
HIL2ohmPU`KoSf2F00?oT62Foi1QUonAHYL01?nAHYL2oi=SU`;oUVFG0onHIiL01?nOK9KoZ7>GojQc
UonXLiL3ok1iU`03o`000?o5S9SoaHbH00;odiRF00?ogZ>Gooooooooool04oooool00ol0003ooooo
ooooo`0cooooo`00>Oooool00ol0003oooooooooo`0Dooooo`;o0000;oooool00on?HISoSf6GohmQ
U`08ohmQU`_oSf2G1?n?H9H<ohmOUP;oSf6H2On?HIL2ohmPU`GoSf2F00?oT6:Hoi1QUon@HIL01OnA
HYL2oi=SU`?oUVFG0_nHIiL2oj=`V0?oZ7>G00Co/7VGok^4V_l0003oaHbH0_o=TiP00ooCV9KogZ>G
ooooo`0Eooooo`03o`000?oooooooooo03;ooooo000eooooo`Co00005?ooool3o`0000;ooooo00?o
0000ooooooooool0:_ooool3ohmQV0[oSf6G2on?H9L5ohmPUPWoSenF00?oT6:Hoi1QV?n?HIP00_n?
HIP8ohmQU`;oSf2G0on?H9H3oi1RV0?oT66G1?nAHYL2oi=SU`?oUVFG00CoV6NGoiYYV?nSL9SoXg2H
0onXLiL01?n`NIOo^hBJo`000?o5S9P2olfCV0;ogZ>G5_ooool00ol0003oooooooooo`0booooo`00
=Oooool00ol0003oooooooooo`0Cooooo`;o0000<?ooool5ohmQV0[oSf6G2on?H9L5ohmPUPGoSenF
1On@HYP2oi1QV0;oSf6H2?n?HIL2ohmPU`03ohmPU_n@HYSoT6:H00CoT6:H0_n@HIL4oi5RU`?oTf>G
0_nFIIL2oiYYV0;oXg2H0onXLiL2ok^4VP04o`000?o5S9SocI>HolfCV0;ogZ>G00?oijfFoooooooo
ool04oooool2o`0003?ooooo000eooooo`Go00003_ooool3o`00033ooooo1on?HIP:ohmQU`coSf2G
1?n?H9H3ohmOUP03oi1RVOn@HYSoT6:H00CoT6:H0_n@HIP2ohmQV0OoSf6G0on@HYT7oi1RV0;oT66G
1OnAHYL2oi=SU`04oiIUUonHJ9WoVVVHoiYYV0?oXg2H0_nXLiL2ok^4VP04o`000?o=TiSocI>HolfC
V0;ogZ>G0_oW[IHFooooo`03o`000?oooooooooo033ooooo0016ooooo`;o0000<?ooool:ohmQV0Wo
Sf6G3On?H9L4ohmPUP04ohmOU_n@HYWoT6:Ioi1RV@KoT6:H0_n@HIP2ohmQV0GoSf6G1On@HYT7oi1R
V0;oT66G1OnAHYL01?nCHiOoU6JIoiQXVOnHJ9T3oiYYV0;oXg2H00GoZ7>Gok9nW?nkQ9[o^hBJo`00
0003olfCV0;ogZ>G0_oW[IHFooooo`03o`000?oooooooooo033ooooo0013ooooo`?o00000_ooool0
0ol0003oooooooooo`0[ooooo`coSf6H2?n?HIL>ohmPU`?oSf2F00?oT6>Ioi1RVOn@HYT00_n@HYT7
oi1RV004oi1QV?n?HISoSf6HohmQV0;oSf6G00?oT6>Ioi1RVOn@HYT01On@HYT6oi1RV0?oT66G0onA
HYL00onBI9WoU6JIoiAVV@02oiQXV@?oVVVH0_nSL9P3ok9nW004ok^4V_l0003ocI>HolfCV0;ofJ2I
0ooW[IH00oo//iGoooooooooo`0Dooooo`03o`000?oooooooooo02oooooo0011ooooo`;o0000<Ooo
ool>ohmQV0?oSf6G0on?HIP2ohmQU`koSf2G00CoSf2Foi1SVOn@HiWoT6>I1?n@HYT7oi1RV0;oT66H
0_n?HIP00on?HIOoT6>Ioi1SV@07oi1RV@OoT6:H0_n@HIL01?nAHYOoTFBJoi9TVOnBI9T2oiAVV@?o
V6RI0_nJJIP2oj=`V0?o/WjL00Co^hBJo`000?o2RicocI>H0_oIX9T3onN]UP03onbcUOoooooooooo
01Gooooo00?o0000ooooooooool0;_ooool003kooooo0ol0000aoooooa3oSf6H00?oSf6GohmQV?n?
HIP00on?HIP2ohmQU`goSf2G00?oT6>Joi1SVOn@HiT00_n@HiT5oi1RV@KoT6:H0_n@HIP00on?HISo
T6>Joi1SVP03oi1SV@KoT6:I1on@HYP01?n@HIOoT6BJoi5TV_nAI9X2oi9TV@;oU6JI0onHJ9T2oiYY
V003oj=`V?n/NYgo/WjL00;o/WjL00Co^hBJo`000?o2RicocI>H0_oIX9T2onN]UP;ok;>E5oooool0
0ol0003oooooooooo`0^ooooo`00>oooool4o`00037ooooo6?n?HIP2ohmQU`_oSf2G0on@HiX4oi1S
V@GoT6:I1_n@HYP00on@HISoT6>Joi1SVP03oi1SVP;oT6>I1_n@HYT6oi1RV0?oT6BJ0_nAI9X2oi9T
V@?oU6JI0_nHJ9T2oiYYV0?o[7ZM0_nbOY`00oo2Rico0000ol:;W003omVPV@;oijfF0_o//iD00ooc
_9?oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo000iooooo`;o00001?ooool00ol0003o
ooooooooo`0[ooooo`03ohmRVOn?HISoSf6H01SoSf6H0on?HIL8ohmPU`GoT6>J1On@HiT4oi1RV@Go
T6:H00?oT6BJoi1SV_n@HiX01?n@HiX2oi1SV@OoT6:I0on@HYP00on@I9_oT6BJoi1TVP02oi1TVP;o
TFBJ0onBI9T2oiAVV@;oV6RI00?oVVVHoj1bW_n/NYd00_n/NYd2ok9nW003ol:;W?l0003o`X^L00?o
fJ2I00?ohj^IonN]U_o//iD00_oc_9<00ooe_i;oooooooooo`0Dooooo`;o0000;_ooool003Kooooo
0ol0000booooo`?oSf:I6on?HIP2ohmQU`GoSf2G0_n@I9X6oi1SVPGoT6>I1?n@HYT01?n@HYSoT6BK
oi1TVon@I9/2oi1TVPKoT6>J0_n@HiT7oi1RV@04oi1RV?n@I9_oT6BKoi1TV`CoT6BJ0onAI9X2oi9T
V@;oU6JI0_nHJ9T2oj1bWP?o[7ZM00Go/WjLokR5W_o2Rico`X^Lo`000002omVPV@;ohj^I0_o//iD2
oo>lT`03ooFoT_oooooooooo01Gooooo00?o0000ooooooooool01_ooool2o`0002Cooooo000doooo
o`;o0000<oooool5ohmRVA_oSf6H0_n?HIL3ohmPU`04oi1TVon@I9[oT6BJoi1TVPOoT6>J1?n@HiT3
oi1RV@GoT6BK0_n@I9X6oi1SVP?oT6>I0on@HYT00on@IIcoT6BKoi1TV`04oi1TV`GoT6BJ0_nAI9X2
oi9TV@;oU6JI00?oV6RIoie`WonPLYh00_nPLYh2ojajW@07ok9nW?nhQIko^8FNol:;W?l0003ocYVO
omVPV@02on>[V@;ok;>E0_oc_9<00ooe_i;oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00008oooool0037ooooo1Ol0000booooo`KoSf:I2_n?HIP00on?HIWoSf6H
ohmQV00>ohmQV0;oSf6G00CoSf2Goi1TVon@I9_oT6BK0on@I9X7oi1SVPCoT6>I00?oT6:Ioi1UW?n@
I9/01On@I9/3oi1TVPKoT6>J0_n@HiT01?n@HYWoT6FLoi1UW?n@II`7oi1TV`CoT6BJ0_nAI9X2oi9T
V@04oiAVVOnHKZ3oWG2Ooie`W`?oX7:N0_n/NYd3okR5WP04ol:;W?l0003ocYVOomVPV@;ohj^I00?o
jK:Ioo>lTooc_9<00_oe_i8Iooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
8oooool002oooooo0_l0000cooooo`[oSf:I2On?HIP2ohmQVA3oSf6H00?oSf6Goi1TVon@I9/00on@
I9/4oi1TVPKoT6>J0on@HiT3oi1UW0OoT6BK0_n@I9X6oi1SVP03oi1SVOn@IIgoT6FL00?oT6FL1on@
I9/4oi1TVP;oTFBJ00CoTVBIoiE/XOnHKZ3oV6jP0onML9l2oj1bWP;o[7ZM0onhQIh00oo2Rico0000
oljIW`02on>[V@;ojK:I0_oc_9<00ooe_i;oml:AooW4T@0Hooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00008oooool002cooooo0ol0000cooooo`coSf:I1on?HIP2ohmRV@;oSf6I
3On?HIP00on@IIcoT6FKoi1UV`07oi1TV`?oT6BJ1_n@HiX00on@HiWoT6FLoi1UW003oi1UW0OoT6BK
0_n@I9X5oi1SVP03oi1VWOn@IIgoT6FM00CoT6FL1on@I9/4oi1TVP04oi5TV_nDJj7oUFbQoiE/X@;o
V6jP0onML9l2oj1bWP03ojajWOnaP:3o/H2P00;o^8FN00?ocYVOo`000?o>VIl00_oSZiT2onVbV@06
oo6mV?oc_9?omKnBooO2TOoia97onLFA6?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002?ooooo000Zooooo`;o0000=?ooool>ohmRV@?oSf6H1_n?HYT2ohmQV@_oSf6H0on@II`2
oi1UV`OoT6BK0on@I9X3oi1SVP03oi1VWOn@IIcoT6FL00OoT6FL1_n@I9/2oi1TVP03oi1SV_nAIiko
T6JM00?oT6JM0_n@IId5oi1UW0KoT6BK0on@I9X00onCJj;oU6^QoiA[X@02oiE/X@?oV6jP0_nML9l2
oj1bWP?o/H2P0_nhQIh01Oo>VIoo0000oljIWooIYZ;ohj^I00;ojK:I00KolKfHooFoT_oe_i;oml:A
ooW4TOoiaI4Hooooo`;o00000oooool01?l0003oooooooooool0000Sooooo`009oooool3o`000003
ooooool0003ooooo033ooooo4On?HYT00on?HISoSf:IohmRV@06ohmRV@?oSf6I2?n?HIP5oi1UW0;o
T6FK1on@I9/3oi1TVP04oi1SV_n@IYgoT6JMoi1VW@WoT6FL1_n@I9/01?n@I9[oTFNNoi5WW_nAIih4
oi1VW@?oT6FM1?n@II`5oi1TV`03oi9/XonBJj;oTV^R00;oTf^R0_nDJj43oiE/X@;oV6jP0_nML9l0
0onPLYkoY7RRok60X002ok60X004okR5W_o4TjCoa9>To`0000;ofJJR0_oY/YT2oo6mV004ooC0Uoog
`Y7onLBAooW4T@;onLFA5_ooool00ol0003oooooo`000004ooooo`;o00009?ooool002Cooooo0ol0
000dooooo`03ohmRV_n?HYWoSf:I01[oSf:I0_n?HIT7ohmQV0OoT6FL0_n@II/6oi1TV`;oT6BJ00?o
TFJMoi1VWOn@IYd00_n@IYd9oi1UW0GoT6BK00?oTFNOoi5WW_nAIih00_nAIih5oi1VW@;oT6FM1?n@
II`3oi1TV`?oTVbS0_nBJj82oi=[XP?oU6^Q0_nEK:42oiQ^X003oie`WonOMZ?oY7RR00;oY7RR0_na
P:02olBCY0;o00000_oIYZ82onVbV@;olKfH00Com<2GooO2TOoia97onLBA0_oiaI400ooiaY7ooooo
ooooo`0Fooooo`03o`000?oooooooooo02Oooooo000Rooooo`;o0000=Oooool3ohmRVQcoSf:I0_n?
HIT3ohmQV0?oT6JM2?n@II`2oi1UV`GoT6BK00CoTFNNoi5VW_nAIYgoTFJM1On@IYd8oi1UW0?oT6BK
00?oTFROoi5WWonAIil01OnAIih4oi1VW@;oT6FM1?n@II`00on@I9_oTVfToi9/X`03oi9/X`;oTV^R
0onCJj82oiA[X@;oUFbQ00CoV6jPoiYbY?nOMZ?oWgJS0onTN:801_naP:3o0000o`000?l0003oa9>T
o`0000;ofJJR00?oh:nTonVbVOoa_IP00_od`9L00oof`iOonLBAooW5T@02ooW5T@;onLJA6?ooool0
0ol0003oooooooooo`0Vooooo`007oooool3o`0003Cooooo00?oSf>JohmRV_n?HYX00on?HYX<ohmR
V@?oSf:J3On?HYT2ohmQV@03ohmQV?nAIYgoT6JM00?oT6JM2?n@II`2oi1UV`?oT6BK0onAIih00onA
IYkoTFJMoi5VW@05oi1VW@OoT6FL00?oTFRPoi5XWonAJ9l00_nAJ9l2oi5WW`GoTFNN1?n@IYd2oi1U
W@04oi1UW?nBKZGoTVfUoi9]Y@;oTVfT1OnBK:<2oi9[XP;oTf^R0_nDJj401?nEK:7oUW2UoiYbY?nJ
LZ@3oimfX`?o00000_nlSjL2olBCY004omVVX_l0003oh:nTon2_Y0;olKfH0_od`9L00oof`iOonLBA
ooW5T@02ooW5T@;onLJA6?ooool00ol0003oooooooooo`0Vooooo`007_ooool2o`0000;ooooo00?o
0000ooooooooool0;oooool3ohmSVPKoSf:J2On?HYT00on?Hi[oSf:JohmRVP02ohmRVPgoSf:I00Co
Sf6Ioi5VWOnAIYgoTFJM1?n@IYd8oi1UW0;oT6FK00?oT6BKoi5WW_nAIih00onAIih01?nAIYkoTFJM
oi5VWOnAIYd4oi1VW@GoT6FL00?oTFVPoi5XX?nAJ:001?nAJ9l3oi5WW`CoTFNN1?n@IYd01?n@IIgo
TfjVoi9^YOnBKZD2oi9]Y@;oTVfT1OnBK:<2oi9[XP;oTf^R00CoU6^QoiE`Y_nFL:GoUW2U0_nJLZ@3
o`0000;oY7RR0onlSjL01_o4TjCocj:YolnRZOoIYZ;o0000on2_Y0;olKfH00Com<2GooK3Uoof`iOo
n<JF0ooiaI43ooW6TASooooo00?o0000ooooooooool09Oooool001kooooo00?o0000ooooool00000
<_ooool4ohmSVPKoSf:J2?n?HYT2ohmSVPCoSf:J2on?HYT2oi5VWPCoTFJM1On@IYd6oi1UW0?oTFRO
1onAIih00onAIYkoTFJMoi5VW@04oi1VW@04oi1UW?nAJJ7oTFVQoi5YX@;oTFVP0_nAJ:05oi5XW`;o
TFNO1?nAIih01?n@IYgoTfnWoi=_Y_nCKjH2oi=^YP;oTVjU0onBKJD2oi9]Y0CoTVbS0_nBJj801OnC
Jj;oTfnWoiE`Y_nEL:KoUW2U00?o000000GoVW:ToimfXonOMZ?oY7RRojb5[003okb?Y`07olBCY?o?
XZWocj:YomVVX_oP[jCo0000on^mY@02ooC0U`05ooK3UoohaYKon<JFooS7UooiaI401?oiaY400ooi
aY;oooooooooo`0Eooooo`03o`000?oooooooooo02Gooooo000Nooooo`04o`000?ooooooooooo`00
02gooooo2?n?HiX6ohmRVPCoSf:I1_n?HiX5ohmRVPSoSf:I0_nAIih2oi5VWPGoTFJM1?n@IYd4oi1U
W0GoTFRO1onAIih00onAIYkoTFJMoi5VW@03oi1VW@03oi5ZX_nAJJ7oTFVQ00;oTFVQ0_nAJJ03oi5X
X0CoTFRO0_nAIil3oi5WWP03oi=`YonCKjOoTfnW00;oTfnV0_nCKZH3oi9^Y@;oTVfU0_nBKJ@3oi9/
X`03oi9`Z?nCKjOoTfnW00;oTfnW0ol00002oiI`Y@;oVW:T0_nOMZ<3ojb5[0;o_8nW0oo?XZT2on2_
Y005o`000?o[_JGom<2GooC0Uoof`iL00_ohaYH00oohaiOon<RGooW6T@03ooW6T@03ooW6T_oooooo
oooo01Gooooo0_l0000Vooooo`007_ooool01Ol0003ooooooooooooooooo000002[ooooo2_n?HiX6
ohmRVP;oSf:I2On?HiX4ohmRVPKoSf:I1?nAIih2oi5VWPGoTFJM1?n@IYd2oi1UW003oi5XX?nAJ9oo
TFRO00CoTFRO1onAIih01OnAIYkoTFJMoi5VWOn@IYgoTVZR00;oTFZR1?nAJJ43oi5YX0;oTFRP1?nA
J9l2oi5WW`04oi5WW_nCL:SoTg2Woi=`Y`;oTfnW0onCKjH2oi=^YP;oTVjU0_nBKJD2oi9]Y005oi9/
XonBL:WoTW2Xoi9`Z?nCKjL00ol000000onCKjOoUG2VoiE`YP02oiI`Y@;oVW:T00?oWgJSojJ3[On/
QJ`00_n/QJ`2okb?Y`08olNN[_o?XZWocj:YomN/[?oP[jCojkfUo`000?o^`ZH2ooK3U`04ooS6U_oh
aiOon<NGooS8U`?onLJA0ooiaY8Hooooo`03o`000?oooooooooo02?ooooo000Mooooo`?o00000ooo
ool00ol0003oooooooooo`0Vooooo`_oSf>J1On?HYX2ohmSV`[oSf>J1?n?HYX2ohmRV@03oi5XWonA
IikoTFNN00KoTFNN0_nAIYh4oi5VW@?oT6JM0_nAJJ02oi5XX0OoTFRO1_nAIih00onAIYkoTV^Roi9[
XP02oi9ZXP;oTFZR1OnAJJ42oi5YX0;oTFRP0onAJ9l00onDLJWoTg6Yoi=aZ@02oi=`Z0?oTg2W0_nC
KjL2oi=_YP;oTfjV0_nBKZD01?nBKJGoTg:Zoi=aZOnCLJT2oi9`Z@?o00001?nCKjL2oiE`YP;oUW2U
00?oVW:Toimn[onVPjd00_nVPjd2ojb5[004okb?Yoo7WZkoaij^olnRZ@;oejb/0_o[_JD00oo^`ZKo
0000oo77YP02ooS6UP04ooS7Uoohb9Oon<RGooS8U`;onLJA0ooiaY800ooiai;oooooooooo`0Eoooo
o`03o`000?oooooooooo02?ooooo000;ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo1?n?Hi/;ohmSVP?o
Sf:J1?n?Hi/:ohmSVPCoSf:J00?oSf:Ioi5XWonAJ9l02?nAIih2oi5VWPCoTFJM00?oT6JMoi5YXOnA
JJ000_nAJJ02oi5XX0OoTFRO1OnAIih01?nBK:?oTV^Soi9[X_nBJj82oi9ZXP?oTFZR1?nAJJ42oi5Y
X0;oTFRP00CoTFROoiAbZ_nDLJWoU76Y0_nCLJT3oi=`Z0;oTg2W0_nCKjL2oi=_YP;oTfjV00CoTVjU
oi=bZonCLZ[oTg:Z0_nCLJT2o`000003oi9`ZOnBL:SoTW2X00CoTfnW0_nEL:H01?nFL:GoVGbaoimn
[onOOZl3ojJ3[@;o[8F/0oo7WZh3omN/[005on>m/Oo[_JGok/:Vo`000?oaajH00_ohaYH01?ohaiOo
n<RGooS8Uoohb9L2ooW6T@?onLJB00?onLNBooW7Toooool05_ooool00ol0003oooooooooo`0Roooo
o`002_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Oooooo`GoSf>K2on?HiX00on?HY[oSf>KohmSV`04ohmS
V`[oSf>J0on?HYX4oi5XW`SoTFNN0_nAIYh3oi5VW@?oTFVQ0onAJJ03oi5XX0KoTFRO00CoTFNNoi9/
Y?nBK:CoTVbT0_nBK:<01?nBJj?oTV^Roi9[X_nBJj82oi9ZXP;oTFZR1?nAJJ401?nAJJ3oU7>[oiAc
ZonDLj/2oiAbZP?oU76Y0_nCLJT2oi=`Z0;oTg2W0_nCKjL01?nCKjKoTgB/oi=c[?nCLj`2oi=bZ`05
oi=bZ_l0003o0000o`000?nCLJT00_nBL:T2oi9`Z0?oTfnW00?oUW^coiQk/_nHNk800_nIO;43oimn
[`;oYX>]00?o[8F/okBD]_ndU;H00_o7WZh01?o>Z;;oejb/omN/[?oS_K42onk2YP03oo77Y_l0003o
ll^V00;on<NG0oohb9L01?ohbISonLJBooW6T_oiaY82ooW7TP03ooW7Tooooooooooo01Kooooo00?o
0000ooooooooool08Oooool000[ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`03ooooo`;o00001oooool00ol0003oooooooooo`0Jooooo`[oSf>K2?n?HiX2ohmTV`SoSf>K2?n?
HiX00onAJ:3oTFROoi5XW`06oi5XW`OoTFNN00CoTFJNoi9ZX_nAJZ7oTFZQ1?nAJJ44oi5YX0;oTFRP
1OnAJ9l00onBKJCoTVbToi9/Y002oi9/Y0;oTVbS0_nBJj<2oi9[XP;oTVZR0_nAJZ83oi5YX@03oiAd
[?nDLj_oU7>[00;oU7>[0onDLZX2oiAaZ@;oTg6Y0_nCL:P01?nCL:OoU7F^oi=d[OnCM:d2oi=d[0;o
Tg>/0ol00002oi=bZP;oTg6Y0_nBL:T2oi9`Z004oi=_YonENkCoUW^coiIk/`;oV7^b0onIO;42oimn
[`03ojJ3[On^TKWo]9Bf00?o]9Bf0oo>Z;82on>m/@06onK3/oo^`ZKolLNVoo?;Y_l0003ollbW1?oh
b9L01OohbISonLJBooW6T_oiaY;onLNB00;onLNC6?ooool00ol0003oooooooooo`0Qooooo`002_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Hooooo`_oSf>K1_n?HiX4ohmTV`SoSf>K1_n?HiX00onAJJ3oTFRP
oi5XX008oi5XW`KoTFNN0onBJZ82oi5ZX@GoTFVQ0onAJJ02oi5XX004oi5XWonBKJGoTVfUoi9]Y@;o
TVfT1OnBK:@2oi9/X`03oi9[XonBJj;oTV^R00;oTVZR00?oTFZRoiAe[OnDM:`00onDM:`5oiAcZ`;o
U7:Z0_nDLJT2oi=aZ@04oi=`Z?nDMZkoU7F^oiAe[P;oTgB]00GoTgB/o`000?l0003o0000oi=c[002
oi=bZ`;oTg:Z0_nCLJT01?nBL:WoU7ffoiEl]OnEO;D2oiEk]0?oUW^c0_nHNk82oiUl/@03oimn[onT
SKco[Y6i00;o[Y6i0ondU;H3oljX/P;ohkfa00?oi/>coo77Y_oaajH00_ocbjH00ol0003om<fWooS8
U`02ooS8U`;on<VH0_oiaY801?oiai;onLNCooW7Tooiai<Hooooo`03o`000?oooooooooo023ooooo
000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01?ooooo1?n?I9/;ohmSV`?oSf>J0_n?I9`5ohmTV`SoSf>K
0on?HiX01?nAJJ7oTFVPoi5YX?nAJJ02oi5XX0SoTFRO0onAIih2oi9[XPCoTVZR0onAJZ44oi5YX@?o
TFVP00?oTFRPoi9^YOnBKJD00onBKJD2oi9]Y0GoTVbT0_nBK:<00onBJj?oTV^RoiEf[P02oiEf[@;o
U7F]1OnDM:`4oiAcZ`;oU7:Z00CoU76YoiAg/?nDMjooU7N_0_nDMZh2oiAe[P?o00000_nCM:`2oi=c
[0;oTg:[00CoTg:ZoiEn^?nEOKOoUGfg0_nDOKH3oiEl]@;oUG^d0_nFNk<2oiQk/P03oiUl/OnLRKko
Y8fl00;oY8fl0on^TKT00ondU;Ko^InnokVO_P02oljX/P09om^l^ooV`k?oi/>con[9]?oaajKoll^V
oo?<Yol0003om<fW00?on<RG0oohbIP2ooW7TPConLNC5oooool2o`00027ooooo000:ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool04?ooool6ohmTV`_oSf>K00?oSf>JohmTW?n?I9`00_n?I9`6ohmTV`OoSf>K00CoSf>Joi5YXOnA
JJ7oTFVQ0onAJJ03oi5XX0OoTFRO00?oTFNNoi9[XonBJj800_nBJj85oi9ZXP;oTFZQ1?nAJJ400onA
JJ3oTfjVoi=^YP02oi9^Y@GoTVfU0_nBKJ@4oi9/Y0;oTVbS00?oTV^SoiEf[_nEMZh00_nEMZd3oiAe
[@CoU7B/0onDLj/00onENK7oU7R`oiAh/002oiAg/0;oU7N_00GoU7J^o`000?l0003o0000oiAe[P02
oi=d[@;oTgB/00CoTg>/oiJ0^_nEOkWoUGni0_nEO[P3oiEm]`;oU7ff0_nEO;D2oiEk]004oiIk/onG
R<;oVXW0oiZ9`0?oW8Vn0_nTSK`2ojjA^@05ok:L`_niWkko^InnokVO__o>Z;800_oK_;/2onK3/`08
on[9]?o]ckKoll^Voo?<YoodcJOo0000ooC>Z?ohb9L4ooS9V003ooS9VOoiai?onLNC00ConLNC5ooo
ool00ol0003oooooooooo`0Oooooo`002oooool2o`0000[ooooo00?o0000ooooooooool00_ooool3
o`0000_ooooo00?o0000ooooooooool03?ooool2ohmTW0SoSfBK2On?Hi/6ohmTW0KoSfBK1_n?Hi/5
oi5YX@CoTFVP0_nAJ:04oi5XW`?oTVbS0_nBJj<4oi9[XPCoTVZR0_nAJZ43oi5YX@04oi=_YonCKjKo
TfjVoi=^YP?oTVjU1?nBKJD2oi9]Y0?oTVbT00CoUGR`oiEg[onEMjooUGN_0onEMZh2oiEf[@;oU7F]
1?nDM:`01?nDLj_oUGVboiEi/OnENK42oiAh/0;oU7N`0ol00002oiAf[P;oU7F^00CoTgB]oiJ2_?nF
PK_oUX6k0_nFP;X3oiEo^@;oUGjh0_nEOKL2oiAm]P04oiEl]OnFRLCoUXS3oiJ8``?oUhS20_nJRL02
oib9_P03ojB=_?nWUlKo/Yc200?o/Yc20_niWkh3om^l^`04omo4_OoZbKCoj/Vdong?]P;ollbW00Co
m<fWooC>Z?l0003om<jX1?ohbIP00oohbIWonLNCooW7T`04ooW7TaSooooo00?o0000ooooooooool0
7_ooool001cooooo00?o0000o`00QOooool03?ooool00ol0003oooooooooo`09ooooo`CoSfBL2?n?
I9/6ohmSV`[oSfBL1On?I9/3ohmSV`03oi5ZX_nAJZ7oTFVQ00GoTFVQ1?nAJJ02oi5XX0?oTFRO1?nB
K:<2oi9[X`CoTV^R1?nBJZ800onAJZ7oTg2Woi=_Y`03oi=_Y`04oi=_Y_nCKZKoTfjVoi=^YP;oTVjU
1?nBKJD2oi9]Y004oi9/Y?nFN;3oUGR`oiEh/0CoUGN_0_nEMZh2oiEf[@;oU7F]00CoU7B/oiEk/onE
N[;oUGZb0_nENK83oiEi/@?o000000GoU7N`oiAg[onDMjooU7J^oiN4_@02oiJ3_0;oUX:l0onFPK/2
oiJ0^P;oUGni0_nEO[P01?nEOKOoUX_6oiJ:aOnFR/D3oiJ9a0;oUXS30_nGR<82oiZ9`003oib9__nN
TlWoYiO600;oYiO60onbW<801?niWkkoa;K=olBfcOoK_;/2omo4_@06on[9]?o]ckKokLnfong@]ooc
c:Oom<fW0_odcZP00ol0003olljYooS9V002ooS9V0;on<VI1Ooiai<00ooiaiCoooooooooo`0Foooo
o`03o`000?oooooooooo01gooooo000Looooo`03o`000?oooooooooo00gooooo0_l00006ooooo`Oo
SfBL2?n?I9/4ohmSV`03ohmUW?n?I9coSfBL00WoSfBL1On?I9/01On?Hi_oTVZRoi5ZX_nAJZ;oTFZQ
00KoTFVQ1?nAJJ000onAJ:3oTVfToi9/Y002oi9/Y0GoTVbS0_nBJj<3oi9[XP?oTVZR00?oTg2Xoi=`
YonCL:L01OnCKjL00onCKjKoTfjVoi=^YP02oi9^Y@?oTVfU0onFNK42oiIh/0?oUGR`0onEMjl2oiEf
[P04oiEf[OnFO;CoUW^doiIk]0;oUG^c0_nEN[83oiEi/P;o00000_nDN;001?nDMk3oUhJooiN5__nG
QKh2oiN4_@?oUX>l0_nFP[`2oiJ1^`;oUX2j00CoUGnioiJ=b?nFS<OoUXc70onFRlH2oiJ:a@;oUXW4
0_nFR<<01?nGR<;oUi;<oi^CbonKTl/3oijCb@?oYiO600?o/Yc2ok^cd_o4]/d00_o4]/d3omo4_@;o
kLnf0_o]d;L01_o]dKOom<fWooC>Z?odcZSo0000oo?>Z@?on<VH0oohbIT4ooW7T`;onLND5oooool0
0ol0003oooooooooo`0Mooooo`007?ooool00ol0003ooooooaTGS`0?ooooo`03o`000?oooooooooo
00;ooooo2On?I9`7ohmTV`03ohmSVon?IIcoSfFL00;oSfFL2on?I9`3ohmTV`;oTV^R0_nBJZ82oi5Z
XP;oTFZQ1OnAJJ43oi5YX0?oTVfT0onBK:@5oi9/X`;oTV^S0onBJj84oi=`Z0?oTg2W1?nCKjL01OnC
KjKoTfjVoi=^Y_nBKZGoUW^b00;oUWZb1?nFNK43oiIh/0;oUGR`0onEMjl2oiIl]@;oUWbd0_nFNk@3
oiEk/`06oiEj/_l0003o0000o`000?nENK7oUhO10_nGQl02oiN6_`?oUhFn0_nGQ;d2oiJ3_0;oUX:l
00CoUX6koiN?b_nGS/WoUhk90onFSLP2oiJ<a`;oUX_60_nFR/D01?nFRLCoUY??oiJBc_nFT/h3oiNB
c0;oVi?;0_nNTlT2ojNGaP05ojb^fOnk/m;o^k?Bok^cd_o4]/d00_o6_]<01?oOa;goh/_0onGA`oo]
ckH2ong@]`08ongA]oo]d[Som<jXooC>Z?occZWo0000oo?>ZOohbIP4ooS9V@03ooS9V_oiai?onLNC
00ConLND5oooool00ol0003oooooooooo`0Looooo`007?ooool2o`000003o`00QOoooooooooo00ko
oooo3On?I9`6ohmTV`;oSfFM1?n?II`;ohmTW003ohmTVonBJj;oTV^R00;oTV^R0_nBJZ82oi5ZXP;o
TFZQ1OnAJJ42oi9]Y@CoTVfT1?nBK:@4oi9/X`;oTV^S00?oTV^Roi=aZOnCLJT01OnCL:P2oi=`Y`Co
TfnW00?oTfnVoi=^Y_nFNk<00_nFNk82oiIj/PGoUWVa0_nFN;02oiEh/003oiEg[onFO[KoUWff00;o
UWbe0onFO;@2oiIk]0?o000000?oUGZboiEi/_nHR<800onGQl42oiN7`0;oUhJo0_nGQKh2oiN4_@04
oiJ3_?nGTLcoUi3;oiN@b`?oUho:0_nGS/T2oiJ=b0;oUXc700CoUX_6oiJEdOnEU=3oUIC@0onFTll2
oiJBcP;oUi;<00CoVi?;oi^XgonPZMgoX:WM1?n/[]T01?nk/m;o_KcIokflfOo6_]<2olW7f0;oiM73
00OoiM;4ong@]oo]dKOokM6gongB^?o]d[Wom<jX00;olljY00?o0000oo??Z_ohbIT00oohbIT2ooS9
VP03ooW7TooiaiConLND00;onLND5oooool2o`0001gooooo000Looooo`04o`000?oooooo001_odTg
V@kooooo3_n?I9`3ohmTV`GoSfFM1?n?II`8ohmTW0?oTV^S1_nBJj82oi9ZXP03oi5ZX_nAJZ7oTFZQ
00?oTFVQ00CoTVjUoi9]YOnBKJGoTVfU1OnBKJ@3oi9/Y0?oTVbS00?oU7:ZoiAbZOnDLZT01?nCLJT4
oi=`Z0;oTg2W0onCKjL01?nGO;CoUgbcoiIk/onFNk<3oiIk/P;oUWZb1?nFNK401?nFN;3oUgnhoiIn
]onFO[L2oiIn]P;oUWff0_nFO;D01_nFO;Co0000o`000?l0003oUG^coiR:``;oV8W20onHR<82oiN7
`@;oUhO00_nGQ[l01?nGQKkoV9?=oiRBc?nHT/`3oiNAc0;oUi3;0_nGSlX01?nGS/WoUYSCoiJGdonF
Um<2oiJFdP?oUYGA0_nEU=02oiJCc`04oiJBc_nDYn;oUZOQoiJWh@?oVjSO0_nPZMd2ojb^f@;o[KOP
00?o_KcIoko5goo9amP00_o9amP01OoUdL?oiM;4onGBa?oVe<GokM6g00;okM:h00KokM:ioo?>ZOoc
cZWolljYo`000?occjX3ooS9V@?on<VJ00?onLNCooW7U?oiai@00_oiai@Hooooo`03o`000?oooooo
oooo01_ooooo000Looooo`04o`000?oooooo001_oaTGS`;oHTNK2?ooool00on=HicoSVBLohiTW00>
ohmTW0[oSfFM0on?II`7ohmTW0CoTV^S1_nBJj82oi9ZXP03oi5ZX_nAJZ7oTfjV00;oTfjV0_nBKZD4
oi9]Y@CoTVfT0onBK:@01?nBK:?oU7:ZoiAbZ_nDLZX2oiAbZ@CoTg6Y1?nCL:P01?nCL:OoUgfeoiMm
]?nGOK@2oiMl]0;oUgbc0_nFNk<2oiIk/P;oUWZb00CoUWVaoiN1^OnGP;SoUh2h0_nGOkP3oiIn]`;o
UWjf00GoUWffo`000?l0003o0000oiR<a@02oiR;a0?oV8[30_nHRL82oiR8`P04oiN7`OnHU]3oV9G?
oiREc`;oV9C>0onHTld2oiRBc0;oUi7<00CoUi3;oiNJeOnGVMCoUiWD0onFV=<2oiJGd`;oUYKB0_nF
UM401?nEU=3oTjSToiBWhonDYn<3oiBWhP;oUZOQ00?oVjSOoiZ`ionO/ND00_nO/ND2ojfgh006ojfo
ionoaMoo_lGOoko5goo9amSobloM0ooUd/@00ooVe<GoiMC5ongB^003ongB^@;olljY00?ollnZo`00
0?occj/00_ohbIT3ooS9VPConLND0_oib9@Hooooo`03o`000?oooooooooo01[ooooo000Kooooo`;o
000000?oooooo`00KolI5hl00_mRAi/00om_Cicoooooooooo`02ooooo`04ohUQWOn<HigoSF>LoheS
W0;oSVBL3On?I9`;ohmUW@?oSfFL0on?I9`01?nBK:CoTVbSoi9/XonBK:<5oi9[X`GoTV^R0_nBJZ80
0onAJZ;oTfjVoi=^YP02oi=^YP;oTVjU1?nBKJD4oi9]Y003oi9/Y?nDLj_oU7>[00GoU7:Z0_nDLZT3
oi=aZ@?oTg2X00?oUgjfoiMm]OnGOKD00_nGOK@3oiMl]005oiMl/onFNk?oUW^coiIk/_nGP[X00_nG
PKX2oiN1^@?oUh2h0_nGOkP2oiIn]`?o00000_nISLD3oiR<a@;oV8_40_nHR/<01?nHRL;oVISAoiVG
d?nIUm03oiRFd0;oV9G?0_nHU<h2oiRCc@04oiRBc?nGW=OoUi_FoiNKeP?oUi[E0_nGVM@2oiJHd`04
oiJGdonDZ^KoU:WUoiBYi@?oTjWT0_nCZ>@2oiBWh`03oiBWh_nB[^WoU:kX00;oU:kX0_nJ/>L00onO
/NGoWK[/ojfoi`03ojfoi`03oko5goo0cNCobloM00;obm7N00CoiM;4onKDaOoVe<GoiMC51?o]d[T0
1Oo/d[[olljYoo??Z_occj_o000000;on<VI0_ohbIX2ooS:VP?onLND0_oib9@00ooib9Gooooooooo
o`0Fooooo`03o`000?oooooooooo01Wooooo000Kooooo`;o000000Koooooo`00Kol008;oBCNIof97
Vom_Ci`2oh5KW@04ohAMWOn9HIgoRF6MohaSW@;oSF>L0_n>I9`9ohmTW003oi1VW_n?IYgoSfJM00co
SfFM0on?II`4oi9/Y0CoTVbS1?nBJj<4oi9[XP03oi=_YonCKjKoTfnV00KoTfjV00?oTVjUoi9]YOnB
KJD00_nBKJD00onBKJCoU7B/oiAcZ`04oiAcZ`GoU7:Z0_nDLZT2oi=aZ@03oiMo]onGO[KoUgjf00;o
Ugjf0onGOKD2oiMm]0;oUgbd00?oUgbcoiN2^onGP[/00_nGP[X3oiN1^P;oUh6i0_nGP;P01?nGOkSo
0000o`000?l00002oiV>a`;oVHg60_nISLD2oiR<a@04oiR;a?nIVM;oVIWBoiVIdP?oVISA0_nIUm02
oiRFd004oiREconHWmWoV9kHoiRNf0;oUigH0onGW=L2oiNKeP04oiNJeOnE[NOoU:cWoiB/i`?oU:_V
0_nDZ^H2oiBYi@03oi>Yi?nA[n_oTJk[00;oTJk[0_nA[^X2oi:^j@03oiB^j?nA]NooV;S^00;oV;S^
0_nM^^`2ojfoi`05ojc7kOo0cNCo_loVoko?i_o;dMh00_o;d^001?oVe<GoiMC5onGDaOoUeLH3ongB
^@;ok=:j00CollnZoo??Zooccj_o00000oohbIX2ooS:VP03ooS:VooiaiConLND00;onLRD0_oib9DG
ooooo`03o`000?oooooooooo01Wooooo000Kooooo`08o`000?ooooooooooooooool008;oBCNIof97
Vom_Ci`2oh5KW@04ohAMWOn9HIgoRF6MohaSW@;oSF>L0_n>I9`8ohmTW0;oT6JN0_n?IYd<ohmUW@03
ohmUW?nBKJCoTVbT00CoTVbT1?nBK:<4oi9[X`03oi9[X_nCKjOoTfnW00;oTfnW0_nCKjH6oi=^YP04
oi9^YOnBKJGoTVfUoi9]Y@?oU7B/1_nDLj/4oiAbZP03oiAbZOnHP;SoUgng00;oUgng1OnGO[H2oiMm
]@;oUgfd00?oUgbdoiR4_?nHPk/00onGP[/2oiN2^P;oUh6j0_nGPKT3o`000004oiV@b?nISlOoVHo7
oiV?a`;oVHk70_nISLH00onISLGoVY_DoiVJd`05oiVIdP;oVISA00CoVIO@oiRQf_nHX=[oV:3J0onH
WmT2oiRNf0;oUigH00?oUicGoiF^j?nE[NL01?nE[NL2oiB/i`03oiB[i_nB/NcoT[3/00;oT[3/0_nA
/>/2oi6_j`03oi6^jon>]O3oSkG`00CoSkG`0_nA]Nl00onH^>koUKkcoiFnl`02oi_1lP04ojc7kOn/
b>oo[<S_oko?iP;o_m3W00Cobm;Pol[ChOo:dn7oiMC50_oUeLH00ooUeLOokM:ioncB^P02oncB^P05
oncB^ooccj_olln[o`000?obcj`00_ohbIX2ooS:VP;on<ZK0ooib9@2ooW8UASooooo00?o0000oooo
ooooool06?ooool001_ooooo00So0000ooooooooooooooooo`00P_lb:9KoHTNKofm?W0;oPE^M00?o
Q5fMohUQWOn9HId00_n<Hid00on=HicoSVBLohiTW004ohmTW0KoT6JN0_n?IYd:ohmUW@CoTVfT1_nB
K:@3oi9/X`?oTV^S0_nCL:L5oi=_Y`03oi=_Y_nCKZKoTfjV00CoTfjV00?oTVjUoiAd[OnDM:d01OnD
M:`5oiAcZ`?oU7:Z00?oV86hoiR0^?nHP;P01?nGOkL4oiMn]P03oiMm]OnHQKgoV8Bl00CoV8Bl00?o
V8>koiN2^onGP[/00_nGP[X01?nGPK[oVY;:o`000?l00003oiV@b@;oVI380_nISlL01?nIS/OoVYcE
oiZLe?nJW=@3oiZKe005oiVJdonIVM;oVIWBoiVId_nIX]`00_nHX]/3oiRQfP;oV:3J00?oV9oIoiJ`
jOnF[nT00_nF[nT2oiJ_j0;oUJkX00?oUJgWoi>ckOnC/^d00_nC/^d2oi:bk0;oT[7/00?oT[3/ohnf
lOn?]_400_n?]_42ohnel@;oS[G`00?oSkG`ohbjmOn=^_D00_n=^_D2ohjkm003oiFnlonD_oCoV/;c
00;oV/;c00?o[<S_oj_:l?nod>L00_nod>L3ol[Ch@05olWChOoUeLKoiMG7onGEaooTeLL00oo/d[X0
1_o/d[_ojm:koo??Zooccj_o0000oo;?[0?on<ZJ0_ohbY/3ooW8U0?onLRE5oooool2o`0001Wooooo
000Kooooo`?o000000Coooooo`00P_lb:9KoHTNK0_m_Ci`01?n1FigoQ5fMohAMWOn9HId2ohaSW@04
oheSW?n>I9coSVBLohmTW0;oSfJN2?n@IYh00on?IYgoSfFMohmUW@06ohmUW@;oTVfU1OnBKJ@5oi9/
Y0;oTVbS0onCL:P4oi=`Y`CoTfnW00GoTfnVoi=^Y_nCKZKoTfjVoiEf[P02oiEe[@03oiAe[OnDM:go
U7B]00GoU7B/1?nDLj/00onHP[WoV86ioiR1^@03oiR1^0;oV82h0onGOkL01?nGO[KoV8JnoiR5__nH
QKh3oiR5_@CoV8Bl00CoV8>koiN2^onJTlcoVY?;0ol000000onJT/[oVY79oiZAb@02oiV@b@04oiV@
b?nJW]KoVYgFoiZMeP?oVYcE0_nJW=@00onJVmCoVJGMoiVTg@03oiVSg0;oVJ;L0_nHX]/00onHXM[o
U[7ZoiJaj@02oiJaj@;oU[3Y00?oUZoYoiBdkOnD]>d00_nD]>d4oi>ck@03oi>bkOnA^?7oT;Oa00Co
T;Oa0on?]_400on=^oGoS;[eohbjm@05ohbjm@03ohfjmOn<^oKoS;_f00;oSKcf0_nD_o@00onJ`_?o
V/?doi[3m002oj_:l004oko@ionndNSo_]7Xol[Ch@;obM?Q00KobM?RonGEaooTeLOoi=G7onCEb?o/
d[X2oncB^`07on_B^ooccj_ol/n/oo;?[?l0003ol/n]ooS:VP04ooS:V`03ooW8U?oib9GonLRE00?o
nLRE5oooool00ol0003oooooooooo`05ooooo`?o00003oooool000Sooooo0_l00004ooooo`04o`00
0?ooooooooooooooo`Go00001?ooool01ol0003ooooooooooooooooo001Loc8XU_mE?i`00_m_Ci`0
1?n1FigoQ5fMohAMWOn9HId2ohaSW@03oheSW?n>I9coSfJN00?oSfJN2?n@IYh00on?IYgoSfFMohmU
W@03ohmUW@GoTVfU1OnBKJ@5oi9/Y003oi9/XonCL:SoTg2X00;oTg2X1?nCL:L4oi=_Y`03oi=_Y_nC
KZKoUGJ^00;oUGJ^0_nEMJd2oiAe[@;oU7B]1?nDM:`00onDLj_oV8>joiR2^P03oiR2^@;oV86i0_nH
PKP2oiR0^003oiMo]onIQkooVHNo00?oV8Jn0_nHQKh2oiR5_@?oV8Bl00?oVYG=oiZDc?l000000_l0
0002oiZCb`;oVY;:00CoVY79oi^Of?nJWmOoVYoG0onJW]H2oiZMeP04oiZLeOnIY]koVJGNoiVUgP?o
VJGM00?oVJCMoiVSg?nG/n/01OnG/^X2oiJajP03oiJajOnD]NkoU;G^00;oU;G^0onD]>d01?nB^O7o
TKWaoi6ilOnA^O44oi6hl@03oi2glOn>_?GoS[ce00;oS[_e1?n=^oD00on<^_GoS;_fohbkmP04oh^k
mP03ohbkm_n;_OOoSKgg00;oSKgg0_nD`OH00onJ`oCoVL?eoiW3m@02oj[:l0?o_]7X00?obM?QolWC
h_o9dn800ooTeLL00ooTeLSohmG8oncB^`02on_B^`04oo??Zoobcjcol/n/o`0000;ol/n]1OohbY/5
ooW8UASooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000kooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`02ooooo`05oc8XU_mE?icoIT^MofI;WOn1Fid00_n4GId01?n9HIgoS6>MohaTWon=IIh5ohmV
WPSoT6JN00?oSfJMohmUWOnBKZH00_nBKZD7oi9]Y@CoTVfT0_nBK:@01?nCLJWoTg6Xoi=aZ?nCLJP5
oi=`Z0?oTg2W0onCKjL00onEMjooUGJ^oiEf[P04oiEf[P;oUGF]00CoU7F]oiAd[OnDM:goU7B/0onH
Pk/2oiR3^P;oV8:j0_nHP[T2oiR1^@04oiR1^?nIR<3oVHS0oiV8`0CoVHNo0_nHQ[h2oiR5_P04oiR5
_OnKU/koViK=oi^Fc@?o00000_nJU<`00onJTlcoVY?;oi^Qf@02oi^Pf0?oVioH0_nJWmL01?nJW]Ko
VZOOoiZWgonJYml3oiVVgP;oVJGN00?oVJGMoiNdjonG/n/00onG/n/00onG/^[oUKO^oiFfkP04oiFf
kP?oU;G^0_nC^_82oi:ilP;oT[Wa00?oTKWaoi2lmOn?_?D01?n?_?D00on>_?GoS[cfohflmP04ohfl
mP?oS;_f1_n;_?L2oh^mm`03ohfmmon=__OoSKkg00;oTl7f0_nI`oD3oj[:l@04okkAj?nmd>So_M3X
olWChP;ob=?R00Coi=G7onCEb?oTeLSohmG80_o[d[/01oo[dkcojm:loo;?[?obcjcol/n]o`000?ob
cjd01OohbY/00oohbYconLREooW8U@02ooW8U@03ooW8U_oooooooooo01Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0<ooooo`001oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2oc8XUP;oIT^M00CoOEZOoh9MWon2
GIooR6:O0_n<I9l00on=IIkoSfJNohmVWP04ohmVWPOoT6JN00?oSfJMoi9^Y_nBKZH00_nBKZD7oi9]
Y@?oTVfT1?nCLJT4oi=aZ0CoTg2X0_nCL:L00onEN:ooUGN_oiEg[`02oiEg[`KoUGJ^0_nEMJd00onD
MJgoU7B]oiV4_005oiR3^`;oV8>j00?oV8:joiR2^OnIRL400_nIRL45oiV8`0?oVHNo00GoV8Jnoi^G
conKUlooViO?oi^FcP03o`000006oi^FcOnJULgoVYG=oiZDc?nKX][oVj;I0onKXMT2oi^Pf003oi^O
f?nJZN3oVZSP00;oVZSP1?nJYml00onIY]koV;C/oiRdk002oiRdj`;oUkC[00?oUk?[oiJgkonF]nh0
0_nF]nh00onE]nkoUKK^oiBjlP06oi>jlPCoTKgd0_n@_O@2oi2lm@03ohnlmOn?_OGoSkge00;oS[ce
0_n>_?H00on=_?KoSKgfohfmmP02ohbmmP;oS;cg1on;_?L2oh^mm`?oSKkg0_nC`OH2oiW3m@04oj[:
lOnYb_7oZL[aokg@j0;o_M3Y00Cob=?RolSBh_o8d^;oi=G80_oSeLP01_oSeLWojm:kon_C_?o[d[co
jm>moo;?[0;ol/n]00?o0000oo;?[OohbY/00oohbY/01?ohbYconLREooW8UOoib9D3ooW8UQOooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`001oooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`05o`08Solb:9KoECnLofI;WOmm
FYl00_n2GIl01?n8HYooS6BOohaTWon=IIh6ohmVWPCoT6JN0onCKZH4oi9^YP03oi9^YOnBKJGoTVfU
00GoTVfU00?oTVfToiAbZ_nCLJT01OnCLJT3oi=aZ0CoTg2X00?oTg2WoiEh[onEN:l01OnEMjl5oiEf
[P03oiEe[OnIQKcoVHBl00?oVHBl1?nHPk/2oiR3^P03oiR2^_nIRL7oVHW100?oVHW11?nIR<000onI
QkooViW@oi^Hd002oi^Gc`?o00000_nKU/h00onKU/goVj?Koi^SfP02oi^SfP;oVj;J00?oVj;Ioi^Q
fOnJZ^400onJZN42oiZYh003oiZXh?nH]^coV;G/00CoV;G/00?oV;C/oiNhkonF^>l01?nF^>l2oiJg
k`04oiJgk_nD^o;oU;_boiBklP;oU;[b00?oTk[boi:mm?nB_O@01OnA_O@4oi2mm@?oSkge1_n>_OH2
ohfmmP?oS;gf0_n<_OL2oh^mm`03oh^lmon;_OOoRkgg00CoRkgg0_n=__L3oi?1mP;oVL?e0onYb_40
1?nmd>Wo_=3Yokc@jOo8d^82olOBhP04on?Eb?oSeLWohmG9on;Db@;ojm:l00?ojm>mon[C_Oobcjd0
0_obcjd01?l0003on<ZKooS:VoohbY/2ooS:W0?onLRE0ooib9HHooooo`04o`000?oooooooooooooo
o`Co00003oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01?ooool01?l028ooECnLofI;WOmmFYl2oh9MW`03ohQRWon<
I9ooS6BO00;oSFFN1On?IYh00on@IYkoTfnWoi=_YP04oi=^YPCoTVjV00?oTVjUoi9]YOnBKJD00onB
KJD4oiAbZPKoTg6Y0onCLJP01OnCL:SoUWV`oiIh/?nFN;3oUGR`00?oUGR_1?nEMjl2oiEf[P03oiV6
_OnIQKgoVHFm00?oVHFl0onIQ;`3oiR3^`03oiZ;`onJRl;oVX_200;oVH[21?nIRL401?nIR<3oW9[A
oi^IdOnKVM42oi^Id0?o000000?oW:GLoibTfonLY=/00onKY=/2oi^Sf`04oi^Sf_nKZn;oVj_Roi^[
hP?oVj[R00?oVZ[QoiZYhOnI]^`00onI]^`2oiRfk003oiRek?nG^NooUkW_00;oUkW_0_nG^>l00onF
^>ooUKcboiFklP02oiFklP?oU;_b1?nC__@2oi:mm0;oT[ke0_nA__D2oi6mm@03oi2mmOn@__KoT;kf
00;oT;kf0_n?__H00on>_OKoSkkfohjmmP04ohjmmP;oSKgf00?oS;gfohfmm_n=_OH00_n<_OL3oh^m
m`03oh^lmon;_OOoRkgg00?oRkgg0_n=__L3oi?1mP;oVL?e00CoZL[aojW9lOnYbO7o_=3Y0_nlcnT0
1?o7d^;oam;SolOBhooSeLT3on;Db@;ojm>m00Koj]>mon[B_Oobcjgol/n]o`000?oacjh2ooS:V`03
ooS:W?ogbYcoml^L00;onLRE1?oib9HGooooo`;o00000_ooool00ol0003oooooooooo`0@ooooo`00
1oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`04ooooo`03o`08Solc<Z7oIT^M00;oOEZO00CoPUfOohQRWon8HYooS6BO0_n=IIh4
ohmVWP04oi9_YonCKjOoTfnWoi=_YPCoTfjV1?nBKZH00onBKZGoTVfUoiAcZ`08oiAbZPGoTg6Y00?o
Tg6XoiIi/OnFNK400_nFNK03oiIh/003oiEh/?nEN:ooUGR_00?oUGN_00?oVHNnoiV6__nIQ[d00_nI
Q[d2oiV5_@;oVHFl0_nIQ;`00onJS<CoVXc3oiZ<``03oiZ;``;oVX_200?oVH[2oiV9`OnLVm800_nL
V]83oibJd@?o000000?oW:KMoibUg?nLYM`00_nLYM`2oibTf`03oi^TfonK[>?oVjcS00;oVjcS1?nK
Zn801?nKZ^;oVKO]oiVgkOnI]nd3oiVfk0;oV;[_1OnG^Nl2oiJllPCoUKcb00?oUK_boiBnm?nD__@0
1OnC__@2oi:nm0?oT[ke1OnA__D5oi2nmPCoSkkf00?oS[gfohjnm_n>__H00_n>_OH5ohfmmP;oS;gg
0_n;_OL2oh^lm`03oh^mmon;_?OoRkcg00;oS;gg0_n=__L3oi?1mP;oVL?e00CoZLWaojS9lOnXbO7o
_<oY0_nkcnT00oo7d^?oa];SolKBh`03on;Db@04on_C_OoZdkgoj]>mon[B_@;ol/n]00Kol/n^o`00
0?oacjkon<ZKooS:W?ogbY`2ooO;W0KonLRF5Oooool00ol0003oooooo`000002ooooo`Go00003_oo
ool000Sooooo0_l00009ooooo`?o00001?ooool2o`0000Gooooo00?o00R?oc<bXOmBAZD00_mmFYl0
1?n2GIooR6:OohQRWon<I9l2oheUWP03ohmVW_nBKjOoTVnW00;oTVnW0_nCKjL2oi=_YP?oTfjV0onB
KZH4oiAcZ`SoU7:Z0_nCLJT00onFN[;oUWVaoiIi/@03oiIi/@?oUWV`0_nFN;000onEN;3oUGR_oiV8
_`02oiV7_`?oVHNn00?oVHJnoiV6_OnIQ[d00_nIQKd00onIQKcoVXg5oiZ=a003oiZ<a0;oVXc30_nJ
Rl<01?nJRl;oW9cCoibLdonLW=<2oibKdP04oibJd_l0003o0000o`0000;oW:OM0onLY]d2oibUg004
oi^]i?nK[N?oVjgSoi^]h`?oVjcS00CoV[S]oiVhkOnI^>goVKS]0onI]nd6oiRjk`03oiNml_nF_?;o
U[cb00CoU[cb0_nE__@7oiBnm0CoTkkd00?oT[kdoi:omOnB_oD00onB__D3oi6nm@;oTKkf1On@__H4
ohnnmP03ohjnm_n?_OKoSkgf00;oS[gf1?n=_OH3ohbmmP;oS;gg1On;_?L2ohbmm`;oSKkg00?oTl7f
oi?0mOnI`_@00_nI`_@3ojS9l@;o^loY0oo6d^<01Oo6dN?oh]C9on;Db_oQe<_oj]>m00;oj]:m00So
j]:noo;?[OobcjkolLn^o`000?oacjoon<ZLooO:W0?oml^L1_oib9HGooooo`03o`000?oooooooooo
01;ooooo000Jooooo`03o`000?oooooooooo00Gooooo00Go<c:Qoe96YOmhGZWoN5jYoh9MW`02ohQR
W`03ohaTWon@KJOoT6fW00KoTVnW00?oTfnWoi=_Y_nCKjH00onCKZH00onBKZKoU7>[oiAcZ`05oiAc
Z`KoU7:Z1?nFN[86oiIi/@;oUWV`00?oUWR`oiZ8`?nJR;l00onIR;l2oiV7_`;oVHNn00?oVHJnoiV6
_OnJS/H00_nJS/D3oiZ=a@04oiZ=a?nJS<CoVXc4oiZ<``?oW9gD1OnLW=<2o`0000CoW:ON0_nLYmd0
0onLY]goVjkToi^^i002oi^^i003oi^]i?nK[N?oV[S]00GoV[S]00?oVKS]oiRkl?nH^_000_nH^_03
oiRjk`GoUkgb00?oU[cboiFom?nE_o@00_nE_o@00onE__CoUKodoiBom004oiBom003oiBnm?nC_oGo
Tkoe00CoTkoe1OnB_oD00onB__GoTKkeoi6nm@03oi6nm@OoT;kf0_n?__H2ohnmmP?oS[gf1?n=_OH5
ohbmmP?oRkcg00CoS;cfohbmm_n<_OKoS;gf0_n=_OH2oi?0m@?oVL;d00?oZ<WaojS8lOnkcnT00_nk
cnT01Oo6d^?oa]7SolKAhoo5dN?oh]C:00;ohMC;00Coj]:mon[B__oZd[kojM>n0ooacjh00ol0003o
mlZLooO;W003ooO;W003ooO;WOoib9KonLRF00?onLRF5oooool00ol0003oooooooooo`0Booooo`00
6_ooool00ol0003oooooooooo`05ooooo`;o<c:Q0_mhGZT01?moHjSoR6VXohQYZ?n>KJP2oi1]Y`Ko
TVnW00CoTfnWoi=_Y_nCKjKoTfjV0_nDM:`8oiAcZ`CoU7:Z00?oUW^coiIj/_nFN[801?nFN[85oiIi
/@03oiIi/?nJRL3oVXS000;oVXS000?oVXRooiV8_onIR;l00_nIQkl00onIQkkoVho7oiZ?aP03oiZ>
aP;oVXk50_nJSLD00onJSLCoW9kEoibNe005oibMe006oibLdol0003o0000o`000?nLZ=ooW:SN0onL
Ymh4oib_i@?oVjkT1?nJ^Nh2oiZhk@CoVK_`0_nH^o000onH^_3oUkgboiNmlP03oiNmlPCoU[oc00?o
U[odoiFom?nE_o@01OnE_o@5oiBom0OoTkoe1_nB_oD7oi6nm@03oi2nm_n@__GoT;kf00;oT;kf1?n?
_OH5ohjmmP;oSKgf00?oS;gfohflm_n=_?H01_n<_?H00on<_OKoS;cfohblmP02ohjmmP;oTl3e00?o
VL;doiS2m?nH`_@00_nXb?401?nkcnWo^/kYok[>jOo6dN<2olGAh`?ohMC;0ooZd[h01_oYdkkojM:n
oo7?[_oacjoo0000oo7@[`Coml^L0_ogbid5ooW8UQOooooo00?o0000ooooooooool04Oooool001Wo
oooo00?o0000ooooooooool01_ooool2oa4RW`03oe96YOmhGZWoOf>X00;oR6VX0_n>KJP2oi1]Y`Go
TVnW00?oTfnWoiAd[?nDM:`00onDM:`8oiAcZ`03oiAbZ_nFNk?oUW^c00;oUW^c1_nFN[83oiIi/@;o
VXW10onJRL02oiZ8`003oiZ8_onIR;ooVi3700;oVi370onKSlL01?nJSlKoVXk6oiZ>a_nJS/D3oifO
eP?oW9kE00?oW9kDoibMe?nMZ^000ol00002oifYg`04oibXgonL/>KoW;3Uoib`i@GoW:oU1onJ^Nh4
oiVkl0CoV;kb0_nH_O800onG_O;oUkocoiNol`02oiNol`?oU[oc0onF_o@7oiFom0GoU;od1onC_oD5
oi:om@03oi:nmOnA__GoTKke00GoTKke0_n@__D3oi2nmPCoSkgf00?oS[gfohnmm_n?_OH01?n>_OH2
ohflmPSoS;cf0_n=_?H2ohjmmP;oTl3e0onH`_@2ojS8l0?o^/kY0_o5dN<4on7Db`09on[B__oYdkko
jM>nonWB__oacjkolLn_oo7@[ol0003olM2_00;oml^L0oogbid6ooW8UQOooooo00?o0000oooooooo
ool04?ooool001Wooooo0_l00008ooooo`03oa4RWomBAZGoN5jY00;oOf>X0_n8JJP00on>KJSoT6fW
oi1]Y`02oi9_Y`?oU7B]1onDM:`4oiAcZ`03oiMl]?nFO;?oUWbc00KoUW^c1?nFN[800onJRl;oVX[2
oiZ:`P02oiZ:`@;oVXW10_nJRL000onJR<3oVi78oi^Ab005oi^@a`;oVho700?oVXo6oifPeonMX=H0
1OnMWmH00onLW]GoWJ_Po`000002o`000003oifZh?nMZMooW;7V00?oW;7V0_nL/>H2oib`i@06oib_
iOnK^^koV[[^oiZjk_nJ^NkoV[c`1OnI_?000onI^o3oVKkboiVnlP04oiRnlPOoUkoc0_nG_o@7oiJo
m0KoUKod1OnD_o@2oiBom@03oi>omOnC_oCoTkod00CoTkoe00?oT[oeoi:nmOnB__D00onB__D5oi6n
m@;oT;ke00?oT;kfoi2mmOn@_OD00_n@_OD4ohnmmPGoS[gf0_n=_?H00on<_?KoSKcfohflmP04ohbl
mP;oSKcf0on>_OH2oi>om@;oV<;d0onWb?02ok[>j@03olGAhoo4d>?oa=3S00?ohMC;00Koh=C<onWC
__oYd[kojM:nonWB_ooacjl2oo7@[`03o`000?oad:ooml^L00?oml^M1_oib9H00ooibIKooooooooo
o`0Dooooo`;o00004Oooool001Wooooo00?o0000ooooooooool01oooool00olA8Yoo?CjYogQNZ@02
ogmSZ0;oR6VX00CoSVfXoi1]YonALjkoTgB]1?nDM:d7oiAd[003oiAcZonGOKCoUgbd00;oUgbd0onF
O;<5oiIk/`03oiIj/_nJRl?oVX_200?oVX_20_nJR/800onJR/7oVXW1oi^Bb@02oi^Ab@CoVi780onK
T<L3oifQe`?oWJ3G00CoWJ3FoifOe_nMZn7oWJ_Q0ol000000onMZn3oWJ[Poibbi`05oibaiPOoVk[^
1OnJ_?000onI_?3oVKkboiVnlP03oiVnlPGoV;oc00?oUkocoiO0lonG`?<00onG_o<4oiO0m0OoU[od
1_nE_o@7oiBom003oi>om?nD_oCoTkod00;oTkod0_nC__D00onB__GoTkkeoi>nm@03oi:nm@03oi6n
mOnB__GoT[ke00CoTKke1On@_OD2ohnmm@;oSkgf1On>_OH7ohflmP;oS;cf0_n=_?H3ohjmmP;oTkoe
0_nH`_@00onWb?3oYlO`ok[>j@02okW>j@04olC@hoo4d>Coa=3Ton7Db`?oh=C<00CojM:nonWB_ooY
d[ooj=:o0_oad:l00ol0003olM2_ooO;W004ooO;W@GonLRF00?onLVFooooooooool05Oooool00ol0
003oooooooooo`0?ooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`07U_lA8YooLV2_00;o
O6J_0_n7KJh01?n?LZkoTG>^oi5c[_nCM:d5oiAd[@CoU7B/0_nGOKD2oiMm]0CoUgbd0_nFO;<2oiIk
/`03oi^<`onJS<?oVXc300?oVX_30onJRl800onJR/;oVi?:oi^Bb@03oi^Bb@;oVi790onKTLP2oifR
f0GoWJ7G00?oWJ3Goif/h_nM[>400ol000000onMZn7oWK;Woibbi`04oibbi`04oibai_nK^nkoVk_^
oi^kkP?oVk[^1OnJ_?06oiVnlPCoV<3c0onH_o<4oiS0l`;oUl3c1onG`?@2oiK0m0GoU[od1_nE_o@9
oiBom0?oTkod0_nC__@00onC__GoTkkdoi:nm@05oi:nm@GoTKke1On@_OD4ohnmm@03ohjmm_n>_?Go
S[ce00;oS[ce1on=_?H2ohblmP;oSKcf0_n>_OH2oi>om@;oV<7d0onWao001?nic^Wo^LgYokW=jOo4
d>@2ol?@i0?oh=C<00CogmC<onWB_ooYd[ooj=:o0ooad:l00ol0003ol=2`ooO;W@04ooO;W@?onLRF
0_oibIHHooooo`03o`000?oooooooooo00kooooo000Iooooo`03o`000?oooooooooo00Sooooo00Co
00NFocdnZOmlIZooO6J_0_n7KJh01On?LZkoTG>^oi5c[_nALjkoTgB]00CoU7B]00?oU7B/oiMm]OnG
OKD01?nGOKD2oiMm]0?oUgbd00?oUWbcoi^=a?nKSL@00onKS<<2oiZ<``;oVX_300?oVX_2oibCb_nL
TlX00onKTlX3oi^Bb@03oi^AbOnMXmWoWJ;H00GoWJ;H00CoWJ7Goif]h_nM[N;oWJgR0ol000000onM
[>7oWK?Woifbi`03oifbi`03oibbionK^nkoVk_^00CoVk_^1?nJ_O000onJ_?3oV[oboiZolP05oiVn
lP?oVL3c3?nH`?<2oiO0l`OoUl3d0_nF`?@7oiJom003oiFom?nF_oCoUKod00?oUKod1onD_o@00onC
_oCoU;kdoiBnm004oi>nm003oi:nmOnC__CoT[ke00?oT[ke0onA__D2oi6mm@OoT;ge0_n?_OD00on>
_?GoSkceohnlm@02ohjlm@[oSKcf00?oS[gfohjlmOnD_o@00_nD_o@2oiS1m0?oYlO`00?o^LgYokS=
jOnhcNT00oo3d>@01?oPe<cogmC<omoDc?oOe<`3onSB_`;olM2_00?olM2`o`000?o`d;001Oogbid2
ooW8UP?onLVF5oooool00ol0003oooooooooo`0>ooooo`006Oooool2o`0000Wooooo00?o00NFoaTa
[OmbH:l00_mlIZl00on7KJkoSg:^ohmb[P02oi5c[P04oi=d[OnDM:goU7B]oiAd[@;oUgjf1_nGOKD2
oiMm]003oiMl]?nKSLCoVhg400CoVhg40_nKS<<00onJS<?oW9C;oibDb`03oibDb`;oW9?:0_nKTlX0
0onKT/WoWZCIoifSf@03oifSf@?oWJ;H0onM[N83o`000003oifcj?nM/nOoWK?W00?oWK?W00GoWK;W
oibkkonL^nkoW;_^oi^kkP06oi^ml003oiZml?nJ_o;oV[ob00;oV[ob2_nI`?<<oiS0l`03oiO0lonH
`??oUl3d00KoUl3d2_nF_o@5oiFom003oiBom?nE_oCoUKod00;oU;od1OnD__@6oi>nm0;oT[kd0_nB
__D00onA__GoT[gdoi:mm004oi6mm@GoT;ge0_n?_OD2ohnlm@GoS[ce0on=_?H00on=_?GoSKcfohfl
mP02ohflm@;oS[ce0onD_o@2oiS1m003ojO7l?nVao3oY/O`00?o^<gY00?o`m3Tol??i?o3cn@00ooO
e<`3onSB_`05onSB`?oad:oolM2`oo3@/?l000001_ogbid00ooib9KonLVFooW9UP02ooW9UQOooooo
00?o0000ooooooooool03Oooool001Wooooo00?o0000ooooooooool02?ooool00ol01iKo6C6]ofQT
^P02ogaV[`06ohM][_n?LZkoSg:^oi5c[_nBO;OoUGfg0_nFO[H4oiMn]PCoUgfe1OnKS/D5oi^=a0;o
W9G<1_nLU</00onLTl[oWZCJoijTfP02oijTfP;oWZCI00?oWJ?Ioij^honN[^<00onN[^<00onM[N;o
0000o`000003oifdj0;oWK?X00?oWK?WoiblkonL_>l00_nL_>l00onL^nooVkg`oi^ml004oi^ml0Go
V[ob0_nJ`?<=oiW0l`goV<3c00GoUl3doiO0lonG`??oUl3coiO0m002oiNol`;oUkod2?nF_o@7oiFo
m0SoU;kd1_nC__@4oi:nm0?oT[gd0_nA_O@2oi6mm@GoT;ge1?n?_?D01?n>_?GoSkceohnlmOn>_?D4
ohflm@?oSK_e0_n=_?D2ohnlm@?oU;od0_nH`O@01OnVao3oY/K`ojK6l?nhcNWo^<cY00?o`loT00Go
`/oTomoDc?oOdlgog]?=onSB_`03onSB`0;ol=2`00?o0000oo3@/?ogbid01?ogbid6ooW9UQKooooo
00?o0000ooooooooool03Oooool001Sooooo00?o0000ooooooooool02_ooool2oaTa[@;oMVbj00?o
QWFioi1k^?n@NkP00_nBO;L2oiEm]`;oUWjf0onGO[H00onGOKGoVho6oi^?aP06oi^>a@04oi^=a?nL
U/goW9K<oibFc0CoW9G<0onLU</00onNYM_oWZGJoijUfP03oijTfP04oij_i?nN[n?oWZoSoij_h`;o
WZkS00CoWKCXo`000?l0003o00000onM]>P6oiblk`GoVkg`0onK_o43oiZolPCoV/3b0onJ`?<=oiW0
l`goV<3c00?oUl3coiNolonG_o<01_nG_o<3oiJom0;oU[oc0onF_o@00onE_oCoU[odoiJom004oiFo
m0OoU;kd1_nC__@5oi:nm0;oT[gd1OnA_O@5oi2mm@;oT;ce1?n?_?D4ohjlm@;oSKce0on=^oD2ohjl
m@;oSkce00?oU;odoiBnm?nD__@00_nH`O<3ojK6l0;o^<cY00?o`loTol;?i?o2cn@00_oOdld00ooN
dlgoj=;0onSB`003onSB`0;ol=2`00?o0000oo3@/?ogbid01?ogbid6ooW9UQGooooo0_l0000>oooo
o`006?ooool00ol0003oooooooooo`0:ooooo`03oj<h0?l05ZGoJ6Bj00;oMVbj00?oQWFioi1k^?n@
NkP00_nBO;L01?nEOKOoUWjfoiIn]_nGO[H6oi^?aP?oVhk500?oW9O=oibFcOnLU/d00_nLU/d2oibF
c0?oW9G<1OnNYM/00onNYM[oW[3Toij_i003oij_i003oij_honM]NWo000000;o00000_nM]>P7oibl
k`;oW;k`00?oVkk`oi^ml?nK_o401_nK_o46oi[0lPCoV/3c3_nI`?<=oiS0l`_oUkoc1OnF_o<4oiJo
m0CoUKod1onD__@00onC__CoU;kdoiBnm003oi>nm003oi:nm?nC_OCoTkgd00CoT[gd00?oTKgdoi:m
m?nB_O@01?nA_O@00on@_OGoT;gdoi2mm002oi2lm@?oSkce1On>_?D5ohfkm@;oS[ce0_n?_?D2oiBn
m0?oV<3c0_nVa_03okS<jP?o`/oT0ooNdld4onSB`0?ol=2`00?o0000oo3@/Oogbid00oogbid00oog
bikonLVFooW9UP03ooW9UQOooooo00?o0000ooooooooool02oooool001Sooooo0ol0000;ooooo`05
oj<h0?mBJlkoMVbjogI/^_n6MKT00_n@NkP2oi9l]`03oiEm]onJSlOoVXo700;oVho71OnKSlH2oibG
cP?oW9O=0onLU/d00onLU/coWZKLoijVf`03oijVf`03oijUfonN/>CoW[3T00CoW[3T00?oWZoToife
jOl000000_l00002oifej@KoW;c_1OnL__04oi^ol@03oi_0l_nJ`?;oV/3b00CoV/3b0_nJ`O82oi[0
lPCoV/7c0_nJ`?<00onI`??oV/3coi[0l`0=oiW0l`03oiS0lonI`??oV<3c00SoV<3c2onG_o<00onF
_o?oUkocoiJol`03oiJol`03oiJom?nF_o?oU[oc00CoUKkd00?oU;kdoiFnm?nE__@01_nD__@4oi>n
m0?oTkgd1onB_O@4oi6mm004oi2mm?nA_?CoTKcdoi2lm0CoSkce0on>_?D4ohjkm@;oSK_e0on>^oD2
ohnlm@;oU;kd0onH`?<2ojK6l003okS<j_ngc>[o]lcZ00;o`/oT1?oNdld3onSB`005onOB`Oo`d;3o
l=2`oo3@/?l000001?ogbid2ooO;WPGonLVF5_ooool00ol0003oooooooooo`0;ooooo`001Oooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool03?ooool0
1?l05ZGoJWS>ofYhc_n3Q<d2oi6<bP;oU8g90_nISlP2oiZ?a`03oi^?aonKSlKoW9S?00;oW9S>1?nL
Ulh2oibGc@04oibFcOnNYmcoWZOLoijWg0;oWZKL00?oWZKKoijaiOnN/>@01?nN/>@2oijfj@?o0000
00?oWKGYoifmkonM_Nl00_nL_Nl00onL_>ooW;k`oibnl004oibnl0GoVkoa0_nK`O83oi_0lP03oi[0
l_nJ`O;oV/7b00GoV/7b1_nJ`O<7oi[0l`goVL3c1OnH`?<4oiRol`goUkoc1OnF_o<4oiJnl`GoUKkd
2?nD__@2oi>nm0GoTkgd1OnB_O@4oi6mm0;oTKcd0_n@_?@2ohnlm0;oSkce00?oS[ceohnkmOn?^oD0
1?n>^oD2ohfkm@?oS[_e0_n?_?D2oiBnm0?oV<3c0_nVa_000ongc>[o]lcYol;?i002ol7?i0Cog]?=
00Soj=;0onSB`OoWd/7oim;1oo3@/?o`d;7o0000oo3@/@?oml^M0_ogbih6ooW9UQKooooo00?o0000
ooooooooool02_ooool000Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool03Oooool01?mBJlkoJWS>ofYhc_n3Q<d2oi6<bP;oU8g9
00?oVHo8oiZ?aonKV=001?nLV<l2oibHcP03oibGc_nNZ=goWZSM00KoWZOL1OnN/ND00onN/>CoW[KY
oijfj@03o`000003oijfjOnM_NooWKg_00?oWKg_1_nL__03oibol@03oi^olOnK`O;oVl7b00SoVl7b
2?nJ`O86oi[1l`OoV/3c3onI`?<7oiRol`03oiNolonH_o?oUkoc00[oUkoc1?nF_o<5oiJnl`;oUKkc
00?oUKkdoiFnlonE__<00_nE__<6oiBnm0;oTkkd1OnC_O@4oi:mm0?oTKgd0onA_?@5oi2lm0;oSkcd
00?oSk_eohnkm?n>^o@00_n>^o@7ohjkm@;oSkcd0_nD__@3oiS0l`;oY/G`00?o]lcYokO<j_o1cn@0
0_o1c^@3omkCc@04omkCc_oWd/7oim;1onOB`@?ol=2a00?o0000oo3@/Oogbid01?ogbih6ooW9UQKo
oooo00?o0000ooooooooool02Oooool000Cooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Ko@F_Eof1lf?mPO=SoPhC=oi6<b_n@U=<2
oiFFdP04oiZHd?nKV=3oViS@oi^Hd0?oW9S?1_nNZ=d00onNYmcoW[7Uoijai@04oijai@;oW[OZ00Co
W[OYo`000?l0003o00001OnM_Nl5oibnl0?oW<3a0onL_o4?oi_1lPGoV/7b0_nK`O82oi[0lP04oi[0
lonJ`O?oV/3boi[0lP?oV/3c0_nJ`?82oi[0l`goVL3c0_nI_o<9oiRol`03oiNolonH_o?oUkoc00So
Ukoc00?oU[ocoiJnlonF__<02?nF__<5oiFnl`;oU;kc00CoU;kdoiBmm?nD_OCoU;gd1onC_O@4oi:m
m003oi6mm?nB_OCoT[gd00?oTKcd1On@_?@2ohnlm0;oSk_d1On>^o@3ohjkm@04ohjkm?n?_?CoSkcd
ohnlm0;oU;kd00GoV<3coiRolonVaO3oY/G`okO<jP02okO;jP?o`LkT00?og]?=omkCc_oNdlh01?oW
d/43oo3@/@03o`000?o`d;7oml^N00?oml^N1_oibIHFooooo`;o00002_ooool000Cooooo00Co0000
oooooooooooo00002Oooool2o`0000Cooooo0_l0000@ooooo`03od5[eOmPO=SoOhcF00?oT9CC0_nE
U]800onJV=3oViS@oibXgP03oifXgPCoWZSM0_nN/^H01?nN/^GoW[7UoijaiOnN/ND3oijgjP?o0000
1OnM_Nl4oibnl0GoW<3a0onL`O8Boi_1lP03oi[1l_nK`O;oVl7b00;oVl7b0_nK`?8=oi[0lP?oVL3c
00?oVL3boiW0lonI`?<00onI`?<2oiVol`;oVL3c0_nI_o<=oiRol`OoUkoc00?oU[kcoiNnlonG__<0
2?nF__<6oiFnl`;oU;gc00?oU;gdoiBmlonD_O<00_nD_O@5oi>mm0GoT[gd00?oT[cdoi6lm?nA_?@0
0_nA_?@7oi2lm0;oSk_d00?oS[_dohnkm?n?^o@01_n>^o@01?n?_?CoSk_doiBnlonD__<2oiRol`04
ojK5l?nUaO3oYLG`okO;jP;o]/_Y0oo1c^@00ooNdlkogM?>omgCcP04onOB`@;ol=2a00?o0000oo3@
/Oo`d;401?ogbih6ooW9UQKooooo00?o0000ooooooooool02?ooool000Cooooo00Co0000oooooooo
oooo00002oooool01Ol0003ooooooooooooooooo000001;ooooo00?o7f_Mod^4i_moS=H00_n@U=<0
1?nEU];oU:KQoi^XgonKZ=l2oibXgP03oifXg_nM/^KoW[;V00CoW[;V1_nN]nX2o`0000GoWKg_0onM
_o000onL__3oW<3aoic0l@03oic0l@SoW<7b4_nK`O86oi_0lPgoV/3b1_nI`?800onI`??oVKoboiVo
lP06oiVol`goV;oc1onG_o<3oiNnl`SoU[kc1_nE__<7oiBml`?oTkgd0_nC_O<2oi>mm0;oT[gd0_nB
_?@4oi6lm0GoT;cd0_n@^o@5ohnkm0CoS[_d0on?^o@00on@^oCoU;gcoiBml`02oiRol`?oYLG`0onf
bnT3ol7>i0?ogM?>1?oWd/42oo3@/@03o`000?o`d;7oml^N00Coml^N1OoibIHEooooo`?o00002Ooo
ool000Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool04Oooool01Ol7Im_oBhCVogNIi_mgVNKoSZ?S00;oU:KQ00CoVjSOoiZaj?nL
/^OoW;;W0_nM/^H01?nN/^KoW[S[oijhj_nN^>X3oijgjP?o000000?oWKk_oifmkonM_o001OnM_o04
oic0l@goW<7b3onK`O88oi_0lQ3oV/3b1?nI`?87oiVolP03oiVolonI_o;oV;oc00coV;oc1OnG_o<6
oiNnl`OoU[kc1_nE__<7oiBml`OoTkgc0onB_?@5oi6lm0?oT;cd1?n@^o@6ohnkm0;oS[_d0_n?^o@3
oi2km0;oU;gc0_nH_o<3ojG5l0?o]/_Y00?o`LkTol3>i?oMdlh00ooMdlh3onOB`@?ol=2a00?o0000
ooO;W_ogbih01?ogbih5ooW9UQ7ooooo0ol00002ooooo`03o`000?oooooooooo00Oooooo0005oooo
o`;o00002Oooool3o`0000Cooooo00?o0000ooooooooool04_ooool00ond<@3o>hKZofnQk`02oh^/
k0;oTZoZ0_nJ/NP01?nL/^OoW;O[oifhjonM^>/2oijhj`05oijhj_l0003o0000o`000?nM_^l01OnM
_o03oig0l@?oW<3a4OnL`O8;oi_1lP03oi_0l_nK`O;oVl3b00WoVl3b4?nJ`?801?nI`?;oV[oboiZo
l_nJ_o89oiVolP;oV;ob0onH_o<2oiRolPKoV;oc0onG_o<8oiNnl`OoU[kc0onE__<3oiFml`OoU;gc
1_nC_O<2oi:ll`;oT[cd00?oTKcdoi:lm?nB_?@01?nA_?@5oi2km0KoSk_d0_n>^_@2ohnkm0;oT;_d
0onD_O<2oiRolP04ojG5l?nUa>ooYLC_okK;j@;o]/[Y00?o`<kTol3=i?oMdlh00_oMdlh01?oMd/ko
im;1onOB`OoWd/43oo3@/@03o`000?ogbikoml^N00Coml^N1OoibIH=ooooo`?o00001Oooool00ol0
003oooooooooo`07ooooo`005oooool2o`0001Cooooo00Go05g@ofZTlomZY??oRjc/ohVal002oi6d
kP;oVKO/00?oW;O[oi^ml?nL_O000ol000000onM_^ooWKo`oifol002oifol0OoWL3a5onL`O801OnK
`O;oW<7boic1l_nL`O;oVl7b013oVl3b3_nJ`?86oiZolPgoVKob0onH_o83oiRol`?oV;ob2onG__<7
oiJnl`;oUKkc1?nE_O<7oiBml`GoTkgc00?oTkccoi:llonB_?<00_nB_?<00onB_?CoT[ccoi:ll`02
oi6lm0;oTK_d1On@^o@4ohnkm0;oSk[d0_n>^_@2ohnkm0;oT;_d0onD_O<2oiRolP?oYLC_0_nfb^T3
ol3=i003omgCc_oMd/kogM;>00Coim;10_o`d;400ol0003ol=2aooO;WP04ooO;WPGonLVF2Oooool4
o`0000Sooooo00?o0000ooooooooool01oooool001Oooooo00?o0000ooooooooool05?ooool00ol0
GM3oJZCcofZTl`02ohVal003oi6dk_n?^O?oV;ca00?o000000?oW;g`oibolOnM_o000_nM_o05oig0
l@GoWL7b7?nL`O8Aoi_0lPKoV/3b0_nK`?86oi[0lPKoV[ob3OnI_o800onH_o;oVKoboiVolP06oiRo
lP_oUkkc1onF__<2oiJml`CoUKgc2OnD_O<00onC_O?oTkccoi>ll`03oi>ll`GoT[cc0_nA_?<2oi6k
m004oi2km?n@^o?oT;_doi2km0CoSk_d1On?^_@2ohnkm0;oT;_d0onD_O<2oiRolP;oYLC_0_nfb^T3
ol3=i0CogM;>0ooWd/401OoWd/;ol=2aoo3@/Ol0003ol=2a00Coml^N00?oml^MooW9U_oibIH00ooi
bIH5ooooo`?o00003Oooool00ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`0E
ooooo`04o`1Lc_lQQ>WoI:OfohJfm@?o000000GoS[[doiRml_nJ__7oV[kaoibol@03oic0l@03oig0
lOnL`O;oW<7b00;oWL7a1_nM`O8Loic1lQ7oVl3b0onJ`?85oi_0lP?oV[ob00?oV/3boiZol_nJ_o80
1_nJ_o8@oiVolP;oV;kb0_nH_o82oiRnlP;oUkkb00?oUkkcoiNnl_nG__800_nG__84oiNnl`OoU[kc
0_nF_O<6oiFml`OoU;gc1_nC_?<7oi:ll`;oTK_c00CoT;_coi2km?n@^o?oT;_c0_n@^o@2ohnkm0Oo
Sk[d0_n@^o<3oiBml`;oV;kb0_nUa>l2okK:j@?o`<gT0ooMd/h3onOB`@06onOB`_oVd/;ol=2aoo3@
/Ol0003ol=2a0oogbih2ooO;W@GonLVF00Coooooo`000?l0003o00004?ooool00ol0003ooooooooo
o`06ooooo`005oooool00ol0003oooooooooo`0Fooooo`?o00000_n5]oH01?n>^_CoS[_eohjkmOnG
__<2oiZolP03oic0lOnK`?;oVl3b00;oW<7b2_nM`O8Foic1lP;oW<3b00?oW<7boic0l_nL`?800_nL
`?8@oi_0lP03oi[0l_nK`?;oVl3b00GoVl3b3?nJ_o8@oiVolPSoV;kb1_nG__800onG__?oUkkboiNn
lP02oiNnl`?oU[kc1OnF_O<5oiFml`GoU;gc00?oU;ccoi>llonC_?<01OnC_?<4oi:ll`?oT[_c0onA
^o<3oi2kl`;oT;[c2On?^_@2oi2kl`04oiBmlonD_??oV;kboiRnlP;oYLC_0onfb^T3ol3=i004omgB
c_oLd/kog=;>onOB`@;oim;200Goi];2oo3@/Oo`d;7ol=2ao`000003ooO;WP?oml^M1?oibIH00ooi
bIGoooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo000Fooooo`;o00005Oooool3o`000003
ooooool0FL_o05W;00;oH:Sg00CoQKSfohjkmOn=_?GoSKce0_nG_o<01?nJ`?;oVl3boi_1l_nK`O82
oic1lP[oWL7b1_nL`O83oic1l@coW<7b00?oW<3aoic0l_nL`?801OnL`?8Boi_0lP04oi^ol_nK`?;o
Vl3boi_0lP;oVkob3_nJ_o8>oiVolPSoV;kb00?oUkkboiRnl_nG__802?nG__82oiJmlP03oiJmlonF
_O;oU[gb00?oU[gc1OnE_O<4oiBml`CoU;cc1OnC_?<4oi:ll`;oT[_c1?nA^o<3oi2kl`;oT;[c1?n?
^_<00on?^_CoSk[cohnjl`02ohnjl`03oi2klonD_??oU;cc00?oV;kb0_nUa>l01?nfb^Wo]LWYokG9
jOo0cN@2oko=i0?og=;>00Coim;2onKB`_oVd/;oi];20_o`d;400ol0003ol=2aooO;WP04ooO;W@Co
nLVF00?onLVEooooooooool04Oooool00ol0003oooooooooo`06ooooo`005_ooool00ol0003ooooo
ooooo`0Booooo`;o00001Oooool2o`1Ib`;oGjSh00CoQ;WgohflmOn=_?GoSKce0_nG_o<01?nJ`?;o
Vl7boi_0l_nK`?82oic1lP[oWL7b00?oW<7boic1lOnL`O401OnL`O48oic1lPOoW<3a1onL`?8@oi_0
lPOoVkob3_nJ_o8<oiVolP;oVKkb2_nH__89oiNnlPKoU[gb0_nF_O<00onE_O?oU[gboiJmlP04oiFm
l`03oiBmlonD_??oU;cc00?oU;cc1OnC_?<2oi:ll`CoT[_c1?nA^o<00on@^o?oTK_coi6kl`04oi2j
l`KoSk[c0_n@^_<2oiBll`?oV;kb0_nU`nl3okG9j@;o_lgT1?oLd/h4onKB`P;ol=2a00?o0000oo3@
/Oogbid01?ogbid3ooW9UP;onLVE4_ooool00ol0003oooooooooo`06ooooo`005_ooool00ol0003o
ooooooooo`0?ooooo`?o00002_ooool2oenXn0;oQ;Wg0_n=_?D2oiNol`;oV/3b00CoVl3boi_1l_nL
`O;oW<7b0onM`O800onM`O7oWL7boig1l@04oig1l@03oic1lOnM`O7oWL7a00GoW<7a0_nL`O8=oic0
l@;oW<3b1_nL`?400onK`?;oVl3aoi_0lP0<oi_0lPOoVkob3_nJ_o87oiVolPOoVKkb2_nH__86oiNn
lPGoUkgb2OnF_O84oiFml`KoU;cc1onC_?<4oi:kl`GoTK_c00?oTK[coi2jlon@^_<00on@^_<6ohnj
l`;oT;[c0_nD_?800onH__;oVKkboiVnlP02ojG3k`?o]LWY00?o_lgToko<i?oLd/h00ooLd/h3onKB
`P?ol=2a00?o0000oo3?/Oogbid01?ogbid00ooibIKonLVEooW9U@02ooW9UA7ooooo00?o0000oooo
ooooool01_ooool001Kooooo00?o0000ooooooooool03?ooool3o`0000kooooo00Co6X;XoenXn?n4
^?OoQ;Sg0_n=_?D2oiNol`;oV/3b00GoVl7boi_0l_nL`O;oW<7boig1lP0<oig1l@?oW<7a0_nM`?4G
oic0l@03oi_0lOnL`?7oVl3b00;oVl3b1?nK`?401?nK_o;oVl3boi^olOnK_o49oi^olPkoV[ob1_nI
_o88oiVnlP[oV;kb00?oUkkboiRnl_nG__800onG__85oiNmlPWoU[gb0onE_?800onD_??oU;cboiBl
l`04oiBll`GoTkcc00?oTk_coi:klonB^o<00onB^o<4oi6kl`;oTK[c1?n@^_<5ohnjl`CoT;[c0_nD
_?83oiVnlP;oYL?_0_nebNT3oko<i0?og=;>0ooVd/801OoVd/7ol=2aoo3@/Ol0003ol<na00Koml^M
1?oibID@ooooo`03od`GJol0003ooooo00Oooooo000Eooooo`;o00002oooool3o`0001;ooooo00Co
6X7WoejXmon4^?OoQ;Sg0on=_?D00onG_o?oV/3boi[0lP03oi_0lP03oic1lOnM`O7oWL7a00[oWL7a
1_nM`?4Ioic0l@OoVl3a1_nK_o401_nK_o;oVkoaoi^olOnK_o7oVkoboi^ol@ooV[ob00?oVKoboiZo
l_nJ_o800_nJ_o800onI_o;oVKkboiVnlP06oiVnlPcoV;kb2?nG_O800onF_O;oUkgboiJmlP06oiJm
lPCoUKcb0_nD_?800onD_??oU;cboiBllP02oiBll`?oTkcc0onC^o<5oi:kl`;oTK_c1?nA^_<4oi2j
l`CoSk[c1On@^_<2oiFllP04oiVnl_nI__7oYL?_ojG3k`?o]LWY0onoc>@3omcBcP03onKB`_oVd/7o
i];100;ol=2a00?ol<nao`000?o`ck401Oogbid4ooW9U@03oo[9U?oooooooooo00gooooo00?oC1M[
ooooool000001oooool001Kooooo00?o0000ooooooooool01_ooool3o`0001Kooooo00Go05O9oejX
mon4^?OoQ;Sgohflm@02ohfkm@03oiNolonJ`?;oV/3b00?oVl3b00?oW<7aoig1lOnM`O401?nM`O4<
oig0lAWoW<3a0_nK_o400onK`?7oW;oaoibol@0>oi^ol@03oiZol_nJ_o7oV[oa00;oV[ob0_nJ_o49
oiZolPCoV[kb2OnI__84oiRnlP;oVKkb1_nH__8:oiNmlPOoU[gb1_nE_?85oiBllP;oTkcb00CoTk_c
oi>kl_nC^o?oTk_c1?nB^o<3oi6kl`?oTK[c1on@^_<2ohnil`?oT;[c0_nA^_<2oiFllP04oiVnlOnI
_O7oYL?_ojG3k`?o]LWY0onoc>@3omcBcP;oi];100Koi]71oo3@/Oo`ck7ol<nao`000?o`ck45ooO;
W@?onLVE0_ojbI@=ooooo`04oeTRLOm<5f_oooooo`0000Oooooo000Fooooo`03o`000?oooooooooo
00?ooooo0ol0000Jooooo`04okTg0?mNZ?OoGZSgohBhm`?oSK_e0_nG_o<01?nJ`?;oVl3boi_0l_nK
`?82oic1l@03oig1lOnM`?7oWL3a013oWL3a5_nL`?42oibol@04oi^olOnL_o7oW;oaoibol@koVkoa
00?oV[oaoi^olOnK_o400_nJ_o42oi^ol@;oV[oa0onJ_o800onJ_o7oV[oboiZolP05oiZnlPWoVKkb
0onH__83oiVnlPCoV;kb0_nH_O8:oiNmlPOoU[gb1_nE_?86oiBllPGoTk_b1?nB^o<00onA^o?oT[[c
oi:jl`03oi6jl`GoT;[c0_n@^O<2ohnil`04oi2jlon@^O?oT;Wcoi6jl`;oUKcb0_nI_O43ojG3kP03
okG9jOneb>Wo]LSY00;o_lcT0ooLd/h01?oLdLkoi];1onKA`OoVdL43oo3?/@03o`000?o`ck7oml^M
00?oml^M00?oml^LooW9UOoibID00oojbI@;ooooo`;oFB9a00?oC1M[ooooool000001oooool001Go
oooo0_l00002ooooo`?o00007oooool2oejWm`04ohBhmon=^oGoSK_eohfkm@;oUkoc00CoV/3boi_0
l_nL`?7oW<3a5OnM`?4Eoic0l@WoW;oa4onK_o46oiZol@;oV[ka00?oV[kboiZnlOnJ__400_nJ__4?
oiVnlPKoV;gb2_nG_O83oiJmlP?oU[cb1onE_?84oiBllP;oU;_b1onC^o82oi:klP;oT[[c1?nA^_<2
oi2jl`GoT;Wc0_n?^O<2oi2il`;oTK[b0_nE^o82oiVml@03ojG3k_nU`^koYL;^00?o]LSY0_noc>@0
1?oLd/kog=7>omcAc_oLdLh3onKA`@;ol<na00?o0000oo3?/Oogbid00oogbid00oogbiconLVEoo[9
U004oo[9U0[ooooo0_mI8W400om146[oooooo`000007ooooo`005Oooool4o`0002?ooooo0_mNYoL2
ohBhm`;oSK_e0_nG__<01?nJ_o;oW<3aoic0lOnL`?4Eoig0lA3oW<3a3_nL_o4Coi^ol@GoV[oa2OnJ
__4>oiVnlPSoV;gb2?nG_O800onF_O;oU[cboiJllP03oiJllPOoUKcb0_nD_?84oiBklPOoTk_b00Co
T[_boi:jlonB^_;oT[[b1?nA^_82oi2jl`GoT;Wc00CoSkWcoi2ilon@^O?oTK[b0_nA^O82oiFklP;o
VKga0onU`^h00oneb>Wo]LSXoko<i002oko<i0?og=7>1?oVdL42oo3?/@03o`000?o`ck3oml^M00;o
ml^M00?oml^LooS;W?ojbI@01?ojbI@00oojbI?oooooooooo`06ooooo`;oJ2me00CoFB9aod4@J_oo
oooo00001oooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`;o
00009_ooool00olIP>OoGZOgohBhm`02ohBhm`03ohfkmOnG__?oUkkc00?oV[ob00?oW<3aoig0lOnM
`?404onM`?401?nL`?7oWL3aoig0lOnM`?4;oic0l@ooW;oa4onK_o4>oiZnl@03oiVnl_nI__7oVKka
00?oVKka1_nI__82oiVnl@SoV;gb2?nG_O86oiJllPOoUKcb00?oU;cboiBkl_nD^o800onD^o86oi>k
lPGoT[[b1?nA^_82oi2ilP04oi2ilon@^O;oT;Wboi2ilP;oT;Wc0_n@^O83oi6ilP;oUK_b0_nI_O42
ojG2kP?o]LSX00?o_lcToko;i?nobn@00ooLdLh3onKA`@;ol<na00Gol<n`o`000?o`ck3oml^MooO;
W003ooS;W0Con/VD00?on/VCooooooooool01Oooool01omb=WOoJ2meofP_MOmI8W7o@A1Zooooool0
00001oooool00005ooooool0003oooooooooool000002_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Cooooo0_lHP>L3ohBhm`;oSK_e00GoUkkcoiZol_nJ_o;oV[oboic0l@0Joig0
l@03oic0lOnM`?7oW<3a00CoW<3a4_nL_o4Coi^ol@koV[ka1_nI__400onI__;oVKkaoiVnl@03oiVn
l@;oVKga2?nH_O88oiNmlPKoU[cb00?oUKcboiJll_nF_?800onE_?87oiBklPKoTk_b1OnB^_84oi6j
lP[oT;Wb0onA^O82oiFklP;oVKga0_nU`^h3okG8j003oko;i?nobn?o_l_S00?og=7>0_oVdL401?oW
dL7ol<naoo3?/?l00002oo3?/003ooO;W?ohbicon<^L00;on<^L0oojbI@00oojbI?on/RCooooo`04
ooooo`;oLSIg0_mX;gD01?mA7G3o@A1Zooooool00007ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`Go00001oooool00ol0003oooooooooo`0Tooooo`03o`1Db?lHP>OoQ;Sg00;oQ;Sf0_n=
^oD01?nG__?oV[oboiZol_nJ_o82oic0lA[oWL3a00?oWKoaoibolOnL_o405OnL_o4Coi^ol@koV[ka
1onI__47oiVml@04oiRmlOnH_O;oV;gboiRmlP;oV;ga0_nH_O86oiNmlP;oUkcb2OnF_?83oiFllPOo
U;_b1?nC^o82oi>jlPGoT[[b0onA^_82oi6ilPWoT;Wb0onA^O800onE^o7oVKgaoiVml@03ojG2kP?o
]LSX0_nobn<3omcAcP;oi]710_oWdL42oo3?/003o`000?o`ck3oml^L00Con<^L0oojbI@00oojbI?o
n/RCoo[8T`04ooooo`;oLSIg0_mX;gD01OmA7G3o@A1Zoooooooooooo000000Kooooo00001Ooooooo
0000oooooooooooo000000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0T
ooooo`05o`1Db?lHOnKoGJOgohBhm_n4]oH00_n=^oD01?nG__?oV[oboiZol_nJ_o82oic0lAGoWL3a
1OnM_o400onM`?7oW;oaoibol@0Eoibol@ooVkoa00CoVkkaoi^olOnK__7oVkka3_nJ__46oiVnl@Oo
VKga2_nH_O400onG_O;oUkgaoiNml@04oiNllPWoU[cb00?oUKcboiFkl_nE^o801onD^o82oi>klPCo
Tk[b1?nB^_82oi6jlPCoTKWb1On@^O82oi2hlP;oT;Wb0_nA^O82oiFkl@;oVKca0onU`^h2okG8j0;o
_l_S0ooLdLh01OoLdLgoim71onOA`OoWdL7oim7000;ol<n`00?o0000oo3?[oohbi`00oohbi`01?oh
bi_on/VDoo[9ToojbI<2oo[8T`;ooooo00CoOd5jogLkNOmb=WOoLSIg0_mX;gD01OmA7G3o:@1Qoooo
oooooooo000000Kooooo00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooool00000
2_ooool00ol0003oooooooooo`0Tooooo`05o`1Db?lHOnKoGJKgoefVmon3]oH00_n=^oD2oiNnl`;o
V[ob0_nL_o4Coig0l@;oWKoa1OnM`?400onM_o7oW;oaoibol@0Eoibol@_oVkoa2?nK__4>oiZnl@Ko
VKka1onI_O4:oiRml@03oiNmlOnG_?7oUkca00?oUkca00?oU[cboiJllOnF_?401_nF_?84oiFklP03
oiBkl_nE^o;oU;_b00GoU;_b1OnC^_84oi:jlP03oi6jl_nB^O;oTKWb00?oTKWb1On@^O82oi2hlP03
oi2il_nA^O;oTKWb00?oUK_a0_nI_?03ojG2kP05okG8j?nobn?o_l_Soko;hooLdLh00_oLdLd3onOA
`@06onOA`?o`ck3ol<n`oo3?/?l0003olLn_0_ohbi`3ooS;V`;on/VC0_ojb9<00oojb9;oOd5jogm1
NP02ogLkN@05og8fMomX;gGoHb]doe4ML?lY06400_ooool00ol0003oooooooooo`04ooooo`0000Go
ooooo`000?ooooooooooo`000009ooooo`;o00002oooool2o`0002Kooooo00Co67oVoefVmomMY_Oo
Q;Of0_n=^oD2oiNnlP;oV[ob0_nL_o4>oig0l@03oifolOnM`?7oWL3a00CoWL3a2?nM_o4Eoibol@Oo
Vkoa3?nK__4>oiZnl@KoVKka1onI_O4:oiRml@KoUkca1onF_?400onF_?;oU[_aoiFklP05oiFklPKo
U;_b1onC^_801?nB^_;oT[Wboi:il_nB^O84oi6ilP?oT;Wb1On@^?82oi6ilP03oiFklOnE^_7oUK[a
00;oVKc`00CoYL;^ojG1kOneanSo]LOX0onobn<3omcAc@04onOA`OoWdL3oim70onOA`0;ol<n`00Co
0000oo7?[ooacjoon<^L0oohbi/00oojbI?on/RCoo[8T`03oo[8TP04ogm1N_mg>gWoMc]iog8fM`;o
Hb]d00GoDAe`obT0HOooooooooooo`000006ooooo`000_ooool2o`0000_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Tooooo`;o67oV00CoGJKgohBgm_n4]oKoSK_e0_nG__82oiZo
lP;oW;oa4?nM`?4=oifolAGoW;oa00?oVkoaoibolOnL_o400onL_o4?oi^nl@coV[ka00?oVKkaoiVm
lOnI_O402_nI_O48oiRml@;oV;ca1_nG_?46oiJll@GoU[_a1?nE^o84oiBklP;oU;[b1_nC^_85oi:i
lPCoTKWb0_n@^O86oi2hlP;oTKWb0onE^_401?nI_?3oYL7]ojG1kOnU`Nd2okG7j0?o_l_S0ooLdLd4
onOA`0;ol<n_00?o0000oo7?[oohbi`00oohbi/00oohbY[on/RCoo[8T`03oo[8TP04ogm1N_mg>gWo
Mc]iog8fM`;oHb]d00Go?PiYo`/0E?ooooooooooo`000006ooooo`007_ooool00ol0003ooooooooo
o`0Tooooo`;o5gkV00CoGJKgoh>gm_n3]oKoSK_e0_nG__83oiZolP03oibolOnM`?7oWKoa00;oWKoa
2OnM`?43oifol@?oWKo`2_nM_o4Koibol@ooVkka3?nJ__4=oiVml@KoV;ga1?nH_?46oiNll@03oiJl
lOnG_?7oUkca00?oU[ca1OnF^o43oiFkl@03oiBkl_nD^o7oU;_a00;oU;[a0_nD^_86oi>jlPGoT[Wb
0onA^O89oi2hlP;oTKSb0_nE^_42oiVll0;oYL7]0onfanP00onobn?o`<_SomcAc@02omcAc@05omgA
cOoWdL3oim70onOA`?oWdKl00_oacjl00ol0003olLn^ooS;V`02ooS;V`;on<ZJ00Son/RCoo[8T_oj
b9;on/RBoo[8TOokb97oMc]iofhdM`;oHb]d00Go?PiYo`/0E?ooooooooooo`000006ooooo`007ooo
ool00ol0003oooooooooo`0Tooooo`;o5gkV00CoGJKgoh>gm_n3]oKoSK_e0_nG__801?nJ_o;oV[oa
oiZolOnL_o43oifol@SoWL3a1OnM_o0:oifol@?oWKo`6onL_o4?oi^nl@coV[ka3OnI_O45oiRml@Go
V;ca2OnG_?400onF_?7oU[_aoiJkl@05oiJkl@?oUK_a0onD^o44oiBjl@04oi>jl_nC^_7oTk[aoi>j
l@;oTkWa1OnB^O800onA^O;oTKSboi6hlP09oi2hlP04oi6hlOnE^_7oUK[aoiFjl@;oVKc`0_nU`Nd0
0onfanSo]/OWokK7i`02ol3;h`03omcAcOoMdLgogM7=00?oim7000Koim6ooo7?[ooacjoolLn_o`00
0?oacjh2ooS;V`;on<ZJ1?ojb9801?ojb97onlRAogDiNOm^=7L2of<[M003och>JOl;05Cooooo00;o
oooo00?o0000ooooooooool00oooool0023ooooo0_l0000Uooooo`03o`1CaolGO^KoGJKg00;oPkOf
00CoSK[doiNnl_nG__;oUkkb0_nJ_o400onL_o7oWKoaoifol@03oifol@03oig0lOnM_o3oWKo`00Go
WKo`1onM_o49oifol003oibolOnM_o7oWKoa00CoW;oa0onL_o0<oibol@GoW;ka3onK__47oiZnl@Go
V[ga3OnI_O43oiRml@OoV;ca2?nG_?49oiJkl@?oUK_a00?oU;_aoiBjlOnD^_400onD^_45oi>jl@;o
TkWa0_nB^O401?nB^O;oT[Waoi6ilOnA^O42oi6hlP?oT;Sb1On@^?42oi6hl@03oiFjlOnF^_7oU[[a
00;oVKc`0_nU`Nd2okK7i`03ol3;hoo0bn;o`<_R00;ogM7=00GogM3<onOA`?oWdKooim6oonO@_`02
oo7?[`03o`000?oacjkon<^K00?on<ZJ00con<ZIoo[8T_ojb9;on/RBoo[8TOokb97onlR@ofhdMomS
:gCoEb5`och>JOl;05@3ooooo`03o`000?oooooooooo00?ooooo000Rooooo`03o`000?oooooooooo
02?ooooo0_l0DlL00omMY_OoPkOfoh>gmP02ohfjm0;oUkkb0_nJ_o400onL_o7oWKoaoifol00=oifo
l003oifolOnM_o3oWKo`00_oWKo`00?oWKoaoifol?nM_o001onL_o000onL_o7oW;o`oibol003oibo
l@03oibnl?nL_o3oW;o`00;oW;k`1OnL__42oibnl0goVkka0onJ__42oi^nl@;oV[ka1_nJ_O42oiVm
l@;oV[ga2OnI_O49oiRll@SoUkca00?oUk_aoiJklOnF^o401_nF^o42oiFkl@;oUK[a1_nD^_43oi>j
l@CoTkWa1?nB^O44oi6hl@SoT;Sa0_nA^?400onF^_7oU[[`oiVkl002oiVkl004ojK1kOnfanOo]/OW
okK7i`?o`<_R00?ogM7=omg@c?oMd<`00_oWdKl01_oWd;ooj=2ooo7?[_oacjko0000oo7?[@?on<ZJ
0_ohbYT01_ojb9;on/RAoo[8TOokb97onlR@oo_8S`;oEb5`00?o?PiYo`00?_ooool00_ooool00ol0
003oooooooooo`03ooooo`008oooool00ol0003oooooooooo`0Tooooo`04o`1BaomMY_OoGJKgoh>g
mP;oSK[d0_nG__82oiZnl@04oibolOnM_o3oWKoaoifolAgoWKo`3?nL_o06oibnl003oibnlOnL__3o
W;k`00CoW;k`1?nK__42oi^nl0OoVkka00?oV[kaoi^nlOnK__400_nK__400onJ__7oV[gaoiZml@05
oiZml@04oiVmlOnJ_O7oV[gaoiZml@WoVKga2OnH_?47oiNll@;oUk_a2?nF^o42oiFkl@;oUK[a1_nD
^_400onC^_7oTkWaoi>il@03oi>il@?oT[Wa0_nB^?46oi6hl@03oi2hlOn@]o7oT;Oa00?oT;Oa0_nA
^?42oiJjl0;oVK_`0_nV`Nd3okK7i`03ol3;h_o0b^;ogM3<00?ogM3<0_oWd;l01_oXd;oolLn^oo7?
[_oacjko0000oo7>[@;on<ZJ0oohbYT01Oojb97onlRAoo_8TOokb93onlR?00;oEb5`00?o9P1Oo`00
?_ooool00_ooool00ol0003oooooooooo`03ooooo`009?ooool00ol0003oooooooooo`0Tooooo`04
o`1BaomMYOOoGJGgoh>gmP;oSK[d0_nG__82oiZnl@?oW;oa8?nM_o0:oibol0goW;k`1onK__000onK
__7oVkk`oi^nl002oi^nl0KoVkka3?nJ_O400onI_O7oV[gaoiVml@06oiVml@WoV;ca1OnG_?46oiNk
l@KoU[_a0_nE^o42oiFjl@03oiBjlOnE^_7oU;[a00?oU;[a1_nC^O42oi:il@?oT[Sa1OnA^?47oi2g
l@;oTKSa00CoU[[`oiVkl?nI^nooVK__0_nV`Nd3okK7i`03ol3:h_o1b^;ogM3<00;ogM3<00Coim2o
onS@_ooXd;ooj=2n0_oacjh00ol0003olLj]ooS:VP04ooS:V@09oo[8TOokb97onlR@oo_8T?okb8oo
o<Z=oeLQL?lV05oo000n00?ooooo00?o0000ooooooooool00oooool002Gooooo00?o0000oooooooo
ool09?ooool01?l0D/OoGJGgoefUmon3]oH2ohfjm0;oUkkb0_nJ__43oibolB3oWKo`1_nL_o0Aoibn
l0goVkk`00?oVkkaoi^ml?nK_O000_nK_O07oiZml@03oiZml?nJ_O7oV[ga00CoV[ga1_nI_O4:oiRl
l@?oUkca2?nG^o44oiJkl@;oU[[a1_nE^_44oiBjl@KoTkWa0_nB^O43oi:hl@GoTKSa1_n@]o42oi6h
l@;oU[W`00?oVK__oiZkkonJ^nl00_nV`>`2okK7i`?o`L[R0_oMd<`00ooMd<_oj=2oonS@_P02onS@
_P;olLn]00?o0000oo;>[?ohbYT00oohbYT02OoibYSonlRAoo_8T?okb93onlR?ooc:SOoncHWoom:0
oo7AGP03ooooo`03o`000?oooooooooo00?ooooo000Vooooo`;o00009Oooool01?l0D/OoG:GgoebU
mon3]oH3ohfjm003oiNml_nJ__7oV[ka00?oW;oa8?nM_o000onL_o3oWKo`oibol002oibol1;oW;k`
3?nK__06oi^ml003oiZml?nJ_O7oV[g`00WoV[g`00?oV[gaoiZml?nI_?400onI_?400onI_O7oVKc`
oiRll@09oiRll@?oUkca1onG^o43oiJkl@CoU[[a1_nE^_42oiBjl@;oU;Wa1_nC^O44oi:hl@CoTKSa
0_nA]o46oi2gl@;oTKOa0_nF^O03oiZkk`;oY/3/00?o]/OWokO7i_o1b^800_o1b^400ooMd<cogM3;
omk@b`03onS@_P05onS@_OoacZgol/j]o`000?obcZ`00_ohbYT3ooW:V007oo_8T?okb8oonlR?ooc:
SOoncHWoom:0oo7AGP03ooooo`03o`000?oooooooooo00?ooooo000Xooooo`03o`000?oooooooooo
02Cooooo0_mMYOH01?n3]_KoSK[dohfjm?n=^_@2oiNmlP04oiZnlOnL_o7oW;oaoibolB7oWKo`00?o
WKk`oibnl?nL__004onL__0;oi^nl0KoVkg`3onJ_O06oiVll0[oV;ca00?oUkcaoiRklOnG^o401onG
^o42oiJkl@GoU[[a1_nE^_43oiBil@OoTkWa1_nB^?44oi6gl@KoT;Oa0_nA]o42oiJil0;oV[__0_nV
`>`00onganKo]lKVokO6iP02ol7:h@04omg@booNd<_og]3;omk@b`;oj=2n00Ooj=2moo7>[OobcZgo
l/j/o`000?obcZcon<ZI00?onLZH00OonLZGoo_8Sookb8ooo<Z=ook=ROoodX3olM5N00Cooooo00?o
0000ooooooooool00_ooool002Wooooo00?o0000ooooooooool09?ooool00olFONKoG:Gfoh>fmP03
ohfjm0;oUkgb00CoV[kaoibolOnL_o7oW;oa8?nM_o02oifnl1CoW;k`2OnK__09oi^ml0ooV[g`1_nI
_?05oiRll@?oV;c`0_nH^o000onH^o7oUk_`oiNkl@07oiNkl@;oU[_a1?nF^_47oiFjl@?oU;Wa1OnC
^O400onC^?7oT[Saoi:hl@05oi:hl@?oTKOa1on@]o42oi6gl0;oU[W`0_nJ^nl2ojK0k0?o]lKV00?o
`L[Qol;:hOoNd</00_oNd</01?oXd;koj=2monS@_OoYd;d2oo;>[003o`000?obcZcon<ZI00;onLZH
0_oibYL01_oibYKoo<Z=oog;S?oncHWoom:0oo7AGPCooooo00?o0000ooooooooool00_ooool002[o
oooo00?o0000ooooooooool09?ooool2oaMmiP?oPkKf00CoSK[doiNml_nG_O;oV[ka0onL_o4Loifo
l0KoWKk`5?nL__06oi^nl0coVkg`3OnJ_O02oiZll0KoVKc`2?nH_?02oiRkl0KoUk_`00CoUk_aoiNk
l?nG^o3oUk_`0_nF^_001?nF^_7oU[[`oiJjl?nF^_05oiFjl@03oiFilOnD^O7oU;Wa00;oU;Wa0onC
^O43oi>hl@GoT[Sa1OnA]o43oi2gl@;oT;K`0_nA]_001?nA]o3oU[W`oiJil?nJ^nl2oiZjk`;oYl3/
0_nga^H3ol;:h@03omk@booNd<[og]3:00;oj=2m00KojM2monW@_?obcZcol/j/o`000?obcZ/2ooW:
V0;onLZG00?onLZFooc:SOoncHT00_oodX05ooooo`03o`000?oooooooooo00;ooooo000[ooooo`;o
00009Oooool2oaMmiP04oefUm_n3]_KoPkKfohfjm0;oUkgb0_nJ__42oibolA_oWKo`1onM__0Doibn
l0KoVkk`3?nK_O09oiZml0KoV[c`1_nI_?06oiRll0?oV;_`00?oUk_`oiRkl?nH^o001_nG^o02oiNj
l0KoU[[`0_nE^_02oiFjl@04oiFilOnE^O3oU;W`oiBil0;oU;Wa00?oTkWaoi>il?nC^?400onC^?44
oi:hl@03oi6glOnB]o3oTKO`00?oTKO`1?n@]_02oi6fl0;oTKO`0_nF^Nl3oiZjk`;oYl3/00?o]lKV
okO6iOo2b^400_o2b^02omk@bP04omo@bOoYd;gojM2monW@_0;ol/j/00Col/j[o`000?occZ[onLZH
0_oibYL01OoibYKonlbDook=ROoodX3olM5N00Gooooo00?o0000ooooooooool00_ooool002gooooo
00?o0000ooooooooool08oooool2oaMmi@04oebUm_n3]_KoPkKfohfjm0;oUkgb0_nJ__42oibnl1Go
WKo`00?oWKk`oifol?nM_o003?nM__0Boibnl0?oVkk`3onK_O07oiZml0SoV[c`1_nI_?02oiRll0[o
V;_`1?nG^o04oiNjl0KoU[[`0_nE^_04oiFil0CoU;W`00?oTkW`oi>hl?nC^?000onC^?02oi:hl0Co
T[O`1?nA]o06oi2fl0;oTKO`0_nF^Nl01OnJ^^ooV[[^ojO0jonW`>_o]lKU00;o^<KU0_o2b^001?oN
d<[ogm39omo@bOoYd;d2onW@_005onW@^oobcZcol/j[oo;>Zol000000ooibYL01OojbYKonlbDoog?
T?oodX3olM5N00Gooooo00?o0000ooooooooool00_ooool002kooooo00?o0000ooooooooool08ooo
ool00ol0D/Oo5ggVoefUmP02ohBfmP03ohfjm?nG_O;oUkgb00;oV[ka0_nL__0Doifol17oWKk`4OnL
__0Boi^ml0KoV[g`2?nJ_?07oiVll0coV;_`0onG^o04oiNjl0OoU[[`1_nE^O03oiBil0OoTkS`1?nB
]o04oi6gl0;oTKK`1?n@]_02oi6fl0;oT[K`0_nF^>l01?nJ^^koYko[ojNojonW_n/3okS6i@05ol;:
h?o3b^3ogm39omo?bOoOclP00_oYd;`03OoYd;_oj]2koo;>ZoobcZ_o0000oo?>ZOoibYOonLZFoo[:
U_okc9CooLn@oooFQ_oYdEX01Oooool00ol0003oooooooooo`02ooooo`00;oooool00ol0003ooooo
ooooo`0Tooooo`05oaMmiOmMYOKoQ;KfohBfm_n=^_@00_nG_O82oiZnl@;oW;k`4_nM_o0Coifnl17o
W;k`4_nK_O05oiZml0WoV[c`1_nI_?0<oiRkl0CoUk_`1?nG^_05oiJjl003oiJil?nE^O3oUKW`00Go
UKW`00?oU;W`oiBhl?nD^?001_nC^?04oi:gl003oi6gl?nB]o3oT[O`00?oTKK`1?n@]_04oi6fl0;o
U[S_0_nJ^^h3ojNoj`;o^<KU00Co`l[Pol?:goo3b]ooglo90_oOclP2onW@^`07on[@^ooZck[olljZ
oo?>ZOl0003olljXooW:UP02oo_<U003oog?T?ooeXKooooo00Gooooo00?o0000ooooooooool00_oo
ool0033ooooo00?o0000ooooooooool09?ooool01OlGONKoGJGfoh>fm_n3]_KoSK[d00?oUkgb00?o
V[kaoibnl?nL__003onM_o0Goifnl0goW;k`0onL_O0Coi^ml003oiZml?nJ_?3oV[c`00[oV[c`1_nI
_?0<oiRkl0SoUk[`0onF^_03oiJil0KoUKW`0_nD^O02oiBhl0CoTkS`0_nC]o05oi:gl003oi6gl?nA
]_3oTKK`00;oTKK`1?n@]_04oi6fl0;oU[S_0_nJ^^h2ojNoj`04okS6iOnha^Co^<KTol?:g`;o`lWO
0_oOclP01OoPclSoj]2kon[@^ooZck[olljZ00;olljY00Ko0000oo[:U_okc9Coo<jBoog?T?omf7X7
ooooo`03o`000?oooooooooo007ooooo000aooooo`;o00009Oooool01OlGONKoGJGfohBfm_n4]_Ko
SKWd00?oUkgb00?oV[kaoibnl?nL__002OnM_o02oifnl003oifol?nM__3oWKk`01SoWKk`2_nL__06
oibml0?oVkg`0onL_O0<oi^ml0koV[c`0onI_?05oiVkl0SoV;_`0_nH^_08oiNjl0;oU[[`1?nF^O04
oiFil0;oUKS`1?nD^?02oi>hl0CoTkO`1?nB]o001?nA]o3oTKK`oi6fl?nA]_04oi2fl004oi2el?nA
]_3oTKG`oi6el0;oT[K_0_nF^>l2oiZjkP03ojNojonX_n_o^<KT00;o^LKT00?o`lWOolC9gooOclP0
0_oPclP01?oZd;_oj/njon[?^_o[ckT2oo?>Z@06o`000?odcZOom]6Voog?T?ooeXKojM5J1oooool0
0ol0003oooooooooo`01ooooo`00<oooool00ol0003oooooooooo`0Sooooo`05oaMmi_mMYOKoQ;Kf
ohBfm_n=^O@00onG_O801?nJ__7oW;k`oibnl?nL__02oifnl0CoWKo`7onM__0:oibnl0KoW;g`0_nK
_O04oibml0_oVkg`00?oVkc`oiZll?nJ_?003?nJ_?02oiVll0KoVK_`2?nH^o02oiRjl0SoUk[`00?o
U[[`oiJil?nF^O000onF^O04oiFil0;oUKS`1?nD^?02oi>hl0CoTkO`0onB]o07oi6fl0?oT;G`00?o
TKG`oi6ekonA]Nl00_nB]^l2oiJhk`04oi^jk_nX_n_oZ;oZojRojP;o^LKT00Coa<WOolC9g_o4bMko
h<o80_oPclL2on[?^P;ojlni00OolljXooC>Z?l0003om]6Voog?T?ooeXKo000:00Oooooo00?o0000
ooooooooool00Oooool003Cooooo00?o0000ooooooooool08oooool01?lGONKoGJGfohBfm_n4]_H2
ohfim0;oUkga00CoV[kaoibnl?nL__3oW;k`9OnM__05oibnl0_oW;g`0_nK_O05oibml0OoVkg`1?nK
_?0>oiZll0OoVK_`1onH^o04oiRjl0SoUk[`1_nF^O02oiFil0;oUKS`1OnD^?000onC^?3oTkO`oi>g
l003oi>gl0;oT[O`0_nB]_04oi6fl0KoT;G`0onA]Nl00onB]NooUkO^oiNgkP02oi^ikP?oZ;oZ0_ni
a^@3olC9gP;oh<o700[ohLo6on_?^Oo[ckWojlnioo?>Z?odcZSom<jWo`000?ojej;on>F82?ooool0
0ol0003oooooooooo`01ooooo`00=Oooool00ol0003oooooooooo`0Sooooo`;o67gV0on4]_D01?n=
^OCoV;gaoiRmlOnJ__43oibnl2GoWKk`0_nL__0>oibml003oi^ml?nL_O3oW;g`00?oW;g`1_nK_O06
oi^ll0koV[c`2?nI^o04oiRkl0KoV;[`1_nG^_000onG^O3oU[W`oiJil004oiJil0;oUKW`1?nE^?04
oiBhl0KoTkO`1?nB]_02oi6fl0;oTKG`1_n@]O001?nA]NooT;C_oi:ekonB]Nl2oiNgkP;oVkW]0_nX
_nX01_nia^Co^/GSok[5hoo4bMkoaLWNon3?a`;ohLo60oo[ckT01_o/d;Som<jWooKAY_ohe:Co0000
ooSUR0Sooooo00?o0000ooooooooool00Oooool003Kooooo0_l0000Tooooo`;o67gV00CoGJCfohBf
mOn4]_GoSKWd0_nH_O42oi^nl@;oW;k`4?nM__02oifnk`koWKk`0_nM_^l2oifnl0;oWKk_3_nL_O00
0onL_NooW;g`oibml003oibml003oibmkonK_O3oVkg`00?oVkg`00?oVkc_oi^ll?nK_?001?nK_?0:
oiZll0?oV[_`2OnI^o03oiRkl0KoV;[`1OnG^_03oiNil003oiJil?nF^NooU[W_00?oU[W`1?nE^?04
oiBhl0;oU;O`00?oTkO`oi>gkonC]o000onC]o04oi:fl004oi6fl?nA]^ooTKG_oi6ek`;oT;G_1_n@
]>l2oi:ek`;oUkO^0_nK^Nd00onX_n[oZKoYok[5h`02ok[5h`0=olG9g_o5bMgohLo6on7?a_oRclGo
jlnion_?^?o/d;SokM2gooKAY_ohe:Co0000ooSUR008ooooo`03o`000?oooooooooo007ooooo000h
ooooo`03o`000?oooooooooo02;ooooo0_lHONH01?mMY?KoQ;KeohBfmOn=^O@2oiRml@04oi^nlOnK
_O3oW;k`oibnl0coWKk`2?nM_^l2oifnl0?oWKk_00?oWKk`oifnkonM_^l02?nM_^l2oifmk`04oibm
konL_O3oW;g`oibml0_oW;g_0_nL_O04oibmk`;oVkg_00CoVkc`oi^lkonK_>ooVkc_0onK_?03oi^l
k`;oV[c_00?oV[c`oiZlkonJ_>l00_nJ_>l00onJ_?3oV[__oiZkk`03oiZkk`?oVK_`0onI^nl01?nI
^o3oVK__oiVkkonH^o03oiRjl0GoV;[_0onG^_05oiNik`CoU[W_0_nF^>l2oiFhk`03oiFhl?nE^>oo
U;S_00?oU;S_0_nD]nl4oi>gk`;oTkK_0onB]^l00onA]^ooTKG_oi6ek`02oi6ek`KoT;C_0_nA]>l2
oi:dk`03oiNgk_nK^NgoVkW]00?oZKoY00?o^/GSok_5hoo5bMd00_o6bMd00ooQclKoh/o5on;?a@02
onc@^005ong@]oobf;Kon]NRooSUR?l000002Oooool1o`00007ooooo0Oooool003Wooooo00?o0000
ooooooooool08oooool01OlHONKoGJCfohBfmOn4]_GoSKWd00;oV;ga0_nK_O02oibnl0OoWKk`7?nM
_^l3oifmkaGoW;g_3?nK_>l7oiZlk`KoV[__00?oVK_`oiVkkonI^nl01?nI^nl2oiVjk`WoV;[_0_nG
^^l6oiNik`;oU[W_1?nF^>l4oiFhk`;oU;S_0onD]nl3oi>gk`?oTkK_1?nB]^l3oi6ek`03oi6dkon@
]>ooT;C_00CoT;C_00CoTKC_oi2dkon@]>ooT[C_0_nG]nh2oi^ik@?oZKoY00Co^lGSok_5h_o6bMgo
a/WL0ooRclD02?o/d;SokM2gonoD]oobf;Kom=fdooSUR?oooooo00002?ooool1o`00007ooooo0Ooo
ool003[ooooo00?o0000ooooooooool08oooool01OlIONKoGJCfohBfmOn4]_GoSKWc00?oV;ca00?o
Vkg`oibnl?nL__000onM__02oifnk`;oW[k_5onM_^l7oifmkaCoW;g_0_nL_>l<oi^lk`GoV[c_2?nJ
^nl6oiVkk`;oVK[_2?nH^^l3oiNjk`KoUkW_0onF^Nl4oiJhk`CoUKS_1OnD]nl00onC]nooTkK_oi>f
k`03oi>fk`;oT[K_0_nB]Nl2oi6ek`;oTKC_2?n@]>l2oi:dkP;oUkO]0_nK^Nd00onY_nWoZ[kYok_5
hP02ok_5hP06olK9g?o7b]coh/o5on?@a?oTd<CokM2g0_obf;H01?odgKCoko2Gooooool00008oooo
o`7o00000Oooool1ooooo`00>oooool00ol0003oooooooooo`0Sooooo`05oaUmi_mNY?KoQ;KeohBf
mOn=^O<00onH_?401?nK_O3oW;k`oibnl?nM__03oifnk`?oW[k_5OnM_^l9oifmka?oW;g_0onL_>l;
oi^lk`?oV[c_3?nJ^nl5oiVkk`;oVK[_2?nH^^l2oiRik`OoUkW_00?oU[W_oiJhkonF^>l00onF^>l3
oiFhk`;oUKO_1OnD]nl4oi>fk`;oT[K_0_nB]Nl3oi6ek`?oTKC_1?n@]>l00on@/nooT;C_oi2dk`03
oi:dkP;oUkK]00OoW;S/ojZnjOnZ_nSoZ[oXok_5h_nla^;oal[L00;ob<_L00Kohm34onC@a?oVe<Co
l]RfooCM]?ohkJ/3ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000looooo`;o
00009?ooool01?lIONKoGZCfohBemOn4]OD2ohjil`;oV;ca00CoVkg`oibnl?nL__3oW;k`0onM_^l3
oijnkaGoWKk_2OnM_Nl@oibmk`KoW;c_2onK_>l00onJ_>ooV[__oiZkk`0;oiZkk`CoVK__1?nI^^l6
oiRjk`;oV;W_1onG^Nl2oiJik`KoU[S_0_nE^>l2oiFgk`KoU;O_1?nC]^l2oi:fk`;oT[G_00?oTKG_
oi6dkonA]>l00onA]>l5oi2ck`;oT;?^0onB]>h00onG]^goW;S/oibhk003ojZoj003okc6h_nman;o
b<_L00;ob<cL00Goi=34onKDa?o]glCom=fdono`U`04ooooo`03o`000?oooooooooo00Cooooo0Ol0
0001ooooo`7ooooo000nooooo`03o`000?oooooooooo02;ooooo0_lIO^H2ohBem@;oS[Wc0_nH_?40
1?nK_O3oW;k`oibnl?nL__04oifnk`03oijnkonM_^ooWKk_013oWKk_3OnM_Nl@oibmk`KoW;c_2onK
_>l>oiZkk`SoVK[_1?nH^^l3oiRik`KoUkW_0_nG^>l8oiJhk`CoUKO_1?nD]nl00onD]^ooTkK_oi>f
k`03oi>fk`?oT[G_1OnA]>l00on@]>ooT;?_oi2ck`02oi2ck`CoT;?^00CoT[C^oi6dk_nG]^goUkK]
0_nL^N`00onZ_nSoZl3Yokg7hP02okg8hP06olS<g?o;dMkoi]C4onWJa?o]glColOFm1_ooool00ol0
003oooooooooo`03ooooo`7o00000Oooool1ooooo`00?oooool00ol0003oooooooooo`0Rooooo`;o
6WkV00CoGZCfohBemOn4]OGoS[Wc0_nH_?401?nK_O3oW;k`oibnl?nL__04oifnk`03oijnkonM_^oo
WKk_00coWKk_4OnM_Nl;oibmk`[oW;c_2_nK_>l2oi^kk`koV[__2?nI^^l2oiRjk`GoV;W_1_nG^Nl2
oiNhk`KoU[S_0_nF]nl4oiFgk`;oU;O_0onD]^l3oi>fk`03oi>ekonB]NooT[G_00;oT[G_1?nA]>l2
oi2dk`KoT;?_00CoT;?^oi6dk_nA]>ooTKC_0_nG]nh2oibik@03oj_0jOn[`NWo_LSR00;o_lgU00Go
bm7NolgHhOo]glCokMo4on7gY@06ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo
0010ooooo`03o`000?oooooooooo02;ooooo00?o05C9oa]ni_mNY?H00_n4]OD00on>^O?oV;caoiRl
l@02oi^ml0;oW;g`1?nM_^l00onN_^ooWKk_oifnk`09oifnkaCoWKg_2_nL_Nl;oiblk`SoVkc_1OnK
^nl;oiZkk`;oV[[_1onI^^l2oiRjk`KoV;W_1?nG^Nl4oiNhk`CoU[S_0onF]nl3oiFgk`;oU;O_0onD
]^l4oi>fk`KoT[G_1?nA]>l2oi2dk`;oT;?_0on?/nl2oi2ck`?oTKC_00CoUkO^oibjkOnL^^goZl7Y
0_n/aN`01OnocNGo`MCXolgHhOo@h>CobOcT00Wooooo00?o0000ooooooooool00oooool1o`00007o
oooo0011ooooo`;o00009?ooool01OlKO^OoGZCfohBemOn4]OGoS[Wc00;oV;ca0_nK_O02oibml0Co
WKk_00?oW[k_oifnkonN_^l01OnN_^l3oifnkaKoWKg_1onL_Nl>oiblk`CoVkc_1onK^nl;oiZkk`?o
V[[_1onI^^l8oiRik`;oUkW_1OnG^>l5oiJhk`03oiJgkonE]nooUKO_00?oUKO_00?oU;O_oiBfkonD
]^l00_nD]^l4oi>fk`GoT[G_0onA]>l4oi2dk`?oSkC_0_n?/nl2oi2dk`04oi6dkon?^?;oU[_aoiJk
l@;oVkk`00?o[<G/ojc<lOo1e>P00_o2g>`00oo9o>Coooooooooo`09ooooo`03o`000?oooooooooo
00;ooooo0Ol00001ooooo`00@oooool00ol0003oooooooooo`0Rooooo`05oa]niomOY?KoQ;GeohBe
mOn>^O<00onH_?400onK_O3oW;g`oibml004oifnk`SoW[k_6OnM_Nl4oibmka7oW;c_0onK_>l8oi^k
k`KoV[__1onJ^^l6oiVjk`[oV;W_00?oUkW_oiNhkonG^>l00_nG^>l5oiJhk`?oU[O_1?nE]nl2oiBg
k`CoU;K_1?nC]^l2oi:fk`04oi:ekonA]NooTKG_oi6ek`;oT;Oa0_n?]o400on>]o7oS[KbohjflP04
ohfflP04ohjgl_n;^oKoSKcfohflmP;oU<3e00KoV/CeoiO;nOn[e?GoZmCeol;Lk?nfn>h=ooooo`05
o`000?ooooooooooooooool000000Oooool004Cooooo00?o0000ooooooooool08_ooool01OlLO^Oo
GjCfohBemOn4]OGoS[Wc00?oV;ca00?oVkg`oibmkonL_Nl01?nM_^l6oijnk`;oW[g_6OnM_Nl00onL
_NooW;c_oiblk`0Boiblk`_oVk__1_nJ^nl6oiZjk`CoVK[_0onI^Nl9oiRik`03oiNhkonG^>koUkS^
00?oUkS_1_nF^>l6oiFgk`CoU;O_0_nC]^l4oi:hl@?oTKOa0on@]o400on>^_CoSK[dohfjm004ohbj
m@;oRk[f00CoRk_fohNon_n8`O[oR<7j0_n9`_X2oi77nP03oiO;nOla^;_ooooo00oooooo00Go0000
ooooooooooooooooo`000001ooooo`00AOooool00ol0003oooooooooo`0Rooooo`;o77oW0_n5]O@2
ohjil`;oV;ca00GoVkg`oibmkonL_NooW;g_oifmk`02oifnk`03oijnkonN_NooW[g_00GoW[g_6?nM
_NlEoiblk`coVk__0onJ^nl5oiZjk`?oV[[^0_nI^^h00onI^^ooVKW^oiVikP03oiVikP?oV;W_1?nH
^Nh00onH^>koV;S_oiRhk`05oiNhk`KoU[S_0onE]nl00onD^O3oU;S`oiBhl003oi>hl0;oTkSa00Co
T[Saoi6klonA^o?oT;_c1?n?^_@01?n>^_CoS;kgoh^nn?n;__P2ohZnn0;oRKkh00CoR;oiohNonOmW
bocoIl_l0_mUbo/00omSc?[oooooooooo`0Eooooo`04o`000?ooooooooooo`00007ooooo0016oooo
o`03o`000?oooooooooo02;ooooo0_lMOnL01OmOYOKoQKGdohjhlon>^??oV;ca00;oVkg`0_nL_Nl4
oifmk`SoW[g_5OnM_Nl3oiflka;oW;c_0onL^nl<oi^kk`03oiZkkonJ^^ooV[[^00SoV[[^0_nI^^h6
oiVikP;oV;W^1OnH^Nl00onH^>ooUkW_oiNik`05oiNhk`04oiJhkonF^O3oU[W`oiJil0;oUKW`0_nD
^O04oi>klP?oT[_c00CoTK_coi2nm_n@__KoSkkf0_n>__H3ohfnm`06og[<oomgc?ooMlcoogC<oom>
angoB<GX8Oooool00ol0003oooooo`000001ooooo`00Aoooool2o`0002?ooooo00Co05O<of2Um_mP
YOKoQKGd0_n>^?<01OnH_?7oVkg`oi^ml?nK_O3oW;g_00CoWKg_1onN_NlEoifmk`CoWKc_3_nL_>l0
0onL_>koW;__oibkk`03oibkk`03oibkk_nK^nooVk__00;oVk__0_nK^nh00onK^nooVk_^oi^kkP03
oi^kkP_oV[[^0_nI^^h5oiVikPSoV;W_0_nG^Nl2oiNil0GoU[W`00GoUK_boiBkl_nD^o;oU;_boi>k
lP04oi:nm0?oTKke00GoT;keoh?;o_n2boooP/_ooh3<o`02ofK@nP03of??n?mNcOKooooo02Oooooo
00?o0000ooooool000000Oooool004Wooooo00?o0000ooooooooool08Oooool01?l0ElcoH:Gfof2U
m_n5]O@2ohjhl`05oiRllOnK_O3oVkg`oi^ml?nL_Nl01?nM_Nl8oijmka7oWKg_1onM_>l5oiblk`Go
W;c^00?oW;c_oiblk_nL_>h00_nL_>h00onK^nooVk_^oi^kkP03oibkkP03oi^kkonK^nkoVk_^00Go
Vk_^0onK^^h:oiZjkP?oVK[^00?oVKW^oiVikonI^Nl00onI^Nl00onH^NooV;[_oiRjk`03oiRjk`03
oiNjkonG^o7oUk_a00GoU[_a00KoUK_aoiBmlonD_OCoU;gdoi>mm?nC__@2oh[9o@;oR<[m00GoQl[n
ohK:o_mddOkoM=7nog7Ao@0aooooo`7o00000Oooool1o`000000B_ooool00ol0003oooooooooo`0Q
ooooo`04o`1GcOmPYOKoH:GfohFem0;oS[Sc0_nH_?02oi^ll003oibmkonM_NooWKg_00;oWKg_2?nN
_Nl>oifmk`WoWKc_0_nM_>h:oiblkPCoW;_^0onK^nh3oibkkPKoVk_^1OnK^^h:oiZjkP?oVK[^0onI
^^l4oiRjk`KoUk_a0onF_O<2oiFml`06oiBmlon=b?_oSLSlohg8o?n<bOcoRlWm0_mmdOl00omkdOoo
?L7Hooooo`0gooooo`;o0000001;ooooo`03o`000?oooooooooo027ooooo00Co05S=of6UmOmQYOGo
QKGd0on>^?<00onH^o3oVkc`oi^ll002oibmk`?oWKg_2?nN_Nl:oifmk`05oifmk_nM_NooWKc^oifl
k_nM_>l02_nM_>h8oiblkPOoW;_^0onK^nh2oibkkPKoVk_^1?nK^^h8oiZjkP03oiZjkonI^^ooVK[_
00;oVK[_1OnH_?001?nH_?7oUkgboiNml_nG_O83oiJmlP?oT<Oj0_n?b?/01On>b?_oQ=3ooh;AoomC
c>WoC/[V03gooooo0ol0000004cooooo0_l0000Rooooo`03o`1Hc_lPP>SoHJGe00;oQKGd0_n>^?<0
0onH^o3oVkc`oi^ll002oibmk`?oWKg_1OnN_Nl3oijmkP;oWKg_1onM_Nh?oiflkPSoW;c^2?nL^nh3
oi^kkP03oibkk_nK^nkoVk_^00GoVk_^0onK^^h00onJ^^koV[__oiZkk`04oiZkk`KoVKc`1?nH_O80
1?nG_O;oTlKioi?6nOnBa_T2oi76n@06oi77n_n9cokoR<ooohS?oon6d?ooGm7b?oooool4o`0000?o
oooo001>ooooo`03o`000?oooooooooo023ooooo0_l0FLh2of:Um@04ohFem?n?^?;oSkSboiRkl0;o
Vkc_0_nL_Nl4oifmk`OoW[g^1_nM_NhBoiflkPCoW;c^2onL^nh9oi^kkP?oVk__1?nJ^nl3oiZll0?o
VKc`0onI_O401_nH_O7oV;gboiC5n?nDaOSoU<Khoi?6n@;oSLkm00GoS<knoh_>o_m]eOWoKMGiof[D
n010ooooo`Co00001oooool004oooooo00?o0000ooooooooool08Oooool01OlRPNSoHZGeohJem?n6
]OCoSkSb00;oV;_`0_nK_>l2oibmk`;oWKg_0_nM_Nh7oijmkP;oWKg^5_nM_>h00onL_>koW;_^oibk
kP0<oibkkP?oVk_^1OnK^nl6oiZll0;oV[ga1?nI_O401OnFaOOoULGgoiG5monEaOOoT<cl00;oSlgm
00CoS/gmogOFoOmee_co0000@oooool3o`0000_ooooo001@ooooo`03o`000?oooooooooo027ooooo
00Go8X7Xof:UmOn6]?CoQ[CdohnhlP03oiRkl004oi^lkonL_>ooW;c_oifmk`?oWKg^2?nN_NhGoifl
kPooW;_^0onK^nl3oi^lk`03oi^ll?nJ_?3oV[ga00?oV[ga0onGa?H3oiK4m`06oi7;o?nAc?coTLcl
oi3<o?mme_koNmKnAOooool4o`0000kooooo001Aooooo`03o`000?oooooooooo027ooooo00Go8h;Y
of:UmOn6]?CoQ[CdohnhlP03oiRkl003oi^lkonL_>ooW;c_00CoWKg^1_nN_Nh00onN_>koWKc^oifl
kP0GoiflkPCoW;_^1?nL_>h00onL^nkoVkc_oi^lk`04oi^lk`GoVkg`00SoV[g`oiS3m_nHa?KoV<Cf
oiO4m_nCb_[oTl_koi;;n`;oPmKo00?oP]Kooh3Fooooool0AOooool4o`0001;ooooo001Booooo`;o
00008_ooool2ob>2j@?oQ[Cd00CoSkSboiRkl?nH^o3oVkc_0_nL_>l3oifmkP03oijmk_nN_>koW[c^
00GoW[c^6OnM_>h4oiblkPCoW;c_00?oVkc_oi^ml?nK_O000_nK_O03oiW3m@?oV<?e00OoULWjoiC:
n_nDb_[oU<[johOEoon6eOoo=kg:04Oooooo1?l0000Fooooo`00E?ooool00ol0003oooooooooo`0P
ooooo`04o`1LdOlUP^WoHjGeohJdl`;oSkSb00GoV;_`oi^lkonK_>ooVkc_oiblk`02oiflkPWoW[c^
5OnM_>h3oibmk`?oW;c_0onL_O02oi^ml0CoVL?d0_nFb?T3oiK9n@04oiG9nOn:e?ooRMCood?5eTSo
oooo1?l0000Jooooo`00EOooool00ol0003oooooooooo`0Pooooo`04o`1MdOmTYOGoI:GeohJdl`;o
SkSb00GoV;_`oi^lkonK_>ooVkc_oiblk`02oiflkPWoW[c^4?nM_>h3oifmk`;oW;g_1_nL_O03oi[2
m006oi[3m?nGb?SoUlShoiO8n?nGb?WoSM?o0on<dom9ooooo`Co00007_ooool005Kooooo00?o0000
ooooooooool08?ooool01?l0GM;oI:GeofBUmOn6]?<2ohnhlP;oV;_`0_nK_>l00onL_>koWKc^oifl
kP0:oijlkPWoWKc^1_nM_Nl3oibmk`03oibml?nK`_?oVl;c00;oV/;c00OoV/;doiS7n?nHaoSoV<Oh
oiS8n?n?d_koS];n00;oFm;Y00?oF=3Wooooooooool0B?ooool3o`0002;ooooo001Gooooo`;o0000
8Oooool01Ol0G];o9h?ZofFUmOn7]??oSkSb00;oSkOb00?oV;_`oi^kkonL_>h00_nL_>h00onM_>ko
W[c^oijlkP08oijlkPCoWKc^2?nM_Nl00onL_NooVl;coi_2l`02oi_2l`?oVLOg00KoV<Ogoi7AoOnA
dOgoTM7moi3Ao_lW/;A<ooooo`Co00009Oooool005Wooooo00?o0000ooooooooool07oooool00ol0
G]?o9hCZofFUm@02ohNdl`04ohngl_nH^nooV;__oi^kk`?oW;c^00?oWKc^oijlk_nN_>h01OnN_>h:
oifmk`CoVl;c0_nIa_H00onIa_OoVLOgoi?@o@02oi;@o@03oi7@oOmYeo?o<[W104cooooo1?l0000Y
ooooo`00F_ooool00ol0003oooooooooo`0Pooooo`05obR4j_mUY_GoQkCcohNdlon@]o800_nI^nl2
oi^kk`;oW;c^0_nM_>h9oifmk`GoW<7b00?oW<;boi[6m_nJa_H00_nJa_H01OnDcocoTloloi?@oOm_
f?Oo?<3;04gooooo1?l0000]ooooo`00Foooool00ol0003oooooooooo`0Pooooo`05obR4j_mVY_Go
QkCcohNdlon@^?800_nH^o02oi^lk`03oiblkonM_NooWKg_00GoWKg_1?nL`O800onKaOGoV/Gfoi[5
mP02oi[6mP06oiG>o?nDcocoM][jogKJn_mdfOWoALKDCOooool4o`00037ooooo001Looooo`03o`00
0?oooooooooo023ooooo00Oo9hGZofFVmOn7]O?oQkGcohnhl_nH^o3oV;c`00;oVkg`00?oW;g_oifm
konL`O800onL`O84oi_5m@07oiK=nonFc__oU/kkoiK>nomjf_coNM[kodg;g01>ooooo`Co0000=Ooo
ool005gooooo0_l0000Pooooo`05o`000?lOPnWoH:SgohNem?n4^?L00_n=^oD01OnG_o?oV/3boi[0
l_nK`?;oV/Ce00?oVlGe00GoUlgjoiO=nonFcO_oOM[moeO@i01Aooooo`?o0000>Oooool005oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`02oe^Yn@07oh6knOn;_oSoRkohoiG3m_n@
b__oU<_koiK<nP02ogkIoP03ogoJo_mLdnWooooo053ooooo1?l0000looooo`00H?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00Ko6YkRoeO4n?mGa?SoIlgkogSEo_mDc^QB
ooooo`Co0000@?ooool0067ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Foooo
o`Co0000A?ooool006;ooooo0_l0000Kooooo`03o`000?oooooooooo05;ooooo1?l00018ooooo`00
I?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04kooooo1?l0001<ooooo`00IOoo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04_ooooo0ol0001@ooooo`00I_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo1?l0001Cooooo`00Ioooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo1?l0001Gooooo`00J?ooool2o`0001Go
oooo00?o0000ooooooooool0?oooool4o`0005_ooooo001Zooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0>oooool4o`0005oooooo001[ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0=oooool4o`0006?ooooo001/ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0=?ooool3o`0006Oooooo001]ooooo`;o00004?ooool00ol0003oooooooooo`0`oooo
o`Co0000J_ooool006oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0]ooooo`Co
0000K_ooool0073ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`Co0000
L_ooool0077ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`Co0000M_oo
ool007;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000N_ooool0
07?ooooo0_l00009ooooo`03o`000?oooooooooo01kooooo0ol0001nooooo`00MOooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01[ooooo1?l00021ooooo`00M_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l00025ooooo`00Moooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01;ooooo1?l00029ooooo`00N?ooool2o`0000Cooooo00?o0000
ooooooooool03_ooool4o`0008gooooo001jooooo`05o`000?ooooooooooooooool000003?ooool4
o`00097ooooo001kooooo`04o`000?ooooooooooo`0000Wooooo0ol0002Eooooo`00O?ooool00ol0
003oooooo`000005ooooo`Co0000V?ooool007gooooo0_l000000ooooooo0000o`000002o`0009co
oooo001nooooo`;o0000X?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00=3o
oooo0ol0001=ooooo`00dOooool00ol0003oooooooooo`1<ooooo`00Goooool00ol0003oooooo`00
0003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00002?ooool3o`0000?ooooo0ol0
0004ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00008ooooo`Go000000Go
ooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003ooooo`?o00000_ooool3o`000003oooo
ool0003o000000Co00000_ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04_ooooo
001Oooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooo
oooooooooooo000000cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
ooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_ooooo
001Oooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`03o`000?oooooo000000;ooooo1Ol0
0008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`Go00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000C?ooool005kooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000008ooooo`?o00000oooool2o`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001<
ooooo`00G_ooool01Ol0003oooooo`000?oooooo000000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000Wooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o
000000;ooooo0ol00002ooooo`Co00000_ooool4o`0000[ooooo00Co0000oooooooooooooooo1?l0
0002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0003o0000
0oooool4o`0000;ooooo0_l000000ooooooo0000o`00001;ooooo`00G_ooool01Ol0003oooooo`00
0?oooooo000001[ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Booooo`00
G_ooool6o`0001Sooooo1Ol0000Dooooo`03o`000?oooooooooo00Sooooo1Ol00008ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Booooo`00oooo
oolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0755268, 0.0565978, \
0.0035823, 0.0035823}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.14478 .20005 -11.9289 -9 ]
[.14478 .20005 .07109 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.53881 .04509 -5.20895 -9 ]
[.53881 .04509 .79105 0 ]
[.76813 .09808 0 -6.16085 ]
[.76813 .09808 12 2.83915 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93425 .35246 0 -5.92044 ]
[.93425 .35246 6 3.07956 ]
[.01773 .30515 -24 -2.77615 ]
[.01773 .30515 0 6.22385 ]
[.00988 .35431 -24 -2.81782 ]
[.00988 .35431 0 6.18218 ]
[.00179 .40505 -18 -2.86096 ]
[.00179 .40505 0 6.13904 ]
[-0.00657 .45743 -6 -2.90566 ]
[-0.00657 .45743 0 6.09434 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15401 .20938 m
.15862 .21405 L
s
[(-5)] .14478 .20005 .98815 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54659 .05566 m
.55048 .06094 L
s
[(5)] .53881 .04509 .73632 1 Mshowa
.125 Mabswid
.19074 .195 m
.19347 .19784 L
s
.22799 .18041 m
.23069 .18328 L
s
.26579 .16561 m
.26845 .16852 L
s
.30415 .15059 m
.30676 .15354 L
s
.38256 .11989 m
.38509 .12291 L
s
.42265 .10419 m
.42513 .10725 L
s
.46334 .08826 m
.46577 .09135 L
s
.50465 .07208 m
.50703 .07521 L
s
.1178 .22356 m
.1206 .22633 L
s
.0821 .23754 m
.08493 .24027 L
s
.04689 .25133 m
.04976 .25402 L
s
.58918 .03898 m
.59146 .04219 L
s
.63243 .02205 m
.63466 .02529 L
s
.67636 .00485 m
.67853 .00813 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75582 .10262 m
.74967 .10489 L
s
[(-5)] .76813 .09808 -1 .36908 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92174 .35641 m
.91548 .35839 L
s
[(5)] .93425 .35246 -1 .31565 Mshowa
.125 Mabswid
.77442 .13107 m
.77072 .13241 L
s
.79253 .15877 m
.78882 .16009 L
s
.81016 .18574 m
.80645 .18704 L
s
.82734 .21201 m
.82362 .2133 L
s
.86039 .26257 m
.85666 .26382 L
s
.8763 .28691 m
.87256 .28814 L
s
.89182 .31064 m
.88807 .31186 L
s
.90696 .33381 m
.90321 .33501 L
s
.73671 .07338 m
.73302 .07476 L
s
.71706 .04332 m
.71338 .04473 L
s
.69685 .01241 m
.69318 .01384 L
s
.93616 .37848 m
.93241 .37965 L
s
.95025 .40003 m
.94649 .40119 L
s
.96402 .42108 m
.96025 .42222 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02998 .30045 m
.03611 .2981 L
s
[(-150)] .01773 .30515 1 -0.38308 Mshowa
.02217 .34971 m
.02832 .34742 L
s
[(-100)] .00988 .35431 1 -0.37382 Mshowa
.01412 .40055 m
.02028 .39831 L
s
[(-50)] .00179 .40505 1 -0.36423 Mshowa
.0058 .45305 m
.01198 .45086 L
s
[(0)] -0.00657 .45743 1 -0.3543 Mshowa
.125 Mabswid
.02844 .31018 m
.03212 .30878 L
s
.02689 .31997 m
.03057 .31857 L
s
.02532 .32982 m
.02901 .32843 L
s
.02375 .33974 m
.02744 .33835 L
s
.02058 .35975 m
.02427 .35838 L
s
.01898 .36986 m
.02267 .36849 L
s
.01737 .38002 m
.02106 .37866 L
s
.01575 .39026 m
.01944 .3889 L
s
.01247 .41092 m
.01617 .40958 L
s
.01082 .42135 m
.01452 .42002 L
s
.00916 .43185 m
.01286 .43052 L
s
.00748 .44242 m
.01119 .44109 L
s
.03151 .29078 m
.03519 .28937 L
s
.03303 .28117 m
.03671 .27975 L
s
.03455 .27162 m
.03822 .2702 L
s
.03605 .26213 m
.03972 .2607 L
s
.0041 .46376 m
.00781 .46245 L
s
.00239 .47453 m
.00611 .47323 L
s
.00067 .48538 m
.00439 .48409 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.809 .397 .266 r
.40191 .60465 .40512 .60371 .41 .61095 .40679 .61178 Mtetra
.805 .385 .248 r
.40679 .61178 .41 .61095 .41492 .61792 .41172 .61864 Mtetra
.801 .372 .229 r
.41172 .61864 .41492 .61792 .41988 .62464 .41669 .62524 Mtetra
.796 .358 .208 r
.41669 .62524 .41988 .62464 .42488 .6311 .4217 .63159 Mtetra
.79 .343 .186 r
.4217 .63159 .42488 .6311 .42993 .63731 .42675 .6377 Mtetra
.783 .326 .162 r
.42675 .6377 .42993 .63731 .43502 .64328 .43185 .64355 Mtetra
.775 .308 .136 r
.43185 .64355 .43502 .64328 .44014 .649 .43698 .64917 Mtetra
.766 .289 .107 r
.43698 .64917 .44014 .649 .44531 .65449 .44215 .65456 Mtetra
.755 .267 .076 r
.44215 .65456 .44531 .65449 .45051 .65975 .44736 .65971 Mtetra
.742 .243 .043 r
.44736 .65971 .45051 .65975 .45574 .66478 .4526 .66464 Mtetra
.728 .218 .007 r
.4526 .66464 .45574 .66478 .46101 .66959 .45788 .66935 Mtetra
.712 .189 0 r
.45788 .66935 .46101 .66959 .46632 .67419 .46319 .67385 Mtetra
.692 .159 0 r
.46319 .67385 .46632 .67419 .47165 .67857 .46853 .67813 Mtetra
.67 .125 0 r
.46853 .67813 .47165 .67857 .47702 .68275 .47391 .68221 Mtetra
.645 .088 0 r
.47391 .68221 .47702 .68275 .48242 .68672 .47932 .68609 Mtetra
.616 .049 0 r
.47932 .68609 .48242 .68672 .48785 .69049 .48476 .68977 Mtetra
.583 .007 0 r
.48476 .68977 .48785 .69049 .49331 .69407 .49022 .69326 Mtetra
.545 0 0 r
.49022 .69326 .49331 .69407 .4988 .69746 .49572 .69656 Mtetra
.504 0 0 r
.49572 .69656 .4988 .69746 .50432 .70066 .50124 .69967 Mtetra
.457 0 0 r
.50124 .69967 .50432 .70066 .50986 .70368 .50679 .70261 Mtetra
.407 0 0 r
.50679 .70261 .50986 .70368 .51543 .70653 .51237 .70536 Mtetra
.353 0 0 r
.51237 .70536 .51543 .70653 .52103 .7092 .51797 .70795 Mtetra
.296 0 0 r
.51797 .70795 .52103 .7092 .52665 .7117 .52359 .71037 Mtetra
0 .34 .685 r
.52359 .71037 .52665 .7117 .53229 .71404 .52924 .71263 Mtetra
0 .388 .736 r
.52924 .71263 .53229 .71404 .53796 .71621 .53492 .71473 Mtetra
0 .434 .782 r
.53492 .71473 .53796 .71621 .54365 .71823 .54061 .71667 Mtetra
0 .475 .823 r
.54061 .71667 .54365 .71823 .54936 .72009 .54633 .71846 Mtetra
.001 .514 .858 r
.54633 .71846 .54936 .72009 .55509 .72181 .55207 .7201 Mtetra
.056 .548 .888 r
.55207 .7201 .55509 .72181 .56085 .72338 .55783 .7216 Mtetra
.108 .578 .913 r
.55783 .7216 .56085 .72338 .56662 .7248 .56361 .72295 Mtetra
.157 .604 .933 r
.56361 .72295 .56662 .7248 .57242 .72608 .56942 .72417 Mtetra
.201 .627 .949 r
.56942 .72417 .57242 .72608 .57823 .72723 .57524 .72525 Mtetra
.243 .646 .961 r
.57524 .72525 .57823 .72723 .58406 .72825 .58107 .7262 Mtetra
.281 .663 .97 r
.58107 .7262 .58406 .72825 .58991 .72913 .58693 .72703 Mtetra
.315 .677 .977 r
.58693 .72703 .58991 .72913 .59578 .72989 .59281 .72772 Mtetra
.347 .689 .981 r
.59281 .72772 .59578 .72989 .60167 .73052 .5987 .7283 Mtetra
.375 .7 .984 r
.5987 .7283 .60167 .73052 .60757 .73103 .60461 .72875 Mtetra
.401 .708 .985 r
.60461 .72875 .60757 .73103 .61349 .73142 .61053 .72909 Mtetra
.425 .715 .985 r
.61053 .72909 .61349 .73142 .61942 .7317 .61647 .72931 Mtetra
.447 .722 .984 r
.61647 .72931 .61942 .7317 .62537 .73186 .62243 .72942 Mtetra
.466 .727 .982 r
.62243 .72942 .62537 .73186 .63134 .73191 .6284 .72942 Mtetra
.484 .731 .98 r
.6284 .72942 .63134 .73191 .63732 .73185 .63439 .72932 Mtetra
.501 .735 .978 r
.63439 .72932 .63732 .73185 .64331 .73168 .64039 .72911 Mtetra
.516 .738 .975 r
.64039 .72911 .64331 .73168 .64932 .7314 .6464 .72879 Mtetra
.53 .741 .972 r
.6464 .72879 .64932 .7314 .65534 .73103 .65243 .72837 Mtetra
.543 .744 .969 r
.65243 .72837 .65534 .73103 .66137 .73055 .65847 .72785 Mtetra
.555 .746 .966 r
.65847 .72785 .66137 .73055 .66742 .72997 .66453 .72724 Mtetra
.566 .748 .963 r
.66453 .72724 .66742 .72997 .67348 .72929 .67059 .72653 Mtetra
.576 .75 .96 r
.67059 .72653 .67348 .72929 .67955 .72851 .67667 .72572 Mtetra
.585 .751 .957 r
.67667 .72572 .67955 .72851 .68563 .72764 .68276 .72482 Mtetra
.594 .753 .954 r
.68276 .72482 .68563 .72764 .69172 .72668 .68886 .72382 Mtetra
.603 .754 .951 r
.68886 .72382 .69172 .72668 .69783 .72561 .69497 .72274 Mtetra
.611 .756 .948 r
.69497 .72274 .69783 .72561 .70394 .72446 .7011 .72156 Mtetra
.618 .757 .945 r
.7011 .72156 .70394 .72446 .71007 .72321 .70723 .72029 Mtetra
.626 .759 .942 r
.70723 .72029 .71007 .72321 .7162 .72188 .71337 .71893 Mtetra
.633 .76 .94 r
.71337 .71893 .7162 .72188 .72234 .72045 .71952 .71749 Mtetra
.639 .762 .937 r
.71952 .71749 .72234 .72045 .7285 .71893 .72568 .71595 Mtetra
.646 .763 .935 r
.72568 .71595 .7285 .71893 .73466 .71731 .73185 .71433 Mtetra
.652 .765 .932 r
.73185 .71433 .73466 .71731 .74083 .71561 .73803 .71261 Mtetra
.658 .767 .93 r
.73803 .71261 .74083 .71561 .747 .71382 .74422 .71081 Mtetra
.663 .769 .928 r
.74422 .71081 .747 .71382 .75319 .71193 .75041 .70892 Mtetra
.669 .771 .926 r
.75041 .70892 .75319 .71193 .75938 .70996 .75661 .70694 Mtetra
.675 .773 .924 r
.75661 .70694 .75938 .70996 .76557 .70789 .76282 .70487 Mtetra
.68 .775 .922 r
.76282 .70487 .76557 .70789 .77177 .70573 .76903 .70271 Mtetra
.686 .777 .92 r
.76903 .70271 .77177 .70573 .77798 .70347 .77525 .70046 Mtetra
.691 .779 .919 r
.77525 .70046 .77798 .70347 .78419 .70112 .78147 .69811 Mtetra
.696 .782 .917 r
.78147 .69811 .78419 .70112 .79041 .69867 .7877 .69568 Mtetra
.702 .785 .916 r
.7877 .69568 .79041 .69867 .79663 .69613 .79393 .69314 Mtetra
.707 .787 .914 r
.79393 .69314 .79663 .69613 .80285 .69349 .80016 .69051 Mtetra
.712 .79 .913 r
.80016 .69051 .80285 .69349 .80908 .69074 .8064 .68778 Mtetra
.718 .793 .911 r
.8064 .68778 .80908 .69074 .8153 .6879 .81264 .68496 Mtetra
.723 .797 .91 r
.81264 .68496 .8153 .6879 .82153 .68495 .81888 .68203 Mtetra
.728 .8 .908 r
.81888 .68203 .82153 .68495 .82776 .68189 .82512 .67899 Mtetra
.734 .804 .907 r
.82512 .67899 .82776 .68189 .83399 .67872 .83137 .67585 Mtetra
.74 .807 .906 r
.83137 .67585 .83399 .67872 .84021 .67544 .83761 .6726 Mtetra
.745 .811 .904 r
.83761 .6726 .84021 .67544 .84644 .67205 .84384 .66924 Mtetra
.751 .815 .903 r
.84384 .66924 .84644 .67205 .85266 .66854 .85008 .66576 Mtetra
.757 .82 .902 r
.85008 .66576 .85266 .66854 .85887 .66491 .85631 .66217 Mtetra
.763 .824 .9 r
.85631 .66217 .85887 .66491 .86509 .66115 .86254 .65845 Mtetra
.769 .829 .898 r
.86254 .65845 .86509 .66115 .87129 .65727 .86877 .65461 Mtetra
.776 .834 .897 r
.86877 .65461 .87129 .65727 .87749 .65325 .87498 .65064 Mtetra
.782 .839 .895 r
.87498 .65064 .87749 .65325 .88368 .6491 .88119 .64653 Mtetra
.789 .844 .893 r
.88119 .64653 .88368 .6491 .88986 .64481 .88739 .64229 Mtetra
.795 .849 .891 r
.88739 .64229 .88986 .64481 .89603 .64037 .89358 .63791 Mtetra
.802 .855 .889 r
.89358 .63791 .89603 .64037 .90219 .63579 .89976 .63338 Mtetra
.809 .86 .887 r
.89976 .63338 .90219 .63579 .90834 .63105 .90593 .62871 Mtetra
.817 .866 .884 r
.90593 .62871 .90834 .63105 .91447 .62615 .91208 .62387 Mtetra
.824 .872 .881 r
.91208 .62387 .91447 .62615 .92058 .62109 .91822 .61888 Mtetra
.831 .878 .878 r
.91822 .61888 .92058 .62109 .92668 .61586 .92434 .61371 Mtetra
.839 .885 .874 r
.92434 .61371 .92668 .61586 .93275 .61046 .93044 .60838 Mtetra
.846 .891 .87 r
.93044 .60838 .93275 .61046 .93881 .60487 .93652 .60287 Mtetra
.854 .897 .866 r
.93652 .60287 .93881 .60487 .94484 .59909 .94257 .59717 Mtetra
.862 .904 .861 r
.94257 .59717 .94484 .59909 .95085 .59312 .94861 .59128 Mtetra
.87 .91 .856 r
.94861 .59128 .95085 .59312 .95683 .58695 .95462 .58519 Mtetra
.877 .916 .85 r
.95462 .58519 .95683 .58695 .96278 .58057 .96059 .5789 Mtetra
.885 .922 .843 r
.96059 .5789 .96278 .58057 .96869 .57397 .96654 .5724 Mtetra
.892 .928 .836 r
.96654 .5724 .96869 .57397 .97458 .56715 .97246 .56568 Mtetra
.9 .934 .827 r
.97246 .56568 .97458 .56715 .98043 .5601 .97834 .55873 Mtetra
.907 .939 .818 r
.97834 .55873 .98043 .5601 .98624 .55282 .98418 .55154 Mtetra
.81 .391 .251 r
.39868 .60542 .40191 .60465 .40679 .61178 .40357 .61243 Mtetra
.805 .378 .232 r
.40357 .61243 .40679 .61178 .41172 .61864 .40851 .61918 Mtetra
.8 .365 .212 r
.40851 .61918 .41172 .61864 .41669 .62524 .41348 .62567 Mtetra
.795 .35 .189 r
.41348 .62567 .41669 .62524 .4217 .63159 .4185 .63192 Mtetra
.788 .333 .165 r
.4185 .63192 .4217 .63159 .42675 .6377 .42357 .63791 Mtetra
.78 .316 .14 r
.42357 .63791 .42675 .6377 .43185 .64355 .42867 .64366 Mtetra
.771 .296 .111 r
.42867 .64366 .43185 .64355 .43698 .64917 .43381 .64918 Mtetra
.761 .275 .081 r
.43381 .64918 .43698 .64917 .44215 .65456 .43898 .65446 Mtetra
.749 .252 .048 r
.43898 .65446 .44215 .65456 .44736 .65971 .4442 .65951 Mtetra
.735 .226 .012 r
.4442 .65951 .44736 .65971 .4526 .66464 .44945 .66434 Mtetra
.718 .198 0 r
.44945 .66434 .4526 .66464 .45788 .66935 .45473 .66896 Mtetra
.7 .168 0 r
.45473 .66896 .45788 .66935 .46319 .67385 .46005 .67335 Mtetra
.678 .135 0 r
.46005 .67335 .46319 .67385 .46853 .67813 .4654 .67754 Mtetra
.653 .099 0 r
.4654 .67754 .46853 .67813 .47391 .68221 .47078 .68153 Mtetra
.624 .059 0 r
.47078 .68153 .47391 .68221 .47932 .68609 .4762 .68531 Mtetra
.591 .017 0 r
.4762 .68531 .47932 .68609 .48476 .68977 .48164 .6889 Mtetra
.554 0 0 r
.48164 .6889 .48476 .68977 .49022 .69326 .48712 .6923 Mtetra
.513 0 0 r
.48712 .6923 .49022 .69326 .49572 .69656 .49262 .69551 Mtetra
.467 0 0 r
.49262 .69551 .49572 .69656 .50124 .69967 .49815 .69854 Mtetra
.417 0 0 r
.49815 .69854 .50124 .69967 .50679 .70261 .5037 .70139 Mtetra
.362 0 0 r
.5037 .70139 .50679 .70261 .51237 .70536 .50929 .70406 Mtetra
.305 0 0 r
.50929 .70406 .51237 .70536 .51797 .70795 .5149 .70657 Mtetra
0 .33 .681 r
.5149 .70657 .51797 .70795 .52359 .71037 .52053 .70891 Mtetra
0 .378 .733 r
.52053 .70891 .52359 .71037 .52924 .71263 .52619 .71109 Mtetra
0 .424 .779 r
.52619 .71109 .52924 .71263 .53492 .71473 .53187 .71311 Mtetra
0 .466 .82 r
.53187 .71311 .53492 .71473 .54061 .71667 .53757 .71498 Mtetra
0 .505 .856 r
.53757 .71498 .54061 .71667 .54633 .71846 .54329 .71669 Mtetra
.049 .539 .886 r
.54329 .71669 .54633 .71846 .55207 .7201 .54904 .71826 Mtetra
.102 .569 .911 r
.54904 .71826 .55207 .7201 .55783 .7216 .55481 .71969 Mtetra
.151 .596 .931 r
.55481 .71969 .55783 .7216 .56361 .72295 .56059 .72098 Mtetra
.196 .619 .947 r
.56059 .72098 .56361 .72295 .56942 .72417 .5664 .72213 Mtetra
.238 .639 .959 r
.5664 .72213 .56942 .72417 .57524 .72525 .57223 .72315 Mtetra
.276 .656 .969 r
.57223 .72315 .57524 .72525 .58107 .7262 .57807 .72404 Mtetra
.311 .67 .975 r
.57807 .72404 .58107 .7262 .58693 .72703 .58394 .7248 Mtetra
.343 .682 .979 r
.58394 .7248 .58693 .72703 .59281 .72772 .58982 .72544 Mtetra
.371 .693 .982 r
.58982 .72544 .59281 .72772 .5987 .7283 .59572 .72595 Mtetra
.398 .701 .983 r
.59572 .72595 .5987 .7283 .60461 .72875 .60163 .72635 Mtetra
.421 .709 .983 r
.60163 .72635 .60461 .72875 .61053 .72909 .60756 .72664 Mtetra
.443 .715 .982 r
.60756 .72664 .61053 .72909 .61647 .72931 .61351 .72681 Mtetra
.463 .72 .98 r
.61351 .72681 .61647 .72931 .62243 .72942 .61947 .72687 Mtetra
.481 .725 .978 r
.61947 .72687 .62243 .72942 .6284 .72942 .62545 .72682 Mtetra
.497 .728 .975 r
.62545 .72682 .6284 .72942 .63439 .72932 .63144 .72667 Mtetra
.513 .732 .973 r
.63144 .72667 .63439 .72932 .64039 .72911 .63745 .72642 Mtetra
.526 .734 .97 r
.63745 .72642 .64039 .72911 .6464 .72879 .64347 .72606 Mtetra
.539 .737 .967 r
.64347 .72606 .6464 .72879 .65243 .72837 .64951 .7256 Mtetra
.551 .739 .963 r
.64951 .7256 .65243 .72837 .65847 .72785 .65556 .72505 Mtetra
.562 .741 .96 r
.65556 .72505 .65847 .72785 .66453 .72724 .66162 .7244 Mtetra
.572 .743 .957 r
.66162 .7244 .66453 .72724 .67059 .72653 .66769 .72365 Mtetra
.582 .744 .954 r
.66769 .72365 .67059 .72653 .67667 .72572 .67378 .72281 Mtetra
.591 .746 .951 r
.67378 .72281 .67667 .72572 .68276 .72482 .67987 .72188 Mtetra
.599 .747 .948 r
.67987 .72188 .68276 .72482 .68886 .72382 .68598 .72086 Mtetra
.607 .749 .945 r
.68598 .72086 .68886 .72382 .69497 .72274 .6921 .71975 Mtetra
.615 .75 .942 r
.6921 .71975 .69497 .72274 .7011 .72156 .69823 .71854 Mtetra
.622 .751 .939 r
.69823 .71854 .7011 .72156 .70723 .72029 .70437 .71726 Mtetra
.628 .753 .937 r
.70437 .71726 .70723 .72029 .71337 .71893 .71052 .71588 Mtetra
.635 .754 .934 r
.71052 .71588 .71337 .71893 .71952 .71749 .71668 .71441 Mtetra
.641 .756 .932 r
.71668 .71441 .71952 .71749 .72568 .71595 .72285 .71286 Mtetra
.647 .757 .929 r
.72285 .71286 .72568 .71595 .73185 .71433 .72903 .71123 Mtetra
.653 .759 .927 r
.72903 .71123 .73185 .71433 .73803 .71261 .73522 .7095 Mtetra
.659 .76 .925 r
.73522 .7095 .73803 .71261 .74422 .71081 .74141 .70769 Mtetra
.664 .762 .923 r
.74141 .70769 .74422 .71081 .75041 .70892 .74762 .7058 Mtetra
.669 .764 .921 r
.74762 .7058 .75041 .70892 .75661 .70694 .75383 .70381 Mtetra
.675 .766 .919 r
.75383 .70381 .75661 .70694 .76282 .70487 .76004 .70174 Mtetra
.68 .768 .917 r
.76004 .70174 .76282 .70487 .76903 .70271 .76627 .69958 Mtetra
.685 .77 .916 r
.76627 .69958 .76903 .70271 .77525 .70046 .77249 .69733 Mtetra
.69 .772 .914 r
.77249 .69733 .77525 .70046 .78147 .69811 .77873 .69499 Mtetra
.695 .775 .913 r
.77873 .69499 .78147 .69811 .7877 .69568 .78497 .69256 Mtetra
.7 .777 .911 r
.78497 .69256 .7877 .69568 .79393 .69314 .79121 .69004 Mtetra
.705 .78 .91 r
.79121 .69004 .79393 .69314 .80016 .69051 .79746 .68742 Mtetra
.71 .783 .908 r
.79746 .68742 .80016 .69051 .8064 .68778 .80371 .6847 Mtetra
.716 .786 .907 r
.80371 .6847 .8064 .68778 .81264 .68496 .80996 .68189 Mtetra
.721 .789 .906 r
.80996 .68189 .81264 .68496 .81888 .68203 .81621 .67898 Mtetra
.726 .792 .904 r
.81621 .67898 .81888 .68203 .82512 .67899 .82247 .67597 Mtetra
.731 .796 .903 r
.82247 .67597 .82512 .67899 .83137 .67585 .82872 .67285 Mtetra
.737 .799 .902 r
.82872 .67285 .83137 .67585 .83761 .6726 .83498 .66963 Mtetra
.742 .803 .901 r
.83498 .66963 .83761 .6726 .84384 .66924 .84123 .6663 Mtetra
.748 .807 .899 r
.84123 .6663 .84384 .66924 .85008 .66576 .84748 .66285 Mtetra
.754 .811 .898 r
.84748 .66285 .85008 .66576 .85631 .66217 .85373 .65929 Mtetra
.76 .815 .897 r
.85373 .65929 .85631 .66217 .86254 .65845 .85998 .65561 Mtetra
.766 .82 .895 r
.85998 .65561 .86254 .65845 .86877 .65461 .86622 .65181 Mtetra
.772 .825 .894 r
.86622 .65181 .86877 .65461 .87498 .65064 .87245 .64788 Mtetra
.778 .829 .892 r
.87245 .64788 .87498 .65064 .88119 .64653 .87868 .64383 Mtetra
.784 .834 .89 r
.87868 .64383 .88119 .64653 .88739 .64229 .8849 .63964 Mtetra
.791 .84 .889 r
.8849 .63964 .88739 .64229 .89358 .63791 .89111 .63531 Mtetra
.798 .845 .887 r
.89111 .63531 .89358 .63791 .89976 .63338 .89731 .63083 Mtetra
.805 .851 .884 r
.89731 .63083 .89976 .63338 .90593 .62871 .90349 .62621 Mtetra
.812 .856 .882 r
.90349 .62621 .90593 .62871 .91208 .62387 .90967 .62144 Mtetra
.819 .862 .879 r
.90967 .62144 .91208 .62387 .91822 .61888 .91583 .61651 Mtetra
.826 .868 .877 r
.91583 .61651 .91822 .61888 .92434 .61371 .92197 .61141 Mtetra
.834 .874 .873 r
.92197 .61141 .92434 .61371 .93044 .60838 .92809 .60615 Mtetra
.841 .88 .87 r
.92809 .60615 .93044 .60838 .93652 .60287 .9342 .60071 Mtetra
.849 .887 .866 r
.9342 .60071 .93652 .60287 .94257 .59717 .94028 .59509 Mtetra
.857 .893 .862 r
.94028 .59509 .94257 .59717 .94861 .59128 .94634 .58928 Mtetra
.864 .899 .857 r
.94634 .58928 .94861 .59128 .95462 .58519 .95237 .58327 Mtetra
.872 .906 .851 r
.95237 .58327 .95462 .58519 .96059 .5789 .95838 .57707 Mtetra
.88 .912 .845 r
.95838 .57707 .96059 .5789 .96654 .5724 .96436 .57066 Mtetra
.888 .918 .839 r
.96436 .57066 .96654 .5724 .97246 .56568 .97031 .56403 Mtetra
.895 .924 .831 r
.97031 .56403 .97246 .56568 .97834 .55873 .97622 .55717 Mtetra
.903 .93 .823 r
.97622 .55717 .97834 .55873 .98418 .55154 .98209 .55009 Mtetra
.81 .385 .236 r
.39545 .606 .39868 .60542 .40357 .61243 .40034 .61291 Mtetra
.805 .371 .215 r
.40034 .61291 .40357 .61243 .40851 .61918 .40528 .61955 Mtetra
.799 .357 .194 r
.40528 .61955 .40851 .61918 .41348 .62567 .41027 .62594 Mtetra
.793 .341 .17 r
.41027 .62594 .41348 .62567 .4185 .63192 .4153 .63207 Mtetra
.786 .323 .144 r
.4153 .63207 .4185 .63192 .42357 .63791 .42036 .63796 Mtetra
.777 .304 .116 r
.42036 .63796 .42357 .63791 .42867 .64366 .42547 .64361 Mtetra
.767 .283 .086 r
.42547 .64361 .42867 .64366 .43381 .64918 .43062 .64902 Mtetra
.755 .261 .053 r
.43062 .64902 .43381 .64918 .43898 .65446 .4358 .6542 Mtetra
.741 .235 .017 r
.4358 .6542 .43898 .65446 .4442 .65951 .44102 .65916 Mtetra
.726 .208 0 r
.44102 .65916 .4442 .65951 .44945 .66434 .44628 .66389 Mtetra
.707 .178 0 r
.44628 .66389 .44945 .66434 .45473 .66896 .45157 .66841 Mtetra
.686 .145 0 r
.45157 .66841 .45473 .66896 .46005 .67335 .4569 .67271 Mtetra
.661 .109 0 r
.4569 .67271 .46005 .67335 .4654 .67754 .46226 .6768 Mtetra
.633 .071 0 r
.46226 .6768 .4654 .67754 .47078 .68153 .46765 .68069 Mtetra
.601 .029 0 r
.46765 .68069 .47078 .68153 .4762 .68531 .47307 .68439 Mtetra
.564 0 0 r
.47307 .68439 .4762 .68531 .48164 .6889 .47852 .68789 Mtetra
.523 0 0 r
.47852 .68789 .48164 .6889 .48712 .6923 .484 .6912 Mtetra
.477 0 0 r
.484 .6912 .48712 .6923 .49262 .69551 .48951 .69432 Mtetra
.427 0 0 r
.48951 .69432 .49262 .69551 .49815 .69854 .49504 .69726 Mtetra
.373 0 0 r
.49504 .69726 .49815 .69854 .5037 .70139 .50061 .70003 Mtetra
.316 0 0 r
.50061 .70003 .5037 .70139 .50929 .70406 .5062 .70262 Mtetra
0 .318 .676 r
.5062 .70262 .50929 .70406 .5149 .70657 .51181 .70505 Mtetra
0 .367 .727 r
.51181 .70505 .5149 .70657 .52053 .70891 .51745 .70731 Mtetra
0 .413 .774 r
.51745 .70731 .52053 .70891 .52619 .71109 .52311 .70941 Mtetra
0 .456 .816 r
.52311 .70941 .52619 .71109 .53187 .71311 .5288 .71136 Mtetra
0 .495 .852 r
.5288 .71136 .53187 .71311 .53757 .71498 .53451 .71315 Mtetra
.041 .529 .883 r
.53451 .71315 .53757 .71498 .54329 .71669 .54024 .7148 Mtetra
.094 .56 .908 r
.54024 .7148 .54329 .71669 .54904 .71826 .54599 .7163 Mtetra
.143 .588 .929 r
.54599 .7163 .54904 .71826 .55481 .71969 .55177 .71766 Mtetra
.189 .611 .945 r
.55177 .71766 .55481 .71969 .56059 .72098 .55756 .71888 Mtetra
.231 .631 .957 r
.55756 .71888 .56059 .72098 .5664 .72213 .56337 .71997 Mtetra
.27 .648 .966 r
.56337 .71997 .5664 .72213 .57223 .72315 .56921 .72092 Mtetra
.305 .663 .973 r
.56921 .72092 .57223 .72315 .57807 .72404 .57506 .72175 Mtetra
.337 .675 .977 r
.57506 .72175 .57807 .72404 .58394 .7248 .58093 .72245 Mtetra
.367 .686 .98 r
.58093 .72245 .58394 .7248 .58982 .72544 .58681 .72303 Mtetra
.393 .695 .981 r
.58681 .72303 .58982 .72544 .59572 .72595 .59272 .72349 Mtetra
.417 .702 .981 r
.59272 .72349 .59572 .72595 .60163 .72635 .59864 .72384 Mtetra
.439 .708 .98 r
.59864 .72384 .60163 .72635 .60756 .72664 .60458 .72407 Mtetra
.459 .714 .978 r
.60458 .72407 .60756 .72664 .61351 .72681 .61053 .72419 Mtetra
.477 .718 .976 r
.61053 .72419 .61351 .72681 .61947 .72687 .6165 .7242 Mtetra
.494 .722 .973 r
.6165 .7242 .61947 .72687 .62545 .72682 .62249 .72411 Mtetra
.509 .725 .97 r
.62249 .72411 .62545 .72682 .63144 .72667 .62849 .72391 Mtetra
.523 .728 .967 r
.62849 .72391 .63144 .72667 .63745 .72642 .6345 .72362 Mtetra
.536 .731 .964 r
.6345 .72362 .63745 .72642 .64347 .72606 .64053 .72322 Mtetra
.548 .733 .961 r
.64053 .72322 .64347 .72606 .64951 .7256 .64657 .72272 Mtetra
.559 .735 .958 r
.64657 .72272 .64951 .7256 .65556 .72505 .65263 .72213 Mtetra
.569 .736 .955 r
.65263 .72213 .65556 .72505 .66162 .7244 .65869 .72144 Mtetra
.578 .738 .951 r
.65869 .72144 .66162 .7244 .66769 .72365 .66477 .72066 Mtetra
.587 .739 .948 r
.66477 .72066 .66769 .72365 .67378 .72281 .67087 .71979 Mtetra
.596 .741 .945 r
.67087 .71979 .67378 .72281 .67987 .72188 .67697 .71883 Mtetra
.603 .742 .942 r
.67697 .71883 .67987 .72188 .68598 .72086 .68309 .71778 Mtetra
.611 .743 .939 r
.68309 .71778 .68598 .72086 .6921 .71975 .68921 .71665 Mtetra
.618 .745 .937 r
.68921 .71665 .6921 .71975 .69823 .71854 .69535 .71542 Mtetra
.624 .746 .934 r
.69535 .71542 .69823 .71854 .70437 .71726 .7015 .71411 Mtetra
.631 .747 .931 r
.7015 .71411 .70437 .71726 .71052 .71588 .70766 .71272 Mtetra
.637 .748 .929 r
.70766 .71272 .71052 .71588 .71668 .71441 .71383 .71123 Mtetra
.643 .75 .927 r
.71383 .71123 .71668 .71441 .72285 .71286 .72001 .70967 Mtetra
.648 .751 .924 r
.72001 .70967 .72285 .71286 .72903 .71123 .72619 .70802 Mtetra
.654 .753 .922 r
.72619 .70802 .72903 .71123 .73522 .7095 .73239 .70628 Mtetra
.659 .754 .92 r
.73239 .70628 .73522 .7095 .74141 .70769 .73859 .70446 Mtetra
.665 .756 .918 r
.73859 .70446 .74141 .70769 .74762 .7058 .74481 .70256 Mtetra
.67 .758 .916 r
.74481 .70256 .74762 .7058 .75383 .70381 .75102 .70057 Mtetra
.675 .76 .915 r
.75102 .70057 .75383 .70381 .76004 .70174 .75725 .6985 Mtetra
.68 .761 .913 r
.75725 .6985 .76004 .70174 .76627 .69958 .76348 .69634 Mtetra
.684 .764 .911 r
.76348 .69634 .76627 .69958 .77249 .69733 .76972 .69409 Mtetra
.689 .766 .91 r
.76972 .69409 .77249 .69733 .77873 .69499 .77597 .69176 Mtetra
.694 .768 .908 r
.77597 .69176 .77873 .69499 .78497 .69256 .78222 .68933 Mtetra
.699 .77 .907 r
.78222 .68933 .78497 .69256 .79121 .69004 .78847 .68682 Mtetra
.704 .773 .906 r
.78847 .68682 .79121 .69004 .79746 .68742 .79473 .68421 Mtetra
.709 .776 .904 r
.79473 .68421 .79746 .68742 .80371 .6847 .80099 .68151 Mtetra
.714 .779 .903 r
.80099 .68151 .80371 .6847 .80996 .68189 .80726 .67872 Mtetra
.719 .782 .902 r
.80726 .67872 .80996 .68189 .81621 .67898 .81352 .67582 Mtetra
.724 .785 .901 r
.81352 .67582 .81621 .67898 .82247 .67597 .81979 .67283 Mtetra
.729 .788 .899 r
.81979 .67283 .82247 .67597 .82872 .67285 .82606 .66974 Mtetra
.734 .792 .898 r
.82606 .66974 .82872 .67285 .83498 .66963 .83233 .66654 Mtetra
.74 .795 .897 r
.83233 .66654 .83498 .66963 .84123 .6663 .8386 .66324 Mtetra
.745 .799 .896 r
.8386 .66324 .84123 .6663 .84748 .66285 .84486 .65982 Mtetra
.751 .803 .895 r
.84486 .65982 .84748 .66285 .85373 .65929 .85113 .6563 Mtetra
.756 .807 .893 r
.85113 .6563 .85373 .65929 .85998 .65561 .85739 .65265 Mtetra
.762 .812 .892 r
.85739 .65265 .85998 .65561 .86622 .65181 .86365 .64889 Mtetra
.768 .816 .891 r
.86365 .64889 .86622 .65181 .87245 .64788 .8699 .64501 Mtetra
.774 .821 .889 r
.8699 .64501 .87245 .64788 .87868 .64383 .87614 .64099 Mtetra
.78 .826 .888 r
.87614 .64099 .87868 .64383 .8849 .63964 .88238 .63685 Mtetra
.787 .831 .886 r
.88238 .63685 .8849 .63964 .89111 .63531 .88861 .63257 Mtetra
.793 .836 .884 r
.88861 .63257 .89111 .63531 .89731 .63083 .89483 .62815 Mtetra
.8 .841 .882 r
.89483 .62815 .89731 .63083 .90349 .62621 .90103 .62358 Mtetra
.807 .847 .88 r
.90103 .62358 .90349 .62621 .90967 .62144 .90723 .61887 Mtetra
.814 .853 .878 r
.90723 .61887 .90967 .62144 .91583 .61651 .91341 .614 Mtetra
.821 .859 .875 r
.91341 .614 .91583 .61651 .92197 .61141 .91957 .60897 Mtetra
.828 .865 .872 r
.91957 .60897 .92197 .61141 .92809 .60615 .92572 .60377 Mtetra
.836 .871 .869 r
.92572 .60377 .92809 .60615 .9342 .60071 .93185 .5984 Mtetra
.844 .877 .866 r
.93185 .5984 .9342 .60071 .94028 .59509 .93796 .59286 Mtetra
.851 .883 .862 r
.93796 .59286 .94028 .59509 .94634 .58928 .94404 .58712 Mtetra
.859 .889 .857 r
.94404 .58712 .94634 .58928 .95237 .58327 .95011 .5812 Mtetra
.867 .896 .852 r
.95011 .5812 .95237 .58327 .95838 .57707 .95614 .57508 Mtetra
.875 .902 .847 r
.95614 .57508 .95838 .57707 .96436 .57066 .96215 .56875 Mtetra
.882 .908 .841 r
.96215 .56875 .96436 .57066 .97031 .56403 .96812 .56221 Mtetra
.89 .914 .834 r
.96812 .56221 .97031 .56403 .97622 .55717 .97406 .55545 Mtetra
.898 .92 .827 r
.97406 .55545 .97622 .55717 .98209 .55009 .97997 .54846 Mtetra
.81 .378 .22 r
.3922 .60642 .39545 .606 .40034 .61291 .3971 .61322 Mtetra
.804 .364 .198 r
.3971 .61322 .40034 .61291 .40528 .61955 .40205 .61975 Mtetra
.798 .348 .175 r
.40205 .61975 .40528 .61955 .41027 .62594 .40704 .62604 Mtetra
.791 .331 .149 r
.40704 .62604 .41027 .62594 .4153 .63207 .41208 .63207 Mtetra
.783 .312 .122 r
.41208 .63207 .4153 .63207 .42036 .63796 .41715 .63785 Mtetra
.773 .292 .092 r
.41715 .63785 .42036 .63796 .42547 .64361 .42227 .6434 Mtetra
.761 .27 .059 r
.42227 .6434 .42547 .64361 .43062 .64902 .42742 .64871 Mtetra
.748 .245 .024 r
.42742 .64871 .43062 .64902 .4358 .6542 .43261 .6538 Mtetra
.733 .218 0 r
.43261 .6538 .4358 .6542 .44102 .65916 .43784 .65865 Mtetra
.715 .189 0 r
.43784 .65865 .44102 .65916 .44628 .66389 .4431 .66329 Mtetra
.694 .156 0 r
.4431 .66329 .44628 .66389 .45157 .66841 .4484 .66771 Mtetra
.67 .121 0 r
.4484 .66771 .45157 .66841 .4569 .67271 .45373 .67192 Mtetra
.643 .083 0 r
.45373 .67192 .4569 .67271 .46226 .6768 .4591 .67592 Mtetra
.611 .042 0 r
.4591 .67592 .46226 .6768 .46765 .68069 .46449 .67972 Mtetra
.575 0 0 r
.46449 .67972 .46765 .68069 .47307 .68439 .46992 .68332 Mtetra
.534 0 0 r
.46992 .68332 .47307 .68439 .47852 .68789 .47538 .68674 Mtetra
.489 0 0 r
.47538 .68674 .47852 .68789 .484 .6912 .48087 .68996 Mtetra
.44 0 0 r
.48087 .68996 .484 .6912 .48951 .69432 .48638 .693 Mtetra
.386 0 0 r
.48638 .693 .48951 .69432 .49504 .69726 .49192 .69586 Mtetra
.329 0 0 r
.49192 .69586 .49504 .69726 .50061 .70003 .49749 .69854 Mtetra
0 .304 .668 r
.49749 .69854 .50061 .70003 .5062 .70262 .50309 .70106 Mtetra
0 .354 .72 r
.50309 .70106 .5062 .70262 .51181 .70505 .50871 .7034 Mtetra
0 .4 .768 r
.50871 .7034 .51181 .70505 .51745 .70731 .51436 .70559 Mtetra
0 .444 .81 r
.51436 .70559 .51745 .70731 .52311 .70941 .52003 .70762 Mtetra
0 .483 .847 r
.52003 .70762 .52311 .70941 .5288 .71136 .52572 .70949 Mtetra
.03 .519 .879 r
.52572 .70949 .5288 .71136 .53451 .71315 .53143 .71121 Mtetra
.084 .551 .904 r
.53143 .71121 .53451 .71315 .54024 .7148 .53717 .71278 Mtetra
.134 .578 .925 r
.53717 .71278 .54024 .7148 .54599 .7163 .54293 .71422 Mtetra
.181 .602 .942 r
.54293 .71422 .54599 .7163 .55177 .71766 .54871 .71551 Mtetra
.224 .623 .955 r
.54871 .71551 .55177 .71766 .55756 .71888 .55451 .71666 Mtetra
.263 .641 .964 r
.55451 .71666 .55756 .71888 .56337 .71997 .56033 .71769 Mtetra
.299 .656 .971 r
.56033 .71769 .56337 .71997 .56921 .72092 .56617 .71858 Mtetra
.331 .668 .975 r
.56617 .71858 .56921 .72092 .57506 .72175 .57203 .71935 Mtetra
.361 .679 .978 r
.57203 .71935 .57506 .72175 .58093 .72245 .5779 .71999 Mtetra
.388 .688 .979 r
.5779 .71999 .58093 .72245 .58681 .72303 .5838 .72052 Mtetra
.412 .696 .979 r
.5838 .72052 .58681 .72303 .59272 .72349 .58971 .72092 Mtetra
.434 .702 .978 r
.58971 .72092 .59272 .72349 .59864 .72384 .59564 .72121 Mtetra
.454 .708 .976 r
.59564 .72121 .59864 .72384 .60458 .72407 .60158 .7214 Mtetra
.473 .712 .974 r
.60158 .7214 .60458 .72407 .61053 .72419 .60754 .72147 Mtetra
.489 .716 .971 r
.60754 .72147 .61053 .72419 .6165 .7242 .61352 .72143 Mtetra
.505 .719 .969 r
.61352 .72143 .6165 .7242 .62249 .72411 .61951 .72129 Mtetra
.519 .722 .966 r
.61951 .72129 .62249 .72411 .62849 .72391 .62551 .72105 Mtetra
.532 .725 .962 r
.62551 .72105 .62849 .72391 .6345 .72362 .63153 .72071 Mtetra
.544 .727 .959 r
.63153 .72071 .6345 .72362 .64053 .72322 .63757 .72027 Mtetra
.555 .729 .956 r
.63757 .72027 .64053 .72322 .64657 .72272 .64362 .71974 Mtetra
.565 .731 .953 r
.64362 .71974 .64657 .72272 .65263 .72213 .64968 .71911 Mtetra
.575 .732 .949 r
.64968 .71911 .65263 .72213 .65869 .72144 .65575 .71839 Mtetra
.583 .734 .946 r
.65575 .71839 .65869 .72144 .66477 .72066 .66184 .71758 Mtetra
.592 .735 .943 r
.66184 .71758 .66477 .72066 .67087 .71979 .66794 .71668 Mtetra
.6 .736 .94 r
.66794 .71668 .67087 .71979 .67697 .71883 .67405 .71569 Mtetra
.607 .737 .937 r
.67405 .71569 .67697 .71883 .68309 .71778 .68018 .71461 Mtetra
.614 .738 .934 r
.68018 .71461 .68309 .71778 .68921 .71665 .68631 .71345 Mtetra
.621 .74 .932 r
.68631 .71345 .68921 .71665 .69535 .71542 .69246 .7122 Mtetra
.627 .741 .929 r
.69246 .7122 .69535 .71542 .7015 .71411 .69861 .71087 Mtetra
.633 .742 .927 r
.69861 .71087 .7015 .71411 .70766 .71272 .70478 .70945 Mtetra
.639 .743 .924 r
.70478 .70945 .70766 .71272 .71383 .71123 .71096 .70795 Mtetra
.644 .745 .922 r
.71096 .70795 .71383 .71123 .72001 .70967 .71714 .70637 Mtetra
.65 .746 .92 r
.71714 .70637 .72001 .70967 .72619 .70802 .72334 .70471 Mtetra
.655 .747 .918 r
.72334 .70471 .72619 .70802 .73239 .70628 .72954 .70296 Mtetra
.66 .749 .916 r
.72954 .70296 .73239 .70628 .73859 .70446 .73576 .70114 Mtetra
.665 .75 .914 r
.73576 .70114 .73859 .70446 .74481 .70256 .74198 .69923 Mtetra
.67 .752 .912 r
.74198 .69923 .74481 .70256 .75102 .70057 .74821 .69723 Mtetra
.674 .754 .911 r
.74821 .69723 .75102 .70057 .75725 .6985 .75444 .69515 Mtetra
.679 .756 .909 r
.75444 .69515 .75725 .6985 .76348 .69634 .76069 .69299 Mtetra
.684 .758 .907 r
.76069 .69299 .76348 .69634 .76972 .69409 .76693 .69075 Mtetra
.689 .76 .906 r
.76693 .69075 .76972 .69409 .77597 .69176 .77319 .68842 Mtetra
.693 .762 .905 r
.77319 .68842 .77597 .69176 .78222 .68933 .77945 .686 Mtetra
.698 .764 .903 r
.77945 .686 .78222 .68933 .78847 .68682 .78572 .68349 Mtetra
.703 .767 .902 r
.78572 .68349 .78847 .68682 .79473 .68421 .79199 .6809 Mtetra
.707 .769 .901 r
.79199 .6809 .79473 .68421 .80099 .68151 .79826 .67821 Mtetra
.712 .772 .899 r
.79826 .67821 .80099 .68151 .80726 .67872 .80454 .67543 Mtetra
.717 .775 .898 r
.80454 .67543 .80726 .67872 .81352 .67582 .81081 .67255 Mtetra
.722 .778 .897 r
.81081 .67255 .81352 .67582 .81979 .67283 .8171 .66958 Mtetra
.727 .781 .896 r
.8171 .66958 .81979 .67283 .82606 .66974 .82338 .66651 Mtetra
.732 .785 .895 r
.82338 .66651 .82606 .66974 .83233 .66654 .82966 .66334 Mtetra
.737 .788 .894 r
.82966 .66334 .83233 .66654 .8386 .66324 .83594 .66006 Mtetra
.742 .792 .893 r
.83594 .66006 .8386 .66324 .84486 .65982 .84222 .65668 Mtetra
.747 .796 .892 r
.84222 .65668 .84486 .65982 .85113 .6563 .8485 .65318 Mtetra
.753 .8 .89 r
.8485 .65318 .85113 .6563 .85739 .65265 .85478 .64958 Mtetra
.759 .804 .889 r
.85478 .64958 .85739 .65265 .86365 .64889 .86105 .64585 Mtetra
.764 .808 .888 r
.86105 .64585 .86365 .64889 .8699 .64501 .86732 .64201 Mtetra
.77 .813 .887 r
.86732 .64201 .8699 .64501 .87614 .64099 .87358 .63803 Mtetra
.776 .818 .885 r
.87358 .63803 .87614 .64099 .88238 .63685 .87984 .63394 Mtetra
.783 .822 .884 r
.87984 .63394 .88238 .63685 .88861 .63257 .88609 .6297 Mtetra
.789 .828 .882 r
.88609 .6297 .88861 .63257 .89483 .62815 .89232 .62533 Mtetra
.796 .833 .88 r
.89232 .62533 .89483 .62815 .90103 .62358 .89855 .62082 Mtetra
.802 .838 .878 r
.89855 .62082 .90103 .62358 .90723 .61887 .90477 .61617 Mtetra
.809 .844 .876 r
.90477 .61617 .90723 .61887 .91341 .614 .91097 .61135 Mtetra
.816 .85 .874 r
.91097 .61135 .91341 .614 .91957 .60897 .91715 .60639 Mtetra
.823 .855 .871 r
.91715 .60639 .91957 .60897 .92572 .60377 .92333 .60126 Mtetra
.831 .861 .868 r
.92333 .60126 .92572 .60377 .93185 .5984 .92948 .59595 Mtetra
.838 .867 .865 r
.92948 .59595 .93185 .5984 .93796 .59286 .93561 .59048 Mtetra
.846 .874 .861 r
.93561 .59048 .93796 .59286 .94404 .58712 .94172 .58482 Mtetra
.854 .88 .857 r
.94172 .58482 .94404 .58712 .95011 .5812 .94781 .57897 Mtetra
.862 .886 .853 r
.94781 .57897 .95011 .5812 .95614 .57508 .95387 .57293 Mtetra
.869 .892 .848 r
.95387 .57293 .95614 .57508 .96215 .56875 .9599 .56669 Mtetra
.877 .899 .843 r
.9599 .56669 .96215 .56875 .96812 .56221 .96591 .56024 Mtetra
.885 .905 .837 r
.96591 .56024 .96812 .56221 .97406 .55545 .97188 .55357 Mtetra
.893 .911 .83 r
.97188 .55357 .97406 .55545 .97997 .54846 .97781 .54667 Mtetra
.809 .371 .203 r
.38894 .60668 .3922 .60642 .3971 .61322 .39385 .61337 Mtetra
.803 .356 .18 r
.39385 .61337 .3971 .61322 .40205 .61975 .3988 .6198 Mtetra
.796 .339 .155 r
.3988 .6198 .40205 .61975 .40704 .62604 .4038 .62598 Mtetra
.788 .321 .128 r
.4038 .62598 .40704 .62604 .41208 .63207 .40884 .63191 Mtetra
.779 .301 .098 r
.40884 .63191 .41208 .63207 .41715 .63785 .41393 .63759 Mtetra
.768 .279 .066 r
.41393 .63759 .41715 .63785 .42227 .6434 .41905 .64304 Mtetra
.755 .255 .032 r
.41905 .64304 .42227 .6434 .42742 .64871 .42421 .64826 Mtetra
.74 .229 0 r
.42421 .64826 .42742 .64871 .43261 .6538 .42941 .65324 Mtetra
.723 .2 0 r
.42941 .65324 .43261 .6538 .43784 .65865 .43464 .658 Mtetra
.703 .168 0 r
.43464 .658 .43784 .65865 .4431 .66329 .43991 .66254 Mtetra
.679 .133 0 r
.43991 .66254 .4431 .66329 .4484 .66771 .44522 .66687 Mtetra
.652 .096 0 r
.44522 .66687 .4484 .66771 .45373 .67192 .45055 .67099 Mtetra
.622 .055 0 r
.45055 .67099 .45373 .67192 .4591 .67592 .45593 .6749 Mtetra
.586 .012 0 r
.45593 .6749 .4591 .67592 .46449 .67972 .46133 .67861 Mtetra
.547 0 0 r
.46133 .67861 .46449 .67972 .46992 .68332 .46676 .68213 Mtetra
.502 0 0 r
.46676 .68213 .46992 .68332 .47538 .68674 .47223 .68545 Mtetra
.453 0 0 r
.47223 .68545 .47538 .68674 .48087 .68996 .47772 .68859 Mtetra
.4 0 0 r
.47772 .68859 .48087 .68996 .48638 .693 .48324 .69155 Mtetra
.343 0 0 r
.48324 .69155 .48638 .693 .49192 .69586 .48879 .69433 Mtetra
0 .29 .658 r
.48879 .69433 .49192 .69586 .49749 .69854 .49437 .69693 Mtetra
0 .34 .711 r
.49437 .69693 .49749 .69854 .50309 .70106 .49997 .69937 Mtetra
0 .387 .76 r
.49997 .69937 .50309 .70106 .50871 .7034 .5056 .70164 Mtetra
0 .431 .803 r
.5056 .70164 .50871 .7034 .51436 .70559 .51125 .70375 Mtetra
0 .471 .841 r
.51125 .70375 .51436 .70559 .52003 .70762 .51693 .7057 Mtetra
.018 .508 .873 r
.51693 .7057 .52003 .70762 .52572 .70949 .52262 .7075 Mtetra
.073 .54 .9 r
.52262 .7075 .52572 .70949 .53143 .71121 .52835 .70915 Mtetra
.124 .568 .921 r
.52835 .70915 .53143 .71121 .53717 .71278 .53409 .71066 Mtetra
.171 .593 .938 r
.53409 .71066 .53717 .71278 .54293 .71422 .53986 .71202 Mtetra
.215 .614 .951 r
.53986 .71202 .54293 .71422 .54871 .71551 .54564 .71325 Mtetra
.255 .633 .961 r
.54564 .71325 .54871 .71551 .55451 .71666 .55145 .71434 Mtetra
.291 .648 .968 r
.55145 .71434 .55451 .71666 .56033 .71769 .55727 .7153 Mtetra
.324 .661 .973 r
.55727 .7153 .56033 .71769 .56617 .71858 .56312 .71613 Mtetra
.354 .672 .976 r
.56312 .71613 .56617 .71858 .57203 .71935 .56898 .71684 Mtetra
.381 .682 .977 r
.56898 .71684 .57203 .71935 .5779 .71999 .57487 .71743 Mtetra
.406 .689 .977 r
.57487 .71743 .5779 .71999 .5838 .72052 .58077 .71789 Mtetra
.429 .696 .976 r
.58077 .71789 .5838 .72052 .58971 .72092 .58668 .71825 Mtetra
.449 .702 .975 r
.58668 .71825 .58971 .72092 .59564 .72121 .59262 .71849 Mtetra
.468 .707 .972 r
.59262 .71849 .59564 .72121 .60158 .7214 .59857 .71862 Mtetra
.485 .711 .97 r
.59857 .71862 .60158 .7214 .60754 .72147 .60453 .71864 Mtetra
.5 .714 .967 r
.60453 .71864 .60754 .72147 .61352 .72143 .61052 .71856 Mtetra
.515 .717 .964 r
.61052 .71856 .61352 .72143 .61951 .72129 .61651 .71838 Mtetra
.528 .719 .961 r
.61651 .71838 .61951 .72129 .62551 .72105 .62253 .71809 Mtetra
.54 .722 .957 r
.62253 .71809 .62551 .72105 .63153 .72071 .62855 .71771 Mtetra
.551 .724 .954 r
.62855 .71771 .63153 .72071 .63757 .72027 .6346 .71723 Mtetra
.561 .725 .951 r
.6346 .71723 .63757 .72027 .64362 .71974 .64065 .71666 Mtetra
.571 .727 .948 r
.64065 .71666 .64362 .71974 .64968 .71911 .64672 .71599 Mtetra
.58 .728 .944 r
.64672 .71599 .64968 .71911 .65575 .71839 .6528 .71524 Mtetra
.588 .729 .941 r
.6528 .71524 .65575 .71839 .66184 .71758 .6589 .71439 Mtetra
.596 .731 .938 r
.6589 .71439 .66184 .71758 .66794 .71668 .665 .71346 Mtetra
.603 .732 .935 r
.665 .71346 .66794 .71668 .67405 .71569 .67112 .71244 Mtetra
.61 .733 .933 r
.67112 .71244 .67405 .71569 .68018 .71461 .67725 .71134 Mtetra
.617 .734 .93 r
.67725 .71134 .68018 .71461 .68631 .71345 .68339 .71015 Mtetra
.623 .735 .927 r
.68339 .71015 .68631 .71345 .69246 .7122 .68955 .70888 Mtetra
.629 .736 .925 r
.68955 .70888 .69246 .7122 .69861 .71087 .69571 .70753 Mtetra
.635 .737 .922 r
.69571 .70753 .69861 .71087 .70478 .70945 .70189 .70609 Mtetra
.64 .739 .92 r
.70189 .70609 .70478 .70945 .71096 .70795 .70807 .70458 Mtetra
.645 .74 .918 r
.70807 .70458 .71096 .70795 .71714 .70637 .71427 .70298 Mtetra
.651 .741 .916 r
.71427 .70298 .71714 .70637 .72334 .70471 .72047 .70131 Mtetra
.655 .742 .914 r
.72047 .70131 .72334 .70471 .72954 .70296 .72668 .69955 Mtetra
.66 .744 .912 r
.72668 .69955 .72954 .70296 .73576 .70114 .7329 .69771 Mtetra
.665 .745 .91 r
.7329 .69771 .73576 .70114 .74198 .69923 .73913 .69579 Mtetra
.67 .747 .908 r
.73913 .69579 .74198 .69923 .74821 .69723 .74537 .6938 Mtetra
.674 .749 .907 r
.74537 .6938 .74821 .69723 .75444 .69515 .75162 .69172 Mtetra
.679 .75 .905 r
.75162 .69172 .75444 .69515 .76069 .69299 .75787 .68955 Mtetra
.683 .752 .904 r
.75787 .68955 .76069 .69299 .76693 .69075 .76413 .68731 Mtetra
.688 .754 .902 r
.76413 .68731 .76693 .69075 .77319 .68842 .77039 .68498 Mtetra
.692 .756 .901 r
.77039 .68498 .77319 .68842 .77945 .686 .77667 .68257 Mtetra
.697 .759 .9 r
.77667 .68257 .77945 .686 .78572 .68349 .78294 .68007 Mtetra
.701 .761 .898 r
.78294 .68007 .78572 .68349 .79199 .6809 .78922 .67748 Mtetra
.706 .764 .897 r
.78922 .67748 .79199 .6809 .79826 .67821 .79551 .67481 Mtetra
.71 .766 .896 r
.79551 .67481 .79826 .67821 .80454 .67543 .8018 .67204 Mtetra
.715 .769 .895 r
.8018 .67204 .80454 .67543 .81081 .67255 .80809 .66918 Mtetra
.72 .772 .894 r
.80809 .66918 .81081 .67255 .8171 .66958 .81438 .66623 Mtetra
.724 .775 .893 r
.81438 .66623 .8171 .66958 .82338 .66651 .82068 .66318 Mtetra
.729 .778 .892 r
.82068 .66318 .82338 .66651 .82966 .66334 .82697 .66003 Mtetra
.734 .782 .891 r
.82697 .66003 .82966 .66334 .83594 .66006 .83327 .65678 Mtetra
.739 .785 .89 r
.83327 .65678 .83594 .66006 .84222 .65668 .83957 .65343 Mtetra
.744 .789 .889 r
.83957 .65343 .84222 .65668 .8485 .65318 .84586 .64996 Mtetra
.75 .793 .888 r
.84586 .64996 .8485 .65318 .85478 .64958 .85215 .64639 Mtetra
.755 .797 .887 r
.85215 .64639 .85478 .64958 .86105 .64585 .85844 .6427 Mtetra
.761 .801 .885 r
.85844 .6427 .86105 .64585 .86732 .64201 .86473 .63889 Mtetra
.767 .806 .884 r
.86473 .63889 .86732 .64201 .87358 .63803 .871 .63496 Mtetra
.773 .81 .883 r
.871 .63496 .87358 .63803 .87984 .63394 .87728 .63091 Mtetra
.779 .815 .881 r
.87728 .63091 .87984 .63394 .88609 .6297 .88354 .62672 Mtetra
.785 .82 .88 r
.88354 .62672 .88609 .6297 .89232 .62533 .8898 .6224 Mtetra
.791 .825 .878 r
.8898 .6224 .89232 .62533 .89855 .62082 .89605 .61794 Mtetra
.798 .83 .876 r
.89605 .61794 .89855 .62082 .90477 .61617 .90228 .61334 Mtetra
.805 .836 .875 r
.90228 .61334 .90477 .61617 .91097 .61135 .9085 .60858 Mtetra
.812 .841 .872 r
.9085 .60858 .91097 .61135 .91715 .60639 .91471 .60368 Mtetra
.819 .847 .87 r
.91471 .60368 .91715 .60639 .92333 .60126 .9209 .59861 Mtetra
.826 .853 .867 r
.9209 .59861 .92333 .60126 .92948 .59595 .92708 .59337 Mtetra
.833 .859 .864 r
.92708 .59337 .92948 .59595 .93561 .59048 .93323 .58796 Mtetra
.841 .865 .861 r
.93323 .58796 .93561 .59048 .94172 .58482 .93937 .58238 Mtetra
.848 .871 .857 r
.93937 .58238 .94172 .58482 .94781 .57897 .94548 .57661 Mtetra
.856 .877 .853 r
.94548 .57661 .94781 .57897 .95387 .57293 .95157 .57064 Mtetra
.864 .883 .849 r
.95157 .57064 .95387 .57293 .9599 .56669 .95763 .56448 Mtetra
.872 .89 .844 r
.95763 .56448 .9599 .56669 .96591 .56024 .96366 .55811 Mtetra
.88 .896 .838 r
.96366 .55811 .96591 .56024 .97188 .55357 .96966 .55153 Mtetra
.888 .902 .832 r
.96966 .55153 .97188 .55357 .97781 .54667 .97563 .54473 Mtetra
.808 .364 .186 r
.38567 .60677 .38894 .60668 .39385 .61337 .39058 .61336 Mtetra
.802 .347 .161 r
.39058 .61336 .39385 .61337 .3988 .6198 .39555 .61969 Mtetra
.794 .33 .134 r
.39555 .61969 .3988 .6198 .4038 .62598 .40055 .62577 Mtetra
.785 .31 .105 r
.40055 .62577 .4038 .62598 .40884 .63191 .4056 .6316 Mtetra
.774 .289 .074 r
.4056 .6316 .40884 .63191 .41393 .63759 .41069 .63719 Mtetra
.762 .265 .04 r
.41069 .63719 .41393 .63759 .41905 .64304 .41582 .64254 Mtetra
.748 .239 .003 r
.41582 .64254 .41905 .64304 .42421 .64826 .42098 .64766 Mtetra
.731 .211 0 r
.42098 .64766 .42421 .64826 .42941 .65324 .42619 .65255 Mtetra
.712 .18 0 r
.42619 .65255 .42941 .65324 .43464 .658 .43143 .65721 Mtetra
.689 .146 0 r
.43143 .65721 .43464 .658 .43991 .66254 .43671 .66166 Mtetra
.663 .109 0 r
.43671 .66166 .43991 .66254 .44522 .66687 .44202 .6659 Mtetra
.633 .07 0 r
.44202 .6659 .44522 .66687 .45055 .67099 .44736 .66992 Mtetra
.598 .027 0 r
.44736 .66992 .45055 .67099 .45593 .6749 .45274 .67375 Mtetra
.559 0 0 r
.45274 .67375 .45593 .6749 .46133 .67861 .45815 .67737 Mtetra
.516 0 0 r
.45815 .67737 .46133 .67861 .46676 .68213 .46359 .6808 Mtetra
.468 0 0 r
.46359 .6808 .46676 .68213 .47223 .68545 .46906 .68404 Mtetra
.415 0 0 r
.46906 .68404 .47223 .68545 .47772 .68859 .47456 .6871 Mtetra
.359 0 0 r
.47456 .6871 .47772 .68859 .48324 .69155 .48009 .68997 Mtetra
0 .274 .647 r
.48009 .68997 .48324 .69155 .48879 .69433 .48565 .69267 Mtetra
0 .324 .701 r
.48565 .69267 .48879 .69433 .49437 .69693 .49123 .6952 Mtetra
0 .372 .75 r
.49123 .6952 .49437 .69693 .49997 .69937 .49684 .69756 Mtetra
0 .417 .795 r
.49684 .69756 .49997 .69937 .5056 .70164 .50247 .69975 Mtetra
0 .458 .833 r
.50247 .69975 .5056 .70164 .51125 .70375 .50813 .70179 Mtetra
.004 .495 .866 r
.50813 .70179 .51125 .70375 .51693 .7057 .51381 .70367 Mtetra
.06 .529 .894 r
.51381 .70367 .51693 .7057 .52262 .7075 .51952 .7054 Mtetra
.111 .558 .916 r
.51952 .7054 .52262 .7075 .52835 .70915 .52525 .70698 Mtetra
.16 .583 .934 r
.52525 .70698 .52835 .70915 .53409 .71066 .531 .70842 Mtetra
.204 .605 .948 r
.531 .70842 .53409 .71066 .53986 .71202 .53677 .70972 Mtetra
.245 .624 .958 r
.53677 .70972 .53986 .71202 .54564 .71325 .54256 .71088 Mtetra
.282 .64 .966 r
.54256 .71088 .54564 .71325 .55145 .71434 .54837 .71191 Mtetra
.316 .654 .971 r
.54837 .71191 .55145 .71434 .55727 .7153 .5542 .71281 Mtetra
.347 .665 .974 r
.5542 .71281 .55727 .7153 .56312 .71613 .56006 .71358 Mtetra
.374 .675 .975 r
.56006 .71358 .56312 .71613 .56898 .71684 .56593 .71423 Mtetra
.4 .683 .975 r
.56593 .71423 .56898 .71684 .57487 .71743 .57181 .71476 Mtetra
.423 .69 .975 r
.57181 .71476 .57487 .71743 .58077 .71789 .57772 .71517 Mtetra
.443 .696 .973 r
.57772 .71517 .58077 .71789 .58668 .71825 .58364 .71547 Mtetra
.462 .701 .971 r
.58364 .71547 .58668 .71825 .59262 .71849 .58958 .71566 Mtetra
.48 .705 .968 r
.58958 .71566 .59262 .71849 .59857 .71862 .59554 .71574 Mtetra
.496 .709 .966 r
.59554 .71574 .59857 .71862 .60453 .71864 .60151 .71572 Mtetra
.51 .712 .963 r
.60151 .71572 .60453 .71864 .61052 .71856 .6075 .71559 Mtetra
.523 .714 .959 r
.6075 .71559 .61052 .71856 .61651 .71838 .61351 .71536 Mtetra
.536 .717 .956 r
.61351 .71536 .61651 .71838 .62253 .71809 .61953 .71504 Mtetra
.547 .719 .953 r
.61953 .71504 .62253 .71809 .62855 .71771 .62556 .71461 Mtetra
.557 .72 .949 r
.62556 .71461 .62855 .71771 .6346 .71723 .63161 .7141 Mtetra
.567 .722 .946 r
.63161 .7141 .6346 .71723 .64065 .71666 .63767 .71349 Mtetra
.576 .723 .943 r
.63767 .71349 .64065 .71666 .64672 .71599 .64375 .71279 Mtetra
.584 .725 .94 r
.64375 .71279 .64672 .71599 .6528 .71524 .64983 .712 Mtetra
.592 .726 .937 r
.64983 .712 .6528 .71524 .6589 .71439 .65593 .71112 Mtetra
.6 .727 .934 r
.65593 .71112 .6589 .71439 .665 .71346 .66205 .71016 Mtetra
.606 .728 .931 r
.66205 .71016 .665 .71346 .67112 .71244 .66817 .70911 Mtetra
.613 .729 .928 r
.66817 .70911 .67112 .71244 .67725 .71134 .67431 .70798 Mtetra
.619 .73 .926 r
.67431 .70798 .67725 .71134 .68339 .71015 .68046 .70677 Mtetra
.625 .731 .923 r
.68046 .70677 .68339 .71015 .68955 .70888 .68662 .70548 Mtetra
.631 .732 .921 r
.68662 .70548 .68955 .70888 .69571 .70753 .69279 .7041 Mtetra
.636 .733 .918 r
.69279 .7041 .69571 .70753 .70189 .70609 .69898 .70265 Mtetra
.641 .734 .916 r
.69898 .70265 .70189 .70609 .70807 .70458 .70517 .70112 Mtetra
.646 .735 .914 r
.70517 .70112 .70807 .70458 .71427 .70298 .71137 .6995 Mtetra
.651 .737 .912 r
.71137 .6995 .71427 .70298 .72047 .70131 .71758 .69781 Mtetra
.656 .738 .91 r
.71758 .69781 .72047 .70131 .72668 .69955 .72381 .69605 Mtetra
.661 .739 .908 r
.72381 .69605 .72668 .69955 .7329 .69771 .73004 .6942 Mtetra
.665 .741 .907 r
.73004 .6942 .7329 .69771 .73913 .69579 .73628 .69227 Mtetra
.67 .742 .905 r
.73628 .69227 .73913 .69579 .74537 .6938 .74252 .69027 Mtetra
.674 .744 .903 r
.74252 .69027 .74537 .6938 .75162 .69172 .74878 .68819 Mtetra
.678 .746 .902 r
.74878 .68819 .75162 .69172 .75787 .68955 .75504 .68602 Mtetra
.683 .748 .9 r
.75504 .68602 .75787 .68955 .76413 .68731 .76131 .68378 Mtetra
.687 .749 .899 r
.76131 .68378 .76413 .68731 .77039 .68498 .76758 .68145 Mtetra
.691 .752 .898 r
.76758 .68145 .77039 .68498 .77667 .68257 .77387 .67905 Mtetra
.695 .754 .897 r
.77387 .67905 .77667 .68257 .78294 .68007 .78015 .67655 Mtetra
.7 .756 .895 r
.78015 .67655 .78294 .68007 .78922 .67748 .78644 .67398 Mtetra
.704 .758 .894 r
.78644 .67398 .78922 .67748 .79551 .67481 .79274 .67131 Mtetra
.709 .761 .893 r
.79274 .67131 .79551 .67481 .8018 .67204 .79904 .66856 Mtetra
.713 .764 .892 r
.79904 .66856 .8018 .67204 .80809 .66918 .80534 .66572 Mtetra
.718 .766 .891 r
.80534 .66572 .80809 .66918 .81438 .66623 .81165 .66278 Mtetra
.722 .769 .89 r
.81165 .66278 .81438 .66623 .82068 .66318 .81796 .65975 Mtetra
.727 .773 .889 r
.81796 .65975 .82068 .66318 .82697 .66003 .82427 .65663 Mtetra
.732 .776 .888 r
.82427 .65663 .82697 .66003 .83327 .65678 .83058 .6534 Mtetra
.737 .779 .887 r
.83058 .6534 .83327 .65678 .83957 .65343 .83689 .65007 Mtetra
.742 .783 .886 r
.83689 .65007 .83957 .65343 .84586 .64996 .8432 .64664 Mtetra
.747 .787 .885 r
.8432 .64664 .84586 .64996 .85215 .64639 .8495 .64309 Mtetra
.752 .791 .884 r
.8495 .64309 .85215 .64639 .85844 .6427 .85581 .63944 Mtetra
.758 .795 .883 r
.85581 .63944 .85844 .6427 .86473 .63889 .86211 .63567 Mtetra
.763 .799 .882 r
.86211 .63567 .86473 .63889 .871 .63496 .8684 .63178 Mtetra
.769 .803 .881 r
.8684 .63178 .871 .63496 .87728 .63091 .87469 .62776 Mtetra
.775 .808 .879 r
.87469 .62776 .87728 .63091 .88354 .62672 .88098 .62362 Mtetra
.781 .813 .878 r
.88098 .62362 .88354 .62672 .8898 .6224 .88725 .61935 Mtetra
.787 .818 .876 r
.88725 .61935 .8898 .6224 .89605 .61794 .89352 .61494 Mtetra
.794 .823 .875 r
.89352 .61494 .89605 .61794 .90228 .61334 .89977 .61039 Mtetra
.8 .828 .873 r
.89977 .61039 .90228 .61334 .9085 .60858 .90601 .60569 Mtetra
.807 .833 .871 r
.90601 .60569 .9085 .60858 .91471 .60368 .91224 .60084 Mtetra
.814 .839 .869 r
.91224 .60084 .91471 .60368 .9209 .59861 .91846 .59583 Mtetra
.821 .845 .866 r
.91846 .59583 .9209 .59861 .92708 .59337 .92466 .59066 Mtetra
.828 .851 .864 r
.92466 .59066 .92708 .59337 .93323 .58796 .93083 .58532 Mtetra
.836 .857 .861 r
.93083 .58532 .93323 .58796 .93937 .58238 .93699 .57981 Mtetra
.843 .863 .857 r
.93699 .57981 .93937 .58238 .94548 .57661 .94313 .57411 Mtetra
.851 .869 .853 r
.94313 .57411 .94548 .57661 .95157 .57064 .94924 .56822 Mtetra
.859 .875 .849 r
.94924 .56822 .95157 .57064 .95763 .56448 .95533 .56214 Mtetra
.867 .881 .845 r
.95533 .56214 .95763 .56448 .96366 .55811 .96139 .55585 Mtetra
.875 .887 .84 r
.96139 .55585 .96366 .55811 .96966 .55153 .96742 .54935 Mtetra
.883 .893 .834 r
.96742 .54935 .96966 .55153 .97563 .54473 .97341 .54263 Mtetra
.807 .356 .168 r
.38238 .60672 .38567 .60677 .39058 .61336 .38731 .61321 Mtetra
.799 .338 .141 r
.38731 .61321 .39058 .61336 .39555 .61969 .39228 .61944 Mtetra
.791 .319 .113 r
.39228 .61944 .39555 .61969 .40055 .62577 .39729 .62542 Mtetra
.781 .299 .082 r
.39729 .62542 .40055 .62577 .4056 .6316 .40234 .63115 Mtetra
.769 .276 .049 r
.40234 .63115 .4056 .6316 .41069 .63719 .40744 .63664 Mtetra
.755 .251 .012 r
.40744 .63664 .41069 .63719 .41582 .64254 .41257 .6419 Mtetra
.739 .223 0 r
.41257 .6419 .41582 .64254 .42098 .64766 .41775 .64692 Mtetra
.72 .193 0 r
.41775 .64692 .42098 .64766 .42619 .65255 .42296 .65172 Mtetra
.699 .16 0 r
.42296 .65172 .42619 .65255 .43143 .65721 .42821 .65629 Mtetra
.673 .124 0 r
.42821 .65629 .43143 .65721 .43671 .66166 .43349 .66065 Mtetra
.644 .085 0 r
.43349 .66065 .43671 .66166 .44202 .6659 .43881 .66479 Mtetra
.611 .042 0 r
.43881 .66479 .44202 .6659 .44736 .66992 .44416 .66873 Mtetra
.573 0 0 r
.44416 .66873 .44736 .66992 .45274 .67375 .44955 .67247 Mtetra
.53 0 0 r
.44955 .67247 .45274 .67375 .45815 .67737 .45496 .67601 Mtetra
.483 0 0 r
.45496 .67601 .45815 .67737 .46359 .6808 .46041 .67936 Mtetra
.431 0 0 r
.46041 .67936 .46359 .6808 .46906 .68404 .46589 .68252 Mtetra
.376 0 0 r
.46589 .68252 .46906 .68404 .47456 .6871 .47139 .68549 Mtetra
0 .256 .633 r
.47139 .68549 .47456 .6871 .48009 .68997 .47693 .68829 Mtetra
0 .307 .688 r
.47693 .68829 .48009 .68997 .48565 .69267 .48249 .69091 Mtetra
0 .356 .739 r
.48249 .69091 .48565 .69267 .49123 .6952 .48808 .69335 Mtetra
0 .402 .784 r
.48808 .69335 .49123 .6952 .49684 .69756 .49369 .69564 Mtetra
0 .444 .824 r
.49369 .69564 .49684 .69756 .50247 .69975 .49933 .69776 Mtetra
0 .482 .859 r
.49933 .69776 .50247 .69975 .50813 .70179 .505 .69972 Mtetra
.045 .516 .887 r
.505 .69972 .50813 .70179 .51381 .70367 .51069 .70153 Mtetra
.098 .547 .911 r
.51069 .70153 .51381 .70367 .51952 .7054 .5164 .70319 Mtetra
.147 .573 .929 r
.5164 .70319 .51952 .7054 .52525 .70698 .52213 .70471 Mtetra
.192 .596 .944 r
.52213 .70471 .52525 .70698 .531 .70842 .52789 .70608 Mtetra
.234 .615 .955 r
.52789 .70608 .531 .70842 .53677 .70972 .53367 .70731 Mtetra
.272 .632 .963 r
.53367 .70731 .53677 .70972 .54256 .71088 .53946 .70841 Mtetra
.307 .646 .968 r
.53946 .70841 .54256 .71088 .54837 .71191 .54528 .70938 Mtetra
.338 .658 .972 r
.54528 .70938 .54837 .71191 .5542 .71281 .55112 .71022 Mtetra
.366 .669 .973 r
.55112 .71022 .5542 .71281 .56006 .71358 .55698 .71093 Mtetra
.392 .677 .974 r
.55698 .71093 .56006 .71358 .56593 .71423 .56285 .71153 Mtetra
.416 .684 .973 r
.56285 .71153 .56593 .71423 .57181 .71476 .56875 .712 Mtetra
.437 .691 .972 r
.56875 .712 .57181 .71476 .57772 .71517 .57466 .71236 Mtetra
.457 .696 .97 r
.57466 .71236 .57772 .71517 .58364 .71547 .58059 .71261 Mtetra
.474 .7 .967 r
.58059 .71261 .58364 .71547 .58958 .71566 .58654 .71275 Mtetra
.49 .704 .964 r
.58654 .71275 .58958 .71566 .59554 .71574 .5925 .71278 Mtetra
.505 .707 .961 r
.5925 .71278 .59554 .71574 .60151 .71572 .59848 .71271 Mtetra
.519 .71 .958 r
.59848 .71271 .60151 .71572 .6075 .71559 .60448 .71254 Mtetra
.531 .712 .955 r
.60448 .71254 .6075 .71559 .61351 .71536 .61049 .71226 Mtetra
.542 .714 .952 r
.61049 .71226 .61351 .71536 .61953 .71504 .61651 .71189 Mtetra
.553 .716 .948 r
.61651 .71189 .61953 .71504 .62556 .71461 .62255 .71143 Mtetra
.563 .718 .945 r
.62255 .71143 .62556 .71461 .63161 .7141 .62861 .71088 Mtetra
.572 .719 .942 r
.62861 .71088 .63161 .7141 .63767 .71349 .63467 .71023 Mtetra
.58 .72 .939 r
.63467 .71023 .63767 .71349 .64375 .71279 .64076 .70949 Mtetra
.588 .721 .936 r
.64076 .70949 .64375 .71279 .64983 .712 .64685 .70867 Mtetra
.596 .722 .933 r
.64685 .70867 .64983 .712 .65593 .71112 .65296 .70776 Mtetra
.603 .723 .93 r
.65296 .70776 .65593 .71112 .66205 .71016 .65908 .70677 Mtetra
.609 .724 .927 r
.65908 .70677 .66205 .71016 .66817 .70911 .66521 .7057 Mtetra
.616 .725 .924 r
.66521 .7057 .66817 .70911 .67431 .70798 .67136 .70454 Mtetra
.621 .726 .922 r
.67136 .70454 .67431 .70798 .68046 .70677 .67752 .7033 Mtetra
.627 .727 .919 r
.67752 .7033 .68046 .70677 .68662 .70548 .68368 .70199 Mtetra
.632 .728 .917 r
.68368 .70199 .68662 .70548 .69279 .7041 .68986 .70059 Mtetra
.638 .729 .915 r
.68986 .70059 .69279 .7041 .69898 .70265 .69605 .69912 Mtetra
.643 .73 .912 r
.69605 .69912 .69898 .70265 .70517 .70112 .70225 .69757 Mtetra
.647 .732 .91 r
.70225 .69757 .70517 .70112 .71137 .6995 .70846 .69594 Mtetra
.652 .733 .909 r
.70846 .69594 .71137 .6995 .71758 .69781 .71469 .69424 Mtetra
.657 .734 .907 r
.71469 .69424 .71758 .69781 .72381 .69605 .72091 .69246 Mtetra
.661 .735 .905 r
.72091 .69246 .72381 .69605 .73004 .6942 .72715 .6906 Mtetra
.665 .737 .903 r
.72715 .6906 .73004 .6942 .73628 .69227 .7334 .68867 Mtetra
.67 .738 .902 r
.7334 .68867 .73628 .69227 .74252 .69027 .73966 .68666 Mtetra
.674 .74 .9 r
.73966 .68666 .74252 .69027 .74878 .68819 .74592 .68457 Mtetra
.678 .741 .899 r
.74592 .68457 .74878 .68819 .75504 .68602 .75219 .68241 Mtetra
.682 .743 .897 r
.75219 .68241 .75504 .68602 .76131 .68378 .75847 .68016 Mtetra
.686 .745 .896 r
.75847 .68016 .76131 .68378 .76758 .68145 .76476 .67784 Mtetra
.69 .747 .895 r
.76476 .67784 .76758 .68145 .77387 .67905 .77105 .67544 Mtetra
.694 .749 .894 r
.77105 .67544 .77387 .67905 .78015 .67655 .77735 .67295 Mtetra
.699 .751 .893 r
.77735 .67295 .78015 .67655 .78644 .67398 .78365 .67038 Mtetra
.703 .754 .891 r
.78365 .67038 .78644 .67398 .79274 .67131 .78996 .66773 Mtetra
.707 .756 .89 r
.78996 .66773 .79274 .67131 .79904 .66856 .79627 .66499 Mtetra
.711 .759 .889 r
.79627 .66499 .79904 .66856 .80534 .66572 .80258 .66216 Mtetra
.716 .761 .888 r
.80258 .66216 .80534 .66572 .81165 .66278 .8089 .65924 Mtetra
.72 .764 .887 r
.8089 .65924 .81165 .66278 .81796 .65975 .81522 .65623 Mtetra
.725 .767 .887 r
.81522 .65623 .81796 .65975 .82427 .65663 .82155 .65313 Mtetra
.729 .77 .886 r
.82155 .65313 .82427 .65663 .83058 .6534 .82787 .64992 Mtetra
.734 .774 .885 r
.82787 .64992 .83058 .6534 .83689 .65007 .83419 .64662 Mtetra
.739 .777 .884 r
.83419 .64662 .83689 .65007 .8432 .64664 .84052 .64322 Mtetra
.744 .781 .883 r
.84052 .64322 .8432 .64664 .8495 .64309 .84684 .6397 Mtetra
.749 .785 .882 r
.84684 .6397 .8495 .64309 .85581 .63944 .85316 .63608 Mtetra
.754 .789 .881 r
.85316 .63608 .85581 .63944 .86211 .63567 .85947 .63235 Mtetra
.76 .793 .88 r
.85947 .63235 .86211 .63567 .8684 .63178 .86579 .62849 Mtetra
.765 .797 .879 r
.86579 .62849 .8684 .63178 .87469 .62776 .87209 .62452 Mtetra
.771 .801 .877 r
.87209 .62452 .87469 .62776 .88098 .62362 .87839 .62042 Mtetra
.777 .806 .876 r
.87839 .62042 .88098 .62362 .88725 .61935 .88468 .61619 Mtetra
.783 .811 .875 r
.88468 .61619 .88725 .61935 .89352 .61494 .89097 .61183 Mtetra
.79 .816 .873 r
.89097 .61183 .89352 .61494 .89977 .61039 .89724 .60733 Mtetra
.796 .821 .871 r
.89724 .60733 .89977 .61039 .90601 .60569 .9035 .60269 Mtetra
.803 .826 .869 r
.9035 .60269 .90601 .60569 .91224 .60084 .90975 .59789 Mtetra
.809 .832 .867 r
.90975 .59789 .91224 .60084 .91846 .59583 .91599 .59294 Mtetra
.816 .837 .865 r
.91599 .59294 .91846 .59583 .92466 .59066 .92221 .58783 Mtetra
.824 .843 .863 r
.92221 .58783 .92466 .59066 .93083 .58532 .92841 .58256 Mtetra
.831 .849 .86 r
.92841 .58256 .93083 .58532 .93699 .57981 .93459 .57711 Mtetra
.838 .855 .857 r
.93459 .57711 .93699 .57981 .94313 .57411 .94075 .57148 Mtetra
.846 .861 .853 r
.94075 .57148 .94313 .57411 .94924 .56822 .94689 .56566 Mtetra
.854 .867 .85 r
.94689 .56566 .94924 .56822 .95533 .56214 .953 .55966 Mtetra
.862 .873 .845 r
.953 .55966 .95533 .56214 .96139 .55585 .95909 .55345 Mtetra
.87 .879 .841 r
.95909 .55345 .96139 .55585 .96742 .54935 .96514 .54703 Mtetra
.878 .885 .835 r
.96514 .54703 .96742 .54935 .97341 .54263 .97117 .5404 Mtetra
.805 .347 .149 r
.37909 .60652 .38238 .60672 .38731 .61321 .38402 .61291 Mtetra
.797 .329 .121 r
.38402 .61291 .38731 .61321 .39228 .61944 .389 .61904 Mtetra
.787 .309 .091 r
.389 .61904 .39228 .61944 .39729 .62542 .39401 .62492 Mtetra
.776 .286 .058 r
.39401 .62492 .39729 .62542 .40234 .63115 .39908 .63056 Mtetra
.763 .262 .023 r
.39908 .63056 .40234 .63115 .40744 .63664 .40418 .63596 Mtetra
.747 .235 0 r
.40418 .63596 .40744 .63664 .41257 .6419 .40932 .64112 Mtetra
.729 .206 0 r
.40932 .64112 .41257 .6419 .41775 .64692 .4145 .64605 Mtetra
.709 .174 0 r
.4145 .64605 .41775 .64692 .42296 .65172 .41972 .65075 Mtetra
.684 .138 0 r
.41972 .65075 .42296 .65172 .42821 .65629 .42497 .65524 Mtetra
.656 .1 0 r
.42497 .65524 .42821 .65629 .43349 .66065 .43026 .65951 Mtetra
.624 .059 0 r
.43026 .65951 .43349 .66065 .43881 .66479 .43559 .66357 Mtetra
.587 .014 0 r
.43559 .66357 .43881 .66479 .44416 .66873 .44095 .66742 Mtetra
.546 0 0 r
.44095 .66742 .44416 .66873 .44955 .67247 .44634 .67107 Mtetra
.5 0 0 r
.44634 .67107 .44955 .67247 .45496 .67601 .45176 .67453 Mtetra
.449 0 0 r
.45176 .67453 .45496 .67601 .46041 .67936 .45721 .67779 Mtetra
.394 0 0 r
.45721 .67779 .46041 .67936 .46589 .68252 .4627 .68087 Mtetra
.336 0 0 r
.4627 .68087 .46589 .68252 .47139 .68549 .46821 .68377 Mtetra
0 .289 .674 r
.46821 .68377 .47139 .68549 .47693 .68829 .47375 .68648 Mtetra
0 .338 .726 r
.47375 .68648 .47693 .68829 .48249 .69091 .47932 .68903 Mtetra
0 .385 .773 r
.47932 .68903 .48249 .69091 .48808 .69335 .48491 .6914 Mtetra
0 .428 .814 r
.48491 .6914 .48808 .69335 .49369 .69564 .49053 .69361 Mtetra
0 .468 .85 r
.49053 .69361 .49369 .69564 .49933 .69776 .49618 .69566 Mtetra
.028 .503 .88 r
.49618 .69566 .49933 .69776 .505 .69972 .50185 .69755 Mtetra
.082 .534 .904 r
.50185 .69755 .505 .69972 .51069 .70153 .50755 .69929 Mtetra
.132 .562 .924 r
.50755 .69929 .51069 .70153 .5164 .70319 .51326 .70089 Mtetra
.179 .586 .939 r
.51326 .70089 .5164 .70319 .52213 .70471 .519 .70233 Mtetra
.222 .606 .951 r
.519 .70233 .52213 .70471 .52789 .70608 .52477 .70364 Mtetra
.261 .624 .96 r
.52477 .70364 .52789 .70608 .53367 .70731 .53055 .70481 Mtetra
.296 .639 .966 r
.53055 .70481 .53367 .70731 .53946 .70841 .53635 .70585 Mtetra
.328 .651 .969 r
.53635 .70585 .53946 .70841 .54528 .70938 .54218 .70675 Mtetra
.358 .662 .972 r
.54218 .70675 .54528 .70938 .55112 .71022 .54802 .70753 Mtetra
.384 .671 .972 r
.54802 .70753 .55112 .71022 .55698 .71093 .55389 .70819 Mtetra
.408 .679 .972 r
.55389 .70819 .55698 .71093 .56285 .71153 .55977 .70873 Mtetra
.43 .685 .971 r
.55977 .70873 .56285 .71153 .56875 .712 .56567 .70915 Mtetra
.45 .691 .969 r
.56567 .70915 .56875 .712 .57466 .71236 .57159 .70946 Mtetra
.468 .695 .966 r
.57159 .70946 .57466 .71236 .58059 .71261 .57753 .70966 Mtetra
.485 .699 .964 r
.57753 .70966 .58059 .71261 .58654 .71275 .58348 .70975 Mtetra
.5 .703 .961 r
.58348 .70975 .58654 .71275 .5925 .71278 .58945 .70973 Mtetra
.514 .705 .957 r
.58945 .70973 .5925 .71278 .59848 .71271 .59543 .70961 Mtetra
.526 .708 .954 r
.59543 .70961 .59848 .71271 .60448 .71254 .60144 .7094 Mtetra
.538 .71 .951 r
.60144 .7094 .60448 .71254 .61049 .71226 .60745 .70908 Mtetra
.549 .712 .947 r
.60745 .70908 .61049 .71226 .61651 .71189 .61348 .70867 Mtetra
.559 .713 .944 r
.61348 .70867 .61651 .71189 .62255 .71143 .61953 .70817 Mtetra
.568 .715 .941 r
.61953 .70817 .62255 .71143 .62861 .71088 .62559 .70757 Mtetra
.576 .716 .938 r
.62559 .70757 .62861 .71088 .63467 .71023 .63167 .70689 Mtetra
.585 .717 .935 r
.63167 .70689 .63467 .71023 .64076 .70949 .63776 .70612 Mtetra
.592 .718 .932 r
.63776 .70612 .64076 .70949 .64685 .70867 .64386 .70527 Mtetra
.599 .719 .929 r
.64386 .70527 .64685 .70867 .65296 .70776 .64997 .70433 Mtetra
.606 .72 .926 r
.64997 .70433 .65296 .70776 .65908 .70677 .6561 .70331 Mtetra
.612 .721 .923 r
.6561 .70331 .65908 .70677 .66521 .7057 .66224 .7022 Mtetra
.618 .722 .921 r
.66224 .7022 .66521 .7057 .67136 .70454 .66839 .70102 Mtetra
.623 .723 .918 r
.66839 .70102 .67136 .70454 .67752 .7033 .67456 .69976 Mtetra
.629 .724 .916 r
.67456 .69976 .67752 .7033 .68368 .70199 .68073 .69842 Mtetra
.634 .725 .913 r
.68073 .69842 .68368 .70199 .68986 .70059 .68692 .69701 Mtetra
.639 .726 .911 r
.68692 .69701 .68986 .70059 .69605 .69912 .69312 .69552 Mtetra
.644 .727 .909 r
.69312 .69552 .69605 .69912 .70225 .69757 .69932 .69395 Mtetra
.648 .728 .907 r
.69932 .69395 .70225 .69757 .70846 .69594 .70554 .69231 Mtetra
.653 .729 .905 r
.70554 .69231 .70846 .69594 .71469 .69424 .71177 .69059 Mtetra
.657 .73 .904 r
.71177 .69059 .71469 .69424 .72091 .69246 .71801 .6888 Mtetra
.661 .732 .902 r
.71801 .6888 .72091 .69246 .72715 .6906 .72426 .68693 Mtetra
.665 .733 .9 r
.72426 .68693 .72715 .6906 .7334 .68867 .73051 .68499 Mtetra
.669 .734 .899 r
.73051 .68499 .7334 .68867 .73966 .68666 .73678 .68297 Mtetra
.673 .736 .897 r
.73678 .68297 .73966 .68666 .74592 .68457 .74305 .68088 Mtetra
.677 .738 .896 r
.74305 .68088 .74592 .68457 .75219 .68241 .74933 .67872 Mtetra
.681 .739 .895 r
.74933 .67872 .75219 .68241 .75847 .68016 .75562 .67647 Mtetra
.685 .741 .893 r
.75562 .67647 .75847 .68016 .76476 .67784 .76192 .67415 Mtetra
.689 .743 .892 r
.76192 .67415 .76476 .67784 .77105 .67544 .76822 .67175 Mtetra
.693 .745 .891 r
.76822 .67175 .77105 .67544 .77735 .67295 .77453 .66927 Mtetra
.697 .747 .89 r
.77453 .66927 .77735 .67295 .78365 .67038 .78084 .66671 Mtetra
.701 .749 .889 r
.78084 .66671 .78365 .67038 .78996 .66773 .78716 .66406 Mtetra
.705 .752 .888 r
.78716 .66406 .78996 .66773 .79627 .66499 .79348 .66134 Mtetra
.71 .754 .887 r
.79348 .66134 .79627 .66499 .80258 .66216 .79981 .65852 Mtetra
.714 .757 .886 r
.79981 .65852 .80258 .66216 .8089 .65924 .80614 .65562 Mtetra
.718 .76 .885 r
.80614 .65562 .8089 .65924 .81522 .65623 .81247 .65263 Mtetra
.723 .763 .884 r
.81247 .65263 .81522 .65623 .82155 .65313 .81881 .64954 Mtetra
.727 .766 .883 r
.81881 .64954 .82155 .65313 .82787 .64992 .82514 .64636 Mtetra
.732 .769 .882 r
.82514 .64636 .82787 .64992 .83419 .64662 .83148 .64308 Mtetra
.736 .772 .882 r
.83148 .64308 .83419 .64662 .84052 .64322 .83782 .6397 Mtetra
.741 .776 .881 r
.83782 .6397 .84052 .64322 .84684 .6397 .84415 .63622 Mtetra
.746 .779 .88 r
.84415 .63622 .84684 .6397 .85316 .63608 .85049 .63263 Mtetra
.751 .783 .879 r
.85049 .63263 .85316 .63608 .85947 .63235 .85682 .62893 Mtetra
.757 .787 .878 r
.85682 .62893 .85947 .63235 .86579 .62849 .86315 .62511 Mtetra
.762 .791 .877 r
.86315 .62511 .86579 .62849 .87209 .62452 .86947 .62118 Mtetra
.768 .796 .876 r
.86947 .62118 .87209 .62452 .87839 .62042 .87579 .61712 Mtetra
.774 .8 .874 r
.87579 .61712 .87839 .62042 .88468 .61619 .8821 .61294 Mtetra
.78 .805 .873 r
.8821 .61294 .88468 .61619 .89097 .61183 .8884 .60862 Mtetra
.786 .809 .871 r
.8884 .60862 .89097 .61183 .89724 .60733 .89469 .60417 Mtetra
.792 .814 .87 r
.89469 .60417 .89724 .60733 .9035 .60269 .90097 .59957 Mtetra
.799 .82 .868 r
.90097 .59957 .9035 .60269 .90975 .59789 .90724 .59483 Mtetra
.805 .825 .866 r
.90724 .59483 .90975 .59789 .91599 .59294 .9135 .58994 Mtetra
.812 .83 .864 r
.9135 .58994 .91599 .59294 .92221 .58783 .91974 .58489 Mtetra
.819 .836 .862 r
.91974 .58489 .92221 .58783 .92841 .58256 .92596 .57968 Mtetra
.826 .842 .859 r
.92596 .57968 .92841 .58256 .93459 .57711 .93217 .57429 Mtetra
.834 .847 .856 r
.93217 .57429 .93459 .57711 .94075 .57148 .93835 .56873 Mtetra
.841 .853 .853 r
.93835 .56873 .94075 .57148 .94689 .56566 .94451 .56298 Mtetra
.849 .859 .85 r
.94451 .56298 .94689 .56566 .953 .55966 .95065 .55705 Mtetra
.857 .865 .846 r
.95065 .55705 .953 .55966 .95909 .55345 .95676 .55092 Mtetra
.865 .871 .841 r
.95676 .55092 .95909 .55345 .96514 .54703 .96285 .54458 Mtetra
.873 .877 .836 r
.96285 .54458 .96514 .54703 .97117 .5404 .9689 .53803 Mtetra
.803 .338 .13 r
.37578 .60618 .37909 .60652 .38402 .61291 .38072 .61247 Mtetra
.794 .319 .1 r
.38072 .61247 .38402 .61291 .389 .61904 .3857 .61851 Mtetra
.783 .297 .068 r
.3857 .61851 .389 .61904 .39401 .62492 .39073 .62429 Mtetra
.77 .274 .033 r
.39073 .62429 .39401 .62492 .39908 .63056 .3958 .62984 Mtetra
.756 .248 0 r
.3958 .62984 .39908 .63056 .40418 .63596 .40091 .63514 Mtetra
.739 .219 0 r
.40091 .63514 .40418 .63596 .40932 .64112 .40605 .64021 Mtetra
.718 .188 0 r
.40605 .64021 .40932 .64112 .4145 .64605 .41124 .64505 Mtetra
.695 .153 0 r
.41124 .64505 .4145 .64605 .41972 .65075 .41647 .64967 Mtetra
.668 .116 0 r
.41647 .64967 .41972 .65075 .42497 .65524 .42173 .65407 Mtetra
.637 .076 0 r
.42173 .65407 .42497 .65524 .43026 .65951 .42702 .65825 Mtetra
.602 .032 0 r
.42702 .65825 .43026 .65951 .43559 .66357 .43235 .66222 Mtetra
.562 0 0 r
.43235 .66222 .43559 .66357 .44095 .66742 .43772 .66599 Mtetra
.517 0 0 r
.43772 .66599 .44095 .66742 .44634 .67107 .44312 .66956 Mtetra
.467 0 0 r
.44312 .66956 .44634 .67107 .45176 .67453 .44855 .67294 Mtetra
.413 0 0 r
.44855 .67294 .45176 .67453 .45721 .67779 .45401 .67612 Mtetra
.356 0 0 r
.45401 .67612 .45721 .67779 .4627 .68087 .45949 .67912 Mtetra
0 .27 .658 r
.45949 .67912 .4627 .68087 .46821 .68377 .46501 .68194 Mtetra
0 .32 .711 r
.46501 .68194 .46821 .68377 .47375 .68648 .47056 .68458 Mtetra
0 .367 .759 r
.47056 .68458 .47375 .68648 .47932 .68903 .47614 .68705 Mtetra
0 .412 .802 r
.47614 .68705 .47932 .68903 .48491 .6914 .48174 .68935 Mtetra
0 .452 .839 r
.48174 .68935 .48491 .6914 .49053 .69361 .48736 .69148 Mtetra
.01 .489 .871 r
.48736 .69148 .49053 .69361 .49618 .69566 .49302 .69346 Mtetra
.065 .521 .897 r
.49302 .69346 .49618 .69566 .50185 .69755 .49869 .69529 Mtetra
.116 .55 .918 r
.49869 .69529 .50185 .69755 .50755 .69929 .50439 .69696 Mtetra
.164 .575 .934 r
.50439 .69696 .50755 .69929 .51326 .70089 .51012 .69848 Mtetra
.208 .596 .947 r
.51012 .69848 .51326 .70089 .519 .70233 .51586 .69987 Mtetra
.248 .615 .956 r
.51586 .69987 .519 .70233 .52477 .70364 .52163 .70111 Mtetra
.285 .63 .963 r
.52163 .70111 .52477 .70364 .53055 .70481 .52742 .70222 Mtetra
.318 .644 .967 r
.52742 .70222 .53055 .70481 .53635 .70585 .53323 .70319 Mtetra
.348 .655 .97 r
.53323 .70319 .53635 .70585 .54218 .70675 .53906 .70404 Mtetra
.375 .665 .971 r
.53906 .70404 .54218 .70675 .54802 .70753 .54491 .70477 Mtetra
.4 .673 .971 r
.54491 .70477 .54802 .70753 .55389 .70819 .55078 .70537 Mtetra
.423 .68 .97 r
.55078 .70537 .55389 .70819 .55977 .70873 .55667 .70585 Mtetra
.443 .686 .968 r
.55667 .70585 .55977 .70873 .56567 .70915 .56258 .70622 Mtetra
.462 .69 .966 r
.56258 .70622 .56567 .70915 .57159 .70946 .56851 .70648 Mtetra
.479 .695 .963 r
.56851 .70648 .57159 .70946 .57753 .70966 .57445 .70662 Mtetra
.494 .698 .96 r
.57445 .70662 .57753 .70966 .58348 .70975 .58041 .70666 Mtetra
.508 .701 .957 r
.58041 .70666 .58348 .70975 .58945 .70973 .58638 .7066 Mtetra
.521 .704 .954 r
.58638 .7066 .58945 .70973 .59543 .70961 .59237 .70644 Mtetra
.533 .706 .95 r
.59237 .70644 .59543 .70961 .60144 .7094 .59838 .70618 Mtetra
.544 .708 .947 r
.59838 .70618 .60144 .7094 .60745 .70908 .6044 .70582 Mtetra
.554 .71 .944 r
.6044 .70582 .60745 .70908 .61348 .70867 .61044 .70537 Mtetra
.564 .711 .94 r
.61044 .70537 .61348 .70867 .61953 .70817 .6165 .70483 Mtetra
.572 .712 .937 r
.6165 .70483 .61953 .70817 .62559 .70757 .62256 .7042 Mtetra
.581 .714 .934 r
.62256 .7042 .62559 .70757 .63167 .70689 .62864 .70348 Mtetra
.588 .715 .931 r
.62864 .70348 .63167 .70689 .63776 .70612 .63474 .70268 Mtetra
.595 .716 .928 r
.63474 .70268 .63776 .70612 .64386 .70527 .64085 .70179 Mtetra
.602 .717 .925 r
.64085 .70179 .64386 .70527 .64997 .70433 .64697 .70082 Mtetra
.608 .718 .922 r
.64697 .70082 .64997 .70433 .6561 .70331 .6531 .69977 Mtetra
.614 .718 .92 r
.6531 .69977 .6561 .70331 .66224 .7022 .65925 .69864 Mtetra
.62 .719 .917 r
.65925 .69864 .66224 .7022 .66839 .70102 .66541 .69743 Mtetra
.625 .72 .915 r
.66541 .69743 .66839 .70102 .67456 .69976 .67158 .69615 Mtetra
.63 .721 .913 r
.67158 .69615 .67456 .69976 .68073 .69842 .67777 .69479 Mtetra
.635 .722 .91 r
.67777 .69479 .68073 .69842 .68692 .69701 .68396 .69335 Mtetra
.64 .723 .908 r
.68396 .69335 .68692 .69701 .69312 .69552 .69016 .69184 Mtetra
.644 .724 .906 r
.69016 .69184 .69312 .69552 .69932 .69395 .69638 .69026 Mtetra
.649 .725 .904 r
.69638 .69026 .69932 .69395 .70554 .69231 .70261 .6886 Mtetra
.653 .726 .903 r
.70261 .6886 .70554 .69231 .71177 .69059 .70884 .68687 Mtetra
.657 .727 .901 r
.70884 .68687 .71177 .69059 .71801 .6888 .71509 .68506 Mtetra
.661 .728 .899 r
.71509 .68506 .71801 .6888 .72426 .68693 .72135 .68319 Mtetra
.665 .73 .898 r
.72135 .68319 .72426 .68693 .73051 .68499 .72761 .68124 Mtetra
.669 .731 .896 r
.72761 .68124 .73051 .68499 .73678 .68297 .73388 .67922 Mtetra
.673 .733 .895 r
.73388 .67922 .73678 .68297 .74305 .68088 .74017 .67712 Mtetra
.677 .734 .893 r
.74017 .67712 .74305 .68088 .74933 .67872 .74646 .67495 Mtetra
.681 .736 .892 r
.74646 .67495 .74933 .67872 .75562 .67647 .75275 .67271 Mtetra
.685 .737 .891 r
.75275 .67271 .75562 .67647 .76192 .67415 .75906 .67038 Mtetra
.688 .739 .89 r
.75906 .67038 .76192 .67415 .76822 .67175 .76537 .66799 Mtetra
.692 .741 .889 r
.76537 .66799 .76822 .67175 .77453 .66927 .77169 .66551 Mtetra
.696 .743 .888 r
.77169 .66551 .77453 .66927 .78084 .66671 .77801 .66296 Mtetra
.7 .745 .887 r
.77801 .66296 .78084 .66671 .78716 .66406 .78434 .66032 Mtetra
.704 .748 .886 r
.78434 .66032 .78716 .66406 .79348 .66134 .79068 .65761 Mtetra
.708 .75 .885 r
.79068 .65761 .79348 .66134 .79981 .65852 .79702 .6548 Mtetra
.712 .753 .884 r
.79702 .6548 .79981 .65852 .80614 .65562 .80336 .65192 Mtetra
.716 .755 .883 r
.80336 .65192 .80614 .65562 .81247 .65263 .8097 .64894 Mtetra
.721 .758 .882 r
.8097 .64894 .81247 .65263 .81881 .64954 .81605 .64588 Mtetra
.725 .761 .881 r
.81605 .64588 .81881 .64954 .82514 .64636 .8224 .64272 Mtetra
.729 .764 .88 r
.8224 .64272 .82514 .64636 .83148 .64308 .82875 .63946 Mtetra
.734 .767 .88 r
.82875 .63946 .83148 .64308 .83782 .6397 .8351 .63611 Mtetra
.739 .771 .879 r
.8351 .63611 .83782 .6397 .84415 .63622 .84145 .63265 Mtetra
.744 .774 .878 r
.84145 .63265 .84415 .63622 .85049 .63263 .8478 .62909 Mtetra
.749 .778 .877 r
.8478 .62909 .85049 .63263 .85682 .62893 .85415 .62542 Mtetra
.754 .782 .876 r
.85415 .62542 .85682 .62893 .86315 .62511 .86049 .62164 Mtetra
.759 .786 .875 r
.86049 .62164 .86315 .62511 .86947 .62118 .86683 .61774 Mtetra
.765 .79 .874 r
.86683 .61774 .86947 .62118 .87579 .61712 .87316 .61372 Mtetra
.77 .794 .873 r
.87316 .61372 .87579 .61712 .8821 .61294 .87949 .60958 Mtetra
.776 .799 .871 r
.87949 .60958 .8821 .61294 .8884 .60862 .88581 .60531 Mtetra
.782 .804 .87 r
.88581 .60531 .8884 .60862 .89469 .60417 .89212 .6009 Mtetra
.788 .808 .869 r
.89212 .6009 .89469 .60417 .90097 .59957 .89842 .59636 Mtetra
.795 .813 .867 r
.89842 .59636 .90097 .59957 .90724 .59483 .90471 .59167 Mtetra
.801 .819 .865 r
.90471 .59167 .90724 .59483 .9135 .58994 .91099 .58683 Mtetra
.808 .824 .863 r
.91099 .58683 .9135 .58994 .91974 .58489 .91725 .58184 Mtetra
.815 .829 .861 r
.91725 .58184 .91974 .58489 .92596 .57968 .92349 .57668 Mtetra
.822 .835 .859 r
.92349 .57668 .92596 .57968 .93217 .57429 .92972 .57136 Mtetra
.829 .84 .856 r
.92972 .57136 .93217 .57429 .93835 .56873 .93593 .56587 Mtetra
.837 .846 .853 r
.93593 .56587 .93835 .56873 .94451 .56298 .94211 .56019 Mtetra
.844 .852 .85 r
.94211 .56019 .94451 .56298 .95065 .55705 .94828 .55432 Mtetra
.852 .858 .846 r
.94828 .55432 .95065 .55705 .95676 .55092 .95441 .54826 Mtetra
.86 .864 .842 r
.95441 .54826 .95676 .55092 .96285 .54458 .96052 .542 Mtetra
.868 .87 .837 r
.96052 .542 .96285 .54458 .9689 .53803 .9666 .53553 Mtetra
.8 .329 .11 r
.37247 .6057 .37578 .60618 .38072 .61247 .37741 .6119 Mtetra
.79 .308 .078 r
.37741 .6119 .38072 .61247 .3857 .61851 .3824 .61784 Mtetra
.778 .285 .045 r
.3824 .61784 .3857 .61851 .39073 .62429 .38743 .62354 Mtetra
.764 .26 .008 r
.38743 .62354 .39073 .62429 .3958 .62984 .39251 .62899 Mtetra
.748 .233 0 r
.39251 .62899 .3958 .62984 .40091 .63514 .39762 .6342 Mtetra
.728 .202 0 r
.39762 .6342 .40091 .63514 .40605 .64021 .40278 .63918 Mtetra
.706 .169 0 r
.40278 .63918 .40605 .64021 .41124 .64505 .40797 .64393 Mtetra
.68 .133 0 r
.40797 .64393 .41124 .64505 .41647 .64967 .4132 .64846 Mtetra
.651 .093 0 r
.4132 .64846 .41647 .64967 .42173 .65407 .41847 .65278 Mtetra
.617 .051 0 r
.41847 .65278 .42173 .65407 .42702 .65825 .42377 .65687 Mtetra
.578 .005 0 r
.42377 .65687 .42702 .65825 .43235 .66222 .42911 .66076 Mtetra
.534 0 0 r
.42911 .66076 .43235 .66222 .43772 .66599 .43448 .66445 Mtetra
.486 0 0 r
.43448 .66445 .43772 .66599 .44312 .66956 .43988 .66794 Mtetra
.433 0 0 r
.43988 .66794 .44312 .66956 .44855 .67294 .44532 .67123 Mtetra
.377 0 0 r
.44532 .67123 .44855 .67294 .45401 .67612 .45078 .67434 Mtetra
0 .249 .641 r
.45078 .67434 .45401 .67612 .45949 .67912 .45628 .67726 Mtetra
0 .3 .695 r
.45628 .67726 .45949 .67912 .46501 .68194 .46181 .68 Mtetra
0 .348 .745 r
.46181 .68 .46501 .68194 .47056 .68458 .46736 .68257 Mtetra
0 .394 .789 r
.46736 .68257 .47056 .68458 .47614 .68705 .47294 .68496 Mtetra
0 .435 .828 r
.47294 .68496 .47614 .68705 .48174 .68935 .47855 .68719 Mtetra
0 .473 .861 r
.47855 .68719 .48174 .68935 .48736 .69148 .48418 .68926 Mtetra
.046 .507 .888 r
.48418 .68926 .48736 .69148 .49302 .69346 .48984 .69117 Mtetra
.099 .537 .911 r
.48984 .69117 .49302 .69346 .49869 .69529 .49552 .69293 Mtetra
.148 .563 .928 r
.49552 .69293 .49869 .69529 .50439 .69696 .50123 .69453 Mtetra
.193 .586 .942 r
.50123 .69453 .50439 .69696 .51012 .69848 .50696 .69599 Mtetra
.234 .605 .952 r
.50696 .69599 .51012 .69848 .51586 .69987 .51271 .69731 Mtetra
.272 .622 .96 r
.51271 .69731 .51586 .69987 .52163 .70111 .51849 .69849 Mtetra
.306 .636 .965 r
.51849 .69849 .52163 .70111 .52742 .70222 .52428 .69954 Mtetra
.337 .648 .968 r
.52428 .69954 .52742 .70222 .53323 .70319 .5301 .70046 Mtetra
.365 .658 .969 r
.5301 .70046 .53323 .70319 .53906 .70404 .53594 .70125 Mtetra
.391 .667 .969 r
.53594 .70125 .53906 .70404 .54491 .70477 .54179 .70191 Mtetra
.414 .674 .969 r
.54179 .70191 .54491 .70477 .55078 .70537 .54767 .70246 Mtetra
.435 .681 .967 r
.54767 .70246 .55078 .70537 .55667 .70585 .55356 .70289 Mtetra
.455 .686 .965 r
.55356 .70289 .55667 .70585 .56258 .70622 .55948 .70321 Mtetra
.472 .69 .962 r
.55948 .70321 .56258 .70622 .56851 .70648 .56541 .70341 Mtetra
.488 .694 .959 r
.56541 .70341 .56851 .70648 .57445 .70662 .57136 .70351 Mtetra
.502 .697 .956 r
.57136 .70351 .57445 .70662 .58041 .70666 .57732 .70351 Mtetra
.516 .7 .953 r
.57732 .70351 .58041 .70666 .58638 .7066 .5833 .7034 Mtetra
.528 .702 .95 r
.5833 .7034 .58638 .7066 .59237 .70644 .5893 .70319 Mtetra
.539 .704 .947 r
.5893 .70319 .59237 .70644 .59838 .70618 .59531 .70289 Mtetra
.55 .706 .943 r
.59531 .70289 .59838 .70618 .6044 .70582 .60134 .70249 Mtetra
.559 .708 .94 r
.60134 .70249 .6044 .70582 .61044 .70537 .60739 .702 Mtetra
.568 .709 .937 r
.60739 .702 .61044 .70537 .6165 .70483 .61345 .70142 Mtetra
.577 .71 .934 r
.61345 .70142 .6165 .70483 .62256 .7042 .61952 .70075 Mtetra
.584 .711 .931 r
.61952 .70075 .62256 .7042 .62864 .70348 .62561 .7 Mtetra
.592 .712 .928 r
.62561 .7 .62864 .70348 .63474 .70268 .63171 .69916 Mtetra
.598 .713 .925 r
.63171 .69916 .63474 .70268 .64085 .70179 .63783 .69824 Mtetra
.605 .714 .922 r
.63783 .69824 .64085 .70179 .64697 .70082 .64396 .69724 Mtetra
.611 .715 .919 r
.64396 .69724 .64697 .70082 .6531 .69977 .6501 .69616 Mtetra
.616 .716 .917 r
.6501 .69616 .6531 .69977 .65925 .69864 .65625 .69501 Mtetra
.622 .717 .914 r
.65625 .69501 .65925 .69864 .66541 .69743 .66242 .69377 Mtetra
.627 .718 .912 r
.66242 .69377 .66541 .69743 .67158 .69615 .6686 .69247 Mtetra
.632 .719 .91 r
.6686 .69247 .67158 .69615 .67777 .69479 .67479 .69108 Mtetra
.636 .719 .908 r
.67479 .69108 .67777 .69479 .68396 .69335 .68099 .68963 Mtetra
.641 .72 .906 r
.68099 .68963 .68396 .69335 .69016 .69184 .6872 .6881 Mtetra
.645 .721 .904 r
.6872 .6881 .69016 .69184 .69638 .69026 .69342 .6865 Mtetra
.65 .722 .902 r
.69342 .6865 .69638 .69026 .70261 .6886 .69966 .68483 Mtetra
.654 .723 .9 r
.69966 .68483 .70261 .6886 .70884 .68687 .7059 .68308 Mtetra
.658 .724 .898 r
.7059 .68308 .70884 .68687 .71509 .68506 .71216 .68127 Mtetra
.661 .726 .897 r
.71216 .68127 .71509 .68506 .72135 .68319 .71842 .67938 Mtetra
.665 .727 .895 r
.71842 .67938 .72135 .68319 .72761 .68124 .72469 .67742 Mtetra
.669 .728 .894 r
.72469 .67742 .72761 .68124 .73388 .67922 .73098 .67539 Mtetra
.673 .73 .892 r
.73098 .67539 .73388 .67922 .74017 .67712 .73727 .67329 Mtetra
.677 .731 .891 r
.73727 .67329 .74017 .67712 .74646 .67495 .74357 .67112 Mtetra
.68 .733 .89 r
.74357 .67112 .74646 .67495 .75275 .67271 .74987 .66887 Mtetra
.684 .734 .889 r
.74987 .66887 .75275 .67271 .75906 .67038 .75619 .66655 Mtetra
.688 .736 .888 r
.75619 .66655 .75906 .67038 .76537 .66799 .76251 .66416 Mtetra
.691 .738 .887 r
.76251 .66416 .76537 .66799 .77169 .66551 .76884 .66169 Mtetra
.695 .74 .886 r
.76884 .66169 .77169 .66551 .77801 .66296 .77517 .65914 Mtetra
.699 .742 .885 r
.77517 .65914 .77801 .66296 .78434 .66032 .78151 .65651 Mtetra
.703 .744 .884 r
.78151 .65651 .78434 .66032 .79068 .65761 .78786 .6538 Mtetra
.707 .747 .883 r
.78786 .6538 .79068 .65761 .79702 .6548 .79421 .65102 Mtetra
.711 .749 .882 r
.79421 .65102 .79702 .6548 .80336 .65192 .80056 .64814 Mtetra
.715 .752 .881 r
.80056 .64814 .80336 .65192 .8097 .64894 .80692 .64518 Mtetra
.719 .754 .88 r
.80692 .64518 .8097 .64894 .81605 .64588 .81328 .64213 Mtetra
.723 .757 .88 r
.81328 .64213 .81605 .64588 .8224 .64272 .81964 .639 Mtetra
.727 .76 .879 r
.81964 .639 .8224 .64272 .82875 .63946 .826 .63576 Mtetra
.732 .763 .878 r
.826 .63576 .82875 .63946 .8351 .63611 .83237 .63243 Mtetra
.736 .767 .877 r
.83237 .63243 .8351 .63611 .84145 .63265 .83873 .629 Mtetra
.741 .77 .876 r
.83873 .629 .84145 .63265 .8478 .62909 .8451 .62547 Mtetra
.746 .774 .875 r
.8451 .62547 .8478 .62909 .85415 .62542 .85146 .62183 Mtetra
.751 .777 .874 r
.85146 .62183 .85415 .62542 .86049 .62164 .85782 .61809 Mtetra
.756 .781 .873 r
.85782 .61809 .86049 .62164 .86683 .61774 .86417 .61422 Mtetra
.762 .785 .872 r
.86417 .61422 .86683 .61774 .87316 .61372 .87052 .61024 Mtetra
.767 .789 .871 r
.87052 .61024 .87316 .61372 .87949 .60958 .87687 .60614 Mtetra
.773 .794 .87 r
.87687 .60614 .87949 .60958 .88581 .60531 .8832 .60191 Mtetra
.779 .798 .869 r
.8832 .60191 .88581 .60531 .89212 .6009 .88953 .59755 Mtetra
.785 .803 .867 r
.88953 .59755 .89212 .6009 .89842 .59636 .89585 .59305 Mtetra
.791 .808 .866 r
.89585 .59305 .89842 .59636 .90471 .59167 .90216 .58841 Mtetra
.797 .813 .864 r
.90216 .58841 .90471 .59167 .91099 .58683 .90845 .58363 Mtetra
.804 .818 .862 r
.90845 .58363 .91099 .58683 .91725 .58184 .91474 .57869 Mtetra
.811 .823 .86 r
.91474 .57869 .91725 .58184 .92349 .57668 .921 .57359 Mtetra
.818 .829 .858 r
.921 .57359 .92349 .57668 .92972 .57136 .92725 .56833 Mtetra
.825 .834 .855 r
.92725 .56833 .92972 .57136 .93593 .56587 .93348 .56289 Mtetra
.832 .84 .853 r
.93348 .56289 .93593 .56587 .94211 .56019 .93969 .55728 Mtetra
.84 .846 .849 r
.93969 .55728 .94211 .56019 .94828 .55432 .94588 .55149 Mtetra
.847 .851 .846 r
.94588 .55149 .94828 .55432 .95441 .54826 .95204 .5455 Mtetra
.855 .857 .842 r
.95204 .5455 .95441 .54826 .96052 .542 .95817 .53931 Mtetra
.863 .863 .838 r
.95817 .53931 .96052 .542 .9666 .53553 .96428 .53291 Mtetra
.796 .319 .089 r
.36914 .60509 .37247 .6057 .37741 .6119 .37409 .61119 Mtetra
.785 .297 .056 r
.37409 .61119 .37741 .6119 .3824 .61784 .37909 .61705 Mtetra
.772 .273 .02 r
.37909 .61705 .3824 .61784 .38743 .62354 .38412 .62265 Mtetra
.756 .246 0 r
.38412 .62265 .38743 .62354 .39251 .62899 .3892 .62801 Mtetra
.738 .217 0 r
.3892 .62801 .39251 .62899 .39762 .6342 .39433 .63314 Mtetra
.717 .185 0 r
.39433 .63314 .39762 .6342 .40278 .63918 .39949 .63803 Mtetra
.693 .149 0 r
.39949 .63803 .40278 .63918 .40797 .64393 .40469 .6427 Mtetra
.664 .111 0 r
.40469 .6427 .40797 .64393 .4132 .64846 .40992 .64714 Mtetra
.632 .07 0 r
.40992 .64714 .4132 .64846 .41847 .65278 .4152 .65137 Mtetra
.594 .025 0 r
.4152 .65137 .41847 .65278 .42377 .65687 .42051 .65539 Mtetra
.552 0 0 r
.42051 .65539 .42377 .65687 .42911 .66076 .42585 .6592 Mtetra
.506 0 0 r
.42585 .6592 .42911 .66076 .43448 .66445 .43123 .6628 Mtetra
.454 0 0 r
.43123 .6628 .43448 .66445 .43988 .66794 .43664 .66621 Mtetra
.399 0 0 r
.43664 .66621 .43988 .66794 .44532 .67123 .44208 .66943 Mtetra
0 .227 .621 r
.44208 .66943 .44532 .67123 .45078 .67434 .44755 .67246 Mtetra
0 .278 .677 r
.44755 .67246 .45078 .67434 .45628 .67726 .45305 .6753 Mtetra
0 .328 .728 r
.45305 .6753 .45628 .67726 .46181 .68 .45858 .67797 Mtetra
0 .374 .774 r
.45858 .67797 .46181 .68 .46736 .68257 .46414 .68047 Mtetra
0 .417 .815 r
.46414 .68047 .46736 .68257 .47294 .68496 .46973 .68279 Mtetra
0 .457 .849 r
.46973 .68279 .47294 .68496 .47855 .68719 .47534 .68495 Mtetra
.026 .492 .879 r
.47534 .68495 .47855 .68719 .48418 .68926 .48098 .68695 Mtetra
.08 .523 .903 r
.48098 .68695 .48418 .68926 .48984 .69117 .48665 .68879 Mtetra
.13 .551 .922 r
.48665 .68879 .48984 .69117 .49552 .69293 .49234 .69048 Mtetra
.176 .575 .937 r
.49234 .69048 .49552 .69293 .50123 .69453 .49805 .69202 Mtetra
.219 .595 .948 r
.49805 .69202 .50123 .69453 .50696 .69599 .50379 .69342 Mtetra
.258 .613 .956 r
.50379 .69342 .50696 .69599 .51271 .69731 .50955 .69467 Mtetra
.293 .628 .962 r
.50955 .69467 .51271 .69731 .51849 .69849 .51533 .69579 Mtetra
.326 .641 .966 r
.51533 .69579 .51849 .69849 .52428 .69954 .52113 .69678 Mtetra
.355 .652 .968 r
.52113 .69678 .52428 .69954 .5301 .70046 .52695 .69764 Mtetra
.381 .661 .968 r
.52695 .69764 .5301 .70046 .53594 .70125 .53279 .69837 Mtetra
.405 .669 .968 r
.53279 .69837 .53594 .70125 .54179 .70191 .53866 .69899 Mtetra
.427 .675 .966 r
.53866 .69899 .54179 .70191 .54767 .70246 .54454 .69948 Mtetra
.447 .681 .964 r
.54454 .69948 .54767 .70246 .55356 .70289 .55044 .69986 Mtetra
.465 .686 .962 r
.55044 .69986 .55356 .70289 .55948 .70321 .55636 .70012 Mtetra
.481 .69 .959 r
.55636 .70012 .55948 .70321 .56541 .70341 .5623 .70028 Mtetra
.496 .693 .956 r
.5623 .70028 .56541 .70341 .57136 .70351 .56825 .70033 Mtetra
.51 .696 .953 r
.56825 .70033 .57136 .70351 .57732 .70351 .57422 .70028 Mtetra
.523 .699 .95 r
.57422 .70028 .57732 .70351 .5833 .7034 .58021 .70013 Mtetra
.534 .701 .946 r
.58021 .70013 .5833 .7034 .5893 .70319 .58622 .69988 Mtetra
.545 .703 .943 r
.58622 .69988 .5893 .70319 .59531 .70289 .59224 .69953 Mtetra
.555 .705 .94 r
.59224 .69953 .59531 .70289 .60134 .70249 .59827 .69909 Mtetra
.564 .706 .937 r
.59827 .69909 .60134 .70249 .60739 .702 .60432 .69856 Mtetra
.572 .707 .933 r
.60432 .69856 .60739 .702 .61345 .70142 .61039 .69795 Mtetra
.58 .708 .93 r
.61039 .69795 .61345 .70142 .61952 .70075 .61647 .69724 Mtetra
.588 .709 .927 r
.61647 .69724 .61952 .70075 .62561 .7 .62256 .69645 Mtetra
.595 .71 .924 r
.62256 .69645 .62561 .7 .63171 .69916 .62867 .69558 Mtetra
.601 .711 .922 r
.62867 .69558 .63171 .69916 .63783 .69824 .63479 .69463 Mtetra
.607 .712 .919 r
.63479 .69463 .63783 .69824 .64396 .69724 .64093 .6936 Mtetra
.613 .713 .916 r
.64093 .6936 .64396 .69724 .6501 .69616 .64708 .6925 Mtetra
.618 .714 .914 r
.64708 .6925 .6501 .69616 .65625 .69501 .65324 .69131 Mtetra
.623 .715 .912 r
.65324 .69131 .65625 .69501 .66242 .69377 .65941 .69006 Mtetra
.628 .715 .909 r
.65941 .69006 .66242 .69377 .6686 .69247 .6656 .68873 Mtetra
.633 .716 .907 r
.6656 .68873 .6686 .69247 .67479 .69108 .67179 .68732 Mtetra
.638 .717 .905 r
.67179 .68732 .67479 .69108 .68099 .68963 .678 .68584 Mtetra
.642 .718 .903 r
.678 .68584 .68099 .68963 .6872 .6881 .68422 .6843 Mtetra
.646 .719 .901 r
.68422 .6843 .6872 .6881 .69342 .6865 .69045 .68268 Mtetra
.65 .72 .899 r
.69045 .68268 .69342 .6865 .69966 .68483 .6967 .68099 Mtetra
.654 .721 .898 r
.6967 .68099 .69966 .68483 .7059 .68308 .70295 .67923 Mtetra
.658 .722 .896 r
.70295 .67923 .7059 .68308 .71216 .68127 .70921 .67741 Mtetra
.662 .723 .895 r
.70921 .67741 .71216 .68127 .71842 .67938 .71548 .67551 Mtetra
.665 .724 .893 r
.71548 .67551 .71842 .67938 .72469 .67742 .72176 .67354 Mtetra
.669 .726 .892 r
.72176 .67354 .72469 .67742 .73098 .67539 .72806 .67151 Mtetra
.673 .727 .89 r
.72806 .67151 .73098 .67539 .73727 .67329 .73436 .6694 Mtetra
.676 .728 .889 r
.73436 .6694 .73727 .67329 .74357 .67112 .74066 .66722 Mtetra
.68 .73 .888 r
.74066 .66722 .74357 .67112 .74987 .66887 .74698 .66498 Mtetra
.683 .731 .887 r
.74698 .66498 .74987 .66887 .75619 .66655 .7533 .66266 Mtetra
.687 .733 .886 r
.7533 .66266 .75619 .66655 .76251 .66416 .75964 .66026 Mtetra
.69 .735 .885 r
.75964 .66026 .76251 .66416 .76884 .66169 .76597 .6578 Mtetra
.694 .737 .884 r
.76597 .6578 .76884 .66169 .77517 .65914 .77232 .65525 Mtetra
.698 .739 .883 r
.77232 .65525 .77517 .65914 .78151 .65651 .77867 .65264 Mtetra
.701 .741 .882 r
.77867 .65264 .78151 .65651 .78786 .6538 .78502 .64994 Mtetra
.705 .743 .881 r
.78502 .64994 .78786 .6538 .79421 .65102 .79139 .64716 Mtetra
.709 .746 .88 r
.79139 .64716 .79421 .65102 .80056 .64814 .79775 .6443 Mtetra
.713 .748 .88 r
.79775 .6443 .80056 .64814 .80692 .64518 .80412 .64135 Mtetra
.717 .751 .879 r
.80412 .64135 .80692 .64518 .81328 .64213 .81049 .63832 Mtetra
.721 .754 .878 r
.81049 .63832 .81328 .64213 .81964 .639 .81687 .6352 Mtetra
.725 .756 .877 r
.81687 .6352 .81964 .639 .826 .63576 .82324 .63199 Mtetra
.73 .759 .876 r
.82324 .63199 .826 .63576 .83237 .63243 .82962 .62869 Mtetra
.734 .763 .876 r
.82962 .62869 .83237 .63243 .83873 .629 .836 .62528 Mtetra
.739 .766 .875 r
.836 .62528 .83873 .629 .8451 .62547 .84238 .62178 Mtetra
.744 .769 .874 r
.84238 .62178 .8451 .62547 .85146 .62183 .84875 .61817 Mtetra
.748 .773 .873 r
.84875 .61817 .85146 .62183 .85782 .61809 .85513 .61445 Mtetra
.753 .777 .872 r
.85513 .61445 .85782 .61809 .86417 .61422 .8615 .61062 Mtetra
.759 .781 .871 r
.8615 .61062 .86417 .61422 .87052 .61024 .86786 .60668 Mtetra
.764 .785 .87 r
.86786 .60668 .87052 .61024 .87687 .60614 .87422 .60261 Mtetra
.77 .789 .869 r
.87422 .60261 .87687 .60614 .8832 .60191 .88058 .59843 Mtetra
.775 .793 .868 r
.88058 .59843 .8832 .60191 .88953 .59755 .88692 .59411 Mtetra
.781 .798 .866 r
.88692 .59411 .88953 .59755 .89585 .59305 .89326 .58966 Mtetra
.787 .803 .865 r
.89326 .58966 .89585 .59305 .90216 .58841 .89959 .58506 Mtetra
.794 .807 .863 r
.89959 .58506 .90216 .58841 .90845 .58363 .9059 .58033 Mtetra
.8 .812 .861 r
.9059 .58033 .90845 .58363 .91474 .57869 .9122 .57544 Mtetra
.807 .818 .859 r
.9122 .57544 .91474 .57869 .921 .57359 .91849 .5704 Mtetra
.814 .823 .857 r
.91849 .5704 .921 .57359 .92725 .56833 .92476 .56519 Mtetra
.821 .828 .855 r
.92476 .56519 .92725 .56833 .93348 .56289 .93101 .55982 Mtetra
.828 .834 .852 r
.93101 .55982 .93348 .56289 .93969 .55728 .93725 .55427 Mtetra
.835 .839 .849 r
.93725 .55427 .93969 .55728 .94588 .55149 .94346 .54854 Mtetra
.843 .845 .846 r
.94346 .54854 .94588 .55149 .95204 .5455 .94964 .54262 Mtetra
.85 .851 .842 r
.94964 .54262 .95204 .5455 .95817 .53931 .9558 .5365 Mtetra
.858 .857 .838 r
.9558 .5365 .95817 .53931 .96428 .53291 .96193 .53018 Mtetra
.792 .309 .068 r
.3658 .60435 .36914 .60509 .37409 .61119 .37076 .61037 Mtetra
.78 .286 .033 r
.37076 .61037 .37409 .61119 .37909 .61705 .37576 .61613 Mtetra
.765 .26 0 r
.37576 .61613 .37909 .61705 .38412 .62265 .3808 .62165 Mtetra
.748 .231 0 r
.3808 .62165 .38412 .62265 .3892 .62801 .38589 .62692 Mtetra
.728 .2 0 r
.38589 .62692 .3892 .62801 .39433 .63314 .39102 .63196 Mtetra
.705 .166 0 r
.39102 .63196 .39433 .63314 .39949 .63803 .39619 .63677 Mtetra
.678 .129 0 r
.39619 .63677 .39949 .63803 .40469 .6427 .40139 .64135 Mtetra
.647 .089 0 r
.40139 .64135 .40469 .6427 .40992 .64714 .40663 .64571 Mtetra
.611 .045 0 r
.40663 .64571 .40992 .64714 .4152 .65137 .41191 .64986 Mtetra
.571 0 0 r
.41191 .64986 .4152 .65137 .42051 .65539 .41723 .6538 Mtetra
.526 0 0 r
.41723 .6538 .42051 .65539 .42585 .6592 .42258 .65752 Mtetra
.476 0 0 r
.42258 .65752 .42585 .6592 .43123 .6628 .42796 .66105 Mtetra
.422 0 0 r
.42796 .66105 .43123 .6628 .43664 .66621 .43338 .66439 Mtetra
.364 0 0 r
.43338 .66439 .43664 .66621 .44208 .66943 .43883 .66753 Mtetra
0 .256 .657 r
.43883 .66753 .44208 .66943 .44755 .67246 .44431 .67048 Mtetra
0 .306 .71 r
.44431 .67048 .44755 .67246 .45305 .6753 .44981 .67325 Mtetra
0 .354 .758 r
.44981 .67325 .45305 .6753 .45858 .67797 .45535 .67585 Mtetra
0 .398 .8 r
.45535 .67585 .45858 .67797 .46414 .68047 .46092 .67827 Mtetra
0 .439 .837 r
.46092 .67827 .46414 .68047 .46973 .68279 .46651 .68052 Mtetra
.004 .476 .868 r
.46651 .68052 .46973 .68279 .47534 .68495 .47213 .68261 Mtetra
.059 .509 .894 r
.47213 .68261 .47534 .68495 .48098 .68695 .47778 .68455 Mtetra
.11 .538 .914 r
.47778 .68455 .48098 .68695 .48665 .68879 .48345 .68632 Mtetra
.158 .563 .931 r
.48345 .68632 .48665 .68879 .49234 .69048 .48914 .68795 Mtetra
.202 .585 .943 r
.48914 .68795 .49234 .69048 .49805 .69202 .49486 .68942 Mtetra
.243 .603 .952 r
.49486 .68942 .49805 .69202 .50379 .69342 .5006 .69076 Mtetra
.279 .619 .959 r
.5006 .69076 .50379 .69342 .50955 .69467 .50637 .69196 Mtetra
.313 .633 .963 r
.50637 .69196 .50955 .69467 .51533 .69579 .51215 .69302 Mtetra
.343 .645 .966 r
.51215 .69302 .51533 .69579 .52113 .69678 .51796 .69395 Mtetra
.37 .655 .967 r
.51796 .69395 .52113 .69678 .52695 .69764 .52379 .69475 Mtetra
.395 .663 .967 r
.52379 .69475 .52695 .69764 .53279 .69837 .52964 .69543 Mtetra
.418 .67 .966 r
.52964 .69543 .53279 .69837 .53866 .69899 .53551 .69599 Mtetra
.439 .676 .964 r
.53551 .69599 .53866 .69899 .54454 .69948 .5414 .69643 Mtetra
.457 .681 .962 r
.5414 .69643 .54454 .69948 .55044 .69986 .54731 .69675 Mtetra
.474 .686 .959 r
.54731 .69675 .55044 .69986 .55636 .70012 .55323 .69697 Mtetra
.49 .69 .956 r
.55323 .69697 .55636 .70012 .5623 .70028 .55917 .69708 Mtetra
.504 .693 .953 r
.55917 .69708 .5623 .70028 .56825 .70033 .56513 .69708 Mtetra
.517 .696 .95 r
.56513 .69708 .56825 .70033 .57422 .70028 .57111 .69699 Mtetra
.529 .698 .947 r
.57111 .69699 .57422 .70028 .58021 .70013 .57711 .69679 Mtetra
.54 .7 .943 r
.57711 .69679 .58021 .70013 .58622 .69988 .58312 .6965 Mtetra
.55 .702 .94 r
.58312 .6965 .58622 .69988 .59224 .69953 .58914 .69611 Mtetra
.559 .703 .937 r
.58914 .69611 .59224 .69953 .59827 .69909 .59519 .69563 Mtetra
.568 .705 .934 r
.59519 .69563 .59827 .69909 .60432 .69856 .60124 .69506 Mtetra
.576 .706 .93 r
.60124 .69506 .60432 .69856 .61039 .69795 .60731 .69441 Mtetra
.584 .707 .927 r
.60731 .69441 .61039 .69795 .61647 .69724 .6134 .69367 Mtetra
.591 .708 .925 r
.6134 .69367 .61647 .69724 .62256 .69645 .6195 .69285 Mtetra
.597 .709 .922 r
.6195 .69285 .62256 .69645 .62867 .69558 .62562 .69195 Mtetra
.604 .71 .919 r
.62562 .69195 .62867 .69558 .63479 .69463 .63175 .69097 Mtetra
.609 .71 .916 r
.63175 .69097 .63479 .69463 .64093 .6936 .63789 .68991 Mtetra
.615 .711 .914 r
.63789 .68991 .64093 .6936 .64708 .6925 .64404 .68877 Mtetra
.62 .712 .911 r
.64404 .68877 .64708 .6925 .65324 .69131 .65021 .68756 Mtetra
.625 .713 .909 r
.65021 .68756 .65324 .69131 .65941 .69006 .65639 .68628 Mtetra
.63 .713 .907 r
.65639 .68628 .65941 .69006 .6656 .68873 .66258 .68493 Mtetra
.634 .714 .905 r
.66258 .68493 .6656 .68873 .67179 .68732 .66879 .6835 Mtetra
.639 .715 .903 r
.66879 .6835 .67179 .68732 .678 .68584 .675 .68201 Mtetra
.643 .716 .901 r
.675 .68201 .678 .68584 .68422 .6843 .68123 .68044 Mtetra
.647 .717 .899 r
.68123 .68044 .68422 .6843 .69045 .68268 .68747 .6788 Mtetra
.651 .718 .897 r
.68747 .6788 .69045 .68268 .6967 .68099 .69372 .6771 Mtetra
.654 .719 .896 r
.69372 .6771 .6967 .68099 .70295 .67923 .69998 .67533 Mtetra
.658 .72 .894 r
.69998 .67533 .70295 .67923 .70921 .67741 .70625 .67349 Mtetra
.662 .721 .893 r
.70625 .67349 .70921 .67741 .71548 .67551 .71253 .67158 Mtetra
.665 .722 .891 r
.71253 .67158 .71548 .67551 .72176 .67354 .71882 .66961 Mtetra
.669 .723 .89 r
.71882 .66961 .72176 .67354 .72806 .67151 .72512 .66757 Mtetra
.672 .725 .889 r
.72512 .66757 .72806 .67151 .73436 .6694 .73143 .66545 Mtetra
.676 .726 .887 r
.73143 .66545 .73436 .6694 .74066 .66722 .73775 .66327 Mtetra
.679 .727 .886 r
.73775 .66327 .74066 .66722 .74698 .66498 .74407 .66102 Mtetra
.683 .729 .885 r
.74407 .66102 .74698 .66498 .7533 .66266 .75041 .6587 Mtetra
.686 .731 .884 r
.75041 .6587 .7533 .66266 .75964 .66026 .75675 .65631 Mtetra
.69 .732 .883 r
.75675 .65631 .75964 .66026 .76597 .6578 .76309 .65385 Mtetra
.693 .734 .882 r
.76309 .65385 .76597 .6578 .77232 .65525 .76945 .65131 Mtetra
.697 .736 .881 r
.76945 .65131 .77232 .65525 .77867 .65264 .77581 .6487 Mtetra
.7 .738 .881 r
.77581 .6487 .77867 .65264 .78502 .64994 .78218 .64601 Mtetra
.704 .74 .88 r
.78218 .64601 .78502 .64994 .79139 .64716 .78855 .64324 Mtetra
.708 .743 .879 r
.78855 .64324 .79139 .64716 .79775 .6443 .79493 .64039 Mtetra
.711 .745 .878 r
.79493 .64039 .79775 .6443 .80412 .64135 .80131 .63746 Mtetra
.715 .748 .877 r
.80131 .63746 .80412 .64135 .81049 .63832 .80769 .63445 Mtetra
.719 .75 .877 r
.80769 .63445 .81049 .63832 .81687 .6352 .81408 .63135 Mtetra
.724 .753 .876 r
.81408 .63135 .81687 .6352 .82324 .63199 .82047 .62816 Mtetra
.728 .756 .875 r
.82047 .62816 .82324 .63199 .82962 .62869 .82686 .62487 Mtetra
.732 .759 .874 r
.82686 .62487 .82962 .62869 .836 .62528 .83325 .62149 Mtetra
.737 .762 .873 r
.83325 .62149 .836 .62528 .84238 .62178 .83964 .61801 Mtetra
.741 .766 .873 r
.83964 .61801 .84238 .62178 .84875 .61817 .84603 .61443 Mtetra
.746 .769 .872 r
.84603 .61443 .84875 .61817 .85513 .61445 .85242 .61075 Mtetra
.751 .773 .871 r
.85242 .61075 .85513 .61445 .8615 .61062 .8588 .60695 Mtetra
.756 .777 .87 r
.8588 .60695 .8615 .61062 .86786 .60668 .86519 .60304 Mtetra
.761 .78 .869 r
.86519 .60304 .86786 .60668 .87422 .60261 .87156 .59901 Mtetra
.767 .785 .868 r
.87156 .59901 .87422 .60261 .88058 .59843 .87793 .59486 Mtetra
.772 .789 .867 r
.87793 .59486 .88058 .59843 .88692 .59411 .8843 .59059 Mtetra
.778 .793 .865 r
.8843 .59059 .88692 .59411 .89326 .58966 .89065 .58618 Mtetra
.784 .798 .864 r
.89065 .58618 .89326 .58966 .89959 .58506 .897 .58163 Mtetra
.79 .803 .862 r
.897 .58163 .89959 .58506 .9059 .58033 .90333 .57694 Mtetra
.796 .807 .861 r
.90333 .57694 .9059 .58033 .9122 .57544 .90965 .57211 Mtetra
.803 .812 .859 r
.90965 .57211 .9122 .57544 .91849 .5704 .91596 .56712 Mtetra
.81 .817 .857 r
.91596 .56712 .91849 .5704 .92476 .56519 .92225 .56197 Mtetra
.817 .823 .854 r
.92225 .56197 .92476 .56519 .93101 .55982 .92852 .55665 Mtetra
.824 .828 .852 r
.92852 .55665 .93101 .55982 .93725 .55427 .93478 .55116 Mtetra
.831 .834 .849 r
.93478 .55116 .93725 .55427 .94346 .54854 .94101 .5455 Mtetra
.838 .839 .846 r
.94101 .5455 .94346 .54854 .94964 .54262 .94722 .53964 Mtetra
.846 .845 .843 r
.94722 .53964 .94964 .54262 .9558 .5365 .95341 .53359 Mtetra
.854 .851 .839 r
.95341 .53359 .9558 .5365 .96193 .53018 .95956 .52734 Mtetra
.788 .298 .047 r
.36246 .60349 .3658 .60435 .37076 .61037 .36742 .60942 Mtetra
.774 .273 .01 r
.36742 .60942 .37076 .61037 .37576 .61613 .37242 .61509 Mtetra
.758 .246 0 r
.37242 .61509 .37576 .61613 .3808 .62165 .37747 .62053 Mtetra
.739 .216 0 r
.37747 .62053 .3808 .62165 .38589 .62692 .38257 .62572 Mtetra
.717 .183 0 r
.38257 .62572 .38589 .62692 .39102 .63196 .3877 .63067 Mtetra
.691 .147 0 r
.3877 .63067 .39102 .63196 .39619 .63677 .39287 .6354 Mtetra
.662 .108 0 r
.39287 .6354 .39619 .63677 .40139 .64135 .39808 .6399 Mtetra
.628 .066 0 r
.39808 .6399 .40139 .64135 .40663 .64571 .40333 .64418 Mtetra
.589 .021 0 r
.40333 .64418 .40663 .64571 .41191 .64986 .40862 .64825 Mtetra
.546 0 0 r
.40862 .64825 .41191 .64986 .41723 .6538 .41394 .6521 Mtetra
.498 0 0 r
.41394 .6521 .41723 .6538 .42258 .65752 .4193 .65575 Mtetra
.445 0 0 r
.4193 .65575 .42258 .65752 .42796 .66105 .42469 .65921 Mtetra
.388 0 0 r
.42469 .65921 .42796 .66105 .43338 .66439 .43011 .66246 Mtetra
0 .232 .636 r
.43011 .66246 .43338 .66439 .43883 .66753 .43556 .66553 Mtetra
0 .283 .69 r
.43556 .66553 .43883 .66753 .44431 .67048 .44105 .66841 Mtetra
0 .332 .739 r
.44105 .66841 .44431 .67048 .44981 .67325 .44656 .67111 Mtetra
0 .378 .784 r
.44656 .67111 .44981 .67325 .45535 .67585 .45211 .67364 Mtetra
0 .42 .823 r
.45211 .67364 .45535 .67585 .46092 .67827 .45768 .67599 Mtetra
0 .458 .856 r
.45768 .67599 .46092 .67827 .46651 .68052 .46328 .67817 Mtetra
.036 .493 .883 r
.46328 .67817 .46651 .68052 .47213 .68261 .4689 .6802 Mtetra
.089 .523 .906 r
.4689 .6802 .47213 .68261 .47778 .68455 .47455 .68206 Mtetra
.139 .55 .924 r
.47455 .68206 .47778 .68455 .48345 .68632 .48023 .68378 Mtetra
.184 .573 .938 r
.48023 .68378 .48345 .68632 .48914 .68795 .48593 .68534 Mtetra
.226 .593 .948 r
.48593 .68534 .48914 .68795 .49486 .68942 .49166 .68675 Mtetra
.264 .61 .956 r
.49166 .68675 .49486 .68942 .5006 .69076 .49741 .68803 Mtetra
.299 .625 .961 r
.49741 .68803 .5006 .69076 .50637 .69196 .50318 .68916 Mtetra
.33 .638 .964 r
.50318 .68916 .50637 .69196 .51215 .69302 .50897 .69017 Mtetra
.359 .648 .965 r
.50897 .69017 .51215 .69302 .51796 .69395 .51478 .69104 Mtetra
.385 .657 .966 r
.51478 .69104 .51796 .69395 .52379 .69475 .52062 .69179 Mtetra
.408 .665 .965 r
.52062 .69179 .52379 .69475 .52964 .69543 .52647 .69241 Mtetra
.429 .672 .964 r
.52647 .69241 .52964 .69543 .53551 .69599 .53235 .69292 Mtetra
.449 .677 .962 r
.53235 .69292 .53551 .69599 .5414 .69643 .53824 .69331 Mtetra
.467 .682 .959 r
.53824 .69331 .5414 .69643 .54731 .69675 .54416 .69359 Mtetra
.483 .686 .956 r
.54416 .69359 .54731 .69675 .55323 .69697 .55009 .69375 Mtetra
.497 .689 .953 r
.55009 .69375 .55323 .69697 .55917 .69708 .55604 .69381 Mtetra
.511 .692 .95 r
.55604 .69381 .55917 .69708 .56513 .69708 .562 .69377 Mtetra
.523 .695 .947 r
.562 .69377 .56513 .69708 .57111 .69699 .56799 .69363 Mtetra
.535 .697 .944 r
.56799 .69363 .57111 .69699 .57711 .69679 .57399 .69339 Mtetra
.545 .699 .94 r
.57399 .69339 .57711 .69679 .58312 .6965 .58001 .69306 Mtetra
.555 .701 .937 r
.58001 .69306 .58312 .6965 .58914 .69611 .58604 .69263 Mtetra
.564 .702 .934 r
.58604 .69263 .58914 .69611 .59519 .69563 .59209 .69211 Mtetra
.572 .703 .931 r
.59209 .69211 .59519 .69563 .60124 .69506 .59815 .69151 Mtetra
.58 .704 .928 r
.59815 .69151 .60124 .69506 .60731 .69441 .60423 .69082 Mtetra
.587 .705 .925 r
.60423 .69082 .60731 .69441 .6134 .69367 .61032 .69005 Mtetra
.594 .706 .922 r
.61032 .69005 .6134 .69367 .6195 .69285 .61643 .68919 Mtetra
.6 .707 .919 r
.61643 .68919 .6195 .69285 .62562 .69195 .62255 .68826 Mtetra
.606 .708 .917 r
.62255 .68826 .62562 .69195 .63175 .69097 .62869 .68725 Mtetra
.611 .709 .914 r
.62869 .68725 .63175 .69097 .63789 .68991 .63484 .68616 Mtetra
.617 .71 .912 r
.63484 .68616 .63789 .68991 .64404 .68877 .641 .685 Mtetra
.622 .71 .909 r
.641 .685 .64404 .68877 .65021 .68756 .64717 .68376 Mtetra
.626 .711 .907 r
.64717 .68376 .65021 .68756 .65639 .68628 .65336 .68246 Mtetra
.631 .712 .905 r
.65336 .68246 .65639 .68628 .66258 .68493 .65956 .68108 Mtetra
.635 .713 .903 r
.65956 .68108 .66258 .68493 .66879 .6835 .66577 .67963 Mtetra
.639 .713 .901 r
.66577 .67963 .66879 .6835 .675 .68201 .67199 .67812 Mtetra
.644 .714 .899 r
.67199 .67812 .675 .68201 .68123 .68044 .67823 .67653 Mtetra
.647 .715 .897 r
.67823 .67653 .68123 .68044 .68747 .6788 .68448 .67488 Mtetra
.651 .716 .896 r
.68448 .67488 .68747 .6788 .69372 .6771 .69073 .67316 Mtetra
.655 .717 .894 r
.69073 .67316 .69372 .6771 .69998 .67533 .697 .67138 Mtetra
.658 .718 .892 r
.697 .67138 .69998 .67533 .70625 .67349 .70328 .66953 Mtetra
.662 .719 .891 r
.70328 .66953 .70625 .67349 .71253 .67158 .70957 .66761 Mtetra
.665 .72 .89 r
.70957 .66761 .71253 .67158 .71882 .66961 .71587 .66562 Mtetra
.669 .721 .888 r
.71587 .66562 .71882 .66961 .72512 .66757 .72217 .66357 Mtetra
.672 .723 .887 r
.72217 .66357 .72512 .66757 .73143 .66545 .72849 .66146 Mtetra
.675 .724 .886 r
.72849 .66146 .73143 .66545 .73775 .66327 .73482 .65927 Mtetra
.679 .725 .885 r
.73482 .65927 .73775 .66327 .74407 .66102 .74115 .65702 Mtetra
.682 .727 .884 r
.74115 .65702 .74407 .66102 .75041 .6587 .74749 .6547 Mtetra
.685 .728 .883 r
.74749 .6547 .75041 .6587 .75675 .65631 .75384 .65231 Mtetra
.689 .73 .882 r
.75384 .65231 .75675 .65631 .76309 .65385 .7602 .64985 Mtetra
.692 .732 .881 r
.7602 .64985 .76309 .65385 .76945 .65131 .76657 .64731 Mtetra
.696 .734 .88 r
.76657 .64731 .76945 .65131 .77581 .6487 .77294 .64471 Mtetra
.699 .736 .879 r
.77294 .64471 .77581 .6487 .78218 .64601 .77932 .64203 Mtetra
.703 .738 .878 r
.77932 .64203 .78218 .64601 .78855 .64324 .7857 .63927 Mtetra
.706 .74 .878 r
.7857 .63927 .78855 .64324 .79493 .64039 .79209 .63643 Mtetra
.71 .742 .877 r
.79209 .63643 .79493 .64039 .80131 .63746 .79848 .63352 Mtetra
.714 .745 .876 r
.79848 .63352 .80131 .63746 .80769 .63445 .80487 .63052 Mtetra
.718 .747 .875 r
.80487 .63052 .80769 .63445 .81408 .63135 .81127 .62743 Mtetra
.722 .75 .875 r
.81127 .62743 .81408 .63135 .82047 .62816 .81768 .62426 Mtetra
.726 .753 .874 r
.81768 .62426 .82047 .62816 .82686 .62487 .82408 .62099 Mtetra
.73 .756 .873 r
.82408 .62099 .82686 .62487 .83325 .62149 .83048 .61764 Mtetra
.734 .759 .872 r
.83048 .61764 .83325 .62149 .83964 .61801 .83689 .61418 Mtetra
.739 .762 .872 r
.83689 .61418 .83964 .61801 .84603 .61443 .84329 .61063 Mtetra
.744 .766 .871 r
.84329 .61063 .84603 .61443 .85242 .61075 .8497 .60697 Mtetra
.748 .769 .87 r
.8497 .60697 .85242 .61075 .8588 .60695 .8561 .60321 Mtetra
.753 .773 .869 r
.8561 .60321 .8588 .60695 .86519 .60304 .86249 .59933 Mtetra
.759 .777 .868 r
.86249 .59933 .86519 .60304 .87156 .59901 .86889 .59534 Mtetra
.764 .781 .867 r
.86889 .59534 .87156 .59901 .87793 .59486 .87527 .59122 Mtetra
.769 .785 .866 r
.87527 .59122 .87793 .59486 .8843 .59059 .88165 .58699 Mtetra
.775 .789 .864 r
.88165 .58699 .8843 .59059 .89065 .58618 .88803 .58262 Mtetra
.781 .793 .863 r
.88803 .58262 .89065 .58618 .897 .58163 .89439 .57812 Mtetra
.787 .798 .862 r
.89439 .57812 .897 .58163 .90333 .57694 .90074 .57348 Mtetra
.793 .803 .86 r
.90074 .57348 .90333 .57694 .90965 .57211 .90708 .56869 Mtetra
.799 .808 .858 r
.90708 .56869 .90965 .57211 .91596 .56712 .91341 .56375 Mtetra
.806 .813 .856 r
.91341 .56375 .91596 .56712 .92225 .56197 .91972 .55865 Mtetra
.813 .818 .854 r
.91972 .55865 .92225 .56197 .92852 .55665 .92602 .55339 Mtetra
.82 .823 .852 r
.92602 .55339 .92852 .55665 .93478 .55116 .93229 .54796 Mtetra
.827 .828 .849 r
.93229 .54796 .93478 .55116 .94101 .5455 .93855 .54236 Mtetra
.834 .834 .846 r
.93855 .54236 .94101 .5455 .94722 .53964 .94478 .53657 Mtetra
.842 .839 .843 r
.94478 .53657 .94722 .53964 .95341 .53359 .95099 .53058 Mtetra
.849 .845 .839 r
.95099 .53058 .95341 .53359 .95956 .52734 .95717 .5244 Mtetra
.782 .287 .024 r
.3591 .60251 .36246 .60349 .36742 .60942 .36406 .60835 Mtetra
.767 .261 0 r
.36406 .60835 .36742 .60942 .37242 .61509 .36908 .61395 Mtetra
.75 .232 0 r
.36908 .61395 .37242 .61509 .37747 .62053 .37413 .61929 Mtetra
.729 .2 0 r
.37413 .61929 .37747 .62053 .38257 .62572 .37923 .6244 Mtetra
.705 .166 0 r
.37923 .6244 .38257 .62572 .3877 .63067 .38437 .62928 Mtetra
.677 .128 0 r
.38437 .62928 .3877 .63067 .39287 .6354 .38955 .63392 Mtetra
.645 .087 0 r
.38955 .63392 .39287 .6354 .39808 .6399 .39477 .63834 Mtetra
.608 .043 0 r
.39477 .63834 .39808 .6399 .40333 .64418 .40002 .64254 Mtetra
.566 0 0 r
.40002 .64254 .40333 .64418 .40862 .64825 .40531 .64653 Mtetra
.52 0 0 r
.40531 .64653 .40862 .64825 .41394 .6521 .41064 .65031 Mtetra
.469 0 0 r
.41064 .65031 .41394 .6521 .4193 .65575 .416 .65389 Mtetra
.414 0 0 r
.416 .65389 .4193 .65575 .42469 .65921 .4214 .65727 Mtetra
0 .208 .613 r
.4214 .65727 .42469 .65921 .43011 .66246 .42683 .66045 Mtetra
0 .259 .668 r
.42683 .66045 .43011 .66246 .43556 .66553 .43229 .66344 Mtetra
0 .309 .72 r
.43229 .66344 .43556 .66553 .44105 .66841 .43778 .66625 Mtetra
0 .356 .766 r
.43778 .66625 .44105 .66841 .44656 .67111 .4433 .66888 Mtetra
0 .399 .807 r
.4433 .66888 .44656 .67111 .45211 .67364 .44885 .67134 Mtetra
0 .44 .842 r
.44885 .67134 .45211 .67364 .45768 .67599 .45443 .67363 Mtetra
.012 .476 .872 r
.45443 .67363 .45768 .67599 .46328 .67817 .46003 .67574 Mtetra
.066 .508 .896 r
.46003 .67574 .46328 .67817 .4689 .6802 .46566 .6777 Mtetra
.117 .536 .916 r
.46566 .6777 .4689 .6802 .47455 .68206 .47132 .6795 Mtetra
.164 .561 .931 r
.47132 .6795 .47455 .68206 .48023 .68378 .477 .68115 Mtetra
.208 .582 .943 r
.477 .68115 .48023 .68378 .48593 .68534 .48271 .68265 Mtetra
.247 .601 .952 r
.48271 .68265 .48593 .68534 .49166 .68675 .48844 .68401 Mtetra
.283 .616 .958 r
.48844 .68401 .49166 .68675 .49741 .68803 .4942 .68522 Mtetra
.316 .63 .962 r
.4942 .68522 .49741 .68803 .50318 .68916 .49997 .6863 Mtetra
.346 .641 .964 r
.49997 .6863 .50318 .68916 .50897 .69017 .50577 .68725 Mtetra
.373 .651 .965 r
.50577 .68725 .50897 .69017 .51478 .69104 .51159 .68807 Mtetra
.397 .659 .964 r
.51159 .68807 .51478 .69104 .52062 .69179 .51743 .68876 Mtetra
.42 .667 .963 r
.51743 .68876 .52062 .69179 .52647 .69241 .5233 .68933 Mtetra
.44 .673 .962 r
.5233 .68933 .52647 .69241 .53235 .69292 .52918 .68979 Mtetra
.458 .678 .959 r
.52918 .68979 .53235 .69292 .53824 .69331 .53508 .69013 Mtetra
.475 .682 .957 r
.53508 .69013 .53824 .69331 .54416 .69359 .541 .69036 Mtetra
.49 .686 .954 r
.541 .69036 .54416 .69359 .55009 .69375 .54693 .69048 Mtetra
.504 .689 .951 r
.54693 .69048 .55009 .69375 .55604 .69381 .55289 .69049 Mtetra
.517 .692 .947 r
.55289 .69049 .55604 .69381 .562 .69377 .55886 .69041 Mtetra
.529 .694 .944 r
.55886 .69041 .562 .69377 .56799 .69363 .56485 .69022 Mtetra
.54 .696 .941 r
.56485 .69022 .56799 .69363 .57399 .69339 .57086 .68994 Mtetra
.55 .698 .938 r
.57086 .68994 .57399 .69339 .58001 .69306 .57688 .68956 Mtetra
.559 .7 .934 r
.57688 .68956 .58001 .69306 .58604 .69263 .58292 .6891 Mtetra
.567 .701 .931 r
.58292 .6891 .58604 .69263 .59209 .69211 .58898 .68854 Mtetra
.575 .702 .928 r
.58898 .68854 .59209 .69211 .59815 .69151 .59505 .6879 Mtetra
.583 .703 .925 r
.59505 .6879 .59815 .69151 .60423 .69082 .60113 .68718 Mtetra
.59 .704 .922 r
.60113 .68718 .60423 .69082 .61032 .69005 .60723 .68637 Mtetra
.596 .705 .92 r
.60723 .68637 .61032 .69005 .61643 .68919 .61334 .68548 Mtetra
.602 .706 .917 r
.61334 .68548 .61643 .68919 .62255 .68826 .61947 .68452 Mtetra
.608 .707 .914 r
.61947 .68452 .62255 .68826 .62869 .68725 .62561 .68348 Mtetra
.613 .708 .912 r
.62561 .68348 .62869 .68725 .63484 .68616 .63177 .68236 Mtetra
.618 .708 .909 r
.63177 .68236 .63484 .68616 .641 .685 .63794 .68117 Mtetra
.623 .709 .907 r
.63794 .68117 .641 .685 .64717 .68376 .64412 .67991 Mtetra
.628 .71 .905 r
.64412 .67991 .64717 .68376 .65336 .68246 .65031 .67858 Mtetra
.632 .71 .903 r
.65031 .67858 .65336 .68246 .65956 .68108 .65652 .67718 Mtetra
.636 .711 .901 r
.65652 .67718 .65956 .68108 .66577 .67963 .66274 .67571 Mtetra
.64 .712 .899 r
.66274 .67571 .66577 .67963 .67199 .67812 .66897 .67418 Mtetra
.644 .713 .897 r
.66897 .67418 .67199 .67812 .67823 .67653 .67521 .67258 Mtetra
.648 .714 .896 r
.67521 .67258 .67823 .67653 .68448 .67488 .68147 .67091 Mtetra
.652 .714 .894 r
.68147 .67091 .68448 .67488 .69073 .67316 .68773 .66918 Mtetra
.655 .715 .892 r
.68773 .66918 .69073 .67316 .697 .67138 .69401 .66738 Mtetra
.659 .716 .891 r
.69401 .66738 .697 .67138 .70328 .66953 .70029 .66551 Mtetra
.662 .717 .89 r
.70029 .66551 .70328 .66953 .70957 .66761 .70659 .66359 Mtetra
.665 .718 .888 r
.70659 .66359 .70957 .66761 .71587 .66562 .7129 .66159 Mtetra
.669 .72 .887 r
.7129 .66159 .71587 .66562 .72217 .66357 .71921 .65954 Mtetra
.672 .721 .886 r
.71921 .65954 .72217 .66357 .72849 .66146 .72554 .65741 Mtetra
.675 .722 .885 r
.72554 .65741 .72849 .66146 .73482 .65927 .73187 .65522 Mtetra
.678 .723 .884 r
.73187 .65522 .73482 .65927 .74115 .65702 .73822 .65297 Mtetra
.682 .725 .883 r
.73822 .65297 .74115 .65702 .74749 .6547 .74457 .65065 Mtetra
.685 .726 .882 r
.74457 .65065 .74749 .6547 .75384 .65231 .75093 .64826 Mtetra
.688 .728 .881 r
.75093 .64826 .75384 .65231 .7602 .64985 .7573 .6458 Mtetra
.691 .73 .88 r
.7573 .6458 .7602 .64985 .76657 .64731 .76367 .64327 Mtetra
.695 .732 .879 r
.76367 .64327 .76657 .64731 .77294 .64471 .77005 .64067 Mtetra
.698 .734 .878 r
.77005 .64067 .77294 .64471 .77932 .64203 .77644 .63799 Mtetra
.702 .736 .877 r
.77644 .63799 .77932 .64203 .7857 .63927 .78284 .63524 Mtetra
.705 .738 .877 r
.78284 .63524 .7857 .63927 .79209 .63643 .78923 .63242 Mtetra
.709 .74 .876 r
.78923 .63242 .79209 .63643 .79848 .63352 .79564 .62951 Mtetra
.712 .742 .875 r
.79564 .62951 .79848 .63352 .80487 .63052 .80204 .62653 Mtetra
.716 .745 .874 r
.80204 .62653 .80487 .63052 .81127 .62743 .80846 .62346 Mtetra
.72 .747 .874 r
.80846 .62346 .81127 .62743 .81768 .62426 .81487 .6203 Mtetra
.724 .75 .873 r
.81487 .6203 .81768 .62426 .82408 .62099 .82129 .61706 Mtetra
.728 .753 .872 r
.82129 .61706 .82408 .62099 .83048 .61764 .8277 .61373 Mtetra
.733 .756 .871 r
.8277 .61373 .83048 .61764 .83689 .61418 .83412 .61029 Mtetra
.737 .759 .871 r
.83412 .61029 .83689 .61418 .84329 .61063 .84054 .60677 Mtetra
.741 .762 .87 r
.84054 .60677 .84329 .61063 .8497 .60697 .84696 .60314 Mtetra
.746 .766 .869 r
.84696 .60314 .8497 .60697 .8561 .60321 .85337 .5994 Mtetra
.751 .769 .868 r
.85337 .5994 .8561 .60321 .86249 .59933 .85978 .59555 Mtetra
.756 .773 .867 r
.85978 .59555 .86249 .59933 .86889 .59534 .86619 .5916 Mtetra
.761 .777 .866 r
.86619 .5916 .86889 .59534 .87527 .59122 .8726 .58752 Mtetra
.767 .781 .865 r
.8726 .58752 .87527 .59122 .88165 .58699 .87899 .58332 Mtetra
.772 .785 .864 r
.87899 .58332 .88165 .58699 .88803 .58262 .88538 .57899 Mtetra
.778 .789 .862 r
.88538 .57899 .88803 .58262 .89439 .57812 .89176 .57453 Mtetra
.784 .794 .861 r
.89176 .57453 .89439 .57812 .90074 .57348 .89814 .56993 Mtetra
.79 .799 .859 r
.89814 .56993 .90074 .57348 .90708 .56869 .90449 .56519 Mtetra
.796 .803 .858 r
.90449 .56519 .90708 .56869 .91341 .56375 .91084 .5603 Mtetra
.803 .808 .856 r
.91084 .5603 .91341 .56375 .91972 .55865 .91717 .55526 Mtetra
.809 .813 .854 r
.91717 .55526 .91972 .55865 .92602 .55339 .92349 .55005 Mtetra
.816 .818 .851 r
.92349 .55005 .92602 .55339 .93229 .54796 .92979 .54468 Mtetra
.823 .823 .849 r
.92979 .54468 .93229 .54796 .93855 .54236 .93606 .53913 Mtetra
.83 .829 .846 r
.93606 .53913 .93855 .54236 .94478 .53657 .94232 .5334 Mtetra
.838 .834 .843 r
.94232 .5334 .94478 .53657 .95099 .53058 .94855 .52748 Mtetra
.845 .84 .839 r
.94855 .52748 .95099 .53058 .95717 .5244 .95476 .52136 Mtetra
.777 .275 .002 r
.35573 .60142 .3591 .60251 .36406 .60835 .3607 .60718 Mtetra
.76 .248 0 r
.3607 .60718 .36406 .60835 .36908 .61395 .36572 .61269 Mtetra
.74 .217 0 r
.36572 .61269 .36908 .61395 .37413 .61929 .37078 .61795 Mtetra
.718 .184 0 r
.37078 .61795 .37413 .61929 .37923 .6244 .37588 .62298 Mtetra
.691 .148 0 r
.37588 .62298 .37923 .6244 .38437 .62928 .38103 .62778 Mtetra
.661 .108 0 r
.38103 .62778 .38437 .62928 .38955 .63392 .38621 .63234 Mtetra
.626 .066 0 r
.38621 .63234 .38955 .63392 .39477 .63834 .39144 .63669 Mtetra
.587 .02 0 r
.39144 .63669 .39477 .63834 .40002 .64254 .3967 .64081 Mtetra
.542 0 0 r
.3967 .64081 .40002 .64254 .40531 .64653 .402 .64472 Mtetra
.493 0 0 r
.402 .64472 .40531 .64653 .41064 .65031 .40733 .64843 Mtetra
.44 0 0 r
.40733 .64843 .41064 .65031 .416 .65389 .4127 .65193 Mtetra
.382 0 0 r
.4127 .65193 .416 .65389 .4214 .65727 .4181 .65524 Mtetra
0 .234 .645 r
.4181 .65524 .4214 .65727 .42683 .66045 .42353 .65835 Mtetra
0 .284 .698 r
.42353 .65835 .42683 .66045 .43229 .66344 .429 .66127 Mtetra
0 .332 .746 r
.429 .66127 .43229 .66344 .43778 .66625 .4345 .66401 Mtetra
0 .378 .789 r
.4345 .66401 .43778 .66625 .4433 .66888 .44002 .66658 Mtetra
0 .419 .827 r
.44002 .66658 .4433 .66888 .44885 .67134 .44558 .66896 Mtetra
0 .457 .859 r
.44558 .66896 .44885 .67134 .45443 .67363 .45116 .67118 Mtetra
.042 .491 .885 r
.45116 .67118 .45443 .67363 .46003 .67574 .45677 .67324 Mtetra
.094 .521 .907 r
.45677 .67324 .46003 .67574 .46566 .6777 .46241 .67513 Mtetra
.143 .547 .924 r
.46241 .67513 .46566 .6777 .47132 .6795 .46808 .67687 Mtetra
.188 .57 .937 r
.46808 .67687 .47132 .6795 .477 .68115 .47376 .67846 Mtetra
.229 .59 .947 r
.47376 .67846 .477 .68115 .48271 .68265 .47948 .6799 Mtetra
.267 .607 .954 r
.47948 .6799 .48271 .68265 .48844 .68401 .48522 .6812 Mtetra
.301 .622 .959 r
.48522 .6812 .48844 .68401 .4942 .68522 .49098 .68236 Mtetra
.332 .634 .962 r
.49098 .68236 .4942 .68522 .49997 .6863 .49676 .68338 Mtetra
.36 .645 .964 r
.49676 .68338 .49997 .6863 .50577 .68725 .50256 .68427 Mtetra
.386 .654 .964 r
.50256 .68427 .50577 .68725 .51159 .68807 .50839 .68503 Mtetra
.409 .661 .963 r
.50839 .68503 .51159 .68807 .51743 .68876 .51424 .68568 Mtetra
.43 .668 .961 r
.51424 .68568 .51743 .68876 .5233 .68933 .5201 .6862 Mtetra
.449 .674 .959 r
.5201 .6862 .5233 .68933 .52918 .68979 .52599 .6866 Mtetra
.467 .678 .957 r
.52599 .6866 .52918 .68979 .53508 .69013 .5319 .68689 Mtetra
.483 .682 .954 r
.5319 .68689 .53508 .69013 .541 .69036 .53782 .68707 Mtetra
.497 .686 .951 r
.53782 .68707 .541 .69036 .54693 .69048 .54377 .68715 Mtetra
.511 .689 .948 r
.54377 .68715 .54693 .69048 .55289 .69049 .54973 .68712 Mtetra
.523 .691 .945 r
.54973 .68712 .55289 .69049 .55886 .69041 .55571 .68699 Mtetra
.534 .694 .942 r
.55571 .68699 .55886 .69041 .56485 .69022 .5617 .68676 Mtetra
.544 .696 .938 r
.5617 .68676 .56485 .69022 .57086 .68994 .56772 .68644 Mtetra
.554 .697 .935 r
.56772 .68644 .57086 .68994 .57688 .68956 .57375 .68602 Mtetra
.563 .699 .932 r
.57375 .68602 .57688 .68956 .58292 .6891 .57979 .68552 Mtetra
.571 .7 .929 r
.57979 .68552 .58292 .6891 .58898 .68854 .58585 .68492 Mtetra
.579 .701 .926 r
.58585 .68492 .58898 .68854 .59505 .6879 .59193 .68425 Mtetra
.586 .702 .923 r
.59193 .68425 .59505 .6879 .60113 .68718 .59802 .68349 Mtetra
.592 .703 .92 r
.59802 .68349 .60113 .68718 .60723 .68637 .60413 .68265 Mtetra
.599 .704 .918 r
.60413 .68265 .60723 .68637 .61334 .68548 .61025 .68173 Mtetra
.604 .705 .915 r
.61025 .68173 .61334 .68548 .61947 .68452 .61638 .68073 Mtetra
.61 .706 .912 r
.61638 .68073 .61947 .68452 .62561 .68348 .62253 .67966 Mtetra
.615 .706 .91 r
.62253 .67966 .62561 .68348 .63177 .68236 .62869 .67852 Mtetra
.62 .707 .908 r
.62869 .67852 .63177 .68236 .63794 .68117 .63487 .67731 Mtetra
.625 .708 .905 r
.63487 .67731 .63794 .68117 .64412 .67991 .64106 .67602 Mtetra
.629 .709 .903 r
.64106 .67602 .64412 .67991 .65031 .67858 .64726 .67467 Mtetra
.633 .709 .901 r
.64726 .67467 .65031 .67858 .65652 .67718 .65347 .67324 Mtetra
.637 .71 .899 r
.65347 .67324 .65652 .67718 .66274 .67571 .6597 .67176 Mtetra
.641 .711 .898 r
.6597 .67176 .66274 .67571 .66897 .67418 .66594 .6702 Mtetra
.645 .711 .896 r
.66594 .6702 .66897 .67418 .67521 .67258 .67219 .66858 Mtetra
.649 .712 .894 r
.67219 .66858 .67521 .67258 .68147 .67091 .67845 .6669 Mtetra
.652 .713 .893 r
.67845 .6669 .68147 .67091 .68773 .66918 .68472 .66515 Mtetra
.655 .714 .891 r
.68472 .66515 .68773 .66918 .69401 .66738 .691 .66334 Mtetra
.659 .715 .89 r
.691 .66334 .69401 .66738 .70029 .66551 .6973 .66146 Mtetra
.662 .716 .888 r
.6973 .66146 .70029 .66551 .70659 .66359 .7036 .65952 Mtetra
.665 .717 .887 r
.7036 .65952 .70659 .66359 .7129 .66159 .70992 .65752 Mtetra
.668 .718 .886 r
.70992 .65752 .7129 .66159 .71921 .65954 .71624 .65545 Mtetra
.672 .719 .885 r
.71624 .65545 .71921 .65954 .72554 .65741 .72258 .65333 Mtetra
.675 .721 .884 r
.72258 .65333 .72554 .65741 .73187 .65522 .72892 .65113 Mtetra
.678 .722 .883 r
.72892 .65113 .73187 .65522 .73822 .65297 .73527 .64887 Mtetra
.681 .723 .882 r
.73527 .64887 .73822 .65297 .74457 .65065 .74163 .64655 Mtetra
.684 .725 .881 r
.74163 .64655 .74457 .65065 .75093 .64826 .748 .64416 Mtetra
.687 .726 .88 r
.748 .64416 .75093 .64826 .7573 .6458 .75438 .6417 Mtetra
.691 .728 .879 r
.75438 .6417 .7573 .6458 .76367 .64327 .76076 .63918 Mtetra
.694 .73 .878 r
.76076 .63918 .76367 .64327 .77005 .64067 .76716 .63658 Mtetra
.697 .732 .877 r
.76716 .63658 .77005 .64067 .77644 .63799 .77355 .63391 Mtetra
.701 .734 .876 r
.77355 .63391 .77644 .63799 .78284 .63524 .77996 .63117 Mtetra
.704 .736 .876 r
.77996 .63117 .78284 .63524 .78923 .63242 .78637 .62836 Mtetra
.707 .738 .875 r
.78637 .62836 .78923 .63242 .79564 .62951 .79278 .62546 Mtetra
.711 .74 .874 r
.79278 .62546 .79564 .62951 .80204 .62653 .7992 .62249 Mtetra
.715 .743 .874 r
.7992 .62249 .80204 .62653 .80846 .62346 .80562 .61944 Mtetra
.719 .745 .873 r
.80562 .61944 .80846 .62346 .81487 .6203 .81205 .6163 Mtetra
.723 .748 .872 r
.81205 .6163 .81487 .6203 .82129 .61706 .81848 .61308 Mtetra
.727 .751 .871 r
.81848 .61308 .82129 .61706 .8277 .61373 .82491 .60976 Mtetra
.731 .753 .871 r
.82491 .60976 .8277 .61373 .83412 .61029 .83134 .60635 Mtetra
.735 .756 .87 r
.83134 .60635 .83412 .61029 .84054 .60677 .83777 .60285 Mtetra
.739 .76 .869 r
.83777 .60285 .84054 .60677 .84696 .60314 .8442 .59924 Mtetra
.744 .763 .868 r
.8442 .59924 .84696 .60314 .85337 .5994 .85063 .59553 Mtetra
.749 .766 .867 r
.85063 .59553 .85337 .5994 .85978 .59555 .85706 .59172 Mtetra
.754 .77 .866 r
.85706 .59172 .85978 .59555 .86619 .5916 .86348 .58779 Mtetra
.759 .774 .865 r
.86348 .58779 .86619 .5916 .8726 .58752 .8699 .58375 Mtetra
.764 .778 .864 r
.8699 .58375 .8726 .58752 .87899 .58332 .87632 .57959 Mtetra
.769 .782 .863 r
.87632 .57959 .87899 .58332 .88538 .57899 .88272 .5753 Mtetra
.775 .786 .862 r
.88272 .5753 .88538 .57899 .89176 .57453 .88912 .57088 Mtetra
.781 .79 .86 r
.88912 .57088 .89176 .57453 .89814 .56993 .89551 .56632 Mtetra
.787 .795 .859 r
.89551 .56632 .89814 .56993 .90449 .56519 .90189 .56163 Mtetra
.793 .799 .857 r
.90189 .56163 .90449 .56519 .91084 .5603 .90825 .55678 Mtetra
.799 .804 .855 r
.90825 .55678 .91084 .5603 .91717 .55526 .91461 .55179 Mtetra
.806 .809 .853 r
.91461 .55179 .91717 .55526 .92349 .55005 .92094 .54663 Mtetra
.813 .814 .851 r
.92094 .54663 .92349 .55005 .92979 .54468 .92726 .54131 Mtetra
.82 .819 .849 r
.92726 .54131 .92979 .54468 .93606 .53913 .93356 .53582 Mtetra
.827 .824 .846 r
.93356 .53582 .93606 .53913 .94232 .5334 .93984 .53014 Mtetra
.834 .829 .843 r
.93984 .53014 .94232 .5334 .94855 .52748 .94609 .52428 Mtetra
.841 .835 .84 r
.94609 .52428 .94855 .52748 .95476 .52136 .95232 .51823 Mtetra
.77 .263 0 r
.35234 .60022 .35573 .60142 .3607 .60718 .35732 .6059 Mtetra
.752 .234 0 r
.35732 .6059 .3607 .60718 .36572 .61269 .36235 .61133 Mtetra
.731 .202 0 r
.36235 .61133 .36572 .61269 .37078 .61795 .36741 .61651 Mtetra
.706 .167 0 r
.36741 .61651 .37078 .61795 .37588 .62298 .37252 .62146 Mtetra
.677 .129 0 r
.37252 .62146 .37588 .62298 .38103 .62778 .37767 .62618 Mtetra
.644 .088 0 r
.37767 .62618 .38103 .62778 .38621 .63234 .38287 .63067 Mtetra
.607 .044 0 r
.38287 .63067 .38621 .63234 .39144 .63669 .3881 .63493 Mtetra
.564 0 0 r
.3881 .63493 .39144 .63669 .3967 .64081 .39336 .63899 Mtetra
.517 0 0 r
.39336 .63899 .3967 .64081 .402 .64472 .39867 .64282 Mtetra
.466 0 0 r
.39867 .64282 .402 .64472 .40733 .64843 .40401 .64646 Mtetra
.41 0 0 r
.40401 .64646 .40733 .64843 .4127 .65193 .40938 .64989 Mtetra
0 .207 .62 r
.40938 .64989 .4127 .65193 .4181 .65524 .41479 .65312 Mtetra
0 .258 .674 r
.41479 .65312 .4181 .65524 .42353 .65835 .42023 .65617 Mtetra
0 .308 .725 r
.42023 .65617 .42353 .65835 .429 .66127 .4257 .65902 Mtetra
0 .354 .77 r
.4257 .65902 .429 .66127 .4345 .66401 .4312 .66169 Mtetra
0 .398 .81 r
.4312 .66169 .4345 .66401 .44002 .66658 .43674 .66419 Mtetra
0 .437 .844 r
.43674 .66419 .44002 .66658 .44558 .66896 .4423 .66651 Mtetra
.016 .473 .873 r
.4423 .66651 .44558 .66896 .45116 .67118 .44789 .66867 Mtetra
.07 .505 .897 r
.44789 .66867 .45116 .67118 .45677 .67324 .4535 .67066 Mtetra
.12 .533 .916 r
.4535 .67066 .45677 .67324 .46241 .67513 .45915 .67249 Mtetra
.167 .557 .931 r
.45915 .67249 .46241 .67513 .46808 .67687 .46482 .67417 Mtetra
.209 .579 .942 r
.46482 .67417 .46808 .67687 .47376 .67846 .47051 .6757 Mtetra
.249 .597 .951 r
.47051 .6757 .47376 .67846 .47948 .6799 .47623 .67708 Mtetra
.284 .613 .956 r
.47623 .67708 .47948 .6799 .48522 .6812 .48198 .67832 Mtetra
.317 .626 .96 r
.48198 .67832 .48522 .6812 .49098 .68236 .48774 .67942 Mtetra
.346 .638 .962 r
.48774 .67942 .49098 .68236 .49676 .68338 .49353 .68039 Mtetra
.373 .647 .963 r
.49353 .68039 .49676 .68338 .50256 .68427 .49934 .68123 Mtetra
.397 .656 .963 r
.49934 .68123 .50256 .68427 .50839 .68503 .50517 .68194 Mtetra
.42 .663 .961 r
.50517 .68194 .50839 .68503 .51424 .68568 .51103 .68253 Mtetra
.44 .669 .96 r
.51103 .68253 .51424 .68568 .5201 .6862 .5169 .683 Mtetra
.458 .674 .957 r
.5169 .683 .5201 .6862 .52599 .6866 .52279 .68336 Mtetra
.475 .679 .955 r
.52279 .68336 .52599 .6866 .5319 .68689 .52871 .6836 Mtetra
.49 .683 .952 r
.52871 .6836 .5319 .68689 .53782 .68707 .53464 .68373 Mtetra
.504 .686 .949 r
.53464 .68373 .53782 .68707 .54377 .68715 .54059 .68376 Mtetra
.516 .689 .946 r
.54059 .68376 .54377 .68715 .54973 .68712 .54656 .68369 Mtetra
.528 .691 .943 r
.54656 .68369 .54973 .68712 .55571 .68699 .55254 .68352 Mtetra
.539 .693 .939 r
.55254 .68352 .55571 .68699 .5617 .68676 .55854 .68325 Mtetra
.549 .695 .936 r
.55854 .68325 .5617 .68676 .56772 .68644 .56456 .68289 Mtetra
.558 .697 .933 r
.56456 .68289 .56772 .68644 .57375 .68602 .5706 .68243 Mtetra
.566 .698 .93 r
.5706 .68243 .57375 .68602 .57979 .68552 .57665 .68189 Mtetra
.574 .699 .927 r
.57665 .68189 .57979 .68552 .58585 .68492 .58272 .68126 Mtetra
.582 .701 .924 r
.58272 .68126 .58585 .68492 .59193 .68425 .5888 .68055 Mtetra
.588 .702 .921 r
.5888 .68055 .59193 .68425 .59802 .68349 .5949 .67976 Mtetra
.595 .703 .918 r
.5949 .67976 .59802 .68349 .60413 .68265 .60101 .67888 Mtetra
.601 .703 .916 r
.60101 .67888 .60413 .68265 .61025 .68173 .60714 .67793 Mtetra
.606 .704 .913 r
.60714 .67793 .61025 .68173 .61638 .68073 .61328 .67691 Mtetra
.612 .705 .911 r
.61328 .67691 .61638 .68073 .62253 .67966 .61944 .67581 Mtetra
.617 .706 .908 r
.61944 .67581 .62253 .67966 .62869 .67852 .6256 .67464 Mtetra
.621 .706 .906 r
.6256 .67464 .62869 .67852 .63487 .67731 .63179 .6734 Mtetra
.626 .707 .904 r
.63179 .6734 .63487 .67731 .64106 .67602 .63798 .67209 Mtetra
.63 .708 .902 r
.63798 .67209 .64106 .67602 .64726 .67467 .64419 .67071 Mtetra
.634 .708 .9 r
.64419 .67071 .64726 .67467 .65347 .67324 .65041 .66927 Mtetra
.638 .709 .898 r
.65041 .66927 .65347 .67324 .6597 .67176 .65664 .66776 Mtetra
.642 .71 .896 r
.65664 .66776 .6597 .67176 .66594 .6702 .66289 .66619 Mtetra
.646 .71 .895 r
.66289 .66619 .66594 .6702 .67219 .66858 .66915 .66455 Mtetra
.649 .711 .893 r
.66915 .66455 .67219 .66858 .67845 .6669 .67542 .66285 Mtetra
.652 .712 .891 r
.67542 .66285 .67845 .6669 .68472 .66515 .6817 .66108 Mtetra
.656 .713 .89 r
.6817 .66108 .68472 .66515 .691 .66334 .68799 .65926 Mtetra
.659 .714 .889 r
.68799 .65926 .691 .66334 .6973 .66146 .69429 .65737 Mtetra
.662 .715 .887 r
.69429 .65737 .6973 .66146 .7036 .65952 .7006 .65542 Mtetra
.665 .716 .886 r
.7006 .65542 .7036 .65952 .70992 .65752 .70693 .65341 Mtetra
.668 .717 .885 r
.70693 .65341 .70992 .65752 .71624 .65545 .71326 .65134 Mtetra
.671 .718 .884 r
.71326 .65134 .71624 .65545 .72258 .65333 .7196 .6492 Mtetra
.675 .719 .883 r
.7196 .6492 .72258 .65333 .72892 .65113 .72595 .647 Mtetra
.678 .721 .882 r
.72595 .647 .72892 .65113 .73527 .64887 .73232 .64474 Mtetra
.681 .722 .881 r
.73232 .64474 .73527 .64887 .74163 .64655 .73869 .64242 Mtetra
.684 .723 .88 r
.73869 .64242 .74163 .64655 .748 .64416 .74506 .64003 Mtetra
.687 .725 .879 r
.74506 .64003 .748 .64416 .75438 .6417 .75145 .63757 Mtetra
.69 .727 .878 r
.75145 .63757 .75438 .6417 .76076 .63918 .75784 .63505 Mtetra
.693 .728 .877 r
.75784 .63505 .76076 .63918 .76716 .63658 .76425 .63246 Mtetra
.696 .73 .876 r
.76425 .63246 .76716 .63658 .77355 .63391 .77065 .62979 Mtetra
.7 .732 .876 r
.77065 .62979 .77355 .63391 .77996 .63117 .77707 .62706 Mtetra
.703 .734 .875 r
.77707 .62706 .77996 .63117 .78637 .62836 .78349 .62425 Mtetra
.706 .736 .874 r
.78349 .62425 .78637 .62836 .79278 .62546 .78992 .62137 Mtetra
.71 .738 .874 r
.78992 .62137 .79278 .62546 .7992 .62249 .79635 .61841 Mtetra
.713 .741 .873 r
.79635 .61841 .7992 .62249 .80562 .61944 .80278 .61537 Mtetra
.717 .743 .872 r
.80278 .61537 .80562 .61944 .81205 .6163 .80922 .61225 Mtetra
.721 .746 .871 r
.80922 .61225 .81205 .6163 .81848 .61308 .81566 .60904 Mtetra
.725 .748 .871 r
.81566 .60904 .81848 .61308 .82491 .60976 .8221 .60575 Mtetra
.729 .751 .87 r
.8221 .60575 .82491 .60976 .83134 .60635 .82855 .60236 Mtetra
.733 .754 .869 r
.82855 .60236 .83134 .60635 .83777 .60285 .83499 .59888 Mtetra
.738 .757 .868 r
.83499 .59888 .83777 .60285 .8442 .59924 .84144 .5953 Mtetra
.742 .76 .868 r
.84144 .5953 .8442 .59924 .85063 .59553 .84788 .59162 Mtetra
.747 .764 .867 r
.84788 .59162 .85063 .59553 .85706 .59172 .85432 .58783 Mtetra
.751 .767 .866 r
.85432 .58783 .85706 .59172 .86348 .58779 .86076 .58393 Mtetra
.756 .771 .865 r
.86076 .58393 .86348 .58779 .8699 .58375 .8672 .57992 Mtetra
.762 .775 .864 r
.8672 .57992 .8699 .58375 .87632 .57959 .87363 .57579 Mtetra
.767 .779 .863 r
.87363 .57579 .87632 .57959 .88272 .5753 .88005 .57154 Mtetra
.772 .783 .861 r
.88005 .57154 .88272 .5753 .88912 .57088 .88646 .56716 Mtetra
.778 .787 .86 r
.88646 .56716 .88912 .57088 .89551 .56632 .89287 .56264 Mtetra
.784 .791 .858 r
.89287 .56264 .89551 .56632 .90189 .56163 .89927 .55799 Mtetra
.79 .796 .857 r
.89927 .55799 .90189 .56163 .90825 .55678 .90565 .55319 Mtetra
.796 .8 .855 r
.90565 .55319 .90825 .55678 .91461 .55179 .91202 .54824 Mtetra
.803 .805 .853 r
.91202 .54824 .91461 .55179 .92094 .54663 .91838 .54314 Mtetra
.809 .81 .851 r
.91838 .54314 .92094 .54663 .92726 .54131 .92472 .53787 Mtetra
.816 .815 .849 r
.92472 .53787 .92726 .54131 .93356 .53582 .93104 .53243 Mtetra
.823 .82 .846 r
.93104 .53243 .93356 .53582 .93984 .53014 .93734 .52681 Mtetra
.83 .825 .843 r
.93734 .52681 .93984 .53014 .94609 .52428 .94362 .52101 Mtetra
.838 .83 .84 r
.94362 .52101 .94609 .52428 .95232 .51823 .94987 .51501 Mtetra
.763 .251 0 r
.34895 .59891 .35234 .60022 .35732 .6059 .35394 .60451 Mtetra
.743 .22 0 r
.35394 .60451 .35732 .6059 .36235 .61133 .35897 .60986 Mtetra
.72 .187 0 r
.35897 .60986 .36235 .61133 .36741 .61651 .36404 .61497 Mtetra
.693 .15 0 r
.36404 .61497 .36741 .61651 .37252 .62146 .36915 .61984 Mtetra
.662 .111 0 r
.36915 .61984 .37252 .62146 .37767 .62618 .37431 .62448 Mtetra
.627 .068 0 r
.37431 .62448 .37767 .62618 .38287 .63067 .37951 .6289 Mtetra
.586 .022 0 r
.37951 .6289 .38287 .63067 .3881 .63493 .38474 .63309 Mtetra
.542 0 0 r
.38474 .63309 .3881 .63493 .39336 .63899 .39001 .63707 Mtetra
.492 0 0 r
.39001 .63707 .39336 .63899 .39867 .64282 .39532 .64084 Mtetra
.438 0 0 r
.39532 .64084 .39867 .64282 .40401 .64646 .40067 .6444 Mtetra
.38 0 0 r
.40067 .6444 .40401 .64646 .40938 .64989 .40605 .64776 Mtetra
0 .231 .649 r
.40605 .64776 .40938 .64989 .41479 .65312 .41146 .65093 Mtetra
0 .282 .702 r
.41146 .65093 .41479 .65312 .42023 .65617 .41691 .6539 Mtetra
0 .329 .749 r
.41691 .6539 .42023 .65617 .4257 .65902 .42239 .65669 Mtetra
0 .374 .791 r
.42239 .65669 .4257 .65902 .4312 .66169 .4279 .6593 Mtetra
0 .416 .828 r
.4279 .6593 .4312 .66169 .43674 .66419 .43343 .66173 Mtetra
0 .454 .859 r
.43343 .66173 .43674 .66419 .4423 .66651 .439 .66399 Mtetra
.043 .487 .885 r
.439 .66399 .4423 .66651 .44789 .66867 .4446 .66609 Mtetra
.095 .517 .907 r
.4446 .66609 .44789 .66867 .4535 .67066 .45022 .66802 Mtetra
.144 .543 .923 r
.45022 .66802 .4535 .67066 .45915 .67249 .45587 .66979 Mtetra
.188 .566 .936 r
.45587 .66979 .45915 .67249 .46482 .67417 .46155 .67141 Mtetra
.229 .586 .946 r
.46155 .67141 .46482 .67417 .47051 .6757 .46725 .67288 Mtetra
.266 .603 .953 r
.46725 .67288 .47051 .6757 .47623 .67708 .47297 .6742 Mtetra
.301 .618 .958 r
.47297 .6742 .47623 .67708 .48198 .67832 .47872 .67539 Mtetra
.331 .63 .96 r
.47872 .67539 .48198 .67832 .48774 .67942 .4845 .67643 Mtetra
.359 .641 .962 r
.4845 .67643 .48774 .67942 .49353 .68039 .49029 .67735 Mtetra
.385 .65 .962 r
.49029 .67735 .49353 .68039 .49934 .68123 .49611 .67813 Mtetra
.408 .658 .961 r
.49611 .67813 .49934 .68123 .50517 .68194 .50195 .6788 Mtetra
.429 .665 .96 r
.50195 .6788 .50517 .68194 .51103 .68253 .50781 .67933 Mtetra
.448 .67 .958 r
.50781 .67933 .51103 .68253 .5169 .683 .51369 .67976 Mtetra
.466 .675 .955 r
.51369 .67976 .5169 .683 .52279 .68336 .51959 .68006 Mtetra
.482 .679 .953 r
.51959 .68006 .52279 .68336 .52871 .6836 .5255 .68026 Mtetra
.496 .683 .95 r
.5255 .68026 .52871 .6836 .53464 .68373 .53144 .68035 Mtetra
.509 .686 .947 r
.53144 .68035 .53464 .68373 .54059 .68376 .5374 .68033 Mtetra
.522 .689 .944 r
.5374 .68033 .54059 .68376 .54656 .68369 .54337 .68022 Mtetra
.533 .691 .94 r
.54337 .68022 .54656 .68369 .55254 .68352 .54936 .68 Mtetra
.543 .693 .937 r
.54936 .68 .55254 .68352 .55854 .68325 .55537 .67969 Mtetra
.553 .695 .934 r
.55537 .67969 .55854 .68325 .56456 .68289 .5614 .67929 Mtetra
.561 .696 .931 r
.5614 .67929 .56456 .68289 .5706 .68243 .56744 .6788 Mtetra
.57 .698 .928 r
.56744 .6788 .5706 .68243 .57665 .68189 .5735 .67822 Mtetra
.577 .699 .925 r
.5735 .67822 .57665 .68189 .58272 .68126 .57957 .67756 Mtetra
.584 .7 .922 r
.57957 .67756 .58272 .68126 .5888 .68055 .58566 .67681 Mtetra
.591 .701 .919 r
.58566 .67681 .5888 .68055 .5949 .67976 .59177 .67599 Mtetra
.597 .702 .917 r
.59177 .67599 .5949 .67976 .60101 .67888 .59788 .67508 Mtetra
.603 .703 .914 r
.59788 .67508 .60101 .67888 .60714 .67793 .60402 .6741 Mtetra
.608 .704 .912 r
.60402 .6741 .60714 .67793 .61328 .67691 .61017 .67305 Mtetra
.613 .704 .909 r
.61017 .67305 .61328 .67691 .61944 .67581 .61633 .67192 Mtetra
.618 .705 .907 r
.61633 .67192 .61944 .67581 .6256 .67464 .6225 .67072 Mtetra
.623 .706 .905 r
.6225 .67072 .6256 .67464 .63179 .6734 .62869 .66946 Mtetra
.627 .706 .903 r
.62869 .66946 .63179 .6734 .63798 .67209 .63489 .66812 Mtetra
.631 .707 .901 r
.63489 .66812 .63798 .67209 .64419 .67071 .64111 .66672 Mtetra
.635 .708 .899 r
.64111 .66672 .64419 .67071 .65041 .66927 .64734 .66526 Mtetra
.639 .708 .897 r
.64734 .66526 .65041 .66927 .65664 .66776 .65358 .66373 Mtetra
.643 .709 .895 r
.65358 .66373 .65664 .66776 .66289 .66619 .65983 .66214 Mtetra
.646 .71 .894 r
.65983 .66214 .66289 .66619 .66915 .66455 .6661 .66048 Mtetra
.65 .71 .892 r
.6661 .66048 .66915 .66455 .67542 .66285 .67237 .65876 Mtetra
.653 .711 .891 r
.67237 .65876 .67542 .66285 .6817 .66108 .67866 .65699 Mtetra
.656 .712 .889 r
.67866 .65699 .6817 .66108 .68799 .65926 .68496 .65515 Mtetra
.659 .713 .888 r
.68496 .65515 .68799 .65926 .69429 .65737 .69127 .65325 Mtetra
.662 .714 .886 r
.69127 .65325 .69429 .65737 .7006 .65542 .69759 .65129 Mtetra
.665 .715 .885 r
.69759 .65129 .7006 .65542 .70693 .65341 .70392 .64927 Mtetra
.668 .716 .884 r
.70392 .64927 .70693 .65341 .71326 .65134 .71026 .64719 Mtetra
.671 .717 .883 r
.71026 .64719 .71326 .65134 .7196 .6492 .71661 .64504 Mtetra
.674 .718 .882 r
.71661 .64504 .7196 .6492 .72595 .647 .72298 .64284 Mtetra
.677 .719 .881 r
.72298 .64284 .72595 .647 .73232 .64474 .72935 .64058 Mtetra
.68 .721 .88 r
.72935 .64058 .73232 .64474 .73869 .64242 .73572 .63825 Mtetra
.683 .722 .879 r
.73572 .63825 .73869 .64242 .74506 .64003 .74211 .63586 Mtetra
.686 .724 .878 r
.74211 .63586 .74506 .64003 .75145 .63757 .74851 .6334 Mtetra
.689 .725 .877 r
.74851 .6334 .75145 .63757 .75784 .63505 .75491 .63088 Mtetra
.692 .727 .877 r
.75491 .63088 .75784 .63505 .76425 .63246 .76132 .62829 Mtetra
.695 .729 .876 r
.76132 .62829 .76425 .63246 .77065 .62979 .76774 .62564 Mtetra
.699 .731 .875 r
.76774 .62564 .77065 .62979 .77707 .62706 .77417 .62291 Mtetra
.702 .732 .874 r
.77417 .62291 .77707 .62706 .78349 .62425 .7806 .62011 Mtetra
.705 .735 .874 r
.7806 .62011 .78349 .62425 .78992 .62137 .78704 .61724 Mtetra
.709 .737 .873 r
.78704 .61724 .78992 .62137 .79635 .61841 .79348 .61429 Mtetra
.712 .739 .872 r
.79348 .61429 .79635 .61841 .80278 .61537 .79992 .61126 Mtetra
.716 .741 .872 r
.79992 .61126 .80278 .61537 .80922 .61225 .80637 .60816 Mtetra
.72 .744 .871 r
.80637 .60816 .80922 .61225 .81566 .60904 .81283 .60497 Mtetra
.723 .746 .87 r
.81283 .60497 .81566 .60904 .8221 .60575 .81928 .60169 Mtetra
.727 .749 .869 r
.81928 .60169 .8221 .60575 .82855 .60236 .82574 .59832 Mtetra
.732 .752 .869 r
.82574 .59832 .82855 .60236 .83499 .59888 .8322 .59486 Mtetra
.736 .755 .868 r
.8322 .59486 .83499 .59888 .84144 .5953 .83866 .5913 Mtetra
.74 .758 .867 r
.83866 .5913 .84144 .5953 .84788 .59162 .84511 .58765 Mtetra
.745 .761 .866 r
.84511 .58765 .84788 .59162 .85432 .58783 .85157 .58389 Mtetra
.749 .765 .865 r
.85157 .58389 .85432 .58783 .86076 .58393 .85802 .58002 Mtetra
.754 .768 .864 r
.85802 .58002 .86076 .58393 .8672 .57992 .86447 .57604 Mtetra
.759 .772 .863 r
.86447 .57604 .8672 .57992 .87363 .57579 .87092 .57194 Mtetra
.765 .776 .862 r
.87092 .57194 .87363 .57579 .88005 .57154 .87736 .56773 Mtetra
.77 .78 .861 r
.87736 .56773 .88005 .57154 .88646 .56716 .88379 .56338 Mtetra
.775 .784 .86 r
.88379 .56338 .88646 .56716 .89287 .56264 .89022 .5589 Mtetra
.781 .788 .858 r
.89022 .5589 .89287 .56264 .89927 .55799 .89663 .55429 Mtetra
.787 .792 .857 r
.89663 .55429 .89927 .55799 .90565 .55319 .90303 .54954 Mtetra
.793 .797 .855 r
.90303 .54954 .90565 .55319 .91202 .54824 .90942 .54463 Mtetra
.8 .801 .853 r
.90942 .54463 .91202 .54824 .91838 .54314 .9158 .53957 Mtetra
.806 .806 .851 r
.9158 .53957 .91838 .54314 .92472 .53787 .92216 .53435 Mtetra
.813 .811 .848 r
.92216 .53435 .92472 .53787 .93104 .53243 .9285 .52896 Mtetra
.82 .816 .846 r
.9285 .52896 .93104 .53243 .93734 .52681 .93482 .5234 Mtetra
.827 .821 .843 r
.93482 .5234 .93734 .52681 .94362 .52101 .94112 .51765 Mtetra
.834 .826 .84 r
.94112 .51765 .94362 .52101 .94987 .51501 .94739 .51172 Mtetra
.755 .238 0 r
.34555 .5975 .34895 .59891 .35394 .60451 .35054 .60302 Mtetra
.733 .206 0 r
.35054 .60302 .35394 .60451 .35897 .60986 .35557 .6083 Mtetra
.708 .171 0 r
.35557 .6083 .35897 .60986 .36404 .61497 .36065 .61333 Mtetra
.679 .133 0 r
.36065 .61333 .36404 .61497 .36915 .61984 .36577 .61813 Mtetra
.646 .092 0 r
.36577 .61813 .36915 .61984 .37431 .62448 .37093 .6227 Mtetra
.608 .048 0 r
.37093 .6227 .37431 .62448 .37951 .6289 .37614 .62704 Mtetra
.565 .001 0 r
.37614 .62704 .37951 .6289 .38474 .63309 .38138 .63117 Mtetra
.518 0 0 r
.38138 .63117 .38474 .63309 .39001 .63707 .38666 .63507 Mtetra
.466 0 0 r
.38666 .63507 .39001 .63707 .39532 .64084 .39197 .63877 Mtetra
.41 0 0 r
.39197 .63877 .39532 .64084 .40067 .6444 .39732 .64227 Mtetra
0 .203 .623 r
.39732 .64227 .40067 .6444 .40605 .64776 .40271 .64556 Mtetra
0 .254 .676 r
.40271 .64556 .40605 .64776 .41146 .65093 .40813 .64866 Mtetra
0 .303 .726 r
.40813 .64866 .41146 .65093 .41691 .6539 .41358 .65157 Mtetra
0 .35 .771 r
.41358 .65157 .41691 .6539 .42239 .65669 .41906 .65429 Mtetra
0 .393 .81 r
.41906 .65429 .42239 .65669 .4279 .6593 .42458 .65684 Mtetra
0 .433 .844 r
.42458 .65684 .4279 .6593 .43343 .66173 .43012 .65921 Mtetra
.015 .468 .872 r
.43012 .65921 .43343 .66173 .439 .66399 .4357 .6614 Mtetra
.069 .5 .896 r
.4357 .6614 .439 .66399 .4446 .66609 .4413 .66344 Mtetra
.119 .528 .915 r
.4413 .66344 .4446 .66609 .45022 .66802 .44693 .66531 Mtetra
.165 .553 .929 r
.44693 .66531 .45022 .66802 .45587 .66979 .45258 .66702 Mtetra
.208 .574 .941 r
.45258 .66702 .45587 .66979 .46155 .67141 .45827 .66858 Mtetra
.247 .592 .949 r
.45827 .66858 .46155 .67141 .46725 .67288 .46397 .67 Mtetra
.283 .608 .955 r
.46397 .67 .46725 .67288 .47297 .6742 .4697 .67127 Mtetra
.315 .622 .958 r
.4697 .67127 .47297 .6742 .47872 .67539 .47546 .6724 Mtetra
.345 .634 .96 r
.47546 .6724 .47872 .67539 .4845 .67643 .48124 .67339 Mtetra
.371 .644 .961 r
.48124 .67339 .4845 .67643 .49029 .67735 .48704 .67425 Mtetra
.396 .652 .961 r
.48704 .67425 .49029 .67735 .49611 .67813 .49286 .67499 Mtetra
.418 .66 .96 r
.49286 .67499 .49611 .67813 .50195 .6788 .49871 .6756 Mtetra
.438 .666 .958 r
.49871 .6756 .50195 .6788 .50781 .67933 .50457 .67609 Mtetra
.456 .671 .956 r
.50457 .67609 .50781 .67933 .51369 .67976 .51046 .67646 Mtetra
.473 .676 .954 r
.51046 .67646 .51369 .67976 .51959 .68006 .51636 .67672 Mtetra
.488 .68 .951 r
.51636 .67672 .51959 .68006 .5255 .68026 .52229 .67688 Mtetra
.502 .683 .948 r
.52229 .67688 .5255 .68026 .53144 .68035 .52823 .67692 Mtetra
.515 .686 .945 r
.52823 .67692 .53144 .68035 .5374 .68033 .53419 .67686 Mtetra
.526 .689 .942 r
.53419 .67686 .5374 .68033 .54337 .68022 .54018 .67671 Mtetra
.537 .691 .938 r
.54018 .67671 .54337 .68022 .54936 .68 .54617 .67645 Mtetra
.547 .693 .935 r
.54617 .67645 .54936 .68 .55537 .67969 .55219 .6761 Mtetra
.556 .695 .932 r
.55219 .6761 .55537 .67969 .5614 .67929 .55822 .67566 Mtetra
.565 .696 .929 r
.55822 .67566 .5614 .67929 .56744 .6788 .56427 .67513 Mtetra
.573 .698 .926 r
.56427 .67513 .56744 .6788 .5735 .67822 .57033 .67452 Mtetra
.58 .699 .923 r
.57033 .67452 .5735 .67822 .57957 .67756 .57641 .67382 Mtetra
.587 .7 .921 r
.57641 .67382 .57957 .67756 .58566 .67681 .58251 .67304 Mtetra
.593 .701 .918 r
.58251 .67304 .58566 .67681 .59177 .67599 .58862 .67218 Mtetra
.599 .702 .915 r
.58862 .67218 .59177 .67599 .59788 .67508 .59475 .67125 Mtetra
.605 .702 .913 r
.59475 .67125 .59788 .67508 .60402 .6741 .60089 .67024 Mtetra
.61 .703 .91 r
.60089 .67024 .60402 .6741 .61017 .67305 .60704 .66915 Mtetra
.615 .704 .908 r
.60704 .66915 .61017 .67305 .61633 .67192 .61321 .668 Mtetra
.62 .704 .906 r
.61321 .668 .61633 .67192 .6225 .67072 .61939 .66678 Mtetra
.624 .705 .904 r
.61939 .66678 .6225 .67072 .62869 .66946 .62559 .66549 Mtetra
.628 .706 .902 r
.62559 .66549 .62869 .66946 .63489 .66812 .6318 .66413 Mtetra
.632 .706 .9 r
.6318 .66413 .63489 .66812 .64111 .66672 .63802 .66271 Mtetra
.636 .707 .898 r
.63802 .66271 .64111 .66672 .64734 .66526 .64425 .66122 Mtetra
.64 .708 .896 r
.64425 .66122 .64734 .66526 .65358 .66373 .6505 .65967 Mtetra
.643 .708 .894 r
.6505 .65967 .65358 .66373 .65983 .66214 .65676 .65806 Mtetra
.647 .709 .893 r
.65676 .65806 .65983 .66214 .6661 .66048 .66303 .65639 Mtetra
.65 .71 .891 r
.66303 .65639 .6661 .66048 .67237 .65876 .66932 .65465 Mtetra
.653 .711 .89 r
.66932 .65465 .67237 .65876 .67866 .65699 .67561 .65286 Mtetra
.656 .711 .888 r
.67561 .65286 .67866 .65699 .68496 .65515 .68192 .65101 Mtetra
.659 .712 .887 r
.68192 .65101 .68496 .65515 .69127 .65325 .68824 .6491 Mtetra
.662 .713 .886 r
.68824 .6491 .69127 .65325 .69759 .65129 .69457 .64713 Mtetra
.665 .714 .885 r
.69457 .64713 .69759 .65129 .70392 .64927 .70091 .6451 Mtetra
.668 .715 .884 r
.70091 .6451 .70392 .64927 .71026 .64719 .70726 .64301 Mtetra
.671 .716 .882 r
.70726 .64301 .71026 .64719 .71661 .64504 .71362 .64086 Mtetra
.674 .717 .881 r
.71362 .64086 .71661 .64504 .72298 .64284 .71999 .63865 Mtetra
.677 .719 .88 r
.71999 .63865 .72298 .64284 .72935 .64058 .72636 .63638 Mtetra
.68 .72 .88 r
.72636 .63638 .72935 .64058 .73572 .63825 .73275 .63405 Mtetra
.683 .721 .879 r
.73275 .63405 .73572 .63825 .74211 .63586 .73915 .63166 Mtetra
.686 .723 .878 r
.73915 .63166 .74211 .63586 .74851 .6334 .74556 .6292 Mtetra
.689 .724 .877 r
.74556 .6292 .74851 .6334 .75491 .63088 .75197 .62668 Mtetra
.692 .726 .876 r
.75197 .62668 .75491 .63088 .76132 .62829 .75839 .6241 Mtetra
.695 .728 .875 r
.75839 .6241 .76132 .62829 .76774 .62564 .76482 .62145 Mtetra
.698 .729 .875 r
.76482 .62145 .76774 .62564 .77417 .62291 .77125 .61873 Mtetra
.701 .731 .874 r
.77125 .61873 .77417 .62291 .7806 .62011 .7777 .61594 Mtetra
.704 .733 .873 r
.7777 .61594 .7806 .62011 .78704 .61724 .78414 .61307 Mtetra
.708 .735 .873 r
.78414 .61307 .78704 .61724 .79348 .61429 .7906 .61014 Mtetra
.711 .737 .872 r
.7906 .61014 .79348 .61429 .79992 .61126 .79705 .60712 Mtetra
.715 .74 .871 r
.79705 .60712 .79992 .61126 .80637 .60816 .80352 .60403 Mtetra
.718 .742 .871 r
.80352 .60403 .80637 .60816 .81283 .60497 .80998 .60085 Mtetra
.722 .745 .87 r
.80998 .60085 .81283 .60497 .81928 .60169 .81645 .59759 Mtetra
.726 .747 .869 r
.81645 .59759 .81928 .60169 .82574 .59832 .82292 .59424 Mtetra
.73 .75 .868 r
.82292 .59424 .82574 .59832 .8322 .59486 .82939 .5908 Mtetra
.734 .753 .868 r
.82939 .5908 .8322 .59486 .83866 .5913 .83586 .58727 Mtetra
.738 .756 .867 r
.83586 .58727 .83866 .5913 .84511 .58765 .84233 .58364 Mtetra
.743 .759 .866 r
.84233 .58364 .84511 .58765 .85157 .58389 .84881 .5799 Mtetra
.747 .763 .865 r
.84881 .5799 .85157 .58389 .85802 .58002 .85527 .57606 Mtetra
.752 .766 .864 r
.85527 .57606 .85802 .58002 .86447 .57604 .86174 .57211 Mtetra
.757 .77 .863 r
.86174 .57211 .86447 .57604 .87092 .57194 .8682 .56804 Mtetra
.762 .773 .862 r
.8682 .56804 .87092 .57194 .87736 .56773 .87466 .56386 Mtetra
.768 .777 .861 r
.87466 .56386 .87736 .56773 .88379 .56338 .8811 .55955 Mtetra
.773 .781 .859 r
.8811 .55955 .88379 .56338 .89022 .5589 .88754 .55511 Mtetra
.779 .785 .858 r
.88754 .55511 .89022 .5589 .89663 .55429 .89398 .55054 Mtetra
.785 .789 .856 r
.89398 .55054 .89663 .55429 .90303 .54954 .9004 .54582 Mtetra
.791 .794 .855 r
.9004 .54582 .90303 .54954 .90942 .54463 .90681 .54096 Mtetra
.797 .798 .853 r
.90681 .54096 .90942 .54463 .9158 .53957 .9132 .53594 Mtetra
.803 .803 .851 r
.9132 .53594 .9158 .53957 .92216 .53435 .91958 .53077 Mtetra
.81 .807 .848 r
.91958 .53077 .92216 .53435 .9285 .52896 .92594 .52543 Mtetra
.817 .812 .846 r
.92594 .52543 .9285 .52896 .93482 .5234 .93228 .51992 Mtetra
.824 .817 .843 r
.93228 .51992 .93482 .5234 .94112 .51765 .9386 .51422 Mtetra
.831 .822 .84 r
.9386 .51422 .94112 .51765 .94739 .51172 .9449 .50834 Mtetra
.746 .225 0 r
.34213 .59599 .34555 .5975 .35054 .60302 .34713 .60144 Mtetra
.723 .192 0 r
.34713 .60144 .35054 .60302 .35557 .6083 .35217 .60664 Mtetra
.696 .155 0 r
.35217 .60664 .35557 .6083 .36065 .61333 .35725 .61161 Mtetra
.665 .116 0 r
.35725 .61161 .36065 .61333 .36577 .61813 .36238 .61633 Mtetra
.629 .073 0 r
.36238 .61633 .36577 .61813 .37093 .6227 .36755 .62083 Mtetra
.589 .027 0 r
.36755 .62083 .37093 .6227 .37614 .62704 .37275 .6251 Mtetra
.544 0 0 r
.37275 .6251 .37614 .62704 .38138 .63117 .378 .62916 Mtetra
.494 0 0 r
.378 .62916 .38138 .63117 .38666 .63507 .38328 .633 Mtetra
.44 0 0 r
.38328 .633 .38666 .63507 .39197 .63877 .38861 .63663 Mtetra
.382 0 0 r
.38861 .63663 .39197 .63877 .39732 .64227 .39396 .64005 Mtetra
0 .226 .65 r
.39396 .64005 .39732 .64227 .40271 .64556 .39935 .64328 Mtetra
0 .276 .701 r
.39935 .64328 .40271 .64556 .40813 .64866 .40478 .64632 Mtetra
0 .324 .748 r
.40478 .64632 .40813 .64866 .41358 .65157 .41024 .64916 Mtetra
0 .368 .79 r
.41024 .64916 .41358 .65157 .41906 .65429 .41573 .65182 Mtetra
0 .41 .827 r
.41573 .65182 .41906 .65429 .42458 .65684 .42125 .65431 Mtetra
0 .448 .858 r
.42125 .65431 .42458 .65684 .43012 .65921 .4268 .65661 Mtetra
.04 .481 .884 r
.4268 .65661 .43012 .65921 .4357 .6614 .43238 .65875 Mtetra
.092 .511 .905 r
.43238 .65875 .4357 .6614 .4413 .66344 .43798 .66072 Mtetra
.14 .538 .921 r
.43798 .66072 .4413 .66344 .44693 .66531 .44362 .66254 Mtetra
.185 .561 .934 r
.44362 .66254 .44693 .66531 .45258 .66702 .44928 .6642 Mtetra
.226 .581 .944 r
.44928 .6642 .45258 .66702 .45827 .66858 .45497 .6657 Mtetra
.263 .598 .951 r
.45497 .6657 .45827 .66858 .46397 .67 .46068 .66706 Mtetra
.298 .613 .956 r
.46068 .66706 .46397 .67 .4697 .67127 .46642 .66828 Mtetra
.329 .626 .959 r
.46642 .66828 .4697 .67127 .47546 .6724 .47218 .66935 Mtetra
.357 .637 .96 r
.47218 .66935 .47546 .6724 .48124 .67339 .47797 .6703 Mtetra
.382 .646 .961 r
.47797 .6703 .48124 .67339 .48704 .67425 .48377 .67111 Mtetra
.405 .654 .96 r
.48377 .67111 .48704 .67425 .49286 .67499 .4896 .67179 Mtetra
.427 .661 .959 r
.4896 .67179 .49286 .67499 .49871 .6756 .49545 .67236 Mtetra
.446 .667 .957 r
.49545 .67236 .49871 .6756 .50457 .67609 .50133 .6728 Mtetra
.463 .672 .954 r
.50133 .6728 .50457 .67609 .51046 .67646 .50722 .67313 Mtetra
.479 .677 .952 r
.50722 .67313 .51046 .67646 .51636 .67672 .51313 .67334 Mtetra
.494 .681 .949 r
.51313 .67334 .51636 .67672 .52229 .67688 .51906 .67345 Mtetra
.507 .684 .946 r
.51906 .67345 .52229 .67688 .52823 .67692 .52501 .67345 Mtetra
.52 .687 .943 r
.52501 .67345 .52823 .67692 .53419 .67686 .53098 .67335 Mtetra
.531 .689 .94 r
.53098 .67335 .53419 .67686 .54018 .67671 .53697 .67315 Mtetra
.541 .691 .937 r
.53697 .67315 .54018 .67671 .54617 .67645 .54297 .67286 Mtetra
.551 .693 .934 r
.54297 .67286 .54617 .67645 .55219 .6761 .54899 .67247 Mtetra
.56 .695 .931 r
.54899 .67247 .55219 .6761 .55822 .67566 .55503 .672 Mtetra
.568 .696 .928 r
.55503 .672 .55822 .67566 .56427 .67513 .56108 .67143 Mtetra
.575 .697 .925 r
.56108 .67143 .56427 .67513 .57033 .67452 .56716 .67078 Mtetra
.583 .699 .922 r
.56716 .67078 .57033 .67452 .57641 .67382 .57324 .67005 Mtetra
.589 .7 .919 r
.57324 .67005 .57641 .67382 .58251 .67304 .57934 .66924 Mtetra
.595 .701 .917 r
.57934 .66924 .58251 .67304 .58862 .67218 .58546 .66835 Mtetra
.601 .701 .914 r
.58546 .66835 .58862 .67218 .59475 .67125 .59159 .66738 Mtetra
.607 .702 .912 r
.59159 .66738 .59475 .67125 .60089 .67024 .59774 .66634 Mtetra
.612 .703 .909 r
.59774 .66634 .60089 .67024 .60704 .66915 .6039 .66523 Mtetra
.616 .704 .907 r
.6039 .66523 .60704 .66915 .61321 .668 .61008 .66405 Mtetra
.621 .704 .905 r
.61008 .66405 .61321 .668 .61939 .66678 .61627 .6628 Mtetra
.625 .705 .903 r
.61627 .6628 .61939 .66678 .62559 .66549 .62247 .66149 Mtetra
.629 .705 .901 r
.62247 .66149 .62559 .66549 .6318 .66413 .62869 .66011 Mtetra
.633 .706 .899 r
.62869 .66011 .6318 .66413 .63802 .66271 .63492 .65866 Mtetra
.637 .707 .897 r
.63492 .65866 .63802 .66271 .64425 .66122 .64116 .65715 Mtetra
.641 .707 .895 r
.64116 .65715 .64425 .66122 .6505 .65967 .64741 .65559 Mtetra
.644 .708 .894 r
.64741 .65559 .6505 .65967 .65676 .65806 .65368 .65396 Mtetra
.647 .709 .892 r
.65368 .65396 .65676 .65806 .66303 .65639 .65996 .65227 Mtetra
.651 .71 .891 r
.65996 .65227 .66303 .65639 .66932 .65465 .66625 .65052 Mtetra
.654 .71 .889 r
.66625 .65052 .66932 .65465 .67561 .65286 .67255 .64871 Mtetra
.657 .711 .888 r
.67255 .64871 .67561 .65286 .68192 .65101 .67887 .64684 Mtetra
.66 .712 .887 r
.67887 .64684 .68192 .65101 .68824 .6491 .68519 .64492 Mtetra
.663 .713 .885 r
.68519 .64492 .68824 .6491 .69457 .64713 .69153 .64294 Mtetra
.665 .714 .884 r
.69153 .64294 .69457 .64713 .70091 .6451 .69788 .6409 Mtetra
.668 .715 .883 r
.69788 .6409 .70091 .6451 .70726 .64301 .70424 .6388 Mtetra
.671 .716 .882 r
.70424 .6388 .70726 .64301 .71362 .64086 .71061 .63665 Mtetra
.674 .717 .881 r
.71061 .63665 .71362 .64086 .71999 .63865 .71698 .63443 Mtetra
.677 .718 .88 r
.71698 .63443 .71999 .63865 .72636 .63638 .72337 .63216 Mtetra
.679 .719 .879 r
.72337 .63216 .72636 .63638 .73275 .63405 .72977 .62983 Mtetra
.682 .721 .878 r
.72977 .62983 .73275 .63405 .73915 .63166 .73618 .62743 Mtetra
.685 .722 .878 r
.73618 .62743 .73915 .63166 .74556 .6292 .74259 .62498 Mtetra
.688 .723 .877 r
.74259 .62498 .74556 .6292 .75197 .62668 .74901 .62246 Mtetra
.691 .725 .876 r
.74901 .62246 .75197 .62668 .75839 .6241 .75544 .61988 Mtetra
.694 .727 .875 r
.75544 .61988 .75839 .6241 .76482 .62145 .76188 .61723 Mtetra
.697 .728 .875 r
.76188 .61723 .76482 .62145 .77125 .61873 .76833 .61451 Mtetra
.7 .73 .874 r
.76833 .61451 .77125 .61873 .7777 .61594 .77478 .61173 Mtetra
.703 .732 .873 r
.77478 .61173 .7777 .61594 .78414 .61307 .78124 .60888 Mtetra
.707 .734 .872 r
.78124 .60888 .78414 .61307 .7906 .61014 .7877 .60595 Mtetra
.71 .736 .872 r
.7877 .60595 .7906 .61014 .79705 .60712 .79417 .60294 Mtetra
.713 .739 .871 r
.79417 .60294 .79705 .60712 .80352 .60403 .80065 .59986 Mtetra
.717 .741 .87 r
.80065 .59986 .80352 .60403 .80998 .60085 .80712 .5967 Mtetra
.721 .743 .87 r
.80712 .5967 .80998 .60085 .81645 .59759 .8136 .59346 Mtetra
.725 .746 .869 r
.8136 .59346 .81645 .59759 .82292 .59424 .82009 .59013 Mtetra
.728 .749 .868 r
.82009 .59013 .82292 .59424 .82939 .5908 .82657 .58671 Mtetra
.733 .751 .867 r
.82657 .58671 .82939 .5908 .83586 .58727 .83306 .58319 Mtetra
.737 .754 .867 r
.83306 .58319 .83586 .58727 .84233 .58364 .83954 .57958 Mtetra
.741 .757 .866 r
.83954 .57958 .84233 .58364 .84881 .5799 .84603 .57587 Mtetra
.746 .761 .865 r
.84603 .57587 .84881 .5799 .85527 .57606 .85251 .57206 Mtetra
.75 .764 .864 r
.85251 .57206 .85527 .57606 .86174 .57211 .85899 .56814 Mtetra
.755 .767 .863 r
.85899 .56814 .86174 .57211 .8682 .56804 .86547 .5641 Mtetra
.76 .771 .862 r
.86547 .5641 .8682 .56804 .87466 .56386 .87194 .55995 Mtetra
.765 .775 .861 r
.87194 .55995 .87466 .56386 .8811 .55955 .8784 .55567 Mtetra
.771 .779 .859 r
.8784 .55567 .8811 .55955 .88754 .55511 .88486 .55126 Mtetra
.776 .783 .858 r
.88486 .55126 .88754 .55511 .89398 .55054 .89131 .54673 Mtetra
.782 .787 .856 r
.89131 .54673 .89398 .55054 .9004 .54582 .89775 .54205 Mtetra
.788 .791 .855 r
.89775 .54205 .9004 .54582 .90681 .54096 .90417 .53723 Mtetra
.794 .795 .853 r
.90417 .53723 .90681 .54096 .9132 .53594 .91059 .53226 Mtetra
.801 .8 .851 r
.91059 .53226 .9132 .53594 .91958 .53077 .91698 .52713 Mtetra
.807 .804 .849 r
.91698 .52713 .91958 .53077 .92594 .52543 .92337 .52183 Mtetra
.814 .809 .846 r
.92337 .52183 .92594 .52543 .93228 .51992 .92973 .51637 Mtetra
.821 .814 .843 r
.92973 .51637 .93228 .51992 .9386 .51422 .93607 .51073 Mtetra
.828 .818 .841 r
.93607 .51073 .9386 .51422 .9449 .50834 .94239 .5049 Mtetra
.737 .212 0 r
.33871 .59439 .34213 .59599 .34713 .60144 .34371 .59977 Mtetra
.712 .177 0 r
.34371 .59977 .34713 .60144 .35217 .60664 .34875 .6049 Mtetra
.683 .139 0 r
.34875 .6049 .35217 .60664 .35725 .61161 .35384 .60979 Mtetra
.65 .098 0 r
.35384 .60979 .35725 .61161 .36238 .61633 .35897 .61445 Mtetra
.612 .054 0 r
.35897 .61445 .36238 .61633 .36755 .62083 .36415 .61888 Mtetra
.569 .007 0 r
.36415 .61888 .36755 .62083 .37275 .6251 .36936 .62308 Mtetra
.522 0 0 r
.36936 .62308 .37275 .6251 .378 .62916 .37461 .62707 Mtetra
.47 0 0 r
.37461 .62707 .378 .62916 .38328 .633 .3799 .63084 Mtetra
.414 0 0 r
.3799 .63084 .38328 .633 .38861 .63663 .38523 .63441 Mtetra
0 .196 .621 r
.38523 .63441 .38861 .63663 .39396 .64005 .39059 .63777 Mtetra
0 .247 .675 r
.39059 .63777 .39396 .64005 .39935 .64328 .39599 .64093 Mtetra
0 .296 .724 r
.39599 .64093 .39935 .64328 .40478 .64632 .40142 .6439 Mtetra
0 .342 .768 r
.40142 .6439 .40478 .64632 .41024 .64916 .40688 .64669 Mtetra
0 .386 .808 r
.40688 .64669 .41024 .64916 .41573 .65182 .41238 .64929 Mtetra
0 .425 .841 r
.41238 .64929 .41573 .65182 .42125 .65431 .4179 .65171 Mtetra
.01 .461 .87 r
.4179 .65171 .42125 .65431 .4268 .65661 .42346 .65396 Mtetra
.064 .493 .893 r
.42346 .65396 .4268 .65661 .43238 .65875 .42905 .65604 Mtetra
.114 .522 .912 r
.42905 .65604 .43238 .65875 .43798 .66072 .43466 .65796 Mtetra
.16 .547 .927 r
.43466 .65796 .43798 .66072 .44362 .66254 .4403 .65971 Mtetra
.203 .568 .938 r
.4403 .65971 .44362 .66254 .44928 .6642 .44597 .66132 Mtetra
.243 .587 .947 r
.44597 .66132 .44928 .6642 .45497 .6657 .45166 .66277 Mtetra
.278 .603 .953 r
.45166 .66277 .45497 .6657 .46068 .66706 .45738 .66407 Mtetra
.311 .617 .957 r
.45738 .66407 .46068 .66706 .46642 .66828 .46313 .66524 Mtetra
.341 .63 .959 r
.46313 .66524 .46642 .66828 .47218 .66935 .46889 .66626 Mtetra
.368 .64 .96 r
.46889 .66626 .47218 .66935 .47797 .6703 .47468 .66715 Mtetra
.392 .649 .96 r
.47468 .66715 .47797 .6703 .48377 .67111 .4805 .66792 Mtetra
.414 .656 .959 r
.4805 .66792 .48377 .67111 .4896 .67179 .48633 .66855 Mtetra
.435 .663 .957 r
.48633 .66855 .4896 .67179 .49545 .67236 .49219 .66907 Mtetra
.453 .669 .955 r
.49219 .66907 .49545 .67236 .50133 .6728 .49807 .66947 Mtetra
.47 .673 .953 r
.49807 .66947 .50133 .6728 .50722 .67313 .50397 .66975 Mtetra
.485 .678 .95 r
.50397 .66975 .50722 .67313 .51313 .67334 .50988 .66992 Mtetra
.499 .681 .947 r
.50988 .66992 .51313 .67334 .51906 .67345 .51582 .66999 Mtetra
.512 .684 .944 r
.51582 .66999 .51906 .67345 .52501 .67345 .52178 .66995 Mtetra
.524 .687 .941 r
.52178 .66995 .52501 .67345 .53098 .67335 .52775 .66981 Mtetra
.535 .689 .938 r
.52775 .66981 .53098 .67335 .53697 .67315 .53374 .66957 Mtetra
.545 .692 .935 r
.53374 .66957 .53697 .67315 .54297 .67286 .53976 .66924 Mtetra
.554 .693 .932 r
.53976 .66924 .54297 .67286 .54899 .67247 .54578 .66881 Mtetra
.563 .695 .929 r
.54578 .66881 .54899 .67247 .55503 .672 .55183 .6683 Mtetra
.571 .696 .926 r
.55183 .6683 .55503 .672 .56108 .67143 .55789 .6677 Mtetra
.578 .698 .923 r
.55789 .6677 .56108 .67143 .56716 .67078 .56397 .66701 Mtetra
.585 .699 .921 r
.56397 .66701 .56716 .67078 .57324 .67005 .57006 .66625 Mtetra
.591 .7 .918 r
.57006 .66625 .57324 .67005 .57934 .66924 .57617 .66541 Mtetra
.597 .701 .915 r
.57617 .66541 .57934 .66924 .58546 .66835 .58229 .66448 Mtetra
.603 .701 .913 r
.58229 .66448 .58546 .66835 .59159 .66738 .58843 .66349 Mtetra
.608 .702 .911 r
.58843 .66349 .59159 .66738 .59774 .66634 .59458 .66242 Mtetra
.613 .703 .908 r
.59458 .66242 .59774 .66634 .6039 .66523 .60075 .66128 Mtetra
.618 .703 .906 r
.60075 .66128 .6039 .66523 .61008 .66405 .60693 .66008 Mtetra
.622 .704 .904 r
.60693 .66008 .61008 .66405 .61627 .6628 .61313 .6588 Mtetra
.626 .705 .902 r
.61313 .6588 .61627 .6628 .62247 .66149 .61934 .65746 Mtetra
.63 .705 .9 r
.61934 .65746 .62247 .66149 .62869 .66011 .62556 .65606 Mtetra
.634 .706 .898 r
.62556 .65606 .62869 .66011 .63492 .65866 .6318 .65459 Mtetra
.638 .707 .896 r
.6318 .65459 .63492 .65866 .64116 .65715 .63805 .65307 Mtetra
.641 .707 .895 r
.63805 .65307 .64116 .65715 .64741 .65559 .64431 .65148 Mtetra
.645 .708 .893 r
.64431 .65148 .64741 .65559 .65368 .65396 .65059 .64983 Mtetra
.648 .709 .892 r
.65059 .64983 .65368 .65396 .65996 .65227 .65687 .64812 Mtetra
.651 .709 .89 r
.65687 .64812 .65996 .65227 .66625 .65052 .66317 .64636 Mtetra
.654 .71 .889 r
.66317 .64636 .66625 .65052 .67255 .64871 .66948 .64454 Mtetra
.657 .711 .887 r
.66948 .64454 .67255 .64871 .67887 .64684 .67581 .64266 Mtetra
.66 .712 .886 r
.67581 .64266 .67887 .64684 .68519 .64492 .68214 .64072 Mtetra
.663 .713 .885 r
.68214 .64072 .68519 .64492 .69153 .64294 .68849 .63873 Mtetra
.665 .713 .884 r
.68849 .63873 .69153 .64294 .69788 .6409 .69484 .63668 Mtetra
.668 .714 .883 r
.69484 .63668 .69788 .6409 .70424 .6388 .70121 .63458 Mtetra
.671 .715 .882 r
.70121 .63458 .70424 .6388 .71061 .63665 .70758 .63241 Mtetra
.674 .716 .881 r
.70758 .63241 .71061 .63665 .71698 .63443 .71397 .63019 Mtetra
.676 .718 .88 r
.71397 .63019 .71698 .63443 .72337 .63216 .72037 .62792 Mtetra
.679 .719 .879 r
.72037 .62792 .72337 .63216 .72977 .62983 .72677 .62558 Mtetra
.682 .72 .878 r
.72677 .62558 .72977 .62983 .73618 .62743 .73319 .62318 Mtetra
.685 .721 .877 r
.73319 .62318 .73618 .62743 .74259 .62498 .73961 .62073 Mtetra
.688 .723 .877 r
.73961 .62073 .74259 .62498 .74901 .62246 .74605 .61821 Mtetra
.69 .724 .876 r
.74605 .61821 .74901 .62246 .75544 .61988 .75249 .61563 Mtetra
.693 .726 .875 r
.75249 .61563 .75544 .61988 .76188 .61723 .75894 .61299 Mtetra
.696 .728 .874 r
.75894 .61299 .76188 .61723 .76833 .61451 .76539 .61028 Mtetra
.699 .729 .874 r
.76539 .61028 .76833 .61451 .77478 .61173 .77185 .6075 Mtetra
.702 .731 .873 r
.77185 .6075 .77478 .61173 .78124 .60888 .77832 .60465 Mtetra
.706 .733 .872 r
.77832 .60465 .78124 .60888 .7877 .60595 .7848 .60173 Mtetra
.709 .735 .872 r
.7848 .60173 .7877 .60595 .79417 .60294 .79128 .59874 Mtetra
.712 .738 .871 r
.79128 .59874 .79417 .60294 .80065 .59986 .79776 .59567 Mtetra
.716 .74 .87 r
.79776 .59567 .80065 .59986 .80712 .5967 .80425 .59252 Mtetra
.719 .742 .87 r
.80425 .59252 .80712 .5967 .8136 .59346 .81075 .58929 Mtetra
.723 .745 .869 r
.81075 .58929 .8136 .59346 .82009 .59013 .81724 .58598 Mtetra
.727 .747 .868 r
.81724 .58598 .82009 .59013 .82657 .58671 .82374 .58258 Mtetra
.731 .75 .867 r
.82374 .58258 .82657 .58671 .83306 .58319 .83024 .57908 Mtetra
.735 .753 .867 r
.83024 .57908 .83306 .58319 .83954 .57958 .83674 .5755 Mtetra
.739 .756 .866 r
.83674 .5755 .83954 .57958 .84603 .57587 .84323 .57181 Mtetra
.744 .759 .865 r
.84323 .57181 .84603 .57587 .85251 .57206 .84973 .56802 Mtetra
.749 .762 .864 r
.84973 .56802 .85251 .57206 .85899 .56814 .85623 .56412 Mtetra
.753 .766 .863 r
.85623 .56412 .85899 .56814 .86547 .5641 .86272 .56011 Mtetra
.758 .769 .862 r
.86272 .56011 .86547 .5641 .87194 .55995 .8692 .55599 Mtetra
.763 .773 .861 r
.8692 .55599 .87194 .55995 .8784 .55567 .87569 .55174 Mtetra
.769 .776 .859 r
.87569 .55174 .8784 .55567 .88486 .55126 .88216 .54737 Mtetra
.774 .78 .858 r
.88216 .54737 .88486 .55126 .89131 .54673 .88862 .54287 Mtetra
.78 .784 .856 r
.88862 .54287 .89131 .54673 .89775 .54205 .89508 .53823 Mtetra
.786 .788 .855 r
.89508 .53823 .89775 .54205 .90417 .53723 .90153 .53345 Mtetra
.792 .793 .853 r
.90153 .53345 .90417 .53723 .91059 .53226 .90796 .52851 Mtetra
.798 .797 .851 r
.90796 .52851 .91059 .53226 .91698 .52713 .91437 .52343 Mtetra
.804 .801 .849 r
.91437 .52343 .91698 .52713 .92337 .52183 .92078 .51818 Mtetra
.811 .806 .846 r
.92078 .51818 .92337 .52183 .92973 .51637 .92716 .51276 Mtetra
.818 .811 .844 r
.92716 .51276 .92973 .51637 .93607 .51073 .93352 .50717 Mtetra
.825 .815 .841 r
.93352 .50717 .93607 .51073 .94239 .5049 .93986 .50139 Mtetra
.728 .199 0 r
.33527 .5927 .33871 .59439 .34371 .59977 .34028 .59801 Mtetra
.701 .162 0 r
.34028 .59801 .34371 .59977 .34875 .6049 .34533 .60307 Mtetra
.669 .123 0 r
.34533 .60307 .34875 .6049 .35384 .60979 .35042 .60789 Mtetra
.634 .08 0 r
.35042 .60789 .35384 .60979 .35897 .61445 .35556 .61248 Mtetra
.594 .035 0 r
.35556 .61248 .35897 .61445 .36415 .61888 .36074 .61684 Mtetra
.549 0 0 r
.36074 .61684 .36415 .61888 .36936 .62308 .36595 .62098 Mtetra
.499 0 0 r
.36595 .62098 .36936 .62308 .37461 .62707 .37121 .6249 Mtetra
.446 0 0 r
.37121 .6249 .37461 .62707 .3799 .63084 .37651 .62861 Mtetra
.388 0 0 r
.37651 .62861 .3799 .63084 .38523 .63441 .38184 .63212 Mtetra
0 .217 .646 r
.38184 .63212 .38523 .63441 .39059 .63777 .38721 .63541 Mtetra
0 .267 .697 r
.38721 .63541 .39059 .63777 .39599 .64093 .39261 .63852 Mtetra
0 .315 .744 r
.39261 .63852 .39599 .64093 .40142 .6439 .39805 .64143 Mtetra
0 .36 .786 r
.39805 .64143 .40142 .6439 .40688 .64669 .40352 .64415 Mtetra
0 .401 .823 r
.40352 .64415 .40688 .64669 .41238 .64929 .40902 .64669 Mtetra
0 .439 .854 r
.40902 .64669 .41238 .64929 .4179 .65171 .41455 .64906 Mtetra
.033 .474 .88 r
.41455 .64906 .4179 .65171 .42346 .65396 .42011 .65125 Mtetra
.085 .504 .901 r
.42011 .65125 .42346 .65396 .42905 .65604 .4257 .65327 Mtetra
.134 .531 .918 r
.4257 .65327 .42905 .65604 .43466 .65796 .43132 .65513 Mtetra
.179 .555 .932 r
.43132 .65513 .43466 .65796 .4403 .65971 .43697 .65684 Mtetra
.22 .575 .942 r
.43697 .65684 .4403 .65971 .44597 .66132 .44264 .65838 Mtetra
.258 .593 .949 r
.44264 .65838 .44597 .66132 .45166 .66277 .44834 .65978 Mtetra
.292 .608 .954 r
.44834 .65978 .45166 .66277 .45738 .66407 .45407 .66104 Mtetra
.323 .621 .957 r
.45407 .66104 .45738 .66407 .46313 .66524 .45982 .66215 Mtetra
.352 .633 .959 r
.45982 .66215 .46313 .66524 .46889 .66626 .46559 .66313 Mtetra
.378 .643 .959 r
.46559 .66313 .46889 .66626 .47468 .66715 .47139 .66397 Mtetra
.401 .651 .959 r
.47139 .66397 .47468 .66715 .4805 .66792 .47721 .66469 Mtetra
.423 .658 .958 r
.47721 .66469 .4805 .66792 .48633 .66855 .48305 .66528 Mtetra
.442 .664 .956 r
.48305 .66528 .48633 .66855 .49219 .66907 .48891 .66575 Mtetra
.46 .67 .954 r
.48891 .66575 .49219 .66907 .49807 .66947 .4948 .6661 Mtetra
.476 .674 .952 r
.4948 .6661 .49807 .66947 .50397 .66975 .5007 .66634 Mtetra
.491 .678 .949 r
.5007 .66634 .50397 .66975 .50988 .66992 .50663 .66647 Mtetra
.504 .682 .946 r
.50663 .66647 .50988 .66992 .51582 .66999 .51257 .66649 Mtetra
.517 .685 .943 r
.51257 .66649 .51582 .66999 .52178 .66995 .51853 .66641 Mtetra
.528 .688 .94 r
.51853 .66641 .52178 .66995 .52775 .66981 .52451 .66623 Mtetra
.539 .69 .937 r
.52451 .66623 .52775 .66981 .53374 .66957 .53051 .66595 Mtetra
.548 .692 .934 r
.53051 .66595 .53374 .66957 .53976 .66924 .53653 .66558 Mtetra
.557 .694 .931 r
.53653 .66558 .53976 .66924 .54578 .66881 .54256 .66512 Mtetra
.566 .695 .928 r
.54256 .66512 .54578 .66881 .55183 .6683 .54861 .66457 Mtetra
.573 .697 .925 r
.54861 .66457 .55183 .6683 .55789 .6677 .55468 .66394 Mtetra
.581 .698 .922 r
.55468 .66394 .55789 .6677 .56397 .66701 .56077 .66322 Mtetra
.587 .699 .92 r
.56077 .66322 .56397 .66701 .57006 .66625 .56686 .66242 Mtetra
.593 .7 .917 r
.56686 .66242 .57006 .66625 .57617 .66541 .57298 .66155 Mtetra
.599 .701 .914 r
.57298 .66155 .57617 .66541 .58229 .66448 .57911 .6606 Mtetra
.605 .701 .912 r
.57911 .6606 .58229 .66448 .58843 .66349 .58526 .65958 Mtetra
.61 .702 .91 r
.58526 .65958 .58843 .66349 .59458 .66242 .59142 .65848 Mtetra
.615 .703 .907 r
.59142 .65848 .59458 .66242 .60075 .66128 .59759 .65732 Mtetra
.619 .704 .905 r
.59759 .65732 .60075 .66128 .60693 .66008 .60378 .65608 Mtetra
.623 .704 .903 r
.60378 .65608 .60693 .66008 .61313 .6588 .60998 .65478 Mtetra
.628 .705 .901 r
.60998 .65478 .61313 .6588 .61934 .65746 .6162 .65342 Mtetra
.631 .705 .899 r
.6162 .65342 .61934 .65746 .62556 .65606 .62243 .652 Mtetra
.635 .706 .898 r
.62243 .652 .62556 .65606 .6318 .65459 .62867 .65051 Mtetra
.639 .707 .896 r
.62867 .65051 .6318 .65459 .63805 .65307 .63493 .64896 Mtetra
.642 .707 .894 r
.63493 .64896 .63805 .65307 .64431 .65148 .6412 .64735 Mtetra
.645 .708 .893 r
.6412 .64735 .64431 .65148 .65059 .64983 .64748 .64569 Mtetra
.648 .709 .891 r
.64748 .64569 .65059 .64983 .65687 .64812 .65378 .64397 Mtetra
.651 .709 .89 r
.65378 .64397 .65687 .64812 .66317 .64636 .66008 .64219 Mtetra
.654 .71 .889 r
.66008 .64219 .66317 .64636 .66948 .64454 .6664 .64035 Mtetra
.657 .711 .887 r
.6664 .64035 .66948 .64454 .67581 .64266 .67273 .63846 Mtetra
.66 .712 .886 r
.67273 .63846 .67581 .64266 .68214 .64072 .67907 .63651 Mtetra
.663 .712 .885 r
.67907 .63651 .68214 .64072 .68849 .63873 .68543 .63451 Mtetra
.666 .713 .884 r
.68543 .63451 .68849 .63873 .69484 .63668 .69179 .63245 Mtetra
.668 .714 .883 r
.69179 .63245 .69484 .63668 .70121 .63458 .69817 .63033 Mtetra
.671 .715 .882 r
.69817 .63033 .70121 .63458 .70758 .63241 .70455 .62816 Mtetra
.674 .716 .881 r
.70455 .62816 .70758 .63241 .71397 .63019 .71095 .62594 Mtetra
.676 .717 .88 r
.71095 .62594 .71397 .63019 .72037 .62792 .71735 .62365 Mtetra
.679 .719 .879 r
.71735 .62365 .72037 .62792 .72677 .62558 .72377 .62132 Mtetra
.682 .72 .878 r
.72377 .62132 .72677 .62558 .73319 .62318 .73019 .61892 Mtetra
.684 .721 .877 r
.73019 .61892 .73319 .62318 .73961 .62073 .73663 .61646 Mtetra
.687 .723 .877 r
.73663 .61646 .73961 .62073 .74605 .61821 .74307 .61394 Mtetra
.69 .724 .876 r
.74307 .61394 .74605 .61821 .75249 .61563 .74952 .61136 Mtetra
.693 .726 .875 r
.74952 .61136 .75249 .61563 .75894 .61299 .75598 .60872 Mtetra
.696 .727 .874 r
.75598 .60872 .75894 .61299 .76539 .61028 .76244 .60602 Mtetra
.699 .729 .874 r
.76244 .60602 .76539 .61028 .77185 .6075 .76892 .60324 Mtetra
.702 .731 .873 r
.76892 .60324 .77185 .6075 .77832 .60465 .7754 .6004 Mtetra
.705 .733 .872 r
.7754 .6004 .77832 .60465 .7848 .60173 .78188 .59749 Mtetra
.708 .735 .872 r
.78188 .59749 .7848 .60173 .79128 .59874 .78837 .59451 Mtetra
.711 .737 .871 r
.78837 .59451 .79128 .59874 .79776 .59567 .79487 .59145 Mtetra
.715 .739 .87 r
.79487 .59145 .79776 .59567 .80425 .59252 .80137 .58832 Mtetra
.718 .741 .87 r
.80137 .58832 .80425 .59252 .81075 .58929 .80788 .5851 Mtetra
.722 .744 .869 r
.80788 .5851 .81075 .58929 .81724 .58598 .81438 .5818 Mtetra
.726 .746 .868 r
.81438 .5818 .81724 .58598 .82374 .58258 .82089 .57842 Mtetra
.73 .749 .867 r
.82089 .57842 .82374 .58258 .83024 .57908 .82741 .57494 Mtetra
.734 .752 .867 r
.82741 .57494 .83024 .57908 .83674 .5755 .83392 .57137 Mtetra
.738 .755 .866 r
.83392 .57137 .83674 .5755 .84323 .57181 .84043 .56771 Mtetra
.742 .758 .865 r
.84043 .56771 .84323 .57181 .84973 .56802 .84694 .56394 Mtetra
.747 .761 .864 r
.84694 .56394 .84973 .56802 .85623 .56412 .85345 .56007 Mtetra
.752 .764 .863 r
.85345 .56007 .85623 .56412 .86272 .56011 .85996 .55609 Mtetra
.756 .767 .862 r
.85996 .55609 .86272 .56011 .8692 .55599 .86646 .55199 Mtetra
.761 .771 .861 r
.86646 .55199 .8692 .55599 .87569 .55174 .87296 .54778 Mtetra
.767 .774 .859 r
.87296 .54778 .87569 .55174 .88216 .54737 .87945 .54344 Mtetra
.772 .778 .858 r
.87945 .54344 .88216 .54737 .88862 .54287 .88593 .53897 Mtetra
.778 .782 .856 r
.88593 .53897 .88862 .54287 .89508 .53823 .8924 .53436 Mtetra
.783 .786 .855 r
.8924 .53436 .89508 .53823 .90153 .53345 .89886 .52961 Mtetra
.789 .79 .853 r
.89886 .52961 .90153 .53345 .90796 .52851 .90531 .52472 Mtetra
.795 .794 .851 r
.90531 .52472 .90796 .52851 .91437 .52343 .91175 .51968 Mtetra
.802 .799 .849 r
.91175 .51968 .91437 .52343 .92078 .51818 .91817 .51447 Mtetra
.808 .803 .847 r
.91817 .51447 .92078 .51818 .92716 .51276 .92457 .5091 Mtetra
.815 .808 .844 r
.92457 .5091 .92716 .51276 .93352 .50717 .93096 .50355 Mtetra
.822 .812 .841 r
.93096 .50355 .93352 .50717 .93986 .50139 .93732 .49782 Mtetra
.717 .185 0 r
.33183 .59092 .33527 .5927 .34028 .59801 .33684 .59616 Mtetra
.688 .147 0 r
.33684 .59616 .34028 .59801 .34533 .60307 .34189 .60115 Mtetra
.655 .106 0 r
.34189 .60115 .34533 .60307 .35042 .60789 .34699 .60591 Mtetra
.618 .063 0 r
.34699 .60591 .35042 .60789 .35556 .61248 .35213 .61044 Mtetra
.575 .016 0 r
.35213 .61044 .35556 .61248 .36074 .61684 .35731 .61473 Mtetra
.528 0 0 r
.35731 .61473 .36074 .61684 .36595 .62098 .36254 .61881 Mtetra
.477 0 0 r
.36254 .61881 .36595 .62098 .37121 .6249 .3678 .62267 Mtetra
.422 0 0 r
.3678 .62267 .37121 .6249 .37651 .62861 .3731 .62631 Mtetra
0 .186 .616 r
.3731 .62631 .37651 .62861 .38184 .63212 .37844 .62976 Mtetra
0 .236 .669 r
.37844 .62976 .38184 .63212 .38721 .63541 .38381 .63299 Mtetra
0 .286 .718 r
.38381 .63299 .38721 .63541 .39261 .63852 .38922 .63604 Mtetra
0 .332 .763 r
.38922 .63604 .39261 .63852 .39805 .64143 .39466 .63889 Mtetra
0 .376 .802 r
.39466 .63889 .39805 .64143 .40352 .64415 .40014 .64155 Mtetra
0 .416 .836 r
.40014 .64155 .40352 .64415 .40902 .64669 .40564 .64404 Mtetra
.001 .452 .865 r
.40564 .64404 .40902 .64669 .41455 .64906 .41118 .64635 Mtetra
.055 .485 .889 r
.41118 .64635 .41455 .64906 .42011 .65125 .41675 .64848 Mtetra
.106 .514 .908 r
.41675 .64848 .42011 .65125 .4257 .65327 .42235 .65045 Mtetra
.152 .539 .924 r
.42235 .65045 .4257 .65327 .43132 .65513 .42797 .65226 Mtetra
.196 .562 .935 r
.42797 .65226 .43132 .65513 .43697 .65684 .43363 .65391 Mtetra
.235 .581 .944 r
.43363 .65391 .43697 .65684 .44264 .65838 .43931 .65541 Mtetra
.272 .598 .951 r
.43931 .65541 .44264 .65838 .44834 .65978 .44501 .65675 Mtetra
.305 .612 .955 r
.44501 .65675 .44834 .65978 .45407 .66104 .45074 .65796 Mtetra
.335 .625 .958 r
.45074 .65796 .45407 .66104 .45982 .66215 .4565 .65902 Mtetra
.362 .636 .959 r
.4565 .65902 .45982 .66215 .46559 .66313 .46228 .65995 Mtetra
.387 .645 .959 r
.46228 .65995 .46559 .66313 .47139 .66397 .46808 .66075 Mtetra
.409 .653 .958 r
.46808 .66075 .47139 .66397 .47721 .66469 .47391 .66141 Mtetra
.43 .66 .957 r
.47391 .66141 .47721 .66469 .48305 .66528 .47975 .66196 Mtetra
.449 .666 .955 r
.47975 .66196 .48305 .66528 .48891 .66575 .48562 .66239 Mtetra
.466 .671 .953 r
.48562 .66239 .48891 .66575 .4948 .6661 .49151 .6627 Mtetra
.481 .675 .95 r
.49151 .6627 .4948 .6661 .5007 .66634 .49742 .66289 Mtetra
.496 .679 .948 r
.49742 .66289 .5007 .66634 .50663 .66647 .50335 .66298 Mtetra
.509 .683 .945 r
.50335 .66298 .50663 .66647 .51257 .66649 .5093 .66296 Mtetra
.521 .686 .942 r
.5093 .66296 .51257 .66649 .51853 .66641 .51527 .66284 Mtetra
.532 .688 .939 r
.51527 .66284 .51853 .66641 .52451 .66623 .52126 .66262 Mtetra
.542 .69 .936 r
.52126 .66262 .52451 .66623 .53051 .66595 .52727 .66231 Mtetra
.552 .692 .933 r
.52727 .66231 .53051 .66595 .53653 .66558 .53329 .6619 Mtetra
.56 .694 .93 r
.53329 .6619 .53653 .66558 .54256 .66512 .53933 .66141 Mtetra
.568 .696 .927 r
.53933 .66141 .54256 .66512 .54861 .66457 .54539 .66082 Mtetra
.576 .697 .924 r
.54539 .66082 .54861 .66457 .55468 .66394 .55146 .66016 Mtetra
.583 .698 .921 r
.55146 .66016 .55468 .66394 .56077 .66322 .55755 .65941 Mtetra
.589 .699 .919 r
.55755 .65941 .56077 .66322 .56686 .66242 .56366 .65858 Mtetra
.595 .7 .916 r
.56366 .65858 .56686 .66242 .57298 .66155 .56978 .65767 Mtetra
.601 .701 .914 r
.56978 .65767 .57298 .66155 .57911 .6606 .57592 .65669 Mtetra
.606 .702 .911 r
.57592 .65669 .57911 .6606 .58526 .65958 .58207 .65564 Mtetra
.611 .703 .909 r
.58207 .65564 .58526 .65958 .59142 .65848 .58824 .65452 Mtetra
.616 .703 .907 r
.58824 .65452 .59142 .65848 .59759 .65732 .59442 .65333 Mtetra
.62 .704 .905 r
.59442 .65333 .59759 .65732 .60378 .65608 .60062 .65207 Mtetra
.625 .705 .903 r
.60062 .65207 .60378 .65608 .60998 .65478 .60683 .65075 Mtetra
.629 .705 .901 r
.60683 .65075 .60998 .65478 .6162 .65342 .61305 .64936 Mtetra
.632 .706 .899 r
.61305 .64936 .6162 .65342 .62243 .652 .61929 .64792 Mtetra
.636 .706 .897 r
.61929 .64792 .62243 .652 .62867 .65051 .62554 .64641 Mtetra
.639 .707 .896 r
.62554 .64641 .62867 .65051 .63493 .64896 .6318 .64484 Mtetra
.643 .708 .894 r
.6318 .64484 .63493 .64896 .6412 .64735 .63808 .64321 Mtetra
.646 .708 .893 r
.63808 .64321 .6412 .64735 .64748 .64569 .64437 .64153 Mtetra
.649 .709 .891 r
.64437 .64153 .64748 .64569 .65378 .64397 .65067 .63979 Mtetra
.652 .71 .89 r
.65067 .63979 .65378 .64397 .66008 .64219 .65698 .638 Mtetra
.655 .71 .888 r
.65698 .638 .66008 .64219 .6664 .64035 .66331 .63615 Mtetra
.658 .711 .887 r
.66331 .63615 .6664 .64035 .67273 .63846 .66965 .63424 Mtetra
.66 .712 .886 r
.66965 .63424 .67273 .63846 .67907 .63651 .676 .63228 Mtetra
.663 .713 .885 r
.676 .63228 .67907 .63651 .68543 .63451 .68236 .63027 Mtetra
.666 .713 .884 r
.68236 .63027 .68543 .63451 .69179 .63245 .68873 .6282 Mtetra
.668 .714 .883 r
.68873 .6282 .69179 .63245 .69817 .63033 .69511 .62608 Mtetra
.671 .715 .882 r
.69511 .62608 .69817 .63033 .70455 .62816 .70151 .6239 Mtetra
.673 .716 .881 r
.70151 .6239 .70455 .62816 .71095 .62594 .70791 .62167 Mtetra
.676 .717 .88 r
.70791 .62167 .71095 .62594 .71735 .62365 .71433 .61938 Mtetra
.679 .719 .879 r
.71433 .61938 .71735 .62365 .72377 .62132 .72075 .61704 Mtetra
.681 .72 .878 r
.72075 .61704 .72377 .62132 .73019 .61892 .72719 .61463 Mtetra
.684 .721 .878 r
.72719 .61463 .73019 .61892 .73663 .61646 .73363 .61218 Mtetra
.687 .722 .877 r
.73363 .61218 .73663 .61646 .74307 .61394 .74008 .60966 Mtetra
.689 .724 .876 r
.74008 .60966 .74307 .61394 .74952 .61136 .74654 .60708 Mtetra
.692 .725 .875 r
.74654 .60708 .74952 .61136 .75598 .60872 .75301 .60444 Mtetra
.695 .727 .875 r
.75301 .60444 .75598 .60872 .76244 .60602 .75949 .60174 Mtetra
.698 .729 .874 r
.75949 .60174 .76244 .60602 .76892 .60324 .76597 .59897 Mtetra
.701 .73 .873 r
.76597 .59897 .76892 .60324 .7754 .6004 .77246 .59614 Mtetra
.704 .732 .873 r
.77246 .59614 .7754 .6004 .78188 .59749 .77896 .59324 Mtetra
.707 .734 .872 r
.77896 .59324 .78188 .59749 .78837 .59451 .78546 .59026 Mtetra
.71 .736 .871 r
.78546 .59026 .78837 .59451 .79487 .59145 .79197 .58721 Mtetra
.714 .738 .871 r
.79197 .58721 .79487 .59145 .80137 .58832 .79848 .58409 Mtetra
.717 .741 .87 r
.79848 .58409 .80137 .58832 .80788 .5851 .80499 .58089 Mtetra
.721 .743 .869 r
.80499 .58089 .80788 .5851 .81438 .5818 .81151 .5776 Mtetra
.725 .745 .868 r
.81151 .5776 .81438 .5818 .82089 .57842 .81804 .57423 Mtetra
.728 .748 .868 r
.81804 .57423 .82089 .57842 .82741 .57494 .82456 .57078 Mtetra
.732 .751 .867 r
.82456 .57078 .82741 .57494 .83392 .57137 .83109 .56723 Mtetra
.737 .753 .866 r
.83109 .56723 .83392 .57137 .84043 .56771 .83761 .56358 Mtetra
.741 .756 .865 r
.83761 .56358 .84043 .56771 .84694 .56394 .84414 .55983 Mtetra
.745 .759 .864 r
.84414 .55983 .84694 .56394 .85345 .56007 .85066 .55599 Mtetra
.75 .763 .863 r
.85066 .55599 .85345 .56007 .85996 .55609 .85718 .55203 Mtetra
.755 .766 .862 r
.85718 .55203 .85996 .55609 .86646 .55199 .8637 .54796 Mtetra
.76 .769 .861 r
.8637 .54796 .86646 .55199 .87296 .54778 .87021 .54377 Mtetra
.765 .773 .86 r
.87021 .54377 .87296 .54778 .87945 .54344 .87672 .53946 Mtetra
.77 .776 .858 r
.87672 .53946 .87945 .54344 .88593 .53897 .88322 .53502 Mtetra
.776 .78 .857 r
.88322 .53502 .88593 .53897 .8924 .53436 .88971 .53045 Mtetra
.781 .784 .855 r
.88971 .53045 .8924 .53436 .89886 .52961 .89619 .52574 Mtetra
.787 .788 .853 r
.89619 .52574 .89886 .52961 .90531 .52472 .90265 .52088 Mtetra
.793 .792 .851 r
.90265 .52088 .90531 .52472 .91175 .51968 .90911 .51587 Mtetra
.799 .796 .849 r
.90911 .51587 .91175 .51968 .91817 .51447 .91555 .51071 Mtetra
.806 .801 .847 r
.91555 .51071 .91817 .51447 .92457 .5091 .92197 .50538 Mtetra
.812 .805 .844 r
.92197 .50538 .92457 .5091 .93096 .50355 .92838 .49987 Mtetra
.819 .81 .842 r
.92838 .49987 .93096 .50355 .93732 .49782 .93476 .49419 Mtetra
.707 .171 0 r
.32837 .58905 .33183 .59092 .33684 .59616 .33338 .59423 Mtetra
.676 .132 0 r
.33338 .59423 .33684 .59616 .34189 .60115 .33844 .59916 Mtetra
.641 .09 0 r
.33844 .59916 .34189 .60115 .34699 .60591 .34355 .60385 Mtetra
.601 .045 0 r
.34355 .60385 .34699 .60591 .35213 .61044 .34869 .60832 Mtetra
.557 0 0 r
.34869 .60832 .35213 .61044 .35731 .61473 .35388 .61255 Mtetra
.508 0 0 r
.35388 .61255 .35731 .61473 .36254 .61881 .35911 .61657 Mtetra
.455 0 0 r
.35911 .61657 .36254 .61881 .3678 .62267 .36438 .62036 Mtetra
.398 0 0 r
.36438 .62036 .3678 .62267 .3731 .62631 .36968 .62395 Mtetra
0 .205 .639 r
.36968 .62395 .3731 .62631 .37844 .62976 .37503 .62733 Mtetra
0 .255 .69 r
.37503 .62733 .37844 .62976 .38381 .63299 .3804 .63051 Mtetra
0 .303 .737 r
.3804 .63051 .38381 .63299 .38922 .63604 .38582 .6335 Mtetra
0 .348 .78 r
.38582 .6335 .38922 .63604 .39466 .63889 .39127 .63629 Mtetra
0 .391 .817 r
.39127 .63629 .39466 .63889 .40014 .64155 .39675 .6389 Mtetra
0 .429 .848 r
.39675 .6389 .40014 .64155 .40564 .64404 .40226 .64133 Mtetra
.023 .464 .875 r
.40226 .64133 .40564 .64404 .41118 .64635 .4078 .64358 Mtetra
.075 .495 .897 r
.4078 .64358 .41118 .64635 .41675 .64848 .41338 .64567 Mtetra
.124 .523 .914 r
.41338 .64567 .41675 .64848 .42235 .65045 .41898 .64758 Mtetra
.169 .547 .928 r
.41898 .64758 .42235 .65045 .42797 .65226 .42461 .64934 Mtetra
.211 .568 .939 r
.42461 .64934 .42797 .65226 .43363 .65391 .43027 .65094 Mtetra
.249 .586 .946 r
.43027 .65094 .43363 .65391 .43931 .65541 .43595 .65238 Mtetra
.284 .602 .952 r
.43595 .65238 .43931 .65541 .44501 .65675 .44167 .65368 Mtetra
.316 .616 .956 r
.44167 .65368 .44501 .65675 .45074 .65796 .4474 .65484 Mtetra
.345 .628 .958 r
.4474 .65484 .45074 .65796 .4565 .65902 .45317 .65585 Mtetra
.371 .638 .959 r
.45317 .65585 .4565 .65902 .46228 .65995 .45895 .65673 Mtetra
.395 .647 .958 r
.45895 .65673 .46228 .65995 .46808 .66075 .46476 .65749 Mtetra
.417 .655 .957 r
.46476 .65749 .46808 .66075 .47391 .66141 .47059 .65811 Mtetra
.437 .662 .956 r
.47059 .65811 .47391 .66141 .47975 .66196 .47645 .65861 Mtetra
.455 .667 .954 r
.47645 .65861 .47975 .66196 .48562 .66239 .48232 .65899 Mtetra
.471 .672 .952 r
.48232 .65899 .48562 .66239 .49151 .6627 .48822 .65926 Mtetra
.487 .677 .949 r
.48822 .65926 .49151 .6627 .49742 .66289 .49413 .65942 Mtetra
.5 .68 .946 r
.49413 .65942 .49742 .66289 .50335 .66298 .50007 .65946 Mtetra
.513 .684 .943 r
.50007 .65946 .50335 .66298 .5093 .66296 .50603 .65941 Mtetra
.525 .686 .941 r
.50603 .65941 .5093 .66296 .51527 .66284 .512 .65925 Mtetra
.535 .689 .938 r
.512 .65925 .51527 .66284 .52126 .66262 .518 .65899 Mtetra
.545 .691 .935 r
.518 .65899 .52126 .66262 .52727 .66231 .52401 .65864 Mtetra
.554 .693 .932 r
.52401 .65864 .52727 .66231 .53329 .6619 .53004 .6582 Mtetra
.563 .695 .929 r
.53004 .6582 .53329 .6619 .53933 .66141 .53609 .65767 Mtetra
.571 .696 .926 r
.53609 .65767 .53933 .66141 .54539 .66082 .54215 .65705 Mtetra
.578 .697 .923 r
.54215 .65705 .54539 .66082 .55146 .66016 .54823 .65635 Mtetra
.585 .699 .921 r
.54823 .65635 .55146 .66016 .55755 .65941 .55433 .65557 Mtetra
.591 .7 .918 r
.55433 .65557 .55755 .65941 .56366 .65858 .56044 .65471 Mtetra
.597 .701 .916 r
.56044 .65471 .56366 .65858 .56978 .65767 .56657 .65378 Mtetra
.603 .701 .913 r
.56657 .65378 .56978 .65767 .57592 .65669 .57271 .65277 Mtetra
.608 .702 .911 r
.57271 .65277 .57592 .65669 .58207 .65564 .57887 .65169 Mtetra
.613 .703 .909 r
.57887 .65169 .58207 .65564 .58824 .65452 .58505 .65054 Mtetra
.617 .704 .907 r
.58505 .65054 .58824 .65452 .59442 .65333 .59123 .64933 Mtetra
.621 .704 .905 r
.59123 .64933 .59442 .65333 .60062 .65207 .59744 .64804 Mtetra
.626 .705 .903 r
.59744 .64804 .60062 .65207 .60683 .65075 .60365 .6467 Mtetra
.629 .706 .901 r
.60365 .6467 .60683 .65075 .61305 .64936 .60989 .64529 Mtetra
.633 .706 .899 r
.60989 .64529 .61305 .64936 .61929 .64792 .61613 .64382 Mtetra
.637 .707 .897 r
.61613 .64382 .61929 .64792 .62554 .64641 .62239 .64229 Mtetra
.64 .707 .896 r
.62239 .64229 .62554 .64641 .6318 .64484 .62866 .64071 Mtetra
.643 .708 .894 r
.62866 .64071 .6318 .64484 .63808 .64321 .63494 .63906 Mtetra
.646 .709 .893 r
.63494 .63906 .63808 .64321 .64437 .64153 .64124 .63736 Mtetra
.649 .709 .891 r
.64124 .63736 .64437 .64153 .65067 .63979 .64755 .63561 Mtetra
.652 .71 .89 r
.64755 .63561 .65067 .63979 .65698 .638 .65387 .6338 Mtetra
.655 .711 .889 r
.65387 .6338 .65698 .638 .66331 .63615 .66021 .63193 Mtetra
.658 .711 .887 r
.66021 .63193 .66331 .63615 .66965 .63424 .66655 .63001 Mtetra
.661 .712 .886 r
.66655 .63001 .66965 .63424 .676 .63228 .67291 .62804 Mtetra
.663 .713 .885 r
.67291 .62804 .676 .63228 .68236 .63027 .67928 .62602 Mtetra
.666 .714 .884 r
.67928 .62602 .68236 .63027 .68873 .6282 .68566 .62394 Mtetra
.668 .715 .883 r
.68566 .62394 .68873 .6282 .69511 .62608 .69205 .62181 Mtetra
.671 .716 .882 r
.69205 .62181 .69511 .62608 .70151 .6239 .69845 .61962 Mtetra
.673 .717 .881 r
.69845 .61962 .70151 .6239 .70791 .62167 .70487 .61738 Mtetra
.676 .718 .88 r
.70487 .61738 .70791 .62167 .71433 .61938 .71129 .61509 Mtetra
.679 .719 .879 r
.71129 .61509 .71433 .61938 .72075 .61704 .71772 .61274 Mtetra
.681 .72 .879 r
.71772 .61274 .72075 .61704 .72719 .61463 .72417 .61034 Mtetra
.684 .721 .878 r
.72417 .61034 .72719 .61463 .73363 .61218 .73062 .60788 Mtetra
.686 .722 .877 r
.73062 .60788 .73363 .61218 .74008 .60966 .73708 .60536 Mtetra
.689 .724 .876 r
.73708 .60536 .74008 .60966 .74654 .60708 .74355 .60279 Mtetra
.692 .725 .876 r
.74355 .60279 .74654 .60708 .75301 .60444 .75003 .60015 Mtetra
.695 .727 .875 r
.75003 .60015 .75301 .60444 .75949 .60174 .75652 .59745 Mtetra
.697 .728 .874 r
.75652 .59745 .75949 .60174 .76597 .59897 .76301 .59469 Mtetra
.7 .73 .874 r
.76301 .59469 .76597 .59897 .77246 .59614 .76951 .59186 Mtetra
.703 .732 .873 r
.76951 .59186 .77246 .59614 .77896 .59324 .77602 .58896 Mtetra
.706 .734 .872 r
.77602 .58896 .77896 .59324 .78546 .59026 .78253 .58599 Mtetra
.71 .736 .872 r
.78253 .58599 .78546 .59026 .79197 .58721 .78905 .58296 Mtetra
.713 .738 .871 r
.78905 .58296 .79197 .58721 .79848 .58409 .79557 .57984 Mtetra
.716 .74 .87 r
.79557 .57984 .79848 .58409 .80499 .58089 .8021 .57665 Mtetra
.72 .742 .869 r
.8021 .57665 .80499 .58089 .81151 .5776 .80863 .57338 Mtetra
.724 .745 .869 r
.80863 .57338 .81151 .5776 .81804 .57423 .81517 .57003 Mtetra
.727 .747 .868 r
.81517 .57003 .81804 .57423 .82456 .57078 .82171 .56658 Mtetra
.731 .75 .867 r
.82171 .56658 .82456 .57078 .83109 .56723 .82825 .56305 Mtetra
.735 .753 .866 r
.82825 .56305 .83109 .56723 .83761 .56358 .83478 .55943 Mtetra
.74 .755 .865 r
.83478 .55943 .83761 .56358 .84414 .55983 .84132 .5557 Mtetra
.744 .758 .864 r
.84132 .5557 .84414 .55983 .85066 .55599 .84786 .55187 Mtetra
.748 .762 .863 r
.84786 .55187 .85066 .55599 .85718 .55203 .8544 .54794 Mtetra
.753 .765 .862 r
.8544 .54794 .85718 .55203 .8637 .54796 .86093 .54389 Mtetra
.758 .768 .861 r
.86093 .54389 .8637 .54796 .87021 .54377 .86746 .53973 Mtetra
.763 .771 .86 r
.86746 .53973 .87021 .54377 .87672 .53946 .87398 .53545 Mtetra
.768 .775 .858 r
.87398 .53545 .87672 .53946 .88322 .53502 .88049 .53104 Mtetra
.774 .779 .857 r
.88049 .53104 .88322 .53502 .88971 .53045 .887 .5265 Mtetra
.779 .782 .855 r
.887 .5265 .88971 .53045 .89619 .52574 .8935 .52182 Mtetra
.785 .786 .853 r
.8935 .52182 .89619 .52574 .90265 .52088 .89998 .517 Mtetra
.791 .79 .852 r
.89998 .517 .90265 .52088 .90911 .51587 .90646 .51203 Mtetra
.797 .794 .849 r
.90646 .51203 .90911 .51587 .91555 .51071 .91291 .5069 Mtetra
.804 .799 .847 r
.91291 .5069 .91555 .51071 .92197 .50538 .91936 .50161 Mtetra
.81 .803 .845 r
.91936 .50161 .92197 .50538 .92838 .49987 .92578 .49615 Mtetra
.817 .807 .842 r
.92578 .49615 .92838 .49987 .93476 .49419 .93218 .49051 Mtetra
.695 .157 0 r
.3249 .58711 .32837 .58905 .33338 .59423 .32992 .59222 Mtetra
.663 .117 0 r
.32992 .59222 .33338 .59423 .33844 .59916 .33498 .59709 Mtetra
.626 .074 0 r
.33498 .59709 .33844 .59916 .34355 .60385 .34009 .60172 Mtetra
.584 .028 0 r
.34009 .60172 .34355 .60385 .34869 .60832 .34524 .60612 Mtetra
.538 0 0 r
.34524 .60612 .34869 .60832 .35388 .61255 .35043 .6103 Mtetra
.487 0 0 r
.35043 .6103 .35388 .61255 .35911 .61657 .35567 .61425 Mtetra
.432 0 0 r
.35567 .61425 .35911 .61657 .36438 .62036 .36094 .61799 Mtetra
0 .172 .607 r
.36094 .61799 .36438 .62036 .36968 .62395 .36625 .62152 Mtetra
0 .223 .66 r
.36625 .62152 .36968 .62395 .37503 .62733 .3716 .62484 Mtetra
0 .272 .71 r
.3716 .62484 .37503 .62733 .3804 .63051 .37698 .62797 Mtetra
0 .319 .755 r
.37698 .62797 .3804 .63051 .38582 .6335 .3824 .6309 Mtetra
0 .363 .795 r
.3824 .6309 .38582 .6335 .39127 .63629 .38786 .63364 Mtetra
0 .404 .829 r
.38786 .63364 .39127 .63629 .39675 .6389 .39334 .63619 Mtetra
0 .441 .859 r
.39334 .63619 .39675 .6389 .40226 .64133 .39886 .63857 Mtetra
.043 .475 .883 r
.39886 .63857 .40226 .64133 .4078 .64358 .40441 .64077 Mtetra
.094 .504 .903 r
.40441 .64077 .4078 .64358 .41338 .64567 .40999 .6428 Mtetra
.141 .531 .919 r
.40999 .6428 .41338 .64567 .41898 .64758 .4156 .64467 Mtetra
.185 .554 .932 r
.4156 .64467 .41898 .64758 .42461 .64934 .42124 .64637 Mtetra
.225 .574 .941 r
.42124 .64637 .42461 .64934 .43027 .65094 .4269 .64792 Mtetra
.262 .591 .948 r
.4269 .64792 .43027 .65094 .43595 .65238 .43259 .64932 Mtetra
.296 .607 .953 r
.43259 .64932 .43595 .65238 .44167 .65368 .43831 .65057 Mtetra
.326 .62 .956 r
.43831 .65057 .44167 .65368 .4474 .65484 .44405 .65168 Mtetra
.354 .631 .958 r
.44405 .65168 .4474 .65484 .45317 .65585 .44982 .65265 Mtetra
.38 .641 .958 r
.44982 .65265 .45317 .65585 .45895 .65673 .45561 .65348 Mtetra
.403 .649 .958 r
.45561 .65348 .45895 .65673 .46476 .65749 .46143 .65419 Mtetra
.424 .657 .957 r
.46143 .65419 .46476 .65749 .47059 .65811 .46727 .65477 Mtetra
.443 .663 .955 r
.46727 .65477 .47059 .65811 .47645 .65861 .47313 .65523 Mtetra
.461 .669 .953 r
.47313 .65523 .47645 .65861 .48232 .65899 .47901 .65557 Mtetra
.477 .673 .951 r
.47901 .65557 .48232 .65899 .48822 .65926 .48491 .6558 Mtetra
.491 .678 .948 r
.48491 .6558 .48822 .65926 .49413 .65942 .49083 .65591 Mtetra
.505 .681 .945 r
.49083 .65591 .49413 .65942 .50007 .65946 .49678 .65592 Mtetra
.517 .684 .943 r
.49678 .65592 .50007 .65946 .50603 .65941 .50274 .65583 Mtetra
.528 .687 .94 r
.50274 .65583 .50603 .65941 .512 .65925 .50872 .65563 Mtetra
.539 .69 .937 r
.50872 .65563 .512 .65925 .518 .65899 .51472 .65534 Mtetra
.548 .692 .934 r
.51472 .65534 .518 .65899 .52401 .65864 .52074 .65496 Mtetra
.557 .694 .931 r
.52074 .65496 .52401 .65864 .53004 .6582 .52678 .65448 Mtetra
.565 .695 .928 r
.52678 .65448 .53004 .6582 .53609 .65767 .53283 .65392 Mtetra
.573 .697 .925 r
.53283 .65392 .53609 .65767 .54215 .65705 .5389 .65327 Mtetra
.58 .698 .923 r
.5389 .65327 .54215 .65705 .54823 .65635 .54499 .65253 Mtetra
.587 .699 .92 r
.54499 .65253 .54823 .65635 .55433 .65557 .55109 .65172 Mtetra
.593 .7 .918 r
.55109 .65172 .55433 .65557 .56044 .65471 .55721 .65083 Mtetra
.599 .701 .915 r
.55721 .65083 .56044 .65471 .56657 .65378 .56335 .64987 Mtetra
.604 .702 .913 r
.56335 .64987 .56657 .65378 .57271 .65277 .5695 .64884 Mtetra
.609 .703 .911 r
.5695 .64884 .57271 .65277 .57887 .65169 .57566 .64773 Mtetra
.614 .704 .908 r
.57566 .64773 .57887 .65169 .58505 .65054 .58184 .64655 Mtetra
.618 .704 .906 r
.58184 .64655 .58505 .65054 .59123 .64933 .58804 .64531 Mtetra
.623 .705 .904 r
.58804 .64531 .59123 .64933 .59744 .64804 .59425 .64401 Mtetra
.627 .706 .902 r
.59425 .64401 .59744 .64804 .60365 .6467 .60047 .64264 Mtetra
.63 .706 .901 r
.60047 .64264 .60365 .6467 .60989 .64529 .60671 .64121 Mtetra
.634 .707 .899 r
.60671 .64121 .60989 .64529 .61613 .64382 .61296 .63972 Mtetra
.637 .707 .897 r
.61296 .63972 .61613 .64382 .62239 .64229 .61923 .63817 Mtetra
.641 .708 .896 r
.61923 .63817 .62239 .64229 .62866 .64071 .62551 .63656 Mtetra
.644 .709 .894 r
.62551 .63656 .62866 .64071 .63494 .63906 .6318 .6349 Mtetra
.647 .709 .893 r
.6318 .6349 .63494 .63906 .64124 .63736 .6381 .63319 Mtetra
.65 .71 .891 r
.6381 .63319 .64124 .63736 .64755 .63561 .64442 .63141 Mtetra
.653 .71 .89 r
.64442 .63141 .64755 .63561 .65387 .6338 .65075 .62959 Mtetra
.655 .711 .889 r
.65075 .62959 .65387 .6338 .66021 .63193 .65709 .62771 Mtetra
.658 .712 .888 r
.65709 .62771 .66021 .63193 .66655 .63001 .66345 .62578 Mtetra
.661 .713 .886 r
.66345 .62578 .66655 .63001 .67291 .62804 .66981 .6238 Mtetra
.663 .713 .885 r
.66981 .6238 .67291 .62804 .67928 .62602 .67619 .62176 Mtetra
.666 .714 .884 r
.67619 .62176 .67928 .62602 .68566 .62394 .68258 .61967 Mtetra
.668 .715 .883 r
.68258 .61967 .68566 .62394 .69205 .62181 .68898 .61753 Mtetra
.671 .716 .882 r
.68898 .61753 .69205 .62181 .69845 .61962 .69539 .61534 Mtetra
.673 .717 .882 r
.69539 .61534 .69845 .61962 .70487 .61738 .70181 .61309 Mtetra
.676 .718 .881 r
.70181 .61309 .70487 .61738 .71129 .61509 .70824 .6108 Mtetra
.678 .719 .88 r
.70824 .6108 .71129 .61509 .71772 .61274 .71469 .60844 Mtetra
.681 .72 .879 r
.71469 .60844 .71772 .61274 .72417 .61034 .72114 .60604 Mtetra
.683 .721 .878 r
.72114 .60604 .72417 .61034 .73062 .60788 .7276 .60357 Mtetra
.686 .723 .878 r
.7276 .60357 .73062 .60788 .73708 .60536 .73407 .60106 Mtetra
.689 .724 .877 r
.73407 .60106 .73708 .60536 .74355 .60279 .74055 .59848 Mtetra
.691 .725 .876 r
.74055 .59848 .74355 .60279 .75003 .60015 .74704 .59584 Mtetra
.694 .727 .875 r
.74704 .59584 .75003 .60015 .75652 .59745 .75353 .59315 Mtetra
.697 .728 .875 r
.75353 .59315 .75652 .59745 .76301 .59469 .76004 .59039 Mtetra
.7 .73 .874 r
.76004 .59039 .76301 .59469 .76951 .59186 .76655 .58756 Mtetra
.703 .732 .873 r
.76655 .58756 .76951 .59186 .77602 .58896 .77307 .58467 Mtetra
.706 .734 .873 r
.77307 .58467 .77602 .58896 .78253 .58599 .77959 .58171 Mtetra
.709 .736 .872 r
.77959 .58171 .78253 .58599 .78905 .58296 .78612 .57868 Mtetra
.712 .738 .871 r
.78612 .57868 .78905 .58296 .79557 .57984 .79266 .57558 Mtetra
.715 .74 .871 r
.79266 .57558 .79557 .57984 .8021 .57665 .7992 .5724 Mtetra
.719 .742 .87 r
.7992 .5724 .8021 .57665 .80863 .57338 .80574 .56914 Mtetra
.723 .744 .869 r
.80574 .56914 .80863 .57338 .81517 .57003 .81229 .5658 Mtetra
.726 .747 .868 r
.81229 .5658 .81517 .57003 .82171 .56658 .81884 .56237 Mtetra
.73 .749 .868 r
.81884 .56237 .82171 .56658 .82825 .56305 .82539 .55886 Mtetra
.734 .752 .867 r
.82539 .55886 .82825 .56305 .83478 .55943 .83194 .55525 Mtetra
.738 .755 .866 r
.83194 .55525 .83478 .55943 .84132 .5557 .8385 .55154 Mtetra
.743 .758 .865 r
.8385 .55154 .84132 .5557 .84786 .55187 .84505 .54774 Mtetra
.747 .761 .864 r
.84505 .54774 .84786 .55187 .8544 .54794 .8516 .54382 Mtetra
.752 .764 .863 r
.8516 .54382 .8544 .54794 .86093 .54389 .85815 .5398 Mtetra
.756 .767 .861 r
.85815 .5398 .86093 .54389 .86746 .53973 .86469 .53567 Mtetra
.761 .77 .86 r
.86469 .53567 .86746 .53973 .87398 .53545 .87123 .53141 Mtetra
.767 .774 .859 r
.87123 .53141 .87398 .53545 .88049 .53104 .87776 .52703 Mtetra
.772 .777 .857 r
.87776 .52703 .88049 .53104 .887 .5265 .88428 .52252 Mtetra
.777 .781 .856 r
.88428 .52252 .887 .5265 .8935 .52182 .89079 .51787 Mtetra
.783 .785 .854 r
.89079 .51787 .8935 .52182 .89998 .517 .8973 .51308 Mtetra
.789 .789 .852 r
.8973 .51308 .89998 .517 .90646 .51203 .90379 .50814 Mtetra
.795 .793 .85 r
.90379 .50814 .90646 .51203 .91291 .5069 .91026 .50305 Mtetra
.801 .797 .847 r
.91026 .50305 .91291 .5069 .91936 .50161 .91672 .4978 Mtetra
.808 .801 .845 r
.91672 .4978 .91936 .50161 .92578 .49615 .92317 .49238 Mtetra
.814 .805 .842 r
.92317 .49238 .92578 .49615 .93218 .49051 .92959 .48678 Mtetra
.684 .144 0 r
.32142 .58508 .3249 .58711 .32992 .59222 .32644 .59013 Mtetra
.649 .102 0 r
.32644 .59013 .32992 .59222 .33498 .59709 .33151 .59494 Mtetra
.61 .058 0 r
.33151 .59494 .33498 .59709 .34009 .60172 .33662 .59952 Mtetra
.567 .011 0 r
.33662 .59952 .34009 .60172 .34524 .60612 .34178 .60386 Mtetra
.519 0 0 r
.34178 .60386 .34524 .60612 .35043 .6103 .34698 .60798 Mtetra
.467 0 0 r
.34698 .60798 .35043 .6103 .35567 .61425 .35221 .61188 Mtetra
.411 0 0 r
.35221 .61188 .35567 .61425 .36094 .61799 .35749 .61556 Mtetra
0 .19 .628 r
.35749 .61556 .36094 .61799 .36625 .62152 .36281 .61903 Mtetra
0 .24 .68 r
.36281 .61903 .36625 .62152 .3716 .62484 .36816 .6223 Mtetra
0 .289 .728 r
.36816 .6223 .3716 .62484 .37698 .62797 .37355 .62537 Mtetra
0 .334 .77 r
.37355 .62537 .37698 .62797 .3824 .6309 .37898 .62825 Mtetra
0 .377 .808 r
.37898 .62825 .3824 .6309 .38786 .63364 .38443 .63093 Mtetra
0 .417 .84 r
.38443 .63093 .38786 .63364 .39334 .63619 .38993 .63343 Mtetra
.009 .452 .868 r
.38993 .63343 .39334 .63619 .39886 .63857 .39545 .63576 Mtetra
.062 .484 .891 r
.39545 .63576 .39886 .63857 .40441 .64077 .401 .63791 Mtetra
.111 .513 .909 r
.401 .63791 .40441 .64077 .40999 .6428 .40659 .63989 Mtetra
.157 .538 .924 r
.40659 .63989 .40999 .6428 .4156 .64467 .4122 .64171 Mtetra
.199 .56 .935 r
.4122 .64171 .4156 .64467 .42124 .64637 .41785 .64336 Mtetra
.238 .579 .944 r
.41785 .64336 .42124 .64637 .4269 .64792 .42352 .64486 Mtetra
.274 .596 .95 r
.42352 .64486 .4269 .64792 .43259 .64932 .42922 .64622 Mtetra
.306 .61 .954 r
.42922 .64622 .43259 .64932 .43831 .65057 .43494 .64742 Mtetra
.336 .623 .956 r
.43494 .64742 .43831 .65057 .44405 .65168 .44069 .64848 Mtetra
.363 .634 .958 r
.44069 .64848 .44405 .65168 .44982 .65265 .44646 .64941 Mtetra
.387 .643 .958 r
.44646 .64941 .44982 .65265 .45561 .65348 .45226 .6502 Mtetra
.41 .651 .957 r
.45226 .6502 .45561 .65348 .46143 .65419 .45808 .65087 Mtetra
.43 .659 .956 r
.45808 .65087 .46143 .65419 .46727 .65477 .46393 .65141 Mtetra
.449 .665 .954 r
.46393 .65141 .46727 .65477 .47313 .65523 .46979 .65182 Mtetra
.466 .67 .952 r
.46979 .65182 .47313 .65523 .47901 .65557 .47568 .65212 Mtetra
.481 .675 .95 r
.47568 .65212 .47901 .65557 .48491 .6558 .48159 .65231 Mtetra
.495 .679 .947 r
.48159 .65231 .48491 .6558 .49083 .65591 .48752 .65239 Mtetra
.508 .682 .944 r
.48752 .65239 .49083 .65591 .49678 .65592 .49347 .65236 Mtetra
.52 .685 .942 r
.49347 .65236 .49678 .65592 .50274 .65583 .49944 .65223 Mtetra
.531 .688 .939 r
.49944 .65223 .50274 .65583 .50872 .65563 .50543 .652 Mtetra
.542 .69 .936 r
.50543 .652 .50872 .65563 .51472 .65534 .51143 .65167 Mtetra
.551 .692 .933 r
.51143 .65167 .51472 .65534 .52074 .65496 .51746 .65125 Mtetra
.56 .694 .93 r
.51746 .65125 .52074 .65496 .52678 .65448 .5235 .65074 Mtetra
.568 .696 .928 r
.5235 .65074 .52678 .65448 .53283 .65392 .52956 .65014 Mtetra
.575 .697 .925 r
.52956 .65014 .53283 .65392 .5389 .65327 .53564 .64946 Mtetra
.582 .699 .922 r
.53564 .64946 .5389 .65327 .54499 .65253 .54173 .6487 Mtetra
.589 .7 .92 r
.54173 .6487 .54499 .65253 .55109 .65172 .54784 .64786 Mtetra
.595 .701 .917 r
.54784 .64786 .55109 .65172 .55721 .65083 .55397 .64694 Mtetra
.6 .702 .915 r
.55397 .64694 .55721 .65083 .56335 .64987 .56011 .64595 Mtetra
.605 .703 .913 r
.56011 .64595 .56335 .64987 .5695 .64884 .56627 .64489 Mtetra
.61 .704 .91 r
.56627 .64489 .5695 .64884 .57566 .64773 .57244 .64376 Mtetra
.615 .704 .908 r
.57244 .64376 .57566 .64773 .58184 .64655 .57863 .64256 Mtetra
.619 .705 .906 r
.57863 .64256 .58184 .64655 .58804 .64531 .58483 .64129 Mtetra
.624 .706 .904 r
.58483 .64129 .58804 .64531 .59425 .64401 .59105 .63996 Mtetra
.628 .706 .902 r
.59105 .63996 .59425 .64401 .60047 .64264 .59728 .63857 Mtetra
.631 .707 .901 r
.59728 .63857 .60047 .64264 .60671 .64121 .60353 .63712 Mtetra
.635 .707 .899 r
.60353 .63712 .60671 .64121 .61296 .63972 .60978 .63561 Mtetra
.638 .708 .897 r
.60978 .63561 .61296 .63972 .61923 .63817 .61606 .63404 Mtetra
.641 .709 .896 r
.61606 .63404 .61923 .63817 .62551 .63656 .62234 .63242 Mtetra
.644 .709 .894 r
.62234 .63242 .62551 .63656 .6318 .6349 .62864 .63074 Mtetra
.647 .71 .893 r
.62864 .63074 .6318 .6349 .6381 .63319 .63495 .629 Mtetra
.65 .71 .892 r
.63495 .629 .6381 .63319 .64442 .63141 .64128 .62722 Mtetra
.653 .711 .89 r
.64128 .62722 .64442 .63141 .65075 .62959 .64762 .62538 Mtetra
.656 .712 .889 r
.64762 .62538 .65075 .62959 .65709 .62771 .65397 .62348 Mtetra
.658 .712 .888 r
.65397 .62348 .65709 .62771 .66345 .62578 .66033 .62154 Mtetra
.661 .713 .887 r
.66033 .62154 .66345 .62578 .66981 .6238 .6667 .61954 Mtetra
.663 .714 .886 r
.6667 .61954 .66981 .6238 .67619 .62176 .67309 .6175 Mtetra
.666 .715 .885 r
.67309 .6175 .67619 .62176 .68258 .61967 .67949 .6154 Mtetra
.668 .716 .884 r
.67949 .6154 .68258 .61967 .68898 .61753 .68589 .61325 Mtetra
.671 .717 .883 r
.68589 .61325 .68898 .61753 .69539 .61534 .69231 .61105 Mtetra
.673 .717 .882 r
.69231 .61105 .69539 .61534 .70181 .61309 .69874 .6088 Mtetra
.676 .718 .881 r
.69874 .6088 .70181 .61309 .70824 .6108 .70519 .6065 Mtetra
.678 .72 .88 r
.70519 .6065 .70824 .6108 .71469 .60844 .71164 .60414 Mtetra
.681 .721 .88 r
.71164 .60414 .71469 .60844 .72114 .60604 .7181 .60173 Mtetra
.683 .722 .879 r
.7181 .60173 .72114 .60604 .7276 .60357 .72457 .59926 Mtetra
.686 .723 .878 r
.72457 .59926 .7276 .60357 .73407 .60106 .73105 .59674 Mtetra
.688 .724 .877 r
.73105 .59674 .73407 .60106 .74055 .59848 .73754 .59417 Mtetra
.691 .726 .877 r
.73754 .59417 .74055 .59848 .74704 .59584 .74404 .59153 Mtetra
.694 .727 .876 r
.74404 .59153 .74704 .59584 .75353 .59315 .75054 .58884 Mtetra
.696 .729 .875 r
.75054 .58884 .75353 .59315 .76004 .59039 .75706 .58608 Mtetra
.699 .73 .875 r
.75706 .58608 .76004 .59039 .76655 .58756 .76358 .58326 Mtetra
.702 .732 .874 r
.76358 .58326 .76655 .58756 .77307 .58467 .77011 .58037 Mtetra
.705 .734 .873 r
.77011 .58037 .77307 .58467 .77959 .58171 .77664 .57742 Mtetra
.708 .736 .873 r
.77664 .57742 .77959 .58171 .78612 .57868 .78319 .5744 Mtetra
.711 .738 .872 r
.78319 .5744 .78612 .57868 .79266 .57558 .78973 .57131 Mtetra
.715 .74 .871 r
.78973 .57131 .79266 .57558 .7992 .5724 .79628 .56814 Mtetra
.718 .742 .87 r
.79628 .56814 .7992 .5724 .80574 .56914 .80284 .56489 Mtetra
.722 .744 .87 r
.80284 .56489 .80574 .56914 .81229 .5658 .8094 .56156 Mtetra
.725 .747 .869 r
.8094 .56156 .81229 .5658 .81884 .56237 .81596 .55815 Mtetra
.729 .749 .868 r
.81596 .55815 .81884 .56237 .82539 .55886 .82253 .55464 Mtetra
.733 .752 .867 r
.82253 .55464 .82539 .55886 .83194 .55525 .82909 .55105 Mtetra
.737 .754 .866 r
.82909 .55105 .83194 .55525 .8385 .55154 .83566 .54736 Mtetra
.741 .757 .865 r
.83566 .54736 .8385 .55154 .84505 .54774 .84222 .54358 Mtetra
.746 .76 .864 r
.84222 .54358 .84505 .54774 .8516 .54382 .84879 .53969 Mtetra
.75 .763 .863 r
.84879 .53969 .8516 .54382 .85815 .5398 .85535 .53569 Mtetra
.755 .766 .862 r
.85535 .53569 .85815 .5398 .86469 .53567 .86191 .53157 Mtetra
.76 .769 .861 r
.86191 .53157 .86469 .53567 .87123 .53141 .86846 .52734 Mtetra
.765 .773 .859 r
.86846 .52734 .87123 .53141 .87776 .52703 .87501 .52299 Mtetra
.77 .776 .858 r
.87501 .52299 .87776 .52703 .88428 .52252 .88155 .5185 Mtetra
.776 .78 .856 r
.88155 .5185 .88428 .52252 .89079 .51787 .88808 .51389 Mtetra
.781 .783 .854 r
.88808 .51389 .89079 .51787 .8973 .51308 .8946 .50913 Mtetra
.787 .787 .852 r
.8946 .50913 .8973 .51308 .90379 .50814 .90111 .50422 Mtetra
.793 .791 .85 r
.90111 .50422 .90379 .50814 .91026 .50305 .9076 .49916 Mtetra
.799 .795 .848 r
.9076 .49916 .91026 .50305 .91672 .4978 .91408 .49394 Mtetra
.806 .799 .845 r
.91408 .49394 .91672 .4978 .92317 .49238 .92054 .48856 Mtetra
.812 .803 .843 r
.92054 .48856 .92317 .49238 .92959 .48678 .92698 .483 Mtetra
.672 .13 0 r
.31793 .58298 .32142 .58508 .32644 .59013 .32295 .58798 Mtetra
.636 .088 0 r
.32295 .58798 .32644 .59013 .33151 .59494 .32803 .59273 Mtetra
.595 .042 0 r
.32803 .59273 .33151 .59494 .33662 .59952 .33314 .59725 Mtetra
.55 0 0 r
.33314 .59725 .33662 .59952 .34178 .60386 .3383 .60153 Mtetra
.5 0 0 r
.3383 .60153 .34178 .60386 .34698 .60798 .34351 .60559 Mtetra
.446 0 0 r
.34351 .60559 .34698 .60798 .35221 .61188 .34875 .60944 Mtetra
0 .156 .595 r
.34875 .60944 .35221 .61188 .35749 .61556 .35403 .61306 Mtetra
0 .207 .648 r
.35403 .61306 .35749 .61556 .36281 .61903 .35935 .61648 Mtetra
0 .256 .698 r
.35935 .61648 .36281 .61903 .36816 .6223 .36471 .6197 Mtetra
0 .304 .744 r
.36471 .6197 .36816 .6223 .37355 .62537 .37011 .62272 Mtetra
0 .348 .784 r
.37011 .62272 .37355 .62537 .37898 .62825 .37554 .62554 Mtetra
0 .39 .82 r
.37554 .62554 .37898 .62825 .38443 .63093 .381 .62818 Mtetra
0 .428 .85 r
.381 .62818 .38443 .63093 .38993 .63343 .3865 .63063 Mtetra
.027 .462 .876 r
.3865 .63063 .38993 .63343 .39545 .63576 .39203 .6329 Mtetra
.079 .493 .897 r
.39203 .6329 .39545 .63576 .401 .63791 .39759 .635 Mtetra
.127 .52 .914 r
.39759 .635 .401 .63791 .40659 .63989 .40318 .63694 Mtetra
.172 .544 .927 r
.40318 .63694 .40659 .63989 .4122 .64171 .4088 .63871 Mtetra
.213 .565 .938 r
.4088 .63871 .4122 .64171 .41785 .64336 .41445 .64032 Mtetra
.25 .584 .945 r
.41445 .64032 .41785 .64336 .42352 .64486 .42012 .64177 Mtetra
.285 .6 .951 r
.42012 .64177 .42352 .64486 .42922 .64622 .42583 .64308 Mtetra
.316 .614 .954 r
.42583 .64308 .42922 .64622 .43494 .64742 .43156 .64424 Mtetra
.345 .626 .957 r
.43156 .64424 .43494 .64742 .44069 .64848 .43731 .64526 Mtetra
.371 .636 .958 r
.43731 .64526 .44069 .64848 .44646 .64941 .44309 .64614 Mtetra
.395 .646 .958 r
.44309 .64614 .44646 .64941 .45226 .6502 .4489 .64689 Mtetra
.416 .653 .957 r
.4489 .64689 .45226 .6502 .45808 .65087 .45472 .64751 Mtetra
.436 .66 .955 r
.45472 .64751 .45808 .65087 .46393 .65141 .46057 .64801 Mtetra
.454 .666 .954 r
.46057 .64801 .46393 .65141 .46979 .65182 .46645 .64839 Mtetra
.47 .671 .951 r
.46645 .64839 .46979 .65182 .47568 .65212 .47234 .64865 Mtetra
.486 .676 .949 r
.47234 .64865 .47568 .65212 .48159 .65231 .47826 .6488 Mtetra
.499 .68 .946 r
.47826 .6488 .48159 .65231 .48752 .65239 .48419 .64884 Mtetra
.512 .683 .944 r
.48419 .64884 .48752 .65239 .49347 .65236 .49015 .64878 Mtetra
.524 .686 .941 r
.49015 .64878 .49347 .65236 .49944 .65223 .49612 .64861 Mtetra
.534 .689 .938 r
.49612 .64861 .49944 .65223 .50543 .652 .50212 .64834 Mtetra
.544 .691 .935 r
.50212 .64834 .50543 .652 .51143 .65167 .50813 .64798 Mtetra
.553 .693 .933 r
.50813 .64798 .51143 .65167 .51746 .65125 .51416 .64753 Mtetra
.562 .695 .93 r
.51416 .64753 .51746 .65125 .5235 .65074 .52021 .64699 Mtetra
.57 .697 .927 r
.52021 .64699 .5235 .65074 .52956 .65014 .52628 .64636 Mtetra
.577 .698 .925 r
.52628 .64636 .52956 .65014 .53564 .64946 .53236 .64565 Mtetra
.584 .7 .922 r
.53236 .64565 .53564 .64946 .54173 .6487 .53846 .64486 Mtetra
.59 .701 .919 r
.53846 .64486 .54173 .6487 .54784 .64786 .54458 .64399 Mtetra
.596 .702 .917 r
.54458 .64399 .54784 .64786 .55397 .64694 .55071 .64304 Mtetra
.602 .703 .915 r
.55071 .64304 .55397 .64694 .56011 .64595 .55686 .64202 Mtetra
.607 .704 .912 r
.55686 .64202 .56011 .64595 .56627 .64489 .56303 .64093 Mtetra
.612 .704 .91 r
.56303 .64093 .56627 .64489 .57244 .64376 .56921 .63978 Mtetra
.616 .705 .908 r
.56921 .63978 .57244 .64376 .57863 .64256 .5754 .63855 Mtetra
.62 .706 .906 r
.5754 .63855 .57863 .64256 .58483 .64129 .58161 .63726 Mtetra
.625 .706 .904 r
.58161 .63726 .58483 .64129 .59105 .63996 .58784 .63591 Mtetra
.628 .707 .903 r
.58784 .63591 .59105 .63996 .59728 .63857 .59408 .6345 Mtetra
.632 .708 .901 r
.59408 .6345 .59728 .63857 .60353 .63712 .60033 .63303 Mtetra
.635 .708 .899 r
.60033 .63303 .60353 .63712 .60978 .63561 .60659 .6315 Mtetra
.639 .709 .898 r
.60659 .6315 .60978 .63561 .61606 .63404 .61287 .62991 Mtetra
.642 .709 .896 r
.61287 .62991 .61606 .63404 .62234 .63242 .61917 .62827 Mtetra
.645 .71 .895 r
.61917 .62827 .62234 .63242 .62864 .63074 .62548 .62657 Mtetra
.648 .711 .893 r
.62548 .62657 .62864 .63074 .63495 .629 .6318 .62482 Mtetra
.651 .711 .892 r
.6318 .62482 .63495 .629 .64128 .62722 .63813 .62302 Mtetra
.653 .712 .891 r
.63813 .62302 .64128 .62722 .64762 .62538 .64447 .62116 Mtetra
.656 .713 .89 r
.64447 .62116 .64762 .62538 .65397 .62348 .65083 .61926 Mtetra
.659 .713 .888 r
.65083 .61926 .65397 .62348 .66033 .62154 .6572 .6173 Mtetra
.661 .714 .887 r
.6572 .6173 .66033 .62154 .6667 .61954 .66358 .61529 Mtetra
.664 .715 .886 r
.66358 .61529 .6667 .61954 .67309 .6175 .66998 .61324 Mtetra
.666 .716 .885 r
.66998 .61324 .67309 .6175 .67949 .6154 .67638 .61113 Mtetra
.669 .716 .884 r
.67638 .61113 .67949 .6154 .68589 .61325 .6828 .60897 Mtetra
.671 .717 .883 r
.6828 .60897 .68589 .61325 .69231 .61105 .68923 .60676 Mtetra
.673 .718 .883 r
.68923 .60676 .69231 .61105 .69874 .6088 .69567 .6045 Mtetra
.676 .719 .882 r
.69567 .6045 .69874 .6088 .70519 .6065 .70212 .60219 Mtetra
.678 .72 .881 r
.70212 .60219 .70519 .6065 .71164 .60414 .70858 .59983 Mtetra
.681 .721 .88 r
.70858 .59983 .71164 .60414 .7181 .60173 .71505 .59742 Mtetra
.683 .722 .879 r
.71505 .59742 .7181 .60173 .72457 .59926 .72153 .59495 Mtetra
.685 .724 .879 r
.72153 .59495 .72457 .59926 .73105 .59674 .72802 .59243 Mtetra
.688 .725 .878 r
.72802 .59243 .73105 .59674 .73754 .59417 .73452 .58985 Mtetra
.691 .726 .877 r
.73452 .58985 .73754 .59417 .74404 .59153 .74103 .58721 Mtetra
.693 .728 .877 r
.74103 .58721 .74404 .59153 .75054 .58884 .74754 .58452 Mtetra
.696 .729 .876 r
.74754 .58452 .75054 .58884 .75706 .58608 .75407 .58177 Mtetra
.699 .731 .875 r
.75407 .58177 .75706 .58608 .76358 .58326 .7606 .57895 Mtetra
.702 .732 .875 r
.7606 .57895 .76358 .58326 .77011 .58037 .76714 .57607 Mtetra
.704 .734 .874 r
.76714 .57607 .77011 .58037 .77664 .57742 .77369 .57312 Mtetra
.708 .736 .873 r
.77369 .57312 .77664 .57742 .78319 .5744 .78024 .57011 Mtetra
.711 .738 .873 r
.78024 .57011 .78319 .5744 .78973 .57131 .7868 .56702 Mtetra
.714 .74 .872 r
.7868 .56702 .78973 .57131 .79628 .56814 .79336 .56386 Mtetra
.717 .742 .871 r
.79336 .56386 .79628 .56814 .80284 .56489 .79993 .56062 Mtetra
.721 .744 .87 r
.79993 .56062 .80284 .56489 .8094 .56156 .8065 .55731 Mtetra
.724 .746 .869 r
.8065 .55731 .8094 .56156 .81596 .55815 .81307 .55391 Mtetra
.728 .749 .869 r
.81307 .55391 .81596 .55815 .82253 .55464 .81965 .55042 Mtetra
.732 .751 .868 r
.81965 .55042 .82253 .55464 .82909 .55105 .82623 .54684 Mtetra
.736 .754 .867 r
.82623 .54684 .82909 .55105 .83566 .54736 .83281 .54317 Mtetra
.74 .757 .866 r
.83281 .54317 .83566 .54736 .84222 .54358 .83939 .5394 Mtetra
.745 .759 .865 r
.83939 .5394 .84222 .54358 .84879 .53969 .84597 .53553 Mtetra
.749 .762 .864 r
.84597 .53553 .84879 .53969 .85535 .53569 .85254 .53155 Mtetra
.754 .765 .862 r
.85254 .53155 .85535 .53569 .86191 .53157 .85912 .52746 Mtetra
.759 .769 .861 r
.85912 .52746 .86191 .53157 .86846 .52734 .86568 .52325 Mtetra
.764 .772 .86 r
.86568 .52325 .86846 .52734 .87501 .52299 .87225 .51892 Mtetra
.769 .775 .858 r
.87225 .51892 .87501 .52299 .88155 .5185 .8788 .51446 Mtetra
.774 .779 .856 r
.8788 .51446 .88155 .5185 .88808 .51389 .88535 .50987 Mtetra
.78 .782 .855 r
.88535 .50987 .88808 .51389 .8946 .50913 .89189 .50514 Mtetra
.785 .786 .853 r
.89189 .50514 .8946 .50913 .90111 .50422 .89841 .50026 Mtetra
.791 .79 .851 r
.89841 .50026 .90111 .50422 .9076 .49916 .90492 .49524 Mtetra
.797 .793 .848 r
.90492 .49524 .9076 .49916 .91408 .49394 .91142 .49005 Mtetra
.804 .797 .846 r
.91142 .49005 .91408 .49394 .92054 .48856 .9179 .4847 Mtetra
.81 .801 .843 r
.9179 .4847 .92054 .48856 .92698 .483 .92436 .47918 Mtetra
.66 .116 0 r
.31442 .58081 .31793 .58298 .32295 .58798 .31945 .58575 Mtetra
.622 .073 0 r
.31945 .58575 .32295 .58798 .32803 .59273 .32453 .59045 Mtetra
.579 .027 0 r
.32453 .59045 .32803 .59273 .33314 .59725 .32965 .59491 Mtetra
.532 0 0 r
.32965 .59491 .33314 .59725 .3383 .60153 .33482 .59914 Mtetra
.481 0 0 r
.33482 .59914 .3383 .60153 .34351 .60559 .34002 .60315 Mtetra
.426 0 0 r
.34002 .60315 .34351 .60559 .34875 .60944 .34527 .60694 Mtetra
0 .173 .615 r
.34527 .60694 .34875 .60944 .35403 .61306 .35056 .61051 Mtetra
0 .223 .667 r
.35056 .61051 .35403 .61306 .35935 .61648 .35589 .61388 Mtetra
0 .272 .715 r
.35589 .61388 .35935 .61648 .36471 .6197 .36125 .61705 Mtetra
0 .318 .758 r
.36125 .61705 .36471 .6197 .37011 .62272 .36665 .62001 Mtetra
0 .361 .797 r
.36665 .62001 .37011 .62272 .37554 .62554 .37209 .62279 Mtetra
0 .402 .831 r
.37209 .62279 .37554 .62554 .381 .62818 .37755 .62537 Mtetra
0 .438 .859 r
.37755 .62537 .381 .62818 .3865 .63063 .38306 .62778 Mtetra
.045 .471 .883 r
.38306 .62778 .3865 .63063 .39203 .6329 .38859 .63 Mtetra
.095 .501 .903 r
.38859 .63 .39203 .6329 .39759 .635 .39416 .63206 Mtetra
.142 .527 .918 r
.39416 .63206 .39759 .635 .40318 .63694 .39975 .63394 Mtetra
.185 .55 .931 r
.39975 .63394 .40318 .63694 .4088 .63871 .40538 .63567 Mtetra
.225 .571 .94 r
.40538 .63567 .4088 .63871 .41445 .64032 .41103 .63723 Mtetra
.261 .588 .947 r
.41103 .63723 .41445 .64032 .42012 .64177 .41672 .63864 Mtetra
.295 .604 .952 r
.41672 .63864 .42012 .64177 .42583 .64308 .42243 .63991 Mtetra
.325 .617 .955 r
.42243 .63991 .42583 .64308 .43156 .64424 .42816 .64102 Mtetra
.353 .629 .957 r
.42816 .64102 .43156 .64424 .43731 .64526 .43392 .642 Mtetra
.378 .639 .957 r
.43392 .642 .43731 .64526 .44309 .64614 .43971 .64284 Mtetra
.401 .648 .957 r
.43971 .64284 .44309 .64614 .4489 .64689 .44552 .64355 Mtetra
.422 .655 .956 r
.44552 .64355 .4489 .64689 .45472 .64751 .45135 .64414 Mtetra
.441 .662 .955 r
.45135 .64414 .45472 .64751 .46057 .64801 .45721 .6446 Mtetra
.459 .668 .953 r
.45721 .6446 .46057 .64801 .46645 .64839 .46309 .64494 Mtetra
.475 .673 .951 r
.46309 .64494 .46645 .64839 .47234 .64865 .46899 .64516 Mtetra
.489 .677 .948 r
.46899 .64516 .47234 .64865 .47826 .6488 .47491 .64527 Mtetra
.503 .681 .946 r
.47491 .64527 .47826 .6488 .48419 .64884 .48085 .64528 Mtetra
.515 .684 .943 r
.48085 .64528 .48419 .64884 .49015 .64878 .48681 .64518 Mtetra
.527 .687 .94 r
.48681 .64518 .49015 .64878 .49612 .64861 .4928 .64498 Mtetra
.537 .69 .938 r
.4928 .64498 .49612 .64861 .50212 .64834 .4988 .64468 Mtetra
.547 .692 .935 r
.4988 .64468 .50212 .64834 .50813 .64798 .50482 .64428 Mtetra
.556 .694 .932 r
.50482 .64428 .50813 .64798 .51416 .64753 .51086 .6438 Mtetra
.564 .696 .93 r
.51086 .6438 .51416 .64753 .52021 .64699 .51691 .64322 Mtetra
.572 .698 .927 r
.51691 .64322 .52021 .64699 .52628 .64636 .52299 .64257 Mtetra
.579 .699 .924 r
.52299 .64257 .52628 .64636 .53236 .64565 .52908 .64183 Mtetra
.586 .7 .922 r
.52908 .64183 .53236 .64565 .53846 .64486 .53518 .641 Mtetra
.592 .702 .919 r
.53518 .641 .53846 .64486 .54458 .64399 .54131 .64011 Mtetra
.598 .703 .917 r
.54131 .64011 .54458 .64399 .55071 .64304 .54745 .63913 Mtetra
.603 .704 .915 r
.54745 .63913 .55071 .64304 .55686 .64202 .5536 .63809 Mtetra
.608 .705 .913 r
.5536 .63809 .55686 .64202 .56303 .64093 .55978 .63698 Mtetra
.613 .705 .91 r
.55978 .63698 .56303 .64093 .56921 .63978 .56596 .63579 Mtetra
.617 .706 .908 r
.56596 .63579 .56921 .63978 .5754 .63855 .57217 .63454 Mtetra
.621 .707 .907 r
.57217 .63454 .5754 .63855 .58161 .63726 .57838 .63323 Mtetra
.625 .707 .905 r
.57838 .63323 .58161 .63726 .58784 .63591 .58461 .63186 Mtetra
.629 .708 .903 r
.58461 .63186 .58784 .63591 .59408 .6345 .59086 .63042 Mtetra
.633 .709 .901 r
.59086 .63042 .59408 .6345 .60033 .63303 .59712 .62893 Mtetra
.636 .709 .9 r
.59712 .62893 .60033 .63303 .60659 .6315 .60339 .62738 Mtetra
.639 .71 .898 r
.60339 .62738 .60659 .6315 .61287 .62991 .60968 .62578 Mtetra
.643 .71 .897 r
.60968 .62578 .61287 .62991 .61917 .62827 .61598 .62412 Mtetra
.645 .711 .895 r
.61598 .62412 .61917 .62827 .62548 .62657 .6223 .6224 Mtetra
.648 .712 .894 r
.6223 .6224 .62548 .62657 .6318 .62482 .62862 .62064 Mtetra
.651 .712 .893 r
.62862 .62064 .6318 .62482 .63813 .62302 .63496 .61882 Mtetra
.654 .713 .891 r
.63496 .61882 .63813 .62302 .64447 .62116 .64132 .61695 Mtetra
.656 .714 .89 r
.64132 .61695 .64447 .62116 .65083 .61926 .64768 .61503 Mtetra
.659 .714 .889 r
.64768 .61503 .65083 .61926 .6572 .6173 .65406 .61306 Mtetra
.661 .715 .888 r
.65406 .61306 .6572 .6173 .66358 .61529 .66045 .61104 Mtetra
.664 .716 .887 r
.66045 .61104 .66358 .61529 .66998 .61324 .66685 .60897 Mtetra
.666 .716 .886 r
.66685 .60897 .66998 .61324 .67638 .61113 .67327 .60686 Mtetra
.669 .717 .885 r
.67327 .60686 .67638 .61113 .6828 .60897 .67969 .60469 Mtetra
.671 .718 .884 r
.67969 .60469 .6828 .60897 .68923 .60676 .68613 .60247 Mtetra
.673 .719 .883 r
.68613 .60247 .68923 .60676 .69567 .6045 .69258 .60021 Mtetra
.676 .72 .883 r
.69258 .60021 .69567 .6045 .70212 .60219 .69904 .59789 Mtetra
.678 .721 .882 r
.69904 .59789 .70212 .60219 .70858 .59983 .70551 .59553 Mtetra
.68 .722 .881 r
.70551 .59553 .70858 .59983 .71505 .59742 .71199 .59311 Mtetra
.683 .723 .88 r
.71199 .59311 .71505 .59742 .72153 .59495 .71848 .59064 Mtetra
.685 .724 .879 r
.71848 .59064 .72153 .59495 .72802 .59243 .72498 .58811 Mtetra
.688 .726 .879 r
.72498 .58811 .72802 .59243 .73452 .58985 .73149 .58553 Mtetra
.69 .727 .878 r
.73149 .58553 .73452 .58985 .74103 .58721 .738 .5829 Mtetra
.693 .728 .877 r
.738 .5829 .74103 .58721 .74754 .58452 .74453 .5802 Mtetra
.696 .73 .877 r
.74453 .5802 .74754 .58452 .75407 .58177 .75107 .57745 Mtetra
.698 .731 .876 r
.75107 .57745 .75407 .58177 .7606 .57895 .75761 .57464 Mtetra
.701 .733 .875 r
.75761 .57464 .7606 .57895 .76714 .57607 .76416 .57176 Mtetra
.704 .734 .875 r
.76416 .57176 .76714 .57607 .77369 .57312 .77072 .56882 Mtetra
.707 .736 .874 r
.77072 .56882 .77369 .57312 .78024 .57011 .77728 .56581 Mtetra
.71 .738 .873 r
.77728 .56581 .78024 .57011 .7868 .56702 .78385 .56273 Mtetra
.713 .74 .873 r
.78385 .56273 .7868 .56702 .79336 .56386 .79042 .55958 Mtetra
.717 .742 .872 r
.79042 .55958 .79336 .56386 .79993 .56062 .797 .55635 Mtetra
.72 .744 .871 r
.797 .55635 .79993 .56062 .8065 .55731 .80359 .55304 Mtetra
.724 .746 .87 r
.80359 .55304 .8065 .55731 .81307 .55391 .81018 .54965 Mtetra
.727 .749 .869 r
.81018 .54965 .81307 .55391 .81965 .55042 .81677 .54618 Mtetra
.731 .751 .868 r
.81677 .54618 .81965 .55042 .82623 .54684 .82336 .54262 Mtetra
.735 .754 .867 r
.82336 .54262 .82623 .54684 .83281 .54317 .82995 .53896 Mtetra
.739 .756 .866 r
.82995 .53896 .83281 .54317 .83939 .5394 .83654 .53521 Mtetra
.743 .759 .865 r
.83654 .53521 .83939 .5394 .84597 .53553 .84314 .53135 Mtetra
.748 .762 .864 r
.84314 .53135 .84597 .53553 .85254 .53155 .84973 .52739 Mtetra
.753 .765 .863 r
.84973 .52739 .85254 .53155 .85912 .52746 .85631 .52332 Mtetra
.757 .768 .862 r
.85631 .52332 .85912 .52746 .86568 .52325 .8629 .51913 Mtetra
.762 .771 .86 r
.8629 .51913 .86568 .52325 .87225 .51892 .86947 .51483 Mtetra
.767 .774 .859 r
.86947 .51483 .87225 .51892 .8788 .51446 .87604 .51039 Mtetra
.773 .778 .857 r
.87604 .51039 .8788 .51446 .88535 .50987 .88261 .50583 Mtetra
.778 .781 .855 r
.88261 .50583 .88535 .50987 .89189 .50514 .88916 .50112 Mtetra
.784 .785 .853 r
.88916 .50112 .89189 .50514 .89841 .50026 .8957 .49628 Mtetra
.79 .788 .851 r
.8957 .49628 .89841 .50026 .90492 .49524 .90223 .49128 Mtetra
.796 .792 .849 r
.90223 .49128 .90492 .49524 .91142 .49005 .90875 .48613 Mtetra
.802 .796 .846 r
.90875 .48613 .91142 .49005 .9179 .4847 .91525 .48081 Mtetra
.808 .8 .844 r
.91525 .48081 .9179 .4847 .92436 .47918 .92173 .47532 Mtetra
.647 .103 0 r
.31091 .57857 .31442 .58081 .31945 .58575 .31594 .58345 Mtetra
.608 .059 0 r
.31594 .58345 .31945 .58575 .32453 .59045 .32102 .5881 Mtetra
.564 .012 0 r
.32102 .5881 .32453 .59045 .32965 .59491 .32615 .59251 Mtetra
.515 0 0 r
.32615 .59251 .32965 .59491 .33482 .59914 .33132 .59669 Mtetra
.463 0 0 r
.33132 .59669 .33482 .59914 .34002 .60315 .33653 .60064 Mtetra
0 .138 .579 r
.33653 .60064 .34002 .60315 .34527 .60694 .34178 .60438 Mtetra
0 .188 .633 r
.34178 .60438 .34527 .60694 .35056 .61051 .34708 .60791 Mtetra
0 .238 .684 r
.34708 .60791 .35056 .61051 .35589 .61388 .35241 .61123 Mtetra
0 .286 .73 r
.35241 .61123 .35589 .61388 .36125 .61705 .35778 .61434 Mtetra
0 .331 .772 r
.35778 .61434 .36125 .61705 .36665 .62001 .36318 .61726 Mtetra
0 .373 .808 r
.36318 .61726 .36665 .62001 .37209 .62279 .36862 .61999 Mtetra
0 .412 .84 r
.36862 .61999 .37209 .62279 .37755 .62537 .3741 .62253 Mtetra
.008 .448 .867 r
.3741 .62253 .37755 .62537 .38306 .62778 .3796 .62488 Mtetra
.061 .48 .889 r
.3796 .62488 .38306 .62778 .38859 .63 .38514 .62707 Mtetra
.11 .508 .908 r
.38514 .62707 .38859 .63 .39416 .63206 .39071 .62907 Mtetra
.155 .534 .922 r
.39071 .62907 .39416 .63206 .39975 .63394 .39632 .63092 Mtetra
.197 .556 .933 r
.39632 .63092 .39975 .63394 .40538 .63567 .40195 .6326 Mtetra
.236 .575 .942 r
.40195 .6326 .40538 .63567 .41103 .63723 .40761 .63412 Mtetra
.271 .592 .948 r
.40761 .63412 .41103 .63723 .41672 .63864 .4133 .63549 Mtetra
.304 .607 .953 r
.4133 .63549 .41672 .63864 .42243 .63991 .41901 .63671 Mtetra
.333 .62 .955 r
.41901 .63671 .42243 .63991 .42816 .64102 .42475 .63778 Mtetra
.36 .631 .957 r
.42475 .63778 .42816 .64102 .43392 .642 .43052 .63872 Mtetra
.385 .641 .957 r
.43052 .63872 .43392 .642 .43971 .64284 .43631 .63952 Mtetra
.407 .65 .957 r
.43631 .63952 .43971 .64284 .44552 .64355 .44213 .64019 Mtetra
.427 .657 .956 r
.44213 .64019 .44552 .64355 .45135 .64414 .44797 .64074 Mtetra
.446 .664 .954 r
.44797 .64074 .45135 .64414 .45721 .6446 .45383 .64116 Mtetra
.463 .669 .953 r
.45383 .64116 .45721 .6446 .46309 .64494 .45972 .64146 Mtetra
.479 .674 .95 r
.45972 .64146 .46309 .64494 .46899 .64516 .46562 .64165 Mtetra
.493 .678 .948 r
.46562 .64165 .46899 .64516 .47491 .64527 .47155 .64173 Mtetra
.506 .682 .945 r
.47155 .64173 .47491 .64527 .48085 .64528 .4775 .6417 Mtetra
.518 .686 .943 r
.4775 .6417 .48085 .64528 .48681 .64518 .48347 .64156 Mtetra
.529 .689 .94 r
.48347 .64156 .48681 .64518 .4928 .64498 .48946 .64133 Mtetra
.54 .691 .937 r
.48946 .64133 .4928 .64498 .4988 .64468 .49547 .641 Mtetra
.549 .693 .935 r
.49547 .641 .4988 .64468 .50482 .64428 .50149 .64057 Mtetra
.558 .695 .932 r
.50149 .64057 .50482 .64428 .51086 .6438 .50754 .64006 Mtetra
.566 .697 .929 r
.50754 .64006 .51086 .6438 .51691 .64322 .5136 .63945 Mtetra
.574 .699 .927 r
.5136 .63945 .51691 .64322 .52299 .64257 .51968 .63876 Mtetra
.581 .7 .924 r
.51968 .63876 .52299 .64257 .52908 .64183 .52578 .638 Mtetra
.587 .702 .922 r
.52578 .638 .52908 .64183 .53518 .641 .53189 .63715 Mtetra
.593 .703 .919 r
.53189 .63715 .53518 .641 .54131 .64011 .53802 .63622 Mtetra
.599 .704 .917 r
.53802 .63622 .54131 .64011 .54745 .63913 .54417 .63522 Mtetra
.604 .705 .915 r
.54417 .63522 .54745 .63913 .5536 .63809 .55033 .63415 Mtetra
.609 .706 .913 r
.55033 .63415 .5536 .63809 .55978 .63698 .55651 .63301 Mtetra
.614 .706 .911 r
.55651 .63301 .55978 .63698 .56596 .63579 .56271 .63181 Mtetra
.618 .707 .909 r
.56271 .63181 .56596 .63579 .57217 .63454 .56892 .63054 Mtetra
.622 .708 .907 r
.56892 .63054 .57217 .63454 .57838 .63323 .57514 .6292 Mtetra
.626 .709 .905 r
.57514 .6292 .57838 .63323 .58461 .63186 .58138 .62781 Mtetra
.63 .709 .903 r
.58138 .62781 .58461 .63186 .59086 .63042 .58763 .62635 Mtetra
.633 .71 .902 r
.58763 .62635 .59086 .63042 .59712 .62893 .5939 .62484 Mtetra
.637 .71 .9 r
.5939 .62484 .59712 .62893 .60339 .62738 .60018 .62327 Mtetra
.64 .711 .899 r
.60018 .62327 .60339 .62738 .60968 .62578 .60648 .62165 Mtetra
.643 .712 .897 r
.60648 .62165 .60968 .62578 .61598 .62412 .61278 .61997 Mtetra
.646 .712 .896 r
.61278 .61997 .61598 .62412 .6223 .6224 .61911 .61824 Mtetra
.649 .713 .894 r
.61911 .61824 .6223 .6224 .62862 .62064 .62544 .61646 Mtetra
.652 .713 .893 r
.62544 .61646 .62862 .62064 .63496 .61882 .63179 .61462 Mtetra
.654 .714 .892 r
.63179 .61462 .63496 .61882 .64132 .61695 .63815 .61274 Mtetra
.657 .715 .891 r
.63815 .61274 .64132 .61695 .64768 .61503 .64453 .61081 Mtetra
.659 .715 .89 r
.64453 .61081 .64768 .61503 .65406 .61306 .65091 .60883 Mtetra
.662 .716 .889 r
.65091 .60883 .65406 .61306 .66045 .61104 .65731 .60679 Mtetra
.664 .717 .888 r
.65731 .60679 .66045 .61104 .66685 .60897 .66372 .60472 Mtetra
.666 .718 .887 r
.66372 .60472 .66685 .60897 .67327 .60686 .67014 .60259 Mtetra
.669 .718 .886 r
.67014 .60259 .67327 .60686 .67969 .60469 .67658 .60041 Mtetra
.671 .719 .885 r
.67658 .60041 .67969 .60469 .68613 .60247 .68302 .59819 Mtetra
.673 .72 .884 r
.68302 .59819 .68613 .60247 .69258 .60021 .68948 .59592 Mtetra
.676 .721 .883 r
.68948 .59592 .69258 .60021 .69904 .59789 .69595 .59359 Mtetra
.678 .722 .883 r
.69595 .59359 .69904 .59789 .70551 .59553 .70243 .59122 Mtetra
.68 .723 .882 r
.70243 .59122 .70551 .59553 .71199 .59311 .70892 .5888 Mtetra
.683 .724 .881 r
.70892 .5888 .71199 .59311 .71848 .59064 .71542 .58632 Mtetra
.685 .725 .88 r
.71542 .58632 .71848 .59064 .72498 .58811 .72192 .5838 Mtetra
.688 .726 .88 r
.72192 .5838 .72498 .58811 .73149 .58553 .72844 .58122 Mtetra
.69 .728 .879 r
.72844 .58122 .73149 .58553 .738 .5829 .73497 .57858 Mtetra
.693 .729 .878 r
.73497 .57858 .738 .5829 .74453 .5802 .74151 .57589 Mtetra
.695 .73 .878 r
.74151 .57589 .74453 .5802 .75107 .57745 .74805 .57314 Mtetra
.698 .732 .877 r
.74805 .57314 .75107 .57745 .75761 .57464 .75461 .57032 Mtetra
.701 .733 .876 r
.75461 .57032 .75761 .57464 .76416 .57176 .76117 .56745 Mtetra
.703 .735 .876 r
.76117 .56745 .76416 .57176 .77072 .56882 .76774 .56451 Mtetra
.706 .737 .875 r
.76774 .56451 .77072 .56882 .77728 .56581 .77431 .56151 Mtetra
.709 .739 .874 r
.77431 .56151 .77728 .56581 .78385 .56273 .78089 .55844 Mtetra
.713 .741 .873 r
.78089 .55844 .78385 .56273 .79042 .55958 .78748 .55529 Mtetra
.716 .742 .873 r
.78748 .55529 .79042 .55958 .797 .55635 .79407 .55207 Mtetra
.719 .745 .872 r
.79407 .55207 .797 .55635 .80359 .55304 .80067 .54877 Mtetra
.723 .747 .871 r
.80067 .54877 .80359 .55304 .81018 .54965 .80727 .5454 Mtetra
.726 .749 .87 r
.80727 .5454 .81018 .54965 .81677 .54618 .81387 .54193 Mtetra
.73 .751 .869 r
.81387 .54193 .81677 .54618 .82336 .54262 .82047 .53838 Mtetra
.734 .754 .868 r
.82047 .53838 .82336 .54262 .82995 .53896 .82708 .53474 Mtetra
.738 .756 .867 r
.82708 .53474 .82995 .53896 .83654 .53521 .83369 .531 Mtetra
.742 .759 .866 r
.83369 .531 .83654 .53521 .84314 .53135 .84029 .52716 Mtetra
.747 .762 .865 r
.84029 .52716 .84314 .53135 .84973 .52739 .8469 .52322 Mtetra
.751 .765 .864 r
.8469 .52322 .84973 .52739 .85631 .52332 .8535 .51917 Mtetra
.756 .768 .862 r
.8535 .51917 .85631 .52332 .8629 .51913 .8601 .515 Mtetra
.761 .771 .861 r
.8601 .515 .8629 .51913 .86947 .51483 .86669 .51071 Mtetra
.766 .774 .859 r
.86669 .51071 .86947 .51483 .87604 .51039 .87328 .5063 Mtetra
.771 .777 .858 r
.87328 .5063 .87604 .51039 .88261 .50583 .87985 .50176 Mtetra
.777 .78 .856 r
.87985 .50176 .88261 .50583 .88916 .50112 .88642 .49708 Mtetra
.782 .784 .854 r
.88642 .49708 .88916 .50112 .8957 .49628 .89298 .49226 Mtetra
.788 .787 .852 r
.89298 .49226 .8957 .49628 .90223 .49128 .89953 .4873 Mtetra
.794 .791 .849 r
.89953 .4873 .90223 .49128 .90875 .48613 .90606 .48217 Mtetra
.8 .795 .847 r
.90606 .48217 .90875 .48613 .91525 .48081 .91258 .47688 Mtetra
.807 .799 .844 r
.91258 .47688 .91525 .48081 .92173 .47532 .91908 .47143 Mtetra
.635 .09 0 r
.30738 .57626 .31091 .57857 .31594 .58345 .31242 .58109 Mtetra
.594 .045 0 r
.31242 .58109 .31594 .58345 .32102 .5881 .31751 .58569 Mtetra
.548 0 0 r
.31751 .58569 .32102 .5881 .32615 .59251 .32264 .59005 Mtetra
.498 0 0 r
.32264 .59005 .32615 .59251 .33132 .59669 .32781 .59418 Mtetra
.445 0 0 r
.32781 .59418 .33132 .59669 .33653 .60064 .33303 .59808 Mtetra
0 .153 .598 r
.33303 .59808 .33653 .60064 .34178 .60438 .33828 .60177 Mtetra
0 .203 .65 r
.33828 .60177 .34178 .60438 .34708 .60791 .34358 .60525 Mtetra
0 .252 .699 r
.34358 .60525 .34708 .60791 .35241 .61123 .34891 .60852 Mtetra
0 .299 .744 r
.34891 .60852 .35241 .61123 .35778 .61434 .35429 .61159 Mtetra
0 .343 .784 r
.35429 .61159 .35778 .61434 .36318 .61726 .3597 .61446 Mtetra
0 .384 .819 r
.3597 .61446 .36318 .61726 .36862 .61999 .36514 .61714 Mtetra
0 .422 .849 r
.36514 .61714 .36862 .61999 .3741 .62253 .37062 .61964 Mtetra
.024 .457 .874 r
.37062 .61964 .3741 .62253 .3796 .62488 .37614 .62195 Mtetra
.076 .487 .895 r
.37614 .62195 .3796 .62488 .38514 .62707 .38168 .62409 Mtetra
.123 .515 .912 r
.38168 .62409 .38514 .62707 .39071 .62907 .38726 .62605 Mtetra
.168 .539 .925 r
.38726 .62605 .39071 .62907 .39632 .63092 .39287 .62785 Mtetra
.208 .561 .936 r
.39287 .62785 .39632 .63092 .40195 .6326 .3985 .62949 Mtetra
.246 .58 .944 r
.3985 .62949 .40195 .6326 .40761 .63412 .40417 .63097 Mtetra
.28 .596 .949 r
.40417 .63097 .40761 .63412 .4133 .63549 .40986 .6323 Mtetra
.312 .61 .953 r
.40986 .6323 .4133 .63549 .41901 .63671 .41558 .63348 Mtetra
.34 .623 .956 r
.41558 .63348 .41901 .63671 .42475 .63778 .42133 .63452 Mtetra
.367 .634 .957 r
.42133 .63452 .42475 .63778 .43052 .63872 .4271 .63541 Mtetra
.391 .643 .957 r
.4271 .63541 .43052 .63872 .43631 .63952 .4329 .63618 Mtetra
.412 .652 .957 r
.4329 .63618 .43631 .63952 .44213 .64019 .43873 .63681 Mtetra
.432 .659 .956 r
.43873 .63681 .44213 .64019 .44797 .64074 .44457 .63732 Mtetra
.45 .665 .954 r
.44457 .63732 .44797 .64074 .45383 .64116 .45044 .6377 Mtetra
.467 .671 .952 r
.45044 .6377 .45383 .64116 .45972 .64146 .45633 .63797 Mtetra
.482 .676 .95 r
.45633 .63797 .45972 .64146 .46562 .64165 .46225 .63813 Mtetra
.496 .68 .948 r
.46225 .63813 .46562 .64165 .47155 .64173 .46818 .63817 Mtetra
.509 .684 .945 r
.46818 .63817 .47155 .64173 .4775 .6417 .47413 .6381 Mtetra
.521 .687 .942 r
.47413 .6381 .4775 .6417 .48347 .64156 .48011 .63794 Mtetra
.532 .69 .94 r
.48011 .63794 .48347 .64156 .48946 .64133 .48611 .63767 Mtetra
.542 .692 .937 r
.48611 .63767 .48946 .64133 .49547 .641 .49212 .63731 Mtetra
.551 .695 .934 r
.49212 .63731 .49547 .641 .50149 .64057 .49815 .63685 Mtetra
.56 .697 .932 r
.49815 .63685 .50149 .64057 .50754 .64006 .5042 .63631 Mtetra
.568 .698 .929 r
.5042 .63631 .50754 .64006 .5136 .63945 .51027 .63567 Mtetra
.575 .7 .927 r
.51027 .63567 .5136 .63945 .51968 .63876 .51636 .63496 Mtetra
.582 .701 .924 r
.51636 .63496 .51968 .63876 .52578 .638 .52247 .63416 Mtetra
.589 .703 .922 r
.52247 .63416 .52578 .638 .53189 .63715 .52859 .63329 Mtetra
.594 .704 .92 r
.52859 .63329 .53189 .63715 .53802 .63622 .53473 .63233 Mtetra
.6 .705 .917 r
.53473 .63233 .53802 .63622 .54417 .63522 .54088 .63131 Mtetra
.605 .706 .915 r
.54088 .63131 .54417 .63522 .55033 .63415 .54705 .63022 Mtetra
.61 .707 .913 r
.54705 .63022 .55033 .63415 .55651 .63301 .55324 .62905 Mtetra
.615 .708 .911 r
.55324 .62905 .55651 .63301 .56271 .63181 .55944 .62782 Mtetra
.619 .708 .909 r
.55944 .62782 .56271 .63181 .56892 .63054 .56565 .62653 Mtetra
.623 .709 .907 r
.56565 .62653 .56892 .63054 .57514 .6292 .57189 .62517 Mtetra
.627 .71 .906 r
.57189 .62517 .57514 .6292 .58138 .62781 .57813 .62376 Mtetra
.631 .71 .904 r
.57813 .62376 .58138 .62781 .58763 .62635 .58439 .62228 Mtetra
.634 .711 .902 r
.58439 .62228 .58763 .62635 .5939 .62484 .59067 .62075 Mtetra
.637 .712 .901 r
.59067 .62075 .5939 .62484 .60018 .62327 .59696 .61916 Mtetra
.641 .712 .899 r
.59696 .61916 .60018 .62327 .60648 .62165 .60326 .61752 Mtetra
.644 .713 .898 r
.60326 .61752 .60648 .62165 .61278 .61997 .60958 .61583 Mtetra
.646 .713 .897 r
.60958 .61583 .61278 .61997 .61911 .61824 .61591 .61408 Mtetra
.649 .714 .895 r
.61591 .61408 .61911 .61824 .62544 .61646 .62225 .61228 Mtetra
.652 .715 .894 r
.62225 .61228 .62544 .61646 .63179 .61462 .62861 .61043 Mtetra
.654 .715 .893 r
.62861 .61043 .63179 .61462 .63815 .61274 .63498 .60854 Mtetra
.657 .716 .892 r
.63498 .60854 .63815 .61274 .64453 .61081 .64136 .60659 Mtetra
.659 .717 .891 r
.64136 .60659 .64453 .61081 .65091 .60883 .64775 .6046 Mtetra
.662 .717 .89 r
.64775 .6046 .65091 .60883 .65731 .60679 .65416 .60255 Mtetra
.664 .718 .889 r
.65416 .60255 .65731 .60679 .66372 .60472 .66058 .60047 Mtetra
.667 .719 .888 r
.66058 .60047 .66372 .60472 .67014 .60259 .66701 .59833 Mtetra
.669 .719 .887 r
.66701 .59833 .67014 .60259 .67658 .60041 .67345 .59614 Mtetra
.671 .72 .886 r
.67345 .59614 .67658 .60041 .68302 .59819 .67991 .59391 Mtetra
.673 .721 .885 r
.67991 .59391 .68302 .59819 .68948 .59592 .68637 .59163 Mtetra
.676 .722 .884 r
.68637 .59163 .68948 .59592 .69595 .59359 .69285 .5893 Mtetra
.678 .723 .884 r
.69285 .5893 .69595 .59359 .70243 .59122 .69934 .58692 Mtetra
.68 .724 .883 r
.69934 .58692 .70243 .59122 .70892 .5888 .70584 .5845 Mtetra
.683 .725 .882 r
.70584 .5845 .70892 .5888 .71542 .58632 .71234 .58202 Mtetra
.685 .726 .881 r
.71234 .58202 .71542 .58632 .72192 .5838 .71886 .57949 Mtetra
.687 .727 .881 r
.71886 .57949 .72192 .5838 .72844 .58122 .72539 .5769 Mtetra
.69 .729 .88 r
.72539 .5769 .72844 .58122 .73497 .57858 .73193 .57427 Mtetra
.692 .73 .879 r
.73193 .57427 .73497 .57858 .74151 .57589 .73848 .57157 Mtetra
.695 .731 .879 r
.73848 .57157 .74151 .57589 .74805 .57314 .74503 .56882 Mtetra
.698 .733 .878 r
.74503 .56882 .74805 .57314 .75461 .57032 .7516 .56601 Mtetra
.7 .734 .877 r
.7516 .56601 .75461 .57032 .76117 .56745 .75817 .56314 Mtetra
.703 .736 .876 r
.75817 .56314 .76117 .56745 .76774 .56451 .76475 .56021 Mtetra
.706 .738 .876 r
.76475 .56021 .76774 .56451 .77431 .56151 .77133 .55721 Mtetra
.709 .739 .875 r
.77133 .55721 .77431 .56151 .78089 .55844 .77792 .55414 Mtetra
.712 .741 .874 r
.77792 .55414 .78089 .55844 .78748 .55529 .78452 .551 Mtetra
.715 .743 .873 r
.78452 .551 .78748 .55529 .79407 .55207 .79113 .54779 Mtetra
.719 .745 .873 r
.79113 .54779 .79407 .55207 .80067 .54877 .79773 .5445 Mtetra
.722 .747 .872 r
.79773 .5445 .80067 .54877 .80727 .5454 .80435 .54113 Mtetra
.726 .749 .871 r
.80435 .54113 .80727 .5454 .81387 .54193 .81096 .53768 Mtetra
.729 .752 .87 r
.81096 .53768 .81387 .54193 .82047 .53838 .81758 .53414 Mtetra
.733 .754 .869 r
.81758 .53414 .82047 .53838 .82708 .53474 .8242 .53051 Mtetra
.737 .757 .868 r
.8242 .53051 .82708 .53474 .83369 .531 .83082 .52679 Mtetra
.742 .759 .867 r
.83082 .52679 .83369 .531 .84029 .52716 .83744 .52296 Mtetra
.746 .762 .866 r
.83744 .52296 .84029 .52716 .8469 .52322 .84406 .51904 Mtetra
.75 .765 .864 r
.84406 .51904 .8469 .52322 .8535 .51917 .85067 .515 Mtetra
.755 .767 .863 r
.85067 .515 .8535 .51917 .8601 .515 .85728 .51085 Mtetra
.76 .77 .862 r
.85728 .51085 .8601 .515 .86669 .51071 .86389 .50659 Mtetra
.765 .773 .86 r
.86389 .50659 .86669 .51071 .87328 .5063 .87049 .5022 Mtetra
.77 .777 .858 r
.87049 .5022 .87328 .5063 .87985 .50176 .87709 .49768 Mtetra
.775 .78 .856 r
.87709 .49768 .87985 .50176 .88642 .49708 .88368 .49302 Mtetra
.781 .783 .854 r
.88368 .49302 .88642 .49708 .89298 .49226 .89025 .48823 Mtetra
.787 .787 .852 r
.89025 .48823 .89298 .49226 .89953 .4873 .89682 .48328 Mtetra
.793 .79 .85 r
.89682 .48328 .89953 .4873 .90606 .48217 .90337 .47819 Mtetra
.799 .794 .848 r
.90337 .47819 .90606 .48217 .91258 .47688 .9099 .47293 Mtetra
.805 .797 .845 r
.9099 .47293 .91258 .47688 .91908 .47143 .91642 .4675 Mtetra
.622 .077 0 r
.30384 .57388 .30738 .57626 .31242 .58109 .30889 .57867 Mtetra
.58 .031 0 r
.30889 .57867 .31242 .58109 .31751 .58569 .31398 .58321 Mtetra
.533 0 0 r
.31398 .58321 .31751 .58569 .32264 .59005 .31911 .58752 Mtetra
.482 0 0 r
.31911 .58752 .32264 .59005 .32781 .59418 .32429 .59161 Mtetra
.427 0 0 r
.32429 .59161 .32781 .59418 .33303 .59808 .32951 .59547 Mtetra
0 .167 .615 r
.32951 .59547 .33303 .59808 .33828 .60177 .33477 .59911 Mtetra
0 .217 .666 r
.33477 .59911 .33828 .60177 .34358 .60525 .34007 .60255 Mtetra
0 .265 .713 r
.34007 .60255 .34358 .60525 .34891 .60852 .34541 .60577 Mtetra
0 .311 .756 r
.34541 .60577 .34891 .60852 .35429 .61159 .35079 .6088 Mtetra
0 .354 .794 r
.35079 .6088 .35429 .61159 .3597 .61446 .3562 .61162 Mtetra
0 .394 .828 r
.3562 .61162 .3597 .61446 .36514 .61714 .36165 .61426 Mtetra
0 .431 .856 r
.36165 .61426 .36514 .61714 .37062 .61964 .36714 .61671 Mtetra
.039 .465 .88 r
.36714 .61671 .37062 .61964 .37614 .62195 .37266 .61898 Mtetra
.089 .494 .9 r
.37266 .61898 .37614 .62195 .38168 .62409 .37821 .62108 Mtetra
.136 .521 .916 r
.37821 .62108 .38168 .62409 .38726 .62605 .38379 .623 Mtetra
.179 .545 .928 r
.38379 .623 .38726 .62605 .39287 .62785 .3894 .62476 Mtetra
.219 .565 .938 r
.3894 .62476 .39287 .62785 .3985 .62949 .39505 .62635 Mtetra
.255 .583 .945 r
.39505 .62635 .3985 .62949 .40417 .63097 .40072 .62779 Mtetra
.289 .599 .95 r
.40072 .62779 .40417 .63097 .40986 .6323 .40642 .62908 Mtetra
.319 .613 .954 r
.40642 .62908 .40986 .6323 .41558 .63348 .41214 .63023 Mtetra
.347 .625 .956 r
.41214 .63023 .41558 .63348 .42133 .63452 .4179 .63122 Mtetra
.373 .636 .957 r
.4179 .63122 .42133 .63452 .4271 .63541 .42368 .63209 Mtetra
.396 .645 .957 r
.42368 .63209 .4271 .63541 .4329 .63618 .42948 .63281 Mtetra
.417 .653 .957 r
.42948 .63281 .4329 .63618 .43873 .63681 .43531 .63341 Mtetra
.437 .661 .955 r
.43531 .63341 .43873 .63681 .44457 .63732 .44116 .63388 Mtetra
.454 .667 .954 r
.44116 .63388 .44457 .63732 .45044 .6377 .44704 .63423 Mtetra
.471 .672 .952 r
.44704 .63423 .45044 .6377 .45633 .63797 .45293 .63447 Mtetra
.486 .677 .95 r
.45293 .63447 .45633 .63797 .46225 .63813 .45885 .63459 Mtetra
.499 .681 .947 r
.45885 .63459 .46225 .63813 .46818 .63817 .4648 .6346 Mtetra
.512 .685 .945 r
.4648 .6346 .46818 .63817 .47413 .6381 .47076 .6345 Mtetra
.524 .688 .942 r
.47076 .6345 .47413 .6381 .48011 .63794 .47674 .6343 Mtetra
.534 .691 .94 r
.47674 .6343 .48011 .63794 .48611 .63767 .48274 .63401 Mtetra
.544 .694 .937 r
.48274 .63401 .48611 .63767 .49212 .63731 .48876 .63361 Mtetra
.553 .696 .934 r
.48876 .63361 .49212 .63731 .49815 .63685 .4948 .63313 Mtetra
.562 .698 .932 r
.4948 .63313 .49815 .63685 .5042 .63631 .50086 .63255 Mtetra
.569 .7 .929 r
.50086 .63255 .5042 .63631 .51027 .63567 .50694 .63189 Mtetra
.577 .701 .927 r
.50694 .63189 .51027 .63567 .51636 .63496 .51303 .63115 Mtetra
.584 .703 .924 r
.51303 .63115 .51636 .63496 .52247 .63416 .51914 .63032 Mtetra
.59 .704 .922 r
.51914 .63032 .52247 .63416 .52859 .63329 .52527 .62942 Mtetra
.596 .705 .92 r
.52527 .62942 .52859 .63329 .53473 .63233 .53142 .62845 Mtetra
.601 .706 .918 r
.53142 .62845 .53473 .63233 .54088 .63131 .53758 .6274 Mtetra
.606 .707 .916 r
.53758 .6274 .54088 .63131 .54705 .63022 .54375 .62628 Mtetra
.611 .708 .914 r
.54375 .62628 .54705 .63022 .55324 .62905 .54995 .62509 Mtetra
.616 .709 .912 r
.54995 .62509 .55324 .62905 .55944 .62782 .55616 .62384 Mtetra
.62 .71 .91 r
.55616 .62384 .55944 .62782 .56565 .62653 .56238 .62253 Mtetra
.624 .71 .908 r
.56238 .62253 .56565 .62653 .57189 .62517 .56862 .62115 Mtetra
.628 .711 .906 r
.56862 .62115 .57189 .62517 .57813 .62376 .57487 .61971 Mtetra
.631 .712 .905 r
.57487 .61971 .57813 .62376 .58439 .62228 .58114 .61822 Mtetra
.635 .712 .903 r
.58114 .61822 .58439 .62228 .59067 .62075 .58742 .61667 Mtetra
.638 .713 .901 r
.58742 .61667 .59067 .62075 .59696 .61916 .59372 .61506 Mtetra
.641 .714 .9 r
.59372 .61506 .59696 .61916 .60326 .61752 .60003 .6134 Mtetra
.644 .714 .899 r
.60003 .6134 .60326 .61752 .60958 .61583 .60636 .61169 Mtetra
.647 .715 .897 r
.60636 .61169 .60958 .61583 .61591 .61408 .61269 .60993 Mtetra
.65 .715 .896 r
.61269 .60993 .61591 .61408 .62225 .61228 .61904 .60811 Mtetra
.652 .716 .895 r
.61904 .60811 .62225 .61228 .62861 .61043 .62541 .60625 Mtetra
.655 .717 .894 r
.62541 .60625 .62861 .61043 .63498 .60854 .63179 .60434 Mtetra
.657 .717 .893 r
.63179 .60434 .63498 .60854 .64136 .60659 .63818 .60238 Mtetra
.66 .718 .892 r
.63818 .60238 .64136 .60659 .64775 .6046 .64458 .60038 Mtetra
.662 .719 .891 r
.64458 .60038 .64775 .6046 .65416 .60255 .651 .59832 Mtetra
.664 .719 .89 r
.651 .59832 .65416 .60255 .66058 .60047 .65742 .59622 Mtetra
.667 .72 .889 r
.65742 .59622 .66058 .60047 .66701 .59833 .66386 .59408 Mtetra
.669 .721 .888 r
.66386 .59408 .66701 .59833 .67345 .59614 .67031 .59188 Mtetra
.671 .722 .887 r
.67031 .59188 .67345 .59614 .67991 .59391 .67678 .58964 Mtetra
.673 .722 .886 r
.67678 .58964 .67991 .59391 .68637 .59163 .68325 .58735 Mtetra
.676 .723 .885 r
.68325 .58735 .68637 .59163 .69285 .5893 .68974 .58502 Mtetra
.678 .724 .885 r
.68974 .58502 .69285 .5893 .69934 .58692 .69624 .58264 Mtetra
.68 .725 .884 r
.69624 .58264 .69934 .58692 .70584 .5845 .70274 .5802 Mtetra
.682 .726 .883 r
.70274 .5802 .70584 .5845 .71234 .58202 .70926 .57772 Mtetra
.685 .727 .882 r
.70926 .57772 .71234 .58202 .71886 .57949 .71579 .57519 Mtetra
.687 .728 .882 r
.71579 .57519 .71886 .57949 .72539 .5769 .72233 .5726 Mtetra
.69 .73 .881 r
.72233 .5726 .72539 .5769 .73193 .57427 .72888 .56996 Mtetra
.692 .731 .88 r
.72888 .56996 .73193 .57427 .73848 .57157 .73543 .56727 Mtetra
.695 .732 .88 r
.73543 .56727 .73848 .57157 .74503 .56882 .742 .56452 Mtetra
.697 .734 .879 r
.742 .56452 .74503 .56882 .7516 .56601 .74857 .56171 Mtetra
.7 .735 .878 r
.74857 .56171 .7516 .56601 .75817 .56314 .75516 .55884 Mtetra
.703 .737 .877 r
.75516 .55884 .75817 .56314 .76475 .56021 .76175 .55591 Mtetra
.706 .738 .877 r
.76175 .55591 .76475 .56021 .77133 .55721 .76834 .55291 Mtetra
.709 .74 .876 r
.76834 .55291 .77133 .55721 .77792 .55414 .77495 .54985 Mtetra
.712 .742 .875 r
.77495 .54985 .77792 .55414 .78452 .551 .78156 .54671 Mtetra
.715 .744 .874 r
.78156 .54671 .78452 .551 .79113 .54779 .78817 .54351 Mtetra
.718 .746 .874 r
.78817 .54351 .79113 .54779 .79773 .5445 .79479 .54023 Mtetra
.722 .748 .873 r
.79479 .54023 .79773 .5445 .80435 .54113 .80142 .53687 Mtetra
.725 .75 .872 r
.80142 .53687 .80435 .54113 .81096 .53768 .80804 .53342 Mtetra
.729 .752 .871 r
.80804 .53342 .81096 .53768 .81758 .53414 .81467 .5299 Mtetra
.733 .754 .87 r
.81467 .5299 .81758 .53414 .8242 .53051 .82131 .52628 Mtetra
.737 .757 .869 r
.82131 .52628 .8242 .53051 .83082 .52679 .82794 .52257 Mtetra
.741 .759 .868 r
.82794 .52257 .83082 .52679 .83744 .52296 .83457 .51875 Mtetra
.745 .762 .866 r
.83457 .51875 .83744 .52296 .84406 .51904 .8412 .51484 Mtetra
.749 .765 .865 r
.8412 .51484 .84406 .51904 .85067 .515 .84784 .51082 Mtetra
.754 .767 .864 r
.84784 .51082 .85067 .515 .85728 .51085 .85446 .50669 Mtetra
.759 .77 .862 r
.85446 .50669 .85728 .51085 .86389 .50659 .86109 .50244 Mtetra
.764 .773 .861 r
.86109 .50244 .86389 .50659 .87049 .5022 .8677 .49807 Mtetra
.769 .776 .859 r
.8677 .49807 .87049 .5022 .87709 .49768 .87431 .49357 Mtetra
.774 .779 .857 r
.87431 .49357 .87709 .49768 .88368 .49302 .88092 .48894 Mtetra
.78 .783 .855 r
.88092 .48894 .88368 .49302 .89025 .48823 .88751 .48417 Mtetra
.785 .786 .853 r
.88751 .48417 .89025 .48823 .89682 .48328 .89409 .47925 Mtetra
.791 .789 .851 r
.89409 .47925 .89682 .48328 .90337 .47819 .90066 .47418 Mtetra
.797 .793 .848 r
.90066 .47418 .90337 .47819 .9099 .47293 .90721 .46894 Mtetra
.803 .796 .846 r
.90721 .46894 .9099 .47293 .91642 .4675 .91375 .46355 Mtetra
.61 .064 0 r
.30029 .57144 .30384 .57388 .30889 .57867 .30534 .57618 Mtetra
.566 .018 0 r
.30534 .57618 .30889 .57867 .31398 .58321 .31043 .58068 Mtetra
.518 0 0 r
.31043 .58068 .31398 .58321 .31911 .58752 .31557 .58495 Mtetra
.466 0 0 r
.31557 .58495 .31911 .58752 .32429 .59161 .32075 .58899 Mtetra
0 .13 .578 r
.32075 .58899 .32429 .59161 .32951 .59547 .32598 .5928 Mtetra
0 .18 .631 r
.32598 .5928 .32951 .59547 .33477 .59911 .33124 .5964 Mtetra
0 .23 .681 r
.33124 .5964 .33477 .59911 .34007 .60255 .33655 .59979 Mtetra
0 .277 .726 r
.33655 .59979 .34007 .60255 .34541 .60577 .34189 .60297 Mtetra
0 .322 .768 r
.34189 .60297 .34541 .60577 .35079 .6088 .34728 .60596 Mtetra
0 .365 .804 r
.34728 .60596 .35079 .6088 .3562 .61162 .3527 .60874 Mtetra
0 .404 .836 r
.3527 .60874 .3562 .61162 .36165 .61426 .35815 .61134 Mtetra
.001 .44 .863 r
.35815 .61134 .36165 .61426 .36714 .61671 .36364 .61375 Mtetra
.053 .472 .885 r
.36364 .61375 .36714 .61671 .37266 .61898 .36916 .61598 Mtetra
.102 .501 .904 r
.36916 .61598 .37266 .61898 .37821 .62108 .37472 .61803 Mtetra
.147 .527 .919 r
.37472 .61803 .37821 .62108 .38379 .623 .38031 .61991 Mtetra
.189 .549 .931 r
.38031 .61991 .38379 .623 .3894 .62476 .38593 .62163 Mtetra
.228 .569 .94 r
.38593 .62163 .3894 .62476 .39505 .62635 .39157 .62319 Mtetra
.264 .587 .946 r
.39157 .62319 .39505 .62635 .40072 .62779 .39725 .62459 Mtetra
.296 .603 .951 r
.39725 .62459 .40072 .62779 .40642 .62908 .40296 .62584 Mtetra
.326 .616 .954 r
.40296 .62584 .40642 .62908 .41214 .63023 .40869 .62695 Mtetra
.353 .628 .956 r
.40869 .62695 .41214 .63023 .4179 .63122 .41445 .62791 Mtetra
.378 .638 .957 r
.41445 .62791 .4179 .63122 .42368 .63209 .42023 .62874 Mtetra
.401 .647 .957 r
.42023 .62874 .42368 .63209 .42948 .63281 .42605 .62943 Mtetra
.422 .655 .956 r
.42605 .62943 .42948 .63281 .43531 .63341 .43188 .62999 Mtetra
.441 .662 .955 r
.43188 .62999 .43531 .63341 .44116 .63388 .43774 .63043 Mtetra
.458 .668 .954 r
.43774 .63043 .44116 .63388 .44704 .63423 .44362 .63075 Mtetra
.474 .674 .952 r
.44362 .63075 .44704 .63423 .45293 .63447 .44952 .63095 Mtetra
.489 .678 .949 r
.44952 .63095 .45293 .63447 .45885 .63459 .45545 .63104 Mtetra
.502 .682 .947 r
.45545 .63104 .45885 .63459 .4648 .6346 .4614 .63102 Mtetra
.514 .686 .945 r
.4614 .63102 .4648 .6346 .47076 .6345 .46737 .63089 Mtetra
.526 .689 .942 r
.46737 .63089 .47076 .6345 .47674 .6343 .47335 .63066 Mtetra
.536 .692 .94 r
.47335 .63066 .47674 .6343 .48274 .63401 .47936 .63033 Mtetra
.546 .695 .937 r
.47936 .63033 .48274 .63401 .48876 .63361 .48539 .62991 Mtetra
.555 .697 .935 r
.48539 .62991 .48876 .63361 .4948 .63313 .49144 .6294 Mtetra
.563 .699 .932 r
.49144 .6294 .4948 .63313 .50086 .63255 .4975 .6288 Mtetra
.571 .701 .93 r
.4975 .6288 .50086 .63255 .50694 .63189 .50359 .62811 Mtetra
.578 .703 .927 r
.50359 .62811 .50694 .63189 .51303 .63115 .50969 .62734 Mtetra
.585 .704 .925 r
.50969 .62734 .51303 .63115 .51914 .63032 .51581 .62649 Mtetra
.591 .705 .923 r
.51581 .62649 .51914 .63032 .52527 .62942 .52194 .62556 Mtetra
.597 .706 .92 r
.52194 .62556 .52527 .62942 .53142 .62845 .52809 .62456 Mtetra
.602 .708 .918 r
.52809 .62456 .53142 .62845 .53758 .6274 .53426 .62349 Mtetra
.607 .709 .916 r
.53426 .62349 .53758 .6274 .54375 .62628 .54045 .62235 Mtetra
.612 .709 .914 r
.54045 .62235 .54375 .62628 .54995 .62509 .54665 .62114 Mtetra
.617 .71 .912 r
.54665 .62114 .54995 .62509 .55616 .62384 .55286 .61986 Mtetra
.621 .711 .91 r
.55286 .61986 .55616 .62384 .56238 .62253 .55909 .61853 Mtetra
.625 .712 .909 r
.55909 .61853 .56238 .62253 .56862 .62115 .56534 .61713 Mtetra
.628 .713 .907 r
.56534 .61713 .56862 .62115 .57487 .61971 .5716 .61567 Mtetra
.632 .713 .905 r
.5716 .61567 .57487 .61971 .58114 .61822 .57788 .61416 Mtetra
.635 .714 .904 r
.57788 .61416 .58114 .61822 .58742 .61667 .58417 .61259 Mtetra
.639 .715 .902 r
.58417 .61259 .58742 .61667 .59372 .61506 .59047 .61097 Mtetra
.642 .715 .901 r
.59047 .61097 .59372 .61506 .60003 .6134 .59679 .60929 Mtetra
.645 .716 .9 r
.59679 .60929 .60003 .6134 .60636 .61169 .60312 .60756 Mtetra
.647 .716 .898 r
.60312 .60756 .60636 .61169 .61269 .60993 .60947 .60579 Mtetra
.65 .717 .897 r
.60947 .60579 .61269 .60993 .61904 .60811 .61583 .60396 Mtetra
.653 .718 .896 r
.61583 .60396 .61904 .60811 .62541 .60625 .6222 .60208 Mtetra
.655 .718 .895 r
.6222 .60208 .62541 .60625 .63179 .60434 .62859 .60016 Mtetra
.658 .719 .894 r
.62859 .60016 .63179 .60434 .63818 .60238 .63499 .59819 Mtetra
.66 .719 .893 r
.63499 .59819 .63818 .60238 .64458 .60038 .6414 .59617 Mtetra
.662 .72 .892 r
.6414 .59617 .64458 .60038 .651 .59832 .64782 .5941 Mtetra
.665 .721 .891 r
.64782 .5941 .651 .59832 .65742 .59622 .65426 .59199 Mtetra
.667 .721 .89 r
.65426 .59199 .65742 .59622 .66386 .59408 .66071 .58984 Mtetra
.669 .722 .889 r
.66071 .58984 .66386 .59408 .67031 .59188 .66717 .58763 Mtetra
.671 .723 .888 r
.66717 .58763 .67031 .59188 .67678 .58964 .67364 .58538 Mtetra
.673 .724 .887 r
.67364 .58538 .67678 .58964 .68325 .58735 .68012 .58309 Mtetra
.676 .725 .887 r
.68012 .58309 .68325 .58735 .68974 .58502 .68662 .58075 Mtetra
.678 .726 .886 r
.68662 .58075 .68974 .58502 .69624 .58264 .69312 .57836 Mtetra
.68 .727 .885 r
.69312 .57836 .69624 .58264 .70274 .5802 .69964 .57592 Mtetra
.682 .728 .884 r
.69964 .57592 .70274 .5802 .70926 .57772 .70617 .57343 Mtetra
.685 .729 .884 r
.70617 .57343 .70926 .57772 .71579 .57519 .71271 .57089 Mtetra
.687 .73 .883 r
.71271 .57089 .71579 .57519 .72233 .5726 .71926 .56831 Mtetra
.689 .731 .882 r
.71926 .56831 .72233 .5726 .72888 .56996 .72581 .56566 Mtetra
.692 .732 .881 r
.72581 .56566 .72888 .56996 .73543 .56727 .73238 .56297 Mtetra
.694 .733 .881 r
.73238 .56297 .73543 .56727 .742 .56452 .73896 .56022 Mtetra
.697 .735 .88 r
.73896 .56022 .742 .56452 .74857 .56171 .74554 .55741 Mtetra
.7 .736 .879 r
.74554 .55741 .74857 .56171 .75516 .55884 .75214 .55454 Mtetra
.702 .738 .879 r
.75214 .55454 .75516 .55884 .76175 .55591 .75874 .55161 Mtetra
.705 .739 .878 r
.75874 .55161 .76175 .55591 .76834 .55291 .76534 .54862 Mtetra
.708 .741 .877 r
.76534 .54862 .76834 .55291 .77495 .54985 .77196 .54556 Mtetra
.711 .743 .876 r
.77196 .54556 .77495 .54985 .78156 .54671 .77858 .54243 Mtetra
.714 .745 .876 r
.77858 .54243 .78156 .54671 .78817 .54351 .78521 .53923 Mtetra
.718 .746 .875 r
.78521 .53923 .78817 .54351 .79479 .54023 .79184 .53596 Mtetra
.721 .748 .874 r
.79184 .53596 .79479 .54023 .80142 .53687 .79848 .5326 Mtetra
.725 .751 .873 r
.79848 .5326 .80142 .53687 .80804 .53342 .80512 .52917 Mtetra
.728 .753 .872 r
.80512 .52917 .80804 .53342 .81467 .5299 .81176 .52565 Mtetra
.732 .755 .871 r
.81176 .52565 .81467 .5299 .82131 .52628 .8184 .52204 Mtetra
.736 .757 .87 r
.8184 .52204 .82131 .52628 .82794 .52257 .82505 .51834 Mtetra
.74 .76 .869 r
.82505 .51834 .82794 .52257 .83457 .51875 .8317 .51454 Mtetra
.744 .762 .867 r
.8317 .51454 .83457 .51875 .8412 .51484 .83834 .51064 Mtetra
.749 .765 .866 r
.83834 .51064 .8412 .51484 .84784 .51082 .84499 .50664 Mtetra
.753 .768 .865 r
.84499 .50664 .84784 .51082 .85446 .50669 .85163 .50252 Mtetra
.758 .77 .863 r
.85163 .50252 .85446 .50669 .86109 .50244 .85827 .49829 Mtetra
.763 .773 .862 r
.85827 .49829 .86109 .50244 .8677 .49807 .8649 .49394 Mtetra
.768 .776 .86 r
.8649 .49394 .8677 .49807 .87431 .49357 .87153 .48945 Mtetra
.773 .779 .858 r
.87153 .48945 .87431 .49357 .88092 .48894 .87814 .48484 Mtetra
.779 .782 .856 r
.87814 .48484 .88092 .48894 .88751 .48417 .88475 .48009 Mtetra
.784 .786 .854 r
.88475 .48009 .88751 .48417 .89409 .47925 .89135 .47519 Mtetra
.79 .789 .851 r
.89135 .47519 .89409 .47925 .90066 .47418 .89793 .47014 Mtetra
.796 .792 .849 r
.89793 .47014 .90066 .47418 .90721 .46894 .9045 .46494 Mtetra
.802 .796 .846 r
.9045 .46494 .90721 .46894 .91375 .46355 .91106 .45956 Mtetra
.597 .052 0 r
.29673 .56894 .30029 .57144 .30534 .57618 .30178 .57364 Mtetra
.552 .005 0 r
.30178 .57364 .30534 .57618 .31043 .58068 .30688 .57809 Mtetra
.503 0 0 r
.30688 .57809 .31043 .58068 .31557 .58495 .31202 .58232 Mtetra
.45 0 0 r
.31202 .58232 .31557 .58495 .32075 .58899 .31721 .58631 Mtetra
0 .143 .594 r
.31721 .58631 .32075 .58899 .32598 .5928 .32243 .59009 Mtetra
0 .193 .646 r
.32243 .59009 .32598 .5928 .33124 .5964 .3277 .59365 Mtetra
0 .242 .694 r
.3277 .59365 .33124 .5964 .33655 .59979 .33301 .59699 Mtetra
0 .288 .738 r
.33301 .59699 .33655 .59979 .34189 .60297 .33836 .60013 Mtetra
0 .333 .778 r
.33836 .60013 .34189 .60297 .34728 .60596 .34375 .60307 Mtetra
0 .374 .813 r
.34375 .60307 .34728 .60596 .3527 .60874 .34917 .60582 Mtetra
0 .412 .843 r
.34917 .60582 .3527 .60874 .35815 .61134 .35463 .60837 Mtetra
.015 .447 .869 r
.35463 .60837 .35815 .61134 .36364 .61375 .36013 .61075 Mtetra
.066 .478 .89 r
.36013 .61075 .36364 .61375 .36916 .61598 .36566 .61294 Mtetra
.113 .507 .908 r
.36566 .61294 .36916 .61598 .37472 .61803 .37122 .61495 Mtetra
.158 .532 .922 r
.37122 .61495 .37472 .61803 .38031 .61991 .37681 .6168 Mtetra
.199 .554 .933 r
.37681 .6168 .38031 .61991 .38593 .62163 .38244 .61848 Mtetra
.237 .573 .941 r
.38244 .61848 .38593 .62163 .39157 .62319 .38809 .62 Mtetra
.271 .59 .947 r
.38809 .62 .39157 .62319 .39725 .62459 .39377 .62137 Mtetra
.303 .605 .952 r
.39377 .62137 .39725 .62459 .40296 .62584 .39948 .62258 Mtetra
.332 .619 .955 r
.39948 .62258 .40296 .62584 .40869 .62695 .40522 .62365 Mtetra
.359 .63 .956 r
.40522 .62365 .40869 .62695 .41445 .62791 .41099 .62458 Mtetra
.383 .64 .957 r
.41099 .62458 .41445 .62791 .42023 .62874 .41678 .62537 Mtetra
.405 .649 .957 r
.41678 .62537 .42023 .62874 .42605 .62943 .4226 .62603 Mtetra
.426 .657 .956 r
.4226 .62603 .42605 .62943 .43188 .62999 .42844 .62656 Mtetra
.444 .664 .955 r
.42844 .62656 .43188 .62999 .43774 .63043 .4343 .62697 Mtetra
.461 .67 .953 r
.4343 .62697 .43774 .63043 .44362 .63075 .44019 .62725 Mtetra
.477 .675 .952 r
.44019 .62725 .44362 .63075 .44952 .63095 .4461 .62742 Mtetra
.491 .68 .949 r
.4461 .62742 .44952 .63095 .45545 .63104 .45203 .62748 Mtetra
.505 .684 .947 r
.45203 .62748 .45545 .63104 .4614 .63102 .45799 .62743 Mtetra
.517 .688 .945 r
.45799 .62743 .4614 .63102 .46737 .63089 .46396 .62727 Mtetra
.528 .691 .942 r
.46396 .62727 .46737 .63089 .47335 .63066 .46996 .62701 Mtetra
.538 .694 .94 r
.46996 .62701 .47335 .63066 .47936 .63033 .47597 .62666 Mtetra
.548 .696 .937 r
.47597 .62666 .47936 .63033 .48539 .62991 .48201 .62621 Mtetra
.557 .698 .935 r
.48201 .62621 .48539 .62991 .49144 .6294 .48806 .62567 Mtetra
.565 .7 .932 r
.48806 .62567 .49144 .6294 .4975 .6288 .49413 .62504 Mtetra
.572 .702 .93 r
.49413 .62504 .4975 .6288 .50359 .62811 .50022 .62433 Mtetra
.579 .704 .928 r
.50022 .62433 .50359 .62811 .50969 .62734 .50633 .62353 Mtetra
.586 .705 .925 r
.50633 .62353 .50969 .62734 .51581 .62649 .51246 .62266 Mtetra
.592 .707 .923 r
.51246 .62266 .51581 .62649 .52194 .62556 .5186 .6217 Mtetra
.598 .708 .921 r
.5186 .6217 .52194 .62556 .52809 .62456 .52476 .62068 Mtetra
.603 .709 .919 r
.52476 .62068 .52809 .62456 .53426 .62349 .53093 .61958 Mtetra
.608 .71 .917 r
.53093 .61958 .53426 .62349 .54045 .62235 .53713 .61842 Mtetra
.613 .711 .915 r
.53713 .61842 .54045 .62235 .54665 .62114 .54333 .61719 Mtetra
.617 .712 .913 r
.54333 .61719 .54665 .62114 .55286 .61986 .54956 .6159 Mtetra
.621 .713 .911 r
.54956 .6159 .55286 .61986 .55909 .61853 .5558 .61454 Mtetra
.625 .713 .909 r
.5558 .61454 .55909 .61853 .56534 .61713 .56205 .61312 Mtetra
.629 .714 .908 r
.56205 .61312 .56534 .61713 .5716 .61567 .56832 .61165 Mtetra
.633 .715 .906 r
.56832 .61165 .5716 .61567 .57788 .61416 .5746 .61011 Mtetra
.636 .715 .905 r
.5746 .61011 .57788 .61416 .58417 .61259 .5809 .60853 Mtetra
.639 .716 .903 r
.5809 .60853 .58417 .61259 .59047 .61097 .58721 .60689 Mtetra
.642 .717 .902 r
.58721 .60689 .59047 .61097 .59679 .60929 .59354 .60519 Mtetra
.645 .717 .901 r
.59354 .60519 .59679 .60929 .60312 .60756 .59988 .60345 Mtetra
.648 .718 .899 r
.59988 .60345 .60312 .60756 .60947 .60579 .60623 .60166 Mtetra
.65 .719 .898 r
.60623 .60166 .60947 .60579 .61583 .60396 .6126 .59981 Mtetra
.653 .719 .897 r
.6126 .59981 .61583 .60396 .6222 .60208 .61898 .59792 Mtetra
.655 .72 .896 r
.61898 .59792 .6222 .60208 .62859 .60016 .62538 .59599 Mtetra
.658 .72 .895 r
.62538 .59599 .62859 .60016 .63499 .59819 .63178 .594 Mtetra
.66 .721 .894 r
.63178 .594 .63499 .59819 .6414 .59617 .6382 .59197 Mtetra
.663 .722 .893 r
.6382 .59197 .6414 .59617 .64782 .5941 .64464 .5899 Mtetra
.665 .722 .892 r
.64464 .5899 .64782 .5941 .65426 .59199 .65108 .58778 Mtetra
.667 .723 .891 r
.65108 .58778 .65426 .59199 .66071 .58984 .65754 .58561 Mtetra
.669 .724 .89 r
.65754 .58561 .66071 .58984 .66717 .58763 .66401 .5834 Mtetra
.671 .725 .889 r
.66401 .5834 .66717 .58763 .67364 .58538 .67049 .58114 Mtetra
.674 .725 .889 r
.67049 .58114 .67364 .58538 .68012 .58309 .67698 .57884 Mtetra
.676 .726 .888 r
.67698 .57884 .68012 .58309 .68662 .58075 .68349 .57649 Mtetra
.678 .727 .887 r
.68349 .57649 .68662 .58075 .69312 .57836 .69 .57409 Mtetra
.68 .728 .886 r
.69 .57409 .69312 .57836 .69964 .57592 .69653 .57165 Mtetra
.682 .729 .886 r
.69653 .57165 .69964 .57592 .70617 .57343 .70307 .56916 Mtetra
.685 .73 .885 r
.70307 .56916 .70617 .57343 .71271 .57089 .70961 .56661 Mtetra
.687 .731 .884 r
.70961 .56661 .71271 .57089 .71926 .56831 .71617 .56402 Mtetra
.689 .732 .883 r
.71617 .56402 .71926 .56831 .72581 .56566 .72274 .56138 Mtetra
.692 .733 .883 r
.72274 .56138 .72581 .56566 .73238 .56297 .72932 .55868 Mtetra
.694 .735 .882 r
.72932 .55868 .73238 .56297 .73896 .56022 .7359 .55593 Mtetra
.697 .736 .881 r
.7359 .55593 .73896 .56022 .74554 .55741 .7425 .55312 Mtetra
.699 .737 .881 r
.7425 .55312 .74554 .55741 .75214 .55454 .7491 .55025 Mtetra
.702 .739 .88 r
.7491 .55025 .75214 .55454 .75874 .55161 .75572 .54732 Mtetra
.705 .74 .879 r
.75572 .54732 .75874 .55161 .76534 .54862 .76234 .54433 Mtetra
.708 .742 .878 r
.76234 .54433 .76534 .54862 .77196 .54556 .76896 .54128 Mtetra
.711 .744 .877 r
.76896 .54128 .77196 .54556 .77858 .54243 .77559 .53815 Mtetra
.714 .746 .877 r
.77559 .53815 .77858 .54243 .78521 .53923 .78223 .53496 Mtetra
.717 .747 .876 r
.78223 .53496 .78521 .53923 .79184 .53596 .78888 .53169 Mtetra
.721 .749 .875 r
.78888 .53169 .79184 .53596 .79848 .5326 .79553 .52834 Mtetra
.724 .751 .874 r
.79553 .52834 .79848 .5326 .80512 .52917 .80218 .52491 Mtetra
.728 .753 .873 r
.80218 .52491 .80512 .52917 .81176 .52565 .80883 .5214 Mtetra
.731 .756 .872 r
.80883 .5214 .81176 .52565 .8184 .52204 .81549 .5178 Mtetra
.735 .758 .871 r
.81549 .5178 .8184 .52204 .82505 .51834 .82215 .51411 Mtetra
.739 .76 .87 r
.82215 .51411 .82505 .51834 .8317 .51454 .82881 .51032 Mtetra
.744 .763 .868 r
.82881 .51032 .8317 .51454 .83834 .51064 .83547 .50644 Mtetra
.748 .765 .867 r
.83547 .50644 .83834 .51064 .84499 .50664 .84213 .50244 Mtetra
.752 .768 .866 r
.84213 .50244 .84499 .50664 .85163 .50252 .84879 .49834 Mtetra
.757 .771 .864 r
.84879 .49834 .85163 .50252 .85827 .49829 .85544 .49413 Mtetra
.762 .773 .862 r
.85544 .49413 .85827 .49829 .8649 .49394 .86209 .48979 Mtetra
.767 .776 .861 r
.86209 .48979 .8649 .49394 .87153 .48945 .86873 .48532 Mtetra
.772 .779 .859 r
.86873 .48532 .87153 .48945 .87814 .48484 .87536 .48073 Mtetra
.778 .782 .857 r
.87536 .48073 .87814 .48484 .88475 .48009 .88198 .476 Mtetra
.783 .785 .854 r
.88198 .476 .88475 .48009 .89135 .47519 .8886 .47112 Mtetra
.789 .789 .852 r
.8886 .47112 .89135 .47519 .89793 .47014 .8952 .46609 Mtetra
.795 .792 .85 r
.8952 .46609 .89793 .47014 .9045 .46494 .90179 .46091 Mtetra
.801 .795 .847 r
.90179 .46091 .9045 .46494 .91106 .45956 .90836 .45556 Mtetra
.585 .04 0 r
.29316 .56639 .29673 .56894 .30178 .57364 .29821 .57104 Mtetra
.538 0 0 r
.29821 .57104 .30178 .57364 .30688 .57809 .30331 .57545 Mtetra
.488 0 0 r
.30331 .57545 .30688 .57809 .31202 .58232 .30846 .57964 Mtetra
.434 0 0 r
.30846 .57964 .31202 .58232 .31721 .58631 .31365 .58359 Mtetra
0 .155 .609 r
.31365 .58359 .31721 .58631 .32243 .59009 .31888 .58733 Mtetra
0 .205 .66 r
.31888 .58733 .32243 .59009 .3277 .59365 .32415 .59084 Mtetra
0 .253 .707 r
.32415 .59084 .3277 .59365 .33301 .59699 .32947 .59415 Mtetra
0 .299 .749 r
.32947 .59415 .33301 .59699 .33836 .60013 .33482 .59725 Mtetra
0 .342 .787 r
.33482 .59725 .33836 .60013 .34375 .60307 .34021 .60015 Mtetra
0 .383 .821 r
.34021 .60015 .34375 .60307 .34917 .60582 .34564 .60286 Mtetra
0 .42 .85 r
.34564 .60286 .34917 .60582 .35463 .60837 .35111 .60538 Mtetra
.027 .454 .874 r
.35111 .60538 .35463 .60837 .36013 .61075 .35661 .60771 Mtetra
.077 .485 .894 r
.35661 .60771 .36013 .61075 .36566 .61294 .36214 .60987 Mtetra
.124 .512 .911 r
.36214 .60987 .36566 .61294 .37122 .61495 .36771 .61185 Mtetra
.167 .536 .924 r
.36771 .61185 .37122 .61495 .37681 .6168 .3733 .61366 Mtetra
.208 .558 .935 r
.3733 .61366 .37681 .6168 .38244 .61848 .37893 .6153 Mtetra
.244 .577 .942 r
.37893 .6153 .38244 .61848 .38809 .62 .38459 .61679 Mtetra
.278 .593 .948 r
.38459 .61679 .38809 .62 .39377 .62137 .39028 .61812 Mtetra
.309 .608 .952 r
.39028 .61812 .39377 .62137 .39948 .62258 .396 .6193 Mtetra
.338 .621 .955 r
.396 .6193 .39948 .62258 .40522 .62365 .40174 .62034 Mtetra
.364 .632 .957 r
.40174 .62034 .40522 .62365 .41099 .62458 .40751 .62123 Mtetra
.388 .642 .957 r
.40751 .62123 .41099 .62458 .41678 .62537 .41331 .62199 Mtetra
.409 .651 .957 r
.41331 .62199 .41678 .62537 .4226 .62603 .41913 .62262 Mtetra
.429 .659 .956 r
.41913 .62262 .4226 .62603 .42844 .62656 .42498 .62312 Mtetra
.448 .665 .955 r
.42498 .62312 .42844 .62656 .4343 .62697 .43085 .62349 Mtetra
.464 .671 .953 r
.43085 .62349 .4343 .62697 .44019 .62725 .43675 .62375 Mtetra
.48 .677 .952 r
.43675 .62375 .44019 .62725 .4461 .62742 .44266 .62389 Mtetra
.494 .681 .949 r
.44266 .62389 .4461 .62742 .45203 .62748 .4486 .62391 Mtetra
.507 .685 .947 r
.4486 .62391 .45203 .62748 .45799 .62743 .45456 .62383 Mtetra
.519 .689 .945 r
.45456 .62383 .45799 .62743 .46396 .62727 .46054 .62365 Mtetra
.53 .692 .942 r
.46054 .62365 .46396 .62727 .46996 .62701 .46655 .62336 Mtetra
.54 .695 .94 r
.46655 .62336 .46996 .62701 .47597 .62666 .47257 .62298 Mtetra
.549 .698 .938 r
.47257 .62298 .47597 .62666 .48201 .62621 .47861 .6225 Mtetra
.558 .7 .935 r
.47861 .6225 .48201 .62621 .48806 .62567 .48467 .62194 Mtetra
.566 .702 .933 r
.48467 .62194 .48806 .62567 .49413 .62504 .49075 .62128 Mtetra
.574 .704 .93 r
.49075 .62128 .49413 .62504 .50022 .62433 .49685 .62055 Mtetra
.581 .705 .928 r
.49685 .62055 .50022 .62433 .50633 .62353 .50296 .61973 Mtetra
.587 .707 .926 r
.50296 .61973 .50633 .62353 .51246 .62266 .50909 .61883 Mtetra
.593 .708 .924 r
.50909 .61883 .51246 .62266 .5186 .6217 .51524 .61785 Mtetra
.599 .709 .922 r
.51524 .61785 .5186 .6217 .52476 .62068 .52141 .61681 Mtetra
.604 .711 .919 r
.52141 .61681 .52476 .62068 .53093 .61958 .52759 .61569 Mtetra
.609 .712 .918 r
.52759 .61569 .53093 .61958 .53713 .61842 .53379 .6145 Mtetra
.614 .713 .916 r
.53379 .6145 .53713 .61842 .54333 .61719 .54001 .61325 Mtetra
.618 .713 .914 r
.54001 .61325 .54333 .61719 .54956 .6159 .54624 .61194 Mtetra
.622 .714 .912 r
.54624 .61194 .54956 .6159 .5558 .61454 .55249 .61056 Mtetra
.626 .715 .91 r
.55249 .61056 .5558 .61454 .56205 .61312 .55875 .60912 Mtetra
.63 .716 .909 r
.55875 .60912 .56205 .61312 .56832 .61165 .56503 .60763 Mtetra
.633 .716 .907 r
.56503 .60763 .56832 .61165 .5746 .61011 .57132 .60608 Mtetra
.636 .717 .906 r
.57132 .60608 .5746 .61011 .5809 .60853 .57762 .60447 Mtetra
.64 .718 .904 r
.57762 .60447 .5809 .60853 .58721 .60689 .58394 .60282 Mtetra
.643 .718 .903 r
.58394 .60282 .58721 .60689 .59354 .60519 .59028 .60111 Mtetra
.645 .719 .902 r
.59028 .60111 .59354 .60519 .59988 .60345 .59663 .59935 Mtetra
.648 .72 .9 r
.59663 .59935 .59988 .60345 .60623 .60166 .60299 .59754 Mtetra
.651 .72 .899 r
.60299 .59754 .60623 .60166 .6126 .59981 .60936 .59568 Mtetra
.653 .721 .898 r
.60936 .59568 .6126 .59981 .61898 .59792 .61575 .59378 Mtetra
.656 .721 .897 r
.61575 .59378 .61898 .59792 .62538 .59599 .62216 .59183 Mtetra
.658 .722 .896 r
.62216 .59183 .62538 .59599 .63178 .594 .62857 .58983 Mtetra
.66 .723 .895 r
.62857 .58983 .63178 .594 .6382 .59197 .635 .58779 Mtetra
.663 .723 .894 r
.635 .58779 .6382 .59197 .64464 .5899 .64144 .58571 Mtetra
.665 .724 .893 r
.64144 .58571 .64464 .5899 .65108 .58778 .64789 .58357 Mtetra
.667 .725 .892 r
.64789 .58357 .65108 .58778 .65754 .58561 .65436 .5814 Mtetra
.669 .725 .891 r
.65436 .5814 .65754 .58561 .66401 .5834 .66084 .57918 Mtetra
.671 .726 .891 r
.66084 .57918 .66401 .5834 .67049 .58114 .66733 .57691 Mtetra
.674 .727 .89 r
.66733 .57691 .67049 .58114 .67698 .57884 .67383 .5746 Mtetra
.676 .728 .889 r
.67383 .5746 .67698 .57884 .68349 .57649 .68035 .57224 Mtetra
.678 .729 .888 r
.68035 .57224 .68349 .57649 .69 .57409 .68687 .56984 Mtetra
.68 .73 .888 r
.68687 .56984 .69 .57409 .69653 .57165 .69341 .56739 Mtetra
.682 .731 .887 r
.69341 .56739 .69653 .57165 .70307 .56916 .69995 .56489 Mtetra
.685 .732 .886 r
.69995 .56489 .70307 .56916 .70961 .56661 .70651 .56235 Mtetra
.687 .733 .885 r
.70651 .56235 .70961 .56661 .71617 .56402 .71308 .55975 Mtetra
.689 .734 .885 r
.71308 .55975 .71617 .56402 .72274 .56138 .71966 .55711 Mtetra
.692 .735 .884 r
.71966 .55711 .72274 .56138 .72932 .55868 .72625 .55441 Mtetra
.694 .736 .883 r
.72625 .55441 .72932 .55868 .7359 .55593 .73284 .55165 Mtetra
.697 .737 .883 r
.73284 .55165 .7359 .55593 .7425 .55312 .73945 .54884 Mtetra
.699 .739 .882 r
.73945 .54884 .7425 .55312 .7491 .55025 .74606 .54598 Mtetra
.702 .74 .881 r
.74606 .54598 .7491 .55025 .75572 .54732 .75269 .54305 Mtetra
.705 .742 .88 r
.75269 .54305 .75572 .54732 .76234 .54433 .75932 .54006 Mtetra
.708 .743 .88 r
.75932 .54006 .76234 .54433 .76896 .54128 .76595 .537 Mtetra
.71 .745 .879 r
.76595 .537 .76896 .54128 .77559 .53815 .7726 .53388 Mtetra
.714 .747 .878 r
.7726 .53388 .77559 .53815 .78223 .53496 .77925 .53069 Mtetra
.717 .748 .877 r
.77925 .53069 .78223 .53496 .78888 .53169 .7859 .52742 Mtetra
.72 .75 .876 r
.7859 .52742 .78888 .53169 .79553 .52834 .79257 .52408 Mtetra
.724 .752 .875 r
.79257 .52408 .79553 .52834 .80218 .52491 .79923 .52066 Mtetra
.727 .754 .874 r
.79923 .52066 .80218 .52491 .80883 .5214 .8059 .51716 Mtetra
.731 .756 .873 r
.8059 .51716 .80883 .5214 .81549 .5178 .81257 .51357 Mtetra
.735 .759 .872 r
.81257 .51357 .81549 .5178 .82215 .51411 .81924 .50988 Mtetra
.739 .761 .871 r
.81924 .50988 .82215 .51411 .82881 .51032 .82592 .50611 Mtetra
.743 .763 .869 r
.82592 .50611 .82881 .51032 .83547 .50644 .83259 .50223 Mtetra
.747 .766 .868 r
.83259 .50223 .83547 .50644 .84213 .50244 .83926 .49825 Mtetra
.752 .768 .867 r
.83926 .49825 .84213 .50244 .84879 .49834 .84593 .49416 Mtetra
.756 .771 .865 r
.84593 .49416 .84879 .49834 .85544 .49413 .8526 .48996 Mtetra
.761 .774 .863 r
.8526 .48996 .85544 .49413 .86209 .48979 .85926 .48563 Mtetra
.766 .776 .861 r
.85926 .48563 .86209 .48979 .86873 .48532 .86592 .48118 Mtetra
.771 .779 .86 r
.86592 .48118 .86873 .48532 .87536 .48073 .87257 .4766 Mtetra
.777 .782 .857 r
.87257 .4766 .87536 .48073 .88198 .476 .87921 .47189 Mtetra
.782 .785 .855 r
.87921 .47189 .88198 .476 .8886 .47112 .88584 .46703 Mtetra
.788 .788 .853 r
.88584 .46703 .8886 .47112 .8952 .46609 .89246 .46202 Mtetra
.794 .792 .85 r
.89246 .46202 .8952 .46609 .90179 .46091 .89906 .45686 Mtetra
.8 .795 .848 r
.89906 .45686 .90179 .46091 .90836 .45556 .90565 .45153 Mtetra
.573 .029 0 r
.28958 .56377 .29316 .56639 .29821 .57104 .29463 .56838 Mtetra
.525 0 0 r
.29463 .56838 .29821 .57104 .30331 .57545 .29973 .57276 Mtetra
.474 0 0 r
.29973 .57276 .30331 .57545 .30846 .57964 .30488 .5769 Mtetra
0 .117 .571 r
.30488 .5769 .30846 .57964 .31365 .58359 .31007 .58082 Mtetra
0 .167 .623 r
.31007 .58082 .31365 .58359 .31888 .58733 .31531 .58452 Mtetra
0 .216 .672 r
.31531 .58452 .31888 .58733 .32415 .59084 .32059 .588 Mtetra
0 .263 .718 r
.32059 .588 .32415 .59084 .32947 .59415 .32591 .59127 Mtetra
0 .309 .759 r
.32591 .59127 .32947 .59415 .33482 .59725 .33126 .59433 Mtetra
0 .351 .796 r
.33126 .59433 .33482 .59725 .34021 .60015 .33666 .5972 Mtetra
0 .391 .828 r
.33666 .5972 .34021 .60015 .34564 .60286 .34209 .59987 Mtetra
0 .427 .855 r
.34209 .59987 .34564 .60286 .35111 .60538 .34756 .60235 Mtetra
.039 .46 .879 r
.34756 .60235 .35111 .60538 .35661 .60771 .35307 .60465 Mtetra
.088 .49 .898 r
.35307 .60465 .35661 .60771 .36214 .60987 .35861 .60677 Mtetra
.134 .517 .914 r
.35861 .60677 .36214 .60987 .36771 .61185 .36418 .60871 Mtetra
.176 .54 .926 r
.36418 .60871 .36771 .61185 .3733 .61366 .36978 .61049 Mtetra
.215 .561 .936 r
.36978 .61049 .3733 .61366 .37893 .6153 .37542 .6121 Mtetra
.252 .58 .944 r
.37542 .6121 .37893 .6153 .38459 .61679 .38108 .61355 Mtetra
.285 .596 .949 r
.38108 .61355 .38459 .61679 .39028 .61812 .38678 .61485 Mtetra
.315 .611 .953 r
.38678 .61485 .39028 .61812 .396 .6193 .3925 .616 Mtetra
.343 .623 .956 r
.3925 .616 .396 .6193 .40174 .62034 .39825 .61701 Mtetra
.368 .634 .957 r
.39825 .61701 .40174 .62034 .40751 .62123 .40403 .61787 Mtetra
.392 .644 .957 r
.40403 .61787 .40751 .62123 .41331 .62199 .40983 .6186 Mtetra
.413 .653 .957 r
.40983 .6186 .41331 .62199 .41913 .62262 .41566 .61919 Mtetra
.433 .66 .956 r
.41566 .61919 .41913 .62262 .42498 .62312 .42151 .61966 Mtetra
.451 .667 .955 r
.42151 .61966 .42498 .62312 .43085 .62349 .42739 .62001 Mtetra
.467 .673 .954 r
.42739 .62001 .43085 .62349 .43675 .62375 .43329 .62023 Mtetra
.482 .678 .952 r
.43329 .62023 .43675 .62375 .44266 .62389 .43921 .62034 Mtetra
.496 .683 .95 r
.43921 .62034 .44266 .62389 .4486 .62391 .44516 .62034 Mtetra
.509 .687 .947 r
.44516 .62034 .4486 .62391 .45456 .62383 .45112 .62024 Mtetra
.52 .69 .945 r
.45112 .62024 .45456 .62383 .46054 .62365 .45711 .62002 Mtetra
.531 .694 .943 r
.45711 .62002 .46054 .62365 .46655 .62336 .46312 .61971 Mtetra
.541 .696 .94 r
.46312 .61971 .46655 .62336 .47257 .62298 .46915 .6193 Mtetra
.551 .699 .938 r
.46915 .6193 .47257 .62298 .47861 .6225 .4752 .6188 Mtetra
.559 .701 .936 r
.4752 .6188 .47861 .6225 .48467 .62194 .48127 .61821 Mtetra
.567 .703 .933 r
.48127 .61821 .48467 .62194 .49075 .62128 .48735 .61753 Mtetra
.575 .705 .931 r
.48735 .61753 .49075 .62128 .49685 .62055 .49346 .61677 Mtetra
.582 .707 .929 r
.49346 .61677 .49685 .62055 .50296 .61973 .49958 .61593 Mtetra
.588 .708 .926 r
.49958 .61593 .50296 .61973 .50909 .61883 .50572 .61501 Mtetra
.594 .71 .924 r
.50572 .61501 .50909 .61883 .51524 .61785 .51188 .61401 Mtetra
.6 .711 .922 r
.51188 .61401 .51524 .61785 .52141 .61681 .51805 .61294 Mtetra
.605 .712 .92 r
.51805 .61294 .52141 .61681 .52759 .61569 .52424 .6118 Mtetra
.61 .713 .918 r
.52424 .6118 .52759 .61569 .53379 .6145 .53045 .61059 Mtetra
.614 .714 .917 r
.53045 .61059 .53379 .6145 .54001 .61325 .53667 .60932 Mtetra
.619 .715 .915 r
.53667 .60932 .54001 .61325 .54624 .61194 .54291 .60799 Mtetra
.623 .716 .913 r
.54291 .60799 .54624 .61194 .55249 .61056 .54916 .60659 Mtetra
.627 .717 .911 r
.54916 .60659 .55249 .61056 .55875 .60912 .55543 .60514 Mtetra
.63 .718 .91 r
.55543 .60514 .55875 .60912 .56503 .60763 .56172 .60363 Mtetra
.634 .718 .908 r
.56172 .60363 .56503 .60763 .57132 .60608 .56802 .60206 Mtetra
.637 .719 .907 r
.56802 .60206 .57132 .60608 .57762 .60447 .57433 .60044 Mtetra
.64 .72 .906 r
.57433 .60044 .57762 .60447 .58394 .60282 .58066 .59876 Mtetra
.643 .72 .904 r
.58066 .59876 .58394 .60282 .59028 .60111 .587 .59704 Mtetra
.646 .721 .903 r
.587 .59704 .59028 .60111 .59663 .59935 .59336 .59527 Mtetra
.648 .721 .902 r
.59336 .59527 .59663 .59935 .60299 .59754 .59973 .59344 Mtetra
.651 .722 .901 r
.59973 .59344 .60299 .59754 .60936 .59568 .60611 .59157 Mtetra
.654 .723 .899 r
.60611 .59157 .60936 .59568 .61575 .59378 .61251 .58965 Mtetra
.656 .723 .898 r
.61251 .58965 .61575 .59378 .62216 .59183 .61892 .58769 Mtetra
.658 .724 .897 r
.61892 .58769 .62216 .59183 .62857 .58983 .62535 .58568 Mtetra
.661 .725 .896 r
.62535 .58568 .62857 .58983 .635 .58779 .63178 .58363 Mtetra
.663 .725 .895 r
.63178 .58363 .635 .58779 .64144 .58571 .63823 .58153 Mtetra
.665 .726 .895 r
.63823 .58153 .64144 .58571 .64789 .58357 .6447 .57939 Mtetra
.667 .727 .894 r
.6447 .57939 .64789 .58357 .65436 .5814 .65117 .5772 Mtetra
.669 .727 .893 r
.65117 .5772 .65436 .5814 .66084 .57918 .65766 .57497 Mtetra
.672 .728 .892 r
.65766 .57497 .66084 .57918 .66733 .57691 .66416 .5727 Mtetra
.674 .729 .891 r
.66416 .5727 .66733 .57691 .67383 .5746 .67067 .57038 Mtetra
.676 .73 .89 r
.67067 .57038 .67383 .5746 .68035 .57224 .67719 .56802 Mtetra
.678 .73 .89 r
.67719 .56802 .68035 .57224 .68687 .56984 .68373 .56561 Mtetra
.68 .731 .889 r
.68373 .56561 .68687 .56984 .69341 .56739 .69027 .56315 Mtetra
.682 .732 .888 r
.69027 .56315 .69341 .56739 .69995 .56489 .69683 .56065 Mtetra
.685 .733 .888 r
.69683 .56065 .69995 .56489 .70651 .56235 .7034 .5581 Mtetra
.687 .734 .887 r
.7034 .5581 .70651 .56235 .71308 .55975 .70998 .5555 Mtetra
.689 .735 .886 r
.70998 .5555 .71308 .55975 .71966 .55711 .71656 .55285 Mtetra
.692 .737 .885 r
.71656 .55285 .71966 .55711 .72625 .55441 .72316 .55015 Mtetra
.694 .738 .885 r
.72316 .55015 .72625 .55441 .73284 .55165 .72977 .54739 Mtetra
.696 .739 .884 r
.72977 .54739 .73284 .55165 .73945 .54884 .73639 .54458 Mtetra
.699 .74 .883 r
.73639 .54458 .73945 .54884 .74606 .54598 .74301 .54171 Mtetra
.702 .742 .882 r
.74301 .54171 .74606 .54598 .75269 .54305 .74965 .53878 Mtetra
.704 .743 .882 r
.74965 .53878 .75269 .54305 .75932 .54006 .75629 .53579 Mtetra
.707 .745 .881 r
.75629 .53579 .75932 .54006 .76595 .537 .76294 .53274 Mtetra
.71 .746 .88 r
.76294 .53274 .76595 .537 .7726 .53388 .76959 .52962 Mtetra
.713 .748 .879 r
.76959 .52962 .7726 .53388 .77925 .53069 .77625 .52643 Mtetra
.716 .75 .878 r
.77625 .52643 .77925 .53069 .7859 .52742 .78292 .52317 Mtetra
.72 .751 .877 r
.78292 .52317 .7859 .52742 .79257 .52408 .7896 .51983 Mtetra
.723 .753 .876 r
.7896 .51983 .79257 .52408 .79923 .52066 .79627 .51642 Mtetra
.727 .755 .875 r
.79627 .51642 .79923 .52066 .8059 .51716 .80295 .51292 Mtetra
.73 .757 .874 r
.80295 .51292 .8059 .51716 .81257 .51357 .80964 .50933 Mtetra
.734 .76 .873 r
.80964 .50933 .81257 .51357 .81924 .50988 .81632 .50566 Mtetra
.738 .762 .872 r
.81632 .50566 .81924 .50988 .82592 .50611 .82301 .50189 Mtetra
.742 .764 .87 r
.82301 .50189 .82592 .50611 .83259 .50223 .8297 .49802 Mtetra
.747 .766 .869 r
.8297 .49802 .83259 .50223 .83926 .49825 .83638 .49405 Mtetra
.751 .769 .868 r
.83638 .49405 .83926 .49825 .84593 .49416 .84307 .48997 Mtetra
.756 .771 .866 r
.84307 .48997 .84593 .49416 .8526 .48996 .84975 .48578 Mtetra
.76 .774 .864 r
.84975 .48578 .8526 .48996 .85926 .48563 .85643 .48147 Mtetra
.765 .777 .862 r
.85643 .48147 .85926 .48563 .86592 .48118 .8631 .47703 Mtetra
.771 .78 .86 r
.8631 .47703 .86592 .48118 .87257 .4766 .86976 .47247 Mtetra
.776 .782 .858 r
.86976 .47247 .87257 .4766 .87921 .47189 .87642 .46777 Mtetra
.781 .785 .856 r
.87642 .46777 .87921 .47189 .88584 .46703 .88306 .46293 Mtetra
.787 .788 .854 r
.88306 .46293 .88584 .46703 .89246 .46202 .8897 .45794 Mtetra
.793 .791 .851 r
.8897 .45794 .89246 .46202 .89906 .45686 .89632 .45279 Mtetra
.799 .794 .848 r
.89632 .45279 .89906 .45686 .90565 .45153 .90293 .44748 Mtetra
.561 .018 0 r
.28598 .5611 .28958 .56377 .29463 .56838 .29104 .56568 Mtetra
.512 0 0 r
.29104 .56568 .29463 .56838 .29973 .57276 .29614 .57002 Mtetra
.46 0 0 r
.29614 .57002 .29973 .57276 .30488 .5769 .30129 .57412 Mtetra
0 .128 .585 r
.30129 .57412 .30488 .5769 .31007 .58082 .30649 .578 Mtetra
0 .178 .636 r
.30649 .578 .31007 .58082 .31531 .58452 .31173 .58166 Mtetra
0 .226 .684 r
.31173 .58166 .31531 .58452 .32059 .588 .31701 .58511 Mtetra
0 .273 .728 r
.31701 .58511 .32059 .588 .32591 .59127 .32233 .58834 Mtetra
0 .317 .768 r
.32233 .58834 .32591 .59127 .33126 .59433 .3277 .59137 Mtetra
0 .359 .803 r
.3277 .59137 .33126 .59433 .33666 .5972 .3331 .5942 Mtetra
0 .398 .834 r
.3331 .5942 .33666 .5972 .34209 .59987 .33853 .59684 Mtetra
0 .434 .861 r
.33853 .59684 .34209 .59987 .34756 .60235 .34401 .59929 Mtetra
.049 .466 .883 r
.34401 .59929 .34756 .60235 .35307 .60465 .34952 .60155 Mtetra
.098 .495 .901 r
.34952 .60155 .35307 .60465 .35861 .60677 .35506 .60364 Mtetra
.142 .521 .916 r
.35506 .60364 .35861 .60677 .36418 .60871 .36064 .60555 Mtetra
.184 .544 .928 r
.36064 .60555 .36418 .60871 .36978 .61049 .36625 .6073 Mtetra
.223 .565 .938 r
.36625 .6073 .36978 .61049 .37542 .6121 .37189 .60888 Mtetra
.258 .583 .945 r
.37189 .60888 .37542 .6121 .38108 .61355 .37756 .6103 Mtetra
.29 .599 .95 r
.37756 .6103 .38108 .61355 .38678 .61485 .38326 .61157 Mtetra
.32 .613 .954 r
.38326 .61157 .38678 .61485 .3925 .616 .38898 .61268 Mtetra
.348 .625 .956 r
.38898 .61268 .3925 .616 .39825 .61701 .39474 .61366 Mtetra
.373 .636 .957 r
.39474 .61366 .39825 .61701 .40403 .61787 .40052 .61449 Mtetra
.395 .646 .958 r
.40052 .61449 .40403 .61787 .40983 .6186 .40633 .61519 Mtetra
.416 .654 .957 r
.40633 .61519 .40983 .6186 .41566 .61919 .41217 .61576 Mtetra
.436 .662 .957 r
.41217 .61576 .41566 .61919 .42151 .61966 .41803 .6162 Mtetra
.453 .669 .955 r
.41803 .6162 .42151 .61966 .42739 .62001 .42391 .61652 Mtetra
.469 .674 .954 r
.42391 .61652 .42739 .62001 .43329 .62023 .42982 .61671 Mtetra
.484 .68 .952 r
.42982 .61671 .43329 .62023 .43921 .62034 .43575 .6168 Mtetra
.498 .684 .95 r
.43575 .6168 .43921 .62034 .44516 .62034 .4417 .61677 Mtetra
.51 .688 .948 r
.4417 .61677 .44516 .62034 .45112 .62024 .44767 .61664 Mtetra
.522 .692 .945 r
.44767 .61664 .45112 .62024 .45711 .62002 .45367 .6164 Mtetra
.533 .695 .943 r
.45367 .6164 .45711 .62002 .46312 .61971 .45968 .61606 Mtetra
.543 .698 .941 r
.45968 .61606 .46312 .61971 .46915 .6193 .46572 .61563 Mtetra
.552 .701 .938 r
.46572 .61563 .46915 .6193 .4752 .6188 .47177 .6151 Mtetra
.56 .703 .936 r
.47177 .6151 .4752 .6188 .48127 .61821 .47785 .61449 Mtetra
.568 .705 .934 r
.47785 .61449 .48127 .61821 .48735 .61753 .48394 .61379 Mtetra
.576 .707 .932 r
.48394 .61379 .48735 .61753 .49346 .61677 .49005 .613 Mtetra
.582 .709 .929 r
.49005 .613 .49346 .61677 .49958 .61593 .49618 .61213 Mtetra
.589 .71 .927 r
.49618 .61213 .49958 .61593 .50572 .61501 .50233 .61119 Mtetra
.595 .711 .925 r
.50233 .61119 .50572 .61501 .51188 .61401 .5085 .61017 Mtetra
.6 .713 .923 r
.5085 .61017 .51188 .61401 .51805 .61294 .51468 .60908 Mtetra
.605 .714 .921 r
.51468 .60908 .51805 .61294 .52424 .6118 .52088 .60792 Mtetra
.61 .715 .919 r
.52088 .60792 .52424 .6118 .53045 .61059 .52709 .6067 Mtetra
.615 .716 .918 r
.52709 .6067 .53045 .61059 .53667 .60932 .53332 .60541 Mtetra
.619 .717 .916 r
.53332 .60541 .53667 .60932 .54291 .60799 .53957 .60405 Mtetra
.623 .718 .914 r
.53957 .60405 .54291 .60799 .54916 .60659 .54583 .60264 Mtetra
.627 .719 .913 r
.54583 .60264 .54916 .60659 .55543 .60514 .55211 .60117 Mtetra
.631 .719 .911 r
.55211 .60117 .55543 .60514 .56172 .60363 .5584 .59964 Mtetra
.634 .72 .91 r
.5584 .59964 .56172 .60363 .56802 .60206 .56471 .59805 Mtetra
.637 .721 .908 r
.56471 .59805 .56802 .60206 .57433 .60044 .57103 .59642 Mtetra
.64 .721 .907 r
.57103 .59642 .57433 .60044 .58066 .59876 .57736 .59473 Mtetra
.643 .722 .905 r
.57736 .59473 .58066 .59876 .587 .59704 .58372 .59299 Mtetra
.646 .723 .904 r
.58372 .59299 .587 .59704 .59336 .59527 .59008 .5912 Mtetra
.649 .723 .903 r
.59008 .5912 .59336 .59527 .59973 .59344 .59646 .58936 Mtetra
.651 .724 .902 r
.59646 .58936 .59973 .59344 .60611 .59157 .60285 .58748 Mtetra
.654 .725 .901 r
.60285 .58748 .60611 .59157 .61251 .58965 .60926 .58555 Mtetra
.656 .725 .9 r
.60926 .58555 .61251 .58965 .61892 .58769 .61568 .58357 Mtetra
.659 .726 .899 r
.61568 .58357 .61892 .58769 .62535 .58568 .62211 .58155 Mtetra
.661 .726 .898 r
.62211 .58155 .62535 .58568 .63178 .58363 .62856 .57949 Mtetra
.663 .727 .897 r
.62856 .57949 .63178 .58363 .63823 .58153 .63502 .57738 Mtetra
.665 .728 .896 r
.63502 .57738 .63823 .58153 .6447 .57939 .64149 .57522 Mtetra
.667 .728 .895 r
.64149 .57522 .6447 .57939 .65117 .5772 .64797 .57303 Mtetra
.67 .729 .894 r
.64797 .57303 .65117 .5772 .65766 .57497 .65447 .57079 Mtetra
.672 .73 .893 r
.65447 .57079 .65766 .57497 .66416 .5727 .66098 .56851 Mtetra
.674 .731 .893 r
.66098 .56851 .66416 .5727 .67067 .57038 .6675 .56618 Mtetra
.676 .731 .892 r
.6675 .56618 .67067 .57038 .67719 .56802 .67403 .56381 Mtetra
.678 .732 .891 r
.67403 .56381 .67719 .56802 .68373 .56561 .68057 .56139 Mtetra
.68 .733 .89 r
.68057 .56139 .68373 .56561 .69027 .56315 .68713 .55893 Mtetra
.682 .734 .89 r
.68713 .55893 .69027 .56315 .69683 .56065 .6937 .55642 Mtetra
.685 .735 .889 r
.6937 .55642 .69683 .56065 .7034 .5581 .70027 .55387 Mtetra
.687 .736 .888 r
.70027 .55387 .7034 .5581 .70998 .5555 .70686 .55126 Mtetra
.689 .737 .888 r
.70686 .55126 .70998 .5555 .71656 .55285 .71346 .54861 Mtetra
.691 .738 .887 r
.71346 .54861 .71656 .55285 .72316 .55015 .72007 .5459 Mtetra
.694 .739 .886 r
.72007 .5459 .72316 .55015 .72977 .54739 .72669 .54314 Mtetra
.696 .741 .885 r
.72669 .54314 .72977 .54739 .73639 .54458 .73332 .54033 Mtetra
.699 .742 .885 r
.73332 .54033 .73639 .54458 .74301 .54171 .73995 .53746 Mtetra
.702 .743 .884 r
.73995 .53746 .74301 .54171 .74965 .53878 .7466 .53453 Mtetra
.704 .745 .883 r
.7466 .53453 .74965 .53878 .75629 .53579 .75325 .53154 Mtetra
.707 .746 .882 r
.75325 .53154 .75629 .53579 .76294 .53274 .75991 .52849 Mtetra
.71 .748 .881 r
.75991 .52849 .76294 .53274 .76959 .52962 .76658 .52537 Mtetra
.713 .749 .88 r
.76658 .52537 .76959 .52962 .77625 .52643 .77325 .52218 Mtetra
.716 .751 .88 r
.77325 .52218 .77625 .52643 .78292 .52317 .77993 .51893 Mtetra
.719 .753 .879 r
.77993 .51893 .78292 .52317 .7896 .51983 .78662 .51559 Mtetra
.723 .755 .878 r
.78662 .51559 .7896 .51983 .79627 .51642 .79331 .51218 Mtetra
.726 .756 .876 r
.79331 .51218 .79627 .51642 .80295 .51292 .8 .50869 Mtetra
.73 .758 .875 r
.8 .50869 .80295 .51292 .80964 .50933 .8067 .50511 Mtetra
.734 .761 .874 r
.8067 .50511 .80964 .50933 .81632 .50566 .81339 .50144 Mtetra
.738 .763 .873 r
.81339 .50144 .81632 .50566 .82301 .50189 .82009 .49768 Mtetra
.742 .765 .872 r
.82009 .49768 .82301 .50189 .8297 .49802 .82679 .49382 Mtetra
.746 .767 .87 r
.82679 .49382 .8297 .49802 .83638 .49405 .83349 .48985 Mtetra
.751 .77 .869 r
.83349 .48985 .83638 .49405 .84307 .48997 .84019 .48579 Mtetra
.755 .772 .867 r
.84019 .48579 .84307 .48997 .84975 .48578 .84689 .4816 Mtetra
.76 .775 .865 r
.84689 .4816 .84975 .48578 .85643 .48147 .85358 .4773 Mtetra
.765 .777 .863 r
.85358 .4773 .85643 .48147 .8631 .47703 .86027 .47288 Mtetra
.77 .78 .861 r
.86027 .47288 .8631 .47703 .86976 .47247 .86695 .46833 Mtetra
.775 .783 .859 r
.86695 .46833 .86976 .47247 .87642 .46777 .87362 .46364 Mtetra
.78 .786 .857 r
.87362 .46364 .87642 .46777 .88306 .46293 .88028 .45881 Mtetra
.786 .788 .854 r
.88028 .45881 .88306 .46293 .8897 .45794 .88693 .45384 Mtetra
.792 .791 .852 r
.88693 .45384 .8897 .45794 .89632 .45279 .89357 .44871 Mtetra
.798 .794 .849 r
.89357 .44871 .89632 .45279 .90293 .44748 .90019 .44341 Mtetra
.549 .008 0 r
.28237 .55838 .28598 .5611 .29104 .56568 .28743 .56292 Mtetra
.5 0 0 r
.28743 .56292 .29104 .56568 .29614 .57002 .29254 .56722 Mtetra
.447 0 0 r
.29254 .56722 .29614 .57002 .30129 .57412 .2977 .57129 Mtetra
0 .139 .598 r
.2977 .57129 .30129 .57412 .30649 .578 .30289 .57514 Mtetra
0 .188 .648 r
.30289 .57514 .30649 .578 .31173 .58166 .30814 .57877 Mtetra
0 .236 .695 r
.30814 .57877 .31173 .58166 .31701 .58511 .31342 .58218 Mtetra
0 .282 .737 r
.31342 .58218 .31701 .58511 .32233 .58834 .31875 .58538 Mtetra
0 .326 .776 r
.31875 .58538 .32233 .58834 .3277 .59137 .32411 .58838 Mtetra
0 .367 .81 r
.32411 .58838 .3277 .59137 .3331 .5942 .32952 .59118 Mtetra
0 .405 .84 r
.32952 .59118 .3331 .5942 .33853 .59684 .33496 .59378 Mtetra
.009 .44 .865 r
.33496 .59378 .33853 .59684 .34401 .59929 .34044 .5962 Mtetra
.059 .471 .887 r
.34044 .5962 .34401 .59929 .34952 .60155 .34595 .59843 Mtetra
.106 .5 .904 r
.34595 .59843 .34952 .60155 .35506 .60364 .3515 .60049 Mtetra
.15 .525 .919 r
.3515 .60049 .35506 .60364 .36064 .60555 .35708 .60237 Mtetra
.191 .548 .93 r
.35708 .60237 .36064 .60555 .36625 .6073 .3627 .60408 Mtetra
.229 .568 .939 r
.3627 .60408 .36625 .6073 .37189 .60888 .36834 .60563 Mtetra
.264 .586 .946 r
.36834 .60563 .37189 .60888 .37756 .6103 .37402 .60702 Mtetra
.296 .601 .951 r
.37402 .60702 .37756 .6103 .38326 .61157 .37972 .60826 Mtetra
.325 .615 .954 r
.37972 .60826 .38326 .61157 .38898 .61268 .38546 .60935 Mtetra
.352 .627 .956 r
.38546 .60935 .38898 .61268 .39474 .61366 .39122 .6103 Mtetra
.376 .638 .957 r
.39122 .6103 .39474 .61366 .40052 .61449 .39701 .6111 Mtetra
.399 .648 .958 r
.39701 .6111 .40052 .61449 .40633 .61519 .40282 .61178 Mtetra
.419 .656 .958 r
.40282 .61178 .40633 .61519 .41217 .61576 .40866 .61231 Mtetra
.438 .663 .957 r
.40866 .61231 .41217 .61576 .41803 .6162 .41453 .61273 Mtetra
.456 .67 .955 r
.41453 .61273 .41803 .6162 .42391 .61652 .42042 .61302 Mtetra
.471 .676 .954 r
.42042 .61302 .42391 .61652 .42982 .61671 .42633 .61319 Mtetra
.486 .681 .952 r
.42633 .61319 .42982 .61671 .43575 .6168 .43227 .61325 Mtetra
.5 .686 .95 r
.43227 .61325 .43575 .6168 .4417 .61677 .43823 .6132 Mtetra
.512 .69 .948 r
.43823 .6132 .4417 .61677 .44767 .61664 .44421 .61304 Mtetra
.523 .693 .946 r
.44421 .61304 .44767 .61664 .45367 .6164 .45021 .61278 Mtetra
.534 .697 .944 r
.45021 .61278 .45367 .6164 .45968 .61606 .45623 .61241 Mtetra
.544 .699 .941 r
.45623 .61241 .45968 .61606 .46572 .61563 .46227 .61196 Mtetra
.553 .702 .939 r
.46227 .61196 .46572 .61563 .47177 .6151 .46834 .61141 Mtetra
.561 .704 .937 r
.46834 .61141 .47177 .6151 .47785 .61449 .47442 .61077 Mtetra
.569 .707 .935 r
.47442 .61077 .47785 .61449 .48394 .61379 .48052 .61005 Mtetra
.576 .708 .932 r
.48052 .61005 .48394 .61379 .49005 .613 .48664 .60924 Mtetra
.583 .71 .93 r
.48664 .60924 .49005 .613 .49618 .61213 .49277 .60835 Mtetra
.59 .712 .928 r
.49277 .60835 .49618 .61213 .50233 .61119 .49893 .60739 Mtetra
.595 .713 .926 r
.49893 .60739 .50233 .61119 .5085 .61017 .5051 .60635 Mtetra
.601 .714 .924 r
.5051 .60635 .5085 .61017 .51468 .60908 .51129 .60524 Mtetra
.606 .716 .922 r
.51129 .60524 .51468 .60908 .52088 .60792 .5175 .60406 Mtetra
.611 .717 .92 r
.5175 .60406 .52088 .60792 .52709 .6067 .52372 .60282 Mtetra
.615 .718 .919 r
.52372 .60282 .52709 .6067 .53332 .60541 .52996 .60151 Mtetra
.62 .719 .917 r
.52996 .60151 .53332 .60541 .53957 .60405 .53621 .60013 Mtetra
.624 .72 .915 r
.53621 .60013 .53957 .60405 .54583 .60264 .54248 .5987 Mtetra
.628 .72 .914 r
.54248 .5987 .54583 .60264 .55211 .60117 .54877 .59721 Mtetra
.631 .721 .912 r
.54877 .59721 .55211 .60117 .5584 .59964 .55507 .59567 Mtetra
.634 .722 .911 r
.55507 .59567 .5584 .59964 .56471 .59805 .56138 .59407 Mtetra
.638 .723 .909 r
.56138 .59407 .56471 .59805 .57103 .59642 .56771 .59241 Mtetra
.641 .723 .908 r
.56771 .59241 .57103 .59642 .57736 .59473 .57406 .59071 Mtetra
.644 .724 .907 r
.57406 .59071 .57736 .59473 .58372 .59299 .58042 .58895 Mtetra
.646 .725 .906 r
.58042 .58895 .58372 .59299 .59008 .5912 .58679 .58715 Mtetra
.649 .725 .904 r
.58679 .58715 .59008 .5912 .59646 .58936 .59318 .5853 Mtetra
.652 .726 .903 r
.59318 .5853 .59646 .58936 .60285 .58748 .59958 .5834 Mtetra
.654 .727 .902 r
.59958 .5834 .60285 .58748 .60926 .58555 .60599 .58146 Mtetra
.657 .727 .901 r
.60599 .58146 .60926 .58555 .61568 .58357 .61242 .57947 Mtetra
.659 .728 .9 r
.61242 .57947 .61568 .58357 .62211 .58155 .61886 .57744 Mtetra
.661 .728 .899 r
.61886 .57744 .62211 .58155 .62856 .57949 .62532 .57536 Mtetra
.663 .729 .898 r
.62532 .57536 .62856 .57949 .63502 .57738 .63179 .57324 Mtetra
.665 .73 .898 r
.63179 .57324 .63502 .57738 .64149 .57522 .63827 .57108 Mtetra
.668 .73 .897 r
.63827 .57108 .64149 .57522 .64797 .57303 .64476 .56887 Mtetra
.67 .731 .896 r
.64476 .56887 .64797 .57303 .65447 .57079 .65127 .56663 Mtetra
.672 .732 .895 r
.65127 .56663 .65447 .57079 .66098 .56851 .65778 .56433 Mtetra
.674 .733 .894 r
.65778 .56433 .66098 .56851 .6675 .56618 .66431 .562 Mtetra
.676 .733 .893 r
.66431 .562 .6675 .56618 .67403 .56381 .67086 .55962 Mtetra
.678 .734 .893 r
.67086 .55962 .67403 .56381 .68057 .56139 .67741 .5572 Mtetra
.68 .735 .892 r
.67741 .5572 .68057 .56139 .68713 .55893 .68398 .55473 Mtetra
.682 .736 .891 r
.68398 .55473 .68713 .55893 .6937 .55642 .69055 .55221 Mtetra
.685 .737 .891 r
.69055 .55221 .6937 .55642 .70027 .55387 .69714 .54965 Mtetra
.687 .738 .89 r
.69714 .54965 .70027 .55387 .70686 .55126 .70374 .54704 Mtetra
.689 .739 .889 r
.70374 .54704 .70686 .55126 .71346 .54861 .71035 .54439 Mtetra
.691 .74 .888 r
.71035 .54439 .71346 .54861 .72007 .5459 .71697 .54168 Mtetra
.694 .741 .888 r
.71697 .54168 .72007 .5459 .72669 .54314 .7236 .53891 Mtetra
.696 .742 .887 r
.7236 .53891 .72669 .54314 .73332 .54033 .73023 .5361 Mtetra
.699 .744 .886 r
.73023 .5361 .73332 .54033 .73995 .53746 .73688 .53323 Mtetra
.701 .745 .885 r
.73688 .53323 .73995 .53746 .7466 .53453 .74354 .5303 Mtetra
.704 .746 .884 r
.74354 .5303 .7466 .53453 .75325 .53154 .7502 .52731 Mtetra
.707 .748 .884 r
.7502 .52731 .75325 .53154 .75991 .52849 .75687 .52425 Mtetra
.71 .749 .883 r
.75687 .52425 .75991 .52849 .76658 .52537 .76355 .52114 Mtetra
.713 .751 .882 r
.76355 .52114 .76658 .52537 .77325 .52218 .77024 .51795 Mtetra
.716 .752 .881 r
.77024 .51795 .77325 .52218 .77993 .51893 .77693 .51469 Mtetra
.719 .754 .88 r
.77693 .51469 .77993 .51893 .78662 .51559 .78363 .51136 Mtetra
.723 .756 .879 r
.78363 .51136 .78662 .51559 .79331 .51218 .79033 .50795 Mtetra
.726 .758 .878 r
.79033 .50795 .79331 .51218 .8 .50869 .79703 .50446 Mtetra
.73 .76 .877 r
.79703 .50446 .8 .50869 .8067 .50511 .80374 .50089 Mtetra
.733 .762 .875 r
.80374 .50089 .8067 .50511 .81339 .50144 .81045 .49723 Mtetra
.737 .764 .874 r
.81045 .49723 .81339 .50144 .82009 .49768 .81717 .49347 Mtetra
.741 .766 .873 r
.81717 .49347 .82009 .49768 .82679 .49382 .82388 .48962 Mtetra
.746 .768 .871 r
.82388 .48962 .82679 .49382 .83349 .48985 .8306 .48566 Mtetra
.75 .77 .87 r
.8306 .48566 .83349 .48985 .84019 .48579 .83731 .4816 Mtetra
.755 .773 .868 r
.83731 .4816 .84019 .48579 .84689 .4816 .84402 .47743 Mtetra
.759 .775 .866 r
.84402 .47743 .84689 .4816 .85358 .4773 .85072 .47313 Mtetra
.764 .778 .864 r
.85072 .47313 .85358 .4773 .86027 .47288 .85743 .46872 Mtetra
.769 .78 .862 r
.85743 .46872 .86027 .47288 .86695 .46833 .86412 .46418 Mtetra
.774 .783 .86 r
.86412 .46418 .86695 .46833 .87362 .46364 .87081 .45951 Mtetra
.78 .786 .858 r
.87081 .45951 .87362 .46364 .88028 .45881 .87748 .45469 Mtetra
.785 .789 .855 r
.87748 .45469 .88028 .45881 .88693 .45384 .88415 .44973 Mtetra
.791 .791 .853 r
.88415 .44973 .88693 .45384 .89357 .44871 .89081 .44461 Mtetra
.797 .794 .85 r
.89081 .44461 .89357 .44871 .90019 .44341 .89745 .43933 Mtetra
.538 0 0 r
.27875 .5556 .28237 .55838 .28743 .56292 .28382 .56011 Mtetra
.488 0 0 r
.28382 .56011 .28743 .56292 .29254 .56722 .28893 .56438 Mtetra
0 .099 .558 r
.28893 .56438 .29254 .56722 .2977 .57129 .29408 .56842 Mtetra
0 .148 .61 r
.29408 .56842 .2977 .57129 .30289 .57514 .29928 .57224 Mtetra
0 .197 .659 r
.29928 .57224 .30289 .57514 .30814 .57877 .30453 .57583 Mtetra
0 .245 .704 r
.30453 .57583 .30814 .57877 .31342 .58218 .30982 .57921 Mtetra
0 .29 .746 r
.30982 .57921 .31342 .58218 .31875 .58538 .31515 .58238 Mtetra
0 .333 .783 r
.31515 .58238 .31875 .58538 .32411 .58838 .32052 .58535 Mtetra
0 .374 .816 r
.32052 .58535 .32411 .58838 .32952 .59118 .32593 .58812 Mtetra
0 .411 .845 r
.32593 .58812 .32952 .59118 .33496 .59378 .33137 .59069 Mtetra
.019 .445 .869 r
.33137 .59069 .33496 .59378 .34044 .5962 .33686 .59308 Mtetra
.068 .476 .89 r
.33686 .59308 .34044 .5962 .34595 .59843 .34237 .59528 Mtetra
.114 .504 .907 r
.34237 .59528 .34595 .59843 .3515 .60049 .34793 .59731 Mtetra
.158 .529 .921 r
.34793 .59731 .3515 .60049 .35708 .60237 .35351 .59916 Mtetra
.198 .551 .931 r
.35351 .59916 .35708 .60237 .3627 .60408 .35913 .60085 Mtetra
.235 .571 .94 r
.35913 .60085 .3627 .60408 .36834 .60563 .36478 .60237 Mtetra
.269 .588 .946 r
.36478 .60237 .36834 .60563 .37402 .60702 .37046 .60373 Mtetra
.3 .604 .951 r
.37046 .60373 .37402 .60702 .37972 .60826 .37617 .60495 Mtetra
.329 .617 .954 r
.37617 .60495 .37972 .60826 .38546 .60935 .38191 .60601 Mtetra
.355 .629 .957 r
.38191 .60601 .38546 .60935 .39122 .6103 .38768 .60693 Mtetra
.379 .64 .958 r
.38768 .60693 .39122 .6103 .39701 .6111 .39348 .60771 Mtetra
.402 .649 .958 r
.39348 .60771 .39701 .6111 .40282 .61178 .3993 .60835 Mtetra
.422 .658 .958 r
.3993 .60835 .40282 .61178 .40866 .61231 .40514 .60886 Mtetra
.44 .665 .957 r
.40514 .60886 .40866 .61231 .41453 .61273 .41102 .60925 Mtetra
.458 .672 .956 r
.41102 .60925 .41453 .61273 .42042 .61302 .41691 .60952 Mtetra
.473 .677 .954 r
.41691 .60952 .42042 .61302 .42633 .61319 .42283 .60967 Mtetra
.488 .682 .952 r
.42283 .60967 .42633 .61319 .43227 .61325 .42878 .6097 Mtetra
.501 .687 .951 r
.42878 .6097 .43227 .61325 .43823 .6132 .43474 .60962 Mtetra
.513 .691 .948 r
.43474 .60962 .43823 .6132 .44421 .61304 .44073 .60944 Mtetra
.525 .695 .946 r
.44073 .60944 .44421 .61304 .45021 .61278 .44674 .60915 Mtetra
.535 .698 .944 r
.44674 .60915 .45021 .61278 .45623 .61241 .45277 .60877 Mtetra
.545 .701 .942 r
.45277 .60877 .45623 .61241 .46227 .61196 .45882 .60829 Mtetra
.554 .704 .94 r
.45882 .60829 .46227 .61196 .46834 .61141 .46488 .60772 Mtetra
.562 .706 .937 r
.46488 .60772 .46834 .61141 .47442 .61077 .47097 .60706 Mtetra
.57 .708 .935 r
.47097 .60706 .47442 .61077 .48052 .61005 .47708 .60631 Mtetra
.577 .71 .933 r
.47708 .60631 .48052 .61005 .48664 .60924 .48321 .60549 Mtetra
.584 .712 .931 r
.48321 .60549 .48664 .60924 .49277 .60835 .48935 .60458 Mtetra
.59 .713 .929 r
.48935 .60458 .49277 .60835 .49893 .60739 .49551 .6036 Mtetra
.596 .715 .927 r
.49551 .6036 .49893 .60739 .5051 .60635 .50169 .60254 Mtetra
.601 .716 .925 r
.50169 .60254 .5051 .60635 .51129 .60524 .50789 .60141 Mtetra
.607 .718 .923 r
.50789 .60141 .51129 .60524 .5175 .60406 .5141 .60021 Mtetra
.611 .719 .921 r
.5141 .60021 .5175 .60406 .52372 .60282 .52033 .59895 Mtetra
.616 .72 .92 r
.52033 .59895 .52372 .60282 .52996 .60151 .52658 .59762 Mtetra
.62 .721 .918 r
.52658 .59762 .52996 .60151 .53621 .60013 .53284 .59623 Mtetra
.624 .722 .917 r
.53284 .59623 .53621 .60013 .54248 .5987 .53912 .59478 Mtetra
.628 .722 .915 r
.53912 .59478 .54248 .5987 .54877 .59721 .54541 .59328 Mtetra
.631 .723 .914 r
.54541 .59328 .54877 .59721 .55507 .59567 .55172 .59171 Mtetra
.635 .724 .912 r
.55172 .59171 .55507 .59567 .56138 .59407 .55805 .5901 Mtetra
.638 .725 .911 r
.55805 .5901 .56138 .59407 .56771 .59241 .56438 .58843 Mtetra
.641 .725 .909 r
.56438 .58843 .56771 .59241 .57406 .59071 .57074 .58671 Mtetra
.644 .726 .908 r
.57074 .58671 .57406 .59071 .58042 .58895 .57711 .58494 Mtetra
.647 .727 .907 r
.57711 .58494 .58042 .58895 .58679 .58715 .58349 .58312 Mtetra
.649 .727 .906 r
.58349 .58312 .58679 .58715 .59318 .5853 .58988 .58126 Mtetra
.652 .728 .905 r
.58988 .58126 .59318 .5853 .59958 .5834 .59629 .57935 Mtetra
.654 .729 .904 r
.59629 .57935 .59958 .5834 .60599 .58146 .60272 .57739 Mtetra
.657 .729 .903 r
.60272 .57739 .60599 .58146 .61242 .57947 .60915 .57539 Mtetra
.659 .73 .902 r
.60915 .57539 .61242 .57947 .61886 .57744 .6156 .57335 Mtetra
.661 .731 .901 r
.6156 .57335 .61886 .57744 .62532 .57536 .62207 .57126 Mtetra
.664 .731 .9 r
.62207 .57126 .62532 .57536 .63179 .57324 .62855 .56913 Mtetra
.666 .732 .899 r
.62855 .56913 .63179 .57324 .63827 .57108 .63503 .56696 Mtetra
.668 .733 .898 r
.63503 .56696 .63827 .57108 .64476 .56887 .64154 .56474 Mtetra
.67 .733 .897 r
.64154 .56474 .64476 .56887 .65127 .56663 .64805 .56249 Mtetra
.672 .734 .897 r
.64805 .56249 .65127 .56663 .65778 .56433 .65458 .56019 Mtetra
.674 .735 .896 r
.65458 .56019 .65778 .56433 .66431 .562 .66112 .55784 Mtetra
.676 .735 .895 r
.66112 .55784 .66431 .562 .67086 .55962 .66767 .55546 Mtetra
.678 .736 .894 r
.66767 .55546 .67086 .55962 .67741 .5572 .67424 .55302 Mtetra
.68 .737 .894 r
.67424 .55302 .67741 .5572 .68398 .55473 .68081 .55055 Mtetra
.682 .738 .893 r
.68081 .55055 .68398 .55473 .69055 .55221 .6874 .54803 Mtetra
.685 .739 .892 r
.6874 .54803 .69055 .55221 .69714 .54965 .694 .54546 Mtetra
.687 .74 .891 r
.694 .54546 .69714 .54965 .70374 .54704 .7006 .54285 Mtetra
.689 .741 .891 r
.7006 .54285 .70374 .54704 .71035 .54439 .70722 .54018 Mtetra
.691 .742 .89 r
.70722 .54018 .71035 .54439 .71697 .54168 .71385 .53747 Mtetra
.694 .743 .889 r
.71385 .53747 .71697 .54168 .7236 .53891 .72049 .53471 Mtetra
.696 .744 .888 r
.72049 .53471 .7236 .53891 .73023 .5361 .72714 .53189 Mtetra
.699 .745 .888 r
.72714 .53189 .73023 .5361 .73688 .53323 .7338 .52901 Mtetra
.701 .747 .887 r
.7338 .52901 .73688 .53323 .74354 .5303 .74047 .52608 Mtetra
.704 .748 .886 r
.74047 .52608 .74354 .5303 .7502 .52731 .74714 .52309 Mtetra
.707 .749 .885 r
.74714 .52309 .7502 .52731 .75687 .52425 .75383 .52004 Mtetra
.71 .751 .884 r
.75383 .52004 .75687 .52425 .76355 .52114 .76052 .51692 Mtetra
.713 .752 .883 r
.76052 .51692 .76355 .52114 .77024 .51795 .76721 .51373 Mtetra
.716 .754 .882 r
.76721 .51373 .77024 .51795 .77693 .51469 .77392 .51047 Mtetra
.719 .756 .881 r
.77392 .51047 .77693 .51469 .78363 .51136 .78063 .50714 Mtetra
.722 .757 .88 r
.78063 .50714 .78363 .51136 .79033 .50795 .78734 .50374 Mtetra
.726 .759 .879 r
.78734 .50374 .79033 .50795 .79703 .50446 .79406 .50025 Mtetra
.729 .761 .878 r
.79406 .50025 .79703 .50446 .80374 .50089 .80078 .49668 Mtetra
.733 .763 .877 r
.80078 .49668 .80374 .50089 .81045 .49723 .80751 .49302 Mtetra
.737 .765 .875 r
.80751 .49302 .81045 .49723 .81717 .49347 .81423 .48927 Mtetra
.741 .767 .874 r
.81423 .48927 .81717 .49347 .82388 .48962 .82096 .48542 Mtetra
.745 .769 .872 r
.82096 .48542 .82388 .48962 .8306 .48566 .82769 .48147 Mtetra
.75 .771 .871 r
.82769 .48147 .8306 .48566 .83731 .4816 .83441 .47741 Mtetra
.754 .774 .869 r
.83441 .47741 .83731 .4816 .84402 .47743 .84114 .47325 Mtetra
.759 .776 .867 r
.84114 .47325 .84402 .47743 .85072 .47313 .84786 .46897 Mtetra
.764 .779 .865 r
.84786 .46897 .85072 .47313 .85743 .46872 .85457 .46456 Mtetra
.769 .781 .863 r
.85457 .46456 .85743 .46872 .86412 .46418 .86128 .46003 Mtetra
.774 .784 .861 r
.86128 .46003 .86412 .46418 .87081 .45951 .86799 .45536 Mtetra
.779 .786 .859 r
.86799 .45536 .87081 .45951 .87748 .45469 .87468 .45056 Mtetra
.785 .789 .856 r
.87468 .45056 .87748 .45469 .88415 .44973 .88136 .44561 Mtetra
.79 .792 .853 r
.88136 .44561 .88415 .44973 .89081 .44461 .88803 .4405 Mtetra
.796 .795 .851 r
.88803 .4405 .89081 .44461 .89745 .43933 .89469 .43524 Mtetra
.527 0 0 r
.27512 .55277 .27875 .5556 .28382 .56011 .28019 .55725 Mtetra
.476 0 0 r
.28019 .55725 .28382 .56011 .28893 .56438 .2853 .56149 Mtetra
0 .108 .57 r
.2853 .56149 .28893 .56438 .29408 .56842 .29046 .56551 Mtetra
0 .157 .621 r
.29046 .56551 .29408 .56842 .29928 .57224 .29566 .56929 Mtetra
0 .206 .669 r
.29566 .56929 .29928 .57224 .30453 .57583 .30091 .57286 Mtetra
0 .253 .713 r
.30091 .57286 .30453 .57583 .30982 .57921 .3062 .57621 Mtetra
0 .298 .754 r
.3062 .57621 .30982 .57921 .31515 .58238 .31154 .57935 Mtetra
0 .34 .79 r
.31154 .57935 .31515 .58238 .32052 .58535 .31691 .58229 Mtetra
0 .38 .822 r
.31691 .58229 .32052 .58535 .32593 .58812 .32232 .58503 Mtetra
0 .416 .85 r
.32232 .58503 .32593 .58812 .33137 .59069 .32777 .58758 Mtetra
.028 .45 .873 r
.32777 .58758 .33137 .59069 .33686 .59308 .33326 .58994 Mtetra
.076 .48 .893 r
.33326 .58994 .33686 .59308 .34237 .59528 .33878 .59211 Mtetra
.122 .507 .909 r
.33878 .59211 .34237 .59528 .34793 .59731 .34434 .59411 Mtetra
.164 .532 .922 r
.34434 .59411 .34793 .59731 .35351 .59916 .34993 .59594 Mtetra
.204 .554 .933 r
.34993 .59594 .35351 .59916 .35913 .60085 .35556 .59759 Mtetra
.24 .573 .941 r
.35556 .59759 .35913 .60085 .36478 .60237 .36121 .59909 Mtetra
.273 .59 .947 r
.36121 .59909 .36478 .60237 .37046 .60373 .3669 .60043 Mtetra
.304 .606 .952 r
.3669 .60043 .37046 .60373 .37617 .60495 .37261 .60161 Mtetra
.332 .619 .955 r
.37261 .60161 .37617 .60495 .38191 .60601 .37836 .60265 Mtetra
.358 .631 .957 r
.37836 .60265 .38191 .60601 .38768 .60693 .38413 .60354 Mtetra
.382 .642 .958 r
.38413 .60354 .38768 .60693 .39348 .60771 .38993 .6043 Mtetra
.404 .651 .958 r
.38993 .6043 .39348 .60771 .3993 .60835 .39576 .60492 Mtetra
.424 .659 .958 r
.39576 .60492 .3993 .60835 .40514 .60886 .40161 .60541 Mtetra
.442 .666 .957 r
.40161 .60541 .40514 .60886 .41102 .60925 .40749 .60577 Mtetra
.459 .673 .956 r
.40749 .60577 .41102 .60925 .41691 .60952 .41339 .60601 Mtetra
.475 .679 .955 r
.41339 .60601 .41691 .60952 .42283 .60967 .41932 .60614 Mtetra
.489 .684 .953 r
.41932 .60614 .42283 .60967 .42878 .6097 .42527 .60615 Mtetra
.502 .689 .951 r
.42527 .60615 .42878 .6097 .43474 .60962 .43124 .60605 Mtetra
.514 .693 .949 r
.43124 .60605 .43474 .60962 .44073 .60944 .43723 .60585 Mtetra
.526 .696 .947 r
.43723 .60585 .44073 .60944 .44674 .60915 .44325 .60554 Mtetra
.536 .7 .945 r
.44325 .60554 .44674 .60915 .45277 .60877 .44929 .60513 Mtetra
.546 .703 .943 r
.44929 .60513 .45277 .60877 .45882 .60829 .45534 .60463 Mtetra
.555 .705 .94 r
.45534 .60463 .45882 .60829 .46488 .60772 .46142 .60404 Mtetra
.563 .708 .938 r
.46142 .60404 .46488 .60772 .47097 .60706 .46751 .60336 Mtetra
.571 .71 .936 r
.46751 .60336 .47097 .60706 .47708 .60631 .47363 .60259 Mtetra
.578 .712 .934 r
.47363 .60259 .47708 .60631 .48321 .60549 .47976 .60175 Mtetra
.584 .714 .932 r
.47976 .60175 .48321 .60549 .48935 .60458 .48592 .60082 Mtetra
.591 .715 .93 r
.48592 .60082 .48935 .60458 .49551 .6036 .49209 .59982 Mtetra
.597 .717 .928 r
.49209 .59982 .49551 .6036 .50169 .60254 .49827 .59874 Mtetra
.602 .718 .926 r
.49827 .59874 .50169 .60254 .50789 .60141 .50448 .59759 Mtetra
.607 .719 .924 r
.50448 .59759 .50789 .60141 .5141 .60021 .5107 .59638 Mtetra
.612 .721 .923 r
.5107 .59638 .5141 .60021 .52033 .59895 .51694 .5951 Mtetra
.616 .722 .921 r
.51694 .5951 .52033 .59895 .52658 .59762 .52319 .59375 Mtetra
.621 .723 .919 r
.52319 .59375 .52658 .59762 .53284 .59623 .52946 .59235 Mtetra
.625 .724 .918 r
.52946 .59235 .53284 .59623 .53912 .59478 .53575 .59088 Mtetra
.628 .724 .916 r
.53575 .59088 .53912 .59478 .54541 .59328 .54205 .58936 Mtetra
.632 .725 .915 r
.54205 .58936 .54541 .59328 .55172 .59171 .54836 .58778 Mtetra
.635 .726 .914 r
.54836 .58778 .55172 .59171 .55805 .5901 .5547 .58615 Mtetra
.638 .727 .912 r
.5547 .58615 .55805 .5901 .56438 .58843 .56104 .58447 Mtetra
.641 .728 .911 r
.56104 .58447 .56438 .58843 .57074 .58671 .56741 .58273 Mtetra
.644 .728 .91 r
.56741 .58273 .57074 .58671 .57711 .58494 .57378 .58095 Mtetra
.647 .729 .909 r
.57378 .58095 .57711 .58494 .58349 .58312 .58017 .57912 Mtetra
.65 .73 .907 r
.58017 .57912 .58349 .58312 .58988 .58126 .58658 .57724 Mtetra
.652 .73 .906 r
.58658 .57724 .58988 .58126 .59629 .57935 .593 .57532 Mtetra
.655 .731 .905 r
.593 .57532 .59629 .57935 .60272 .57739 .59943 .57335 Mtetra
.657 .731 .904 r
.59943 .57335 .60272 .57739 .60915 .57539 .60587 .57134 Mtetra
.659 .732 .903 r
.60587 .57134 .60915 .57539 .6156 .57335 .61233 .56928 Mtetra
.661 .733 .903 r
.61233 .56928 .6156 .57335 .62207 .57126 .61881 .56718 Mtetra
.664 .733 .902 r
.61881 .56718 .62207 .57126 .62855 .56913 .62529 .56504 Mtetra
.666 .734 .901 r
.62529 .56504 .62855 .56913 .63503 .56696 .63179 .56286 Mtetra
.668 .735 .9 r
.63179 .56286 .63503 .56696 .64154 .56474 .6383 .56064 Mtetra
.67 .735 .899 r
.6383 .56064 .64154 .56474 .64805 .56249 .64483 .55837 Mtetra
.672 .736 .898 r
.64483 .55837 .64805 .56249 .65458 .56019 .65137 .55606 Mtetra
.674 .737 .898 r
.65137 .55606 .65458 .56019 .66112 .55784 .65792 .55371 Mtetra
.676 .738 .897 r
.65792 .55371 .66112 .55784 .66767 .55546 .66448 .55131 Mtetra
.678 .738 .896 r
.66448 .55131 .66767 .55546 .67424 .55302 .67105 .54888 Mtetra
.68 .739 .895 r
.67105 .54888 .67424 .55302 .68081 .55055 .67764 .54639 Mtetra
.683 .74 .895 r
.67764 .54639 .68081 .55055 .6874 .54803 .68423 .54387 Mtetra
.685 .741 .894 r
.68423 .54387 .6874 .54803 .694 .54546 .69084 .54129 Mtetra
.687 .742 .893 r
.69084 .54129 .694 .54546 .7006 .54285 .69746 .53867 Mtetra
.689 .743 .892 r
.69746 .53867 .7006 .54285 .70722 .54018 .70409 .536 Mtetra
.691 .744 .892 r
.70409 .536 .70722 .54018 .71385 .53747 .71073 .53329 Mtetra
.694 .745 .891 r
.71073 .53329 .71385 .53747 .72049 .53471 .71738 .53052 Mtetra
.696 .746 .89 r
.71738 .53052 .72049 .53471 .72714 .53189 .72404 .52769 Mtetra
.699 .747 .889 r
.72404 .52769 .72714 .53189 .7338 .52901 .73071 .52482 Mtetra
.701 .749 .888 r
.73071 .52482 .7338 .52901 .74047 .52608 .73739 .52188 Mtetra
.704 .75 .888 r
.73739 .52188 .74047 .52608 .74714 .52309 .74407 .51889 Mtetra
.707 .751 .887 r
.74407 .51889 .74714 .52309 .75383 .52004 .75077 .51583 Mtetra
.71 .753 .886 r
.75077 .51583 .75383 .52004 .76052 .51692 .75747 .51271 Mtetra
.713 .754 .885 r
.75747 .51271 .76052 .51692 .76721 .51373 .76418 .50953 Mtetra
.716 .756 .884 r
.76418 .50953 .76721 .51373 .77392 .51047 .7709 .50627 Mtetra
.719 .757 .883 r
.7709 .50627 .77392 .51047 .78063 .50714 .77762 .50294 Mtetra
.722 .759 .882 r
.77762 .50294 .78063 .50714 .78734 .50374 .78434 .49954 Mtetra
.726 .761 .88 r
.78434 .49954 .78734 .50374 .79406 .50025 .79107 .49605 Mtetra
.729 .762 .879 r
.79107 .49605 .79406 .50025 .80078 .49668 .79781 .49248 Mtetra
.733 .764 .878 r
.79781 .49248 .80078 .49668 .80751 .49302 .80455 .48882 Mtetra
.737 .766 .877 r
.80455 .48882 .80751 .49302 .81423 .48927 .81129 .48507 Mtetra
.741 .768 .875 r
.81129 .48507 .81423 .48927 .82096 .48542 .81803 .48123 Mtetra
.745 .77 .874 r
.81803 .48123 .82096 .48542 .82769 .48147 .82477 .47729 Mtetra
.749 .773 .872 r
.82477 .47729 .82769 .48147 .83441 .47741 .83151 .47324 Mtetra
.754 .775 .87 r
.83151 .47324 .83441 .47741 .84114 .47325 .83825 .46907 Mtetra
.758 .777 .868 r
.83825 .46907 .84114 .47325 .84786 .46897 .84498 .4648 Mtetra
.763 .779 .866 r
.84498 .4648 .84786 .46897 .85457 .46456 .85171 .4604 Mtetra
.768 .782 .864 r
.85171 .4604 .85457 .46456 .86128 .46003 .85844 .45588 Mtetra
.773 .784 .862 r
.85844 .45588 .86128 .46003 .86799 .45536 .86515 .45122 Mtetra
.779 .787 .86 r
.86515 .45122 .86799 .45536 .87468 .45056 .87186 .44642 Mtetra
.784 .789 .857 r
.87186 .44642 .87468 .45056 .88136 .44561 .87856 .44148 Mtetra
.79 .792 .854 r
.87856 .44148 .88136 .44561 .88803 .4405 .88525 .43639 Mtetra
.795 .795 .851 r
.88525 .43639 .88803 .4405 .89469 .43524 .89192 .43114 Mtetra
.516 0 0 r
.27148 .54989 .27512 .55277 .28019 .55725 .27654 .55435 Mtetra
.465 0 0 r
.27654 .55435 .28019 .55725 .2853 .56149 .28166 .55856 Mtetra
0 .117 .581 r
.28166 .55856 .2853 .56149 .29046 .56551 .28682 .56255 Mtetra
0 .166 .631 r
.28682 .56255 .29046 .56551 .29566 .56929 .29203 .5663 Mtetra
0 .214 .678 r
.29203 .5663 .29566 .56929 .30091 .57286 .29728 .56984 Mtetra
0 .26 .721 r
.29728 .56984 .30091 .57286 .3062 .57621 .30257 .57317 Mtetra
0 .304 .761 r
.30257 .57317 .3062 .57621 .31154 .57935 .30791 .57628 Mtetra
0 .346 .796 r
.30791 .57628 .31154 .57935 .31691 .58229 .31329 .5792 Mtetra
0 .385 .827 r
.31329 .5792 .31691 .58229 .32232 .58503 .3187 .58191 Mtetra
0 .421 .854 r
.3187 .58191 .32232 .58503 .32777 .58758 .32416 .58443 Mtetra
.036 .454 .876 r
.32416 .58443 .32777 .58758 .33326 .58994 .32965 .58676 Mtetra
.083 .484 .895 r
.32965 .58676 .33326 .58994 .33878 .59211 .33518 .58892 Mtetra
.128 .511 .911 r
.33518 .58892 .33878 .59211 .34434 .59411 .34074 .59089 Mtetra
.17 .535 .924 r
.34074 .59089 .34434 .59411 .34993 .59594 .34633 .59269 Mtetra
.209 .556 .934 r
.34633 .59269 .34993 .59594 .35556 .59759 .35196 .59432 Mtetra
.245 .575 .942 r
.35196 .59432 .35556 .59759 .36121 .59909 .35762 .59579 Mtetra
.277 .592 .948 r
.35762 .59579 .36121 .59909 .3669 .60043 .36332 .59711 Mtetra
.308 .607 .952 r
.36332 .59711 .3669 .60043 .37261 .60161 .36904 .59827 Mtetra
.336 .621 .955 r
.36904 .59827 .37261 .60161 .37836 .60265 .37479 .59928 Mtetra
.361 .633 .957 r
.37479 .59928 .37836 .60265 .38413 .60354 .38057 .60015 Mtetra
.385 .643 .958 r
.38057 .60015 .38413 .60354 .38993 .6043 .38637 .60088 Mtetra
.406 .652 .959 r
.38637 .60088 .38993 .6043 .39576 .60492 .39221 .60148 Mtetra
.426 .661 .958 r
.39221 .60148 .39576 .60492 .40161 .60541 .39806 .60195 Mtetra
.444 .668 .958 r
.39806 .60195 .40161 .60541 .40749 .60577 .40395 .60229 Mtetra
.461 .674 .956 r
.40395 .60229 .40749 .60577 .41339 .60601 .40986 .60251 Mtetra
.476 .68 .955 r
.40986 .60251 .41339 .60601 .41932 .60614 .41579 .60261 Mtetra
.49 .685 .953 r
.41579 .60261 .41932 .60614 .42527 .60615 .42175 .6026 Mtetra
.503 .69 .952 r
.42175 .6026 .42527 .60615 .43124 .60605 .42773 .60248 Mtetra
.515 .694 .95 r
.42773 .60248 .43124 .60605 .43723 .60585 .43373 .60225 Mtetra
.527 .698 .948 r
.43373 .60225 .43723 .60585 .44325 .60554 .43975 .60193 Mtetra
.537 .701 .945 r
.43975 .60193 .44325 .60554 .44929 .60513 .44579 .6015 Mtetra
.546 .704 .943 r
.44579 .6015 .44929 .60513 .45534 .60463 .45186 .60098 Mtetra
.555 .707 .941 r
.45186 .60098 .45534 .60463 .46142 .60404 .45794 .60037 Mtetra
.564 .709 .939 r
.45794 .60037 .46142 .60404 .46751 .60336 .46404 .59967 Mtetra
.571 .712 .937 r
.46404 .59967 .46751 .60336 .47363 .60259 .47016 .59888 Mtetra
.578 .714 .935 r
.47016 .59888 .47363 .60259 .47976 .60175 .47631 .59802 Mtetra
.585 .715 .933 r
.47631 .59802 .47976 .60175 .48592 .60082 .48247 .59707 Mtetra
.591 .717 .931 r
.48247 .59707 .48592 .60082 .49209 .59982 .48864 .59605 Mtetra
.597 .719 .929 r
.48864 .59605 .49209 .59982 .49827 .59874 .49484 .59496 Mtetra
.602 .72 .927 r
.49484 .59496 .49827 .59874 .50448 .59759 .50105 .59379 Mtetra
.607 .721 .926 r
.50105 .59379 .50448 .59759 .5107 .59638 .50728 .59256 Mtetra
.612 .723 .924 r
.50728 .59256 .5107 .59638 .51694 .5951 .51352 .59126 Mtetra
.617 .724 .922 r
.51352 .59126 .51694 .5951 .52319 .59375 .51979 .5899 Mtetra
.621 .725 .921 r
.51979 .5899 .52319 .59375 .52946 .59235 .52607 .58848 Mtetra
.625 .726 .919 r
.52607 .58848 .52946 .59235 .53575 .59088 .53236 .587 Mtetra
.629 .727 .918 r
.53236 .587 .53575 .59088 .54205 .58936 .53867 .58546 Mtetra
.632 .727 .916 r
.53867 .58546 .54205 .58936 .54836 .58778 .54499 .58387 Mtetra
.635 .728 .915 r
.54499 .58387 .54836 .58778 .5547 .58615 .55133 .58222 Mtetra
.639 .729 .914 r
.55133 .58222 .5547 .58615 .56104 .58447 .55769 .58053 Mtetra
.642 .73 .913 r
.55769 .58053 .56104 .58447 .56741 .58273 .56406 .57878 Mtetra
.644 .73 .911 r
.56406 .57878 .56741 .58273 .57378 .58095 .57045 .57698 Mtetra
.647 .731 .91 r
.57045 .57698 .57378 .58095 .58017 .57912 .57684 .57514 Mtetra
.65 .732 .909 r
.57684 .57514 .58017 .57912 .58658 .57724 .58326 .57325 Mtetra
.652 .732 .908 r
.58326 .57325 .58658 .57724 .593 .57532 .58969 .57131 Mtetra
.655 .733 .907 r
.58969 .57131 .593 .57532 .59943 .57335 .59613 .56933 Mtetra
.657 .734 .906 r
.59613 .56933 .59943 .57335 .60587 .57134 .60258 .56731 Mtetra
.659 .734 .905 r
.60258 .56731 .60587 .57134 .61233 .56928 .60905 .56524 Mtetra
.662 .735 .904 r
.60905 .56524 .61233 .56928 .61881 .56718 .61553 .56313 Mtetra
.664 .736 .903 r
.61553 .56313 .61881 .56718 .62529 .56504 .62203 .56098 Mtetra
.666 .736 .902 r
.62203 .56098 .62529 .56504 .63179 .56286 .62854 .55879 Mtetra
.668 .737 .902 r
.62854 .55879 .63179 .56286 .6383 .56064 .63506 .55655 Mtetra
.67 .738 .901 r
.63506 .55655 .6383 .56064 .64483 .55837 .64159 .55428 Mtetra
.672 .738 .9 r
.64159 .55428 .64483 .55837 .65137 .55606 .64814 .55196 Mtetra
.674 .739 .899 r
.64814 .55196 .65137 .55606 .65792 .55371 .6547 .5496 Mtetra
.676 .74 .899 r
.6547 .5496 .65792 .55371 .66448 .55131 .66127 .5472 Mtetra
.678 .741 .898 r
.66127 .5472 .66448 .55131 .67105 .54888 .66785 .54475 Mtetra
.68 .741 .897 r
.66785 .54475 .67105 .54888 .67764 .54639 .67445 .54226 Mtetra
.683 .742 .896 r
.67445 .54226 .67764 .54639 .68423 .54387 .68106 .53973 Mtetra
.685 .743 .896 r
.68106 .53973 .68423 .54387 .69084 .54129 .68767 .53715 Mtetra
.687 .744 .895 r
.68767 .53715 .69084 .54129 .69746 .53867 .6943 .53452 Mtetra
.689 .745 .894 r
.6943 .53452 .69746 .53867 .70409 .536 .70094 .53185 Mtetra
.691 .746 .893 r
.70094 .53185 .70409 .536 .71073 .53329 .7076 .52912 Mtetra
.694 .747 .892 r
.7076 .52912 .71073 .53329 .71738 .53052 .71426 .52635 Mtetra
.696 .748 .892 r
.71426 .52635 .71738 .53052 .72404 .52769 .72093 .52352 Mtetra
.699 .749 .891 r
.72093 .52352 .72404 .52769 .73071 .52482 .72761 .52064 Mtetra
.701 .751 .89 r
.72761 .52064 .73071 .52482 .73739 .52188 .7343 .5177 Mtetra
.704 .752 .889 r
.7343 .5177 .73739 .52188 .74407 .51889 .74099 .51471 Mtetra
.707 .753 .888 r
.74099 .51471 .74407 .51889 .75077 .51583 .7477 .51165 Mtetra
.71 .754 .887 r
.7477 .51165 .75077 .51583 .75747 .51271 .75441 .50853 Mtetra
.712 .756 .886 r
.75441 .50853 .75747 .51271 .76418 .50953 .76114 .50534 Mtetra
.716 .757 .885 r
.76114 .50534 .76418 .50953 .7709 .50627 .76786 .50208 Mtetra
.719 .759 .884 r
.76786 .50208 .7709 .50627 .77762 .50294 .7746 .49875 Mtetra
.722 .761 .883 r
.7746 .49875 .77762 .50294 .78434 .49954 .78134 .49535 Mtetra
.726 .762 .882 r
.78134 .49535 .78434 .49954 .79107 .49605 .78808 .49186 Mtetra
.729 .764 .881 r
.78808 .49186 .79107 .49605 .79781 .49248 .79483 .48829 Mtetra
.733 .766 .879 r
.79483 .48829 .79781 .49248 .80455 .48882 .80158 .48464 Mtetra
.737 .768 .878 r
.80158 .48464 .80455 .48882 .81129 .48507 .80833 .48089 Mtetra
.741 .77 .876 r
.80833 .48089 .81129 .48507 .81803 .48123 .81508 .47705 Mtetra
.745 .772 .875 r
.81508 .47705 .81803 .48123 .82477 .47729 .82184 .47311 Mtetra
.749 .774 .873 r
.82184 .47311 .82477 .47729 .83151 .47324 .82859 .46906 Mtetra
.754 .776 .871 r
.82859 .46906 .83151 .47324 .83825 .46907 .83535 .46491 Mtetra
.758 .778 .869 r
.83535 .46491 .83825 .46907 .84498 .4648 .84209 .46063 Mtetra
.763 .78 .867 r
.84209 .46063 .84498 .4648 .85171 .4604 .84884 .45624 Mtetra
.768 .783 .865 r
.84884 .45624 .85171 .4604 .85844 .45588 .85558 .45172 Mtetra
.773 .785 .863 r
.85558 .45172 .85844 .45588 .86515 .45122 .86231 .44707 Mtetra
.778 .788 .86 r
.86231 .44707 .86515 .45122 .87186 .44642 .86904 .44228 Mtetra
.784 .79 .858 r
.86904 .44228 .87186 .44642 .87856 .44148 .87575 .43735 Mtetra
.789 .793 .855 r
.87575 .43735 .87856 .44148 .88525 .43639 .88245 .43226 Mtetra
.795 .795 .852 r
.88245 .43226 .88525 .43639 .89192 .43114 .88914 .42702 Mtetra
.506 0 0 r
.26782 .54697 .27148 .54989 .27654 .55435 .27289 .5514 Mtetra
.455 0 0 r
.27289 .5514 .27654 .55435 .28166 .55856 .27801 .55559 Mtetra
0 .125 .591 r
.27801 .55559 .28166 .55856 .28682 .56255 .28317 .55955 Mtetra
0 .174 .64 r
.28317 .55955 .28682 .56255 .29203 .5663 .28838 .56328 Mtetra
0 .221 .686 r
.28838 .56328 .29203 .5663 .29728 .56984 .29363 .56679 Mtetra
0 .267 .728 r
.29363 .56679 .29728 .56984 .30257 .57317 .29893 .57009 Mtetra
0 .311 .767 r
.29893 .57009 .30257 .57317 .30791 .57628 .30427 .57319 Mtetra
0 .352 .801 r
.30427 .57319 .30791 .57628 .31329 .5792 .30965 .57607 Mtetra
0 .39 .831 r
.30965 .57607 .31329 .5792 .3187 .58191 .31507 .57876 Mtetra
0 .426 .857 r
.31507 .57876 .3187 .58191 .32416 .58443 .32053 .58126 Mtetra
.043 .458 .879 r
.32053 .58126 .32416 .58443 .32965 .58676 .32603 .58357 Mtetra
.09 .487 .898 r
.32603 .58357 .32965 .58676 .33518 .58892 .33156 .5857 Mtetra
.134 .514 .913 r
.33156 .5857 .33518 .58892 .34074 .59089 .33712 .58765 Mtetra
.175 .537 .925 r
.33712 .58765 .34074 .59089 .34633 .59269 .34272 .58942 Mtetra
.213 .559 .935 r
.34272 .58942 .34633 .59269 .35196 .59432 .34836 .59104 Mtetra
.249 .577 .943 r
.34836 .59104 .35196 .59432 .35762 .59579 .35402 .59248 Mtetra
.281 .594 .948 r
.35402 .59248 .35762 .59579 .36332 .59711 .35972 .59378 Mtetra
.311 .609 .953 r
.35972 .59378 .36332 .59711 .36904 .59827 .36545 .59491 Mtetra
.338 .622 .956 r
.36545 .59491 .36904 .59827 .37479 .59928 .3712 .59591 Mtetra
.364 .634 .958 r
.3712 .59591 .37479 .59928 .38057 .60015 .37699 .59675 Mtetra
.387 .644 .959 r
.37699 .59675 .38057 .60015 .38637 .60088 .3828 .59746 Mtetra
.408 .654 .959 r
.3828 .59746 .38637 .60088 .39221 .60148 .38864 .59804 Mtetra
.427 .662 .959 r
.38864 .59804 .39221 .60148 .39806 .60195 .3945 .59848 Mtetra
.445 .669 .958 r
.3945 .59848 .39806 .60195 .40395 .60229 .40039 .5988 Mtetra
.462 .676 .957 r
.40039 .5988 .40395 .60229 .40986 .60251 .40631 .599 Mtetra
.477 .682 .956 r
.40631 .599 .40986 .60251 .41579 .60261 .41225 .59909 Mtetra
.491 .687 .954 r
.41225 .59909 .41579 .60261 .42175 .6026 .41821 .59905 Mtetra
.504 .691 .952 r
.41821 .59905 .42175 .6026 .42773 .60248 .4242 .59891 Mtetra
.516 .696 .95 r
.4242 .59891 .42773 .60248 .43373 .60225 .4302 .59867 Mtetra
.527 .699 .948 r
.4302 .59867 .43373 .60225 .43975 .60193 .43623 .59832 Mtetra
.537 .703 .946 r
.43623 .59832 .43975 .60193 .44579 .6015 .44228 .59788 Mtetra
.547 .706 .944 r
.44228 .59788 .44579 .6015 .45186 .60098 .44835 .59734 Mtetra
.556 .709 .942 r
.44835 .59734 .45186 .60098 .45794 .60037 .45444 .59671 Mtetra
.564 .711 .94 r
.45444 .59671 .45794 .60037 .46404 .59967 .46056 .59599 Mtetra
.572 .713 .938 r
.46056 .59599 .46404 .59967 .47016 .59888 .46669 .59519 Mtetra
.579 .715 .936 r
.46669 .59519 .47016 .59888 .47631 .59802 .47283 .5943 Mtetra
.585 .717 .934 r
.47283 .5943 .47631 .59802 .48247 .59707 .479 .59334 Mtetra
.591 .719 .932 r
.479 .59334 .48247 .59707 .48864 .59605 .48519 .5923 Mtetra
.597 .721 .931 r
.48519 .5923 .48864 .59605 .49484 .59496 .49139 .59119 Mtetra
.603 .722 .929 r
.49139 .59119 .49484 .59496 .50105 .59379 .49761 .59001 Mtetra
.608 .723 .927 r
.49761 .59001 .50105 .59379 .50728 .59256 .50385 .58876 Mtetra
.612 .725 .925 r
.50385 .58876 .50728 .59256 .51352 .59126 .5101 .58745 Mtetra
.617 .726 .924 r
.5101 .58745 .51352 .59126 .51979 .5899 .51637 .58607 Mtetra
.621 .727 .922 r
.51637 .58607 .51979 .5899 .52607 .58848 .52266 .58463 Mtetra
.625 .728 .921 r
.52266 .58463 .52607 .58848 .53236 .587 .52896 .58314 Mtetra
.629 .729 .919 r
.52896 .58314 .53236 .587 .53867 .58546 .53528 .58159 Mtetra
.632 .73 .918 r
.53528 .58159 .53867 .58546 .54499 .58387 .54161 .57998 Mtetra
.636 .73 .917 r
.54161 .57998 .54499 .58387 .55133 .58222 .54796 .57832 Mtetra
.639 .731 .915 r
.54796 .57832 .55133 .58222 .55769 .58053 .55432 .57661 Mtetra
.642 .732 .914 r
.55432 .57661 .55769 .58053 .56406 .57878 .5607 .57485 Mtetra
.645 .733 .913 r
.5607 .57485 .56406 .57878 .57045 .57698 .5671 .57304 Mtetra
.647 .733 .912 r
.5671 .57304 .57045 .57698 .57684 .57514 .5735 .57118 Mtetra
.65 .734 .911 r
.5735 .57118 .57684 .57514 .58326 .57325 .57993 .56928 Mtetra
.653 .735 .91 r
.57993 .56928 .58326 .57325 .58969 .57131 .58636 .56733 Mtetra
.655 .735 .909 r
.58636 .56733 .58969 .57131 .59613 .56933 .59281 .56534 Mtetra
.657 .736 .908 r
.59281 .56534 .59613 .56933 .60258 .56731 .59928 .56331 Mtetra
.66 .737 .907 r
.59928 .56331 .60258 .56731 .60905 .56524 .60576 .56123 Mtetra
.662 .737 .906 r
.60576 .56123 .60905 .56524 .61553 .56313 .61225 .55911 Mtetra
.664 .738 .905 r
.61225 .55911 .61553 .56313 .62203 .56098 .61875 .55695 Mtetra
.666 .739 .904 r
.61875 .55695 .62203 .56098 .62854 .55879 .62527 .55474 Mtetra
.668 .739 .903 r
.62527 .55474 .62854 .55879 .63506 .55655 .6318 .5525 Mtetra
.67 .74 .903 r
.6318 .5525 .63506 .55655 .64159 .55428 .63835 .55021 Mtetra
.672 .741 .902 r
.63835 .55021 .64159 .55428 .64814 .55196 .6449 .54789 Mtetra
.674 .741 .901 r
.6449 .54789 .64814 .55196 .6547 .5496 .65147 .54552 Mtetra
.676 .742 .9 r
.65147 .54552 .6547 .5496 .66127 .5472 .65805 .54311 Mtetra
.678 .743 .9 r
.65805 .54311 .66127 .5472 .66785 .54475 .66465 .54065 Mtetra
.681 .744 .899 r
.66465 .54065 .66785 .54475 .67445 .54226 .67125 .53816 Mtetra
.683 .745 .898 r
.67125 .53816 .67445 .54226 .68106 .53973 .67787 .53561 Mtetra
.685 .745 .897 r
.67787 .53561 .68106 .53973 .68767 .53715 .6845 .53303 Mtetra
.687 .746 .897 r
.6845 .53303 .68767 .53715 .6943 .53452 .69114 .5304 Mtetra
.689 .747 .896 r
.69114 .5304 .6943 .53452 .70094 .53185 .69779 .52772 Mtetra
.691 .748 .895 r
.69779 .52772 .70094 .53185 .7076 .52912 .70445 .52499 Mtetra
.694 .749 .894 r
.70445 .52499 .7076 .52912 .71426 .52635 .71112 .52221 Mtetra
.696 .75 .893 r
.71112 .52221 .71426 .52635 .72093 .52352 .7178 .51938 Mtetra
.699 .751 .893 r
.7178 .51938 .72093 .52352 .72761 .52064 .7245 .51649 Mtetra
.701 .753 .892 r
.7245 .51649 .72761 .52064 .7343 .5177 .7312 .51355 Mtetra
.704 .754 .891 r
.7312 .51355 .7343 .5177 .74099 .51471 .73791 .51055 Mtetra
.707 .755 .89 r
.73791 .51055 .74099 .51471 .7477 .51165 .74462 .50749 Mtetra
.71 .756 .889 r
.74462 .50749 .7477 .51165 .75441 .50853 .75135 .50436 Mtetra
.712 .758 .888 r
.75135 .50436 .75441 .50853 .76114 .50534 .75808 .50117 Mtetra
.716 .759 .887 r
.75808 .50117 .76114 .50534 .76786 .50208 .76482 .49791 Mtetra
.719 .761 .886 r
.76482 .49791 .76786 .50208 .7746 .49875 .77157 .49458 Mtetra
.722 .762 .885 r
.77157 .49458 .7746 .49875 .78134 .49535 .77832 .49118 Mtetra
.725 .764 .883 r
.77832 .49118 .78134 .49535 .78808 .49186 .78508 .48769 Mtetra
.729 .766 .882 r
.78508 .48769 .78808 .49186 .79483 .48829 .79184 .48412 Mtetra
.733 .767 .881 r
.79184 .48412 .79483 .48829 .80158 .48464 .7986 .48047 Mtetra
.737 .769 .879 r
.7986 .48047 .80158 .48464 .80833 .48089 .80537 .47672 Mtetra
.741 .771 .878 r
.80537 .47672 .80833 .48089 .81508 .47705 .81213 .47288 Mtetra
.745 .773 .876 r
.81213 .47288 .81508 .47705 .82184 .47311 .8189 .46894 Mtetra
.749 .775 .874 r
.8189 .46894 .82184 .47311 .82859 .46906 .82567 .4649 Mtetra
.753 .777 .872 r
.82567 .4649 .82859 .46906 .83535 .46491 .83243 .46074 Mtetra
.758 .779 .87 r
.83243 .46074 .83535 .46491 .84209 .46063 .8392 .45647 Mtetra
.763 .781 .868 r
.8392 .45647 .84209 .46063 .84884 .45624 .84596 .45208 Mtetra
.768 .784 .866 r
.84596 .45208 .84884 .45624 .85558 .45172 .85271 .44757 Mtetra
.773 .786 .864 r
.85271 .44757 .85558 .45172 .86231 .44707 .85946 .44292 Mtetra
.778 .788 .861 r
.85946 .44292 .86231 .44707 .86904 .44228 .8662 .43814 Mtetra
.783 .791 .859 r
.8662 .43814 .86904 .44228 .87575 .43735 .87293 .43321 Mtetra
.789 .793 .856 r
.87293 .43321 .87575 .43735 .88245 .43226 .87964 .42813 Mtetra
.795 .796 .853 r
.87964 .42813 .88245 .43226 .88914 .42702 .88635 .4229 Mtetra
.497 0 0 r
.26415 .544 .26782 .54697 .27289 .5514 .26922 .5484 Mtetra
0 .084 .55 r
.26922 .5484 .27289 .5514 .27801 .55559 .27434 .55257 Mtetra
0 .133 .601 r
.27434 .55257 .27801 .55559 .28317 .55955 .27951 .5565 Mtetra
0 .181 .649 r
.27951 .5565 .28317 .55955 .28838 .56328 .28472 .56022 Mtetra
0 .228 .694 r
.28472 .56022 .28838 .56328 .29363 .56679 .28998 .56371 Mtetra
0 .273 .735 r
.28998 .56371 .29363 .56679 .29893 .57009 .29528 .56699 Mtetra
0 .316 .772 r
.29528 .56699 .29893 .57009 .30427 .57319 .30062 .57005 Mtetra
0 .357 .806 r
.30062 .57005 .30427 .57319 .30965 .57607 .306 .57292 Mtetra
0 .395 .835 r
.306 .57292 .30965 .57607 .31507 .57876 .31143 .57559 Mtetra
0 .43 .86 r
.31143 .57559 .31507 .57876 .32053 .58126 .31689 .57806 Mtetra
.049 .461 .882 r
.31689 .57806 .32053 .58126 .32603 .58357 .32239 .58035 Mtetra
.096 .49 .9 r
.32239 .58035 .32603 .58357 .33156 .5857 .32792 .58246 Mtetra
.139 .516 .914 r
.32792 .58246 .33156 .5857 .33712 .58765 .33349 .58439 Mtetra
.18 .54 .926 r
.33349 .58439 .33712 .58765 .34272 .58942 .3391 .58614 Mtetra
.217 .561 .936 r
.3391 .58614 .34272 .58942 .34836 .59104 .34474 .58773 Mtetra
.252 .579 .943 r
.34474 .58773 .34836 .59104 .35402 .59248 .35041 .58916 Mtetra
.284 .596 .949 r
.35041 .58916 .35402 .59248 .35972 .59378 .35611 .59043 Mtetra
.314 .611 .953 r
.35611 .59043 .35972 .59378 .36545 .59491 .36184 .59155 Mtetra
.341 .624 .956 r
.36184 .59155 .36545 .59491 .3712 .59591 .3676 .59252 Mtetra
.366 .635 .958 r
.3676 .59252 .3712 .59591 .37699 .59675 .37339 .59335 Mtetra
.388 .646 .959 r
.37339 .59335 .37699 .59675 .3828 .59746 .37921 .59404 Mtetra
.409 .655 .959 r
.37921 .59404 .3828 .59746 .38864 .59804 .38506 .59459 Mtetra
.429 .663 .959 r
.38506 .59459 .38864 .59804 .3945 .59848 .39093 .59502 Mtetra
.447 .671 .958 r
.39093 .59502 .3945 .59848 .40039 .5988 .39682 .59532 Mtetra
.463 .677 .957 r
.39682 .59532 .40039 .5988 .40631 .599 .40275 .5955 Mtetra
.478 .683 .956 r
.40275 .5955 .40631 .599 .41225 .59909 .40869 .59556 Mtetra
.492 .688 .955 r
.40869 .59556 .41225 .59909 .41821 .59905 .41466 .59551 Mtetra
.505 .693 .953 r
.41466 .59551 .41821 .59905 .4242 .59891 .42065 .59535 Mtetra
.517 .697 .951 r
.42065 .59535 .4242 .59891 .4302 .59867 .42667 .59509 Mtetra
.528 .701 .949 r
.42667 .59509 .4302 .59867 .43623 .59832 .4327 .59473 Mtetra
.538 .704 .947 r
.4327 .59473 .43623 .59832 .44228 .59788 .43876 .59426 Mtetra
.547 .707 .945 r
.43876 .59426 .44228 .59788 .44835 .59734 .44484 .59371 Mtetra
.556 .71 .943 r
.44484 .59371 .44835 .59734 .45444 .59671 .45094 .59306 Mtetra
.564 .713 .941 r
.45094 .59306 .45444 .59671 .46056 .59599 .45705 .59232 Mtetra
.572 .715 .939 r
.45705 .59232 .46056 .59599 .46669 .59519 .46319 .5915 Mtetra
.579 .717 .937 r
.46319 .5915 .46669 .59519 .47283 .5943 .46935 .5906 Mtetra
.586 .719 .935 r
.46935 .5906 .47283 .5943 .479 .59334 .47552 .58962 Mtetra
.592 .721 .934 r
.47552 .58962 .479 .59334 .48519 .5923 .48172 .58857 Mtetra
.597 .723 .932 r
.48172 .58857 .48519 .5923 .49139 .59119 .48793 .58744 Mtetra
.603 .724 .93 r
.48793 .58744 .49139 .59119 .49761 .59001 .49415 .58625 Mtetra
.608 .725 .928 r
.49415 .58625 .49761 .59001 .50385 .58876 .5004 .58498 Mtetra
.613 .727 .927 r
.5004 .58498 .50385 .58876 .5101 .58745 .50666 .58365 Mtetra
.617 .728 .925 r
.50666 .58365 .5101 .58745 .51637 .58607 .51294 .58226 Mtetra
.621 .729 .924 r
.51294 .58226 .51637 .58607 .52266 .58463 .51923 .58081 Mtetra
.625 .73 .922 r
.51923 .58081 .52266 .58463 .52896 .58314 .52554 .5793 Mtetra
.629 .731 .921 r
.52554 .5793 .52896 .58314 .53528 .58159 .53187 .57773 Mtetra
.632 .732 .92 r
.53187 .57773 .53528 .58159 .54161 .57998 .53821 .57611 Mtetra
.636 .733 .918 r
.53821 .57611 .54161 .57998 .54796 .57832 .54457 .57444 Mtetra
.639 .734 .917 r
.54457 .57444 .54796 .57832 .55432 .57661 .55094 .57272 Mtetra
.642 .734 .916 r
.55094 .57272 .55432 .57661 .5607 .57485 .55733 .57094 Mtetra
.645 .735 .915 r
.55733 .57094 .5607 .57485 .5671 .57304 .56373 .56912 Mtetra
.648 .736 .914 r
.56373 .56912 .5671 .57304 .5735 .57118 .57015 .56725 Mtetra
.65 .736 .912 r
.57015 .56725 .5735 .57118 .57993 .56928 .57658 .56534 Mtetra
.653 .737 .911 r
.57658 .56534 .57993 .56928 .58636 .56733 .58303 .56338 Mtetra
.655 .738 .911 r
.58303 .56338 .58636 .56733 .59281 .56534 .58949 .56137 Mtetra
.657 .738 .91 r
.58949 .56137 .59281 .56534 .59928 .56331 .59596 .55933 Mtetra
.66 .739 .909 r
.59596 .55933 .59928 .56331 .60576 .56123 .60245 .55724 Mtetra
.662 .74 .908 r
.60245 .55724 .60576 .56123 .61225 .55911 .60895 .55511 Mtetra
.664 .74 .907 r
.60895 .55511 .61225 .55911 .61875 .55695 .61546 .55294 Mtetra
.666 .741 .906 r
.61546 .55294 .61875 .55695 .62527 .55474 .62199 .55073 Mtetra
.668 .742 .905 r
.62199 .55073 .62527 .55474 .6318 .5525 .62853 .54847 Mtetra
.67 .742 .904 r
.62853 .54847 .6318 .5525 .63835 .55021 .63509 .54618 Mtetra
.672 .743 .904 r
.63509 .54618 .63835 .55021 .6449 .54789 .64165 .54384 Mtetra
.674 .744 .903 r
.64165 .54384 .6449 .54789 .65147 .54552 .64823 .54146 Mtetra
.677 .745 .902 r
.64823 .54146 .65147 .54552 .65805 .54311 .65482 .53904 Mtetra
.679 .745 .901 r
.65482 .53904 .65805 .54311 .66465 .54065 .66143 .53658 Mtetra
.681 .746 .901 r
.66143 .53658 .66465 .54065 .67125 .53816 .66804 .53408 Mtetra
.683 .747 .9 r
.66804 .53408 .67125 .53816 .67787 .53561 .67467 .53153 Mtetra
.685 .748 .899 r
.67467 .53153 .67787 .53561 .6845 .53303 .68131 .52894 Mtetra
.687 .749 .898 r
.68131 .52894 .6845 .53303 .69114 .5304 .68796 .5263 Mtetra
.689 .75 .898 r
.68796 .5263 .69114 .5304 .69779 .52772 .69462 .52361 Mtetra
.692 .751 .897 r
.69462 .52361 .69779 .52772 .70445 .52499 .7013 .52088 Mtetra
.694 .752 .896 r
.7013 .52088 .70445 .52499 .71112 .52221 .70798 .51809 Mtetra
.696 .753 .895 r
.70798 .51809 .71112 .52221 .7178 .51938 .71467 .51525 Mtetra
.699 .754 .894 r
.71467 .51525 .7178 .51938 .7245 .51649 .72137 .51236 Mtetra
.701 .755 .893 r
.72137 .51236 .7245 .51649 .7312 .51355 .72809 .50942 Mtetra
.704 .756 .892 r
.72809 .50942 .7312 .51355 .73791 .51055 .73481 .50641 Mtetra
.707 .757 .892 r
.73481 .50641 .73791 .51055 .74462 .50749 .74154 .50335 Mtetra
.71 .758 .891 r
.74154 .50335 .74462 .50749 .75135 .50436 .74827 .50022 Mtetra
.712 .76 .889 r
.74827 .50022 .75135 .50436 .75808 .50117 .75502 .49703 Mtetra
.716 .761 .888 r
.75502 .49703 .75808 .50117 .76482 .49791 .76177 .49376 Mtetra
.719 .763 .887 r
.76177 .49376 .76482 .49791 .77157 .49458 .76853 .49043 Mtetra
.722 .764 .886 r
.76853 .49043 .77157 .49458 .77832 .49118 .77529 .48702 Mtetra
.725 .766 .885 r
.77529 .48702 .77832 .49118 .78508 .48769 .78206 .48353 Mtetra
.729 .767 .883 r
.78206 .48353 .78508 .48769 .79184 .48412 .78883 .47996 Mtetra
.733 .769 .882 r
.78883 .47996 .79184 .48412 .7986 .48047 .79561 .47631 Mtetra
.736 .771 .881 r
.79561 .47631 .7986 .48047 .80537 .47672 .80239 .47256 Mtetra
.74 .773 .879 r
.80239 .47256 .80537 .47672 .81213 .47288 .80917 .46872 Mtetra
.745 .774 .877 r
.80917 .46872 .81213 .47288 .8189 .46894 .81595 .46478 Mtetra
.749 .776 .875 r
.81595 .46478 .8189 .46894 .82567 .4649 .82273 .46074 Mtetra
.753 .778 .874 r
.82273 .46074 .82567 .4649 .83243 .46074 .82951 .45658 Mtetra
.758 .78 .872 r
.82951 .45658 .83243 .46074 .8392 .45647 .83629 .45232 Mtetra
.763 .783 .869 r
.83629 .45232 .8392 .45647 .84596 .45208 .84306 .44793 Mtetra
.767 .785 .867 r
.84306 .44793 .84596 .45208 .85271 .44757 .84983 .44342 Mtetra
.772 .787 .865 r
.84983 .44342 .85271 .44757 .85946 .44292 .85659 .43878 Mtetra
.778 .789 .862 r
.85659 .43878 .85946 .44292 .8662 .43814 .86335 .434 Mtetra
.783 .791 .86 r
.86335 .434 .8662 .43814 .87293 .43321 .87009 .42907 Mtetra
.789 .794 .857 r
.87009 .42907 .87293 .43321 .87964 .42813 .87683 .424 Mtetra
.794 .796 .854 r
.87683 .424 .87964 .42813 .88635 .4229 .88355 .41877 Mtetra
.487 0 0 r
.26047 .54098 .26415 .544 .26922 .5484 .26554 .54536 Mtetra
0 .091 .559 r
.26554 .54536 .26922 .5484 .27434 .55257 .27066 .54951 Mtetra
0 .139 .609 r
.27066 .54951 .27434 .55257 .27951 .5565 .27583 .55342 Mtetra
0 .187 .656 r
.27583 .55342 .27951 .5565 .28472 .56022 .28104 .55711 Mtetra
0 .234 .7 r
.28104 .55711 .28472 .56022 .28998 .56371 .2863 .56059 Mtetra
0 .279 .741 r
.2863 .56059 .28998 .56371 .29528 .56699 .29161 .56384 Mtetra
0 .321 .778 r
.29161 .56384 .29528 .56699 .30062 .57005 .29695 .56689 Mtetra
0 .361 .81 r
.29695 .56689 .30062 .57005 .306 .57292 .30234 .56974 Mtetra
0 .399 .838 r
.30234 .56974 .306 .57292 .31143 .57559 .30777 .57239 Mtetra
.007 .433 .863 r
.30777 .57239 .31143 .57559 .31689 .57806 .31323 .57484 Mtetra
.055 .464 .884 r
.31323 .57484 .31689 .57806 .32239 .58035 .31873 .57711 Mtetra
.101 .493 .901 r
.31873 .57711 .32239 .58035 .32792 .58246 .32427 .5792 Mtetra
.144 .519 .916 r
.32427 .5792 .32792 .58246 .33349 .58439 .32985 .58111 Mtetra
.184 .542 .927 r
.32985 .58111 .33349 .58439 .3391 .58614 .33546 .58284 Mtetra
.221 .562 .937 r
.33546 .58284 .3391 .58614 .34474 .58773 .3411 .58441 Mtetra
.255 .581 .944 r
.3411 .58441 .34474 .58773 .35041 .58916 .34678 .58582 Mtetra
.287 .597 .949 r
.34678 .58582 .35041 .58916 .35611 .59043 .35248 .58707 Mtetra
.316 .612 .954 r
.35248 .58707 .35611 .59043 .36184 .59155 .35822 .58817 Mtetra
.343 .625 .956 r
.35822 .58817 .36184 .59155 .3676 .59252 .36399 .58913 Mtetra
.367 .637 .958 r
.36399 .58913 .3676 .59252 .37339 .59335 .36978 .58994 Mtetra
.39 .647 .959 r
.36978 .58994 .37339 .59335 .37921 .59404 .37561 .59061 Mtetra
.411 .656 .96 r
.37561 .59061 .37921 .59404 .38506 .59459 .38146 .59114 Mtetra
.43 .664 .96 r
.38146 .59114 .38506 .59459 .39093 .59502 .38734 .59155 Mtetra
.447 .672 .959 r
.38734 .59155 .39093 .59502 .39682 .59532 .39324 .59184 Mtetra
.464 .678 .958 r
.39324 .59184 .39682 .59532 .40275 .5955 .39917 .592 Mtetra
.479 .684 .957 r
.39917 .592 .40275 .5955 .40869 .59556 .40512 .59204 Mtetra
.493 .69 .955 r
.40512 .59204 .40869 .59556 .41466 .59551 .41109 .59198 Mtetra
.505 .694 .954 r
.41109 .59198 .41466 .59551 .42065 .59535 .41709 .5918 Mtetra
.517 .699 .952 r
.41709 .5918 .42065 .59535 .42667 .59509 .42311 .59152 Mtetra
.528 .702 .95 r
.42311 .59152 .42667 .59509 .4327 .59473 .42916 .59114 Mtetra
.538 .706 .948 r
.42916 .59114 .4327 .59473 .43876 .59426 .43522 .59066 Mtetra
.548 .709 .946 r
.43522 .59066 .43876 .59426 .44484 .59371 .44131 .59009 Mtetra
.556 .712 .944 r
.44131 .59009 .44484 .59371 .45094 .59306 .44741 .58942 Mtetra
.564 .715 .942 r
.44741 .58942 .45094 .59306 .45705 .59232 .45354 .58867 Mtetra
.572 .717 .94 r
.45354 .58867 .45705 .59232 .46319 .5915 .45968 .58783 Mtetra
.579 .719 .939 r
.45968 .58783 .46319 .5915 .46935 .5906 .46585 .58692 Mtetra
.586 .721 .937 r
.46585 .58692 .46935 .5906 .47552 .58962 .47203 .58592 Mtetra
.592 .723 .935 r
.47203 .58592 .47552 .58962 .48172 .58857 .47823 .58485 Mtetra
.598 .725 .933 r
.47823 .58485 .48172 .58857 .48793 .58744 .48445 .58371 Mtetra
.603 .726 .931 r
.48445 .58371 .48793 .58744 .49415 .58625 .49068 .5825 Mtetra
.608 .728 .93 r
.49068 .5825 .49415 .58625 .5004 .58498 .49694 .58122 Mtetra
.613 .729 .928 r
.49694 .58122 .5004 .58498 .50666 .58365 .50321 .57988 Mtetra
.617 .73 .927 r
.50321 .57988 .50666 .58365 .51294 .58226 .50949 .57847 Mtetra
.621 .731 .925 r
.50949 .57847 .51294 .58226 .51923 .58081 .5158 .57701 Mtetra
.625 .732 .924 r
.5158 .57701 .51923 .58081 .52554 .5793 .52212 .57549 Mtetra
.629 .733 .922 r
.52212 .57549 .52554 .5793 .53187 .57773 .52845 .57391 Mtetra
.633 .734 .921 r
.52845 .57391 .53187 .57773 .53821 .57611 .5348 .57227 Mtetra
.636 .735 .92 r
.5348 .57227 .53821 .57611 .54457 .57444 .54117 .57059 Mtetra
.639 .736 .919 r
.54117 .57059 .54457 .57444 .55094 .57272 .54755 .56885 Mtetra
.642 .737 .918 r
.54755 .56885 .55094 .57272 .55733 .57094 .55395 .56706 Mtetra
.645 .737 .916 r
.55395 .56706 .55733 .57094 .56373 .56912 .56036 .56523 Mtetra
.648 .738 .915 r
.56036 .56523 .56373 .56912 .57015 .56725 .56678 .56335 Mtetra
.65 .739 .914 r
.56678 .56335 .57015 .56725 .57658 .56534 .57323 .56142 Mtetra
.653 .74 .913 r
.57323 .56142 .57658 .56534 .58303 .56338 .57968 .55945 Mtetra
.655 .74 .912 r
.57968 .55945 .58303 .56338 .58949 .56137 .58615 .55744 Mtetra
.658 .741 .911 r
.58615 .55744 .58949 .56137 .59596 .55933 .59263 .55538 Mtetra
.66 .742 .91 r
.59263 .55538 .59596 .55933 .60245 .55724 .59913 .55328 Mtetra
.662 .742 .91 r
.59913 .55328 .60245 .55724 .60895 .55511 .60564 .55114 Mtetra
.664 .743 .909 r
.60564 .55114 .60895 .55511 .61546 .55294 .61216 .54896 Mtetra
.666 .744 .908 r
.61216 .54896 .61546 .55294 .62199 .55073 .6187 .54674 Mtetra
.668 .744 .907 r
.6187 .54674 .62199 .55073 .62853 .54847 .62525 .54447 Mtetra
.67 .745 .906 r
.62525 .54447 .62853 .54847 .63509 .54618 .63182 .54217 Mtetra
.673 .746 .906 r
.63182 .54217 .63509 .54618 .64165 .54384 .63839 .53982 Mtetra
.675 .746 .905 r
.63839 .53982 .64165 .54384 .64823 .54146 .64498 .53744 Mtetra
.677 .747 .904 r
.64498 .53744 .64823 .54146 .65482 .53904 .65158 .53501 Mtetra
.679 .748 .903 r
.65158 .53501 .65482 .53904 .66143 .53658 .6582 .53254 Mtetra
.681 .749 .902 r
.6582 .53254 .66143 .53658 .66804 .53408 .66482 .53003 Mtetra
.683 .749 .902 r
.66482 .53003 .66804 .53408 .67467 .53153 .67146 .52747 Mtetra
.685 .75 .901 r
.67146 .52747 .67467 .53153 .68131 .52894 .67811 .52487 Mtetra
.687 .751 .9 r
.67811 .52487 .68131 .52894 .68796 .5263 .68477 .52222 Mtetra
.689 .752 .899 r
.68477 .52222 .68796 .5263 .69462 .52361 .69145 .51953 Mtetra
.692 .753 .899 r
.69145 .51953 .69462 .52361 .7013 .52088 .69813 .51679 Mtetra
.694 .754 .898 r
.69813 .51679 .7013 .52088 .70798 .51809 .70482 .514 Mtetra
.696 .755 .897 r
.70482 .514 .70798 .51809 .71467 .51525 .71153 .51116 Mtetra
.699 .756 .896 r
.71153 .51116 .71467 .51525 .72137 .51236 .71824 .50826 Mtetra
.701 .757 .895 r
.71824 .50826 .72137 .51236 .72809 .50942 .72496 .50531 Mtetra
.704 .758 .894 r
.72496 .50531 .72809 .50942 .73481 .50641 .7317 .5023 Mtetra
.707 .759 .893 r
.7317 .5023 .73481 .50641 .74154 .50335 .73844 .49923 Mtetra
.71 .761 .892 r
.73844 .49923 .74154 .50335 .74827 .50022 .74519 .4961 Mtetra
.713 .762 .891 r
.74519 .4961 .74827 .50022 .75502 .49703 .75194 .4929 Mtetra
.716 .763 .89 r
.75194 .4929 .75502 .49703 .76177 .49376 .75871 .48963 Mtetra
.719 .765 .889 r
.75871 .48963 .76177 .49376 .76853 .49043 .76548 .4863 Mtetra
.722 .766 .888 r
.76548 .4863 .76853 .49043 .77529 .48702 .77225 .48288 Mtetra
.725 .768 .886 r
.77225 .48288 .77529 .48702 .78206 .48353 .77904 .47939 Mtetra
.729 .769 .885 r
.77904 .47939 .78206 .48353 .78883 .47996 .78582 .47582 Mtetra
.733 .771 .883 r
.78582 .47582 .78883 .47996 .79561 .47631 .79261 .47216 Mtetra
.736 .773 .882 r
.79261 .47216 .79561 .47631 .80239 .47256 .7994 .46842 Mtetra
.74 .774 .88 r
.7994 .46842 .80239 .47256 .80917 .46872 .8062 .46457 Mtetra
.745 .776 .879 r
.8062 .46457 .80917 .46872 .81595 .46478 .81299 .46063 Mtetra
.749 .778 .877 r
.81299 .46063 .81595 .46478 .82273 .46074 .81979 .45659 Mtetra
.753 .78 .875 r
.81979 .45659 .82273 .46074 .82951 .45658 .82658 .45244 Mtetra
.758 .782 .873 r
.82658 .45244 .82951 .45658 .83629 .45232 .83337 .44817 Mtetra
.762 .784 .871 r
.83337 .44817 .83629 .45232 .84306 .44793 .84016 .44378 Mtetra
.767 .786 .868 r
.84016 .44378 .84306 .44793 .84983 .44342 .84694 .43927 Mtetra
.772 .788 .866 r
.84694 .43927 .84983 .44342 .85659 .43878 .85372 .43463 Mtetra
.778 .79 .863 r
.85372 .43463 .85659 .43878 .86335 .434 .86049 .42985 Mtetra
.783 .792 .86 r
.86049 .42985 .86335 .434 .87009 .42907 .86725 .42493 Mtetra
.788 .795 .857 r
.86725 .42493 .87009 .42907 .87683 .424 .874 .41986 Mtetra
.794 .797 .854 r
.874 .41986 .87683 .424 .88355 .41877 .88073 .41463 Mtetra
.479 0 0 r
.25678 .53791 .26047 .54098 .26554 .54536 .26185 .54228 Mtetra
0 .098 .568 r
.26185 .54228 .26554 .54536 .27066 .54951 .26697 .54641 Mtetra
0 .146 .617 r
.26697 .54641 .27066 .54951 .27583 .55342 .27214 .5503 Mtetra
0 .193 .663 r
.27214 .5503 .27583 .55342 .28104 .55711 .27736 .55398 Mtetra
0 .239 .707 r
.27736 .55398 .28104 .55711 .2863 .56059 .28262 .55743 Mtetra
0 .284 .746 r
.28262 .55743 .2863 .56059 .29161 .56384 .28792 .56067 Mtetra
0 .326 .782 r
.28792 .56067 .29161 .56384 .29695 .56689 .29327 .5637 Mtetra
0 .365 .814 r
.29327 .5637 .29695 .56689 .30234 .56974 .29866 .56653 Mtetra
0 .402 .841 r
.29866 .56653 .30234 .56974 .30777 .57239 .30409 .56916 Mtetra
.012 .436 .865 r
.30409 .56916 .30777 .57239 .31323 .57484 .30956 .5716 Mtetra
.06 .467 .886 r
.30956 .5716 .31323 .57484 .31873 .57711 .31507 .57385 Mtetra
.106 .495 .903 r
.31507 .57385 .31873 .57711 .32427 .5792 .32061 .57592 Mtetra
.148 .521 .917 r
.32061 .57592 .32427 .5792 .32985 .58111 .32619 .57781 Mtetra
.187 .543 .928 r
.32619 .57781 .32985 .58111 .33546 .58284 .3318 .57953 Mtetra
.224 .564 .937 r
.3318 .57953 .33546 .58284 .3411 .58441 .33745 .58108 Mtetra
.258 .582 .944 r
.33745 .58108 .3411 .58441 .34678 .58582 .34313 .58247 Mtetra
.289 .599 .95 r
.34313 .58247 .34678 .58582 .35248 .58707 .34884 .58371 Mtetra
.318 .613 .954 r
.34884 .58371 .35248 .58707 .35822 .58817 .35459 .58479 Mtetra
.344 .626 .957 r
.35459 .58479 .35822 .58817 .36399 .58913 .36036 .58573 Mtetra
.368 .638 .959 r
.36036 .58573 .36399 .58913 .36978 .58994 .36616 .58652 Mtetra
.391 .648 .96 r
.36616 .58652 .36978 .58994 .37561 .59061 .37199 .58717 Mtetra
.412 .657 .96 r
.37199 .58717 .37561 .59061 .38146 .59114 .37785 .58769 Mtetra
.431 .666 .96 r
.37785 .58769 .38146 .59114 .38734 .59155 .38373 .58809 Mtetra
.448 .673 .959 r
.38373 .58809 .38734 .59155 .39324 .59184 .38964 .58835 Mtetra
.464 .68 .959 r
.38964 .58835 .39324 .59184 .39917 .592 .39557 .5885 Mtetra
.479 .686 .957 r
.39557 .5885 .39917 .592 .40512 .59204 .40153 .58853 Mtetra
.493 .691 .956 r
.40153 .58853 .40512 .59204 .41109 .59198 .40751 .58844 Mtetra
.506 .696 .954 r
.40751 .58844 .41109 .59198 .41709 .5918 .41352 .58825 Mtetra
.517 .7 .953 r
.41352 .58825 .41709 .5918 .42311 .59152 .41955 .58796 Mtetra
.528 .704 .951 r
.41955 .58796 .42311 .59152 .42916 .59114 .4256 .58756 Mtetra
.538 .708 .949 r
.4256 .58756 .42916 .59114 .43522 .59066 .43167 .58706 Mtetra
.548 .711 .947 r
.43167 .58706 .43522 .59066 .44131 .59009 .43776 .58648 Mtetra
.556 .714 .945 r
.43776 .58648 .44131 .59009 .44741 .58942 .44387 .5858 Mtetra
.565 .716 .943 r
.44387 .5858 .44741 .58942 .45354 .58867 .45001 .58503 Mtetra
.572 .719 .942 r
.45001 .58503 .45354 .58867 .45968 .58783 .45616 .58418 Mtetra
.579 .721 .94 r
.45616 .58418 .45968 .58783 .46585 .58692 .46233 .58325 Mtetra
.586 .723 .938 r
.46233 .58325 .46585 .58692 .47203 .58592 .46852 .58224 Mtetra
.592 .725 .936 r
.46852 .58224 .47203 .58592 .47823 .58485 .47473 .58116 Mtetra
.598 .727 .935 r
.47473 .58116 .47823 .58485 .48445 .58371 .48096 .58 Mtetra
.603 .728 .933 r
.48096 .58 .48445 .58371 .49068 .5825 .4872 .57878 Mtetra
.608 .73 .931 r
.4872 .57878 .49068 .5825 .49694 .58122 .49346 .57749 Mtetra
.613 .731 .93 r
.49346 .57749 .49694 .58122 .50321 .57988 .49974 .57613 Mtetra
.617 .732 .928 r
.49974 .57613 .50321 .57988 .50949 .57847 .50604 .57471 Mtetra
.621 .733 .927 r
.50604 .57471 .50949 .57847 .5158 .57701 .51235 .57323 Mtetra
.625 .735 .925 r
.51235 .57323 .5158 .57701 .52212 .57549 .51868 .5717 Mtetra
.629 .736 .924 r
.51868 .5717 .52212 .57549 .52845 .57391 .52502 .5701 Mtetra
.633 .737 .923 r
.52502 .5701 .52845 .57391 .5348 .57227 .53138 .56846 Mtetra
.636 .737 .922 r
.53138 .56846 .5348 .57227 .54117 .57059 .53775 .56676 Mtetra
.639 .738 .92 r
.53775 .56676 .54117 .57059 .54755 .56885 .54414 .56501 Mtetra
.642 .739 .919 r
.54414 .56501 .54755 .56885 .55395 .56706 .55055 .56321 Mtetra
.645 .74 .918 r
.55055 .56321 .55395 .56706 .56036 .56523 .55697 .56137 Mtetra
.648 .741 .917 r
.55697 .56137 .56036 .56523 .56678 .56335 .56341 .55947 Mtetra
.65 .741 .916 r
.56341 .55947 .56678 .56335 .57323 .56142 .56986 .55754 Mtetra
.653 .742 .915 r
.56986 .55754 .57323 .56142 .57968 .55945 .57632 .55555 Mtetra
.655 .743 .914 r
.57632 .55555 .57968 .55945 .58615 .55744 .5828 .55353 Mtetra
.658 .744 .913 r
.5828 .55353 .58615 .55744 .59263 .55538 .58929 .55146 Mtetra
.66 .744 .912 r
.58929 .55146 .59263 .55538 .59913 .55328 .5958 .54935 Mtetra
.662 .745 .912 r
.5958 .54935 .59913 .55328 .60564 .55114 .60232 .5472 Mtetra
.664 .746 .911 r
.60232 .5472 .60564 .55114 .61216 .54896 .60885 .54501 Mtetra
.666 .746 .91 r
.60885 .54501 .61216 .54896 .6187 .54674 .6154 .54278 Mtetra
.669 .747 .909 r
.6154 .54278 .6187 .54674 .62525 .54447 .62196 .5405 Mtetra
.671 .748 .908 r
.62196 .5405 .62525 .54447 .63182 .54217 .62853 .53819 Mtetra
.673 .748 .907 r
.62853 .53819 .63182 .54217 .63839 .53982 .63512 .53584 Mtetra
.675 .749 .907 r
.63512 .53584 .63839 .53982 .64498 .53744 .64172 .53344 Mtetra
.677 .75 .906 r
.64172 .53344 .64498 .53744 .65158 .53501 .64833 .531 Mtetra
.679 .75 .905 r
.64833 .531 .65158 .53501 .6582 .53254 .65496 .52853 Mtetra
.681 .751 .904 r
.65496 .52853 .6582 .53254 .66482 .53003 .66159 .52601 Mtetra
.683 .752 .904 r
.66159 .52601 .66482 .53003 .67146 .52747 .66824 .52344 Mtetra
.685 .753 .903 r
.66824 .52344 .67146 .52747 .67811 .52487 .6749 .52083 Mtetra
.687 .754 .902 r
.6749 .52083 .67811 .52487 .68477 .52222 .68157 .51818 Mtetra
.689 .754 .901 r
.68157 .51818 .68477 .52222 .69145 .51953 .68826 .51548 Mtetra
.692 .755 .9 r
.68826 .51548 .69145 .51953 .69813 .51679 .69495 .51273 Mtetra
.694 .756 .9 r
.69495 .51273 .69813 .51679 .70482 .514 .70166 .50993 Mtetra
.696 .757 .899 r
.70166 .50993 .70482 .514 .71153 .51116 .70837 .50708 Mtetra
.699 .758 .898 r
.70837 .50708 .71153 .51116 .71824 .50826 .7151 .50418 Mtetra
.701 .759 .897 r
.7151 .50418 .71824 .50826 .72496 .50531 .72183 .50122 Mtetra
.704 .76 .896 r
.72183 .50122 .72496 .50531 .7317 .5023 .72858 .49821 Mtetra
.707 .762 .895 r
.72858 .49821 .7317 .5023 .73844 .49923 .73533 .49513 Mtetra
.71 .763 .894 r
.73533 .49513 .73844 .49923 .74519 .4961 .74209 .492 Mtetra
.713 .764 .893 r
.74209 .492 .74519 .4961 .75194 .4929 .74886 .48879 Mtetra
.716 .765 .892 r
.74886 .48879 .75194 .4929 .75871 .48963 .75564 .48552 Mtetra
.719 .767 .89 r
.75564 .48552 .75871 .48963 .76548 .4863 .76242 .48218 Mtetra
.722 .768 .889 r
.76242 .48218 .76548 .4863 .77225 .48288 .76921 .47877 Mtetra
.725 .77 .888 r
.76921 .47877 .77225 .48288 .77904 .47939 .776 .47527 Mtetra
.729 .771 .886 r
.776 .47527 .77904 .47939 .78582 .47582 .7828 .4717 Mtetra
.733 .773 .885 r
.7828 .4717 .78582 .47582 .79261 .47216 .7896 .46804 Mtetra
.737 .774 .883 r
.7896 .46804 .79261 .47216 .7994 .46842 .79641 .46428 Mtetra
.74 .776 .882 r
.79641 .46428 .7994 .46842 .8062 .46457 .80322 .46044 Mtetra
.745 .778 .88 r
.80322 .46044 .8062 .46457 .81299 .46063 .81002 .4565 Mtetra
.749 .779 .878 r
.81002 .4565 .81299 .46063 .81979 .45659 .81683 .45245 Mtetra
.753 .781 .876 r
.81683 .45245 .81979 .45659 .82658 .45244 .82364 .4483 Mtetra
.758 .783 .874 r
.82364 .4483 .82658 .45244 .83337 .44817 .83045 .44403 Mtetra
.762 .785 .872 r
.83045 .44403 .83337 .44817 .84016 .44378 .83725 .43964 Mtetra
.767 .787 .869 r
.83725 .43964 .84016 .44378 .84694 .43927 .84405 .43513 Mtetra
.772 .789 .867 r
.84405 .43513 .84694 .43927 .85372 .43463 .85084 .43049 Mtetra
.777 .791 .864 r
.85084 .43049 .85372 .43463 .86049 .42985 .85762 .42571 Mtetra
.783 .793 .861 r
.85762 .42571 .86049 .42985 .86725 .42493 .8644 .42079 Mtetra
.788 .795 .858 r
.8644 .42079 .86725 .42493 .874 .41986 .87116 .41572 Mtetra
.794 .798 .855 r
.87116 .41572 .874 .41986 .88073 .41463 .87791 .41049 Mtetra
.471 0 0 r
.25307 .5348 .25678 .53791 .26185 .54228 .25814 .53915 Mtetra
0 .104 .576 r
.25814 .53915 .26185 .54228 .26697 .54641 .26327 .54326 Mtetra
0 .151 .624 r
.26327 .54326 .26697 .54641 .27214 .5503 .26844 .54715 Mtetra
0 .198 .67 r
.26844 .54715 .27214 .5503 .27736 .55398 .27366 .55081 Mtetra
0 .244 .712 r
.27366 .55081 .27736 .55398 .28262 .55743 .27892 .55424 Mtetra
0 .288 .751 r
.27892 .55424 .28262 .55743 .28792 .56067 .28423 .55747 Mtetra
0 .33 .786 r
.28423 .55747 .28792 .56067 .29327 .5637 .28958 .56048 Mtetra
0 .369 .817 r
.28958 .56048 .29327 .5637 .29866 .56653 .29497 .5633 Mtetra
0 .405 .844 r
.29497 .5633 .29866 .56653 .30409 .56916 .3004 .56591 Mtetra
.017 .439 .867 r
.3004 .56591 .30409 .56916 .30956 .5716 .30588 .56833 Mtetra
.065 .469 .887 r
.30588 .56833 .30956 .5716 .31507 .57385 .31139 .57057 Mtetra
.109 .497 .904 r
.31139 .57057 .31507 .57385 .32061 .57592 .31693 .57262 Mtetra
.151 .522 .918 r
.31693 .57262 .32061 .57592 .32619 .57781 .32252 .5745 Mtetra
.19 .545 .929 r
.32252 .5745 .32619 .57781 .3318 .57953 .32814 .5762 Mtetra
.226 .565 .938 r
.32814 .5762 .3318 .57953 .33745 .58108 .33379 .57774 Mtetra
.26 .583 .945 r
.33379 .57774 .33745 .58108 .34313 .58247 .33947 .57911 Mtetra
.291 .6 .95 r
.33947 .57911 .34313 .58247 .34884 .58371 .34519 .58033 Mtetra
.319 .614 .954 r
.34519 .58033 .34884 .58371 .35459 .58479 .35094 .5814 Mtetra
.345 .627 .957 r
.35094 .5814 .35459 .58479 .36036 .58573 .35671 .58232 Mtetra
.369 .639 .959 r
.35671 .58232 .36036 .58573 .36616 .58652 .36252 .5831 Mtetra
.392 .649 .96 r
.36252 .5831 .36616 .58652 .37199 .58717 .36836 .58374 Mtetra
.412 .658 .961 r
.36836 .58374 .37199 .58717 .37785 .58769 .37422 .58424 Mtetra
.431 .667 .961 r
.37422 .58424 .37785 .58769 .38373 .58809 .38011 .58462 Mtetra
.448 .674 .96 r
.38011 .58462 .38373 .58809 .38964 .58835 .38602 .58487 Mtetra
.464 .681 .959 r
.38602 .58487 .38964 .58835 .39557 .5885 .39196 .585 Mtetra
.479 .687 .958 r
.39196 .585 .39557 .5885 .40153 .58853 .39793 .58502 Mtetra
.493 .692 .957 r
.39793 .58502 .40153 .58853 .40751 .58844 .40392 .58492 Mtetra
.506 .697 .955 r
.40392 .58492 .40751 .58844 .41352 .58825 .40993 .58471 Mtetra
.517 .702 .954 r
.40993 .58471 .41352 .58825 .41955 .58796 .41596 .5844 Mtetra
.528 .705 .952 r
.41596 .5844 .41955 .58796 .4256 .58756 .42202 .58399 Mtetra
.538 .709 .95 r
.42202 .58399 .4256 .58756 .43167 .58706 .4281 .58348 Mtetra
.548 .712 .948 r
.4281 .58348 .43167 .58706 .43776 .58648 .4342 .58288 Mtetra
.556 .715 .946 r
.4342 .58288 .43776 .58648 .44387 .5858 .44032 .58219 Mtetra
.565 .718 .945 r
.44032 .58219 .44387 .5858 .45001 .58503 .44646 .58141 Mtetra
.572 .721 .943 r
.44646 .58141 .45001 .58503 .45616 .58418 .45262 .58054 Mtetra
.579 .723 .941 r
.45262 .58054 .45616 .58418 .46233 .58325 .4588 .5796 Mtetra
.586 .725 .939 r
.4588 .5796 .46233 .58325 .46852 .58224 .465 .57858 Mtetra
.592 .727 .938 r
.465 .57858 .46852 .58224 .47473 .58116 .47121 .57748 Mtetra
.598 .729 .936 r
.47121 .57748 .47473 .58116 .48096 .58 .47745 .57631 Mtetra
.603 .73 .934 r
.47745 .57631 .48096 .58 .4872 .57878 .4837 .57507 Mtetra
.608 .732 .933 r
.4837 .57507 .4872 .57878 .49346 .57749 .48997 .57377 Mtetra
.613 .733 .931 r
.48997 .57377 .49346 .57749 .49974 .57613 .49626 .5724 Mtetra
.617 .734 .93 r
.49626 .5724 .49974 .57613 .50604 .57471 .50256 .57097 Mtetra
.621 .736 .929 r
.50256 .57097 .50604 .57471 .51235 .57323 .50888 .56948 Mtetra
.625 .737 .927 r
.50888 .56948 .51235 .57323 .51868 .5717 .51522 .56793 Mtetra
.629 .738 .926 r
.51522 .56793 .51868 .5717 .52502 .5701 .52157 .56633 Mtetra
.633 .739 .925 r
.52157 .56633 .52502 .5701 .53138 .56846 .52794 .56467 Mtetra
.636 .74 .923 r
.52794 .56467 .53138 .56846 .53775 .56676 .53432 .56296 Mtetra
.639 .741 .922 r
.53432 .56296 .53775 .56676 .54414 .56501 .54072 .5612 Mtetra
.642 .742 .921 r
.54072 .5612 .54414 .56501 .55055 .56321 .54714 .55939 Mtetra
.645 .742 .92 r
.54714 .55939 .55055 .56321 .55697 .56137 .55357 .55753 Mtetra
.648 .743 .919 r
.55357 .55753 .55697 .56137 .56341 .55947 .56001 .55563 Mtetra
.65 .744 .918 r
.56001 .55563 .56341 .55947 .56986 .55754 .56647 .55368 Mtetra
.653 .745 .917 r
.56647 .55368 .56986 .55754 .57632 .55555 .57295 .55169 Mtetra
.655 .745 .916 r
.57295 .55169 .57632 .55555 .5828 .55353 .57943 .54965 Mtetra
.658 .746 .915 r
.57943 .54965 .5828 .55353 .58929 .55146 .58594 .54757 Mtetra
.66 .747 .914 r
.58594 .54757 .58929 .55146 .5958 .54935 .59245 .54545 Mtetra
.662 .747 .913 r
.59245 .54545 .5958 .54935 .60232 .5472 .59898 .54329 Mtetra
.664 .748 .913 r
.59898 .54329 .60232 .5472 .60885 .54501 .60553 .54109 Mtetra
.666 .749 .912 r
.60553 .54109 .60885 .54501 .6154 .54278 .61208 .53885 Mtetra
.669 .749 .911 r
.61208 .53885 .6154 .54278 .62196 .5405 .61865 .53657 Mtetra
.671 .75 .91 r
.61865 .53657 .62196 .5405 .62853 .53819 .62524 .53424 Mtetra
.673 .751 .909 r
.62524 .53424 .62853 .53819 .63512 .53584 .63183 .53188 Mtetra
.675 .752 .909 r
.63183 .53188 .63512 .53584 .64172 .53344 .63844 .52948 Mtetra
.677 .752 .908 r
.63844 .52948 .64172 .53344 .64833 .531 .64507 .52703 Mtetra
.679 .753 .907 r
.64507 .52703 .64833 .531 .65496 .52853 .6517 .52454 Mtetra
.681 .754 .906 r
.6517 .52454 .65496 .52853 .66159 .52601 .65835 .52201 Mtetra
.683 .754 .906 r
.65835 .52201 .66159 .52601 .66824 .52344 .66501 .51944 Mtetra
.685 .755 .905 r
.66501 .51944 .66824 .52344 .6749 .52083 .67168 .51683 Mtetra
.687 .756 .904 r
.67168 .51683 .6749 .52083 .68157 .51818 .67836 .51416 Mtetra
.69 .757 .903 r
.67836 .51416 .68157 .51818 .68826 .51548 .68506 .51146 Mtetra
.692 .758 .902 r
.68506 .51146 .68826 .51548 .69495 .51273 .69176 .5087 Mtetra
.694 .759 .901 r
.69176 .5087 .69495 .51273 .70166 .50993 .69848 .5059 Mtetra
.697 .76 .901 r
.69848 .5059 .70166 .50993 .70837 .50708 .70521 .50304 Mtetra
.699 .761 .9 r
.70521 .50304 .70837 .50708 .7151 .50418 .71194 .50013 Mtetra
.702 .762 .899 r
.71194 .50013 .7151 .50418 .72183 .50122 .71869 .49717 Mtetra
.704 .763 .898 r
.71869 .49717 .72183 .50122 .72858 .49821 .72545 .49415 Mtetra
.707 .764 .897 r
.72545 .49415 .72858 .49821 .73533 .49513 .73221 .49106 Mtetra
.71 .765 .896 r
.73221 .49106 .73533 .49513 .74209 .492 .73898 .48792 Mtetra
.713 .766 .894 r
.73898 .48792 .74209 .492 .74886 .48879 .74577 .48471 Mtetra
.716 .768 .893 r
.74577 .48471 .74886 .48879 .75564 .48552 .75255 .48144 Mtetra
.719 .769 .892 r
.75255 .48144 .75564 .48552 .76242 .48218 .75935 .47809 Mtetra
.722 .77 .891 r
.75935 .47809 .76242 .48218 .76921 .47877 .76615 .47467 Mtetra
.726 .772 .889 r
.76615 .47467 .76921 .47877 .776 .47527 .77296 .47117 Mtetra
.729 .773 .888 r
.77296 .47117 .776 .47527 .7828 .4717 .77977 .46759 Mtetra
.733 .775 .886 r
.77977 .46759 .7828 .4717 .7896 .46804 .78658 .46392 Mtetra
.737 .776 .885 r
.78658 .46392 .7896 .46804 .79641 .46428 .7934 .46017 Mtetra
.741 .778 .883 r
.7934 .46017 .79641 .46428 .80322 .46044 .80022 .45632 Mtetra
.745 .779 .881 r
.80022 .45632 .80322 .46044 .81002 .4565 .80704 .45237 Mtetra
.749 .781 .879 r
.80704 .45237 .81002 .4565 .81683 .45245 .81387 .44832 Mtetra
.753 .783 .877 r
.81387 .44832 .81683 .45245 .82364 .4483 .82069 .44417 Mtetra
.758 .785 .875 r
.82069 .44417 .82364 .4483 .83045 .44403 .82751 .4399 Mtetra
.762 .786 .873 r
.82751 .4399 .83045 .44403 .83725 .43964 .83432 .43551 Mtetra
.767 .788 .87 r
.83432 .43551 .83725 .43964 .84405 .43513 .84114 .43099 Mtetra
.772 .79 .868 r
.84114 .43099 .84405 .43513 .85084 .43049 .84794 .42635 Mtetra
.777 .792 .865 r
.84794 .42635 .85084 .43049 .85762 .42571 .85474 .42157 Mtetra
.783 .794 .862 r
.85474 .42157 .85762 .42571 .8644 .42079 .86153 .41664 Mtetra
.788 .796 .859 r
.86153 .41664 .8644 .42079 .87116 .41572 .86831 .41157 Mtetra
.794 .798 .856 r
.86831 .41157 .87116 .41572 .87791 .41049 .87508 .40634 Mtetra
.463 0 0 r
.24935 .53165 .25307 .5348 .25814 .53915 .25443 .53598 Mtetra
0 .109 .583 r
.25443 .53598 .25814 .53915 .26327 .54326 .25955 .54008 Mtetra
0 .156 .631 r
.25955 .54008 .26327 .54326 .26844 .54715 .26472 .54395 Mtetra
0 .203 .676 r
.26472 .54395 .26844 .54715 .27366 .55081 .26994 .5476 Mtetra
0 .248 .717 r
.26994 .5476 .27366 .55081 .27892 .55424 .27521 .55102 Mtetra
0 .292 .755 r
.27521 .55102 .27892 .55424 .28423 .55747 .28052 .55423 Mtetra
0 .333 .789 r
.28052 .55423 .28423 .55747 .28958 .56048 .28587 .55723 Mtetra
0 .372 .82 r
.28587 .55723 .28958 .56048 .29497 .5633 .29127 .56003 Mtetra
0 .408 .846 r
.29127 .56003 .29497 .5633 .3004 .56591 .2967 .56263 Mtetra
.022 .441 .869 r
.2967 .56263 .3004 .56591 .30588 .56833 .30218 .56504 Mtetra
.069 .471 .889 r
.30218 .56504 .30588 .56833 .31139 .57057 .30769 .56726 Mtetra
.113 .499 .905 r
.30769 .56726 .31139 .57057 .31693 .57262 .31324 .5693 Mtetra
.154 .524 .918 r
.31324 .5693 .31693 .57262 .32252 .5745 .31883 .57117 Mtetra
.193 .546 .929 r
.31883 .57117 .32252 .5745 .32814 .5762 .32445 .57286 Mtetra
.228 .566 .938 r
.32445 .57286 .32814 .5762 .33379 .57774 .33011 .57438 Mtetra
.261 .584 .945 r
.33011 .57438 .33379 .57774 .33947 .57911 .3358 .57574 Mtetra
.292 .601 .951 r
.3358 .57574 .33947 .57911 .34519 .58033 .34152 .57695 Mtetra
.32 .615 .955 r
.34152 .57695 .34519 .58033 .35094 .5814 .34727 .578 Mtetra
.346 .628 .958 r
.34727 .578 .35094 .5814 .35671 .58232 .35305 .57891 Mtetra
.37 .64 .959 r
.35305 .57891 .35671 .58232 .36252 .5831 .35887 .57967 Mtetra
.392 .65 .961 r
.35887 .57967 .36252 .5831 .36836 .58374 .36471 .5803 Mtetra
.412 .659 .961 r
.36471 .5803 .36836 .58374 .37422 .58424 .37058 .58079 Mtetra
.431 .668 .961 r
.37058 .58079 .37422 .58424 .38011 .58462 .37647 .58115 Mtetra
.449 .675 .961 r
.37647 .58115 .38011 .58462 .38602 .58487 .38239 .58139 Mtetra
.464 .682 .96 r
.38239 .58139 .38602 .58487 .39196 .585 .38834 .58151 Mtetra
.479 .688 .959 r
.38834 .58151 .39196 .585 .39793 .58502 .39431 .58151 Mtetra
.493 .694 .958 r
.39431 .58151 .39793 .58502 .40392 .58492 .40031 .5814 Mtetra
.506 .698 .956 r
.40031 .5814 .40392 .58492 .40993 .58471 .40632 .58118 Mtetra
.517 .703 .955 r
.40632 .58118 .40993 .58471 .41596 .5844 .41237 .58086 Mtetra
.528 .707 .953 r
.41237 .58086 .41596 .5844 .42202 .58399 .41843 .58044 Mtetra
.538 .711 .951 r
.41843 .58044 .42202 .58399 .4281 .58348 .42452 .57991 Mtetra
.548 .714 .949 r
.42452 .57991 .4281 .58348 .4342 .58288 .43062 .5793 Mtetra
.556 .717 .948 r
.43062 .5793 .4342 .58288 .44032 .58219 .43675 .57859 Mtetra
.564 .72 .946 r
.43675 .57859 .44032 .58219 .44646 .58141 .4429 .5778 Mtetra
.572 .722 .944 r
.4429 .5778 .44646 .58141 .45262 .58054 .44907 .57692 Mtetra
.579 .725 .943 r
.44907 .57692 .45262 .58054 .4588 .5796 .45525 .57597 Mtetra
.585 .727 .941 r
.45525 .57597 .4588 .5796 .465 .57858 .46146 .57493 Mtetra
.592 .729 .939 r
.46146 .57493 .465 .57858 .47121 .57748 .46769 .57382 Mtetra
.597 .731 .938 r
.46769 .57382 .47121 .57748 .47745 .57631 .47393 .57264 Mtetra
.603 .732 .936 r
.47393 .57264 .47745 .57631 .4837 .57507 .48019 .57139 Mtetra
.608 .734 .934 r
.48019 .57139 .4837 .57507 .48997 .57377 .48647 .57008 Mtetra
.613 .735 .933 r
.48647 .57008 .48997 .57377 .49626 .5724 .49276 .56869 Mtetra
.617 .737 .932 r
.49276 .56869 .49626 .5724 .50256 .57097 .49907 .56725 Mtetra
.621 .738 .93 r
.49907 .56725 .50256 .57097 .50888 .56948 .5054 .56575 Mtetra
.625 .739 .929 r
.5054 .56575 .50888 .56948 .51522 .56793 .51175 .56419 Mtetra
.629 .74 .928 r
.51175 .56419 .51522 .56793 .52157 .56633 .51811 .56257 Mtetra
.633 .741 .926 r
.51811 .56257 .52157 .56633 .52794 .56467 .52449 .5609 Mtetra
.636 .742 .925 r
.52449 .5609 .52794 .56467 .53432 .56296 .53088 .55918 Mtetra
.639 .743 .924 r
.53088 .55918 .53432 .56296 .54072 .5612 .53729 .55741 Mtetra
.642 .744 .923 r
.53729 .55741 .54072 .5612 .54714 .55939 .54371 .55559 Mtetra
.645 .745 .922 r
.54371 .55559 .54714 .55939 .55357 .55753 .55015 .55372 Mtetra
.648 .746 .921 r
.55015 .55372 .55357 .55753 .56001 .55563 .55661 .55181 Mtetra
.65 .747 .92 r
.55661 .55181 .56001 .55563 .56647 .55368 .56307 .54985 Mtetra
.653 .747 .919 r
.56307 .54985 .56647 .55368 .57295 .55169 .56956 .54785 Mtetra
.655 .748 .918 r
.56956 .54785 .57295 .55169 .57943 .54965 .57606 .5458 Mtetra
.658 .749 .917 r
.57606 .5458 .57943 .54965 .58594 .54757 .58257 .54371 Mtetra
.66 .749 .916 r
.58257 .54371 .58594 .54757 .59245 .54545 .58909 .54158 Mtetra
.662 .75 .915 r
.58909 .54158 .59245 .54545 .59898 .54329 .59563 .53941 Mtetra
.664 .751 .915 r
.59563 .53941 .59898 .54329 .60553 .54109 .60219 .5372 Mtetra
.667 .751 .914 r
.60219 .5372 .60553 .54109 .61208 .53885 .60875 .53495 Mtetra
.669 .752 .913 r
.60875 .53495 .61208 .53885 .61865 .53657 .61534 .53266 Mtetra
.671 .753 .912 r
.61534 .53266 .61865 .53657 .62524 .53424 .62193 .53033 Mtetra
.673 .754 .911 r
.62193 .53033 .62524 .53424 .63183 .53188 .62854 .52795 Mtetra
.675 .754 .911 r
.62854 .52795 .63183 .53188 .63844 .52948 .63516 .52554 Mtetra
.677 .755 .91 r
.63516 .52554 .63844 .52948 .64507 .52703 .64179 .52309 Mtetra
.679 .756 .909 r
.64179 .52309 .64507 .52703 .6517 .52454 .64844 .52059 Mtetra
.681 .756 .908 r
.64844 .52059 .6517 .52454 .65835 .52201 .6551 .51805 Mtetra
.683 .757 .907 r
.6551 .51805 .65835 .52201 .66501 .51944 .66177 .51547 Mtetra
.685 .758 .907 r
.66177 .51547 .66501 .51944 .67168 .51683 .66845 .51285 Mtetra
.687 .759 .906 r
.66845 .51285 .67168 .51683 .67836 .51416 .67514 .51018 Mtetra
.69 .76 .905 r
.67514 .51018 .67836 .51416 .68506 .51146 .68185 .50746 Mtetra
.692 .76 .904 r
.68185 .50746 .68506 .51146 .69176 .5087 .68856 .5047 Mtetra
.694 .761 .903 r
.68856 .5047 .69176 .5087 .69848 .5059 .69529 .50189 Mtetra
.697 .762 .902 r
.69529 .50189 .69848 .5059 .70521 .50304 .70203 .49902 Mtetra
.699 .763 .901 r
.70203 .49902 .70521 .50304 .71194 .50013 .70878 .49611 Mtetra
.702 .764 .9 r
.70878 .49611 .71194 .50013 .71869 .49717 .71554 .49314 Mtetra
.704 .765 .899 r
.71554 .49314 .71869 .49717 .72545 .49415 .7223 .49011 Mtetra
.707 .766 .898 r
.7223 .49011 .72545 .49415 .73221 .49106 .72908 .48702 Mtetra
.71 .767 .897 r
.72908 .48702 .73221 .49106 .73898 .48792 .73587 .48387 Mtetra
.713 .769 .896 r
.73587 .48387 .73898 .48792 .74577 .48471 .74266 .48065 Mtetra
.716 .77 .895 r
.74266 .48065 .74577 .48471 .75255 .48144 .74946 .47737 Mtetra
.719 .771 .894 r
.74946 .47737 .75255 .48144 .75935 .47809 .75627 .47402 Mtetra
.722 .772 .892 r
.75627 .47402 .75935 .47809 .76615 .47467 .76308 .47059 Mtetra
.726 .774 .891 r
.76308 .47059 .76615 .47467 .77296 .47117 .7699 .46709 Mtetra
.729 .775 .889 r
.7699 .46709 .77296 .47117 .77977 .46759 .77673 .4635 Mtetra
.733 .777 .888 r
.77673 .4635 .77977 .46759 .78658 .46392 .78355 .45983 Mtetra
.737 .778 .886 r
.78355 .45983 .78658 .46392 .7934 .46017 .79039 .45607 Mtetra
.741 .78 .884 r
.79039 .45607 .7934 .46017 .80022 .45632 .79722 .45222 Mtetra
.745 .781 .882 r
.79722 .45222 .80022 .45632 .80704 .45237 .80406 .44826 Mtetra
.749 .783 .88 r
.80406 .44826 .80704 .45237 .81387 .44832 .81089 .44421 Mtetra
.753 .784 .878 r
.81089 .44421 .81387 .44832 .82069 .44417 .81773 .44005 Mtetra
.758 .786 .876 r
.81773 .44005 .82069 .44417 .82751 .4399 .82456 .43577 Mtetra
.763 .788 .874 r
.82456 .43577 .82751 .4399 .83432 .43551 .83139 .43138 Mtetra
.767 .79 .871 r
.83139 .43138 .83432 .43551 .84114 .43099 .83822 .42686 Mtetra
.772 .792 .869 r
.83822 .42686 .84114 .43099 .84794 .42635 .84504 .42221 Mtetra
.777 .793 .866 r
.84504 .42221 .84794 .42635 .85474 .42157 .85185 .41743 Mtetra
.783 .795 .863 r
.85185 .41743 .85474 .42157 .86153 .41664 .85866 .4125 Mtetra
.788 .797 .86 r
.85866 .4125 .86153 .41664 .86831 .41157 .86545 .40743 Mtetra
.794 .799 .857 r
.86545 .40743 .86831 .41157 .87508 .40634 .87223 .40219 Mtetra
0 .067 .541 r
.24562 .52845 .24935 .53165 .25443 .53598 .2507 .53277 Mtetra
0 .114 .59 r
.2507 .53277 .25443 .53598 .25955 .54008 .25582 .53686 Mtetra
0 .161 .637 r
.25582 .53686 .25955 .54008 .26472 .54395 .26099 .54072 Mtetra
0 .207 .681 r
.26099 .54072 .26472 .54395 .26994 .5476 .26621 .54435 Mtetra
0 .252 .722 r
.26621 .54435 .26994 .5476 .27521 .55102 .27148 .54777 Mtetra
0 .295 .759 r
.27148 .54777 .27521 .55102 .28052 .55423 .27679 .55097 Mtetra
0 .336 .792 r
.27679 .55097 .28052 .55423 .28587 .55723 .28215 .55396 Mtetra
0 .374 .822 r
.28215 .55396 .28587 .55723 .29127 .56003 .28755 .55675 Mtetra
0 .41 .848 r
.28755 .55675 .29127 .56003 .2967 .56263 .29299 .55934 Mtetra
.026 .443 .871 r
.29299 .55934 .2967 .56263 .30218 .56504 .29846 .56173 Mtetra
.072 .473 .89 r
.29846 .56173 .30218 .56504 .30769 .56726 .30398 .56394 Mtetra
.116 .5 .906 r
.30398 .56394 .30769 .56726 .31324 .5693 .30954 .56597 Mtetra
.156 .525 .919 r
.30954 .56597 .31324 .5693 .31883 .57117 .31513 .56782 Mtetra
.194 .547 .93 r
.31513 .56782 .31883 .57117 .32445 .57286 .32075 .5695 Mtetra
.23 .567 .939 r
.32075 .5695 .32445 .57286 .33011 .57438 .32641 .57101 Mtetra
.263 .585 .946 r
.32641 .57101 .33011 .57438 .3358 .57574 .33211 .57236 Mtetra
.293 .601 .951 r
.33211 .57236 .3358 .57574 .34152 .57695 .33783 .57356 Mtetra
.321 .616 .955 r
.33783 .57356 .34152 .57695 .34727 .578 .34359 .5746 Mtetra
.347 .629 .958 r
.34359 .5746 .34727 .578 .35305 .57891 .34938 .57549 Mtetra
.37 .641 .96 r
.34938 .57549 .35305 .57891 .35887 .57967 .3552 .57625 Mtetra
.392 .651 .961 r
.3552 .57625 .35887 .57967 .36471 .5803 .36104 .57686 Mtetra
.413 .66 .962 r
.36104 .57686 .36471 .5803 .37058 .58079 .36692 .57734 Mtetra
.431 .669 .962 r
.36692 .57734 .37058 .58079 .37647 .58115 .37282 .57769 Mtetra
.448 .676 .961 r
.37282 .57769 .37647 .58115 .38239 .58139 .37874 .57792 Mtetra
.464 .683 .961 r
.37874 .57792 .38239 .58139 .38834 .58151 .3847 .57803 Mtetra
.479 .689 .96 r
.3847 .57803 .38834 .58151 .39431 .58151 .39068 .57802 Mtetra
.493 .695 .958 r
.39068 .57802 .39431 .58151 .40031 .5814 .39668 .57789 Mtetra
.505 .7 .957 r
.39668 .57789 .40031 .5814 .40632 .58118 .4027 .57766 Mtetra
.517 .704 .956 r
.4027 .57766 .40632 .58118 .41237 .58086 .40875 .57733 Mtetra
.528 .708 .954 r
.40875 .57733 .41237 .58086 .41843 .58044 .41482 .57689 Mtetra
.538 .712 .952 r
.41482 .57689 .41843 .58044 .42452 .57991 .42092 .57636 Mtetra
.547 .716 .951 r
.42092 .57636 .42452 .57991 .43062 .5793 .42703 .57573 Mtetra
.556 .719 .949 r
.42703 .57573 .43062 .5793 .43675 .57859 .43317 .57501 Mtetra
.564 .722 .947 r
.43317 .57501 .43675 .57859 .4429 .5778 .43932 .57421 Mtetra
.572 .724 .946 r
.43932 .57421 .4429 .5778 .44907 .57692 .4455 .57332 Mtetra
.579 .727 .944 r
.4455 .57332 .44907 .57692 .45525 .57597 .45169 .57235 Mtetra
.585 .729 .942 r
.45169 .57235 .45525 .57597 .46146 .57493 .45791 .57131 Mtetra
.591 .731 .941 r
.45791 .57131 .46146 .57493 .46769 .57382 .46414 .57019 Mtetra
.597 .733 .939 r
.46414 .57019 .46769 .57382 .47393 .57264 .47039 .569 Mtetra
.603 .734 .938 r
.47039 .569 .47393 .57264 .48019 .57139 .47666 .56773 Mtetra
.608 .736 .936 r
.47666 .56773 .48019 .57139 .48647 .57008 .48295 .56641 Mtetra
.612 .738 .935 r
.48295 .56641 .48647 .57008 .49276 .56869 .48925 .56501 Mtetra
.617 .739 .933 r
.48925 .56501 .49276 .56869 .49907 .56725 .49557 .56356 Mtetra
.621 .74 .932 r
.49557 .56356 .49907 .56725 .5054 .56575 .50191 .56205 Mtetra
.625 .742 .931 r
.50191 .56205 .5054 .56575 .51175 .56419 .50826 .56048 Mtetra
.629 .743 .929 r
.50826 .56048 .51175 .56419 .51811 .56257 .51463 .55885 Mtetra
.632 .744 .928 r
.51463 .55885 .51811 .56257 .52449 .5609 .52102 .55717 Mtetra
.636 .745 .927 r
.52102 .55717 .52449 .5609 .53088 .55918 .52742 .55544 Mtetra
.639 .746 .926 r
.52742 .55544 .53088 .55918 .53729 .55741 .53384 .55366 Mtetra
.642 .747 .925 r
.53384 .55366 .53729 .55741 .54371 .55559 .54027 .55182 Mtetra
.645 .747 .924 r
.54027 .55182 .54371 .55559 .55015 .55372 .54672 .54995 Mtetra
.648 .748 .923 r
.54672 .54995 .55015 .55372 .55661 .55181 .55319 .54802 Mtetra
.65 .749 .922 r
.55319 .54802 .55661 .55181 .56307 .54985 .55966 .54605 Mtetra
.653 .75 .921 r
.55966 .54605 .56307 .54985 .56956 .54785 .56616 .54404 Mtetra
.655 .751 .92 r
.56616 .54404 .56956 .54785 .57606 .5458 .57266 .54198 Mtetra
.658 .751 .919 r
.57266 .54198 .57606 .5458 .58257 .54371 .57919 .53989 Mtetra
.66 .752 .918 r
.57919 .53989 .58257 .54371 .58909 .54158 .58572 .53775 Mtetra
.662 .753 .917 r
.58572 .53775 .58909 .54158 .59563 .53941 .59227 .53557 Mtetra
.664 .753 .917 r
.59227 .53557 .59563 .53941 .60219 .5372 .59884 .53335 Mtetra
.667 .754 .916 r
.59884 .53335 .60219 .5372 .60875 .53495 .60541 .53108 Mtetra
.669 .755 .915 r
.60541 .53108 .60875 .53495 .61534 .53266 .61201 .52878 Mtetra
.671 .756 .914 r
.61201 .52878 .61534 .53266 .62193 .53033 .61861 .52644 Mtetra
.673 .756 .913 r
.61861 .52644 .62193 .53033 .62854 .52795 .62523 .52406 Mtetra
.675 .757 .913 r
.62523 .52406 .62854 .52795 .63516 .52554 .63186 .52164 Mtetra
.677 .758 .912 r
.63186 .52164 .63516 .52554 .64179 .52309 .6385 .51917 Mtetra
.679 .758 .911 r
.6385 .51917 .64179 .52309 .64844 .52059 .64516 .51667 Mtetra
.681 .759 .91 r
.64516 .51667 .64844 .52059 .6551 .51805 .65183 .51412 Mtetra
.683 .76 .909 r
.65183 .51412 .6551 .51805 .66177 .51547 .65851 .51153 Mtetra
.685 .761 .909 r
.65851 .51153 .66177 .51547 .66845 .51285 .6652 .5089 Mtetra
.688 .761 .908 r
.6652 .5089 .66845 .51285 .67514 .51018 .67191 .50622 Mtetra
.69 .762 .907 r
.67191 .50622 .67514 .51018 .68185 .50746 .67863 .5035 Mtetra
.692 .763 .906 r
.67863 .5035 .68185 .50746 .68856 .5047 .68535 .50073 Mtetra
.694 .764 .905 r
.68535 .50073 .68856 .5047 .69529 .50189 .69209 .49791 Mtetra
.697 .765 .904 r
.69209 .49791 .69529 .50189 .70203 .49902 .69884 .49504 Mtetra
.699 .766 .903 r
.69884 .49504 .70203 .49902 .70878 .49611 .7056 .49211 Mtetra
.702 .767 .902 r
.7056 .49211 .70878 .49611 .71554 .49314 .71237 .48913 Mtetra
.705 .768 .901 r
.71237 .48913 .71554 .49314 .7223 .49011 .71915 .4861 Mtetra
.707 .769 .9 r
.71915 .4861 .7223 .49011 .72908 .48702 .72594 .483 Mtetra
.71 .77 .899 r
.72594 .483 .72908 .48702 .73587 .48387 .73274 .47984 Mtetra
.713 .771 .898 r
.73274 .47984 .73587 .48387 .74266 .48065 .73954 .47662 Mtetra
.716 .772 .897 r
.73954 .47662 .74266 .48065 .74946 .47737 .74636 .47333 Mtetra
.719 .773 .895 r
.74636 .47333 .74946 .47737 .75627 .47402 .75318 .46997 Mtetra
.723 .775 .894 r
.75318 .46997 .75627 .47402 .76308 .47059 .76 .46654 Mtetra
.726 .776 .892 r
.76 .46654 .76308 .47059 .7699 .46709 .76684 .46302 Mtetra
.73 .777 .891 r
.76684 .46302 .7699 .46709 .77673 .4635 .77367 .45943 Mtetra
.733 .779 .889 r
.77367 .45943 .77673 .4635 .78355 .45983 .78051 .45575 Mtetra
.737 .78 .887 r
.78051 .45575 .78355 .45983 .79039 .45607 .78736 .45199 Mtetra
.741 .781 .886 r
.78736 .45199 .79039 .45607 .79722 .45222 .79421 .44813 Mtetra
.745 .783 .884 r
.79421 .44813 .79722 .45222 .80406 .44826 .80106 .44417 Mtetra
.749 .785 .882 r
.80106 .44417 .80406 .44826 .81089 .44421 .8079 .44011 Mtetra
.754 .786 .88 r
.8079 .44011 .81089 .44421 .81773 .44005 .81475 .43594 Mtetra
.758 .788 .877 r
.81475 .43594 .81773 .44005 .82456 .43577 .8216 .43166 Mtetra
.763 .789 .875 r
.8216 .43166 .82456 .43577 .83139 .43138 .82845 .42726 Mtetra
.768 .791 .872 r
.82845 .42726 .83139 .43138 .83822 .42686 .83529 .42274 Mtetra
.772 .793 .87 r
.83529 .42274 .83822 .42686 .84504 .42221 .84212 .41808 Mtetra
.778 .795 .867 r
.84212 .41808 .84504 .42221 .85185 .41743 .84895 .41329 Mtetra
.783 .796 .864 r
.84895 .41329 .85185 .41743 .85866 .4125 .85577 .40836 Mtetra
.788 .798 .861 r
.85577 .40836 .85866 .4125 .86545 .40743 .86258 .40328 Mtetra
.794 .8 .857 r
.86258 .40328 .86545 .40743 .87223 .40219 .86938 .39804 Mtetra
0 .071 .548 r
.24188 .52521 .24562 .52845 .2507 .53277 .24695 .52952 Mtetra
0 .118 .596 r
.24695 .52952 .2507 .53277 .25582 .53686 .25208 .5336 Mtetra
0 .165 .642 r
.25208 .5336 .25582 .53686 .26099 .54072 .25725 .53745 Mtetra
0 .211 .685 r
.25725 .53745 .26099 .54072 .26621 .54435 .26247 .54108 Mtetra
0 .255 .725 r
.26247 .54108 .26621 .54435 .27148 .54777 .26774 .54448 Mtetra
0 .298 .762 r
.26774 .54448 .27148 .54777 .27679 .55097 .27306 .54767 Mtetra
0 .339 .795 r
.27306 .54767 .27679 .55097 .28215 .55396 .27841 .55065 Mtetra
0 .376 .824 r
.27841 .55065 .28215 .55396 .28755 .55675 .28381 .55343 Mtetra
0 .412 .85 r
.28381 .55343 .28755 .55675 .29299 .55934 .28925 .55601 Mtetra
.029 .444 .872 r
.28925 .55601 .29299 .55934 .29846 .56173 .29474 .5584 Mtetra
.075 .474 .891 r
.29474 .5584 .29846 .56173 .30398 .56394 .30026 .5606 Mtetra
.118 .501 .906 r
.30026 .5606 .30398 .56394 .30954 .56597 .30581 .56262 Mtetra
.158 .526 .919 r
.30581 .56262 .30954 .56597 .31513 .56782 .31141 .56446 Mtetra
.196 .548 .93 r
.31141 .56446 .31513 .56782 .32075 .5695 .31704 .56613 Mtetra
.231 .568 .939 r
.31704 .56613 .32075 .5695 .32641 .57101 .3227 .56763 Mtetra
.263 .586 .946 r
.3227 .56763 .32641 .57101 .33211 .57236 .3284 .56897 Mtetra
.293 .602 .951 r
.3284 .56897 .33211 .57236 .33783 .57356 .33413 .57016 Mtetra
.321 .617 .955 r
.33413 .57016 .33783 .57356 .34359 .5746 .33989 .57119 Mtetra
.347 .63 .958 r
.33989 .57119 .34359 .5746 .34938 .57549 .34569 .57207 Mtetra
.37 .641 .96 r
.34569 .57207 .34938 .57549 .3552 .57625 .35151 .57282 Mtetra
.392 .652 .961 r
.35151 .57282 .3552 .57625 .36104 .57686 .35736 .57342 Mtetra
.412 .661 .962 r
.35736 .57342 .36104 .57686 .36692 .57734 .36324 .57389 Mtetra
.431 .67 .962 r
.36324 .57389 .36692 .57734 .37282 .57769 .36915 .57423 Mtetra
.448 .677 .962 r
.36915 .57423 .37282 .57769 .37874 .57792 .37508 .57445 Mtetra
.464 .684 .961 r
.37508 .57445 .37874 .57792 .3847 .57803 .38104 .57454 Mtetra
.479 .69 .96 r
.38104 .57454 .3847 .57803 .39068 .57802 .38703 .57452 Mtetra
.492 .696 .959 r
.38703 .57452 .39068 .57802 .39668 .57789 .39304 .57439 Mtetra
.505 .701 .958 r
.39304 .57439 .39668 .57789 .4027 .57766 .39907 .57415 Mtetra
.516 .706 .957 r
.39907 .57415 .4027 .57766 .40875 .57733 .40512 .5738 Mtetra
.527 .71 .955 r
.40512 .5738 .40875 .57733 .41482 .57689 .4112 .57336 Mtetra
.537 .714 .953 r
.4112 .57336 .41482 .57689 .42092 .57636 .4173 .57281 Mtetra
.547 .717 .952 r
.4173 .57281 .42092 .57636 .42703 .57573 .42342 .57218 Mtetra
.555 .72 .95 r
.42342 .57218 .42703 .57573 .43317 .57501 .42957 .57145 Mtetra
.564 .723 .949 r
.42957 .57145 .43317 .57501 .43932 .57421 .43573 .57063 Mtetra
.571 .726 .947 r
.43573 .57063 .43932 .57421 .4455 .57332 .44191 .56974 Mtetra
.578 .729 .945 r
.44191 .56974 .4455 .57332 .45169 .57235 .44812 .56876 Mtetra
.585 .731 .944 r
.44812 .56876 .45169 .57235 .45791 .57131 .45434 .5677 Mtetra
.591 .733 .942 r
.45434 .5677 .45791 .57131 .46414 .57019 .46058 .56657 Mtetra
.597 .735 .941 r
.46058 .56657 .46414 .57019 .47039 .569 .46684 .56537 Mtetra
.602 .737 .939 r
.46684 .56537 .47039 .569 .47666 .56773 .47312 .5641 Mtetra
.607 .738 .938 r
.47312 .5641 .47666 .56773 .48295 .56641 .47941 .56276 Mtetra
.612 .74 .936 r
.47941 .56276 .48295 .56641 .48925 .56501 .48572 .56136 Mtetra
.617 .741 .935 r
.48572 .56136 .48925 .56501 .49557 .56356 .49205 .55989 Mtetra
.621 .743 .934 r
.49205 .55989 .49557 .56356 .50191 .56205 .4984 .55837 Mtetra
.625 .744 .932 r
.4984 .55837 .50191 .56205 .50826 .56048 .50476 .55679 Mtetra
.629 .745 .931 r
.50476 .55679 .50826 .56048 .51463 .55885 .51114 .55515 Mtetra
.632 .746 .93 r
.51114 .55515 .51463 .55885 .52102 .55717 .51754 .55346 Mtetra
.636 .747 .929 r
.51754 .55346 .52102 .55717 .52742 .55544 .52395 .55172 Mtetra
.639 .748 .928 r
.52395 .55172 .52742 .55544 .53384 .55366 .53038 .54993 Mtetra
.642 .749 .927 r
.53038 .54993 .53384 .55366 .54027 .55182 .53682 .54809 Mtetra
.645 .75 .926 r
.53682 .54809 .54027 .55182 .54672 .54995 .54328 .5462 Mtetra
.648 .751 .925 r
.54328 .5462 .54672 .54995 .55319 .54802 .54975 .54427 Mtetra
.65 .752 .924 r
.54975 .54427 .55319 .54802 .55966 .54605 .55624 .54229 Mtetra
.653 .753 .923 r
.55624 .54229 .55966 .54605 .56616 .54404 .56274 .54026 Mtetra
.655 .753 .922 r
.56274 .54026 .56616 .54404 .57266 .54198 .56926 .5382 Mtetra
.658 .754 .921 r
.56926 .5382 .57266 .54198 .57919 .53989 .57579 .53609 Mtetra
.66 .755 .92 r
.57579 .53609 .57919 .53989 .58572 .53775 .58234 .53394 Mtetra
.662 .756 .919 r
.58234 .53394 .58572 .53775 .59227 .53557 .5889 .53175 Mtetra
.664 .756 .919 r
.5889 .53175 .59227 .53557 .59884 .53335 .59547 .52952 Mtetra
.667 .757 .918 r
.59547 .52952 .59884 .53335 .60541 .53108 .60206 .52725 Mtetra
.669 .758 .917 r
.60206 .52725 .60541 .53108 .61201 .52878 .60866 .52494 Mtetra
.671 .758 .916 r
.60866 .52494 .61201 .52878 .61861 .52644 .61528 .52259 Mtetra
.673 .759 .915 r
.61528 .52259 .61861 .52644 .62523 .52406 .62191 .5202 Mtetra
.675 .76 .915 r
.62191 .5202 .62523 .52406 .63186 .52164 .62855 .51777 Mtetra
.677 .76 .914 r
.62855 .51777 .63186 .52164 .6385 .51917 .6352 .51529 Mtetra
.679 .761 .913 r
.6352 .51529 .6385 .51917 .64516 .51667 .64187 .51278 Mtetra
.681 .762 .912 r
.64187 .51278 .64516 .51667 .65183 .51412 .64855 .51023 Mtetra
.683 .763 .911 r
.64855 .51023 .65183 .51412 .65851 .51153 .65524 .50763 Mtetra
.685 .763 .911 r
.65524 .50763 .65851 .51153 .6652 .5089 .66195 .50499 Mtetra
.688 .764 .91 r
.66195 .50499 .6652 .5089 .67191 .50622 .66866 .5023 Mtetra
.69 .765 .909 r
.66866 .5023 .67191 .50622 .67863 .5035 .67539 .49957 Mtetra
.692 .766 .908 r
.67539 .49957 .67863 .5035 .68535 .50073 .68213 .49679 Mtetra
.695 .767 .907 r
.68213 .49679 .68535 .50073 .69209 .49791 .68888 .49396 Mtetra
.697 .767 .906 r
.68888 .49396 .69209 .49791 .69884 .49504 .69564 .49108 Mtetra
.699 .768 .905 r
.69564 .49108 .69884 .49504 .7056 .49211 .70242 .48814 Mtetra
.702 .769 .904 r
.70242 .48814 .7056 .49211 .71237 .48913 .7092 .48516 Mtetra
.705 .77 .903 r
.7092 .48516 .71237 .48913 .71915 .4861 .71599 .48211 Mtetra
.707 .771 .902 r
.71599 .48211 .71915 .4861 .72594 .483 .72279 .47901 Mtetra
.71 .772 .901 r
.72279 .47901 .72594 .483 .73274 .47984 .7296 .47584 Mtetra
.713 .773 .899 r
.7296 .47584 .73274 .47984 .73954 .47662 .73642 .47261 Mtetra
.716 .774 .898 r
.73642 .47261 .73954 .47662 .74636 .47333 .74324 .46931 Mtetra
.72 .776 .897 r
.74324 .46931 .74636 .47333 .75318 .46997 .75008 .46594 Mtetra
.723 .777 .895 r
.75008 .46594 .75318 .46997 .76 .46654 .75691 .4625 Mtetra
.726 .778 .894 r
.75691 .4625 .76 .46654 .76684 .46302 .76376 .45898 Mtetra
.73 .779 .892 r
.76376 .45898 .76684 .46302 .77367 .45943 .77061 .45538 Mtetra
.733 .781 .891 r
.77061 .45538 .77367 .45943 .78051 .45575 .77746 .4517 Mtetra
.737 .782 .889 r
.77746 .4517 .78051 .45575 .78736 .45199 .78432 .44792 Mtetra
.741 .783 .887 r
.78432 .44792 .78736 .45199 .79421 .44813 .79118 .44405 Mtetra
.745 .785 .885 r
.79118 .44405 .79421 .44813 .80106 .44417 .79805 .44009 Mtetra
.749 .786 .883 r
.79805 .44009 .80106 .44417 .8079 .44011 .80491 .43602 Mtetra
.754 .788 .881 r
.80491 .43602 .8079 .44011 .81475 .43594 .81177 .43184 Mtetra
.758 .789 .878 r
.81177 .43184 .81475 .43594 .8216 .43166 .81863 .42756 Mtetra
.763 .791 .876 r
.81863 .42756 .8216 .43166 .82845 .42726 .82549 .42315 Mtetra
.768 .793 .873 r
.82549 .42315 .82845 .42726 .83529 .42274 .83235 .41862 Mtetra
.773 .794 .871 r
.83235 .41862 .83529 .42274 .84212 .41808 .83919 .41396 Mtetra
.778 .796 .868 r
.83919 .41396 .84212 .41808 .84895 .41329 .84604 .40916 Mtetra
.783 .798 .865 r
.84604 .40916 .84895 .41329 .85577 .40836 .85287 .40422 Mtetra
.788 .799 .861 r
.85287 .40422 .85577 .40836 .86258 .40328 .8597 .39913 Mtetra
.794 .801 .858 r
.8597 .39913 .86258 .40328 .86938 .39804 .86651 .39389 Mtetra
0 .075 .554 r
.23813 .52192 .24188 .52521 .24695 .52952 .2432 .52623 Mtetra
0 .122 .601 r
.2432 .52623 .24695 .52952 .25208 .5336 .24832 .53031 Mtetra
0 .168 .647 r
.24832 .53031 .25208 .5336 .25725 .53745 .2535 .53415 Mtetra
0 .214 .689 r
.2535 .53415 .25725 .53745 .26247 .54108 .25872 .53777 Mtetra
0 .258 .729 r
.25872 .53777 .26247 .54108 .26774 .54448 .26399 .54116 Mtetra
0 .3 .765 r
.26399 .54116 .26774 .54448 .27306 .54767 .2693 .54435 Mtetra
0 .341 .797 r
.2693 .54435 .27306 .54767 .27841 .55065 .27466 .54732 Mtetra
0 .378 .826 r
.27466 .54732 .27841 .55065 .28381 .55343 .28006 .55009 Mtetra
0 .413 .851 r
.28006 .55009 .28381 .55343 .28925 .55601 .28551 .55267 Mtetra
.031 .445 .873 r
.28551 .55267 .28925 .55601 .29474 .5584 .29099 .55505 Mtetra
.077 .475 .891 r
.29099 .55505 .29474 .5584 .30026 .5606 .29652 .55724 Mtetra
.119 .502 .907 r
.29652 .55724 .30026 .5606 .30581 .56262 .30208 .55925 Mtetra
.159 .526 .92 r
.30208 .55925 .30581 .56262 .31141 .56446 .30768 .56108 Mtetra
.197 .548 .93 r
.30768 .56108 .31141 .56446 .31704 .56613 .31331 .56275 Mtetra
.232 .568 .939 r
.31331 .56275 .31704 .56613 .3227 .56763 .31898 .56424 Mtetra
.264 .586 .946 r
.31898 .56424 .3227 .56763 .3284 .56897 .32468 .56557 Mtetra
.294 .602 .951 r
.32468 .56557 .3284 .56897 .33413 .57016 .33042 .56675 Mtetra
.321 .617 .955 r
.33042 .56675 .33413 .57016 .33989 .57119 .33618 .56777 Mtetra
.347 .63 .958 r
.33618 .56777 .33989 .57119 .34569 .57207 .34198 .56865 Mtetra
.37 .642 .96 r
.34198 .56865 .34569 .57207 .35151 .57282 .34781 .56938 Mtetra
.392 .652 .962 r
.34781 .56938 .35151 .57282 .35736 .57342 .35367 .56998 Mtetra
.412 .662 .963 r
.35367 .56998 .35736 .57342 .36324 .57389 .35955 .57044 Mtetra
.43 .67 .963 r
.35955 .57044 .36324 .57389 .36915 .57423 .36546 .57077 Mtetra
.447 .678 .963 r
.36546 .57077 .36915 .57423 .37508 .57445 .3714 .57098 Mtetra
.463 .685 .962 r
.3714 .57098 .37508 .57445 .38104 .57454 .37737 .57107 Mtetra
.478 .691 .961 r
.37737 .57107 .38104 .57454 .38703 .57452 .38336 .57104 Mtetra
.492 .697 .96 r
.38336 .57104 .38703 .57452 .39304 .57439 .38938 .5709 Mtetra
.504 .702 .959 r
.38938 .5709 .39304 .57439 .39907 .57415 .39542 .57065 Mtetra
.516 .707 .958 r
.39542 .57065 .39907 .57415 .40512 .5738 .40148 .57029 Mtetra
.527 .711 .956 r
.40148 .57029 .40512 .5738 .4112 .57336 .40756 .56984 Mtetra
.537 .715 .955 r
.40756 .56984 .4112 .57336 .4173 .57281 .41367 .56928 Mtetra
.546 .719 .953 r
.41367 .56928 .4173 .57281 .42342 .57218 .4198 .56864 Mtetra
.555 .722 .952 r
.4198 .56864 .42342 .57218 .42957 .57145 .42595 .5679 Mtetra
.563 .725 .95 r
.42595 .5679 .42957 .57145 .43573 .57063 .43212 .56708 Mtetra
.571 .728 .948 r
.43212 .56708 .43573 .57063 .44191 .56974 .43831 .56617 Mtetra
.578 .73 .947 r
.43831 .56617 .44191 .56974 .44812 .56876 .44452 .56518 Mtetra
.584 .733 .945 r
.44452 .56518 .44812 .56876 .45434 .5677 .45075 .56412 Mtetra
.591 .735 .944 r
.45075 .56412 .45434 .5677 .46058 .56657 .457 .56298 Mtetra
.596 .737 .942 r
.457 .56298 .46058 .56657 .46684 .56537 .46327 .56177 Mtetra
.602 .739 .941 r
.46327 .56177 .46684 .56537 .47312 .5641 .46956 .56048 Mtetra
.607 .74 .939 r
.46956 .56048 .47312 .5641 .47941 .56276 .47586 .55914 Mtetra
.612 .742 .938 r
.47586 .55914 .47941 .56276 .48572 .56136 .48218 .55773 Mtetra
.616 .744 .937 r
.48218 .55773 .48572 .56136 .49205 .55989 .48852 .55625 Mtetra
.621 .745 .936 r
.48852 .55625 .49205 .55989 .4984 .55837 .49488 .55472 Mtetra
.625 .746 .934 r
.49488 .55472 .4984 .55837 .50476 .55679 .50125 .55313 Mtetra
.628 .748 .933 r
.50125 .55313 .50476 .55679 .51114 .55515 .50764 .55148 Mtetra
.632 .749 .932 r
.50764 .55148 .51114 .55515 .51754 .55346 .51404 .54978 Mtetra
.635 .75 .931 r
.51404 .54978 .51754 .55346 .52395 .55172 .52046 .54803 Mtetra
.639 .751 .93 r
.52046 .54803 .52395 .55172 .53038 .54993 .5269 .54623 Mtetra
.642 .752 .929 r
.5269 .54623 .53038 .54993 .53682 .54809 .53335 .54438 Mtetra
.645 .753 .928 r
.53335 .54438 .53682 .54809 .54328 .5462 .53982 .54248 Mtetra
.647 .754 .927 r
.53982 .54248 .54328 .5462 .54975 .54427 .5463 .54054 Mtetra
.65 .754 .926 r
.5463 .54054 .54975 .54427 .55624 .54229 .5528 .53855 Mtetra
.653 .755 .925 r
.5528 .53855 .55624 .54229 .56274 .54026 .55931 .53652 Mtetra
.655 .756 .924 r
.55931 .53652 .56274 .54026 .56926 .5382 .56584 .53444 Mtetra
.658 .757 .923 r
.56584 .53444 .56926 .5382 .57579 .53609 .57238 .53233 Mtetra
.66 .758 .922 r
.57238 .53233 .57579 .53609 .58234 .53394 .57894 .53017 Mtetra
.662 .758 .921 r
.57894 .53017 .58234 .53394 .5889 .53175 .58551 .52797 Mtetra
.664 .759 .921 r
.58551 .52797 .5889 .53175 .59547 .52952 .59209 .52573 Mtetra
.667 .76 .92 r
.59209 .52573 .59547 .52952 .60206 .52725 .59869 .52345 Mtetra
.669 .76 .919 r
.59869 .52345 .60206 .52725 .60866 .52494 .60531 .52113 Mtetra
.671 .761 .918 r
.60531 .52113 .60866 .52494 .61528 .52259 .61193 .51877 Mtetra
.673 .762 .917 r
.61193 .51877 .61528 .52259 .62191 .5202 .61857 .51637 Mtetra
.675 .762 .917 r
.61857 .51637 .62191 .5202 .62855 .51777 .62522 .51393 Mtetra
.677 .763 .916 r
.62522 .51393 .62855 .51777 .6352 .51529 .63189 .51145 Mtetra
.679 .764 .915 r
.63189 .51145 .6352 .51529 .64187 .51278 .63857 .50892 Mtetra
.681 .765 .914 r
.63857 .50892 .64187 .51278 .64855 .51023 .64526 .50636 Mtetra
.683 .765 .913 r
.64526 .50636 .64855 .51023 .65524 .50763 .65196 .50375 Mtetra
.686 .766 .913 r
.65196 .50375 .65524 .50763 .66195 .50499 .65868 .5011 Mtetra
.688 .767 .912 r
.65868 .5011 .66195 .50499 .66866 .5023 .66541 .49841 Mtetra
.69 .768 .911 r
.66541 .49841 .66866 .5023 .67539 .49957 .67215 .49566 Mtetra
.692 .768 .91 r
.67215 .49566 .67539 .49957 .68213 .49679 .6789 .49287 Mtetra
.695 .769 .909 r
.6789 .49287 .68213 .49679 .68888 .49396 .68566 .49004 Mtetra
.697 .77 .908 r
.68566 .49004 .68888 .49396 .69564 .49108 .69243 .48715 Mtetra
.7 .771 .907 r
.69243 .48715 .69564 .49108 .70242 .48814 .69922 .4842 Mtetra
.702 .772 .906 r
.69922 .4842 .70242 .48814 .7092 .48516 .70601 .48121 Mtetra
.705 .773 .905 r
.70601 .48121 .7092 .48516 .71599 .48211 .71281 .47815 Mtetra
.708 .774 .904 r
.71281 .47815 .71599 .48211 .72279 .47901 .71963 .47504 Mtetra
.711 .775 .902 r
.71963 .47504 .72279 .47901 .7296 .47584 .72645 .47187 Mtetra
.714 .776 .901 r
.72645 .47187 .7296 .47584 .73642 .47261 .73328 .46863 Mtetra
.717 .777 .9 r
.73328 .46863 .73642 .47261 .74324 .46931 .74012 .46532 Mtetra
.72 .778 .898 r
.74012 .46532 .74324 .46931 .75008 .46594 .74696 .46194 Mtetra
.723 .779 .897 r
.74696 .46194 .75008 .46594 .75691 .4625 .75381 .45849 Mtetra
.727 .78 .895 r
.75381 .45849 .75691 .4625 .76376 .45898 .76067 .45496 Mtetra
.73 .782 .894 r
.76067 .45496 .76376 .45898 .77061 .45538 .76754 .45135 Mtetra
.734 .783 .892 r
.76754 .45135 .77061 .45538 .77746 .4517 .7744 .44766 Mtetra
.738 .784 .89 r
.7744 .44766 .77746 .4517 .78432 .44792 .78127 .44387 Mtetra
.741 .785 .888 r
.78127 .44387 .78432 .44792 .79118 .44405 .78815 .44 Mtetra
.746 .787 .886 r
.78815 .44 .79118 .44405 .79805 .44009 .79502 .43602 Mtetra
.75 .788 .884 r
.79502 .43602 .79805 .44009 .80491 .43602 .8019 .43195 Mtetra
.754 .79 .882 r
.8019 .43195 .80491 .43602 .81177 .43184 .80878 .42776 Mtetra
.759 .791 .879 r
.80878 .42776 .81177 .43184 .81863 .42756 .81565 .42346 Mtetra
.763 .793 .877 r
.81565 .42346 .81863 .42756 .82549 .42315 .82253 .41905 Mtetra
.768 .794 .874 r
.82253 .41905 .82549 .42315 .83235 .41862 .82939 .41451 Mtetra
.773 .796 .871 r
.82939 .41451 .83235 .41862 .83919 .41396 .83626 .40984 Mtetra
.778 .797 .868 r
.83626 .40984 .83919 .41396 .84604 .40916 .84311 .40503 Mtetra
.783 .799 .865 r
.84311 .40503 .84604 .40916 .85287 .40422 .84996 .40008 Mtetra
.789 .8 .862 r
.84996 .40008 .85287 .40422 .8597 .39913 .8568 .39499 Mtetra
.794 .802 .859 r
.8568 .39499 .8597 .39913 .86651 .39389 .86363 .38973 Mtetra
0 .078 .559 r
.23436 .51859 .23813 .52192 .2432 .52623 .23943 .5229 Mtetra
0 .125 .606 r
.23943 .5229 .2432 .52623 .24832 .53031 .24456 .52697 Mtetra
0 .171 .651 r
.24456 .52697 .24832 .53031 .2535 .53415 .24973 .53081 Mtetra
0 .217 .693 r
.24973 .53081 .2535 .53415 .25872 .53777 .25495 .53442 Mtetra
0 .26 .732 r
.25495 .53442 .25872 .53777 .26399 .54116 .26022 .53782 Mtetra
0 .302 .767 r
.26022 .53782 .26399 .54116 .2693 .54435 .26554 .54099 Mtetra
0 .342 .799 r
.26554 .54099 .2693 .54435 .27466 .54732 .2709 .54396 Mtetra
0 .379 .827 r
.2709 .54396 .27466 .54732 .28006 .55009 .2763 .54673 Mtetra
0 .414 .852 r
.2763 .54673 .28006 .55009 .28551 .55267 .28175 .5493 Mtetra
.033 .446 .873 r
.28175 .5493 .28551 .55267 .29099 .55505 .28723 .55167 Mtetra
.078 .475 .892 r
.28723 .55167 .29099 .55505 .29652 .55724 .29276 .55386 Mtetra
.121 .502 .907 r
.29276 .55386 .29652 .55724 .30208 .55925 .29833 .55587 Mtetra
.16 .527 .92 r
.29833 .55587 .30208 .55925 .30768 .56108 .30393 .55769 Mtetra
.197 .549 .931 r
.30393 .55769 .30768 .56108 .31331 .56275 .30956 .55935 Mtetra
.232 .569 .939 r
.30956 .55935 .31331 .56275 .31898 .56424 .31524 .56084 Mtetra
.264 .587 .946 r
.31524 .56084 .31898 .56424 .32468 .56557 .32094 .56216 Mtetra
.293 .603 .951 r
.32094 .56216 .32468 .56557 .33042 .56675 .32668 .56333 Mtetra
.321 .617 .956 r
.32668 .56333 .33042 .56675 .33618 .56777 .33246 .56435 Mtetra
.346 .63 .959 r
.33246 .56435 .33618 .56777 .34198 .56865 .33826 .56522 Mtetra
.369 .642 .961 r
.33826 .56522 .34198 .56865 .34781 .56938 .34409 .56595 Mtetra
.391 .653 .962 r
.34409 .56595 .34781 .56938 .35367 .56998 .34995 .56654 Mtetra
.411 .662 .963 r
.34995 .56654 .35367 .56998 .35955 .57044 .35584 .56699 Mtetra
.43 .671 .963 r
.35584 .56699 .35955 .57044 .36546 .57077 .36176 .56732 Mtetra
.447 .679 .963 r
.36176 .56732 .36546 .57077 .3714 .57098 .36771 .56752 Mtetra
.463 .686 .963 r
.36771 .56752 .3714 .57098 .37737 .57107 .37368 .5676 Mtetra
.477 .692 .962 r
.37368 .5676 .37737 .57107 .38336 .57104 .37968 .56756 Mtetra
.491 .698 .961 r
.37968 .56756 .38336 .57104 .38938 .5709 .3857 .56741 Mtetra
.503 .703 .96 r
.3857 .56741 .38938 .5709 .39542 .57065 .39175 .56716 Mtetra
.515 .708 .959 r
.39175 .56716 .39542 .57065 .40148 .57029 .39782 .56679 Mtetra
.526 .713 .957 r
.39782 .56679 .40148 .57029 .40756 .56984 .40391 .56633 Mtetra
.536 .717 .956 r
.40391 .56633 .40756 .56984 .41367 .56928 .41002 .56577 Mtetra
.545 .72 .954 r
.41002 .56577 .41367 .56928 .4198 .56864 .41616 .56511 Mtetra
.554 .724 .953 r
.41616 .56511 .4198 .56864 .42595 .5679 .42232 .56437 Mtetra
.562 .727 .951 r
.42232 .56437 .42595 .5679 .43212 .56708 .4285 .56354 Mtetra
.57 .73 .95 r
.4285 .56354 .43212 .56708 .43831 .56617 .4347 .56262 Mtetra
.577 .732 .948 r
.4347 .56262 .43831 .56617 .44452 .56518 .44092 .56163 Mtetra
.584 .735 .947 r
.44092 .56163 .44452 .56518 .45075 .56412 .44715 .56055 Mtetra
.59 .737 .945 r
.44715 .56055 .45075 .56412 .457 .56298 .45341 .5594 Mtetra
.596 .739 .944 r
.45341 .5594 .457 .56298 .46327 .56177 .45969 .55818 Mtetra
.601 .741 .943 r
.45969 .55818 .46327 .56177 .46956 .56048 .46598 .5569 Mtetra
.606 .743 .941 r
.46598 .5569 .46956 .56048 .47586 .55914 .47229 .55554 Mtetra
.611 .744 .94 r
.47229 .55554 .47586 .55914 .48218 .55773 .47862 .55412 Mtetra
.616 .746 .939 r
.47862 .55412 .48218 .55773 .48852 .55625 .48497 .55264 Mtetra
.62 .747 .937 r
.48497 .55264 .48852 .55625 .49488 .55472 .49134 .5511 Mtetra
.624 .749 .936 r
.49134 .5511 .49488 .55472 .50125 .55313 .49772 .5495 Mtetra
.628 .75 .935 r
.49772 .5495 .50125 .55313 .50764 .55148 .50412 .54784 Mtetra
.632 .751 .934 r
.50412 .54784 .50764 .55148 .51404 .54978 .51053 .54613 Mtetra
.635 .752 .933 r
.51053 .54613 .51404 .54978 .52046 .54803 .51696 .54437 Mtetra
.638 .753 .932 r
.51696 .54437 .52046 .54803 .5269 .54623 .52341 .54256 Mtetra
.641 .754 .931 r
.52341 .54256 .5269 .54623 .53335 .54438 .52987 .5407 Mtetra
.644 .755 .93 r
.52987 .5407 .53335 .54438 .53982 .54248 .53635 .5388 Mtetra
.647 .756 .929 r
.53635 .5388 .53982 .54248 .5463 .54054 .54284 .53684 Mtetra
.65 .757 .928 r
.54284 .53684 .5463 .54054 .5528 .53855 .54935 .53485 Mtetra
.652 .758 .927 r
.54935 .53485 .5528 .53855 .55931 .53652 .55587 .53281 Mtetra
.655 .759 .926 r
.55587 .53281 .55931 .53652 .56584 .53444 .56241 .53072 Mtetra
.657 .76 .925 r
.56241 .53072 .56584 .53444 .57238 .53233 .56896 .5286 Mtetra
.66 .76 .924 r
.56896 .5286 .57238 .53233 .57894 .53017 .57553 .52643 Mtetra
.662 .761 .924 r
.57553 .52643 .57894 .53017 .58551 .52797 .58211 .52422 Mtetra
.664 .762 .923 r
.58211 .52422 .58551 .52797 .59209 .52573 .5887 .52197 Mtetra
.666 .763 .922 r
.5887 .52197 .59209 .52573 .59869 .52345 .59531 .51968 Mtetra
.669 .763 .921 r
.59531 .51968 .59869 .52345 .60531 .52113 .60194 .51735 Mtetra
.671 .764 .92 r
.60194 .51735 .60531 .52113 .61193 .51877 .60857 .51498 Mtetra
.673 .765 .919 r
.60857 .51498 .61193 .51877 .61857 .51637 .61522 .51257 Mtetra
.675 .765 .919 r
.61522 .51257 .61857 .51637 .62522 .51393 .62189 .51012 Mtetra
.677 .766 .918 r
.62189 .51012 .62522 .51393 .63189 .51145 .62856 .50763 Mtetra
.679 .767 .917 r
.62856 .50763 .63189 .51145 .63857 .50892 .63525 .5051 Mtetra
.681 .767 .916 r
.63525 .5051 .63857 .50892 .64526 .50636 .64195 .50253 Mtetra
.684 .768 .915 r
.64195 .50253 .64526 .50636 .65196 .50375 .64867 .49991 Mtetra
.686 .769 .915 r
.64867 .49991 .65196 .50375 .65868 .5011 .6554 .49725 Mtetra
.688 .77 .914 r
.6554 .49725 .65868 .5011 .66541 .49841 .66214 .49454 Mtetra
.69 .77 .913 r
.66214 .49454 .66541 .49841 .67215 .49566 .66889 .49179 Mtetra
.693 .771 .912 r
.66889 .49179 .67215 .49566 .6789 .49287 .67565 .48899 Mtetra
.695 .772 .911 r
.67565 .48899 .6789 .49287 .68566 .49004 .68243 .48614 Mtetra
.697 .773 .91 r
.68243 .48614 .68566 .49004 .69243 .48715 .68921 .48325 Mtetra
.7 .774 .909 r
.68921 .48325 .69243 .48715 .69922 .4842 .69601 .48029 Mtetra
.702 .774 .908 r
.69601 .48029 .69922 .4842 .70601 .48121 .70281 .47729 Mtetra
.705 .775 .907 r
.70281 .47729 .70601 .48121 .71281 .47815 .70963 .47422 Mtetra
.708 .776 .905 r
.70963 .47422 .71281 .47815 .71963 .47504 .71645 .4711 Mtetra
.711 .777 .904 r
.71645 .4711 .71963 .47504 .72645 .47187 .72329 .46792 Mtetra
.714 .778 .903 r
.72329 .46792 .72645 .47187 .73328 .46863 .73013 .46467 Mtetra
.717 .779 .901 r
.73013 .46467 .73328 .46863 .74012 .46532 .73698 .46135 Mtetra
.72 .78 .9 r
.73698 .46135 .74012 .46532 .74696 .46194 .74384 .45796 Mtetra
.723 .781 .898 r
.74384 .45796 .74696 .46194 .75381 .45849 .7507 .4545 Mtetra
.727 .783 .897 r
.7507 .4545 .75381 .45849 .76067 .45496 .75757 .45096 Mtetra
.73 .784 .895 r
.75757 .45096 .76067 .45496 .76754 .45135 .76445 .44734 Mtetra
.734 .785 .893 r
.76445 .44734 .76754 .45135 .7744 .44766 .77133 .44364 Mtetra
.738 .786 .892 r
.77133 .44364 .7744 .44766 .78127 .44387 .77822 .43985 Mtetra
.742 .787 .89 r
.77822 .43985 .78127 .44387 .78815 .44 .7851 .43596 Mtetra
.746 .789 .887 r
.7851 .43596 .78815 .44 .79502 .43602 .79199 .43197 Mtetra
.75 .79 .885 r
.79199 .43197 .79502 .43602 .8019 .43195 .79888 .42789 Mtetra
.755 .791 .883 r
.79888 .42789 .8019 .43195 .80878 .42776 .80577 .42369 Mtetra
.759 .793 .88 r
.80577 .42369 .80878 .42776 .81565 .42346 .81266 .41938 Mtetra
.764 .794 .878 r
.81266 .41938 .81565 .42346 .82253 .41905 .81955 .41495 Mtetra
.768 .796 .875 r
.81955 .41495 .82253 .41905 .82939 .41451 .82643 .4104 Mtetra
.773 .797 .872 r
.82643 .4104 .82939 .41451 .83626 .40984 .83331 .40572 Mtetra
.778 .799 .869 r
.83331 .40572 .83626 .40984 .84311 .40503 .84018 .40091 Mtetra
.784 .8 .866 r
.84018 .40091 .84311 .40503 .84996 .40008 .84704 .39595 Mtetra
.789 .802 .863 r
.84704 .39595 .84996 .40008 .8568 .39499 .8539 .39084 Mtetra
.794 .803 .859 r
.8539 .39084 .8568 .39499 .86363 .38973 .86074 .38557 Mtetra
0 .081 .564 r
.23058 .51522 .23436 .51859 .23943 .5229 .23565 .51952 Mtetra
0 .128 .61 r
.23565 .51952 .23943 .5229 .24456 .52697 .24077 .52359 Mtetra
0 .174 .655 r
.24077 .52359 .24456 .52697 .24973 .53081 .24595 .52743 Mtetra
0 .219 .696 r
.24595 .52743 .24973 .53081 .25495 .53442 .25117 .53104 Mtetra
0 .262 .734 r
.25117 .53104 .25495 .53442 .26022 .53782 .25644 .53443 Mtetra
0 .304 .769 r
.25644 .53443 .26022 .53782 .26554 .54099 .26176 .53761 Mtetra
0 .343 .8 r
.26176 .53761 .26554 .54099 .2709 .54396 .26712 .54058 Mtetra
0 .38 .828 r
.26712 .54058 .2709 .54396 .2763 .54673 .27253 .54334 Mtetra
0 .415 .853 r
.27253 .54334 .2763 .54673 .28175 .5493 .27797 .54591 Mtetra
.035 .446 .874 r
.27797 .54591 .28175 .5493 .28723 .55167 .28346 .54828 Mtetra
.08 .476 .892 r
.28346 .54828 .28723 .55167 .29276 .55386 .28899 .55046 Mtetra
.121 .502 .907 r
.28899 .55046 .29276 .55386 .29833 .55587 .29456 .55246 Mtetra
.161 .527 .92 r
.29456 .55246 .29833 .55587 .30393 .55769 .30016 .55429 Mtetra
.197 .549 .931 r
.30016 .55429 .30393 .55769 .30956 .55935 .3058 .55594 Mtetra
.232 .569 .939 r
.3058 .55594 .30956 .55935 .31524 .56084 .31148 .55742 Mtetra
.263 .587 .946 r
.31148 .55742 .31524 .56084 .32094 .56216 .31719 .55875 Mtetra
.293 .603 .951 r
.31719 .55875 .32094 .56216 .32668 .56333 .32294 .55991 Mtetra
.32 .617 .956 r
.32294 .55991 .32668 .56333 .33246 .56435 .32871 .56092 Mtetra
.345 .631 .959 r
.32871 .56092 .33246 .56435 .33826 .56522 .33452 .56179 Mtetra
.369 .642 .961 r
.33452 .56179 .33826 .56522 .34409 .56595 .34036 .56251 Mtetra
.39 .653 .963 r
.34036 .56251 .34409 .56595 .34995 .56654 .34623 .5631 Mtetra
.41 .663 .964 r
.34623 .5631 .34995 .56654 .35584 .56699 .35212 .56354 Mtetra
.429 .672 .964 r
.35212 .56354 .35584 .56699 .36176 .56732 .35805 .56387 Mtetra
.446 .68 .964 r
.35805 .56387 .36176 .56732 .36771 .56752 .364 .56406 Mtetra
.461 .687 .963 r
.364 .56406 .36771 .56752 .37368 .5676 .36998 .56413 Mtetra
.476 .693 .963 r
.36998 .56413 .37368 .5676 .37968 .56756 .37598 .56409 Mtetra
.49 .699 .962 r
.37598 .56409 .37968 .56756 .3857 .56741 .38201 .56394 Mtetra
.502 .705 .961 r
.38201 .56394 .3857 .56741 .39175 .56716 .38806 .56367 Mtetra
.514 .709 .96 r
.38806 .56367 .39175 .56716 .39782 .56679 .39414 .5633 Mtetra
.525 .714 .958 r
.39414 .5633 .39782 .56679 .40391 .56633 .40024 .56283 Mtetra
.535 .718 .957 r
.40024 .56283 .40391 .56633 .41002 .56577 .40636 .56227 Mtetra
.545 .722 .956 r
.40636 .56227 .41002 .56577 .41616 .56511 .4125 .56161 Mtetra
.553 .725 .954 r
.4125 .56161 .41616 .56511 .42232 .56437 .41867 .56085 Mtetra
.561 .728 .953 r
.41867 .56085 .42232 .56437 .4285 .56354 .42486 .56002 Mtetra
.569 .731 .951 r
.42486 .56002 .4285 .56354 .4347 .56262 .43106 .55909 Mtetra
.576 .734 .95 r
.43106 .55909 .4347 .56262 .44092 .56163 .43729 .55809 Mtetra
.583 .737 .948 r
.43729 .55809 .44092 .56163 .44715 .56055 .44354 .55701 Mtetra
.589 .739 .947 r
.44354 .55701 .44715 .56055 .45341 .5594 .4498 .55585 Mtetra
.595 .741 .946 r
.4498 .55585 .45341 .5594 .45969 .55818 .45609 .55463 Mtetra
.601 .743 .944 r
.45609 .55463 .45969 .55818 .46598 .5569 .46239 .55333 Mtetra
.606 .745 .943 r
.46239 .55333 .46598 .5569 .47229 .55554 .46871 .55197 Mtetra
.611 .747 .942 r
.46871 .55197 .47229 .55554 .47862 .55412 .47505 .55054 Mtetra
.615 .748 .94 r
.47505 .55054 .47862 .55412 .48497 .55264 .48141 .54905 Mtetra
.62 .75 .939 r
.48141 .54905 .48497 .55264 .49134 .5511 .48778 .5475 Mtetra
.624 .751 .938 r
.48778 .5475 .49134 .5511 .49772 .5495 .49417 .54589 Mtetra
.628 .752 .937 r
.49417 .54589 .49772 .5495 .50412 .54784 .50058 .54423 Mtetra
.631 .754 .936 r
.50058 .54423 .50412 .54784 .51053 .54613 .507 .54251 Mtetra
.635 .755 .935 r
.507 .54251 .51053 .54613 .51696 .54437 .51344 .54074 Mtetra
.638 .756 .934 r
.51344 .54074 .51696 .54437 .52341 .54256 .5199 .53892 Mtetra
.641 .757 .933 r
.5199 .53892 .52341 .54256 .52987 .5407 .52637 .53706 Mtetra
.644 .758 .932 r
.52637 .53706 .52987 .5407 .53635 .5388 .53286 .53514 Mtetra
.647 .759 .931 r
.53286 .53514 .53635 .5388 .54284 .53684 .53936 .53318 Mtetra
.65 .76 .93 r
.53936 .53318 .54284 .53684 .54935 .53485 .54588 .53117 Mtetra
.652 .761 .929 r
.54588 .53117 .54935 .53485 .55587 .53281 .55241 .52912 Mtetra
.655 .762 .928 r
.55241 .52912 .55587 .53281 .56241 .53072 .55896 .52703 Mtetra
.657 .762 .927 r
.55896 .52703 .56241 .53072 .56896 .5286 .56552 .5249 Mtetra
.66 .763 .926 r
.56552 .5249 .56896 .5286 .57553 .52643 .5721 .52272 Mtetra
.662 .764 .926 r
.5721 .52272 .57553 .52643 .58211 .52422 .57869 .5205 Mtetra
.664 .765 .925 r
.57869 .5205 .58211 .52422 .5887 .52197 .5853 .51824 Mtetra
.666 .765 .924 r
.5853 .51824 .5887 .52197 .59531 .51968 .59192 .51595 Mtetra
.669 .766 .923 r
.59192 .51595 .59531 .51968 .60194 .51735 .59855 .51361 Mtetra
.671 .767 .922 r
.59855 .51361 .60194 .51735 .60857 .51498 .6052 .51123 Mtetra
.673 .767 .922 r
.6052 .51123 .60857 .51498 .61522 .51257 .61186 .50881 Mtetra
.675 .768 .921 r
.61186 .50881 .61522 .51257 .62189 .51012 .61853 .50635 Mtetra
.677 .769 .92 r
.61853 .50635 .62189 .51012 .62856 .50763 .62522 .50385 Mtetra
.679 .77 .919 r
.62522 .50385 .62856 .50763 .63525 .5051 .63192 .50131 Mtetra
.681 .77 .918 r
.63192 .50131 .63525 .5051 .64195 .50253 .63864 .49873 Mtetra
.684 .771 .917 r
.63864 .49873 .64195 .50253 .64867 .49991 .64536 .4961 Mtetra
.686 .772 .917 r
.64536 .4961 .64867 .49991 .6554 .49725 .6521 .49343 Mtetra
.688 .772 .916 r
.6521 .49343 .6554 .49725 .66214 .49454 .65885 .49071 Mtetra
.69 .773 .915 r
.65885 .49071 .66214 .49454 .66889 .49179 .66562 .48795 Mtetra
.693 .774 .914 r
.66562 .48795 .66889 .49179 .67565 .48899 .67239 .48514 Mtetra
.695 .775 .913 r
.67239 .48514 .67565 .48899 .68243 .48614 .67918 .48228 Mtetra
.698 .775 .912 r
.67918 .48228 .68243 .48614 .68921 .48325 .68598 .47937 Mtetra
.7 .776 .911 r
.68598 .47937 .68921 .48325 .69601 .48029 .69278 .47641 Mtetra
.703 .777 .91 r
.69278 .47641 .69601 .48029 .70281 .47729 .6996 .4734 Mtetra
.705 .778 .908 r
.6996 .4734 .70281 .47729 .70963 .47422 .70643 .47032 Mtetra
.708 .779 .907 r
.70643 .47032 .70963 .47422 .71645 .4711 .71327 .46719 Mtetra
.711 .78 .906 r
.71327 .46719 .71645 .4711 .72329 .46792 .72011 .46399 Mtetra
.714 .781 .904 r
.72011 .46399 .72329 .46792 .73013 .46467 .72697 .46073 Mtetra
.717 .782 .903 r
.72697 .46073 .73013 .46467 .73698 .46135 .73383 .45741 Mtetra
.72 .783 .902 r
.73383 .45741 .73698 .46135 .74384 .45796 .7407 .45401 Mtetra
.724 .784 .9 r
.7407 .45401 .74384 .45796 .7507 .4545 .74758 .45054 Mtetra
.727 .785 .898 r
.74758 .45054 .7507 .4545 .75757 .45096 .75447 .44699 Mtetra
.731 .786 .897 r
.75447 .44699 .75757 .45096 .76445 .44734 .76135 .44335 Mtetra
.734 .787 .895 r
.76135 .44335 .76445 .44734 .77133 .44364 .76825 .43964 Mtetra
.738 .788 .893 r
.76825 .43964 .77133 .44364 .77822 .43985 .77515 .43583 Mtetra
.742 .79 .891 r
.77515 .43583 .77822 .43985 .7851 .43596 .78205 .43193 Mtetra
.746 .791 .889 r
.78205 .43193 .7851 .43596 .79199 .43197 .78895 .42794 Mtetra
.751 .792 .886 r
.78895 .42794 .79199 .43197 .79888 .42789 .79585 .42384 Mtetra
.755 .793 .884 r
.79585 .42384 .79888 .42789 .80577 .42369 .80276 .41963 Mtetra
.759 .795 .881 r
.80276 .41963 .80577 .42369 .81266 .41938 .80966 .41531 Mtetra
.764 .796 .879 r
.80966 .41531 .81266 .41938 .81955 .41495 .81656 .41087 Mtetra
.769 .797 .876 r
.81656 .41087 .81955 .41495 .82643 .4104 .82346 .40631 Mtetra
.774 .799 .873 r
.82346 .40631 .82643 .4104 .83331 .40572 .83035 .40162 Mtetra
.779 .8 .87 r
.83035 .40162 .83331 .40572 .84018 .40091 .83724 .39679 Mtetra
.784 .801 .867 r
.83724 .39679 .84018 .40091 .84704 .39595 .84411 .39181 Mtetra
.789 .803 .863 r
.84411 .39181 .84704 .39595 .8539 .39084 .85098 .38669 Mtetra
.795 .804 .86 r
.85098 .38669 .8539 .39084 .86074 .38557 .85784 .38141 Mtetra
0 .084 .568 r
.22679 .5118 .23058 .51522 .23565 .51952 .23186 .51611 Mtetra
0 .13 .614 r
.23186 .51611 .23565 .51952 .24077 .52359 .23698 .52018 Mtetra
0 .176 .658 r
.23698 .52018 .24077 .52359 .24595 .52743 .24215 .52402 Mtetra
0 .22 .699 r
.24215 .52402 .24595 .52743 .25117 .53104 .24738 .52763 Mtetra
0 .263 .736 r
.24738 .52763 .25117 .53104 .25644 .53443 .25265 .53102 Mtetra
0 .305 .771 r
.25265 .53102 .25644 .53443 .26176 .53761 .25797 .5342 Mtetra
0 .344 .802 r
.25797 .5342 .26176 .53761 .26712 .54058 .26333 .53716 Mtetra
0 .381 .829 r
.26333 .53716 .26712 .54058 .27253 .54334 .26874 .53993 Mtetra
0 .415 .853 r
.26874 .53993 .27253 .54334 .27797 .54591 .27418 .54249 Mtetra
.036 .446 .874 r
.27418 .54249 .27797 .54591 .28346 .54828 .27968 .54486 Mtetra
.08 .476 .892 r
.27968 .54486 .28346 .54828 .28899 .55046 .28521 .54705 Mtetra
.122 .502 .907 r
.28521 .54705 .28899 .55046 .29456 .55246 .29078 .54905 Mtetra
.161 .526 .92 r
.29078 .54905 .29456 .55246 .30016 .55429 .29638 .55087 Mtetra
.197 .548 .93 r
.29638 .55087 .30016 .55429 .3058 .55594 .30203 .55252 Mtetra
.231 .568 .939 r
.30203 .55252 .3058 .55594 .31148 .55742 .30771 .554 Mtetra
.263 .586 .946 r
.30771 .554 .31148 .55742 .31719 .55875 .31342 .55532 Mtetra
.292 .603 .952 r
.31342 .55532 .31719 .55875 .32294 .55991 .31917 .55648 Mtetra
.319 .617 .956 r
.31917 .55648 .32294 .55991 .32871 .56092 .32495 .55749 Mtetra
.344 .631 .959 r
.32495 .55749 .32871 .56092 .33452 .56179 .33076 .55835 Mtetra
.368 .643 .961 r
.33076 .55835 .33452 .56179 .34036 .56251 .33661 .55907 Mtetra
.389 .653 .963 r
.33661 .55907 .34036 .56251 .34623 .5631 .34248 .55965 Mtetra
.409 .663 .964 r
.34248 .55965 .34623 .5631 .35212 .56354 .34838 .5601 Mtetra
.427 .672 .964 r
.34838 .5601 .35212 .56354 .35805 .56387 .35431 .56042 Mtetra
.444 .68 .965 r
.35431 .56042 .35805 .56387 .364 .56406 .36027 .56061 Mtetra
.46 .687 .964 r
.36027 .56061 .364 .56406 .36998 .56413 .36625 .56068 Mtetra
.475 .694 .964 r
.36625 .56068 .36998 .56413 .37598 .56409 .37226 .56063 Mtetra
.489 .7 .963 r
.37226 .56063 .37598 .56409 .38201 .56394 .3783 .56047 Mtetra
.501 .706 .962 r
.3783 .56047 .38201 .56394 .38806 .56367 .38436 .5602 Mtetra
.513 .711 .961 r
.38436 .5602 .38806 .56367 .39414 .5633 .39044 .55983 Mtetra
.524 .715 .96 r
.39044 .55983 .39414 .5633 .40024 .56283 .39655 .55935 Mtetra
.534 .719 .958 r
.39655 .55935 .40024 .56283 .40636 .56227 .40268 .55878 Mtetra
.543 .723 .957 r
.40268 .55878 .40636 .56227 .4125 .56161 .40883 .55811 Mtetra
.552 .727 .956 r
.40883 .55811 .4125 .56161 .41867 .56085 .415 .55736 Mtetra
.561 .73 .954 r
.415 .55736 .41867 .56085 .42486 .56002 .4212 .55651 Mtetra
.568 .733 .953 r
.4212 .55651 .42486 .56002 .43106 .55909 .42741 .55558 Mtetra
.575 .736 .951 r
.42741 .55558 .43106 .55909 .43729 .55809 .43365 .55457 Mtetra
.582 .738 .95 r
.43365 .55457 .43729 .55809 .44354 .55701 .4399 .55349 Mtetra
.589 .741 .949 r
.4399 .55349 .44354 .55701 .4498 .55585 .44618 .55233 Mtetra
.594 .743 .947 r
.44618 .55233 .4498 .55585 .45609 .55463 .45247 .55109 Mtetra
.6 .745 .946 r
.45247 .55109 .45609 .55463 .46239 .55333 .45878 .54979 Mtetra
.605 .747 .945 r
.45878 .54979 .46239 .55333 .46871 .55197 .46511 .54842 Mtetra
.61 .749 .943 r
.46511 .54842 .46871 .55197 .47505 .55054 .47146 .54698 Mtetra
.615 .75 .942 r
.47146 .54698 .47505 .55054 .48141 .54905 .47783 .54548 Mtetra
.619 .752 .941 r
.47783 .54548 .48141 .54905 .48778 .5475 .48421 .54393 Mtetra
.623 .753 .94 r
.48421 .54393 .48778 .5475 .49417 .54589 .49061 .54231 Mtetra
.627 .755 .939 r
.49061 .54231 .49417 .54589 .50058 .54423 .49703 .54064 Mtetra
.631 .756 .938 r
.49703 .54064 .50058 .54423 .507 .54251 .50346 .53892 Mtetra
.634 .757 .937 r
.50346 .53892 .507 .54251 .51344 .54074 .50991 .53714 Mtetra
.638 .758 .936 r
.50991 .53714 .51344 .54074 .5199 .53892 .51638 .53532 Mtetra
.641 .76 .935 r
.51638 .53532 .5199 .53892 .52637 .53706 .52286 .53344 Mtetra
.644 .761 .934 r
.52286 .53344 .52637 .53706 .53286 .53514 .52936 .53152 Mtetra
.647 .762 .933 r
.52936 .53152 .53286 .53514 .53936 .53318 .53587 .52955 Mtetra
.649 .763 .932 r
.53587 .52955 .53936 .53318 .54588 .53117 .5424 .52753 Mtetra
.652 .763 .931 r
.5424 .52753 .54588 .53117 .55241 .52912 .54894 .52548 Mtetra
.655 .764 .93 r
.54894 .52548 .55241 .52912 .55896 .52703 .5555 .52337 Mtetra
.657 .765 .929 r
.5555 .52337 .55896 .52703 .56552 .5249 .56207 .52123 Mtetra
.659 .766 .928 r
.56207 .52123 .56552 .5249 .5721 .52272 .56866 .51905 Mtetra
.662 .767 .928 r
.56866 .51905 .5721 .52272 .57869 .5205 .57526 .51682 Mtetra
.664 .767 .927 r
.57526 .51682 .57869 .5205 .5853 .51824 .58188 .51455 Mtetra
.666 .768 .926 r
.58188 .51455 .5853 .51824 .59192 .51595 .58851 .51224 Mtetra
.669 .769 .925 r
.58851 .51224 .59192 .51595 .59855 .51361 .59515 .5099 Mtetra
.671 .77 .924 r
.59515 .5099 .59855 .51361 .6052 .51123 .60181 .50751 Mtetra
.673 .77 .924 r
.60181 .50751 .6052 .51123 .61186 .50881 .60848 .50508 Mtetra
.675 .771 .923 r
.60848 .50508 .61186 .50881 .61853 .50635 .61517 .50261 Mtetra
.677 .772 .922 r
.61517 .50261 .61853 .50635 .62522 .50385 .62187 .5001 Mtetra
.679 .772 .921 r
.62187 .5001 .62522 .50385 .63192 .50131 .62858 .49755 Mtetra
.681 .773 .92 r
.62858 .49755 .63192 .50131 .63864 .49873 .63531 .49496 Mtetra
.684 .774 .919 r
.63531 .49496 .63864 .49873 .64536 .4961 .64205 .49232 Mtetra
.686 .774 .918 r
.64205 .49232 .64536 .4961 .6521 .49343 .6488 .48964 Mtetra
.688 .775 .918 r
.6488 .48964 .6521 .49343 .65885 .49071 .65556 .48691 Mtetra
.69 .776 .917 r
.65556 .48691 .65885 .49071 .66562 .48795 .66233 .48414 Mtetra
.693 .777 .916 r
.66233 .48414 .66562 .48795 .67239 .48514 .66912 .48132 Mtetra
.695 .777 .915 r
.66912 .48132 .67239 .48514 .67918 .48228 .67592 .47845 Mtetra
.698 .778 .914 r
.67592 .47845 .67918 .48228 .68598 .47937 .68273 .47553 Mtetra
.7 .779 .912 r
.68273 .47553 .68598 .47937 .69278 .47641 .68955 .47256 Mtetra
.703 .78 .911 r
.68955 .47256 .69278 .47641 .6996 .4734 .69638 .46953 Mtetra
.706 .781 .91 r
.69638 .46953 .6996 .4734 .70643 .47032 .70322 .46645 Mtetra
.709 .782 .909 r
.70322 .46645 .70643 .47032 .71327 .46719 .71007 .4633 Mtetra
.711 .782 .908 r
.71007 .4633 .71327 .46719 .72011 .46399 .71693 .4601 Mtetra
.714 .783 .906 r
.71693 .4601 .72011 .46399 .72697 .46073 .7238 .45682 Mtetra
.718 .784 .905 r
.7238 .45682 .72697 .46073 .73383 .45741 .73067 .45349 Mtetra
.721 .785 .903 r
.73067 .45349 .73383 .45741 .7407 .45401 .73756 .45008 Mtetra
.724 .786 .901 r
.73756 .45008 .7407 .45401 .74758 .45054 .74445 .44659 Mtetra
.728 .787 .9 r
.74445 .44659 .74758 .45054 .75447 .44699 .75134 .44303 Mtetra
.731 .788 .898 r
.75134 .44303 .75447 .44699 .76135 .44335 .75825 .43939 Mtetra
.735 .789 .896 r
.75825 .43939 .76135 .44335 .76825 .43964 .76515 .43566 Mtetra
.739 .79 .894 r
.76515 .43566 .76825 .43964 .77515 .43583 .77207 .43184 Mtetra
.743 .792 .892 r
.77207 .43184 .77515 .43583 .78205 .43193 .77898 .42793 Mtetra
.747 .793 .89 r
.77898 .42793 .78205 .43193 .78895 .42794 .7859 .42392 Mtetra
.751 .794 .888 r
.7859 .42392 .78895 .42794 .79585 .42384 .79281 .41981 Mtetra
.755 .795 .885 r
.79281 .41981 .79585 .42384 .80276 .41963 .79973 .41558 Mtetra
.76 .796 .882 r
.79973 .41558 .80276 .41963 .80966 .41531 .80665 .41125 Mtetra
.765 .798 .88 r
.80665 .41125 .80966 .41531 .81656 .41087 .81356 .4068 Mtetra
.769 .799 .877 r
.81356 .4068 .81656 .41087 .82346 .40631 .82047 .40222 Mtetra
.774 .8 .874 r
.82047 .40222 .82346 .40631 .83035 .40162 .82738 .39751 Mtetra
.779 .801 .871 r
.82738 .39751 .83035 .40162 .83724 .39679 .83428 .39267 Mtetra
.784 .803 .867 r
.83428 .39267 .83724 .39679 .84411 .39181 .84117 .38768 Mtetra
.79 .804 .864 r
.84117 .38768 .84411 .39181 .85098 .38669 .84805 .38255 Mtetra
.795 .805 .86 r
.84805 .38255 .85098 .38669 .85784 .38141 .85493 .37725 Mtetra
0 .086 .572 r
.22298 .50834 .22679 .5118 .23186 .51611 .22805 .51265 Mtetra
0 .132 .617 r
.22805 .51265 .23186 .51611 .23698 .52018 .23317 .51673 Mtetra
0 .177 .66 r
.23317 .51673 .23698 .52018 .24215 .52402 .23835 .52057 Mtetra
0 .221 .701 r
.23835 .52057 .24215 .52402 .24738 .52763 .24357 .52418 Mtetra
0 .264 .738 r
.24357 .52418 .24738 .52763 .25265 .53102 .24884 .52758 Mtetra
0 .305 .772 r
.24884 .52758 .25265 .53102 .25797 .5342 .25416 .53075 Mtetra
0 .344 .802 r
.25416 .53075 .25797 .5342 .26333 .53716 .25952 .53372 Mtetra
0 .381 .83 r
.25952 .53372 .26333 .53716 .26874 .53993 .26493 .53649 Mtetra
0 .415 .853 r
.26493 .53649 .26874 .53993 .27418 .54249 .27038 .53905 Mtetra
.037 .446 .874 r
.27038 .53905 .27418 .54249 .27968 .54486 .27587 .54143 Mtetra
.08 .475 .892 r
.27587 .54143 .27968 .54486 .28521 .54705 .28141 .54361 Mtetra
.122 .502 .907 r
.28141 .54361 .28521 .54705 .29078 .54905 .28698 .54561 Mtetra
.16 .526 .92 r
.28698 .54561 .29078 .54905 .29638 .55087 .29259 .54743 Mtetra
.197 .548 .93 r
.29259 .54743 .29638 .55087 .30203 .55252 .29824 .54908 Mtetra
.23 .568 .939 r
.29824 .54908 .30203 .55252 .30771 .554 .30392 .55056 Mtetra
.262 .586 .946 r
.30392 .55056 .30771 .554 .31342 .55532 .30964 .55188 Mtetra
.291 .602 .951 r
.30964 .55188 .31342 .55532 .31917 .55648 .31539 .55304 Mtetra
.318 .617 .956 r
.31539 .55304 .31917 .55648 .32495 .55749 .32118 .55405 Mtetra
.343 .631 .959 r
.32118 .55405 .32495 .55749 .33076 .55835 .32699 .55491 Mtetra
.366 .643 .962 r
.32699 .55491 .33076 .55835 .33661 .55907 .33284 .55563 Mtetra
.388 .654 .963 r
.33284 .55563 .33661 .55907 .34248 .55965 .33872 .55621 Mtetra
.408 .663 .964 r
.33872 .55621 .34248 .55965 .34838 .5601 .34463 .55665 Mtetra
.426 .672 .965 r
.34463 .55665 .34838 .5601 .35431 .56042 .35056 .55697 Mtetra
.443 .681 .965 r
.35056 .55697 .35431 .56042 .36027 .56061 .35653 .55716 Mtetra
.459 .688 .965 r
.35653 .55716 .36027 .56061 .36625 .56068 .36252 .55722 Mtetra
.474 .695 .964 r
.36252 .55722 .36625 .56068 .37226 .56063 .36853 .55717 Mtetra
.487 .701 .964 r
.36853 .55717 .37226 .56063 .3783 .56047 .37457 .55701 Mtetra
.5 .707 .963 r
.37457 .55701 .3783 .56047 .38436 .5602 .38064 .55674 Mtetra
.512 .712 .962 r
.38064 .55674 .38436 .5602 .39044 .55983 .38673 .55636 Mtetra
.523 .716 .961 r
.38673 .55636 .39044 .55983 .39655 .55935 .39285 .55588 Mtetra
.533 .721 .96 r
.39285 .55588 .39655 .55935 .40268 .55878 .39898 .55531 Mtetra
.542 .725 .958 r
.39898 .55531 .40268 .55878 .40883 .55811 .40514 .55464 Mtetra
.551 .728 .957 r
.40514 .55464 .40883 .55811 .415 .55736 .41132 .55387 Mtetra
.559 .732 .956 r
.41132 .55387 .415 .55736 .4212 .55651 .41752 .55303 Mtetra
.567 .735 .954 r
.41752 .55303 .4212 .55651 .42741 .55558 .42375 .55209 Mtetra
.574 .738 .953 r
.42375 .55209 .42741 .55558 .43365 .55457 .42999 .55108 Mtetra
.581 .74 .952 r
.42999 .55108 .43365 .55457 .4399 .55349 .43625 .54999 Mtetra
.588 .743 .95 r
.43625 .54999 .4399 .55349 .44618 .55233 .44254 .54882 Mtetra
.594 .745 .949 r
.44254 .54882 .44618 .55233 .45247 .55109 .44884 .54758 Mtetra
.599 .747 .948 r
.44884 .54758 .45247 .55109 .45878 .54979 .45516 .54627 Mtetra
.604 .749 .946 r
.45516 .54627 .45878 .54979 .46511 .54842 .4615 .54489 Mtetra
.609 .751 .945 r
.4615 .54489 .46511 .54842 .47146 .54698 .46786 .54345 Mtetra
.614 .753 .944 r
.46786 .54345 .47146 .54698 .47783 .54548 .47423 .54195 Mtetra
.618 .754 .943 r
.47423 .54195 .47783 .54548 .48421 .54393 .48062 .54038 Mtetra
.623 .756 .942 r
.48062 .54038 .48421 .54393 .49061 .54231 .48703 .53876 Mtetra
.627 .757 .941 r
.48703 .53876 .49061 .54231 .49703 .54064 .49346 .53709 Mtetra
.63 .759 .94 r
.49346 .53709 .49703 .54064 .50346 .53892 .4999 .53535 Mtetra
.634 .76 .939 r
.4999 .53535 .50346 .53892 .50991 .53714 .50636 .53357 Mtetra
.637 .761 .938 r
.50636 .53357 .50991 .53714 .51638 .53532 .51284 .53174 Mtetra
.64 .762 .937 r
.51284 .53174 .51638 .53532 .52286 .53344 .51933 .52985 Mtetra
.643 .763 .936 r
.51933 .52985 .52286 .53344 .52936 .53152 .52584 .52792 Mtetra
.646 .764 .935 r
.52584 .52792 .52936 .53152 .53587 .52955 .53236 .52595 Mtetra
.649 .765 .934 r
.53236 .52595 .53587 .52955 .5424 .52753 .5389 .52392 Mtetra
.652 .766 .933 r
.5389 .52392 .5424 .52753 .54894 .52548 .54545 .52186 Mtetra
.654 .767 .932 r
.54545 .52186 .54894 .52548 .5555 .52337 .55202 .51975 Mtetra
.657 .768 .931 r
.55202 .51975 .5555 .52337 .56207 .52123 .55861 .5176 Mtetra
.659 .769 .93 r
.55861 .5176 .56207 .52123 .56866 .51905 .5652 .5154 Mtetra
.662 .769 .93 r
.5652 .5154 .56866 .51905 .57526 .51682 .57182 .51317 Mtetra
.664 .77 .929 r
.57182 .51317 .57526 .51682 .58188 .51455 .57844 .51089 Mtetra
.666 .771 .928 r
.57844 .51089 .58188 .51455 .58851 .51224 .58509 .50858 Mtetra
.668 .772 .927 r
.58509 .50858 .58851 .51224 .59515 .5099 .59174 .50622 Mtetra
.671 .772 .926 r
.59174 .50622 .59515 .5099 .60181 .50751 .59841 .50382 Mtetra
.673 .773 .926 r
.59841 .50382 .60181 .50751 .60848 .50508 .6051 .50138 Mtetra
.675 .774 .925 r
.6051 .50138 .60848 .50508 .61517 .50261 .61179 .4989 Mtetra
.677 .775 .924 r
.61179 .4989 .61517 .50261 .62187 .5001 .6185 .49639 Mtetra
.679 .775 .923 r
.6185 .49639 .62187 .5001 .62858 .49755 .62523 .49382 Mtetra
.682 .776 .922 r
.62523 .49382 .62858 .49755 .63531 .49496 .63196 .49122 Mtetra
.684 .777 .921 r
.63196 .49122 .63531 .49496 .64205 .49232 .63871 .48857 Mtetra
.686 .777 .92 r
.63871 .48857 .64205 .49232 .6488 .48964 .64548 .48588 Mtetra
.688 .778 .919 r
.64548 .48588 .6488 .48964 .65556 .48691 .65225 .48315 Mtetra
.691 .779 .919 r
.65225 .48315 .65556 .48691 .66233 .48414 .65904 .48036 Mtetra
.693 .779 .918 r
.65904 .48036 .66233 .48414 .66912 .48132 .66584 .47753 Mtetra
.695 .78 .916 r
.66584 .47753 .66912 .48132 .67592 .47845 .67265 .47465 Mtetra
.698 .781 .915 r
.67265 .47465 .67592 .47845 .68273 .47553 .67947 .47172 Mtetra
.701 .782 .914 r
.67947 .47172 .68273 .47553 .68955 .47256 .6863 .46874 Mtetra
.703 .783 .913 r
.6863 .46874 .68955 .47256 .69638 .46953 .69315 .4657 Mtetra
.706 .783 .912 r
.69315 .4657 .69638 .46953 .70322 .46645 .7 .4626 Mtetra
.709 .784 .911 r
.7 .4626 .70322 .46645 .71007 .4633 .70686 .45944 Mtetra
.712 .785 .909 r
.70686 .45944 .71007 .4633 .71693 .4601 .71373 .45623 Mtetra
.715 .786 .908 r
.71373 .45623 .71693 .4601 .7238 .45682 .72061 .45294 Mtetra
.718 .787 .906 r
.72061 .45294 .7238 .45682 .73067 .45349 .7275 .44959 Mtetra
.721 .788 .905 r
.7275 .44959 .73067 .45349 .73756 .45008 .7344 .44617 Mtetra
.725 .789 .903 r
.7344 .44617 .73756 .45008 .74445 .44659 .7413 .44267 Mtetra
.728 .79 .901 r
.7413 .44267 .74445 .44659 .75134 .44303 .74821 .43909 Mtetra
.732 .791 .899 r
.74821 .43909 .75134 .44303 .75825 .43939 .75513 .43544 Mtetra
.735 .792 .897 r
.75513 .43544 .75825 .43939 .76515 .43566 .76205 .4317 Mtetra
.739 .793 .895 r
.76205 .4317 .76515 .43566 .77207 .43184 .76897 .42786 Mtetra
.743 .794 .893 r
.76897 .42786 .77207 .43184 .77898 .42793 .7759 .42394 Mtetra
.747 .795 .891 r
.7759 .42394 .77898 .42793 .7859 .42392 .78283 .41991 Mtetra
.752 .796 .889 r
.78283 .41991 .7859 .42392 .79281 .41981 .78976 .41579 Mtetra
.756 .797 .886 r
.78976 .41579 .79281 .41981 .79973 .41558 .79669 .41155 Mtetra
.76 .798 .883 r
.79669 .41155 .79973 .41558 .80665 .41125 .80362 .4072 Mtetra
.765 .799 .881 r
.80362 .4072 .80665 .41125 .81356 .4068 .81055 .40273 Mtetra
.77 .8 .878 r
.81055 .40273 .81356 .4068 .82047 .40222 .81748 .39814 Mtetra
.775 .802 .875 r
.81748 .39814 .82047 .40222 .82738 .39751 .8244 .39342 Mtetra
.78 .803 .871 r
.8244 .39342 .82738 .39751 .83428 .39267 .83131 .38856 Mtetra
.785 .804 .868 r
.83131 .38856 .83428 .39267 .84117 .38768 .83822 .38355 Mtetra
.79 .805 .864 r
.83822 .38355 .84117 .38768 .84805 .38255 .84512 .3784 Mtetra
.795 .806 .861 r
.84512 .3784 .84805 .38255 .85493 .37725 .852 .37309 Mtetra
0 .088 .575 r
.21917 .50484 .22298 .50834 .22805 .51265 .22423 .50915 Mtetra
0 .133 .62 r
.22423 .50915 .22805 .51265 .23317 .51673 .22935 .51323 Mtetra
0 .178 .663 r
.22935 .51323 .23317 .51673 .23835 .52057 .23452 .51708 Mtetra
0 .222 .702 r
.23452 .51708 .23835 .52057 .24357 .52418 .23975 .5207 Mtetra
0 .265 .739 r
.23975 .5207 .24357 .52418 .24884 .52758 .24502 .5241 Mtetra
0 .305 .773 r
.24502 .5241 .24884 .52758 .25416 .53075 .25034 .52728 Mtetra
0 .344 .803 r
.25034 .52728 .25416 .53075 .25952 .53372 .2557 .53025 Mtetra
0 .38 .83 r
.2557 .53025 .25952 .53372 .26493 .53649 .26111 .53302 Mtetra
0 .414 .853 r
.26111 .53302 .26493 .53649 .27038 .53905 .26656 .53559 Mtetra
.037 .446 .874 r
.26656 .53559 .27038 .53905 .27587 .54143 .27206 .53797 Mtetra
.08 .474 .892 r
.27206 .53797 .27587 .54143 .28141 .54361 .27759 .54015 Mtetra
.121 .501 .907 r
.27759 .54015 .28141 .54361 .28698 .54561 .28317 .54216 Mtetra
.159 .525 .919 r
.28317 .54216 .28698 .54561 .29259 .54743 .28878 .54398 Mtetra
.195 .547 .93 r
.28878 .54398 .29259 .54743 .29824 .54908 .29443 .54563 Mtetra
.229 .567 .939 r
.29443 .54563 .29824 .54908 .30392 .55056 .30012 .54712 Mtetra
.26 .585 .946 r
.30012 .54712 .30392 .55056 .30964 .55188 .30584 .54844 Mtetra
.289 .602 .951 r
.30584 .54844 .30964 .55188 .31539 .55304 .3116 .5496 Mtetra
.316 .617 .956 r
.3116 .5496 .31539 .55304 .32118 .55405 .31738 .55061 Mtetra
.341 .63 .959 r
.31738 .55061 .32118 .55405 .32699 .55491 .32321 .55147 Mtetra
.364 .642 .962 r
.32321 .55147 .32699 .55491 .33284 .55563 .32906 .55219 Mtetra
.386 .654 .964 r
.32906 .55219 .33284 .55563 .33872 .55621 .33494 .55277 Mtetra
.406 .664 .965 r
.33494 .55277 .33872 .55621 .34463 .55665 .34085 .55321 Mtetra
.424 .673 .966 r
.34085 .55321 .34463 .55665 .35056 .55697 .3468 .55352 Mtetra
.441 .681 .966 r
.3468 .55352 .35056 .55697 .35653 .55716 .35277 .55371 Mtetra
.457 .689 .966 r
.35277 .55371 .35653 .55716 .36252 .55722 .35876 .55378 Mtetra
.472 .695 .965 r
.35876 .55378 .36252 .55722 .36853 .55717 .36478 .55373 Mtetra
.486 .702 .965 r
.36478 .55373 .36853 .55717 .37457 .55701 .37083 .55356 Mtetra
.498 .707 .964 r
.37083 .55356 .37457 .55701 .38064 .55674 .37691 .55329 Mtetra
.51 .713 .963 r
.37691 .55329 .38064 .55674 .38673 .55636 .383 .55291 Mtetra
.521 .717 .962 r
.383 .55291 .38673 .55636 .39285 .55588 .38912 .55243 Mtetra
.531 .722 .961 r
.38912 .55243 .39285 .55588 .39898 .55531 .39527 .55185 Mtetra
.541 .726 .96 r
.39527 .55185 .39898 .55531 .40514 .55464 .40143 .55117 Mtetra
.55 .73 .958 r
.40143 .55117 .40514 .55464 .41132 .55387 .40762 .55041 Mtetra
.558 .733 .957 r
.40762 .55041 .41132 .55387 .41752 .55303 .41383 .54956 Mtetra
.566 .736 .956 r
.41383 .54956 .41752 .55303 .42375 .55209 .42006 .54862 Mtetra
.573 .739 .954 r
.42006 .54862 .42375 .55209 .42999 .55108 .42632 .5476 Mtetra
.58 .742 .953 r
.42632 .5476 .42999 .55108 .43625 .54999 .43259 .5465 Mtetra
.587 .745 .952 r
.43259 .5465 .43625 .54999 .44254 .54882 .43888 .54533 Mtetra
.593 .747 .951 r
.43888 .54533 .44254 .54882 .44884 .54758 .44519 .54409 Mtetra
.598 .749 .949 r
.44519 .54409 .44884 .54758 .45516 .54627 .45152 .54277 Mtetra
.604 .751 .948 r
.45152 .54277 .45516 .54627 .4615 .54489 .45787 .54139 Mtetra
.609 .753 .947 r
.45787 .54139 .4615 .54489 .46786 .54345 .46423 .53995 Mtetra
.613 .755 .946 r
.46423 .53995 .46786 .54345 .47423 .54195 .47062 .53844 Mtetra
.618 .757 .945 r
.47062 .53844 .47423 .54195 .48062 .54038 .47702 .53687 Mtetra
.622 .758 .944 r
.47702 .53687 .48062 .54038 .48703 .53876 .48344 .53524 Mtetra
.626 .76 .943 r
.48344 .53524 .48703 .53876 .49346 .53709 .48987 .53356 Mtetra
.63 .761 .941 r
.48987 .53356 .49346 .53709 .4999 .53535 .49633 .53182 Mtetra
.633 .762 .94 r
.49633 .53182 .4999 .53535 .50636 .53357 .5028 .53003 Mtetra
.637 .764 .94 r
.5028 .53003 .50636 .53357 .51284 .53174 .50928 .52819 Mtetra
.64 .765 .939 r
.50928 .52819 .51284 .53174 .51933 .52985 .51578 .5263 Mtetra
.643 .766 .938 r
.51578 .5263 .51933 .52985 .52584 .52792 .5223 .52436 Mtetra
.646 .767 .937 r
.5223 .52436 .52584 .52792 .53236 .52595 .52884 .52238 Mtetra
.649 .768 .936 r
.52884 .52238 .53236 .52595 .5389 .52392 .53539 .52035 Mtetra
.651 .769 .935 r
.53539 .52035 .5389 .52392 .54545 .52186 .54195 .51827 Mtetra
.654 .77 .934 r
.54195 .51827 .54545 .52186 .55202 .51975 .54853 .51616 Mtetra
.657 .771 .933 r
.54853 .51616 .55202 .51975 .55861 .5176 .55512 .514 Mtetra
.659 .771 .932 r
.55512 .514 .55861 .5176 .5652 .5154 .56173 .51179 Mtetra
.661 .772 .932 r
.56173 .51179 .5652 .5154 .57182 .51317 .56836 .50955 Mtetra
.664 .773 .931 r
.56836 .50955 .57182 .51317 .57844 .51089 .575 .50726 Mtetra
.666 .774 .93 r
.575 .50726 .57844 .51089 .58509 .50858 .58165 .50494 Mtetra
.668 .775 .929 r
.58165 .50494 .58509 .50858 .59174 .50622 .58832 .50257 Mtetra
.67 .775 .928 r
.58832 .50257 .59174 .50622 .59841 .50382 .595 .50017 Mtetra
.673 .776 .928 r
.595 .50017 .59841 .50382 .6051 .50138 .60169 .49772 Mtetra
.675 .777 .927 r
.60169 .49772 .6051 .50138 .61179 .4989 .6084 .49523 Mtetra
.677 .777 .926 r
.6084 .49523 .61179 .4989 .6185 .49639 .61512 .4927 Mtetra
.679 .778 .925 r
.61512 .4927 .6185 .49639 .62523 .49382 .62186 .49013 Mtetra
.682 .779 .924 r
.62186 .49013 .62523 .49382 .63196 .49122 .62861 .48752 Mtetra
.684 .779 .923 r
.62861 .48752 .63196 .49122 .63871 .48857 .63537 .48486 Mtetra
.686 .78 .922 r
.63537 .48486 .63871 .48857 .64548 .48588 .64214 .48216 Mtetra
.688 .781 .921 r
.64214 .48216 .64548 .48588 .65225 .48315 .64893 .47941 Mtetra
.691 .782 .92 r
.64893 .47941 .65225 .48315 .65904 .48036 .65573 .47662 Mtetra
.693 .782 .919 r
.65573 .47662 .65904 .48036 .66584 .47753 .66254 .47377 Mtetra
.696 .783 .918 r
.66254 .47377 .66584 .47753 .67265 .47465 .66936 .47088 Mtetra
.698 .784 .917 r
.66936 .47088 .67265 .47465 .67947 .47172 .6762 .46794 Mtetra
.701 .784 .916 r
.6762 .46794 .67947 .47172 .6863 .46874 .68304 .46494 Mtetra
.704 .785 .915 r
.68304 .46494 .6863 .46874 .69315 .4657 .6899 .46189 Mtetra
.706 .786 .914 r
.6899 .46189 .69315 .4657 .7 .4626 .69676 .45878 Mtetra
.709 .787 .912 r
.69676 .45878 .7 .4626 .70686 .45944 .70364 .45561 Mtetra
.712 .788 .911 r
.70364 .45561 .70686 .45944 .71373 .45623 .71052 .45238 Mtetra
.715 .788 .909 r
.71052 .45238 .71373 .45623 .72061 .45294 .71742 .44908 Mtetra
.718 .789 .908 r
.71742 .44908 .72061 .45294 .7275 .44959 .72432 .44572 Mtetra
.722 .79 .906 r
.72432 .44572 .7275 .44959 .7344 .44617 .73123 .44228 Mtetra
.725 .791 .904 r
.73123 .44228 .7344 .44617 .7413 .44267 .73815 .43877 Mtetra
.729 .792 .903 r
.73815 .43877 .7413 .44267 .74821 .43909 .74507 .43518 Mtetra
.732 .793 .901 r
.74507 .43518 .74821 .43909 .75513 .43544 .752 .43151 Mtetra
.736 .794 .899 r
.752 .43151 .75513 .43544 .76205 .4317 .75893 .42775 Mtetra
.74 .795 .897 r
.75893 .42775 .76205 .4317 .76897 .42786 .76587 .42391 Mtetra
.744 .796 .894 r
.76587 .42391 .76897 .42786 .7759 .42394 .77281 .41996 Mtetra
.748 .797 .892 r
.77281 .41996 .7759 .42394 .78283 .41991 .77975 .41592 Mtetra
.752 .798 .89 r
.77975 .41592 .78283 .41991 .78976 .41579 .7867 .41178 Mtetra
.757 .799 .887 r
.7867 .41178 .78976 .41579 .79669 .41155 .79365 .40753 Mtetra
.761 .8 .884 r
.79365 .40753 .79669 .41155 .80362 .4072 .80059 .40316 Mtetra
.766 .801 .881 r
.80059 .40316 .80362 .4072 .81055 .40273 .80753 .39868 Mtetra
.77 .802 .878 r
.80753 .39868 .81055 .40273 .81748 .39814 .81447 .39407 Mtetra
.775 .803 .875 r
.81447 .39407 .81748 .39814 .8244 .39342 .82141 .38933 Mtetra
.78 .804 .872 r
.82141 .38933 .8244 .39342 .83131 .38856 .82833 .38445 Mtetra
.785 .805 .869 r
.82833 .38445 .83131 .38856 .83822 .38355 .83525 .37943 Mtetra
.791 .806 .865 r
.83525 .37943 .83822 .38355 .84512 .3784 .84217 .37425 Mtetra
.796 .807 .861 r
.84217 .37425 .84512 .3784 .852 .37309 .84907 .36892 Mtetra
0 .089 .578 r
.21534 .50129 .21917 .50484 .22423 .50915 .2204 .50561 Mtetra
0 .134 .623 r
.2204 .50561 .22423 .50915 .22935 .51323 .22552 .5097 Mtetra
0 .179 .665 r
.22552 .5097 .22935 .51323 .23452 .51708 .23069 .51355 Mtetra
0 .222 .704 r
.23069 .51355 .23452 .51708 .23975 .5207 .23591 .51718 Mtetra
0 .265 .74 r
.23591 .51718 .23975 .5207 .24502 .5241 .24118 .52059 Mtetra
0 .305 .773 r
.24118 .52059 .24502 .5241 .25034 .52728 .2465 .52378 Mtetra
0 .344 .803 r
.2465 .52378 .25034 .52728 .2557 .53025 .25186 .52676 Mtetra
0 .38 .83 r
.25186 .52676 .2557 .53025 .26111 .53302 .25727 .52953 Mtetra
0 .413 .853 r
.25727 .52953 .26111 .53302 .26656 .53559 .26273 .53211 Mtetra
.036 .445 .874 r
.26273 .53211 .26656 .53559 .27206 .53797 .26822 .53449 Mtetra
.079 .474 .891 r
.26822 .53449 .27206 .53797 .27759 .54015 .27376 .53668 Mtetra
.12 .5 .906 r
.27376 .53668 .27759 .54015 .28317 .54216 .27934 .53868 Mtetra
.158 .524 .919 r
.27934 .53868 .28317 .54216 .28878 .54398 .28495 .54051 Mtetra
.194 .546 .929 r
.28495 .54051 .28878 .54398 .29443 .54563 .29061 .54217 Mtetra
.228 .566 .938 r
.29061 .54217 .29443 .54563 .30012 .54712 .2963 .54366 Mtetra
.259 .585 .945 r
.2963 .54366 .30012 .54712 .30584 .54844 .30202 .54498 Mtetra
.288 .601 .951 r
.30202 .54498 .30584 .54844 .3116 .5496 .30778 .54615 Mtetra
.314 .616 .956 r
.30778 .54615 .3116 .5496 .31738 .55061 .31358 .54716 Mtetra
.339 .63 .959 r
.31358 .54716 .31738 .55061 .32321 .55147 .3194 .54802 Mtetra
.363 .642 .962 r
.3194 .54802 .32321 .55147 .32906 .55219 .32526 .54874 Mtetra
.384 .653 .964 r
.32526 .54874 .32906 .55219 .33494 .55277 .33115 .54932 Mtetra
.404 .664 .965 r
.33115 .54932 .33494 .55277 .34085 .55321 .33707 .54977 Mtetra
.422 .673 .966 r
.33707 .54977 .34085 .55321 .3468 .55352 .34301 .55008 Mtetra
.44 .681 .966 r
.34301 .55008 .3468 .55352 .35277 .55371 .34899 .55027 Mtetra
.455 .689 .966 r
.34899 .55027 .35277 .55371 .35876 .55378 .35499 .55033 Mtetra
.47 .696 .966 r
.35499 .55033 .35876 .55378 .36478 .55373 .36102 .55028 Mtetra
.484 .702 .966 r
.36102 .55028 .36478 .55373 .37083 .55356 .36707 .55012 Mtetra
.497 .708 .965 r
.36707 .55012 .37083 .55356 .37691 .55329 .37315 .54984 Mtetra
.509 .714 .964 r
.37315 .54984 .37691 .55329 .383 .55291 .37926 .54946 Mtetra
.52 .718 .963 r
.37926 .54946 .383 .55291 .38912 .55243 .38539 .54898 Mtetra
.53 .723 .962 r
.38539 .54898 .38912 .55243 .39527 .55185 .39154 .5484 Mtetra
.54 .727 .961 r
.39154 .5484 .39527 .55185 .40143 .55117 .39771 .54772 Mtetra
.549 .731 .96 r
.39771 .54772 .40143 .55117 .40762 .55041 .40391 .54696 Mtetra
.557 .735 .958 r
.40391 .54696 .40762 .55041 .41383 .54956 .41013 .5461 Mtetra
.565 .738 .957 r
.41013 .5461 .41383 .54956 .42006 .54862 .41636 .54516 Mtetra
.572 .741 .956 r
.41636 .54516 .42006 .54862 .42632 .5476 .42262 .54414 Mtetra
.579 .744 .955 r
.42262 .54414 .42632 .5476 .43259 .5465 .4289 .54304 Mtetra
.586 .746 .953 r
.4289 .54304 .43259 .5465 .43888 .54533 .4352 .54187 Mtetra
.592 .749 .952 r
.4352 .54187 .43888 .54533 .44519 .54409 .44152 .54062 Mtetra
.597 .751 .951 r
.44152 .54062 .44519 .54409 .45152 .54277 .44786 .5393 Mtetra
.603 .753 .95 r
.44786 .5393 .45152 .54277 .45787 .54139 .45422 .53792 Mtetra
.608 .755 .949 r
.45422 .53792 .45787 .54139 .46423 .53995 .46059 .53646 Mtetra
.612 .757 .948 r
.46059 .53646 .46423 .53995 .47062 .53844 .46699 .53495 Mtetra
.617 .759 .947 r
.46699 .53495 .47062 .53844 .47702 .53687 .4734 .53338 Mtetra
.621 .76 .945 r
.4734 .53338 .47702 .53687 .48344 .53524 .47983 .53174 Mtetra
.625 .762 .944 r
.47983 .53174 .48344 .53524 .48987 .53356 .48627 .53006 Mtetra
.629 .763 .943 r
.48627 .53006 .48987 .53356 .49633 .53182 .49274 .52831 Mtetra
.633 .765 .942 r
.49274 .52831 .49633 .53182 .5028 .53003 .49922 .52652 Mtetra
.636 .766 .941 r
.49922 .52652 .5028 .53003 .50928 .52819 .50571 .52467 Mtetra
.639 .767 .941 r
.50571 .52467 .50928 .52819 .51578 .5263 .51222 .52277 Mtetra
.642 .768 .94 r
.51222 .52277 .51578 .5263 .5223 .52436 .51875 .52083 Mtetra
.645 .769 .939 r
.51875 .52083 .5223 .52436 .52884 .52238 .5253 .51884 Mtetra
.648 .771 .938 r
.5253 .51884 .52884 .52238 .53539 .52035 .53186 .5168 Mtetra
.651 .772 .937 r
.53186 .5168 .53539 .52035 .54195 .51827 .53843 .51472 Mtetra
.654 .772 .936 r
.53843 .51472 .54195 .51827 .54853 .51616 .54502 .51259 Mtetra
.656 .773 .935 r
.54502 .51259 .54853 .51616 .55512 .514 .55163 .51043 Mtetra
.659 .774 .935 r
.55163 .51043 .55512 .514 .56173 .51179 .55825 .50822 Mtetra
.661 .775 .934 r
.55825 .50822 .56173 .51179 .56836 .50955 .56488 .50596 Mtetra
.663 .776 .933 r
.56488 .50596 .56836 .50955 .575 .50726 .57153 .50367 Mtetra
.666 .777 .932 r
.57153 .50367 .575 .50726 .58165 .50494 .5782 .50134 Mtetra
.668 .777 .931 r
.5782 .50134 .58165 .50494 .58832 .50257 .58488 .49896 Mtetra
.67 .778 .93 r
.58488 .49896 .58832 .50257 .595 .50017 .59157 .49655 Mtetra
.673 .779 .93 r
.59157 .49655 .595 .50017 .60169 .49772 .59827 .49409 Mtetra
.675 .78 .929 r
.59827 .49409 .60169 .49772 .6084 .49523 .605 .49159 Mtetra
.677 .78 .928 r
.605 .49159 .6084 .49523 .61512 .4927 .61173 .48905 Mtetra
.679 .781 .927 r
.61173 .48905 .61512 .4927 .62186 .49013 .61848 .48647 Mtetra
.682 .782 .926 r
.61848 .48647 .62186 .49013 .62861 .48752 .62524 .48384 Mtetra
.684 .782 .925 r
.62524 .48384 .62861 .48752 .63537 .48486 .63201 .48118 Mtetra
.686 .783 .924 r
.63201 .48118 .63537 .48486 .64214 .48216 .6388 .47846 Mtetra
.689 .784 .923 r
.6388 .47846 .64214 .48216 .64893 .47941 .6456 .4757 Mtetra
.691 .784 .922 r
.6456 .4757 .64893 .47941 .65573 .47662 .65241 .4729 Mtetra
.693 .785 .921 r
.65241 .4729 .65573 .47662 .66254 .47377 .65923 .47005 Mtetra
.696 .786 .92 r
.65923 .47005 .66254 .47377 .66936 .47088 .66607 .46714 Mtetra
.698 .786 .919 r
.66607 .46714 .66936 .47088 .6762 .46794 .67291 .46419 Mtetra
.701 .787 .918 r
.67291 .46419 .6762 .46794 .68304 .46494 .67977 .46118 Mtetra
.704 .788 .916 r
.67977 .46118 .68304 .46494 .6899 .46189 .68664 .45811 Mtetra
.707 .789 .915 r
.68664 .45811 .6899 .46189 .69676 .45878 .69352 .45499 Mtetra
.71 .789 .914 r
.69352 .45499 .69676 .45878 .70364 .45561 .70041 .45181 Mtetra
.713 .79 .912 r
.70041 .45181 .70364 .45561 .71052 .45238 .7073 .44856 Mtetra
.716 .791 .911 r
.7073 .44856 .71052 .45238 .71742 .44908 .71421 .44525 Mtetra
.719 .792 .909 r
.71421 .44525 .71742 .44908 .72432 .44572 .72112 .44187 Mtetra
.722 .793 .908 r
.72112 .44187 .72432 .44572 .73123 .44228 .72805 .43842 Mtetra
.726 .793 .906 r
.72805 .43842 .73123 .44228 .73815 .43877 .73498 .43489 Mtetra
.729 .794 .904 r
.73498 .43489 .73815 .43877 .74507 .43518 .74191 .43129 Mtetra
.733 .795 .902 r
.74191 .43129 .74507 .43518 .752 .43151 .74886 .4276 Mtetra
.736 .796 .9 r
.74886 .4276 .752 .43151 .75893 .42775 .7558 .42383 Mtetra
.74 .797 .898 r
.7558 .42383 .75893 .42775 .76587 .42391 .76275 .41996 Mtetra
.744 .798 .896 r
.76275 .41996 .76587 .42391 .77281 .41996 .76971 .41601 Mtetra
.748 .799 .893 r
.76971 .41601 .77281 .41996 .77975 .41592 .77667 .41195 Mtetra
.753 .8 .891 r
.77667 .41195 .77975 .41592 .7867 .41178 .78363 .40779 Mtetra
.757 .801 .888 r
.78363 .40779 .7867 .41178 .79365 .40753 .79058 .40352 Mtetra
.762 .802 .885 r
.79058 .40352 .79365 .40753 .80059 .40316 .79754 .39913 Mtetra
.766 .803 .882 r
.79754 .39913 .80059 .40316 .80753 .39868 .8045 .39463 Mtetra
.771 .804 .879 r
.8045 .39463 .80753 .39868 .81447 .39407 .81145 .39 Mtetra
.776 .805 .876 r
.81145 .39 .81447 .39407 .82141 .38933 .8184 .38524 Mtetra
.781 .806 .873 r
.8184 .38524 .82141 .38933 .82833 .38445 .82534 .38034 Mtetra
.786 .807 .869 r
.82534 .38034 .82833 .38445 .83525 .37943 .83228 .3753 Mtetra
.791 .808 .865 r
.83228 .3753 .83525 .37943 .84217 .37425 .8392 .37011 Mtetra
.797 .809 .861 r
.8392 .37011 .84217 .37425 .84907 .36892 .84612 .36476 Mtetra
0 .089 .581 r
.2115 .49769 .21534 .50129 .2204 .50561 .21656 .50203 Mtetra
0 .134 .624 r
.21656 .50203 .2204 .50561 .22552 .5097 .22167 .50613 Mtetra
0 .179 .666 r
.22167 .50613 .22552 .5097 .23069 .51355 .22684 .50999 Mtetra
0 .222 .705 r
.22684 .50999 .23069 .51355 .23591 .51718 .23206 .51363 Mtetra
0 .264 .741 r
.23206 .51363 .23591 .51718 .24118 .52059 .23733 .51704 Mtetra
0 .305 .773 r
.23733 .51704 .24118 .52059 .2465 .52378 .24265 .52024 Mtetra
0 .343 .803 r
.24265 .52024 .2465 .52378 .25186 .52676 .24802 .52323 Mtetra
0 .379 .829 r
.24802 .52323 .25186 .52676 .25727 .52953 .25343 .52601 Mtetra
0 .412 .853 r
.25343 .52601 .25727 .52953 .26273 .53211 .25888 .52859 Mtetra
.036 .443 .873 r
.25888 .52859 .26273 .53211 .26822 .53449 .26438 .53098 Mtetra
.078 .472 .891 r
.26438 .53098 .26822 .53449 .27376 .53668 .26991 .53318 Mtetra
.119 .499 .906 r
.26991 .53318 .27376 .53668 .27934 .53868 .27549 .5352 Mtetra
.157 .523 .918 r
.27549 .5352 .27934 .53868 .28495 .54051 .28111 .53703 Mtetra
.192 .545 .929 r
.28111 .53703 .28495 .54051 .29061 .54217 .28677 .53869 Mtetra
.226 .565 .938 r
.28677 .53869 .29061 .54217 .2963 .54366 .29246 .54018 Mtetra
.257 .584 .945 r
.29246 .54018 .2963 .54366 .30202 .54498 .29819 .54151 Mtetra
.286 .6 .951 r
.29819 .54151 .30202 .54498 .30778 .54615 .30395 .54268 Mtetra
.312 .615 .956 r
.30395 .54268 .30778 .54615 .31358 .54716 .30975 .5437 Mtetra
.337 .629 .959 r
.30975 .5437 .31358 .54716 .3194 .54802 .31558 .54457 Mtetra
.36 .642 .962 r
.31558 .54457 .3194 .54802 .32526 .54874 .32144 .54529 Mtetra
.382 .653 .964 r
.32144 .54529 .32526 .54874 .33115 .54932 .32734 .54587 Mtetra
.402 .663 .966 r
.32734 .54587 .33115 .54932 .33707 .54977 .33326 .54632 Mtetra
.42 .673 .966 r
.33326 .54632 .33707 .54977 .34301 .55008 .33921 .54664 Mtetra
.437 .681 .967 r
.33921 .54664 .34301 .55008 .34899 .55027 .34519 .54683 Mtetra
.453 .689 .967 r
.34519 .54683 .34899 .55027 .35499 .55033 .3512 .5469 Mtetra
.468 .696 .967 r
.3512 .5469 .35499 .55033 .36102 .55028 .35724 .54685 Mtetra
.482 .703 .966 r
.35724 .54685 .36102 .55028 .36707 .55012 .3633 .54668 Mtetra
.495 .709 .966 r
.3633 .54668 .36707 .55012 .37315 .54984 .36938 .54641 Mtetra
.507 .714 .965 r
.36938 .54641 .37315 .54984 .37926 .54946 .37549 .54603 Mtetra
.518 .719 .964 r
.37549 .54603 .37926 .54946 .38539 .54898 .38163 .54555 Mtetra
.528 .724 .963 r
.38163 .54555 .38539 .54898 .39154 .5484 .38779 .54497 Mtetra
.538 .728 .962 r
.38779 .54497 .39154 .5484 .39771 .54772 .39397 .54429 Mtetra
.547 .732 .961 r
.39397 .54429 .39771 .54772 .40391 .54696 .40017 .54352 Mtetra
.556 .736 .96 r
.40017 .54352 .40391 .54696 .41013 .5461 .4064 .54267 Mtetra
.563 .739 .959 r
.4064 .54267 .41013 .5461 .41636 .54516 .41265 .54173 Mtetra
.571 .742 .957 r
.41265 .54173 .41636 .54516 .42262 .54414 .41892 .5407 Mtetra
.578 .745 .956 r
.41892 .5407 .42262 .54414 .4289 .54304 .4252 .5396 Mtetra
.584 .748 .955 r
.4252 .5396 .4289 .54304 .4352 .54187 .43151 .53842 Mtetra
.59 .751 .954 r
.43151 .53842 .4352 .54187 .44152 .54062 .43784 .53717 Mtetra
.596 .753 .953 r
.43784 .53717 .44152 .54062 .44786 .5393 .44419 .53585 Mtetra
.602 .755 .952 r
.44419 .53585 .44786 .5393 .45422 .53792 .45055 .53446 Mtetra
.607 .757 .95 r
.45055 .53446 .45422 .53792 .46059 .53646 .45694 .53301 Mtetra
.611 .759 .949 r
.45694 .53301 .46059 .53646 .46699 .53495 .46334 .53149 Mtetra
.616 .761 .948 r
.46334 .53149 .46699 .53495 .4734 .53338 .46976 .52991 Mtetra
.62 .763 .947 r
.46976 .52991 .4734 .53338 .47983 .53174 .4762 .52828 Mtetra
.624 .764 .946 r
.4762 .52828 .47983 .53174 .48627 .53006 .48266 .52658 Mtetra
.628 .766 .945 r
.48266 .52658 .48627 .53006 .49274 .52831 .48913 .52483 Mtetra
.632 .767 .944 r
.48913 .52483 .49274 .52831 .49922 .52652 .49562 .52303 Mtetra
.635 .768 .943 r
.49562 .52303 .49922 .52652 .50571 .52467 .50212 .52118 Mtetra
.639 .77 .942 r
.50212 .52118 .50571 .52467 .51222 .52277 .50865 .51928 Mtetra
.642 .771 .942 r
.50865 .51928 .51222 .52277 .51875 .52083 .51519 .51733 Mtetra
.645 .772 .941 r
.51519 .51733 .51875 .52083 .5253 .51884 .52174 .51533 Mtetra
.648 .773 .94 r
.52174 .51533 .5253 .51884 .53186 .5168 .52831 .51328 Mtetra
.651 .774 .939 r
.52831 .51328 .53186 .5168 .53843 .51472 .5349 .5112 Mtetra
.653 .775 .938 r
.5349 .5112 .53843 .51472 .54502 .51259 .5415 .50906 Mtetra
.656 .776 .937 r
.5415 .50906 .54502 .51259 .55163 .51043 .54811 .50689 Mtetra
.658 .777 .936 r
.54811 .50689 .55163 .51043 .55825 .50822 .55475 .50467 Mtetra
.661 .778 .936 r
.55475 .50467 .55825 .50822 .56488 .50596 .56139 .50241 Mtetra
.663 .779 .935 r
.56139 .50241 .56488 .50596 .57153 .50367 .56805 .50011 Mtetra
.666 .779 .934 r
.56805 .50011 .57153 .50367 .5782 .50134 .57473 .49776 Mtetra
.668 .78 .933 r
.57473 .49776 .5782 .50134 .58488 .49896 .58142 .49538 Mtetra
.67 .781 .932 r
.58142 .49538 .58488 .49896 .59157 .49655 .58812 .49296 Mtetra
.673 .782 .932 r
.58812 .49296 .59157 .49655 .59827 .49409 .59484 .49049 Mtetra
.675 .782 .931 r
.59484 .49049 .59827 .49409 .605 .49159 .60157 .48798 Mtetra
.677 .783 .93 r
.60157 .48798 .605 .49159 .61173 .48905 .60832 .48543 Mtetra
.679 .784 .929 r
.60832 .48543 .61173 .48905 .61848 .48647 .61508 .48284 Mtetra
.682 .785 .928 r
.61508 .48284 .61848 .48647 .62524 .48384 .62185 .4802 Mtetra
.684 .785 .927 r
.62185 .4802 .62524 .48384 .63201 .48118 .62864 .47752 Mtetra
.686 .786 .926 r
.62864 .47752 .63201 .48118 .6388 .47846 .63544 .4748 Mtetra
.689 .787 .925 r
.63544 .4748 .6388 .47846 .6456 .4757 .64225 .47203 Mtetra
.691 .787 .924 r
.64225 .47203 .6456 .4757 .65241 .4729 .64907 .46921 Mtetra
.694 .788 .923 r
.64907 .46921 .65241 .4729 .65923 .47005 .65591 .46635 Mtetra
.696 .789 .922 r
.65591 .46635 .65923 .47005 .66607 .46714 .66276 .46343 Mtetra
.699 .789 .921 r
.66276 .46343 .66607 .46714 .67291 .46419 .66961 .46046 Mtetra
.701 .79 .919 r
.66961 .46046 .67291 .46419 .67977 .46118 .67648 .45744 Mtetra
.704 .791 .918 r
.67648 .45744 .67977 .46118 .68664 .45811 .68337 .45436 Mtetra
.707 .791 .917 r
.68337 .45436 .68664 .45811 .69352 .45499 .69026 .45122 Mtetra
.71 .792 .915 r
.69026 .45122 .69352 .45499 .70041 .45181 .69716 .44803 Mtetra
.713 .793 .914 r
.69716 .44803 .70041 .45181 .7073 .44856 .70407 .44477 Mtetra
.716 .794 .912 r
.70407 .44477 .7073 .44856 .71421 .44525 .71099 .44144 Mtetra
.719 .794 .911 r
.71099 .44144 .71421 .44525 .72112 .44187 .71792 .43805 Mtetra
.723 .795 .909 r
.71792 .43805 .72112 .44187 .72805 .43842 .72485 .43458 Mtetra
.726 .796 .907 r
.72485 .43458 .72805 .43842 .73498 .43489 .7318 .43104 Mtetra
.73 .797 .905 r
.7318 .43104 .73498 .43489 .74191 .43129 .73875 .42742 Mtetra
.733 .797 .903 r
.73875 .42742 .74191 .43129 .74886 .4276 .7457 .42371 Mtetra
.737 .798 .901 r
.7457 .42371 .74886 .4276 .7558 .42383 .75266 .41992 Mtetra
.741 .799 .899 r
.75266 .41992 .7558 .42383 .76275 .41996 .75963 .41604 Mtetra
.745 .8 .897 r
.75963 .41604 .76275 .41996 .76971 .41601 .7666 .41206 Mtetra
.749 .801 .894 r
.7666 .41206 .76971 .41601 .77667 .41195 .77357 .40799 Mtetra
.753 .802 .892 r
.77357 .40799 .77667 .41195 .78363 .40779 .78054 .40381 Mtetra
.758 .803 .889 r
.78054 .40381 .78363 .40779 .79058 .40352 .78751 .39952 Mtetra
.762 .803 .886 r
.78751 .39952 .79058 .40352 .79754 .39913 .79448 .39512 Mtetra
.767 .804 .883 r
.79448 .39512 .79754 .39913 .8045 .39463 .80146 .39059 Mtetra
.772 .805 .88 r
.80146 .39059 .8045 .39463 .81145 .39 .80842 .38594 Mtetra
.777 .806 .877 r
.80842 .38594 .81145 .39 .8184 .38524 .81538 .38116 Mtetra
.782 .807 .873 r
.81538 .38116 .8184 .38524 .82534 .38034 .82234 .37624 Mtetra
.787 .808 .869 r
.82234 .37624 .82534 .38034 .83228 .3753 .82929 .37117 Mtetra
.792 .809 .866 r
.82929 .37117 .83228 .3753 .8392 .37011 .83623 .36596 Mtetra
.797 .81 .862 r
.83623 .36596 .8392 .37011 .84612 .36476 .84316 .36058 Mtetra
0 .09 .583 r
.20764 .49405 .2115 .49769 .21656 .50203 .2127 .4984 Mtetra
0 .134 .626 r
.2127 .4984 .21656 .50203 .22167 .50613 .21782 .50251 Mtetra
0 .179 .667 r
.21782 .50251 .22167 .50613 .22684 .50999 .22298 .50639 Mtetra
0 .222 .705 r
.22298 .50639 .22684 .50999 .23206 .51363 .2282 .51004 Mtetra
0 .263 .741 r
.2282 .51004 .23206 .51363 .23733 .51704 .23347 .51346 Mtetra
0 .303 .773 r
.23347 .51346 .23733 .51704 .24265 .52024 .23879 .51667 Mtetra
0 .341 .803 r
.23879 .51667 .24265 .52024 .24802 .52323 .24415 .51967 Mtetra
0 .377 .829 r
.24415 .51967 .24802 .52323 .25343 .52601 .24956 .52247 Mtetra
0 .411 .852 r
.24956 .52247 .25343 .52601 .25888 .52859 .25502 .52506 Mtetra
.034 .442 .872 r
.25502 .52506 .25888 .52859 .26438 .53098 .26051 .52746 Mtetra
.077 .471 .89 r
.26051 .52746 .26438 .53098 .26991 .53318 .26605 .52966 Mtetra
.117 .497 .905 r
.26605 .52966 .26991 .53318 .27549 .5352 .27163 .53169 Mtetra
.155 .521 .918 r
.27163 .53169 .27549 .5352 .28111 .53703 .27725 .53353 Mtetra
.19 .544 .928 r
.27725 .53353 .28111 .53703 .28677 .53869 .28291 .5352 Mtetra
.223 .564 .937 r
.28291 .5352 .28677 .53869 .29246 .54018 .28861 .5367 Mtetra
.254 .582 .945 r
.28861 .5367 .29246 .54018 .29819 .54151 .29434 .53804 Mtetra
.283 .599 .951 r
.29434 .53804 .29819 .54151 .30395 .54268 .30011 .53921 Mtetra
.31 .615 .955 r
.30011 .53921 .30395 .54268 .30975 .5437 .30591 .54024 Mtetra
.335 .628 .959 r
.30591 .54024 .30975 .5437 .31558 .54457 .31174 .54111 Mtetra
.358 .641 .962 r
.31174 .54111 .31558 .54457 .32144 .54529 .31761 .54184 Mtetra
.38 .653 .964 r
.31761 .54184 .32144 .54529 .32734 .54587 .32351 .54242 Mtetra
.399 .663 .966 r
.32351 .54242 .32734 .54587 .33326 .54632 .32944 .54288 Mtetra
.418 .673 .967 r
.32944 .54288 .33326 .54632 .33921 .54664 .33539 .5432 Mtetra
.435 .681 .967 r
.33539 .5432 .33921 .54664 .34519 .54683 .34138 .54339 Mtetra
.451 .689 .968 r
.34138 .54339 .34519 .54683 .3512 .5469 .34739 .54346 Mtetra
.466 .697 .968 r
.34739 .54346 .3512 .5469 .35724 .54685 .35343 .54342 Mtetra
.48 .703 .967 r
.35343 .54342 .35724 .54685 .3633 .54668 .3595 .54326 Mtetra
.493 .709 .967 r
.3595 .54326 .3633 .54668 .36938 .54641 .3656 .54298 Mtetra
.505 .715 .966 r
.3656 .54298 .36938 .54641 .37549 .54603 .37171 .54261 Mtetra
.516 .72 .965 r
.37171 .54261 .37549 .54603 .38163 .54555 .37786 .54213 Mtetra
.527 .725 .964 r
.37786 .54213 .38163 .54555 .38779 .54497 .38402 .54155 Mtetra
.536 .729 .963 r
.38402 .54155 .38779 .54497 .39397 .54429 .39021 .54087 Mtetra
.545 .733 .962 r
.39021 .54087 .39397 .54429 .40017 .54352 .39642 .5401 Mtetra
.554 .737 .961 r
.39642 .5401 .40017 .54352 .4064 .54267 .40266 .53925 Mtetra
.562 .741 .96 r
.40266 .53925 .4064 .54267 .41265 .54173 .40891 .53831 Mtetra
.569 .744 .959 r
.40891 .53831 .41265 .54173 .41892 .5407 .41519 .53728 Mtetra
.576 .747 .958 r
.41519 .53728 .41892 .5407 .4252 .5396 .42149 .53618 Mtetra
.583 .75 .957 r
.42149 .53618 .4252 .5396 .43151 .53842 .4278 .535 Mtetra
.589 .752 .956 r
.4278 .535 .43151 .53842 .43784 .53717 .43414 .53375 Mtetra
.595 .755 .954 r
.43414 .53375 .43784 .53717 .44419 .53585 .4405 .53242 Mtetra
.6 .757 .953 r
.4405 .53242 .44419 .53585 .45055 .53446 .44687 .53103 Mtetra
.606 .759 .952 r
.44687 .53103 .45055 .53446 .45694 .53301 .45327 .52957 Mtetra
.61 .761 .951 r
.45327 .52957 .45694 .53301 .46334 .53149 .45968 .52805 Mtetra
.615 .763 .95 r
.45968 .52805 .46334 .53149 .46976 .52991 .46611 .52647 Mtetra
.619 .765 .949 r
.46611 .52647 .46976 .52991 .4762 .52828 .47256 .52483 Mtetra
.624 .767 .948 r
.47256 .52483 .4762 .52828 .48266 .52658 .47902 .52313 Mtetra
.627 .768 .947 r
.47902 .52313 .48266 .52658 .48913 .52483 .4855 .52138 Mtetra
.631 .77 .946 r
.4855 .52138 .48913 .52483 .49562 .52303 .492 .51958 Mtetra
.635 .771 .945 r
.492 .51958 .49562 .52303 .50212 .52118 .49852 .51772 Mtetra
.638 .772 .944 r
.49852 .51772 .50212 .52118 .50865 .51928 .50505 .51581 Mtetra
.641 .773 .943 r
.50505 .51581 .50865 .51928 .51519 .51733 .5116 .51385 Mtetra
.644 .775 .943 r
.5116 .51385 .51519 .51733 .52174 .51533 .51817 .51185 Mtetra
.647 .776 .942 r
.51817 .51185 .52174 .51533 .52831 .51328 .52475 .5098 Mtetra
.65 .777 .941 r
.52475 .5098 .52831 .51328 .5349 .5112 .53135 .5077 Mtetra
.653 .778 .94 r
.53135 .5077 .5349 .5112 .5415 .50906 .53796 .50556 Mtetra
.655 .779 .939 r
.53796 .50556 .5415 .50906 .54811 .50689 .54459 .50338 Mtetra
.658 .78 .938 r
.54459 .50338 .54811 .50689 .55475 .50467 .55123 .50116 Mtetra
.66 .781 .938 r
.55123 .50116 .55475 .50467 .56139 .50241 .55789 .49889 Mtetra
.663 .781 .937 r
.55789 .49889 .56139 .50241 .56805 .50011 .56456 .49658 Mtetra
.665 .782 .936 r
.56456 .49658 .56805 .50011 .57473 .49776 .57125 .49423 Mtetra
.668 .783 .935 r
.57125 .49423 .57473 .49776 .58142 .49538 .57795 .49183 Mtetra
.67 .784 .934 r
.57795 .49183 .58142 .49538 .58812 .49296 .58466 .4894 Mtetra
.672 .785 .933 r
.58466 .4894 .58812 .49296 .59484 .49049 .59139 .48692 Mtetra
.675 .785 .933 r
.59139 .48692 .59484 .49049 .60157 .48798 .59814 .4844 Mtetra
.677 .786 .932 r
.59814 .4844 .60157 .48798 .60832 .48543 .6049 .48184 Mtetra
.679 .787 .931 r
.6049 .48184 .60832 .48543 .61508 .48284 .61167 .47924 Mtetra
.682 .787 .93 r
.61167 .47924 .61508 .48284 .62185 .4802 .61845 .47659 Mtetra
.684 .788 .929 r
.61845 .47659 .62185 .4802 .62864 .47752 .62525 .4739 Mtetra
.686 .789 .928 r
.62525 .4739 .62864 .47752 .63544 .4748 .63206 .47117 Mtetra
.689 .789 .927 r
.63206 .47117 .63544 .4748 .64225 .47203 .63889 .46839 Mtetra
.691 .79 .926 r
.63889 .46839 .64225 .47203 .64907 .46921 .64572 .46556 Mtetra
.694 .791 .925 r
.64572 .46556 .64907 .46921 .65591 .46635 .65257 .46268 Mtetra
.696 .791 .924 r
.65257 .46268 .65591 .46635 .66276 .46343 .65943 .45975 Mtetra
.699 .792 .922 r
.65943 .45975 .66276 .46343 .66961 .46046 .6663 .45677 Mtetra
.702 .793 .921 r
.6663 .45677 .66961 .46046 .67648 .45744 .67319 .45373 Mtetra
.705 .793 .92 r
.67319 .45373 .67648 .45744 .68337 .45436 .68008 .45064 Mtetra
.707 .794 .918 r
.68008 .45064 .68337 .45436 .69026 .45122 .68698 .44749 Mtetra
.71 .795 .917 r
.68698 .44749 .69026 .45122 .69716 .44803 .6939 .44427 Mtetra
.713 .795 .915 r
.6939 .44427 .69716 .44803 .70407 .44477 .70082 .441 Mtetra
.717 .796 .914 r
.70082 .441 .70407 .44477 .71099 .44144 .70776 .43766 Mtetra
.72 .797 .912 r
.70776 .43766 .71099 .44144 .71792 .43805 .7147 .43424 Mtetra
.723 .798 .91 r
.7147 .43424 .71792 .43805 .72485 .43458 .72165 .43076 Mtetra
.727 .798 .908 r
.72165 .43076 .72485 .43458 .7318 .43104 .7286 .4272 Mtetra
.73 .799 .906 r
.7286 .4272 .7318 .43104 .73875 .42742 .73557 .42356 Mtetra
.734 .8 .904 r
.73557 .42356 .73875 .42742 .7457 .42371 .74253 .41984 Mtetra
.738 .801 .902 r
.74253 .41984 .7457 .42371 .75266 .41992 .74951 .41603 Mtetra
.742 .801 .9 r
.74951 .41603 .75266 .41992 .75963 .41604 .75649 .41213 Mtetra
.746 .802 .898 r
.75649 .41213 .75963 .41604 .7666 .41206 .76347 .40814 Mtetra
.75 .803 .895 r
.76347 .40814 .7666 .41206 .77357 .40799 .77046 .40404 Mtetra
.754 .804 .892 r
.77046 .40404 .77357 .40799 .78054 .40381 .77744 .39984 Mtetra
.759 .804 .89 r
.77744 .39984 .78054 .40381 .78751 .39952 .78443 .39553 Mtetra
.763 .805 .887 r
.78443 .39553 .78751 .39952 .79448 .39512 .79141 .3911 Mtetra
.768 .806 .884 r
.79141 .3911 .79448 .39512 .80146 .39059 .7984 .38656 Mtetra
.773 .807 .88 r
.7984 .38656 .80146 .39059 .80842 .38594 .80538 .38189 Mtetra
.777 .808 .877 r
.80538 .38189 .80842 .38594 .81538 .38116 .81236 .37708 Mtetra
.782 .808 .873 r
.81236 .37708 .81538 .38116 .82234 .37624 .81933 .37214 Mtetra
.787 .809 .87 r
.81933 .37214 .82234 .37624 .82929 .37117 .82629 .36705 Mtetra
.793 .81 .866 r
.82629 .36705 .82929 .37117 .83623 .36596 .83324 .36181 Mtetra
.798 .811 .862 r
.83324 .36181 .83623 .36596 .84316 .36058 .84019 .35641 Mtetra
0 .09 .584 r
.20378 .49036 .20764 .49405 .2127 .4984 .20883 .49473 Mtetra
0 .134 .627 r
.20883 .49473 .2127 .4984 .21782 .50251 .21395 .49885 Mtetra
0 .178 .668 r
.21395 .49885 .21782 .50251 .22298 .50639 .21911 .50275 Mtetra
0 .221 .706 r
.21911 .50275 .22298 .50639 .2282 .51004 .22433 .50641 Mtetra
0 .262 .741 r
.22433 .50641 .2282 .51004 .23347 .51346 .22959 .50985 Mtetra
0 .302 .773 r
.22959 .50985 .23347 .51346 .23879 .51667 .23491 .51307 Mtetra
0 .34 .802 r
.23491 .51307 .23879 .51667 .24415 .51967 .24027 .51609 Mtetra
0 .376 .828 r
.24027 .51609 .24415 .51967 .24956 .52247 .24568 .51889 Mtetra
0 .409 .851 r
.24568 .51889 .24956 .52247 .25502 .52506 .25114 .5215 Mtetra
.033 .44 .871 r
.25114 .5215 .25502 .52506 .26051 .52746 .25664 .5239 Mtetra
.075 .469 .889 r
.25664 .5239 .26051 .52746 .26605 .52966 .26218 .52612 Mtetra
.115 .495 .904 r
.26218 .52612 .26605 .52966 .27163 .53169 .26776 .52816 Mtetra
.153 .52 .917 r
.26776 .52816 .27163 .53169 .27725 .53353 .27338 .53001 Mtetra
.188 .542 .928 r
.27338 .53001 .27725 .53353 .28291 .5352 .27904 .53169 Mtetra
.221 .562 .937 r
.27904 .53169 .28291 .5352 .28861 .5367 .28474 .5332 Mtetra
.252 .581 .944 r
.28474 .5332 .28861 .5367 .29434 .53804 .29048 .53455 Mtetra
.281 .598 .95 r
.29048 .53455 .29434 .53804 .30011 .53921 .29625 .53573 Mtetra
.307 .613 .955 r
.29625 .53573 .30011 .53921 .30591 .54024 .30205 .53676 Mtetra
.332 .627 .959 r
.30205 .53676 .30591 .54024 .31174 .54111 .30789 .53764 Mtetra
.355 .64 .962 r
.30789 .53764 .31174 .54111 .31761 .54184 .31376 .53838 Mtetra
.377 .652 .964 r
.31376 .53838 .31761 .54184 .32351 .54242 .31966 .53897 Mtetra
.397 .663 .966 r
.31966 .53897 .32351 .54242 .32944 .54288 .3256 .53943 Mtetra
.416 .672 .967 r
.3256 .53943 .32944 .54288 .33539 .5432 .33156 .53976 Mtetra
.433 .681 .968 r
.33156 .53976 .33539 .5432 .34138 .54339 .33755 .53996 Mtetra
.449 .689 .968 r
.33755 .53996 .34138 .54339 .34739 .54346 .34357 .54003 Mtetra
.464 .697 .968 r
.34357 .54003 .34739 .54346 .35343 .54342 .34962 .53999 Mtetra
.478 .704 .968 r
.34962 .53999 .35343 .54342 .3595 .54326 .35569 .53983 Mtetra
.491 .71 .968 r
.35569 .53983 .3595 .54326 .3656 .54298 .36179 .53957 Mtetra
.503 .716 .967 r
.36179 .53957 .3656 .54298 .37171 .54261 .36791 .53919 Mtetra
.514 .721 .966 r
.36791 .53919 .37171 .54261 .37786 .54213 .37406 .53871 Mtetra
.525 .726 .966 r
.37406 .53871 .37786 .54213 .38402 .54155 .38024 .53814 Mtetra
.534 .73 .965 r
.38024 .53814 .38402 .54155 .39021 .54087 .38643 .53746 Mtetra
.544 .735 .964 r
.38643 .53746 .39021 .54087 .39642 .5401 .39265 .5367 Mtetra
.552 .738 .963 r
.39265 .5367 .39642 .5401 .40266 .53925 .3989 .53584 Mtetra
.56 .742 .962 r
.3989 .53584 .40266 .53925 .40891 .53831 .40516 .5349 Mtetra
.568 .745 .96 r
.40516 .5349 .40891 .53831 .41519 .53728 .41144 .53388 Mtetra
.575 .748 .959 r
.41144 .53388 .41519 .53728 .42149 .53618 .41775 .53278 Mtetra
.582 .751 .958 r
.41775 .53278 .42149 .53618 .4278 .535 .42408 .5316 Mtetra
.588 .754 .957 r
.42408 .5316 .4278 .535 .43414 .53375 .43042 .53034 Mtetra
.594 .757 .956 r
.43042 .53034 .43414 .53375 .4405 .53242 .43679 .52902 Mtetra
.599 .759 .955 r
.43679 .52902 .4405 .53242 .44687 .53103 .44317 .52762 Mtetra
.604 .761 .954 r
.44317 .52762 .44687 .53103 .45327 .52957 .44957 .52617 Mtetra
.609 .763 .953 r
.44957 .52617 .45327 .52957 .45968 .52805 .456 .52464 Mtetra
.614 .765 .952 r
.456 .52464 .45968 .52805 .46611 .52647 .46244 .52306 Mtetra
.618 .767 .951 r
.46244 .52306 .46611 .52647 .47256 .52483 .46889 .52141 Mtetra
.623 .769 .95 r
.46889 .52141 .47256 .52483 .47902 .52313 .47537 .51971 Mtetra
.627 .77 .949 r
.47537 .51971 .47902 .52313 .4855 .52138 .48186 .51796 Mtetra
.63 .772 .948 r
.48186 .51796 .4855 .52138 .492 .51958 .48837 .51615 Mtetra
.634 .773 .947 r
.48837 .51615 .492 .51958 .49852 .51772 .4949 .51428 Mtetra
.637 .775 .946 r
.4949 .51428 .49852 .51772 .50505 .51581 .50144 .51237 Mtetra
.641 .776 .945 r
.50144 .51237 .50505 .51581 .5116 .51385 .508 .51041 Mtetra
.644 .777 .945 r
.508 .51041 .5116 .51385 .51817 .51185 .51458 .5084 Mtetra
.647 .778 .944 r
.51458 .5084 .51817 .51185 .52475 .5098 .52117 .50634 Mtetra
.65 .779 .943 r
.52117 .50634 .52475 .5098 .53135 .5077 .52778 .50424 Mtetra
.652 .78 .942 r
.52778 .50424 .53135 .5077 .53796 .50556 .5344 .5021 Mtetra
.655 .781 .941 r
.5344 .5021 .53796 .50556 .54459 .50338 .54104 .49991 Mtetra
.658 .782 .94 r
.54104 .49991 .54459 .50338 .55123 .50116 .5477 .49767 Mtetra
.66 .783 .94 r
.5477 .49767 .55123 .50116 .55789 .49889 .55437 .4954 Mtetra
.663 .784 .939 r
.55437 .4954 .55789 .49889 .56456 .49658 .56105 .49308 Mtetra
.665 .785 .938 r
.56105 .49308 .56456 .49658 .57125 .49423 .56775 .49072 Mtetra
.667 .786 .937 r
.56775 .49072 .57125 .49423 .57795 .49183 .57446 .48832 Mtetra
.67 .787 .936 r
.57446 .48832 .57795 .49183 .58466 .4894 .58119 .48587 Mtetra
.672 .787 .935 r
.58119 .48587 .58466 .4894 .59139 .48692 .58793 .48339 Mtetra
.675 .788 .935 r
.58793 .48339 .59139 .48692 .59814 .4844 .59469 .48086 Mtetra
.677 .789 .934 r
.59469 .48086 .59814 .4844 .6049 .48184 .60146 .47829 Mtetra
.679 .789 .933 r
.60146 .47829 .6049 .48184 .61167 .47924 .60824 .47567 Mtetra
.682 .79 .932 r
.60824 .47567 .61167 .47924 .61845 .47659 .61504 .47302 Mtetra
.684 .791 .931 r
.61504 .47302 .61845 .47659 .62525 .4739 .62185 .47031 Mtetra
.686 .791 .93 r
.62185 .47031 .62525 .4739 .63206 .47117 .62867 .46757 Mtetra
.689 .792 .929 r
.62867 .46757 .63206 .47117 .63889 .46839 .63551 .46477 Mtetra
.691 .793 .928 r
.63551 .46477 .63889 .46839 .64572 .46556 .64236 .46193 Mtetra
.694 .793 .926 r
.64236 .46193 .64572 .46556 .65257 .46268 .64922 .45904 Mtetra
.697 .794 .925 r
.64922 .45904 .65257 .46268 .65943 .45975 .65609 .45609 Mtetra
.699 .795 .924 r
.65609 .45609 .65943 .45975 .6663 .45677 .66298 .4531 Mtetra
.702 .795 .923 r
.66298 .4531 .6663 .45677 .67319 .45373 .66987 .45005 Mtetra
.705 .796 .921 r
.66987 .45005 .67319 .45373 .68008 .45064 .67678 .44694 Mtetra
.708 .797 .92 r
.67678 .44694 .68008 .45064 .68698 .44749 .6837 .44377 Mtetra
.711 .797 .918 r
.6837 .44377 .68698 .44749 .6939 .44427 .69063 .44054 Mtetra
.714 .798 .917 r
.69063 .44054 .6939 .44427 .70082 .441 .69756 .43725 Mtetra
.717 .799 .915 r
.69756 .43725 .70082 .441 .70776 .43766 .70451 .43389 Mtetra
.72 .799 .913 r
.70451 .43389 .70776 .43766 .7147 .43424 .71146 .43046 Mtetra
.724 .8 .912 r
.71146 .43046 .7147 .43424 .72165 .43076 .71843 .42696 Mtetra
.727 .801 .91 r
.71843 .42696 .72165 .43076 .7286 .4272 .7254 .42339 Mtetra
.731 .801 .908 r
.7254 .42339 .7286 .4272 .73557 .42356 .73237 .41973 Mtetra
.735 .802 .906 r
.73237 .41973 .73557 .42356 .74253 .41984 .73936 .41599 Mtetra
.738 .803 .903 r
.73936 .41599 .74253 .41984 .74951 .41603 .74634 .41216 Mtetra
.742 .803 .901 r
.74634 .41216 .74951 .41603 .75649 .41213 .75334 .40824 Mtetra
.746 .804 .899 r
.75334 .40824 .75649 .41213 .76347 .40814 .76033 .40422 Mtetra
.751 .805 .896 r
.76033 .40422 .76347 .40814 .77046 .40404 .76733 .40011 Mtetra
.755 .806 .893 r
.76733 .40011 .77046 .40404 .77744 .39984 .77433 .39588 Mtetra
.759 .806 .89 r
.77433 .39588 .77744 .39984 .78443 .39553 .78133 .39155 Mtetra
.764 .807 .887 r
.78133 .39155 .78443 .39553 .79141 .3911 .78833 .3871 Mtetra
.769 .808 .884 r
.78833 .3871 .79141 .3911 .7984 .38656 .79533 .38253 Mtetra
.773 .808 .881 r
.79533 .38253 .7984 .38656 .80538 .38189 .80232 .37784 Mtetra
.778 .809 .877 r
.80232 .37784 .80538 .38189 .81236 .37708 .80932 .37301 Mtetra
.783 .81 .874 r
.80932 .37301 .81236 .37708 .81933 .37214 .8163 .36804 Mtetra
.788 .81 .87 r
.8163 .36804 .81933 .37214 .82629 .36705 .82328 .36292 Mtetra
.793 .811 .866 r
.82328 .36292 .82629 .36705 .83324 .36181 .83025 .35765 Mtetra
.799 .812 .862 r
.83025 .35765 .83324 .36181 .84019 .35641 .8372 .35223 Mtetra
0 .089 .586 r
.1999 .48663 .20378 .49036 .20883 .49473 .20495 .49101 Mtetra
0 .133 .628 r
.20495 .49101 .20883 .49473 .21395 .49885 .21006 .49515 Mtetra
0 .177 .668 r
.21006 .49515 .21395 .49885 .21911 .50275 .21522 .49906 Mtetra
0 .219 .706 r
.21522 .49906 .21911 .50275 .22433 .50641 .22044 .50274 Mtetra
0 .261 .74 r
.22044 .50274 .22433 .50641 .22959 .50985 .2257 .5062 Mtetra
0 .3 .772 r
.2257 .5062 .22959 .50985 .23491 .51307 .23102 .50944 Mtetra
0 .338 .801 r
.23102 .50944 .23491 .51307 .24027 .51609 .23638 .51247 Mtetra
0 .374 .827 r
.23638 .51247 .24027 .51609 .24568 .51889 .24179 .51529 Mtetra
0 .407 .85 r
.24179 .51529 .24568 .51889 .25114 .5215 .24724 .51791 Mtetra
.031 .438 .87 r
.24724 .51791 .25114 .5215 .25664 .5239 .25274 .52033 Mtetra
.073 .467 .888 r
.25274 .52033 .25664 .5239 .26218 .52612 .25829 .52256 Mtetra
.113 .493 .903 r
.25829 .52256 .26218 .52612 .26776 .52816 .26387 .52461 Mtetra
.15 .518 .916 r
.26387 .52461 .26776 .52816 .27338 .53001 .26949 .52647 Mtetra
.185 .54 .927 r
.26949 .52647 .27338 .53001 .27904 .53169 .27516 .52816 Mtetra
.218 .561 .936 r
.27516 .52816 .27904 .53169 .28474 .5332 .28086 .52969 Mtetra
.249 .579 .943 r
.28086 .52969 .28474 .5332 .29048 .53455 .28659 .53104 Mtetra
.278 .597 .95 r
.28659 .53104 .29048 .53455 .29625 .53573 .29237 .53224 Mtetra
.304 .612 .955 r
.29237 .53224 .29625 .53573 .30205 .53676 .29818 .53328 Mtetra
.329 .626 .959 r
.29818 .53328 .30205 .53676 .30789 .53764 .30402 .53417 Mtetra
.353 .639 .962 r
.30402 .53417 .30789 .53764 .31376 .53838 .30989 .53491 Mtetra
.374 .651 .965 r
.30989 .53491 .31376 .53838 .31966 .53897 .3158 .53552 Mtetra
.394 .662 .966 r
.3158 .53552 .31966 .53897 .3256 .53943 .32174 .53598 Mtetra
.413 .672 .968 r
.32174 .53598 .3256 .53943 .33156 .53976 .32771 .53632 Mtetra
.43 .681 .968 r
.32771 .53632 .33156 .53976 .33755 .53996 .3337 .53652 Mtetra
.446 .689 .969 r
.3337 .53652 .33755 .53996 .34357 .54003 .33973 .53661 Mtetra
.461 .697 .969 r
.33973 .53661 .34357 .54003 .34962 .53999 .34578 .53657 Mtetra
.475 .704 .969 r
.34578 .53657 .34962 .53999 .35569 .53983 .35186 .53642 Mtetra
.488 .71 .969 r
.35186 .53642 .35569 .53983 .36179 .53957 .35797 .53616 Mtetra
.501 .716 .968 r
.35797 .53616 .36179 .53957 .36791 .53919 .3641 .53579 Mtetra
.512 .722 .967 r
.3641 .53579 .36791 .53919 .37406 .53871 .37026 .53531 Mtetra
.523 .727 .967 r
.37026 .53531 .37406 .53871 .38024 .53814 .37644 .53474 Mtetra
.532 .731 .966 r
.37644 .53474 .38024 .53814 .38643 .53746 .38264 .53407 Mtetra
.542 .736 .965 r
.38264 .53407 .38643 .53746 .39265 .5367 .38887 .5333 Mtetra
.55 .74 .964 r
.38887 .5333 .39265 .5367 .3989 .53584 .39512 .53245 Mtetra
.559 .743 .963 r
.39512 .53245 .3989 .53584 .40516 .5349 .40139 .53151 Mtetra
.566 .747 .962 r
.40139 .53151 .40516 .5349 .41144 .53388 .40768 .53049 Mtetra
.573 .75 .961 r
.40768 .53049 .41144 .53388 .41775 .53278 .414 .52939 Mtetra
.58 .753 .96 r
.414 .52939 .41775 .53278 .42408 .5316 .42033 .52821 Mtetra
.586 .756 .959 r
.42033 .52821 .42408 .5316 .43042 .53034 .42669 .52696 Mtetra
.592 .758 .958 r
.42669 .52696 .43042 .53034 .43679 .52902 .43306 .52563 Mtetra
.598 .761 .957 r
.43306 .52563 .43679 .52902 .44317 .52762 .43945 .52424 Mtetra
.603 .763 .956 r
.43945 .52424 .44317 .52762 .44957 .52617 .44587 .52278 Mtetra
.608 .765 .955 r
.44587 .52278 .44957 .52617 .456 .52464 .4523 .52125 Mtetra
.613 .767 .954 r
.4523 .52125 .456 .52464 .46244 .52306 .45875 .51967 Mtetra
.617 .769 .953 r
.45875 .51967 .46244 .52306 .46889 .52141 .46522 .51802 Mtetra
.622 .771 .952 r
.46522 .51802 .46889 .52141 .47537 .51971 .4717 .51632 Mtetra
.626 .773 .951 r
.4717 .51632 .47537 .51971 .48186 .51796 .4782 .51456 Mtetra
.629 .774 .95 r
.4782 .51456 .48186 .51796 .48837 .51615 .48473 .51274 Mtetra
.633 .776 .949 r
.48473 .51274 .48837 .51615 .4949 .51428 .49126 .51088 Mtetra
.636 .777 .948 r
.49126 .51088 .4949 .51428 .50144 .51237 .49782 .50896 Mtetra
.64 .778 .947 r
.49782 .50896 .50144 .51237 .508 .51041 .50439 .50699 Mtetra
.643 .78 .946 r
.50439 .50699 .508 .51041 .51458 .5084 .51097 .50498 Mtetra
.646 .781 .946 r
.51097 .50498 .51458 .5084 .52117 .50634 .51758 .50292 Mtetra
.649 .782 .945 r
.51758 .50292 .52117 .50634 .52778 .50424 .5242 .50081 Mtetra
.652 .783 .944 r
.5242 .50081 .52778 .50424 .5344 .5021 .53083 .49866 Mtetra
.654 .784 .943 r
.53083 .49866 .5344 .5021 .54104 .49991 .53748 .49646 Mtetra
.657 .785 .942 r
.53748 .49646 .54104 .49991 .5477 .49767 .54415 .49422 Mtetra
.66 .786 .941 r
.54415 .49422 .5477 .49767 .55437 .4954 .55083 .49193 Mtetra
.662 .787 .941 r
.55083 .49193 .55437 .4954 .56105 .49308 .55752 .48961 Mtetra
.665 .788 .94 r
.55752 .48961 .56105 .49308 .56775 .49072 .56423 .48724 Mtetra
.667 .789 .939 r
.56423 .48724 .56775 .49072 .57446 .48832 .57096 .48483 Mtetra
.67 .789 .938 r
.57096 .48483 .57446 .48832 .58119 .48587 .5777 .48238 Mtetra
.672 .79 .937 r
.5777 .48238 .58119 .48587 .58793 .48339 .58445 .47988 Mtetra
.674 .791 .936 r
.58445 .47988 .58793 .48339 .59469 .48086 .59122 .47734 Mtetra
.677 .792 .935 r
.59122 .47734 .59469 .48086 .60146 .47829 .59801 .47476 Mtetra
.679 .792 .934 r
.59801 .47476 .60146 .47829 .60824 .47567 .6048 .47214 Mtetra
.682 .793 .934 r
.6048 .47214 .60824 .47567 .61504 .47302 .61161 .46947 Mtetra
.684 .794 .933 r
.61161 .46947 .61504 .47302 .62185 .47031 .61843 .46675 Mtetra
.687 .794 .931 r
.61843 .46675 .62185 .47031 .62867 .46757 .62527 .46399 Mtetra
.689 .795 .93 r
.62527 .46399 .62867 .46757 .63551 .46477 .63212 .46118 Mtetra
.692 .796 .929 r
.63212 .46118 .63551 .46477 .64236 .46193 .63898 .45833 Mtetra
.694 .796 .928 r
.63898 .45833 .64236 .46193 .64922 .45904 .64586 .45542 Mtetra
.697 .797 .927 r
.64586 .45542 .64922 .45904 .65609 .45609 .65274 .45246 Mtetra
.7 .797 .926 r
.65274 .45246 .65609 .45609 .66298 .4531 .65964 .44945 Mtetra
.702 .798 .924 r
.65964 .44945 .66298 .4531 .66987 .45005 .66655 .44639 Mtetra
.705 .799 .923 r
.66655 .44639 .66987 .45005 .67678 .44694 .67347 .44327 Mtetra
.708 .799 .921 r
.67347 .44327 .67678 .44694 .6837 .44377 .6804 .44008 Mtetra
.711 .8 .92 r
.6804 .44008 .6837 .44377 .69063 .44054 .68734 .43684 Mtetra
.714 .8 .918 r
.68734 .43684 .69063 .44054 .69756 .43725 .69429 .43353 Mtetra
.718 .801 .917 r
.69429 .43353 .69756 .43725 .70451 .43389 .70125 .43015 Mtetra
.721 .802 .915 r
.70125 .43015 .70451 .43389 .71146 .43046 .70822 .42671 Mtetra
.724 .802 .913 r
.70822 .42671 .71146 .43046 .71843 .42696 .71519 .42319 Mtetra
.728 .803 .911 r
.71519 .42319 .71843 .42696 .7254 .42339 .72218 .41959 Mtetra
.732 .804 .909 r
.72218 .41959 .7254 .42339 .73237 .41973 .72917 .41591 Mtetra
.735 .804 .907 r
.72917 .41591 .73237 .41973 .73936 .41599 .73616 .41215 Mtetra
.739 .805 .904 r
.73616 .41215 .73936 .41599 .74634 .41216 .74317 .4083 Mtetra
.743 .806 .902 r
.74317 .4083 .74634 .41216 .75334 .40824 .75017 .40436 Mtetra
.747 .806 .899 r
.75017 .40436 .75334 .40824 .76033 .40422 .75718 .40032 Mtetra
.751 .807 .897 r
.75718 .40032 .76033 .40422 .76733 .40011 .76419 .39618 Mtetra
.756 .807 .894 r
.76419 .39618 .76733 .40011 .77433 .39588 .77121 .39194 Mtetra
.76 .808 .891 r
.77121 .39194 .77433 .39588 .78133 .39155 .77822 .38758 Mtetra
.765 .809 .888 r
.77822 .38758 .78133 .39155 .78833 .3871 .78524 .38311 Mtetra
.769 .809 .885 r
.78524 .38311 .78833 .3871 .79533 .38253 .79225 .37851 Mtetra
.774 .81 .881 r
.79225 .37851 .79533 .38253 .80232 .37784 .79926 .37379 Mtetra
.779 .81 .878 r
.79926 .37379 .80232 .37784 .80932 .37301 .80626 .36893 Mtetra
.784 .811 .874 r
.80626 .36893 .80932 .37301 .8163 .36804 .81326 .36394 Mtetra
.789 .812 .87 r
.81326 .36394 .8163 .36804 .82328 .36292 .82025 .35879 Mtetra
.794 .812 .866 r
.82025 .35879 .82328 .36292 .83025 .35765 .82723 .3535 Mtetra
.8 .813 .862 r
.82723 .3535 .83025 .35765 .8372 .35223 .83421 .34804 Mtetra
0 .088 .586 r
.19601 .48284 .1999 .48663 .20495 .49101 .20106 .48724 Mtetra
0 .132 .628 r
.20106 .48724 .20495 .49101 .21006 .49515 .20617 .49141 Mtetra
0 .175 .668 r
.20617 .49141 .21006 .49515 .21522 .49906 .21132 .49534 Mtetra
0 .218 .705 r
.21132 .49534 .21522 .49906 .22044 .50274 .21654 .49904 Mtetra
0 .259 .74 r
.21654 .49904 .22044 .50274 .2257 .5062 .2218 .50251 Mtetra
0 .298 .771 r
.2218 .50251 .2257 .5062 .23102 .50944 .22711 .50577 Mtetra
0 .336 .8 r
.22711 .50577 .23102 .50944 .23638 .51247 .23247 .50881 Mtetra
0 .371 .826 r
.23247 .50881 .23638 .51247 .24179 .51529 .23788 .51165 Mtetra
0 .404 .849 r
.23788 .51165 .24179 .51529 .24724 .51791 .24334 .51429 Mtetra
.029 .435 .869 r
.24334 .51429 .24724 .51791 .25274 .52033 .24884 .51673 Mtetra
.07 .464 .886 r
.24884 .51673 .25274 .52033 .25829 .52256 .25438 .51897 Mtetra
.11 .491 .902 r
.25438 .51897 .25829 .52256 .26387 .52461 .25996 .52104 Mtetra
.147 .515 .915 r
.25996 .52104 .26387 .52461 .26949 .52647 .26559 .52292 Mtetra
.182 .538 .926 r
.26559 .52292 .26949 .52647 .27516 .52816 .27125 .52462 Mtetra
.215 .559 .935 r
.27125 .52462 .27516 .52816 .28086 .52969 .27696 .52616 Mtetra
.246 .578 .943 r
.27696 .52616 .28086 .52969 .28659 .53104 .2827 .52752 Mtetra
.275 .595 .949 r
.2827 .52752 .28659 .53104 .29237 .53224 .28847 .52873 Mtetra
.301 .611 .954 r
.28847 .52873 .29237 .53224 .29818 .53328 .29428 .52978 Mtetra
.326 .625 .959 r
.29428 .52978 .29818 .53328 .30402 .53417 .30013 .53069 Mtetra
.349 .638 .962 r
.30013 .53069 .30402 .53417 .30989 .53491 .30601 .53144 Mtetra
.371 .65 .965 r
.30601 .53144 .30989 .53491 .3158 .53552 .31192 .53205 Mtetra
.391 .661 .967 r
.31192 .53205 .3158 .53552 .32174 .53598 .31786 .53253 Mtetra
.41 .671 .968 r
.31786 .53253 .32174 .53598 .32771 .53632 .32384 .53287 Mtetra
.427 .68 .969 r
.32384 .53287 .32771 .53632 .3337 .53652 .32984 .53309 Mtetra
.444 .689 .969 r
.32984 .53309 .3337 .53652 .33973 .53661 .33587 .53318 Mtetra
.459 .697 .97 r
.33587 .53318 .33973 .53661 .34578 .53657 .34193 .53315 Mtetra
.473 .704 .97 r
.34193 .53315 .34578 .53657 .35186 .53642 .34801 .53301 Mtetra
.486 .71 .969 r
.34801 .53301 .35186 .53642 .35797 .53616 .35413 .53275 Mtetra
.498 .716 .969 r
.35413 .53275 .35797 .53616 .3641 .53579 .36026 .53239 Mtetra
.51 .722 .968 r
.36026 .53239 .3641 .53579 .37026 .53531 .36643 .53192 Mtetra
.52 .727 .968 r
.36643 .53192 .37026 .53531 .37644 .53474 .37262 .53135 Mtetra
.53 .732 .967 r
.37262 .53135 .37644 .53474 .38264 .53407 .37883 .53068 Mtetra
.54 .736 .966 r
.37883 .53068 .38264 .53407 .38887 .5333 .38506 .52992 Mtetra
.548 .741 .965 r
.38506 .52992 .38887 .5333 .39512 .53245 .39132 .52908 Mtetra
.557 .744 .964 r
.39132 .52908 .39512 .53245 .40139 .53151 .3976 .52814 Mtetra
.564 .748 .963 r
.3976 .52814 .40139 .53151 .40768 .53049 .4039 .52712 Mtetra
.572 .751 .962 r
.4039 .52712 .40768 .53049 .414 .52939 .41022 .52602 Mtetra
.578 .754 .961 r
.41022 .52602 .414 .52939 .42033 .52821 .41657 .52484 Mtetra
.585 .757 .96 r
.41657 .52484 .42033 .52821 .42669 .52696 .42293 .52359 Mtetra
.591 .76 .959 r
.42293 .52359 .42669 .52696 .43306 .52563 .42931 .52227 Mtetra
.597 .762 .958 r
.42931 .52227 .43306 .52563 .43945 .52424 .43572 .52087 Mtetra
.602 .765 .957 r
.43572 .52087 .43945 .52424 .44587 .52278 .44214 .51941 Mtetra
.607 .767 .956 r
.44214 .51941 .44587 .52278 .4523 .52125 .44858 .51789 Mtetra
.612 .769 .955 r
.44858 .51789 .4523 .52125 .45875 .51967 .45504 .5163 Mtetra
.616 .771 .954 r
.45504 .5163 .45875 .51967 .46522 .51802 .46152 .51465 Mtetra
.62 .773 .954 r
.46152 .51465 .46522 .51802 .4717 .51632 .46801 .51295 Mtetra
.625 .775 .953 r
.46801 .51295 .4717 .51632 .4782 .51456 .47453 .51118 Mtetra
.628 .776 .952 r
.47453 .51118 .4782 .51456 .48473 .51274 .48106 .50937 Mtetra
.632 .778 .951 r
.48106 .50937 .48473 .51274 .49126 .51088 .48761 .5075 Mtetra
.636 .779 .95 r
.48761 .5075 .49126 .51088 .49782 .50896 .49417 .50558 Mtetra
.639 .781 .949 r
.49417 .50558 .49782 .50896 .50439 .50699 .50075 .5036 Mtetra
.642 .782 .948 r
.50075 .5036 .50439 .50699 .51097 .50498 .50735 .50159 Mtetra
.645 .783 .947 r
.50735 .50159 .51097 .50498 .51758 .50292 .51397 .49952 Mtetra
.648 .784 .947 r
.51397 .49952 .51758 .50292 .5242 .50081 .5206 .4974 Mtetra
.651 .786 .946 r
.5206 .4974 .5242 .50081 .53083 .49866 .52724 .49525 Mtetra
.654 .787 .945 r
.52724 .49525 .53083 .49866 .53748 .49646 .5339 .49304 Mtetra
.657 .788 .944 r
.5339 .49304 .53748 .49646 .54415 .49422 .54058 .49079 Mtetra
.659 .789 .943 r
.54058 .49079 .54415 .49422 .55083 .49193 .54727 .4885 Mtetra
.662 .789 .942 r
.54727 .4885 .55083 .49193 .55752 .48961 .55398 .48617 Mtetra
.664 .79 .942 r
.55398 .48617 .55752 .48961 .56423 .48724 .5607 .48379 Mtetra
.667 .791 .941 r
.5607 .48379 .56423 .48724 .57096 .48483 .56744 .48137 Mtetra
.669 .792 .94 r
.56744 .48137 .57096 .48483 .5777 .48238 .57419 .47891 Mtetra
.672 .793 .939 r
.57419 .47891 .5777 .48238 .58445 .47988 .58096 .4764 Mtetra
.674 .794 .938 r
.58096 .4764 .58445 .47988 .59122 .47734 .58774 .47385 Mtetra
.677 .794 .937 r
.58774 .47385 .59122 .47734 .59801 .47476 .59454 .47126 Mtetra
.679 .795 .936 r
.59454 .47126 .59801 .47476 .6048 .47214 .60135 .46863 Mtetra
.682 .796 .935 r
.60135 .46863 .6048 .47214 .61161 .46947 .60817 .46595 Mtetra
.684 .796 .934 r
.60817 .46595 .61161 .46947 .61843 .46675 .615 .46322 Mtetra
.687 .797 .933 r
.615 .46322 .61843 .46675 .62527 .46399 .62185 .46045 Mtetra
.689 .798 .932 r
.62185 .46045 .62527 .46399 .63212 .46118 .62871 .45763 Mtetra
.692 .798 .931 r
.62871 .45763 .63212 .46118 .63898 .45833 .63559 .45476 Mtetra
.694 .799 .93 r
.63559 .45476 .63898 .45833 .64586 .45542 .64248 .45184 Mtetra
.697 .799 .928 r
.64248 .45184 .64586 .45542 .65274 .45246 .64937 .44886 Mtetra
.7 .8 .927 r
.64937 .44886 .65274 .45246 .65964 .44945 .65629 .44584 Mtetra
.703 .801 .926 r
.65629 .44584 .65964 .44945 .66655 .44639 .66321 .44276 Mtetra
.706 .801 .924 r
.66321 .44276 .66655 .44639 .67347 .44327 .67014 .43962 Mtetra
.709 .802 .923 r
.67014 .43962 .67347 .44327 .6804 .44008 .67709 .43642 Mtetra
.712 .802 .921 r
.67709 .43642 .6804 .44008 .68734 .43684 .68404 .43316 Mtetra
.715 .803 .92 r
.68404 .43316 .68734 .43684 .69429 .43353 .691 .42983 Mtetra
.718 .804 .918 r
.691 .42983 .69429 .43353 .70125 .43015 .69798 .42643 Mtetra
.722 .804 .916 r
.69798 .42643 .70125 .43015 .70822 .42671 .70496 .42297 Mtetra
.725 .805 .914 r
.70496 .42297 .70822 .42671 .71519 .42319 .71195 .41943 Mtetra
.729 .805 .912 r
.71195 .41943 .71519 .42319 .72218 .41959 .71894 .41581 Mtetra
.732 .806 .91 r
.71894 .41581 .72218 .41959 .72917 .41591 .72595 .41211 Mtetra
.736 .806 .908 r
.72595 .41211 .72917 .41591 .73616 .41215 .73296 .40833 Mtetra
.74 .807 .905 r
.73296 .40833 .73616 .41215 .74317 .4083 .73997 .40446 Mtetra
.744 .808 .903 r
.73997 .40446 .74317 .4083 .75017 .40436 .74699 .40049 Mtetra
.748 .808 .9 r
.74699 .40049 .75017 .40436 .75718 .40032 .75402 .39643 Mtetra
.752 .809 .897 r
.75402 .39643 .75718 .40032 .76419 .39618 .76104 .39227 Mtetra
.757 .809 .895 r
.76104 .39227 .76419 .39618 .77121 .39194 .76807 .388 Mtetra
.761 .81 .892 r
.76807 .388 .77121 .39194 .77822 .38758 .7751 .38362 Mtetra
.766 .81 .888 r
.7751 .38362 .77822 .38758 .78524 .38311 .78213 .37912 Mtetra
.77 .811 .885 r
.78213 .37912 .78524 .38311 .79225 .37851 .78915 .37449 Mtetra
.775 .811 .882 r
.78915 .37449 .79225 .37851 .79926 .37379 .79618 .36974 Mtetra
.78 .812 .878 r
.79618 .36974 .79926 .37379 .80626 .36893 .8032 .36486 Mtetra
.785 .812 .874 r
.8032 .36486 .80626 .36893 .81326 .36394 .81021 .35983 Mtetra
.79 .813 .87 r
.81021 .35983 .81326 .36394 .82025 .35879 .81721 .35466 Mtetra
.795 .813 .866 r
.81721 .35466 .82025 .35879 .82723 .3535 .82421 .34933 Mtetra
.8 .814 .862 r
.82421 .34933 .82723 .3535 .83421 .34804 .8312 .34384 Mtetra
0 .087 .587 r
.19212 .479 .19601 .48284 .20106 .48724 .19716 .48343 Mtetra
0 .13 .628 r
.19716 .48343 .20106 .48724 .20617 .49141 .20226 .48762 Mtetra
0 .173 .668 r
.20226 .48762 .20617 .49141 .21132 .49534 .20741 .49157 Mtetra
0 .216 .705 r
.20741 .49157 .21132 .49534 .21654 .49904 .21262 .49529 Mtetra
0 .256 .739 r
.21262 .49529 .21654 .49904 .2218 .50251 .21788 .49879 Mtetra
0 .296 .77 r
.21788 .49879 .2218 .50251 .22711 .50577 .22319 .50206 Mtetra
0 .333 .799 r
.22319 .50206 .22711 .50577 .23247 .50881 .22855 .50513 Mtetra
0 .368 .824 r
.22855 .50513 .23247 .50881 .23788 .51165 .23396 .50799 Mtetra
0 .402 .847 r
.23396 .50799 .23788 .51165 .24334 .51429 .23941 .51064 Mtetra
.026 .433 .867 r
.23941 .51064 .24334 .51429 .24884 .51673 .24491 .5131 Mtetra
.067 .462 .885 r
.24491 .5131 .24884 .51673 .25438 .51897 .25046 .51536 Mtetra
.107 .488 .9 r
.25046 .51536 .25438 .51897 .25996 .52104 .25604 .51744 Mtetra
.144 .513 .913 r
.25604 .51744 .25996 .52104 .26559 .52292 .26167 .51934 Mtetra
.179 .536 .925 r
.26167 .51934 .26559 .52292 .27125 .52462 .26733 .52106 Mtetra
.212 .556 .934 r
.26733 .52106 .27125 .52462 .27696 .52616 .27304 .52261 Mtetra
.242 .575 .942 r
.27304 .52261 .27696 .52616 .2827 .52752 .27878 .52399 Mtetra
.271 .593 .949 r
.27878 .52399 .2827 .52752 .28847 .52873 .28456 .52521 Mtetra
.298 .609 .954 r
.28456 .52521 .28847 .52873 .29428 .52978 .29038 .52628 Mtetra
.323 .623 .958 r
.29038 .52628 .29428 .52978 .30013 .53069 .29623 .52719 Mtetra
.346 .637 .962 r
.29623 .52719 .30013 .53069 .30601 .53144 .30211 .52796 Mtetra
.368 .649 .965 r
.30211 .52796 .30601 .53144 .31192 .53205 .30802 .52859 Mtetra
.388 .66 .967 r
.30802 .52859 .31192 .53205 .31786 .53253 .31397 .52907 Mtetra
.407 .67 .968 r
.31397 .52907 .31786 .53253 .32384 .53287 .31995 .52943 Mtetra
.424 .68 .969 r
.31995 .52943 .32384 .53287 .32984 .53309 .32596 .52965 Mtetra
.441 .689 .97 r
.32596 .52965 .32984 .53309 .33587 .53318 .33199 .52975 Mtetra
.456 .696 .97 r
.33199 .52975 .33587 .53318 .34193 .53315 .33806 .52973 Mtetra
.47 .704 .97 r
.33806 .52973 .34193 .53315 .34801 .53301 .34415 .5296 Mtetra
.483 .71 .97 r
.34415 .5296 .34801 .53301 .35413 .53275 .35027 .52935 Mtetra
.496 .717 .97 r
.35027 .52935 .35413 .53275 .36026 .53239 .35641 .52899 Mtetra
.507 .722 .969 r
.35641 .52899 .36026 .53239 .36643 .53192 .36258 .52853 Mtetra
.518 .728 .969 r
.36258 .52853 .36643 .53192 .37262 .53135 .36878 .52797 Mtetra
.528 .733 .968 r
.36878 .52797 .37262 .53135 .37883 .53068 .375 .52731 Mtetra
.538 .737 .967 r
.375 .52731 .37883 .53068 .38506 .52992 .38124 .52656 Mtetra
.546 .741 .966 r
.38124 .52656 .38506 .52992 .39132 .52908 .3875 .52571 Mtetra
.555 .745 .966 r
.3875 .52571 .39132 .52908 .3976 .52814 .39379 .52478 Mtetra
.563 .749 .965 r
.39379 .52478 .3976 .52814 .4039 .52712 .4001 .52376 Mtetra
.57 .752 .964 r
.4001 .52376 .4039 .52712 .41022 .52602 .40643 .52267 Mtetra
.577 .756 .963 r
.40643 .52267 .41022 .52602 .41657 .52484 .41279 .52149 Mtetra
.583 .759 .962 r
.41279 .52149 .41657 .52484 .42293 .52359 .41916 .52024 Mtetra
.589 .761 .961 r
.41916 .52024 .42293 .52359 .42931 .52227 .42555 .51892 Mtetra
.595 .764 .96 r
.42555 .51892 .42931 .52227 .43572 .52087 .43196 .51753 Mtetra
.6 .767 .959 r
.43196 .51753 .43572 .52087 .44214 .51941 .4384 .51607 Mtetra
.606 .769 .958 r
.4384 .51607 .44214 .51941 .44858 .51789 .44485 .51454 Mtetra
.61 .771 .957 r
.44485 .51454 .44858 .51789 .45504 .5163 .45132 .51295 Mtetra
.615 .773 .956 r
.45132 .51295 .45504 .5163 .46152 .51465 .4578 .51131 Mtetra
.619 .775 .955 r
.4578 .51131 .46152 .51465 .46801 .51295 .46431 .5096 Mtetra
.623 .777 .954 r
.46431 .5096 .46801 .51295 .47453 .51118 .47083 .50783 Mtetra
.627 .778 .953 r
.47083 .50783 .47453 .51118 .48106 .50937 .47738 .50601 Mtetra
.631 .78 .953 r
.47738 .50601 .48106 .50937 .48761 .5075 .48393 .50414 Mtetra
.635 .782 .952 r
.48393 .50414 .48761 .5075 .49417 .50558 .49051 .50222 Mtetra
.638 .783 .951 r
.49051 .50222 .49417 .50558 .50075 .5036 .4971 .50024 Mtetra
.641 .784 .95 r
.4971 .50024 .50075 .5036 .50735 .50159 .50371 .49822 Mtetra
.645 .786 .949 r
.50371 .49822 .50735 .50159 .51397 .49952 .51034 .49615 Mtetra
.648 .787 .948 r
.51034 .49615 .51397 .49952 .5206 .4974 .51698 .49403 Mtetra
.651 .788 .948 r
.51698 .49403 .5206 .4974 .52724 .49525 .52364 .49186 Mtetra
.653 .789 .947 r
.52364 .49186 .52724 .49525 .5339 .49304 .53031 .48965 Mtetra
.656 .79 .946 r
.53031 .48965 .5339 .49304 .54058 .49079 .537 .4874 Mtetra
.659 .791 .945 r
.537 .4874 .54058 .49079 .54727 .4885 .5437 .4851 Mtetra
.661 .792 .944 r
.5437 .4851 .54727 .4885 .55398 .48617 .55042 .48276 Mtetra
.664 .793 .943 r
.55042 .48276 .55398 .48617 .5607 .48379 .55716 .48037 Mtetra
.667 .794 .943 r
.55716 .48037 .5607 .48379 .56744 .48137 .56391 .47794 Mtetra
.669 .795 .942 r
.56391 .47794 .56744 .48137 .57419 .47891 .57067 .47547 Mtetra
.672 .795 .941 r
.57067 .47547 .57419 .47891 .58096 .4764 .57745 .47295 Mtetra
.674 .796 .94 r
.57745 .47295 .58096 .4764 .58774 .47385 .58424 .4704 Mtetra
.677 .797 .939 r
.58424 .4704 .58774 .47385 .59454 .47126 .59105 .46779 Mtetra
.679 .798 .938 r
.59105 .46779 .59454 .47126 .60135 .46863 .59787 .46515 Mtetra
.682 .798 .937 r
.59787 .46515 .60135 .46863 .60817 .46595 .60471 .46245 Mtetra
.684 .799 .936 r
.60471 .46245 .60817 .46595 .615 .46322 .61156 .45971 Mtetra
.687 .8 .935 r
.61156 .45971 .615 .46322 .62185 .46045 .61842 .45693 Mtetra
.689 .8 .934 r
.61842 .45693 .62185 .46045 .62871 .45763 .62529 .45409 Mtetra
.692 .801 .932 r
.62529 .45409 .62871 .45763 .63559 .45476 .63218 .45121 Mtetra
.695 .801 .931 r
.63218 .45121 .63559 .45476 .64248 .45184 .63908 .44828 Mtetra
.697 .802 .93 r
.63908 .44828 .64248 .45184 .64937 .44886 .64599 .44529 Mtetra
.7 .803 .929 r
.64599 .44529 .64937 .44886 .65629 .44584 .65292 .44225 Mtetra
.703 .803 .927 r
.65292 .44225 .65629 .44584 .66321 .44276 .65985 .43915 Mtetra
.706 .804 .926 r
.65985 .43915 .66321 .44276 .67014 .43962 .6668 .43599 Mtetra
.709 .804 .924 r
.6668 .43599 .67014 .43962 .67709 .43642 .67376 .43278 Mtetra
.712 .805 .923 r
.67376 .43278 .67709 .43642 .68404 .43316 .68072 .4295 Mtetra
.715 .805 .921 r
.68072 .4295 .68404 .43316 .691 .42983 .6877 .42615 Mtetra
.719 .806 .919 r
.6877 .42615 .691 .42983 .69798 .42643 .69469 .42274 Mtetra
.722 .806 .917 r
.69469 .42274 .69798 .42643 .70496 .42297 .70168 .41925 Mtetra
.726 .807 .915 r
.70168 .41925 .70496 .42297 .71195 .41943 .70869 .41569 Mtetra
.729 .808 .913 r
.70869 .41569 .71195 .41943 .71894 .41581 .7157 .41205 Mtetra
.733 .808 .911 r
.7157 .41205 .71894 .41581 .72595 .41211 .72272 .40833 Mtetra
.737 .809 .909 r
.72272 .40833 .72595 .41211 .73296 .40833 .72974 .40452 Mtetra
.741 .809 .906 r
.72974 .40452 .73296 .40833 .73997 .40446 .73677 .40063 Mtetra
.745 .81 .904 r
.73677 .40063 .73997 .40446 .74699 .40049 .7438 .39664 Mtetra
.749 .81 .901 r
.7438 .39664 .74699 .40049 .75402 .39643 .75084 .39255 Mtetra
.753 .811 .898 r
.75084 .39255 .75402 .39643 .76104 .39227 .75788 .38836 Mtetra
.758 .811 .895 r
.75788 .38836 .76104 .39227 .76807 .388 .76492 .38407 Mtetra
.762 .811 .892 r
.76492 .38407 .76807 .388 .7751 .38362 .77197 .37966 Mtetra
.767 .812 .889 r
.77197 .37966 .7751 .38362 .78213 .37912 .77901 .37513 Mtetra
.771 .812 .886 r
.77901 .37513 .78213 .37912 .78915 .37449 .78605 .37048 Mtetra
.776 .813 .882 r
.78605 .37048 .78915 .37449 .79618 .36974 .79308 .3657 Mtetra
.781 .813 .878 r
.79308 .3657 .79618 .36974 .8032 .36486 .80012 .36079 Mtetra
.786 .814 .874 r
.80012 .36079 .8032 .36486 .81021 .35983 .80714 .35573 Mtetra
.791 .814 .87 r
.80714 .35573 .81021 .35983 .81721 .35466 .81416 .35052 Mtetra
.796 .814 .866 r
.81416 .35052 .81721 .35466 .82421 .34933 .82117 .34516 Mtetra
.801 .814 .862 r
.82117 .34516 .82421 .34933 .8312 .34384 .82817 .33964 Mtetra
0 .085 .587 r
.1882 .47511 .19212 .479 .19716 .48343 .19324 .47957 Mtetra
0 .128 .628 r
.19324 .47957 .19716 .48343 .20226 .48762 .19834 .48378 Mtetra
0 .171 .667 r
.19834 .48378 .20226 .48762 .20741 .49157 .20349 .48775 Mtetra
0 .213 .704 r
.20349 .48775 .20741 .49157 .21262 .49529 .20869 .4915 Mtetra
0 .254 .738 r
.20869 .4915 .21262 .49529 .21788 .49879 .21395 .49502 Mtetra
0 .293 .769 r
.21395 .49502 .21788 .49879 .22319 .50206 .21926 .49832 Mtetra
0 .33 .797 r
.21926 .49832 .22319 .50206 .22855 .50513 .22462 .50141 Mtetra
0 .365 .823 r
.22462 .50141 .22855 .50513 .23396 .50799 .23002 .50429 Mtetra
0 .399 .846 r
.23002 .50429 .23396 .50799 .23941 .51064 .23548 .50696 Mtetra
.023 .43 .866 r
.23548 .50696 .23941 .51064 .24491 .5131 .24098 .50944 Mtetra
.064 .459 .883 r
.24098 .50944 .24491 .5131 .25046 .51536 .24652 .51172 Mtetra
.103 .485 .899 r
.24652 .51172 .25046 .51536 .25604 .51744 .2521 .51382 Mtetra
.14 .51 .912 r
.2521 .51382 .25604 .51744 .26167 .51934 .25773 .51574 Mtetra
.175 .533 .923 r
.25773 .51574 .26167 .51934 .26733 .52106 .2634 .51748 Mtetra
.208 .554 .933 r
.2634 .51748 .26733 .52106 .27304 .52261 .26911 .51904 Mtetra
.239 .573 .941 r
.26911 .51904 .27304 .52261 .27878 .52399 .27485 .52044 Mtetra
.268 .591 .948 r
.27485 .52044 .27878 .52399 .28456 .52521 .28063 .52168 Mtetra
.294 .607 .953 r
.28063 .52168 .28456 .52521 .29038 .52628 .28645 .52276 Mtetra
.319 .622 .958 r
.28645 .52276 .29038 .52628 .29623 .52719 .2923 .52369 Mtetra
.343 .635 .961 r
.2923 .52369 .29623 .52719 .30211 .52796 .29819 .52447 Mtetra
.364 .648 .964 r
.29819 .52447 .30211 .52796 .30802 .52859 .30411 .52511 Mtetra
.385 .659 .967 r
.30411 .52511 .30802 .52859 .31397 .52907 .31006 .52561 Mtetra
.404 .67 .968 r
.31006 .52561 .31397 .52907 .31995 .52943 .31604 .52598 Mtetra
.421 .679 .97 r
.31604 .52598 .31995 .52943 .32596 .52965 .32205 .52622 Mtetra
.438 .688 .97 r
.32205 .52622 .32596 .52965 .33199 .52975 .3281 .52633 Mtetra
.453 .696 .971 r
.3281 .52633 .33199 .52975 .33806 .52973 .33417 .52632 Mtetra
.467 .704 .971 r
.33417 .52632 .33806 .52973 .34415 .5296 .34026 .52619 Mtetra
.481 .71 .971 r
.34026 .52619 .34415 .5296 .35027 .52935 .34639 .52595 Mtetra
.493 .717 .971 r
.34639 .52595 .35027 .52935 .35641 .52899 .35254 .5256 Mtetra
.505 .723 .97 r
.35254 .5256 .35641 .52899 .36258 .52853 .35872 .52515 Mtetra
.516 .728 .97 r
.35872 .52515 .36258 .52853 .36878 .52797 .36492 .5246 Mtetra
.526 .733 .969 r
.36492 .5246 .36878 .52797 .375 .52731 .37115 .52394 Mtetra
.535 .738 .968 r
.37115 .52394 .375 .52731 .38124 .52656 .3774 .5232 Mtetra
.544 .742 .968 r
.3774 .5232 .38124 .52656 .3875 .52571 .38367 .52236 Mtetra
.553 .746 .967 r
.38367 .52236 .3875 .52571 .39379 .52478 .38997 .52143 Mtetra
.561 .75 .966 r
.38997 .52143 .39379 .52478 .4001 .52376 .39628 .52042 Mtetra
.568 .754 .965 r
.39628 .52042 .4001 .52376 .40643 .52267 .40262 .51933 Mtetra
.575 .757 .964 r
.40262 .51933 .40643 .52267 .41279 .52149 .40899 .51816 Mtetra
.581 .76 .963 r
.40899 .51816 .41279 .52149 .41916 .52024 .41537 .51691 Mtetra
.588 .763 .962 r
.41537 .51691 .41916 .52024 .42555 .51892 .42177 .51559 Mtetra
.593 .766 .961 r
.42177 .51559 .42555 .51892 .43196 .51753 .42819 .5142 Mtetra
.599 .768 .961 r
.42819 .5142 .43196 .51753 .4384 .51607 .43463 .51274 Mtetra
.604 .771 .96 r
.43463 .51274 .4384 .51607 .44485 .51454 .44109 .51122 Mtetra
.609 .773 .959 r
.44109 .51122 .44485 .51454 .45132 .51295 .44757 .50963 Mtetra
.614 .775 .958 r
.44757 .50963 .45132 .51295 .4578 .51131 .45407 .50798 Mtetra
.618 .777 .957 r
.45407 .50798 .4578 .51131 .46431 .5096 .46059 .50627 Mtetra
.622 .779 .956 r
.46059 .50627 .46431 .5096 .47083 .50783 .46712 .50451 Mtetra
.626 .78 .955 r
.46712 .50451 .47083 .50783 .47738 .50601 .47367 .50269 Mtetra
.63 .782 .954 r
.47367 .50269 .47738 .50601 .48393 .50414 .48024 .50081 Mtetra
.634 .784 .953 r
.48024 .50081 .48393 .50414 .49051 .50222 .48683 .49888 Mtetra
.637 .785 .953 r
.48683 .49888 .49051 .50222 .4971 .50024 .49343 .49691 Mtetra
.641 .787 .952 r
.49343 .49691 .4971 .50024 .50371 .49822 .50005 .49488 Mtetra
.644 .788 .951 r
.50005 .49488 .50371 .49822 .51034 .49615 .50669 .4928 Mtetra
.647 .789 .95 r
.50669 .4928 .51034 .49615 .51698 .49403 .51334 .49068 Mtetra
.65 .79 .949 r
.51334 .49068 .51698 .49403 .52364 .49186 .52001 .48851 Mtetra
.653 .791 .949 r
.52001 .48851 .52364 .49186 .53031 .48965 .5267 .48629 Mtetra
.656 .793 .948 r
.5267 .48629 .53031 .48965 .537 .4874 .5334 .48403 Mtetra
.658 .794 .947 r
.5334 .48403 .537 .4874 .5437 .4851 .54012 .48172 Mtetra
.661 .795 .946 r
.54012 .48172 .5437 .4851 .55042 .48276 .54685 .47937 Mtetra
.664 .795 .945 r
.54685 .47937 .55042 .48276 .55716 .48037 .5536 .47698 Mtetra
.666 .796 .944 r
.5536 .47698 .55716 .48037 .56391 .47794 .56036 .47454 Mtetra
.669 .797 .943 r
.56036 .47454 .56391 .47794 .57067 .47547 .56713 .47206 Mtetra
.671 .798 .942 r
.56713 .47206 .57067 .47547 .57745 .47295 .57393 .46953 Mtetra
.674 .799 .942 r
.57393 .46953 .57745 .47295 .58424 .4704 .58073 .46696 Mtetra
.677 .799 .941 r
.58073 .46696 .58424 .4704 .59105 .46779 .58755 .46435 Mtetra
.679 .8 .94 r
.58755 .46435 .59105 .46779 .59787 .46515 .59439 .46169 Mtetra
.682 .801 .939 r
.59439 .46169 .59787 .46515 .60471 .46245 .60123 .45899 Mtetra
.684 .802 .937 r
.60123 .45899 .60471 .46245 .61156 .45971 .6081 .45623 Mtetra
.687 .802 .936 r
.6081 .45623 .61156 .45971 .61842 .45693 .61497 .45344 Mtetra
.689 .803 .935 r
.61497 .45344 .61842 .45693 .62529 .45409 .62186 .45059 Mtetra
.692 .803 .934 r
.62186 .45059 .62529 .45409 .63218 .45121 .62876 .44769 Mtetra
.695 .804 .933 r
.62876 .44769 .63218 .45121 .63908 .44828 .63567 .44474 Mtetra
.698 .805 .931 r
.63567 .44474 .63908 .44828 .64599 .44529 .6426 .44174 Mtetra
.701 .805 .93 r
.6426 .44174 .64599 .44529 .65292 .44225 .64954 .43868 Mtetra
.703 .806 .929 r
.64954 .43868 .65292 .44225 .65985 .43915 .65648 .43556 Mtetra
.707 .806 .927 r
.65648 .43556 .65985 .43915 .6668 .43599 .66344 .43239 Mtetra
.71 .807 .925 r
.66344 .43239 .6668 .43599 .67376 .43278 .67042 .42915 Mtetra
.713 .807 .924 r
.67042 .42915 .67376 .43278 .68072 .4295 .6774 .42585 Mtetra
.716 .808 .922 r
.6774 .42585 .68072 .4295 .6877 .42615 .68439 .42249 Mtetra
.719 .808 .92 r
.68439 .42249 .6877 .42615 .69469 .42274 .69139 .41905 Mtetra
.723 .809 .918 r
.69139 .41905 .69469 .42274 .70168 .41925 .6984 .41555 Mtetra
.726 .809 .916 r
.6984 .41555 .70168 .41925 .70869 .41569 .70541 .41197 Mtetra
.73 .81 .914 r
.70541 .41197 .70869 .41569 .7157 .41205 .71244 .4083 Mtetra
.734 .81 .912 r
.71244 .4083 .7157 .41205 .72272 .40833 .71947 .40456 Mtetra
.738 .811 .909 r
.71947 .40456 .72272 .40833 .72974 .40452 .72651 .40073 Mtetra
.742 .811 .907 r
.72651 .40073 .72974 .40452 .73677 .40063 .73355 .39681 Mtetra
.746 .812 .904 r
.73355 .39681 .73677 .40063 .7438 .39664 .7406 .3928 Mtetra
.75 .812 .902 r
.7406 .3928 .7438 .39664 .75084 .39255 .74765 .38869 Mtetra
.754 .812 .899 r
.74765 .38869 .75084 .39255 .75788 .38836 .7547 .38447 Mtetra
.758 .813 .896 r
.7547 .38447 .75788 .38836 .76492 .38407 .76176 .38014 Mtetra
.763 .813 .893 r
.76176 .38014 .76492 .38407 .77197 .37966 .76882 .37571 Mtetra
.768 .813 .889 r
.76882 .37571 .77197 .37966 .77901 .37513 .77587 .37115 Mtetra
.772 .814 .886 r
.77587 .37115 .77901 .37513 .78605 .37048 .78293 .36647 Mtetra
.777 .814 .882 r
.78293 .36647 .78605 .37048 .79308 .3657 .78998 .36166 Mtetra
.782 .814 .878 r
.78998 .36166 .79308 .3657 .80012 .36079 .79702 .35671 Mtetra
.787 .815 .874 r
.79702 .35671 .80012 .36079 .80714 .35573 .80407 .35162 Mtetra
.792 .815 .87 r
.80407 .35162 .80714 .35573 .81416 .35052 .8111 .34638 Mtetra
.797 .815 .866 r
.8111 .34638 .81416 .35052 .82117 .34516 .81812 .34098 Mtetra
.802 .815 .862 r
.81812 .34098 .82117 .34516 .82817 .33964 .82514 .33543 Mtetra
0 .083 .587 r
.18428 .47117 .1882 .47511 .19324 .47957 .18932 .47565 Mtetra
0 .126 .628 r
.18932 .47565 .19324 .47957 .19834 .48378 .19441 .47989 Mtetra
0 .169 .666 r
.19441 .47989 .19834 .48378 .20349 .48775 .19955 .48389 Mtetra
0 .21 .702 r
.19955 .48389 .20349 .48775 .20869 .4915 .20475 .48767 Mtetra
0 .251 .736 r
.20475 .48767 .20869 .4915 .21395 .49502 .21001 .49121 Mtetra
0 .29 .767 r
.21001 .49121 .21395 .49502 .21926 .49832 .21531 .49454 Mtetra
0 .327 .796 r
.21531 .49454 .21926 .49832 .22462 .50141 .22067 .49765 Mtetra
0 .362 .821 r
.22067 .49765 .22462 .50141 .23002 .50429 .22607 .50055 Mtetra
0 .395 .844 r
.22607 .50055 .23002 .50429 .23548 .50696 .23153 .50325 Mtetra
.02 .426 .864 r
.23153 .50325 .23548 .50696 .24098 .50944 .23702 .50575 Mtetra
.061 .455 .882 r
.23702 .50575 .24098 .50944 .24652 .51172 .24257 .50806 Mtetra
.1 .482 .897 r
.24257 .50806 .24652 .51172 .2521 .51382 .24815 .51018 Mtetra
.137 .507 .911 r
.24815 .51018 .2521 .51382 .25773 .51574 .25378 .51211 Mtetra
.172 .53 .922 r
.25378 .51211 .25773 .51574 .2634 .51748 .25945 .51387 Mtetra
.204 .551 .932 r
.25945 .51387 .2634 .51748 .26911 .51904 .26516 .51546 Mtetra
.235 .571 .94 r
.26516 .51546 .26911 .51904 .27485 .52044 .2709 .51688 Mtetra
.264 .588 .947 r
.2709 .51688 .27485 .52044 .28063 .52168 .27669 .51813 Mtetra
.29 .605 .953 r
.27669 .51813 .28063 .52168 .28645 .52276 .28251 .51923 Mtetra
.316 .62 .957 r
.28251 .51923 .28645 .52276 .2923 .52369 .28836 .52018 Mtetra
.339 .634 .961 r
.28836 .52018 .2923 .52369 .29819 .52447 .29425 .52097 Mtetra
.361 .646 .964 r
.29425 .52097 .29819 .52447 .30411 .52511 .30018 .52163 Mtetra
.381 .658 .967 r
.30018 .52163 .30411 .52511 .31006 .52561 .30613 .52214 Mtetra
.4 .668 .968 r
.30613 .52214 .31006 .52561 .31604 .52598 .31212 .52252 Mtetra
.418 .678 .97 r
.31212 .52252 .31604 .52598 .32205 .52622 .31814 .52277 Mtetra
.434 .687 .971 r
.31814 .52277 .32205 .52622 .3281 .52633 .32418 .5229 Mtetra
.45 .695 .971 r
.32418 .5229 .3281 .52633 .33417 .52632 .33026 .5229 Mtetra
.464 .703 .972 r
.33026 .5229 .33417 .52632 .34026 .52619 .33636 .52279 Mtetra
.478 .71 .972 r
.33636 .52279 .34026 .52619 .34639 .52595 .34249 .52256 Mtetra
.49 .717 .972 r
.34249 .52256 .34639 .52595 .35254 .5256 .34865 .52222 Mtetra
.502 .723 .971 r
.34865 .52222 .35254 .5256 .35872 .52515 .35484 .52178 Mtetra
.513 .728 .971 r
.35484 .52178 .35872 .52515 .36492 .5246 .36105 .52123 Mtetra
.523 .734 .97 r
.36105 .52123 .36492 .5246 .37115 .52394 .36728 .52059 Mtetra
.533 .738 .97 r
.36728 .52059 .37115 .52394 .3774 .5232 .37354 .51985 Mtetra
.542 .743 .969 r
.37354 .51985 .3774 .5232 .38367 .52236 .37982 .51902 Mtetra
.55 .747 .968 r
.37982 .51902 .38367 .52236 .38997 .52143 .38612 .5181 Mtetra
.558 .751 .967 r
.38612 .5181 .38997 .52143 .39628 .52042 .39245 .51709 Mtetra
.566 .755 .966 r
.39245 .51709 .39628 .52042 .40262 .51933 .3988 .516 Mtetra
.573 .758 .966 r
.3988 .516 .40262 .51933 .40899 .51816 .40517 .51484 Mtetra
.58 .761 .965 r
.40517 .51484 .40899 .51816 .41537 .51691 .41156 .5136 Mtetra
.586 .764 .964 r
.41156 .5136 .41537 .51691 .42177 .51559 .41797 .51228 Mtetra
.592 .767 .963 r
.41797 .51228 .42177 .51559 .42819 .5142 .4244 .51089 Mtetra
.597 .77 .962 r
.4244 .51089 .42819 .5142 .43463 .51274 .43085 .50943 Mtetra
.603 .772 .961 r
.43085 .50943 .43463 .51274 .44109 .51122 .43732 .50791 Mtetra
.608 .774 .96 r
.43732 .50791 .44109 .51122 .44757 .50963 .44381 .50633 Mtetra
.612 .777 .959 r
.44381 .50633 .44757 .50963 .45407 .50798 .45032 .50468 Mtetra
.617 .779 .959 r
.45032 .50468 .45407 .50798 .46059 .50627 .45685 .50297 Mtetra
.621 .781 .958 r
.45685 .50297 .46059 .50627 .46712 .50451 .46339 .5012 Mtetra
.625 .782 .957 r
.46339 .5012 .46712 .50451 .47367 .50269 .46995 .49938 Mtetra
.629 .784 .956 r
.46995 .49938 .47367 .50269 .48024 .50081 .47653 .4975 Mtetra
.633 .786 .955 r
.47653 .4975 .48024 .50081 .48683 .49888 .48313 .49557 Mtetra
.636 .787 .954 r
.48313 .49557 .48683 .49888 .49343 .49691 .48975 .49359 Mtetra
.64 .789 .953 r
.48975 .49359 .49343 .49691 .50005 .49488 .49638 .49156 Mtetra
.643 .79 .953 r
.49638 .49156 .50005 .49488 .50669 .4928 .50303 .48948 Mtetra
.646 .791 .952 r
.50303 .48948 .50669 .4928 .51334 .49068 .50969 .48735 Mtetra
.649 .793 .951 r
.50969 .48735 .51334 .49068 .52001 .48851 .51637 .48518 Mtetra
.652 .794 .95 r
.51637 .48518 .52001 .48851 .5267 .48629 .52307 .48295 Mtetra
.655 .795 .949 r
.52307 .48295 .5267 .48629 .5334 .48403 .52978 .48069 Mtetra
.658 .796 .949 r
.52978 .48069 .5334 .48403 .54012 .48172 .53651 .47837 Mtetra
.661 .797 .948 r
.53651 .47837 .54012 .48172 .54685 .47937 .54326 .47601 Mtetra
.663 .798 .947 r
.54326 .47601 .54685 .47937 .5536 .47698 .55002 .47361 Mtetra
.666 .799 .946 r
.55002 .47361 .5536 .47698 .56036 .47454 .55679 .47117 Mtetra
.669 .8 .945 r
.55679 .47117 .56036 .47454 .56713 .47206 .56358 .46868 Mtetra
.671 .8 .944 r
.56358 .46868 .56713 .47206 .57393 .46953 .57038 .46614 Mtetra
.674 .801 .943 r
.57038 .46614 .57393 .46953 .58073 .46696 .5772 .46356 Mtetra
.676 .802 .942 r
.5772 .46356 .58073 .46696 .58755 .46435 .58403 .46093 Mtetra
.679 .803 .941 r
.58403 .46093 .58755 .46435 .59439 .46169 .59088 .45826 Mtetra
.682 .803 .94 r
.59088 .45826 .59439 .46169 .60123 .45899 .59774 .45555 Mtetra
.684 .804 .939 r
.59774 .45555 .60123 .45899 .6081 .45623 .60462 .45278 Mtetra
.687 .805 .938 r
.60462 .45278 .6081 .45623 .61497 .45344 .61151 .44997 Mtetra
.69 .805 .937 r
.61151 .44997 .61497 .45344 .62186 .45059 .61841 .44711 Mtetra
.692 .806 .935 r
.61841 .44711 .62186 .45059 .62876 .44769 .62532 .44419 Mtetra
.695 .807 .934 r
.62532 .44419 .62876 .44769 .63567 .44474 .63225 .44123 Mtetra
.698 .807 .933 r
.63225 .44123 .63567 .44474 .6426 .44174 .63919 .43821 Mtetra
.701 .808 .931 r
.63919 .43821 .6426 .44174 .64954 .43868 .64614 .43513 Mtetra
.704 .808 .93 r
.64614 .43513 .64954 .43868 .65648 .43556 .6531 .432 Mtetra
.707 .809 .928 r
.6531 .432 .65648 .43556 .66344 .43239 .66007 .42881 Mtetra
.71 .809 .927 r
.66007 .42881 .66344 .43239 .67042 .42915 .66706 .42555 Mtetra
.713 .81 .925 r
.66706 .42555 .67042 .42915 .6774 .42585 .67405 .42223 Mtetra
.717 .81 .923 r
.67405 .42223 .6774 .42585 .68439 .42249 .68106 .41885 Mtetra
.72 .811 .921 r
.68106 .41885 .68439 .42249 .69139 .41905 .68807 .41539 Mtetra
.724 .811 .919 r
.68807 .41539 .69139 .41905 .6984 .41555 .6951 .41186 Mtetra
.727 .811 .917 r
.6951 .41186 .6984 .41555 .70541 .41197 .70213 .40826 Mtetra
.731 .812 .915 r
.70213 .40826 .70541 .41197 .71244 .4083 .70916 .40457 Mtetra
.735 .812 .913 r
.70916 .40457 .71244 .4083 .71947 .40456 .71621 .40081 Mtetra
.738 .813 .91 r
.71621 .40081 .71947 .40456 .72651 .40073 .72326 .39695 Mtetra
.742 .813 .908 r
.72326 .39695 .72651 .40073 .73355 .39681 .73032 .39301 Mtetra
.747 .813 .905 r
.73032 .39301 .73355 .39681 .7406 .3928 .73738 .38896 Mtetra
.751 .814 .902 r
.73738 .38896 .7406 .3928 .74765 .38869 .74445 .38482 Mtetra
.755 .814 .899 r
.74445 .38482 .74765 .38869 .7547 .38447 .75152 .38058 Mtetra
.759 .814 .896 r
.75152 .38058 .7547 .38447 .76176 .38014 .75858 .37623 Mtetra
.764 .815 .893 r
.75858 .37623 .76176 .38014 .76882 .37571 .76566 .37176 Mtetra
.769 .815 .889 r
.76566 .37176 .76882 .37571 .77587 .37115 .77273 .36717 Mtetra
.773 .815 .886 r
.77273 .36717 .77587 .37115 .78293 .36647 .77979 .36246 Mtetra
.778 .815 .882 r
.77979 .36246 .78293 .36647 .78998 .36166 .78686 .35761 Mtetra
.783 .816 .878 r
.78686 .35761 .78998 .36166 .79702 .35671 .79392 .35263 Mtetra
.788 .816 .874 r
.79392 .35263 .79702 .35671 .80407 .35162 .80097 .3475 Mtetra
.793 .816 .87 r
.80097 .3475 .80407 .35162 .8111 .34638 .80802 .34223 Mtetra
.798 .816 .866 r
.80802 .34223 .8111 .34638 .81812 .34098 .81506 .3368 Mtetra
.803 .816 .861 r
.81506 .3368 .81812 .34098 .82514 .33543 .82209 .3312 Mtetra
0 .081 .586 r
.18035 .46717 .18428 .47117 .18932 .47565 .18538 .47168 Mtetra
0 .123 .627 r
.18538 .47168 .18932 .47565 .19441 .47989 .19046 .47595 Mtetra
0 .166 .665 r
.19046 .47595 .19441 .47989 .19955 .48389 .1956 .47999 Mtetra
0 .207 .701 r
.1956 .47999 .19955 .48389 .20475 .48767 .2008 .48379 Mtetra
0 .248 .735 r
.2008 .48379 .20475 .48767 .21001 .49121 .20605 .48736 Mtetra
0 .286 .765 r
.20605 .48736 .21001 .49121 .21531 .49454 .21135 .49071 Mtetra
0 .323 .794 r
.21135 .49071 .21531 .49454 .22067 .49765 .21671 .49385 Mtetra
0 .359 .819 r
.21671 .49385 .22067 .49765 .22607 .50055 .22211 .49678 Mtetra
0 .392 .842 r
.22211 .49678 .22607 .50055 .23153 .50325 .22756 .4995 Mtetra
.016 .423 .862 r
.22756 .4995 .23153 .50325 .23702 .50575 .23306 .50203 Mtetra
.057 .452 .88 r
.23306 .50203 .23702 .50575 .24257 .50806 .2386 .50436 Mtetra
.096 .479 .895 r
.2386 .50436 .24257 .50806 .24815 .51018 .24418 .5065 Mtetra
.133 .504 .909 r
.24418 .5065 .24815 .51018 .25378 .51211 .24981 .50846 Mtetra
.167 .527 .921 r
.24981 .50846 .25378 .51211 .25945 .51387 .25548 .51024 Mtetra
.2 .548 .93 r
.25548 .51024 .25945 .51387 .26516 .51546 .26119 .51185 Mtetra
.231 .568 .939 r
.26119 .51185 .26516 .51546 .2709 .51688 .26694 .51329 Mtetra
.26 .586 .946 r
.26694 .51329 .2709 .51688 .27669 .51813 .27273 .51456 Mtetra
.286 .602 .952 r
.27273 .51456 .27669 .51813 .28251 .51923 .27855 .51568 Mtetra
.312 .618 .957 r
.27855 .51568 .28251 .51923 .28836 .52018 .28441 .51665 Mtetra
.335 .632 .961 r
.28441 .51665 .28836 .52018 .29425 .52097 .2903 .51746 Mtetra
.357 .644 .964 r
.2903 .51746 .29425 .52097 .30018 .52163 .29623 .51813 Mtetra
.377 .656 .966 r
.29623 .51813 .30018 .52163 .30613 .52214 .30219 .51866 Mtetra
.397 .667 .968 r
.30219 .51866 .30613 .52214 .31212 .52252 .30818 .51906 Mtetra
.414 .677 .97 r
.30818 .51906 .31212 .52252 .31814 .52277 .3142 .51933 Mtetra
.431 .686 .971 r
.3142 .51933 .31814 .52277 .32418 .5229 .32025 .51947 Mtetra
.447 .695 .972 r
.32025 .51947 .32418 .5229 .33026 .5229 .32633 .51948 Mtetra
.461 .703 .972 r
.32633 .51948 .33026 .5229 .33636 .52279 .33244 .51938 Mtetra
.475 .71 .972 r
.33244 .51938 .33636 .52279 .34249 .52256 .33858 .51916 Mtetra
.487 .717 .972 r
.33858 .51916 .34249 .52256 .34865 .52222 .34474 .51884 Mtetra
.499 .723 .972 r
.34474 .51884 .34865 .52222 .35484 .52178 .35094 .51841 Mtetra
.51 .728 .972 r
.35094 .51841 .35484 .52178 .36105 .52123 .35715 .51787 Mtetra
.521 .734 .971 r
.35715 .51787 .36105 .52123 .36728 .52059 .36339 .51724 Mtetra
.53 .739 .971 r
.36339 .51724 .36728 .52059 .37354 .51985 .36966 .51651 Mtetra
.54 .743 .97 r
.36966 .51651 .37354 .51985 .37982 .51902 .37595 .51568 Mtetra
.548 .748 .969 r
.37595 .51568 .37982 .51902 .38612 .5181 .38226 .51477 Mtetra
.556 .752 .969 r
.38226 .51477 .38612 .5181 .39245 .51709 .38859 .51377 Mtetra
.564 .756 .968 r
.38859 .51377 .39245 .51709 .3988 .516 .39495 .51269 Mtetra
.571 .759 .967 r
.39495 .51269 .3988 .516 .40517 .51484 .40133 .51153 Mtetra
.578 .762 .966 r
.40133 .51153 .40517 .51484 .41156 .5136 .40773 .51029 Mtetra
.584 .765 .965 r
.40773 .51029 .41156 .5136 .41797 .51228 .41415 .50898 Mtetra
.59 .768 .964 r
.41415 .50898 .41797 .51228 .4244 .51089 .42059 .5076 Mtetra
.596 .771 .964 r
.42059 .5076 .4244 .51089 .43085 .50943 .42705 .50614 Mtetra
.601 .774 .963 r
.42705 .50614 .43085 .50943 .43732 .50791 .43353 .50462 Mtetra
.606 .776 .962 r
.43353 .50462 .43732 .50791 .44381 .50633 .44003 .50304 Mtetra
.611 .778 .961 r
.44003 .50304 .44381 .50633 .45032 .50468 .44655 .50139 Mtetra
.615 .78 .96 r
.44655 .50139 .45032 .50468 .45685 .50297 .45309 .49968 Mtetra
.62 .782 .959 r
.45309 .49968 .45685 .50297 .46339 .5012 .45964 .49792 Mtetra
.624 .784 .958 r
.45964 .49792 .46339 .5012 .46995 .49938 .46622 .4961 Mtetra
.628 .786 .958 r
.46622 .4961 .46995 .49938 .47653 .4975 .47281 .49422 Mtetra
.632 .788 .957 r
.47281 .49422 .47653 .4975 .48313 .49557 .47942 .49229 Mtetra
.635 .789 .956 r
.47942 .49229 .48313 .49557 .48975 .49359 .48604 .4903 Mtetra
.639 .791 .955 r
.48604 .4903 .48975 .49359 .49638 .49156 .49269 .48827 Mtetra
.642 .792 .954 r
.49269 .48827 .49638 .49156 .50303 .48948 .49935 .48618 Mtetra
.645 .794 .953 r
.49935 .48618 .50303 .48948 .50969 .48735 .50602 .48405 Mtetra
.648 .795 .953 r
.50602 .48405 .50969 .48735 .51637 .48518 .51271 .48187 Mtetra
.651 .796 .952 r
.51271 .48187 .51637 .48518 .52307 .48295 .51942 .47964 Mtetra
.654 .797 .951 r
.51942 .47964 .52307 .48295 .52978 .48069 .52615 .47737 Mtetra
.657 .798 .95 r
.52615 .47737 .52978 .48069 .53651 .47837 .53289 .47505 Mtetra
.66 .799 .949 r
.53289 .47505 .53651 .47837 .54326 .47601 .53965 .47268 Mtetra
.663 .8 .948 r
.53965 .47268 .54326 .47601 .55002 .47361 .54642 .47027 Mtetra
.666 .801 .948 r
.54642 .47027 .55002 .47361 .55679 .47117 .55321 .46782 Mtetra
.668 .802 .947 r
.55321 .46782 .55679 .47117 .56358 .46868 .56001 .46532 Mtetra
.671 .803 .946 r
.56001 .46532 .56358 .46868 .57038 .46614 .56682 .46277 Mtetra
.674 .804 .945 r
.56682 .46277 .57038 .46614 .5772 .46356 .57366 .46018 Mtetra
.676 .804 .944 r
.57366 .46018 .5772 .46356 .58403 .46093 .5805 .45754 Mtetra
.679 .805 .943 r
.5805 .45754 .58403 .46093 .59088 .45826 .58736 .45486 Mtetra
.682 .806 .942 r
.58736 .45486 .59088 .45826 .59774 .45555 .59424 .45213 Mtetra
.684 .807 .94 r
.59424 .45213 .59774 .45555 .60462 .45278 .60112 .44935 Mtetra
.687 .807 .939 r
.60112 .44935 .60462 .45278 .61151 .44997 .60802 .44652 Mtetra
.69 .808 .938 r
.60802 .44652 .61151 .44997 .61841 .44711 .61494 .44365 Mtetra
.693 .808 .937 r
.61494 .44365 .61841 .44711 .62532 .44419 .62187 .44072 Mtetra
.695 .809 .935 r
.62187 .44072 .62532 .44419 .63225 .44123 .62881 .43774 Mtetra
.698 .809 .934 r
.62881 .43774 .63225 .44123 .63919 .43821 .63576 .4347 Mtetra
.701 .81 .933 r
.63576 .4347 .63919 .43821 .64614 .43513 .64272 .43161 Mtetra
.704 .81 .931 r
.64272 .43161 .64614 .43513 .6531 .432 .6497 .42846 Mtetra
.707 .811 .929 r
.6497 .42846 .6531 .432 .66007 .42881 .65669 .42524 Mtetra
.711 .811 .928 r
.65669 .42524 .66007 .42881 .66706 .42555 .66369 .42197 Mtetra
.714 .812 .926 r
.66369 .42197 .66706 .42555 .67405 .42223 .6707 .41863 Mtetra
.717 .812 .924 r
.6707 .41863 .67405 .42223 .68106 .41885 .67771 .41522 Mtetra
.721 .813 .922 r
.67771 .41522 .68106 .41885 .68807 .41539 .68474 .41175 Mtetra
.724 .813 .92 r
.68474 .41175 .68807 .41539 .6951 .41186 .69178 .40819 Mtetra
.728 .814 .918 r
.69178 .40819 .6951 .41186 .70213 .40826 .69882 .40456 Mtetra
.732 .814 .916 r
.69882 .40456 .70213 .40826 .70916 .40457 .70588 .40086 Mtetra
.735 .814 .913 r
.70588 .40086 .70916 .40457 .71621 .40081 .71294 .39706 Mtetra
.739 .815 .911 r
.71294 .39706 .71621 .40081 .72326 .39695 .72 .39318 Mtetra
.743 .815 .908 r
.72 .39318 .72326 .39695 .73032 .39301 .72707 .38921 Mtetra
.748 .815 .905 r
.72707 .38921 .73032 .39301 .73738 .38896 .73415 .38514 Mtetra
.752 .815 .903 r
.73415 .38514 .73738 .38896 .74445 .38482 .74123 .38097 Mtetra
.756 .816 .9 r
.74123 .38097 .74445 .38482 .75152 .38058 .74831 .37669 Mtetra
.76 .816 .896 r
.74831 .37669 .75152 .38058 .75858 .37623 .7554 .37231 Mtetra
.765 .816 .893 r
.7554 .37231 .75858 .37623 .76566 .37176 .76248 .36781 Mtetra
.77 .816 .89 r
.76248 .36781 .76566 .37176 .77273 .36717 .76956 .36319 Mtetra
.774 .816 .886 r
.76956 .36319 .77273 .36717 .77979 .36246 .77665 .35844 Mtetra
.779 .817 .882 r
.77665 .35844 .77979 .36246 .78686 .35761 .78372 .35356 Mtetra
.784 .817 .878 r
.78372 .35356 .78686 .35761 .79392 .35263 .7908 .34854 Mtetra
.789 .817 .874 r
.7908 .34854 .79392 .35263 .80097 .3475 .79787 .34338 Mtetra
.794 .817 .87 r
.79787 .34338 .80097 .3475 .80802 .34223 .80493 .33807 Mtetra
.799 .817 .866 r
.80493 .33807 .80802 .34223 .81506 .3368 .81198 .3326 Mtetra
.804 .817 .861 r
.81198 .3326 .81506 .3368 .82209 .3312 .81902 .32696 Mtetra
0 .078 .586 r
.17641 .46312 .18035 .46717 .18538 .47168 .18143 .46766 Mtetra
0 .121 .626 r
.18143 .46766 .18538 .47168 .19046 .47595 .18651 .47196 Mtetra
0 .163 .664 r
.18651 .47196 .19046 .47595 .1956 .47999 .19164 .47603 Mtetra
0 .204 .699 r
.19164 .47603 .1956 .47999 .2008 .48379 .19684 .47986 Mtetra
0 .244 .733 r
.19684 .47986 .2008 .48379 .20605 .48736 .20208 .48346 Mtetra
0 .283 .763 r
.20208 .48346 .20605 .48736 .21135 .49071 .20738 .48685 Mtetra
0 .319 .791 r
.20738 .48685 .21135 .49071 .21671 .49385 .21273 .49002 Mtetra
0 .355 .817 r
.21273 .49002 .21671 .49385 .22211 .49678 .21813 .49297 Mtetra
0 .388 .84 r
.21813 .49297 .22211 .49678 .22756 .4995 .22358 .49572 Mtetra
.012 .419 .86 r
.22358 .49572 .22756 .4995 .23306 .50203 .22907 .49828 Mtetra
.053 .448 .878 r
.22907 .49828 .23306 .50203 .2386 .50436 .23462 .50063 Mtetra
.092 .475 .893 r
.23462 .50063 .2386 .50436 .24418 .5065 .2402 .5028 Mtetra
.129 .5 .907 r
.2402 .5028 .24418 .5065 .24981 .50846 .24583 .50478 Mtetra
.163 .524 .919 r
.24583 .50478 .24981 .50846 .25548 .51024 .2515 .50659 Mtetra
.196 .545 .929 r
.2515 .50659 .25548 .51024 .26119 .51185 .25721 .50822 Mtetra
.227 .565 .938 r
.25721 .50822 .26119 .51185 .26694 .51329 .26296 .50968 Mtetra
.255 .583 .945 r
.26296 .50968 .26694 .51329 .27273 .51456 .26875 .51098 Mtetra
.282 .6 .951 r
.26875 .51098 .27273 .51456 .27855 .51568 .27457 .51212 Mtetra
.307 .615 .956 r
.27457 .51212 .27855 .51568 .28441 .51665 .28043 .5131 Mtetra
.331 .629 .96 r
.28043 .5131 .28441 .51665 .2903 .51746 .28633 .51394 Mtetra
.353 .643 .964 r
.28633 .51394 .2903 .51746 .29623 .51813 .29226 .51463 Mtetra
.374 .655 .966 r
.29226 .51463 .29623 .51813 .30219 .51866 .29822 .51518 Mtetra
.393 .666 .968 r
.29822 .51518 .30219 .51866 .30818 .51906 .30422 .51559 Mtetra
.411 .676 .97 r
.30422 .51559 .30818 .51906 .3142 .51933 .31025 .51587 Mtetra
.427 .685 .971 r
.31025 .51587 .3142 .51933 .32025 .51947 .3163 .51603 Mtetra
.443 .694 .972 r
.3163 .51603 .32025 .51947 .32633 .51948 .32239 .51606 Mtetra
.458 .702 .973 r
.32239 .51606 .32633 .51948 .33244 .51938 .3285 .51597 Mtetra
.471 .709 .973 r
.3285 .51597 .33244 .51938 .33858 .51916 .33465 .51577 Mtetra
.484 .716 .973 r
.33465 .51577 .33858 .51916 .34474 .51884 .34082 .51546 Mtetra
.496 .722 .973 r
.34082 .51546 .34474 .51884 .35094 .51841 .34702 .51504 Mtetra
.507 .728 .973 r
.34702 .51504 .35094 .51841 .35715 .51787 .35324 .51451 Mtetra
.518 .734 .972 r
.35324 .51451 .35715 .51787 .36339 .51724 .35949 .51389 Mtetra
.528 .739 .972 r
.35949 .51389 .36339 .51724 .36966 .51651 .36576 .51317 Mtetra
.537 .744 .971 r
.36576 .51317 .36966 .51651 .37595 .51568 .37206 .51236 Mtetra
.546 .748 .97 r
.37206 .51236 .37595 .51568 .38226 .51477 .37838 .51145 Mtetra
.554 .752 .97 r
.37838 .51145 .38226 .51477 .38859 .51377 .38472 .51046 Mtetra
.562 .756 .969 r
.38472 .51046 .38859 .51377 .39495 .51269 .39109 .50939 Mtetra
.569 .76 .968 r
.39109 .50939 .39495 .51269 .40133 .51153 .39747 .50824 Mtetra
.576 .763 .967 r
.39747 .50824 .40133 .51153 .40773 .51029 .40388 .507 Mtetra
.582 .766 .967 r
.40388 .507 .40773 .51029 .41415 .50898 .41031 .5057 Mtetra
.588 .769 .966 r
.41031 .5057 .41415 .50898 .42059 .5076 .41676 .50432 Mtetra
.594 .772 .965 r
.41676 .50432 .42059 .5076 .42705 .50614 .42323 .50287 Mtetra
.599 .775 .964 r
.42323 .50287 .42705 .50614 .43353 .50462 .42972 .50135 Mtetra
.605 .777 .963 r
.42972 .50135 .43353 .50462 .44003 .50304 .43623 .49977 Mtetra
.609 .78 .962 r
.43623 .49977 .44003 .50304 .44655 .50139 .44276 .49813 Mtetra
.614 .782 .962 r
.44276 .49813 .44655 .50139 .45309 .49968 .44931 .49642 Mtetra
.618 .784 .961 r
.44931 .49642 .45309 .49968 .45964 .49792 .45588 .49465 Mtetra
.623 .786 .96 r
.45588 .49465 .45964 .49792 .46622 .4961 .46246 .49283 Mtetra
.627 .788 .959 r
.46246 .49283 .46622 .4961 .47281 .49422 .46906 .49095 Mtetra
.631 .79 .958 r
.46906 .49095 .47281 .49422 .47942 .49229 .47568 .48902 Mtetra
.634 .791 .958 r
.47568 .48902 .47942 .49229 .48604 .4903 .48232 .48703 Mtetra
.638 .793 .957 r
.48232 .48703 .48604 .4903 .49269 .48827 .48897 .485 Mtetra
.641 .794 .956 r
.48897 .485 .49269 .48827 .49935 .48618 .49565 .48291 Mtetra
.644 .796 .955 r
.49565 .48291 .49935 .48618 .50602 .48405 .50233 .48077 Mtetra
.648 .797 .954 r
.50233 .48077 .50602 .48405 .51271 .48187 .50904 .47858 Mtetra
.651 .798 .953 r
.50904 .47858 .51271 .48187 .51942 .47964 .51576 .47635 Mtetra
.654 .799 .953 r
.51576 .47635 .51942 .47964 .52615 .47737 .5225 .47407 Mtetra
.657 .8 .952 r
.5225 .47407 .52615 .47737 .53289 .47505 .52925 .47174 Mtetra
.66 .802 .951 r
.52925 .47174 .53289 .47505 .53965 .47268 .53602 .46937 Mtetra
.662 .803 .95 r
.53602 .46937 .53965 .47268 .54642 .47027 .5428 .46695 Mtetra
.665 .803 .949 r
.5428 .46695 .54642 .47027 .55321 .46782 .5496 .46449 Mtetra
.668 .804 .948 r
.5496 .46449 .55321 .46782 .56001 .46532 .55642 .46198 Mtetra
.671 .805 .947 r
.55642 .46198 .56001 .46532 .56682 .46277 .56325 .45942 Mtetra
.673 .806 .946 r
.56325 .45942 .56682 .46277 .57366 .46018 .57009 .45682 Mtetra
.676 .807 .945 r
.57009 .45682 .57366 .46018 .5805 .45754 .57695 .45417 Mtetra
.679 .808 .944 r
.57695 .45417 .5805 .45754 .58736 .45486 .58382 .45148 Mtetra
.682 .808 .943 r
.58382 .45148 .58736 .45486 .59424 .45213 .59071 .44874 Mtetra
.684 .809 .942 r
.59071 .44874 .59424 .45213 .60112 .44935 .59761 .44594 Mtetra
.687 .81 .941 r
.59761 .44594 .60112 .44935 .60802 .44652 .60453 .4431 Mtetra
.69 .81 .939 r
.60453 .4431 .60802 .44652 .61494 .44365 .61146 .44021 Mtetra
.693 .811 .938 r
.61146 .44021 .61494 .44365 .62187 .44072 .6184 .43726 Mtetra
.696 .811 .937 r
.6184 .43726 .62187 .44072 .62881 .43774 .62535 .43427 Mtetra
.699 .812 .935 r
.62535 .43427 .62881 .43774 .63576 .4347 .63232 .43121 Mtetra
.702 .812 .934 r
.63232 .43121 .63576 .4347 .64272 .43161 .6393 .4281 Mtetra
.705 .813 .932 r
.6393 .4281 .64272 .43161 .6497 .42846 .64629 .42493 Mtetra
.708 .813 .93 r
.64629 .42493 .6497 .42846 .65669 .42524 .65329 .4217 Mtetra
.711 .814 .929 r
.65329 .4217 .65669 .42524 .66369 .42197 .6603 .41841 Mtetra
.715 .814 .927 r
.6603 .41841 .66369 .42197 .6707 .41863 .66732 .41504 Mtetra
.718 .814 .925 r
.66732 .41504 .6707 .41863 .67771 .41522 .67435 .41161 Mtetra
.721 .815 .923 r
.67435 .41161 .67771 .41522 .68474 .41175 .6814 .40811 Mtetra
.725 .815 .921 r
.6814 .40811 .68474 .41175 .69178 .40819 .68845 .40454 Mtetra
.729 .816 .919 r
.68845 .40454 .69178 .40819 .69882 .40456 .69551 .40088 Mtetra
.732 .816 .916 r
.69551 .40088 .69882 .40456 .70588 .40086 .70257 .39715 Mtetra
.736 .816 .914 r
.70257 .39715 .70588 .40086 .71294 .39706 .70965 .39333 Mtetra
.74 .816 .911 r
.70965 .39333 .71294 .39706 .72 .39318 .71673 .38942 Mtetra
.744 .817 .909 r
.71673 .38942 .72 .39318 .72707 .38921 .72381 .38542 Mtetra
.749 .817 .906 r
.72381 .38542 .72707 .38921 .73415 .38514 .7309 .38132 Mtetra
.753 .817 .903 r
.7309 .38132 .73415 .38514 .74123 .38097 .738 .37712 Mtetra
.757 .817 .9 r
.738 .37712 .74123 .38097 .74831 .37669 .74509 .37281 Mtetra
.762 .817 .897 r
.74509 .37281 .74831 .37669 .7554 .37231 .75219 .3684 Mtetra
.766 .818 .893 r
.75219 .3684 .7554 .37231 .76248 .36781 .75929 .36386 Mtetra
.771 .818 .89 r
.75929 .36386 .76248 .36781 .76956 .36319 .76639 .35921 Mtetra
.775 .818 .886 r
.76639 .35921 .76956 .36319 .77665 .35844 .77348 .35442 Mtetra
.78 .818 .882 r
.77348 .35442 .77665 .35844 .78372 .35356 .78058 .34951 Mtetra
.785 .818 .878 r
.78058 .34951 .78372 .35356 .7908 .34854 .78767 .34445 Mtetra
.79 .818 .874 r
.78767 .34445 .7908 .34854 .79787 .34338 .79475 .33925 Mtetra
.795 .818 .87 r
.79475 .33925 .79787 .34338 .80493 .33807 .80182 .3339 Mtetra
.8 .817 .865 r
.80182 .3339 .80493 .33807 .81198 .3326 .80889 .32838 Mtetra
.805 .817 .86 r
.80889 .32838 .81198 .3326 .81902 .32696 .81594 .3227 Mtetra
0 .075 .585 r
.17245 .459 .17641 .46312 .18143 .46766 .17747 .46358 Mtetra
0 .117 .624 r
.17747 .46358 .18143 .46766 .18651 .47196 .18254 .46792 Mtetra
0 .159 .662 r
.18254 .46792 .18651 .47196 .19164 .47603 .18767 .47202 Mtetra
0 .2 .697 r
.18767 .47202 .19164 .47603 .19684 .47986 .19286 .47588 Mtetra
0 .24 .73 r
.19286 .47588 .19684 .47986 .20208 .48346 .1981 .47952 Mtetra
0 .278 .761 r
.1981 .47952 .20208 .48346 .20738 .48685 .20339 .48294 Mtetra
0 .315 .789 r
.20339 .48294 .20738 .48685 .21273 .49002 .20874 .48614 Mtetra
0 .35 .814 r
.20874 .48614 .21273 .49002 .21813 .49297 .21414 .48912 Mtetra
0 .384 .837 r
.21414 .48912 .21813 .49297 .22358 .49572 .21958 .4919 Mtetra
.008 .415 .858 r
.21958 .4919 .22358 .49572 .22907 .49828 .22508 .49449 Mtetra
.049 .444 .876 r
.22508 .49449 .22907 .49828 .23462 .50063 .23062 .49687 Mtetra
.087 .471 .891 r
.23062 .49687 .23462 .50063 .2402 .5028 .2362 .49907 Mtetra
.124 .496 .905 r
.2362 .49907 .2402 .5028 .24583 .50478 .24183 .50108 Mtetra
.159 .52 .917 r
.24183 .50108 .24583 .50478 .2515 .50659 .2475 .50291 Mtetra
.191 .542 .927 r
.2475 .50291 .2515 .50659 .25721 .50822 .25321 .50456 Mtetra
.222 .562 .936 r
.25321 .50456 .25721 .50822 .26296 .50968 .25896 .50605 Mtetra
.251 .58 .944 r
.25896 .50605 .26296 .50968 .26875 .51098 .26475 .50737 Mtetra
.278 .597 .95 r
.26475 .50737 .26875 .51098 .27457 .51212 .27058 .50853 Mtetra
.303 .613 .955 r
.27058 .50853 .27457 .51212 .28043 .5131 .27644 .50954 Mtetra
.327 .627 .96 r
.27644 .50954 .28043 .5131 .28633 .51394 .28234 .5104 Mtetra
.349 .64 .963 r
.28234 .5104 .28633 .51394 .29226 .51463 .28828 .51111 Mtetra
.369 .653 .966 r
.28828 .51111 .29226 .51463 .29822 .51518 .29424 .51168 Mtetra
.389 .664 .968 r
.29424 .51168 .29822 .51518 .30422 .51559 .30024 .51211 Mtetra
.407 .674 .97 r
.30024 .51211 .30422 .51559 .31025 .51587 .30627 .51241 Mtetra
.424 .684 .971 r
.30627 .51241 .31025 .51587 .3163 .51603 .31234 .51258 Mtetra
.439 .693 .972 r
.31234 .51258 .3163 .51603 .32239 .51606 .31843 .51263 Mtetra
.454 .701 .973 r
.31843 .51263 .32239 .51606 .3285 .51597 .32455 .51256 Mtetra
.468 .709 .973 r
.32455 .51256 .3285 .51597 .33465 .51577 .3307 .51237 Mtetra
.481 .716 .974 r
.3307 .51237 .33465 .51577 .34082 .51546 .33687 .51208 Mtetra
.493 .722 .974 r
.33687 .51208 .34082 .51546 .34702 .51504 .34308 .51167 Mtetra
.504 .728 .973 r
.34308 .51167 .34702 .51504 .35324 .51451 .34931 .51116 Mtetra
.515 .734 .973 r
.34931 .51116 .35324 .51451 .35949 .51389 .35556 .51055 Mtetra
.525 .739 .973 r
.35556 .51055 .35949 .51389 .36576 .51317 .36184 .50984 Mtetra
.534 .744 .972 r
.36184 .50984 .36576 .51317 .37206 .51236 .36815 .50903 Mtetra
.543 .749 .971 r
.36815 .50903 .37206 .51236 .37838 .51145 .37448 .50814 Mtetra
.551 .753 .971 r
.37448 .50814 .37838 .51145 .38472 .51046 .38083 .50716 Mtetra
.559 .757 .97 r
.38083 .50716 .38472 .51046 .39109 .50939 .3872 .5061 Mtetra
.567 .761 .969 r
.3872 .5061 .39109 .50939 .39747 .50824 .3936 .50495 Mtetra
.574 .764 .969 r
.3936 .50495 .39747 .50824 .40388 .507 .40001 .50373 Mtetra
.58 .767 .968 r
.40001 .50373 .40388 .507 .41031 .5057 .40645 .50243 Mtetra
.586 .771 .967 r
.40645 .50243 .41031 .5057 .41676 .50432 .41291 .50105 Mtetra
.592 .773 .966 r
.41291 .50105 .41676 .50432 .42323 .50287 .41939 .49961 Mtetra
.598 .776 .965 r
.41939 .49961 .42323 .50287 .42972 .50135 .42589 .4981 Mtetra
.603 .779 .965 r
.42589 .4981 .42972 .50135 .43623 .49977 .43241 .49652 Mtetra
.608 .781 .964 r
.43241 .49652 .43623 .49977 .44276 .49813 .43895 .49487 Mtetra
.613 .783 .963 r
.43895 .49487 .44276 .49813 .44931 .49642 .44551 .49317 Mtetra
.617 .786 .962 r
.44551 .49317 .44931 .49642 .45588 .49465 .45209 .49141 Mtetra
.621 .788 .961 r
.45209 .49141 .45588 .49465 .46246 .49283 .45868 .48958 Mtetra
.625 .79 .961 r
.45868 .48958 .46246 .49283 .46906 .49095 .4653 .4877 Mtetra
.629 .791 .96 r
.4653 .4877 .46906 .49095 .47568 .48902 .47193 .48577 Mtetra
.633 .793 .959 r
.47193 .48577 .47568 .48902 .48232 .48703 .47858 .48378 Mtetra
.637 .795 .958 r
.47858 .48378 .48232 .48703 .48897 .485 .48524 .48174 Mtetra
.64 .796 .957 r
.48524 .48174 .48897 .485 .49565 .48291 .49193 .47965 Mtetra
.644 .798 .957 r
.49193 .47965 .49565 .48291 .50233 .48077 .49863 .47751 Mtetra
.647 .799 .956 r
.49863 .47751 .50233 .48077 .50904 .47858 .50534 .47532 Mtetra
.65 .8 .955 r
.50534 .47532 .50904 .47858 .51576 .47635 .51208 .47308 Mtetra
.653 .801 .954 r
.51208 .47308 .51576 .47635 .5225 .47407 .51883 .4708 Mtetra
.656 .803 .953 r
.51883 .4708 .5225 .47407 .52925 .47174 .52559 .46846 Mtetra
.659 .804 .952 r
.52559 .46846 .52925 .47174 .53602 .46937 .53237 .46608 Mtetra
.662 .805 .951 r
.53237 .46608 .53602 .46937 .5428 .46695 .53917 .46366 Mtetra
.665 .806 .95 r
.53917 .46366 .5428 .46695 .5496 .46449 .54598 .46119 Mtetra
.668 .807 .95 r
.54598 .46119 .5496 .46449 .55642 .46198 .55281 .45867 Mtetra
.67 .807 .949 r
.55281 .45867 .55642 .46198 .56325 .45942 .55965 .4561 Mtetra
.673 .808 .948 r
.55965 .4561 .56325 .45942 .57009 .45682 .56651 .45349 Mtetra
.676 .809 .946 r
.56651 .45349 .57009 .45682 .57695 .45417 .57338 .45083 Mtetra
.679 .81 .945 r
.57338 .45083 .57695 .45417 .58382 .45148 .58027 .44812 Mtetra
.682 .811 .944 r
.58027 .44812 .58382 .45148 .59071 .44874 .58717 .44536 Mtetra
.684 .811 .943 r
.58717 .44536 .59071 .44874 .59761 .44594 .59409 .44256 Mtetra
.687 .812 .942 r
.59409 .44256 .59761 .44594 .60453 .4431 .60101 .4397 Mtetra
.69 .812 .941 r
.60101 .4397 .60453 .4431 .61146 .44021 .60796 .43679 Mtetra
.693 .813 .939 r
.60796 .43679 .61146 .44021 .6184 .43726 .61491 .43383 Mtetra
.696 .814 .938 r
.61491 .43383 .6184 .43726 .62535 .43427 .62188 .43081 Mtetra
.699 .814 .936 r
.62188 .43081 .62535 .43427 .63232 .43121 .62886 .42774 Mtetra
.702 .815 .935 r
.62886 .42774 .63232 .43121 .6393 .4281 .63585 .42461 Mtetra
.705 .815 .933 r
.63585 .42461 .6393 .4281 .64629 .42493 .64285 .42142 Mtetra
.709 .815 .931 r
.64285 .42142 .64629 .42493 .65329 .4217 .64987 .41817 Mtetra
.712 .816 .93 r
.64987 .41817 .65329 .4217 .6603 .41841 .6569 .41486 Mtetra
.715 .816 .928 r
.6569 .41486 .6603 .41841 .66732 .41504 .66393 .41147 Mtetra
.719 .817 .926 r
.66393 .41147 .66732 .41504 .67435 .41161 .67098 .40802 Mtetra
.722 .817 .924 r
.67098 .40802 .67435 .41161 .6814 .40811 .67804 .40449 Mtetra
.726 .817 .922 r
.67804 .40449 .6814 .40811 .68845 .40454 .6851 .40089 Mtetra
.73 .817 .919 r
.6851 .40089 .68845 .40454 .69551 .40088 .69217 .39721 Mtetra
.733 .818 .917 r
.69217 .39721 .69551 .40088 .70257 .39715 .69926 .39345 Mtetra
.737 .818 .914 r
.69926 .39345 .70257 .39715 .70965 .39333 .70634 .3896 Mtetra
.741 .818 .912 r
.70634 .3896 .70965 .39333 .71673 .38942 .71344 .38567 Mtetra
.745 .818 .909 r
.71344 .38567 .71673 .38942 .72381 .38542 .72054 .38163 Mtetra
.75 .819 .906 r
.72054 .38163 .72381 .38542 .7309 .38132 .72764 .3775 Mtetra
.754 .819 .903 r
.72764 .3775 .7309 .38132 .738 .37712 .73475 .37327 Mtetra
.758 .819 .9 r
.73475 .37327 .738 .37712 .74509 .37281 .74186 .36893 Mtetra
.763 .819 .897 r
.74186 .36893 .74509 .37281 .75219 .3684 .74897 .36448 Mtetra
.767 .819 .893 r
.74897 .36448 .75219 .3684 .75929 .36386 .75609 .35991 Mtetra
.772 .819 .89 r
.75609 .35991 .75929 .36386 .76639 .35921 .7632 .35522 Mtetra
.777 .819 .886 r
.7632 .35522 .76639 .35921 .77348 .35442 .77031 .3504 Mtetra
.781 .819 .882 r
.77031 .3504 .77348 .35442 .78058 .34951 .77741 .34544 Mtetra
.786 .819 .878 r
.77741 .34544 .78058 .34951 .78767 .34445 .78452 .34035 Mtetra
.791 .818 .874 r
.78452 .34035 .78767 .34445 .79475 .33925 .79161 .33511 Mtetra
.796 .818 .869 r
.79161 .33511 .79475 .33925 .80182 .3339 .7987 .32971 Mtetra
.801 .818 .865 r
.7987 .32971 .80182 .3339 .80889 .32838 .80578 .32415 Mtetra
.806 .818 .86 r
.80578 .32415 .80889 .32838 .81594 .3227 .81285 .31843 Mtetra
0 .072 .583 r
.16849 .45483 .17245 .459 .17747 .46358 .1735 .45945 Mtetra
0 .114 .623 r
.1735 .45945 .17747 .46358 .18254 .46792 .17856 .46382 Mtetra
0 .155 .66 r
.17856 .46382 .18254 .46792 .18767 .47202 .18369 .46796 Mtetra
0 .196 .695 r
.18369 .46796 .18767 .47202 .19286 .47588 .18887 .47186 Mtetra
0 .236 .728 r
.18887 .47186 .19286 .47588 .1981 .47952 .19411 .47553 Mtetra
0 .274 .759 r
.19411 .47553 .1981 .47952 .20339 .48294 .1994 .47898 Mtetra
0 .311 .786 r
.1994 .47898 .20339 .48294 .20874 .48614 .20474 .48221 Mtetra
0 .346 .812 r
.20474 .48221 .20874 .48614 .21414 .48912 .21013 .48523 Mtetra
0 .379 .835 r
.21013 .48523 .21414 .48912 .21958 .4919 .21558 .48805 Mtetra
.004 .41 .855 r
.21558 .48805 .21958 .4919 .22508 .49449 .22107 .49066 Mtetra
.044 .44 .873 r
.22107 .49066 .22508 .49449 .23062 .49687 .22661 .49307 Mtetra
.083 .467 .889 r
.22661 .49307 .23062 .49687 .2362 .49907 .23219 .4953 Mtetra
.119 .492 .903 r
.23219 .4953 .2362 .49907 .24183 .50108 .23782 .49734 Mtetra
.154 .516 .915 r
.23782 .49734 .24183 .50108 .2475 .50291 .24349 .4992 Mtetra
.187 .538 .926 r
.24349 .4992 .2475 .50291 .25321 .50456 .2492 .50088 Mtetra
.217 .558 .935 r
.2492 .50088 .25321 .50456 .25896 .50605 .25495 .50239 Mtetra
.246 .577 .942 r
.25495 .50239 .25896 .50605 .26475 .50737 .26074 .50374 Mtetra
.273 .594 .949 r
.26074 .50374 .26475 .50737 .27058 .50853 .26657 .50493 Mtetra
.298 .61 .954 r
.26657 .50493 .27058 .50853 .27644 .50954 .27243 .50596 Mtetra
.322 .625 .959 r
.27243 .50596 .27644 .50954 .28234 .5104 .27834 .50684 Mtetra
.344 .638 .963 r
.27834 .50684 .28234 .5104 .28828 .51111 .28427 .50757 Mtetra
.365 .65 .966 r
.28427 .50757 .28828 .51111 .29424 .51168 .29024 .50816 Mtetra
.385 .662 .968 r
.29024 .50816 .29424 .51168 .30024 .51211 .29625 .50862 Mtetra
.403 .673 .97 r
.29625 .50862 .30024 .51211 .30627 .51241 .30228 .50894 Mtetra
.42 .682 .971 r
.30228 .50894 .30627 .51241 .31234 .51258 .30835 .50913 Mtetra
.436 .691 .973 r
.30835 .50913 .31234 .51258 .31843 .51263 .31445 .5092 Mtetra
.451 .7 .973 r
.31445 .5092 .31843 .51263 .32455 .51256 .32057 .50914 Mtetra
.465 .708 .974 r
.32057 .50914 .32455 .51256 .3307 .51237 .32673 .50897 Mtetra
.478 .715 .974 r
.32673 .50897 .3307 .51237 .33687 .51208 .33291 .50869 Mtetra
.49 .722 .974 r
.33291 .50869 .33687 .51208 .34308 .51167 .33912 .5083 Mtetra
.501 .728 .974 r
.33912 .5083 .34308 .51167 .34931 .51116 .34536 .5078 Mtetra
.512 .734 .974 r
.34536 .5078 .34931 .51116 .35556 .51055 .35162 .5072 Mtetra
.522 .739 .973 r
.35162 .5072 .35556 .51055 .36184 .50984 .35791 .50651 Mtetra
.532 .744 .973 r
.35791 .50651 .36184 .50984 .36815 .50903 .36422 .50572 Mtetra
.541 .749 .972 r
.36422 .50572 .36815 .50903 .37448 .50814 .37055 .50484 Mtetra
.549 .753 .972 r
.37055 .50484 .37448 .50814 .38083 .50716 .37691 .50387 Mtetra
.557 .757 .971 r
.37691 .50387 .38083 .50716 .3872 .5061 .3833 .50281 Mtetra
.564 .761 .971 r
.3833 .50281 .3872 .5061 .3936 .50495 .3897 .50167 Mtetra
.571 .765 .97 r
.3897 .50167 .3936 .50495 .40001 .50373 .39613 .50046 Mtetra
.578 .768 .969 r
.39613 .50046 .40001 .50373 .40645 .50243 .40258 .49916 Mtetra
.584 .771 .968 r
.40258 .49916 .40645 .50243 .41291 .50105 .40905 .4978 Mtetra
.59 .774 .968 r
.40905 .4978 .41291 .50105 .41939 .49961 .41554 .49636 Mtetra
.596 .777 .967 r
.41554 .49636 .41939 .49961 .42589 .4981 .42205 .49485 Mtetra
.601 .78 .966 r
.42205 .49485 .42589 .4981 .43241 .49652 .42858 .49328 Mtetra
.606 .782 .965 r
.42858 .49328 .43241 .49652 .43895 .49487 .43513 .49164 Mtetra
.611 .785 .964 r
.43513 .49164 .43895 .49487 .44551 .49317 .44169 .48994 Mtetra
.616 .787 .964 r
.44169 .48994 .44551 .49317 .45209 .49141 .44828 .48817 Mtetra
.62 .789 .963 r
.44828 .48817 .45209 .49141 .45868 .48958 .45489 .48635 Mtetra
.624 .791 .962 r
.45489 .48635 .45868 .48958 .4653 .4877 .46151 .48447 Mtetra
.628 .793 .961 r
.46151 .48447 .4653 .4877 .47193 .48577 .46816 .48254 Mtetra
.632 .795 .96 r
.46816 .48254 .47193 .48577 .47858 .48378 .47482 .48055 Mtetra
.636 .796 .96 r
.47482 .48055 .47858 .48378 .48524 .48174 .48149 .47851 Mtetra
.639 .798 .959 r
.48149 .47851 .48524 .48174 .49193 .47965 .48819 .47642 Mtetra
.643 .799 .958 r
.48819 .47642 .49193 .47965 .49863 .47751 .4949 .47427 Mtetra
.646 .801 .957 r
.4949 .47427 .49863 .47751 .50534 .47532 .50163 .47208 Mtetra
.649 .802 .956 r
.50163 .47208 .50534 .47532 .51208 .47308 .50838 .46984 Mtetra
.652 .803 .955 r
.50838 .46984 .51208 .47308 .51883 .4708 .51514 .46754 Mtetra
.655 .805 .955 r
.51514 .46754 .51883 .4708 .52559 .46846 .52192 .4652 Mtetra
.659 .806 .954 r
.52192 .4652 .52559 .46846 .53237 .46608 .52871 .46282 Mtetra
.661 .807 .953 r
.52871 .46282 .53237 .46608 .53917 .46366 .53552 .46038 Mtetra
.664 .808 .952 r
.53552 .46038 .53917 .46366 .54598 .46119 .54235 .4579 Mtetra
.667 .809 .951 r
.54235 .4579 .54598 .46119 .55281 .45867 .54919 .45537 Mtetra
.67 .81 .95 r
.54919 .45537 .55281 .45867 .55965 .4561 .55604 .4528 Mtetra
.673 .81 .949 r
.55604 .4528 .55965 .4561 .56651 .45349 .56291 .45017 Mtetra
.676 .811 .948 r
.56291 .45017 .56651 .45349 .57338 .45083 .5698 .4475 Mtetra
.679 .812 .947 r
.5698 .4475 .57338 .45083 .58027 .44812 .5767 .44478 Mtetra
.682 .813 .945 r
.5767 .44478 .58027 .44812 .58717 .44536 .58361 .44201 Mtetra
.684 .813 .944 r
.58361 .44201 .58717 .44536 .59409 .44256 .59054 .43919 Mtetra
.687 .814 .943 r
.59054 .43919 .59409 .44256 .60101 .4397 .59748 .43632 Mtetra
.69 .815 .942 r
.59748 .43632 .60101 .4397 .60796 .43679 .60444 .43339 Mtetra
.693 .815 .94 r
.60444 .43339 .60796 .43679 .61491 .43383 .61141 .43041 Mtetra
.696 .816 .939 r
.61141 .43041 .61491 .43383 .62188 .43081 .61839 .42738 Mtetra
.699 .816 .937 r
.61839 .42738 .62188 .43081 .62886 .42774 .62538 .42429 Mtetra
.703 .817 .936 r
.62538 .42429 .62886 .42774 .63585 .42461 .63239 .42114 Mtetra
.706 .817 .934 r
.63239 .42114 .63585 .42461 .64285 .42142 .63941 .41793 Mtetra
.709 .817 .932 r
.63941 .41793 .64285 .42142 .64987 .41817 .64644 .41466 Mtetra
.712 .818 .931 r
.64644 .41466 .64987 .41817 .6569 .41486 .65348 .41132 Mtetra
.716 .818 .929 r
.65348 .41132 .6569 .41486 .66393 .41147 .66053 .40791 Mtetra
.719 .819 .927 r
.66053 .40791 .66393 .41147 .67098 .40802 .66759 .40443 Mtetra
.723 .819 .924 r
.66759 .40443 .67098 .40802 .67804 .40449 .67466 .40088 Mtetra
.727 .819 .922 r
.67466 .40088 .67804 .40449 .6851 .40089 .68174 .39726 Mtetra
.73 .819 .92 r
.68174 .39726 .6851 .40089 .69217 .39721 .68883 .39355 Mtetra
.734 .82 .917 r
.68883 .39355 .69217 .39721 .69926 .39345 .69592 .38976 Mtetra
.738 .82 .915 r
.69592 .38976 .69926 .39345 .70634 .3896 .70303 .38588 Mtetra
.742 .82 .912 r
.70303 .38588 .70634 .3896 .71344 .38567 .71013 .38192 Mtetra
.746 .82 .909 r
.71013 .38192 .71344 .38567 .72054 .38163 .71725 .37785 Mtetra
.751 .82 .906 r
.71725 .37785 .72054 .38163 .72764 .3775 .72437 .37369 Mtetra
.755 .82 .903 r
.72437 .37369 .72764 .3775 .73475 .37327 .73149 .36943 Mtetra
.759 .82 .9 r
.73149 .36943 .73475 .37327 .74186 .36893 .73861 .36505 Mtetra
.764 .82 .897 r
.73861 .36505 .74186 .36893 .74897 .36448 .74574 .36056 Mtetra
.768 .82 .893 r
.74574 .36056 .74897 .36448 .75609 .35991 .75287 .35596 Mtetra
.773 .82 .89 r
.75287 .35596 .75609 .35991 .7632 .35522 .75999 .35123 Mtetra
.778 .82 .886 r
.75999 .35123 .7632 .35522 .77031 .3504 .76712 .34637 Mtetra
.783 .82 .882 r
.76712 .34637 .77031 .3504 .77741 .34544 .77424 .34137 Mtetra
.787 .819 .877 r
.77424 .34137 .77741 .34544 .78452 .34035 .78135 .33623 Mtetra
.792 .819 .873 r
.78135 .33623 .78452 .34035 .79161 .33511 .78846 .33095 Mtetra
.797 .819 .869 r
.78846 .33095 .79161 .33511 .7987 .32971 .79557 .32551 Mtetra
.802 .818 .864 r
.79557 .32551 .7987 .32971 .80578 .32415 .80266 .31991 Mtetra
.807 .818 .859 r
.80266 .31991 .80578 .32415 .81285 .31843 .80974 .31413 Mtetra
0 .068 .582 r
.16452 .45059 .16849 .45483 .1735 .45945 .16952 .45525 Mtetra
0 .11 .621 r
.16952 .45525 .1735 .45945 .17856 .46382 .17457 .45966 Mtetra
0 .151 .658 r
.17457 .45966 .17856 .46382 .18369 .46796 .17969 .46384 Mtetra
0 .192 .693 r
.17969 .46384 .18369 .46796 .18887 .47186 .18487 .46778 Mtetra
0 .231 .725 r
.18487 .46778 .18887 .47186 .19411 .47553 .1901 .47149 Mtetra
0 .269 .756 r
.1901 .47149 .19411 .47553 .1994 .47898 .19538 .47497 Mtetra
0 .306 .784 r
.19538 .47497 .1994 .47898 .20474 .48221 .20072 .47824 Mtetra
0 .341 .809 r
.20072 .47824 .20474 .48221 .21013 .48523 .20611 .4813 Mtetra
0 .374 .832 r
.20611 .4813 .21013 .48523 .21558 .48805 .21155 .48415 Mtetra
0 .406 .853 r
.21155 .48415 .21558 .48805 .22107 .49066 .21704 .48679 Mtetra
.04 .435 .871 r
.21704 .48679 .22107 .49066 .22661 .49307 .22258 .48924 Mtetra
.078 .462 .887 r
.22258 .48924 .22661 .49307 .23219 .4953 .22816 .4915 Mtetra
.115 .488 .901 r
.22816 .4915 .23219 .4953 .23782 .49734 .23379 .49357 Mtetra
.149 .512 .913 r
.23379 .49357 .23782 .49734 .24349 .4992 .23946 .49546 Mtetra
.182 .534 .924 r
.23946 .49546 .24349 .4992 .2492 .50088 .24517 .49717 Mtetra
.212 .554 .933 r
.24517 .49717 .2492 .50088 .25495 .50239 .25092 .49871 Mtetra
.241 .573 .941 r
.25092 .49871 .25495 .50239 .26074 .50374 .25671 .50009 Mtetra
.268 .591 .948 r
.25671 .50009 .26074 .50374 .26657 .50493 .26254 .5013 Mtetra
.294 .607 .953 r
.26254 .5013 .26657 .50493 .27243 .50596 .26841 .50236 Mtetra
.318 .622 .958 r
.26841 .50236 .27243 .50596 .27834 .50684 .27431 .50326 Mtetra
.34 .635 .962 r
.27431 .50326 .27834 .50684 .28427 .50757 .28025 .50402 Mtetra
.361 .648 .965 r
.28025 .50402 .28427 .50757 .29024 .50816 .28623 .50463 Mtetra
.38 .66 .968 r
.28623 .50463 .29024 .50816 .29625 .50862 .29223 .50511 Mtetra
.399 .671 .97 r
.29223 .50511 .29625 .50862 .30228 .50894 .29827 .50545 Mtetra
.416 .681 .971 r
.29827 .50545 .30228 .50894 .30835 .50913 .30434 .50566 Mtetra
.432 .69 .973 r
.30434 .50566 .30835 .50913 .31445 .5092 .31045 .50575 Mtetra
.447 .699 .974 r
.31045 .50575 .31445 .5092 .32057 .50914 .31658 .50572 Mtetra
.461 .707 .974 r
.31658 .50572 .32057 .50914 .32673 .50897 .32274 .50557 Mtetra
.474 .714 .975 r
.32274 .50557 .32673 .50897 .33291 .50869 .32893 .5053 Mtetra
.486 .721 .975 r
.32893 .5053 .33291 .50869 .33912 .5083 .33514 .50493 Mtetra
.498 .727 .975 r
.33514 .50493 .33912 .5083 .34536 .5078 .34139 .50444 Mtetra
.509 .733 .975 r
.34139 .50444 .34536 .5078 .35162 .5072 .34766 .50386 Mtetra
.519 .739 .974 r
.34766 .50386 .35162 .5072 .35791 .50651 .35395 .50318 Mtetra
.529 .744 .974 r
.35395 .50318 .35791 .50651 .36422 .50572 .36027 .5024 Mtetra
.538 .749 .973 r
.36027 .5024 .36422 .50572 .37055 .50484 .36661 .50153 Mtetra
.546 .753 .973 r
.36661 .50153 .37055 .50484 .37691 .50387 .37298 .50057 Mtetra
.554 .758 .972 r
.37298 .50057 .37691 .50387 .3833 .50281 .37937 .49953 Mtetra
.562 .762 .972 r
.37937 .49953 .3833 .50281 .3897 .50167 .38579 .4984 Mtetra
.569 .765 .971 r
.38579 .4984 .3897 .50167 .39613 .50046 .39222 .4972 Mtetra
.576 .769 .97 r
.39222 .4972 .39613 .50046 .40258 .49916 .39868 .49591 Mtetra
.582 .772 .97 r
.39868 .49591 .40258 .49916 .40905 .4978 .40516 .49455 Mtetra
.588 .775 .969 r
.40516 .49455 .40905 .4978 .41554 .49636 .41166 .49312 Mtetra
.594 .778 .968 r
.41166 .49312 .41554 .49636 .42205 .49485 .41818 .49162 Mtetra
.599 .781 .967 r
.41818 .49162 .42205 .49485 .42858 .49328 .42472 .49005 Mtetra
.605 .784 .967 r
.42472 .49005 .42858 .49328 .43513 .49164 .43128 .48841 Mtetra
.609 .786 .966 r
.43128 .48841 .43513 .49164 .44169 .48994 .43786 .48672 Mtetra
.614 .788 .965 r
.43786 .48672 .44169 .48994 .44828 .48817 .44446 .48496 Mtetra
.619 .79 .964 r
.44446 .48496 .44828 .48817 .45489 .48635 .45107 .48314 Mtetra
.623 .793 .963 r
.45107 .48314 .45489 .48635 .46151 .48447 .45771 .48126 Mtetra
.627 .794 .963 r
.45771 .48126 .46151 .48447 .46816 .48254 .46436 .47933 Mtetra
.631 .796 .962 r
.46436 .47933 .46816 .48254 .47482 .48055 .47104 .47734 Mtetra
.635 .798 .961 r
.47104 .47734 .47482 .48055 .48149 .47851 .47773 .47529 Mtetra
.638 .8 .96 r
.47773 .47529 .48149 .47851 .48819 .47642 .48443 .4732 Mtetra
.642 .801 .959 r
.48443 .4732 .48819 .47642 .4949 .47427 .49116 .47105 Mtetra
.645 .803 .959 r
.49116 .47105 .4949 .47427 .50163 .47208 .4979 .46885 Mtetra
.648 .804 .958 r
.4979 .46885 .50163 .47208 .50838 .46984 .50466 .4666 Mtetra
.652 .805 .957 r
.50466 .4666 .50838 .46984 .51514 .46754 .51143 .46431 Mtetra
.655 .806 .956 r
.51143 .46431 .51514 .46754 .52192 .4652 .51822 .46196 Mtetra
.658 .808 .955 r
.51822 .46196 .52192 .4652 .52871 .46282 .52503 .45957 Mtetra
.661 .809 .954 r
.52503 .45957 .52871 .46282 .53552 .46038 .53185 .45712 Mtetra
.664 .81 .953 r
.53185 .45712 .53552 .46038 .54235 .4579 .53869 .45463 Mtetra
.667 .811 .952 r
.53869 .45463 .54235 .4579 .54919 .45537 .54554 .4521 Mtetra
.67 .812 .951 r
.54554 .4521 .54919 .45537 .55604 .4528 .55241 .44951 Mtetra
.673 .812 .95 r
.55241 .44951 .55604 .4528 .56291 .45017 .5593 .44687 Mtetra
.676 .813 .949 r
.5593 .44687 .56291 .45017 .5698 .4475 .5662 .44419 Mtetra
.679 .814 .948 r
.5662 .44419 .5698 .4475 .5767 .44478 .57311 .44146 Mtetra
.682 .815 .947 r
.57311 .44146 .5767 .44478 .58361 .44201 .58004 .43867 Mtetra
.685 .815 .945 r
.58004 .43867 .58361 .44201 .59054 .43919 .58698 .43584 Mtetra
.688 .816 .944 r
.58698 .43584 .59054 .43919 .59748 .43632 .59394 .43295 Mtetra
.691 .817 .943 r
.59394 .43295 .59748 .43632 .60444 .43339 .60091 .43001 Mtetra
.694 .817 .941 r
.60091 .43001 .60444 .43339 .61141 .43041 .60789 .42701 Mtetra
.697 .818 .94 r
.60789 .42701 .61141 .43041 .61839 .42738 .61488 .42396 Mtetra
.7 .818 .938 r
.61488 .42396 .61839 .42738 .62538 .42429 .62189 .42085 Mtetra
.703 .819 .937 r
.62189 .42085 .62538 .42429 .63239 .42114 .62891 .41768 Mtetra
.706 .819 .935 r
.62891 .41768 .63239 .42114 .63941 .41793 .63594 .41445 Mtetra
.71 .819 .933 r
.63594 .41445 .63941 .41793 .64644 .41466 .64299 .41116 Mtetra
.713 .82 .931 r
.64299 .41116 .64644 .41466 .65348 .41132 .65004 .40779 Mtetra
.717 .82 .929 r
.65004 .40779 .65348 .41132 .66053 .40791 .65711 .40436 Mtetra
.72 .82 .927 r
.65711 .40436 .66053 .40791 .66759 .40443 .66418 .40086 Mtetra
.724 .821 .925 r
.66418 .40086 .66759 .40443 .67466 .40088 .67127 .39728 Mtetra
.728 .821 .923 r
.67127 .39728 .67466 .40088 .68174 .39726 .67836 .39363 Mtetra
.731 .821 .92 r
.67836 .39363 .68174 .39726 .68883 .39355 .68546 .38989 Mtetra
.735 .821 .918 r
.68546 .38989 .68883 .39355 .69592 .38976 .69257 .38608 Mtetra
.739 .821 .915 r
.69257 .38608 .69592 .38976 .70303 .38588 .69969 .38217 Mtetra
.743 .821 .912 r
.69969 .38217 .70303 .38588 .71013 .38192 .70681 .37817 Mtetra
.748 .821 .91 r
.70681 .37817 .71013 .38192 .71725 .37785 .71394 .37407 Mtetra
.752 .821 .907 r
.71394 .37407 .71725 .37785 .72437 .37369 .72107 .36988 Mtetra
.756 .821 .903 r
.72107 .36988 .72437 .37369 .73149 .36943 .72821 .36558 Mtetra
.761 .821 .9 r
.72821 .36558 .73149 .36943 .73861 .36505 .73535 .36117 Mtetra
.765 .821 .897 r
.73535 .36117 .73861 .36505 .74574 .36056 .74249 .35664 Mtetra
.77 .821 .893 r
.74249 .35664 .74574 .36056 .75287 .35596 .74963 .352 Mtetra
.774 .821 .889 r
.74963 .352 .75287 .35596 .75999 .35123 .75677 .34723 Mtetra
.779 .821 .885 r
.75677 .34723 .75999 .35123 .76712 .34637 .76391 .34233 Mtetra
.784 .82 .881 r
.76391 .34233 .76712 .34637 .77424 .34137 .77105 .33729 Mtetra
.789 .82 .877 r
.77105 .33729 .77424 .34137 .78135 .33623 .77818 .33211 Mtetra
.794 .82 .873 r
.77818 .33211 .78135 .33623 .78846 .33095 .7853 .32678 Mtetra
.799 .819 .868 r
.7853 .32678 .78846 .33095 .79557 .32551 .79242 .32129 Mtetra
.804 .819 .863 r
.79242 .32129 .79557 .32551 .80266 .31991 .79952 .31564 Mtetra
.809 .818 .858 r
.79952 .31564 .80266 .31991 .80974 .31413 .80662 .30982 Mtetra
0 .064 .58 r
.16054 .44628 .16452 .45059 .16952 .45525 .16553 .45099 Mtetra
0 .106 .619 r
.16553 .45099 .16952 .45525 .17457 .45966 .17058 .45544 Mtetra
0 .147 .655 r
.17058 .45544 .17457 .45966 .17969 .46384 .17569 .45966 Mtetra
0 .187 .69 r
.17569 .45966 .17969 .46384 .18487 .46778 .18086 .46364 Mtetra
0 .226 .723 r
.18086 .46364 .18487 .46778 .1901 .47149 .18608 .46739 Mtetra
0 .264 .753 r
.18608 .46739 .1901 .47149 .19538 .47497 .19136 .47092 Mtetra
0 .301 .781 r
.19136 .47092 .19538 .47497 .20072 .47824 .1967 .47422 Mtetra
0 .336 .806 r
.1967 .47422 .20072 .47824 .20611 .4813 .20208 .47732 Mtetra
0 .369 .829 r
.20208 .47732 .20611 .4813 .21155 .48415 .20752 .4802 Mtetra
0 .401 .85 r
.20752 .4802 .21155 .48415 .21704 .48679 .213 .48288 Mtetra
.035 .43 .868 r
.213 .48288 .21704 .48679 .22258 .48924 .21854 .48537 Mtetra
.073 .458 .884 r
.21854 .48537 .22258 .48924 .22816 .4915 .22412 .48766 Mtetra
.109 .483 .899 r
.22412 .48766 .22816 .4915 .23379 .49357 .22974 .48976 Mtetra
.144 .507 .911 r
.22974 .48976 .23379 .49357 .23946 .49546 .23541 .49168 Mtetra
.177 .53 .922 r
.23541 .49168 .23946 .49546 .24517 .49717 .24112 .49343 Mtetra
.207 .55 .931 r
.24112 .49343 .24517 .49717 .25092 .49871 .24687 .495 Mtetra
.236 .569 .939 r
.24687 .495 .25092 .49871 .25671 .50009 .25267 .4964 Mtetra
.263 .587 .946 r
.25267 .4964 .25671 .50009 .26254 .5013 .2585 .49765 Mtetra
.289 .604 .952 r
.2585 .49765 .26254 .5013 .26841 .50236 .26437 .49873 Mtetra
.313 .619 .957 r
.26437 .49873 .26841 .50236 .27431 .50326 .27027 .49966 Mtetra
.335 .633 .961 r
.27027 .49966 .27431 .50326 .28025 .50402 .27622 .50045 Mtetra
.356 .646 .965 r
.27622 .50045 .28025 .50402 .28623 .50463 .28219 .50109 Mtetra
.376 .657 .967 r
.28219 .50109 .28623 .50463 .29223 .50511 .2882 .50159 Mtetra
.394 .669 .97 r
.2882 .50159 .29223 .50511 .29827 .50545 .29425 .50195 Mtetra
.412 .679 .971 r
.29425 .50195 .29827 .50545 .30434 .50566 .30032 .50219 Mtetra
.428 .688 .973 r
.30032 .50219 .30434 .50566 .31045 .50575 .30643 .5023 Mtetra
.443 .697 .974 r
.30643 .5023 .31045 .50575 .31658 .50572 .31257 .50228 Mtetra
.457 .705 .974 r
.31257 .50228 .31658 .50572 .32274 .50557 .31873 .50215 Mtetra
.471 .713 .975 r
.31873 .50215 .32274 .50557 .32893 .5053 .32493 .5019 Mtetra
.483 .72 .975 r
.32493 .5019 .32893 .5053 .33514 .50493 .33115 .50155 Mtetra
.495 .726 .975 r
.33115 .50155 .33514 .50493 .34139 .50444 .3374 .50108 Mtetra
.506 .733 .975 r
.3374 .50108 .34139 .50444 .34766 .50386 .34367 .50052 Mtetra
.516 .738 .975 r
.34367 .50052 .34766 .50386 .35395 .50318 .34998 .49985 Mtetra
.526 .744 .975 r
.34998 .49985 .35395 .50318 .36027 .5024 .3563 .49909 Mtetra
.535 .749 .974 r
.3563 .49909 .36027 .5024 .36661 .50153 .36266 .49823 Mtetra
.544 .753 .974 r
.36266 .49823 .36661 .50153 .37298 .50057 .36903 .49729 Mtetra
.552 .758 .973 r
.36903 .49729 .37298 .50057 .37937 .49953 .37543 .49625 Mtetra
.56 .762 .973 r
.37543 .49625 .37937 .49953 .38579 .4984 .38185 .49514 Mtetra
.567 .766 .972 r
.38185 .49514 .38579 .4984 .39222 .4972 .3883 .49394 Mtetra
.574 .769 .971 r
.3883 .49394 .39222 .4972 .39868 .49591 .39476 .49266 Mtetra
.58 .773 .971 r
.39476 .49266 .39868 .49591 .40516 .49455 .40125 .49131 Mtetra
.586 .776 .97 r
.40125 .49131 .40516 .49455 .41166 .49312 .40776 .48989 Mtetra
.592 .779 .969 r
.40776 .48989 .41166 .49312 .41818 .49162 .41429 .48839 Mtetra
.598 .782 .969 r
.41429 .48839 .41818 .49162 .42472 .49005 .42084 .48683 Mtetra
.603 .785 .968 r
.42084 .48683 .42472 .49005 .43128 .48841 .42741 .4852 Mtetra
.608 .787 .967 r
.42741 .4852 .43128 .48841 .43786 .48672 .434 .48351 Mtetra
.613 .789 .966 r
.434 .48351 .43786 .48672 .44446 .48496 .44061 .48175 Mtetra
.617 .792 .965 r
.44061 .48175 .44446 .48496 .45107 .48314 .44724 .47993 Mtetra
.621 .794 .965 r
.44724 .47993 .45107 .48314 .45771 .48126 .45389 .47806 Mtetra
.626 .796 .964 r
.45389 .47806 .45771 .48126 .46436 .47933 .46055 .47612 Mtetra
.63 .798 .963 r
.46055 .47612 .46436 .47933 .47104 .47734 .46724 .47413 Mtetra
.634 .8 .962 r
.46724 .47413 .47104 .47734 .47773 .47529 .47394 .47209 Mtetra
.637 .801 .961 r
.47394 .47209 .47773 .47529 .48443 .4732 .48066 .46999 Mtetra
.641 .803 .961 r
.48066 .46999 .48443 .4732 .49116 .47105 .48739 .46784 Mtetra
.644 .804 .96 r
.48739 .46784 .49116 .47105 .4979 .46885 .49415 .46564 Mtetra
.648 .806 .959 r
.49415 .46564 .4979 .46885 .50466 .4666 .50092 .46339 Mtetra
.651 .807 .958 r
.50092 .46339 .50466 .4666 .51143 .46431 .50771 .46109 Mtetra
.654 .808 .957 r
.50771 .46109 .51143 .46431 .51822 .46196 .51451 .45874 Mtetra
.657 .809 .956 r
.51451 .45874 .51822 .46196 .52503 .45957 .52133 .45633 Mtetra
.661 .811 .955 r
.52133 .45633 .52503 .45957 .53185 .45712 .52816 .45388 Mtetra
.664 .812 .954 r
.52816 .45388 .53185 .45712 .53869 .45463 .53502 .45138 Mtetra
.667 .813 .953 r
.53502 .45138 .53869 .45463 .54554 .4521 .54188 .44884 Mtetra
.67 .814 .952 r
.54188 .44884 .54554 .4521 .55241 .44951 .54877 .44624 Mtetra
.673 .814 .951 r
.54877 .44624 .55241 .44951 .5593 .44687 .55566 .44359 Mtetra
.676 .815 .95 r
.55566 .44359 .5593 .44687 .5662 .44419 .56258 .4409 Mtetra
.679 .816 .949 r
.56258 .4409 .5662 .44419 .57311 .44146 .5695 .43815 Mtetra
.682 .817 .948 r
.5695 .43815 .57311 .44146 .58004 .43867 .57645 .43535 Mtetra
.685 .817 .946 r
.57645 .43535 .58004 .43867 .58698 .43584 .5834 .4325 Mtetra
.688 .818 .945 r
.5834 .4325 .58698 .43584 .59394 .43295 .59037 .4296 Mtetra
.691 .819 .944 r
.59037 .4296 .59394 .43295 .60091 .43001 .59735 .42664 Mtetra
.694 .819 .942 r
.59735 .42664 .60091 .43001 .60789 .42701 .60435 .42363 Mtetra
.697 .82 .941 r
.60435 .42363 .60789 .42701 .61488 .42396 .61136 .42056 Mtetra
.7 .82 .939 r
.61136 .42056 .61488 .42396 .62189 .42085 .61838 .41743 Mtetra
.704 .821 .937 r
.61838 .41743 .62189 .42085 .62891 .41768 .62542 .41423 Mtetra
.707 .821 .936 r
.62542 .41423 .62891 .41768 .63594 .41445 .63246 .41098 Mtetra
.71 .821 .934 r
.63246 .41098 .63594 .41445 .64299 .41116 .63952 .40766 Mtetra
.714 .822 .932 r
.63952 .40766 .64299 .41116 .65004 .40779 .64659 .40428 Mtetra
.717 .822 .93 r
.64659 .40428 .65004 .40779 .65711 .40436 .65367 .40082 Mtetra
.721 .822 .928 r
.65367 .40082 .65711 .40436 .66418 .40086 .66076 .39729 Mtetra
.725 .822 .926 r
.66076 .39729 .66418 .40086 .67127 .39728 .66786 .39369 Mtetra
.729 .823 .923 r
.66786 .39369 .67127 .39728 .67836 .39363 .67497 .39001 Mtetra
.732 .823 .921 r
.67497 .39001 .67836 .39363 .68546 .38989 .68209 .38624 Mtetra
.736 .823 .918 r
.68209 .38624 .68546 .38989 .69257 .38608 .68921 .38239 Mtetra
.74 .823 .915 r
.68921 .38239 .69257 .38608 .69969 .38217 .69634 .37845 Mtetra
.744 .823 .913 r
.69634 .37845 .69969 .38217 .70681 .37817 .70348 .37442 Mtetra
.749 .823 .91 r
.70348 .37442 .70681 .37817 .71394 .37407 .71062 .37029 Mtetra
.753 .823 .907 r
.71062 .37029 .71394 .37407 .72107 .36988 .71777 .36606 Mtetra
.757 .823 .903 r
.71777 .36606 .72107 .36988 .72821 .36558 .72492 .36172 Mtetra
.762 .823 .9 r
.72492 .36172 .72821 .36558 .73535 .36117 .73207 .35728 Mtetra
.766 .822 .896 r
.73207 .35728 .73535 .36117 .74249 .35664 .73923 .35271 Mtetra
.771 .822 .893 r
.73923 .35271 .74249 .35664 .74963 .352 .74638 .34803 Mtetra
.776 .822 .889 r
.74638 .34803 .74963 .352 .75677 .34723 .75354 .34322 Mtetra
.78 .822 .885 r
.75354 .34322 .75677 .34723 .76391 .34233 .76069 .33827 Mtetra
.785 .821 .881 r
.76069 .33827 .76391 .34233 .77105 .33729 .76784 .33319 Mtetra
.79 .821 .876 r
.76784 .33319 .77105 .33729 .77818 .33211 .77498 .32796 Mtetra
.795 .82 .872 r
.77498 .32796 .77818 .33211 .7853 .32678 .78212 .32258 Mtetra
.8 .82 .867 r
.78212 .32258 .7853 .32678 .79242 .32129 .78925 .31705 Mtetra
.805 .819 .862 r
.78925 .31705 .79242 .32129 .79952 .31564 .79637 .31135 Mtetra
.81 .818 .857 r
.79637 .31135 .79952 .31564 .80662 .30982 .80348 .30547 Mtetra
0 .06 .578 r
.15655 .44191 .16054 .44628 .16553 .45099 .16153 .44666 Mtetra
0 .101 .616 r
.16153 .44666 .16553 .45099 .17058 .45544 .16657 .45116 Mtetra
0 .142 .653 r
.16657 .45116 .17058 .45544 .17569 .45966 .17167 .45542 Mtetra
0 .182 .687 r
.17167 .45542 .17569 .45966 .18086 .46364 .17683 .45945 Mtetra
0 .221 .72 r
.17683 .45945 .18086 .46364 .18608 .46739 .18205 .46324 Mtetra
0 .259 .75 r
.18205 .46324 .18608 .46739 .19136 .47092 .18733 .46681 Mtetra
0 .296 .778 r
.18733 .46681 .19136 .47092 .1967 .47422 .19265 .47015 Mtetra
0 .331 .803 r
.19265 .47015 .1967 .47422 .20208 .47732 .19804 .47329 Mtetra
0 .364 .826 r
.19804 .47329 .20208 .47732 .20752 .4802 .20347 .47621 Mtetra
0 .395 .847 r
.20347 .47621 .20752 .4802 .213 .48288 .20895 .47893 Mtetra
.03 .425 .865 r
.20895 .47893 .213 .48288 .21854 .48537 .21448 .48145 Mtetra
.068 .453 .882 r
.21448 .48145 .21854 .48537 .22412 .48766 .22006 .48378 Mtetra
.104 .479 .896 r
.22006 .48378 .22412 .48766 .22974 .48976 .22568 .48592 Mtetra
.139 .503 .909 r
.22568 .48592 .22974 .48976 .23541 .49168 .23135 .48787 Mtetra
.171 .525 .92 r
.23135 .48787 .23541 .49168 .24112 .49343 .23706 .48965 Mtetra
.202 .546 .93 r
.23706 .48965 .24112 .49343 .24687 .495 .24281 .49126 Mtetra
.231 .565 .938 r
.24281 .49126 .24687 .495 .25267 .4964 .24861 .49269 Mtetra
.258 .583 .945 r
.24861 .49269 .25267 .4964 .2585 .49765 .25444 .49397 Mtetra
.284 .6 .951 r
.25444 .49397 .2585 .49765 .26437 .49873 .26031 .49508 Mtetra
.308 .615 .956 r
.26031 .49508 .26437 .49873 .27027 .49966 .26622 .49604 Mtetra
.33 .63 .96 r
.26622 .49604 .27027 .49966 .27622 .50045 .27216 .49685 Mtetra
.352 .643 .964 r
.27216 .49685 .27622 .50045 .28219 .50109 .27814 .49752 Mtetra
.371 .655 .967 r
.27814 .49752 .28219 .50109 .2882 .50159 .28416 .49804 Mtetra
.39 .666 .969 r
.28416 .49804 .2882 .50159 .29425 .50195 .2902 .49844 Mtetra
.407 .677 .971 r
.2902 .49844 .29425 .50195 .30032 .50219 .29628 .49869 Mtetra
.424 .686 .973 r
.29628 .49869 .30032 .50219 .30643 .5023 .30239 .49883 Mtetra
.439 .695 .974 r
.30239 .49883 .30643 .5023 .31257 .50228 .30853 .49883 Mtetra
.453 .704 .975 r
.30853 .49883 .31257 .50228 .31873 .50215 .31471 .49872 Mtetra
.467 .712 .975 r
.31471 .49872 .31873 .50215 .32493 .5019 .32091 .4985 Mtetra
.479 .719 .976 r
.32091 .4985 .32493 .5019 .33115 .50155 .32713 .49816 Mtetra
.491 .726 .976 r
.32713 .49816 .33115 .50155 .3374 .50108 .33339 .49772 Mtetra
.503 .732 .976 r
.33339 .49772 .3374 .50108 .34367 .50052 .33967 .49717 Mtetra
.513 .738 .976 r
.33967 .49717 .34367 .50052 .34998 .49985 .34598 .49652 Mtetra
.523 .743 .975 r
.34598 .49652 .34998 .49985 .3563 .49909 .35232 .49577 Mtetra
.532 .748 .975 r
.35232 .49577 .3563 .49909 .36266 .49823 .35868 .49493 Mtetra
.541 .753 .975 r
.35868 .49493 .36266 .49823 .36903 .49729 .36506 .494 Mtetra
.549 .758 .974 r
.36506 .494 .36903 .49729 .37543 .49625 .37147 .49298 Mtetra
.557 .762 .974 r
.37147 .49298 .37543 .49625 .38185 .49514 .3779 .49187 Mtetra
.564 .766 .973 r
.3779 .49187 .38185 .49514 .3883 .49394 .38435 .49069 Mtetra
.571 .77 .972 r
.38435 .49069 .3883 .49394 .39476 .49266 .39083 .48942 Mtetra
.578 .773 .972 r
.39083 .48942 .39476 .49266 .40125 .49131 .39733 .48808 Mtetra
.584 .777 .971 r
.39733 .48808 .40125 .49131 .40776 .48989 .40385 .48666 Mtetra
.59 .78 .97 r
.40385 .48666 .40776 .48989 .41429 .48839 .41039 .48518 Mtetra
.596 .783 .97 r
.41039 .48518 .41429 .48839 .42084 .48683 .41695 .48362 Mtetra
.601 .785 .969 r
.41695 .48362 .42084 .48683 .42741 .4852 .42353 .482 Mtetra
.606 .788 .968 r
.42353 .482 .42741 .4852 .434 .48351 .43013 .48031 Mtetra
.611 .79 .967 r
.43013 .48031 .434 .48351 .44061 .48175 .43675 .47855 Mtetra
.616 .793 .967 r
.43675 .47855 .44061 .48175 .44724 .47993 .44339 .47674 Mtetra
.62 .795 .966 r
.44339 .47674 .44724 .47993 .45389 .47806 .45005 .47487 Mtetra
.624 .797 .965 r
.45005 .47487 .45389 .47806 .46055 .47612 .45672 .47293 Mtetra
.628 .799 .964 r
.45672 .47293 .46055 .47612 .46724 .47413 .46342 .47095 Mtetra
.632 .801 .964 r
.46342 .47095 .46724 .47413 .47394 .47209 .47013 .4689 Mtetra
.636 .803 .963 r
.47013 .4689 .47394 .47209 .48066 .46999 .47686 .4668 Mtetra
.64 .804 .962 r
.47686 .4668 .48066 .46999 .48739 .46784 .48361 .46465 Mtetra
.643 .806 .961 r
.48361 .46465 .48739 .46784 .49415 .46564 .49038 .46245 Mtetra
.647 .807 .96 r
.49038 .46245 .49415 .46564 .50092 .46339 .49716 .46019 Mtetra
.65 .809 .959 r
.49716 .46019 .50092 .46339 .50771 .46109 .50396 .45788 Mtetra
.654 .81 .958 r
.50396 .45788 .50771 .46109 .51451 .45874 .51078 .45552 Mtetra
.657 .811 .957 r
.51078 .45552 .51451 .45874 .52133 .45633 .51761 .45311 Mtetra
.66 .812 .956 r
.51761 .45311 .52133 .45633 .52816 .45388 .52446 .45066 Mtetra
.663 .813 .955 r
.52446 .45066 .52816 .45388 .53502 .45138 .53132 .44815 Mtetra
.666 .814 .954 r
.53132 .44815 .53502 .45138 .54188 .44884 .5382 .44559 Mtetra
.669 .815 .953 r
.5382 .44559 .54188 .44884 .54877 .44624 .5451 .44298 Mtetra
.672 .816 .952 r
.5451 .44298 .54877 .44624 .55566 .44359 .55201 .44032 Mtetra
.676 .817 .951 r
.55201 .44032 .55566 .44359 .56258 .4409 .55894 .43762 Mtetra
.679 .818 .95 r
.55894 .43762 .56258 .4409 .5695 .43815 .56588 .43486 Mtetra
.682 .819 .949 r
.56588 .43486 .5695 .43815 .57645 .43535 .57283 .43204 Mtetra
.685 .819 .947 r
.57283 .43204 .57645 .43535 .5834 .4325 .5798 .42918 Mtetra
.688 .82 .946 r
.5798 .42918 .5834 .4325 .59037 .4296 .58679 .42626 Mtetra
.691 .82 .945 r
.58679 .42626 .59037 .4296 .59735 .42664 .59379 .42328 Mtetra
.694 .821 .943 r
.59379 .42328 .59735 .42664 .60435 .42363 .6008 .42025 Mtetra
.698 .821 .942 r
.6008 .42025 .60435 .42363 .61136 .42056 .60782 .41716 Mtetra
.701 .822 .94 r
.60782 .41716 .61136 .42056 .61838 .41743 .61486 .41401 Mtetra
.704 .822 .938 r
.61486 .41401 .61838 .41743 .62542 .41423 .62191 .4108 Mtetra
.708 .823 .936 r
.62191 .4108 .62542 .41423 .63246 .41098 .62897 .40752 Mtetra
.711 .823 .934 r
.62897 .40752 .63246 .41098 .63952 .40766 .63604 .40418 Mtetra
.715 .823 .932 r
.63604 .40418 .63952 .40766 .64659 .40428 .64312 .40077 Mtetra
.718 .824 .93 r
.64312 .40077 .64659 .40428 .65367 .40082 .65022 .39729 Mtetra
.722 .824 .928 r
.65022 .39729 .65367 .40082 .66076 .39729 .65732 .39373 Mtetra
.726 .824 .926 r
.65732 .39373 .66076 .39729 .66786 .39369 .66444 .3901 Mtetra
.729 .824 .924 r
.66444 .3901 .66786 .39369 .67497 .39001 .67156 .38639 Mtetra
.733 .824 .921 r
.67156 .38639 .67497 .39001 .68209 .38624 .67869 .38259 Mtetra
.737 .824 .918 r
.67869 .38259 .68209 .38624 .68921 .38239 .68583 .37871 Mtetra
.741 .824 .916 r
.68583 .37871 .68921 .38239 .69634 .37845 .69297 .37474 Mtetra
.746 .824 .913 r
.69297 .37474 .69634 .37845 .70348 .37442 .70013 .37067 Mtetra
.75 .824 .91 r
.70013 .37067 .70348 .37442 .71062 .37029 .70728 .36651 Mtetra
.754 .824 .906 r
.70728 .36651 .71062 .37029 .71777 .36606 .71445 .36224 Mtetra
.759 .824 .903 r
.71445 .36224 .71777 .36606 .72492 .36172 .72161 .35787 Mtetra
.763 .824 .9 r
.72161 .35787 .72492 .36172 .73207 .35728 .72878 .35338 Mtetra
.768 .823 .896 r
.72878 .35338 .73207 .35728 .73923 .35271 .73595 .34877 Mtetra
.772 .823 .892 r
.73595 .34877 .73923 .35271 .74638 .34803 .74312 .34405 Mtetra
.777 .823 .888 r
.74312 .34405 .74638 .34803 .75354 .34322 .75029 .33919 Mtetra
.782 .822 .884 r
.75029 .33919 .75354 .34322 .76069 .33827 .75745 .3342 Mtetra
.786 .822 .88 r
.75745 .3342 .76069 .33827 .76784 .33319 .76462 .32907 Mtetra
.791 .821 .876 r
.76462 .32907 .76784 .33319 .77498 .32796 .77177 .3238 Mtetra
.796 .821 .871 r
.77177 .3238 .77498 .32796 .78212 .32258 .77892 .31837 Mtetra
.801 .82 .866 r
.77892 .31837 .78212 .32258 .78925 .31705 .78607 .31278 Mtetra
.806 .819 .861 r
.78607 .31278 .78925 .31705 .79637 .31135 .7932 .30703 Mtetra
.811 .818 .856 r
.7932 .30703 .79637 .31135 .80348 .30547 .80032 .3011 Mtetra
0 .056 .576 r
.15255 .43746 .15655 .44191 .16153 .44666 .15752 .44226 Mtetra
0 .096 .614 r
.15752 .44226 .16153 .44666 .16657 .45116 .16255 .44681 Mtetra
0 .137 .65 r
.16255 .44681 .16657 .45116 .17167 .45542 .16764 .45112 Mtetra
0 .177 .684 r
.16764 .45112 .17167 .45542 .17683 .45945 .1728 .45519 Mtetra
0 .216 .717 r
.1728 .45519 .17683 .45945 .18205 .46324 .17801 .45903 Mtetra
0 .254 .747 r
.17801 .45903 .18205 .46324 .18733 .46681 .18328 .46264 Mtetra
0 .29 .774 r
.18328 .46264 .18733 .46681 .19265 .47015 .1886 .46603 Mtetra
0 .325 .8 r
.1886 .46603 .19265 .47015 .19804 .47329 .19398 .46921 Mtetra
0 .358 .823 r
.19398 .46921 .19804 .47329 .20347 .47621 .19941 .47217 Mtetra
0 .39 .844 r
.19941 .47217 .20347 .47621 .20895 .47893 .20488 .47493 Mtetra
.025 .419 .862 r
.20488 .47493 .20895 .47893 .21448 .48145 .21041 .47749 Mtetra
.063 .447 .879 r
.21041 .47749 .21448 .48145 .22006 .48378 .21599 .47986 Mtetra
.099 .473 .894 r
.21599 .47986 .22006 .48378 .22568 .48592 .22161 .48203 Mtetra
.133 .498 .906 r
.22161 .48203 .22568 .48592 .23135 .48787 .22727 .48403 Mtetra
.166 .521 .918 r
.22727 .48403 .23135 .48787 .23706 .48965 .23298 .48584 Mtetra
.197 .542 .928 r
.23298 .48584 .23706 .48965 .24281 .49126 .23874 .48748 Mtetra
.226 .561 .936 r
.23874 .48748 .24281 .49126 .24861 .49269 .24453 .48895 Mtetra
.253 .579 .943 r
.24453 .48895 .24861 .49269 .25444 .49397 .25036 .49025 Mtetra
.279 .596 .95 r
.25036 .49025 .25444 .49397 .26031 .49508 .25623 .4914 Mtetra
.303 .612 .955 r
.25623 .4914 .26031 .49508 .26622 .49604 .26214 .49239 Mtetra
.326 .626 .959 r
.26214 .49239 .26622 .49604 .27216 .49685 .26809 .49323 Mtetra
.347 .64 .963 r
.26809 .49323 .27216 .49685 .27814 .49752 .27407 .49393 Mtetra
.367 .652 .966 r
.27407 .49393 .27814 .49752 .28416 .49804 .28009 .49448 Mtetra
.385 .664 .969 r
.28009 .49448 .28416 .49804 .2902 .49844 .28614 .4949 Mtetra
.403 .674 .971 r
.28614 .4949 .2902 .49844 .29628 .49869 .29222 .49518 Mtetra
.42 .684 .972 r
.29222 .49518 .29628 .49869 .30239 .49883 .29834 .49534 Mtetra
.435 .693 .974 r
.29834 .49534 .30239 .49883 .30853 .49883 .30448 .49537 Mtetra
.449 .702 .975 r
.30448 .49537 .30853 .49883 .31471 .49872 .31066 .49529 Mtetra
.463 .71 .975 r
.31066 .49529 .31471 .49872 .32091 .4985 .31687 .49508 Mtetra
.476 .717 .976 r
.31687 .49508 .32091 .4985 .32713 .49816 .3231 .49476 Mtetra
.488 .724 .976 r
.3231 .49476 .32713 .49816 .33339 .49772 .32936 .49434 Mtetra
.499 .731 .976 r
.32936 .49434 .33339 .49772 .33967 .49717 .33565 .49381 Mtetra
.51 .737 .976 r
.33565 .49381 .33967 .49717 .34598 .49652 .34197 .49318 Mtetra
.52 .743 .976 r
.34197 .49318 .34598 .49652 .35232 .49577 .34831 .49245 Mtetra
.529 .748 .976 r
.34831 .49245 .35232 .49577 .35868 .49493 .35468 .49162 Mtetra
.538 .753 .975 r
.35468 .49162 .35868 .49493 .36506 .494 .36107 .49071 Mtetra
.546 .758 .975 r
.36107 .49071 .36506 .494 .37147 .49298 .36749 .4897 Mtetra
.554 .762 .974 r
.36749 .4897 .37147 .49298 .3779 .49187 .37392 .48861 Mtetra
.562 .766 .974 r
.37392 .48861 .3779 .49187 .38435 .49069 .38039 .48743 Mtetra
.569 .77 .973 r
.38039 .48743 .38435 .49069 .39083 .48942 .38687 .48618 Mtetra
.576 .774 .973 r
.38687 .48618 .39083 .48942 .39733 .48808 .39338 .48485 Mtetra
.582 .777 .972 r
.39338 .48485 .39733 .48808 .40385 .48666 .39991 .48344 Mtetra
.588 .78 .971 r
.39991 .48344 .40385 .48666 .41039 .48518 .40646 .48196 Mtetra
.594 .783 .971 r
.40646 .48196 .41039 .48518 .41695 .48362 .41303 .48041 Mtetra
.599 .786 .97 r
.41303 .48041 .41695 .48362 .42353 .482 .41962 .4788 Mtetra
.604 .789 .969 r
.41962 .4788 .42353 .482 .43013 .48031 .42623 .47711 Mtetra
.609 .791 .969 r
.42623 .47711 .43013 .48031 .43675 .47855 .43286 .47537 Mtetra
.614 .794 .968 r
.43286 .47537 .43675 .47855 .44339 .47674 .43951 .47356 Mtetra
.619 .796 .967 r
.43951 .47356 .44339 .47674 .45005 .47487 .44618 .47168 Mtetra
.623 .798 .966 r
.44618 .47168 .45005 .47487 .45672 .47293 .45287 .46975 Mtetra
.627 .8 .965 r
.45287 .46975 .45672 .47293 .46342 .47095 .45958 .46777 Mtetra
.631 .802 .965 r
.45958 .46777 .46342 .47095 .47013 .4689 .46631 .46572 Mtetra
.635 .804 .964 r
.46631 .46572 .47013 .4689 .47686 .4668 .47305 .46362 Mtetra
.639 .806 .963 r
.47305 .46362 .47686 .4668 .48361 .46465 .47981 .46147 Mtetra
.643 .807 .962 r
.47981 .46147 .48361 .46465 .49038 .46245 .48659 .45926 Mtetra
.646 .809 .961 r
.48659 .45926 .49038 .46245 .49716 .46019 .49338 .457 Mtetra
.65 .81 .96 r
.49338 .457 .49716 .46019 .50396 .45788 .5002 .45469 Mtetra
.653 .811 .959 r
.5002 .45469 .50396 .45788 .51078 .45552 .50703 .45232 Mtetra
.656 .813 .958 r
.50703 .45232 .51078 .45552 .51761 .45311 .51387 .44991 Mtetra
.66 .814 .957 r
.51387 .44991 .51761 .45311 .52446 .45066 .52073 .44744 Mtetra
.663 .815 .956 r
.52073 .44744 .52446 .45066 .53132 .44815 .52761 .44492 Mtetra
.666 .816 .955 r
.52761 .44492 .53132 .44815 .5382 .44559 .53451 .44236 Mtetra
.669 .817 .954 r
.53451 .44236 .5382 .44559 .5451 .44298 .54142 .43974 Mtetra
.672 .818 .953 r
.54142 .43974 .5451 .44298 .55201 .44032 .54834 .43707 Mtetra
.675 .819 .952 r
.54834 .43707 .55201 .44032 .55894 .43762 .55528 .43435 Mtetra
.679 .82 .951 r
.55528 .43435 .55894 .43762 .56588 .43486 .56224 .43157 Mtetra
.682 .82 .95 r
.56224 .43157 .56588 .43486 .57283 .43204 .5692 .42875 Mtetra
.685 .821 .948 r
.5692 .42875 .57283 .43204 .5798 .42918 .57619 .42586 Mtetra
.688 .822 .947 r
.57619 .42586 .5798 .42918 .58679 .42626 .58319 .42293 Mtetra
.691 .822 .945 r
.58319 .42293 .58679 .42626 .59379 .42328 .5902 .41993 Mtetra
.695 .823 .944 r
.5902 .41993 .59379 .42328 .6008 .42025 .59722 .41688 Mtetra
.698 .823 .942 r
.59722 .41688 .6008 .42025 .60782 .41716 .60426 .41377 Mtetra
.701 .824 .94 r
.60426 .41377 .60782 .41716 .61486 .41401 .61131 .4106 Mtetra
.705 .824 .939 r
.61131 .4106 .61486 .41401 .62191 .4108 .61838 .40737 Mtetra
.708 .824 .937 r
.61838 .40737 .62191 .4108 .62897 .40752 .62545 .40407 Mtetra
.712 .825 .935 r
.62545 .40407 .62897 .40752 .63604 .40418 .63254 .4007 Mtetra
.715 .825 .933 r
.63254 .4007 .63604 .40418 .64312 .40077 .63964 .39726 Mtetra
.719 .825 .931 r
.63964 .39726 .64312 .40077 .65022 .39729 .64675 .39376 Mtetra
.723 .825 .929 r
.64675 .39376 .65022 .39729 .65732 .39373 .65387 .39017 Mtetra
.727 .825 .926 r
.65387 .39017 .65732 .39373 .66444 .3901 .66099 .38651 Mtetra
.73 .825 .924 r
.66099 .38651 .66444 .3901 .67156 .38639 .66813 .38277 Mtetra
.734 .826 .921 r
.66813 .38277 .67156 .38639 .67869 .38259 .67528 .37894 Mtetra
.738 .826 .918 r
.67528 .37894 .67869 .38259 .68583 .37871 .68243 .37503 Mtetra
.743 .825 .916 r
.68243 .37503 .68583 .37871 .69297 .37474 .68959 .37102 Mtetra
.747 .825 .913 r
.68959 .37102 .69297 .37474 .70013 .37067 .69676 .36692 Mtetra
.751 .825 .909 r
.69676 .36692 .70013 .37067 .70728 .36651 .70393 .36272 Mtetra
.755 .825 .906 r
.70393 .36272 .70728 .36651 .71445 .36224 .71111 .35841 Mtetra
.76 .825 .903 r
.71111 .35841 .71445 .36224 .72161 .35787 .71829 .354 Mtetra
.764 .824 .899 r
.71829 .354 .72161 .35787 .72878 .35338 .72547 .34947 Mtetra
.769 .824 .896 r
.72547 .34947 .72878 .35338 .73595 .34877 .73265 .34482 Mtetra
.773 .824 .892 r
.73265 .34482 .73595 .34877 .74312 .34405 .73984 .34005 Mtetra
.778 .823 .888 r
.73984 .34005 .74312 .34405 .75029 .33919 .74702 .33515 Mtetra
.783 .823 .884 r
.74702 .33515 .75029 .33919 .75745 .3342 .7542 .33011 Mtetra
.788 .822 .879 r
.7542 .33011 .75745 .3342 .76462 .32907 .76138 .32493 Mtetra
.792 .821 .875 r
.76138 .32493 .76462 .32907 .77177 .3238 .76855 .31961 Mtetra
.797 .821 .87 r
.76855 .31961 .77177 .3238 .77892 .31837 .77571 .31413 Mtetra
.802 .82 .865 r
.77571 .31413 .77892 .31837 .78607 .31278 .78287 .30849 Mtetra
.807 .819 .86 r
.78287 .30849 .78607 .31278 .7932 .30703 .79002 .30268 Mtetra
.812 .818 .855 r
.79002 .30268 .7932 .30703 .80032 .3011 .79715 .2967 Mtetra
0 .051 .573 r
.14854 .43295 .15255 .43746 .15752 .44226 .1535 .43779 Mtetra
0 .091 .611 r
.1535 .43779 .15752 .44226 .16255 .44681 .15852 .4424 Mtetra
0 .132 .647 r
.15852 .4424 .16255 .44681 .16764 .45112 .16361 .44675 Mtetra
0 .171 .681 r
.16361 .44675 .16764 .45112 .1728 .45519 .16875 .45087 Mtetra
0 .21 .713 r
.16875 .45087 .1728 .45519 .17801 .45903 .17396 .45476 Mtetra
0 .248 .743 r
.17396 .45476 .17801 .45903 .18328 .46264 .17922 .45842 Mtetra
0 .284 .771 r
.17922 .45842 .18328 .46264 .1886 .46603 .18454 .46185 Mtetra
0 .319 .796 r
.18454 .46185 .1886 .46603 .19398 .46921 .18991 .46507 Mtetra
0 .352 .82 r
.18991 .46507 .19398 .46921 .19941 .47217 .19533 .46808 Mtetra
0 .384 .84 r
.19533 .46808 .19941 .47217 .20488 .47493 .2008 .47088 Mtetra
.019 .414 .859 r
.2008 .47088 .20488 .47493 .21041 .47749 .20633 .47348 Mtetra
.057 .442 .876 r
.20633 .47348 .21041 .47749 .21599 .47986 .2119 .47589 Mtetra
.093 .468 .891 r
.2119 .47589 .21599 .47986 .22161 .48203 .21752 .47811 Mtetra
.128 .493 .904 r
.21752 .47811 .22161 .48203 .22727 .48403 .22318 .48014 Mtetra
.16 .516 .915 r
.22318 .48014 .22727 .48403 .23298 .48584 .22889 .48199 Mtetra
.191 .537 .925 r
.22889 .48199 .23298 .48584 .23874 .48748 .23464 .48367 Mtetra
.22 .557 .934 r
.23464 .48367 .23874 .48748 .24453 .48895 .24044 .48517 Mtetra
.248 .575 .942 r
.24044 .48517 .24453 .48895 .25036 .49025 .24627 .48651 Mtetra
.273 .592 .948 r
.24627 .48651 .25036 .49025 .25623 .4914 .25214 .48769 Mtetra
.298 .608 .954 r
.25214 .48769 .25623 .4914 .26214 .49239 .25805 .48871 Mtetra
.32 .623 .958 r
.25805 .48871 .26214 .49239 .26809 .49323 .264 .48959 Mtetra
.342 .636 .962 r
.264 .48959 .26809 .49323 .27407 .49393 .26999 .49031 Mtetra
.362 .649 .965 r
.26999 .49031 .27407 .49393 .28009 .49448 .276 .4909 Mtetra
.381 .661 .968 r
.276 .4909 .28009 .49448 .28614 .4949 .28206 .49134 Mtetra
.399 .672 .97 r
.28206 .49134 .28614 .4949 .29222 .49518 .28815 .49165 Mtetra
.415 .682 .972 r
.28815 .49165 .29222 .49518 .29834 .49534 .29426 .49184 Mtetra
.431 .691 .974 r
.29426 .49184 .29834 .49534 .30448 .49537 .30042 .49189 Mtetra
.445 .7 .975 r
.30042 .49189 .30448 .49537 .31066 .49529 .3066 .49183 Mtetra
.459 .708 .975 r
.3066 .49183 .31066 .49529 .31687 .49508 .31281 .49165 Mtetra
.472 .716 .976 r
.31281 .49165 .31687 .49508 .3231 .49476 .31905 .49136 Mtetra
.484 .723 .976 r
.31905 .49136 .3231 .49476 .32936 .49434 .32532 .49095 Mtetra
.496 .73 .977 r
.32532 .49095 .32936 .49434 .33565 .49381 .33161 .49044 Mtetra
.506 .736 .977 r
.33161 .49044 .33565 .49381 .34197 .49318 .33794 .48983 Mtetra
.517 .742 .977 r
.33794 .48983 .34197 .49318 .34831 .49245 .34428 .48912 Mtetra
.526 .747 .976 r
.34428 .48912 .34831 .49245 .35468 .49162 .35066 .48831 Mtetra
.535 .752 .976 r
.35066 .48831 .35468 .49162 .36107 .49071 .35706 .48741 Mtetra
.544 .757 .976 r
.35706 .48741 .36107 .49071 .36749 .4897 .36348 .48642 Mtetra
.552 .762 .975 r
.36348 .48642 .36749 .4897 .37392 .48861 .36993 .48534 Mtetra
.559 .766 .975 r
.36993 .48534 .37392 .48861 .38039 .48743 .3764 .48418 Mtetra
.567 .77 .974 r
.3764 .48418 .38039 .48743 .38687 .48618 .3829 .48294 Mtetra
.573 .774 .974 r
.3829 .48294 .38687 .48618 .39338 .48485 .38941 .48162 Mtetra
.58 .777 .973 r
.38941 .48162 .39338 .48485 .39991 .48344 .39595 .48022 Mtetra
.586 .781 .972 r
.39595 .48022 .39991 .48344 .40646 .48196 .40251 .47875 Mtetra
.592 .784 .972 r
.40251 .47875 .40646 .48196 .41303 .48041 .40909 .47721 Mtetra
.597 .787 .971 r
.40909 .47721 .41303 .48041 .41962 .4788 .41569 .4756 Mtetra
.603 .789 .97 r
.41569 .4756 .41962 .4788 .42623 .47711 .42232 .47392 Mtetra
.608 .792 .97 r
.42232 .47392 .42623 .47711 .43286 .47537 .42896 .47218 Mtetra
.613 .795 .969 r
.42896 .47218 .43286 .47537 .43951 .47356 .43562 .47038 Mtetra
.617 .797 .968 r
.43562 .47038 .43951 .47356 .44618 .47168 .4423 .46851 Mtetra
.622 .799 .967 r
.4423 .46851 .44618 .47168 .45287 .46975 .449 .46658 Mtetra
.626 .801 .966 r
.449 .46658 .45287 .46975 .45958 .46777 .45572 .46459 Mtetra
.63 .803 .966 r
.45572 .46459 .45958 .46777 .46631 .46572 .46246 .46255 Mtetra
.634 .805 .965 r
.46246 .46255 .46631 .46572 .47305 .46362 .46921 .46045 Mtetra
.638 .807 .964 r
.46921 .46045 .47305 .46362 .47981 .46147 .47599 .45829 Mtetra
.642 .808 .963 r
.47599 .45829 .47981 .46147 .48659 .45926 .48278 .45608 Mtetra
.645 .81 .962 r
.48278 .45608 .48659 .45926 .49338 .457 .48959 .45382 Mtetra
.649 .811 .961 r
.48959 .45382 .49338 .457 .5002 .45469 .49641 .4515 Mtetra
.652 .813 .96 r
.49641 .4515 .5002 .45469 .50703 .45232 .50325 .44913 Mtetra
.656 .814 .959 r
.50325 .44913 .50703 .45232 .51387 .44991 .51011 .44671 Mtetra
.659 .815 .958 r
.51011 .44671 .51387 .44991 .52073 .44744 .51699 .44424 Mtetra
.662 .816 .957 r
.51699 .44424 .52073 .44744 .52761 .44492 .52388 .44171 Mtetra
.666 .817 .956 r
.52388 .44171 .52761 .44492 .53451 .44236 .53079 .43913 Mtetra
.669 .818 .955 r
.53079 .43913 .53451 .44236 .54142 .43974 .53771 .4365 Mtetra
.672 .819 .954 r
.53771 .4365 .54142 .43974 .54834 .43707 .54465 .43382 Mtetra
.675 .82 .953 r
.54465 .43382 .54834 .43707 .55528 .43435 .5516 .43109 Mtetra
.679 .821 .952 r
.5516 .43109 .55528 .43435 .56224 .43157 .55857 .4283 Mtetra
.682 .822 .95 r
.55857 .4283 .56224 .43157 .5692 .42875 .56556 .42546 Mtetra
.685 .823 .949 r
.56556 .42546 .5692 .42875 .57619 .42586 .57256 .42256 Mtetra
.688 .823 .947 r
.57256 .42256 .57619 .42586 .58319 .42293 .57957 .4196 Mtetra
.692 .824 .946 r
.57957 .4196 .58319 .42293 .5902 .41993 .58659 .41659 Mtetra
.695 .824 .944 r
.58659 .41659 .5902 .41993 .59722 .41688 .59363 .41352 Mtetra
.698 .825 .943 r
.59363 .41352 .59722 .41688 .60426 .41377 .60069 .41039 Mtetra
.702 .825 .941 r
.60069 .41039 .60426 .41377 .61131 .4106 .60775 .4072 Mtetra
.705 .826 .939 r
.60775 .4072 .61131 .4106 .61838 .40737 .61483 .40394 Mtetra
.709 .826 .937 r
.61483 .40394 .61838 .40737 .62545 .40407 .62192 .40062 Mtetra
.713 .826 .935 r
.62192 .40062 .62545 .40407 .63254 .4007 .62902 .39722 Mtetra
.716 .826 .933 r
.62902 .39722 .63254 .4007 .63964 .39726 .63614 .39376 Mtetra
.72 .827 .931 r
.63614 .39376 .63964 .39726 .64675 .39376 .64326 .39023 Mtetra
.724 .827 .929 r
.64326 .39023 .64675 .39376 .65387 .39017 .65039 .38661 Mtetra
.728 .827 .926 r
.65039 .38661 .65387 .39017 .66099 .38651 .65754 .38292 Mtetra
.732 .827 .924 r
.65754 .38292 .66099 .38651 .66813 .38277 .66469 .37915 Mtetra
.736 .827 .921 r
.66469 .37915 .66813 .38277 .67528 .37894 .67185 .37529 Mtetra
.74 .827 .918 r
.67185 .37529 .67528 .37894 .68243 .37503 .67902 .37134 Mtetra
.744 .827 .915 r
.67902 .37134 .68243 .37503 .68959 .37102 .68619 .3673 Mtetra
.748 .826 .912 r
.68619 .3673 .68959 .37102 .69676 .36692 .69337 .36316 Mtetra
.752 .826 .909 r
.69337 .36316 .69676 .36692 .70393 .36272 .70056 .35892 Mtetra
.757 .826 .906 r
.70056 .35892 .70393 .36272 .71111 .35841 .70775 .35457 Mtetra
.761 .826 .902 r
.70775 .35457 .71111 .35841 .71829 .354 .71495 .35012 Mtetra
.766 .825 .899 r
.71495 .35012 .71829 .354 .72547 .34947 .72214 .34554 Mtetra
.77 .825 .895 r
.72214 .34554 .72547 .34947 .73265 .34482 .72934 .34085 Mtetra
.775 .824 .891 r
.72934 .34085 .73265 .34482 .73984 .34005 .73654 .33604 Mtetra
.78 .824 .887 r
.73654 .33604 .73984 .34005 .74702 .33515 .74374 .33109 Mtetra
.784 .823 .883 r
.74374 .33109 .74702 .33515 .7542 .33011 .75093 .326 Mtetra
.789 .822 .878 r
.75093 .326 .7542 .33011 .76138 .32493 .75812 .32077 Mtetra
.794 .822 .874 r
.75812 .32077 .76138 .32493 .76855 .31961 .76531 .3154 Mtetra
.799 .821 .869 r
.76531 .3154 .76855 .31961 .77571 .31413 .77248 .30986 Mtetra
.804 .82 .864 r
.77248 .30986 .77571 .31413 .78287 .30849 .77966 .30417 Mtetra
.808 .819 .859 r
.77966 .30417 .78287 .30849 .79002 .30268 .78681 .2983 Mtetra
.813 .818 .854 r
.78681 .2983 .79002 .30268 .79715 .2967 .79396 .29226 Mtetra
0 .046 .571 r
.14452 .42835 .14854 .43295 .1535 .43779 .14947 .43325 Mtetra
0 .086 .608 r
.14947 .43325 .1535 .43779 .15852 .4424 .15449 .43791 Mtetra
0 .126 .644 r
.15449 .43791 .15852 .4424 .16361 .44675 .15956 .44232 Mtetra
0 .166 .678 r
.15956 .44232 .16361 .44675 .16875 .45087 .1647 .44649 Mtetra
0 .204 .71 r
.1647 .44649 .16875 .45087 .17396 .45476 .1699 .45042 Mtetra
0 .242 .74 r
.1699 .45042 .17396 .45476 .17922 .45842 .17515 .45413 Mtetra
0 .278 .767 r
.17515 .45413 .17922 .45842 .18454 .46185 .18046 .45761 Mtetra
0 .313 .793 r
.18046 .45761 .18454 .46185 .18991 .46507 .18582 .46088 Mtetra
0 .346 .816 r
.18582 .46088 .18991 .46507 .19533 .46808 .19124 .46393 Mtetra
0 .378 .837 r
.19124 .46393 .19533 .46808 .2008 .47088 .19671 .46678 Mtetra
.014 .408 .856 r
.19671 .46678 .2008 .47088 .20633 .47348 .20223 .46943 Mtetra
.052 .436 .873 r
.20223 .46943 .20633 .47348 .2119 .47589 .2078 .47188 Mtetra
.088 .462 .888 r
.2078 .47188 .2119 .47589 .21752 .47811 .21342 .47413 Mtetra
.122 .487 .901 r
.21342 .47413 .21752 .47811 .22318 .48014 .21908 .47621 Mtetra
.155 .51 .913 r
.21908 .47621 .22318 .48014 .22889 .48199 .22478 .4781 Mtetra
.185 .532 .923 r
.22478 .4781 .22889 .48199 .23464 .48367 .23053 .47981 Mtetra
.215 .552 .932 r
.23053 .47981 .23464 .48367 .24044 .48517 .23633 .48135 Mtetra
.242 .571 .94 r
.23633 .48135 .24044 .48517 .24627 .48651 .24216 .48273 Mtetra
.268 .588 .946 r
.24216 .48273 .24627 .48651 .25214 .48769 .24803 .48395 Mtetra
.292 .604 .952 r
.24803 .48395 .25214 .48769 .25805 .48871 .25394 .485 Mtetra
.315 .619 .957 r
.25394 .485 .25805 .48871 .264 .48959 .25989 .48591 Mtetra
.337 .633 .961 r
.25989 .48591 .264 .48959 .26999 .49031 .26588 .48667 Mtetra
.357 .646 .965 r
.26588 .48667 .26999 .49031 .276 .4909 .2719 .48728 Mtetra
.376 .658 .967 r
.2719 .48728 .276 .4909 .28206 .49134 .27796 .48776 Mtetra
.394 .669 .97 r
.27796 .48776 .28206 .49134 .28815 .49165 .28405 .4881 Mtetra
.411 .679 .972 r
.28405 .4881 .28815 .49165 .29426 .49184 .29017 .48831 Mtetra
.426 .689 .973 r
.29017 .48831 .29426 .49184 .30042 .49189 .29633 .4884 Mtetra
.441 .698 .975 r
.29633 .4884 .30042 .49189 .3066 .49183 .30251 .48836 Mtetra
.455 .706 .975 r
.30251 .48836 .3066 .49183 .31281 .49165 .30873 .4882 Mtetra
.468 .714 .976 r
.30873 .4882 .31281 .49165 .31905 .49136 .31498 .48793 Mtetra
.481 .722 .977 r
.31498 .48793 .31905 .49136 .32532 .49095 .32125 .48755 Mtetra
.492 .728 .977 r
.32125 .48755 .32532 .49095 .33161 .49044 .32755 .48706 Mtetra
.503 .735 .977 r
.32755 .48706 .33161 .49044 .33794 .48983 .33388 .48647 Mtetra
.513 .741 .977 r
.33388 .48647 .33794 .48983 .34428 .48912 .34024 .48578 Mtetra
.523 .746 .977 r
.34024 .48578 .34428 .48912 .35066 .48831 .34662 .48499 Mtetra
.532 .752 .977 r
.34662 .48499 .35066 .48831 .35706 .48741 .35303 .48411 Mtetra
.541 .757 .976 r
.35303 .48411 .35706 .48741 .36348 .48642 .35946 .48313 Mtetra
.549 .761 .976 r
.35946 .48313 .36348 .48642 .36993 .48534 .36592 .48207 Mtetra
.557 .766 .975 r
.36592 .48207 .36993 .48534 .3764 .48418 .3724 .48092 Mtetra
.564 .77 .975 r
.3724 .48092 .3764 .48418 .3829 .48294 .3789 .4797 Mtetra
.571 .774 .974 r
.3789 .4797 .3829 .48294 .38941 .48162 .38543 .47839 Mtetra
.578 .777 .974 r
.38543 .47839 .38941 .48162 .39595 .48022 .39197 .477 Mtetra
.584 .781 .973 r
.39197 .477 .39595 .48022 .40251 .47875 .39854 .47554 Mtetra
.59 .784 .973 r
.39854 .47554 .40251 .47875 .40909 .47721 .40514 .47401 Mtetra
.595 .787 .972 r
.40514 .47401 .40909 .47721 .41569 .4756 .41175 .47241 Mtetra
.601 .79 .971 r
.41175 .47241 .41569 .4756 .42232 .47392 .41838 .47074 Mtetra
.606 .793 .97 r
.41838 .47074 .42232 .47392 .42896 .47218 .42503 .469 Mtetra
.611 .795 .97 r
.42503 .469 .42896 .47218 .43562 .47038 .43171 .4672 Mtetra
.616 .798 .969 r
.43171 .4672 .43562 .47038 .4423 .46851 .4384 .46534 Mtetra
.62 .8 .968 r
.4384 .46534 .4423 .46851 .449 .46658 .44511 .46341 Mtetra
.625 .802 .967 r
.44511 .46341 .449 .46658 .45572 .46459 .45184 .46143 Mtetra
.629 .804 .967 r
.45184 .46143 .45572 .46459 .46246 .46255 .45859 .45938 Mtetra
.633 .806 .966 r
.45859 .45938 .46246 .46255 .46921 .46045 .46536 .45728 Mtetra
.637 .808 .965 r
.46536 .45728 .46921 .46045 .47599 .45829 .47215 .45512 Mtetra
.641 .809 .964 r
.47215 .45512 .47599 .45829 .48278 .45608 .47895 .45291 Mtetra
.644 .811 .963 r
.47895 .45291 .48278 .45608 .48959 .45382 .48577 .45064 Mtetra
.648 .813 .962 r
.48577 .45064 .48959 .45382 .49641 .4515 .49261 .44832 Mtetra
.652 .814 .961 r
.49261 .44832 .49641 .4515 .50325 .44913 .49946 .44595 Mtetra
.655 .815 .96 r
.49946 .44595 .50325 .44913 .51011 .44671 .50634 .44352 Mtetra
.659 .817 .959 r
.50634 .44352 .51011 .44671 .51699 .44424 .51322 .44104 Mtetra
.662 .818 .958 r
.51322 .44104 .51699 .44424 .52388 .44171 .52013 .4385 Mtetra
.665 .819 .957 r
.52013 .4385 .52388 .44171 .53079 .43913 .52705 .43592 Mtetra
.669 .82 .956 r
.52705 .43592 .53079 .43913 .53771 .4365 .53399 .43327 Mtetra
.672 .821 .955 r
.53399 .43327 .53771 .4365 .54465 .43382 .54094 .43058 Mtetra
.675 .822 .954 r
.54094 .43058 .54465 .43382 .5516 .43109 .54791 .42783 Mtetra
.679 .822 .952 r
.54791 .42783 .5516 .43109 .55857 .4283 .55489 .42503 Mtetra
.682 .823 .951 r
.55489 .42503 .55857 .4283 .56556 .42546 .56189 .42217 Mtetra
.685 .824 .95 r
.56189 .42217 .56556 .42546 .57256 .42256 .5689 .41926 Mtetra
.689 .825 .948 r
.5689 .41926 .57256 .42256 .57957 .4196 .57593 .41629 Mtetra
.692 .825 .947 r
.57593 .41629 .57957 .4196 .58659 .41659 .58297 .41326 Mtetra
.696 .826 .945 r
.58297 .41326 .58659 .41659 .59363 .41352 .59003 .41016 Mtetra
.699 .826 .943 r
.59003 .41016 .59363 .41352 .60069 .41039 .59709 .40701 Mtetra
.703 .827 .941 r
.59709 .40701 .60069 .41039 .60775 .4072 .60417 .4038 Mtetra
.706 .827 .94 r
.60417 .4038 .60775 .4072 .61483 .40394 .61127 .40052 Mtetra
.71 .827 .938 r
.61127 .40052 .61483 .40394 .62192 .40062 .61837 .39717 Mtetra
.713 .827 .936 r
.61837 .39717 .62192 .40062 .62902 .39722 .62549 .39375 Mtetra
.717 .828 .933 r
.62549 .39375 .62902 .39722 .63614 .39376 .63262 .39026 Mtetra
.721 .828 .931 r
.63262 .39026 .63614 .39376 .64326 .39023 .63975 .38669 Mtetra
.725 .828 .929 r
.63975 .38669 .64326 .39023 .65039 .38661 .6469 .38305 Mtetra
.729 .828 .926 r
.6469 .38305 .65039 .38661 .65754 .38292 .65406 .37933 Mtetra
.733 .828 .924 r
.65406 .37933 .65754 .38292 .66469 .37915 .66123 .37552 Mtetra
.737 .828 .921 r
.66123 .37552 .66469 .37915 .67185 .37529 .6684 .37163 Mtetra
.741 .828 .918 r
.6684 .37163 .67185 .37529 .67902 .37134 .67559 .36764 Mtetra
.745 .827 .915 r
.67559 .36764 .67902 .37134 .68619 .3673 .68278 .36356 Mtetra
.749 .827 .912 r
.68278 .36356 .68619 .3673 .69337 .36316 .68997 .35939 Mtetra
.754 .827 .909 r
.68997 .35939 .69337 .36316 .70056 .35892 .69717 .35511 Mtetra
.758 .827 .905 r
.69717 .35511 .70056 .35892 .70775 .35457 .70438 .35072 Mtetra
.762 .826 .902 r
.70438 .35072 .70775 .35457 .71495 .35012 .71159 .34622 Mtetra
.767 .826 .898 r
.71159 .34622 .71495 .35012 .72214 .34554 .7188 .3416 Mtetra
.772 .825 .894 r
.7188 .3416 .72214 .34554 .72934 .34085 .72601 .33687 Mtetra
.776 .825 .89 r
.72601 .33687 .72934 .34085 .73654 .33604 .73322 .332 Mtetra
.781 .824 .886 r
.73322 .332 .73654 .33604 .74374 .33109 .74044 .327 Mtetra
.786 .823 .882 r
.74044 .327 .74374 .33109 .75093 .326 .74764 .32187 Mtetra
.79 .822 .877 r
.74764 .32187 .75093 .326 .75812 .32077 .75485 .31659 Mtetra
.795 .822 .873 r
.75485 .31659 .75812 .32077 .76531 .3154 .76205 .31116 Mtetra
.8 .821 .868 r
.76205 .31116 .76531 .3154 .77248 .30986 .76924 .30557 Mtetra
.805 .82 .863 r
.76924 .30557 .77248 .30986 .77966 .30417 .77642 .29981 Mtetra
.81 .819 .858 r
.77642 .29981 .77966 .30417 .78681 .2983 .7836 .29389 Mtetra
.815 .817 .852 r
.7836 .29389 .78681 .2983 .79396 .29226 .79076 .28778 Mtetra
0 .041 .568 r
.1405 .42368 .14452 .42835 .14947 .43325 .14544 .42864 Mtetra
0 .081 .605 r
.14544 .42864 .14947 .43325 .15449 .43791 .15044 .43334 Mtetra
0 .121 .641 r
.15044 .43334 .15449 .43791 .15956 .44232 .15551 .43781 Mtetra
0 .16 .674 r
.15551 .43781 .15956 .44232 .1647 .44649 .16064 .44203 Mtetra
0 .198 .706 r
.16064 .44203 .1647 .44649 .1699 .45042 .16582 .44602 Mtetra
0 .236 .736 r
.16582 .44602 .1699 .45042 .17515 .45413 .17107 .44978 Mtetra
0 .272 .764 r
.17107 .44978 .17515 .45413 .18046 .45761 .17637 .45331 Mtetra
0 .307 .789 r
.17637 .45331 .18046 .45761 .18582 .46088 .18173 .45663 Mtetra
0 .34 .812 r
.18173 .45663 .18582 .46088 .19124 .46393 .18714 .45973 Mtetra
0 .372 .833 r
.18714 .45973 .19124 .46393 .19671 .46678 .19261 .46262 Mtetra
.008 .402 .853 r
.19261 .46262 .19671 .46678 .20223 .46943 .19812 .46532 Mtetra
.046 .43 .87 r
.19812 .46532 .20223 .46943 .2078 .47188 .20369 .46781 Mtetra
.082 .457 .885 r
.20369 .46781 .2078 .47188 .21342 .47413 .2093 .47011 Mtetra
.116 .481 .898 r
.2093 .47011 .21342 .47413 .21908 .47621 .21496 .47223 Mtetra
.149 .505 .91 r
.21496 .47223 .21908 .47621 .22478 .4781 .22066 .47416 Mtetra
.18 .527 .921 r
.22066 .47416 .22478 .4781 .23053 .47981 .22641 .47592 Mtetra
.209 .547 .93 r
.22641 .47592 .23053 .47981 .23633 .48135 .2322 .4775 Mtetra
.236 .566 .938 r
.2322 .4775 .23633 .48135 .24216 .48273 .23803 .47891 Mtetra
.262 .583 .945 r
.23803 .47891 .24216 .48273 .24803 .48395 .24391 .48017 Mtetra
.287 .6 .951 r
.24391 .48017 .24803 .48395 .25394 .485 .24982 .48126 Mtetra
.31 .615 .956 r
.24982 .48126 .25394 .485 .25989 .48591 .25577 .4822 Mtetra
.332 .629 .96 r
.25577 .4822 .25989 .48591 .26588 .48667 .26176 .48299 Mtetra
.352 .642 .964 r
.26176 .48299 .26588 .48667 .2719 .48728 .26778 .48364 Mtetra
.371 .655 .967 r
.26778 .48364 .2719 .48728 .27796 .48776 .27384 .48415 Mtetra
.389 .666 .969 r
.27384 .48415 .27796 .48776 .28405 .4881 .27994 .48452 Mtetra
.406 .677 .971 r
.27994 .48452 .28405 .4881 .29017 .48831 .28606 .48476 Mtetra
.422 .686 .973 r
.28606 .48476 .29017 .48831 .29633 .4884 .29222 .48487 Mtetra
.437 .696 .974 r
.29222 .48487 .29633 .4884 .30251 .48836 .29841 .48486 Mtetra
.451 .704 .975 r
.29841 .48486 .30251 .48836 .30873 .4882 .30463 .48474 Mtetra
.464 .712 .976 r
.30463 .48474 .30873 .4882 .31498 .48793 .31089 .48449 Mtetra
.477 .72 .977 r
.31089 .48449 .31498 .48793 .32125 .48755 .31717 .48413 Mtetra
.489 .727 .977 r
.31717 .48413 .32125 .48755 .32755 .48706 .32347 .48367 Mtetra
.5 .733 .977 r
.32347 .48367 .32755 .48706 .33388 .48647 .32981 .4831 Mtetra
.51 .74 .977 r
.32981 .4831 .33388 .48647 .34024 .48578 .33617 .48243 Mtetra
.52 .745 .977 r
.33617 .48243 .34024 .48578 .34662 .48499 .34256 .48166 Mtetra
.529 .751 .977 r
.34256 .48166 .34662 .48499 .35303 .48411 .34898 .48079 Mtetra
.538 .756 .977 r
.34898 .48079 .35303 .48411 .35946 .48313 .35542 .47984 Mtetra
.546 .761 .977 r
.35542 .47984 .35946 .48313 .36592 .48207 .36188 .47879 Mtetra
.554 .765 .976 r
.36188 .47879 .36592 .48207 .3724 .48092 .36837 .47766 Mtetra
.562 .769 .976 r
.36837 .47766 .3724 .48092 .3789 .4797 .37488 .47645 Mtetra
.569 .773 .975 r
.37488 .47645 .3789 .4797 .38543 .47839 .38142 .47515 Mtetra
.575 .777 .975 r
.38142 .47515 .38543 .47839 .39197 .477 .38798 .47378 Mtetra
.582 .781 .974 r
.38798 .47378 .39197 .477 .39854 .47554 .39456 .47233 Mtetra
.588 .784 .973 r
.39456 .47233 .39854 .47554 .40514 .47401 .40116 .47081 Mtetra
.594 .787 .973 r
.40116 .47081 .40514 .47401 .41175 .47241 .40778 .46921 Mtetra
.599 .79 .972 r
.40778 .46921 .41175 .47241 .41838 .47074 .41443 .46755 Mtetra
.604 .793 .971 r
.41443 .46755 .41838 .47074 .42503 .469 .42109 .46582 Mtetra
.609 .796 .971 r
.42109 .46582 .42503 .469 .43171 .4672 .42777 .46402 Mtetra
.614 .798 .97 r
.42777 .46402 .43171 .4672 .4384 .46534 .43448 .46217 Mtetra
.619 .8 .969 r
.43448 .46217 .4384 .46534 .44511 .46341 .4412 .46024 Mtetra
.623 .803 .968 r
.4412 .46024 .44511 .46341 .45184 .46143 .44794 .45826 Mtetra
.628 .805 .967 r
.44794 .45826 .45184 .46143 .45859 .45938 .4547 .45622 Mtetra
.632 .807 .967 r
.4547 .45622 .45859 .45938 .46536 .45728 .46148 .45412 Mtetra
.636 .809 .966 r
.46148 .45412 .46536 .45728 .47215 .45512 .46828 .45196 Mtetra
.64 .81 .965 r
.46828 .45196 .47215 .45512 .47895 .45291 .4751 .44974 Mtetra
.644 .812 .964 r
.4751 .44974 .47895 .45291 .48577 .45064 .48193 .44747 Mtetra
.647 .814 .963 r
.48193 .44747 .48577 .45064 .49261 .44832 .48878 .44515 Mtetra
.651 .815 .962 r
.48878 .44515 .49261 .44832 .49946 .44595 .49565 .44277 Mtetra
.655 .816 .961 r
.49565 .44277 .49946 .44595 .50634 .44352 .50254 .44033 Mtetra
.658 .818 .96 r
.50254 .44033 .50634 .44352 .51322 .44104 .50944 .43784 Mtetra
.662 .819 .959 r
.50944 .43784 .51322 .44104 .52013 .4385 .51636 .4353 Mtetra
.665 .82 .958 r
.51636 .4353 .52013 .4385 .52705 .43592 .5233 .4327 Mtetra
.669 .821 .957 r
.5233 .4327 .52705 .43592 .53399 .43327 .53025 .43005 Mtetra
.672 .822 .955 r
.53025 .43005 .53399 .43327 .54094 .43058 .53721 .42734 Mtetra
.675 .823 .954 r
.53721 .42734 .54094 .43058 .54791 .42783 .5442 .42458 Mtetra
.679 .824 .953 r
.5442 .42458 .54791 .42783 .55489 .42503 .55119 .42176 Mtetra
.682 .824 .951 r
.55119 .42176 .55489 .42503 .56189 .42217 .55821 .41889 Mtetra
.686 .825 .95 r
.55821 .41889 .56189 .42217 .5689 .41926 .56523 .41596 Mtetra
.689 .826 .949 r
.56523 .41596 .5689 .41926 .57593 .41629 .57227 .41297 Mtetra
.693 .826 .947 r
.57227 .41297 .57593 .41629 .58297 .41326 .57933 .40992 Mtetra
.696 .827 .945 r
.57933 .40992 .58297 .41326 .59003 .41016 .5864 .40681 Mtetra
.7 .827 .944 r
.5864 .40681 .59003 .41016 .59709 .40701 .59348 .40363 Mtetra
.703 .828 .942 r
.59348 .40363 .59709 .40701 .60417 .4038 .60058 .4004 Mtetra
.707 .828 .94 r
.60058 .4004 .60417 .4038 .61127 .40052 .60768 .39709 Mtetra
.71 .828 .938 r
.60768 .39709 .61127 .40052 .61837 .39717 .6148 .39372 Mtetra
.714 .829 .936 r
.6148 .39372 .61837 .39717 .62549 .39375 .62193 .39027 Mtetra
.718 .829 .934 r
.62193 .39027 .62549 .39375 .63262 .39026 .62908 .38675 Mtetra
.722 .829 .931 r
.62908 .38675 .63262 .39026 .63975 .38669 .63623 .38316 Mtetra
.726 .829 .929 r
.63623 .38316 .63975 .38669 .6469 .38305 .64339 .37948 Mtetra
.73 .829 .926 r
.64339 .37948 .6469 .38305 .65406 .37933 .65057 .37573 Mtetra
.734 .829 .924 r
.65057 .37573 .65406 .37933 .66123 .37552 .65775 .37189 Mtetra
.738 .829 .921 r
.65775 .37189 .66123 .37552 .6684 .37163 .66494 .36796 Mtetra
.742 .829 .918 r
.66494 .36796 .6684 .37163 .67559 .36764 .67214 .36394 Mtetra
.746 .828 .915 r
.67214 .36394 .67559 .36764 .68278 .36356 .67934 .35982 Mtetra
.751 .828 .912 r
.67934 .35982 .68278 .36356 .68997 .35939 .68655 .3556 Mtetra
.755 .828 .908 r
.68655 .3556 .68997 .35939 .69717 .35511 .69377 .35128 Mtetra
.759 .827 .905 r
.69377 .35128 .69717 .35511 .70438 .35072 .70099 .34685 Mtetra
.764 .827 .901 r
.70099 .34685 .70438 .35072 .71159 .34622 .70821 .34231 Mtetra
.768 .826 .897 r
.70821 .34231 .71159 .34622 .7188 .3416 .71544 .33764 Mtetra
.773 .826 .893 r
.71544 .33764 .7188 .3416 .72601 .33687 .72267 .33286 Mtetra
.778 .825 .889 r
.72267 .33286 .72601 .33687 .73322 .332 .72989 .32794 Mtetra
.782 .824 .885 r
.72989 .32794 .73322 .332 .74044 .327 .73712 .3229 Mtetra
.787 .823 .881 r
.73712 .3229 .74044 .327 .74764 .32187 .74434 .31771 Mtetra
.792 .822 .876 r
.74434 .31771 .74764 .32187 .75485 .31659 .75156 .31237 Mtetra
.796 .821 .871 r
.75156 .31237 .75485 .31659 .76205 .31116 .75877 .30688 Mtetra
.801 .82 .866 r
.75877 .30688 .76205 .31116 .76924 .30557 .76598 .30123 Mtetra
.806 .819 .861 r
.76598 .30123 .76924 .30557 .77642 .29981 .77318 .29542 Mtetra
.811 .818 .856 r
.77318 .29542 .77642 .29981 .7836 .29389 .78036 .28943 Mtetra
.816 .817 .851 r
.78036 .28943 .7836 .29389 .79076 .28778 .78754 .28326 Mtetra
0 .036 .565 r
.13647 .41892 .1405 .42368 .14544 .42864 .1414 .42394 Mtetra
0 .075 .602 r
.1414 .42394 .14544 .42864 .15044 .43334 .14639 .4287 Mtetra
0 .115 .637 r
.14639 .4287 .15044 .43334 .15551 .43781 .15145 .43322 Mtetra
0 .154 .671 r
.15145 .43322 .15551 .43781 .16064 .44203 .15656 .4375 Mtetra
0 .192 .702 r
.15656 .4375 .16064 .44203 .16582 .44602 .16174 .44154 Mtetra
0 .229 .732 r
.16174 .44154 .16582 .44602 .17107 .44978 .16698 .44536 Mtetra
0 .265 .76 r
.16698 .44536 .17107 .44978 .17637 .45331 .17227 .44894 Mtetra
0 .3 .785 r
.17227 .44894 .17637 .45331 .18173 .45663 .17763 .45231 Mtetra
0 .333 .809 r
.17763 .45231 .18173 .45663 .18714 .45973 .18303 .45547 Mtetra
0 .365 .83 r
.18303 .45547 .18714 .45973 .19261 .46262 .18849 .45841 Mtetra
.003 .395 .849 r
.18849 .45841 .19261 .46262 .19812 .46532 .194 .46115 Mtetra
.04 .424 .866 r
.194 .46115 .19812 .46532 .20369 .46781 .19956 .46369 Mtetra
.076 .45 .882 r
.19956 .46369 .20369 .46781 .2093 .47011 .20517 .46604 Mtetra
.11 .476 .895 r
.20517 .46604 .2093 .47011 .21496 .47223 .21082 .4682 Mtetra
.143 .499 .908 r
.21082 .4682 .21496 .47223 .22066 .47416 .21653 .47018 Mtetra
.174 .521 .918 r
.21653 .47018 .22066 .47416 .22641 .47592 .22227 .47197 Mtetra
.203 .542 .928 r
.22227 .47197 .22641 .47592 .2322 .4775 .22806 .4736 Mtetra
.231 .561 .936 r
.22806 .4736 .2322 .4775 .23803 .47891 .23389 .47505 Mtetra
.257 .579 .943 r
.23389 .47505 .23803 .47891 .24391 .48017 .23977 .47635 Mtetra
.281 .595 .949 r
.23977 .47635 .24391 .48017 .24982 .48126 .24568 .47748 Mtetra
.305 .611 .954 r
.24568 .47748 .24982 .48126 .25577 .4822 .25163 .47846 Mtetra
.326 .625 .959 r
.25163 .47846 .25577 .4822 .26176 .48299 .25762 .47928 Mtetra
.347 .639 .963 r
.25762 .47928 .26176 .48299 .26778 .48364 .26365 .47997 Mtetra
.366 .651 .966 r
.26365 .47997 .26778 .48364 .27384 .48415 .26971 .48051 Mtetra
.384 .663 .968 r
.26971 .48051 .27384 .48415 .27994 .48452 .27581 .48091 Mtetra
.402 .674 .971 r
.27581 .48091 .27994 .48452 .28606 .48476 .28194 .48119 Mtetra
.418 .684 .972 r
.28194 .48119 .28606 .48476 .29222 .48487 .2881 .48133 Mtetra
.433 .693 .974 r
.2881 .48133 .29222 .48487 .29841 .48486 .29429 .48135 Mtetra
.447 .702 .975 r
.29429 .48135 .29841 .48486 .30463 .48474 .30052 .48125 Mtetra
.46 .71 .976 r
.30052 .48125 .30463 .48474 .31089 .48449 .30678 .48103 Mtetra
.473 .718 .977 r
.30678 .48103 .31089 .48449 .31717 .48413 .31306 .4807 Mtetra
.485 .725 .977 r
.31306 .4807 .31717 .48413 .32347 .48367 .31938 .48025 Mtetra
.496 .732 .977 r
.31938 .48025 .32347 .48367 .32981 .4831 .32572 .47971 Mtetra
.507 .738 .978 r
.32572 .47971 .32981 .4831 .33617 .48243 .33209 .47906 Mtetra
.517 .744 .978 r
.33209 .47906 .33617 .48243 .34256 .48166 .33849 .47831 Mtetra
.526 .75 .978 r
.33849 .47831 .34256 .48166 .34898 .48079 .34491 .47747 Mtetra
.535 .755 .977 r
.34491 .47747 .34898 .48079 .35542 .47984 .35136 .47653 Mtetra
.543 .76 .977 r
.35136 .47653 .35542 .47984 .36188 .47879 .35783 .4755 Mtetra
.551 .764 .977 r
.35783 .4755 .36188 .47879 .36837 .47766 .36433 .47439 Mtetra
.559 .769 .976 r
.36433 .47439 .36837 .47766 .37488 .47645 .37085 .47319 Mtetra
.566 .773 .976 r
.37085 .47319 .37488 .47645 .38142 .47515 .37739 .47191 Mtetra
.573 .777 .975 r
.37739 .47191 .38142 .47515 .38798 .47378 .38396 .47055 Mtetra
.58 .78 .975 r
.38396 .47055 .38798 .47378 .39456 .47233 .39055 .46911 Mtetra
.586 .784 .974 r
.39055 .46911 .39456 .47233 .40116 .47081 .39716 .4676 Mtetra
.592 .787 .973 r
.39716 .4676 .40116 .47081 .40778 .46921 .40379 .46601 Mtetra
.597 .79 .973 r
.40379 .46601 .40778 .46921 .41443 .46755 .41045 .46436 Mtetra
.603 .793 .972 r
.41045 .46436 .41443 .46755 .42109 .46582 .41712 .46264 Mtetra
.608 .796 .971 r
.41712 .46264 .42109 .46582 .42777 .46402 .42382 .46085 Mtetra
.613 .798 .971 r
.42382 .46085 .42777 .46402 .43448 .46217 .43053 .45899 Mtetra
.617 .801 .97 r
.43053 .45899 .43448 .46217 .4412 .46024 .43727 .45707 Mtetra
.622 .803 .969 r
.43727 .45707 .4412 .46024 .44794 .45826 .44402 .45509 Mtetra
.626 .805 .968 r
.44402 .45509 .44794 .45826 .4547 .45622 .4508 .45305 Mtetra
.631 .807 .967 r
.4508 .45305 .4547 .45622 .46148 .45412 .45759 .45095 Mtetra
.635 .809 .967 r
.45759 .45095 .46148 .45412 .46828 .45196 .4644 .44879 Mtetra
.639 .811 .966 r
.4644 .44879 .46828 .45196 .4751 .44974 .47123 .44658 Mtetra
.643 .813 .965 r
.47123 .44658 .4751 .44974 .48193 .44747 .47808 .4443 Mtetra
.647 .814 .964 r
.47808 .4443 .48193 .44747 .48878 .44515 .48494 .44197 Mtetra
.65 .816 .963 r
.48494 .44197 .48878 .44515 .49565 .44277 .49182 .43959 Mtetra
.654 .817 .962 r
.49182 .43959 .49565 .44277 .50254 .44033 .49872 .43715 Mtetra
.658 .819 .961 r
.49872 .43715 .50254 .44033 .50944 .43784 .50564 .43465 Mtetra
.661 .82 .96 r
.50564 .43465 .50944 .43784 .51636 .4353 .51257 .4321 Mtetra
.665 .821 .958 r
.51257 .4321 .51636 .4353 .5233 .4327 .51952 .42949 Mtetra
.668 .822 .957 r
.51952 .42949 .5233 .4327 .53025 .43005 .52648 .42683 Mtetra
.672 .823 .956 r
.52648 .42683 .53025 .43005 .53721 .42734 .53347 .42411 Mtetra
.675 .824 .955 r
.53347 .42411 .53721 .42734 .5442 .42458 .54046 .42133 Mtetra
.679 .825 .953 r
.54046 .42133 .5442 .42458 .55119 .42176 .54747 .4185 Mtetra
.682 .826 .952 r
.54747 .4185 .55119 .42176 .55821 .41889 .5545 .41561 Mtetra
.686 .826 .95 r
.5545 .41561 .55821 .41889 .56523 .41596 .56154 .41266 Mtetra
.689 .827 .949 r
.56154 .41266 .56523 .41596 .57227 .41297 .5686 .40965 Mtetra
.693 .827 .947 r
.5686 .40965 .57227 .41297 .57933 .40992 .57567 .40658 Mtetra
.697 .828 .946 r
.57567 .40658 .57933 .40992 .5864 .40681 .58275 .40345 Mtetra
.7 .828 .944 r
.58275 .40345 .5864 .40681 .59348 .40363 .58985 .40025 Mtetra
.704 .829 .942 r
.58985 .40025 .59348 .40363 .60058 .4004 .59696 .39699 Mtetra
.708 .829 .94 r
.59696 .39699 .60058 .4004 .60768 .39709 .60408 .39366 Mtetra
.711 .829 .938 r
.60408 .39366 .60768 .39709 .6148 .39372 .61122 .39026 Mtetra
.715 .83 .936 r
.61122 .39026 .6148 .39372 .62193 .39027 .61836 .38679 Mtetra
.719 .83 .933 r
.61836 .38679 .62193 .39027 .62908 .38675 .62552 .38324 Mtetra
.723 .83 .931 r
.62552 .38324 .62908 .38675 .63623 .38316 .63269 .37961 Mtetra
.727 .83 .929 r
.63269 .37961 .63623 .38316 .64339 .37948 .63987 .37591 Mtetra
.731 .83 .926 r
.63987 .37591 .64339 .37948 .65057 .37573 .64706 .37212 Mtetra
.735 .83 .923 r
.64706 .37212 .65057 .37573 .65775 .37189 .65425 .36824 Mtetra
.739 .829 .92 r
.65425 .36824 .65775 .37189 .66494 .36796 .66146 .36428 Mtetra
.743 .829 .917 r
.66146 .36428 .66494 .36796 .67214 .36394 .66867 .36022 Mtetra
.748 .829 .914 r
.66867 .36022 .67214 .36394 .67934 .35982 .67589 .35606 Mtetra
.752 .829 .911 r
.67589 .35606 .67934 .35982 .68655 .3556 .68312 .3518 Mtetra
.756 .828 .908 r
.68312 .3518 .68655 .3556 .69377 .35128 .69035 .34743 Mtetra
.761 .828 .904 r
.69035 .34743 .69377 .35128 .70099 .34685 .69758 .34296 Mtetra
.765 .827 .9 r
.69758 .34296 .70099 .34685 .70821 .34231 .70482 .33837 Mtetra
.77 .826 .896 r
.70482 .33837 .70821 .34231 .71544 .33764 .71206 .33366 Mtetra
.774 .826 .892 r
.71206 .33366 .71544 .33764 .72267 .33286 .7193 .32882 Mtetra
.779 .825 .888 r
.7193 .32882 .72267 .33286 .72989 .32794 .72654 .32386 Mtetra
.784 .824 .884 r
.72654 .32386 .72989 .32794 .73712 .3229 .73378 .31876 Mtetra
.788 .823 .879 r
.73378 .31876 .73712 .3229 .74434 .31771 .74102 .31351 Mtetra
.793 .822 .875 r
.74102 .31351 .74434 .31771 .75156 .31237 .74825 .30812 Mtetra
.798 .821 .87 r
.74825 .30812 .75156 .31237 .75877 .30688 .75548 .30257 Mtetra
.803 .82 .865 r
.75548 .30257 .75877 .30688 .76598 .30123 .7627 .29686 Mtetra
.807 .819 .86 r
.7627 .29686 .76598 .30123 .77318 .29542 .76991 .29099 Mtetra
.812 .817 .854 r
.76991 .29099 .77318 .29542 .78036 .28943 .77711 .28493 Mtetra
.817 .816 .849 r
.77711 .28493 .78036 .28943 .78754 .28326 .7843 .2787 Mtetra
0 .03 .562 r
.13244 .41407 .13647 .41892 .1414 .42394 .13735 .41915 Mtetra
0 .069 .599 r
.13735 .41915 .1414 .42394 .14639 .4287 .14233 .42398 Mtetra
0 .109 .634 r
.14233 .42398 .14639 .4287 .15145 .43322 .14738 .42856 Mtetra
0 .147 .667 r
.14738 .42856 .15145 .43322 .15656 .4375 .15248 .4329 Mtetra
0 .186 .699 r
.15248 .4329 .15656 .4375 .16174 .44154 .15765 .437 Mtetra
0 .223 .728 r
.15765 .437 .16174 .44154 .16698 .44536 .16288 .44087 Mtetra
0 .259 .756 r
.16288 .44087 .16698 .44536 .17227 .44894 .16817 .44451 Mtetra
0 .293 .781 r
.16817 .44451 .17227 .44894 .17763 .45231 .17351 .44793 Mtetra
0 .327 .805 r
.17351 .44793 .17763 .45231 .18303 .45547 .17891 .45114 Mtetra
0 .358 .826 r
.17891 .45114 .18303 .45547 .18849 .45841 .18436 .45413 Mtetra
0 .389 .845 r
.18436 .45413 .18849 .45841 .194 .46115 .18986 .45692 Mtetra
.034 .417 .863 r
.18986 .45692 .194 .46115 .19956 .46369 .19542 .45951 Mtetra
.07 .444 .878 r
.19542 .45951 .19956 .46369 .20517 .46604 .20102 .46191 Mtetra
.104 .469 .892 r
.20102 .46191 .20517 .46604 .21082 .4682 .20668 .46412 Mtetra
.137 .493 .905 r
.20668 .46412 .21082 .4682 .21653 .47018 .21237 .46614 Mtetra
.168 .515 .916 r
.21237 .46614 .21653 .47018 .22227 .47197 .21812 .46798 Mtetra
.197 .536 .925 r
.21812 .46798 .22227 .47197 .22806 .4736 .22391 .46965 Mtetra
.225 .556 .933 r
.22391 .46965 .22806 .4736 .23389 .47505 .22974 .47115 Mtetra
.251 .574 .941 r
.22974 .47115 .23389 .47505 .23977 .47635 .23561 .47248 Mtetra
.276 .591 .947 r
.23561 .47248 .23977 .47635 .24568 .47748 .24152 .47366 Mtetra
.299 .606 .953 r
.24152 .47366 .24568 .47748 .25163 .47846 .24748 .47467 Mtetra
.321 .621 .957 r
.24748 .47467 .25163 .47846 .25762 .47928 .25347 .47554 Mtetra
.342 .635 .961 r
.25347 .47554 .25762 .47928 .26365 .47997 .25949 .47626 Mtetra
.361 .647 .965 r
.25949 .47626 .26365 .47997 .26971 .48051 .26556 .47683 Mtetra
.38 .659 .968 r
.26556 .47683 .26971 .48051 .27581 .48091 .27166 .47727 Mtetra
.397 .67 .97 r
.27166 .47727 .27581 .48091 .28194 .48119 .27779 .47758 Mtetra
.413 .681 .972 r
.27779 .47758 .28194 .48119 .2881 .48133 .28396 .47775 Mtetra
.428 .69 .974 r
.28396 .47775 .2881 .48133 .29429 .48135 .29016 .4778 Mtetra
.443 .699 .975 r
.29016 .4778 .29429 .48135 .30052 .48125 .29639 .47773 Mtetra
.456 .708 .976 r
.29639 .47773 .30052 .48125 .30678 .48103 .30265 .47754 Mtetra
.469 .716 .977 r
.30265 .47754 .30678 .48103 .31306 .4807 .30894 .47724 Mtetra
.481 .723 .977 r
.30894 .47724 .31306 .4807 .31938 .48025 .31526 .47682 Mtetra
.492 .73 .978 r
.31526 .47682 .31938 .48025 .32572 .47971 .32161 .4763 Mtetra
.503 .736 .978 r
.32161 .4763 .32572 .47971 .33209 .47906 .32798 .47567 Mtetra
.513 .743 .978 r
.32798 .47567 .33209 .47906 .33849 .47831 .33439 .47495 Mtetra
.523 .748 .978 r
.33439 .47495 .33849 .47831 .34491 .47747 .34082 .47412 Mtetra
.532 .754 .978 r
.34082 .47412 .34491 .47747 .35136 .47653 .34727 .4732 Mtetra
.541 .759 .977 r
.34727 .4732 .35136 .47653 .35783 .4755 .35375 .4722 Mtetra
.549 .764 .977 r
.35375 .4722 .35783 .4755 .36433 .47439 .36026 .4711 Mtetra
.556 .768 .977 r
.36026 .4711 .36433 .47439 .37085 .47319 .36679 .46992 Mtetra
.564 .772 .976 r
.36679 .46992 .37085 .47319 .37739 .47191 .37334 .46865 Mtetra
.571 .776 .976 r
.37334 .46865 .37739 .47191 .38396 .47055 .37992 .4673 Mtetra
.577 .78 .975 r
.37992 .4673 .38396 .47055 .39055 .46911 .38652 .46588 Mtetra
.584 .784 .975 r
.38652 .46588 .39055 .46911 .39716 .4676 .39314 .46438 Mtetra
.59 .787 .974 r
.39314 .46438 .39716 .4676 .40379 .46601 .39979 .46281 Mtetra
.595 .79 .973 r
.39979 .46281 .40379 .46601 .41045 .46436 .40645 .46116 Mtetra
.601 .793 .973 r
.40645 .46116 .41045 .46436 .41712 .46264 .41314 .45945 Mtetra
.606 .796 .972 r
.41314 .45945 .41712 .46264 .42382 .46085 .41984 .45766 Mtetra
.611 .799 .971 r
.41984 .45766 .42382 .46085 .43053 .45899 .42657 .45581 Mtetra
.616 .801 .971 r
.42657 .45581 .43053 .45899 .43727 .45707 .43332 .4539 Mtetra
.621 .803 .97 r
.43332 .4539 .43727 .45707 .44402 .45509 .44008 .45192 Mtetra
.625 .806 .969 r
.44008 .45192 .44402 .45509 .4508 .45305 .44687 .44989 Mtetra
.63 .808 .968 r
.44687 .44989 .4508 .45305 .45759 .45095 .45367 .44779 Mtetra
.634 .81 .967 r
.45367 .44779 .45759 .45095 .4644 .44879 .4605 .44563 Mtetra
.638 .812 .966 r
.4605 .44563 .4644 .44879 .47123 .44658 .46734 .44341 Mtetra
.642 .813 .965 r
.46734 .44341 .47123 .44658 .47808 .4443 .4742 .44113 Mtetra
.646 .815 .964 r
.4742 .44113 .47808 .4443 .48494 .44197 .48108 .4388 Mtetra
.65 .817 .963 r
.48108 .4388 .48494 .44197 .49182 .43959 .48797 .43641 Mtetra
.654 .818 .962 r
.48797 .43641 .49182 .43959 .49872 .43715 .49488 .43396 Mtetra
.657 .819 .961 r
.49488 .43396 .49872 .43715 .50564 .43465 .50181 .43145 Mtetra
.661 .821 .96 r
.50181 .43145 .50564 .43465 .51257 .4321 .50876 .42889 Mtetra
.665 .822 .959 r
.50876 .42889 .51257 .4321 .51952 .42949 .51572 .42627 Mtetra
.668 .823 .958 r
.51572 .42627 .51952 .42949 .52648 .42683 .5227 .4236 Mtetra
.672 .824 .956 r
.5227 .4236 .52648 .42683 .53347 .42411 .5297 .42087 Mtetra
.676 .825 .955 r
.5297 .42087 .53347 .42411 .54046 .42133 .53671 .41808 Mtetra
.679 .826 .954 r
.53671 .41808 .54046 .42133 .54747 .4185 .54373 .41523 Mtetra
.683 .826 .952 r
.54373 .41523 .54747 .4185 .5545 .41561 .55078 .41233 Mtetra
.686 .827 .951 r
.55078 .41233 .5545 .41561 .56154 .41266 .55783 .40936 Mtetra
.69 .828 .949 r
.55783 .40936 .56154 .41266 .5686 .40965 .5649 .40633 Mtetra
.694 .828 .947 r
.5649 .40633 .5686 .40965 .57567 .40658 .57199 .40324 Mtetra
.697 .829 .946 r
.57199 .40324 .57567 .40658 .58275 .40345 .57909 .40009 Mtetra
.701 .829 .944 r
.57909 .40009 .58275 .40345 .58985 .40025 .5862 .39687 Mtetra
.705 .83 .942 r
.5862 .39687 .58985 .40025 .59696 .39699 .59332 .39358 Mtetra
.708 .83 .94 r
.59332 .39358 .59696 .39699 .60408 .39366 .60046 .39022 Mtetra
.712 .83 .938 r
.60046 .39022 .60408 .39366 .61122 .39026 .60761 .38679 Mtetra
.716 .83 .936 r
.60761 .38679 .61122 .39026 .61836 .38679 .61477 .38329 Mtetra
.72 .83 .933 r
.61477 .38329 .61836 .38679 .62552 .38324 .62195 .37971 Mtetra
.724 .83 .931 r
.62195 .37971 .62552 .38324 .63269 .37961 .62913 .37606 Mtetra
.728 .83 .928 r
.62913 .37606 .63269 .37961 .63987 .37591 .63632 .37232 Mtetra
.732 .83 .926 r
.63632 .37232 .63987 .37591 .64706 .37212 .64353 .36849 Mtetra
.736 .83 .923 r
.64353 .36849 .64706 .37212 .65425 .36824 .65074 .36458 Mtetra
.74 .83 .92 r
.65074 .36458 .65425 .36824 .66146 .36428 .65796 .36058 Mtetra
.745 .83 .917 r
.65796 .36058 .66146 .36428 .66867 .36022 .66519 .35648 Mtetra
.749 .829 .914 r
.66519 .35648 .66867 .36022 .67589 .35606 .67242 .35228 Mtetra
.753 .829 .91 r
.67242 .35228 .67589 .35606 .68312 .3518 .67966 .34798 Mtetra
.758 .828 .907 r
.67966 .34798 .68312 .3518 .69035 .34743 .68691 .34357 Mtetra
.762 .828 .903 r
.68691 .34357 .69035 .34743 .69758 .34296 .69416 .33905 Mtetra
.767 .827 .899 r
.69416 .33905 .69758 .34296 .70482 .33837 .70141 .33441 Mtetra
.771 .826 .895 r
.70141 .33441 .70482 .33837 .71206 .33366 .70867 .32965 Mtetra
.776 .826 .891 r
.70867 .32965 .71206 .33366 .7193 .32882 .71592 .32476 Mtetra
.78 .825 .887 r
.71592 .32476 .7193 .32882 .72654 .32386 .72318 .31974 Mtetra
.785 .824 .883 r
.72318 .31974 .72654 .32386 .73378 .31876 .73043 .31459 Mtetra
.79 .823 .878 r
.73043 .31459 .73378 .31876 .74102 .31351 .73768 .30928 Mtetra
.794 .822 .873 r
.73768 .30928 .74102 .31351 .74825 .30812 .74493 .30383 Mtetra
.799 .821 .868 r
.74493 .30383 .74825 .30812 .75548 .30257 .75217 .29822 Mtetra
.804 .819 .863 r
.75217 .29822 .75548 .30257 .7627 .29686 .7594 .29245 Mtetra
.809 .818 .858 r
.7594 .29245 .7627 .29686 .76991 .29099 .76663 .28651 Mtetra
.813 .817 .853 r
.76663 .28651 .76991 .29099 .77711 .28493 .77384 .28039 Mtetra
.818 .815 .847 r
.77384 .28039 .77711 .28493 .7843 .2787 .78104 .27409 Mtetra
0 .024 .559 r
.1284 .40914 .13244 .41407 .13735 .41915 .1333 .41428 Mtetra
0 .063 .595 r
.1333 .41428 .13735 .41915 .14233 .42398 .13827 .41917 Mtetra
0 .102 .63 r
.13827 .41917 .14233 .42398 .14738 .42856 .1433 .42381 Mtetra
0 .141 .663 r
.1433 .42381 .14738 .42856 .15248 .4329 .14839 .42821 Mtetra
0 .179 .694 r
.14839 .42821 .15248 .4329 .15765 .437 .15355 .43237 Mtetra
0 .216 .724 r
.15355 .43237 .15765 .437 .16288 .44087 .15877 .4363 Mtetra
0 .252 .751 r
.15877 .4363 .16288 .44087 .16817 .44451 .16405 .44 Mtetra
0 .286 .777 r
.16405 .44 .16817 .44451 .17351 .44793 .16938 .44348 Mtetra
0 .32 .8 r
.16938 .44348 .17351 .44793 .17891 .45114 .17477 .44674 Mtetra
0 .351 .822 r
.17477 .44674 .17891 .45114 .18436 .45413 .18022 .44979 Mtetra
0 .382 .841 r
.18022 .44979 .18436 .45413 .18986 .45692 .18572 .45263 Mtetra
.028 .41 .859 r
.18572 .45263 .18986 .45692 .19542 .45951 .19127 .45528 Mtetra
.064 .437 .875 r
.19127 .45528 .19542 .45951 .20102 .46191 .19687 .45772 Mtetra
.098 .463 .889 r
.19687 .45772 .20102 .46191 .20668 .46412 .20251 .45998 Mtetra
.131 .487 .902 r
.20251 .45998 .20668 .46412 .21237 .46614 .20821 .46205 Mtetra
.162 .509 .913 r
.20821 .46205 .21237 .46614 .21812 .46798 .21395 .46394 Mtetra
.191 .53 .922 r
.21395 .46394 .21812 .46798 .22391 .46965 .21974 .46565 Mtetra
.219 .55 .931 r
.21974 .46565 .22391 .46965 .22974 .47115 .22557 .4672 Mtetra
.245 .568 .939 r
.22557 .4672 .22974 .47115 .23561 .47248 .23144 .46857 Mtetra
.27 .586 .945 r
.23144 .46857 .23561 .47248 .24152 .47366 .23735 .46979 Mtetra
.294 .601 .951 r
.23735 .46979 .24152 .47366 .24748 .47467 .2433 .47085 Mtetra
.316 .616 .956 r
.2433 .47085 .24748 .47467 .25347 .47554 .24929 .47175 Mtetra
.337 .63 .96 r
.24929 .47175 .25347 .47554 .25949 .47626 .25532 .47251 Mtetra
.356 .643 .964 r
.25532 .47251 .25949 .47626 .26556 .47683 .26139 .47312 Mtetra
.375 .655 .967 r
.26139 .47312 .26556 .47683 .27166 .47727 .26749 .4736 Mtetra
.392 .667 .969 r
.26749 .4736 .27166 .47727 .27779 .47758 .27363 .47394 Mtetra
.408 .677 .971 r
.27363 .47394 .27779 .47758 .28396 .47775 .2798 .47415 Mtetra
.424 .687 .973 r
.2798 .47415 .28396 .47775 .29016 .4778 .286 .47423 Mtetra
.438 .696 .974 r
.286 .47423 .29016 .4778 .29639 .47773 .29223 .47419 Mtetra
.452 .705 .976 r
.29223 .47419 .29639 .47773 .30265 .47754 .2985 .47403 Mtetra
.465 .713 .976 r
.2985 .47403 .30265 .47754 .30894 .47724 .3048 .47375 Mtetra
.477 .721 .977 r
.3048 .47375 .30894 .47724 .31526 .47682 .31112 .47336 Mtetra
.489 .728 .978 r
.31112 .47336 .31526 .47682 .32161 .4763 .31748 .47287 Mtetra
.5 .735 .978 r
.31748 .47287 .32161 .4763 .32798 .47567 .32386 .47226 Mtetra
.51 .741 .978 r
.32386 .47226 .32798 .47567 .33439 .47495 .33027 .47156 Mtetra
.52 .747 .978 r
.33027 .47156 .33439 .47495 .34082 .47412 .33671 .47076 Mtetra
.529 .752 .978 r
.33671 .47076 .34082 .47412 .34727 .4732 .34317 .46986 Mtetra
.538 .758 .978 r
.34317 .46986 .34727 .4732 .35375 .4722 .34966 .46887 Mtetra
.546 .762 .977 r
.34966 .46887 .35375 .4722 .36026 .4711 .35618 .4678 Mtetra
.554 .767 .977 r
.35618 .4678 .36026 .4711 .36679 .46992 .36271 .46663 Mtetra
.561 .771 .977 r
.36271 .46663 .36679 .46992 .37334 .46865 .36928 .46538 Mtetra
.568 .776 .976 r
.36928 .46538 .37334 .46865 .37992 .4673 .37586 .46405 Mtetra
.575 .779 .976 r
.37586 .46405 .37992 .4673 .38652 .46588 .38247 .46264 Mtetra
.582 .783 .975 r
.38247 .46264 .38652 .46588 .39314 .46438 .3891 .46115 Mtetra
.588 .787 .975 r
.3891 .46115 .39314 .46438 .39979 .46281 .39576 .45959 Mtetra
.594 .79 .974 r
.39576 .45959 .39979 .46281 .40645 .46116 .40243 .45795 Mtetra
.599 .793 .973 r
.40243 .45795 .40645 .46116 .41314 .45945 .40913 .45625 Mtetra
.605 .796 .973 r
.40913 .45625 .41314 .45945 .41984 .45766 .41585 .45447 Mtetra
.61 .799 .972 r
.41585 .45447 .41984 .45766 .42657 .45581 .42259 .45263 Mtetra
.615 .801 .971 r
.42259 .45263 .42657 .45581 .43332 .4539 .42934 .45072 Mtetra
.62 .804 .97 r
.42934 .45072 .43332 .4539 .44008 .45192 .43612 .44875 Mtetra
.624 .806 .97 r
.43612 .44875 .44008 .45192 .44687 .44989 .44292 .44671 Mtetra
.629 .808 .969 r
.44292 .44671 .44687 .44989 .45367 .44779 .44974 .44461 Mtetra
.633 .81 .968 r
.44974 .44461 .45367 .44779 .4605 .44563 .45657 .44245 Mtetra
.637 .812 .967 r
.45657 .44245 .4605 .44563 .46734 .44341 .46343 .44023 Mtetra
.641 .814 .966 r
.46343 .44023 .46734 .44341 .4742 .44113 .4703 .43795 Mtetra
.645 .816 .965 r
.4703 .43795 .4742 .44113 .48108 .4388 .47719 .43562 Mtetra
.649 .817 .964 r
.47719 .43562 .48108 .4388 .48797 .43641 .4841 .43322 Mtetra
.653 .819 .963 r
.4841 .43322 .48797 .43641 .49488 .43396 .49103 .43076 Mtetra
.657 .82 .962 r
.49103 .43076 .49488 .43396 .50181 .43145 .49797 .42825 Mtetra
.661 .821 .961 r
.49797 .42825 .50181 .43145 .50876 .42889 .50493 .42568 Mtetra
.665 .822 .959 r
.50493 .42568 .50876 .42889 .51572 .42627 .51191 .42305 Mtetra
.668 .824 .958 r
.51191 .42305 .51572 .42627 .5227 .4236 .5189 .42037 Mtetra
.672 .825 .957 r
.5189 .42037 .5227 .4236 .5297 .42087 .52591 .41762 Mtetra
.676 .826 .955 r
.52591 .41762 .5297 .42087 .53671 .41808 .53294 .41482 Mtetra
.679 .826 .954 r
.53294 .41482 .53671 .41808 .54373 .41523 .53998 .41196 Mtetra
.683 .827 .953 r
.53998 .41196 .54373 .41523 .55078 .41233 .54703 .40903 Mtetra
.687 .828 .951 r
.54703 .40903 .55078 .41233 .55783 .40936 .5541 .40605 Mtetra
.69 .829 .949 r
.5541 .40605 .55783 .40936 .5649 .40633 .56119 .403 Mtetra
.694 .829 .948 r
.56119 .403 .5649 .40633 .57199 .40324 .56829 .39989 Mtetra
.698 .83 .946 r
.56829 .39989 .57199 .40324 .57909 .40009 .5754 .39671 Mtetra
.702 .83 .944 r
.5754 .39671 .57909 .40009 .5862 .39687 .58253 .39347 Mtetra
.705 .83 .942 r
.58253 .39347 .5862 .39687 .59332 .39358 .58967 .39016 Mtetra
.709 .831 .94 r
.58967 .39016 .59332 .39358 .60046 .39022 .59682 .38677 Mtetra
.713 .831 .938 r
.59682 .38677 .60046 .39022 .60761 .38679 .60399 .38332 Mtetra
.717 .831 .935 r
.60399 .38332 .60761 .38679 .61477 .38329 .61116 .37978 Mtetra
.721 .831 .933 r
.61116 .37978 .61477 .38329 .62195 .37971 .61835 .37618 Mtetra
.725 .831 .93 r
.61835 .37618 .62195 .37971 .62913 .37606 .62555 .37248 Mtetra
.729 .831 .928 r
.62555 .37248 .62913 .37606 .63632 .37232 .63276 .36871 Mtetra
.733 .831 .925 r
.63276 .36871 .63632 .37232 .64353 .36849 .63998 .36485 Mtetra
.737 .831 .922 r
.63998 .36485 .64353 .36849 .65074 .36458 .64721 .3609 Mtetra
.742 .83 .919 r
.64721 .3609 .65074 .36458 .65796 .36058 .65444 .35686 Mtetra
.746 .83 .916 r
.65444 .35686 .65796 .36058 .66519 .35648 .66168 .35272 Mtetra
.75 .83 .913 r
.66168 .35272 .66519 .35648 .67242 .35228 .66893 .34848 Mtetra
.755 .829 .909 r
.66893 .34848 .67242 .35228 .67966 .34798 .67619 .34413 Mtetra
.759 .828 .906 r
.67619 .34413 .67966 .34798 .68691 .34357 .68345 .33967 Mtetra
.764 .828 .902 r
.68345 .33967 .68691 .34357 .69416 .33905 .69072 .33511 Mtetra
.768 .827 .898 r
.69072 .33511 .69416 .33905 .70141 .33441 .69798 .33042 Mtetra
.773 .826 .894 r
.69798 .33042 .70141 .33441 .70867 .32965 .70525 .32561 Mtetra
.777 .825 .89 r
.70525 .32561 .70867 .32965 .71592 .32476 .71252 .32067 Mtetra
.782 .824 .886 r
.71252 .32067 .71592 .32476 .72318 .31974 .71979 .31559 Mtetra
.786 .823 .881 r
.71979 .31559 .72318 .31974 .73043 .31459 .72706 .31038 Mtetra
.791 .822 .877 r
.72706 .31038 .73043 .31459 .73768 .30928 .73433 .30502 Mtetra
.796 .821 .872 r
.73433 .30502 .73768 .30928 .74493 .30383 .74159 .2995 Mtetra
.801 .82 .867 r
.74159 .2995 .74493 .30383 .75217 .29822 .74884 .29383 Mtetra
.805 .819 .862 r
.74884 .29383 .75217 .29822 .7594 .29245 .75609 .28799 Mtetra
.81 .817 .856 r
.75609 .28799 .7594 .29245 .76663 .28651 .76332 .28198 Mtetra
.815 .816 .851 r
.76332 .28198 .76663 .28651 .77384 .28039 .77055 .27579 Mtetra
.819 .814 .845 r
.77055 .27579 .77384 .28039 .78104 .27409 .77776 .26942 Mtetra
0 .018 .556 r
.12436 .40411 .1284 .40914 .1333 .41428 .12924 .40932 Mtetra
0 .057 .592 r
.12924 .40932 .1333 .41428 .13827 .41917 .1342 .41428 Mtetra
0 .096 .626 r
.1342 .41428 .13827 .41917 .1433 .42381 .13921 .41898 Mtetra
0 .134 .659 r
.13921 .41898 .1433 .42381 .14839 .42821 .1443 .42344 Mtetra
0 .172 .69 r
.1443 .42344 .14839 .42821 .15355 .43237 .14944 .42767 Mtetra
0 .209 .72 r
.14944 .42767 .15355 .43237 .15877 .4363 .15465 .43165 Mtetra
0 .245 .747 r
.15465 .43165 .15877 .4363 .16405 .44 .15992 .43541 Mtetra
0 .279 .773 r
.15992 .43541 .16405 .44 .16938 .44348 .16525 .43895 Mtetra
0 .312 .796 r
.16525 .43895 .16938 .44348 .17477 .44674 .17063 .44227 Mtetra
0 .344 .818 r
.17063 .44227 .17477 .44674 .18022 .44979 .17607 .44538 Mtetra
0 .375 .837 r
.17607 .44538 .18022 .44979 .18572 .45263 .18156 .44828 Mtetra
.022 .403 .855 r
.18156 .44828 .18572 .45263 .19127 .45528 .1871 .45097 Mtetra
.058 .431 .871 r
.1871 .45097 .19127 .45528 .19687 .45772 .1927 .45347 Mtetra
.092 .456 .886 r
.1927 .45347 .19687 .45772 .20251 .45998 .19834 .45578 Mtetra
.125 .48 .898 r
.19834 .45578 .20251 .45998 .20821 .46205 .20403 .4579 Mtetra
.156 .503 .91 r
.20403 .4579 .20821 .46205 .21395 .46394 .20977 .45984 Mtetra
.185 .524 .92 r
.20977 .45984 .21395 .46394 .21974 .46565 .21555 .4616 Mtetra
.213 .544 .929 r
.21555 .4616 .21974 .46565 .22557 .4672 .22138 .46319 Mtetra
.239 .563 .936 r
.22138 .46319 .22557 .4672 .23144 .46857 .22725 .46461 Mtetra
.264 .58 .943 r
.22725 .46461 .23144 .46857 .23735 .46979 .23316 .46587 Mtetra
.288 .596 .949 r
.23316 .46587 .23735 .46979 .2433 .47085 .23911 .46697 Mtetra
.31 .612 .954 r
.23911 .46697 .2433 .47085 .24929 .47175 .24511 .46792 Mtetra
.331 .626 .958 r
.24511 .46792 .24929 .47175 .25532 .47251 .25114 .46872 Mtetra
.351 .639 .962 r
.25114 .46872 .25532 .47251 .26139 .47312 .2572 .46937 Mtetra
.37 .651 .965 r
.2572 .46937 .26139 .47312 .26749 .4736 .26331 .46988 Mtetra
.387 .663 .968 r
.26331 .46988 .26749 .4736 .27363 .47394 .26944 .47026 Mtetra
.404 .674 .97 r
.26944 .47026 .27363 .47394 .2798 .47415 .27562 .4705 Mtetra
.419 .684 .972 r
.27562 .4705 .2798 .47415 .286 .47423 .28182 .47062 Mtetra
.434 .693 .974 r
.28182 .47062 .286 .47423 .29223 .47419 .28806 .47061 Mtetra
.448 .702 .975 r
.28806 .47061 .29223 .47419 .2985 .47403 .29433 .47048 Mtetra
.461 .711 .976 r
.29433 .47048 .2985 .47403 .3048 .47375 .30063 .47023 Mtetra
.473 .718 .977 r
.30063 .47023 .3048 .47375 .31112 .47336 .30697 .46988 Mtetra
.485 .726 .977 r
.30697 .46988 .31112 .47336 .31748 .47287 .31333 .46941 Mtetra
.496 .732 .978 r
.31333 .46941 .31748 .47287 .32386 .47226 .31972 .46883 Mtetra
.507 .739 .978 r
.31972 .46883 .32386 .47226 .33027 .47156 .32613 .46815 Mtetra
.517 .745 .978 r
.32613 .46815 .33027 .47156 .33671 .47076 .33258 .46737 Mtetra
.526 .751 .978 r
.33258 .46737 .33671 .47076 .34317 .46986 .33905 .4665 Mtetra
.535 .756 .978 r
.33905 .4665 .34317 .46986 .34966 .46887 .34555 .46553 Mtetra
.543 .761 .978 r
.34555 .46553 .34966 .46887 .35618 .4678 .35207 .46447 Mtetra
.551 .766 .977 r
.35207 .46447 .35618 .4678 .36271 .46663 .35862 .46333 Mtetra
.559 .77 .977 r
.35862 .46333 .36271 .46663 .36928 .46538 .36519 .46209 Mtetra
.566 .775 .977 r
.36519 .46209 .36928 .46538 .37586 .46405 .37178 .46078 Mtetra
.573 .779 .976 r
.37178 .46078 .37586 .46405 .38247 .46264 .3784 .45938 Mtetra
.579 .782 .976 r
.3784 .45938 .38247 .46264 .3891 .46115 .38504 .45791 Mtetra
.586 .786 .975 r
.38504 .45791 .3891 .46115 .39576 .45959 .39171 .45636 Mtetra
.592 .789 .974 r
.39171 .45636 .39576 .45959 .40243 .45795 .39839 .45473 Mtetra
.597 .793 .974 r
.39839 .45473 .40243 .45795 .40913 .45625 .4051 .45304 Mtetra
.603 .795 .973 r
.4051 .45304 .40913 .45625 .41585 .45447 .41183 .45127 Mtetra
.608 .798 .972 r
.41183 .45127 .41585 .45447 .42259 .45263 .41858 .44943 Mtetra
.613 .801 .972 r
.41858 .44943 .42259 .45263 .42934 .45072 .42535 .44753 Mtetra
.618 .804 .971 r
.42535 .44753 .42934 .45072 .43612 .44875 .43214 .44556 Mtetra
.623 .806 .97 r
.43214 .44556 .43612 .44875 .44292 .44671 .43895 .44353 Mtetra
.628 .808 .969 r
.43895 .44353 .44292 .44671 .44974 .44461 .44578 .44143 Mtetra
.632 .81 .968 r
.44578 .44143 .44974 .44461 .45657 .44245 .45263 .43927 Mtetra
.636 .812 .967 r
.45263 .43927 .45657 .44245 .46343 .44023 .4595 .43705 Mtetra
.641 .814 .966 r
.4595 .43705 .46343 .44023 .4703 .43795 .46638 .43477 Mtetra
.645 .816 .965 r
.46638 .43477 .4703 .43795 .47719 .43562 .47329 .43243 Mtetra
.649 .817 .964 r
.47329 .43243 .47719 .43562 .4841 .43322 .48021 .43002 Mtetra
.653 .819 .963 r
.48021 .43002 .4841 .43322 .49103 .43076 .48715 .42756 Mtetra
.657 .82 .962 r
.48715 .42756 .49103 .43076 .49797 .42825 .49411 .42504 Mtetra
.661 .822 .961 r
.49411 .42504 .49797 .42825 .50493 .42568 .50108 .42246 Mtetra
.664 .823 .96 r
.50108 .42246 .50493 .42568 .51191 .42305 .50807 .41983 Mtetra
.668 .824 .958 r
.50807 .41983 .51191 .42305 .5189 .42037 .51508 .41713 Mtetra
.672 .825 .957 r
.51508 .41713 .5189 .42037 .52591 .41762 .5221 .41437 Mtetra
.676 .826 .956 r
.5221 .41437 .52591 .41762 .53294 .41482 .52914 .41155 Mtetra
.68 .827 .954 r
.52914 .41155 .53294 .41482 .53998 .41196 .5362 .40867 Mtetra
.683 .828 .953 r
.5362 .40867 .53998 .41196 .54703 .40903 .54327 .40573 Mtetra
.687 .828 .951 r
.54327 .40573 .54703 .40903 .5541 .40605 .55035 .40273 Mtetra
.691 .829 .949 r
.55035 .40273 .5541 .40605 .56119 .403 .55745 .39966 Mtetra
.695 .83 .948 r
.55745 .39966 .56119 .403 .56829 .39989 .56457 .39653 Mtetra
.698 .83 .946 r
.56457 .39653 .56829 .39989 .5754 .39671 .5717 .39333 Mtetra
.702 .831 .944 r
.5717 .39333 .5754 .39671 .58253 .39347 .57884 .39006 Mtetra
.706 .831 .942 r
.57884 .39006 .58253 .39347 .58967 .39016 .58599 .38672 Mtetra
.71 .831 .94 r
.58599 .38672 .58967 .39016 .59682 .38677 .59316 .38331 Mtetra
.714 .831 .937 r
.59316 .38331 .59682 .38677 .60399 .38332 .60034 .37982 Mtetra
.718 .831 .935 r
.60034 .37982 .60399 .38332 .61116 .37978 .60754 .37626 Mtetra
.722 .831 .933 r
.60754 .37626 .61116 .37978 .61835 .37618 .61474 .37262 Mtetra
.726 .831 .93 r
.61474 .37262 .61835 .37618 .62555 .37248 .62195 .3689 Mtetra
.73 .831 .927 r
.62195 .3689 .62555 .37248 .63276 .36871 .62918 .36509 Mtetra
.734 .831 .924 r
.62918 .36509 .63276 .36871 .63998 .36485 .63641 .36119 Mtetra
.739 .831 .922 r
.63641 .36119 .63998 .36485 .64721 .3609 .64365 .3572 Mtetra
.743 .831 .918 r
.64365 .3572 .64721 .3609 .65444 .35686 .65091 .35312 Mtetra
.747 .83 .915 r
.65091 .35312 .65444 .35686 .66168 .35272 .65816 .34893 Mtetra
.752 .83 .912 r
.65816 .34893 .66168 .35272 .66893 .34848 .66543 .34465 Mtetra
.756 .829 .908 r
.66543 .34465 .66893 .34848 .67619 .34413 .6727 .34026 Mtetra
.761 .828 .905 r
.6727 .34026 .67619 .34413 .68345 .33967 .67997 .33575 Mtetra
.765 .828 .901 r
.67997 .33575 .68345 .33967 .69072 .33511 .68725 .33113 Mtetra
.77 .827 .897 r
.68725 .33113 .69072 .33511 .69798 .33042 .69454 .32639 Mtetra
.774 .826 .893 r
.69454 .32639 .69798 .33042 .70525 .32561 .70182 .32153 Mtetra
.779 .825 .889 r
.70182 .32153 .70525 .32561 .71252 .32067 .70911 .31653 Mtetra
.783 .824 .884 r
.70911 .31653 .71252 .32067 .71979 .31559 .71639 .3114 Mtetra
.788 .823 .88 r
.71639 .3114 .71979 .31559 .72706 .31038 .72367 .30613 Mtetra
.793 .822 .875 r
.72367 .30613 .72706 .31038 .73433 .30502 .73095 .3007 Mtetra
.797 .82 .87 r
.73095 .3007 .73433 .30502 .74159 .2995 .73823 .29513 Mtetra
.802 .819 .865 r
.73823 .29513 .74159 .2995 .74884 .29383 .74549 .28939 Mtetra
.806 .818 .86 r
.74549 .28939 .74884 .29383 .75609 .28799 .75275 .28349 Mtetra
.811 .816 .854 r
.75275 .28349 .75609 .28799 .76332 .28198 .76 .27741 Mtetra
.816 .814 .849 r
.76 .27741 .76332 .28198 .77055 .27579 .76724 .27114 Mtetra
.82 .813 .843 r
.76724 .27114 .77055 .27579 .77776 .26942 .77447 .26469 Mtetra
0 .012 .552 r
.12031 .39899 .12436 .40411 .12924 .40932 .12518 .40427 Mtetra
0 .051 .588 r
.12518 .40427 .12924 .40932 .1342 .41428 .13012 .40929 Mtetra
0 .089 .622 r
.13012 .40929 .1342 .41428 .13921 .41898 .13512 .41406 Mtetra
0 .127 .655 r
.13512 .41406 .13921 .41898 .1443 .42344 .1402 .41859 Mtetra
0 .165 .686 r
.1402 .41859 .1443 .42344 .14944 .42767 .14533 .42288 Mtetra
0 .202 .715 r
.14533 .42288 .14944 .42767 .15465 .43165 .15053 .42693 Mtetra
0 .237 .743 r
.15053 .42693 .15465 .43165 .15992 .43541 .15579 .43075 Mtetra
0 .272 .768 r
.15579 .43075 .15992 .43541 .16525 .43895 .1611 .43435 Mtetra
0 .305 .792 r
.1611 .43435 .16525 .43895 .17063 .44227 .16648 .43773 Mtetra
0 .337 .813 r
.16648 .43773 .17063 .44227 .17607 .44538 .17191 .44089 Mtetra
0 .367 .833 r
.17191 .44089 .17607 .44538 .18156 .44828 .17739 .44385 Mtetra
.016 .396 .851 r
.17739 .44385 .18156 .44828 .1871 .45097 .18293 .4466 Mtetra
.052 .423 .867 r
.18293 .4466 .1871 .45097 .1927 .45347 .18852 .44916 Mtetra
.086 .449 .882 r
.18852 .44916 .1927 .45347 .19834 .45578 .19415 .45152 Mtetra
.119 .474 .895 r
.19415 .45152 .19834 .45578 .20403 .4579 .19984 .45369 Mtetra
.15 .497 .907 r
.19984 .45369 .20403 .4579 .20977 .45984 .20557 .45568 Mtetra
.179 .518 .917 r
.20557 .45568 .20977 .45984 .21555 .4616 .21135 .45749 Mtetra
.207 .538 .926 r
.21135 .45749 .21555 .4616 .22138 .46319 .21718 .45913 Mtetra
.234 .557 .934 r
.21718 .45913 .22138 .46319 .22725 .46461 .22305 .4606 Mtetra
.259 .575 .941 r
.22305 .4606 .22725 .46461 .23316 .46587 .22896 .46191 Mtetra
.282 .591 .947 r
.22896 .46191 .23316 .46587 .23911 .46697 .23491 .46305 Mtetra
.305 .607 .952 r
.23491 .46305 .23911 .46697 .24511 .46792 .2409 .46404 Mtetra
.326 .621 .957 r
.2409 .46404 .24511 .46792 .25114 .46872 .24693 .46488 Mtetra
.346 .635 .961 r
.24693 .46488 .25114 .46872 .2572 .46937 .253 .46558 Mtetra
.365 .647 .964 r
.253 .46558 .2572 .46937 .26331 .46988 .25911 .46613 Mtetra
.382 .659 .967 r
.25911 .46613 .26331 .46988 .26944 .47026 .26525 .46654 Mtetra
.399 .67 .969 r
.26525 .46654 .26944 .47026 .27562 .4705 .27142 .46682 Mtetra
.415 .68 .971 r
.27142 .46682 .27562 .4705 .28182 .47062 .27763 .46697 Mtetra
.43 .69 .973 r
.27763 .46697 .28182 .47062 .28806 .47061 .28387 .467 Mtetra
.444 .699 .974 r
.28387 .467 .28806 .47061 .29433 .47048 .29015 .4669 Mtetra
.457 .708 .976 r
.29015 .4669 .29433 .47048 .30063 .47023 .29645 .46669 Mtetra
.47 .716 .976 r
.29645 .46669 .30063 .47023 .30697 .46988 .30279 .46636 Mtetra
.481 .723 .977 r
.30279 .46636 .30697 .46988 .31333 .46941 .30916 .46592 Mtetra
.493 .73 .978 r
.30916 .46592 .31333 .46941 .31972 .46883 .31555 .46537 Mtetra
.503 .737 .978 r
.31555 .46537 .31972 .46883 .32613 .46815 .32198 .46472 Mtetra
.513 .743 .978 r
.32198 .46472 .32613 .46815 .33258 .46737 .32843 .46396 Mtetra
.523 .749 .978 r
.32843 .46396 .33258 .46737 .33905 .4665 .33491 .46311 Mtetra
.532 .754 .978 r
.33491 .46311 .33905 .4665 .34555 .46553 .34141 .46217 Mtetra
.54 .76 .978 r
.34141 .46217 .34555 .46553 .35207 .46447 .34794 .46113 Mtetra
.549 .764 .978 r
.34794 .46113 .35207 .46447 .35862 .46333 .3545 .46 Mtetra
.556 .769 .977 r
.3545 .46 .35862 .46333 .36519 .46209 .36108 .45879 Mtetra
.564 .773 .977 r
.36108 .45879 .36519 .46209 .37178 .46078 .36768 .45749 Mtetra
.571 .778 .976 r
.36768 .45749 .37178 .46078 .3784 .45938 .37431 .45611 Mtetra
.577 .781 .976 r
.37431 .45611 .3784 .45938 .38504 .45791 .38096 .45465 Mtetra
.584 .785 .975 r
.38096 .45465 .38504 .45791 .39171 .45636 .38764 .45311 Mtetra
.59 .789 .975 r
.38764 .45311 .39171 .45636 .39839 .45473 .39434 .45149 Mtetra
.596 .792 .974 r
.39434 .45149 .39839 .45473 .4051 .45304 .40105 .44981 Mtetra
.601 .795 .973 r
.40105 .44981 .4051 .45304 .41183 .45127 .40779 .44805 Mtetra
.607 .798 .973 r
.40779 .44805 .41183 .45127 .41858 .44943 .41456 .44622 Mtetra
.612 .801 .972 r
.41456 .44622 .41858 .44943 .42535 .44753 .42134 .44432 Mtetra
.617 .803 .971 r
.42134 .44432 .42535 .44753 .43214 .44556 .42814 .44236 Mtetra
.622 .806 .97 r
.42814 .44236 .43214 .44556 .43895 .44353 .43496 .44033 Mtetra
.627 .808 .969 r
.43496 .44033 .43895 .44353 .44578 .44143 .4418 .43823 Mtetra
.631 .81 .969 r
.4418 .43823 .44578 .44143 .45263 .43927 .44866 .43607 Mtetra
.636 .812 .968 r
.44866 .43607 .45263 .43927 .4595 .43705 .45554 .43385 Mtetra
.64 .814 .967 r
.45554 .43385 .4595 .43705 .46638 .43477 .46244 .43157 Mtetra
.644 .816 .966 r
.46244 .43157 .46638 .43477 .47329 .43243 .46936 .42922 Mtetra
.648 .818 .965 r
.46936 .42922 .47329 .43243 .48021 .43002 .4763 .42682 Mtetra
.652 .819 .963 r
.4763 .42682 .48021 .43002 .48715 .42756 .48325 .42435 Mtetra
.656 .821 .962 r
.48325 .42435 .48715 .42756 .49411 .42504 .49022 .42182 Mtetra
.66 .822 .961 r
.49022 .42182 .49411 .42504 .50108 .42246 .49721 .41923 Mtetra
.664 .823 .96 r
.49721 .41923 .50108 .42246 .50807 .41983 .50421 .41659 Mtetra
.668 .824 .958 r
.50421 .41659 .50807 .41983 .51508 .41713 .51124 .41388 Mtetra
.672 .825 .957 r
.51124 .41388 .51508 .41713 .5221 .41437 .51827 .41111 Mtetra
.676 .826 .956 r
.51827 .41111 .5221 .41437 .52914 .41155 .52533 .40827 Mtetra
.68 .827 .954 r
.52533 .40827 .52914 .41155 .5362 .40867 .5324 .40538 Mtetra
.684 .828 .953 r
.5324 .40538 .5362 .40867 .54327 .40573 .53948 .40242 Mtetra
.688 .829 .951 r
.53948 .40242 .54327 .40573 .55035 .40273 .54658 .3994 Mtetra
.691 .829 .949 r
.54658 .3994 .55035 .40273 .55745 .39966 .5537 .39631 Mtetra
.695 .83 .947 r
.5537 .39631 .55745 .39966 .56457 .39653 .56083 .39315 Mtetra
.699 .831 .945 r
.56083 .39315 .56457 .39653 .5717 .39333 .56797 .38993 Mtetra
.703 .831 .943 r
.56797 .38993 .5717 .39333 .57884 .39006 .57513 .38663 Mtetra
.707 .831 .941 r
.57513 .38663 .57884 .39006 .58599 .38672 .5823 .38327 Mtetra
.711 .831 .939 r
.5823 .38327 .58599 .38672 .59316 .38331 .58948 .37983 Mtetra
.715 .832 .937 r
.58948 .37983 .59316 .38331 .60034 .37982 .59668 .37631 Mtetra
.719 .832 .935 r
.59668 .37631 .60034 .37982 .60754 .37626 .60389 .37272 Mtetra
.723 .832 .932 r
.60389 .37272 .60754 .37626 .61474 .37262 .61111 .36904 Mtetra
.727 .832 .929 r
.61111 .36904 .61474 .37262 .62195 .3689 .61834 .36528 Mtetra
.732 .831 .927 r
.61834 .36528 .62195 .3689 .62918 .36509 .62558 .36144 Mtetra
.736 .831 .924 r
.62558 .36144 .62918 .36509 .63641 .36119 .63283 .3575 Mtetra
.74 .831 .921 r
.63283 .3575 .63641 .36119 .64365 .3572 .64008 .35347 Mtetra
.744 .83 .918 r
.64008 .35347 .64365 .3572 .65091 .35312 .64735 .34935 Mtetra
.749 .83 .914 r
.64735 .34935 .65091 .35312 .65816 .34893 .65462 .34512 Mtetra
.753 .829 .911 r
.65462 .34512 .65816 .34893 .66543 .34465 .6619 .34079 Mtetra
.758 .829 .907 r
.6619 .34079 .66543 .34465 .6727 .34026 .66919 .33635 Mtetra
.762 .828 .903 r
.66919 .33635 .6727 .34026 .67997 .33575 .67648 .3318 Mtetra
.766 .827 .9 r
.67648 .3318 .67997 .33575 .68725 .33113 .68377 .32713 Mtetra
.771 .826 .896 r
.68377 .32713 .68725 .33113 .69454 .32639 .69107 .32233 Mtetra
.776 .825 .891 r
.69107 .32233 .69454 .32639 .70182 .32153 .69837 .31741 Mtetra
.78 .824 .887 r
.69837 .31741 .70182 .32153 .70911 .31653 .70567 .31236 Mtetra
.785 .823 .883 r
.70567 .31236 .70911 .31653 .71639 .3114 .71297 .30717 Mtetra
.789 .822 .878 r
.71297 .30717 .71639 .3114 .72367 .30613 .72026 .30183 Mtetra
.794 .821 .873 r
.72026 .30183 .72367 .30613 .73095 .3007 .72756 .29635 Mtetra
.799 .819 .868 r
.72756 .29635 .73095 .3007 .73823 .29513 .73485 .2907 Mtetra
.803 .818 .863 r
.73485 .2907 .73823 .29513 .74549 .28939 .74213 .2849 Mtetra
.808 .816 .858 r
.74213 .2849 .74549 .28939 .75275 .28349 .7494 .27892 Mtetra
.812 .815 .852 r
.7494 .27892 .75275 .28349 .76 .27741 .75666 .27277 Mtetra
.817 .813 .846 r
.75666 .27277 .76 .27741 .76724 .27114 .76391 .26643 Mtetra
.821 .811 .841 r
.76391 .26643 .76724 .27114 .77447 .26469 .77115 .2599 Mtetra
0 .006 .549 r
.11626 .39376 .12031 .39899 .12518 .40427 .12111 .39911 Mtetra
0 .044 .584 r
.12111 .39911 .12518 .40427 .13012 .40929 .12604 .40421 Mtetra
0 .083 .618 r
.12604 .40421 .13012 .40929 .13512 .41406 .13103 .40905 Mtetra
0 .12 .65 r
.13103 .40905 .13512 .41406 .1402 .41859 .13609 .41364 Mtetra
0 .158 .681 r
.13609 .41364 .1402 .41859 .14533 .42288 .14121 .418 Mtetra
0 .194 .711 r
.14121 .418 .14533 .42288 .15053 .42693 .14639 .42211 Mtetra
0 .23 .738 r
.14639 .42211 .15053 .42693 .15579 .43075 .15164 .426 Mtetra
0 .264 .764 r
.15164 .426 .15579 .43075 .1611 .43435 .15695 .42966 Mtetra
0 .297 .787 r
.15695 .42966 .1611 .43435 .16648 .43773 .16231 .43311 Mtetra
0 .329 .809 r
.16231 .43311 .16648 .43773 .17191 .44089 .16773 .43633 Mtetra
0 .36 .829 r
.16773 .43633 .17191 .44089 .17739 .44385 .17321 .43935 Mtetra
.01 .389 .847 r
.17321 .43935 .17739 .44385 .18293 .4466 .17874 .44216 Mtetra
.046 .416 .863 r
.17874 .44216 .18293 .4466 .18852 .44916 .18432 .44477 Mtetra
.08 .442 .878 r
.18432 .44477 .18852 .44916 .19415 .45152 .18995 .44719 Mtetra
.112 .467 .891 r
.18995 .44719 .19415 .45152 .19984 .45369 .19564 .44942 Mtetra
.143 .49 .903 r
.19564 .44942 .19984 .45369 .20557 .45568 .20137 .45146 Mtetra
.173 .511 .914 r
.20137 .45146 .20557 .45568 .21135 .45749 .20714 .45333 Mtetra
.201 .532 .923 r
.20714 .45333 .21135 .45749 .21718 .45913 .21297 .45501 Mtetra
.228 .551 .931 r
.21297 .45501 .21718 .45913 .22305 .4606 .21883 .45653 Mtetra
.253 .569 .938 r
.21883 .45653 .22305 .4606 .22896 .46191 .22474 .45788 Mtetra
.277 .586 .945 r
.22474 .45788 .22896 .46191 .23491 .46305 .23069 .45908 Mtetra
.299 .601 .95 r
.23069 .45908 .23491 .46305 .2409 .46404 .23668 .46011 Mtetra
.32 .616 .955 r
.23668 .46011 .2409 .46404 .24693 .46488 .24271 .461 Mtetra
.341 .63 .959 r
.24271 .461 .24693 .46488 .253 .46558 .24878 .46173 Mtetra
.36 .643 .963 r
.24878 .46173 .253 .46558 .25911 .46613 .25489 .46232 Mtetra
.377 .655 .966 r
.25489 .46232 .25911 .46613 .26525 .46654 .26103 .46278 Mtetra
.394 .666 .968 r
.26103 .46278 .26525 .46654 .27142 .46682 .26721 .4631 Mtetra
.41 .677 .97 r
.26721 .4631 .27142 .46682 .27763 .46697 .27342 .46329 Mtetra
.425 .686 .972 r
.27342 .46329 .27763 .46697 .28387 .467 .27967 .46335 Mtetra
.44 .696 .974 r
.27967 .46335 .28387 .467 .29015 .4669 .28595 .46328 Mtetra
.453 .704 .975 r
.28595 .46328 .29015 .4669 .29645 .46669 .29226 .4631 Mtetra
.466 .713 .976 r
.29226 .4631 .29645 .46669 .30279 .46636 .2986 .4628 Mtetra
.478 .72 .977 r
.2986 .4628 .30279 .46636 .30916 .46592 .30497 .46239 Mtetra
.489 .728 .977 r
.30497 .46239 .30916 .46592 .31555 .46537 .31137 .46187 Mtetra
.5 .734 .978 r
.31137 .46187 .31555 .46537 .32198 .46472 .3178 .46125 Mtetra
.51 .741 .978 r
.3178 .46125 .32198 .46472 .32843 .46396 .32426 .46052 Mtetra
.52 .747 .978 r
.32426 .46052 .32843 .46396 .33491 .46311 .33075 .4597 Mtetra
.529 .752 .978 r
.33075 .4597 .33491 .46311 .34141 .46217 .33726 .45877 Mtetra
.538 .758 .978 r
.33726 .45877 .34141 .46217 .34794 .46113 .3438 .45776 Mtetra
.546 .763 .978 r
.3438 .45776 .34794 .46113 .3545 .46 .35036 .45665 Mtetra
.554 .768 .977 r
.35036 .45665 .3545 .46 .36108 .45879 .35695 .45545 Mtetra
.561 .772 .977 r
.35695 .45545 .36108 .45879 .36768 .45749 .36356 .45417 Mtetra
.568 .776 .977 r
.36356 .45417 .36768 .45749 .37431 .45611 .3702 .45281 Mtetra
.575 .78 .976 r
.3702 .45281 .37431 .45611 .38096 .45465 .37686 .45136 Mtetra
.582 .784 .976 r
.37686 .45136 .38096 .45465 .38764 .45311 .38355 .44984 Mtetra
.588 .788 .975 r
.38355 .44984 .38764 .45311 .39434 .45149 .39026 .44824 Mtetra
.594 .791 .974 r
.39026 .44824 .39434 .45149 .40105 .44981 .39698 .44656 Mtetra
.6 .794 .974 r
.39698 .44656 .40105 .44981 .40779 .44805 .40374 .44481 Mtetra
.605 .797 .973 r
.40374 .44481 .40779 .44805 .41456 .44622 .41051 .44299 Mtetra
.611 .8 .972 r
.41051 .44299 .41456 .44622 .42134 .44432 .4173 .4411 Mtetra
.616 .803 .971 r
.4173 .4411 .42134 .44432 .42814 .44236 .42412 .43914 Mtetra
.621 .805 .971 r
.42412 .43914 .42814 .44236 .43496 .44033 .43095 .43711 Mtetra
.626 .808 .97 r
.43095 .43711 .43496 .44033 .4418 .43823 .4378 .43502 Mtetra
.63 .81 .969 r
.4378 .43502 .4418 .43823 .44866 .43607 .44468 .43286 Mtetra
.635 .812 .968 r
.44468 .43286 .44866 .43607 .45554 .43385 .45157 .43064 Mtetra
.639 .814 .967 r
.45157 .43064 .45554 .43385 .46244 .43157 .45848 .42835 Mtetra
.644 .816 .966 r
.45848 .42835 .46244 .43157 .46936 .42922 .46541 .42601 Mtetra
.648 .817 .965 r
.46541 .42601 .46936 .42922 .4763 .42682 .47236 .42359 Mtetra
.652 .819 .964 r
.47236 .42359 .4763 .42682 .48325 .42435 .47933 .42112 Mtetra
.656 .821 .962 r
.47933 .42112 .48325 .42435 .49022 .42182 .48631 .41859 Mtetra
.66 .822 .961 r
.48631 .41859 .49022 .42182 .49721 .41923 .49332 .41599 Mtetra
.664 .823 .96 r
.49332 .41599 .49721 .41923 .50421 .41659 .50034 .41333 Mtetra
.668 .824 .959 r
.50034 .41333 .50421 .41659 .51124 .41388 .50737 .41061 Mtetra
.672 .826 .957 r
.50737 .41061 .51124 .41388 .51827 .41111 .51443 .40782 Mtetra
.676 .827 .956 r
.51443 .40782 .51827 .41111 .52533 .40827 .52149 .40498 Mtetra
.68 .827 .954 r
.52149 .40498 .52533 .40827 .5324 .40538 .52858 .40206 Mtetra
.684 .828 .952 r
.52858 .40206 .5324 .40538 .53948 .40242 .53568 .39909 Mtetra
.688 .829 .951 r
.53568 .39909 .53948 .40242 .54658 .3994 .54279 .39604 Mtetra
.692 .83 .949 r
.54279 .39604 .54658 .3994 .5537 .39631 .54993 .39293 Mtetra
.696 .83 .947 r
.54993 .39293 .5537 .39631 .56083 .39315 .55707 .38976 Mtetra
.7 .831 .945 r
.55707 .38976 .56083 .39315 .56797 .38993 .56423 .38651 Mtetra
.704 .831 .943 r
.56423 .38651 .56797 .38993 .57513 .38663 .5714 .38319 Mtetra
.708 .831 .941 r
.5714 .38319 .57513 .38663 .5823 .38327 .57859 .37979 Mtetra
.712 .832 .939 r
.57859 .37979 .5823 .38327 .58948 .37983 .58579 .37632 Mtetra
.716 .832 .936 r
.58579 .37632 .58948 .37983 .59668 .37631 .593 .37278 Mtetra
.72 .832 .934 r
.593 .37278 .59668 .37631 .60389 .37272 .60022 .36915 Mtetra
.724 .832 .931 r
.60022 .36915 .60389 .37272 .61111 .36904 .60745 .36544 Mtetra
.729 .832 .929 r
.60745 .36544 .61111 .36904 .61834 .36528 .6147 .36164 Mtetra
.733 .831 .926 r
.6147 .36164 .61834 .36528 .62558 .36144 .62196 .35776 Mtetra
.737 .831 .923 r
.62196 .35776 .62558 .36144 .63283 .3575 .62922 .35378 Mtetra
.741 .831 .92 r
.62922 .35378 .63283 .3575 .64008 .35347 .63649 .34971 Mtetra
.746 .83 .916 r
.63649 .34971 .64008 .35347 .64735 .34935 .64377 .34554 Mtetra
.75 .83 .913 r
.64377 .34554 .64735 .34935 .65462 .34512 .65106 .34127 Mtetra
.754 .829 .91 r
.65106 .34127 .65462 .34512 .6619 .34079 .65836 .33689 Mtetra
.759 .828 .906 r
.65836 .33689 .6619 .34079 .66919 .33635 .66566 .33241 Mtetra
.763 .828 .902 r
.66566 .33241 .66919 .33635 .67648 .3318 .67297 .3278 Mtetra
.768 .827 .898 r
.67297 .3278 .67648 .3318 .68377 .32713 .68028 .32308 Mtetra
.772 .826 .894 r
.68028 .32308 .68377 .32713 .69107 .32233 .68759 .31823 Mtetra
.777 .825 .89 r
.68759 .31823 .69107 .32233 .69837 .31741 .6949 .31325 Mtetra
.782 .824 .885 r
.6949 .31325 .69837 .31741 .70567 .31236 .70221 .30814 Mtetra
.786 .822 .881 r
.70221 .30814 .70567 .31236 .71297 .30717 .70953 .30289 Mtetra
.791 .821 .876 r
.70953 .30289 .71297 .30717 .72026 .30183 .71684 .29749 Mtetra
.795 .82 .871 r
.71684 .29749 .72026 .30183 .72756 .29635 .72415 .29193 Mtetra
.8 .818 .866 r
.72415 .29193 .72756 .29635 .73485 .2907 .73145 .28622 Mtetra
.804 .817 .861 r
.73145 .28622 .73485 .2907 .74213 .2849 .73874 .28035 Mtetra
.809 .815 .855 r
.73874 .28035 .74213 .2849 .7494 .27892 .74603 .2743 Mtetra
.814 .813 .85 r
.74603 .2743 .7494 .27892 .75666 .27277 .7533 .26807 Mtetra
.818 .811 .844 r
.7533 .26807 .75666 .27277 .76391 .26643 .76057 .26166 Mtetra
.823 .81 .838 r
.76057 .26166 .76391 .26643 .77115 .2599 .76782 .25505 Mtetra
0 0 .545 r
.11221 .38843 .11626 .39376 .12111 .39911 .11705 .39385 Mtetra
0 .038 .58 r
.11705 .39385 .12111 .39911 .12604 .40421 .12195 .39902 Mtetra
0 .076 .614 r
.12195 .39902 .12604 .40421 .13103 .40905 .12693 .40393 Mtetra
0 .113 .646 r
.12693 .40393 .13103 .40905 .13609 .41364 .13197 .4086 Mtetra
0 .15 .677 r
.13197 .4086 .13609 .41364 .14121 .418 .13708 .41302 Mtetra
0 .187 .706 r
.13708 .41302 .14121 .418 .14639 .42211 .14226 .41721 Mtetra
0 .222 .733 r
.14226 .41721 .14639 .42211 .15164 .426 .14749 .42117 Mtetra
0 .256 .759 r
.14749 .42117 .15164 .426 .15695 .42966 .15279 .42489 Mtetra
0 .289 .783 r
.15279 .42489 .15695 .42966 .16231 .43311 .15814 .4284 Mtetra
0 .321 .804 r
.15814 .4284 .16231 .43311 .16773 .43633 .16355 .43169 Mtetra
0 .352 .825 r
.16355 .43169 .16773 .43633 .17321 .43935 .16902 .43477 Mtetra
.005 .381 .843 r
.16902 .43477 .17321 .43935 .17874 .44216 .17454 .43764 Mtetra
.04 .409 .859 r
.17454 .43764 .17874 .44216 .18432 .44477 .18012 .44031 Mtetra
.074 .435 .874 r
.18012 .44031 .18432 .44477 .18995 .44719 .18574 .44279 Mtetra
.106 .459 .888 r
.18574 .44279 .18995 .44719 .19564 .44942 .19142 .44507 Mtetra
.137 .483 .9 r
.19142 .44507 .19564 .44942 .20137 .45146 .19715 .44717 Mtetra
.167 .505 .91 r
.19715 .44717 .20137 .45146 .20714 .45333 .20292 .44909 Mtetra
.195 .525 .92 r
.20292 .44909 .20714 .45333 .21297 .45501 .20874 .45083 Mtetra
.222 .545 .928 r
.20874 .45083 .21297 .45501 .21883 .45653 .2146 .4524 Mtetra
.247 .563 .936 r
.2146 .4524 .21883 .45653 .22474 .45788 .22051 .4538 Mtetra
.271 .58 .942 r
.22051 .4538 .22474 .45788 .23069 .45908 .22646 .45504 Mtetra
.294 .596 .948 r
.22646 .45504 .23069 .45908 .23668 .46011 .23245 .45613 Mtetra
.315 .611 .953 r
.23245 .45613 .23668 .46011 .24271 .461 .23848 .45706 Mtetra
.335 .625 .957 r
.23848 .45706 .24271 .461 .24878 .46173 .24455 .45784 Mtetra
.354 .638 .961 r
.24455 .45784 .24878 .46173 .25489 .46232 .25065 .45847 Mtetra
.372 .65 .964 r
.25065 .45847 .25489 .46232 .26103 .46278 .2568 .45897 Mtetra
.39 .662 .967 r
.2568 .45897 .26103 .46278 .26721 .4631 .26298 .45933 Mtetra
.406 .672 .969 r
.26298 .45933 .26721 .4631 .27342 .46329 .26919 .45955 Mtetra
.421 .683 .971 r
.26919 .45955 .27342 .46329 .27967 .46335 .27544 .45965 Mtetra
.435 .692 .973 r
.27544 .45965 .27967 .46335 .28595 .46328 .28172 .45962 Mtetra
.449 .701 .974 r
.28172 .45962 .28595 .46328 .29226 .4631 .28804 .45948 Mtetra
.462 .709 .975 r
.28804 .45948 .29226 .4631 .2986 .4628 .29439 .45921 Mtetra
.474 .717 .976 r
.29439 .45921 .2986 .4628 .30497 .46239 .30076 .45883 Mtetra
.485 .725 .977 r
.30076 .45883 .30497 .46239 .31137 .46187 .30717 .45834 Mtetra
.496 .732 .977 r
.30717 .45834 .31137 .46187 .3178 .46125 .31361 .45775 Mtetra
.507 .738 .978 r
.31361 .45775 .3178 .46125 .32426 .46052 .32007 .45705 Mtetra
.517 .744 .978 r
.32007 .45705 .32426 .46052 .33075 .4597 .32656 .45625 Mtetra
.526 .75 .978 r
.32656 .45625 .33075 .4597 .33726 .45877 .33308 .45535 Mtetra
.535 .756 .978 r
.33308 .45535 .33726 .45877 .3438 .45776 .33963 .45435 Mtetra
.543 .761 .978 r
.33963 .45435 .3438 .45776 .35036 .45665 .3462 .45327 Mtetra
.551 .766 .977 r
.3462 .45327 .35036 .45665 .35695 .45545 .3528 .45209 Mtetra
.559 .771 .977 r
.3528 .45209 .35695 .45545 .36356 .45417 .35942 .45083 Mtetra
.566 .775 .977 r
.35942 .45083 .36356 .45417 .3702 .45281 .36607 .44948 Mtetra
.573 .779 .976 r
.36607 .44948 .3702 .45281 .37686 .45136 .37274 .44805 Mtetra
.58 .783 .976 r
.37274 .44805 .37686 .45136 .38355 .44984 .37944 .44654 Mtetra
.586 .787 .975 r
.37944 .44654 .38355 .44984 .39026 .44824 .38615 .44495 Mtetra
.592 .79 .975 r
.38615 .44495 .39026 .44824 .39698 .44656 .39289 .44329 Mtetra
.598 .793 .974 r
.39289 .44329 .39698 .44656 .40374 .44481 .39966 .44155 Mtetra
.604 .796 .973 r
.39966 .44155 .40374 .44481 .41051 .44299 .40644 .43974 Mtetra
.609 .799 .972 r
.40644 .43974 .41051 .44299 .4173 .4411 .41325 .43785 Mtetra
.615 .802 .972 r
.41325 .43785 .4173 .4411 .42412 .43914 .42007 .4359 Mtetra
.62 .805 .971 r
.42007 .4359 .42412 .43914 .43095 .43711 .42692 .43388 Mtetra
.625 .807 .97 r
.42692 .43388 .43095 .43711 .4378 .43502 .43378 .43179 Mtetra
.629 .809 .969 r
.43378 .43179 .4378 .43502 .44468 .43286 .44067 .42963 Mtetra
.634 .812 .968 r
.44067 .42963 .44468 .43286 .45157 .43064 .44758 .42741 Mtetra
.639 .814 .967 r
.44758 .42741 .45157 .43064 .45848 .42835 .4545 .42512 Mtetra
.643 .815 .966 r
.4545 .42512 .45848 .42835 .46541 .42601 .46145 .42277 Mtetra
.648 .817 .965 r
.46145 .42277 .46541 .42601 .47236 .42359 .46841 .42035 Mtetra
.652 .819 .964 r
.46841 .42035 .47236 .42359 .47933 .42112 .47539 .41787 Mtetra
.656 .82 .962 r
.47539 .41787 .47933 .42112 .48631 .41859 .48239 .41533 Mtetra
.66 .822 .961 r
.48239 .41533 .48631 .41859 .49332 .41599 .4894 .41272 Mtetra
.664 .823 .96 r
.4894 .41272 .49332 .41599 .50034 .41333 .49644 .41005 Mtetra
.668 .824 .958 r
.49644 .41005 .50034 .41333 .50737 .41061 .50349 .40732 Mtetra
.673 .825 .957 r
.50349 .40732 .50737 .41061 .51443 .40782 .51056 .40452 Mtetra
.677 .826 .955 r
.51056 .40452 .51443 .40782 .52149 .40498 .51764 .40166 Mtetra
.681 .827 .954 r
.51764 .40166 .52149 .40498 .52858 .40206 .52474 .39873 Mtetra
.685 .828 .952 r
.52474 .39873 .52858 .40206 .53568 .39909 .53185 .39573 Mtetra
.689 .829 .95 r
.53185 .39573 .53568 .39909 .54279 .39604 .53898 .39267 Mtetra
.693 .83 .949 r
.53898 .39267 .54279 .39604 .54993 .39293 .54613 .38954 Mtetra
.697 .83 .947 r
.54613 .38954 .54993 .39293 .55707 .38976 .55329 .38634 Mtetra
.701 .831 .945 r
.55329 .38634 .55707 .38976 .56423 .38651 .56046 .38306 Mtetra
.705 .831 .943 r
.56046 .38306 .56423 .38651 .5714 .38319 .56765 .37972 Mtetra
.709 .831 .94 r
.56765 .37972 .5714 .38319 .57859 .37979 .57485 .37629 Mtetra
.713 .831 .938 r
.57485 .37629 .57859 .37979 .58579 .37632 .58207 .37279 Mtetra
.717 .832 .936 r
.58207 .37279 .58579 .37632 .593 .37278 .5893 .36922 Mtetra
.721 .832 .933 r
.5893 .36922 .593 .37278 .60022 .36915 .59653 .36555 Mtetra
.726 .831 .93 r
.59653 .36555 .60022 .36915 .60745 .36544 .60378 .36181 Mtetra
.73 .831 .928 r
.60378 .36181 .60745 .36544 .6147 .36164 .61104 .35798 Mtetra
.734 .831 .925 r
.61104 .35798 .6147 .36164 .62196 .35776 .61831 .35405 Mtetra
.738 .831 .922 r
.61831 .35405 .62196 .35776 .62922 .35378 .62559 .35004 Mtetra
.743 .83 .919 r
.62559 .35004 .62922 .35378 .63649 .34971 .63288 .34592 Mtetra
.747 .83 .915 r
.63288 .34592 .63649 .34971 .64377 .34554 .64018 .34171 Mtetra
.751 .829 .912 r
.64018 .34171 .64377 .34554 .65106 .34127 .64749 .33739 Mtetra
.756 .829 .908 r
.64749 .33739 .65106 .34127 .65836 .33689 .6548 .33296 Mtetra
.76 .828 .904 r
.6548 .33296 .65836 .33689 .66566 .33241 .66211 .32842 Mtetra
.765 .827 .901 r
.66211 .32842 .66566 .33241 .67297 .3278 .66943 .32376 Mtetra
.769 .826 .896 r
.66943 .32376 .67297 .3278 .68028 .32308 .67676 .31899 Mtetra
.774 .825 .892 r
.67676 .31899 .68028 .32308 .68759 .31823 .68408 .31408 Mtetra
.778 .824 .888 r
.68408 .31408 .68759 .31823 .6949 .31325 .69141 .30904 Mtetra
.783 .823 .883 r
.69141 .30904 .6949 .31325 .70221 .30814 .69874 .30387 Mtetra
.788 .821 .879 r
.69874 .30387 .70221 .30814 .70953 .30289 .70607 .29855 Mtetra
.792 .82 .874 r
.70607 .29855 .70953 .30289 .71684 .29749 .71339 .29309 Mtetra
.797 .818 .869 r
.71339 .29309 .71684 .29749 .72415 .29193 .72071 .28747 Mtetra
.801 .817 .864 r
.72071 .28747 .72415 .29193 .73145 .28622 .72803 .28168 Mtetra
.806 .815 .858 r
.72803 .28168 .73145 .28622 .73874 .28035 .73534 .27573 Mtetra
.81 .813 .853 r
.73534 .27573 .73874 .28035 .74603 .2743 .74264 .26961 Mtetra
.815 .812 .847 r
.74264 .26961 .74603 .2743 .7533 .26807 .74993 .26331 Mtetra
.819 .81 .842 r
.74993 .26331 .7533 .26807 .76057 .26166 .7572 .25681 Mtetra
.824 .808 .836 r
.7572 .25681 .76057 .26166 .76782 .25505 .76446 .25012 Mtetra
0 0 .541 r
.10816 .38299 .11221 .38843 .11705 .39385 .11298 .38849 Mtetra
0 .031 .576 r
.11298 .38849 .11705 .39385 .12195 .39902 .11787 .39373 Mtetra
0 .069 .609 r
.11787 .39373 .12195 .39902 .12693 .40393 .12283 .39872 Mtetra
0 .106 .641 r
.12283 .39872 .12693 .40393 .13197 .4086 .12786 .40346 Mtetra
0 .143 .672 r
.12786 .40346 .13197 .4086 .13708 .41302 .13295 .40796 Mtetra
0 .179 .701 r
.13295 .40796 .13708 .41302 .14226 .41721 .13811 .41221 Mtetra
0 .214 .729 r
.13811 .41221 .14226 .41721 .14749 .42117 .14333 .41624 Mtetra
0 .248 .754 r
.14333 .41624 .14749 .42117 .15279 .42489 .14862 .42003 Mtetra
0 .281 .778 r
.14862 .42003 .15279 .42489 .15814 .4284 .15396 .42361 Mtetra
0 .313 .8 r
.15396 .42361 .15814 .4284 .16355 .43169 .15936 .42696 Mtetra
0 .344 .82 r
.15936 .42696 .16355 .43169 .16902 .43477 .16482 .43011 Mtetra
0 .373 .838 r
.16482 .43011 .16902 .43477 .17454 .43764 .17034 .43304 Mtetra
.034 .401 .855 r
.17034 .43304 .17454 .43764 .18012 .44031 .1759 .43577 Mtetra
.068 .427 .87 r
.1759 .43577 .18012 .44031 .18574 .44279 .18152 .43831 Mtetra
.1 .452 .884 r
.18152 .43831 .18574 .44279 .19142 .44507 .18719 .44065 Mtetra
.131 .475 .896 r
.18719 .44065 .19142 .44507 .19715 .44717 .19291 .44281 Mtetra
.161 .498 .907 r
.19291 .44281 .19715 .44717 .20292 .44909 .19868 .44478 Mtetra
.189 .519 .917 r
.19868 .44478 .20292 .44909 .20874 .45083 .2045 .44658 Mtetra
.216 .538 .925 r
.2045 .44658 .20874 .45083 .2146 .4524 .21036 .4482 Mtetra
.241 .557 .933 r
.21036 .4482 .2146 .4524 .22051 .4538 .21626 .44966 Mtetra
.265 .574 .94 r
.21626 .44966 .22051 .4538 .22646 .45504 .22221 .45095 Mtetra
.288 .59 .946 r
.22221 .45095 .22646 .45504 .23245 .45613 .2282 .45208 Mtetra
.31 .605 .951 r
.2282 .45208 .23245 .45613 .23848 .45706 .23423 .45306 Mtetra
.33 .619 .955 r
.23423 .45306 .23848 .45706 .24455 .45784 .2403 .45388 Mtetra
.349 .633 .959 r
.2403 .45388 .24455 .45784 .25065 .45847 .2464 .45456 Mtetra
.367 .645 .963 r
.2464 .45456 .25065 .45847 .2568 .45897 .25255 .4551 Mtetra
.385 .657 .966 r
.25255 .4551 .2568 .45897 .26298 .45933 .25873 .4555 Mtetra
.401 .668 .968 r
.25873 .4555 .26298 .45933 .26919 .45955 .26495 .45577 Mtetra
.416 .679 .97 r
.26495 .45577 .26919 .45955 .27544 .45965 .2712 .45591 Mtetra
.431 .688 .972 r
.2712 .45591 .27544 .45965 .28172 .45962 .27749 .45592 Mtetra
.445 .697 .973 r
.27749 .45592 .28172 .45962 .28804 .45948 .2838 .45581 Mtetra
.458 .706 .975 r
.2838 .45581 .28804 .45948 .29439 .45921 .29016 .45557 Mtetra
.47 .714 .976 r
.29016 .45557 .29439 .45921 .30076 .45883 .29654 .45523 Mtetra
.482 .722 .976 r
.29654 .45523 .30076 .45883 .30717 .45834 .30295 .45477 Mtetra
.493 .729 .977 r
.30295 .45477 .30717 .45834 .31361 .45775 .30939 .4542 Mtetra
.503 .736 .977 r
.30939 .4542 .31361 .45775 .32007 .45705 .31586 .45353 Mtetra
.513 .742 .978 r
.31586 .45353 .32007 .45705 .32656 .45625 .32236 .45276 Mtetra
.523 .748 .978 r
.32236 .45276 .32656 .45625 .33308 .45535 .32889 .45189 Mtetra
.532 .754 .978 r
.32889 .45189 .33308 .45535 .33963 .45435 .33544 .45092 Mtetra
.541 .759 .978 r
.33544 .45092 .33963 .45435 .3462 .45327 .34203 .44985 Mtetra
.549 .764 .977 r
.34203 .44985 .3462 .45327 .3528 .45209 .34863 .4487 Mtetra
.556 .769 .977 r
.34863 .4487 .3528 .45209 .35942 .45083 .35526 .44745 Mtetra
.564 .773 .977 r
.35526 .44745 .35942 .45083 .36607 .44948 .36192 .44612 Mtetra
.571 .777 .976 r
.36192 .44612 .36607 .44948 .37274 .44805 .3686 .44471 Mtetra
.578 .781 .976 r
.3686 .44471 .37274 .44805 .37944 .44654 .37531 .44322 Mtetra
.584 .785 .975 r
.37531 .44322 .37944 .44654 .38615 .44495 .38203 .44164 Mtetra
.591 .789 .975 r
.38203 .44164 .38615 .44495 .39289 .44329 .38878 .43999 Mtetra
.597 .792 .974 r
.38878 .43999 .39289 .44329 .39966 .44155 .39556 .43826 Mtetra
.602 .795 .973 r
.39556 .43826 .39966 .44155 .40644 .43974 .40235 .43646 Mtetra
.608 .798 .972 r
.40235 .43646 .40644 .43974 .41325 .43785 .40917 .43458 Mtetra
.613 .801 .972 r
.40917 .43458 .41325 .43785 .42007 .4359 .41601 .43263 Mtetra
.619 .804 .971 r
.41601 .43263 .42007 .4359 .42692 .43388 .42286 .43062 Mtetra
.624 .806 .97 r
.42286 .43062 .42692 .43388 .43378 .43179 .42974 .42853 Mtetra
.629 .809 .969 r
.42974 .42853 .43378 .43179 .44067 .42963 .43664 .42637 Mtetra
.633 .811 .968 r
.43664 .42637 .44067 .42963 .44758 .42741 .44356 .42415 Mtetra
.638 .813 .967 r
.44356 .42415 .44758 .42741 .4545 .42512 .4505 .42186 Mtetra
.643 .815 .966 r
.4505 .42186 .4545 .42512 .46145 .42277 .45746 .41951 Mtetra
.647 .817 .965 r
.45746 .41951 .46145 .42277 .46841 .42035 .46443 .41709 Mtetra
.652 .818 .964 r
.46443 .41709 .46841 .42035 .47539 .41787 .47143 .4146 Mtetra
.656 .82 .962 r
.47143 .4146 .47539 .41787 .48239 .41533 .47844 .41205 Mtetra
.66 .821 .961 r
.47844 .41205 .48239 .41533 .4894 .41272 .48547 .40943 Mtetra
.664 .823 .96 r
.48547 .40943 .4894 .41272 .49644 .41005 .49252 .40675 Mtetra
.669 .824 .958 r
.49252 .40675 .49644 .41005 .50349 .40732 .49958 .40401 Mtetra
.673 .825 .957 r
.49958 .40401 .50349 .40732 .51056 .40452 .50667 .40119 Mtetra
.677 .826 .955 r
.50667 .40119 .51056 .40452 .51764 .40166 .51376 .39831 Mtetra
.681 .827 .953 r
.51376 .39831 .51764 .40166 .52474 .39873 .52088 .39537 Mtetra
.685 .828 .952 r
.52088 .39537 .52474 .39873 .53185 .39573 .52801 .39235 Mtetra
.689 .829 .95 r
.52801 .39235 .53185 .39573 .53898 .39267 .53515 .38927 Mtetra
.693 .829 .948 r
.53515 .38927 .53898 .39267 .54613 .38954 .54231 .38612 Mtetra
.697 .83 .946 r
.54231 .38612 .54613 .38954 .55329 .38634 .54949 .38289 Mtetra
.702 .83 .944 r
.54949 .38289 .55329 .38634 .56046 .38306 .55668 .37959 Mtetra
.706 .831 .942 r
.55668 .37959 .56046 .38306 .56765 .37972 .56388 .37622 Mtetra
.71 .831 .94 r
.56388 .37622 .56765 .37972 .57485 .37629 .5711 .37276 Mtetra
.714 .831 .937 r
.5711 .37276 .57485 .37629 .58207 .37279 .57833 .36923 Mtetra
.718 .831 .935 r
.57833 .36923 .58207 .37279 .5893 .36922 .58557 .36562 Mtetra
.723 .831 .932 r
.58557 .36562 .5893 .36922 .59653 .36555 .59283 .36193 Mtetra
.727 .831 .929 r
.59283 .36193 .59653 .36555 .60378 .36181 .60009 .35814 Mtetra
.731 .831 .927 r
.60009 .35814 .60378 .36181 .61104 .35798 .60737 .35427 Mtetra
.735 .831 .924 r
.60737 .35427 .61104 .35798 .61831 .35405 .61465 .35031 Mtetra
.74 .83 .92 r
.61465 .35031 .61831 .35405 .62559 .35004 .62195 .34625 Mtetra
.744 .83 .917 r
.62195 .34625 .62559 .35004 .63288 .34592 .62925 .34209 Mtetra
.749 .829 .914 r
.62925 .34209 .63288 .34592 .64018 .34171 .63657 .33783 Mtetra
.753 .828 .91 r
.63657 .33783 .64018 .34171 .64749 .33739 .64389 .33346 Mtetra
.757 .828 .907 r
.64389 .33346 .64749 .33739 .6548 .33296 .65121 .32898 Mtetra
.762 .827 .903 r
.65121 .32898 .6548 .33296 .66211 .32842 .65854 .32439 Mtetra
.766 .826 .899 r
.65854 .32439 .66211 .32842 .66943 .32376 .66588 .31968 Mtetra
.771 .825 .895 r
.66588 .31968 .66943 .32376 .67676 .31899 .67322 .31484 Mtetra
.775 .824 .89 r
.67322 .31484 .67676 .31899 .68408 .31408 .68056 .30988 Mtetra
.78 .823 .886 r
.68056 .30988 .68408 .31408 .69141 .30904 .6879 .30478 Mtetra
.784 .821 .881 r
.6879 .30478 .69141 .30904 .69874 .30387 .69525 .29954 Mtetra
.789 .82 .877 r
.69525 .29954 .69874 .30387 .70607 .29855 .70259 .29416 Mtetra
.793 .818 .872 r
.70259 .29416 .70607 .29855 .71339 .29309 .70993 .28863 Mtetra
.798 .817 .867 r
.70993 .28863 .71339 .29309 .72071 .28747 .71726 .28293 Mtetra
.802 .815 .861 r
.71726 .28293 .72071 .28747 .72803 .28168 .72459 .27708 Mtetra
.807 .813 .856 r
.72459 .27708 .72803 .28168 .73534 .27573 .73191 .27106 Mtetra
.811 .812 .851 r
.73191 .27106 .73534 .27573 .74264 .26961 .73923 .26485 Mtetra
.816 .81 .845 r
.73923 .26485 .74264 .26961 .74993 .26331 .74653 .25847 Mtetra
.82 .808 .839 r
.74653 .25847 .74993 .26331 .7572 .25681 .75382 .25189 Mtetra
.825 .806 .833 r
.75382 .25189 .7572 .25681 .76446 .25012 .76109 .24511 Mtetra
0 0 .537 r
.1041 .37743 .10816 .38299 .11298 .38849 .1089 .38301 Mtetra
0 .024 .572 r
.1089 .38301 .11298 .38849 .11787 .39373 .11378 .38833 Mtetra
0 .061 .605 r
.11378 .38833 .11787 .39373 .12283 .39872 .11872 .3934 Mtetra
0 .098 .637 r
.11872 .3934 .12283 .39872 .12786 .40346 .12373 .39821 Mtetra
0 .135 .667 r
.12373 .39821 .12786 .40346 .13295 .40796 .12881 .40278 Mtetra
0 .171 .696 r
.12881 .40278 .13295 .40796 .13811 .41221 .13396 .40712 Mtetra
0 .206 .724 r
.13396 .40712 .13811 .41221 .14333 .41624 .13917 .41121 Mtetra
0 .24 .749 r
.13917 .41121 .14333 .41624 .14862 .42003 .14444 .41508 Mtetra
0 .273 .773 r
.14444 .41508 .14862 .42003 .15396 .42361 .14977 .41872 Mtetra
0 .305 .795 r
.14977 .41872 .15396 .42361 .15936 .42696 .15517 .42215 Mtetra
0 .336 .815 r
.15517 .42215 .15936 .42696 .16482 .43011 .16062 .42536 Mtetra
0 .365 .834 r
.16062 .42536 .16482 .43011 .17034 .43304 .16612 .42836 Mtetra
.028 .393 .851 r
.16612 .42836 .17034 .43304 .1759 .43577 .17168 .43115 Mtetra
.062 .419 .866 r
.17168 .43115 .1759 .43577 .18152 .43831 .17729 .43375 Mtetra
.094 .444 .88 r
.17729 .43375 .18152 .43831 .18719 .44065 .18296 .43616 Mtetra
.125 .468 .892 r
.18296 .43616 .18719 .44065 .19291 .44281 .18867 .43837 Mtetra
.155 .49 .904 r
.18867 .43837 .19291 .44281 .19868 .44478 .19443 .44041 Mtetra
.183 .511 .913 r
.19443 .44041 .19868 .44478 .2045 .44658 .20024 .44226 Mtetra
.21 .531 .922 r
.20024 .44226 .2045 .44658 .21036 .4482 .2061 .44394 Mtetra
.235 .55 .93 r
.2061 .44394 .21036 .4482 .21626 .44966 .212 .44545 Mtetra
.259 .567 .937 r
.212 .44545 .21626 .44966 .22221 .45095 .21794 .44679 Mtetra
.282 .584 .943 r
.21794 .44679 .22221 .45095 .2282 .45208 .22393 .44797 Mtetra
.304 .599 .949 r
.22393 .44797 .2282 .45208 .23423 .45306 .22996 .449 Mtetra
.325 .614 .953 r
.22996 .449 .23423 .45306 .2403 .45388 .23603 .44987 Mtetra
.344 .628 .958 r
.23603 .44987 .2403 .45388 .2464 .45456 .24214 .4506 Mtetra
.362 .64 .961 r
.24214 .4506 .2464 .45456 .25255 .4551 .24828 .45118 Mtetra
.38 .652 .964 r
.24828 .45118 .25255 .4551 .25873 .4555 .25447 .45163 Mtetra
.396 .664 .967 r
.25447 .45163 .25873 .4555 .26495 .45577 .26069 .45193 Mtetra
.412 .674 .969 r
.26069 .45193 .26495 .45577 .2712 .45591 .26694 .45211 Mtetra
.427 .684 .971 r
.26694 .45211 .2712 .45591 .27749 .45592 .27323 .45216 Mtetra
.441 .693 .972 r
.27323 .45216 .27749 .45592 .2838 .45581 .27955 .45209 Mtetra
.454 .702 .974 r
.27955 .45209 .2838 .45581 .29016 .45557 .28591 .45189 Mtetra
.466 .711 .975 r
.28591 .45189 .29016 .45557 .29654 .45523 .29229 .45158 Mtetra
.478 .718 .976 r
.29229 .45158 .29654 .45523 .30295 .45477 .29871 .45115 Mtetra
.49 .726 .976 r
.29871 .45115 .30295 .45477 .30939 .4542 .30516 .45062 Mtetra
.5 .733 .977 r
.30516 .45062 .30939 .4542 .31586 .45353 .31164 .44998 Mtetra
.51 .739 .977 r
.31164 .44998 .31586 .45353 .32236 .45276 .31814 .44923 Mtetra
.52 .745 .977 r
.31814 .44923 .32236 .45276 .32889 .45189 .32468 .44838 Mtetra
.529 .751 .977 r
.32468 .44838 .32889 .45189 .33544 .45092 .33124 .44744 Mtetra
.538 .757 .977 r
.33124 .44744 .33544 .45092 .34203 .44985 .33783 .4464 Mtetra
.546 .762 .977 r
.33783 .4464 .34203 .44985 .34863 .4487 .34444 .44527 Mtetra
.554 .767 .977 r
.34444 .44527 .34863 .4487 .35526 .44745 .35108 .44404 Mtetra
.562 .771 .976 r
.35108 .44404 .35526 .44745 .36192 .44612 .35775 .44273 Mtetra
.569 .776 .976 r
.35775 .44273 .36192 .44612 .3686 .44471 .36444 .44134 Mtetra
.576 .78 .976 r
.36444 .44134 .3686 .44471 .37531 .44322 .37115 .43986 Mtetra
.583 .784 .975 r
.37115 .43986 .37531 .44322 .38203 .44164 .37789 .4383 Mtetra
.589 .787 .974 r
.37789 .4383 .38203 .44164 .38878 .43999 .38465 .43666 Mtetra
.595 .791 .974 r
.38465 .43666 .38878 .43999 .39556 .43826 .39144 .43494 Mtetra
.601 .794 .973 r
.39144 .43494 .39556 .43826 .40235 .43646 .39824 .43315 Mtetra
.607 .797 .972 r
.39824 .43315 .40235 .43646 .40917 .43458 .40507 .43128 Mtetra
.612 .8 .972 r
.40507 .43128 .40917 .43458 .41601 .43263 .41192 .42934 Mtetra
.618 .803 .971 r
.41192 .42934 .41601 .43263 .42286 .43062 .41879 .42732 Mtetra
.623 .805 .97 r
.41879 .42732 .42286 .43062 .42974 .42853 .42568 .42524 Mtetra
.628 .808 .969 r
.42568 .42524 .42974 .42853 .43664 .42637 .43259 .42309 Mtetra
.633 .81 .968 r
.43259 .42309 .43664 .42637 .44356 .42415 .43952 .42087 Mtetra
.638 .812 .967 r
.43952 .42087 .44356 .42415 .4505 .42186 .44648 .41857 Mtetra
.642 .814 .966 r
.44648 .41857 .4505 .42186 .45746 .41951 .45345 .41622 Mtetra
.647 .816 .964 r
.45345 .41622 .45746 .41951 .46443 .41709 .46044 .41379 Mtetra
.651 .818 .963 r
.46044 .41379 .46443 .41709 .47143 .4146 .46744 .4113 Mtetra
.656 .819 .962 r
.46744 .4113 .47143 .4146 .47844 .41205 .47447 .40874 Mtetra
.66 .821 .961 r
.47447 .40874 .47844 .41205 .48547 .40943 .48152 .40612 Mtetra
.665 .822 .959 r
.48152 .40612 .48547 .40943 .49252 .40675 .48858 .40342 Mtetra
.669 .823 .958 r
.48858 .40342 .49252 .40675 .49958 .40401 .49566 .40066 Mtetra
.673 .825 .956 r
.49566 .40066 .49958 .40401 .50667 .40119 .50275 .39784 Mtetra
.677 .826 .955 r
.50275 .39784 .50667 .40119 .51376 .39831 .50987 .39494 Mtetra
.682 .827 .953 r
.50987 .39494 .51376 .39831 .52088 .39537 .517 .39198 Mtetra
.686 .827 .951 r
.517 .39198 .52088 .39537 .52801 .39235 .52414 .38894 Mtetra
.69 .828 .949 r
.52414 .38894 .52801 .39235 .53515 .38927 .5313 .38584 Mtetra
.694 .829 .947 r
.5313 .38584 .53515 .38927 .54231 .38612 .53848 .38266 Mtetra
.698 .829 .945 r
.53848 .38266 .54231 .38612 .54949 .38289 .54567 .37941 Mtetra
.702 .83 .943 r
.54567 .37941 .54949 .38289 .55668 .37959 .55287 .37608 Mtetra
.707 .83 .941 r
.55287 .37608 .55668 .37959 .56388 .37622 .56009 .37268 Mtetra
.711 .83 .939 r
.56009 .37268 .56388 .37622 .5711 .37276 .56733 .3692 Mtetra
.715 .831 .936 r
.56733 .3692 .5711 .37276 .57833 .36923 .57457 .36564 Mtetra
.719 .831 .934 r
.57457 .36564 .57833 .36923 .58557 .36562 .58183 .36199 Mtetra
.724 .831 .931 r
.58183 .36199 .58557 .36562 .59283 .36193 .5891 .35826 Mtetra
.728 .83 .928 r
.5891 .35826 .59283 .36193 .60009 .35814 .59638 .35444 Mtetra
.732 .83 .925 r
.59638 .35444 .60009 .35814 .60737 .35427 .60367 .35053 Mtetra
.737 .83 .922 r
.60367 .35053 .60737 .35427 .61465 .35031 .61097 .34652 Mtetra
.741 .829 .919 r
.61097 .34652 .61465 .35031 .62195 .34625 .61828 .34242 Mtetra
.745 .829 .916 r
.61828 .34242 .62195 .34625 .62925 .34209 .6256 .33821 Mtetra
.75 .828 .912 r
.6256 .33821 .62925 .34209 .63657 .33783 .63293 .33391 Mtetra
.754 .827 .909 r
.63293 .33391 .63657 .33783 .64389 .33346 .64027 .32949 Mtetra
.759 .827 .905 r
.64027 .32949 .64389 .33346 .65121 .32898 .64761 .32496 Mtetra
.763 .826 .901 r
.64761 .32496 .65121 .32898 .65854 .32439 .65496 .32031 Mtetra
.768 .825 .897 r
.65496 .32031 .65854 .32439 .66588 .31968 .66231 .31554 Mtetra
.772 .824 .893 r
.66231 .31554 .66588 .31968 .67322 .31484 .66966 .31065 Mtetra
.777 .822 .888 r
.66966 .31065 .67322 .31484 .68056 .30988 .67702 .30562 Mtetra
.781 .821 .884 r
.67702 .30562 .68056 .30988 .6879 .30478 .68438 .30046 Mtetra
.786 .82 .879 r
.68438 .30046 .6879 .30478 .69525 .29954 .69173 .29516 Mtetra
.79 .818 .874 r
.69173 .29516 .69525 .29954 .70259 .29416 .69909 .28971 Mtetra
.795 .817 .869 r
.69909 .28971 .70259 .29416 .70993 .28863 .70644 .2841 Mtetra
.799 .815 .864 r
.70644 .2841 .70993 .28863 .71726 .28293 .71379 .27834 Mtetra
.804 .813 .859 r
.71379 .27834 .71726 .28293 .72459 .27708 .72113 .27241 Mtetra
.808 .812 .853 r
.72113 .27241 .72459 .27708 .73191 .27106 .72847 .2663 Mtetra
.812 .81 .848 r
.72847 .2663 .73191 .27106 .73923 .26485 .73579 .26002 Mtetra
.817 .808 .842 r
.73579 .26002 .73923 .26485 .74653 .25847 .74311 .25355 Mtetra
.821 .806 .836 r
.74311 .25355 .74653 .25847 .75382 .25189 .75041 .24689 Mtetra
.825 .803 .83 r
.75041 .24689 .75382 .25189 .76109 .24511 .7577 .24002 Mtetra
0 0 .533 r
.10005 .37175 .1041 .37743 .1089 .38301 .10483 .37742 Mtetra
0 .017 .567 r
.10483 .37742 .1089 .38301 .11378 .38833 .10969 .38282 Mtetra
0 .054 .6 r
.10969 .38282 .11378 .38833 .11872 .3934 .11461 .38797 Mtetra
0 .091 .632 r
.11461 .38797 .11872 .3934 .12373 .39821 .11961 .39286 Mtetra
0 .127 .662 r
.11961 .39286 .12373 .39821 .12881 .40278 .12467 .39751 Mtetra
0 .163 .691 r
.12467 .39751 .12881 .40278 .13396 .40712 .12981 .40191 Mtetra
0 .198 .719 r
.12981 .40191 .13396 .40712 .13917 .41121 .135 .40608 Mtetra
0 .232 .744 r
.135 .40608 .13917 .41121 .14444 .41508 .14026 .41002 Mtetra
0 .265 .768 r
.14026 .41002 .14444 .41508 .14977 .41872 .14558 .41374 Mtetra
0 .297 .79 r
.14558 .41374 .14977 .41872 .15517 .42215 .15096 .41723 Mtetra
0 .327 .81 r
.15096 .41723 .15517 .42215 .16062 .42536 .1564 .42051 Mtetra
0 .357 .829 r
.1564 .42051 .16062 .42536 .16612 .42836 .1619 .42358 Mtetra
.022 .385 .846 r
.1619 .42358 .16612 .42836 .17168 .43115 .16745 .42645 Mtetra
.056 .411 .862 r
.16745 .42645 .17168 .43115 .17729 .43375 .17305 .42911 Mtetra
.088 .436 .876 r
.17305 .42911 .17729 .43375 .18296 .43616 .17871 .43158 Mtetra
.119 .46 .888 r
.17871 .43158 .18296 .43616 .18867 .43837 .18441 .43385 Mtetra
.149 .483 .9 r
.18441 .43385 .18867 .43837 .19443 .44041 .19017 .43595 Mtetra
.177 .504 .91 r
.19017 .43595 .19443 .44041 .20024 .44226 .19598 .43786 Mtetra
.204 .524 .919 r
.19598 .43786 .20024 .44226 .2061 .44394 .20183 .43959 Mtetra
.229 .543 .927 r
.20183 .43959 .2061 .44394 .212 .44545 .20773 .44116 Mtetra
.254 .561 .934 r
.20773 .44116 .212 .44545 .21794 .44679 .21367 .44256 Mtetra
.277 .578 .941 r
.21367 .44256 .21794 .44679 .22393 .44797 .21965 .44379 Mtetra
.299 .593 .946 r
.21965 .44379 .22393 .44797 .22996 .449 .22568 .44487 Mtetra
.319 .608 .951 r
.22568 .44487 .22996 .449 .23603 .44987 .23175 .44579 Mtetra
.339 .622 .955 r
.23175 .44579 .23603 .44987 .24214 .4506 .23786 .44657 Mtetra
.358 .635 .959 r
.23786 .44657 .24214 .4506 .24828 .45118 .244 .4472 Mtetra
.375 .647 .962 r
.244 .4472 .24828 .45118 .25447 .45163 .25019 .44769 Mtetra
.392 .659 .965 r
.25019 .44769 .25447 .45163 .26069 .45193 .25641 .44804 Mtetra
.407 .67 .968 r
.25641 .44804 .26069 .45193 .26694 .45211 .26266 .44826 Mtetra
.422 .68 .97 r
.26266 .44826 .26694 .45211 .27323 .45216 .26896 .44835 Mtetra
.437 .689 .971 r
.26896 .44835 .27323 .45216 .27955 .45209 .27528 .44831 Mtetra
.45 .698 .973 r
.27528 .44831 .27955 .45209 .28591 .45189 .28164 .44815 Mtetra
.463 .707 .974 r
.28164 .44815 .28591 .45189 .29229 .45158 .28803 .44788 Mtetra
.475 .715 .975 r
.28803 .44788 .29229 .45158 .29871 .45115 .29445 .44749 Mtetra
.486 .722 .975 r
.29445 .44749 .29871 .45115 .30516 .45062 .30091 .44698 Mtetra
.497 .729 .976 r
.30091 .44698 .30516 .45062 .31164 .44998 .30739 .44637 Mtetra
.507 .736 .976 r
.30739 .44637 .31164 .44998 .31814 .44923 .3139 .44566 Mtetra
.517 .742 .977 r
.3139 .44566 .31814 .44923 .32468 .44838 .32044 .44484 Mtetra
.526 .748 .977 r
.32044 .44484 .32468 .44838 .33124 .44744 .32701 .44392 Mtetra
.535 .754 .977 r
.32701 .44392 .33124 .44744 .33783 .4464 .33361 .4429 Mtetra
.544 .759 .977 r
.33361 .4429 .33783 .4464 .34444 .44527 .34023 .44179 Mtetra
.552 .764 .976 r
.34023 .44179 .34444 .44527 .35108 .44404 .34688 .44059 Mtetra
.56 .769 .976 r
.34688 .44059 .35108 .44404 .35775 .44273 .35356 .4393 Mtetra
.567 .773 .976 r
.35356 .4393 .35775 .44273 .36444 .44134 .36026 .43792 Mtetra
.574 .778 .975 r
.36026 .43792 .36444 .44134 .37115 .43986 .36698 .43646 Mtetra
.581 .782 .975 r
.36698 .43646 .37115 .43986 .37789 .4383 .37373 .43492 Mtetra
.587 .785 .974 r
.37373 .43492 .37789 .4383 .38465 .43666 .3805 .43329 Mtetra
.594 .789 .974 r
.3805 .43329 .38465 .43666 .39144 .43494 .38729 .43158 Mtetra
.6 .792 .973 r
.38729 .43158 .39144 .43494 .39824 .43315 .39411 .4298 Mtetra
.606 .796 .972 r
.39411 .4298 .39824 .43315 .40507 .43128 .40095 .42794 Mtetra
.611 .799 .971 r
.40095 .42794 .40507 .43128 .41192 .42934 .40781 .42601 Mtetra
.617 .801 .97 r
.40781 .42601 .41192 .42934 .41879 .42732 .41469 .424 Mtetra
.622 .804 .97 r
.41469 .424 .41879 .42732 .42568 .42524 .4216 .42192 Mtetra
.627 .807 .969 r
.4216 .42192 .42568 .42524 .43259 .42309 .42852 .41977 Mtetra
.632 .809 .968 r
.42852 .41977 .43259 .42309 .43952 .42087 .43547 .41755 Mtetra
.637 .811 .966 r
.43547 .41755 .43952 .42087 .44648 .41857 .44243 .41526 Mtetra
.642 .813 .965 r
.44243 .41526 .44648 .41857 .45345 .41622 .44942 .41289 Mtetra
.647 .815 .964 r
.44942 .41289 .45345 .41622 .46044 .41379 .45642 .41046 Mtetra
.651 .817 .963 r
.45642 .41046 .46044 .41379 .46744 .4113 .46344 .40797 Mtetra
.656 .818 .962 r
.46344 .40797 .46744 .4113 .47447 .40874 .47048 .4054 Mtetra
.66 .82 .96 r
.47048 .4054 .47447 .40874 .48152 .40612 .47754 .40276 Mtetra
.665 .821 .959 r
.47754 .40276 .48152 .40612 .48858 .40342 .48462 .40006 Mtetra
.669 .823 .957 r
.48462 .40006 .48858 .40342 .49566 .40066 .49171 .39729 Mtetra
.673 .824 .956 r
.49171 .39729 .49566 .40066 .50275 .39784 .49882 .39445 Mtetra
.678 .825 .954 r
.49882 .39445 .50275 .39784 .50987 .39494 .50595 .39154 Mtetra
.682 .826 .952 r
.50595 .39154 .50987 .39494 .517 .39198 .51309 .38855 Mtetra
.686 .827 .95 r
.51309 .38855 .517 .39198 .52414 .38894 .52025 .3855 Mtetra
.691 .827 .949 r
.52025 .3855 .52414 .38894 .5313 .38584 .52743 .38237 Mtetra
.695 .828 .947 r
.52743 .38237 .5313 .38584 .53848 .38266 .53462 .37917 Mtetra
.699 .829 .945 r
.53462 .37917 .53848 .38266 .54567 .37941 .54183 .37589 Mtetra
.703 .829 .942 r
.54183 .37589 .54567 .37941 .55287 .37608 .54905 .37254 Mtetra
.708 .829 .94 r
.54905 .37254 .55287 .37608 .56009 .37268 .55628 .36911 Mtetra
.712 .83 .938 r
.55628 .36911 .56009 .37268 .56733 .3692 .56353 .3656 Mtetra
.716 .83 .935 r
.56353 .3656 .56733 .3692 .57457 .36564 .57079 .362 Mtetra
.721 .83 .932 r
.57079 .362 .57457 .36564 .58183 .36199 .57807 .35832 Mtetra
.725 .83 .93 r
.57807 .35832 .58183 .36199 .5891 .35826 .58535 .35455 Mtetra
.729 .829 .927 r
.58535 .35455 .5891 .35826 .59638 .35444 .59265 .35069 Mtetra
.734 .829 .924 r
.59265 .35069 .59638 .35444 .60367 .35053 .59996 .34674 Mtetra
.738 .829 .921 r
.59996 .34674 .60367 .35053 .61097 .34652 .60727 .34269 Mtetra
.742 .828 .917 r
.60727 .34269 .61097 .34652 .61828 .34242 .6146 .33854 Mtetra
.747 .828 .914 r
.6146 .33854 .61828 .34242 .6256 .33821 .62194 .33429 Mtetra
.751 .827 .91 r
.62194 .33429 .6256 .33821 .63293 .33391 .62928 .32993 Mtetra
.756 .826 .907 r
.62928 .32993 .63293 .33391 .64027 .32949 .63663 .32546 Mtetra
.76 .825 .903 r
.63663 .32546 .64027 .32949 .64761 .32496 .64399 .32088 Mtetra
.765 .824 .899 r
.64399 .32088 .64761 .32496 .65496 .32031 .65135 .31617 Mtetra
.769 .823 .895 r
.65135 .31617 .65496 .32031 .66231 .31554 .65871 .31135 Mtetra
.774 .822 .891 r
.65871 .31135 .66231 .31554 .66966 .31065 .66608 .30639 Mtetra
.778 .821 .886 r
.66608 .30639 .66966 .31065 .67702 .30562 .67345 .3013 Mtetra
.783 .82 .881 r
.67345 .3013 .67702 .30562 .68438 .30046 .68083 .29608 Mtetra
.787 .818 .877 r
.68083 .29608 .68438 .30046 .69173 .29516 .6882 .2907 Mtetra
.792 .816 .872 r
.6882 .2907 .69173 .29516 .69909 .28971 .69557 .28518 Mtetra
.796 .815 .867 r
.69557 .28518 .69909 .28971 .70644 .2841 .70294 .27951 Mtetra
.8 .813 .862 r
.70294 .27951 .70644 .2841 .71379 .27834 .7103 .27367 Mtetra
.805 .811 .856 r
.7103 .27367 .71379 .27834 .72113 .27241 .71765 .26766 Mtetra
.809 .809 .851 r
.71765 .26766 .72113 .27241 .72847 .2663 .725 .26147 Mtetra
.814 .807 .845 r
.725 .26147 .72847 .2663 .73579 .26002 .73234 .25511 Mtetra
.818 .805 .839 r
.73234 .25511 .73579 .26002 .74311 .25355 .73967 .24855 Mtetra
.822 .803 .833 r
.73967 .24855 .74311 .25355 .75041 .24689 .74698 .2418 Mtetra
.826 .801 .827 r
.74698 .2418 .75041 .24689 .7577 .24002 .75428 .23485 Mtetra
0 0 .529 r
.096 .36595 .10005 .37175 .10483 .37742 .10076 .3717 Mtetra
0 .01 .563 r
.10076 .3717 .10483 .37742 .10969 .38282 .1056 .37719 Mtetra
0 .047 .596 r
.1056 .37719 .10969 .38282 .11461 .38797 .1105 .38242 Mtetra
0 .083 .627 r
.1105 .38242 .11461 .38797 .11961 .39286 .11548 .38739 Mtetra
0 .119 .657 r
.11548 .38739 .11961 .39286 .12467 .39751 .12053 .39212 Mtetra
0 .155 .686 r
.12053 .39212 .12467 .39751 .12981 .40191 .12565 .3966 Mtetra
0 .19 .713 r
.12565 .3966 .12981 .40191 .135 .40608 .13083 .40085 Mtetra
0 .224 .739 r
.13083 .40085 .135 .40608 .14026 .41002 .13607 .40487 Mtetra
0 .256 .763 r
.13607 .40487 .14026 .41002 .14558 .41374 .14138 .40866 Mtetra
0 .288 .785 r
.14138 .40866 .14558 .41374 .15096 .41723 .14675 .41222 Mtetra
0 .319 .805 r
.14675 .41222 .15096 .41723 .1564 .42051 .15218 .41557 Mtetra
0 .348 .824 r
.15218 .41557 .1564 .42051 .1619 .42358 .15766 .41871 Mtetra
.016 .376 .841 r
.15766 .41871 .1619 .42358 .16745 .42645 .1632 .42164 Mtetra
.05 .403 .857 r
.1632 .42164 .16745 .42645 .17305 .42911 .1688 .42437 Mtetra
.082 .428 .871 r
.1688 .42437 .17305 .42911 .17871 .43158 .17445 .42691 Mtetra
.113 .452 .884 r
.17445 .42691 .17871 .43158 .18441 .43385 .18015 .42925 Mtetra
.143 .475 .896 r
.18015 .42925 .18441 .43385 .19017 .43595 .1859 .43141 Mtetra
.171 .497 .906 r
.1859 .43141 .19017 .43595 .19598 .43786 .1917 .43338 Mtetra
.198 .517 .916 r
.1917 .43338 .19598 .43786 .20183 .43959 .19755 .43517 Mtetra
.224 .536 .924 r
.19755 .43517 .20183 .43959 .20773 .44116 .20344 .4368 Mtetra
.248 .554 .931 r
.20344 .4368 .20773 .44116 .21367 .44256 .20938 .43825 Mtetra
.271 .571 .938 r
.20938 .43825 .21367 .44256 .21965 .44379 .21536 .43954 Mtetra
.293 .587 .944 r
.21536 .43954 .21965 .44379 .22568 .44487 .22139 .44067 Mtetra
.314 .602 .949 r
.22139 .44067 .22568 .44487 .23175 .44579 .22745 .44165 Mtetra
.334 .616 .953 r
.22745 .44165 .23175 .44579 .23786 .44657 .23356 .44247 Mtetra
.353 .629 .957 r
.23356 .44247 .23786 .44657 .244 .4472 .23971 .44315 Mtetra
.37 .642 .96 r
.23971 .44315 .244 .4472 .25019 .44769 .24589 .44368 Mtetra
.387 .654 .963 r
.24589 .44368 .25019 .44769 .25641 .44804 .25211 .44408 Mtetra
.403 .665 .966 r
.25211 .44408 .25641 .44804 .26266 .44826 .25837 .44434 Mtetra
.418 .675 .968 r
.25837 .44434 .26266 .44826 .26896 .44835 .26467 .44448 Mtetra
.432 .685 .97 r
.26467 .44448 .26896 .44835 .27528 .44831 .27099 .44448 Mtetra
.446 .694 .971 r
.27099 .44448 .27528 .44831 .28164 .44815 .27736 .44436 Mtetra
.459 .703 .973 r
.27736 .44436 .28164 .44815 .28803 .44788 .28375 .44412 Mtetra
.471 .711 .974 r
.28375 .44412 .28803 .44788 .29445 .44749 .29018 .44377 Mtetra
.483 .719 .975 r
.29018 .44377 .29445 .44749 .30091 .44698 .29664 .4433 Mtetra
.494 .726 .975 r
.29664 .4433 .30091 .44698 .30739 .44637 .30313 .44272 Mtetra
.504 .733 .976 r
.30313 .44272 .30739 .44637 .3139 .44566 .30965 .44203 Mtetra
.514 .739 .976 r
.30965 .44203 .3139 .44566 .32044 .44484 .31619 .44124 Mtetra
.524 .745 .976 r
.31619 .44124 .32044 .44484 .32701 .44392 .32277 .44035 Mtetra
.533 .751 .976 r
.32277 .44035 .32701 .44392 .33361 .4429 .32937 .43936 Mtetra
.541 .757 .976 r
.32937 .43936 .33361 .4429 .34023 .44179 .336 .43828 Mtetra
.549 .762 .976 r
.336 .43828 .34023 .44179 .34688 .44059 .34266 .4371 Mtetra
.557 .767 .976 r
.34266 .4371 .34688 .44059 .35356 .4393 .34934 .43583 Mtetra
.565 .771 .975 r
.34934 .43583 .35356 .4393 .36026 .43792 .35605 .43447 Mtetra
.572 .776 .975 r
.35605 .43447 .36026 .43792 .36698 .43646 .36279 .43302 Mtetra
.579 .78 .974 r
.36279 .43302 .36698 .43646 .37373 .43492 .36954 .43149 Mtetra
.586 .783 .974 r
.36954 .43149 .37373 .43492 .3805 .43329 .37633 .42988 Mtetra
.592 .787 .973 r
.37633 .42988 .3805 .43329 .38729 .43158 .38313 .42819 Mtetra
.598 .791 .973 r
.38313 .42819 .38729 .43158 .39411 .4298 .38996 .42642 Mtetra
.604 .794 .972 r
.38996 .42642 .39411 .4298 .40095 .42794 .39681 .42456 Mtetra
.61 .797 .971 r
.39681 .42456 .40095 .42794 .40781 .42601 .40368 .42264 Mtetra
.616 .8 .97 r
.40368 .42264 .40781 .42601 .41469 .424 .41058 .42064 Mtetra
.621 .803 .969 r
.41058 .42064 .41469 .424 .4216 .42192 .41749 .41856 Mtetra
.626 .805 .968 r
.41749 .41856 .4216 .42192 .42852 .41977 .42443 .41641 Mtetra
.632 .808 .967 r
.42443 .41641 .42852 .41977 .43547 .41755 .43139 .41419 Mtetra
.637 .81 .966 r
.43139 .41419 .43547 .41755 .44243 .41526 .43837 .4119 Mtetra
.642 .812 .965 r
.43837 .4119 .44243 .41526 .44942 .41289 .44536 .40953 Mtetra
.646 .814 .964 r
.44536 .40953 .44942 .41289 .45642 .41046 .45238 .4071 Mtetra
.651 .816 .962 r
.45238 .4071 .45642 .41046 .46344 .40797 .45942 .4046 Mtetra
.656 .817 .961 r
.45942 .4046 .46344 .40797 .47048 .4054 .46647 .40202 Mtetra
.66 .819 .96 r
.46647 .40202 .47048 .4054 .47754 .40276 .47354 .39938 Mtetra
.665 .82 .958 r
.47354 .39938 .47754 .40276 .48462 .40006 .48063 .39666 Mtetra
.669 .822 .957 r
.48063 .39666 .48462 .40006 .49171 .39729 .48774 .39388 Mtetra
.674 .823 .955 r
.48774 .39388 .49171 .39729 .49882 .39445 .49487 .39102 Mtetra
.678 .824 .953 r
.49487 .39102 .49882 .39445 .50595 .39154 .50201 .38809 Mtetra
.683 .825 .952 r
.50201 .38809 .50595 .39154 .51309 .38855 .50917 .38509 Mtetra
.687 .826 .95 r
.50917 .38509 .51309 .38855 .52025 .3855 .51635 .38201 Mtetra
.691 .826 .948 r
.51635 .38201 .52025 .3855 .52743 .38237 .52354 .37887 Mtetra
.696 .827 .946 r
.52354 .37887 .52743 .38237 .53462 .37917 .53074 .37564 Mtetra
.7 .828 .943 r
.53074 .37564 .53462 .37917 .54183 .37589 .53797 .37234 Mtetra
.704 .828 .941 r
.53797 .37234 .54183 .37589 .54905 .37254 .5452 .36896 Mtetra
.709 .828 .939 r
.5452 .36896 .54905 .37254 .55628 .36911 .55245 .36549 Mtetra
.713 .829 .936 r
.55245 .36549 .55628 .36911 .56353 .3656 .55971 .36195 Mtetra
.717 .829 .934 r
.55971 .36195 .56353 .3656 .57079 .362 .56699 .35832 Mtetra
.722 .829 .931 r
.56699 .35832 .57079 .362 .57807 .35832 .57428 .3546 Mtetra
.726 .829 .928 r
.57428 .3546 .57807 .35832 .58535 .35455 .58158 .35079 Mtetra
.731 .828 .925 r
.58158 .35079 .58535 .35455 .59265 .35069 .58889 .34689 Mtetra
.735 .828 .922 r
.58889 .34689 .59265 .35069 .59996 .34674 .59622 .3429 Mtetra
.739 .828 .919 r
.59622 .3429 .59996 .34674 .60727 .34269 .60355 .33881 Mtetra
.744 .827 .916 r
.60355 .33881 .60727 .34269 .6146 .33854 .61089 .33461 Mtetra
.748 .826 .912 r
.61089 .33461 .6146 .33854 .62194 .33429 .61825 .33031 Mtetra
.753 .826 .909 r
.61825 .33031 .62194 .33429 .62928 .32993 .6256 .3259 Mtetra
.757 .825 .905 r
.6256 .3259 .62928 .32993 .63663 .32546 .63297 .32138 Mtetra
.762 .824 .901 r
.63297 .32138 .63663 .32546 .64399 .32088 .64034 .31674 Mtetra
.766 .823 .897 r
.64034 .31674 .64399 .32088 .65135 .31617 .64772 .31198 Mtetra
.771 .822 .893 r
.64772 .31198 .65135 .31617 .65871 .31135 .6551 .30709 Mtetra
.775 .82 .888 r
.6551 .30709 .65871 .31135 .66608 .30639 .66248 .30207 Mtetra
.78 .819 .884 r
.66248 .30207 .66608 .30639 .67345 .3013 .66987 .29692 Mtetra
.784 .818 .879 r
.66987 .29692 .67345 .3013 .68083 .29608 .67726 .29162 Mtetra
.788 .816 .874 r
.67726 .29162 .68083 .29608 .6882 .2907 .68464 .28618 Mtetra
.793 .814 .869 r
.68464 .28618 .6882 .2907 .69557 .28518 .69203 .28059 Mtetra
.797 .813 .864 r
.69203 .28059 .69557 .28518 .70294 .27951 .69941 .27483 Mtetra
.802 .811 .859 r
.69941 .27483 .70294 .27951 .7103 .27367 .70679 .26892 Mtetra
.806 .809 .853 r
.70679 .26892 .7103 .27367 .71765 .26766 .71416 .26283 Mtetra
.81 .807 .848 r
.71416 .26283 .71765 .26766 .725 .26147 .72152 .25656 Mtetra
.815 .805 .842 r
.72152 .25656 .725 .26147 .73234 .25511 .72887 .25011 Mtetra
.819 .803 .836 r
.72887 .25011 .73234 .25511 .73967 .24855 .73621 .24347 Mtetra
.823 .801 .83 r
.73621 .24347 .73967 .24855 .74698 .2418 .74353 .23662 Mtetra
.827 .798 .824 r
.74353 .23662 .74698 .2418 .75428 .23485 .75084 .22957 Mtetra
0 0 .525 r
.09195 .36003 .096 .36595 .10076 .3717 .09669 .36586 Mtetra
0 .003 .559 r
.09669 .36586 .10076 .3717 .1056 .37719 .10151 .37143 Mtetra
0 .039 .591 r
.10151 .37143 .1056 .37719 .1105 .38242 .1064 .37675 Mtetra
0 .075 .622 r
.1064 .37675 .1105 .38242 .11548 .38739 .11136 .3818 Mtetra
0 .111 .652 r
.11136 .3818 .11548 .38739 .12053 .39212 .11639 .38661 Mtetra
0 .147 .681 r
.11639 .38661 .12053 .39212 .12565 .3966 .12149 .39118 Mtetra
0 .181 .708 r
.12149 .39118 .12565 .3966 .13083 .40085 .12665 .39551 Mtetra
0 .215 .734 r
.12665 .39551 .13083 .40085 .13607 .40487 .13189 .3996 Mtetra
0 .248 .757 r
.13189 .3996 .13607 .40487 .14138 .40866 .13718 .40347 Mtetra
0 .28 .78 r
.13718 .40347 .14138 .40866 .14675 .41222 .14253 .40711 Mtetra
0 .31 .8 r
.14253 .40711 .14675 .41222 .15218 .41557 .14795 .41053 Mtetra
0 .34 .819 r
.14795 .41053 .15218 .41557 .15766 .41871 .15342 .41374 Mtetra
.01 .368 .836 r
.15342 .41374 .15766 .41871 .1632 .42164 .15896 .41675 Mtetra
.044 .394 .852 r
.15896 .41675 .1632 .42164 .1688 .42437 .16454 .41955 Mtetra
.076 .42 .867 r
.16454 .41955 .1688 .42437 .17445 .42691 .17018 .42215 Mtetra
.107 .444 .88 r
.17018 .42215 .17445 .42691 .18015 .42925 .17587 .42456 Mtetra
.137 .467 .892 r
.17587 .42456 .18015 .42925 .1859 .43141 .18162 .42678 Mtetra
.165 .489 .902 r
.18162 .42678 .1859 .43141 .1917 .43338 .18741 .42881 Mtetra
.192 .509 .912 r
.18741 .42881 .1917 .43338 .19755 .43517 .19325 .43067 Mtetra
.218 .529 .92 r
.19325 .43067 .19755 .43517 .20344 .4368 .19914 .43235 Mtetra
.242 .547 .928 r
.19914 .43235 .20344 .4368 .20938 .43825 .20508 .43386 Mtetra
.266 .564 .935 r
.20508 .43386 .20938 .43825 .21536 .43954 .21106 .43521 Mtetra
.288 .58 .941 r
.21106 .43521 .21536 .43954 .22139 .44067 .21708 .43639 Mtetra
.309 .596 .946 r
.21708 .43639 .22139 .44067 .22745 .44165 .22314 .43742 Mtetra
.329 .61 .951 r
.22314 .43742 .22745 .44165 .23356 .44247 .22925 .4383 Mtetra
.348 .623 .955 r
.22925 .4383 .23356 .44247 .23971 .44315 .2354 .43903 Mtetra
.365 .636 .958 r
.2354 .43903 .23971 .44315 .24589 .44368 .24158 .43961 Mtetra
.382 .648 .962 r
.24158 .43961 .24589 .44368 .25211 .44408 .2478 .44006 Mtetra
.399 .659 .964 r
.2478 .44006 .25211 .44408 .25837 .44434 .25406 .44036 Mtetra
.414 .67 .966 r
.25406 .44036 .25837 .44434 .26467 .44448 .26036 .44054 Mtetra
.428 .68 .968 r
.26036 .44054 .26467 .44448 .27099 .44448 .26669 .44059 Mtetra
.442 .689 .97 r
.26669 .44059 .27099 .44448 .27736 .44436 .27306 .44051 Mtetra
.455 .698 .971 r
.27306 .44051 .27736 .44436 .28375 .44412 .27946 .44031 Mtetra
.467 .707 .973 r
.27946 .44031 .28375 .44412 .29018 .44377 .28589 .43999 Mtetra
.479 .715 .974 r
.28589 .43999 .29018 .44377 .29664 .4433 .29235 .43955 Mtetra
.49 .722 .974 r
.29235 .43955 .29664 .4433 .30313 .44272 .29884 .43901 Mtetra
.501 .729 .975 r
.29884 .43901 .30313 .44272 .30965 .44203 .30537 .43835 Mtetra
.511 .736 .975 r
.30537 .43835 .30965 .44203 .31619 .44124 .31192 .43759 Mtetra
.521 .742 .975 r
.31192 .43759 .31619 .44124 .32277 .44035 .31851 .43673 Mtetra
.53 .748 .975 r
.31851 .43673 .32277 .44035 .32937 .43936 .32512 .43577 Mtetra
.539 .754 .975 r
.32512 .43577 .32937 .43936 .336 .43828 .33176 .43471 Mtetra
.547 .759 .975 r
.33176 .43471 .336 .43828 .34266 .4371 .33842 .43355 Mtetra
.555 .764 .975 r
.33842 .43355 .34266 .4371 .34934 .43583 .34511 .4323 Mtetra
.563 .769 .975 r
.34511 .4323 .34934 .43583 .35605 .43447 .35183 .43096 Mtetra
.57 .773 .974 r
.35183 .43096 .35605 .43447 .36279 .43302 .35857 .42954 Mtetra
.577 .777 .974 r
.35857 .42954 .36279 .43302 .36954 .43149 .36534 .42802 Mtetra
.584 .781 .973 r
.36534 .42802 .36954 .43149 .37633 .42988 .37213 .42643 Mtetra
.591 .785 .973 r
.37213 .42643 .37633 .42988 .38313 .42819 .37895 .42475 Mtetra
.597 .789 .972 r
.37895 .42475 .38313 .42819 .38996 .42642 .38579 .42298 Mtetra
.603 .792 .971 r
.38579 .42298 .38996 .42642 .39681 .42456 .39265 .42114 Mtetra
.609 .795 .97 r
.39265 .42114 .39681 .42456 .40368 .42264 .39953 .41923 Mtetra
.615 .798 .97 r
.39953 .41923 .40368 .42264 .41058 .42064 .40644 .41723 Mtetra
.62 .801 .969 r
.40644 .41723 .41058 .42064 .41749 .41856 .41337 .41516 Mtetra
.626 .803 .968 r
.41337 .41516 .41749 .41856 .42443 .41641 .42032 .41301 Mtetra
.631 .806 .967 r
.42032 .41301 .42443 .41641 .43139 .41419 .42729 .41079 Mtetra
.636 .808 .965 r
.42729 .41079 .43139 .41419 .43837 .4119 .43428 .4085 Mtetra
.641 .81 .964 r
.43428 .4085 .43837 .4119 .44536 .40953 .44129 .40613 Mtetra
.646 .812 .963 r
.44129 .40613 .44536 .40953 .45238 .4071 .44832 .40369 Mtetra
.651 .814 .962 r
.44832 .40369 .45238 .4071 .45942 .4046 .45537 .40118 Mtetra
.656 .816 .96 r
.45537 .40118 .45942 .4046 .46647 .40202 .46244 .3986 Mtetra
.66 .818 .959 r
.46244 .3986 .46647 .40202 .47354 .39938 .46952 .39595 Mtetra
.665 .819 .957 r
.46952 .39595 .47354 .39938 .48063 .39666 .47663 .39322 Mtetra
.67 .82 .956 r
.47663 .39322 .48063 .39666 .48774 .39388 .48375 .39042 Mtetra
.674 .822 .954 r
.48375 .39042 .48774 .39388 .49487 .39102 .49089 .38755 Mtetra
.679 .823 .952 r
.49089 .38755 .49487 .39102 .50201 .38809 .49805 .3846 Mtetra
.683 .824 .951 r
.49805 .3846 .50201 .38809 .50917 .38509 .50523 .38158 Mtetra
.688 .825 .949 r
.50523 .38158 .50917 .38509 .51635 .38201 .51242 .37849 Mtetra
.692 .825 .947 r
.51242 .37849 .51635 .38201 .52354 .37887 .51962 .37531 Mtetra
.697 .826 .944 r
.51962 .37531 .52354 .37887 .53074 .37564 .52684 .37206 Mtetra
.701 .826 .942 r
.52684 .37206 .53074 .37564 .53797 .37234 .53408 .36873 Mtetra
.705 .827 .94 r
.53408 .36873 .53797 .37234 .5452 .36896 .54133 .36532 Mtetra
.71 .827 .938 r
.54133 .36532 .5452 .36896 .55245 .36549 .5486 .36183 Mtetra
.714 .827 .935 r
.5486 .36183 .55245 .36549 .55971 .36195 .55588 .35825 Mtetra
.719 .827 .932 r
.55588 .35825 .55971 .36195 .56699 .35832 .56317 .35459 Mtetra
.723 .827 .93 r
.56317 .35459 .56699 .35832 .57428 .3546 .57048 .35083 Mtetra
.727 .827 .927 r
.57048 .35083 .57428 .3546 .58158 .35079 .57779 .34699 Mtetra
.732 .827 .924 r
.57779 .34699 .58158 .35079 .58889 .34689 .58512 .34304 Mtetra
.736 .826 .92 r
.58512 .34304 .58889 .34689 .59622 .3429 .59246 .33901 Mtetra
.741 .826 .917 r
.59246 .33901 .59622 .3429 .60355 .33881 .59981 .33487 Mtetra
.745 .825 .914 r
.59981 .33487 .60355 .33881 .61089 .33461 .60717 .33062 Mtetra
.75 .825 .91 r
.60717 .33062 .61089 .33461 .61825 .33031 .61453 .32627 Mtetra
.754 .824 .906 r
.61453 .32627 .61825 .33031 .6256 .3259 .62191 .32181 Mtetra
.759 .823 .903 r
.62191 .32181 .6256 .3259 .63297 .32138 .62929 .31723 Mtetra
.763 .822 .899 r
.62929 .31723 .63297 .32138 .64034 .31674 .63668 .31253 Mtetra
.768 .821 .894 r
.63668 .31253 .64034 .31674 .64772 .31198 .64407 .30771 Mtetra
.772 .82 .89 r
.64407 .30771 .64772 .31198 .6551 .30709 .65147 .30276 Mtetra
.776 .818 .886 r
.65147 .30276 .6551 .30709 .66248 .30207 .65887 .29768 Mtetra
.781 .817 .881 r
.65887 .29768 .66248 .30207 .66987 .29692 .66627 .29246 Mtetra
.785 .815 .876 r
.66627 .29246 .66987 .29692 .67726 .29162 .67367 .2871 Mtetra
.79 .814 .871 r
.67367 .2871 .67726 .29162 .68464 .28618 .68107 .28158 Mtetra
.794 .812 .866 r
.68107 .28158 .68464 .28618 .69203 .28059 .68847 .27591 Mtetra
.798 .81 .861 r
.68847 .27591 .69203 .28059 .69941 .27483 .69586 .27008 Mtetra
.803 .808 .856 r
.69586 .27008 .69941 .27483 .70679 .26892 .70325 .26408 Mtetra
.807 .806 .85 r
.70325 .26408 .70679 .26892 .71416 .26283 .71063 .25791 Mtetra
.811 .804 .845 r
.71063 .25791 .71416 .26283 .72152 .25656 .71801 .25156 Mtetra
.815 .802 .839 r
.71801 .25156 .72152 .25656 .72887 .25011 .72537 .24502 Mtetra
.82 .8 .833 r
.72537 .24502 .72887 .25011 .73621 .24347 .73273 .23828 Mtetra
.824 .798 .827 r
.73273 .23828 .73621 .24347 .74353 .23662 .74006 .23135 Mtetra
.828 .795 .821 r
.74006 .23135 .74353 .23662 .75084 .22957 .74738 .2242 Mtetra
0 0 .521 r
.08791 .35396 .09195 .36003 .09669 .36586 .09263 .35989 Mtetra
0 0 .554 r
.09263 .35989 .09669 .36586 .10151 .37143 .09742 .36555 Mtetra
0 .032 .586 r
.09742 .36555 .10151 .37143 .1064 .37675 .10229 .37095 Mtetra
0 .068 .617 r
.10229 .37095 .1064 .37675 .11136 .3818 .10723 .37609 Mtetra
0 .103 .647 r
.10723 .37609 .11136 .3818 .11639 .38661 .11224 .38099 Mtetra
0 .138 .676 r
.11224 .38099 .11639 .38661 .12149 .39118 .11733 .38564 Mtetra
0 .173 .703 r
.11733 .38564 .12149 .39118 .12665 .39551 .12248 .39005 Mtetra
0 .206 .728 r
.12248 .39005 .12665 .39551 .13189 .3996 .12769 .39422 Mtetra
0 .239 .752 r
.12769 .39422 .13189 .3996 .13718 .40347 .13297 .39816 Mtetra
0 .271 .774 r
.13297 .39816 .13718 .40347 .14253 .40711 .13831 .40188 Mtetra
0 .301 .795 r
.13831 .40188 .14253 .40711 .14795 .41053 .14372 .40538 Mtetra
0 .331 .814 r
.14372 .40538 .14795 .41053 .15342 .41374 .14918 .40867 Mtetra
.004 .359 .831 r
.14918 .40867 .15342 .41374 .15896 .41675 .1547 .41175 Mtetra
.038 .386 .848 r
.1547 .41175 .15896 .41675 .16454 .41955 .16028 .41462 Mtetra
.07 .411 .862 r
.16028 .41462 .16454 .41955 .17018 .42215 .16591 .41729 Mtetra
.101 .436 .875 r
.16591 .41729 .17018 .42215 .17587 .42456 .17159 .41977 Mtetra
.131 .459 .887 r
.17159 .41977 .17587 .42456 .18162 .42678 .17733 .42205 Mtetra
.159 .481 .898 r
.17733 .42205 .18162 .42678 .18741 .42881 .18311 .42415 Mtetra
.186 .502 .908 r
.18311 .42415 .18741 .42881 .19325 .43067 .18895 .42607 Mtetra
.212 .521 .917 r
.18895 .42607 .19325 .43067 .19914 .43235 .19483 .42782 Mtetra
.237 .54 .925 r
.19483 .42782 .19914 .43235 .20508 .43386 .20076 .42939 Mtetra
.26 .557 .932 r
.20076 .42939 .20508 .43386 .21106 .43521 .20674 .43079 Mtetra
.282 .573 .938 r
.20674 .43079 .21106 .43521 .21708 .43639 .21276 .43204 Mtetra
.303 .589 .943 r
.21276 .43204 .21708 .43639 .22314 .43742 .21882 .43312 Mtetra
.324 .604 .948 r
.21882 .43312 .22314 .43742 .22925 .4383 .22493 .43405 Mtetra
.343 .617 .952 r
.22493 .43405 .22925 .4383 .2354 .43903 .23107 .43483 Mtetra
.361 .63 .956 r
.23107 .43483 .2354 .43903 .24158 .43961 .23726 .43547 Mtetra
.378 .642 .959 r
.23726 .43547 .24158 .43961 .2478 .44006 .24348 .43596 Mtetra
.394 .654 .962 r
.24348 .43596 .2478 .44006 .25406 .44036 .24974 .43631 Mtetra
.41 .665 .965 r
.24974 .43631 .25406 .44036 .26036 .44054 .25604 .43653 Mtetra
.424 .675 .967 r
.25604 .43653 .26036 .44054 .26669 .44059 .26237 .43662 Mtetra
.438 .685 .969 r
.26237 .43662 .26669 .44059 .27306 .44051 .26874 .43658 Mtetra
.451 .694 .97 r
.26874 .43658 .27306 .44051 .27946 .44031 .27514 .43642 Mtetra
.464 .702 .971 r
.27514 .43642 .27946 .44031 .28589 .43999 .28158 .43614 Mtetra
.476 .71 .972 r
.28158 .43614 .28589 .43999 .29235 .43955 .28804 .43575 Mtetra
.487 .718 .973 r
.28804 .43575 .29235 .43955 .29884 .43901 .29454 .43524 Mtetra
.498 .725 .974 r
.29454 .43524 .29884 .43901 .30537 .43835 .30107 .43461 Mtetra
.508 .732 .974 r
.30107 .43461 .30537 .43835 .31192 .43759 .30763 .43389 Mtetra
.518 .738 .974 r
.30763 .43389 .31192 .43759 .31851 .43673 .31422 .43305 Mtetra
.527 .745 .975 r
.31422 .43305 .31851 .43673 .32512 .43577 .32084 .43212 Mtetra
.536 .75 .975 r
.32084 .43212 .32512 .43577 .33176 .43471 .32749 .43108 Mtetra
.545 .756 .975 r
.32749 .43108 .33176 .43471 .33842 .43355 .33416 .42995 Mtetra
.553 .761 .974 r
.33416 .42995 .33842 .43355 .34511 .4323 .34086 .42872 Mtetra
.561 .766 .974 r
.34086 .42872 .34511 .4323 .35183 .43096 .34759 .42741 Mtetra
.568 .77 .974 r
.34759 .42741 .35183 .43096 .35857 .42954 .35434 .426 Mtetra
.576 .775 .973 r
.35434 .426 .35857 .42954 .36534 .42802 .36112 .4245 Mtetra
.583 .779 .973 r
.36112 .4245 .36534 .42802 .37213 .42643 .36792 .42292 Mtetra
.589 .783 .972 r
.36792 .42292 .37213 .42643 .37895 .42475 .37475 .42125 Mtetra
.596 .786 .971 r
.37475 .42125 .37895 .42475 .38579 .42298 .3816 .4195 Mtetra
.602 .79 .971 r
.3816 .4195 .38579 .42298 .39265 .42114 .38847 .41767 Mtetra
.608 .793 .97 r
.38847 .41767 .39265 .42114 .39953 .41923 .39537 .41576 Mtetra
.614 .796 .969 r
.39537 .41576 .39953 .41923 .40644 .41723 .40228 .41377 Mtetra
.62 .799 .968 r
.40228 .41377 .40644 .41723 .41337 .41516 .40922 .41171 Mtetra
.625 .802 .967 r
.40922 .41171 .41337 .41516 .42032 .41301 .41619 .40956 Mtetra
.631 .804 .966 r
.41619 .40956 .42032 .41301 .42729 .41079 .42317 .40735 Mtetra
.636 .806 .965 r
.42317 .40735 .42729 .41079 .43428 .4085 .43017 .40505 Mtetra
.641 .809 .964 r
.43017 .40505 .43428 .4085 .44129 .40613 .43719 .40268 Mtetra
.646 .811 .962 r
.43719 .40268 .44129 .40613 .44832 .40369 .44424 .40024 Mtetra
.651 .813 .961 r
.44424 .40024 .44832 .40369 .45537 .40118 .4513 .39772 Mtetra
.656 .814 .96 r
.4513 .39772 .45537 .40118 .46244 .3986 .45838 .39513 Mtetra
.661 .816 .958 r
.45838 .39513 .46244 .3986 .46952 .39595 .46549 .39247 Mtetra
.665 .817 .956 r
.46549 .39247 .46952 .39595 .47663 .39322 .4726 .38973 Mtetra
.67 .819 .955 r
.4726 .38973 .47663 .39322 .48375 .39042 .47974 .38692 Mtetra
.675 .82 .953 r
.47974 .38692 .48375 .39042 .49089 .38755 .4869 .38403 Mtetra
.679 .821 .951 r
.4869 .38403 .49089 .38755 .49805 .3846 .49407 .38106 Mtetra
.684 .822 .949 r
.49407 .38106 .49805 .3846 .50523 .38158 .50126 .37802 Mtetra
.688 .823 .947 r
.50126 .37802 .50523 .38158 .51242 .37849 .50846 .37491 Mtetra
.693 .824 .945 r
.50846 .37491 .51242 .37849 .51962 .37531 .51569 .37171 Mtetra
.697 .824 .943 r
.51569 .37171 .51962 .37531 .52684 .37206 .52292 .36843 Mtetra
.702 .825 .941 r
.52292 .36843 .52684 .37206 .53408 .36873 .53018 .36508 Mtetra
.706 .825 .939 r
.53018 .36508 .53408 .36873 .54133 .36532 .53744 .36164 Mtetra
.711 .826 .936 r
.53744 .36164 .54133 .36532 .5486 .36183 .54473 .35811 Mtetra
.715 .826 .933 r
.54473 .35811 .5486 .36183 .55588 .35825 .55202 .3545 Mtetra
.72 .826 .931 r
.55202 .3545 .55588 .35825 .56317 .35459 .55933 .3508 Mtetra
.724 .826 .928 r
.55933 .3508 .56317 .35459 .57048 .35083 .56665 .347 Mtetra
.729 .825 .925 r
.56665 .347 .57048 .35083 .57779 .34699 .57398 .34312 Mtetra
.733 .825 .922 r
.57398 .34312 .57779 .34699 .58512 .34304 .58133 .33913 Mtetra
.738 .825 .919 r
.58133 .33913 .58512 .34304 .59246 .33901 .58868 .33505 Mtetra
.742 .824 .915 r
.58868 .33505 .59246 .33901 .59981 .33487 .59605 .33086 Mtetra
.747 .824 .912 r
.59605 .33086 .59981 .33487 .60717 .33062 .60342 .32657 Mtetra
.751 .823 .908 r
.60342 .32657 .60717 .33062 .61453 .32627 .6108 .32217 Mtetra
.756 .822 .904 r
.6108 .32217 .61453 .32627 .62191 .32181 .61819 .31765 Mtetra
.76 .821 .9 r
.61819 .31765 .62191 .32181 .62929 .31723 .62559 .31302 Mtetra
.764 .82 .896 r
.62559 .31302 .62929 .31723 .63668 .31253 .63299 .30826 Mtetra
.769 .819 .892 r
.63299 .30826 .63668 .31253 .64407 .30771 .6404 .30338 Mtetra
.773 .818 .888 r
.6404 .30338 .64407 .30771 .65147 .30276 .64781 .29836 Mtetra
.778 .816 .883 r
.64781 .29836 .65147 .30276 .65887 .29768 .65523 .29321 Mtetra
.782 .815 .878 r
.65523 .29321 .65887 .29768 .66627 .29246 .66264 .28792 Mtetra
.787 .813 .874 r
.66264 .28792 .66627 .29246 .67367 .2871 .67006 .28249 Mtetra
.791 .811 .869 r
.67006 .28249 .67367 .2871 .68107 .28158 .67747 .2769 Mtetra
.795 .81 .863 r
.67747 .2769 .68107 .28158 .68847 .27591 .68489 .27115 Mtetra
.8 .808 .858 r
.68489 .27115 .68847 .27591 .69586 .27008 .69229 .26524 Mtetra
.804 .806 .853 r
.69229 .26524 .69586 .27008 .70325 .26408 .6997 .25916 Mtetra
.808 .804 .847 r
.6997 .25916 .70325 .26408 .71063 .25791 .70709 .2529 Mtetra
.812 .802 .842 r
.70709 .2529 .71063 .25791 .71801 .25156 .71448 .24646 Mtetra
.816 .799 .836 r
.71448 .24646 .71801 .25156 .72537 .24502 .72186 .23983 Mtetra
.82 .797 .83 r
.72186 .23983 .72537 .24502 .73273 .23828 .72922 .233 Mtetra
.824 .795 .824 r
.72922 .233 .73273 .23828 .74006 .23135 .73657 .22596 Mtetra
.828 .792 .818 r
.73657 .22596 .74006 .23135 .74738 .2242 .7439 .21871 Mtetra
0 0 .517 r
.08387 .34776 .08791 .35396 .09263 .35989 .08856 .35378 Mtetra
0 0 .55 r
.08856 .35378 .09263 .35989 .09742 .36555 .09334 .35953 Mtetra
0 .024 .581 r
.09334 .35953 .09742 .36555 .10229 .37095 .09818 .36502 Mtetra
0 .06 .612 r
.09818 .36502 .10229 .37095 .10723 .37609 .10311 .37025 Mtetra
0 .095 .642 r
.10311 .37025 .10723 .37609 .11224 .38099 .1081 .37523 Mtetra
0 .13 .67 r
.1081 .37523 .11224 .38099 .11733 .38564 .11317 .37997 Mtetra
0 .164 .697 r
.11317 .37997 .11733 .38564 .12248 .39005 .1183 .38446 Mtetra
0 .198 .723 r
.1183 .38446 .12248 .39005 .12769 .39422 .1235 .38872 Mtetra
0 .23 .746 r
.1235 .38872 .12769 .39422 .13297 .39816 .12876 .39275 Mtetra
0 .262 .769 r
.12876 .39275 .13297 .39816 .13831 .40188 .13409 .39655 Mtetra
0 .292 .789 r
.13409 .39655 .13831 .40188 .14372 .40538 .13948 .40012 Mtetra
0 .322 .809 r
.13948 .40012 .14372 .40538 .14918 .40867 .14493 .40349 Mtetra
0 .35 .826 r
.14493 .40349 .14918 .40867 .1547 .41175 .15044 .40664 Mtetra
.032 .377 .842 r
.15044 .40664 .1547 .41175 .16028 .41462 .156 .40958 Mtetra
.064 .403 .857 r
.156 .40958 .16028 .41462 .16591 .41729 .16162 .41233 Mtetra
.095 .427 .871 r
.16162 .41233 .16591 .41729 .17159 .41977 .1673 .41487 Mtetra
.125 .451 .883 r
.1673 .41487 .17159 .41977 .17733 .42205 .17303 .41723 Mtetra
.153 .473 .894 r
.17303 .41723 .17733 .42205 .18311 .42415 .17881 .4194 Mtetra
.18 .494 .904 r
.17881 .4194 .18311 .42415 .18895 .42607 .18464 .42138 Mtetra
.206 .513 .913 r
.18464 .42138 .18895 .42607 .19483 .42782 .19051 .42319 Mtetra
.231 .532 .921 r
.19051 .42319 .19483 .42782 .20076 .42939 .19644 .42482 Mtetra
.255 .55 .928 r
.19644 .42482 .20076 .42939 .20674 .43079 .20241 .42629 Mtetra
.277 .566 .935 r
.20241 .42629 .20674 .43079 .21276 .43204 .20843 .42759 Mtetra
.298 .582 .94 r
.20843 .42759 .21276 .43204 .21882 .43312 .21449 .42873 Mtetra
.318 .597 .945 r
.21449 .42873 .21882 .43312 .22493 .43405 .22059 .42972 Mtetra
.338 .611 .95 r
.22059 .42972 .22493 .43405 .23107 .43483 .22673 .43055 Mtetra
.356 .624 .954 r
.22673 .43055 .23107 .43483 .23726 .43547 .23292 .43124 Mtetra
.373 .637 .957 r
.23292 .43124 .23726 .43547 .24348 .43596 .23914 .43178 Mtetra
.39 .648 .96 r
.23914 .43178 .24348 .43596 .24974 .43631 .2454 .43218 Mtetra
.405 .659 .963 r
.2454 .43218 .24974 .43631 .25604 .43653 .2517 .43245 Mtetra
.42 .67 .965 r
.2517 .43245 .25604 .43653 .26237 .43662 .25803 .43258 Mtetra
.434 .68 .967 r
.25803 .43258 .26237 .43662 .26874 .43658 .26441 .43259 Mtetra
.448 .689 .968 r
.26441 .43259 .26874 .43658 .27514 .43642 .27081 .43247 Mtetra
.46 .698 .97 r
.27081 .43247 .27514 .43642 .28158 .43614 .27725 .43223 Mtetra
.472 .706 .971 r
.27725 .43223 .28158 .43614 .28804 .43575 .28372 .43187 Mtetra
.484 .714 .972 r
.28372 .43187 .28804 .43575 .29454 .43524 .29023 .4314 Mtetra
.495 .721 .972 r
.29023 .4314 .29454 .43524 .30107 .43461 .29676 .43081 Mtetra
.505 .728 .973 r
.29676 .43081 .30107 .43461 .30763 .43389 .30333 .43011 Mtetra
.515 .735 .973 r
.30333 .43011 .30763 .43389 .31422 .43305 .30992 .42931 Mtetra
.525 .741 .974 r
.30992 .42931 .31422 .43305 .32084 .43212 .31655 .4284 Mtetra
.534 .747 .974 r
.31655 .4284 .32084 .43212 .32749 .43108 .3232 .4274 Mtetra
.543 .752 .974 r
.3232 .4274 .32749 .43108 .33416 .42995 .32988 .42629 Mtetra
.551 .758 .973 r
.32988 .42629 .33416 .42995 .34086 .42872 .33659 .42509 Mtetra
.559 .763 .973 r
.33659 .42509 .34086 .42872 .34759 .42741 .34333 .42379 Mtetra
.567 .767 .973 r
.34333 .42379 .34759 .42741 .35434 .426 .35009 .4224 Mtetra
.574 .772 .972 r
.35009 .4224 .35434 .426 .36112 .4245 .35687 .42092 Mtetra
.581 .776 .972 r
.35687 .42092 .36112 .4245 .36792 .42292 .36369 .41936 Mtetra
.588 .78 .971 r
.36369 .41936 .36792 .42292 .37475 .42125 .37052 .41771 Mtetra
.595 .784 .971 r
.37052 .41771 .37475 .42125 .3816 .4195 .37738 .41597 Mtetra
.601 .787 .97 r
.37738 .41597 .3816 .4195 .38847 .41767 .38427 .41415 Mtetra
.607 .791 .969 r
.38427 .41415 .38847 .41767 .39537 .41576 .39117 .41225 Mtetra
.613 .794 .968 r
.39117 .41225 .39537 .41576 .40228 .41377 .3981 .41027 Mtetra
.619 .797 .967 r
.3981 .41027 .40228 .41377 .40922 .41171 .40506 .4082 Mtetra
.625 .799 .966 r
.40506 .4082 .40922 .41171 .41619 .40956 .41203 .40606 Mtetra
.63 .802 .965 r
.41203 .40606 .41619 .40956 .42317 .40735 .41903 .40385 Mtetra
.636 .804 .964 r
.41903 .40385 .42317 .40735 .43017 .40505 .42604 .40155 Mtetra
.641 .807 .963 r
.42604 .40155 .43017 .40505 .43719 .40268 .43308 .39918 Mtetra
.646 .809 .961 r
.43308 .39918 .43719 .40268 .44424 .40024 .44014 .39673 Mtetra
.651 .811 .96 r
.44014 .39673 .44424 .40024 .4513 .39772 .44721 .39421 Mtetra
.656 .812 .959 r
.44721 .39421 .4513 .39772 .45838 .39513 .45431 .39161 Mtetra
.661 .814 .957 r
.45431 .39161 .45838 .39513 .46549 .39247 .46142 .38894 Mtetra
.666 .816 .955 r
.46142 .38894 .46549 .39247 .4726 .38973 .46856 .38619 Mtetra
.67 .817 .954 r
.46856 .38619 .4726 .38973 .47974 .38692 .47571 .38336 Mtetra
.675 .818 .952 r
.47571 .38336 .47974 .38692 .4869 .38403 .48288 .38045 Mtetra
.68 .819 .95 r
.48288 .38045 .4869 .38403 .49407 .38106 .49007 .37747 Mtetra
.685 .82 .948 r
.49007 .37747 .49407 .38106 .50126 .37802 .49727 .37441 Mtetra
.689 .821 .946 r
.49727 .37441 .50126 .37802 .50846 .37491 .50449 .37127 Mtetra
.694 .822 .944 r
.50449 .37127 .50846 .37491 .51569 .37171 .51173 .36805 Mtetra
.698 .823 .942 r
.51173 .36805 .51569 .37171 .52292 .36843 .51898 .36475 Mtetra
.703 .823 .939 r
.51898 .36475 .52292 .36843 .53018 .36508 .52625 .36136 Mtetra
.707 .823 .937 r
.52625 .36136 .53018 .36508 .53744 .36164 .53353 .35789 Mtetra
.712 .824 .934 r
.53353 .35789 .53744 .36164 .54473 .35811 .54083 .35433 Mtetra
.716 .824 .932 r
.54083 .35433 .54473 .35811 .55202 .3545 .54814 .35069 Mtetra
.721 .824 .929 r
.54814 .35069 .55202 .3545 .55933 .3508 .55547 .34695 Mtetra
.725 .824 .926 r
.55547 .34695 .55933 .3508 .56665 .347 .5628 .34312 Mtetra
.73 .824 .923 r
.5628 .34312 .56665 .347 .57398 .34312 .57015 .33919 Mtetra
.734 .823 .92 r
.57015 .33919 .57398 .34312 .58133 .33913 .57751 .33516 Mtetra
.739 .823 .916 r
.57751 .33516 .58133 .33913 .58868 .33505 .58488 .33103 Mtetra
.743 .822 .913 r
.58488 .33103 .58868 .33505 .59605 .33086 .59226 .32679 Mtetra
.748 .822 .909 r
.59226 .32679 .59605 .33086 .60342 .32657 .59965 .32245 Mtetra
.752 .821 .906 r
.59965 .32245 .60342 .32657 .6108 .32217 .60705 .31799 Mtetra
.757 .82 .902 r
.60705 .31799 .6108 .32217 .61819 .31765 .61446 .31342 Mtetra
.761 .819 .898 r
.61446 .31342 .61819 .31765 .62559 .31302 .62187 .30873 Mtetra
.766 .818 .894 r
.62187 .30873 .62559 .31302 .63299 .30826 .62929 .30391 Mtetra
.77 .816 .889 r
.62929 .30391 .63299 .30826 .6404 .30338 .63671 .29896 Mtetra
.775 .815 .885 r
.63671 .29896 .6404 .30338 .64781 .29836 .64414 .29388 Mtetra
.779 .814 .88 r
.64414 .29388 .64781 .29836 .65523 .29321 .65156 .28866 Mtetra
.783 .812 .875 r
.65156 .28866 .65523 .29321 .66264 .28792 .659 .2833 Mtetra
.788 .81 .871 r
.659 .2833 .66264 .28792 .67006 .28249 .66643 .27779 Mtetra
.792 .809 .866 r
.66643 .27779 .67006 .28249 .67747 .2769 .67386 .27212 Mtetra
.796 .807 .86 r
.67386 .27212 .67747 .2769 .68489 .27115 .68128 .2663 Mtetra
.801 .805 .855 r
.68128 .2663 .68489 .27115 .69229 .26524 .6887 .2603 Mtetra
.805 .803 .85 r
.6887 .2603 .69229 .26524 .6997 .25916 .69612 .25414 Mtetra
.809 .801 .844 r
.69612 .25414 .6997 .25916 .70709 .2529 .70353 .24779 Mtetra
.813 .799 .838 r
.70353 .24779 .70709 .2529 .71448 .24646 .71093 .24126 Mtetra
.817 .796 .832 r
.71093 .24126 .71448 .24646 .72186 .23983 .71832 .23453 Mtetra
.821 .794 .826 r
.71832 .23453 .72186 .23983 .72922 .233 .7257 .2276 Mtetra
.825 .791 .82 r
.7257 .2276 .72922 .233 .73657 .22596 .73306 .22047 Mtetra
.829 .789 .814 r
.73306 .22047 .73657 .22596 .7439 .21871 .7404 .21312 Mtetra
0 0 .512 r
.07984 .34142 .08387 .34776 .08856 .35378 .08451 .34753 Mtetra
0 0 .545 r
.08451 .34753 .08856 .35378 .09334 .35953 .08926 .35337 Mtetra
0 .017 .577 r
.08926 .35337 .09334 .35953 .09818 .36502 .09408 .35895 Mtetra
0 .052 .607 r
.09408 .35895 .09818 .36502 .10311 .37025 .09898 .36428 Mtetra
0 .087 .637 r
.09898 .36428 .10311 .37025 .1081 .37523 .10396 .36935 Mtetra
0 .121 .665 r
.10396 .36935 .1081 .37523 .11317 .37997 .109 .37417 Mtetra
0 .155 .692 r
.109 .37417 .11317 .37997 .1183 .38446 .11412 .37875 Mtetra
0 .189 .717 r
.11412 .37875 .1183 .38446 .1235 .38872 .1193 .38309 Mtetra
0 .221 .741 r
.1193 .38309 .1235 .38872 .12876 .39275 .12455 .3872 Mtetra
0 .253 .763 r
.12455 .3872 .12876 .39275 .13409 .39655 .12986 .39109 Mtetra
0 .283 .784 r
.12986 .39109 .13409 .39655 .13948 .40012 .13524 .39475 Mtetra
0 .313 .803 r
.13524 .39475 .13948 .40012 .14493 .40349 .14067 .39819 Mtetra
0 .341 .821 r
.14067 .39819 .14493 .40349 .15044 .40664 .14617 .40142 Mtetra
.027 .368 .837 r
.14617 .40142 .15044 .40664 .156 .40958 .15172 .40444 Mtetra
.059 .394 .852 r
.15172 .40444 .156 .40958 .16162 .41233 .15734 .40725 Mtetra
.09 .418 .866 r
.15734 .40725 .16162 .41233 .1673 .41487 .163 .40987 Mtetra
.119 .442 .878 r
.163 .40987 .1673 .41487 .17303 .41723 .16872 .4123 Mtetra
.148 .464 .89 r
.16872 .4123 .17303 .41723 .17881 .4194 .17449 .41454 Mtetra
.175 .485 .9 r
.17449 .41454 .17881 .4194 .18464 .42138 .18031 .41659 Mtetra
.201 .505 .909 r
.18031 .41659 .18464 .42138 .19051 .42319 .18618 .41846 Mtetra
.226 .524 .917 r
.18618 .41846 .19051 .42319 .19644 .42482 .1921 .42016 Mtetra
.249 .542 .925 r
.1921 .42016 .19644 .42482 .20241 .42629 .19807 .42169 Mtetra
.272 .559 .931 r
.19807 .42169 .20241 .42629 .20843 .42759 .20408 .42305 Mtetra
.293 .575 .937 r
.20408 .42305 .20843 .42759 .21449 .42873 .21014 .42425 Mtetra
.313 .59 .942 r
.21014 .42425 .21449 .42873 .22059 .42972 .21624 .4253 Mtetra
.333 .604 .947 r
.21624 .4253 .22059 .42972 .22673 .43055 .22238 .42619 Mtetra
.351 .618 .951 r
.22238 .42619 .22673 .43055 .23292 .43124 .22856 .42693 Mtetra
.369 .63 .955 r
.22856 .42693 .23292 .43124 .23914 .43178 .23479 .42752 Mtetra
.385 .642 .958 r
.23479 .42752 .23914 .43178 .2454 .43218 .24105 .42797 Mtetra
.401 .653 .96 r
.24105 .42797 .2454 .43218 .2517 .43245 .24735 .42829 Mtetra
.416 .664 .963 r
.24735 .42829 .2517 .43245 .25803 .43258 .25368 .42847 Mtetra
.43 .674 .965 r
.25368 .42847 .25803 .43258 .26441 .43259 .26006 .42852 Mtetra
.444 .684 .967 r
.26006 .42852 .26441 .43259 .27081 .43247 .26646 .42844 Mtetra
.457 .693 .968 r
.26646 .42844 .27081 .43247 .27725 .43223 .27291 .42824 Mtetra
.469 .701 .969 r
.27291 .42824 .27725 .43223 .28372 .43187 .27938 .42792 Mtetra
.481 .709 .97 r
.27938 .42792 .28372 .43187 .29023 .4314 .28589 .42748 Mtetra
.492 .717 .971 r
.28589 .42748 .29023 .4314 .29676 .43081 .29243 .42693 Mtetra
.503 .724 .972 r
.29243 .42693 .29676 .43081 .30333 .43011 .299 .42627 Mtetra
.513 .731 .972 r
.299 .42627 .30333 .43011 .30992 .42931 .3056 .4255 Mtetra
.522 .737 .972 r
.3056 .4255 .30992 .42931 .31655 .4284 .31224 .42462 Mtetra
.532 .743 .972 r
.31224 .42462 .31655 .4284 .3232 .4274 .3189 .42364 Mtetra
.541 .749 .972 r
.3189 .42364 .3232 .4274 .32988 .42629 .32558 .42256 Mtetra
.549 .754 .972 r
.32558 .42256 .32988 .42629 .33659 .42509 .3323 .42138 Mtetra
.557 .759 .972 r
.3323 .42138 .33659 .42509 .34333 .42379 .33904 .42011 Mtetra
.565 .764 .972 r
.33904 .42011 .34333 .42379 .35009 .4224 .34582 .41874 Mtetra
.572 .769 .971 r
.34582 .41874 .35009 .4224 .35687 .42092 .35261 .41728 Mtetra
.58 .773 .971 r
.35261 .41728 .35687 .42092 .36369 .41936 .35943 .41573 Mtetra
.587 .777 .97 r
.35943 .41573 .36369 .41936 .37052 .41771 .36628 .4141 Mtetra
.593 .781 .97 r
.36628 .4141 .37052 .41771 .37738 .41597 .37315 .41237 Mtetra
.6 .784 .969 r
.37315 .41237 .37738 .41597 .38427 .41415 .38005 .41057 Mtetra
.606 .788 .968 r
.38005 .41057 .38427 .41415 .39117 .41225 .38696 .40867 Mtetra
.612 .791 .967 r
.38696 .40867 .39117 .41225 .3981 .41027 .39391 .4067 Mtetra
.618 .794 .966 r
.39391 .4067 .3981 .41027 .40506 .4082 .40087 .40464 Mtetra
.624 .797 .965 r
.40087 .40464 .40506 .4082 .41203 .40606 .40786 .4025 Mtetra
.63 .8 .964 r
.40786 .4025 .41203 .40606 .41903 .40385 .41486 .40029 Mtetra
.635 .802 .963 r
.41486 .40029 .41903 .40385 .42604 .40155 .42189 .39799 Mtetra
.641 .804 .962 r
.42189 .39799 .42604 .40155 .43308 .39918 .42894 .39562 Mtetra
.646 .806 .96 r
.42894 .39562 .43308 .39918 .44014 .39673 .43601 .39317 Mtetra
.651 .808 .959 r
.43601 .39317 .44014 .39673 .44721 .39421 .4431 .39064 Mtetra
.656 .81 .957 r
.4431 .39064 .44721 .39421 .45431 .39161 .45021 .38803 Mtetra
.661 .812 .956 r
.45021 .38803 .45431 .39161 .46142 .38894 .45734 .38535 Mtetra
.666 .814 .954 r
.45734 .38535 .46142 .38894 .46856 .38619 .46449 .38258 Mtetra
.671 .815 .952 r
.46449 .38258 .46856 .38619 .47571 .38336 .47166 .37974 Mtetra
.676 .816 .951 r
.47166 .37974 .47571 .38336 .48288 .38045 .47884 .37682 Mtetra
.681 .817 .949 r
.47884 .37682 .48288 .38045 .49007 .37747 .48604 .37382 Mtetra
.685 .818 .947 r
.48604 .37382 .49007 .37747 .49727 .37441 .49326 .37074 Mtetra
.69 .819 .945 r
.49326 .37074 .49727 .37441 .50449 .37127 .5005 .36758 Mtetra
.695 .82 .942 r
.5005 .36758 .50449 .37127 .51173 .36805 .50775 .36433 Mtetra
.699 .821 .94 r
.50775 .36433 .51173 .36805 .51898 .36475 .51502 .361 Mtetra
.704 .821 .938 r
.51502 .361 .51898 .36475 .52625 .36136 .5223 .35759 Mtetra
.708 .821 .935 r
.5223 .35759 .52625 .36136 .53353 .35789 .5296 .35408 Mtetra
.713 .822 .932 r
.5296 .35408 .53353 .35789 .54083 .35433 .53691 .35049 Mtetra
.718 .822 .93 r
.53691 .35049 .54083 .35433 .54814 .35069 .54424 .34681 Mtetra
.722 .822 .927 r
.54424 .34681 .54814 .35069 .55547 .34695 .55158 .34303 Mtetra
.727 .822 .924 r
.55158 .34303 .55547 .34695 .5628 .34312 .55893 .33916 Mtetra
.731 .821 .921 r
.55893 .33916 .5628 .34312 .57015 .33919 .5663 .33519 Mtetra
.736 .821 .917 r
.5663 .33519 .57015 .33919 .57751 .33516 .57367 .33111 Mtetra
.74 .82 .914 r
.57367 .33111 .57751 .33516 .58488 .33103 .58106 .32693 Mtetra
.745 .82 .911 r
.58106 .32693 .58488 .33103 .59226 .32679 .58846 .32265 Mtetra
.749 .819 .907 r
.58846 .32265 .59226 .32679 .59965 .32245 .59586 .31825 Mtetra
.754 .818 .903 r
.59586 .31825 .59965 .32245 .60705 .31799 .60328 .31374 Mtetra
.758 .817 .899 r
.60328 .31374 .60705 .31799 .61446 .31342 .6107 .30911 Mtetra
.763 .816 .895 r
.6107 .30911 .61446 .31342 .62187 .30873 .61813 .30436 Mtetra
.767 .815 .891 r
.61813 .30436 .62187 .30873 .62929 .30391 .62556 .29948 Mtetra
.771 .814 .886 r
.62556 .29948 .62929 .30391 .63671 .29896 .633 .29446 Mtetra
.776 .812 .882 r
.633 .29446 .63671 .29896 .64414 .29388 .64044 .28932 Mtetra
.78 .811 .877 r
.64044 .28932 .64414 .29388 .65156 .28866 .64788 .28403 Mtetra
.785 .809 .872 r
.64788 .28403 .65156 .28866 .659 .2833 .65533 .27859 Mtetra
.789 .808 .867 r
.65533 .27859 .659 .2833 .66643 .27779 .66277 .273 Mtetra
.793 .806 .862 r
.66277 .273 .66643 .27779 .67386 .27212 .67022 .26726 Mtetra
.797 .804 .857 r
.67022 .26726 .67386 .27212 .68128 .2663 .67766 .26135 Mtetra
.802 .802 .852 r
.67766 .26135 .68128 .2663 .6887 .2603 .68509 .25527 Mtetra
.806 .8 .846 r
.68509 .25527 .6887 .2603 .69612 .25414 .69252 .24901 Mtetra
.81 .798 .84 r
.69252 .24901 .69612 .25414 .70353 .24779 .69995 .24257 Mtetra
.814 .795 .835 r
.69995 .24257 .70353 .24779 .71093 .24126 .70736 .23595 Mtetra
.818 .793 .829 r
.70736 .23595 .71093 .24126 .71832 .23453 .71476 .22912 Mtetra
.822 .791 .823 r
.71476 .22912 .71832 .23453 .7257 .2276 .72215 .2221 Mtetra
.826 .788 .817 r
.72215 .2221 .7257 .2276 .73306 .22047 .72952 .21486 Mtetra
.829 .785 .81 r
.72952 .21486 .73306 .22047 .7404 .21312 .73687 .2074 Mtetra
0 0 .508 r
.07581 .33492 .07984 .34142 .08451 .34753 .08046 .34113 Mtetra
0 0 .54 r
.08046 .34113 .08451 .34753 .08926 .35337 .08518 .34707 Mtetra
0 .009 .572 r
.08518 .34707 .08926 .35337 .09408 .35895 .08999 .35275 Mtetra
0 .044 .602 r
.08999 .35275 .09408 .35895 .09898 .36428 .09487 .35816 Mtetra
0 .079 .631 r
.09487 .35816 .09898 .36428 .10396 .36935 .09982 .36333 Mtetra
0 .113 .659 r
.09982 .36333 .10396 .36935 .109 .37417 .10485 .36824 Mtetra
0 .147 .686 r
.10485 .36824 .109 .37417 .11412 .37875 .10994 .37291 Mtetra
0 .18 .711 r
.10994 .37291 .11412 .37875 .1193 .38309 .11511 .37734 Mtetra
0 .212 .735 r
.11511 .37734 .1193 .38309 .12455 .3872 .12034 .38153 Mtetra
0 .244 .757 r
.12034 .38153 .12455 .3872 .12986 .39109 .12563 .3855 Mtetra
0 .274 .778 r
.12563 .3855 .12986 .39109 .13524 .39475 .131 .38924 Mtetra
0 .303 .797 r
.131 .38924 .13524 .39475 .14067 .39819 .13642 .39277 Mtetra
0 .332 .815 r
.13642 .39277 .14067 .39819 .14617 .40142 .1419 .39608 Mtetra
.021 .359 .832 r
.1419 .39608 .14617 .40142 .15172 .40444 .14744 .39917 Mtetra
.053 .385 .847 r
.14744 .39917 .15172 .40444 .15734 .40725 .15304 .40207 Mtetra
.084 .41 .861 r
.15304 .40207 .15734 .40725 .163 .40987 .1587 .40476 Mtetra
.114 .433 .874 r
.1587 .40476 .163 .40987 .16872 .4123 .16441 .40726 Mtetra
.142 .456 .885 r
.16441 .40726 .16872 .4123 .17449 .41454 .17017 .40957 Mtetra
.169 .477 .895 r
.17017 .40957 .17449 .41454 .18031 .41659 .17598 .41169 Mtetra
.195 .497 .905 r
.17598 .41169 .18031 .41659 .18618 .41846 .18185 .41364 Mtetra
.22 .516 .913 r
.18185 .41364 .18618 .41846 .1921 .42016 .18776 .4154 Mtetra
.244 .534 .921 r
.18776 .4154 .1921 .42016 .19807 .42169 .19372 .41699 Mtetra
.266 .551 .928 r
.19372 .41699 .19807 .42169 .20408 .42305 .19973 .41842 Mtetra
.288 .567 .934 r
.19973 .41842 .20408 .42305 .21014 .42425 .20578 .41968 Mtetra
.309 .583 .939 r
.20578 .41968 .21014 .42425 .21624 .4253 .21188 .42078 Mtetra
.328 .597 .944 r
.21188 .42078 .21624 .4253 .22238 .42619 .21802 .42173 Mtetra
.347 .611 .948 r
.21802 .42173 .22238 .42619 .22856 .42693 .2242 .42252 Mtetra
.364 .624 .952 r
.2242 .42252 .22856 .42693 .23479 .42752 .23042 .42317 Mtetra
.381 .636 .955 r
.23042 .42317 .23479 .42752 .24105 .42797 .23668 .42367 Mtetra
.397 .647 .958 r
.23668 .42367 .24105 .42797 .24735 .42829 .24298 .42404 Mtetra
.412 .658 .961 r
.24298 .42404 .24735 .42829 .25368 .42847 .24932 .42427 Mtetra
.427 .668 .963 r
.24932 .42427 .25368 .42847 .26006 .42852 .25569 .42436 Mtetra
.44 .678 .965 r
.25569 .42436 .26006 .42852 .26646 .42844 .2621 .42433 Mtetra
.453 .687 .966 r
.2621 .42433 .26646 .42844 .27291 .42824 .26855 .42417 Mtetra
.466 .696 .967 r
.26855 .42417 .27291 .42824 .27938 .42792 .27503 .42389 Mtetra
.478 .704 .968 r
.27503 .42389 .27938 .42792 .28589 .42748 .28154 .42349 Mtetra
.489 .712 .969 r
.28154 .42349 .28589 .42748 .29243 .42693 .28808 .42298 Mtetra
.5 .719 .97 r
.28808 .42298 .29243 .42693 .299 .42627 .29466 .42235 Mtetra
.51 .726 .971 r
.29466 .42235 .299 .42627 .3056 .4255 .30127 .42161 Mtetra
.52 .733 .971 r
.30127 .42161 .3056 .4255 .31224 .42462 .30791 .42077 Mtetra
.529 .739 .971 r
.30791 .42077 .31224 .42462 .3189 .42364 .31457 .41982 Mtetra
.538 .745 .971 r
.31457 .41982 .3189 .42364 .32558 .42256 .32127 .41876 Mtetra
.547 .75 .971 r
.32127 .41876 .32558 .42256 .3323 .42138 .32799 .41761 Mtetra
.555 .755 .971 r
.32799 .41761 .3323 .42138 .33904 .42011 .33474 .41636 Mtetra
.563 .76 .971 r
.33474 .41636 .33904 .42011 .34582 .41874 .34152 .41502 Mtetra
.571 .765 .97 r
.34152 .41502 .34582 .41874 .35261 .41728 .34833 .41358 Mtetra
.578 .77 .97 r
.34833 .41358 .35261 .41728 .35943 .41573 .35516 .41204 Mtetra
.585 .774 .969 r
.35516 .41204 .35943 .41573 .36628 .4141 .36202 .41042 Mtetra
.592 .778 .968 r
.36202 .41042 .36628 .4141 .37315 .41237 .3689 .40871 Mtetra
.599 .781 .968 r
.3689 .40871 .37315 .41237 .38005 .41057 .3758 .40691 Mtetra
.605 .785 .967 r
.3758 .40691 .38005 .41057 .38696 .40867 .38273 .40503 Mtetra
.612 .788 .966 r
.38273 .40503 .38696 .40867 .39391 .4067 .38969 .40306 Mtetra
.618 .791 .965 r
.38969 .40306 .39391 .4067 .40087 .40464 .39666 .40101 Mtetra
.624 .794 .964 r
.39666 .40101 .40087 .40464 .40786 .4025 .40366 .39888 Mtetra
.629 .797 .963 r
.40366 .39888 .40786 .4025 .41486 .40029 .41068 .39667 Mtetra
.635 .799 .962 r
.41068 .39667 .41486 .40029 .42189 .39799 .41772 .39437 Mtetra
.64 .802 .96 r
.41772 .39437 .42189 .39799 .42894 .39562 .42479 .392 Mtetra
.646 .804 .959 r
.42479 .392 .42894 .39562 .43601 .39317 .43187 .38954 Mtetra
.651 .806 .957 r
.43187 .38954 .43601 .39317 .4431 .39064 .43897 .387 Mtetra
.656 .808 .956 r
.43897 .387 .4431 .39064 .45021 .38803 .4461 .38439 Mtetra
.661 .81 .954 r
.4461 .38439 .45021 .38803 .45734 .38535 .45324 .38169 Mtetra
.666 .811 .953 r
.45324 .38169 .45734 .38535 .46449 .38258 .4604 .37892 Mtetra
.671 .813 .951 r
.4604 .37892 .46449 .38258 .47166 .37974 .46758 .37606 Mtetra
.676 .814 .949 r
.46758 .37606 .47166 .37974 .47884 .37682 .47478 .37312 Mtetra
.681 .815 .947 r
.47478 .37312 .47884 .37682 .48604 .37382 .482 .3701 Mtetra
.686 .816 .945 r
.482 .3701 .48604 .37382 .49326 .37074 .48923 .367 Mtetra
.691 .817 .943 r
.48923 .367 .49326 .37074 .5005 .36758 .49649 .36381 Mtetra
.695 .818 .941 r
.49649 .36381 .5005 .36758 .50775 .36433 .50375 .36054 Mtetra
.7 .818 .938 r
.50375 .36054 .50775 .36433 .51502 .361 .51104 .35718 Mtetra
.705 .819 .936 r
.51104 .35718 .51502 .361 .5223 .35759 .51834 .35374 Mtetra
.709 .819 .933 r
.51834 .35374 .5223 .35759 .5296 .35408 .52565 .3502 Mtetra
.714 .819 .93 r
.52565 .3502 .5296 .35408 .53691 .35049 .53298 .34658 Mtetra
.719 .819 .928 r
.53298 .34658 .53691 .35049 .54424 .34681 .54032 .34286 Mtetra
.723 .819 .925 r
.54032 .34286 .54424 .34681 .55158 .34303 .54768 .33904 Mtetra
.728 .819 .922 r
.54768 .33904 .55158 .34303 .55893 .33916 .55504 .33512 Mtetra
.732 .819 .918 r
.55504 .33512 .55893 .33916 .5663 .33519 .56242 .33111 Mtetra
.737 .818 .915 r
.56242 .33111 .5663 .33519 .57367 .33111 .56982 .32699 Mtetra
.741 .818 .912 r
.56982 .32699 .57367 .33111 .58106 .32693 .57722 .32276 Mtetra
.746 .817 .908 r
.57722 .32276 .58106 .32693 .58846 .32265 .58463 .31842 Mtetra
.75 .817 .904 r
.58463 .31842 .58846 .32265 .59586 .31825 .59205 .31397 Mtetra
.755 .816 .9 r
.59205 .31397 .59586 .31825 .60328 .31374 .59948 .3094 Mtetra
.759 .815 .896 r
.59948 .3094 .60328 .31374 .6107 .30911 .60692 .30471 Mtetra
.764 .813 .892 r
.60692 .30471 .6107 .30911 .61813 .30436 .61436 .2999 Mtetra
.768 .812 .888 r
.61436 .2999 .61813 .30436 .62556 .29948 .62181 .29495 Mtetra
.773 .811 .883 r
.62181 .29495 .62556 .29948 .633 .29446 .62926 .28987 Mtetra
.777 .809 .879 r
.62926 .28987 .633 .29446 .64044 .28932 .63672 .28465 Mtetra
.781 .808 .874 r
.63672 .28465 .64044 .28932 .64788 .28403 .64418 .27929 Mtetra
.786 .806 .869 r
.64418 .27929 .64788 .28403 .65533 .27859 .65164 .27378 Mtetra
.79 .804 .864 r
.65164 .27378 .65533 .27859 .66277 .273 .6591 .26811 Mtetra
.794 .803 .859 r
.6591 .26811 .66277 .273 .67022 .26726 .66656 .26228 Mtetra
.798 .801 .854 r
.66656 .26228 .67022 .26726 .67766 .26135 .67401 .25629 Mtetra
.802 .799 .848 r
.67401 .25629 .67766 .26135 .68509 .25527 .68146 .25012 Mtetra
.806 .796 .843 r
.68146 .25012 .68509 .25527 .69252 .24901 .6889 .24378 Mtetra
.81 .794 .837 r
.6889 .24378 .69252 .24901 .69995 .24257 .69634 .23724 Mtetra
.814 .792 .831 r
.69634 .23724 .69995 .24257 .70736 .23595 .70376 .23052 Mtetra
.818 .789 .825 r
.70376 .23052 .70736 .23595 .71476 .22912 .71118 .2236 Mtetra
.822 .787 .819 r
.71118 .2236 .71476 .22912 .72215 .2221 .71858 .21647 Mtetra
.826 .784 .813 r
.71858 .21647 .72215 .2221 .72952 .21486 .72596 .20912 Mtetra
.83 .782 .807 r
.72596 .20912 .72952 .21486 .73687 .2074 .73333 .20155 Mtetra
0 0 .504 r
.0718 .32827 .07581 .33492 .08046 .34113 .07642 .33458 Mtetra
0 0 .536 r
.07642 .33458 .08046 .34113 .08518 .34707 .08112 .34062 Mtetra
0 .001 .567 r
.08112 .34062 .08518 .34707 .08999 .35275 .0859 .34639 Mtetra
0 .036 .597 r
.0859 .34639 .08999 .35275 .09487 .35816 .09075 .3519 Mtetra
0 .07 .626 r
.09075 .3519 .09487 .35816 .09982 .36333 .09569 .35716 Mtetra
0 .104 .654 r
.09569 .35716 .09982 .36333 .10485 .36824 .10069 .36217 Mtetra
0 .138 .68 r
.10069 .36217 .10485 .36824 .10994 .37291 .10577 .36693 Mtetra
0 .171 .705 r
.10577 .36693 .10994 .37291 .11511 .37734 .11091 .37145 Mtetra
0 .203 .729 r
.11091 .37145 .11511 .37734 .12034 .38153 .11613 .37573 Mtetra
0 .234 .751 r
.11613 .37573 .12034 .38153 .12563 .3855 .12141 .37978 Mtetra
0 .265 .772 r
.12141 .37978 .12563 .3855 .131 .38924 .12675 .38361 Mtetra
0 .294 .792 r
.12675 .38361 .131 .38924 .13642 .39277 .13216 .38722 Mtetra
0 .322 .81 r
.13216 .38722 .13642 .39277 .1419 .39608 .13763 .39061 Mtetra
.016 .349 .826 r
.13763 .39061 .1419 .39608 .14744 .39917 .14316 .39379 Mtetra
.048 .376 .842 r
.14316 .39379 .14744 .39917 .15304 .40207 .14874 .39676 Mtetra
.079 .4 .856 r
.14874 .39676 .15304 .40207 .1587 .40476 .15439 .39953 Mtetra
.108 .424 .868 r
.15439 .39953 .1587 .40476 .16441 .40726 .16009 .40211 Mtetra
.137 .447 .88 r
.16009 .40211 .16441 .40726 .17017 .40957 .16584 .40449 Mtetra
.164 .468 .891 r
.16584 .40449 .17017 .40957 .17598 .41169 .17164 .40668 Mtetra
.19 .488 .9 r
.17164 .40668 .17598 .41169 .18185 .41364 .1775 .4087 Mtetra
.215 .508 .909 r
.1775 .4087 .18185 .41364 .18776 .4154 .18341 .41053 Mtetra
.239 .526 .917 r
.18341 .41053 .18776 .4154 .19372 .41699 .18936 .41219 Mtetra
.261 .543 .924 r
.18936 .41219 .19372 .41699 .19973 .41842 .19536 .41368 Mtetra
.283 .56 .93 r
.19536 .41368 .19973 .41842 .20578 .41968 .20141 .415 Mtetra
.304 .575 .936 r
.20141 .415 .20578 .41968 .21188 .42078 .2075 .41616 Mtetra
.323 .59 .941 r
.2075 .41616 .21188 .42078 .21802 .42173 .21364 .41717 Mtetra
.342 .604 .945 r
.21364 .41717 .21802 .42173 .2242 .42252 .21982 .41802 Mtetra
.36 .617 .949 r
.21982 .41802 .2242 .42252 .23042 .42317 .22604 .41872 Mtetra
.377 .629 .952 r
.22604 .41872 .23042 .42317 .23668 .42367 .2323 .41928 Mtetra
.393 .641 .955 r
.2323 .41928 .23668 .42367 .24298 .42404 .2386 .4197 Mtetra
.408 .652 .958 r
.2386 .4197 .24298 .42404 .24932 .42427 .24494 .41998 Mtetra
.423 .663 .96 r
.24494 .41998 .24932 .42427 .25569 .42436 .25131 .42012 Mtetra
.437 .672 .962 r
.25131 .42012 .25569 .42436 .2621 .42433 .25773 .42013 Mtetra
.45 .682 .964 r
.25773 .42013 .2621 .42433 .26855 .42417 .26417 .42002 Mtetra
.462 .691 .965 r
.26417 .42002 .26855 .42417 .27503 .42389 .27066 .41978 Mtetra
.475 .699 .967 r
.27066 .41978 .27503 .42389 .28154 .42349 .27717 .41942 Mtetra
.486 .707 .967 r
.27717 .41942 .28154 .42349 .28808 .42298 .28372 .41894 Mtetra
.497 .714 .968 r
.28372 .41894 .28808 .42298 .29466 .42235 .2903 .41835 Mtetra
.507 .721 .969 r
.2903 .41835 .29466 .42235 .30127 .42161 .29691 .41765 Mtetra
.517 .728 .969 r
.29691 .41765 .30127 .42161 .30791 .42077 .30356 .41683 Mtetra
.527 .734 .969 r
.30356 .41683 .30791 .42077 .31457 .41982 .31023 .41591 Mtetra
.536 .74 .97 r
.31023 .41591 .31457 .41982 .32127 .41876 .31693 .41489 Mtetra
.545 .746 .97 r
.31693 .41489 .32127 .41876 .32799 .41761 .32367 .41376 Mtetra
.553 .751 .969 r
.32367 .41376 .32799 .41761 .33474 .41636 .33043 .41254 Mtetra
.562 .757 .969 r
.33043 .41254 .33474 .41636 .34152 .41502 .33721 .41121 Mtetra
.569 .761 .969 r
.33721 .41121 .34152 .41502 .34833 .41358 .34403 .40979 Mtetra
.577 .766 .968 r
.34403 .40979 .34833 .41358 .35516 .41204 .35087 .40828 Mtetra
.584 .77 .968 r
.35087 .40828 .35516 .41204 .36202 .41042 .35773 .40667 Mtetra
.591 .774 .967 r
.35773 .40667 .36202 .41042 .3689 .40871 .36463 .40498 Mtetra
.598 .778 .966 r
.36463 .40498 .3689 .40871 .3758 .40691 .37154 .40319 Mtetra
.605 .782 .965 r
.37154 .40319 .3758 .40691 .38273 .40503 .37848 .40132 Mtetra
.611 .785 .965 r
.37848 .40132 .38273 .40503 .38969 .40306 .38545 .39936 Mtetra
.617 .788 .964 r
.38545 .39936 .38969 .40306 .39666 .40101 .39243 .39732 Mtetra
.623 .791 .963 r
.39243 .39732 .39666 .40101 .40366 .39888 .39944 .39519 Mtetra
.629 .794 .961 r
.39944 .39519 .40366 .39888 .41068 .39667 .40648 .39297 Mtetra
.635 .796 .96 r
.40648 .39297 .41068 .39667 .41772 .39437 .41353 .39068 Mtetra
.64 .799 .959 r
.41353 .39068 .41772 .39437 .42479 .392 .42061 .3883 Mtetra
.646 .801 .957 r
.42061 .3883 .42479 .392 .43187 .38954 .4277 .38584 Mtetra
.651 .803 .956 r
.4277 .38584 .43187 .38954 .43897 .387 .43482 .3833 Mtetra
.656 .805 .954 r
.43482 .3833 .43897 .387 .4461 .38439 .44196 .38067 Mtetra
.662 .807 .953 r
.44196 .38067 .4461 .38439 .45324 .38169 .44912 .37797 Mtetra
.667 .808 .951 r
.44912 .37797 .45324 .38169 .4604 .37892 .45629 .37518 Mtetra
.672 .81 .949 r
.45629 .37518 .4604 .37892 .46758 .37606 .46349 .37231 Mtetra
.677 .811 .947 r
.46349 .37231 .46758 .37606 .47478 .37312 .4707 .36935 Mtetra
.682 .812 .945 r
.4707 .36935 .47478 .37312 .482 .3701 .47793 .36631 Mtetra
.687 .813 .943 r
.47793 .36631 .482 .3701 .48923 .367 .48518 .36319 Mtetra
.691 .814 .941 r
.48518 .36319 .48923 .367 .49649 .36381 .49245 .35998 Mtetra
.696 .815 .939 r
.49245 .35998 .49649 .36381 .50375 .36054 .49973 .35668 Mtetra
.701 .816 .936 r
.49973 .35668 .50375 .36054 .51104 .35718 .50703 .35329 Mtetra
.706 .816 .934 r
.50703 .35329 .51104 .35718 .51834 .35374 .51435 .34982 Mtetra
.71 .816 .931 r
.51435 .34982 .51834 .35374 .52565 .3502 .52168 .34625 Mtetra
.715 .817 .928 r
.52168 .34625 .52565 .3502 .53298 .34658 .52902 .34258 Mtetra
.72 .817 .925 r
.52902 .34258 .53298 .34658 .54032 .34286 .53638 .33883 Mtetra
.724 .817 .922 r
.53638 .33883 .54032 .34286 .54768 .33904 .54375 .33497 Mtetra
.729 .816 .919 r
.54375 .33497 .54768 .33904 .55504 .33512 .55113 .33101 Mtetra
.734 .816 .916 r
.55113 .33101 .55504 .33512 .56242 .33111 .55853 .32695 Mtetra
.738 .816 .912 r
.55853 .32695 .56242 .33111 .56982 .32699 .56594 .32278 Mtetra
.743 .815 .909 r
.56594 .32278 .56982 .32699 .57722 .32276 .57335 .3185 Mtetra
.747 .814 .905 r
.57335 .3185 .57722 .32276 .58463 .31842 .58078 .31411 Mtetra
.752 .814 .901 r
.58078 .31411 .58463 .31842 .59205 .31397 .58822 .3096 Mtetra
.756 .813 .897 r
.58822 .3096 .59205 .31397 .59948 .3094 .59566 .30498 Mtetra
.761 .812 .893 r
.59566 .30498 .59948 .3094 .60692 .30471 .60312 .30023 Mtetra
.765 .81 .889 r
.60312 .30023 .60692 .30471 .61436 .2999 .61058 .29535 Mtetra
.769 .809 .885 r
.61058 .29535 .61436 .2999 .62181 .29495 .61804 .29033 Mtetra
.774 .808 .88 r
.61804 .29033 .62181 .29495 .62926 .28987 .62551 .28518 Mtetra
.778 .806 .875 r
.62551 .28518 .62926 .28987 .63672 .28465 .63298 .27989 Mtetra
.782 .805 .871 r
.63298 .27989 .63672 .28465 .64418 .27929 .64045 .27445 Mtetra
.787 .803 .866 r
.64045 .27445 .64418 .27929 .65164 .27378 .64793 .26886 Mtetra
.791 .801 .86 r
.64793 .26886 .65164 .27378 .6591 .26811 .6554 .26311 Mtetra
.795 .799 .855 r
.6554 .26311 .6591 .26811 .66656 .26228 .66287 .2572 Mtetra
.799 .797 .85 r
.66287 .2572 .66656 .26228 .67401 .25629 .67034 .25112 Mtetra
.803 .795 .844 r
.67034 .25112 .67401 .25629 .68146 .25012 .6778 .24486 Mtetra
.807 .793 .839 r
.6778 .24486 .68146 .25012 .6889 .24378 .68526 .23842 Mtetra
.811 .79 .833 r
.68526 .23842 .6889 .24378 .69634 .23724 .69271 .23179 Mtetra
.815 .788 .827 r
.69271 .23179 .69634 .23724 .70376 .23052 .70015 .22497 Mtetra
.819 .786 .821 r
.70015 .22497 .70376 .23052 .71118 .2236 .70757 .21794 Mtetra
.823 .783 .815 r
.70757 .21794 .71118 .2236 .71858 .21647 .71498 .21071 Mtetra
.826 .78 .809 r
.71498 .21071 .71858 .21647 .72596 .20912 .72238 .20325 Mtetra
.83 .778 .803 r
.72238 .20325 .72596 .20912 .73333 .20155 .72975 .19557 Mtetra
0 0 .499 r
.06779 .32145 .0718 .32827 .07642 .33458 .07238 .32786 Mtetra
0 0 .531 r
.07238 .32786 .07642 .33458 .08112 .34062 .07706 .334 Mtetra
0 0 .561 r
.07706 .334 .08112 .34062 .0859 .34639 .08181 .33988 Mtetra
0 .028 .591 r
.08181 .33988 .0859 .34639 .09075 .3519 .08665 .34549 Mtetra
0 .062 .62 r
.08665 .34549 .09075 .3519 .09569 .35716 .09156 .35084 Mtetra
0 .096 .648 r
.09156 .35084 .09569 .35716 .10069 .36217 .09654 .35594 Mtetra
0 .129 .674 r
.09654 .35594 .10069 .36217 .10577 .36693 .10159 .3608 Mtetra
0 .162 .699 r
.10159 .3608 .10577 .36693 .11091 .37145 .10672 .36541 Mtetra
0 .194 .723 r
.10672 .36541 .11091 .37145 .11613 .37573 .11192 .36979 Mtetra
0 .225 .745 r
.11192 .36979 .11613 .37573 .12141 .37978 .11718 .37393 Mtetra
0 .255 .766 r
.11718 .37393 .12141 .37978 .12675 .38361 .12251 .37784 Mtetra
0 .285 .786 r
.12251 .37784 .12675 .38361 .13216 .38722 .1279 .38154 Mtetra
0 .313 .804 r
.1279 .38154 .13216 .38722 .13763 .39061 .13335 .38501 Mtetra
.011 .34 .821 r
.13335 .38501 .13763 .39061 .14316 .39379 .13887 .38827 Mtetra
.043 .366 .836 r
.13887 .38827 .14316 .39379 .14874 .39676 .14444 .39133 Mtetra
.073 .391 .85 r
.14444 .39133 .14874 .39676 .15439 .39953 .15007 .39418 Mtetra
.103 .415 .863 r
.15007 .39418 .15439 .39953 .16009 .40211 .15576 .39683 Mtetra
.131 .438 .875 r
.15576 .39683 .16009 .40211 .16584 .40449 .1615 .39929 Mtetra
.158 .459 .886 r
.1615 .39929 .16584 .40449 .17164 .40668 .1673 .40156 Mtetra
.185 .48 .896 r
.1673 .40156 .17164 .40668 .1775 .4087 .17315 .40364 Mtetra
.21 .499 .904 r
.17315 .40364 .1775 .4087 .18341 .41053 .17905 .40554 Mtetra
.233 .518 .912 r
.17905 .40554 .18341 .41053 .18936 .41219 .18499 .40727 Mtetra
.256 .535 .92 r
.18499 .40727 .18936 .41219 .19536 .41368 .19099 .40883 Mtetra
.278 .552 .926 r
.19099 .40883 .19536 .41368 .20141 .415 .19703 .41021 Mtetra
.299 .568 .932 r
.19703 .41021 .20141 .415 .2075 .41616 .20312 .41144 Mtetra
.319 .582 .937 r
.20312 .41144 .2075 .41616 .21364 .41717 .20925 .4125 Mtetra
.337 .597 .942 r
.20925 .4125 .21364 .41717 .21982 .41802 .21543 .41342 Mtetra
.355 .61 .946 r
.21543 .41342 .21982 .41802 .22604 .41872 .22165 .41418 Mtetra
.372 .622 .949 r
.22165 .41418 .22604 .41872 .2323 .41928 .22791 .41479 Mtetra
.389 .634 .953 r
.22791 .41479 .2323 .41928 .2386 .4197 .23421 .41526 Mtetra
.404 .646 .955 r
.23421 .41526 .2386 .4197 .24494 .41998 .24054 .41559 Mtetra
.419 .656 .958 r
.24054 .41559 .24494 .41998 .25131 .42012 .24692 .41578 Mtetra
.433 .666 .96 r
.24692 .41578 .25131 .42012 .25773 .42013 .25333 .41584 Mtetra
.446 .676 .962 r
.25333 .41584 .25773 .42013 .26417 .42002 .25978 .41577 Mtetra
.459 .685 .963 r
.25978 .41577 .26417 .42002 .27066 .41978 .26627 .41558 Mtetra
.471 .693 .964 r
.26627 .41558 .27066 .41978 .27717 .41942 .27279 .41526 Mtetra
.483 .702 .965 r
.27279 .41526 .27717 .41942 .28372 .41894 .27934 .41482 Mtetra
.494 .709 .966 r
.27934 .41482 .28372 .41894 .2903 .41835 .28593 .41427 Mtetra
.505 .716 .967 r
.28593 .41427 .2903 .41835 .29691 .41765 .29255 .4136 Mtetra
.515 .723 .967 r
.29255 .4136 .29691 .41765 .30356 .41683 .29919 .41282 Mtetra
.525 .73 .968 r
.29919 .41282 .30356 .41683 .31023 .41591 .30587 .41193 Mtetra
.534 .736 .968 r
.30587 .41193 .31023 .41591 .31693 .41489 .31258 .41093 Mtetra
.543 .742 .968 r
.31258 .41093 .31693 .41489 .32367 .41376 .31932 .40983 Mtetra
.552 .747 .968 r
.31932 .40983 .32367 .41376 .33043 .41254 .32609 .40863 Mtetra
.56 .752 .967 r
.32609 .40863 .33043 .41254 .33721 .41121 .33289 .40733 Mtetra
.568 .757 .967 r
.33289 .40733 .33721 .41121 .34403 .40979 .33971 .40593 Mtetra
.576 .762 .967 r
.33971 .40593 .34403 .40979 .35087 .40828 .34656 .40443 Mtetra
.583 .766 .966 r
.34656 .40443 .35087 .40828 .35773 .40667 .35343 .40285 Mtetra
.59 .77 .965 r
.35343 .40285 .35773 .40667 .36463 .40498 .36034 .40116 Mtetra
.597 .774 .965 r
.36034 .40116 .36463 .40498 .37154 .40319 .36726 .39939 Mtetra
.604 .778 .964 r
.36726 .39939 .37154 .40319 .37848 .40132 .37421 .39753 Mtetra
.61 .781 .963 r
.37421 .39753 .37848 .40132 .38545 .39936 .38119 .39558 Mtetra
.617 .785 .962 r
.38119 .39558 .38545 .39936 .39243 .39732 .38819 .39354 Mtetra
.623 .788 .961 r
.38819 .39354 .39243 .39732 .39944 .39519 .39521 .39142 Mtetra
.629 .791 .96 r
.39521 .39142 .39944 .39519 .40648 .39297 .40225 .38921 Mtetra
.635 .793 .958 r
.40225 .38921 .40648 .39297 .41353 .39068 .40932 .38691 Mtetra
.64 .796 .957 r
.40932 .38691 .41353 .39068 .42061 .3883 .41641 .38453 Mtetra
.646 .798 .956 r
.41641 .38453 .42061 .3883 .4277 .38584 .42352 .38206 Mtetra
.651 .8 .954 r
.42352 .38206 .4277 .38584 .43482 .3833 .43065 .37951 Mtetra
.657 .802 .953 r
.43065 .37951 .43482 .3833 .44196 .38067 .4378 .37688 Mtetra
.662 .804 .951 r
.4378 .37688 .44196 .38067 .44912 .37797 .44497 .37416 Mtetra
.667 .805 .949 r
.44497 .37416 .44912 .37797 .45629 .37518 .45216 .37136 Mtetra
.672 .807 .947 r
.45216 .37136 .45629 .37518 .46349 .37231 .45937 .36847 Mtetra
.677 .808 .945 r
.45937 .36847 .46349 .37231 .4707 .36935 .4666 .3655 Mtetra
.682 .809 .943 r
.4666 .3655 .4707 .36935 .47793 .36631 .47385 .36244 Mtetra
.687 .81 .941 r
.47385 .36244 .47793 .36631 .48518 .36319 .48111 .35929 Mtetra
.692 .811 .939 r
.48111 .35929 .48518 .36319 .49245 .35998 .48839 .35606 Mtetra
.697 .812 .936 r
.48839 .35606 .49245 .35998 .49973 .35668 .49569 .35274 Mtetra
.702 .813 .934 r
.49569 .35274 .49973 .35668 .50703 .35329 .50301 .34932 Mtetra
.707 .813 .931 r
.50301 .34932 .50703 .35329 .51435 .34982 .51034 .34581 Mtetra
.711 .813 .928 r
.51034 .34581 .51435 .34982 .52168 .34625 .51768 .34221 Mtetra
.716 .814 .926 r
.51768 .34221 .52168 .34625 .52902 .34258 .52504 .33851 Mtetra
.721 .814 .923 r
.52504 .33851 .52902 .34258 .53638 .33883 .53241 .33471 Mtetra
.725 .814 .92 r
.53241 .33471 .53638 .33883 .54375 .33497 .5398 .33081 Mtetra
.73 .813 .916 r
.5398 .33081 .54375 .33497 .55113 .33101 .5472 .32681 Mtetra
.735 .813 .913 r
.5472 .32681 .55113 .33101 .55853 .32695 .55461 .3227 Mtetra
.739 .813 .909 r
.55461 .3227 .55853 .32695 .56594 .32278 .56204 .31848 Mtetra
.744 .812 .906 r
.56204 .31848 .56594 .32278 .57335 .3185 .56947 .31415 Mtetra
.748 .811 .902 r
.56947 .31415 .57335 .3185 .58078 .31411 .57691 .30971 Mtetra
.753 .81 .898 r
.57691 .30971 .58078 .31411 .58822 .3096 .58437 .30514 Mtetra
.757 .809 .894 r
.58437 .30514 .58822 .3096 .59566 .30498 .59183 .30045 Mtetra
.762 .808 .89 r
.59183 .30045 .59566 .30498 .60312 .30023 .59929 .29564 Mtetra
.766 .807 .886 r
.59929 .29564 .60312 .30023 .61058 .29535 .60677 .29069 Mtetra
.77 .806 .881 r
.60677 .29069 .61058 .29535 .61804 .29033 .61425 .28561 Mtetra
.775 .804 .877 r
.61425 .28561 .61804 .29033 .62551 .28518 .62173 .28039 Mtetra
.779 .803 .872 r
.62173 .28039 .62551 .28518 .63298 .27989 .62922 .27502 Mtetra
.783 .801 .867 r
.62922 .27502 .63298 .27989 .64045 .27445 .63671 .26951 Mtetra
.788 .799 .862 r
.63671 .26951 .64045 .27445 .64793 .26886 .6442 .26383 Mtetra
.792 .797 .857 r
.6442 .26383 .64793 .26886 .6554 .26311 .65168 .258 Mtetra
.796 .795 .852 r
.65168 .258 .6554 .26311 .66287 .2572 .65917 .252 Mtetra
.8 .793 .846 r
.65917 .252 .66287 .2572 .67034 .25112 .66665 .24583 Mtetra
.804 .791 .841 r
.66665 .24583 .67034 .25112 .6778 .24486 .67413 .23948 Mtetra
.808 .789 .835 r
.67413 .23948 .6778 .24486 .68526 .23842 .6816 .23294 Mtetra
.812 .787 .829 r
.6816 .23294 .68526 .23842 .69271 .23179 .68906 .22622 Mtetra
.815 .784 .823 r
.68906 .22622 .69271 .23179 .70015 .22497 .69651 .21929 Mtetra
.819 .782 .817 r
.69651 .21929 .70015 .22497 .70757 .21794 .70394 .21215 Mtetra
.823 .779 .811 r
.70394 .21215 .70757 .21794 .71498 .21071 .71137 .20481 Mtetra
.827 .776 .805 r
.71137 .20481 .71498 .21071 .72238 .20325 .71877 .19724 Mtetra
.83 .774 .799 r
.71877 .19724 .72238 .20325 .72975 .19557 .72616 .18944 Mtetra
0 0 .495 r
.0638 .31447 .06779 .32145 .07238 .32786 .06836 .32099 Mtetra
0 0 .526 r
.06836 .32099 .07238 .32786 .07706 .334 .07301 .32723 Mtetra
0 0 .556 r
.07301 .32723 .07706 .334 .08181 .33988 .07774 .3332 Mtetra
0 .02 .586 r
.07774 .3332 .08181 .33988 .08665 .34549 .08255 .33892 Mtetra
0 .054 .614 r
.08255 .33892 .08665 .34549 .09156 .35084 .08743 .34437 Mtetra
0 .087 .642 r
.08743 .34437 .09156 .35084 .09654 .35594 .09239 .34957 Mtetra
0 .12 .668 r
.09239 .34957 .09654 .35594 .10159 .3608 .09743 .35452 Mtetra
0 .153 .693 r
.09743 .35452 .10159 .3608 .10672 .36541 .10253 .35923 Mtetra
0 .185 .717 r
.10253 .35923 .10672 .36541 .11192 .36979 .10771 .3637 Mtetra
0 .216 .739 r
.10771 .3637 .11192 .36979 .11718 .37393 .11295 .36793 Mtetra
0 .246 .76 r
.11295 .36793 .11718 .37393 .12251 .37784 .11826 .37194 Mtetra
0 .275 .78 r
.11826 .37194 .12251 .37784 .1279 .38154 .12364 .37572 Mtetra
0 .303 .798 r
.12364 .37572 .1279 .38154 .13335 .38501 .12908 .37928 Mtetra
.006 .33 .815 r
.12908 .37928 .13335 .38501 .13887 .38827 .13458 .38262 Mtetra
.038 .357 .83 r
.13458 .38262 .13887 .38827 .14444 .39133 .14014 .38576 Mtetra
.068 .382 .845 r
.14014 .38576 .14444 .39133 .15007 .39418 .14576 .38869 Mtetra
.098 .406 .858 r
.14576 .38869 .15007 .39418 .15576 .39683 .15143 .39142 Mtetra
.126 .428 .87 r
.15143 .39142 .15576 .39683 .1615 .39929 .15716 .39396 Mtetra
.153 .45 .881 r
.15716 .39396 .1615 .39929 .1673 .40156 .16295 .3963 Mtetra
.179 .471 .891 r
.16295 .3963 .1673 .40156 .17315 .40364 .16879 .39846 Mtetra
.204 .49 .9 r
.16879 .39846 .17315 .40364 .17905 .40554 .17468 .40044 Mtetra
.228 .509 .908 r
.17468 .40044 .17905 .40554 .18499 .40727 .18062 .40223 Mtetra
.251 .527 .915 r
.18062 .40223 .18499 .40727 .19099 .40883 .18661 .40386 Mtetra
.273 .544 .922 r
.18661 .40386 .19099 .40883 .19703 .41021 .19265 .40531 Mtetra
.294 .56 .928 r
.19265 .40531 .19703 .41021 .20312 .41144 .19873 .4066 Mtetra
.314 .575 .933 r
.19873 .4066 .20312 .41144 .20925 .4125 .20486 .40773 Mtetra
.333 .589 .938 r
.20486 .40773 .20925 .4125 .21543 .41342 .21103 .4087 Mtetra
.351 .602 .942 r
.21103 .4087 .21543 .41342 .22165 .41418 .21725 .40952 Mtetra
.368 .615 .946 r
.21725 .40952 .22165 .41418 .22791 .41479 .2235 .41019 Mtetra
.385 .627 .949 r
.2235 .41019 .22791 .41479 .23421 .41526 .2298 .41071 Mtetra
.4 .639 .952 r
.2298 .41071 .23421 .41526 .24054 .41559 .23614 .41109 Mtetra
.415 .65 .955 r
.23614 .41109 .24054 .41559 .24692 .41578 .24252 .41134 Mtetra
.429 .66 .957 r
.24252 .41134 .24692 .41578 .25333 .41584 .24893 .41145 Mtetra
.443 .67 .959 r
.24893 .41145 .25333 .41584 .25978 .41577 .25538 .41142 Mtetra
.456 .679 .961 r
.25538 .41142 .25978 .41577 .26627 .41558 .26187 .41127 Mtetra
.468 .688 .962 r
.26187 .41127 .26627 .41558 .27279 .41526 .26839 .411 Mtetra
.48 .696 .963 r
.26839 .411 .27279 .41526 .27934 .41482 .27495 .4106 Mtetra
.491 .704 .964 r
.27495 .4106 .27934 .41482 .28593 .41427 .28154 .41008 Mtetra
.502 .711 .965 r
.28154 .41008 .28593 .41427 .29255 .4136 .28816 .40945 Mtetra
.513 .718 .965 r
.28816 .40945 .29255 .4136 .29919 .41282 .29481 .4087 Mtetra
.523 .725 .966 r
.29481 .4087 .29919 .41282 .30587 .41193 .3015 .40785 Mtetra
.532 .731 .966 r
.3015 .40785 .30587 .41193 .31258 .41093 .30822 .40688 Mtetra
.541 .737 .966 r
.30822 .40688 .31258 .41093 .31932 .40983 .31496 .40581 Mtetra
.55 .743 .966 r
.31496 .40581 .31932 .40983 .32609 .40863 .32174 .40463 Mtetra
.558 .748 .966 r
.32174 .40463 .32609 .40863 .33289 .40733 .32854 .40336 Mtetra
.566 .753 .965 r
.32854 .40336 .33289 .40733 .33971 .40593 .33537 .40198 Mtetra
.574 .758 .965 r
.33537 .40198 .33971 .40593 .34656 .40443 .34223 .4005 Mtetra
.582 .762 .964 r
.34223 .4005 .34656 .40443 .35343 .40285 .34911 .39893 Mtetra
.589 .766 .964 r
.34911 .39893 .35343 .40285 .36034 .40116 .35603 .39727 Mtetra
.596 .77 .963 r
.35603 .39727 .36034 .40116 .36726 .39939 .36296 .39551 Mtetra
.603 .774 .962 r
.36296 .39551 .36726 .39939 .37421 .39753 .36992 .39366 Mtetra
.61 .778 .961 r
.36992 .39366 .37421 .39753 .38119 .39558 .37691 .39171 Mtetra
.616 .781 .96 r
.37691 .39171 .38119 .39558 .38819 .39354 .38392 .38968 Mtetra
.622 .784 .959 r
.38392 .38968 .38819 .39354 .39521 .39142 .39095 .38756 Mtetra
.628 .787 .958 r
.39095 .38756 .39521 .39142 .40225 .38921 .39801 .38535 Mtetra
.634 .79 .957 r
.39801 .38535 .40225 .38921 .40932 .38691 .40509 .38306 Mtetra
.64 .792 .955 r
.40509 .38306 .40932 .38691 .41641 .38453 .41219 .38067 Mtetra
.646 .795 .954 r
.41219 .38067 .41641 .38453 .42352 .38206 .41931 .37821 Mtetra
.651 .797 .952 r
.41931 .37821 .42352 .38206 .43065 .37951 .42646 .37565 Mtetra
.657 .799 .951 r
.42646 .37565 .43065 .37951 .4378 .37688 .43362 .37301 Mtetra
.662 .801 .949 r
.43362 .37301 .4378 .37688 .44497 .37416 .44081 .37028 Mtetra
.668 .802 .947 r
.44081 .37028 .44497 .37416 .45216 .37136 .44801 .36746 Mtetra
.673 .804 .945 r
.44801 .36746 .45216 .37136 .45937 .36847 .45524 .36456 Mtetra
.678 .805 .943 r
.45524 .36456 .45937 .36847 .4666 .3655 .46248 .36157 Mtetra
.683 .806 .941 r
.46248 .36157 .4666 .3655 .47385 .36244 .46974 .35849 Mtetra
.688 .807 .939 r
.46974 .35849 .47385 .36244 .48111 .35929 .47702 .35532 Mtetra
.693 .808 .936 r
.47702 .35532 .48111 .35929 .48839 .35606 .48432 .35206 Mtetra
.698 .809 .934 r
.48432 .35206 .48839 .35606 .49569 .35274 .49163 .3487 Mtetra
.703 .809 .931 r
.49163 .3487 .49569 .35274 .50301 .34932 .49896 .34526 Mtetra
.708 .81 .929 r
.49896 .34526 .50301 .34932 .51034 .34581 .5063 .34172 Mtetra
.712 .81 .926 r
.5063 .34172 .51034 .34581 .51768 .34221 .51366 .33808 Mtetra
.717 .81 .923 r
.51366 .33808 .51768 .34221 .52504 .33851 .52104 .33434 Mtetra
.722 .81 .92 r
.52104 .33434 .52504 .33851 .53241 .33471 .52843 .3305 Mtetra
.727 .81 .917 r
.52843 .3305 .53241 .33471 .5398 .33081 .53583 .32656 Mtetra
.731 .81 .913 r
.53583 .32656 .5398 .33081 .5472 .32681 .54325 .32251 Mtetra
.736 .81 .91 r
.54325 .32251 .5472 .32681 .55461 .3227 .55068 .31835 Mtetra
.74 .809 .906 r
.55068 .31835 .55461 .3227 .56204 .31848 .55811 .31408 Mtetra
.745 .808 .903 r
.55811 .31408 .56204 .31848 .56947 .31415 .56556 .3097 Mtetra
.749 .808 .899 r
.56556 .3097 .56947 .31415 .57691 .30971 .57302 .3052 Mtetra
.754 .807 .895 r
.57302 .3052 .57691 .30971 .58437 .30514 .58049 .30057 Mtetra
.758 .806 .891 r
.58049 .30057 .58437 .30514 .59183 .30045 .58797 .29582 Mtetra
.763 .805 .887 r
.58797 .29582 .59183 .30045 .59929 .29564 .59545 .29094 Mtetra
.767 .803 .882 r
.59545 .29094 .59929 .29564 .60677 .29069 .60294 .28593 Mtetra
.771 .802 .878 r
.60294 .28593 .60677 .29069 .61425 .28561 .61044 .28078 Mtetra
.776 .8 .873 r
.61044 .28078 .61425 .28561 .62173 .28039 .61793 .27548 Mtetra
.78 .799 .868 r
.61793 .27548 .62173 .28039 .62922 .27502 .62544 .27004 Mtetra
.784 .797 .863 r
.62544 .27004 .62922 .27502 .63671 .26951 .63294 .26444 Mtetra
.788 .795 .858 r
.63294 .26444 .63671 .26951 .6442 .26383 .64044 .25869 Mtetra
.792 .793 .853 r
.64044 .25869 .6442 .26383 .65168 .258 .64794 .25277 Mtetra
.796 .791 .848 r
.64794 .25277 .65168 .258 .65917 .252 .65544 .24668 Mtetra
.8 .789 .842 r
.65544 .24668 .65917 .252 .66665 .24583 .66294 .24041 Mtetra
.804 .787 .837 r
.66294 .24041 .66665 .24583 .67413 .23948 .67043 .23397 Mtetra
.808 .785 .831 r
.67043 .23397 .67413 .23948 .6816 .23294 .67791 .22733 Mtetra
.812 .782 .825 r
.67791 .22733 .6816 .23294 .68906 .22622 .68538 .2205 Mtetra
.816 .78 .819 r
.68538 .2205 .68906 .22622 .69651 .21929 .69285 .21347 Mtetra
.819 .777 .813 r
.69285 .21347 .69651 .21929 .70394 .21215 .70029 .20622 Mtetra
.823 .775 .807 r
.70029 .20622 .70394 .21215 .71137 .20481 .70773 .19876 Mtetra
.827 .772 .801 r
.70773 .19876 .71137 .20481 .71877 .19724 .71514 .19108 Mtetra
.83 .769 .795 r
.71514 .19108 .71877 .19724 .72616 .18944 .72254 .18316 Mtetra
0 0 .49 r
.05982 .30731 .0638 .31447 .06836 .32099 .06436 .31394 Mtetra
0 0 .521 r
.06436 .31394 .06836 .32099 .07301 .32723 .06898 .32028 Mtetra
0 0 .551 r
.06898 .32028 .07301 .32723 .07774 .3332 .07368 .32636 Mtetra
0 .012 .58 r
.07368 .32636 .07774 .3332 .08255 .33892 .07846 .33218 Mtetra
0 .045 .609 r
.07846 .33218 .08255 .33892 .08743 .34437 .08332 .33773 Mtetra
0 .079 .636 r
.08332 .33773 .08743 .34437 .09239 .34957 .08826 .34303 Mtetra
0 .111 .662 r
.08826 .34303 .09239 .34957 .09743 .35452 .09327 .34808 Mtetra
0 .144 .687 r
.09327 .34808 .09743 .35452 .10253 .35923 .09835 .35289 Mtetra
0 .175 .711 r
.09835 .35289 .10253 .35923 .10771 .3637 .10351 .35745 Mtetra
0 .206 .733 r
.10351 .35745 .10771 .3637 .11295 .36793 .10873 .36178 Mtetra
0 .236 .754 r
.10873 .36178 .11295 .36793 .11826 .37194 .11402 .36588 Mtetra
0 .265 .773 r
.11402 .36588 .11826 .37194 .12364 .37572 .11938 .36975 Mtetra
0 .294 .792 r
.11938 .36975 .12364 .37572 .12908 .37928 .1248 .3734 Mtetra
.001 .321 .809 r
.1248 .3734 .12908 .37928 .13458 .38262 .13029 .37683 Mtetra
.033 .347 .824 r
.13029 .37683 .13458 .38262 .14014 .38576 .13583 .38005 Mtetra
.063 .372 .839 r
.13583 .38005 .14014 .38576 .14576 .38869 .14144 .38307 Mtetra
.093 .396 .852 r
.14144 .38307 .14576 .38869 .15143 .39142 .1471 .38588 Mtetra
.121 .419 .864 r
.1471 .38588 .15143 .39142 .15716 .39396 .15282 .3885 Mtetra
.148 .441 .875 r
.15282 .3885 .15716 .39396 .16295 .3963 .1586 .39092 Mtetra
.174 .462 .886 r
.1586 .39092 .16295 .3963 .16879 .39846 .16443 .39315 Mtetra
.199 .481 .895 r
.16443 .39315 .16879 .39846 .17468 .40044 .17031 .3952 Mtetra
.223 .5 .903 r
.17031 .3952 .17468 .40044 .18062 .40223 .17624 .39707 Mtetra
.246 .518 .911 r
.17624 .39707 .18062 .40223 .18661 .40386 .18222 .39877 Mtetra
.268 .535 .918 r
.18222 .39877 .18661 .40386 .19265 .40531 .18825 .40029 Mtetra
.289 .551 .924 r
.18825 .40029 .19265 .40531 .19873 .4066 .19433 .40164 Mtetra
.309 .567 .929 r
.19433 .40164 .19873 .4066 .20486 .40773 .20045 .40284 Mtetra
.329 .581 .934 r
.20045 .40284 .20486 .40773 .21103 .4087 .20662 .40387 Mtetra
.347 .595 .939 r
.20662 .40387 .21103 .4087 .21725 .40952 .21283 .40475 Mtetra
.364 .608 .943 r
.21283 .40475 .21725 .40952 .2235 .41019 .21909 .40548 Mtetra
.381 .62 .946 r
.21909 .40548 .2235 .41019 .2298 .41071 .22539 .40606 Mtetra
.396 .632 .949 r
.22539 .40606 .2298 .41071 .23614 .41109 .23172 .40649 Mtetra
.412 .643 .952 r
.23172 .40649 .23614 .41109 .24252 .41134 .2381 .40679 Mtetra
.426 .653 .954 r
.2381 .40679 .24252 .41134 .24893 .41145 .24451 .40695 Mtetra
.44 .663 .956 r
.24451 .40695 .24893 .41145 .25538 .41142 .25097 .40697 Mtetra
.453 .673 .958 r
.25097 .40697 .25538 .41142 .26187 .41127 .25745 .40687 Mtetra
.465 .681 .959 r
.25745 .40687 .26187 .41127 .26839 .411 .26398 .40664 Mtetra
.477 .69 .961 r
.26398 .40664 .26839 .411 .27495 .4106 .27054 .40628 Mtetra
.489 .698 .962 r
.27054 .40628 .27495 .4106 .28154 .41008 .27713 .4058 Mtetra
.5 .705 .962 r
.27713 .4058 .28154 .41008 .28816 .40945 .28376 .40521 Mtetra
.51 .713 .963 r
.28376 .40521 .28816 .40945 .29481 .4087 .29042 .4045 Mtetra
.52 .719 .963 r
.29042 .4045 .29481 .4087 .3015 .40785 .29711 .40367 Mtetra
.53 .726 .964 r
.29711 .40367 .3015 .40785 .30822 .40688 .30383 .40274 Mtetra
.539 .732 .964 r
.30383 .40274 .30822 .40688 .31496 .40581 .31058 .40169 Mtetra
.548 .738 .964 r
.31058 .40169 .31496 .40581 .32174 .40463 .31737 .40054 Mtetra
.557 .743 .964 r
.31737 .40054 .32174 .40463 .32854 .40336 .32418 .39929 Mtetra
.565 .748 .963 r
.32418 .39929 .32854 .40336 .33537 .40198 .33102 .39794 Mtetra
.573 .753 .963 r
.33102 .39794 .33537 .40198 .34223 .4005 .33788 .39648 Mtetra
.581 .758 .962 r
.33788 .39648 .34223 .4005 .34911 .39893 .34478 .39493 Mtetra
.588 .762 .962 r
.34478 .39493 .34911 .39893 .35603 .39727 .3517 .39328 Mtetra
.595 .766 .961 r
.3517 .39328 .35603 .39727 .36296 .39551 .35864 .39153 Mtetra
.602 .77 .96 r
.35864 .39153 .36296 .39551 .36992 .39366 .36562 .38969 Mtetra
.609 .774 .959 r
.36562 .38969 .36992 .39366 .37691 .39171 .37261 .38776 Mtetra
.615 .777 .958 r
.37261 .38776 .37691 .39171 .38392 .38968 .37963 .38573 Mtetra
.622 .78 .957 r
.37963 .38573 .38392 .38968 .39095 .38756 .38668 .38362 Mtetra
.628 .783 .956 r
.38668 .38362 .39095 .38756 .39801 .38535 .39375 .38141 Mtetra
.634 .786 .955 r
.39375 .38141 .39801 .38535 .40509 .38306 .40084 .37912 Mtetra
.64 .788 .953 r
.40084 .37912 .40509 .38306 .41219 .38067 .40795 .37673 Mtetra
.646 .791 .952 r
.40795 .37673 .41219 .38067 .41931 .37821 .41509 .37426 Mtetra
.652 .793 .95 r
.41509 .37426 .41931 .37821 .42646 .37565 .42225 .37169 Mtetra
.657 .795 .948 r
.42225 .37169 .42646 .37565 .43362 .37301 .42942 .36904 Mtetra
.663 .797 .947 r
.42942 .36904 .43362 .37301 .44081 .37028 .43662 .3663 Mtetra
.668 .799 .945 r
.43662 .3663 .44081 .37028 .44801 .36746 .44384 .36347 Mtetra
.673 .8 .943 r
.44384 .36347 .44801 .36746 .45524 .36456 .45108 .36055 Mtetra
.678 .801 .941 r
.45108 .36055 .45524 .36456 .46248 .36157 .45834 .35754 Mtetra
.684 .803 .938 r
.45834 .35754 .46248 .36157 .46974 .35849 .46561 .35444 Mtetra
.689 .804 .936 r
.46561 .35444 .46974 .35849 .47702 .35532 .47291 .35125 Mtetra
.694 .805 .934 r
.47291 .35125 .47702 .35532 .48432 .35206 .48022 .34796 Mtetra
.699 .805 .931 r
.48022 .34796 .48432 .35206 .49163 .3487 .48755 .34458 Mtetra
.704 .806 .929 r
.48755 .34458 .49163 .3487 .49896 .34526 .49489 .3411 Mtetra
.708 .806 .926 r
.49489 .3411 .49896 .34526 .5063 .34172 .50225 .33753 Mtetra
.713 .807 .923 r
.50225 .33753 .5063 .34172 .51366 .33808 .50963 .33385 Mtetra
.718 .807 .92 r
.50963 .33385 .51366 .33808 .52104 .33434 .51702 .33007 Mtetra
.723 .807 .917 r
.51702 .33007 .52104 .33434 .52843 .3305 .52442 .32619 Mtetra
.728 .807 .914 r
.52442 .32619 .52843 .3305 .53583 .32656 .53184 .32221 Mtetra
.732 .806 .91 r
.53184 .32221 .53583 .32656 .54325 .32251 .53927 .31811 Mtetra
.737 .806 .907 r
.53927 .31811 .54325 .32251 .55068 .31835 .54672 .3139 Mtetra
.741 .805 .903 r
.54672 .3139 .55068 .31835 .55811 .31408 .55417 .30958 Mtetra
.746 .805 .899 r
.55417 .30958 .55811 .31408 .56556 .3097 .56164 .30514 Mtetra
.75 .804 .895 r
.56164 .30514 .56556 .3097 .57302 .3052 .56911 .30058 Mtetra
.755 .803 .891 r
.56911 .30058 .57302 .3052 .58049 .30057 .5766 .2959 Mtetra
.759 .802 .887 r
.5766 .2959 .58049 .30057 .58797 .29582 .58409 .29108 Mtetra
.764 .801 .883 r
.58409 .29108 .58797 .29582 .59545 .29094 .59159 .28613 Mtetra
.768 .799 .878 r
.59159 .28613 .59545 .29094 .60294 .28593 .59909 .28105 Mtetra
.772 .798 .874 r
.59909 .28105 .60294 .28593 .61044 .28078 .6066 .27582 Mtetra
.777 .796 .869 r
.6066 .27582 .61044 .28078 .61793 .27548 .61411 .27045 Mtetra
.781 .795 .864 r
.61411 .27045 .61793 .27548 .62544 .27004 .62163 .26493 Mtetra
.785 .793 .859 r
.62163 .26493 .62544 .27004 .63294 .26444 .62915 .25925 Mtetra
.789 .791 .854 r
.62915 .25925 .63294 .26444 .64044 .25869 .63666 .25341 Mtetra
.793 .789 .849 r
.63666 .25341 .64044 .25869 .64794 .25277 .64418 .2474 Mtetra
.797 .787 .843 r
.64418 .2474 .64794 .25277 .65544 .24668 .65169 .24122 Mtetra
.801 .785 .838 r
.65169 .24122 .65544 .24668 .66294 .24041 .6592 .23486 Mtetra
.805 .783 .832 r
.6592 .23486 .66294 .24041 .67043 .23397 .66671 .22832 Mtetra
.809 .78 .827 r
.66671 .22832 .67043 .23397 .67791 .22733 .6742 .22158 Mtetra
.812 .778 .821 r
.6742 .22158 .67791 .22733 .68538 .2205 .68169 .21464 Mtetra
.816 .776 .815 r
.68169 .21464 .68538 .2205 .69285 .21347 .68916 .2075 Mtetra
.82 .773 .809 r
.68916 .2075 .69285 .21347 .70029 .20622 .69662 .20014 Mtetra
.823 .77 .803 r
.69662 .20014 .70029 .20622 .70773 .19876 .70406 .19257 Mtetra
.827 .768 .797 r
.70406 .19257 .70773 .19876 .71514 .19108 .71149 .18476 Mtetra
.83 .765 .79 r
.71149 .18476 .71514 .19108 .72254 .18316 .7189 .17672 Mtetra
0 0 .486 r
.05586 .29997 .05982 .30731 .06436 .31394 .06036 .30671 Mtetra
0 0 .516 r
.06036 .30671 .06436 .31394 .06898 .32028 .06495 .31316 Mtetra
0 0 .546 r
.06495 .31316 .06898 .32028 .07368 .32636 .06963 .31935 Mtetra
0 .004 .575 r
.06963 .31935 .07368 .32636 .07846 .33218 .07438 .32527 Mtetra
0 .037 .603 r
.07438 .32527 .07846 .33218 .08332 .33773 .07922 .33093 Mtetra
0 .07 .63 r
.07922 .33093 .08332 .33773 .08826 .34303 .08413 .33633 Mtetra
0 .103 .656 r
.08413 .33633 .08826 .34303 .09327 .34808 .08912 .34148 Mtetra
0 .135 .681 r
.08912 .34148 .09327 .34808 .09835 .35289 .09418 .34639 Mtetra
0 .166 .704 r
.09418 .34639 .09835 .35289 .10351 .35745 .09931 .35105 Mtetra
0 .197 .726 r
.09931 .35105 .10351 .35745 .10873 .36178 .10451 .35547 Mtetra
0 .227 .747 r
.10451 .35547 .10873 .36178 .11402 .36588 .10979 .35966 Mtetra
0 .256 .767 r
.10979 .35966 .11402 .36588 .11938 .36975 .11513 .36363 Mtetra
0 .284 .785 r
.11513 .36363 .11938 .36975 .1248 .3734 .12053 .36737 Mtetra
0 .311 .802 r
.12053 .36737 .1248 .3734 .13029 .37683 .126 .37089 Mtetra
.028 .337 .818 r
.126 .37089 .13029 .37683 .13583 .38005 .13153 .3742 Mtetra
.058 .362 .833 r
.13153 .3742 .13583 .38005 .14144 .38307 .13712 .3773 Mtetra
.088 .386 .846 r
.13712 .3773 .14144 .38307 .1471 .38588 .14277 .3802 Mtetra
.116 .409 .859 r
.14277 .3802 .1471 .38588 .15282 .3885 .14848 .3829 Mtetra
.143 .431 .87 r
.14848 .3829 .15282 .3885 .1586 .39092 .15424 .3854 Mtetra
.169 .452 .88 r
.15424 .3854 .1586 .39092 .16443 .39315 .16006 .38771 Mtetra
.195 .472 .89 r
.16006 .38771 .16443 .39315 .17031 .3952 .16593 .38984 Mtetra
.219 .491 .898 r
.16593 .38984 .17031 .3952 .17624 .39707 .17185 .39178 Mtetra
.242 .509 .906 r
.17185 .39178 .17624 .39707 .18222 .39877 .17783 .39354 Mtetra
.264 .527 .913 r
.17783 .39354 .18222 .39877 .18825 .40029 .18385 .39514 Mtetra
.285 .543 .919 r
.18385 .39514 .18825 .40029 .19433 .40164 .18992 .39656 Mtetra
.305 .558 .925 r
.18992 .39656 .19433 .40164 .20045 .40284 .19604 .39782 Mtetra
.324 .573 .93 r
.19604 .39782 .20045 .40284 .20662 .40387 .2022 .39892 Mtetra
.343 .587 .935 r
.2022 .39892 .20662 .40387 .21283 .40475 .20841 .39986 Mtetra
.36 .6 .939 r
.20841 .39986 .21283 .40475 .21909 .40548 .21466 .40064 Mtetra
.377 .613 .942 r
.21466 .40064 .21909 .40548 .22539 .40606 .22096 .40128 Mtetra
.393 .624 .946 r
.22096 .40128 .22539 .40606 .23172 .40649 .22729 .40177 Mtetra
.408 .636 .948 r
.22729 .40177 .23172 .40649 .2381 .40679 .23367 .40212 Mtetra
.423 .646 .951 r
.23367 .40212 .2381 .40679 .24451 .40695 .24008 .40233 Mtetra
.436 .656 .953 r
.24008 .40233 .24451 .40695 .25097 .40697 .24654 .40241 Mtetra
.45 .666 .955 r
.24654 .40241 .25097 .40697 .25745 .40687 .25303 .40235 Mtetra
.462 .675 .956 r
.25303 .40235 .25745 .40687 .26398 .40664 .25955 .40216 Mtetra
.475 .684 .958 r
.25955 .40216 .26398 .40664 .27054 .40628 .26612 .40185 Mtetra
.486 .692 .959 r
.26612 .40185 .27054 .40628 .27713 .4058 .27271 .40141 Mtetra
.497 .7 .96 r
.27271 .40141 .27713 .4058 .28376 .40521 .27934 .40086 Mtetra
.508 .707 .96 r
.27934 .40086 .28376 .40521 .29042 .4045 .28601 .40018 Mtetra
.518 .714 .961 r
.28601 .40018 .29042 .4045 .29711 .40367 .2927 .39939 Mtetra
.528 .72 .961 r
.2927 .39939 .29711 .40367 .30383 .40274 .29943 .39849 Mtetra
.537 .727 .961 r
.29943 .39849 .30383 .40274 .31058 .40169 .30619 .39747 Mtetra
.546 .732 .961 r
.30619 .39747 .31058 .40169 .31737 .40054 .31298 .39635 Mtetra
.555 .738 .961 r
.31298 .39635 .31737 .40054 .32418 .39929 .3198 .39513 Mtetra
.563 .743 .961 r
.3198 .39513 .32418 .39929 .33102 .39794 .32664 .39379 Mtetra
.572 .748 .961 r
.32664 .39379 .33102 .39794 .33788 .39648 .33352 .39236 Mtetra
.579 .753 .96 r
.33352 .39236 .33788 .39648 .34478 .39493 .34042 .39082 Mtetra
.587 .757 .959 r
.34042 .39082 .34478 .39493 .3517 .39328 .34735 .38919 Mtetra
.594 .761 .959 r
.34735 .38919 .3517 .39328 .35864 .39153 .35431 .38746 Mtetra
.601 .765 .958 r
.35431 .38746 .35864 .39153 .36562 .38969 .36129 .38563 Mtetra
.608 .769 .957 r
.36129 .38563 .36562 .38969 .37261 .38776 .3683 .38371 Mtetra
.615 .773 .956 r
.3683 .38371 .37261 .38776 .37963 .38573 .37533 .38169 Mtetra
.621 .776 .955 r
.37533 .38169 .37963 .38573 .38668 .38362 .38239 .37958 Mtetra
.628 .779 .954 r
.38239 .37958 .38668 .38362 .39375 .38141 .38947 .37737 Mtetra
.634 .782 .952 r
.38947 .37737 .39375 .38141 .40084 .37912 .39657 .37508 Mtetra
.64 .784 .951 r
.39657 .37508 .40084 .37912 .40795 .37673 .4037 .37269 Mtetra
.646 .787 .949 r
.4037 .37269 .40795 .37673 .41509 .37426 .41084 .37021 Mtetra
.652 .789 .948 r
.41084 .37021 .41509 .37426 .42225 .37169 .41801 .36764 Mtetra
.657 .791 .946 r
.41801 .36764 .42225 .37169 .42942 .36904 .42521 .36498 Mtetra
.663 .793 .944 r
.42521 .36498 .42942 .36904 .43662 .3663 .43242 .36223 Mtetra
.668 .795 .942 r
.43242 .36223 .43662 .3663 .44384 .36347 .43965 .35938 Mtetra
.674 .796 .94 r
.43965 .35938 .44384 .36347 .45108 .36055 .4469 .35645 Mtetra
.679 .798 .938 r
.4469 .35645 .45108 .36055 .45834 .35754 .45417 .35342 Mtetra
.684 .799 .936 r
.45417 .35342 .45834 .35754 .46561 .35444 .46146 .35029 Mtetra
.689 .8 .933 r
.46146 .35029 .46561 .35444 .47291 .35125 .46877 .34708 Mtetra
.694 .801 .931 r
.46877 .34708 .47291 .35125 .48022 .34796 .4761 .34376 Mtetra
.699 .801 .928 r
.4761 .34376 .48022 .34796 .48755 .34458 .48344 .34035 Mtetra
.704 .802 .926 r
.48344 .34035 .48755 .34458 .49489 .3411 .4908 .33684 Mtetra
.709 .802 .923 r
.4908 .33684 .49489 .3411 .50225 .33753 .49818 .33323 Mtetra
.714 .803 .92 r
.49818 .33323 .50225 .33753 .50963 .33385 .50557 .32952 Mtetra
.719 .803 .917 r
.50557 .32952 .50963 .33385 .51702 .33007 .51298 .3257 Mtetra
.724 .803 .914 r
.51298 .3257 .51702 .33007 .52442 .32619 .5204 .32178 Mtetra
.728 .803 .91 r
.5204 .32178 .52442 .32619 .53184 .32221 .52783 .31775 Mtetra
.733 .802 .907 r
.52783 .31775 .53184 .32221 .53927 .31811 .53528 .3136 Mtetra
.738 .802 .903 r
.53528 .3136 .53927 .31811 .54672 .3139 .54274 .30934 Mtetra
.742 .801 .9 r
.54274 .30934 .54672 .3139 .55417 .30958 .55021 .30497 Mtetra
.747 .801 .896 r
.55021 .30497 .55417 .30958 .56164 .30514 .55769 .30047 Mtetra
.751 .8 .892 r
.55769 .30047 .56164 .30514 .56911 .30058 .56518 .29585 Mtetra
.756 .799 .888 r
.56518 .29585 .56911 .30058 .5766 .2959 .57268 .2911 Mtetra
.76 .798 .883 r
.57268 .2911 .5766 .2959 .58409 .29108 .58019 .28622 Mtetra
.765 .797 .879 r
.58019 .28622 .58409 .29108 .59159 .28613 .5877 .2812 Mtetra
.769 .795 .874 r
.5877 .2812 .59159 .28613 .59909 .28105 .59522 .27605 Mtetra
.773 .794 .87 r
.59522 .27605 .59909 .28105 .6066 .27582 .60274 .27075 Mtetra
.777 .792 .865 r
.60274 .27075 .6066 .27582 .61411 .27045 .61027 .2653 Mtetra
.781 .79 .86 r
.61027 .2653 .61411 .27045 .62163 .26493 .6178 .25969 Mtetra
.786 .789 .855 r
.6178 .25969 .62163 .26493 .62915 .25925 .62533 .25393 Mtetra
.79 .787 .85 r
.62533 .25393 .62915 .25925 .63666 .25341 .63287 .248 Mtetra
.794 .785 .845 r
.63287 .248 .63666 .25341 .64418 .2474 .6404 .2419 Mtetra
.797 .783 .839 r
.6404 .2419 .64418 .2474 .65169 .24122 .64792 .23562 Mtetra
.801 .78 .834 r
.64792 .23562 .65169 .24122 .6592 .23486 .65545 .22917 Mtetra
.805 .778 .828 r
.65545 .22917 .6592 .23486 .66671 .22832 .66296 .22252 Mtetra
.809 .776 .822 r
.66296 .22252 .66671 .22832 .6742 .22158 .67047 .21568 Mtetra
.813 .773 .816 r
.67047 .21568 .6742 .22158 .68169 .21464 .67797 .20863 Mtetra
.816 .771 .81 r
.67797 .20863 .68169 .21464 .68916 .2075 .68545 .20138 Mtetra
.82 .768 .804 r
.68545 .20138 .68916 .2075 .69662 .20014 .69292 .1939 Mtetra
.823 .766 .798 r
.69292 .1939 .69662 .20014 .70406 .19257 .70038 .18621 Mtetra
.826 .763 .792 r
.70038 .18621 .70406 .19257 .71149 .18476 .70781 .17828 Mtetra
.83 .76 .786 r
.70781 .17828 .71149 .18476 .7189 .17672 .71523 .17012 Mtetra
0 0 .481 r
.05191 .29245 .05586 .29997 .06036 .30671 .05638 .29929 Mtetra
0 0 .511 r
.05638 .29929 .06036 .30671 .06495 .31316 .06094 .30586 Mtetra
0 0 .541 r
.06094 .30586 .06495 .31316 .06963 .31935 .06559 .31216 Mtetra
0 0 .569 r
.06559 .31216 .06963 .31935 .07438 .32527 .07032 .31818 Mtetra
0 .029 .597 r
.07032 .31818 .07438 .32527 .07922 .33093 .07512 .32395 Mtetra
0 .061 .624 r
.07512 .32395 .07922 .33093 .08413 .33633 .08001 .32946 Mtetra
0 .094 .65 r
.08001 .32946 .08413 .33633 .08912 .34148 .08497 .33471 Mtetra
0 .125 .674 r
.08497 .33471 .08912 .34148 .09418 .34639 .09001 .33972 Mtetra
0 .157 .698 r
.09001 .33972 .09418 .34639 .09931 .35105 .09512 .34448 Mtetra
0 .187 .72 r
.09512 .34448 .09931 .35105 .10451 .35547 .1003 .349 Mtetra
0 .217 .741 r
.1003 .349 .10451 .35547 .10979 .35966 .10555 .35329 Mtetra
0 .246 .76 r
.10555 .35329 .10979 .35966 .11513 .36363 .11087 .35735 Mtetra
0 .274 .779 r
.11087 .35735 .11513 .36363 .12053 .36737 .11626 .36118 Mtetra
0 .301 .796 r
.11626 .36118 .12053 .36737 .126 .37089 .12171 .3648 Mtetra
.024 .327 .812 r
.12171 .3648 .126 .37089 .13153 .3742 .12723 .3682 Mtetra
.054 .352 .826 r
.12723 .3682 .13153 .3742 .13712 .3773 .1328 .37138 Mtetra
.083 .377 .84 r
.1328 .37138 .13712 .3773 .14277 .3802 .13844 .37437 Mtetra
.111 .4 .853 r
.13844 .37437 .14277 .3802 .14848 .3829 .14413 .37715 Mtetra
.139 .422 .864 r
.14413 .37715 .14848 .3829 .15424 .3854 .14988 .37973 Mtetra
.165 .443 .875 r
.14988 .37973 .15424 .3854 .16006 .38771 .15569 .38212 Mtetra
.19 .463 .884 r
.15569 .38212 .16006 .38771 .16593 .38984 .16155 .38433 Mtetra
.214 .482 .893 r
.16155 .38433 .16593 .38984 .17185 .39178 .16746 .38635 Mtetra
.237 .5 .901 r
.16746 .38635 .17185 .39178 .17783 .39354 .17343 .38819 Mtetra
.259 .518 .908 r
.17343 .38819 .17783 .39354 .18385 .39514 .17944 .38985 Mtetra
.28 .534 .915 r
.17944 .38985 .18385 .39514 .18992 .39656 .18551 .39134 Mtetra
.301 .55 .92 r
.18551 .39134 .18992 .39656 .19604 .39782 .19162 .39267 Mtetra
.32 .565 .926 r
.19162 .39267 .19604 .39782 .2022 .39892 .19778 .39383 Mtetra
.338 .579 .93 r
.19778 .39383 .2022 .39892 .20841 .39986 .20398 .39484 Mtetra
.356 .592 .935 r
.20398 .39484 .20841 .39986 .21466 .40064 .21023 .39569 Mtetra
.373 .605 .938 r
.21023 .39569 .21466 .40064 .22096 .40128 .21652 .39638 Mtetra
.389 .617 .942 r
.21652 .39638 .22096 .40128 .22729 .40177 .22286 .39693 Mtetra
.404 .628 .945 r
.22286 .39693 .22729 .40177 .23367 .40212 .22923 .39733 Mtetra
.419 .639 .947 r
.22923 .39733 .23367 .40212 .24008 .40233 .23564 .3976 Mtetra
.433 .649 .95 r
.23564 .3976 .24008 .40233 .24654 .40241 .2421 .39772 Mtetra
.447 .659 .952 r
.2421 .39772 .24654 .40241 .25303 .40235 .24859 .39771 Mtetra
.459 .668 .953 r
.24859 .39771 .25303 .40235 .25955 .40216 .25512 .39757 Mtetra
.472 .677 .955 r
.25512 .39757 .25955 .40216 .26612 .40185 .26168 .3973 Mtetra
.483 .685 .956 r
.26168 .3973 .26612 .40185 .27271 .40141 .26828 .39691 Mtetra
.495 .693 .957 r
.26828 .39691 .27271 .40141 .27934 .40086 .27491 .39639 Mtetra
.506 .701 .957 r
.27491 .39639 .27934 .40086 .28601 .40018 .28158 .39575 Mtetra
.516 .708 .958 r
.28158 .39575 .28601 .40018 .2927 .39939 .28828 .395 Mtetra
.526 .714 .958 r
.28828 .395 .2927 .39939 .29943 .39849 .29502 .39413 Mtetra
.535 .721 .959 r
.29502 .39413 .29943 .39849 .30619 .39747 .30178 .39315 Mtetra
.545 .727 .959 r
.30178 .39315 .30619 .39747 .31298 .39635 .30858 .39205 Mtetra
.554 .732 .959 r
.30858 .39205 .31298 .39635 .3198 .39513 .3154 .39085 Mtetra
.562 .738 .958 r
.3154 .39085 .3198 .39513 .32664 .39379 .32226 .38954 Mtetra
.57 .743 .958 r
.32226 .38954 .32664 .39379 .33352 .39236 .32914 .38813 Mtetra
.578 .748 .957 r
.32914 .38813 .33352 .39236 .34042 .39082 .33605 .38661 Mtetra
.586 .752 .957 r
.33605 .38661 .34042 .39082 .34735 .38919 .34299 .385 Mtetra
.593 .757 .956 r
.34299 .385 .34735 .38919 .35431 .38746 .34995 .38328 Mtetra
.601 .761 .955 r
.34995 .38328 .35431 .38746 .36129 .38563 .35695 .38146 Mtetra
.608 .764 .954 r
.35695 .38146 .36129 .38563 .3683 .38371 .36396 .37955 Mtetra
.614 .768 .953 r
.36396 .37955 .3683 .38371 .37533 .38169 .37101 .37754 Mtetra
.621 .771 .952 r
.37101 .37754 .37533 .38169 .38239 .37958 .37807 .37543 Mtetra
.627 .774 .951 r
.37807 .37543 .38239 .37958 .38947 .37737 .38517 .37323 Mtetra
.634 .777 .95 r
.38517 .37323 .38947 .37737 .39657 .37508 .39228 .37093 Mtetra
.64 .78 .948 r
.39228 .37093 .39657 .37508 .4037 .37269 .39942 .36854 Mtetra
.646 .782 .947 r
.39942 .36854 .4037 .37269 .41084 .37021 .40658 .36606 Mtetra
.652 .785 .945 r
.40658 .36606 .41084 .37021 .41801 .36764 .41376 .36348 Mtetra
.657 .787 .943 r
.41376 .36348 .41801 .36764 .42521 .36498 .42097 .36081 Mtetra
.663 .789 .941 r
.42097 .36081 .42521 .36498 .43242 .36223 .42819 .35805 Mtetra
.669 .79 .939 r
.42819 .35805 .43242 .36223 .43965 .35938 .43544 .35519 Mtetra
.674 .792 .937 r
.43544 .35519 .43965 .35938 .4469 .35645 .44271 .35223 Mtetra
.679 .793 .935 r
.44271 .35223 .4469 .35645 .45417 .35342 .44999 .34919 Mtetra
.685 .795 .933 r
.44999 .34919 .45417 .35342 .46146 .35029 .4573 .34604 Mtetra
.69 .796 .93 r
.4573 .34604 .46146 .35029 .46877 .34708 .46462 .3428 Mtetra
.695 .796 .928 r
.46462 .3428 .46877 .34708 .4761 .34376 .47196 .33945 Mtetra
.7 .797 .925 r
.47196 .33945 .4761 .34376 .48344 .34035 .47932 .33601 Mtetra
.705 .798 .922 r
.47932 .33601 .48344 .34035 .4908 .33684 .48669 .33247 Mtetra
.71 .798 .92 r
.48669 .33247 .4908 .33684 .49818 .33323 .49409 .32882 Mtetra
.715 .799 .917 r
.49409 .32882 .49818 .33323 .50557 .32952 .50149 .32507 Mtetra
.72 .799 .913 r
.50149 .32507 .50557 .32952 .51298 .3257 .50891 .32122 Mtetra
.725 .799 .91 r
.50891 .32122 .51298 .3257 .5204 .32178 .51635 .31725 Mtetra
.729 .798 .907 r
.51635 .31725 .5204 .32178 .52783 .31775 .5238 .31317 Mtetra
.734 .798 .903 r
.5238 .31317 .52783 .31775 .53528 .3136 .53126 .30897 Mtetra
.739 .798 .9 r
.53126 .30897 .53528 .3136 .54274 .30934 .53874 .30466 Mtetra
.743 .797 .896 r
.53874 .30466 .54274 .30934 .55021 .30497 .54622 .30023 Mtetra
.748 .796 .892 r
.54622 .30023 .55021 .30497 .55769 .30047 .55372 .29568 Mtetra
.752 .795 .888 r
.55372 .29568 .55769 .30047 .56518 .29585 .56122 .29099 Mtetra
.757 .794 .884 r
.56122 .29099 .56518 .29585 .57268 .2911 .56874 .28618 Mtetra
.761 .793 .879 r
.56874 .28618 .57268 .2911 .58019 .28622 .57626 .28123 Mtetra
.765 .792 .875 r
.57626 .28123 .58019 .28622 .5877 .2812 .58379 .27614 Mtetra
.77 .791 .87 r
.58379 .27614 .5877 .2812 .59522 .27605 .59133 .27091 Mtetra
.774 .789 .866 r
.59133 .27091 .59522 .27605 .60274 .27075 .59887 .26553 Mtetra
.778 .788 .861 r
.59887 .26553 .60274 .27075 .61027 .2653 .60641 .26 Mtetra
.782 .786 .856 r
.60641 .26 .61027 .2653 .6178 .25969 .61395 .25431 Mtetra
.786 .784 .851 r
.61395 .25431 .6178 .25969 .62533 .25393 .6215 .24846 Mtetra
.79 .782 .846 r
.6215 .24846 .62533 .25393 .63287 .248 .62905 .24244 Mtetra
.794 .78 .84 r
.62905 .24244 .63287 .248 .6404 .2419 .63659 .23625 Mtetra
.798 .778 .835 r
.63659 .23625 .6404 .2419 .64792 .23562 .64413 .22988 Mtetra
.802 .776 .829 r
.64413 .22988 .64792 .23562 .65545 .22917 .65167 .22332 Mtetra
.805 .773 .824 r
.65167 .22332 .65545 .22917 .66296 .22252 .65919 .21657 Mtetra
.809 .771 .818 r
.65919 .21657 .66296 .22252 .67047 .21568 .66671 .20961 Mtetra
.813 .769 .812 r
.66671 .20961 .67047 .21568 .67797 .20863 .67422 .20246 Mtetra
.816 .766 .806 r
.67422 .20246 .67797 .20863 .68545 .20138 .68172 .19509 Mtetra
.82 .763 .8 r
.68172 .19509 .68545 .20138 .69292 .1939 .6892 .1875 Mtetra
.823 .761 .794 r
.6892 .1875 .69292 .1939 .70038 .18621 .69667 .17968 Mtetra
.826 .758 .788 r
.69667 .17968 .70038 .18621 .70781 .17828 .70411 .17163 Mtetra
.829 .755 .781 r
.70411 .17163 .70781 .17828 .71523 .17012 .71154 .16333 Mtetra
0 0 .477 r
.04798 .28473 .05191 .29245 .05638 .29929 .05242 .29169 Mtetra
0 0 .506 r
.05242 .29169 .05638 .29929 .06094 .30586 .05695 .29837 Mtetra
0 0 .535 r
.05695 .29837 .06094 .30586 .06559 .31216 .06157 .30477 Mtetra
0 0 .564 r
.06157 .30477 .06559 .31216 .07032 .31818 .06627 .31091 Mtetra
0 .021 .591 r
.06627 .31091 .07032 .31818 .07512 .32395 .07105 .31679 Mtetra
0 .053 .618 r
.07105 .31679 .07512 .32395 .08001 .32946 .0759 .3224 Mtetra
0 .085 .644 r
.0759 .3224 .08001 .32946 .08497 .33471 .08084 .32776 Mtetra
0 .116 .668 r
.08084 .32776 .08497 .33471 .09001 .33972 .08585 .33287 Mtetra
0 .147 .691 r
.08585 .33287 .09001 .33972 .09512 .34448 .09094 .33773 Mtetra
0 .178 .713 r
.09094 .33773 .09512 .34448 .1003 .349 .0961 .34236 Mtetra
0 .207 .734 r
.0961 .34236 .1003 .349 .10555 .35329 .10133 .34674 Mtetra
0 .236 .754 r
.10133 .34674 .10555 .35329 .11087 .35735 .10663 .3509 Mtetra
0 .264 .772 r
.10663 .3509 .11087 .35735 .11626 .36118 .112 .35483 Mtetra
0 .291 .789 r
.112 .35483 .11626 .36118 .12171 .3648 .11743 .35854 Mtetra
.019 .317 .805 r
.11743 .35854 .12171 .3648 .12723 .3682 .12293 .36203 Mtetra
.05 .342 .82 r
.12293 .36203 .12723 .3682 .1328 .37138 .12849 .36531 Mtetra
.079 .367 .834 r
.12849 .36531 .1328 .37138 .13844 .37437 .13411 .36838 Mtetra
.107 .39 .846 r
.13411 .36838 .13844 .37437 .14413 .37715 .13979 .37124 Mtetra
.134 .412 .858 r
.13979 .37124 .14413 .37715 .14988 .37973 .14552 .37391 Mtetra
.16 .433 .869 r
.14552 .37391 .14988 .37973 .15569 .38212 .15132 .37639 Mtetra
.185 .453 .878 r
.15132 .37639 .15569 .38212 .16155 .38433 .15717 .37867 Mtetra
.209 .473 .887 r
.15717 .37867 .16155 .38433 .16746 .38635 .16307 .38077 Mtetra
.233 .491 .895 r
.16307 .38077 .16746 .38635 .17343 .38819 .16903 .38268 Mtetra
.255 .508 .903 r
.16903 .38268 .17343 .38819 .17944 .38985 .17503 .38442 Mtetra
.276 .525 .91 r
.17503 .38442 .17944 .38985 .18551 .39134 .18109 .38598 Mtetra
.296 .541 .916 r
.18109 .38598 .18551 .39134 .19162 .39267 .1872 .38738 Mtetra
.316 .556 .921 r
.1872 .38738 .19162 .39267 .19778 .39383 .19335 .38861 Mtetra
.334 .57 .926 r
.19335 .38861 .19778 .39383 .20398 .39484 .19955 .38968 Mtetra
.352 .584 .93 r
.19955 .38968 .20398 .39484 .21023 .39569 .20579 .39059 Mtetra
.369 .597 .934 r
.20579 .39059 .21023 .39569 .21652 .39638 .21208 .39135 Mtetra
.385 .609 .938 r
.21208 .39135 .21652 .39638 .22286 .39693 .21841 .39196 Mtetra
.401 .621 .941 r
.21841 .39196 .22286 .39693 .22923 .39733 .22478 .39242 Mtetra
.416 .632 .943 r
.22478 .39242 .22923 .39733 .23564 .3976 .23119 .39273 Mtetra
.43 .642 .946 r
.23119 .39273 .23564 .3976 .2421 .39772 .23765 .39291 Mtetra
.444 .652 .948 r
.23765 .39291 .2421 .39772 .24859 .39771 .24414 .39295 Mtetra
.457 .661 .95 r
.24414 .39295 .24859 .39771 .25512 .39757 .25067 .39286 Mtetra
.469 .67 .951 r
.25067 .39286 .25512 .39757 .26168 .3973 .25723 .39264 Mtetra
.481 .679 .952 r
.25723 .39264 .26168 .3973 .26828 .39691 .26383 .39228 Mtetra
.492 .687 .953 r
.26383 .39228 .26828 .39691 .27491 .39639 .27047 .39181 Mtetra
.503 .694 .954 r
.27047 .39181 .27491 .39639 .28158 .39575 .27714 .39121 Mtetra
.514 .701 .955 r
.27714 .39121 .28158 .39575 .28828 .395 .28385 .39049 Mtetra
.524 .708 .955 r
.28385 .39049 .28828 .395 .29502 .39413 .29059 .38965 Mtetra
.534 .715 .956 r
.29059 .38965 .29502 .39413 .30178 .39315 .29736 .3887 Mtetra
.543 .721 .956 r
.29736 .3887 .30178 .39315 .30858 .39205 .30416 .38764 Mtetra
.552 .727 .956 r
.30416 .38764 .30858 .39205 .3154 .39085 .31099 .38646 Mtetra
.561 .732 .955 r
.31099 .38646 .3154 .39085 .32226 .38954 .31785 .38518 Mtetra
.569 .737 .955 r
.31785 .38518 .32226 .38954 .32914 .38813 .32474 .38379 Mtetra
.577 .742 .955 r
.32474 .38379 .32914 .38813 .33605 .38661 .33166 .38229 Mtetra
.585 .747 .954 r
.33166 .38229 .33605 .38661 .34299 .385 .33861 .38069 Mtetra
.592 .751 .953 r
.33861 .38069 .34299 .385 .34995 .38328 .34558 .37899 Mtetra
.6 .755 .953 r
.34558 .37899 .34995 .38328 .35695 .38146 .35259 .37718 Mtetra
.607 .759 .952 r
.35259 .37718 .35695 .38146 .36396 .37955 .35961 .37528 Mtetra
.614 .763 .951 r
.35961 .37528 .36396 .37955 .37101 .37754 .36667 .37328 Mtetra
.621 .766 .949 r
.36667 .37328 .37101 .37754 .37807 .37543 .37375 .37118 Mtetra
.627 .769 .948 r
.37375 .37118 .37807 .37543 .38517 .37323 .38085 .36898 Mtetra
.633 .772 .947 r
.38085 .36898 .38517 .37323 .39228 .37093 .38798 .36668 Mtetra
.64 .775 .945 r
.38798 .36668 .39228 .37093 .39942 .36854 .39513 .36429 Mtetra
.646 .778 .944 r
.39513 .36429 .39942 .36854 .40658 .36606 .4023 .3618 Mtetra
.652 .78 .942 r
.4023 .3618 .40658 .36606 .41376 .36348 .40949 .35921 Mtetra
.658 .782 .94 r
.40949 .35921 .41376 .36348 .42097 .36081 .41671 .35653 Mtetra
.663 .784 .938 r
.41671 .35653 .42097 .36081 .42819 .35805 .42395 .35376 Mtetra
.669 .786 .936 r
.42395 .35376 .42819 .35805 .43544 .35519 .43121 .35088 Mtetra
.674 .787 .934 r
.43121 .35088 .43544 .35519 .44271 .35223 .43849 .34791 Mtetra
.68 .789 .932 r
.43849 .34791 .44271 .35223 .44999 .34919 .44579 .34484 Mtetra
.685 .79 .93 r
.44579 .34484 .44999 .34919 .4573 .34604 .45311 .34167 Mtetra
.69 .791 .927 r
.45311 .34167 .4573 .34604 .46462 .3428 .46045 .3384 Mtetra
.696 .792 .924 r
.46045 .3384 .46462 .3428 .47196 .33945 .4678 .33503 Mtetra
.701 .793 .922 r
.4678 .33503 .47196 .33945 .47932 .33601 .47518 .33156 Mtetra
.706 .793 .919 r
.47518 .33156 .47932 .33601 .48669 .33247 .48257 .32798 Mtetra
.711 .794 .916 r
.48257 .32798 .48669 .33247 .49409 .32882 .48997 .3243 Mtetra
.716 .794 .913 r
.48997 .3243 .49409 .32882 .50149 .32507 .49739 .32051 Mtetra
.72 .794 .91 r
.49739 .32051 .50149 .32507 .50891 .32122 .50483 .31661 Mtetra
.725 .794 .906 r
.50483 .31661 .50891 .32122 .51635 .31725 .51228 .31259 Mtetra
.73 .794 .903 r
.51228 .31259 .51635 .31725 .5238 .31317 .51975 .30847 Mtetra
.735 .794 .899 r
.51975 .30847 .5238 .31317 .53126 .30897 .52723 .30422 Mtetra
.739 .793 .896 r
.52723 .30422 .53126 .30897 .53874 .30466 .53472 .29986 Mtetra
.744 .792 .892 r
.53472 .29986 .53874 .30466 .54622 .30023 .54222 .29537 Mtetra
.748 .792 .888 r
.54222 .29537 .54622 .30023 .55372 .29568 .54973 .29075 Mtetra
.753 .791 .884 r
.54973 .29075 .55372 .29568 .56122 .29099 .55725 .286 Mtetra
.757 .79 .879 r
.55725 .286 .56122 .29099 .56874 .28618 .56478 .28112 Mtetra
.762 .789 .875 r
.56478 .28112 .56874 .28618 .57626 .28123 .57232 .2761 Mtetra
.766 .787 .871 r
.57232 .2761 .57626 .28123 .58379 .27614 .57986 .27094 Mtetra
.77 .786 .866 r
.57986 .27094 .58379 .27614 .59133 .27091 .58741 .26564 Mtetra
.774 .784 .861 r
.58741 .26564 .59133 .27091 .59887 .26553 .59497 .26018 Mtetra
.778 .783 .856 r
.59497 .26018 .59887 .26553 .60641 .26 .60252 .25456 Mtetra
.782 .781 .851 r
.60252 .25456 .60641 .26 .61395 .25431 .61008 .24879 Mtetra
.786 .779 .846 r
.61008 .24879 .61395 .25431 .6215 .24846 .61764 .24285 Mtetra
.79 .777 .841 r
.61764 .24285 .6215 .24846 .62905 .24244 .6252 .23674 Mtetra
.794 .775 .836 r
.6252 .23674 .62905 .24244 .63659 .23625 .63276 .23045 Mtetra
.798 .773 .83 r
.63276 .23045 .63659 .23625 .64413 .22988 .64031 .22397 Mtetra
.802 .771 .825 r
.64031 .22397 .64413 .22988 .65167 .22332 .64786 .21731 Mtetra
.805 .768 .819 r
.64786 .21731 .65167 .22332 .65919 .21657 .6554 .21045 Mtetra
.809 .766 .813 r
.6554 .21045 .65919 .21657 .66671 .20961 .66294 .20339 Mtetra
.812 .764 .807 r
.66294 .20339 .66671 .20961 .67422 .20246 .67046 .19612 Mtetra
.816 .761 .801 r
.67046 .19612 .67422 .20246 .68172 .19509 .67796 .18863 Mtetra
.819 .758 .795 r
.67796 .18863 .68172 .19509 .6892 .1875 .68546 .18092 Mtetra
.823 .756 .789 r
.68546 .18092 .6892 .1875 .69667 .17968 .69293 .17297 Mtetra
.826 .753 .783 r
.69293 .17297 .69667 .17968 .70411 .17163 .70039 .16479 Mtetra
.829 .75 .777 r
.70039 .16479 .70411 .17163 .71154 .16333 .70782 .15636 Mtetra
0 0 .472 r
.04408 .27681 .04798 .28473 .05242 .29169 .04849 .28388 Mtetra
0 0 .501 r
.04849 .28388 .05242 .29169 .05695 .29837 .05298 .29068 Mtetra
0 0 .53 r
.05298 .29068 .05695 .29837 .06157 .30477 .05756 .2972 Mtetra
0 0 .558 r
.05756 .2972 .06157 .30477 .06627 .31091 .06223 .30345 Mtetra
0 .013 .585 r
.06223 .30345 .06627 .31091 .07105 .31679 .06698 .30943 Mtetra
0 .045 .612 r
.06698 .30943 .07105 .31679 .0759 .3224 .07181 .31516 Mtetra
0 .076 .637 r
.07181 .31516 .0759 .3224 .08084 .32776 .07672 .32062 Mtetra
0 .107 .661 r
.07672 .32062 .08084 .32776 .08585 .33287 .08171 .32584 Mtetra
0 .138 .685 r
.08171 .32584 .08585 .33287 .09094 .33773 .08677 .33081 Mtetra
0 .168 .707 r
.08677 .33081 .09094 .33773 .0961 .34236 .09191 .33553 Mtetra
0 .198 .727 r
.09191 .33553 .0961 .34236 .10133 .34674 .09712 .34002 Mtetra
0 .226 .747 r
.09712 .34002 .10133 .34674 .10663 .3509 .10239 .34428 Mtetra
0 .254 .765 r
.10239 .34428 .10663 .3509 .112 .35483 .10774 .34831 Mtetra
0 .281 .782 r
.10774 .34831 .112 .35483 .11743 .35854 .11315 .35211 Mtetra
.015 .307 .799 r
.11315 .35211 .11743 .35854 .12293 .36203 .11863 .35569 Mtetra
.045 .332 .813 r
.11863 .35569 .12293 .36203 .12849 .36531 .12417 .35906 Mtetra
.074 .357 .827 r
.12417 .35906 .12849 .36531 .13411 .36838 .12978 .36222 Mtetra
.103 .38 .84 r
.12978 .36222 .13411 .36838 .13979 .37124 .13544 .36518 Mtetra
.13 .402 .852 r
.13544 .36518 .13979 .37124 .14552 .37391 .14117 .36793 Mtetra
.156 .423 .863 r
.14117 .36793 .14552 .37391 .15132 .37639 .14695 .37049 Mtetra
.181 .444 .873 r
.14695 .37049 .15132 .37639 .15717 .37867 .15279 .37286 Mtetra
.205 .463 .882 r
.15279 .37286 .15717 .37867 .16307 .38077 .15868 .37503 Mtetra
.228 .481 .89 r
.15868 .37503 .16307 .38077 .16903 .38268 .16462 .37703 Mtetra
.25 .499 .897 r
.16462 .37703 .16903 .38268 .17503 .38442 .17062 .37884 Mtetra
.272 .516 .904 r
.17062 .37884 .17503 .38442 .18109 .38598 .17667 .38048 Mtetra
.292 .532 .91 r
.17667 .38048 .18109 .38598 .1872 .38738 .18277 .38195 Mtetra
.312 .547 .916 r
.18277 .38195 .1872 .38738 .19335 .38861 .18891 .38324 Mtetra
.33 .562 .921 r
.18891 .38324 .19335 .38861 .19955 .38968 .19511 .38438 Mtetra
.348 .575 .926 r
.19511 .38438 .19955 .38968 .20579 .39059 .20134 .38536 Mtetra
.365 .588 .93 r
.20134 .38536 .20579 .39059 .21208 .39135 .20763 .38618 Mtetra
.382 .601 .933 r
.20763 .38618 .21208 .39135 .21841 .39196 .21395 .38684 Mtetra
.397 .612 .937 r
.21395 .38684 .21841 .39196 .22478 .39242 .22032 .38736 Mtetra
.412 .624 .939 r
.22032 .38736 .22478 .39242 .23119 .39273 .22674 .38774 Mtetra
.427 .634 .942 r
.22674 .38774 .23119 .39273 .23765 .39291 .23319 .38797 Mtetra
.441 .644 .944 r
.23319 .38797 .23765 .39291 .24414 .39295 .23968 .38806 Mtetra
.454 .654 .946 r
.23968 .38806 .24414 .39295 .25067 .39286 .24621 .38801 Mtetra
.466 .663 .948 r
.24621 .38801 .25067 .39286 .25723 .39264 .25277 .38784 Mtetra
.478 .672 .949 r
.25277 .38784 .25723 .39264 .26383 .39228 .25938 .38753 Mtetra
.49 .68 .95 r
.25938 .38753 .26383 .39228 .27047 .39181 .26602 .38709 Mtetra
.501 .688 .951 r
.26602 .38709 .27047 .39181 .27714 .39121 .27269 .38653 Mtetra
.512 .695 .952 r
.27269 .38653 .27714 .39121 .28385 .39049 .2794 .38585 Mtetra
.522 .702 .952 r
.2794 .38585 .28385 .39049 .29059 .38965 .28614 .38505 Mtetra
.532 .708 .952 r
.28614 .38505 .29059 .38965 .29736 .3887 .29292 .38413 Mtetra
.541 .715 .952 r
.29292 .38413 .29736 .3887 .30416 .38764 .29973 .3831 Mtetra
.55 .721 .952 r
.29973 .3831 .30416 .38764 .31099 .38646 .30656 .38195 Mtetra
.559 .726 .952 r
.30656 .38195 .31099 .38646 .31785 .38518 .31343 .38069 Mtetra
.568 .731 .952 r
.31343 .38069 .31785 .38518 .32474 .38379 .32033 .37932 Mtetra
.576 .736 .952 r
.32033 .37932 .32474 .38379 .33166 .38229 .32726 .37784 Mtetra
.584 .741 .951 r
.32726 .37784 .33166 .38229 .33861 .38069 .33421 .37626 Mtetra
.592 .746 .95 r
.33421 .37626 .33861 .38069 .34558 .37899 .3412 .37457 Mtetra
.599 .75 .949 r
.3412 .37457 .34558 .37899 .35259 .37718 .34821 .37278 Mtetra
.606 .754 .949 r
.34821 .37278 .35259 .37718 .35961 .37528 .35525 .37089 Mtetra
.613 .757 .947 r
.35525 .37089 .35961 .37528 .36667 .37328 .36231 .36889 Mtetra
.62 .761 .946 r
.36231 .36889 .36667 .37328 .37375 .37118 .3694 .3668 Mtetra
.627 .764 .945 r
.3694 .3668 .37375 .37118 .38085 .36898 .37651 .3646 Mtetra
.633 .767 .944 r
.37651 .3646 .38085 .36898 .38798 .36668 .38365 .36231 Mtetra
.64 .77 .942 r
.38365 .36231 .38798 .36668 .39513 .36429 .39081 .35991 Mtetra
.646 .772 .94 r
.39081 .35991 .39513 .36429 .4023 .3618 .398 .35742 Mtetra
.652 .775 .939 r
.398 .35742 .4023 .3618 .40949 .35921 .40521 .35483 Mtetra
.658 .777 .937 r
.40521 .35483 .40949 .35921 .41671 .35653 .41244 .35213 Mtetra
.663 .779 .935 r
.41244 .35213 .41671 .35653 .42395 .35376 .41969 .34934 Mtetra
.669 .781 .933 r
.41969 .34934 .42395 .35376 .43121 .35088 .42696 .34645 Mtetra
.675 .782 .931 r
.42696 .34645 .43121 .35088 .43849 .34791 .43426 .34346 Mtetra
.68 .784 .928 r
.43426 .34346 .43849 .34791 .44579 .34484 .44157 .34037 Mtetra
.686 .785 .926 r
.44157 .34037 .44579 .34484 .45311 .34167 .4489 .33718 Mtetra
.691 .786 .924 r
.4489 .33718 .45311 .34167 .46045 .3384 .45625 .33388 Mtetra
.696 .787 .921 r
.45625 .33388 .46045 .3384 .4678 .33503 .46362 .33048 Mtetra
.701 .788 .918 r
.46362 .33048 .4678 .33503 .47518 .33156 .47101 .32698 Mtetra
.706 .788 .915 r
.47101 .32698 .47518 .33156 .48257 .32798 .47842 .32337 Mtetra
.711 .789 .912 r
.47842 .32337 .48257 .32798 .48997 .3243 .48584 .31965 Mtetra
.716 .789 .909 r
.48584 .31965 .48997 .3243 .49739 .32051 .49328 .31581 Mtetra
.721 .789 .906 r
.49328 .31581 .49739 .32051 .50483 .31661 .50073 .31187 Mtetra
.726 .789 .902 r
.50073 .31187 .50483 .31661 .51228 .31259 .50819 .30781 Mtetra
.731 .789 .899 r
.50819 .30781 .51228 .31259 .51975 .30847 .51567 .30363 Mtetra
.735 .789 .895 r
.51567 .30363 .51975 .30847 .52723 .30422 .52317 .29933 Mtetra
.74 .788 .892 r
.52317 .29933 .52723 .30422 .53472 .29986 .53067 .29491 Mtetra
.744 .787 .888 r
.53067 .29491 .53472 .29986 .54222 .29537 .53819 .29036 Mtetra
.749 .787 .884 r
.53819 .29036 .54222 .29537 .54973 .29075 .54572 .28568 Mtetra
.753 .786 .879 r
.54572 .28568 .54973 .29075 .55725 .286 .55325 .28087 Mtetra
.758 .785 .875 r
.55325 .28087 .55725 .286 .56478 .28112 .5608 .27592 Mtetra
.762 .784 .871 r
.5608 .27592 .56478 .28112 .57232 .2761 .56835 .27083 Mtetra
.766 .782 .866 r
.56835 .27083 .57232 .2761 .57986 .27094 .57591 .2656 Mtetra
.771 .781 .861 r
.57591 .2656 .57986 .27094 .58741 .26564 .58348 .26021 Mtetra
.775 .779 .857 r
.58348 .26021 .58741 .26564 .59497 .26018 .59105 .25467 Mtetra
.779 .778 .852 r
.59105 .25467 .59497 .26018 .60252 .25456 .59862 .24897 Mtetra
.783 .776 .847 r
.59862 .24897 .60252 .25456 .61008 .24879 .60619 .24311 Mtetra
.787 .774 .842 r
.60619 .24311 .61008 .24879 .61764 .24285 .61377 .23707 Mtetra
.791 .772 .836 r
.61377 .23707 .61764 .24285 .6252 .23674 .62134 .23087 Mtetra
.794 .77 .831 r
.62134 .23087 .6252 .23674 .63276 .23045 .62891 .22448 Mtetra
.798 .768 .825 r
.62891 .22448 .63276 .23045 .64031 .22397 .63648 .2179 Mtetra
.802 .766 .82 r
.63648 .2179 .64031 .22397 .64786 .21731 .64404 .21113 Mtetra
.805 .763 .814 r
.64404 .21113 .64786 .21731 .6554 .21045 .65159 .20416 Mtetra
.809 .761 .808 r
.65159 .20416 .6554 .21045 .66294 .20339 .65913 .19698 Mtetra
.812 .758 .802 r
.65913 .19698 .66294 .20339 .67046 .19612 .66667 .18959 Mtetra
.816 .756 .797 r
.66667 .18959 .67046 .19612 .67796 .18863 .67419 .18199 Mtetra
.819 .753 .791 r
.67419 .18199 .67796 .18863 .68546 .18092 .68169 .17415 Mtetra
.822 .751 .784 r
.68169 .17415 .68546 .18092 .69293 .17297 .68917 .16608 Mtetra
.825 .748 .778 r
.68917 .16608 .69293 .17297 .70039 .16479 .69664 .15776 Mtetra
.828 .745 .772 r
.69664 .15776 .70039 .16479 .70782 .15636 .70408 .14919 Mtetra
0 0 .467 r
.04019 .26868 .04408 .27681 .04849 .28388 .04457 .27587 Mtetra
0 0 .496 r
.04457 .27587 .04849 .28388 .05298 .29068 .04903 .28278 Mtetra
0 0 .525 r
.04903 .28278 .05298 .29068 .05756 .2972 .05358 .28942 Mtetra
0 0 .553 r
.05358 .28942 .05756 .2972 .06223 .30345 .05822 .29579 Mtetra
0 .005 .58 r
.05822 .29579 .06223 .30345 .06698 .30943 .06294 .30188 Mtetra
0 .036 .606 r
.06294 .30188 .06698 .30943 .07181 .31516 .06774 .30772 Mtetra
0 .068 .631 r
.06774 .30772 .07181 .31516 .07672 .32062 .07262 .3133 Mtetra
0 .098 .655 r
.07262 .3133 .07672 .32062 .08171 .32584 .07758 .31862 Mtetra
0 .129 .678 r
.07758 .31862 .08171 .32584 .08677 .33081 .08262 .32369 Mtetra
0 .159 .7 r
.08262 .32369 .08677 .33081 .09191 .33553 .08773 .32853 Mtetra
0 .188 .72 r
.08773 .32853 .09191 .33553 .09712 .34002 .09291 .33312 Mtetra
0 .217 .74 r
.09291 .33312 .09712 .34002 .10239 .34428 .09817 .33748 Mtetra
0 .244 .758 r
.09817 .33748 .10239 .34428 .10774 .34831 .10349 .3416 Mtetra
0 .271 .776 r
.10349 .3416 .10774 .34831 .11315 .35211 .10888 .3455 Mtetra
.012 .297 .792 r
.10888 .3455 .11315 .35211 .11863 .35569 .11434 .34918 Mtetra
.042 .322 .807 r
.11434 .34918 .11863 .35569 .12417 .35906 .11987 .35265 Mtetra
.07 .346 .821 r
.11987 .35265 .12417 .35906 .12978 .36222 .12546 .3559 Mtetra
.098 .37 .833 r
.12546 .3559 .12978 .36222 .13544 .36518 .1311 .35895 Mtetra
.125 .392 .845 r
.1311 .35895 .13544 .36518 .14117 .36793 .13681 .36179 Mtetra
.152 .413 .856 r
.13681 .36179 .14117 .36793 .14695 .37049 .14258 .36443 Mtetra
.177 .434 .866 r
.14258 .36443 .14695 .37049 .15279 .37286 .1484 .36688 Mtetra
.201 .453 .876 r
.1484 .36688 .15279 .37286 .15868 .37503 .15428 .36914 Mtetra
.224 .472 .884 r
.15428 .36914 .15868 .37503 .16462 .37703 .16022 .37121 Mtetra
.246 .49 .892 r
.16022 .37121 .16462 .37703 .17062 .37884 .16621 .3731 Mtetra
.268 .506 .899 r
.16621 .3731 .17062 .37884 .17667 .38048 .17224 .37482 Mtetra
.288 .523 .905 r
.17224 .37482 .17667 .38048 .18277 .38195 .17833 .37636 Mtetra
.308 .538 .911 r
.17833 .37636 .18277 .38195 .18891 .38324 .18447 .37773 Mtetra
.327 .553 .916 r
.18447 .37773 .18891 .38324 .19511 .38438 .19066 .37893 Mtetra
.345 .566 .921 r
.19066 .37893 .19511 .38438 .20134 .38536 .19689 .37997 Mtetra
.362 .58 .925 r
.19689 .37997 .20134 .38536 .20763 .38618 .20317 .38086 Mtetra
.378 .592 .929 r
.20317 .38086 .20763 .38618 .21395 .38684 .20949 .38159 Mtetra
.394 .604 .932 r
.20949 .38159 .21395 .38684 .22032 .38736 .21586 .38216 Mtetra
.409 .616 .935 r
.21586 .38216 .22032 .38736 .22674 .38774 .22227 .38259 Mtetra
.424 .626 .938 r
.22227 .38259 .22674 .38774 .23319 .38797 .22872 .38288 Mtetra
.438 .637 .94 r
.22872 .38288 .23319 .38797 .23968 .38806 .23521 .38302 Mtetra
.451 .646 .942 r
.23521 .38302 .23968 .38806 .24621 .38801 .24174 .38303 Mtetra
.464 .655 .944 r
.24174 .38303 .24621 .38801 .25277 .38784 .24831 .3829 Mtetra
.476 .664 .945 r
.24831 .3829 .25277 .38784 .25938 .38753 .25491 .38264 Mtetra
.487 .673 .946 r
.25491 .38264 .25938 .38753 .26602 .38709 .26155 .38224 Mtetra
.499 .68 .947 r
.26155 .38224 .26602 .38709 .27269 .38653 .26823 .38172 Mtetra
.51 .688 .948 r
.26823 .38172 .27269 .38653 .2794 .38585 .27494 .38108 Mtetra
.52 .695 .948 r
.27494 .38108 .2794 .38585 .28614 .38505 .28169 .38031 Mtetra
.53 .702 .949 r
.28169 .38031 .28614 .38505 .29292 .38413 .28847 .37943 Mtetra
.54 .708 .949 r
.28847 .37943 .29292 .38413 .29973 .3831 .29528 .37842 Mtetra
.549 .714 .949 r
.29528 .37842 .29973 .3831 .30656 .38195 .30212 .3773 Mtetra
.558 .72 .949 r
.30212 .3773 .30656 .38195 .31343 .38069 .309 .37607 Mtetra
.566 .725 .949 r
.309 .37607 .31343 .38069 .32033 .37932 .3159 .37473 Mtetra
.575 .73 .948 r
.3159 .37473 .32033 .37932 .32726 .37784 .32284 .37327 Mtetra
.583 .735 .948 r
.32284 .37327 .32726 .37784 .33421 .37626 .3298 .37171 Mtetra
.591 .74 .947 r
.3298 .37171 .33421 .37626 .3412 .37457 .3368 .37003 Mtetra
.598 .744 .946 r
.3368 .37003 .3412 .37457 .34821 .37278 .34382 .36826 Mtetra
.605 .748 .945 r
.34382 .36826 .34821 .37278 .35525 .37089 .35086 .36637 Mtetra
.613 .752 .944 r
.35086 .36637 .35525 .37089 .36231 .36889 .35794 .36439 Mtetra
.62 .755 .943 r
.35794 .36439 .36231 .36889 .3694 .3668 .36504 .36229 Mtetra
.626 .759 .942 r
.36504 .36229 .3694 .3668 .37651 .3646 .37216 .3601 Mtetra
.633 .762 .94 r
.37216 .3601 .37651 .3646 .38365 .36231 .37931 .35781 Mtetra
.639 .764 .939 r
.37931 .35781 .38365 .36231 .39081 .35991 .38648 .35541 Mtetra
.646 .767 .937 r
.38648 .35541 .39081 .35991 .398 .35742 .39368 .35291 Mtetra
.652 .769 .935 r
.39368 .35291 .398 .35742 .40521 .35483 .4009 .35031 Mtetra
.658 .772 .933 r
.4009 .35031 .40521 .35483 .41244 .35213 .40814 .34761 Mtetra
.664 .774 .931 r
.40814 .34761 .41244 .35213 .41969 .34934 .41541 .3448 Mtetra
.669 .776 .929 r
.41541 .3448 .41969 .34934 .42696 .34645 .4227 .3419 Mtetra
.675 .777 .927 r
.4227 .3419 .42696 .34645 .43426 .34346 .43 .33889 Mtetra
.68 .779 .925 r
.43 .33889 .43426 .34346 .44157 .34037 .43733 .33577 Mtetra
.686 .78 .922 r
.43733 .33577 .44157 .34037 .4489 .33718 .44468 .33256 Mtetra
.691 .781 .92 r
.44468 .33256 .4489 .33718 .45625 .33388 .45204 .32923 Mtetra
.697 .782 .917 r
.45204 .32923 .45625 .33388 .46362 .33048 .45943 .3258 Mtetra
.702 .783 .914 r
.45943 .3258 .46362 .33048 .47101 .32698 .46683 .32227 Mtetra
.707 .783 .911 r
.46683 .32227 .47101 .32698 .47842 .32337 .47425 .31862 Mtetra
.712 .784 .908 r
.47425 .31862 .47842 .32337 .48584 .31965 .48169 .31486 Mtetra
.717 .784 .905 r
.48169 .31486 .48584 .31965 .49328 .31581 .48914 .31098 Mtetra
.722 .784 .902 r
.48914 .31098 .49328 .31581 .50073 .31187 .4966 .30699 Mtetra
.726 .784 .898 r
.4966 .30699 .50073 .31187 .50819 .30781 .50409 .30289 Mtetra
.731 .784 .895 r
.50409 .30289 .50819 .30781 .51567 .30363 .51158 .29866 Mtetra
.736 .783 .891 r
.51158 .29866 .51567 .30363 .52317 .29933 .51909 .2943 Mtetra
.74 .783 .887 r
.51909 .2943 .52317 .29933 .53067 .29491 .52661 .28982 Mtetra
.745 .782 .883 r
.52661 .28982 .53067 .29491 .53819 .29036 .53414 .28521 Mtetra
.749 .781 .879 r
.53414 .28521 .53819 .29036 .54572 .28568 .54169 .28047 Mtetra
.754 .781 .875 r
.54169 .28047 .54572 .28568 .55325 .28087 .54924 .27559 Mtetra
.758 .78 .871 r
.54924 .27559 .55325 .28087 .5608 .27592 .5568 .27057 Mtetra
.762 .778 .866 r
.5568 .27057 .5608 .27592 .56835 .27083 .56437 .26541 Mtetra
.767 .777 .861 r
.56437 .26541 .56835 .27083 .57591 .2656 .57194 .26009 Mtetra
.771 .776 .857 r
.57194 .26009 .57591 .2656 .58348 .26021 .57952 .25463 Mtetra
.775 .774 .852 r
.57952 .25463 .58348 .26021 .59105 .25467 .5871 .249 Mtetra
.779 .772 .847 r
.5871 .249 .59105 .25467 .59862 .24897 .59469 .24322 Mtetra
.783 .771 .842 r
.59469 .24322 .59862 .24897 .60619 .24311 .60228 .23726 Mtetra
.787 .769 .837 r
.60228 .23726 .60619 .24311 .61377 .23707 .60987 .23113 Mtetra
.791 .767 .831 r
.60987 .23113 .61377 .23707 .62134 .23087 .61745 .22483 Mtetra
.794 .765 .826 r
.61745 .22483 .62134 .23087 .62891 .22448 .62504 .21833 Mtetra
.798 .762 .82 r
.62504 .21833 .62891 .22448 .63648 .2179 .63262 .21165 Mtetra
.802 .76 .815 r
.63262 .21165 .63648 .2179 .64404 .21113 .64019 .20477 Mtetra
.805 .758 .809 r
.64019 .20477 .64404 .21113 .65159 .20416 .64775 .19769 Mtetra
.809 .755 .803 r
.64775 .19769 .65159 .20416 .65913 .19698 .65531 .19039 Mtetra
.812 .753 .798 r
.65531 .19039 .65913 .19698 .66667 .18959 .66285 .18288 Mtetra
.815 .75 .792 r
.66285 .18288 .66667 .18959 .67419 .18199 .67038 .17515 Mtetra
.818 .748 .786 r
.67038 .17515 .67419 .18199 .68169 .17415 .6779 .16718 Mtetra
.822 .745 .78 r
.6779 .16718 .68169 .17415 .68917 .16608 .68539 .15898 Mtetra
.825 .743 .773 r
.68539 .15898 .68917 .16608 .69664 .15776 .69287 .15053 Mtetra
.828 .74 .767 r
.69287 .15053 .69664 .15776 .70408 .14919 .70032 .14182 Mtetra
0 0 .463 r
.03634 .26033 .04019 .26868 .04457 .27587 .04067 .26765 Mtetra
0 0 .491 r
.04067 .26765 .04457 .27587 .04903 .28278 .0451 .27468 Mtetra
0 0 .519 r
.0451 .27468 .04903 .28278 .05358 .28942 .04962 .28143 Mtetra
0 0 .547 r
.04962 .28143 .05358 .28942 .05822 .29579 .05422 .28792 Mtetra
0 0 .574 r
.05422 .28792 .05822 .29579 .06294 .30188 .05891 .29413 Mtetra
0 .028 .599 r
.05891 .29413 .06294 .30188 .06774 .30772 .06368 .30008 Mtetra
0 .059 .624 r
.06368 .30008 .06774 .30772 .07262 .3133 .06853 .30577 Mtetra
0 .09 .648 r
.06853 .30577 .07262 .3133 .07758 .31862 .07346 .3112 Mtetra
0 .12 .671 r
.07346 .3112 .07758 .31862 .08262 .32369 .07847 .31639 Mtetra
0 .149 .693 r
.07847 .31639 .08262 .32369 .08773 .32853 .08356 .32132 Mtetra
0 .178 .713 r
.08356 .32132 .08773 .32853 .09291 .33312 .08872 .32602 Mtetra
0 .207 .733 r
.08872 .32602 .09291 .33312 .09817 .33748 .09395 .33048 Mtetra
0 .234 .751 r
.09395 .33048 .09817 .33748 .10349 .3416 .09925 .33471 Mtetra
0 .261 .768 r
.09925 .33471 .10349 .3416 .10888 .3455 .10462 .33871 Mtetra
.008 .287 .785 r
.10462 .33871 .10888 .3455 .11434 .34918 .11006 .34249 Mtetra
.038 .312 .8 r
.11006 .34249 .11434 .34918 .11987 .35265 .11557 .34605 Mtetra
.067 .336 .814 r
.11557 .34605 .11987 .35265 .12546 .3559 .12114 .3494 Mtetra
.095 .359 .827 r
.12114 .3494 .12546 .3559 .1311 .35895 .12677 .35253 Mtetra
.121 .382 .839 r
.12677 .35253 .1311 .35895 .13681 .36179 .13246 .35547 Mtetra
.147 .403 .85 r
.13246 .35547 .13681 .36179 .14258 .36443 .13821 .3582 Mtetra
.173 .424 .86 r
.13821 .3582 .14258 .36443 .1484 .36688 .14403 .36073 Mtetra
.197 .443 .869 r
.14403 .36073 .1484 .36688 .15428 .36914 .14989 .36307 Mtetra
.22 .462 .878 r
.14989 .36307 .15428 .36914 .16022 .37121 .15581 .36523 Mtetra
.242 .48 .886 r
.15581 .36523 .16022 .37121 .16621 .3731 .16179 .3672 Mtetra
.264 .497 .893 r
.16179 .3672 .16621 .3731 .17224 .37482 .16782 .36899 Mtetra
.284 .513 .899 r
.16782 .36899 .17224 .37482 .17833 .37636 .1739 .3706 Mtetra
.304 .529 .905 r
.1739 .3706 .17833 .37636 .18447 .37773 .18003 .37205 Mtetra
.323 .543 .911 r
.18003 .37205 .18447 .37773 .19066 .37893 .18621 .37332 Mtetra
.341 .557 .915 r
.18621 .37332 .19066 .37893 .19689 .37997 .19244 .37443 Mtetra
.358 .571 .92 r
.19244 .37443 .19689 .37997 .20317 .38086 .19871 .37538 Mtetra
.375 .584 .924 r
.19871 .37538 .20317 .38086 .20949 .38159 .20503 .37617 Mtetra
.391 .596 .927 r
.20503 .37617 .20949 .38159 .21586 .38216 .21139 .37681 Mtetra
.406 .607 .93 r
.21139 .37681 .21586 .38216 .22227 .38259 .2178 .3773 Mtetra
.421 .618 .933 r
.2178 .3773 .22227 .38259 .22872 .38288 .22424 .37764 Mtetra
.435 .628 .935 r
.22424 .37764 .22872 .38288 .23521 .38302 .23073 .37784 Mtetra
.448 .638 .937 r
.23073 .37784 .23521 .38302 .24174 .38303 .23726 .37789 Mtetra
.461 .648 .939 r
.23726 .37789 .24174 .38303 .24831 .3829 .24383 .37781 Mtetra
.473 .657 .941 r
.24383 .37781 .24831 .3829 .25491 .38264 .25043 .3776 Mtetra
.485 .665 .942 r
.25043 .3776 .25491 .38264 .26155 .38224 .25708 .37725 Mtetra
.496 .673 .943 r
.25708 .37725 .26155 .38224 .26823 .38172 .26376 .37677 Mtetra
.507 .681 .944 r
.26376 .37677 .26823 .38172 .27494 .38108 .27047 .37617 Mtetra
.518 .688 .944 r
.27047 .37617 .27494 .38108 .28169 .38031 .27722 .37544 Mtetra
.528 .695 .945 r
.27722 .37544 .28169 .38031 .28847 .37943 .28401 .37458 Mtetra
.538 .701 .945 r
.28401 .37458 .28847 .37943 .29528 .37842 .29082 .37361 Mtetra
.547 .707 .945 r
.29082 .37361 .29528 .37842 .30212 .3773 .29767 .37252 Mtetra
.556 .713 .945 r
.29767 .37252 .30212 .3773 .309 .37607 .30455 .37131 Mtetra
.565 .719 .945 r
.30455 .37131 .309 .37607 .3159 .37473 .31146 .36999 Mtetra
.573 .724 .944 r
.31146 .36999 .3159 .37473 .32284 .37327 .31841 .36856 Mtetra
.582 .729 .944 r
.31841 .36856 .32284 .37327 .3298 .37171 .32538 .36701 Mtetra
.59 .733 .943 r
.32538 .36701 .3298 .37171 .3368 .37003 .33238 .36536 Mtetra
.597 .738 .942 r
.33238 .36536 .3368 .37003 .34382 .36826 .33941 .36359 Mtetra
.605 .742 .941 r
.33941 .36359 .34382 .36826 .35086 .36637 .34646 .36172 Mtetra
.612 .746 .94 r
.34646 .36172 .35086 .36637 .35794 .36439 .35355 .35974 Mtetra
.619 .749 .939 r
.35355 .35974 .35794 .36439 .36504 .36229 .36066 .35765 Mtetra
.626 .753 .938 r
.36066 .35765 .36504 .36229 .37216 .3601 .36779 .35546 Mtetra
.633 .756 .936 r
.36779 .35546 .37216 .3601 .37931 .35781 .37495 .35317 Mtetra
.639 .759 .935 r
.37495 .35317 .37931 .35781 .38648 .35541 .38214 .35077 Mtetra
.645 .761 .933 r
.38214 .35077 .38648 .35541 .39368 .35291 .38935 .34826 Mtetra
.652 .764 .931 r
.38935 .34826 .39368 .35291 .4009 .35031 .39658 .34565 Mtetra
.658 .766 .93 r
.39658 .34565 .4009 .35031 .40814 .34761 .40383 .34294 Mtetra
.664 .768 .928 r
.40383 .34294 .40814 .34761 .41541 .3448 .41111 .34012 Mtetra
.669 .77 .925 r
.41111 .34012 .41541 .3448 .4227 .3419 .41841 .3372 Mtetra
.675 .772 .923 r
.41841 .3372 .4227 .3419 .43 .33889 .42573 .33417 Mtetra
.681 .773 .921 r
.42573 .33417 .43 .33889 .43733 .33577 .43307 .33104 Mtetra
.686 .774 .918 r
.43307 .33104 .43733 .33577 .44468 .33256 .44043 .32779 Mtetra
.692 .775 .916 r
.44043 .32779 .44468 .33256 .45204 .32923 .44781 .32444 Mtetra
.697 .776 .913 r
.44781 .32444 .45204 .32923 .45943 .3258 .45521 .32098 Mtetra
.702 .777 .91 r
.45521 .32098 .45943 .3258 .46683 .32227 .46263 .31741 Mtetra
.707 .778 .907 r
.46263 .31741 .46683 .32227 .47425 .31862 .47006 .31372 Mtetra
.712 .778 .904 r
.47006 .31372 .47425 .31862 .48169 .31486 .47751 .30992 Mtetra
.717 .778 .901 r
.47751 .30992 .48169 .31486 .48914 .31098 .48498 .30601 Mtetra
.722 .779 .897 r
.48498 .30601 .48914 .31098 .4966 .30699 .49246 .30197 Mtetra
.727 .778 .894 r
.49246 .30197 .4966 .30699 .50409 .30289 .49996 .29781 Mtetra
.732 .778 .89 r
.49996 .29781 .50409 .30289 .51158 .29866 .50747 .29353 Mtetra
.736 .778 .886 r
.50747 .29353 .51158 .29866 .51909 .2943 .51499 .28912 Mtetra
.741 .777 .883 r
.51499 .28912 .51909 .2943 .52661 .28982 .52253 .28458 Mtetra
.745 .777 .878 r
.52253 .28458 .52661 .28982 .53414 .28521 .53008 .27991 Mtetra
.75 .776 .874 r
.53008 .27991 .53414 .28521 .54169 .28047 .53763 .2751 Mtetra
.754 .775 .87 r
.53763 .2751 .54169 .28047 .54924 .27559 .5452 .27015 Mtetra
.758 .774 .866 r
.5452 .27015 .54924 .27559 .5568 .27057 .55278 .26506 Mtetra
.763 .773 .861 r
.55278 .26506 .5568 .27057 .56437 .26541 .56036 .25982 Mtetra
.767 .771 .857 r
.56036 .25982 .56437 .26541 .57194 .26009 .56795 .25443 Mtetra
.771 .77 .852 r
.56795 .25443 .57194 .26009 .57952 .25463 .57554 .24888 Mtetra
.775 .768 .847 r
.57554 .24888 .57952 .25463 .5871 .249 .58314 .24317 Mtetra
.779 .767 .842 r
.58314 .24317 .5871 .249 .59469 .24322 .59074 .23729 Mtetra
.783 .765 .837 r
.59074 .23729 .59469 .24322 .60228 .23726 .59834 .23124 Mtetra
.787 .763 .832 r
.59834 .23124 .60228 .23726 .60987 .23113 .60594 .22501 Mtetra
.79 .761 .826 r
.60594 .22501 .60987 .23113 .61745 .22483 .61354 .2186 Mtetra
.794 .759 .821 r
.61354 .2186 .61745 .22483 .62504 .21833 .62114 .21201 Mtetra
.798 .757 .815 r
.62114 .21201 .62504 .21833 .63262 .21165 .62873 .20522 Mtetra
.801 .755 .81 r
.62873 .20522 .63262 .21165 .64019 .20477 .63632 .19822 Mtetra
.805 .752 .804 r
.63632 .19822 .64019 .20477 .64775 .19769 .6439 .19102 Mtetra
.808 .75 .798 r
.6439 .19102 .64775 .19769 .65531 .19039 .65146 .18361 Mtetra
.811 .747 .793 r
.65146 .18361 .65531 .19039 .66285 .18288 .65902 .17598 Mtetra
.815 .745 .787 r
.65902 .17598 .66285 .18288 .67038 .17515 .66656 .16811 Mtetra
.818 .742 .781 r
.66656 .16811 .67038 .17515 .6779 .16718 .67408 .16002 Mtetra
.821 .74 .775 r
.67408 .16002 .6779 .16718 .68539 .15898 .68159 .15168 Mtetra
.824 .737 .769 r
.68159 .15168 .68539 .15898 .69287 .15053 .68907 .14308 Mtetra
.827 .734 .762 r
.68907 .14308 .69287 .15053 .70032 .14182 .69653 .13423 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15401 .20938 m
.15862 .21405 L
s
[(-5)] .14478 .20005 .98815 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54659 .05566 m
.55048 .06094 L
s
[(5)] .53881 .04509 .73632 1 Mshowa
.125 Mabswid
.19074 .195 m
.19347 .19784 L
s
.22799 .18041 m
.23069 .18328 L
s
.26579 .16561 m
.26845 .16852 L
s
.30415 .15059 m
.30676 .15354 L
s
.38256 .11989 m
.38509 .12291 L
s
.42265 .10419 m
.42513 .10725 L
s
.46334 .08826 m
.46577 .09135 L
s
.50465 .07208 m
.50703 .07521 L
s
.1178 .22356 m
.1206 .22633 L
s
.0821 .23754 m
.08493 .24027 L
s
.04689 .25133 m
.04976 .25402 L
s
.58918 .03898 m
.59146 .04219 L
s
.63243 .02205 m
.63466 .02529 L
s
.67636 .00485 m
.67853 .00813 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[58]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00boooool2o`0005?ooooo0038ooooo`?o000000?oooooo`000?ooool0
D_ooool00<Kooooo0_l000001?oooooo0000ooooooooool2o`0005;ooooo0033ooooo`?o00001_oo
ool00ol0003oooooo`00001Aooooo`00X?ooool3o`0001kooooo0_l00009ooooo`?o0000DOooool0
09oooooo00Go0000ooooooooooooooooo`00000Jooooo`?o00002oooool01?l0003oooooooooool0
001@ooooo`00Xoooool00ol0003oooooooooo`0Eooooo`?o00003_ooool01Ol0003ooooooooooooo
oooo000004oooooo002Sooooo`03o`000?oooooooooo01?ooooo0_l00002ooooo`03o`000?oooooo
oooo00cooooo00Go0000ooooooooooooooooo`00001?ooooo`00Woooool4o`0001?ooooo0ol0000C
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C?ooool009oooooo00?o0000oooo
ooooool04_ooool2o`0001Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1;oooo
o`00Woooool5o`0000gooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0Boooool00:oooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
B_ooool00:cooooo0ol00003ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_oo
ool2o`0004cooooo002Zooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo04Wooooo002Wooooo`?o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Sooooo002Uooooo`;o00009_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04So
oooo002Rooooo`?o000000?oooooo`000?ooool09Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo04Oooooo002Oooooo`?o00001Oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0A_ooool009gooooo0_l0000^ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0A_ooool009[ooooo0ol0000`ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0AOooool009Sooooo0_l00002ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool02?ooool2o`0004Kooooo002Eooooo`?o0000=Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo04Cooooo002Cooooo`;o0000>?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo0ol0000eooooo`00T?ooool3o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool00000=?oo
ool008kooooo0ol0000looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool5
o`0000Gooooo00?o0000ooooooooool0<_ooool008_ooooo0ol00003ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03;ooooo001Zooooo`;o00007Oooool2o`0004?ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`07ooooo`Co0000=Oooool006Wooooo00Co0000oooooooooooo00006Oooool3o`0004Go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Ko
oooo001Yooooo`04o`000?ooooooooooo`0001Kooooo0ol00018ooooo`03o`000?oooooooooo00_o
oooo0ol00008ooooo`Go0000=?ooool006Wooooo00Co0000oooooooooooo00005?ooool2o`0000?o
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03ko
oooo001Yooooo`04o`000?ooooooooooo`00017ooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0?_ooool006Wooooo00Co0000oooooooooooo00003oooool2o`00053o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0mooooo`00J_ooool2o`0000gooooo
0ol0001Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?Oooool007Oooooo0_l0
0002ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0looooo`00M?ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0k
ooooo`00L_ooool2o`0005[ooooo00?o0000ooooooooool04Oooool2o`0003cooooo001_ooooo`?o
0000G?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03[ooooo001]ooooo`;o0000
00?oooooo`000?ooool0G?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Wooooo
001Zooooo`?o00001?ooool00ol0003oooooooooo`1Iooooo`03om>k`ol0003ooooo01Cooooo00?o
0000ooooooooool0>Oooool006Sooooo0_l0001Rooooo`;odk_300?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0hooooo`00IOooool3o`0006Cooooo00Cod[c4om>k`ol0003odkg45_ooool0
0ol0003oooooooooo`0gooooo`00H_ooool3o`000003ooooool0003ooooo06?ooooo0_oB_<@00ooC
_LCo0000om>ma00Fooooo`03o`000?oooooooooo03Oooooo001Pooooo`;o0000J?ooool3om:la004
om>naOoC_LCo0000om>naAKooooo00?o0000ooooooooool0=_ooool005gooooo0ol0001Yooooo`;o
d[g600Kod[c4om>naOoC_/Godkk5o`000?oC_/DEooooo`?o0000=oooool005_ooooo0_l0001[oooo
o`?od[g600God[k7om>naOoC_lOodko7o`000002omBoaQKooooo00?o0000ooooooooool0=Oooool0
03Kooooo0ol0000Oooooo`?o000000?oooooo`000?ooool0JOooool2om6ma`03om:ma_oB_/Ood[k7
00?odko700?o0000omBoa_oD_lH05oooool00ol0003oooooooooo`0dooooo`00=Oooool01Ol0003o
oooooooooooooooo000001cooooo0_l0001^ooooo`?odKg70ooB_/L01OoB`<Sodko7om?0b?l0003o
e;o600;oe<775oooool00ol0003oooooooooo`0cooooo`00;oooool5o`0000Gooooo00?o0000oooo
ooooool05oooool3o`0006oooooo0_o@_/T01?oA_LOodKo9om6obOoB_/L2om;0b0;odl3800Go0000
omC1aooD`LOoe<77omC2b@0Fooooo`03o`000?oooooooooo03?ooooo000iooooo`03o`000?oooooo
oooo01Gooooo0_l0001aooooo`?od;k90ooA_lT02?oA`<[od/38om;1bOoB`LWodl38o`000?oC`/Wo
e<770_oD`/TGooooo`03o`000?oooooooooo03;ooooo000eooooo`Co00005Oooool3o`000003oooo
ool0003ooooo06oooooo0_o?_l/01?o@_/Wod;o:om2ob_oA_lT2om70bP?od/7900Godl;9o`000?oC
`/Wodl?:omC2b@02omC3bQKooooo00?o0000ooooooooool0<_ooool003Gooooo00?o0000oooooooo
ool05?ooool2o`0007Cooooo0oo?_l/3om2obP05om31c?oA`<[odL;;om72booB`LT00_oB`//00ol0
003odl?:om?3bP03omC3bQKooooo0_l0000cooooo`00=Oooool5o`0000oooooo0ol0001eooooo`;o
c[o<00Cocko;olo0c?o?`<cod;o:0_o@`L`3om72b`?od/;;00Go0000om?3b_oCa<codlC<omC3bP02
omC4baOooooo00?o0000ooooooooool0<?ooool004Kooooo0ol0001gooooo`?oc[o<0oo?`<`01Oo?
`/god<7<om32cOo@`/godL;;00;odL?<00?od/;;om;4c?l000000ooCa<`3omC4b`03omC6c?oooooo
oooo01Cooooo00?o0000ooooooooool0<?ooool004Cooooo0_l00002ooooo`03o`000?oooooooooo
07Cooooo0_o>`<d01?o>_lcocl7=olo1cOo?`<`2olo2c@?od<;=0ooA`l`01OoAa<god/C<o`000?oB
aLgodlC<00;odlG=00?oe<C;omC6c?oDa/`05oooool00ol0003oooooooooo`0_ooooo`00@Oooool3
o`0007[ooooo0oo>`<d3olo1c@05olo2c_o?`/gocl?>olo3c_o@`/d00_o@a<h01_oA`lcodLC=om74
cOoBaLgo0000om;5c@?odlG=00CodlK>omC6c?oDalgoe<O=5oooool00ol0003oooooooooo`0^oooo
o`00?oooool2o`0007cooooo0_o=`Ll01?o>`<goc/;?olk2coo?`Ld2olo2cP?ocl?>0oo@a<h01Oo@
aLoodLC=om75cooAaLoo000000;od/K>00?odlG=om?6c_oCa/h00ooDald00ooDb<koooooooooo`0D
ooooo`03o`000?oooooooooo02kooooo000looooo`?o0000OOooool3olg1c`05olg2d?o>`/ooc/?@
olk3d?o?`/h00_o?a=001?o?`lkod<C?om34coo@a<h2om35c`?odLG?00Go0000om;6c_oBa/kod/O?
om?6cP02om?7c`03omC7cOoDb<koe<S>01Oooooo00?o0000ooooooooool0;Oooool003[ooooo0_l0
0003ooooo`03o`000?oooooooooo07Wooooo0_o<`M000oo=`LoocL;@olg2d003olk3d0?oclC@0oo@
a<l02?o@aM3od<G?om36d?o@a]3odLG?om76d?l0003od/K>0_oBall3om?7c`04om?8d?oDb<koe<S?
omC8caKooooo0_l0000^ooooo`00=oooool3o`0007oooooo0_o;`]801?o<`M3oc<?Aolc3dOo=`]02
olg4d@04olk3d?o>a=7oc/CAolo4d0;oclGA00?od<C?om35d?o@aM000oo@a]02om76d003o`000?oA
b=7od/O?00;od/S@00?odlO?om?8d?oCb=000ooDb<lGooooo`03o`000?oooooooooo00Kooooo0_l0
000Tooooo`00=Oooool2o`00087ooooo0oo;`]83olc3d@?ocLCA0oo>a=401Oo>aM;oclGAolo6d_o?
a];od<G@00;oclOB00Kod<K@om37dOo@am7odLK@om78dOl00003om;8d006om;9dOoCb=3odlWAom?9
dOoDb<ooe<W@6?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002?ooooo000b
ooooo`Co0000POooool2ol[2d`04ol_2d_o;`m?obl?Colc3d@;oc<CC00CocLCAolg5doo=aM?oc/CA
0_o>aM83olo6dP?oclOB00SoclSCom37dOo@b=;od<SBom78dOl0003odLWBom;8d0;od/WA0ooCbM40
0ooCb]7oe<W@om?:d@0Hooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00008ooo
ool0033ooooo0_l00024ooooo`?ob/;C0oo;`m<3olc4d`05olc5e?o=aM?ocLKDolg6e?o>aM800_o>
am<01?o?a];oclOColo7doo?am82olo8d`?od<SB00GodLWBo`000?oAbM;odLWCom;9d@02om;:dP03
om?9dOoCb]7odl[A00;odl[A00?odl_Booooooooool05Oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0002?ooooo000]ooooo`?o0000QOooool2olW3e004ol[2doo:a=Cob/CDol_3
d`;oblGD00?oc<CColc5e?o<aM@00oo=a]@3olk7d`05olk8e?o?am?oc/SDolk8e?o?b=<00_o?bM@0
1?o@b=;od<WCom39dol00002om79d`?od/[B00Cod/_Com?:dOoBbm;odl[A0_oCbm8Hooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool002[ooooo0ol00026ooooo`;ob<?F
00CobL?DolW4e_o9a=Kob/CD0_o:aMH01?o;aMCoblKFol_6e_o<aM@2olc7e@04olg6e?o=amGocLOE
olk7d`Goc/SD0oo?bM@01Oo?b]God<WCom3:e?l0003odLWC00;odL_D00?od/[Bom;;dooBbm<00_oB
bm801?oBc=?odl_Bom?<d_oCc=8Gooooo`;o00000oooool01?l0003oooooooooool0000Sooooo`00
:?ooool2o`000003ooooool0003ooooo08Gooooo0oo8`mH3olW4eP?ob/GF0oo;a]H3olc7e@05olc8
e_o=amGocLSFolg8e_o>b=@00_o=bMH01?o>b=Coc/WEolk9eOo?bM@2olo:e@;od<[D00?o0000om3;
eOoAbm@00_oAbm@01OoBbm?odLcDom7<e?oBbm;od/cC00?odlcB00?odlgCooooooooool04oooool0
0ol0003oooooo`000004ooooo`;o00009?ooool002Gooooo0ol00029ooooo`;oalCG00Cob<?FolS5
eoo8aMOobLCF0_o9a]L01?o:aMKob/KGol[6eoo;a]H2ol_7e`03olc7eOo<b=Koc<SF00?ocLSF0oo=
bMH01Oo=b]Ooc/WEolk;e_o>bmKocl[E00;ocl_F00?od<[Do`000?o@bmD00ooAbm@01?o@c=KodLcD
om7<eOoBc=<2om;=e004om?<d_oCcM?odlgCom?=e1Oooooo00?o0000ooooooooool09oooool002?o
oooo0_l0002:ooooo`;oa/CH00CoalCGolO5f?o7aMSob<GG0_o8a]P01?o9a]OobLOHolW7f?o:a]L2
ol[8f004ol_7eoo;b=SoblSHolc8eP;oc<WG00CocLSFolc9eoo<bMOocLWF0_o=b]L3olk;eP03olk;
eoo?bmKoclcG00;o00000_o@c=H00ooAbmCod<cFom3<eP02om7<e@05om7=e_oBcMCod/gEom;=eOoC
cM<00_oCcM@Hooooo`03o`000?oooooooooo02Kooooo000Pooooo`?o0000Roooool3olK4f0?oalGH
0oo8a]P3olW7f0?ob/SH0oo;b=P01Oo;bMWoc<WGol_:fOo;b]Woc<WG00;oc<_H00GocL[Golg;f?o=
bmSoc/_Folk;e`03o`000008olo<eol0003od<cFom3<e_o?cMOod<cFom3=e_oAc=D2om7=eP?od/gE
00Cod/kFom?=e?oCc]GodlkE5oooool00ol0003oooooooooo`0Vooooo`007oooool2o`000003oooo
ool0003ooooo08Wooooo0_o5aMX01?o6a=Soa/KJolK6f_o7aMP2olO7fP04olS6f?o8amWob<OIolW7
f0;obLSI00Cob/SHol[9fOo:bMWoblSH0_o;bMT3ol_:f@?oc<_H00?oc<cIolg;f?l000000_l00002
olk<f004olo<eoo?cMSoclgHo`0000;oclgG00CoclgHom3=e_o@c]OodLgF0_oAc]H00ooBcMGod/kF
om;>eP03om?>e@03om;>e_oooooooooo01Gooooo00?o0000ooooooooool09Oooool001oooooo00?o
0000ooooool00000ROooool2olC5f`04olG5f_o5a]_oaLKKolK6fP;oa/OK00CoalOJolO8foo7b=_o
b<OI0_o8bM/01?o9b=WobLWJolW9f_o:bMT2olW:fP04ol_9fOo:bm[ob/_Jol_:f@;obl_J00Coc<_H
o`000?l0003o00000_o=c=T01Oo=cM[oc/cHolk=fOo>cMWoclgH00;oc/gH00?o0000olo=f?o?cMP0
0_o@c]L01Oo@c]SodLkFom7>eooAc]Ood/kF00;odLkF00CodlkEom;>e_oBc]Kod/oF5_ooool00ol0
003oooooooooo`0Uooooo`007_ooool2o`0000;ooooo00?o0000ooooooooool0QOooool3olC5f`?o
aLKK0oo6am/3olO8f`?ob<WK0oo9bMX3olW:fP04olW;foo:bm[ob/cKol[<f`?o000000Coc<cIolc=
f_o<cM[ocLcI0_o=cMX3olk=f@07olg>f_o>cMSoc/kIolk>fOl0003oclkIom3>e`02om3>f0?odLkG
00God<oHom7>e_oAcmOodLoGom;>eP02om;?eQKooooo0_l0000Vooooo`007oooool01Ol0003ooooo
oooooooooooo000008Gooooo0_o3aM`01?o4aM_oa<KLolC6g?o5a]/2olG7g004olK7foo6b=coa/SL
olO8f`;oalWL00Cob<WKolO:g?o7b]cobLWJ0_o8bm/00oo9b][obL_KolW;f`03o`0000?oblcJ00Go
blgKolc=f_o<cM_oc<gKolg=fP02olg>fP03olk=fOo=c][ocLkJ00?oc/kI00Co0000olo>fOo?cmWo
d<kH0_o?cmT00ooAc]Ood<oHom3?f003om7?e`04om7?f?oBcmKod/oGom;?eaOooooo00?o0000oooo
ooooool08oooool001kooooo0_l00004ooooo`03o`000?oooooooooo083ooooo0_o2a]d01?o3aMco
`lOMol?7gOo4a]`2olC8g@04olG7g?o5bMgoaLWMolK8g0;oa/WM00CoalWLolK:gOo6b]goal[L0_o7
bmd00oo8bm_ob<cLo`000002o`000005olW<g?o:c=_ob/gLol[=g?o;c=X00_o;cM/3olc=f`05ol_>
g?o=c][oc<kKolc>foo=c]X00_o=c]/01_o>c]Woc/oJolk?f_l0003ocloIolk?fP?ocloI0oo@cmP0
1_oAcmOodLoHom7?f?oAd=Sod/oGom7@eaOooooo00?o0000ooooooooool08oooool001kooooo00?o
0000ooooool007H01?ooool00ol0003oooooooooo`1mooooo`04ol76g_o2a]go`/KMol;6g@?o`lOM
0oo4b=d3olG9g@?oa/WM0oo6b]d2olO;g@?o00000_o8cMd01?o9c=cobLgMolW=gOo:cM`2ol[=g@04
ol_=foo;c]coblkLolc=f`;oblkL0oo<c]/02Oo<cmcocLkKolg?foo=cm_oc/oJolk?foo?cmWo0000
olk?fP03olo?f@05olo@f_o@cmSod=3Iom3@fOoAcmP00_oAd=P2om7@e`03om7@f?oooooooooo01Go
oooo00?o0000ooooooooool08_ooool001kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1kooooo`?o`LKN00Co`/KMol;7g_o2amko`lOM0_o3b=h01?o4b=goa<WNolC9g_o5bMd2olG:
gP04olK9gOo5bmkoaL_NolK:g@?o00000_o7c=h3olS=g@?obLgM00GobLkNol[=gOo9c]gobLkMol_>
g002ol[?g@04ol_>g?o;cmcobloLolc>f`;oc<oL0oo=cm/01?o>cm_ocM3Kolg@fol00002olk@f`05
olo?fOo?d=[ocm3Jolo@f_o@d=T00_o?d=X01?oAd=Sod=3Iom3@fOoAd=L2om7@f1Oooooo00?o0000
ooooooooool08Oooool001kooooo0_l000000ooooooo001nooooo`04ooooo`03o`000?oooooooooo
07Wooooo0_noa]l01?o1a]ko`LOOol77goo2amh2ol;8g`04ol?8g_o3bMoo`lWOolC9gP;o`l[O00?o
aL[NolC;goo4bml00ol000001?o6bmkoa/cOolK<goo7c=h2olO=g`04olS=gOo8c]kob<kNolW=g@;o
bLkN0oo9c]d01Oo9cmkob/oMol[?g_o:cmkobloL00;obloM00Ooc<oLolc@gOo<d=gocLoKolc@g?o<
d=gocM3K00;ocM3L00?o0000olk@foo>d=/01oo?d=X2om3@f@?odM3H5oooool00ol0003ooooooooo
o`0Qooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Kooooo0_nna^00
1?noa]oo_lOQoko7hOo1aml2ol39h@04ol;8goo1b^7o`L[Qol?9g`;o`/_Q00?o`l[Ool?<hOl00000
0_l000001Oo4c>3oaLcOolG=h?o5cN3oa/cO00;oa/gP00CoalgOolO>goo7c]oob<kN0_o7c]l01?o9
c]kob<oOolS?goo9c]d2olW?gP?ob/oN00Gob]3Nol_?gOo;d=kobm3Nolc@g@02ol_@g@03olc@g?o<
d=gocM3L00;ocM3L00GocM7Mo`000?o=dMcocM7Lolo@fP02olk@f`?ocm3J00Cocm7Kom3@fOo@dM[o
dM3H0_oAd=TGooooo`03o`000?oooooooooo023ooooo000Nooooo`05o`000?ooooooooooooooool0
07h01_ooool00ol0003oooooooooo`1cooooo`;o_LKR00Go_/KPokk8h_nnb>;o_lOQoko9hP03ol39
h@?o`L[Q0_o2bn43o`000004ol?<hOo4c>3oa<cPolC<h0?oaLgP00GoaLkQolK=h?o6c^7oa/kQolO>
g`02olK?h@03olO>goo7cn3oaloP00?ob<oO00CobLoNolW@goo9d=oob/oN0_o:d=h3ol_@gP04ol[@
goo;d=gobm7Nolc@g@;oc=7M00GocM3LolgAgOo=dMgocM7Lo`000002olgAg004olk@foo>dMcoc]7L
olo@fP;ocm7K0_o@dMX01?o?dM[odM3Iom3AfOo@dMTFooooo`;o00008Oooool001gooooo00?o0000
ooooooooool00oooool2o`00TPGooooo00?o0000ooooooooool0L?ooool01?nlan;o_LKRokg6h_nm
a^83okk8hP?o_lWR00Co`<WQol3:h_o0b^;o`L[Q0ol00002ol;<hP04ol?<hOo3cN;o`lgRolC<h0;o
a<gQ00?oaLgPolG>hOo5c^400oo6c^44olK?h@04olO?h?o7d>7oam3QolS?g`;ob=3P00CobM3OolS@
h?o8d>3ob]3N0_o9d=l01oo;d=kob]3Ool[@goo:dMoobm7Nol_Agoo<dMd00_o<dMh01?o=dMgoc=7M
olcAgOl00002olgAg004olgAgOo>dMcoc]7LolkAg0;ocm7K00God=7JoloAf_o?dM[ocm7Kom3Af@02
om3AfQKooooo00?o0000ooooooooool07oooool001gooooo00?o0000ooooooooool00oooool00ol0
08Oo002Booooo`05ooooo`03o`000?oooooooooo06gooooo00Go^lOSokc7h_nlan;o_<ORokg6hP02
okg8h`04okk8h_nnbN?o_/WSoko9hP;o_l[S00Co`<[Ro`000?l0003o`L_R0_o1c><01?o2c>;o`/gS
ol;=hoo3cN82ol?>h`04olC=hOo4c^;oa<kRolG>h@;oa<oR00?oa/kQolG?h_o5cn800oo6cn43olO@
h@05olO@h_o8d>3oam7QolOAhOo8d>000_o8dN401?o9d=oobM7PolWAh?o:d=l2ol[Ag`;obm7O00Go
b]7OolcAg_o;dMkobm7NolcAg@02olcAgP03o`000?o=dMgocM7M00?oc]7L00Cocm7KolkAg?o>dMco
cm7J0_o?dM/4om3AfQKooooo00?o0000ooooooooool07_ooool001gooooo0_l00005ooooo`03o`01
U?l009;ooooo00Gooooo00?o0000ooooooooool0Joooool3ok_7h`04okc7h_nlb>Co_<STokg8h`;o
_LWT00?o_/WSokk:i?nnb^@00ol000001?o0bn?o`<cTol3<i?o1c><2ol7=i003ol;=hoo2c^Co`/kT
00?o`lkS00Coa<kRol??hoo3cn?oa<oR0_o4cn<01?o5cn;oaM3RolG@h_o6cn42olK@hP03olO@hOo7
d>;oam3R00?oam7Q00Goam7RolSAhOo8dN7ob=7QolWAh002olWAh@03ol[Agoo9dN3obm7O00;ob]7O
0oo;dMh01Oo;d]ooc=7NolcAg_o<dMko000000;ocM7M00?oc]7LolgAg?o=dMd00oo>dM`3oloAf`?o
d=7J5oooool00ol0003oooooooooo`0Mooooo`002Oooool3o`0000?ooooo0ol00004ooooo`;o0000
1Oooool00ol0003oooooooooo`04ooooo`03o`00R?l00ICooooo00Kooooo0_l0001Zooooo`;o^/OT
00Co^lOSok_8iOnkb>Go_<ST0_nlbND00onmbNCo_L_Uo`000002o`000005okk<iOnobnCo_lgUoko=
iOo0c>@00_nocND01?o1cNCo`LkUol7>iOo2c^@2ol7?i004ol?>hoo2cnCo`/oTol??h`;o`m3T00Co
a<oSolC@i?o4d>CoaM3R0_o5d><01?o6d>;oaM7SolGAhoo7d>82olKAhP03olOAhOo7dN;oam7R00?o
b=7Q00Coam;RolWAhOo8d^7obM7P0_o9d^401?o:dMoob];Pol[Bh?o;dMh3ol_Bg`04olcAg_o;d]oo
bm;Oo`0000;oc=;N00?ocM7LolgAgOo=dMd00oo>dM`01_o?dM_oc]7KolkAfoo@dM[ocm7JoloAfaKo
oooo00?o0000ooooooooool07Oooool000[ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`03UOl02I_ooooo00Oooooo00?o0000ooooooooool0IOooool2okS7i@04ok[7i?nib>Go^LSU
ok_8i@;o^lWV00Co_<WUo`000?l0003o00000_nmc>H00onnc>Go_LgVoko=i@05oko=i@?o`LkU0oo1
cn@3ol;?i005ol;@iOo3d>Co`m3Uol?@iOo4d>@00_o4dN@00oo5d>?oa=7TolCAi003olGAh`04olKA
h_o6dN?oa]7SolOAhP;oam;R00Kob=7QolOBh_o7d^;oam;RolSBhOo8d^83olWBh@03ol[Bh?o9d^3o
bM;P00?obm;O00Cob];Pol_Bgoo;d]oo00000_o<d]h3olgAg@?oc]7L00KocM7MolkAfoo>dMcoc]7L
oloAf_o?dM/Gooooo`03o`000?oooooooooo01cooooo0002ooooo`Go00000oooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo0_l00007oooo
o`03o`00R_l00iGo01NU00Sooooo00?o0000ooooooooool0H_ooool2okO7iP04okS7iOnhb>Ko^<SV
okW8i@;o^LWV0ol00002okc;iP?o_LcV0onmcNH01?nocNGo_/kVokk>i_nocND2oko>iP04ol7>iOo0
cnGo`<oUol7?i0;o`M3U00?o`/oTol;@iOo2d>D00oo3d>D01Oo2dNGoa=7Tol?AiOo3dNGoa=7T00;o
a=;T00CoaM7SolGBi?o5d^Coa]7S0_o6d^@00oo7d^;oa];SolKBh`03olOBhP?ob=;R00CobM;QolSB
h_o8d^;obM;P0_o9d^400oo;d]oob];Pol[Bh003ol_Bg`04o`000?o<d]kobm;NolgAg@;oc=;N00Co
c]7LolgAgOo=dMgocM7M0_o>dM`3oloAfaKooooo0_l0000Mooooo`002_ooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000009ooooo`04
o`00TOl01IOo01j[o`0NZ`Oooooo00?o0000ooooooooool0Goooool2okK7i`05okO7i_ngb>Oo]lSW
okS8i_nhbNL00ol00003ok[;i`04okc;i_nkc>Oo^lcWokg<iP;o_<gW00Co_LgVokg>ionmc^Oo_/kV
0_nnc^L01?noc^Ko_loVoko?i_o0cnD2ol3@iP04ol7@iOo1d>Ko`M3Vol;@i@;o`]7V00?o`m3Uol;A
iOo2dND00oo3dND01Oo3d^Koa=;TolCBiOo4d^GoaM;T00;oa=;U00?oa];TolGBi?o5d^@00oo6d^<0
0oo7d^;oam;SolSBhP02olSBhP04olOBhoo8d^;ob=;RolSBhP?obM;Q0oo:d^03ol_Bg`03o`000?o;
d]oobm;O00?oc=;N0oo=dMd3olkAg0?ocm7K5_ooool00ol0003oooooooooo`0Kooooo`002_ooool0
1?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00000oooool2o`0000Sooooo
00Co0025o`00TOl04j?o01j[2?ooool00ol0003oooooooooo`1Looooo`;o]<OX00Co]/OWokK8j?nf
b>So]lSW0ol000001OnhbnSo^L_WokW;ionibnOo^/_W00;o^/cX00Co^lcWok_=j?nkcNSo_<gW0_nl
c^P01?nmc^Oo_LoWokg?ionnc^L2okk?i`04oko?i_nod>Oo_m3Wol3@iP;o_m7W00Co`M3Vol7Aioo1
dNOo`]7V0_o1dNH01?o2dNGo`];Vol;Bi_o3dND2ol?BiP?oa=;U00Go`m;VolCBiOo4dnGoa=?UolGB
i002olGCi@06olKBhoo6dnCoa]?TolOBhoo6dn?ob=;R0_o7d^<4olSBhP04olWBhOo8d^;ob=;Rol[B
h0;obM;Q00Cobm;Ool[Bh?o;d]oo00000_o;d]l3olcBgP?ocM7M0_o>dM`01?o=dMcocm7KolkAfoo>
dM/Fooooo`03o`000?oooooooooo01[ooooo0009ooooo`;o00000oooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool01?l00I?o00NHo`0K
ZOl08Jd8ooooo`03o`000?oooooooooo05Wooooo0_nca^P00ondanSo]<SYokC8j@03o`000003okO9
j?ngbnWo^<_X00;o^<_X00Co^L_WokW<j?nic>So^/cX0_njcNP01?nkcNSo^lkXok_>j?nlc^P2okc?
j004okg?ionmd>So_M3Xokk?i`;o_]3X00Co_m3WokkAj?nndNSo_m7W0_nodNP01?o1dNOo`=;Wol3B
ioo1dNH2ol7Bi`03ol;Bi_o2d^Oo`];W00?o`m;V00Goa=;Uol?Bi_o3d^Ko`m?VolCCi@02olCCiP06
olGCiOo4dnGoa=?UolKCi?o5dnCoa]?S0_o6dn@00oo7d^?oam?SolOCh`03olSBhP04olOChoo8d^;o
b=;RolSBhP;obM;Q0oo:d^001Ol0003obm;Ool_Bgoo:d]ooc=;N00;obm;N00?ocM7MolcAgOo>dM`0
0_o=dM`01?o=dMgoc]7KolkAg?o>dM`Fooooo`03o`000?oooooooooo01Wooooo000:ooooo`04o`00
0?ooooooooooooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool02?ooool01Ol007oo
006Co`0EY?l06jWo02ff00Sooooo00?o0000ooooooooool0E_ooool2ok;6j@03ok?6j?ncb>Wo0000
00;o000000?o]<WZokK9jOnfbnX00ongbnT01?nhbnSo^<cYokS<jOnic>P2okW=j@04ok[=j?njc^Wo
^/kYok_>j0;o^loY00Co_<oXokc@jOnld>Wo_M3X0_nld>T01?nnd>So_M7YokgAjOnndNP2okkAj@04
okoAj?nod^So_m;Xol3Bi`;o`=;X0oo1d^L01?o2d^Oo`M?Wol7Cioo3d^H2ol;Ci`03ol?Bi_o3dnKo
`m?V00?oa=?V00Ko`m?VolCCiOo4dnGoa=?UolGCi?o5dnD3olKCi004olOChoo6dn?oa]?SolSBhP?o
am?S0oo8d^82olWBh@04ol[Bh?o9d^3obM;Po`0000;ob];O00Cob];Pol_Bg_o;dMooc=7M0_o<dMh0
0oo=dMcocM7MolgAg@03olkAg1Kooooo00?o0000ooooooooool06Oooool001cooooo0_l0000:oooo
o`06o`00S_l02I[o01f[o`0S[ol0;KKo03Bk1oooool00ol0003oooooooooo`1Aooooo`05ojo6jona
a^[o/LKZok76j_nba^T00ol00002ok?9j`03okC9j_ndbn_o]/_Z00;o]/_Z00Co]l_YokO<j_ngc>[o
^<cY0_nhcNX01?nicNWo^LkZokW>j_njc^T2ok[?jP04ok_?jOnjd>[o^]3Zokc@j@;o^m3Z00?o_=3Y
okcAj_nldNX00onmdNT01?nndNWo_];YokkBjOnod^P2okoBj@04ol3Bj?nodnSo_m?Xol7Bi`;o`=?X
00?o`M?Wol7Cj?o1dnP00oo2dnL01?o3dnKo`m?Wol?Cioo4dnH3ol?CiP03olCCiOo4dnKoaM?U00;o
aM?U00Coa]?TolGCi?o5dnCoa]?S0_o6dn@3olOCh`?ob=;R00CobM;QolSBh_o8d^;obM;P0_o9d^40
0ol0003ob];Pol[Bh003ol_Ag`?oc=7N0oo=dMd2olkAg003olgAg?oooooooooo01Cooooo00?o0000
ooooooooool06?ooool001cooooo00?o0000ooooooooool02_ooool01_l008ko01RVo`0MZol0:kCo
032ho`0k`0Oooooo00?o0000ooooooooool0C_ooool01?n^aN_o[lK[ojo6jon_a^/3o`000005ok;8
j_nbbN_o//W[ok?9joncbn`00ondbn/01?nfbn[o]Lc[okG<jongc>X2okK=j`04okS=j_ngc^_o]lk[
okW>jP;o^<o[00Co^/oZokW@jonid>_o^]3Z0_njd>/01?nkd>[o^m7[ok_AjonldNX2okcBjP04okgA
jOnmd^[o_M;ZokkBj@;o_M;Z00Co_m;YokkCjOnndnWo_m?X0_nodnT3ol3Cj0?o`M?X00Co`]?Wol7C
j?o1dnSo`m?W0_o2dnL3ol?CiP;oa=?V00Go`m?VolGCiOo4dnGoa=?UolGCi002olGCi@?oa]?T0oo7
dn<00oo8d^;oam;RolOBh`03olSBhP;obM;Q00Co0000ol[Bh?o:d^3ob];P0_o;dMl01Oo:dMooc=7N
ol_Ag_o;dMkocM7M00;oc=7M00?oc]7LolgAg?o=d=`05Oooool2o`0001Wooooo000Looooo`03o`00
0?oooooooooo00[ooooo00Ko002?o`05U_l06:Ko02F`o`0b^_l0=kd2o`12a0Kooooo00?o0000oooo
ooooool0Boooool2ojc5k006ojk5jol0003o0000o`000?n_anco/<O[0_n`bN`00onbbN_o//[/ok;:
k002ok?;k004okC;jondc>co]<c/okG<j`;o]Lg/00Co]/g[okK>k?nfc^co]lk[0_ngcn`01?nhcn_o
^=3/okS@k?nid>/2okWAk004ok[@jonjdNco^]7/ok_Aj`;o^m;[00Co_=;Zok_Bjonkd^_o_M;Z0_nl
dn/01?nmd^[o_M?ZokgCj_nndnT2okkCjP?o_m?Y00Co`=?XokoCjOnodnWo`M?X0_o0dnP00oo1dnSo
`MCXol7Dj003ol;Ci`03ol?Ci_o3dnOoa=?V00?o`m?V00?oa=?UolCCi_o4dnH00oo5dnD01?o6dnCo
aM?TolGCi?o7dn<2olKCh`03olOBh_o7d^?oam;S00?ob=;R00KobM;QolSBhOl0003ob];PolWAh?o;
dMl3ol[Ag`?obm7N0_o<dMd00oo=dMcocM3Lolg@g00Fooooo`03o`000?oooooooooo00Gooooo0ol0
000?ooooo`006oooool00ol0003oooooooooo`0<ooooo`08o`00Sol05:;o01ZWo`0]]_l0<[[o03k2
o`12a?l2BLP6ooooo`03o`000?oooooooooo04Sooooo0_n[aN`3o`0000;o[/O/00Co[lO/ojo8kOn_
b>go/<W/0_n`b^d00onbb^co/L_]ok?<k002ok?<k004okC<k?ndcNgo]<g]okG=k0;o]Lk]00Co]/k/
okK?kOnfcngo]lo/0_ngd>d00onhd>co^=7/okSAk003okWAk004ok[Ak?njd^co^];/ok_Bj`;o^];/
00?o^m;[ok_Ck?nkdn`00onldn/01?nmdn[o_M?[okgCjonndnX2okgCjP04okoCjOnne>[o_]CZokoC
j@;o_mCY00?o`=?Xol3DjOo0e>T00oo1e>P01Oo2dnOo`]CXol;Dj?o3dnOo`]?W00?o`m?V00Go`m?W
olCCi_o3dnKo`m?VolGCi@02olCCi@?oaM?T00?oa]?SolKBi?o7d^<00_o7d^<01oo6d^?ob=;RolOB
h_o7d^;ob=;QolSAhOl000000_o9dN03ol[Ag`Cobm7N00?oc=7Molc@gOo=d=`00_o=d=`Fooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`006oooool00ol0003o
ooooooooo`0<ooooo`06o`00R_l0097o01bYo`0R[_l0;KKo03Bk0_l0ALH2o`U?c0Gooooo00?o0000
ooooooooool0@oooool01?nXa>koZLC]ojW4kOnYa>d2o`000004oj_6kOn/a^go[<K]ojk7k0;o[/S]
00Go[lS]ojo:k_n_b^ko/<[]ok3;kP03ok7;k@04ok?<k?nbcNgo//g]okC=k@;o]<k]00Co]Lk]okG?
kOnecngo]/o]0_nfd>d01?ngd>go]m7]okOAkOnhdN`2okSAk@04okWAk?nhd^go^=;]ok[Bk0;o^M;]
00?o^];/ok[Ck?njdn`00onkdn`01?nldn_o_=?/okcCk?nmdn/2okcDj`03okgCj_nme>_o_MC[00?o
_]CZ00Co_mCYokoDj_noe>[o`=CY0_noe>T01Oo1e>So`=CYol3DjOo2e>So`MCX00?o`]?W00Co`m?V
ol?Cioo3dnOo`]?W0oo3dnH3olCCi@03olGCi?o5dnGoa];T00;oaM;T00?oam;SolKBhoo6d^<01?o7
d^82olSAh@03o`000?o9dN3obM7P00?ob]7O0oo;dMh3olc@g@?ocM3L5Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00cooooo000Kooooo`;o00003_ooool00ol008[o01JTo`0LZ@02
o`0_^005o`11`ol0ALKo0dc:o`U?c?lAE]001Oooool00ol0003oooooooooo`10ooooo`;oY/?^00Oo
Z<C^o`000?l0003o0000ojW6k_n[a^goZlO^00?o[<S^00Co[/S]ojk9k_n^bNko[l[^0_n_bnh2ok3;
kP04ok7;kOnacNko/Lg^ok;=k@;o//k^00Co]<k]ok??k_nccnko]Lo]0ondd>h01_nfd>go]M3^okG@
k_ngdNgo]]7^okSAk@;o]m;^0_nhd^d3okWBk@?o^]?/1?nkdn`01?nldnco^mC/ok_Dk?nle>/2okcD
k0?o_MC[00Co_]CZokkDjonne>_o_mCZ0_nne>X3okoDj@?o`=CY0_o1e>P01?o2dnOo`]?Xol;Cj?o3
dnL3ol;Ci`?o`m?V00Goa=?UolCCi_o4dnKoaM?UolCBi@03olGBi0?oa];S0oo7d^801?o8dN7oam7Q
o`000?o9dN02olSAh007ol[Agoo9dMoobM7Ool_Ag_o;d=kob]3Nolc@g@02ol_@g@03olg@g?o<d=co
oooo01Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`001oooool3o`00
00Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0>ooooo`07o`00Rol05ZCo01j[
o`0_^?l0=kgo0473o`17b002o`YBcP;o65_C1?ooool2o`0003kooooo0_nU`^h3o`0000;oZ<G^00?o
ZLK^ojW7konYanl00_n[anh01?n/b>ko[<W_ojc9kon^bNh3ojg;k`05ojo;k_n_c>oo[lc_ok3<k_na
cNh00onac^l01?nbc^ko//o_ok;?konccnh2ok?@k`04okC@k_ndd>oo]=3_okG@kP;o]M7^00?o]]7^
okKBk_nfd^h00ongd^h01Onhd^go^M;]okWCkOnidngo^]?/00;o^]?]0onkdn`01?nje>go^mC/ok_D
k?nke>`3okcDk004okgDjonle>co_=C/okkDj`;o_MC[00Co_]CZokkDjonne>_o_mCY0_noe>X00oo0
e>Wo_mCYol7Dj002ol3Dj003ol;Cj?o1dnSo`M?X00?o`]?W0oo3dnH00oo2dnKoa=?Vol?BiP03olCB
i@?oaM;T0oo6d^<00oo7d^;oam7RolKAhP02olOAh@07o`000?o8dN3ob=7PolSAh?o9dMoobM3Ool_@
gP02ol[@gPCobm3M0_o<d=`Fooooo`04o`000?ooooooooooooooo`Co00003oooool000Sooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool03_ooool03?l008co00^Jo`0HYOl0;;Ko03:io`0n`_l0@lGo0dk<o`YB
c_lAF=;o65_CoaiQePGooooo00?o0000ooooooooool0>?ooool2oj;1k`?o00000_nUa>l2ojK4k`04
ojS5k_nXa^ooZ<K_ojW7k`;oZLS`0_n[bNl01?n/bNoo[<[_ojc:kon]bnl2ojg<l003ojo<kon_cO3o
/<g_00;o/<g_0onac^l3ok;?k`?o/m3_00Co]=3_okCAkonddNoo]M7^0_ned^l01?nfd^ko]];_okKB
kongd^h2okOCkP05okSCk_nidngo^M?^okWCk_njdnd00_nie>d01Onkdnco^]C]ok[DkOnje>go^mC/
00;o^mC]00?o_=C/ok_Dk?nke>`00onle>`3okgDj`?o_]C[00?o_mCZokkDj_nne>X00_noe>T00oo0
e>So`=CYol3Dj@03ol7Cj0?o`]?W00Co`m?Vol;Ci_o2dnKo`]?W0_o3d^H3olCBi@?oaM;T00Goa];S
olGAhoo5dN?oam7RolKAhP03olOAh@04o`000?o8dN3ob=3PolS@h0;obM3O0oo:d=h3ol_@g@03olc@
g?o<cmcoc<oL01Gooooo0_l00002ooooo`03o`000?oooooooooo013ooooo0005o`0000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo0_l0000Aooooo`03o`00S?l06ZOo026/00;o03Bk0_l0A/L2o`=>c0;o6EkE00?o7V7FobEWfOl/
K=`00oooool00ol0003oooooooooo`0cooooo`03oijol?nP`?3oX<3`00?o00000onS`o000onUa>oo
YLG`ojG5l002ojK6l005ojS6konXb?3oZ<S`ojW8l?nYbO000on[b_001?n/b^oo[<_`ojc;l?n]c?02
ojg=l0;o[lg`00Co/<g_ok3>l?n`c_3o/Lk_0_naco001?nbcnoo/]3`ok;@l?ncd>l2ok?Al004okCA
kondd_3o]=;`okGBk`;o]=;_00Co]];_okKCkonfdnoo]m?^0_nfdnl01Onhdnko^M?^okSDk_nhe>ko
^MC]00?o^MC^0onje>d01?nke>go^]C]ok[DkOnke>`2ok_Dk@?o_=C/00Co_MC[okgDk?nme>co_]C[
0_nme>/2okkDjP?o_mCY00?o`=CYol3CjOo0dnT00oo1dnP01?o2dnOo`M?Wol7Cioo2dnH2ol;Ci`?o
`m;V00Coa=;Uol?BiOo3d^GoaM;T0_o4dN@2olGAh`?oa]7R0oo7dN400ol0003ob=3PolS@h003olW@
g`?ob]3N00?obm3Mol_?gOo;cmd00oo<cm`Cooooo`03o`000?oooooo000000;ooooo1Ol0000>oooo
o`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`0@ooooo`0:o`00Q_l008go01ZWo`0Y/_l0=;_o0474
o`16aol0CL_o157>o`aGd@;o6EkE0_lVJM/2oc9agP;ooooo00?o0000ooooooooool0;_ooool01?nJ
_O3oW;k`oibnl?nL__03o`0000;oX<;a0_nR`o001OnS`o3oXlGaoj?5lOnUaO3oYLOa00?oY/Oa00?o
Z<S`ojS9lOnXbO400_nYbO001?n[b_3oZl_aoj_;lOn/bo02ojc<l@03ojg=l?n]c_7o[Lka00;o[/k`
00Co/<k`ojo?l?n_co3o/Lo`0_n`d?001?nbd?3o/M7`ok7Al?ncdO02ok;Bl004okCBl?ncd_3o/m;`
okCBk`;o]=?`00Co]]?_okGCl?nedo3o]]?_0_nfe>l2okODk`03okSDk_nhe>oo^=C_00?o^MC^00?o
^]C]okWDk_nie>h00onje>d3ok_Dk@04okcDk?nke>co^mC/okgDk0;o_=C/0onme>/2okkDjP04okoD
jOnndn[o_]?Zol3Cj@;o_m?Y00?o`M?Xol3Cj?o0dnP00oo1dnL01?o2dnOo`];Wol7Bioo3d^H2ol;B
iP03ol?BiOo3dNGo`m7U00?oa=7T0_o5dN<02_o6dN;oa]3RolK@h_o7dN7oam3Qo`000?o6d>7ob=3P
olO@h?o9d=l2olS?g`03ol[@g_o9cmkobLoN00;obloM1?o<cm`Eooooo`03o`000?oooooooooo01;o
oooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00003ooooo`;o00004_ooool01ol008Ko01JSo`0LZ?l0<KWo03Nmo`11a?l0B<P00_l6
Dll2oaAMe@03ob5Vf_lVJM_o;FoM00;o<W7N0_lmN^800ol0003oooooooooo`0Yooooo`05oiNklOnH
_?7oV;caoiRllOnJ_O000ol000001?nL`?7oW/7aoik1lOnP`_42oj33l@;oX/Ca00?oXlGaoj?6lOnS
a_400_nUao401?nVao7oY/SaojK8lOnXbO42ojS:lP;oZL_a00CoZl_aoj_<lOn[c?7o[<ca0_n/cO43
ojg>l@;o[/oa00Co[lo`ojo@lOn_d?7o/=3`0_n`dO401?nadO3o/M7aok7AlOnbd_02ok;Bl@03ok?B
l?ncdo3o/m?`00?o]=?`0onedo000onfe>oo]]C`okKDl002okODk`04okSDkonge>oo]mC_okWDkP;o
^=C^0onie>h3ok[Dk@03ok_DkOnje>go^]C]00?o^mC/0onle>`3okgDj`03okkDj_nme>_o_]?Z00;o
_]?Z0onodnT3ol3Cj004ol7Cioo1d^Oo`M;Wol;Bi`;o`M;W00?o`];Vol;Ai_o2dNH00oo3dND2olCA
i004olGAhoo5d>?oaM3SolK@hP;oaM3R00?oam3QolK@hOl000000_o7d>001?o7cn3ob<oOolS?goo8
cml2olW?gP?obloM0oo<cm`Eooooo`03o`000?oooooooooo01;ooooo0007ooooo`;o00001?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
4_ooool04?l008Oo01JSo`0U[ol0<KWo03k2o`13aOl0Clgo1U??o`eJdolDGMGo6f?Hob5Vf_lWK=co
;FoMoc=ch?liN>82ocejhP03od=oi?m8PnKooooo02Gooooo0_nB^O400onD^_7oUk_aoiNkl@03o`00
00;oV[oa00?oW<3aoic1l_nL`O800_nN`_800onP`o7oX<Cboj34lP02oj;5lP03oj?6lOnSao;oXlOb
00;oYLSb00CoY/SaojK9l_nVbO;oZ<[b0_nXbo82ojW<lP04oj_<lOn[cO;oZlgbojc=l@;o[<kb00?o
[Lkaojg?l_n]co800_n^co43ojo@l@?o/=7a00?o/M7aok7BlOnad_400onbd_400oncdo3o/m?aok?C
l@03okCCl003okGCl?nee?3o]MC`00?o]]C`00?o]mC_okKDkonge>l00_nge>l00onhe>ko^=C_okSD
k`03okWDkP03ok[DkOnie>ko^MC^00?o^]C]00?o^mC/ok_DkOnke>d00onle>`00onme>_o_=C[okgD
j`02okgCj`?o_]?Z0onodnT01Oo0dnSo_m;XokoBj?o1d^Oo`=;X00?o`M;W00Co`M7Wol;Ai_o2dNKo
`]7V0oo3dND00oo4dNCo`m3TolG@h`02olC@h`?oaM3R0_o6d>401?l0003oaloPolO?h?o7cn03olS?
g`;obLoN00?obloMol[?gOo:cmd00_o<cm`00oo;c]coooooooooo`0Cooooo`03o`000?oooooooooo
017ooooo0008ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001?ooool00ol0003o
ooooooooo`0Cooooo`04o`09Uol06:Co03>jo`0c^P;o04K700Co04o=o`MFdOlEH=Oo5F3G0_lRJM/0
0olWK=co;W7OocAfh@02ocUhhP;oA87V00GoB8?Vodf7iomBRnWoDX_YoeN>jP0Kooooo`04ohbdlOn>
]_7oS[Kaohjfl@;oT;Sa00?oT[Waoi>jl_l000000_l00002oiNmlP06oiVnl_nI_o;oVl7boi_1l_nL
`O;oWL?c0onNa?800onPa?;oX<Kcoj;6l`02oj;6l`03oj?7l_nSb??oXlSc00;oYLWb00CoY/WbojK;
lonVbo?oZ<_b0_nXc?<2ojW=lP04oj_=l_nZc_;oZ/kbojc>lP;o[<ob00?o[Lobojg@l_n]d?800_n^
d?801?n_d?7o[m7bojoAl_n`dO42ok3BlP?o/M;a00?o/];aok;ClOnbdo400oncdo401?nddo3o/mCa
ok?DlOnee?02okCDl005okKDl?nee?3o]MC`okKDkonfe?000onge>l3okSDk`03okWDk_nhe>ko^=C^
00?o^MC^0onje>d3ok_Dk@05okcDk?nke>co^mC/okcDjonldn/00onmdn/3okkCjP03okoCjOnnd^Wo
_];Y00?o_m;X0_o0d^P01Oo1d^Oo`M7Wol7Aioo1dNOo`]7V00;o`M7V00?o`m7Uol;@iOo3d>@00_o3
d>@3olC@h`03olG@h_o5cn;oa]3Q00;oa/oQ00Oo0000olO?h?o7cn3oaloPolS?goo8c]oobLoN00;o
bLkN00Gob/oMol[>gOo:c]goc<oLol_>g00Fooooo`03o`000?oooooooooo013ooooo000Iooooo`;o
00005_ooool02?l06ZGo026[o`0c^_l0>l3o04K7o`1=c?l0D/oo25SB0_lEH=L2ob9Yf`;o;g?P00?o
=7KQocYkholoOnD00_m4PNH2odj9j@;oDX_Y00GoEhkZoe^BjomKT^_oGiG/ofBHk@02ofNKkP_ooooo
00?oOZcaoh6^lOn1[_400on4/?42ohNal@04ohVclOn<]?7oS;Caohjfl@;oS[Sb0ol000001?nC^_;o
UKcboiFmlonE_O<2oiNnl`;oVKob00GoVl7boi_2lonK`_?oWL?coik4lP02oik5l`;oX<Kc00CoX/Kc
oj;8lonRb??oXlSc0_nSbO<2ojG:l`04ojK;lonVc??oY/ccojS<l`;oZ<gc0_nYcO<01?nZc_;oZ/kc
oj[>lon/co82oj_@l`03ojg@l_n]d??o[M3c00;o[]7b0on_dO83ok3BlP04ok7BlOnado;o/M?bok;C
l@;o/]?b00?o/m?aok;DlOnbe?400once?400onde?3o]=CaokCDl@03okGDl0;o]]C`0onge>l00onh
e>oo]mC_okODk`03okSDkP?o^MC^0onje>d01Onke>go^]C]ok[DkOnke>co^m?/00?o_=?[00Co_M?[
okcCjonldn_o_]?Z0_nmd^X3okkBj@;o_m;X00?o`=;Xol3Aioo0dNL00oo1dNL3ol7AiP?o`]3U0oo3
d>@00oo4d>?oa<oSolC?h`02olG?hP;oa/oQ00Co0000olO?h?o7cn3oaloP0oo8c]l3olW>gP;ob/kM
0oo;c]`Eooooo`;o00004Oooool001[ooooo00?o0000ooooooooool05Oooool00ol06ZGo02Vbo`0`
]`02o`13a@;o0EC@00Go45oFoaIRf?lMJ=_o8fcMobYag`02obmch0;o>ggU00?o?goUodF4iom:R>P0
0_m>RNT2oe>=jP;oG9C/0_mPUnd00omTV>goIi_^ofNKkP02of^NkP03ofnPkombXnooLZ?_00;oMZG`
0_miZ?000omlZ_7oOZcaogj/l@02oh6^l@03ohB`lOn5/O;oQk?b00;oQk?b00?oR[Gbohbfl_l00000
0_l00003oi6kl`;oTkcc00?oUKgcoiFom?nG`?<00_nG`?<2oiW1l`03oi_2lonK`oCoVl?d00;oWLCc
00GoW/Gcoik6m?nNa_CoX<Odoj;8l`02oj;9m003oj?9lonSb_CoXl[d00;oYL_d00CoY/ccojK<m?nV
c?CoZ<gc0_nWc_@2ojW>l`03oj[>lonZco?oZ/oc00?oZm3c00?o[M3cojcAlon/dO<00_n^dO<01?n_
dO;o[m;bojoBl_n`d_82ok3ClP04ok7Cl_n`do;o/=?bok;ClP;o/M?b0onbe?43ok?Dl@?o]=Ca0one
e?02okKDl003okODkonfe>oo]]C_00?o]mC_0onhe>h3okWDkP04ok[DkOnie>go^MC]ok[Dk@;o^]?]
0_nkdn`01?nldn_o^m?[ok_Cjonldn/2okcBj`?o_M;Z0onnd^T00onod^So_]7Xol3Ai`02okoAi`04
ol7Aioo0dNOo`=7Wol7AiP;o`M3V0oo2d>D00oo3d>Co`loTol??i002olC?h`08olG?h_o4cn;oa<oR
olK?hOo5c^7o0000olO?h?o6c^03olS>g`04olO>goo9c]kob<kNolS>gP;ob/kM0oo;c]`Eooooo`03
o`000?oooooooooo00oooooo000Iooooo`03o`000?oooooooooo01Kooooo00Ko00JBo`0EX?l0<[Wo
03Rmo`13aOl0BlX2o`5Dd007oa1Oe_lGIM[o96kNobA^g_lZLMoo<7KRocIki002oc]mi@04od62iom6
Q^SoBXSXodZ8j0;oE8o[00?oFI?]oebDk?mLU>`00_mPUnd00omTV^koJ9g_ofRMk`02ofbPl0;oL:?`
00?oLjGaogJWlOmfYo400_miZO42ogb/lP03ogn^l_n2/?;oP[3b00;oQK7b00KoQk?bo`000?l0003o
0000ohZglon<^?<2ohnil`03oi6klonA_?CoTKcd00;oTkgd0_nE_o@00onG`??oUl7doiO1m002oiW2
m003oi_3m?nKa?CoVlCd00;oWLGd00?oW/Kdoio7m?nOao@00_nPb?@01?nRbOCoX/[doj;:m?nSb_@2
oj?;m004ojG<m?nVc?CoY/gdojK=m0?oYlkd0_nYco@01?nZco?oZ]3doj[@m?n[d?<2oj_Am0?o[=7c
0on]d_<2ojkBl`03ok3Cl_n_do?o[m?c00?o/=?b00Co/M?bok7Dl_nae?;o/]Ca0_nbe?83ok?Dl@?o
]=Ca00Ko]MC`okCDl?nde?3o]]C`okGDl?nfe>l2okKDl0?o]mC_0onhe>h01?nie>ko^=C^okSDk_ni
e>d2okWCk@;o^]?]00Co^m?/ok[Ck?njdnco^m?[0_nkd^/3okcBj`?o_M;Z00?o_];YokgAjOnndNP0
0_nndNP3okoAi`03ol3Aioo0d>Oo`=3W00;o`M3V00Go`LoVol;@iOo2cnGo`/oUol??i002ol;?i003
olC?hoo3cn?oa<oR00;oa<kR0_o5c^401?l0003oa/kPolK>h?o8c]l2olO>g`?ob<kN00Cob/kMol[=
gOo:cMgoblkL0_o;cM`Eooooo`03o`000?oooooooooo00kooooo000Iooooo`;o00006?ooool02_l0
5j7o01jXo`0b^Ol0@<?o04K7o`1Bcol2Em;o2egFoa5Qf?lGIMX2obA^gP04ob]chOlaN>?o=W_TocIk
i0;o@XCX00?oAXKXod^:j_m@S^/00_mDSn/2oeVCk@05oefFk_mQVNkoHIW^ofFLkomYWo000_m]X_42
og2Tl@03ogBWl_mgZO;oMjWb00;oNZcb0omm[_<00on0/??oPk7coh>al`02o`0000;oR;Gc00?oR[Oc
oh^hm?n;^?@00_n=^_@00on?^oCoTKcdoi6nm@03oi>om0;oU/3d00?oUl7doiS2mOnH`_D00_nI`oD0
0onKa?CoVlKeoi_6m@02oig6m@03oio7m?nOb?GoWlSe00;oX<We00CoX/[doj;;mOnRboGoXl_d0_nS
c?D2ojG=m004ojK=m?nVc_CoY/kdojO>m0;oYlod00CoZLodoj[@m?nZd?CoZ]3d0on[dO@00on/dO?o
[=;dojcBm003ojgBl`;o[]?c0on_do<3ok3ClP?o/MCb0onbe?83ok?Dl@04okCDlOnce?7o/mCaokCD
l0;o]=Ca0_nee?03okKDl0?o]mC_00Co^=C^okODkonge>oo^=C^0_nhdnh3okWCk@;o^]?]00?o^]?/
ok[Bk?njd^`00onkd^/3okcBj`03okgBj_nldN[o_M7Y00;o_M7Y0onndNP01_nodNOo_m3Woko@ioo0
d>Oo`=3Vol7@iP;o`LoV0oo2cnD01?o1cnGo`/oTol;>i?o3cn<2ol?>h`?oa<kR00?oaLkQo`000?o6
c^000_o6c^001oo7c]ooalgOolO=goo8c]kob<gNolS=gOo:cMd00_o9cM`00oo;cMcoblgKooooo`0D
ooooo`03o`000?oooooooooo00kooooo000Iooooo`03o`000?oooooooooo01Sooooo00?o01NQo`0^
]Ol0;[D00_l0B<P01?l0D/oo15WCoa9TfOlBI=T2ob1]gP;o;7KR00?o<GSSocQmiOlmP^L00_m2Q>P2
odf<j`03oe2>jomETNgoEI7]00;oFYG^0_mRVo02ofJNl003ofVOl?m]X_7oKJ;a00;oL:Ca00?oM:Ob
ogNYl_mgZO800_mj[?800omm[_?oOJoco`000002o`000003oh>cm?n6]OCoQ[Gd00;oR;Od00?oRkSd
oh^jmOn=^oD00_n=^oD2ohnlm@04oi6nmOnC_oCoU<3eoiC0m@;oU/7e00?oV<;eoiS4m_nHa?H00_nJ
aOD00onKa_GoW<Ofoic7mP02oig7m@03oio8mOnObOKoWlWf00;oXL[e0onRboD00onSc?GoXlgeoj?=
m@02ojG=m@04ojK>m?nVc_GoY/keojO?m0;oYloe0_nYd?@00onZd?CoZ]7doj_Am002oj_Am0?o[=;d
00?o[M;cojgCm?n]do@00on^do<2ojoCl`03ok3Cl_n`e??o/=Cc00?o/MCb0onbe?800once?7o/]Ca
ok;Dl@03ok?Dl@;o]=Ca0onee?03okKDl004okODkonfe>oo]]C_okODk`;o]m?^0onhdnh2okWCk@03
ok[CkOnid^go^M;]00?o^];/0onkd^/01_nld^_o^m7Zok_Aj_nldN[o_=7YokgAj@;o_M3Y00?o_]7X
okk@j?nnd>P00onod>L00oo0d>Ko_loVol7?iP02ol3?i@06ol;?iOo1cnGo`LoUol7>i?o2c^Co`/kS
0oo3c^<01_o4c^;oa<gRolC=h_o5c^7o0000olK>h0;oa/gO00?oalgOolO=g_o8cMh00_o8cMd3olW=
g0?oblgK5Oooool00ol0003oooooooooo`0=ooooo`006Oooool2o`0001[ooooo00Oo016Ko`0^]Ol0
=k_o04S8o`1@cOl0E=3o15WC00;o4VCI0_lPKMh2obafhP;o>GoW00?o?H;Wod>6jOm8Rn/00_m=S>/2
oe6@k@;oFiO_00?oGi[`of:Kl?mRVo000_mVW_000omZXO7oKZCbofjTlP02og6VlP;oM:Wc00OoN:_c
o`000?l0003o0000ogf_lon0/OCoPK?d00?oQ;Ge00?oQ[KeohRhmOn8^?D00_n;^_D00on=^oGoS[cf
ohjlmP02oi2nmP;oT[of00GoU<3eoiC2m_nD`_KoU/?foiS4mP02oiS5mP;oV/Kf0onLaoH2oig8mP03
oio9m_nOb_KoWl[f00;oXL_f00CoX/_eoj;<m_nRc?KoXlge0_nTcOH2ojG>m@04ojK>mOnVcoGoY/oe
ojO?m@;oYm3e0_nYd?D3oj[Am003oj_Am?n[d_Co[=;d00;o[=;d0on]do@3ojkCl`?o[m?c0_n`e?<3
ok7DlP04ok;Dl_nae?;o/MCbok;Dl@;o/]Cb0once?42okCDl@?o]MC`00Co]]C`okGCl?nedo3o]]C_
0_nfdnl3okOCkP?o^=?^00?o^M?]okSBkOnid^d00_nid^d3ok[Bk003ok_BjonjdN_o^]7[00;o^m7Z
00?o_=7Yokc@jOnld>T00onmd>T01Onnd>So_M3Xokg@j?nod>Oo_/oW00?o_loV0oo0cnD00oo1cnGo
`LkTol7>i002ol;>h`09ol;=hoo3c^?o`lgRol?=h_o4cN;oa<gQolG=hOo5cN3o000000?oa/gO0_o7
cMh3olS=g@;obLgL00CobLcLol_=foo;cM_oblgK5?ooool00ol0003oooooooooo`0=ooooo`002_oo
ool3o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo01Wooooo00Go01>Mo`0KY?l0<;Ko03o1
o`15aP02o`1GdP;o3F;H00Go6fcNob5`golXMN;o;GSTocAmiP02ocUoi`;oA8S[00GoB8_[odj>k?m>
S^coDY;^oeNFk`02oe^Gk`;oGi[`00?oHigaofNPlOmWX?400_m[Xo800om^Y_?oLZSco`000002o`00
00;oN:gd00?oNjodogjam?mn/O@00_n1/o@00on4]OGoQ;KfohNhmP02ohNhmP04ohVjm_n;^oKoRk_f
ohjlmP;oS[kf0_n@_oH2oi;0mP03oiC2m_nD`oKoU<?f00;oU/Cf00GoV<GfoiS6monHa_OoV/Ofoic7
mP02oic8m`;oWLWf00?oWl[foio;m_nOboH00_nQc?H01?nRc?KoX/gfoj;=m_nTcOH2ojC>mP;oYLof
00?oY/oeojK@m_nVd?H00onWd?D3ojSAm@;oZ]7e0on[d_@00on/d_Co[=?dojgCm002ojgCm003ojkC
lon^doCo[]?d00?o[m?c0on`e?<3ok3DlP;o/MCb0onbe?83ok?Dl@;o]=Ca00?o]MC`okCCl?nddo00
0onedo03okKCk`?o]m?^00?o^=?^okOBk_ngd^h00_nhd^d01?nid^go^M;/okWBk?njd^`2ok[Ak0?o
^]7[00?o^m7Zok_@j_nld>T00_nld>T01?nmd>Wo_=3Xokc@j?nmd>P2okg?j0;o_/oW00Co_loVoko>
i_noc^Ko`<oU0_o0c^D2ol7>i003ol;>hoo2cN?o`/gS00Co`lgR0_o4cN401_o5cN3oaLcPo`000?o6
cMooa/cOolO=gP;oalcN00Cob<gMolS<gOo8c=gobLgL0_o9c=`00oo;cM_oblcKol_<f`0Cooooo`;o
00003_ooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool06_ooool00ol04igo02^bo`0b^002o`17a`;o05OB00Wo3F;HoaEX
g?lKK=ko8g;QobQeh_l_N^Go=7gVocZ2j?m0Q^X00_m4R>/2odV=k0;oE9C_00?oEiK_oebIl?mLVO00
0_mPW?400omTWo;oJ:;bofRRlP03o`000004ofnWlomcZ_CoMZcdogJ/m0;oNJoe00?oO;7eogncmOmo
/oD00_n2]?D2ohBfmP03ohNhm_n7^OKoQkWf00;oRK_f00?oS;cfohjnm_n>_oL00on@`?L2oi;2m`03
oiC3m_nEa?OoULCg00;oUlGg00?oV<KgoiW7monIaoL00_nJb?L01OnLb?OoW<Wgoic9monNb_OoWl_f
00;oWlcg0_nQc?H3oj;=mP03ojC>m_nTcoKoY<of00;oYLof0onVd?H00onWd?GoYm7fojOAmP03ojSA
m@?oZ];e0_n[d_D2ojcCm0?o[M?d0on^do@3ojoCl`03ok3Dlon_do?o[m?c00?o/=Cb00Co/MCbok7C
l_nado;o/]Cb0_nbdo82ok?Cl@03okCDlOncdo7o]=?`00;o]=?`00?o]M?`okGCkonednl00onfdnl0
0ongdnko]m;^okOBkP02okOBkP04okSBkOnhdNgo^=7]okWBk0;o^M7/00Co^]7/okWAk?nidNco^]7[
0_njd>/2ok_@jP04okc@jOnlcnWo_<oYokc@j0;o_<oX00?o_LoXokg?ionncnL00_nnc^L3oko>iP?o
`<kU00?o`LkTol7=i?o2cN<00_o2cN<3ol?=hP06olC=hOo3c>7o`lcQolG<h?l0003oa<cP0_o6c=l3
olO<gP;ob<cM0oo9c=`3ol_<faGooooo00?o0000ooooooooool02oooool000?ooooo1Ol00005oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0001gooooo00go01FN
o`0[/_l0>kko04O7o`1?c?l0E=3o263Go`mTf_lEJ=co7FkOob=bhOlYMnCo<7cV00;o=GoW0_m0Q^X0
0om5RncoBho]oe2CkP02oeBDk`;oF9S`00?oGI_aof6Nl_l000000_l00002offWm0;oL:Wd00CoLjce
ogN^mOmg[_GoMjke0_mj/?H2ogfbmP03ogndm_n2]_KoP[Kf00;oQKSf00?oQkWfohRkmon8^oL00_n:
_?L01?n<__OoS[ogohjomon@`?L2oi71m`;oTl?g00?oULCgoiG5monEaOL00_nGa_L3oiW7m`;oV/Sg
00CoW<Wgoic:monLb_OoW/_g0onOc?L2oj7=m`03oj;=m_nRc_OoX/kg00?oY<of00?oYLofojG@m_nU
d?H00_nVd?H3ojOAmP04ojSAmOnXd_KoZ=;foj[Bm@;oZM;e0_n[d_D3ojcCm0;o[M?d0on^do@00on_
do?o[]?cojkCl`03ojoCl`03ok3Dl_n`do;o/=?b00?o/M?b00Go/]?bok;ClOnbdo7o/m?aok;Cl@03
ok?Cl0;o]=?`00Co]M?_okGBkoned^oo]]?_0_nfd^l01Ongd^ko]];^okKBk_ngd^ko]m7]00?o^=7]
00Co^M7/okSAk?nhdNco^M7/0_nid>/2ok[@j`04ok_@j_nkcn[o^loZokc?j@;o^loY0onlcnP00onm
cnOo_LkWokk>i`02okk>iP06oko>i_nncNKo_/gVol3>iOnocNGo`LgT0_o0cN@01Oo2cN?o`LgSol7=
hoo3cN;o`/cR00Co`lcQ00?oa<cPo`000?o6c=l00_o5c=l3olO<gP;ob<cM0oo9c=`3ol_<faCooooo
00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01gooooo00Co00jGo`0]/ol0@lCo04?40_l0Em402Ol8H=Oo
46OKoaiah?lNLN3o97CRob]jiOl`O>Ko=h;Xocf6jP02od68j`;oC97^00?oD9?^oeFFl?mEU_000ol0
00001?mRX?;oIZ?cofJSlomYY?<2offWm0;oL:Wd00?oLjceogN^mOmg/?H00_mj/_H3ogfdmP;oP;Kg
00GoPkOgohFimon5^OOoR;_gohRlm`03oh^mm`;oSKog00CoSl3goi71monA`_SoTL;h0_nCa?L00onE
aOOoULKhoiG6n002oiO7m`03oiW7monIb?SoVLSh00;oVlWg00?oW<[goic;monLboL00_nNc?L01OnO
c?OoWlggoio=monQcOOoXLkg00;oX/kg00?oY<ofojC?monTcoL00onUd?H2ojKAmP?oYm7f0onXd_H3
ojWBm@?oZm;e0_n/do@2ojgCm0?o[]?d0on^do<3ojoCl`?o/=?b0onado85ok;Cl@03ok?Cl?ncd_3o
/m;`00?o]=;`00?o]M;_okCBkondd^l00_ned^l00onfd^ko]]7^okOAk@02okOAk@?o^=7]00?o^=7/
okS@k?nhd>`00onid>/00onjd>_o^/oZok_?jP02ok[?j@05ok_?jOnkc^Wo^lkYokc?j?nlc^P00onm
c^L01?nnc^Ko_LgVokg=i_nncNH2okk=i@03oko=iOnocNCo`<gT00;o`<cT00?o`LgSol7<hoo2c>80
0_o2c>83ol?<h@;oa<cP00Oo0000olG<goo5bmkoaL_NolO<g_o7bmkob<cM00;ob<_M0oo9c=`2ol_<
f`03ol_<f_oooooooooo01;ooooo00?o0000ooooooooool02_ooool000Wooooo1?l00003ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool02Ol049So02R^o`0_]?l0@lCo
04c:o`1GdOl2G]Ko2F;Ioa5Yg002oaiah0;o;7cV00?o<GoWocR4jOlmQ^X00_m2Rn`01om<TNko0000
o`000?l0003oEYSaoeZLl_mOWo800_mRX?82ofJSl`03ofZVm?m]Z?CoKJSd00;oLJ_e0_md[OH01?mg
/?KoN[;fogZbm_mm]?H2ogjem`;oPKOg0_n3^OL01?n6^_OoR;cgohRlmon;_OL2oh^nn0;oSL3h0_n?
`OP01OnA`_SoT/?hoi;3n?nCaOSoULKh00;oU/Kh0_nGaoP00onIb?SoVLWhoiW9n002oi_:n003oic;
monMboSoWL_h00;oW/cg00?oWlggoj3=monPcOL00onQc_L01?nScoOoY<ogojC@monTd?L3ojG@mP?o
Y]7f0_nWdOH3ojSBmP?oZM;e0on[d_D3ojcCm004ojgCm?n^doCo[M?dojgCm0?o[]?c0on_do<3ok3C
lP?o/M?b00Go/]?aok7BlOnad_7o/]?aok;Bl@03ok?Bl004okCBl?ndd^oo]=;_okCBk`;o]=7_0_ne
dNh2okKAkP04okOAkOngd>go]m3]okSAk@;o]m3/0onhd>`00onid>_o^Lo[ok[?jP02okW?jP04ok[?
jOnjc^Wo^/kYok_>j@;o^lkX00?o_<kXokc=j?nmc^L00_nlcNL3okg=iP03okk=iOnnc>Go_lgT00;o
_lcT00Ko`<cTol3<hoo0c>?o`LcSol7<h_o2c>82ol;;h@06ol?<hOo3bn7o`l_QolC<h?o4bmoo0000
0oo5bmh00oo7bmkoal_MolS;g@02olS;g003olW<g?o9bm_oblcK00;oblcJ5Oooool00ol0003ooooo
ooooo`09ooooo`002Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo
0_l0000Oooooo`09o`0@V?l0<KKo036fo`15aOl0C<[o05WBo`9Ne_l;I=[o4FWL00;o7g?R0_l/O>H2
ocV6jP?o000000CoBI7_odfCkomBUo3oDYO`0_mLWO82oenOlP03of>RlomWYOCoIjGd00;oJjOe00?o
KZ[eog:]m_mb[OH00_me[oH2ogRamP03og^cmomn]OOoOkKg00?oPKSh0_n4^_P01?n6^oSoRKghohVm
n?n;__P2ohbon0;oS/7h0_n@`_P01OnB`oSoT/Choi;4n?nDaOSoU/Kh00;oU/Oh0_nHb?P00onIbOSo
V/[hoi[:n002oi_;n003oig;n?nMc?SoWLch00;oW/gh00CoX<ggoj3>monPc_OoXLkg0_nQcoL01OnS
coOoY=3gojC@monTd?OoYM3f00;oYM7g0onVdOH2ojOAmP?oZ=;f0onYd_D3oj_Bm@?o[=?d0on]do@2
ojgCl`;o[]?c0on_do<3ok3ClP03ok7Cl_nad_;o/M;b00;o/M;a0onbd_401?ncd_3o/m7`ok?Al?nd
d^l2ok?Ak`?o]=7_00?o]M7^okG@k_nfd>h00_nfd>d2okO@k@04okO@k?ngcnco]lo/okS@k0;o^<o[
0_nicn/00onicn[o^LkZokW>jP03ok[>j@03ok_>j?nkcNSo_<gX00?o_<gW0_nlcNH00onmcNKo_LcV
okk<i@02okk<i@?o_lcT00?o`<cSol3;hoo1c>800_o1bn83ol;;h@05ol?;hOo3bn3oa<_OolC;gol0
00000oo5bmh00oo7bmgoa/_MolK;g@02olS;g0?obL_K0oo;c=XDooooo`;o00002_ooool000Wooooo
1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0Oooooo`04o`0AVOl0<KKo03Zlo`17a`;o
05K@0_l<Im/2oa]ah@07obQkiOl0003o0000o`000?liQ^[o?h[/odF?kP02odVAk`03odnEl?mCV?7o
F9cb00;oG9gb0_mPXO<00omTY?CoJ:KeofRVm@02ofbYm@03ofn/m_mc[_KoLjkf00;oM[3g0_mi/_L0
1?ml]?OoOkKgognfmon1^?P2oh:in0;oQK_h0_n7_OP01?n9__SoS;ohohc1n?n<`OP2ohk2n0;oT<?h
00?oT/Choi;5n?nBaOP00_nDa_P01?nFaoSoU/ShoiK8n?nHbOP3oi[:n0;oVl_h0onMc?P00onNcOSo
Wlghoio=n002oj3>n004oj7?monRcoOoX/ogoj??m`;oXm3g00CoY=3gojGAmonUdOOoYM7g0onVdOH3
ojOBmP;oZ=;f0onYd_D3oj_Bm@06ojcCm?n/d_Co[=;dojgCm?n/d_Co[M?c0_n]d_<3ojkBl`;o[m;c
00Co/=?bok3Bl_n`d_;o/M;b0_n`d_42ok7Bl@03ok;BlOnbdO3o/]7`00?o/m7`0oncdNl00onddNoo
]=3^okC@kP02okG@kP04okK@kOnfcngo]/o]okK?k@;o]/o/0_ngcn`00onhcn_o^<k[okW?j`02okS>
jP04okW>j_nic^Wo^LkYok[>j@;o^/gY0_nkcNP01?nlcNOo^lcWok_<ionlcNH2okc<iP03okg<i_nm
c>Go_/cU00;o_/_T00?o_lcToko;i?nobn@00_o0bn<3ol7;hP?o`/_Q0_o3bn02olC;g`03o`000?o5
bmkoaL_N00?oa/_M00?oa/[MolS;g?o8bm`00oo9bm/00oo;c=[obl_Jooooo`0Dooooo`03o`000?oo
oooooooo00Sooooo000Hooooo`03o`000?oooooooooo023ooooo00Oo00ZAo`0//?l0@l?o04?3o`1F
d?l0GMGo36OK00?o00000_lXNnD2ocB3j@03oc^8jom1S>goAHo^00;oBi?_00GoD9OaoeFJl_mHW?;o
F9cboefOl`02of6Rm0;oIJGe00?oJJSfoff[m_m]ZoH00_m`[OL00omc[oOoMk;gogNbm`02ogZdm`;o
OKKh00CoOkShoh:in?n3^oSoPk_h0_n5_?P2ohRnn0;oR[oh00GoS<7hohg2nOn?`oWoSl?ioi74n@02
oi75n@;oTlKi0_nEaoT01OnFb?SoUlSioiO8nOnHbOSoV/[h00;oV/_h0onLc?P2oig=n003oio=n?nO
c_SoWlkh00;oX<kh0onRcoL3oj?@m`?oY=3g00GoYM7gojKAm_nVdOKoY]7fojOBmP02ojSAmP?oZM;f
0_nZd_D3oj_Bm@Go[=;d0on]d_<3ojkBl`?o[m;b0_n`d_801On`d_7o/=7aok3AlOnad_7o/M7a00?o
/]7`00Co/m7`ok;@konbd>oo/m7_0_ncd>l2okC@kP04okG@k_ndcngo]<o]okK?k@;o]Lo]00?o]/o/
okK>k?nfc^`00_ngc^`2okS>j`04okS>j_nhcN[o^<gZokW>j@;o^LgY00?o^/gYok[=j?nkcNP00_nj
c>L3ok_<i`03okc<i_nlbnKo_LcU00;o_L_U0onnbn@00onobnCo_l_Sol3;h`02ol3:hP06ol7;h_o1
b^;o`L[Rol;;hOo2b^7o`l_P0_o3b^001_o4bmooa<[Oo`000?o5bmkoaL[NolK;g@;oa/[M0_o8bm`0
1?o8b]cobL_KolW;foo9bm/2ol_;fQ?ooooo0ol00009ooooo`005oooool2o`0002?ooooo00?o00^B
o`0]/Ol0@l<00ol000001?l>JMco5VoPoaach_lTNND2obYmiP;o=XGZ0_m2S^h01Om6T>ooC9C`odbD
l?mAV?7oEYcc00;oFIkc00?oGZ7dof:TmOmRY?D00_mVYoD00omZZOKoKZcgofj/m`02og6_m`;oM;7g
00?oN;?hog^en?mk]OP00_mm]oP01?n0^OSoPk_hoh>lnOn3_?T2ohJmn@;oR;oi0_n;`?T3ohg2n@04
oho4nOnAaOWoTLGioi75n@;oTlKi0_nEaoT00onGb?WoUlWioiO9n@03oiW:n@04oi_;n?nLc?SoW<ch
oic<n0;oW/gh0onOc_P3oj7?n0;oX/og0onSd?L3ojC@m`04ojGAmonVdOKoYm7fojOAmP?oZ=7f00?o
ZM;fojWBmOnYd_D00onZd_D2oj_Bm0Go[=;d0on]d_<01?n^d_?o[]7cojkAlon_d_82ojoAlP05ok3A
l_n`dO7o/=7aok3AlOnadO400_nadO000onbdO3o/]3`ok;@l003ok;@k`05ok?@konccnoo/lo_okC@
k_ndcnh00ondcnd00onecngo]Lk/okG>k003okK>k004okO>jonhc^_o]lg[okO=j`?o^<gZ00Go^LgY
okW<jOnic>Wo^/gXok[<j003ok[<i`03ok_<ionkbnKo^l_V00;o_<_V0onmbnD01_nnbnCo_/[Tokk:
i?nobn?o_/[Sol3:hP;o_l[R00Ko`L[Rol7:hOo1b^7o`/[Qol;9h?o3b^02ol?9g`03olC:gol0003o
aL[N00;oaL[N0_o6b]d01?o8bmcob<[LolS:g?o8b]`2olW;f`?obl_J3oooool3o`0000;ooooo00?o
0000ooooooooool01oooool001Oooooo00?o0000ooooooooool08_ooool3o`000003o`15a?l0E<oo
05[C00;o26KJ00Go5VoPoaieholTNNGo:goWoc:4jP02ocN7j`;o@Xk^0_m8T_02oe:JlP03oeJLlomK
WoCoFiod00;oGj?d00?oHjGeofNXm_mWZ?H00_m[ZoL00om_[_OoL[3gog:`m`02ogFbn003ogRdn?mk
]_SoNkKh00;oO[Sh0_n1^_T01?n3_?WoQ;ciohJnnOn6__T2ohVon@03oh_1nOn<`_WoS<;i00;oS/?i
00CoT<Cioi75nOnBa_WoT/Ki0_nDaoT3oiK8n@;oV<Wi00?oVL[ioiW;nOnIboT00_nKc?P01?nLc?So
W<ghoik=n?nNcOP3oio>n0?oXLoh0_nRcoL3oj?@m`03ojC@monUd?OoYM3g00;oY]7f0_nWdOH3ojSA
mP04ojWBmOnYdOGoZM7eoj[Bm@;oZ]7e00?oZm;doj_Am?n[dO@00on/d_@01On/dO?o[M;cojgAlon]
dO?o[]7c00;o[]7b0on_dO801On`dO7o/=3aok3@lOn`dO7o/=3a00;o/M3`0onbd?001?nbd>oo//o_
ok;?konccnl2ok??kP03okC?k_ndc^ko]<o]00;o]<k]00Ko]Lk/okG=k?necNco]/k/okK=jongcN/2
okK<j`;o]lgZ00Ko^<gZokS<jOnhc>Wo^LcYokW<j?njc>P2okW;j003ok[<ionjbnOo^/_W00;o^l_V
00Co_<_Vokc:iOnlb^Go_L_U0_nmb^@00onnb^Co_L[Tokk:h`02okk9h`05oko:h_nobN;o_lWRol7:
hOo1bN400oo2bN02ol?9g`04olC:g_o4bMko0000olG:gP;oaLWM00?oa/[MolO:g?o8b]`00_o8b]`0
1?o9bm_obL_JolW;f_o;bmX2ol_;f@_ooooo0ol00005ooooo`03o`000?oooooooooo00Oooooo000G
ooooo`;o00008Oooool2o`000005ooooool03I;o02nbo`0i^_l0AlD00_l0E<l2o`QVfP;o677Q0_lV
NnH00olbQ>[o>HW/ocn=kP02odB@k`;oBIC`0_mBV_800omGWO?oG:7doebQm002of2Tm@03ofBWm_mX
Z_OoJ:[g00;oK:cg00?oL:ohog>an?mc/OP00_mf/oP2ogVen003ogbgnOmo^OWoOkWi00;oP[_i00Co
Q;ciohFmnOn5_OWoQkoi0_n9`OT00on<`_WoS<?iohc3n@02ohk4n@;oT<Gi00GoT/Kioi;7nOnDb?Wo
U<SioiK8n@02oiK9n@;oV<[i00?oVL_ioi[;nOnJboT00_nKc?P00onLcOSoWLghoig=n002oik>n0;o
X<kh0onQcoP3oj;?m`;oY=3g0onUd?L3ojKAmP;oYm7f0_nXdOH3ojWAm@03oj[AmOnZdOCoZ]7d00?o
Zm7d00Co[=7dojcAlon/dO?o[=7c0on]dO<3ojkAlP04ojoAl_n_d?7o[m3aok3@l@;o[m3a00?o/=3a
ok3?l?nad?000_naco05ok;?k`03ok??k_ncc^ko]<k^00;o/lk]00?o]<k]okC=kOndcNd00onecN`0
0onfcN_o]/c[okK<j`02okK<jP;o]lcZ0onhc>T00onic>So^L_XokW;j002okW;i`06ok[;ionjb^Oo
^/[Wok_;i_nkb^Ko_<[U0_nlbND01_nmb^Co_<WTokc9i?nmb^Co_LWSokk9h`;o_/WR0_nobN83ol79
h@?o`/WP0_o3bMl2olC9gP04o`000?o5bMgoaLWMolO:g0;oalWL00?ob<[LolS:foo9bmX00_o9bmX0
0oo:b][obl_Iol_;f@07ooooo`Co00002?ooool00ol0003oooooooooo`07ooooo`005oooool00ol0
003oooooooooo`0Mooooo`?o00001?ooool01_l03Y?o02R/o`12`Ol0@/7o05K@o`1Me@;o2VSK00Co
6G?Rob5iiOlWONOo9ggW0_ldQ^/2ocn=kP03odFBl?m;U_7oBiKa00;oE9cc0_mIWo@00omMX_GoHJGf
of6UmP02ofJXmP03ofV[mom][_OoKJkg00;oLK3h00?oM;;hogNdnOmg]?T00_mj]oT00omm^?WoP;[i
oh2jn@02oh:ln@04ohFmnOn6__WoQ[kiohS0n@;oR/7i00?oS<?iohg3nOn=`oT00_n?a?T2oi75n@05
oi;7nOnCaoWoTlOioiG8nOnFbOT00_nGbOT2oiS:n@?oV/_i00?oVlchoic<n?nLc?P00_nMcOP01OnN
c_SoWlkhoj3>n?nPc_SoXLoh00;oXLog00?oX/ogoj??monScoL00_nTd?L01?nUd?OoYM3fojG@m_nV
dOH2ojK@mP03ojOAm_nWd?KoZ=7e00;oZ=7e0_nYdOD3oj[Am0?oZm7d00?o[=7cojc@lon]dO<00_n]
d?<2ojg@lP03ojkAl_n^d?;o[]3b00Co[m3a00Go[loaok3?l?n`co3o/<o`ok7?l002ok7>k`;o/Lo_
00?o//o_ok;>k_nbc^h00_ncc^h01?ncc^go/lg]ok?=kOndcNd2okC=k003okG=k?nec>_o]/c[00;o
]/c[00?o]/cZokK;j_nfbnX00_ngbnT00onhc>Wo^<_YokW;j002okS;j006okW;ionib^Oo^L[Wok[:
ionjb^Ko^l[V0_nkbND00onlbNGo^lWUok_9i@02okc9i004okg9honmb>?o_LSSokk9hP;o_/SR00?o
_lWRoko8hOo1bN400_o0b>000oo2bN3o`/SOol?9g`02ol?8g`;oa<WN00?o0000olG9gOo5bMd00oo7
bM`2olS:f`04olW;f_o:b][ob/[Jol_;f@;oc<_I0oooool3o`0000gooooo00?o0000ooooooooool0
1_ooool001Oooooo00?o0000ooooooooool06_ooool3o`0000Wooooo00_o02Z]o`12`Ol0BlOo05SA
o`1MeOl;J]co577Poa]eholQNNGo:GoXoc24jP02ocF7k0;o@Ho_00?oAY?`odbGl_mAVo<00_mEWO<2
oeZQm003oejTmOmSYoKoHjOf00;oIj[g00?oJjcgofj_n?m^[oP00_mb/OP00ome/oWoN;KiogRfn@02
og^hn@;oO[Wi00CoPK_ioh>mnOn4_O[oQ;gj0_n6_oX2ohS1nP04oh_2n_n=`oWoSLCjohg4nP;oSlGi
00?oTLKioi;6nOnBa_T00_nCaoT01?nEb?WoUlWioiO:nOnGb_T3oiW;n@;oV/ci00?oW<choic=n?nL
cOP00_nMcOP3oio>n004oj3>n?nQc_SoX/ogoj;?m`?oXlog0onTd?L2ojG@mP?oY]3f00?oYm3fojO@
mOnXdOD00_nXd?D2ojW@m004oj[Am?nZd?CoZ]3doj_Am0;oZm3c0_n/d?<01?n]d??o[M3bojg@l_n]
d?82ojg?lP;o[]3a00Ko[m3aojo?lOn_co7o[loaojo?l?n`co02ok3>l0Co/Lk_0_nacNh00onbc^ko
/lk^ok?=k@04ok?=k@03okC=k?ndc>co]<c/00;o]Lc[00Co]/c[okG;j_nebn[o]/_Z0_nfbnT2okO;
j@03okS;jOnhb^So^<_X00;o^<[W00Go^L[WokW9ionibNOo^/[Vok[9iP04ok_9i@;o^lST00?o_<WT
okc8honmb><00_nmb><2okk8hP?o_lSQ0oo0b>02ol;8g`05ol?8goo3b=ko`lSNolC9g_l000000oo5
bMd2olO9g003olS:foo8bM_ob<WK00;ob/[J1?o<bmT2o`00013ooooo00?o0000ooooooooool01_oo
ool001Oooooo0_l0000Hooooo`?o00003Oooool01?l0:jko04?2o`1;aol0FM82o`EWfP05oaAah?lL
MnCo8g_VobZ1j?l`Q>X00_lgRN`2od:Ak`05odRElOm=VO;oDI_coe6KlomFWo@00_mKX_D00omOYOKo
I:SgofBXm`02ofR[m`03ofb^n?m_/?SoKk3h00;oLk;i0_mf]?T00omi]oWoO;Siogbhn@02ognjn@04
oh6lnOn4_O[oQKkjohFnnP;oQl3j0_n9`OX01?n;`o[oSLCjohk4n_n>a?X2oi35nP03oi;6nOnBaoWo
T/Oi00;oU<Si0onFbOT01?nHb_WoVL_ioiW;nOnIboT2oi_<n@?oW<gh0_nNcOP3oio>n004oj7>n?nQ
c_OoX/ogoj;?m`?oXlog00?oY=3gojC?m_nTcoH00onUd?H2ojK@mP;oYm3e00?oZ=3eojS@m?nXd?@0
0onYd?@2oj[@m0?oZm3c00?o[=3cojc?lon]d?800on]co82ojg?l@;o[/oa0on_co400on_co3o[lk`
ok3>l002ok3>k`03ok7>konacNoo/Lg_00?o/Lg^00Go//g^ok?=kOncc>go/lc]ok?=k@02ok?<k006
okC<k?ndbn_o]<_[okG<jondbn_o]L_Z0_neb^X01OnfbnWo]/[YokK:jOngb^Wo^<[X00;o]lWX00Ko
^<[WokS9ionhbNOo^LWWokW9i_njbNH2ok[8i@03ok_9iOnjb>Go^/SU00;o^lST0onlb><01onmb>?o
_LORokg7h_nnb>;o_/OQoko8hOnoan400oo0b>03ol;8g`?o`lSN00?oa<SMo`000?o5bMd00_o5b=`2
olO9g0?ob<WK0_o:b]X3olc;fA;ooooo00?o0000ooooooooool01_ooool000oooooo0_l00005oooo
o`;o00005_ooool3o`00017ooooo00Co02f_o`15`ol0ELoo05_C0_l5ImX2oaIbh@05obAmiol/P^Wo
<HK[ocR;kOloT>l00_m3T_02odVGlP;oDigc00?oF:3eoebSm_mLXoH00_mQY_H00omUZOOoJJchofV/
n002off_n003og2an?md/oWoM;?i00;oMkKi00?oN[OiogfinOmm^OT00_mo^oX2oh:mnP04ohFnn_n5
_o[oR<7johS1nP;oR/;j00CoS<?johg4n_n=a?[oSlGj0_n@a_X00onBaoWoTlOioi?7n@02oiC8n@05
oiK9nOnGbOWoUlWioiS:nOnIboT00_nJboT2oi_<n003oic=n?nMcOSoWLgh00?oW/gh0_nOc_P2oj7>
m`?oX/og0_nScoL3ojC?mP04ojG@m_nVcoKoY/ofojK@m@;oYloe00GoYm3eojS@m?nXcoCoZ<odojW@
m002ojW?m003oj[@lonZco?oZ/oc00;oZloc00?o[<ocojc?l_n]co800_n]co800on]co7o[Lkaojg>
l@03ojk>l@Co[lk`00Co/<k_ok3=kon`cNoo/Lg_0onacNh00onac>ko//c]ok;<k@03ok?<k@03ok?<
k?ncbnco/l_/00?o]<_[0_ndb^X01Oneb^[o]LWYokG9jOnfb^Wo]/WY00?o]lWX0_ngbNL01OnhbNOo
^<SWokS8ionibNKo^LSV00Co^/SU0_njb>@00onkb>Co^lOTokc8h`02okc7h`;o_LOR0_nnan43oko7
h@03ol38h?o0an3o`/SO00;o`/SO0oo3b=h2olC8g@04o`000?o5b=coaLSLolO9g0;oalWK00?ob<WK
olS9f_o:b]X00_o:b]X3olc;fA7ooooo00?o0000ooooooooool01_ooool000kooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0Booooo`?o00005Oooool01?l09JOo04O4o`1Ecol0
ELl2o`MXf`04oaMdh_lON^Go9WoXobIoj0;o<hS/0_loT>l00om5U?7oBiSboe2Ll`02oeBNm003oeVR
mOmMYOKoGJGf00;oHZSg00?oIZ_gofZ]n?mZ[OP00_m^/?P00oma/_WoMKCiogFdn@02ogRfn@03og^h
nOmn^_[oO[[j00;oP;cj0_n3_OX01?n5_o[oQ[ojohS1n_n8`OX2oh_2nP?oSLCj0_n?aOX01?nAa_[o
T/Oioi?7nOnCaoT2oiG8n@?oUlWi0_nHboT2oi[;n@?oW<ch0_nMcOP00onNcOSoWlghoio=n002oj3>
m`;oXLkg00CoX/ogoj?>monSc_OoY<of0_nTc_H2ojG?mP03ojK?m_nVcoGoY/oe00?oYloe0_nXco@3
ojW?m0;oZLoc0onZco<01On[co?oZlkbojc>l_n/c_;o[Lob00Go[Lka00Go[/kaojk=l?n^cO3o[lg`
ojo>l002ojo=k`04ok3=kon`c>oo/<c_ok7=kP?o/Lc^00?o/L_]ok;<kOnbbn`00onbbn`01_ncbnco
/l_[ok?;jondbn_o]<[[okC:jP;o]<WZ0onebNT01OnfbNWo]lWXokO9j?ngbNSo]lWW00;o]lSW00?o
^<SWokS8i_nib>H00_nianD01_njb>Go^/OUok[7iOnjb>Co^/OTok_7i0;o^lOS00Co_<OSokc7h_nm
an;o_LOR0onnan401_noan7o_lOPoko7h?o0an3o`<OOol;8g`;o`/OO00?o`lSNol?7g_o4b=d00_o4
b=d00ol0003oaLSLolK8g003olO9f`03olS9f_o9bM[ob/[J00;obl[I0_o<bmT00oo=bmSooooooooo
o`0>ooooo`03o`000?oooooooooo00Kooooo000>ooooo`04o`000?ooooooooooo`0000Cooooo0_l0
000@ooooo`?o00006?ooool01Ol09ZSo02n`o`11_ol0Eloo05oE00;o26[L00Co6GKSoamjiOlWP>So
;hK[0_ldRNd2od2Al003odJFlOm<VO?oD9cc00;oEIod0_mJXoH00omOY_KoHjWgof>Ym`02ofN/n003
of^^n?m_/OWoKk7i00;oL[?i00?oM[GiogVgnOmi]oT00_ml^OX01?mn^o[oPKcjoh6ln_n4__X2ohFo
nP;oQl3j00CoRL;joh_3n_n;`o[oSLCj0_n>a?X2oi35nP;oT/Oi0_nDb?T3oiK9n@;oV<[i0onIboT0
1?nKboSoW<choic<n?nLc?P2oig=n004oio=n?nOcOOoWlggoj3>m`;oXLgg0_nRc_L00onSc_OoXlkf
ojC>mP02ojC>mP;oYLof0onVcoD01OnWcoGoYlkdojO>m?nXcoCoZ<kd00;oZLod00CoZLocojW>lonY
c_?oZ/oc0_n[c_<2oj_>lP;o[<kb00Co[Lkaojg=lOn]cO7o[Lka0_n]cO03ojk=l005ojo=kon_c>oo
[lc_ojo<kon`c>l00_n`c>h00onac>ko/L_]ok7;k@02ok7;k@03ok;;k?nbb^co//[/00;o//[/00?o
/l_[ok?:jondb^/00ondbNX2okC9j@05okG9jOneb>Wo]/SXokK8j?ngbNP00_nfb>L3okO8i`03okS8
i_nhanKo^LOU00;o^LOU00Oo^/OUokW7i?nianCo^/OTok[6i?nkan?o^lKS00?o_<OR0_nman83okk7
h@;o_lOP0oo0aml01Oo2amoo`/ONol;7g_o3amko`lOM00;oa<SM00Co0000olG8g?o6b=coa/SL0_o7
bM/3olW9fP;obl[I00Coc<_Iolg;f?o=bmSocL_H3oooool00ol0003oooooooooo`06ooooo`003_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00cooooo0ol0000Looooo`0;o`0V
Z?l0>KWo04:oo`1Hd?l0GmGo0VKJoa=chOlJN>Co8GcVobV2jOl_Q^/00_lfRnd2od:Cl003odRGl_m>
Vo?oDIgd00;oEj7e0_mLY?H00omPYoOoI:[gofBZm`02ofR]n003ofb_n?m`/_WoL;;i00;oLkCi00?o
MkKiogZhn_mj^?X00_mm^_X00omo^o[oP[gjoh:mnP03ohFonP;oR<7j00CoR/;johc3n_n=a?[oSLCj
0_n?aOX2oi36nP05oi;7nOnCaoWoTlOioiC8nOnFbOT00_nGbOT2oiS:n@03oiW;nOnJboSoV/_h00;o
Vl_h00?oW<choig<n?nNc?P00_nNc?L2oio=m`?oXLgg00CoX/kgoj;=m_nRcOKoXlkf0onTc_H3ojG>
m@;oY/ke0onWc_@2ojS>m0?oZLkc0_nZc_<01On[c_?oZlgboj_=l_n[c_;oZlgb00?o[<ga0_n]cO40
1_n]cO3o[Lc`ojg<l?n^cO3o[/c_ojo<k`;o[l__0_n_c>h01_n`c>ko/<_^ok3;k_nabngo/<_]ok7;
k@;o/L[/00?o//[/ok;9k?nbbN`00_nbbN/00oncb^_o/lW[okC9jP02okC8jP05okC9jOndb>Wo]<SY
okG8jOneb>P00_nfb>P01_nfb>Oo]/OWokK7iongb>Oo]lOVokS7iP;o^<OU00Oo^LOUokW6iOnia^Go
^LOTokW6i?nja^Co^/KS00?o^lKS00?o_<ORokc6h_nman800_nma^401_nnan7o_/KQokk6hOnoan3o
_lKOol37g`;o`<KO0_o2amh3ol?7g@03olC8gOo4amco000000;oa/SL0_o7bM/01?o7b=_obLWJolW9
f_o9bMX2ol_:f@?ocL_H3oooool00ol0003oooooooooo`06ooooo`003_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Wooooo0ol0000Pooooo`0;o`0WZ?l0@l3o04?0o`1JdOl0
H=Ko0fSKoa=chOlLNNGo8gkWob^3j_l`Qn`00_lhS>h2od>Dl@;oBISb0_mCW_@01?mHX_KoGJGfoefU
m_mQZ?L2ofJ[n0;oJZkh00?oK[3iog6bnOma/_T00_md]OT00omh]oWoNkWjog^inP02ogjjnP;oP;cj
00CoPkkjohBnn_n6`?[oQ/3j0_n8`OX01?n;`_[oSLCjohg4n_n=a?X2oho5nP03oi76nOnBa_WoT/Ki
00;oTlOi00CoULSioiO9nOnGbOWoUlWi0_nHb_T3oi[;n005oi_;n?nLboSoW<_hoig<n?nNc?L00_nO
c?L2oj3=m`?oXLgg0onRcOH01OnScOKoY<kfojC=mOnTcOGoYLke00;oYLge0_nVc_@2ojO>m004ojS>
m?nXcO?oZ<gcojW>l`;oZLgc0_nZcO84oj_=lP04oj_<lOn/cO7o[<caojc<l@Go[Lc`00?o[/c_ojk;
kon_bnl01?n_bnh01_n`bnko/<[]ok3:kOn`bngo/<[]ok7:k0;o/LW/00Go//W/ok;9jonbbN_o//W[
ok?9j`02ok?8jP04okC8j_ncb>Wo/lSYokC8j@;o]<OX00?o]LSXokG7j?nfanL01?nfanL00onganKo
]lKVokS7i@02okS6i@03okW6iOnia^Co^LKT00;o^LKT0_nja^<00onka^?o^lKRok_6hP02okc6hP?o
_LKQ00?o_/KQokk6h?noa]l00_noa]l01Oo0a]oo`LKNol76g_o2amko`/KN00?o`lOM0_o4am`01_l0
003oa/SKolK8foo7bM_oalSKolS8fP;obLWJ0oo;b]T2olg;f13ooooo00?o0000ooooooooool01Ooo
ool000kooooo00Co0000oooooooooooo00001?ooool2o`0000Oooooo0ol0000Tooooo`06o`0XZOl0
@l3o04?0o`1Kd_l0H]Oo16WK0_lDM>801OlTOnSo;8G[oc:9k?liS^ko@9;`00;oAIKa0_m;VO<2oeBP
m@03oeVSm_mNY_OoGZKg00;oHjWg00?oIjchof^_n?m[[oP00_m_/OT00omb/oWoM[KiogJfn@02ogVg
nP03ogbin_mn^o[oO[_j00;oPKgj00CoQ;kjohFon_n7`?[oQl3j0_n9`_X01?n;`o[oS<?johc3n_n>
a?X2oi35n@?oT/Ki0_nDaoT2oiK8n@;oV<Wi0onIb_P2oi_;n0?oW<_h00GoWLcgoio<monOc?OoWlcg
oj3<m`02oj3<mP;oXLgf00GoX/gfoj?=m_nScOKoY<gfojC=m@03ojG=m@?oY/gd0_nWcO@01OnWcO?o
Z<gcojS=lonXcO?oZLgc00;oZLcb00?oZ/gboj[<l_nZc?801?n[c?400on/c?7o[<_`ojc;l003ojg<
l0;o[L__0_n^bnl01?n_bnko[l[^ojo:k_n_b^h2ojo9k@05ok39kOn`b^go/<W/ok39k?nabN`00_na
b>/01OnbbN_o//S[ok;8jonbb>[o/lSZ00?o/lSY0_ncanT2okC7j003okG7j?nea^Oo]/KW00;o]/KW
00?o]/OWokK6i_nga^H00_nga^D01onha^Go^<GUokS5iOnia^Co^<GTokW6i?niaN<00onjaN<00onk
a^;o^lGRokc6hP02okc5h@05okg6hOnmaN7o_LGQokk6h?nnaN000onoa]l2ol76gP03ol;6g_o2a]go
`/KM00;o`lOM00Koa<OLolG7g?o5amco0000olK8foo7b=/2olS8fP;obLWJ00Kob/WIol_:fOo<bmWo
c<_Iolg;f?o>c=P?ooooo`03o`000?oooooooooo00Gooooo000?ooooo`;o00001Oooool00ol0003o
ooooooooo`03ooooo`?o0000:?ooool01?l0:JWo04C1o`1>b?l0E/h2o`I[g0;o5WKS0_lVPNP2oc>:
k@;o@9;`00?oAYObodbKlom<Vo<00_mFXOD00omKY?KoGjOgoenWm`02ofBZn003ofR]n?m/[oWoK:oi
00;oL;;i00?oLkCiogNfnOmg]_T00_mj^?X01?mm^_[oOkcjognln_n2_OX2oh>nnP03ohFon_n8`O[o
R<7j00;oR/;j00CoS<?johg3n_n=`o[oSlCi0_n@aOT00onBa_WoTlKioi?6n@02oiC7n@05oiK8nOnG
b?WoUlSioiS9n?nIb_P00_nJbOP2oi_:n003oic;n?nMboOoWL_g00;oW/_g0_nOc?L00onPc?KoXLcf
oj7<mP02oj;<mP05oj?=m_nSc?GoXlceojC=mOnTc?D00_nUcO@01?nVcOCoY/cdojK<m?nWcO@2ojO<
l`04ojS<lonXcO?oZ<cbojS<lP?oZLcb00?oZ/cboj[;lOnZbo400_n[c?45ojc;l005ojg;kon]b^oo
[L[_ojg:kon^bnl00_n^b^h00on_b^ko[lW]ojo9k@03ojo9k@;o/<W/0_n`b>`3ok78j`05ok;8jona
an[o//OZok;7j_ncb>T00oncanT2ok?6j005okC7j?nda^So]LKWokG6ionfa^L00onfa^H01OnfaNKo
]lKUokO5iOngaNGo^<GU00?o^<GT0oniaN<00onjaN?o^/GRok[5hP02ok_5hP?o_<GQ00?o_LGQokg5
h?nnaN000_nnaMl00onoa]oo_lGOoko5g`02ol76gP?o`/KM00Go`lOMol?6g?o5amcoaLOLo`000002
olK8f`?ob<SJ00?obLWJol[9fOo:bMT00_o<bmT3olk<f0kooooo00?o0000ooooooooool01Oooool0
01Gooooo00Co0000oooooooooooooooo0ol0000/ooooo`04o`0PX?l0A/;o04k8o`1Gc`;o1V_L0_lG
Mn@2obN2j@;o=Hc^0_m1U?400om7V?;oCYcdodjLm002oeNRmP;oG:Gg00CoHJSgofF[n?mUZoSoJJkh
0_m]/?T2og6bn@03ogBenOmh]o[oN;Oj00;oNkWj00CoOK[joh2ln_n0_?[oPkkj0_n4__X2ohJonP04
ohS1n_n;`_[oRl;johg3nP;oSL?i0_n?a?T01OnAaOWoT/Kioi?6nOnCa_WoULOi00;oU/Oh0_nGb?P0
1OnHbOSoV/Whoi[9n?nJbOSoVl[h00;oW<[g0_nMboL2oik;m`;oX<_f00CoXLcfoj7;m_nQboKoX/cf
0_nRboD2oj?<m@03ojC<mOnTc?CoYLcd00;oYLcd0_nVc?<3ojO<l`03ojS<lonXbo;oZLcb00;oZLcb
0_nYbo43oj[;l@03oj_;lOn/bo3o[<_`00;o[<_`0_n/b^l01On]b^oo[LW_ojg9kon]bNko[/[^00;o
[/W^00Go[lW]ojo8kOn_b>go[lW]ojo8k003ok38k0;o/<S[00Go/LS[ok77jonaan_o/LOZok76jP02
ok;7j@03ok?7jOnca^Wo/lKY00;o/lKX00?o]<KXokC5iondaNL00_nea^L01Onfa^Ko]LGVokG5i_nf
aNKo]/GU00?o]lGU00Co^<GTokS4i?nhaNCo^<GT0oniaN<00onjaN;o^/CRok_5hP02ok_4h@03okc5
hOnla>7o_<CQ00;o_LGP0onnaMl00onoaMoo_lGNol76gP02ol75gP;o`/KM0oo3a]`2olG7g005o`00
0?o7b=_oalSKolS8f_o8bMX00oo:bMT00oo;b]Woc<_Iolc;f002olk<f0kooooo00?o0000oooooooo
ool01Oooool001Gooooo1?l0000`ooooo`04o`0PX?l0?[_o04o9o`1Hc`;o1fcM0_lINN@2obR4jP;o
=hg^0_m3UO400om9VO?oCigdodnMm002oeRSmP;oGJKg00CoHZWgofJ/n?mV[?SoJjoh0_m^/OT2og:c
n@03ogFenOmi]o[oNKOj00;oO;Wj00CoO[_joh6ln_n2_O[oP[gj0_n5__X2ohO0nP04ohW1n_n;`_[o
S<;iohc2n@;oS/Ci0_n@aOT2oi;6n@;oU<Ki0onFaoP2oiS8n005oiW9n?nIb?SoVlWgoi_9monLb_L0
0_nLbOL2oig:m`05oik;monOboKoX<_foj3;m_nQboH00_nQboD00onRboGoXl_eoj?;m@02oj?;m003
ojC<m?nTboCoYLcd00;oYL_c0_nVbo<00onWc??oYl_bojO;lP02ojS;lP;oZL_b0onYbo401OnZbo7o
Z/[`oj[:l?n[b_3oZlW`00?o[<[_0_n/bNl01On]bNoo[LW^ojg9k_n]bNko[/W^00;o[/S]00Go[lS]
ojo8k?n_b>co[lS/ojo7k002ok37j`04ok38jon`an_o/<O[ok77j`;o/LKZ0_naa^T2ok;6j@05ok?6
jOnca^So/lKXok?6j?ncaNL00ondaNL2okC5iP;o]LGV00Co]/GUokK4iOnfa>Go]lGU0_nga>@01Onh
a>Co^<CSokS4honha>?o^LGS00;o^LCR0_nja>83ok_4h@03okc4hOnla>3o_LGP00;o_LCO00?o_/GO
okk4gonna=l00_noaMh00oo1aMko`LGMol75g@02ol;6g@06ol?6g?o4a]coa<KLolG7g?o5am_o0000
0_o7b=/2olS9fP04ol[9fOo;b]Wobl[Iolc;f0;ocL_H00?oc/cHolo=eoooool03?ooool00ol0003o
ooooooooo`05ooooo`005Oooool2o`0003?ooooo00Ko026Po`0o_?l0D<Wo05W@o`1Wf_l8K]h2oaYj
i@;o:XG[0_lhS^l2odBFlP05odZJlom@W_CoD9kdoeJRm_mJY?H00_mNYoL00omSZ_SoIjghofN]n002
ofb_n@03ofnbnOmc]?WoLkCi00;oM[Ki00?oN[Sjogfjn_mm^_X00_mo^oX01?n2_O[oPkgjohFnn_n5
__X2ohS0nP04oh[1nOn<`_WoSL?iohg3n@;oSlCi0onAaOT01?nCa_WoU<KhoiC6n?nFaoP2oiO7n0;o
V<Sh00GoVLShoi[8monKbOOoVlWgoic9m`02oig9m`;oW/[f00?oWl_foio:m_nPboH00_nQb_D2oj;;
m@05oj?;mOnSboCoXl_dojC;m?nTb_@00onUbo<3ojK;l`;oYl[b0_nWbo800onXbo;oZ<[aojW:l@02
ojW9l@;oZL[a00?oZ/[`oj[9l?n[bO000_n[bNl3ojc9k`;o[<S^00Co[LW^ojg8k_n]b>go[LS]0on^
b>d01On_b>co[lO/ojo7k?n_anco[lK[00?o/<O[0_n`a^X00onaa^[o/LKYok76j@02ok75j@;o//GX
00?o/lKXok?5j?ncaNL00_nca>L00ondaNOo]<CVokC4iP02okC4iP03okG5i_nea>Go]/CU00;o]/CT
00?o]lCTokO3i?nha><01?nha><2okW4hP03ok[4h_nja>7o^/CQ00?o^lCQ0_nla>03okg4g`03okk4
gonna=ko_lGN00;o`<GN0_o1aMd00oo2a]go`/KLol;6g002olC6g0;oaLOK00Co0000olO8foo7b=[o
b<WJ0_o9bMX3ol_:f@03olg;f?o=c=SoclgG00;oclgG3?ooool00ol0003oooooooooo`05ooooo`00
5oooool00ol0003oooooooooo`0aooooo`06o`0QX?l0@;co05[Ao`1JdOl1J=[o2VoN0_lKNnH2ob^6
j`;o>Ho_0_m5Uo82odbKm003oe6OmOmGX_KoFjGg00;oH:Sg00?oI:_hofV]n?mY[OP00_m]/?T00om`
/_WoM;CiogBdn@02ogNfn@04og^hn_mm^_[oOK[joh2lnP;oPKcj00?oQ;gjohJonOn6_oT00_n8`?T0
1?n;`OWoRl;ioh_2nOn=`oT2oho4n@05oi75nOnBaOSoT/Ghoi?5n?nEa_P00_nFa_P2oiO7n005oiW8
n?nIaoOoVLOgoi[8monKbOL00_nLb?H2oig9mP?oW/Wf00CoWl[foj7:mOnQb_GoXL[e0_nRb_D01OnS
boCoXl[doj?:m?nTb_CoY<[c00;oYL[c00CoY/_cojK:l_nVb_;oYl[b0_nWbO801OnWb_;oZ<[aojS9
lOnXbO7oZLWa00;oZLW`0onZbO001?nZbNooZlW_oj_8kon[b>l5ojc8kP05ojg8k_n]ango[LO]ojg7
kOn^b>d00_n^an`00on_anco[lK[ojo6j`02ojo6j`;o/<K[00Co/<KZok35j_n`aN[o/LKY0_naaNT0
1onaa>So//GXok;5j?nbaNSo/lGXok;4ionca>L00_nca>H3okC4iP05okC4iOnea>Go]L?UokG3iOnf
a>@00_nf`n@01Ong`nCo]l?SokS3honh`n?o^<CS00;o^<?R00?o^LCRokW3h_nja>400_nj`n400onk
a>7o^l?Pokc4h002okc3g`;o_LCO0_nna=h3ol35gP;o`LGM0oo2a]`3olC6g003olG7foo6am_o0000
00;oalSJ0oo9bMX2ol_:f@;ocLcH00?oc/cHolo=eoo@c]L03?ooool00ol0003oooooooooo`05oooo
o`006?ooool00ol0003oooooooooo`0aooooo`08o`0RX?l0@Kco05[Ao`1JdOl2J]_o2g3OoaEgholM
O>H2obf7k0;o>i3`0_m7V?<2odfLm003oe>PmOmHXoKoG:Kg00;oHJWg00?oIZchofZ^n?mZ[_P00_m^
/?T00oma/oWoMKGiogFen@02ogRgn@04og^inOmn^_[oOk_iognkn@;oP[ci00?oQKkiohNonOn7_oT0
0_n9`?T01?n;`_WoS<;iohc2nOn>`oT2oi34n@04oi;5n?nBa?SoT/ChoiC5n0?oU/Kh0_nHaoL3oiW7
m`04oi_8monLb?KoW<Sfoic8mP;oWLWf00GoW/Wfoio9mOnObOGoX<Weoj7:m@02oj79m0?oX/Wd0_nS
bO<01OnTb_?oY<WcojG9lonUbO?oY/[b00;oY/Wb00?oYlWbojO9lOnWbO400_nXbO42ojS9l003ojW9
l?nYb?3oZLS`00;oZ/S`00?oZ/W_oj_8kon[b>l00_n[anh3ojc8kP05ojc7kOn]ango[LK]ojg6kOn]
an`00_n]a^`2ojk6k0?o[lK[0_n_aNX3ok35jP03ok35jOnaaNWo/LCX00?o/LCX00?o//GXok;4ionb
a>L00_nba>L00onca>Ko/l?Vok?3iP02okC3iP03okC4iOnd`nGo]L?U00;o]L?T0_nf`n@00ong`n?o
]l;SokS3h`02okS3h`;o^<?R00?o^L?RokW3hOni`n400onj`n42ok_3h0;o_<?O0_nma=l3okk4gP03
ol35g_o0a=ko`<CN00;o`LGM00?o`/KLol?5g?o3aM`00_o4a]`3olK7f`06o`000?o8b=[ob<SJolW9
f_o:bMWobl[I0_o<bmT01Oo=c=Soc/cHolk=f?o@c]OodLkG00cooooo00?o0000ooooooooool01?oo
ool001Wooooo00?o0000ooooooooool0<Oooool03_l08Z3o046mo`1KdOl0Fm7o0f_Lo`aah?lFN>Co
7WgWobN4j_l^R>co=Xg^ocbAl?m3U_;oB9Wc0_m>WO@00omDXOGoFZCfoeZTmP02of:Yn0;oIjch00Co
JjohofnanOm_/OWoL[?i0_mf]OT2ogVgn@04ogbinOmo^oWoP;_ioh2kn@;oPkci0_n5__T01?n8_oWo
R/3ioh_0nOn;`?T2ohg2n@04oho3nOnAa?SoTL?hoi73n0;oTlCh0_nDaOP01OnFa_SoUlKgoiS6monH
a_OoVLOg00;oV/Og00CoVlOfoic8m_nMb?KoWLSf0_nNb?H01OnObOGoWlSeoio8mOnPbOGoXLSd00?o
X/Wd0_nSb?<3ojC9l`;oYLWb0_nUb?82ojK9lP05ojO9lOnWb?7oYlSaojS8lOnXbO000_nXb?000onY
b?3oZLO_ojW7k`02oj[8k`03oj_8kon[ankoZlO^00;oZlO^0_n/anh00on/ango[<K]ojg6k@03ojg6
k0;o[LG[0_n^aN/00on_a^_o[lGZojo5jP02ojo4jP?o/<GY00?o/<CYok74j?naa>P00onaa>P00onb
a>Oo//?Wok;4i`02ok;3iP?o/l?V1?nd`nD01One`nCo]L;TokG2i?nf`nCo]/;S00;o]l;S00Ko^<?S
okS2h_nh`^;o^<?RokS2h_ni`n42okW2h@04ok[3hOnj`^3o^l?Pok_3g`?o_<?O00?o_LCOokg3gonn
a=h00_noa=h00oo0a=ko`<CMol75g@02ol75g@;o`lGL00?oa<KLolC6foo4a]/00oo6am/01Ol0003o
b<SJolS8f_o:bMWob/[I00;oc<_I00Coc/cHolk=f?o>cMSodLkG0_oAcmL;ooooo`03o`000?oooooo
oooo00Cooooo000Jooooo`;o0000<_ooool03?l08Z3o04:mo`1Dc?l0G=;o16cLo`ebh?lGNNCo7gkW
obR5j_l_RNgo=hk_ocfBl0;oA9Ob0_m@W_@00omEX_KoFjGgoe^Um`02of>Zn0;oJ:gh00?oK:oiog2a
nOm`/OT00_mc]?T01?mg]_WoN[SiogZhnOmm^OT2ogjin@03oh6knOn4_?WoQ;ci00;oQ[ki00CoR;oi
oh_0nOn;`?WoRl3i0_n=`_P01?n?`oSoTL?hoi;3n?nB`oP2oi?4n005oiG5monFaOOoU/GgoiO5monI
a_L00_nIa_H2oi[6mP05oi_7m_nMb?KoWLOeoig7mOnNb?D00_nNaoD2oio8m0;oXLSd0_nRb?<3oj?8
l`;oY<Sc00?oYLWbojG8l_nUb?801?nVb?401?nWb?7oYlO`ojO7l?nXb?03ojS7l0?oZLO_00GoZ/O_
oj[6k_n[a^koZlK^oj_7kP02oj_6k@?o[<K]00Co[<K/ojg6k?n]aNco[LG/0on]aN/00on^aN_o[lGZ
ojo4jP02ojo4jP;o[lCY0_n`a>T2ok33j003ok74j?na`nOo/L?W00;o/L?W00?o//?Wok;3i_nb`nH0
0_nb`^H01Onc`nKo/l;UokC2iOnd`^Go]<?U00;o]<;T0_ne`^@2okK2h`?o]l;S0onh`^82okS2h@?o
^L;Q0_nj`^02ok_3g`;o_<?O00?o_L?Ookg3g_nm`mh00onoa=h2ol34g@03ol75gOo2aMco`/GL00;o
`lGL00?oa<KKolG6foo5a]/00_o6am/01?l0003ob<SJolS8f_o:b]T2ol_:f@06olc;fOo=c=Soc/gH
olo=f?o?c]SodLoG0_oBcmL:ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooo
oooo033ooooo00co02:Oo`12_Ol0ELco05gBo`E]gOl>Ln7o67[Uob5oj?lYQ^_o<8[]ocR?kolnTo42
odFHlP;oDIoe00?oEj;foebUmomLYOL00_mQZ?L2ofV]n003off`nOma/_WoLK;i00;oM;Ci00CoN;Ki
og^hnOml^?WoO;Si0_mo^_T00on2^oWoQ;giohBmn@02ohNnn@04ohVonOn:_oSoS<3hohc0n0;oS/7h
00CoT<;hoi72n?nB`oSoT/?h0_nDa?L01?nFaOOoU/CgoiK4monHaOL3oiW6mP;oVlKf00GoW<Ofoic6
mOnMaoGoWLOeoik7m@02oio7m0;oX<Od00GoXLSdoj77lonRb??oX/Scoj?8l`02oj?7lP05ojC8l_nT
ao;oY<ObojG7l_nVb?401?nVao42ojO7l003ojS7l?nXa^ooZ<K_00?oZLO_0_nYa^h2oj[6kP?oZlK]
0_n[aNd01On/aNgo[<G/ojc5k?n/aNco[LG/00;o[LC[00Go[LG[ojg4j_n^a>[o[/CZojo4jP02ojk3
j@03ojo4jOn_`nWo/<?X00Co/<?X00Go/L?Wok72iona`^Oo/L;Wok;3iP03ok;2iP;o//;U00?o/l;U
okC2iOnd`^@00_nd`^@2okC1i005okG2i?ne`N?o]/;SokK2hong`^<00_ng`N800onh`^;o^<7RokS2
h@02okS1h@04okW2hOni`^3o^/;Pok[2g`?o^l;O0_nl`ml01Onm`mko_/?Nokk3g_noa=ko_l?M00?o
`<CM0_o2aM`3ol?5g0;oaLKK00Soa/OKolO7f_o7am[o0000olS9f_o9bM[obl[Iol_;f@?ocLcH00Ko
clgHolo>f?o@c]Sod/oGom?@eooCdML9ooooo`03o`000?oooooooooo00Cooooo000Mooooo`03o`00
0?oooooooooo033ooooo00co02:Oo`13_Ol0E/co05K<o`E^gOl?M>7o6G_Uob:1j?lZQ^_o<X_]ocZ@
l?m0U?42odNHl`;oDYoe00?oF:?foefVmomMY_L00_mRZOL2ofZ^n003ofj`nOmb/_WoL[;i00;oM[Ci
00CoNKKiogZgnOmm^?WoOKSi0_n0^_T00on3^oWoQKgiohFmn@02ohRnn@04ohZon?n;_oSoSL3hohg0
n0;oSl7h00CoTL;hoi72monC`oOoTl?g0_nDa?L01OnFa?OoUlCfoiO4m_nHaOKoVLKf00;oV/Gf0_nK
a_D01OnLa_GoWLKeoik6m?nNa_CoWlOd00;oWlKd0_nPao<2oj77l`;oX/Oc0onSao801OnTao;oY<Ka
ojC6lOnUao7oY/Oa00;oY/K`0onWao001?nWa^ooZ<K_ojS6konXa^l2ojW6k`05ojW6k_nYaNkoZLG^
oj[6k_nZaNd00on[aNd2oj_5k004ojc5k?n/a>co[<C[ojc4j`?o[LC[00?o[LCZojk4j_n^`nT01?n^
`nT2ojo3j@03ok33j?n``^So/<?X00;o/<;W00Go/L;Wok72i_na`^Ko/L;Vok;2iP02ok;1iP05ok;2
iOnb`NGo/l7Uok?1iOnd`^@00ond`N@00ond`N?o]L7SokG1h`03okK1hP;o]l7R00Co^<7RokS1hOnh
`N7o^<7Q0_ni`N401?ni`^3o^/;Ook[2gonj`]l2ok_2g`03okc3gonm`]ko_L;N00?o_/?N0_no`md0
0oo0a=go`LCMol74g@02ol;5g006ol?5g?o4a]_oa<KKolG6foo5am_oalOJ0_o7b=X02?l0003obLWJ
olW9f_o;bmWoc<_Iolg<f?o>cMSoclkH0_o@c]P01?oAcmSodm3Gom?AeooDd]L8ooooo`03o`000?oo
oooooooo00Cooooo000Nooooo`03o`000?oooooooooo037ooooo00_o03Rdo`1FcOl0E/go06OIoa1e
h_lJO>Ko8h7Yobb7k?lcS>ko>i7`od6El@02odRIl`;oDj3e0_mIXoH01?mNYoOoHjWgof>YmomX[?P2
ofb_n0;oL;7h00CoM;?iogNenOmg]OWoNkOi0_mn^?T2oh6jn@04oh>knOn6_OWoQ[giohRnn0;oRKkh
00?oRkohohg0n?n=`?P00_n?`OP01OnA`_OoT/;goi;2monC`oOoUL?g00;oU/?f0_nGa?H01?nHaOKo
V/Gfoi[5mOnJaOD2oi_5m@05oig6mOnMaOCoW/Kdoik6m?nOa_@00_nOa_<2oj36l`03oj77lonRa_;o
X/Kb00;oXlKb1?nTa_42ojG6l@?oY/K`00GoYlK`ojO5konWaNooYlG_ojS6k`02ojS5kP?oZLG^00Co
ZLG]oj[5kOnZa>goZ/C]0_n[a>`01?n[aNcoZlC/oj_4k?n/a>`3ojc3j`04ojg4jon]`n[o[L?Zojg3
jPCo[/?Y0_n^`^P01On_`^So/<;Xojo2ion_`^Oo/<;W00;o/<7W0_na`^H2ok71iP04ok;1i_nb`NGo
//7Uok;1i@?o/l7T0ond`N@01?nd`N?o]<3SokG1hone`N<3okK1hP03okO1h_ng`N7o^<7Q00;o^<7Q
00Go^L7QokW1h?ni`N3o^L7Pok[2g`02ok[1g`03ok_2gonl`]oo_L;N00;o_L;N00?o_/?Nokk3gOno
`md00_no`md00oo1a=go`LCLol;5g002ol;5g0;oa<KK00?oaLOKolK7foo6am/00_o7b=X00oo9bM[o
0000olW9fP03olc;f@;oc/gH00Cod<kHom7?f?oBd=Oodm7G0_oDd]L8ooooo`03o`000?oooooooooo
00Cooooo000Oooooo`03o`000?oooooooooo037ooooo00_o03Rdo`1GcOl0Elgo06SIoa5fh_lKO>Ko
8h;Yobb8k?ldSNko?9;`od:FlP02odVJl`;oE:7e0_mJY?H01?mOYoOoI:[gofBZmomY[OP2off_n0;o
LK7h00CoMK?iogRenOmh]OWoNkOi0_mn^?T2oh6jn@04ohBkn?n7_OSoQkghohVnn0;oR[kh00?oS;oh
ohk0n?n>`?P00on@`OL2oi;2m`04oiC2monF`oKoU/?foiK3mP;oUlCf00GoVLCfoiW4mOnKa?GoVlCe
oic5m002oic4m004oig5m?nNaOCoWlGcoio5l`;oX<Gc00GoXLKcoj75l_nQaO;oX/Gboj?6lP02oj?5
l@;oY<Ga00GoY<KaojG5l?nUaO3oYLG`ojK6l002ojK5k`?oYlG_0_nXaNh2ojS4kP;oZLC^00?oZLG]
ojW4kOnZa>d00_nZ`n`3oj_4k003oj_3jon/`n_o[<?Z00?o[<?Z00Go[L?Zojg2jOn]`^Wo[L;Yojk3
j@03ojk2j0;o[/7X00Go[l;Xojo2ion_`NOo[l7Wok31i`02ok31iP;o/L7V0_na`ND01Onb`NGo//3U
ok;0iOnb`NCo/l7T00;o/l3T00?o]<7TokC0hond`><00_nd`><2okG0hP03okK1h_nf`>;o]l7Q00;o
]l3Q00?o^<7QokS0hOnh`>400_ni`N03ok[1g`04ok_1gonl`]oo_<;Nokc2gP?o_L;N0_nn`md3oko3
g@;o`LCL00?o`/GLol?5g?o3aM`00_o4a]/2olK7f`09olO8f_o8b=[ob<SJo`000?o:b][obl[Iolc;
fOo=c=Woc/gH00;oclkH00Kod<oHom;@eooBdMOoe=;GomGCeooFe=L8ooooo`03o`000?oooooooooo
00?ooooo000Pooooo`;o0000<_ooool02ol0>;?o05O=o`1GcOl0J=Wo4GKRoaami_lTPnWo;HW/ocF=
k_lmT_3o@iKb00;oBY[c0_m@W_@2oe^TmP04of2WmomUZ_OoIJ[gofV]n0;oKZoh0_mb/OP01?mf/oSo
NKGhogVen?ml]oP2ognin0;oP[[h00CoQK_hohNmn?n8_?SoR;ch0_n:__P01?n<_oOoS/3gohk0mon@
`OL2oi71m`;oTl7f00CoU<;foiK3m_nF`_KoU/;f0_nH`oD01?nIa?GoV/?doi_4m?nKa?@3oic4m004
oig4lonOaO?oWlCcoio4l`;oX<Gb0onQaO801?nRaO7oXlGaoj?5lOnSaO42ojC5l@05ojG5l?nUa?3o
YLG`ojG5l?nVaNl00_nVa>l00onWaNooYlC^ojS4kP02ojS4kP;oZ<C]0onYa>d01?nY`ncoZ/?/oj[3
k?nZ`n`3oj_3j`04oj_2jon/`n[o[<?Zojc3jP;o[<;Z1?n]`^T01On^`^So[/7Xojk1j?n^`NSo[/7W
00?o[l7W0_n_`NH01On``NKo/<3Vok70i_na`>Ko/L7U00;o/L3U00Go//3Uok:oi?nb`>Co//3Tok?0
i002ok?0h`04okC0hond_n?o]<3SokBohP?o]L3R00?o]/3RokK0hOng`>400_ng`>401?nh`>7o^<3P
okW0h?ni`>03ok[1g`;o^l7O00?o_<;Nokc1g_nl`Mh00_nm`]h3okk3g@03oko3gOo0`mgo`LCL00;o
`LCL0_o3aM`00oo4a]_oaLKKolG6f`02olK7f`09olS8f_o8bM[ob<WJo`000?o;b]Wobl_Iolg<fOo=
cMWoclkH00;od<oH00God]7Gom?BeooCd]OoeM?GomKDe`08ooooo`03o`000?oooooooooo00?ooooo
000Rooooo`03o`000?oooooooooo033ooooo00_o03Rco`1>aOl0F<go06WJo`Q`g_lCN>?o9H?Zobj9
kOlfS^oo?I?aodBGlP02od^Kl`;oDIoe0_mLYOH01?mQZ?OoIZ_gofJ[mom[[OP2ofn_n0;oLk7h00?o
M[?hogZen?mj]OP00_mm]oP01On0^OSoPk[hoh>jn?n5^oSoQ[_h00;oR;cg0_n;_OL01?n=__OoSkog
oi2omon@_oL2oi70mP;oTl7f00CoUL;foiG1mOnG`_GoUl;e0_nH`oD2oi[3m0;oVl?d00GoW<Cdoig3
lonM`o?oW/Ccoio4l`02oio4lP;oX<Cb00GoXLGboj74lOnRa?7oX/Caoj?5l@02oj?4l0;oY<C`00?o
YLC`ojG4konVa>l00_nV`nl2ojK4kP05ojO4k_nW`nkoZ<?]ojS3kOnXa>d00_nX`nd01OnY`ngoZL?/
ojW3k?nY`ncoZ/?/00;oZ/;[0on[`^/01?n[`^[o[<;Zojc2j_n/`^X2ojc1j@05ojg2jOn]`NSo[L7X
ojg1j?n^`NP00on^`NL01?n^`>Oo[l3Wojo0ion_`NH2ojo0iP03ok30i_na`>Go/L3U00;o/L3U0_na
_n@4ok:oi004ok?0honc_n?o/koSokBoh`?o];oR00?o]L3RokFoh_nf`>400_nf_n401Ong`>7o]koP
okNoh?nh`>3o^L3P00;o^L3O00Go^/7Ook[0gonj`=oo^l7Ook_1gP03okc1gP03okg2g_nm`]go_/?M
00;o_l?M00?o`<?Mol33g?o1a=`00_o2a=`01Oo3aMco`lGKolG6foo5a]_oa/OK00;oalSJ00Kob<WJ
olW9f_o;b]Wo0000ol_;fOo=cMT2olk=f@08om3?f?oAcmSodM3Hom?BeooDdmOoe]CGomOEeooHemH7
ooooo`03o`000?oooooooooo00?ooooo000Sooooo`03o`000?oooooooooo033ooooo00Wo01nIo`0h
/_l0F<go06WJo`QagolCN>?o9XCZobn:kOlgSnl00_lnTo401?m6V?;oC9_doe:OmOmBWoD2oefUmP04
of:XmomWZoOoIj_gof^]n0;oL;3h0_mc/_P00omg]?SoNkGhog^en002ogjgn004oh6in?n4^_SoQ;[h
ohJkn0;oQk_g00GoRKcgoh^mmon;_OOoS[kgoi2om`02oi2omP;oT/3f0_nC`OH01?nE`OGoU/7eoiO2
mOnG`_D3oiW2m003oi[2m?nK`o?oVl?c00?oWL?c00CoW/?boio4l_nO`o;oWl?b0_nPa?401OnQa?7o
X/?aoj;4l?nRa?3oXlC`00;oXl?`0_nTa?000onUa>ooYL?_ojK3k`04ojK3kP03ojO3k_nW`ngoZ<?]
00;oZ<?]0_nX`^`01OnY`^coZL?/ojW2jonY`^_oZ/;[00;oZ/7[0_n[`^X2oj_1j@Co[<7Y00?o[L7X
ojg0j?n]`>P00_n]`>P01?n^`NOo[/3Wojk0ion^_nH3ojnoiP05ojo0i_n__nGo/;oUok2oiOna`>D0
0_n`_nD2ok6oi003ok:oi?nb_^?o/[oS00;o/[oS0_nc_n<00ond_n;o];kRokBohP02okBohP03okFo
h_ne_n7o][oQ00;o][oQ0_ng_n02okRoh0?o^L3O0_nj`=l3ok_1gP;o_<7N0onm`]d2oko3g@;o`<?L
0oo2a=`01Oo3aM_oa<KKolC6foo5a]_oa/OK00?oalSJ00KobLWJolW:f_l0003oc<cIolg<fOo>cMT2
olo>f@06om7?f?oAd=Sod]7HomCCeooEe=Oof=OF0_oIf=H6ooooo`03o`000?oooooooooo00?ooooo
000Tooooo`03o`000?oooooooooo033ooooo00Ko01jHo`0g/Ol0F<go06WJo`UagolCN>@2obN5jP;o
=ho_00?o?iCaodNHlom=W?@00_mCWoD00omIXoKoGZKgof>Xm`02ofR[m`03ofb^n?m`/?SoL;3h00;o
M;;h00?oN;Chog^en?mk]OP00_mn]oP01?n1^?SoQ;[hohFjmon5^_L2ohNkm`04ohZlmon<_OOoS;gg
ohjnmP?oT;of0_nB_oH2oiC0m@05oiK1mOnF`OCoV<7doiS1m?nI`_@00_nI`O<01?nK`_?oW<;coic2
lonM`o<2oig2lP04oik3l_nO`o;oWl?aoio3l@;oXL?a00?oX/?aoj;3l?nS`o000_nS`o02oj?3k`05
ojC3konU`nooYL?^ojG3k_nV`nh00_nV`^h2ojK2k@03ojO3kOnW`^goZ<;/00CoZ<;/0_nY`^/2ojW1
j`05oj[1jonZ`N[oZ/7Zoj_1j_n[`NT00_n[`>T3ojc1j@03ojc0j?n]`>So[KoW00?o[KoW00Co[/3W
ojjoi_n^_nKo[[oV0on__nH00on__nGo[kkUok2oi@02ok2oi@;o/;kT00Go/KoTok6ni?nb_^?o/[kS
ok:oh`02ok:nh`05ok>ohonc_^;o];kRokBnh_nd_n800_nd_^400one_n7o]KkQokJoh@02okJoh004
okNoh?nh_n3o^;oOokRog`?o^L3O00?o^/3Ook[0g_nk`Mh00_nk`Mh01?nl`Mko_<7Mokg2gOnn`]d2
oko3g@03ol33g?o1`mco`L?L00;o`/CL0oo4a]/3olK7f`03olO8f_o8bM[obL[J00;ob/_J00Ko0000
olg<fOo=cMWoclkIom3?fOoAd=P2om;Af006omGDeooFeMOoemKGomWHe_oJfMKofm_F1Oooool00ol0
003oooooooooo`03ooooo`009Oooool2o`00037ooooo00go01fGo`0f/?l0F<go06WJo`UagolDNNCo
7WoWobR5jol`Rngo>I3_od2DlOm7VO?oCIcd00;oE:3e00?oFZ?foenVmomTZOL00_mXZoL2off^n004
og6`n?me/_SoMK;hogVdn0;oO;Gh0_mo]oP01?n2^?OoQK[gohFjmon5^_L2ohRkm`05ohZlmon<_OKo
S;gfohnnm_n?_OH00_nA__D2oi>om@04oiC0mOnE_oCoU/3doiK0m0;oV<7d00GoVL7coi[1lonJ`O?o
Vl7coic2lP02oic1lP;oWL;b00CoW/;aoio2lOnP`_7oX<;a0_nQ`_001OnR`o3oX/;`oj?2l?nS`_3o
Xl?_00?oY<;_00CoY<;^ojG2k_nU`^koY/;^0_nV`Nd01?nV`^goYl;]ojO1k?nW`N`2ojS1k003ojS2
k?nX`N_oZL7[00;oZL7[0_nY`>X00onZ`N[oZ/3Yoj_0j@02oj_0j@;oZkoX0on/`>P00on/_nSo[KoW
ojfoi`03ojfoi`05ojjoi_n^_^Ko[[oVojjoi_n__nH01?n__^D4ok2ni003ok6ni?na_^?o/KkS00?o
/[kS00Co/[kRok>nh_nc_^;o/kkR0_nd_^82okBnh@?o]KkQ00Co][oPokJnh?ng_n3o]koP0onh_ml0
0oni`=oo^KoOok[0gP02ok[0gP;o^l7N00?o_<7Mokg1gOnn`]d00_nn`]d2oko3g@05ol73g?o1a=co
`LCLol;4g?o2aM`00_o4a]/05oo5a]_oa/OKolO8foo7b=_ob<WJolW9f_o:bm[obl_Jolg<fOl0003o
cLgIolk>fOo@cmWod=3Iom;Af?oCd]Soe=CHomKEeooGe]Oof=SGom[Ie_oKfmKog=cF00Cooooo00?o
0000ooooooooool00oooool002Oooooo00?o0000ooooooooool0;oooool03Ol06iGo03J_o`1Gc?l0
J][o2G;OoaAii?lNOnOo:8K[oc6;kOliT?3o@ICaodRIlom>W?@00_mDX?D00omJXoKoH:Kfof2VmP02
ofV/m`;oKZkg00CoL[3hogJbn?mf/_SoNKCh0_ml]OP2oh2gm`;oPkSg0_n6^OL2ohRjm`05oh^lm_n=
_?KoSKcfohnmm_n?_OD00_nA__D2oi>om@;oUKod0_nG`?@2oiS0l`04oi[1lonJ`??oVl7boi_1lP?o
W<7b0_nN`O401OnO`_7oWl7aoj31l?nP`O3oXL;`00;oXL7`00CoX/7_oj?2konS`NooXl7_0_nT`Nh0
1?nT`^koY<7^ojG1kOnU`Nd3ojK1k@;oYl7/0_nW`>`3ojS1j`03ojS0jonY`>[oZL3Z00?oZL3Z00Co
Z/3Yoj^ojOn[_nWoZkoY0on[_nP2ojboj0;o[;kW0on]_nL01?n]_^Ko[[kVojjni_n^_^H2ojjni@?o
[kkU00?o[kgTok2ni?n`_^@00_n`_^@00on`_N?o/KkSok6mh`03ok:mh`04ok:nh_nb_N;o/kkRok>m
h@Co];kQ0_ne_^43okJnh003okNoh?ng_]oo]kkO00?o^;oO00?o^KoOokVog_nj`=h00_nj`=h01?nk
`Mko_L7Mokg1gOnm`Md2okk2g@03oko3gOno`mco_l?L00;o`LCL00Go`/GLol?5g?o3aMcoa<KKolG6
f`03olO8f`09olW9f_o9b][obL[Jol_;f_o<c=[ocLgIo`000?o>c]Wod=3I00;odM7I00Wodm;HomGE
f?oGe]Oof=SGomWIeooKfmKog=cFomkNe_oOh=H00oooool00ol0003oooooooooo`03ooooo`00:?oo
ool00ol0003oooooooooo`0`ooooo`0:o`0d[_l0Elco06[Jo`1Zf_lDNNCo7X3XobR6jolaRngo>Y3`
od6El@;oBIWc0_mEX?D00omKY?KoHJOfof6WmP02ofZ/m`;oKZkg00CoL[3gogJbmomf/_OoN[Cg0_mm
]OL01?n0]oOoPKOgoh6gmon4^?L2ohJimP;oRK[f00GoRk_fohflm_n>_?GoS[ceoi2mm@02oi:mm0;o
Tkkd00GoUKodoiJnlonG_o?oUkocoiS0l`02oiVolP04oi[0l_nK`?;oVl3boic1lP;oWL3a00CoW/7a
oio1lOnO`?3oWl3`0_nP`O001OnQ`O3oXL7_oj;1konR`NooXl7_00;oXl3^0onT`Nh01?nU`>goYL7]
ojG1kOnV`Nd2ojK0k0;oYl3/0_nW`>/3ojS0j`04ojRoj_nY_n[oZKoZojW0jP;oZKoY00?oZ[oYoj^o
jOn[_nP00_n[_nP2oj^ni`Co[;kW1?n]_^H00on^_^Ko[[gUojjmi@02ojjmi@05ojnniOn__NCo[kgT
ojnmi?n`_^@00_n`_N@2ok2mh`;o/KgS00?o/[gSok:mh_nb_N800_nb_N82ok>mh@03okBnhOnd_N7o
]KkQ00;o]KgP1?nf_^03okNng`;o^;oO0oni_mh01?nj`=ko^l3Nokc1gOnl`Md3okg1g@;o_/;M00Go
_l?Lol33g?o0`mco`LCLol;4g002ol?5g003olG6foo5am_oaLOK00;oalSK00Cob<WKolW:f_o:bm[o
c<cJ0_o<cMX03ol0003ocloIom3@fOoAdMWod];Iom?CfOoEeMSoe]KHomOHf?oIfMOof]_GomcMeooN
g]Kogn3Fon;Te@03ooooo`03o`000?oooooooooo00;ooooo000Yooooo`03o`000?oooooooooo033o
oooo00[o03>]o`1Gc?l0J][o06[JoaAii?lOP>So:8K[oc6<k_ljTO3o@YGa0_m9VO<2oeJQm@05oebT
m_mQYoKoHJOfofJYmom[[?L00_m_[_L01?mc/?OoMk;gogNbmomj/oL3ogjem`;oPKKg00?oQ;SfohNi
m_n7^OH00_n9^_H01On<^oKoS[ceohjlmOn>_?GoT;cd00;oT[gd00CoU;kdoiBmlonD_O?oU[kc0_nG
_o<3oiVolP04oiZol_nK`?7oVl3aoig0l@;oWKoa00CoW/3`oio0l?nO`?3oWl3`0_nP`>l01?nQ`Noo
XL3_oj;0k_nR`>h3oj?0kP04ojC0kOnU`>goYKo]ojFok@;oYL3/00GoY/3/ojJok?nW_n_oYko[ojO0
j`02ojNoj`?oZ;oZ00GoZ;oYojVojOnY_nWoZKoYojVnj@02ojZnj005oj^oj?n[_^SoZkkXoj^nion[
_NL00on/_^L2ojbmiP;o[KgV00?o[KkVojfmiOn^_ND00on^_ND5ojnmi003ok2mi?n`_N?o/;gS00;o
/;cS0_na_N83ok:mhP;o/[gQ0_nc_N42okBmh@?o]KgP0_nf_^03okNng`;o^;kO00Co^;oOokVog_ni
_mko^[oN0_nk`=h3okc1g@;o_L7M00?o_/;Moko2gOno`]d00_o0`m`3ol;4g003ol?5g?o4a]_oaLOK
00;oa/OK00KoalSKolS9foo8bM_ob/_Jol_<f_o<cMX2olg>fP06o`000?o@dMWod=7Iom;BfOoCdmWo
e]KH0_oGf=P01ooJfmOog=gGomcMeooOh=Koh>;Eon;TeOoSi]@00_ooool00ol0003oooooooooo`02
ooooo`00:_ooool2o`00037ooooo00[o03:[o`1Fbol0H=?o06WIoaAii?lOP>So:HK[oc:<k_ljTO3o
@YGb0_m9V_<2oeJQm@04oebTm_mRYoKoHZOfofNYm`;oK:cg0_m`[_L01?mg/_OoN;;gogRbmomk/oL2
ognem`;oP[Kf00?oQKOfohNim_n7^OH00_n:^_H01On<^oGoS[ceohjkm?n>^oCoT;cd00;oT[gd0onD
_O<01?nF__?oV;kboiRnl_nI_o82oiVnlP04oiZolOnL_o7oW;oaoifol@;oWKo`00CoW[o`oio0l?nO
_nooWko_0_nP_nl01OnQ`>ooXKo^oj:ok_nR_nkoXl3^00;oXko]00?oY;o]ojFokOnU_n`00onU_n`0
0onV_ncoY[o[ojNoj`02ojNoj`;oYkkZ00CoZ;kZojRojOnX_^WoZ;kY0onY_^T01?nY_^SoZ[kXojZn
j?n[_^P3oj^mi`Ko[;gV00Co[KgVojfmiOn]_>Go[KcU0on^_ND01?n^_>Co[kgTojnli?n__>@2ojnl
h`03ok2mhon`_>?o/;cS00Co/KcR00Co/[gRok:lh_nb_N7o/[cQ0_nc_N400ond_N7o];gPokBmh002
okFmh0;o][gO0ong_]l2okRng`03okVog_ni_]ko^KkN00;o^[oN0_nk`=h3okc1g@03okg1gOnn`]go
_l;M00;o_l?L00Co`<?Lol74g?o2a=co`/GL0oo4a]/00oo6am_oa/SKolS9f`02olS9f`?oblcJ01Co
cLkJolk?f_o?d=[o0000om7Bf_oCdmWoe=GIomGFfOoGf=Sof=WHom[Kf?oLgMOogMkGomkQeooRi=Go
hnKDonCYe?oUjm?oooooo`0000Cooooo000/ooooo`03o`000?oooooooooo02oooooo00CoM000o`1F
b_l0E/[o06WI0_lCNN@01?lYQ^_o<Xc^oc^Al?lkTO02odZJl`03oe6Mm?mGXOGoGJCf00;oHZOf00?o
IjWgofb/mom/[?L00_m`[_L01?md/?OoN;7gogRamoml/oL2ogndmP;oP[Kf00GoQKOfohNhm_n7^?Ko
R[Weohbjm@02ohfjm0;oSk_d00CoTKcdoi:llonB_??oU;gc0_nD_?<01?nF_O;oV;kboiRnl_nI__82
oiVnl@04oi^nlOnL_o7oW;oaoifol0;oWKk`00CoW[o_oinokonO_^ooWkk_0_nP_nh01OnQ_nkoXKk^
oj:okOnR_ngoXko]00;oXkk]00CoY;o/ojFok?nU_^coYKk/0_nU_^/00onV_n_oY[k[ojNnjP02ojNn
jP;oYkkY0_nX_^T2ojRmj0;oZKgX00CoZKkXojVmj?nZ_NOoZ[gW1?n[_NL01On/_NKo[;cVojbli_n/
_NKo[;cU00?o[KcU0_n]_>@4ojjli005ojnli?n__>?o[kcSojnlhon`_><00_n`_>84ok6lhP03ok:l
h_nb_>7o/[cQ00;o/[cQ00?o/kgQok>lhOnd_N000_nd_>02okFmh0;o][gO00Go]kkOokNmgong_Moo
^;kOokRngP02okVngP;o^[oN00?o^l3Nok_0gOnk`=d00_nl`Md3okk2g@;o_l?L0oo1a=`00oo2aMco
`lGLolC6f`02olG7f`08olK8foo7b=_ob<WKolW:foo:bm_oblcJolc=f_o>cmX2olo@fP04om3Af_l0
003od]?JomCEf@;oemSI00_of=WHom_Mf?oKgMSog^7GomoSeooQiMKoh^OFonCYe?oWk];oj?3Ao`00
0004ooooo`00;Oooool00ol0003oooooooooo`0`ooooo`03o`0^Y_l0E<Wo06SI00;o4gWT0_lXQ^/2
oc^Al0;oBY[c00?oDIgdoeRQmOmMY?H00_mSYoH00omXZOKoKJcgoff/m`02og6^m`04ogF`momi/OKo
NK7fogbcmP;oOkCf0_n3]_H01?n5]oKoR;SeohRhmOn:^OD3ohfjm0;oSk[d00CoTK_coi>llonC_??o
U;cc0_nE_?801?nF_O;oV;gboiRml_nI__42oiVml@04oi^nl?nL__3oW;g`oibml0;oWKk_00CoW[k_
oinnkonO_^koWkk^0onQ_^h01?nQ_^goX[k]oj:nkOnS_^d2oj>nk004ojBnk?nU_^coYKg[ojFmj`;o
YKk[00KoY[k[ojJmj_nW_N[oYkgZojNnjOnW_NT2ojRmj@?oZ;gX0onY_NP01?nY_>OoZ[gWojZmion[
_NL3oj^liP04ojbli_n/_>Go[;cUojbli@?o[KcU00?o[KcTojfki?n]^n@00_n^_>@2ojjkh`?o[kcS
00Co[k_Sok2lh_n`^n;o/;_R0ona_>800ona_>7o/[cQok:lh@03ok>lh@;o/kcP0ond_>001?ne_Moo
][gOokJmgonf_Ml2okNmg`?o^;kN0_ni_]h2okZogP?o^l3M00?o_<7Mokg1gOnn`]d00_nn`]d01Ono
`mco`<?Lol74g?o2a=co`lGL00;o`lKL0_o5am/02Oo7b=_oalWKolO9foo9b]_ob/_Kol_<foo<cM[o
cLkKolo@fP02om3AfP0:o`000?oCeM[oe=OJomOHfOoHf]WofM_Iom_Mf?oLgmSogN7HomoSe`;oh^OF
00CoiNcDonO^d_oooooo00001?ooool002kooooo00?o0000ooooooooool0<?ooool00ol0>[7o05?8
o`1Xf002oa=ii0;o:8K[0_lkTO02od^Jl`03oe6Mm?mHXOGoGZCf00;oHjOf00?oJ:Wfoff/m_m][?H0
0_ma[_L01?me[oKoNK7fogVam_mm/oH2oh2dmP;oPkKf00GoQ[OeohRhmOn8^?GoRkWdohfjm002ohfi
m0;oSk[c00?oTK_coi>klonC^o<00onE_?801?nG_?7oV;gaoiRmlOnI_O42oiZml004oi^ml?nL_O3o
W;g_oibmk`;oWKg_00CoW[k_oinnk_nO_NkoWkg^0onQ_^d01OnR_NgoX[g/oj:mk?nS_^coXkg/00;o
Y;g[0onU_N/01?nU_N[oY[gZojJmjOnV_NT3ojNmj@04ojNljOnX_>SoZ;cXojRmj0;oZ;cX1?nY_>L2
ojZliPCoZkcV00Go[;cUojbkiOn/^nGo[;cUojfli@04ojfki0Go[[_S0on_^n<00on_^n;o/;_Rok2k
hP02ok6khP03ok6lhOna^n7o/K_Q00;o/[cQ00?o/kcQok>lh?nc_>000_nc_>001?nd_>3o];cOokFm
gone_Ml3okJmg`04okNmgong_Mko^;kNokRngP;o^KoN0onj_mh00onk`=go_<3Mokg1g@02okg1g@03
okk2gOno`]go`<?L00;o`<CL00?o`/CLol;5g?o3a]`00_o4a]`01_o5am_oa/SLolO9foo8b]_ob/_K
ol_<f`;oblgK017ocLkKolk@foo@dM[odM;Jom;Cf_l0003oe=OJomKHf_oHf]WofM_Iom[MfOoLgmSo
gn?Hon3VeooRimKohnWEonG/e002ooooo`03o`000?oooooooooo00;ooooo000_ooooo`;o0000<Ooo
ool01Ol0>:oo05;7o`1Wf?l5L=ko4GSS00;o:8K[0_lkTO02od^Jl`03oe:Mm?mHXOGoF:7e00;oHjOf
00?oJ:Wfoff/m_m][?H00_mb[_H01?mf[oKoNK7fogVam_mm/_H2oh2dmP;oPkGe00?oQ[KeohRgm?n8
]o@00_n;^?@2ohfil`;oSk[c00CoTK[coi>kl_nC^_;oTk[b0_nE^o401OnG_?7oV;caoiRllOnJ_O3o
V[c`00;oVkc`00CoW;g_oiblkonL_>ooWKg^0_nN_Nh01OnO_NkoWkg]oinmkOnQ_NgoX[g]00CoX[g/
00GoXkg/oj>ljonT_N_oY;g[ojFmj`03ojFljP03ojJmjOnV_>WoYkcY00?oYkcY1?nX_>P01OnX^nOo
ZKcWojVlionY_>OoZK_V00?oZ[_V00CoZkcVoj^kiOn[^nGoZk_U0_n/^nD2ojbki0Co[K_T1On^^n<5
ojnkhP;o/;_R00?o/K_Rok6khOna^n400_na^n42ok:kh@03ok>lh?nc^n3o/kcP00;o/kcP00Co];cO
okFmgone_=oo]KcO0_nf_Ml2okNmgP?o^;kN0_ni_mh00onj_mko^koMok^og@02okc0g@08okg1gOnm
`]go_L;Moko2gOno`mgo`<CLol74g?o2aM`2ol?5g003olC6g?o5amcoa/SL00;oalWL00Kob<[KolW;
foo:c=_oblgKolc>foo>d=/2oloAf`0:om;Cf_oCeM[oe=OJo`000?oGf][ofM_Iom[MfOoKgmWogN;I
omoSf0;ohNSG00GoiNcDonK_doooooooooooo`000004ooooo`00<Oooool00ol0003oooooooooo`0_
ooooo`05o`0f[Ol0D<Go06KGo`A`gOl@N><00_lWQ^/2oc^Al003od>Fl_m;V_?oDYgd00;oF:7e0_mT
YoH00omYZOKoKZ_fofj[mP02og:]mP04ogJ_m_mj/OKoN[7fogfbmP;oP;?e0_n3]OD01On6]_CoRKOd
ohVgm?n;^?CoRkSc00;oS[Sc0_n@^O<01?nB^_;oTk[boi>jlOnC^_42oiFkl@05oiNklOnH_?3oV;_`
oiRkl?nJ^o000_nK_>l01?nL_>ooW;c^oiblk_nM_>h2oijlkP05oinmkOnO_>goWkc]oj6lkOnR_N`0
1?nR_>`2oj>lj`;oY;c[0_nU_>X2ojFlj@;oY[cY00GoYkcYojNlj?nW_>SoYkcXojRlj004ojRki`04
ojVlionY^nOoZK_VojVkiP;oZ[_V00?oZk_Uoj^jiOn[^nD00_n[^nD01On/^nGo[;[Tojbki?n/^nCo
[K_T00?o[K[S00?o[[_Sojjjhon^^^<00_n^^n<00on_^n;o[k[RojnkhP02ojnjhP03ok2khOna^n7o
/K_Q00?o/K_Q0_nb^n03ok>kh005ok>lh?nd^moo];cOokBlgone_=l00_nf_=l01onf_Moo]kgNokNm
g_ng_Mko^;kNokVng_ni_mh00_nj_mh00onk_mgo^l3Mokc0g@02okc1g@03okg2gOnn`]go_l?M00;o
_l?M00?o`LCLol75g?o3aM`00_o3a]`01Oo5amcoaLSLolO9g?o7b]cobL_K00;ob/cK01;oblgLolc>
foo=cm_ocm7Kom3BfooAe=_odmGJomCGfooEf=_o0000omSLf_oIg][ofmoIomgRfOoOi]SohNSGon?[
e_oTkMH4ooooo`03o`000?oooooooooo007ooooo000booooo`03o`000?oooooooooo033ooooo00_o
04o4o`1Ve_l0I]Ko3gORoa]oiolVQN_o<H_]ocZ@l?m3UO;oBiWcoe:Mm002oeRQm@03oejTmOmTY_Ko
JJWf00;oKZ_f0_mb[OH01?mf[oKoN[3fogZ`m_mm/_D2oh6cm@04ohBdmOn6]_CoQ[KdohVgm0;oRKKc
00?oS;Ocohjhlon>^?<00_n@^O801OnB^O;oTk[aoiBjlOnD^_7oUK[a00;oUk_`0onH^o001?nJ^noo
Vk__oi^kkonL_>h2oibkkP04oifkk_nN_>goW[c]oinlk@;oWkc/00CoXKc/oj:lk?nR^n_oX[_[0_nR
_>/01?nS_>_oXk_ZojBkj_nT^nX2ojFljP06ojFljOnU^nWoY[_YojJkjOnW_>SoY[_X0_nW^nP4ojRk
i`03ojVkionY^nKoZK_V00;oZK_V00GoZ[_VojZjiOn[^^GoZk[Uoj^ki@02oj^ji0Co[;[T1?n]^^<0
1?n^^^?o[[[Rojjjh_n^^^84ojnjhP04ojnjhOn`^^7o/;[Qok6kh@;o/K[Q0_na^n42ok:kh005ok>k
h?nc^moo/k_OokBkgond_=l00_ne_=l2okJlg`?o]kgN0_nh_Mh2okVngP?o^[oN0_nk`=d00onl`Mgo
_L7Mokg1g@02okk2g@08oko3gOo0a=go`<CMol75g?o2aMco`lKLolC7g?o5b=`2olK9g003olO:g?o8
bmcob/cK00;oblgL00KocLoKolkAfoo>dM_od=;Kom7DfooDem/2omGHf`08o`000?oIg][ofn3JomgR
fOoNi=WognKHon7Yf?oTkMH5ooooo`03o`000?oooooooooo007ooooo000cooooo`03o`000?oooooo
oooo033ooooo00_o032Uo`1<`Ol0HmCo3WKRoa]niolUQN[o<8_]ocV@l?m2UO7oBYWcoe:Mm002oeRQ
m@03oejTmOmTY_KoJJWf00;oKZ_f00?oLZgfogJ_m_mf[oH00_mj/?D01?mm/_GoPK?eoh6cmOn4]?@2
ohJem0?oRKKc00?oS;Ocohjhl_n>^?800_n@^?801OnB^O;oU;[aoiBilOnD^O7oUK[`00;oUk[`00Co
V;_`oiVjkonI^^ooV[[_0_nK^nh3oibkkP05oifkkOnN^ngoW[_]oinlk?nO^n`00_nQ^n`01?nR^n_o
XK_[oj6kjonR^n/2oj>kjP?oY;_Y0_nU^nT2ojFkj0?oY[_X00CoY[[WojNkionW^nOoZ;_W0_nX^^L0
1?nX^^KoZK_VojVji_nY^^H2ojVji@CoZ[[U0_n[^^@3ojbji0;o[;[S1?n]^^<4ojjjhP03ojnjh_n_
^^7o[k[Q00;o[k[Q0_n`^^401?na^^7o/K[Pok6jh?na^^03ok:kh0;o/k_O0_nd^ml3okFlg`04okJl
gonf_=ko]kgNokNmgP;o^;gN0oni_]h00onj_mko^[oMok_0g@02okc0g@;o_L7M00Ko_/;Moko3gOno
`mgo`<CMol74gOo2aM`2ol?6g@05olC7g?o4b=coa/WLolO9g?o8bm`00_o9c=`04Oo;cMcoblkLolc?
g?o>dM_ocm;Lom7DfooBeM_odmOKomGHfooFf]_oemcKo`000?oKh=[og>;JomoVf?oQjMSoh^cG00Ko
oooo00?o0000ooooooooool00Oooool003Cooooo00?o0000ooooooooool0<?ooool01Ol0;J;o04Zn
o`1Rdol<M^7o67gV00;o;h_]00Co>I3_od:ElOm:VO?oBYWc0_mHX?D00omNXoGoI:KfofBVmP02ofj[
mP03og:]m_mf[_KoMZkf00;oN[3e00CoO[7eoh6cm?n1/oCoQ;Cd0_n7]O@3ohVfl`04ohbfl_n>]o;o
S[Oboi2hlP;oT[Sa00CoU;WaoiBil?nD^O3oU[W`0_nG^_03oiVjk`05oiZjk_nK^^koVk[^oibkk_nL
^^d00_nM^^d2oijkk003oinkk?nO^^coXK_[00;oXK_[0_nQ^^/01?nR^^[oXk_Zoj>kj_nT^nT3ojBj
j@03ojFkj?nU^^SoYK[X00;oY[[X0_nV^^L2ojNji`05ojRjionX^^KoZ;[VojRji_nY^^H00_nY^ND0
1?nY^^GoZ[[UojZiiOnZ^ND2ojZji005oj^ji?n[^NCoZkWToj^ii?n/^^<00_n/^N<01On]^N?o[K[S
ojfih_n]^N;o[[[R00?o[[WR00Co[k[QojnihOn_^N7o[k[Q0on`^^42ok6jh0;o/[[P00Co/[_Pok:k
gonb^moo/k_O0ond^ml2okFlg`?o][cN0_ng_Mh00onh_Mko^;kNokVngP02okVngP03okZogOnk_mgo
_<3M00;o_<7M00?o_L7Mokk2gOno`md00_no`md01Oo1a=go`LGMol?6gOo3amgoa<SL00;oaLSM00?o
alWLolO;g?o9c=`00_o:cM`01_o<cmcocM7LolgAg?o?d]cod=CLom?Gf`;oe=WL00SoemcKomWNfooI
g]_o0000omgUf_oOimWoh>[Ion;/e`Kooooo00?o0000ooooooooool00Oooool003Gooooo0_l0000b
ooooo`04o`18_?l0Jm[o2gGQoaMli@;o;h[]0_m2U?42odVIl`;oF:3d00?oGZ?eofBVmOmTY_D00_m^
ZoH00omb[?KoMZkeogJ^m@02ogZ`m@04ogjamOn1/_CoPK;dohBcm0?oQkCc0_n9]O<01?n<]_;oS[Ob
ohjgl_n@]o43oi:hl@;oU;S`00GoU[W`oiNikonG^NooVK[_oiVikP02oiZikP;oVk[^0_nL^^d2oifj
k0;oW[[/00?oWk[/oinjjonQ^^/00_nQ^^/2oj6jjP03oj:jj_nS^^WoXk[Y00;oY;[Y0_nT^^P3ojFj
j0;oY[[W0_nV^NL2ojNjiP04ojRji_nW^NKoZ;WVojRiiPCoZKWU00?oZ[WUojZii?nZ^N@00_nZ^N@0
1?n[^NCoZkWSoj^ihon[^N<2ojbih`;o[KWS0on]^N82ojjihP;o[[WQ0_n_^N42ok2ih@04ok2jhOn`
^^3o/;[Pok6jh0?o/[[P00Co/[_Ook:jgonc^moo/k_O0ond^ml2okFlg`;o][cN0_ng_Mh3okRngP03
okVng_nj_mko^koM00;o^l3M0_nl`Md3okk2g@03oko3gOo0a=go`LGM00;o`/KM00Go`lOMolC7gOo5
b=goa/WMolO;g002olS<g@0@ol[=g?o;c]coc=3MolgAg?o>d]cod=CLom7Fg?oBemcoe=WLomKKg?oG
gMcofMkKom[Qfol0003ognOIon3Zf@Sooooo00?o0000ooooooooool00Oooool003Oooooo00?o0000
ooooooooool0<?ooool02_l0DlKo06[Io`1ZfOlENnGo8X?Yobb9k?lgSnoo@9CaodVHl_m@W?@2oeRP
m006oejSmOmTYOGoI:GeofVXmOm^Z_GoLZce0_mf[_D2ogZ_m@04ogjam?n1/_CoPK;dohBcm0?oQkCc
00?oRKGbohbfl_n<]_800_n>]_401?n@]o7oT[Saoi:gl?nB]o02oiBhl005oiJhkonG^NooUkW_oiVi
k_nH^Nh00_nJ^Nh2oi^ik@04oibjkOnL^NcoWKW/oifik0;oW[[/00KoWk[[oinijonQ^^_oXK[[oj6j
j_nQ^NX2oj:ij@;oXk[Y00GoY;[YojBij?nT^NSoY;WXojFjj002ojFii`;oY[WW0_nV^NH3ojNiiP?o
Z;WU00KoZKWUojRiiOnY^NCoZKWTojZii?nZ^>@2ojZii003oj^ihon[^>?oZkWS00;oZkWS00?o[;WS
ojbhh_n]^N800on]^N82ojjihP?o[[WQ00Go[kWQok2ihOn`^N7o/;WQok2jh002ok2ih003ok6jh?nb
^^3o/[[O00;o/[[O0onc^ml3okBkg`04okFlgone_=ko][cNokJlgP;o]kgN00?o^;kNokVng_ni_]h0
0_nj_mh01onk`=go^l3Nok_0g_nl`Mgo_L;Mokk2gOno`md00_o0a=d01?o1aMgo`/KMol;6gOo4amd2
olC8g@03olK9gOo7bmgob<cM00;obLgM00KoblkLolgAgOo=dMgoc];LoloDgOoBem`2om?Ig@06omKK
g?oHgmcof=oLom_SfooMi]_o00002Oooool00ol0003oooooooooo`01ooooo`00>?ooool00ol0003o
ooooooooo`0`ooooo`09o`0aYOl0Cl;o06OGoa=ji?lPP^Wo:hS/ocJ?koloTo7oB9Sb00;oD9cc00Go
EiodoefSmOmSYOGoHjGeofVWm@02ofjYm@;oMZke00?oNZodogj`m?mn/?@00_n1/_@01On4/o?oQ;;c
ohNclon7/o?oRKCb00;oS;Gb0_n>]_401On@]o7oT[O`oi:gl?nB]o3oU;O_00;oU[S_0_nG^>l01?nH
^NkoV;S^oiZhkOnJ^>d2oi^ik@;oW;W/0_nM^N`2oijij`;oWkW[0_nP^NX01?nQ^N[oX[WYoj:ijOnR
^NT2oj>ij@CoY;WX0_nU^NL2ojJii`04ojJii_nV^>KoYkWVojNiiP;oYkWU00GoZ;WUojRhiOnX^>Go
Z;WUojVii002ojVhi0;oZ[ST00KoZ[WTojZhhon[^>?oZkSSoj^ihon[^><2ojbhhP?o[KSR00?o[KWR
ojjihOn^^N401?n^^N400on_^N7o/;WQok2ih003ok2ih0;o/K[P0onb^]l01?nc^]oo/k_Ook>kgonc
^ml2okBkg`03okFlg_nf_=ko]kgN00?o]kgN00?o^;gNokVng_ni_]h00onj_mh01?nk`=ko_<7Nokg2
gOnm`]h3oko3g@08ol34gOo1aMgo`LGMol;6gOo3amgoa<SMolG9gOo7bmd2olO<g@0AolW=gOo:c]go
bm3MolgAgOo>dmgocmCMom3FgOoBf=godmWMomGKgOoFgMgof=oLomWRg?oKi=cog^SKooooool00000
2Oooool1o`00007ooooo0Oooool003Wooooo00?o0000ooooooooool0<Oooool02?l0C;oo06GEoa5i
holANN?o:HS/ocF>kolnTo7oAiSb0_m?Vo<2oefRm@;oHjGe00KoJ:OeoffYmOm]ZOGoLZ_eogJ]m?mj
[o@2ogj`m004oh6am?n1/O?oPK7cohBbl`;oQk?b00?oRKCbohbdlOn<]?400_n>]O401On@]_3oT[O`
oi:fl?nB]_3oU;O_00;oUKO_0_nG^>h01?nH^>koV;S]oiZhkOnJ^>d2oi^hk@06oibik?nL^>coWKS[
oifhjonN^N_oWkW[0_nO^>X2oj2hjP04oj6ijOnR^NWoX[SYoj:hj@;oXkWX00GoY;WXoj>hj?nT^>Oo
Y;SWojFii`03ojFhiP;oY[SV00CoYkWVojNhiOnW^>GoYkSU0onX^>D01?nX^>CoZKSTojVhi?nY^>@2
ojZhi0;oZ[SS0on[^><00on[^>;o[;SRojbhhP04ojfhhP05ojjihOn^^>7o[[SQojjihOn^^>400_n_
^N44ok2ih003ok6jh?na^]oo/K[O00;o/[[O0_nc^]l01Onc^moo];_OokBkgond^moo]KcO00;o][cN
0_ng_Mh01_nh_Mko^;kNokRng_ni_]ko^KoNokZogP;o^l3N0_nl`Mh2okg2gP03oko3gOnoa=go`LGM
00;o`LGM00Ko`lOMolC8g_o4b=koaLWMolK;g_o7c=d2olS=g@06ol[>gOo;d=goc=7NolkCgOo?e=go
d=KM0_oCf]d01OoEfmgof>3MomSPgOoKi=cog>OL00?ooooo00?o0000ooooooooool01_ooool1o`00
007ooooo0Oooool003[ooooo0_l0000booooo`04o`19_?l0I=?o3gSSo`mhh`;o:8O[0_lmT_02odjK
l`;oGJ;e0_mSY?D01?mXYoGoKJWeoffYmOmaZoD2ogJ]m004ogZ^m?mm[oCoOJodoh6`l`;oQ;;c0_n6
/_800on9/o;oS;Caohbdl@02ohjel@05oi2fl?nB]_3oT[K_oi:fkonC]^l00_nE]nh2oiNgkP06oiRh
kOnH]ngoV[O]oiZgkOnK^>coW;S/0_nL^>/2oifhj`04oijhjonO^>[oWkSZoinhjP;oX;SY00CoXKSY
oj:hjOnR^>SoX[SX0_nS^>P2oj>hi`;oY;SW00CoYKSWojFhi_nU^>KoYKSV0_nV^>H4ojNhi@04ojRh
iOnX^>CoZ;STojRhi0?oZKST00CoZKSSojZhhonZ^>?oZ[SS0_n[^><2oj^hhP;o[;SR0_n]^>82ojfh
h@Co[[SQ00?o[kWQojnih?n_^N001?n`^N03ok6jg`04ok:jgonc^]oo/k[Ook>jg`;o];_O0one_=l2
okJlgP;o]kgN0_nh_]h01oni_mko^[oNokZog_nk`=ko^l7Nokc1g_nm`]h00onn`mh02?noa=go`<CN
ol75gOo2a]ko`/ONolC8g_o5bMkoa/_N0_o7c=h03_o8cMgobLkNol_@gOo<dMkocM?NoloDgOo@e]ko
dMSNom?JgOoDg=koe]kNomSPgOoIhmgof^GM1?ooool00ol0003oooooooooo`06ooooo`7o00000Ooo
ool1ooooo`00??ooool00ol0003oooooooooo`0`ooooo`04o`0SU?l0H];o06;Bo`Ueh@;o9XK[0_ll
T_02odfKl`03oeBNm?mKXOCoHZCe00;oIjKe0_m]ZOD01?maZoGoMZcdogJ/m?mi[_@2ogf_l`03oh2`
lon3/O?oPk7c00;oQ[;b00CoRK?aoh^dlOn;]?7oS[C`0_n@]O001?nB]^ooT[G_oi:ekonC]^l2oiFf
kP04oiNgk_nH]ngoV;O]oiRgk@;oVKO/00CoVkO/oibhjonL]n_oW;O[0_nM]n/01OnN^>[oWkSZoing
jOnO]nWoX;SY00;oXKSY00KoX[SXoj:gj?nR]nSoXkSXoj>hionS]nL3ojBgi`;oYKSV0_nU]nH00onV
^>GoYkSUojNgi@03ojNgi@05ojRhi?nX]nCoZ;OTojRgi?nY^>@00onY]n<01OnZ^>?oZ[OSoj^gh_n[
]n;oZkSR00;oZkOR0_n/^>801?n]^>;o[KSQojfhhOn]^>44ojjhh@?o[kWP00Co/;WPok6ih?na^N3o
/KWP0_na^]l2ok:jg`03ok>jgonc^moo/k_O00;o];_O0_ne_=l2okJmgP?o]kgN00?o^;kNokVng_nj
_mh00_nj`=h01onk`Mko_<7Nokg2g_nm`]ko_/?Nokk4g_o0a=h00_o0aMh01_o2a]ko`lSNol?8g_o5
bMkoaL_NolO<gP;ob<gN00KobLkNol[@g_o;d]kocM?NolkEg_o@e]h2om;JgP04omCLg_oGhMkoen7N
om[Ug@Kooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool003gooooo00?o0000oooo
ooooool0<Oooool01Ol0@;;o05g=o`IdgolFONGo8XCY00;o>Y7`0_m<V_<00omDWOCoFZ7dof6Tm@02
ofNVm@03ofbXmOmaZ_CoLJ[d00;oMJcd00CoNJgdogf_lomm[o?oP;3c0_n3/O82ohJblP04ohVclOn;
/o7oRk?aohjdl0;oT;G`00CoT[G_oi6ekonA]NooTkG^0_nE]^h01?nG]^goV;O]oiRfkOnH]^d2oiVf
k003oi^gk?nL]n_oW;O[00;oWKO[0_nN]nX2oingj@;oX;OY0_nQ]nP3oj:gj005oj:gionS]nOoXkOW
ojBgionT]nH00onU]nH2ojFgi@04ojJgiOnW]nGoY[OUojJgi@;oYkOT1?nX]n@4ojVgh`;oZ[OS1?n[
]n82ojbghP03ojfhhOn]]n7o[KSQ00;o[KSQ0_n^^>42ojjhh005ojnih?n_^>3o/;WPok2ih?na^N00
0_na^Ml01?na^]oo/[[Ook:jgonb^]l2ok>kg`?o];_O0_ne_=l00onf_Mko]kgNokNmgP02okRngP06
okVng_ni_mko^/3Nok_0g_nl`Mko_<;N0onm`mh02?nna=ko_lCNol35g_o1a]ko`/ONol?8g_o4bMko
aL_N0_o6c=h03Oo8cMkobLoNol[@g_o;d]koc=?OolkEg_o?emood=WOom;Jg_oCgMooeMoOomOQg_oH
i=h02?ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00?_ooool00ol0003ooooo
ooooo`0aooooo`0:o`1<__l0ImKo0g;Noa=li?lOPnWo;H[]ocN?kom2UO7oBYWcoe>Mm0;oFZ3d0_mV
Y_D00om/Z?GoL:[dog2Zm002ogF/m004ogV]m?ml[_?oO:kcoh2_l`;oPk3b00?oQ[7bohRblOn8/_40
0_n;/o401On=]?3oSkC_ohndkonA]NooTKC_00;oTkG^0_nE]Nh01OnG]^goV;K]oiRfk?nH]^coVKK/
00;oV[K[0_nL]n/01?nM]n_oWKKZoijgj_nN]nX2oingj@05oj2gjOnP]nSoXKOXoj6gj?nR]nP00onR
]nL2oj>gi`;oY;OV0_nU]nH2ojFgi@?oY[OU00?oY[OTojNgi?nW]n@00onX]n@2ojRgh`CoZKOS0_nZ
]n84oj^ghP04ojbgh_n/]n7o[KOQojfgh@?o[KSQ00?o[[SQojnhh?n_^>000on_^>02ok2ih0;o/KWO
1Onb^]l2ok>kg`05okBkgone_=oo]KcOokJlgong_Mh00_ng_Ml2okRngP05okVog_nj`=ko^/3Nok_0
g_nk`Mh00_nl`]h00onm`mko_/CNoko4gP02ol35gP06ol76g_o3b=oo`lSOolC9g_o5bmooa/cN0_o7
c]l02Oo9cmkob]3Ool_Bgoo<dmooc]KOoloGgoo@fMood]_Oom?Mg`02omKRg`[ooooo00?o0000oooo
ooooool00oooool1o`00007ooooo0Oooool003oooooo0_l0000cooooo`;o06CC00Oo3GSRobZ9k?lZ
RNco=Hk_od2DlOm8V?;oDIcd00;oFIod0_mVYOD01?m[YoGoL:Wdog2Ym?mdZo@2ogR]m0;oO:kc00Co
Ojocoh>`l_n3/?;oQK7b0_n8/_42oh^bl003ohfcl?n?]>ooSkC_00;oTKC_0_nC]>h2oiBek@05oiJe
kOnH]^coV;G/oiRek?nI]^`00_nJ]^/2oibfj`;oWKKZ0_nN]^T2oinfj@05oj2gj?nO]^SoXKKXoj6f
j?nR]nL00onR]^L2oj>giP05ojBgi_nT]^KoY;KVojBfi_nU]nD00onV]^D2ojJgi006ojNgi?nW]^Co
Z;OTojRgi?nX]n?oZ;KS0onY]n<2ojVghP03ojZgh_n[]n;oZkOR00?oZkOR0_n/]n42ojfgh@;o[KSQ
0_n^^>44ojnhh0?o/;WP0_na^Ml3ok:jg`04ok>jgonc^moo];_OokBkg`;o]KcO0_nf_Ml02?ng_Moo
]kkOokNngonh_]ko^KoOok[0g_nj`=oo^l7N0_nk`]l2okg3g`06okk4g_nna=oo`<GNol36goo1amoo
`lSO0_o3b]l02?o5bmooa/cOolO>goo8cmoob]3Ool_Bgoo<e>3oc]KO0_o?f>001?oBfmoodmkPomCP
h?oFh]l;ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo0011ooooo`03o`000?oo
oooooooo037ooooo00Go046bo`1Oc_l9Mn7o6X3WobF6j`02ocjCl@07odNGl_m@W??oEiodoeNOm?mN
X_CoI:CdofZWm002ofnYm003og>[m?mh[?CoN:cd00;oNjkc00CoOjocoh:`l_n2/?;oQK7a0_n8/O40
0on;/_3oSK?`ohfcl002ohnck`05oi6dkonA/nkoTkC^oi>dk_nD]>d00_nF]Nd01?nH]NcoUkG/oiNe
k?nI]N`2oiZfj`;oVkK[00GoWKKZoibfj_nM]^WoWKKYoijfj@03oinfj0;oX;KX00GoXKKWoj:fionR
]^OoX[KWoj>fiP03ojBfiP;oY;KU00?oYKKUojJfiOnV]^@00onV]^@2ojNfi0;oYkKS0_nX]^<2ojVf
h`04ojVgh_nY]^;oZ[ORojZghP?oZkOR00CoZkOQojbghOn/]n7o[;OQ0_n]]n42ojfhh@;o[[SP0_n_
^>02ojnih0?o/;WP00Oo/KWOok6jgonb^]oo/[[Ook>jgonc^moo];_O00;o];cO00Ko]KcOokJmgonf
_Moo][gOokNngonh_]l3okVog`03ok[0gonj`Moo^l;O00;o_<?O00Go_LCOokk4gonoaMoo_lGOol36
g`02ol;9g`03ol?:goo4bn3oa/cO00;oa/kP00Wob<oOolWAh?o:dn3oc=CPolgFh?o?f>3od=[Pom7L
hOoCg^003_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool004;ooooo00?o0000oooooooo
ool0<_ooool02?l0G<co1WCOoaIni_lRQN[o<8c^ocZAl?m5Uo;oCI[c0_mFW_@00omMXOCoHjCdofVW
m002ofjXm004og>Zm?mg[?CoMjcdog^]l`;oOZkc0_n2[o801?n5/?7oQk7aohNalOn:/_02ohfbl0;o
Sk?_00GoTK?^oi2ck_nB]>koT[C^oiBdk@02oiJdk@04oiNek?nG]>coUkC/oiVej`;oV[G[00CoVkGZ
oibfj_nL]NWoW;GY0_nM]NT01OnN]^SoWkKXoinej?nO]NSoX;KW00;oXKKW00KoX[KWoj:fi_nR]^Ko
XkKVojBfi_nS]^H2ojBfi@;oYKKU00CoY[KTojFfi?nU]^CoY[KT0onW]^@2ojNfh`05ojRfhonY]^?o
ZKKSojVfhonY]^800onZ]^82oj^ghP;oZkOQ0_n/]n42ojfgh@?o[KSQ0_n^^>02ojnhh0Co/;WP0_na
^]l3ok:jg`;o/k_O0_nd_=l2okFlg`06okJmgong_]oo]kkOokRngonh_moo^KoO0_ni`=l01?nj`Moo
^l;Ookc3gonma=l2okk4g`04oko5goo0a]oo`LSPol;9g`;o`l[P00Soa<_PolG=h?o6c^3oam3PolWA
h?o:dn3obmGQolgFh0;oc]SQ00?odMcQom;OhOooool03oooool00ol0003oooooooooo`02ooooo`7o
00000Oooool004?ooooo00?o0000ooooooooool0<_ooool02Ol0AKGo05G5o`1`folOPnWo;H_]ocR@
l?m3U_;oBi[coeBNm002oe^Qm0;oHZ?d0_m]Z?@01?mbZ_CoMZ_cogJ[lomj[O<2ogj^lP;oPJob00Co
Q;3aohNalOn7/O7oR[7`0_n</_02ohjck`;oT;?^0_nB/nh00onD]>goU[C/oiJdk002oiNdk0;oV;C[
0_nJ]N/01OnK]N[oW;GYoibejOnL]NWoWKGY00;oW[GX0onO]NP01OnP]NOoXKGWoj6eionR]^KoX[GV
00;oXkGV0_nS]^H01?nT]^GoY;GUojFfiOnU]^D3ojFfi003ojJfi?nW]^CoYkKS00;oYkKS0_nX]^<0
1?nY]^?oZKKRojVfh_nY]^83ojZfhP;oZkOR0_n[]n42ojbgh@;o[KOQ0_n]^>42ojjhh0?o[kSP0on`
^N001Ona^N3o/K[Ook6jgonb^]oo/[_O00?o/k_O00Co];cOokJmgonf_Moo][gO0_ng_]l3okRog`03
okW0gonj`Moo^l;O00;o^l?P00Go_LCOokg5h?nna]oo_lOPol78h002ol79h003ol?:h?o3c>7oaLgP
00;oa/kQ00Woam3PolSAhOo9dn7obmGQolcGhOo>f>7ocm_Qom7Mh_oBgn404Oooool01Ol0003ooooo
oooooooooooo0000007ooooo0014ooooo`03o`000?oooooooooo03;ooooo00?o046`o`1Pc_l0KMT0
0_lLP^P01?leSnoo@IGaodVIlom9VO<2oeZPm005of2Sm?mVYOCoKJSdoffXm?maZO@00_mfZo<01?mj
[??oOJkbogf^l_n1[o82ohB`l@;oQk3a00GoRK7`ohbbkon</^ooS[;_oi2ckP02oi2bkP;oT[?^00Co
Tk?]oiFdk?nE]>coUkC/0onH]>/2oiVdj`05oi^dj_nL]NWoW;CYoibdjOnM]NT00_nN]NP2oinej0;o
X;GW0_nQ]NL4oj:eiP;oXkGU0_nT]ND2ojFei@04ojFfi?nU]NCoY[GTojJei0CoYkKS0_nX]^<4ojVf
hP?oZ[KR00CoZkKRoj^ghOn[]n7oZkOQ0_n/]n42ojfgh@;o[KSQ0_n^^>001On_^>3o[kWPok2ih?n`
^N3o/KWP00Co/K[P00?o/[_Ook>kh?nc^ml00_nd_>001ond_=oo][gOokJmgonf_Moo]kkOokNogonh
_ml00_ni`>001Onj`Moo^/;Pok_3h?nla>3o_LGP00;o_/KP00?o_lOPol38hOo1bN000_o2bn402?o3
c>7oa<gQolK>hOo7d>7ob=7QolWChOo;e^;oc=OQ0_o>fN800ooAgN;oooooooooo`0Aooooo`05o`00
0?ooooooooooooooool000000Oooool004Gooooo0_l0000dooooo`04o`1Lbol6M^3o1WKPobB6j`;o
<Xk^0_m7V?82oeROm005oenRm?mUYOCoIJGdofZWm?m`ZO@00_meZo@01?mi[??oOJgbogf]l_n0[_82
oh>_l@;oQ[3a00GoRK7`oh^akon;/NooS[;_oi2bkP02ohnbkP03oi6ckOnC/ngoTk?]00;oUK?/00Go
UkC/oiRdjonH]>_oV;C[oiVdjP02oiZdjP04oibdjOnK]>WoWKCYoifdj@;oW[CX0_nO]NP01?nP]NOo
WkCWoj6eionQ]NL4oj:eiP;oXkGU0_nT]ND2ojBei004ojFei?nV]NCoY[GTojJei0;oYkGS0_nW]^<2
ojRfh`04ojVfh_nX]^;oZKKRojVfhP;oZ[KR0_n[]^83oj^gh@04ojbghOn]]n7o[KOQojfgh@;o[KSQ
00Co[[SPojjhhOn_^N3o[kWP0_n`^N03ok6jh004ok:jh?nc^n3o/k_Pok>kh0;o];cP0_ne_N000onf
_Moo][kPokNog`02okRoh003okW0h?ni`N3o^/;P00;o^l?P00Go_<CPokg5hOnna^3o_/OQol38h@02
ol79h@03ol;;hOo3c>7oa<gQ00;oaLoR00Ooam3QolWDh_o9e>;obmKRolcHhoo>fN;ocmcS01Gooooo
00Co0000oooooooooooo00000Oooool004Oooooo00?o0000ooooooooool0<_ooool01_mg003o05C3
o`1`folPQNWo;hc^ocVBl0;oAIOb00?oCI_coeFNm?mMX_@00_mTY?@01OmYY_CoKZSdogBZm?mdZ_Co
N:cc00;oO:gc00CoOjkboh>_lOn3[o7oQ[3a0_n8/?02oh^ak`05ohfbkon=/NooSk;^ohnbk_nA/^d0
0_nC/nd2oiBck005oiJck?nH]>_oUk?[oiNcjonI]>X00_nJ]>X2oi^dj@05oifdjOnL]>SoWKCXoifd
j?nN]>P00onO]>L2oj2di`05oj6ei_nR]NKoX[CVoj:di_nS]ND00_nT]ND3ojBei006ojFei?nV]NCo
Y[GTojJei?nV]N?oYkKS0_nW]N<2ojRfh`05ojRfh_nY]^;oZKKRojVfh_nZ]^800on[]^82oj^gh@;o
[;OQ00?o[KOQojfhhOn]^>401?n^^>401?n_^N3o/;WPok2jh?n`^^02ok6jh0;o/[_P00Go/k_Pok>l
h?nc_>3o];cPokBmh002okFmh003okJnh?ng_n3o^;oP00;o^<7P00Go^L7Pok[2hOnk`n3o^lCQokg5
h@02okg6h@03okk7hOnob>7o`LWQ00;o`/_R00Wo`lcQolC>h_o5cn;oa]7RolOChoo9e>;ob]OSolcH
hoo=f^<06?ooool00ol0003oooooo`000001ooooo`00B?ooool00ol0003oooooooooo`0cooooo`04
o`1@__l0KMWo78?Xoab3j0;o=Y3`0_m;V_<01omCWOCoG:7dof:Tm?mRY?CoJ:KdoffXm?mcZ_@00_mg
Zo<2og^]l`04ogj^l_n2[o7oPZoaohF_l@;oR;3`00CoR[7_ohfakon</NooS;7_0_n>/Nh01?n@/^go
T[;]oi:bkOnD/n`2oiJck0?oUk?[00CoVK?ZoiZdj_nJ]>[oVkCY0onL]>P2oifdj005oijdionO]>Oo
WkCWoindionP]>H00_nQ]>H3oj:diP03oj>diOnT]NGoY;GU00;oY;GT0_nU]N@3ojJei003ojJehonW
]N?oYkGS00;oZ;KS0_nX]^83ojVfhP05ojZfh_n[]^;oZkORoj^gh_n[]n400on/]n42ojfhh@?o[[SQ
0on_^N401?n`^^3o/;[Qok2jhOna^^03ok:kh0;o/kcP00Go];gPokFnhOne_^7o][kPokNoh002okO0
h@03okS1h?ni`N7o^/;Q00;o^/?Q00?o^lCQokc5hOnma^400_nnan801Onob>7o`<[Rol;;h_o2cN;o
a<kR00;oaM3S00Goa]7RolSEhoo8eN?ob]OSol_Ii00Iooooo`03o`000?oooooo0000007ooooo0019
ooooo`03o`000?oooooooooo03Cooooo00?o05O4o`1Vd_lCO^D00_lbSnl2odRIl`05oe2Mm?mHX?Co
H:?dof2Sm?mVYO@00_m/Yo@2ogJ[l`03ogZ/lomn[O;oOZgb00;oPJka00CoQ:oaohN`l?n7/?3oR[3_
0on</Nl00on>/NkoT;;^oi2bkP02oi:bk@03oiBbk?nF/ncoU[?/00;oUk?[0_nH/nX2oiZcjP05oi^d
jOnL]>SoW;CXoibdj?nM]>P00_nN]>L3oindi`03oj2di_nQ]>KoXKCV00;oX[CV1?nS]>D2ojBei0;o
YKGT00CoY[GTojFei?nV]N?oY[GS0_nW]N<2ojRfh`;oZ;KR0_nY]^82ojZfhP?oZkOR00GoZkOQojbg
hOn/]n7o[;OQojfhh@03ojjhh@Co[kWQ0_n`^^42ok6kh@05ok:kh?nb_>7o/[cQok>lh?nd_N400one
_^402Onf_n7o]l3QokS1hOnh`N7o^L7QokW2hOnj`n7o^lCQokc5h@02okg6hP03okk7h_nobN;o`<[R
00;o`LcS00So`/gRol?>hoo5d>?oa];SolODi?o8eN?obMSTol_Ii1_ooooo0Ol00001ooooo`7o0000
001:ooooo`;o0000=Oooool02_l0D[oo073Jo`ilholOQNWo:hc]ocVBl?m3Uo;oCYcdoeJOm?mNX_D2
ofFUm@;oJZOd00?oKjSdogBZm?mi[?<00_mm[O800on0[_;oPjoaoh>_l@02ohJ_l005ohV`l?n</Noo
Rk3_oh^`kon=/Nh00_n?/Nh2oi6bk@05oi>bk?nE/ncoUK?/oiNcjonF/n/00_nH/nX2oiVcjP05oiZc
jOnL]>SoVk?Yoi^cjOnM]>P00_nN]>L01?nO]>OoW[CWoj2dionP]>L2oj6diP04oj:di_nR]>GoX[CU
oj:di@;oXkCU00?oY;GTojBdi?nU]N@00_nU]N@3ojJeh`;oYkGS1?nX]^<2ojVfhP;oZ[KR1?n[]n80
1On/]n7o[;SRojfhhOn]^>7o[[SQ00;o[[WQ0_n_^N43ok2jh@06ok6khOnb^n7o/[_Qok:lhOnc_>7o
];gQ0_nd_^401one_^7o][oQokO0hOng`>7o^<7QokS2hOni`^400_nja>800onka>7o^lKRokg6hP02
okg8hP08oko9h_nobn?o`LcSol;=hoo3c^?oa=3TolGCi?o7e>@2olSFi@03olWHi?oooooooooo01_o
oooo0_l0000004cooooo00?o0000ooooooooool0<Oooool02_l0003oooooooooool0B;?o06SCoaF1
i_lVRNco=Y7`ocnFl_m;Vo<2oe>Nm0;oHjCe00?oJ:KdofjXm?m^Z?@00_mbZ_@2ogb]lP03ogn^l_n3
[_7oPjka00;oQZo`00GoR;3`oh^`kon:/>ooR[3_ohfakP02ohnakP03oi6bkOnC/^coTk;/00;oU;;/
00GoU[?[oiJbjonG/n_oUk?[oiVcjP02oiZcj@;oVk?Y0_nL/nP2oifdj004oijdionP]>OoWkCWoind
i`?oXKCV0onR]>D01?nS]>GoY;CTojBdiOnT]>D3ojFei005ojJehonV]NCoY[GTojNehonX]^<00_nW
]^<01?nX]^?oZKKRojVfh_nY]^82ojZghPCoZkOR0_n/^>82ojfhhP04ojjihOn^^N;o[kWQojnih@?o
/;[Q0_na^n42ok:lh@03ok>lhOnc_N7o];kQ00;o];oR00Wo][oQokK0h_ng`N;o]l7RokS2hOni`n;o
^/CRok[5h_nka^800_nlan<00onmb>;o_/WSoko;h`02ol3<h`06ol;=hoo4dNGoa=7UolGCi?o6eNGo
b=KU7_ooool3o`000000COooool00ol0003oooooooooo`0`ooooo`0;o`000?oooooooooooooooomY
003o06C?oa1ni?lRQn_o;Hk^ocbDlOm5VO<00_m@WO@2of6Tm@04ofNVmOm/Z?CoK:Sdog6Ym0;oMZ_c
00KoNZccogj]l_n2[_7oPZkaohF_lOn7/?02ohN_l003ohV`kon</NooS;7_00;oS[7^00?oT;7]oi:b
k?nB/^`00_nD/^`01OnF/^_oUK;[oiNcjonG/n_oV;?Z00;oV[?Y00CoVk?Yoibcj?nL/nSoW;?X0_nM
/nP01OnN]>OoWkCWoindionO]>OoX;CV00;oXKCV0onR]>D00onS]>GoY;CUojBdi@02ojBei0;oYKGT
0_nV]N@5ojNfh`03ojRfhonY]^;oZKOS00;oZ[OR0_n[]n85ojbhhP;o[KWR00Oo[[WRojjjh_n_^^;o
[k[Rok2jhOn`^n;o/K_Q00;o/KcR00Oo/[gRok>mhOnc_^;o/kkRokBoh_ne_n;o]/3R00;o]/7R00Oo
]l;RokW3h_nia>?o^LCSok[5h_nka^?o_<OS00;o_LSS00So_/WSoko;i?o0c>?o`LkTol;@iOo4dNGo
a=CUolKEiAcooooo1?l00003ooooo`00C_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00?ooooo00Oo04Rbo`1Zdol3Mmoo:8c]ocRClOm2Uo;oCYcd00;oEIoe00GoG:;eofFUmOmZYoCo
JZOdofnYm002ogBZm003ogR/loml[O;oO:gb00;oOjkb00CoPjoaohJ_l?n6[o3oR;3`0_n;/>l2ohfa
kP04oi2akOnB/^goT[;]oi>bk0?oUK;[00?oU[;[oiRcj_nH/nX00_nI/nT01OnK/nWoW;?Xoibcj?nL
/nSoWK?X00;oW[CW0onO]>L01OnP]>KoXKCVoj6di_nR]>GoX[CV00;oXkCU0_nT]>D2ojBei0;oYKGT
0_nV]N@2ojNfi0;oYkKS0_nX]^<2ojVgh`04ojZgh_nZ]n?oZkORoj^ghP?o[;SR00Co[;WRojfih_n]
^N;o[KWR0_n^^^82ojnkhP03ok2kh_n`_>;o/KcR00;o/KgR00So/[gRok>nh_nd_n;o];oRokFoh_ne
`N?o]/7RokO2h`;o^<?S00_o^LCSok[5honjaN?o^lKSok_8i?nmb>?o_L[Toko;i?o0cNGo`LoUol;@
i@02ol?BiP03olCDiOoooooooooo01Oooooo1?l00007ooooo`00Coooool2o`0002oooooo00?o0000
ooooooooool01Oooool01?l0ILoo4GoUob>9jolSRN/2ocjFlP;oDYkd00GoFZ;eof2TmOmXYoGoJ:Oe
ofjXm002og:Zm004ogN[lomk[??oNjccogj]lP;oPZka0_n5[o401?n8/?3oR[3_ohZ`kon=/Nh2ohna
kP;oTK;]00?oTk;/oiFbjonD/^`00_nF/^/2oiNcjP;oVK?Y00GoV[?Yoibcj?nK/nWoVk?Yoibcj002
oijci`04oindionN]>OoWkCWoindi`;oXKCV00KoX[CVoj6di_nR]>GoX[CUoj>eiOnT]N@2ojBei@;o
YKGT00KoY[GTojJfi?nV]^CoY[KTojNfhonX]^<2ojRgh`;oZKOS0_nZ]n<2oj^hh`07ojbhh_n/^N?o
[;WRojbih_n]^N;o[K[RojjjhP02ojjkh`06ojnkh_n`_>;o/;cSok2lhona_N;o/[kS0_nc_^<00ond
_n;o]<3SokG1h`02okK2h`03okO2honga>Co^<CS00;o^LKT00Go^/OTok_8i?nlbNCo_L_Uokk<i@02
oko>iP03ol7?iOo1dNKo`m;V01Sooooo0ol0000;ooooo`00DOooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00Kooooo00Co04R`o`1Ka?l4NMoo:Xg]0_liU?42odnMm005oeNQmOmNXoGo
IZKeofJVmOm/Z?D00_maZO@01?meZoCoNJccogV/lomm[O82oh6^lP03ohB_lOn7/?3oQk3`00;oRK3_
00CoS;7_ohjak_n>/NkoT;7]0_nB/^`2oiBbk005oiJbjonE/^_oUk?[oiNcjonH/nX00_nJ/nT2oi^c
j@;oW;?X0_nM]>P2oijdi`;oWkCW0_nP]>H2oj6diP;oX[GV00GoXkGUojBeiOnT]NGoY;GUojFei@05
ojJfi006ojNfi?nX]n?oZ;OTojRgi?nY]n?oZ[OS0_nZ^><01?n[^>?o[;WSojbihon/^N<2ojfih`03
ojfjh_n^^^?o[[_S00;o[k_S0_n`_><2ok6mh`07ok:nhonb_n?o/koSok>ohond`>?o]<7SokK2h`02
okK3i005okO4i?nhaNCo^LKTok[7iOnkb>D00_nkb^D01OnmbnGo_LgVoko>i_o0d>Oo`M7V01Kooooo
1?l0000>ooooo`00D_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo00Co
06K>o`1dfolAPNGo7XSZ0_loUo801?m8VoCoE:3eoe^SmOmKXoD2ofVWm@03ofnYm?mcZoCoLj_d00;o
N:cc00CoO:gcogn^l_mo[_;oPjoa0_n6[o02ohR`l004oh^akon=/NkoSK7^oi2ak@;oT[;]0_nC/^`0
1OnE/^_oUK;/oiJcjonF/n_oV;?Z00;oVK?Y00CoVk?YoiZcjOnL/nSoW;?X0_nM]>P01onN]>OoWkCW
oindionO]>OoX;CWoj6di_nQ]NH00_nR]NH2oj>ei@04ojBeiOnT]^GoY;KUojFfi@CoY[KT0_nW]n@2
ojRgi0;oZKST00GoZ[SSojZhi?nZ^>CoZkWSojbih`02ojbjh`06ojfjhon^^^?o[[_Sojjkhon_^n?o
[kcT0_n`_N<00ona_N?o/KkTok:oh`02ok;0i007ok?1i?nd`N?o]L;TokG2i?nf`nCo]lCUokS5i002
okS7i@05ok[7iOnjbNKo^l[Uokc<i_nmcNH00_nncnL00oo0d>Ooooooooooo`0Aooooo`Co00004_oo
ool005?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0:ooooo`07o`1J`_l3NMoo
68GXobZ>k_leU?7oA9[codfNm@02oeRRm@03oejTm_mUY_KoKJWe00;oLZ[d00?oMZcdogZ]lomj[O<0
0_mn[_801?n1[o;oQJoaohF_lOn7/?02ohZ`k`;oSK7_00GoSk7^oi6bkOnA/^goTk;/oi:bk@02oiBb
k003oiJcjonG/n_oUk?[00;oVK?Z0_nJ/nT2oi^dj@04oibdj?nN]>SoW[CXoindi`;oW[CW00?oX;CW
oj6ei_nQ]NH00_nR]NH2oj>eiP04ojBfiOnS]^KoY;KUojBfi@;oYKKU00KoY[KTojJgiOnW]nCoYkOT
ojRgi?nX^>@2ojVhi006ojZhi?nZ^NCoZkWToj^ii?n/^^?o[;[T0_n]^n@01On^^n?o[[cTojjli?n_
_>Co[kgT00;o/;kT00?o/KkTok6oi?nb`>@00_nc`ND02Ond`^Co]L;TokG4iOnea>Go]lCUokO6iOnh
anGo^LSVok[9iP02ok_;i`03okc<i_nmc^Oo_/oW017ooooo1?l0000Fooooo`00E?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00cooooo00Oo04bao`1`e_lMRN[o<97_ocnHlom8W?Co
E:7e00;oFjCf0_mRY_H2og2Zm@04ogB[m?mi[OCoNJgdogb^l`;oP:kb0_n3[o401?n6/?7oRK3`ohV`
l?n</Nl2ohjakP;oT;;]00GoT[;]oi6bkOnC/^coTk;/oiFck002oiNcj`;oV;?Z00GoV[?YoiVcj_nK
]>WoVkCYoibdj@02oifdj004oijdionN]>SoWkGWoinei`;oXKGW00CoX[GVoj6eionR]^KoX[KV0_nS
]^H2ojBfiP04ojFgiOnV]nGoY[OUojJgi@;oYkSU00KoZ;STojRhiOnY^NGoZKWUojZii?nZ^^D2oj^j
i007ojbji?n/^nGo[K_Tojfki?n^_>Co[[gUojnmi002ojnni@07ok2oiOna_nCo/L7Uok71iOnc`NGo
/l;UokC3i@02okC4iP09okK5i_nga^Go^<SVokS8i_nib>Ko^L[Wok_;ionkcNSo_LkW00oooooo1?l0
000Jooooo`00EOooool2o`0002Wooooo00?o0000ooooooooool03_ooool01?l0J]3o5XGWoaJ5iole
U?42odBKm0;oF:?f00GoGjGfofFWm_mUYoKoJjWfog:[m@02ogN/m004og^]lomn[_?oOZkcoh:_lP;o
QK3a0_n8/?001On;/NooSK7_ohfakon?/^koTK;]00;oT;;^00?oT[;]oiBck?nD/n`00_nF/n/01OnH
/n_oVK?ZoiVdjonI]>_oV[CZ00;oW;CY0_nM]>P01_nN]>SoW[GXoinej?nO]NSoX;GWoj6ei`;oXKKW
0_nR]^L01_nS]^KoY;OVojBgi_nT]nKoYKOVojJgi@;oY[SV00GoYkSUojRhiOnX^NGoZ;WUojVii@03
ojZji@;oZk_U00Oo[;_UojbliOn]_>Go[KcUojjmiOn^_^Go[kkU00;o[koV00Wo/<3Uok71iOnb`^Ko
//;Vok?2iOnca>Ko]<CVokG6ionfanL00_ngbNP00onhbNOo^LcXok[<j00?ooooo`?o00007_ooool0
05Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`04o`1_dol6ON7o;i;`
obnBl0;oB9ge00KoD:7foebUm_mRYoKoHZOfofRYm_m^ZoH2ogF/m004ogV]m?mm[_?oOJkcoh6_lP;o
Q;3b00?oQk3aohVal?n9/O000_n</Nl01On>/^koT;;^oi2bk_n@/^koT[?]00;oU;?]0_nF/n`01OnG
/n_oVKC[oiRdjonH]>_oV[CZ00;oVkCY0_nL]NT01_nN]NSoWKGYoinej?nO]NSoX;KXoj6fi`;oXKKX
00GoX[KWoj>gionS]nOoY;OVojBgi`02ojFhiP?oY[SV00KoYkWVojRiiOnX^^KoZ;[VojVji_nZ^^D2
ojZkiP06oj^ki_n/_>Go[;gVojbmi_n]_NKo[[kU0_n^_nH01on__nKo/<7Vok71i_na`NKo//;Vok;3
ionca>H00_ndaNL01Onea^Oo]LSXokO9j?ngbnWo^LcX00gooooo1?l0000Qooooo`00F?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo00So04j`o`1RaOl;PN?o8Hg/oc>ElOln
V_?oC9ofoeBSmP;oGjKg00?oIJSfof^Zm_m[Z_H00_mg[O@2og^^m004ogn_lon2/?;oP[3bohF`l@;o
R;7a0_n;/_001On=/^ooS;;`ohnckon?/nooTK?^00;oTk?]00GoUK?/oiNdk?nG]>coV;C[oiRdk002
oiVdj`;oVkGZ00GoW;GYoifejOnM]^WoWKKYoijfj@02oinfj004oj6fj?nP]nSoX[OXoj:gj0;oXkOW
00KoY;OWojBhionU^>OoYKSWojJhi_nV^NL2ojNii`06ojRji_nX^^OoZK_VojVki_nZ^nKoZ[cW0_n[
_>H01On/_NKo[;kWojbnion]_^Ko[KoW00;o[/3W00Co/<7Vok32iona`nOo/LCX0_nbaNP00ondaNOo
]<OXokG8j002okK:j@03okO;jOoooooooooo00Sooooo1?l0000Uooooo`00FOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01Cooooo00Go0WgNoaV9jOlUT>go>9SbodNNm@02oe2RmP;o
HZSg0_mXZ_L00om][?KoLZgfog:]mP02ogf_m0;oPK3c00GoQ;7bohNalOn7/O7oR[;`ohbbl002oh^b
l003ohjckon@/nooT;?_00;oT[?^00GoU;C]oiJdk?nF]>coV;C/oiNek002oiRek004oiZejonK]N[o
VkGZoiffj@;oW;KZ00GoW[KYoingjOnO]nWoX;OXoj2gj@02oj6hj0;oX[SX0_nS^NP2ojBii`06ojJi
ionU^^SoYk[WojNjionX^^OoZ;_X0_nY_>L01onZ_>OoZ[gXoj^mion[_NOo[;kWojboj?n]_nL00_n]
`NP02?n_`^So/<;Wok34j?n`a>So/LCXok76jOnca^Wo/lSZ0_ndbNT00onfb^Woooooooooo`06oooo
o`Co0000:Oooool005[ooooo0_l0000Tooooo`03o`000?oooooooooo01Gooooo00GoE000o`1ad_lM
S>_o7Hc[oc^Jl`02od^PmP03oe>TmomJY_OoIJWg00;oJj_g0_m`[OH01?md[_KoNJoeogV_mOmm/?@2
oh6al`03ohBblon7/_;oQk;b00;oR[?a00CoS;?`ohnckon?/nooTKC_0_nC]>h2oiFdk@05oiNek?nF
]NgoV;G/oiRek?nI]^`00_nK]^/01?nL]^[oW;O[oifgj_nM]nX2oingj@06oj2gjOnO^>[oXKSYoj6h
jOnR^>SoX[WY0_nS^NT01_nT^^SoYK[XojFkj?nU^nSoY[_XojRkj0;oYkcX0_nY_NP02?nZ_NSoZ[kX
oj^oj?n[_nSo[;oXojc1jOn]`NSo[/;Y0_n_`nT00on`a>So/<GYok76j@02ok;8jP03ok?8j_oooooo
oooo00Gooooo1?l0000]ooooo`00G?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01Sooooo00Co07GEo`^4holeV?;o=ISb0_m>X_L2oeJUm`;oIj_g00CoKJcgog:^m_mb[_KoMjof0_mk
/?D2ogjam004oh:blon5/_?oQK;cohRclP;oRk?a0_n>]?001On@]>ooT[C^oi:dk_nD]NkoTkG_00;o
UKK^00CoUkK]oiVfk?nI]^coV[K/0_nJ]n`01OnK]ncoWKO[oifgjonN^>[oWkSZ00;oWkW[00CoXKWZ
oj:ijOnQ^^[oXK[Z0_nS^^X01_nT^^WoYK_XojFljOnU_>WoY[cYojNlj0;oYkgY00KoZ;kYojZnj?nZ
_nWoZ[oYoj_0jOn[`^X2ojc2jP03ojk2jOn^a>[o[lGZ00;o[lK[00?o/<O[ok;8j_ooool01Oooool3
o`00037ooooo001Mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06_ooool01_l0
I/Co3hOTobFBkOlhVo?o@Yoeoe6Tm`;oFJOh00GoGj[hofV/n?m_[_OoKjkgogB_m`02ogR`mP03ogba
mOn0/_CoP;;d00;oQ;?c00CoQk?cohVdl_n9]?;oS;Ca0_n?]O02oi6ek`05oi>ekonB]^ooU;K_oiBf
konF]nh00_nH]nd01?nJ]ncoVKS]oi^hkOnK^>d2oibhk006oijhjonM^NcoW[W/oijik?nP^^_oXK[Z
0_nQ^n/01OnR^n_oY;_Zoj>mjonS_N_oYKg[00;oY[gZ00?oYkgYojNojonX_nX00_nX`N/01?nZ`N_o
Zl;Zoj_3jon[`n/2ojc4j`03ojk4j_n^a^co[lK[00Gooooo1?l0000dooooo`00G_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01cooooo00Co06W6o`1kf?lXUNoo>igd0_m5XOH01_m>
YOOoFjWhof:[n?mRZoSoJ:ghog6_m`;oM[3g00CoN[7fogjbmOmn/_GoP[?d0_n5]?@2ohRdl`05oh^e
l_n=]O7oSKGaoi2fl?n?]_400_nA]o000onC]o3oUKO_oiFgk`02oiNgkP06oiVhkOnH^>koV[W^oiZi
k_nK^NgoWKW/0_nL^^d01OnN^^goWk_/oinkk?nQ^n_oXKc/00;oX[c/00GoXkg[oj>nk?nT_^coY;k/
ojJnj`02ojG0k006ojO0k?nX`N_oZ<;/ojS2k?nY`ncoZl?[0_n[aNd00on/aNcoooooooooo`02oooo
o`Co0000>?ooool005oooooo0_l0000Oooooo`03o`000?oooooooooo01kooooo00Oo06c7o`1nf_lE
SNOo:iO`ocNMlom8XoOoD:Oh00;oGJ_i00GoI:giofZ_nOmZ[oWoKk3hogNam`02ogbbmP04ogncm_n3
]?CoPkCdohJem0;oRKGc00CoS;KbohZflon=]o;oSKOb0_n@]o401OnB^?7oU;S`oiBhl?nF^>ooUKW`
00;oUkW_0_nI^^l01OnK^^koW;[]oibkk_nL^nkoWK_^00;oWkc]00KoXKc/oj2mkOnR_NgoX[g]oj>n
k?nS_nd2ojBok@07ojG0k?nU`NgoYl;]ojO2kOnX`^coZ<C^ojW4k@04ooooo`Co0000??ooool0067o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Qooooo`04o`21folHSnSo;Y[aocVO
m0;oBZGg0_mO[?T2ofJ^n@04ofb`nOma/_WoLK;iogJcn0;oN[Cg00?oO[Ggoh:fm_n2]_H00_n5]_D0
1?n9]oCoS;Scohbhlon>^?82oi6hlP;oTkWa00KoUKW`oiBjlOnF^_3oU[[`oiRkl?nJ^nl2oiVll005
oi^lkonM_>ooWKc_oijmk_nN_^l00_nO_^l01?nQ_nkoX<3_oj;1konR`Nl2ojC1kP03ojG1kOnU`noo
Y/?^00?ooooo1?l00010ooooo`00H_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
02Cooooo00Go08?KoaZAjOlVV>ko>j7dodbWn002oeB[n@;oIk3j0_m]/_T01?mb/oWoMkChogNdn?ml
]_P2ognfm`03oh>gm_n7^?KoQkSf00;oR[Sd00GoSKWdohnilon?^O?oT[[boi2kl`02oi>klP05oiFk
l_nG_?7oUkcaoiVll?nH_O400_nJ_O42oibnl006oijnkonM_o7oWl3`oio0l?nP`>ooX<;a0_nR`_00
1?nS`nooooooooooooooool3o`0004Cooooo001Sooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:?ooool00olXV^ko?:?eocbSm@02oeJ/nP;oGJoj0_m_/oX00omd]OWoNKKiogVfn@02
ogfgn005oh6hn?n4^?OoQ;SgohRim_n;^_D00_n9^oH00on<^oKoSkceohnlm@02oi6lm005oi>llonF
_O;oU;kdoiBnm?nG__<00_nI_o801OnK_o7oV/7coic1l_nL`O;oW/7a00Cooooo1?l00017ooooo`00
I?ooool2o`0001[ooooo00?o0000ooooooooool0;Oooool2odNYn0;oG[7k00?oIK?kof^enom[]O/0
0_ma]o/01?mf^?[oNkWjog^in_mo^_T2oh>kn@;oQ[_h00GoRKcgohfmm_n=_OKoSkgeohjnm`02oi2o
mP04oi>omOnE`?CoUL3doiS0m0Gooooo1?l0001;ooooo`00I_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo03?ooooo0_mV]O`00om/]ocoL[Skog:hn`02ogNjn`04og^kn_n0_?[oP;cj
ohBln@;oQkgh00?oRkkhooooooooool01oooool4o`0004oooooo001Wooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0A_ooool4o`0005?ooooo001Xooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0@_ooool4o`0005Oooooo001Yooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0?oooool3o`0005_ooooo001Zooooo`;o00005?ooool00ol0003ooooooooo
o`0kooooo`Co0000G_ooool006cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0g
ooooo`Co0000H_ooool006gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0coooo
o`Co0000I_ooool006kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0_ooooo`Co
0000J_ooool006oooooo0_l0000>ooooo`03o`000?oooooooooo02gooooo0ol0001^ooooo`00LOoo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo1?l0001aooooo`00L_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0001eooooo`00Loooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0001iooooo`00M?ooool2o`0000Wo
oooo00?o0000ooooooooool07Oooool4o`0007gooooo001fooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06_ooool3o`00087ooooo001gooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool05_ooool4o`0008Cooooo001hooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04_ooool4o`0008Sooooo001iooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03_ooool4o`0008cooooo001jooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co
0000T?ooool007cooooo00Co0000oooooooooooo00002Oooool3o`0009Cooooo001mooooo`03o`00
0?oooooo000000Gooooo1?l0002Gooooo`00O_ooool2o`000003ooooool0003o000000;o0000Vooo
ool007oooooo0_l0002Oooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00<Ooo
ool3o`0008[ooooo00?o0000ooooooooool0:oooool3o`0001Gooooo00?o0000ooooooooool06Ooo
ool003;ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool06?ooool002cooooo0ol00003ooooo`?o00001?ooool2o`00
00;ooooo1Ol00002ooooo`?o00000oooool4o`000003ooooool0003o000000?o00001oooool3o`00
00Cooooo1?l00003ooooo`;o00000_ooool6o`0000Kooooo1?l00002ooooo`Go000000?oooooo`00
0?l000000ol000000ooooooo0000o`000003o`0000;ooooo0ol00002ooooo`?o00001?ooool3o`00
00;ooooo0ol000001?oooooo0000o`000?ooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool00_ooool3
o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`Co00000ooo
ool2o`0000;ooooo2_l00005ooooo`03o`000?oooooooooo01Oooooo000[ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000003?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo0000
1?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Oooooo000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00003
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooooooool5o`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Ko0000oooooooo
oooo0000ooooool00005ooooo`Go00002?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
0000ooooool000000_ooool3o`0000?ooooo00?o0000ooooool000000_ooool5o`0000?ooooo00Co
0000oooooooooooooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0
003oooooooooool00005ooooo`04o`000?ooooooooooo`0000;ooooo0ol00005ooooo`03o`000?oo
oooooooo01Oooooo000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`?o
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo
00Co0000oooooooooooo00001Oooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000
ooooooooool05oooool002_ooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000;ooooo1?l0
0002ooooo`?o00001?ooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00Co
0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002Oooool01Ol0003ooooo
ooooool0003ooooo00?o00001?ooool4o`0000;ooooo1?l00002ooooo`?o00000_ooool2o`000003
ooooool0003o000000;ooooo0ol00002ooooo`Co00000oooool3o`0000?ooooo0ol00009ooooo`03
o`000?oooooooooo00;ooooo1_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l0
00000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1?l00003ooooo`Wo
00000oooool3o`0000?ooooo1?l00004ooooo`03o`000?oooooooooo01Oooooo000[ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00So
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`00;?ooool3o`00
00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`?o00002Oooool4o`00
00Wooooo00?o0000ooooooooool00_ooool2o`0000[ooooo1?l00004ooooo`03o`000?oooooooooo
00Cooooo0_l00004ooooo`;o0000;_ooool00ol0003oooooooooo`0Hooooo`?o00005_ooool00ol0
003oooooooooo`02ooooo`;o00002oooool00ol0003oooooooooo`0Iooooo`00oooooolQooooo`00
oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0766635, 0.0561551, \
0.00358626, 0.00358626}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[BoxData[
    \("Warning: too few sample points."\)], "Print",
  CellLabel->"From In[58]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[BoxData[
    \("Need to increase the NumberOfPoints option."\)], "Print",
  CellLabel->"From In[58]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[BoxData[
    InterpretationBox[\("Suggestion: NumberOfPoints -> "\[InvisibleSpace]2048\
\[InvisibleSpace]"."\),
      SequenceForm[ "Suggestion: NumberOfPoints -> ", 2048, "."],
      Editable->False]], "Print",
  CellLabel->"From In[58]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -93 0 ]
[.5 .82364 93 9 ]
[.1146 .21193 -24 -8.95964 ]
[.1146 .21193 0 .04036 ]
[.33419 .12554 -5.58728 -9 ]
[.33419 .12554 .41272 0 ]
[.57359 .03143 -15.4422 -9 ]
[.57359 .03143 2.55775 0 ]
[.74299 .05958 0 -6.19846 ]
[.74299 .05958 24 2.80154 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95308 .38129 0 -5.89405 ]
[.95308 .38129 18 3.10595 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01401 .32842 -18 -2.79587 ]
[.01401 .32842 0 6.20413 ]
[.00348 .3944 -18 -2.8519 ]
[.00348 .3944 0 6.1481 ]
[-0.00749 .4632 -18 -2.91059 ]
[-0.00749 .4632 0 6.08941 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Point Spread Intensity Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.12392 .22116 m
.12858 .22578 L
s
[(-0.5)] .1146 .21193 1 .99103 Mshowa
.34276 .13547 m
.34705 .14044 L
s
[(0)] .33419 .12554 .86243 1 Mshowa
.58123 .0421 m
.58505 .04743 L
s
[(0.5)] .57359 .03143 .71581 1 Mshowa
.125 Mabswid
.16624 .20459 m
.16899 .20741 L
s
.20926 .18775 m
.21197 .1906 L
s
.25301 .17062 m
.25568 .17351 L
s
.2975 .15319 m
.30012 .15613 L
s
.3888 .11744 m
.39132 .12047 L
s
.43565 .0991 m
.43812 .10217 L
s
.48332 .08043 m
.48573 .08355 L
s
.53184 .06144 m
.53419 .06459 L
s
.0823 .23746 m
.08513 .24019 L
s
.04135 .2535 m
.04422 .25619 L
s
.63151 .02241 m
.63374 .02565 L
s
.68271 .00236 m
.68488 .00565 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.73071 .06421 m
.72457 .06653 L
s
[(-0.2)] .74299 .05958 -1 .37743 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94054 .38517 m
.93427 .38712 L
s
[(0.2)] .95308 .38129 -1 .30979 Mshowa
.125 Mabswid
.76088 .11035 m
.75718 .1117 L
s
.78977 .15455 m
.78607 .15588 L
s
.81748 .19693 m
.81376 .19823 L
s
.86962 .27669 m
.86588 .27793 L
s
.89417 .31425 m
.89043 .31546 L
s
.9178 .35038 m
.91405 .35157 L
s
.6992 .01601 m
.69553 .01743 L
s
.96245 .41869 m
.95868 .41983 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02628 .32378 m
.03242 .32145 L
s
[(200)] .01401 .32842 1 -0.3787 Mshowa
.01581 .38989 m
.02197 .38763 L
s
[(400)] .00348 .3944 1 -0.36624 Mshowa
.00488 .45883 m
.01107 .45665 L
s
[(600)] -0.00749 .4632 1 -0.3532 Mshowa
.125 Mabswid
.03386 .27595 m
.03753 .27453 L
s
.03136 .29173 m
.03503 .29032 L
s
.02883 .30767 m
.03251 .30627 L
s
.0237 .34005 m
.02739 .33866 L
s
.0211 .35649 m
.02479 .35511 L
s
.01847 .3731 m
.02216 .37174 L
s
.01312 .40685 m
.01682 .40551 L
s
.0104 .42399 m
.01411 .42266 L
s
.00766 .44132 m
.01136 .44 L
s
.00207 .47654 m
.00579 .47524 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.41009 .59326 m .41211 .589 L .41504 .59177 L .664 .742 .908 r
F
.41009 .59326 m .40714 .5905 L .41211 .589 L F
.41504 .59177 m .41708 .5875 L .42001 .59027 L .663 .741 .908 r
F
.41504 .59177 m .41211 .589 L .41708 .5875 L F
.40714 .5905 m .40916 .58621 L .41211 .589 L .665 .743 .908 r
F
.40714 .5905 m .40419 .58775 L .40916 .58621 L F
.42001 .59027 m .42207 .58599 L .42499 .58876 L .664 .742 .908 r
F
.42001 .59027 m .41708 .5875 L .42207 .58599 L F
.41211 .589 m .41414 .58472 L .41708 .5875 L .663 .741 .908 r
F
.41211 .589 m .40916 .58621 L .41414 .58472 L F
.42499 .58876 m .42706 .58448 L .42998 .58726 L F
.42499 .58876 m .42207 .58599 L .42706 .58448 L F
.40419 .58775 m .40621 .58344 L .40916 .58621 L .663 .74 .907 r
F
.40419 .58775 m .40123 .58494 L .40621 .58344 L F
.41708 .5875 m .41913 .5832 L .42207 .58599 L .664 .741 .908 r
F
.41708 .5875 m .41414 .58472 L .41913 .5832 L F
.42998 .58726 m .43206 .58297 L .43497 .58575 L .663 .741 .908 r
F
.42998 .58726 m .42706 .58448 L .43206 .58297 L F
.40916 .58621 m .41119 .58192 L .41414 .58472 L .664 .742 .908 r
F
.40916 .58621 m .40621 .58344 L .41119 .58192 L F
.42207 .58599 m .42413 .58168 L .42706 .58448 L F
.42207 .58599 m .41913 .5832 L .42413 .58168 L F
.43497 .58575 m .43707 .58144 L .43998 .58426 L .665 .742 .908 r
F
.43497 .58575 m .43206 .58297 L .43707 .58144 L F
.40123 .58494 m .40324 .58063 L .40621 .58344 L .664 .742 .908 r
F
.40123 .58494 m .39826 .58216 L .40324 .58063 L F
.41414 .58472 m .41619 .5804 L .41913 .5832 L .663 .741 .908 r
F
.41414 .58472 m .41119 .58192 L .41619 .5804 L F
.42706 .58448 m .42914 .58017 L .43206 .58297 L F
.42706 .58448 m .42413 .58168 L .42914 .58017 L F
.43998 .58426 m .44209 .57994 L .44499 .58273 L .663 .74 .907 r
F
.43998 .58426 m .43707 .58144 L .44209 .57994 L F
.40621 .58344 m .40823 .57912 L .41119 .58192 L .663 .741 .908 r
F
.40621 .58344 m .40324 .58063 L .40823 .57912 L F
.41913 .5832 m .42119 .57888 L .42413 .58168 L .664 .741 .908 r
F
.41913 .5832 m .41619 .5804 L .42119 .57888 L F
.43206 .58297 m .43416 .57865 L .43707 .58144 L .664 .742 .908 r
F
.43206 .58297 m .42914 .58017 L .43416 .57865 L F
.44499 .58273 m .44712 .57841 L .45002 .58122 L F
.44499 .58273 m .44209 .57994 L .44712 .57841 L F
.39826 .58216 m .40027 .57783 L .40324 .58063 L .665 .742 .908 r
F
.39826 .58216 m .39528 .57936 L .40027 .57783 L F
.41119 .58192 m .41324 .57759 L .41619 .5804 L .664 .741 .908 r
F
.41119 .58192 m .40823 .57912 L .41324 .57759 L F
.42413 .58168 m .42621 .57736 L .42914 .58017 L .664 .742 .908 r
F
.42413 .58168 m .42119 .57888 L .42621 .57736 L F
.43707 .58144 m .43918 .57712 L .44209 .57994 L F
.43707 .58144 m .43416 .57865 L .43918 .57712 L F
.45002 .58122 m .45216 .57689 L .45505 .57969 L F
.45002 .58122 m .44712 .57841 L .45216 .57689 L F
.40324 .58063 m .40527 .5763 L .40823 .57912 L .663 .741 .908 r
F
.40324 .58063 m .40027 .57783 L .40527 .5763 L F
.41619 .5804 m .41825 .57606 L .42119 .57888 L .664 .742 .908 r
F
.41619 .5804 m .41324 .57759 L .41825 .57606 L F
.42914 .58017 m .43123 .57584 L .43416 .57865 L .663 .74 .908 r
F
.42914 .58017 m .42621 .57736 L .43123 .57584 L F
.44209 .57994 m .44422 .5756 L .44712 .57841 L .663 .74 .907 r
F
.44209 .57994 m .43918 .57712 L .44422 .5756 L F
.45505 .57969 m .45721 .57535 L .46009 .57818 L .664 .742 .908 r
F
.45505 .57969 m .45216 .57689 L .45721 .57535 L F
.39528 .57936 m .39728 .57502 L .40027 .57783 L .663 .74 .907 r
F
.39528 .57936 m .39229 .57654 L .39728 .57502 L F
.40823 .57912 m .41027 .57478 L .41324 .57759 L .663 .741 .908 r
F
.40823 .57912 m .40527 .5763 L .41027 .57478 L F
.42119 .57888 m .42326 .57454 L .42621 .57736 L F
.42119 .57888 m .41825 .57606 L .42326 .57454 L F
.43416 .57865 m .43626 .5743 L .43918 .57712 L .664 .742 .908 r
F
.43416 .57865 m .43123 .57584 L .43626 .5743 L F
.44712 .57841 m .44926 .57407 L .45216 .57689 L .664 .741 .908 r
F
.44712 .57841 m .44422 .5756 L .44926 .57407 L F
.46009 .57818 m .46227 .57383 L .46514 .57666 L .663 .741 .908 r
F
.46009 .57818 m .45721 .57535 L .46227 .57383 L F
.40027 .57783 m .40229 .57348 L .40527 .5763 L .664 .742 .908 r
F
.40027 .57783 m .39728 .57502 L .40229 .57348 L F
.41324 .57759 m .41529 .57324 L .41825 .57606 L F
.41324 .57759 m .41027 .57478 L .41529 .57324 L F
.42621 .57736 m .42829 .573 L .43123 .57584 L F
.42621 .57736 m .42326 .57454 L .42829 .573 L F
.43918 .57712 m .4413 .57277 L .44422 .5756 L F
.43918 .57712 m .43626 .5743 L .4413 .57277 L F
.45216 .57689 m .45432 .57253 L .45721 .57535 L .664 .741 .908 r
F
.45216 .57689 m .44926 .57407 L .45432 .57253 L F
.46514 .57666 m .46733 .57231 L .4702 .57512 L .663 .741 .908 r
F
.46514 .57666 m .46227 .57383 L .46733 .57231 L F
.39229 .57654 m .39429 .57219 L .39728 .57502 L F
.39229 .57654 m .38929 .57372 L .39429 .57219 L F
.40527 .5763 m .4073 .57195 L .41027 .57478 L F
.40527 .5763 m .40229 .57348 L .4073 .57195 L F
.41825 .57606 m .42031 .57171 L .42326 .57454 L F
.41825 .57606 m .41529 .57324 L .42031 .57171 L F
.43123 .57584 m .43333 .57147 L .43626 .5743 L .663 .74 .907 r
F
.43123 .57584 m .42829 .573 L .43333 .57147 L F
.44422 .5756 m .44635 .57124 L .44926 .57407 L .663 .741 .908 r
F
.44422 .5756 m .4413 .57277 L .44635 .57124 L F
.45721 .57535 m .45938 .571 L .46227 .57383 L .664 .742 .908 r
F
.45721 .57535 m .45432 .57253 L .45938 .571 L F
.4702 .57512 m .47241 .57077 L .47527 .57359 L .664 .743 .908 r
F
.4702 .57512 m .46733 .57231 L .47241 .57077 L F
.39728 .57502 m .3993 .57064 L .40229 .57348 L .664 .741 .907 r
F
.39728 .57502 m .39429 .57219 L .3993 .57064 L F
.41027 .57478 m .41232 .57041 L .41529 .57324 L .664 .741 .908 r
F
.41027 .57478 m .4073 .57195 L .41232 .57041 L F
.42326 .57454 m .42535 .57018 L .42829 .573 L F
.42326 .57454 m .42031 .57171 L .42535 .57018 L F
.43626 .5743 m .43838 .56994 L .4413 .57277 L F
.43626 .5743 m .43333 .57147 L .43838 .56994 L F
.44926 .57407 m .45141 .5697 L .45432 .57253 L F
.44926 .57407 m .44635 .57124 L .45141 .5697 L F
.46227 .57383 m .46445 .56946 L .46733 .57231 L .663 .741 .908 r
F
.46227 .57383 m .45938 .571 L .46445 .56946 L F
.38929 .57372 m .39128 .56935 L .39429 .57219 L .664 .742 .908 r
F
.38929 .57372 m .38627 .57089 L .39128 .56935 L F
.47527 .57359 m .4775 .56923 L .48035 .57207 L F
.47527 .57359 m .47241 .57077 L .4775 .56923 L F
.40229 .57348 m .40431 .56911 L .4073 .57195 L .663 .741 .908 r
F
.40229 .57348 m .3993 .57064 L .40431 .56911 L F
.41529 .57324 m .41735 .56887 L .42031 .57171 L .663 .742 .908 r
F
.41529 .57324 m .41232 .57041 L .41735 .56887 L F
.42829 .573 m .43039 .56863 L .43333 .57147 L .664 .742 .908 r
F
.42829 .573 m .42535 .57018 L .43039 .56863 L F
.4413 .57277 m .44344 .5684 L .44635 .57124 L .663 .741 .908 r
F
.4413 .57277 m .43838 .56994 L .44344 .5684 L F
.45432 .57253 m .45648 .56816 L .45938 .571 L F
.45432 .57253 m .45141 .5697 L .45648 .56816 L F
.46733 .57231 m .46954 .56793 L .47241 .57077 L .663 .74 .908 r
F
.46733 .57231 m .46445 .56946 L .46954 .56793 L F
.39429 .57219 m .39629 .5678 L .3993 .57064 L .664 .741 .908 r
F
.39429 .57219 m .39128 .56935 L .39629 .5678 L F
.48035 .57207 m .48259 .56769 L .48544 .57053 L F
.48035 .57207 m .4775 .56923 L .48259 .56769 L F
.4073 .57195 m .40934 .56757 L .41232 .57041 L F
.4073 .57195 m .40431 .56911 L .40934 .56757 L F
.42031 .57171 m .42239 .56734 L .42535 .57018 L .663 .741 .908 r
F
.42031 .57171 m .41735 .56887 L .42239 .56734 L F
.43333 .57147 m .43544 .56709 L .43838 .56994 L F
.43333 .57147 m .43039 .56863 L .43544 .56709 L F
.44635 .57124 m .4485 .56685 L .45141 .5697 L .664 .741 .908 r
F
.44635 .57124 m .44344 .5684 L .4485 .56685 L F
.45938 .571 m .46156 .56662 L .46445 .56946 L .664 .742 .908 r
F
.45938 .571 m .45648 .56816 L .46156 .56662 L F
.38627 .57089 m .38826 .56651 L .39128 .56935 L .663 .74 .908 r
F
.38627 .57089 m .38325 .56804 L .38826 .56651 L F
.47241 .57077 m .47463 .56639 L .4775 .56923 L .664 .742 .908 r
F
.47241 .57077 m .46954 .56793 L .47463 .56639 L F
.3993 .57064 m .40132 .56627 L .40431 .56911 L .663 .741 .908 r
F
.3993 .57064 m .39629 .5678 L .40132 .56627 L F
.48544 .57053 m .4877 .56614 L .49054 .56899 L .664 .741 .908 r
F
.48544 .57053 m .48259 .56769 L .4877 .56614 L F
.41232 .57041 m .41438 .56603 L .41735 .56887 L .663 .741 .908 r
F
.41232 .57041 m .40934 .56757 L .41438 .56603 L F
.42535 .57018 m .42744 .56579 L .43039 .56863 L .664 .742 .908 r
F
.42535 .57018 m .42239 .56734 L .42744 .56579 L F
.43838 .56994 m .44051 .56555 L .44344 .5684 L .663 .741 .908 r
F
.43838 .56994 m .43544 .56709 L .44051 .56555 L F
.45141 .5697 m .45358 .56531 L .45648 .56816 L F
.45141 .5697 m .4485 .56685 L .45358 .56531 L F
.46445 .56946 m .46665 .56507 L .46954 .56793 L .664 .741 .908 r
F
.46445 .56946 m .46156 .56662 L .46665 .56507 L F
.39128 .56935 m .39328 .56495 L .39629 .5678 L .665 .742 .908 r
F
.39128 .56935 m .38826 .56651 L .39328 .56495 L F
.4775 .56923 m .47973 .56483 L .48259 .56769 L .664 .742 .908 r
F
.4775 .56923 m .47463 .56639 L .47973 .56483 L F
.40431 .56911 m .40635 .56471 L .40934 .56757 L .664 .741 .908 r
F
.40431 .56911 m .40132 .56627 L .40635 .56471 L F
.49054 .56899 m .49281 .56459 L .49565 .56745 L .663 .741 .908 r
F
.49054 .56899 m .4877 .56614 L .49281 .56459 L F
.41735 .56887 m .41942 .56447 L .42239 .56734 L .664 .742 .908 r
F
.41735 .56887 m .41438 .56603 L .41942 .56447 L F
.43039 .56863 m .4325 .56424 L .43544 .56709 L F
.43039 .56863 m .42744 .56579 L .4325 .56424 L F
.44344 .5684 m .44558 .564 L .4485 .56685 L .664 .741 .908 r
F
.44344 .5684 m .44051 .56555 L .44558 .564 L F
.45648 .56816 m .45866 .56377 L .46156 .56662 L .663 .741 .908 r
F
.45648 .56816 m .45358 .56531 L .45866 .56377 L F
.38325 .56804 m .38524 .56365 L .38826 .56651 L F
.38325 .56804 m .38022 .56519 L .38524 .56365 L F
.46954 .56793 m .47175 .56353 L .47463 .56639 L .663 .74 .907 r
F
.46954 .56793 m .46665 .56507 L .47175 .56353 L F
.39629 .5678 m .39831 .56341 L .40132 .56627 L .663 .741 .908 r
F
.39629 .5678 m .39328 .56495 L .39831 .56341 L F
.48259 .56769 m .48484 .56329 L .4877 .56614 L .664 .741 .908 r
F
.48259 .56769 m .47973 .56483 L .48484 .56329 L F
.40934 .56757 m .41139 .56317 L .41438 .56603 L .663 .741 .908 r
F
.40934 .56757 m .40635 .56471 L .41139 .56317 L F
.49565 .56745 m .49793 .56305 L .50077 .56592 L F
.49565 .56745 m .49281 .56459 L .49793 .56305 L F
.42239 .56734 m .42448 .56293 L .42744 .56579 L .663 .74 .907 r
F
.42239 .56734 m .41942 .56447 L .42448 .56293 L F
.43544 .56709 m .43757 .56269 L .44051 .56555 L .663 .741 .908 r
F
.43544 .56709 m .4325 .56424 L .43757 .56269 L F
.4485 .56685 m .45066 .56245 L .45358 .56531 L .664 .742 .908 r
F
.4485 .56685 m .44558 .564 L .45066 .56245 L F
.46156 .56662 m .46376 .56221 L .46665 .56507 L F
.46156 .56662 m .45866 .56377 L .46376 .56221 L F
.38826 .56651 m .39026 .56209 L .39328 .56495 L .664 .741 .907 r
F
.38826 .56651 m .38524 .56365 L .39026 .56209 L F
.47463 .56639 m .47686 .56197 L .47973 .56483 L .664 .741 .908 r
F
.47463 .56639 m .47175 .56353 L .47686 .56197 L F
.40132 .56627 m .40335 .56185 L .40635 .56471 L F
.40132 .56627 m .39831 .56341 L .40335 .56185 L F
.4877 .56614 m .48996 .56173 L .49281 .56459 L .664 .742 .908 r
F
.4877 .56614 m .48484 .56329 L .48996 .56173 L F
.41438 .56603 m .41645 .56162 L .41942 .56447 L .664 .741 .908 r
F
.41438 .56603 m .41139 .56317 L .41645 .56162 L F
.50077 .56592 m .50307 .56149 L .5059 .56437 L .664 .74 .907 r
F
.50077 .56592 m .49793 .56305 L .50307 .56149 L F
.42744 .56579 m .42954 .56137 L .4325 .56424 L .664 .741 .908 r
F
.42744 .56579 m .42448 .56293 L .42954 .56137 L F
.44051 .56555 m .44265 .56114 L .44558 .564 L .663 .741 .908 r
F
.44051 .56555 m .43757 .56269 L .44265 .56114 L F
.45358 .56531 m .45575 .5609 L .45866 .56377 L F
.45358 .56531 m .45066 .56245 L .45575 .5609 L F
.38022 .56519 m .3822 .56078 L .38524 .56365 L .664 .742 .908 r
F
.38022 .56519 m .37718 .56234 L .3822 .56078 L F
.46665 .56507 m .46886 .56066 L .47175 .56353 L F
.46665 .56507 m .46376 .56221 L .46886 .56066 L F
.39328 .56495 m .3953 .56054 L .39831 .56341 L .663 .741 .908 r
F
.39328 .56495 m .39026 .56209 L .3953 .56054 L F
.47973 .56483 m .48197 .56042 L .48484 .56329 L .664 .741 .908 r
F
.47973 .56483 m .47686 .56197 L .48197 .56042 L F
.40635 .56471 m .4084 .5603 L .41139 .56317 L .664 .742 .908 r
F
.40635 .56471 m .40335 .56185 L .4084 .5603 L F
.49281 .56459 m .49509 .56018 L .49793 .56305 L .663 .741 .908 r
F
.49281 .56459 m .48996 .56173 L .49509 .56018 L F
.41942 .56447 m .42151 .56006 L .42448 .56293 L .664 .742 .908 r
F
.41942 .56447 m .41645 .56162 L .42151 .56006 L F
.5059 .56437 m .50821 .55994 L .51103 .56281 L .664 .74 .907 r
F
.5059 .56437 m .50307 .56149 L .50821 .55994 L F
.4325 .56424 m .43462 .55982 L .43757 .56269 L .663 .741 .908 r
F
.4325 .56424 m .42954 .56137 L .43462 .55982 L F
.44558 .564 m .44773 .55958 L .45066 .56245 L .664 .741 .908 r
F
.44558 .564 m .44265 .56114 L .44773 .55958 L F
.45866 .56377 m .46085 .55935 L .46376 .56221 L .663 .741 .908 r
F
.45866 .56377 m .45575 .5609 L .46085 .55935 L F
.38524 .56365 m .38723 .55922 L .39026 .56209 L .663 .741 .907 r
F
.38524 .56365 m .3822 .56078 L .38723 .55922 L F
.47175 .56353 m .47398 .5591 L .47686 .56197 L .664 .741 .908 r
F
.47175 .56353 m .46886 .56066 L .47398 .5591 L F
.39831 .56341 m .40034 .55898 L .40335 .56185 L F
.39831 .56341 m .3953 .56054 L .40034 .55898 L F
.48484 .56329 m .4871 .55887 L .48996 .56173 L .663 .741 .908 r
F
.48484 .56329 m .48197 .56042 L .4871 .55887 L F
.41139 .56317 m .41346 .55875 L .41645 .56162 L .662 .741 .908 r
F
.41139 .56317 m .4084 .5603 L .41346 .55875 L F
.49793 .56305 m .50023 .55862 L .50307 .56149 L .664 .741 .908 r
F
.49793 .56305 m .49509 .56018 L .50023 .55862 L F
.42448 .56293 m .42658 .5585 L .42954 .56137 L .663 .741 .908 r
F
.42448 .56293 m .42151 .56006 L .42658 .5585 L F
.51103 .56281 m .51336 .55838 L .51618 .56125 L .664 .741 .908 r
F
.51103 .56281 m .50821 .55994 L .51336 .55838 L F
.43757 .56269 m .4397 .55826 L .44265 .56114 L F
.43757 .56269 m .43462 .55982 L .4397 .55826 L F
.45066 .56245 m .45283 .55802 L .45575 .5609 L .664 .742 .908 r
F
.45066 .56245 m .44773 .55958 L .45283 .55802 L F
.37718 .56234 m .37915 .55791 L .3822 .56078 L .663 .74 .908 r
F
.37718 .56234 m .37412 .55946 L .37915 .55791 L F
.46376 .56221 m .46596 .55779 L .46886 .56066 L .664 .742 .908 r
F
.46376 .56221 m .46085 .55935 L .46596 .55779 L F
.39026 .56209 m .39227 .55766 L .3953 .56054 L .663 .741 .908 r
F
.39026 .56209 m .38723 .55922 L .39227 .55766 L F
.47686 .56197 m .4791 .55754 L .48197 .56042 L .664 .741 .908 r
F
.47686 .56197 m .47398 .5591 L .4791 .55754 L F
.40335 .56185 m .4054 .55742 L .4084 .5603 L F
.40335 .56185 m .40034 .55898 L .4054 .55742 L F
.48996 .56173 m .49224 .55732 L .49509 .56018 L .663 .741 .909 r
F
.48996 .56173 m .4871 .55887 L .49224 .55732 L F
.41645 .56162 m .41853 .55718 L .42151 .56006 L .664 .742 .908 r
F
.41645 .56162 m .41346 .55875 L .41853 .55718 L F
.50307 .56149 m .50538 .55706 L .50821 .55994 L F
.50307 .56149 m .50023 .55862 L .50538 .55706 L F
.42954 .56137 m .43166 .55694 L .43462 .55982 L .663 .741 .908 r
F
.42954 .56137 m .42658 .5585 L .43166 .55694 L F
.51618 .56125 m .51853 .55682 L .52134 .5597 L F
.51618 .56125 m .51336 .55838 L .51853 .55682 L F
.44265 .56114 m .4448 .5567 L .44773 .55958 L F
.44265 .56114 m .4397 .55826 L .4448 .5567 L F
.45575 .5609 m .45794 .55646 L .46085 .55935 L .664 .741 .908 r
F
.45575 .5609 m .45283 .55802 L .45794 .55646 L F
.3822 .56078 m .38419 .55633 L .38723 .55922 L .665 .742 .908 r
F
.3822 .56078 m .37915 .55791 L .38419 .55633 L F
.46886 .56066 m .47108 .55622 L .47398 .5591 L .664 .742 .908 r
F
.46886 .56066 m .46596 .55779 L .47108 .55622 L F
.3953 .56054 m .39732 .5561 L .40034 .55898 L .664 .741 .908 r
F
.3953 .56054 m .39227 .55766 L .39732 .5561 L F
.48197 .56042 m .48423 .55598 L .4871 .55887 L F
.48197 .56042 m .4791 .55754 L .48423 .55598 L F
.4084 .5603 m .41046 .55586 L .41346 .55875 L F
.4084 .5603 m .4054 .55742 L .41046 .55586 L F
.49509 .56018 m .49738 .55575 L .50023 .55862 L .664 .742 .908 r
F
.49509 .56018 m .49224 .55732 L .49738 .55575 L F
.42151 .56006 m .4236 .55561 L .42658 .5585 L F
.42151 .56006 m .41853 .55718 L .4236 .55561 L F
.50821 .55994 m .51054 .55549 L .51336 .55838 L F
.50821 .55994 m .50538 .55706 L .51054 .55549 L F
.43462 .55982 m .43675 .55538 L .4397 .55826 L .663 .741 .908 r
F
.43462 .55982 m .43166 .55694 L .43675 .55538 L F
.52134 .5597 m .5237 .55525 L .5265 .55815 L F
.52134 .5597 m .51853 .55682 L .5237 .55525 L F
.44773 .55958 m .4499 .55514 L .45283 .55802 L F
.44773 .55958 m .4448 .5567 L .4499 .55514 L F
.37412 .55946 m .37609 .55502 L .37915 .55791 L F
.37412 .55946 m .37106 .55657 L .37609 .55502 L F
.46085 .55935 m .46306 .55489 L .46596 .55779 L .663 .741 .907 r
F
.46085 .55935 m .45794 .55646 L .46306 .55489 L F
.38723 .55922 m .38924 .55477 L .39227 .55766 L .663 .741 .908 r
F
.38723 .55922 m .38419 .55633 L .38924 .55477 L F
.47398 .5591 m .47621 .55466 L .4791 .55754 L .664 .741 .908 r
F
.47398 .5591 m .47108 .55622 L .47621 .55466 L F
.40034 .55898 m .40238 .55454 L .4054 .55742 L .663 .741 .908 r
F
.40034 .55898 m .39732 .5561 L .40238 .55454 L F
.4871 .55887 m .48937 .55441 L .49224 .55732 L .664 .741 .908 r
F
.4871 .55887 m .48423 .55598 L .48937 .55441 L F
.41346 .55875 m .41554 .5543 L .41853 .55718 L .663 .74 .907 r
F
.41346 .55875 m .41046 .55586 L .41554 .5543 L F
.50023 .55862 m .50254 .55417 L .50538 .55706 L .664 .742 .908 r
F
.50023 .55862 m .49738 .55575 L .50254 .55417 L F
.42658 .5585 m .42869 .55405 L .43166 .55694 L .663 .741 .908 r
F
.42658 .5585 m .4236 .55561 L .42869 .55405 L F
.51336 .55838 m .51571 .55393 L .51853 .55682 L F
.51336 .55838 m .51054 .55549 L .51571 .55393 L F
.4397 .55826 m .44185 .55381 L .4448 .5567 L .664 .742 .908 r
F
.4397 .55826 m .43675 .55538 L .44185 .55381 L F
.5265 .55815 m .52888 .5537 L .53168 .55658 L .663 .74 .908 r
F
.5265 .55815 m .5237 .55525 L .52888 .5537 L F
.45283 .55802 m .45501 .55357 L .45794 .55646 L .664 .742 .908 r
F
.45283 .55802 m .4499 .55514 L .45501 .55357 L F
.37915 .55791 m .38114 .55345 L .38419 .55633 L .664 .741 .908 r
F
.37915 .55791 m .37609 .55502 L .38114 .55345 L F
.46596 .55779 m .46818 .55333 L .47108 .55622 L F
.46596 .55779 m .46306 .55489 L .46818 .55333 L F
.39227 .55766 m .39429 .55321 L .39732 .5561 L .663 .741 .908 r
F
.39227 .55766 m .38924 .55477 L .39429 .55321 L F
.4791 .55754 m .48135 .55309 L .48423 .55598 L .664 .741 .908 r
F
.4791 .55754 m .47621 .55466 L .48135 .55309 L F
.4054 .55742 m .40745 .55297 L .41046 .55586 L .664 .742 .908 r
F
.4054 .55742 m .40238 .55454 L .40745 .55297 L F
.49224 .55732 m .49453 .55284 L .49738 .55575 L .664 .74 .907 r
F
.49224 .55732 m .48937 .55441 L .49453 .55284 L F
.41853 .55718 m .42062 .55272 L .4236 .55561 L .664 .742 .908 r
F
.41853 .55718 m .41554 .5543 L .42062 .55272 L F
.50538 .55706 m .50771 .5526 L .51054 .55549 L F
.50538 .55706 m .50254 .55417 L .50771 .5526 L F
.43166 .55694 m .43379 .55249 L .43675 .55538 L .663 .741 .908 r
F
.43166 .55694 m .42869 .55405 L .43379 .55249 L F
.51853 .55682 m .52089 .55238 L .5237 .55525 L .663 .741 .909 r
F
.51853 .55682 m .51571 .55393 L .52089 .55238 L F
.4448 .5567 m .44696 .55225 L .4499 .55514 L .663 .741 .908 r
F
.4448 .5567 m .44185 .55381 L .44696 .55225 L F
.37106 .55657 m .37302 .55212 L .37609 .55502 L .664 .742 .908 r
F
.37106 .55657 m .36798 .5537 L .37302 .55212 L F
.53168 .55658 m .53407 .55214 L .53686 .55501 L .663 .742 .909 r
F
.53168 .55658 m .52888 .5537 L .53407 .55214 L F
.45794 .55646 m .46014 .552 L .46306 .55489 L .664 .742 .908 r
F
.45794 .55646 m .45501 .55357 L .46014 .552 L F
.38419 .55633 m .38619 .55188 L .38924 .55477 L .664 .741 .908 r
F
.38419 .55633 m .38114 .55345 L .38619 .55188 L F
.47108 .55622 m .47332 .55176 L .47621 .55466 L .663 .741 .908 r
F
.47108 .55622 m .46818 .55333 L .47332 .55176 L F
.39732 .5561 m .39936 .55163 L .40238 .55454 L .664 .742 .908 r
F
.39732 .5561 m .39429 .55321 L .39936 .55163 L F
.48423 .55598 m .4865 .55152 L .48937 .55441 L .663 .741 .908 r
F
.48423 .55598 m .48135 .55309 L .4865 .55152 L F
.41046 .55586 m .41253 .55139 L .41554 .5543 L .664 .742 .908 r
F
.41046 .55586 m .40745 .55297 L .41253 .55139 L F
.49738 .55575 m .49969 .55127 L .50254 .55417 L .664 .741 .907 r
F
.49738 .55575 m .49453 .55284 L .49969 .55127 L F
.4236 .55561 m .42571 .55115 L .42869 .55405 L .663 .741 .908 r
F
.4236 .55561 m .42062 .55272 L .42571 .55115 L F
.51054 .55549 m .51288 .55103 L .51571 .55393 L F
.51054 .55549 m .50771 .5526 L .51288 .55103 L F
.43675 .55538 m .43889 .55091 L .44185 .55381 L .664 .741 .908 r
F
.43675 .55538 m .43379 .55249 L .43889 .55091 L F
.5237 .55525 m .52608 .55081 L .52888 .5537 L .663 .742 .909 r
F
.5237 .55525 m .52089 .55238 L .52608 .55081 L F
.4499 .55514 m .45208 .55067 L .45501 .55357 L .664 .741 .908 r
F
.4499 .55514 m .44696 .55225 L .45208 .55067 L F
.53686 .55501 m .53928 .55055 L .54206 .55345 L .665 .743 .909 r
F
.53686 .55501 m .53407 .55214 L .53928 .55055 L F
.37609 .55502 m .37807 .55055 L .38114 .55345 L .663 .74 .907 r
F
.37609 .55502 m .37302 .55212 L .37807 .55055 L F
.46306 .55489 m .46527 .55043 L .46818 .55333 L .664 .741 .908 r
F
.46306 .55489 m .46014 .552 L .46527 .55043 L F
.38924 .55477 m .39125 .55031 L .39429 .55321 L .663 .741 .908 r
F
.38924 .55477 m .38619 .55188 L .39125 .55031 L F
.47621 .55466 m .47846 .55019 L .48135 .55309 L F
.47621 .55466 m .47332 .55176 L .47846 .55019 L F
.40238 .55454 m .40443 .55008 L .40745 .55297 L .662 .74 .908 r
F
.40238 .55454 m .39936 .55163 L .40443 .55008 L F
.48937 .55441 m .49166 .54995 L .49453 .55284 L .664 .742 .908 r
F
.48937 .55441 m .4865 .55152 L .49166 .54995 L F
.41554 .5543 m .41762 .54982 L .42062 .55272 L .663 .741 .908 r
F
.41554 .5543 m .41253 .55139 L .41762 .54982 L F
.50254 .55417 m .50486 .5497 L .50771 .5526 L .664 .741 .908 r
F
.50254 .55417 m .49969 .55127 L .50486 .5497 L F
.42869 .55405 m .43081 .54958 L .43379 .55249 L .663 .741 .908 r
F
.42869 .55405 m .42571 .55115 L .43081 .54958 L F
.51571 .55393 m .51807 .54946 L .52089 .55238 L F
.51571 .55393 m .51288 .55103 L .51807 .54946 L F
.44185 .55381 m .44401 .54933 L .44696 .55225 L .664 .742 .908 r
F
.44185 .55381 m .43889 .55091 L .44401 .54933 L F
.36798 .5537 m .36994 .54922 L .37302 .55212 L .664 .741 .908 r
F
.36798 .5537 m .3649 .55079 L .36994 .54922 L F
.52888 .5537 m .53128 .54922 L .53407 .55214 L .665 .743 .908 r
F
.52888 .5537 m .52608 .55081 L .53128 .54922 L F
.45501 .55357 m .45721 .54909 L .46014 .552 L .664 .742 .908 r
F
.45501 .55357 m .45208 .55067 L .45721 .54909 L F
.38114 .55345 m .38313 .54897 L .38619 .55188 L F
.38114 .55345 m .37807 .55055 L .38313 .54897 L F
.54206 .55345 m .54449 .54897 L .54726 .55187 L F
.54206 .55345 m .53928 .55055 L .54449 .54897 L F
.46818 .55333 m .47041 .54885 L .47332 .55176 L .663 .741 .908 r
F
.46818 .55333 m .46527 .55043 L .47041 .54885 L F
.39429 .55321 m .39632 .54873 L .39936 .55163 L .664 .742 .908 r
F
.39429 .55321 m .39125 .55031 L .39632 .54873 L F
.48135 .55309 m .48362 .54862 L .4865 .55152 L .663 .742 .908 r
F
.48135 .55309 m .47846 .55019 L .48362 .54862 L F
.40745 .55297 m .40952 .54849 L .41253 .55139 L .665 .742 .908 r
F
.40745 .55297 m .40443 .55008 L .40952 .54849 L F
.49453 .55284 m .49683 .54837 L .49969 .55127 L .664 .742 .908 r
F
.49453 .55284 m .49166 .54995 L .49683 .54837 L F
.42062 .55272 m .42272 .54824 L .42571 .55115 L F
.42062 .55272 m .41762 .54982 L .42272 .54824 L F
.50771 .5526 m .51004 .54812 L .51288 .55103 L .663 .741 .908 r
F
.50771 .5526 m .50486 .5497 L .51004 .54812 L F
.43379 .55249 m .43593 .548 L .43889 .55091 L F
.43379 .55249 m .43081 .54958 L .43593 .548 L F
.52089 .55238 m .52326 .54788 L .52608 .55081 L .664 .741 .907 r
F
.52089 .55238 m .51807 .54946 L .52326 .54788 L F
.44696 .55225 m .44914 .54775 L .45208 .55067 L F
.44696 .55225 m .44401 .54933 L .44914 .54775 L F
.37302 .55212 m .375 .54763 L .37807 .55055 L .664 .742 .908 r
F
.37302 .55212 m .36994 .54922 L .375 .54763 L F
.53407 .55214 m .53648 .54763 L .53928 .55055 L .664 .74 .907 r
F
.53407 .55214 m .53128 .54922 L .53648 .54763 L F
.46014 .552 m .46235 .54751 L .46527 .55043 L .664 .741 .908 r
F
.46014 .552 m .45721 .54909 L .46235 .54751 L F
.54726 .55187 m .54971 .5474 L .55248 .5503 L .663 .741 .908 r
F
.54726 .55187 m .54449 .54897 L .54971 .5474 L F
.38619 .55188 m .3882 .54739 L .39125 .55031 L F
.38619 .55188 m .38313 .54897 L .3882 .54739 L F
.47332 .55176 m .47556 .54727 L .47846 .55019 L .664 .741 .908 r
F
.47332 .55176 m .47041 .54885 L .47556 .54727 L F
.39936 .55163 m .40141 .54715 L .40443 .55008 L F
.39936 .55163 m .39632 .54873 L .40141 .54715 L F
.4865 .55152 m .48878 .54703 L .49166 .54995 L .664 .742 .908 r
F
.4865 .55152 m .48362 .54862 L .48878 .54703 L F
.41253 .55139 m .41462 .5469 L .41762 .54982 L F
.41253 .55139 m .40952 .54849 L .41462 .5469 L F
.49969 .55127 m .50201 .54678 L .50486 .5497 L .664 .741 .908 r
F
.49969 .55127 m .49683 .54837 L .50201 .54678 L F
.42571 .55115 m .42783 .54666 L .43081 .54958 L .663 .741 .908 r
F
.42571 .55115 m .42272 .54824 L .42783 .54666 L F
.51288 .55103 m .51523 .54654 L .51807 .54946 L F
.51288 .55103 m .51004 .54812 L .51523 .54654 L F
.43889 .55091 m .44105 .54643 L .44401 .54933 L F
.43889 .55091 m .43593 .548 L .44105 .54643 L F
.3649 .55079 m .36685 .5463 L .36994 .54922 L F
.3649 .55079 m .3618 .54787 L .36685 .5463 L F
.52608 .55081 m .52847 .5463 L .53128 .54922 L .663 .739 .907 r
F
.52608 .55081 m .52326 .54788 L .52847 .5463 L F
.45208 .55067 m .45427 .54617 L .45721 .54909 L .663 .741 .907 r
F
.45208 .55067 m .44914 .54775 L .45427 .54617 L F
.37807 .55055 m .38006 .54605 L .38313 .54897 L .664 .741 .908 r
F
.37807 .55055 m .375 .54763 L .38006 .54605 L F
.53928 .55055 m .5417 .54605 L .54449 .54897 L F
.53928 .55055 m .53648 .54763 L .5417 .54605 L F
.46527 .55043 m .4675 .54593 L .47041 .54885 L .663 .741 .908 r
F
.46527 .55043 m .46235 .54751 L .4675 .54593 L F
.55248 .5503 m .55494 .54582 L .5577 .54874 L .663 .742 .909 r
F
.55248 .5503 m .54971 .5474 L .55494 .54582 L F
.39125 .55031 m .39328 .54582 L .39632 .54873 L .663 .741 .908 r
F
.39125 .55031 m .3882 .54739 L .39328 .54582 L F
.47846 .55019 m .48072 .54569 L .48362 .54862 L .664 .741 .907 r
F
.47846 .55019 m .47556 .54727 L .48072 .54569 L F
.40443 .55008 m .4065 .54557 L .40952 .54849 L .663 .74 .907 r
F
.40443 .55008 m .40141 .54715 L .4065 .54557 L F
.49166 .54995 m .49396 .54545 L .49683 .54837 L .664 .741 .908 r
F
.49166 .54995 m .48878 .54703 L .49396 .54545 L F
.41762 .54982 m .41972 .54532 L .42272 .54824 L F
.41762 .54982 m .41462 .5469 L .41972 .54532 L F
.50486 .5497 m .5072 .54521 L .51004 .54812 L .663 .741 .908 r
F
.50486 .5497 m .50201 .54678 L .5072 .54521 L F
.43081 .54958 m .43295 .54508 L .43593 .548 L .664 .741 .908 r
F
.43081 .54958 m .42783 .54666 L .43295 .54508 L F
.51807 .54946 m .52044 .54498 L .52326 .54788 L .662 .741 .908 r
F
.51807 .54946 m .51523 .54654 L .52044 .54498 L F
.44401 .54933 m .44618 .54484 L .44914 .54775 L .664 .742 .908 r
F
.44401 .54933 m .44105 .54643 L .44618 .54484 L F
.36994 .54922 m .37191 .54471 L .375 .54763 L F
.36994 .54922 m .36685 .5463 L .37191 .54471 L F
.53128 .54922 m .53368 .54472 L .53648 .54763 L .664 .741 .908 r
F
.53128 .54922 m .52847 .5463 L .53368 .54472 L F
.45721 .54909 m .45941 .54459 L .46235 .54751 L F
.45721 .54909 m .45427 .54617 L .45941 .54459 L F
.54449 .54897 m .54693 .54447 L .54971 .5474 L .663 .741 .908 r
F
.54449 .54897 m .5417 .54605 L .54693 .54447 L F
.38313 .54897 m .38514 .54447 L .3882 .54739 L F
.38313 .54897 m .38006 .54605 L .38514 .54447 L F
.47041 .54885 m .47265 .54435 L .47556 .54727 L F
.47041 .54885 m .4675 .54593 L .47265 .54435 L F
.39632 .54873 m .39837 .54422 L .40141 .54715 L .664 .742 .908 r
F
.39632 .54873 m .39328 .54582 L .39837 .54422 L F
.5577 .54874 m .56018 .54424 L .56294 .54717 L .663 .742 .908 r
F
.5577 .54874 m .55494 .54582 L .56018 .54424 L F
.48362 .54862 m .4859 .54411 L .48878 .54703 L .663 .74 .907 r
F
.48362 .54862 m .48072 .54569 L .4859 .54411 L F
.40952 .54849 m .4116 .54398 L .41462 .5469 L .664 .742 .908 r
F
.40952 .54849 m .4065 .54557 L .4116 .54398 L F
.49683 .54837 m .49914 .54386 L .50201 .54678 L .664 .741 .908 r
F
.49683 .54837 m .49396 .54545 L .49914 .54386 L F
.42272 .54824 m .42484 .54374 L .42783 .54666 L .663 .741 .908 r
F
.42272 .54824 m .41972 .54532 L .42484 .54374 L F
.51004 .54812 m .51239 .54363 L .51523 .54654 L F
.51004 .54812 m .5072 .54521 L .51239 .54363 L F
.43593 .548 m .43808 .5435 L .44105 .54643 L F
.43593 .548 m .43295 .54508 L .43808 .5435 L F
.3618 .54787 m .36375 .54337 L .36685 .5463 L .664 .742 .908 r
F
.3618 .54787 m .35869 .54496 L .36375 .54337 L F
.52326 .54788 m .52565 .54338 L .52847 .5463 L .664 .743 .909 r
F
.52326 .54788 m .52044 .54498 L .52565 .54338 L F
.44914 .54775 m .45132 .54324 L .45427 .54617 L .664 .742 .908 r
F
.44914 .54775 m .44618 .54484 L .45132 .54324 L F
.53648 .54763 m .53891 .54312 L .5417 .54605 L F
.53648 .54763 m .53368 .54472 L .53891 .54312 L F
.375 .54763 m .37698 .54312 L .38006 .54605 L .664 .741 .908 r
F
.375 .54763 m .37191 .54471 L .37698 .54312 L F
.46235 .54751 m .46457 .54301 L .4675 .54593 L .663 .741 .908 r
F
.46235 .54751 m .45941 .54459 L .46457 .54301 L F
.3882 .54739 m .39022 .54288 L .39328 .54582 L .664 .741 .908 r
F
.3882 .54739 m .38514 .54447 L .39022 .54288 L F
.54971 .5474 m .55217 .54289 L .55494 .54582 L .663 .741 .908 r
F
.54971 .5474 m .54693 .54447 L .55217 .54289 L F
.47556 .54727 m .47782 .54277 L .48072 .54569 L F
.47556 .54727 m .47265 .54435 L .47782 .54277 L F
.40141 .54715 m .40346 .54264 L .4065 .54557 L F
.40141 .54715 m .39837 .54422 L .40346 .54264 L F
.56294 .54717 m .56543 .54265 L .56818 .54558 L .664 .741 .907 r
F
.56294 .54717 m .56018 .54424 L .56543 .54265 L F
.48878 .54703 m .49108 .54252 L .49396 .54545 L .664 .741 .908 r
F
.48878 .54703 m .4859 .54411 L .49108 .54252 L F
.41462 .5469 m .41671 .54239 L .41972 .54532 L F
.41462 .5469 m .4116 .54398 L .41671 .54239 L F
.50201 .54678 m .50434 .54228 L .5072 .54521 L .663 .741 .908 r
F
.50201 .54678 m .49914 .54386 L .50434 .54228 L F
.42783 .54666 m .42996 .54215 L .43295 .54508 L .664 .742 .908 r
F
.42783 .54666 m .42484 .54374 L .42996 .54215 L F
.51523 .54654 m .5176 .54204 L .52044 .54498 L .663 .742 .909 r
F
.51523 .54654 m .51239 .54363 L .5176 .54204 L F
.44105 .54643 m .44321 .54191 L .44618 .54484 L .664 .741 .908 r
F
.44105 .54643 m .43808 .5435 L .44321 .54191 L F
.52847 .5463 m .53087 .54178 L .53368 .54472 L .664 .742 .908 r
F
.52847 .5463 m .52565 .54338 L .53087 .54178 L F
.36685 .5463 m .36882 .54179 L .37191 .54471 L .663 .741 .908 r
F
.36685 .5463 m .36375 .54337 L .36882 .54179 L F
.45427 .54617 m .45647 .54166 L .45941 .54459 L F
.45427 .54617 m .45132 .54324 L .45647 .54166 L F
.38006 .54605 m .38206 .54154 L .38514 .54447 L F
.38006 .54605 m .37698 .54312 L .38206 .54154 L F
.5417 .54605 m .54414 .54154 L .54693 .54447 L F
.5417 .54605 m .53891 .54312 L .54414 .54154 L F
.4675 .54593 m .46973 .54143 L .47265 .54435 L F
.4675 .54593 m .46457 .54301 L .46973 .54143 L F
.39328 .54582 m .39532 .5413 L .39837 .54422 L F
.39328 .54582 m .39022 .54288 L .39532 .5413 L F
.55494 .54582 m .55742 .5413 L .56018 .54424 L F
.55494 .54582 m .55217 .54289 L .55742 .5413 L F
.48072 .54569 m .483 .54117 L .4859 .54411 L .664 .742 .908 r
F
.48072 .54569 m .47782 .54277 L .483 .54117 L F
.4065 .54557 m .40857 .54105 L .4116 .54398 L .663 .741 .908 r
F
.4065 .54557 m .40346 .54264 L .40857 .54105 L F
.56818 .54558 m .5707 .54171 L .57344 .5444 L .612 .724 .925 r
F
.56818 .54558 m .56543 .54265 L .5707 .54171 L F
.49396 .54545 m .49627 .54092 L .49914 .54386 L .664 .741 .908 r
F
.49396 .54545 m .49108 .54252 L .49627 .54092 L F
.41972 .54532 m .42183 .5408 L .42484 .54374 L .663 .741 .908 r
F
.41972 .54532 m .41671 .54239 L .42183 .5408 L F
.5072 .54521 m .50954 .54068 L .51239 .54363 L .664 .741 .908 r
F
.5072 .54521 m .50434 .54228 L .50954 .54068 L F
.43295 .54508 m .43509 .54055 L .43808 .5435 L .664 .742 .908 r
F
.43295 .54508 m .42996 .54215 L .43509 .54055 L F
.35869 .54496 m .36064 .54043 L .36375 .54337 L F
.35869 .54496 m .35557 .54203 L .36064 .54043 L F
.52044 .54498 m .52282 .54044 L .52565 .54338 L .665 .741 .907 r
F
.52044 .54498 m .5176 .54204 L .52282 .54044 L F
.44618 .54484 m .44836 .54031 L .45132 .54324 L .664 .742 .908 r
F
.44618 .54484 m .44321 .54191 L .44836 .54031 L F
.37191 .54471 m .37389 .54018 L .37698 .54312 L F
.37191 .54471 m .36882 .54179 L .37389 .54018 L F
.53368 .54472 m .5361 .54019 L .53891 .54312 L .664 .741 .908 r
F
.53368 .54472 m .53087 .54178 L .5361 .54019 L F
.45941 .54459 m .46163 .54007 L .46457 .54301 L .663 .741 .908 r
F
.45941 .54459 m .45647 .54166 L .46163 .54007 L F
.38514 .54447 m .38716 .53994 L .39022 .54288 L .664 .742 .908 r
F
.38514 .54447 m .38206 .54154 L .38716 .53994 L F
.54693 .54447 m .54938 .53995 L .55217 .54289 L .663 .741 .908 r
F
.54693 .54447 m .54414 .54154 L .54938 .53995 L F
.47265 .54435 m .47491 .53984 L .47782 .54277 L .663 .742 .908 r
F
.47265 .54435 m .46973 .54143 L .47491 .53984 L F
.39837 .54422 m .40042 .5397 L .40346 .54264 L .664 .742 .908 r
F
.39837 .54422 m .39532 .5413 L .40042 .5397 L F
.56018 .54424 m .56267 .53972 L .56543 .54265 L .663 .741 .908 r
F
.56018 .54424 m .55742 .5413 L .56267 .53972 L F
.4859 .54411 m .48819 .53958 L .49108 .54252 L .664 .741 .908 r
F
.4859 .54411 m .483 .54117 L .48819 .53958 L F
.4116 .54398 m .41369 .53945 L .41671 .54239 L .664 .742 .908 r
F
.4116 .54398 m .40857 .54105 L .41369 .53945 L F
.49914 .54386 m .50147 .53933 L .50434 .54228 L .664 .741 .908 r
F
.49914 .54386 m .49627 .54092 L .50147 .53933 L F
.57344 .5444 m .57641 .56881 L .57906 .56497 L .951 .61 .329 r
F
.57344 .5444 m .5707 .54171 L .57641 .56881 L F
.42484 .54374 m .42696 .53922 L .42996 .54215 L .663 .741 .908 r
F
.42484 .54374 m .42183 .5408 L .42696 .53922 L F
.51239 .54363 m .51476 .53909 L .5176 .54204 L .664 .741 .907 r
F
.51239 .54363 m .50954 .54068 L .51476 .53909 L F
.43808 .5435 m .44024 .53896 L .44321 .54191 L .663 .74 .907 r
F
.43808 .5435 m .43509 .54055 L .44024 .53896 L F
.36375 .54337 m .36571 .53884 L .36882 .54179 L .663 .741 .908 r
F
.36375 .54337 m .36064 .54043 L .36571 .53884 L F
.52565 .54338 m .52805 .53884 L .53087 .54178 L .664 .741 .907 r
F
.52565 .54338 m .52282 .54044 L .52805 .53884 L F
.45132 .54324 m .45352 .53871 L .45647 .54166 L .664 .741 .908 r
F
.45132 .54324 m .44836 .54031 L .45352 .53871 L F
.37698 .54312 m .37898 .5386 L .38206 .54154 L .663 .741 .908 r
F
.37698 .54312 m .37389 .54018 L .37898 .5386 L F
.53891 .54312 m .54134 .5386 L .54414 .54154 L F
.53891 .54312 m .5361 .54019 L .54134 .5386 L F
.46457 .54301 m .4668 .53847 L .46973 .54143 L .664 .741 .908 r
F
.46457 .54301 m .46163 .54007 L .4668 .53847 L F
.39022 .54288 m .39226 .53835 L .39532 .5413 L .663 .741 .908 r
F
.39022 .54288 m .38716 .53994 L .39226 .53835 L F
.55217 .54289 m .55464 .53837 L .55742 .5413 L .662 .741 .908 r
F
.55217 .54289 m .54938 .53995 L .55464 .53837 L F
.47782 .54277 m .48009 .53823 L .483 .54117 L .664 .742 .908 r
F
.47782 .54277 m .47491 .53984 L .48009 .53823 L F
.40346 .54264 m .40553 .5381 L .40857 .54105 L .664 .741 .908 r
F
.40346 .54264 m .40042 .5397 L .40553 .5381 L F
.56543 .54265 m .56795 .53901 L .5707 .54171 L .59 .717 .932 r
F
.56543 .54265 m .56267 .53972 L .56795 .53901 L F
.49108 .54252 m .49338 .53798 L .49627 .54092 L .664 .741 .908 r
F
.49108 .54252 m .48819 .53958 L .49338 .53798 L F
.41671 .54239 m .41882 .53785 L .42183 .5408 L .663 .741 .908 r
F
.41671 .54239 m .41369 .53945 L .41882 .53785 L F
.50434 .54228 m .50668 .53774 L .50954 .54068 L F
.50434 .54228 m .50147 .53933 L .50668 .53774 L F
.42996 .54215 m .4321 .53762 L .43509 .54055 L .663 .742 .908 r
F
.42996 .54215 m .42696 .53922 L .4321 .53762 L F
.35557 .54203 m .35751 .53749 L .36064 .54043 L .663 .741 .908 r
F
.35557 .54203 m .35244 .53909 L .35751 .53749 L F
.5176 .54204 m .51998 .53749 L .52282 .54044 L .663 .74 .907 r
F
.5176 .54204 m .51476 .53909 L .51998 .53749 L F
.44321 .54191 m .44539 .53736 L .44836 .54031 L .663 .741 .907 r
F
.44321 .54191 m .44024 .53896 L .44539 .53736 L F
.53087 .54178 m .53328 .53724 L .5361 .54019 L .664 .741 .908 r
F
.53087 .54178 m .52805 .53884 L .53328 .53724 L F
.36882 .54179 m .37079 .53724 L .37389 .54018 L F
.36882 .54179 m .36571 .53884 L .37079 .53724 L F
.45647 .54166 m .45869 .53712 L .46163 .54007 L .663 .741 .908 r
F
.45647 .54166 m .45352 .53871 L .45869 .53712 L F
.54414 .54154 m .54659 .53701 L .54938 .53995 L F
.54414 .54154 m .54134 .5386 L .54659 .53701 L F
.38206 .54154 m .38408 .537 L .38716 .53994 L .664 .741 .908 r
F
.38206 .54154 m .37898 .5386 L .38408 .537 L F
.46973 .54143 m .47198 .53687 L .47491 .53984 L .664 .74 .907 r
F
.46973 .54143 m .4668 .53847 L .47198 .53687 L F
.39532 .5413 m .39736 .53676 L .40042 .5397 L .663 .741 .908 r
F
.39532 .5413 m .39226 .53835 L .39736 .53676 L F
.55742 .5413 m .5599 .53675 L .56267 .53972 L .665 .743 .908 r
F
.55742 .5413 m .55464 .53837 L .5599 .53675 L F
.483 .54117 m .48529 .53663 L .48819 .53958 L .664 .741 .908 r
F
.483 .54117 m .48009 .53823 L .48529 .53663 L F
.40857 .54105 m .41066 .5365 L .41369 .53945 L F
.40857 .54105 m .40553 .5381 L .41066 .5365 L F
.49627 .54092 m .49859 .53639 L .50147 .53933 L .663 .741 .908 r
F
.49627 .54092 m .49338 .53798 L .49859 .53639 L F
.42183 .5408 m .42395 .53626 L .42696 .53922 L F
.42183 .5408 m .41882 .53785 L .42395 .53626 L F
.5707 .54171 m .57379 .57611 L .57641 .56881 L .956 .635 .375 r
F
.5707 .54171 m .56795 .53901 L .57379 .57611 L F
.50954 .54068 m .5119 .53615 L .51476 .53909 L .663 .741 .908 r
F
.50954 .54068 m .50668 .53774 L .5119 .53615 L F
.43509 .54055 m .43725 .53601 L .44024 .53896 L .664 .743 .909 r
F
.43509 .54055 m .4321 .53762 L .43725 .53601 L F
.36064 .54043 m .36259 .53589 L .36571 .53884 L .664 .742 .908 r
F
.36064 .54043 m .35751 .53749 L .36259 .53589 L F
.52282 .54044 m .52521 .53589 L .52805 .53884 L F
.52282 .54044 m .51998 .53749 L .52521 .53589 L F
.44836 .54031 m .45056 .53576 L .45352 .53871 L .664 .741 .908 r
F
.44836 .54031 m .44539 .53736 L .45056 .53576 L F
.37389 .54018 m .37589 .53564 L .37898 .5386 L .663 .741 .908 r
F
.37389 .54018 m .37079 .53724 L .37589 .53564 L F
.5361 .54019 m .53853 .53565 L .54134 .5386 L F
.5361 .54019 m .53328 .53724 L .53853 .53565 L F
.46163 .54007 m .46386 .53552 L .4668 .53847 L .664 .741 .908 r
F
.46163 .54007 m .45869 .53712 L .46386 .53552 L F
.38716 .53994 m .38918 .53539 L .39226 .53835 L .664 .742 .908 r
F
.38716 .53994 m .38408 .537 L .38918 .53539 L F
.54938 .53995 m .55185 .53541 L .55464 .53837 L .663 .742 .908 r
F
.54938 .53995 m .54659 .53701 L .55185 .53541 L F
.47491 .53984 m .47717 .53527 L .48009 .53823 L .663 .74 .907 r
F
.47491 .53984 m .47198 .53687 L .47717 .53527 L F
.40042 .5397 m .40248 .53515 L .40553 .5381 L .664 .742 .908 r
F
.40042 .5397 m .39736 .53676 L .40248 .53515 L F
.56267 .53972 m .56519 .53655 L .56795 .53901 L .539 .695 .94 r
F
.56267 .53972 m .5599 .53675 L .56519 .53655 L F
.48819 .53958 m .49049 .53502 L .49338 .53798 L .664 .742 .908 r
F
.48819 .53958 m .48529 .53663 L .49049 .53502 L F
.41369 .53945 m .41579 .5349 L .41882 .53785 L .663 .741 .908 r
F
.41369 .53945 m .41066 .5365 L .41579 .5349 L F
.50147 .53933 m .50381 .53479 L .50668 .53774 L .663 .742 .908 r
F
.50147 .53933 m .49859 .53639 L .50381 .53479 L F
.42696 .53922 m .4291 .53466 L .4321 .53762 L .663 .741 .908 r
F
.42696 .53922 m .42395 .53626 L .4291 .53466 L F
.35244 .53909 m .35438 .53453 L .35751 .53749 L F
.35244 .53909 m .3493 .53613 L .35438 .53453 L F
.51476 .53909 m .51713 .53454 L .51998 .53749 L .664 .742 .908 r
F
.51476 .53909 m .5119 .53615 L .51713 .53454 L F
.44024 .53896 m .44241 .5344 L .44539 .53736 L F
.44024 .53896 m .43725 .53601 L .44241 .5344 L F
.52805 .53884 m .53046 .53428 L .53328 .53724 L .664 .741 .908 r
F
.52805 .53884 m .52521 .53589 L .53046 .53428 L F
.36571 .53884 m .36768 .53428 L .37079 .53724 L F
.36571 .53884 m .36259 .53589 L .36768 .53428 L F
.45352 .53871 m .45573 .53417 L .45869 .53712 L .663 .741 .908 r
F
.45352 .53871 m .45056 .53576 L .45573 .53417 L F
.37898 .5386 m .38099 .53404 L .38408 .537 L F
.37898 .5386 m .37589 .53564 L .38099 .53404 L F
.54134 .5386 m .54379 .53405 L .54659 .53701 L F
.54134 .5386 m .53853 .53565 L .54379 .53405 L F
.4668 .53847 m .46905 .53392 L .47198 .53687 L .664 .742 .908 r
F
.4668 .53847 m .46386 .53552 L .46905 .53392 L F
.39226 .53835 m .3943 .53379 L .39736 .53676 L .663 .741 .908 r
F
.39226 .53835 m .38918 .53539 L .3943 .53379 L F
.55464 .53837 m .55712 .5338 L .5599 .53675 L .664 .741 .907 r
F
.55464 .53837 m .55185 .53541 L .55712 .5338 L F
.48009 .53823 m .48237 .53367 L .48529 .53663 L .664 .741 .908 r
F
.48009 .53823 m .47717 .53527 L .48237 .53367 L F
.40553 .5381 m .40761 .53354 L .41066 .5365 L F
.40553 .5381 m .40248 .53515 L .40761 .53354 L F
.49338 .53798 m .4957 .53342 L .49859 .53639 L .663 .741 .908 r
F
.49338 .53798 m .49049 .53502 L .4957 .53342 L F
.41882 .53785 m .42093 .5333 L .42395 .53626 L .664 .741 .908 r
F
.41882 .53785 m .41579 .5349 L .42093 .5333 L F
.50668 .53774 m .50904 .53318 L .5119 .53615 L .664 .742 .908 r
F
.50668 .53774 m .50381 .53479 L .50904 .53318 L F
.58932 .54231 m .59196 .54084 L .59507 .56211 L 0 0 0 r
F
.58694 .70962 m .58668 .54395 L .58932 .54231 L .973 .714 .481 r
F
.58932 .54231 m .58668 .54395 L .59196 .54084 L 0 0 0 r
F
.56795 .53901 m .57113 .58239 L .57379 .57611 L .956 .645 .4 r
F
.56795 .53901 m .56519 .53655 L .57113 .58239 L F
.4321 .53762 m .43426 .53306 L .43725 .53601 L .664 .741 .908 r
F
.4321 .53762 m .4291 .53466 L .43426 .53306 L F
.35751 .53749 m .35946 .53293 L .36259 .53589 L F
.35751 .53749 m .35438 .53453 L .35946 .53293 L F
.51998 .53749 m .52237 .53293 L .52521 .53589 L .664 .742 .908 r
F
.51998 .53749 m .51713 .53454 L .52237 .53293 L F
.44539 .53736 m .44758 .5328 L .45056 .53576 L .664 .741 .908 r
F
.44539 .53736 m .44241 .5344 L .44758 .5328 L F
.37079 .53724 m .37278 .53268 L .37589 .53564 L .663 .741 .908 r
F
.37079 .53724 m .36768 .53428 L .37278 .53268 L F
.53328 .53724 m .53571 .53268 L .53853 .53565 L F
.53328 .53724 m .53046 .53428 L .53571 .53268 L F
.45869 .53712 m .46091 .53257 L .46386 .53552 L F
.45869 .53712 m .45573 .53417 L .46091 .53257 L F
.38408 .537 m .3861 .53243 L .38918 .53539 L F
.38408 .537 m .38099 .53404 L .3861 .53243 L F
.54659 .53701 m .54906 .53244 L .55185 .53541 L .664 .741 .908 r
F
.54659 .53701 m .54379 .53405 L .54906 .53244 L F
.47198 .53687 m .47425 .5323 L .47717 .53527 L .664 .742 .908 r
F
.47198 .53687 m .46905 .53392 L .47425 .5323 L F
.5599 .53675 m .56243 .53419 L .56519 .53655 L .466 .665 .949 r
F
.5599 .53675 m .55712 .5338 L .56243 .53419 L F
.39736 .53676 m .39943 .53218 L .40248 .53515 L .664 .741 .908 r
F
.39736 .53676 m .3943 .53379 L .39943 .53218 L F
.48529 .53663 m .48758 .53206 L .49049 .53502 L F
.48529 .53663 m .48237 .53367 L .48758 .53206 L F
.41066 .5365 m .41275 .53193 L .41579 .5349 L .663 .741 .908 r
F
.41066 .5365 m .40761 .53354 L .41275 .53193 L F
.49859 .53639 m .50093 .53181 L .50381 .53479 L .664 .741 .908 r
F
.49859 .53639 m .4957 .53342 L .50093 .53181 L F
.42395 .53626 m .42609 .53168 L .4291 .53466 L F
.42395 .53626 m .42093 .5333 L .42609 .53168 L F
.3493 .53613 m .35123 .53156 L .35438 .53453 L .664 .742 .908 r
F
.3493 .53613 m .34615 .53318 L .35123 .53156 L F
.5119 .53615 m .51427 .53157 L .51713 .53454 L .664 .741 .908 r
F
.5119 .53615 m .50904 .53318 L .51427 .53157 L F
.43725 .53601 m .43942 .53144 L .44241 .5344 L .664 .742 .908 r
F
.43725 .53601 m .43426 .53306 L .43942 .53144 L F
.36259 .53589 m .36456 .53131 L .36768 .53428 L F
.36259 .53589 m .35946 .53293 L .36456 .53131 L F
.52521 .53589 m .52762 .53131 L .53046 .53428 L .664 .741 .908 r
F
.52521 .53589 m .52237 .53293 L .52762 .53131 L F
.45056 .53576 m .45276 .53119 L .45573 .53417 L .663 .741 .908 r
F
.45056 .53576 m .44758 .5328 L .45276 .53119 L F
.37589 .53564 m .37789 .53107 L .38099 .53404 L .664 .741 .908 r
F
.37589 .53564 m .37278 .53268 L .37789 .53107 L F
.53853 .53565 m .54098 .53107 L .54379 .53405 L .663 .741 .908 r
F
.53853 .53565 m .53571 .53268 L .54098 .53107 L F
.46386 .53552 m .46611 .53096 L .46905 .53392 L .663 .742 .908 r
F
.46386 .53552 m .46091 .53257 L .46611 .53096 L F
.38918 .53539 m .39122 .53082 L .3943 .53379 L .664 .742 .908 r
F
.38918 .53539 m .3861 .53243 L .39122 .53082 L F
.55185 .53541 m .55433 .53085 L .55712 .5338 L .662 .74 .908 r
F
.55185 .53541 m .54906 .53244 L .55433 .53085 L F
.47717 .53527 m .47945 .53069 L .48237 .53367 L .664 .741 .908 r
F
.47717 .53527 m .47425 .5323 L .47945 .53069 L F
.40248 .53515 m .40456 .53057 L .40761 .53354 L .664 .742 .908 r
F
.40248 .53515 m .39943 .53218 L .40456 .53057 L F
.49049 .53502 m .4928 .53045 L .4957 .53342 L .664 .741 .908 r
F
.49049 .53502 m .48758 .53206 L .4928 .53045 L F
.41579 .5349 m .4179 .53033 L .42093 .5333 L .663 .741 .908 r
F
.41579 .5349 m .41275 .53193 L .4179 .53033 L F
.50381 .53479 m .50616 .5302 L .50904 .53318 L .663 .74 .907 r
F
.50381 .53479 m .50093 .53181 L .50616 .5302 L F
.4291 .53466 m .43125 .53007 L .43426 .53306 L F
.4291 .53466 m .42609 .53168 L .43125 .53007 L F
.35438 .53453 m .35632 .52996 L .35946 .53293 L .663 .741 .908 r
F
.35438 .53453 m .35123 .53156 L .35632 .52996 L F
.51713 .53454 m .51952 .52995 L .52237 .53293 L .664 .741 .908 r
F
.51713 .53454 m .51427 .53157 L .51952 .52995 L F
.56519 .53655 m .5685 .59336 L .57113 .58239 L .957 .655 .42 r
F
.56519 .53655 m .56243 .53419 L .5685 .59336 L F
.44241 .5344 m .4446 .52982 L .44758 .5328 L .664 .742 .908 r
F
.44241 .5344 m .43942 .53144 L .4446 .52982 L F
.36768 .53428 m .36966 .52971 L .37278 .53268 L .663 .741 .908 r
F
.36768 .53428 m .36456 .53131 L .36966 .52971 L F
.53046 .53428 m .53288 .52971 L .53571 .53268 L F
.53046 .53428 m .52762 .53131 L .53288 .52971 L F
.45573 .53417 m .45795 .52958 L .46091 .53257 L .664 .741 .908 r
F
.45573 .53417 m .45276 .53119 L .45795 .52958 L F
.38099 .53404 m .38301 .52946 L .3861 .53243 L .663 .741 .908 r
F
.38099 .53404 m .37789 .53107 L .38301 .52946 L F
.54379 .53405 m .54625 .52949 L .54906 .53244 L .662 .74 .908 r
F
.54379 .53405 m .54098 .53107 L .54625 .52949 L F
.46905 .53392 m .47131 .52934 L .47425 .5323 L .664 .742 .908 r
F
.46905 .53392 m .46611 .53096 L .47131 .52934 L F
.3943 .53379 m .39635 .52921 L .39943 .53218 L .663 .741 .908 r
F
.3943 .53379 m .39122 .53082 L .39635 .52921 L F
.55712 .5338 m .55965 .53227 L .56243 .53419 L .305 .584 .94 r
F
.55712 .5338 m .55433 .53085 L .55965 .53227 L F
.48237 .53367 m .48467 .52908 L .48758 .53206 L .663 .741 .908 r
F
.48237 .53367 m .47945 .53069 L .48467 .52908 L F
.40761 .53354 m .40971 .52896 L .41275 .53193 L F
.40761 .53354 m .40456 .53057 L .40971 .52896 L F
.4957 .53342 m .49803 .52884 L .50093 .53181 L F
.4957 .53342 m .4928 .53045 L .49803 .52884 L F
.42093 .5333 m .42306 .52872 L .42609 .53168 L .664 .742 .908 r
F
.42093 .5333 m .4179 .53033 L .42306 .52872 L F
.34615 .53318 m .34808 .52858 L .35123 .53156 L F
.34615 .53318 m .34299 .53021 L .34808 .52858 L F
.50904 .53318 m .5114 .52859 L .51427 .53157 L .663 .741 .907 r
F
.50904 .53318 m .50616 .5302 L .5114 .52859 L F
.43426 .53306 m .43642 .52846 L .43942 .53144 L .664 .741 .907 r
F
.43426 .53306 m .43125 .53007 L .43642 .52846 L F
.52237 .53293 m .52478 .52834 L .52762 .53131 L .664 .741 .908 r
F
.52237 .53293 m .51952 .52995 L .52478 .52834 L F
.35946 .53293 m .36143 .52833 L .36456 .53131 L .664 .742 .908 r
F
.35946 .53293 m .35632 .52996 L .36143 .52833 L F
.44758 .5328 m .44978 .52821 L .45276 .53119 L .663 .741 .908 r
F
.44758 .5328 m .4446 .52982 L .44978 .52821 L F
.37278 .53268 m .37478 .52809 L .37789 .53107 L .664 .741 .908 r
F
.37278 .53268 m .36966 .52971 L .37478 .52809 L F
.53571 .53268 m .53815 .5281 L .54098 .53107 L .663 .741 .908 r
F
.53571 .53268 m .53288 .52971 L .53815 .5281 L F
.46091 .53257 m .46315 .52797 L .46611 .53096 L .663 .74 .907 r
F
.46091 .53257 m .45795 .52958 L .46315 .52797 L F
.3861 .53243 m .38814 .52784 L .39122 .53082 L .664 .741 .908 r
F
.3861 .53243 m .38301 .52946 L .38814 .52784 L F
.54906 .53244 m .55154 .5279 L .55433 .53085 L .662 .742 .91 r
F
.54906 .53244 m .54625 .52949 L .55154 .5279 L F
.57906 .56497 m .58426 .71733 L .58694 .70962 L .946 .664 .472 r
F
.58694 .70962 m .58426 .71733 L .58668 .54395 L .973 .714 .481 r
F
.58668 .54395 m .58915 .53342 L .59196 .54084 L .738 .736 .215 r
F
.58668 .54395 m .58463 .55167 L .58915 .53342 L F
.58463 .55167 m .58469 .5513 L .58915 .53342 L F
.58426 .71733 m .58416 .55345 L .58668 .54395 L .957 .698 .502 r
F
.58416 .55345 m .58658 .5396 L .58915 .53342 L 0 0 0 r
F
.57906 .56497 m .57641 .56881 L .58426 .71733 L .946 .664 .472 r
F
.57641 .56881 m .58138 .71469 L .58426 .71733 L .938 .655 .479 r
F
.58426 .71733 m .58138 .71469 L .58416 .55345 L .957 .698 .502 r
F
.58138 .71469 m .58173 .57005 L .58416 .55345 L .949 .692 .513 r
F
.58173 .57005 m .58414 .555 L .58522 .54822 L 0 0 0 r
F
.58503 .54933 m .58522 .54822 L .58658 .5396 L F
.58173 .57005 m .58522 .54822 L .58503 .54933 L F
.58463 .55167 m .58416 .55345 L .58469 .5513 L .738 .736 .215 r
F
.47425 .5323 m .47652 .52772 L .47945 .53069 L .664 .742 .908 r
F
.47425 .5323 m .47131 .52934 L .47652 .52772 L F
.39943 .53218 m .4015 .52758 L .40456 .53057 L .664 .741 .908 r
F
.39943 .53218 m .39635 .52921 L .4015 .52758 L F
.48758 .53206 m .4899 .52747 L .4928 .53045 L .663 .741 .908 r
F
.48758 .53206 m .48467 .52908 L .4899 .52747 L F
.41275 .53193 m .41486 .52734 L .4179 .53033 L F
.41275 .53193 m .40971 .52896 L .41486 .52734 L F
.50093 .53181 m .50327 .52723 L .50616 .5302 L F
.50093 .53181 m .49803 .52884 L .50327 .52723 L F
.42609 .53168 m .42823 .52709 L .43125 .53007 L .664 .742 .908 r
F
.42609 .53168 m .42306 .52872 L .42823 .52709 L F
.35123 .53156 m .35317 .52697 L .35632 .52996 L .663 .741 .908 r
F
.35123 .53156 m .34808 .52858 L .35317 .52697 L F
.51427 .53157 m .51666 .52697 L .51952 .52995 L .664 .741 .908 r
F
.51427 .53157 m .5114 .52859 L .51666 .52697 L F
.59507 .56211 m .59196 .54084 L .59728 .53886 L .607 .445 .637 r
F
.59196 .54084 m .59459 .53775 L .59728 .53886 L .319 .373 .762 r
F
.59196 .54084 m .58915 .53342 L .59459 .53775 L F
.43942 .53144 m .4416 .52684 L .4446 .52982 L .664 .741 .908 r
F
.43942 .53144 m .43642 .52846 L .4416 .52684 L F
.36456 .53131 m .36654 .52672 L .36966 .52971 L .663 .741 .908 r
F
.36456 .53131 m .36143 .52833 L .36654 .52672 L F
.52762 .53131 m .53004 .52673 L .53288 .52971 L F
.52762 .53131 m .52478 .52834 L .53004 .52673 L F
.45276 .53119 m .45498 .52659 L .45795 .52958 L F
.45276 .53119 m .44978 .52821 L .45498 .52659 L F
.56243 .53419 m .56582 .60316 L .5685 .59336 L .955 .659 .434 r
F
.56243 .53419 m .55965 .53227 L .56582 .60316 L F
.37789 .53107 m .3799 .52647 L .38301 .52946 L .664 .741 .908 r
F
.37789 .53107 m .37478 .52809 L .3799 .52647 L F
.54098 .53107 m .54344 .52649 L .54625 .52949 L .663 .742 .909 r
F
.54098 .53107 m .53815 .5281 L .54344 .52649 L F
.46611 .53096 m .46836 .52635 L .47131 .52934 L .663 .74 .907 r
F
.46611 .53096 m .46315 .52797 L .46836 .52635 L F
.39122 .53082 m .39327 .52622 L .39635 .52921 L .664 .741 .908 r
F
.39122 .53082 m .38814 .52784 L .39327 .52622 L F
.58915 .53342 m .59214 .54908 L .59459 .53775 L .764 .421 .404 r
F
.58915 .53342 m .58658 .5396 L .59214 .54908 L F
.55433 .53085 m .55687 .53045 L .55965 .53227 L .083 .45 .882 r
F
.55433 .53085 m .55154 .5279 L .55687 .53045 L F
.47945 .53069 m .48174 .5261 L .48467 .52908 L .664 .742 .908 r
F
.47945 .53069 m .47652 .52772 L .48174 .5261 L F
.40456 .53057 m .40665 .52597 L .40971 .52896 L .663 .741 .908 r
F
.40456 .53057 m .4015 .52758 L .40665 .52597 L F
.60536 .54214 m .60953 .59965 L .61212 .5964 L .863 .57 .49 r
F
.60536 .54214 m .60303 .55556 L .60953 .59965 L F
.60023 .55257 m .60303 .55556 L .60536 .54214 L 0 0 .512 r
F
.4928 .53045 m .49513 .52586 L .49803 .52884 L .663 .742 .908 r
F
.4928 .53045 m .4899 .52747 L .49513 .52586 L F
.4179 .53033 m .42003 .52573 L .42306 .52872 L .663 .741 .908 r
F
.4179 .53033 m .41486 .52734 L .42003 .52573 L F
.50616 .5302 m .50853 .5256 L .5114 .52859 L .664 .742 .908 r
F
.50616 .5302 m .50327 .52723 L .50853 .5256 L F
.34299 .53021 m .34491 .5256 L .34808 .52858 L .663 .74 .908 r
F
.34299 .53021 m .33982 .52721 L .34491 .5256 L F
.60023 .55257 m .59728 .53886 L .60303 .55556 L 0 0 .512 r
F
.59507 .56211 m .59728 .53886 L .60023 .55257 L .607 .445 .637 r
F
.59728 .53886 m .60083 .5763 L .60303 .55556 L .948 .627 .388 r
F
.59728 .53886 m .59459 .53775 L .60072 .57559 L F
.59459 .53775 m .59848 .5924 L .60083 .5763 L .874 .577 .482 r
F
.59459 .53775 m .59214 .54908 L .59848 .5924 L F
.59214 .54908 m .59583 .5959 L .59848 .5924 L .788 .503 .504 r
F
.59214 .54908 m .5898 .56785 L .59583 .5959 L F
.59338 .57784 m .59438 .52469 L .597 .52121 L .828 .598 .59 r
F
.5898 .56785 m .59288 .58561 L .59583 .5959 L .523 .266 .467 r
F
.59288 .58561 m .59307 .57793 L .59338 .57784 L .828 .598 .59 r
F
.59307 .57793 m .59438 .52469 L .59338 .57784 L F
.60076 .57558 m .60072 .57559 L .60083 .5763 L .948 .627 .388 r
F
.59728 .53886 m .60072 .57559 L .60076 .57558 L F
.43125 .53007 m .43341 .52547 L .43642 .52846 L .664 .741 .908 r
F
.43125 .53007 m .42823 .52709 L .43341 .52547 L F
.51952 .52995 m .52192 .52535 L .52478 .52834 L F
.51952 .52995 m .51666 .52697 L .52192 .52535 L F
.35632 .52996 m .35828 .52534 L .36143 .52833 L .664 .741 .907 r
F
.35632 .52996 m .35317 .52697 L .35828 .52534 L F
.4446 .52982 m .44679 .52522 L .44978 .52821 L .663 .741 .908 r
F
.4446 .52982 m .4416 .52684 L .44679 .52522 L F
.53288 .52971 m .53532 .52511 L .53815 .5281 L .663 .742 .908 r
F
.53288 .52971 m .53004 .52673 L .53532 .52511 L F
.36966 .52971 m .37166 .5251 L .37478 .52809 L .663 .741 .908 r
F
.36966 .52971 m .36654 .52672 L .37166 .5251 L F
.45795 .52958 m .46018 .52497 L .46315 .52797 L .664 .741 .908 r
F
.45795 .52958 m .45498 .52659 L .46018 .52497 L F
.38301 .52946 m .38504 .52485 L .38814 .52784 L .663 .741 .908 r
F
.38301 .52946 m .3799 .52647 L .38504 .52485 L F
.54625 .52949 m .54873 .52494 L .55154 .5279 L .659 .739 .909 r
F
.54625 .52949 m .54344 .52649 L .54873 .52494 L F
.47131 .52934 m .47358 .52473 L .47652 .52772 L .664 .741 .908 r
F
.47131 .52934 m .46836 .52635 L .47358 .52473 L F
.39635 .52921 m .39842 .52459 L .4015 .52758 L F
.39635 .52921 m .39327 .52622 L .39842 .52459 L F
.48467 .52908 m .48698 .52448 L .4899 .52747 L .663 .741 .908 r
F
.48467 .52908 m .48174 .5261 L .48698 .52448 L F
.40971 .52896 m .41181 .52435 L .41486 .52734 L .664 .741 .908 r
F
.40971 .52896 m .40665 .52597 L .41181 .52435 L F
.49803 .52884 m .50038 .52424 L .50327 .52723 L .663 .742 .909 r
F
.49803 .52884 m .49513 .52586 L .50038 .52424 L F
.42306 .52872 m .4252 .5241 L .42823 .52709 L .664 .742 .908 r
F
.42306 .52872 m .42003 .52573 L .4252 .5241 L F
.34808 .52858 m .35001 .52397 L .35317 .52697 L F
.34808 .52858 m .34491 .5256 L .35001 .52397 L F
.5114 .52859 m .51379 .52398 L .51666 .52697 L .664 .741 .908 r
F
.5114 .52859 m .50853 .5256 L .51379 .52398 L F
.43642 .52846 m .4386 .52384 L .4416 .52684 L F
.43642 .52846 m .43341 .52547 L .4386 .52384 L F
.36143 .52833 m .3634 .52372 L .36654 .52672 L .663 .741 .908 r
F
.36143 .52833 m .35828 .52534 L .3634 .52372 L F
.52478 .52834 m .5272 .52373 L .53004 .52673 L F
.52478 .52834 m .52192 .52535 L .5272 .52373 L F
.44978 .52821 m .452 .52361 L .45498 .52659 L F
.44978 .52821 m .44679 .52522 L .452 .52361 L F
.37478 .52809 m .37679 .52347 L .3799 .52647 L .664 .742 .908 r
F
.37478 .52809 m .37166 .5251 L .37679 .52347 L F
.53815 .5281 m .54061 .52349 L .54344 .52649 L .663 .741 .908 r
F
.53815 .5281 m .53532 .52511 L .54061 .52349 L F
.46315 .52797 m .4654 .52335 L .46836 .52635 L .664 .741 .908 r
F
.46315 .52797 m .46018 .52497 L .4654 .52335 L F
.38814 .52784 m .39018 .52322 L .39327 .52622 L .664 .742 .908 r
F
.38814 .52784 m .38504 .52485 L .39018 .52322 L F
.55154 .5279 m .55408 .52927 L .55687 .53045 L 0 .175 .678 r
F
.55154 .5279 m .54873 .52494 L .55408 .52927 L F
.47652 .52772 m .47881 .5231 L .48174 .5261 L .664 .741 .908 r
F
.47652 .52772 m .47358 .52473 L .47881 .5231 L F
.55965 .53227 m .56315 .6159 L .56582 .60316 L .956 .664 .443 r
F
.55128 .52845 m .55495 .65824 L .5577 .64216 L .954 .67 .46 r
F
.5577 .64216 m .55495 .65824 L .55613 .63322 L .995 .757 .442 r
F
.55965 .53227 m .55687 .53045 L .56297 .61342 L .956 .664 .443 r
F
.55687 .53045 m .56046 .62999 L .56315 .6159 L .954 .666 .452 r
F
.55687 .53045 m .55408 .52927 L .56046 .62999 L F
.55408 .52927 m .5577 .64216 L .56046 .62999 L .954 .668 .456 r
F
.55408 .52927 m .55128 .52845 L .5577 .64216 L F
.55803 .62772 m .55613 .63322 L .55925 .567 L .995 .757 .442 r
F
.55803 .62772 m .55925 .567 L .55938 .56787 L F
.55495 .65824 m .55651 .53993 L .55954 .56105 L .982 .73 .476 r
F
.55128 .52845 m .54847 .52774 L .5549 .65728 L .954 .67 .46 r
F
.55492 .65724 m .5549 .65728 L .55495 .65824 L F
.55128 .52845 m .5549 .65728 L .55492 .65724 L F
.54565 .52848 m .54925 .68189 L .55211 .66892 L .953 .671 .465 r
F
.55211 .66892 m .54925 .68189 L .54961 .66845 L .98 .725 .472 r
F
.54873 .52494 m .55128 .52845 L .55408 .52927 L .618 .123 0 r
F
.54847 .52774 m .55211 .66892 L .55495 .65824 L .951 .668 .465 r
F
.54847 .52774 m .54565 .52848 L .55211 .66892 L F
.55343 .53154 m .55329 .53053 L .55352 .52189 L .98 .725 .472 r
F
.55495 .65824 m .55211 .66892 L .55613 .55091 L .982 .73 .476 r
F
.55627 .55189 m .55613 .55091 L .55636 .5442 L F
.55495 .65824 m .55613 .55091 L .55627 .55189 L F
.55495 .65824 m .55636 .5442 L .55644 .5448 L F
.5487 .52495 m .54591 .52203 L .54873 .52494 L .651 .737 .912 r
F
.54344 .52649 m .54591 .52203 L .5487 .52495 L F
.54061 .52349 m .54308 .51906 L .54591 .52203 L .651 .74 .915 r
F
.54591 .52203 m .54308 .51906 L .54311 .51911 L .781 .312 0 r
F
.54344 .52649 m .54061 .52349 L .54591 .52203 L .651 .737 .912 r
F
.54591 .52203 m .54311 .51911 L .54847 .52774 L .781 .312 0 r
F
.54873 .52494 m .54591 .52203 L .55128 .52845 L .618 .123 0 r
F
.54591 .52203 m .54847 .52774 L .55128 .52845 L .781 .312 0 r
F
.54925 .68189 m .55062 .51124 L .55352 .52189 L .972 .714 .483 r
F
.55211 .66892 m .55352 .52189 L .55651 .53993 L .98 .725 .472 r
F
.55352 .52189 m .55062 .51124 L .55484 .54002 L .955 .644 .221 r
F
.55585 .54516 m .55484 .54002 L .55637 .55045 L F
.55352 .52189 m .55484 .54002 L .55585 .54516 L F
.55229 .52265 m .55333 .52868 L .55637 .55045 L .939 .587 .177 r
F
.54565 .52848 m .54281 .52841 L .54925 .68189 L .953 .671 .465 r
F
.54281 .52841 m .54633 .69023 L .54925 .68189 L .95 .669 .469 r
F
.54925 .68189 m .54633 .69023 L .55062 .51124 L .972 .714 .483 r
F
.55127 .51572 m .5518 .51903 L .55229 .52265 L .939 .587 .177 r
F
.5518 .51903 m .55333 .52868 L .55229 .52265 L F
.55062 .51124 m .55099 .51365 L .55127 .51572 L F
.55099 .51365 m .55333 .52868 L .55127 .51572 L F
.54308 .51906 m .54565 .52848 L .54847 .52774 L .888 .466 .081 r
F
.54633 .69023 m .54774 .50522 L .55062 .51124 L .968 .709 .488 r
F
.55062 .51124 m .54774 .50522 L .55117 .51962 L .939 .587 .177 r
F
.5525 .52337 m .55117 .51962 L .55333 .52868 L F
.55062 .51124 m .55117 .51962 L .5525 .52337 L F
.54774 .50522 m .54828 .50646 L .54941 .51224 L .769 .274 .044 r
F
.54828 .50646 m .55034 .51116 L .54941 .51224 L F
.54281 .52841 m .53996 .5301 L .54598 .68131 L .95 .669 .469 r
F
.53532 .52511 m .53777 .52052 L .54061 .52349 L .66 .74 .909 r
F
.54061 .52349 m .53777 .52052 L .54308 .51906 L .651 .74 .915 r
F
.53777 .52052 m .54024 .5161 L .54308 .51906 L .644 .734 .914 r
F
.53777 .52052 m .53493 .51747 L .54024 .5161 L F
.54308 .51906 m .54024 .5161 L .54565 .52848 L .888 .466 .081 r
F
.5402 .51611 m .53739 .51321 L .54024 .5161 L .633 .731 .919 r
F
.53493 .51747 m .53739 .51321 L .5402 .51611 L F
.53207 .51444 m .53453 .51012 L .53739 .51321 L .638 .736 .919 r
F
.53739 .51321 m .53453 .51012 L .53458 .51029 L .941 .574 .255 r
F
.53532 .52511 m .53248 .5221 L .53777 .52052 L .66 .74 .909 r
F
.53248 .5221 m .53493 .51747 L .53777 .52052 L .663 .743 .909 r
F
.53493 .51747 m .53207 .51444 L .53739 .51321 L .633 .731 .919 r
F
.53739 .51321 m .53458 .51029 L .53996 .5301 L .941 .574 .255 r
F
.54024 .5161 m .54281 .52841 L .54565 .52848 L .919 .523 .175 r
F
.54024 .5161 m .53739 .51321 L .54281 .52841 L F
.53739 .51321 m .53996 .5301 L .54281 .52841 L .941 .574 .255 r
F
.53453 .51012 m .5371 .53226 L .53996 .5301 L .949 .602 .314 r
F
.53996 .5301 m .54337 .69608 L .54633 .69023 L .95 .668 .47 r
F
.53996 .5301 m .5371 .53226 L .54337 .69608 L F
.5371 .53226 m .54037 .70035 L .54337 .69608 L .95 .669 .47 r
F
.5371 .53226 m .53422 .53404 L .54037 .70035 L F
.54035 .6999 m .53732 .69777 L .54037 .70035 L .946 .664 .474 r
F
.53422 .53404 m .53719 .69086 L .53985 .6865 L F
.53248 .5221 m .52963 .51911 L .53493 .51747 L .663 .743 .909 r
F
.52963 .51911 m .53207 .51444 L .53493 .51747 L .663 .74 .907 r
F
.53207 .51444 m .52921 .51144 L .53453 .51012 L .638 .736 .919 r
F
.53451 .51013 m .53166 .50728 L .53453 .51012 L .619 .724 .921 r
F
.52921 .51144 m .53166 .50728 L .53451 .51013 L F
.52633 .50835 m .52878 .50429 L .53166 .50728 L .611 .724 .926 r
F
.53166 .50728 m .52878 .50429 L .5288 .50441 L .953 .619 .343 r
F
.53004 .52673 m .53248 .5221 L .53532 .52511 L .664 .741 .908 r
F
.53004 .52673 m .5272 .52373 L .53248 .5221 L F
.5272 .52373 m .52963 .51911 L .53248 .5221 L .662 .741 .908 r
F
.52963 .51911 m .52676 .51607 L .53207 .51444 L .663 .74 .907 r
F
.52676 .51607 m .52921 .51144 L .53207 .51444 L .66 .74 .909 r
F
.52921 .51144 m .52633 .50835 L .53166 .50728 L .619 .724 .921 r
F
.53166 .50728 m .5288 .50441 L .53422 .53404 L .953 .619 .343 r
F
.53453 .51012 m .53166 .50728 L .5371 .53226 L .949 .602 .314 r
F
.53166 .50728 m .53422 .53404 L .5371 .53226 L .953 .619 .343 r
F
.53422 .53404 m .53132 .53819 L .53732 .69777 L .946 .664 .474 r
F
.53132 .53819 m .53426 .69612 L .53732 .69777 L .947 .665 .472 r
F
.53428 .69563 m .53635 .52772 L .53921 .51698 L .948 .689 .512 r
F
.53426 .69612 m .53427 .69564 L .53428 .69563 L F
.53427 .69564 m .53635 .52772 L .53428 .69563 L F
.53985 .6865 m .53732 .69777 L .54035 .6999 L .946 .664 .474 r
F
.53719 .69086 m .53732 .69777 L .53985 .6865 L F
.53732 .69777 m .53426 .69612 L .53428 .69563 L .958 .699 .5 r
F
.53732 .69777 m .53428 .69563 L .53921 .51698 L F
.53733 .69751 m .53921 .51698 L .54206 .50928 L F
.53732 .69777 m .53732 .69751 L .53733 .69751 L F
.53732 .69751 m .53921 .51698 L .53733 .69751 L F
.54613 .68102 m .54598 .68131 L .54633 .69022 L .95 .669 .469 r
F
.54281 .52841 m .54598 .68131 L .54613 .68102 L F
.54633 .69022 m .54633 .69022 L .54633 .69023 L F
.54281 .52841 m .54633 .69022 L .54633 .69022 L F
.54044 .69737 m .54206 .50928 L .5449 .5052 L .957 .697 .501 r
F
.54037 .70035 m .54039 .69742 L .54044 .69737 L F
.54039 .69742 m .54206 .50928 L .54044 .69737 L F
.54633 .69023 m .54337 .69608 L .54774 .50522 L .968 .709 .488 r
F
.54337 .69608 m .5449 .5052 L .54774 .50522 L .966 .706 .49 r
F
.54774 .50522 m .5449 .5052 L .55034 .51116 L .769 .274 .044 r
F
.54678 .50726 m .54742 .5004 L .55034 .51116 L .706 .867 .459 r
F
.5449 .5052 m .54558 .50389 L .54678 .50726 L F
.54558 .50389 m .54742 .5004 L .54678 .50726 L F
.54941 .51224 m .55034 .51116 L .55333 .52868 L .769 .274 .044 r
F
.55217 .66306 m .54961 .66845 L .55329 .53053 L .98 .725 .472 r
F
.55217 .66306 m .55329 .53053 L .55343 .53154 L F
.55211 .66892 m .54961 .66845 L .55217 .66306 L F
.55644 .5448 m .55636 .5442 L .55651 .53993 L .982 .73 .476 r
F
.55444 .53009 m .55534 .54013 L .55629 .54666 L .955 .644 .221 r
F
.55352 .52189 m .55407 .52736 L .55444 .53009 L F
.55407 .52736 m .55534 .54013 L .55444 .53009 L F
.55965 .53227 m .56297 .61342 L .56304 .61321 L .956 .664 .443 r
F
.5577 .64216 m .55954 .56105 L .56265 .58807 L .995 .757 .442 r
F
.55637 .55045 m .55333 .52868 L .55356 .52831 L .68 .495 .629 r
F
.55629 .54666 m .55637 .55045 L .55921 .57275 L .955 .644 .221 r
F
.55534 .54013 m .55637 .55045 L .55629 .54666 L F
.55651 .53993 m .55352 .52189 L .55946 .57501 L .925 .648 .166 r
F
.55938 .56787 m .55925 .567 L .55945 .56293 L .995 .757 .442 r
F
.55949 .56318 m .55945 .56293 L .55954 .56105 L F
.55938 .56787 m .55945 .56293 L .55949 .56318 L F
.56304 .61321 m .56297 .61342 L .56315 .6159 L .956 .664 .443 r
F
.56582 .60316 m .56315 .6159 L .56897 .64455 L .827 .53 .486 r
F
.56899 .64459 m .56897 .64455 L .569 .64471 L F
.56582 .60316 m .56897 .64455 L .56899 .64459 L F
.56315 .6159 m .5658 .61612 L .569 .64471 L .014 0 .242 r
F
.56315 .6159 m .56046 .62999 L .5658 .61612 L F
.5606 .6296 m .56265 .58807 L .5658 .61612 L .996 .79 .428 r
F
.56046 .62999 m .56049 .62939 L .5606 .6296 L F
.56049 .62939 m .56265 .58807 L .5606 .6296 L F
.56046 .62999 m .5577 .64216 L .56263 .58828 L F
.56264 .58831 m .56263 .58828 L .56265 .58807 L F
.56046 .62999 m .56263 .58828 L .56264 .58831 L F
.56034 .57765 m .55946 .57501 L .56258 .59971 L .925 .648 .166 r
F
.55792 .55382 m .55931 .57285 L .56034 .57765 L F
.55931 .57285 m .55946 .57501 L .56034 .57765 L F
.55651 .53993 m .55743 .55093 L .55792 .55382 L F
.55743 .55093 m .55946 .57501 L .55792 .55382 L F
.55954 .56105 m .55651 .53993 L .56258 .59971 L .915 .648 .154 r
F
.55637 .55045 m .55356 .52831 L .55869 .51963 L .68 .495 .629 r
F
.55921 .57275 m .55637 .55045 L .55946 .57501 L .955 .644 .221 r
F
.5577 .64216 m .55613 .63322 L .55803 .62772 L .995 .757 .442 r
F
.4015 .52758 m .40358 .52297 L .40665 .52597 L .663 .741 .908 r
F
.4015 .52758 m .39842 .52459 L .40358 .52297 L F
.4899 .52747 m .49222 .52285 L .49513 .52586 L .664 .741 .908 r
F
.4899 .52747 m .48698 .52448 L .49222 .52285 L F
.41486 .52734 m .41698 .52272 L .42003 .52573 L .663 .741 .908 r
F
.41486 .52734 m .41181 .52435 L .41698 .52272 L F
.33982 .52721 m .34173 .5226 L .34491 .5256 L F
.33982 .52721 m .33663 .52422 L .34173 .5226 L F
.50327 .52723 m .50564 .52261 L .50853 .5256 L .664 .741 .908 r
F
.50327 .52723 m .50038 .52424 L .50564 .52261 L F
.42823 .52709 m .43039 .52247 L .43341 .52547 L .664 .742 .908 r
F
.42823 .52709 m .4252 .5241 L .43039 .52247 L F
.51666 .52697 m .51906 .52235 L .52192 .52535 L F
.51666 .52697 m .51379 .52398 L .51906 .52235 L F
.35317 .52697 m .35513 .52234 L .35828 .52534 L .664 .741 .908 r
F
.35317 .52697 m .35001 .52397 L .35513 .52234 L F
.4416 .52684 m .4438 .52222 L .44679 .52522 L .663 .741 .908 r
F
.4416 .52684 m .4386 .52384 L .4438 .52222 L F
.36654 .52672 m .36852 .5221 L .37166 .5251 L F
.36654 .52672 m .3634 .52372 L .36852 .5221 L F
.45498 .52659 m .45721 .52198 L .46018 .52497 L .664 .742 .908 r
F
.45498 .52659 m .452 .52361 L .45721 .52198 L F
.3799 .52647 m .38193 .52185 L .38504 .52485 L .663 .741 .908 r
F
.3799 .52647 m .37679 .52347 L .38193 .52185 L F
.46836 .52635 m .47063 .52172 L .47358 .52473 L .664 .741 .908 r
F
.46836 .52635 m .4654 .52335 L .47063 .52172 L F
.39327 .52622 m .39534 .52159 L .39842 .52459 L .664 .742 .908 r
F
.39327 .52622 m .39018 .52322 L .39534 .52159 L F
.48174 .5261 m .48405 .52147 L .48698 .52448 L .664 .741 .908 r
F
.48174 .5261 m .47881 .5231 L .48405 .52147 L F
.40665 .52597 m .40875 .52135 L .41181 .52435 L .663 .741 .908 r
F
.40665 .52597 m .40358 .52297 L .40875 .52135 L F
.49513 .52586 m .49747 .52122 L .50038 .52424 L .663 .741 .907 r
F
.49513 .52586 m .49222 .52285 L .49747 .52122 L F
.42003 .52573 m .42216 .5211 L .4252 .5241 L .663 .74 .907 r
F
.42003 .52573 m .41698 .52272 L .42216 .5211 L F
.34491 .5256 m .34684 .52097 L .35001 .52397 L .663 .741 .908 r
F
.34491 .5256 m .34173 .5226 L .34684 .52097 L F
.50853 .5256 m .5109 .52097 L .51379 .52398 L .664 .742 .908 r
F
.50853 .5256 m .50564 .52261 L .5109 .52097 L F
.43341 .52547 m .43558 .52084 L .4386 .52384 L .664 .741 .908 r
F
.43341 .52547 m .43039 .52247 L .43558 .52084 L F
.35828 .52534 m .36025 .52072 L .3634 .52372 L .663 .741 .908 r
F
.35828 .52534 m .35513 .52234 L .36025 .52072 L F
.52192 .52535 m .52434 .52072 L .5272 .52373 L F
.52192 .52535 m .51906 .52235 L .52434 .52072 L F
.44679 .52522 m .449 .52059 L .452 .52361 L F
.44679 .52522 m .4438 .52222 L .449 .52059 L F
.37166 .5251 m .37366 .52047 L .37679 .52347 L F
.37166 .5251 m .36852 .5221 L .37366 .52047 L F
.46018 .52497 m .46243 .52034 L .4654 .52335 L .664 .742 .908 r
F
.46018 .52497 m .45721 .52198 L .46243 .52034 L F
.61212 .5964 m .61332 .53468 L .6162 .54459 L .981 .741 .497 r
F
.6162 .54459 m .61332 .53468 L .61791 .56371 L .956 .641 .224 r
F
.61212 .5964 m .60953 .59965 L .61332 .53468 L .981 .741 .497 r
F
.61879 .56682 m .61791 .56371 L .61989 .5762 L .956 .641 .224 r
F
.6162 .54459 m .61791 .56371 L .61879 .56682 L F
.61791 .56371 m .61668 .55567 L .61989 .5762 L .799 .469 .429 r
F
.61332 .53468 m .61608 .55197 L .61791 .56371 L F
.61608 .55197 m .61668 .55567 L .61791 .56371 L F
.60953 .59965 m .61087 .54179 L .61332 .53468 L .851 .619 .588 r
F
.61332 .53468 m .61087 .54179 L .61515 .55202 L .799 .469 .429 r
F
.61608 .55197 m .61515 .55202 L .61668 .55567 L F
.61332 .53468 m .61515 .55202 L .61608 .55197 L F
.60693 .58203 m .60641 .58175 L .60953 .59965 L .628 .361 .494 r
F
.60303 .55556 m .60622 .58026 L .60693 .58203 L F
.60622 .58026 m .60641 .58175 L .60693 .58203 L F
.60303 .55556 m .60083 .5763 L .60641 .58175 L F
.60641 .58175 m .60314 .55673 L .60862 .55773 L .566 .408 .627 r
F
.60314 .55673 m .60631 .573 L .60862 .55773 L 0 0 .247 r
F
.60314 .55673 m .60291 .55498 L .60443 .5612 L F
.60291 .55498 m .59993 .53289 L .60326 .55385 L F
.60291 .55498 m .60326 .55385 L .60443 .5612 L F
.60443 .5628 m .60443 .5612 L .60544 .56754 L F
.60314 .55673 m .60443 .5612 L .60443 .5628 L F
.60314 .55673 m .60544 .56754 L .60554 .56902 L F
.59583 .5959 m .597 .52121 L .59993 .53289 L .922 .676 .55 r
F
.59848 .5924 m .59993 .53289 L .60314 .55673 L .982 .743 .499 r
F
.59848 .5924 m .59583 .5959 L .59872 .5514 L F
.59938 .55537 m .59872 .5514 L .59993 .53289 L F
.59848 .5924 m .59872 .5514 L .59938 .55537 L F
.59583 .5959 m .59288 .58561 L .597 .52121 L .922 .676 .55 r
F
.59527 .53057 m .5976 .54698 L .60076 .56684 L .672 .38 .47 r
F
.59438 .52469 m .59496 .52869 L .59527 .53057 L F
.59496 .52869 m .5976 .54698 L .59527 .53057 L F
.60083 .5763 m .60314 .55673 L .60641 .58175 L .779 .7 .16 r
F
.60083 .5763 m .59848 .5924 L .60314 .55673 L F
.59993 .53289 m .597 .52121 L .60155 .55896 L .971 .667 .281 r
F
.60187 .55551 m .60155 .55896 L .60369 .57668 L F
.59993 .53289 m .60155 .55896 L .60187 .55551 L F
.597 .52121 m .60076 .56684 L .60369 .57668 L .922 .61 .434 r
F
.60554 .56902 m .60544 .56754 L .60631 .573 L 0 0 .247 r
F
.59993 .53289 m .60369 .57668 L .60631 .573 L .971 .667 .281 r
F
.60167 .56989 m .60076 .56684 L .60403 .55139 L .861 .651 .618 r
F
.60167 .56989 m .60403 .55139 L .60443 .54954 L F
.60479 .54948 m .60443 .54954 L .60571 .54351 L F
.60167 .56989 m .60443 .54954 L .60479 .54948 L F
.60088 .56623 m .60337 .55869 L .60571 .54351 L .317 .247 .618 r
F
.597 .52121 m .59438 .52469 L .60076 .56684 L .922 .61 .434 r
F
.60076 .56684 m .60086 .56652 L .60088 .56623 L .317 .247 .618 r
F
.60086 .56652 m .60337 .55869 L .60088 .56623 L F
.60076 .56684 m .5976 .54698 L .60035 .55257 L F
.60242 .56166 m .60096 .55524 L .60337 .55869 L F
.60096 .55524 m .6013 .55449 L .60337 .55869 L F
.60076 .56684 m .60035 .55257 L .60242 .56166 L F
.60096 .55524 m .60035 .55257 L .6013 .55449 L F
.59924 .55032 m .60078 .56487 L .60337 .55869 L 0 0 .177 r
F
.60369 .57668 m .60167 .56989 L .60571 .54351 L .861 .651 .618 r
F
.60571 .54351 m .60443 .55182 L .60797 .52157 L .839 .735 .212 r
F
.60443 .55182 m .60442 .55015 L .60797 .52157 L F
.60442 .55015 m .60576 .54127 L .60797 .52157 L .973 .85 .45 r
F
.60443 .55182 m .60337 .55869 L .60442 .55015 L .839 .735 .212 r
F
.60337 .55869 m .60463 .5495 L .60442 .55015 L .973 .85 .45 r
F
.60463 .5495 m .60576 .54127 L .60442 .55015 L F
.60337 .55869 m .60078 .56487 L .60576 .54127 L F
.60078 .56487 m .60349 .56007 L .60522 .54575 L .41 .42 .76 r
F
.60446 .54744 m .60522 .54575 L .60576 .54127 L F
.60078 .56487 m .60522 .54575 L .60446 .54744 L F
.5976 .54698 m .59822 .55047 L .59924 .55032 L 0 0 .177 r
F
.59822 .55047 m .60078 .56487 L .59924 .55032 L F
.58658 .5396 m .5898 .56785 L .59214 .54908 L .721 .431 .486 r
F
.59288 .58561 m .58972 .56374 L .59438 .52469 L .828 .598 .59 r
F
.59147 .54902 m .59197 .53933 L .59429 .52524 L .593 .431 .631 r
F
.58972 .56374 m .59153 .54417 L .59147 .54902 L F
.59153 .54417 m .59197 .53933 L .59147 .54902 L F
.58972 .56374 m .59429 .52524 L .59431 .52529 L F
.59431 .52529 m .59429 .52524 L .59438 .52469 L F
.59438 .52469 m .59197 .53933 L .59653 .54552 L .672 .38 .47 r
F
.59724 .54446 m .59653 .54552 L .5976 .54698 L F
.59438 .52469 m .59653 .54552 L .59724 .54446 L F
.58658 .5396 m .58414 .555 L .5898 .56785 L .721 .431 .486 r
F
.58972 .56374 m .58655 .54059 L .59197 .53933 L .593 .431 .631 r
F
.58655 .54059 m .58961 .55871 L .59197 .53933 L 0 0 .133 r
F
.59197 .53933 m .59444 .5261 L .5976 .54698 L 0 0 .028 r
F
.59197 .53933 m .59161 .54228 L .59444 .5261 L F
.59161 .54228 m .58961 .55871 L .59236 .54015 L F
.59417 .53145 m .59472 .53764 L .59786 .55677 L .95 .602 .31 r
F
.59161 .54228 m .59236 .54015 L .59409 .52851 L 0 0 .028 r
F
.59161 .54228 m .59409 .52851 L .59408 .52819 L F
.59408 .52819 m .59409 .52851 L .59444 .5261 L F
.59016 .55505 m .59146 .51291 L .59444 .5261 L .996 .781 .423 r
F
.59275 .52175 m .59423 .53368 L .59417 .53145 L .95 .602 .31 r
F
.59423 .53368 m .59472 .53764 L .59417 .53145 L F
.58974 .55568 m .59146 .51291 L .59016 .55505 L .996 .781 .423 r
F
.58414 .555 m .58744 .58772 L .5898 .56785 L .694 .417 .5 r
F
.58416 .55345 m .58173 .57005 L .58658 .5396 L 0 0 0 r
F
.5861 .51887 m .58455 .52663 L .58851 .50181 L .823 .748 .228 r
F
.58529 .53279 m .58347 .52161 L .58518 .53193 L 0 0 .133 r
F
.57641 .56881 m .57379 .57611 L .58138 .71469 L .938 .655 .479 r
F
.57379 .57611 m .57843 .70818 L .58138 .71469 L .938 .655 .476 r
F
.58138 .71469 m .57843 .70818 L .58173 .57005 L .949 .692 .513 r
F
.58146 .58133 m .57929 .58914 L .58173 .57005 L .919 .666 .54 r
F
.57843 .70818 m .57926 .59441 L .58146 .58133 L F
.57926 .59441 m .57929 .58914 L .58146 .58133 L F
.57379 .57611 m .57113 .58239 L .57843 .70818 L .938 .655 .476 r
F
.57113 .58239 m .57534 .69214 L .57843 .70818 L .919 .634 .486 r
F
.57843 .70818 m .57534 .69214 L .57929 .58914 L .919 .666 .54 r
F
.57904 .59571 m .57683 .60884 L .57929 .58914 L .873 .631 .57 r
F
.57534 .69214 m .57683 .60884 L .57904 .59571 L F
.57683 .60884 m .57665 .60988 L .57666 .6098 L .734 .686 .143 r
F
.57929 .58914 m .57683 .60884 L .58058 .58327 L 0 0 .009 r
F
.58058 .58327 m .57927 .59287 L .58175 .57525 L .734 .686 .143 r
F
.57683 .60884 m .57927 .59287 L .58058 .58327 L F
.57683 .60884 m .57666 .6098 L .57927 .59287 L F
.57425 .6242 m .57665 .60352 L .57927 .59287 L .987 .839 .458 r
F
.57927 .59287 m .57665 .60352 L .57756 .60286 L .401 .108 .349 r
F
.57665 .60988 m .57461 .62197 L .57927 .59287 L .734 .686 .143 r
F
.57461 .62197 m .57444 .623 L .57481 .62068 L F
.57461 .62197 m .57481 .62068 L .57927 .59287 L F
.57929 .58914 m .58058 .58327 L .5809 .58006 L 0 0 .009 r
F
.57947 .58773 m .57929 .58914 L .57949 .58778 L 0 0 0 r
F
.57947 .58773 m .57949 .58778 L .58414 .555 L F
.58173 .57005 m .57947 .58773 L .58414 .555 L F
.57929 .58914 m .58175 .57525 L .58414 .555 L 0 0 .009 r
F
.57665 .60352 m .57908 .58596 L .57972 .58883 L .997 .852 .569 r
F
.57927 .59287 m .57756 .60286 L .57796 .60258 L .401 .108 .349 r
F
.57927 .59287 m .57796 .60258 L .57868 .60206 L F
.57954 .5935 m .57868 .60206 L .5821 .59958 L F
.57927 .59287 m .57868 .60206 L .57954 .5935 L F
.58175 .57525 m .57927 .59287 L .58487 .59907 L .643 .364 .481 r
F
.57927 .59287 m .5821 .59958 L .58487 .59907 L .401 .108 .349 r
F
.57756 .60286 m .57972 .58883 L .5821 .59958 L .997 .852 .569 r
F
.57665 .60352 m .57972 .58883 L .57756 .60286 L F
.5809 .58006 m .58058 .58327 L .58175 .57525 L 0 0 .009 r
F
.57665 .60988 m .57425 .6242 L .57444 .623 L .734 .686 .143 r
F
.58414 .555 m .58175 .57525 L .58744 .58772 L .694 .417 .5 r
F
.58175 .57525 m .58487 .59907 L .58744 .58772 L .643 .364 .481 r
F
.5821 .59958 m .58347 .52161 L .58655 .54059 L .907 .662 .556 r
F
.58655 .54059 m .58529 .53279 L .58944 .55768 L 0 0 .133 r
F
.58529 .53279 m .58518 .53193 L .58944 .55768 L F
.5895 .55802 m .58944 .55768 L .58961 .55871 L F
.58655 .54059 m .58944 .55768 L .5895 .55802 L F
.58487 .59907 m .58655 .54059 L .58972 .56374 L .97 .732 .52 r
F
.58487 .59907 m .5821 .59958 L .5861 .54656 L F
.58636 .54725 m .5861 .54656 L .58655 .54059 L F
.58487 .59907 m .5861 .54656 L .58636 .54725 L F
.5821 .59958 m .57908 .58596 L .58347 .52161 L .907 .662 .556 r
F
.57908 .58596 m .5806 .51365 L .58347 .52161 L .852 .614 .579 r
F
.57908 .58596 m .57595 .56381 L .5806 .51365 L F
.57931 .52857 m .58133 .56125 L .58434 .5737 L .85 .549 .478 r
F
.57595 .56381 m .57789 .51581 L .5806 .51365 L .766 .552 .607 r
F
.57789 .51581 m .57874 .52706 L .57931 .52857 L .85 .549 .478 r
F
.57874 .52706 m .58133 .56125 L .57931 .52857 L F
.58347 .52161 m .58707 .57025 L .58961 .55871 L .974 .667 .346 r
F
.58347 .52161 m .5806 .51365 L .58478 .55021 L F
.58347 .52161 m .58478 .55021 L .58541 .5486 L F
.58347 .52161 m .58677 .56766 L .58688 .56766 L F
.5806 .51365 m .58434 .5737 L .58707 .57025 L .939 .635 .437 r
F
.5806 .51365 m .57789 .51581 L .58434 .5737 L F
.58168 .55818 m .58356 .53159 L .5861 .51887 L .709 .522 .634 r
F
.58133 .56125 m .58154 .55855 L .58168 .55818 L F
.58154 .55855 m .58356 .53159 L .58168 .55818 L F
.58541 .5486 m .58478 .55021 L .58677 .56766 L .974 .667 .346 r
F
.58688 .56766 m .58677 .56766 L .58707 .57025 L F
.58476 .56761 m .58563 .53351 L .58665 .53998 L .889 .655 .578 r
F
.58434 .5737 m .58454 .56761 L .58476 .56761 L F
.58454 .56761 m .58563 .53351 L .58476 .56761 L F
.58455 .52663 m .58356 .53159 L .58448 .52605 L .823 .748 .228 r
F
.58455 .52663 m .58448 .52605 L .58851 .50181 L F
.58665 .53998 m .5861 .51887 L .58868 .51034 L .889 .655 .578 r
F
.58563 .53351 m .5861 .51887 L .58665 .53998 L F
.58961 .55871 m .58707 .57025 L .59052 .5252 L .996 .781 .423 r
F
.59082 .52886 m .59052 .5252 L .59146 .51291 L F
.58961 .55871 m .59052 .5252 L .59082 .52886 L F
.58707 .57025 m .58868 .51034 L .59146 .51291 L .982 .744 .498 r
F
.59146 .51291 m .58868 .51034 L .59349 .53209 L .95 .602 .31 r
F
.58947 .5124 m .59155 .51671 L .59184 .51864 L .439 .116 .32 r
F
.58868 .51034 m .58944 .51201 L .58947 .5124 L F
.58944 .51201 m .59155 .51671 L .58947 .5124 L F
.58868 .51034 m .59184 .51864 L .59177 .52431 L F
.58707 .57025 m .58434 .5737 L .58868 .51034 L .982 .744 .498 r
F
.58868 .51034 m .5861 .51887 L .59155 .51671 L .439 .116 .32 r
F
.58816 .51805 m .58851 .50181 L .59155 .51671 L .823 .748 .228 r
F
.5861 .51887 m .58675 .51431 L .58816 .51805 L F
.58675 .51431 m .58851 .50181 L .58816 .51805 L F
.59425 .53409 m .59349 .53209 L .59472 .53764 L .95 .602 .31 r
F
.59146 .51291 m .59349 .53209 L .59425 .53409 L F
.59177 .52431 m .59184 .51864 L .59427 .53472 L .439 .116 .32 r
F
.59415 .53508 m .59427 .53472 L .59472 .53764 L F
.59177 .52431 m .59427 .53472 L .59415 .53508 L F
.58961 .55871 m .58974 .55568 L .59016 .55505 L .996 .781 .423 r
F
.59146 .51291 m .59257 .52134 L .59275 .52175 L .95 .602 .31 r
F
.59257 .52134 m .59472 .53764 L .59275 .52175 L F
.5976 .54698 m .59444 .5261 L .60078 .56487 L 0 0 .177 r
F
.59471 .52775 m .59786 .55677 L .60078 .56487 L .932 .632 .165 r
F
.59444 .5261 m .59454 .52701 L .59471 .52775 L F
.59454 .52701 m .59786 .55677 L .59471 .52775 L F
.60505 .56143 m .60571 .54351 L .60801 .52814 L .861 .651 .618 r
F
.60389 .57449 m .60484 .55822 L .60505 .56143 L F
.60484 .55822 m .60571 .54351 L .60505 .56143 L F
.60369 .57668 m .60384 .57436 L .60389 .57449 L F
.60384 .57436 m .60571 .54351 L .60389 .57449 L F
.60953 .59965 m .60641 .58175 L .61087 .54179 L .851 .619 .588 r
F
.61087 .54179 m .61349 .53527 L .61668 .55567 L 0 0 .138 r
F
.60641 .58175 m .60862 .55773 L .61087 .54179 L .566 .408 .627 r
F
.61087 .54179 m .61044 .54484 L .61349 .53527 L 0 0 .138 r
F
.61044 .54484 m .60862 .55773 L .61202 .54203 L F
.61044 .54484 m .61202 .54203 L .61349 .53527 L F
.61057 .52442 m .61336 .52428 L .615 .53675 L .003 0 0 r
F
.61191 .54256 m .61057 .52442 L .61349 .53526 L .946 .775 .315 r
F
.61349 .53528 m .61349 .53526 L .61349 .53527 L F
.61191 .54256 m .61349 .53526 L .61349 .53528 L F
.6162 .54459 m .61989 .5762 L .62268 .58185 L .956 .641 .224 r
F
.62268 .58185 m .62521 .57043 L .62706 .54519 L .771 .666 .746 r
F
.62268 .58185 m .61989 .5762 L .62233 .57355 L F
.62385 .57658 m .62233 .57355 L .62521 .57043 L F
.62268 .58185 m .62233 .57355 L .62385 .57658 L F
.61989 .5762 m .62292 .58259 L .62521 .57043 L 0 0 .437 r
F
.61989 .5762 m .61668 .55567 L .62292 .58259 L F
.61952 .5679 m .62011 .57701 L .62292 .58259 L 0 0 .123 r
F
.61668 .55567 m .61823 .56533 L .61952 .5679 L F
.61823 .56533 m .62011 .57701 L .61952 .5679 L F
.61668 .55567 m .61349 .53527 L .61938 .5724 L F
.61982 .5752 m .61938 .5724 L .62011 .57701 L F
.61668 .55567 m .61938 .5724 L .61982 .5752 L F
.61349 .53527 m .61669 .54962 L .62011 .57701 L .769 .477 0 r
F
.61349 .53527 m .61057 .52442 L .61381 .53774 L F
.61349 .53527 m .61381 .53774 L .61522 .54303 L F
.61057 .52442 m .615 .53675 L .614 .53853 L .003 0 0 r
F
.60992 .53553 m .61057 .52442 L .61191 .54256 L .946 .775 .315 r
F
.60862 .55773 m .60631 .573 L .6091 .54113 L F
.60888 .55322 m .6091 .54113 L .61057 .52442 L F
.60862 .55773 m .6091 .54113 L .60888 .55322 L F
.60801 .52814 m .60919 .52052 L .60946 .52154 L 0 0 0 r
F
.60631 .573 m .60801 .52814 L .61057 .52442 L .989 .762 .501 r
F
.60938 .52615 m .60801 .52814 L .60926 .52724 L .003 0 0 r
F
.60936 .52704 m .60926 .52724 L .60936 .52717 L F
.60938 .52615 m .60926 .52724 L .60936 .52704 L F
.60801 .52814 m .60946 .52154 L .60936 .52717 L 0 0 0 r
F
.60938 .52615 m .60936 .52717 L .61336 .52428 L .003 0 0 r
F
.61057 .52442 m .60938 .52615 L .61336 .52428 L F
.60919 .52052 m .61041 .51265 L .61071 .52619 L 0 0 0 r
F
.60631 .573 m .60369 .57668 L .60801 .52814 L .989 .762 .501 r
F
.60801 .52814 m .60571 .54351 L .60971 .51721 L 0 0 0 r
F
.60978 .5167 m .60971 .51721 L .61041 .51265 L F
.60801 .52814 m .60971 .51721 L .60978 .5167 L F
.61071 .52619 m .61041 .51265 L .61336 .52428 L F
.61336 .52428 m .61041 .51265 L .61608 .52038 L .274 .273 .677 r
F
.61041 .51265 m .61323 .51313 L .61608 .52038 L .068 0 .187 r
F
.60945 .51919 m .61071 .51875 L .61323 .51313 L 0 0 .258 r
F
.60773 .53023 m .60797 .52157 L .61041 .51265 L .839 .735 .212 r
F
.60797 .52157 m .60933 .52017 L .60945 .51919 L 0 0 .258 r
F
.60933 .52017 m .61071 .51875 L .60945 .51919 L F
.60571 .54351 m .60691 .53183 L .60773 .53023 L .839 .735 .212 r
F
.60691 .53183 m .60797 .52157 L .60773 .53023 L F
.60936 .52717 m .60946 .52154 L .61071 .52619 L 0 0 0 r
F
.61522 .54303 m .61381 .53774 L .61669 .54962 L .769 .477 0 r
F
.61417 .53922 m .615 .53675 L .61669 .54962 L .003 0 0 r
F
.614 .53853 m .61404 .53845 L .61417 .53922 L F
.61404 .53845 m .615 .53675 L .61417 .53922 L F
.60979 .55231 m .60992 .53553 L .61191 .54256 L .946 .775 .315 r
F
.60862 .55773 m .60893 .55236 L .60979 .55231 L F
.60893 .55236 m .60992 .53553 L .60979 .55231 L F
.38504 .52485 m .38708 .52022 L .39018 .52322 L .663 .741 .908 r
F
.38504 .52485 m .38193 .52185 L .38708 .52022 L F
.47358 .52473 m .47586 .52009 L .47881 .5231 L .664 .741 .908 r
F
.47358 .52473 m .47063 .52172 L .47586 .52009 L F
.39842 .52459 m .4005 .51996 L .40358 .52297 L .663 .741 .908 r
F
.39842 .52459 m .39534 .52159 L .4005 .51996 L F
.48698 .52448 m .4893 .51984 L .49222 .52285 L F
.48698 .52448 m .48405 .52147 L .4893 .51984 L F
.41181 .52435 m .41392 .51971 L .41698 .52272 L .664 .742 .908 r
F
.41181 .52435 m .40875 .52135 L .41392 .51971 L F
.33663 .52422 m .33854 .51958 L .34173 .5226 L .665 .742 .908 r
F
.33663 .52422 m .33343 .52123 L .33854 .51958 L F
.50038 .52424 m .50274 .51959 L .50564 .52261 L .664 .741 .907 r
F
.50038 .52424 m .49747 .52122 L .50274 .51959 L F
.4252 .5241 m .42735 .51946 L .43039 .52247 L .664 .741 .908 r
F
.4252 .5241 m .42216 .5211 L .42735 .51946 L F
.35001 .52397 m .35196 .51933 L .35513 .52234 L .664 .742 .908 r
F
.35001 .52397 m .34684 .52097 L .35196 .51933 L F
.51379 .52398 m .51618 .51934 L .51906 .52235 L .664 .741 .908 r
F
.51379 .52398 m .5109 .52097 L .51618 .51934 L F
.4386 .52384 m .44079 .51921 L .4438 .52222 L .663 .741 .908 r
F
.4386 .52384 m .43558 .52084 L .44079 .51921 L F
.3634 .52372 m .36538 .51908 L .36852 .5221 L .664 .742 .908 r
F
.3634 .52372 m .36025 .52072 L .36538 .51908 L F
.5272 .52373 m .52434 .52072 L .52963 .51911 L .662 .741 .908 r
F
.452 .52361 m .45422 .51897 L .45721 .52198 L .663 .741 .908 r
F
.452 .52361 m .449 .52059 L .45422 .51897 L F
.63209 .53202 m .63503 .53425 L .63752 .53198 L .201 0 .274 r
F
.63209 .53202 m .62981 .5419 L .63503 .53425 L F
.62706 .54519 m .62981 .5419 L .63209 .53202 L 0 0 .307 r
F
.37679 .52347 m .37881 .51883 L .38193 .52185 L .664 .742 .908 r
F
.37679 .52347 m .37366 .52047 L .37881 .51883 L F
.4654 .52335 m .46766 .51871 L .47063 .52172 L F
.4654 .52335 m .46243 .52034 L .46766 .51871 L F
.39018 .52322 m .39224 .51858 L .39534 .52159 L F
.39018 .52322 m .38708 .52022 L .39224 .51858 L F
.47881 .5231 m .48111 .51846 L .48405 .52147 L .663 .741 .908 r
F
.47881 .5231 m .47586 .52009 L .48111 .51846 L F
.40358 .52297 m .40567 .51834 L .40875 .52135 L F
.40358 .52297 m .4005 .51996 L .40567 .51834 L F
.49222 .52285 m .49456 .51821 L .49747 .52122 L F
.49222 .52285 m .4893 .51984 L .49456 .51821 L F
.41698 .52272 m .41911 .51808 L .42216 .5211 L .664 .741 .908 r
F
.41698 .52272 m .41392 .51971 L .41911 .51808 L F
.34173 .5226 m .34365 .51796 L .34684 .52097 L .663 .741 .908 r
F
.34173 .5226 m .33854 .51958 L .34365 .51796 L F
.50564 .52261 m .50801 .51795 L .5109 .52097 L .664 .741 .907 r
F
.50564 .52261 m .50274 .51959 L .50801 .51795 L F
.43039 .52247 m .43255 .51782 L .43558 .52084 L .664 .742 .908 r
F
.43039 .52247 m .42735 .51946 L .43255 .51782 L F
.35513 .52234 m .35709 .5177 L .36025 .52072 L .663 .741 .908 r
F
.35513 .52234 m .35196 .51933 L .35709 .5177 L F
.51906 .52235 m .52147 .51771 L .52434 .52072 L F
.51906 .52235 m .51618 .51934 L .52147 .51771 L F
.4438 .52222 m .446 .51757 L .449 .52059 L F
.4438 .52222 m .44079 .51921 L .446 .51757 L F
.36852 .5221 m .37052 .51745 L .37366 .52047 L F
.36852 .5221 m .36538 .51908 L .37052 .51745 L F
.45721 .52198 m .45945 .51733 L .46243 .52034 L .664 .741 .908 r
F
.45721 .52198 m .45422 .51897 L .45945 .51733 L F
.38193 .52185 m .38396 .5172 L .38708 .52022 L .663 .741 .908 r
F
.38193 .52185 m .37881 .51883 L .38396 .5172 L F
.47063 .52172 m .47291 .51707 L .47586 .52009 L .664 .742 .908 r
F
.47063 .52172 m .46766 .51871 L .47291 .51707 L F
.39534 .52159 m .39741 .51694 L .4005 .51996 L .663 .741 .908 r
F
.39534 .52159 m .39224 .51858 L .39741 .51694 L F
.48405 .52147 m .48636 .51683 L .4893 .51984 L .663 .742 .908 r
F
.48405 .52147 m .48111 .51846 L .48636 .51683 L F
.40875 .52135 m .41086 .5167 L .41392 .51971 L F
.40875 .52135 m .40567 .51834 L .41086 .5167 L F
.49747 .52122 m .49983 .51657 L .50274 .51959 L .664 .742 .908 r
F
.49747 .52122 m .49456 .51821 L .49983 .51657 L F
.33343 .52123 m .33534 .51656 L .33854 .51958 L .664 .741 .907 r
F
.33343 .52123 m .33023 .51821 L .33534 .51656 L F
.42216 .5211 m .42431 .51644 L .42735 .51946 L .664 .741 .908 r
F
.42216 .5211 m .41911 .51808 L .42431 .51644 L F
.63752 .53198 m .6405 .53429 L .64283 .52782 L .398 0 0 r
F
.63752 .53198 m .63503 .53425 L .6405 .53429 L F
.5109 .52097 m .51329 .51632 L .51618 .51934 L .663 .741 .908 r
F
.5109 .52097 m .50801 .51795 L .51329 .51632 L F
.34684 .52097 m .34878 .51631 L .35196 .51933 L .664 .742 .908 r
F
.34684 .52097 m .34365 .51796 L .34878 .51631 L F
.43558 .52084 m .43777 .51619 L .44079 .51921 L .663 .741 .908 r
F
.43558 .52084 m .43255 .51782 L .43777 .51619 L F
.52434 .52072 m .52676 .51607 L .52963 .51911 L .663 .742 .908 r
F
.52434 .52072 m .52147 .51771 L .52676 .51607 L F
.36025 .52072 m .36223 .51606 L .36538 .51908 L .664 .741 .908 r
F
.36025 .52072 m .35709 .5177 L .36223 .51606 L F
.64283 .52782 m .6465 .54854 L .64862 .53659 L .81 .473 .418 r
F
.64283 .52782 m .6405 .53429 L .6465 .54854 L F
.449 .52059 m .45123 .51594 L .45422 .51897 L .663 .741 .908 r
F
.449 .52059 m .446 .51757 L .45123 .51594 L F
.37366 .52047 m .37568 .51581 L .37881 .51883 L .664 .741 .908 r
F
.37366 .52047 m .37052 .51745 L .37568 .51581 L F
.46243 .52034 m .46469 .51569 L .46766 .51871 L .664 .742 .908 r
F
.46243 .52034 m .45945 .51733 L .46469 .51569 L F
.38708 .52022 m .38913 .51555 L .39224 .51858 L .664 .741 .908 r
F
.38708 .52022 m .38396 .5172 L .38913 .51555 L F
.47586 .52009 m .47816 .51543 L .48111 .51846 L .663 .741 .908 r
F
.47586 .52009 m .47291 .51707 L .47816 .51543 L F
.4005 .51996 m .40259 .51531 L .40567 .51834 L F
.4005 .51996 m .39741 .51694 L .40259 .51531 L F
.4893 .51984 m .49163 .51519 L .49456 .51821 L .663 .742 .909 r
F
.4893 .51984 m .48636 .51683 L .49163 .51519 L F
.41392 .51971 m .41605 .51505 L .41911 .51808 L .664 .742 .908 r
F
.41392 .51971 m .41086 .5167 L .41605 .51505 L F
.33854 .51958 m .34046 .51493 L .34365 .51796 L .663 .741 .908 r
F
.33854 .51958 m .33534 .51656 L .34046 .51493 L F
.50274 .51959 m .50511 .51493 L .50801 .51795 L .663 .742 .908 r
F
.50274 .51959 m .49983 .51657 L .50511 .51493 L F
.42735 .51946 m .42952 .51479 L .43255 .51782 L .664 .741 .908 r
F
.42735 .51946 m .42431 .51644 L .42952 .51479 L F
.35196 .51933 m .35391 .51467 L .35709 .5177 L .663 .741 .908 r
F
.35196 .51933 m .34878 .51631 L .35391 .51467 L F
.51618 .51934 m .51859 .51468 L .52147 .51771 L F
.51618 .51934 m .51329 .51632 L .51859 .51468 L F
.62706 .54519 m .62521 .57043 L .62981 .5419 L 0 0 .307 r
F
.44079 .51921 m .44299 .51455 L .446 .51757 L .663 .741 .908 r
F
.44079 .51921 m .43777 .51619 L .44299 .51455 L F
.36538 .51908 m .36737 .51442 L .37052 .51745 L .664 .742 .908 r
F
.36538 .51908 m .36223 .51606 L .36737 .51442 L F
.45422 .51897 m .45646 .5143 L .45945 .51733 L .664 .741 .908 r
F
.45422 .51897 m .45123 .51594 L .45646 .5143 L F
.37881 .51883 m .38084 .51417 L .38396 .5172 L .664 .742 .908 r
F
.37881 .51883 m .37568 .51581 L .38084 .51417 L F
.46766 .51871 m .46994 .51404 L .47291 .51707 L F
.46766 .51871 m .46469 .51569 L .46994 .51404 L F
.39224 .51858 m .39431 .51391 L .39741 .51694 L .663 .741 .908 r
F
.39224 .51858 m .38913 .51555 L .39431 .51391 L F
.48111 .51846 m .48342 .51379 L .48636 .51683 L F
.48111 .51846 m .47816 .51543 L .48342 .51379 L F
.40567 .51834 m .40778 .51367 L .41086 .5167 L F
.40567 .51834 m .40259 .51531 L .40778 .51367 L F
.33023 .51821 m .33212 .51354 L .33534 .51656 L F
.33023 .51821 m .32701 .51518 L .33212 .51354 L F
.49456 .51821 m .49691 .51355 L .49983 .51657 L .664 .742 .908 r
F
.49456 .51821 m .49163 .51519 L .49691 .51355 L F
.41911 .51808 m .42125 .51341 L .42431 .51644 L .664 .741 .908 r
F
.41911 .51808 m .41605 .51505 L .42125 .51341 L F
.50801 .51795 m .5104 .51328 L .51329 .51632 L .664 .742 .908 r
F
.50801 .51795 m .50511 .51493 L .5104 .51328 L F
.34365 .51796 m .34559 .51328 L .34878 .51631 L .664 .741 .907 r
F
.34365 .51796 m .34046 .51493 L .34559 .51328 L F
.43255 .51782 m .43473 .51315 L .43777 .51619 L .663 .741 .908 r
F
.43255 .51782 m .42952 .51479 L .43473 .51315 L F
.35709 .5177 m .35906 .51304 L .36223 .51606 L F
.35709 .5177 m .35391 .51467 L .35906 .51304 L F
.52147 .51771 m .52389 .51303 L .52676 .51607 L F
.52147 .51771 m .51859 .51468 L .52389 .51303 L F
.446 .51757 m .44822 .51291 L .45123 .51594 L .664 .742 .908 r
F
.446 .51757 m .44299 .51455 L .44822 .51291 L F
.37052 .51745 m .37253 .51278 L .37568 .51581 L .663 .741 .908 r
F
.37052 .51745 m .36737 .51442 L .37253 .51278 L F
.45945 .51733 m .46171 .51265 L .46469 .51569 L .664 .741 .907 r
F
.45945 .51733 m .45646 .5143 L .46171 .51265 L F
.38396 .5172 m .38601 .51252 L .38913 .51555 L .664 .741 .908 r
F
.38396 .5172 m .38084 .51417 L .38601 .51252 L F
.47291 .51707 m .4752 .51239 L .47816 .51543 L .663 .741 .908 r
F
.47291 .51707 m .46994 .51404 L .4752 .51239 L F
.39741 .51694 m .39949 .51227 L .40259 .51531 L .664 .741 .908 r
F
.39741 .51694 m .39431 .51391 L .39949 .51227 L F
.48636 .51683 m .48869 .51215 L .49163 .51519 L .663 .741 .908 r
F
.48636 .51683 m .48342 .51379 L .48869 .51215 L F
.41086 .5167 m .41298 .51202 L .41605 .51505 L .664 .741 .908 r
F
.41086 .5167 m .40778 .51367 L .41298 .51202 L F
.33534 .51656 m .33725 .51189 L .34046 .51493 L .664 .742 .908 r
F
.33534 .51656 m .33212 .51354 L .33725 .51189 L F
.49983 .51657 m .50219 .51189 L .50511 .51493 L F
.49983 .51657 m .49691 .51355 L .50219 .51189 L F
.42431 .51644 m .42647 .51176 L .42952 .51479 L .664 .741 .908 r
F
.42431 .51644 m .42125 .51341 L .42647 .51176 L F
.34878 .51631 m .35073 .51163 L .35391 .51467 L .663 .741 .908 r
F
.34878 .51631 m .34559 .51328 L .35073 .51163 L F
.51329 .51632 m .5157 .51163 L .51859 .51468 L .664 .741 .908 r
F
.51329 .51632 m .5104 .51328 L .5157 .51163 L F
.43777 .51619 m .43996 .51151 L .44299 .51455 L .663 .741 .908 r
F
.43777 .51619 m .43473 .51315 L .43996 .51151 L F
.36223 .51606 m .36421 .51138 L .36737 .51442 L .664 .742 .908 r
F
.36223 .51606 m .35906 .51304 L .36421 .51138 L F
.52676 .51607 m .52389 .51303 L .52921 .51144 L .66 .74 .909 r
F
.45123 .51594 m .45346 .51125 L .45646 .5143 L .664 .741 .908 r
F
.45123 .51594 m .44822 .51291 L .45346 .51125 L F
.37568 .51581 m .3777 .51113 L .38084 .51417 L .664 .742 .908 r
F
.37568 .51581 m .37253 .51278 L .3777 .51113 L F
.46469 .51569 m .46696 .511 L .46994 .51404 L .664 .741 .908 r
F
.46469 .51569 m .46171 .51265 L .46696 .511 L F
.38913 .51555 m .39119 .51087 L .39431 .51391 L .663 .741 .908 r
F
.38913 .51555 m .38601 .51252 L .39119 .51087 L F
.47816 .51543 m .48047 .51075 L .48342 .51379 L F
.47816 .51543 m .4752 .51239 L .48047 .51075 L F
.63503 .53425 m .63858 .55365 L .6405 .53429 L .619 .337 .468 r
F
.63503 .53425 m .63294 .54979 L .63858 .55365 L F
.62981 .5419 m .63294 .54979 L .63503 .53425 L .333 .104 .41 r
F
.40259 .51531 m .40469 .51062 L .40778 .51367 L .664 .741 .908 r
F
.40259 .51531 m .39949 .51227 L .40469 .51062 L F
.32701 .51518 m .3289 .51049 L .33212 .51354 L .664 .742 .908 r
F
.32701 .51518 m .32378 .51214 L .3289 .51049 L F
.49163 .51519 m .49398 .5105 L .49691 .51355 L .664 .741 .908 r
F
.49163 .51519 m .48869 .51215 L .49398 .5105 L F
.41605 .51505 m .41819 .51037 L .42125 .51341 L .664 .742 .908 r
F
.41605 .51505 m .41298 .51202 L .41819 .51037 L F
.34046 .51493 m .34239 .51024 L .34559 .51328 L .664 .741 .908 r
F
.34046 .51493 m .33725 .51189 L .34239 .51024 L F
.50511 .51493 m .50749 .51024 L .5104 .51328 L F
.50511 .51493 m .50219 .51189 L .50749 .51024 L F
.42952 .51479 m .43169 .51011 L .43473 .51315 L .663 .741 .908 r
F
.42952 .51479 m .42647 .51176 L .43169 .51011 L F
.35391 .51467 m .35588 .50999 L .35906 .51304 L F
.35391 .51467 m .35073 .51163 L .35588 .50999 L F
.51859 .51468 m .52101 .51001 L .52389 .51303 L .661 .74 .909 r
F
.51859 .51468 m .5157 .51163 L .52101 .51001 L F
.44299 .51455 m .4452 .50987 L .44822 .51291 L .663 .741 .908 r
F
.44299 .51455 m .43996 .51151 L .4452 .50987 L F
.36737 .51442 m .36938 .50973 L .37253 .51278 L F
.36737 .51442 m .36421 .51138 L .36938 .50973 L F
.45646 .5143 m .45871 .5096 L .46171 .51265 L .664 .741 .908 r
F
.45646 .5143 m .45346 .51125 L .45871 .5096 L F
.38084 .51417 m .38288 .50947 L .38601 .51252 L .664 .742 .908 r
F
.38084 .51417 m .3777 .51113 L .38288 .50947 L F
.46994 .51404 m .47223 .50935 L .4752 .51239 L .663 .741 .908 r
F
.46994 .51404 m .46696 .511 L .47223 .50935 L F
.62981 .5419 m .62776 .55979 L .63294 .54979 L .333 .104 .41 r
F
.62521 .57043 m .62776 .55979 L .62981 .5419 L 0 0 0 r
F
.39431 .51391 m .39639 .50923 L .39949 .51227 L .663 .741 .908 r
F
.39431 .51391 m .39119 .51087 L .39639 .50923 L F
.64862 .53659 m .6526 .56381 L .65501 .55984 L .764 .458 .467 r
F
.64862 .53659 m .6465 .54854 L .6526 .56381 L F
.48342 .51379 m .48575 .5091 L .48869 .51215 L .663 .741 .908 r
F
.48342 .51379 m .48047 .51075 L .48575 .5091 L F
.40778 .51367 m .40989 .50897 L .41298 .51202 L F
.40778 .51367 m .40469 .51062 L .40989 .50897 L F
.33212 .51354 m .33403 .50884 L .33725 .51189 L F
.33212 .51354 m .3289 .51049 L .33403 .50884 L F
.49691 .51355 m .49927 .50884 L .50219 .51189 L .664 .741 .907 r
F
.49691 .51355 m .49398 .5105 L .49927 .50884 L F
.42125 .51341 m .42341 .50871 L .42647 .51176 L .664 .741 .908 r
F
.42125 .51341 m .41819 .51037 L .42341 .50871 L F
.34559 .51328 m .34754 .50859 L .35073 .51163 L .663 .741 .908 r
F
.34559 .51328 m .34239 .51024 L .34754 .50859 L F
.5104 .51328 m .5128 .50859 L .5157 .51163 L F
.5104 .51328 m .50749 .51024 L .5128 .50859 L F
.43473 .51315 m .43693 .50846 L .43996 .51151 L F
.43473 .51315 m .43169 .51011 L .43693 .50846 L F
.52389 .51303 m .52633 .50835 L .52921 .51144 L .665 .743 .909 r
F
.52389 .51303 m .52101 .51001 L .52633 .50835 L F
.35906 .51304 m .36104 .50834 L .36421 .51138 L .663 .741 .908 r
F
.35906 .51304 m .35588 .50999 L .36104 .50834 L F
.44822 .51291 m .45045 .50821 L .45346 .51125 L .664 .742 .908 r
F
.44822 .51291 m .4452 .50987 L .45045 .50821 L F
.6405 .53429 m .64433 .55994 L .6465 .54854 L .64 .367 .489 r
F
.6405 .53429 m .63858 .55365 L .64433 .55994 L F
.37253 .51278 m .37455 .50808 L .3777 .51113 L .663 .741 .908 r
F
.37253 .51278 m .36938 .50973 L .37455 .50808 L F
.46171 .51265 m .46397 .50794 L .46696 .511 L .664 .741 .908 r
F
.46171 .51265 m .45871 .5096 L .46397 .50794 L F
.38601 .51252 m .38807 .50782 L .39119 .51087 L F
.38601 .51252 m .38288 .50947 L .38807 .50782 L F
.4752 .51239 m .4775 .5077 L .48047 .51075 L .663 .741 .908 r
F
.4752 .51239 m .47223 .50935 L .4775 .5077 L F
.39949 .51227 m .40159 .50757 L .40469 .51062 L .664 .742 .908 r
F
.39949 .51227 m .39639 .50923 L .40159 .50757 L F
.32378 .51214 m .32566 .50744 L .3289 .51049 L F
.32378 .51214 m .32053 .5091 L .32566 .50744 L F
.48869 .51215 m .49104 .50744 L .49398 .5105 L .664 .741 .908 r
F
.48869 .51215 m .48575 .5091 L .49104 .50744 L F
.41298 .51202 m .41511 .50732 L .41819 .51037 L F
.41298 .51202 m .40989 .50897 L .41511 .50732 L F
.33725 .51189 m .33918 .50718 L .34239 .51024 L .664 .742 .908 r
F
.33725 .51189 m .33403 .50884 L .33918 .50718 L F
.50219 .51189 m .50457 .50718 L .50749 .51024 L .664 .741 .908 r
F
.50219 .51189 m .49927 .50884 L .50457 .50718 L F
.42647 .51176 m .42864 .50706 L .43169 .51011 L .663 .741 .908 r
F
.42647 .51176 m .42341 .50871 L .42864 .50706 L F
.35073 .51163 m .35269 .50693 L .35588 .50999 L .664 .742 .908 r
F
.35073 .51163 m .34754 .50859 L .35269 .50693 L F
.5157 .51163 m .51811 .50694 L .52101 .51001 L .663 .742 .908 r
F
.5157 .51163 m .5128 .50859 L .51811 .50694 L F
.43996 .51151 m .44217 .50681 L .4452 .50987 L .663 .741 .908 r
F
.43996 .51151 m .43693 .50846 L .44217 .50681 L F
.36421 .51138 m .36621 .50667 L .36938 .50973 L .664 .742 .908 r
F
.36421 .51138 m .36104 .50834 L .36621 .50667 L F
.45346 .51125 m .45571 .50655 L .45871 .5096 L F
.45346 .51125 m .45045 .50821 L .45571 .50655 L F
.65971 .53869 m .6631 .54797 L .66525 .53889 L 0 0 .381 r
F
.66218 .54069 m .66307 .5351 L .66514 .52393 L .525 .404 .656 r
F
.65971 .53869 m .65656 .52288 L .66184 .54315 L 0 0 .381 r
F
.65971 .53869 m .66184 .54315 L .66171 .54415 L F
.66171 .54415 m .66184 .54315 L .6631 .54797 L F
.65501 .55984 m .65656 .52288 L .65971 .53869 L .996 .779 .487 r
F
.65656 .52288 m .66062 .54953 L .6631 .54797 L .93 .582 .347 r
F
.66062 .54953 m .66243 .53887 L .66218 .54069 L .525 .404 .656 r
F
.66243 .53887 m .66307 .5351 L .66218 .54069 L F
.65597 .53687 m .65553 .53348 L .65656 .52288 L .996 .779 .487 r
F
.6526 .56381 m .65404 .5232 L .65656 .52288 L .741 .536 .616 r
F
.65656 .52288 m .65404 .5232 L .65976 .54606 L .93 .582 .347 r
F
.66026 .54713 m .65976 .54606 L .66062 .54953 L F
.65656 .52288 m .65976 .54606 L .66026 .54713 L F
.65438 .52456 m .65739 .53226 L .66062 .54953 L .463 .181 .399 r
F
.65404 .5232 m .65429 .52389 L .65438 .52456 L F
.65429 .52389 m .65739 .53226 L .65438 .52456 L F
.6526 .56381 m .64919 .54113 L .65404 .5232 L .741 .536 .616 r
F
.65404 .5232 m .65195 .53532 L .656 .53304 L .463 .181 .399 r
F
.65685 .5308 m .656 .53304 L .65739 .53226 L F
.65404 .5232 m .656 .53304 L .65685 .5308 L F
.65254 .52875 m .65195 .53532 L .65404 .5232 L .324 .281 .655 r
F
.64919 .54113 m .65195 .53532 L .65254 .52875 L F
.6465 .54854 m .64919 .54113 L .6526 .56381 L 0 0 .024 r
F
.65195 .53532 m .65002 .55241 L .65136 .54196 L 0 0 0 r
F
.65223 .53516 m .65275 .53113 L .65414 .53409 L F
.6526 .53082 m .65432 .5189 L .65414 .53409 L F
.65414 .53409 m .65432 .5189 L .65739 .53226 L F
.65347 .52478 m .65362 .52432 L .65432 .5189 L F
.65195 .53532 m .65136 .54196 L .65362 .52432 L F
.65195 .53532 m .65362 .52432 L .65347 .52478 L F
.64919 .54113 m .64609 .52651 L .65195 .53532 L .324 .281 .655 r
F
.6465 .54854 m .64433 .55994 L .64919 .54113 L 0 0 .024 r
F
.64433 .55994 m .64609 .52651 L .64919 .54113 L .873 .661 .612 r
F
.64609 .52651 m .65002 .55241 L .65195 .53532 L .952 .611 .219 r
F
.6507 .54711 m .65154 .51324 L .65432 .5189 L .877 .655 .599 r
F
.65432 .5189 m .65154 .51324 L .65812 .53897 L .931 .575 .152 r
F
.65404 .52303 m .65495 .52358 L .65812 .53897 L .629 .281 .362 r
F
.65154 .51324 m .6544 .52194 L .65404 .52303 L F
.6544 .52194 m .65495 .52358 L .65404 .52303 L F
.65002 .55241 m .65017 .54851 L .6507 .54711 L .877 .655 .599 r
F
.65017 .54851 m .65154 .51324 L .6507 .54711 L F
.65501 .55984 m .6526 .56381 L .65553 .53348 L .996 .779 .487 r
F
.65501 .55984 m .65553 .53348 L .65597 .53687 L F
.3777 .51113 m .37974 .50642 L .38288 .50947 L .664 .742 .908 r
F
.3777 .51113 m .37455 .50808 L .37974 .50642 L F
.46696 .511 m .46924 .50629 L .47223 .50935 L .663 .741 .908 r
F
.46696 .511 m .46397 .50794 L .46924 .50629 L F
.39119 .51087 m .39327 .50617 L .39639 .50923 L F
.39119 .51087 m .38807 .50782 L .39327 .50617 L F
.48047 .51075 m .48279 .50605 L .48575 .5091 L .663 .742 .908 r
F
.48047 .51075 m .4775 .5077 L .48279 .50605 L F
.40469 .51062 m .4068 .50591 L .40989 .50897 L .664 .742 .908 r
F
.40469 .51062 m .40159 .50757 L .4068 .50591 L F
.3289 .51049 m .3308 .50579 L .33403 .50884 L .663 .741 .908 r
F
.3289 .51049 m .32566 .50744 L .3308 .50579 L F
.49398 .5105 m .49634 .50579 L .49927 .50884 L F
.49398 .5105 m .49104 .50744 L .49634 .50579 L F
.41819 .51037 m .42034 .50565 L .42341 .50871 L .664 .742 .908 r
F
.41819 .51037 m .41511 .50732 L .42034 .50565 L F
.34239 .51024 m .34433 .50553 L .34754 .50859 L .663 .741 .908 r
F
.34239 .51024 m .33918 .50718 L .34433 .50553 L F
.50749 .51024 m .50989 .50553 L .5128 .50859 L F
.50749 .51024 m .50457 .50718 L .50989 .50553 L F
.43169 .51011 m .43388 .5054 L .43693 .50846 L F
.43169 .51011 m .42864 .50706 L .43388 .5054 L F
.35588 .50999 m .35786 .50528 L .36104 .50834 L F
.35588 .50999 m .35269 .50693 L .35786 .50528 L F
.52101 .51001 m .52344 .50528 L .52633 .50835 L .663 .74 .907 r
F
.52101 .51001 m .51811 .50694 L .52344 .50528 L F
.4452 .50987 m .44742 .50515 L .45045 .50821 L .664 .741 .908 r
F
.4452 .50987 m .44217 .50681 L .44742 .50515 L F
.36938 .50973 m .37139 .50502 L .37455 .50808 L .663 .741 .908 r
F
.36938 .50973 m .36621 .50667 L .37139 .50502 L F
.45871 .5096 m .46097 .50488 L .46397 .50794 L .664 .742 .908 r
F
.45871 .5096 m .45571 .50655 L .46097 .50488 L F
.38288 .50947 m .38493 .50475 L .38807 .50782 L .664 .741 .908 r
F
.38288 .50947 m .37974 .50642 L .38493 .50475 L F
.47223 .50935 m .47453 .50464 L .4775 .5077 L .663 .741 .908 r
F
.47223 .50935 m .46924 .50629 L .47453 .50464 L F
.39639 .50923 m .39848 .50451 L .40159 .50757 L F
.39639 .50923 m .39327 .50617 L .39848 .50451 L F
.32053 .5091 m .32242 .50437 L .32566 .50744 L .664 .741 .908 r
F
.32053 .5091 m .31728 .50604 L .32242 .50437 L F
.48575 .5091 m .48808 .50439 L .49104 .50744 L .663 .741 .908 r
F
.48575 .5091 m .48279 .50605 L .48808 .50439 L F
.57113 .58239 m .5685 .59336 L .57534 .69214 L .919 .634 .486 r
F
.40989 .50897 m .41202 .50425 L .41511 .50732 L .663 .741 .908 r
F
.40989 .50897 m .4068 .50591 L .41202 .50425 L F
.49927 .50884 m .50165 .50412 L .50457 .50718 L .664 .742 .908 r
F
.49927 .50884 m .49634 .50579 L .50165 .50412 L F
.33403 .50884 m .33595 .50412 L .33918 .50718 L .664 .741 .908 r
F
.33403 .50884 m .3308 .50579 L .33595 .50412 L F
.42341 .50871 m .42557 .50399 L .42864 .50706 L .663 .741 .908 r
F
.42341 .50871 m .42034 .50565 L .42557 .50399 L F
.34754 .50859 m .34949 .50387 L .35269 .50693 L F
.34754 .50859 m .34433 .50553 L .34949 .50387 L F
.5128 .50859 m .51521 .50387 L .51811 .50694 L F
.5128 .50859 m .50989 .50553 L .51521 .50387 L F
.43693 .50846 m .43913 .50374 L .44217 .50681 L F
.43693 .50846 m .43388 .5054 L .43913 .50374 L F
.61041 .51265 m .60797 .52157 L .61323 .51313 L .068 0 .187 r
F
.36104 .50834 m .36304 .50361 L .36621 .50667 L .664 .741 .908 r
F
.36104 .50834 m .35786 .50528 L .36304 .50361 L F
.52633 .50835 m .52344 .50528 L .52878 .50429 L .611 .724 .926 r
F
.45045 .50821 m .45269 .50348 L .45571 .50655 L .664 .741 .908 r
F
.45045 .50821 m .44742 .50515 L .45269 .50348 L F
.37455 .50808 m .37659 .50335 L .37974 .50642 L F
.37455 .50808 m .37139 .50502 L .37659 .50335 L F
.46397 .50794 m .46625 .50322 L .46924 .50629 L .663 .741 .908 r
F
.46397 .50794 m .46097 .50488 L .46625 .50322 L F
.38807 .50782 m .39014 .50309 L .39327 .50617 L F
.38807 .50782 m .38493 .50475 L .39014 .50309 L F
.4775 .5077 m .47982 .50298 L .48279 .50605 L F
.4775 .5077 m .47453 .50464 L .47982 .50298 L F
.40159 .50757 m .4037 .50284 L .4068 .50591 L .664 .742 .908 r
F
.40159 .50757 m .39848 .50451 L .4037 .50284 L F
.68186 .52087 m .68396 .51582 L .68699 .52764 L 0 0 .244 r
F
.68105 .51979 m .68396 .51582 L .68186 .52087 L F
.68105 .51979 m .6793 .53567 L .68396 .51582 L F
.68699 .52764 m .68396 .51582 L .68955 .51591 L .58 .473 .696 r
F
.68396 .51582 m .68674 .5088 L .68955 .51591 L 0 0 0 r
F
.6793 .53567 m .68182 .52295 L .68396 .51582 L .763 .736 .212 r
F
.68396 .51582 m .68182 .52295 L .68607 .51074 L 0 0 0 r
F
.68396 .51582 m .68607 .51074 L .68674 .5088 L F
.67892 .53848 m .6793 .53567 L .68105 .51979 L .974 .837 .43 r
F
.6793 .53567 m .6772 .54437 L .67969 .53283 L .763 .736 .212 r
F
.6793 .53567 m .67969 .53283 L .68182 .52295 L F
.67707 .55472 m .6793 .53567 L .67892 .53848 L .974 .837 .43 r
F
.32566 .50744 m .32756 .50271 L .3308 .50579 L .663 .741 .908 r
F
.32566 .50744 m .32242 .50437 L .32756 .50271 L F
.49104 .50744 m .49339 .50272 L .49634 .50579 L .664 .742 .908 r
F
.49104 .50744 m .48808 .50439 L .49339 .50272 L F
.41511 .50732 m .41726 .50258 L .42034 .50565 L .664 .741 .908 r
F
.41511 .50732 m .41202 .50425 L .41726 .50258 L F
.33918 .50718 m .34111 .50245 L .34433 .50553 L F
.33918 .50718 m .33595 .50412 L .34111 .50245 L F
.50457 .50718 m .50697 .50245 L .50989 .50553 L .663 .741 .908 r
F
.50457 .50718 m .50165 .50412 L .50697 .50245 L F
.61669 .54962 m .61336 .52428 L .6193 .54101 L .279 .203 .589 r
F
.61336 .52428 m .61608 .52038 L .6193 .54101 L .274 .273 .677 r
F
.42864 .50706 m .43082 .50233 L .43388 .5054 L .663 .741 .908 r
F
.42864 .50706 m .42557 .50399 L .43082 .50233 L F
.35269 .50693 m .35467 .5022 L .35786 .50528 L .664 .742 .908 r
F
.35269 .50693 m .34949 .50387 L .35467 .5022 L F
.51811 .50694 m .52055 .50222 L .52344 .50528 L .662 .74 .908 r
F
.51811 .50694 m .51521 .50387 L .52055 .50222 L F
.44217 .50681 m .44439 .50207 L .44742 .50515 L .664 .741 .907 r
F
.44217 .50681 m .43913 .50374 L .44439 .50207 L F
.36621 .50667 m .36822 .50194 L .37139 .50502 L .664 .742 .908 r
F
.36621 .50667 m .36304 .50361 L .36822 .50194 L F
.45571 .50655 m .45796 .50181 L .46097 .50488 L .664 .741 .908 r
F
.45571 .50655 m .45269 .50348 L .45796 .50181 L F
.37974 .50642 m .38179 .50169 L .38493 .50475 L .663 .741 .908 r
F
.37974 .50642 m .37659 .50335 L .38179 .50169 L F
.46924 .50629 m .47154 .50156 L .47453 .50464 L F
.46924 .50629 m .46625 .50322 L .47154 .50156 L F
.39327 .50617 m .39535 .50143 L .39848 .50451 L .663 .74 .908 r
F
.39327 .50617 m .39014 .50309 L .39535 .50143 L F
.31728 .50604 m .31916 .5013 L .32242 .50437 L .664 .741 .908 r
F
.31728 .50604 m .31401 .50297 L .31916 .5013 L F
.48279 .50605 m .48512 .50131 L .48808 .50439 L .664 .742 .908 r
F
.48279 .50605 m .47982 .50298 L .48512 .50131 L F
.66525 .53889 m .66763 .52349 L .67082 .53953 L .838 .768 .259 r
F
.67082 .53953 m .66763 .52349 L .67481 .56037 L .716 .47 0 r
F
.66514 .52393 m .66777 .5141 L .66808 .51622 L 0 0 0 r
F
.66525 .53889 m .66404 .544 L .66763 .52349 L .838 .768 .259 r
F
.66404 .544 m .66479 .53884 L .66763 .52349 L F
.67082 .53953 m .67481 .56037 L .67707 .55472 L .716 .47 0 r
F
.66763 .52349 m .6713 .5377 L .67481 .56037 L .887 .485 .254 r
F
.6631 .54797 m .66514 .52393 L .66763 .52349 L .994 .807 .545 r
F
.66763 .52349 m .66514 .52393 L .6682 .53078 L .887 .485 .254 r
F
.66975 .5317 m .6682 .53078 L .6713 .5377 L F
.66763 .52349 m .6682 .53078 L .66975 .5317 L F
.66514 .52393 m .66808 .51622 L .66651 .527 L 0 0 0 r
F
.6631 .54797 m .66062 .54953 L .66514 .52393 L .994 .807 .545 r
F
.66514 .52393 m .66307 .5351 L .66651 .51972 L 0 0 0 r
F
.6653 .52332 m .66651 .51972 L .66777 .5141 L F
.66514 .52393 m .66651 .51972 L .6653 .52332 L F
.66499 .50791 m .6681 .50913 L .66882 .51285 L .14 0 .259 r
F
.66651 .527 m .66808 .51622 L .6713 .5377 L 0 0 0 r
F
.67481 .56037 m .6713 .5377 L .67172 .53818 L .476 .352 .631 r
F
.67505 .55879 m .67172 .53818 L .6772 .54437 L F
.67481 .56037 m .67172 .53818 L .67505 .55879 L F
.6713 .5377 m .67483 .54771 L .6772 .54437 L 0 0 .411 r
F
.66806 .51549 m .67134 .52583 L .67483 .54771 L .809 .443 0 r
F
.66777 .5141 m .66791 .51457 L .66806 .51549 L F
.66791 .51457 m .67134 .52583 L .66806 .51549 L F
.6713 .5377 m .66777 .5141 L .67483 .54771 L 0 0 .411 r
F
.66453 .5286 m .66499 .50791 L .66777 .5141 L .927 .773 .296 r
F
.66777 .5141 m .66499 .50791 L .66891 .51897 L .809 .443 0 r
F
.66998 .52137 m .66891 .51897 L .67134 .52583 L F
.66777 .5141 m .66891 .51897 L .66998 .52137 L F
.66499 .50791 m .66882 .51285 L .66781 .51586 L .14 0 .259 r
F
.66357 .52804 m .66499 .50791 L .66453 .5286 L .927 .773 .296 r
F
.66062 .54953 m .65739 .53226 L .66307 .5351 L .525 .404 .656 r
F
.65739 .53226 m .66101 .54702 L .66307 .5351 L 0 0 .191 r
F
.66307 .5351 m .66251 .53834 L .66499 .50791 L .927 .773 .296 r
F
.66251 .53834 m .66101 .54702 L .66277 .52969 L F
.66251 .53834 m .66277 .52969 L .66499 .50791 L F
.66101 .54702 m .66288 .51821 L .66499 .50791 L .874 .67 .624 r
F
.66344 .51549 m .66288 .51821 L .66313 .51779 L .14 0 .259 r
F
.66344 .51549 m .66313 .51779 L .66574 .51323 L F
.66344 .51549 m .66574 .51323 L .66606 .51191 L F
.66499 .50791 m .66344 .51549 L .6681 .50913 L F
.66313 .51779 m .66435 .50879 L .66608 .51264 L 0 0 .121 r
F
.66288 .51821 m .66317 .51639 L .66313 .51779 L F
.66317 .51639 m .66435 .50879 L .66313 .51779 L F
.66435 .50879 m .66529 .50274 L .66608 .51264 L F
.65739 .53226 m .65709 .53098 L .66101 .54702 L 0 0 .191 r
F
.65709 .53098 m .65738 .53192 L .66101 .54702 L F
.65582 .52543 m .65674 .52909 L .66101 .54702 L F
.65709 .53098 m .65582 .52543 L .65738 .53192 L F
.65582 .52543 m .65432 .5189 L .65674 .52909 L F
.65432 .5189 m .65812 .53897 L .66101 .54702 L .931 .575 .152 r
F
.66101 .54702 m .65812 .53897 L .65914 .53455 L .874 .67 .624 r
F
.65812 .53897 m .65949 .53999 L .65865 .53666 L 0 .015 .542 r
F
.64433 .55994 m .64142 .5508 L .64609 .52651 L .873 .661 .612 r
F
.64142 .5508 m .6433 .52037 L .64609 .52651 L .761 .566 .633 r
F
.64609 .52651 m .6433 .52037 L .65002 .55241 L .952 .611 .219 r
F
.6433 .52037 m .64704 .54194 L .65002 .55241 L .782 .453 .431 r
F
.65002 .55241 m .64704 .54194 L .65154 .51324 L .877 .655 .599 r
F
.64799 .53587 m .64924 .52042 L .65154 .51324 L .699 .533 .658 r
F
.64704 .54194 m .64823 .53027 L .64799 .53587 L F
.64823 .53027 m .64924 .52042 L .64799 .53587 L F
.65154 .51324 m .65148 .51342 L .65465 .52268 L .629 .281 .362 r
F
.65148 .51342 m .64924 .52042 L .65465 .52268 L F
.65465 .52268 m .64924 .52042 L .65495 .52358 L F
.64924 .52042 m .65171 .50644 L .65495 .52358 L .799 .752 .234 r
F
.66134 .54193 m .65914 .53455 L .65995 .53101 L .874 .67 .624 r
F
.66191 .53311 m .65995 .53101 L .66288 .51821 L F
.66134 .54193 m .65995 .53101 L .66191 .53311 L F
.66101 .54702 m .65914 .53455 L .66134 .54193 L F
.65865 .53666 m .66127 .54132 L .66288 .51821 L 0 .015 .542 r
F
.65949 .53999 m .66127 .54132 L .65865 .53666 L F
.65812 .53897 m .65774 .53711 L .66127 .54132 L F
.65774 .53711 m .65879 .53436 L .66127 .54132 L F
.65774 .53711 m .65495 .52358 L .65879 .53436 L F
.65615 .52695 m .65866 .54066 L .66127 .54132 L 0 0 .201 r
F
.66127 .54132 m .65866 .54066 L .66044 .52803 L .976 .763 .551 r
F
.66205 .5273 m .66044 .52803 L .66304 .50952 L F
.66127 .54132 m .66044 .52803 L .66205 .5273 L F
.65999 .53121 m .66122 .52787 L .66304 .50952 L .638 .522 .706 r
F
.6591 .53759 m .66117 .52813 L .65999 .53121 L F
.66117 .52813 m .66122 .52787 L .65999 .53121 L F
.65554 .52629 m .65866 .54066 L .65615 .52695 L 0 0 .201 r
F
.65626 .52962 m .65643 .52965 L .65866 .54066 L F
.65495 .52358 m .65554 .52629 L .65615 .52695 L F
.65495 .52358 m .65171 .50644 L .65643 .52965 L F
.65495 .52358 m .65643 .52965 L .65626 .52962 L F
.65378 .51662 m .65566 .53011 L .65646 .52979 L .947 .589 .263 r
F
.65866 .54066 m .65566 .53011 L .65669 .5297 L .638 .522 .706 r
F
.65566 .53011 m .65662 .52977 L .65676 .52971 L .084 .064 .534 r
F
.65866 .54066 m .65921 .53795 L .6591 .53759 L .638 .522 .706 r
F
.65921 .53795 m .66122 .52787 L .6591 .53759 L F
.6569 .53087 m .65739 .52941 L .65995 .52838 L F
.65866 .54066 m .6569 .53087 L .65995 .52838 L F
.65866 .54066 m .65995 .52838 L .66073 .53033 L F
.65755 .52935 m .65868 .52905 L .66122 .52787 L .084 .064 .534 r
F
.66304 .50952 m .66556 .49652 L .66699 .4976 L 0 0 .083 r
F
.66529 .50274 m .66819 .49851 L .67145 .51523 L 0 0 0 r
F
.66288 .51821 m .66248 .52396 L .66529 .50274 L 0 0 .121 r
F
.66248 .52396 m .66402 .51501 L .66529 .50274 L F
.66248 .52396 m .66127 .54132 L .66402 .51501 L F
.663 .52473 m .66304 .50952 L .66529 .50274 L .976 .763 .551 r
F
.66606 .51191 m .66574 .51323 L .6681 .50913 L .14 0 .259 r
F
.66608 .51264 m .66529 .50274 L .6681 .50913 L 0 0 .121 r
F
.6681 .50913 m .66529 .50274 L .66758 .50738 L 0 0 .387 r
F
.66885 .5105 m .66758 .50738 L .67145 .51523 L F
.6681 .50913 m .66758 .50738 L .66885 .5105 L F
.66639 .50114 m .66606 .50305 L .66819 .49851 L 0 0 0 r
F
.66529 .50274 m .66606 .50305 L .66639 .50114 L F
.66529 .50274 m .66304 .50952 L .66606 .50305 L F
.66593 .50332 m .66699 .4976 L .66606 .50305 L 0 0 .083 r
F
.66304 .50952 m .66547 .50219 L .66593 .50332 L F
.66547 .50219 m .66699 .4976 L .66593 .50332 L F
.66606 .50305 m .66699 .4976 L .66819 .49851 L F
.66195 .52915 m .66304 .50952 L .663 .52473 L .976 .763 .551 r
F
.66304 .50952 m .66122 .52787 L .66479 .50209 L 0 0 .083 r
F
.66364 .50641 m .66479 .50209 L .66556 .49652 L F
.66304 .50952 m .66479 .50209 L .66364 .50641 L F
.66819 .49851 m .66556 .49652 L .67096 .49117 L .849 .849 .842 r
F
.66556 .49652 m .66826 .48726 L .67096 .49117 L 0 0 .033 r
F
.66122 .52787 m .66355 .50938 L .66556 .49652 L .994 .838 .579 r
F
.66355 .50938 m .66619 .49844 L .66714 .4933 L 0 0 0 r
F
.66631 .49639 m .66714 .4933 L .66826 .48726 L F
.66355 .50938 m .66714 .4933 L .66631 .49639 L F
.66122 .52787 m .66086 .52804 L .66355 .50938 L .994 .838 .579 r
F
.66086 .52804 m .65868 .52905 L .65959 .52536 L F
.66086 .52804 m .65959 .52536 L .66355 .50938 L F
.65868 .52905 m .66151 .52252 L .66306 .51253 L .633 .626 .825 r
F
.65868 .52905 m .66306 .51253 L .66196 .51581 L F
.6569 .53087 m .65669 .5297 L .65739 .52941 L .638 .522 .706 r
F
.65669 .5297 m .65676 .52971 L .65755 .52935 L .084 .064 .534 r
F
.65566 .53011 m .65676 .52971 L .65669 .5297 L F
.65662 .52977 m .65868 .52905 L .65755 .52935 L F
.65566 .53011 m .65204 .50344 L .65868 .52905 L F
.65588 .51826 m .65587 .52379 L .65868 .52905 L .775 .503 0 r
F
.65204 .50344 m .6539 .51332 L .65588 .51826 L F
.6539 .51332 m .65587 .52379 L .65588 .51826 L F
.65868 .52905 m .65587 .52379 L .66151 .52252 L .633 .626 .825 r
F
.65587 .52379 m .65914 .52823 L .66151 .52252 L 0 0 .486 r
F
.65587 .52379 m .6525 .50408 L .65914 .52823 L F
.65662 .51907 m .65618 .51977 L .65914 .52823 L 0 0 .223 r
F
.6525 .50408 m .65543 .51655 L .65662 .51907 L F
.65543 .51655 m .65618 .51977 L .65662 .51907 L F
.66196 .51581 m .66306 .51253 L .66355 .50938 L .633 .626 .825 r
F
.66073 .53033 m .65995 .52838 L .66122 .52787 L .638 .522 .706 r
F
.65171 .50644 m .65294 .51381 L .65378 .51662 L .947 .589 .263 r
F
.65294 .51381 m .65566 .53011 L .65378 .51662 L F
.64142 .5508 m .63828 .53502 L .6433 .52037 L .761 .566 .633 r
F
.6433 .52037 m .641 .52859 L .64704 .54194 L .782 .453 .431 r
F
.64704 .54194 m .64393 .52765 L .64691 .52359 L .699 .533 .658 r
F
.63828 .53502 m .641 .52859 L .6433 .52037 L .314 .261 .638 r
F
.641 .52859 m .64393 .52765 L .64584 .53643 L .001 0 .26 r
F
.64574 .53908 m .64584 .53643 L .64704 .54194 L F
.641 .52859 m .64584 .53643 L .64574 .53908 L F
.64704 .54194 m .64691 .52359 L .64762 .52526 L .699 .533 .658 r
F
.64762 .52526 m .64691 .52359 L .64771 .5225 L F
.64881 .5246 m .64771 .5225 L .64924 .52042 L F
.64704 .54194 m .64771 .5225 L .64881 .5246 L F
.64393 .52765 m .64699 .52984 L .64924 .52042 L 0 .001 .513 r
F
.64393 .52765 m .64058 .50624 L .64605 .52636 L F
.64591 .52907 m .64605 .52636 L .64699 .52984 L F
.64393 .52765 m .64605 .52636 L .64591 .52907 L F
.64605 .52636 m .6444 .53037 L .64699 .52984 L .947 .591 .28 r
F
.64207 .51171 m .6444 .53037 L .64605 .52636 L F
.6444 .53037 m .64673 .51141 L .64657 .5158 L .776 .613 .678 r
F
.64643 .51864 m .64657 .5158 L .64648 .51835 L F
.6444 .53037 m .64657 .5158 L .64643 .51864 L F
.6444 .53037 m .64672 .51143 L .64673 .51141 L F
.64648 .51835 m .64673 .51141 L .64903 .50361 L F
.63294 .54979 m .63624 .56181 L .63858 .55365 L .563 .263 .417 r
F
.63858 .55365 m .64142 .5508 L .64433 .55994 L 0 0 .05 r
F
.63858 .55365 m .63624 .56181 L .64142 .5508 L F
.63624 .56181 m .63828 .53502 L .64142 .5508 L .877 .679 .631 r
F
.641 .52859 m .63889 .54305 L .64393 .52765 L .001 0 .26 r
F
.63828 .53502 m .63513 .51845 L .641 .52859 L .314 .261 .638 r
F
.63294 .54979 m .63068 .56109 L .63624 .56181 L .563 .263 .417 r
F
.63339 .55464 m .63513 .51845 L .63828 .53502 L .721 .523 .622 r
F
.63624 .56181 m .63339 .55464 L .63828 .53502 L .877 .679 .631 r
F
.63513 .51845 m .63889 .54305 L .641 .52859 L .952 .6 .272 r
F
.63889 .54305 m .64058 .50624 L .64393 .52765 L .972 .75 .544 r
F
.62776 .55979 m .63068 .56109 L .63294 .54979 L .129 0 .259 r
F
.63339 .55464 m .63007 .5327 L .63513 .51845 L .721 .523 .622 r
F
.63007 .5327 m .63241 .51508 L .63513 .51845 L .564 .424 .649 r
F
.63513 .51845 m .63241 .51508 L .63889 .54305 L .952 .6 .272 r
F
.63241 .51508 m .63623 .54226 L .63889 .54305 L .791 .475 .454 r
F
.63889 .54305 m .63623 .54226 L .64011 .51012 L .972 .75 .544 r
F
.64037 .51083 m .64011 .51012 L .64058 .50624 L F
.63889 .54305 m .64011 .51012 L .64037 .51083 L F
.63623 .54226 m .63789 .50374 L .64058 .50624 L .901 .679 .592 r
F
.63806 .50443 m .64145 .52103 L .6444 .53037 L .801 .445 .383 r
F
.63789 .50374 m .638 .50426 L .63806 .50443 L F
.638 .50426 m .64145 .52103 L .63806 .50443 L F
.64118 .51001 m .63789 .50374 L .6444 .53037 L .947 .591 .28 r
F
.64058 .50624 m .63894 .50472 L .64118 .51001 L F
.63894 .50472 m .63789 .50374 L .64118 .51001 L F
.64058 .50624 m .64118 .51001 L .64207 .51171 L F
.64118 .51001 m .6444 .53037 L .64207 .51171 L F
.64924 .52042 m .64863 .52298 L .65171 .50644 L .799 .752 .234 r
F
.64863 .52298 m .64699 .52984 L .64947 .51755 L F
.64863 .52298 m .64947 .51755 L .65171 .50644 L F
.64699 .52984 m .64903 .50361 L .65171 .50644 L .986 .789 .557 r
F
.65171 .50644 m .64903 .50361 L .65321 .52034 L .947 .589 .263 r
F
.65456 .5235 m .65321 .52034 L .65566 .53011 L F
.65171 .50644 m .65321 .52034 L .65456 .5235 L F
.64933 .50481 m .65164 .50364 L .65064 .51005 L .031 0 .142 r
F
.65164 .50364 m .65204 .50344 L .65064 .51005 L F
.64903 .50361 m .64938 .50359 L .64933 .50481 L F
.64938 .50359 m .65204 .50344 L .64933 .50481 L F
.64699 .52984 m .6444 .53037 L .64903 .50361 L .986 .789 .557 r
F
.64903 .50361 m .64672 .51143 L .65134 .50449 L .031 0 .142 r
F
.6509 .5035 m .65134 .50449 L .65204 .50344 L F
.64903 .50361 m .65134 .50449 L .6509 .5035 L F
.64892 .48951 m .6525 .50408 L .65336 .50912 L .909 .505 .198 r
F
.65064 .51005 m .65204 .50344 L .65566 .53011 L .031 0 .142 r
F
.64837 .50895 m .64892 .48951 L .65204 .50344 L .892 .77 .274 r
F
.65204 .50344 m .64892 .48951 L .65476 .51828 L .775 .503 0 r
F
.65533 .52093 m .65476 .51828 L .65587 .52379 L F
.65204 .50344 m .65476 .51828 L .65533 .52093 L F
.64892 .48951 m .65336 .50912 L .65249 .50713 L .909 .505 .198 r
F
.64724 .50628 m .64892 .48951 L .64837 .50895 L .892 .77 .274 r
F
.6444 .53037 m .64145 .52103 L .64471 .51509 L .776 .613 .678 r
F
.64611 .51645 m .64471 .51509 L .64672 .51143 L F
.6444 .53037 m .64471 .51509 L .64611 .51645 L F
.63007 .5327 m .62688 .51424 L .63241 .51508 L .564 .424 .649 r
F
.63241 .51508 m .63012 .52534 L .63623 .54226 L .791 .475 .454 r
F
.63623 .54226 m .63332 .53405 L .63789 .50374 L .901 .679 .592 r
F
.63332 .53405 m .63546 .50916 L .63789 .50374 L .664 .492 .642 r
F
.63789 .50374 m .63546 .50916 L .6408 .51975 L .801 .445 .383 r
F
.6412 .51982 m .6408 .51975 L .64145 .52103 L F
.63789 .50374 m .6408 .51975 L .6412 .51982 L F
.62688 .51424 m .63012 .52534 L .63241 .51508 L .854 .464 0 r
F
.63332 .53405 m .63009 .51542 L .63546 .50916 L .664 .492 .642 r
F
.63546 .50916 m .63835 .50721 L .64145 .52103 L 0 0 .245 r
F
.63546 .50916 m .63333 .52485 L .63835 .50721 L F
.63009 .51542 m .63333 .52485 L .63546 .50916 L 0 0 .288 r
F
.63507 .51875 m .63536 .49659 L .63835 .50721 L .987 .785 .547 r
F
.63333 .52485 m .63379 .51852 L .63507 .51875 L F
.63379 .51852 m .63536 .49659 L .63507 .51875 L F
.64145 .52103 m .64452 .52283 L .64672 .51143 L 0 .027 .555 r
F
.64145 .52103 m .63835 .50721 L .64295 .51886 L F
.64278 .52181 m .64295 .51886 L .64452 .52283 L F
.64145 .52103 m .64295 .51886 L .64278 .52181 L F
.64325 .51363 m .64419 .50303 L .64628 .48826 L .878 .698 .654 r
F
.63945 .50998 m .64194 .52461 L .64452 .52283 L .816 .511 0 r
F
.64194 .52461 m .64346 .5101 L .64325 .51363 L .878 .698 .654 r
F
.64346 .5101 m .64419 .50303 L .64325 .51363 L F
.63835 .50721 m .63879 .50935 L .63945 .50998 L .816 .511 0 r
F
.63879 .50935 m .64194 .52461 L .63945 .50998 L F
.64672 .51143 m .64452 .52283 L .64755 .4999 L .892 .77 .274 r
F
.64732 .50543 m .64755 .4999 L .64892 .48951 L F
.64672 .51143 m .64755 .4999 L .64732 .50543 L F
.64452 .52283 m .64628 .48826 L .64892 .48951 L .991 .775 .516 r
F
.64802 .48908 m .64628 .48826 L .64785 .49227 L .909 .505 .198 r
F
.64802 .48908 m .64785 .49227 L .65072 .49955 L F
.64802 .48908 m .65072 .49955 L .65137 .50029 L F
.64892 .48951 m .64802 .48908 L .6525 .50408 L F
.64785 .49227 m .64809 .48774 L .6506 .49926 L .001 0 .259 r
F
.64628 .48826 m .64804 .48776 L .64785 .49227 L F
.64804 .48776 m .64809 .48774 L .64785 .49227 L F
.64809 .48774 m .64926 .48741 L .6506 .49926 L F
.64452 .52283 m .64194 .52461 L .64628 .48826 L .991 .775 .516 r
F
.64628 .48826 m .64598 .49039 L .64926 .48741 L .001 0 .259 r
F
.64598 .49039 m .64419 .50303 L .64799 .49133 L F
.64598 .49039 m .64799 .49133 L .64926 .48741 L F
.64637 .47971 m .64954 .48333 L .6514 .49293 L .376 0 .185 r
F
.64926 .48741 m .6528 .50022 L .65618 .51977 L .794 .453 0 r
F
.64678 .49506 m .64637 .47971 L .64926 .48741 L .895 .768 .273 r
F
.65137 .50029 m .65072 .49955 L .6525 .50408 L .909 .505 .198 r
F
.6506 .49926 m .64926 .48741 L .6525 .50408 L .001 0 .259 r
F
.6525 .50408 m .64926 .48741 L .65466 .51264 L 0 0 .223 r
F
.65538 .51635 m .65466 .51264 L .65618 .51977 L F
.6525 .50408 m .65466 .51264 L .65538 .51635 L F
.64926 .48741 m .64637 .47971 L .65029 .49113 L .794 .453 0 r
F
.65029 .49113 m .64637 .47971 L .6512 .4951 L F
.64637 .47971 m .65022 .48984 L .65037 .49245 L .376 0 .185 r
F
.64511 .49315 m .64637 .47971 L .64678 .49506 L .895 .768 .273 r
F
.63835 .50721 m .63536 .49659 L .63923 .51304 L .816 .511 0 r
F
.63887 .50975 m .63923 .51304 L .64194 .52461 L F
.63835 .50721 m .63923 .51304 L .63887 .50975 L F
.63536 .49659 m .63909 .51863 L .64194 .52461 L .942 .578 .265 r
F
.64194 .52461 m .63909 .51863 L .64396 .50375 L .878 .698 .654 r
F
.64413 .50366 m .64396 .50375 L .64419 .50303 L F
.64194 .52461 m .64396 .50375 L .64413 .50366 L F
.63964 .51693 m .64198 .51501 L .64419 .50303 L .192 .175 .609 r
F
.63909 .51863 m .63974 .51782 L .63964 .51693 L F
.63974 .51782 m .64198 .51501 L .63964 .51693 L F
.63009 .51542 m .6271 .50444 L .63195 .52035 L 0 0 .288 r
F
.63227 .52177 m .63195 .52035 L .63333 .52485 L F
.63009 .51542 m .63195 .52035 L .63227 .52177 L F
.63 .51154 m .63016 .49966 L .63265 .4943 L .649 .478 .639 r
F
.62485 .5424 m .62688 .51424 L .63007 .5327 L .691 .509 .636 r
F
.62485 .5424 m .62165 .52325 L .62688 .51424 L F
.62165 .52325 m .6241 .5092 L .62688 .51424 L .685 .555 .702 r
F
.62688 .51424 m .6241 .5092 L .63012 .52534 L .854 .464 0 r
F
.6241 .5092 m .62776 .53452 L .63012 .52534 L .798 .476 .444 r
F
.62165 .52325 m .61872 .51336 L .6241 .5092 L .685 .555 .702 r
F
.6241 .5092 m .62172 .51822 L .62776 .53452 L .798 .476 .444 r
F
.62172 .51822 m .62526 .54007 L .62776 .53452 L .662 .369 .465 r
F
.62526 .54007 m .6271 .50444 L .63009 .51542 L .882 .666 .605 r
F
.62798 .55867 m .63007 .5327 L .63339 .55464 L .714 .534 .644 r
F
.62798 .55867 m .62485 .5424 L .63007 .5327 L F
.63012 .52534 m .63332 .53405 L .63623 .54226 L .518 .198 .365 r
F
.63012 .52534 m .62776 .53452 L .63332 .53405 L F
.62776 .53452 m .63009 .51542 L .63332 .53405 L .984 .844 .46 r
F
.62776 .53452 m .62526 .54007 L .63009 .51542 L F
.6271 .50444 m .6307 .52573 L .63333 .52485 L .945 .586 .221 r
F
.6193 .54101 m .62165 .52325 L .62485 .5424 L .531 .394 .639 r
F
.6193 .54101 m .61608 .52038 L .62165 .52325 L F
.61608 .52038 m .61872 .51336 L .62165 .52325 L .565 .528 .773 r
F
.62172 .51822 m .61948 .53304 L .62526 .54007 L .662 .369 .465 r
F
.62526 .54007 m .62232 .53095 L .6271 .50444 L .882 .666 .605 r
F
.61872 .51336 m .62172 .51822 L .6241 .5092 L .625 .142 .087 r
F
.62232 .53095 m .62432 .50028 L .6271 .50444 L .775 .578 .632 r
F
.6271 .50444 m .62432 .50028 L .62994 .52271 L .945 .586 .221 r
F
.63018 .52268 m .62994 .52271 L .6307 .52573 L F
.6271 .50444 m .62994 .52271 L .63018 .52268 L F
.62432 .50028 m .62799 .52463 L .6307 .52573 L .783 .459 .44 r
F
.62824 .52296 m .62937 .50872 L .63 .51154 L .649 .478 .639 r
F
.62799 .52463 m .62813 .52297 L .62824 .52296 L F
.62813 .52297 m .62937 .50872 L .62824 .52296 L F
.62937 .50872 m .63016 .49966 L .63 .51154 L F
.63333 .52485 m .6307 .52573 L .63409 .50455 L .987 .785 .547 r
F
.63453 .50819 m .63409 .50455 L .63536 .49659 L F
.63333 .52485 m .63409 .50455 L .63453 .50819 L F
.6307 .52573 m .63265 .4943 L .63536 .49659 L .97 .759 .562 r
F
.63536 .49659 m .63265 .4943 L .63767 .51329 L .942 .578 .265 r
F
.63852 .51526 m .63767 .51329 L .63909 .51863 L F
.63536 .49659 m .63767 .51329 L .63852 .51526 L F
.63301 .49569 m .63585 .50159 L .63909 .51863 L .588 .201 .278 r
F
.63265 .4943 m .63292 .49493 L .63301 .49569 L F
.63292 .49493 m .63585 .50159 L .63301 .49569 L F
.6307 .52573 m .62799 .52463 L .63265 .4943 L .97 .759 .562 r
F
.63265 .4943 m .63016 .49966 L .63585 .50159 L .588 .201 .278 r
F
.63211 .50032 m .6328 .48948 L .63585 .50159 L .801 .804 .314 r
F
.63016 .49966 m .63079 .49723 L .63211 .50032 L F
.63079 .49723 m .6328 .48948 L .63211 .50032 L F
.63909 .51863 m .63585 .50159 L .64198 .51501 L .192 .175 .609 r
F
.63818 .50668 m .63968 .52577 L .64198 .51501 L .875 .573 .056 r
F
.63585 .50159 m .63677 .5074 L .63818 .50668 L F
.63677 .5074 m .63968 .52577 L .63818 .50668 L F
.64419 .50303 m .64356 .50644 L .64637 .47971 L .895 .768 .273 r
F
.64356 .50644 m .64198 .51501 L .64416 .49744 L F
.64356 .50644 m .64416 .49744 L .64637 .47971 L F
.64394 .48519 m .64525 .47846 L .6454 .47888 L .761 .731 .205 r
F
.64198 .51501 m .64394 .48519 L .64637 .47971 L .962 .79 .351 r
F
.64516 .48244 m .64394 .48519 L .645 .48484 L .376 0 .185 r
F
.64516 .48244 m .645 .48484 L .64954 .48333 L F
.64637 .47971 m .64516 .48244 L .64954 .48333 L F
.645 .48484 m .6454 .47888 L .64726 .48409 L .761 .731 .205 r
F
.64394 .48519 m .6454 .47888 L .645 .48484 L F
.64726 .48409 m .6465 .47202 L .64954 .48333 L F
.64525 .47846 m .6465 .47202 L .64726 .48409 L F
.65204 .49746 m .6512 .4951 L .6528 .50022 L .794 .453 0 r
F
.65029 .49113 m .6512 .4951 L .65204 .49746 L F
.65022 .48984 m .6514 .49293 L .65076 .49264 L .376 0 .185 r
F
.65022 .48984 m .65076 .49264 L .65037 .49245 L F
.65037 .49245 m .6514 .49293 L .6528 .50022 L F
.64419 .50303 m .64511 .49315 L .64678 .49506 L .895 .768 .273 r
F
.65249 .50713 m .65336 .50912 L .65587 .52379 L .909 .505 .198 r
F
.64672 .51143 m .64724 .50628 L .64837 .50895 L .892 .77 .274 r
F
.66127 .54132 m .66195 .52915 L .663 .52473 L .976 .763 .551 r
F
.66781 .51586 m .66882 .51285 L .67134 .52583 L .14 0 .259 r
F
.66307 .5351 m .66357 .52804 L .66453 .5286 L .927 .773 .296 r
F
.66404 .544 m .6631 .54797 L .66479 .53884 L .838 .768 .259 r
F
.4068 .50591 m .40892 .50117 L .41202 .50425 L .664 .741 .908 r
F
.4068 .50591 m .4037 .50284 L .40892 .50117 L F
.3308 .50579 m .33272 .50104 L .33595 .50412 L F
.3308 .50579 m .32756 .50271 L .33272 .50104 L F
.49634 .50579 m .49871 .50104 L .50165 .50412 L .664 .742 .908 r
F
.49634 .50579 m .49339 .50272 L .49871 .50104 L F
.42034 .50565 m .4225 .50091 L .42557 .50399 L .663 .741 .908 r
F
.42034 .50565 m .41726 .50258 L .4225 .50091 L F
.34433 .50553 m .34628 .50079 L .34949 .50387 L F
.34433 .50553 m .34111 .50245 L .34628 .50079 L F
.50989 .50553 m .5123 .50081 L .51521 .50387 L .662 .741 .908 r
F
.50989 .50553 m .50697 .50245 L .5123 .50081 L F
.43388 .5054 m .43608 .50066 L .43913 .50374 L .663 .741 .908 r
F
.43388 .5054 m .43082 .50233 L .43608 .50066 L F
.35786 .50528 m .35985 .50053 L .36304 .50361 L F
.35786 .50528 m .35467 .5022 L .35985 .50053 L F
.52344 .50528 m .52589 .50133 L .52878 .50429 L .602 .722 .929 r
F
.52344 .50528 m .52055 .50222 L .52589 .50133 L F
.44742 .50515 m .44966 .5004 L .45269 .50348 L .664 .741 .907 r
F
.44742 .50515 m .44439 .50207 L .44966 .5004 L F
.37139 .50502 m .37342 .50027 L .37659 .50335 L .664 .741 .908 r
F
.37139 .50502 m .36822 .50194 L .37342 .50027 L F
.46097 .50488 m .46325 .50014 L .46625 .50322 L .663 .741 .908 r
F
.46097 .50488 m .45796 .50181 L .46325 .50014 L F
.38493 .50475 m .387 .50002 L .39014 .50309 L .664 .742 .908 r
F
.38493 .50475 m .38179 .50169 L .387 .50002 L F
.47453 .50464 m .47684 .4999 L .47982 .50298 L .663 .741 .908 r
F
.47453 .50464 m .47154 .50156 L .47684 .4999 L F
.39848 .50451 m .40058 .49977 L .4037 .50284 L F
.39848 .50451 m .39535 .50143 L .40058 .49977 L F
.32242 .50437 m .32431 .49963 L .32756 .50271 L .664 .742 .908 r
F
.32242 .50437 m .31916 .5013 L .32431 .49963 L F
.48808 .50439 m .49043 .49963 L .49339 .50272 L .664 .741 .907 r
F
.48808 .50439 m .48512 .50131 L .49043 .49963 L F
.41202 .50425 m .41416 .4995 L .41726 .50258 L .664 .741 .908 r
F
.41202 .50425 m .40892 .50117 L .41416 .4995 L F
.50165 .50412 m .50403 .49938 L .50697 .50245 L .663 .741 .908 r
F
.50165 .50412 m .49871 .50104 L .50403 .49938 L F
.33595 .50412 m .33788 .49937 L .34111 .50245 L .664 .741 .908 r
F
.33595 .50412 m .33272 .50104 L .33788 .49937 L F
.42557 .50399 m .42775 .49925 L .43082 .50233 L .663 .741 .908 r
F
.42557 .50399 m .4225 .50091 L .42775 .49925 L F
.34949 .50387 m .35146 .49911 L .35467 .5022 L .664 .742 .908 r
F
.34949 .50387 m .34628 .50079 L .35146 .49911 L F
.51521 .50387 m .51764 .49912 L .52055 .50222 L .665 .743 .908 r
F
.51521 .50387 m .5123 .50081 L .51764 .49912 L F
.43913 .50374 m .44135 .49899 L .44439 .50207 L .664 .742 .908 r
F
.43913 .50374 m .43608 .50066 L .44135 .49899 L F
.36304 .50361 m .36504 .49886 L .36822 .50194 L .664 .741 .908 r
F
.36304 .50361 m .35985 .50053 L .36504 .49886 L F
.45269 .50348 m .45494 .49872 L .45796 .50181 L F
.45269 .50348 m .44966 .5004 L .45494 .49872 L F
.37659 .50335 m .37863 .4986 L .38179 .50169 L .663 .741 .908 r
F
.37659 .50335 m .37342 .50027 L .37863 .4986 L F
.52878 .50429 m .53132 .53819 L .53422 .53404 L .956 .635 .373 r
F
.52878 .50429 m .52589 .50133 L .53132 .53819 L F
.46625 .50322 m .46854 .49848 L .47154 .50156 L .663 .741 .908 r
F
.46625 .50322 m .46325 .50014 L .46854 .49848 L F
.39014 .50309 m .39222 .49834 L .39535 .50143 L .664 .741 .908 r
F
.39014 .50309 m .387 .50002 L .39222 .49834 L F
.31401 .50297 m .31588 .49822 L .31916 .5013 L .663 .741 .908 r
F
.31401 .50297 m .31074 .49989 L .31588 .49822 L F
.47982 .50298 m .48215 .49822 L .48512 .50131 L .664 .741 .907 r
F
.47982 .50298 m .47684 .4999 L .48215 .49822 L F
.4037 .50284 m .40581 .49809 L .40892 .50117 L .664 .742 .908 r
F
.4037 .50284 m .40058 .49977 L .40581 .49809 L F
.32756 .50271 m .32947 .49795 L .33272 .50104 L .664 .741 .908 r
F
.32756 .50271 m .32431 .49963 L .32947 .49795 L F
.49339 .50272 m .49576 .49795 L .49871 .50104 L .664 .741 .907 r
F
.49339 .50272 m .49043 .49963 L .49576 .49795 L F
.41726 .50258 m .41941 .49782 L .4225 .50091 L .664 .741 .908 r
F
.41726 .50258 m .41416 .4995 L .41941 .49782 L F
.34111 .50245 m .34306 .4977 L .34628 .50079 L .663 .741 .908 r
F
.34111 .50245 m .33788 .49937 L .34306 .4977 L F
.50697 .50245 m .50937 .49772 L .5123 .50081 L .663 .742 .909 r
F
.50697 .50245 m .50403 .49938 L .50937 .49772 L F
.43082 .50233 m .43302 .49759 L .43608 .50066 L .663 .741 .908 r
F
.43082 .50233 m .42775 .49925 L .43302 .49759 L F
.35467 .5022 m .35665 .49744 L .35985 .50053 L .664 .741 .908 r
F
.35467 .5022 m .35146 .49911 L .35665 .49744 L F
.51764 .49912 m .52008 .49573 L .52299 .49859 L .542 .697 .941 r
F
.52299 .49859 m .52008 .49573 L .52009 .49585 L .957 .65 .407 r
F
.52055 .50222 m .52299 .49859 L .52588 .50133 L .567 .706 .935 r
F
.52055 .50222 m .51764 .49912 L .52299 .49859 L F
.52299 .49859 m .52009 .49585 L .52546 .54622 L .957 .65 .407 r
F
.52588 .50133 m .52299 .49859 L .52589 .50133 L .567 .706 .935 r
F
.44439 .50207 m .44662 .49731 L .44966 .5004 L .664 .742 .908 r
F
.44439 .50207 m .44135 .49899 L .44662 .49731 L F
.62521 .57043 m .62292 .58259 L .62776 .55979 L 0 0 0 r
F
.62292 .58259 m .62545 .57063 L .62776 .55979 L .785 .674 .741 r
F
.62776 .55979 m .62545 .57063 L .63068 .56109 L .129 0 .259 r
F
.62545 .57063 m .62798 .55867 L .62845 .55909 L .655 .544 .717 r
F
.62594 .56973 m .62845 .55909 L .63068 .56109 L F
.62545 .57063 m .62845 .55909 L .62594 .56973 L F
.5898 .56785 m .58744 .58772 L .59288 .58561 L .523 .266 .467 r
F
.61608 .52038 m .61323 .51313 L .61872 .51336 L .565 .528 .773 r
F
.36822 .50194 m .37025 .49718 L .37342 .50027 L .664 .741 .908 r
F
.36822 .50194 m .36504 .49886 L .37025 .49718 L F
.45796 .50181 m .46023 .49705 L .46325 .50014 L .663 .741 .908 r
F
.45796 .50181 m .45494 .49872 L .46023 .49705 L F
.38179 .50169 m .38385 .49693 L .387 .50002 L F
.38179 .50169 m .37863 .4986 L .38385 .49693 L F
.47154 .50156 m .47385 .4968 L .47684 .4999 L F
.47154 .50156 m .46854 .49848 L .47385 .4968 L F
.39535 .50143 m .39745 .49667 L .40058 .49977 L F
.39535 .50143 m .39222 .49834 L .39745 .49667 L F
.31916 .5013 m .32104 .49654 L .32431 .49963 L .664 .741 .908 r
F
.31916 .5013 m .31588 .49822 L .32104 .49654 L F
.48512 .50131 m .48747 .49654 L .49043 .49963 L .663 .741 .907 r
F
.48512 .50131 m .48215 .49822 L .48747 .49654 L F
.70835 .50747 m .71423 .55465 L .71614 .5456 L .871 .558 .455 r
F
.70835 .50747 m .70652 .51809 L .71423 .55465 L F
.70357 .52296 m .70652 .51809 L .70835 .50747 L .355 .335 .698 r
F
.40892 .50117 m .41106 .49641 L .41416 .4995 L .664 .742 .908 r
F
.40892 .50117 m .40581 .49809 L .41106 .49641 L F
.49871 .50104 m .50109 .49629 L .50403 .49938 L .663 .741 .908 r
F
.49871 .50104 m .49576 .49795 L .50109 .49629 L F
.33272 .50104 m .33464 .49628 L .33788 .49937 L .664 .741 .908 r
F
.33272 .50104 m .32947 .49795 L .33464 .49628 L F
.61323 .51313 m .61612 .51537 L .61872 .51336 L .262 0 .147 r
F
.61323 .51313 m .61071 .51875 L .61612 .51537 L F
.68699 .52764 m .68955 .51591 L .69305 .53703 L .58 .473 .696 r
F
.4225 .50091 m .42467 .49615 L .42775 .49925 L .663 .741 .908 r
F
.4225 .50091 m .41941 .49782 L .42467 .49615 L F
.34628 .50079 m .34824 .49603 L .35146 .49911 L F
.34628 .50079 m .34306 .4977 L .34824 .49603 L F
.5123 .50081 m .51472 .49602 L .51764 .49912 L .665 .741 .907 r
F
.5123 .50081 m .50937 .49772 L .51472 .49602 L F
.43608 .50066 m .43829 .4959 L .44135 .49899 L .664 .742 .908 r
F
.43608 .50066 m .43302 .49759 L .43829 .4959 L F
.35985 .50053 m .36185 .49577 L .36504 .49886 L .663 .741 .908 r
F
.35985 .50053 m .35665 .49744 L .36185 .49577 L F
.44966 .5004 m .45191 .49563 L .45494 .49872 L .664 .742 .908 r
F
.44966 .5004 m .44662 .49731 L .45191 .49563 L F
.37342 .50027 m .37546 .4955 L .37863 .4986 L .664 .741 .908 r
F
.37342 .50027 m .37025 .49718 L .37546 .4955 L F
.46325 .50014 m .46554 .49538 L .46854 .49848 L .663 .741 .908 r
F
.46325 .50014 m .46023 .49705 L .46554 .49538 L F
.52589 .50133 m .5284 .54174 L .53132 .53819 L .956 .643 .394 r
F
.52589 .50133 m .52299 .49859 L .5284 .54174 L F
.387 .50002 m .38907 .49525 L .39222 .49834 L .664 .742 .908 r
F
.387 .50002 m .38385 .49693 L .38907 .49525 L F
.31074 .49989 m .3126 .49512 L .31588 .49822 L F
.31074 .49989 m .30745 .4968 L .3126 .49512 L F
.47684 .4999 m .47917 .49513 L .48215 .49822 L .663 .741 .908 r
F
.47684 .4999 m .47385 .4968 L .47917 .49513 L F
.69305 .53703 m .68955 .51591 L .69521 .51711 L .562 .416 .64 r
F
.68955 .51591 m .69249 .51167 L .69521 .51711 L .424 .449 .782 r
F
.68955 .51591 m .68674 .5088 L .69249 .51167 L F
.40058 .49977 m .40269 .49499 L .40581 .49809 L .663 .741 .908 r
F
.40058 .49977 m .39745 .49667 L .40269 .49499 L F
.32431 .49963 m .32621 .49486 L .32947 .49795 L .664 .741 .908 r
F
.32431 .49963 m .32104 .49654 L .32621 .49486 L F
.49043 .49963 m .4928 .49485 L .49576 .49795 L .664 .742 .908 r
F
.49043 .49963 m .48747 .49654 L .4928 .49485 L F
.41416 .4995 m .41632 .49473 L .41941 .49782 L .663 .741 .908 r
F
.41416 .4995 m .41106 .49641 L .41632 .49473 L F
.59444 .5261 m .59146 .51291 L .59786 .55677 L .932 .632 .165 r
F
.33788 .49937 m .33982 .4946 L .34306 .4977 L .663 .741 .908 r
F
.33788 .49937 m .33464 .49628 L .33982 .4946 L F
.50403 .49938 m .50644 .4946 L .50937 .49772 L .664 .741 .908 r
F
.50403 .49938 m .50109 .49629 L .50644 .4946 L F
.42775 .49925 m .42994 .49448 L .43302 .49759 L .663 .741 .908 r
F
.42775 .49925 m .42467 .49615 L .42994 .49448 L F
.60797 .52157 m .60576 .54127 L .61071 .51875 L 0 0 .258 r
F
.35146 .49911 m .35344 .49434 L .35665 .49744 L .664 .742 .908 r
F
.35146 .49911 m .34824 .49603 L .35344 .49434 L F
.51764 .49912 m .51472 .49602 L .52008 .49573 L .542 .697 .941 r
F
.44135 .49899 m .44357 .49421 L .44662 .49731 L .664 .742 .908 r
F
.44135 .49899 m .43829 .4959 L .44357 .49421 L F
.5685 .59336 m .57219 .67117 L .57534 .69214 L .907 .617 .482 r
F
.5685 .59336 m .56582 .60316 L .57219 .67117 L F
.36504 .49886 m .36706 .49408 L .37025 .49718 L .664 .741 .908 r
F
.36504 .49886 m .36185 .49577 L .36706 .49408 L F
.68674 .5088 m .69038 .51862 L .69249 .51167 L .534 .226 .391 r
F
.68674 .5088 m .68476 .51885 L .69038 .51862 L F
.68182 .52295 m .68476 .51885 L .68674 .5088 L 0 0 .228 r
F
.62011 .57701 m .61669 .54962 L .62253 .56128 L .411 .293 .608 r
F
.61669 .54962 m .6193 .54101 L .62253 .56128 L .279 .203 .589 r
F
.45494 .49872 m .45721 .49395 L .46023 .49705 L .663 .741 .908 r
F
.45494 .49872 m .45191 .49563 L .45721 .49395 L F
.37863 .4986 m .38068 .49383 L .38385 .49693 L F
.37863 .4986 m .37546 .4955 L .38068 .49383 L F
.46854 .49848 m .47085 .49371 L .47385 .4968 L F
.46854 .49848 m .46554 .49538 L .47085 .49371 L F
.61872 .51336 m .61612 .51537 L .62172 .51822 L .625 .142 .087 r
F
.39222 .49834 m .39431 .49356 L .39745 .49667 L .664 .742 .908 r
F
.39222 .49834 m .38907 .49525 L .39431 .49356 L F
.57595 .56381 m .5728 .53982 L .57789 .51581 L .766 .552 .607 r
F
.5728 .53982 m .5753 .52763 L .57789 .51581 L .393 .293 .621 r
F
.57789 .51581 m .5753 .52763 L .58133 .56125 L .85 .549 .478 r
F
.31588 .49822 m .31777 .49344 L .32104 .49654 L .663 .741 .908 r
F
.31588 .49822 m .3126 .49512 L .31777 .49344 L F
.48215 .49822 m .48449 .49344 L .48747 .49654 L .664 .742 .908 r
F
.48215 .49822 m .47917 .49513 L .48449 .49344 L F
.40581 .49809 m .40795 .4933 L .41106 .49641 L F
.40581 .49809 m .40269 .49499 L .40795 .4933 L F
.49576 .49795 m .49814 .49318 L .50109 .49629 L .663 .741 .908 r
F
.49576 .49795 m .4928 .49485 L .49814 .49318 L F
.32947 .49795 m .33139 .49317 L .33464 .49628 L .664 .741 .908 r
F
.32947 .49795 m .32621 .49486 L .33139 .49317 L F
.41941 .49782 m .42158 .49304 L .42467 .49615 L .664 .742 .908 r
F
.41941 .49782 m .41632 .49473 L .42158 .49304 L F
.34306 .4977 m .34501 .49292 L .34824 .49603 L .663 .741 .908 r
F
.34306 .4977 m .33982 .4946 L .34501 .49292 L F
.50937 .49772 m .51179 .49292 L .51472 .49602 L .664 .741 .907 r
F
.50937 .49772 m .50644 .4946 L .51179 .49292 L F
.43302 .49759 m .43522 .49279 L .43829 .4959 L F
.43302 .49759 m .42994 .49448 L .43522 .49279 L F
.35665 .49744 m .35864 .49266 L .36185 .49577 L .663 .741 .908 r
F
.35665 .49744 m .35344 .49434 L .35864 .49266 L F
.44662 .49731 m .44887 .49252 L .45191 .49563 L .664 .742 .908 r
F
.44662 .49731 m .44357 .49421 L .44887 .49252 L F
.37025 .49718 m .37228 .49239 L .37546 .4955 L .664 .741 .908 r
F
.37025 .49718 m .36706 .49408 L .37228 .49239 L F
.46023 .49705 m .46252 .49228 L .46554 .49538 L .663 .741 .908 r
F
.46023 .49705 m .45721 .49395 L .46252 .49228 L F
.38385 .49693 m .38592 .49215 L .38907 .49525 L F
.38385 .49693 m .38068 .49383 L .38592 .49215 L F
.70357 .52296 m .70055 .51178 L .70652 .51809 L .355 .335 .698 r
F
.69843 .53233 m .70055 .51178 L .70357 .52296 L .669 .508 .658 r
F
.69843 .53233 m .69521 .51711 L .70055 .51178 L F
.70055 .51178 m .70503 .53556 L .70652 .51809 L .902 .543 .349 r
F
.69521 .51711 m .69824 .51403 L .70055 .51178 L .402 .49 .835 r
F
.70055 .51178 m .69824 .51403 L .70503 .53556 L .902 .543 .349 r
F
.52299 .49859 m .52546 .54622 L .5284 .54174 L .957 .65 .407 r
F
.30745 .4968 m .30931 .49201 L .3126 .49512 L .664 .742 .908 r
F
.30745 .4968 m .30415 .4937 L .30931 .49201 L F
.47385 .4968 m .47617 .49203 L .47917 .49513 L .664 .742 .909 r
F
.47385 .4968 m .47085 .49371 L .47617 .49203 L F
.39745 .49667 m .39956 .49188 L .40269 .49499 L .663 .741 .908 r
F
.39745 .49667 m .39431 .49356 L .39956 .49188 L F
.69305 .53703 m .69521 .51711 L .69843 .53233 L .562 .416 .64 r
F
.69521 .51711 m .69249 .51167 L .69824 .51403 L .402 .49 .835 r
F
.32104 .49654 m .32294 .49175 L .32621 .49486 L .664 .741 .908 r
F
.32104 .49654 m .31777 .49344 L .32294 .49175 L F
.48747 .49654 m .48983 .49174 L .4928 .49485 L .664 .742 .908 r
F
.48747 .49654 m .48449 .49344 L .48983 .49174 L F
.41106 .49641 m .41321 .49162 L .41632 .49473 L .663 .741 .908 r
F
.41106 .49641 m .40795 .4933 L .41321 .49162 L F
.56479 .56054 m .56678 .50629 L .56972 .51815 L .819 .594 .597 r
F
.5679 .58313 m .56972 .51815 L .5728 .53982 L .834 .601 .587 r
F
.5679 .58313 m .56479 .56054 L .56972 .51815 L F
.57091 .59664 m .5679 .58313 L .5728 .53982 L .882 .649 .58 r
F
.56972 .51815 m .56678 .50629 L .57271 .54142 L .911 .607 .119 r
F
.56479 .56054 m .56173 .53985 L .56678 .50629 L .819 .594 .597 r
F
.56678 .50629 m .57009 .5564 L .57271 .54142 L .963 .654 .39 r
F
.56173 .53985 m .56394 .50263 L .56678 .50629 L .748 .546 .621 r
F
.56678 .50629 m .56394 .50263 L .56901 .54693 L .963 .654 .39 r
F
.56173 .53985 m .55869 .51963 L .56394 .50263 L .748 .546 .621 r
F
.56394 .50263 m .56732 .5625 L .57009 .5564 L .914 .613 .459 r
F
.55869 .51963 m .5612 .50906 L .56394 .50263 L .454 .363 .663 r
F
.56394 .50263 m .5612 .50906 L .56732 .5625 L .914 .613 .459 r
F
.56265 .58807 m .55954 .56105 L .5656 .61714 L .76 .549 0 r
F
.55954 .56105 m .56258 .59971 L .56564 .61753 L .915 .648 .154 r
F
.56039 .5725 m .56173 .53985 L .56479 .56054 L .683 .491 .621 r
F
.55946 .57501 m .5599 .56828 L .56039 .5725 L F
.5599 .56828 m .56173 .53985 L .56039 .5725 L F
.56562 .61731 m .5656 .61714 L .56564 .61753 L .76 .549 0 r
F
.56265 .58807 m .5656 .61714 L .56562 .61731 L F
.56582 .60316 m .569 .64471 L .57219 .67117 L .827 .53 .486 r
F
.569 .64471 m .5658 .61612 L .57152 .63119 L .346 .243 .593 r
F
.5658 .61612 m .56866 .63075 L .57152 .63119 L 0 0 .273 r
F
.5658 .61612 m .56265 .58807 L .56866 .63075 L F
.56265 .58807 m .56564 .61753 L .56866 .63075 L .76 .549 0 r
F
.56258 .59971 m .56479 .56054 L .5679 .58313 L .71 .511 .618 r
F
.56258 .59971 m .55946 .57501 L .56479 .56054 L F
.5612 .50906 m .56446 .563 L .56732 .5625 L .879 .578 .475 r
F
.55869 .51963 m .55571 .50435 L .5612 .50906 L .454 .363 .663 r
F
.55333 .52868 m .55571 .50435 L .55869 .51963 L .676 .503 .645 r
F
.55637 .55045 m .55869 .51963 L .56173 .53985 L .68 .495 .629 r
F
.55946 .57501 m .55637 .55045 L .56173 .53985 L .683 .491 .621 r
F
.5612 .50906 m .55847 .51963 L .56446 .563 L .879 .578 .475 r
F
.55847 .51963 m .5615 .55554 L .56446 .563 L .784 .485 .482 r
F
.56191 .55 m .56351 .49666 L .56626 .49031 L .878 .643 .579 r
F
.5615 .55554 m .56169 .55009 L .56191 .55 L F
.56169 .55009 m .56351 .49666 L .56191 .55 L F
.56945 .54673 m .56901 .54693 L .57009 .5564 L .963 .654 .39 r
F
.56678 .50629 m .56901 .54693 L .56945 .54673 L F
.33464 .49628 m .33658 .49149 L .33982 .4946 L .663 .741 .908 r
F
.33464 .49628 m .33139 .49317 L .33658 .49149 L F
.50109 .49629 m .50349 .4915 L .50644 .4946 L F
.50109 .49629 m .49814 .49318 L .50349 .4915 L F
.42467 .49615 m .42686 .49136 L .42994 .49448 L .664 .741 .908 r
F
.42467 .49615 m .42158 .49304 L .42686 .49136 L F
.51472 .49602 m .51715 .49305 L .52008 .49573 L .492 .677 .947 r
F
.51472 .49602 m .51179 .49292 L .51715 .49305 L F
.62253 .56128 m .6193 .54101 L .62485 .5424 L .556 .413 .642 r
F
.34824 .49603 m .35022 .49123 L .35344 .49434 L .664 .742 .908 r
F
.34824 .49603 m .34501 .49292 L .35022 .49123 L F
.43829 .4959 m .44051 .4911 L .44357 .49421 L .664 .741 .907 r
F
.43829 .4959 m .43522 .49279 L .44051 .4911 L F
.36185 .49577 m .36386 .49097 L .36706 .49408 L .664 .741 .908 r
F
.36185 .49577 m .35864 .49266 L .36386 .49097 L F
.45191 .49563 m .45417 .49084 L .45721 .49395 L .663 .741 .908 r
F
.45191 .49563 m .44887 .49252 L .45417 .49084 L F
.37546 .4955 m .37751 .49071 L .38068 .49383 L F
.37546 .4955 m .37228 .49239 L .37751 .49071 L F
.46554 .49538 m .46784 .4906 L .47085 .49371 L .663 .741 .909 r
F
.46554 .49538 m .46252 .49228 L .46784 .4906 L F
.38907 .49525 m .39116 .49045 L .39431 .49356 L .664 .742 .908 r
F
.38907 .49525 m .38592 .49215 L .39116 .49045 L F
.54337 .69608 m .54037 .70035 L .5449 .5052 L .966 .706 .49 r
F
.5449 .5052 m .54206 .50928 L .54742 .5004 L .706 .867 .459 r
F
.3126 .49512 m .31448 .49032 L .31777 .49344 L .663 .741 .908 r
F
.3126 .49512 m .30931 .49201 L .31448 .49032 L F
.47917 .49513 m .4815 .49032 L .48449 .49344 L .665 .742 .908 r
F
.47917 .49513 m .47617 .49203 L .4815 .49032 L F
.40269 .49499 m .40482 .49019 L .40795 .4933 L .664 .741 .908 r
F
.40269 .49499 m .39956 .49188 L .40482 .49019 L F
.5728 .53982 m .56972 .51815 L .5753 .52763 L .393 .293 .621 r
F
.57091 .59664 m .5728 .53982 L .57595 .56381 L .882 .649 .58 r
F
.57271 .54142 m .57009 .5564 L .5702 .55562 L .85 .75 .234 r
F
.56972 .51815 m .57271 .54142 L .57518 .52743 L .911 .607 .119 r
F
.57271 .54142 m .5702 .55562 L .57509 .52061 L .85 .75 .234 r
F
.57518 .52743 m .57271 .54142 L .5753 .52763 L .911 .607 .119 r
F
.4928 .49485 m .49518 .49006 L .49814 .49318 L .663 .741 .908 r
F
.4928 .49485 m .48983 .49174 L .49518 .49006 L F
.32621 .49486 m .32812 .49006 L .33139 .49317 L .664 .741 .908 r
F
.32621 .49486 m .32294 .49175 L .32812 .49006 L F
.69249 .51167 m .69649 .52782 L .69824 .51403 L .75 .403 .395 r
F
.69249 .51167 m .69038 .51862 L .69649 .52782 L F
.41632 .49473 m .41848 .48993 L .42158 .49304 L .663 .741 .908 r
F
.41632 .49473 m .41321 .49162 L .41848 .48993 L F
.67758 .55038 m .67709 .54783 L .6793 .53567 L .974 .837 .43 r
F
.6777 .54448 m .6772 .54437 L .6793 .53567 L .476 .352 .631 r
F
.67481 .56037 m .6772 .54437 L .6777 .54448 L F
.6772 .54437 m .67483 .54771 L .6767 .54426 L .778 .892 .481 r
F
.6772 .54437 m .68003 .53807 L .68182 .52295 L F
.6772 .54437 m .6767 .54426 L .68003 .53807 L F
.67483 .54771 m .67789 .54629 L .68003 .53807 L .119 .104 .564 r
F
.67519 .53784 m .67488 .53552 L .67789 .54629 L 0 0 .385 r
F
.67134 .52583 m .6746 .53474 L .67519 .53784 L F
.6746 .53474 m .67488 .53552 L .67519 .53784 L F
.67707 .55472 m .67481 .56037 L .67709 .54783 L .974 .837 .43 r
F
.67707 .55472 m .67709 .54783 L .67758 .55038 L F
.33982 .4946 m .34177 .4898 L .34501 .49292 L .663 .741 .908 r
F
.33982 .4946 m .33658 .49149 L .34177 .4898 L F
.50644 .4946 m .50885 .48981 L .51179 .49292 L .664 .742 .908 r
F
.50644 .4946 m .50349 .4915 L .50885 .48981 L F
.42994 .49448 m .43215 .48967 L .43522 .49279 L .664 .741 .907 r
F
.42994 .49448 m .42686 .49136 L .43215 .48967 L F
.35344 .49434 m .35543 .48954 L .35864 .49266 L .664 .742 .908 r
F
.35344 .49434 m .35022 .49123 L .35543 .48954 L F
.44357 .49421 m .44582 .4894 L .44887 .49252 L .664 .741 .908 r
F
.44357 .49421 m .44051 .4911 L .44582 .4894 L F
.36706 .49408 m .36909 .48928 L .37228 .49239 L F
.36706 .49408 m .36386 .49097 L .36909 .48928 L F
.68182 .52295 m .68003 .53807 L .68476 .51885 L 0 0 .228 r
F
.45721 .49395 m .45949 .48916 L .46252 .49228 L .663 .741 .908 r
F
.45721 .49395 m .45417 .49084 L .45949 .48916 L F
.38068 .49383 m .38275 .48903 L .38592 .49215 L F
.38068 .49383 m .37751 .49071 L .38275 .48903 L F
.30415 .4937 m .306 .48889 L .30931 .49201 L .664 .741 .908 r
F
.30415 .4937 m .30083 .49059 L .306 .48889 L F
.47085 .49371 m .47317 .4889 L .47617 .49203 L .665 .742 .908 r
F
.47085 .49371 m .46784 .4906 L .47317 .4889 L F
.52008 .49573 m .52249 .55155 L .52546 .54622 L .957 .655 .42 r
F
.52008 .49573 m .51715 .49305 L .52249 .55155 L F
.39431 .49356 m .39642 .48876 L .39956 .49188 L .664 .741 .908 r
F
.39431 .49356 m .39116 .49045 L .39642 .48876 L F
.61071 .51875 m .61377 .52736 L .61612 .51537 L .39 .131 .396 r
F
.61071 .51875 m .60839 .53346 L .61377 .52736 L F
.60576 .54127 m .60839 .53346 L .61071 .51875 L 0 0 .144 r
F
.31777 .49344 m .31966 .48863 L .32294 .49175 L .664 .741 .908 r
F
.31777 .49344 m .31448 .49032 L .31966 .48863 L F
.48449 .49344 m .48685 .48862 L .48983 .49174 L .664 .741 .907 r
F
.48449 .49344 m .4815 .49032 L .48685 .48862 L F
.73067 .50303 m .73451 .51083 L .73842 .5354 L .807 .322 0 r
F
.72696 .53552 m .72823 .50161 L .73067 .50303 L .816 .677 .132 r
F
.73067 .50303 m .72823 .50161 L .73135 .50618 L .807 .322 0 r
F
.73262 .50699 m .73135 .50618 L .73451 .51083 L F
.73067 .50303 m .73135 .50618 L .73262 .50699 L F
.72823 .50161 m .7311 .49396 L .73451 .51083 L 0 0 .124 r
F
.72144 .53875 m .72569 .5544 L .72696 .53552 L 0 0 .376 r
F
.72696 .53552 m .72678 .53822 L .72823 .50161 L .816 .677 .132 r
F
.72678 .53822 m .72569 .5544 L .72709 .52533 L F
.72678 .53822 m .72709 .52533 L .72823 .50161 L F
.72662 .51405 m .72754 .50378 L .72761 .50382 L 0 0 0 r
F
.72569 .5544 m .72662 .51405 L .72823 .50161 L .993 .776 .402 r
F
.72754 .50698 m .72662 .51405 L .72746 .5103 L 0 0 .124 r
F
.72754 .50698 m .72746 .5103 L .7311 .49396 L F
.72823 .50161 m .72754 .50698 L .7311 .49396 L F
.72746 .5103 m .72761 .50382 L .72874 .50454 L 0 0 0 r
F
.72662 .51405 m .72761 .50382 L .72746 .5103 L F
.72874 .50454 m .7286 .49179 L .7311 .49396 L F
.72754 .50378 m .7286 .49179 L .72874 .50454 L F
.40795 .4933 m .41009 .4885 L .41321 .49162 L .664 .741 .908 r
F
.40795 .4933 m .40482 .49019 L .41009 .4885 L F
.33139 .49317 m .33332 .48837 L .33658 .49149 L .663 .741 .908 r
F
.33139 .49317 m .32812 .49006 L .33332 .48837 L F
.49814 .49318 m .50053 .48839 L .50349 .4915 L .663 .741 .909 r
F
.49814 .49318 m .49518 .49006 L .50053 .48839 L F
.42158 .49304 m .42376 .48825 L .42686 .49136 L .663 .742 .908 r
F
.42158 .49304 m .41848 .48993 L .42376 .48825 L F
.51179 .49292 m .51422 .4905 L .51715 .49305 L .415 .641 .95 r
F
.51179 .49292 m .50885 .48981 L .51422 .4905 L F
.34501 .49292 m .34698 .48811 L .35022 .49123 L .664 .741 .908 r
F
.34501 .49292 m .34177 .4898 L .34698 .48811 L F
.62253 .56128 m .62485 .5424 L .62798 .55867 L .556 .413 .642 r
F
.43522 .49279 m .43744 .48798 L .44051 .4911 L .664 .741 .908 r
F
.43522 .49279 m .43215 .48967 L .43744 .48798 L F
.61612 .51537 m .61948 .53304 L .62172 .51822 L .657 .351 .442 r
F
.61612 .51537 m .61377 .52736 L .61948 .53304 L F
.35864 .49266 m .36065 .48785 L .36386 .49097 L .664 .741 .908 r
F
.35864 .49266 m .35543 .48954 L .36065 .48785 L F
.63068 .56109 m .63339 .55464 L .63624 .56181 L .794 .813 .867 r
F
.63068 .56109 m .62798 .55867 L .63339 .55464 L F
.44887 .49252 m .45113 .48771 L .45417 .49084 L .663 .741 .908 r
F
.44887 .49252 m .44582 .4894 L .45113 .48771 L F
.37228 .49239 m .37432 .48759 L .37751 .49071 L F
.37228 .49239 m .36909 .48928 L .37432 .48759 L F
.58744 .58772 m .58972 .56374 L .59288 .58561 L .948 .803 .352 r
F
.58744 .58772 m .58487 .59907 L .58972 .56374 L F
.46252 .49228 m .46481 .48746 L .46784 .4906 L .664 .741 .908 r
F
.46252 .49228 m .45949 .48916 L .46481 .48746 L F
.38592 .49215 m .388 .48733 L .39116 .49045 L F
.38592 .49215 m .38275 .48903 L .388 .48733 L F
.30931 .49201 m .31118 .48719 L .31448 .49032 L F
.30931 .49201 m .306 .48889 L .31118 .48719 L F
.47617 .49203 m .47851 .48719 L .4815 .49032 L .664 .741 .907 r
F
.47617 .49203 m .47317 .4889 L .47851 .48719 L F
.39956 .49188 m .40168 .48706 L .40482 .49019 L .664 .741 .908 r
F
.39956 .49188 m .39642 .48876 L .40168 .48706 L F
.48983 .49174 m .4922 .48694 L .49518 .49006 L .663 .741 .908 r
F
.48983 .49174 m .48685 .48862 L .4922 .48694 L F
.32294 .49175 m .32485 .48693 L .32812 .49006 L .664 .741 .908 r
F
.32294 .49175 m .31966 .48863 L .32485 .48693 L F
.41321 .49162 m .41537 .48681 L .41848 .48993 L .663 .741 .908 r
F
.41321 .49162 m .41009 .4885 L .41537 .48681 L F
.33658 .49149 m .33852 .48667 L .34177 .4898 L .664 .742 .908 r
F
.33658 .49149 m .33332 .48837 L .33852 .48667 L F
.50349 .4915 m .5059 .48669 L .50885 .48981 L F
.50349 .4915 m .50053 .48839 L .5059 .48669 L F
.42686 .49136 m .42906 .48655 L .43215 .48967 L .664 .742 .909 r
F
.42686 .49136 m .42376 .48825 L .42906 .48655 L F
.62292 .58259 m .62011 .57701 L .62545 .57063 L .785 .674 .741 r
F
.35022 .49123 m .3522 .48641 L .35543 .48954 L .664 .741 .908 r
F
.35022 .49123 m .34698 .48811 L .3522 .48641 L F
.71423 .55465 m .71436 .49897 L .71751 .51226 L .945 .699 .536 r
F
.71614 .5456 m .71751 .51226 L .72144 .53875 L .974 .782 .357 r
F
.71614 .5456 m .71423 .55465 L .71619 .5293 L F
.71666 .53295 m .71619 .5293 L .71751 .51226 L F
.71614 .5456 m .71619 .5293 L .71666 .53295 L F
.70652 .51809 m .71143 .54817 L .71423 .55465 L .707 .418 .484 r
F
.71423 .55465 m .71143 .54817 L .71436 .49897 L .945 .699 .536 r
F
.71143 .54817 m .71221 .50347 L .71436 .49897 L .784 .567 .606 r
F
.71436 .49897 m .71221 .50347 L .71928 .54376 L .93 .608 .41 r
F
.71986 .54486 m .71928 .54376 L .72071 .55188 L F
.71436 .49897 m .71928 .54376 L .71986 .54486 L F
.71221 .50347 m .71433 .51486 L .71468 .51753 L .674 .385 .475 r
F
.70652 .51809 m .70503 .53556 L .71143 .54817 L .707 .418 .484 r
F
.71143 .54817 m .70784 .5273 L .71221 .50347 L .784 .567 .606 r
F
.71468 .51753 m .71695 .52888 L .72071 .55188 L .674 .385 .475 r
F
.71433 .51486 m .71695 .52888 L .71468 .51753 L F
.71221 .50347 m .71071 .52008 L .71695 .52888 L F
.70784 .5273 m .71071 .52008 L .71149 .51148 L .304 .238 .616 r
F
.71106 .50973 m .71149 .51148 L .71221 .50347 L F
.70784 .5273 m .71149 .51148 L .71106 .50973 L F
.70784 .5273 m .70426 .50633 L .71071 .52008 L F
.69824 .51403 m .70323 .54779 L .70503 .53556 L .782 .477 .471 r
F
.70503 .53556 m .70784 .5273 L .70885 .53317 L 0 0 .078 r
F
.70776 .54093 m .70885 .53317 L .71143 .54817 L F
.70503 .53556 m .70885 .53317 L .70776 .54093 L F
.71071 .52008 m .71299 .50206 L .71695 .52888 L 0 0 .026 r
F
.71185 .51186 m .71195 .51201 L .71232 .50844 L F
.71177 .51174 m .71232 .50844 L .71299 .50206 L F
.71097 .51808 m .71184 .51185 L .71177 .51174 L F
.71184 .51185 m .71232 .50844 L .71177 .51174 L F
.71071 .52008 m .71232 .50844 L .71097 .51808 L F
.71071 .52008 m .70924 .53777 L .71176 .51382 L F
.71171 .51355 m .71176 .51382 L .71195 .51201 L F
.71071 .52008 m .71176 .51382 L .71171 .51355 L F
.71071 .52008 m .71195 .51201 L .71185 .51186 L F
.71022 .51903 m .71033 .52474 L .71071 .52008 L .893 .588 .085 r
F
.70426 .50633 m .71033 .52474 L .71022 .51903 L F
.70503 .53556 m .70323 .54779 L .70784 .5273 L 0 0 .078 r
F
.70769 .52796 m .70426 .50633 L .70784 .5273 L .943 .711 .558 r
F
.70323 .54779 m .70426 .50633 L .70769 .52796 L F
.70426 .50633 m .70924 .53777 L .71033 .52474 L .893 .588 .085 r
F
.71037 .52703 m .70981 .49732 L .71213 .51029 L .995 .759 .42 r
F
.70932 .52506 m .70957 .48432 L .71037 .52703 L F
.69824 .51403 m .69649 .52782 L .70323 .54779 L .782 .477 .471 r
F
.69649 .52782 m .70048 .54259 L .70323 .54779 L .649 .33 .418 r
F
.70048 .54259 m .70116 .49403 L .70426 .50633 L .825 .599 .596 r
F
.70323 .54779 m .70048 .54259 L .70426 .50633 L .943 .711 .558 r
F
.70426 .50633 m .70116 .49403 L .70711 .52623 L .893 .588 .085 r
F
.70749 .52673 m .70711 .52623 L .70924 .53777 L F
.70426 .50633 m .70711 .52623 L .70749 .52673 L F
.70116 .49403 m .70715 .54468 L .70924 .53777 L .941 .617 .392 r
F
.70565 .508 m .70519 .49352 L .70698 .48146 L .791 .574 .607 r
F
.70924 .53777 m .70901 .53853 L .70914 .49494 L .995 .759 .42 r
F
.70901 .53853 m .70715 .54468 L .70794 .52486 L F
.70901 .53853 m .70794 .52486 L .70914 .49494 L F
.70949 .49721 m .70914 .49494 L .70957 .48432 L F
.70924 .53777 m .70914 .49494 L .70949 .49721 L F
.70715 .54468 m .70698 .48146 L .70957 .48432 L .94 .69 .531 r
F
.70957 .48432 m .70698 .48146 L .71366 .51888 L .961 .63 .319 r
F
.70048 .54259 m .69705 .52413 L .70116 .49403 L .825 .599 .596 r
F
.69705 .52413 m .69884 .49639 L .70116 .49403 L .637 .463 .631 r
F
.70116 .49403 m .69884 .49639 L .70715 .54468 L .941 .617 .392 r
F
.69884 .49639 m .70423 .53658 L .70715 .54468 L .836 .523 .458 r
F
.70715 .54468 m .70423 .53658 L .70698 .48146 L .94 .69 .531 r
F
.70772 .48558 m .71131 .5056 L .71128 .50554 L .742 .427 .45 r
F
.71131 .5056 m .71265 .51308 L .71128 .50554 L F
.71128 .50554 m .71265 .51308 L .71262 .51303 L F
.70698 .48146 m .7077 .48545 L .70772 .48558 L F
.7077 .48545 m .71265 .51308 L .70772 .48558 L F
.70698 .48146 m .71166 .50629 L .71285 .51338 L F
.70698 .48146 m .71285 .51338 L .71265 .51308 L F
.70698 .48146 m .70519 .49352 L .71166 .50629 L F
.70555 .49422 m .70623 .49211 L .70804 .49913 L 0 0 .249 r
F
.70623 .49211 m .70809 .48629 L .70804 .49913 L F
.70545 .49289 m .70809 .48629 L .70555 .49422 L F
.70519 .49352 m .70545 .49289 L .70555 .49422 L F
.70512 .50132 m .70519 .49352 L .70565 .508 L .791 .574 .607 r
F
.70454 .52283 m .70519 .49352 L .70489 .5233 L F
.70804 .49913 m .70809 .48629 L .71166 .50629 L 0 0 .249 r
F
.70865 .4953 m .70984 .50238 L .713 .52127 L .951 .598 .255 r
F
.69705 .52413 m .69342 .50142 L .69884 .49639 L .637 .463 .631 r
F
.69884 .49639 m .69699 .50834 L .70423 .53658 L .836 .523 .458 r
F
.70423 .53658 m .7007 .51701 L .70497 .49472 L .791 .574 .607 r
F
.70517 .49468 m .70497 .49472 L .70519 .49352 L F
.70423 .53658 m .70497 .49472 L .70517 .49468 L F
.69342 .50142 m .69699 .50834 L .69884 .49639 L 0 0 .453 r
F
.69699 .50834 m .7007 .51701 L .70359 .53306 L .404 .144 .403 r
F
.70374 .5347 m .70359 .53306 L .70423 .53658 L F
.69699 .50834 m .70359 .53306 L .70374 .5347 L F
.69038 .51862 m .69453 .53789 L .69649 .52782 L .701 .386 .44 r
F
.69038 .51862 m .68843 .52956 L .69453 .53789 L F
.68843 .52956 m .69206 .53827 L .69453 .53789 L .626 .253 .316 r
F
.69206 .53827 m .69342 .50142 L .69705 .52413 L .823 .609 .614 r
F
.69699 .50834 m .69525 .5229 L .7007 .51701 L .404 .144 .403 r
F
.7007 .51701 m .70384 .51419 L .70519 .49352 L .167 .14 .581 r
F
.7007 .51701 m .69709 .49543 L .70384 .51419 L F
.69342 .50142 m .69024 .48754 L .69699 .50834 L 0 0 .453 r
F
.68476 .51885 m .68843 .52956 L .69038 .51862 L .435 .181 .429 r
F
.68885 .52394 m .69024 .48754 L .69342 .50142 L .775 .568 .619 r
F
.69206 .53827 m .68885 .52394 L .69342 .50142 L .823 .609 .614 r
F
.69024 .48754 m .69525 .5229 L .69699 .50834 L .942 .602 .348 r
F
.69525 .5229 m .69709 .49543 L .7007 .51701 L .977 .801 .386 r
F
.69742 .49637 m .70234 .53301 L .70384 .51419 L .874 .591 .068 r
F
.69722 .49641 m .70234 .53301 L .69742 .49637 L F
.69649 .52782 m .69453 .53789 L .70048 .54259 L .649 .33 .418 r
F
.69453 .53789 m .69705 .52413 L .70048 .54259 L .985 .871 .639 r
F
.68885 .52394 m .68549 .50619 L .69024 .48754 L .775 .568 .619 r
F
.68549 .50619 m .68777 .48778 L .69024 .48754 L .647 .497 .665 r
F
.69024 .48754 m .68777 .48778 L .69525 .5229 L .942 .602 .348 r
F
.68777 .48778 m .69311 .5303 L .69525 .5229 L .848 .534 .457 r
F
.69311 .5303 m .69374 .47884 L .69709 .49543 L .957 .714 .53 r
F
.69525 .5229 m .69311 .5303 L .6953 .51106 L .977 .801 .386 r
F
.69592 .51288 m .6953 .51106 L .69709 .49543 L F
.69525 .5229 m .6953 .51106 L .69592 .51288 L F
.69453 .53789 m .69206 .53827 L .69705 .52413 L .985 .871 .639 r
F
.68549 .50619 m .68228 .49153 L .68777 .48778 L .647 .497 .665 r
F
.68777 .48778 m .68584 .49946 L .69311 .5303 L .848 .534 .457 r
F
.68584 .49946 m .69035 .52584 L .69311 .5303 L .701 .402 .468 r
F
.69311 .5303 m .69035 .52584 L .69374 .47884 L .957 .714 .53 r
F
.69238 .50238 m .69387 .51611 L .69745 .53642 L .833 .516 .452 r
F
.69035 .52584 m .69098 .47346 L .69374 .47884 L .885 .648 .574 r
F
.68012 .5127 m .68228 .49153 L .68549 .50619 L .648 .487 .653 r
F
.68476 .51885 m .68304 .5352 L .68843 .52956 L .435 .181 .429 r
F
.68003 .53807 m .68304 .5352 L .68476 .51885 L 0 0 .079 r
F
.68334 .52775 m .68549 .50619 L .68885 .52394 L .685 .52 .657 r
F
.68334 .52775 m .68012 .5127 L .68549 .50619 L F
.68584 .49946 m .68406 .51495 L .69035 .52584 L .701 .402 .468 r
F
.69035 .52584 m .68715 .51233 L .69098 .47346 L .885 .648 .574 r
F
.68715 .51233 m .68868 .47761 L .69098 .47346 L .746 .545 .623 r
F
.68868 .47761 m .69178 .50063 L .69238 .50238 L .833 .516 .452 r
F
.69178 .50063 m .69387 .51611 L .69238 .50238 L F
.69709 .49543 m .69374 .47884 L .70033 .52033 L .874 .591 .068 r
F
.69374 .47884 m .70018 .53996 L .70234 .53301 L .97 .653 .33 r
F
.69374 .47884 m .69098 .47346 L .69894 .53103 L F
.69917 .53035 m .69894 .53103 L .70018 .53996 L F
.69374 .47884 m .69894 .53103 L .69917 .53035 L F
.69098 .47346 m .69745 .53642 L .70018 .53996 L .939 .621 .409 r
F
.69748 .53556 m .69781 .51553 L .69804 .51606 L .807 .583 .598 r
F
.69745 .53642 m .69747 .53559 L .69748 .53556 L F
.69747 .53559 m .69781 .51553 L .69748 .53556 L F
.69709 .49543 m .70033 .52033 L .70039 .52045 L .874 .591 .068 r
F
.69709 .49543 m .70058 .52192 L .70089 .52263 L F
.69709 .49543 m .69722 .49641 L .69742 .49637 L F
.69098 .47346 m .68868 .47761 L .69745 .53642 L .939 .621 .409 r
F
.69745 .53642 m .69387 .51611 L .69726 .49474 L .807 .583 .598 r
F
.69813 .49649 m .69726 .49474 L .69827 .48839 L F
.69745 .53642 m .69726 .49474 L .69813 .49649 L F
.68228 .49153 m .68584 .49946 L .68777 .48778 L .81 .341 0 r
F
.68012 .5127 m .67682 .49591 L .68228 .49153 L .648 .487 .653 r
F
.67682 .49591 m .67881 .49126 L .68228 .49153 L .564 .54 .787 r
F
.67881 .49126 m .67966 .48927 L .68184 .49116 L F
.67881 .49126 m .68184 .49116 L .68228 .49153 L F
.67096 .49117 m .67398 .48907 L .67682 .49591 L .354 .546 .903 r
F
.67682 .49591 m .67398 .48907 L .67966 .48927 L .564 .54 .787 r
F
.67515 .49139 m .67156 .49166 L .67744 .49593 L .687 .234 .173 r
F
.67398 .48907 m .6717 .49151 L .67515 .49139 L F
.6717 .49151 m .67156 .49166 L .67515 .49139 L F
.68228 .49153 m .67966 .48927 L .68584 .49946 L .81 .341 0 r
F
.67966 .48927 m .68406 .51495 L .68584 .49946 L .841 .501 .41 r
F
.68715 .51233 m .68369 .49316 L .68868 .47761 L .746 .545 .623 r
F
.68868 .47761 m .68673 .4893 L .69387 .51611 L .833 .516 .452 r
F
.68369 .49316 m .68673 .4893 L .68868 .47761 L .222 .203 .624 r
F
.68673 .4893 m .69024 .4945 L .69387 .51611 L .331 .052 .331 r
F
.67966 .48927 m .67744 .49593 L .68406 .51495 L .841 .501 .41 r
F
.67787 .53227 m .68012 .5127 L .68334 .52775 L .548 .404 .638 r
F
.67436 .51075 m .67682 .49591 L .68012 .5127 L .493 .372 .644 r
F
.67787 .53227 m .67436 .51075 L .68012 .5127 L .548 .404 .638 r
F
.67744 .49593 m .68199 .52517 L .68406 .51495 L .768 .455 .458 r
F
.68406 .51495 m .68715 .51233 L .69035 .52584 L 0 0 .149 r
F
.68406 .51495 m .68199 .52517 L .68715 .51233 L F
.68199 .52517 m .68369 .49316 L .68715 .51233 L .959 .744 .568 r
F
.68673 .4893 m .68472 .50039 L .69024 .4945 L .331 .052 .331 r
F
.69726 .49474 m .69644 .50169 L .69827 .48839 L .451 .337 .633 r
F
.69387 .51611 m .6961 .50357 L .69726 .49474 L F
.6961 .50357 m .69644 .50169 L .69726 .49474 L F
.69387 .51611 m .69024 .4945 L .69632 .50156 L F
.69635 .50221 m .69632 .50156 L .69644 .50169 L F
.69387 .51611 m .69632 .50156 L .69635 .50221 L F
.69024 .4945 m .69458 .51519 L .69644 .50169 L 0 0 .245 r
F
.69311 .50421 m .69318 .47283 L .69505 .46397 L .981 .743 .502 r
F
.6951 .46548 m .69505 .46397 L .69522 .46317 L F
.69311 .50421 m .69505 .46397 L .6951 .46548 L F
.69165 .49328 m .69124 .48498 L .69318 .47283 L .909 .69 .593 r
F
.69024 .4945 m .6872 .47551 L .69281 .50569 L 0 0 .245 r
F
.69024 .4945 m .69281 .50569 L .6929 .50669 L F
.69024 .4945 m .69352 .5095 L .69362 .51045 L F
.69024 .4945 m .69422 .51325 L .69428 .51374 L F
.6872 .47551 m .68656 .47154 L .69414 .51282 L F
.69415 .51289 m .69414 .51282 L .69455 .51504 L F
.6872 .47551 m .69414 .51282 L .69415 .51289 L F
.69028 .47983 m .69048 .45507 L .69262 .44684 L .991 .779 .397 r
F
.69455 .51504 m .69435 .51395 L .69458 .51519 L 0 0 .245 r
F
.69355 .5096 m .68656 .47154 L .69355 .50955 L F
.6929 .50669 m .69281 .50569 L .69352 .5095 L F
.69362 .51045 m .69352 .5095 L .69422 .51325 L F
.69428 .51374 m .69422 .51325 L .69455 .51504 L F
.68369 .49316 m .68037 .47685 L .68673 .4893 L .222 .203 .624 r
F
.67744 .49593 m .67547 .50865 L .68199 .52517 L .768 .455 .458 r
F
.67701 .51255 m .67929 .52231 L .68199 .52517 L .711 .354 .368 r
F
.67547 .50865 m .67657 .51256 L .67701 .51255 L F
.67657 .51256 m .67929 .52231 L .67701 .51255 L F
.6681 .50913 m .67145 .51523 L .67488 .53552 L 0 0 .387 r
F
.67488 .53552 m .67145 .51523 L .67787 .53227 L .181 .153 .589 r
F
.67145 .51523 m .67436 .51075 L .67787 .53227 L .247 .216 .625 r
F
.67145 .51523 m .66819 .49851 L .67436 .51075 L F
.66819 .49851 m .67096 .49117 L .67436 .51075 L .849 .849 .842 r
F
.67436 .51075 m .67096 .49117 L .67682 .49591 L .493 .372 .644 r
F
.66952 .5034 m .67321 .51547 L .67547 .50865 L .636 .295 .378 r
F
.67134 .52583 m .6681 .50913 L .67488 .53552 L 0 0 .385 r
F
.66952 .5034 m .6673 .51171 L .67321 .51547 L .636 .295 .378 r
F
.6673 .51171 m .67068 .51676 L .67321 .51547 L .493 .091 .207 r
F
.67321 .51547 m .67068 .51676 L .6739 .51264 L .852 .99 .726 r
F
.67547 .50865 m .67321 .51547 L .67929 .52231 L .711 .354 .368 r
F
.67468 .51261 m .6739 .51264 L .67614 .50977 L .852 .99 .726 r
F
.67321 .51547 m .6739 .51264 L .67468 .51261 L F
.67929 .52231 m .68037 .47685 L .68369 .49316 L .878 .647 .586 r
F
.68199 .52517 m .67929 .52231 L .68369 .49316 L .959 .744 .568 r
F
.68037 .47685 m .68472 .50039 L .68673 .4893 L .889 .563 .065 r
F
.68472 .50039 m .68656 .47154 L .69024 .4945 L .953 .785 .333 r
F
.68705 .47419 m .69228 .52046 L .69458 .51519 L .93 .634 .162 r
F
.69435 .51395 m .69355 .5096 L .69434 .5139 L 0 0 .245 r
F
.69355 .5096 m .69355 .50955 L .69434 .5139 L F
.69435 .51395 m .69434 .5139 L .69458 .51519 L F
.68705 .47419 m .69458 .51519 L .69458 .51518 L .93 .634 .162 r
F
.68682 .47372 m .69228 .52046 L .68705 .47419 L F
.67398 .48907 m .67744 .49593 L .67966 .48927 L .687 .234 .173 r
F
.67156 .49166 m .67547 .50865 L .67744 .49593 L .649 .338 .431 r
F
.67614 .50977 m .67739 .46749 L .68037 .47685 L .793 .576 .607 r
F
.67929 .52231 m .67614 .50977 L .68037 .47685 L .878 .647 .586 r
F
.68037 .47685 m .67739 .46749 L .68472 .50039 L .889 .563 .065 r
F
.67739 .46749 m .68261 .51022 L .68472 .50039 L .954 .621 .344 r
F
.68261 .51022 m .68324 .45549 L .68656 .47154 L .985 .741 .484 r
F
.68472 .50039 m .68261 .51022 L .6859 .47802 L .953 .785 .333 r
F
.68616 .47782 m .6859 .47802 L .68656 .47154 L F
.68472 .50039 m .6859 .47802 L .68616 .47782 L F
.67096 .49117 m .66826 .48726 L .67398 .48907 L .354 .546 .903 r
F
.66826 .48726 m .67156 .49166 L .67398 .48907 L .295 .027 .326 r
F
.67614 .50977 m .6727 .49064 L .67739 .46749 L .793 .576 .607 r
F
.6727 .49064 m .67479 .4664 L .67739 .46749 L .657 .487 .643 r
F
.67739 .46749 m .67479 .4664 L .68261 .51022 L .954 .621 .344 r
F
.67479 .4664 m .68006 .51097 L .68261 .51022 L .9 .575 .422 r
F
.68261 .51022 m .68006 .51097 L .68174 .48162 L .985 .741 .484 r
F
.68261 .51022 m .68174 .48162 L .68267 .48546 L F
.68261 .51022 m .68271 .46473 L .68312 .46585 L F
.68006 .51097 m .68034 .44806 L .68324 .45549 L .96 .71 .513 r
F
.6727 .49064 m .6693 .47213 L .67479 .4664 L .657 .487 .643 r
F
.67479 .4664 m .67253 .47332 L .68006 .51097 L .9 .575 .422 r
F
.67253 .47332 m .67724 .50624 L .68006 .51097 L .843 .514 .431 r
F
.68006 .51097 m .67724 .50624 L .68034 .44806 L .96 .71 .513 r
F
.67724 .50624 m .67781 .44865 L .68034 .44806 L .921 .676 .55 r
F
.66826 .48726 m .66619 .49844 L .67156 .49166 L .295 .027 .326 r
F
.67156 .49166 m .66952 .5034 L .67547 .50865 L .649 .338 .431 r
F
.66619 .49844 m .66952 .5034 L .67156 .49166 L .238 .025 .374 r
F
.66619 .49844 m .66435 .51608 L .66952 .5034 L F
.66762 .50609 m .6693 .47213 L .6727 .49064 L .801 .594 .622 r
F
.67253 .47332 m .67034 .48234 L .67106 .48484 L .843 .514 .431 r
F
.67329 .47862 m .67106 .48484 L .67724 .50624 L F
.67253 .47332 m .67106 .48484 L .67329 .47862 L F
.66556 .49652 m .66355 .50938 L .66826 .48726 L 0 0 .033 r
F
.66355 .50938 m .66151 .52252 L .66619 .49844 L 0 0 0 r
F
.66151 .52252 m .66435 .51608 L .66619 .49844 L F
.66762 .50609 m .66438 .49124 L .6693 .47213 L .801 .594 .622 r
F
.66438 .49124 m .66621 .46031 L .6693 .47213 L .773 .575 .63 r
F
.66438 .49124 m .66113 .47587 L .66621 .46031 L F
.66113 .47587 m .66347 .45671 L .66621 .46031 L .725 .565 .674 r
F
.66347 .45671 m .66819 .49302 L .67034 .48234 L .912 .575 .392 r
F
.66113 .47587 m .65805 .46422 L .66347 .45671 L .725 .565 .674 r
F
.66347 .45671 m .66103 .46076 L .66819 .49302 L .912 .575 .392 r
F
.66193 .50781 m .66438 .49124 L .66762 .50609 L .648 .508 .678 r
F
.66103 .46076 m .66582 .49935 L .66819 .49302 L .858 .535 .438 r
F
.67068 .51676 m .6727 .49064 L .67614 .50977 L .817 .625 .643 r
F
.66435 .51608 m .6673 .51171 L .66952 .5034 L 0 0 .088 r
F
.67068 .51676 m .66762 .50609 L .6727 .49064 L .817 .625 .643 r
F
.67106 .48484 m .67415 .49582 L .67724 .50624 L .602 .281 .399 r
F
.67034 .48234 m .671 .48468 L .67106 .48484 L F
.671 .48468 m .67415 .49582 L .67106 .48484 L F
.67034 .48234 m .66819 .49302 L .67415 .49582 L F
.66828 .49261 m .66582 .49935 L .67037 .48297 L .845 .819 .338 r
F
.67042 .48313 m .67037 .48297 L .67088 .48112 L F
.66828 .49261 m .67037 .48297 L .67042 .48313 L F
.66819 .49302 m .6669 .49648 L .66828 .49261 L F
.6669 .49648 m .66582 .49935 L .66828 .49261 L F
.67724 .50624 m .67415 .49582 L .67781 .44865 L .921 .676 .55 r
F
.67415 .49582 m .67556 .45581 L .67781 .44865 L .836 .616 .604 r
F
.67567 .45642 m .68008 .48297 L .68342 .49852 L .805 .471 .424 r
F
.67556 .45581 m .67564 .45628 L .67567 .45642 L F
.67564 .45628 m .68008 .48297 L .67567 .45642 L F
.68267 .48546 m .68174 .48162 L .68271 .46473 L .985 .741 .484 r
F
.68312 .46585 m .68271 .46473 L .68324 .45549 L F
.6784 .4529 m .68149 .48138 L .6823 .48077 L .908 .584 .421 r
F
.67781 .44865 m .67823 .45244 L .6784 .4529 L F
.67823 .45244 m .68149 .48138 L .6784 .4529 L F
.6823 .48077 m .68342 .49852 L .68668 .51215 L F
.68149 .48138 m .68342 .49852 L .6823 .48077 L F
.68656 .47154 m .68324 .45549 L .68941 .49983 L .93 .634 .162 r
F
.68656 .47154 m .68941 .49983 L .68966 .49899 L F
.68656 .47154 m .69121 .5128 L .69137 .51274 L F
.68324 .45549 m .68966 .5198 L .69228 .52046 L .972 .657 .314 r
F
.68324 .45549 m .68034 .44806 L .68966 .5198 L F
.68789 .50495 m .68918 .49531 L .69124 .48498 L .64 .501 .677 r
F
.68034 .44806 m .68668 .51215 L .68966 .5198 L .955 .636 .381 r
F
.68668 .51215 m .68761 .50591 L .68789 .50495 L .64 .501 .677 r
F
.68761 .50591 m .68918 .49531 L .68789 .50495 L F
.68966 .49899 m .68941 .49983 L .69121 .5128 L .93 .634 .162 r
F
.69137 .51274 m .69121 .5128 L .69228 .52046 L F
.69015 .51319 m .69112 .48765 L .69165 .49328 L .909 .69 .593 r
F
.68966 .5198 m .68995 .51327 L .69015 .51319 L F
.68995 .51327 m .69112 .48765 L .69015 .51319 L F
.68656 .47154 m .68682 .47372 L .68705 .47419 L .93 .634 .162 r
F
.68034 .44806 m .67781 .44865 L .68668 .51215 L .955 .636 .381 r
F
.68577 .49383 m .68623 .47351 L .68838 .46438 L .993 .777 .508 r
F
.67781 .44865 m .67556 .45581 L .68342 .49852 L .908 .584 .421 r
F
.68668 .51215 m .68342 .49852 L .68837 .49576 L .64 .501 .677 r
F
.68881 .49641 m .68837 .49576 L .68894 .49544 L F
.68668 .51215 m .68837 .49576 L .68881 .49641 L F
.68897 .49671 m .68894 .49544 L .68918 .49531 L F
.68668 .51215 m .68894 .49544 L .68897 .49671 L F
.68342 .49852 m .68696 .5031 L .68918 .49531 L 0 0 .5 r
F
.68342 .49852 m .68145 .48935 L .68521 .49856 L F
.68145 .48935 m .68008 .48297 L .68643 .50156 L F
.68526 .50038 m .68521 .49856 L .68643 .50156 L F
.68342 .49852 m .68521 .49856 L .68526 .50038 L F
.68651 .50252 m .68643 .50156 L .68696 .5031 L F
.68342 .49852 m .68643 .50156 L .68651 .50252 L F
.68065 .48465 m .68455 .50763 L .68696 .5031 L .758 .499 0 r
F
.68029 .48413 m .68455 .50763 L .68065 .48465 L F
.6693 .47213 m .67253 .47332 L .67479 .4664 L 0 .073 .595 r
F
.6693 .47213 m .66621 .46031 L .67253 .47332 L F
.66621 .46031 m .67034 .48234 L .67253 .47332 L .94 .572 .204 r
F
.67415 .49582 m .67088 .48112 L .67556 .45581 L .836 .616 .604 r
F
.67088 .48112 m .67339 .46527 L .67556 .45581 L .623 .49 .679 r
F
.67556 .45581 m .67339 .46527 L .67972 .48202 L .805 .471 .424 r
F
.67995 .48219 m .67972 .48202 L .68008 .48297 L F
.67556 .45581 m .67972 .48202 L .67995 .48219 L F
.67088 .48112 m .66766 .46759 L .67339 .46527 L .623 .49 .679 r
F
.66766 .46759 m .67127 .47639 L .67339 .46527 L 0 0 .372 r
F
.67339 .46527 m .6767 .4666 L .68008 .48297 L .121 0 .248 r
F
.67339 .46527 m .67127 .47639 L .6767 .4666 L F
.67158 .47584 m .67341 .45177 L .6767 .4666 L .944 .795 .339 r
F
.67127 .47639 m .67134 .47565 L .67158 .47584 L F
.67134 .47565 m .67341 .45177 L .67158 .47584 L F
.68008 .48297 m .6767 .4666 L .68363 .50281 L .758 .499 0 r
F
.68375 .50322 m .68363 .50281 L .68455 .50763 L F
.68008 .48297 m .68363 .50281 L .68375 .50322 L F
.6767 .4666 m .68196 .50859 L .68455 .50763 L .919 .62 .138 r
F
.68279 .49998 m .68408 .48318 L .68467 .48054 L .951 .755 .603 r
F
.68196 .50859 m .6827 .49969 L .68279 .49998 L F
.6827 .49969 m .68408 .48318 L .68279 .49998 L F
.68481 .4852 m .68467 .48054 L .68623 .47351 L F
.68196 .50859 m .68467 .48054 L .68481 .4852 L F
.68008 .48297 m .68029 .48413 L .68065 .48465 L .758 .499 0 r
F
.68836 .46643 m .68838 .46438 L .68846 .46405 L .998 .78 .449 r
F
.68696 .5031 m .68834 .46543 L .68836 .46643 L F
.68834 .46543 m .68834 .46541 L .68836 .46643 L F
.68834 .46534 m .68838 .46438 L .68836 .46643 L F
.68928 .47143 m .68846 .46404 L .69048 .45507 L F
.68696 .5031 m .68846 .46404 L .68928 .47143 L F
.68981 .47585 m .68928 .47143 L .69048 .45507 L .991 .779 .397 r
F
.68981 .47585 m .69048 .45507 L .69028 .47983 L F
.68696 .5031 m .68455 .50763 L .68838 .46438 L .998 .78 .449 r
F
.68628 .47333 m .6891 .464 L .69112 .45624 L 0 0 0 r
F
.68626 .47341 m .6891 .464 L .68628 .47333 L F
.68838 .46438 m .68623 .47351 L .68628 .47333 L F
.68834 .46543 m .68834 .46534 L .68834 .46541 L .998 .78 .449 r
F
.68838 .46438 m .68628 .47333 L .69127 .45571 L 0 0 0 r
F
.68543 .4898 m .68623 .47351 L .68577 .49383 L .993 .777 .508 r
F
.68455 .50763 m .68196 .50859 L .68623 .47351 L F
.68623 .47351 m .68408 .48318 L .6891 .464 L 0 0 0 r
F
.68623 .47351 m .68626 .47341 L .68628 .47333 L F
.68905 .46418 m .68682 .47064 L .6891 .464 L .847 .816 .333 r
F
.68408 .48318 m .68682 .47064 L .68905 .46418 L F
.68174 .48951 m .68449 .4768 L .68682 .47064 L .936 .882 .469 r
F
.68682 .47064 m .68449 .4768 L .68456 .47717 L .909 .575 .4 r
F
.68918 .49531 m .68696 .5031 L .68928 .47143 L .991 .779 .397 r
F
.68918 .49531 m .68928 .47143 L .68981 .47585 L F
.68918 .49531 m .68981 .47585 L .69028 .47983 L F
.69098 .48628 m .68918 .49531 L .69028 .47983 L .973 .775 .349 r
F
.69228 .52046 m .69266 .5005 L .69311 .50421 L .981 .743 .502 r
F
.69228 .52046 m .68966 .5198 L .69318 .47283 L F
.68966 .5198 m .68668 .51215 L .69124 .48498 L .909 .69 .593 r
F
.68408 .48318 m .68174 .48951 L .68682 .47064 L .847 .816 .333 r
F
.68682 .47064 m .68456 .47717 L .69242 .51504 L .909 .575 .4 r
F
.6891 .464 m .68682 .47064 L .68706 .47184 L .909 .578 .405 r
F
.69112 .48765 m .69124 .48498 L .69165 .49328 L .909 .69 .593 r
F
.69124 .48498 m .69098 .48628 L .69248 .4502 L .973 .775 .349 r
F
.69124 .48498 m .69248 .4502 L .69248 .45018 L F
.69124 .48498 m .69251 .44943 L .69253 .44939 L F
.69098 .48628 m .69028 .47983 L .69262 .44684 L F
.69124 .48498 m .69262 .44684 L .69491 .44212 L F
.68879 .46306 m .69127 .45571 L .69346 .4482 L 0 0 0 r
F
.68838 .46438 m .68863 .46361 L .68879 .46306 L F
.68863 .46361 m .69127 .45571 L .68879 .46306 L F
.69248 .45018 m .69248 .4502 L .69251 .44943 L .973 .775 .349 r
F
.69253 .44939 m .69251 .44943 L .69262 .44684 L F
.69742 .44202 m .69491 .44212 L .70054 .43836 L .704 .983 .888 r
F
.69318 .47283 m .69491 .44212 L .69742 .44202 L .923 .76 .277 r
F
.69318 .47283 m .69482 .44316 L .69485 .44305 L F
.69491 .44212 m .69803 .43849 L .70054 .43836 L 0 0 0 r
F
.6948 .44351 m .69479 .44353 L .69482 .44316 L .923 .76 .277 r
F
.69485 .44305 m .69482 .44316 L .69491 .44212 L F
.69491 .44212 m .69262 .44684 L .69803 .43849 L 0 0 0 r
F
.69375 .4451 m .69569 .44207 L .69803 .43849 L F
.69262 .44684 m .69346 .44553 L .69375 .4451 L F
.69346 .44553 m .69569 .44207 L .69375 .4451 L F
.69318 .47283 m .69124 .48498 L .69479 .44353 L .923 .76 .277 r
F
.69318 .47283 m .69479 .44353 L .6948 .44351 L F
.69239 .4503 m .69346 .4482 L .69569 .44207 L 0 0 0 r
F
.69075 .4544 m .69188 .45181 L .69239 .4503 L F
.69188 .45181 m .69346 .4482 L .69239 .4503 L F
.69048 .45507 m .69066 .45467 L .69075 .4544 L F
.69066 .45467 m .69346 .4482 L .69075 .4544 L F
.69266 .5005 m .69318 .47283 L .69311 .50421 L .981 .743 .502 r
F
.69532 .50983 m .69458 .51519 L .69488 .50892 L .964 .759 .316 r
F
.69458 .51519 m .69522 .46317 L .6974 .4567 L .996 .759 .437 r
F
.69458 .51518 m .69458 .51519 L .69458 .51519 L .93 .634 .162 r
F
.69458 .51519 m .69228 .52046 L .69522 .46317 L .996 .759 .437 r
F
.6891 .464 m .68706 .47184 L .69486 .51086 L .909 .578 .405 r
F
.69112 .45624 m .6891 .464 L .69127 .45571 L 0 0 0 r
F
.68455 .50763 m .68543 .4898 L .68577 .49383 L .993 .777 .508 r
F
.68846 .46405 m .68838 .46438 L .68846 .46404 L .998 .78 .449 r
F
.69644 .50169 m .69532 .50983 L .6974 .4567 L .964 .759 .316 r
F
.69532 .50983 m .69488 .50892 L .6974 .4567 L F
.70039 .52045 m .70033 .52033 L .70058 .52192 L .874 .591 .068 r
F
.70089 .52263 m .70058 .52192 L .70234 .53301 L F
.69804 .51606 m .69827 .48839 L .69898 .4833 L .807 .583 .598 r
F
.69781 .51553 m .69827 .48839 L .69804 .51606 L F
.6995 .48892 m .69898 .4833 L .70008 .47535 L F
.69745 .53642 m .69898 .4833 L .6995 .48892 L F
.70519 .49352 m .70492 .49772 L .7075 .48841 L 0 0 .249 r
F
.70519 .49352 m .7075 .48841 L .70742 .48795 L F
.70492 .49772 m .70621 .49862 L .70764 .48924 L F
.7075 .48841 m .70764 .48924 L .70809 .48629 L F
.70492 .49772 m .70764 .48924 L .7075 .48841 L F
.70859 .49489 m .713 .52127 L .71296 .52105 L .951 .598 .255 r
F
.70742 .48795 m .7075 .48841 L .70809 .48629 L 0 0 .249 r
F
.70489 .5233 m .70512 .50132 L .70565 .508 L .791 .574 .607 r
F
.70492 .49772 m .70384 .51419 L .70621 .49862 L 0 0 .249 r
F
.70604 .49977 m .70489 .47285 L .70809 .48629 L .892 .719 .209 r
F
.70432 .49546 m .70489 .47285 L .70604 .49977 L F
.7045 .48713 m .70439 .4848 L .7048 .47515 L F
.70452 .48749 m .7048 .47515 L .70483 .47533 L F
.70384 .51419 m .7045 .48713 L .70452 .48749 L F
.7045 .48713 m .7048 .47515 L .70452 .48749 L F
.70483 .47533 m .7048 .47515 L .70489 .47285 L F
.70234 .53301 m .70226 .46969 L .70489 .47285 L .994 .75 .422 r
F
.70489 .47285 m .70226 .46969 L .7081 .4949 L .951 .598 .255 r
F
.70906 .49771 m .7081 .4949 L .70984 .50238 L F
.70489 .47285 m .7081 .4949 L .70906 .49771 L F
.70401 .47725 m .7096 .50098 L .7095 .5009 L .686 .307 .324 r
F
.70272 .47168 m .70401 .47716 L .70401 .47725 L F
.70401 .47716 m .7096 .50098 L .70401 .47725 L F
.70401 .47716 m .70615 .4805 L .7096 .50098 L F
.70272 .47168 m .70388 .47467 L .70401 .47716 L F
.70388 .47467 m .70615 .4805 L .70401 .47716 L F
.70226 .46969 m .70265 .47076 L .70272 .47168 L F
.70265 .47076 m .70615 .4805 L .70272 .47168 L F
.70234 .53301 m .70018 .53996 L .70226 .46969 L .994 .75 .422 r
F
.70018 .53996 m .70008 .47535 L .70226 .46969 L .967 .715 .502 r
F
.70226 .46969 m .70008 .47535 L .70453 .47912 L .686 .307 .324 r
F
.70544 .47853 m .70453 .47912 L .70615 .4805 L F
.70226 .46969 m .70453 .47912 L .70544 .47853 L F
.70008 .47535 m .70069 .47304 L .70204 .47701 L 0 0 .039 r
F
.70069 .47304 m .70282 .46497 L .70204 .47701 L F
.70018 .53996 m .69745 .53642 L .70008 .47535 L .967 .715 .502 r
F
.70008 .47535 m .69827 .48839 L .70176 .47046 L 0 0 .039 r
F
.7007 .47303 m .70176 .47046 L .70282 .46497 L F
.70008 .47535 m .70176 .47046 L .7007 .47303 L F
.69991 .45703 m .7034 .46031 L .70419 .46454 L .551 0 0 r
F
.70204 .47701 m .70282 .46497 L .70615 .4805 L 0 0 .039 r
F
.70615 .4805 m .70314 .46643 L .70597 .47926 L 0 0 .173 r
F
.70314 .46643 m .70308 .46615 L .70597 .47926 L F
.70489 .47285 m .70681 .48428 L .70682 .48434 L .951 .598 .255 r
F
.70489 .47285 m .70947 .50018 L .70865 .4953 L F
.70809 .48629 m .70489 .47285 L .71357 .52466 L .91 .608 .118 r
F
.71416 .52014 m .71366 .51888 L .71487 .52566 L .961 .63 .319 r
F
.70957 .48432 m .71366 .51888 L .71416 .52014 L F
.70957 .48432 m .71487 .52566 L .71514 .52669 L F
.71262 .51303 m .71479 .52501 L .71465 .52443 L .742 .427 .45 r
F
.71265 .51308 m .71479 .52501 L .71262 .51303 L F
.71166 .50629 m .70809 .48629 L .71507 .5312 L .824 .561 .009 r
F
.71551 .53313 m .71507 .5312 L .71721 .54498 L F
.71166 .50629 m .71507 .5312 L .71551 .53313 L F
.70809 .48629 m .71357 .52466 L .71721 .54498 L .91 .608 .118 r
F
.71514 .52669 m .71487 .52566 L .71537 .52843 L .961 .63 .319 r
F
.71251 .50667 m .70957 .48432 L .71299 .50206 L .995 .759 .42 r
F
.70957 .48432 m .71537 .52843 L .71884 .54625 L .961 .63 .319 r
F
.71751 .51226 m .71436 .49897 L .72079 .54206 L .945 .64 .193 r
F
.72073 .53787 m .72079 .54206 L .7237 .56157 L F
.71751 .51226 m .72079 .54206 L .72073 .53787 L F
.71436 .49897 m .72071 .55188 L .7237 .56157 L .93 .608 .41 r
F
.72391 .54667 m .72398 .54558 L .72467 .5491 L 0 0 .376 r
F
.72144 .53875 m .72467 .5491 L .72463 .55048 L F
.72144 .53875 m .71751 .51226 L .72398 .54558 L F
.72144 .53875 m .72398 .54558 L .72391 .54667 L F
.72463 .55048 m .72467 .5491 L .72569 .5544 L F
.71751 .51226 m .7237 .56157 L .72569 .5544 L .945 .64 .193 r
F
.7237 .56157 m .72071 .55188 L .72311 .54156 L .855 .65 .625 r
F
.72457 .54561 m .72311 .54156 L .72531 .53211 L F
.7237 .56157 m .72311 .54156 L .72457 .54561 L F
.72311 .54156 m .72384 .54799 L .72531 .53211 L .205 .164 .587 r
F
.72092 .55095 m .72309 .54875 L .72311 .54156 L F
.72309 .54875 m .72384 .54799 L .72311 .54156 L F
.72071 .55188 m .72093 .5516 L .72092 .55095 L F
.72093 .5516 m .72384 .54799 L .72092 .55095 L F
.72071 .55188 m .72025 .54912 L .72384 .54799 L F
.72025 .54912 m .71695 .52888 L .72193 .54272 L F
.72025 .54912 m .72193 .54272 L .72384 .54799 L F
.71695 .52888 m .72168 .55291 L .72384 .54799 L 0 0 .262 r
F
.72531 .53211 m .72384 .54799 L .72675 .50391 L .832 .697 .161 r
F
.72493 .5315 m .72561 .5212 L .72686 .50219 L .993 .809 .436 r
F
.72384 .54799 m .72516 .52796 L .72493 .5315 L F
.72516 .52796 m .72561 .5212 L .72493 .5315 L F
.72384 .54799 m .72468 .52868 L .72561 .5212 L F
.72468 .52868 m .7249 .53142 L .72561 .5212 L .766 .649 .732 r
F
.72384 .54799 m .72168 .55291 L .72341 .53894 L .993 .809 .436 r
F
.72428 .53785 m .72341 .53894 L .72468 .52868 L F
.72384 .54799 m .72341 .53894 L .72428 .53785 L F
.72168 .55291 m .7243 .53997 L .7249 .53142 L .766 .649 .732 r
F
.72168 .55291 m .7249 .53142 L .72385 .53542 L F
.71695 .52888 m .71315 .5031 L .72168 .55291 L 0 0 .262 r
F
.71315 .5031 m .71299 .50206 L .71335 .50412 L F
.71315 .5031 m .71335 .50412 L .72168 .55291 L F
.71673 .52394 m .71884 .54625 L .72168 .55291 L .889 .605 .093 r
F
.7154 .52027 m .71884 .54625 L .71673 .52394 L F
.71299 .50206 m .70957 .48432 L .71434 .51615 L F
.71332 .5045 m .71434 .51615 L .71884 .54625 L F
.71299 .50206 m .71434 .51615 L .71332 .5045 L F
.71884 .54625 m .71537 .52843 L .71962 .54322 L 0 0 .463 r
F
.72168 .55291 m .71884 .54625 L .7243 .53997 L .766 .649 .732 r
F
.71884 .54625 m .72267 .55385 L .7243 .53997 L 0 0 .463 r
F
.72152 .55155 m .71962 .54322 L .72267 .55385 L F
.71884 .54625 m .71962 .54322 L .72152 .55155 L F
.71544 .52867 m .71851 .54513 L .71973 .5436 L 0 0 .184 r
F
.71537 .52843 m .71546 .52891 L .71544 .52867 L F
.71546 .52891 m .71851 .54513 L .71544 .52867 L F
.71851 .54513 m .72022 .55418 L .71973 .5436 L F
.71537 .52843 m .71373 .51868 L .72022 .55418 L F
.71373 .51868 m .71166 .50629 L .72022 .55418 L F
.71265 .51308 m .71285 .51338 L .71479 .52501 L .742 .427 .45 r
F
.71465 .52443 m .71479 .52501 L .71537 .52843 L F
.71334 .51568 m .71721 .54498 L .72022 .55418 L .824 .561 .009 r
F
.71166 .50629 m .71244 .51176 L .71334 .51568 L F
.71244 .51176 m .71721 .54498 L .71334 .51568 L F
.71973 .5436 m .72022 .55418 L .72267 .55385 L 0 0 .184 r
F
.72385 .53542 m .72425 .5339 L .72468 .52868 L .766 .649 .732 r
F
.72425 .5339 m .7249 .53142 L .72468 .52868 L F
.72681 .50313 m .72675 .50391 L .72686 .50219 L .832 .697 .161 r
F
.72531 .53211 m .72675 .50391 L .72681 .50313 L F
.71299 .50206 m .7154 .52027 L .71673 .52394 L .889 .605 .093 r
F
.72481 .54354 m .72531 .53211 L .72662 .51405 L .855 .65 .625 r
F
.7237 .56157 m .72492 .53934 L .72481 .54354 L F
.72492 .53934 m .72531 .53211 L .72481 .54354 L F
.71721 .54498 m .71357 .52466 L .71763 .54263 L 0 0 .344 r
F
.72569 .5544 m .7237 .56157 L .72662 .51405 L .993 .776 .402 r
F
.72022 .55418 m .72422 .5642 L .72618 .55534 L 0 0 .317 r
F
.72257 .55386 m .72027 .55417 L .72178 .55447 L .307 0 0 r
F
.72027 .55417 m .72022 .55418 L .72028 .55419 L F
.72027 .55417 m .72028 .55419 L .72618 .55534 L F
.72022 .55418 m .71721 .54498 L .71975 .55194 L 0 0 .317 r
F
.72035 .55451 m .71975 .55194 L .72422 .5642 L F
.72022 .55418 m .71975 .55194 L .72035 .55451 L F
.71721 .54498 m .7203 .55561 L .72091 .55513 L 0 0 .344 r
F
.7203 .55561 m .72147 .55964 L .72091 .55513 L F
.71981 .55393 m .71763 .54263 L .72147 .55964 L F
.71721 .54498 m .71763 .54263 L .71981 .55393 L F
.71361 .52484 m .71811 .54489 L .71859 .54697 L 0 0 .267 r
F
.71901 .54878 m .71859 .54697 L .72066 .5561 L F
.71361 .52484 m .71859 .54697 L .71901 .54878 L F
.72091 .55513 m .72147 .55964 L .72422 .5642 L 0 0 .344 r
F
.72267 .55385 m .72257 .55386 L .72618 .55534 L .307 0 0 r
F
.72257 .55386 m .72178 .55447 L .72618 .55534 L F
.72062 .5559 m .72066 .5561 L .72147 .55964 L 0 0 .267 r
F
.71361 .52484 m .72066 .5561 L .72062 .5559 L F
.71205 .51374 m .71456 .52637 L .71811 .54489 L 0 0 .201 r
F
.70984 .50238 m .71085 .50753 L .71205 .51374 L F
.71085 .50753 m .71456 .52637 L .71205 .51374 L F
.71357 .52466 m .7136 .52479 L .71361 .52484 L 0 0 .267 r
F
.7136 .52479 m .71811 .54489 L .71361 .52484 L F
.70282 .46497 m .70692 .47901 L .71059 .50029 L .77 .435 0 r
F
.69944 .48238 m .69991 .45703 L .70282 .46497 L .908 .748 .253 r
F
.70314 .46643 m .70282 .46497 L .70308 .46615 L 0 0 .173 r
F
.70282 .46497 m .69991 .45703 L .70453 .47153 L .77 .435 0 r
F
.70579 .47516 m .70453 .47153 L .70692 .47901 L F
.70282 .46497 m .70453 .47153 L .70579 .47516 L F
.69991 .45703 m .70419 .46454 L .70313 .46713 L .551 0 0 r
F
.69856 .48295 m .69991 .45703 L .69944 .48238 L .908 .748 .253 r
F
.69827 .48839 m .69644 .50169 L .69904 .4682 L F
.69903 .47384 m .69904 .4682 L .69991 .45703 L F
.69827 .48839 m .69904 .4682 L .69903 .47384 L F
.6974 .4567 m .69835 .45374 L .69906 .45581 L .689 .741 .235 r
F
.69644 .50169 m .6974 .4567 L .69991 .45703 L .964 .759 .316 r
F
.69906 .45692 m .6974 .4567 L .69906 .4577 L .551 0 0 r
F
.69906 .45692 m .69906 .4577 L .7034 .46031 L F
.69991 .45703 m .69906 .45692 L .7034 .46031 L F
.69906 .4577 m .69906 .45581 L .6999 .4582 L .689 .741 .235 r
F
.6974 .4567 m .69906 .45581 L .69906 .4577 L F
.6999 .4582 m .70023 .44787 L .7034 .46031 L F
.69835 .45374 m .70023 .44787 L .6999 .4582 L F
.70313 .46713 m .70419 .46454 L .70692 .47901 L .551 0 0 r
F
.69827 .48839 m .69856 .48295 L .69944 .48238 L .908 .748 .253 r
F
.70384 .51419 m .70234 .53301 L .70439 .4848 L .892 .719 .209 r
F
.70384 .51419 m .70439 .4848 L .7045 .48713 L F
.70625 .48093 m .70597 .47926 L .71059 .50029 L 0 0 .173 r
F
.70615 .4805 m .70597 .47926 L .70625 .48093 L F
.70682 .48434 m .70865 .4953 L .70859 .49489 L .951 .598 .255 r
F
.70681 .48428 m .70865 .4953 L .70682 .48434 L F
.70865 .4953 m .713 .52127 L .70859 .49489 L F
.70947 .50018 m .70984 .50238 L .70865 .4953 L F
.7095 .5009 m .7096 .50098 L .70984 .50238 L .686 .307 .324 r
F
.70384 .51419 m .70432 .49546 L .70604 .49977 L .892 .719 .209 r
F
.70423 .53658 m .70454 .52283 L .70489 .5233 L .791 .574 .607 r
F
.71296 .52105 m .713 .52127 L .71357 .52466 L .951 .598 .255 r
F
.70924 .53777 m .70932 .52506 L .71037 .52703 L .995 .759 .42 r
F
.44051 .4911 m .44275 .48628 L .44582 .4894 L .664 .741 .908 r
F
.44051 .4911 m .43744 .48798 L .44275 .48628 L F
.36386 .49097 m .36588 .48615 L .36909 .48928 L F
.36386 .49097 m .36065 .48785 L .36588 .48615 L F
.45417 .49084 m .45645 .48602 L .45949 .48916 L .663 .741 .908 r
F
.45417 .49084 m .45113 .48771 L .45645 .48602 L F
.37751 .49071 m .37957 .48589 L .38275 .48903 L F
.37751 .49071 m .37432 .48759 L .37957 .48589 L F
.30083 .49059 m .30268 .48576 L .306 .48889 L F
.30083 .49059 m .29751 .48745 L .30268 .48576 L F
.46784 .4906 m .47015 .48576 L .47317 .4889 L .664 .74 .907 r
F
.46784 .4906 m .46481 .48746 L .47015 .48576 L F
.55333 .52868 m .55034 .51116 L .55571 .50435 L .676 .503 .645 r
F
.55571 .50435 m .55847 .51963 L .5612 .50906 L .885 .552 .054 r
F
.55034 .51116 m .5528 .49584 L .55571 .50435 L .685 .547 .692 r
F
.55571 .50435 m .5528 .49584 L .55847 .51963 L .885 .552 .054 r
F
.39116 .49045 m .39326 .48563 L .39642 .48876 L .664 .742 .908 r
F
.39116 .49045 m .388 .48733 L .39326 .48563 L F
.55034 .51116 m .54742 .5004 L .5528 .49584 L .685 .547 .692 r
F
.54742 .5004 m .54994 .49381 L .5528 .49584 L .652 .642 .827 r
F
.54742 .5004 m .54453 .49543 L .54994 .49381 L F
.54206 .50928 m .54453 .49543 L .54742 .5004 L .924 .848 .403 r
F
.31448 .49032 m .31636 .4855 L .31966 .48863 L .664 .741 .908 r
F
.31448 .49032 m .31118 .48719 L .31636 .4855 L F
.4815 .49032 m .48386 .48549 L .48685 .48862 L F
.4815 .49032 m .47851 .48719 L .48386 .48549 L F
.62545 .57063 m .62253 .56128 L .62798 .55867 L .655 .544 .717 r
F
.62011 .57701 m .62253 .56128 L .62545 .57063 L .411 .293 .608 r
F
.51715 .49305 m .51949 .55687 L .52249 .55155 L .957 .659 .428 r
F
.51715 .49305 m .51422 .4905 L .51949 .55687 L F
.5528 .49584 m .55575 .53412 L .55847 .51963 L .953 .633 .383 r
F
.5528 .49584 m .54994 .49381 L .55575 .53412 L F
.40482 .49019 m .40696 .48536 L .41009 .4885 L .664 .741 .908 r
F
.40482 .49019 m .40168 .48706 L .40696 .48536 L F
.32812 .49006 m .33005 .48524 L .33332 .48837 L .663 .741 .908 r
F
.32812 .49006 m .32485 .48693 L .33005 .48524 L F
.49518 .49006 m .49757 .48525 L .50053 .48839 L .663 .742 .908 r
F
.49518 .49006 m .4922 .48694 L .49757 .48525 L F
.41848 .48993 m .42066 .48512 L .42376 .48825 L .663 .741 .908 r
F
.41848 .48993 m .41537 .48681 L .42066 .48512 L F
.34177 .4898 m .34374 .48497 L .34698 .48811 L F
.34177 .4898 m .33852 .48667 L .34374 .48497 L F
.50885 .48981 m .51127 .48796 L .51422 .4905 L .324 .593 .943 r
F
.50885 .48981 m .5059 .48669 L .51127 .48796 L F
.43215 .48967 m .43436 .48484 L .43744 .48798 L .664 .742 .908 r
F
.43215 .48967 m .42906 .48655 L .43436 .48484 L F
.35543 .48954 m .35743 .48471 L .36065 .48785 L .664 .741 .908 r
F
.35543 .48954 m .3522 .48641 L .35743 .48471 L F
.44582 .4894 m .44807 .48458 L .45113 .48771 L .663 .741 .908 r
F
.44582 .4894 m .44275 .48628 L .44807 .48458 L F
.36909 .48928 m .37113 .48445 L .37432 .48759 L F
.36909 .48928 m .36588 .48615 L .37113 .48445 L F
.45949 .48916 m .46178 .48433 L .46481 .48746 L F
.45949 .48916 m .45645 .48602 L .46178 .48433 L F
.38275 .48903 m .38483 .4842 L .388 .48733 L F
.38275 .48903 m .37957 .48589 L .38483 .4842 L F
.306 .48889 m .30786 .48406 L .31118 .48719 L .664 .742 .908 r
F
.306 .48889 m .30268 .48576 L .30786 .48406 L F
.47317 .4889 m .4755 .48406 L .47851 .48719 L .663 .741 .908 r
F
.47317 .4889 m .47015 .48576 L .4755 .48406 L F
.39642 .48876 m .39853 .48393 L .40168 .48706 L .664 .742 .908 r
F
.39642 .48876 m .39326 .48563 L .39853 .48393 L F
.48685 .48862 m .48922 .4838 L .4922 .48694 L .663 .741 .908 r
F
.48685 .48862 m .48386 .48549 L .48922 .4838 L F
.31966 .48863 m .32156 .48379 L .32485 .48693 L .664 .741 .908 r
F
.31966 .48863 m .31636 .4855 L .32156 .48379 L F
.41009 .4885 m .41224 .48367 L .41537 .48681 L .663 .741 .908 r
F
.41009 .4885 m .40696 .48536 L .41224 .48367 L F
.59155 .51671 m .58851 .50181 L .59451 .52627 L 0 0 .303 r
F
.58851 .50181 m .5913 .50387 L .59451 .52627 L 0 .076 .62 r
F
.58851 .50181 m .58569 .49797 L .5913 .50387 L F
.58356 .53159 m .58569 .49797 L .58851 .50181 L .965 .788 .352 r
F
.33332 .48837 m .33526 .48354 L .33852 .48667 L .664 .742 .908 r
F
.33332 .48837 m .33005 .48524 L .33526 .48354 L F
.50053 .48839 m .50294 .48357 L .5059 .48669 L .662 .74 .908 r
F
.50053 .48839 m .49757 .48525 L .50294 .48357 L F
.54037 .70035 m .53732 .69777 L .54206 .50928 L .957 .697 .501 r
F
.54206 .50928 m .53921 .51698 L .54453 .49543 L .924 .848 .403 r
F
.54453 .49543 m .54711 .49827 L .54994 .49381 L .503 0 0 r
F
.53921 .51698 m .54166 .49655 L .54453 .49543 L .944 .818 .37 r
F
.54453 .49543 m .54166 .49655 L .54711 .49827 L .503 0 0 r
F
.42376 .48825 m .42596 .48341 L .42906 .48655 L .664 .742 .908 r
F
.42376 .48825 m .42066 .48512 L .42596 .48341 L F
.34698 .48811 m .34896 .48327 L .3522 .48641 L .664 .741 .908 r
F
.34698 .48811 m .34374 .48497 L .34896 .48327 L F
.43744 .48798 m .43968 .48314 L .44275 .48628 L .664 .742 .908 r
F
.43744 .48798 m .43436 .48484 L .43968 .48314 L F
.36065 .48785 m .36267 .48301 L .36588 .48615 L .664 .741 .908 r
F
.36065 .48785 m .35743 .48471 L .36267 .48301 L F
.45113 .48771 m .4534 .48289 L .45645 .48602 L .663 .741 .908 r
F
.45113 .48771 m .44807 .48458 L .4534 .48289 L F
.37432 .48759 m .37638 .48275 L .37957 .48589 L .664 .741 .908 r
F
.37432 .48759 m .37113 .48445 L .37638 .48275 L F
.58133 .56125 m .57823 .54234 L .58218 .53438 L .709 .522 .634 r
F
.58322 .53621 m .58218 .53438 L .58356 .53159 L F
.58133 .56125 m .58218 .53438 L .58322 .53621 L F
.57823 .54234 m .58101 .54563 L .58356 .53159 L 0 0 .465 r
F
.57823 .54234 m .57779 .53934 L .58032 .54271 L F
.57779 .53934 m .57509 .52061 L .57835 .53436 L F
.57779 .53934 m .57835 .53436 L .58032 .54271 L F
.58037 .54488 m .58032 .54271 L .58101 .54563 L F
.57823 .54234 m .58032 .54271 L .58037 .54488 L F
.5753 .52763 m .57823 .54234 L .58094 .55885 L .565 .275 .434 r
F
.5753 .52763 m .58094 .55885 L .58102 .55952 L F
.5753 .52763 m .57271 .54142 L .57823 .54234 L F
.57271 .54142 m .57509 .52061 L .57823 .54234 L .85 .75 .234 r
F
.57558 .52266 m .57827 .55043 L .58101 .54563 L .872 .606 .079 r
F
.57525 .52208 m .57827 .55043 L .57558 .52266 L F
.57009 .5564 m .57203 .50203 L .57509 .52061 L .991 .759 .485 r
F
.57509 .52061 m .57203 .50203 L .577 .5406 L .872 .606 .079 r
F
.57718 .54018 m .577 .5406 L .57827 .55043 L F
.57509 .52061 m .577 .5406 L .57718 .54018 L F
.57203 .50203 m .57541 .54835 L .57827 .55043 L .975 .669 .317 r
F
.57645 .54191 m .57789 .53139 L .5798 .52121 L .727 .579 .688 r
F
.57541 .54835 m .5763 .54228 L .57645 .54191 L F
.5763 .54228 m .57789 .53139 L .57645 .54191 L F
.57963 .52275 m .5798 .52121 L .58048 .5176 L F
.57541 .54835 m .5798 .52121 L .57963 .52275 L F
.57509 .52061 m .57525 .52208 L .57558 .52266 L .872 .606 .079 r
F
.58008 .53318 m .58048 .5176 L .58305 .50486 L .956 .743 .576 r
F
.57901 .54345 m .57993 .5272 L .58008 .53318 L F
.57993 .5272 m .58048 .5176 L .58008 .53318 L F
.57827 .55043 m .57883 .54208 L .57901 .54345 L F
.57883 .54208 m .58048 .5176 L .57901 .54345 L F
.58102 .55952 m .58094 .55885 L .58133 .56125 L .565 .275 .434 r
F
.29751 .48745 m .29935 .48262 L .30268 .48576 L .663 .741 .908 r
F
.29751 .48745 m .29417 .48431 L .29935 .48262 L F
.46481 .48746 m .46712 .48264 L .47015 .48576 L F
.46481 .48746 m .46178 .48433 L .46712 .48264 L F
.388 .48733 m .3901 .48249 L .39326 .48563 L .664 .741 .908 r
F
.388 .48733 m .38483 .4842 L .3901 .48249 L F
.47851 .48719 m .48085 .48235 L .48386 .48549 L .664 .742 .908 r
F
.47851 .48719 m .4755 .48406 L .48085 .48235 L F
.31118 .48719 m .31306 .48235 L .31636 .4855 L .663 .741 .908 r
F
.31118 .48719 m .30786 .48406 L .31306 .48235 L F
.40168 .48706 m .40382 .48222 L .40696 .48536 L F
.40168 .48706 m .39853 .48393 L .40382 .48222 L F
.74478 .54469 m .74468 .49131 L .74761 .50061 L .76 .54 .599 r
F
.74761 .50061 m .74468 .49131 L .75732 .61483 L .977 .676 .361 r
F
.75759 .61396 m .75732 .61483 L .75983 .63938 L F
.74761 .50061 m .75732 .61483 L .75759 .61396 L F
.74468 .49131 m .7597 .66357 L .76179 .65858 L .967 .666 .4 r
F
.74478 .54469 m .74064 .51709 L .74468 .49131 L .76 .54 .599 r
F
.74064 .51709 m .74238 .49155 L .74468 .49131 L .637 .467 .636 r
F
.74468 .49131 m .74238 .49155 L .7597 .66357 L .967 .666 .4 r
F
.74238 .49155 m .75724 .66325 L .7597 .66357 L .951 .651 .431 r
F
.74064 .51709 m .73694 .49608 L .74238 .49155 L .637 .467 .636 r
F
.74238 .49155 m .74071 .50187 L .75724 .66325 L .951 .651 .431 r
F
.73842 .5354 m .74064 .51709 L .74478 .54469 L .495 .361 .628 r
F
.74071 .50187 m .75436 .65676 L .75724 .66325 L .937 .636 .446 r
F
.73451 .51083 m .73694 .49608 L .74064 .51709 L .541 .417 .66 r
F
.73842 .5354 m .73451 .51083 L .74064 .51709 L .495 .361 .628 r
F
.74071 .50187 m .73936 .51742 L .75436 .65676 L .937 .636 .446 r
F
.73936 .51742 m .75113 .64511 L .75436 .65676 L .91 .611 .465 r
F
.751 .63492 m .74826 .5474 L .74972 .53356 L .908 .647 .532 r
F
.75113 .64511 m .75085 .63541 L .751 .63492 L F
.75085 .63541 m .74826 .5474 L .751 .63492 L F
.74761 .50061 m .75983 .63938 L .75997 .63925 L .977 .676 .361 r
F
.74761 .50061 m .76101 .65092 L .76109 .6509 L F
.74761 .50061 m .7617 .65765 L .76171 .65766 L F
.74761 .50061 m .76179 .65858 L .76366 .6507 L F
.75409 .64463 m .74972 .53356 L .75142 .52375 L .953 .683 .487 r
F
.75436 .65676 m .75391 .6448 L .75409 .64463 L F
.75391 .6448 m .74972 .53356 L .75409 .64463 L F
.75997 .63925 m .75983 .63938 L .76101 .65092 L .977 .676 .361 r
F
.76109 .6509 m .76101 .65092 L .7617 .65765 L F
.75693 .65192 m .75142 .52375 L .75319 .51529 L .967 .694 .463 r
F
.75724 .66325 m .75677 .65196 L .75693 .65192 L F
.75677 .65196 m .75142 .52375 L .75693 .65192 L F
.75949 .65651 m .75319 .51529 L .75511 .50945 L .977 .704 .44 r
F
.7597 .66357 m .75939 .65646 L .75949 .65651 L F
.75939 .65646 m .75319 .51529 L .75949 .65651 L F
.76171 .65766 m .7617 .65765 L .76179 .65858 L .977 .676 .361 r
F
.32485 .48693 m .32677 .48209 L .33005 .48524 L .663 .741 .908 r
F
.32485 .48693 m .32156 .48379 L .32677 .48209 L F
.4922 .48694 m .49459 .4821 L .49757 .48525 L F
.4922 .48694 m .48922 .4838 L .49459 .4821 L F
.58434 .5737 m .58133 .56125 L .5861 .51887 L .889 .655 .578 r
F
.51422 .4905 m .51647 .56251 L .51949 .55687 L .957 .662 .435 r
F
.51422 .4905 m .51127 .48796 L .51647 .56251 L F
.41537 .48681 m .41754 .48196 L .42066 .48512 L .663 .741 .908 r
F
.41537 .48681 m .41224 .48367 L .41754 .48196 L F
.33852 .48667 m .34048 .48183 L .34374 .48497 L .664 .742 .908 r
F
.33852 .48667 m .33526 .48354 L .34048 .48183 L F
.5059 .48669 m .50831 .48546 L .51127 .48796 L .208 .528 .921 r
F
.5059 .48669 m .50294 .48357 L .50831 .48546 L F
.42906 .48655 m .43127 .4817 L .43436 .48484 L .664 .742 .908 r
F
.42906 .48655 m .42596 .48341 L .43127 .4817 L F
.54994 .49381 m .55297 .54623 L .55575 .53412 L .92 .614 .447 r
F
.54994 .49381 m .54711 .49827 L .55297 .54623 L F
.3522 .48641 m .3542 .48157 L .35743 .48471 L .664 .741 .908 r
F
.3522 .48641 m .34896 .48327 L .3542 .48157 L F
.76387 .48687 m .76699 .4817 L .76948 .48485 L .685 .749 .9 r
F
.76387 .48687 m .76137 .48373 L .76699 .4817 L F
.75934 .50415 m .76137 .48373 L .76387 .48687 L .999 .834 .503 r
F
.44275 .48628 m .445 .48144 L .44807 .48458 L .663 .741 .908 r
F
.44275 .48628 m .43968 .48314 L .445 .48144 L F
.36588 .48615 m .36792 .48131 L .37113 .48445 L F
.36588 .48615 m .36267 .48301 L .36792 .48131 L F
.73451 .51083 m .7311 .49396 L .73694 .49608 L .541 .417 .66 r
F
.7311 .49396 m .73397 .48617 L .73694 .49608 L .855 .841 .831 r
F
.7311 .49396 m .7286 .49179 L .73397 .48617 L F
.45645 .48602 m .45874 .4812 L .46178 .48433 L .662 .741 .909 r
F
.45645 .48602 m .4534 .48289 L .45874 .4812 L F
.37957 .48589 m .38164 .48104 L .38483 .4842 L .664 .741 .908 r
F
.37957 .48589 m .37638 .48275 L .38164 .48104 L F
.47015 .48576 m .47248 .48092 L .4755 .48406 L .664 .743 .908 r
F
.47015 .48576 m .46712 .48264 L .47248 .48092 L F
.30268 .48576 m .30454 .48091 L .30786 .48406 L .664 .741 .908 r
F
.30268 .48576 m .29935 .48262 L .30454 .48091 L F
.58356 .53159 m .58101 .54563 L .58569 .49797 L .965 .788 .352 r
F
.58569 .49797 m .58829 .49029 L .5913 .50387 L .715 .774 .282 r
F
.58569 .49797 m .58305 .50486 L .58829 .49029 L F
.58101 .54563 m .58305 .50486 L .58569 .49797 L .994 .775 .495 r
F
.67483 .54771 m .67134 .52583 L .67789 .54629 L .119 .104 .564 r
F
.39326 .48563 m .39537 .48078 L .39853 .48393 L .664 .741 .908 r
F
.39326 .48563 m .3901 .48249 L .39537 .48078 L F
.48386 .48549 m .48622 .48065 L .48922 .4838 L .663 .741 .908 r
F
.48386 .48549 m .48085 .48235 L .48622 .48065 L F
.31636 .4855 m .31826 .48064 L .32156 .48379 L .664 .741 .908 r
F
.31636 .4855 m .31306 .48235 L .31826 .48064 L F
.60078 .56487 m .59786 .55677 L .59976 .55789 L .41 .42 .76 r
F
.60129 .56397 m .59976 .55789 L .60349 .56007 L F
.60078 .56487 m .59976 .55789 L .60129 .56397 L F
.59786 .55677 m .60079 .56209 L .60349 .56007 L 0 0 .441 r
F
.59908 .54871 m .60023 .53372 L .60322 .54459 L .454 .331 .622 r
F
.59786 .55677 m .59472 .53764 L .60055 .56111 L 0 0 .441 r
F
.59472 .53764 m .59667 .54556 L .59788 .55038 L 0 0 .29 r
F
.59777 .55001 m .59859 .54458 L .59908 .54871 L .454 .331 .622 r
F
.59859 .54458 m .60023 .53372 L .59908 .54871 L F
.60063 .5618 m .60055 .56111 L .60079 .56209 L 0 0 .441 r
F
.59786 .55677 m .60055 .56111 L .60063 .5618 L F
.59788 .55038 m .59777 .55001 L .60079 .56209 L 0 0 .29 r
F
.59667 .54556 m .59777 .55001 L .59788 .55038 L F
.59472 .53764 m .59155 .51671 L .59777 .55001 L F
.59155 .51671 m .59451 .52627 L .59777 .55001 L 0 0 .303 r
F
.40696 .48536 m .40911 .48051 L .41224 .48367 L .664 .741 .908 r
F
.40696 .48536 m .40382 .48222 L .40911 .48051 L F
.33005 .48524 m .33198 .48039 L .33526 .48354 L .663 .741 .908 r
F
.33005 .48524 m .32677 .48209 L .33198 .48039 L F
.49757 .48525 m .49997 .48044 L .50294 .48357 L .66 .74 .909 r
F
.49757 .48525 m .49459 .4821 L .49997 .48044 L F
.42066 .48512 m .42285 .48025 L .42596 .48341 L .664 .741 .907 r
F
.42066 .48512 m .41754 .48196 L .42285 .48025 L F
.34374 .48497 m .34571 .48012 L .34896 .48327 L .663 .741 .908 r
F
.34374 .48497 m .34048 .48183 L .34571 .48012 L F
.43436 .48484 m .43659 .47998 L .43968 .48314 L .664 .741 .908 r
F
.43436 .48484 m .43127 .4817 L .43659 .47998 L F
.76948 .48485 m .77264 .47999 L .77512 .48314 L .664 .741 .907 r
F
.76948 .48485 m .76699 .4817 L .77264 .47999 L F
.35743 .48471 m .35944 .47985 L .36267 .48301 L .664 .741 .908 r
F
.35743 .48471 m .3542 .48157 L .35944 .47985 L F
.44807 .48458 m .45033 .47974 L .4534 .48289 L .663 .741 .908 r
F
.44807 .48458 m .445 .48144 L .45033 .47974 L F
.56732 .5625 m .56909 .49205 L .57203 .50203 L .969 .725 .512 r
F
.57009 .5564 m .56732 .5625 L .5711 .51402 L .991 .759 .485 r
F
.57009 .5564 m .5711 .51402 L .57154 .51572 L F
.57009 .5564 m .57203 .50205 L .57203 .50205 L F
.56732 .5625 m .56446 .563 L .56909 .49205 L .969 .725 .512 r
F
.56446 .563 m .56626 .49031 L .56909 .49205 L .936 .69 .542 r
F
.56758 .50059 m .56934 .52124 L .57242 .53814 L .866 .541 .435 r
F
.56626 .49031 m .5671 .49874 L .56758 .50059 L F
.5671 .49874 m .56934 .52124 L .56758 .50059 L F
.57154 .51572 m .5711 .51402 L .57203 .50205 L .991 .759 .485 r
F
.57203 .50205 m .57203 .50205 L .57203 .50203 L F
.56994 .49964 m .57242 .53814 L .57541 .54835 L .954 .64 .394 r
F
.56909 .49205 m .56961 .49926 L .56994 .49964 L F
.56961 .49926 m .57242 .53814 L .56994 .49964 L F
.57203 .50203 m .56909 .49205 L .57541 .54835 L .975 .669 .317 r
F
.56909 .49205 m .56626 .49031 L .57242 .53814 L .954 .64 .394 r
F
.37113 .48445 m .37318 .4796 L .37638 .48275 L .663 .741 .908 r
F
.37113 .48445 m .36792 .48131 L .37318 .4796 L F
.60566 .54213 m .60349 .56007 L .60699 .54109 L 0 0 .144 r
F
.60566 .54213 m .60699 .54109 L .60839 .53346 L F
.60667 .54281 m .60591 .54292 L .60839 .53346 L .995 .851 .582 r
F
.60349 .56007 m .60591 .54292 L .60667 .54281 L F
.60591 .54292 m .60322 .54459 L .60515 .54304 L .559 .901 .67 r
F
.60591 .54292 m .60869 .54021 L .60941 .5392 L F
.60591 .54292 m .60941 .5392 L .60839 .54 L F
.60839 .53346 m .60591 .54292 L .61131 .53654 L .239 0 .265 r
F
.60591 .54292 m .60515 .54304 L .60869 .54021 L .559 .901 .67 r
F
.60839 .54 m .60941 .5392 L .61131 .53654 L F
.60576 .54127 m .60566 .54213 L .60839 .53346 L 0 0 .144 r
F
.29417 .48431 m .29601 .47946 L .29935 .48262 L .664 .742 .908 r
F
.29417 .48431 m .29082 .48118 L .29601 .47946 L F
.46178 .48433 m .46409 .47948 L .46712 .48264 L .665 .743 .909 r
F
.46178 .48433 m .45874 .4812 L .46409 .47948 L F
.38483 .4842 m .38692 .47933 L .3901 .48249 L .663 .741 .908 r
F
.38483 .4842 m .38164 .48104 L .38692 .47933 L F
.30786 .48406 m .30974 .4792 L .31306 .48235 L F
.30786 .48406 m .30454 .48091 L .30974 .4792 L F
.4755 .48406 m .47784 .47919 L .48085 .48235 L .664 .742 .908 r
F
.4755 .48406 m .47248 .48092 L .47784 .47919 L F
.39853 .48393 m .40066 .47907 L .40382 .48222 L .663 .741 .908 r
F
.39853 .48393 m .39537 .48078 L .40066 .47907 L F
.32156 .48379 m .32347 .47893 L .32677 .48209 L .664 .741 .908 r
F
.32156 .48379 m .31826 .48064 L .32347 .47893 L F
.48922 .4838 m .4916 .47895 L .49459 .4821 L .663 .741 .908 r
F
.48922 .4838 m .48622 .48065 L .4916 .47895 L F
.41224 .48367 m .41441 .4788 L .41754 .48196 L F
.41224 .48367 m .40911 .48051 L .41441 .4788 L F
.33526 .48354 m .33721 .47867 L .34048 .48183 L .664 .742 .908 r
F
.33526 .48354 m .33198 .48039 L .33721 .47867 L F
.50294 .48357 m .50534 .48311 L .50831 .48546 L .049 .428 .869 r
F
.50294 .48357 m .49997 .48044 L .50534 .48311 L F
.51127 .48796 m .51343 .56795 L .51647 .56251 L .957 .664 .44 r
F
.51127 .48796 m .50831 .48546 L .51343 .56795 L F
.42596 .48341 m .42816 .47854 L .43127 .4817 L .664 .741 .907 r
F
.42596 .48341 m .42285 .48025 L .42816 .47854 L F
.34896 .48327 m .35095 .47841 L .3542 .48157 L .664 .741 .908 r
F
.34896 .48327 m .34571 .48012 L .35095 .47841 L F
.75934 .50415 m .75721 .50639 L .76137 .48373 L .999 .834 .503 r
F
.76137 .48373 m .7645 .47855 L .76699 .4817 L .697 .766 .905 r
F
.76137 .48373 m .75889 .48078 L .7645 .47855 L F
.75721 .50639 m .75889 .48078 L .76137 .48373 L .999 .81 .467 r
F
.43968 .48314 m .44192 .47828 L .445 .48144 L .663 .741 .908 r
F
.43968 .48314 m .43659 .47998 L .44192 .47828 L F
.77512 .48314 m .7783 .47828 L .78077 .48144 L F
.77512 .48314 m .77264 .47999 L .7783 .47828 L F
.36267 .48301 m .3647 .47815 L .36792 .48131 L F
.36267 .48301 m .35944 .47985 L .3647 .47815 L F
.53921 .51698 m .53635 .52772 L .54166 .49655 L .944 .818 .37 r
F
.54166 .49655 m .54428 .50684 L .54711 .49827 L .709 .326 .322 r
F
.53635 .52772 m .53879 .50132 L .54166 .49655 L .976 .814 .4 r
F
.54166 .49655 m .53879 .50132 L .54428 .50684 L .709 .326 .322 r
F
.4534 .48289 m .45568 .47803 L .45874 .4812 L .663 .742 .908 r
F
.4534 .48289 m .45033 .47974 L .45568 .47803 L F
.73694 .49608 m .74071 .50187 L .74238 .49155 L 0 0 .501 r
F
.73694 .49608 m .73397 .48617 L .74071 .50187 L F
.73397 .48617 m .73936 .51742 L .74071 .50187 L .926 .575 .347 r
F
.7286 .49179 m .73173 .48801 L .73397 .48617 L 0 0 .163 r
F
.73397 .48617 m .73173 .48801 L .73936 .51742 L .926 .575 .347 r
F
.37638 .48275 m .37845 .47788 L .38164 .48104 L .664 .742 .908 r
F
.37638 .48275 m .37318 .4796 L .37845 .47788 L F
.29935 .48262 m .3012 .47775 L .30454 .48091 L .663 .741 .908 r
F
.29935 .48262 m .29601 .47946 L .3012 .47775 L F
.46712 .48264 m .46945 .47775 L .47248 .48092 L .665 .742 .907 r
F
.46712 .48264 m .46409 .47948 L .46945 .47775 L F
.3901 .48249 m .3922 .47762 L .39537 .48078 L .664 .741 .908 r
F
.3901 .48249 m .38692 .47933 L .3922 .47762 L F
.72662 .51405 m .72531 .53211 L .7286 .49179 L 0 0 0 r
F
.72531 .53211 m .72686 .50219 L .7286 .49179 L .832 .697 .161 r
F
.7286 .49179 m .72686 .50219 L .73173 .48801 L 0 0 .163 r
F
.5913 .50387 m .58829 .49029 L .59404 .50179 L .129 .155 .619 r
F
.58829 .49029 m .59107 .49136 L .59404 .50179 L 0 .314 .7 r
F
.58829 .49029 m .5855 .48873 L .59107 .49136 L F
.58305 .50486 m .5855 .48873 L .58829 .49029 L .803 .739 .215 r
F
.48085 .48235 m .48321 .47749 L .48622 .48065 L .663 .741 .908 r
F
.48085 .48235 m .47784 .47919 L .48321 .47749 L F
.31306 .48235 m .31495 .47748 L .31826 .48064 L .664 .741 .908 r
F
.31306 .48235 m .30974 .4792 L .31495 .47748 L F
.40382 .48222 m .40596 .47736 L .40911 .48051 L .663 .741 .908 r
F
.40382 .48222 m .40066 .47907 L .40596 .47736 L F
.32677 .48209 m .32869 .47723 L .33198 .48039 L F
.32677 .48209 m .32347 .47893 L .32869 .47723 L F
.49459 .4821 m .49699 .47731 L .49997 .48044 L .658 .74 .91 r
F
.49459 .4821 m .4916 .47895 L .49699 .47731 L F
.41754 .48196 m .41972 .47709 L .42285 .48025 L .663 .741 .908 r
F
.41754 .48196 m .41441 .4788 L .41972 .47709 L F
.34048 .48183 m .34245 .47696 L .34571 .48012 L F
.34048 .48183 m .33721 .47867 L .34245 .47696 L F
.61377 .52736 m .617 .54074 L .61948 .53304 L .644 .317 .403 r
F
.61377 .52736 m .61131 .53654 L .617 .54074 L F
.60839 .53346 m .61131 .53654 L .61377 .52736 L .239 0 .265 r
F
.43127 .4817 m .43349 .47682 L .43659 .47998 L .664 .741 .908 r
F
.43127 .4817 m .42816 .47854 L .43349 .47682 L F
.76699 .4817 m .77015 .47682 L .77264 .47999 L .665 .742 .908 r
F
.76699 .4817 m .7645 .47855 L .77015 .47682 L F
.57534 .69214 m .57219 .67117 L .57683 .60884 L .873 .631 .57 r
F
.57219 .67117 m .57425 .6242 L .57683 .60884 L .738 .53 .611 r
F
.3542 .48157 m .3562 .47669 L .35944 .47985 L .664 .741 .908 r
F
.3542 .48157 m .35095 .47841 L .3562 .47669 L F
.68003 .53807 m .67789 .54629 L .68304 .5352 L 0 0 .079 r
F
.78077 .48144 m .78398 .47657 L .78644 .47974 L .663 .741 .908 r
F
.78077 .48144 m .7783 .47828 L .78398 .47657 L F
.445 .48144 m .44726 .47657 L .45033 .47974 L F
.445 .48144 m .44192 .47828 L .44726 .47657 L F
.36792 .48131 m .36996 .47644 L .37318 .4796 L F
.36792 .48131 m .3647 .47815 L .36996 .47644 L F
.29082 .48118 m .29265 .47629 L .29601 .47946 L .664 .742 .908 r
F
.29082 .48118 m .28746 .47802 L .29265 .47629 L F
.45874 .4812 m .46104 .4763 L .46409 .47948 L .665 .741 .907 r
F
.45874 .4812 m .45568 .47803 L .46104 .4763 L F
.38164 .48104 m .38373 .47617 L .38692 .47933 L .664 .741 .908 r
F
.38164 .48104 m .37845 .47788 L .38373 .47617 L F
.30454 .48091 m .30641 .47603 L .30974 .4792 L F
.30454 .48091 m .3012 .47775 L .30641 .47603 L F
.47248 .48092 m .47482 .47603 L .47784 .47919 L .664 .741 .907 r
F
.47248 .48092 m .46945 .47775 L .47482 .47603 L F
.57387 .60638 m .57595 .56381 L .57908 .58596 L .888 .665 .595 r
F
.57387 .60638 m .57091 .59664 L .57595 .56381 L F
.39537 .48078 m .3975 .4759 L .40066 .47907 L .663 .741 .908 r
F
.39537 .48078 m .3922 .47762 L .3975 .4759 L F
.31826 .48064 m .32017 .47577 L .32347 .47893 L .664 .741 .908 r
F
.31826 .48064 m .31495 .47748 L .32017 .47577 L F
.48622 .48065 m .4886 .47579 L .4916 .47895 L .663 .741 .908 r
F
.48622 .48065 m .48321 .47749 L .4886 .47579 L F
.56446 .563 m .5615 .55554 L .56626 .49031 L .936 .69 .542 r
F
.56626 .49031 m .56351 .49666 L .56915 .52044 L .866 .541 .435 r
F
.55847 .51963 m .55575 .53412 L .5615 .55554 L .784 .485 .482 r
F
.5615 .55554 m .55846 .54069 L .56351 .49666 L .878 .643 .579 r
F
.56626 .49031 m .56915 .52044 L .56928 .52068 L .866 .541 .435 r
F
.56351 .49666 m .56628 .50533 L .56934 .52124 L .482 .168 .357 r
F
.55846 .54069 m .56077 .50674 L .56313 .49807 L .789 .586 .625 r
F
.56328 .49864 m .56313 .49807 L .56351 .49666 L F
.55846 .54069 m .56313 .49807 L .56328 .49864 L F
.56351 .49666 m .56313 .49807 L .56628 .50533 L .482 .168 .357 r
F
.56313 .49807 m .56077 .50674 L .56432 .50584 L F
.56313 .49807 m .56432 .50584 L .56628 .50533 L F
.56155 .50654 m .56325 .49033 L .56628 .50533 L .818 .75 .231 r
F
.56096 .50547 m .56325 .49033 L .56155 .50654 L F
.55846 .54069 m .55543 .5252 L .56018 .50877 L .789 .586 .625 r
F
.56063 .50877 m .56018 .50877 L .56077 .50674 L F
.55846 .54069 m .56018 .50877 L .56063 .50877 L F
.55543 .5252 m .55803 .51983 L .56077 .50674 L .228 .198 .615 r
F
.55543 .5252 m .55239 .50827 L .55803 .51983 L F
.54711 .49827 m .55012 .55483 L .55297 .54623 L .897 .596 .468 r
F
.55012 .55483 m .55239 .50827 L .55543 .5252 L .989 .763 .505 r
F
.55575 .53412 m .55846 .54069 L .5615 .55554 L .348 .068 .339 r
F
.55575 .53412 m .55297 .54623 L .55846 .54069 L F
.55297 .54623 m .55543 .5252 L .55846 .54069 L .972 .832 .421 r
F
.55297 .54623 m .55012 .55483 L .55543 .5252 L F
.55267 .50884 m .55522 .52973 L .55803 .51983 L .854 .576 .04 r
F
.55239 .50827 m .55247 .50885 L .55267 .50884 L F
.55247 .50885 m .55522 .52973 L .55267 .50884 L F
.55803 .51983 m .56028 .47991 L .56325 .49033 L .998 .791 .442 r
F
.55803 .51983 m .55522 .52973 L .55873 .49517 L F
.55922 .49866 m .55873 .49517 L .56028 .47991 L F
.55803 .51983 m .55873 .49517 L .55922 .49866 L F
.55522 .52973 m .55736 .47489 L .56028 .47991 L .992 .76 .483 r
F
.54711 .49827 m .54428 .50684 L .55012 .55483 L .897 .596 .468 r
F
.54428 .50684 m .54721 .55907 L .55012 .55483 L .862 .563 .48 r
F
.54721 .55907 m .54938 .49355 L .55239 .50827 L .96 .718 .527 r
F
.55012 .55483 m .54721 .55907 L .55239 .50827 L .989 .763 .505 r
F
.55239 .50827 m .54938 .49355 L .55485 .5274 L .854 .576 .04 r
F
.555 .52801 m .55485 .5274 L .55522 .52973 L F
.55239 .50827 m .55485 .5274 L .555 .52801 L F
.54428 .50684 m .54144 .5191 L .54721 .55907 L .862 .563 .48 r
F
.54144 .5191 m .54425 .55733 L .54721 .55907 L .821 .516 .474 r
F
.54425 .55733 m .54641 .48285 L .54938 .49355 L .944 .698 .535 r
F
.54721 .55907 m .54425 .55733 L .54938 .49355 L .96 .718 .527 r
F
.54938 .49355 m .54641 .48285 L .55122 .52597 L .974 .668 .301 r
F
.54144 .5191 m .53856 .53136 L .54425 .55733 L .821 .516 .474 r
F
.53856 .53136 m .54125 .5516 L .54425 .55733 L .701 .386 .441 r
F
.54425 .55733 m .54125 .5516 L .54641 .48285 L .944 .698 .535 r
F
.54641 .48285 m .54944 .54001 L .55235 .53608 L .973 .67 .373 r
F
.53879 .50132 m .54144 .5191 L .54428 .50684 L .742 .409 .417 r
F
.54125 .5516 m .54346 .47538 L .54641 .48285 L .93 .684 .544 r
F
.54641 .48285 m .54346 .47538 L .54758 .51996 L .973 .67 .373 r
F
.54836 .51976 m .54758 .51996 L .54944 .54001 L F
.54641 .48285 m .54758 .51996 L .54836 .51976 L F
.53635 .52772 m .53345 .53889 L .53879 .50132 L .976 .814 .4 r
F
.53345 .53889 m .53591 .50948 L .53879 .50132 L .981 .809 .404 r
F
.53879 .50132 m .53591 .50948 L .54144 .5191 L .742 .409 .417 r
F
.53591 .50948 m .53856 .53136 L .54144 .5191 L .763 .439 .438 r
F
.53132 .53819 m .5284 .54174 L .53426 .69612 L .947 .665 .472 r
F
.5284 .54174 m .53118 .68809 L .53426 .69612 L .944 .661 .473 r
F
.53426 .69612 m .53118 .68809 L .53635 .52772 L .948 .689 .512 r
F
.53118 .68809 m .53345 .53889 L .53635 .52772 L .942 .685 .519 r
F
.53856 .53136 m .53564 .54292 L .54125 .5516 L .701 .386 .441 r
F
.54125 .5516 m .53824 .54255 L .54346 .47538 L .93 .684 .544 r
F
.54346 .47538 m .54645 .53711 L .54944 .54001 L .963 .66 .404 r
F
.53824 .54255 m .54052 .4717 L .54346 .47538 L .918 .674 .554 r
F
.54346 .47538 m .54052 .4717 L .54645 .53711 L .963 .66 .404 r
F
.54645 .53704 m .54344 .53076 L .54645 .53711 L .951 .645 .42 r
F
.54052 .4717 m .54344 .53076 L .54645 .53704 L F
.53345 .53889 m .53052 .5507 L .53591 .5095 L .981 .809 .404 r
F
.53591 .50949 m .53591 .5095 L .53591 .50948 L F
.53345 .53889 m .53591 .5095 L .53591 .50949 L F
.5284 .54174 m .52546 .54622 L .53118 .68809 L .944 .661 .473 r
F
.53292 .51945 m .53006 .52824 L .533 .51882 L .997 .805 .449 r
F
.52755 .56202 m .52995 .52975 L .53246 .52307 L F
.53052 .5507 m .533 .51882 L .53591 .50948 L .99 .807 .422 r
F
.52546 .54622 m .52809 .67803 L .53118 .68809 L .94 .656 .474 r
F
.52809 .67803 m .53052 .5507 L .53345 .53889 L .938 .683 .526 r
F
.53052 .5507 m .52755 .56202 L .53246 .52307 L .99 .807 .422 r
F
.53273 .52227 m .53246 .52307 L .533 .51882 L F
.53052 .5507 m .53246 .52307 L .53273 .52227 L F
.52546 .54622 m .52249 .55155 L .52809 .67803 L .94 .656 .474 r
F
.52249 .55155 m .52501 .66754 L .52809 .67803 L .938 .652 .472 r
F
.52809 .67803 m .52501 .66754 L .53052 .5507 L .938 .683 .526 r
F
.52501 .66754 m .52755 .56202 L .53052 .5507 L .921 .67 .542 r
F
.52755 .56202 m .52454 .57193 L .52916 .53538 L .997 .805 .449 r
F
.52755 .56202 m .52916 .53538 L .5295 .53469 L F
.52755 .56202 m .52983 .53007 L .52995 .52975 L F
.52992 .52934 m .52708 .53691 L .53006 .52824 L .999 .797 .489 r
F
.52249 .55155 m .51949 .55687 L .52501 .66754 L .938 .652 .472 r
F
.51949 .55687 m .52192 .65342 L .52501 .66754 L .933 .644 .47 r
F
.51949 .55687 m .51647 .56251 L .52192 .65342 L F
.52377 .54639 m .52104 .5499 L .52407 .5442 L .994 .788 .519 r
F
.51843 .58474 m .52072 .55414 L .52261 .5547 L F
.52632 .54267 m .52407 .5442 L .52708 .53691 L .998 .794 .504 r
F
.5215 .57891 m .52372 .54902 L .5256 .54809 L F
.52261 .5547 m .52104 .5499 L .52377 .54639 L .994 .788 .519 r
F
.52072 .55414 m .52104 .5499 L .52261 .5547 L F
.52454 .57193 m .527 .53801 L .52959 .53196 L .999 .797 .489 r
F
.52454 .57193 m .5215 .57891 L .52708 .53691 L F
.5215 .57891 m .51843 .58474 L .52407 .5442 L .998 .794 .504 r
F
.52121 .55026 m .52359 .56118 L .52665 .56184 L .783 .382 .294 r
F
.52104 .5499 m .52113 .5503 L .52121 .55026 L F
.52113 .5503 m .52359 .56118 L .52121 .55026 L F
.5256 .54809 m .52393 .54619 L .52632 .54267 L .998 .794 .504 r
F
.52372 .54902 m .52393 .54619 L .5256 .54809 L F
.52393 .54619 m .52407 .5442 L .52632 .54267 L F
.51647 .56251 m .51885 .63891 L .52192 .65342 L .927 .633 .465 r
F
.51647 .56251 m .51343 .56795 L .51885 .63891 L F
.52089 .55092 m .51798 .55299 L .52104 .5499 L .971 .757 .558 r
F
.51958 .56 m .51798 .55299 L .52089 .55092 L F
.51762 .55787 m .51798 .55299 L .51958 .56 L F
.51882 .6385 m .51579 .62416 L .51885 .63891 L .913 .611 .459 r
F
.51343 .56795 m .51521 .61033 L .51669 .61063 L F
.51343 .56795 m .51035 .57375 L .51579 .62416 L F
.51035 .57375 m .51273 .61 L .51579 .62416 L .892 .574 .439 r
F
.51276 .60985 m .51534 .58931 L .51843 .58474 L .682 .522 .663 r
F
.51273 .61 m .51275 .60985 L .51276 .60985 L F
.51275 .60985 m .51534 .58931 L .51276 .60985 L F
.51669 .61063 m .51579 .62416 L .51882 .6385 L .913 .611 .459 r
F
.51521 .61033 m .51579 .62416 L .51669 .61063 L F
.51579 .62416 m .51273 .61 L .51276 .60985 L .832 .619 .614 r
F
.51579 .62416 m .51276 .60985 L .51843 .58474 L F
.51782 .554 m .5149 .55495 L .51798 .55299 L .965 .754 .569 r
F
.51578 .56698 m .5149 .55495 L .51782 .554 L F
.51431 .5627 m .5149 .55495 L .51578 .56698 L F
.50831 .48546 m .51035 .57375 L .51343 .56795 L .956 .666 .445 r
F
.51035 .57375 m .50725 .57881 L .51273 .61 L .892 .574 .439 r
F
.51105 .57757 m .51181 .55591 L .5149 .55495 L .968 .761 .57 r
F
.50966 .59251 m .50968 .59539 L .51273 .61 L .819 .457 .37 r
F
.50725 .57881 m .50871 .58877 L .50966 .59251 L F
.50871 .58877 m .50968 .59539 L .50966 .59251 L F
.50725 .57881 m .50413 .58304 L .50873 .59327 L F
.50945 .59382 m .50873 .59327 L .50968 .59539 L F
.50725 .57881 m .50873 .59327 L .50945 .59382 L F
.50532 .48311 m .50235 .48086 L .50534 .48311 L 0 .295 .777 r
F
.49997 .48044 m .50235 .48086 L .50532 .48311 L F
.49699 .47731 m .49936 .47834 L .50235 .48086 L 0 .195 .695 r
F
.50235 .48086 m .49936 .47834 L .49937 .4786 L .957 .669 .45 r
F
.49997 .48044 m .49699 .47731 L .50235 .48086 L 0 .295 .777 r
F
.50235 .48086 m .49937 .4786 L .50413 .58304 L .957 .669 .45 r
F
.50235 .48086 m .50413 .58304 L .50725 .57881 L F
.49936 .47834 m .50099 .58756 L .50413 .58304 L .957 .67 .452 r
F
.50413 .58304 m .50665 .58057 L .50968 .59539 L 0 0 0 r
F
.50413 .58304 m .50099 .58756 L .50665 .58057 L F
.50106 .58747 m .5036 .56908 L .50665 .58057 L .996 .851 .572 r
F
.50099 .58756 m .501 .58743 L .50106 .58747 L F
.501 .58743 m .5036 .56908 L .50106 .58747 L F
.51025 .59389 m .50665 .58057 L .51203 .58913 L .264 .239 .643 r
F
.50968 .59539 m .50665 .58057 L .51025 .59389 L F
.50968 .59539 m .51203 .58913 L .51209 .58985 L F
.51219 .5894 m .50913 .58886 L .51224 .58948 L 0 0 .225 r
F
.50665 .58057 m .50913 .58886 L .51219 .5894 L F
.50665 .58057 m .50638 .57956 L .50913 .58886 L F
.50638 .57956 m .5036 .56908 L .50494 .57388 L F
.50638 .57956 m .50494 .57388 L .50913 .58886 L F
.5036 .56908 m .506 .58863 L .50913 .58886 L .918 .601 .126 r
F
.50913 .58886 m .506 .58863 L .50605 .58833 L .968 .761 .57 r
F
.50831 .48546 m .50534 .48311 L .51035 .57375 L .956 .666 .445 r
F
.50534 .48311 m .50725 .57881 L .51035 .57375 L .956 .668 .448 r
F
.50913 .58886 m .50605 .58833 L .51181 .55591 L .968 .761 .57 r
F
.50913 .58886 m .51054 .57148 L .51105 .57757 L F
.51054 .57148 m .51181 .55591 L .51105 .57757 L F
.51209 .58985 m .51203 .58913 L .51224 .58948 L .264 .239 .643 r
F
.5149 .55495 m .51181 .55591 L .51196 .55591 L .247 0 0 r
F
.51798 .55299 m .51505 .55507 L .51539 .55532 L .69 .22 .132 r
F
.51843 .58474 m .51534 .58931 L .51958 .56 L .994 .788 .519 r
F
.52018 .56067 m .51958 .56 L .52089 .55092 L F
.51843 .58474 m .51958 .56 L .52018 .56067 L F
.51843 .58474 m .52089 .55092 L .52097 .55086 L F
.51534 .58931 m .51224 .58948 L .51798 .55299 L .971 .757 .558 r
F
.51806 .55319 m .51539 .55532 L .52053 .55926 L .69 .22 .132 r
F
.51539 .55532 m .51745 .55616 L .52053 .55926 L .247 0 0 r
F
.51505 .55507 m .51523 .55515 L .51539 .55532 L F
.51798 .55299 m .51539 .55532 L .51806 .55319 L .69 .22 .132 r
F
.51523 .55515 m .51745 .55616 L .51539 .55532 L .247 0 0 r
F
.51798 .55299 m .5149 .55495 L .51505 .55507 L .69 .22 .132 r
F
.5149 .55495 m .51498 .55499 L .51505 .55507 L .247 0 0 r
F
.51498 .55499 m .51745 .55616 L .51505 .55507 L F
.51224 .58948 m .50913 .58886 L .5149 .55495 L .965 .754 .569 r
F
.5149 .55495 m .51196 .55591 L .51745 .55616 L .247 0 0 r
F
.51196 .55591 m .51437 .55054 L .51745 .55616 L .809 .913 .91 r
F
.51181 .55591 m .5119 .55572 L .51196 .55591 L F
.5119 .55572 m .51437 .55054 L .51196 .55591 L F
.51224 .58948 m .51431 .5627 L .51578 .56698 L .965 .754 .569 r
F
.52097 .55086 m .52089 .55092 L .52104 .5499 L .994 .788 .519 r
F
.51534 .58931 m .51762 .55787 L .51958 .56 L .971 .757 .558 r
F
.52104 .5499 m .51828 .55343 L .51865 .55396 L .783 .382 .294 r
F
.52113 .5503 m .51865 .55396 L .52359 .56118 L F
.52104 .5499 m .51865 .55396 L .52113 .5503 L F
.51828 .55343 m .52053 .55926 L .52359 .56118 L .69 .22 .132 r
F
.51798 .55299 m .51814 .55339 L .51828 .55343 L F
.51814 .55339 m .52053 .55926 L .51828 .55343 L F
.52104 .5499 m .51798 .55299 L .51828 .55343 L .783 .382 .294 r
F
.52407 .5442 m .52104 .5499 L .5215 .55088 L .796 .444 .39 r
F
.52415 .54469 m .5215 .55088 L .52665 .56184 L F
.52407 .5442 m .5215 .55088 L .52415 .54469 L F
.52959 .53196 m .52708 .53691 L .52992 .52934 L .999 .797 .489 r
F
.527 .53801 m .52708 .53691 L .52959 .53196 L F
.52708 .53691 m .52407 .5442 L .52421 .54456 L .799 .464 .421 r
F
.52708 .53691 m .52421 .54456 L .52968 .55848 L F
.52441 .54505 m .52665 .56184 L .52968 .55848 L .796 .444 .39 r
F
.52407 .5442 m .52425 .54538 L .52441 .54505 L F
.52425 .54538 m .52665 .56184 L .52441 .54505 L F
.5295 .53469 m .52916 .53538 L .52983 .53007 L .997 .805 .449 r
F
.52995 .52975 m .52983 .53007 L .53006 .52824 L F
.52712 .53724 m .52713 .5373 L .52716 .53713 L .799 .464 .421 r
F
.52713 .5373 m .52968 .55848 L .52717 .53718 L F
.52713 .5373 m .52717 .53718 L .52716 .53713 L F
.52748 .53799 m .52968 .55848 L .53267 .5521 L F
.52716 .53713 m .52732 .53846 L .52748 .53799 L F
.52732 .53846 m .52968 .55848 L .52748 .53799 L F
.52708 .53691 m .52712 .53724 L .52716 .53713 L F
.53246 .52307 m .53006 .52824 L .53292 .51945 L .997 .805 .449 r
F
.52995 .52975 m .53006 .52824 L .53246 .52307 L F
.53006 .52824 m .52708 .53691 L .52716 .53713 L .792 .466 .437 r
F
.53006 .52824 m .52716 .53713 L .53267 .5521 L F
.533 .51882 m .53006 .52824 L .5305 .52942 L .781 .459 .443 r
F
.53311 .51982 m .5305 .52942 L .53564 .54292 L F
.533 .51882 m .5305 .52942 L .53311 .51982 L F
.53591 .50948 m .533 .51882 L .53856 .53136 L .763 .439 .438 r
F
.533 .51882 m .53564 .54292 L .53856 .53136 L .781 .459 .443 r
F
.53824 .54255 m .53521 .53167 L .54052 .4717 L .918 .674 .554 r
F
.53521 .53167 m .53759 .47116 L .54052 .4717 L .902 .664 .569 r
F
.53759 .47116 m .54042 .5245 L .54344 .53076 L .943 .633 .423 r
F
.54344 .53076 m .54042 .5245 L .54043 .52446 L .928 .699 .571 r
F
.54052 .4717 m .53759 .47116 L .54344 .53076 L .951 .645 .42 r
F
.54344 .53076 m .54043 .52446 L .54581 .48519 L .928 .699 .571 r
F
.5408 .52174 m .54289 .49055 L .54581 .48519 L .872 .661 .614 r
F
.54042 .5245 m .54062 .52179 L .5408 .52174 L F
.54062 .52179 m .54289 .49055 L .5408 .52174 L F
.54484 .51749 m .54581 .48519 L .54872 .48066 L .928 .699 .571 r
F
.54344 .53076 m .54418 .51661 L .54484 .51749 L F
.54418 .51661 m .54581 .48519 L .54484 .51749 L F
.55154 .52639 m .55122 .52597 L .55193 .5323 L .974 .668 .301 r
F
.54938 .49355 m .55122 .52597 L .55154 .52639 L F
.55211 .5326 m .55193 .5323 L .55235 .53608 L F
.54938 .49355 m .55193 .5323 L .55211 .5326 L F
.54749 .52494 m .54797 .49932 L .54922 .50444 L .935 .698 .554 r
F
.54645 .53711 m .54698 .5241 L .54749 .52494 L F
.54698 .5241 m .54797 .49932 L .54749 .52494 L F
.54938 .49355 m .55235 .53608 L .55522 .52973 L .974 .668 .301 r
F
.54922 .50444 m .54872 .48066 L .5516 .47639 L .935 .698 .554 r
F
.54797 .49932 m .54872 .48066 L .54922 .50444 L F
.55522 .52973 m .55235 .53608 L .55577 .49434 L .992 .76 .483 r
F
.55646 .49811 m .55577 .49434 L .55736 .47489 L F
.55522 .52973 m .55577 .49434 L .55646 .49811 L F
.55235 .53608 m .55447 .47348 L .55736 .47489 L .983 .744 .497 r
F
.55736 .47489 m .55447 .47348 L .55865 .48669 L .923 .543 .262 r
F
.55968 .48851 m .55865 .48669 L .5602 .49157 L F
.55736 .47489 m .55865 .48669 L .55968 .48851 L F
.55574 .47748 m .55626 .47762 L .55664 .48032 L .537 .068 .089 r
F
.55447 .47348 m .55626 .47762 L .55574 .47748 L F
.55447 .47348 m .55603 .47601 L .55626 .47762 L F
.55603 .47601 m .55717 .47786 L .55664 .48032 L F
.55235 .53608 m .54944 .54001 L .55447 .47348 L .983 .744 .497 r
F
.54944 .54001 m .5516 .47639 L .55447 .47348 L .956 .714 .531 r
F
.55447 .47348 m .5516 .47639 L .55717 .47786 L .537 .068 .089 r
F
.55305 .47677 m .55418 .46862 L .55717 .47786 L .871 .912 .508 r
F
.55255 .47664 m .55266 .47608 L .55305 .47677 L F
.55266 .47608 m .55418 .46862 L .55305 .47677 L F
.5516 .47639 m .55218 .47464 L .55255 .47664 L F
.55218 .47464 m .55418 .46862 L .55255 .47664 L F
.55664 .48032 m .55717 .47786 L .5602 .49157 L .537 .068 .089 r
F
.56077 .50674 m .55803 .51983 L .56217 .49643 L .818 .75 .231 r
F
.56232 .49651 m .56217 .49643 L .56295 .49205 L F
.56232 .49651 m .56295 .49205 L .56301 .49192 L F
.5602 .49157 m .55717 .47786 L .55766 .47983 L 0 0 .257 r
F
.5657 .51632 m .56321 .50527 L .56586 .51739 L .959 .619 .276 r
F
.56229 .49338 m .56318 .50488 L .56564 .51594 L F
.56077 .50674 m .56217 .49643 L .56232 .49651 L .818 .75 .231 r
F
.56192 .49413 m .56325 .50568 L .56229 .49338 L .959 .619 .276 r
F
.56003 .48953 m .5602 .49157 L .56112 .49584 L .923 .543 .262 r
F
.5588 .4824 m .55969 .48824 L .56003 .48953 L F
.55969 .48824 m .5602 .49157 L .56003 .48953 L F
.5588 .4824 m .56112 .49584 L .5614 .49599 L F
.55849 .48128 m .5602 .49157 L .5588 .4824 L F
.55839 .48091 m .55842 .48111 L .55849 .48128 L F
.55842 .48111 m .5602 .49157 L .55849 .48128 L F
.55717 .47786 m .55418 .46862 L .55666 .47673 L .717 .409 0 r
F
.56028 .47991 m .55736 .47489 L .56325 .50568 L .959 .619 .276 r
F
.55766 .47983 m .55995 .48747 L .55789 .48076 L .717 .409 0 r
F
.55789 .48076 m .55995 .48747 L .56301 .50115 L F
.55717 .47786 m .55742 .47873 L .55766 .47983 L F
.55742 .47873 m .55995 .48747 L .55766 .47983 L F
.5603 .4919 m .55766 .47983 L .56301 .50115 L 0 0 .257 r
F
.5602 .49157 m .55766 .47983 L .5603 .4919 L F
.5573 .47833 m .55666 .47673 L .55995 .48747 L .717 .409 0 r
F
.55717 .47786 m .55666 .47673 L .5573 .47833 L F
.55666 .47673 m .55693 .47692 L .55995 .48747 L .761 .394 0 r
F
.55418 .46862 m .55587 .47372 L .55666 .47673 L F
.55587 .47372 m .55693 .47692 L .55666 .47673 L F
.5614 .49599 m .56112 .49584 L .56325 .50568 L .923 .543 .262 r
F
.56301 .49192 m .56295 .49205 L .56325 .49033 L .818 .75 .231 r
F
.56325 .49033 m .56028 .47991 L .56631 .5204 L .955 .641 .22 r
F
.56325 .49033 m .56631 .5204 L .56936 .53389 L F
.56564 .51594 m .56318 .5049 L .5657 .51632 L .959 .619 .276 r
F
.56318 .50488 m .56318 .5049 L .56564 .51594 L F
.56318 .5049 m .56321 .50527 L .5657 .51632 L F
.56586 .51739 m .56325 .50568 L .56631 .5204 L F
.56321 .50527 m .56325 .50568 L .56586 .51739 L F
.56628 .50533 m .56325 .49033 L .56696 .51677 L .909 .621 .125 r
F
.56778 .51919 m .56696 .51677 L .56812 .52504 L F
.56778 .51919 m .56812 .52504 L .56853 .52614 L F
.56934 .52124 m .56628 .50533 L .57232 .53981 L .771 .516 0 r
F
.56628 .50533 m .56936 .53389 L .57232 .53981 L .909 .621 .125 r
F
.57541 .54835 m .57485 .54646 L .57789 .53139 L .727 .579 .688 r
F
.57485 .54646 m .57242 .53814 L .57625 .53341 L F
.57666 .53398 m .57625 .53341 L .57686 .53266 L F
.57485 .54646 m .57625 .53341 L .57666 .53398 L F
.57485 .54646 m .57686 .53266 L .57789 .53139 L F
.57242 .53814 m .57517 .53933 L .57789 .53139 L 0 0 .519 r
F
.57242 .53814 m .57179 .53472 L .57362 .53721 L F
.57242 .53814 m .57362 .53721 L .57333 .53854 L F
.57179 .53472 m .56934 .52124 L .57517 .53933 L F
.57333 .53854 m .57362 .53721 L .57517 .53933 L F
.57091 .52611 m .57232 .53981 L .57517 .53933 L .771 .516 0 r
F
.57232 .53981 m .57492 .52996 L .57564 .52792 L .724 .648 .773 r
F
.57493 .53119 m .57564 .52792 L .57766 .5222 L F
.57232 .53981 m .57564 .52792 L .57493 .53119 L F
.56934 .52124 m .5699 .52473 L .57091 .52611 L .771 .516 0 r
F
.5699 .52473 m .57232 .53981 L .57091 .52611 L F
.57517 .53933 m .57766 .5222 L .57978 .51248 L .981 .834 .623 r
F
.57931 .51575 m .57978 .51248 L .58029 .51016 L F
.57517 .53933 m .57978 .51248 L .57931 .51575 L F
.5666 .52092 m .56908 .52382 L .57206 .53052 L 0 0 .47 r
F
.56631 .5204 m .5665 .52063 L .5666 .52092 L F
.5665 .52063 m .56908 .52382 L .5666 .52092 L F
.56853 .52614 m .56812 .52504 L .56936 .53389 L .909 .621 .125 r
F
.56628 .50533 m .56696 .51677 L .56778 .51919 L F
.56631 .5204 m .56325 .50568 L .56908 .52382 L 0 0 .47 r
F
.56375 .50725 m .56607 .51469 L .56908 .52382 L 0 0 .284 r
F
.56325 .50568 m .56357 .50671 L .56375 .50725 L F
.56357 .50671 m .56607 .51469 L .56375 .50725 L F
.56039 .4923 m .56301 .50115 L .56607 .51469 L 0 0 .257 r
F
.5602 .49157 m .5603 .4919 L .56039 .4923 L F
.5603 .4919 m .56301 .50115 L .56039 .4923 L F
.56028 .47991 m .56192 .49413 L .56229 .49338 L .959 .619 .276 r
F
.55736 .47489 m .55839 .48091 L .5588 .4824 L .923 .543 .262 r
F
.56077 .50674 m .56096 .50547 L .56155 .50654 L .818 .75 .231 r
F
.56928 .52068 m .56915 .52044 L .56934 .52124 L .866 .541 .435 r
F
.40911 .48051 m .41127 .47565 L .41441 .4788 L .663 .741 .908 r
F
.40911 .48051 m .40596 .47736 L .41127 .47565 L F
.33198 .48039 m .33393 .4755 L .33721 .47867 L .664 .741 .908 r
F
.33198 .48039 m .32869 .47723 L .33393 .4755 L F
.42285 .48025 m .42505 .47537 L .42816 .47854 L F
.42285 .48025 m .41972 .47709 L .42505 .47537 L F
.34571 .48012 m .34769 .47524 L .35095 .47841 L F
.34571 .48012 m .34245 .47696 L .34769 .47524 L F
.59451 .52627 m .5913 .50387 L .59711 .51728 L .302 .226 .603 r
F
.5913 .50387 m .59404 .50179 L .59711 .51728 L .129 .155 .619 r
F
.43659 .47998 m .43883 .47511 L .44192 .47828 L .663 .741 .908 r
F
.43659 .47998 m .43349 .47682 L .43883 .47511 L F
.77264 .47999 m .77583 .47512 L .7783 .47828 L .662 .741 .908 r
F
.77264 .47999 m .77015 .47682 L .77583 .47512 L F
.75721 .50639 m .75511 .50945 L .75889 .48078 L .999 .81 .467 r
F
.75889 .48078 m .76199 .47538 L .7645 .47855 L .71 .771 .9 r
F
.75889 .48078 m .75639 .47783 L .76199 .47538 L F
.75511 .50945 m .75639 .47783 L .75889 .48078 L .988 .789 .397 r
F
.76366 .6507 m .75721 .50639 L .75934 .50415 L .986 .715 .409 r
F
.35944 .47985 m .36146 .47497 L .3647 .47815 L .663 .741 .908 r
F
.35944 .47985 m .3562 .47669 L .36146 .47497 L F
.78644 .47974 m .78966 .47485 L .79212 .47804 L F
.78644 .47974 m .78398 .47657 L .78966 .47485 L F
.45033 .47974 m .45261 .47484 L .45568 .47803 L .664 .741 .907 r
F
.45033 .47974 m .44726 .47657 L .45261 .47484 L F
.37318 .4796 m .37524 .47472 L .37845 .47788 L .664 .742 .908 r
F
.37318 .4796 m .36996 .47644 L .37524 .47472 L F
.29601 .47946 m .29785 .47458 L .3012 .47775 L .663 .741 .908 r
F
.29601 .47946 m .29265 .47629 L .29785 .47458 L F
.46409 .47948 m .4664 .47458 L .46945 .47775 L .664 .74 .907 r
F
.46409 .47948 m .46104 .4763 L .4664 .47458 L F
.38692 .47933 m .38902 .47444 L .3922 .47762 L .664 .741 .908 r
F
.38692 .47933 m .38373 .47617 L .38902 .47444 L F
.47784 .47919 m .4802 .47432 L .48321 .47749 L .663 .741 .908 r
F
.47784 .47919 m .47482 .47603 L .4802 .47432 L F
.30974 .4792 m .31162 .47431 L .31495 .47748 L .664 .741 .908 r
F
.30974 .4792 m .30641 .47603 L .31162 .47431 L F
.40066 .47907 m .4028 .47419 L .40596 .47736 L .663 .741 .908 r
F
.40066 .47907 m .3975 .4759 L .4028 .47419 L F
.32347 .47893 m .32539 .47405 L .32869 .47723 L .664 .741 .908 r
F
.32347 .47893 m .32017 .47577 L .32539 .47405 L F
.4916 .47895 m .49399 .47417 L .49699 .47731 L .656 .739 .911 r
F
.4916 .47895 m .4886 .47579 L .49399 .47417 L F
.41441 .4788 m .41659 .47392 L .41972 .47709 L .664 .742 .908 r
F
.41441 .4788 m .41127 .47565 L .41659 .47392 L F
.33721 .47867 m .33917 .47378 L .34245 .47696 L F
.33721 .47867 m .33393 .4755 L .33917 .47378 L F
.62232 .53095 m .6192 .51595 L .62432 .50028 L .775 .578 .632 r
F
.62432 .50028 m .62193 .50974 L .62799 .52463 L .783 .459 .44 r
F
.6192 .51595 m .62193 .50974 L .62432 .50028 L .326 .284 .657 r
F
.42816 .47854 m .43038 .47365 L .43349 .47682 L .664 .741 .908 r
F
.42816 .47854 m .42505 .47537 L .43038 .47365 L F
.7645 .47855 m .76766 .47365 L .77015 .47682 L .664 .742 .908 r
F
.7645 .47855 m .76199 .47538 L .76766 .47365 L F
.35095 .47841 m .35295 .47352 L .3562 .47669 L .664 .741 .908 r
F
.35095 .47841 m .34769 .47524 L .35295 .47352 L F
.58456 .49489 m .58441 .49499 L .5855 .48873 L .803 .739 .215 r
F
.5855 .48873 m .58826 .48926 L .59107 .49136 L .048 0 .138 r
F
.58048 .5176 m .58287 .49685 L .5855 .48873 L .867 .762 .255 r
F
.5855 .48873 m .58287 .49685 L .58826 .48926 L .048 0 .138 r
F
.58401 .49525 m .58555 .49277 L .58826 .48926 L 0 0 .11 r
F
.58287 .49685 m .58386 .49535 L .58401 .49525 L F
.58386 .49535 m .58555 .49277 L .58401 .49525 L F
.58305 .50486 m .58048 .5176 L .58441 .49499 L .803 .739 .215 r
F
.58305 .50486 m .58441 .49499 L .58456 .49489 L F
.44192 .47828 m .44418 .47339 L .44726 .47657 L .663 .741 .908 r
F
.44192 .47828 m .43883 .47511 L .44418 .47339 L F
.7783 .47828 m .78151 .4734 L .78398 .47657 L .663 .742 .908 r
F
.7783 .47828 m .77583 .47512 L .78151 .4734 L F
.3647 .47815 m .36674 .47326 L .36996 .47644 L .663 .741 .908 r
F
.3647 .47815 m .36146 .47497 L .36674 .47326 L F
.28746 .47802 m .28929 .47312 L .29265 .47629 L .664 .741 .908 r
F
.28746 .47802 m .28409 .47485 L .28929 .47312 L F
.45568 .47803 m .45798 .47313 L .46104 .4763 L .663 .74 .907 r
F
.45568 .47803 m .45261 .47484 L .45798 .47313 L F
.79212 .47804 m .79536 .47314 L .7978 .47631 L F
.79212 .47804 m .78966 .47485 L .79536 .47314 L F
.37845 .47788 m .38053 .47299 L .38373 .47617 L .664 .742 .908 r
F
.37845 .47788 m .37524 .47472 L .38053 .47299 L F
.46945 .47775 m .47178 .47285 L .47482 .47603 L .664 .741 .908 r
F
.46945 .47775 m .4664 .47458 L .47178 .47285 L F
.3012 .47775 m .30306 .47285 L .30641 .47603 L F
.3012 .47775 m .29785 .47458 L .30306 .47285 L F
.3922 .47762 m .39432 .47272 L .3975 .4759 L .663 .741 .908 r
F
.3922 .47762 m .38902 .47444 L .39432 .47272 L F
.31495 .47748 m .31685 .47259 L .32017 .47577 L F
.31495 .47748 m .31162 .47431 L .31685 .47259 L F
.48321 .47749 m .48559 .4726 L .4886 .47579 L F
.48321 .47749 m .4802 .47432 L .48559 .4726 L F
.58101 .54563 m .57827 .55043 L .58305 .50486 L .994 .775 .495 r
F
.40596 .47736 m .40812 .47247 L .41127 .47565 L .663 .741 .908 r
F
.40596 .47736 m .4028 .47419 L .40812 .47247 L F
.32869 .47723 m .33063 .47233 L .33393 .4755 L F
.32869 .47723 m .32539 .47405 L .33063 .47233 L F
.49699 .47731 m .49399 .47417 L .49936 .47834 L 0 .195 .695 r
F
.41972 .47709 m .42192 .47219 L .42505 .47537 L .664 .742 .908 r
F
.41972 .47709 m .41659 .47392 L .42192 .47219 L F
.73173 .48801 m .7383 .53825 L .73936 .51742 L .859 .547 .459 r
F
.73173 .48801 m .73016 .50106 L .7383 .53825 L F
.72686 .50219 m .73016 .50106 L .73173 .48801 L .058 0 .335 r
F
.34245 .47696 m .34443 .47206 L .34769 .47524 L .663 .741 .908 r
F
.34245 .47696 m .33917 .47378 L .34443 .47206 L F
.77015 .47682 m .77334 .47193 L .77583 .47512 L F
.77015 .47682 m .76766 .47365 L .77334 .47193 L F
.43349 .47682 m .43573 .47193 L .43883 .47511 L F
.43349 .47682 m .43038 .47365 L .43573 .47193 L F
.75511 .50945 m .75319 .51529 L .75639 .47783 L .988 .789 .397 r
F
.75639 .47783 m .75948 .47219 L .76199 .47538 L .743 .802 .9 r
F
.75639 .47783 m .7539 .47518 L .75948 .47219 L F
.75319 .51529 m .7539 .47518 L .75639 .47783 L .98 .769 .357 r
F
.3562 .47669 m .35822 .47179 L .36146 .47497 L .664 .741 .908 r
F
.3562 .47669 m .35295 .47352 L .35822 .47179 L F
.44726 .47657 m .44954 .47167 L .45261 .47484 L .663 .741 .908 r
F
.44726 .47657 m .44418 .47339 L .44954 .47167 L F
.78398 .47657 m .7872 .47168 L .78966 .47485 L .663 .742 .908 r
F
.78398 .47657 m .78151 .4734 L .7872 .47168 L F
.36996 .47644 m .37202 .47154 L .37524 .47472 L .664 .741 .908 r
F
.36996 .47644 m .36674 .47326 L .37202 .47154 L F
.50534 .48311 m .50235 .48086 L .50725 .57881 L .956 .668 .448 r
F
.29265 .47629 m .29449 .47139 L .29785 .47458 L .664 .742 .908 r
F
.29265 .47629 m .28929 .47312 L .29449 .47139 L F
.46104 .4763 m .46335 .4714 L .4664 .47458 L F
.46104 .4763 m .45798 .47313 L .46335 .4714 L F
.7978 .47631 m .80107 .47141 L .8035 .47458 L F
.7978 .47631 m .79536 .47314 L .80107 .47141 L F
.61948 .53304 m .62232 .53095 L .62526 .54007 L 0 0 .037 r
F
.61948 .53304 m .617 .54074 L .62232 .53095 L F
.38373 .47617 m .38582 .47126 L .38902 .47444 L .664 .741 .908 r
F
.38373 .47617 m .38053 .47299 L .38582 .47126 L F
.68843 .52956 m .68622 .53534 L .69206 .53827 L .626 .253 .316 r
F
.68304 .5352 m .68622 .53534 L .68843 .52956 L .081 0 .189 r
F
.47482 .47603 m .47717 .47113 L .4802 .47432 L .663 .741 .908 r
F
.47482 .47603 m .47178 .47285 L .47717 .47113 L F
.30641 .47603 m .30829 .47113 L .31162 .47431 L .664 .741 .908 r
F
.30641 .47603 m .30306 .47285 L .30829 .47113 L F
.3975 .4759 m .39963 .471 L .4028 .47419 L .663 .741 .908 r
F
.3975 .4759 m .39432 .47272 L .39963 .471 L F
.32017 .47577 m .32208 .47086 L .32539 .47405 L .664 .742 .908 r
F
.32017 .47577 m .31685 .47259 L .32208 .47086 L F
.4886 .47579 m .49099 .471 L .49399 .47417 L .655 .738 .911 r
F
.4886 .47579 m .48559 .4726 L .49099 .471 L F
.6192 .51595 m .61612 .50153 L .62193 .50974 L .326 .284 .657 r
F
.61421 .53752 m .61612 .50153 L .6192 .51595 L .792 .585 .62 r
F
.61421 .53752 m .61107 .52133 L .61612 .50153 L F
.61107 .52133 m .61323 .49449 L .61612 .50153 L .7 .519 .64 r
F
.617 .54074 m .6192 .51595 L .62232 .53095 L .937 .744 .615 r
F
.617 .54074 m .61421 .53752 L .6192 .51595 L F
.61323 .49449 m .61687 .52191 L .6194 .51555 L .919 .574 .367 r
F
.6194 .51555 m .61687 .52191 L .61693 .52153 L .986 .831 .444 r
F
.61612 .50153 m .6194 .51555 L .62185 .50963 L .862 .508 .002 r
F
.61612 .50153 m .61323 .49449 L .6194 .51555 L F
.62081 .50202 m .62048 .50067 L .62169 .49359 L .986 .831 .444 r
F
.61687 .52191 m .61864 .48119 L .62169 .49359 L .956 .729 .554 r
F
.61107 .52133 m .60791 .50366 L .61323 .49449 L .7 .519 .64 r
F
.60985 .50032 m .61057 .49589 L .61323 .49449 L .39 .33 .669 r
F
.60791 .50366 m .60913 .5001 L .60985 .50032 L F
.60913 .5001 m .61057 .49589 L .60985 .50032 L F
.60267 .51718 m .60485 .48962 L .60791 .50366 L .75 .562 .641 r
F
.60267 .51718 m .59959 .50217 L .60485 .48962 L F
.59959 .50217 m .60202 .48541 L .60485 .48962 L .714 .567 .687 r
F
.60485 .48962 m .60202 .48541 L .6067 .49935 L .909 .52 .103 r
F
.60791 .50366 m .60485 .48962 L .61057 .49589 L .39 .33 .669 r
F
.60714 .49949 m .6067 .49935 L .60803 .50334 L .909 .52 .103 r
F
.60485 .48962 m .6067 .49935 L .60714 .49949 L F
.61323 .49449 m .61057 .49589 L .61687 .52191 L .919 .574 .367 r
F
.61057 .49589 m .61406 .519 L .61687 .52191 L .809 .474 .421 r
F
.61687 .52191 m .61406 .519 L .61864 .48119 L .956 .729 .554 r
F
.61406 .519 m .61598 .48278 L .61864 .48119 L .837 .624 .614 r
F
.62185 .50963 m .6194 .51555 L .62193 .50974 L .862 .508 .002 r
F
.62193 .50974 m .62471 .50498 L .62799 .52463 L 0 0 0 r
F
.62193 .50974 m .6194 .51555 L .62456 .50528 L F
.62455 .50525 m .62456 .50528 L .62471 .50498 L F
.62193 .50974 m .62456 .50528 L .62455 .50525 L F
.62456 .50528 m .62169 .49359 L .62471 .50498 L .986 .831 .444 r
F
.6194 .51555 m .62169 .49359 L .62456 .50528 L F
.62169 .49359 m .61864 .48119 L .61882 .48192 L .692 .427 0 r
F
.62169 .49359 m .61882 .48192 L .62391 .50277 L F
.62401 .50317 m .62391 .50277 L .62455 .50539 L F
.62169 .49359 m .62391 .50277 L .62401 .50317 L F
.62169 .49359 m .62455 .50539 L .62461 .50563 L F
.62169 .49359 m .62479 .50639 L .62478 .50635 L F
.61864 .48119 m .62232 .50732 L .62503 .50737 L .915 .565 .36 r
F
.62799 .52463 m .62471 .50498 L .63016 .49966 L .649 .478 .639 r
F
.62471 .50498 m .6277 .50643 L .63016 .49966 L 0 .043 .579 r
F
.62471 .50498 m .62169 .49359 L .62741 .50582 L F
.62747 .50633 m .62741 .50582 L .6277 .50643 L F
.62471 .50498 m .62741 .50582 L .62747 .50633 L F
.62653 .49899 m .62725 .48327 L .62984 .48055 L .981 .793 .577 r
F
.62169 .49359 m .62503 .50737 L .6277 .50643 L .692 .427 0 r
F
.62503 .50737 m .62611 .49567 L .62653 .49899 L .981 .793 .577 r
F
.62611 .49567 m .62725 .48327 L .62653 .49899 L F
.62627 .47307 m .62614 .47216 L .62701 .46664 L .919 .799 .327 r
F
.61864 .48119 m .61598 .48278 L .62039 .49987 L .915 .565 .36 r
F
.62164 .50252 m .62039 .49987 L .62232 .50732 L F
.61864 .48119 m .62039 .49987 L .62164 .50252 L F
.62054 .50042 m .61925 .49521 L .62232 .50732 L .829 .423 .275 r
F
.61877 .49358 m .61925 .49521 L .62054 .50042 L F
.61598 .48278 m .61819 .49117 L .61877 .49358 L F
.61819 .49117 m .61925 .49521 L .61877 .49358 L F
.61057 .49589 m .60803 .50334 L .61292 .51604 L .809 .474 .421 r
F
.61368 .51647 m .61292 .51604 L .61406 .519 L F
.61057 .49589 m .61292 .51604 L .61368 .51647 L F
.60485 .48962 m .60803 .50334 L .61057 .49589 L .909 .52 .103 r
F
.60575 .53154 m .60791 .50366 L .61107 .52133 L .764 .573 .64 r
F
.60575 .53154 m .60267 .51718 L .60791 .50366 L F
.60202 .48541 m .60551 .51255 L .60803 .50334 L .883 .543 .401 r
F
.60803 .50334 m .61098 .50607 L .61406 .519 L .212 0 .241 r
F
.60803 .50334 m .60551 .51255 L .61098 .50607 L F
.60593 .51206 m .60802 .49732 L .61098 .50607 L .99 .863 .613 r
F
.60551 .51255 m .60562 .51188 L .60593 .51206 L F
.60562 .51188 m .60802 .49732 L .60593 .51206 L F
.61406 .519 m .61098 .50607 L .61598 .48278 L .837 .624 .614 r
F
.61098 .50607 m .61332 .48492 L .61598 .48278 L .814 .639 .666 r
F
.61598 .48278 m .61332 .48492 L .61925 .49521 L .829 .423 .275 r
F
.61925 .49521 m .6163 .48741 L .61796 .48997 L 0 .08 .63 r
F
.62232 .50732 m .61925 .49521 L .62037 .49349 L .73 .565 .668 r
F
.62232 .50732 m .62037 .49349 L .62467 .48691 L F
.61925 .49521 m .62224 .4966 L .62467 .48691 L 0 .08 .63 r
F
.61925 .49521 m .61796 .48997 L .62224 .4966 L F
.6163 .48741 m .61327 .4764 L .6149 .48229 L 0 0 .194 r
F
.6177 .49252 m .6163 .48741 L .61925 .49521 L .187 0 .242 r
F
.6163 .48741 m .61958 .49914 L .62224 .4966 L 0 0 .194 r
F
.61749 .49152 m .61901 .47166 L .62146 .46199 L .947 .752 .608 r
F
.6163 .48741 m .6149 .48229 L .61825 .49435 L 0 0 .194 r
F
.6163 .48741 m .61825 .49435 L .6185 .49528 L F
.61354 .48531 m .6163 .48741 L .6177 .49252 L .187 0 .242 r
F
.6185 .49528 m .61825 .49435 L .61958 .49914 L 0 0 .194 r
F
.61339 .48498 m .6163 .48741 L .61354 .48531 L .187 0 .242 r
F
.61332 .48492 m .61339 .48498 L .61354 .48531 L F
.61098 .50607 m .60802 .49732 L .61237 .48715 L .814 .639 .666 r
F
.61305 .48734 m .61237 .48715 L .61332 .48492 L F
.61098 .50607 m .61237 .48715 L .61305 .48734 L F
.60802 .49732 m .61084 .49468 L .61332 .48492 L .147 .157 .612 r
F
.60802 .49732 m .6049 .48234 L .61084 .49468 L F
.59959 .50217 m .59661 .49159 L .60202 .48541 L .714 .567 .687 r
F
.60202 .48541 m .59938 .48961 L .60551 .51255 L .883 .543 .401 r
F
.59938 .48961 m .60278 .5138 L .60551 .51255 L .776 .453 .44 r
F
.60278 .5138 m .6049 .48234 L .60802 .49732 L .985 .777 .542 r
F
.60551 .51255 m .60278 .5138 L .60802 .49732 L .99 .863 .613 r
F
.60639 .48544 m .60822 .50005 L .61084 .49468 L .933 .56 .18 r
F
.6049 .48234 m .60543 .48516 L .60639 .48544 L F
.60543 .48516 m .60822 .50005 L .60639 .48544 L F
.61332 .48492 m .61084 .49468 L .6163 .48741 L .187 0 .242 r
F
.61084 .49468 m .61327 .4764 L .6163 .48741 L .983 .851 .468 r
F
.61327 .4764 m .61676 .49688 L .61958 .49914 L .934 .58 .159 r
F
.61676 .49688 m .6173 .49084 L .61749 .49152 L .947 .752 .608 r
F
.6173 .49084 m .61901 .47166 L .61749 .49152 L F
.62229 .49639 m .62228 .49634 L .62469 .48121 L .919 .799 .327 r
F
.62469 .48127 m .62469 .48121 L .62701 .46664 L F
.62229 .49639 m .62469 .48121 L .62469 .48127 L F
.62224 .4966 m .62416 .46164 L .62701 .46664 L .994 .779 .508 r
F
.62224 .4966 m .61958 .49914 L .62298 .47135 L F
.62345 .4746 m .62298 .47135 L .62416 .46164 L F
.62224 .4966 m .62298 .47135 L .62345 .4746 L F
.6277 .50643 m .62984 .48055 L .6328 .48948 L .989 .795 .553 r
F
.6277 .50643 m .62503 .50737 L .62984 .48055 L F
.63016 .49966 m .6277 .50643 L .63239 .49084 L .801 .804 .314 r
F
.63245 .49083 m .63239 .49084 L .6328 .48948 L F
.63016 .49966 m .63239 .49084 L .63245 .49083 L F
.63194 .49091 m .63348 .50088 L .6366 .51401 L .879 .513 .348 r
F
.62984 .48055 m .6317 .49095 L .63194 .49091 L F
.6317 .49095 m .63348 .50088 L .63194 .49091 L F
.62984 .48055 m .62725 .48327 L .63214 .4971 L F
.63303 .49837 m .63214 .4971 L .63348 .50088 L F
.62984 .48055 m .63214 .4971 L .63303 .49837 L F
.62354 .50135 m .62467 .48691 L .62725 .48327 L .73 .565 .668 r
F
.6328 .48948 m .62984 .48055 L .63601 .51107 L .924 .596 .135 r
F
.63631 .51213 m .63601 .51107 L .6366 .51401 L F
.6328 .48948 m .63601 .51107 L .63631 .51213 L F
.62725 .48327 m .63016 .48124 L .63348 .50088 L 0 0 0 r
F
.62461 .50563 m .62455 .50539 L .62479 .50639 L .692 .427 0 r
F
.62478 .50635 m .62479 .50639 L .62503 .50737 L F
.62503 .50737 m .62232 .50732 L .62725 .48327 L .981 .793 .577 r
F
.62725 .48327 m .62467 .48691 L .63016 .48124 L 0 0 0 r
F
.6281 .48337 m .62701 .46664 L .63016 .48124 L .919 .799 .327 r
F
.62488 .48669 m .62601 .47607 L .6281 .48337 L F
.62601 .47607 m .62701 .46664 L .6281 .48337 L F
.62467 .48691 m .62472 .48647 L .62488 .48669 L F
.62472 .48647 m .62701 .46664 L .62488 .48669 L F
.62701 .46664 m .62416 .46164 L .63088 .49435 L .955 .611 .248 r
F
.62572 .46921 m .62763 .47765 L .63088 .49435 L .896 .501 .263 r
F
.62416 .46164 m .62555 .46803 L .62572 .46921 L F
.62555 .46803 m .62763 .47765 L .62572 .46921 L F
.62467 .48691 m .62229 .49639 L .62614 .47216 L .919 .799 .327 r
F
.62467 .48691 m .62614 .47216 L .62627 .47307 L F
.61958 .49914 m .62146 .46199 L .62416 .46164 L .963 .741 .554 r
F
.62416 .46164 m .62146 .46199 L .62616 .47391 L .896 .501 .263 r
F
.62702 .47483 m .62616 .47391 L .62763 .47765 L F
.62416 .46164 m .62616 .47391 L .62702 .47483 L F
.62163 .46215 m .6245 .46415 L .62467 .46488 L .165 0 .229 r
F
.62146 .46199 m .62163 .46211 L .62163 .46215 L F
.62163 .46211 m .6245 .46415 L .62163 .46215 L F
.62146 .46199 m .62467 .46488 L .62467 .47014 L F
.61958 .49914 m .61676 .49688 L .62146 .46199 L .963 .741 .554 r
F
.62146 .46199 m .61901 .47166 L .62403 .46478 L .165 0 .229 r
F
.62396 .46377 m .62403 .46478 L .6245 .46415 L F
.62146 .46199 m .62403 .46478 L .62396 .46377 L F
.62448 .47055 m .62517 .4776 L .62827 .48911 L .916 .577 .113 r
F
.62122 .46864 m .62153 .45616 L .6245 .46415 L .971 .866 .474 r
F
.62153 .45616 m .62489 .47594 L .62448 .47055 L .916 .577 .113 r
F
.62489 .47594 m .62517 .4776 L .62448 .47055 L F
.61901 .47166 m .61976 .46708 L .62122 .46864 L .971 .866 .474 r
F
.61976 .46708 m .62153 .45616 L .62122 .46864 L F
.62467 .47014 m .62467 .46488 L .62763 .47765 L .165 0 .229 r
F
.62229 .49639 m .62224 .4966 L .62228 .49634 L .919 .799 .327 r
F
.62232 .50732 m .62318 .49988 L .62354 .50135 L .73 .565 .668 r
F
.62318 .49988 m .62467 .48691 L .62354 .50135 L F
.6194 .51555 m .61693 .52153 L .62048 .50067 L .986 .831 .444 r
F
.6194 .51555 m .62048 .50067 L .62081 .50202 L F
.68304 .5352 m .68091 .54354 L .68622 .53534 L .081 0 .189 r
F
.67789 .54629 m .68091 .54354 L .68304 .5352 L .243 .267 .687 r
F
.41127 .47565 m .41344 .47074 L .41659 .47392 L .664 .742 .908 r
F
.41127 .47565 m .40812 .47247 L .41344 .47074 L F
.33393 .4755 m .33588 .4706 L .33917 .47378 L F
.33393 .4755 m .33063 .47233 L .33588 .4706 L F
.42505 .47537 m .42726 .47046 L .43038 .47365 L .664 .741 .908 r
F
.42505 .47537 m .42192 .47219 L .42726 .47046 L F
.76199 .47538 m .76515 .47046 L .76766 .47365 L .664 .741 .907 r
F
.76199 .47538 m .75948 .47219 L .76515 .47046 L F
.34769 .47524 m .34969 .47033 L .35295 .47352 L .664 .741 .908 r
F
.34769 .47524 m .34443 .47206 L .34969 .47033 L F
.43883 .47511 m .44108 .47021 L .44418 .47339 L .663 .741 .908 r
F
.43883 .47511 m .43573 .47193 L .44108 .47021 L F
.77583 .47512 m .77903 .47021 L .78151 .4734 L .663 .74 .908 r
F
.77583 .47512 m .77334 .47193 L .77903 .47021 L F
.36146 .47497 m .3635 .47007 L .36674 .47326 L .663 .741 .908 r
F
.36146 .47497 m .35822 .47179 L .3635 .47007 L F
.45261 .47484 m .45491 .46995 L .45798 .47313 L .663 .742 .909 r
F
.45261 .47484 m .44954 .47167 L .45491 .46995 L F
.28409 .47485 m .28591 .46994 L .28929 .47312 L .663 .741 .908 r
F
.28409 .47485 m .2807 .47166 L .28591 .46994 L F
.78966 .47485 m .7929 .46994 L .79536 .47314 L .664 .742 .908 r
F
.78966 .47485 m .7872 .47168 L .7929 .46994 L F
.37524 .47472 m .37731 .4698 L .38053 .47299 L F
.37524 .47472 m .37202 .47154 L .37731 .4698 L F
.8035 .47458 m .80678 .46967 L .80921 .47286 L .664 .743 .908 r
F
.8035 .47458 m .80107 .47141 L .80678 .46967 L F
.4664 .47458 m .46873 .46966 L .47178 .47285 L .664 .742 .908 r
F
.4664 .47458 m .46335 .4714 L .46873 .46966 L F
.29785 .47458 m .29971 .46967 L .30306 .47285 L .664 .741 .908 r
F
.29785 .47458 m .29449 .47139 L .29971 .46967 L F
.38902 .47444 m .39113 .46953 L .39432 .47272 L F
.38902 .47444 m .38582 .47126 L .39113 .46953 L F
.59404 .50179 m .59107 .49136 L .59661 .49159 L .568 .48 .715 r
F
.59107 .49136 m .5938 .48892 L .59661 .49159 L .486 .758 .991 r
F
.59107 .49136 m .58826 .48926 L .5938 .48892 L F
.31162 .47431 m .31352 .46941 L .31685 .47259 L .663 .741 .908 r
F
.31162 .47431 m .30829 .47113 L .31352 .46941 L F
.4802 .47432 m .48257 .46941 L .48559 .4726 L F
.4802 .47432 m .47717 .47113 L .48257 .46941 L F
.57665 .60352 m .57387 .60638 L .57908 .58596 L .997 .852 .569 r
F
.4028 .47419 m .40495 .46927 L .40812 .47247 L .663 .741 .908 r
F
.4028 .47419 m .39963 .471 L .40495 .46927 L F
.32539 .47405 m .32733 .46913 L .33063 .47233 L F
.32539 .47405 m .32208 .47086 L .32733 .46913 L F
.49399 .47417 m .49635 .47592 L .49936 .47834 L 0 .08 .59 r
F
.49399 .47417 m .49099 .471 L .49635 .47592 L F
.76366 .6507 m .76179 .65858 L .75721 .50639 L .986 .715 .409 r
F
.76179 .65858 m .75511 .50945 L .75721 .50639 L .983 .711 .421 r
F
.41659 .47392 m .41878 .469 L .42192 .47219 L .664 .741 .908 r
F
.41659 .47392 m .41344 .47074 L .41878 .469 L F
.33917 .47378 m .34114 .46887 L .34443 .47206 L .663 .741 .908 r
F
.33917 .47378 m .33588 .4706 L .34114 .46887 L F
.59711 .51728 m .59404 .50179 L .59959 .50217 L .567 .439 .666 r
F
.59404 .50179 m .59661 .49159 L .59959 .50217 L .568 .48 .715 r
F
.43038 .47365 m .43261 .46874 L .43573 .47193 L .663 .741 .908 r
F
.43038 .47365 m .42726 .47046 L .43261 .46874 L F
.76766 .47365 m .77084 .46874 L .77334 .47193 L F
.76766 .47365 m .76515 .47046 L .77084 .46874 L F
.35295 .47352 m .35496 .4686 L .35822 .47179 L F
.35295 .47352 m .34969 .47033 L .35496 .4686 L F
.44418 .47339 m .44645 .46849 L .44954 .47167 L .663 .742 .909 r
F
.44418 .47339 m .44108 .47021 L .44645 .46849 L F
.78151 .4734 m .78473 .46849 L .7872 .47168 L .663 .741 .908 r
F
.78151 .4734 m .77903 .47021 L .78473 .46849 L F
.67789 .54629 m .67488 .53552 L .68091 .54354 L .243 .267 .687 r
F
.67488 .53552 m .67787 .53227 L .68091 .54354 L .181 .153 .589 r
F
.36674 .47326 m .36879 .46834 L .37202 .47154 L .663 .741 .908 r
F
.36674 .47326 m .3635 .47007 L .36879 .46834 L F
.75319 .51529 m .75142 .52375 L .7539 .47518 L .98 .769 .357 r
F
.7539 .47518 m .75696 .46904 L .75948 .47219 L .783 .828 .887 r
F
.7539 .47518 m .75143 .47278 L .75696 .46904 L F
.75142 .52375 m .75143 .47278 L .7539 .47518 L .984 .756 .355 r
F
.59777 .55001 m .59451 .52627 L .60023 .53372 L .454 .331 .622 r
F
.59451 .52627 m .59711 .51728 L .60023 .53372 L .302 .226 .603 r
F
.28929 .47312 m .29112 .4682 L .29449 .47139 L .664 .742 .908 r
F
.28929 .47312 m .28591 .46994 L .29112 .4682 L F
.45798 .47313 m .46029 .4682 L .46335 .4714 L F
.45798 .47313 m .45491 .46995 L .46029 .4682 L F
.79536 .47314 m .79862 .46821 L .80107 .47141 L .663 .74 .907 r
F
.79536 .47314 m .7929 .46994 L .79862 .46821 L F
.38053 .47299 m .38262 .46807 L .38582 .47126 L .664 .741 .908 r
F
.38053 .47299 m .37731 .4698 L .38262 .46807 L F
.47178 .47285 m .47413 .46794 L .47717 .47113 L .663 .741 .908 r
F
.47178 .47285 m .46873 .46966 L .47413 .46794 L F
.30306 .47285 m .30494 .46793 L .30829 .47113 L .664 .741 .908 r
F
.30306 .47285 m .29971 .46967 L .30494 .46793 L F
.80921 .47286 m .81251 .46793 L .81494 .47114 L F
.80921 .47286 m .80678 .46967 L .81251 .46793 L F
.39432 .47272 m .39645 .4678 L .39963 .471 L F
.39432 .47272 m .39113 .46953 L .39645 .4678 L F
.31685 .47259 m .31876 .46767 L .32208 .47086 L F
.31685 .47259 m .31352 .46941 L .31876 .46767 L F
.48559 .4726 m .48798 .46783 L .49099 .471 L .653 .738 .912 r
F
.48559 .4726 m .48257 .46941 L .48798 .46783 L F
.57425 .6242 m .57152 .63119 L .57665 .60352 L .987 .839 .458 r
F
.57152 .63119 m .57387 .60638 L .57665 .60352 L .967 .777 .596 r
F
.40812 .47247 m .41029 .46754 L .41344 .47074 L .664 .741 .907 r
F
.40812 .47247 m .40495 .46927 L .41029 .46754 L F
.33063 .47233 m .33259 .4674 L .33588 .4706 L .664 .741 .908 r
F
.33063 .47233 m .32733 .46913 L .33259 .4674 L F
.59661 .49159 m .59938 .48961 L .60202 .48541 L .38 .659 .967 r
F
.61131 .53654 m .61421 .53752 L .617 .54074 L .163 0 0 r
F
.61131 .53654 m .60869 .54021 L .61421 .53752 L F
.75948 .47219 m .76264 .46726 L .76515 .47046 L .666 .745 .909 r
F
.75948 .47219 m .75696 .46904 L .76264 .46726 L F
.42192 .47219 m .42413 .46726 L .42726 .47046 L .664 .741 .908 r
F
.42192 .47219 m .41878 .469 L .42413 .46726 L F
.72686 .50219 m .72561 .5212 L .73016 .50106 L .058 0 .335 r
F
.34443 .47206 m .34642 .46713 L .34969 .47033 L .664 .741 .908 r
F
.34443 .47206 m .34114 .46887 L .34642 .46713 L F
.43573 .47193 m .43797 .46701 L .44108 .47021 L .663 .741 .908 r
F
.43573 .47193 m .43261 .46874 L .43797 .46701 L F
.77334 .47193 m .77654 .46701 L .77903 .47021 L F
.77334 .47193 m .77084 .46874 L .77654 .46701 L F
.35822 .47179 m .36025 .46686 L .3635 .47007 L .664 .742 .908 r
F
.35822 .47179 m .35496 .4686 L .36025 .46686 L F
.59661 .49159 m .5938 .48892 L .59938 .48961 L .38 .659 .967 r
F
.2807 .47166 m .28251 .46674 L .28591 .46994 L .663 .741 .908 r
F
.2807 .47166 m .27731 .46846 L .28251 .46674 L F
.44954 .47167 m .45182 .46674 L .45491 .46995 L .665 .742 .908 r
F
.44954 .47167 m .44645 .46849 L .45182 .46674 L F
.7872 .47168 m .79044 .46675 L .7929 .46994 L .664 .742 .908 r
F
.7872 .47168 m .78473 .46849 L .79044 .46675 L F
.37202 .47154 m .37409 .4666 L .37731 .4698 L .664 .741 .908 r
F
.37202 .47154 m .36879 .46834 L .37409 .4666 L F
.60349 .56007 m .60079 .56209 L .60591 .54292 L .995 .851 .582 r
F
.60079 .56209 m .60322 .54459 L .60591 .54292 L .689 .54 .679 r
F
.29449 .47139 m .29634 .46646 L .29971 .46967 L .663 .741 .908 r
F
.29449 .47139 m .29112 .4682 L .29634 .46646 L F
.46335 .4714 m .46568 .46646 L .46873 .46966 L .664 .741 .908 r
F
.46335 .4714 m .46029 .4682 L .46568 .46646 L F
.80107 .47141 m .80435 .46647 L .80678 .46967 L .663 .741 .908 r
F
.80107 .47141 m .79862 .46821 L .80435 .46647 L F
.38582 .47126 m .38793 .46633 L .39113 .46953 L F
.38582 .47126 m .38262 .46807 L .38793 .46633 L F
.30829 .47113 m .31017 .4662 L .31352 .46941 L F
.30829 .47113 m .30494 .46793 L .31017 .4662 L F
.47717 .47113 m .47953 .46621 L .48257 .46941 L F
.47717 .47113 m .47413 .46794 L .47953 .46621 L F
.81494 .47114 m .81825 .4662 L .82067 .46941 L .663 .74 .907 r
F
.81494 .47114 m .81251 .46793 L .81825 .4662 L F
.39963 .471 m .40178 .46606 L .40495 .46927 L .663 .741 .908 r
F
.39963 .471 m .39645 .4678 L .40178 .46606 L F
.59711 .51728 m .59959 .50217 L .60267 .51718 L .567 .439 .666 r
F
.32208 .47086 m .32401 .46593 L .32733 .46913 L .664 .742 .908 r
F
.32208 .47086 m .31876 .46767 L .32401 .46593 L F
.49099 .471 m .49332 .47375 L .49635 .47592 L .552 .059 0 r
F
.49099 .471 m .48798 .46783 L .49332 .47375 L F
.41344 .47074 m .41563 .4658 L .41878 .469 L .664 .741 .908 r
F
.41344 .47074 m .41029 .46754 L .41563 .4658 L F
.58826 .48926 m .59109 .49161 L .5938 .48892 L .327 0 .016 r
F
.58826 .48926 m .58555 .49277 L .59109 .49161 L F
.33588 .4706 m .33785 .46566 L .34114 .46887 L .664 .741 .908 r
F
.33588 .4706 m .33259 .4674 L .33785 .46566 L F
.42726 .47046 m .42949 .46553 L .43261 .46874 L .663 .741 .908 r
F
.42726 .47046 m .42413 .46726 L .42949 .46553 L F
.76515 .47046 m .76834 .46554 L .77084 .46874 L F
.76515 .47046 m .76264 .46726 L .76834 .46554 L F
.60023 .53372 m .59711 .51728 L .60267 .51718 L .577 .442 .66 r
F
.34969 .47033 m .3517 .4654 L .35496 .4686 L .663 .741 .908 r
F
.34969 .47033 m .34642 .46713 L .3517 .4654 L F
.44108 .47021 m .44335 .46528 L .44645 .46849 L .664 .742 .908 r
F
.44108 .47021 m .43797 .46701 L .44335 .46528 L F
.77903 .47021 m .78225 .46528 L .78473 .46849 L .663 .741 .908 r
F
.77903 .47021 m .77654 .46701 L .78225 .46528 L F
.3635 .47007 m .36555 .46513 L .36879 .46834 L .664 .741 .908 r
F
.3635 .47007 m .36025 .46686 L .36555 .46513 L F
.28591 .46994 m .28773 .46499 L .29112 .4682 L F
.28591 .46994 m .28251 .46674 L .28773 .46499 L F
.7929 .46994 m .79616 .465 L .79862 .46821 L .664 .742 .908 r
F
.7929 .46994 m .79044 .46675 L .79616 .465 L F
.45491 .46995 m .45721 .465 L .46029 .4682 L .664 .741 .907 r
F
.45491 .46995 m .45182 .46674 L .45721 .465 L F
.37731 .4698 m .3794 .46486 L .38262 .46807 L .664 .741 .908 r
F
.37731 .4698 m .37409 .4666 L .3794 .46486 L F
.46873 .46966 m .47108 .46473 L .47413 .46794 L .663 .741 .908 r
F
.46873 .46966 m .46568 .46646 L .47108 .46473 L F
.29971 .46967 m .30158 .46472 L .30494 .46793 L .664 .741 .908 r
F
.29971 .46967 m .29634 .46646 L .30158 .46472 L F
.80678 .46967 m .81008 .46473 L .81251 .46793 L .664 .742 .908 r
F
.80678 .46967 m .80435 .46647 L .81008 .46473 L F
.75142 .52375 m .74972 .53356 L .75143 .47278 L .984 .756 .355 r
F
.75143 .47278 m .75443 .46583 L .75696 .46904 L .826 .845 .862 r
F
.75143 .47278 m .74895 .47054 L .75443 .46583 L F
.74972 .53356 m .74895 .47054 L .75143 .47278 L .976 .743 .324 r
F
.39113 .46953 m .39326 .46459 L .39645 .4678 L .663 .741 .908 r
F
.39113 .46953 m .38793 .46633 L .39326 .46459 L F
.31352 .46941 m .31542 .46447 L .31876 .46767 L F
.31352 .46941 m .31017 .4662 L .31542 .46447 L F
.82067 .46941 m .82401 .46447 L .82641 .46768 L F
.82067 .46941 m .81825 .4662 L .82401 .46447 L F
.48492 .46468 m .48191 .46148 L .48495 .46467 L .648 .737 .914 r
F
.47953 .46621 m .48191 .46148 L .48492 .46468 L F
.47649 .463 m .47886 .45823 L .48191 .46148 L .649 .737 .914 r
F
.48191 .46148 m .47886 .45823 L .47889 .45826 L .712 .23 0 r
F
.48257 .46941 m .47953 .46621 L .48495 .46467 L .649 .737 .914 r
F
.47953 .46621 m .47649 .463 L .48191 .46148 L .648 .737 .914 r
F
.48191 .46148 m .47889 .45826 L .48419 .46584 L .712 .23 0 r
F
.48495 .46467 m .48191 .46148 L .48193 .4615 L .662 .172 0 r
F
.48257 .46941 m .48495 .46467 L .48796 .46784 L .649 .737 .914 r
F
.48495 .46467 m .48193 .4615 L .48725 .46842 L .662 .172 0 r
F
.48796 .46784 m .48495 .46467 L .48798 .46783 L .649 .737 .914 r
F
.5817 .50702 m .58127 .50794 L .58287 .49685 L .867 .762 .255 r
F
.58233 .50061 m .58029 .51016 L .58287 .49685 L .975 .831 .424 r
F
.57841 .52773 m .58029 .51016 L .58233 .50061 L F
.5784 .5269 m .58029 .51016 L .57841 .52773 L F
.58029 .51016 m .57766 .5222 L .57823 .51982 L 0 0 0 r
F
.58356 .4958 m .58029 .51016 L .58555 .49277 L 0 0 .11 r
F
.58287 .49685 m .58029 .51016 L .58356 .4958 L F
.58521 .49388 m .58289 .50055 L .58555 .49277 L 0 0 0 r
F
.58039 .50983 m .58289 .50055 L .58521 .49388 L F
.58029 .51016 m .58036 .50989 L .58039 .50983 L F
.58036 .50989 m .58289 .50055 L .58039 .50983 L F
.57789 .53139 m .57517 .53933 L .58029 .51016 L .975 .831 .424 r
F
.58029 .51016 m .57823 .51982 L .58289 .50055 L 0 0 0 r
F
.58239 .50262 m .58018 .5074 L .58289 .50055 L .917 .837 .383 r
F
.57823 .51982 m .58018 .5074 L .58239 .50262 L F
.57913 .51192 m .57742 .51238 L .58018 .5074 L .983 .832 .617 r
F
.57492 .52996 m .57742 .51238 L .57913 .51192 L F
.57206 .53052 m .57457 .51314 L .57742 .51238 L .827 .672 .691 r
F
.57742 .51238 m .57457 .51314 L .5757 .51284 L 0 0 0 r
F
.57821 .51894 m .58018 .5074 L .57823 .51982 L .917 .837 .383 r
F
.57766 .5222 m .57492 .52996 L .57913 .51192 L F
.57942 .51184 m .57913 .51192 L .58018 .5074 L F
.57766 .5222 m .57913 .51192 L .57942 .51184 L F
.57742 .51238 m .5757 .51284 L .57713 .51247 L 0 0 0 r
F
.57492 .52996 m .57206 .53052 L .57742 .51238 L .983 .832 .617 r
F
.57794 .51225 m .57713 .51247 L .58018 .51167 L 0 0 0 r
F
.57742 .51238 m .57713 .51247 L .57794 .51225 L F
.58018 .5074 m .57742 .51238 L .57795 .51222 L .359 0 .134 r
F
.58048 .5176 m .57789 .53139 L .58127 .50794 L .867 .762 .255 r
F
.58048 .5176 m .58127 .50794 L .5817 .50702 L F
.58018 .5074 m .57795 .51222 L .58302 .51074 L .359 0 .134 r
F
.58289 .50055 m .58018 .5074 L .58054 .50729 L .418 .062 .25 r
F
.58289 .50055 m .58054 .50729 L .58576 .5057 L F
.57766 .5222 m .57821 .51894 L .57823 .51982 L .917 .837 .383 r
F
.57789 .53139 m .5784 .5269 L .57841 .52773 L .975 .831 .424 r
F
.40495 .46927 m .40712 .46433 L .41029 .46754 L .663 .741 .908 r
F
.40495 .46927 m .40178 .46606 L .40712 .46433 L F
.57219 .67117 m .569 .64471 L .57425 .6242 L .738 .53 .611 r
F
.569 .64471 m .57152 .63119 L .57425 .6242 L .346 .243 .593 r
F
.49936 .47834 m .49635 .47592 L .50099 .58756 L .957 .67 .452 r
F
.32733 .46913 m .32927 .46419 L .33259 .4674 L .663 .741 .908 r
F
.32733 .46913 m .32401 .46593 L .32927 .46419 L F
.41878 .469 m .42098 .46405 L .42413 .46726 L .664 .741 .908 r
F
.41878 .469 m .41563 .4658 L .42098 .46405 L F
.75696 .46904 m .76012 .46406 L .76264 .46726 L .666 .742 .907 r
F
.75696 .46904 m .75443 .46583 L .76012 .46406 L F
.34114 .46887 m .34313 .46392 L .34642 .46713 L .664 .741 .908 r
F
.34114 .46887 m .33785 .46566 L .34313 .46392 L F
.56564 .61753 m .5679 .58313 L .57091 .59664 L .76 .56 .627 r
F
.56564 .61753 m .56258 .59971 L .5679 .58313 L F
.43261 .46874 m .43485 .46379 L .43797 .46701 L .663 .741 .908 r
F
.43261 .46874 m .42949 .46553 L .43485 .46379 L F
.77084 .46874 m .77404 .4638 L .77654 .46701 L .663 .742 .908 r
F
.77084 .46874 m .76834 .46554 L .77404 .4638 L F
.35496 .4686 m .35699 .46366 L .36025 .46686 L .663 .741 .908 r
F
.35496 .4686 m .3517 .4654 L .35699 .46366 L F
.27731 .46846 m .27911 .46352 L .28251 .46674 L .664 .741 .908 r
F
.27731 .46846 m .2739 .46526 L .27911 .46352 L F
.78473 .46849 m .78797 .46353 L .79044 .46675 L F
.78473 .46849 m .78225 .46528 L .78797 .46353 L F
.44645 .46849 m .44873 .46353 L .45182 .46674 L .664 .741 .907 r
F
.44645 .46849 m .44335 .46528 L .44873 .46353 L F
.36879 .46834 m .37085 .46339 L .37409 .4666 L .663 .741 .908 r
F
.36879 .46834 m .36555 .46513 L .37085 .46339 L F
.68622 .53534 m .68885 .52394 L .69206 .53827 L .699 .597 .738 r
F
.68622 .53534 m .68334 .52775 L .68885 .52394 L F
.68091 .54354 m .68334 .52775 L .68622 .53534 L .68 .541 .689 r
F
.5938 .48892 m .59683 .49937 L .59938 .48961 L .783 .37 .268 r
F
.5938 .48892 m .59109 .49161 L .59683 .49937 L F
.29112 .4682 m .29296 .46325 L .29634 .46646 L .663 .741 .908 r
F
.29112 .4682 m .28773 .46499 L .29296 .46325 L F
.46029 .4682 m .46261 .46325 L .46568 .46646 L .664 .741 .908 r
F
.46029 .4682 m .45721 .465 L .46261 .46325 L F
.79862 .46821 m .8019 .46325 L .80435 .46647 L F
.79862 .46821 m .79616 .465 L .8019 .46325 L F
.38262 .46807 m .38472 .46312 L .38793 .46633 L .663 .741 .908 r
F
.38262 .46807 m .3794 .46486 L .38472 .46312 L F
.60869 .54021 m .61107 .52133 L .61421 .53752 L .791 .628 .679 r
F
.60869 .54021 m .60575 .53154 L .61107 .52133 L F
.30494 .46793 m .30682 .46298 L .31017 .4662 L .664 .741 .908 r
F
.30494 .46793 m .30158 .46472 L .30682 .46298 L F
.81251 .46793 m .81583 .46299 L .81825 .4662 L .664 .742 .908 r
F
.81251 .46793 m .81008 .46473 L .81583 .46299 L F
.47413 .46794 m .47649 .463 L .47953 .46621 L .663 .741 .908 r
F
.47413 .46794 m .47108 .46473 L .47649 .463 L F
.60023 .53372 m .60267 .51718 L .60575 .53154 L .577 .442 .66 r
F
.39645 .4678 m .39859 .46286 L .40178 .46606 L .663 .741 .908 r
F
.39645 .4678 m .39326 .46459 L .39859 .46286 L F
.31876 .46767 m .32068 .46271 L .32401 .46593 L .664 .742 .908 r
F
.31876 .46767 m .31542 .46447 L .32068 .46271 L F
.82641 .46768 m .82977 .46272 L .83217 .46594 L .664 .741 .907 r
F
.82641 .46768 m .82401 .46447 L .82977 .46272 L F
.68091 .54354 m .67787 .53227 L .68334 .52775 L .68 .541 .689 r
F
.48798 .46783 m .49029 .47121 L .49332 .47375 L .626 .133 0 r
F
.48798 .46783 m .48495 .46467 L .49029 .47121 L F
.41029 .46754 m .41247 .46258 L .41563 .4658 L .664 .741 .908 r
F
.41029 .46754 m .40712 .46433 L .41247 .46258 L F
.76179 .65858 m .7597 .66357 L .75511 .50945 L .983 .711 .421 r
F
.33259 .4674 m .33455 .46245 L .33785 .46566 L .664 .741 .908 r
F
.33259 .4674 m .32927 .46419 L .33455 .46245 L F
.76264 .46726 m .76582 .46231 L .76834 .46554 L .664 .742 .908 r
F
.76264 .46726 m .76012 .46406 L .76582 .46231 L F
.42413 .46726 m .42635 .46231 L .42949 .46553 L .663 .741 .908 r
F
.42413 .46726 m .42098 .46405 L .42635 .46231 L F
.34642 .46713 m .34842 .46218 L .3517 .4654 L F
.34642 .46713 m .34313 .46392 L .34842 .46218 L F
.77654 .46701 m .77976 .46206 L .78225 .46528 L .663 .742 .908 r
F
.77654 .46701 m .77404 .4638 L .77976 .46206 L F
.43797 .46701 m .44023 .46205 L .44335 .46528 L .664 .741 .907 r
F
.43797 .46701 m .43485 .46379 L .44023 .46205 L F
.36025 .46686 m .36229 .46191 L .36555 .46513 L .664 .742 .908 r
F
.36025 .46686 m .35699 .46366 L .36229 .46191 L F
.28251 .46674 m .28434 .46177 L .28773 .46499 L .664 .741 .908 r
F
.28251 .46674 m .27911 .46352 L .28434 .46177 L F
.45182 .46674 m .45412 .46178 L .45721 .465 L F
.45182 .46674 m .44873 .46353 L .45412 .46178 L F
.79044 .46675 m .7937 .46178 L .79616 .465 L F
.79044 .46675 m .78797 .46353 L .7937 .46178 L F
.60322 .54459 m .60023 .53372 L .60575 .53154 L .634 .517 .702 r
F
.37409 .4666 m .37617 .46164 L .3794 .46486 L .664 .741 .908 r
F
.37409 .4666 m .37085 .46339 L .37617 .46164 L F
.56866 .63075 m .57091 .59664 L .57387 .60638 L .818 .613 .625 r
F
.56866 .63075 m .56564 .61753 L .57091 .59664 L F
.46568 .46646 m .46802 .46151 L .47108 .46473 L .663 .741 .908 r
F
.46568 .46646 m .46261 .46325 L .46802 .46151 L F
.29634 .46646 m .2982 .46151 L .30158 .46472 L .664 .741 .908 r
F
.29634 .46646 m .29296 .46325 L .2982 .46151 L F
.80435 .46647 m .80764 .46152 L .81008 .46473 L .663 .741 .908 r
F
.80435 .46647 m .8019 .46325 L .80764 .46152 L F
.38793 .46633 m .39005 .46138 L .39326 .46459 L F
.38793 .46633 m .38472 .46312 L .39005 .46138 L F
.57152 .63119 m .56866 .63075 L .57387 .60638 L .967 .777 .596 r
F
.31017 .4662 m .31207 .46125 L .31542 .46447 L .663 .741 .908 r
F
.31017 .4662 m .30682 .46298 L .31207 .46125 L F
.81825 .4662 m .82159 .46124 L .82401 .46447 L F
.81825 .4662 m .81583 .46299 L .82159 .46124 L F
.40178 .46606 m .40394 .46111 L .40712 .46433 L .664 .742 .908 r
F
.40178 .46606 m .39859 .46286 L .40394 .46111 L F
.74972 .53356 m .74826 .5474 L .74895 .47054 L .976 .743 .324 r
F
.74895 .47054 m .75189 .46264 L .75443 .46583 L .887 .883 .824 r
F
.74895 .47054 m .74651 .46894 L .75189 .46264 L F
.74826 .5474 m .74651 .46894 L .74895 .47054 L .989 .739 .365 r
F
.32401 .46593 m .32595 .46097 L .32927 .46419 L .663 .741 .908 r
F
.32401 .46593 m .32068 .46271 L .32595 .46097 L F
.83217 .46594 m .83555 .46097 L .83794 .4642 L .664 .741 .907 r
F
.83217 .46594 m .82977 .46272 L .83555 .46097 L F
.57827 .55043 m .57541 .54835 L .58048 .5176 L .956 .743 .576 r
F
.60079 .56209 m .59777 .55001 L .60322 .54459 L .689 .54 .679 r
F
.60322 .54459 m .60575 .53154 L .60869 .54021 L .634 .517 .702 r
F
.41563 .4658 m .41783 .46083 L .42098 .46405 L .664 .741 .908 r
F
.41563 .4658 m .41247 .46258 L .41783 .46083 L F
.75443 .46583 m .75759 .46083 L .76012 .46406 L .667 .744 .908 r
F
.75443 .46583 m .75189 .46264 L .75759 .46083 L F
.33785 .46566 m .33983 .4607 L .34313 .46392 L .664 .741 .908 r
F
.33785 .46566 m .33455 .46245 L .33983 .4607 L F
.42949 .46553 m .43172 .46057 L .43485 .46379 L F
.42949 .46553 m .42635 .46231 L .43172 .46057 L F
.49635 .47592 m .49782 .59088 L .50099 .58756 L .956 .671 .454 r
F
.49635 .47592 m .49332 .47375 L .49782 .59088 L F
.76834 .46554 m .77153 .46059 L .77404 .4638 L .662 .74 .908 r
F
.76834 .46554 m .76582 .46231 L .77153 .46059 L F
.3517 .4654 m .35371 .46045 L .35699 .46366 L .663 .741 .908 r
F
.3517 .4654 m .34842 .46218 L .35371 .46045 L F
.2739 .46526 m .27569 .4603 L .27911 .46352 L .664 .742 .908 r
F
.2739 .46526 m .27047 .46205 L .27569 .4603 L F
.73016 .50106 m .737 .55592 L .7383 .53825 L .824 .523 .481 r
F
.73016 .50106 m .72889 .5195 L .737 .55592 L F
.72561 .5212 m .72889 .5195 L .73016 .50106 L .034 0 .323 r
F
.44335 .46528 m .44562 .4603 L .44873 .46353 L .663 .741 .907 r
F
.44335 .46528 m .44023 .46205 L .44562 .4603 L F
.78225 .46528 m .78549 .46031 L .78797 .46353 L .664 .741 .908 r
F
.78225 .46528 m .77976 .46206 L .78549 .46031 L F
.59938 .48961 m .59683 .49937 L .60278 .5138 L .776 .453 .44 r
F
.36555 .46513 m .3676 .46016 L .37085 .46339 L .664 .742 .908 r
F
.36555 .46513 m .36229 .46191 L .3676 .46016 L F
.28773 .46499 m .28957 .46003 L .29296 .46325 L .664 .741 .908 r
F
.28773 .46499 m .28434 .46177 L .28957 .46003 L F
.45721 .465 m .45953 .46002 L .46261 .46325 L F
.45721 .465 m .45412 .46178 L .45953 .46002 L F
.79616 .465 m .79944 .46003 L .8019 .46325 L .664 .742 .908 r
F
.79616 .465 m .7937 .46178 L .79944 .46003 L F
.3794 .46486 m .3815 .4599 L .38472 .46312 L .663 .741 .908 r
F
.3794 .46486 m .37617 .46164 L .3815 .4599 L F
.30158 .46472 m .30345 .45976 L .30682 .46298 L .664 .741 .908 r
F
.30158 .46472 m .2982 .46151 L .30345 .45976 L F
.47108 .46473 m .47344 .45978 L .47649 .463 L .662 .741 .908 r
F
.47108 .46473 m .46802 .46151 L .47344 .45978 L F
.81008 .46473 m .8134 .45977 L .81583 .46299 L .663 .741 .908 r
F
.81008 .46473 m .80764 .46152 L .8134 .45977 L F
.39326 .46459 m .39539 .45964 L .39859 .46286 L .663 .742 .908 r
F
.39326 .46459 m .39005 .46138 L .39539 .45964 L F
.82401 .46447 m .82737 .45949 L .82977 .46272 L .664 .741 .908 r
F
.82401 .46447 m .82159 .46124 L .82737 .45949 L F
.31542 .46447 m .31734 .45949 L .32068 .46271 L F
.31542 .46447 m .31207 .46125 L .31734 .45949 L F
.48495 .46467 m .48725 .46842 L .49029 .47121 L .662 .172 0 r
F
.40712 .46433 m .4093 .45935 L .41247 .46258 L .664 .741 .908 r
F
.40712 .46433 m .40394 .46111 L .4093 .45935 L F
.32927 .46419 m .33123 .45922 L .33455 .46245 L F
.32927 .46419 m .32595 .46097 L .33123 .45922 L F
.83794 .4642 m .84133 .45922 L .84371 .46245 L .664 .741 .907 r
F
.83794 .4642 m .83555 .46097 L .84133 .45922 L F
.42098 .46405 m .4232 .45909 L .42635 .46231 L .663 .741 .908 r
F
.42098 .46405 m .41783 .46083 L .4232 .45909 L F
.76012 .46406 m .7633 .45909 L .76582 .46231 L F
.76012 .46406 m .75759 .46083 L .7633 .45909 L F
.58555 .49277 m .58845 .49945 L .59109 .49161 L .469 .127 .303 r
F
.58555 .49277 m .58289 .50055 L .58845 .49945 L F
.34313 .46392 m .34512 .45895 L .34842 .46218 L .664 .741 .908 r
F
.34313 .46392 m .33983 .4607 L .34512 .45895 L F
.43485 .46379 m .43711 .45883 L .44023 .46205 L .663 .741 .908 r
F
.43485 .46379 m .43172 .46057 L .43711 .45883 L F
.77404 .4638 m .77726 .45883 L .77976 .46206 L .664 .742 .908 r
F
.77404 .4638 m .77153 .46059 L .77726 .45883 L F
.35699 .46366 m .35902 .45869 L .36229 .46191 L F
.35699 .46366 m .35371 .46045 L .35902 .45869 L F
.27911 .46352 m .28092 .45855 L .28434 .46177 L .663 .741 .908 r
F
.27911 .46352 m .27569 .4603 L .28092 .45855 L F
.44873 .46353 m .45102 .45855 L .45412 .46178 L .664 .742 .908 r
F
.44873 .46353 m .44562 .4603 L .45102 .45855 L F
.78797 .46353 m .79122 .45855 L .7937 .46178 L .664 .741 .908 r
F
.78797 .46353 m .78549 .46031 L .79122 .45855 L F
.37085 .46339 m .37293 .45841 L .37617 .46164 L F
.37085 .46339 m .3676 .46016 L .37293 .45841 L F
.46261 .46325 m .46494 .45828 L .46802 .46151 L .663 .741 .908 r
F
.46261 .46325 m .45953 .46002 L .46494 .45828 L F
.29296 .46325 m .29482 .45827 L .2982 .46151 L .664 .741 .908 r
F
.29296 .46325 m .28957 .46003 L .29482 .45827 L F
.8019 .46325 m .8052 .45828 L .80764 .46152 L F
.8019 .46325 m .79944 .46003 L .8052 .45828 L F
.38472 .46312 m .38683 .45815 L .39005 .46138 L .663 .741 .908 r
F
.38472 .46312 m .3815 .4599 L .38683 .45815 L F
.30682 .46298 m .30871 .45801 L .31207 .46125 L F
.30682 .46298 m .30345 .45976 L .30871 .45801 L F
.81583 .46299 m .81917 .45802 L .82159 .46124 L .664 .742 .908 r
F
.81583 .46299 m .8134 .45977 L .81917 .45802 L F
.47649 .463 m .47344 .45978 L .47886 .45823 L .649 .737 .914 r
F
.39859 .46286 m .40075 .45788 L .40394 .46111 L .664 .742 .908 r
F
.39859 .46286 m .39539 .45964 L .40075 .45788 L F
.32068 .46271 m .32262 .45773 L .32595 .46097 L .664 .741 .908 r
F
.32068 .46271 m .31734 .45949 L .32262 .45773 L F
.82977 .46272 m .83315 .45774 L .83555 .46097 L .664 .742 .908 r
F
.82977 .46272 m .82737 .45949 L .83315 .45774 L F
.41247 .46258 m .41466 .4576 L .41783 .46083 L .664 .741 .908 r
F
.41247 .46258 m .4093 .45935 L .41466 .4576 L F
.75189 .46264 m .75504 .4576 L .75759 .46083 L .671 .748 .908 r
F
.75189 .46264 m .74935 .45947 L .75504 .4576 L F
.74651 .46894 m .74935 .45947 L .75189 .46264 L .909 .86 .781 r
F
.84371 .46245 m .84713 .45747 L .84951 .4607 L .663 .741 .908 r
F
.84371 .46245 m .84133 .45922 L .84713 .45747 L F
.33455 .46245 m .33652 .45747 L .33983 .4607 L F
.33455 .46245 m .33123 .45922 L .33652 .45747 L F
.76582 .46231 m .76902 .45734 L .77153 .46059 L .664 .742 .908 r
F
.76582 .46231 m .7633 .45909 L .76902 .45734 L F
.42635 .46231 m .42858 .45734 L .43172 .46057 L .663 .741 .908 r
F
.42635 .46231 m .4232 .45909 L .42858 .45734 L F
.34842 .46218 m .35043 .4572 L .35371 .46045 L F
.34842 .46218 m .34512 .45895 L .35043 .4572 L F
.44023 .46205 m .44251 .45707 L .44562 .4603 L .664 .742 .908 r
F
.44023 .46205 m .43711 .45883 L .44251 .45707 L F
.27047 .46205 m .27226 .45706 L .27569 .4603 L F
.27047 .46205 m .26704 .45882 L .27226 .45706 L F
.77976 .46206 m .78299 .45707 L .78549 .46031 L F
.77976 .46206 m .77726 .45883 L .78299 .45707 L F
.36229 .46191 m .36434 .45693 L .3676 .46016 L F
.36229 .46191 m .35902 .45869 L .36434 .45693 L F
.59109 .49161 m .59426 .50922 L .59683 .49937 L .747 .406 .407 r
F
.59109 .49161 m .58845 .49945 L .59426 .50922 L F
.74826 .5474 m .74663 .55913 L .74651 .46894 L .989 .739 .365 r
F
.74651 .46894 m .74404 .46713 L .74935 .45947 L .909 .86 .781 r
F
.74663 .55913 m .74404 .46713 L .74651 .46894 L .985 .733 .346 r
F
.63585 .50159 m .6328 .48948 L .63717 .5125 L .875 .573 .056 r
F
.63585 .50159 m .63717 .5125 L .63746 .51174 L F
.6328 .48948 m .6366 .51401 L .63968 .52577 L .924 .596 .135 r
F
.63665 .51384 m .63927 .50335 L .64165 .49499 L .508 .417 .688 r
F
.6366 .51401 m .63664 .51386 L .63665 .51384 L F
.63664 .51386 m .63927 .50335 L .63665 .51384 L F
.63746 .51174 m .63717 .5125 L .63968 .52577 L .875 .573 .056 r
F
.28434 .46177 m .28617 .45679 L .28957 .46003 L .664 .741 .908 r
F
.28434 .46177 m .28092 .45855 L .28617 .45679 L F
.45412 .46178 m .45644 .45679 L .45953 .46002 L F
.45412 .46178 m .45102 .45855 L .45644 .45679 L F
.7937 .46178 m .79698 .4568 L .79944 .46003 L .663 .741 .908 r
F
.7937 .46178 m .79122 .45855 L .79698 .4568 L F
.49332 .47375 m .49465 .59295 L .49782 .59088 L .957 .672 .455 r
F
.49332 .47375 m .49029 .47121 L .49465 .59295 L F
.37617 .46164 m .37826 .45666 L .3815 .4599 L .663 .741 .908 r
F
.37617 .46164 m .37293 .45841 L .37826 .45666 L F
.2982 .46151 m .30007 .45652 L .30345 .45976 L F
.2982 .46151 m .29482 .45827 L .30007 .45652 L F
.46802 .46151 m .47037 .45654 L .47344 .45978 L F
.46802 .46151 m .46494 .45828 L .47037 .45654 L F
.80764 .46152 m .81096 .45652 L .8134 .45977 L F
.80764 .46152 m .8052 .45828 L .81096 .45652 L F
.39005 .46138 m .39218 .4564 L .39539 .45964 L F
.39005 .46138 m .38683 .45815 L .39218 .4564 L F
.82159 .46124 m .82495 .45626 L .82737 .45949 L .664 .742 .908 r
F
.82159 .46124 m .81917 .45802 L .82495 .45626 L F
.31207 .46125 m .31398 .45625 L .31734 .45949 L .664 .741 .908 r
F
.31207 .46125 m .30871 .45801 L .31398 .45625 L F
.48191 .46148 m .48419 .46584 L .48725 .46842 L .712 .23 0 r
F
.40394 .46111 m .40611 .45612 L .4093 .45935 L .664 .741 .908 r
F
.40394 .46111 m .40075 .45788 L .40611 .45612 L F
.83555 .46097 m .83894 .45598 L .84133 .45922 L .664 .742 .908 r
F
.83555 .46097 m .83315 .45774 L .83894 .45598 L F
.32595 .46097 m .3279 .45598 L .33123 .45922 L .663 .741 .908 r
F
.32595 .46097 m .32262 .45773 L .3279 .45598 L F
.41783 .46083 m .42004 .45585 L .4232 .45909 L F
.41783 .46083 m .41466 .4576 L .42004 .45585 L F
.75759 .46083 m .76076 .45586 L .7633 .45909 L F
.75759 .46083 m .75504 .4576 L .76076 .45586 L F
.33983 .4607 m .34182 .45571 L .34512 .45895 L .664 .741 .908 r
F
.33983 .4607 m .33652 .45747 L .34182 .45571 L F
.84951 .4607 m .85294 .45571 L .85531 .45896 L F
.84951 .4607 m .84713 .45747 L .85294 .45571 L F
.43172 .46057 m .43398 .45559 L .43711 .45883 L .663 .742 .909 r
F
.43172 .46057 m .42858 .45734 L .43398 .45559 L F
.77153 .46059 m .77475 .4556 L .77726 .45883 L .662 .74 .908 r
F
.77153 .46059 m .76902 .45734 L .77475 .4556 L F
.35371 .46045 m .35574 .45545 L .35902 .45869 L .664 .741 .907 r
F
.35371 .46045 m .35043 .4572 L .35574 .45545 L F
.27569 .4603 m .2775 .4553 L .28092 .45855 L .663 .741 .908 r
F
.27569 .4603 m .27226 .45706 L .2775 .4553 L F
.44562 .4603 m .44791 .45531 L .45102 .45855 L .664 .742 .908 r
F
.44562 .4603 m .44251 .45707 L .44791 .45531 L F
.78549 .46031 m .78874 .45531 L .79122 .45855 L .664 .741 .908 r
F
.78549 .46031 m .78299 .45707 L .78874 .45531 L F
.3676 .46016 m .36967 .45517 L .37293 .45841 L F
.3676 .46016 m .36434 .45693 L .36967 .45517 L F
.45953 .46002 m .46186 .45504 L .46494 .45828 L .663 .741 .908 r
F
.45953 .46002 m .45644 .45679 L .46186 .45504 L F
.28957 .46003 m .29142 .45503 L .29482 .45827 L .664 .741 .908 r
F
.28957 .46003 m .28617 .45679 L .29142 .45503 L F
.79944 .46003 m .80274 .45504 L .8052 .45828 L .663 .741 .908 r
F
.79944 .46003 m .79698 .4568 L .80274 .45504 L F
.3815 .4599 m .38361 .4549 L .38683 .45815 L F
.3815 .4599 m .37826 .45666 L .38361 .4549 L F
.30345 .45976 m .30534 .45476 L .30871 .45801 L .664 .742 .908 r
F
.30345 .45976 m .30007 .45652 L .30534 .45476 L F
.8134 .45977 m .81674 .45477 L .81917 .45802 L .663 .74 .907 r
F
.8134 .45977 m .81096 .45652 L .81674 .45477 L F
.47344 .45978 m .4758 .455 L .47886 .45823 L .648 .736 .914 r
F
.47344 .45978 m .47037 .45654 L .4758 .455 L F
.39539 .45964 m .39754 .45463 L .40075 .45788 L .664 .741 .908 r
F
.39539 .45964 m .39218 .4564 L .39754 .45463 L F
.7597 .66357 m .75724 .66325 L .75319 .51529 L .977 .704 .44 r
F
.31734 .45949 m .31927 .45449 L .32262 .45773 L .664 .742 .908 r
F
.31734 .45949 m .31398 .45625 L .31927 .45449 L F
.82737 .45949 m .83074 .4545 L .83315 .45774 L F
.82737 .45949 m .82495 .45626 L .83074 .4545 L F
.4093 .45935 m .41148 .45435 L .41466 .4576 L .664 .741 .908 r
F
.4093 .45935 m .40611 .45612 L .41148 .45435 L F
.74935 .45947 m .75249 .45436 L .75504 .4576 L .67 .743 .905 r
F
.74935 .45947 m .74679 .45622 L .75249 .45436 L F
.74404 .46713 m .74679 .45622 L .74935 .45947 L .953 .881 .724 r
F
.84133 .45922 m .84475 .45422 L .84713 .45747 L .664 .741 .908 r
F
.84133 .45922 m .83894 .45598 L .84475 .45422 L F
.33123 .45922 m .3332 .45422 L .33652 .45747 L .663 .741 .908 r
F
.33123 .45922 m .3279 .45598 L .3332 .45422 L F
.4232 .45909 m .42543 .4541 L .42858 .45734 L F
.4232 .45909 m .42004 .45585 L .42543 .4541 L F
.7633 .45909 m .76649 .4541 L .76902 .45734 L F
.7633 .45909 m .76076 .45586 L .76649 .4541 L F
.34512 .45895 m .34713 .45395 L .35043 .4572 L .664 .741 .908 r
F
.34512 .45895 m .34182 .45571 L .34713 .45395 L F
.85531 .45896 m .85876 .45395 L .86112 .45721 L F
.85531 .45896 m .85294 .45571 L .85876 .45395 L F
.73936 .51742 m .7383 .53825 L .75113 .64511 L .91 .611 .465 r
F
.26704 .45882 m .26882 .45381 L .27226 .45706 L .664 .741 .908 r
F
.26704 .45882 m .26359 .45558 L .26882 .45381 L F
.43711 .45883 m .43938 .45382 L .44251 .45707 L .664 .742 .908 r
F
.43711 .45883 m .43398 .45559 L .43938 .45382 L F
.77726 .45883 m .78049 .45382 L .78299 .45707 L F
.77726 .45883 m .77475 .4556 L .78049 .45382 L F
.64198 .51501 m .63968 .52577 L .64394 .48519 L .962 .79 .351 r
F
.64394 .48519 m .64165 .49499 L .6465 .47202 L .761 .731 .205 r
F
.63968 .52577 m .64165 .49499 L .64394 .48519 L .827 .624 .628 r
F
.35902 .45869 m .36107 .45368 L .36434 .45693 L .664 .741 .908 r
F
.35902 .45869 m .35574 .45545 L .36107 .45368 L F
.53118 .68809 m .52809 .67803 L .53345 .53889 L .942 .685 .519 r
F
.28092 .45855 m .28275 .45354 L .28617 .45679 L .664 .741 .908 r
F
.28092 .45855 m .2775 .4553 L .28275 .45354 L F
.45102 .45855 m .45333 .45354 L .45644 .45679 L F
.45102 .45855 m .44791 .45531 L .45333 .45354 L F
.79122 .45855 m .7945 .45354 L .79698 .4568 L F
.79122 .45855 m .78874 .45531 L .7945 .45354 L F
.37293 .45841 m .37501 .45341 L .37826 .45666 L .663 .741 .908 r
F
.37293 .45841 m .36967 .45517 L .37501 .45341 L F
.29482 .45827 m .29668 .45328 L .30007 .45652 L F
.29482 .45827 m .29142 .45503 L .29668 .45328 L F
.8052 .45828 m .80851 .45328 L .81096 .45652 L .664 .742 .908 r
F
.8052 .45828 m .80274 .45504 L .80851 .45328 L F
.46494 .45828 m .46729 .45329 L .47037 .45654 L .663 .741 .908 r
F
.46494 .45828 m .46186 .45504 L .46729 .45329 L F
.49029 .47121 m .49145 .59492 L .49465 .59295 L .957 .673 .455 r
F
.49029 .47121 m .48725 .46842 L .49145 .59492 L F
.64954 .48333 m .6465 .47202 L .65275 .48703 L 0 0 .52 r
F
.6465 .47202 m .64941 .46828 L .65275 .48703 L .72 .987 .813 r
F
.6465 .47202 m .64389 .47281 L .64941 .46828 L F
.64165 .49499 m .64389 .47281 L .6465 .47202 L .954 .812 .37 r
F
.38683 .45815 m .38896 .45314 L .39218 .4564 L .663 .741 .908 r
F
.38683 .45815 m .38361 .4549 L .38896 .45314 L F
.30871 .45801 m .31062 .453 L .31398 .45625 L F
.30871 .45801 m .30534 .45476 L .31062 .453 L F
.81917 .45802 m .82253 .453 L .82495 .45626 L .664 .741 .908 r
F
.81917 .45802 m .81674 .45477 L .82253 .453 L F
.47886 .45823 m .48112 .46325 L .48419 .46584 L .757 .281 0 r
F
.47886 .45823 m .4758 .455 L .48112 .46325 L F
.74663 .55913 m .74522 .57479 L .74404 .46713 L .985 .733 .346 r
F
.74404 .46713 m .74162 .46617 L .74679 .45622 L .953 .881 .724 r
F
.74522 .57479 m .74162 .46617 L .74404 .46713 L .99 .727 .383 r
F
.40075 .45788 m .40291 .45287 L .40611 .45612 L .664 .741 .908 r
F
.40075 .45788 m .39754 .45463 L .40291 .45287 L F
.32262 .45773 m .32456 .45273 L .3279 .45598 L .663 .741 .908 r
F
.32262 .45773 m .31927 .45449 L .32456 .45273 L F
.83315 .45774 m .83655 .45273 L .83894 .45598 L .664 .742 .908 r
F
.83315 .45774 m .83074 .4545 L .83655 .45273 L F
.41466 .4576 m .41687 .4526 L .42004 .45585 L .663 .741 .908 r
F
.41466 .4576 m .41148 .45435 L .41687 .4526 L F
.75504 .4576 m .75822 .45259 L .76076 .45586 L .664 .742 .908 r
F
.75504 .4576 m .75249 .45436 L .75822 .45259 L F
.33652 .45747 m .3385 .45246 L .34182 .45571 L .663 .741 .908 r
F
.33652 .45747 m .3332 .45422 L .3385 .45246 L F
.84713 .45747 m .85057 .45246 L .85294 .45571 L F
.84713 .45747 m .84475 .45422 L .85057 .45246 L F
.76902 .45734 m .77223 .45233 L .77475 .4556 L .664 .742 .908 r
F
.76902 .45734 m .76649 .4541 L .77223 .45233 L F
.42858 .45734 m .43083 .45234 L .43398 .45559 L .663 .742 .908 r
F
.42858 .45734 m .42543 .4541 L .43083 .45234 L F
.72561 .5212 m .7243 .53997 L .72889 .5195 L .034 0 .323 r
F
.35043 .4572 m .35245 .45219 L .35574 .45545 L .663 .741 .908 r
F
.35043 .4572 m .34713 .45395 L .35245 .45219 L F
.86112 .45721 m .8646 .45219 L .86695 .45545 L .663 .74 .907 r
F
.86112 .45721 m .85876 .45395 L .8646 .45219 L F
.6528 .50022 m .64954 .48333 L .65616 .50698 L 0 0 .437 r
F
.64954 .48333 m .65275 .48703 L .65616 .50698 L 0 0 .52 r
F
.27226 .45706 m .27407 .45205 L .2775 .4553 L .664 .741 .908 r
F
.27226 .45706 m .26882 .45381 L .27407 .45205 L F
.78299 .45707 m .78625 .45205 L .78874 .45531 L F
.78299 .45707 m .78049 .45382 L .78625 .45205 L F
.44251 .45707 m .44479 .45205 L .44791 .45531 L F
.44251 .45707 m .43938 .45382 L .44479 .45205 L F
.36434 .45693 m .36641 .45191 L .36967 .45517 L F
.36434 .45693 m .36107 .45368 L .36641 .45191 L F
.45644 .45679 m .45876 .45178 L .46186 .45504 L .663 .741 .908 r
F
.45644 .45679 m .45333 .45354 L .45876 .45178 L F
.28617 .45679 m .28801 .45178 L .29142 .45503 L .664 .741 .908 r
F
.28617 .45679 m .28275 .45354 L .28801 .45178 L F
.79698 .4568 m .80027 .45179 L .80274 .45504 L .663 .741 .908 r
F
.79698 .4568 m .7945 .45354 L .80027 .45179 L F
.37826 .45666 m .38037 .45164 L .38361 .4549 L .664 .741 .908 r
F
.37826 .45666 m .37501 .45341 L .38037 .45164 L F
.30007 .45652 m .30196 .45151 L .30534 .45476 L .664 .742 .908 r
F
.30007 .45652 m .29668 .45328 L .30196 .45151 L F
.81096 .45652 m .8143 .45151 L .81674 .45477 L F
.81096 .45652 m .80851 .45328 L .8143 .45151 L F
.47269 .45181 m .46965 .44854 L .47273 .4518 L .643 .736 .916 r
F
.46729 .45329 m .46965 .44854 L .47269 .45181 L F
.4642 .45003 m .46656 .4452 L .46965 .44854 L .648 .737 .914 r
F
.46965 .44854 m .46656 .4452 L .46659 .44526 L .768 .298 0 r
F
.47037 .45654 m .47273 .4518 L .47577 .45501 L .643 .735 .915 r
F
.47037 .45654 m .46729 .45329 L .47273 .4518 L F
.46729 .45329 m .4642 .45003 L .46965 .44854 L .643 .736 .916 r
F
.46965 .44854 m .46659 .44526 L .47186 .45376 L .768 .298 0 r
F
.47273 .4518 m .46965 .44854 L .46968 .44859 L .762 .287 0 r
F
.47273 .4518 m .46968 .44859 L .47496 .4569 L F
.47577 .45501 m .47273 .4518 L .4758 .455 L .643 .735 .915 r
F
.39218 .4564 m .39433 .45138 L .39754 .45463 L .663 .741 .908 r
F
.39218 .4564 m .38896 .45314 L .39433 .45138 L F
.31398 .45625 m .31591 .45123 L .31927 .45449 L .664 .741 .908 r
F
.31398 .45625 m .31062 .453 L .31591 .45123 L F
.82495 .45626 m .82833 .45123 L .83074 .4545 L F
.82495 .45626 m .82253 .453 L .82833 .45123 L F
.40611 .45612 m .40829 .4511 L .41148 .45435 L .664 .742 .908 r
F
.40611 .45612 m .40291 .45287 L .40829 .4511 L F
.74679 .45622 m .74993 .4511 L .75249 .45436 L .676 .751 .908 r
F
.74679 .45622 m .74422 .45306 L .74993 .4511 L F
.74162 .46617 m .74422 .45306 L .74679 .45622 L .964 .855 .685 r
F
.66151 .52252 m .65914 .52823 L .66435 .51608 L 0 0 0 r
F
.83894 .45598 m .84236 .45097 L .84475 .45422 L .663 .741 .908 r
F
.83894 .45598 m .83655 .45273 L .84236 .45097 L F
.3279 .45598 m .32986 .45096 L .3332 .45422 L .664 .741 .908 r
F
.3279 .45598 m .32456 .45273 L .32986 .45096 L F
.42004 .45585 m .42226 .45084 L .42543 .4541 L .663 .741 .908 r
F
.42004 .45585 m .41687 .4526 L .42226 .45084 L F
.76076 .45586 m .76396 .45085 L .76649 .4541 L .662 .74 .908 r
F
.76076 .45586 m .75822 .45259 L .76396 .45085 L F
.34182 .45571 m .34382 .45069 L .34713 .45395 L .664 .742 .908 r
F
.34182 .45571 m .3385 .45246 L .34382 .45069 L F
.85294 .45571 m .8564 .45071 L .85876 .45395 L .663 .741 .908 r
F
.85294 .45571 m .85057 .45246 L .8564 .45071 L F
.26359 .45558 m .26537 .45056 L .26882 .45381 L F
.26359 .45558 m .26013 .45232 L .26537 .45056 L F
.43398 .45559 m .43624 .45056 L .43938 .45382 L .664 .741 .908 r
F
.43398 .45559 m .43083 .45234 L .43624 .45056 L F
.77475 .4556 m .77799 .45057 L .78049 .45382 L .663 .74 .907 r
F
.77475 .4556 m .77223 .45233 L .77799 .45057 L F
.35574 .45545 m .35779 .45042 L .36107 .45368 L .664 .741 .908 r
F
.35574 .45545 m .35245 .45219 L .35779 .45042 L F
.86695 .45545 m .87044 .45042 L .87278 .45368 L .663 .741 .907 r
F
.86695 .45545 m .8646 .45219 L .87044 .45042 L F
.2775 .4553 m .27932 .45028 L .28275 .45354 L .664 .741 .908 r
F
.2775 .4553 m .27407 .45205 L .27932 .45028 L F
.44791 .45531 m .45022 .45028 L .45333 .45354 L .664 .742 .908 r
F
.44791 .45531 m .44479 .45205 L .45022 .45028 L F
.78874 .45531 m .79202 .45028 L .7945 .45354 L .664 .741 .908 r
F
.78874 .45531 m .78625 .45205 L .79202 .45028 L F
.36967 .45517 m .37175 .45015 L .37501 .45341 L .663 .741 .908 r
F
.36967 .45517 m .36641 .45191 L .37175 .45015 L F
.59683 .49937 m .60002 .51476 L .60278 .5138 L .664 .337 .41 r
F
.59683 .49937 m .59426 .50922 L .60002 .51476 L F
.29142 .45503 m .29328 .45001 L .29668 .45328 L .663 .741 .908 r
F
.29142 .45503 m .28801 .45178 L .29328 .45001 L F
.46186 .45504 m .4642 .45003 L .46729 .45329 L .662 .741 .908 r
F
.46186 .45504 m .45876 .45178 L .4642 .45003 L F
.80274 .45504 m .80605 .45003 L .80851 .45328 L .663 .741 .908 r
F
.80274 .45504 m .80027 .45179 L .80605 .45003 L F
.58289 .50055 m .58576 .5057 L .58845 .49945 L .418 .062 .25 r
F
.38361 .4549 m .38573 .44988 L .38896 .45314 L .663 .741 .908 r
F
.38361 .4549 m .38037 .45164 L .38573 .44988 L F
.30534 .45476 m .30724 .44974 L .31062 .453 L F
.30534 .45476 m .30196 .45151 L .30724 .44974 L F
.81674 .45477 m .82009 .44974 L .82253 .453 L .664 .741 .908 r
F
.81674 .45477 m .8143 .45151 L .82009 .44974 L F
.48725 .46842 m .48824 .59608 L .49145 .59492 L .957 .673 .456 r
F
.48725 .46842 m .48419 .46584 L .48824 .59608 L F
.4758 .455 m .47804 .4602 L .48112 .46325 L .768 .293 0 r
F
.4758 .455 m .47273 .4518 L .47804 .4602 L F
.39754 .45463 m .3997 .44961 L .40291 .45287 L .664 .741 .908 r
F
.39754 .45463 m .39433 .45138 L .3997 .44961 L F
.31927 .45449 m .32121 .44946 L .32456 .45273 L F
.31927 .45449 m .31591 .45123 L .32121 .44946 L F
.83074 .4545 m .83414 .44946 L .83655 .45273 L F
.83074 .4545 m .82833 .45123 L .83414 .44946 L F
.41148 .45435 m .41369 .44933 L .41687 .4526 L .663 .741 .908 r
F
.41148 .45435 m .40829 .4511 L .41369 .44933 L F
.75249 .45436 m .75567 .44934 L .75822 .45259 L F
.75249 .45436 m .74993 .4511 L .75567 .44934 L F
.53521 .53167 m .53219 .51981 L .53759 .47116 L .902 .664 .569 r
F
.53219 .51981 m .53464 .47203 L .53759 .47116 L .884 .656 .588 r
F
.53759 .47116 m .53464 .47203 L .54042 .5245 L .943 .633 .423 r
F
.84475 .45422 m .84819 .4492 L .85057 .45246 L .663 .742 .908 r
F
.84475 .45422 m .84236 .45097 L .84819 .4492 L F
.3332 .45422 m .33518 .4492 L .3385 .45246 L .663 .741 .908 r
F
.3332 .45422 m .32986 .45096 L .33518 .4492 L F
.42543 .4541 m .42767 .44907 L .43083 .45234 L .664 .741 .908 r
F
.42543 .4541 m .42226 .45084 L .42767 .44907 L F
.76649 .4541 m .76971 .44908 L .77223 .45233 L .663 .742 .908 r
F
.76649 .4541 m .76396 .45085 L .76971 .44908 L F
.85876 .45395 m .86224 .44894 L .8646 .45219 L .663 .742 .909 r
F
.85876 .45395 m .8564 .45071 L .86224 .44894 L F
.34713 .45395 m .34915 .44892 L .35245 .45219 L .664 .741 .908 r
F
.34713 .45395 m .34382 .45069 L .34915 .44892 L F
.59699 .50431 m .59917 .47389 L .60204 .47828 L .854 .649 .625 r
F
.60204 .47828 m .59917 .47389 L .6003 .47814 L .938 .572 .191 r
F
.60278 .5138 m .60002 .51476 L .60213 .50075 L .985 .777 .542 r
F
.60331 .50585 m .60213 .50075 L .60487 .48253 L F
.60278 .5138 m .60213 .50075 L .60331 .50585 L F
.60002 .51476 m .60204 .47828 L .6049 .48234 L .87 .654 .607 r
F
.60002 .51476 m .59699 .50431 L .60204 .47828 L F
.59699 .50431 m .59398 .49441 L .59917 .47389 L .854 .649 .625 r
F
.59398 .49441 m .59646 .47689 L .59917 .47389 L .706 .556 .682 r
F
.59917 .47389 m .59646 .47689 L .60138 .49482 L .895 .545 .376 r
F
.60224 .49648 m .60138 .49482 L .60263 .49939 L F
.59917 .47389 m .60138 .49482 L .60224 .49648 L F
.60199 .49704 m .59955 .48708 L .60263 .49939 L .757 .343 .265 r
F
.59735 .48016 m .59955 .48708 L .60199 .49704 L F
.59646 .47689 m .59705 .47884 L .59735 .48016 L F
.59705 .47884 m .59955 .48708 L .59735 .48016 L F
.59398 .49441 m .59094 .483 L .59646 .47689 L .706 .556 .682 r
F
.59646 .47689 m .59372 .4801 L .59955 .48708 L .757 .343 .265 r
F
.59955 .48708 m .59653 .47791 L .5971 .47711 L .755 .606 .693 r
F
.60278 .5138 m .60487 .48253 L .60488 .48254 L .985 .777 .542 r
F
.60237 .48012 m .6003 .47814 L .60537 .49731 L .938 .572 .191 r
F
.60204 .47828 m .6003 .47814 L .60237 .48012 L F
.59917 .47389 m .60263 .49939 L .60537 .49731 L .895 .545 .376 r
F
.59955 .48708 m .5971 .47711 L .60205 .47018 L .755 .606 .693 r
F
.59379 .48018 m .59653 .47791 L .59955 .48708 L .464 .856 .658 r
F
.59372 .4801 m .59374 .48008 L .59379 .48018 L F
.59374 .48008 m .59653 .47791 L .59379 .48018 L F
.60488 .48254 m .60487 .48253 L .6049 .48234 L .985 .777 .542 r
F
.6049 .48234 m .60204 .47828 L .60766 .49807 L .933 .56 .18 r
F
.60785 .49821 m .60766 .49807 L .60815 .4998 L F
.6049 .48234 m .60766 .49807 L .60785 .49821 L F
.60537 .49731 m .60263 .49939 L .60333 .49498 L .993 .793 .529 r
F
.6049 .48234 m .60815 .4998 L .60818 .49984 L .933 .56 .18 r
F
.60204 .47828 m .60537 .49731 L .60822 .50005 L .938 .572 .191 r
F
.60703 .47511 m .60667 .47371 L .60755 .46809 L .993 .793 .529 r
F
.60551 .49657 m .60755 .46809 L .61037 .47033 L F
.60544 .49648 m .60755 .46809 L .60551 .49657 L F
.60822 .50005 m .61037 .47033 L .61327 .4764 L .953 .746 .585 r
F
.60818 .49984 m .60815 .4998 L .60822 .50005 L .933 .56 .18 r
F
.60822 .50005 m .60537 .49731 L .61037 .47033 L .953 .746 .585 r
F
.60263 .49939 m .60475 .46685 L .60755 .46809 L .829 .622 .623 r
F
.60755 .46809 m .60475 .46685 L .61013 .48056 L .907 .501 .199 r
F
.61059 .48127 m .61013 .48056 L .61084 .48235 L F
.60755 .46809 m .61013 .48056 L .61059 .48127 L F
.60517 .46791 m .6078 .47263 L .61084 .48235 L .598 .149 .157 r
F
.60475 .46685 m .60503 .46738 L .60517 .46791 L F
.60503 .46738 m .6078 .47263 L .60517 .46791 L F
.60263 .49939 m .59955 .48708 L .60475 .46685 L .829 .622 .623 r
F
.59955 .48708 m .60205 .47018 L .60475 .46685 L .755 .606 .693 r
F
.60475 .46685 m .60205 .47018 L .6078 .47263 L .598 .149 .157 r
F
.59925 .47057 m .60178 .4549 L .60481 .46441 L .991 .862 .61 r
F
.60481 .46441 m .60178 .4549 L .60207 .45629 L .91 .585 .106 r
F
.60407 .47104 m .60481 .46441 L .60755 .47252 L .876 .988 .821 r
F
.60268 .46886 m .60481 .46441 L .60407 .47104 L F
.60544 .49648 m .60333 .49498 L .60667 .47371 L .993 .793 .529 r
F
.60544 .49648 m .60667 .47371 L .60703 .47511 L F
.60205 .47018 m .59925 .47057 L .60481 .46441 L .876 .988 .821 r
F
.60481 .46441 m .60207 .45629 L .60778 .48438 L .91 .585 .106 r
F
.60481 .46441 m .60778 .48438 L .60795 .48462 L F
.60755 .47252 m .60481 .46441 L .6078 .47263 L .876 .988 .821 r
F
.61084 .49468 m .60822 .50005 L .61177 .4834 L .983 .851 .468 r
F
.61218 .48462 m .61177 .4834 L .61327 .4764 L F
.61084 .49468 m .61177 .4834 L .61218 .48462 L F
.61084 .48235 m .6078 .47263 L .60869 .47458 L 0 0 .505 r
F
.60997 .47793 m .61084 .48235 L .61297 .49011 L .907 .501 .199 r
F
.60755 .46809 m .60945 .47633 L .60997 .47793 L F
.60945 .47633 m .61084 .48235 L .60997 .47793 L F
.61037 .47033 m .60755 .46809 L .61297 .49011 L .944 .584 .279 r
F
.61359 .49173 m .61297 .49011 L .61392 .49394 L F
.61037 .47033 m .61297 .49011 L .61359 .49173 L F
.61037 .47033 m .61392 .49394 L .61676 .49688 L F
.61297 .49011 m .61084 .48235 L .61392 .49394 L .907 .501 .199 r
F
.61327 .4764 m .61037 .47033 L .61572 .49257 L .934 .58 .159 r
F
.61603 .49259 m .61572 .49257 L .61676 .49688 L F
.61327 .4764 m .61572 .49257 L .61603 .49259 L F
.61425 .49249 m .6164 .47653 L .61901 .47166 L .699 .551 .683 r
F
.61392 .49394 m .61412 .49249 L .61425 .49249 L F
.61412 .49249 m .6164 .47653 L .61425 .49249 L F
.61392 .49394 m .61084 .48235 L .6164 .47653 L F
.61084 .48235 m .61388 .48598 L .6164 .47653 L 0 0 .505 r
F
.61016 .47163 m .61031 .44971 L .61304 .44788 L .984 .764 .526 r
F
.61084 .48235 m .60869 .47458 L .61354 .48522 L 0 0 .505 r
F
.61366 .48572 m .61354 .48522 L .61388 .48598 L F
.61084 .48235 m .61354 .48522 L .61366 .48572 L F
.6078 .47263 m .61125 .49203 L .61388 .48598 L .902 .564 .084 r
F
.6078 .47263 m .60481 .46441 L .60959 .48491 L F
.60205 .47018 m .60268 .46886 L .60407 .47104 L .876 .988 .821 r
F
.60178 .4549 m .60549 .48759 L .6083 .48694 L .962 .627 .279 r
F
.61068 .4896 m .6083 .48694 L .61125 .49203 L .91 .585 .106 r
F
.60481 .46441 m .6083 .48689 L .61068 .4896 L F
.59266 .4811 m .59372 .4801 L .59646 .47689 L .204 .246 .684 r
F
.59094 .483 m .59372 .4801 L .59266 .4811 L F
.59094 .483 m .58792 .47248 L .59372 .4801 L F
.59261 .47863 m .59093 .48169 L .59372 .4801 L .792 .41 0 r
F
.58792 .47248 m .59093 .48169 L .59261 .47863 L F
.58845 .49945 m .58576 .5057 L .59155 .51407 L .744 .386 .373 r
F
.58576 .5057 m .58874 .51499 L .59155 .51407 L .668 .277 .297 r
F
.58576 .5057 m .58302 .51074 L .58874 .51499 L F
.58578 .50801 m .58792 .47248 L .59094 .483 L .865 .651 .61 r
F
.58018 .5074 m .58302 .51074 L .58576 .5057 L .359 0 .134 r
F
.58578 .50801 m .58274 .49743 L .58792 .47248 L .865 .651 .61 r
F
.58274 .49743 m .58499 .46659 L .58792 .47248 L .848 .643 .625 r
F
.58499 .46659 m .58821 .48775 L .59093 .48169 L .944 .591 .195 r
F
.59093 .48169 m .58821 .48775 L .58925 .48477 L .83 .844 .38 r
F
.58792 .47248 m .58499 .46659 L .59093 .48169 L .792 .41 0 r
F
.59093 .48169 m .58925 .48477 L .59359 .47226 L .83 .844 .38 r
F
.59372 .4801 m .59093 .48169 L .59479 .47908 L .464 .856 .658 r
F
.59372 .4801 m .59479 .47908 L .59653 .47791 L F
.59653 .47791 m .59359 .47226 L .59925 .47057 L .647 .625 .814 r
F
.59912 .47061 m .59646 .47177 L .59925 .47057 L .02 .084 .59 r
F
.59359 .47226 m .59646 .47177 L .59912 .47061 L F
.59093 .48169 m .59359 .47226 L .59653 .47791 L .83 .844 .38 r
F
.59359 .47226 m .59049 .45891 L .59646 .47177 L .02 .084 .59 r
F
.58821 .48775 m .59049 .45891 L .59359 .47226 L .953 .749 .589 r
F
.59049 .45891 m .59365 .4735 L .59646 .47177 L .903 .526 .08 r
F
.59646 .47177 m .59365 .4735 L .59377 .47294 L .995 .821 .557 r
F
.59646 .47177 m .59377 .47294 L .59831 .452 L F
.59646 .47177 m .59831 .452 L .59854 .45241 L F
.59925 .47057 m .59646 .47177 L .60063 .45856 L .991 .862 .61 r
F
.60108 .45925 m .60063 .45856 L .60178 .4549 L F
.59925 .47057 m .60063 .45856 L .60108 .45925 L F
.59653 .47791 m .59925 .47057 L .60205 .47018 L .647 .625 .814 r
F
.59646 .47177 m .59885 .4495 L .60178 .4549 L .995 .821 .557 r
F
.59365 .4735 m .59593 .44511 L .59885 .4495 L .948 .744 .595 r
F
.58274 .49743 m .57971 .48702 L .58499 .46659 L .848 .643 .625 r
F
.57971 .48702 m .58206 .46094 L .58499 .46659 L .774 .586 .646 r
F
.57971 .48702 m .57664 .47404 L .58206 .46094 L F
.57664 .47404 m .5792 .4605 L .58206 .46094 L .651 .531 .705 r
F
.57664 .47404 m .57361 .46345 L .5792 .4605 L F
.57895 .46063 m .57634 .46032 L .5792 .4605 L .293 .377 .778 r
F
.57361 .46345 m .57634 .46032 L .57895 .46063 L F
.57361 .46345 m .57063 .45626 L .57634 .46032 L F
.57634 .46032 m .57343 .45886 L .57371 .46 L .939 .583 .306 r
F
.57634 .46032 m .57371 .46 L .57953 .48443 L F
.57634 .46032 m .57953 .48443 L .58239 .48303 L F
.58239 .48303 m .57953 .48443 L .58067 .47668 L .987 .777 .533 r
F
.58499 .46659 m .58206 .46094 L .58746 .48447 L .944 .591 .195 r
F
.58206 .46094 m .5853 .48511 L .58821 .48775 L .931 .575 .323 r
F
.58206 .46094 m .5792 .4605 L .5853 .48511 L F
.5792 .4605 m .58239 .48303 L .5853 .48511 L .925 .563 .318 r
F
.5792 .4605 m .57634 .46032 L .58239 .48303 L F
.58267 .47897 m .58067 .47668 L .58459 .45012 L .987 .777 .533 r
F
.58267 .47897 m .58459 .45012 L .58461 .45014 L F
.58499 .46659 m .58746 .48447 L .58774 .48479 L .944 .591 .195 r
F
.58499 .46659 m .58815 .48748 L .58818 .48752 L F
.58721 .45553 m .58463 .44986 L .58755 .45358 L .987 .777 .533 r
F
.58239 .48303 m .58463 .44986 L .58721 .45553 L F
.57953 .48443 m .58164 .44247 L .58463 .44986 L .925 .698 .575 r
F
.58463 .44986 m .58164 .44247 L .58205 .44418 L .913 .566 .104 r
F
.58461 .45014 m .58459 .45012 L .58463 .44986 L .987 .777 .533 r
F
.58543 .48329 m .583 .47955 L .58721 .45553 L .961 .75 .574 r
F
.58739 .45589 m .58721 .45553 L .58755 .45358 L F
.58543 .48329 m .58721 .45553 L .58739 .45589 L F
.58463 .44986 m .58205 .44418 L .5824 .44565 L .913 .566 .104 r
F
.5853 .48511 m .58755 .45358 L .59049 .45891 L .961 .75 .574 r
F
.58473 .45044 m .5824 .44565 L .5878 .46815 L .913 .566 .104 r
F
.58463 .44986 m .5824 .44565 L .58473 .45044 L F
.58164 .44247 m .58492 .46709 L .58783 .46824 L .944 .588 .291 r
F
.57428 .50111 m .57664 .47404 L .57971 .48702 L .863 .666 .635 r
F
.57127 .49278 m .57361 .46345 L .57664 .47404 L .846 .645 .63 r
F
.57428 .50111 m .57127 .49278 L .57664 .47404 L .863 .666 .635 r
F
.57952 .48437 m .57652 .47768 L .57953 .48443 L .877 .504 .334 r
F
.5782 .47886 m .57619 .47569 L .57835 .4795 L F
.57343 .45886 m .57614 .4754 L .5782 .47886 L F
.57614 .4754 m .57619 .47569 L .5782 .47886 L F
.57127 .49278 m .56824 .48273 L .57361 .46345 L .846 .645 .63 r
F
.56824 .48273 m .57063 .45626 L .57361 .46345 L .856 .661 .638 r
F
.56824 .48273 m .56523 .47415 L .57063 .45626 L F
.56523 .47415 m .56765 .44919 L .57063 .45626 L .86 .67 .643 r
F
.57057 .46116 m .56767 .462 L .5735 .47105 L .826 .383 .184 r
F
.56767 .462 m .57057 .47057 L .5735 .47105 L .844 .398 0 r
F
.5735 .47105 m .57057 .47057 L .57116 .46702 L .975 .765 .557 r
F
.57063 .45626 m .57343 .45886 L .57634 .46032 L 0 0 .547 r
F
.57063 .45626 m .56765 .44919 L .57343 .45886 L F
.56765 .44919 m .57057 .46116 L .57343 .45886 L .885 .493 .04 r
F
.57343 .45886 m .57057 .46116 L .57652 .47768 L .877 .504 .334 r
F
.57576 .47557 m .5735 .47105 L .57652 .47768 L .826 .383 .184 r
F
.57057 .46116 m .5735 .47105 L .57576 .47557 L F
.57351 .47097 m .57322 .47049 L .57582 .43897 L .975 .765 .557 r
F
.57322 .47049 m .57116 .46702 L .57124 .46652 L F
.57322 .47049 m .57124 .46652 L .57582 .43897 L F
.5735 .47105 m .57116 .46702 L .57351 .47097 L F
.57057 .47057 m .57284 .43398 L .57582 .43897 L .944 .723 .575 r
F
.57582 .43897 m .57284 .43398 L .57325 .43555 L .934 .568 .169 r
F
.57351 .47098 m .57582 .43897 L .57838 .44238 L .975 .765 .557 r
F
.57351 .47097 m .57582 .43897 L .57351 .47098 L F
.57619 .47569 m .57652 .47768 L .57835 .4795 L .877 .504 .334 r
F
.57652 .47768 m .57351 .47098 L .57873 .44032 L .92 .699 .587 r
F
.57652 .47768 m .57873 .44032 L .58164 .44247 L F
.57582 .43897 m .57325 .43555 L .57894 .45747 L .934 .568 .169 r
F
.57838 .44238 m .57582 .43897 L .57873 .44032 L .975 .765 .557 r
F
.5735 .47105 m .57351 .47097 L .57351 .47098 L F
.57835 .4795 m .57652 .47768 L .57952 .48437 L .877 .504 .334 r
F
.57652 .47768 m .5735 .47105 L .57351 .47098 L .92 .699 .587 r
F
.57953 .48443 m .57652 .47768 L .58164 .44247 L .925 .698 .575 r
F
.58164 .44247 m .57873 .44032 L .58492 .46709 L .944 .588 .291 r
F
.58284 .45776 m .58429 .43395 L .58722 .43699 L .929 .727 .608 r
F
.58486 .46685 m .58193 .46206 L .58492 .46709 L .934 .567 .285 r
F
.58411 .46359 m .58177 .46072 L .58413 .46366 L F
.57995 .44559 m .58177 .46069 L .58411 .46359 L F
.58177 .46069 m .58177 .46072 L .58411 .46359 L F
.57284 .43398 m .57599 .45593 L .57894 .45747 L .944 .582 .252 r
F
.57894 .45747 m .57599 .45593 L .57642 .45407 L .965 .774 .595 r
F
.57873 .44032 m .57943 .44508 L .57995 .44559 L .934 .567 .285 r
F
.57943 .44508 m .58193 .46206 L .57995 .44559 L F
.57873 .44032 m .57582 .43897 L .58193 .46206 L F
.57582 .43897 m .57894 .45747 L .58048 .45983 L .934 .568 .169 r
F
.5818 .46157 m .58048 .45983 L .58193 .46206 L F
.57582 .43897 m .58048 .45983 L .5818 .46157 L F
.56523 .47415 m .56223 .46627 L .56765 .44919 L .86 .67 .643 r
F
.56223 .46627 m .56469 .44429 L .56765 .44919 L .856 .676 .658 r
F
.56765 .44919 m .56469 .44429 L .57057 .46116 L .885 .493 .04 r
F
.56469 .44429 m .56767 .462 L .57057 .46116 L .935 .558 .219 r
F
.56767 .462 m .5647 .4589 L .57057 .47057 L .844 .398 0 r
F
.5647 .4589 m .56757 .46633 L .57057 .47057 L .815 .331 .018 r
F
.57057 .47057 m .56757 .46633 L .57284 .43398 L .944 .723 .575 r
F
.56757 .46633 m .56988 .43083 L .57284 .43398 L .899 .682 .6 r
F
.57284 .43398 m .56988 .43083 L .57599 .45593 L .944 .582 .252 r
F
.56988 .43083 m .573 .45266 L .57599 .45593 L .932 .565 .289 r
F
.573 .45266 m .57542 .42486 L .57842 .42967 L .912 .711 .618 r
F
.57842 .42967 m .57542 .42486 L .57572 .42586 L .916 .537 .118 r
F
.57635 .45438 m .57842 .42967 L .5811 .43345 L .944 .748 .607 r
F
.57616 .45414 m .57842 .42967 L .57635 .45438 L F
.57897 .45722 m .57642 .45407 L .5811 .43345 L .965 .774 .595 r
F
.58124 .43363 m .5811 .43345 L .58137 .43229 L F
.57897 .45722 m .5811 .43345 L .58124 .43363 L F
.57842 .42967 m .57572 .42586 L .576 .42682 L .916 .537 .118 r
F
.58416 .4345 m .58137 .43229 L .58429 .43395 L .965 .774 .595 r
F
.57899 .45726 m .58137 .43229 L .58416 .4345 L F
.5811 .43345 m .57842 .42967 L .58137 .43229 L .944 .748 .607 r
F
.58137 .43229 m .57842 .42967 L .57856 .43008 L .917 .519 .167 r
F
.57897 .45722 m .58137 .43229 L .57899 .45726 L .965 .774 .595 r
F
.58177 .46072 m .58193 .46206 L .58413 .46366 L .934 .567 .285 r
F
.58193 .46206 m .57899 .45726 L .58429 .43395 L .929 .727 .608 r
F
.58237 .45679 m .58429 .43395 L .58284 .45776 L F
.58137 .43229 m .57856 .43008 L .5845 .44728 L .917 .519 .167 r
F
.57599 .45593 m .573 .45266 L .57842 .42967 L .944 .748 .607 r
F
.57849 .43006 m .576 .42682 L .58154 .44539 L .916 .537 .118 r
F
.57842 .42967 m .576 .42682 L .57849 .43006 L F
.57599 .45593 m .57616 .45414 L .57635 .45438 L .944 .748 .607 r
F
.57894 .45747 m .57642 .45407 L .57897 .45722 L .965 .774 .595 r
F
.57894 .45747 m .57897 .45722 L .57899 .45726 L F
.58413 .46366 m .58193 .46206 L .58486 .46685 L .934 .567 .285 r
F
.58193 .46206 m .57894 .45747 L .57899 .45726 L .929 .727 .608 r
F
.58193 .46206 m .58237 .45679 L .58284 .45776 L F
.58781 .46817 m .5878 .46815 L .58783 .46824 L .913 .566 .104 r
F
.58473 .45044 m .5878 .46815 L .58781 .46817 L F
.58239 .48303 m .58067 .47668 L .58267 .47897 L .987 .777 .533 r
F
.58774 .48479 m .58746 .48447 L .58815 .48748 L .944 .591 .195 r
F
.58818 .48752 m .58815 .48748 L .58821 .48775 L F
.5853 .48511 m .58239 .48303 L .583 .47955 L .961 .75 .574 r
F
.5853 .48511 m .583 .47955 L .58543 .48329 L F
.58821 .48775 m .5853 .48511 L .59049 .45891 L .953 .749 .589 r
F
.59049 .45891 m .58755 .45358 L .59339 .47263 L .903 .526 .08 r
F
.59327 .47225 m .59074 .47034 L .59365 .4735 L .929 .548 .173 r
F
.58755 .45358 m .59067 .46999 L .59327 .47225 L F
.59067 .46999 m .59074 .47034 L .59327 .47225 L F
.58783 .46824 m .58492 .46709 L .58526 .46529 L .971 .768 .573 r
F
.58755 .45358 m .58463 .44986 L .59061 .46993 L .929 .548 .173 r
F
.59067 .46999 m .59061 .46993 L .59074 .47034 L F
.58755 .45358 m .59061 .46993 L .59067 .46999 L F
.58463 .44986 m .58783 .46824 L .59074 .47034 L .913 .566 .104 r
F
.58788 .46756 m .58526 .46529 L .58538 .46468 L .971 .768 .573 r
F
.58791 .46722 m .58538 .46468 L .58926 .44414 L F
.58945 .4445 m .58926 .44414 L .5896 .44236 L F
.58791 .46722 m .58926 .44414 L .58945 .4445 L F
.58791 .46722 m .5896 .44236 L .58986 .44292 L F
.59293 .44161 m .59013 .43952 L .59302 .44119 L F
.58722 .43699 m .58429 .43395 L .58457 .43494 L .936 .561 .217 r
F
.58843 .46509 m .59011 .43983 L .59282 .44222 L .971 .768 .573 r
F
.58812 .46461 m .59013 .43952 L .58843 .46509 L F
.59049 .45891 m .59339 .47263 L .59344 .47271 L .903 .526 .08 r
F
.59049 .45891 m .59351 .47304 L .59358 .47314 L F
.59085 .46887 m .58843 .46509 L .59302 .44119 L .961 .756 .581 r
F
.58492 .46709 m .58722 .43699 L .59013 .43952 L .927 .719 .602 r
F
.58492 .46709 m .58193 .46206 L .58722 .43699 L F
.58728 .43733 m .58457 .43494 L .59048 .45615 L .936 .561 .217 r
F
.58722 .43699 m .58457 .43494 L .58728 .43733 L F
.59282 .44222 m .59013 .43952 L .59293 .44161 L .971 .768 .573 r
F
.59011 .43983 m .59013 .43952 L .59282 .44222 L F
.59013 .43952 m .58722 .43699 L .58732 .43742 L .946 .589 .28 r
F
.58986 .44292 m .5896 .44236 L .59013 .43952 L .971 .768 .573 r
F
.59344 .47271 m .59339 .47263 L .59351 .47304 L .903 .526 .08 r
F
.59358 .47314 m .59351 .47304 L .59365 .4735 L F
.59365 .4735 m .59074 .47034 L .59577 .44588 L .948 .744 .595 r
F
.59291 .4598 m .5927 .46079 L .59354 .46441 L .946 .589 .28 r
F
.59074 .47034 m .59302 .44119 L .59593 .44511 L .961 .756 .581 r
F
.59013 .43952 m .5927 .46079 L .59291 .4598 L .946 .589 .28 r
F
.59013 .43952 m .58732 .43742 L .5927 .46079 L F
.58137 .43229 m .5845 .44728 L .58745 .44914 L .917 .519 .167 r
F
.58745 .44914 m .5845 .44728 L .586 .44785 L 0 .433 .813 r
F
.58468 .43534 m .58745 .44914 L .58889 .45043 L .913 .513 .198 r
F
.58451 .43503 m .58745 .44914 L .58468 .43534 L F
.59323 .46309 m .59048 .45615 L .59354 .46441 L .936 .561 .217 r
F
.58737 .43765 m .59048 .45615 L .59323 .46309 L F
.58889 .45043 m .58745 .44914 L .59048 .45615 L .913 .513 .198 r
F
.59048 .45615 m .58745 .44914 L .58773 .4492 L .487 .504 .801 r
F
.58731 .43752 m .59048 .45615 L .58737 .43765 L .936 .561 .217 r
F
.59365 .4735 m .59577 .44588 L .59586 .44602 L .948 .744 .595 r
F
.59302 .44119 m .59013 .43952 L .59648 .46773 L .944 .59 .304 r
F
.59013 .43952 m .59354 .46441 L .59648 .46773 L .946 .589 .28 r
F
.59048 .45615 m .58773 .4492 L .59307 .45039 L .487 .504 .801 r
F
.58429 .43395 m .58137 .43229 L .58745 .44914 L .913 .513 .198 r
F
.58745 .44914 m .586 .44785 L .59036 .44948 L 0 .433 .813 r
F
.59307 .45039 m .59036 .44948 L .59328 .45044 L F
.58745 .44914 m .59036 .44948 L .59307 .45039 L F
.5845 .44728 m .58746 .44997 L .59036 .44948 L .497 0 0 r
F
.59036 .44948 m .58746 .44997 L .58764 .44857 L .984 .762 .525 r
F
.59036 .44948 m .58764 .44857 L .58917 .43679 L F
.59076 .44233 m .58917 .43679 L .5925 .4112 L F
.59036 .44948 m .58917 .43679 L .59076 .44233 L F
.59316 .45069 m .59307 .45039 L .59328 .45044 L .487 .504 .801 r
F
.59048 .45615 m .59307 .45039 L .59316 .45069 L F
.58429 .43395 m .58451 .43503 L .58468 .43534 L .913 .513 .198 r
F
.58722 .43699 m .58731 .43752 L .58737 .43765 L .936 .561 .217 r
F
.58788 .46756 m .58538 .46468 L .58791 .46722 L .971 .768 .573 r
F
.58783 .46824 m .58526 .46529 L .58788 .46756 L F
.58783 .46824 m .58812 .46461 L .58843 .46509 L F
.59074 .47034 m .58783 .46824 L .58843 .46509 L .961 .756 .581 r
F
.59074 .47034 m .58843 .46509 L .59085 .46887 L F
.59648 .46773 m .59354 .46441 L .59389 .46405 L .826 .783 .811 r
F
.5931 .44159 m .59648 .46773 L .59906 .4714 L .944 .59 .304 r
F
.59306 .44154 m .59648 .46773 L .5931 .44159 L F
.59933 .46525 m .59947 .47344 L .6019 .48052 L .955 .61 .278 r
F
.59735 .45355 m .59864 .46558 L .59933 .46525 L F
.59864 .46558 m .59947 .47344 L .59933 .46525 L F
.59707 .45311 m .59947 .47344 L .59735 .45355 L F
.59635 .44847 m .59947 .47344 L .59656 .44885 L F
.60178 .4549 m .59885 .4495 L .60119 .46289 L .962 .627 .279 r
F
.60252 .46138 m .60119 .46289 L .60549 .48759 L F
.60178 .4549 m .60119 .46289 L .60252 .46138 L F
.59885 .4495 m .60258 .48458 L .60549 .48759 L .962 .628 .305 r
F
.59854 .45241 m .59831 .452 L .59885 .4495 L .995 .821 .557 r
F
.59885 .4495 m .59593 .44511 L .60258 .48458 L .962 .628 .305 r
F
.59586 .44602 m .59577 .44588 L .59593 .44511 L .948 .744 .595 r
F
.59593 .44511 m .59302 .44119 L .59947 .47344 L .955 .61 .278 r
F
.59704 .46635 m .59922 .45865 L .60197 .45413 L .826 .783 .811 r
F
.59648 .46773 m .59687 .46643 L .59704 .46635 L F
.59687 .46643 m .59922 .45865 L .59704 .46635 L F
.59648 .46773 m .59389 .46405 L .59922 .45865 L F
.59906 .4714 m .59648 .46773 L .59947 .47344 L .944 .59 .304 r
F
.59302 .44119 m .59306 .44154 L .5931 .44159 L F
.59947 .47344 m .59648 .46773 L .59704 .46635 L .874 .708 .672 r
F
.59947 .47344 m .59704 .46635 L .60197 .45413 L F
.6019 .48052 m .59947 .47344 L .60258 .48458 L .955 .61 .278 r
F
.59656 .44885 m .59707 .45311 L .59735 .45355 L F
.59593 .44511 m .59635 .44847 L .59656 .44885 L F
.60329 .48057 m .60481 .45455 L .60766 .45574 L .836 .633 .629 r
F
.60258 .48458 m .60291 .4801 L .60329 .48057 L F
.60291 .4801 m .60481 .45455 L .60329 .48057 L F
.6083 .48689 m .6083 .48694 L .6086 .48727 L .91 .585 .106 r
F
.6083 .48689 m .6086 .48727 L .61068 .4896 L F
.6083 .48694 m .60549 .48759 L .60592 .48426 L .984 .764 .526 r
F
.6078 .47263 m .60959 .48491 L .60994 .48539 L .902 .564 .084 r
F
.6078 .47263 m .61056 .4891 L .61082 .4896 L F
.60795 .48462 m .60778 .48438 L .6083 .48694 L .91 .585 .106 r
F
.6083 .48694 m .60592 .48426 L .61031 .44971 L .984 .764 .526 r
F
.60639 .48055 m .60766 .45574 L .61031 .44971 L .955 .742 .578 r
F
.6062 .48203 m .60629 .48042 L .60639 .48055 L F
.60629 .48042 m .60766 .45574 L .60639 .48055 L F
.60994 .48539 m .60959 .48491 L .61056 .4891 L .902 .564 .084 r
F
.61082 .4896 m .61056 .4891 L .61125 .49203 L F
.60853 .48506 m .60931 .46822 L .61016 .47163 L .984 .764 .526 r
F
.6083 .48694 m .60842 .48483 L .60853 .48506 L F
.60842 .48483 m .60931 .46822 L .60853 .48506 L F
.60931 .46822 m .61031 .44971 L .61016 .47163 L F
.60549 .48759 m .6059 .48159 L .6062 .48203 L .955 .742 .578 r
F
.6059 .48159 m .60766 .45574 L .6062 .48203 L F
.60537 .49731 m .60333 .49498 L .60544 .49648 L .993 .793 .529 r
F
.60537 .49731 m .60544 .49648 L .60551 .49657 L F
.26882 .45381 m .27062 .44878 L .27407 .45205 L .664 .742 .908 r
F
.26882 .45381 m .26537 .45056 L .27062 .44878 L F
.43938 .45382 m .44166 .44879 L .44479 .45205 L .664 .741 .908 r
F
.43938 .45382 m .43624 .45056 L .44166 .44879 L F
.78049 .45382 m .78375 .44879 L .78625 .45205 L F
.78049 .45382 m .77799 .45057 L .78375 .44879 L F
.36107 .45368 m .36313 .44865 L .36641 .45191 L F
.36107 .45368 m .35779 .45042 L .36313 .44865 L F
.87278 .45368 m .8763 .44865 L .87863 .45192 L F
.87278 .45368 m .87044 .45042 L .8763 .44865 L F
.45333 .45354 m .45566 .44852 L .45876 .45178 L .663 .741 .908 r
F
.45333 .45354 m .45022 .45028 L .45566 .44852 L F
.28275 .45354 m .28459 .44851 L .28801 .45178 L .664 .741 .908 r
F
.28275 .45354 m .27932 .45028 L .28459 .44851 L F
.7945 .45354 m .7978 .44851 L .80027 .45179 L .663 .741 .908 r
F
.7945 .45354 m .79202 .45028 L .7978 .44851 L F
.7383 .53825 m .74734 .62465 L .75113 .64511 L .89 .586 .466 r
F
.7383 .53825 m .737 .55592 L .74734 .62465 L F
.737 .55592 m .74341 .60176 L .74734 .62465 L .815 .508 .471 r
F
.737 .55592 m .73557 .57201 L .74341 .60176 L F
.74341 .60176 m .73908 .57218 L .7452 .57478 L .548 .389 .618 r
F
.74521 .57491 m .7452 .57478 L .74522 .57479 L F
.74341 .60176 m .7452 .57478 L .74521 .57491 L F
.72889 .5195 m .73557 .57201 L .737 .55592 L .785 .493 .492 r
F
.7452 .57478 m .74352 .58655 L .74522 .57479 L 0 0 .405 r
F
.73908 .57218 m .74352 .58655 L .7452 .57478 L F
.73908 .57218 m .73484 .54377 L .74352 .58655 L F
.72889 .5195 m .7278 .54141 L .73557 .57201 L .785 .493 .492 r
F
.7278 .54141 m .73356 .57936 L .73557 .57201 L .804 .492 .462 r
F
.73557 .57201 m .73908 .57218 L .74341 .60176 L .1 0 .163 r
F
.73557 .57201 m .73356 .57936 L .73907 .57219 L F
.73907 .57218 m .73907 .57219 L .73908 .57218 L F
.73557 .57201 m .73907 .57219 L .73907 .57218 L F
.73356 .57936 m .73484 .54377 L .73907 .57219 L .987 .765 .516 r
F
.7278 .54141 m .72618 .55534 L .73356 .57936 L .804 .492 .462 r
F
.72618 .55534 m .73107 .57912 L .73356 .57936 L .789 .452 .418 r
F
.73107 .57912 m .73065 .51558 L .73484 .54377 L .942 .69 .528 r
F
.73356 .57936 m .73107 .57912 L .73484 .54377 L .987 .765 .516 r
F
.73484 .54377 m .73066 .51567 L .73947 .58127 L .811 .566 .007 r
F
.7394 .5797 m .73947 .58127 L .74184 .5989 L F
.73484 .54377 m .73947 .58127 L .7394 .5797 L F
.73907 .57219 m .73484 .54377 L .73908 .57218 L .987 .765 .516 r
F
.73484 .54377 m .73065 .51558 L .73066 .51567 L .811 .566 .007 r
F
.73484 .54377 m .74184 .5989 L .74352 .58655 L F
.74352 .58655 m .74184 .5989 L .74183 .59847 L .989 .724 .384 r
F
.74352 .58655 m .74183 .59847 L .74023 .51795 L F
.74165 .53423 m .74023 .51795 L .73918 .46506 L F
.74352 .58655 m .74023 .51795 L .74165 .53423 L F
.74522 .57479 m .74352 .58655 L .74162 .46617 L .99 .727 .383 r
F
.74162 .46617 m .73918 .46506 L .74422 .45306 L .964 .855 .685 r
F
.74352 .58655 m .73918 .46506 L .74162 .46617 L .989 .724 .384 r
F
.37501 .45341 m .37711 .44838 L .38037 .45164 L .663 .741 .908 r
F
.37501 .45341 m .37175 .45015 L .37711 .44838 L F
.29668 .45328 m .29856 .44824 L .30196 .45151 L .664 .741 .908 r
F
.29668 .45328 m .29328 .45001 L .29856 .44824 L F
.80851 .45328 m .81185 .44826 L .8143 .45151 L .663 .742 .908 r
F
.80851 .45328 m .80605 .45003 L .81185 .44826 L F
.38896 .45314 m .3911 .4481 L .39433 .45138 L .664 .741 .908 r
F
.38896 .45314 m .38573 .44988 L .3911 .4481 L F
.65914 .52823 m .66218 .52652 L .66435 .51608 L .19 .274 .721 r
F
.65914 .52823 m .65664 .52108 L .66218 .52652 L F
.65664 .52108 m .65618 .51977 L .65667 .52032 L F
.65664 .52108 m .65667 .52032 L .66218 .52652 L F
.6528 .50022 m .65616 .50698 L .65704 .51176 L 0 0 .437 r
F
.65618 .51977 m .65951 .52518 L .66218 .52652 L 0 0 .468 r
F
.65688 .5154 m .65704 .51176 L .65951 .52518 L 0 0 .437 r
F
.6528 .50022 m .65704 .51176 L .65688 .5154 L F
.65618 .51977 m .6528 .50022 L .65951 .52518 L 0 0 .468 r
F
.82253 .453 m .8259 .44797 L .82833 .45123 L .664 .742 .908 r
F
.82253 .453 m .82009 .44974 L .8259 .44797 L F
.31062 .453 m .31253 .44797 L .31591 .45123 L .664 .741 .908 r
F
.31062 .453 m .30724 .44974 L .31253 .44797 L F
.40291 .45287 m .40509 .44783 L .40829 .4511 L F
.40291 .45287 m .3997 .44961 L .40509 .44783 L F
.58845 .49945 m .59155 .51407 L .59426 .50922 L .744 .386 .373 r
F
.64165 .49499 m .63927 .50335 L .64389 .47281 L .954 .812 .37 r
F
.64389 .47281 m .64647 .46009 L .64941 .46828 L .862 .818 .337 r
F
.64609 .46197 m .64602 .46187 L .64647 .46009 L F
.64941 .46828 m .64647 .46009 L .65239 .46582 L .242 .314 .738 r
F
.64647 .46009 m .64953 .46006 L .65239 .46582 L .01 0 0 r
F
.64148 .47972 m .64388 .46166 L .64647 .46009 L .792 .719 .186 r
F
.64647 .46009 m .64388 .46166 L .64953 .46006 L .01 0 0 r
F
.64553 .46119 m .64689 .45999 L .64953 .46006 L 0 0 .129 r
F
.64388 .46166 m .64531 .46087 L .64553 .46119 L F
.64531 .46087 m .64689 .45999 L .64553 .46119 L F
.64389 .47281 m .64148 .47972 L .64602 .46187 L .862 .818 .337 r
F
.64389 .47281 m .64602 .46187 L .64609 .46197 L F
.63927 .50335 m .64148 .47972 L .64389 .47281 L .963 .811 .378 r
F
.74422 .45306 m .74736 .44783 L .74993 .4511 L .678 .748 .904 r
F
.74422 .45306 m .74165 .44982 L .74736 .44783 L F
.73918 .46506 m .74165 .44982 L .74422 .45306 L .979 .847 .64 r
F
.83655 .45273 m .83996 .44769 L .84236 .45097 L .663 .741 .908 r
F
.83655 .45273 m .83414 .44946 L .83996 .44769 L F
.32456 .45273 m .32651 .44769 L .32986 .45096 L .664 .741 .908 r
F
.32456 .45273 m .32121 .44946 L .32651 .44769 L F
.75822 .45259 m .76141 .44756 L .76396 .45085 L .664 .742 .908 r
F
.75822 .45259 m .75567 .44934 L .76141 .44756 L F
.41687 .4526 m .41909 .44756 L .42226 .45084 L .664 .741 .908 r
F
.41687 .4526 m .41369 .44933 L .41909 .44756 L F
.65275 .48703 m .64941 .46828 L .65552 .4787 L .334 .266 .629 r
F
.64941 .46828 m .65239 .46582 L .65552 .4787 L .242 .314 .738 r
F
.3385 .45246 m .3405 .44743 L .34382 .45069 L .663 .741 .908 r
F
.3385 .45246 m .33518 .4492 L .3405 .44743 L F
.85057 .45246 m .85403 .44743 L .8564 .45071 L .663 .742 .908 r
F
.85057 .45246 m .84819 .4492 L .85403 .44743 L F
.26013 .45232 m .2619 .44729 L .26537 .45056 L .663 .741 .908 r
F
.26013 .45232 m .25665 .44905 L .2619 .44729 L F
.77223 .45233 m .77547 .44729 L .77799 .45057 L .665 .743 .908 r
F
.77223 .45233 m .76971 .44908 L .77547 .44729 L F
.43083 .45234 m .43309 .44729 L .43624 .45056 L .664 .741 .907 r
F
.43083 .45234 m .42767 .44907 L .43309 .44729 L F
.8646 .45219 m .8681 .44716 L .87044 .45042 L .664 .743 .909 r
F
.8646 .45219 m .86224 .44894 L .8681 .44716 L F
.35245 .45219 m .35449 .44715 L .35779 .45042 L .663 .741 .908 r
F
.35245 .45219 m .34915 .44892 L .35449 .44715 L F
.27407 .45205 m .27588 .44701 L .27932 .45028 L F
.27407 .45205 m .27062 .44878 L .27588 .44701 L F
.78625 .45205 m .78952 .44701 L .79202 .45028 L .664 .741 .908 r
F
.78625 .45205 m .78375 .44879 L .78952 .44701 L F
.44479 .45205 m .44709 .44701 L .45022 .45028 L F
.44479 .45205 m .44166 .44879 L .44709 .44701 L F
.36641 .45191 m .36848 .44688 L .37175 .45015 L .663 .741 .908 r
F
.36641 .45191 m .36313 .44865 L .36848 .44688 L F
.87863 .45192 m .88217 .44688 L .88449 .45015 L F
.87863 .45192 m .8763 .44865 L .88217 .44688 L F
.66435 .51608 m .66218 .52652 L .6673 .51171 L 0 0 .088 r
F
.28801 .45178 m .28986 .44674 L .29328 .45001 L .663 .741 .908 r
F
.28801 .45178 m .28459 .44851 L .28986 .44674 L F
.45876 .45178 m .4611 .44677 L .4642 .45003 L .662 .741 .909 r
F
.45876 .45178 m .45566 .44852 L .4611 .44677 L F
.80027 .45179 m .80359 .44674 L .80605 .45003 L .663 .741 .908 r
F
.80027 .45179 m .7978 .44851 L .80359 .44674 L F
.38037 .45164 m .38248 .44661 L .38573 .44988 L .663 .742 .908 r
F
.38037 .45164 m .37711 .44838 L .38248 .44661 L F
.30196 .45151 m .30385 .44646 L .30724 .44974 L .664 .742 .908 r
F
.30196 .45151 m .29856 .44824 L .30385 .44646 L F
.8143 .45151 m .81765 .44647 L .82009 .44974 L F
.8143 .45151 m .81185 .44826 L .81765 .44647 L F
.6366 .51401 m .63348 .50088 L .63524 .50163 L .508 .417 .688 r
F
.63754 .51028 m .63524 .50163 L .63852 .50303 L F
.6366 .51401 m .63524 .50163 L .63754 .51028 L F
.63788 .50893 m .63852 .50303 L .63927 .50335 L F
.63754 .51028 m .63852 .50303 L .63788 .50893 L F
.63348 .50088 m .63686 .51174 L .63927 .50335 L 0 0 .344 r
F
.63686 .51174 m .63925 .49243 L .64037 .48607 L .736 .576 .675 r
F
.63975 .49174 m .64037 .48607 L .64148 .47972 L F
.63686 .51174 m .64037 .48607 L .63975 .49174 L F
.63348 .50088 m .63268 .49611 L .63544 .50644 L 0 0 .344 r
F
.6354 .50703 m .63544 .50644 L .63686 .51174 L F
.63348 .50088 m .63544 .50644 L .6354 .50703 L F
.63268 .49611 m .63367 .49722 L .63686 .51174 L F
.63551 .50559 m .63379 .50049 L .63686 .51174 L .755 .492 0 r
F
.63268 .49611 m .63016 .48124 L .63367 .49722 L 0 0 .344 r
F
.63172 .48835 m .63379 .50049 L .63551 .50559 L .755 .492 0 r
F
.62701 .46664 m .63088 .49435 L .63379 .50049 L .955 .611 .248 r
F
.63379 .50049 m .63088 .49435 L .63206 .49538 L .134 .309 .776 r
F
.63753 .50636 m .636 .50397 L .63925 .49243 L .736 .576 .675 r
F
.636 .50397 m .63379 .50049 L .63754 .49495 L F
.636 .50397 m .63754 .49495 L .63925 .49243 L F
.635 .4987 m .6368 .49952 L .63925 .49243 L .134 .309 .776 r
F
.63925 .49243 m .6368 .49952 L .63958 .48305 L .967 .825 .403 r
F
.64076 .47872 m .63958 .48305 L .64157 .47132 L F
.63925 .49243 m .63958 .48305 L .64076 .47872 L F
.63886 .4873 m .63935 .48461 L .6414 .47232 L .989 .88 .543 r
F
.6368 .49952 m .63935 .48461 L .63886 .4873 L F
.6368 .49952 m .6414 .47232 L .64113 .47391 L F
.63379 .50049 m .63597 .49978 L .635 .4987 L .134 .309 .776 r
F
.63597 .49978 m .6368 .49952 L .635 .4987 L F
.63095 .48543 m .63379 .50049 L .63172 .48835 L .755 .492 0 r
F
.63016 .48124 m .62701 .46664 L .63379 .50049 L F
.63379 .50049 m .63206 .49538 L .63487 .49784 L .134 .309 .776 r
F
.6356 .49918 m .63487 .49784 L .63605 .49887 L F
.63379 .50049 m .63487 .49784 L .6356 .49918 L F
.63686 .51174 m .63379 .50049 L .63753 .50636 L .736 .576 .675 r
F
.63597 .49978 m .63605 .49887 L .6368 .49952 L .134 .309 .776 r
F
.63379 .50049 m .63605 .49887 L .63597 .49978 L F
.63088 .49435 m .63418 .50254 L .6368 .49952 L 0 0 .385 r
F
.63088 .49435 m .62763 .47765 L .63418 .50254 L F
.63113 .49096 m .63133 .49912 L .63418 .50254 L .818 .534 0 r
F
.62763 .47765 m .62937 .48771 L .63113 .49096 L F
.62937 .48771 m .63133 .49912 L .63113 .49096 L F
.6368 .49952 m .63418 .50254 L .63935 .48461 L .989 .88 .543 r
F
.63621 .49548 m .63695 .49369 L .63935 .48461 L .815 .773 .813 r
F
.64148 .47972 m .63925 .49243 L .64297 .46774 L .792 .719 .186 r
F
.64315 .46717 m .64297 .46774 L .64388 .46166 L F
.64148 .47972 m .64297 .46774 L .64315 .46717 L F
.63925 .49243 m .64157 .47132 L .64388 .46166 L .967 .825 .403 r
F
.64237 .46962 m .64444 .46581 L .64689 .45999 L 0 0 .109 r
F
.64157 .47132 m .64223 .47005 L .64237 .46962 L F
.64223 .47005 m .64444 .46581 L .64237 .46962 L F
.64157 .47132 m .63935 .48461 L .64444 .46581 L F
.63935 .48461 m .63695 .49369 L .63985 .48181 L .74 .735 .213 r
F
.63935 .48461 m .63985 .48181 L .64201 .47296 L F
.63418 .50254 m .63509 .49962 L .63621 .49548 L .815 .773 .813 r
F
.63509 .49962 m .63695 .49369 L .63621 .49548 L F
.64113 .47391 m .6414 .47232 L .64157 .47132 L .989 .88 .543 r
F
.63016 .48124 m .63095 .48543 L .63172 .48835 L .755 .492 0 r
F
.39433 .45138 m .39648 .44633 L .3997 .44961 L .664 .741 .908 r
F
.39433 .45138 m .3911 .4481 L .39648 .44633 L F
.47273 .4518 m .47496 .4569 L .47804 .4602 L .762 .287 0 r
F
.82833 .45123 m .83172 .44619 L .83414 .44946 L .664 .742 .908 r
F
.82833 .45123 m .8259 .44797 L .83172 .44619 L F
.31591 .45123 m .31784 .44619 L .32121 .44946 L .664 .741 .908 r
F
.31591 .45123 m .31253 .44797 L .31784 .44619 L F
.48419 .46584 m .48503 .59548 L .48824 .59608 L .957 .673 .457 r
F
.47804 .4602 m .47858 .59312 L .48181 .59427 L .958 .675 .456 r
F
.48181 .59427 m .47858 .59312 L .47865 .59224 L .96 .717 .526 r
F
.48419 .46584 m .48112 .46325 L .48503 .59544 L .957 .673 .457 r
F
.48419 .46584 m .48503 .59544 L .48503 .59544 L F
.48112 .46325 m .48181 .59427 L .48503 .59548 L .958 .674 .456 r
F
.48112 .46325 m .47804 .4602 L .48179 .59339 L F
.48181 .5934 m .48179 .59339 L .48181 .59427 L F
.48112 .46325 m .48179 .59339 L .48181 .5934 L F
.47804 .4602 m .47496 .4569 L .47858 .59312 L .958 .675 .456 r
F
.47496 .4569 m .47534 .59055 L .47858 .59312 L F
.47541 .58979 m .47886 .51313 L .48204 .51447 L .947 .703 .536 r
F
.47534 .59055 m .47538 .58977 L .47541 .58979 L F
.47538 .58977 m .47886 .51313 L .47541 .58979 L F
.48183 .59383 m .47865 .59224 L .48517 .51915 L .96 .717 .526 r
F
.48181 .59427 m .47865 .59224 L .48183 .59383 L F
.48503 .59544 m .48503 .59544 L .48503 .59548 L .957 .673 .457 r
F
.40829 .4511 m .41049 .44605 L .41369 .44933 L .664 .741 .908 r
F
.40829 .4511 m .40509 .44783 L .41049 .44605 L F
.74993 .4511 m .75311 .44607 L .75567 .44934 L .663 .741 .908 r
F
.74993 .4511 m .74736 .44783 L .75311 .44607 L F
.54944 .54001 m .54645 .53711 L .5516 .47639 L .956 .714 .531 r
F
.55325 .47142 m .55332 .47052 L .55418 .46862 L .871 .912 .508 r
F
.54872 .48066 m .55122 .46204 L .55418 .46862 L .996 .854 .521 r
F
.55418 .46862 m .55122 .46204 L .55693 .47692 L .761 .394 0 r
F
.55351 .46801 m .55391 .46603 L .55693 .47692 L 0 0 .403 r
F
.55122 .46204 m .55368 .4657 L .55351 .46801 L F
.55368 .4657 m .55391 .46603 L .55351 .46801 L F
.5516 .47639 m .54872 .48066 L .55332 .47052 L .871 .912 .508 r
F
.5516 .47639 m .55332 .47052 L .55325 .47142 L F
.32986 .45096 m .33183 .44592 L .33518 .4492 L .663 .741 .908 r
F
.32986 .45096 m .32651 .44769 L .33183 .44592 L F
.84236 .45097 m .8458 .44592 L .84819 .4492 L F
.84236 .45097 m .83996 .44769 L .8458 .44592 L F
.42226 .45084 m .4245 .44579 L .42767 .44907 L F
.42226 .45084 m .41909 .44756 L .4245 .44579 L F
.76396 .45085 m .76717 .44581 L .76971 .44908 L .662 .739 .907 r
F
.76396 .45085 m .76141 .44756 L .76717 .44581 L F
.34382 .45069 m .34583 .44565 L .34915 .44892 L .664 .742 .908 r
F
.34382 .45069 m .3405 .44743 L .34583 .44565 L F
.8564 .45071 m .85988 .44565 L .86224 .44894 L .664 .741 .907 r
F
.8564 .45071 m .85403 .44743 L .85988 .44565 L F
.7243 .53997 m .7278 .54141 L .72889 .5195 L .154 0 .321 r
F
.26537 .45056 m .26716 .4455 L .27062 .44878 L .664 .742 .908 r
F
.26537 .45056 m .2619 .44729 L .26716 .4455 L F
.43624 .45056 m .43852 .44551 L .44166 .44879 L .664 .741 .908 r
F
.43624 .45056 m .43309 .44729 L .43852 .44551 L F
.77799 .45057 m .78124 .44551 L .78375 .44879 L F
.77799 .45057 m .77547 .44729 L .78124 .44551 L F
.35779 .45042 m .35984 .44537 L .36313 .44865 L F
.35779 .45042 m .35449 .44715 L .35984 .44537 L F
.87044 .45042 m .87396 .44537 L .8763 .44865 L .664 .742 .908 r
F
.87044 .45042 m .8681 .44716 L .87396 .44537 L F
.45022 .45028 m .45254 .44524 L .45566 .44852 L .663 .741 .908 r
F
.45022 .45028 m .44709 .44701 L .45254 .44524 L F
.27932 .45028 m .28115 .44523 L .28459 .44851 L .664 .741 .908 r
F
.27932 .45028 m .27588 .44701 L .28115 .44523 L F
.79202 .45028 m .79531 .44524 L .7978 .44851 L .663 .741 .908 r
F
.79202 .45028 m .78952 .44701 L .79531 .44524 L F
.75724 .66325 m .75436 .65676 L .75142 .52375 L .967 .694 .463 r
F
.88449 .45015 m .88805 .4451 L .89036 .44839 L .664 .742 .908 r
F
.88449 .45015 m .88217 .44688 L .88805 .4451 L F
.37175 .45015 m .37385 .44511 L .37711 .44838 L .663 .741 .908 r
F
.37175 .45015 m .36848 .44688 L .37385 .44511 L F
.29328 .45001 m .29515 .44497 L .29856 .44824 L F
.29328 .45001 m .28986 .44674 L .29515 .44497 L F
.80605 .45003 m .80939 .44497 L .81185 .44826 L .663 .74 .907 r
F
.80605 .45003 m .80359 .44674 L .80939 .44497 L F
.4642 .45003 m .4611 .44677 L .46656 .4452 L .648 .737 .914 r
F
.38573 .44988 m .38786 .44482 L .3911 .4481 L .664 .742 .908 r
F
.38573 .44988 m .38248 .44661 L .38786 .44482 L F
.30724 .44974 m .30915 .44468 L .31253 .44797 L .663 .741 .908 r
F
.30724 .44974 m .30385 .44646 L .30915 .44468 L F
.82009 .44974 m .82347 .44469 L .8259 .44797 L .664 .741 .908 r
F
.82009 .44974 m .81765 .44647 L .82347 .44469 L F
.3997 .44961 m .40188 .44455 L .40509 .44783 L F
.3997 .44961 m .39648 .44633 L .40188 .44455 L F
.73918 .46506 m .73675 .46439 L .74165 .44982 L .979 .847 .64 r
F
.74165 .44982 m .74478 .44455 L .74736 .44783 L .68 .75 .904 r
F
.74165 .44982 m .73906 .44659 L .74478 .44455 L F
.73675 .46439 m .73906 .44659 L .74165 .44982 L .992 .84 .588 r
F
.83414 .44946 m .83755 .44441 L .83996 .44769 L .663 .741 .908 r
F
.83414 .44946 m .83172 .44619 L .83755 .44441 L F
.32121 .44946 m .32315 .44441 L .32651 .44769 L .664 .741 .908 r
F
.32121 .44946 m .31784 .44619 L .32315 .44441 L F
.41369 .44933 m .4159 .44428 L .41909 .44756 L .663 .741 .908 r
F
.41369 .44933 m .41049 .44605 L .4159 .44428 L F
.75567 .44934 m .75886 .44429 L .76141 .44756 L F
.75567 .44934 m .75311 .44607 L .75886 .44429 L F
.33518 .4492 m .33716 .44415 L .3405 .44743 L F
.33518 .4492 m .33183 .44592 L .33716 .44415 L F
.84819 .4492 m .85164 .44414 L .85403 .44743 L .664 .741 .908 r
F
.84819 .4492 m .8458 .44592 L .85164 .44414 L F
.25665 .44905 m .25842 .444 L .2619 .44729 L .663 .741 .908 r
F
.25665 .44905 m .25317 .44578 L .25842 .444 L F
.42767 .44907 m .42993 .444 L .43309 .44729 L .664 .741 .908 r
F
.42767 .44907 m .4245 .44579 L .42993 .444 L F
.76971 .44908 m .77294 .44402 L .77547 .44729 L .664 .742 .908 r
F
.76971 .44908 m .76717 .44581 L .77294 .44402 L F
.74184 .5989 m .73675 .46439 L .73918 .46506 L .989 .72 .391 r
F
.34915 .44892 m .35118 .44386 L .35449 .44715 L .664 .741 .908 r
F
.34915 .44892 m .34583 .44565 L .35118 .44386 L F
.86224 .44894 m .86574 .44387 L .8681 .44716 L .664 .741 .907 r
F
.86224 .44894 m .85988 .44565 L .86574 .44387 L F
.53219 .51981 m .52917 .50818 L .53464 .47203 L .884 .656 .588 r
F
.53464 .47203 m .53738 .51501 L .54042 .5245 L .929 .612 .419 r
F
.52917 .50818 m .53168 .4741 L .53464 .47203 L .859 .648 .617 r
F
.53464 .47203 m .53168 .4741 L .53738 .51501 L .929 .612 .419 r
F
.27062 .44878 m .27242 .44372 L .27588 .44701 L .663 .741 .908 r
F
.27062 .44878 m .26716 .4455 L .27242 .44372 L F
.78375 .44879 m .78702 .44372 L .78952 .44701 L .664 .741 .908 r
F
.78375 .44879 m .78124 .44551 L .78702 .44372 L F
.44166 .44879 m .44396 .44372 L .44709 .44701 L F
.44166 .44879 m .43852 .44551 L .44396 .44372 L F
.36313 .44865 m .3652 .44359 L .36848 .44688 L .663 .741 .908 r
F
.36313 .44865 m .35984 .44537 L .3652 .44359 L F
.8763 .44865 m .87984 .44359 L .88217 .44688 L .664 .741 .908 r
F
.8763 .44865 m .87396 .44537 L .87984 .44359 L F
.66621 .46031 m .66347 .45671 L .67034 .48234 L .94 .572 .204 r
F
.63968 .52577 m .6366 .51401 L .64165 .49499 L .827 .624 .628 r
F
.28459 .44851 m .28643 .44345 L .28986 .44674 L .664 .741 .908 r
F
.28459 .44851 m .28115 .44523 L .28643 .44345 L F
.7978 .44851 m .80111 .44346 L .80359 .44674 L .664 .742 .908 r
F
.7978 .44851 m .79531 .44524 L .80111 .44346 L F
.45566 .44852 m .45799 .44347 L .4611 .44677 L .663 .741 .908 r
F
.45566 .44852 m .45254 .44524 L .45799 .44347 L F
.37711 .44838 m .37922 .44333 L .38248 .44661 L .663 .742 .908 r
F
.37711 .44838 m .37385 .44511 L .37922 .44333 L F
.89036 .44839 m .89394 .44331 L .89625 .44661 L .664 .741 .907 r
F
.89036 .44839 m .88805 .4451 L .89394 .44331 L F
.29856 .44824 m .30044 .44318 L .30385 .44646 L .664 .742 .908 r
F
.29856 .44824 m .29515 .44497 L .30044 .44318 L F
.81185 .44826 m .8152 .44318 L .81765 .44647 L .664 .741 .908 r
F
.81185 .44826 m .80939 .44497 L .8152 .44318 L F
.3911 .4481 m .39325 .44304 L .39648 .44633 L F
.3911 .4481 m .38786 .44482 L .39325 .44304 L F
.46965 .44854 m .47186 .45376 L .47496 .4569 L .768 .298 0 r
F
.31253 .44797 m .31446 .4429 L .31784 .44619 L .664 .741 .908 r
F
.31253 .44797 m .30915 .44468 L .31446 .4429 L F
.8259 .44797 m .8293 .4429 L .83172 .44619 L F
.8259 .44797 m .82347 .44469 L .8293 .4429 L F
.40509 .44783 m .40728 .44277 L .41049 .44605 L .663 .741 .908 r
F
.40509 .44783 m .40188 .44455 L .40728 .44277 L F
.74736 .44783 m .75053 .44277 L .75311 .44607 L .664 .741 .908 r
F
.74736 .44783 m .74478 .44455 L .75053 .44277 L F
.32651 .44769 m .32848 .44263 L .33183 .44592 L .663 .741 .908 r
F
.32651 .44769 m .32315 .44441 L .32848 .44263 L F
.83996 .44769 m .8434 .44263 L .8458 .44592 L F
.83996 .44769 m .83755 .44441 L .8434 .44263 L F
.41909 .44756 m .42132 .4425 L .4245 .44579 L F
.41909 .44756 m .4159 .44428 L .42132 .4425 L F
.76141 .44756 m .76462 .44249 L .76717 .44581 L .664 .743 .908 r
F
.76141 .44756 m .75886 .44429 L .76462 .44249 L F
.65616 .50698 m .65275 .48703 L .65878 .49469 L .424 .323 .636 r
F
.65275 .48703 m .65552 .4787 L .65878 .49469 L .334 .266 .629 r
F
.3405 .44743 m .34251 .44236 L .34583 .44565 L .664 .742 .908 r
F
.3405 .44743 m .33716 .44415 L .34251 .44236 L F
.85403 .44743 m .8575 .44236 L .85988 .44565 L .663 .741 .908 r
F
.85403 .44743 m .85164 .44414 L .8575 .44236 L F
.2619 .44729 m .26368 .44221 L .26716 .4455 L .664 .741 .908 r
F
.2619 .44729 m .25842 .444 L .26368 .44221 L F
.77547 .44729 m .77872 .44222 L .78124 .44551 L .664 .742 .908 r
F
.77547 .44729 m .77294 .44402 L .77872 .44222 L F
.43309 .44729 m .43536 .44222 L .43852 .44551 L .664 .741 .908 r
F
.43309 .44729 m .42993 .444 L .43536 .44222 L F
.35449 .44715 m .35654 .44208 L .35984 .44537 L F
.35449 .44715 m .35118 .44386 L .35654 .44208 L F
.8681 .44716 m .87161 .44208 L .87396 .44537 L .664 .741 .907 r
F
.8681 .44716 m .86574 .44387 L .87161 .44208 L F
.44709 .44701 m .44941 .44195 L .45254 .44524 L .663 .741 .908 r
F
.44709 .44701 m .44396 .44372 L .44941 .44195 L F
.27588 .44701 m .2777 .44194 L .28115 .44523 L F
.27588 .44701 m .27242 .44372 L .2777 .44194 L F
.78952 .44701 m .79282 .44195 L .79531 .44524 L F
.78952 .44701 m .78702 .44372 L .79282 .44195 L F
.36848 .44688 m .37057 .44181 L .37385 .44511 L F
.36848 .44688 m .3652 .44359 L .37057 .44181 L F
.88217 .44688 m .88573 .4418 L .88805 .4451 L F
.88217 .44688 m .87984 .44359 L .88573 .4418 L F
.53006 .52824 m .53267 .5521 L .53564 .54292 L .792 .466 .437 r
F
.28986 .44674 m .29172 .44167 L .29515 .44497 L .663 .741 .908 r
F
.28986 .44674 m .28643 .44345 L .29172 .44167 L F
.80359 .44674 m .80692 .44167 L .80939 .44497 L .664 .742 .908 r
F
.80359 .44674 m .80111 .44346 L .80692 .44167 L F
.4611 .44677 m .46345 .4419 L .46656 .4452 L .648 .736 .913 r
F
.4611 .44677 m .45799 .44347 L .46345 .4419 L F
.38248 .44661 m .38461 .44153 L .38786 .44482 L .664 .742 .908 r
F
.38248 .44661 m .37922 .44333 L .38461 .44153 L F
.89625 .44661 m .89985 .44154 L .90214 .44482 L .663 .74 .907 r
F
.89625 .44661 m .89394 .44331 L .89985 .44154 L F
.66218 .52652 m .66491 .51663 L .6673 .51171 L .924 .868 .765 r
F
.6673 .51171 m .66491 .51663 L .67068 .51676 L .493 .091 .207 r
F
.30385 .44646 m .30575 .44139 L .30915 .44468 L .664 .741 .908 r
F
.30385 .44646 m .30044 .44318 L .30575 .44139 L F
.81765 .44647 m .82103 .44139 L .82347 .44469 L F
.81765 .44647 m .8152 .44318 L .82103 .44139 L F
.39648 .44633 m .39865 .44125 L .40188 .44455 L .663 .741 .908 r
F
.39648 .44633 m .39325 .44304 L .39865 .44125 L F
.31784 .44619 m .31978 .44112 L .32315 .44441 L F
.31784 .44619 m .31446 .4429 L .31978 .44112 L F
.83172 .44619 m .83514 .44112 L .83755 .44441 L F
.83172 .44619 m .8293 .4429 L .83514 .44112 L F
.73675 .46439 m .73437 .46455 L .73906 .44659 L .992 .84 .588 r
F
.73906 .44659 m .7422 .44126 L .74478 .44455 L .687 .757 .905 r
F
.73906 .44659 m .73647 .44341 L .7422 .44126 L F
.73437 .46455 m .73647 .44341 L .73906 .44659 L .99 .814 .572 r
F
.57517 .53933 m .57232 .53981 L .57766 .5222 L .981 .834 .623 r
F
.65552 .4787 m .65239 .46582 L .65805 .46422 L .611 .486 .685 r
F
.65239 .46582 m .65522 .45912 L .65805 .46422 L .613 .602 .816 r
F
.65239 .46582 m .64953 .46006 L .65522 .45912 L F
.41049 .44605 m .4127 .44099 L .4159 .44428 L .663 .741 .908 r
F
.41049 .44605 m .40728 .44277 L .4127 .44099 L F
.75311 .44607 m .7563 .441 L .75886 .44429 L .662 .74 .908 r
F
.75311 .44607 m .75053 .44277 L .7563 .441 L F
.54872 .48066 m .54581 .48519 L .55122 .46204 L .996 .854 .521 r
F
.55122 .46204 m .54826 .45739 L .55391 .46603 L 0 0 .403 r
F
.54581 .48519 m .54826 .45739 L .55122 .46204 L 1 .813 .499 r
F
.64388 .46166 m .64157 .47132 L .64689 .45999 L 0 0 .129 r
F
.8458 .44592 m .84925 .44085 L .85164 .44414 L .663 .741 .908 r
F
.8458 .44592 m .8434 .44263 L .84925 .44085 L F
.33183 .44592 m .33382 .44085 L .33716 .44415 L F
.33183 .44592 m .32848 .44263 L .33382 .44085 L F
.25317 .44578 m .25493 .4407 L .25842 .444 L .664 .742 .908 r
F
.25317 .44578 m .24967 .44249 L .25493 .4407 L F
.4245 .44579 m .42675 .44071 L .42993 .444 L F
.4245 .44579 m .42132 .4425 L .42675 .44071 L F
.76717 .44581 m .7704 .44071 L .77294 .44402 L .663 .739 .907 r
F
.76717 .44581 m .76462 .44249 L .7704 .44071 L F
.34583 .44565 m .34786 .44057 L .35118 .44386 L .664 .741 .908 r
F
.34583 .44565 m .34251 .44236 L .34786 .44057 L F
.85988 .44565 m .86337 .44057 L .86574 .44387 L .663 .741 .908 r
F
.85988 .44565 m .8575 .44236 L .86337 .44057 L F
.65805 .46422 m .66103 .46076 L .66347 .45671 L .428 .53 .859 r
F
.26716 .4455 m .26896 .44043 L .27242 .44372 L .664 .741 .908 r
F
.26716 .4455 m .26368 .44221 L .26896 .44043 L F
.43852 .44551 m .44081 .44043 L .44396 .44372 L F
.43852 .44551 m .43536 .44222 L .44081 .44043 L F
.78124 .44551 m .78451 .44043 L .78702 .44372 L F
.78124 .44551 m .77872 .44222 L .78451 .44043 L F
.35984 .44537 m .3619 .44029 L .3652 .44359 L .663 .741 .908 r
F
.35984 .44537 m .35654 .44208 L .3619 .44029 L F
.87396 .44537 m .8775 .44029 L .87984 .44359 L .664 .741 .908 r
F
.87396 .44537 m .87161 .44208 L .8775 .44029 L F
.28115 .44523 m .28299 .44015 L .28643 .44345 L F
.28115 .44523 m .2777 .44194 L .28299 .44015 L F
.79531 .44524 m .79862 .44017 L .80111 .44346 L .663 .741 .908 r
F
.79531 .44524 m .79282 .44195 L .79862 .44017 L F
.45254 .44524 m .45487 .44016 L .45799 .44347 L .664 .741 .908 r
F
.45254 .44524 m .44941 .44195 L .45487 .44016 L F
.56325 .50568 m .5602 .49157 L .56607 .51469 L 0 0 .284 r
F
.88805 .4451 m .89163 .44003 L .89394 .44331 L .663 .741 .908 r
F
.88805 .4451 m .88573 .4418 L .89163 .44003 L F
.37385 .44511 m .37595 .44003 L .37922 .44333 L F
.37385 .44511 m .37057 .44181 L .37595 .44003 L F
.29515 .44497 m .29703 .43988 L .30044 .44318 L .664 .742 .908 r
F
.29515 .44497 m .29172 .44167 L .29703 .43988 L F
.80939 .44497 m .81274 .43988 L .8152 .44318 L .664 .741 .907 r
F
.80939 .44497 m .80692 .44167 L .81274 .43988 L F
.59426 .50922 m .59699 .50431 L .60002 .51476 L 0 0 0 r
F
.59426 .50922 m .59155 .51407 L .59699 .50431 L F
.46656 .4452 m .46875 .45063 L .47186 .45376 L .78 .311 0 r
F
.46656 .4452 m .46345 .4419 L .46875 .45063 L F
.90214 .44482 m .90576 .43975 L .90805 .44304 L .664 .742 .908 r
F
.90214 .44482 m .89985 .44154 L .90576 .43975 L F
.38786 .44482 m .39001 .43974 L .39325 .44304 L .664 .741 .908 r
F
.38786 .44482 m .38461 .44153 L .39001 .43974 L F
.30915 .44468 m .31107 .4396 L .31446 .4429 L F
.30915 .44468 m .30575 .44139 L .31107 .4396 L F
.82347 .44469 m .82686 .4396 L .8293 .4429 L F
.82347 .44469 m .82103 .44139 L .82686 .4396 L F
.40188 .44455 m .40406 .43947 L .40728 .44277 L .663 .741 .908 r
F
.40188 .44455 m .39865 .44125 L .40406 .43947 L F
.74478 .44455 m .74795 .43948 L .75053 .44277 L .663 .742 .908 r
F
.74478 .44455 m .7422 .44126 L .74795 .43948 L F
.32315 .44441 m .32512 .43933 L .32848 .44263 L .664 .741 .908 r
F
.32315 .44441 m .31978 .44112 L .32512 .43933 L F
.83755 .44441 m .84099 .43934 L .8434 .44263 L .663 .742 .908 r
F
.83755 .44441 m .83514 .44112 L .84099 .43934 L F
.73065 .51558 m .74007 .61054 L .74184 .5989 L .945 .659 .203 r
F
.74184 .5989 m .74007 .61054 L .73675 .46439 L .989 .72 .391 r
F
.74007 .61054 m .73437 .46455 L .73675 .46439 L .985 .713 .413 r
F
.4159 .44428 m .41813 .43921 L .42132 .4425 L .663 .742 .908 r
F
.4159 .44428 m .4127 .44099 L .41813 .43921 L F
.70984 .50238 m .70615 .4805 L .71456 .52637 L 0 0 .201 r
F
.70615 .4805 m .71059 .50029 L .71456 .52637 L 0 0 .173 r
F
.75886 .44429 m .76207 .43922 L .76462 .44249 L .663 .742 .908 r
F
.75886 .44429 m .7563 .441 L .76207 .43922 L F
.65552 .4787 m .65805 .46422 L .66113 .47587 L .611 .486 .685 r
F
.65805 .46422 m .65522 .45912 L .66103 .46076 L .428 .53 .859 r
F
.65878 .49469 m .65552 .4787 L .66113 .47587 L .625 .476 .66 r
F
.64953 .46006 m .65262 .46001 L .65522 .45912 L .015 .589 .727 r
F
.64953 .46006 m .64689 .45999 L .65262 .46001 L F
.85164 .44414 m .85512 .43907 L .8575 .44236 L .663 .742 .908 r
F
.85164 .44414 m .84925 .44085 L .85512 .43907 L F
.33716 .44415 m .33917 .43906 L .34251 .44236 L .664 .741 .908 r
F
.33716 .44415 m .33382 .44085 L .33917 .43906 L F
.63927 .50335 m .63686 .51174 L .64148 .47972 L .963 .811 .378 r
F
.25842 .444 m .26019 .43891 L .26368 .44221 L .664 .741 .908 r
F
.25842 .444 m .25493 .4407 L .26019 .43891 L F
.42993 .444 m .43219 .43892 L .43536 .44222 L F
.42993 .444 m .42675 .44071 L .43219 .43892 L F
.77294 .44402 m .77619 .43892 L .77872 .44222 L .664 .741 .907 r
F
.77294 .44402 m .7704 .44071 L .77619 .43892 L F
.35118 .44386 m .35322 .43877 L .35654 .44208 L .664 .741 .908 r
F
.35118 .44386 m .34786 .44057 L .35322 .43877 L F
.86574 .44387 m .86926 .43878 L .87161 .44208 L .664 .742 .908 r
F
.86574 .44387 m .86337 .44057 L .86926 .43878 L F
.54645 .53711 m .54344 .53076 L .54872 .48066 L .935 .698 .554 r
F
.72089 .53356 m .71979 .45693 L .7231 .47155 L .859 .61 .562 r
F
.7243 .53997 m .72267 .55385 L .7278 .54141 L .154 0 .321 r
F
.72267 .55385 m .72618 .55534 L .7278 .54141 L .307 0 0 r
F
.72456 .55368 m .7231 .47155 L .72668 .49056 L .892 .638 .546 r
F
.72456 .55368 m .72089 .53356 L .7231 .47155 L F
.72618 .55534 m .72422 .5642 L .73107 .57912 L .789 .452 .418 r
F
.72806 .57057 m .72668 .49056 L .73065 .51558 L .908 .652 .539 r
F
.72806 .57057 m .72456 .55368 L .72668 .49056 L F
.73107 .57912 m .72806 .57057 L .73065 .51558 L .942 .69 .528 r
F
.72089 .53356 m .71699 .50934 L .71979 .45693 L .859 .61 .562 r
F
.71699 .50934 m .71688 .44906 L .71979 .45693 L .837 .599 .579 r
F
.72422 .5642 m .72806 .57057 L .73107 .57912 L .607 .197 0 r
F
.72422 .5642 m .72147 .55964 L .72806 .57057 L F
.72147 .55964 m .72456 .55368 L .72806 .57057 L .33 .29 .662 r
F
.71688 .44906 m .73141 .63553 L .73373 .63114 L .972 .671 .388 r
F
.73373 .63114 m .73141 .63553 L .73093 .61587 L .982 .708 .421 r
F
.7231 .47155 m .71979 .45693 L .73569 .62352 L .978 .679 .337 r
F
.71979 .45693 m .73373 .63114 L .73604 .62717 L .976 .675 .37 r
F
.71979 .45693 m .71688 .44906 L .73289 .62214 L F
.73301 .62219 m .73289 .62214 L .73373 .63114 L F
.71979 .45693 m .73289 .62214 L .73301 .62219 L F
.71699 .50934 m .71325 .48755 L .71688 .44906 L .837 .599 .579 r
F
.71325 .48755 m .71424 .44582 L .71688 .44906 L .782 .566 .607 r
F
.72147 .55964 m .71811 .54489 L .72456 .55368 L .33 .29 .662 r
F
.71811 .54489 m .72089 .53356 L .72456 .55368 L .43 .336 .647 r
F
.71688 .44906 m .71424 .44582 L .72999 .6198 L .972 .671 .388 r
F
.73018 .61967 m .72999 .6198 L .73141 .63553 L F
.71688 .44906 m .72999 .6198 L .73018 .61967 L F
.71424 .44582 m .72896 .6379 L .73141 .63553 L .966 .665 .403 r
F
.71325 .48755 m .70964 .46767 L .71424 .44582 L .782 .566 .607 r
F
.70964 .46767 m .71188 .44755 L .71424 .44582 L .666 .508 .661 r
F
.71456 .52637 m .71699 .50934 L .72089 .53356 L .446 .323 .619 r
F
.71811 .54489 m .71456 .52637 L .72089 .53356 L .43 .336 .647 r
F
.71424 .44582 m .71188 .44755 L .72896 .6379 L .966 .665 .403 r
F
.71357 .52466 m .70984 .50238 L .71811 .54489 L 0 0 .267 r
F
.71456 .52637 m .71059 .50029 L .71699 .50934 L .446 .323 .619 r
F
.71059 .50029 m .71325 .48755 L .71699 .50934 L .422 .318 .632 r
F
.71188 .44755 m .72629 .63688 L .72896 .6379 L .962 .661 .412 r
F
.70964 .46767 m .70632 .45271 L .71188 .44755 L .666 .508 .661 r
F
.71059 .50029 m .70692 .47901 L .71325 .48755 L .422 .318 .632 r
F
.70692 .47901 m .70964 .46767 L .71325 .48755 L .424 .329 .644 r
F
.71188 .44755 m .70968 .45258 L .72629 .63688 L .962 .661 .412 r
F
.70968 .45258 m .72355 .63484 L .72629 .63688 L .958 .656 .418 r
F
.70692 .47901 m .7034 .46031 L .70964 .46767 L .424 .329 .644 r
F
.7034 .46031 m .70632 .45271 L .70964 .46767 L .425 .37 .693 r
F
.70968 .45258 m .7076 .46013 L .72355 .63484 L .958 .656 .418 r
F
.7076 .46013 m .7206 .62939 L .72355 .63484 L .954 .651 .422 r
F
.72055 .62669 m .71589 .48535 L .71815 .48071 L .968 .695 .459 r
F
.7206 .62939 m .72051 .62672 L .72055 .62669 L F
.72051 .62672 m .71589 .48535 L .72055 .62669 L F
.72321 .6179 m .71815 .48071 L .7204 .47642 L .971 .696 .453 r
F
.72355 .63484 m .72295 .61778 L .72321 .6179 L F
.72295 .61778 m .71815 .48071 L .72321 .6179 L F
.72551 .60159 m .7204 .47642 L .72268 .47298 L .976 .7 .442 r
F
.72629 .63688 m .72495 .60038 L .72551 .60159 L F
.72495 .60038 m .7204 .47642 L .72551 .60159 L F
.73573 .62361 m .73569 .62352 L .73594 .62612 L .978 .679 .337 r
F
.7231 .47155 m .73569 .62352 L .73573 .62361 L F
.73596 .62615 m .73594 .62612 L .73602 .62697 L F
.7231 .47155 m .73594 .62612 L .73596 .62615 L F
.7231 .47155 m .73602 .62697 L .73603 .62698 L F
.72668 .49056 m .7231 .47155 L .73797 .61725 L .974 .677 .294 r
F
.7231 .47155 m .73604 .62717 L .73797 .61725 L .978 .679 .337 r
F
.72828 .60933 m .72268 .47298 L .72494 .46951 L .977 .701 .438 r
F
.72896 .6379 m .72783 .60835 L .72828 .60933 L F
.72783 .60835 m .72268 .47298 L .72828 .60933 L F
.73065 .51558 m .72668 .49056 L .73993 .60923 L .945 .659 .203 r
F
.73996 .60936 m .73993 .60923 L .74007 .61054 L F
.73065 .51558 m .73993 .60923 L .73996 .60936 L F
.73797 .61725 m .73604 .62717 L .73504 .5872 L .987 .715 .402 r
F
.72668 .49056 m .73797 .61725 L .74007 .61054 L .974 .677 .294 r
F
.73717 .59679 m .73504 .5872 L .73194 .46431 L .987 .715 .402 r
F
.73797 .61725 m .73504 .5872 L .73717 .59679 L F
.73333 .6211 m .73093 .61587 L .72726 .46718 L .982 .708 .421 r
F
.73373 .63114 m .73093 .61587 L .73333 .6211 L F
.73603 .62698 m .73602 .62697 L .73604 .62717 L .978 .679 .337 r
F
.44396 .44372 m .44626 .43864 L .44941 .44195 L .663 .741 .908 r
F
.44396 .44372 m .44081 .44043 L .44626 .43864 L F
.78702 .44372 m .79031 .43864 L .79282 .44195 L F
.78702 .44372 m .78451 .44043 L .79031 .43864 L F
.27242 .44372 m .27424 .43864 L .2777 .44194 L F
.27242 .44372 m .26896 .44043 L .27424 .43864 L F
.87984 .44359 m .8834 .43851 L .88573 .4418 L F
.87984 .44359 m .8775 .44029 L .8834 .43851 L F
.3652 .44359 m .36728 .4385 L .37057 .44181 L F
.3652 .44359 m .3619 .44029 L .36728 .4385 L F
.54581 .48519 m .54289 .49055 L .54826 .45739 L 1 .813 .499 r
F
.54826 .45739 m .55091 .45739 L .55391 .46603 L 0 .501 .846 r
F
.54826 .45739 m .54531 .45578 L .55091 .45739 L F
.54289 .49055 m .54531 .45578 L .54826 .45739 L .993 .783 .519 r
F
.28643 .44345 m .28829 .43837 L .29172 .44167 L .663 .741 .908 r
F
.28643 .44345 m .28299 .44015 L .28829 .43837 L F
.80111 .44346 m .80444 .43839 L .80692 .44167 L .663 .742 .909 r
F
.80111 .44346 m .79862 .44017 L .80444 .43839 L F
.46027 .43868 m .4572 .43536 L .46033 .43866 L .642 .735 .917 r
F
.45487 .44016 m .4572 .43536 L .46027 .43868 L F
.45173 .43686 m .45407 .43196 L .4572 .43536 L .649 .738 .914 r
F
.4572 .43536 m .45407 .43196 L .45412 .43204 L .687 .203 0 r
F
.45799 .44347 m .45487 .44016 L .46033 .43866 L .643 .734 .915 r
F
.45487 .44016 m .45173 .43686 L .4572 .43536 L .642 .735 .917 r
F
.4572 .43536 m .45412 .43204 L .45938 .43932 L .687 .203 0 r
F
.46033 .43866 m .4572 .43536 L .45723 .4354 L .727 .245 0 r
F
.45799 .44347 m .46033 .43866 L .46342 .44191 L .643 .734 .915 r
F
.46033 .43866 m .45723 .4354 L .46251 .44314 L .727 .245 0 r
F
.46342 .44191 m .46033 .43866 L .46345 .4419 L .643 .734 .915 r
F
.89394 .44331 m .89754 .43824 L .89985 .44154 L .664 .742 .909 r
F
.89394 .44331 m .89163 .44003 L .89754 .43824 L F
.37922 .44333 m .38135 .43823 L .38461 .44153 L .664 .741 .908 r
F
.37922 .44333 m .37595 .44003 L .38135 .43823 L F
.30044 .44318 m .30234 .43808 L .30575 .44139 L F
.30044 .44318 m .29703 .43988 L .30234 .43808 L F
.8152 .44318 m .81857 .43809 L .82103 .44139 L F
.8152 .44318 m .81274 .43988 L .81857 .43809 L F
.39325 .44304 m .39541 .43795 L .39865 .44125 L .664 .742 .908 r
F
.39325 .44304 m .39001 .43974 L .39541 .43795 L F
.90805 .44304 m .91169 .43795 L .91397 .44125 L F
.90805 .44304 m .90576 .43975 L .91169 .43795 L F
.65878 .49469 m .66113 .47587 L .66438 .49124 L .625 .476 .66 r
F
.31446 .4429 m .3164 .43781 L .31978 .44112 L .663 .741 .908 r
F
.31446 .4429 m .31107 .4396 L .3164 .43781 L F
.8293 .4429 m .83271 .43781 L .83514 .44112 L F
.8293 .4429 m .82686 .4396 L .83271 .43781 L F
.73437 .46455 m .73194 .46431 L .73647 .44341 L .99 .814 .572 r
F
.73647 .44341 m .7396 .43795 L .7422 .44126 L .691 .754 .9 r
F
.73647 .44341 m .73387 .44017 L .7396 .43795 L F
.73194 .46431 m .73387 .44017 L .73647 .44341 L .999 .814 .513 r
F
.75053 .44277 m .75372 .43767 L .7563 .441 L .664 .742 .908 r
F
.75053 .44277 m .74795 .43948 L .75372 .43767 L F
.40728 .44277 m .40949 .43769 L .4127 .44099 L .663 .741 .908 r
F
.40728 .44277 m .40406 .43947 L .40949 .43769 L F
.52917 .50818 m .52616 .49771 L .53168 .4741 L .859 .648 .617 r
F
.53162 .47435 m .5287 .4769 L .53168 .4741 L .789 .618 .669 r
F
.52616 .49771 m .5287 .4769 L .53162 .47435 L F
.52838 .47754 m .5257 .47928 L .5287 .4769 L .565 .506 .748 r
F
.52315 .488 m .5257 .47928 L .52838 .47754 L F
.52315 .488 m .52014 .47924 L .5257 .47928 L F
.5257 .47928 m .52268 .48062 L .523 .48104 L .788 .341 .186 r
F
.52616 .49771 m .52315 .488 L .5287 .4769 L .789 .618 .669 r
F
.5257 .47928 m .523 .48104 L .52828 .48785 L .788 .341 .186 r
F
.5287 .4769 m .5257 .47928 L .52576 .47946 L .876 .512 .354 r
F
.5287 .4769 m .52576 .47946 L .53131 .49596 L F
.53419 .5038 m .53131 .49596 L .53434 .50456 L F
.5287 .4769 m .53131 .49596 L .53419 .5038 L F
.5257 .47928 m .52828 .48785 L .53131 .49596 L .788 .341 .186 r
F
.53131 .49596 m .52828 .48785 L .52843 .48811 L 0 .003 .575 r
F
.53434 .50456 m .53131 .49596 L .53156 .49596 L .565 .51 .752 r
F
.53168 .4741 m .53434 .50456 L .53713 .51315 L .907 .574 .403 r
F
.53168 .4741 m .5287 .4769 L .53434 .50456 L F
.53434 .50456 m .53156 .49596 L .53694 .496 L .565 .51 .752 r
F
.53131 .49596 m .53392 .49755 L .53694 .496 L 0 .003 .575 r
F
.53131 .49596 m .52843 .48811 L .53392 .49755 L F
.53713 .51315 m .53434 .50456 L .53738 .51501 L .907 .574 .403 r
F
.32848 .44263 m .33046 .43754 L .33382 .44085 L .663 .741 .908 r
F
.32848 .44263 m .32512 .43933 L .33046 .43754 L F
.8434 .44263 m .84685 .43754 L .84925 .44085 L .664 .742 .908 r
F
.8434 .44263 m .84099 .43934 L .84685 .43754 L F
.24967 .44249 m .25142 .43739 L .25493 .4407 L F
.24967 .44249 m .24615 .4392 L .25142 .43739 L F
.76462 .44249 m .76785 .4374 L .7704 .44071 L .665 .744 .909 r
F
.76462 .44249 m .76207 .43922 L .76785 .4374 L F
.42132 .4425 m .42356 .43741 L .42675 .44071 L .664 .742 .908 r
F
.42132 .4425 m .41813 .43921 L .42356 .43741 L F
.34251 .44236 m .34453 .43726 L .34786 .44057 L .664 .741 .908 r
F
.34251 .44236 m .33917 .43906 L .34453 .43726 L F
.8575 .44236 m .861 .43727 L .86337 .44057 L .664 .742 .908 r
F
.8575 .44236 m .85512 .43907 L .861 .43727 L F
.26368 .44221 m .26547 .43712 L .26896 .44043 L .664 .741 .908 r
F
.26368 .44221 m .26019 .43891 L .26547 .43712 L F
.43536 .44222 m .43765 .43712 L .44081 .44043 L .664 .742 .908 r
F
.43536 .44222 m .43219 .43892 L .43765 .43712 L F
.77872 .44222 m .78199 .43712 L .78451 .44043 L F
.77872 .44222 m .77619 .43892 L .78199 .43712 L F
.35654 .44208 m .3586 .43698 L .3619 .44029 L .664 .741 .908 r
F
.35654 .44208 m .35322 .43877 L .3586 .43698 L F
.87161 .44208 m .87515 .43698 L .8775 .44029 L .663 .741 .908 r
F
.87161 .44208 m .86926 .43878 L .87515 .43698 L F
.6974 .4567 m .69522 .46317 L .70023 .44787 L .689 .741 .235 r
F
.2777 .44194 m .27953 .43684 L .28299 .44015 L .664 .741 .908 r
F
.2777 .44194 m .27424 .43864 L .27953 .43684 L F
.79282 .44195 m .79613 .43685 L .79862 .44017 L .663 .741 .908 r
F
.79282 .44195 m .79031 .43864 L .79613 .43685 L F
.44941 .44195 m .45173 .43686 L .45487 .44016 L F
.44941 .44195 m .44626 .43864 L .45173 .43686 L F
.65522 .45912 m .6588 .47032 L .66103 .46076 L .843 .408 .194 r
F
.65522 .45912 m .65262 .46001 L .6588 .47032 L F
.67321 .51547 m .67614 .50977 L .67929 .52231 L .852 .99 .726 r
F
.88573 .4418 m .88931 .43672 L .89163 .44003 L .664 .742 .908 r
F
.88573 .4418 m .8834 .43851 L .88931 .43672 L F
.37057 .44181 m .37267 .43672 L .37595 .44003 L .663 .741 .908 r
F
.37057 .44181 m .36728 .4385 L .37267 .43672 L F
.65951 .52518 m .65616 .50698 L .66193 .50781 L .56 .423 .652 r
F
.65616 .50698 m .65878 .49469 L .66193 .50781 L .424 .323 .636 r
F
.80692 .44167 m .81027 .43658 L .81274 .43988 L .664 .743 .909 r
F
.80692 .44167 m .80444 .43839 L .81027 .43658 L F
.29172 .44167 m .2936 .43657 L .29703 .43988 L .664 .741 .908 r
F
.29172 .44167 m .28829 .43837 L .2936 .43657 L F
.46345 .4419 m .46563 .44706 L .46875 .45063 L .768 .293 0 r
F
.46345 .4419 m .46033 .43866 L .46563 .44706 L F
.38461 .44153 m .38675 .43643 L .39001 .43974 L .664 .742 .908 r
F
.38461 .44153 m .38135 .43823 L .38675 .43643 L F
.89985 .44154 m .90346 .43643 L .90576 .43975 L F
.89985 .44154 m .89754 .43824 L .90346 .43643 L F
.30575 .44139 m .30766 .43629 L .31107 .4396 L .664 .741 .908 r
F
.30575 .44139 m .30234 .43808 L .30766 .43629 L F
.82103 .44139 m .82442 .43629 L .82686 .4396 L F
.82103 .44139 m .81857 .43809 L .82442 .43629 L F
.66218 .52652 m .65951 .52518 L .66491 .51663 L .924 .868 .765 r
F
.91397 .44125 m .91763 .43616 L .9199 .43947 L .663 .741 .908 r
F
.91397 .44125 m .91169 .43795 L .91763 .43616 L F
.39865 .44125 m .40083 .43616 L .40406 .43947 L F
.39865 .44125 m .39541 .43795 L .40083 .43616 L F
.58874 .51499 m .59094 .483 L .59398 .49441 L .901 .691 .608 r
F
.58874 .51499 m .58578 .50801 L .59094 .483 L F
.7422 .44126 m .74536 .43617 L .74795 .43948 L .663 .741 .908 r
F
.7422 .44126 m .7396 .43795 L .74536 .43617 L F
.31978 .44112 m .32174 .43601 L .32512 .43933 L .664 .741 .908 r
F
.31978 .44112 m .3164 .43781 L .32174 .43601 L F
.83514 .44112 m .83857 .43602 L .84099 .43934 L .663 .741 .908 r
F
.83514 .44112 m .83271 .43781 L .83857 .43602 L F
.4127 .44099 m .41492 .43589 L .41813 .43921 L F
.4127 .44099 m .40949 .43769 L .41492 .43589 L F
.7563 .441 m .75951 .43591 L .76207 .43922 L .662 .739 .907 r
F
.7563 .441 m .75372 .43767 L .75951 .43591 L F
.33382 .44085 m .33581 .43574 L .33917 .43906 L .663 .741 .908 r
F
.33382 .44085 m .33046 .43754 L .33581 .43574 L F
.84925 .44085 m .85273 .43574 L .85512 .43907 L .664 .741 .908 r
F
.84925 .44085 m .84685 .43754 L .85273 .43574 L F
.47496 .4569 m .47186 .45376 L .47534 .59055 L .958 .675 .456 r
F
.25493 .4407 m .25669 .4356 L .26019 .43891 L .663 .741 .908 r
F
.25493 .4407 m .25142 .43739 L .25669 .4356 L F
.42675 .44071 m .42901 .43561 L .43219 .43892 L .664 .742 .908 r
F
.42675 .44071 m .42356 .43741 L .42901 .43561 L F
.7704 .44071 m .77365 .4356 L .77619 .43892 L .664 .741 .907 r
F
.7704 .44071 m .76785 .4374 L .77365 .4356 L F
.66193 .50781 m .65878 .49469 L .66438 .49124 L .648 .508 .678 r
F
.34786 .44057 m .34989 .43546 L .35322 .43877 L .664 .741 .908 r
F
.34786 .44057 m .34453 .43726 L .34989 .43546 L F
.86337 .44057 m .86689 .43546 L .86926 .43878 L .664 .742 .908 r
F
.86337 .44057 m .861 .43727 L .86689 .43546 L F
.78451 .44043 m .7878 .43532 L .79031 .43864 L .663 .741 .908 r
F
.78451 .44043 m .78199 .43712 L .7878 .43532 L F
.44081 .44043 m .44311 .43533 L .44626 .43864 L F
.44081 .44043 m .43765 .43712 L .44311 .43533 L F
.26896 .44043 m .27076 .43532 L .27424 .43864 L F
.26896 .44043 m .26547 .43712 L .27076 .43532 L F
.3619 .44029 m .36398 .43519 L .36728 .4385 L F
.3619 .44029 m .3586 .43698 L .36398 .43519 L F
.8775 .44029 m .88106 .43519 L .8834 .43851 L .664 .741 .908 r
F
.8775 .44029 m .87515 .43698 L .88106 .43519 L F
.28299 .44015 m .28484 .43505 L .28829 .43837 L F
.28299 .44015 m .27953 .43684 L .28484 .43505 L F
.59155 .51407 m .59398 .49441 L .59699 .50431 L .988 .825 .591 r
F
.59155 .51407 m .58874 .51499 L .59398 .49441 L F
.79862 .44017 m .80196 .43506 L .80444 .43839 L .663 .74 .907 r
F
.79862 .44017 m .79613 .43685 L .80196 .43506 L F
.75436 .65676 m .75113 .64511 L .74972 .53356 L .953 .683 .487 r
F
.37595 .44003 m .37807 .43492 L .38135 .43823 L .664 .741 .908 r
F
.37595 .44003 m .37267 .43672 L .37807 .43492 L F
.89163 .44003 m .89523 .43491 L .89754 .43824 L F
.89163 .44003 m .88931 .43672 L .89523 .43491 L F
.29703 .43988 m .29892 .43477 L .30234 .43808 L .664 .742 .908 r
F
.29703 .43988 m .2936 .43657 L .29892 .43477 L F
.81274 .43988 m .81611 .43477 L .81857 .43809 L F
.81274 .43988 m .81027 .43658 L .81611 .43477 L F
.56936 .53389 m .56631 .5204 L .57206 .53052 L .182 .194 .637 r
F
.39001 .43974 m .39216 .43463 L .39541 .43795 L .664 .742 .908 r
F
.39001 .43974 m .38675 .43643 L .39216 .43463 L F
.90576 .43975 m .9094 .43463 L .91169 .43795 L .664 .741 .907 r
F
.90576 .43975 m .90346 .43643 L .9094 .43463 L F
.31107 .4396 m .313 .43449 L .3164 .43781 L .663 .741 .908 r
F
.31107 .4396 m .30766 .43629 L .313 .43449 L F
.82686 .4396 m .83028 .43449 L .83271 .43781 L F
.82686 .4396 m .82442 .43629 L .83028 .43449 L F
.73194 .46431 m .72961 .46584 L .73387 .44017 L .999 .814 .513 r
F
.73387 .44017 m .73699 .43463 L .7396 .43795 L .701 .765 .901 r
F
.73387 .44017 m .73126 .43703 L .73699 .43463 L F
.72961 .46584 m .73126 .43703 L .73387 .44017 L .998 .794 .502 r
F
.57232 .53981 m .56936 .53389 L .57492 .52996 L .724 .648 .773 r
F
.40406 .43947 m .40626 .43436 L .40949 .43769 L .663 .741 .908 r
F
.40406 .43947 m .40083 .43616 L .40626 .43436 L F
.9199 .43947 m .92358 .43437 L .92584 .43767 L F
.9199 .43947 m .91763 .43616 L .92358 .43437 L F
.74795 .43948 m .75114 .43437 L .75372 .43767 L F
.74795 .43948 m .74536 .43617 L .75114 .43437 L F
.32512 .43933 m .32709 .43421 L .33046 .43754 L F
.32512 .43933 m .32174 .43601 L .32709 .43421 L F
.84099 .43934 m .84445 .43422 L .84685 .43754 L .664 .741 .908 r
F
.84099 .43934 m .83857 .43602 L .84445 .43422 L F
.54289 .49055 m .53993 .49403 L .54531 .45578 L .993 .783 .519 r
F
.54531 .45578 m .54793 .45171 L .55091 .45739 L .724 .91 .959 r
F
.54531 .45578 m .54236 .45458 L .54793 .45171 L F
.53993 .49403 m .54236 .45458 L .54531 .45578 L .984 .765 .528 r
F
.74007 .61054 m .73797 .61725 L .73437 .46455 L .985 .713 .413 r
F
.73797 .61725 m .73194 .46431 L .73437 .46455 L .987 .715 .402 r
F
.24615 .4392 m .2479 .43407 L .25142 .43739 L .664 .741 .908 r
F
.24615 .4392 m .24263 .43588 L .2479 .43407 L F
.41813 .43921 m .42037 .43409 L .42356 .43741 L F
.41813 .43921 m .41492 .43589 L .42037 .43409 L F
.76207 .43922 m .7653 .4341 L .76785 .4374 L .664 .742 .908 r
F
.76207 .43922 m .75951 .43591 L .7653 .4341 L F
.64689 .45999 m .65017 .46503 L .65262 .46001 L .451 .069 .223 r
F
.64689 .45999 m .64444 .46581 L .65017 .46503 L F
.33917 .43906 m .34118 .43394 L .34453 .43726 L .664 .741 .908 r
F
.33917 .43906 m .33581 .43574 L .34118 .43394 L F
.85512 .43907 m .85862 .43394 L .861 .43727 L .664 .741 .907 r
F
.85512 .43907 m .85273 .43574 L .85862 .43394 L F
.7034 .46031 m .70023 .44787 L .70632 .45271 L .425 .37 .693 r
F
.70023 .44787 m .70329 .44296 L .70632 .45271 L .506 .543 .829 r
F
.70023 .44787 m .69742 .44202 L .70329 .44296 L F
.69522 .46317 m .69742 .44202 L .70023 .44787 L .887 .77 .272 r
F
.66491 .51663 m .66762 .50609 L .67068 .51676 L .631 .542 .736 r
F
.66491 .51663 m .66193 .50781 L .66762 .50609 L F
.65951 .52518 m .66193 .50781 L .66491 .51663 L .56 .423 .652 r
F
.26019 .43891 m .26198 .4338 L .26547 .43712 L .664 .741 .908 r
F
.26019 .43891 m .25669 .4356 L .26198 .4338 L F
.77619 .43892 m .77946 .43379 L .78199 .43712 L F
.77619 .43892 m .77365 .4356 L .77946 .43379 L F
.43219 .43892 m .43447 .4338 L .43765 .43712 L .664 .742 .908 r
F
.43219 .43892 m .42901 .43561 L .43447 .4338 L F
.35322 .43877 m .35528 .43366 L .3586 .43698 L .663 .741 .908 r
F
.35322 .43877 m .34989 .43546 L .35528 .43366 L F
.86926 .43878 m .87279 .43366 L .87515 .43698 L .664 .741 .908 r
F
.86926 .43878 m .86689 .43546 L .87279 .43366 L F
.57742 .51238 m .58018 .51167 L .58302 .51074 L 0 0 0 r
F
.79031 .43864 m .79362 .43353 L .79613 .43685 L .663 .741 .908 r
F
.79031 .43864 m .7878 .43532 L .79362 .43353 L F
.27424 .43864 m .27606 .43352 L .27953 .43684 L F
.27424 .43864 m .27076 .43532 L .27606 .43352 L F
.44626 .43864 m .44858 .43356 L .45173 .43686 L .661 .741 .909 r
F
.44626 .43864 m .44311 .43533 L .44858 .43356 L F
.36728 .4385 m .36938 .43339 L .37267 .43672 L .663 .741 .908 r
F
.36728 .4385 m .36398 .43519 L .36938 .43339 L F
.8834 .43851 m .88697 .43338 L .88931 .43672 L .664 .741 .907 r
F
.8834 .43851 m .88106 .43519 L .88697 .43338 L F
.28829 .43837 m .29015 .43325 L .2936 .43657 L .663 .741 .908 r
F
.28829 .43837 m .28484 .43505 L .29015 .43325 L F
.80444 .43839 m .80779 .43326 L .81027 .43658 L .664 .741 .907 r
F
.80444 .43839 m .80196 .43506 L .80779 .43326 L F
.66103 .46076 m .6588 .47032 L .66582 .49935 L .858 .535 .438 r
F
.38135 .43823 m .38348 .43311 L .38675 .43643 L .664 .741 .908 r
F
.38135 .43823 m .37807 .43492 L .38348 .43311 L F
.89754 .43824 m .90116 .43311 L .90346 .43643 L .664 .741 .907 r
F
.89754 .43824 m .89523 .43491 L .90116 .43311 L F
.46033 .43866 m .46251 .44314 L .46563 .44706 L .727 .245 0 r
F
.30234 .43808 m .30425 .43296 L .30766 .43629 L .664 .741 .908 r
F
.30234 .43808 m .29892 .43477 L .30425 .43296 L F
.81857 .43809 m .82197 .43297 L .82442 .43629 L F
.81857 .43809 m .81611 .43477 L .82197 .43297 L F
.91169 .43795 m .91535 .43284 L .91763 .43616 L .663 .741 .908 r
F
.91169 .43795 m .9094 .43463 L .91535 .43284 L F
.39541 .43795 m .39759 .43283 L .40083 .43616 L F
.39541 .43795 m .39216 .43463 L .39759 .43283 L F
.7396 .43795 m .74276 .43283 L .74536 .43617 L F
.7396 .43795 m .73699 .43463 L .74276 .43283 L F
.3164 .43781 m .31835 .43269 L .32174 .43601 L F
.3164 .43781 m .313 .43449 L .31835 .43269 L F
.83271 .43781 m .83615 .43269 L .83857 .43602 L F
.83271 .43781 m .83028 .43449 L .83615 .43269 L F
.75372 .43767 m .75693 .43255 L .75951 .43591 L .664 .742 .908 r
F
.75372 .43767 m .75114 .43437 L .75693 .43255 L F
.92584 .43767 m .92954 .43255 L .9318 .4359 L .665 .743 .908 r
F
.92584 .43767 m .92358 .43437 L .92954 .43255 L F
.40949 .43769 m .4117 .43256 L .41492 .43589 L .663 .741 .908 r
F
.40949 .43769 m .40626 .43436 L .4117 .43256 L F
.56936 .53389 m .57206 .53052 L .57492 .52996 L .182 .194 .637 r
F
.33046 .43754 m .33245 .43242 L .33581 .43574 L .663 .741 .908 r
F
.33046 .43754 m .32709 .43421 L .33245 .43242 L F
.84685 .43754 m .85033 .43242 L .85273 .43574 L .664 .741 .908 r
F
.84685 .43754 m .84445 .43422 L .85033 .43242 L F
.47186 .45376 m .47213 .5859 L .47534 .59055 L .958 .674 .456 r
F
.47186 .45376 m .46875 .45063 L .47213 .5859 L F
.25142 .43739 m .25318 .43227 L .25669 .4356 L .663 .741 .908 r
F
.25142 .43739 m .2479 .43407 L .25318 .43227 L F
.76785 .4374 m .7711 .43227 L .77365 .4356 L .665 .743 .908 r
F
.76785 .4374 m .7653 .4341 L .7711 .43227 L F
.42356 .43741 m .42582 .43227 L .42901 .43561 L .664 .742 .908 r
F
.42356 .43741 m .42037 .43409 L .42582 .43227 L F
.34453 .43726 m .34656 .43213 L .34989 .43546 L .664 .741 .908 r
F
.34453 .43726 m .34118 .43394 L .34656 .43213 L F
.861 .43727 m .86452 .43213 L .86689 .43546 L .664 .741 .907 r
F
.861 .43727 m .85862 .43394 L .86452 .43213 L F
.78199 .43712 m .78528 .432 L .7878 .43532 L .663 .741 .908 r
F
.78199 .43712 m .77946 .43379 L .78528 .432 L F
.43765 .43712 m .43994 .43201 L .44311 .43533 L F
.43765 .43712 m .43447 .4338 L .43994 .43201 L F
.26547 .43712 m .26728 .43199 L .27076 .43532 L .664 .741 .908 r
F
.26547 .43712 m .26198 .4338 L .26728 .43199 L F
.69522 .46317 m .69318 .47283 L .69742 .44202 L .887 .77 .272 r
F
.69742 .44202 m .70054 .43836 L .70329 .44296 L .704 .983 .888 r
F
.3586 .43698 m .36067 .43186 L .36398 .43519 L .663 .741 .908 r
F
.3586 .43698 m .35528 .43366 L .36067 .43186 L F
.87515 .43698 m .87871 .43186 L .88106 .43519 L F
.87515 .43698 m .87279 .43366 L .87871 .43186 L F
.58302 .51074 m .58578 .50801 L .58874 .51499 L .595 .945 .801 r
F
.58302 .51074 m .58018 .51167 L .58578 .50801 L F
.27953 .43684 m .28138 .43171 L .28484 .43505 L .664 .742 .908 r
F
.27953 .43684 m .27606 .43352 L .28138 .43171 L F
.79613 .43685 m .79946 .43172 L .80196 .43506 L F
.79613 .43685 m .79362 .43353 L .79946 .43172 L F
.45173 .43686 m .44858 .43356 L .45407 .43196 L .649 .738 .914 r
F
.37267 .43672 m .37478 .43158 L .37807 .43492 L .664 .741 .908 r
F
.37267 .43672 m .36938 .43339 L .37478 .43158 L F
.88931 .43672 m .89291 .43159 L .89523 .43491 L .663 .74 .908 r
F
.88931 .43672 m .88697 .43338 L .89291 .43159 L F
.52501 .66754 m .52192 .65342 L .52755 .56202 L .921 .67 .542 r
F
.52192 .65342 m .52454 .57193 L .52755 .56202 L .905 .661 .558 r
F
.2936 .43657 m .29548 .43144 L .29892 .43477 L .664 .742 .908 r
F
.2936 .43657 m .29015 .43325 L .29548 .43144 L F
.81027 .43658 m .81364 .43144 L .81611 .43477 L F
.81027 .43658 m .80779 .43326 L .81364 .43144 L F
.90346 .43643 m .90711 .4313 L .9094 .43463 L F
.90346 .43643 m .90116 .43311 L .90711 .4313 L F
.38675 .43643 m .3889 .4313 L .39216 .43463 L .664 .741 .908 r
F
.38675 .43643 m .38348 .43311 L .3889 .4313 L F
.53564 .54292 m .53824 .54255 L .54125 .5516 L 0 0 .093 r
F
.53564 .54292 m .53267 .5521 L .53824 .54255 L F
.65262 .46001 m .65652 .47937 L .6588 .47032 L .828 .464 .365 r
F
.65262 .46001 m .65017 .46503 L .65652 .47937 L F
.30766 .43629 m .30959 .43116 L .313 .43449 L .663 .741 .908 r
F
.30766 .43629 m .30425 .43296 L .30959 .43116 L F
.82442 .43629 m .82783 .43117 L .83028 .43449 L F
.82442 .43629 m .82197 .43297 L .82783 .43117 L F
.40083 .43616 m .40303 .43103 L .40626 .43436 L F
.40083 .43616 m .39759 .43283 L .40303 .43103 L F
.91763 .43616 m .92131 .43102 L .92358 .43437 L .664 .742 .908 r
F
.91763 .43616 m .91535 .43284 L .92131 .43102 L F
.74536 .43617 m .74855 .43104 L .75114 .43437 L .662 .74 .908 r
F
.74536 .43617 m .74276 .43283 L .74855 .43104 L F
.72961 .46584 m .72726 .46718 L .73126 .43703 L .998 .794 .502 r
F
.73126 .43703 m .73437 .43131 L .73699 .43463 L .71 .768 .897 r
F
.73126 .43703 m .72865 .43387 L .73437 .43131 L F
.72726 .46718 m .72865 .43387 L .73126 .43703 L .998 .784 .473 r
F
.55693 .47692 m .55391 .46603 L .55964 .47812 L 0 .01 .563 r
F
.55391 .46603 m .55663 .46978 L .55964 .47812 L 0 0 .461 r
F
.55391 .46603 m .55091 .45739 L .55663 .46978 L F
.32174 .43601 m .3237 .43088 L .32709 .43421 L .664 .742 .908 r
F
.32174 .43601 m .31835 .43269 L .3237 .43088 L F
.83857 .43602 m .84203 .43089 L .84445 .43422 L .663 .741 .908 r
F
.83857 .43602 m .83615 .43269 L .84203 .43089 L F
.24263 .43588 m .24437 .43074 L .2479 .43407 L .664 .741 .908 r
F
.24263 .43588 m .23909 .43255 L .24437 .43074 L F
.41492 .43589 m .41716 .43075 L .42037 .43409 L F
.41492 .43589 m .4117 .43256 L .41716 .43075 L F
.9318 .4359 m .93552 .43076 L .93776 .43408 L .662 .739 .907 r
F
.9318 .4359 m .92954 .43255 L .93552 .43076 L F
.75951 .43591 m .76273 .43076 L .7653 .4341 L .663 .739 .907 r
F
.75951 .43591 m .75693 .43255 L .76273 .43076 L F
.85273 .43574 m .85623 .43061 L .85862 .43394 L .664 .741 .908 r
F
.85273 .43574 m .85033 .43242 L .85623 .43061 L F
.33581 .43574 m .33782 .43061 L .34118 .43394 L F
.33581 .43574 m .33245 .43242 L .33782 .43061 L F
.55091 .45739 m .54793 .45171 L .55363 .46334 L .679 .291 0 r
F
.55356 .4632 m .55063 .45726 L .55363 .46334 L .671 .27 0 r
F
.54793 .45171 m .55063 .45726 L .55356 .4632 L F
.54236 .45458 m .54494 .44642 L .54793 .45171 L .899 .885 .81 r
F
.54793 .45171 m .54494 .44642 L .55063 .45726 L .671 .27 0 r
F
.55063 .45726 m .54763 .45134 L .54769 .4513 L .707 .645 .785 r
F
.55063 .45726 m .54769 .4513 L .55324 .44799 L F
.55363 .46334 m .55063 .45726 L .55076 .45717 L .726 .648 .771 r
F
.55091 .45739 m .55363 .46334 L .5565 .4695 L .679 .291 0 r
F
.55363 .46334 m .55076 .45717 L .55623 .45318 L .726 .648 .771 r
F
.5565 .4695 m .55363 .46334 L .55663 .46978 L .679 .291 0 r
F
.77365 .4356 m .77692 .43046 L .77946 .43379 L .664 .742 .908 r
F
.77365 .4356 m .7711 .43227 L .77692 .43046 L F
.25669 .4356 m .25847 .43046 L .26198 .4338 L .664 .741 .908 r
F
.25669 .4356 m .25318 .43227 L .25847 .43046 L F
.42901 .43561 m .43129 .43046 L .43447 .4338 L F
.42901 .43561 m .42582 .43227 L .43129 .43046 L F
.34989 .43546 m .35194 .43033 L .35528 .43366 L .663 .741 .908 r
F
.34989 .43546 m .34656 .43213 L .35194 .43033 L F
.86689 .43546 m .87043 .43033 L .87279 .43366 L F
.86689 .43546 m .86452 .43213 L .87043 .43033 L F
.27076 .43532 m .27258 .43019 L .27606 .43352 L F
.27076 .43532 m .26728 .43199 L .27258 .43019 L F
.7878 .43532 m .79111 .4302 L .79362 .43353 L F
.7878 .43532 m .78528 .432 L .79111 .4302 L F
.44311 .43533 m .44543 .43022 L .44858 .43356 L .662 .741 .909 r
F
.44311 .43533 m .43994 .43201 L .44543 .43022 L F
.55995 .48747 m .55693 .47692 L .56266 .48729 L 0 .095 .615 r
F
.55693 .47692 m .55964 .47812 L .56266 .48729 L 0 .01 .563 r
F
.36398 .43519 m .36607 .43005 L .36938 .43339 L .663 .741 .908 r
F
.36398 .43519 m .36067 .43186 L .36607 .43005 L F
.88106 .43519 m .88464 .43006 L .88697 .43338 L F
.88106 .43519 m .87871 .43186 L .88464 .43006 L F
.28484 .43505 m .2867 .42991 L .29015 .43325 L F
.28484 .43505 m .28138 .43171 L .2867 .42991 L F
.80196 .43506 m .80531 .42991 L .80779 .43326 L .664 .741 .907 r
F
.80196 .43506 m .79946 .43172 L .80531 .42991 L F
.62763 .47765 m .6273 .47623 L .63133 .49912 L .818 .534 0 r
F
.6273 .47623 m .62821 .48314 L .63133 .49912 L F
.6245 .46415 m .62827 .48911 L .63133 .49912 L .934 .599 .158 r
F
.63418 .50254 m .63133 .49912 L .63695 .49369 L .815 .773 .813 r
F
.63133 .49912 m .62827 .48911 L .6306 .49357 L 0 .034 .585 r
F
.63133 .49912 m .63445 .50094 L .63695 .49369 L F
.63367 .49526 m .63429 .4859 L .63698 .48442 L .804 .663 .708 r
F
.6329 .50003 m .6306 .49357 L .63428 .5006 L 0 .034 .585 r
F
.63133 .49912 m .6306 .49357 L .6329 .50003 L F
.63431 .50085 m .63428 .5006 L .63445 .50094 L F
.6329 .50003 m .63428 .5006 L .63431 .50085 L F
.62923 .49095 m .63172 .50164 L .63445 .50094 L 0 0 .193 r
F
.63172 .50164 m .6333 .49197 L .63367 .49526 L .804 .663 .708 r
F
.6333 .49197 m .63429 .4859 L .63367 .49526 L F
.62827 .48911 m .62965 .49411 L .62923 .49095 L 0 0 .193 r
F
.62965 .49411 m .63172 .50164 L .62923 .49095 L F
.6245 .46415 m .62153 .45616 L .62827 .48911 L .934 .599 .158 r
F
.62827 .48911 m .62517 .4776 L .63074 .49805 L 0 0 .193 r
F
.631 .49901 m .63074 .49805 L .63172 .50164 L F
.62827 .48911 m .63074 .49805 L .631 .49901 L F
.62952 .49344 m .63146 .48381 L .63429 .4859 L .682 .594 .751 r
F
.62598 .48056 m .62874 .49468 L .63172 .50164 L .757 .479 0 r
F
.62874 .49468 m .62928 .49252 L .62952 .49344 L .682 .594 .751 r
F
.62928 .49252 m .63146 .48381 L .62952 .49344 L F
.62517 .4776 m .62552 .47928 L .62598 .48056 L .757 .479 0 r
F
.62552 .47928 m .62874 .49468 L .62598 .48056 L F
.6273 .47623 m .6245 .46415 L .62821 .48314 L .818 .534 0 r
F
.89523 .43491 m .89885 .42977 L .90116 .43311 L .664 .742 .908 r
F
.89523 .43491 m .89291 .43159 L .89885 .42977 L F
.37807 .43492 m .3802 .42977 L .38348 .43311 L .664 .741 .908 r
F
.37807 .43492 m .37478 .43158 L .3802 .42977 L F
.4572 .43536 m .45938 .43932 L .46251 .44314 L .687 .203 0 r
F
.53993 .49403 m .53694 .496 L .54236 .45458 L .984 .765 .528 r
F
.54236 .45458 m .53939 .4534 L .54494 .44642 L .899 .885 .81 r
F
.53694 .496 m .53939 .4534 L .54236 .45458 L .981 .757 .527 r
F
.29892 .43477 m .30082 .42963 L .30425 .43296 L .664 .741 .908 r
F
.29892 .43477 m .29548 .43144 L .30082 .42963 L F
.81611 .43477 m .81951 .42963 L .82197 .43297 L F
.81611 .43477 m .81364 .43144 L .81951 .42963 L F
.56301 .50115 m .55995 .48747 L .56566 .49553 L .286 .263 .658 r
F
.55995 .48747 m .56266 .48729 L .56566 .49553 L 0 .095 .615 r
F
.39216 .43463 m .39433 .42949 L .39759 .43283 L .663 .741 .908 r
F
.39216 .43463 m .3889 .4313 L .39433 .42949 L F
.9094 .43463 m .91306 .4295 L .91535 .43284 L F
.9094 .43463 m .90711 .4313 L .91306 .4295 L F
.73699 .43463 m .74015 .4295 L .74276 .43283 L .664 .742 .908 r
F
.73699 .43463 m .73437 .43131 L .74015 .4295 L F
.83028 .43449 m .83371 .42937 L .83615 .43269 L .663 .742 .908 r
F
.83028 .43449 m .82783 .43117 L .83371 .42937 L F
.313 .43449 m .31494 .42936 L .31835 .43269 L .663 .741 .908 r
F
.313 .43449 m .30959 .43116 L .31494 .42936 L F
.40626 .43436 m .40847 .42922 L .4117 .43256 L F
.40626 .43436 m .40303 .43103 L .40847 .42922 L F
.75114 .43437 m .75435 .42924 L .75693 .43255 L .663 .742 .908 r
F
.75114 .43437 m .74855 .43104 L .75435 .42924 L F
.92358 .43437 m .92728 .42922 L .92954 .43255 L .663 .74 .907 r
F
.92358 .43437 m .92131 .43102 L .92728 .42922 L F
.73604 .62717 m .72961 .46584 L .73194 .46431 L .982 .708 .423 r
F
.32709 .43421 m .32907 .42907 L .33245 .43242 L .664 .741 .908 r
F
.32709 .43421 m .3237 .43088 L .32907 .42907 L F
.84445 .43422 m .84792 .42908 L .85033 .43242 L .663 .741 .908 r
F
.84445 .43422 m .84203 .43089 L .84792 .42908 L F
.61901 .47166 m .6164 .47653 L .61938 .46469 L .971 .866 .474 r
F
.61962 .46761 m .61938 .46469 L .62104 .45812 L F
.61901 .47166 m .61938 .46469 L .61962 .46761 L F
.61901 .47166 m .62104 .45812 L .62115 .45848 L F
.6164 .47653 m .61856 .4482 L .62153 .45616 L .974 .803 .384 r
F
.6164 .47653 m .61388 .48598 L .61752 .45663 L F
.61778 .45849 m .61752 .45663 L .61856 .4482 L F
.6164 .47653 m .61752 .45663 L .61778 .45849 L F
.61835 .4499 m .61584 .44902 L .61856 .4482 L .999 .789 .458 r
F
.61662 .46388 m .61584 .44902 L .61835 .4499 L F
.61537 .45792 m .61584 .44902 L .61662 .46388 L F
.61125 .49203 m .61304 .44788 L .61584 .44902 L .945 .713 .557 r
F
.61584 .44902 m .61304 .44788 L .61331 .44813 L .678 .133 0 r
F
.61856 .4482 m .61584 .44902 L .62203 .46472 L .891 .498 .275 r
F
.61681 .45149 m .61842 .45277 L .61871 .4563 L .678 .133 0 r
F
.61584 .44902 m .61663 .45017 L .61681 .45149 L F
.61663 .45017 m .61842 .45277 L .61681 .45149 L F
.61842 .45277 m .61894 .45352 L .61871 .4563 L F
.61388 .48598 m .61125 .49203 L .61508 .45612 L .999 .789 .458 r
F
.61537 .45792 m .61508 .45612 L .61584 .44902 L F
.61388 .48598 m .61508 .45612 L .61537 .45792 L F
.61584 .44902 m .61403 .44838 L .61894 .45352 L .678 .133 0 r
F
.61403 .44838 m .61331 .44813 L .61894 .45352 L F
.61389 .44869 m .61591 .44431 L .61894 .45352 L .651 .934 .667 r
F
.61331 .44813 m .6137 .44754 L .61389 .44869 L F
.6137 .44754 m .61591 .44431 L .61389 .44869 L F
.61304 .44788 m .61321 .44767 L .61331 .44813 L F
.61321 .44767 m .61591 .44431 L .61331 .44813 L F
.61388 .48598 m .61537 .45792 L .61662 .46388 L .999 .789 .458 r
F
.61871 .4563 m .61894 .45352 L .62203 .46472 L .678 .133 0 r
F
.62025 .45572 m .62203 .46472 L .62517 .4776 L .891 .498 .275 r
F
.61856 .4482 m .61994 .45476 L .62025 .45572 L F
.61994 .45476 m .62203 .46472 L .62025 .45572 L F
.62115 .45848 m .62104 .45812 L .62153 .45616 L .971 .866 .474 r
F
.62153 .45616 m .61856 .4482 L .62517 .4776 L .916 .577 .113 r
F
.2479 .43407 m .24966 .42893 L .25318 .43227 L .664 .741 .908 r
F
.2479 .43407 m .24437 .43074 L .24966 .42893 L F
.93776 .43408 m .94151 .42894 L .94374 .43228 L .664 .743 .908 r
F
.93776 .43408 m .93552 .43076 L .94151 .42894 L F
.42037 .43409 m .42262 .42893 L .42582 .43227 L .664 .741 .907 r
F
.42037 .43409 m .41716 .43075 L .42262 .42893 L F
.7653 .4341 m .76854 .42894 L .7711 .43227 L F
.7653 .4341 m .76273 .43076 L .76854 .42894 L F
.46563 .44706 m .46568 .57625 L .46891 .58082 L .959 .676 .454 r
F
.46891 .58082 m .46568 .57625 L .4657 .57608 L .946 .705 .543 r
F
.47196 .57926 m .46891 .58082 L .47212 .58554 L .959 .675 .455 r
F
.46875 .45063 m .4689 .56936 L .4717 .56879 L F
.46875 .45063 m .46563 .44706 L .46891 .58082 L F
.46563 .44706 m .46251 .44314 L .46568 .57625 L .959 .676 .454 r
F
.46251 .44314 m .46245 .5707 L .46568 .57625 L .959 .675 .454 r
F
.46246 .57067 m .46583 .51546 L .46915 .51267 L .921 .687 .568 r
F
.46245 .5707 m .46245 .57067 L .46246 .57067 L F
.46245 .57067 m .46583 .51546 L .46246 .57067 L F
.4717 .56879 m .46891 .57771 L .47196 .57926 L .959 .675 .455 r
F
.4689 .56936 m .46891 .57771 L .4717 .56879 L F
.46891 .57771 m .46891 .58082 L .47196 .57926 L F
.4657 .57608 m .46915 .51267 L .4724 .51285 L .94 .701 .55 r
F
.46568 .57625 m .46569 .57608 L .4657 .57608 L F
.46569 .57608 m .46915 .51267 L .4657 .57608 L F
.46891 .58082 m .4657 .57608 L .4724 .51285 L .946 .705 .543 r
F
.47212 .58554 m .46891 .58082 L .47213 .5859 L .959 .675 .455 r
F
.85862 .43394 m .86213 .42879 L .86452 .43213 L .664 .742 .908 r
F
.85862 .43394 m .85623 .43061 L .86213 .42879 L F
.34118 .43394 m .3432 .42879 L .34656 .43213 L .664 .741 .908 r
F
.34118 .43394 m .33782 .43061 L .3432 .42879 L F
.77946 .43379 m .78275 .42865 L .78528 .432 L .663 .741 .908 r
F
.77946 .43379 m .77692 .43046 L .78275 .42865 L F
.43447 .4338 m .43677 .42867 L .43994 .43201 L .662 .741 .908 r
F
.43447 .4338 m .43129 .43046 L .43677 .42867 L F
.26198 .4338 m .26378 .42865 L .26728 .43199 L .664 .741 .908 r
F
.26198 .4338 m .25847 .43046 L .26378 .42865 L F
.70632 .45271 m .70968 .45258 L .71188 .44755 L .078 .175 .664 r
F
.70632 .45271 m .70329 .44296 L .70968 .45258 L F
.70329 .44296 m .7076 .46013 L .70968 .45258 L .898 .516 .069 r
F
.70329 .44296 m .70054 .43836 L .7076 .46013 L F
.61676 .49688 m .61392 .49394 L .61901 .47166 L .947 .752 .608 r
F
.87279 .43366 m .87635 .42852 L .87871 .43186 L .663 .741 .908 r
F
.87279 .43366 m .87043 .43033 L .87635 .42852 L F
.35528 .43366 m .35734 .42852 L .36067 .43186 L F
.35528 .43366 m .35194 .43033 L .35734 .42852 L F
.27606 .43352 m .2779 .42837 L .28138 .43171 L .664 .741 .908 r
F
.27606 .43352 m .27258 .43019 L .2779 .42837 L F
.79362 .43353 m .79696 .4284 L .79946 .43172 L .663 .742 .909 r
F
.79362 .43353 m .79111 .4302 L .79696 .4284 L F
.44858 .43356 m .45092 .42856 L .45407 .43196 L .653 .738 .912 r
F
.44858 .43356 m .44543 .43022 L .45092 .42856 L F
.88697 .43338 m .89057 .42824 L .89291 .43159 L .664 .742 .908 r
F
.88697 .43338 m .88464 .43006 L .89057 .42824 L F
.36938 .43339 m .37148 .42824 L .37478 .43158 L .664 .741 .908 r
F
.36938 .43339 m .36607 .43005 L .37148 .42824 L F
.57206 .53052 m .56908 .52382 L .57457 .51314 L .827 .672 .691 r
F
.57457 .51314 m .57725 .50714 L .58018 .51167 L .736 .779 .887 r
F
.57457 .51314 m .57164 .51014 L .57725 .50714 L F
.56908 .52382 m .57164 .51014 L .57457 .51314 L .699 .576 .714 r
F
.29015 .43325 m .29203 .4281 L .29548 .43144 L .664 .741 .908 r
F
.29015 .43325 m .2867 .42991 L .29203 .4281 L F
.80779 .43326 m .81116 .4281 L .81364 .43144 L .664 .741 .907 r
F
.80779 .43326 m .80531 .42991 L .81116 .4281 L F
.90116 .43311 m .9048 .42796 L .90711 .4313 L .664 .741 .908 r
F
.90116 .43311 m .89885 .42977 L .9048 .42796 L F
.38348 .43311 m .38563 .42795 L .3889 .4313 L F
.38348 .43311 m .3802 .42977 L .38563 .42795 L F
.30425 .43296 m .30617 .42782 L .30959 .43116 L .663 .741 .908 r
F
.30425 .43296 m .30082 .42963 L .30617 .42782 L F
.82197 .43297 m .82538 .42782 L .82783 .43117 L F
.82197 .43297 m .81951 .42963 L .82538 .42782 L F
.52053 .55926 m .52315 .488 L .52616 .49771 L .955 .711 .53 r
F
.52053 .55926 m .51745 .55616 L .52315 .488 L F
.51745 .55616 m .52014 .47924 L .52315 .488 L .945 .699 .534 r
F
.39759 .43283 m .39978 .42768 L .40303 .43103 L .663 .741 .908 r
F
.39759 .43283 m .39433 .42949 L .39978 .42768 L F
.74276 .43283 m .74595 .42768 L .74855 .43104 L .664 .742 .908 r
F
.74276 .43283 m .74015 .4295 L .74595 .42768 L F
.91535 .43284 m .91903 .42768 L .92131 .43102 L .664 .741 .907 r
F
.91535 .43284 m .91306 .4295 L .91903 .42768 L F
.52359 .56118 m .52616 .49771 L .52917 .50818 L .959 .719 .531 r
F
.52359 .56118 m .52053 .55926 L .52616 .49771 L F
.72726 .46718 m .72494 .46951 L .72865 .43387 L .998 .784 .473 r
F
.72865 .43387 m .73174 .42796 L .73437 .43131 L .725 .778 .895 r
F
.72865 .43387 m .72603 .43079 L .73174 .42796 L F
.72494 .46951 m .72603 .43079 L .72865 .43387 L .998 .775 .448 r
F
.83615 .43269 m .8396 .42755 L .84203 .43089 L .664 .742 .908 r
F
.83615 .43269 m .83371 .42937 L .8396 .42755 L F
.31835 .43269 m .32031 .42754 L .3237 .43088 L F
.31835 .43269 m .31494 .42936 L .32031 .42754 L F
.92954 .43255 m .93327 .42742 L .93552 .43076 L .663 .742 .909 r
F
.92954 .43255 m .92728 .42922 L .93327 .42742 L F
.75693 .43255 m .76016 .4274 L .76273 .43076 L .665 .743 .908 r
F
.75693 .43255 m .75435 .42924 L .76016 .4274 L F
.23909 .43255 m .24082 .4274 L .24437 .43074 L .664 .741 .908 r
F
.23909 .43255 m .23554 .42921 L .24082 .4274 L F
.4117 .43256 m .41393 .4274 L .41716 .43075 L F
.4117 .43256 m .40847 .42922 L .41393 .4274 L F
.51745 .55616 m .51437 .55054 L .52014 .47924 L .945 .699 .534 r
F
.52014 .47924 m .52268 .48062 L .5257 .47928 L 0 .029 .599 r
F
.52014 .47924 m .51712 .47218 L .52268 .48062 L F
.51437 .55054 m .51712 .47218 L .52014 .47924 L .943 .696 .535 r
F
.85033 .43242 m .85382 .42726 L .85623 .43061 L .664 .742 .908 r
F
.85033 .43242 m .84792 .42908 L .85382 .42726 L F
.33245 .43242 m .33445 .42726 L .33782 .43061 L .663 .741 .908 r
F
.33245 .43242 m .32907 .42907 L .33445 .42726 L F
.56607 .51469 m .56301 .50115 L .56867 .50376 L .498 .407 .683 r
F
.56301 .50115 m .56566 .49553 L .56867 .50376 L .286 .263 .658 r
F
.25318 .43227 m .25495 .42712 L .25847 .43046 L .664 .741 .908 r
F
.25318 .43227 m .24966 .42893 L .25495 .42712 L F
.7711 .43227 m .77437 .42711 L .77692 .43046 L .664 .742 .908 r
F
.7711 .43227 m .76854 .42894 L .77437 .42711 L F
.42582 .43227 m .42809 .42712 L .43129 .43046 L .664 .741 .908 r
F
.42582 .43227 m .42262 .42893 L .42809 .42712 L F
.94374 .43228 m .94751 .42714 L .94974 .43048 L .663 .741 .908 r
F
.94374 .43228 m .94151 .42894 L .94751 .42714 L F
.52665 .56184 m .52917 .50818 L .53219 .51981 L .965 .731 .534 r
F
.52665 .56184 m .52359 .56118 L .52917 .50818 L F
.86452 .43213 m .86805 .42698 L .87043 .43033 L .663 .741 .908 r
F
.86452 .43213 m .86213 .42879 L .86805 .42698 L F
.34656 .43213 m .3486 .42698 L .35194 .43033 L F
.34656 .43213 m .3432 .42879 L .3486 .42698 L F
.26728 .43199 m .26909 .42684 L .27258 .43019 L F
.26728 .43199 m .26378 .42865 L .26909 .42684 L F
.78528 .432 m .78859 .42684 L .79111 .4302 L F
.78528 .432 m .78275 .42865 L .78859 .42684 L F
.43994 .43201 m .44226 .42685 L .44543 .43022 L .664 .741 .908 r
F
.43994 .43201 m .43677 .42867 L .44226 .42685 L F
.36067 .43186 m .36275 .4267 L .36607 .43005 L F
.36067 .43186 m .35734 .42852 L .36275 .4267 L F
.87871 .43186 m .88229 .42671 L .88464 .43006 L .663 .742 .908 r
F
.87871 .43186 m .87635 .42852 L .88229 .42671 L F
.28138 .43171 m .28323 .42656 L .2867 .42991 L .664 .741 .908 r
F
.28138 .43171 m .2779 .42837 L .28323 .42656 L F
.79946 .43172 m .80281 .42657 L .80531 .42991 L .664 .743 .909 r
F
.79946 .43172 m .79696 .4284 L .80281 .42657 L F
.57725 .50714 m .57971 .48702 L .58274 .49743 L .868 .696 .667 r
F
.57725 .50714 m .57428 .50111 L .57971 .48702 L F
.45407 .43196 m .45623 .43565 L .45938 .43932 L .666 .18 0 r
F
.45407 .43196 m .45092 .42856 L .45623 .43565 L F
.37478 .43158 m .37691 .42642 L .3802 .42977 L .664 .741 .908 r
F
.37478 .43158 m .37148 .42824 L .37691 .42642 L F
.89291 .43159 m .89652 .42642 L .89885 .42977 L .664 .742 .908 r
F
.89291 .43159 m .89057 .42824 L .89652 .42642 L F
.29548 .43144 m .29738 .42628 L .30082 .42963 L .664 .741 .908 r
F
.29548 .43144 m .29203 .4281 L .29738 .42628 L F
.81364 .43144 m .81703 .42628 L .81951 .42963 L F
.81364 .43144 m .81116 .4281 L .81703 .42628 L F
.54494 .44642 m .54763 .45134 L .55002 .4561 L .655 .231 0 r
F
.53939 .4534 m .54195 .44176 L .54494 .44642 L .956 .868 .711 r
F
.54494 .44642 m .54195 .44176 L .54763 .45134 L .655 .231 0 r
F
.54716 .45055 m .54463 .44692 L .54763 .45134 L .721 .246 0 r
F
.54195 .44176 m .54463 .44692 L .54716 .45055 L F
.53939 .4534 m .5364 .45299 L .54195 .44176 L .956 .868 .711 r
F
.5364 .45299 m .53896 .43844 L .54195 .44176 L .954 .827 .68 r
F
.53896 .43844 m .54162 .44355 L .54463 .44692 L .723 .241 0 r
F
.54463 .44692 m .54162 .44355 L .54208 .44326 L .754 .766 .862 r
F
.54195 .44176 m .53896 .43844 L .54463 .44692 L .721 .246 0 r
F
.54463 .44692 m .54208 .44326 L .54725 .44003 L .754 .766 .862 r
F
.54763 .45134 m .54463 .44692 L .54522 .44657 L .726 .705 .831 r
F
.54763 .45134 m .54522 .44657 L .55025 .44366 L F
.55002 .4561 m .54763 .45134 L .55063 .45726 L .655 .231 0 r
F
.58018 .51167 m .58274 .49743 L .58578 .50801 L .858 .728 .718 r
F
.58018 .51167 m .57725 .50714 L .58274 .49743 L F
.3889 .4313 m .39107 .42614 L .39433 .42949 L .663 .741 .908 r
F
.3889 .4313 m .38563 .42795 L .39107 .42614 L F
.90711 .4313 m .91077 .42615 L .91306 .4295 L F
.90711 .4313 m .9048 .42796 L .91077 .42615 L F
.73437 .43131 m .73753 .42615 L .74015 .4295 L F
.73437 .43131 m .73174 .42796 L .73753 .42615 L F
.51437 .55054 m .51128 .54432 L .51712 .47218 L .943 .696 .535 r
F
.51712 .47218 m .51963 .48087 L .52268 .48062 L .821 .434 0 r
F
.51128 .54432 m .51409 .46634 L .51712 .47218 L .95 .703 .53 r
F
.51712 .47218 m .51409 .46634 L .51963 .48087 L .821 .434 0 r
F
.30959 .43116 m .31153 .42601 L .31494 .42936 L .663 .741 .908 r
F
.30959 .43116 m .30617 .42782 L .31153 .42601 L F
.82783 .43117 m .83127 .42601 L .83371 .42937 L F
.82783 .43117 m .82538 .42782 L .83127 .42601 L F
.70054 .43836 m .70558 .46912 L .7076 .46013 L .938 .581 .311 r
F
.70054 .43836 m .69803 .43849 L .70558 .46912 L F
.92131 .43102 m .92502 .42588 L .92728 .42922 L .663 .741 .908 r
F
.92131 .43102 m .91903 .42768 L .92502 .42588 L F
.40303 .43103 m .40523 .42587 L .40847 .42922 L F
.40303 .43103 m .39978 .42768 L .40523 .42587 L F
.74855 .43104 m .75176 .42589 L .75435 .42924 L .662 .74 .908 r
F
.74855 .43104 m .74595 .42768 L .75176 .42589 L F
.52968 .55848 m .53219 .51981 L .53521 .53167 L .988 .773 .523 r
F
.52968 .55848 m .52665 .56184 L .53219 .51981 L F
.3237 .43088 m .32568 .42572 L .32907 .42907 L .664 .742 .908 r
F
.3237 .43088 m .32031 .42754 L .32568 .42572 L F
.64444 .46581 m .64776 .47207 L .65017 .46503 L .468 .112 .278 r
F
.6443 .46633 m .64201 .47296 L .64444 .46581 L .74 .735 .213 r
F
.63935 .48461 m .64201 .47296 L .6443 .46633 L F
.64144 .47528 m .63954 .47968 L .64201 .47296 L .881 .821 .345 r
F
.63695 .49369 m .63954 .47968 L .64144 .47528 L F
.63868 .4833 m .63698 .48442 L .63954 .47968 L .99 .853 .61 r
F
.63445 .50094 m .63698 .48442 L .63868 .4833 L F
.63698 .48442 m .63429 .4859 L .63527 .48555 L 0 0 0 r
F
.63695 .49369 m .63445 .50094 L .63868 .4833 L .881 .821 .345 r
F
.63891 .48309 m .63868 .4833 L .63954 .47968 L F
.63695 .49369 m .63868 .4833 L .63891 .48309 L F
.63698 .48442 m .63527 .48555 L .63673 .48504 L 0 0 0 r
F
.63445 .50094 m .63172 .50164 L .63698 .48442 L .99 .853 .61 r
F
.63753 .48432 m .63673 .48504 L .64006 .48388 L 0 0 0 r
F
.63698 .48442 m .63673 .48504 L .63753 .48432 L F
.63954 .47968 m .63698 .48442 L .63763 .48412 L .25 0 .062 r
F
.63954 .47968 m .63763 .48412 L .64272 .48174 L F
.64201 .47296 m .63954 .47968 L .6397 .47966 L .458 .093 .257 r
F
.64201 .47296 m .6397 .47966 L .64532 .47878 L F
.64444 .46581 m .64201 .47296 L .64776 .47207 L .468 .112 .278 r
F
.84203 .43089 m .8455 .42572 L .84792 .42908 L .664 .742 .908 r
F
.84203 .43089 m .8396 .42755 L .8455 .42572 L F
.24437 .43074 m .24612 .42558 L .24966 .42893 L F
.24437 .43074 m .24082 .4274 L .24612 .42558 L F
.41716 .43075 m .4194 .42558 L .42262 .42893 L .664 .741 .908 r
F
.41716 .43075 m .41393 .4274 L .4194 .42558 L F
.76273 .43076 m .76598 .42558 L .76854 .42894 L .664 .741 .907 r
F
.76273 .43076 m .76016 .4274 L .76598 .42558 L F
.93552 .43076 m .93926 .42558 L .94151 .42894 L .665 .742 .907 r
F
.93552 .43076 m .93327 .42742 L .93926 .42558 L F
.85623 .43061 m .85974 .42544 L .86213 .42879 L .664 .742 .908 r
F
.85623 .43061 m .85382 .42726 L .85974 .42544 L F
.33782 .43061 m .33984 .42544 L .3432 .42879 L .664 .741 .908 r
F
.33782 .43061 m .33445 .42726 L .33984 .42544 L F
.77692 .43046 m .78021 .4253 L .78275 .42865 L .663 .741 .908 r
F
.77692 .43046 m .77437 .42711 L .78021 .4253 L F
.25847 .43046 m .26026 .4253 L .26378 .42865 L .664 .741 .908 r
F
.25847 .43046 m .25495 .42712 L .26026 .4253 L F
.43129 .43046 m .43358 .42531 L .43677 .42867 L .663 .741 .908 r
F
.43129 .43046 m .42809 .42712 L .43358 .42531 L F
.53694 .496 m .53392 .49755 L .53939 .4534 L .981 .757 .527 r
F
.53392 .49755 m .5364 .45299 L .53939 .4534 L .972 .745 .537 r
F
.87043 .43033 m .87399 .42516 L .87635 .42852 L .663 .741 .908 r
F
.87043 .43033 m .86805 .42698 L .87399 .42516 L F
.35194 .43033 m .354 .42517 L .35734 .42852 L F
.35194 .43033 m .3486 .42698 L .354 .42517 L F
.56908 .52382 m .56607 .51469 L .57164 .51014 L .699 .576 .714 r
F
.27258 .43019 m .27441 .42502 L .2779 .42837 L .664 .741 .908 r
F
.27258 .43019 m .26909 .42684 L .27441 .42502 L F
.79111 .4302 m .79444 .42504 L .79696 .4284 L .663 .74 .907 r
F
.79111 .4302 m .78859 .42684 L .79444 .42504 L F
.44543 .43022 m .44775 .42523 L .45092 .42856 L .65 .736 .912 r
F
.44543 .43022 m .44226 .42685 L .44775 .42523 L F
.56607 .51469 m .56867 .50376 L .57164 .51014 L .498 .407 .683 r
F
.36607 .43005 m .36817 .42488 L .37148 .42824 L .664 .741 .908 r
F
.36607 .43005 m .36275 .4267 L .36817 .42488 L F
.88464 .43006 m .88823 .42488 L .89057 .42824 L F
.88464 .43006 m .88229 .42671 L .88823 .42488 L F
.80531 .42991 m .80868 .42475 L .81116 .4281 L .664 .742 .908 r
F
.80531 .42991 m .80281 .42657 L .80868 .42475 L F
.2867 .42991 m .28857 .42474 L .29203 .4281 L .664 .741 .908 r
F
.2867 .42991 m .28323 .42656 L .28857 .42474 L F
.57164 .51014 m .57428 .50111 L .57725 .50714 L .678 .617 .78 r
F
.57164 .51014 m .56867 .50376 L .57428 .50111 L F
.3802 .42977 m .38234 .4246 L .38563 .42795 L .664 .741 .908 r
F
.3802 .42977 m .37691 .42642 L .38234 .4246 L F
.89885 .42977 m .90249 .42461 L .9048 .42796 L .663 .741 .908 r
F
.89885 .42977 m .89652 .42642 L .90249 .42461 L F
.53267 .5521 m .53521 .53167 L .53824 .54255 L .992 .846 .486 r
F
.53267 .5521 m .52968 .55848 L .53521 .53167 L F
.30082 .42963 m .30273 .42446 L .30617 .42782 L .663 .741 .908 r
F
.30082 .42963 m .29738 .42628 L .30273 .42446 L F
.81951 .42963 m .82292 .42446 L .82538 .42782 L F
.81951 .42963 m .81703 .42628 L .82292 .42446 L F
.39433 .42949 m .39652 .42433 L .39978 .42768 L F
.39433 .42949 m .39107 .42614 L .39652 .42433 L F
.91306 .4295 m .91675 .42433 L .91903 .42768 L .664 .741 .908 r
F
.91306 .4295 m .91077 .42615 L .91675 .42433 L F
.74015 .4295 m .74334 .42433 L .74595 .42768 L .664 .742 .908 r
F
.74015 .4295 m .73753 .42615 L .74334 .42433 L F
.31494 .42936 m .3169 .42419 L .32031 .42754 L .663 .741 .908 r
F
.31494 .42936 m .31153 .42601 L .3169 .42419 L F
.83371 .42937 m .83716 .42418 L .8396 .42755 L .664 .741 .907 r
F
.83371 .42937 m .83127 .42601 L .83716 .42418 L F
.56223 .46627 m .55922 .45908 L .56469 .44429 L .856 .676 .658 r
F
.56468 .44433 m .56175 .44127 L .56469 .44429 L .855 .697 .685 r
F
.55922 .45908 m .56175 .44127 L .56468 .44433 L F
.55623 .45318 m .55879 .43813 L .56175 .44127 L .848 .711 .711 r
F
.56175 .44127 m .55879 .43813 L .55881 .43819 L .935 .558 .215 r
F
.55922 .45908 m .55623 .45318 L .56175 .44127 L .855 .697 .685 r
F
.56175 .44127 m .55881 .43819 L .5647 .4589 L .935 .558 .215 r
F
.56469 .44429 m .56175 .44127 L .56767 .462 L .935 .558 .219 r
F
.51128 .54432 m .50818 .5398 L .51409 .46634 L .95 .703 .53 r
F
.51409 .46634 m .51657 .48067 L .51963 .48087 L .922 .551 .13 r
F
.50818 .5398 m .51106 .46084 L .51409 .46634 L .951 .704 .529 r
F
.51409 .46634 m .51106 .46084 L .51657 .48067 L .922 .551 .13 r
F
.23554 .42921 m .23726 .42404 L .24082 .4274 L .663 .741 .908 r
F
.23554 .42921 m .23197 .42586 L .23726 .42404 L F
.72494 .46951 m .72268 .47298 L .72603 .43079 L .998 .775 .448 r
F
.72603 .43079 m .72911 .42461 L .73174 .42796 L .741 .785 .888 r
F
.72603 .43079 m .7234 .42773 L .72911 .42461 L F
.72268 .47298 m .7234 .42773 L .72603 .43079 L .996 .763 .444 r
F
.92728 .42922 m .93101 .42405 L .93327 .42742 L .664 .742 .908 r
F
.92728 .42922 m .92502 .42588 L .93101 .42405 L F
.40847 .42922 m .4107 .42405 L .41393 .4274 L .664 .741 .908 r
F
.40847 .42922 m .40523 .42587 L .4107 .42405 L F
.75435 .42924 m .75757 .42406 L .76016 .4274 L .665 .742 .908 r
F
.75435 .42924 m .75176 .42589 L .75757 .42406 L F
.32907 .42907 m .33107 .4239 L .33445 .42726 L .663 .741 .908 r
F
.32907 .42907 m .32568 .42572 L .33107 .4239 L F
.84792 .42908 m .85141 .4239 L .85382 .42726 L .664 .741 .908 r
F
.84792 .42908 m .8455 .42572 L .85141 .4239 L F
.24966 .42893 m .25142 .42376 L .25495 .42712 L F
.24966 .42893 m .24612 .42558 L .25142 .42376 L F
.42262 .42893 m .42488 .42376 L .42809 .42712 L .664 .742 .908 r
F
.42262 .42893 m .4194 .42558 L .42488 .42376 L F
.94151 .42894 m .94528 .42378 L .94751 .42714 L .662 .74 .908 r
F
.94151 .42894 m .93926 .42558 L .94528 .42378 L F
.76854 .42894 m .77181 .42376 L .77437 .42711 L .664 .741 .908 r
F
.76854 .42894 m .76598 .42558 L .77181 .42376 L F
.86213 .42879 m .86567 .42362 L .86805 .42698 L .663 .741 .908 r
F
.86213 .42879 m .85974 .42544 L .86567 .42362 L F
.3432 .42879 m .34524 .42362 L .3486 .42698 L F
.3432 .42879 m .33984 .42544 L .34524 .42362 L F
.26378 .42865 m .26558 .42348 L .26909 .42684 L F
.26378 .42865 m .26026 .4253 L .26558 .42348 L F
.78275 .42865 m .78605 .42348 L .78859 .42684 L F
.78275 .42865 m .78021 .4253 L .78605 .42348 L F
.43677 .42867 m .43907 .42349 L .44226 .42685 L .664 .741 .908 r
F
.43677 .42867 m .43358 .42531 L .43907 .42349 L F
.65017 .46503 m .65422 .48881 L .65652 .47937 L .823 .477 .401 r
F
.65017 .46503 m .64776 .47207 L .65422 .48881 L F
.35734 .42852 m .35942 .42335 L .36275 .4267 L .663 .741 .908 r
F
.35734 .42852 m .354 .42517 L .35942 .42335 L F
.87635 .42852 m .87993 .42334 L .88229 .42671 L .664 .741 .907 r
F
.87635 .42852 m .87399 .42516 L .87993 .42334 L F
.2779 .42837 m .27975 .4232 L .28323 .42656 L .664 .742 .908 r
F
.2779 .42837 m .27441 .42502 L .27975 .4232 L F
.79696 .4284 m .8003 .42321 L .80281 .42657 L .664 .74 .907 r
F
.79696 .4284 m .79444 .42504 L .8003 .42321 L F
.54042 .5245 m .53738 .51501 L .54289 .49055 L .872 .661 .614 r
F
.53738 .51501 m .53993 .49403 L .54289 .49055 L .774 .605 .669 r
F
.73604 .62717 m .73373 .63114 L .72961 .46584 L .982 .708 .423 r
F
.73373 .63114 m .72726 .46718 L .72961 .46584 L .982 .708 .421 r
F
.45092 .42856 m .45308 .43176 L .45623 .43565 L .622 .129 0 r
F
.45092 .42856 m .44775 .42523 L .45308 .43176 L F
.37148 .42824 m .3736 .42306 L .37691 .42642 L .664 .741 .908 r
F
.37148 .42824 m .36817 .42488 L .3736 .42306 L F
.89057 .42824 m .89419 .42306 L .89652 .42642 L F
.89057 .42824 m .88823 .42488 L .89419 .42306 L F
.56867 .50376 m .57127 .49278 L .57428 .50111 L .664 .571 .741 r
F
.56867 .50376 m .56566 .49553 L .57127 .49278 L F
.29203 .4281 m .29392 .42292 L .29738 .42628 L .664 .741 .908 r
F
.29203 .4281 m .28857 .42474 L .29392 .42292 L F
.81116 .4281 m .81456 .42292 L .81703 .42628 L .664 .742 .908 r
F
.81116 .4281 m .80868 .42475 L .81456 .42292 L F
.6588 .47032 m .66319 .49981 L .66582 .49935 L .825 .493 .427 r
F
.6588 .47032 m .65652 .47937 L .66319 .49981 L F
.38563 .42795 m .38779 .42278 L .39107 .42614 L .663 .741 .908 r
F
.38563 .42795 m .38234 .4246 L .38779 .42278 L F
.9048 .42796 m .90846 .42279 L .91077 .42615 L F
.9048 .42796 m .90249 .42461 L .90846 .42279 L F
.73174 .42796 m .7349 .42278 L .73753 .42615 L .664 .742 .908 r
F
.73174 .42796 m .72911 .42461 L .7349 .42278 L F
.46251 .44314 m .45938 .43932 L .46245 .5707 L .959 .675 .454 r
F
.30617 .42782 m .3081 .42264 L .31153 .42601 L .663 .741 .908 r
F
.30617 .42782 m .30273 .42446 L .3081 .42264 L F
.82538 .42782 m .82881 .42264 L .83127 .42601 L .664 .741 .908 r
F
.82538 .42782 m .82292 .42446 L .82881 .42264 L F
.75113 .64511 m .74734 .62465 L .74826 .5474 L .908 .647 .532 r
F
.74734 .62465 m .74663 .55913 L .74826 .5474 L .842 .602 .575 r
F
.91903 .42768 m .92274 .4225 L .92502 .42588 L .664 .742 .908 r
F
.91903 .42768 m .91675 .42433 L .92274 .4225 L F
.74595 .42768 m .74915 .42251 L .75176 .42589 L F
.74595 .42768 m .74334 .42433 L .74915 .42251 L F
.39978 .42768 m .40198 .42251 L .40523 .42587 L .663 .741 .908 r
F
.39978 .42768 m .39652 .42433 L .40198 .42251 L F
.56566 .49553 m .56824 .48273 L .57127 .49278 L .709 .595 .726 r
F
.56566 .49553 m .56266 .48729 L .56824 .48273 L F
.32031 .42754 m .32228 .42236 L .32568 .42572 L .664 .742 .908 r
F
.32031 .42754 m .3169 .42419 L .32228 .42236 L F
.8396 .42755 m .84307 .42236 L .8455 .42572 L .664 .741 .907 r
F
.8396 .42755 m .83716 .42418 L .84307 .42236 L F
.76016 .4274 m .7634 .42222 L .76598 .42558 L .665 .743 .908 r
F
.76016 .4274 m .75757 .42406 L .7634 .42222 L F
.24082 .4274 m .24256 .42221 L .24612 .42558 L .664 .741 .908 r
F
.24082 .4274 m .23726 .42404 L .24256 .42221 L F
.41393 .4274 m .41617 .42222 L .4194 .42558 L .663 .741 .908 r
F
.41393 .4274 m .4107 .42405 L .41617 .42222 L F
.93327 .42742 m .93701 .42222 L .93926 .42558 L .664 .74 .907 r
F
.93327 .42742 m .93101 .42405 L .93701 .42222 L F
.33445 .42726 m .33646 .42207 L .33984 .42544 L .664 .741 .908 r
F
.33445 .42726 m .33107 .4239 L .33646 .42207 L F
.85382 .42726 m .85734 .42207 L .85974 .42544 L F
.85382 .42726 m .85141 .4239 L .85734 .42207 L F
.50818 .5398 m .50507 .53549 L .51106 .46084 L .951 .704 .529 r
F
.51106 .46084 m .5135 .47967 L .51657 .48067 L .947 .588 .229 r
F
.50507 .53549 m .50801 .45614 L .51106 .46084 L .946 .699 .532 r
F
.51106 .46084 m .50801 .45614 L .51334 .47898 L .947 .588 .229 r
F
.51106 .46084 m .51334 .47898 L .51342 .47907 L F
.50801 .45614 m .51042 .47662 L .5135 .47967 L .946 .588 .276 r
F
.51069 .47607 m .513 .46286 L .51608 .46492 L .847 .724 .727 r
F
.51042 .47662 m .51055 .47592 L .51069 .47607 L F
.51055 .47592 m .513 .46286 L .51069 .47607 L F
.51342 .47907 m .51334 .47898 L .5135 .47967 L .947 .588 .229 r
F
.77437 .42711 m .77766 .42194 L .78021 .4253 L .663 .741 .908 r
F
.77437 .42711 m .77181 .42376 L .77766 .42194 L F
.25495 .42712 m .25674 .42193 L .26026 .4253 L .664 .741 .908 r
F
.25495 .42712 m .25142 .42376 L .25674 .42193 L F
.42809 .42712 m .43038 .42194 L .43358 .42531 L .663 .741 .908 r
F
.42809 .42712 m .42488 .42376 L .43038 .42194 L F
.86805 .42698 m .87161 .4218 L .87399 .42516 L F
.86805 .42698 m .86567 .42362 L .87161 .4218 L F
.3486 .42698 m .35065 .4218 L .354 .42517 L F
.3486 .42698 m .34524 .42362 L .35065 .4218 L F
.56266 .48729 m .56523 .47415 L .56824 .48273 L .686 .569 .718 r
F
.56266 .48729 m .55964 .47812 L .56523 .47415 L F
.26909 .42684 m .27091 .42166 L .27441 .42502 L .663 .741 .908 r
F
.26909 .42684 m .26558 .42348 L .27091 .42166 L F
.78859 .42684 m .79191 .42165 L .79444 .42504 L .664 .741 .908 r
F
.78859 .42684 m .78605 .42348 L .79191 .42165 L F
.44226 .42685 m .44457 .42189 L .44775 .42523 L .647 .736 .914 r
F
.44226 .42685 m .43907 .42349 L .44457 .42189 L F
.55964 .47812 m .56223 .46627 L .56523 .47415 L .683 .58 .733 r
F
.55964 .47812 m .55663 .46978 L .56223 .46627 L F
.36275 .4267 m .36484 .42152 L .36817 .42488 L .664 .742 .908 r
F
.36275 .4267 m .35942 .42335 L .36484 .42152 L F
.88229 .42671 m .88589 .42152 L .88823 .42488 L .663 .74 .907 r
F
.88229 .42671 m .87993 .42334 L .88589 .42152 L F
.28323 .42656 m .2851 .42137 L .28857 .42474 L .663 .741 .908 r
F
.28323 .42656 m .27975 .4232 L .2851 .42137 L F
.80281 .42657 m .80618 .42138 L .80868 .42475 L .664 .742 .908 r
F
.80281 .42657 m .8003 .42321 L .80618 .42138 L F
.52192 .65342 m .51885 .63891 L .52454 .57193 L .905 .661 .558 r
F
.51885 .63891 m .5215 .57891 L .52454 .57193 L .879 .645 .58 r
F
.89652 .42642 m .90017 .42124 L .90249 .42461 L .663 .741 .908 r
F
.89652 .42642 m .89419 .42306 L .90017 .42124 L F
.37691 .42642 m .37904 .42123 L .38234 .4246 L .664 .741 .908 r
F
.37691 .42642 m .3736 .42306 L .37904 .42123 L F
.29738 .42628 m .29928 .42109 L .30273 .42446 L .663 .741 .908 r
F
.29738 .42628 m .29392 .42292 L .29928 .42109 L F
.81703 .42628 m .82045 .4211 L .82292 .42446 L F
.81703 .42628 m .81456 .42292 L .82045 .4211 L F
.55663 .46978 m .55922 .45908 L .56223 .46627 L .726 .638 .761 r
F
.55663 .46978 m .55363 .46334 L .55922 .45908 L F
.39107 .42614 m .39324 .42096 L .39652 .42433 L .663 .741 .908 r
F
.39107 .42614 m .38779 .42278 L .39324 .42096 L F
.91077 .42615 m .91445 .42095 L .91675 .42433 L .664 .742 .908 r
F
.91077 .42615 m .90846 .42279 L .91445 .42095 L F
.73753 .42615 m .74072 .42097 L .74334 .42433 L .663 .741 .908 r
F
.73753 .42615 m .7349 .42278 L .74072 .42097 L F
.31153 .42601 m .31347 .42082 L .3169 .42419 L F
.31153 .42601 m .3081 .42264 L .31347 .42082 L F
.83127 .42601 m .83472 .42081 L .83716 .42418 L F
.83127 .42601 m .82881 .42264 L .83472 .42081 L F
.23197 .42586 m .23369 .42067 L .23726 .42404 L F
.23197 .42586 m .22839 .4225 L .23369 .42067 L F
.40523 .42587 m .40745 .42068 L .4107 .42405 L F
.40523 .42587 m .40198 .42251 L .40745 .42068 L F
.92502 .42588 m .92874 .42068 L .93101 .42405 L .663 .74 .907 r
F
.92502 .42588 m .92274 .4225 L .92874 .42068 L F
.75176 .42589 m .75498 .42069 L .75757 .42406 L F
.75176 .42589 m .74915 .42251 L .75498 .42069 L F
.69803 .43849 m .70358 .47908 L .70558 .46912 L .925 .585 .376 r
F
.69803 .43849 m .69569 .44207 L .70358 .47908 L F
.56175 .44127 m .5647 .4589 L .56767 .462 L .935 .558 .215 r
F
.32568 .42572 m .32767 .42053 L .33107 .4239 L .664 .741 .908 r
F
.32568 .42572 m .32228 .42236 L .32767 .42053 L F
.8455 .42572 m .849 .42053 L .85141 .4239 L F
.8455 .42572 m .84307 .42236 L .849 .42053 L F
.72268 .47298 m .7204 .47642 L .7234 .42773 L .996 .763 .444 r
F
.7234 .42773 m .72646 .42125 L .72911 .42461 L .758 .792 .881 r
F
.7234 .42773 m .72076 .42472 L .72646 .42125 L F
.7204 .47642 m .72076 .42472 L .7234 .42773 L .995 .756 .431 r
F
.24612 .42558 m .24787 .42039 L .25142 .42376 L .664 .741 .908 r
F
.24612 .42558 m .24256 .42221 L .24787 .42039 L F
.93926 .42558 m .94303 .42041 L .94528 .42378 L .663 .741 .908 r
F
.93926 .42558 m .93701 .42222 L .94303 .42041 L F
.76598 .42558 m .76924 .42038 L .77181 .42376 L .664 .741 .908 r
F
.76598 .42558 m .7634 .42222 L .76924 .42038 L F
.4194 .42558 m .42166 .42039 L .42488 .42376 L .664 .742 .908 r
F
.4194 .42558 m .41617 .42222 L .42166 .42039 L F
.85974 .42544 m .86328 .42025 L .86567 .42362 L .663 .741 .908 r
F
.85974 .42544 m .85734 .42207 L .86328 .42025 L F
.33984 .42544 m .34187 .42025 L .34524 .42362 L .664 .741 .908 r
F
.33984 .42544 m .33646 .42207 L .34187 .42025 L F
.52828 .48785 m .53089 .49746 L .53392 .49755 L .796 .444 0 r
F
.53392 .49755 m .53089 .49746 L .5364 .45299 L .972 .745 .537 r
F
.5364 .45299 m .5334 .45198 L .53881 .43881 L .954 .827 .68 r
F
.5364 .45299 m .53881 .43881 L .53888 .4389 L F
.53883 .43875 m .53596 .43532 L .53896 .43844 L .934 .785 .673 r
F
.5334 .45198 m .53596 .43532 L .53883 .43875 L F
.53038 .44967 m .53294 .4317 L .53596 .43532 L .924 .766 .667 r
F
.53596 .43532 m .53294 .4317 L .53307 .43188 L .668 .199 0 r
F
.5334 .45198 m .53038 .44967 L .53591 .43544 L .934 .785 .673 r
F
.53594 .43547 m .53591 .43544 L .53596 .43532 L F
.5334 .45198 m .53591 .43544 L .53594 .43547 L F
.53038 .44967 m .52735 .44671 L .53294 .4317 L .924 .766 .667 r
F
.52735 .44671 m .52992 .42813 L .53294 .4317 L .914 .752 .667 r
F
.53494 .43512 m .53254 .43333 L .53557 .436 L .732 .249 0 r
F
.52992 .42813 m .53254 .43333 L .53494 .43512 L F
.52735 .44671 m .5243 .44312 L .52992 .42813 L .914 .752 .667 r
F
.5243 .44312 m .52688 .42504 L .52992 .42813 L .89 .73 .678 r
F
.53234 .43304 m .52949 .43194 L .53254 .43333 L .813 .344 0 r
F
.52688 .42504 m .52949 .43194 L .53234 .43304 L F
.5243 .44312 m .52124 .43857 L .52688 .42504 L .89 .73 .678 r
F
.52124 .43857 m .52383 .4223 L .52688 .42504 L .855 .709 .7 r
F
.52383 .4223 m .52642 .43099 L .52949 .43194 L .86 .41 .034 r
F
.52949 .43194 m .52642 .43099 L .52662 .43084 L .818 .934 .907 r
F
.53294 .4317 m .52992 .42813 L .53557 .436 L .656 .183 0 r
F
.52992 .42813 m .52688 .42504 L .53254 .43333 L .732 .249 0 r
F
.52688 .42504 m .52383 .4223 L .52949 .43194 L .813 .344 0 r
F
.52949 .43194 m .52662 .43084 L .5321 .42657 L .818 .934 .907 r
F
.53254 .43333 m .52949 .43194 L .53012 .43153 L .785 .906 .925 r
F
.53294 .4317 m .5331 .43196 L .53327 .43216 L .656 .183 0 r
F
.5331 .43196 m .53557 .436 L .53327 .43216 L F
.53596 .43532 m .53307 .43188 L .5386 .43983 L .668 .199 0 r
F
.53254 .43333 m .53012 .43153 L .53515 .42818 L .785 .906 .925 r
F
.53557 .436 m .53254 .43333 L .5331 .43298 L .759 .811 .894 r
F
.53327 .43216 m .53557 .436 L .53803 .439 L .656 .183 0 r
F
.53557 .436 m .5331 .43298 L .53819 .42992 L .759 .811 .894 r
F
.53803 .439 m .53557 .436 L .5386 .43983 L .656 .183 0 r
F
.5365 .4361 m .5386 .43983 L .54162 .44355 L .668 .199 0 r
F
.53596 .43532 m .53624 .43581 L .5365 .4361 L F
.53624 .43581 m .5386 .43983 L .5365 .4361 L F
.53888 .4389 m .53881 .43881 L .53896 .43844 L .954 .827 .68 r
F
.53089 .49746 m .5334 .45198 L .5364 .45299 L .963 .734 .545 r
F
.53896 .43844 m .53596 .43532 L .54162 .44355 L .723 .241 0 r
F
.26026 .4253 m .26206 .42011 L .26558 .42348 L .663 .741 .908 r
F
.26026 .4253 m .25674 .42193 L .26206 .42011 L F
.78021 .4253 m .78351 .42012 L .78605 .42348 L F
.78021 .4253 m .77766 .42194 L .78351 .42012 L F
.43358 .42531 m .43588 .42013 L .43907 .42349 L .662 .741 .908 r
F
.43358 .42531 m .43038 .42194 L .43588 .42013 L F
.87399 .42516 m .87756 .41998 L .87993 .42334 L .663 .741 .908 r
F
.87399 .42516 m .87161 .4218 L .87756 .41998 L F
.354 .42517 m .35607 .41998 L .35942 .42335 L F
.354 .42517 m .35065 .4218 L .35607 .41998 L F
.27441 .42502 m .27626 .41982 L .27975 .4232 L .664 .742 .908 r
F
.27441 .42502 m .27091 .42166 L .27626 .41982 L F
.79444 .42504 m .79779 .41983 L .8003 .42321 L .664 .74 .907 r
F
.79444 .42504 m .79191 .42165 L .79779 .41983 L F
.44775 .42523 m .44457 .42189 L .44992 .42759 L .523 .03 0 r
F
.44457 .42189 m .44675 .42336 L .44992 .42759 L 0 .09 .601 r
F
.44992 .42759 m .44675 .42336 L .44675 .4234 L .96 .674 .447 r
F
.44775 .42523 m .44992 .42759 L .45308 .43176 L .523 .03 0 r
F
.44992 .42759 m .44675 .4234 L .44976 .53507 L .96 .674 .447 r
F
.45308 .43176 m .44992 .42759 L .45308 .43176 L .523 .03 0 r
F
.36817 .42488 m .37028 .41969 L .3736 .42306 L .664 .742 .908 r
F
.36817 .42488 m .36484 .42152 L .37028 .41969 L F
.88823 .42488 m .89185 .41969 L .89419 .42306 L .664 .741 .908 r
F
.88823 .42488 m .88589 .42152 L .89185 .41969 L F
.28857 .42474 m .29045 .41954 L .29392 .42292 L F
.28857 .42474 m .2851 .42137 L .29045 .41954 L F
.80868 .42475 m .81207 .41954 L .81456 .42292 L F
.80868 .42475 m .80618 .42138 L .81207 .41954 L F
.45938 .43932 m .45927 .56264 L .46245 .5707 L .959 .675 .453 r
F
.45938 .43932 m .45623 .43565 L .45927 .56264 L F
.38234 .4246 m .3845 .41941 L .38779 .42278 L .663 .741 .908 r
F
.38234 .4246 m .37904 .42123 L .3845 .41941 L F
.90249 .42461 m .90615 .41941 L .90846 .42279 L .664 .741 .908 r
F
.90249 .42461 m .90017 .42124 L .90615 .41941 L F
.72911 .42461 m .73227 .41941 L .7349 .42278 L .664 .742 .908 r
F
.72911 .42461 m .72646 .42125 L .73227 .41941 L F
.50507 .53549 m .50196 .52998 L .50801 .45614 L .946 .699 .532 r
F
.50196 .52998 m .50495 .45291 L .50801 .45614 L .95 .704 .53 r
F
.50801 .45614 m .50495 .45291 L .51042 .47662 L .946 .588 .276 r
F
.55363 .46334 m .55623 .45318 L .55922 .45908 L .726 .648 .771 r
F
.30273 .42446 m .30465 .41926 L .3081 .42264 L .664 .741 .908 r
F
.30273 .42446 m .29928 .42109 L .30465 .41926 L F
.82292 .42446 m .82635 .41928 L .82881 .42264 L .663 .742 .908 r
F
.82292 .42446 m .82045 .4211 L .82635 .41928 L F
.39652 .42433 m .39871 .41914 L .40198 .42251 L .663 .741 .908 r
F
.39652 .42433 m .39324 .42096 L .39871 .41914 L F
.91675 .42433 m .92045 .41913 L .92274 .4225 L .663 .74 .908 r
F
.91675 .42433 m .91445 .42095 L .92045 .41913 L F
.74334 .42433 m .74654 .41914 L .74915 .42251 L .664 .742 .908 r
F
.74334 .42433 m .74072 .42097 L .74654 .41914 L F
.83716 .42418 m .84064 .41899 L .84307 .42236 L .663 .741 .908 r
F
.83716 .42418 m .83472 .42081 L .84064 .41899 L F
.3169 .42419 m .31886 .41898 L .32228 .42236 L .664 .741 .908 r
F
.3169 .42419 m .31347 .42082 L .31886 .41898 L F
.69262 .44684 m .69048 .45507 L .69569 .44207 L 0 0 0 r
F
.23726 .42404 m .239 .41884 L .24256 .42221 L .664 .741 .908 r
F
.23726 .42404 m .23369 .42067 L .239 .41884 L F
.4107 .42405 m .41294 .41885 L .41617 .42222 L .664 .742 .908 r
F
.4107 .42405 m .40745 .42068 L .41294 .41885 L F
.93101 .42405 m .93475 .41884 L .93701 .42222 L F
.93101 .42405 m .92874 .42068 L .93475 .41884 L F
.75757 .42406 m .76081 .41885 L .7634 .42222 L F
.75757 .42406 m .75498 .42069 L .76081 .41885 L F
.85141 .4239 m .85493 .4187 L .85734 .42207 L .664 .741 .908 r
F
.85141 .4239 m .849 .42053 L .85493 .4187 L F
.33107 .4239 m .33307 .4187 L .33646 .42207 L .663 .741 .908 r
F
.33107 .4239 m .32767 .42053 L .33307 .4187 L F
.52268 .48062 m .52524 .48039 L .52828 .48785 L .064 .628 .709 r
F
.52268 .48062 m .51963 .48087 L .52524 .48039 L F
.77181 .42376 m .7751 .41856 L .77766 .42194 L .663 .741 .908 r
F
.77181 .42376 m .76924 .42038 L .7751 .41856 L F
.25142 .42376 m .2532 .41856 L .25674 .42193 L F
.25142 .42376 m .24787 .42039 L .2532 .41856 L F
.42488 .42376 m .42716 .41856 L .43038 .42194 L F
.42488 .42376 m .42166 .42039 L .42716 .41856 L F
.86567 .42362 m .86923 .41843 L .87161 .4218 L F
.86567 .42362 m .86328 .42025 L .86923 .41843 L F
.34524 .42362 m .34729 .41842 L .35065 .4218 L F
.34524 .42362 m .34187 .42025 L .34729 .41842 L F
.26558 .42348 m .2674 .41828 L .27091 .42166 L F
.26558 .42348 m .26206 .42011 L .2674 .41828 L F
.78605 .42348 m .78938 .4183 L .79191 .42165 L .663 .742 .909 r
F
.78605 .42348 m .78351 .42012 L .78938 .4183 L F
.43907 .42349 m .44139 .41849 L .44457 .42189 L .65 .738 .914 r
F
.43907 .42349 m .43588 .42013 L .44139 .41849 L F
.87993 .42334 m .88353 .41814 L .88589 .42152 L .664 .742 .908 r
F
.87993 .42334 m .87756 .41998 L .88353 .41814 L F
.35942 .42335 m .36151 .41815 L .36484 .42152 L F
.35942 .42335 m .35607 .41998 L .36151 .41815 L F
.61125 .49203 m .6083 .48694 L .61304 .44788 L .945 .713 .557 r
F
.61304 .44788 m .61031 .44971 L .61591 .44431 L .651 .934 .667 r
F
.27975 .4232 m .28161 .41799 L .2851 .42137 L .664 .741 .908 r
F
.27975 .4232 m .27626 .41982 L .28161 .41799 L F
.8003 .42321 m .80367 .41799 L .80618 .42138 L .664 .74 .907 r
F
.8003 .42321 m .79779 .41983 L .80367 .41799 L F
.3736 .42306 m .37573 .41785 L .37904 .42123 L .664 .742 .908 r
F
.3736 .42306 m .37028 .41969 L .37573 .41785 L F
.89419 .42306 m .89784 .41786 L .90017 .42124 L .663 .741 .908 r
F
.89419 .42306 m .89185 .41969 L .89784 .41786 L F
.29392 .42292 m .29582 .41771 L .29928 .42109 L F
.29392 .42292 m .29045 .41954 L .29582 .41771 L F
.81456 .42292 m .81797 .41772 L .82045 .4211 L F
.81456 .42292 m .81207 .41954 L .81797 .41772 L F
.38779 .42278 m .38996 .41758 L .39324 .42096 L F
.38779 .42278 m .3845 .41941 L .38996 .41758 L F
.7349 .42278 m .73808 .41758 L .74072 .42097 L F
.7349 .42278 m .73227 .41941 L .73808 .41758 L F
.90846 .42279 m .91215 .41757 L .91445 .42095 L .664 .741 .908 r
F
.90846 .42279 m .90615 .41941 L .91215 .41757 L F
.55063 .45726 m .55324 .44799 L .55623 .45318 L .707 .645 .785 r
F
.82881 .42264 m .83227 .41745 L .83472 .42081 L .663 .742 .909 r
F
.82881 .42264 m .82635 .41928 L .83227 .41745 L F
.3081 .42264 m .31004 .41743 L .31347 .42082 L .663 .741 .908 r
F
.3081 .42264 m .30465 .41926 L .31004 .41743 L F
.22839 .4225 m .2301 .41729 L .23369 .42067 L F
.22839 .4225 m .2248 .41912 L .2301 .41729 L F
.92274 .4225 m .92646 .4173 L .92874 .42068 L .664 .742 .908 r
F
.92274 .4225 m .92045 .41913 L .92646 .4173 L F
.74915 .42251 m .75237 .41729 L .75498 .42069 L F
.74915 .42251 m .74654 .41914 L .75237 .41729 L F
.40198 .42251 m .40419 .4173 L .40745 .42068 L F
.40198 .42251 m .39871 .41914 L .40419 .4173 L F
.73141 .63553 m .72494 .46951 L .72726 .46718 L .98 .705 .428 r
F
.32228 .42236 m .32426 .41715 L .32767 .42053 L .664 .742 .908 r
F
.32228 .42236 m .31886 .41898 L .32426 .41715 L F
.84307 .42236 m .84657 .41715 L .849 .42053 L F
.84307 .42236 m .84064 .41899 L .84657 .41715 L F
.55623 .45318 m .55324 .44799 L .55879 .43813 L .848 .711 .711 r
F
.56174 .45792 m .55878 .45835 L .55917 .45834 L .062 0 0 r
F
.5643 .45749 m .56174 .45792 L .5647 .4589 L .941 .573 .245 r
F
.5647 .4589 m .56174 .45792 L .56411 .46134 L .815 .331 .018 r
F
.5662 .46278 m .56411 .46134 L .56757 .46633 L F
.5647 .4589 m .56411 .46134 L .5662 .46278 L F
.56174 .45792 m .56451 .4582 L .56757 .46633 L .062 0 0 r
F
.56174 .45792 m .55917 .45834 L .56451 .4582 L F
.55879 .43813 m .56174 .45792 L .5643 .45749 L .941 .573 .245 r
F
.55324 .44799 m .55582 .43513 L .55879 .43813 L .85 .736 .738 r
F
.55879 .43813 m .55582 .43513 L .56174 .45792 L .941 .573 .245 r
F
.55582 .43513 m .55878 .45835 L .56174 .45792 L .946 .589 .281 r
F
.55974 .45833 m .56151 .45513 L .56451 .4582 L .462 .642 .935 r
F
.55878 .45835 m .55915 .45792 L .55974 .45833 L F
.55915 .45792 m .56151 .45513 L .55974 .45833 L F
.24256 .42221 m .24431 .417 L .24787 .42039 L .664 .741 .908 r
F
.24256 .42221 m .239 .41884 L .24431 .417 L F
.7634 .42222 m .76666 .417 L .76924 .42038 L .664 .742 .908 r
F
.7634 .42222 m .76081 .41885 L .76666 .417 L F
.93701 .42222 m .94078 .41702 L .94303 .42041 L .663 .741 .908 r
F
.93701 .42222 m .93475 .41884 L .94078 .41702 L F
.41617 .42222 m .41843 .417 L .42166 .42039 L .664 .742 .908 r
F
.41617 .42222 m .41294 .41885 L .41843 .417 L F
.7204 .47642 m .71815 .48071 L .72076 .42472 L .995 .756 .431 r
F
.72076 .42472 m .7238 .41788 L .72646 .42125 L .779 .803 .872 r
F
.72076 .42472 m .71812 .42179 L .7238 .41788 L F
.71815 .48071 m .71812 .42179 L .72076 .42472 L .994 .749 .427 r
F
.85734 .42207 m .86088 .41687 L .86328 .42025 L .663 .741 .908 r
F
.85734 .42207 m .85493 .4187 L .86088 .41687 L F
.33646 .42207 m .33849 .41686 L .34187 .42025 L .664 .741 .908 r
F
.33646 .42207 m .33307 .4187 L .33849 .41686 L F
.25674 .42193 m .25853 .41672 L .26206 .42011 L F
.25674 .42193 m .2532 .41856 L .25853 .41672 L F
.77766 .42194 m .78096 .41673 L .78351 .42012 L .663 .741 .908 r
F
.77766 .42194 m .7751 .41856 L .78096 .41673 L F
.43038 .42194 m .43267 .41675 L .43588 .42013 L .662 .741 .909 r
F
.43038 .42194 m .42716 .41856 L .43267 .41675 L F
.64201 .47296 m .64532 .47878 L .64776 .47207 L .458 .093 .257 r
F
.87161 .4218 m .87519 .41659 L .87756 .41998 L .663 .742 .908 r
F
.87161 .4218 m .86923 .41843 L .87519 .41659 L F
.35065 .4218 m .35272 .4166 L .35607 .41998 L .663 .741 .908 r
F
.35065 .4218 m .34729 .41842 L .35272 .4166 L F
.79191 .42165 m .79526 .41645 L .79779 .41983 L .664 .743 .909 r
F
.79191 .42165 m .78938 .4183 L .79526 .41645 L F
.27091 .42166 m .27275 .41644 L .27626 .41982 L .664 .742 .908 r
F
.27091 .42166 m .2674 .41828 L .27275 .41644 L F
.45308 .43176 m .45293 .54429 L .4561 .5534 L .96 .674 .449 r
F
.4561 .5534 m .45293 .54429 L .45294 .54427 L .843 .654 .647 r
F
.45861 .53515 m .4561 .5534 L .45926 .56252 L .959 .674 .451 r
F
.45623 .43565 m .45612 .53916 L .45861 .53515 L F
.45612 .53916 m .4561 .5534 L .45861 .53515 L F
.45623 .43565 m .45308 .43176 L .4561 .5534 L F
.45294 .54427 m .45551 .53357 L .45898 .52724 L .615 .534 .74 r
F
.45293 .54429 m .45293 .54428 L .45294 .54427 L F
.45293 .54428 m .45551 .53357 L .45294 .54427 L F
.4561 .5534 m .45294 .54427 L .45898 .52724 L .843 .654 .647 r
F
.45926 .56252 m .4561 .5534 L .45927 .56264 L .959 .674 .451 r
F
.44457 .42189 m .44139 .41849 L .44675 .42336 L 0 .09 .601 r
F
.88589 .42152 m .88951 .4163 L .89185 .41969 L .664 .742 .908 r
F
.88589 .42152 m .88353 .41814 L .88951 .4163 L F
.36484 .42152 m .36695 .4163 L .37028 .41969 L F
.36484 .42152 m .36151 .41815 L .36695 .4163 L F
.2851 .42137 m .28697 .41615 L .29045 .41954 L .664 .741 .908 r
F
.2851 .42137 m .28161 .41799 L .28697 .41615 L F
.80618 .42138 m .80957 .41615 L .81207 .41954 L F
.80618 .42138 m .80367 .41799 L .80957 .41615 L F
.53738 .51501 m .53434 .50456 L .53993 .49403 L .774 .605 .669 r
F
.53434 .50456 m .53694 .496 L .53993 .49403 L .565 .51 .752 r
F
.37904 .42123 m .38119 .41602 L .3845 .41941 L .663 .741 .908 r
F
.37904 .42123 m .37573 .41785 L .38119 .41602 L F
.90017 .42124 m .90383 .41602 L .90615 .41941 L .664 .741 .908 r
F
.90017 .42124 m .89784 .41786 L .90383 .41602 L F
.72646 .42125 m .72962 .41602 L .73227 .41941 L .664 .742 .908 r
F
.72646 .42125 m .7238 .41788 L .72962 .41602 L F
.50196 .52998 m .49883 .52548 L .50495 .45291 L .95 .704 .53 r
F
.50495 .45291 m .50734 .47192 L .51042 .47662 L .938 .572 .276 r
F
.49883 .52548 m .50187 .45049 L .50495 .45291 L .96 .715 .522 r
F
.50495 .45291 m .50187 .45049 L .50734 .47192 L .938 .572 .276 r
F
.65652 .47937 m .66041 .49713 L .66319 .49981 L .709 .372 .405 r
F
.66041 .49713 m .66141 .44426 L .66448 .45455 L .929 .687 .551 r
F
.66319 .49981 m .66448 .45455 L .66766 .46759 L .968 .732 .528 r
F
.66319 .49981 m .66041 .49713 L .66448 .45455 L F
.66582 .49935 m .66766 .46759 L .67088 .48112 L .989 .777 .528 r
F
.66582 .49935 m .66319 .49981 L .66766 .46759 L F
.66448 .45455 m .66141 .44426 L .66902 .48537 L .923 .603 .136 r
F
.65652 .47937 m .65422 .48881 L .66041 .49713 L .709 .372 .405 r
F
.66041 .49713 m .65738 .4885 L .66141 .44426 L .929 .687 .551 r
F
.66141 .44426 m .66659 .49076 L .66902 .48537 L .966 .642 .287 r
F
.65738 .4885 m .6585 .43785 L .66141 .44426 L .906 .667 .567 r
F
.66141 .44426 m .6585 .43785 L .66659 .49076 L .966 .642 .287 r
F
.29928 .42109 m .3012 .41587 L .30465 .41926 L .664 .741 .908 r
F
.29928 .42109 m .29582 .41771 L .3012 .41587 L F
.82045 .4211 m .82388 .41588 L .82635 .41928 L .663 .741 .908 r
F
.82045 .4211 m .81797 .41772 L .82388 .41588 L F
.91445 .42095 m .91816 .41575 L .92045 .41913 L F
.91445 .42095 m .91215 .41757 L .91816 .41575 L F
.39324 .42096 m .39543 .41575 L .39871 .41914 L F
.39324 .42096 m .38996 .41758 L .39543 .41575 L F
.74072 .42097 m .74392 .41576 L .74654 .41914 L .662 .74 .908 r
F
.74072 .42097 m .73808 .41758 L .74392 .41576 L F
.52828 .48785 m .52524 .48039 L .53089 .49746 L .796 .444 0 r
F
.52524 .48039 m .52784 .49592 L .53089 .49746 L .922 .56 .128 r
F
.53089 .49746 m .52784 .49592 L .5334 .45198 L .963 .734 .545 r
F
.52784 .49592 m .53038 .44967 L .5334 .45198 L .96 .731 .547 r
F
.83472 .42081 m .83819 .41559 L .84064 .41899 L .664 .743 .908 r
F
.83472 .42081 m .83227 .41745 L .83819 .41559 L F
.31347 .42082 m .31543 .4156 L .31886 .41898 L .664 .741 .908 r
F
.31347 .42082 m .31004 .41743 L .31543 .4156 L F
.54763 .45134 m .55025 .44366 L .55324 .44799 L .726 .705 .831 r
F
.66766 .46759 m .66448 .45455 L .67127 .47639 L 0 0 .372 r
F
.66448 .45455 m .66902 .48537 L .67127 .47639 L .923 .603 .136 r
F
.23369 .42067 m .23542 .41545 L .239 .41884 L .664 .741 .908 r
F
.23369 .42067 m .2301 .41729 L .23542 .41545 L F
.40745 .42068 m .40968 .41545 L .41294 .41885 L .664 .742 .908 r
F
.40745 .42068 m .40419 .4173 L .40968 .41545 L F
.92874 .42068 m .93248 .41545 L .93475 .41884 L .664 .741 .908 r
F
.92874 .42068 m .92646 .4173 L .93248 .41545 L F
.75498 .42069 m .75822 .41546 L .76081 .41885 L .663 .74 .907 r
F
.75498 .42069 m .75237 .41729 L .75822 .41546 L F
.32767 .42053 m .32967 .41531 L .33307 .4187 L .664 .741 .908 r
F
.32767 .42053 m .32426 .41715 L .32967 .41531 L F
.849 .42053 m .85251 .41531 L .85493 .4187 L .664 .742 .908 r
F
.849 .42053 m .84657 .41715 L .85251 .41531 L F
.76924 .42038 m .77253 .41517 L .7751 .41856 L .663 .741 .908 r
F
.76924 .42038 m .76666 .417 L .77253 .41517 L F
.24787 .42039 m .24964 .41517 L .2532 .41856 L F
.24787 .42039 m .24431 .417 L .24964 .41517 L F
.42166 .42039 m .42394 .41517 L .42716 .41856 L F
.42166 .42039 m .41843 .417 L .42394 .41517 L F
.34187 .42025 m .34391 .41503 L .34729 .41842 L F
.34187 .42025 m .33849 .41686 L .34391 .41503 L F
.86328 .42025 m .86684 .41503 L .86923 .41843 L .664 .742 .908 r
F
.86328 .42025 m .86088 .41687 L .86684 .41503 L F
.26206 .42011 m .26387 .41489 L .2674 .41828 L .663 .741 .908 r
F
.26206 .42011 m .25853 .41672 L .26387 .41489 L F
.78351 .42012 m .78684 .4149 L .78938 .4183 L F
.78351 .42012 m .78096 .41673 L .78684 .4149 L F
.43588 .42013 m .43819 .41504 L .44139 .41849 L .654 .739 .912 r
F
.43588 .42013 m .43267 .41675 L .43819 .41504 L F
.87756 .41998 m .88116 .41474 L .88353 .41814 L .664 .742 .908 r
F
.87756 .41998 m .87519 .41659 L .88116 .41474 L F
.35607 .41998 m .35816 .41475 L .36151 .41815 L F
.35607 .41998 m .35272 .4166 L .35816 .41475 L F
.27626 .41982 m .27811 .4146 L .28161 .41799 L .664 .741 .908 r
F
.27626 .41982 m .27275 .41644 L .27811 .4146 L F
.79779 .41983 m .80115 .4146 L .80367 .41799 L .664 .742 .908 r
F
.79779 .41983 m .79526 .41645 L .80115 .4146 L F
.55324 .44799 m .55025 .44366 L .55582 .43513 L .85 .736 .738 r
F
.89185 .41969 m .8955 .41446 L .89784 .41786 L .663 .741 .908 r
F
.89185 .41969 m .88951 .4163 L .8955 .41446 L F
.37028 .41969 m .37241 .41445 L .37573 .41785 L .664 .742 .908 r
F
.37028 .41969 m .36695 .4163 L .37241 .41445 L F
.29045 .41954 m .29235 .41432 L .29582 .41771 L .663 .741 .908 r
F
.29045 .41954 m .28697 .41615 L .29235 .41432 L F
.81207 .41954 m .81548 .41432 L .81797 .41772 L F
.81207 .41954 m .80957 .41615 L .81548 .41432 L F
.64776 .47207 m .65174 .49429 L .65422 .48881 L .817 .467 .393 r
F
.64776 .47207 m .64532 .47878 L .65174 .49429 L F
.65738 .4885 m .65425 .47742 L .6585 .43785 L .906 .667 .567 r
F
.6585 .43785 m .66402 .49361 L .66659 .49076 L .967 .646 .331 r
F
.65425 .47742 m .65567 .43343 L .6585 .43785 L .897 .665 .58 r
F
.6585 .43785 m .65567 .43343 L .66375 .4916 L .967 .646 .331 r
F
.65567 .43343 m .66131 .4933 L .66402 .49361 L .961 .641 .361 r
F
.65425 .47742 m .65115 .46676 L .65567 .43343 L .897 .665 .58 r
F
.65115 .46676 m .65294 .43172 L .65567 .43343 L .851 .636 .611 r
F
.65567 .43343 m .65294 .43172 L .66131 .4933 L .961 .641 .361 r
F
.65294 .43172 m .65846 .48998 L .66131 .4933 L .955 .632 .373 r
F
.65115 .46676 m .64799 .4548 L .65294 .43172 L .851 .636 .611 r
F
.64799 .4548 m .65027 .43181 L .65294 .43172 L .799 .619 .657 r
F
.65294 .43172 m .65027 .43181 L .65846 .48998 L .955 .632 .373 r
F
.65422 .48881 m .65738 .4885 L .66041 .49713 L 0 0 0 r
F
.65422 .48881 m .65174 .49429 L .65738 .4885 L F
.65174 .49429 m .65425 .47742 L .65738 .4885 L .955 .807 .658 r
F
.65027 .43181 m .65554 .48522 L .65846 .48998 L .953 .627 .368 r
F
.65566 .48261 m .65596 .41537 L .6587 .4169 L .958 .704 .509 r
F
.65554 .48522 m .65556 .48249 L .65566 .48261 L F
.65556 .48249 m .65596 .41537 L .65566 .48261 L F
.66384 .4917 m .66375 .4916 L .66402 .49361 L .967 .646 .331 r
F
.6585 .43785 m .66375 .4916 L .66384 .4917 L F
.3845 .41941 m .38666 .41419 L .38996 .41758 L .663 .741 .908 r
F
.3845 .41941 m .38119 .41602 L .38666 .41419 L F
.90615 .41941 m .90983 .41418 L .91215 .41757 L F
.90615 .41941 m .90383 .41602 L .90983 .41418 L F
.73227 .41941 m .73544 .41418 L .73808 .41758 L .664 .741 .908 r
F
.73227 .41941 m .72962 .41602 L .73544 .41418 L F
.30465 .41926 m .30659 .41404 L .31004 .41743 L .663 .741 .908 r
F
.30465 .41926 m .3012 .41587 L .30659 .41404 L F
.82635 .41928 m .8298 .41404 L .83227 .41745 L .664 .741 .907 r
F
.82635 .41928 m .82388 .41588 L .8298 .41404 L F
.2248 .41912 m .2265 .41389 L .2301 .41729 L .664 .741 .908 r
F
.2248 .41912 m .2212 .41573 L .2265 .41389 L F
.92045 .41913 m .92417 .41389 L .92646 .4173 L .664 .742 .908 r
F
.92045 .41913 m .91816 .41575 L .92417 .41389 L F
.74654 .41914 m .74976 .4139 L .75237 .41729 L .665 .743 .908 r
F
.74654 .41914 m .74392 .41576 L .74976 .4139 L F
.39871 .41914 m .40092 .4139 L .40419 .4173 L .664 .742 .908 r
F
.39871 .41914 m .39543 .41575 L .40092 .4139 L F
.31886 .41898 m .32084 .41375 L .32426 .41715 L F
.31886 .41898 m .31543 .4156 L .32084 .41375 L F
.84064 .41899 m .84413 .41375 L .84657 .41715 L .664 .741 .908 r
F
.84064 .41899 m .83819 .41559 L .84413 .41375 L F
.239 .41884 m .24074 .41361 L .24431 .417 L F
.239 .41884 m .23542 .41545 L .24074 .41361 L F
.93475 .41884 m .93852 .41362 L .94078 .41702 L .663 .741 .908 r
F
.93475 .41884 m .93248 .41545 L .93852 .41362 L F
.41294 .41885 m .41519 .41361 L .41843 .417 L .664 .741 .908 r
F
.41294 .41885 m .40968 .41545 L .41519 .41361 L F
.76081 .41885 m .76408 .4136 L .76666 .417 L F
.76081 .41885 m .75822 .41546 L .76408 .4136 L F
.55577 .4352 m .55285 .43234 L .55582 .43513 L .854 .763 .761 r
F
.55025 .44366 m .55285 .43234 L .55577 .4352 L F
.55278 .43243 m .54985 .42924 L .55285 .43234 L .839 .757 .772 r
F
.54725 .44003 m .54985 .42924 L .55278 .43243 L F
.54979 .42932 m .54685 .42579 L .54985 .42924 L .838 .762 .779 r
F
.54424 .43623 m .54685 .42579 L .54979 .42932 L F
.54677 .42588 m .54383 .42201 L .54685 .42579 L .881 .808 .772 r
F
.54122 .43256 m .54383 .42201 L .54677 .42588 L F
.54382 .42201 m .54079 .41783 L .54383 .42201 L .927 .831 .73 r
F
.53819 .42992 m .54079 .41783 L .54382 .42201 L F
.53515 .42818 m .53775 .41361 L .54079 .41783 L .944 .817 .69 r
F
.54079 .41783 m .53775 .41361 L .53775 .41362 L .939 .569 .202 r
F
.5386 .43983 m .54122 .43256 L .54424 .43623 L .743 .74 .849 r
F
.54424 .43623 m .54122 .43256 L .54685 .42579 L .838 .762 .779 r
F
.54122 .43256 m .53819 .42992 L .54383 .42201 L .881 .808 .772 r
F
.53819 .42992 m .53515 .42818 L .54079 .41783 L .927 .831 .73 r
F
.54079 .41783 m .53775 .41362 L .54358 .43612 L .939 .569 .202 r
F
.54383 .42201 m .54079 .41783 L .54087 .41813 L .943 .579 .221 r
F
.54463 .44692 m .54725 .44003 L .55025 .44366 L .754 .766 .862 r
F
.54162 .44355 m .54424 .43623 L .54725 .44003 L .75 .746 .848 r
F
.54725 .44003 m .54424 .43623 L .54985 .42924 L .839 .757 .772 r
F
.54383 .42201 m .54087 .41813 L .54664 .44176 L .943 .579 .221 r
F
.54685 .42579 m .54383 .42201 L .54389 .42225 L .94 .571 .218 r
F
.55025 .44366 m .54725 .44003 L .55285 .43234 L .854 .763 .761 r
F
.54685 .42579 m .54389 .42225 L .54968 .44461 L .94 .571 .218 r
F
.54985 .42924 m .54685 .42579 L .54691 .42604 L .941 .572 .231 r
F
.54985 .42924 m .54691 .42604 L .55272 .44855 L F
.55285 .43234 m .54985 .42924 L .54991 .42947 L .946 .587 .268 r
F
.55285 .43234 m .54991 .42947 L .55577 .45469 L F
.55582 .43513 m .55285 .43234 L .55878 .45835 L .946 .589 .281 r
F
.85493 .4187 m .85847 .41347 L .86088 .41687 L .663 .741 .908 r
F
.85493 .4187 m .85251 .41531 L .85847 .41347 L F
.33307 .4187 m .33509 .41346 L .33849 .41686 L .664 .741 .908 r
F
.33307 .4187 m .32967 .41531 L .33509 .41346 L F
.69569 .44207 m .70151 .48838 L .70358 .47908 L .912 .581 .403 r
F
.69569 .44207 m .69346 .4482 L .70151 .48838 L F
.51963 .48087 m .5222 .47422 L .52524 .48039 L .897 .947 .831 r
F
.51963 .48087 m .51657 .48067 L .5222 .47422 L F
.2532 .41856 m .25498 .41332 L .25853 .41672 L .664 .741 .908 r
F
.2532 .41856 m .24964 .41517 L .25498 .41332 L F
.7751 .41856 m .7784 .41333 L .78096 .41673 L .663 .741 .908 r
F
.7751 .41856 m .77253 .41517 L .7784 .41333 L F
.42716 .41856 m .42945 .41335 L .43267 .41675 L .662 .741 .909 r
F
.42716 .41856 m .42394 .41517 L .42945 .41335 L F
.71815 .48071 m .71589 .48535 L .71812 .42179 L .994 .749 .427 r
F
.71812 .42179 m .72113 .41448 L .7238 .41788 L .797 .806 .859 r
F
.71812 .42179 m .71547 .41885 L .72113 .41448 L F
.71589 .48535 m .71547 .41885 L .71812 .42179 L .993 .742 .423 r
F
.45308 .43176 m .44992 .42759 L .45293 .54429 L .96 .674 .449 r
F
.34729 .41842 m .34935 .41319 L .35272 .4166 L .663 .741 .908 r
F
.34729 .41842 m .34391 .41503 L .34935 .41319 L F
.86923 .41843 m .8728 .41318 L .87519 .41659 L .664 .741 .908 r
F
.86923 .41843 m .86684 .41503 L .8728 .41318 L F
.2674 .41828 m .26923 .41304 L .27275 .41644 L F
.2674 .41828 m .26387 .41489 L .26923 .41304 L F
.78938 .4183 m .79273 .41306 L .79526 .41645 L F
.78938 .4183 m .78684 .4149 L .79273 .41306 L F
.44139 .41849 m .44357 .4192 L .44675 .42336 L 0 .201 .704 r
F
.44139 .41849 m .43819 .41504 L .44357 .4192 L F
.88353 .41814 m .88715 .4129 L .88951 .4163 L .663 .741 .908 r
F
.88353 .41814 m .88116 .41474 L .88715 .4129 L F
.36151 .41815 m .36361 .4129 L .36695 .4163 L .664 .741 .908 r
F
.36151 .41815 m .35816 .41475 L .36361 .4129 L F
.66819 .49302 m .67088 .48112 L .67415 .49582 L .845 .819 .338 r
F
.28161 .41799 m .28348 .41275 L .28697 .41615 L .664 .741 .908 r
F
.28161 .41799 m .27811 .4146 L .28348 .41275 L F
.80367 .41799 m .80706 .41276 L .80957 .41615 L .664 .742 .908 r
F
.80367 .41799 m .80115 .4146 L .80706 .41276 L F
.37573 .41785 m .37787 .41262 L .38119 .41602 L .663 .741 .908 r
F
.37573 .41785 m .37241 .41445 L .37787 .41262 L F
.89784 .41786 m .9015 .41262 L .90383 .41602 L .664 .741 .908 r
F
.89784 .41786 m .8955 .41446 L .9015 .41262 L F
.7238 .41788 m .72696 .41262 L .72962 .41602 L .665 .742 .908 r
F
.7238 .41788 m .72113 .41448 L .72696 .41262 L F
.51885 .63891 m .51579 .62416 L .5215 .57891 L .879 .645 .58 r
F
.51579 .62416 m .51843 .58474 L .5215 .57891 L .832 .619 .614 r
F
.29582 .41771 m .29773 .41247 L .3012 .41587 L .664 .741 .908 r
F
.29582 .41771 m .29235 .41432 L .29773 .41247 L F
.81797 .41772 m .8214 .41247 L .82388 .41588 L F
.81797 .41772 m .81548 .41432 L .8214 .41247 L F
.91215 .41757 m .91585 .41233 L .91816 .41575 L .664 .742 .908 r
F
.91215 .41757 m .90983 .41418 L .91585 .41233 L F
.38996 .41758 m .39214 .41235 L .39543 .41575 L .663 .741 .908 r
F
.38996 .41758 m .38666 .41419 L .39214 .41235 L F
.73808 .41758 m .74128 .41235 L .74392 .41576 L F
.73808 .41758 m .73544 .41418 L .74128 .41235 L F
.31004 .41743 m .31199 .4122 L .31543 .4156 L F
.31004 .41743 m .30659 .41404 L .31199 .4122 L F
.83227 .41745 m .83574 .41219 L .83819 .41559 L .664 .741 .907 r
F
.83227 .41745 m .8298 .41404 L .83574 .41219 L F
.61031 .44971 m .61292 .43659 L .61591 .44431 L .915 .856 .412 r
F
.61894 .46238 m .6164 .45466 L .61949 .46472 L .924 .554 .139 r
F
.61292 .43659 m .6164 .45466 L .61894 .46238 L F
.61031 .44971 m .60766 .45574 L .61179 .44069 L .915 .856 .412 r
F
.61193 .44102 m .61179 .44069 L .61243 .43835 L F
.61031 .44971 m .61179 .44069 L .61193 .44102 L F
.61031 .44971 m .61243 .43835 L .61254 .43846 L F
.60766 .45574 m .61 .43165 L .61292 .43659 L .971 .782 .592 r
F
.61057 .43785 m .61031 .43743 L .61335 .44577 L .834 .409 0 r
F
.60766 .45574 m .60481 .45455 L .60927 .43485 L .971 .782 .592 r
F
.60766 .45574 m .60927 .43485 L .60935 .43502 L F
.60766 .45574 m .60941 .43422 L .60968 .43494 L F
.60996 .4318 m .6071 .42795 L .61 .43165 L .98 .783 .569 r
F
.60481 .45455 m .6071 .42795 L .60996 .4318 L F
.60197 .45413 m .60419 .42399 L .6071 .42795 L 1 .804 .484 r
F
.6071 .42795 m .60419 .42399 L .60423 .42408 L .834 .409 0 r
F
.60935 .43502 m .60927 .43485 L .60941 .43422 L .971 .782 .592 r
F
.60481 .45455 m .60197 .45413 L .60662 .43039 L .98 .783 .569 r
F
.60685 .43081 m .60662 .43039 L .6071 .42795 L F
.60481 .45455 m .60662 .43039 L .60685 .43081 L F
.60197 .45413 m .59922 .45865 L .60394 .42573 L 1 .804 .484 r
F
.60404 .42593 m .60394 .42573 L .60419 .42399 L F
.60197 .45413 m .60394 .42573 L .60404 .42593 L F
.59922 .45865 m .60129 .42114 L .60419 .42399 L .968 .746 .548 r
F
.60419 .42399 m .60129 .42114 L .60612 .42904 L .784 .313 0 r
F
.60692 .4301 m .60612 .42904 L .60732 .43101 L F
.60419 .42399 m .60612 .42904 L .60692 .4301 L F
.60227 .42274 m .60436 .42589 L .60732 .43101 L .683 .162 0 r
F
.60226 .42273 m .60227 .42273 L .60227 .42274 L F
.60227 .42273 m .60436 .42589 L .60227 .42274 L F
.60186 .42202 m .60436 .42589 L .60226 .42273 L F
.59922 .45865 m .5963 .4568 L .60113 .42227 L .968 .746 .548 r
F
.60122 .42238 m .60113 .42227 L .60129 .42114 L F
.59922 .45865 m .60113 .42227 L .60122 .42238 L F
.5984 .41906 m .59547 .41565 L .5957 .41587 L 0 .074 .597 r
F
.60129 .42114 m .60186 .42202 L .60226 .42273 L .683 .162 0 r
F
.5963 .4568 m .5984 .41906 L .59928 .41969 L .927 .704 .58 r
F
.60121 .42174 m .59928 .41969 L .60129 .42114 L F
.5963 .4568 m .59928 .41969 L .60121 .42174 L F
.6023 .4227 m .5984 .41906 L .60436 .42589 L .683 .162 0 r
F
.60129 .42114 m .59928 .41969 L .6023 .4227 L F
.59928 .41969 m .5984 .41906 L .6023 .4227 L F
.59565 .41583 m .59846 .41824 L .6014 .42136 L 0 .017 .573 r
F
.59547 .41565 m .59556 .41573 L .59565 .41583 L F
.59556 .41573 m .59846 .41824 L .59565 .41583 L F
.59841 .41907 m .5957 .41587 L .6014 .42136 L 0 .074 .597 r
F
.5984 .41906 m .5957 .41587 L .59841 .41907 L F
.59993 .42081 m .6014 .42136 L .60436 .42589 L F
.5984 .41906 m .5989 .41944 L .59993 .42081 L F
.5989 .41944 m .6014 .42136 L .59993 .42081 L F
.6071 .42795 m .60423 .42408 L .61031 .43743 L .834 .409 0 r
F
.60505 .42589 m .60732 .43101 L .61031 .43743 L .784 .313 0 r
F
.60419 .42399 m .6047 .42514 L .60505 .42589 L F
.6047 .42514 m .60732 .43101 L .60505 .42589 L F
.60968 .43494 m .60941 .43422 L .61 .43165 L .971 .782 .592 r
F
.60747 .42902 m .61002 .43655 L .61057 .43785 L .834 .409 0 r
F
.6071 .42795 m .60733 .42864 L .60747 .42902 L F
.60733 .42864 m .61002 .43655 L .60747 .42902 L F
.61002 .43655 m .61031 .43743 L .61057 .43785 L F
.61335 .44577 m .61031 .43743 L .61079 .43864 L 0 0 .309 r
F
.61165 .43758 m .61335 .44577 L .61591 .45289 L .905 .507 .1 r
F
.61133 .43727 m .61335 .44577 L .61165 .43758 L F
.61894 .45352 m .61591 .44431 L .62264 .47699 L .913 .585 .111 r
F
.61254 .43846 m .61243 .43835 L .61292 .43659 L .915 .856 .412 r
F
.61292 .43659 m .61 .43165 L .6164 .45466 L .924 .554 .139 r
F
.6164 .45466 m .61386 .44693 L .61521 .45003 L 0 0 .425 r
F
.61591 .44431 m .61921 .46315 L .62098 .46896 L .912 .568 .102 r
F
.61591 .44431 m .61292 .43659 L .61949 .46472 L F
.61686 .45544 m .61521 .45003 L .61958 .46003 L 0 0 .425 r
F
.6164 .45466 m .61521 .45003 L .61686 .45544 L F
.62098 .46896 m .61949 .46472 L .62264 .47699 L .912 .568 .102 r
F
.61921 .46315 m .61949 .46472 L .62098 .46896 L F
.61 .43165 m .6071 .42795 L .61335 .44577 L .905 .507 .1 r
F
.61881 .45827 m .61657 .45329 L .61958 .46003 L 0 0 .309 r
F
.61335 .44577 m .61657 .45329 L .61881 .45827 L F
.61591 .45289 m .61335 .44577 L .6164 .45466 L .905 .507 .1 r
F
.6164 .45466 m .61335 .44577 L .61386 .44693 L 0 0 .425 r
F
.61335 .44577 m .61079 .43864 L .61657 .45329 L 0 0 .309 r
F
.61633 .45267 m .61361 .44819 L .61657 .45329 L .798 .427 0 r
F
.61031 .43743 m .61361 .44819 L .61633 .45267 L F
.60732 .43101 m .61064 .44365 L .61361 .44819 L .87 .479 .007 r
F
.61361 .44819 m .61064 .44365 L .61088 .44369 L .43 .573 .896 r
F
.61031 .43743 m .60732 .43101 L .61361 .44819 L .798 .427 0 r
F
.61361 .44819 m .61088 .44369 L .61655 .4448 L .43 .573 .896 r
F
.61657 .45329 m .61361 .44819 L .61433 .4483 L .477 .569 .87 r
F
.61657 .45329 m .61433 .4483 L .6195 .44907 L F
.61 .43165 m .61133 .43727 L .61165 .43758 L .905 .507 .1 r
F
.61949 .46472 m .6164 .45466 L .61687 .45561 L 0 0 .551 r
F
.62203 .46472 m .61894 .45352 L .62501 .48351 L .874 .563 .048 r
F
.62203 .46472 m .62501 .48351 L .62531 .48454 L F
.61894 .45352 m .62264 .47699 L .62572 .48704 L .913 .585 .111 r
F
.62517 .4776 m .62203 .46472 L .62435 .4751 L .757 .479 0 r
F
.62524 .47794 m .62435 .4751 L .62874 .49468 L F
.62517 .4776 m .62435 .4751 L .62524 .47794 L F
.6164 .45466 m .61958 .46003 L .61981 .46057 L 0 0 .425 r
F
.62203 .46472 m .62572 .48704 L .62874 .49468 L .874 .563 .048 r
F
.62067 .46333 m .61981 .46057 L .6226 .46725 L 0 0 .425 r
F
.6164 .45466 m .61981 .46057 L .62067 .46333 L F
.61954 .46476 m .61687 .45561 L .6226 .46725 L 0 0 .551 r
F
.61949 .46472 m .61687 .45561 L .61954 .46476 L F
.62531 .48454 m .62501 .48351 L .62572 .48704 L .874 .563 .048 r
F
.49883 .52548 m .49567 .52373 L .50117 .45876 L .96 .715 .522 r
F
.50142 .45932 m .50117 .45876 L .50167 .45282 L F
.49883 .52548 m .50117 .45876 L .50142 .45932 L F
.49567 .52373 m .49878 .44812 L .50187 .45049 L .963 .718 .519 r
F
.49567 .52373 m .49248 .5228 L .4984 .45252 L F
.49858 .45291 m .4984 .45252 L .49878 .44812 L F
.49567 .52373 m .4984 .45252 L .49858 .45291 L F
.49248 .5228 m .49566 .44634 L .49878 .44812 L .958 .713 .523 r
F
.4957 .44646 m .49806 .45452 L .50115 .46165 L .822 .36 .121 r
F
.49568 .4464 m .49569 .44644 L .4957 .44646 L F
.49569 .44644 m .49806 .45452 L .4957 .44646 L F
.49566 .44634 m .49567 .44638 L .49568 .4464 L F
.49567 .44638 m .49806 .45452 L .49568 .4464 L F
.49883 .52548 m .50167 .45282 L .50177 .45298 L .96 .715 .522 r
F
.4988 .44822 m .50115 .46165 L .50424 .46699 L .912 .512 .214 r
F
.49878 .44812 m .49879 .44819 L .4988 .44822 L F
.49879 .44819 m .50115 .46165 L .4988 .44822 L F
.50177 .45298 m .50167 .45282 L .50187 .45049 L .96 .715 .522 r
F
.50187 .45049 m .50424 .46699 L .50734 .47192 L .93 .552 .247 r
F
.50187 .45049 m .49878 .44812 L .50424 .46699 L F
.2301 .41729 m .23182 .41204 L .23542 .41545 L .664 .741 .908 r
F
.2301 .41729 m .2265 .41389 L .23182 .41204 L F
.75237 .41729 m .75561 .41205 L .75822 .41546 L .664 .742 .908 r
F
.75237 .41729 m .74976 .4139 L .75561 .41205 L F
.92646 .4173 m .93021 .41205 L .93248 .41545 L .663 .741 .908 r
F
.92646 .4173 m .92417 .41389 L .93021 .41205 L F
.40419 .4173 m .40642 .41205 L .40968 .41545 L .664 .741 .907 r
F
.40419 .4173 m .40092 .4139 L .40642 .41205 L F
.32426 .41715 m .32625 .4119 L .32967 .41531 L .664 .742 .908 r
F
.32426 .41715 m .32084 .41375 L .32625 .4119 L F
.84657 .41715 m .85008 .4119 L .85251 .41531 L .663 .741 .908 r
F
.84657 .41715 m .84413 .41375 L .85008 .4119 L F
.76666 .417 m .76995 .41176 L .77253 .41517 L F
.76666 .417 m .76408 .4136 L .76995 .41176 L F
.24431 .417 m .24608 .41176 L .24964 .41517 L F
.24431 .417 m .24074 .41361 L .24608 .41176 L F
.41843 .417 m .4207 .41177 L .42394 .41517 L F
.41843 .417 m .41519 .41361 L .4207 .41177 L F
.52524 .48039 m .5222 .47422 L .52784 .49592 L .922 .56 .128 r
F
.5222 .47422 m .52477 .49391 L .52784 .49592 L .947 .593 .218 r
F
.52784 .49592 m .52477 .49391 L .53038 .44967 L .96 .731 .547 r
F
.52477 .49391 m .52735 .44671 L .53038 .44967 L .955 .725 .55 r
F
.33849 .41686 m .34052 .41162 L .34391 .41503 L .663 .741 .908 r
F
.33849 .41686 m .33509 .41346 L .34052 .41162 L F
.86088 .41687 m .86443 .41162 L .86684 .41503 L .664 .741 .908 r
F
.86088 .41687 m .85847 .41347 L .86443 .41162 L F
.25853 .41672 m .26033 .41148 L .26387 .41489 L .663 .741 .908 r
F
.25853 .41672 m .25498 .41332 L .26033 .41148 L F
.78096 .41673 m .78428 .41148 L .78684 .4149 L .664 .741 .908 r
F
.78096 .41673 m .7784 .41333 L .78428 .41148 L F
.43267 .41675 m .43498 .4116 L .43819 .41504 L .657 .739 .91 r
F
.43267 .41675 m .42945 .41335 L .43498 .4116 L F
.87519 .41659 m .87879 .41134 L .88116 .41474 L .663 .74 .907 r
F
.87519 .41659 m .8728 .41318 L .87879 .41134 L F
.35272 .4166 m .35479 .41134 L .35816 .41475 L .664 .741 .907 r
F
.35272 .4166 m .34935 .41319 L .35479 .41134 L F
.74734 .62465 m .74341 .60176 L .74663 .55913 L .842 .602 .575 r
F
.74341 .60176 m .74522 .57479 L .74663 .55913 L .548 .389 .618 r
F
.27275 .41644 m .27459 .41119 L .27811 .4146 L .664 .742 .908 r
F
.27275 .41644 m .26923 .41304 L .27459 .41119 L F
.79526 .41645 m .79863 .4112 L .80115 .4146 L F
.79526 .41645 m .79273 .41306 L .79863 .4112 L F
.7076 .46013 m .70558 .46912 L .7206 .62939 L .954 .651 .422 r
F
.88951 .4163 m .89315 .41106 L .8955 .41446 L .663 .741 .908 r
F
.88951 .4163 m .88715 .4129 L .89315 .41106 L F
.36695 .4163 m .36907 .41105 L .37241 .41445 L .664 .741 .908 r
F
.36695 .4163 m .36361 .4129 L .36907 .41105 L F
.28697 .41615 m .28886 .41091 L .29235 .41432 L .663 .741 .908 r
F
.28697 .41615 m .28348 .41275 L .28886 .41091 L F
.80957 .41615 m .81298 .41091 L .81548 .41432 L F
.80957 .41615 m .80706 .41276 L .81298 .41091 L F
.90383 .41602 m .90751 .41077 L .90983 .41418 L .664 .742 .908 r
F
.90383 .41602 m .9015 .41262 L .90751 .41077 L F
.38119 .41602 m .38335 .41078 L .38666 .41419 L .663 .741 .908 r
F
.38119 .41602 m .37787 .41262 L .38335 .41078 L F
.72962 .41602 m .73279 .41078 L .73544 .41418 L F
.72962 .41602 m .72696 .41262 L .73279 .41078 L F
.73141 .63553 m .72896 .6379 L .72494 .46951 L .98 .705 .428 r
F
.3012 .41587 m .30313 .41063 L .30659 .41404 L .663 .741 .908 r
F
.3012 .41587 m .29773 .41247 L .30313 .41063 L F
.82388 .41588 m .82733 .41062 L .8298 .41404 L .663 .741 .907 r
F
.82388 .41588 m .8214 .41247 L .82733 .41062 L F
.2212 .41573 m .22289 .41048 L .2265 .41389 L .664 .742 .908 r
F
.2212 .41573 m .21758 .41233 L .22289 .41048 L F
.91816 .41575 m .92188 .41049 L .92417 .41389 L .663 .74 .907 r
F
.91816 .41575 m .91585 .41233 L .92188 .41049 L F
.39543 .41575 m .39764 .41049 L .40092 .4139 L .665 .742 .907 r
F
.39543 .41575 m .39214 .41235 L .39764 .41049 L F
.74392 .41576 m .74713 .4105 L .74976 .4139 L .663 .74 .907 r
F
.74392 .41576 m .74128 .41235 L .74713 .4105 L F
.83819 .41559 m .84168 .41034 L .84413 .41375 L .664 .741 .908 r
F
.83819 .41559 m .83574 .41219 L .84168 .41034 L F
.31543 .4156 m .3174 .41034 L .32084 .41375 L F
.31543 .4156 m .31199 .4122 L .3174 .41034 L F
.44992 .42759 m .44976 .53507 L .45293 .54429 L .96 .674 .447 r
F
.23542 .41545 m .23715 .4102 L .24074 .41361 L .664 .741 .908 r
F
.23542 .41545 m .23182 .41204 L .23715 .4102 L F
.93248 .41545 m .93625 .41021 L .93852 .41362 L .663 .742 .908 r
F
.93248 .41545 m .93021 .41205 L .93625 .41021 L F
.40968 .41545 m .41193 .4102 L .41519 .41361 L .664 .741 .908 r
F
.40968 .41545 m .40642 .41205 L .41193 .4102 L F
.75822 .41546 m .76148 .4102 L .76408 .4136 L F
.75822 .41546 m .75561 .41205 L .76148 .4102 L F
.85251 .41531 m .85605 .41006 L .85847 .41347 L .663 .741 .908 r
F
.85251 .41531 m .85008 .4119 L .85605 .41006 L F
.32967 .41531 m .33168 .41006 L .33509 .41346 L F
.32967 .41531 m .32625 .4119 L .33168 .41006 L F
.24964 .41517 m .25142 .40991 L .25498 .41332 L .664 .741 .908 r
F
.24964 .41517 m .24608 .41176 L .25142 .40991 L F
.77253 .41517 m .77583 .40992 L .7784 .41333 L .663 .741 .908 r
F
.77253 .41517 m .76995 .41176 L .77583 .40992 L F
.42394 .41517 m .42622 .40993 L .42945 .41335 L F
.42394 .41517 m .4207 .41177 L .42622 .40993 L F
.55285 .43234 m .55577 .45469 L .55878 .45835 L .946 .587 .268 r
F
.34391 .41503 m .34596 .40977 L .34935 .41319 L .663 .741 .908 r
F
.34391 .41503 m .34052 .41162 L .34596 .40977 L F
.86684 .41503 m .87041 .40978 L .8728 .41318 L F
.86684 .41503 m .86443 .41162 L .87041 .40978 L F
.26387 .41489 m .26569 .40963 L .26923 .41304 L .664 .741 .908 r
F
.26387 .41489 m .26033 .41148 L .26569 .40963 L F
.71589 .48535 m .71363 .49026 L .71547 .41885 L .993 .742 .423 r
F
.71547 .41885 m .71846 .41107 L .72113 .41448 L .818 .814 .846 r
F
.71547 .41885 m .71282 .416 L .71846 .41107 L F
.71363 .49026 m .71282 .416 L .71547 .41885 L .991 .735 .428 r
F
.78684 .4149 m .79018 .40963 L .79273 .41306 L .664 .74 .907 r
F
.78684 .4149 m .78428 .41148 L .79018 .40963 L F
.43498 .4116 m .43718 .41091 L .44038 .41507 L .029 .411 .86 r
F
.44038 .41507 m .43718 .41091 L .43718 .41092 L .961 .67 .438 r
F
.43819 .41504 m .44038 .41507 L .44357 .4192 L 0 .306 .788 r
F
.43819 .41504 m .43498 .4116 L .44038 .41507 L F
.44038 .41507 m .43718 .41092 L .44039 .50171 L .961 .67 .438 r
F
.44357 .4192 m .44038 .41507 L .44357 .4192 L 0 .306 .788 r
F
.88116 .41474 m .88478 .40949 L .88715 .4129 L .663 .741 .908 r
F
.88116 .41474 m .87879 .41134 L .88478 .40949 L F
.35816 .41475 m .36025 .40949 L .36361 .4129 L .664 .741 .907 r
F
.35816 .41475 m .35479 .41134 L .36025 .40949 L F
.27811 .4146 m .27997 .40934 L .28348 .41275 L .664 .741 .908 r
F
.27811 .4146 m .27459 .41119 L .27997 .40934 L F
.80115 .4146 m .80454 .40934 L .80706 .41276 L .664 .742 .908 r
F
.80115 .4146 m .79863 .4112 L .80454 .40934 L F
.54162 .44355 m .5386 .43983 L .54424 .43623 L .75 .746 .848 r
F
.37241 .41445 m .37454 .4092 L .37787 .41262 L .663 .741 .908 r
F
.37241 .41445 m .36907 .41105 L .37454 .4092 L F
.8955 .41446 m .89916 .4092 L .9015 .41262 L .664 .742 .908 r
F
.8955 .41446 m .89315 .41106 L .89916 .4092 L F
.72113 .41448 m .72429 .40921 L .72696 .41262 L .664 .741 .907 r
F
.72113 .41448 m .71846 .41107 L .72429 .40921 L F
.69048 .45507 m .68838 .46438 L .69346 .4482 L 0 0 0 r
F
.81548 .41432 m .81891 .40907 L .8214 .41247 L .663 .741 .908 r
F
.81548 .41432 m .81298 .41091 L .81891 .40907 L F
.29235 .41432 m .29425 .40906 L .29773 .41247 L F
.29235 .41432 m .28886 .41091 L .29425 .40906 L F
.51657 .48067 m .51914 .4689 L .5222 .47422 L .941 .85 .725 r
F
.5222 .47422 m .51914 .4689 L .52477 .49391 L .947 .593 .218 r
F
.90983 .41418 m .91354 .40892 L .91585 .41233 L .663 .741 .908 r
F
.90983 .41418 m .90751 .41077 L .91354 .40892 L F
.73544 .41418 m .73864 .40893 L .74128 .41235 L .664 .742 .908 r
F
.73544 .41418 m .73279 .41078 L .73864 .40893 L F
.38666 .41419 m .38884 .40893 L .39214 .41235 L .664 .741 .908 r
F
.38666 .41419 m .38335 .41078 L .38884 .40893 L F
.30659 .41404 m .30854 .40878 L .31199 .4122 L .663 .741 .908 r
F
.30659 .41404 m .30313 .41063 L .30854 .40878 L F
.8298 .41404 m .83327 .40878 L .83574 .41219 L F
.8298 .41404 m .82733 .41062 L .83327 .40878 L F
.2265 .41389 m .22822 .40863 L .23182 .41204 L .664 .741 .908 r
F
.2265 .41389 m .22289 .41048 L .22822 .40863 L F
.92417 .41389 m .92792 .40864 L .93021 .41205 L .664 .742 .908 r
F
.92417 .41389 m .92188 .41049 L .92792 .40864 L F
.74976 .4139 m .753 .40864 L .75561 .41205 L F
.74976 .4139 m .74713 .4105 L .753 .40864 L F
.40092 .4139 m .40314 .40863 L .40642 .41205 L .664 .741 .907 r
F
.40092 .4139 m .39764 .41049 L .40314 .40863 L F
.84413 .41375 m .84765 .40849 L .85008 .4119 L .663 .741 .908 r
F
.84413 .41375 m .84168 .41034 L .84765 .40849 L F
.32084 .41375 m .32283 .40849 L .32625 .4119 L .664 .741 .908 r
F
.32084 .41375 m .3174 .41034 L .32283 .40849 L F
.76408 .4136 m .76736 .40835 L .76995 .41176 L .663 .741 .908 r
F
.76408 .4136 m .76148 .4102 L .76736 .40835 L F
.24074 .41361 m .2425 .40834 L .24608 .41176 L F
.24074 .41361 m .23715 .4102 L .2425 .40834 L F
.41519 .41361 m .41745 .40835 L .4207 .41177 L F
.41519 .41361 m .41193 .4102 L .41745 .40835 L F
.51657 .48067 m .5135 .47967 L .51914 .4689 L .941 .85 .725 r
F
.33509 .41346 m .33712 .4082 L .34052 .41162 L .664 .741 .908 r
F
.33509 .41346 m .33168 .41006 L .33712 .4082 L F
.85847 .41347 m .86202 .40821 L .86443 .41162 L .663 .741 .908 r
F
.85847 .41347 m .85605 .41006 L .86202 .40821 L F
.49878 .44812 m .49566 .44634 L .50115 .46165 L .912 .512 .214 r
F
.25498 .41332 m .25678 .40806 L .26033 .41148 L .663 .741 .908 r
F
.25498 .41332 m .25142 .40991 L .25678 .40806 L F
.7784 .41333 m .78172 .40807 L .78428 .41148 L F
.7784 .41333 m .77583 .40992 L .78172 .40807 L F
.42945 .41335 m .43176 .40817 L .43498 .4116 L .657 .739 .91 r
F
.42945 .41335 m .42622 .40993 L .43176 .40817 L F
.51914 .4689 m .52169 .49106 L .52477 .49391 L .951 .599 .271 r
F
.52477 .49391 m .52169 .49106 L .52735 .44671 L .955 .725 .55 r
F
.52169 .49106 m .5243 .44312 L .52735 .44671 L .949 .718 .554 r
F
.8728 .41318 m .8764 .40793 L .87879 .41134 L .664 .742 .908 r
F
.8728 .41318 m .87041 .40978 L .8764 .40793 L F
.34935 .41319 m .35142 .40792 L .35479 .41134 L .664 .741 .907 r
F
.34935 .41319 m .34596 .40977 L .35142 .40792 L F
.26923 .41304 m .27107 .40777 L .27459 .41119 L .664 .741 .908 r
F
.26923 .41304 m .26569 .40963 L .27107 .40777 L F
.79273 .41306 m .79609 .40778 L .79863 .4112 L .664 .74 .907 r
F
.79273 .41306 m .79018 .40963 L .79609 .40778 L F
.63954 .47968 m .64272 .48174 L .64532 .47878 L .25 0 .062 r
F
.88715 .4129 m .89079 .40764 L .89315 .41106 L .663 .741 .908 r
F
.88715 .4129 m .88478 .40949 L .89079 .40764 L F
.36361 .4129 m .36572 .40763 L .36907 .41105 L .664 .741 .908 r
F
.36361 .4129 m .36025 .40949 L .36572 .40763 L F
.66902 .48537 m .67024 .43949 L .67341 .45177 L .997 .769 .441 r
F
.67127 .47639 m .66902 .48537 L .67314 .45384 L .944 .795 .339 r
F
.67325 .45365 m .67314 .45384 L .67341 .45177 L F
.67127 .47639 m .67314 .45384 L .67325 .45365 L F
.66902 .48537 m .66659 .49076 L .67021 .43996 L .997 .769 .441 r
F
.67023 .43997 m .67021 .43996 L .67024 .43949 L F
.66902 .48537 m .67021 .43996 L .67023 .43997 L F
.66659 .49076 m .6672 .43019 L .67024 .43949 L .99 .744 .461 r
F
.66659 .49076 m .66402 .49361 L .66694 .43548 L F
.66659 .49076 m .66694 .43548 L .66699 .43554 L F
.66659 .49076 m .667 .43433 L .66716 .43459 L F
.66402 .49361 m .66428 .4236 L .6672 .43019 L .979 .726 .478 r
F
.66402 .49361 m .66131 .4933 L .66398 .43072 L F
.66425 .43117 m .66398 .43072 L .66428 .4236 L F
.66402 .49361 m .66398 .43072 L .66425 .43117 L F
.66131 .4933 m .66146 .41932 L .66428 .4236 L .969 .713 .492 r
F
.66131 .4933 m .65846 .48998 L .66146 .41932 L F
.65846 .48998 m .6587 .4169 L .66146 .41932 L .964 .708 .5 r
F
.65846 .48998 m .65554 .48522 L .6587 .4169 L F
.65641 .41821 m .661 .45963 L .66401 .4666 L .956 .621 .334 r
F
.65596 .41537 m .65626 .41796 L .65641 .41821 L F
.65626 .41796 m .661 .45963 L .65641 .41821 L F
.66015 .4269 m .66401 .4666 L .66705 .47454 L .958 .629 .343 r
F
.6587 .4169 m .65971 .42634 L .66015 .4269 L F
.65971 .42634 m .66401 .4666 L .66015 .4269 L F
.66699 .43554 m .66694 .43548 L .667 .43433 L .99 .744 .461 r
F
.66716 .43459 m .667 .43433 L .6672 .43019 L F
.66254 .42742 m .66621 .46619 L .66744 .46399 L .963 .638 .343 r
F
.66146 .41932 m .66223 .42693 L .66254 .42742 L F
.66223 .42693 m .66621 .46619 L .66254 .42742 L F
.66622 .4386 m .67018 .48438 L .67325 .49306 L .968 .648 .335 r
F
.66428 .4236 m .66572 .43843 L .66622 .4386 L F
.66572 .43843 m .67018 .48438 L .66622 .4386 L F
.66744 .46399 m .66705 .47454 L .67018 .48438 L .963 .638 .343 r
F
.66621 .46619 m .66705 .47454 L .66744 .46399 L F
.67341 .45177 m .67024 .43949 L .67795 .49637 L .959 .649 .233 r
F
.67341 .45177 m .67795 .49637 L .67816 .49604 L F
.67024 .43949 m .6762 .49919 L .67915 .50524 L .97 .655 .285 r
F
.6767 .4666 m .67341 .45177 L .6809 .50152 L .919 .62 .138 r
F
.68106 .50145 m .6809 .50152 L .68196 .50859 L F
.6767 .4666 m .6809 .50152 L .68106 .50145 L F
.67341 .45177 m .67915 .50524 L .68196 .50859 L .959 .649 .233 r
F
.67988 .50196 m .68174 .48951 L .68408 .48318 L .835 .695 .709 r
F
.67915 .50524 m .67967 .50205 L .67988 .50196 L F
.67967 .50205 m .68174 .48951 L .67988 .50196 L F
.67667 .49836 m .67928 .49359 L .68174 .48951 L .528 .555 .827 r
F
.6762 .49919 m .67654 .49858 L .67667 .49836 L F
.67654 .49858 m .67928 .49359 L .67667 .49836 L F
.67816 .49604 m .67795 .49637 L .67915 .50524 L .959 .649 .233 r
F
.67024 .43949 m .6672 .43019 L .6762 .49919 L .97 .655 .285 r
F
.28348 .41275 m .28536 .40749 L .28886 .41091 L .663 .741 .908 r
F
.28348 .41275 m .27997 .40934 L .28536 .40749 L F
.6672 .43019 m .67325 .49306 L .6762 .49919 L .971 .654 .317 r
F
.6672 .43019 m .66428 .4236 L .67325 .49306 L F
.80706 .41276 m .81047 .40749 L .81298 .41091 L .663 .741 .908 r
F
.80706 .41276 m .80454 .40934 L .81047 .40749 L F
.37787 .41262 m .38003 .40735 L .38335 .41078 L F
.37787 .41262 m .37454 .4092 L .38003 .40735 L F
.9015 .41262 m .90518 .40735 L .90751 .41077 L .664 .741 .908 r
F
.9015 .41262 m .89916 .4092 L .90518 .40735 L F
.72696 .41262 m .73013 .40736 L .73279 .41078 L .663 .741 .908 r
F
.72696 .41262 m .72429 .40921 L .73013 .40736 L F
.44675 .42336 m .44661 .52494 L .44976 .53507 L .96 .673 .445 r
F
.44675 .42336 m .44357 .4192 L .44661 .52494 L F
.8214 .41247 m .82485 .40722 L .82733 .41062 L .663 .742 .909 r
F
.8214 .41247 m .81891 .40907 L .82485 .40722 L F
.29773 .41247 m .29965 .40721 L .30313 .41063 L .664 .741 .908 r
F
.29773 .41247 m .29425 .40906 L .29965 .40721 L F
.21758 .41233 m .21926 .40706 L .22289 .41048 L .664 .742 .908 r
F
.21758 .41233 m .21394 .40892 L .21926 .40706 L F
.91585 .41233 m .91958 .40707 L .92188 .41049 L F
.91585 .41233 m .91354 .40892 L .91958 .40707 L F
.74128 .41235 m .7445 .40707 L .74713 .4105 L .664 .741 .908 r
F
.74128 .41235 m .73864 .40893 L .7445 .40707 L F
.39214 .41235 m .39434 .40706 L .39764 .41049 L .664 .741 .907 r
F
.39214 .41235 m .38884 .40893 L .39434 .40706 L F
.83574 .41219 m .83923 .40692 L .84168 .41034 L .664 .742 .908 r
F
.83574 .41219 m .83327 .40878 L .83923 .40692 L F
.31199 .4122 m .31395 .40692 L .3174 .41034 L .664 .741 .908 r
F
.31199 .4122 m .30854 .40878 L .31395 .40692 L F
.23182 .41204 m .23355 .40677 L .23715 .4102 L F
.23182 .41204 m .22822 .40863 L .23355 .40677 L F
.40642 .41205 m .40866 .40677 L .41193 .4102 L F
.40642 .41205 m .40314 .40863 L .40866 .40677 L F
.75561 .41205 m .75887 .40677 L .76148 .4102 L .664 .742 .908 r
F
.75561 .41205 m .753 .40864 L .75887 .40677 L F
.93021 .41205 m .93398 .40678 L .93625 .41021 L .663 .741 .908 r
F
.93021 .41205 m .92792 .40864 L .93398 .40678 L F
.5135 .47967 m .51608 .46492 L .51914 .4689 L .905 .773 .705 r
F
.51914 .4689 m .51608 .46492 L .52169 .49106 L .951 .599 .271 r
F
.85008 .4119 m .85362 .40664 L .85605 .41006 L .663 .741 .908 r
F
.85008 .4119 m .84765 .40849 L .85362 .40664 L F
.32625 .4119 m .32826 .40663 L .33168 .41006 L F
.32625 .4119 m .32283 .40849 L .32826 .40663 L F
.24608 .41176 m .24785 .40649 L .25142 .40991 L F
.24608 .41176 m .2425 .40834 L .24785 .40649 L F
.76995 .41176 m .77325 .4065 L .77583 .40992 L F
.76995 .41176 m .76736 .40835 L .77325 .4065 L F
.4207 .41177 m .42298 .4065 L .42622 .40993 L F
.4207 .41177 m .41745 .40835 L .42298 .4065 L F
.86443 .41162 m .86801 .40636 L .87041 .40978 L .663 .742 .908 r
F
.86443 .41162 m .86202 .40821 L .86801 .40636 L F
.34052 .41162 m .34257 .40635 L .34596 .40977 L .664 .741 .908 r
F
.34052 .41162 m .33712 .4082 L .34257 .40635 L F
.55272 .44855 m .54968 .44461 L .5504 .44557 L .586 .13 0 r
F
.55503 .45152 m .55272 .44855 L .55577 .45469 L .941 .572 .231 r
F
.54985 .42924 m .55272 .44855 L .55503 .45152 L F
.55878 .45835 m .55577 .45469 L .55825 .45488 L .462 .642 .935 r
F
.56005 .45685 m .55825 .45488 L .56151 .45513 L F
.55878 .45835 m .55825 .45488 L .56005 .45685 L F
.55577 .45469 m .55853 .45569 L .56151 .45513 L 0 .107 .661 r
F
.55577 .45469 m .55272 .44855 L .55853 .45569 L F
.55485 .45117 m .5555 .45243 L .55853 .45569 L .586 .13 0 r
F
.55272 .44855 m .55368 .44989 L .55485 .45117 L F
.55368 .44989 m .5555 .45243 L .55485 .45117 L F
.55272 .44855 m .5504 .44557 L .5555 .45243 L F
.78428 .41148 m .78763 .40621 L .79018 .40963 L .664 .742 .908 r
F
.78428 .41148 m .78172 .40807 L .78763 .40621 L F
.26033 .41148 m .26215 .40621 L .26569 .40963 L .663 .741 .908 r
F
.26033 .41148 m .25678 .40806 L .26215 .40621 L F
.43498 .4116 m .43176 .40817 L .43718 .41091 L .029 .411 .86 r
F
.5386 .43983 m .53557 .436 L .54122 .43256 L .743 .74 .849 r
F
.87879 .41134 m .88241 .40606 L .88478 .40949 L .664 .742 .908 r
F
.87879 .41134 m .8764 .40793 L .88241 .40606 L F
.35479 .41134 m .35688 .40606 L .36025 .40949 L .664 .741 .908 r
F
.35479 .41134 m .35142 .40792 L .35688 .40606 L F
.27459 .41119 m .27645 .40591 L .27997 .40934 L F
.27459 .41119 m .27107 .40777 L .27645 .40591 L F
.79863 .4112 m .80201 .40592 L .80454 .40934 L F
.79863 .4112 m .79609 .40778 L .80201 .40592 L F
.71363 .49026 m .71131 .49452 L .71282 .416 L .991 .735 .428 r
F
.71282 .416 m .71577 .40767 L .71846 .41107 L .832 .813 .831 r
F
.71282 .416 m .71015 .41311 L .71577 .40767 L F
.71131 .49452 m .71015 .41311 L .71282 .416 L .99 .731 .426 r
F
.66428 .4236 m .66146 .41932 L .67018 .48438 L .968 .648 .335 r
F
.36907 .41105 m .3712 .40577 L .37454 .4092 L .663 .741 .908 r
F
.36907 .41105 m .36572 .40763 L .3712 .40577 L F
.89315 .41106 m .89681 .40577 L .89916 .4092 L .664 .741 .908 r
F
.89315 .41106 m .89079 .40764 L .89681 .40577 L F
.71846 .41107 m .72161 .40578 L .72429 .40921 L .666 .743 .908 r
F
.71846 .41107 m .71577 .40767 L .72161 .40578 L F
.28886 .41091 m .29076 .40564 L .29425 .40906 L .663 .741 .908 r
F
.28886 .41091 m .28536 .40749 L .29076 .40564 L F
.81298 .41091 m .8164 .40564 L .81891 .40907 L F
.81298 .41091 m .81047 .40749 L .8164 .40564 L F
.90751 .41077 m .91122 .40551 L .91354 .40892 L F
.90751 .41077 m .90518 .40735 L .91122 .40551 L F
.38335 .41078 m .38553 .40549 L .38884 .40893 L .664 .741 .908 r
F
.38335 .41078 m .38003 .40735 L .38553 .40549 L F
.73279 .41078 m .73599 .40551 L .73864 .40893 L .663 .741 .908 r
F
.73279 .41078 m .73013 .40736 L .73599 .40551 L F
.64532 .47878 m .64896 .49246 L .65174 .49429 L .819 .416 .285 r
F
.64532 .47878 m .64272 .48174 L .64896 .49246 L F
.82733 .41062 m .8308 .40535 L .83327 .40878 L .664 .742 .908 r
F
.82733 .41062 m .82485 .40722 L .8308 .40535 L F
.30313 .41063 m .30507 .40535 L .30854 .40878 L .664 .741 .908 r
F
.30313 .41063 m .29965 .40721 L .30507 .40535 L F
.22289 .41048 m .2246 .4052 L .22822 .40863 L .663 .741 .908 r
F
.22289 .41048 m .21926 .40706 L .2246 .4052 L F
.39764 .41049 m .39985 .40521 L .40314 .40863 L F
.39764 .41049 m .39434 .40706 L .39985 .40521 L F
.92188 .41049 m .92563 .40521 L .92792 .40864 L .664 .741 .908 r
F
.92188 .41049 m .91958 .40707 L .92563 .40521 L F
.74713 .4105 m .75037 .40521 L .753 .40864 L .663 .741 .907 r
F
.74713 .4105 m .7445 .40707 L .75037 .40521 L F
.84168 .41034 m .8452 .40506 L .84765 .40849 L .664 .742 .908 r
F
.84168 .41034 m .83923 .40692 L .8452 .40506 L F
.3174 .41034 m .31938 .40506 L .32283 .40849 L .664 .741 .908 r
F
.3174 .41034 m .31395 .40692 L .31938 .40506 L F
.76148 .4102 m .76476 .40492 L .76736 .40835 L .663 .741 .908 r
F
.76148 .4102 m .75887 .40677 L .76476 .40492 L F
.23715 .4102 m .2389 .40491 L .2425 .40834 L .664 .741 .908 r
F
.23715 .4102 m .23355 .40677 L .2389 .40491 L F
.41193 .4102 m .41419 .40492 L .41745 .40835 L .663 .741 .908 r
F
.41193 .4102 m .40866 .40677 L .41419 .40492 L F
.85605 .41006 m .8596 .40478 L .86202 .40821 L .664 .742 .908 r
F
.85605 .41006 m .85362 .40664 L .8596 .40478 L F
.33168 .41006 m .3337 .40477 L .33712 .4082 L .663 .741 .908 r
F
.33168 .41006 m .32826 .40663 L .3337 .40477 L F
.69346 .4482 m .69937 .49686 L .70151 .48838 L .905 .577 .414 r
F
.69346 .4482 m .69127 .45571 L .69937 .49686 L F
.51608 .46492 m .5186 .48727 L .52169 .49106 L .941 .585 .305 r
F
.52169 .49106 m .5186 .48727 L .5243 .44312 L .949 .718 .554 r
F
.5186 .48727 m .52124 .43857 L .5243 .44312 L .947 .715 .555 r
F
.25142 .40991 m .25321 .40463 L .25678 .40806 L .664 .741 .908 r
F
.25142 .40991 m .24785 .40649 L .25321 .40463 L F
.77583 .40992 m .77915 .40465 L .78172 .40807 L .663 .741 .908 r
F
.77583 .40992 m .77325 .4065 L .77915 .40465 L F
.42622 .40993 m .42852 .40473 L .43176 .40817 L .657 .739 .91 r
F
.42622 .40993 m .42298 .4065 L .42852 .40473 L F
.34596 .40977 m .34803 .40449 L .35142 .40792 L .663 .741 .908 r
F
.34596 .40977 m .34257 .40635 L .34803 .40449 L F
.87041 .40978 m .87401 .40448 L .8764 .40793 L .665 .742 .908 r
F
.87041 .40978 m .86801 .40636 L .87401 .40448 L F
.79018 .40963 m .79355 .40434 L .79609 .40778 L .664 .741 .908 r
F
.79018 .40963 m .78763 .40621 L .79355 .40434 L F
.26569 .40963 m .26752 .40434 L .27107 .40777 L F
.26569 .40963 m .26215 .40621 L .26752 .40434 L F
.44357 .4192 m .44349 .51369 L .44661 .52494 L .96 .672 .442 r
F
.44357 .4192 m .44038 .41507 L .44349 .51369 L F
.36025 .40949 m .36236 .4042 L .36572 .40763 L .664 .741 .908 r
F
.36025 .40949 m .35688 .40606 L .36236 .4042 L F
.88478 .40949 m .88842 .4042 L .89079 .40764 L .663 .741 .908 r
F
.88478 .40949 m .88241 .40606 L .88842 .4042 L F
.27997 .40934 m .28184 .40406 L .28536 .40749 L F
.27997 .40934 m .27645 .40591 L .28184 .40406 L F
.80454 .40934 m .80795 .40406 L .81047 .40749 L F
.80454 .40934 m .80201 .40592 L .80795 .40406 L F
.37454 .4092 m .37669 .40391 L .38003 .40735 L F
.37454 .4092 m .3712 .40577 L .37669 .40391 L F
.89916 .4092 m .90284 .40392 L .90518 .40735 L F
.89916 .4092 m .89681 .40577 L .90284 .40392 L F
.72429 .40921 m .72746 .40392 L .73013 .40736 L F
.72429 .40921 m .72161 .40578 L .72746 .40392 L F
.49248 .5228 m .48929 .52054 L .49566 .44634 L .958 .713 .523 r
F
.48929 .52054 m .49252 .44624 L .49566 .44634 L .957 .712 .526 r
F
.49566 .44634 m .49252 .44624 L .49806 .45452 L .822 .36 .121 r
F
.29425 .40906 m .29617 .40377 L .29965 .40721 L .664 .741 .908 r
F
.29425 .40906 m .29076 .40564 L .29617 .40377 L F
.81891 .40907 m .82235 .40378 L .82485 .40722 L .663 .741 .908 r
F
.81891 .40907 m .8164 .40564 L .82235 .40378 L F
.5135 .47967 m .51042 .47662 L .51608 .46492 L .905 .773 .705 r
F
.51608 .46492 m .513 .46286 L .5186 .48727 L .941 .585 .305 r
F
.21394 .40892 m .21562 .40362 L .21926 .40706 L .664 .742 .908 r
F
.21394 .40892 m .2103 .4055 L .21562 .40362 L F
.91354 .40892 m .91726 .40363 L .91958 .40707 L .665 .742 .908 r
F
.91354 .40892 m .91122 .40551 L .91726 .40363 L F
.73864 .40893 m .74185 .40363 L .7445 .40707 L F
.73864 .40893 m .73599 .40551 L .74185 .40363 L F
.38884 .40893 m .39103 .40363 L .39434 .40706 L .663 .741 .908 r
F
.38884 .40893 m .38553 .40549 L .39103 .40363 L F
.72896 .6379 m .72629 .63688 L .72268 .47298 L .977 .701 .438 r
F
.83327 .40878 m .83676 .40348 L .83923 .40692 L .664 .742 .908 r
F
.83327 .40878 m .8308 .40535 L .83676 .40348 L F
.30854 .40878 m .31049 .40348 L .31395 .40692 L .664 .741 .908 r
F
.30854 .40878 m .30507 .40535 L .31049 .40348 L F
.22822 .40863 m .22994 .40334 L .23355 .40677 L F
.22822 .40863 m .2246 .4052 L .22994 .40334 L F
.40314 .40863 m .40538 .40334 L .40866 .40677 L .664 .742 .908 r
F
.40314 .40863 m .39985 .40521 L .40538 .40334 L F
.92792 .40864 m .93169 .40335 L .93398 .40678 L .663 .741 .908 r
F
.92792 .40864 m .92563 .40521 L .93169 .40335 L F
.753 .40864 m .75625 .40334 L .75887 .40677 L .664 .742 .908 r
F
.753 .40864 m .75037 .40521 L .75625 .40334 L F
.60549 .48759 m .60258 .48458 L .60766 .45574 L .955 .742 .578 r
F
.32283 .40849 m .32482 .4032 L .32826 .40663 L .663 .741 .908 r
F
.32283 .40849 m .31938 .40506 L .32482 .4032 L F
.84765 .40849 m .85118 .4032 L .85362 .40664 L F
.84765 .40849 m .8452 .40506 L .85118 .4032 L F
.2425 .40834 m .24426 .40306 L .24785 .40649 L F
.2425 .40834 m .2389 .40491 L .24426 .40306 L F
.76736 .40835 m .77066 .40306 L .77325 .4065 L F
.76736 .40835 m .76476 .40492 L .77066 .40306 L F
.41745 .40835 m .41972 .40306 L .42298 .4065 L F
.41745 .40835 m .41419 .40492 L .41972 .40306 L F
.53557 .436 m .53819 .42992 L .54122 .43256 L .759 .811 .894 r
F
.66146 .41932 m .6587 .4169 L .66705 .47454 L .963 .638 .343 r
F
.33712 .4082 m .33916 .40291 L .34257 .40635 L .663 .741 .908 r
F
.33712 .4082 m .3337 .40477 L .33916 .40291 L F
.86202 .40821 m .8656 .40291 L .86801 .40636 L .664 .741 .908 r
F
.86202 .40821 m .8596 .40478 L .8656 .40291 L F
.54383 .42201 m .54664 .44176 L .54968 .44461 L .943 .579 .221 r
F
.54968 .44461 m .54664 .44176 L .54699 .44202 L 0 .178 .661 r
F
.54685 .42579 m .54968 .44461 L .55237 .44719 L .94 .571 .218 r
F
.55177 .4456 m .54938 .44294 L .55243 .44609 L 0 .1 .656 r
F
.54664 .44176 m .54938 .44294 L .55177 .4456 L F
.54968 .44461 m .54699 .44202 L .55177 .4456 L 0 .178 .661 r
F
.54079 .41783 m .54358 .43612 L .54664 .44176 L .939 .569 .202 r
F
.54664 .44176 m .54358 .43612 L .54938 .44294 L 0 .1 .656 r
F
.54358 .43612 m .54635 .444 L .54938 .44294 L .674 .355 0 r
F
.54938 .44294 m .54915 .44302 L .54918 .44272 L .986 .78 .543 r
F
.54938 .44294 m .54918 .44272 L .55176 .4127 L F
.55177 .4127 m .55176 .4127 L .55183 .41193 L F
.54938 .44294 m .55176 .4127 L .55177 .4127 L F
.54938 .44294 m .55183 .41193 L .55183 .41193 L F
.54915 .44302 m .54689 .44079 L .55187 .41143 L F
.55479 .41492 m .55187 .41143 L .5549 .41436 L F
.54938 .44294 m .55187 .41143 L .55479 .41492 L F
.54635 .444 m .54882 .40751 L .55187 .41143 L .974 .757 .547 r
F
.55187 .41143 m .54882 .40751 L .54894 .40792 L .931 .554 .181 r
F
.55183 .41193 m .55183 .41193 L .55187 .41143 L .986 .78 .543 r
F
.55762 .4181 m .5549 .41436 L .55791 .41653 L .951 .741 .583 r
F
.55243 .44609 m .55474 .41643 L .55717 .42051 L F
.5555 .45243 m .55791 .41653 L .56092 .42034 L .922 .703 .59 r
F
.5555 .45243 m .55243 .44609 L .55791 .41653 L F
.55243 .44609 m .54938 .44294 L .5549 .41436 L .951 .741 .583 r
F
.55476 .42858 m .5517 .42397 L .55478 .42867 L .927 .542 .186 r
F
.54936 .40942 m .55131 .4215 L .55319 .42303 L F
.55187 .41143 m .54894 .40792 L .54911 .40854 L .931 .554 .181 r
F
.55192 .41169 m .54911 .40854 L .55478 .42867 L F
.55187 .41143 m .54911 .40854 L .55192 .41169 L F
.54358 .43612 m .54049 .42754 L .54587 .44267 L .674 .355 0 r
F
.54608 .44324 m .54587 .44267 L .54635 .444 L F
.54358 .43612 m .54587 .44267 L .54608 .44324 L F
.53775 .41361 m .54049 .42754 L .54358 .43612 L .917 .521 .146 r
F
.54049 .42754 m .54328 .44338 L .54635 .444 L .89 .546 .058 r
F
.54146 .43048 m .54271 .40339 L .54577 .40429 L .908 .691 .598 r
F
.54049 .42754 m .5374 .41938 L .54136 .43556 L .89 .546 .058 r
F
.53515 .42818 m .5321 .42657 L .53688 .41561 L .944 .817 .69 r
F
.53724 .41647 m .53688 .41561 L .53775 .41361 L F
.53515 .42818 m .53688 .41561 L .53724 .41647 L F
.5321 .42657 m .5347 .41017 L .53775 .41361 L .952 .809 .666 r
F
.53504 .4112 m .5374 .41938 L .54049 .42754 L .863 .415 .053 r
F
.5347 .41017 m .5349 .41086 L .53504 .4112 L F
.5349 .41086 m .5374 .41938 L .53504 .4112 L F
.53775 .41361 m .5347 .41017 L .54049 .42754 L .917 .521 .146 r
F
.5374 .41938 m .54018 .43831 L .54328 .44338 L .932 .579 .154 r
F
.5321 .42657 m .52904 .42509 L .53374 .41271 L .952 .809 .666 r
F
.53415 .41365 m .53374 .41271 L .5347 .41017 L F
.5321 .42657 m .53374 .41271 L .53415 .41365 L F
.52904 .42509 m .53164 .40804 L .5347 .41017 L .973 .828 .64 r
F
.5347 .41017 m .53164 .40804 L .53668 .41797 L .863 .415 .053 r
F
.5347 .41017 m .53668 .41797 L .53719 .41866 L F
.53178 .4083 m .53431 .41274 L .5374 .41938 L .691 .149 0 r
F
.53164 .40804 m .53172 .40817 L .53178 .4083 L F
.53172 .40817 m .53431 .41274 L .53178 .4083 L F
.52904 .42509 m .52596 .42481 L .53164 .40804 L .973 .828 .64 r
F
.52596 .42481 m .52857 .40766 L .53164 .40804 L .991 .851 .604 r
F
.53164 .40804 m .52857 .40766 L .53431 .41274 L .691 .149 0 r
F
.53019 .40909 m .53121 .40686 L .53431 .41274 L 0 0 0 r
F
.52857 .40766 m .52904 .40751 L .53019 .40909 L F
.52904 .40751 m .53121 .40686 L .53019 .40909 L F
.53719 .41866 m .53668 .41797 L .5374 .41938 L .863 .415 .053 r
F
.5374 .41938 m .53431 .41274 L .54018 .43831 L .932 .579 .154 r
F
.53254 .43333 m .53515 .42818 L .53819 .42992 L .785 .906 .925 r
F
.54016 .43823 m .53705 .43085 L .54018 .43831 L .933 .572 .159 r
F
.53431 .41274 m .53608 .42439 L .53708 .42484 L F
.53431 .41274 m .53121 .40686 L .53705 .43085 L F
.53704 .4308 m .53393 .42352 L .53705 .43085 L .928 .558 .152 r
F
.53121 .40686 m .53393 .42352 L .53704 .4308 L F
.52124 .43857 m .51818 .43319 L .52383 .4223 L .855 .709 .7 r
F
.51818 .43319 m .52077 .41989 L .52383 .4223 L .804 .686 .734 r
F
.52383 .4223 m .52077 .41989 L .52642 .43099 L .86 .41 .034 r
F
.52613 .43041 m .52335 .43003 L .52642 .43099 L .879 .442 .113 r
F
.52077 .41989 m .52335 .43003 L .52613 .43041 L F
.51818 .43319 m .51511 .42736 L .52077 .41989 L .804 .686 .734 r
F
.51511 .42736 m .51769 .41813 L .52077 .41989 L .702 .643 .788 r
F
.52286 .42901 m .52025 .42991 L .52335 .43003 L .878 .455 .197 r
F
.51769 .41813 m .52025 .42991 L .52286 .42901 L F
.513 .46286 m .51549 .48303 L .5186 .48727 L .928 .563 .302 r
F
.51042 .47662 m .50734 .47192 L .513 .46286 L .847 .724 .727 r
F
.513 .46287 m .50991 .46173 L .513 .46286 L .777 .703 .781 r
F
.50734 .47192 m .50991 .46173 L .513 .46287 L F
.50424 .46699 m .50679 .46057 L .50991 .46173 L .614 .626 .84 r
F
.50991 .46173 m .50679 .46057 L .5068 .46059 L .917 .532 .261 r
F
.50734 .47192 m .50424 .46699 L .50991 .46173 L .777 .703 .781 r
F
.50991 .46173 m .5068 .46059 L .51238 .47796 L .917 .532 .261 r
F
.513 .46286 m .50991 .46173 L .51549 .48303 L .928 .563 .302 r
F
.50991 .46173 m .51238 .47796 L .51549 .48303 L .917 .532 .261 r
F
.51238 .47796 m .51511 .42736 L .51818 .43319 L .931 .697 .563 r
F
.51511 .42736 m .51204 .42137 L .51769 .41813 L .702 .643 .788 r
F
.51204 .42137 m .51459 .41771 L .51769 .41813 L .381 .492 .847 r
F
.51459 .41771 m .51713 .43124 L .52025 .42991 L .856 .452 .27 r
F
.52025 .42991 m .51713 .43124 L .51762 .43082 L .707 .978 .778 r
F
.52077 .41989 m .51769 .41813 L .52335 .43003 L .879 .442 .113 r
F
.51769 .41813 m .51459 .41771 L .52025 .42991 L .878 .455 .197 r
F
.52035 .4271 m .52237 .41298 L .52548 .40934 L .994 .872 .563 r
F
.52025 .42991 m .51762 .43082 L .52256 .42656 L .707 .978 .778 r
F
.5227 .42644 m .51973 .42923 L .52286 .4263 L 0 0 0 r
F
.51713 .43124 m .51973 .42923 L .5227 .42644 L F
.50679 .46057 m .50927 .47124 L .51238 .47796 L .863 .431 .186 r
F
.51238 .47796 m .50927 .47124 L .51511 .42736 L .931 .697 .563 r
F
.50927 .47124 m .51204 .42137 L .51511 .42736 L .92 .687 .57 r
F
.51399 .43369 m .51659 .4326 L .51973 .42923 L 0 0 0 r
F
.51973 .42923 m .51659 .4326 L .51675 .43205 L .994 .872 .563 r
F
.51204 .42137 m .50895 .41569 L .51459 .41771 L .381 .492 .847 r
F
.51459 .41771 m .51147 .41913 L .51713 .43124 L .856 .452 .27 r
F
.50424 .46699 m .50115 .46165 L .50679 .46057 L .614 .626 .84 r
F
.50115 .46165 m .50366 .46035 L .50679 .46057 L .066 .239 .732 r
F
.50679 .46057 m .50366 .46035 L .50927 .47124 L .863 .431 .186 r
F
.50927 .47124 m .50617 .46305 L .51204 .42137 L .92 .687 .57 r
F
.50617 .46305 m .50895 .41569 L .51204 .42137 L .909 .679 .578 r
F
.51147 .41913 m .51399 .43369 L .51713 .43124 L .82 .43 .315 r
F
.51713 .43124 m .51399 .43369 L .51911 .42972 L 0 0 0 r
F
.51939 .4295 m .51911 .42972 L .51973 .42923 L F
.51713 .43124 m .51911 .42972 L .51939 .4295 L F
.51694 .4314 m .51923 .41794 L .52237 .41298 L .992 .883 .599 r
F
.51659 .4326 m .51678 .43153 L .51694 .4314 L F
.51678 .43153 m .51923 .41794 L .51694 .4314 L F
.51973 .42923 m .51675 .43205 L .52237 .41298 L .994 .872 .563 r
F
.51973 .42923 m .52007 .42717 L .52035 .4271 L F
.52007 .42717 m .52237 .41298 L .52035 .4271 L F
.52269 .42653 m .52256 .42656 L .52286 .4263 L .707 .978 .778 r
F
.52025 .42991 m .52256 .42656 L .52269 .42653 L F
.52335 .43003 m .52025 .42991 L .52054 .42964 L .838 .977 .879 r
F
.52335 .43003 m .52054 .42964 L .52596 .42481 L F
.52596 .42481 m .52286 .4263 L .52857 .40766 L .991 .851 .604 r
F
.52286 .4263 m .52548 .40934 L .52857 .40766 L .996 .864 .571 r
F
.52857 .40766 m .52548 .40934 L .53121 .40686 L 0 0 0 r
F
.52548 .40934 m .52811 .40169 L .53121 .40686 L .887 .938 .567 r
F
.52811 .40169 m .5308 .41624 L .53393 .42352 L .919 .526 .157 r
F
.53393 .42352 m .5308 .41624 L .53081 .41622 L .769 .647 .727 r
F
.53121 .40686 m .52811 .40169 L .53393 .42352 L .928 .558 .152 r
F
.53393 .42352 m .53081 .41622 L .53659 .40943 L .769 .647 .727 r
F
.53395 .42346 m .53659 .40943 L .53966 .4054 L F
.53393 .42352 m .53394 .42346 L .53395 .42346 L F
.53394 .42346 m .53659 .40943 L .53395 .42346 L F
.53708 .42484 m .53705 .43085 L .54016 .43823 L .933 .572 .159 r
F
.53608 .42439 m .53705 .43085 L .53708 .42484 L F
.53705 .43085 m .53393 .42352 L .53395 .42346 L .877 .686 .639 r
F
.53705 .43085 m .53395 .42346 L .53966 .4054 L F
.53749 .42875 m .53966 .4054 L .54271 .40339 L F
.53705 .43085 m .5373 .42842 L .53749 .42875 L F
.5373 .42842 m .53966 .4054 L .53749 .42875 L F
.54203 .43673 m .54136 .43556 L .54285 .44162 L .89 .546 .058 r
F
.54049 .42754 m .54136 .43556 L .54203 .43673 L F
.54304 .44205 m .54285 .44162 L .54328 .44338 L F
.54049 .42754 m .54285 .44162 L .54304 .44205 L F
.54048 .43646 m .54086 .42883 L .54146 .43048 L .908 .691 .598 r
F
.54018 .43831 m .54033 .43614 L .54048 .43646 L F
.54033 .43614 m .54086 .42883 L .54048 .43646 L F
.54086 .42883 m .54271 .40339 L .54146 .43048 L F
.54635 .444 m .54328 .44338 L .54791 .41345 L .974 .757 .547 r
F
.54836 .41431 m .54791 .41345 L .54882 .40751 L F
.54635 .444 m .54791 .41345 L .54836 .41431 L F
.54328 .44338 m .54577 .40429 L .54882 .40751 L .939 .716 .573 r
F
.54328 .44338 m .54018 .43831 L .54577 .40429 L F
.54302 .40422 m .5455 .41302 L .54861 .41943 L .78 .337 .197 r
F
.54271 .40339 m .54288 .40395 L .54302 .40422 L F
.54288 .40395 m .5455 .41302 L .54302 .40422 L F
.54679 .40768 m .54861 .41943 L .5517 .42397 L .906 .504 .223 r
F
.54911 .40917 m .5517 .42397 L .54936 .40942 L .927 .542 .186 r
F
.54882 .40751 m .54577 .40429 L .5517 .42397 L F
.54864 .41934 m .55123 .39959 L .55425 .39871 L .863 .696 .673 r
F
.54861 .41943 m .54863 .41933 L .54864 .41934 L F
.54863 .41933 m .55123 .39959 L .54864 .41934 L F
.55319 .42303 m .5517 .42397 L .55476 .42858 L .927 .542 .186 r
F
.55131 .4215 m .5517 .42397 L .55319 .42303 L F
.5517 .42397 m .54861 .41943 L .54864 .41934 L .925 .732 .624 r
F
.55762 .43386 m .55478 .42867 L .55768 .43411 L .931 .554 .181 r
F
.55196 .41176 m .55454 .42725 L .55679 .43064 L F
.55192 .41169 m .55478 .42867 L .55196 .41176 L F
.55717 .42051 m .55485 .41499 L .55762 .4181 L .951 .741 .583 r
F
.55474 .41643 m .55485 .41499 L .55717 .42051 L F
.55485 .41499 m .5549 .41436 L .55762 .4181 L F
.5549 .41436 m .55187 .41143 L .55787 .43483 L .94 .571 .243 r
F
.55188 .42323 m .55425 .39871 L .55729 .39997 L .925 .732 .624 r
F
.5517 .42397 m .55179 .4231 L .55188 .42323 L F
.55179 .4231 m .55425 .39871 L .55188 .42323 L F
.55679 .43064 m .55477 .4286 L .55762 .43386 L .931 .554 .181 r
F
.55454 .42725 m .55477 .4286 L .55679 .43064 L F
.55477 .4286 m .55478 .42867 L .55762 .43386 L F
.5517 .42397 m .54864 .41934 L .54901 .41797 L .925 .732 .624 r
F
.55187 .41143 m .55192 .41169 L .55196 .41176 L .931 .554 .181 r
F
.55179 .4231 m .54901 .41797 L .55425 .39871 L .925 .732 .624 r
F
.5517 .42397 m .54901 .41797 L .55179 .4231 L F
.55478 .42867 m .5517 .42397 L .55188 .42323 L .93 .727 .606 r
F
.55853 .45569 m .56092 .42034 L .56394 .42592 L .952 .735 .572 r
F
.55853 .45569 m .5555 .45243 L .56092 .42034 L F
.55791 .41653 m .5549 .41436 L .56094 .44053 L .943 .584 .287 r
F
.5549 .41436 m .55787 .43483 L .56094 .44053 L .94 .571 .243 r
F
.55478 .42867 m .55188 .42323 L .55729 .39997 L .93 .727 .606 r
F
.55768 .43411 m .55478 .42867 L .55787 .43483 L .931 .554 .181 r
F
.54577 .40429 m .54632 .4072 L .54679 .40768 L .906 .504 .223 r
F
.54632 .4072 m .54861 .41943 L .54679 .40768 L F
.54882 .40751 m .54911 .40917 L .54936 .40942 L .927 .542 .186 r
F
.54915 .44302 m .54635 .444 L .54689 .44079 L .986 .78 .543 r
F
.55208 .4459 m .55177 .4456 L .55243 .44609 L 0 .178 .661 r
F
.54968 .44461 m .55177 .4456 L .55208 .4459 L F
.55237 .44719 m .54968 .44461 L .55272 .44855 L .94 .571 .218 r
F
.25678 .40806 m .25858 .40277 L .26215 .40621 L .663 .741 .908 r
F
.25678 .40806 m .25321 .40463 L .25858 .40277 L F
.78172 .40807 m .78507 .40278 L .78763 .40621 L .664 .742 .908 r
F
.78172 .40807 m .77915 .40465 L .78507 .40278 L F
.43176 .40817 m .43397 .40674 L .43718 .41091 L .174 .506 .911 r
F
.43176 .40817 m .42852 .40473 L .43397 .40674 L F
.35142 .40792 m .3535 .40262 L .35688 .40606 L .664 .741 .908 r
F
.35142 .40792 m .34803 .40449 L .3535 .40262 L F
.8764 .40793 m .88002 .40262 L .88241 .40606 L .663 .741 .907 r
F
.8764 .40793 m .87401 .40448 L .88002 .40262 L F
.27107 .40777 m .27291 .40248 L .27645 .40591 L .664 .741 .908 r
F
.27107 .40777 m .26752 .40434 L .27291 .40248 L F
.79609 .40778 m .79948 .40248 L .80201 .40592 L F
.79609 .40778 m .79355 .40434 L .79948 .40248 L F
.36572 .40763 m .36785 .40233 L .3712 .40577 L .663 .741 .908 r
F
.36572 .40763 m .36236 .4042 L .36785 .40233 L F
.89079 .40764 m .89445 .40234 L .89681 .40577 L .664 .741 .908 r
F
.89079 .40764 m .88842 .4042 L .89445 .40234 L F
.71577 .40767 m .71892 .40234 L .72161 .40578 L .666 .743 .907 r
F
.71577 .40767 m .71307 .40425 L .71892 .40234 L F
.71015 .41311 m .71307 .40425 L .71577 .40767 L .847 .815 .818 r
F
.28536 .40749 m .28725 .4022 L .29076 .40564 L .663 .741 .908 r
F
.28536 .40749 m .28184 .40406 L .28725 .4022 L F
.81047 .40749 m .81389 .40219 L .8164 .40564 L .664 .741 .908 r
F
.81047 .40749 m .80795 .40406 L .81389 .40219 L F
.71131 .49452 m .70897 .49879 L .71015 .41311 L .99 .731 .426 r
F
.71015 .41311 m .70747 .41022 L .71307 .40425 L .847 .815 .818 r
F
.70897 .49879 m .70747 .41022 L .71015 .41311 L .989 .729 .421 r
F
.90518 .40735 m .90889 .40205 L .91122 .40551 L .664 .742 .908 r
F
.90518 .40735 m .90284 .40392 L .90889 .40205 L F
.38003 .40735 m .3822 .40205 L .38553 .40549 L .663 .741 .908 r
F
.38003 .40735 m .37669 .40391 L .3822 .40205 L F
.73013 .40736 m .73332 .40207 L .73599 .40551 L F
.73013 .40736 m .72746 .40392 L .73332 .40207 L F
.56757 .46633 m .56451 .4582 L .56988 .43083 L .899 .682 .6 r
F
.56959 .43232 m .56694 .4297 L .56988 .43083 L .948 .746 .595 r
F
.56394 .42592 m .56092 .42034 L .56177 .42356 L .926 .56 .14 r
F
.56451 .4582 m .56684 .4308 L .56922 .4342 L .948 .746 .595 r
F
.56451 .4582 m .56151 .45513 L .56694 .4297 L F
.56151 .45513 m .56394 .42592 L .56694 .4297 L .984 .783 .555 r
F
.56151 .45513 m .55853 .45569 L .56394 .42592 L F
.56412 .42691 m .56177 .42356 L .56696 .44334 L .926 .56 .14 r
F
.56394 .42592 m .56177 .42356 L .56412 .42691 L F
.56922 .4342 m .56694 .4297 L .56959 .43232 L .948 .746 .595 r
F
.56684 .4308 m .56694 .4297 L .56922 .4342 L F
.56694 .4297 m .56394 .42592 L .56427 .42706 L .931 .553 .182 r
F
.56694 .4297 m .56427 .42706 L .56959 .4456 L F
.56974 .44573 m .56959 .4456 L .5699 .44668 L F
.56694 .4297 m .56959 .4456 L .56974 .44573 L F
.56092 .42034 m .56396 .44265 L .56696 .44334 L .947 .587 .244 r
F
.56696 .44334 m .56396 .44265 L .56436 .44083 L .975 .782 .58 r
F
.56694 .4297 m .5699 .44668 L .56994 .44671 L .931 .553 .182 r
F
.56988 .43083 m .56694 .4297 L .573 .45266 L .932 .565 .289 r
F
.572 .44887 m .56997 .44691 L .573 .45266 L .931 .553 .182 r
F
.56694 .4297 m .56977 .44576 L .572 .44887 L F
.56977 .44576 m .56997 .44691 L .572 .44887 L F
.56394 .42592 m .56696 .44334 L .56987 .44679 L .926 .56 .14 r
F
.56996 .44689 m .56987 .44679 L .56997 .44691 L F
.56394 .42592 m .56987 .44679 L .56996 .44689 L F
.55791 .41653 m .56094 .44053 L .56396 .44265 L .943 .584 .287 r
F
.56396 .44265 m .56094 .44053 L .56144 .43809 L .961 .758 .583 r
F
.56092 .42034 m .55791 .41653 L .56396 .44265 L .947 .587 .244 r
F
.56412 .44085 m .56144 .43809 L .56641 .41361 L .961 .758 .583 r
F
.56396 .44265 m .56144 .43809 L .56412 .44085 L F
.56697 .44321 m .56436 .44083 L .56479 .43883 L .975 .782 .58 r
F
.56094 .44053 m .56337 .40839 L .56641 .41361 L .924 .712 .598 r
F
.56641 .41361 m .56337 .40839 L .56415 .41253 L .956 .613 .256 r
F
.56708 .44202 m .56479 .43883 L .56928 .41794 L .975 .782 .58 r
F
.56708 .44202 m .56928 .41794 L .56935 .41801 L F
.57236 .42063 m .56942 .41726 L .57242 .42039 L F
.56698 .44323 m .56942 .41726 L .57236 .42063 L F
.56396 .44265 m .56641 .41361 L .56682 .4141 L .961 .758 .583 r
F
.56932 .41774 m .56682 .4141 L .56942 .41726 L F
.56396 .44265 m .56682 .4141 L .56932 .41774 L F
.55787 .43483 m .56033 .40335 L .56337 .40839 L .917 .706 .603 r
F
.56337 .40839 m .56033 .40335 L .56062 .40506 L .96 .623 .284 r
F
.56094 .44053 m .55787 .43483 L .56337 .40839 L .924 .712 .598 r
F
.55787 .43483 m .55478 .42867 L .56033 .40335 L .917 .706 .603 r
F
.55478 .42867 m .55729 .39997 L .56033 .40335 L .93 .727 .606 r
F
.55729 .39997 m .56045 .4339 L .56353 .437 L .948 .608 .34 r
F
.56353 .437 m .56045 .4339 L .56073 .43189 L .96 .732 .548 r
F
.56345 .40919 m .56062 .40506 L .56658 .44012 L .96 .623 .284 r
F
.56345 .40919 m .56658 .44012 L .56659 .44012 L F
.56697 .44321 m .56942 .41726 L .56698 .44323 L .975 .782 .58 r
F
.56994 .44671 m .5699 .44668 L .56997 .44691 L .931 .553 .182 r
F
.56997 .44691 m .56696 .44334 L .57242 .42039 L .941 .744 .608 r
F
.56658 .41509 m .56415 .41253 L .56962 .44138 L .956 .613 .256 r
F
.56641 .41361 m .56415 .41253 L .56658 .41509 L F
.56337 .40839 m .56659 .44015 L .56962 .44138 L .96 .623 .284 r
F
.56033 .40335 m .56353 .437 L .56659 .44015 L .957 .62 .314 r
F
.56033 .40335 m .55729 .39997 L .56353 .437 L F
.56359 .43591 m .56073 .43189 L .56585 .39473 L .96 .732 .548 r
F
.56353 .437 m .56073 .43189 L .56359 .43591 L F
.56659 .44012 m .56658 .44012 L .56659 .44015 L .96 .623 .284 r
F
.56337 .40839 m .56062 .40506 L .56345 .40919 L F
.56942 .41726 m .56641 .41361 L .56648 .41388 L .946 .584 .241 r
F
.56935 .41801 m .56928 .41794 L .56942 .41726 L .975 .782 .58 r
F
.573 .45266 m .56997 .44691 L .57542 .42486 L .912 .711 .618 r
F
.56997 .44691 m .57242 .42039 L .57542 .42486 L .941 .744 .608 r
F
.56942 .41726 m .56648 .41388 L .57258 .43978 L .946 .584 .241 r
F
.56697 .44321 m .56479 .43883 L .56708 .44202 L .975 .782 .58 r
F
.56696 .44334 m .56436 .44083 L .56697 .44321 L F
.56696 .44334 m .56697 .44321 L .56698 .44323 L F
.5186 .48727 m .51549 .48303 L .52124 .43857 L .947 .715 .555 r
F
.51549 .48303 m .51818 .43319 L .52124 .43857 L .942 .709 .557 r
F
.29965 .40721 m .30159 .4019 L .30507 .40535 L .664 .741 .908 r
F
.29965 .40721 m .29617 .40377 L .30159 .4019 L F
.82485 .40722 m .82832 .40191 L .8308 .40535 L .664 .741 .907 r
F
.82485 .40722 m .82235 .40378 L .82832 .40191 L F
.49145 .59492 m .49445 .5374 L .49751 .54701 L .97 .736 .528 r
F
.49465 .59295 m .49751 .54701 L .50055 .55847 L .977 .753 .534 r
F
.49465 .59295 m .49145 .59492 L .49751 .54701 L F
.50352 .56939 m .50055 .55847 L .5036 .56908 L .983 .779 .553 r
F
.49782 .59088 m .50055 .55847 L .50352 .56939 L F
.50055 .55847 m .49751 .54701 L .49758 .54755 L .954 .644 .217 r
F
.49782 .59088 m .49465 .59295 L .50055 .55847 L .983 .779 .553 r
F
.50099 .58756 m .49782 .59088 L .50352 .56939 L .996 .851 .572 r
F
.50355 .56942 m .50352 .56939 L .5036 .56908 L F
.50099 .58756 m .50352 .56939 L .50355 .56942 L F
.50055 .55847 m .49758 .54755 L .50002 .56527 L .954 .644 .217 r
F
.50125 .56671 m .50002 .56527 L .50267 .58449 L F
.50125 .56671 m .50267 .58449 L .50277 .58474 L F
.50055 .55847 m .50002 .56527 L .50125 .56671 L F
.50277 .58519 m .49973 .58159 L .50286 .58588 L .972 .66 .297 r
F
.49751 .54701 m .49969 .58098 L .50259 .58388 L F
.49751 .54701 m .49445 .5374 L .49965 .5809 L F
.49969 .58098 m .49965 .5809 L .49973 .58159 L F
.49751 .54701 m .49965 .5809 L .49969 .58098 L F
.4997 .58131 m .49658 .57846 L .49973 .58159 L .969 .657 .358 r
F
.49445 .5374 m .49658 .57846 L .4997 .58131 L F
.49145 .59492 m .48824 .59608 L .49445 .5374 L .97 .736 .528 r
F
.48824 .59608 m .49137 .53106 L .49445 .5374 L .962 .724 .531 r
F
.49137 .53106 m .4934 .57577 L .49658 .57846 L .967 .657 .375 r
F
.49658 .57846 m .4934 .57577 L .49344 .5756 L .945 .742 .599 r
F
.49445 .5374 m .49137 .53106 L .49641 .57698 L .969 .657 .358 r
F
.49651 .57711 m .49641 .57698 L .49658 .57846 L F
.49445 .5374 m .49641 .57698 L .49651 .57711 L F
.48824 .59608 m .48503 .59548 L .49133 .53143 L .962 .724 .531 r
F
.49135 .53146 m .49133 .53143 L .49137 .53106 L F
.48824 .59608 m .49133 .53143 L .49135 .53146 L F
.48181 .59427 m .48517 .51915 L .48827 .52545 L .96 .717 .526 r
F
.48827 .52545 m .48517 .51915 L .48562 .52383 L .969 .661 .374 r
F
.48503 .59548 m .48827 .52545 L .49137 .53106 L .96 .719 .53 r
F
.48503 .59548 m .48181 .59427 L .48827 .52545 L F
.47858 .59312 m .48204 .51447 L .48517 .51915 L .955 .71 .529 r
F
.48701 .56736 m .48384 .56515 L .48705 .56783 L .95 .642 .415 r
F
.48204 .51447 m .48384 .56515 L .48701 .56736 L F
.47858 .59312 m .47534 .59055 L .48204 .51447 L .955 .71 .529 r
F
.47886 .51313 m .48061 .56317 L .48384 .56515 L .942 .633 .423 r
F
.48384 .56515 m .48061 .56317 L .48066 .56293 L .952 .752 .596 r
F
.49005 .57004 m .48705 .56783 L .49023 .57188 L .964 .656 .391 r
F
.48517 .51915 m .48703 .56738 L .49005 .57004 L F
.48703 .56738 m .48705 .56783 L .49005 .57004 L F
.48384 .56515 m .48066 .56293 L .48087 .56198 L .952 .752 .596 r
F
.48517 .51915 m .48204 .51447 L .48701 .56736 L .964 .656 .391 r
F
.48703 .56738 m .48701 .56736 L .48705 .56783 L F
.48517 .51915 m .48701 .56736 L .48703 .56738 L F
.48204 .51447 m .47886 .51313 L .48384 .56515 L .95 .642 .415 r
F
.48389 .56463 m .48087 .56198 L .48096 .56157 L .952 .752 .596 r
F
.48391 .56439 m .48096 .56157 L .48666 .53557 L F
.48389 .56463 m .48096 .56157 L .48391 .56439 L F
.48384 .56515 m .48087 .56198 L .48389 .56463 L F
.48705 .56783 m .48384 .56515 L .48429 .56311 L .945 .743 .599 r
F
.48835 .52747 m .48562 .52383 L .49009 .57039 L .969 .661 .374 r
F
.49012 .57043 m .49009 .57039 L .49014 .57096 L F
.48835 .52747 m .49009 .57039 L .49012 .57043 L F
.48835 .52747 m .49014 .57096 L .4902 .57104 L F
.49137 .53106 m .48827 .52545 L .49314 .57321 L .967 .657 .375 r
F
.4933 .57339 m .49314 .57321 L .4934 .57577 L F
.49137 .53106 m .49314 .57321 L .4933 .57339 L F
.48827 .52545 m .49023 .57188 L .4934 .57577 L .969 .661 .374 r
F
.48434 .56291 m .48666 .53557 L .48985 .53787 L .952 .752 .596 r
F
.48429 .56311 m .48431 .56288 L .48434 .56291 L F
.48431 .56288 m .48666 .53557 L .48434 .56291 L F
.48384 .56515 m .48406 .56283 L .48429 .56311 L F
.48406 .56283 m .48666 .53557 L .48429 .56311 L F
.48714 .56693 m .48429 .56311 L .48985 .53787 L .945 .743 .599 r
F
.48705 .56783 m .48429 .56311 L .48714 .56693 L F
.4902 .57104 m .49014 .57096 L .49023 .57188 L .969 .661 .374 r
F
.48827 .52545 m .48562 .52383 L .48835 .52747 L F
.48774 .56471 m .48985 .53787 L .49302 .5407 L .945 .743 .599 r
F
.48705 .56783 m .48739 .56421 L .48774 .56471 L F
.48739 .56421 m .48985 .53787 L .48774 .56471 L F
.49658 .57846 m .49344 .5756 L .49932 .54836 L .945 .742 .599 r
F
.5036 .56908 m .50055 .55847 L .5056 .58645 L .918 .601 .126 r
F
.50579 .58697 m .5056 .58645 L .506 .58863 L F
.5036 .56908 m .5056 .58645 L .50579 .58697 L F
.50055 .55847 m .50286 .58588 L .506 .58863 L .954 .644 .217 r
F
.4988 .56786 m .49932 .54836 L .50246 .55042 L .945 .742 .599 r
F
.49711 .5759 m .49794 .56552 L .4988 .56786 L F
.49794 .56552 m .49932 .54836 L .4988 .56786 L F
.49668 .57797 m .4969 .57548 L .49711 .5759 L F
.4969 .57548 m .49932 .54836 L .49711 .5759 L F
.49658 .57846 m .49663 .57791 L .49668 .57797 L F
.49663 .57791 m .49932 .54836 L .49668 .57797 L F
.50259 .58388 m .49973 .58159 L .50277 .58519 L .972 .66 .297 r
F
.49969 .58098 m .49973 .58159 L .50259 .58388 L F
.49973 .58159 m .49658 .57846 L .49668 .57797 L .941 .736 .598 r
F
.49973 .58159 m .49668 .57797 L .50246 .55042 L F
.50036 .57845 m .50246 .55042 L .50559 .55235 L F
.49973 .58159 m .50007 .5777 L .50036 .57845 L F
.50007 .5777 m .50246 .55042 L .50036 .57845 L F
.50277 .58474 m .50267 .58449 L .50286 .58588 L .954 .644 .217 r
F
.21926 .40706 m .22096 .40176 L .2246 .4052 L .663 .741 .908 r
F
.21926 .40706 m .21562 .40362 L .22096 .40176 L F
.39434 .40706 m .39655 .40177 L .39985 .40521 L .663 .742 .908 r
F
.39434 .40706 m .39103 .40363 L .39655 .40177 L F
.91958 .40707 m .92333 .40177 L .92563 .40521 L .663 .74 .908 r
F
.91958 .40707 m .91726 .40363 L .92333 .40177 L F
.7445 .40707 m .74773 .40176 L .75037 .40521 L .663 .741 .908 r
F
.7445 .40707 m .74185 .40363 L .74773 .40176 L F
.64799 .4548 m .6449 .44439 L .65027 .43181 L .799 .619 .657 r
F
.6449 .44439 m .64757 .43194 L .65027 .43181 L .701 .593 .732 r
F
.65027 .43181 m .64757 .43194 L .65554 .48522 L .953 .627 .368 r
F
.83923 .40692 m .84274 .40162 L .8452 .40506 L .663 .741 .908 r
F
.83923 .40692 m .83676 .40348 L .84274 .40162 L F
.31395 .40692 m .31593 .40161 L .31938 .40506 L .664 .741 .908 r
F
.31395 .40692 m .31049 .40348 L .31593 .40161 L F
.75887 .40677 m .76215 .40147 L .76476 .40492 L F
.75887 .40677 m .75625 .40334 L .76215 .40147 L F
.23355 .40677 m .23529 .40147 L .2389 .40491 L F
.23355 .40677 m .22994 .40334 L .23529 .40147 L F
.40866 .40677 m .41091 .40147 L .41419 .40492 L .663 .741 .908 r
F
.40866 .40677 m .40538 .40334 L .41091 .40147 L F
.32826 .40663 m .33028 .40133 L .3337 .40477 L F
.32826 .40663 m .32482 .4032 L .33028 .40133 L F
.85362 .40664 m .85717 .40133 L .8596 .40478 L .664 .741 .908 r
F
.85362 .40664 m .85118 .4032 L .85717 .40133 L F
.44038 .41507 m .44039 .50171 L .44349 .51369 L .961 .67 .438 r
F
.24785 .40649 m .24963 .40118 L .25321 .40463 L .664 .741 .908 r
F
.24785 .40649 m .24426 .40306 L .24963 .40118 L F
.77325 .4065 m .77657 .40119 L .77915 .40465 L F
.77325 .4065 m .77066 .40306 L .77657 .40119 L F
.42298 .4065 m .42527 .40127 L .42852 .40473 L .659 .74 .91 r
F
.42298 .4065 m .41972 .40306 L .42527 .40127 L F
.34257 .40635 m .34463 .40105 L .34803 .40449 L .664 .742 .908 r
F
.34257 .40635 m .33916 .40291 L .34463 .40105 L F
.86801 .40636 m .87161 .40104 L .87401 .40448 L .663 .74 .907 r
F
.86801 .40636 m .8656 .40291 L .87161 .40104 L F
.26215 .40621 m .26397 .4009 L .26752 .40434 L .664 .741 .908 r
F
.26215 .40621 m .25858 .40277 L .26397 .4009 L F
.78763 .40621 m .79099 .4009 L .79355 .40434 L .664 .742 .908 r
F
.78763 .40621 m .78507 .40278 L .79099 .4009 L F
.70558 .46912 m .71758 .62285 L .7206 .62939 L .95 .646 .425 r
F
.70558 .46912 m .70358 .47908 L .71758 .62285 L F
.88241 .40606 m .88605 .40076 L .88842 .4042 L .663 .741 .908 r
F
.88241 .40606 m .88002 .40262 L .88605 .40076 L F
.35688 .40606 m .35899 .40075 L .36236 .4042 L .664 .741 .908 r
F
.35688 .40606 m .3535 .40262 L .35899 .40075 L F
.27645 .40591 m .27832 .40061 L .28184 .40406 L .663 .741 .908 r
F
.27645 .40591 m .27291 .40248 L .27832 .40061 L F
.80201 .40592 m .80542 .40061 L .80795 .40406 L F
.80201 .40592 m .79948 .40248 L .80542 .40061 L F
.89681 .40577 m .90049 .40047 L .90284 .40392 L .664 .742 .908 r
F
.89681 .40577 m .89445 .40234 L .90049 .40047 L F
.3712 .40577 m .37335 .40047 L .37669 .40391 L .663 .741 .908 r
F
.3712 .40577 m .36785 .40233 L .37335 .40047 L F
.72161 .40578 m .72478 .40048 L .72746 .40392 L F
.72161 .40578 m .71892 .40234 L .72478 .40048 L F
.29076 .40564 m .29266 .40033 L .29617 .40377 L .664 .741 .908 r
F
.29076 .40564 m .28725 .4022 L .29266 .40033 L F
.8164 .40564 m .81985 .40032 L .82235 .40378 L .664 .741 .907 r
F
.8164 .40564 m .81389 .40219 L .81985 .40032 L F
.38553 .40549 m .38771 .40019 L .39103 .40363 L .663 .741 .908 r
F
.38553 .40549 m .3822 .40205 L .38771 .40019 L F
.2103 .4055 m .21197 .40018 L .21562 .40362 L .664 .741 .908 r
F
.2103 .4055 m .20663 .40206 L .21197 .40018 L F
.91122 .40551 m .91494 .40018 L .91726 .40363 L .664 .74 .907 r
F
.91122 .40551 m .90889 .40205 L .91494 .40018 L F
.73599 .40551 m .7392 .40019 L .74185 .40363 L .664 .742 .908 r
F
.73599 .40551 m .73332 .40207 L .7392 .40019 L F
.30507 .40535 m .30702 .40003 L .31049 .40348 L .664 .741 .908 r
F
.30507 .40535 m .30159 .4019 L .30702 .40003 L F
.8308 .40535 m .83429 .40003 L .83676 .40348 L F
.8308 .40535 m .82832 .40191 L .83429 .40003 L F
.2246 .4052 m .22631 .39989 L .22994 .40334 L F
.2246 .4052 m .22096 .40176 L .22631 .39989 L F
.39985 .40521 m .40208 .39989 L .40538 .40334 L .664 .742 .908 r
F
.39985 .40521 m .39655 .40177 L .40208 .39989 L F
.92563 .40521 m .9294 .3999 L .93169 .40335 L F
.92563 .40521 m .92333 .40177 L .9294 .3999 L F
.75037 .40521 m .75363 .39989 L .75625 .40334 L .664 .741 .907 r
F
.75037 .40521 m .74773 .40176 L .75363 .39989 L F
.63868 .48362 m .64006 .48388 L .64272 .48174 L 0 0 0 r
F
.64272 .48174 m .64006 .48388 L .64616 .49026 L .75 .296 .174 r
F
.64006 .48388 m .63729 .48302 L .64145 .48415 L 0 .425 .712 r
F
.64006 .48388 m .64145 .48415 L .64322 .48462 L F
.63698 .48442 m .64006 .48388 L .63868 .48362 L 0 0 0 r
F
.31938 .40506 m .32138 .39975 L .32482 .4032 L .663 .741 .908 r
F
.31938 .40506 m .31593 .40161 L .32138 .39975 L F
.8452 .40506 m .84873 .39975 L .85118 .4032 L .664 .741 .908 r
F
.8452 .40506 m .84274 .40162 L .84873 .39975 L F
.2389 .40491 m .24066 .39961 L .24426 .40306 L .663 .741 .908 r
F
.2389 .40491 m .23529 .40147 L .24066 .39961 L F
.76476 .40492 m .76806 .39961 L .77066 .40306 L F
.76476 .40492 m .76215 .40147 L .76806 .39961 L F
.41419 .40492 m .41646 .39962 L .41972 .40306 L F
.41419 .40492 m .41091 .40147 L .41646 .39962 L F
.51549 .48303 m .51238 .47796 L .51818 .43319 L .942 .709 .557 r
F
.3337 .40477 m .33574 .39947 L .33916 .40291 L .663 .741 .908 r
F
.3337 .40477 m .33028 .40133 L .33574 .39947 L F
.8596 .40478 m .86318 .39947 L .8656 .40291 L F
.8596 .40478 m .85717 .40133 L .86318 .39947 L F
.25321 .40463 m .25501 .39932 L .25858 .40277 L F
.25321 .40463 m .24963 .40118 L .25501 .39932 L F
.77915 .40465 m .78249 .39932 L .78507 .40278 L .664 .741 .907 r
F
.77915 .40465 m .77657 .40119 L .78249 .39932 L F
.42852 .40473 m .43074 .4026 L .43397 .40674 L .298 .577 .938 r
F
.42852 .40473 m .42527 .40127 L .43074 .4026 L F
.87401 .40448 m .87763 .39918 L .88002 .40262 L .663 .741 .908 r
F
.87401 .40448 m .87161 .40104 L .87763 .39918 L F
.34803 .40449 m .35011 .39917 L .3535 .40262 L .664 .742 .908 r
F
.34803 .40449 m .34463 .40105 L .35011 .39917 L F
.26752 .40434 m .26937 .39902 L .27291 .40248 L .664 .741 .908 r
F
.26752 .40434 m .26397 .4009 L .26937 .39902 L F
.79355 .40434 m .79693 .39903 L .79948 .40248 L .664 .742 .908 r
F
.79355 .40434 m .79099 .4009 L .79693 .39903 L F
.6587 .4169 m .65596 .41537 L .66401 .4666 L .958 .629 .343 r
F
.36236 .4042 m .36448 .39888 L .36785 .40233 L .663 .741 .908 r
F
.36236 .4042 m .35899 .40075 L .36448 .39888 L F
.88842 .4042 m .89209 .39888 L .89445 .40234 L .664 .741 .908 r
F
.88842 .4042 m .88605 .40076 L .89209 .39888 L F
.71307 .40425 m .71622 .39889 L .71892 .40234 L .665 .74 .906 r
F
.71307 .40425 m .71036 .40078 L .71622 .39889 L F
.70747 .41022 m .71036 .40078 L .71307 .40425 L .867 .822 .802 r
F
.28184 .40406 m .28373 .39874 L .28725 .4022 L .663 .741 .908 r
F
.28184 .40406 m .27832 .40061 L .28373 .39874 L F
.80795 .40406 m .81138 .39874 L .81389 .40219 L F
.80795 .40406 m .80542 .40061 L .81138 .39874 L F
.37669 .40391 m .37886 .39861 L .3822 .40205 L .662 .741 .908 r
F
.37669 .40391 m .37335 .40047 L .37886 .39861 L F
.90284 .40392 m .90655 .3986 L .90889 .40205 L .663 .741 .908 r
F
.90284 .40392 m .90049 .40047 L .90655 .3986 L F
.72746 .40392 m .73065 .39861 L .73332 .40207 L F
.72746 .40392 m .72478 .40048 L .73065 .39861 L F
.60258 .48458 m .59947 .47344 L .60481 .45455 L .836 .633 .629 r
F
.59947 .47344 m .60197 .45413 L .60481 .45455 L .874 .708 .672 r
F
.48929 .52054 m .48609 .51795 L .49252 .44624 L .957 .712 .526 r
F
.49252 .44624 m .49498 .44544 L .49795 .45436 L 0 0 0 r
F
.48609 .51795 m .48933 .44791 L .49252 .44624 L .964 .722 .522 r
F
.49252 .44624 m .48933 .44791 L .49498 .44544 L 0 0 0 r
F
.48933 .44791 m .4919 .43592 L .49498 .44544 L .983 .907 .627 r
F
.49498 .44544 m .4919 .43592 L .49201 .43652 L .937 .612 .168 r
F
.49498 .44544 m .49201 .43652 L .49728 .46666 L F
.49795 .45436 m .49498 .44544 L .49806 .45452 L 0 0 0 r
F
.64272 .48174 m .64616 .49026 L .64896 .49246 L .75 .296 .174 r
F
.29617 .40377 m .29809 .39845 L .30159 .4019 L .664 .741 .908 r
F
.29617 .40377 m .29266 .40033 L .29809 .39845 L F
.82235 .40378 m .82582 .39845 L .82832 .40191 L .663 .741 .907 r
F
.82235 .40378 m .81985 .40032 L .82582 .39845 L F
.70897 .49879 m .70665 .50375 L .70747 .41022 L .989 .729 .421 r
F
.70747 .41022 m .70479 .40746 L .71036 .40078 L .867 .822 .802 r
F
.70665 .50375 m .70479 .40746 L .70747 .41022 L .986 .722 .433 r
F
.21562 .40362 m .21731 .3983 L .22096 .40176 L .664 .741 .908 r
F
.21562 .40362 m .21197 .40018 L .21731 .3983 L F
.91726 .40363 m .92101 .39832 L .92333 .40177 L .663 .741 .908 r
F
.91726 .40363 m .91494 .40018 L .92101 .39832 L F
.74185 .40363 m .74509 .39831 L .74773 .40176 L .664 .742 .908 r
F
.74185 .40363 m .7392 .40019 L .74509 .39831 L F
.39103 .40363 m .39324 .39831 L .39655 .40177 L F
.39103 .40363 m .38771 .40019 L .39324 .39831 L F
.43718 .41091 m .4373 .48943 L .44039 .50171 L .961 .668 .433 r
F
.43718 .41091 m .43397 .40674 L .4373 .48943 L F
.83676 .40348 m .84028 .39816 L .84274 .40162 L .663 .741 .908 r
F
.83676 .40348 m .83429 .40003 L .84028 .39816 L F
.31049 .40348 m .31246 .39816 L .31593 .40161 L .664 .741 .908 r
F
.31049 .40348 m .30702 .40003 L .31246 .39816 L F
.40538 .40334 m .40762 .39802 L .41091 .40147 L .663 .741 .908 r
F
.40538 .40334 m .40208 .39989 L .40762 .39802 L F
.22994 .40334 m .23167 .39801 L .23529 .40147 L .664 .741 .908 r
F
.22994 .40334 m .22631 .39989 L .23167 .39801 L F
.75625 .40334 m .75953 .39802 L .76215 .40147 L .663 .741 .908 r
F
.75625 .40334 m .75363 .39989 L .75953 .39802 L F
.32482 .4032 m .32684 .39788 L .33028 .40133 L F
.32482 .4032 m .32138 .39975 L .32684 .39788 L F
.85118 .4032 m .85474 .39788 L .85717 .40133 L F
.85118 .4032 m .84873 .39975 L .85474 .39788 L F
.24426 .40306 m .24603 .39773 L .24963 .40118 L .664 .741 .908 r
F
.24426 .40306 m .24066 .39961 L .24603 .39773 L F
.77066 .40306 m .77398 .39774 L .77657 .40119 L .663 .741 .908 r
F
.77066 .40306 m .76806 .39961 L .77398 .39774 L F
.41972 .40306 m .42201 .39779 L .42527 .40127 L .66 .741 .909 r
F
.41972 .40306 m .41646 .39962 L .42201 .39779 L F
.8656 .40291 m .8692 .39759 L .87161 .40104 L .663 .742 .908 r
F
.8656 .40291 m .86318 .39947 L .8692 .39759 L F
.33916 .40291 m .34121 .39759 L .34463 .40105 L .664 .742 .908 r
F
.33916 .40291 m .33574 .39947 L .34121 .39759 L F
.64322 .48462 m .6449 .44439 L .64799 .4548 L .889 .664 .59 r
F
.64322 .48462 m .6401 .4742 L .6449 .44439 L F
.6449 .44439 m .64188 .43615 L .64757 .43194 L .701 .593 .732 r
F
.6401 .4742 m .64188 .43615 L .6449 .44439 L .907 .683 .587 r
F
.25858 .40277 m .2604 .39744 L .26397 .4009 L .664 .741 .908 r
F
.25858 .40277 m .25501 .39932 L .2604 .39744 L F
.78507 .40278 m .78843 .39744 L .79099 .4009 L F
.78507 .40278 m .78249 .39932 L .78843 .39744 L F
.3535 .40262 m .3556 .39729 L .35899 .40075 L F
.3535 .40262 m .35011 .39917 L .3556 .39729 L F
.88002 .40262 m .88367 .3973 L .88605 .40076 L .664 .742 .908 r
F
.88002 .40262 m .87763 .39918 L .88367 .3973 L F
.27291 .40248 m .27477 .39715 L .27832 .40061 L .664 .741 .908 r
F
.27291 .40248 m .26937 .39902 L .27477 .39715 L F
.79948 .40248 m .80288 .39715 L .80542 .40061 L .663 .741 .908 r
F
.79948 .40248 m .79693 .39903 L .80288 .39715 L F
.64616 .49026 m .64799 .4548 L .65115 .46676 L .934 .713 .58 r
F
.64616 .49026 m .64322 .48462 L .64799 .4548 L F
.36785 .40233 m .36999 .39702 L .37335 .40047 L .663 .741 .908 r
F
.36785 .40233 m .36448 .39888 L .36999 .39702 L F
.89445 .40234 m .89814 .39701 L .90049 .40047 L .664 .741 .908 r
F
.89445 .40234 m .89209 .39888 L .89814 .39701 L F
.71892 .40234 m .72209 .39702 L .72478 .40048 L .663 .742 .908 r
F
.71892 .40234 m .71622 .39889 L .72209 .39702 L F
.81389 .40219 m .81734 .39687 L .81985 .40032 L F
.81389 .40219 m .81138 .39874 L .81734 .39687 L F
.28725 .4022 m .28915 .39687 L .29266 .40033 L .663 .741 .908 r
F
.28725 .4022 m .28373 .39874 L .28915 .39687 L F
.6401 .4742 m .63706 .46577 L .64188 .43615 L .907 .683 .587 r
F
.64188 .43615 m .63889 .42848 L .64489 .43269 L .314 .38 .77 r
F
.64489 .43269 m .64218 .43328 L .64221 .43342 L .944 .606 .354 r
F
.64188 .43615 m .64489 .43269 L .64755 .43195 L .314 .38 .77 r
F
.64489 .43269 m .64221 .43342 L .64959 .47342 L .944 .606 .354 r
F
.64755 .43195 m .64489 .43269 L .64757 .43194 L .314 .38 .77 r
F
.63706 .46577 m .63889 .42848 L .64188 .43615 L .911 .688 .587 r
F
.51273 .61 m .50968 .59539 L .51534 .58931 L .682 .522 .663 r
F
.50968 .59539 m .51224 .58948 L .51534 .58931 L .264 .239 .643 r
F
.90889 .40205 m .91261 .39673 L .91494 .40018 L .663 .741 .908 r
F
.90889 .40205 m .90655 .3986 L .91261 .39673 L F
.3822 .40205 m .38438 .39674 L .38771 .40019 L .664 .742 .909 r
F
.3822 .40205 m .37886 .39861 L .38438 .39674 L F
.20663 .40206 m .2083 .39672 L .21197 .40018 L .664 .741 .908 r
F
.20663 .40206 m .20296 .3986 L .2083 .39672 L F
.73332 .40207 m .73654 .39674 L .7392 .40019 L .663 .741 .907 r
F
.73332 .40207 m .73065 .39861 L .73654 .39674 L F
.30159 .4019 m .30353 .39657 L .30702 .40003 L .664 .741 .908 r
F
.30159 .4019 m .29809 .39845 L .30353 .39657 L F
.82832 .40191 m .83181 .39658 L .83429 .40003 L .663 .741 .908 r
F
.82832 .40191 m .82582 .39845 L .83181 .39658 L F
.51181 .55591 m .5087 .55474 L .51437 .55054 L .809 .913 .91 r
F
.506 .58863 m .5087 .55474 L .51181 .55591 L .946 .736 .586 r
F
.22096 .40176 m .22267 .39643 L .22631 .39989 L .664 .741 .908 r
F
.22096 .40176 m .21731 .3983 L .22267 .39643 L F
.74773 .40176 m .75099 .39643 L .75363 .39989 L F
.74773 .40176 m .74509 .39831 L .75099 .39643 L F
.39655 .40177 m .39878 .39643 L .40208 .39989 L .664 .742 .908 r
F
.39655 .40177 m .39324 .39831 L .39878 .39643 L F
.92333 .40177 m .92709 .39643 L .9294 .3999 L .664 .741 .908 r
F
.92333 .40177 m .92101 .39832 L .92709 .39643 L F
.72629 .63688 m .72355 .63484 L .7204 .47642 L .976 .7 .442 r
F
.31593 .40161 m .31792 .39629 L .32138 .39975 L .663 .741 .908 r
F
.31593 .40161 m .31246 .39816 L .31792 .39629 L F
.84274 .40162 m .84628 .39629 L .84873 .39975 L F
.84274 .40162 m .84028 .39816 L .84628 .39629 L F
.64896 .49246 m .65115 .46676 L .65425 .47742 L .963 .767 .592 r
F
.65174 .49429 m .64896 .49246 L .65425 .47742 L .955 .807 .658 r
F
.64896 .49246 m .64616 .49026 L .65115 .46676 L .963 .767 .592 r
F
.65254 .47913 m .64959 .47342 L .65257 .47933 L .944 .606 .354 r
F
.65176 .47438 m .64938 .47157 L .65187 .4751 L F
.64489 .43269 m .64926 .47049 L .65176 .47438 L F
.64926 .47049 m .64938 .47157 L .65176 .47438 L F
.64757 .43194 m .64489 .43269 L .65257 .47933 L .947 .617 .366 r
F
.63889 .42848 m .64218 .43328 L .64489 .43269 L 0 0 .447 r
F
.64218 .43328 m .64662 .46794 L .64959 .47342 L .944 .598 .328 r
F
.64218 .43328 m .63943 .43291 L .64662 .46794 L F
.64656 .46764 m .64363 .46203 L .64662 .46794 L .942 .586 .298 r
F
.6462 .46586 m .64354 .4614 L .64626 .46617 L F
.63943 .43291 m .64352 .46126 L .6462 .46586 L F
.64352 .46126 m .64354 .4614 L .6462 .46586 L F
.63706 .46577 m .63403 .4578 L .63889 .42848 L .911 .688 .587 r
F
.63403 .4578 m .63594 .4223 L .63889 .42848 L .893 .673 .599 r
F
.63403 .4578 m .63096 .44873 L .63594 .4223 L F
.63096 .44873 m .63303 .41747 L .63594 .4223 L .901 .69 .607 r
F
.64059 .45653 m .63775 .45369 L .64066 .4568 L .942 .575 .226 r
F
.63378 .42979 m .63775 .45369 L .64059 .45653 L F
.63096 .44873 m .62794 .44126 L .63303 .41747 L .901 .69 .607 r
F
.62794 .44126 m .63012 .41297 L .63303 .41747 L .921 .716 .609 r
F
.63089 .42661 m .63486 .45134 L .63775 .45369 L .944 .582 .221 r
F
.63775 .45369 m .63486 .45134 L .6349 .45083 L .972 .731 .512 r
F
.63889 .42848 m .63594 .4223 L .64218 .43328 L 0 0 .447 r
F
.63594 .4223 m .63943 .43291 L .64218 .43328 L .824 .42 0 r
F
.63594 .4223 m .63303 .41747 L .63943 .43291 L F
.63303 .41747 m .63663 .43185 L .63943 .43291 L .891 .498 .054 r
F
.63303 .41747 m .63012 .41297 L .63663 .43185 L F
.63012 .41297 m .63378 .42979 L .63663 .43185 L .916 .529 .122 r
F
.63943 .43291 m .63663 .43185 L .64363 .46203 L .942 .586 .298 r
F
.64331 .46063 m .64066 .4568 L .64363 .46203 L .941 .575 .256 r
F
.63663 .43185 m .64062 .45655 L .64331 .46063 L F
.64062 .45655 m .64066 .4568 L .64331 .46063 L F
.63775 .45369 m .6349 .45083 L .63513 .44822 L .972 .731 .512 r
F
.63663 .43185 m .63378 .42979 L .64066 .4568 L .941 .575 .256 r
F
.63378 .42979 m .63089 .42661 L .63775 .45368 L .942 .575 .226 r
F
.63775 .45368 m .63775 .45368 L .63775 .45369 L F
.63378 .42979 m .63775 .45368 L .63775 .45368 L F
.62546 .46041 m .62794 .44126 L .63096 .44873 L .851 .687 .678 r
F
.62794 .44126 m .62498 .43565 L .63012 .41297 L .921 .716 .609 r
F
.62498 .43565 m .62722 .40895 L .63012 .41297 L .923 .723 .615 r
F
.62498 .43565 m .62202 .43048 L .62722 .40895 L F
.63176 .44749 m .62899 .44547 L .63193 .44821 L .945 .598 .195 r
F
.62245 .45372 m .62498 .43565 L .62794 .44126 L .895 .737 .678 r
F
.62245 .45372 m .6195 .44907 L .62498 .43565 L F
.62202 .43048 m .62433 .40545 L .62722 .40895 L .931 .737 .618 r
F
.62202 .43048 m .61907 .42609 L .62433 .40545 L F
.61907 .42609 m .62142 .40203 L .62433 .40545 L .953 .764 .609 r
F
.6195 .44907 m .62202 .43048 L .62498 .43565 L .908 .746 .669 r
F
.61907 .42609 m .61616 .42325 L .62104 .40355 L .953 .764 .609 r
F
.62124 .40391 m .62104 .40355 L .62142 .40203 L F
.61907 .42609 m .62104 .40355 L .62124 .40391 L F
.61616 .42325 m .61852 .39882 L .62142 .40203 L .97 .781 .592 r
F
.61857 .39898 m .62199 .41206 L .625 .41823 L .895 .476 .1 r
F
.61852 .39882 m .61855 .39894 L .61857 .39898 L F
.61855 .39894 m .62199 .41206 L .61857 .39898 L F
.6195 .44907 m .61655 .4448 L .62202 .43048 L .908 .746 .669 r
F
.61655 .4448 m .61907 .42609 L .62202 .43048 L .902 .74 .671 r
F
.61893 .40468 m .62325 .44522 L .62612 .44485 L .962 .635 .257 r
F
.62612 .44485 m .62325 .44522 L .62347 .44161 L .982 .733 .479 r
F
.625 .41823 m .62895 .44518 L .63163 .44693 L .945 .598 .195 r
F
.62722 .40895 m .62433 .40545 L .63089 .42661 L .923 .536 .151 r
F
.62433 .40545 m .62796 .42284 L .63089 .42661 L .921 .534 .15 r
F
.62433 .40545 m .62142 .40203 L .62796 .42284 L F
.62142 .40203 m .625 .41823 L .62796 .42284 L .915 .52 .137 r
F
.62142 .40203 m .61852 .39882 L .625 .41823 L F
.62796 .42284 m .625 .41823 L .63163 .44693 L .945 .587 .209 r
F
.63175 .44706 m .63163 .44693 L .63193 .44821 L F
.62796 .42284 m .63163 .44693 L .63175 .44706 L F
.62546 .46041 m .62245 .45372 L .62794 .44126 L .851 .687 .678 r
F
.62199 .41206 m .62612 .44485 L .62899 .44547 L .952 .618 .217 r
F
.62199 .41206 m .61893 .40468 L .62612 .44485 L F
.62614 .44335 m .62347 .44161 L .62371 .4377 L .982 .733 .479 r
F
.625 .41823 m .62199 .41206 L .62892 .44514 L .945 .598 .195 r
F
.62895 .44518 m .62892 .44514 L .62899 .44547 L F
.625 .41823 m .62892 .44514 L .62895 .44518 L F
.62619 .44059 m .62532 .43959 L .62722 .37996 L .982 .733 .479 r
F
.62532 .43959 m .62371 .4377 L .62374 .43714 L F
.62532 .43959 m .62374 .43714 L .62722 .37996 L F
.62614 .44335 m .62371 .4377 L .62619 .44059 L F
.62612 .44485 m .62347 .44161 L .62614 .44335 L F
.63163 .44693 m .62899 .44547 L .63176 .44749 L .945 .598 .195 r
F
.62895 .44518 m .62899 .44547 L .63163 .44693 L F
.62899 .44547 m .62612 .44485 L .62621 .44344 L .98 .733 .49 r
F
.63012 .41297 m .62722 .40895 L .63378 .42979 L .916 .529 .122 r
F
.62722 .40895 m .63089 .42661 L .63378 .42979 L .923 .536 .151 r
F
.63089 .42661 m .62796 .42284 L .63449 .44983 L .944 .582 .221 r
F
.63464 .44998 m .63449 .44983 L .63486 .45134 L F
.63089 .42661 m .63449 .44983 L .63464 .44998 L F
.62899 .44547 m .62621 .44344 L .62634 .44158 L .98 .733 .49 r
F
.62796 .42284 m .63193 .44821 L .63486 .45134 L .945 .587 .209 r
F
.62902 .44428 m .62634 .44158 L .63022 .3861 L .98 .733 .49 r
F
.62899 .44547 m .62634 .44158 L .62902 .44428 L F
.63193 .44821 m .62899 .44547 L .62906 .44459 L .971 .726 .509 r
F
.63194 .4476 m .62906 .44459 L .63323 .39248 L F
.63193 .44821 m .62906 .44459 L .63194 .4476 L F
.63616 .39836 m .63323 .39248 L .6362 .39784 L F
.63193 .44821 m .63323 .39248 L .63616 .39836 L F
.62899 .44547 m .63022 .3861 L .63323 .39248 L .98 .733 .49 r
F
.63323 .39248 m .63022 .3861 L .6303 .38659 L .961 .629 .26 r
F
.63779 .45225 m .63513 .44822 L .63897 .40362 L .972 .731 .512 r
F
.63903 .40372 m .63897 .40362 L .63906 .40263 L F
.63779 .45225 m .63897 .40362 L .63903 .40372 L F
.63323 .39248 m .6303 .38659 L .63089 .3902 L .961 .629 .26 r
F
.63486 .45134 m .6362 .39784 L .63912 .40193 L .968 .725 .514 r
F
.63486 .45134 m .63193 .44821 L .63618 .39808 L F
.63619 .39811 m .63618 .39808 L .6362 .39784 L F
.63486 .45134 m .63618 .39808 L .63619 .39811 L F
.62612 .44485 m .62722 .37996 L .63022 .3861 L .982 .733 .479 r
F
.63022 .3861 m .62722 .37996 L .62783 .3842 L .966 .64 .292 r
F
.63047 .3886 m .62783 .3842 L .63499 .43395 L F
.63022 .3861 m .62783 .3842 L .63047 .3886 L F
.63346 .39446 m .63089 .3902 L .63777 .43226 L .961 .629 .26 r
F
.63323 .39248 m .63089 .3902 L .63346 .39446 L F
.6362 .39784 m .63323 .39248 L .63361 .39448 L .955 .613 .243 r
F
.63779 .45225 m .63906 .40263 L .6391 .40269 L .972 .731 .512 r
F
.64067 .45636 m .63793 .45165 L .64199 .40586 L .968 .726 .518 r
F
.642 .40588 m .64199 .40586 L .64201 .40565 L F
.64067 .45636 m .64199 .40586 L .642 .40588 L F
.63912 .40193 m .6362 .39784 L .63633 .39842 L .952 .6 .244 r
F
.6391 .40269 m .63906 .40263 L .63912 .40193 L .972 .731 .512 r
F
.64488 .40928 m .64201 .40565 L .64489 .40919 L .968 .726 .518 r
F
.6407 .4564 m .64201 .40565 L .64488 .40928 L F
.63775 .45369 m .63912 .40193 L .64201 .40565 L .972 .731 .512 r
F
.64201 .40565 m .63912 .40193 L .63913 .40199 L .95 .596 .244 r
F
.64067 .45636 m .64201 .40565 L .6407 .4564 L .968 .726 .518 r
F
.64354 .4614 m .64363 .46203 L .64626 .46617 L .942 .586 .298 r
F
.64363 .46203 m .6407 .4564 L .64489 .40919 L .956 .712 .529 r
F
.64764 .41248 m .64489 .40919 L .64771 .41164 L F
.64365 .46179 m .64488 .40929 L .64764 .41248 L F
.64488 .40929 m .64489 .40919 L .64764 .41248 L F
.64201 .40565 m .63913 .40199 L .63932 .40285 L .95 .596 .244 r
F
.64364 .46177 m .64489 .40919 L .64365 .46179 L .956 .712 .529 r
F
.64626 .46617 m .64363 .46203 L .64656 .46764 L .942 .586 .298 r
F
.64662 .46794 m .64363 .46203 L .64771 .41164 L .953 .707 .527 r
F
.64207 .40603 m .63932 .40285 L .64627 .43447 L .95 .596 .244 r
F
.64201 .40565 m .63932 .40285 L .64207 .40603 L F
.63914 .40212 m .63633 .39842 L .64338 .43178 L .952 .6 .244 r
F
.63912 .40193 m .63633 .39842 L .63914 .40212 L F
.63629 .39848 m .63361 .39448 L .64055 .43102 L .955 .613 .243 r
F
.6362 .39784 m .63361 .39448 L .63629 .39848 L F
.63775 .45369 m .63513 .44822 L .63779 .45225 L .972 .731 .512 r
F
.64066 .4568 m .63775 .45369 L .63793 .45165 L .968 .726 .518 r
F
.64066 .4568 m .63793 .45165 L .64067 .45636 L F
.64066 .4568 m .64067 .45636 L .6407 .4564 L F
.64363 .46203 m .64066 .4568 L .6407 .4564 L .956 .712 .529 r
F
.64363 .46203 m .64364 .46177 L .64365 .46179 L F
.65548 .48479 m .65257 .47933 L .65554 .48522 L .947 .617 .366 r
F
.64757 .43194 m .65234 .47715 L .65484 .48055 L F
.64938 .47157 m .64959 .47342 L .65187 .4751 L .944 .606 .354 r
F
.65042 .41363 m .64771 .41164 L .65047 .41286 L .953 .707 .527 r
F
.65032 .41501 m .6477 .41205 L .65036 .41443 L F
.64664 .4677 m .64769 .41236 L .65032 .41501 L F
.64769 .41236 m .6477 .41205 L .65032 .41501 L F
.64489 .40919 m .64201 .40565 L .6423 .40694 L .949 .594 .244 r
F
.64959 .47342 m .64664 .4677 L .65047 .41286 L .957 .708 .519 r
F
.64663 .46769 m .6477 .41184 L .64664 .4677 L .953 .707 .527 r
F
.6477 .41184 m .64771 .41164 L .6477 .41184 L F
.64769 .41236 m .64769 .41236 L .64664 .4677 L F
.64495 .4096 m .6423 .40694 L .64916 .43761 L .949 .594 .244 r
F
.6477 .41184 m .6477 .41184 L .64769 .41236 L .953 .707 .527 r
F
.6477 .41184 m .64769 .41236 L .64769 .41236 L F
.6423 .40694 m .64627 .43447 L .64916 .43761 L .95 .596 .244 r
F
.64201 .40565 m .64218 .40683 L .6423 .40694 L F
.64218 .40683 m .64627 .43447 L .6423 .40694 L F
.64489 .40919 m .6423 .40694 L .64495 .4096 L .949 .594 .244 r
F
.65304 .41685 m .65047 .41286 L .65321 .41405 L .957 .708 .519 r
F
.64959 .47342 m .65044 .41505 L .65296 .41818 L F
.6477 .41205 m .64771 .41164 L .65036 .41443 L .953 .707 .527 r
F
.65484 .48055 m .65255 .47914 L .65548 .48479 L .947 .617 .366 r
F
.65234 .47715 m .65255 .47914 L .65484 .48055 L F
.65255 .47914 m .65257 .47933 L .65548 .48479 L F
.65187 .4751 m .64959 .47342 L .65254 .47913 L .944 .606 .354 r
F
.65257 .47933 m .64959 .47342 L .65322 .41398 L .957 .705 .514 r
F
.65554 .48522 m .65257 .47933 L .65554 .48522 L .947 .617 .366 r
F
.65554 .48522 m .65257 .47933 L .65596 .41537 L .958 .704 .509 r
F
.65257 .47933 m .65322 .41398 L .65596 .41537 L .957 .705 .514 r
F
.64772 .41168 m .65204 .44066 L .65496 .44514 L .948 .591 .268 r
F
.64771 .41164 m .64771 .41167 L .64772 .41168 L F
.64771 .41167 m .65204 .44066 L .64772 .41168 L F
.65296 .41818 m .65045 .41454 L .65304 .41685 L .957 .708 .519 r
F
.65044 .41505 m .65045 .41454 L .65296 .41818 L F
.65045 .41454 m .65047 .41286 L .65304 .41685 L F
.645 .40969 m .64916 .43761 L .65204 .44066 L .949 .594 .244 r
F
.64498 .40963 m .64499 .40968 L .645 .40969 L F
.64499 .40968 m .64916 .43761 L .645 .40969 L F
.64489 .40919 m .64495 .4096 L .64498 .40963 L F
.64495 .4096 m .64916 .43761 L .64498 .40963 L F
.65036 .41443 m .64771 .41164 L .65042 .41363 L .953 .707 .527 r
F
.64771 .41164 m .64489 .40919 L .64498 .40963 L .948 .591 .268 r
F
.64771 .41164 m .64498 .40963 L .65204 .44066 L F
.65047 .41286 m .64771 .41164 L .64772 .41168 L .947 .595 .302 r
F
.65047 .41286 m .64772 .41168 L .65496 .44514 L F
.65321 .41405 m .65047 .41286 L .65322 .41398 L .957 .708 .519 r
F
.64959 .47342 m .6495 .47324 L .64959 .47342 L F
.6495 .47324 m .64664 .4677 L .64959 .47342 L F
.64662 .46794 m .64663 .46769 L .64664 .4677 L .953 .707 .527 r
F
.64959 .47342 m .64662 .46794 L .64664 .4677 L .957 .708 .519 r
F
.65257 .47933 m .64959 .47342 L .64959 .47342 L .957 .705 .514 r
F
.23529 .40147 m .23704 .39614 L .24066 .39961 L .663 .741 .908 r
F
.23529 .40147 m .23167 .39801 L .23704 .39614 L F
.76215 .40147 m .76545 .39614 L .76806 .39961 L .664 .742 .908 r
F
.76215 .40147 m .75953 .39802 L .76545 .39614 L F
.41091 .40147 m .41318 .39616 L .41646 .39962 L .663 .741 .908 r
F
.41091 .40147 m .40762 .39802 L .41318 .39616 L F
.85717 .40133 m .86075 .39601 L .86318 .39947 L F
.85717 .40133 m .85474 .39788 L .86075 .39601 L F
.33028 .40133 m .33231 .39601 L .33574 .39947 L F
.33028 .40133 m .32684 .39788 L .33231 .39601 L F
.24963 .40118 m .25142 .39585 L .25501 .39932 L .664 .741 .908 r
F
.24963 .40118 m .24603 .39773 L .25142 .39585 L F
.77657 .40119 m .77991 .39585 L .78249 .39932 L F
.77657 .40119 m .77398 .39774 L .77991 .39585 L F
.42527 .40127 m .4275 .39852 L .43074 .4026 L .394 .628 .948 r
F
.42527 .40127 m .42201 .39779 L .4275 .39852 L F
.87161 .40104 m .87523 .39571 L .87763 .39918 L .664 .742 .908 r
F
.87161 .40104 m .8692 .39759 L .87523 .39571 L F
.34463 .40105 m .3467 .39571 L .35011 .39917 L F
.34463 .40105 m .34121 .39759 L .3467 .39571 L F
.26397 .4009 m .26581 .39556 L .26937 .39902 L .664 .741 .908 r
F
.26397 .4009 m .2604 .39744 L .26581 .39556 L F
.79099 .4009 m .79437 .39556 L .79693 .39903 L F
.79099 .4009 m .78843 .39744 L .79437 .39556 L F
.35899 .40075 m .3611 .39542 L .36448 .39888 L .663 .741 .908 r
F
.35899 .40075 m .3556 .39729 L .3611 .39542 L F
.88605 .40076 m .88971 .39541 L .89209 .39888 L .664 .741 .908 r
F
.88605 .40076 m .88367 .3973 L .88971 .39541 L F
.71036 .40078 m .71351 .39542 L .71622 .39889 L .666 .743 .908 r
F
.71036 .40078 m .70765 .39734 L .71351 .39542 L F
.70479 .40746 m .70765 .39734 L .71036 .40078 L .869 .809 .788 r
F
.27832 .40061 m .28019 .39527 L .28373 .39874 L .663 .741 .908 r
F
.27832 .40061 m .27477 .39715 L .28019 .39527 L F
.80542 .40061 m .80885 .39528 L .81138 .39874 L F
.80542 .40061 m .80288 .39715 L .80885 .39528 L F
.69127 .45571 m .6972 .50528 L .69937 .49686 L .9 .573 .419 r
F
.69127 .45571 m .6891 .464 L .6972 .50528 L F
.43397 .40674 m .43422 .47703 L .4373 .48943 L .961 .666 .427 r
F
.43397 .40674 m .43074 .4026 L .43422 .47703 L F
.90049 .40047 m .9042 .39515 L .90655 .3986 L .662 .741 .908 r
F
.90049 .40047 m .89814 .39701 L .9042 .39515 L F
.37335 .40047 m .3755 .39516 L .37886 .39861 L .662 .741 .909 r
F
.37335 .40047 m .36999 .39702 L .3755 .39516 L F
.72478 .40048 m .72797 .39514 L .73065 .39861 L .663 .741 .908 r
F
.72478 .40048 m .72209 .39702 L .72797 .39514 L F
.81985 .40032 m .82332 .39499 L .82582 .39845 L .664 .742 .908 r
F
.81985 .40032 m .81734 .39687 L .82332 .39499 L F
.29266 .40033 m .29458 .39498 L .29809 .39845 L F
.29266 .40033 m .28915 .39687 L .29458 .39498 L F
.21197 .40018 m .21365 .39484 L .21731 .3983 L .664 .741 .908 r
F
.21197 .40018 m .2083 .39672 L .21365 .39484 L F
.91494 .40018 m .91869 .39484 L .92101 .39832 L .664 .742 .908 r
F
.91494 .40018 m .91261 .39673 L .91869 .39484 L F
.7392 .40019 m .74243 .39485 L .74509 .39831 L F
.7392 .40019 m .73654 .39674 L .74243 .39485 L F
.38771 .40019 m .38991 .39484 L .39324 .39831 L .665 .742 .908 r
F
.38771 .40019 m .38438 .39674 L .38991 .39484 L F
.30702 .40003 m .30898 .39469 L .31246 .39816 L .664 .741 .908 r
F
.30702 .40003 m .30353 .39657 L .30898 .39469 L F
.83429 .40003 m .8378 .3947 L .84028 .39816 L F
.83429 .40003 m .83181 .39658 L .8378 .3947 L F
.70358 .47908 m .71437 .61281 L .71758 .62285 L .948 .641 .423 r
F
.70358 .47908 m .70151 .48838 L .71437 .61281 L F
.70665 .50375 m .70418 .5065 L .70479 .40746 L .986 .722 .433 r
F
.70479 .40746 m .70208 .40446 L .70765 .39734 L .869 .809 .788 r
F
.70418 .5065 m .70208 .40446 L .70479 .40746 L .984 .718 .436 r
F
.40208 .39989 m .40432 .39455 L .40762 .39802 L .663 .741 .908 r
F
.40208 .39989 m .39878 .39643 L .40432 .39455 L F
.22631 .39989 m .22804 .39455 L .23167 .39801 L .664 .741 .908 r
F
.22631 .39989 m .22267 .39643 L .22804 .39455 L F
.75363 .39989 m .7569 .39455 L .75953 .39802 L .663 .741 .908 r
F
.75363 .39989 m .75099 .39643 L .7569 .39455 L F
.52949 .43194 m .5321 .42657 L .53515 .42818 L .818 .934 .907 r
F
.84873 .39975 m .85229 .39441 L .85474 .39788 L .663 .742 .908 r
F
.84873 .39975 m .84628 .39629 L .85229 .39441 L F
.32138 .39975 m .32338 .39441 L .32684 .39788 L .663 .741 .908 r
F
.32138 .39975 m .31792 .39629 L .32338 .39441 L F
.65596 .41537 m .65322 .41398 L .661 .45963 L .956 .621 .334 r
F
.24066 .39961 m .24243 .39426 L .24603 .39773 L .664 .741 .908 r
F
.24066 .39961 m .23704 .39614 L .24243 .39426 L F
.76806 .39961 m .77137 .39427 L .77398 .39774 L .663 .741 .908 r
F
.76806 .39961 m .76545 .39614 L .77137 .39427 L F
.41646 .39962 m .41874 .39431 L .42201 .39779 L .661 .741 .909 r
F
.41646 .39962 m .41318 .39616 L .41874 .39431 L F
.86318 .39947 m .86678 .39411 L .8692 .39759 L .664 .742 .908 r
F
.86318 .39947 m .86075 .39601 L .86678 .39411 L F
.33574 .39947 m .33779 .39412 L .34121 .39759 L F
.33574 .39947 m .33231 .39601 L .33779 .39412 L F
.5963 .4568 m .59328 .45044 L .5984 .41906 L .927 .704 .58 r
F
.59328 .45044 m .59547 .41565 L .5984 .41906 L .975 .758 .547 r
F
.25501 .39932 m .25682 .39397 L .2604 .39744 L .663 .741 .908 r
F
.25501 .39932 m .25142 .39585 L .25682 .39397 L F
.78249 .39932 m .78585 .39397 L .78843 .39744 L .664 .741 .908 r
F
.78249 .39932 m .77991 .39585 L .78585 .39397 L F
.35011 .39917 m .3522 .39382 L .3556 .39729 L F
.35011 .39917 m .3467 .39571 L .3522 .39382 L F
.87763 .39918 m .88127 .39383 L .88367 .3973 L F
.87763 .39918 m .87523 .39571 L .88127 .39383 L F
.63172 .50164 m .62874 .49468 L .63429 .4859 L .804 .663 .708 r
F
.63429 .4859 m .63729 .48302 L .64006 .48388 L .528 .789 .993 r
F
.63429 .4859 m .63146 .48381 L .63729 .48302 L F
.26937 .39902 m .27122 .39368 L .27477 .39715 L .664 .741 .908 r
F
.26937 .39902 m .26581 .39556 L .27122 .39368 L F
.79693 .39903 m .80033 .39368 L .80288 .39715 L .663 .741 .908 r
F
.79693 .39903 m .79437 .39556 L .80033 .39368 L F
.89209 .39888 m .89577 .39355 L .89814 .39701 L F
.89209 .39888 m .88971 .39541 L .89577 .39355 L F
.36448 .39888 m .36661 .39355 L .36999 .39702 L F
.36448 .39888 m .3611 .39542 L .36661 .39355 L F
.71622 .39889 m .71939 .39355 L .72209 .39702 L F
.71622 .39889 m .71351 .39542 L .71939 .39355 L F
.28373 .39874 m .28562 .3934 L .28915 .39687 L F
.28373 .39874 m .28019 .39527 L .28562 .3934 L F
.81138 .39874 m .81482 .3934 L .81734 .39687 L F
.81138 .39874 m .80885 .39528 L .81482 .3934 L F
.50617 .46305 m .50306 .45392 L .50895 .41569 L .909 .679 .578 r
F
.50895 .41569 m .51147 .41913 L .51459 .41771 L 0 0 .427 r
F
.50895 .41569 m .50585 .41101 L .51147 .41913 L F
.50306 .45392 m .50585 .41101 L .50895 .41569 L .892 .667 .59 r
F
.90655 .3986 m .91027 .39324 L .91261 .39673 L .665 .743 .908 r
F
.90655 .3986 m .9042 .39515 L .91027 .39324 L F
.20296 .3986 m .20462 .39325 L .2083 .39672 L .664 .741 .908 r
F
.20296 .3986 m .19927 .39513 L .20462 .39325 L F
.73065 .39861 m .73386 .39325 L .73654 .39674 L F
.73065 .39861 m .72797 .39514 L .73386 .39325 L F
.37886 .39861 m .38103 .39326 L .38438 .39674 L .665 .742 .908 r
F
.37886 .39861 m .3755 .39516 L .38103 .39326 L F
.29809 .39845 m .30003 .3931 L .30353 .39657 L .664 .741 .908 r
F
.29809 .39845 m .29458 .39498 L .30003 .3931 L F
.82582 .39845 m .82931 .3931 L .83181 .39658 L .664 .742 .908 r
F
.82582 .39845 m .82332 .39499 L .82931 .3931 L F
.21731 .3983 m .21901 .39295 L .22267 .39643 L .664 .741 .908 r
F
.21731 .3983 m .21365 .39484 L .21901 .39295 L F
.74509 .39831 m .74834 .39296 L .75099 .39643 L .664 .742 .908 r
F
.74509 .39831 m .74243 .39485 L .74834 .39296 L F
.39324 .39831 m .39546 .39295 L .39878 .39643 L .664 .741 .908 r
F
.39324 .39831 m .38991 .39484 L .39546 .39295 L F
.92101 .39832 m .92478 .39296 L .92709 .39643 L F
.92101 .39832 m .91869 .39484 L .92478 .39296 L F
.31246 .39816 m .31444 .39281 L .31792 .39629 L .663 .741 .908 r
F
.31246 .39816 m .30898 .39469 L .31444 .39281 L F
.84028 .39816 m .84381 .39282 L .84628 .39629 L F
.84028 .39816 m .8378 .3947 L .84381 .39282 L F
.23167 .39801 m .23341 .39267 L .23704 .39614 L F
.23167 .39801 m .22804 .39455 L .23341 .39267 L F
.40762 .39802 m .40988 .39268 L .41318 .39616 L F
.40762 .39802 m .40432 .39455 L .40988 .39268 L F
.75953 .39802 m .76283 .39267 L .76545 .39614 L F
.75953 .39802 m .7569 .39455 L .76283 .39267 L F
.85474 .39788 m .85831 .39252 L .86075 .39601 L .664 .742 .908 r
F
.85474 .39788 m .85229 .39441 L .85831 .39252 L F
.32684 .39788 m .32886 .39253 L .33231 .39601 L .663 .741 .908 r
F
.32684 .39788 m .32338 .39441 L .32886 .39253 L F
.62264 .47699 m .61949 .46472 L .62559 .47362 L .206 .227 .662 r
F
.61949 .46472 m .6226 .46725 L .62559 .47362 L 0 0 .551 r
F
.50115 .46165 m .49806 .45452 L .50366 .46035 L .066 .239 .732 r
F
.24603 .39773 m .24782 .39237 L .25142 .39585 L .664 .742 .908 r
F
.24603 .39773 m .24243 .39426 L .24782 .39237 L F
.77398 .39774 m .77732 .39238 L .77991 .39585 L F
.77398 .39774 m .77137 .39427 L .77732 .39238 L F
.42201 .39779 m .42425 .39447 L .4275 .39852 L .469 .665 .948 r
F
.42201 .39779 m .41874 .39431 L .42425 .39447 L F
.48609 .51795 m .48286 .51725 L .48933 .44791 L .964 .722 .522 r
F
.48933 .44791 m .48612 .45039 L .4919 .43592 L .983 .907 .627 r
F
.48286 .51725 m .48612 .45039 L .48933 .44791 L .967 .726 .521 r
F
.8692 .39759 m .87282 .39223 L .87523 .39571 L .663 .741 .908 r
F
.8692 .39759 m .86678 .39411 L .87282 .39223 L F
.34121 .39759 m .34328 .39223 L .3467 .39571 L .664 .741 .908 r
F
.34121 .39759 m .33779 .39412 L .34328 .39223 L F
.43074 .4026 m .43115 .46459 L .43422 .47703 L .961 .662 .42 r
F
.43074 .4026 m .4275 .39852 L .43115 .46459 L F
.2604 .39744 m .26223 .39208 L .26581 .39556 L .664 .741 .908 r
F
.2604 .39744 m .25682 .39397 L .26223 .39208 L F
.78843 .39744 m .79181 .39208 L .79437 .39556 L F
.78843 .39744 m .78585 .39397 L .79181 .39208 L F
.64006 .48388 m .64322 .48462 L .64616 .49026 L 0 .425 .712 r
F
.506 .58863 m .50286 .58588 L .5087 .55474 L .946 .736 .586 r
F
.5087 .55474 m .51128 .54432 L .51437 .55054 L .883 .811 .773 r
F
.5087 .55474 m .50559 .55235 L .51128 .54432 L F
.50286 .58588 m .50559 .55235 L .5087 .55474 L .931 .721 .597 r
F
.3556 .39729 m .35771 .39194 L .3611 .39542 L .663 .741 .908 r
F
.3556 .39729 m .3522 .39382 L .35771 .39194 L F
.88367 .3973 m .88733 .39194 L .88971 .39541 L F
.88367 .3973 m .88127 .39383 L .88733 .39194 L F
.70765 .39734 m .71079 .39194 L .71351 .39542 L .668 .744 .907 r
F
.70765 .39734 m .70492 .39389 L .71079 .39194 L F
.70208 .40446 m .70492 .39389 L .70765 .39734 L .875 .806 .778 r
F
.62874 .49468 m .62572 .48704 L .63146 .48381 L .682 .594 .751 r
F
.27477 .39715 m .27664 .39179 L .28019 .39527 L .663 .741 .908 r
F
.27477 .39715 m .27122 .39368 L .27664 .39179 L F
.80288 .39715 m .80631 .39179 L .80885 .39528 L .664 .741 .908 r
F
.80288 .39715 m .80033 .39368 L .80631 .39179 L F
.89814 .39701 m .90184 .39165 L .9042 .39515 L .664 .742 .908 r
F
.89814 .39701 m .89577 .39355 L .90184 .39165 L F
.36999 .39702 m .37214 .39167 L .3755 .39516 L .663 .741 .908 r
F
.36999 .39702 m .36661 .39355 L .37214 .39167 L F
.72209 .39702 m .72528 .39167 L .72797 .39514 L F
.72209 .39702 m .71939 .39355 L .72528 .39167 L F
.28915 .39687 m .29106 .39151 L .29458 .39498 L .664 .742 .908 r
F
.28915 .39687 m .28562 .3934 L .29106 .39151 L F
.81734 .39687 m .82081 .39151 L .82332 .39499 L F
.81734 .39687 m .81482 .3934 L .82081 .39151 L F
.57842 .42967 m .58154 .44539 L .5845 .44728 L .916 .537 .118 r
F
.2083 .39672 m .20998 .39135 L .21365 .39484 L .664 .741 .908 r
F
.2083 .39672 m .20462 .39325 L .20998 .39135 L F
.91261 .39673 m .91636 .39137 L .91869 .39484 L .663 .74 .908 r
F
.91261 .39673 m .91027 .39324 L .91636 .39137 L F
.73654 .39674 m .73977 .39137 L .74243 .39485 L .663 .74 .907 r
F
.73654 .39674 m .73386 .39325 L .73977 .39137 L F
.38438 .39674 m .38657 .39136 L .38991 .39484 L .664 .741 .907 r
F
.38438 .39674 m .38103 .39326 L .38657 .39136 L F
.30353 .39657 m .30549 .39121 L .30898 .39469 L .664 .741 .908 r
F
.30353 .39657 m .30003 .3931 L .30549 .39121 L F
.83181 .39658 m .83532 .39121 L .8378 .3947 L .663 .741 .908 r
F
.83181 .39658 m .82931 .3931 L .83532 .39121 L F
.39878 .39643 m .40101 .39107 L .40432 .39455 L F
.39878 .39643 m .39546 .39295 L .40101 .39107 L F
.22267 .39643 m .22439 .39106 L .22804 .39455 L .664 .741 .908 r
F
.22267 .39643 m .21901 .39295 L .22439 .39106 L F
.75099 .39643 m .75426 .39107 L .7569 .39455 L F
.75099 .39643 m .74834 .39296 L .75426 .39107 L F
.49498 .44544 m .49728 .46666 L .50049 .46271 L .937 .612 .168 r
F
.50049 .46271 m .49728 .46666 L .49777 .46558 L .924 .933 .568 r
F
.49806 .45452 m .50049 .46271 L .50318 .45986 L .716 .4 0 r
F
.49806 .45452 m .49498 .44544 L .50049 .46271 L F
.50049 .46271 m .49777 .46558 L .50306 .45392 L .924 .933 .568 r
F
.50318 .45986 m .50049 .46271 L .50366 .46035 L .716 .4 0 r
F
.62572 .48704 m .62264 .47699 L .62854 .47926 L .483 .438 .731 r
F
.62264 .47699 m .62559 .47362 L .62854 .47926 L .206 .227 .662 r
F
.31792 .39629 m .31991 .39093 L .32338 .39441 L .663 .741 .908 r
F
.31792 .39629 m .31444 .39281 L .31991 .39093 L F
.84628 .39629 m .84983 .39092 L .85229 .39441 L .664 .741 .908 r
F
.84628 .39629 m .84381 .39282 L .84983 .39092 L F
.71436 .61269 m .71112 .6021 L .71437 .61281 L .945 .636 .42 r
F
.70151 .48838 m .71035 .59301 L .71246 .5943 L F
.70151 .48838 m .69937 .49686 L .71112 .6021 L F
.69937 .49686 m .70788 .59159 L .71112 .6021 L .939 .626 .42 r
F
.70788 .59151 m .70665 .50375 L .70897 .49879 L .931 .669 .519 r
F
.70788 .59159 m .70788 .59151 L .70788 .59151 L F
.70788 .59151 m .70665 .50375 L .70788 .59151 L F
.71246 .5943 m .71112 .6021 L .71436 .61269 L .945 .636 .42 r
F
.71035 .59301 m .71112 .6021 L .71246 .5943 L F
.71112 .6021 m .70788 .59159 L .70788 .59151 L .953 .686 .492 r
F
.71112 .6021 m .70788 .59151 L .70897 .49879 L F
.70418 .5065 m .70165 .50855 L .70208 .40446 L .984 .718 .436 r
F
.70208 .40446 m .69936 .40141 L .70492 .39389 L .875 .806 .778 r
F
.70165 .50855 m .69936 .40141 L .70208 .40446 L .985 .719 .429 r
F
.76545 .39614 m .76876 .39079 L .77137 .39427 L .663 .742 .908 r
F
.76545 .39614 m .76283 .39267 L .76876 .39079 L F
.23704 .39614 m .2388 .39078 L .24243 .39426 L .663 .741 .908 r
F
.23704 .39614 m .23341 .39267 L .2388 .39078 L F
.41318 .39616 m .41546 .39081 L .41874 .39431 L .662 .741 .908 r
F
.41318 .39616 m .40988 .39268 L .41546 .39081 L F
.62572 .48704 m .62854 .47926 L .63146 .48381 L .483 .438 .731 r
F
.4919 .43592 m .49404 .47025 L .49728 .46666 L .97 .655 .291 r
F
.48612 .45039 m .48883 .42676 L .4919 .43592 L .995 .82 .556 r
F
.4919 .43592 m .48883 .42676 L .49404 .47025 L .97 .655 .291 r
F
.86075 .39601 m .86435 .39063 L .86678 .39411 L .664 .741 .907 r
F
.86075 .39601 m .85831 .39252 L .86435 .39063 L F
.33231 .39601 m .33435 .39064 L .33779 .39412 L .664 .741 .908 r
F
.33231 .39601 m .32886 .39253 L .33435 .39064 L F
.59328 .45044 m .59036 .44948 L .59547 .41565 L .975 .758 .547 r
F
.59547 .41565 m .5925 .4112 L .59846 .41824 L 0 .017 .573 r
F
.59036 .44948 m .5925 .4112 L .59547 .41565 L .984 .762 .525 r
F
.50306 .45392 m .49997 .44381 L .50585 .41101 L .892 .667 .59 r
F
.50585 .41101 m .50832 .42246 L .51147 .41913 L .9 .485 .122 r
F
.49997 .44381 m .50273 .40818 L .50585 .41101 L .859 .646 .612 r
F
.50585 .41101 m .50273 .40818 L .50832 .42246 L .9 .485 .122 r
F
.25142 .39585 m .25323 .39049 L .25682 .39397 L .663 .741 .908 r
F
.25142 .39585 m .24782 .39237 L .25323 .39049 L F
.77991 .39585 m .78327 .39049 L .78585 .39397 L .664 .742 .908 r
F
.77991 .39585 m .77732 .39238 L .78327 .39049 L F
.48612 .45039 m .48288 .45341 L .48883 .42676 L .995 .82 .556 r
F
.48883 .42676 m .4908 .47228 L .49404 .47025 L .974 .667 .342 r
F
.48288 .45341 m .48574 .41814 L .48883 .42676 L .992 .785 .524 r
F
.48883 .42676 m .48574 .41814 L .4908 .47228 L .974 .667 .342 r
F
.87523 .39571 m .87887 .39034 L .88127 .39383 L .664 .741 .908 r
F
.87523 .39571 m .87282 .39223 L .87887 .39034 L F
.3467 .39571 m .34879 .39034 L .3522 .39382 L F
.3467 .39571 m .34328 .39223 L .34879 .39034 L F
.26581 .39556 m .26765 .39019 L .27122 .39368 L F
.26581 .39556 m .26223 .39208 L .26765 .39019 L F
.79437 .39556 m .79778 .39019 L .80033 .39368 L .663 .741 .908 r
F
.79437 .39556 m .79181 .39208 L .79778 .39019 L F
.88971 .39541 m .8934 .39005 L .89577 .39355 L .663 .742 .908 r
F
.88971 .39541 m .88733 .39194 L .8934 .39005 L F
.3611 .39542 m .36323 .39006 L .36661 .39355 L .663 .741 .908 r
F
.3611 .39542 m .35771 .39194 L .36323 .39006 L F
.71351 .39542 m .71667 .39006 L .71939 .39355 L F
.71351 .39542 m .71079 .39194 L .71667 .39006 L F
.28019 .39527 m .28208 .38991 L .28562 .3934 L F
.28019 .39527 m .27664 .39179 L .28208 .38991 L F
.80885 .39528 m .81229 .3899 L .81482 .3934 L .664 .741 .908 r
F
.80885 .39528 m .80631 .39179 L .81229 .3899 L F
.48288 .45341 m .47959 .4573 L .48511 .42213 L .992 .785 .524 r
F
.47959 .4573 m .48264 .4105 L .48574 .41814 L .99 .767 .506 r
F
.47959 .4573 m .47627 .46218 L .48059 .42713 L F
.48145 .42883 m .48059 .42713 L .48264 .4105 L F
.47959 .4573 m .48059 .42713 L .48145 .42883 L F
.47627 .46218 m .47951 .40482 L .48264 .4105 L .986 .754 .5 r
F
.47627 .46218 m .47291 .46735 L .47951 .40482 L F
.47291 .46735 m .47632 .40223 L .47951 .40482 L .981 .743 .503 r
F
.47291 .46735 m .46954 .47152 L .47355 .43053 L F
.47455 .43608 m .47355 .43053 L .47632 .40223 L F
.47291 .46735 m .47355 .43053 L .47455 .43608 L F
.46954 .47152 m .47306 .40354 L .47632 .40223 L .973 .733 .512 r
F
.46954 .47152 m .46619 .47321 L .47306 .40354 L F
.46619 .47321 m .4697 .40903 L .47306 .40354 L .96 .719 .531 r
F
.46974 .40933 m .47183 .42519 L .47484 .44317 L .689 .342 .382 r
F
.4697 .40903 m .46972 .40921 L .46974 .40933 L F
.46972 .40921 m .47183 .42519 L .46974 .40933 L F
.47402 .41411 m .47484 .44317 L .47794 .45703 L .898 .576 .429 r
F
.47306 .40354 m .47349 .41305 L .47402 .41411 L F
.47349 .41305 m .47484 .44317 L .47402 .41411 L F
.47534 .59055 m .47213 .5859 L .47886 .51313 L .947 .703 .536 r
F
.47882 .5135 m .47564 .5133 L .47886 .51313 L .944 .702 .541 r
F
.47831 .51899 m .47554 .51529 L .47847 .51736 L F
.47213 .5859 m .47545 .51712 L .47831 .51899 L F
.47545 .51712 m .47554 .51529 L .47831 .51899 L F
.47213 .5859 m .46891 .58082 L .47564 .5133 L F
.46891 .58082 m .4724 .51285 L .47564 .5133 L .946 .705 .543 r
F
.46568 .57625 m .46245 .5707 L .46915 .51267 L .94 .701 .55 r
F
.46583 .51546 m .46762 .55028 L .47089 .55345 L .885 .561 .432 r
F
.47089 .55345 m .46762 .55028 L .46763 .55023 L .946 .729 .579 r
F
.46919 .51304 m .47089 .55345 L .47413 .55667 L .92 .602 .425 r
F
.46917 .51303 m .47089 .55345 L .46919 .51304 L F
.47734 .56001 m .47414 .55673 L .47738 .56035 L .942 .627 .412 r
F
.47243 .5131 m .47414 .55667 L .47734 .56001 L F
.47414 .55667 m .47414 .55673 L .47734 .56001 L F
.47089 .55345 m .46763 .55023 L .46768 .54993 L .946 .729 .579 r
F
.47241 .51309 m .47414 .55673 L .47243 .5131 L .942 .627 .412 r
F
.47554 .51529 m .47564 .5133 L .47847 .51736 L .944 .702 .541 r
F
.47564 .5133 m .47243 .5131 L .47738 .56035 L .945 .633 .415 r
F
.4724 .51285 m .46915 .51267 L .47414 .55673 L .942 .627 .412 r
F
.46915 .51267 m .46583 .51546 L .47089 .55345 L .92 .602 .425 r
F
.4709 .55329 m .46768 .54993 L .4739 .51551 L .946 .729 .579 r
F
.47089 .55345 m .46768 .54993 L .4709 .55329 L F
.47413 .55667 m .47089 .55345 L .47414 .55673 L .92 .602 .425 r
F
.46915 .51267 m .46917 .51303 L .46919 .51304 L F
.4724 .51285 m .47241 .51309 L .47243 .5131 L .942 .627 .412 r
F
.47847 .51736 m .47564 .5133 L .47882 .5135 L .944 .702 .541 r
F
.47564 .5133 m .4724 .51285 L .47243 .5131 L .945 .633 .415 r
F
.47886 .51313 m .47564 .5133 L .48061 .56317 L .942 .633 .423 r
F
.47634 .51539 m .47959 .4573 L .48288 .45341 L .945 .708 .549 r
F
.47564 .5133 m .47738 .56035 L .48061 .56317 L .945 .633 .415 r
F
.47634 .51539 m .47311 .5106 L .47959 .4573 L .945 .708 .549 r
F
.47311 .5106 m .47627 .46218 L .47959 .4573 L .923 .693 .573 r
F
.47757 .41895 m .47794 .45703 L .4811 .46601 L .94 .631 .424 r
F
.47632 .40223 m .4768 .41862 L .47757 .41895 L F
.4768 .41862 m .47794 .45703 L .47757 .41895 L F
.48541 .42226 m .48511 .42213 L .48574 .41814 L .992 .785 .524 r
F
.48288 .45341 m .48511 .42213 L .48541 .42226 L F
.48574 .41814 m .48756 .47252 L .4908 .47228 L .973 .669 .371 r
F
.48286 .51725 m .47959 .51727 L .48612 .45039 L .967 .726 .521 r
F
.47959 .51727 m .48288 .45341 L .48612 .45039 L .96 .72 .531 r
F
.48574 .41814 m .48264 .4105 L .48705 .46615 L .973 .669 .371 r
F
.48264 .4105 m .48432 .47074 L .48756 .47252 L .968 .665 .393 r
F
.48264 .4105 m .47951 .40482 L .48432 .47074 L F
.47959 .51727 m .47634 .51539 L .48288 .45341 L .96 .72 .531 r
F
.47951 .40482 m .4811 .46601 L .48432 .47074 L .958 .654 .41 r
F
.47951 .40482 m .47632 .40223 L .4811 .46601 L F
.47835 .45307 m .48127 .39285 L .48448 .39391 L .898 .657 .565 r
F
.47794 .45703 m .47816 .45279 L .47835 .45307 L F
.47816 .45279 m .48127 .39285 L .47835 .45307 L F
.48736 .46661 m .48705 .46615 L .48756 .47252 L .973 .669 .371 r
F
.48574 .41814 m .48705 .46615 L .48736 .46661 L F
.60732 .43101 m .60436 .42589 L .61064 .44365 L .87 .479 .007 r
F
.19927 .39513 m .20092 .38976 L .20462 .39325 L .663 .741 .908 r
F
.19927 .39513 m .19557 .39165 L .20092 .38976 L F
.72797 .39514 m .73118 .38976 L .73386 .39325 L .664 .742 .908 r
F
.72797 .39514 m .72528 .39167 L .73118 .38976 L F
.9042 .39515 m .90793 .38976 L .91027 .39324 L .664 .74 .907 r
F
.9042 .39515 m .90184 .39165 L .90793 .38976 L F
.3755 .39516 m .37767 .38976 L .38103 .39326 L .665 .741 .907 r
F
.3755 .39516 m .37214 .39167 L .37767 .38976 L F
.65322 .41398 m .65797 .45201 L .661 .45963 L .951 .609 .322 r
F
.65322 .41398 m .65047 .41286 L .65797 .45201 L F
.63146 .48381 m .63434 .47745 L .63729 .48302 L .657 .678 .858 r
F
.63146 .48381 m .62854 .47926 L .63434 .47745 L F
.52642 .43099 m .52904 .42509 L .5321 .42657 L .842 .929 .887 r
F
.52642 .43099 m .52335 .43003 L .52904 .42509 L F
.29458 .39498 m .29652 .38961 L .30003 .3931 L .664 .742 .908 r
F
.29458 .39498 m .29106 .39151 L .29652 .38961 L F
.82332 .39499 m .82681 .38961 L .82931 .3931 L .664 .741 .908 r
F
.82332 .39499 m .82081 .39151 L .82681 .38961 L F
.50559 .55235 m .50818 .5398 L .51128 .54432 L .918 .815 .728 r
F
.21365 .39484 m .21535 .38946 L .21901 .39295 L .664 .741 .908 r
F
.21365 .39484 m .20998 .39135 L .21535 .38946 L F
.38991 .39484 m .39212 .38946 L .39546 .39295 L F
.38991 .39484 m .38657 .39136 L .39212 .38946 L F
.91869 .39484 m .92246 .38947 L .92478 .39296 L .664 .742 .908 r
F
.91869 .39484 m .91636 .39137 L .92246 .38947 L F
.74243 .39485 m .74568 .38947 L .74834 .39296 L .664 .741 .908 r
F
.74243 .39485 m .73977 .39137 L .74568 .38947 L F
.30898 .39469 m .31096 .38932 L .31444 .39281 L .663 .741 .908 r
F
.30898 .39469 m .30549 .39121 L .31096 .38932 L F
.8378 .3947 m .84134 .38932 L .84381 .39282 L .664 .741 .908 r
F
.8378 .3947 m .83532 .39121 L .84134 .38932 L F
.22804 .39455 m .22977 .38918 L .23341 .39267 L .663 .741 .908 r
F
.22804 .39455 m .22439 .39106 L .22977 .38918 L F
.40432 .39455 m .40658 .38919 L .40988 .39268 L F
.40432 .39455 m .40101 .39107 L .40658 .38919 L F
.7569 .39455 m .7602 .38918 L .76283 .39267 L F
.7569 .39455 m .75426 .39107 L .7602 .38918 L F
.85229 .39441 m .85586 .38903 L .85831 .39252 L .664 .741 .908 r
F
.85229 .39441 m .84983 .39092 L .85586 .38903 L F
.32338 .39441 m .3254 .38904 L .32886 .39253 L .663 .741 .908 r
F
.32338 .39441 m .31991 .39093 L .3254 .38904 L F
.4275 .39852 m .42808 .45226 L .43115 .46459 L .961 .658 .41 r
F
.4275 .39852 m .42425 .39447 L .42808 .45226 L F
.24243 .39426 m .24421 .38888 L .24782 .39237 L .664 .742 .908 r
F
.24243 .39426 m .2388 .39078 L .24421 .38888 L F
.77137 .39427 m .77471 .38889 L .77732 .39238 L .664 .741 .908 r
F
.77137 .39427 m .76876 .39079 L .77471 .38889 L F
.41874 .39431 m .42099 .39047 L .42425 .39447 L .528 .691 .943 r
F
.41874 .39431 m .41546 .39081 L .42099 .39047 L F
.57782 .43876 m .57554 .4386 L .57853 .44116 L .933 .554 .204 r
F
.57242 .42039 m .57554 .4386 L .57782 .43876 L F
.57547 .43837 m .57258 .43978 L .57554 .4386 L .946 .584 .241 r
F
.56942 .41726 m .57258 .43978 L .57547 .43837 L F
.56641 .41361 m .56962 .44138 L .57258 .43978 L .956 .613 .256 r
F
.57258 .43978 m .56962 .44138 L .56968 .4412 L .992 .875 .606 r
F
.57542 .42486 m .57242 .42039 L .57853 .44116 L .922 .543 .139 r
F
.57242 .42039 m .56942 .41726 L .57554 .4386 L .933 .554 .204 r
F
.57258 .43978 m .56968 .4412 L .57522 .42462 L .992 .875 .606 r
F
.57554 .4386 m .57258 .43978 L .57324 .43844 L .971 .928 .676 r
F
.57542 .42486 m .57853 .44116 L .58114 .44402 L .922 .543 .139 r
F
.57554 .4386 m .57324 .43844 L .57825 .42814 L .971 .928 .676 r
F
.57853 .44116 m .57554 .4386 L .57592 .4383 L .808 .83 .867 r
F
.57853 .44116 m .57592 .4383 L .5813 .43401 L F
.58114 .44402 m .57853 .44116 L .58154 .44539 L .922 .543 .139 r
F
.86678 .39411 m .8704 .38874 L .87282 .39223 L .663 .741 .908 r
F
.86678 .39411 m .86435 .39063 L .8704 .38874 L F
.33779 .39412 m .33985 .38874 L .34328 .39223 L .664 .741 .908 r
F
.33779 .39412 m .33435 .39064 L .33985 .38874 L F
.72355 .63484 m .7206 .62939 L .71815 .48071 L .971 .696 .453 r
F
.78585 .39397 m .78923 .38859 L .79181 .39208 L .664 .742 .908 r
F
.78585 .39397 m .78327 .39049 L .78923 .38859 L F
.25682 .39397 m .25864 .38859 L .26223 .39208 L .664 .741 .908 r
F
.25682 .39397 m .25323 .39049 L .25864 .38859 L F
.3522 .39382 m .3543 .38845 L .35771 .39194 L .663 .741 .908 r
F
.3522 .39382 m .34879 .39034 L .3543 .38845 L F
.88127 .39383 m .88493 .38845 L .88733 .39194 L .664 .741 .908 r
F
.88127 .39383 m .87887 .39034 L .88493 .38845 L F
.70492 .39389 m .70806 .38845 L .71079 .39194 L .667 .741 .906 r
F
.70492 .39389 m .70218 .39039 L .70806 .38845 L F
.69936 .40141 m .70218 .39039 L .70492 .39389 L .89 .814 .767 r
F
.27122 .39368 m .27308 .3883 L .27664 .39179 L .663 .741 .908 r
F
.27122 .39368 m .26765 .39019 L .27308 .3883 L F
.80033 .39368 m .80376 .3883 L .80631 .39179 L .664 .741 .908 r
F
.80033 .39368 m .79778 .39019 L .80376 .3883 L F
.89577 .39355 m .89948 .38815 L .90184 .39165 L .664 .741 .907 r
F
.89577 .39355 m .8934 .39005 L .89948 .38815 L F
.71939 .39355 m .72257 .38817 L .72528 .39167 L .663 .741 .908 r
F
.71939 .39355 m .71667 .39006 L .72257 .38817 L F
.36661 .39355 m .36876 .38817 L .37214 .39167 L .664 .741 .908 r
F
.36661 .39355 m .36323 .39006 L .36876 .38817 L F
.50286 .58588 m .49973 .58159 L .50559 .55235 L .931 .721 .597 r
F
.50559 .55235 m .50246 .55042 L .50818 .5398 L .918 .815 .728 r
F
.28562 .3934 m .28753 .38802 L .29106 .39151 L .664 .742 .908 r
F
.28562 .3934 m .28208 .38991 L .28753 .38802 L F
.81482 .3934 m .81829 .38801 L .82081 .39151 L .664 .741 .907 r
F
.81482 .3934 m .81229 .3899 L .81829 .38801 L F
.91027 .39324 m .91402 .38787 L .91636 .39137 L .663 .741 .908 r
F
.91027 .39324 m .90793 .38976 L .91402 .38787 L F
.20462 .39325 m .20629 .38786 L .20998 .39135 L .664 .741 .908 r
F
.20462 .39325 m .20092 .38976 L .20629 .38786 L F
.73386 .39325 m .73709 .38786 L .73977 .39137 L F
.73386 .39325 m .73118 .38976 L .73709 .38786 L F
.38103 .39326 m .38322 .38786 L .38657 .39136 L .664 .741 .907 r
F
.38103 .39326 m .37767 .38976 L .38322 .38786 L F
.30003 .3931 m .30198 .38771 L .30549 .39121 L .664 .741 .908 r
F
.30003 .3931 m .29652 .38961 L .30198 .38771 L F
.82931 .3931 m .83282 .38772 L .83532 .39121 L .663 .741 .908 r
F
.82931 .3931 m .82681 .38961 L .83282 .38772 L F
.5925 .4112 m .59555 .41684 L .59846 .41824 L .692 .237 0 r
F
.58746 .44997 m .58954 .40739 L .5925 .4112 L .935 .705 .566 r
F
.5925 .4112 m .58954 .40739 L .59555 .41684 L .692 .237 0 r
F
.21901 .39295 m .22073 .38757 L .22439 .39106 L .664 .741 .908 r
F
.21901 .39295 m .21535 .38946 L .22073 .38757 L F
.39546 .39295 m .39769 .38758 L .40101 .39107 L .663 .741 .908 r
F
.39546 .39295 m .39212 .38946 L .39769 .38758 L F
.74834 .39296 m .75161 .38757 L .75426 .39107 L .664 .742 .908 r
F
.74834 .39296 m .74568 .38947 L .75161 .38757 L F
.31444 .39281 m .31643 .38743 L .31991 .39093 L .663 .741 .908 r
F
.31444 .39281 m .31096 .38932 L .31643 .38743 L F
.84381 .39282 m .84736 .38742 L .84983 .39092 L .664 .741 .908 r
F
.84381 .39282 m .84134 .38932 L .84736 .38742 L F
.60688 .43674 m .60472 .43546 L .60767 .43895 L .906 .502 .116 r
F
.6014 .42136 m .60472 .43546 L .60688 .43674 L F
.60436 .43448 m .6018 .43405 L .60472 .43546 L .912 .51 .199 r
F
.59846 .41824 m .6018 .43405 L .60436 .43448 L F
.59555 .41684 m .59889 .43359 L .6018 .43405 L .909 .511 .232 r
F
.6018 .43405 m .59889 .43359 L .59923 .43362 L 0 .559 .757 r
F
.6014 .42136 m .59846 .41824 L .60472 .43546 L .906 .502 .116 r
F
.59846 .41824 m .59555 .41684 L .6018 .43405 L .912 .51 .199 r
F
.6018 .43405 m .59923 .43362 L .60481 .43411 L 0 .559 .757 r
F
.60472 .43546 m .6018 .43405 L .60254 .43417 L .087 .595 .891 r
F
.60436 .42589 m .60767 .43895 L .61018 .44234 L .885 .488 .042 r
F
.60436 .42589 m .6014 .42136 L .60767 .43895 L F
.60472 .43546 m .60254 .43417 L .60772 .43503 L .087 .595 .891 r
F
.60767 .43895 m .60472 .43546 L .60515 .43555 L .338 .591 .938 r
F
.60767 .43895 m .60515 .43555 L .61063 .43678 L F
.61018 .44234 m .60767 .43895 L .61064 .44365 L .885 .488 .042 r
F
.23341 .39267 m .23517 .38729 L .2388 .39078 L .663 .741 .908 r
F
.23341 .39267 m .22977 .38918 L .23517 .38729 L F
.76283 .39267 m .76614 .38729 L .76876 .39079 L F
.76283 .39267 m .7602 .38918 L .76614 .38729 L F
.40988 .39268 m .41216 .3873 L .41546 .39081 L F
.40988 .39268 m .40658 .38919 L .41216 .3873 L F
.63729 .48302 m .6401 .4742 L .64322 .48462 L .707 .659 .8 r
F
.63729 .48302 m .63434 .47745 L .6401 .4742 L F
.85831 .39252 m .86191 .38714 L .86435 .39063 L .663 .741 .908 r
F
.85831 .39252 m .85586 .38903 L .86191 .38714 L F
.32886 .39253 m .33089 .38714 L .33435 .39064 L .664 .741 .908 r
F
.32886 .39253 m .3254 .38904 L .33089 .38714 L F
.69937 .49686 m .6972 .50528 L .70788 .59159 L .939 .626 .42 r
F
.70165 .50855 m .69917 .51172 L .69936 .40141 L .985 .719 .429 r
F
.69936 .40141 m .69664 .39854 L .70218 .39039 L .89 .814 .767 r
F
.69917 .51172 m .69664 .39854 L .69936 .40141 L .983 .714 .436 r
F
.24782 .39237 m .24962 .38699 L .25323 .39049 L .663 .741 .908 r
F
.24782 .39237 m .24421 .38888 L .24962 .38699 L F
.77732 .39238 m .78067 .38699 L .78327 .39049 L .664 .742 .908 r
F
.77732 .39238 m .77471 .38889 L .78067 .38699 L F
.87282 .39223 m .87646 .38684 L .87887 .39034 L F
.87282 .39223 m .8704 .38874 L .87646 .38684 L F
.34328 .39223 m .34536 .38684 L .34879 .39034 L .664 .741 .908 r
F
.34328 .39223 m .33985 .38874 L .34536 .38684 L F
.62854 .47926 m .63141 .47251 L .63434 .47745 L .616 .616 .827 r
F
.62854 .47926 m .62559 .47362 L .63141 .47251 L F
.50246 .55042 m .50507 .53549 L .50818 .5398 L .928 .797 .696 r
F
.26223 .39208 m .26407 .38669 L .26765 .39019 L .663 .741 .908 r
F
.26223 .39208 m .25864 .38859 L .26407 .38669 L F
.79181 .39208 m .79521 .38669 L .79778 .39019 L F
.79181 .39208 m .78923 .38859 L .79521 .38669 L F
.49997 .44381 m .49688 .4326 L .50273 .40818 L .859 .646 .612 r
F
.50273 .40818 m .50513 .42732 L .50832 .42246 L .914 .542 .304 r
F
.49688 .4326 m .49958 .40802 L .50273 .40818 L .782 .599 .652 r
F
.50273 .40818 m .49958 .40802 L .50513 .42732 L .914 .542 .304 r
F
.88733 .39194 m .89101 .38655 L .8934 .39005 L .664 .741 .908 r
F
.88733 .39194 m .88493 .38845 L .89101 .38655 L F
.71079 .39194 m .71395 .38656 L .71667 .39006 L .663 .741 .908 r
F
.71079 .39194 m .70806 .38845 L .71395 .38656 L F
.35771 .39194 m .35983 .38656 L .36323 .39006 L F
.35771 .39194 m .3543 .38845 L .35983 .38656 L F
.27664 .39179 m .27853 .38641 L .28208 .38991 L F
.27664 .39179 m .27308 .3883 L .27853 .38641 L F
.80631 .39179 m .80975 .3864 L .81229 .3899 L F
.80631 .39179 m .80376 .3883 L .80975 .3864 L F
.19557 .39165 m .19721 .38626 L .20092 .38976 L F
.19557 .39165 m .19185 .38815 L .19721 .38626 L F
.90184 .39165 m .90557 .38626 L .90793 .38976 L F
.90184 .39165 m .89948 .38815 L .90557 .38626 L F
.72528 .39167 m .72848 .38627 L .73118 .38976 L .664 .741 .908 r
F
.72528 .39167 m .72257 .38817 L .72848 .38627 L F
.37214 .39167 m .3743 .38626 L .37767 .38976 L .664 .741 .907 r
F
.37214 .39167 m .36876 .38817 L .3743 .38626 L F
.29106 .39151 m .29299 .38611 L .29652 .38961 L .664 .742 .908 r
F
.29106 .39151 m .28753 .38802 L .29299 .38611 L F
.82081 .39151 m .8243 .38611 L .82681 .38961 L .663 .741 .908 r
F
.82081 .39151 m .81829 .38801 L .8243 .38611 L F
.20998 .39135 m .21166 .38596 L .21535 .38946 L .664 .741 .908 r
F
.20998 .39135 m .20629 .38786 L .21166 .38596 L F
.38657 .39136 m .38878 .38596 L .39212 .38946 L F
.38657 .39136 m .38322 .38786 L .38878 .38596 L F
.91636 .39137 m .92013 .38596 L .92246 .38947 L .664 .742 .908 r
F
.91636 .39137 m .91402 .38787 L .92013 .38596 L F
.73977 .39137 m .74302 .38597 L .74568 .38947 L .663 .741 .907 r
F
.73977 .39137 m .73709 .38786 L .74302 .38597 L F
.30549 .39121 m .30745 .38582 L .31096 .38932 L .663 .741 .908 r
F
.30549 .39121 m .30198 .38771 L .30745 .38582 L F
.83532 .39121 m .83885 .38582 L .84134 .38932 L F
.83532 .39121 m .83282 .38772 L .83885 .38582 L F
.42425 .39447 m .425 .44028 L .42808 .45226 L .96 .652 .397 r
F
.42425 .39447 m .42099 .39047 L .425 .44028 L F
.22439 .39106 m .22612 .38567 L .22977 .38918 L .663 .741 .908 r
F
.22439 .39106 m .22073 .38757 L .22612 .38567 L F
.75426 .39107 m .75755 .38567 L .7602 .38918 L .664 .741 .908 r
F
.75426 .39107 m .75161 .38757 L .75755 .38567 L F
.40101 .39107 m .40326 .38568 L .40658 .38919 L .663 .741 .908 r
F
.40101 .39107 m .39769 .38758 L .40326 .38568 L F
.59354 .46441 m .5963 .4568 L .59922 .45865 L .535 .502 .765 r
F
.84983 .39092 m .85341 .38553 L .85586 .38903 L .663 .741 .908 r
F
.84983 .39092 m .84736 .38742 L .85341 .38553 L F
.31991 .39093 m .32193 .38553 L .3254 .38904 L F
.31991 .39093 m .31643 .38743 L .32193 .38553 L F
.2388 .39078 m .24058 .38538 L .24421 .38888 L .664 .742 .908 r
F
.2388 .39078 m .23517 .38729 L .24058 .38538 L F
.76876 .39079 m .7721 .38538 L .77471 .38889 L .664 .741 .908 r
F
.76876 .39079 m .76614 .38729 L .7721 .38538 L F
.41546 .39081 m .41771 .38653 L .42099 .39047 L .571 .709 .935 r
F
.41546 .39081 m .41216 .3873 L .41771 .38653 L F
.6891 .464 m .69486 .51086 L .6972 .50528 L .909 .578 .405 r
F
.59354 .46441 m .59048 .45615 L .5963 .4568 L .535 .502 .765 r
F
.86435 .39063 m .86797 .38524 L .8704 .38874 L .664 .742 .908 r
F
.86435 .39063 m .86191 .38714 L .86797 .38524 L F
.33435 .39064 m .3364 .38524 L .33985 .38874 L .664 .741 .908 r
F
.33435 .39064 m .33089 .38714 L .3364 .38524 L F
.25323 .39049 m .25504 .38508 L .25864 .38859 L F
.25323 .39049 m .24962 .38699 L .25504 .38508 L F
.78327 .39049 m .78665 .38508 L .78923 .38859 L .664 .742 .908 r
F
.78327 .39049 m .78067 .38699 L .78665 .38508 L F
.34879 .39034 m .35088 .38494 L .3543 .38845 L .663 .741 .908 r
F
.34879 .39034 m .34536 .38684 L .35088 .38494 L F
.87887 .39034 m .88253 .38494 L .88493 .38845 L .664 .741 .908 r
F
.87887 .39034 m .87646 .38684 L .88253 .38494 L F
.63434 .47745 m .63706 .46577 L .6401 .4742 L .811 .716 .76 r
F
.63434 .47745 m .63141 .47251 L .63706 .46577 L F
.70218 .39039 m .70532 .38495 L .70806 .38845 L .666 .742 .907 r
F
.70218 .39039 m .69943 .38689 L .70532 .38495 L F
.69664 .39854 m .69943 .38689 L .70218 .39039 L .893 .806 .755 r
F
.65047 .41286 m .65496 .44514 L .65797 .45201 L .947 .595 .302 r
F
.50366 .46035 m .50617 .46305 L .50927 .47124 L .389 0 0 r
F
.50366 .46035 m .50049 .46271 L .50617 .46305 L F
.26765 .39019 m .26951 .38479 L .27308 .3883 L .664 .741 .908 r
F
.26765 .39019 m .26407 .38669 L .26951 .38479 L F
.79778 .39019 m .8012 .3848 L .80376 .3883 L .663 .741 .908 r
F
.79778 .39019 m .79521 .38669 L .8012 .3848 L F
.52335 .43003 m .52596 .42481 L .52904 .42509 L .838 .977 .879 r
F
.8934 .39005 m .8971 .38466 L .89948 .38815 L .663 .741 .908 r
F
.8934 .39005 m .89101 .38655 L .8971 .38466 L F
.71667 .39006 m .71986 .38467 L .72257 .38817 L F
.71667 .39006 m .71395 .38656 L .71986 .38467 L F
.36323 .39006 m .36537 .38465 L .36876 .38817 L .664 .741 .908 r
F
.36323 .39006 m .35983 .38656 L .36537 .38465 L F
.62559 .47362 m .62847 .46753 L .63141 .47251 L .543 .554 .816 r
F
.62559 .47362 m .6226 .46725 L .62847 .46753 L F
.81229 .3899 m .81576 .3845 L .81829 .38801 L .664 .741 .908 r
F
.81229 .3899 m .80975 .3864 L .81576 .3845 L F
.28208 .38991 m .28398 .38451 L .28753 .38802 L F
.28208 .38991 m .27853 .38641 L .28398 .38451 L F
.59048 .45615 m .59328 .45044 L .5963 .4568 L .487 .504 .801 r
F
.58746 .44997 m .58441 .44367 L .58954 .40739 L .935 .705 .566 r
F
.58954 .40739 m .59264 .41624 L .59555 .41684 L .835 .39 0 r
F
.58951 .40757 m .58658 .40418 L .58954 .40739 L .895 .671 .591 r
F
.57825 .42814 m .5806 .39702 L .5836 .40069 L .95 .74 .584 r
F
.5836 .40069 m .5806 .39702 L .58068 .39728 L .925 .54 .16 r
F
.58441 .44367 m .58657 .4043 L .58948 .40777 L .895 .671 .591 r
F
.58441 .44367 m .5813 .43401 L .58658 .40418 L F
.5813 .43401 m .5836 .40069 L .58658 .40418 L .926 .711 .592 r
F
.5813 .43401 m .57825 .42814 L .5836 .40069 L F
.58361 .40077 m .58068 .39728 L .58683 .41763 L .925 .54 .16 r
F
.5836 .40069 m .58068 .39728 L .58361 .40077 L F
.58948 .40777 m .58658 .40418 L .58951 .40757 L .895 .671 .591 r
F
.58657 .4043 m .58658 .40418 L .58948 .40777 L F
.58658 .40418 m .5836 .40069 L .58363 .40077 L .885 .47 .055 r
F
.58658 .40418 m .58363 .40077 L .58973 .4161 L F
.58954 .40739 m .58658 .40418 L .59264 .41624 L .835 .39 0 r
F
.90793 .38976 m .91168 .38436 L .91402 .38787 L .664 .742 .908 r
F
.90793 .38976 m .90557 .38626 L .91168 .38436 L F
.20092 .38976 m .20258 .38435 L .20629 .38786 L .664 .741 .908 r
F
.20092 .38976 m .19721 .38626 L .20258 .38435 L F
.73118 .38976 m .7344 .38436 L .73709 .38786 L .664 .742 .908 r
F
.73118 .38976 m .72848 .38627 L .7344 .38436 L F
.37767 .38976 m .37986 .38436 L .38322 .38786 L .664 .741 .908 r
F
.37767 .38976 m .3743 .38626 L .37986 .38436 L F
.29652 .38961 m .29846 .38421 L .30198 .38771 L F
.29652 .38961 m .29299 .38611 L .29846 .38421 L F
.82681 .38961 m .83032 .38421 L .83282 .38772 L .663 .741 .908 r
F
.82681 .38961 m .8243 .38611 L .83032 .38421 L F
.21535 .38946 m .21705 .38406 L .22073 .38757 L F
.21535 .38946 m .21166 .38596 L .21705 .38406 L F
.39212 .38946 m .39435 .38407 L .39769 .38758 L F
.39212 .38946 m .38878 .38596 L .39435 .38407 L F
.74568 .38947 m .74895 .38407 L .75161 .38757 L F
.74568 .38947 m .74302 .38597 L .74895 .38407 L F
.54968 .44461 m .55243 .44609 L .5555 .45243 L 0 .178 .661 r
F
.31096 .38932 m .31294 .38392 L .31643 .38743 L .664 .741 .908 r
F
.31096 .38932 m .30745 .38582 L .31294 .38392 L F
.84134 .38932 m .84489 .38392 L .84736 .38742 L .663 .741 .908 r
F
.84134 .38932 m .83885 .38582 L .84489 .38392 L F
.50246 .55042 m .49932 .54836 L .50507 .53549 L .928 .797 .696 r
F
.49932 .54836 m .50196 .52998 L .50507 .53549 L .909 .75 .673 r
F
.22977 .38918 m .23152 .38378 L .23517 .38729 L .663 .741 .908 r
F
.22977 .38918 m .22612 .38567 L .23152 .38378 L F
.7602 .38918 m .76351 .38377 L .76614 .38729 L F
.7602 .38918 m .75755 .38567 L .76351 .38377 L F
.40658 .38919 m .40885 .38378 L .41216 .3873 L .664 .741 .908 r
F
.40658 .38919 m .40326 .38568 L .40885 .38378 L F
.85586 .38903 m .85946 .38363 L .86191 .38714 L .664 .742 .908 r
F
.85586 .38903 m .85341 .38553 L .85946 .38363 L F
.3254 .38904 m .32743 .38363 L .33089 .38714 L .664 .741 .908 r
F
.3254 .38904 m .32193 .38553 L .32743 .38363 L F
.24421 .38888 m .24599 .38347 L .24962 .38699 L F
.24421 .38888 m .24058 .38538 L .24599 .38347 L F
.77471 .38889 m .77807 .38348 L .78067 .38699 L .664 .741 .907 r
F
.77471 .38889 m .7721 .38538 L .77807 .38348 L F
.33985 .38874 m .34192 .38333 L .34536 .38684 L .664 .741 .908 r
F
.33985 .38874 m .3364 .38524 L .34192 .38333 L F
.8704 .38874 m .87404 .38333 L .87646 .38684 L F
.8704 .38874 m .86797 .38524 L .87404 .38333 L F
.70774 .59047 m .70444 .57722 L .70788 .59159 L .939 .619 .403 r
F
.70405 .56064 m .7036 .5689 L .70555 .57278 L F
.6972 .50528 m .70147 .54773 L .70263 .54913 L F
.6972 .50528 m .69486 .51086 L .70444 .57722 L F
.70425 .57594 m .7011 .56475 L .70444 .57722 L .934 .604 .386 r
F
.69486 .51086 m .69818 .53949 L .69922 .54107 L F
.69486 .51086 m .69242 .51504 L .7011 .56475 L F
.69242 .51504 m .69788 .55445 L .7011 .56475 L .916 .573 .374 r
F
.69242 .51504 m .68996 .51931 L .69788 .55445 L F
.69772 .5537 m .69453 .54148 L .69788 .55445 L .905 .521 .286 r
F
.68996 .51931 m .68734 .52069 L .69453 .54148 L F
.69123 .52961 m .68813 .52161 L .68891 .52038 L .794 .649 .701 r
F
.68996 .51931 m .69408 .53928 L .69629 .5474 L .905 .521 .286 r
F
.68682 .47064 m .69242 .51504 L .69486 .51086 L .909 .575 .4 r
F
.68449 .4768 m .68996 .51931 L .69242 .51504 L .904 .568 .399 r
F
.68196 .50859 m .67915 .50524 L .68408 .48318 L .951 .755 .603 r
F
.68174 .48951 m .67928 .49359 L .68449 .4768 L .936 .882 .469 r
F
.68415 .47787 m .68213 .48307 L .68449 .4768 L .888 .884 .454 r
F
.67928 .49359 m .68213 .48307 L .68415 .47787 L F
.6762 .49919 m .67325 .49306 L .67771 .49346 L .528 .555 .827 r
F
.67876 .49453 m .67771 .49346 L .67928 .49359 L F
.6762 .49919 m .67771 .49346 L .67876 .49453 L F
.67325 .49306 m .67679 .49779 L .67928 .49359 L 0 0 .497 r
F
.67325 .49306 m .67018 .48438 L .67679 .49779 L F
.67148 .48703 m .67413 .49866 L .67679 .49779 L .735 .426 0 r
F
.67018 .48438 m .67068 .4862 L .67148 .48703 L F
.67068 .4862 m .67413 .49866 L .67148 .48703 L F
.6819 .48372 m .67961 .48613 L .68213 .48307 L .978 .917 .653 r
F
.67679 .49779 m .67961 .48613 L .6819 .48372 L F
.67413 .49866 m .67696 .48712 L .67961 .48613 L .938 .862 .739 r
F
.67961 .48613 m .67696 .48712 L .6773 .48856 L .935 .582 .329 r
F
.67915 .50524 m .6762 .49919 L .68174 .48951 L .835 .695 .709 r
F
.67928 .49359 m .67679 .49779 L .68213 .48307 L .888 .884 .454 r
F
.67679 .49779 m .67413 .49866 L .67961 .48613 L .978 .917 .653 r
F
.67961 .48613 m .6773 .48856 L .68462 .52029 L .935 .582 .329 r
F
.68213 .48307 m .67961 .48613 L .6801 .48832 L .924 .578 .362 r
F
.68213 .48307 m .6801 .48832 L .68734 .52069 L F
.68449 .4768 m .68213 .48307 L .68996 .51931 L .904 .568 .399 r
F
.68213 .48307 m .68734 .52069 L .68996 .51931 L .924 .578 .362 r
F
.69131 .52914 m .68891 .52038 L .69386 .51259 L .794 .649 .701 r
F
.69123 .52961 m .68891 .52038 L .69131 .52914 L F
.69629 .5474 m .69453 .54148 L .69772 .5537 L .905 .521 .286 r
F
.69408 .53928 m .69453 .54148 L .69629 .5474 L F
.69453 .54148 m .69123 .52961 L .69135 .52927 L .816 .62 .638 r
F
.69453 .54148 m .69135 .52927 L .69658 .51332 L F
.69137 .52919 m .69386 .51259 L .69658 .51332 L .794 .649 .701 r
F
.69123 .52961 m .69131 .5291 L .69137 .52919 L F
.69131 .5291 m .69386 .51259 L .69137 .52919 L F
.69922 .54107 m .7011 .56475 L .70425 .57594 L .934 .604 .386 r
F
.69818 .53949 m .7011 .56475 L .69922 .54107 L F
.7011 .56475 m .69788 .55445 L .69796 .55357 L .926 .68 .546 r
F
.7011 .56475 m .69796 .55357 L .70165 .50855 L F
.69481 .53965 m .69658 .51332 L .69917 .51172 L .816 .62 .638 r
F
.69453 .54148 m .69467 .53948 L .69481 .53965 L F
.69467 .53948 m .69658 .51332 L .69481 .53965 L F
.70263 .54913 m .70257 .5586 L .70405 .56064 L .939 .619 .403 r
F
.70147 .54773 m .70257 .5586 L .70263 .54913 L F
.70257 .5586 m .7036 .5689 L .70405 .56064 L F
.69805 .55242 m .69917 .51172 L .70165 .50855 L .873 .644 .59 r
F
.69788 .55445 m .69795 .55228 L .69805 .55242 L F
.69795 .55228 m .69917 .51172 L .69805 .55242 L F
.70114 .564 m .70165 .50855 L .70418 .5065 L .926 .68 .546 r
F
.7011 .56475 m .70111 .56394 L .70114 .564 L F
.70111 .56394 m .70165 .50855 L .70114 .564 L F
.70555 .57278 m .70444 .57722 L .70774 .59047 L .939 .619 .403 r
F
.7036 .5689 m .70444 .57722 L .70555 .57278 L F
.70444 .57722 m .7011 .56475 L .70114 .564 L .928 .673 .532 r
F
.70444 .57722 m .70114 .564 L .70418 .5065 L F
.69917 .51172 m .69658 .51332 L .69664 .39854 L .983 .714 .436 r
F
.69664 .39854 m .6939 .39552 L .69943 .38689 L .893 .806 .755 r
F
.69658 .51332 m .6939 .39552 L .69664 .39854 L .979 .709 .444 r
F
.78923 .38859 m .79263 .38318 L .79521 .38669 L .663 .741 .908 r
F
.78923 .38859 m .78665 .38508 L .79263 .38318 L F
.25864 .38859 m .26047 .38318 L .26407 .38669 L F
.25864 .38859 m .25504 .38508 L .26047 .38318 L F
.63141 .47251 m .63403 .4578 L .63706 .46577 L .855 .724 .717 r
F
.88493 .38845 m .88862 .38305 L .89101 .38655 L .663 .741 .908 r
F
.88493 .38845 m .88253 .38494 L .88862 .38305 L F
.3543 .38845 m .35642 .38304 L .35983 .38656 L F
.3543 .38845 m .35088 .38494 L .35642 .38304 L F
.70806 .38845 m .71122 .38304 L .71395 .38656 L .664 .742 .908 r
F
.70806 .38845 m .70532 .38495 L .71122 .38304 L F
.51147 .41913 m .50832 .42246 L .51399 .43369 L .82 .43 .315 r
F
.27308 .3883 m .27496 .3829 L .27853 .38641 L .663 .741 .908 r
F
.27308 .3883 m .26951 .38479 L .27496 .3829 L F
.80376 .3883 m .8072 .3829 L .80975 .3864 L F
.80376 .3883 m .8012 .3848 L .8072 .3829 L F
.6226 .46725 m .62546 .46041 L .62847 .46753 L .544 .531 .791 r
F
.6226 .46725 m .61958 .46003 L .62546 .46041 L F
.19185 .38815 m .19349 .38275 L .19721 .38626 L .663 .741 .908 r
F
.19185 .38815 m .18812 .38465 L .19349 .38275 L F
.89948 .38815 m .9032 .38274 L .90557 .38626 L .664 .742 .908 r
F
.89948 .38815 m .8971 .38466 L .9032 .38274 L F
.36876 .38817 m .37092 .38275 L .3743 .38626 L .664 .741 .907 r
F
.36876 .38817 m .36537 .38465 L .37092 .38275 L F
.72257 .38817 m .72578 .38276 L .72848 .38627 L .664 .741 .908 r
F
.72257 .38817 m .71986 .38467 L .72578 .38276 L F
.81829 .38801 m .82178 .3826 L .8243 .38611 L F
.81829 .38801 m .81576 .3845 L .82178 .3826 L F
.28753 .38802 m .28945 .3826 L .29299 .38611 L .664 .742 .908 r
F
.28753 .38802 m .28398 .38451 L .28945 .3826 L F
.42099 .39047 m .42192 .42884 L .425 .44028 L .959 .644 .381 r
F
.42099 .39047 m .41771 .38653 L .42192 .42884 L F
.47632 .40223 m .47306 .40354 L .47794 .45703 L .94 .631 .424 r
F
.20629 .38786 m .20796 .38245 L .21166 .38596 L .664 .741 .908 r
F
.20629 .38786 m .20258 .38435 L .20796 .38245 L F
.38322 .38786 m .38542 .38245 L .38878 .38596 L .664 .742 .908 r
F
.38322 .38786 m .37986 .38436 L .38542 .38245 L F
.73709 .38786 m .74034 .38245 L .74302 .38597 L F
.73709 .38786 m .7344 .38436 L .74034 .38245 L F
.91402 .38787 m .91779 .38245 L .92013 .38596 L .664 .741 .907 r
F
.91402 .38787 m .91168 .38436 L .91779 .38245 L F
.30198 .38771 m .30394 .3823 L .30745 .38582 L .663 .741 .908 r
F
.30198 .38771 m .29846 .38421 L .30394 .3823 L F
.63141 .47251 m .62847 .46753 L .63403 .4578 L .855 .724 .717 r
F
.83282 .38772 m .83636 .38231 L .83885 .38582 L .663 .741 .908 r
F
.83282 .38772 m .83032 .38421 L .83636 .38231 L F
.62847 .46753 m .63096 .44873 L .63403 .4578 L .837 .674 .682 r
F
.22073 .38757 m .22245 .38215 L .22612 .38567 L .664 .741 .908 r
F
.22073 .38757 m .21705 .38406 L .22245 .38215 L F
.75161 .38757 m .7549 .38216 L .75755 .38567 L .664 .742 .908 r
F
.75161 .38757 m .74895 .38407 L .7549 .38216 L F
.39769 .38758 m .39993 .38217 L .40326 .38568 L .663 .741 .908 r
F
.39769 .38758 m .39435 .38407 L .39993 .38217 L F
.84736 .38742 m .85094 .38201 L .85341 .38553 L .663 .742 .908 r
F
.84736 .38742 m .84489 .38392 L .85094 .38201 L F
.31643 .38743 m .31844 .38201 L .32193 .38553 L .663 .741 .908 r
F
.31643 .38743 m .31294 .38392 L .31844 .38201 L F
.62847 .46753 m .62546 .46041 L .63096 .44873 L .837 .674 .682 r
F
.76614 .38729 m .76948 .38186 L .7721 .38538 L .664 .741 .908 r
F
.76614 .38729 m .76351 .38377 L .76948 .38186 L F
.23517 .38729 m .23693 .38186 L .24058 .38538 L F
.23517 .38729 m .23152 .38378 L .23693 .38186 L F
.41216 .3873 m .41442 .38267 L .41771 .38653 L .602 .72 .928 r
F
.41216 .3873 m .40885 .38378 L .41442 .38267 L F
.33089 .38714 m .33294 .38172 L .3364 .38524 L .664 .741 .908 r
F
.33089 .38714 m .32743 .38363 L .33294 .38172 L F
.86191 .38714 m .86553 .38172 L .86797 .38524 L F
.86191 .38714 m .85946 .38363 L .86553 .38172 L F
.49932 .54836 m .49617 .54478 L .50196 .52998 L .909 .75 .673 r
F
.49617 .54478 m .49883 .52548 L .50196 .52998 L .902 .738 .669 r
F
.24962 .38699 m .25142 .38157 L .25504 .38508 L .664 .741 .908 r
F
.24962 .38699 m .24599 .38347 L .25142 .38157 L F
.78067 .38699 m .78405 .38157 L .78665 .38508 L F
.78067 .38699 m .77807 .38348 L .78405 .38157 L F
.34536 .38684 m .34745 .38142 L .35088 .38494 L .663 .741 .908 r
F
.34536 .38684 m .34192 .38333 L .34745 .38142 L F
.87646 .38684 m .88012 .38142 L .88253 .38494 L F
.87646 .38684 m .87404 .38333 L .88012 .38142 L F
.61958 .46003 m .62245 .45372 L .62546 .46041 L .536 .54 .806 r
F
.61958 .46003 m .61657 .45329 L .62245 .45372 L F
.69943 .38689 m .70256 .38143 L .70532 .38495 L .668 .745 .908 r
F
.69943 .38689 m .69667 .38341 L .70256 .38143 L F
.6939 .39552 m .69667 .38341 L .69943 .38689 L .887 .791 .749 r
F
.79521 .38669 m .79863 .38128 L .8012 .3848 L .663 .741 .908 r
F
.79521 .38669 m .79263 .38318 L .79863 .38128 L F
.26407 .38669 m .26592 .38127 L .26951 .38479 L .664 .741 .908 r
F
.26407 .38669 m .26047 .38318 L .26592 .38127 L F
.49688 .4326 m .4938 .42069 L .49958 .40802 L .782 .599 .652 r
F
.49958 .40802 m .50191 .43303 L .50513 .42732 L .89 .54 .376 r
F
.4938 .42069 m .49638 .41105 L .49958 .40802 L .494 .426 .709 r
F
.49958 .40802 m .49638 .41105 L .50191 .43303 L .89 .54 .376 r
F
.89101 .38655 m .89472 .38113 L .8971 .38466 L .664 .742 .908 r
F
.89101 .38655 m .88862 .38305 L .89472 .38113 L F
.35983 .38656 m .36196 .38113 L .36537 .38465 L .664 .741 .908 r
F
.35983 .38656 m .35642 .38304 L .36196 .38113 L F
.71395 .38656 m .71713 .38115 L .71986 .38467 L .663 .741 .908 r
F
.71395 .38656 m .71122 .38304 L .71713 .38115 L F
.80975 .3864 m .81322 .38099 L .81576 .3845 L .664 .742 .908 r
F
.80975 .3864 m .8072 .3829 L .81322 .38099 L F
.27853 .38641 m .28042 .38099 L .28398 .38451 L .664 .741 .908 r
F
.27853 .38641 m .27496 .3829 L .28042 .38099 L F
.19721 .38626 m .19886 .38083 L .20258 .38435 L F
.19721 .38626 m .19349 .38275 L .19886 .38083 L F
.3743 .38626 m .37648 .38084 L .37986 .38436 L F
.3743 .38626 m .37092 .38275 L .37648 .38084 L F
.90557 .38626 m .90932 .38084 L .91168 .38436 L .663 .741 .908 r
F
.90557 .38626 m .9032 .38274 L .90932 .38084 L F
.72848 .38627 m .73171 .38084 L .7344 .38436 L .664 .741 .908 r
F
.72848 .38627 m .72578 .38276 L .73171 .38084 L F
.7206 .62939 m .71758 .62285 L .71589 .48535 L .968 .695 .459 r
F
.71758 .62285 m .71363 .49026 L .71589 .48535 L .96 .688 .474 r
F
.58658 .40418 m .58973 .4161 L .59264 .41624 L .885 .47 .055 r
F
.29299 .38611 m .29492 .38068 L .29846 .38421 L .664 .741 .908 r
F
.29299 .38611 m .28945 .3826 L .29492 .38068 L F
.8243 .38611 m .82781 .38069 L .83032 .38421 L F
.8243 .38611 m .82178 .3826 L .82781 .38069 L F
.21166 .38596 m .21336 .38054 L .21705 .38406 L .663 .741 .908 r
F
.21166 .38596 m .20796 .38245 L .21336 .38054 L F
.38878 .38596 m .391 .38054 L .39435 .38407 L F
.38878 .38596 m .38542 .38245 L .391 .38054 L F
.74302 .38597 m .74628 .38054 L .74895 .38407 L F
.74302 .38597 m .74034 .38245 L .74628 .38054 L F
.30745 .38582 m .30943 .38039 L .31294 .38392 L .664 .741 .908 r
F
.30745 .38582 m .30394 .3823 L .30943 .38039 L F
.83885 .38582 m .8424 .3804 L .84489 .38392 L .664 .742 .908 r
F
.83885 .38582 m .83636 .38231 L .8424 .3804 L F
.75755 .38567 m .76087 .38025 L .76351 .38377 L .663 .742 .908 r
F
.75755 .38567 m .7549 .38216 L .76087 .38025 L F
.22612 .38567 m .22785 .38025 L .23152 .38378 L .663 .741 .908 r
F
.22612 .38567 m .22245 .38215 L .22785 .38025 L F
.40326 .38568 m .40553 .38025 L .40885 .38378 L .664 .741 .908 r
F
.40326 .38568 m .39993 .38217 L .40553 .38025 L F
.32193 .38553 m .32395 .3801 L .32743 .38363 L .663 .741 .908 r
F
.32193 .38553 m .31844 .38201 L .32395 .3801 L F
.85341 .38553 m .857 .3801 L .85946 .38363 L .664 .741 .908 r
F
.85341 .38553 m .85094 .38201 L .857 .3801 L F
.24058 .38538 m .24236 .37995 L .24599 .38347 L F
.24058 .38538 m .23693 .38186 L .24236 .37995 L F
.7721 .38538 m .77545 .37995 L .77807 .38348 L F
.7721 .38538 m .76948 .38186 L .77545 .37995 L F
.3364 .38524 m .33847 .3798 L .34192 .38333 L F
.3364 .38524 m .33294 .38172 L .33847 .3798 L F
.86797 .38524 m .87161 .3798 L .87404 .38333 L F
.86797 .38524 m .86553 .38172 L .87161 .3798 L F
.61657 .45329 m .6195 .44907 L .62245 .45372 L .477 .569 .87 r
F
.4934 .57577 m .49617 .54478 L .49932 .54836 L .933 .728 .603 r
F
.25504 .38508 m .25686 .37966 L .26047 .38318 L .663 .741 .908 r
F
.25504 .38508 m .25142 .38157 L .25686 .37966 L F
.78665 .38508 m .79005 .37966 L .79263 .38318 L F
.78665 .38508 m .78405 .38157 L .79005 .37966 L F
.88253 .38494 m .88622 .37952 L .88862 .38305 L F
.88253 .38494 m .88012 .38142 L .88622 .37952 L F
.35088 .38494 m .35299 .37951 L .35642 .38304 L .664 .741 .908 r
F
.35088 .38494 m .34745 .38142 L .35299 .37951 L F
.70532 .38495 m .70847 .37953 L .71122 .38304 L .663 .741 .908 r
F
.70532 .38495 m .70256 .38143 L .70847 .37953 L F
.69658 .51332 m .69386 .51259 L .6939 .39552 L .979 .709 .444 r
F
.6939 .39552 m .69114 .39216 L .69667 .38341 L .887 .791 .749 r
F
.69386 .51259 m .69114 .39216 L .6939 .39552 L .979 .708 .443 r
F
.26951 .38479 m .27138 .37936 L .27496 .3829 L .663 .741 .908 r
F
.26951 .38479 m .26592 .38127 L .27138 .37936 L F
.8012 .3848 m .80464 .37937 L .8072 .3829 L F
.8012 .3848 m .79863 .38128 L .80464 .37937 L F
.52025 .42991 m .52286 .4263 L .52596 .42481 L .707 .978 .778 r
F
.41771 .38653 m .41881 .41801 L .42192 .42884 L .958 .632 .358 r
F
.41771 .38653 m .41442 .38267 L .41881 .41801 L F
.18812 .38465 m .18975 .37922 L .19349 .38275 L .663 .741 .908 r
F
.18812 .38465 m .18438 .38113 L .18975 .37922 L F
.36537 .38465 m .36752 .37922 L .37092 .38275 L F
.36537 .38465 m .36196 .38113 L .36752 .37922 L F
.8971 .38466 m .90083 .37922 L .9032 .38274 L .664 .741 .907 r
F
.8971 .38466 m .89472 .38113 L .90083 .37922 L F
.71986 .38467 m .72306 .37922 L .72578 .38276 L .664 .742 .908 r
F
.71986 .38467 m .71713 .38115 L .72306 .37922 L F
.81576 .3845 m .81925 .37907 L .82178 .3826 L F
.81576 .3845 m .81322 .38099 L .81925 .37907 L F
.28398 .38451 m .28589 .37907 L .28945 .3826 L .664 .741 .908 r
F
.28398 .38451 m .28042 .38099 L .28589 .37907 L F
.20258 .38435 m .20425 .37892 L .20796 .38245 L F
.20258 .38435 m .19886 .38083 L .20425 .37892 L F
.37986 .38436 m .38205 .37892 L .38542 .38245 L F
.37986 .38436 m .37648 .38084 L .38205 .37892 L F
.7344 .38436 m .73765 .37892 L .74034 .38245 L .664 .742 .908 r
F
.7344 .38436 m .73171 .38084 L .73765 .37892 L F
.91168 .38436 m .91545 .37892 L .91779 .38245 L F
.91168 .38436 m .90932 .38084 L .91545 .37892 L F
.49617 .54478 m .49302 .5407 L .49883 .52548 L .902 .738 .669 r
F
.49302 .5407 m .49567 .52373 L .49883 .52548 L .919 .771 .681 r
F
.29846 .38421 m .30041 .37877 L .30394 .3823 L .663 .741 .908 r
F
.29846 .38421 m .29492 .38068 L .30041 .37877 L F
.83032 .38421 m .83385 .37878 L .83636 .38231 L F
.83032 .38421 m .82781 .38069 L .83385 .37878 L F
.21705 .38406 m .21876 .37862 L .22245 .38215 L .664 .741 .908 r
F
.21705 .38406 m .21336 .38054 L .21876 .37862 L F
.39435 .38407 m .39659 .37864 L .39993 .38217 L .663 .741 .908 r
F
.39435 .38407 m .391 .38054 L .39659 .37864 L F
.5845 .44728 m .58154 .44539 L .58746 .44997 L .497 0 0 r
F
.74895 .38407 m .75224 .37864 L .7549 .38216 L .663 .741 .908 r
F
.74895 .38407 m .74628 .38054 L .75224 .37864 L F
.31294 .38392 m .31494 .37848 L .31844 .38201 L F
.31294 .38392 m .30943 .38039 L .31494 .37848 L F
.84489 .38392 m .84846 .37848 L .85094 .38201 L .664 .742 .908 r
F
.84489 .38392 m .8424 .3804 L .84846 .37848 L F
.76351 .38377 m .76684 .37834 L .76948 .38186 L F
.76351 .38377 m .76087 .38025 L .76684 .37834 L F
.23152 .38378 m .23327 .37833 L .23693 .38186 L .664 .741 .908 r
F
.23152 .38378 m .22785 .38025 L .23327 .37833 L F
.40885 .38378 m .41111 .37888 L .41442 .38267 L .623 .728 .922 r
F
.40885 .38378 m .40553 .38025 L .41111 .37888 L F
.32743 .38363 m .32947 .37819 L .33294 .38172 L .664 .741 .908 r
F
.32743 .38363 m .32395 .3801 L .32947 .37819 L F
.85946 .38363 m .86308 .37819 L .86553 .38172 L .663 .741 .908 r
F
.85946 .38363 m .857 .3801 L .86308 .37819 L F
.50049 .46271 m .50306 .45392 L .50617 .46305 L .924 .933 .568 r
F
.4938 .42069 m .49072 .40922 L .49638 .41105 L .494 .426 .709 r
F
.48756 .47252 m .49072 .40922 L .4938 .42069 L .962 .721 .527 r
F
.48756 .47252 m .48432 .47074 L .49072 .40922 L F
.49072 .40922 m .49312 .41723 L .49638 .41105 L .703 .395 0 r
F
.48432 .47074 m .48763 .39977 L .49072 .40922 L .95 .706 .532 r
F
.49072 .40922 m .48763 .39977 L .49312 .41723 L .703 .395 0 r
F
.24599 .38347 m .24779 .37803 L .25142 .38157 L .664 .741 .908 r
F
.24599 .38347 m .24236 .37995 L .24779 .37803 L F
.77807 .38348 m .78145 .37803 L .78405 .38157 L F
.77807 .38348 m .77545 .37995 L .78145 .37803 L F
.48432 .47074 m .4811 .46601 L .48763 .39977 L .95 .706 .532 r
F
.48763 .39977 m .48981 .4257 L .49312 .41723 L .96 .623 .274 r
F
.4811 .46601 m .48448 .39391 L .48763 .39977 L .932 .686 .544 r
F
.48763 .39977 m .48448 .39391 L .48981 .4257 L .96 .623 .274 r
F
.34192 .38333 m .344 .37789 L .34745 .38142 L .663 .741 .908 r
F
.34192 .38333 m .33847 .3798 L .344 .37789 L F
.87404 .38333 m .8777 .37789 L .88012 .38142 L F
.87404 .38333 m .87161 .3798 L .8777 .37789 L F
.69667 .38341 m .6998 .37789 L .70256 .38143 L .668 .743 .906 r
F
.69667 .38341 m .6939 .37988 L .6998 .37789 L F
.69114 .39216 m .6939 .37988 L .69667 .38341 L .889 .791 .747 r
F
.26047 .38318 m .26232 .37774 L .26592 .38127 L .664 .741 .908 r
F
.26047 .38318 m .25686 .37966 L .26232 .37774 L F
.79263 .38318 m .79605 .37774 L .79863 .38128 L F
.79263 .38318 m .79005 .37966 L .79605 .37774 L F
.35642 .38304 m .35854 .3776 L .36196 .38113 L .663 .741 .908 r
F
.35642 .38304 m .35299 .37951 L .35854 .3776 L F
.71122 .38304 m .7144 .37761 L .71713 .38115 L .664 .742 .908 r
F
.71122 .38304 m .70847 .37953 L .7144 .37761 L F
.88862 .38305 m .89232 .37759 L .89472 .38113 L F
.88862 .38305 m .88622 .37952 L .89232 .37759 L F
.27496 .3829 m .27684 .37745 L .28042 .38099 L .663 .741 .908 r
F
.27496 .3829 m .27138 .37936 L .27684 .37745 L F
.8072 .3829 m .81067 .37745 L .81322 .38099 L .664 .741 .908 r
F
.8072 .3829 m .80464 .37937 L .81067 .37745 L F
.9032 .38274 m .90696 .37731 L .90932 .38084 L .663 .741 .908 r
F
.9032 .38274 m .90083 .37922 L .90696 .37731 L F
.19349 .38275 m .19513 .3773 L .19886 .38083 L .664 .741 .908 r
F
.19349 .38275 m .18975 .37922 L .19513 .3773 L F
.37092 .38275 m .37309 .3773 L .37648 .38084 L .664 .742 .908 r
F
.37092 .38275 m .36752 .37922 L .37309 .3773 L F
.72578 .38276 m .729 .37731 L .73171 .38084 L .664 .741 .908 r
F
.72578 .38276 m .72306 .37922 L .729 .37731 L F
.61361 .44819 m .61655 .4448 L .6195 .44907 L .43 .573 .896 r
F
.5836 .40069 m .58683 .41763 L .58973 .4161 L .925 .54 .16 r
F
.28945 .3826 m .29138 .37715 L .29492 .38068 L .664 .741 .908 r
F
.28945 .3826 m .28589 .37907 L .29138 .37715 L F
.82178 .3826 m .82529 .37715 L .82781 .38069 L F
.82178 .3826 m .81925 .37907 L .82529 .37715 L F
.4908 .47228 m .4938 .42069 L .49688 .4326 L .972 .74 .529 r
F
.4908 .47228 m .48756 .47252 L .4938 .42069 L F
.20796 .38245 m .20965 .377 L .21336 .38054 L .663 .741 .908 r
F
.20796 .38245 m .20425 .37892 L .20965 .377 L F
.38542 .38245 m .38764 .37701 L .391 .38054 L F
.38542 .38245 m .38205 .37892 L .38764 .37701 L F
.74034 .38245 m .7436 .377 L .74628 .38054 L .664 .741 .908 r
F
.74034 .38245 m .73765 .37892 L .7436 .377 L F
.30394 .3823 m .30591 .37686 L .30943 .38039 L .663 .741 .908 r
F
.30394 .3823 m .30041 .37877 L .30591 .37686 L F
.83636 .38231 m .83991 .37686 L .8424 .3804 L .664 .741 .908 r
F
.83636 .38231 m .83385 .37878 L .83991 .37686 L F
.22245 .38215 m .22418 .37671 L .22785 .38025 L .663 .741 .908 r
F
.22245 .38215 m .21876 .37862 L .22418 .37671 L F
.7549 .38216 m .75822 .37672 L .76087 .38025 L .664 .742 .908 r
F
.7549 .38216 m .75224 .37864 L .75822 .37672 L F
.39993 .38217 m .40219 .37672 L .40553 .38025 L .664 .741 .908 r
F
.39993 .38217 m .39659 .37864 L .40219 .37672 L F
.31844 .38201 m .32045 .37656 L .32395 .3801 L .663 .741 .908 r
F
.31844 .38201 m .31494 .37848 L .32045 .37656 L F
.85094 .38201 m .85454 .37656 L .857 .3801 L F
.85094 .38201 m .84846 .37848 L .85454 .37656 L F
.23693 .38186 m .23871 .37641 L .24236 .37995 L .664 .741 .908 r
F
.23693 .38186 m .23327 .37833 L .23871 .37641 L F
.76948 .38186 m .77283 .37642 L .77545 .37995 L .664 .742 .908 r
F
.76948 .38186 m .76684 .37834 L .77283 .37642 L F
.4934 .57577 m .49023 .57188 L .49617 .54478 L .933 .728 .603 r
F
.49023 .57188 m .49302 .5407 L .49617 .54478 L .931 .726 .604 r
F
.33294 .38172 m .335 .37626 L .33847 .3798 L .664 .741 .908 r
F
.33294 .38172 m .32947 .37819 L .335 .37626 L F
.86553 .38172 m .86917 .37626 L .87161 .3798 L .664 .742 .908 r
F
.86553 .38172 m .86308 .37819 L .86917 .37626 L F
.47306 .40354 m .4697 .40903 L .47484 .44317 L .898 .576 .429 r
F
.25142 .38157 m .25324 .37612 L .25686 .37966 L .663 .741 .908 r
F
.25142 .38157 m .24779 .37803 L .25324 .37612 L F
.78405 .38157 m .78745 .37611 L .79005 .37966 L F
.78405 .38157 m .78145 .37803 L .78745 .37611 L F
.59555 .41684 m .59264 .41624 L .59889 .43359 L .909 .511 .232 r
F
.88012 .38142 m .8838 .37597 L .88622 .37952 L .664 .741 .908 r
F
.88012 .38142 m .8777 .37789 L .8838 .37597 L F
.34745 .38142 m .34955 .37597 L .35299 .37951 L .663 .741 .908 r
F
.34745 .38142 m .344 .37789 L .34955 .37597 L F
.70256 .38143 m .70572 .37599 L .70847 .37953 L .662 .741 .908 r
F
.70256 .38143 m .6998 .37789 L .70572 .37599 L F
.41442 .38267 m .41568 .40786 L .41881 .41801 L .954 .616 .328 r
F
.41442 .38267 m .41111 .37888 L .41568 .40786 L F
.69386 .51259 m .69113 .51196 L .69114 .39216 L .979 .708 .443 r
F
.69114 .39216 m .68836 .38879 L .6939 .37988 L .889 .791 .747 r
F
.69113 .51196 m .68836 .38879 L .69114 .39216 L .98 .709 .441 r
F
.26592 .38127 m .26778 .37582 L .27138 .37936 L .664 .741 .908 r
F
.26592 .38127 m .26232 .37774 L .26778 .37582 L F
.79863 .38128 m .80207 .37582 L .80464 .37937 L F
.79863 .38128 m .79605 .37774 L .80207 .37582 L F
.49404 .47025 m .49688 .4326 L .49997 .44381 L .984 .77 .535 r
F
.49404 .47025 m .4908 .47228 L .49688 .4326 L F
.4811 .46601 m .47794 .45703 L .48448 .39391 L .932 .686 .544 r
F
.48448 .39391 m .48645 .43442 L .48981 .4257 L .948 .625 .385 r
F
.48448 .39391 m .48127 .39285 L .48645 .43442 L F
.18438 .38113 m .18599 .37568 L .18975 .37922 L .663 .741 .908 r
F
.18438 .38113 m .18062 .37759 L .18599 .37568 L F
.36196 .38113 m .36411 .37568 L .36752 .37922 L F
.36196 .38113 m .35854 .3776 L .36411 .37568 L F
.89472 .38113 m .89845 .37568 L .90083 .37922 L F
.89472 .38113 m .89232 .37759 L .89845 .37568 L F
.71713 .38115 m .72033 .37568 L .72306 .37922 L .664 .741 .908 r
F
.71713 .38115 m .7144 .37761 L .72033 .37568 L F
.50832 .42246 m .51082 .43621 L .51399 .43369 L .766 .382 .327 r
F
.50832 .42246 m .50513 .42732 L .51082 .43621 L F
.28042 .38099 m .28232 .37553 L .28589 .37907 L .664 .741 .908 r
F
.28042 .38099 m .27684 .37745 L .28232 .37553 L F
.81322 .38099 m .8167 .37553 L .81925 .37907 L .664 .741 .907 r
F
.81322 .38099 m .81067 .37745 L .8167 .37553 L F
.19886 .38083 m .20053 .37538 L .20425 .37892 L .664 .741 .908 r
F
.19886 .38083 m .19513 .3773 L .20053 .37538 L F
.37648 .38084 m .37867 .37538 L .38205 .37892 L F
.37648 .38084 m .37309 .3773 L .37867 .37538 L F
.90932 .38084 m .91309 .37538 L .91545 .37892 L .664 .742 .908 r
F
.90932 .38084 m .90696 .37731 L .91309 .37538 L F
.73171 .38084 m .73495 .37538 L .73765 .37892 L .664 .741 .908 r
F
.73171 .38084 m .729 .37731 L .73495 .37538 L F
.29492 .38068 m .29687 .37523 L .30041 .37877 L .663 .741 .908 r
F
.29492 .38068 m .29138 .37715 L .29687 .37523 L F
.82781 .38069 m .83134 .37523 L .83385 .37878 L .664 .741 .908 r
F
.82781 .38069 m .82529 .37715 L .83134 .37523 L F
.21336 .38054 m .21506 .37508 L .21876 .37862 L F
.21336 .38054 m .20965 .377 L .21506 .37508 L F
.391 .38054 m .39323 .37509 L .39659 .37864 L .663 .741 .908 r
F
.391 .38054 m .38764 .37701 L .39323 .37509 L F
.74628 .38054 m .74957 .37509 L .75224 .37864 L F
.74628 .38054 m .7436 .377 L .74957 .37509 L F
.30943 .38039 m .31142 .37494 L .31494 .37848 L F
.30943 .38039 m .30591 .37686 L .31142 .37494 L F
.8424 .3804 m .84598 .37494 L .84846 .37848 L F
.8424 .3804 m .83991 .37686 L .84598 .37494 L F
.49728 .46666 m .49997 .44381 L .50306 .45392 L .998 .829 .546 r
F
.49728 .46666 m .49404 .47025 L .49997 .44381 L F
.40553 .38025 m .40779 .37515 L .41111 .37888 L .638 .733 .918 r
F
.40553 .38025 m .40219 .37672 L .40779 .37515 L F
.22785 .38025 m .2296 .37479 L .23327 .37833 L .664 .741 .908 r
F
.22785 .38025 m .22418 .37671 L .2296 .37479 L F
.76087 .38025 m .7642 .37479 L .76684 .37834 L .664 .742 .908 r
F
.76087 .38025 m .75822 .37672 L .7642 .37479 L F
.857 .3801 m .86062 .37465 L .86308 .37819 L .663 .741 .908 r
F
.857 .3801 m .85454 .37656 L .86062 .37465 L F
.32395 .3801 m .32598 .37464 L .32947 .37819 L .664 .741 .908 r
F
.32395 .3801 m .32045 .37656 L .32598 .37464 L F
.77545 .37995 m .77883 .37449 L .78145 .37803 L .664 .742 .908 r
F
.77545 .37995 m .77283 .37642 L .77883 .37449 L F
.24236 .37995 m .24415 .37449 L .24779 .37803 L .664 .741 .908 r
F
.24236 .37995 m .23871 .37641 L .24415 .37449 L F
.49302 .5407 m .48985 .53787 L .49567 .52373 L .919 .771 .681 r
F
.48985 .53787 m .49248 .5228 L .49567 .52373 L .923 .792 .698 r
F
.87161 .3798 m .87527 .37434 L .8777 .37789 L .663 .741 .908 r
F
.87161 .3798 m .86917 .37626 L .87527 .37434 L F
.33847 .3798 m .34054 .37434 L .344 .37789 L F
.33847 .3798 m .335 .37626 L .34054 .37434 L F
.61616 .42325 m .61327 .42164 L .61679 .40632 L .97 .781 .592 r
F
.61736 .40798 m .61679 .40632 L .61786 .40169 L F
.61616 .42325 m .61679 .40632 L .61736 .40798 L F
.61616 .42325 m .61786 .40169 L .61817 .40244 L F
.61327 .42164 m .61562 .39633 L .61852 .39882 L .979 .787 .576 r
F
.61327 .42164 m .61039 .42081 L .61335 .40693 L F
.61429 .41062 m .61335 .40693 L .61562 .39633 L F
.61327 .42164 m .61335 .40693 L .61429 .41062 L F
.61039 .42081 m .61273 .39466 L .61562 .39633 L .988 .795 .558 r
F
.61562 .39633 m .61273 .39466 L .61879 .40446 L .822 .346 0 r
F
.61889 .40458 m .61879 .40446 L .61893 .40468 L F
.61562 .39633 m .61879 .40446 L .61889 .40458 L F
.61879 .40446 m .61586 .39715 L .61893 .40468 L .463 0 0 r
F
.61288 .39491 m .61586 .39715 L .61879 .40446 L F
.61273 .39466 m .61282 .39474 L .61288 .39491 L F
.61282 .39474 m .61586 .39715 L .61288 .39491 L F
.61039 .42081 m .60751 .42098 L .61273 .39466 L .988 .795 .558 r
F
.60751 .42098 m .60985 .39372 L .61273 .39466 L .995 .801 .534 r
F
.61273 .39466 m .60985 .39372 L .61586 .39715 L .463 0 0 r
F
.61052 .3941 m .61279 .38976 L .61586 .39715 L .727 .987 .885 r
F
.61002 .39382 m .61015 .39363 L .61052 .3941 L F
.61015 .39363 m .61279 .38976 L .61052 .3941 L F
.60985 .39372 m .60996 .39357 L .61002 .39382 L F
.60996 .39357 m .61279 .38976 L .61002 .39382 L F
.61575 .39667 m .61893 .40468 L .62199 .41206 L .822 .346 0 r
F
.61562 .39633 m .6157 .39654 L .61575 .39667 L F
.6157 .39654 m .61893 .40468 L .61575 .39667 L F
.61817 .40244 m .61786 .40169 L .61852 .39882 L .97 .781 .592 r
F
.61852 .39882 m .61562 .39633 L .62199 .41206 L .895 .476 .1 r
F
.61064 .44365 m .61358 .44026 L .61655 .4448 L .421 .561 .889 r
F
.61064 .44365 m .60767 .43895 L .61358 .44026 L F
.6939 .37988 m .69703 .37435 L .6998 .37789 L .667 .741 .906 r
F
.6939 .37988 m .69111 .37632 L .69703 .37435 L F
.68836 .38879 m .69111 .37632 L .6939 .37988 L .898 .798 .742 r
F
.58154 .44539 m .58441 .44367 L .58746 .44997 L .234 .482 .889 r
F
.58154 .44539 m .57853 .44116 L .58441 .44367 L F
.25686 .37966 m .2587 .37419 L .26232 .37774 L .664 .741 .908 r
F
.25686 .37966 m .25324 .37612 L .2587 .37419 L F
.79005 .37966 m .79347 .37419 L .79605 .37774 L .663 .741 .908 r
F
.79005 .37966 m .78745 .37611 L .79347 .37419 L F
.52286 .4263 m .51973 .42923 L .52548 .40934 L .996 .864 .571 r
F
.52548 .40934 m .52237 .41298 L .52811 .40169 L .887 .938 .567 r
F
.35299 .37951 m .35511 .37406 L .35854 .3776 L .663 .741 .908 r
F
.35299 .37951 m .34955 .37597 L .35511 .37406 L F
.88622 .37952 m .88992 .37405 L .89232 .37759 L F
.88622 .37952 m .8838 .37597 L .88992 .37405 L F
.70847 .37953 m .71165 .37406 L .7144 .37761 L .664 .742 .908 r
F
.70847 .37953 m .70572 .37599 L .71165 .37406 L F
.49638 .41105 m .49866 .43852 L .50191 .43303 L .855 .515 .409 r
F
.49638 .41105 m .49312 .41723 L .49866 .43852 L F
.27138 .37936 m .27325 .3739 L .27684 .37745 L .663 .741 .908 r
F
.27138 .37936 m .26778 .37582 L .27325 .3739 L F
.80464 .37937 m .80811 .3739 L .81067 .37745 L .664 .741 .907 r
F
.80464 .37937 m .80207 .37582 L .80811 .3739 L F
.90083 .37922 m .90458 .37376 L .90696 .37731 L .664 .742 .908 r
F
.90083 .37922 m .89845 .37568 L .90458 .37376 L F
.18975 .37922 m .19138 .37375 L .19513 .3773 L .664 .741 .908 r
F
.18975 .37922 m .18599 .37568 L .19138 .37375 L F
.36752 .37922 m .36968 .37375 L .37309 .3773 L .664 .742 .908 r
F
.36752 .37922 m .36411 .37568 L .36968 .37375 L F
.72306 .37922 m .72628 .37375 L .729 .37731 L F
.72306 .37922 m .72033 .37568 L .72628 .37375 L F
.57825 .42814 m .57522 .42462 L .5806 .39702 L .95 .74 .584 r
F
.5806 .39702 m .58395 .42153 L .58683 .41763 L .945 .584 .266 r
F
.57522 .42462 m .57762 .39439 L .5806 .39702 L .898 .69 .614 r
F
.5806 .39702 m .57762 .39439 L .58395 .42153 L .945 .584 .266 r
F
.28589 .37907 m .28781 .3736 L .29138 .37715 L .664 .741 .908 r
F
.28589 .37907 m .28232 .37553 L .28781 .3736 L F
.81925 .37907 m .82275 .3736 L .82529 .37715 L F
.81925 .37907 m .8167 .37553 L .82275 .3736 L F
.54577 .40429 m .54271 .40339 L .54861 .41943 L .906 .504 .223 r
F
.20425 .37892 m .20593 .37345 L .20965 .377 L .663 .741 .908 r
F
.20425 .37892 m .20053 .37538 L .20593 .37345 L F
.38205 .37892 m .38426 .37346 L .38764 .37701 L F
.38205 .37892 m .37867 .37538 L .38426 .37346 L F
.73765 .37892 m .74091 .37346 L .7436 .377 L .664 .741 .908 r
F
.73765 .37892 m .73495 .37538 L .74091 .37346 L F
.49023 .57188 m .48705 .56783 L .49302 .5407 L .931 .726 .604 r
F
.30041 .37877 m .30238 .37331 L .30591 .37686 L .663 .741 .908 r
F
.30041 .37877 m .29687 .37523 L .30238 .37331 L F
.83385 .37878 m .8374 .3733 L .83991 .37686 L .664 .741 .908 r
F
.83385 .37878 m .83134 .37523 L .8374 .3733 L F
.21876 .37862 m .22048 .37316 L .22418 .37671 L .663 .741 .908 r
F
.21876 .37862 m .21506 .37508 L .22048 .37316 L F
.39659 .37864 m .39884 .37317 L .40219 .37672 L F
.39659 .37864 m .39323 .37509 L .39884 .37317 L F
.75224 .37864 m .75555 .37317 L .75822 .37672 L F
.75224 .37864 m .74957 .37509 L .75555 .37317 L F
.31494 .37848 m .31695 .37301 L .32045 .37656 L .664 .741 .908 r
F
.31494 .37848 m .31142 .37494 L .31695 .37301 L F
.84846 .37848 m .85206 .37302 L .85454 .37656 L .663 .741 .908 r
F
.84846 .37848 m .84598 .37494 L .85206 .37302 L F
.23327 .37833 m .23504 .37286 L .23871 .37641 L .664 .741 .908 r
F
.23327 .37833 m .2296 .37479 L .23504 .37286 L F
.76684 .37834 m .7702 .37286 L .77283 .37642 L F
.76684 .37834 m .7642 .37479 L .7702 .37286 L F
.61655 .4448 m .61358 .44026 L .61907 .42609 L .902 .74 .671 r
F
.61358 .44026 m .61616 .42325 L .61907 .42609 L .919 .769 .68 r
F
.32947 .37819 m .33152 .37271 L .335 .37626 L .664 .741 .908 r
F
.32947 .37819 m .32598 .37464 L .33152 .37271 L F
.86308 .37819 m .86672 .37271 L .86917 .37626 L .664 .742 .908 r
F
.86308 .37819 m .86062 .37465 L .86672 .37271 L F
.71758 .62285 m .71437 .61281 L .71363 .49026 L .96 .688 .474 r
F
.71437 .61281 m .71131 .49452 L .71363 .49026 L .956 .686 .483 r
F
.78145 .37803 m .78484 .37256 L .78745 .37611 L .663 .741 .908 r
F
.78145 .37803 m .77883 .37449 L .78484 .37256 L F
.24779 .37803 m .2496 .37256 L .25324 .37612 L F
.24779 .37803 m .24415 .37449 L .2496 .37256 L F
.41111 .37888 m .41253 .39843 L .41568 .40786 L .947 .592 .284 r
F
.41111 .37888 m .40779 .37515 L .41253 .39843 L F
.344 .37789 m .3461 .37242 L .34955 .37597 L .663 .741 .908 r
F
.344 .37789 m .34054 .37434 L .3461 .37242 L F
.8777 .37789 m .88138 .37242 L .8838 .37597 L F
.8777 .37789 m .87527 .37434 L .88138 .37242 L F
.6998 .37789 m .70296 .37243 L .70572 .37599 L F
.6998 .37789 m .69703 .37435 L .70296 .37243 L F
.26232 .37774 m .26417 .37227 L .26778 .37582 L .664 .741 .908 r
F
.26232 .37774 m .2587 .37419 L .26417 .37227 L F
.79605 .37774 m .7995 .37227 L .80207 .37582 L .663 .741 .908 r
F
.79605 .37774 m .79347 .37419 L .7995 .37227 L F
.69113 .51196 m .6884 .51175 L .68836 .38879 L .98 .709 .441 r
F
.68836 .38879 m .68558 .3856 L .69111 .37632 L .898 .798 .742 r
F
.6884 .51175 m .68558 .3856 L .68836 .38879 L .977 .705 .447 r
F
.18062 .37759 m .18223 .37212 L .18599 .37568 L .663 .741 .908 r
F
.18062 .37759 m .17684 .37404 L .18223 .37212 L F
.89232 .37759 m .89605 .37213 L .89845 .37568 L .663 .742 .908 r
F
.89232 .37759 m .88992 .37405 L .89605 .37213 L F
.35854 .3776 m .36068 .37213 L .36411 .37568 L .664 .742 .908 r
F
.35854 .3776 m .35511 .37406 L .36068 .37213 L F
.7144 .37761 m .7176 .37213 L .72033 .37568 L F
.7144 .37761 m .71165 .37406 L .7176 .37213 L F
.81067 .37745 m .81415 .37197 L .8167 .37553 L .663 .741 .908 r
F
.81067 .37745 m .80811 .3739 L .81415 .37197 L F
.27684 .37745 m .27874 .37197 L .28232 .37553 L .664 .741 .908 r
F
.27684 .37745 m .27325 .3739 L .27874 .37197 L F
.19513 .3773 m .19679 .37182 L .20053 .37538 L F
.19513 .3773 m .19138 .37375 L .19679 .37182 L F
.37309 .3773 m .37527 .37182 L .37867 .37538 L F
.37309 .3773 m .36968 .37375 L .37527 .37182 L F
.729 .37731 m .73224 .37182 L .73495 .37538 L F
.729 .37731 m .72628 .37375 L .73224 .37182 L F
.90696 .37731 m .91073 .37182 L .91309 .37538 L F
.90696 .37731 m .90458 .37376 L .91073 .37182 L F
.29138 .37715 m .29332 .37168 L .29687 .37523 L .663 .741 .908 r
F
.29138 .37715 m .28781 .3736 L .29332 .37168 L F
.82529 .37715 m .82882 .37168 L .83134 .37523 L F
.82529 .37715 m .82275 .3736 L .82882 .37168 L F
.44639 .39906 m .4433 .3887 L .44747 .38956 L .51 .451 .727 r
F
.44639 .39906 m .44747 .38956 L .44803 .393 L F
.4433 .3887 m .4458 .37917 L .44888 .38984 L .727 .668 .792 r
F
.4494 .41279 m .44639 .39906 L .4514 .40546 L .281 .259 .656 r
F
.45162 .40668 m .4514 .40546 L .45185 .40603 L F
.4494 .41279 m .4514 .40546 L .45162 .40668 L F
.44639 .39906 m .44888 .38984 L .45185 .40603 L .51 .451 .727 r
F
.45238 .42846 m .4494 .41279 L .45424 .42417 L .036 .07 .566 r
F
.4545 .42574 m .45424 .42417 L .45476 .4254 L F
.45238 .42846 m .45424 .42417 L .4545 .42574 L F
.4494 .41279 m .45185 .40603 L .45476 .4254 L .281 .259 .656 r
F
.45536 .44472 m .45238 .42846 L .4572 .44412 L 0 0 .461 r
F
.45744 .44555 m .4572 .44412 L .45767 .44564 L F
.45536 .44472 m .4572 .44412 L .45744 .44555 L F
.44862 .49231 m .45238 .42846 L .45536 .44472 L .873 .635 .576 r
F
.45238 .42846 m .45476 .4254 L .45767 .44564 L .036 .07 .566 r
F
.45 .40094 m .45057 .4161 L .45351 .43577 L .958 .644 .23 r
F
.44946 .39561 m .44963 .39873 L .45 .40094 L F
.44963 .39873 m .45057 .4161 L .45 .40094 L F
.44917 .39272 m .44928 .39451 L .44946 .39561 L F
.44928 .39451 m .45057 .4161 L .44946 .39561 L F
.44888 .38984 m .44901 .39177 L .44917 .39272 L F
.44901 .39177 m .45057 .4161 L .44917 .39272 L F
.44583 .37948 m .44766 .3962 L .45057 .4161 L .937 .565 .245 r
F
.4458 .37917 m .44582 .37936 L .44583 .37948 L F
.44582 .37936 m .44766 .3962 L .44583 .37948 L F
.44803 .393 m .44747 .38956 L .44888 .38984 L .51 .451 .727 r
F
.43981 .4367 m .4433 .3887 L .44639 .39906 L .821 .597 .599 r
F
.43981 .4367 m .43692 .41783 L .4433 .3887 L F
.4433 .3887 m .44009 .38306 L .4458 .37917 L .727 .668 .792 r
F
.43692 .41783 m .44009 .38306 L .4433 .3887 L .777 .571 .622 r
F
.20965 .377 m .21135 .37152 L .21506 .37508 L .664 .741 .908 r
F
.20965 .377 m .20593 .37345 L .21135 .37152 L F
.7436 .377 m .74689 .37153 L .74957 .37509 L .664 .742 .908 r
F
.7436 .377 m .74091 .37346 L .74689 .37153 L F
.38764 .37701 m .38986 .37154 L .39323 .37509 L .663 .741 .908 r
F
.38764 .37701 m .38426 .37346 L .38986 .37154 L F
.60767 .43895 m .61063 .43678 L .61358 .44026 L .338 .591 .938 r
F
.83991 .37686 m .84348 .37139 L .84598 .37494 L .663 .741 .908 r
F
.83991 .37686 m .8374 .3733 L .84348 .37139 L F
.30591 .37686 m .3079 .37138 L .31142 .37494 L F
.30591 .37686 m .30238 .37331 L .3079 .37138 L F
.22418 .37671 m .22592 .37123 L .2296 .37479 L .664 .741 .908 r
F
.22418 .37671 m .22048 .37316 L .22592 .37123 L F
.40219 .37672 m .40445 .37147 L .40779 .37515 L .648 .737 .914 r
F
.40219 .37672 m .39884 .37317 L .40445 .37147 L F
.75822 .37672 m .76155 .37123 L .7642 .37479 L .664 .741 .908 r
F
.75822 .37672 m .75555 .37317 L .76155 .37123 L F
.44271 .4561 m .44639 .39906 L .4494 .41279 L .844 .612 .587 r
F
.44271 .4561 m .43981 .4367 L .44639 .39906 L F
.57853 .44116 m .5813 .43401 L .58441 .44367 L .808 .83 .867 r
F
.32045 .37656 m .32248 .37108 L .32598 .37464 L .664 .741 .908 r
F
.32045 .37656 m .31695 .37301 L .32248 .37108 L F
.85454 .37656 m .85815 .37109 L .86062 .37465 L .664 .742 .908 r
F
.85454 .37656 m .85206 .37302 L .85815 .37109 L F
.23871 .37641 m .24049 .37093 L .24415 .37449 L .664 .741 .908 r
F
.23871 .37641 m .23504 .37286 L .24049 .37093 L F
.77283 .37642 m .7762 .37093 L .77883 .37449 L .664 .742 .908 r
F
.77283 .37642 m .7702 .37286 L .7762 .37093 L F
.59264 .41624 m .59596 .43272 L .59889 .43359 L .902 .502 .239 r
F
.59264 .41624 m .58973 .4161 L .59596 .43272 L F
.86917 .37626 m .87283 .37078 L .87527 .37434 L .663 .741 .908 r
F
.86917 .37626 m .86672 .37271 L .87283 .37078 L F
.335 .37626 m .33707 .37078 L .34054 .37434 L F
.335 .37626 m .33152 .37271 L .33707 .37078 L F
.47794 .45703 m .47484 .44317 L .48127 .39285 L .898 .657 .565 r
F
.48127 .39285 m .4831 .44047 L .48645 .43442 L .919 .602 .428 r
F
.47484 .44317 m .47796 .39711 L .48127 .39285 L .824 .6 .6 r
F
.48127 .39285 m .47796 .39711 L .4831 .44047 L .919 .602 .428 r
F
.69111 .37632 m .69424 .37079 L .69703 .37435 L .667 .743 .907 r
F
.69111 .37632 m .68832 .37278 L .69424 .37079 L F
.68558 .3856 m .68832 .37278 L .69111 .37632 L .895 .791 .737 r
F
.78745 .37611 m .79087 .37064 L .79347 .37419 L .663 .741 .908 r
F
.78745 .37611 m .78484 .37256 L .79087 .37064 L F
.25324 .37612 m .25507 .37064 L .2587 .37419 L F
.25324 .37612 m .2496 .37256 L .25507 .37064 L F
.34955 .37597 m .35167 .3705 L .35511 .37406 L F
.34955 .37597 m .3461 .37242 L .35167 .3705 L F
.8838 .37597 m .88751 .37049 L .88992 .37405 L F
.8838 .37597 m .88138 .37242 L .88751 .37049 L F
.70572 .37599 m .7089 .37051 L .71165 .37406 L .663 .74 .908 r
F
.70572 .37599 m .70296 .37243 L .7089 .37051 L F
.80207 .37582 m .80554 .37035 L .80811 .3739 L .663 .742 .908 r
F
.80207 .37582 m .7995 .37227 L .80554 .37035 L F
.26778 .37582 m .26965 .37034 L .27325 .3739 L .663 .741 .908 r
F
.26778 .37582 m .26417 .37227 L .26965 .37034 L F
.18599 .37568 m .18762 .37019 L .19138 .37375 L .664 .741 .908 r
F
.18599 .37568 m .18223 .37212 L .18762 .37019 L F
.89845 .37568 m .9022 .37019 L .90458 .37376 L F
.89845 .37568 m .89605 .37213 L .9022 .37019 L F
.72033 .37568 m .72355 .37019 L .72628 .37375 L F
.72033 .37568 m .7176 .37213 L .72355 .37019 L F
.36411 .37568 m .36627 .37019 L .36968 .37375 L F
.36411 .37568 m .36068 .37213 L .36627 .37019 L F
.8167 .37553 m .82021 .37004 L .82275 .3736 L F
.8167 .37553 m .81415 .37197 L .82021 .37004 L F
.28232 .37553 m .28424 .37004 L .28781 .3736 L F
.28232 .37553 m .27874 .37197 L .28424 .37004 L F
.55729 .39997 m .55425 .39871 L .56045 .4339 L .948 .608 .34 r
F
.20053 .37538 m .2022 .36989 L .20593 .37345 L .663 .741 .908 r
F
.20053 .37538 m .19679 .37182 L .2022 .36989 L F
.37867 .37538 m .38087 .36989 L .38426 .37346 L F
.37867 .37538 m .37527 .37182 L .38087 .36989 L F
.73495 .37538 m .73821 .3699 L .74091 .37346 L F
.73495 .37538 m .73224 .37182 L .73821 .3699 L F
.52237 .41298 m .52501 .39826 L .52811 .40169 L .977 .882 .513 r
F
.52811 .40169 m .52501 .39826 L .5308 .41624 L .919 .526 .157 r
F
.83134 .37523 m .83489 .36975 L .8374 .3733 L .663 .741 .908 r
F
.83134 .37523 m .82882 .37168 L .83489 .36975 L F
.29687 .37523 m .29883 .36975 L .30238 .37331 L F
.29687 .37523 m .29332 .37168 L .29883 .36975 L F
.57522 .42462 m .57213 .4172 L .57762 .39439 L .898 .69 .614 r
F
.57762 .39439 m .58107 .42686 L .58395 .42153 L .943 .598 .334 r
F
.57213 .4172 m .57465 .39371 L .57762 .39439 L .787 .606 .656 r
F
.57762 .39439 m .57465 .39371 L .58107 .42686 L .943 .598 .334 r
F
.21506 .37508 m .21678 .3696 L .22048 .37316 L .663 .741 .908 r
F
.21506 .37508 m .21135 .37152 L .21678 .3696 L F
.74957 .37509 m .75288 .3696 L .75555 .37317 L F
.74957 .37509 m .74689 .37153 L .75288 .3696 L F
.39323 .37509 m .39548 .36962 L .39884 .37317 L .662 .741 .908 r
F
.39323 .37509 m .38986 .37154 L .39548 .36962 L F
.48985 .53787 m .48666 .53557 L .49248 .5228 L .923 .792 .698 r
F
.48666 .53557 m .48929 .52054 L .49248 .5228 L .884 .752 .711 r
F
.84598 .37494 m .84957 .36945 L .85206 .37302 L .664 .742 .908 r
F
.84598 .37494 m .84348 .37139 L .84957 .36945 L F
.31142 .37494 m .31343 .36945 L .31695 .37301 L F
.31142 .37494 m .3079 .37138 L .31343 .36945 L F
.2296 .37479 m .23136 .36929 L .23504 .37286 L .664 .741 .908 r
F
.2296 .37479 m .22592 .37123 L .23136 .36929 L F
.7642 .37479 m .76755 .36929 L .7702 .37286 L F
.7642 .37479 m .76155 .37123 L .76755 .36929 L F
.43692 .41783 m .434 .40071 L .44009 .38306 L .777 .571 .622 r
F
.44009 .38306 m .44252 .37596 L .4458 .37917 L .912 .951 .81 r
F
.44009 .38306 m .43671 .38319 L .44252 .37596 L F
.434 .40071 m .43671 .38319 L .44009 .38306 L .638 .495 .672 r
F
.32598 .37464 m .32803 .36914 L .33152 .37271 L .664 .741 .908 r
F
.32598 .37464 m .32248 .37108 L .32803 .36914 L F
.86062 .37465 m .86426 .36914 L .86672 .37271 L F
.86062 .37465 m .85815 .37109 L .86426 .36914 L F
.40779 .37515 m .40936 .38977 L .41253 .39843 L .934 .555 .219 r
F
.40779 .37515 m .40445 .37147 L .40936 .38977 L F
.63912 .40193 m .64338 .43178 L .64627 .43447 L .952 .6 .244 r
F
.77883 .37449 m .78223 .369 L .78484 .37256 L .663 .741 .908 r
F
.77883 .37449 m .7762 .37093 L .78223 .369 L F
.24415 .37449 m .24595 .369 L .2496 .37256 L F
.24415 .37449 m .24049 .37093 L .24595 .369 L F
.61358 .44026 m .61063 .43678 L .61616 .42325 L .919 .769 .68 r
F
.61063 .43678 m .61327 .42164 L .61616 .42325 L .951 .822 .681 r
F
.44564 .47496 m .4494 .41279 L .45238 .42846 L .859 .623 .58 r
F
.44564 .47496 m .44271 .4561 L .4494 .41279 L F
.34054 .37434 m .34263 .36886 L .3461 .37242 L .663 .741 .908 r
F
.34054 .37434 m .33707 .37078 L .34263 .36886 L F
.87527 .37434 m .87895 .36886 L .88138 .37242 L F
.87527 .37434 m .87283 .37078 L .87895 .36886 L F
.69703 .37435 m .70018 .36885 L .70296 .37243 L .664 .742 .908 r
F
.69703 .37435 m .69424 .37079 L .70018 .36885 L F
.2587 .37419 m .26055 .3687 L .26417 .37227 L .664 .741 .908 r
F
.2587 .37419 m .25507 .37064 L .26055 .3687 L F
.79347 .37419 m .79691 .36872 L .7995 .37227 L .663 .741 .908 r
F
.79347 .37419 m .79087 .37064 L .79691 .36872 L F
.17684 .37404 m .17844 .36855 L .18223 .37212 L F
.17684 .37404 m .17305 .37048 L .17844 .36855 L F
.88992 .37405 m .89365 .36855 L .89605 .37213 L .664 .742 .908 r
F
.88992 .37405 m .88751 .37049 L .89365 .36855 L F
.35511 .37406 m .35724 .36856 L .36068 .37213 L F
.35511 .37406 m .35167 .3705 L .35724 .36856 L F
.71165 .37406 m .71485 .36856 L .7176 .37213 L .665 .742 .908 r
F
.71165 .37406 m .7089 .37051 L .71485 .36856 L F
.54018 .43831 m .53705 .43085 L .54271 .40339 L .908 .691 .598 r
F
.54271 .40339 m .53966 .4054 L .5455 .41302 L .78 .337 .197 r
F
.67961 .48613 m .68462 .52029 L .68734 .52069 L .935 .582 .329 r
F
.68504 .51393 m .6819 .50543 L .6884 .51175 L .202 .296 .737 r
F
.6819 .50543 m .68557 .50974 L .6884 .51175 L 0 0 .516 r
F
.6884 .51175 m .68557 .50974 L .68558 .3856 L .977 .705 .447 r
F
.68558 .3856 m .68278 .38222 L .68832 .37278 L .895 .791 .737 r
F
.68557 .50974 m .68278 .38222 L .68558 .3856 L .973 .701 .454 r
F
.80811 .3739 m .81159 .36841 L .81415 .37197 L .664 .742 .908 r
F
.80811 .3739 m .80554 .37035 L .81159 .36841 L F
.27325 .3739 m .27514 .3684 L .27874 .37197 L .664 .741 .908 r
F
.27325 .3739 m .26965 .37034 L .27514 .3684 L F
.44888 .38984 m .4458 .37917 L .45057 .4161 L .958 .644 .23 r
F
.4458 .37917 m .44252 .37596 L .44611 .39011 L .937 .565 .245 r
F
.44723 .3923 m .44611 .39011 L .44766 .3962 L F
.4458 .37917 m .44611 .39011 L .44723 .3923 L F
.44252 .37596 m .44469 .37951 L .44766 .3962 L .313 0 .06 r
F
.44252 .37596 m .439 .3811 L .44335 .37988 L F
.4436 .37772 m .44335 .37988 L .44469 .37951 L F
.44252 .37596 m .44335 .37988 L .4436 .37772 L F
.44287 .38422 m .44313 .39707 L .446 .41964 L .939 .597 .352 r
F
.43996 .37915 m .439 .3811 L .44252 .37596 L 0 0 0 r
F
.43671 .38319 m .439 .3811 L .43996 .37915 L F
.434 .40071 m .431 .38669 L .43671 .38319 L .638 .495 .672 r
F
.43818 .38229 m .43524 .39391 L .439 .3811 L .139 0 .202 r
F
.43313 .3896 m .43524 .39391 L .43818 .38229 L F
.42808 .45226 m .425 .44028 L .42627 .59174 L .972 .69 .437 r
F
.425 .44028 m .42266 .59207 L .42627 .59174 L .97 .689 .442 r
F
.43115 .46459 m .42808 .45226 L .42995 .58803 L .973 .691 .43 r
F
.42808 .45226 m .42627 .59174 L .42995 .58803 L .972 .69 .437 r
F
.42266 .59207 m .431 .38669 L .434 .40071 L .956 .696 .501 r
F
.425 .44028 m .42192 .42884 L .42266 .59043 L .97 .689 .442 r
F
.42269 .59052 m .42266 .59043 L .42266 .59207 L F
.425 .44028 m .42266 .59043 L .42269 .59052 L F
.42192 .42884 m .41881 .41801 L .41914 .57661 L .969 .689 .446 r
F
.41936 .57693 m .41914 .57661 L .41916 .5883 L F
.42192 .42884 m .41914 .57661 L .41936 .57693 L F
.41881 .41801 m .41568 .40786 L .41577 .5805 L .968 .688 .448 r
F
.41568 .40786 m .4125 .56893 L .41577 .5805 L .967 .686 .449 r
F
.41881 .41801 m .41577 .5805 L .41916 .5883 L .968 .688 .448 r
F
.41262 .56702 m .42108 .37508 L .42458 .37302 L .94 .68 .514 r
F
.4125 .56893 m .41259 .56698 L .41262 .56702 L F
.41259 .56698 m .42108 .37508 L .41262 .56702 L F
.42192 .42884 m .41916 .5883 L .42266 .59207 L .969 .689 .446 r
F
.41619 .57345 m .42458 .37302 L .42788 .37711 L .946 .685 .509 r
F
.41577 .5805 m .41608 .57317 L .41619 .57345 L F
.41608 .57317 m .42458 .37302 L .41619 .57345 L F
.42266 .59207 m .41916 .5883 L .431 .38669 L .956 .696 .501 r
F
.41916 .5883 m .42788 .37711 L .431 .38669 L .951 .69 .505 r
F
.43516 .39402 m .43128 .41188 L .43524 .39391 L .309 .035 .325 r
F
.42934 .40196 m .43128 .41188 L .43516 .39402 L F
.41916 .5883 m .41577 .5805 L .42788 .37711 L .951 .69 .505 r
F
.42535 .41895 m .42723 .43076 L .43128 .41188 L .331 .062 .347 r
F
.43128 .41188 m .42723 .43076 L .42733 .43005 L .968 .801 .372 r
F
.431 .38669 m .43313 .3896 L .43671 .38319 L 0 0 .41 r
F
.431 .38669 m .42788 .37711 L .43313 .3896 L F
.42788 .37711 m .42934 .40196 L .43313 .3896 L .955 .615 .313 r
F
.43671 .38319 m .43313 .3896 L .439 .3811 L 0 0 0 r
F
.43313 .3896 m .42934 .40196 L .43524 .39391 L .139 0 .202 r
F
.42934 .40196 m .42535 .41895 L .43128 .41188 L .309 .035 .325 r
F
.43128 .41188 m .43059 .41504 L .43453 .37666 L .968 .801 .372 r
F
.43059 .41504 m .43077 .40458 L .43453 .37666 L F
.43128 .41188 m .43453 .37666 L .43819 .36826 L F
.43453 .37666 m .43062 .39255 L .43587 .36622 L .862 .786 .288 r
F
.43622 .36589 m .43587 .36622 L .43727 .3592 L F
.43453 .37666 m .43587 .36622 L .43622 .36589 L F
.43524 .39391 m .43352 .40069 L .43819 .36826 L .927 .798 .329 r
F
.43352 .40069 m .43226 .4057 L .4342 .39343 L F
.43352 .40069 m .4342 .39343 L .43819 .36826 L F
.43453 .37666 m .43727 .3592 L .43736 .35966 L .862 .786 .288 r
F
.439 .3811 m .4388 .3815 L .44156 .36939 L .796 .777 .272 r
F
.4388 .3815 m .43804 .38307 L .4391 .37895 L F
.4388 .3815 m .4391 .37895 L .44156 .36939 L F
.439 .3811 m .43975 .37768 L .44119 .38049 L F
.43975 .37768 m .44156 .36939 L .44119 .38049 L F
.44119 .38049 m .44156 .36939 L .44184 .38031 L F
.44184 .38031 m .44156 .36939 L .44469 .37951 L F
.43524 .39391 m .43819 .36826 L .44156 .36939 L .927 .798 .329 r
F
.44156 .36939 m .43819 .36826 L .44211 .3911 L .939 .597 .352 r
F
.44291 .39319 m .44211 .3911 L .44313 .39707 L F
.44156 .36939 m .44211 .3911 L .44291 .39319 L F
.43819 .36826 m .43975 .37327 L .43947 .37572 L .398 .037 .23 r
F
.43975 .37327 m .44027 .37495 L .43947 .37572 L F
.43819 .36826 m .43453 .37666 L .44027 .37495 L F
.43634 .37612 m .43736 .35966 L .44027 .37495 L .862 .786 .288 r
F
.43581 .37628 m .43592 .37504 L .43634 .37612 L F
.43592 .37504 m .43736 .35966 L .43634 .37612 L F
.43947 .37572 m .44027 .37495 L .44313 .39707 L .398 .037 .23 r
F
.43453 .37666 m .43736 .35966 L .43581 .37628 L .862 .786 .288 r
F
.439 .3811 m .43524 .39391 L .43804 .38307 L .796 .777 .272 r
F
.43062 .39255 m .43397 .35425 L .43727 .3592 L .977 .8 .385 r
F
.43495 .36709 m .43535 .38559 L .43818 .40967 L .86 .526 .419 r
F
.43397 .35425 m .43455 .36746 L .43495 .36709 L F
.43455 .36746 m .43535 .38559 L .43495 .36709 L F
.42723 .43076 m .43062 .39255 L .43453 .37666 L .992 .805 .428 r
F
.42788 .37711 m .42458 .37302 L .42934 .40196 L .955 .615 .313 r
F
.42458 .37302 m .42535 .41895 L .42934 .40196 L .93 .615 .424 r
F
.43062 .39255 m .42656 .41114 L .43397 .35425 L .977 .8 .385 r
F
.42656 .41114 m .4303 .36124 L .43397 .35425 L .998 .788 .444 r
F
.43397 .35425 m .4303 .36124 L .43446 .3813 L .86 .526 .419 r
F
.4352 .38217 m .43446 .3813 L .43535 .38559 L F
.43397 .35425 m .43446 .3813 L .4352 .38217 L F
.4303 .36124 m .43151 .35993 L .4314 .36652 L 0 0 .025 r
F
.43151 .35993 m .43263 .35871 L .4314 .36652 L F
.41577 .5805 m .4125 .56893 L .42458 .37302 L .946 .685 .509 r
F
.42458 .37302 m .42108 .37508 L .42535 .41895 L .93 .615 .424 r
F
.42108 .37508 m .42125 .4381 L .42535 .41895 L .906 .603 .46 r
F
.42656 .41114 m .42257 .42573 L .4303 .36124 L .998 .788 .444 r
F
.42257 .42573 m .42633 .37706 L .4303 .36124 L .986 .762 .516 r
F
.4303 .36124 m .42633 .37706 L .43164 .36157 L 0 0 .025 r
F
.43196 .35944 m .43164 .36157 L .43263 .35871 L F
.4303 .36124 m .43164 .36157 L .43196 .35944 L F
.42762 .37329 m .42971 .33945 L .43263 .35871 L .98 .802 .393 r
F
.42633 .37706 m .42676 .37228 L .42762 .37329 L F
.42676 .37228 m .42971 .33945 L .42762 .37329 L F
.42633 .37706 m .42429 .38584 L .42881 .3461 L F
.42429 .38584 m .42425 .37981 L .42881 .3461 L F
.42633 .37706 m .42881 .3461 L .42911 .34614 L F
.42224 .39467 m .42634 .3354 L .42971 .33945 L .995 .769 .473 r
F
.41568 .40786 m .41253 .39843 L .4125 .56893 L .967 .686 .449 r
F
.41253 .39843 m .40935 .55407 L .4125 .56893 L .966 .685 .449 r
F
.4125 .56893 m .40935 .55407 L .42108 .37508 L .94 .68 .514 r
F
.40935 .55407 m .41734 .38339 L .42108 .37508 L .933 .673 .521 r
F
.42108 .37508 m .41734 .38339 L .42125 .4381 L .906 .603 .46 r
F
.41734 .38339 m .41712 .45595 L .42125 .4381 L .885 .586 .476 r
F
.42224 .39467 m .41832 .40528 L .42634 .3354 L .995 .769 .473 r
F
.41832 .40528 m .42244 .34743 L .42634 .3354 L .955 .719 .54 r
F
.42634 .3354 m .42244 .34743 L .42691 .36984 L .822 .5 .444 r
F
.42737 .37018 m .42691 .36984 L .42744 .37249 L F
.42634 .3354 m .42691 .36984 L .42737 .37018 L F
.42244 .34743 m .42403 .34711 L .42409 .35567 L 0 0 .121 r
F
.42403 .34711 m .42468 .34698 L .42409 .35567 L F
.41253 .39843 m .40936 .38977 L .40935 .55407 L .966 .685 .449 r
F
.40936 .38977 m .4063 .53651 L .40935 .55407 L .965 .684 .448 r
F
.40935 .55407 m .4063 .53651 L .41734 .38339 L .933 .673 .521 r
F
.4063 .53651 m .41335 .39751 L .41734 .38339 L .921 .664 .532 r
F
.41734 .38339 m .41335 .39751 L .41712 .45595 L .885 .586 .476 r
F
.40936 .38977 m .40615 .38185 L .4063 .53651 L .965 .684 .448 r
F
.40615 .38185 m .40334 .51694 L .4063 .53651 L .965 .682 .447 r
F
.4063 .53651 m .40334 .51694 L .41335 .39751 L .921 .664 .532 r
F
.41335 .39751 m .41311 .46857 L .41712 .45595 L .855 .558 .485 r
F
.40334 .51694 m .40915 .41642 L .41335 .39751 L .898 .647 .551 r
F
.41335 .39751 m .40915 .41642 L .41311 .46857 L .855 .558 .485 r
F
.41562 .41938 m .41531 .41676 L .41832 .40528 L .335 .239 .595 r
F
.41531 .41676 m .41282 .39616 L .41524 .40018 L F
.41601 .40509 m .41524 .40018 L .41621 .40177 L F
.41531 .41676 m .41524 .40018 L .41601 .40509 L F
.41531 .41676 m .41621 .40177 L .41832 .40528 L F
.41282 .39616 m .41483 .4021 L .41832 .40528 L 0 0 .273 r
F
.41282 .39616 m .41116 .377 L .41483 .4021 L F
.41116 .377 m .41027 .36676 L .41171 .3779 L F
.41116 .377 m .41171 .3779 L .41483 .4021 L F
.41138 .37532 m .41184 .38408 L .41483 .4021 L .73 .535 0 r
F
.41483 .4021 m .41184 .38408 L .41588 .3741 L .759 .557 .623 r
F
.41734 .37696 m .41588 .3741 L .41819 .36839 L F
.41483 .4021 m .41588 .3741 L .41734 .37696 L F
.41184 .38408 m .41401 .38531 L .41465 .38273 L 0 0 .362 r
F
.41184 .38408 m .41465 .38273 L .41329 .3805 L F
.41027 .36676 m .41059 .37027 L .41138 .37532 L .73 .535 0 r
F
.41059 .37027 m .41184 .38408 L .41138 .37532 L F
.40786 .37375 m .4052 .34911 L .41014 .36629 L .065 .038 .512 r
F
.4102 .36695 m .41014 .36629 L .41027 .36676 L F
.40786 .37375 m .41014 .36629 L .4102 .36695 L F
.4052 .34911 m .40764 .34084 L .41027 .36676 L .266 .229 .629 r
F
.40786 .37375 m .41027 .36676 L .41282 .39616 L .065 .038 .512 r
F
.40785 .34296 m .4092 .35714 L .40956 .36086 L .876 .585 .065 r
F
.40785 .34296 m .40956 .36086 L .40968 .36185 L F
.40968 .36185 m .40956 .36086 L .41184 .38408 L F
.41027 .36676 m .40764 .34084 L .41184 .38408 L .73 .535 0 r
F
.41278 .36661 m .41443 .33303 L .41841 .32138 L .846 .614 .586 r
F
.41184 .38408 m .40956 .36086 L .41344 .38217 L 0 0 .362 r
F
.40956 .36086 m .40968 .36 L .41401 .38531 L F
.41356 .38505 m .41344 .38217 L .41401 .38531 L F
.41184 .38408 m .41344 .38217 L .41356 .38505 L F
.40445 .37147 m .40615 .38185 L .40936 .38977 L .904 .495 .12 r
F
.41043 .40189 m .40786 .37375 L .41282 .39616 L 0 0 .472 r
F
.41018 .36292 m .41034 .38622 L .41401 .38531 L .878 .637 .112 r
F
.41034 .38622 m .41245 .35877 L .41278 .36661 L .846 .614 .586 r
F
.41245 .35877 m .41443 .33303 L .41278 .36661 L F
.40956 .36086 m .4092 .35714 L .40968 .36 L 0 0 .362 r
F
.4092 .35714 m .40936 .3613 L .40936 .36131 L .878 .637 .112 r
F
.40968 .36 m .40936 .36131 L .41018 .36292 L F
.4092 .35714 m .40936 .36131 L .40968 .36 L F
.40926 .35838 m .41012 .35229 L .41199 .34394 L .256 .16 .549 r
F
.41148 .34751 m .41199 .34394 L .41443 .33303 L F
.40926 .35838 m .41199 .34394 L .41148 .34751 L F
.4052 .34911 m .40223 .33317 L .40764 .34084 L .266 .229 .629 r
F
.40223 .33317 m .40457 .32716 L .40764 .34084 L .66 .725 .897 r
F
.40764 .34084 m .40457 .32716 L .40727 .34464 L .876 .585 .065 r
F
.40854 .3503 m .40727 .34464 L .4092 .35714 L F
.40764 .34084 m .40727 .34464 L .40854 .3503 L F
.40223 .33317 m .3988 .32915 L .40457 .32716 L .66 .725 .897 r
F
.40151 .32822 m .40086 .3301 L .40457 .32716 L 0 0 0 r
F
.3988 .32915 m .40086 .3301 L .40151 .32822 L F
.39547 .35993 m .3988 .32915 L .40223 .33317 L .668 .479 .621 r
F
.39547 .35993 m .39276 .33772 L .3988 .32915 L F
.39998 .33122 m .39653 .34771 L .40086 .3301 L .241 0 .299 r
F
.39484 .33777 m .39653 .34771 L .39998 .33122 L F
.38986 .37154 m .3921 .36605 L .39548 .36962 L .662 .741 .909 r
F
.39548 .36962 m .3921 .36605 L .39773 .3642 L .657 .74 .911 r
F
.3921 .36605 m .39435 .36058 L .39773 .3642 L .658 .739 .91 r
F
.3921 .36605 m .38871 .36245 L .39435 .36058 L F
.38871 .36245 m .39096 .35697 L .39435 .36058 L .657 .739 .91 r
F
.39435 .36058 m .39096 .35697 L .39634 .36208 L 0 .053 .565 r
F
.39096 .35697 m .39301 .35657 L .39634 .36208 L 0 .335 .808 r
F
.39884 .37317 m .39548 .36962 L .4011 .36782 L .654 .739 .912 r
F
.39548 .36962 m .39773 .3642 L .4011 .36782 L .657 .74 .911 r
F
.39773 .3642 m .39435 .36058 L .39964 .36808 L .698 .214 0 r
F
.39435 .36058 m .39634 .36208 L .39964 .36808 L 0 .053 .565 r
F
.39634 .36208 m .39301 .35657 L .39478 .45313 L .963 .674 .435 r
F
.39301 .35657 m .39196 .43243 L .39478 .45313 L .963 .669 .426 r
F
.38986 .37154 m .38648 .36797 L .3921 .36605 L .662 .741 .909 r
F
.38648 .36797 m .38871 .36245 L .3921 .36605 L .663 .741 .908 r
F
.38871 .36245 m .38531 .35884 L .39096 .35697 L .657 .739 .91 r
F
.38531 .35884 m .38755 .35334 L .39096 .35697 L F
.39096 .35697 m .38755 .35334 L .39301 .35657 L 0 .335 .808 r
F
.38755 .35334 m .38965 .35145 L .39301 .35657 L .211 .528 .92 r
F
.39301 .35657 m .38965 .35145 L .39196 .43243 L .963 .669 .426 r
F
.38426 .37346 m .38648 .36797 L .38986 .37154 L .663 .741 .908 r
F
.38965 .35145 m .3891 .41296 L .39196 .43243 L .963 .663 .415 r
F
.38648 .36797 m .38308 .36439 L .38871 .36245 L .663 .741 .908 r
F
.38308 .36439 m .38531 .35884 L .38871 .36245 L .664 .742 .908 r
F
.38531 .35884 m .3819 .35521 L .38755 .35334 L .657 .739 .91 r
F
.3819 .35521 m .38413 .34969 L .38755 .35334 L F
.38755 .35334 m .38413 .34969 L .38965 .35145 L .211 .528 .92 r
F
.38413 .34969 m .38627 .34666 L .38965 .35145 L .396 .629 .948 r
F
.38965 .35145 m .38627 .34666 L .3891 .41296 L .963 .663 .415 r
F
.38426 .37346 m .38087 .36989 L .38648 .36797 L .663 .741 .908 r
F
.38087 .36989 m .38308 .36439 L .38648 .36797 L .662 .741 .908 r
F
.38627 .34666 m .3862 .3951 L .3891 .41296 L .962 .655 .398 r
F
.3891 .41296 m .3862 .3951 L .38687 .51765 L .982 .7 .406 r
F
.3862 .3951 m .38278 .52438 L .38687 .51765 L .977 .697 .425 r
F
.39196 .43243 m .3891 .41296 L .39121 .5038 L .984 .703 .361 r
F
.3891 .41296 m .38687 .51765 L .39121 .5038 L .982 .7 .406 r
F
.38278 .52438 m .39276 .33772 L .39547 .35993 L .96 .7 .498 r
F
.38308 .36439 m .37968 .3608 L .38531 .35884 L .664 .742 .908 r
F
.37968 .3608 m .3819 .35521 L .38531 .35884 L F
.3819 .35521 m .37847 .35157 L .38413 .34969 L .657 .739 .91 r
F
.37847 .35157 m .3807 .34602 L .38413 .34969 L .659 .74 .91 r
F
.38413 .34969 m .3807 .34602 L .38627 .34666 L .396 .629 .948 r
F
.3807 .34602 m .38286 .34213 L .38627 .34666 L .504 .68 .945 r
F
.38627 .34666 m .38286 .34213 L .3862 .3951 L .962 .655 .398 r
F
.38286 .34213 m .38324 .37908 L .3862 .3951 L .96 .642 .373 r
F
.3862 .3951 m .38324 .37908 L .3828 .51914 L .977 .697 .425 r
F
.38291 .51947 m .3828 .51914 L .38278 .52438 L F
.3862 .3951 m .3828 .51914 L .38291 .51947 L F
.38087 .36989 m .37747 .36632 L .38308 .36439 L .662 .741 .908 r
F
.37747 .36632 m .37968 .3608 L .38308 .36439 L F
.37968 .3608 m .37625 .35718 L .3819 .35521 L .664 .742 .908 r
F
.37625 .35718 m .37847 .35157 L .3819 .35521 L .664 .741 .908 r
F
.37847 .35157 m .37503 .34793 L .3807 .34602 L .659 .74 .91 r
F
.37503 .34793 m .37725 .34233 L .3807 .34602 L .661 .741 .909 r
F
.3807 .34602 m .37725 .34233 L .38286 .34213 L .504 .68 .945 r
F
.37725 .34233 m .37944 .33781 L .38286 .34213 L .567 .706 .935 r
F
.38286 .34213 m .37944 .33781 L .38324 .37908 L .96 .642 .373 r
F
.37944 .33781 m .3802 .36496 L .38324 .37908 L .956 .623 .334 r
F
.37527 .37182 m .37747 .36632 L .38087 .36989 L .663 .741 .908 r
F
.38324 .37908 m .3802 .36496 L .37919 .4984 L .974 .693 .435 r
F
.37972 .49866 m .37919 .4984 L .379 .52313 L F
.38324 .37908 m .37919 .4984 L .37972 .49866 L F
.37527 .37182 m .37186 .36825 L .37747 .36632 L .663 .741 .908 r
F
.37186 .36825 m .37405 .36273 L .37747 .36632 L F
.37747 .36632 m .37405 .36273 L .37968 .3608 L .662 .741 .908 r
F
.37405 .36273 m .37625 .35718 L .37968 .3608 L F
.37625 .35718 m .37282 .35355 L .37847 .35157 L .664 .741 .908 r
F
.3802 .36496 m .37708 .35269 L .37556 .51387 L .971 .69 .44 r
F
.37708 .35269 m .37244 .49753 L .37556 .51387 L .969 .688 .442 r
F
.3802 .36496 m .37556 .51387 L .379 .52313 L .971 .69 .44 r
F
.37262 .49523 m .38181 .33745 L .38599 .3261 L .924 .664 .526 r
F
.37244 .49753 m .37258 .4952 L .37262 .49523 L F
.37258 .4952 m .38181 .33745 L .37262 .49523 L F
.38324 .37908 m .379 .52313 L .38278 .52438 L .974 .693 .435 r
F
.37656 .50057 m .38599 .3261 L .38964 .32596 L .939 .677 .514 r
F
.37556 .51387 m .37634 .49992 L .37656 .50057 L F
.37634 .49992 m .38599 .3261 L .37656 .50057 L F
.379 .52313 m .38964 .32596 L .39276 .33772 L .95 .689 .506 r
F
.38278 .52438 m .379 .52313 L .39276 .33772 L .96 .7 .498 r
F
.39038 .35694 m .39186 .3719 L .39653 .34771 L .302 .047 .352 r
F
.39653 .34771 m .39186 .3719 L .39301 .36449 L .882 .772 .273 r
F
.3988 .32915 m .39484 .33777 L .40086 .3301 L 0 0 0 r
F
.39276 .33772 m .39484 .33777 L .3988 .32915 L 0 0 .502 r
F
.39484 .33777 m .39038 .35694 L .39653 .34771 L .241 0 .299 r
F
.39528 .34013 m .39422 .34537 L .39891 .30305 L .958 .796 .353 r
F
.39276 .33772 m .38964 .32596 L .39484 .33777 L 0 0 .502 r
F
.38964 .32596 m .39038 .35694 L .39484 .33777 L .931 .595 .378 r
F
.379 .52313 m .37556 .51387 L .38964 .32596 L .95 .689 .506 r
F
.39038 .35694 m .38561 .38178 L .39186 .3719 L .302 .047 .352 r
F
.39422 .34537 m .39063 .36301 L .39474 .33319 L .958 .796 .353 r
F
.39422 .34537 m .39474 .33319 L .39891 .30305 L F
.39653 .34771 m .39501 .35497 L .39968 .32183 L .882 .772 .273 r
F
.39501 .35497 m .39308 .36417 L .39537 .34949 L F
.39501 .35497 m .39537 .34949 L .39968 .32183 L F
.39308 .36417 m .3931 .36391 L .39968 .32183 L F
.39653 .34771 m .39968 .32183 L .40344 .31822 L F
.40086 .3301 m .40021 .332 L .40344 .31822 L .736 .726 .2 r
F
.40457 .32716 m .40653 .33177 L .4092 .35714 L .51 .014 .014 r
F
.40457 .32716 m .40448 .32723 L .40653 .33177 L F
.40448 .32723 m .40086 .3301 L .40464 .33121 L F
.40448 .32723 m .40464 .33121 L .40653 .33177 L F
.40464 .33121 m .40344 .31822 L .40653 .33177 L .736 .726 .2 r
F
.40422 .33109 m .40344 .31822 L .40464 .33121 L F
.40344 .31822 m .40483 .33787 L .40495 .33931 L .854 .483 .347 r
F
.4048 .33534 m .40495 .33931 L .40736 .36769 L F
.40344 .31822 m .40495 .33931 L .4048 .33534 L F
.40086 .3301 m .4024 .32302 L .40422 .33109 L .736 .726 .2 r
F
.4024 .32302 m .40344 .31822 L .40422 .33109 L F
.40344 .31822 m .39968 .32183 L .40283 .33165 L .854 .483 .347 r
F
.40441 .33191 m .40283 .33165 L .40483 .33787 L F
.40344 .31822 m .40283 .33165 L .40441 .33191 L F
.39968 .32183 m .4022 .31191 L .40483 .33787 L 0 0 0 r
F
.39186 .3719 m .39528 .34013 L .39968 .32183 L .96 .807 .369 r
F
.40086 .3301 m .39653 .34771 L .40021 .332 L .736 .726 .2 r
F
.39884 .37317 m .4011 .36782 L .40445 .37147 L .654 .739 .912 r
F
.40445 .37147 m .4011 .36782 L .40615 .38185 L .904 .495 .12 r
F
.4011 .36782 m .40291 .37464 L .40615 .38185 L .84 .392 0 r
F
.4011 .36782 m .39773 .3642 L .40291 .37464 L F
.39773 .3642 m .39964 .36808 L .40291 .37464 L .698 .214 0 r
F
.40291 .37464 m .39964 .36808 L .40045 .49604 L .964 .68 .444 r
F
.39964 .36808 m .3976 .47455 L .40045 .49604 L .964 .677 .44 r
F
.39964 .36808 m .39634 .36208 L .3976 .47455 L F
.39793 .38904 m .40223 .33317 L .4052 .34911 L .762 .536 .59 r
F
.39634 .36208 m .39478 .45313 L .3976 .47455 L .963 .674 .435 r
F
.39793 .38904 m .39547 .35993 L .40223 .33317 L .762 .536 .59 r
F
.40012 .32075 m .39985 .33287 L .40171 .34927 L .782 .45 .425 r
F
.40012 .32075 m .40171 .34927 L .40214 .35031 L F
.39955 .32332 m .39985 .33287 L .40012 .32075 L F
.39968 .32183 m .39759 .33055 L .40105 .31654 L 0 0 0 r
F
.39759 .33055 m .39528 .34013 L .4022 .31191 L F
.40125 .31563 m .40105 .31654 L .4022 .31191 L F
.39968 .32183 m .40105 .31654 L .40125 .31563 L F
.39758 .33077 m .39891 .30305 L .4022 .31191 L .958 .796 .353 r
F
.39622 .33055 m .39891 .30305 L .39758 .33077 L F
.39063 .36301 m .39475 .31501 L .39891 .30305 L .999 .791 .455 r
F
.39891 .30305 m .39556 .31266 L .39881 .32799 L .782 .45 .425 r
F
.39968 .32758 m .39881 .32799 L .39985 .33287 L F
.39891 .30305 m .39881 .32799 L .39968 .32758 L F
.39556 .31266 m .39475 .31501 L .39985 .33287 L F
.39475 .31501 m .39568 .3115 L .39557 .31417 L 0 0 0 r
F
.39568 .3115 m .39726 .30557 L .39557 .31417 L F
.39475 .31501 m .39785 .31184 L .39688 .32247 L F
.38964 .32596 m .38599 .3261 L .39038 .35694 L .931 .595 .378 r
F
.38599 .3261 m .38561 .38178 L .39038 .35694 L .879 .57 .459 r
F
.39063 .36301 m .38629 .37669 L .39475 .31501 L .999 .791 .455 r
F
.38629 .37669 m .39002 .33926 L .39177 .33031 L .93 .714 .589 r
F
.39186 .33612 m .39177 .33031 L .39475 .31501 L F
.38629 .37669 m .39177 .33031 L .39186 .33612 L F
.39475 .31501 m .39177 .33031 L .39726 .30557 L 0 0 0 r
F
.39177 .33031 m .39002 .33926 L .3921 .32958 L F
.39177 .33031 m .3921 .32958 L .39726 .30557 L F
.39172 .33134 m .39413 .29189 L .39726 .30557 L .99 .796 .411 r
F
.39066 .33183 m .39413 .29189 L .39172 .33134 L F
.37556 .51387 m .37244 .49753 L .38599 .3261 L .939 .677 .514 r
F
.38599 .3261 m .38181 .33745 L .38561 .38178 L .879 .57 .459 r
F
.39002 .33926 m .38541 .35873 L .39147 .31234 L .99 .796 .411 r
F
.39186 .31802 m .39147 .31234 L .39413 .29189 L F
.39002 .33926 m .39147 .31234 L .39186 .31802 L F
.38541 .35873 m .3901 .29952 L .39413 .29189 L .967 .731 .529 r
F
.39413 .29189 m .3901 .29952 L .39436 .32843 L .876 .546 .422 r
F
.39463 .3289 m .39436 .32843 L .39466 .3304 L F
.39413 .29189 m .39436 .32843 L .39463 .3289 L F
.3901 .29952 m .39133 .30252 L .39142 .30852 L 0 0 .191 r
F
.39133 .30252 m .39201 .30417 L .39142 .30852 L F
.38181 .33745 m .38084 .40498 L .38561 .38178 L .842 .541 .48 r
F
.37282 .35355 m .37503 .34793 L .37847 .35157 L .663 .741 .908 r
F
.37503 .34793 m .37158 .34428 L .37725 .34233 L .661 .741 .909 r
F
.37158 .34428 m .37379 .33862 L .37725 .34233 L .663 .742 .908 r
F
.37725 .34233 m .37379 .33862 L .37944 .33781 L .567 .706 .935 r
F
.37379 .33862 m .37599 .33366 L .37944 .33781 L .606 .721 .926 r
F
.37944 .33781 m .37599 .33366 L .3802 .36496 L .956 .623 .334 r
F
.37599 .33366 m .37708 .35269 L .3802 .36496 L .947 .59 .274 r
F
.36968 .37375 m .37186 .36825 L .37527 .37182 L .664 .741 .908 r
F
.37186 .36825 m .36844 .36467 L .37405 .36273 L .663 .741 .908 r
F
.36844 .36467 m .37062 .35912 L .37405 .36273 L F
.37405 .36273 m .37062 .35912 L .37625 .35718 L .662 .741 .908 r
F
.37062 .35912 m .37282 .35355 L .37625 .35718 L .663 .741 .908 r
F
.37282 .35355 m .36937 .3499 L .37503 .34793 L F
.36937 .3499 m .37158 .34428 L .37503 .34793 L .662 .74 .908 r
F
.37708 .35269 m .37389 .34213 L .37244 .49753 L .969 .688 .442 r
F
.37389 .34213 m .36959 .47579 L .37244 .49753 L .968 .685 .442 r
F
.37244 .49753 m .36959 .47579 L .38181 .33745 L .924 .664 .526 r
F
.36959 .47579 m .37717 .35762 L .38181 .33745 L .898 .643 .544 r
F
.38181 .33745 m .37717 .35762 L .38084 .40498 L .842 .541 .48 r
F
.38276 .37111 m .38008 .34654 L .38156 .34991 L .232 .158 .563 r
F
.37533 .3236 m .3778 .31414 L .38008 .34654 L .123 .077 .529 r
F
.38315 .36408 m .38156 .34991 L .38367 .35474 L .232 .158 .563 r
F
.38276 .37111 m .38156 .34991 L .38315 .36408 L F
.38288 .37055 m .38367 .35474 L .38541 .35873 L F
.38276 .37111 m .38367 .35474 L .38288 .37055 L F
.38008 .34654 m .38166 .35784 L .38541 .35873 L 0 0 .151 r
F
.38008 .34654 m .37852 .32435 L .38115 .35208 L F
.37852 .32435 m .37886 .32615 L .38115 .35208 L F
.38126 .35502 m .38115 .35208 L .38166 .35784 L F
.38008 .34654 m .38115 .35208 L .38126 .35502 L F
.37878 .32526 m .37894 .33387 L .38166 .35784 L .809 .588 .029 r
F
.38166 .35784 m .37894 .33387 L .38268 .32653 L .699 .497 .61 r
F
.38426 .33236 m .38268 .32653 L .38539 .3212 L F
.38166 .35784 m .38268 .32653 L .38426 .33236 L F
.37894 .33387 m .38083 .33815 L .38101 .33749 L 0 0 .264 r
F
.37995 .33189 m .38101 .33749 L .38539 .3212 L F
.37894 .33387 m .38101 .33749 L .37995 .33189 L F
.37852 .32435 m .3778 .31414 L .37886 .32615 L 0 0 .151 r
F
.3778 .31414 m .37809 .31908 L .37878 .32526 L .809 .588 .029 r
F
.37809 .31908 m .37894 .33387 L .37878 .32526 L F
.37533 .3236 m .37274 .29907 L .37623 .30947 L .123 .077 .529 r
F
.37669 .31839 m .37623 .30947 L .3778 .31414 L F
.37533 .3236 m .37623 .30947 L .37669 .31839 L F
.37274 .29907 m .37521 .28952 L .3778 .31414 L .494 .447 .733 r
F
.3778 .31414 m .37521 .28952 L .37765 .31857 L .809 .588 .029 r
F
.37854 .32692 m .37765 .31857 L .37894 .33387 L F
.3778 .31414 m .37765 .31857 L .37854 .32692 L F
.37522 .28966 m .37674 .29988 L .37894 .33387 L .894 .5 .064 r
F
.37521 .28952 m .37521 .28957 L .37522 .28966 L F
.37521 .28957 m .37674 .29988 L .37522 .28966 L F
.37274 .29907 m .36949 .28856 L .37521 .28952 L .494 .447 .733 r
F
.37036 .2887 m .3717 .28406 L .37521 .28952 L .701 .861 .449 r
F
.36949 .28856 m .3717 .28406 L .37036 .2887 L F
.36683 .33118 m .36333 .32744 L .36904 .32569 L .645 .735 .915 r
F
.36333 .32744 m .36554 .32182 L .36904 .32569 L .653 .738 .912 r
F
.37032 .3349 m .36683 .33118 L .37252 .32963 L .63 .73 .92 r
F
.36683 .33118 m .36904 .32569 L .37252 .32963 L .645 .735 .915 r
F
.36904 .32569 m .36554 .32182 L .36929 .33012 L .856 .417 0 r
F
.37039 .33195 m .36929 .33012 L .37063 .33307 L F
.36904 .32569 m .36929 .33012 L .37039 .33195 L F
.36333 .32744 m .35982 .3237 L .36554 .32182 L .653 .738 .912 r
F
.35982 .3237 m .36202 .31799 L .36554 .32182 L .658 .74 .91 r
F
.36554 .32182 m .3673 .32527 L .37063 .33307 L .673 .189 0 r
F
.36554 .32182 m .36202 .31799 L .3673 .32527 L F
.36209 .31809 m .36391 .3185 L .3673 .32527 L 0 .17 .676 r
F
.36202 .31799 m .36203 .31799 L .36209 .31809 L F
.36203 .31799 m .36391 .3185 L .36209 .31809 L F
.36068 .37213 m .36284 .36662 L .36627 .37019 L .664 .741 .908 r
F
.36627 .37019 m .36284 .36662 L .36844 .36467 L F
.36284 .36662 m .365 .36107 L .36844 .36467 L F
.36284 .36662 m .35939 .36303 L .365 .36107 L F
.36844 .36467 m .365 .36107 L .37062 .35912 L .663 .741 .908 r
F
.35939 .36303 m .36155 .35746 L .365 .36107 L .664 .741 .908 r
F
.365 .36107 m .36718 .35551 L .37062 .35912 L .663 .741 .908 r
F
.365 .36107 m .36155 .35746 L .36718 .35551 L F
.36155 .35746 m .36372 .35188 L .36718 .35551 L F
.36718 .35551 m .36372 .35188 L .36937 .3499 L .664 .741 .908 r
F
.36372 .35188 m .36591 .34624 L .36937 .3499 L F
.36372 .35188 m .36025 .34823 L .36591 .34624 L F
.36937 .3499 m .36591 .34624 L .37158 .34428 L .662 .74 .908 r
F
.36025 .34823 m .36243 .34257 L .36591 .34624 L .664 .741 .908 r
F
.36591 .34624 m .36811 .34062 L .37158 .34428 L .661 .74 .909 r
F
.36591 .34624 m .36243 .34257 L .36811 .34062 L F
.36243 .34257 m .36462 .33693 L .36811 .34062 L .661 .741 .909 r
F
.36243 .34257 m .35894 .33889 L .36462 .33693 L F
.36811 .34062 m .36462 .33693 L .37032 .3349 L .665 .742 .907 r
F
.35894 .33889 m .36113 .33322 L .36462 .33693 L .662 .741 .909 r
F
.36462 .33693 m .36683 .33118 L .37032 .3349 L .665 .742 .907 r
F
.36462 .33693 m .36113 .33322 L .36683 .33118 L F
.36113 .33322 m .36333 .32744 L .36683 .33118 L .665 .741 .907 r
F
.3673 .32527 m .36391 .3185 L .36434 .42475 L .966 .677 .434 r
F
.36556 .32725 m .36949 .28856 L .37274 .29907 L .652 .451 .599 r
F
.36556 .32725 m .36324 .29831 L .36949 .28856 L F
.36949 .28856 m .36539 .29457 L .3717 .28406 L .701 .861 .449 r
F
.36324 .29831 m .36539 .29457 L .36949 .28856 L 0 .045 .561 r
F
.37001 .28687 m .36928 .28994 L .3717 .28406 L 0 0 .164 r
F
.36928 .28994 m .36969 .2906 L .3717 .28406 L F
.3717 .28406 m .36969 .2906 L .37305 .27938 L .691 .73 .216 r
F
.36928 .28994 m .36716 .29887 L .36969 .2906 L 0 0 .164 r
F
.36969 .2906 m .36716 .29887 L .37035 .2883 L .691 .73 .216 r
F
.36969 .2906 m .37035 .2883 L .37305 .27938 L F
.3717 .28406 m .37305 .27938 L .3741 .27589 L F
.37521 .28952 m .3717 .28406 L .37651 .29917 L .894 .5 .064 r
F
.3766 .29896 m .37651 .29917 L .37674 .29988 L F
.37521 .28952 m .37651 .29917 L .3766 .29896 L F
.37764 .3548 m .37533 .3236 L .38008 .34654 L .009 0 .464 r
F
.37549 .30158 m .37462 .30713 L .37721 .3335 L .938 .599 .361 r
F
.37512 .29481 m .37512 .29473 L .37513 .29483 L .691 .73 .216 r
F
.3717 .28406 m .37512 .29473 L .37512 .29481 L F
.3717 .28406 m .37338 .27835 L .37512 .29473 L F
.37338 .27835 m .3741 .27589 L .37513 .29483 L F
.3741 .27589 m .37457 .30377 L .37549 .30158 L .938 .599 .361 r
F
.37457 .30377 m .37462 .30713 L .37549 .30158 L F
.36539 .29457 m .36716 .29887 L .37001 .28687 L 0 0 .164 r
F
.36716 .29887 m .37034 .27518 L .3741 .27589 L .863 .767 .262 r
F
.3741 .27589 m .37034 .27518 L .37323 .29671 L .938 .599 .361 r
F
.37449 .29898 m .37323 .29671 L .37462 .30713 L F
.3741 .27589 m .37323 .29671 L .37449 .29898 L F
.37034 .27518 m .37228 .27653 L .37258 .28049 L 0 0 .101 r
F
.37034 .27518 m .37258 .28049 L .37169 .28363 L F
.37034 .27518 m .37387 .29732 L .37315 .29617 L F
.36068 .37213 m .35724 .36856 L .36284 .36662 L .664 .741 .908 r
F
.35724 .36856 m .35939 .36303 L .36284 .36662 L F
.35724 .36856 m .35379 .36498 L .35939 .36303 L F
.35379 .36498 m .35593 .35942 L .35939 .36303 L F
.35939 .36303 m .35593 .35942 L .36155 .35746 L F
.35593 .35942 m .35809 .35383 L .36155 .35746 L F
.36155 .35746 m .35809 .35383 L .36372 .35188 L .663 .741 .908 r
F
.35809 .35383 m .36025 .34823 L .36372 .35188 L F
.35809 .35383 m .35461 .35019 L .36025 .34823 L F
.35461 .35019 m .35677 .34457 L .36025 .34823 L F
.36025 .34823 m .35677 .34457 L .36243 .34257 L .664 .741 .908 r
F
.35677 .34457 m .35894 .33889 L .36243 .34257 L .663 .741 .908 r
F
.35894 .33889 m .35544 .3352 L .36113 .33322 L .662 .741 .909 r
F
.35544 .3352 m .35762 .32949 L .36113 .33322 L F
.36113 .33322 m .35762 .32949 L .36333 .32744 L .665 .741 .907 r
F
.35762 .32949 m .35982 .3237 L .36333 .32744 L F
.35982 .3237 m .35629 .31995 L .36202 .31799 L .658 .74 .91 r
F
.35629 .31995 m .35848 .31417 L .36202 .31799 L .66 .74 .909 r
F
.36202 .31799 m .35848 .31417 L .36391 .3185 L 0 .17 .676 r
F
.35848 .31417 m .36048 .31253 L .36391 .3185 L .128 .475 .896 r
F
.36391 .3185 m .36175 .39947 L .36434 .42475 L .965 .672 .426 r
F
.36391 .3185 m .36048 .31253 L .36175 .39947 L F
.36048 .31253 m .3591 .37621 L .36175 .39947 L .964 .665 .413 r
F
.35677 .34457 m .35328 .34089 L .35894 .33889 L .663 .741 .908 r
F
.35328 .34089 m .35544 .3352 L .35894 .33889 L F
.35762 .32949 m .3541 .32575 L .35982 .3237 L .665 .741 .907 r
F
.3541 .32575 m .35629 .31995 L .35982 .3237 L .664 .741 .907 r
F
.35629 .31995 m .35274 .31618 L .35848 .31417 L .66 .74 .909 r
F
.35274 .31618 m .35493 .31036 L .35848 .31417 L .661 .741 .909 r
F
.35848 .31417 m .35493 .31036 L .36048 .31253 L .128 .475 .896 r
F
.35493 .31036 m .357 .3072 L .36048 .31253 L .385 .624 .947 r
F
.36048 .31253 m .357 .3072 L .3591 .37621 L .964 .665 .413 r
F
.35593 .35942 m .35246 .3558 L .35809 .35383 L .664 .741 .908 r
F
.35246 .3558 m .35461 .35019 L .35809 .35383 L F
.35461 .35019 m .35112 .34654 L .35677 .34457 L .663 .741 .908 r
F
.35112 .34654 m .35328 .34089 L .35677 .34457 L F
.35544 .3352 m .35192 .33149 L .35762 .32949 L .662 .741 .909 r
F
.35192 .33149 m .3541 .32575 L .35762 .32949 L .663 .741 .908 r
F
.357 .3072 m .35634 .35562 L .3591 .37621 L .963 .655 .394 r
F
.35167 .3705 m .35379 .36498 L .35724 .36856 L .664 .742 .908 r
F
.3591 .37621 m .35634 .35562 L .35695 .45702 L .985 .705 .374 r
F
.35634 .35562 m .35231 .4698 L .35695 .45702 L .98 .7 .413 r
F
.36175 .39947 m .3591 .37621 L .36192 .43635 L .948 .683 .225 r
F
.3591 .37621 m .35695 .45702 L .36192 .43635 L .985 .705 .374 r
F
.35231 .4698 m .36324 .29831 L .36556 .32725 L .966 .708 .494 r
F
.35379 .36498 m .35033 .36138 L .35593 .35942 L .664 .741 .908 r
F
.35033 .36138 m .35246 .3558 L .35593 .35942 L F
.35328 .34089 m .34976 .33719 L .35544 .3352 L .663 .741 .908 r
F
.34976 .33719 m .35192 .33149 L .35544 .3352 L .662 .741 .908 r
F
.3541 .32575 m .35056 .32199 L .35629 .31995 L .664 .741 .907 r
F
.35056 .32199 m .35274 .31618 L .35629 .31995 L .664 .741 .908 r
F
.35274 .31618 m .34918 .31239 L .35493 .31036 L .661 .741 .909 r
F
.34918 .31239 m .35137 .30654 L .35493 .31036 L .662 .741 .909 r
F
.35493 .31036 m .35137 .30654 L .357 .3072 L .385 .624 .947 r
F
.35137 .30654 m .35348 .30233 L .357 .3072 L .516 .686 .944 r
F
.357 .3072 m .35348 .30233 L .35634 .35562 L .963 .655 .394 r
F
.35192 .33149 m .34839 .32777 L .3541 .32575 L .663 .741 .908 r
F
.34839 .32777 m .35056 .32199 L .3541 .32575 L F
.35348 .30233 m .35345 .33781 L .35634 .35562 L .96 .64 .365 r
F
.35167 .3705 m .34821 .36693 L .35379 .36498 L .664 .742 .908 r
F
.34821 .36693 m .35033 .36138 L .35379 .36498 L .664 .741 .908 r
F
.35246 .3558 m .34898 .35217 L .35461 .35019 L F
.34898 .35217 m .35112 .34654 L .35461 .35019 L F
.35634 .35562 m .35345 .33781 L .35235 .46495 L .98 .7 .413 r
F
.35247 .46532 m .35235 .46495 L .35231 .4698 L F
.35634 .35562 m .35235 .46495 L .35247 .46532 L F
.3461 .37242 m .34821 .36693 L .35167 .3705 L .663 .741 .908 r
F
.35033 .36138 m .34685 .35777 L .35246 .3558 L .664 .741 .908 r
F
.34685 .35777 m .34898 .35217 L .35246 .3558 L F
.35112 .34654 m .34762 .34287 L .35328 .34089 L .663 .741 .908 r
F
.34762 .34287 m .34976 .33719 L .35328 .34089 L F
.35056 .32199 m .34701 .31823 L .35274 .31618 L .664 .741 .908 r
F
.34701 .31823 m .34918 .31239 L .35274 .31618 L F
.34918 .31239 m .34561 .30858 L .35137 .30654 L .662 .741 .909 r
F
.34561 .30858 m .34779 .30271 L .35137 .30654 L .662 .741 .908 r
F
.35137 .30654 m .34779 .30271 L .35348 .30233 L .516 .686 .944 r
F
.34779 .30271 m .34993 .29781 L .35348 .30233 L .582 .713 .933 r
F
.35348 .30233 m .34993 .29781 L .35345 .33781 L .96 .64 .365 r
F
.34839 .32777 m .34485 .32402 L .35056 .32199 L .663 .741 .908 r
F
.34485 .32402 m .34701 .31823 L .35056 .32199 L F
.34993 .29781 m .35043 .32259 L .35345 .33781 L .955 .615 .318 r
F
.34821 .36693 m .34474 .36334 L .35033 .36138 L .664 .741 .908 r
F
.34474 .36334 m .34685 .35777 L .35033 .36138 L F
.34898 .35217 m .34548 .34852 L .35112 .34654 L F
.34548 .34852 m .34762 .34287 L .35112 .34654 L F
.34976 .33719 m .34624 .33349 L .35192 .33149 L .662 .741 .908 r
F
.34624 .33349 m .34839 .32777 L .35192 .33149 L F
.35345 .33781 m .35043 .32259 L .34862 .44176 L .976 .695 .429 r
F
.34937 .44167 m .34862 .44176 L .34816 .47246 L F
.35345 .33781 m .34862 .44176 L .34937 .44167 L F
.3461 .37242 m .34263 .36886 L .34821 .36693 L .663 .741 .908 r
F
.34263 .36886 m .34474 .36334 L .34821 .36693 L F
.34685 .35777 m .34336 .35415 L .34898 .35217 L .664 .741 .908 r
F
.34336 .35415 m .34548 .34852 L .34898 .35217 L F
.34762 .34287 m .3441 .33919 L .34976 .33719 L .663 .741 .908 r
F
.3441 .33919 m .34624 .33349 L .34976 .33719 L F
.34701 .31823 m .34344 .31445 L .34918 .31239 L .664 .741 .908 r
F
.34344 .31445 m .34561 .30858 L .34918 .31239 L F
.34561 .30858 m .34203 .30476 L .34779 .30271 L .662 .741 .908 r
F
.34203 .30476 m .3442 .29886 L .34779 .30271 L .663 .741 .908 r
F
.34779 .30271 m .3442 .29886 L .34993 .29781 L .582 .713 .933 r
F
.3442 .29886 m .34635 .29353 L .34993 .29781 L .617 .726 .924 r
F
.34993 .29781 m .34635 .29353 L .35043 .32259 L .955 .615 .318 r
F
.34635 .29353 m .3473 .30967 L .35043 .32259 L .939 .569 .236 r
F
.34474 .36334 m .34125 .35973 L .34685 .35777 L .664 .741 .908 r
F
.34125 .35973 m .34336 .35415 L .34685 .35777 L F
.34548 .34852 m .34197 .34486 L .34762 .34287 L F
.34197 .34486 m .3441 .33919 L .34762 .34287 L F
.34624 .33349 m .3427 .32977 L .34839 .32777 L .662 .741 .908 r
F
.3427 .32977 m .34485 .32402 L .34839 .32777 L F
.35043 .32259 m .3473 .30967 L .34459 .4639 L .972 .691 .436 r
F
.34485 .32402 m .34129 .32027 L .34701 .31823 L .663 .741 .908 r
F
.34129 .32027 m .34344 .31445 L .34701 .31823 L F
.3473 .30967 m .34159 .44515 L .34459 .4639 L .97 .688 .437 r
F
.35043 .32259 m .34459 .4639 L .34816 .47246 L .972 .691 .436 r
F
.34183 .44257 m .35153 .3018 L .35628 .28566 L .911 .651 .532 r
F
.34159 .44515 m .34177 .44257 L .34183 .44257 L F
.34177 .44257 m .35153 .3018 L .34183 .44257 L F
.35345 .33781 m .34816 .47246 L .35231 .4698 L .976 .695 .429 r
F
.34619 .44548 m .35628 .28566 L .3602 .28368 L .935 .673 .516 r
F
.34459 .4639 m .34586 .44447 L .34619 .44548 L F
.34586 .44447 m .35628 .28566 L .34619 .44548 L F
.34816 .47246 m .3602 .28368 L .36324 .29831 L .951 .69 .504 r
F
.35231 .4698 m .34816 .47246 L .36324 .29831 L .966 .708 .494 r
F
.36539 .29457 m .36054 .31435 L .36716 .29887 L 0 0 .164 r
F
.36054 .31435 m .362 .32436 L .36716 .29887 L .102 0 .266 r
F
.36716 .29887 m .36426 .31104 L .37034 .27518 L .863 .767 .262 r
F
.36267 .32037 m .36544 .29615 L .37034 .27518 L .94 .806 .351 r
F
.362 .32436 m .36296 .31646 L .36267 .32037 L F
.36296 .31646 m .36544 .29615 L .36267 .32037 L F
.3677 .28651 m .36544 .29615 L .36814 .2884 L 0 0 .101 r
F
.3677 .28651 m .36814 .2884 L .37179 .27794 L F
.3677 .28651 m .37179 .27794 L .37183 .27751 L F
.37034 .27518 m .3677 .28651 L .37228 .27653 L F
.37183 .27751 m .37179 .27794 L .37228 .27653 L F
.36833 .28786 m .36914 .26274 L .37228 .27653 L .927 .788 .316 r
F
.36914 .26274 m .36957 .29444 L .36991 .29666 L .806 .469 .417 r
F
.37062 .35912 m .36718 .35551 L .37282 .35355 L .663 .741 .908 r
F
.36718 .35551 m .36937 .3499 L .37282 .35355 L .664 .741 .908 r
F
.37158 .34428 m .36811 .34062 L .37379 .33862 L .663 .742 .908 r
F
.36811 .34062 m .37032 .3349 L .37379 .33862 L .665 .742 .907 r
F
.37379 .33862 m .37032 .3349 L .37599 .33366 L .606 .721 .926 r
F
.37032 .3349 m .37252 .32963 L .37599 .33366 L .63 .73 .92 r
F
.37599 .33366 m .37252 .32963 L .37708 .35269 L .947 .59 .274 r
F
.37252 .32963 m .37389 .34213 L .37708 .35269 L .922 .531 .173 r
F
.37252 .32963 m .36904 .32569 L .37389 .34213 L F
.36904 .32569 m .37063 .33307 L .37389 .34213 L .856 .417 0 r
F
.36968 .37375 m .36627 .37019 L .37186 .36825 L .664 .741 .908 r
F
.36627 .37019 m .36844 .36467 L .37186 .36825 L F
.37389 .34213 m .37063 .33307 L .36959 .47579 L .968 .685 .442 r
F
.37063 .33307 m .36692 .45081 L .36959 .47579 L .967 .681 .439 r
F
.37063 .33307 m .3673 .32527 L .36692 .45081 L F
.36759 .36315 m .37274 .29907 L .37533 .3236 L .743 .512 .58 r
F
.36692 .45022 m .36434 .42475 L .36692 .45081 L .966 .677 .434 r
F
.36725 .34105 m .36434 .42475 L .36692 .45022 L F
.36663 .34766 m .36434 .42475 L .36725 .34105 L F
.36434 .42475 m .36175 .39947 L .36178 .39952 L .275 .186 .57 r
F
.36692 .45081 m .36434 .42475 L .37221 .38326 L .827 .589 .579 r
F
.36434 .42475 m .36706 .41068 L .37221 .38326 L .275 .186 .57 r
F
.36434 .42475 m .36178 .39952 L .36706 .41068 L F
.36178 .39952 m .36192 .43635 L .36706 .41068 L .948 .683 .225 r
F
.36175 .39947 m .36176 .39976 L .36178 .39952 L F
.36176 .39976 m .36192 .43635 L .36178 .39952 L F
.3673 .32527 m .36663 .34766 L .36725 .34105 L .966 .677 .434 r
F
.36759 .36315 m .36556 .32725 L .37274 .29907 L .743 .512 .58 r
F
.3708 .28781 m .36991 .29666 L .3725 .31368 L .806 .469 .417 r
F
.36914 .26274 m .36991 .29666 L .3708 .28781 L F
.36544 .29615 m .36669 .2849 L .36833 .28786 L .927 .788 .316 r
F
.36669 .2849 m .36914 .26274 L .36833 .28786 L F
.36324 .29831 m .3602 .28368 L .36539 .29457 L 0 .045 .561 r
F
.3602 .28368 m .36054 .31435 L .36539 .29457 L .913 .574 .384 r
F
.34816 .47246 m .34459 .4639 L .3602 .28368 L .951 .69 .504 r
F
.36054 .31435 m .35526 .34056 L .362 .32436 L .102 0 .266 r
F
.36544 .29615 m .36017 .32286 L .36914 .26274 L .927 .788 .316 r
F
.36017 .32286 m .36472 .27388 L .36914 .26274 L .999 .788 .472 r
F
.36914 .26274 m .36472 .27388 L .36841 .28955 L .806 .469 .417 r
F
.3695 .28943 m .36841 .28955 L .36957 .29444 L F
.36914 .26274 m .36841 .28955 L .3695 .28943 L F
.36472 .27388 m .36656 .26765 L .36577 .27836 L 0 0 0 r
F
.36656 .26765 m .36713 .26573 L .36577 .27836 L F
.3602 .28368 m .35628 .28566 L .36054 .31435 L .913 .574 .384 r
F
.35628 .28566 m .35526 .34056 L .36054 .31435 L .843 .532 .463 r
F
.36017 .32286 m .35561 .33463 L .36472 .27388 L .999 .788 .472 r
F
.35561 .33463 m .35952 .29867 L .36061 .29347 L .834 .622 .615 r
F
.36037 .30285 m .36061 .29347 L .36472 .27388 L F
.35561 .33463 m .36061 .29347 L .36037 .30285 L F
.36472 .27388 m .36061 .29347 L .36713 .26573 L 0 0 0 r
F
.36061 .29347 m .35952 .29867 L .36094 .29252 L F
.36061 .29347 m .36094 .29252 L .36713 .26573 L F
.36144 .29036 m .36408 .24973 L .36713 .26573 L .998 .794 .448 r
F
.36028 .2905 m .36408 .24973 L .36144 .29036 L F
.34459 .4639 m .34159 .44515 L .35628 .28566 L .935 .673 .516 r
F
.35628 .28566 m .35153 .3018 L .35526 .34056 L .843 .532 .463 r
F
.35153 .3018 m .35011 .36282 L .35526 .34056 L .791 .488 .476 r
F
.35561 .33463 m .3524 .32067 L .35573 .31036 L .834 .622 .615 r
F
.35759 .31638 m .35573 .31036 L .35952 .29867 L F
.35561 .33463 m .35573 .31036 L .35759 .31638 L F
.34263 .36886 m .33916 .36528 L .34474 .36334 L .663 .741 .908 r
F
.33916 .36528 m .34125 .35973 L .34474 .36334 L F
.34125 .35973 m .33775 .35612 L .34336 .35415 L .664 .741 .908 r
F
.33775 .35612 m .33986 .35051 L .34336 .35415 L F
.34336 .35415 m .33986 .35051 L .34548 .34852 L F
.33986 .35051 m .34197 .34486 L .34548 .34852 L F
.34197 .34486 m .33845 .34119 L .3441 .33919 L F
.33845 .34119 m .34057 .33549 L .3441 .33919 L .664 .742 .908 r
F
.3441 .33919 m .34057 .33549 L .34624 .33349 L .663 .741 .908 r
F
.34057 .33549 m .3427 .32977 L .34624 .33349 L F
.3427 .32977 m .33915 .32603 L .34485 .32402 L .662 .741 .908 r
F
.33915 .32603 m .34129 .32027 L .34485 .32402 L F
.34344 .31445 m .33986 .31065 L .34561 .30858 L .664 .741 .908 r
F
.33986 .31065 m .34203 .30476 L .34561 .30858 L .664 .742 .908 r
F
.34203 .30476 m .33842 .30093 L .3442 .29886 L .663 .741 .908 r
F
.33842 .30093 m .34059 .29499 L .3442 .29886 L F
.3473 .30967 m .34405 .29874 L .34159 .44515 L .97 .688 .437 r
F
.33707 .37078 m .33916 .36528 L .34263 .36886 L .663 .741 .908 r
F
.34129 .32027 m .33772 .31649 L .34344 .31445 L F
.33772 .31649 m .33986 .31065 L .34344 .31445 L F
.34405 .29874 m .33903 .41908 L .34159 .44515 L .969 .684 .436 r
F
.34159 .44515 m .33903 .41908 L .35153 .3018 L .911 .651 .532 r
F
.33903 .41908 m .34622 .32692 L .35153 .3018 L .858 .607 .559 r
F
.35153 .3018 m .34622 .32692 L .35011 .36282 L .791 .488 .476 r
F
.3524 .32067 m .35474 .31407 L .35952 .29867 L 0 0 .415 r
F
.3524 .32067 m .35162 .30904 L .35474 .31407 L F
.35162 .30904 m .35024 .28817 L .35254 .30143 L F
.35162 .30904 m .35254 .30143 L .35474 .31407 L F
.35198 .29819 m .35131 .30387 L .35474 .31407 L 0 0 .051 r
F
.35131 .30387 m .35445 .28278 L .35519 .27936 L .345 .218 .561 r
F
.35397 .28958 m .35519 .27936 L .35971 .25862 L F
.35131 .30387 m .35519 .27936 L .35397 .28958 L F
.35024 .28817 m .35062 .2938 L .35198 .29819 L 0 0 .051 r
F
.35062 .2938 m .35131 .30387 L .35198 .29819 L F
.35952 .29867 m .35474 .31407 L .36408 .24973 L .998 .794 .448 r
F
.35474 .31407 m .35971 .25862 L .36408 .24973 L .918 .681 .564 r
F
.36408 .24973 m .35971 .25862 L .36384 .28153 L .849 .511 .412 r
F
.36429 .28193 m .36384 .28153 L .3643 .28408 L F
.36408 .24973 m .36384 .28153 L .36429 .28193 L F
.35971 .25862 m .36153 .2569 L .36127 .26726 L 0 0 .031 r
F
.36153 .2569 m .3618 .25664 L .36127 .26726 L F
.35474 .31407 m .35131 .30387 L .35971 .25862 L .918 .681 .564 r
F
.35971 .25862 m .35445 .28278 L .3618 .25664 L 0 0 .031 r
F
.35661 .27509 m .35905 .23452 L .3618 .25664 L .999 .793 .456 r
F
.35445 .28278 m .3553 .27392 L .35661 .27509 L F
.3553 .27392 m .35905 .23452 L .35661 .27509 L F
.36127 .26726 m .3618 .25664 L .36421 .28312 L 0 0 .031 r
F
.36416 .28328 m .36421 .28312 L .3643 .28408 L F
.36127 .26726 m .36421 .28312 L .36416 .28328 L F
.35952 .29867 m .36028 .2905 L .36144 .29036 L .998 .794 .448 r
F
.36577 .27836 m .36713 .26573 L .36957 .29444 L 0 0 0 r
F
.37169 .28363 m .37258 .28049 L .37387 .29732 L 0 0 .101 r
F
.37315 .29617 m .37387 .29732 L .37462 .30713 L F
.36716 .29887 m .362 .32436 L .36426 .31104 L .863 .767 .262 r
F
.37513 .29483 m .3741 .27589 L .37674 .29988 L .691 .73 .216 r
F
.37894 .33387 m .37725 .30771 L .38083 .33815 L 0 0 .264 r
F
.37725 .30771 m .37674 .29988 L .37748 .30678 L F
.37725 .30771 m .37748 .30678 L .38083 .33815 L F
.37756 .30756 m .37721 .3335 L .38083 .33815 L .926 .668 .182 r
F
.37674 .29988 m .37681 .30477 L .37756 .30756 L F
.37681 .30477 m .37721 .3335 L .37756 .30756 L F
.37674 .29988 m .3741 .27589 L .37721 .3335 L F
.37721 .3335 m .37462 .30713 L .37915 .29661 L .709 .498 .601 r
F
.38044 .29997 m .37915 .29661 L .38123 .29179 L F
.37721 .3335 m .37915 .29661 L .38044 .29997 L F
.37462 .30713 m .37653 .31049 L .38123 .29179 L 0 0 .276 r
F
.37462 .30713 m .37274 .28255 L .37653 .31049 L F
.37274 .28255 m .37228 .27653 L .37291 .28157 L F
.37274 .28255 m .37291 .28157 L .37653 .31049 L F
.37267 .27961 m .3725 .31368 L .37653 .31049 L .972 .673 .284 r
F
.37228 .27653 m .37229 .27864 L .37267 .27961 L F
.37229 .27864 m .3725 .31368 L .37267 .27961 L F
.37228 .27653 m .36914 .26274 L .3725 .31368 L F
.36957 .29444 m .36713 .26573 L .37226 .28126 L .17 .097 .525 r
F
.36713 .26573 m .36769 .29468 L .37226 .28126 L .95 .659 .213 r
F
.37226 .28126 m .36769 .29468 L .373 .27688 L .792 .793 .298 r
F
.37166 .28488 m .37226 .28126 L .37502 .2695 L .17 .097 .525 r
F
.36957 .29444 m .37502 .2695 L .37464 .27167 L F
.37464 .27167 m .37502 .2695 L .37713 .26053 L F
.37653 .31049 m .3725 .31368 L .3808 .25951 L .983 .756 .515 r
F
.38092 .25947 m .3808 .25951 L .38108 .2577 L F
.37653 .31049 m .3808 .25951 L .38092 .25947 L F
.38123 .29179 m .3798 .29749 L .38378 .28162 L .687 .702 .173 r
F
.3798 .29749 m .37653 .31049 L .3805 .29467 L F
.3798 .29749 m .3805 .29467 L .38378 .28162 L F
.37976 .3165 m .38123 .29179 L .38569 .27695 L .709 .498 .601 r
F
.3795 .30976 m .38123 .29179 L .37976 .3165 L F
.37653 .31049 m .38108 .2577 L .38378 .28162 L .983 .756 .515 r
F
.3725 .31368 m .37713 .26053 L .38108 .2577 L .844 .609 .584 r
F
.37713 .26057 m .37741 .29819 L .38128 .29826 L .716 .4 .442 r
F
.37713 .26053 m .37713 .26057 L .37713 .26057 L F
.37713 .26057 m .37741 .29819 L .37713 .26057 L F
.3725 .31368 m .36957 .29444 L .37713 .26053 L .844 .609 .584 r
F
.37713 .26053 m .37226 .28126 L .37741 .29819 L .716 .4 .442 r
F
.37226 .28126 m .373 .27688 L .37484 .2707 L .792 .793 .298 r
F
.36957 .29444 m .37226 .28126 L .37166 .28488 L .17 .097 .525 r
F
.37721 .3335 m .3795 .30976 L .37976 .3165 L .709 .498 .601 r
F
.3845 .3382 m .38539 .3212 L .3901 .29952 L .699 .497 .61 r
F
.38166 .35784 m .3853 .3221 L .3845 .3382 L F
.3853 .3221 m .38539 .3212 L .3845 .3382 L F
.38541 .35873 m .38166 .35784 L .3901 .29952 L .967 .731 .529 r
F
.3901 .29952 m .38539 .3212 L .39201 .30417 L 0 0 .191 r
F
.38732 .31623 m .38925 .28117 L .39201 .30417 L .989 .804 .417 r
F
.38539 .3212 m .38608 .31408 L .38732 .31623 L F
.38608 .31408 m .38925 .28117 L .38732 .31623 L F
.39557 .31417 m .39726 .30557 L .39785 .31184 L 0 0 0 r
F
.39528 .34013 m .39622 .33055 L .39758 .33077 L .958 .796 .353 r
F
.39688 .32247 m .39785 .31184 L .39985 .33287 L 0 0 0 r
F
.39726 .30557 m .39413 .29189 L .39737 .33376 L .969 .669 .271 r
F
.39782 .33466 m .39737 .33376 L .39795 .34137 L F
.39726 .30557 m .39737 .33376 L .39782 .33466 L F
.39891 .30305 m .39955 .32332 L .40012 .32075 L .782 .45 .425 r
F
.39785 .31184 m .39726 .30557 L .398 .30953 L 0 0 .4 r
F
.4022 .31191 m .39891 .30305 L .4026 .35705 L .974 .666 .347 r
F
.39413 .29189 m .39466 .3304 L .39795 .34137 L .876 .546 .422 r
F
.40214 .35031 m .40171 .34927 L .4026 .35705 L .782 .45 .425 r
F
.40653 .33177 m .40344 .31822 L .40736 .36769 L .97 .671 .276 r
F
.40483 .33787 m .40238 .3137 L .40478 .34708 L .85 .619 .078 r
F
.40238 .3137 m .40236 .31413 L .40478 .34708 L F
.40615 .38185 m .40291 .37464 L .40334 .51694 L .965 .682 .447 r
F
.40291 .37464 m .40045 .49604 L .40334 .51694 L .964 .68 .444 r
F
.40037 .4198 m .4052 .34911 L .40786 .37375 L .802 .565 .579 r
F
.40037 .4198 m .39793 .38904 L .4052 .34911 L F
.4022 .31191 m .4026 .35705 L .40603 .36405 L .974 .666 .347 r
F
.4026 .35705 m .39985 .33287 L .40516 .31582 L .76 .54 .599 r
F
.4018 .32659 m .40208 .33114 L .40502 .31812 L 0 0 .4 r
F
.40605 .31682 m .40516 .31582 L .40652 .31146 L .76 .54 .599 r
F
.4026 .35705 m .40516 .31582 L .40605 .31682 L F
.4018 .32659 m .40502 .31812 L .40652 .31146 L 0 0 .4 r
F
.39985 .33287 m .40158 .33152 L .4018 .32659 L F
.40158 .33152 m .40208 .33114 L .4018 .32659 L F
.40238 .3137 m .4022 .31191 L .40236 .31413 L .85 .619 .078 r
F
.40536 .34953 m .40478 .34708 L .40603 .36405 L F
.40483 .33787 m .40478 .34708 L .40536 .34953 L F
.39985 .33287 m .39785 .31184 L .40208 .33114 L 0 0 .4 r
F
.39785 .31184 m .398 .30953 L .40208 .33114 L F
.3976 .30737 m .39795 .34137 L .40208 .33114 L .969 .669 .271 r
F
.40208 .33114 m .40139 .33286 L .40522 .30614 L .987 .836 .455 r
F
.40139 .33286 m .39823 .3407 L .40053 .3293 L F
.40139 .33286 m .40053 .3293 L .40522 .30614 L F
.39726 .30557 m .39728 .30702 L .3976 .30737 L .969 .669 .271 r
F
.39728 .30702 m .39795 .34137 L .3976 .30737 L F
.39489 .32891 m .39868 .28453 L .40254 .28051 L .74 .521 .597 r
F
.39466 .3304 m .3948 .32873 L .39489 .32891 L F
.3948 .32873 m .39868 .28453 L .39489 .32891 L F
.39466 .3304 m .39201 .30417 L .39868 .28453 L F
.39201 .30417 m .39389 .31009 L .39868 .28453 L 0 0 .243 r
F
.39201 .30417 m .38932 .28174 L .39389 .31009 L F
.38932 .28174 m .38925 .28117 L .3893 .28148 L F
.38932 .28174 m .3893 .28148 L .39389 .31009 L F
.39142 .30852 m .39201 .30417 L .39412 .32513 L 0 0 .191 r
F
.39394 .32554 m .39412 .32513 L .39466 .3304 L F
.39142 .30852 m .39412 .32513 L .39394 .32554 L F
.39002 .33926 m .39066 .33183 L .39172 .33134 L .99 .796 .411 r
F
.39823 .3407 m .39795 .34137 L .39814 .34048 L .987 .836 .455 r
F
.39823 .3407 m .39814 .34048 L .40522 .30614 L F
.39308 .36417 m .39301 .36449 L .3931 .36391 L .882 .772 .273 r
F
.4092 .35714 m .40653 .33177 L .40871 .36293 L .878 .637 .112 r
F
.40936 .36132 m .40871 .36293 L .41034 .38622 L F
.4092 .35714 m .40871 .36293 L .40936 .36132 L F
.40653 .33177 m .40736 .36769 L .41034 .38622 L .97 .671 .276 r
F
.40795 .36483 m .40917 .35761 L .40926 .35838 L .256 .16 .549 r
F
.40736 .36769 m .40782 .36515 L .40795 .36483 L F
.40782 .36515 m .40917 .35761 L .40795 .36483 L F
.40917 .35761 m .41012 .35229 L .40926 .35838 L F
.40764 .34084 m .40772 .34171 L .40785 .34296 L .876 .585 .065 r
F
.40772 .34171 m .4092 .35714 L .40785 .34296 L F
.40936 .3613 m .41034 .38622 L .41018 .36292 L .878 .637 .112 r
F
.41329 .3805 m .41465 .38273 L .41819 .36839 L 0 0 .362 r
F
.41483 .4021 m .41819 .36839 L .41822 .36822 L .759 .557 .623 r
F
.41401 .38531 m .41034 .38622 L .41841 .32138 L .972 .734 .517 r
F
.41754 .38262 m .41822 .36822 L .42244 .34743 L .759 .557 .623 r
F
.4175 .38032 m .41822 .36822 L .41754 .38262 L F
.41483 .4021 m .41822 .36822 L .41722 .38492 L F
.41832 .40528 m .41483 .4021 L .42244 .34743 L .955 .719 .54 r
F
.42244 .34743 m .41819 .36839 L .42468 .34698 L 0 0 .121 r
F
.41859 .36375 m .4218 .32651 L .41942 .36435 L .989 .799 .412 r
F
.41819 .36839 m .41401 .38531 L .42161 .3279 L F
.42169 .3278 m .42161 .3279 L .4218 .32651 L F
.41819 .36839 m .42161 .3279 L .42169 .3278 L F
.41942 .36435 m .4218 .32651 L .42468 .34698 L F
.41401 .38531 m .41841 .32138 L .4218 .32651 L .972 .734 .517 r
F
.41924 .33125 m .41922 .36357 L .42259 .37138 L .846 .525 .445 r
F
.41841 .32138 m .41862 .33212 L .41924 .33125 L F
.41862 .33212 m .41922 .36357 L .41924 .33125 L F
.41841 .32138 m .41443 .33303 L .41922 .36357 L F
.41443 .33303 m .41645 .33843 L .41676 .34117 L .052 0 .223 r
F
.4169 .34876 m .41676 .34117 L .41922 .36357 L F
.41443 .33303 m .41676 .34117 L .4169 .34876 L F
.41722 .38492 m .4175 .38032 L .41754 .38262 L .759 .557 .623 r
F
.41819 .36839 m .41859 .36375 L .41942 .36435 L .989 .799 .412 r
F
.42409 .35567 m .42468 .34698 L .42744 .37249 L 0 0 .121 r
F
.42429 .38584 m .42224 .39467 L .42425 .37981 L .98 .802 .393 r
F
.42911 .34614 m .42881 .3461 L .42971 .33945 L F
.42692 .34589 m .42744 .37249 L .42884 .38069 L .822 .5 .444 r
F
.42634 .3354 m .42665 .34585 L .42692 .34589 L F
.42665 .34585 m .42744 .37249 L .42692 .34589 L F
.42944 .3766 m .42884 .38069 L .43046 .39017 L F
.42634 .3354 m .42884 .38069 L .42944 .3766 L F
.4314 .36652 m .43263 .35871 L .43535 .38559 L 0 0 .025 r
F
.43059 .41504 m .42733 .43005 L .43077 .40458 L .968 .801 .372 r
F
.43524 .39391 m .43128 .41188 L .43226 .4057 L .927 .798 .329 r
F
.44156 .36939 m .44256 .38701 L .44287 .38422 L .939 .597 .352 r
F
.44256 .38701 m .44313 .39707 L .44287 .38422 L F
.19138 .37375 m .19303 .36825 L .19679 .37182 L .664 .741 .908 r
F
.19138 .37375 m .18762 .37019 L .19303 .36825 L F
.72628 .37375 m .72952 .36825 L .73224 .37182 L F
.72628 .37375 m .72355 .37019 L .72952 .36825 L F
.90458 .37376 m .90835 .36825 L .91073 .37182 L F
.90458 .37376 m .9022 .37019 L .90835 .36825 L F
.28781 .3736 m .28975 .36811 L .29332 .37168 L .663 .741 .908 r
F
.28781 .3736 m .28424 .37004 L .28975 .36811 L F
.82275 .3736 m .82628 .36811 L .82882 .37168 L F
.82275 .3736 m .82021 .37004 L .82628 .36811 L F
.20593 .37345 m .20762 .36795 L .21135 .37152 L .664 .741 .908 r
F
.20593 .37345 m .2022 .36989 L .20762 .36795 L F
.74091 .37346 m .7442 .36796 L .74689 .37153 L .664 .742 .908 r
F
.74091 .37346 m .73821 .3699 L .7442 .36796 L F
.60472 .43546 m .60772 .43503 L .61063 .43678 L .087 .595 .891 r
F
.45185 .40603 m .44888 .38984 L .45351 .43577 L .94 .654 .192 r
F
.8374 .3733 m .84098 .36781 L .84348 .37139 L .664 .742 .908 r
F
.8374 .3733 m .83489 .36975 L .84098 .36781 L F
.30238 .37331 m .30436 .36782 L .3079 .37138 L .663 .742 .908 r
F
.30238 .37331 m .29883 .36975 L .30436 .36782 L F
.22048 .37316 m .22222 .36766 L .22592 .37123 L .664 .741 .908 r
F
.22048 .37316 m .21678 .3696 L .22222 .36766 L F
.75555 .37317 m .75888 .36766 L .76155 .37123 L F
.75555 .37317 m .75288 .3696 L .75888 .36766 L F
.46366 .48078 m .46063 .46462 L .46465 .47083 L .272 .234 .631 r
F
.45836 .46048 m .45536 .44472 L .46024 .46317 L 0 0 .364 r
F
.46041 .46423 m .46024 .46317 L .46063 .46462 L F
.45836 .46048 m .46024 .46317 L .46041 .46423 L F
.45767 .44564 m .45476 .4254 L .45671 .44091 L .788 .554 0 r
F
.45536 .44472 m .45767 .44564 L .46063 .46462 L 0 0 .461 r
F
.45836 .46048 m .46063 .46462 L .46317 .47819 L 0 0 .364 r
F
.4633 .47943 m .46317 .47819 L .46366 .48078 L F
.45836 .46048 m .46317 .47819 L .4633 .47943 L F
.46082 .45617 m .46272 .42935 L .46625 .41816 L .848 .637 .617 r
F
.45851 .45099 m .45767 .44564 L .45857 .45003 L 0 0 .296 r
F
.4581 .44964 m .45671 .44091 L .45786 .45006 L .788 .554 0 r
F
.45821 .45067 m .45786 .45006 L .45966 .46434 L F
.4581 .44964 m .45786 .45006 L .45821 .45067 L F
.45767 .44564 m .45671 .44091 L .4581 .44964 L F
.45767 .44564 m .45789 .44769 L .45856 .44998 L F
.45167 .50746 m .45536 .44472 L .45836 .46048 L .885 .647 .574 r
F
.45476 .4254 m .45653 .45239 L .45966 .46434 L .897 .632 .122 r
F
.45726 .44898 m .45915 .43998 L .45923 .43974 L .441 .347 .653 r
F
.45653 .45239 m .45725 .44897 L .45726 .44898 L F
.45725 .44897 m .45915 .43998 L .45726 .44898 L F
.45901 .44314 m .45923 .43974 L .46272 .42935 L F
.45653 .45239 m .45923 .43974 L .45901 .44314 L F
.46063 .46462 m .45851 .45099 L .46155 .46463 L 0 0 .296 r
F
.45851 .45099 m .45857 .45003 L .46155 .46463 L F
.46515 .47254 m .46465 .47083 L .46528 .47181 L .272 .234 .631 r
F
.46366 .48078 m .46465 .47083 L .46515 .47254 L F
.46555 .47514 m .46528 .47181 L .46619 .47321 L F
.46366 .48078 m .46528 .47181 L .46555 .47514 L F
.46063 .46462 m .46288 .47114 L .46619 .47321 L 0 0 .296 r
F
.46189 .46826 m .46155 .46463 L .46288 .47114 L F
.46063 .46462 m .46155 .46463 L .46189 .46826 L F
.46079 .45637 m .46057 .45384 L .46082 .45617 L .848 .637 .617 r
F
.46155 .46463 m .45966 .46434 L .46288 .47114 L .788 .554 0 r
F
.45856 .44998 m .45966 .46434 L .46155 .46463 L F
.45966 .46434 m .46057 .45392 L .46079 .45637 L .848 .637 .617 r
F
.46057 .45392 m .46057 .45384 L .46079 .45637 L F
.46057 .45384 m .46272 .42935 L .46082 .45617 L F
.45789 .44769 m .45966 .46434 L .45856 .44998 L .788 .554 0 r
F
.46425 .45872 m .46625 .41816 L .4697 .40903 L .931 .697 .562 r
F
.46288 .47114 m .46393 .45468 L .46425 .45872 L F
.46393 .45468 m .46625 .41816 L .46425 .45872 L F
.46619 .47321 m .46288 .47114 L .4697 .40903 L .96 .719 .531 r
F
.4697 .40903 m .46625 .41816 L .47183 .42519 L .689 .342 .382 r
F
.31695 .37301 m .31897 .36751 L .32248 .37108 L .664 .741 .908 r
F
.31695 .37301 m .31343 .36945 L .31897 .36751 L F
.85206 .37302 m .85568 .36751 L .85815 .37109 L F
.85206 .37302 m .84957 .36945 L .85568 .36751 L F
.23504 .37286 m .23682 .36736 L .24049 .37093 L F
.23504 .37286 m .23136 .36929 L .23682 .36736 L F
.7702 .37286 m .77357 .36735 L .7762 .37093 L F
.7702 .37286 m .76755 .36929 L .77357 .36735 L F
.50513 .42732 m .50763 .43762 L .51082 .43621 L .663 .271 .293 r
F
.50513 .42732 m .50191 .43303 L .50763 .43762 L F
.86672 .37271 m .87038 .36721 L .87283 .37078 L .663 .741 .908 r
F
.86672 .37271 m .86426 .36914 L .87038 .36721 L F
.33152 .37271 m .33359 .36721 L .33707 .37078 L F
.33152 .37271 m .32803 .36914 L .33359 .36721 L F
.68832 .37278 m .69145 .36722 L .69424 .37079 L .668 .745 .907 r
F
.68832 .37278 m .68552 .36923 L .69145 .36722 L F
.68278 .38222 m .68552 .36923 L .68832 .37278 L .882 .775 .738 r
F
.57554 .4386 m .57825 .42814 L .5813 .43401 L .971 .928 .676 r
F
.78484 .37256 m .78826 .36706 L .79087 .37064 L .663 .741 .908 r
F
.78484 .37256 m .78223 .369 L .78826 .36706 L F
.2496 .37256 m .25142 .36706 L .25507 .37064 L F
.2496 .37256 m .24595 .369 L .25142 .36706 L F
.88138 .37242 m .88509 .36691 L .88751 .37049 L .664 .742 .908 r
F
.88138 .37242 m .87895 .36886 L .88509 .36691 L F
.70296 .37243 m .70613 .36693 L .7089 .37051 L .662 .74 .908 r
F
.70296 .37243 m .70018 .36885 L .70613 .36693 L F
.26417 .37227 m .26603 .36676 L .26965 .37034 L .664 .741 .908 r
F
.26417 .37227 m .26055 .3687 L .26603 .36676 L F
.7995 .37227 m .80296 .36677 L .80554 .37035 L .664 .742 .908 r
F
.7995 .37227 m .79691 .36872 L .80296 .36677 L F
.18223 .37212 m .18385 .36661 L .18762 .37019 L .664 .741 .908 r
F
.18223 .37212 m .17844 .36855 L .18385 .36661 L F
.89605 .37213 m .8998 .36662 L .9022 .37019 L .663 .741 .908 r
F
.89605 .37213 m .89365 .36855 L .8998 .36662 L F
.7176 .37213 m .72081 .36662 L .72355 .37019 L .664 .741 .908 r
F
.7176 .37213 m .71485 .36856 L .72081 .36662 L F
.27874 .37197 m .28065 .36646 L .28424 .37004 L F
.27874 .37197 m .27514 .3684 L .28065 .36646 L F
.81415 .37197 m .81766 .36646 L .82021 .37004 L .664 .742 .908 r
F
.81415 .37197 m .81159 .36841 L .81766 .36646 L F
.52345 .40696 m .52327 .40417 L .52501 .39826 L .977 .882 .513 r
F
.51923 .41794 m .52188 .39751 L .52501 .39826 L .996 .848 .509 r
F
.52501 .39826 m .52188 .39751 L .52733 .40711 L .85 .395 .108 r
F
.52757 .40738 m .52733 .40711 L .52766 .4077 L F
.52501 .39826 m .52733 .40711 L .52757 .40738 L F
.52188 .39751 m .52286 .39767 L .52297 .39943 L .038 0 0 r
F
.52286 .39767 m .52452 .39793 L .52297 .39943 L F
.51923 .41794 m .51606 .42303 L .52188 .39751 L .996 .848 .509 r
F
.51606 .42303 m .51874 .3996 L .52188 .39751 L .999 .828 .535 r
F
.52188 .39751 m .51874 .3996 L .52452 .39793 L .038 0 0 r
F
.52012 .3992 m .52139 .38884 L .52452 .39793 L .946 .914 .541 r
F
.51874 .3996 m .51911 .39809 L .52012 .3992 L F
.51911 .39809 m .52139 .38884 L .52012 .3992 L F
.52297 .39943 m .52452 .39793 L .52766 .4077 L .038 0 0 r
F
.52237 .41298 m .51923 .41794 L .52327 .40417 L .977 .882 .513 r
F
.52237 .41298 m .52327 .40417 L .52345 .40696 L F
.19679 .37182 m .19845 .36631 L .2022 .36989 L .663 .741 .908 r
F
.19679 .37182 m .19303 .36825 L .19845 .36631 L F
.73224 .37182 m .7355 .36632 L .73821 .3699 L F
.73224 .37182 m .72952 .36825 L .7355 .36632 L F
.52501 .39826 m .52766 .4077 L .5308 .41624 L .85 .395 .108 r
F
.46245 .5707 m .45927 .56264 L .46583 .51546 L .921 .687 .568 r
F
.45927 .56264 m .46243 .52098 L .46583 .51546 L .894 .673 .597 r
F
.46583 .51546 m .46243 .52098 L .46762 .55028 L .885 .561 .432 r
F
.51399 .43369 m .51082 .43621 L .51659 .4326 L 0 0 0 r
F
.82882 .37168 m .83237 .36617 L .83489 .36975 L .664 .741 .908 r
F
.82882 .37168 m .82628 .36811 L .83237 .36617 L F
.29332 .37168 m .29527 .36617 L .29883 .36975 L .663 .741 .908 r
F
.29332 .37168 m .28975 .36811 L .29527 .36617 L F
.21135 .37152 m .21306 .36602 L .21678 .3696 L F
.21135 .37152 m .20762 .36795 L .21306 .36602 L F
.74689 .37153 m .7502 .36602 L .75288 .3696 L .664 .742 .908 r
F
.74689 .37153 m .7442 .36796 L .7502 .36602 L F
.3079 .37138 m .30989 .36587 L .31343 .36945 L F
.3079 .37138 m .30436 .36782 L .30989 .36587 L F
.84348 .37139 m .84708 .36586 L .84957 .36945 L .664 .741 .908 r
F
.84348 .37139 m .84098 .36781 L .84708 .36586 L F
.6362 .39784 m .64055 .43102 L .64338 .43178 L .955 .613 .243 r
F
.22592 .37123 m .22767 .36571 L .23136 .36929 L .664 .741 .908 r
F
.22592 .37123 m .22222 .36766 L .22767 .36571 L F
.76155 .37123 m .7649 .36571 L .76755 .36929 L .664 .742 .908 r
F
.76155 .37123 m .75888 .36766 L .7649 .36571 L F
.32248 .37108 m .32452 .36557 L .32803 .36914 L .664 .741 .908 r
F
.32248 .37108 m .31897 .36751 L .32452 .36557 L F
.85815 .37109 m .86179 .36556 L .86426 .36914 L F
.85815 .37109 m .85568 .36751 L .86179 .36556 L F
.44862 .49231 m .44564 .47496 L .45238 .42846 L .873 .635 .576 r
F
.48666 .53557 m .48347 .53175 L .48929 .52054 L .884 .752 .711 r
F
.48347 .53175 m .48609 .51795 L .48929 .52054 L .82 .7 .731 r
F
.48061 .56317 m .48347 .53175 L .48666 .53557 L .945 .74 .595 r
F
.7762 .37093 m .7796 .36542 L .78223 .369 L .663 .741 .908 r
F
.7762 .37093 m .77357 .36735 L .7796 .36542 L F
.24049 .37093 m .24229 .36542 L .24595 .369 L F
.24049 .37093 m .23682 .36736 L .24229 .36542 L F
.59289 .43148 m .59006 .43172 L .59301 .43174 L .797 .398 .298 r
F
.58683 .41763 m .59006 .43172 L .59289 .43148 L F
.58395 .42153 m .58709 .43198 L .59006 .43172 L .678 .277 .279 r
F
.59006 .43172 m .58709 .43198 L .5872 .43195 L .276 .78 .804 r
F
.58973 .4161 m .59301 .43174 L .59561 .43179 L .87 .467 .267 r
F
.58973 .4161 m .58683 .41763 L .59301 .43174 L F
.58683 .41763 m .58395 .42153 L .59006 .43172 L .797 .398 .298 r
F
.59006 .43172 m .5872 .43195 L .59302 .43051 L .276 .78 .804 r
F
.59301 .43174 m .59006 .43172 L .59039 .4317 L .069 .632 .75 r
F
.59301 .43174 m .59039 .4317 L .59599 .43144 L F
.59561 .43179 m .59301 .43174 L .59596 .43272 L .87 .467 .267 r
F
.87283 .37078 m .87651 .36528 L .87895 .36886 L .663 .741 .908 r
F
.87283 .37078 m .87038 .36721 L .87651 .36528 L F
.33707 .37078 m .33359 .36721 L .33916 .36528 L F
.69424 .37079 m .69739 .36528 L .70018 .36885 L F
.69424 .37079 m .69145 .36722 L .69739 .36528 L F
.25507 .37064 m .25691 .36512 L .26055 .3687 L .664 .741 .908 r
F
.25507 .37064 m .25142 .36706 L .25691 .36512 L F
.79087 .37064 m .79431 .36512 L .79691 .36872 L .663 .741 .908 r
F
.79087 .37064 m .78826 .36706 L .79431 .36512 L F
.55425 .39871 m .55736 .43012 L .56045 .4339 L .93 .584 .355 r
F
.55425 .39871 m .55123 .39959 L .55736 .43012 L F
.17305 .37048 m .17465 .36497 L .17844 .36855 L .663 .741 .908 r
F
.17305 .37048 m .16925 .36691 L .17465 .36497 L F
.88751 .37049 m .89124 .36497 L .89365 .36855 L F
.88751 .37049 m .88509 .36691 L .89124 .36497 L F
.7089 .37051 m .71209 .36498 L .71485 .36856 L .664 .741 .907 r
F
.7089 .37051 m .70613 .36693 L .71209 .36498 L F
.49312 .41723 m .4954 .44207 L .49866 .43852 L .803 .465 .415 r
F
.49312 .41723 m .48981 .4257 L .4954 .44207 L F
.26965 .37034 m .27153 .36482 L .27514 .3684 L .664 .741 .908 r
F
.26965 .37034 m .26603 .36676 L .27153 .36482 L F
.80554 .37035 m .80902 .36482 L .81159 .36841 L .664 .742 .908 r
F
.80554 .37035 m .80296 .36677 L .80902 .36482 L F
.71437 .61281 m .71112 .6021 L .71131 .49452 L .956 .686 .483 r
F
.71112 .6021 m .70897 .49879 L .71131 .49452 L .953 .686 .492 r
F
.67966 .49773 m .67711 .3745 L .67995 .37842 L .973 .701 .453 r
F
.67696 .48712 m .68191 .52045 L .68462 .52029 L .93 .576 .333 r
F
.6819 .50543 m .67888 .49933 L .68552 .50966 L 0 0 .516 r
F
.67018 .48438 m .66705 .47454 L .67413 .49866 L .735 .426 0 r
F
.67399 .49817 m .67135 .4971 L .67413 .49866 L .901 .558 .079 r
F
.66705 .47454 m .67135 .4971 L .67399 .49817 L F
.66401 .4666 m .66858 .49617 L .67135 .4971 L .941 .599 .18 r
F
.67135 .4971 m .66858 .49617 L .6687 .49602 L .916 .921 .803 r
F
.66705 .47454 m .66401 .4666 L .67135 .4971 L .901 .558 .079 r
F
.67135 .4971 m .6687 .49602 L .67432 .48863 L .916 .921 .803 r
F
.67413 .49866 m .67135 .4971 L .67696 .48712 L .938 .862 .739 r
F
.67684 .48734 m .67432 .48863 L .67696 .48712 L .916 .921 .803 r
F
.67135 .4971 m .67432 .48863 L .67684 .48734 L F
.67389 .4892 m .67163 .48925 L .67432 .48863 L .841 .892 .876 r
F
.66858 .49617 m .67163 .48925 L .67389 .4892 L F
.66401 .4666 m .661 .45963 L .66858 .49617 L .941 .599 .18 r
F
.661 .45963 m .66576 .4944 L .66858 .49617 L .95 .616 .206 r
F
.67142 .48943 m .66879 .48709 L .67163 .48925 L .737 .747 .86 r
F
.66576 .4944 m .66879 .48709 L .67142 .48943 L F
.661 .45963 m .65797 .45201 L .66576 .4944 L .95 .616 .206 r
F
.66571 .49413 m .66284 .49049 L .66576 .4944 L .958 .625 .24 r
F
.65797 .45201 m .66284 .49049 L .66571 .49413 L F
.66262 .48923 m .65992 .48686 L .66284 .49049 L .961 .626 .286 r
F
.65496 .44514 m .65992 .48686 L .66262 .48923 L F
.65204 .44066 m .65704 .48457 L .65992 .48686 L .96 .625 .31 r
F
.65992 .48686 m .65704 .48457 L .65721 .48447 L .757 .855 .923 r
F
.65797 .45201 m .65496 .44514 L .66284 .49049 L .958 .625 .24 r
F
.65496 .44514 m .65204 .44066 L .65992 .48686 L .961 .626 .286 r
F
.65992 .48686 m .65721 .48447 L .66302 .48111 L .757 .855 .923 r
F
.66284 .49049 m .65992 .48686 L .65996 .48684 L .729 .76 .878 r
F
.66284 .49049 m .65996 .48684 L .66589 .48371 L F
.66284 .49049 m .66589 .48371 L .66879 .48709 L F
.66879 .48709 m .66589 .48371 L .66615 .48474 L .943 .578 .219 r
F
.66858 .49617 m .66576 .4944 L .67163 .48925 L .841 .892 .876 r
F
.66576 .4944 m .66284 .49049 L .66879 .48709 L .737 .747 .86 r
F
.66879 .48709 m .66615 .48474 L .67328 .51335 L .943 .578 .219 r
F
.66879 .48709 m .67328 .51335 L .6733 .51337 L F
.67163 .48925 m .66935 .4893 L .67625 .51677 L .943 .578 .25 r
F
.67432 .48863 m .67179 .48993 L .67913 .51965 L .933 .574 .314 r
F
.67432 .48863 m .67913 .51965 L .68191 .52045 L F
.67163 .48925 m .67625 .51677 L .67913 .51965 L .943 .578 .25 r
F
.67611 .51621 m .67334 .51361 L .67625 .51677 L .943 .578 .219 r
F
.66879 .48709 m .67334 .51361 L .67611 .51621 L F
.66589 .48371 m .67046 .51127 L .67334 .51361 L .944 .579 .242 r
F
.67334 .51361 m .67046 .51127 L .67056 .51099 L .951 .808 .666 r
F
.6733 .51337 m .67328 .51335 L .67334 .51361 L .943 .578 .219 r
F
.67334 .51361 m .67056 .51099 L .676 .49657 L .951 .808 .666 r
F
.67314 .49457 m .67025 .49216 L .67038 .49226 L 0 .124 .591 r
F
.67696 .48712 m .67432 .48863 L .67658 .4981 L .93 .576 .333 r
F
.67887 .49997 m .67658 .4981 L .68191 .52045 L F
.67696 .48712 m .67658 .4981 L .67887 .49997 L F
.67334 .51361 m .676 .49657 L .67888 .49933 L .951 .808 .666 r
F
.67888 .49933 m .676 .49657 L .67664 .49744 L .698 .207 0 r
F
.67888 .49934 m .67888 .49933 L .67889 .49935 L .934 .786 .673 r
F
.67888 .49934 m .67889 .49935 L .6819 .50543 L F
.67625 .51677 m .67888 .49934 L .6819 .50543 L F
.67625 .51677 m .67334 .51361 L .67888 .49933 L F
.67889 .49935 m .67664 .49744 L .68134 .50381 L .698 .207 0 r
F
.67888 .49933 m .67664 .49744 L .67889 .49935 L F
.67059 .51093 m .67314 .49457 L .67589 .49686 L .937 .796 .679 r
F
.68214 .50474 m .68134 .50381 L .68262 .50555 L .698 .207 0 r
F
.676 .49657 m .67965 .50111 L .68262 .50555 L .615 .081 0 r
F
.67589 .49686 m .67314 .49457 L .676 .49657 L .937 .796 .679 r
F
.676 .49657 m .67314 .49457 L .67965 .50111 L .615 .081 0 r
F
.6752 .49663 m .6767 .49712 L .67965 .50111 L 0 .124 .591 r
F
.67314 .49457 m .67389 .49511 L .6752 .49663 L F
.67389 .49511 m .6767 .49712 L .6752 .49663 L F
.67889 .49935 m .68134 .50381 L .68214 .50474 L .698 .207 0 r
F
.67314 .49457 m .67038 .49226 L .67209 .49358 L 0 .124 .591 r
F
.67389 .49511 m .67209 .49358 L .6767 .49712 L F
.67314 .49457 m .67209 .49358 L .67389 .49511 L F
.67046 .51127 m .67052 .51087 L .67059 .51093 L .937 .796 .679 r
F
.67052 .51087 m .67314 .49457 L .67059 .51093 L F
.67163 .48925 m .66879 .48709 L .66935 .4893 L .943 .578 .25 r
F
.67432 .48863 m .67163 .48925 L .67179 .48993 L .933 .574 .314 r
F
.68553 .50968 m .68552 .50966 L .68555 .5097 L 0 0 .516 r
F
.67888 .49933 m .68262 .50555 L .68557 .50974 L .698 .207 0 r
F
.67965 .50111 m .67958 .49757 L .67966 .49773 L .973 .701 .453 r
F
.67958 .49757 m .67711 .3745 L .67966 .49773 L F
.6819 .50543 m .68552 .50966 L .68553 .50968 L 0 0 .516 r
F
.68556 .50972 m .68555 .5097 L .68557 .50974 L F
.6819 .50543 m .68555 .5097 L .68556 .50972 L F
.68262 .50375 m .67995 .37842 L .68278 .38222 L .972 .7 .455 r
F
.68262 .50555 m .68258 .50366 L .68262 .50375 L F
.68258 .50366 m .67995 .37842 L .68262 .50375 L F
.68557 .50974 m .68262 .50555 L .68278 .38222 L .973 .701 .454 r
F
.68278 .38222 m .67995 .37842 L .68552 .36923 L .882 .775 .738 r
F
.18762 .37019 m .18926 .36467 L .19303 .36825 L .664 .741 .908 r
F
.18762 .37019 m .18385 .36661 L .18926 .36467 L F
.9022 .37019 m .90597 .36467 L .90835 .36825 L .664 .742 .908 r
F
.9022 .37019 m .8998 .36662 L .90597 .36467 L F
.72355 .37019 m .72679 .36467 L .72952 .36825 L F
.72355 .37019 m .72081 .36662 L .72679 .36467 L F
.28424 .37004 m .28617 .36452 L .28975 .36811 L .663 .741 .908 r
F
.28424 .37004 m .28065 .36646 L .28617 .36452 L F
.82021 .37004 m .82374 .36452 L .82628 .36811 L .664 .741 .908 r
F
.82021 .37004 m .81766 .36646 L .82374 .36452 L F
.57258 .43978 m .57522 .42462 L .57825 .42814 L .992 .875 .606 r
F
.57213 .4172 m .56899 .40591 L .57465 .39371 L .787 .606 .656 r
F
.57465 .39371 m .57815 .43164 L .58107 .42686 L .931 .594 .373 r
F
.56899 .40591 m .5717 .39553 L .57465 .39371 L .534 .456 .715 r
F
.57465 .39371 m .5717 .39553 L .57815 .43164 L .931 .594 .373 r
F
.2022 .36989 m .20388 .36437 L .20762 .36795 L .664 .741 .908 r
F
.2022 .36989 m .19845 .36631 L .20388 .36437 L F
.73821 .3699 m .7415 .36438 L .7442 .36796 L .663 .741 .908 r
F
.73821 .3699 m .7355 .36632 L .7415 .36438 L F
.61063 .43678 m .60772 .43503 L .61327 .42164 L .951 .822 .681 r
F
.60772 .43503 m .61039 .42081 L .61327 .42164 L .964 .849 .678 r
F
.83489 .36975 m .83846 .36422 L .84098 .36781 L .664 .741 .908 r
F
.83489 .36975 m .83237 .36617 L .83846 .36422 L F
.29883 .36975 m .3008 .36423 L .30436 .36782 L .663 .741 .908 r
F
.29883 .36975 m .29527 .36617 L .3008 .36423 L F
.45476 .4254 m .45398 .42019 L .45595 .44664 L .897 .632 .122 r
F
.45398 .42019 m .45185 .40603 L .45395 .42685 L F
.45398 .42019 m .45395 .42685 L .45595 .44664 L F
.45476 .4254 m .45595 .44664 L .45621 .44748 L F
.45167 .50746 m .44862 .49231 L .45536 .44472 L .885 .647 .574 r
F
.45185 .40603 m .45351 .43577 L .45653 .45239 L .94 .654 .192 r
F
.45621 .44748 m .45595 .44664 L .45653 .45239 L .897 .632 .122 r
F
.45653 .45239 m .45351 .43577 L .45765 .43886 L .441 .347 .653 r
F
.45872 .44202 m .45765 .43886 L .45915 .43998 L F
.45653 .45239 m .45765 .43886 L .45872 .44202 L F
.45351 .43577 m .45391 .43785 L .45392 .43608 L 0 0 .172 r
F
.45391 .43785 m .45563 .44674 L .45392 .43608 L F
.45351 .43577 m .45057 .4161 L .45348 .43371 L F
.45359 .43253 m .45606 .3783 L .45954 .37217 L .929 .685 .549 r
F
.45418 .43927 m .45348 .43371 L .4553 .44474 L 0 0 .172 r
F
.45544 .44579 m .4553 .44474 L .45563 .44674 L F
.45418 .43927 m .4553 .44474 L .45544 .44579 L F
.45351 .43577 m .45348 .43371 L .45418 .43927 L F
.45117 .41971 m .45223 .44644 L .45563 .44674 L .915 .647 .153 r
F
.45223 .44644 m .45318 .42955 L .45359 .43253 L .929 .685 .549 r
F
.45318 .42955 m .45606 .3783 L .45359 .43253 L F
.45139 .41732 m .45239 .39216 L .45606 .3783 L .825 .602 .601 r
F
.45057 .4161 m .45069 .41831 L .45117 .41971 L .915 .647 .153 r
F
.45069 .41831 m .45223 .44644 L .45117 .41971 L F
.45057 .4161 m .44905 .40571 L .45223 .44644 L F
.44905 .40571 m .44766 .3962 L .44868 .40745 L F
.44905 .40571 m .44868 .40745 L .45132 .43643 L F
.44905 .40571 m .45132 .43643 L .45148 .43692 L F
.44766 .3962 m .44469 .37951 L .44901 .43722 L .967 .679 .265 r
F
.44469 .37951 m .446 .41964 L .44901 .43722 L .975 .668 .32 r
F
.44766 .3962 m .44901 .43722 L .45223 .44644 L .967 .679 .265 r
F
.44901 .43722 m .446 .41964 L .45166 .39528 L .825 .602 .601 r
F
.45217 .39506 m .45166 .39528 L .45239 .39216 L F
.44901 .43722 m .45166 .39528 L .45217 .39506 L F
.45166 .39528 m .44859 .40882 L .45239 .39216 L .26 .189 .584 r
F
.44712 .41481 m .44859 .40882 L .45166 .39528 L F
.44469 .37951 m .44156 .36939 L .446 .41964 L .975 .668 .32 r
F
.446 .41964 m .44686 .41604 L .44712 .41481 L .26 .189 .584 r
F
.44686 .41604 m .44859 .40882 L .44712 .41481 L F
.446 .41964 m .44313 .39707 L .44859 .40882 L F
.44383 .39859 m .44485 .42119 L .44859 .40882 L .846 .603 .06 r
F
.44313 .39707 m .44325 .39883 L .44383 .39859 L F
.44325 .39883 m .44485 .42119 L .44383 .39859 L F
.44859 .40882 m .44544 .41924 L .45189 .36748 L .997 .797 .444 r
F
.44544 .41924 m .44485 .42119 L .44519 .41853 L F
.44544 .41924 m .44519 .41853 L .45189 .36748 L F
.45148 .43692 m .45132 .43643 L .45223 .44644 L .915 .647 .153 r
F
.45015 .42774 m .451 .4142 L .45139 .41732 L .825 .602 .601 r
F
.451 .4142 m .45239 .39216 L .45139 .41732 L F
.45392 .43608 m .45563 .44674 L .45915 .43998 L 0 0 .172 r
F
.44901 .43722 m .4498 .42663 L .45015 .42774 L .825 .602 .601 r
F
.4498 .42663 m .45239 .39216 L .45015 .42774 L F
.21678 .3696 m .2185 .36407 L .22222 .36766 L .663 .741 .908 r
F
.21678 .3696 m .21306 .36602 L .2185 .36407 L F
.75288 .3696 m .75621 .36408 L .75888 .36766 L .664 .741 .908 r
F
.75288 .3696 m .7502 .36602 L .75621 .36408 L F
.31343 .36945 m .31544 .36392 L .31897 .36751 L F
.31343 .36945 m .30989 .36587 L .31544 .36392 L F
.84957 .36945 m .85319 .36392 L .85568 .36751 L .663 .741 .908 r
F
.84957 .36945 m .84708 .36586 L .85319 .36392 L F
.23136 .36929 m .23313 .36377 L .23682 .36736 L .664 .741 .908 r
F
.23136 .36929 m .22767 .36571 L .23313 .36377 L F
.76755 .36929 m .77092 .36377 L .77357 .36735 L F
.76755 .36929 m .7649 .36571 L .77092 .36377 L F
.86426 .36914 m .86792 .36363 L .87038 .36721 L .663 .741 .908 r
F
.86426 .36914 m .86179 .36556 L .86792 .36363 L F
.32803 .36914 m .33009 .36363 L .33359 .36721 L F
.32803 .36914 m .32452 .36557 L .33009 .36363 L F
.68552 .36923 m .68864 .36363 L .69145 .36722 L .668 .742 .906 r
F
.68552 .36923 m .68271 .36564 L .68864 .36363 L F
.67995 .37842 m .68271 .36564 L .68552 .36923 L .875 .771 .743 r
F
.24595 .369 m .24777 .36348 L .25142 .36706 L .663 .741 .908 r
F
.24595 .369 m .24229 .36542 L .24777 .36348 L F
.78223 .369 m .78564 .36348 L .78826 .36706 L F
.78223 .369 m .7796 .36542 L .78564 .36348 L F
.70018 .36885 m .70335 .36333 L .70613 .36693 L .664 .742 .908 r
F
.70018 .36885 m .69739 .36528 L .70335 .36333 L F
.87895 .36886 m .88266 .36332 L .88509 .36691 L .664 .741 .908 r
F
.87895 .36886 m .87651 .36528 L .88266 .36332 L F
.63323 .39248 m .63777 .43226 L .64055 .43102 L .961 .629 .26 r
F
.6018 .43405 m .60481 .43411 L .60772 .43503 L 0 .559 .757 r
F
.26055 .3687 m .2624 .36317 L .26603 .36676 L .664 .741 .908 r
F
.26055 .3687 m .25691 .36512 L .2624 .36317 L F
.79691 .36872 m .80037 .36317 L .80296 .36677 L .664 .741 .907 r
F
.79691 .36872 m .79431 .36512 L .80037 .36317 L F
.89365 .36855 m .8974 .36303 L .8998 .36662 L .664 .742 .908 r
F
.89365 .36855 m .89124 .36497 L .8974 .36303 L F
.17844 .36855 m .18006 .36302 L .18385 .36661 L .664 .741 .908 r
F
.17844 .36855 m .17465 .36497 L .18006 .36302 L F
.71485 .36856 m .71806 .36303 L .72081 .36662 L .664 .742 .908 r
F
.71485 .36856 m .71209 .36498 L .71806 .36303 L F
.27514 .3684 m .27705 .36287 L .28065 .36646 L .664 .741 .908 r
F
.27514 .3684 m .27153 .36482 L .27705 .36287 L F
.81159 .36841 m .8151 .36287 L .81766 .36646 L F
.81159 .36841 m .80902 .36482 L .8151 .36287 L F
.19303 .36825 m .19469 .36272 L .19845 .36631 L .663 .741 .908 r
F
.19303 .36825 m .18926 .36467 L .19469 .36272 L F
.72952 .36825 m .73278 .36272 L .7355 .36632 L F
.72952 .36825 m .72679 .36467 L .73278 .36272 L F
.47484 .44317 m .47183 .42519 L .47796 .39711 L .824 .6 .6 r
F
.47796 .39711 m .47979 .44075 L .4831 .44047 L .876 .558 .445 r
F
.47183 .42519 m .47455 .40601 L .47796 .39711 L .546 .404 .639 r
F
.47796 .39711 m .47455 .40601 L .47979 .44075 L .876 .558 .445 r
F
.28975 .36811 m .29169 .36258 L .29527 .36617 L .663 .741 .908 r
F
.28975 .36811 m .28617 .36452 L .29169 .36258 L F
.82628 .36811 m .82983 .36257 L .83237 .36617 L .664 .741 .908 r
F
.82628 .36811 m .82374 .36452 L .82983 .36257 L F
.47311 .5106 m .46992 .50328 L .47627 .46218 L .923 .693 .573 r
F
.46992 .50328 m .47291 .46735 L .47627 .46218 L .877 .664 .61 r
F
.20762 .36795 m .20932 .36242 L .21306 .36602 L .663 .741 .908 r
F
.20762 .36795 m .20388 .36437 L .20932 .36242 L F
.7442 .36796 m .74751 .36244 L .7502 .36602 L .663 .742 .908 r
F
.7442 .36796 m .7415 .36438 L .74751 .36244 L F
.84098 .36781 m .84457 .36228 L .84708 .36586 L .663 .741 .908 r
F
.84098 .36781 m .83846 .36422 L .84457 .36228 L F
.30436 .36782 m .30635 .36228 L .30989 .36587 L .664 .742 .908 r
F
.30436 .36782 m .3008 .36423 L .30635 .36228 L F
.48061 .56317 m .47738 .56035 L .48347 .53175 L .945 .74 .595 r
F
.48347 .53175 m .48029 .52624 L .48609 .51795 L .82 .7 .731 r
F
.47738 .56035 m .48029 .52624 L .48347 .53175 L .939 .729 .592 r
F
.22222 .36766 m .22396 .36212 L .22767 .36571 L .664 .741 .908 r
F
.22222 .36766 m .2185 .36407 L .22396 .36212 L F
.75888 .36766 m .76223 .36212 L .7649 .36571 L F
.75888 .36766 m .75621 .36408 L .76223 .36212 L F
.43422 .47703 m .43115 .46459 L .43366 .58216 L .975 .691 .42 r
F
.43115 .46459 m .42995 .58803 L .43366 .58216 L .973 .691 .43 r
F
.42627 .59174 m .434 .40071 L .43692 .41783 L .961 .702 .497 r
F
.42627 .59174 m .42266 .59207 L .434 .40071 L F
.31897 .36751 m .321 .36197 L .32452 .36557 L .664 .741 .908 r
F
.31897 .36751 m .31544 .36392 L .321 .36197 L F
.85568 .36751 m .85931 .36197 L .86179 .36556 L .664 .742 .908 r
F
.85568 .36751 m .85319 .36392 L .85931 .36197 L F
.77357 .36735 m .77696 .36182 L .7796 .36542 L .663 .741 .908 r
F
.77357 .36735 m .77092 .36377 L .77696 .36182 L F
.23682 .36736 m .23861 .36182 L .24229 .36542 L F
.23682 .36736 m .23313 .36377 L .23861 .36182 L F
.53966 .4054 m .54238 .40445 L .5455 .41302 L 0 0 0 r
F
.53966 .4054 m .53659 .40943 L .54238 .40445 L F
.33359 .36721 m .33566 .36169 L .33916 .36528 L .663 .741 .908 r
F
.33359 .36721 m .33009 .36363 L .33566 .36169 L F
.87038 .36721 m .87406 .36167 L .87651 .36528 L .664 .741 .908 r
F
.87038 .36721 m .86792 .36363 L .87406 .36167 L F
.69145 .36722 m .6946 .3617 L .69739 .36528 L .662 .74 .908 r
F
.69145 .36722 m .68864 .36363 L .6946 .3617 L F
.25142 .36706 m .25326 .36153 L .25691 .36512 L .663 .741 .908 r
F
.25142 .36706 m .24777 .36348 L .25326 .36153 L F
.78826 .36706 m .7917 .36152 L .79431 .36512 L .664 .741 .908 r
F
.78826 .36706 m .78564 .36348 L .7917 .36152 L F
.48029 .52624 m .48286 .51725 L .48609 .51795 L .718 .669 .801 r
F
.16925 .36691 m .17083 .36137 L .17465 .36497 L .664 .741 .908 r
F
.16925 .36691 m .16543 .36332 L .17083 .36137 L F
.88509 .36691 m .88882 .36138 L .89124 .36497 L .663 .741 .908 r
F
.88509 .36691 m .88266 .36332 L .88882 .36138 L F
.70613 .36693 m .70932 .36139 L .71209 .36498 L .663 .74 .907 r
F
.70613 .36693 m .70335 .36333 L .70932 .36139 L F
.63022 .3861 m .63499 .43395 L .63777 .43226 L .966 .64 .292 r
F
.68262 .50555 m .67965 .50111 L .67995 .37842 L .972 .7 .455 r
F
.67995 .37842 m .67711 .3745 L .68271 .36564 L .875 .771 .743 r
F
.45915 .43998 m .46279 .37561 L .46587 .38773 L .988 .753 .49 r
F
.46272 .42935 m .46587 .38773 L .46885 .40553 L .999 .794 .459 r
F
.46272 .42935 m .45915 .43998 L .46587 .38773 L F
.46625 .41816 m .46885 .40553 L .47183 .42519 L .839 .804 .313 r
F
.46625 .41816 m .46272 .42935 L .46885 .40553 L F
.46587 .38773 m .46279 .37561 L .46755 .42735 L .972 .669 .29 r
F
.45915 .43998 m .45563 .44674 L .4608 .39533 L .988 .753 .49 r
F
.46152 .39748 m .4608 .39533 L .46268 .3767 L F
.45915 .43998 m .4608 .39533 L .46152 .39748 L F
.45915 .43998 m .46268 .3767 L .46273 .3767 L F
.45563 .44674 m .45954 .37217 L .46279 .37561 L .967 .722 .515 r
F
.45563 .44674 m .45223 .44644 L .45954 .37217 L F
.45647 .38231 m .45774 .41047 L .46083 .42589 L .771 .453 .449 r
F
.45606 .3783 m .45624 .38163 L .45647 .38231 L F
.45624 .38163 m .45774 .41047 L .45647 .38231 L F
.45988 .3766 m .46083 .42589 L .46411 .43137 L .912 .6 .441 r
F
.45954 .37217 m .45964 .37659 L .45988 .3766 L F
.45964 .37659 m .46083 .42589 L .45988 .3766 L F
.46273 .3767 m .46268 .3767 L .46279 .37561 L .988 .753 .49 r
F
.46288 .47114 m .45966 .46434 L .46625 .41816 L .931 .697 .562 r
F
.46279 .37561 m .46411 .43137 L .46755 .42735 L .961 .653 .397 r
F
.46279 .37561 m .45954 .37217 L .46411 .43137 L F
.56899 .40591 m .56585 .39473 L .5717 .39553 L .534 .456 .715 r
F
.56353 .437 m .56585 .39473 L .56899 .40591 L .96 .732 .548 r
F
.56585 .39473 m .56876 .39988 L .5717 .39553 L 0 0 .393 r
F
.56585 .39473 m .56274 .3861 L .56876 .39988 L F
.56045 .4339 m .56274 .3861 L .56585 .39473 L .957 .723 .541 r
F
.26603 .36676 m .26791 .36122 L .27153 .36482 L .664 .741 .908 r
F
.26603 .36676 m .2624 .36317 L .26791 .36122 L F
.80296 .36677 m .80644 .36122 L .80902 .36482 L .664 .741 .907 r
F
.80296 .36677 m .80037 .36317 L .80644 .36122 L F
.18385 .36661 m .18548 .36107 L .18926 .36467 L .664 .741 .908 r
F
.18385 .36661 m .18006 .36302 L .18548 .36107 L F
.8998 .36662 m .90358 .36107 L .90597 .36467 L F
.8998 .36662 m .8974 .36303 L .90358 .36107 L F
.72081 .36662 m .72405 .36107 L .72679 .36467 L F
.72081 .36662 m .71806 .36303 L .72405 .36107 L F
.28065 .36646 m .28257 .36092 L .28617 .36452 L .663 .741 .908 r
F
.28065 .36646 m .27705 .36287 L .28257 .36092 L F
.81766 .36646 m .82119 .36092 L .82374 .36452 L .664 .741 .908 r
F
.81766 .36646 m .8151 .36287 L .82119 .36092 L F
.56962 .44138 m .57213 .4172 L .57522 .42462 L .97 .784 .596 r
F
.19845 .36631 m .20012 .36077 L .20388 .36437 L .664 .741 .908 r
F
.19845 .36631 m .19469 .36272 L .20012 .36077 L F
.7355 .36632 m .73879 .36078 L .7415 .36438 L .663 .741 .908 r
F
.7355 .36632 m .73278 .36272 L .73879 .36078 L F
.83237 .36617 m .83594 .36062 L .83846 .36422 L F
.83237 .36617 m .82983 .36257 L .83594 .36062 L F
.29527 .36617 m .29723 .36063 L .3008 .36423 L F
.29527 .36617 m .29169 .36258 L .29723 .36063 L F
.56045 .4339 m .55736 .43012 L .56274 .3861 L .957 .723 .541 r
F
.56274 .3861 m .56582 .40585 L .56876 .39988 L .933 .572 .159 r
F
.55736 .43012 m .55966 .38034 L .56274 .3861 L .933 .696 .557 r
F
.56274 .3861 m .55966 .38034 L .56582 .40585 L .933 .572 .159 r
F
.21306 .36602 m .21477 .36048 L .2185 .36407 L .663 .741 .908 r
F
.21306 .36602 m .20932 .36242 L .21477 .36048 L F
.7502 .36602 m .75352 .36048 L .75621 .36408 L .664 .742 .908 r
F
.7502 .36602 m .74751 .36244 L .75352 .36048 L F
.56659 .44015 m .56899 .40591 L .57213 .4172 L .956 .74 .571 r
F
.56659 .44015 m .56353 .437 L .56899 .40591 L F
.60751 .42098 m .60465 .42241 L .60985 .39372 L .995 .801 .534 r
F
.60985 .39372 m .60697 .39389 L .61279 .38976 L .727 .987 .885 r
F
.60465 .42241 m .60697 .39389 L .60985 .39372 L .998 .803 .515 r
F
.84708 .36586 m .85069 .36033 L .85319 .36392 L .663 .742 .908 r
F
.84708 .36586 m .84457 .36228 L .85069 .36033 L F
.30989 .36587 m .3119 .36032 L .31544 .36392 L .664 .741 .908 r
F
.30989 .36587 m .30635 .36228 L .3119 .36032 L F
.22767 .36571 m .22943 .36017 L .23313 .36377 L F
.22767 .36571 m .22396 .36212 L .22943 .36017 L F
.7649 .36571 m .76827 .36017 L .77092 .36377 L .664 .742 .908 r
F
.7649 .36571 m .76223 .36212 L .76827 .36017 L F
.86179 .36556 m .86545 .36002 L .86792 .36363 L .663 .741 .908 r
F
.86179 .36556 m .85931 .36197 L .86545 .36002 L F
.32452 .36557 m .32657 .36003 L .33009 .36363 L F
.32452 .36557 m .321 .36197 L .32657 .36003 L F
.68271 .36564 m .68583 .36002 L .68864 .36363 L .666 .74 .905 r
F
.68271 .36564 m .67988 .36202 L .68583 .36002 L F
.67711 .3745 m .67988 .36202 L .68271 .36564 L .879 .78 .748 r
F
.47183 .42519 m .46885 .40553 L .47455 .40601 L .546 .404 .639 r
F
.46885 .40553 m .47106 .41734 L .47455 .40601 L 0 0 .147 r
F
.46885 .40553 m .46587 .38773 L .47106 .41734 L F
.46587 .38773 m .46755 .42735 L .47106 .41734 L .972 .669 .29 r
F
.24229 .36542 m .24409 .35988 L .24777 .36348 L .663 .741 .908 r
F
.24229 .36542 m .23861 .36182 L .24409 .35988 L F
.7796 .36542 m .78302 .35987 L .78564 .36348 L F
.7796 .36542 m .77696 .36182 L .78302 .35987 L F
.47738 .56035 m .47414 .55673 L .48029 .52624 L .939 .729 .592 r
F
.48029 .52624 m .4771 .52078 L .48286 .51725 L .718 .669 .801 r
F
.47414 .55673 m .4771 .52078 L .48029 .52624 L .944 .73 .584 r
F
.87651 .36528 m .88022 .35973 L .88266 .36332 L .663 .741 .908 r
F
.87651 .36528 m .87406 .36167 L .88022 .35973 L F
.33916 .36528 m .33566 .36169 L .34125 .35973 L F
.69739 .36528 m .70056 .35973 L .70335 .36333 L .664 .742 .908 r
F
.69739 .36528 m .6946 .3617 L .70056 .35973 L F
.60772 .43503 m .60481 .43411 L .61039 .42081 L .964 .849 .678 r
F
.25691 .36512 m .25876 .35957 L .2624 .36317 L .664 .742 .908 r
F
.25691 .36512 m .25326 .36153 L .25876 .35957 L F
.79431 .36512 m .79777 .35957 L .80037 .36317 L .664 .741 .908 r
F
.79431 .36512 m .7917 .36152 L .79777 .35957 L F
.56962 .44138 m .56659 .44015 L .57213 .4172 L .97 .784 .596 r
F
.17465 .36497 m .17625 .35942 L .18006 .36302 L .664 .741 .908 r
F
.17465 .36497 m .17083 .36137 L .17625 .35942 L F
.89124 .36497 m .89499 .35942 L .8974 .36303 L .664 .742 .908 r
F
.89124 .36497 m .88882 .36138 L .89499 .35942 L F
.71209 .36498 m .7153 .35942 L .71806 .36303 L .664 .741 .908 r
F
.71209 .36498 m .70932 .36139 L .7153 .35942 L F
.27153 .36482 m .27343 .35926 L .27705 .36287 L F
.27153 .36482 m .26791 .36122 L .27343 .35926 L F
.80902 .36482 m .81253 .35927 L .8151 .36287 L F
.80902 .36482 m .80644 .36122 L .81253 .35927 L F
.62722 .37996 m .63218 .43526 L .63499 .43395 L .968 .645 .319 r
F
.62325 .44522 m .62423 .37475 L .62722 .37996 L .976 .723 .485 r
F
.62722 .37996 m .62423 .37475 L .63218 .43526 L .968 .645 .319 r
F
.51082 .43621 m .51341 .43507 L .51659 .4326 L 0 0 0 r
F
.51082 .43621 m .50763 .43762 L .51341 .43507 L F
.60481 .43411 m .60751 .42098 L .61039 .42081 L .958 .857 .698 r
F
.18926 .36467 m .19091 .35912 L .19469 .36272 L .663 .741 .908 r
F
.18926 .36467 m .18548 .36107 L .19091 .35912 L F
.72679 .36467 m .73005 .35912 L .73278 .36272 L F
.72679 .36467 m .72405 .36107 L .73005 .35912 L F
.82374 .36452 m .82729 .35897 L .82983 .36257 L F
.82374 .36452 m .82119 .36092 L .82729 .35897 L F
.28617 .36452 m .2881 .35897 L .29169 .36258 L F
.28617 .36452 m .28257 .36092 L .2881 .35897 L F
.54861 .41943 m .5455 .41302 L .55123 .39959 L .863 .696 .673 r
F
.55123 .39959 m .55422 .42263 L .55736 .43012 L .889 .525 .345 r
F
.5455 .41302 m .54819 .40228 L .55123 .39959 L .639 .558 .747 r
F
.55123 .39959 m .54819 .40228 L .55422 .42263 L .889 .525 .345 r
F
.20388 .36437 m .20557 .35882 L .20932 .36242 L .664 .741 .908 r
F
.20388 .36437 m .20012 .36077 L .20557 .35882 L F
.7415 .36438 m .7448 .35883 L .74751 .36244 L .663 .741 .908 r
F
.7415 .36438 m .73879 .36078 L .7448 .35883 L F
.83846 .36422 m .84206 .35868 L .84457 .36228 L F
.83846 .36422 m .83594 .36062 L .84206 .35868 L F
.3008 .36423 m .30278 .35867 L .30635 .36228 L .664 .741 .908 r
F
.3008 .36423 m .29723 .36063 L .30278 .35867 L F
.2185 .36407 m .22024 .35851 L .22396 .36212 L F
.2185 .36407 m .21477 .36048 L .22024 .35851 L F
.75621 .36408 m .75956 .35852 L .76223 .36212 L F
.75621 .36408 m .75352 .36048 L .75956 .35852 L F
.50191 .43303 m .50444 .43681 L .50763 .43762 L .334 0 .104 r
F
.50191 .43303 m .49866 .43852 L .50444 .43681 L F
.31544 .36392 m .31747 .35836 L .321 .36197 L .664 .741 .908 r
F
.31544 .36392 m .3119 .36032 L .31747 .35836 L F
.85319 .36392 m .85683 .35836 L .85931 .36197 L .664 .742 .908 r
F
.85319 .36392 m .85069 .36033 L .85683 .35836 L F
.46139 .47508 m .45836 .46048 L .46366 .48078 L 0 0 .311 r
F
.45478 .52016 m .45836 .46048 L .46139 .47508 L .897 .66 .573 r
F
.45478 .52016 m .45167 .50746 L .45836 .46048 L F
.55736 .43012 m .55422 .42263 L .55966 .38034 L .933 .696 .557 r
F
.55966 .38034 m .56285 .41165 L .56582 .40585 L .951 .606 .311 r
F
.55422 .42263 m .5566 .37796 L .55966 .38034 L .876 .647 .588 r
F
.55966 .38034 m .5566 .37796 L .56285 .41165 L .951 .606 .311 r
F
.77092 .36377 m .77432 .35821 L .77696 .36182 L .663 .741 .908 r
F
.77092 .36377 m .76827 .36017 L .77432 .35821 L F
.23313 .36377 m .23491 .35821 L .23861 .36182 L F
.23313 .36377 m .22943 .36017 L .23491 .35821 L F
.51659 .4326 m .51341 .43507 L .51923 .41794 L .992 .883 .599 r
F
.86792 .36363 m .87161 .35807 L .87406 .36167 L .663 .741 .908 r
F
.86792 .36363 m .86545 .36002 L .87161 .35807 L F
.68864 .36363 m .69179 .35808 L .6946 .3617 L .662 .741 .908 r
F
.68864 .36363 m .68583 .36002 L .69179 .35808 L F
.33009 .36363 m .33216 .35808 L .33566 .36169 L .663 .741 .908 r
F
.33009 .36363 m .32657 .36003 L .33216 .35808 L F
.51341 .43507 m .51606 .42303 L .51923 .41794 L .967 .885 .697 r
F
.78564 .36348 m .78908 .35792 L .7917 .36152 L .663 .741 .908 r
F
.78564 .36348 m .78302 .35987 L .78908 .35792 L F
.24777 .36348 m .24959 .35792 L .25326 .36153 L F
.24777 .36348 m .24409 .35988 L .24959 .35792 L F
.67965 .50111 m .6767 .49712 L .67711 .3745 L .973 .701 .453 r
F
.67711 .3745 m .67426 .37079 L .67988 .36202 L .879 .78 .748 r
F
.6767 .49712 m .67426 .37079 L .67711 .3745 L .971 .699 .457 r
F
.59889 .43359 m .60188 .4331 L .60481 .43411 L .106 .639 .864 r
F
.59889 .43359 m .59596 .43272 L .60188 .4331 L F
.4373 .48943 m .43422 .47703 L .43737 .57498 L .977 .69 .405 r
F
.43422 .47703 m .43366 .58216 L .43737 .57498 L .975 .691 .42 r
F
.42995 .58803 m .43692 .41783 L .43981 .4367 L .966 .709 .494 r
F
.42995 .58803 m .42627 .59174 L .43692 .41783 L F
.88266 .36332 m .88639 .35777 L .88882 .36138 L .664 .742 .908 r
F
.88266 .36332 m .88022 .35973 L .88639 .35777 L F
.16543 .36332 m .16701 .35776 L .17083 .36137 L .664 .741 .908 r
F
.16543 .36332 m .1616 .35972 L .16701 .35776 L F
.70335 .36333 m .70654 .35777 L .70932 .36139 L .664 .742 .908 r
F
.70335 .36333 m .70056 .35973 L .70654 .35777 L F
.5717 .39553 m .57517 .43404 L .57815 .43164 L .911 .575 .395 r
F
.5717 .39553 m .56876 .39988 L .57517 .43404 L F
.45927 .56264 m .4561 .5534 L .46243 .52098 L .894 .673 .597 r
F
.46243 .52098 m .46436 .54577 L .46762 .55028 L .838 .499 .413 r
F
.4561 .5534 m .45898 .52724 L .46243 .52098 L .843 .654 .647 r
F
.46243 .52098 m .45898 .52724 L .46436 .54577 L .838 .499 .413 r
F
.2624 .36317 m .26427 .35761 L .26791 .36122 L .664 .741 .908 r
F
.2624 .36317 m .25876 .35957 L .26427 .35761 L F
.80037 .36317 m .80385 .35761 L .80644 .36122 L .663 .741 .908 r
F
.80037 .36317 m .79777 .35957 L .80385 .35761 L F
.45954 .37217 m .45606 .3783 L .46083 .42589 L .912 .6 .441 r
F
.18006 .36302 m .18168 .35746 L .18548 .36107 L .664 .741 .908 r
F
.18006 .36302 m .17625 .35942 L .18168 .35746 L F
.8974 .36303 m .90117 .35746 L .90358 .36107 L F
.8974 .36303 m .89499 .35942 L .90117 .35746 L F
.71806 .36303 m .7213 .35746 L .72405 .36107 L F
.71806 .36303 m .7153 .35942 L .7213 .35746 L F
.47414 .55673 m .47089 .55345 L .4771 .52078 L .944 .73 .584 r
F
.4771 .52078 m .47959 .51727 L .48286 .51725 L .384 .518 .869 r
F
.4771 .52078 m .4739 .51551 L .47959 .51727 L F
.47089 .55345 m .4739 .51551 L .4771 .52078 L .946 .729 .579 r
F
.27705 .36287 m .27896 .35731 L .28257 .36092 L .663 .741 .908 r
F
.27705 .36287 m .27343 .35926 L .27896 .35731 L F
.8151 .36287 m .81862 .35731 L .82119 .36092 L F
.8151 .36287 m .81253 .35927 L .81862 .35731 L F
.19469 .36272 m .19635 .35716 L .20012 .36077 L F
.19469 .36272 m .19091 .35912 L .19635 .35716 L F
.73278 .36272 m .73606 .35716 L .73879 .36078 L .664 .741 .908 r
F
.73278 .36272 m .73005 .35912 L .73606 .35716 L F
.82983 .36257 m .8334 .35702 L .83594 .36062 L .663 .741 .908 r
F
.82983 .36257 m .82729 .35897 L .8334 .35702 L F
.29169 .36258 m .29365 .35702 L .29723 .36063 L F
.29169 .36258 m .2881 .35897 L .29365 .35702 L F
.20932 .36242 m .21103 .35686 L .21477 .36048 L F
.20932 .36242 m .20557 .35882 L .21103 .35686 L F
.74751 .36244 m .75083 .35686 L .75352 .36048 L .664 .742 .908 r
F
.74751 .36244 m .7448 .35883 L .75083 .35686 L F
.30635 .36228 m .30835 .35671 L .3119 .36032 L .664 .741 .908 r
F
.30635 .36228 m .30278 .35867 L .30835 .35671 L F
.84457 .36228 m .84819 .35671 L .85069 .36033 L .664 .742 .908 r
F
.84457 .36228 m .84206 .35868 L .84819 .35671 L F
.61893 .40468 m .61586 .39715 L .6226 .44101 L .962 .635 .257 r
F
.62284 .44142 m .6226 .44101 L .62324 .44517 L F
.61893 .40468 m .6226 .44101 L .62284 .44142 L F
.61586 .39715 m .62032 .44386 L .62325 .44522 L .967 .644 .282 r
F
.61586 .39715 m .61279 .38976 L .61871 .43235 L F
.61927 .43294 m .61871 .43235 L .62032 .44386 L F
.61586 .39715 m .61871 .43235 L .61927 .43294 L F
.60697 .39389 m .60973 .38255 L .61279 .38976 L .975 .923 .625 r
F
.61279 .38976 m .6173 .44022 L .62032 .44386 L .968 .647 .296 r
F
.61279 .38976 m .60973 .38255 L .61449 .41883 L F
.61539 .41887 m .61449 .41883 L .6173 .44022 L F
.61279 .38976 m .61449 .41883 L .61539 .41887 L F
.60697 .39389 m .60413 .39569 L .60971 .38258 L .975 .923 .625 r
F
.60972 .38258 m .60971 .38258 L .60973 .38255 L F
.60697 .39389 m .60971 .38258 L .60972 .38258 L F
.60413 .39569 m .60667 .37599 L .60973 .38255 L .996 .85 .509 r
F
.60754 .38277 m .61111 .42817 L .61423 .43497 L .967 .644 .321 r
F
.60667 .37599 m .60725 .3828 L .60754 .38277 L F
.60725 .3828 m .61111 .42817 L .60754 .38277 L F
.60973 .38255 m .61423 .43497 L .6173 .44022 L .969 .648 .307 r
F
.60973 .38255 m .60667 .37599 L .61423 .43497 L F
.60465 .42241 m .60179 .42479 L .60697 .39389 L .998 .803 .515 r
F
.60179 .42479 m .60413 .39569 L .60697 .39389 L .998 .801 .514 r
F
.60413 .39569 m .6013 .39935 L .60541 .38146 L .996 .85 .509 r
F
.60413 .39569 m .60541 .38146 L .60582 .38184 L F
.60413 .39569 m .6064 .37719 L .60652 .3772 L F
.6013 .39935 m .60365 .37096 L .60667 .37599 L .998 .813 .465 r
F
.60179 .42479 m .59892 .42719 L .60413 .39569 L .998 .801 .514 r
F
.59892 .42719 m .6013 .39935 L .60413 .39569 L .995 .801 .532 r
F
.6013 .39935 m .59848 .40451 L .60153 .38474 L .998 .813 .465 r
F
.60228 .38749 m .60153 .38474 L .60365 .37096 L F
.6013 .39935 m .60153 .38474 L .60228 .38749 L F
.59848 .40451 m .60067 .36836 L .60365 .37096 L .999 .792 .456 r
F
.59848 .40451 m .59817 .40513 L .60067 .36836 L F
.59817 .40513 m .59565 .41009 L .59737 .39579 L F
.59817 .40513 m .59737 .39579 L .60067 .36836 L F
.59565 .41009 m .59776 .36892 L .60067 .36836 L .997 .778 .47 r
F
.59565 .41009 m .59276 .41444 L .59776 .36892 L F
.59276 .41444 m .5949 .37288 L .59776 .36892 L .989 .764 .503 r
F
.59776 .36892 m .5949 .37288 L .6011 .38987 L .862 .487 .334 r
F
.60125 .39006 m .6011 .38987 L .60131 .39045 L F
.59776 .36892 m .6011 .38987 L .60125 .39006 L F
.59557 .37473 m .59794 .37311 L .60131 .39045 L 0 0 .016 r
F
.5949 .37288 m .59542 .37292 L .59557 .37473 L F
.59542 .37292 m .59794 .37311 L .59557 .37473 L F
.59276 .41444 m .58978 .41566 L .5949 .37288 L .989 .764 .503 r
F
.58978 .41566 m .59207 .37975 L .5949 .37288 L .959 .738 .562 r
F
.5949 .37288 m .59207 .37975 L .59794 .37311 L 0 0 .016 r
F
.59277 .37896 m .59461 .35663 L .59794 .37311 L .963 .82 .391 r
F
.59207 .37975 m .59224 .37826 L .59277 .37896 L F
.59224 .37826 m .59461 .35663 L .59277 .37896 L F
.59893 .37524 m .60131 .39045 L .60465 .40622 L .862 .487 .334 r
F
.59776 .36892 m .59861 .37409 L .59893 .37524 L F
.59861 .37409 m .60131 .39045 L .59893 .37524 L F
.60212 .37843 m .60465 .40622 L .60792 .41887 L .941 .598 .345 r
F
.60067 .36836 m .60169 .37803 L .60212 .37843 L F
.60169 .37803 m .60465 .40622 L .60212 .37843 L F
.60582 .38184 m .60541 .38146 L .6064 .37719 L .996 .85 .509 r
F
.60652 .3772 m .6064 .37719 L .60667 .37599 L F
.60444 .37704 m .60792 .41887 L .61111 .42817 L .96 .631 .335 r
F
.60365 .37096 m .60419 .37702 L .60444 .37704 L F
.60419 .37702 m .60792 .41887 L .60444 .37704 L F
.60667 .37599 m .60365 .37096 L .61111 .42817 L .967 .644 .321 r
F
.60795 .41857 m .60991 .37613 L .61266 .37041 L .877 .648 .588 r
F
.60792 .41887 m .60794 .41857 L .60795 .41857 L F
.60794 .41857 m .60991 .37613 L .60795 .41857 L F
.61137 .42456 m .61266 .37041 L .61547 .36779 L .934 .687 .541 r
F
.61111 .42817 m .61122 .42439 L .61137 .42456 L F
.61122 .42439 m .61266 .37041 L .61137 .42456 L F
.61469 .42759 m .61547 .36779 L .61835 .36807 L .954 .701 .516 r
F
.61423 .43497 m .61438 .42706 L .61469 .42759 L F
.61438 .42706 m .61547 .36779 L .61469 .42759 L F
.61893 .40468 m .62324 .44517 L .62325 .44517 L .962 .635 .257 r
F
.61765 .43414 m .61835 .36807 L .62127 .37063 L .962 .707 .503 r
F
.6173 .44022 m .6174 .43364 L .61765 .43414 L F
.6174 .43364 m .61835 .36807 L .61765 .43414 L F
.62325 .44517 m .62324 .44517 L .62325 .44522 L .962 .635 .257 r
F
.62325 .44522 m .62032 .44386 L .62423 .37475 L .976 .723 .485 r
F
.62423 .37475 m .62935 .43666 L .63218 .43526 L .967 .647 .339 r
F
.62032 .44386 m .62127 .37063 L .62423 .37475 L .969 .713 .494 r
F
.62423 .37475 m .62127 .37063 L .62935 .43666 L .967 .647 .339 r
F
.22396 .36212 m .22572 .35655 L .22943 .36017 L .664 .741 .908 r
F
.22396 .36212 m .22024 .35851 L .22572 .35655 L F
.76223 .36212 m .7656 .35655 L .76827 .36017 L F
.76223 .36212 m .75956 .35852 L .7656 .35655 L F
.85931 .36197 m .86298 .35641 L .86545 .36002 L .663 .741 .908 r
F
.85931 .36197 m .85683 .35836 L .86298 .35641 L F
.321 .36197 m .32305 .35641 L .32657 .36003 L F
.321 .36197 m .31747 .35836 L .32305 .35641 L F
.67988 .36202 m .683 .35641 L .68583 .36002 L .666 .742 .907 r
F
.67988 .36202 m .67704 .35841 L .683 .35641 L F
.67426 .37079 m .67704 .35841 L .67988 .36202 L .879 .782 .75 r
F
.77696 .36182 m .78038 .35626 L .78302 .35987 L .663 .741 .908 r
F
.77696 .36182 m .77432 .35821 L .78038 .35626 L F
.23861 .36182 m .2404 .35626 L .24409 .35988 L F
.23861 .36182 m .23491 .35821 L .2404 .35626 L F
.87406 .36167 m .87777 .35611 L .88022 .35973 L F
.87406 .36167 m .87161 .35807 L .87777 .35611 L F
.33566 .36169 m .33775 .35612 L .34125 .35973 L F
.33566 .36169 m .33216 .35808 L .33775 .35612 L F
.6946 .3617 m .69777 .35614 L .70056 .35973 L .663 .74 .908 r
F
.6946 .3617 m .69179 .35808 L .69777 .35614 L F
.7917 .36152 m .79516 .35596 L .79777 .35957 L .664 .742 .908 r
F
.7917 .36152 m .78908 .35792 L .79516 .35596 L F
.25326 .36153 m .2551 .35595 L .25876 .35957 L F
.25326 .36153 m .24959 .35792 L .2551 .35595 L F
.17083 .36137 m .17243 .3558 L .17625 .35942 L .664 .741 .908 r
F
.17083 .36137 m .16701 .35776 L .17243 .3558 L F
.88882 .36138 m .89257 .3558 L .89499 .35942 L F
.88882 .36138 m .88639 .35777 L .89257 .3558 L F
.70932 .36139 m .71253 .35581 L .7153 .35942 L F
.70932 .36139 m .70654 .35777 L .71253 .35581 L F
.26791 .36122 m .2698 .35565 L .27343 .35926 L F
.26791 .36122 m .26427 .35761 L .2698 .35565 L F
.80644 .36122 m .80994 .35565 L .81253 .35927 L F
.80644 .36122 m .80385 .35761 L .80994 .35565 L F
.46446 .48823 m .46139 .47508 L .46676 .49354 L 0 0 .325 r
F
.45898 .52724 m .45551 .53357 L .46113 .53919 L .686 .311 .33 r
F
.45793 .53063 m .46139 .47508 L .46446 .48823 L .907 .672 .573 r
F
.45793 .53063 m .45478 .52016 L .46139 .47508 L F
.46139 .47508 m .46366 .48078 L .46676 .49354 L 0 0 .311 r
F
.18548 .36107 m .18712 .3555 L .19091 .35912 L .663 .741 .908 r
F
.18548 .36107 m .18168 .35746 L .18712 .3555 L F
.72405 .36107 m .72731 .3555 L .73005 .35912 L F
.72405 .36107 m .7213 .35746 L .72731 .3555 L F
.82119 .36092 m .82474 .35536 L .82729 .35897 L F
.82119 .36092 m .81862 .35731 L .82474 .35536 L F
.28257 .36092 m .2845 .35535 L .2881 .35897 L F
.28257 .36092 m .27896 .35731 L .2845 .35535 L F
.20012 .36077 m .20181 .3552 L .20557 .35882 L .664 .741 .908 r
F
.20012 .36077 m .19635 .35716 L .20181 .3552 L F
.73879 .36078 m .74209 .3552 L .7448 .35883 L .663 .741 .908 r
F
.73879 .36078 m .73606 .35716 L .74209 .3552 L F
.83594 .36062 m .83953 .35505 L .84206 .35868 L .664 .742 .908 r
F
.83594 .36062 m .8334 .35702 L .83953 .35505 L F
.29723 .36063 m .29921 .35505 L .30278 .35867 L .664 .741 .908 r
F
.29723 .36063 m .29365 .35702 L .29921 .35505 L F
.65204 .44066 m .64916 .43761 L .65704 .48457 L .96 .625 .31 r
F
.21477 .36048 m .2165 .35489 L .22024 .35851 L .664 .741 .908 r
F
.21477 .36048 m .21103 .35686 L .2165 .35489 L F
.75352 .36048 m .75687 .35489 L .75956 .35852 L .664 .742 .908 r
F
.75352 .36048 m .75083 .35686 L .75687 .35489 L F
.4739 .51551 m .47634 .51539 L .47959 .51727 L 0 .15 .688 r
F
.4739 .51551 m .47072 .5088 L .47634 .51539 L F
.46762 .55028 m .47072 .5088 L .4739 .51551 L .937 .716 .577 r
F
.3119 .36032 m .31392 .35474 L .31747 .35836 L .664 .741 .908 r
F
.3119 .36032 m .30835 .35671 L .31392 .35474 L F
.85069 .36033 m .85433 .35474 L .85683 .35836 L F
.85069 .36033 m .84819 .35671 L .85433 .35474 L F
.76827 .36017 m .77166 .35459 L .77432 .35821 L .663 .741 .908 r
F
.76827 .36017 m .7656 .35655 L .77166 .35459 L F
.22943 .36017 m .2312 .35459 L .23491 .35821 L F
.22943 .36017 m .22572 .35655 L .2312 .35459 L F
.60481 .43411 m .60188 .4331 L .60751 .42098 L .958 .857 .698 r
F
.48981 .4257 m .49215 .44135 L .4954 .44207 L .69 .338 .374 r
F
.48981 .4257 m .48645 .43442 L .49215 .44135 L F
.86545 .36002 m .86914 .35445 L .87161 .35807 L .663 .741 .908 r
F
.86545 .36002 m .86298 .35641 L .86914 .35445 L F
.68583 .36002 m .68897 .35444 L .69179 .35808 L .664 .742 .908 r
F
.68583 .36002 m .683 .35641 L .68897 .35444 L F
.32657 .36003 m .32864 .35445 L .33216 .35808 L .663 .741 .908 r
F
.32657 .36003 m .32305 .35641 L .32864 .35445 L F
.6767 .49712 m .67368 .49209 L .67426 .37079 L .971 .699 .457 r
F
.67426 .37079 m .67141 .36711 L .67704 .35841 L .879 .782 .75 r
F
.67368 .49209 m .67141 .36711 L .67426 .37079 L .967 .695 .465 r
F
.78302 .35987 m .78645 .3543 L .78908 .35792 L .663 .741 .908 r
F
.78302 .35987 m .78038 .35626 L .78645 .3543 L F
.24409 .35988 m .24591 .3543 L .24959 .35792 L F
.24409 .35988 m .2404 .35626 L .24591 .3543 L F
.5455 .41302 m .54238 .40445 L .54774 .40244 L .639 .558 .747 r
F
.53659 .40943 m .53924 .39518 L .54238 .40445 L .984 .89 .549 r
F
.54808 .40272 m .54774 .40244 L .54819 .40228 L .639 .558 .747 r
F
.5455 .41302 m .54774 .40244 L .54808 .40272 L F
.54238 .40445 m .54513 .40572 L .54819 .40228 L 0 .005 .572 r
F
.54238 .40445 m .53924 .39518 L .54513 .40572 L F
.53956 .39575 m .54205 .4082 L .54513 .40572 L .845 .499 0 r
F
.53924 .39518 m .53932 .39556 L .53956 .39575 L F
.53932 .39556 m .54205 .4082 L .53956 .39575 L F
.51606 .42303 m .51287 .4266 L .51874 .3996 L .999 .828 .535 r
F
.5207 .39162 m .52054 .39102 L .52139 .38884 L .946 .914 .541 r
F
.51556 .40385 m .51824 .38282 L .52139 .38884 L .997 .846 .513 r
F
.52139 .38884 m .51824 .38282 L .52403 .40292 L .901 .528 .076 r
F
.51992 .38867 m .52087 .39174 L .52403 .40292 L .851 .391 .052 r
F
.51824 .38282 m .5196 .38744 L .51992 .38867 L F
.5196 .38744 m .52087 .39174 L .51992 .38867 L F
.51874 .3996 m .51556 .40385 L .52054 .39102 L .946 .914 .541 r
F
.51874 .3996 m .52054 .39102 L .5207 .39162 L F
.51287 .4266 m .51556 .40385 L .51874 .3996 L .979 .803 .595 r
F
.1616 .35972 m .16317 .35414 L .16701 .35776 L .664 .741 .908 r
F
.1616 .35972 m .15775 .35611 L .16317 .35414 L F
.88022 .35973 m .88395 .35414 L .88639 .35777 L .664 .742 .908 r
F
.88022 .35973 m .87777 .35611 L .88395 .35414 L F
.70056 .35973 m .70375 .35414 L .70654 .35777 L .665 .743 .908 r
F
.70056 .35973 m .69777 .35614 L .70375 .35414 L F
.79777 .35957 m .80125 .35399 L .80385 .35761 L .664 .742 .908 r
F
.79777 .35957 m .79516 .35596 L .80125 .35399 L F
.25876 .35957 m .26062 .35399 L .26427 .35761 L .664 .741 .908 r
F
.25876 .35957 m .2551 .35595 L .26062 .35399 L F
.55422 .42263 m .55103 .40977 L .5566 .37796 L .876 .647 .588 r
F
.5566 .37796 m .55982 .41509 L .56285 .41165 L .928 .59 .375 r
F
.55103 .40977 m .55357 .38 L .5566 .37796 L .75 .555 .633 r
F
.5566 .37796 m .55357 .38 L .55982 .41509 L .928 .59 .375 r
F
.46992 .50328 m .46676 .49354 L .47291 .46735 L .877 .664 .61 r
F
.46676 .49354 m .46954 .47152 L .47291 .46735 L .738 .569 .664 r
F
.17625 .35942 m .17786 .35383 L .18168 .35746 L .664 .741 .908 r
F
.17625 .35942 m .17243 .3558 L .17786 .35383 L F
.89499 .35942 m .89876 .35384 L .90117 .35746 L .663 .741 .908 r
F
.89499 .35942 m .89257 .3558 L .89876 .35384 L F
.7153 .35942 m .71854 .35383 L .7213 .35746 L .664 .741 .908 r
F
.7153 .35942 m .71253 .35581 L .71854 .35383 L F
.5308 .41624 m .53349 .4132 L .53659 .40943 L .203 .293 .735 r
F
.53659 .40943 m .53349 .4132 L .53924 .39518 L .984 .89 .549 r
F
.27343 .35926 m .27533 .35368 L .27896 .35731 L .663 .741 .908 r
F
.27343 .35926 m .2698 .35565 L .27533 .35368 L F
.81253 .35927 m .81605 .35369 L .81862 .35731 L F
.81253 .35927 m .80994 .35565 L .81605 .35369 L F
.46757 .49965 m .46446 .48823 L .46992 .50328 L 0 0 .401 r
F
.45898 .52724 m .46113 .53919 L .46436 .54577 L .686 .311 .33 r
F
.46113 .53919 m .46446 .48823 L .46757 .49965 L .915 .684 .575 r
F
.46113 .53919 m .45793 .53063 L .46446 .48823 L F
.46446 .48823 m .46676 .49354 L .46992 .50328 L 0 0 .325 r
F
.19091 .35912 m .19257 .35353 L .19635 .35716 L .663 .741 .908 r
F
.19091 .35912 m .18712 .3555 L .19257 .35353 L F
.73005 .35912 m .73333 .35354 L .73606 .35716 L .664 .742 .908 r
F
.73005 .35912 m .72731 .3555 L .73333 .35354 L F
.60188 .4331 m .60465 .42241 L .60751 .42098 L .941 .883 .747 r
F
.82729 .35897 m .83086 .35339 L .8334 .35702 L .664 .742 .908 r
F
.82729 .35897 m .82474 .35536 L .83086 .35339 L F
.2881 .35897 m .29005 .35339 L .29365 .35702 L .663 .741 .908 r
F
.2881 .35897 m .2845 .35535 L .29005 .35339 L F
.62032 .44386 m .6173 .44022 L .62127 .37063 L .969 .713 .494 r
F
.62127 .37063 m .6265 .43816 L .62935 .43666 L .965 .646 .357 r
F
.62127 .37063 m .61835 .36807 L .6265 .43816 L F
.20557 .35882 m .20727 .35323 L .21103 .35686 L .663 .741 .908 r
F
.20557 .35882 m .20181 .3552 L .20727 .35323 L F
.7448 .35883 m .74812 .35324 L .75083 .35686 L .664 .741 .907 r
F
.7448 .35883 m .74209 .3552 L .74812 .35324 L F
.53349 .4132 m .53611 .38705 L .53924 .39518 L .988 .799 .562 r
F
.53924 .39518 m .53611 .38705 L .54205 .4082 L .845 .499 0 r
F
.46762 .55028 m .46436 .54577 L .47072 .5088 L .937 .716 .577 r
F
.47072 .5088 m .47311 .5106 L .47634 .51539 L 0 0 .515 r
F
.47072 .5088 m .46757 .49965 L .47311 .5106 L F
.46436 .54577 m .46757 .49965 L .47072 .5088 L .925 .698 .576 r
F
.30278 .35867 m .30478 .35308 L .30835 .35671 L .664 .741 .908 r
F
.30278 .35867 m .29921 .35505 L .30478 .35308 L F
.84206 .35868 m .84567 .35308 L .84819 .35671 L .664 .741 .907 r
F
.84206 .35868 m .83953 .35505 L .84567 .35308 L F
.22024 .35851 m .22199 .35292 L .22572 .35655 L .664 .741 .908 r
F
.22024 .35851 m .2165 .35489 L .22199 .35292 L F
.75956 .35852 m .76292 .35292 L .7656 .35655 L F
.75956 .35852 m .75687 .35489 L .76292 .35292 L F
.5308 .41624 m .52766 .4077 L .53113 .41098 L .203 .293 .735 r
F
.53275 .41403 m .53113 .41098 L .53349 .4132 L F
.5308 .41624 m .53113 .41098 L .53275 .41403 L F
.52766 .4077 m .53036 .41414 L .53349 .4132 L 0 0 .305 r
F
.52527 .39789 m .52671 .38031 L .52985 .37915 L .781 .605 .662 r
F
.52766 .4077 m .52452 .39793 L .52835 .40857 L 0 0 .305 r
F
.52452 .39793 m .52473 .39892 L .52519 .39979 L .829 .497 0 r
F
.52473 .39892 m .5272 .41072 L .52519 .39979 L F
.52452 .39793 m .52139 .38884 L .52605 .40638 L F
.52651 .40744 m .52605 .40638 L .5272 .41072 L F
.52452 .39793 m .52605 .40638 L .52651 .40744 L F
.52139 .38884 m .52403 .40292 L .5272 .41072 L .901 .528 .076 r
F
.52421 .40221 m .52482 .39632 L .52527 .39789 L .781 .605 .662 r
F
.52403 .40292 m .52414 .40205 L .52421 .40221 L F
.52414 .40205 m .52482 .39632 L .52421 .40221 L F
.52482 .39632 m .52671 .38031 L .52527 .39789 L F
.52905 .41098 m .52835 .40857 L .5302 .41371 L 0 0 .305 r
F
.52766 .4077 m .52835 .40857 L .52905 .41098 L F
.53027 .41394 m .5302 .41371 L .53036 .41414 L F
.52766 .4077 m .5302 .41371 L .53027 .41394 L F
.52802 .40659 m .52985 .37915 L .53298 .38143 L .896 .687 .612 r
F
.52519 .39979 m .5272 .41072 L .53036 .41414 L .829 .497 0 r
F
.5272 .41072 m .52765 .40539 L .52802 .40659 L .896 .687 .612 r
F
.52765 .40539 m .52985 .37915 L .52802 .40659 L F
.85683 .35836 m .86049 .35278 L .86298 .35641 L .663 .741 .908 r
F
.85683 .35836 m .85433 .35474 L .86049 .35278 L F
.31747 .35836 m .31951 .35278 L .32305 .35641 L F
.31747 .35836 m .31392 .35474 L .31951 .35278 L F
.46436 .54577 m .46113 .53919 L .46757 .49965 L .925 .698 .576 r
F
.46757 .49965 m .46992 .50328 L .47311 .5106 L 0 0 .401 r
F
.67704 .35841 m .68016 .35279 L .683 .35641 L .667 .744 .908 r
F
.67704 .35841 m .6742 .35481 L .68016 .35279 L F
.67141 .36711 m .6742 .35481 L .67704 .35841 L .865 .768 .754 r
F
.59596 .43272 m .59894 .43207 L .60188 .4331 L .14 .659 .888 r
F
.59596 .43272 m .59301 .43174 L .59894 .43207 L F
.50763 .43762 m .51023 .43521 L .51341 .43507 L .513 .88 .978 r
F
.50763 .43762 m .50444 .43681 L .51023 .43521 L F
.77432 .35821 m .77773 .35263 L .78038 .35626 L .663 .741 .908 r
F
.77432 .35821 m .77166 .35459 L .77773 .35263 L F
.23491 .35821 m .2367 .35263 L .2404 .35626 L F
.23491 .35821 m .2312 .35459 L .2367 .35263 L F
.44039 .50171 m .4373 .48943 L .44107 .5669 L .979 .687 .38 r
F
.4373 .48943 m .43737 .57498 L .44107 .5669 L .977 .69 .405 r
F
.43366 .58216 m .43981 .4367 L .44271 .4561 L .97 .716 .493 r
F
.43366 .58216 m .42995 .58803 L .43981 .4367 L F
.87161 .35807 m .87531 .35247 L .87777 .35611 L .664 .742 .908 r
F
.87161 .35807 m .86914 .35445 L .87531 .35247 L F
.33216 .35808 m .33424 .35248 L .33775 .35612 L .663 .741 .908 r
F
.33216 .35808 m .32864 .35445 L .33424 .35248 L F
.69179 .35808 m .69496 .35251 L .69777 .35614 L .662 .74 .908 r
F
.69179 .35808 m .68897 .35444 L .69496 .35251 L F
.24959 .35792 m .25143 .35232 L .2551 .35595 L .664 .741 .908 r
F
.24959 .35792 m .24591 .3543 L .25143 .35232 L F
.78908 .35792 m .79254 .35233 L .79516 .35596 L F
.78908 .35792 m .78645 .3543 L .79254 .35233 L F
.53349 .4132 m .53036 .41414 L .53505 .39203 L .988 .799 .562 r
F
.53349 .4132 m .53505 .39203 L .53552 .39298 L F
.53036 .41414 m .53298 .38143 L .53611 .38705 L .951 .739 .581 r
F
.53036 .41414 m .5272 .41072 L .53298 .38143 L F
.53095 .38369 m .53259 .39489 L .53577 .40367 L .876 .477 .269 r
F
.52985 .37915 m .53048 .38273 L .53095 .38369 L F
.53048 .38273 m .53259 .39489 L .53095 .38369 L F
.53552 .39298 m .53505 .39203 L .53611 .38705 L .988 .799 .562 r
F
.53611 .38705 m .53892 .40796 L .54205 .4082 L .942 .586 .193 r
F
.53611 .38705 m .53298 .38143 L .53892 .40796 L F
.16701 .35776 m .1686 .35217 L .17243 .3558 L .663 .741 .908 r
F
.16701 .35776 m .16317 .35414 L .1686 .35217 L F
.88639 .35777 m .89014 .35217 L .89257 .3558 L F
.88639 .35777 m .88395 .35414 L .89014 .35217 L F
.70654 .35777 m .70975 .35217 L .71253 .35581 L .664 .741 .908 r
F
.70654 .35777 m .70375 .35414 L .70975 .35217 L F
.26427 .35761 m .26615 .35201 L .2698 .35565 L F
.26427 .35761 m .26062 .35399 L .26615 .35201 L F
.80385 .35761 m .80735 .35202 L .80994 .35565 L .664 .742 .908 r
F
.80385 .35761 m .80125 .35399 L .80735 .35202 L F
.47455 .40601 m .47658 .43314 L .47979 .44075 L .772 .445 .433 r
F
.47455 .40601 m .47106 .41734 L .47658 .43314 L F
.18168 .35746 m .18331 .35186 L .18712 .3555 L .663 .741 .908 r
F
.18168 .35746 m .17786 .35383 L .18331 .35186 L F
.7213 .35746 m .72455 .35187 L .72731 .3555 L F
.7213 .35746 m .71854 .35383 L .72455 .35187 L F
.81862 .35731 m .82217 .35172 L .82474 .35536 L .664 .741 .908 r
F
.81862 .35731 m .81605 .35369 L .82217 .35172 L F
.27896 .35731 m .28088 .35172 L .2845 .35535 L .663 .741 .908 r
F
.27896 .35731 m .27533 .35368 L .28088 .35172 L F
.54819 .40228 m .55103 .40977 L .55422 .42263 L .657 .208 .175 r
F
.54819 .40228 m .54513 .40572 L .55103 .40977 L F
.73606 .35716 m .73936 .35156 L .74209 .3552 L .664 .742 .908 r
F
.73606 .35716 m .73333 .35354 L .73936 .35156 L F
.19635 .35716 m .19803 .35156 L .20181 .3552 L .664 .741 .908 r
F
.19635 .35716 m .19257 .35353 L .19803 .35156 L F
.29365 .35702 m .29562 .35142 L .29921 .35505 L F
.29365 .35702 m .29005 .35339 L .29562 .35142 L F
.8334 .35702 m .837 .35141 L .83953 .35505 L F
.8334 .35702 m .83086 .35339 L .837 .35141 L F
.21103 .35686 m .21275 .35126 L .2165 .35489 L F
.21103 .35686 m .20727 .35323 L .21275 .35126 L F
.75083 .35686 m .75417 .35126 L .75687 .35489 L F
.75083 .35686 m .74812 .35324 L .75417 .35126 L F
.51341 .43507 m .51023 .43521 L .51606 .42303 L .967 .885 .697 r
F
.64916 .43761 m .65412 .4815 L .65704 .48457 L .96 .625 .309 r
F
.64916 .43761 m .64627 .43447 L .65412 .4815 L F
.84819 .35671 m .85182 .3511 L .85433 .35474 L .664 .741 .908 r
F
.84819 .35671 m .84567 .35308 L .85182 .3511 L F
.30835 .35671 m .31036 .3511 L .31392 .35474 L F
.30835 .35671 m .30478 .35308 L .31036 .3511 L F
.58395 .42153 m .58107 .42686 L .58709 .43198 L .678 .277 .279 r
F
.7656 .35655 m .76899 .35096 L .77166 .35459 L .663 .741 .908 r
F
.7656 .35655 m .76292 .35292 L .76899 .35096 L F
.22572 .35655 m .22748 .35095 L .2312 .35459 L F
.22572 .35655 m .22199 .35292 L .22748 .35095 L F
.86298 .35641 m .86666 .35081 L .86914 .35445 L .664 .742 .908 r
F
.86298 .35641 m .86049 .35278 L .86666 .35081 L F
.32305 .35641 m .32511 .35081 L .32864 .35445 L .663 .741 .908 r
F
.32305 .35641 m .31951 .35278 L .32511 .35081 L F
.683 .35641 m .68614 .35081 L .68897 .35444 L .664 .742 .908 r
F
.683 .35641 m .68016 .35279 L .68614 .35081 L F
.67368 .49209 m .67056 .48488 L .67141 .36711 L .967 .695 .465 r
F
.67141 .36711 m .66853 .36309 L .6742 .35481 L .865 .768 .754 r
F
.67056 .48488 m .66853 .36309 L .67141 .36711 L .964 .692 .47 r
F
.78038 .35626 m .78381 .35066 L .78645 .3543 L .663 .742 .908 r
F
.78038 .35626 m .77773 .35263 L .78381 .35066 L F
.2404 .35626 m .24221 .35066 L .24591 .3543 L .663 .741 .908 r
F
.2404 .35626 m .2367 .35263 L .24221 .35066 L F
.47977 .38233 m .47669 .36815 L .48237 .3719 L .434 .36 .674 r
F
.47348 .41771 m .47669 .36815 L .47977 .38233 L .814 .588 .595 r
F
.47348 .41771 m .47049 .3973 L .47669 .36815 L F
.47669 .36815 m .47901 .37605 L .48237 .3719 L .829 .406 0 r
F
.47049 .3973 m .47346 .36353 L .47669 .36815 L .728 .528 .621 r
F
.47669 .36815 m .47346 .36353 L .47901 .37605 L .829 .406 0 r
F
.15775 .35611 m .15931 .3505 L .16317 .35414 L .664 .741 .908 r
F
.15775 .35611 m .15389 .35248 L .15931 .3505 L F
.87777 .35611 m .8815 .35051 L .88395 .35414 L .663 .74 .908 r
F
.87777 .35611 m .87531 .35247 L .8815 .35051 L F
.33775 .35612 m .33424 .35248 L .33986 .35051 L .664 .741 .908 r
F
.69777 .35614 m .70095 .35052 L .70375 .35414 L .665 .742 .908 r
F
.69777 .35614 m .69496 .35251 L .70095 .35052 L F
.2551 .35595 m .25695 .35035 L .26062 .35399 L .664 .741 .908 r
F
.2551 .35595 m .25143 .35232 L .25695 .35035 L F
.79516 .35596 m .79864 .35035 L .80125 .35399 L F
.79516 .35596 m .79254 .35233 L .79864 .35035 L F
.17243 .3558 m .17404 .35019 L .17786 .35383 L F
.17243 .3558 m .1686 .35217 L .17404 .35019 L F
.89257 .3558 m .89634 .3502 L .89876 .35384 L .664 .742 .908 r
F
.89257 .3558 m .89014 .35217 L .89634 .3502 L F
.71253 .35581 m .71576 .35019 L .71854 .35383 L .664 .741 .908 r
F
.71253 .35581 m .70975 .35217 L .71576 .35019 L F
.2698 .35565 m .2717 .35004 L .27533 .35368 L .663 .741 .908 r
F
.2698 .35565 m .26615 .35201 L .2717 .35004 L F
.80994 .35565 m .81347 .35004 L .81605 .35369 L .664 .741 .908 r
F
.80994 .35565 m .80735 .35202 L .81347 .35004 L F
.18712 .3555 m .18877 .34989 L .19257 .35353 L .663 .741 .908 r
F
.18712 .3555 m .18331 .35186 L .18877 .34989 L F
.72731 .3555 m .73058 .34991 L .73333 .35354 L F
.72731 .3555 m .72455 .35187 L .73058 .34991 L F
.53298 .38143 m .53577 .40367 L .53892 .40796 L .939 .574 .268 r
F
.53298 .38143 m .52985 .37915 L .53577 .40367 L F
.2845 .35535 m .28644 .34975 L .29005 .35339 L .663 .741 .908 r
F
.2845 .35535 m .28088 .35172 L .28644 .34975 L F
.82474 .35536 m .8283 .34974 L .83086 .35339 L .664 .741 .908 r
F
.82474 .35536 m .82217 .35172 L .8283 .34974 L F
.49866 .43852 m .50125 .43273 L .50444 .43681 L .812 .939 .576 r
F
.49866 .43852 m .4954 .44207 L .50125 .43273 L F
.20181 .3552 m .2035 .34959 L .20727 .35323 L .663 .741 .908 r
F
.20181 .3552 m .19803 .35156 L .2035 .34959 L F
.74209 .3552 m .74541 .34959 L .74812 .35324 L .664 .741 .908 r
F
.74209 .3552 m .73936 .35156 L .74541 .34959 L F
.56876 .39988 m .57212 .43283 L .57517 .43404 L .881 .54 .399 r
F
.56876 .39988 m .56582 .40585 L .57212 .43283 L F
.60188 .4331 m .59894 .43207 L .60465 .42241 L .941 .883 .747 r
F
.51665 .39531 m .51644 .39074 L .51824 .38282 L .997 .846 .513 r
F
.51236 .40869 m .51507 .38118 L .51824 .38282 L .996 .807 .536 r
F
.51824 .38282 m .51507 .38118 L .52087 .39174 L .851 .391 .052 r
F
.51608 .38303 m .51771 .37889 L .52087 .39174 L .478 .841 .59 r
F
.51507 .38118 m .51596 .3804 L .51608 .38303 L F
.51596 .3804 m .51771 .37889 L .51608 .38303 L F
.51556 .40385 m .51236 .40869 L .51644 .39074 L .997 .846 .513 r
F
.51556 .40385 m .51644 .39074 L .51665 .39531 L F
.83953 .35505 m .84315 .34944 L .84567 .35308 L .663 .741 .908 r
F
.83953 .35505 m .837 .35141 L .84315 .34944 L F
.29921 .35505 m .3012 .34944 L .30478 .35308 L .664 .741 .908 r
F
.29921 .35505 m .29562 .35142 L .3012 .34944 L F
.51023 .43521 m .51287 .4266 L .51606 .42303 L .808 .781 .828 r
F
.2165 .35489 m .21824 .34928 L .22199 .35292 L .664 .741 .908 r
F
.2165 .35489 m .21275 .35126 L .21824 .34928 L F
.75687 .35489 m .76024 .34928 L .76292 .35292 L F
.75687 .35489 m .75417 .35126 L .76024 .34928 L F
.49184 .39859 m .48874 .38483 L .4945 .38369 L .586 .464 .681 r
F
.48584 .42034 m .48874 .38483 L .49184 .39859 L .76 .555 .619 r
F
.48584 .42034 m .48279 .40155 L .48874 .38483 L F
.48874 .38483 m .49136 .37362 L .4945 .38369 L .605 .519 .73 r
F
.48874 .38483 m .4856 .37502 L .49136 .37362 L F
.48279 .40155 m .4856 .37502 L .48874 .38483 L .669 .491 .635 r
F
.48279 .40155 m .47977 .38233 L .4856 .37502 L F
.4856 .37502 m .48814 .37049 L .49136 .37362 L .618 .758 .946 r
F
.4856 .37502 m .48237 .3719 L .48814 .37049 L F
.47977 .38233 m .48237 .3719 L .4856 .37502 L .434 .36 .674 r
F
.85433 .35474 m .85799 .34914 L .86049 .35278 L .663 .741 .908 r
F
.85433 .35474 m .85182 .3511 L .85799 .34914 L F
.31392 .35474 m .31595 .34913 L .31951 .35278 L F
.31392 .35474 m .31036 .3511 L .31595 .34913 L F
.6742 .35481 m .67731 .34914 L .68016 .35279 L .667 .743 .907 r
F
.6742 .35481 m .67134 .35118 L .67731 .34914 L F
.66853 .36309 m .67134 .35118 L .6742 .35481 L .849 .758 .762 r
F
.6173 .44022 m .61423 .43497 L .61835 .36807 L .962 .707 .503 r
F
.61835 .36807 m .62361 .43878 L .6265 .43816 L .959 .641 .374 r
F
.61835 .36807 m .61547 .36779 L .62361 .43878 L F
.2312 .35459 m .23299 .34898 L .2367 .35263 L .663 .741 .908 r
F
.2312 .35459 m .22748 .35095 L .23299 .34898 L F
.77166 .35459 m .77507 .34899 L .77773 .35263 L F
.77166 .35459 m .76899 .35096 L .77507 .34899 L F
.68897 .35444 m .69213 .34884 L .69496 .35251 L F
.68897 .35444 m .68614 .35081 L .69213 .34884 L F
.32864 .35445 m .33072 .34884 L .33424 .35248 L F
.32864 .35445 m .32511 .35081 L .33072 .34884 L F
.86914 .35445 m .87284 .34883 L .87531 .35247 L .664 .741 .907 r
F
.86914 .35445 m .86666 .35081 L .87284 .34883 L F
.24591 .3543 m .24774 .34868 L .25143 .35232 L .664 .741 .908 r
F
.24591 .3543 m .24221 .35066 L .24774 .34868 L F
.78645 .3543 m .78991 .34868 L .79254 .35233 L F
.78645 .3543 m .78381 .35066 L .78991 .34868 L F
.70788 .59159 m .70444 .57722 L .70665 .50375 L .931 .669 .519 r
F
.70444 .57722 m .70418 .5065 L .70665 .50375 L .928 .673 .532 r
F
.16317 .35414 m .16474 .34852 L .1686 .35217 L .663 .741 .908 r
F
.16317 .35414 m .15931 .3505 L .16474 .34852 L F
.88395 .35414 m .8877 .34852 L .89014 .35217 L .664 .742 .908 r
F
.88395 .35414 m .8815 .35051 L .8877 .34852 L F
.70375 .35414 m .70696 .34852 L .70975 .35217 L .665 .742 .908 r
F
.70375 .35414 m .70095 .35052 L .70696 .34852 L F
.26062 .35399 m .26249 .34837 L .26615 .35201 L .664 .741 .908 r
F
.26062 .35399 m .25695 .35035 L .26249 .34837 L F
.80125 .35399 m .80475 .34837 L .80735 .35202 L F
.80125 .35399 m .79864 .35035 L .80475 .34837 L F
.45223 .44644 m .44901 .43722 L .45606 .3783 L .929 .685 .549 r
F
.45606 .3783 m .45239 .39216 L .4577 .41033 L .771 .453 .449 r
F
.45774 .41035 m .4577 .41033 L .45774 .41047 L F
.45606 .3783 m .4577 .41033 L .45774 .41035 L F
.45239 .39216 m .45481 .38875 L .45774 .41047 L 0 0 .038 r
F
.45239 .39216 m .44859 .40882 L .45481 .38875 L F
.44901 .40746 m .45189 .36748 L .45481 .38875 L .997 .797 .444 r
F
.44859 .40882 m .44871 .40736 L .44901 .40746 L F
.44871 .40736 m .45189 .36748 L .44901 .40746 L F
.17786 .35383 m .17949 .34822 L .18331 .35186 L .663 .741 .908 r
F
.17786 .35383 m .17404 .35019 L .17949 .34822 L F
.71854 .35383 m .72179 .34822 L .72455 .35187 L F
.71854 .35383 m .71576 .35019 L .72179 .34822 L F
.47658 .43314 m .47977 .38233 L .48279 .40155 L .864 .633 .586 r
F
.47658 .43314 m .47348 .41771 L .47977 .38233 L F
.27533 .35368 m .27725 .34807 L .28088 .35172 L .663 .741 .908 r
F
.27533 .35368 m .2717 .35004 L .27725 .34807 L F
.81605 .35369 m .8196 .34806 L .82217 .35172 L .664 .741 .908 r
F
.81605 .35369 m .81347 .35004 L .8196 .34806 L F
.19257 .35353 m .19423 .34791 L .19803 .35156 L F
.19257 .35353 m .18877 .34989 L .19423 .34791 L F
.73333 .35354 m .73663 .34793 L .73936 .35156 L .664 .742 .908 r
F
.73333 .35354 m .73058 .34991 L .73663 .34793 L F
.60365 .37096 m .60067 .36836 L .60792 .41887 L .96 .631 .335 r
F
.83086 .35339 m .83445 .34777 L .837 .35141 L .663 .741 .908 r
F
.83086 .35339 m .8283 .34974 L .83445 .34777 L F
.29005 .35339 m .29202 .34777 L .29562 .35142 L .664 .741 .908 r
F
.29005 .35339 m .28644 .34975 L .29202 .34777 L F
.59301 .43174 m .59599 .43144 L .59894 .43207 L .069 .632 .75 r
F
.20727 .35323 m .20899 .34761 L .21275 .35126 L .664 .741 .908 r
F
.20727 .35323 m .2035 .34959 L .20899 .34761 L F
.74812 .35324 m .75147 .34761 L .75417 .35126 L F
.74812 .35324 m .74541 .34959 L .75147 .34761 L F
.50444 .43681 m .50704 .43178 L .51023 .43521 L .595 .687 .907 r
F
.50444 .43681 m .50125 .43273 L .50704 .43178 L F
.47049 .3973 m .46751 .37714 L .47346 .36353 L .728 .528 .621 r
F
.47346 .36353 m .47556 .38496 L .47901 .37605 L .813 .458 .384 r
F
.46751 .37714 m .47004 .37004 L .47346 .36353 L .297 .272 .662 r
F
.47346 .36353 m .47004 .37004 L .47556 .38496 L .813 .458 .384 r
F
.84567 .35308 m .84931 .34745 L .85182 .3511 L .664 .742 .908 r
F
.84567 .35308 m .84315 .34944 L .84931 .34745 L F
.30478 .35308 m .30679 .34745 L .31036 .3511 L .664 .741 .908 r
F
.30478 .35308 m .3012 .34944 L .30679 .34745 L F
.67056 .48488 m .66739 .47651 L .66853 .36309 L .964 .692 .47 r
F
.66853 .36309 m .66563 .35882 L .67134 .35118 L .849 .758 .762 r
F
.66739 .47651 m .66563 .35882 L .66853 .36309 L .964 .693 .471 r
F
.76292 .35292 m .76631 .3473 L .76899 .35096 L .663 .741 .908 r
F
.76292 .35292 m .76024 .34928 L .76631 .3473 L F
.22199 .35292 m .22374 .3473 L .22748 .35095 L F
.22199 .35292 m .21824 .34928 L .22374 .3473 L F
.65097 .47579 m .64812 .47201 L .65113 .47673 L .95 .608 .327 r
F
.64338 .43178 m .64812 .47201 L .65097 .47579 L F
.64055 .43102 m .64515 .46839 L .64812 .47201 L .936 .59 .343 r
F
.64812 .47201 m .64515 .46839 L .64527 .4682 L .881 .784 .75 r
F
.64627 .43447 m .65113 .47673 L .65411 .48144 L .958 .621 .31 r
F
.64627 .43447 m .64338 .43178 L .65113 .47673 L F
.64338 .43178 m .64055 .43102 L .64812 .47201 L .95 .608 .327 r
F
.64055 .43102 m .63777 .43226 L .64515 .46839 L .936 .59 .343 r
F
.63777 .43226 m .64214 .46405 L .64515 .46839 L .925 .569 .335 r
F
.63777 .43226 m .63499 .43395 L .64214 .46405 L F
.63499 .43395 m .63902 .45703 L .64214 .46405 L .908 .53 .295 r
F
.64427 .44453 m .64143 .43256 L .64468 .44356 L .841 .654 .65 r
F
.63902 .45703 m .64137 .43312 L .64426 .44456 L F
.63499 .43395 m .63218 .43526 L .63902 .45703 L .908 .53 .295 r
F
.63218 .43526 m .63583 .44775 L .63902 .45703 L .837 .401 .195 r
F
.63218 .43526 m .62935 .43666 L .63583 .44775 L F
.63795 .4204 m .63479 .40609 L .63812 .41987 L .834 .629 .625 r
F
.63259 .43715 m .63465 .40805 L .63752 .42175 L F
.62595 .41088 m .62806 .37642 L .63143 .39147 L .793 .584 .618 r
F
.63412 .40841 m .63143 .39147 L .63479 .40609 L .817 .607 .619 r
F
.6293 .42506 m .63125 .39422 L .63412 .40841 L F
.63125 .39422 m .63143 .39147 L .63412 .40841 L F
.62255 .39471 m .62472 .36183 L .62806 .37642 L .767 .563 .623 r
F
.62595 .41088 m .62255 .39471 L .62806 .37642 L .793 .584 .618 r
F
.6293 .42506 m .62595 .41088 L .631 .39298 L .817 .607 .619 r
F
.63125 .39422 m .631 .39298 L .63143 .39147 L F
.6293 .42506 m .631 .39298 L .63125 .39422 L F
.62492 .36287 m .62862 .3836 L .63209 .40091 L .819 .525 0 r
F
.62479 .36218 m .62486 .36258 L .62492 .36287 L F
.62486 .36258 m .62862 .3836 L .62492 .36287 L F
.62472 .36183 m .62476 .36204 L .62479 .36218 L F
.62476 .36204 m .62862 .3836 L .62479 .36218 L F
.63259 .43715 m .6293 .42506 L .63447 .40719 L .834 .629 .625 r
F
.63465 .40805 m .63447 .40719 L .63479 .40609 L F
.63259 .43715 m .63447 .40719 L .63465 .40805 L F
.62876 .38029 m .63209 .40091 L .63556 .41773 L .821 .537 0 r
F
.62834 .37797 m .62858 .37943 L .62876 .38029 L F
.62858 .37943 m .63209 .40091 L .62876 .38029 L F
.62806 .37642 m .62822 .37739 L .62834 .37797 L F
.62822 .37739 m .63209 .40091 L .62834 .37797 L F
.63752 .42175 m .63477 .40634 L .63795 .4204 L .834 .629 .625 r
F
.63465 .40805 m .63477 .40634 L .63752 .42175 L F
.63477 .40634 m .63479 .40609 L .63795 .4204 L F
.63143 .39147 m .62806 .37642 L .62834 .37797 L .831 .547 .001 r
F
.63149 .39187 m .62834 .37797 L .63556 .41773 L F
.63143 .39147 m .62834 .37797 L .63149 .39187 L F
.64115 .43332 m .63812 .41987 L .64143 .43256 L .84 .642 .635 r
F
.63583 .44775 m .63802 .42114 L .64091 .43396 L F
.63583 .44775 m .63259 .43715 L .63789 .42059 L F
.63802 .42114 m .63789 .42059 L .63812 .41987 L F
.63583 .44775 m .63789 .42059 L .63802 .42114 L F
.63236 .39662 m .63556 .41773 L .639 .4334 L .831 .547 .001 r
F
.63183 .39373 m .63213 .39565 L .63236 .39662 L F
.63213 .39565 m .63556 .41773 L .63236 .39662 L F
.63143 .39147 m .63166 .39296 L .63183 .39373 L F
.63166 .39296 m .63556 .41773 L .63183 .39373 L F
.64091 .43396 m .63809 .42031 L .64115 .43332 L .84 .642 .635 r
F
.63802 .42114 m .63809 .42031 L .64091 .43396 L F
.63809 .42031 m .63812 .41987 L .64115 .43332 L F
.63479 .40609 m .63143 .39147 L .63183 .39373 L .846 .556 .019 r
F
.63487 .40663 m .63183 .39373 L .639 .4334 L F
.63479 .40609 m .63183 .39373 L .63487 .40663 L F
.63902 .45703 m .63583 .44775 L .64131 .43288 L .841 .654 .65 r
F
.64137 .43312 m .64131 .43288 L .64143 .43256 L F
.63902 .45703 m .64131 .43288 L .64137 .43312 L F
.63585 .4119 m .639 .4334 L .64239 .44743 L .846 .556 .019 r
F
.63541 .40946 m .63566 .41115 L .63585 .4119 L F
.63566 .41115 m .639 .4334 L .63585 .4119 L F
.63479 .40609 m .63515 .40844 L .63541 .40946 L F
.63515 .40844 m .639 .4334 L .63541 .40946 L F
.64426 .44456 m .64138 .43309 L .64427 .44453 L .841 .654 .65 r
F
.64137 .43312 m .64138 .43309 L .64426 .44456 L F
.64138 .43309 m .64143 .43256 L .64427 .44453 L F
.63812 .41987 m .63479 .40609 L .63541 .40946 L .86 .563 .034 r
F
.63826 .42076 m .63541 .40946 L .64239 .44743 L F
.63812 .41987 m .63541 .40946 L .63826 .42076 L F
.64214 .46405 m .63902 .45703 L .6445 .44399 L .86 .69 .671 r
F
.64459 .4443 m .6445 .44399 L .64468 .44356 L F
.64214 .46405 m .6445 .44399 L .64459 .4443 L F
.64143 .43256 m .63812 .41987 L .63949 .42704 L .872 .566 .047 r
F
.64515 .46839 m .64214 .46405 L .64721 .45359 L .895 .757 .702 r
F
.64749 .45442 m .64721 .45359 L .64784 .4523 L F
.64515 .46839 m .64721 .45359 L .64749 .45442 L F
.64179 .43481 m .63949 .42704 L .64096 .43475 L .872 .566 .047 r
F
.64739 .45324 m .64468 .44356 L .64784 .4523 L .86 .69 .671 r
F
.64214 .46405 m .64464 .44385 L .64739 .45324 L F
.64464 .44385 m .64468 .44356 L .64739 .45324 L F
.63904 .42466 m .64239 .44743 L .64572 .45979 L .86 .563 .034 r
F
.63812 .41987 m .63867 .42341 L .63904 .42466 L F
.63867 .42341 m .64239 .44743 L .63904 .42466 L F
.64252 .43944 m .64096 .43475 L .64572 .45979 L .872 .566 .047 r
F
.64179 .43481 m .64096 .43475 L .64252 .43944 L F
.64143 .43256 m .63949 .42704 L .64179 .43481 L F
.64468 .44356 m .64143 .43256 L .64398 .44539 L .893 .574 .076 r
F
.64812 .47201 m .64527 .4682 L .65018 .4606 L .881 .784 .75 r
F
.64812 .47201 m .65018 .4606 L .65043 .4612 L F
.64812 .47201 m .65074 .45974 L .65082 .4599 L F
.64812 .47201 m .65092 .45946 L .65093 .45948 L F
.64812 .47201 m .65095 .45942 L .65404 .46662 L F
.65027 .46047 m .64784 .4523 L .65095 .45942 L .895 .757 .702 r
F
.64515 .46839 m .64773 .45298 L .65027 .46047 L F
.64773 .45298 m .64784 .4523 L .65027 .46047 L F
.6423 .43696 m .64572 .45979 L .64901 .47072 L .872 .566 .047 r
F
.64143 .43256 m .64197 .43597 L .6423 .43696 L F
.64197 .43597 m .64572 .45979 L .6423 .43696 L F
.6456 .44938 m .64398 .44539 L .64901 .47072 L .893 .574 .076 r
F
.64468 .44356 m .64398 .44539 L .6456 .44938 L F
.65043 .4612 m .65018 .4606 L .65074 .45974 L .881 .784 .75 r
F
.65082 .4599 m .65074 .45974 L .65092 .45946 L F
.64784 .4523 m .64468 .44356 L .64609 .45041 L .921 .586 .126 r
F
.65113 .47673 m .64813 .472 L .65404 .46662 L .787 .728 .798 r
F
.65411 .48144 m .65113 .47673 L .65412 .4815 L .958 .621 .31 r
F
.65412 .4815 m .65113 .47673 L .65712 .47346 L .717 .703 .836 r
F
.65707 .47349 m .65404 .46662 L .65712 .47346 L .787 .728 .798 r
F
.65113 .47673 m .65404 .46662 L .65707 .47349 L F
.65404 .46662 m .65095 .45942 L .65102 .45974 L .928 .581 .141 r
F
.65704 .48457 m .65412 .4815 L .66012 .47834 L .735 .798 .902 r
F
.65978 .47852 m .65712 .47346 L .66012 .47834 L .717 .703 .836 r
F
.65412 .4815 m .65712 .47346 L .65978 .47852 L F
.65712 .47346 m .65404 .46662 L .65446 .46839 L .924 .573 .13 r
F
.66264 .48133 m .66012 .47834 L .66302 .48111 L .735 .798 .902 r
F
.65704 .48457 m .66012 .47834 L .66264 .48133 L F
.66012 .47834 m .65712 .47346 L .65758 .47534 L .937 .576 .179 r
F
.66586 .48373 m .66302 .48111 L .66589 .48371 L .757 .855 .923 r
F
.65992 .48686 m .66302 .48111 L .66586 .48373 L F
.66302 .48111 m .66012 .47834 L .66015 .47848 L .943 .579 .237 r
F
.66302 .48111 m .66015 .47848 L .66754 .50835 L F
.66012 .47834 m .65758 .47534 L .66454 .50373 L .937 .576 .179 r
F
.65712 .47346 m .65446 .46839 L .66149 .49826 L .924 .573 .13 r
F
.65404 .46662 m .65102 .45974 L .65844 .49303 L .928 .581 .141 r
F
.64822 .45468 m .64609 .45041 L .65223 .48013 L .921 .586 .126 r
F
.64784 .4523 m .64609 .45041 L .64822 .45468 L F
.64844 .45506 m .65223 .48013 L .65538 .48751 L F
.64784 .4523 m .64822 .45468 L .64844 .45506 L F
.64822 .45468 m .65223 .48013 L .64844 .45506 L F
.65093 .45948 m .65092 .45946 L .65095 .45942 L .881 .784 .75 r
F
.65113 .47673 m .64812 .47201 L .64813 .472 L .787 .728 .798 r
F
.31951 .35278 m .32156 .34716 L .32511 .35081 L .663 .741 .908 r
F
.31951 .35278 m .31595 .34913 L .32156 .34716 L F
.86049 .35278 m .86417 .34715 L .86666 .35081 L .664 .741 .908 r
F
.86049 .35278 m .85799 .34914 L .86417 .34715 L F
.68016 .35279 m .6833 .34717 L .68614 .35081 L .663 .741 .908 r
F
.68016 .35279 m .67731 .34914 L .6833 .34717 L F
.44349 .51369 m .44039 .50171 L .44475 .55809 L .978 .678 .331 r
F
.44039 .50171 m .44107 .5669 L .44475 .55809 L .979 .687 .38 r
F
.43737 .57498 m .44271 .4561 L .44564 .47496 L .975 .725 .492 r
F
.43737 .57498 m .43366 .58216 L .44271 .4561 L F
.55103 .40977 m .54782 .3933 L .55357 .38 L .75 .555 .633 r
F
.55357 .38 m .55672 .41405 L .55982 .41509 L .881 .542 .403 r
F
.54782 .3933 m .55055 .38624 L .55357 .38 L .27 .235 .634 r
F
.55357 .38 m .55055 .38624 L .55672 .41405 L .881 .542 .403 r
F
.2367 .35263 m .2385 .34701 L .24221 .35066 L .663 .741 .908 r
F
.2367 .35263 m .23299 .34898 L .2385 .34701 L F
.77773 .35263 m .78116 .34701 L .78381 .35066 L .664 .741 .908 r
F
.77773 .35263 m .77507 .34899 L .78116 .34701 L F
.53892 .40796 m .54147 .36577 L .54463 .3773 L .951 .723 .557 r
F
.54205 .4082 m .54463 .3773 L .54782 .3933 L .98 .774 .557 r
F
.54205 .4082 m .53892 .40796 L .5435 .38335 L F
.54404 .3843 m .5435 .38335 L .54463 .3773 L F
.54205 .4082 m .5435 .38335 L .54404 .3843 L F
.53892 .40796 m .53577 .40367 L .54147 .36577 L .951 .723 .557 r
F
.53577 .40367 m .53834 .36127 L .54147 .36577 L .912 .684 .58 r
F
.53577 .40367 m .53259 .39489 L .53834 .36127 L F
.53259 .39489 m .53523 .3646 L .53834 .36127 L .822 .62 .629 r
F
.53632 .37072 m .53808 .39005 L .54128 .39864 L .786 .444 .409 r
F
.53523 .3646 m .53582 .36984 L .53632 .37072 L F
.53582 .36984 m .53808 .39005 L .53632 .37072 L F
.54463 .3773 m .54147 .36577 L .54752 .39407 L .835 .53 0 r
F
.54147 .36577 m .54443 .39943 L .54752 .39407 L .96 .624 .299 r
F
.54147 .36577 m .53834 .36127 L .54443 .39943 L F
.49495 .41282 m .49184 .39859 L .49762 .39775 L .578 .456 .677 r
F
.48895 .43427 m .49184 .39859 L .49495 .41282 L .827 .615 .617 r
F
.48895 .43427 m .48584 .42034 L .49184 .39859 L F
.49184 .39859 m .4945 .38369 L .49762 .39775 L .586 .464 .681 r
F
.4945 .38369 m .49136 .37362 L .4971 .3759 L .453 .423 .734 r
F
.49136 .37362 m .49397 .36359 L .4971 .3759 L .855 .798 .794 r
F
.49136 .37362 m .48814 .37049 L .49397 .36359 L F
.59894 .43207 m .60179 .42479 L .60465 .42241 L .897 .944 .832 r
F
.87531 .35247 m .87904 .34686 L .8815 .35051 L .663 .741 .908 r
F
.87531 .35247 m .87284 .34883 L .87904 .34686 L F
.15389 .35248 m .15544 .34684 L .15931 .3505 L .664 .741 .908 r
F
.15389 .35248 m .15001 .34883 L .15544 .34684 L F
.33424 .35248 m .33634 .34685 L .33986 .35051 L F
.33424 .35248 m .33072 .34884 L .33634 .34685 L F
.69496 .35251 m .69814 .34687 L .70095 .35052 L .663 .74 .907 r
F
.69496 .35251 m .69213 .34884 L .69814 .34687 L F
.49762 .39775 m .4945 .38369 L .5002 .39311 L .168 .18 .629 r
F
.4945 .38369 m .4971 .3759 L .5002 .39311 L .453 .423 .734 r
F
.25143 .35232 m .25327 .34669 L .25695 .35035 L .664 .741 .908 r
F
.25143 .35232 m .24774 .34868 L .25327 .34669 L F
.79254 .35233 m .79602 .3467 L .79864 .35035 L F
.79254 .35233 m .78991 .34868 L .79602 .3467 L F
.1686 .35217 m .17019 .34654 L .17404 .35019 L F
.1686 .35217 m .16474 .34852 L .17019 .34654 L F
.70975 .35217 m .71298 .34654 L .71576 .35019 L F
.70975 .35217 m .70696 .34852 L .71298 .34654 L F
.89014 .35217 m .89391 .34654 L .89634 .3502 L F
.89014 .35217 m .8877 .34852 L .89391 .34654 L F
.26615 .35201 m .26804 .34639 L .2717 .35004 L .663 .741 .908 r
F
.26615 .35201 m .26249 .34837 L .26804 .34639 L F
.80735 .35202 m .81088 .34639 L .81347 .35004 L .664 .741 .908 r
F
.80735 .35202 m .80475 .34837 L .81088 .34639 L F
.18331 .35186 m .18495 .34624 L .18877 .34989 L .663 .741 .908 r
F
.18331 .35186 m .17949 .34822 L .18495 .34624 L F
.72455 .35187 m .72783 .34625 L .73058 .34991 L F
.72455 .35187 m .72179 .34822 L .72783 .34625 L F
.82217 .35172 m .82574 .34609 L .8283 .34974 L F
.82217 .35172 m .8196 .34806 L .82574 .34609 L F
.28088 .35172 m .28282 .3461 L .28644 .34975 L F
.28088 .35172 m .27725 .34807 L .28282 .3461 L F
.51287 .4266 m .50967 .42663 L .51556 .40385 L .979 .803 .595 r
F
.50967 .42663 m .51236 .40869 L .51556 .40385 L .872 .718 .687 r
F
.46676 .49354 m .46366 .48078 L .46954 .47152 L .738 .569 .664 r
F
.46366 .48078 m .46619 .47321 L .46954 .47152 L .272 .234 .631 r
F
.54782 .3933 m .54463 .3773 L .55055 .38624 L .27 .235 .634 r
F
.54463 .3773 m .54752 .39407 L .55055 .38624 L .835 .53 0 r
F
.19803 .35156 m .19971 .34593 L .2035 .34959 L .663 .741 .908 r
F
.19803 .35156 m .19423 .34791 L .19971 .34593 L F
.73936 .35156 m .74268 .34594 L .74541 .34959 L .664 .742 .908 r
F
.73936 .35156 m .73663 .34793 L .74268 .34594 L F
.837 .35141 m .84061 .34578 L .84315 .34944 L F
.837 .35141 m .83445 .34777 L .84061 .34578 L F
.29562 .35142 m .2976 .34578 L .3012 .34944 L .664 .741 .908 r
F
.29562 .35142 m .29202 .34777 L .2976 .34578 L F
.21275 .35126 m .21448 .34562 L .21824 .34928 L F
.21275 .35126 m .20899 .34761 L .21448 .34562 L F
.75417 .35126 m .75754 .34562 L .76024 .34928 L F
.75417 .35126 m .75147 .34761 L .75754 .34562 L F
.85182 .3511 m .85548 .34547 L .85799 .34914 L .663 .741 .908 r
F
.85182 .3511 m .84931 .34745 L .85548 .34547 L F
.31036 .3511 m .31239 .34547 L .31595 .34913 L F
.31036 .3511 m .30679 .34745 L .31239 .34547 L F
.67134 .35118 m .67445 .34548 L .67731 .34914 L .666 .741 .906 r
F
.67134 .35118 m .66847 .3475 L .67445 .34548 L F
.66563 .35882 m .66847 .3475 L .67134 .35118 L .84 .759 .774 r
F
.51023 .43521 m .50704 .43178 L .51287 .4266 L .808 .781 .828 r
F
.5272 .41072 m .52403 .40292 L .52985 .37915 L .896 .687 .612 r
F
.52985 .37915 m .52671 .38031 L .53259 .39489 L .876 .477 .269 r
F
.22748 .35095 m .22926 .34532 L .23299 .34898 L .663 .741 .908 r
F
.22748 .35095 m .22374 .3473 L .22926 .34532 L F
.76899 .35096 m .7724 .34532 L .77507 .34899 L F
.76899 .35096 m .76631 .3473 L .7724 .34532 L F
.47901 .37605 m .48138 .38405 L .4848 .37491 L .45 .094 .269 r
F
.4848 .37491 m .48138 .38405 L .4833 .37893 L .663 .744 .249 r
F
.48237 .3719 m .4848 .37491 L .4863 .37094 L .31 0 0 r
F
.48237 .3719 m .47901 .37605 L .4848 .37491 L F
.4848 .37491 m .4833 .37893 L .48738 .36802 L .663 .744 .249 r
F
.4863 .37094 m .4848 .37491 L .48814 .37049 L .31 0 0 r
F
.32511 .35081 m .32718 .34518 L .33072 .34884 L .663 .741 .908 r
F
.32511 .35081 m .32156 .34716 L .32718 .34518 L F
.86666 .35081 m .87036 .34518 L .87284 .34883 L F
.86666 .35081 m .86417 .34715 L .87036 .34518 L F
.68614 .35081 m .6893 .34517 L .69213 .34884 L .665 .743 .908 r
F
.68614 .35081 m .6833 .34717 L .6893 .34517 L F
.78381 .35066 m .78727 .34502 L .78991 .34868 L .664 .741 .908 r
F
.78381 .35066 m .78116 .34701 L .78727 .34502 L F
.24221 .35066 m .24403 .34502 L .24774 .34868 L F
.24221 .35066 m .2385 .34701 L .24403 .34502 L F
.46751 .37714 m .46442 .36351 L .47004 .37004 L .297 .272 .662 r
F
.46083 .42589 m .46442 .36351 L .46751 .37714 L .887 .647 .569 r
F
.46083 .42589 m .45774 .41047 L .46442 .36351 L F
.46411 .43137 m .46751 .37714 L .47049 .3973 L .943 .707 .552 r
F
.46411 .43137 m .46083 .42589 L .46751 .37714 L F
.46442 .36351 m .46643 .38466 L .47004 .37004 L .939 .576 .286 r
F
.45774 .41047 m .46112 .36121 L .46442 .36351 L .801 .576 .596 r
F
.46442 .36351 m .46112 .36121 L .46643 .38466 L .939 .576 .286 r
F
.15931 .3505 m .16088 .34486 L .16474 .34852 L .663 .741 .908 r
F
.15931 .3505 m .15544 .34684 L .16088 .34486 L F
.8815 .35051 m .88525 .34486 L .8877 .34852 L .665 .742 .908 r
F
.8815 .35051 m .87904 .34686 L .88525 .34486 L F
.33986 .35051 m .33634 .34685 L .34197 .34486 L .664 .741 .908 r
F
.70095 .35052 m .70416 .34487 L .70696 .34852 L .664 .742 .908 r
F
.70095 .35052 m .69814 .34687 L .70416 .34487 L F
.25695 .35035 m .25882 .34471 L .26249 .34837 L .664 .741 .908 r
F
.25695 .35035 m .25327 .34669 L .25882 .34471 L F
.79864 .35035 m .80214 .34471 L .80475 .34837 L F
.79864 .35035 m .79602 .3467 L .80214 .34471 L F
.51236 .40869 m .50913 .41149 L .51507 .38118 L .996 .807 .536 r
F
.51507 .38118 m .51187 .38355 L .51771 .37889 L .478 .841 .59 r
F
.50913 .41149 m .51187 .38355 L .51507 .38118 L .958 .759 .594 r
F
.17404 .35019 m .17565 .34455 L .17949 .34822 L .663 .741 .908 r
F
.17404 .35019 m .17019 .34654 L .17565 .34455 L F
.71576 .35019 m .71902 .34456 L .72179 .34822 L F
.71576 .35019 m .71298 .34654 L .71902 .34456 L F
.45966 .46434 m .45653 .45239 L .46272 .42935 L .848 .637 .617 r
F
.2717 .35004 m .27361 .34441 L .27725 .34807 L .663 .741 .908 r
F
.2717 .35004 m .26804 .34639 L .27361 .34441 L F
.81347 .35004 m .81702 .34441 L .8196 .34806 L F
.81347 .35004 m .81088 .34639 L .81702 .34441 L F
.59894 .43207 m .59599 .43144 L .60179 .42479 L .897 .944 .832 r
F
.49808 .42469 m .49495 .41282 L .50073 .41217 L .577 .477 .703 r
F
.49215 .44135 m .49495 .41282 L .49808 .42469 L .893 .693 .625 r
F
.49215 .44135 m .48895 .43427 L .49495 .41282 L F
.49495 .41282 m .49762 .39775 L .50073 .41217 L .578 .456 .677 r
F
.50073 .41217 m .49762 .39775 L .50332 .40956 L .047 .093 .588 r
F
.49762 .39775 m .5002 .39311 L .50332 .40956 L .168 .18 .629 r
F
.50125 .43273 m .50388 .42403 L .50704 .43178 L .584 .539 .771 r
F
.50125 .43273 m .49808 .42469 L .50388 .42403 L F
.4954 .44207 m .49808 .42469 L .50125 .43273 L .965 .82 .649 r
F
.18877 .34989 m .19043 .34425 L .19423 .34791 L .664 .741 .908 r
F
.18877 .34989 m .18495 .34624 L .19043 .34425 L F
.73058 .34991 m .73388 .34428 L .73663 .34793 L .663 .741 .908 r
F
.73058 .34991 m .72783 .34625 L .73388 .34428 L F
.8283 .34974 m .8319 .34411 L .83445 .34777 L F
.8283 .34974 m .82574 .34609 L .8319 .34411 L F
.28644 .34975 m .2884 .34411 L .29202 .34777 L .664 .741 .908 r
F
.28644 .34975 m .28282 .3461 L .2884 .34411 L F
.66739 .47651 m .66422 .46834 L .66563 .35882 L .964 .693 .471 r
F
.66563 .35882 m .66272 .35459 L .66847 .3475 L .84 .759 .774 r
F
.66422 .46834 m .66272 .35459 L .66563 .35882 L .963 .692 .474 r
F
.54513 .40572 m .54782 .3933 L .55103 .40977 L .981 .91 .605 r
F
.54513 .40572 m .54205 .4082 L .54782 .3933 L F
.74541 .34959 m .74875 .34394 L .75147 .34761 L .664 .742 .908 r
F
.74541 .34959 m .74268 .34594 L .74875 .34394 L F
.2035 .34959 m .20521 .34394 L .20899 .34761 L .664 .741 .908 r
F
.2035 .34959 m .19971 .34593 L .20521 .34394 L F
.49397 .36359 m .49645 .36996 L .49958 .38527 L .791 .312 0 r
F
.4971 .3759 m .49397 .36359 L .49716 .3759 L 0 0 .187 r
F
.48814 .37049 m .49074 .36076 L .49397 .36359 L .93 .921 .544 r
F
.49397 .36359 m .49307 .3628 L .49645 .36996 L .791 .312 0 r
F
.49307 .3628 m .49074 .36076 L .49455 .36689 L F
.49307 .3628 m .49455 .36689 L .49645 .36996 L F
.49512 .36782 m .49327 .36004 L .49645 .36996 L 0 0 0 r
F
.50272 .39998 m .49958 .38527 L .50242 .38831 L .344 .296 .66 r
F
.50379 .39249 m .50242 .38831 L .50412 .39013 L F
.50272 .39998 m .50242 .38831 L .50379 .39249 L F
.50404 .39576 m .50412 .39013 L .50538 .39147 L F
.50272 .39998 m .50412 .39013 L .50404 .39576 L F
.49958 .38527 m .50213 .38994 L .50538 .39147 L 0 0 .372 r
F
.50005 .37832 m .50157 .37383 L .50489 .36551 L .31 .28 .663 r
F
.49894 .38213 m .49645 .36996 L .49943 .38045 L 0 0 .372 r
F
.49894 .38213 m .49943 .38045 L .50213 .38994 L F
.49671 .37089 m .49892 .38132 L .50213 .38994 L .794 .476 0 r
F
.49892 .38132 m .5004 .37712 L .50005 .37832 L .31 .28 .663 r
F
.5004 .37712 m .50157 .37383 L .50005 .37832 L F
.49958 .38527 m .49894 .38213 L .50213 .38994 L 0 0 .372 r
F
.49645 .36996 m .49653 .37033 L .49671 .37089 L .794 .476 0 r
F
.49653 .37033 m .49892 .38132 L .49671 .37089 L F
.50429 .37894 m .50489 .36551 L .50817 .3592 L .85 .664 .65 r
F
.50213 .38994 m .50442 .36963 L .50429 .37894 L F
.50442 .36963 m .50489 .36551 L .50429 .37894 L F
.49645 .36996 m .49327 .36004 L .49883 .38099 L .794 .476 0 r
F
.49889 .38119 m .49883 .38099 L .49892 .38132 L F
.49645 .36996 m .49883 .38099 L .49889 .38119 L F
.49327 .36004 m .49575 .36731 L .49753 .37518 L .799 .308 .021 r
F
.49327 .36004 m .49753 .37518 L .49662 .37264 L F
.49074 .36076 m .49317 .36007 L .49512 .36782 L 0 0 0 r
F
.49317 .36007 m .49327 .36004 L .49512 .36782 L F
.48814 .37049 m .4848 .37491 L .49074 .36076 L .93 .921 .544 r
F
.48628 .3714 m .48738 .36802 L .49074 .36076 L .663 .744 .249 r
F
.4848 .37491 m .48738 .36802 L .48628 .3714 L F
.49074 .36076 m .48738 .36802 L .49327 .36004 L 0 0 0 r
F
.48738 .36802 m .48392 .38058 L .48633 .37218 L F
.48738 .36802 m .49 .35938 L .49327 .36004 L F
.48738 .36802 m .48633 .37218 L .4885 .36461 L F
.48738 .36802 m .4885 .36461 L .49 .35938 L F
.49327 .36004 m .49 .35938 L .49575 .36731 L .799 .308 .021 r
F
.49403 .36493 m .4926 .35353 L .49575 .36731 L .648 .764 .29 r
F
.49 .35938 m .49141 .35619 L .49403 .36493 L F
.49141 .35619 m .4926 .35353 L .49403 .36493 L F
.49662 .37264 m .49753 .37518 L .49892 .38132 L .799 .308 .021 r
F
.49825 .38023 m .49716 .3759 L .49958 .38527 L 0 0 .187 r
F
.4971 .3759 m .49716 .3759 L .49825 .38023 L F
.53834 .36127 m .54128 .39864 L .54443 .39943 L .918 .58 .387 r
F
.53834 .36127 m .53523 .3646 L .54128 .39864 L F
.84315 .34944 m .84678 .34379 L .84931 .34745 L .664 .742 .908 r
F
.84315 .34944 m .84061 .34578 L .84678 .34379 L F
.3012 .34944 m .3032 .34379 L .30679 .34745 L .664 .741 .908 r
F
.3012 .34944 m .2976 .34578 L .3032 .34379 L F
.48645 .43442 m .48895 .43427 L .49215 .44135 L 0 0 0 r
F
.48645 .43442 m .4831 .44047 L .48895 .43427 L F
.76024 .34928 m .76362 .34364 L .76631 .3473 L .663 .741 .908 r
F
.76024 .34928 m .75754 .34562 L .76362 .34364 L F
.21824 .34928 m .21999 .34364 L .22374 .3473 L F
.21824 .34928 m .21448 .34562 L .21999 .34364 L F
.60067 .36836 m .59776 .36892 L .60465 .40622 L .941 .598 .345 r
F
.31595 .34913 m .318 .34349 L .32156 .34716 L .663 .741 .908 r
F
.31595 .34913 m .31239 .34547 L .318 .34349 L F
.85799 .34914 m .86167 .34349 L .86417 .34715 L F
.85799 .34914 m .85548 .34547 L .86167 .34349 L F
.67731 .34914 m .68045 .34351 L .6833 .34717 L .662 .74 .908 r
F
.67731 .34914 m .67445 .34548 L .68045 .34351 L F
.61423 .43497 m .61111 .42817 L .61547 .36779 L .954 .701 .516 r
F
.61547 .36779 m .62063 .43717 L .62361 .43878 L .949 .629 .391 r
F
.61547 .36779 m .61266 .37041 L .62063 .43717 L F
.23299 .34898 m .23478 .34334 L .2385 .34701 L .663 .741 .908 r
F
.23299 .34898 m .22926 .34532 L .23478 .34334 L F
.77507 .34899 m .7785 .34334 L .78116 .34701 L F
.77507 .34899 m .7724 .34532 L .7785 .34334 L F
.4954 .44207 m .49215 .44135 L .49808 .42469 L .965 .82 .649 r
F
.49808 .42469 m .50073 .41217 L .50388 .42403 L .577 .477 .703 r
F
.87284 .34883 m .87657 .34318 L .87904 .34686 L .664 .742 .908 r
F
.87284 .34883 m .87036 .34518 L .87657 .34318 L F
.15001 .34883 m .15155 .34318 L .15544 .34684 L .664 .741 .908 r
F
.15001 .34883 m .14611 .34517 L .15155 .34318 L F
.69213 .34884 m .69532 .34319 L .69814 .34687 L .663 .741 .908 r
F
.69213 .34884 m .6893 .34517 L .69532 .34319 L F
.33072 .34884 m .33281 .34318 L .33634 .34685 L .664 .741 .908 r
F
.33072 .34884 m .32718 .34518 L .33281 .34318 L F
.24774 .34868 m .24958 .34302 L .25327 .34669 L F
.24774 .34868 m .24403 .34502 L .24958 .34302 L F
.78991 .34868 m .79338 .34303 L .79602 .3467 L F
.78991 .34868 m .78727 .34502 L .79338 .34303 L F
.16474 .34852 m .16633 .34287 L .17019 .34654 L F
.16474 .34852 m .16088 .34486 L .16633 .34287 L F
.70696 .34852 m .71019 .34287 L .71298 .34654 L .664 .742 .908 r
F
.70696 .34852 m .70416 .34487 L .71019 .34287 L F
.8877 .34852 m .89147 .34288 L .89391 .34654 L .663 .741 .908 r
F
.8877 .34852 m .88525 .34486 L .89147 .34288 L F
.44661 .52494 m .44349 .51369 L .44839 .54906 L .95 .638 .207 r
F
.44349 .51369 m .44475 .55809 L .44839 .54906 L .978 .678 .331 r
F
.26249 .34837 m .26438 .34272 L .26804 .34639 L .663 .741 .908 r
F
.26249 .34837 m .25882 .34471 L .26438 .34272 L F
.80475 .34837 m .80827 .34272 L .81088 .34639 L .664 .741 .908 r
F
.80475 .34837 m .80214 .34471 L .80827 .34272 L F
.47979 .44075 m .48279 .40155 L .48584 .42034 L .912 .691 .59 r
F
.47979 .44075 m .47658 .43314 L .48279 .40155 L F
.17949 .34822 m .18112 .34257 L .18495 .34624 L .663 .741 .908 r
F
.17949 .34822 m .17565 .34455 L .18112 .34257 L F
.72179 .34822 m .72506 .34257 L .72783 .34625 L F
.72179 .34822 m .71902 .34456 L .72506 .34257 L F
.5002 .39311 m .4971 .3759 L .50272 .39998 L 0 0 .309 r
F
.4971 .3759 m .49958 .38527 L .50272 .39998 L 0 0 .187 r
F
.8196 .34806 m .82317 .34242 L .82574 .34609 L .663 .741 .908 r
F
.8196 .34806 m .81702 .34441 L .82317 .34242 L F
.27725 .34807 m .27918 .34243 L .28282 .3461 L F
.27725 .34807 m .27361 .34441 L .27918 .34243 L F
.19423 .34791 m .19591 .34226 L .19971 .34593 L F
.19423 .34791 m .19043 .34425 L .19591 .34226 L F
.73663 .34793 m .73994 .34227 L .74268 .34594 L .664 .742 .908 r
F
.73663 .34793 m .73388 .34428 L .73994 .34227 L F
.45293 .54429 m .44976 .53507 L .45551 .53357 L .615 .534 .74 r
F
.58107 .42686 m .58409 .43074 L .58709 .43198 L .38 0 .093 r
F
.58107 .42686 m .57815 .43164 L .58409 .43074 L F
.83445 .34777 m .83806 .34211 L .84061 .34578 L .664 .742 .908 r
F
.83445 .34777 m .8319 .34411 L .83806 .34211 L F
.29202 .34777 m .29399 .34211 L .2976 .34578 L .664 .741 .908 r
F
.29202 .34777 m .2884 .34411 L .29399 .34211 L F
.59006 .43172 m .59302 .43051 L .59599 .43144 L .276 .78 .804 r
F
.45527 .53364 m .45198 .5407 L .45551 .53357 L 0 0 .282 r
F
.44976 .53507 m .45198 .5407 L .45527 .53364 L F
.44976 .53507 m .44661 .52494 L .45193 .54057 L F
.45195 .54064 m .45193 .54057 L .45198 .5407 L F
.44976 .53507 m .45193 .54057 L .45195 .54064 L F
.45193 .54057 m .44839 .54906 L .45198 .5407 L .95 .638 .207 r
F
.44661 .52494 m .44839 .54906 L .45193 .54057 L F
.44839 .54906 m .44475 .55809 L .44481 .55765 L .999 .792 .485 r
F
.44839 .54906 m .44481 .55765 L .44869 .52925 L F
.44968 .53271 m .44869 .52925 L .45167 .50746 L F
.44839 .54906 m .44869 .52925 L .44968 .53271 L F
.45198 .5407 m .44839 .54906 L .44866 .54784 L .986 .85 .473 r
F
.45198 .5407 m .44866 .54784 L .45478 .52016 L F
.20899 .34761 m .21071 .34195 L .21448 .34562 L .664 .741 .908 r
F
.20899 .34761 m .20521 .34394 L .21071 .34195 L F
.75147 .34761 m .75483 .34195 L .75754 .34562 L F
.75147 .34761 m .74875 .34394 L .75483 .34195 L F
.44107 .5669 m .44564 .47496 L .44862 .49231 L .981 .737 .491 r
F
.44107 .5669 m .43737 .57498 L .44564 .47496 L F
.84931 .34745 m .85297 .3418 L .85548 .34547 L .663 .741 .908 r
F
.84931 .34745 m .84678 .34379 L .85297 .3418 L F
.30679 .34745 m .3088 .3418 L .31239 .34547 L F
.30679 .34745 m .3032 .34379 L .3088 .3418 L F
.66847 .3475 m .67158 .3418 L .67445 .34548 L .665 .741 .906 r
F
.66847 .3475 m .66559 .34382 L .67158 .3418 L F
.66272 .35459 m .66559 .34382 L .66847 .3475 L .833 .763 .785 r
F
.50704 .43178 m .50967 .42663 L .51287 .4266 L .395 .437 .786 r
F
.50704 .43178 m .50388 .42403 L .50967 .42663 L F
.50388 .42403 m .50073 .41217 L .50648 .42122 L .098 .16 .64 r
F
.50073 .41217 m .50332 .40956 L .50648 .42122 L .047 .093 .588 r
F
.22374 .3473 m .22551 .34165 L .22926 .34532 L .663 .741 .908 r
F
.22374 .3473 m .21999 .34364 L .22551 .34165 L F
.76631 .3473 m .76972 .34165 L .7724 .34532 L F
.76631 .3473 m .76362 .34364 L .76972 .34165 L F
.86417 .34715 m .86788 .3415 L .87036 .34518 L F
.86417 .34715 m .86167 .34349 L .86788 .3415 L F
.32156 .34716 m .32362 .34151 L .32718 .34518 L F
.32156 .34716 m .318 .34349 L .32362 .34151 L F
.6833 .34717 m .68646 .34151 L .6893 .34517 L .664 .742 .908 r
F
.6833 .34717 m .68045 .34351 L .68646 .34151 L F
.78116 .34701 m .78462 .34134 L .78727 .34502 L .664 .741 .908 r
F
.78116 .34701 m .7785 .34334 L .78462 .34134 L F
.2385 .34701 m .24032 .34134 L .24403 .34502 L F
.2385 .34701 m .23478 .34334 L .24032 .34134 L F
.15544 .34684 m .157 .34119 L .16088 .34486 L .663 .741 .908 r
F
.15544 .34684 m .15155 .34318 L .157 .34119 L F
.33634 .34685 m .33845 .34119 L .34197 .34486 L .664 .741 .908 r
F
.33634 .34685 m .33281 .34318 L .33845 .34119 L F
.87904 .34686 m .88279 .34119 L .88525 .34486 L .664 .741 .907 r
F
.87904 .34686 m .87657 .34318 L .88279 .34119 L F
.69814 .34687 m .70134 .34119 L .70416 .34487 L F
.69814 .34687 m .69532 .34319 L .70134 .34119 L F
.25327 .34669 m .25513 .34103 L .25882 .34471 L .664 .741 .908 r
F
.25327 .34669 m .24958 .34302 L .25513 .34103 L F
.79602 .3467 m .79952 .34103 L .80214 .34471 L F
.79602 .3467 m .79338 .34303 L .79952 .34103 L F
.71298 .34654 m .71623 .34088 L .71902 .34456 L .663 .741 .908 r
F
.71298 .34654 m .71019 .34287 L .71623 .34088 L F
.17019 .34654 m .1718 .34088 L .17565 .34455 L F
.17019 .34654 m .16633 .34287 L .1718 .34088 L F
.66422 .46834 m .66104 .45987 L .66272 .35459 L .963 .692 .474 r
F
.66272 .35459 m .65981 .35046 L .66559 .34382 L .833 .763 .785 r
F
.66104 .45987 m .65981 .35046 L .66272 .35459 L .96 .69 .48 r
F
.26804 .34639 m .26995 .34073 L .27361 .34441 L .663 .741 .908 r
F
.26804 .34639 m .26438 .34272 L .26995 .34073 L F
.81088 .34639 m .81442 .34073 L .81702 .34441 L F
.81088 .34639 m .80827 .34272 L .81442 .34073 L F
.18495 .34624 m .1866 .34057 L .19043 .34425 L .664 .741 .908 r
F
.18495 .34624 m .18112 .34257 L .1866 .34057 L F
.72783 .34625 m .73112 .34059 L .73388 .34428 L .663 .74 .908 r
F
.72783 .34625 m .72506 .34257 L .73112 .34059 L F
.50388 .42403 m .50648 .42122 L .50967 .42663 L .098 .16 .64 r
F
.45774 .41047 m .45481 .38875 L .46112 .36121 L .801 .576 .596 r
F
.46112 .36121 m .46276 .39963 L .46643 .38466 L .855 .531 .439 r
F
.45481 .38875 m .45755 .37085 L .46112 .36121 L .481 .351 .626 r
F
.46112 .36121 m .45755 .37085 L .46276 .39963 L .855 .531 .439 r
F
.82574 .34609 m .82933 .34043 L .8319 .34411 L .664 .742 .908 r
F
.82574 .34609 m .82317 .34242 L .82933 .34043 L F
.28282 .3461 m .28477 .34043 L .2884 .34411 L .664 .741 .908 r
F
.28282 .3461 m .27918 .34243 L .28477 .34043 L F
.56582 .40585 m .56899 .42714 L .57212 .43283 L .826 .462 .366 r
F
.56582 .40585 m .56285 .41165 L .56899 .42714 L F
.19971 .34593 m .20141 .34027 L .20521 .34394 L .664 .741 .908 r
F
.19971 .34593 m .19591 .34226 L .20141 .34027 L F
.74268 .34594 m .74602 .34027 L .74875 .34394 L .664 .742 .908 r
F
.74268 .34594 m .73994 .34227 L .74602 .34027 L F
.84061 .34578 m .84425 .34011 L .84678 .34379 L .664 .741 .908 r
F
.84061 .34578 m .83806 .34211 L .84425 .34011 L F
.2976 .34578 m .29959 .34011 L .3032 .34379 L F
.2976 .34578 m .29399 .34211 L .29959 .34011 L F
.59892 .42719 m .59599 .42867 L .6013 .39935 L .995 .801 .532 r
F
.59599 .42867 m .59848 .40451 L .6013 .39935 L .985 .802 .575 r
F
.75754 .34562 m .76092 .33996 L .76362 .34364 L .663 .741 .908 r
F
.75754 .34562 m .75483 .34195 L .76092 .33996 L F
.21448 .34562 m .21622 .33996 L .21999 .34364 L F
.21448 .34562 m .21071 .34195 L .21622 .33996 L F
.59599 .43144 m .59892 .42719 L .60179 .42479 L .728 .943 .953 r
F
.31239 .34547 m .31442 .33981 L .318 .34349 L .663 .741 .908 r
F
.31239 .34547 m .3088 .3418 L .31442 .33981 L F
.85548 .34547 m .85917 .33981 L .86167 .34349 L F
.85548 .34547 m .85297 .3418 L .85917 .33981 L F
.67445 .34548 m .67759 .33982 L .68045 .34351 L F
.67445 .34548 m .67158 .3418 L .67759 .33982 L F
.45551 .53357 m .45793 .53063 L .46113 .53919 L 0 0 0 r
F
.45551 .53357 m .45198 .5407 L .45793 .53063 L F
.7724 .34532 m .77583 .33966 L .7785 .34334 L .663 .741 .908 r
F
.7724 .34532 m .76972 .34165 L .77583 .33966 L F
.22926 .34532 m .23104 .33966 L .23478 .34334 L F
.22926 .34532 m .22551 .34165 L .23104 .33966 L F
.47106 .41734 m .47348 .41771 L .47658 .43314 L 0 0 .055 r
F
.47106 .41734 m .46755 .42735 L .47348 .41771 L F
.14611 .34517 m .14765 .3395 L .15155 .34318 L .664 .741 .908 r
F
.14611 .34517 m .1422 .3415 L .14765 .3395 L F
.6893 .34517 m .69248 .3395 L .69532 .34319 L .665 .743 .908 r
F
.6893 .34517 m .68646 .34151 L .69248 .3395 L F
.87036 .34518 m .87409 .3395 L .87657 .34318 L .664 .741 .908 r
F
.87036 .34518 m .86788 .3415 L .87409 .3395 L F
.32718 .34518 m .32926 .3395 L .33281 .34318 L F
.32718 .34518 m .32362 .34151 L .32926 .3395 L F
.44027 .37495 m .43727 .3592 L .44051 .40963 L .976 .684 .301 r
F
.44027 .37495 m .44051 .40963 L .44106 .41002 L F
.43727 .3592 m .43818 .40967 L .44134 .42252 L .965 .656 .383 r
F
.44313 .39707 m .44027 .37495 L .44331 .40568 L .846 .603 .06 r
F
.44399 .40923 m .44331 .40568 L .44485 .42119 L F
.44313 .39707 m .44331 .40568 L .44399 .40923 L F
.44027 .37495 m .44134 .42252 L .44485 .42119 L .976 .684 .301 r
F
.44054 .39125 m .44169 .36413 L .44542 .35306 L .759 .542 .602 r
F
.43838 .40811 m .4399 .38795 L .44054 .39125 L F
.4399 .38795 m .44169 .36413 L .44054 .39125 L F
.43818 .40967 m .43831 .40806 L .43838 .40811 L F
.43831 .40806 m .44169 .36413 L .43838 .40811 L F
.44106 .41002 m .44051 .40963 L .44134 .42252 L .976 .684 .301 r
F
.43727 .3592 m .43397 .35425 L .43818 .40967 L .965 .656 .383 r
F
.78727 .34502 m .79074 .33935 L .79338 .34303 L .664 .742 .908 r
F
.78727 .34502 m .78462 .34134 L .79074 .33935 L F
.24403 .34502 m .24587 .33934 L .24958 .34302 L .664 .741 .908 r
F
.24403 .34502 m .24032 .34134 L .24587 .33934 L F
.88525 .34486 m .88902 .33919 L .89147 .34288 L .663 .741 .908 r
F
.88525 .34486 m .88279 .34119 L .88902 .33919 L F
.16088 .34486 m .16246 .33919 L .16633 .34287 L .664 .741 .908 r
F
.16088 .34486 m .157 .34119 L .16246 .33919 L F
.70416 .34487 m .70738 .33919 L .71019 .34287 L .664 .742 .908 r
F
.70416 .34487 m .70134 .34119 L .70738 .33919 L F
.59599 .43144 m .59302 .43051 L .59892 .42719 L .728 .943 .953 r
F
.25882 .34471 m .26069 .33903 L .26438 .34272 L .663 .741 .908 r
F
.25882 .34471 m .25513 .34103 L .26069 .33903 L F
.80214 .34471 m .80566 .33904 L .80827 .34272 L .664 .741 .908 r
F
.80214 .34471 m .79952 .34103 L .80566 .33904 L F
.52403 .40292 m .52087 .39174 L .52671 .38031 L .781 .605 .662 r
F
.52671 .38031 m .52941 .38251 L .53259 .39489 L .255 0 0 r
F
.52087 .39174 m .52354 .38381 L .52671 .38031 L .372 .333 .685 r
F
.52671 .38031 m .52354 .38381 L .52941 .38251 L .255 0 0 r
F
.17565 .34455 m .17727 .33889 L .18112 .34257 L .663 .741 .908 r
F
.17565 .34455 m .1718 .34088 L .17727 .33889 L F
.71902 .34456 m .72229 .33888 L .72506 .34257 L .664 .741 .908 r
F
.71902 .34456 m .71623 .34088 L .72229 .33888 L F
.81702 .34441 m .82058 .33874 L .82317 .34242 L .663 .741 .908 r
F
.81702 .34441 m .81442 .34073 L .82058 .33874 L F
.27361 .34441 m .27553 .33874 L .27918 .34243 L F
.27361 .34441 m .26995 .34073 L .27553 .33874 L F
.19043 .34425 m .1921 .33858 L .19591 .34226 L F
.19043 .34425 m .1866 .34057 L .1921 .33858 L F
.73388 .34428 m .7372 .33859 L .73994 .34227 L .664 .741 .907 r
F
.73388 .34428 m .73112 .34059 L .7372 .33859 L F
.8319 .34411 m .83551 .33842 L .83806 .34211 L .664 .741 .908 r
F
.8319 .34411 m .82933 .34043 L .83551 .33842 L F
.2884 .34411 m .29036 .33842 L .29399 .34211 L F
.2884 .34411 m .28477 .34043 L .29036 .33842 L F
.20521 .34394 m .20692 .33826 L .21071 .34195 L F
.20521 .34394 m .20141 .34027 L .20692 .33826 L F
.74875 .34394 m .75211 .33826 L .75483 .34195 L F
.74875 .34394 m .74602 .34027 L .75211 .33826 L F
.52087 .39174 m .51771 .37889 L .52354 .38381 L .372 .333 .685 r
F
.51771 .37889 m .52035 .38697 L .52354 .38381 L 0 0 .248 r
F
.51616 .37064 m .51665 .36057 L .51987 .356 L .713 .56 .679 r
F
.51771 .37889 m .51455 .36709 L .51809 .3792 L 0 0 .248 r
F
.51187 .38355 m .51455 .36709 L .51771 .37889 L .989 .874 .528 r
F
.51869 .38188 m .51809 .3792 L .52035 .38697 L 0 0 .248 r
F
.51771 .37889 m .51809 .3792 L .51869 .38188 L F
.51455 .36709 m .51714 .38625 L .52035 .38697 L .928 .581 .142 r
F
.51187 .38355 m .50863 .38806 L .51227 .37518 L .989 .874 .528 r
F
.51283 .37766 m .51227 .37518 L .51455 .36709 L F
.51187 .38355 m .51227 .37518 L .51283 .37766 L F
.50863 .38806 m .51138 .35964 L .51455 .36709 L .998 .807 .525 r
F
.50863 .38806 m .5059 .39093 L .51006 .36664 L F
.5059 .39093 m .50583 .38906 L .51006 .36664 L F
.51052 .36851 m .51006 .36664 L .51138 .35964 L F
.50863 .38806 m .51006 .36664 L .51052 .36851 L F
.50538 .39147 m .50817 .3592 L .51138 .35964 L .968 .759 .569 r
F
.51138 .35964 m .50817 .3592 L .51394 .37941 L .918 .54 .281 r
F
.50858 .36064 m .50991 .36475 L .51051 .3674 L .559 .159 .241 r
F
.50817 .3592 m .50843 .36003 L .50858 .36064 L F
.50843 .36003 m .50991 .36475 L .50858 .36064 L F
.50991 .36475 m .51075 .36743 L .51051 .3674 L F
.50538 .39147 m .50213 .38994 L .50817 .3592 L .968 .759 .569 r
F
.50817 .3592 m .50489 .36551 L .51075 .36743 L .559 .159 .241 r
F
.50502 .36555 m .50756 .35475 L .51075 .36743 L .835 .829 .354 r
F
.50489 .36551 m .505 .36507 L .50502 .36555 L F
.505 .36507 m .50756 .35475 L .50502 .36555 L F
.5059 .39093 m .50538 .39147 L .50583 .38906 L .998 .807 .525 r
F
.51051 .3674 m .51075 .36743 L .51394 .37941 L .559 .159 .241 r
F
.51455 .36709 m .51138 .35964 L .51581 .38012 L .928 .581 .142 r
F
.51635 .38042 m .51581 .38012 L .51714 .38625 L F
.51455 .36709 m .51581 .38012 L .51635 .38042 L F
.51138 .35964 m .51394 .37941 L .51714 .38625 L .918 .54 .281 r
F
.51402 .3791 m .51558 .36803 L .51616 .37064 L .713 .56 .679 r
F
.51394 .37941 m .51398 .37908 L .51402 .3791 L F
.51398 .37908 m .51558 .36803 L .51402 .3791 L F
.51558 .36803 m .51665 .36057 L .51616 .37064 L F
.50332 .40956 m .5002 .39311 L .50591 .4092 L 0 0 .512 r
F
.5002 .39311 m .50272 .39998 L .50591 .4092 L 0 0 .309 r
F
.84678 .34379 m .85044 .33812 L .85297 .3418 L .663 .741 .908 r
F
.84678 .34379 m .84425 .34011 L .85044 .33812 L F
.3032 .34379 m .30521 .33811 L .3088 .3418 L F
.3032 .34379 m .29959 .34011 L .30521 .33811 L F
.66559 .34382 m .6687 .33812 L .67158 .3418 L .665 .741 .907 r
F
.66559 .34382 m .6627 .34014 L .6687 .33812 L F
.65981 .35046 m .6627 .34014 L .66559 .34382 L .823 .761 .795 r
F
.21999 .34364 m .22175 .33796 L .22551 .34165 L .663 .741 .908 r
F
.21999 .34364 m .21622 .33996 L .22175 .33796 L F
.76362 .34364 m .76703 .33797 L .76972 .34165 L F
.76362 .34364 m .76092 .33996 L .76703 .33797 L F
.47004 .37004 m .47208 .39324 L .47556 .38496 L .672 .353 .425 r
F
.47004 .37004 m .46643 .38466 L .47208 .39324 L F
.86167 .34349 m .86538 .33781 L .86788 .3415 L .664 .742 .908 r
F
.86167 .34349 m .85917 .33981 L .86538 .33781 L F
.318 .34349 m .32005 .33782 L .32362 .34151 L .663 .741 .908 r
F
.318 .34349 m .31442 .33981 L .32005 .33782 L F
.68045 .34351 m .68361 .33784 L .68646 .34151 L .662 .74 .908 r
F
.68045 .34351 m .67759 .33982 L .68361 .33784 L F
.44475 .55809 m .44862 .49231 L .45167 .50746 L .99 .758 .489 r
F
.44475 .55809 m .44107 .5669 L .44862 .49231 L F
.7785 .34334 m .78195 .33766 L .78462 .34134 L .663 .741 .908 r
F
.7785 .34334 m .77583 .33966 L .78195 .33766 L F
.23478 .34334 m .23659 .33765 L .24032 .34134 L .664 .741 .908 r
F
.23478 .34334 m .23104 .33966 L .23659 .33765 L F
.55055 .38624 m .55355 .40687 L .55672 .41405 L .778 .422 .382 r
F
.55055 .38624 m .54752 .39407 L .55355 .40687 L F
.15155 .34318 m .1531 .3375 L .157 .34119 L .663 .741 .908 r
F
.15155 .34318 m .14765 .3395 L .1531 .3375 L F
.87657 .34318 m .88032 .3375 L .88279 .34119 L F
.87657 .34318 m .87409 .3395 L .88032 .3375 L F
.33281 .34318 m .33491 .3375 L .33845 .34119 L .664 .741 .908 r
F
.33281 .34318 m .32926 .3395 L .33491 .3375 L F
.69532 .34319 m .69852 .3375 L .70134 .34119 L .663 .741 .908 r
F
.69532 .34319 m .69248 .3395 L .69852 .3375 L F
.50913 .41149 m .50591 .4092 L .51187 .38355 L .958 .759 .594 r
F
.50591 .4092 m .50863 .38806 L .51187 .38355 L .81 .639 .671 r
F
.50967 .42663 m .50648 .42122 L .51236 .40869 L .872 .718 .687 r
F
.50648 .42122 m .50913 .41149 L .51236 .40869 L .487 .423 .71 r
F
.4831 .44047 m .48584 .42034 L .48895 .43427 L .979 .817 .613 r
F
.4831 .44047 m .47979 .44075 L .48584 .42034 L F
.24958 .34302 m .25143 .33734 L .25513 .34103 L .664 .741 .908 r
F
.24958 .34302 m .24587 .33934 L .25143 .33734 L F
.79338 .34303 m .79688 .33734 L .79952 .34103 L .664 .742 .908 r
F
.79338 .34303 m .79074 .33935 L .79688 .33734 L F
.66104 .45987 m .65781 .45035 L .65981 .35046 L .96 .69 .48 r
F
.65981 .35046 m .65688 .34632 L .6627 .34014 L .823 .761 .795 r
F
.65781 .45035 m .65688 .34632 L .65981 .35046 L .956 .687 .486 r
F
.16633 .34287 m .16793 .33719 L .1718 .34088 L .663 .741 .908 r
F
.16633 .34287 m .16246 .33919 L .16793 .33719 L F
.71019 .34287 m .71343 .33719 L .71623 .34088 L F
.71019 .34287 m .70738 .33919 L .71343 .33719 L F
.47901 .37605 m .47556 .38496 L .48138 .38405 L .45 .094 .269 r
F
.26438 .34272 m .26627 .33704 L .26995 .34073 L .663 .741 .908 r
F
.26438 .34272 m .26069 .33903 L .26627 .33704 L F
.80827 .34272 m .81182 .33704 L .81442 .34073 L F
.80827 .34272 m .80566 .33904 L .81182 .33704 L F
.18112 .34257 m .18276 .33688 L .1866 .34057 L .664 .741 .908 r
F
.18112 .34257 m .17727 .33889 L .18276 .33688 L F
.72506 .34257 m .72835 .33688 L .73112 .34059 L F
.72506 .34257 m .72229 .33888 L .72835 .33688 L F
.82317 .34242 m .82676 .33673 L .82933 .34043 L F
.82317 .34242 m .82058 .33874 L .82676 .33673 L F
.27918 .34243 m .28112 .33674 L .28477 .34043 L F
.27918 .34243 m .27553 .33874 L .28112 .33674 L F
.46755 .42735 m .47049 .3973 L .47348 .41771 L .996 .803 .528 r
F
.46755 .42735 m .46411 .43137 L .47049 .3973 L F
.19591 .34226 m .1976 .33657 L .20141 .34027 L .664 .741 .908 r
F
.19591 .34226 m .1921 .33858 L .1976 .33657 L F
.73994 .34227 m .74328 .33657 L .74602 .34027 L .664 .742 .908 r
F
.73994 .34227 m .7372 .33859 L .74328 .33657 L F
.83806 .34211 m .8417 .33642 L .84425 .34011 L .664 .741 .908 r
F
.83806 .34211 m .83551 .33842 L .8417 .33642 L F
.29399 .34211 m .29598 .33642 L .29959 .34011 L F
.29399 .34211 m .29036 .33842 L .29598 .33642 L F
.21071 .34195 m .21244 .33626 L .21622 .33996 L .663 .741 .908 r
F
.21071 .34195 m .20692 .33826 L .21244 .33626 L F
.75483 .34195 m .75821 .33627 L .76092 .33996 L F
.75483 .34195 m .75211 .33826 L .75821 .33627 L F
.44485 .42119 m .44881 .354 L .45189 .36748 L .973 .733 .512 r
F
.45189 .36748 m .44881 .354 L .45379 .38731 L .897 .601 .098 r
F
.44485 .42119 m .44134 .42252 L .44881 .354 L .973 .733 .512 r
F
.44881 .354 m .45004 .40081 L .45379 .38731 L .949 .632 .396 r
F
.44134 .42252 m .44542 .35306 L .44881 .354 L .912 .667 .555 r
F
.44881 .354 m .44542 .35306 L .45004 .40081 L .949 .632 .396 r
F
.58709 .43198 m .59 .42795 L .59302 .43051 L .692 .917 .97 r
F
.58709 .43198 m .58409 .43074 L .59 .42795 L F
.3088 .3418 m .31083 .33612 L .31442 .33981 L .663 .741 .908 r
F
.3088 .3418 m .30521 .33811 L .31083 .33612 L F
.85297 .3418 m .85665 .33611 L .85917 .33981 L .664 .742 .908 r
F
.85297 .3418 m .85044 .33812 L .85665 .33611 L F
.67158 .3418 m .67471 .33612 L .67759 .33982 L .664 .741 .908 r
F
.67158 .3418 m .6687 .33812 L .67471 .33612 L F
.53259 .39489 m .52941 .38251 L .53523 .3646 L .822 .62 .629 r
F
.53523 .3646 m .53211 .37436 L .53808 .39005 L .786 .444 .409 r
F
.52941 .38251 m .53211 .37436 L .53523 .3646 L .371 .328 .681 r
F
.61111 .42817 m .60792 .41887 L .61266 .37041 L .934 .687 .541 r
F
.61266 .37041 m .61754 .43236 L .62063 .43717 L .931 .607 .404 r
F
.61266 .37041 m .60991 .37613 L .61754 .43236 L F
.76972 .34165 m .77315 .33597 L .77583 .33966 L .663 .742 .908 r
F
.76972 .34165 m .76703 .33797 L .77315 .33597 L F
.22551 .34165 m .22729 .33596 L .23104 .33966 L .663 .741 .908 r
F
.22551 .34165 m .22175 .33796 L .22729 .33596 L F
.1422 .3415 m .14373 .3358 L .14765 .3395 L .664 .741 .908 r
F
.1422 .3415 m .13828 .33781 L .14373 .3358 L F
.86788 .3415 m .8716 .33581 L .87409 .3395 L .663 .741 .908 r
F
.86788 .3415 m .86538 .33781 L .8716 .33581 L F
.32362 .34151 m .3257 .33581 L .32926 .3395 L .664 .741 .908 r
F
.32362 .34151 m .32005 .33782 L .3257 .33581 L F
.68646 .34151 m .68964 .33581 L .69248 .3395 L .665 .743 .908 r
F
.68646 .34151 m .68361 .33784 L .68964 .33581 L F
.24032 .34134 m .24214 .33565 L .24587 .33934 L .664 .741 .908 r
F
.24032 .34134 m .23659 .33765 L .24214 .33565 L F
.78462 .34134 m .78809 .33565 L .79074 .33935 L .664 .742 .908 r
F
.78462 .34134 m .78195 .33766 L .78809 .33565 L F
.88279 .34119 m .88656 .3355 L .88902 .33919 L .663 .741 .908 r
F
.88279 .34119 m .88032 .3375 L .88656 .3355 L F
.157 .34119 m .15857 .33549 L .16246 .33919 L .664 .741 .908 r
F
.157 .34119 m .1531 .3375 L .15857 .33549 L F
.33845 .34119 m .33491 .3375 L .34057 .33549 L .664 .742 .908 r
F
.70134 .34119 m .70456 .33549 L .70738 .33919 L .664 .741 .908 r
F
.70134 .34119 m .69852 .3375 L .70456 .33549 L F
.55596 .36157 m .55277 .34952 L .55873 .35405 L .38 .348 .698 r
F
.55032 .3933 m .55277 .34952 L .55596 .36157 L .821 .597 .599 r
F
.55032 .3933 m .54707 .37554 L .55277 .34952 L F
.55277 .34952 m .5557 .36003 L .55873 .35405 L .861 .411 .1 r
F
.54707 .37554 m .54968 .34851 L .55277 .34952 L .713 .528 .638 r
F
.55277 .34952 m .54968 .34851 L .5557 .36003 L .861 .411 .1 r
F
.25513 .34103 m .257 .33534 L .26069 .33903 L .663 .741 .908 r
F
.25513 .34103 m .25143 .33734 L .257 .33534 L F
.79952 .34103 m .80304 .33534 L .80566 .33904 L .664 .741 .908 r
F
.79952 .34103 m .79688 .33734 L .80304 .33534 L F
.56817 .37761 m .56496 .36418 L .57086 .36291 L .591 .471 .685 r
F
.56252 .39988 m .56496 .36418 L .56817 .37761 L .75 .545 .617 r
F
.56252 .39988 m .55922 .38023 L .56496 .36418 L F
.56496 .36418 m .56771 .3546 L .57086 .36291 L .592 .532 .757 r
F
.56496 .36418 m .5618 .35553 L .56771 .3546 L F
.55922 .38023 m .5618 .35553 L .56496 .36418 L .655 .483 .64 r
F
.1718 .34088 m .17341 .33519 L .17727 .33889 L .663 .741 .908 r
F
.1718 .34088 m .16793 .33719 L .17341 .33519 L F
.71623 .34088 m .7195 .33519 L .72229 .33888 L F
.71623 .34088 m .71343 .33719 L .7195 .33519 L F
.26995 .34073 m .27186 .33504 L .27553 .33874 L F
.26995 .34073 m .26627 .33704 L .27186 .33504 L F
.81442 .34073 m .81799 .33503 L .82058 .33874 L .664 .741 .908 r
F
.81442 .34073 m .81182 .33704 L .81799 .33503 L F
.1866 .34057 m .18826 .33488 L .1921 .33858 L .663 .741 .908 r
F
.1866 .34057 m .18276 .33688 L .18826 .33488 L F
.73112 .34059 m .73444 .33488 L .7372 .33859 L .663 .74 .907 r
F
.73112 .34059 m .72835 .33688 L .73444 .33488 L F
.82933 .34043 m .83294 .33472 L .83551 .33842 L .664 .741 .908 r
F
.82933 .34043 m .82676 .33673 L .83294 .33472 L F
.28477 .34043 m .28673 .33472 L .29036 .33842 L F
.28477 .34043 m .28112 .33674 L .28673 .33472 L F
.44839 .54906 m .45167 .50746 L .45478 .52016 L .999 .792 .485 r
F
.20141 .34027 m .20312 .33456 L .20692 .33826 L .664 .741 .908 r
F
.20141 .34027 m .1976 .33657 L .20312 .33456 L F
.74602 .34027 m .74938 .33456 L .75211 .33826 L F
.74602 .34027 m .74328 .33657 L .74938 .33456 L F
.55922 .38023 m .55596 .36157 L .5618 .35553 L .655 .483 .64 r
F
.5618 .35553 m .56464 .35292 L .56506 .35502 L .497 .837 .998 r
F
.5618 .35553 m .55873 .35405 L .56464 .35292 L F
.55596 .36157 m .55873 .35405 L .5618 .35553 L .38 .348 .698 r
F
.56325 .35319 m .56164 .35809 L .56464 .35292 L .331 0 .12 r
F
.55873 .35405 m .56164 .35809 L .56325 .35319 L F
.5557 .36003 m .55865 .36766 L .56164 .35809 L .387 .059 .282 r
F
.56164 .35809 m .55865 .36766 L .56001 .36304 L .72 .746 .235 r
F
.55873 .35405 m .5557 .36003 L .56164 .35809 L .331 0 .12 r
F
.56164 .35809 m .56001 .36304 L .56441 .34811 L .72 .746 .235 r
F
.56464 .35292 m .56164 .35809 L .56423 .35081 L .906 .887 .464 r
F
.56464 .35292 m .56423 .35081 L .56739 .34193 L F
.56506 .35502 m .56464 .35292 L .56771 .3546 L .497 .837 .998 r
F
.84425 .34011 m .84791 .33442 L .85044 .33812 L .663 .741 .908 r
F
.84425 .34011 m .8417 .33642 L .84791 .33442 L F
.29959 .34011 m .3016 .33441 L .30521 .33811 L F
.29959 .34011 m .29598 .33642 L .3016 .33441 L F
.6627 .34014 m .6658 .33442 L .6687 .33812 L .665 .742 .908 r
F
.6627 .34014 m .65979 .33644 L .6658 .33442 L F
.65688 .34632 m .65979 .33644 L .6627 .34014 L .809 .757 .805 r
F
.50648 .42122 m .50332 .40956 L .50913 .41149 L .487 .423 .71 r
F
.50332 .40956 m .50591 .4092 L .50913 .41149 L 0 0 .512 r
F
.21622 .33996 m .21798 .33426 L .22175 .33796 L .663 .741 .908 r
F
.21622 .33996 m .21244 .33626 L .21798 .33426 L F
.76092 .33996 m .76433 .33427 L .76703 .33797 L F
.76092 .33996 m .75821 .33627 L .76433 .33427 L F
.55355 .40687 m .55596 .36157 L .55922 .38023 L .872 .642 .587 r
F
.55355 .40687 m .55032 .3933 L .55596 .36157 L F
.31442 .33981 m .31647 .33411 L .32005 .33782 L .663 .741 .908 r
F
.31442 .33981 m .31083 .33612 L .31647 .33411 L F
.85917 .33981 m .86287 .3341 L .86538 .33781 L .664 .741 .908 r
F
.85917 .33981 m .85665 .33611 L .86287 .3341 L F
.67759 .33982 m .68074 .33413 L .68361 .33784 L .662 .74 .908 r
F
.67759 .33982 m .67471 .33612 L .68074 .33413 L F
.45481 .38875 m .45189 .36748 L .45755 .37085 L .481 .351 .626 r
F
.45189 .36748 m .45379 .38731 L .45755 .37085 L .897 .601 .098 r
F
.77583 .33966 m .77928 .33395 L .78195 .33766 L .664 .742 .908 r
F
.77583 .33966 m .77315 .33597 L .77928 .33395 L F
.23104 .33966 m .23284 .33395 L .23659 .33765 L .664 .741 .908 r
F
.23104 .33966 m .22729 .33596 L .23284 .33395 L F
.65781 .45035 m .65454 .43988 L .65688 .34632 L .956 .687 .486 r
F
.65688 .34632 m .65395 .34213 L .65979 .33644 L .809 .757 .805 r
F
.65454 .43988 m .65395 .34213 L .65688 .34632 L .952 .685 .492 r
F
.59302 .43051 m .59599 .42867 L .59892 .42719 L .32 .661 .973 r
F
.59355 .42617 m .59565 .41009 L .59848 .40451 L .943 .787 .658 r
F
.59302 .43051 m .59 .42795 L .59458 .4285 L .32 .661 .973 r
F
.59302 .43051 m .59458 .4285 L .59494 .42932 L F
.59 .42795 m .59302 .42851 L .59599 .42867 L 0 .204 .732 r
F
.59302 .42851 m .5934 .42583 L .59355 .42617 L .943 .787 .658 r
F
.5934 .42583 m .59565 .41009 L .59355 .42617 L F
.59494 .42932 m .59458 .4285 L .59599 .42867 L .32 .661 .973 r
F
.14765 .3395 m .14919 .33379 L .1531 .3375 L .663 .741 .908 r
F
.14765 .3395 m .14373 .3358 L .14919 .33379 L F
.87409 .3395 m .87784 .33379 L .88032 .3375 L .664 .742 .908 r
F
.87409 .3395 m .8716 .33581 L .87784 .33379 L F
.69248 .3395 m .69568 .3338 L .69852 .3375 L F
.69248 .3395 m .68964 .33581 L .69568 .3338 L F
.32926 .3395 m .33135 .3338 L .33491 .3375 L .663 .741 .908 r
F
.32926 .3395 m .3257 .33581 L .33135 .3338 L F
.57815 .43164 m .58101 .42642 L .58409 .43074 L .781 .958 .641 r
F
.57815 .43164 m .57517 .43404 L .58101 .42642 L F
.24587 .33934 m .24771 .33364 L .25143 .33734 L .664 .741 .908 r
F
.24587 .33934 m .24214 .33565 L .24771 .33364 L F
.79074 .33935 m .79424 .33364 L .79688 .33734 L .664 .742 .908 r
F
.79074 .33935 m .78809 .33565 L .79424 .33364 L F
.16246 .33919 m .16405 .33348 L .16793 .33719 L .663 .741 .908 r
F
.16246 .33919 m .15857 .33549 L .16405 .33348 L F
.70738 .33919 m .71063 .33349 L .71343 .33719 L F
.70738 .33919 m .70456 .33549 L .71063 .33349 L F
.26069 .33903 m .26258 .33333 L .26627 .33704 L F
.26069 .33903 m .257 .33534 L .26258 .33333 L F
.80566 .33904 m .8092 .33333 L .81182 .33704 L .664 .741 .908 r
F
.80566 .33904 m .80304 .33534 L .8092 .33333 L F
.57142 .39273 m .56817 .37761 L .57408 .37571 L .601 .465 .669 r
F
.56578 .41616 m .56817 .37761 L .57142 .39273 L .814 .597 .609 r
F
.56578 .41616 m .56252 .39988 L .56817 .37761 L F
.56817 .37761 m .57086 .36291 L .57408 .37571 L .591 .471 .685 r
F
.72229 .33888 m .72558 .33318 L .72835 .33688 L .664 .742 .908 r
F
.72229 .33888 m .7195 .33519 L .72558 .33318 L F
.17727 .33889 m .17891 .33317 L .18276 .33688 L .664 .741 .908 r
F
.17727 .33889 m .17341 .33519 L .17891 .33317 L F
.45198 .5407 m .45478 .52016 L .45793 .53063 L .986 .85 .473 r
F
.82058 .33874 m .82417 .33302 L .82676 .33673 L .664 .741 .908 r
F
.82058 .33874 m .81799 .33503 L .82417 .33302 L F
.27553 .33874 m .27746 .33303 L .28112 .33674 L F
.27553 .33874 m .27186 .33504 L .27746 .33303 L F
.57408 .37571 m .57086 .36291 L .57697 .37309 L .102 .152 .629 r
F
.57086 .36291 m .57368 .35625 L .57697 .37309 L .469 .468 .774 r
F
.57251 .359 m .57215 .35583 L .57368 .35625 L F
.56771 .3546 m .57048 .34486 L .57368 .35625 L .911 .873 .787 r
F
.5836 .4075 m .5803 .39141 L .58303 .40025 L 0 0 .432 r
F
.58683 .41908 m .5836 .4075 L .58701 .412 L .178 .222 .671 r
F
.58776 .41424 m .58701 .412 L .58795 .41325 L F
.58683 .41908 m .58701 .412 L .58776 .41424 L F
.58806 .41766 m .58795 .41325 L .58978 .41566 L F
.58683 .41908 m .58795 .41325 L .58806 .41766 L F
.5836 .4075 m .58669 .41208 L .58978 .41566 L 0 0 .432 r
F
.58519 .40986 m .58361 .4028 L .58669 .41208 L F
.58361 .4028 m .58303 .40025 L .58372 .40248 L F
.58361 .4028 m .58372 .40248 L .58669 .41208 L F
.58925 .38801 m .58887 .38896 L .59073 .35514 L .997 .779 .436 r
F
.59081 .35525 m .59073 .35514 L .59135 .3439 L F
.58925 .38801 m .59073 .35514 L .59081 .35525 L F
.58925 .38801 m .59135 .3439 L .59135 .3439 L F
.58887 .38896 m .5877 .38147 L .59136 .34378 L F
.58886 .389 m .58887 .38896 L .58925 .38801 L .327 .289 .663 r
F
.58776 .40565 m .58925 .38801 L .59207 .37975 L .838 .653 .653 r
F
.58769 .40269 m .58925 .38801 L .58776 .40565 L F
.58925 .38801 m .59136 .34378 L .59461 .35663 L .997 .779 .436 r
F
.58636 .39518 m .58824 .33718 L .59136 .34378 L .99 .749 .469 r
F
.59207 .37975 m .58925 .38801 L .59313 .36526 L .963 .82 .391 r
F
.59369 .365 m .59313 .36526 L .59461 .35663 L F
.59207 .37975 m .59313 .36526 L .59369 .365 L F
.58978 .41566 m .58669 .41208 L .59207 .37975 L .959 .738 .562 r
F
.58847 .36738 m .58932 .39 L .59269 .40533 L .893 .566 .421 r
F
.5836 .4075 m .58303 .40025 L .58519 .40986 L 0 0 .432 r
F
.5826 .39887 m .58349 .40283 L .58669 .41208 L 0 0 .269 r
F
.5803 .39141 m .58126 .39487 L .5826 .39887 L F
.58126 .39487 m .58349 .40283 L .5826 .39887 L F
.5803 .39141 m .57781 .37774 L .58349 .40283 L F
.57781 .37774 m .5785 .3801 L .58349 .40283 L F
.57859 .3805 m .58019 .38829 L .58349 .40283 L 0 0 .165 r
F
.58253 .36916 m .58243 .34814 L .58528 .33862 L .9 .665 .574 r
F
.58349 .40283 m .58019 .38829 L .58437 .39296 L .327 .289 .663 r
F
.58019 .38829 m .58337 .39825 L .58372 .3979 L 0 0 .299 r
F
.58019 .38829 m .58372 .3979 L .58125 .38948 L F
.57732 .39011 m .5803 .39141 L .5836 .4075 L 0 0 .522 r
F
.58485 .3992 m .58437 .39296 L .58636 .39518 L .327 .289 .663 r
F
.58349 .40283 m .58437 .39296 L .58485 .3992 L F
.58125 .38948 m .58372 .3979 L .58636 .39518 L 0 0 .299 r
F
.57879 .37147 m .57965 .36332 L .58243 .34814 L .594 .447 .651 r
F
.57855 .37954 m .57685 .37045 L .5786 .37791 L 0 0 .299 r
F
.57781 .37774 m .57697 .37309 L .5785 .3801 L 0 0 .269 r
F
.57697 .37309 m .57765 .37631 L .57859 .3805 L 0 0 .165 r
F
.57765 .37631 m .58019 .38829 L .57859 .3805 L F
.57697 .37309 m .57368 .35625 L .58004 .38755 L F
.57697 .37309 m .58004 .38755 L .58012 .38797 L F
.57732 .39011 m .57408 .37571 L .5803 .39141 L 0 0 .522 r
F
.57408 .37571 m .57697 .37309 L .5803 .39141 L .102 .152 .629 r
F
.57368 .35625 m .57685 .37045 L .58019 .38829 L .766 .468 0 r
F
.57368 .35625 m .57048 .34486 L .57489 .36258 L F
.57597 .36652 m .57489 .36258 L .57685 .37045 L F
.57368 .35625 m .57489 .36258 L .57597 .36652 L F
.57129 .34813 m .57299 .35172 L .57603 .36716 L .809 .346 0 r
F
.57299 .35172 m .57352 .35284 L .57603 .36716 L F
.57048 .34486 m .57111 .34652 L .57129 .34813 L F
.57111 .34652 m .57352 .35284 L .57129 .34813 L F
.56771 .3546 m .56464 .35292 L .57048 .34486 L .911 .873 .787 r
F
.56464 .35292 m .56739 .34193 L .57048 .34486 L .906 .887 .464 r
F
.57048 .34486 m .56739 .34193 L .57089 .34815 L .809 .346 0 r
F
.56739 .34193 m .5689 .34079 L .57096 .34828 L 0 0 0 r
F
.57048 .34486 m .57089 .34815 L .57201 .34937 L .809 .346 0 r
F
.57048 .34486 m .57268 .35135 L .57276 .35084 L F
.5689 .34079 m .57028 .33975 L .57096 .34828 L 0 0 0 r
F
.56356 .35269 m .56441 .34811 L .56739 .34193 L .72 .746 .235 r
F
.56164 .35809 m .56441 .34811 L .56356 .35269 L F
.56428 .34856 m .56147 .3608 L .56441 .34811 L 0 0 0 r
F
.55865 .36766 m .56147 .3608 L .56428 .34856 L F
.55562 .37668 m .55849 .37402 L .56147 .3608 L .492 .835 .556 r
F
.56147 .3608 m .55849 .37402 L .55862 .37322 L .875 .774 .275 r
F
.55865 .36766 m .55562 .37668 L .56147 .3608 L 0 0 0 r
F
.56311 .34776 m .56303 .34638 L .56413 .33971 L .875 .774 .275 r
F
.56441 .34811 m .56147 .3608 L .56526 .34351 L .73 .714 .183 r
F
.56441 .34811 m .56526 .34351 L .56715 .33492 L F
.56739 .34193 m .56441 .34811 L .57028 .33975 L 0 0 0 r
F
.56441 .34811 m .56559 .34241 L .56719 .34415 L .73 .714 .183 r
F
.56147 .3608 m .56413 .33971 L .56715 .33492 L .875 .774 .275 r
F
.56719 .34415 m .56715 .33492 L .57028 .33975 L .73 .714 .183 r
F
.56559 .34241 m .56715 .33492 L .56719 .34415 L F
.57201 .34937 m .57089 .34815 L .57268 .35135 L .809 .346 0 r
F
.57276 .35084 m .57268 .35135 L .57352 .35284 L F
.57096 .34828 m .57028 .33975 L .57352 .35284 L 0 0 0 r
F
.57086 .36291 m .56771 .3546 L .57215 .35583 L .469 .468 .774 r
F
.57086 .36291 m .57215 .35583 L .57251 .359 L F
.57028 .33975 m .56715 .33492 L .57275 .36131 L .947 .591 .219 r
F
.57331 .36304 m .57275 .36131 L .57361 .36535 L F
.57028 .33975 m .57275 .36131 L .57331 .36304 L F
.56715 .33492 m .57023 .34547 L .57361 .36535 L .694 .275 .247 r
F
.56715 .33492 m .56671 .3356 L .57023 .34547 L F
.56671 .3356 m .56413 .33971 L .56844 .34378 L F
.56413 .33971 m .56487 .33683 L .56653 .34198 L 0 0 0 r
F
.56487 .33683 m .56691 .32892 L .56653 .34198 L F
.55849 .37402 m .56116 .35172 L .56413 .33971 L .987 .839 .46 r
F
.56529 .3356 m .5673 .3699 L .57068 .38637 L .938 .606 .376 r
F
.56413 .33971 m .56261 .34585 L .56645 .33072 L 0 0 0 r
F
.56413 .33971 m .56645 .33072 L .56654 .33035 L F
.56261 .34585 m .56116 .35172 L .56691 .32892 L F
.56654 .33035 m .56645 .33072 L .56691 .32892 L F
.5626 .346 m .56371 .32071 L .56691 .32892 L .953 .791 .341 r
F
.56371 .32071 m .56491 .33718 L .56529 .3356 L .938 .606 .376 r
F
.56491 .33718 m .5673 .3699 L .56529 .3356 L F
.56116 .35172 m .5616 .34638 L .5626 .346 L .953 .791 .341 r
F
.5616 .34638 m .56371 .32071 L .5626 .346 L F
.56948 .34338 m .56844 .34378 L .57023 .34547 L .694 .275 .247 r
F
.56671 .3356 m .56844 .34378 L .56948 .34338 L F
.56653 .34198 m .56691 .32892 L .57023 .34547 L 0 0 0 r
F
.56116 .35172 m .55816 .36471 L .56196 .33463 L .953 .791 .341 r
F
.56228 .3381 m .56196 .33463 L .56371 .32071 L F
.56116 .35172 m .56196 .33463 L .56228 .3381 L F
.55816 .36471 m .56063 .32323 L .56371 .32071 L .998 .783 .456 r
F
.56371 .32071 m .56063 .32323 L .5673 .3699 L .938 .606 .376 r
F
.56137 .32844 m .56227 .33357 L .56238 .33547 L .69 .345 .386 r
F
.56063 .32323 m .56126 .3272 L .56137 .32844 L F
.56126 .3272 m .56227 .33357 L .56137 .32844 L F
.56238 .33547 m .56381 .34331 L .56564 .35727 L F
.56541 .35664 m .56564 .35727 L .5673 .3699 L F
.56238 .33547 m .56564 .35727 L .56541 .35664 L F
.56227 .33357 m .56381 .34331 L .56238 .33547 L F
.56147 .3608 m .55862 .37322 L .56303 .34638 L .875 .774 .275 r
F
.56147 .3608 m .56303 .34638 L .56311 .34776 L F
.57238 .3534 m .57361 .36535 L .57697 .38308 L .947 .591 .219 r
F
.57028 .33975 m .57221 .35461 L .57238 .3534 L F
.57221 .35461 m .57361 .36535 L .57238 .3534 L F
.57603 .36716 m .57352 .35284 L .57685 .37045 L .809 .346 0 r
F
.57685 .37045 m .57352 .35284 L .57788 .3799 L .805 .543 0 r
F
.57815 .37974 m .57788 .3799 L .58024 .39458 L F
.57685 .37045 m .57788 .3799 L .57815 .37974 L F
.57352 .35284 m .57697 .38308 L .58024 .39458 L .915 .609 .126 r
F
.58019 .38829 m .57855 .37954 L .58232 .39375 L 0 0 .299 r
F
.57855 .37954 m .5786 .37791 L .58232 .39375 L F
.58261 .39585 m .58232 .39375 L .58337 .39825 L F
.58019 .38829 m .58232 .39375 L .58261 .39585 L F
.58012 .38797 m .58004 .38755 L .58019 .38829 L 0 0 .165 r
F
.57685 .37045 m .58024 .39458 L .58337 .39825 L .805 .543 0 r
F
.57743 .38017 m .57885 .36918 L .57879 .37147 L .594 .447 .651 r
F
.57697 .38308 m .57736 .3802 L .57743 .38017 L F
.57736 .3802 m .57885 .36918 L .57743 .38017 L F
.57885 .36918 m .57965 .36332 L .57879 .37147 L F
.58111 .38497 m .58185 .36043 L .58253 .36916 L .9 .665 .574 r
F
.58024 .39458 m .5808 .38275 L .58111 .38497 L F
.5808 .38275 m .58185 .36043 L .58111 .38497 L F
.58185 .36043 m .58243 .34814 L .58253 .36916 L F
.58636 .39518 m .58337 .39825 L .58824 .33718 L .99 .749 .469 r
F
.58337 .39825 m .58528 .33862 L .58824 .33718 L .967 .72 .511 r
F
.58646 .34926 m .58775 .3677 L .58847 .36738 L .893 .566 .421 r
F
.58669 .41208 m .58349 .40283 L .58925 .38801 L .838 .653 .653 r
F
.58775 .3677 m .58932 .39 L .58847 .36738 L .893 .566 .421 r
F
.58528 .33862 m .58607 .34872 L .58646 .34926 L F
.58607 .34872 m .58932 .39 L .58646 .34926 L F
.59 .42795 m .58691 .42281 L .5886 .42438 L 0 .204 .732 r
F
.59061 .42398 m .59276 .41444 L .59565 .41009 L .732 .649 .766 r
F
.59001 .42796 m .5886 .42438 L .59097 .42659 L 0 .204 .732 r
F
.58691 .42281 m .58997 .42575 L .59302 .42851 L 0 0 .529 r
F
.58997 .42575 m .59054 .42345 L .59061 .42398 L .732 .649 .766 r
F
.59054 .42345 m .59276 .41444 L .59061 .42398 L F
.59118 .42817 m .59097 .42659 L .59302 .42851 L 0 .204 .732 r
F
.59001 .42796 m .59097 .42659 L .59118 .42817 L F
.59 .42795 m .5886 .42438 L .59001 .42796 L F
.58718 .42078 m .58683 .41908 L .58997 .42575 L 0 0 .448 r
F
.58376 .41469 m .5861 .41803 L .58718 .42078 L F
.5861 .41803 m .58683 .41908 L .58718 .42078 L F
.59302 .42851 m .58997 .42575 L .59565 .41009 L .943 .787 .658 r
F
.58905 .34514 m .59269 .40533 L .59589 .41234 L .952 .632 .384 r
F
.58824 .33718 m .58877 .34529 L .58905 .34514 L F
.58877 .34529 m .59269 .40533 L .58905 .34514 L F
.59135 .3439 m .59135 .3439 L .59136 .34378 L .997 .779 .436 r
F
.58887 .38896 m .58636 .39518 L .5877 .38147 L F
.58337 .39825 m .58024 .39458 L .58528 .33862 L .967 .72 .511 r
F
.58528 .33862 m .58243 .34814 L .58932 .39 L .893 .566 .421 r
F
.58361 .3553 m .58584 .36838 L .58895 .38773 L .615 .297 .408 r
F
.58243 .34814 m .58329 .35325 L .58361 .3553 L F
.58329 .35325 m .58584 .36838 L .58361 .3553 L F
.58895 .38776 m .58895 .38773 L .58932 .39 L F
.58243 .34814 m .58895 .38773 L .58895 .38776 L F
.58462 .39993 m .58636 .39518 L .58887 .38896 L .327 .289 .663 r
F
.58462 .39993 m .58887 .38896 L .58886 .389 L F
.58349 .40283 m .58513 .39846 L .58462 .39993 L F
.58513 .39846 m .58636 .39518 L .58462 .39993 L F
.58669 .41208 m .58769 .40269 L .58776 .40565 L .838 .653 .653 r
F
.1921 .33858 m .19378 .33287 L .1976 .33657 L .664 .741 .908 r
F
.1921 .33858 m .18826 .33488 L .19378 .33287 L F
.7372 .33859 m .74053 .33287 L .74328 .33657 L .664 .741 .907 r
F
.7372 .33859 m .73444 .33488 L .74053 .33287 L F
.83551 .33842 m .83914 .33271 L .8417 .33642 L .664 .741 .908 r
F
.83551 .33842 m .83294 .33472 L .83914 .33271 L F
.29036 .33842 m .29234 .33271 L .29598 .33642 L F
.29036 .33842 m .28673 .33472 L .29234 .33271 L F
.20692 .33826 m .20865 .33255 L .21244 .33626 L .663 .741 .908 r
F
.20692 .33826 m .20312 .33456 L .20865 .33255 L F
.75211 .33826 m .75549 .33256 L .75821 .33627 L F
.75211 .33826 m .74938 .33456 L .75549 .33256 L F
.30521 .33811 m .30723 .33241 L .31083 .33612 L F
.30521 .33811 m .3016 .33441 L .30723 .33241 L F
.85044 .33812 m .85412 .3324 L .85665 .33611 L .664 .741 .908 r
F
.85044 .33812 m .84791 .33442 L .85412 .3324 L F
.6687 .33812 m .67183 .33241 L .67471 .33612 L .663 .741 .908 r
F
.6687 .33812 m .6658 .33442 L .67183 .33241 L F
.22175 .33796 m .22352 .33225 L .22729 .33596 L F
.22175 .33796 m .21798 .33426 L .22352 .33225 L F
.76703 .33797 m .77046 .33226 L .77315 .33597 L .664 .742 .908 r
F
.76703 .33797 m .76433 .33427 L .77046 .33226 L F
.86538 .33781 m .86911 .3321 L .8716 .33581 L .663 .741 .908 r
F
.86538 .33781 m .86287 .3341 L .86911 .3321 L F
.13828 .33781 m .1398 .33209 L .14373 .3358 L .664 .741 .908 r
F
.13828 .33781 m .13434 .33411 L .1398 .33209 L F
.32005 .33782 m .32212 .3321 L .3257 .33581 L F
.32005 .33782 m .31647 .33411 L .32212 .3321 L F
.68361 .33784 m .68678 .33211 L .68964 .33581 L .664 .741 .907 r
F
.68361 .33784 m .68074 .33413 L .68678 .33211 L F
.23659 .33765 m .2384 .33194 L .24214 .33565 L .664 .741 .908 r
F
.23659 .33765 m .23284 .33395 L .2384 .33194 L F
.78195 .33766 m .78543 .33194 L .78809 .33565 L F
.78195 .33766 m .77928 .33395 L .78543 .33194 L F
.1531 .3375 m .15467 .33178 L .15857 .33549 L F
.1531 .3375 m .14919 .33379 L .15467 .33178 L F
.88032 .3375 m .88409 .33179 L .88656 .3355 L .663 .741 .908 r
F
.88032 .3375 m .87784 .33379 L .88409 .33179 L F
.33491 .3375 m .33702 .33178 L .34057 .33549 L .664 .742 .908 r
F
.33491 .3375 m .33135 .3338 L .33702 .33178 L F
.69852 .3375 m .70174 .33178 L .70456 .33549 L .664 .741 .908 r
F
.69852 .3375 m .69568 .3338 L .70174 .33178 L F
.25143 .33734 m .25329 .33163 L .257 .33534 L .663 .741 .908 r
F
.25143 .33734 m .24771 .33364 L .25329 .33163 L F
.79688 .33734 m .8004 .33163 L .80304 .33534 L .664 .741 .908 r
F
.79688 .33734 m .79424 .33364 L .8004 .33163 L F
.16793 .33719 m .16954 .33147 L .17341 .33519 L .663 .741 .908 r
F
.16793 .33719 m .16405 .33348 L .16954 .33147 L F
.71343 .33719 m .7167 .33149 L .7195 .33519 L F
.71343 .33719 m .71063 .33349 L .7167 .33149 L F
.26627 .33704 m .26818 .33133 L .27186 .33504 L F
.26627 .33704 m .26258 .33333 L .26818 .33133 L F
.81182 .33704 m .81538 .33132 L .81799 .33503 L .664 .741 .908 r
F
.81182 .33704 m .8092 .33333 L .81538 .33132 L F
.59599 .42867 m .59302 .42851 L .59848 .40451 L .985 .802 .575 r
F
.18276 .33688 m .18442 .33116 L .18826 .33488 L .663 .741 .908 r
F
.18276 .33688 m .17891 .33317 L .18442 .33116 L F
.72835 .33688 m .73167 .33116 L .73444 .33488 L .664 .742 .908 r
F
.72835 .33688 m .72558 .33318 L .73167 .33116 L F
.57142 .39273 m .57408 .37571 L .57732 .39011 L .601 .465 .669 r
F
.56285 .41165 m .56578 .41616 L .56899 .42714 L .488 .013 .054 r
F
.56285 .41165 m .55982 .41509 L .56578 .41616 L F
.58409 .43074 m .58691 .42281 L .59 .42795 L .739 .729 .843 r
F
.58409 .43074 m .58101 .42642 L .58691 .42281 L F
.52354 .38381 m .52623 .36926 L .52941 .38251 L .989 .89 .572 r
F
.52354 .38381 m .52035 .38697 L .52623 .36926 L F
.82676 .33673 m .83037 .33101 L .83294 .33472 L .664 .741 .908 r
F
.82676 .33673 m .82417 .33302 L .83037 .33101 L F
.28112 .33674 m .28307 .33101 L .28673 .33472 L F
.28112 .33674 m .27746 .33303 L .28307 .33101 L F
.44134 .42252 m .43818 .40967 L .44542 .35306 L .912 .667 .555 r
F
.44542 .35306 m .44655 .40146 L .45004 .40081 L .868 .553 .452 r
F
.44542 .35306 m .44169 .36413 L .44655 .40146 L F
.1976 .33657 m .1993 .33085 L .20312 .33456 L .664 .741 .908 r
F
.1976 .33657 m .19378 .33287 L .1993 .33085 L F
.74328 .33657 m .74664 .33085 L .74938 .33456 L F
.74328 .33657 m .74053 .33287 L .74664 .33085 L F
.29598 .33642 m .29797 .3307 L .3016 .33441 L .663 .741 .908 r
F
.29598 .33642 m .29234 .33271 L .29797 .3307 L F
.8417 .33642 m .84536 .3307 L .84791 .33442 L F
.8417 .33642 m .83914 .33271 L .84536 .3307 L F
.65979 .33644 m .6629 .3307 L .6658 .33442 L .665 .742 .907 r
F
.65979 .33644 m .65688 .33274 L .6629 .3307 L F
.65395 .34213 m .65688 .33274 L .65979 .33644 L .795 .754 .816 r
F
.52035 .38697 m .52306 .35918 L .52623 .36926 L .975 .779 .576 r
F
.52623 .36926 m .52306 .35918 L .52896 .38586 L .868 .544 .03 r
F
.52035 .38697 m .51714 .38625 L .52273 .36066 L .975 .779 .576 r
F
.52035 .38697 m .52273 .36066 L .52289 .36086 L F
.51714 .38625 m .51987 .356 L .52306 .35918 L .907 .701 .612 r
F
.52009 .35735 m .52253 .38478 L .52575 .39144 L .884 .534 .379 r
F
.51987 .356 m .51998 .35721 L .52009 .35735 L F
.51998 .35721 m .52253 .38478 L .52009 .35735 L F
.52289 .36086 m .52273 .36066 L .52306 .35918 L .975 .779 .576 r
F
.52306 .35918 m .52575 .39144 L .52896 .38586 L .955 .614 .312 r
F
.52306 .35918 m .51987 .356 L .52575 .39144 L F
.52941 .38251 m .52623 .36926 L .53211 .37436 L .371 .328 .681 r
F
.52623 .36926 m .52896 .38586 L .53211 .37436 L .868 .544 .03 r
F
.21244 .33626 m .21419 .33054 L .21798 .33426 L .663 .741 .908 r
F
.21244 .33626 m .20865 .33255 L .21419 .33054 L F
.75821 .33627 m .76162 .33055 L .76433 .33427 L F
.75821 .33627 m .75549 .33256 L .76162 .33055 L F
.65454 .43988 m .65125 .42891 L .65395 .34213 L .952 .685 .492 r
F
.65395 .34213 m .651 .33791 L .65688 .33274 L .795 .754 .816 r
F
.65125 .42891 m .651 .33791 L .65395 .34213 L .949 .683 .499 r
F
.85665 .33611 m .86035 .33039 L .86287 .3341 L .663 .741 .908 r
F
.85665 .33611 m .85412 .3324 L .86035 .33039 L F
.67471 .33612 m .67786 .3304 L .68074 .33413 L F
.67471 .33612 m .67183 .33241 L .67786 .3304 L F
.31083 .33612 m .31288 .33039 L .31647 .33411 L F
.31083 .33612 m .30723 .33241 L .31288 .33039 L F
.22729 .33596 m .22908 .33023 L .23284 .33395 L .664 .741 .908 r
F
.22729 .33596 m .22352 .33225 L .22908 .33023 L F
.77315 .33597 m .7766 .33023 L .77928 .33395 L .664 .742 .908 r
F
.77315 .33597 m .77046 .33226 L .7766 .33023 L F
.54707 .37554 m .54384 .35847 L .54968 .34851 L .713 .528 .638 r
F
.54968 .34851 m .55269 .37057 L .5557 .36003 L .739 .395 .399 r
F
.54968 .34851 m .54664 .35896 L .55269 .37057 L F
.54384 .35847 m .54664 .35896 L .54968 .34851 L 0 .03 .583 r
F
.57466 .40689 m .57142 .39273 L .57732 .39011 L .619 .484 .675 r
F
.56899 .42714 m .57142 .39273 L .57466 .40689 L .865 .651 .611 r
F
.56899 .42714 m .56578 .41616 L .57142 .39273 L F
.14373 .3358 m .14527 .33008 L .14919 .33379 L .663 .741 .908 r
F
.14373 .3358 m .1398 .33209 L .14527 .33008 L F
.3257 .33581 m .32779 .33008 L .33135 .3338 L F
.3257 .33581 m .32212 .3321 L .32779 .33008 L F
.8716 .33581 m .87535 .33007 L .87784 .33379 L .664 .742 .908 r
F
.8716 .33581 m .86911 .3321 L .87535 .33007 L F
.68964 .33581 m .69283 .33008 L .69568 .3338 L .665 .742 .908 r
F
.68964 .33581 m .68678 .33211 L .69283 .33008 L F
.24214 .33565 m .24398 .32992 L .24771 .33364 L .664 .741 .908 r
F
.24214 .33565 m .2384 .33194 L .24398 .32992 L F
.78809 .33565 m .79159 .32992 L .79424 .33364 L F
.78809 .33565 m .78543 .33194 L .79159 .32992 L F
.15857 .33549 m .16015 .32976 L .16405 .33348 L .663 .741 .908 r
F
.15857 .33549 m .15467 .33178 L .16015 .32976 L F
.34057 .33549 m .33702 .33178 L .3427 .32977 L F
.70456 .33549 m .70781 .32977 L .71063 .33349 L F
.70456 .33549 m .70174 .33178 L .70781 .32977 L F
.257 .33534 m .25888 .32961 L .26258 .33333 L F
.257 .33534 m .25329 .33163 L .25888 .32961 L F
.80304 .33534 m .80658 .32961 L .8092 .33333 L .664 .741 .908 r
F
.80304 .33534 m .8004 .33163 L .80658 .32961 L F
.48138 .38405 m .48392 .38058 L .48738 .36802 L 0 0 0 r
F
.17341 .33519 m .17504 .32945 L .17891 .33317 L .664 .741 .908 r
F
.17341 .33519 m .16954 .33147 L .17504 .32945 L F
.7195 .33519 m .72279 .32947 L .72558 .33318 L .663 .741 .908 r
F
.7195 .33519 m .7167 .33149 L .72279 .32947 L F
.81799 .33503 m .82158 .3293 L .82417 .33302 L F
.81799 .33503 m .81538 .33132 L .82158 .3293 L F
.27186 .33504 m .27379 .3293 L .27746 .33303 L .664 .741 .908 r
F
.27186 .33504 m .26818 .33133 L .27379 .3293 L F
.18826 .33488 m .18994 .32914 L .19378 .33287 L F
.18826 .33488 m .18442 .33116 L .18994 .32914 L F
.73444 .33488 m .73777 .32914 L .74053 .33287 L F
.73444 .33488 m .73167 .33116 L .73777 .32914 L F
.50591 .4092 m .50272 .39998 L .50863 .38806 L .81 .639 .671 r
F
.50272 .39998 m .50538 .39147 L .50863 .38806 L .344 .296 .66 r
F
.83294 .33472 m .83658 .32899 L .83914 .33271 L .664 .741 .908 r
F
.83294 .33472 m .83037 .33101 L .83658 .32899 L F
.28673 .33472 m .2887 .32898 L .29234 .33271 L F
.28673 .33472 m .28307 .33101 L .2887 .32898 L F
.55672 .41405 m .55922 .38023 L .56252 .39988 L .913 .698 .598 r
F
.55672 .41405 m .55355 .40687 L .55922 .38023 L F
.45755 .37085 m .45923 .40514 L .46276 .39963 L .75 .437 .454 r
F
.45755 .37085 m .45379 .38731 L .45923 .40514 L F
.74938 .33456 m .75276 .32883 L .75549 .33256 L .663 .741 .908 r
F
.74938 .33456 m .74664 .33085 L .75276 .32883 L F
.20312 .33456 m .20483 .32883 L .20865 .33255 L F
.20312 .33456 m .1993 .33085 L .20483 .32883 L F
.3016 .33441 m .30361 .32868 L .30723 .33241 L F
.3016 .33441 m .29797 .3307 L .30361 .32868 L F
.84791 .33442 m .85159 .32868 L .85412 .3324 L .664 .741 .908 r
F
.84791 .33442 m .84536 .3307 L .85159 .32868 L F
.6658 .33442 m .66893 .32869 L .67183 .33241 L .663 .741 .908 r
F
.6658 .33442 m .6629 .3307 L .66893 .32869 L F
.21798 .33426 m .21974 .32853 L .22352 .33225 L F
.21798 .33426 m .21419 .33054 L .21974 .32853 L F
.76433 .33427 m .76776 .32853 L .77046 .33226 L .664 .741 .908 r
F
.76433 .33427 m .76162 .33055 L .76776 .32853 L F
.58056 .4036 m .57732 .39011 L .5836 .4075 L 0 0 .457 r
F
.57466 .40689 m .57732 .39011 L .58056 .4036 L .619 .484 .675 r
F
.86287 .3341 m .8666 .32837 L .86911 .3321 L .664 .742 .908 r
F
.86287 .3341 m .86035 .33039 L .8666 .32837 L F
.13434 .33411 m .13585 .32836 L .1398 .33209 L .664 .741 .908 r
F
.13434 .33411 m .13039 .33039 L .13585 .32836 L F
.31647 .33411 m .31854 .32837 L .32212 .3321 L F
.31647 .33411 m .31288 .33039 L .31854 .32837 L F
.68074 .33413 m .68391 .32839 L .68678 .33211 L .663 .74 .907 r
F
.68074 .33413 m .67786 .3304 L .68391 .32839 L F
.68734 .52069 m .69123 .52961 L .69453 .54148 L .812 .328 .025 r
F
.68734 .52069 m .68462 .52029 L .69095 .52922 L F
.68734 .52069 m .69095 .52922 L .69115 .52941 L F
.69115 .52941 m .69095 .52922 L .69123 .52961 L F
.68462 .52029 m .68813 .52161 L .69123 .52961 L .256 0 0 r
F
.68462 .52029 m .68191 .52045 L .68813 .52161 L F
.68232 .52053 m .68504 .51393 L .68813 .52161 L .864 .955 .867 r
F
.68191 .52045 m .68202 .52022 L .68232 .52053 L F
.68202 .52022 m .68504 .51393 L .68232 .52053 L F
.23284 .33395 m .23465 .32821 L .2384 .33194 L .664 .741 .908 r
F
.23284 .33395 m .22908 .33023 L .23465 .32821 L F
.77928 .33395 m .78275 .32821 L .78543 .33194 L F
.77928 .33395 m .7766 .33023 L .78275 .32821 L F
.14919 .33379 m .15075 .32805 L .15467 .33178 L F
.14919 .33379 m .14527 .33008 L .15075 .32805 L F
.87784 .33379 m .88161 .32806 L .88409 .33179 L .663 .741 .908 r
F
.87784 .33379 m .87535 .33007 L .88161 .32806 L F
.69568 .3338 m .6989 .32805 L .70174 .33178 L .664 .741 .908 r
F
.69568 .3338 m .69283 .33008 L .6989 .32805 L F
.33135 .3338 m .33346 .32805 L .33702 .33178 L .664 .742 .908 r
F
.33135 .3338 m .32779 .33008 L .33346 .32805 L F
.24771 .33364 m .24956 .3279 L .25329 .33163 L .663 .741 .908 r
F
.24771 .33364 m .24398 .32992 L .24956 .3279 L F
.79424 .33364 m .79776 .3279 L .8004 .33163 L .664 .741 .908 r
F
.79424 .33364 m .79159 .32992 L .79776 .3279 L F
.58101 .42642 m .58376 .41469 L .58691 .42281 L .69 .598 .748 r
F
.58101 .42642 m .57786 .41841 L .58376 .41469 L F
.57517 .43404 m .57786 .41841 L .58101 .42642 L .962 .833 .669 r
F
.16405 .33348 m .16565 .32775 L .16954 .33147 L .663 .741 .908 r
F
.16405 .33348 m .16015 .32976 L .16565 .32775 L F
.71063 .33349 m .71389 .32775 L .7167 .33149 L F
.71063 .33349 m .70781 .32977 L .71389 .32775 L F
.54384 .35847 m .54066 .34813 L .54664 .35896 L 0 .03 .583 r
F
.53808 .39005 m .54066 .34813 L .54384 .35847 L .843 .619 .599 r
F
.53808 .39005 m .53486 .37484 L .54066 .34813 L F
.54128 .39864 m .54384 .35847 L .54707 .37554 L .911 .685 .584 r
F
.54128 .39864 m .53808 .39005 L .54384 .35847 L F
.54066 .34813 m .5436 .37563 L .54664 .35896 L .927 .569 .327 r
F
.53486 .37484 m .53752 .34864 L .54066 .34813 L .69 .51 .639 r
F
.54066 .34813 m .53752 .34864 L .5436 .37563 L .927 .569 .327 r
F
.57786 .41841 m .57466 .40689 L .58056 .4036 L .648 .525 .7 r
F
.57212 .43283 m .57466 .40689 L .57786 .41841 L .912 .718 .626 r
F
.57212 .43283 m .56899 .42714 L .57466 .40689 L F
.8092 .33333 m .81277 .3276 L .81538 .33132 L .663 .741 .908 r
F
.8092 .33333 m .80658 .32961 L .81277 .3276 L F
.26258 .33333 m .26448 .32759 L .26818 .33133 L F
.26258 .33333 m .25888 .32961 L .26448 .32759 L F
.17891 .33317 m .18055 .32743 L .18442 .33116 L .664 .741 .908 r
F
.17891 .33317 m .17504 .32945 L .18055 .32743 L F
.72558 .33318 m .72889 .32744 L .73167 .33116 L .664 .742 .908 r
F
.72558 .33318 m .72279 .32947 L .72889 .32744 L F
.69788 .55445 m .69453 .54148 L .69917 .51172 L .873 .644 .59 r
F
.82417 .33302 m .82778 .32728 L .83037 .33101 L .664 .742 .908 r
F
.82417 .33302 m .82158 .3293 L .82778 .32728 L F
.27746 .33303 m .27941 .32728 L .28307 .33101 L .664 .741 .908 r
F
.27746 .33303 m .27379 .3293 L .27941 .32728 L F
.54752 .39407 m .55032 .3933 L .55355 .40687 L 0 0 0 r
F
.54752 .39407 m .54443 .39943 L .55032 .3933 L F
.74053 .33287 m .74389 .32712 L .74664 .33085 L .664 .741 .908 r
F
.74053 .33287 m .73777 .32914 L .74389 .32712 L F
.19378 .33287 m .19547 .32712 L .1993 .33085 L F
.19378 .33287 m .18994 .32914 L .19547 .32712 L F
.65125 .42891 m .64795 .41764 L .651 .33791 L .949 .683 .499 r
F
.651 .33791 m .65395 .32901 L .65688 .33274 L .78 .752 .827 r
F
.651 .33791 m .64804 .3337 L .65395 .32901 L F
.64795 .41764 m .64804 .3337 L .651 .33791 L .944 .681 .507 r
F
.29234 .33271 m .29433 .32697 L .29797 .3307 L .663 .741 .908 r
F
.29234 .33271 m .2887 .32898 L .29433 .32697 L F
.83914 .33271 m .8428 .32697 L .84536 .3307 L F
.83914 .33271 m .83658 .32899 L .8428 .32697 L F
.65688 .33274 m .65998 .32697 L .6629 .3307 L .664 .741 .907 r
F
.65688 .33274 m .65395 .32901 L .65998 .32697 L F
.20865 .33255 m .21038 .32681 L .21419 .33054 L .663 .741 .908 r
F
.20865 .33255 m .20483 .32883 L .21038 .32681 L F
.75549 .33256 m .75889 .32681 L .76162 .33055 L .664 .741 .908 r
F
.75549 .33256 m .75276 .32883 L .75889 .32681 L F
.58691 .42281 m .58376 .41469 L .58997 .42575 L 0 0 .529 r
F
.60792 .41887 m .60465 .40622 L .60991 .37613 L .877 .648 .588 r
F
.60991 .37613 m .61434 .42381 L .61754 .43236 L .895 .564 .414 r
F
.60465 .40622 m .60721 .38464 L .60991 .37613 L .667 .506 .656 r
F
.60991 .37613 m .60721 .38464 L .61434 .42381 L .895 .564 .414 r
F
.57517 .43404 m .57212 .43283 L .57786 .41841 L .962 .833 .669 r
F
.57786 .41841 m .58056 .4036 L .58376 .41469 L .648 .525 .7 r
F
.51714 .38625 m .51394 .37941 L .51987 .356 L .907 .701 .612 r
F
.51987 .356 m .51665 .36057 L .52253 .38478 L .884 .534 .379 r
F
.85412 .3324 m .85783 .32666 L .86035 .33039 L .663 .741 .908 r
F
.85412 .3324 m .85159 .32868 L .85783 .32666 L F
.30723 .33241 m .30927 .32666 L .31288 .33039 L F
.30723 .33241 m .30361 .32868 L .30927 .32666 L F
.67183 .33241 m .67497 .32666 L .67786 .3304 L .664 .742 .908 r
F
.67183 .33241 m .66893 .32869 L .67497 .32666 L F
.22352 .33225 m .2253 .3265 L .22908 .33023 L .664 .741 .908 r
F
.22352 .33225 m .21974 .32853 L .2253 .3265 L F
.77046 .33226 m .77391 .3265 L .7766 .33023 L .664 .741 .907 r
F
.77046 .33226 m .76776 .32853 L .77391 .3265 L F
.58376 .41469 m .58056 .4036 L .58683 .41908 L 0 0 .448 r
F
.58056 .4036 m .5836 .4075 L .58683 .41908 L 0 0 .457 r
F
.1398 .33209 m .14132 .32634 L .14527 .33008 L .663 .741 .908 r
F
.1398 .33209 m .13585 .32836 L .14132 .32634 L F
.32212 .3321 m .32421 .32635 L .32779 .33008 L .664 .741 .908 r
F
.32212 .3321 m .31854 .32837 L .32421 .32635 L F
.86911 .3321 m .87285 .32634 L .87535 .33007 L F
.86911 .3321 m .8666 .32837 L .87285 .32634 L F
.68678 .33211 m .68997 .32635 L .69283 .33008 L .664 .742 .908 r
F
.68678 .33211 m .68391 .32839 L .68997 .32635 L F
.2384 .33194 m .24023 .32618 L .24398 .32992 L .664 .741 .908 r
F
.2384 .33194 m .23465 .32821 L .24023 .32618 L F
.78543 .33194 m .78892 .32619 L .79159 .32992 L F
.78543 .33194 m .78275 .32821 L .78892 .32619 L F
.15467 .33178 m .15624 .32603 L .16015 .32976 L .663 .741 .908 r
F
.15467 .33178 m .15075 .32805 L .15624 .32603 L F
.33702 .33178 m .33915 .32603 L .3427 .32977 L F
.33702 .33178 m .33346 .32805 L .33915 .32603 L F
.70174 .33178 m .70498 .32604 L .70781 .32977 L F
.70174 .33178 m .6989 .32805 L .70498 .32604 L F
.47556 .38496 m .47793 .39191 L .48138 .38405 L .419 .054 .236 r
F
.47556 .38496 m .47208 .39324 L .47793 .39191 L F
.25329 .33163 m .25516 .32588 L .25888 .32961 L .663 .741 .908 r
F
.25329 .33163 m .24956 .3279 L .25516 .32588 L F
.8004 .33163 m .80394 .32588 L .80658 .32961 L F
.8004 .33163 m .79776 .3279 L .80394 .32588 L F
.16954 .33147 m .17116 .32572 L .17504 .32945 L .664 .741 .908 r
F
.16954 .33147 m .16565 .32775 L .17116 .32572 L F
.7167 .33149 m .71999 .32574 L .72279 .32947 L .663 .741 .908 r
F
.7167 .33149 m .71389 .32775 L .71999 .32574 L F
.49041 .35846 m .49098 .35717 L .4926 .35353 L .648 .764 .29 r
F
.48661 .36697 m .48937 .34662 L .4926 .35353 L .963 .838 .418 r
F
.4926 .35353 m .48937 .34662 L .49496 .36866 L .909 .549 .094 r
F
.495 .36877 m .49496 .36866 L .49501 .36886 L F
.4926 .35353 m .49496 .36866 L .495 .36877 L F
.48937 .34662 m .49186 .35217 L .49225 .35427 L .581 .095 .066 r
F
.48937 .34662 m .49225 .35427 L .49165 .35563 L F
.48661 .36697 m .4849 .37158 L .48937 .34662 L .963 .838 .418 r
F
.4849 .37158 m .48315 .37632 L .48566 .36434 L F
.4849 .37158 m .48566 .36434 L .48937 .34662 L F
.48602 .3495 m .48693 .34482 L .48752 .34657 L .903 .846 .391 r
F
.48315 .37632 m .48602 .3495 L .48937 .34662 L .994 .808 .549 r
F
.48937 .34662 m .48602 .3495 L .49186 .35217 L .581 .095 .066 r
F
.48716 .35002 m .48752 .34657 L .48896 .35085 L .903 .846 .391 r
F
.48602 .3495 m .48752 .34657 L .48716 .35002 L F
.48896 .35085 m .48871 .33573 L .49186 .35217 L F
.48693 .34482 m .48871 .33573 L .48896 .35085 L F
.49165 .35563 m .49225 .35427 L .49501 .36886 L .581 .095 .066 r
F
.49 .35938 m .48661 .36697 L .49098 .35717 L .648 .764 .29 r
F
.49 .35938 m .49098 .35717 L .49041 .35846 L F
.48392 .38058 m .48661 .36697 L .49 .35938 L .896 .842 .382 r
F
.81538 .33132 m .81897 .32557 L .82158 .3293 L .664 .742 .908 r
F
.81538 .33132 m .81277 .3276 L .81897 .32557 L F
.26818 .33133 m .2701 .32556 L .27379 .3293 L .664 .741 .908 r
F
.26818 .33133 m .26448 .32759 L .2701 .32556 L F
.59461 .35663 m .59136 .34378 L .59838 .40669 L .965 .657 .254 r
F
.59136 .34378 m .59589 .41234 L .59891 .41142 L .971 .657 .335 r
F
.59136 .34378 m .58824 .33718 L .59589 .41234 L F
.58824 .33718 m .58528 .33862 L .59269 .40533 L .952 .632 .384 r
F
.59 .3814 m .59104 .3245 L .59412 .32872 L .86 .613 .564 r
F
.58932 .39 m .58958 .38014 L .59 .3814 L F
.58958 .38014 m .59104 .3245 L .59 .3814 L F
.59859 .40731 m .59838 .40669 L .59891 .41142 L .965 .657 .254 r
F
.59461 .35663 m .59838 .40669 L .59859 .40731 L F
.42535 .41895 m .42125 .4381 L .42723 .43076 L .331 .062 .347 r
F
.73167 .33116 m .735 .32541 L .73777 .32914 L .664 .742 .908 r
F
.73167 .33116 m .72889 .32744 L .735 .32541 L F
.18442 .33116 m .18608 .32541 L .18994 .32914 L .664 .741 .908 r
F
.18442 .33116 m .18055 .32743 L .18608 .32541 L F
.28307 .33101 m .28504 .32525 L .2887 .32898 L F
.28307 .33101 m .27941 .32728 L .28504 .32525 L F
.83037 .33101 m .834 .32525 L .83658 .32899 L F
.83037 .33101 m .82778 .32728 L .834 .32525 L F
.74664 .33085 m .75002 .3251 L .75276 .32883 L .663 .741 .908 r
F
.74664 .33085 m .74389 .32712 L .75002 .3251 L F
.1993 .33085 m .20101 .32509 L .20483 .32883 L F
.1993 .33085 m .19547 .32712 L .20101 .32509 L F
.29797 .3307 m .29998 .32494 L .30361 .32868 L F
.29797 .3307 m .29433 .32697 L .29998 .32494 L F
.84536 .3307 m .84904 .32494 L .85159 .32868 L F
.84536 .3307 m .8428 .32697 L .84904 .32494 L F
.6629 .3307 m .66602 .32496 L .66893 .32869 L F
.6629 .3307 m .65998 .32697 L .66602 .32496 L F
.21419 .33054 m .21594 .32479 L .21974 .32853 L F
.21419 .33054 m .21038 .32681 L .21594 .32479 L F
.76162 .33055 m .76504 .32478 L .76776 .32853 L .664 .741 .908 r
F
.76162 .33055 m .75889 .32681 L .76504 .32478 L F
.13039 .33039 m .13189 .32462 L .13585 .32836 L F
.13039 .33039 m .12642 .32666 L .13189 .32462 L F
.86035 .33039 m .86408 .32463 L .8666 .32837 L .664 .742 .908 r
F
.86035 .33039 m .85783 .32666 L .86408 .32463 L F
.31288 .33039 m .31493 .32464 L .31854 .32837 L .663 .741 .908 r
F
.31288 .33039 m .30927 .32666 L .31493 .32464 L F
.67786 .3304 m .68103 .32464 L .68391 .32839 L F
.67786 .3304 m .67497 .32666 L .68103 .32464 L F
.7766 .33023 m .78007 .32447 L .78275 .32821 L F
.7766 .33023 m .77391 .3265 L .78007 .32447 L F
.22908 .33023 m .23088 .32447 L .23465 .32821 L .664 .741 .908 r
F
.22908 .33023 m .2253 .3265 L .23088 .32447 L F
.43263 .35871 m .42971 .33945 L .43211 .3694 L .938 .662 .194 r
F
.42971 .33945 m .43046 .39017 L .43394 .39235 L .962 .651 .387 r
F
.42971 .33945 m .42634 .3354 L .43046 .39017 L F
.42887 .36372 m .4307 .33958 L .43452 .32889 L .642 .453 .612 r
F
.42744 .37249 m .42839 .36289 L .42887 .36372 L F
.42839 .36289 m .4307 .33958 L .42887 .36372 L F
.43311 .37116 m .43211 .3694 L .43394 .39235 L .938 .662 .194 r
F
.43263 .35871 m .43211 .3694 L .43311 .37116 L F
.53211 .37436 m .53486 .37484 L .53808 .39005 L 0 0 .119 r
F
.53211 .37436 m .52896 .38586 L .53486 .37484 L F
.87535 .33007 m .87913 .32432 L .88161 .32806 L .663 .741 .908 r
F
.87535 .33007 m .87285 .32634 L .87913 .32432 L F
.14527 .33008 m .14681 .32431 L .15075 .32805 L .664 .741 .908 r
F
.14527 .33008 m .14132 .32634 L .14681 .32431 L F
.69283 .33008 m .69605 .32431 L .6989 .32805 L .664 .742 .908 r
F
.69283 .33008 m .68997 .32635 L .69605 .32431 L F
.32779 .33008 m .32989 .32431 L .33346 .32805 L F
.32779 .33008 m .32421 .32635 L .32989 .32431 L F
.66589 .48371 m .66302 .48111 L .67046 .51127 L .944 .579 .242 r
F
.24398 .32992 m .24582 .32416 L .24956 .3279 L .663 .741 .908 r
F
.24398 .32992 m .24023 .32618 L .24582 .32416 L F
.79159 .32992 m .7951 .32416 L .79776 .3279 L .664 .741 .908 r
F
.79159 .32992 m .78892 .32619 L .7951 .32416 L F
.16015 .32976 m .16174 .324 L .16565 .32775 L .663 .741 .908 r
F
.16015 .32976 m .15624 .32603 L .16174 .324 L F
.70781 .32977 m .71107 .32401 L .71389 .32775 L F
.70781 .32977 m .70498 .32604 L .71107 .32401 L F
.80658 .32961 m .81014 .32386 L .81277 .3276 L F
.80658 .32961 m .80394 .32588 L .81014 .32386 L F
.25888 .32961 m .26077 .32385 L .26448 .32759 L F
.25888 .32961 m .25516 .32588 L .26077 .32385 L F
.59794 .37311 m .59461 .35663 L .60176 .40464 L .876 .592 .07 r
F
.59461 .35663 m .59891 .41142 L .60176 .40464 L .965 .657 .254 r
F
.17504 .32945 m .17668 .32369 L .18055 .32743 L .664 .741 .908 r
F
.17504 .32945 m .17116 .32572 L .17668 .32369 L F
.72279 .32947 m .7261 .3237 L .72889 .32744 L .664 .742 .908 r
F
.72279 .32947 m .71999 .32574 L .7261 .3237 L F
.64795 .41764 m .64464 .40604 L .64804 .3337 L .944 .681 .507 r
F
.64804 .3337 m .65101 .32527 L .65395 .32901 L .765 .749 .838 r
F
.64804 .3337 m .64507 .3295 L .65101 .32527 L F
.64464 .40604 m .64507 .3295 L .64804 .3337 L .939 .679 .516 r
F
.27379 .3293 m .27572 .32353 L .27941 .32728 L .664 .741 .908 r
F
.27379 .3293 m .2701 .32556 L .27572 .32353 L F
.82158 .3293 m .82519 .32353 L .82778 .32728 L .664 .742 .908 r
F
.82158 .3293 m .81897 .32557 L .82519 .32353 L F
.46643 .38466 m .46868 .39462 L .47208 .39324 L .358 .065 .324 r
F
.46643 .38466 m .46276 .39963 L .46868 .39462 L F
.73777 .32914 m .74113 .32337 L .74389 .32712 L .664 .741 .908 r
F
.73777 .32914 m .735 .32541 L .74113 .32337 L F
.18994 .32914 m .19162 .32337 L .19547 .32712 L F
.18994 .32914 m .18608 .32541 L .19162 .32337 L F
.55982 .41509 m .56252 .39988 L .56578 .41616 L .963 .839 .672 r
F
.55982 .41509 m .55672 .41405 L .56252 .39988 L F
.48138 .38405 m .47793 .39191 L .4837 .381 L 0 0 0 r
F
.48138 .38405 m .4837 .381 L .48381 .38073 L F
.47793 .39191 m .48046 .38959 L .48392 .38058 L .514 .912 .906 r
F
.48108 .38731 m .48315 .37632 L .48661 .36697 L .907 .802 .732 r
F
.48046 .38959 m .48077 .38805 L .48108 .38731 L F
.48077 .38805 m .48315 .37632 L .48108 .38731 L F
.48381 .38073 m .4837 .381 L .48392 .38058 L 0 0 0 r
F
.2887 .32898 m .29068 .32322 L .29433 .32697 L .663 .741 .908 r
F
.2887 .32898 m .28504 .32525 L .29068 .32322 L F
.83658 .32899 m .84024 .32322 L .8428 .32697 L F
.83658 .32899 m .834 .32525 L .84024 .32322 L F
.65395 .32901 m .65705 .32323 L .65998 .32697 L .664 .741 .907 r
F
.65395 .32901 m .65101 .32527 L .65705 .32323 L F
.54443 .39943 m .54707 .37554 L .55032 .3933 L .976 .793 .593 r
F
.54443 .39943 m .54128 .39864 L .54707 .37554 L F
.20483 .32883 m .20656 .32306 L .21038 .32681 L .663 .741 .908 r
F
.20483 .32883 m .20101 .32509 L .20656 .32306 L F
.75276 .32883 m .75616 .32307 L .75889 .32681 L F
.75276 .32883 m .75002 .3251 L .75616 .32307 L F
.42125 .4381 m .42326 .44541 L .42723 .43076 L .183 0 .278 r
F
.42723 .43076 m .42326 .44541 L .43062 .39255 L .992 .805 .428 r
F
.42326 .44541 m .42656 .41114 L .43062 .39255 L .997 .798 .517 r
F
.85159 .32868 m .85529 .32291 L .85783 .32666 L .664 .741 .908 r
F
.85159 .32868 m .84904 .32494 L .85529 .32291 L F
.30361 .32868 m .30564 .32292 L .30927 .32666 L .663 .741 .908 r
F
.30361 .32868 m .29998 .32494 L .30564 .32292 L F
.66893 .32869 m .67207 .32292 L .67497 .32666 L .664 .741 .908 r
F
.66893 .32869 m .66602 .32496 L .67207 .32292 L F
.76776 .32853 m .7712 .32275 L .77391 .3265 L .663 .741 .908 r
F
.76776 .32853 m .76504 .32478 L .7712 .32275 L F
.21974 .32853 m .22151 .32276 L .2253 .3265 L .664 .741 .908 r
F
.21974 .32853 m .21594 .32479 L .22151 .32276 L F
.13585 .32836 m .13737 .32259 L .14132 .32634 L .663 .741 .908 r
F
.13585 .32836 m .13189 .32462 L .13737 .32259 L F
.8666 .32837 m .87035 .32259 L .87285 .32634 L .664 .741 .908 r
F
.8666 .32837 m .86408 .32463 L .87035 .32259 L F
.31854 .32837 m .32061 .3226 L .32421 .32635 L .664 .742 .908 r
F
.31854 .32837 m .31493 .32464 L .32061 .3226 L F
.68391 .32839 m .6871 .3226 L .68997 .32635 L .664 .741 .907 r
F
.68391 .32839 m .68103 .32464 L .6871 .3226 L F
.78275 .32821 m .78625 .32244 L .78892 .32619 L .664 .741 .908 r
F
.78275 .32821 m .78007 .32447 L .78625 .32244 L F
.23465 .32821 m .23647 .32244 L .24023 .32618 L F
.23465 .32821 m .23088 .32447 L .23647 .32244 L F
.15075 .32805 m .15231 .32228 L .15624 .32603 L .663 .741 .908 r
F
.15075 .32805 m .14681 .32431 L .15231 .32228 L F
.33346 .32805 m .33558 .32229 L .33915 .32603 L F
.33346 .32805 m .32989 .32431 L .33558 .32229 L F
.6989 .32805 m .70214 .32229 L .70498 .32604 L F
.6989 .32805 m .69605 .32431 L .70214 .32229 L F
.79776 .3279 m .8013 .32213 L .80394 .32588 L F
.79776 .3279 m .7951 .32416 L .8013 .32213 L F
.24956 .3279 m .25143 .32213 L .25516 .32588 L F
.24956 .3279 m .24582 .32416 L .25143 .32213 L F
.16565 .32775 m .16726 .32197 L .17116 .32572 L .664 .741 .908 r
F
.16565 .32775 m .16174 .324 L .16726 .32197 L F
.71389 .32775 m .71717 .32198 L .71999 .32574 L .663 .741 .908 r
F
.71389 .32775 m .71107 .32401 L .71717 .32198 L F
.53486 .37484 m .53164 .35706 L .53752 .34864 L .69 .51 .639 r
F
.53164 .35706 m .53439 .35915 L .53752 .34864 L 0 0 .479 r
F
.53164 .35706 m .52844 .34322 L .53439 .35915 L F
.52575 .39144 m .52844 .34322 L .53164 .35706 L .939 .704 .555 r
F
.52575 .39144 m .52253 .38478 L .52844 .34322 L F
.52896 .38586 m .53164 .35706 L .53486 .37484 L 1 .815 .484 r
F
.52896 .38586 m .52575 .39144 L .53036 .36456 L F
.5309 .36502 m .53036 .36456 L .53164 .35706 L F
.52896 .38586 m .53036 .36456 L .5309 .36502 L F
.52253 .38478 m .52526 .33929 L .52844 .34322 L .819 .593 .597 r
F
.52443 .35953 m .52476 .37057 L .52801 .37904 L .722 .387 .411 r
F
.52253 .38478 m .51932 .36607 L .52526 .33929 L .819 .593 .597 r
F
.51932 .36607 m .52205 .34653 L .52526 .33929 L .5 .362 .624 r
F
.52205 .34653 m .52342 .35867 L .52443 .35953 L .722 .387 .411 r
F
.52342 .35867 m .52476 .37057 L .52443 .35953 L F
.52844 .34322 m .53123 .37275 L .53439 .35915 L .955 .609 .283 r
F
.52844 .34322 m .52526 .33929 L .53123 .37275 L F
.26448 .32759 m .26639 .32181 L .2701 .32556 L .664 .741 .908 r
F
.26448 .32759 m .26077 .32385 L .26639 .32181 L F
.81277 .3276 m .81636 .32182 L .81897 .32557 L .664 .742 .908 r
F
.81277 .3276 m .81014 .32386 L .81636 .32182 L F
.18055 .32743 m .18221 .32166 L .18608 .32541 L .664 .741 .908 r
F
.18055 .32743 m .17668 .32369 L .18221 .32166 L F
.72889 .32744 m .73222 .32166 L .735 .32541 L .664 .742 .908 r
F
.72889 .32744 m .7261 .3237 L .73222 .32166 L F
.61574 .36096 m .61824 .33868 L .62144 .34885 L .703 .534 .657 r
F
.61913 .37759 m .62144 .34885 L .62472 .36183 L .739 .547 .634 r
F
.62255 .39471 m .61913 .37759 L .62472 .36183 L .767 .563 .623 r
F
.62472 .36183 m .62144 .34885 L .62645 .37312 L .819 .525 0 r
F
.61913 .37759 m .61574 .36096 L .62144 .34885 L .739 .547 .634 r
F
.62709 .37571 m .62645 .37312 L .62759 .37861 L .819 .525 0 r
F
.62472 .36183 m .62645 .37312 L .62709 .37571 L F
.62472 .36183 m .62759 .37861 L .62823 .38143 L F
.62144 .34885 m .62517 .3665 L .62862 .3836 L .821 .501 0 r
F
.62144 .34885 m .61824 .33868 L .62517 .3665 L F
.61824 .33868 m .61926 .34208 L .62113 .35026 L .809 .43 0 r
F
.61926 .34208 m .62177 .35043 L .62113 .35026 L F
.61574 .36096 m .61241 .34636 L .61824 .33868 L .703 .534 .657 r
F
.61241 .34636 m .61516 .33246 L .61824 .33868 L .643 .529 .709 r
F
.61824 .33868 m .61516 .33246 L .62014 .346 L .809 .43 0 r
F
.62113 .3483 m .62014 .346 L .62177 .35043 L F
.61824 .33868 m .62014 .346 L .62113 .3483 L F
.61516 .33246 m .61696 .33463 L .619 .34292 L .6 .036 0 r
F
.61696 .33463 m .61843 .3364 L .619 .34292 L F
.61241 .34636 m .6092 .33542 L .61516 .33246 L .643 .529 .709 r
F
.61415 .33296 m .61221 .33122 L .61516 .33246 L .425 .529 .86 r
F
.6092 .33542 m .61116 .33268 L .61415 .33296 L F
.6092 .33542 m .60612 .32977 L .61221 .33122 L F
.611 .33093 m .60939 .33567 L .61221 .33122 L .681 .155 0 r
F
.60612 .32977 m .60939 .33567 L .611 .33093 L F
.60721 .38464 m .61103 .41129 L .61434 .42381 L .788 .444 .405 r
F
.60465 .40622 m .60131 .39045 L .60711 .38473 L .667 .506 .656 r
F
.60718 .38482 m .60711 .38473 L .60721 .38464 L F
.60465 .40622 m .60711 .38473 L .60718 .38482 L F
.60131 .39045 m .60451 .39481 L .60721 .38464 L 0 0 .445 r
F
.60131 .39045 m .59794 .37311 L .60451 .39481 L F
.59833 .37439 m .60176 .40464 L .60451 .39481 L .876 .592 .07 r
F
.59794 .37311 m .59806 .37407 L .59833 .37439 L F
.59806 .37407 m .60176 .40464 L .59833 .37439 L F
.60721 .38464 m .60451 .39481 L .61103 .41129 L .788 .444 .405 r
F
.60764 .39508 m .6092 .33542 L .61241 .34636 L .867 .623 .567 r
F
.60764 .39508 m .60419 .37633 L .6092 .33542 L F
.60419 .37633 m .60612 .32977 L .6092 .33542 L .82 .592 .592 r
F
.60419 .37633 m .60074 .35714 L .60612 .32977 L F
.60074 .35714 m .60319 .33069 L .60612 .32977 L .711 .528 .64 r
F
.6088 .3352 m .60669 .34582 L .60939 .33567 L .699 .324 .335 r
F
.60319 .33069 m .60669 .34582 L .6088 .3352 L F
.60074 .35714 m .59737 .34032 L .60319 .33069 L .711 .528 .64 r
F
.60645 .34553 m .60408 .36073 L .60669 .34582 L .673 .343 .407 r
F
.60041 .33851 m .60408 .36073 L .60645 .34553 L F
.59891 .41142 m .60074 .35714 L .60419 .37633 L .986 .746 .484 r
F
.59589 .41234 m .59737 .34032 L .60074 .35714 L .956 .701 .509 r
F
.59891 .41142 m .59589 .41234 L .60074 .35714 L .986 .746 .484 r
F
.59773 .35226 m .60149 .37849 L .60408 .36073 L .66 .345 .428 r
F
.60408 .36073 m .60149 .37849 L .60168 .37617 L .928 .755 .274 r
F
.60612 .32977 m .60319 .33069 L .60496 .33211 L .681 .155 0 r
F
.60755 .33235 m .60496 .33211 L .60939 .33567 L F
.60612 .32977 m .60496 .33211 L .60755 .33235 L F
.60319 .33069 m .60041 .33851 L .60669 .34582 L .699 .324 .335 r
F
.60041 .33851 m .59773 .35226 L .60408 .36073 L .673 .343 .407 r
F
.60408 .36073 m .60168 .37617 L .60437 .34332 L .928 .755 .274 r
F
.60495 .3417 m .60437 .34332 L .60553 .32916 L F
.60408 .36073 m .60437 .34332 L .60495 .3417 L F
.60451 .39481 m .60764 .39508 L .61103 .41129 L 0 0 .116 r
F
.60451 .39481 m .60176 .40464 L .60764 .39508 L F
.60176 .40464 m .60419 .37633 L .60764 .39508 L .99 .813 .43 r
F
.60176 .40464 m .59891 .41142 L .60419 .37633 L F
.60149 .37849 m .60346 .33006 L .60622 .32083 L .955 .76 .306 r
F
.59269 .40533 m .59412 .32872 L .59737 .34032 L .918 .661 .534 r
F
.59589 .41234 m .59269 .40533 L .59737 .34032 L .956 .701 .509 r
F
.59773 .35226 m .59509 .36953 L .60149 .37849 L .66 .345 .428 r
F
.59509 .36953 m .59884 .39632 L .60149 .37849 L .669 .351 .427 r
F
.60149 .37849 m .59884 .39632 L .60089 .36692 L .955 .76 .306 r
F
.60191 .368 m .60089 .36692 L .60346 .33006 L F
.60149 .37849 m .60089 .36692 L .60191 .368 L F
.59884 .39632 m .60079 .34455 L .60346 .33006 L .979 .767 .352 r
F
.59269 .40533 m .58932 .39 L .59412 .32872 L .918 .661 .534 r
F
.59509 .36953 m .59239 .38664 L .59884 .39632 L .669 .351 .427 r
F
.59239 .38664 m .59607 .41084 L .59884 .39632 L .72 .379 .401 r
F
.59884 .39632 m .59607 .41084 L .60079 .34455 L .979 .767 .352 r
F
.59607 .41084 m .59818 .36357 L .60079 .34455 L .996 .776 .419 r
F
.59239 .38664 m .58954 .39916 L .59607 .41084 L .72 .379 .401 r
F
.58997 .42575 m .58683 .41908 L .59276 .41444 L .732 .649 .766 r
F
.58683 .41908 m .58978 .41566 L .59276 .41444 L .178 .222 .671 r
F
.58954 .39916 m .59311 .41872 L .59607 .41084 L .85 .456 .299 r
F
.59607 .41084 m .59311 .41872 L .59818 .36357 L .996 .776 .419 r
F
.59311 .41872 m .59559 .38583 L .59818 .36357 L .981 .771 .546 r
F
.59818 .36357 m .59559 .38583 L .60235 .40761 L .743 .431 .455 r
F
.60241 .4076 m .60235 .40761 L .60243 .40788 L F
.59818 .36357 m .60235 .40761 L .60241 .4076 L F
.58954 .39916 m .58648 .40295 L .59311 .41872 L .85 .456 .299 r
F
.58648 .40295 m .58993 .41741 L .59311 .41872 L .841 .48 0 r
F
.59311 .41872 m .58993 .41741 L .59537 .38702 L .981 .771 .546 r
F
.59553 .38657 m .59537 .38702 L .59559 .38583 L F
.59311 .41872 m .59537 .38702 L .59553 .38657 L F
.58648 .40295 m .58319 .3954 L .58739 .40912 L .841 .48 0 r
F
.58024 .39458 m .57697 .38308 L .58243 .34814 L .9 .665 .574 r
F
.58243 .34814 m .57965 .36332 L .58584 .36838 L .615 .297 .408 r
F
.57965 .36332 m .58234 .34477 L .58584 .36838 L .768 .707 .17 r
F
.58251 .35621 m .57968 .37191 L .58648 .40295 L .825 .501 .44 r
F
.57968 .37191 m .58319 .3954 L .58648 .40295 L .768 .412 .38 r
F
.57352 .35284 m .57028 .33975 L .57697 .38308 L .915 .609 .126 r
F
.57697 .38308 m .57361 .36535 L .57859 .36368 L .594 .447 .651 r
F
.57938 .36528 m .57859 .36368 L .57965 .36332 L F
.57697 .38308 m .57859 .36368 L .57938 .36528 L F
.57361 .36535 m .57683 .3791 L .57965 .36332 L 0 0 .224 r
F
.57361 .36535 m .57023 .34547 L .57683 .3791 L F
.57064 .34758 m .57386 .38877 L .57683 .3791 L .936 .641 .177 r
F
.57023 .34547 m .57036 .347 L .57064 .34758 L F
.57036 .347 m .57386 .38877 L .57064 .34758 L F
.57968 .37191 m .5767 .38156 L .58319 .3954 L .768 .412 .38 r
F
.57386 .38877 m .57568 .31338 L .57893 .32473 L .973 .718 .487 r
F
.57683 .3791 m .57893 .32473 L .58234 .34477 L .995 .768 .415 r
F
.57683 .3791 m .57386 .38877 L .57875 .32693 L F
.57885 .32679 m .57875 .32693 L .57893 .32473 L F
.57683 .3791 m .57875 .32693 L .57885 .32679 L F
.57023 .34547 m .56691 .32892 L .57132 .36688 L .936 .641 .177 r
F
.56691 .32892 m .57068 .38637 L .57386 .38877 L .971 .655 .309 r
F
.56691 .32892 m .56371 .32071 L .57068 .38637 L F
.56799 .36263 m .56967 .32502 L .57261 .3137 L .729 .513 .599 r
F
.5673 .3699 m .5677 .36227 L .56799 .36263 L F
.5677 .36227 m .56967 .32502 L .56799 .36263 L F
.57208 .36786 m .57132 .36688 L .5737 .38743 L .936 .641 .177 r
F
.57023 .34547 m .57132 .36688 L .57208 .36786 L F
.57377 .38766 m .5737 .38743 L .57386 .38877 L F
.57023 .34547 m .5737 .38743 L .57377 .38766 L F
.57123 .37837 m .57261 .3137 L .57568 .31338 L .907 .653 .542 r
F
.57068 .38637 m .57092 .37724 L .57123 .37837 L F
.57092 .37724 m .57261 .3137 L .57123 .37837 L F
.57386 .38877 m .57068 .38637 L .57568 .31338 L .973 .718 .487 r
F
.57068 .38637 m .5673 .3699 L .57261 .3137 L .907 .653 .542 r
F
.57127 .33788 m .57351 .3804 L .5767 .38156 L .837 .517 .449 r
F
.56967 .32502 m .57063 .33881 L .57127 .33788 L F
.57063 .33881 m .57351 .3804 L .57127 .33788 L F
.57965 .36332 m .57683 .3791 L .58234 .34477 L .768 .707 .17 r
F
.57568 .31338 m .57968 .37191 L .58251 .35621 L .954 .627 .366 r
F
.57568 .31338 m .57261 .3137 L .57968 .37191 L F
.57261 .3137 m .5767 .38156 L .57968 .37191 L .906 .585 .428 r
F
.57261 .3137 m .56967 .32502 L .5767 .38156 L F
.5761 .34961 m .57249 .32009 L .57932 .35795 L 0 0 .349 r
F
.57249 .32009 m .57567 .32853 L .57932 .35795 L 0 0 .34 r
F
.58279 .38418 m .57932 .35795 L .58297 .38512 L 0 0 .349 r
F
.5761 .34961 m .57932 .35795 L .58279 .38418 L F
.57932 .35795 m .57567 .32853 L .57589 .33198 L .963 .681 .253 r
F
.57932 .35795 m .57589 .33198 L .57735 .35495 L F
.58319 .3954 m .5797 .37658 L .58576 .40258 L 0 0 .293 r
F
.5797 .37658 m .5761 .34961 L .58297 .38512 L 0 0 .348 r
F
.57351 .3804 m .5761 .34961 L .5797 .37658 L .808 .606 .628 r
F
.5767 .38156 m .5797 .37658 L .58319 .3954 L .754 .943 .944 r
F
.5767 .38156 m .57351 .3804 L .5797 .37658 L F
.5797 .37658 m .58297 .38512 L .58653 .40589 L 0 0 .348 r
F
.57985 .36908 m .57735 .35495 L .58439 .46533 L .963 .681 .253 r
F
.57932 .35795 m .57735 .35495 L .57985 .36908 L F
.58578 .40272 m .58576 .40258 L .58581 .40279 L 0 0 .293 r
F
.58319 .3954 m .58576 .40258 L .58578 .40272 L F
.58612 .40461 m .58581 .40279 L .58653 .40589 L F
.58319 .3954 m .58581 .40279 L .58612 .40461 L F
.58297 .38512 m .57932 .35795 L .58059 .37267 L .925 .652 .169 r
F
.58728 .40756 m .58739 .40912 L .58777 .41035 L .841 .48 0 r
F
.58648 .40295 m .58739 .40912 L .58728 .40756 L F
.58839 .41098 m .58777 .41035 L .58993 .41741 L F
.58648 .40295 m .58777 .41035 L .58839 .41098 L F
.58777 .41035 m .58653 .40589 L .58993 .41741 L 0 0 .293 r
F
.58653 .40589 m .58297 .38512 L .58567 .40265 L .774 .528 0 r
F
.58319 .3954 m .58612 .40461 L .58707 .40791 L 0 0 .293 r
F
.58319 .3954 m .58707 .40791 L .58739 .40912 L F
.58612 .40461 m .58653 .40589 L .58777 .41035 L F
.58653 .40589 m .58567 .40265 L .58795 .41749 L .774 .528 0 r
F
.58739 .40912 m .58707 .40791 L .58777 .41035 L 0 0 .293 r
F
.58301 .38662 m .58059 .37267 L .58214 .39069 L .925 .652 .169 r
F
.58319 .39435 m .58214 .39069 L .58347 .40608 L F
.58301 .38662 m .58214 .39069 L .58319 .39435 L F
.58297 .38512 m .58059 .37267 L .58301 .38662 L F
.58776 .41469 m .58795 .41749 L .59024 .43237 L .774 .528 0 r
F
.58653 .40589 m .58795 .41749 L .58776 .41469 L F
.58443 .40703 m .58347 .40608 L .5874 .45179 L .925 .652 .169 r
F
.58297 .38512 m .58347 .40608 L .58443 .40703 L F
.58993 .41741 m .59296 .40953 L .59559 .38583 L .404 .38 .719 r
F
.58993 .41741 m .58653 .40589 L .59296 .40953 L F
.58838 .40694 m .59024 .43237 L .59296 .40953 L .774 .528 0 r
F
.58653 .40589 m .58716 .41039 L .58838 .40694 L F
.58716 .41039 m .59024 .43237 L .58838 .40694 L F
.59559 .38583 m .59885 .38844 L .60243 .40788 L .017 0 .274 r
F
.59559 .38583 m .59296 .40953 L .59885 .38844 L F
.59309 .40906 m .5953 .36962 L .59885 .38844 L .881 .729 .216 r
F
.59296 .40953 m .59298 .40907 L .59309 .40906 L F
.59298 .40907 m .5953 .36962 L .59309 .40906 L F
.60243 .40788 m .59885 .38844 L .59886 .38825 L .935 .663 .5 r
F
.60466 .41644 m .60243 .40788 L .60603 .42762 L .743 .431 .455 r
F
.59825 .36416 m .60203 .40367 L .60466 .41644 L F
.60203 .40367 m .60243 .40788 L .60466 .41644 L F
.59824 .36415 m .60242 .40772 L .59825 .36416 L F
.60242 .40772 m .60243 .40788 L .60242 .40772 L F
.60242 .40772 m .60242 .40772 L .59825 .36416 L F
.59885 .38844 m .5953 .36962 L .59533 .36897 L .929 .66 .508 r
F
.59818 .36357 m .59824 .36415 L .59825 .36416 L .743 .431 .455 r
F
.59737 .34032 m .60041 .33851 L .60319 .33069 L .068 .147 .639 r
F
.59737 .34032 m .59412 .32872 L .60041 .33851 L F
.59412 .32872 m .59773 .35226 L .60041 .33851 L .939 .573 .195 r
F
.59412 .32872 m .59104 .3245 L .59773 .35226 L F
.59104 .3245 m .59509 .36953 L .59773 .35226 L .925 .587 .377 r
F
.60079 .34455 m .59818 .36357 L .60604 .42773 L .884 .569 .447 r
F
.59885 .38822 m .59533 .36897 L .59956 .28319 L .929 .66 .508 r
F
.59885 .38844 m .59533 .36897 L .59885 .38822 L F
.59886 .38825 m .59956 .28319 L .60271 .28827 L F
.59885 .38844 m .59885 .38822 L .59886 .38825 L F
.59885 .38822 m .59956 .28319 L .59886 .38825 L F
.6014 .35159 m .60604 .42773 L .60967 .44764 L .884 .569 .447 r
F
.60079 .34455 m .60126 .35197 L .6014 .35159 L F
.60126 .35197 m .60604 .42773 L .6014 .35159 L F
.60408 .36073 m .60553 .32916 L .60583 .328 L .928 .755 .274 r
F
.60669 .34582 m .60408 .36073 L .60456 .35657 L .895 .757 .258 r
F
.60669 .34582 m .60456 .35657 L .60856 .32165 L F
.60879 .32069 m .60856 .32165 L .60908 .31713 L F
.60669 .34582 m .60856 .32165 L .60879 .32069 L F
.60939 .33567 m .60669 .34582 L .60776 .34046 L .847 .778 .274 r
F
.61103 .41129 m .61241 .34636 L .61574 .36096 L .897 .647 .552 r
F
.61103 .41129 m .60764 .39508 L .61241 .34636 L F
.61434 .42381 m .61103 .41129 L .61574 .36096 L .919 .669 .543 r
F
.60669 .34582 m .60908 .31713 L .61208 .31885 L .895 .757 .258 r
F
.60408 .36073 m .60622 .32083 L .60908 .31713 L .928 .755 .274 r
F
.60677 .32938 m .61331 .46712 L .61693 .48561 L .951 .643 .416 r
F
.60622 .32083 m .60665 .32988 L .60677 .32938 L F
.60665 .32988 m .61331 .46712 L .60677 .32938 L F
.60346 .33006 m .60079 .34455 L .60967 .44764 L .93 .618 .431 r
F
.60243 .40788 m .59886 .38825 L .60271 .28827 L .935 .663 .5 r
F
.60603 .42762 m .60243 .40788 L .60604 .42773 L .743 .431 .455 r
F
.60386 .33566 m .60967 .44764 L .61331 .46712 L .93 .618 .431 r
F
.60346 .33006 m .60377 .336 L .60386 .33566 L F
.60377 .336 m .60967 .44764 L .60386 .33566 L F
.60583 .328 m .60553 .32916 L .60622 .32083 L .928 .755 .274 r
F
.60939 .33567 m .60776 .34046 L .61171 .3207 L .847 .778 .274 r
F
.60939 .33567 m .61171 .3207 L .61186 .32018 L F
.61221 .33122 m .60939 .33567 L .61401 .3276 L .674 .832 .405 r
F
.61434 .42381 m .61574 .36096 L .61913 .37759 L .919 .669 .543 r
F
.61754 .43236 m .61434 .42381 L .61913 .37759 L .938 .693 .541 r
F
.60939 .33567 m .61208 .31885 L .61519 .32553 L .847 .778 .274 r
F
.60971 .32731 m .61693 .48561 L .62053 .50256 L .962 .658 .403 r
F
.60908 .31713 m .60958 .32776 L .60971 .32731 L F
.60958 .32776 m .61693 .48561 L .60971 .32731 L F
.61186 .32018 m .61171 .3207 L .61208 .31885 L .847 .778 .274 r
F
.61221 .33122 m .61401 .3276 L .61519 .32553 L .674 .832 .405 r
F
.61146 .33271 m .61221 .33122 L .61415 .33296 L .425 .529 .86 r
F
.61116 .33268 m .61221 .33122 L .61146 .33271 L F
.61516 .33246 m .61221 .33122 L .61841 .33638 L .6 .036 0 r
F
.61842 .33639 m .61841 .33638 L .61843 .3364 L F
.61516 .33246 m .61841 .33638 L .61842 .33639 L F
.61754 .43236 m .61913 .37759 L .62255 .39471 L .938 .693 .541 r
F
.62063 .43717 m .62255 .39471 L .62595 .41088 L .956 .723 .547 r
F
.62063 .43717 m .61754 .43236 L .62255 .39471 L F
.62361 .43878 m .62063 .43717 L .62595 .41088 L .976 .776 .57 r
F
.61579 .33543 m .62407 .51745 L .62754 .52976 L .974 .674 .38 r
F
.61465 .33325 m .61519 .32553 L .61843 .3364 L .674 .832 .405 r
F
.61519 .32553 m .61565 .33538 L .61579 .33543 L .974 .674 .38 r
F
.61565 .33538 m .62407 .51745 L .61579 .33543 L F
.61221 .33122 m .61307 .32958 L .61465 .33325 L .674 .832 .405 r
F
.61307 .32958 m .61519 .32553 L .61465 .33325 L F
.619 .34292 m .61843 .3364 L .62177 .35043 L .6 .036 0 r
F
.62823 .38143 m .62759 .37861 L .62862 .3836 L .819 .525 0 r
F
.62113 .35026 m .62177 .35043 L .62517 .3665 L .809 .43 0 r
F
.27941 .32728 m .28136 .32149 L .28504 .32525 L .664 .741 .908 r
F
.27941 .32728 m .27572 .32353 L .28136 .32149 L F
.82778 .32728 m .83142 .3215 L .834 .32525 L F
.82778 .32728 m .82519 .32353 L .83142 .3215 L F
.50213 .38994 m .49892 .38132 L .50489 .36551 L .85 .664 .65 r
F
.50157 .37383 m .50435 .34703 L .50756 .35475 L .997 .812 .536 r
F
.49892 .38132 m .49575 .36731 L .50157 .37383 L .31 .28 .663 r
F
.49575 .36731 m .49825 .37669 L .50157 .37383 L 0 0 .204 r
F
.50157 .37383 m .49825 .37669 L .50249 .3561 L .997 .812 .536 r
F
.50303 .35974 m .50249 .3561 L .50435 .34703 L F
.50157 .37383 m .50249 .3561 L .50303 .35974 L F
.50489 .36551 m .50401 .3677 L .50756 .35475 L .835 .829 .354 r
F
.50401 .3677 m .50414 .36563 L .50756 .35475 L F
.49825 .37669 m .50108 .34744 L .50435 .34703 L .889 .687 .622 r
F
.50435 .34703 m .50108 .34744 L .50685 .36863 L .913 .54 .304 r
F
.5013 .34808 m .50365 .35338 L .50461 .35797 L .437 .032 .172 r
F
.50108 .34744 m .50126 .34786 L .5013 .34808 L F
.50126 .34786 m .50365 .35338 L .5013 .34808 L F
.50449 .35997 m .50461 .35797 L .50685 .36863 L F
.50108 .34744 m .50461 .35797 L .50449 .35997 L F
.50401 .3677 m .50157 .37383 L .50414 .36563 L .835 .829 .354 r
F
.53752 .34864 m .54049 .38878 L .5436 .37563 L .854 .525 .429 r
F
.53752 .34864 m .53439 .35915 L .54049 .38878 L F
.19547 .32712 m .19717 .32134 L .20101 .32509 L .663 .741 .908 r
F
.19547 .32712 m .19162 .32337 L .19717 .32134 L F
.74389 .32712 m .74726 .32135 L .75002 .3251 L F
.74389 .32712 m .74113 .32337 L .74726 .32135 L F
.29433 .32697 m .29634 .32119 L .29998 .32494 L F
.29433 .32697 m .29068 .32322 L .29634 .32119 L F
.8428 .32697 m .84648 .32119 L .84904 .32494 L F
.8428 .32697 m .84024 .32322 L .84648 .32119 L F
.65998 .32697 m .6631 .3212 L .66602 .32496 L F
.65998 .32697 m .65705 .32323 L .6631 .3212 L F
.75889 .32681 m .76232 .32103 L .76504 .32478 L F
.75889 .32681 m .75616 .32307 L .76232 .32103 L F
.21038 .32681 m .21213 .32104 L .21594 .32479 L F
.21038 .32681 m .20656 .32306 L .21213 .32104 L F
.12642 .32666 m .12791 .32087 L .13189 .32462 L .664 .741 .908 r
F
.12642 .32666 m .12243 .32291 L .12791 .32087 L F
.30927 .32666 m .31132 .32089 L .31493 .32464 L .663 .741 .908 r
F
.30927 .32666 m .30564 .32292 L .31132 .32089 L F
.67497 .32666 m .67814 .32088 L .68103 .32464 L .664 .742 .908 r
F
.67497 .32666 m .67207 .32292 L .67814 .32088 L F
.85783 .32666 m .86155 .32087 L .86408 .32463 L .664 .741 .908 r
F
.85783 .32666 m .85529 .32291 L .86155 .32087 L F
.77391 .3265 m .77738 .32072 L .78007 .32447 L .663 .741 .908 r
F
.77391 .3265 m .7712 .32275 L .77738 .32072 L F
.2253 .3265 m .2271 .32072 L .23088 .32447 L .664 .741 .908 r
F
.2253 .3265 m .22151 .32276 L .2271 .32072 L F
.87285 .32634 m .87663 .32056 L .87913 .32432 L .663 .741 .908 r
F
.87285 .32634 m .87035 .32259 L .87663 .32056 L F
.14132 .32634 m .14286 .32056 L .14681 .32431 L .664 .741 .908 r
F
.14132 .32634 m .13737 .32259 L .14286 .32056 L F
.68997 .32635 m .69319 .32056 L .69605 .32431 L .664 .742 .908 r
F
.68997 .32635 m .6871 .3226 L .69319 .32056 L F
.32421 .32635 m .3263 .32056 L .32989 .32431 L F
.32421 .32635 m .32061 .3226 L .3263 .32056 L F
.24023 .32618 m .24207 .3204 L .24582 .32416 L .663 .741 .908 r
F
.24023 .32618 m .23647 .32244 L .24207 .3204 L F
.78892 .32619 m .79244 .3204 L .7951 .32416 L F
.78892 .32619 m .78625 .32244 L .79244 .3204 L F
.15624 .32603 m .15782 .32025 L .16174 .324 L F
.15624 .32603 m .15231 .32228 L .15782 .32025 L F
.33915 .32603 m .33558 .32229 L .34129 .32027 L .662 .741 .908 r
F
.70498 .32604 m .70824 .32025 L .71107 .32401 L .663 .741 .908 r
F
.70498 .32604 m .70214 .32229 L .70824 .32025 L F
.64464 .40604 m .64133 .39419 L .64507 .3295 L .939 .679 .516 r
F
.64507 .3295 m .64806 .32151 L .65101 .32527 L .748 .745 .849 r
F
.64507 .3295 m .6421 .32531 L .64806 .32151 L F
.64133 .39419 m .6421 .32531 L .64507 .3295 L .934 .677 .525 r
F
.25516 .32588 m .25704 .32009 L .26077 .32385 L .664 .741 .908 r
F
.25516 .32588 m .25143 .32213 L .25704 .32009 L F
.80394 .32588 m .80751 .3201 L .81014 .32386 L .663 .741 .908 r
F
.80394 .32588 m .8013 .32213 L .80751 .3201 L F
.5557 .36003 m .55269 .37057 L .55865 .36766 L .387 .059 .282 r
F
.49583 .36595 m .49773 .35372 L .50108 .34744 L .512 .396 .658 r
F
.49575 .36731 m .4926 .35353 L .49645 .3693 L 0 0 .204 r
F
.4968 .37123 m .49645 .3693 L .49825 .37669 L F
.49575 .36731 m .49645 .3693 L .4968 .37123 L F
.4926 .35353 m .49501 .36886 L .49825 .37669 L .909 .549 .094 r
F
.49501 .36886 m .49568 .36511 L .49583 .36595 L .512 .396 .658 r
F
.49568 .36511 m .49773 .35372 L .49583 .36595 L F
.17116 .32572 m .17278 .31993 L .17668 .32369 L .664 .741 .908 r
F
.17116 .32572 m .16726 .32197 L .17278 .31993 L F
.66302 .48111 m .66754 .50835 L .67046 .51127 L .943 .579 .237 r
F
.71999 .32574 m .72329 .31994 L .7261 .3237 L .664 .741 .907 r
F
.71999 .32574 m .71717 .32198 L .72329 .31994 L F
.2701 .32556 m .27203 .31977 L .27572 .32353 L .664 .741 .908 r
F
.2701 .32556 m .26639 .32181 L .27203 .31977 L F
.81897 .32557 m .82258 .31977 L .82519 .32353 L F
.81897 .32557 m .81636 .32182 L .82258 .31977 L F
.45026 .34496 m .44716 .33099 L .45268 .34193 L .027 .084 .586 r
F
.44169 .36413 m .44346 .38563 L .44655 .40146 L .608 .297 .416 r
F
.44346 .38563 m .44716 .33099 L .45026 .34496 L .784 .556 .59 r
F
.43818 .40967 m .43535 .38559 L .44096 .36662 L .759 .542 .602 r
F
.44147 .36703 m .44096 .36662 L .44169 .36413 L F
.43818 .40967 m .44096 .36662 L .44147 .36703 L F
.43535 .38559 m .43778 .38068 L .44169 .36413 L 0 0 .478 r
F
.43535 .38559 m .43263 .35871 L .43778 .38068 L F
.43298 .36023 m .43394 .39235 L .43778 .38068 L .938 .662 .194 r
F
.43263 .35871 m .43268 .35998 L .43298 .36023 L F
.43268 .35998 m .43394 .39235 L .43298 .36023 L F
.44169 .36413 m .43778 .38068 L .44346 .38563 L .608 .297 .416 r
F
.44346 .38563 m .44065 .35958 L .44716 .33099 L .784 .556 .59 r
F
.45309 .37097 m .45026 .34496 L .45618 .33884 L .627 .441 .611 r
F
.45026 .34496 m .45268 .34193 L .45618 .33884 L .027 .084 .586 r
F
.44655 .40146 m .45026 .34496 L .45309 .37097 L .876 .639 .577 r
F
.44655 .40146 m .44346 .38563 L .45026 .34496 L F
.44716 .33099 m .44892 .35502 L .45268 .34193 L .839 .485 .385 r
F
.44065 .35958 m .44355 .33707 L .44716 .33099 L .537 .384 .621 r
F
.44716 .33099 m .44355 .33707 L .44892 .35502 L .839 .485 .385 r
F
.62806 .37642 m .62472 .36183 L .63209 .40091 L .821 .537 0 r
F
.18608 .32541 m .18775 .31961 L .19162 .32337 L .664 .741 .908 r
F
.18608 .32541 m .18221 .32166 L .18775 .31961 L F
.735 .32541 m .73835 .31961 L .74113 .32337 L .664 .742 .908 r
F
.735 .32541 m .73222 .32166 L .73835 .31961 L F
.28504 .32525 m .28701 .31946 L .29068 .32322 L .663 .741 .908 r
F
.28504 .32525 m .28136 .32149 L .28701 .31946 L F
.834 .32525 m .83766 .31947 L .84024 .32322 L F
.834 .32525 m .83142 .3215 L .83766 .31947 L F
.65101 .32527 m .65411 .31947 L .65705 .32323 L .664 .741 .908 r
F
.65101 .32527 m .64806 .32151 L .65411 .31947 L F
.20101 .32509 m .20273 .3193 L .20656 .32306 L .663 .741 .908 r
F
.20101 .32509 m .19717 .32134 L .20273 .3193 L F
.75002 .3251 m .75342 .31931 L .75616 .32307 L F
.75002 .3251 m .74726 .32135 L .75342 .31931 L F
.84904 .32494 m .85274 .31914 L .85529 .32291 L .664 .741 .908 r
F
.84904 .32494 m .84648 .32119 L .85274 .31914 L F
.29998 .32494 m .302 .31916 L .30564 .32292 L .663 .741 .908 r
F
.29998 .32494 m .29634 .32119 L .302 .31916 L F
.66602 .32496 m .66916 .31917 L .67207 .32292 L F
.66602 .32496 m .6631 .3212 L .66916 .31917 L F
.76504 .32478 m .76849 .31899 L .7712 .32275 L .663 .742 .908 r
F
.76504 .32478 m .76232 .32103 L .76849 .31899 L F
.21594 .32479 m .21771 .31899 L .22151 .32276 L .664 .741 .908 r
F
.21594 .32479 m .21213 .32104 L .21771 .31899 L F
.13189 .32462 m .13339 .31883 L .13737 .32259 L .663 .741 .908 r
F
.13189 .32462 m .12791 .32087 L .13339 .31883 L F
.86408 .32463 m .86783 .31883 L .87035 .32259 L .664 .741 .908 r
F
.86408 .32463 m .86155 .32087 L .86783 .31883 L F
.31493 .32464 m .317 .31884 L .32061 .3226 L .664 .742 .908 r
F
.31493 .32464 m .31132 .32089 L .317 .31884 L F
.68103 .32464 m .68422 .31884 L .6871 .3226 L .663 .741 .908 r
F
.68103 .32464 m .67814 .32088 L .68422 .31884 L F
.51394 .37941 m .51075 .36743 L .51563 .36175 L .713 .56 .679 r
F
.51639 .36238 m .51563 .36175 L .51665 .36057 L F
.51394 .37941 m .51563 .36175 L .51639 .36238 L F
.51075 .36743 m .51339 .36901 L .51665 .36057 L 0 0 .495 r
F
.51075 .36743 m .50756 .35475 L .51261 .3671 L F
.51288 .36871 m .51261 .3671 L .51339 .36901 L F
.51075 .36743 m .51261 .3671 L .51288 .36871 L F
.50977 .3503 m .50968 .33355 L .51295 .33039 L .809 .599 .617 r
F
.50776 .35523 m .51011 .37386 L .51339 .36901 L .926 .579 .135 r
F
.50761 .3551 m .51011 .37386 L .50776 .35523 L F
.50756 .35475 m .50435 .34703 L .50935 .37033 L F
.5097 .37083 m .50935 .37033 L .51011 .37386 L F
.50756 .35475 m .50935 .37033 L .5097 .37083 L F
.50435 .34703 m .50685 .36863 L .51011 .37386 L .913 .54 .304 r
F
.50709 .36713 m .5088 .34453 L .50977 .3503 L .809 .599 .617 r
F
.50685 .36863 m .50698 .36698 L .50709 .36713 L F
.50698 .36698 m .5088 .34453 L .50709 .36713 L F
.5088 .34453 m .50968 .33355 L .50977 .3503 L F
.50756 .35475 m .50761 .3551 L .50776 .35523 L .926 .579 .135 r
F
.23088 .32447 m .23269 .31867 L .23647 .32244 L .664 .741 .908 r
F
.23088 .32447 m .2271 .32072 L .23269 .31867 L F
.78007 .32447 m .78356 .31868 L .78625 .32244 L .664 .742 .908 r
F
.78007 .32447 m .77738 .32072 L .78356 .31868 L F
.14681 .32431 m .14836 .31852 L .15231 .32228 L .663 .741 .908 r
F
.14681 .32431 m .14286 .32056 L .14836 .31852 L F
.32989 .32431 m .332 .31852 L .33558 .32229 L F
.32989 .32431 m .3263 .32056 L .332 .31852 L F
.69605 .32431 m .69928 .31852 L .70214 .32229 L F
.69605 .32431 m .69319 .32056 L .69928 .31852 L F
.7951 .32416 m .79864 .31836 L .8013 .32213 L F
.7951 .32416 m .79244 .3204 L .79864 .31836 L F
.24582 .32416 m .24768 .31836 L .25143 .32213 L F
.24582 .32416 m .24207 .3204 L .24768 .31836 L F
.52526 .33929 m .52801 .37904 L .53123 .37275 L .886 .553 .412 r
F
.52526 .33929 m .52205 .34653 L .52801 .37904 L F
.16174 .324 m .16334 .3182 L .16726 .32197 L .664 .741 .908 r
F
.16174 .324 m .15782 .32025 L .16334 .3182 L F
.71107 .32401 m .71435 .31821 L .71717 .32198 L F
.71107 .32401 m .70824 .32025 L .71435 .31821 L F
.26077 .32385 m .26267 .31805 L .26639 .32181 L F
.26077 .32385 m .25704 .32009 L .26267 .31805 L F
.81014 .32386 m .81373 .31805 L .81636 .32182 L .664 .741 .907 r
F
.81014 .32386 m .80751 .3201 L .81373 .31805 L F
.51665 .36057 m .51932 .36607 L .52253 .38478 L .333 0 .204 r
F
.51665 .36057 m .51339 .36901 L .51932 .36607 L F
.54664 .35896 m .54963 .37984 L .55269 .37057 L .598 .289 .417 r
F
.54664 .35896 m .5436 .37563 L .54963 .37984 L F
.17668 .32369 m .17832 .31789 L .18221 .32166 L .664 .741 .908 r
F
.17668 .32369 m .17278 .31993 L .17832 .31789 L F
.7261 .3237 m .72942 .31789 L .73222 .32166 L F
.7261 .3237 m .72329 .31994 L .72942 .31789 L F
.45936 .34915 m .45618 .33884 L .46197 .33873 L .553 .483 .73 r
F
.45309 .37097 m .45618 .33884 L .45936 .34915 L .627 .441 .611 r
F
.45618 .33884 m .45844 .34457 L .46197 .33873 L .58 .101 .082 r
F
.45618 .33884 m .45268 .34193 L .45844 .34457 L F
.82519 .32353 m .82882 .31773 L .83142 .3215 L .663 .741 .908 r
F
.82519 .32353 m .82258 .31977 L .82882 .31773 L F
.27572 .32353 m .27767 .31773 L .28136 .32149 L .664 .741 .908 r
F
.27572 .32353 m .27203 .31977 L .27767 .31773 L F
.46239 .36778 m .45936 .34915 L .46523 .34586 L .612 .453 .642 r
F
.45379 .38731 m .45601 .39481 L .45923 .40514 L .285 0 .275 r
F
.45601 .39481 m .45936 .34915 L .46239 .36778 L .763 .544 .601 r
F
.45601 .39481 m .45309 .37097 L .45936 .34915 L F
.45936 .34915 m .46197 .33873 L .46523 .34586 L .553 .483 .73 r
F
.19162 .32337 m .19331 .31757 L .19717 .32134 L .663 .741 .908 r
F
.19162 .32337 m .18775 .31961 L .19331 .31757 L F
.74113 .32337 m .7445 .31758 L .74726 .32135 L F
.74113 .32337 m .73835 .31961 L .7445 .31758 L F
.29068 .32322 m .29268 .31742 L .29634 .32119 L F
.29068 .32322 m .28701 .31946 L .29268 .31742 L F
.84024 .32322 m .84391 .31742 L .84648 .32119 L .664 .742 .908 r
F
.84024 .32322 m .83766 .31947 L .84391 .31742 L F
.65705 .32323 m .66017 .31743 L .6631 .3212 L .663 .741 .908 r
F
.65705 .32323 m .65411 .31947 L .66017 .31743 L F
.20656 .32306 m .2083 .31727 L .21213 .32104 L F
.20656 .32306 m .20273 .3193 L .2083 .31727 L F
.75616 .32307 m .75958 .31727 L .76232 .32103 L .663 .742 .908 r
F
.75616 .32307 m .75342 .31931 L .75958 .31727 L F
.68191 .52045 m .67913 .51965 L .68504 .51393 L .864 .955 .867 r
F
.12243 .32291 m .12391 .3171 L .12791 .32087 L .664 .741 .908 r
F
.12243 .32291 m .11843 .31915 L .12391 .3171 L F
.85529 .32291 m .85901 .31711 L .86155 .32087 L .663 .741 .908 r
F
.85529 .32291 m .85274 .31914 L .85901 .31711 L F
.30564 .32292 m .30768 .31712 L .31132 .32089 L F
.30564 .32292 m .302 .31916 L .30768 .31712 L F
.67207 .32292 m .67524 .31711 L .67814 .32088 L .665 .742 .908 r
F
.67207 .32292 m .66916 .31917 L .67524 .31711 L F
.7712 .32275 m .77467 .31695 L .77738 .32072 L .664 .742 .908 r
F
.7712 .32275 m .76849 .31899 L .77467 .31695 L F
.22151 .32276 m .2233 .31695 L .2271 .32072 L .664 .741 .908 r
F
.22151 .32276 m .21771 .31899 L .2233 .31695 L F
.13737 .32259 m .13889 .31678 L .14286 .32056 L F
.13737 .32259 m .13339 .31883 L .13889 .31678 L F
.87035 .32259 m .87412 .31679 L .87663 .32056 L .663 .741 .908 r
F
.87035 .32259 m .86783 .31883 L .87412 .31679 L F
.6871 .3226 m .69031 .31679 L .69319 .32056 L .664 .741 .908 r
F
.6871 .3226 m .68422 .31884 L .69031 .31679 L F
.32061 .3226 m .3227 .31678 L .3263 .32056 L F
.32061 .3226 m .317 .31884 L .3227 .31678 L F
.64133 .39419 m .63802 .3824 L .6421 .32531 L .934 .677 .525 r
F
.6421 .32531 m .6451 .31774 L .64806 .32151 L .731 .741 .86 r
F
.6421 .32531 m .63911 .32113 L .6451 .31774 L F
.63802 .3824 m .63911 .32113 L .6421 .32531 L .928 .676 .536 r
F
.23647 .32244 m .2383 .31663 L .24207 .3204 L .663 .741 .908 r
F
.23647 .32244 m .23269 .31867 L .2383 .31663 L F
.78625 .32244 m .78976 .31663 L .79244 .3204 L F
.78625 .32244 m .78356 .31868 L .78976 .31663 L F
.15231 .32228 m .15388 .31648 L .15782 .32025 L F
.15231 .32228 m .14836 .31852 L .15388 .31648 L F
.70214 .32229 m .70539 .31648 L .70824 .32025 L F
.70214 .32229 m .69928 .31852 L .70539 .31648 L F
.33558 .32229 m .33772 .31649 L .34129 .32027 L F
.33558 .32229 m .332 .31852 L .33772 .31649 L F
.25143 .32213 m .2533 .31632 L .25704 .32009 L .664 .741 .908 r
F
.25143 .32213 m .24768 .31836 L .2533 .31632 L F
.8013 .32213 m .80486 .31631 L .80751 .3201 L F
.8013 .32213 m .79864 .31836 L .80486 .31631 L F
.4683 .36298 m .46523 .34586 L .471 .34812 L .492 .379 .652 r
F
.46239 .36778 m .46523 .34586 L .4683 .36298 L .612 .453 .642 r
F
.46523 .34586 m .4679 .33236 L .471 .34812 L .765 .653 .738 r
F
.46523 .34586 m .46197 .33873 L .4679 .33236 L F
.48392 .38058 m .48046 .38959 L .48661 .36697 L .896 .842 .382 r
F
.16726 .32197 m .16887 .31616 L .17278 .31993 L .664 .741 .908 r
F
.16726 .32197 m .16334 .3182 L .16887 .31616 L F
.71717 .32198 m .72048 .31616 L .72329 .31994 L F
.71717 .32198 m .71435 .31821 L .72048 .31616 L F
.26639 .32181 m .26831 .316 L .27203 .31977 L F
.26639 .32181 m .26267 .31805 L .26831 .316 L F
.81636 .32182 m .81996 .316 L .82258 .31977 L F
.81636 .32182 m .81373 .31805 L .81996 .316 L F
.18221 .32166 m .18387 .31584 L .18775 .31961 L F
.18221 .32166 m .17832 .31789 L .18387 .31584 L F
.73222 .32166 m .73557 .31584 L .73835 .31961 L .664 .742 .908 r
F
.73222 .32166 m .72942 .31789 L .73557 .31584 L F
.66012 .47834 m .66454 .50373 L .66754 .50835 L .937 .576 .179 r
F
.28136 .32149 m .28333 .31568 L .28701 .31946 L .663 .741 .908 r
F
.28136 .32149 m .27767 .31773 L .28333 .31568 L F
.83142 .3215 m .83507 .31569 L .83766 .31947 L F
.83142 .3215 m .82882 .31773 L .83507 .31569 L F
.64806 .32151 m .65116 .31569 L .65411 .31947 L .664 .741 .908 r
F
.64806 .32151 m .6451 .31774 L .65116 .31569 L F
.19717 .32134 m .19888 .31553 L .20273 .3193 L .663 .741 .908 r
F
.19717 .32134 m .19331 .31757 L .19888 .31553 L F
.74726 .32135 m .75066 .31554 L .75342 .31931 L F
.74726 .32135 m .7445 .31758 L .75066 .31554 L F
.68813 .52161 m .69113 .51196 L .69386 .51259 L .64 .579 .77 r
F
.29634 .32119 m .29835 .31539 L .302 .31916 L .663 .741 .908 r
F
.29634 .32119 m .29268 .31742 L .29835 .31539 L F
.84648 .32119 m .85018 .31537 L .85274 .31914 L F
.84648 .32119 m .84391 .31742 L .85018 .31537 L F
.6631 .3212 m .66624 .3154 L .66916 .31917 L F
.6631 .3212 m .66017 .31743 L .66624 .3154 L F
.76232 .32103 m .76576 .31522 L .76849 .31899 L .664 .742 .908 r
F
.76232 .32103 m .75958 .31727 L .76576 .31522 L F
.21213 .32104 m .21388 .31522 L .21771 .31899 L .664 .741 .908 r
F
.21213 .32104 m .2083 .31727 L .21388 .31522 L F
.46886 .33724 m .4679 .33236 L .46917 .33649 L 0 0 .425 r
F
.4679 .33236 m .47031 .3341 L .47343 .35032 L .361 0 0 r
F
.46197 .33873 m .46451 .33217 L .4679 .33236 L .779 .872 .44 r
F
.4679 .33236 m .46451 .33217 L .47031 .3341 L .361 0 0 r
F
.46451 .33217 m .46698 .33021 L .46606 .33266 L 0 0 .023 r
F
.46451 .33217 m .47021 .33398 L .47018 .33406 L F
.46451 .33217 m .46082 .34567 L .46698 .33021 L F
.46621 .33214 m .46338 .33944 L .46698 .33021 L 0 0 0 r
F
.46082 .34567 m .46338 .33944 L .46621 .33214 L F
.46082 .34567 m .45708 .35965 L .46338 .33944 L F
.46338 .33944 m .45969 .35075 L .46052 .34682 L .939 .829 .382 r
F
.46197 .33873 m .45844 .34457 L .46451 .33217 L .779 .872 .44 r
F
.45844 .34457 m .46082 .34567 L .46451 .33217 L 0 0 .102 r
F
.45844 .34457 m .45472 .35732 L .46082 .34567 L F
.45472 .35732 m .45708 .35965 L .46082 .34567 L .095 0 .036 r
F
.46338 .33944 m .46052 .34682 L .4662 .31968 L .939 .829 .382 r
F
.46698 .33021 m .46338 .33944 L .46791 .32771 L .668 .752 .261 r
F
.46698 .33021 m .46791 .32771 L .46955 .32345 L F
.46606 .33266 m .46698 .33021 L .47021 .33398 L 0 0 .023 r
F
.47018 .33406 m .47021 .33398 L .47031 .3341 L F
.471 .34812 m .46886 .33724 L .47343 .35032 L 0 0 .425 r
F
.46886 .33724 m .46917 .33649 L .47343 .35032 L F
.47208 .39324 m .47457 .39199 L .47793 .39191 L .318 .787 .678 r
F
.47208 .39324 m .46868 .39462 L .47457 .39199 L F
.12791 .32087 m .1294 .31505 L .13339 .31883 L .663 .741 .908 r
F
.12791 .32087 m .12391 .3171 L .1294 .31505 L F
.86155 .32087 m .8653 .31505 L .86783 .31883 L .664 .742 .908 r
F
.86155 .32087 m .85901 .31711 L .8653 .31505 L F
.67814 .32088 m .68133 .31506 L .68422 .31884 L .664 .741 .908 r
F
.67814 .32088 m .67524 .31711 L .68133 .31506 L F
.31132 .32089 m .31338 .31506 L .317 .31884 L .664 .742 .908 r
F
.31132 .32089 m .30768 .31712 L .31338 .31506 L F
.2271 .32072 m .2289 .31489 L .23269 .31867 L .664 .741 .908 r
F
.2271 .32072 m .2233 .31695 L .2289 .31489 L F
.77738 .32072 m .78087 .3149 L .78356 .31868 L F
.77738 .32072 m .77467 .31695 L .78087 .3149 L F
.51011 .37386 m .51295 .33039 L .51614 .34381 L .946 .716 .559 r
F
.51932 .36607 m .51614 .34381 L .52205 .34653 L .5 .362 .624 r
F
.51339 .36901 m .51614 .34381 L .51932 .36607 L 1 .827 .503 r
F
.51339 .36901 m .51011 .37386 L .51562 .34639 L F
.51584 .34653 m .51562 .34639 L .51614 .34381 L F
.51339 .36901 m .51562 .34639 L .51584 .34653 L F
.51011 .37386 m .50685 .36863 L .51295 .33039 L .946 .716 .559 r
F
.51152 .34369 m .51224 .35771 L .5155 .36558 L .657 .338 .422 r
F
.50968 .33355 m .5107 .34314 L .51152 .34369 L F
.5107 .34314 m .51224 .35771 L .51152 .34369 L F
.51614 .34381 m .51295 .33039 L .51879 .35898 L .787 .506 0 r
F
.51295 .33039 m .5155 .36558 L .51879 .35898 L .915 .573 .379 r
F
.51295 .33039 m .50968 .33355 L .5155 .36558 L F
.3263 .32056 m .32841 .31475 L .332 .31852 L .663 .741 .908 r
F
.3263 .32056 m .3227 .31678 L .32841 .31475 L F
.14286 .32056 m .1444 .31474 L .14836 .31852 L F
.14286 .32056 m .13889 .31678 L .1444 .31474 L F
.69319 .32056 m .69642 .31474 L .69928 .31852 L F
.69319 .32056 m .69031 .31679 L .69642 .31474 L F
.24207 .3204 m .24392 .31458 L .24768 .31836 L .664 .741 .908 r
F
.24207 .3204 m .2383 .31663 L .24392 .31458 L F
.79244 .3204 m .79598 .31458 L .79864 .31836 L F
.79244 .3204 m .78976 .31663 L .79598 .31458 L F
.15782 .32025 m .15941 .31442 L .16334 .3182 L F
.15782 .32025 m .15388 .31648 L .15941 .31442 L F
.70824 .32025 m .71152 .31443 L .71435 .31821 L F
.70824 .32025 m .70539 .31648 L .71152 .31443 L F
.25704 .32009 m .25894 .31427 L .26267 .31805 L F
.25704 .32009 m .2533 .31632 L .25894 .31427 L F
.80751 .3201 m .81109 .31427 L .81373 .31805 L .663 .741 .907 r
F
.80751 .3201 m .80486 .31631 L .81109 .31427 L F
.17278 .31993 m .17442 .31411 L .17832 .31789 L .664 .741 .908 r
F
.17278 .31993 m .16887 .31616 L .17442 .31411 L F
.72329 .31994 m .72662 .31411 L .72942 .31789 L F
.72329 .31994 m .72048 .31616 L .72662 .31411 L F
.82258 .31977 m .82621 .31395 L .82882 .31773 L F
.82258 .31977 m .81996 .316 L .82621 .31395 L F
.27203 .31977 m .27397 .31395 L .27767 .31773 L F
.27203 .31977 m .26831 .316 L .27397 .31395 L F
.18775 .31961 m .18944 .31379 L .19331 .31757 L .663 .741 .908 r
F
.18775 .31961 m .18387 .31584 L .18944 .31379 L F
.73835 .31961 m .74173 .31379 L .7445 .31758 L F
.73835 .31961 m .73557 .31584 L .74173 .31379 L F
.28701 .31946 m .289 .31364 L .29268 .31742 L F
.28701 .31946 m .28333 .31568 L .289 .31364 L F
.65411 .31947 m .65723 .31365 L .66017 .31743 L F
.65411 .31947 m .65116 .31569 L .65723 .31365 L F
.83766 .31947 m .84134 .31363 L .84391 .31742 L .664 .741 .908 r
F
.83766 .31947 m .83507 .31569 L .84134 .31363 L F
.44065 .35958 m .43779 .3366 L .44355 .33707 L .537 .384 .621 r
F
.43394 .39235 m .43779 .3366 L .44065 .35958 L .961 .726 .536 r
F
.43394 .39235 m .43046 .39017 L .43779 .3366 L F
.43779 .3366 m .4395 .35839 L .44355 .33707 L .952 .614 .216 r
F
.43046 .39017 m .43452 .32889 L .43779 .3366 L .872 .632 .573 r
F
.43779 .3366 m .43452 .32889 L .4395 .35839 L .952 .614 .216 r
F
.20273 .3193 m .20446 .31348 L .2083 .31727 L .663 .741 .908 r
F
.20273 .3193 m .19888 .31553 L .20446 .31348 L F
.75342 .31931 m .75684 .31349 L .75958 .31727 L F
.75342 .31931 m .75066 .31554 L .75684 .31349 L F
.68813 .52161 m .68504 .51393 L .69113 .51196 L .64 .579 .77 r
F
.85274 .31914 m .85647 .31333 L .85901 .31711 L .663 .741 .908 r
F
.85274 .31914 m .85018 .31537 L .85647 .31333 L F
.11843 .31915 m .1199 .31332 L .12391 .3171 L .664 .741 .908 r
F
.11843 .31915 m .11441 .31537 L .1199 .31332 L F
.302 .31916 m .30404 .31334 L .30768 .31712 L .663 .741 .908 r
F
.302 .31916 m .29835 .31539 L .30404 .31334 L F
.66916 .31917 m .67232 .31333 L .67524 .31711 L .665 .742 .908 r
F
.66916 .31917 m .66624 .3154 L .67232 .31333 L F
.45379 .38731 m .45004 .40081 L .45601 .39481 L .285 0 .275 r
F
.76849 .31899 m .77195 .31316 L .77467 .31695 L .664 .741 .908 r
F
.76849 .31899 m .76576 .31522 L .77195 .31316 L F
.21771 .31899 m .21948 .31316 L .2233 .31695 L F
.21771 .31899 m .21388 .31522 L .21948 .31316 L F
.63802 .3824 m .63472 .37095 L .63911 .32113 L .928 .676 .536 r
F
.63911 .32113 m .64213 .31396 L .6451 .31774 L .716 .74 .87 r
F
.63911 .32113 m .63612 .317 L .64213 .31396 L F
.63472 .37095 m .63612 .317 L .63911 .32113 L .923 .676 .548 r
F
.13339 .31883 m .13491 .313 L .13889 .31678 L .664 .741 .908 r
F
.13339 .31883 m .1294 .31505 L .13491 .313 L F
.86783 .31883 m .8716 .31301 L .87412 .31679 L .663 .741 .908 r
F
.86783 .31883 m .8653 .31505 L .8716 .31301 L F
.68422 .31884 m .68743 .313 L .69031 .31679 L .664 .741 .908 r
F
.68422 .31884 m .68133 .31506 L .68743 .313 L F
.317 .31884 m .31908 .313 L .3227 .31678 L F
.317 .31884 m .31338 .31506 L .31908 .313 L F
.23269 .31867 m .23451 .31284 L .2383 .31663 L .663 .741 .908 r
F
.23269 .31867 m .2289 .31489 L .23451 .31284 L F
.78356 .31868 m .78708 .31284 L .78976 .31663 L .664 .741 .908 r
F
.78356 .31868 m .78087 .3149 L .78708 .31284 L F
.65404 .46662 m .65844 .49303 L .66149 .49826 L .928 .581 .141 r
F
.66149 .49826 m .65844 .49303 L .6585 .49303 L .502 .589 .874 r
F
.65712 .47346 m .66149 .49826 L .66447 .50348 L .924 .573 .13 r
F
.66149 .49826 m .6585 .49303 L .66461 .49353 L .502 .589 .874 r
F
.66149 .49826 m .66461 .49353 L .66467 .49357 L F
.66447 .50348 m .66149 .49826 L .66454 .50373 L .924 .573 .13 r
F
.65095 .45942 m .65538 .48751 L .65844 .49303 L .935 .59 .159 r
F
.66454 .50373 m .66149 .49826 L .66741 .49128 L .807 .711 .759 r
F
.66149 .49826 m .66467 .49357 L .66479 .49347 L .502 .589 .874 r
F
.66149 .49826 m .66479 .49347 L .6666 .49225 L F
.66467 .49357 m .66461 .49353 L .66469 .49354 L F
.66464 .49353 m .66204 .49779 L .66469 .49354 L 0 0 .463 r
F
.65844 .49303 m .66201 .49776 L .66464 .49353 L F
.66201 .49776 m .66204 .49779 L .66464 .49353 L F
.65844 .49303 m .65538 .48751 L .66176 .49737 L F
.65844 .49303 m .66176 .49737 L .66185 .49754 L F
.65844 .49303 m .662 .49774 L .66201 .49776 L F
.65556 .48779 m .65857 .49903 L .66127 .49661 L .815 .457 0 r
F
.64572 .45979 m .65132 .51929 L .65398 .51228 L .962 .651 .246 r
F
.65398 .51228 m .65132 .51929 L .65135 .51854 L .993 .745 .418 r
F
.64901 .47072 m .65398 .51228 L .65415 .51186 L .945 .625 .189 r
F
.64901 .47072 m .65416 .51189 L .65659 .50617 L F
.65095 .45942 m .64784 .4523 L .65538 .48751 L .935 .59 .159 r
F
.65538 .48751 m .65223 .48013 L .6591 .5012 L .815 .457 0 r
F
.65919 .50137 m .6591 .5012 L .65935 .50195 L F
.65538 .48751 m .6591 .5012 L .65919 .50137 L F
.64901 .47072 m .64572 .45979 L .65398 .51228 L .945 .625 .189 r
F
.65398 .51228 m .65135 .51854 L .65258 .4881 L .993 .745 .418 r
F
.6591 .5012 m .65665 .50642 L .65935 .50195 L .904 .572 .09 r
F
.65223 .48013 m .6566 .50614 L .6591 .5012 L F
.6566 .50614 m .65665 .50642 L .6591 .5012 L F
.65223 .48013 m .64901 .47072 L .65658 .50609 L F
.6566 .50614 m .65658 .50609 L .65665 .50642 L F
.65223 .48013 m .65658 .50609 L .6566 .50614 L F
.65406 .50098 m .65258 .4881 L .65414 .49122 L .993 .745 .418 r
F
.65398 .5113 m .65326 .49936 L .65406 .50098 L F
.65326 .49936 m .65258 .4881 L .65406 .50098 L F
.65398 .51228 m .65393 .51141 L .65398 .5113 L F
.65393 .51141 m .65258 .4881 L .65398 .5113 L F
.65414 .49122 m .65258 .4881 L .65454 .43988 L F
.65415 .51186 m .65398 .51228 L .65416 .51189 L .945 .625 .189 r
F
.65659 .50617 m .65416 .51189 L .65665 .50642 L F
.64239 .44743 m .64863 .52629 L .65132 .51929 L .97 .665 .277 r
F
.65132 .51929 m .64863 .52629 L .64867 .52475 L .991 .734 .418 r
F
.64468 .44356 m .64901 .47072 L .65223 .48013 L .893 .574 .076 r
F
.64572 .45979 m .64239 .44743 L .65132 .51929 L .962 .651 .246 r
F
.65132 .51854 m .64867 .52475 L .65125 .42891 L .991 .734 .418 r
F
.65132 .51929 m .64867 .52475 L .65132 .51854 L F
.65665 .50642 m .65398 .51228 L .65408 .51064 L .996 .759 .427 r
F
.65538 .48751 m .65543 .48771 L .65556 .48779 L .815 .457 0 r
F
.65543 .48771 m .65935 .50195 L .65556 .48779 L F
.65664 .50622 m .65408 .51064 L .65563 .48553 L .996 .759 .427 r
F
.65665 .50642 m .65408 .51064 L .65664 .50622 L F
.65702 .48822 m .65563 .48553 L .65781 .45035 L F
.65665 .50642 m .65563 .48553 L .65702 .48822 L F
.66185 .49754 m .66176 .49737 L .662 .49774 L 0 0 .463 r
F
.66201 .49776 m .662 .49774 L .66204 .49779 L F
.65857 .49903 m .65935 .50195 L .66127 .49661 L .815 .457 0 r
F
.65935 .50195 m .65673 .50628 L .65821 .49032 L .998 .777 .447 r
F
.6597 .49323 m .65821 .49032 L .66104 .45987 L F
.65935 .50195 m .65821 .49032 L .6597 .49323 L F
.65673 .50628 m .65665 .50642 L .65665 .50642 L F
.65673 .50628 m .65665 .50642 L .66104 .45987 L F
.66469 .49354 m .66204 .49779 L .66278 .49484 L .972 .864 .471 r
F
.66469 .49354 m .66278 .49484 L .66739 .47651 L F
.6666 .49225 m .66479 .49347 L .66741 .49128 L .502 .589 .874 r
F
.66467 .49357 m .66469 .49354 L .6649 .49337 L F
.66467 .49357 m .6649 .49337 L .66741 .49128 L F
.66127 .49661 m .65935 .50195 L .66204 .49779 L .815 .457 0 r
F
.51614 .34381 m .51879 .35898 L .52205 .34653 L .787 .506 0 r
F
.47793 .39191 m .47457 .39199 L .48046 .38959 L .514 .912 .906 r
F
.14836 .31852 m .14993 .31269 L .15388 .31648 L .663 .741 .908 r
F
.14836 .31852 m .1444 .31474 L .14993 .31269 L F
.69928 .31852 m .70254 .31269 L .70539 .31648 L F
.69928 .31852 m .69642 .31474 L .70254 .31269 L F
.332 .31852 m .33413 .3127 L .33772 .31649 L F
.332 .31852 m .32841 .31475 L .33413 .3127 L F
.24768 .31836 m .24955 .31253 L .2533 .31632 L .664 .741 .908 r
F
.24768 .31836 m .24392 .31458 L .24955 .31253 L F
.79864 .31836 m .8022 .31253 L .80486 .31631 L .663 .741 .908 r
F
.79864 .31836 m .79598 .31458 L .8022 .31253 L F
.40334 .51694 m .40045 .49604 L .40915 .41642 L .898 .647 .551 r
F
.40915 .41642 m .40936 .47234 L .41311 .46857 L .796 .498 .484 r
F
.40045 .49604 m .40476 .43859 L .40915 .41642 L .83 .599 .588 r
F
.40915 .41642 m .40476 .43859 L .40936 .47234 L .796 .498 .484 r
F
.46545 .38547 m .46239 .36778 L .4683 .36298 L .64 .477 .646 r
F
.45923 .40514 m .46239 .36778 L .46545 .38547 L .88 .663 .604 r
F
.45923 .40514 m .45601 .39481 L .46239 .36778 L F
.16334 .3182 m .16495 .31237 L .16887 .31616 L .663 .741 .908 r
F
.16334 .3182 m .15941 .31442 L .16495 .31237 L F
.71435 .31821 m .71765 .31237 L .72048 .31616 L .664 .742 .908 r
F
.71435 .31821 m .71152 .31443 L .71765 .31237 L F
.81373 .31805 m .81734 .31221 L .81996 .316 L .664 .741 .908 r
F
.81373 .31805 m .81109 .31427 L .81734 .31221 L F
.26267 .31805 m .26459 .31221 L .26831 .316 L F
.26267 .31805 m .25894 .31427 L .26459 .31221 L F
.43046 .39017 m .42744 .37249 L .43452 .32889 L .872 .632 .573 r
F
.43452 .32889 m .43544 .37777 L .4395 .35839 L .873 .556 .447 r
F
.43452 .32889 m .4307 .33958 L .43544 .37777 L F
.68504 .51393 m .6884 .51175 L .69113 .51196 L .202 .296 .737 r
F
.67913 .51965 m .6819 .50543 L .68504 .51393 L .922 .805 .714 r
F
.17832 .31789 m .17998 .31205 L .18387 .31584 L .664 .741 .908 r
F
.17832 .31789 m .17442 .31411 L .17998 .31205 L F
.72942 .31789 m .73277 .31205 L .73557 .31584 L F
.72942 .31789 m .72662 .31411 L .73277 .31205 L F
.47136 .38124 m .4683 .36298 L .47401 .37046 L .338 .266 .627 r
F
.46545 .38547 m .4683 .36298 L .47136 .38124 L .64 .477 .646 r
F
.4683 .36298 m .471 .34812 L .47401 .37046 L .492 .379 .652 r
F
.67913 .51965 m .67625 .51677 L .6819 .50543 L .922 .805 .714 r
F
.27767 .31773 m .27963 .31189 L .28333 .31568 L .663 .741 .908 r
F
.27767 .31773 m .27397 .31395 L .27963 .31189 L F
.82882 .31773 m .83247 .3119 L .83507 .31569 L F
.82882 .31773 m .82621 .31395 L .83247 .3119 L F
.6451 .31774 m .64819 .3119 L .65116 .31569 L .664 .741 .908 r
F
.6451 .31774 m .64213 .31396 L .64819 .3119 L F
.19331 .31757 m .19501 .31174 L .19888 .31553 L .663 .741 .908 r
F
.19331 .31757 m .18944 .31379 L .19501 .31174 L F
.7445 .31758 m .7479 .31174 L .75066 .31554 L F
.7445 .31758 m .74173 .31379 L .7479 .31174 L F
.47401 .37046 m .471 .34812 L .47652 .36875 L 0 0 .473 r
F
.471 .34812 m .47343 .35032 L .47652 .36875 L 0 0 .425 r
F
.84391 .31742 m .84762 .31159 L .85018 .31537 L .663 .741 .908 r
F
.84391 .31742 m .84134 .31363 L .84762 .31159 L F
.29268 .31742 m .29468 .3116 L .29835 .31539 L .662 .741 .908 r
F
.29268 .31742 m .289 .31364 L .29468 .3116 L F
.66017 .31743 m .66331 .3116 L .66624 .3154 L .663 .741 .908 r
F
.66017 .31743 m .65723 .31365 L .66331 .3116 L F
.2083 .31727 m .21005 .31143 L .21388 .31522 L .664 .741 .908 r
F
.2083 .31727 m .20446 .31348 L .21005 .31143 L F
.75958 .31727 m .76303 .31143 L .76576 .31522 L .664 .742 .908 r
F
.75958 .31727 m .75684 .31349 L .76303 .31143 L F
.62935 .43666 m .63259 .43715 L .63583 .44775 L .086 0 0 r
F
.62935 .43666 m .6265 .43816 L .63259 .43715 L F
.12391 .3171 m .1254 .31126 L .1294 .31505 L .663 .741 .908 r
F
.12391 .3171 m .1199 .31332 L .1254 .31126 L F
.67524 .31711 m .67842 .31126 L .68133 .31506 L .664 .742 .908 r
F
.67524 .31711 m .67232 .31333 L .67842 .31126 L F
.85901 .31711 m .86276 .31126 L .8653 .31505 L F
.85901 .31711 m .85647 .31333 L .86276 .31126 L F
.30768 .31712 m .30974 .31127 L .31338 .31506 L F
.30768 .31712 m .30404 .31334 L .30974 .31127 L F
.2233 .31695 m .22509 .3111 L .2289 .31489 L .664 .741 .908 r
F
.2233 .31695 m .21948 .31316 L .22509 .3111 L F
.77467 .31695 m .77816 .3111 L .78087 .3149 L F
.77467 .31695 m .77195 .31316 L .77816 .3111 L F
.42257 .42573 m .41887 .42971 L .42633 .37706 L .986 .762 .516 r
F
.41887 .42971 m .42224 .39467 L .42633 .37706 L .871 .66 .614 r
F
.49825 .37669 m .49501 .36886 L .50108 .34744 L .889 .687 .622 r
F
.50108 .34744 m .49773 .35372 L .50365 .35338 L .437 .032 .172 r
F
.3227 .31678 m .3248 .31095 L .32841 .31475 L .663 .741 .908 r
F
.3227 .31678 m .31908 .313 L .3248 .31095 L F
.13889 .31678 m .14043 .31094 L .1444 .31474 L F
.13889 .31678 m .13491 .313 L .14043 .31094 L F
.69031 .31679 m .69354 .31095 L .69642 .31474 L F
.69031 .31679 m .68743 .313 L .69354 .31095 L F
.2383 .31663 m .24014 .31079 L .24392 .31458 L .664 .741 .908 r
F
.2383 .31663 m .23451 .31284 L .24014 .31079 L F
.78976 .31663 m .7933 .31079 L .79598 .31458 L F
.78976 .31663 m .78708 .31284 L .7933 .31079 L F
.15388 .31648 m .15546 .31063 L .15941 .31442 L F
.15388 .31648 m .14993 .31269 L .15546 .31063 L F
.70539 .31648 m .70867 .31064 L .71152 .31443 L .663 .741 .908 r
F
.70539 .31648 m .70254 .31269 L .70867 .31064 L F
.33772 .31649 m .33413 .3127 L .33986 .31065 L F
.80486 .31631 m .80845 .31048 L .81109 .31427 L F
.80486 .31631 m .8022 .31253 L .80845 .31048 L F
.2533 .31632 m .25519 .31047 L .25894 .31427 L .664 .741 .908 r
F
.2533 .31632 m .24955 .31253 L .25519 .31047 L F
.48315 .37632 m .47976 .37861 L .48602 .3495 L .994 .808 .549 r
F
.48602 .3495 m .48256 .35821 L .48779 .33911 L .903 .846 .391 r
F
.48602 .3495 m .48779 .33911 L .48796 .33959 L F
.48256 .35821 m .48545 .32964 L .48871 .33573 L 1 .815 .505 r
F
.48718 .33739 m .48785 .34141 L .49106 .35478 L .647 .26 .297 r
F
.48545 .32964 m .48683 .33639 L .48718 .33739 L F
.48683 .33639 m .48785 .34141 L .48718 .33739 L F
.48796 .33959 m .48779 .33911 L .48871 .33573 L .903 .846 .391 r
F
.47976 .37861 m .48256 .35821 L .48602 .3495 L .788 .623 .676 r
F
.16887 .31616 m .1705 .31031 L .17442 .31411 L .664 .741 .908 r
F
.16887 .31616 m .16495 .31237 L .1705 .31031 L F
.72048 .31616 m .7238 .31031 L .72662 .31411 L F
.72048 .31616 m .71765 .31237 L .7238 .31031 L F
.81996 .316 m .82359 .31015 L .82621 .31395 L F
.81996 .316 m .81734 .31221 L .82359 .31015 L F
.26831 .316 m .27025 .31015 L .27397 .31395 L F
.26831 .316 m .26459 .31221 L .27025 .31015 L F
.44355 .33707 m .44514 .36674 L .44892 .35502 L .637 .336 .444 r
F
.43778 .38068 m .44065 .35958 L .44346 .38563 L .956 .833 .403 r
F
.43778 .38068 m .43394 .39235 L .44065 .35958 L F
.44355 .33707 m .4395 .35839 L .44514 .36674 L .637 .336 .444 r
F
.18387 .31584 m .18555 .30999 L .18944 .31379 L .663 .741 .908 r
F
.18387 .31584 m .17998 .31205 L .18555 .30999 L F
.73557 .31584 m .73894 .31 L .74173 .31379 L F
.73557 .31584 m .73277 .31205 L .73894 .31 L F
.45268 .34193 m .45472 .35732 L .45844 .34457 L .563 .233 .369 r
F
.45268 .34193 m .44892 .35502 L .45472 .35732 L F
.28333 .31568 m .28531 .30984 L .289 .31364 L .663 .741 .908 r
F
.28333 .31568 m .27963 .31189 L .28531 .30984 L F
.65116 .31569 m .65427 .30985 L .65723 .31365 L F
.65116 .31569 m .64819 .3119 L .65427 .30985 L F
.83507 .31569 m .83875 .30983 L .84134 .31363 L .664 .741 .908 r
F
.83507 .31569 m .83247 .3119 L .83875 .30983 L F
.19888 .31553 m .2006 .30969 L .20446 .31348 L .663 .741 .908 r
F
.19888 .31553 m .19501 .31174 L .2006 .30969 L F
.75066 .31554 m .75408 .30968 L .75684 .31349 L F
.75066 .31554 m .7479 .31174 L .75408 .30968 L F
.63472 .37095 m .63145 .36001 L .63612 .317 L .923 .676 .548 r
F
.63612 .317 m .63915 .31016 L .64213 .31396 L .705 .741 .88 r
F
.63612 .317 m .63311 .31296 L .63915 .31016 L F
.63145 .36001 m .63311 .31296 L .63612 .317 L .916 .676 .561 r
F
.85018 .31537 m .85391 .30952 L .85647 .31333 L .664 .742 .908 r
F
.85018 .31537 m .84762 .31159 L .85391 .30952 L F
.11441 .31537 m .11587 .30952 L .1199 .31332 L .664 .741 .908 r
F
.11441 .31537 m .11037 .31158 L .11587 .30952 L F
.29835 .31539 m .30038 .30954 L .30404 .31334 L .664 .742 .908 r
F
.29835 .31539 m .29468 .3116 L .30038 .30954 L F
.66624 .3154 m .6694 .30954 L .67232 .31333 L .664 .741 .908 r
F
.66624 .3154 m .66331 .3116 L .6694 .30954 L F
.21388 .31522 m .21565 .30936 L .21948 .31316 L F
.21388 .31522 m .21005 .31143 L .21565 .30936 L F
.76576 .31522 m .76923 .30936 L .77195 .31316 L F
.76576 .31522 m .76303 .31143 L .76923 .30936 L F
.49501 .36886 m .49186 .35217 L .49773 .35372 L .512 .396 .658 r
F
.49186 .35217 m .49437 .35862 L .49773 .35372 L 0 0 .309 r
F
.49264 .34787 m .49387 .33259 L .49724 .32767 L .729 .559 .662 r
F
.49186 .35217 m .48871 .33573 L .49336 .35455 L 0 0 .309 r
F
.49358 .35661 m .49336 .35455 L .49437 .35862 L F
.49186 .35217 m .49336 .35455 L .49358 .35661 L F
.48871 .33573 m .49106 .35478 L .49437 .35862 L .937 .579 .174 r
F
.49106 .35478 m .49231 .34489 L .49264 .34787 L .729 .559 .662 r
F
.49231 .34489 m .49387 .33259 L .49264 .34787 L F
.48871 .33573 m .48545 .32964 L .49106 .35478 L .937 .579 .174 r
F
.8653 .31505 m .86907 .30921 L .8716 .31301 L .663 .741 .908 r
F
.8653 .31505 m .86276 .31126 L .86907 .30921 L F
.1294 .31505 m .13091 .3092 L .13491 .313 L .664 .741 .908 r
F
.1294 .31505 m .1254 .31126 L .13091 .3092 L F
.68133 .31506 m .68453 .3092 L .68743 .313 L .663 .741 .908 r
F
.68133 .31506 m .67842 .31126 L .68453 .3092 L F
.31338 .31506 m .31545 .3092 L .31908 .313 L .664 .741 .908 r
F
.31338 .31506 m .30974 .31127 L .31545 .3092 L F
.53439 .35915 m .53728 .38858 L .54049 .38878 L .754 .426 .429 r
F
.53439 .35915 m .53123 .37275 L .53728 .38858 L F
.2289 .31489 m .23071 .30904 L .23451 .31284 L .663 .741 .908 r
F
.2289 .31489 m .22509 .3111 L .23071 .30904 L F
.78087 .3149 m .78438 .30904 L .78708 .31284 L .664 .741 .908 r
F
.78087 .3149 m .77816 .3111 L .78438 .30904 L F
.1444 .31474 m .14596 .30889 L .14993 .31269 L .663 .741 .908 r
F
.1444 .31474 m .14043 .31094 L .14596 .30889 L F
.69642 .31474 m .69967 .30889 L .70254 .31269 L .664 .741 .908 r
F
.69642 .31474 m .69354 .31095 L .69967 .30889 L F
.32841 .31475 m .33053 .3089 L .33413 .3127 L .663 .741 .908 r
F
.32841 .31475 m .3248 .31095 L .33053 .3089 L F
.79598 .31458 m .79954 .30874 L .8022 .31253 L F
.79598 .31458 m .7933 .31079 L .79954 .30874 L F
.24392 .31458 m .24578 .30873 L .24955 .31253 L .664 .741 .908 r
F
.24392 .31458 m .24014 .31079 L .24578 .30873 L F
.46276 .39963 m .46545 .38547 L .46868 .39462 L .972 .889 .52 r
F
.46276 .39963 m .45923 .40514 L .46545 .38547 L F
.15941 .31442 m .16101 .30857 L .16495 .31237 L .663 .741 .908 r
F
.15941 .31442 m .15546 .31063 L .16101 .30857 L F
.71152 .31443 m .71482 .30857 L .71765 .31237 L .664 .742 .908 r
F
.71152 .31443 m .70867 .31064 L .71482 .30857 L F
.25894 .31427 m .26085 .30841 L .26459 .31221 L .664 .741 .908 r
F
.25894 .31427 m .25519 .31047 L .26085 .30841 L F
.81109 .31427 m .8147 .30841 L .81734 .31221 L .664 .742 .908 r
F
.81109 .31427 m .80845 .31048 L .8147 .30841 L F
.46868 .39462 m .47136 .38124 L .47457 .39199 L .69 .58 .727 r
F
.46868 .39462 m .46545 .38547 L .47136 .38124 L F
.42125 .4381 m .41712 .45595 L .42326 .44541 L .183 0 .278 r
F
.17442 .31411 m .17607 .30825 L .17998 .31205 L .664 .741 .908 r
F
.17442 .31411 m .1705 .31031 L .17607 .30825 L F
.72662 .31411 m .72996 .30825 L .73277 .31205 L F
.72662 .31411 m .7238 .31031 L .72996 .30825 L F
.61843 .3364 m .61519 .32553 L .62754 .52976 L .977 .678 .37 r
F
.61519 .32553 m .61208 .31885 L .62407 .51745 L .974 .674 .38 r
F
.27397 .31395 m .27592 .30809 L .27963 .31189 L .663 .741 .908 r
F
.27397 .31395 m .27025 .31015 L .27592 .30809 L F
.82621 .31395 m .82987 .30809 L .83247 .3119 L F
.82621 .31395 m .82359 .31015 L .82987 .30809 L F
.64213 .31396 m .64522 .30809 L .64819 .3119 L F
.64213 .31396 m .63915 .31016 L .64522 .30809 L F
.18944 .31379 m .19113 .30793 L .19501 .31174 L F
.18944 .31379 m .18555 .30999 L .19113 .30793 L F
.74173 .31379 m .74512 .30793 L .7479 .31174 L .664 .741 .908 r
F
.74173 .31379 m .73894 .31 L .74512 .30793 L F
.52205 .34653 m .51879 .35898 L .52476 .37057 L .722 .387 .411 r
F
.84134 .31363 m .84504 .30778 L .84762 .31159 L .663 .741 .908 r
F
.84134 .31363 m .83875 .30983 L .84504 .30778 L F
.289 .31364 m .291 .30779 L .29468 .3116 L .662 .741 .908 r
F
.289 .31364 m .28531 .30984 L .291 .30779 L F
.65723 .31365 m .66036 .30779 L .66331 .3116 L .663 .741 .908 r
F
.65723 .31365 m .65427 .30985 L .66036 .30779 L F
.45004 .40081 m .45309 .37097 L .45601 .39481 L .98 .783 .566 r
F
.45004 .40081 m .44655 .40146 L .45309 .37097 L F
.55269 .37057 m .55562 .37668 L .55865 .36766 L .348 .007 .237 r
F
.55269 .37057 m .54963 .37984 L .55562 .37668 L F
.62361 .43878 m .62595 .41088 L .6293 .42506 L .976 .776 .57 r
F
.6265 .43816 m .62361 .43878 L .6293 .42506 L .983 .898 .65 r
F
.62177 .35043 m .61843 .3364 L .63062 .53401 L .978 .681 .36 r
F
.63069 .53424 m .63062 .53401 L .63087 .538 L F
.62177 .35043 m .63062 .53401 L .63069 .53424 L F
.61843 .3364 m .62754 .52976 L .63092 .53883 L .977 .678 .37 r
F
.61208 .31885 m .62053 .50256 L .62407 .51745 L .97 .668 .392 r
F
.62055 .49833 m .61851 .32131 L .62172 .33006 L .956 .677 .469 r
F
.62053 .50256 m .62048 .49805 L .62055 .49833 L F
.62048 .49805 m .61851 .32131 L .62055 .49833 L F
.62177 .35043 m .63087 .538 L .63088 .53805 L .978 .681 .36 r
F
.6265 .43816 m .6293 .42506 L .63259 .43715 L .983 .898 .65 r
F
.62517 .3665 m .62177 .35043 L .63416 .54383 L .979 .682 .35 r
F
.62177 .35043 m .63092 .53883 L .63416 .54383 L .978 .681 .36 r
F
.62409 .51327 m .62172 .33006 L .62495 .33951 L .96 .681 .464 r
F
.62407 .51745 m .62401 .51299 L .62409 .51327 L F
.62401 .51299 m .62172 .33006 L .62409 .51327 L F
.63088 .53805 m .63087 .538 L .63092 .53883 L .978 .681 .36 r
F
.20446 .31348 m .2062 .30762 L .21005 .31143 L .664 .741 .908 r
F
.20446 .31348 m .2006 .30969 L .2062 .30762 L F
.75684 .31349 m .76028 .30762 L .76303 .31143 L .664 .741 .907 r
F
.75684 .31349 m .75408 .30968 L .76028 .30762 L F
.403 .44667 m .40786 .37375 L .41043 .40189 L .833 .592 .575 r
F
.403 .44667 m .40037 .4198 L .40786 .37375 L F
.1199 .31332 m .12138 .30745 L .1254 .31126 L .663 .741 .908 r
F
.1199 .31332 m .11587 .30952 L .12138 .30745 L F
.85647 .31333 m .86021 .30745 L .86276 .31126 L .664 .741 .908 r
F
.85647 .31333 m .85391 .30952 L .86021 .30745 L F
.67232 .31333 m .67551 .30746 L .67842 .31126 L .665 .742 .908 r
F
.67232 .31333 m .6694 .30954 L .67551 .30746 L F
.30404 .31334 m .30609 .30746 L .30974 .31127 L .665 .742 .907 r
F
.30404 .31334 m .30038 .30954 L .30609 .30746 L F
.77195 .31316 m .77544 .30729 L .77816 .3111 L .664 .741 .908 r
F
.77195 .31316 m .76923 .30936 L .77544 .30729 L F
.21948 .31316 m .22127 .30729 L .22509 .3111 L F
.21948 .31316 m .21565 .30936 L .22127 .30729 L F
.31908 .313 m .32118 .30714 L .3248 .31095 L .663 .741 .908 r
F
.31908 .313 m .31545 .3092 L .32118 .30714 L F
.13491 .313 m .13644 .30713 L .14043 .31094 L F
.13491 .313 m .13091 .3092 L .13644 .30713 L F
.68743 .313 m .69066 .30714 L .69354 .31095 L F
.68743 .313 m .68453 .3092 L .69066 .30714 L F
.47457 .39199 m .47136 .38124 L .47713 .38678 L .265 .293 .704 r
F
.47136 .38124 m .47401 .37046 L .47713 .38678 L .338 .266 .627 r
F
.39478 .45313 m .39196 .43243 L .3957 .48455 L .934 .665 .191 r
F
.39196 .43243 m .39121 .5038 L .3957 .48455 L .984 .703 .361 r
F
.38687 .51765 m .39547 .35993 L .39793 .38904 L .971 .715 .49 r
F
.38687 .51765 m .38278 .52438 L .39547 .35993 L F
.78708 .31284 m .79061 .30698 L .7933 .31079 L .663 .741 .908 r
F
.78708 .31284 m .78438 .30904 L .79061 .30698 L F
.23451 .31284 m .23635 .30698 L .24014 .31079 L .664 .741 .908 r
F
.23451 .31284 m .23071 .30904 L .23635 .30698 L F
.48256 .35821 m .47911 .36334 L .48545 .32964 L 1 .815 .505 r
F
.47911 .36334 m .48201 .33669 L .48545 .32964 L .901 .706 .63 r
F
.48545 .32964 m .48201 .33669 L .48785 .34141 L .647 .26 .297 r
F
.50685 .36863 m .50365 .35338 L .50926 .33492 L .809 .599 .617 r
F
.50958 .33485 m .50926 .33492 L .50968 .33355 L F
.50685 .36863 m .50926 .33492 L .50958 .33485 L F
.50365 .35338 m .50631 .34954 L .50968 .33355 L .064 .082 .567 r
F
.50365 .35338 m .50048 .33615 L .50631 .34954 L F
.49773 .35372 m .50048 .33615 L .50365 .35338 L .989 .868 .518 r
F
.50083 .33696 m .50291 .36344 L .50631 .34954 L .953 .622 .215 r
F
.50048 .33615 m .50056 .33703 L .50083 .33696 L F
.50056 .33703 m .50291 .36344 L .50083 .33696 L F
.50968 .33355 m .50631 .34954 L .51224 .35771 L .657 .338 .422 r
F
.14993 .31269 m .1515 .30682 L .15546 .31063 L .664 .741 .908 r
F
.14993 .31269 m .14596 .30889 L .1515 .30682 L F
.70254 .31269 m .70581 .30683 L .70867 .31064 L .663 .741 .908 r
F
.70254 .31269 m .69967 .30889 L .70581 .30683 L F
.33413 .3127 m .33627 .30684 L .33986 .31065 L F
.33413 .3127 m .33053 .3089 L .33627 .30684 L F
.47457 .39199 m .47713 .38678 L .48046 .38959 L .265 .293 .704 r
F
.24955 .31253 m .25143 .30666 L .25519 .31047 L .663 .741 .908 r
F
.24955 .31253 m .24578 .30873 L .25143 .30666 L F
.8022 .31253 m .80579 .30667 L .80845 .31048 L .664 .742 .908 r
F
.8022 .31253 m .79954 .30874 L .80579 .30667 L F
.71765 .31237 m .72097 .3065 L .7238 .31031 L F
.71765 .31237 m .71482 .30857 L .72097 .3065 L F
.16495 .31237 m .16657 .3065 L .1705 .31031 L .664 .741 .908 r
F
.16495 .31237 m .16101 .30857 L .16657 .3065 L F
.58932 .39 m .58584 .36838 L .59104 .3245 L .86 .613 .564 r
F
.58584 .36838 m .58811 .32861 L .59104 .3245 L .729 .519 .607 r
F
.59104 .3245 m .58811 .32861 L .59509 .36953 L .925 .587 .377 r
F
.26459 .31221 m .26652 .30634 L .27025 .31015 L .664 .741 .908 r
F
.26459 .31221 m .26085 .30841 L .26652 .30634 L F
.81734 .31221 m .82097 .30634 L .82359 .31015 L F
.81734 .31221 m .8147 .30841 L .82097 .30634 L F
.17998 .31205 m .18165 .30618 L .18555 .30999 L .663 .741 .908 r
F
.17998 .31205 m .17607 .30825 L .18165 .30618 L F
.73277 .31205 m .73614 .30618 L .73894 .31 L F
.73277 .31205 m .72996 .30825 L .73614 .30618 L F
.61208 .31885 m .60908 .31713 L .62053 .50256 L .97 .668 .392 r
F
.27963 .31189 m .28161 .30603 L .28531 .30984 L .663 .741 .908 r
F
.27963 .31189 m .27592 .30809 L .28161 .30603 L F
.83247 .3119 m .83615 .30603 L .83875 .30983 L F
.83247 .3119 m .82987 .30809 L .83615 .30603 L F
.64819 .3119 m .6513 .30603 L .65427 .30985 L F
.64819 .3119 m .64522 .30809 L .6513 .30603 L F
.42326 .44541 m .41951 .45108 L .42656 .41114 L .997 .798 .517 r
F
.41951 .45108 m .42257 .42573 L .42656 .41114 L .896 .708 .641 r
F
.63145 .36001 m .62819 .34953 L .63311 .31296 L .916 .676 .561 r
F
.63311 .31296 m .63615 .30634 L .63915 .31016 L .696 .742 .887 r
F
.63311 .31296 m .6301 .30896 L .63615 .30634 L F
.62819 .34953 m .6301 .30896 L .63311 .31296 L .906 .676 .578 r
F
.19501 .31174 m .19672 .30587 L .2006 .30969 L .663 .741 .908 r
F
.19501 .31174 m .19113 .30793 L .19672 .30587 L F
.7479 .31174 m .75131 .30586 L .75408 .30968 L .664 .741 .908 r
F
.7479 .31174 m .74512 .30793 L .75131 .30586 L F
.11037 .31158 m .11183 .3057 L .11587 .30952 L F
.11037 .31158 m .10632 .30777 L .11183 .3057 L F
.84762 .31159 m .85134 .3057 L .85391 .30952 L .664 .742 .908 r
F
.84762 .31159 m .84504 .30778 L .85134 .3057 L F
.29468 .3116 m .2967 .30572 L .30038 .30954 L F
.29468 .3116 m .291 .30779 L .2967 .30572 L F
.66331 .3116 m .66646 .30572 L .6694 .30954 L .663 .741 .908 r
F
.66331 .3116 m .66036 .30779 L .66646 .30572 L F
.76303 .31143 m .76649 .30554 L .76923 .30936 L .664 .741 .908 r
F
.76303 .31143 m .76028 .30762 L .76649 .30554 L F
.21005 .31143 m .21181 .30554 L .21565 .30936 L F
.21005 .31143 m .2062 .30762 L .21181 .30554 L F
.86276 .31126 m .86653 .30539 L .86907 .30921 L .663 .741 .908 r
F
.86276 .31126 m .86021 .30745 L .86653 .30539 L F
.67842 .31126 m .68163 .30538 L .68453 .3092 L .664 .742 .908 r
F
.67842 .31126 m .67551 .30746 L .68163 .30538 L F
.1254 .31126 m .1269 .30538 L .13091 .3092 L .664 .741 .908 r
F
.1254 .31126 m .12138 .30745 L .1269 .30538 L F
.30974 .31127 m .31181 .30538 L .31545 .3092 L F
.30974 .31127 m .30609 .30746 L .31181 .30538 L F
.22509 .3111 m .2269 .30522 L .23071 .30904 L .663 .741 .908 r
F
.22509 .3111 m .22127 .30729 L .2269 .30522 L F
.77816 .3111 m .78167 .30522 L .78438 .30904 L .664 .741 .908 r
F
.77816 .3111 m .77544 .30729 L .78167 .30522 L F
.14043 .31094 m .14197 .30507 L .14596 .30889 L .663 .741 .908 r
F
.14043 .31094 m .13644 .30713 L .14197 .30507 L F
.69354 .31095 m .69679 .30508 L .69967 .30889 L F
.69354 .31095 m .69066 .30714 L .69679 .30508 L F
.3248 .31095 m .32691 .30508 L .33053 .3089 L F
.3248 .31095 m .32118 .30714 L .32691 .30508 L F
.7933 .31079 m .79686 .30492 L .79954 .30874 L F
.7933 .31079 m .79061 .30698 L .79686 .30492 L F
.24014 .31079 m .24199 .30491 L .24578 .30873 L F
.24014 .31079 m .23635 .30698 L .24199 .30491 L F
.48046 .38959 m .47713 .38678 L .48315 .37632 L .907 .802 .732 r
F
.42744 .37249 m .42468 .34698 L .4307 .33958 L .642 .453 .612 r
F
.42468 .34698 m .42656 .35929 L .4307 .33958 L 0 0 .116 r
F
.42468 .34698 m .4218 .32651 L .42656 .35929 L F
.4218 .32651 m .42259 .37138 L .42656 .35929 L .965 .65 .366 r
F
.4218 .32651 m .41841 .32138 L .42259 .37138 L F
.15546 .31063 m .15706 .30475 L .16101 .30857 L .663 .741 .908 r
F
.15546 .31063 m .1515 .30682 L .15706 .30475 L F
.70867 .31064 m .71197 .30476 L .71482 .30857 L .664 .742 .908 r
F
.70867 .31064 m .70581 .30683 L .71197 .30476 L F
.47652 .36875 m .47496 .35946 L .47911 .36334 L .111 .106 .571 r
F
.47496 .35946 m .47343 .35032 L .47599 .35618 L F
.47496 .35946 m .47599 .35618 L .47911 .36334 L F
.47343 .35032 m .47581 .35684 L .47911 .36334 L 0 0 .291 r
F
.47911 .36334 m .47581 .35684 L .4799 .34356 L .901 .706 .63 r
F
.48124 .34371 m .4799 .34356 L .48201 .33669 L F
.47911 .36334 m .4799 .34356 L .48124 .34371 L F
.47581 .35684 m .47846 .34835 L .47952 .34486 L .271 .228 .625 r
F
.47806 .34955 m .47952 .34486 L .48201 .33669 L F
.47581 .35684 m .47952 .34486 L .47806 .34955 L F
.47581 .35684 m .47268 .33987 L .47798 .34765 L F
.47796 .34996 m .47798 .34765 L .47846 .34835 L F
.47581 .35684 m .47798 .34765 L .47796 .34996 L F
.47478 .34296 m .47501 .35027 L .47846 .34835 L 0 0 .177 r
F
.47501 .35027 m .47792 .32465 L .47821 .32423 L .744 .561 .647 r
F
.4781 .33543 m .47821 .32423 L .48139 .31965 L F
.47501 .35027 m .47821 .32423 L .4781 .33543 L F
.47268 .33987 m .47333 .34279 L .47478 .34296 L 0 0 .177 r
F
.47333 .34279 m .47501 .35027 L .47478 .34296 L F
.47031 .3341 m .47268 .33987 L .47581 .35684 L .755 .294 0 r
F
.47343 .35032 m .47031 .3341 L .47561 .356 L 0 0 .291 r
F
.47031 .3341 m .46698 .33021 L .47268 .33987 L .755 .294 0 r
F
.47241 .33941 m .46955 .32345 L .47268 .33987 L .668 .752 .261 r
F
.46698 .33021 m .4694 .32385 L .47241 .33941 L F
.4694 .32385 m .46955 .32345 L .47241 .33941 L F
.47573 .3566 m .47561 .356 L .47581 .35684 L 0 0 .291 r
F
.47343 .35032 m .47561 .356 L .47573 .3566 L F
.33986 .31065 m .33627 .30684 L .34203 .30476 L .664 .742 .908 r
F
.25519 .31047 m .25709 .30459 L .26085 .30841 L .664 .741 .908 r
F
.25519 .31047 m .25143 .30666 L .25709 .30459 L F
.80845 .31048 m .81205 .30459 L .8147 .30841 L .664 .742 .908 r
F
.80845 .31048 m .80579 .30667 L .81205 .30459 L F
.7238 .31031 m .72715 .30443 L .72996 .30825 L .664 .741 .908 r
F
.7238 .31031 m .72097 .3065 L .72715 .30443 L F
.1705 .31031 m .17214 .30443 L .17607 .30825 L F
.1705 .31031 m .16657 .3065 L .17214 .30443 L F
.47713 .38678 m .47401 .37046 L .47976 .37861 L .278 .238 .632 r
F
.47401 .37046 m .47652 .36875 L .47976 .37861 L 0 0 .473 r
F
.27025 .31015 m .2722 .30427 L .27592 .30809 L .663 .741 .908 r
F
.27025 .31015 m .26652 .30634 L .2722 .30427 L F
.82359 .31015 m .82725 .30427 L .82987 .30809 L F
.82359 .31015 m .82097 .30634 L .82725 .30427 L F
.63915 .31016 m .64223 .30428 L .64522 .30809 L F
.63915 .31016 m .63615 .30634 L .64223 .30428 L F
.18555 .30999 m .18723 .30411 L .19113 .30793 L F
.18555 .30999 m .18165 .30618 L .18723 .30411 L F
.73894 .31 m .74233 .30411 L .74512 .30793 L .664 .741 .908 r
F
.73894 .31 m .73614 .30618 L .74233 .30411 L F
.53073 .34455 m .52749 .32185 L .53344 .32067 L .568 .408 .625 r
F
.52476 .37057 m .52749 .32185 L .53073 .34455 L .807 .579 .592 r
F
.52476 .37057 m .52152 .34929 L .52749 .32185 L F
.52749 .32185 m .53024 .32296 L .53344 .32067 L 0 .089 .646 r
F
.52749 .32185 m .52427 .31619 L .53024 .32296 L F
.52152 .34929 m .52427 .31619 L .52749 .32185 L .69 .495 .618 r
F
.83875 .30983 m .84245 .30395 L .84504 .30778 L .664 .742 .908 r
F
.83875 .30983 m .83615 .30603 L .84245 .30395 L F
.28531 .30984 m .2873 .30397 L .291 .30779 L .662 .741 .908 r
F
.28531 .30984 m .28161 .30603 L .2873 .30397 L F
.65427 .30985 m .6574 .30396 L .66036 .30779 L .663 .741 .908 r
F
.65427 .30985 m .6513 .30603 L .6574 .30396 L F
.75408 .30968 m .75752 .30379 L .76028 .30762 L .664 .741 .908 r
F
.75408 .30968 m .75131 .30586 L .75752 .30379 L F
.2006 .30969 m .20233 .3038 L .2062 .30762 L F
.2006 .30969 m .19672 .30587 L .20233 .3038 L F
.11587 .30952 m .11734 .30363 L .12138 .30745 L .663 .741 .908 r
F
.11587 .30952 m .11183 .3057 L .11734 .30363 L F
.85391 .30952 m .85766 .30363 L .86021 .30745 L F
.85391 .30952 m .85134 .3057 L .85766 .30363 L F
.6694 .30954 m .67258 .30364 L .67551 .30746 L .664 .742 .908 r
F
.6694 .30954 m .66646 .30572 L .67258 .30364 L F
.30038 .30954 m .30242 .30363 L .30609 .30746 L .665 .742 .907 r
F
.30038 .30954 m .2967 .30572 L .30242 .30363 L F
.47713 .38678 m .47976 .37861 L .48315 .37632 L .278 .238 .632 r
F
.76923 .30936 m .77271 .30347 L .77544 .30729 L .664 .741 .908 r
F
.76923 .30936 m .76649 .30554 L .77271 .30347 L F
.21565 .30936 m .21743 .30347 L .22127 .30729 L F
.21565 .30936 m .21181 .30554 L .21743 .30347 L F
.31545 .3092 m .31754 .30332 L .32118 .30714 L .663 .741 .908 r
F
.31545 .3092 m .31181 .30538 L .31754 .30332 L F
.13091 .3092 m .13243 .30331 L .13644 .30713 L F
.13091 .3092 m .1269 .30538 L .13243 .30331 L F
.68453 .3092 m .68776 .30332 L .69066 .30714 L F
.68453 .3092 m .68163 .30538 L .68776 .30332 L F
.78438 .30904 m .78791 .30316 L .79061 .30698 L F
.78438 .30904 m .78167 .30522 L .78791 .30316 L F
.23071 .30904 m .23254 .30315 L .23635 .30698 L .664 .741 .908 r
F
.23071 .30904 m .2269 .30522 L .23254 .30315 L F
.14596 .30889 m .14752 .30299 L .1515 .30682 L F
.14596 .30889 m .14197 .30507 L .14752 .30299 L F
.69967 .30889 m .70295 .30301 L .70581 .30683 L .663 .741 .908 r
F
.69967 .30889 m .69679 .30508 L .70295 .30301 L F
.33053 .3089 m .33266 .30302 L .33627 .30684 L F
.33053 .3089 m .32691 .30508 L .33266 .30302 L F
.24578 .30873 m .24765 .30283 L .25143 .30666 L F
.24578 .30873 m .24199 .30491 L .24765 .30283 L F
.79954 .30874 m .80312 .30284 L .80579 .30667 L .664 .742 .908 r
F
.79954 .30874 m .79686 .30492 L .80312 .30284 L F
.16101 .30857 m .16262 .30267 L .16657 .3065 L .664 .741 .908 r
F
.16101 .30857 m .15706 .30475 L .16262 .30267 L F
.71482 .30857 m .71814 .30267 L .72097 .3065 L .664 .742 .908 r
F
.71482 .30857 m .71197 .30476 L .71814 .30267 L F
.8147 .30841 m .81833 .30251 L .82097 .30634 L .663 .741 .908 r
F
.8147 .30841 m .81205 .30459 L .81833 .30251 L F
.26085 .30841 m .26277 .30251 L .26652 .30634 L .664 .741 .908 r
F
.26085 .30841 m .25709 .30459 L .26277 .30251 L F
.49773 .35372 m .49529 .35727 L .50048 .33615 L .989 .868 .518 r
F
.49529 .35727 m .49531 .35516 L .50048 .33615 L F
.49437 .35862 m .49724 .32767 L .50048 .33615 L .947 .74 .591 r
F
.49437 .35862 m .49106 .35478 L .49724 .32767 L F
.49724 .32767 m .49387 .33259 L .49959 .35967 L .89 .544 .386 r
F
.49539 .33977 m .49643 .33677 L .49959 .35967 L .152 0 .189 r
F
.49387 .33259 m .49541 .33511 L .49539 .33977 L F
.49541 .33511 m .49643 .33677 L .49539 .33977 L F
.49529 .35727 m .49437 .35862 L .49531 .35516 L .989 .868 .518 r
F
.50048 .33615 m .49724 .32767 L .50291 .36344 L .953 .622 .215 r
F
.17607 .30825 m .17773 .30235 L .18165 .30618 L .663 .741 .908 r
F
.17607 .30825 m .17214 .30443 L .17773 .30235 L F
.72996 .30825 m .73333 .30235 L .73614 .30618 L F
.72996 .30825 m .72715 .30443 L .73333 .30235 L F
.82987 .30809 m .83354 .3022 L .83615 .30603 L F
.82987 .30809 m .82725 .30427 L .83354 .3022 L F
.27592 .30809 m .27789 .3022 L .28161 .30603 L F
.27592 .30809 m .2722 .30427 L .27789 .3022 L F
.64522 .30809 m .64832 .3022 L .6513 .30603 L F
.64522 .30809 m .64223 .30428 L .64832 .3022 L F
.62819 .34953 m .62495 .33951 L .6301 .30896 L .906 .676 .578 r
F
.6301 .30896 m .63314 .30251 L .63615 .30634 L .688 .742 .892 r
F
.6301 .30896 m .62708 .305 L .63314 .30251 L F
.62495 .33951 m .62708 .305 L .6301 .30896 L .896 .676 .597 r
F
.19113 .30793 m .19283 .30204 L .19672 .30587 L .663 .741 .908 r
F
.19113 .30793 m .18723 .30411 L .19283 .30204 L F
.74512 .30793 m .74853 .30203 L .75131 .30586 L .664 .741 .908 r
F
.74512 .30793 m .74233 .30411 L .74853 .30203 L F
.5436 .37563 m .54647 .38128 L .54963 .37984 L .228 0 .261 r
F
.5436 .37563 m .54049 .38878 L .54647 .38128 L F
.10632 .30777 m .10777 .30187 L .11183 .3057 L .664 .741 .908 r
F
.10632 .30777 m .10226 .30395 L .10777 .30187 L F
.84504 .30778 m .84876 .30187 L .85134 .3057 L .664 .741 .907 r
F
.84504 .30778 m .84245 .30395 L .84876 .30187 L F
.66036 .30779 m .66351 .30188 L .66646 .30572 L .664 .741 .908 r
F
.66036 .30779 m .6574 .30396 L .66351 .30188 L F
.291 .30779 m .29301 .30189 L .2967 .30572 L .664 .742 .908 r
F
.291 .30779 m .2873 .30397 L .29301 .30189 L F
.76028 .30762 m .76374 .30171 L .76649 .30554 L .663 .741 .908 r
F
.76028 .30762 m .75752 .30379 L .76374 .30171 L F
.2062 .30762 m .20795 .30171 L .21181 .30554 L .664 .741 .908 r
F
.2062 .30762 m .20233 .3038 L .20795 .30171 L F
.62862 .3836 m .62517 .3665 L .63725 .54474 L .979 .682 .34 r
F
.62517 .3665 m .63416 .54383 L .63725 .54474 L .979 .682 .35 r
F
.86021 .30745 m .86399 .30156 L .86653 .30539 L .663 .741 .908 r
F
.86021 .30745 m .85766 .30363 L .86399 .30156 L F
.12138 .30745 m .12287 .30155 L .1269 .30538 L .664 .741 .908 r
F
.12138 .30745 m .11734 .30363 L .12287 .30155 L F
.67551 .30746 m .67871 .30155 L .68163 .30538 L .664 .742 .908 r
F
.67551 .30746 m .67258 .30364 L .67871 .30155 L F
.30609 .30746 m .30815 .30155 L .31181 .30538 L .664 .741 .908 r
F
.30609 .30746 m .30242 .30363 L .30815 .30155 L F
.49724 .32767 m .49959 .35967 L .50291 .36344 L .89 .544 .386 r
F
.53667 .33212 m .53344 .32067 L .53942 .32043 L .559 .472 .713 r
F
.53073 .34455 m .53344 .32067 L .53667 .33212 L .568 .408 .625 r
F
.53344 .32067 m .53622 .31864 L .536 .32057 L .418 .81 .578 r
F
.53344 .32067 m .53024 .32296 L .53622 .31864 L F
.53515 .31941 m .53303 .32865 L .53622 .31864 L .229 0 .244 r
F
.53024 .32296 m .53303 .32865 L .53515 .31941 L F
.53303 .32865 m .52981 .34204 L .53089 .33801 L 0 0 0 r
F
.53622 .31864 m .53303 .32865 L .53644 .3167 L .758 .766 .259 r
F
.53303 .32865 m .53089 .33801 L .53581 .31966 L 0 0 0 r
F
.53622 .31864 m .53644 .3167 L .53898 .30778 L .758 .766 .259 r
F
.536 .32057 m .53622 .31864 L .53942 .32043 L .418 .81 .578 r
F
.22127 .30729 m .22307 .30139 L .2269 .30522 L .663 .741 .908 r
F
.22127 .30729 m .21743 .30347 L .22307 .30139 L F
.77544 .30729 m .77895 .30139 L .78167 .30522 L F
.77544 .30729 m .77271 .30347 L .77895 .30139 L F
.52152 .34929 m .5183 .32696 L .52427 .31619 L .69 .495 .618 r
F
.52427 .31619 m .52702 .33548 L .53024 .32296 L .634 .303 .392 r
F
.52427 .31619 m .52101 .3296 L .52702 .33548 L F
.5183 .32696 m .52101 .3296 L .52427 .31619 L 0 0 .484 r
F
.13644 .30713 m .13797 .30124 L .14197 .30507 L .663 .741 .908 r
F
.13644 .30713 m .13243 .30331 L .13797 .30124 L F
.32118 .30714 m .32328 .30125 L .32691 .30508 L F
.32118 .30714 m .31754 .30332 L .32328 .30125 L F
.69066 .30714 m .69391 .30125 L .69679 .30508 L F
.69066 .30714 m .68776 .30332 L .69391 .30125 L F
.23635 .30698 m .23819 .30107 L .24199 .30491 L F
.23635 .30698 m .23254 .30315 L .23819 .30107 L F
.79061 .30698 m .79417 .30108 L .79686 .30492 L F
.79061 .30698 m .78791 .30316 L .79417 .30108 L F
.60908 .31713 m .60622 .32083 L .61693 .48561 L .962 .658 .403 r
F
.1515 .30682 m .15308 .30091 L .15706 .30475 L .663 .741 .908 r
F
.1515 .30682 m .14752 .30299 L .15308 .30091 L F
.70581 .30683 m .70911 .30093 L .71197 .30476 L .664 .741 .908 r
F
.70581 .30683 m .70295 .30301 L .70911 .30093 L F
.33627 .30684 m .33842 .30093 L .34203 .30476 L F
.33627 .30684 m .33266 .30302 L .33842 .30093 L F
.25143 .30666 m .25332 .30075 L .25709 .30459 L F
.25143 .30666 m .24765 .30283 L .25332 .30075 L F
.80579 .30667 m .80939 .30075 L .81205 .30459 L F
.80579 .30667 m .80312 .30284 L .80939 .30075 L F
.72097 .3065 m .72432 .30059 L .72715 .30443 L .664 .742 .908 r
F
.72097 .3065 m .71814 .30267 L .72432 .30059 L F
.16657 .3065 m .1682 .30059 L .17214 .30443 L .664 .741 .908 r
F
.16657 .3065 m .16262 .30267 L .1682 .30059 L F
.53994 .3522 m .53667 .33212 L .54267 .33454 L .5 .371 .636 r
F
.53401 .37155 m .53667 .33212 L .53994 .3522 L .684 .481 .605 r
F
.53401 .37155 m .53073 .34455 L .53667 .33212 L F
.53667 .33212 m .53942 .32043 L .54267 .33454 L .559 .472 .713 r
F
.26652 .30634 m .26845 .30043 L .2722 .30427 L .663 .741 .908 r
F
.26652 .30634 m .26277 .30251 L .26845 .30043 L F
.82097 .30634 m .82462 .30044 L .82725 .30427 L F
.82097 .30634 m .81833 .30251 L .82462 .30044 L F
.63615 .30634 m .63923 .30044 L .64223 .30428 L F
.63615 .30634 m .63314 .30251 L .63923 .30044 L F
.18165 .30618 m .18332 .30027 L .18723 .30411 L F
.18165 .30618 m .17773 .30235 L .18332 .30027 L F
.73614 .30618 m .73953 .30028 L .74233 .30411 L F
.73614 .30618 m .73333 .30235 L .73953 .30028 L F
.83615 .30603 m .83985 .30011 L .84245 .30395 L .664 .741 .908 r
F
.83615 .30603 m .83354 .3022 L .83985 .30011 L F
.28161 .30603 m .28359 .30014 L .2873 .30397 L .662 .741 .908 r
F
.28161 .30603 m .27789 .3022 L .28359 .30014 L F
.6513 .30603 m .65443 .30013 L .6574 .30396 L .663 .741 .908 r
F
.6513 .30603 m .64832 .3022 L .65443 .30013 L F
.67046 .51127 m .66754 .50835 L .67314 .49457 L .937 .796 .679 r
F
.66754 .50835 m .67025 .49216 L .67314 .49457 L .888 .75 .704 r
F
.75131 .30586 m .75475 .29995 L .75752 .30379 L .663 .741 .908 r
F
.75131 .30586 m .74853 .30203 L .75475 .29995 L F
.19672 .30587 m .19845 .29996 L .20233 .3038 L .664 .741 .908 r
F
.19672 .30587 m .19283 .30204 L .19845 .29996 L F
.85134 .3057 m .85509 .29979 L .85766 .30363 L F
.85134 .3057 m .84876 .30187 L .85509 .29979 L F
.11183 .3057 m .11329 .29979 L .11734 .30363 L F
.11183 .3057 m .10777 .30187 L .11329 .29979 L F
.66646 .30572 m .66964 .2998 L .67258 .30364 L F
.66646 .30572 m .66351 .30188 L .66964 .2998 L F
.2967 .30572 m .29874 .29979 L .30242 .30363 L .664 .741 .907 r
F
.2967 .30572 m .29301 .30189 L .29874 .29979 L F
.76649 .30554 m .76997 .29963 L .77271 .30347 L .664 .741 .908 r
F
.76649 .30554 m .76374 .30171 L .76997 .29963 L F
.21181 .30554 m .21358 .29963 L .21743 .30347 L F
.21181 .30554 m .20795 .30171 L .21358 .29963 L F
.4307 .33958 m .4319 .37688 L .43544 .37777 L .728 .42 .457 r
F
.4307 .33958 m .42656 .35929 L .4319 .37688 L F
.31181 .30538 m .31389 .29948 L .31754 .30332 L .663 .741 .908 r
F
.31181 .30538 m .30815 .30155 L .31389 .29948 L F
.1269 .30538 m .12841 .29947 L .13243 .30331 L F
.1269 .30538 m .12287 .30155 L .12841 .29947 L F
.68163 .30538 m .68485 .29947 L .68776 .30332 L F
.68163 .30538 m .67871 .30155 L .68485 .29947 L F
.78167 .30522 m .7852 .29932 L .78791 .30316 L F
.78167 .30522 m .77895 .30139 L .7852 .29932 L F
.2269 .30522 m .22872 .29931 L .23254 .30315 L .664 .741 .908 r
F
.2269 .30522 m .22307 .30139 L .22872 .29931 L F
.14197 .30507 m .14353 .29915 L .14752 .30299 L F
.14197 .30507 m .13797 .30124 L .14353 .29915 L F
.69679 .30508 m .70007 .29916 L .70295 .30301 L F
.69679 .30508 m .69391 .30125 L .70007 .29916 L F
.32691 .30508 m .32904 .29917 L .33266 .30302 L .663 .741 .908 r
F
.32691 .30508 m .32328 .30125 L .32904 .29917 L F
.47976 .37861 m .47652 .36875 L .48256 .35821 L .788 .623 .676 r
F
.47652 .36875 m .47911 .36334 L .48256 .35821 L .111 .106 .571 r
F
.24199 .30491 m .24386 .29899 L .24765 .30283 L .663 .741 .908 r
F
.24199 .30491 m .23819 .30107 L .24386 .29899 L F
.79686 .30492 m .80044 .29899 L .80312 .30284 L .664 .741 .907 r
F
.79686 .30492 m .79417 .30108 L .80044 .29899 L F
.15706 .30475 m .15866 .29883 L .16262 .30267 L .664 .741 .908 r
F
.15706 .30475 m .15308 .30091 L .15866 .29883 L F
.71197 .30476 m .71529 .29884 L .71814 .30267 L .664 .742 .908 r
F
.71197 .30476 m .70911 .30093 L .71529 .29884 L F
.81205 .30459 m .81568 .29867 L .81833 .30251 L .663 .741 .908 r
F
.81205 .30459 m .80939 .30075 L .81568 .29867 L F
.25709 .30459 m .259 .29867 L .26277 .30251 L .664 .741 .908 r
F
.25709 .30459 m .25332 .30075 L .259 .29867 L F
.17214 .30443 m .17379 .29851 L .17773 .30235 L F
.17214 .30443 m .1682 .30059 L .17379 .29851 L F
.72715 .30443 m .73051 .29851 L .73333 .30235 L .663 .741 .908 r
F
.72715 .30443 m .72432 .30059 L .73051 .29851 L F
.62495 .33951 m .62172 .33006 L .62708 .305 L .896 .676 .597 r
F
.62708 .305 m .63012 .29867 L .63314 .30251 L .682 .742 .896 r
F
.62708 .305 m .62404 .30106 L .63012 .29867 L F
.62172 .33006 m .62404 .30106 L .62708 .305 L .884 .678 .62 r
F
.2722 .30427 m .27415 .29836 L .27789 .3022 L .663 .741 .908 r
F
.2722 .30427 m .26845 .30043 L .27415 .29836 L F
.82725 .30427 m .83092 .29835 L .83354 .3022 L .664 .742 .908 r
F
.82725 .30427 m .82462 .30044 L .83092 .29835 L F
.64223 .30428 m .64533 .29836 L .64832 .3022 L .663 .741 .908 r
F
.64223 .30428 m .63923 .30044 L .64533 .29836 L F
.54267 .33454 m .53942 .32043 L .54547 .3296 L .183 .194 .636 r
F
.53942 .32043 m .54218 .31129 L .54547 .3296 L .896 .879 .81 r
F
.53942 .32043 m .53622 .31864 L .54218 .31129 L F
.18723 .30411 m .18893 .2982 L .19283 .30204 L .663 .741 .908 r
F
.18723 .30411 m .18332 .30027 L .18893 .2982 L F
.74233 .30411 m .74575 .2982 L .74853 .30203 L F
.74233 .30411 m .73953 .30028 L .74575 .2982 L F
.57893 .32473 m .57568 .31338 L .58251 .35621 L .93 .612 .152 r
F
.5155 .36558 m .5183 .32696 L .52152 .34929 L .917 .694 .585 r
F
.5155 .36558 m .51224 .35771 L .5183 .32696 L F
.5183 .32696 m .51507 .31739 L .52101 .3296 L 0 0 .484 r
F
.51224 .35771 m .51507 .31739 L .5183 .32696 L .773 .558 .607 r
F
.84245 .30395 m .84617 .29803 L .84876 .30187 L .663 .741 .908 r
F
.84245 .30395 m .83985 .30011 L .84617 .29803 L F
.10226 .30395 m .10369 .29803 L .10777 .30187 L .664 .741 .908 r
F
.10226 .30395 m .09817 .30011 L .10369 .29803 L F
.6574 .30396 m .66055 .29803 L .66351 .30188 L .664 .742 .908 r
F
.6574 .30396 m .65443 .30013 L .66055 .29803 L F
.2873 .30397 m .28931 .29804 L .29301 .30189 L F
.2873 .30397 m .28359 .30014 L .28931 .29804 L F
.75752 .30379 m .76098 .29787 L .76374 .30171 L .664 .741 .908 r
F
.75752 .30379 m .75475 .29995 L .76098 .29787 L F
.20233 .3038 m .20407 .29787 L .20795 .30171 L F
.20233 .3038 m .19845 .29996 L .20407 .29787 L F
.58584 .36838 m .58234 .34477 L .58811 .32861 L .729 .519 .607 r
F
.58811 .32861 m .59239 .38664 L .59509 .36953 L .891 .566 .427 r
F
.58811 .32861 m .58529 .34017 L .59239 .38664 L F
.58234 .34477 m .58529 .34017 L .58811 .32861 L .112 .103 .566 r
F
.51224 .35771 m .50904 .33732 L .51507 .31739 L .773 .558 .607 r
F
.51507 .31739 m .5177 .34993 L .52101 .3296 L .849 .506 .405 r
F
.50904 .33732 m .51177 .32585 L .51507 .31739 L .326 .248 .614 r
F
.51507 .31739 m .51177 .32585 L .5177 .34993 L .849 .506 .405 r
F
.11734 .30363 m .11882 .2977 L .12287 .30155 L .664 .741 .908 r
F
.11734 .30363 m .11329 .29979 L .11882 .2977 L F
.85766 .30363 m .86143 .29771 L .86399 .30156 L .663 .741 .908 r
F
.85766 .30363 m .85509 .29979 L .86143 .29771 L F
.30242 .30363 m .30447 .2977 L .30815 .30155 L .664 .741 .908 r
F
.30242 .30363 m .29874 .29979 L .30447 .2977 L F
.67258 .30364 m .67578 .29771 L .67871 .30155 L .664 .742 .908 r
F
.67258 .30364 m .66964 .2998 L .67578 .29771 L F
.21743 .30347 m .21922 .29754 L .22307 .30139 L .663 .741 .908 r
F
.21743 .30347 m .21358 .29963 L .21922 .29754 L F
.77271 .30347 m .77622 .29755 L .77895 .30139 L F
.77271 .30347 m .76997 .29963 L .77622 .29755 L F
.58234 .34477 m .57893 .32473 L .58529 .34017 L .112 .103 .566 r
F
.57893 .32473 m .58251 .35621 L .58529 .34017 L .93 .612 .152 r
F
.13243 .30331 m .13396 .29739 L .13797 .30124 L .663 .741 .908 r
F
.13243 .30331 m .12841 .29947 L .13396 .29739 L F
.63209 .40091 m .62862 .3836 L .64022 .54239 L .978 .681 .328 r
F
.62862 .3836 m .63725 .54474 L .64022 .54239 L .979 .682 .34 r
F
.31754 .30332 m .31964 .2974 L .32328 .30125 L .663 .741 .908 r
F
.31754 .30332 m .31389 .29948 L .31964 .2974 L F
.68776 .30332 m .691 .29739 L .69391 .30125 L F
.68776 .30332 m .68485 .29947 L .691 .29739 L F
.23254 .30315 m .23437 .29723 L .23819 .30107 L F
.23254 .30315 m .22872 .29931 L .23437 .29723 L F
.78791 .30316 m .79147 .29723 L .79417 .30108 L .664 .741 .908 r
F
.78791 .30316 m .7852 .29932 L .79147 .29723 L F
.14752 .30299 m .1491 .29706 L .15308 .30091 L .663 .741 .908 r
F
.14752 .30299 m .14353 .29915 L .1491 .29706 L F
.70295 .30301 m .70624 .29707 L .70911 .30093 L .664 .741 .908 r
F
.70295 .30301 m .70007 .29916 L .70624 .29707 L F
.33266 .30302 m .33481 .29708 L .33842 .30093 L F
.33266 .30302 m .32904 .29917 L .33481 .29708 L F
.24765 .30283 m .24953 .2969 L .25332 .30075 L F
.24765 .30283 m .24386 .29899 L .24953 .2969 L F
.80312 .30284 m .80672 .2969 L .80939 .30075 L F
.80312 .30284 m .80044 .29899 L .80672 .2969 L F
.41313 .42748 m .41043 .40189 L .41562 .41938 L .103 .063 .523 r
F
.40476 .43859 m .40597 .46504 L .40936 .47234 L .566 .278 .438 r
F
.40597 .46504 m .41043 .40189 L .41313 .42748 L .868 .63 .576 r
F
.40045 .49604 m .3976 .47455 L .40453 .4397 L .83 .599 .588 r
F
.40469 .43949 m .40453 .4397 L .40476 .43859 L F
.40045 .49604 m .40453 .4397 L .40469 .43949 L F
.3976 .47455 m .40025 .46204 L .40476 .43859 L .32 .236 .603 r
F
.3976 .47455 m .39478 .45313 L .40025 .46204 L F
.39479 .45314 m .3957 .48455 L .40025 .46204 L .934 .665 .191 r
F
.39478 .45313 m .39478 .45315 L .39479 .45314 L F
.39478 .45315 m .3957 .48455 L .39479 .45314 L F
.40476 .43859 m .40025 .46204 L .40597 .46504 L .566 .278 .438 r
F
.40597 .46504 m .403 .44667 L .41043 .40189 L .868 .63 .576 r
F
.41043 .40189 m .41282 .39616 L .41562 .41938 L 0 0 .472 r
F
.16262 .30267 m .16424 .29674 L .1682 .30059 L .664 .741 .908 r
F
.16262 .30267 m .15866 .29883 L .16424 .29674 L F
.71814 .30267 m .72148 .29674 L .72432 .30059 L .664 .742 .908 r
F
.71814 .30267 m .71529 .29884 L .72148 .29674 L F
.26277 .30251 m .2647 .29658 L .26845 .30043 L .663 .741 .908 r
F
.26277 .30251 m .259 .29867 L .2647 .29658 L F
.63314 .30251 m .63622 .29659 L .63923 .30044 L F
.63314 .30251 m .63012 .29867 L .63622 .29659 L F
.81833 .30251 m .82198 .29659 L .82462 .30044 L F
.81833 .30251 m .81568 .29867 L .82198 .29659 L F
.48201 .33669 m .48468 .32626 L .48785 .34141 L .743 .755 .244 r
F
.48201 .33669 m .47846 .34835 L .48401 .32863 L F
.48201 .33669 m .48401 .32863 L .48413 .32838 L F
.47846 .34835 m .48139 .31965 L .48468 .32626 L .992 .799 .546 r
F
.48339 .32988 m .48371 .33605 L .48697 .34824 L .795 .406 .319 r
F
.48139 .31965 m .48296 .33073 L .48339 .32988 L F
.48296 .33073 m .48371 .33605 L .48339 .32988 L F
.48413 .32838 m .48401 .32863 L .48468 .32626 L .743 .755 .244 r
F
.17773 .30235 m .17939 .29642 L .18332 .30027 L .663 .741 .908 r
F
.17773 .30235 m .17379 .29851 L .17939 .29642 L F
.73333 .30235 m .73672 .29643 L .73953 .30028 L F
.73333 .30235 m .73051 .29851 L .73672 .29643 L F
.53123 .37275 m .53401 .37155 L .53728 .38858 L 0 0 0 r
F
.53123 .37275 m .52801 .37904 L .53401 .37155 L F
.52801 .37904 m .53073 .34455 L .53401 .37155 L .901 .685 .601 r
F
.52801 .37904 m .52476 .37057 L .53073 .34455 L F
.83354 .3022 m .83724 .29626 L .83985 .30011 L .663 .741 .908 r
F
.83354 .3022 m .83092 .29835 L .83724 .29626 L F
.27789 .3022 m .27986 .29629 L .28359 .30014 L .662 .741 .908 r
F
.27789 .3022 m .27415 .29836 L .27986 .29629 L F
.64832 .3022 m .65145 .29628 L .65443 .30013 L .663 .741 .908 r
F
.64832 .3022 m .64533 .29836 L .65145 .29628 L F
.5503 .37948 m .55249 .3793 L .55562 .37668 L 0 0 0 r
F
.55562 .37668 m .55249 .3793 L .55665 .37563 L .492 .835 .556 r
F
.55688 .37551 m .55665 .37563 L .55849 .37402 L F
.55562 .37668 m .55665 .37563 L .55688 .37551 L F
.55625 .37585 m .55816 .36471 L .56116 .35172 L .811 .682 .722 r
F
.55249 .3793 m .55539 .38007 L .55849 .37402 L 0 .073 .631 r
F
.55539 .38007 m .55614 .37591 L .55625 .37585 L .811 .682 .722 r
F
.55614 .37591 m .55816 .36471 L .55625 .37585 L F
.55249 .3793 m .54926 .37161 L .5547 .37911 L 0 .073 .631 r
F
.55249 .3793 m .5547 .37911 L .55539 .38007 L F
.54963 .37984 m .55249 .3793 L .5503 .37948 L 0 0 0 r
F
.54963 .37984 m .54647 .38128 L .55249 .3793 L F
.74853 .30203 m .75197 .29611 L .75475 .29995 L .664 .742 .908 r
F
.74853 .30203 m .74575 .2982 L .75197 .29611 L F
.19283 .30204 m .19455 .29611 L .19845 .29996 L .664 .741 .908 r
F
.19283 .30204 m .18893 .2982 L .19455 .29611 L F
.10777 .30187 m .10922 .29594 L .11329 .29979 L F
.10777 .30187 m .10369 .29803 L .10922 .29594 L F
.84876 .30187 m .85251 .29594 L .85509 .29979 L .664 .742 .908 r
F
.84876 .30187 m .84617 .29803 L .85251 .29594 L F
.66351 .30188 m .66669 .29595 L .66964 .2998 L .663 .741 .908 r
F
.66351 .30188 m .66055 .29803 L .66669 .29595 L F
.29301 .30189 m .29504 .29594 L .29874 .29979 L .664 .741 .907 r
F
.29301 .30189 m .28931 .29804 L .29504 .29594 L F
.44892 .35502 m .45107 .36468 L .45472 .35732 L .419 .088 .295 r
F
.44892 .35502 m .44514 .36674 L .45107 .36468 L F
.20795 .30171 m .20971 .29577 L .21358 .29963 L .664 .741 .908 r
F
.20795 .30171 m .20407 .29787 L .20971 .29577 L F
.76374 .30171 m .76722 .29577 L .76997 .29963 L F
.76374 .30171 m .76098 .29787 L .76722 .29577 L F
.54597 .35457 m .54267 .33454 L .54882 .35399 L 0 0 .498 r
F
.53994 .3522 m .54267 .33454 L .54597 .35457 L .5 .371 .636 r
F
.54267 .33454 m .54547 .3296 L .54882 .35399 L .183 .194 .636 r
F
.39121 .5038 m .39793 .38904 L .40037 .4198 L .985 .739 .477 r
F
.39121 .5038 m .38687 .51765 L .39793 .38904 L F
.30815 .30155 m .31022 .29562 L .31389 .29948 L .663 .741 .908 r
F
.30815 .30155 m .30447 .2977 L .31022 .29562 L F
.12287 .30155 m .12437 .29561 L .12841 .29947 L F
.12287 .30155 m .11882 .2977 L .12437 .29561 L F
.67871 .30155 m .68193 .29562 L .68485 .29947 L .664 .741 .908 r
F
.67871 .30155 m .67578 .29771 L .68193 .29562 L F
.66754 .50835 m .66454 .50373 L .67025 .49216 L .888 .75 .704 r
F
.67025 .49216 m .67368 .49209 L .6767 .49712 L .02 .575 .821 r
F
.67025 .49216 m .66741 .49128 L .67368 .49209 L F
.66454 .50373 m .66741 .49128 L .67025 .49216 L .807 .711 .759 r
F
.47268 .33987 m .47146 .33346 L .47501 .35027 L 0 0 .177 r
F
.47146 .33346 m .47171 .33406 L .47501 .35027 L F
.47146 .33346 m .46955 .32345 L .47171 .33406 L F
.46955 .32345 m .47182 .33563 L .47501 .35027 L .901 .492 .099 r
F
.47501 .35027 m .47182 .33563 L .4759 .32829 L .744 .561 .647 r
F
.47725 .33057 m .4759 .32829 L .47792 .32465 L F
.47501 .35027 m .4759 .32829 L .47725 .33057 L F
.47213 .33507 m .47437 .33281 L .47792 .32465 L 0 0 .492 r
F
.46338 .33944 m .4662 .31968 L .46955 .32345 L .939 .829 .382 r
F
.46955 .32345 m .4662 .31968 L .4699 .33017 L .901 .492 .099 r
F
.47119 .33223 m .4699 .33017 L .47182 .33563 L F
.46955 .32345 m .4699 .33017 L .47119 .33223 L F
.4662 .31968 m .46876 .31401 L .47182 .33563 L 0 0 0 r
F
.45969 .35075 m .46257 .32943 L .4662 .31968 L .971 .804 .619 r
F
.4662 .31968 m .46257 .32943 L .46818 .31547 L 0 0 0 r
F
.4682 .31527 m .46818 .31547 L .46876 .31401 L F
.4662 .31968 m .46818 .31547 L .4682 .31527 L F
.46525 .32276 m .46553 .30311 L .46876 .31401 L .978 .824 .419 r
F
.46553 .30311 m .46776 .31592 L .46803 .3172 L .647 .266 .307 r
F
.4681 .31637 m .46803 .3172 L .47095 .33107 L F
.46553 .30311 m .46803 .3172 L .4681 .31637 L F
.46257 .32943 m .46361 .32015 L .46525 .32276 L .978 .824 .419 r
F
.46361 .32015 m .46553 .30311 L .46525 .32276 L F
.47182 .33563 m .4722 .33521 L .47213 .33507 L 0 0 .492 r
F
.4722 .33521 m .47437 .33281 L .47213 .33507 L F
.47182 .33563 m .46876 .31401 L .47352 .32995 L F
.47347 .33381 m .47352 .32995 L .47437 .33281 L F
.47182 .33563 m .47352 .32995 L .47347 .33381 L F
.47367 .31903 m .47385 .30792 L .47736 .30263 L .703 .532 .654 r
F
.47008 .31844 m .47095 .33107 L .47437 .33281 L .885 .566 .062 r
F
.47095 .33107 m .47381 .30823 L .47367 .31903 L .703 .532 .654 r
F
.47381 .30823 m .47385 .30792 L .47367 .31903 L F
.46876 .31401 m .46912 .31681 L .47008 .31844 L .885 .566 .062 r
F
.46912 .31681 m .47095 .33107 L .47008 .31844 L F
.22307 .30139 m .22488 .29545 L .22872 .29931 L .664 .741 .908 r
F
.22307 .30139 m .21922 .29754 L .22488 .29545 L F
.77895 .30139 m .78248 .29546 L .7852 .29932 L .663 .741 .908 r
F
.77895 .30139 m .77622 .29755 L .78248 .29546 L F
.13797 .30124 m .13952 .29529 L .14353 .29915 L .664 .741 .908 r
F
.13797 .30124 m .13396 .29739 L .13952 .29529 L F
.69391 .30125 m .69717 .2953 L .70007 .29916 L F
.69391 .30125 m .691 .29739 L .69717 .2953 L F
.32328 .30125 m .3254 .29532 L .32904 .29917 L .663 .741 .908 r
F
.32328 .30125 m .31964 .2974 L .3254 .29532 L F
.23819 .30107 m .24005 .29514 L .24386 .29899 L F
.23819 .30107 m .23437 .29723 L .24005 .29514 L F
.79417 .30108 m .79775 .29513 L .80044 .29899 L .664 .741 .908 r
F
.79417 .30108 m .79147 .29723 L .79775 .29513 L F
.50904 .33732 m .50586 .31721 L .51177 .32585 L .326 .248 .614 r
F
.50291 .36344 m .50586 .31721 L .50904 .33732 L .958 .726 .544 r
F
.50291 .36344 m .49959 .35967 L .50586 .31721 L F
.50631 .34954 m .50904 .33732 L .51224 .35771 L .723 .717 .19 r
F
.50631 .34954 m .50291 .36344 L .50904 .33732 L F
.50586 .31721 m .50837 .34337 L .51177 .32585 L .953 .608 .234 r
F
.49959 .35967 m .50259 .31116 L .50586 .31721 L .789 .563 .594 r
F
.50586 .31721 m .50259 .31116 L .50837 .34337 L .953 .608 .234 r
F
.15308 .30091 m .15468 .29497 L .15866 .29883 L .664 .741 .908 r
F
.15308 .30091 m .1491 .29706 L .15468 .29497 L F
.70911 .30093 m .71243 .29498 L .71529 .29884 L F
.70911 .30093 m .70624 .29707 L .71243 .29498 L F
.33842 .30093 m .33481 .29708 L .34059 .29499 L .663 .741 .908 r
F
.41712 .45595 m .41951 .45108 L .42326 .44541 L 0 0 0 r
F
.80939 .30075 m .81302 .29481 L .81568 .29867 L .664 .741 .908 r
F
.80939 .30075 m .80672 .2969 L .81302 .29481 L F
.25332 .30075 m .25522 .29481 L .259 .29867 L F
.25332 .30075 m .24953 .2969 L .25522 .29481 L F
.1682 .30059 m .16984 .29465 L .17379 .29851 L F
.1682 .30059 m .16424 .29674 L .16984 .29465 L F
.72432 .30059 m .72768 .29465 L .73051 .29851 L .663 .741 .908 r
F
.72432 .30059 m .72148 .29674 L .72768 .29465 L F
.62172 .33006 m .61851 .32131 L .62404 .30106 L .884 .678 .62 r
F
.62404 .30106 m .62709 .29481 L .63012 .29867 L .677 .741 .899 r
F
.62404 .30106 m .621 .29712 L .62709 .29481 L F
.61851 .32131 m .621 .29712 L .62404 .30106 L .871 .683 .645 r
F
.41887 .42971 m .41562 .41938 L .42224 .39467 L .871 .66 .614 r
F
.41562 .41938 m .41832 .40528 L .42224 .39467 L .335 .239 .595 r
F
.54323 .37129 m .53994 .3522 L .54597 .35457 L .5 .376 .642 r
F
.53728 .38858 m .53994 .3522 L .54323 .37129 L .793 .581 .615 r
F
.53728 .38858 m .53401 .37155 L .53994 .3522 L F
.26845 .30043 m .2704 .2945 L .27415 .29836 L .663 .741 .908 r
F
.26845 .30043 m .2647 .29658 L .2704 .2945 L F
.82462 .30044 m .82829 .29449 L .83092 .29835 L .664 .741 .908 r
F
.82462 .30044 m .82198 .29659 L .82829 .29449 L F
.63923 .30044 m .64233 .2945 L .64533 .29836 L .663 .741 .908 r
F
.63923 .30044 m .63622 .29659 L .64233 .2945 L F
.18332 .30027 m .18501 .29434 L .18893 .2982 L F
.18332 .30027 m .17939 .29642 L .18501 .29434 L F
.73953 .30028 m .74294 .29434 L .74575 .2982 L F
.73953 .30028 m .73672 .29643 L .74294 .29434 L F
.54218 .31129 m .54509 .32226 L .54845 .34559 L .868 .441 .019 r
F
.54547 .3296 m .54218 .31129 L .54658 .33534 L 0 0 .137 r
F
.53622 .31864 m .53898 .30778 L .54218 .31129 L .758 .766 .259 r
F
.54218 .31129 m .53898 .30778 L .54215 .3153 L .868 .441 .019 r
F
.54365 .31692 m .54215 .3153 L .54499 .32203 L F
.54218 .31129 m .54215 .3153 L .54365 .31692 L F
.54218 .31129 m .54499 .32203 L .54501 .32194 L F
.53898 .30778 m .54122 .30549 L .5436 .31873 L 0 0 .014 r
F
.54122 .30549 m .54179 .30491 L .5436 .31873 L F
.53898 .30778 m .53807 .31117 L .54179 .30491 L F
.53807 .31117 m .53581 .31966 L .53911 .31153 L F
.53807 .31117 m .53911 .31153 L .54179 .30491 L F
.53664 .31598 m .53581 .31966 L .53898 .30778 L 0 0 0 r
F
.53303 .32865 m .53581 .31966 L .53664 .31598 L F
.52981 .34204 m .53262 .33772 L .53581 .31966 L .602 .811 .404 r
F
.53581 .31966 m .53262 .33772 L .53497 .32339 L .751 .698 .158 r
F
.53581 .31966 m .53497 .32339 L .53856 .30156 L F
.53897 .31187 m .53856 .30156 L .54179 .30491 L F
.54179 .30491 m .53856 .30156 L .54396 .32973 L .951 .597 .269 r
F
.54454 .33147 m .54396 .32973 L .54483 .33428 L F
.54179 .30491 m .54396 .32973 L .54454 .33147 L F
.53856 .30156 m .54145 .30944 L .54186 .31249 L .369 .037 .266 r
F
.53856 .30156 m .54186 .31249 L .54057 .31204 L F
.53581 .31966 m .53727 .31004 L .53897 .31187 L .751 .698 .158 r
F
.53727 .31004 m .53856 .30156 L .53897 .31187 L F
.53262 .33772 m .53537 .31256 L .53856 .30156 L .969 .82 .398 r
F
.53856 .30156 m .53537 .31256 L .53959 .3104 L .369 .037 .266 r
F
.53975 .30479 m .53959 .3104 L .54145 .30944 L F
.53856 .30156 m .53959 .3104 L .53975 .30479 L F
.53537 .31256 m .53613 .30624 L .53782 .31131 L .851 .752 .238 r
F
.53613 .30624 m .53812 .28971 L .53782 .31131 L F
.53024 .32296 m .52702 .33548 L .53303 .32865 L .229 0 .244 r
F
.53215 .3292 m .53486 .2848 L .53812 .28971 L .997 .784 .431 r
F
.53486 .2848 m .5358 .29889 L .53592 .29866 L .86 .528 .422 r
F
.53537 .31256 m .53275 .3261 L .53711 .29639 L .851 .752 .238 r
F
.53275 .3261 m .53287 .32445 L .53711 .29639 L F
.53537 .31256 m .53711 .29639 L .53738 .29588 L F
.53486 .2848 m .53884 .33696 L .53904 .32982 L .86 .528 .422 r
F
.53738 .29588 m .53711 .29639 L .53812 .28971 L .851 .752 .238 r
F
.53782 .31131 m .53812 .28971 L .54145 .30944 L F
.53812 .28971 m .53486 .2848 L .54131 .3542 L .968 .651 .346 r
F
.52702 .33548 m .52981 .34204 L .53303 .32865 L .295 0 .248 r
F
.52101 .3296 m .52375 .34696 L .52702 .33548 L .456 .172 .393 r
F
.52702 .33548 m .52375 .34696 L .52981 .34204 L .295 0 .248 r
F
.52503 .34592 m .52687 .34636 L .52981 .34204 L 0 .531 .823 r
F
.52981 .34204 m .52687 .34636 L .53089 .34031 L .602 .811 .404 r
F
.52981 .34204 m .53089 .34031 L .53111 .34004 L F
.52687 .34636 m .52697 .3462 L .53262 .33772 L F
.5313 .31639 m .53163 .29663 L .53486 .2848 L .924 .695 .573 r
F
.53111 .34004 m .53089 .34031 L .53262 .33772 L .602 .811 .404 r
F
.52394 .34681 m .52654 .34686 L .52687 .34636 L 0 .531 .823 r
F
.52687 .34636 m .52654 .34686 L .52697 .3462 L .602 .811 .404 r
F
.52394 .34681 m .52687 .34636 L .52503 .34592 L 0 .531 .823 r
F
.52654 .34686 m .52935 .34724 L .53262 .33772 L 0 .013 .572 r
F
.52935 .34724 m .52603 .33794 L .52907 .33361 L .775 .627 .696 r
F
.53064 .33766 m .52907 .33361 L .53169 .32986 L F
.52935 .34724 m .52907 .33361 L .53064 .33766 L F
.52603 .33794 m .52273 .3131 L .52361 .31668 L 0 0 .446 r
F
.53174 .33181 m .53169 .32986 L .53215 .3292 L .775 .627 .696 r
F
.52935 .34724 m .53169 .32986 L .53174 .33181 L F
.52603 .33794 m .52886 .33804 L .53215 .3292 L 0 0 .446 r
F
.52668 .33796 m .52525 .32802 L .52886 .33804 L F
.52525 .32802 m .52584 .32575 L .52886 .33804 L F
.52525 .32802 m .52361 .31668 L .52584 .32575 L F
.52555 .32459 m .52553 .32977 L .52886 .33804 L 0 0 .163 r
F
.52886 .33804 m .52553 .32977 L .53061 .30218 L .924 .695 .573 r
F
.53132 .30128 m .53061 .30218 L .53163 .29663 L F
.52886 .33804 m .53061 .30218 L .53132 .30128 L F
.52553 .32977 m .52835 .31676 L .52863 .31509 L .315 .229 .597 r
F
.52729 .32021 m .52863 .31509 L .53163 .29663 L F
.52553 .32977 m .52863 .31509 L .52729 .32021 L F
.52603 .33794 m .52361 .31668 L .52668 .33796 L 0 0 .446 r
F
.52273 .3131 m .52398 .32054 L .52555 .32459 L 0 0 .163 r
F
.52398 .32054 m .52553 .32977 L .52555 .32459 L F
.52356 .31622 m .5222 .30673 L .52553 .32977 L .892 .559 .067 r
F
.51965 .28929 m .5222 .30673 L .52356 .31622 L F
.51945 .28791 m .51954 .28847 L .51965 .28929 L F
.51954 .28847 m .5222 .30673 L .51965 .28929 L F
.5167 .2953 m .51945 .28791 L .52273 .3131 L .699 .722 .867 r
F
.5167 .2953 m .5134 .29077 L .51945 .28791 L F
.5134 .29077 m .51617 .27832 L .51945 .28791 L .795 .778 .274 r
F
.52273 .3131 m .51945 .28791 L .52553 .32977 L 0 0 .163 r
F
.51829 .28451 m .51617 .27832 L .51866 .29005 L .892 .559 .067 r
F
.51945 .28791 m .51829 .28451 L .51994 .29606 L F
.52122 .29999 m .51994 .29606 L .5222 .30673 L F
.51945 .28791 m .51994 .29606 L .52122 .29999 L F
.51994 .29606 m .51891 .28211 L .5222 .30673 L .142 0 .159 r
F
.51829 .28451 m .51866 .29005 L .51994 .29606 L .892 .559 .067 r
F
.51617 .27832 m .51891 .28211 L .51994 .29606 L .142 0 .159 r
F
.51394 .30679 m .51068 .29418 L .5167 .2953 L .508 .428 .7 r
F
.5079 .31263 m .51068 .29418 L .51394 .30679 L .497 .365 .631 r
F
.51068 .29418 m .5134 .29077 L .5129 .29459 L .555 .816 .448 r
F
.5079 .31263 m .50469 .29191 L .51068 .29418 L .497 .365 .631 r
F
.50469 .29191 m .50733 .2983 L .51068 .29418 L .592 .115 .091 r
F
.51068 .29418 m .50733 .2983 L .5134 .29077 L .555 .816 .448 r
F
.5124 .292 m .51001 .30171 L .5134 .29077 L .063 0 .185 r
F
.50733 .2983 m .51001 .30171 L .5124 .292 L F
.50259 .31116 m .50498 .35165 L .50837 .34337 L .855 .524 .425 r
F
.49959 .35967 m .49643 .33677 L .50259 .31116 L .789 .563 .594 r
F
.49643 .33677 m .49919 .3217 L .50259 .31116 L .333 .232 .587 r
F
.50259 .31116 m .49919 .3217 L .50498 .35165 L .855 .524 .425 r
F
.49919 .3217 m .50171 .33855 L .50498 .35165 L .559 .235 .376 r
F
.50171 .33855 m .50469 .29191 L .5079 .31263 L .742 .522 .596 r
F
.50388 .31216 m .50657 .31601 L .51001 .30171 L .23 0 .096 r
F
.51001 .30171 m .50657 .31601 L .50759 .31155 L .725 .716 .187 r
F
.50733 .2983 m .50388 .31216 L .50799 .30516 L .063 0 .185 r
F
.50864 .29997 m .50799 .30516 L .51001 .30171 L F
.50733 .2983 m .50799 .30516 L .50864 .29997 L F
.51001 .30171 m .50759 .31155 L .5128 .28893 L .725 .716 .187 r
F
.5134 .29077 m .51001 .30171 L .5139 .28692 L .795 .778 .274 r
F
.51236 .29279 m .5128 .28893 L .51617 .27832 L .725 .716 .187 r
F
.51001 .30171 m .5128 .28893 L .51236 .29279 L F
.50669 .31547 m .50934 .30868 L .5128 .28893 L .904 .982 .722 r
F
.5128 .28893 m .50934 .30868 L .51324 .28504 L .743 .693 .151 r
F
.5128 .28893 m .51324 .28504 L .51561 .27071 L F
.50657 .31601 m .50665 .31579 L .50669 .31547 L .904 .982 .722 r
F
.50665 .31579 m .50934 .30868 L .50669 .31547 L F
.5134 .29077 m .5139 .28692 L .51617 .27832 L .795 .778 .274 r
F
.5129 .29459 m .5134 .29077 L .5167 .2953 L .555 .816 .448 r
F
.51617 .27832 m .5128 .28893 L .51751 .28367 L .142 0 .159 r
F
.51732 .27991 m .51751 .28367 L .51891 .28211 L F
.51617 .27832 m .51751 .28367 L .51732 .27991 L F
.51996 .31446 m .5167 .2953 L .52273 .3131 L 0 0 .504 r
F
.51792 .29183 m .51831 .29803 L .5201 .31165 L .834 .474 .374 r
F
.51633 .28499 m .51561 .27071 L .51891 .28211 L .743 .693 .151 r
F
.51561 .27071 m .51816 .29653 L .51792 .29183 L .834 .474 .374 r
F
.51816 .29653 m .51831 .29803 L .51792 .29183 L F
.52324 .33616 m .51996 .31446 L .52603 .33794 L 0 0 .431 r
F
.51996 .31446 m .52273 .3131 L .52603 .33794 L 0 0 .504 r
F
.51983 .30754 m .5201 .31165 L .52165 .32343 L .834 .474 .374 r
F
.51561 .27071 m .5201 .31165 L .51983 .30754 L F
.5128 .28893 m .51434 .27891 L .51633 .28499 L .743 .693 .151 r
F
.51434 .27891 m .51561 .27071 L .51633 .28499 L F
.5222 .30673 m .51891 .28211 L .52084 .29724 L .732 .518 0 r
F
.5222 .30673 m .52084 .29724 L .52376 .32004 L F
.5222 .30673 m .52376 .32004 L .5241 .32232 L F
.52553 .32977 m .5222 .30673 L .5262 .31325 L .315 .229 .597 r
F
.52618 .32678 m .5262 .31325 L .52835 .31676 L F
.52553 .32977 m .5262 .31325 L .52618 .32678 L F
.5222 .30673 m .52279 .31152 L .52297 .30798 L .732 .518 0 r
F
.52279 .31152 m .52284 .31198 L .52297 .30798 L F
.52297 .30798 m .52284 .31198 L .5243 .31014 L F
.51891 .28211 m .52165 .32343 L .52502 .32986 L .96 .646 .24 r
F
.52271 .31298 m .5245 .27809 L .52626 .26998 L .746 .526 .596 r
F
.52625 .2782 m .52626 .26998 L .52781 .26283 L F
.52271 .31298 m .52626 .26998 L .52625 .2782 L F
.52165 .32343 m .52243 .31107 L .52271 .31298 L F
.52243 .31107 m .5245 .27809 L .52271 .31298 L F
.5241 .32232 m .52376 .32004 L .52502 .32986 L .732 .518 0 r
F
.5243 .31014 m .52502 .32986 L .52835 .31676 L F
.52284 .31198 m .52502 .32986 L .5243 .31014 L F
.52886 .33804 m .531 .30598 L .5313 .31639 L .924 .695 .573 r
F
.531 .30598 m .53163 .29663 L .5313 .31639 L F
.53215 .3292 m .532 .32961 L .53209 .32823 L .997 .784 .431 r
F
.53215 .3292 m .53209 .32823 L .53486 .2848 L F
.532 .32961 m .52886 .33804 L .5317 .31286 L F
.532 .32961 m .5317 .31286 L .53486 .2848 L F
.53073 .33931 m .53215 .3292 L .53537 .31256 L .775 .627 .696 r
F
.53262 .33772 m .52935 .34724 L .53537 .31256 L .969 .82 .398 r
F
.53486 .2848 m .53163 .29663 L .53707 .32589 L .86 .528 .422 r
F
.53766 .32681 m .53707 .32589 L .53789 .3303 L F
.53486 .2848 m .53707 .32589 L .53766 .32681 L F
.53163 .29663 m .53447 .29601 L .53539 .30526 L 0 0 .167 r
F
.53163 .29663 m .53539 .30526 L .53448 .31195 L F
.53163 .29663 m .52835 .31676 L .53447 .29601 L F
.52927 .31365 m .53112 .26912 L .53447 .29601 L .989 .781 .39 r
F
.52835 .31676 m .5286 .31259 L .52927 .31365 L F
.5286 .31259 m .53112 .26912 L .52927 .31365 L F
.53448 .31195 m .53539 .30526 L .53789 .3303 L 0 0 .167 r
F
.53046 .34086 m .53148 .33382 L .53073 .33931 L .775 .627 .696 r
F
.53148 .33382 m .53215 .3292 L .53073 .33931 L F
.52935 .34724 m .53031 .34105 L .53046 .34086 L F
.53031 .34105 m .53215 .3292 L .53046 .34086 L F
.52324 .33616 m .52603 .33794 L .52825 .34415 L 0 0 .431 r
F
.52795 .34462 m .52825 .34415 L .52923 .34692 L F
.52324 .33616 m .52825 .34415 L .52795 .34462 L F
.52916 .3469 m .52923 .34692 L .52935 .34724 L F
.52324 .33616 m .52923 .34692 L .52916 .3469 L F
.52375 .34696 m .52654 .34686 L .52394 .34681 L 0 .531 .823 r
F
.52654 .34686 m .52324 .33616 L .52916 .3469 L 0 .013 .572 r
F
.52654 .34686 m .52916 .3469 L .52935 .34724 L F
.53447 .29601 m .53112 .26912 L .53545 .28844 L 0 0 .427 r
F
.53592 .29866 m .53789 .3303 L .53884 .33696 L .86 .528 .422 r
F
.5358 .29889 m .53789 .3303 L .53592 .29866 L F
.54057 .31204 m .54186 .31249 L .54483 .33428 L .369 .037 .266 r
F
.54145 .30944 m .53812 .28971 L .54266 .33625 L .933 .648 .176 r
F
.54342 .33859 m .54266 .33625 L .54462 .35631 L F
.54145 .30944 m .54266 .33625 L .54342 .33859 L F
.53812 .28971 m .54131 .3542 L .54462 .35631 L .968 .651 .346 r
F
.53859 .32368 m .54055 .27938 L .54377 .27428 L .687 .47 .586 r
F
.53789 .3303 m .53829 .32276 L .53859 .32368 L F
.53829 .32276 m .54055 .27938 L .53859 .32368 L F
.53789 .3303 m .53447 .29601 L .54055 .27938 L F
.53447 .29601 m .53735 .29692 L .54055 .27938 L 0 0 .427 r
F
.5349 .29614 m .53545 .28844 L .53735 .29692 L F
.53447 .29601 m .53545 .28844 L .5349 .29614 L F
.53275 .3261 m .53215 .3292 L .53287 .32445 L .851 .752 .238 r
F
.53904 .32982 m .53884 .33696 L .54131 .3542 L .86 .528 .422 r
F
.54501 .32194 m .54499 .32203 L .54509 .32226 L .868 .441 .019 r
F
.54449 .32497 m .54483 .33428 L .54811 .35208 L .951 .597 .269 r
F
.54449 .32497 m .54811 .35208 L .54813 .35208 L F
.54751 .34055 m .54658 .33534 L .54845 .34559 L 0 0 .137 r
F
.54547 .3296 m .54658 .33534 L .54751 .34055 L F
.55216 .37329 m .54882 .35399 L .55089 .35956 L .016 .038 .539 r
F
.55191 .36521 m .55089 .35956 L .55224 .36319 L F
.55539 .38007 m .55216 .37329 L .5552 .36895 L .811 .682 .722 r
F
.55681 .37222 m .5552 .36895 L .55728 .36596 L F
.5574 .36896 m .55728 .36596 L .55816 .36471 L F
.55681 .37222 m .55728 .36596 L .5574 .36896 L F
.55689 .35511 m .55762 .33467 L .56063 .32323 L .931 .71 .582 r
F
.55539 .38007 m .5552 .36895 L .55681 .37222 L .811 .682 .722 r
F
.55728 .36596 m .55505 .37075 L .55816 .36471 L .016 .038 .539 r
F
.55216 .37329 m .55505 .37075 L .55728 .36596 L F
.55505 .37075 m .55664 .3484 L .55689 .35511 L .931 .71 .582 r
F
.55664 .3484 m .55762 .33467 L .55689 .35511 L F
.55191 .36521 m .55201 .36463 L .55505 .37075 L .016 .038 .539 r
F
.55189 .36224 m .5518 .36421 L .55505 .37075 L 0 0 .294 r
F
.55216 .37329 m .55089 .35956 L .5532 .37237 L .016 .038 .539 r
F
.54882 .35399 m .55027 .35896 L .55189 .36224 L 0 0 .294 r
F
.55027 .35896 m .5518 .36421 L .55189 .36224 L F
.5518 .36421 m .55458 .34884 L .55459 .34879 L .474 .361 .645 r
F
.55342 .356 m .55459 .34879 L .55762 .33467 L F
.5518 .36421 m .55459 .34879 L .55342 .356 L F
.5532 .37237 m .55191 .36521 L .55505 .37075 L .016 .038 .539 r
F
.5518 .36421 m .54845 .34559 L .55211 .34752 L .474 .361 .645 r
F
.55381 .35313 m .55211 .34752 L .55458 .34884 L F
.5518 .36421 m .55211 .34752 L .55381 .35313 L F
.54845 .34559 m .55145 .35709 L .55458 .34884 L 0 0 .265 r
F
.54845 .34559 m .54509 .32226 L .54992 .34872 L F
.55016 .35212 m .54992 .34872 L .55145 .35709 L F
.54845 .34559 m .54992 .34872 L .55016 .35212 L F
.5473 .33961 m .54845 .34559 L .55113 .36049 L 0 0 .137 r
F
.5473 .33961 m .55113 .36049 L .5513 .36146 L F
.54547 .3296 m .5463 .33405 L .5473 .33961 L F
.5463 .33405 m .54845 .34559 L .5473 .33961 L F
.54748 .34424 m .54547 .3296 L .5469 .33741 L 0 0 .294 r
F
.54748 .34424 m .5469 .33741 L .5518 .36421 L F
.54882 .35399 m .54748 .34424 L .5518 .36421 L F
.54606 .32756 m .54819 .35249 L .55145 .35709 L .881 .6 .082 r
F
.54509 .32226 m .54542 .32544 L .54606 .32756 L F
.54542 .32544 m .54819 .35249 L .54606 .32756 L F
.54939 .34082 m .5508 .31392 L .55384 .29742 L .793 .577 .608 r
F
.54878 .34675 m .54926 .33895 L .54939 .34082 L F
.54926 .33895 m .5508 .31392 L .54939 .34082 L F
.54819 .35249 m .54864 .34591 L .54878 .34675 L F
.54864 .34591 m .5508 .31392 L .54878 .34675 L F
.5513 .36146 m .55113 .36049 L .5518 .36421 L 0 0 .137 r
F
.5436 .31873 m .54179 .30491 L .54509 .32226 L 0 0 .014 r
F
.54509 .32226 m .54179 .30491 L .54819 .35249 L .881 .6 .082 r
F
.54813 .35208 m .54811 .35208 L .54819 .35249 L .951 .597 .269 r
F
.54819 .35249 m .54483 .33428 L .54992 .31692 L .793 .577 .608 r
F
.55058 .31722 m .54992 .31692 L .5508 .31392 L F
.54819 .35249 m .54992 .31692 L .55058 .31722 L F
.54179 .30491 m .5441 .32723 L .54449 .32497 L .951 .597 .269 r
F
.5441 .32723 m .54483 .33428 L .54449 .32497 L F
.54483 .33428 m .54777 .33861 L .5508 .31392 L 0 0 .39 r
F
.54483 .33428 m .54145 .30944 L .54777 .33861 L F
.5423 .31338 m .54462 .35631 L .54777 .33861 L .933 .648 .176 r
F
.54145 .30944 m .5417 .3131 L .5423 .31338 L F
.5417 .3131 m .54462 .35631 L .5423 .31338 L F
.54777 .33861 m .54552 .35126 L .55046 .30807 L .9 .762 .267 r
F
.54552 .35126 m .54462 .35631 L .54524 .35117 L F
.54552 .35126 m .54524 .35117 L .55046 .30807 L F
.51879 .35898 m .52152 .34929 L .52476 .37057 L .845 .86 .408 r
F
.51879 .35898 m .5155 .36558 L .52152 .34929 L F
.83985 .30011 m .84357 .29417 L .84617 .29803 L .663 .742 .908 r
F
.83985 .30011 m .83724 .29626 L .84357 .29417 L F
.09817 .30011 m .0996 .29417 L .10369 .29803 L .664 .741 .908 r
F
.09817 .30011 m .09408 .29626 L .0996 .29417 L F
.65443 .30013 m .65758 .29417 L .66055 .29803 L .664 .742 .908 r
F
.65443 .30013 m .65145 .29628 L .65758 .29417 L F
.28359 .30014 m .28559 .29418 L .28931 .29804 L F
.28359 .30014 m .27986 .29629 L .28559 .29418 L F
.75475 .29995 m .75821 .29401 L .76098 .29787 L F
.75475 .29995 m .75197 .29611 L .75821 .29401 L F
.19845 .29996 m .20018 .29401 L .20407 .29787 L .664 .741 .908 r
F
.19845 .29996 m .19455 .29611 L .20018 .29401 L F
.11329 .29979 m .11476 .29384 L .11882 .2977 L F
.11329 .29979 m .10922 .29594 L .11476 .29384 L F
.85509 .29979 m .85886 .29385 L .86143 .29771 L .663 .741 .908 r
F
.85509 .29979 m .85251 .29594 L .85886 .29385 L F
.29874 .29979 m .30078 .29384 L .30447 .2977 L .664 .741 .908 r
F
.29874 .29979 m .29504 .29594 L .30078 .29384 L F
.66964 .2998 m .67283 .29384 L .67578 .29771 L F
.66964 .2998 m .66669 .29595 L .67283 .29384 L F
.42906 .35206 m .42649 .31964 L .4326 .30991 L .642 .44 .594 r
F
.42649 .31964 m .42884 .31681 L .4326 .30991 L 0 .01 .532 r
F
.42649 .31964 m .42345 .30327 L .42884 .31681 L F
.41922 .36357 m .42345 .30327 L .42649 .31964 L .814 .578 .582 r
F
.41922 .36357 m .41645 .33843 L .42345 .30327 L F
.42656 .35929 m .42906 .35206 L .4319 .37688 L 0 0 0 r
F
.42656 .35929 m .42259 .37138 L .42906 .35206 L F
.42259 .37138 m .42649 .31964 L .42906 .35206 L .929 .694 .563 r
F
.42259 .37138 m .41922 .36357 L .42649 .31964 L F
.42345 .30327 m .42468 .33506 L .42884 .31681 L .809 .476 .425 r
F
.41645 .33843 m .4195 .31428 L .42345 .30327 L .502 .348 .604 r
F
.42345 .30327 m .4195 .31428 L .42468 .33506 L .809 .476 .425 r
F
.21358 .29963 m .21536 .29368 L .21922 .29754 L .663 .741 .908 r
F
.21358 .29963 m .20971 .29577 L .21536 .29368 L F
.76997 .29963 m .77348 .29368 L .77622 .29755 L F
.76997 .29963 m .76722 .29577 L .77348 .29368 L F
.12841 .29947 m .12992 .29352 L .13396 .29739 L F
.12841 .29947 m .12437 .29561 L .12992 .29352 L F
.68485 .29947 m .68809 .29352 L .691 .29739 L F
.68485 .29947 m .68193 .29562 L .68809 .29352 L F
.31389 .29948 m .31598 .29354 L .31964 .2974 L F
.31389 .29948 m .31022 .29562 L .31598 .29354 L F
.49106 .35478 m .48785 .34141 L .49217 .33508 L .729 .559 .662 r
F
.49339 .33638 m .49217 .33508 L .49387 .33259 L F
.49106 .35478 m .49217 .33508 L .49339 .33638 L F
.48785 .34141 m .4904 .34416 L .49387 .33259 L 0 0 .421 r
F
.48785 .34141 m .48607 .33289 L .4904 .34416 L F
.48607 .33289 m .48468 .32626 L .48615 .33087 L F
.48607 .33289 m .48615 .33087 L .4904 .34416 L F
.48506 .32746 m .48697 .34824 L .4904 .34416 L .945 .597 .199 r
F
.48468 .32626 m .48477 .32715 L .48506 .32746 L F
.48477 .32715 m .48697 .34824 L .48506 .32746 L F
.48468 .32626 m .48139 .31965 L .48697 .34824 L F
.48371 .33605 m .48651 .31808 L .48672 .31722 L .482 .353 .628 r
F
.48654 .32162 m .48672 .31722 L .49006 .30363 L F
.48371 .33605 m .48672 .31722 L .48654 .32162 L F
.22872 .29931 m .23054 .29336 L .23437 .29723 L .663 .741 .908 r
F
.22872 .29931 m .22488 .29545 L .23054 .29336 L F
.7852 .29932 m .78876 .29336 L .79147 .29723 L .664 .741 .908 r
F
.7852 .29932 m .78248 .29546 L .78876 .29336 L F
.14353 .29915 m .14509 .2932 L .1491 .29706 L .663 .741 .908 r
F
.14353 .29915 m .13952 .29529 L .14509 .2932 L F
.70007 .29916 m .70336 .2932 L .70624 .29707 L .664 .741 .908 r
F
.70007 .29916 m .69717 .2953 L .70336 .2932 L F
.32904 .29917 m .33118 .29321 L .33481 .29708 L F
.32904 .29917 m .3254 .29532 L .33118 .29321 L F
.63556 .41773 m .63209 .40091 L .64308 .53803 L .977 .678 .314 r
F
.63209 .40091 m .64022 .54239 L .64308 .53803 L .978 .681 .328 r
F
.80044 .29899 m .80404 .29304 L .80672 .2969 L .664 .741 .908 r
F
.80044 .29899 m .79775 .29513 L .80404 .29304 L F
.24386 .29899 m .24573 .29304 L .24953 .2969 L F
.24386 .29899 m .24005 .29514 L .24573 .29304 L F
.15866 .29883 m .16027 .29287 L .16424 .29674 L F
.15866 .29883 m .15468 .29497 L .16027 .29287 L F
.71529 .29884 m .71863 .29288 L .72148 .29674 L F
.71529 .29884 m .71243 .29498 L .71863 .29288 L F
.3442 .29886 m .34059 .29499 L .34635 .29353 L .617 .726 .924 r
F
.259 .29867 m .26093 .29272 L .2647 .29658 L .663 .741 .908 r
F
.259 .29867 m .25522 .29481 L .26093 .29272 L F
.63012 .29867 m .63319 .29272 L .63622 .29659 L F
.63012 .29867 m .62709 .29481 L .63319 .29272 L F
.81568 .29867 m .81933 .29272 L .82198 .29659 L F
.81568 .29867 m .81302 .29481 L .81933 .29272 L F
.55816 .36471 m .55505 .37075 L .56063 .32323 L .998 .783 .456 r
F
.56063 .32323 m .55762 .33467 L .56381 .34331 L .69 .345 .386 r
F
.60622 .32083 m .60346 .33006 L .61331 .46712 L .951 .643 .416 r
F
.17379 .29851 m .17545 .29256 L .17939 .29642 L .663 .741 .908 r
F
.17379 .29851 m .16984 .29465 L .17545 .29256 L F
.73051 .29851 m .7339 .29256 L .73672 .29643 L F
.73051 .29851 m .72768 .29465 L .7339 .29256 L F
.43576 .32256 m .4326 .30991 L .43837 .31198 L .468 .4 .697 r
F
.42906 .35206 m .4326 .30991 L .43576 .32256 L .642 .44 .594 r
F
.4326 .30991 m .43452 .32284 L .43837 .31198 L .68 .292 .306 r
F
.4326 .30991 m .42884 .31681 L .43452 .32284 L F
.83092 .29835 m .83462 .2924 L .83724 .29626 L .663 .741 .908 r
F
.83092 .29835 m .82829 .29449 L .83462 .2924 L F
.27415 .29836 m .27612 .29242 L .27986 .29629 L F
.27415 .29836 m .2704 .2945 L .27612 .29242 L F
.64533 .29836 m .64846 .29241 L .65145 .29628 L F
.64533 .29836 m .64233 .2945 L .64846 .29241 L F
.49387 .33259 m .4904 .34416 L .49643 .33677 L .152 0 .189 r
F
.74575 .2982 m .74918 .29224 L .75197 .29611 L .664 .742 .908 r
F
.74575 .2982 m .74294 .29434 L .74918 .29224 L F
.18893 .2982 m .19063 .29224 L .19455 .29611 L .664 .741 .908 r
F
.18893 .2982 m .18501 .29434 L .19063 .29224 L F
.10369 .29803 m .10513 .29207 L .10922 .29594 L F
.10369 .29803 m .0996 .29417 L .10513 .29207 L F
.66055 .29803 m .66372 .29207 L .66669 .29595 L F
.66055 .29803 m .65758 .29417 L .66372 .29207 L F
.84617 .29803 m .84992 .29207 L .85251 .29594 L .664 .742 .908 r
F
.84617 .29803 m .84357 .29417 L .84992 .29207 L F
.28931 .29804 m .29133 .29207 L .29504 .29594 L .664 .741 .908 r
F
.28931 .29804 m .28559 .29418 L .29133 .29207 L F
.41712 .45595 m .41311 .46857 L .41951 .45108 L 0 0 0 r
F
.20407 .29787 m .20583 .2919 L .20971 .29577 L .664 .741 .908 r
F
.20407 .29787 m .20018 .29401 L .20583 .2919 L F
.76098 .29787 m .76446 .2919 L .76722 .29577 L F
.76098 .29787 m .75821 .29401 L .76446 .2919 L F
.11882 .2977 m .12031 .29174 L .12437 .29561 L .663 .741 .908 r
F
.11882 .2977 m .11476 .29384 L .12031 .29174 L F
.30447 .2977 m .30654 .29175 L .31022 .29562 L F
.30447 .2977 m .30078 .29384 L .30654 .29175 L F
.67578 .29771 m .67899 .29175 L .68193 .29562 L .664 .741 .908 r
F
.67578 .29771 m .67283 .29384 L .67899 .29175 L F
.21922 .29754 m .22102 .29158 L .22488 .29545 L F
.21922 .29754 m .21536 .29368 L .22102 .29158 L F
.77622 .29755 m .77975 .29158 L .78248 .29546 L .663 .741 .908 r
F
.77622 .29755 m .77348 .29368 L .77975 .29158 L F
.13396 .29739 m .13549 .29142 L .13952 .29529 L .664 .741 .908 r
F
.13396 .29739 m .12992 .29352 L .13549 .29142 L F
.691 .29739 m .69427 .29143 L .69717 .2953 L .663 .741 .908 r
F
.691 .29739 m .68809 .29352 L .69427 .29143 L F
.31964 .2974 m .32175 .29144 L .3254 .29532 L F
.31964 .2974 m .31598 .29354 L .32175 .29144 L F
.41951 .45108 m .41613 .44501 L .42257 .42573 L .896 .708 .641 r
F
.41613 .44501 m .41887 .42971 L .42257 .42573 L .493 .378 .651 r
F
.79147 .29723 m .79505 .29126 L .79775 .29513 L .663 .741 .908 r
F
.79147 .29723 m .78876 .29336 L .79505 .29126 L F
.23437 .29723 m .23622 .29126 L .24005 .29514 L .664 .741 .908 r
F
.23437 .29723 m .23054 .29336 L .23622 .29126 L F
.47846 .34835 m .47501 .35027 L .48139 .31965 L .992 .799 .546 r
F
.48139 .31965 m .47792 .32465 L .48371 .33605 L .795 .406 .319 r
F
.45472 .35732 m .45107 .36468 L .45708 .35965 L .095 0 .036 r
F
.1491 .29706 m .15068 .2911 L .15468 .29497 L .664 .741 .908 r
F
.1491 .29706 m .14509 .2932 L .15068 .2911 L F
.70624 .29707 m .70955 .2911 L .71243 .29498 L F
.70624 .29707 m .70336 .2932 L .70955 .2911 L F
.33481 .29708 m .33697 .29111 L .34059 .29499 L F
.33481 .29708 m .33118 .29321 L .33697 .29111 L F
.4395 .35839 m .44167 .36467 L .44514 .36674 L .108 0 .255 r
F
.4395 .35839 m .43544 .37777 L .44167 .36467 L F
.43863 .34632 m .43576 .32256 L .44175 .31715 L .623 .443 .618 r
F
.4319 .37688 m .43576 .32256 L .43863 .34632 L .795 .565 .589 r
F
.4319 .37688 m .42906 .35206 L .43576 .32256 L F
.43576 .32256 m .43837 .31198 L .44175 .31715 L .468 .4 .697 r
F
.55849 .37402 m .55539 .38007 L .56116 .35172 L .987 .839 .46 r
F
.44475 .33667 m .44175 .31715 L .44764 .31522 L .582 .428 .638 r
F
.43863 .34632 m .44175 .31715 L .44475 .33667 L .623 .443 .618 r
F
.44175 .31715 m .4444 .30476 L .44764 .31522 L .819 .724 .76 r
F
.44175 .31715 m .43837 .31198 L .4444 .30476 L F
.80672 .2969 m .81035 .29094 L .81302 .29481 L .664 .741 .908 r
F
.80672 .2969 m .80404 .29304 L .81035 .29094 L F
.24953 .2969 m .25143 .29093 L .25522 .29481 L F
.24953 .2969 m .24573 .29304 L .25143 .29093 L F
.61851 .32131 m .61532 .31332 L .621 .29712 L .871 .683 .645 r
F
.621 .29712 m .62404 .29094 L .62709 .29481 L .673 .741 .902 r
F
.621 .29712 m .61794 .29319 L .62404 .29094 L F
.61532 .31332 m .61794 .29319 L .621 .29712 L .858 .691 .673 r
F
.16424 .29674 m .16587 .29077 L .16984 .29465 L .664 .741 .908 r
F
.16424 .29674 m .16027 .29287 L .16587 .29077 L F
.72148 .29674 m .72484 .29078 L .72768 .29465 L .663 .741 .908 r
F
.72148 .29674 m .71863 .29288 L .72484 .29078 L F
.2647 .29658 m .26664 .29062 L .2704 .2945 L F
.2647 .29658 m .26093 .29272 L .26664 .29062 L F
.82198 .29659 m .82565 .29061 L .82829 .29449 L .664 .741 .908 r
F
.82198 .29659 m .81933 .29272 L .82565 .29061 L F
.63622 .29659 m .63932 .29063 L .64233 .2945 L .663 .741 .908 r
F
.63622 .29659 m .63319 .29272 L .63932 .29063 L F
.17939 .29642 m .18107 .29047 L .18501 .29434 L F
.17939 .29642 m .17545 .29256 L .18107 .29047 L F
.73672 .29643 m .74013 .29047 L .74294 .29434 L F
.73672 .29643 m .7339 .29256 L .74013 .29047 L F
.09408 .29626 m .09549 .29029 L .0996 .29417 L F
.09408 .29626 m .08996 .29239 L .09549 .29029 L F
.83724 .29626 m .84096 .29029 L .84357 .29417 L .664 .742 .908 r
F
.83724 .29626 m .83462 .2924 L .84096 .29029 L F
.65145 .29628 m .65459 .2903 L .65758 .29417 L F
.65145 .29628 m .64846 .29241 L .65459 .2903 L F
.27986 .29629 m .28186 .2903 L .28559 .29418 L .664 .742 .907 r
F
.27986 .29629 m .27612 .29242 L .28186 .2903 L F
.66741 .49128 m .67056 .48488 L .67368 .49209 L .817 .956 .619 r
F
.66741 .49128 m .66469 .49354 L .67056 .48488 L F
.75197 .29611 m .75543 .29013 L .75821 .29401 L .664 .742 .908 r
F
.75197 .29611 m .74918 .29224 L .75543 .29013 L F
.19455 .29611 m .19627 .29013 L .20018 .29401 L .664 .741 .908 r
F
.19455 .29611 m .19063 .29224 L .19627 .29013 L F
.85251 .29594 m .85628 .28997 L .85886 .29385 L .663 .741 .908 r
F
.85251 .29594 m .84992 .29207 L .85628 .28997 L F
.10922 .29594 m .11068 .28996 L .11476 .29384 L .664 .741 .908 r
F
.10922 .29594 m .10513 .29207 L .11068 .28996 L F
.29504 .29594 m .29708 .28996 L .30078 .29384 L F
.29504 .29594 m .29133 .29207 L .29708 .28996 L F
.66669 .29595 m .66988 .28997 L .67283 .29384 L F
.66669 .29595 m .66372 .29207 L .66988 .28997 L F
.20971 .29577 m .21148 .2898 L .21536 .29368 L .663 .741 .908 r
F
.20971 .29577 m .20583 .2919 L .21148 .2898 L F
.76722 .29577 m .77073 .2898 L .77348 .29368 L F
.76722 .29577 m .76446 .2919 L .77073 .2898 L F
.54926 .37161 m .54597 .35457 L .55216 .37329 L 0 0 .476 r
F
.54323 .37129 m .54597 .35457 L .54926 .37161 L .5 .376 .642 r
F
.54597 .35457 m .54882 .35399 L .55216 .37329 L 0 0 .498 r
F
.12437 .29561 m .12587 .28964 L .12992 .29352 L .663 .741 .908 r
F
.12437 .29561 m .12031 .29174 L .12587 .28964 L F
.68193 .29562 m .68517 .28964 L .68809 .29352 L .664 .741 .908 r
F
.68193 .29562 m .67899 .29175 L .68517 .28964 L F
.31022 .29562 m .3123 .28966 L .31598 .29354 L .663 .741 .908 r
F
.31022 .29562 m .30654 .29175 L .3123 .28966 L F
.49643 .33677 m .49333 .31126 L .49919 .3217 L .333 .232 .587 r
F
.4904 .34416 m .49333 .31126 L .49643 .33677 L .998 .798 .507 r
F
.4904 .34416 m .48849 .34642 L .49333 .31126 L F
.48849 .34642 m .48815 .34134 L .49333 .31126 L F
.48697 .34824 m .49006 .30363 L .49333 .31126 L .886 .656 .585 r
F
.48697 .34824 m .48371 .33605 L .49006 .30363 L F
.49006 .30363 m .48651 .31808 L .49231 .33621 L .765 .437 .431 r
F
.48662 .31842 m .48911 .31711 L .49231 .33621 L 0 0 .121 r
F
.48651 .31808 m .48659 .31805 L .48662 .31842 L F
.48659 .31805 m .48911 .31711 L .48662 .31842 L F
.48849 .34642 m .48697 .34824 L .48815 .34134 L .998 .798 .507 r
F
.49333 .31126 m .4957 .33623 L .49919 .3217 L .949 .61 .206 r
F
.49333 .31126 m .49006 .30363 L .4957 .33623 L F
.22488 .29545 m .2267 .28948 L .23054 .29336 L .663 .741 .908 r
F
.22488 .29545 m .22102 .29158 L .2267 .28948 L F
.78248 .29546 m .78604 .28948 L .78876 .29336 L F
.78248 .29546 m .77975 .29158 L .78604 .28948 L F
.13952 .29529 m .14107 .28932 L .14509 .2932 L F
.13952 .29529 m .13549 .29142 L .14107 .28932 L F
.69717 .2953 m .70046 .28932 L .70336 .2932 L .664 .741 .908 r
F
.69717 .2953 m .69427 .29143 L .70046 .28932 L F
.3254 .29532 m .32754 .28934 L .33118 .29321 L F
.3254 .29532 m .32175 .29144 L .32754 .28934 L F
.45708 .35965 m .45969 .35075 L .46338 .33944 L .914 .905 .801 r
F
.79775 .29513 m .80135 .28916 L .80404 .29304 L .664 .742 .908 r
F
.79775 .29513 m .79505 .29126 L .80135 .28916 L F
.24005 .29514 m .24192 .28916 L .24573 .29304 L .664 .741 .908 r
F
.24005 .29514 m .23622 .29126 L .24192 .28916 L F
.54647 .38128 m .54926 .37161 L .55249 .3793 L .539 .482 .74 r
F
.54647 .38128 m .54323 .37129 L .54926 .37161 L F
.54049 .38878 m .54323 .37129 L .54647 .38128 L .98 .84 .632 r
F
.54049 .38878 m .53728 .38858 L .54323 .37129 L F
.639 .4334 m .63556 .41773 L .64589 .53257 L .974 .673 .298 r
F
.63556 .41773 m .64308 .53803 L .64589 .53257 L .977 .678 .314 r
F
.15468 .29497 m .15628 .28899 L .16027 .29287 L .664 .741 .908 r
F
.15468 .29497 m .15068 .2911 L .15628 .28899 L F
.71243 .29498 m .71576 .28899 L .71863 .29288 L F
.71243 .29498 m .70955 .2911 L .71576 .28899 L F
.34059 .29499 m .34275 .2894 L .34635 .29353 L .636 .732 .918 r
F
.34059 .29499 m .33697 .29111 L .34275 .2894 L F
.44764 .31522 m .4444 .30476 L .45009 .31201 L .094 .185 .669 r
F
.44506 .3056 m .44679 .30363 L .45009 .31201 L 0 0 0 r
F
.44764 .31522 m .45009 .31201 L .4531 .33305 L .094 .185 .669 r
F
.45622 .34992 m .4531 .33305 L .45391 .33406 L .31 .256 .634 r
F
.45487 .34017 m .45391 .33406 L .45575 .33638 L F
.45487 .34017 m .45575 .33638 L .45887 .34029 L F
.45622 .34992 m .45391 .33406 L .45635 .34948 L F
.4531 .33305 m .45543 .33706 L .45887 .34029 L 0 0 .342 r
F
.45543 .33706 m .45812 .32558 L .45955 .32005 L .336 .262 .624 r
F
.45809 .32634 m .45955 .32005 L .46192 .31089 L F
.45543 .33706 m .45955 .32005 L .45809 .32634 L F
.45635 .34948 m .45487 .34017 L .45887 .34029 L .31 .256 .634 r
F
.45136 .31796 m .45234 .31838 L .45543 .33706 L .69 .353 0 r
F
.45009 .31201 m .45068 .31369 L .45136 .31796 L F
.45068 .31369 m .45234 .31838 L .45136 .31796 L F
.4531 .33305 m .45009 .31201 L .45543 .33706 L 0 0 .342 r
F
.45009 .31201 m .44679 .30363 L .44883 .30907 L .69 .353 0 r
F
.45039 .31287 m .44883 .30907 L .45234 .31838 L F
.45009 .31201 m .44883 .30907 L .45039 .31287 L F
.44679 .30363 m .44925 .3002 L .45234 .31838 L 0 0 0 r
F
.44679 .30363 m .44853 .30165 L .44925 .3002 L F
.44703 .30466 m .44574 .29917 L .44925 .3002 L .828 .792 .294 r
F
.44679 .30363 m .44303 .31269 L .44853 .30165 L 0 0 0 r
F
.4444 .30476 m .44679 .30363 L .44506 .3056 L F
.4444 .30476 m .44062 .31476 L .44679 .30363 L F
.44527 .30637 m .44303 .31269 L .44679 .30363 L 0 0 .053 r
F
.44062 .31476 m .44303 .31269 L .44527 .30637 L F
.44062 .31476 m .43658 .33232 L .44303 .31269 L F
.43658 .33232 m .43911 .32564 L .44303 .31269 L .875 .968 .646 r
F
.44303 .31269 m .43911 .32564 L .44076 .31908 L .828 .792 .294 r
F
.43837 .31198 m .44062 .31476 L .4444 .30476 L .038 0 .107 r
F
.44303 .31269 m .44076 .31908 L .44574 .29917 L .828 .792 .294 r
F
.44303 .31269 m .44542 .30075 L .44703 .30466 L F
.44542 .30075 m .44574 .29917 L .44703 .30466 L F
.25522 .29481 m .25714 .28883 L .26093 .29272 L .663 .741 .908 r
F
.25522 .29481 m .25143 .29093 L .25714 .28883 L F
.62709 .29481 m .63016 .28883 L .63319 .29272 L F
.62709 .29481 m .62404 .29094 L .63016 .28883 L F
.81302 .29481 m .81667 .28883 L .81933 .29272 L .664 .741 .908 r
F
.81302 .29481 m .81035 .29094 L .81667 .28883 L F
.45055 .33942 m .44764 .31522 L .4531 .33305 L .059 .038 .516 r
F
.44475 .33667 m .44764 .31522 L .45055 .33942 L .582 .428 .638 r
F
.16984 .29465 m .17149 .28867 L .17545 .29256 L .663 .741 .908 r
F
.16984 .29465 m .16587 .29077 L .17149 .28867 L F
.72768 .29465 m .73107 .28868 L .7339 .29256 L F
.72768 .29465 m .72484 .29078 L .73107 .28868 L F
.82829 .29449 m .83199 .28852 L .83462 .2924 L F
.82829 .29449 m .82565 .29061 L .83199 .28852 L F
.2704 .2945 m .27237 .28853 L .27612 .29242 L F
.2704 .2945 m .26664 .29062 L .27237 .28853 L F
.64233 .2945 m .64545 .28853 L .64846 .29241 L .664 .741 .908 r
F
.64233 .2945 m .63932 .29063 L .64545 .28853 L F
.41034 .38622 m .40736 .36769 L .41443 .33303 L .846 .614 .586 r
F
.41443 .33303 m .41012 .35229 L .41645 .33843 L .052 0 .223 r
F
.18501 .29434 m .1867 .28835 L .19063 .29224 L .664 .741 .908 r
F
.18501 .29434 m .18107 .29047 L .1867 .28835 L F
.74294 .29434 m .74638 .28835 L .74918 .29224 L F
.74294 .29434 m .74013 .29047 L .74638 .28835 L F
.0996 .29417 m .10103 .28818 L .10513 .29207 L F
.0996 .29417 m .09549 .29029 L .10103 .28818 L F
.65758 .29417 m .66075 .28818 L .66372 .29207 L .664 .742 .908 r
F
.65758 .29417 m .65459 .2903 L .66075 .28818 L F
.84357 .29417 m .84732 .28818 L .84992 .29207 L .664 .741 .908 r
F
.84357 .29417 m .84096 .29029 L .84732 .28818 L F
.28559 .29418 m .2876 .28819 L .29133 .29207 L F
.28559 .29418 m .28186 .2903 L .2876 .28819 L F
.49006 .30363 m .49231 .33621 L .4957 .33623 L .765 .437 .431 r
F
.20018 .29401 m .20193 .28802 L .20583 .2919 L .664 .741 .908 r
F
.20018 .29401 m .19627 .29013 L .20193 .28802 L F
.75821 .29401 m .76169 .28802 L .76446 .2919 L F
.75821 .29401 m .75543 .29013 L .76169 .28802 L F
.43837 .31198 m .43452 .32284 L .44062 .31476 L .038 0 .107 r
F
.11476 .29384 m .11624 .28786 L .12031 .29174 L .663 .741 .908 r
F
.11476 .29384 m .11068 .28996 L .11624 .28786 L F
.30078 .29384 m .30284 .28786 L .30654 .29175 L F
.30078 .29384 m .29708 .28996 L .30284 .28786 L F
.67283 .29384 m .67605 .28786 L .67899 .29175 L F
.67283 .29384 m .66988 .28997 L .67605 .28786 L F
.21536 .29368 m .21715 .2877 L .22102 .29158 L F
.21536 .29368 m .21148 .2898 L .21715 .2877 L F
.77348 .29368 m .77701 .2877 L .77975 .29158 L F
.77348 .29368 m .77073 .2898 L .77701 .2877 L F
.12992 .29352 m .13145 .28753 L .13549 .29142 L .664 .741 .908 r
F
.12992 .29352 m .12587 .28964 L .13145 .28753 L F
.68809 .29352 m .69136 .28754 L .69427 .29143 L .663 .741 .908 r
F
.68809 .29352 m .68517 .28964 L .69136 .28754 L F
.31598 .29354 m .31808 .28755 L .32175 .29144 L F
.31598 .29354 m .3123 .28966 L .31808 .28755 L F
.41613 .44501 m .41313 .42748 L .41887 .42971 L .493 .378 .651 r
F
.40936 .47234 m .41313 .42748 L .41613 .44501 L .921 .695 .58 r
F
.40936 .47234 m .40597 .46504 L .41313 .42748 L F
.41313 .42748 m .41562 .41938 L .41887 .42971 L .103 .063 .523 r
F
.78876 .29336 m .79234 .28738 L .79505 .29126 L .663 .741 .908 r
F
.78876 .29336 m .78604 .28948 L .79234 .28738 L F
.23054 .29336 m .23238 .28738 L .23622 .29126 L .664 .741 .908 r
F
.23054 .29336 m .2267 .28948 L .23238 .28738 L F
.14509 .2932 m .14667 .28721 L .15068 .2911 L F
.14509 .2932 m .14107 .28932 L .14667 .28721 L F
.70336 .2932 m .70667 .28721 L .70955 .2911 L F
.70336 .2932 m .70046 .28932 L .70667 .28721 L F
.33118 .29321 m .33333 .28722 L .33697 .29111 L .664 .742 .908 r
F
.33118 .29321 m .32754 .28934 L .33333 .28722 L F
.80404 .29304 m .80767 .28705 L .81035 .29094 L .664 .741 .908 r
F
.80404 .29304 m .80135 .28916 L .80767 .28705 L F
.24573 .29304 m .24762 .28704 L .25143 .29093 L F
.24573 .29304 m .24192 .28916 L .24762 .28704 L F
.61532 .31332 m .61215 .30611 L .61794 .29319 L .858 .691 .673 r
F
.61794 .29319 m .62098 .28705 L .62404 .29094 L .67 .741 .904 r
F
.61794 .29319 m .61488 .28926 L .62098 .28705 L F
.61215 .30611 m .61488 .28926 L .61794 .29319 L .844 .7 .704 r
F
.52101 .3296 m .5177 .34993 L .52375 .34696 L .456 .172 .393 r
F
.16027 .29287 m .16189 .28688 L .16587 .29077 L .664 .741 .908 r
F
.16027 .29287 m .15628 .28899 L .16189 .28688 L F
.71863 .29288 m .72199 .28689 L .72484 .29078 L .663 .741 .908 r
F
.71863 .29288 m .71576 .28899 L .72199 .28689 L F
.63092 .53883 m .62819 .34953 L .63145 .36001 L .968 .69 .452 r
F
.63092 .53883 m .62754 .52976 L .62819 .34953 L F
.62754 .52976 m .62495 .33951 L .62819 .34953 L .963 .685 .458 r
F
.62754 .52976 m .62407 .51745 L .62495 .33951 L F
.81933 .29272 m .823 .28672 L .82565 .29061 L .663 .741 .908 r
F
.81933 .29272 m .81667 .28883 L .823 .28672 L F
.26093 .29272 m .26286 .28673 L .26664 .29062 L F
.26093 .29272 m .25714 .28883 L .26286 .28673 L F
.63319 .29272 m .63629 .28674 L .63932 .29063 L .662 .741 .908 r
F
.63319 .29272 m .63016 .28883 L .63629 .28674 L F
.63416 .54383 m .63145 .36001 L .63472 .37095 L .972 .695 .445 r
F
.63416 .54383 m .63092 .53883 L .63145 .36001 L F
.17545 .29256 m .17712 .28657 L .18107 .29047 L .663 .741 .908 r
F
.17545 .29256 m .17149 .28867 L .17712 .28657 L F
.7339 .29256 m .73731 .28657 L .74013 .29047 L F
.7339 .29256 m .73107 .28868 L .73731 .28657 L F
.34635 .29353 m .34275 .2894 L .3473 .30967 L .939 .569 .236 r
F
.08996 .29239 m .09136 .2864 L .09549 .29029 L .663 .741 .908 r
F
.08996 .29239 m .08583 .28851 L .09136 .2864 L F
.83462 .2924 m .83834 .2864 L .84096 .29029 L .664 .741 .908 r
F
.83462 .2924 m .83199 .28852 L .83834 .2864 L F
.64846 .29241 m .6516 .28641 L .65459 .2903 L F
.64846 .29241 m .64545 .28853 L .6516 .28641 L F
.27612 .29242 m .27811 .28641 L .28186 .2903 L .664 .741 .907 r
F
.27612 .29242 m .27237 .28853 L .27811 .28641 L F
.62407 .51745 m .62053 .50256 L .62172 .33006 L .96 .681 .464 r
F
.51177 .32585 m .51436 .35772 L .5177 .34993 L .714 .396 .438 r
F
.51177 .32585 m .50837 .34337 L .51436 .35772 L F
.19063 .29224 m .19235 .28623 L .19627 .29013 L .664 .741 .908 r
F
.19063 .29224 m .1867 .28835 L .19235 .28623 L F
.74918 .29224 m .75263 .28624 L .75543 .29013 L F
.74918 .29224 m .74638 .28835 L .75263 .28624 L F
.63725 .54474 m .63472 .37095 L .63802 .3824 L .977 .702 .437 r
F
.63725 .54474 m .63416 .54383 L .63472 .37095 L F
.84992 .29207 m .85369 .28607 L .85628 .28997 L .663 .741 .908 r
F
.84992 .29207 m .84732 .28818 L .85369 .28607 L F
.10513 .29207 m .10658 .28607 L .11068 .28996 L .664 .741 .908 r
F
.10513 .29207 m .10103 .28818 L .10658 .28607 L F
.66372 .29207 m .66691 .28607 L .66988 .28997 L F
.66372 .29207 m .66075 .28818 L .66691 .28607 L F
.29133 .29207 m .29336 .28607 L .29708 .28996 L F
.29133 .29207 m .2876 .28819 L .29336 .28607 L F
.46876 .31401 m .46553 .30311 L .47095 .33107 L .885 .566 .062 r
F
.46257 .32943 m .4612 .33344 L .46553 .30311 L .978 .824 .419 r
F
.4612 .33344 m .46163 .32486 L .46553 .30311 L F
.45887 .34029 m .46192 .31089 L .46553 .30311 L .951 .75 .596 r
F
.46553 .30311 m .46192 .31089 L .46776 .31592 L .647 .266 .307 r
F
.46231 .31123 m .46461 .29898 L .46776 .31592 L .736 .73 .207 r
F
.46192 .31089 m .46245 .30854 L .46231 .31123 L F
.46245 .30854 m .46461 .29898 L .46231 .31123 L F
.4612 .33344 m .45887 .34029 L .46163 .32486 L .978 .824 .419 r
F
.55458 .34884 m .557 .29804 L .56034 .31579 L .997 .772 .432 r
F
.55762 .33467 m .56034 .31579 L .56381 .34331 L .824 .75 .231 r
F
.55762 .33467 m .55458 .34884 L .56034 .31579 L F
.56034 .31579 m .557 .29804 L .56381 .3587 L .928 .638 .163 r
F
.55458 .34884 m .55145 .35709 L .55668 .30153 L .997 .772 .432 r
F
.55458 .34884 m .55668 .30153 L .55684 .3015 L F
.55145 .35709 m .55384 .29742 L .557 .29804 L .963 .716 .515 r
F
.55505 .37075 m .5518 .36421 L .55762 .33467 L .931 .71 .582 r
F
.5543 .30193 m .55737 .3568 L .56068 .36502 L .857 .537 .445 r
F
.55384 .29742 m .55411 .30196 L .5543 .30193 L F
.55411 .30196 m .55737 .3568 L .5543 .30193 L F
.55684 .3015 m .55668 .30153 L .557 .29804 L .997 .772 .432 r
F
.557 .29804 m .56068 .36502 L .56381 .3587 L .959 .638 .371 r
F
.557 .29804 m .55384 .29742 L .56068 .36502 L F
.20583 .2919 m .20759 .28591 L .21148 .2898 L .663 .741 .908 r
F
.20583 .2919 m .20193 .28802 L .20759 .28591 L F
.76446 .2919 m .76797 .28591 L .77073 .2898 L F
.76446 .2919 m .76169 .28802 L .76797 .28591 L F
.40736 .36769 m .40483 .33787 L .40891 .349 L .256 .16 .549 r
F
.40866 .36046 m .40891 .349 L .41012 .35229 L F
.40736 .36769 m .40891 .349 L .40866 .36046 L F
.40483 .33787 m .40603 .36405 L .41012 .35229 L .85 .619 .078 r
F
.4026 .35705 m .40652 .31146 L .40994 .30291 L .76 .54 .599 r
F
.40987 .30606 m .40994 .30291 L .41053 .30144 L F
.4026 .35705 m .40994 .30291 L .40987 .30606 L F
.40603 .36405 m .41053 .30144 L .41376 .31206 L .94 .699 .545 r
F
.41012 .35229 m .41376 .31206 L .41645 .33843 L .998 .801 .457 r
F
.41012 .35229 m .40603 .36405 L .41145 .32757 L F
.41226 .32866 m .41145 .32757 L .41376 .31206 L F
.41012 .35229 m .41145 .32757 L .41226 .32866 L F
.40603 .36405 m .4026 .35705 L .41053 .30144 L .94 .699 .545 r
F
.40754 .32227 m .40759 .34126 L .41075 .35625 L .66 .349 .434 r
F
.40652 .31146 m .40687 .32137 L .40754 .32227 L F
.40687 .32137 m .40759 .34126 L .40754 .32227 L F
.41376 .31206 m .41053 .30144 L .41496 .34103 L .963 .648 .25 r
F
.41053 .30144 m .41075 .35625 L .41496 .34103 L .889 .574 .445 r
F
.41053 .30144 m .40652 .31146 L .41075 .35625 L F
.64239 .44743 m .639 .4334 L .64863 .52629 L .97 .665 .277 r
F
.639 .4334 m .64589 .53257 L .64863 .52629 L .974 .673 .298 r
F
.12031 .29174 m .12181 .28575 L .12587 .28964 L .663 .741 .908 r
F
.12031 .29174 m .11624 .28786 L .12181 .28575 L F
.67899 .29175 m .68223 .28575 L .68517 .28964 L .664 .742 .908 r
F
.67899 .29175 m .67605 .28786 L .68223 .28575 L F
.30654 .29175 m .30861 .28577 L .3123 .28966 L .663 .741 .908 r
F
.30654 .29175 m .30284 .28786 L .30861 .28577 L F
.22102 .29158 m .22283 .28559 L .2267 .28948 L F
.22102 .29158 m .21715 .2877 L .22283 .28559 L F
.77975 .29158 m .78331 .28559 L .78604 .28948 L F
.77975 .29158 m .77701 .2877 L .78331 .28559 L F
.41311 .46857 m .41613 .44501 L .41951 .45108 L .996 .829 .56 r
F
.54926 .37161 m .55216 .37329 L .55539 .38007 L 0 0 .476 r
F
.62053 .50256 m .61693 .48561 L .61851 .32131 L .956 .677 .469 r
F
.61693 .48561 m .61532 .31332 L .61851 .32131 L .952 .674 .474 r
F
.41645 .33843 m .41376 .31206 L .4195 .31428 L .502 .348 .604 r
F
.41376 .31206 m .41496 .34103 L .4195 .31428 L .963 .648 .25 r
F
.13549 .29142 m .13704 .28542 L .14107 .28932 L .663 .741 .908 r
F
.13549 .29142 m .13145 .28753 L .13704 .28542 L F
.69427 .29143 m .69756 .28542 L .70046 .28932 L .664 .741 .908 r
F
.69427 .29143 m .69136 .28754 L .69756 .28542 L F
.32175 .29144 m .32388 .28544 L .32754 .28934 L F
.32175 .29144 m .31808 .28755 L .32388 .28544 L F
.64022 .54239 m .63802 .3824 L .64133 .39419 L .981 .708 .431 r
F
.64022 .54239 m .63725 .54474 L .63802 .3824 L F
.23622 .29126 m .23808 .28526 L .24192 .28916 L .664 .741 .908 r
F
.23622 .29126 m .23238 .28738 L .23808 .28526 L F
.79505 .29126 m .79865 .28526 L .80135 .28916 L .664 .742 .908 r
F
.79505 .29126 m .79234 .28738 L .79865 .28526 L F
.44775 .35698 m .44475 .33667 L .45055 .33942 L .484 .356 .631 r
F
.44167 .36467 m .44475 .33667 L .44775 .35698 L .701 .515 .634 r
F
.44167 .36467 m .43863 .34632 L .44475 .33667 L F
.15068 .2911 m .15227 .28509 L .15628 .28899 L .664 .741 .908 r
F
.15068 .2911 m .14667 .28721 L .15227 .28509 L F
.70955 .2911 m .71289 .28509 L .71576 .28899 L F
.70955 .2911 m .70667 .28721 L .71289 .28509 L F
.33697 .29111 m .33913 .28535 L .34275 .2894 L .647 .736 .914 r
F
.33697 .29111 m .33333 .28722 L .33913 .28535 L F
.25143 .29093 m .25334 .28494 L .25714 .28883 L .663 .741 .908 r
F
.25143 .29093 m .24762 .28704 L .25334 .28494 L F
.81035 .29094 m .814 .28493 L .81667 .28883 L F
.81035 .29094 m .80767 .28705 L .814 .28493 L F
.62404 .29094 m .62711 .28494 L .63016 .28883 L F
.62404 .29094 m .62098 .28705 L .62711 .28494 L F
.66469 .49354 m .66739 .47651 L .67056 .48488 L .972 .864 .471 r
F
.16587 .29077 m .16751 .28477 L .17149 .28867 L .663 .741 .908 r
F
.16587 .29077 m .16189 .28688 L .16751 .28477 L F
.72484 .29078 m .72822 .28477 L .73107 .28868 L .664 .741 .908 r
F
.72484 .29078 m .72199 .28689 L .72822 .28477 L F
.82565 .29061 m .82935 .28461 L .83199 .28852 L .663 .741 .908 r
F
.82565 .29061 m .823 .28672 L .82935 .28461 L F
.26664 .29062 m .26859 .28463 L .27237 .28853 L F
.26664 .29062 m .26286 .28673 L .26859 .28463 L F
.63932 .29063 m .64243 .28463 L .64545 .28853 L F
.63932 .29063 m .63629 .28674 L .64243 .28463 L F
.58529 .34017 m .58954 .39916 L .59239 .38664 L .859 .539 .444 r
F
.58529 .34017 m .58251 .35621 L .58954 .39916 L F
.18107 .29047 m .18276 .28445 L .1867 .28835 L .664 .741 .908 r
F
.18107 .29047 m .17712 .28657 L .18276 .28445 L F
.74013 .29047 m .74356 .28445 L .74638 .28835 L .664 .741 .907 r
F
.74013 .29047 m .73731 .28657 L .74356 .28445 L F
.64308 .53803 m .64133 .39419 L .64464 .40604 L .984 .713 .426 r
F
.64308 .53803 m .64022 .54239 L .64133 .39419 L F
.09549 .29029 m .09691 .28428 L .10103 .28818 L .664 .741 .908 r
F
.09549 .29029 m .09136 .2864 L .09691 .28428 L F
.84096 .29029 m .84471 .28428 L .84732 .28818 L .663 .741 .908 r
F
.84096 .29029 m .83834 .2864 L .84471 .28428 L F
.65459 .2903 m .65776 .28428 L .66075 .28818 L .664 .742 .908 r
F
.65459 .2903 m .6516 .28641 L .65776 .28428 L F
.28186 .2903 m .28386 .28429 L .2876 .28819 L .664 .741 .908 r
F
.28186 .2903 m .27811 .28641 L .28386 .28429 L F
.61693 .48561 m .61331 .46712 L .61532 .31332 L .952 .674 .474 r
F
.61331 .46712 m .61215 .30611 L .61532 .31332 L .948 .671 .48 r
F
.19627 .29013 m .19801 .28412 L .20193 .28802 L .664 .741 .908 r
F
.19627 .29013 m .19235 .28623 L .19801 .28412 L F
.75543 .29013 m .75891 .28412 L .76169 .28802 L F
.75543 .29013 m .75263 .28624 L .75891 .28412 L F
.11068 .28996 m .11215 .28396 L .11624 .28786 L .663 .741 .908 r
F
.11068 .28996 m .10658 .28607 L .11215 .28396 L F
.29708 .28996 m .29913 .28396 L .30284 .28786 L F
.29708 .28996 m .29336 .28607 L .29913 .28396 L F
.66988 .28997 m .67309 .28397 L .67605 .28786 L F
.66988 .28997 m .66691 .28607 L .67309 .28397 L F
.77073 .2898 m .77426 .2838 L .77701 .2877 L F
.77073 .2898 m .76797 .28591 L .77426 .2838 L F
.21148 .2898 m .21327 .28379 L .21715 .2877 L F
.21148 .2898 m .20759 .28591 L .21327 .28379 L F
.66204 .49779 m .66422 .46834 L .66739 .47651 L .998 .808 .462 r
F
.68517 .28964 m .68843 .28364 L .69136 .28754 L .663 .741 .908 r
F
.68517 .28964 m .68223 .28575 L .68843 .28364 L F
.12587 .28964 m .12739 .28363 L .13145 .28753 L .664 .741 .908 r
F
.12587 .28964 m .12181 .28575 L .12739 .28363 L F
.3123 .28966 m .3144 .28365 L .31808 .28755 L .663 .741 .908 r
F
.3123 .28966 m .30861 .28577 L .3144 .28365 L F
.2267 .28948 m .22853 .28347 L .23238 .28738 L .664 .741 .908 r
F
.2267 .28948 m .22283 .28559 L .22853 .28347 L F
.78604 .28948 m .78961 .28347 L .79234 .28738 L F
.78604 .28948 m .78331 .28559 L .78961 .28347 L F
.64589 .53257 m .64464 .40604 L .64795 .41764 L .986 .718 .424 r
F
.64589 .53257 m .64308 .53803 L .64464 .40604 L F
.70046 .28932 m .70377 .2833 L .70667 .28721 L .664 .742 .908 r
F
.70046 .28932 m .69756 .28542 L .70377 .2833 L F
.14107 .28932 m .14264 .2833 L .14667 .28721 L .664 .741 .908 r
F
.14107 .28932 m .13704 .28542 L .14264 .2833 L F
.32754 .28934 m .32968 .28331 L .33333 .28722 L .664 .742 .908 r
F
.32754 .28934 m .32388 .28544 L .32968 .28331 L F
.3957 .48455 m .40037 .4198 L .403 .44667 L .998 .779 .442 r
F
.3957 .48455 m .39121 .5038 L .40037 .4198 L F
.80135 .28916 m .80497 .28314 L .80767 .28705 L .664 .741 .908 r
F
.80135 .28916 m .79865 .28526 L .80497 .28314 L F
.24192 .28916 m .2438 .28314 L .24762 .28704 L F
.24192 .28916 m .23808 .28526 L .2438 .28314 L F
.41311 .46857 m .40936 .47234 L .41613 .44501 L .996 .829 .56 r
F
.61215 .30611 m .609 .29961 L .61488 .28926 L .844 .7 .704 r
F
.61488 .28926 m .61791 .28314 L .62098 .28705 L .668 .741 .905 r
F
.61488 .28926 m .6118 .28534 L .61791 .28314 L F
.609 .29961 m .6118 .28534 L .61488 .28926 L .828 .711 .735 r
F
.15628 .28899 m .15789 .28298 L .16189 .28688 L .663 .741 .908 r
F
.15628 .28899 m .15227 .28509 L .15789 .28298 L F
.71576 .28899 m .71912 .28298 L .72199 .28689 L F
.71576 .28899 m .71289 .28509 L .71912 .28298 L F
.81667 .28883 m .82034 .28282 L .823 .28672 L F
.81667 .28883 m .814 .28493 L .82034 .28282 L F
.25714 .28883 m .25907 .28283 L .26286 .28673 L F
.25714 .28883 m .25334 .28494 L .25907 .28283 L F
.63016 .28883 m .63325 .28283 L .63629 .28674 L F
.63016 .28883 m .62711 .28494 L .63325 .28283 L F
.34275 .2894 m .34405 .29874 L .3473 .30967 L .892 .474 .082 r
F
.34275 .2894 m .33913 .28535 L .34263 .29487 L F
.33333 .28722 m .33549 .28134 L .33913 .28535 L .654 .738 .912 r
F
.34275 .2894 m .34263 .29487 L .34383 .29715 L .892 .474 .082 r
F
.33913 .28535 m .34071 .28953 L .34405 .29874 L .732 .257 0 r
F
.33913 .28535 m .33549 .28134 L .34071 .28953 L F
.33555 .28143 m .33728 .2818 L .34071 .28953 L 0 .151 .661 r
F
.33549 .28134 m .3355 .28134 L .33555 .28143 L F
.3355 .28134 m .33728 .2818 L .33555 .28143 L F
.34383 .29715 m .34263 .29487 L .34405 .29874 L .892 .474 .082 r
F
.17149 .28867 m .17315 .28267 L .17712 .28657 L .663 .741 .908 r
F
.17149 .28867 m .16751 .28477 L .17315 .28267 L F
.73107 .28868 m .73447 .28265 L .73731 .28657 L .664 .741 .908 r
F
.73107 .28868 m .72822 .28477 L .73447 .28265 L F
.43544 .37777 m .43863 .34632 L .44167 .36467 L .97 .767 .574 r
F
.43544 .37777 m .4319 .37688 L .43863 .34632 L F
.66204 .49779 m .65935 .50195 L .66422 .46834 L .998 .808 .462 r
F
.65935 .50195 m .66104 .45987 L .66422 .46834 L .998 .777 .447 r
F
.44514 .36674 m .44775 .35698 L .45107 .36468 L .891 .852 .798 r
F
.44514 .36674 m .44167 .36467 L .44775 .35698 L F
.64863 .52629 m .64795 .41764 L .65125 .42891 L .988 .725 .421 r
F
.64863 .52629 m .64589 .53257 L .64795 .41764 L F
.08583 .28851 m .08722 .28249 L .09136 .2864 L .663 .741 .908 r
F
.08583 .28851 m .08168 .28461 L .08722 .28249 L F
.83199 .28852 m .83571 .28249 L .83834 .2864 L .664 .741 .908 r
F
.83199 .28852 m .82935 .28461 L .83571 .28249 L F
.64545 .28853 m .64859 .2825 L .6516 .28641 L .664 .742 .908 r
F
.64545 .28853 m .64243 .28463 L .64859 .2825 L F
.27237 .28853 m .27434 .2825 L .27811 .28641 L .664 .741 .908 r
F
.27237 .28853 m .26859 .28463 L .27434 .2825 L F
.61331 .46712 m .60967 .44764 L .61215 .30611 L .948 .671 .48 r
F
.60967 .44764 m .609 .29961 L .61215 .30611 L .944 .668 .486 r
F
.1867 .28835 m .18841 .28233 L .19235 .28623 L .664 .741 .908 r
F
.1867 .28835 m .18276 .28445 L .18841 .28233 L F
.74638 .28835 m .74983 .28233 L .75263 .28624 L F
.74638 .28835 m .74356 .28445 L .74983 .28233 L F
.10103 .28818 m .10247 .28216 L .10658 .28607 L F
.10103 .28818 m .09691 .28428 L .10247 .28216 L F
.84732 .28818 m .85109 .28216 L .85369 .28607 L .663 .741 .908 r
F
.84732 .28818 m .84471 .28428 L .85109 .28216 L F
.66075 .28818 m .66393 .28216 L .66691 .28607 L .664 .741 .908 r
F
.66075 .28818 m .65776 .28428 L .66393 .28216 L F
.2876 .28819 m .28963 .28216 L .29336 .28607 L F
.2876 .28819 m .28386 .28429 L .28963 .28216 L F
.42884 .31681 m .43054 .33648 L .43452 .32284 L .535 .228 .394 r
F
.42884 .31681 m .42468 .33506 L .43054 .33648 L F
.20193 .28802 m .20368 .282 L .20759 .28591 L .663 .741 .908 r
F
.20193 .28802 m .19801 .28412 L .20368 .282 L F
.76169 .28802 m .76519 .282 L .76797 .28591 L F
.76169 .28802 m .75891 .28412 L .76519 .282 L F
.48047 .32967 m .48235 .32692 L .48371 .33605 L .813 .833 .362 r
F
.48371 .33605 m .48059 .31512 L .48651 .31808 L .482 .353 .628 r
F
.48905 .31713 m .48286 .33633 L .48911 .31711 L 0 0 .121 r
F
.48651 .31808 m .48573 .32198 L .48905 .31713 L F
.48573 .32198 m .48286 .33633 L .48905 .31713 L F
.47792 .32465 m .48059 .31512 L .48235 .32692 L .813 .833 .362 r
F
.47792 .32465 m .48235 .32692 L .48047 .32967 L F
.47792 .32465 m .47437 .33281 L .48059 .31512 L F
.65132 .51929 m .65125 .42891 L .65454 .43988 L .991 .734 .418 r
F
.11624 .28786 m .11773 .28184 L .12181 .28575 L .664 .741 .908 r
F
.11624 .28786 m .11215 .28396 L .11773 .28184 L F
.30284 .28786 m .30491 .28186 L .30861 .28577 L .663 .741 .908 r
F
.30284 .28786 m .29913 .28396 L .30491 .28186 L F
.67605 .28786 m .67928 .28185 L .68223 .28575 L .664 .741 .908 r
F
.67605 .28786 m .67309 .28397 L .67928 .28185 L F
.77701 .2877 m .78056 .28168 L .78331 .28559 L .663 .741 .908 r
F
.77701 .2877 m .77426 .2838 L .78056 .28168 L F
.21715 .2877 m .21896 .28168 L .22283 .28559 L F
.21715 .2877 m .21327 .28379 L .21896 .28168 L F
.65665 .50642 m .65781 .45035 L .66104 .45987 L .996 .759 .427 r
F
.13145 .28753 m .13299 .28151 L .13704 .28542 L .663 .741 .908 r
F
.13145 .28753 m .12739 .28363 L .13299 .28151 L F
.69136 .28754 m .69464 .28152 L .69756 .28542 L .664 .741 .908 r
F
.69136 .28754 m .68843 .28364 L .69464 .28152 L F
.31808 .28755 m .3202 .28153 L .32388 .28544 L .663 .741 .908 r
F
.31808 .28755 m .3144 .28365 L .3202 .28153 L F
.65398 .51228 m .65454 .43988 L .65781 .45035 L .993 .745 .418 r
F
.23238 .28738 m .23424 .28135 L .23808 .28526 L .664 .741 .908 r
F
.23238 .28738 m .22853 .28347 L .23424 .28135 L F
.79234 .28738 m .79594 .28134 L .79865 .28526 L F
.79234 .28738 m .78961 .28347 L .79594 .28134 L F
.5673 .3699 m .56381 .34331 L .56944 .32576 L .729 .513 .599 r
F
.56962 .32595 m .56944 .32576 L .56967 .32502 L F
.5673 .3699 m .56944 .32576 L .56962 .32595 L F
.56381 .34331 m .56678 .34264 L .56967 .32502 L 0 0 .465 r
F
.56381 .34331 m .56034 .31579 L .56678 .34264 L F
.56051 .3165 m .56381 .3587 L .56678 .34264 L .928 .638 .163 r
F
.56034 .31579 m .56039 .31637 L .56051 .3165 L F
.56039 .31637 m .56381 .3587 L .56051 .3165 L F
.70667 .28721 m .71 .28118 L .71289 .28509 L .664 .741 .908 r
F
.70667 .28721 m .70377 .2833 L .71 .28118 L F
.14667 .28721 m .14825 .28118 L .15227 .28509 L F
.14667 .28721 m .14264 .2833 L .14825 .28118 L F
.33333 .28722 m .32968 .28331 L .33549 .28134 L .654 .738 .912 r
F
.24762 .28704 m .24952 .28102 L .25334 .28494 L .663 .741 .908 r
F
.24762 .28704 m .2438 .28314 L .24952 .28102 L F
.80767 .28705 m .81131 .28102 L .814 .28493 L F
.80767 .28705 m .80497 .28314 L .81131 .28102 L F
.62098 .28705 m .62405 .28102 L .62711 .28494 L F
.62098 .28705 m .61791 .28314 L .62405 .28102 L F
.16189 .28688 m .16352 .28086 L .16751 .28477 L F
.16189 .28688 m .15789 .28298 L .16352 .28086 L F
.72199 .28689 m .72537 .28086 L .72822 .28477 L .664 .741 .908 r
F
.72199 .28689 m .71912 .28298 L .72537 .28086 L F
.4195 .31428 m .42074 .34459 L .42468 .33506 L .563 .276 .438 r
F
.4195 .31428 m .41496 .34103 L .42074 .34459 L F
.823 .28672 m .8267 .28069 L .82935 .28461 L .664 .741 .908 r
F
.823 .28672 m .82034 .28282 L .8267 .28069 L F
.26286 .28673 m .26481 .28071 L .26859 .28463 L .663 .741 .908 r
F
.26286 .28673 m .25907 .28283 L .26481 .28071 L F
.63629 .28674 m .6394 .28072 L .64243 .28463 L F
.63629 .28674 m .63325 .28283 L .6394 .28072 L F
.73731 .28657 m .74074 .28053 L .74356 .28445 L .664 .741 .908 r
F
.73731 .28657 m .73447 .28265 L .74074 .28053 L F
.17712 .28657 m .1788 .28054 L .18276 .28445 L F
.17712 .28657 m .17315 .28267 L .1788 .28054 L F
.45107 .36468 m .45361 .35867 L .45708 .35965 L .433 .471 .799 r
F
.45107 .36468 m .44775 .35698 L .45361 .35867 L F
.83834 .2864 m .84209 .28037 L .84471 .28428 L .664 .741 .908 r
F
.83834 .2864 m .83571 .28249 L .84209 .28037 L F
.09136 .2864 m .09277 .28036 L .09691 .28428 L F
.09136 .2864 m .08722 .28249 L .09277 .28036 L F
.27811 .28641 m .2801 .28037 L .28386 .28429 L F
.27811 .28641 m .27434 .2825 L .2801 .28037 L F
.6516 .28641 m .65476 .28037 L .65776 .28428 L F
.6516 .28641 m .64859 .2825 L .65476 .28037 L F
.19235 .28623 m .19408 .2802 L .19801 .28412 L F
.19235 .28623 m .18841 .28233 L .19408 .2802 L F
.75263 .28624 m .75611 .2802 L .75891 .28412 L F
.75263 .28624 m .74983 .28233 L .75611 .2802 L F
.45708 .35965 m .45361 .35867 L .45969 .35075 L .914 .905 .801 r
F
.55145 .35709 m .54819 .35249 L .55384 .29742 L .963 .716 .515 r
F
.55384 .29742 m .5508 .31392 L .55737 .3568 L .857 .537 .445 r
F
.45361 .35867 m .45055 .33942 L .45622 .34992 L .225 .181 .596 r
F
.44775 .35698 m .45055 .33942 L .45361 .35867 L .484 .356 .631 r
F
.45055 .33942 m .4531 .33305 L .45622 .34992 L .059 .038 .516 r
F
.60967 .44764 m .60604 .42773 L .609 .29961 L .944 .668 .486 r
F
.609 .29961 m .60585 .29371 L .6118 .28534 L .828 .711 .735 r
F
.60604 .42773 m .60585 .29371 L .609 .29961 L .939 .665 .493 r
F
.10658 .28607 m .10804 .28004 L .11215 .28396 L .663 .741 .908 r
F
.10658 .28607 m .10247 .28216 L .10804 .28004 L F
.29336 .28607 m .2954 .28004 L .29913 .28396 L F
.29336 .28607 m .28963 .28216 L .2954 .28004 L F
.66691 .28607 m .67012 .28005 L .67309 .28397 L F
.66691 .28607 m .66393 .28216 L .67012 .28005 L F
.76797 .28591 m .77149 .27988 L .77426 .2838 L F
.76797 .28591 m .76519 .282 L .77149 .27988 L F
.20759 .28591 m .20937 .27987 L .21327 .28379 L F
.20759 .28591 m .20368 .282 L .20937 .27987 L F
.49919 .3217 m .4957 .33623 L .50171 .33855 L .559 .235 .376 r
F
.12181 .28575 m .12332 .27971 L .12739 .28363 L .664 .741 .908 r
F
.12181 .28575 m .11773 .28184 L .12332 .27971 L F
.68223 .28575 m .68549 .27972 L .68843 .28364 L .664 .742 .908 r
F
.68223 .28575 m .67928 .28185 L .68549 .27972 L F
.30861 .28577 m .31071 .27973 L .3144 .28365 L .664 .741 .908 r
F
.30861 .28577 m .30491 .28186 L .31071 .27973 L F
.22283 .28559 m .22466 .27955 L .22853 .28347 L F
.22283 .28559 m .21896 .28168 L .22466 .27955 L F
.78331 .28559 m .78688 .27955 L .78961 .28347 L .664 .742 .908 r
F
.78331 .28559 m .78056 .28168 L .78688 .27955 L F
.47437 .33281 m .47736 .30263 L .48059 .31512 L .967 .765 .578 r
F
.48059 .31512 m .47736 .30263 L .48286 .33633 L .899 .592 .094 r
F
.47437 .33281 m .47095 .33107 L .47736 .30263 L .967 .765 .578 r
F
.47736 .30263 m .47945 .33392 L .48286 .33633 L .883 .535 .383 r
F
.47736 .30263 m .47385 .30792 L .47929 .33321 L F
.47095 .33107 m .46776 .31592 L .47146 .31107 L .703 .532 .654 r
F
.47312 .3138 m .47146 .31107 L .47385 .30792 L F
.47095 .33107 m .47146 .31107 L .47312 .3138 L F
.46776 .31592 m .47016 .32135 L .47385 .30792 L 0 0 .317 r
F
.46776 .31592 m .46461 .29898 L .47015 .32127 L F
.47015 .32132 m .47015 .32127 L .47016 .32135 L F
.46776 .31592 m .47015 .32127 L .47015 .32132 L F
.46866 .31098 m .46984 .28503 L .47332 .2835 L .795 .58 .611 r
F
.46495 .30033 m .46664 .32283 L .47016 .32135 L .948 .591 .26 r
F
.46664 .32283 m .46802 .30657 L .46866 .31098 L .795 .58 .611 r
F
.46802 .30657 m .46984 .28503 L .46866 .31098 L F
.46461 .29898 m .46469 .2999 L .46495 .30033 L .948 .591 .26 r
F
.46469 .2999 m .46664 .32283 L .46495 .30033 L F
.47941 .33343 m .47929 .33321 L .47945 .33392 L .883 .535 .383 r
F
.47736 .30263 m .47929 .33321 L .47941 .33343 L F
.47385 .30792 m .47638 .30806 L .47945 .33392 L 0 0 .079 r
F
.47385 .30792 m .47016 .32135 L .47638 .30806 L F
.47145 .31861 m .47332 .2835 L .47638 .30806 L .987 .773 .527 r
F
.47016 .32135 m .47053 .31691 L .47145 .31861 L F
.47053 .31691 m .47332 .2835 L .47145 .31861 L F
.45969 .35075 m .45622 .34992 L .46257 .32943 L .971 .804 .619 r
F
.45622 .34992 m .45887 .34029 L .46257 .32943 L .31 .256 .634 r
F
.13704 .28542 m .13859 .27938 L .14264 .2833 L .664 .741 .908 r
F
.13704 .28542 m .13299 .28151 L .13859 .27938 L F
.69756 .28542 m .70086 .27939 L .70377 .2833 L .664 .742 .908 r
F
.69756 .28542 m .69464 .28152 L .70086 .27939 L F
.32388 .28544 m .32602 .27939 L .32968 .28331 L F
.32388 .28544 m .3202 .28153 L .32602 .27939 L F
.79865 .28526 m .80227 .27922 L .80497 .28314 L .664 .741 .908 r
F
.79865 .28526 m .79594 .28134 L .80227 .27922 L F
.23808 .28526 m .23995 .27922 L .2438 .28314 L F
.23808 .28526 m .23424 .28135 L .23995 .27922 L F
.6118 .28534 m .61483 .27922 L .61791 .28314 L .668 .742 .906 r
F
.6118 .28534 m .6087 .28141 L .61483 .27922 L F
.60585 .29371 m .6087 .28141 L .6118 .28534 L .811 .721 .765 r
F
.15227 .28509 m .15388 .27906 L .15789 .28298 L .663 .741 .908 r
F
.15227 .28509 m .14825 .28118 L .15388 .27906 L F
.71289 .28509 m .71624 .27906 L .71912 .28298 L F
.71289 .28509 m .71 .28118 L .71624 .27906 L F
.814 .28493 m .81767 .2789 L .82034 .28282 L F
.814 .28493 m .81131 .28102 L .81767 .2789 L F
.62711 .28494 m .6302 .2789 L .63325 .28283 L F
.62711 .28494 m .62405 .28102 L .6302 .2789 L F
.25334 .28494 m .25526 .27891 L .25907 .28283 L F
.25334 .28494 m .24952 .28102 L .25526 .27891 L F
.50171 .33855 m .49855 .3121 L .50469 .29191 L .742 .522 .596 r
F
.49855 .3121 m .50133 .29527 L .50469 .29191 L .506 .381 .644 r
F
.50469 .29191 m .50133 .29527 L .50733 .2983 L .592 .115 .091 r
F
.72822 .28477 m .73163 .27873 L .73447 .28265 L .664 .741 .908 r
F
.72822 .28477 m .72537 .28086 L .73163 .27873 L F
.16751 .28477 m .16916 .27874 L .17315 .28267 L .663 .741 .908 r
F
.16751 .28477 m .16352 .28086 L .16916 .27874 L F
.08168 .28461 m .08306 .27857 L .08722 .28249 L F
.08168 .28461 m .07751 .28069 L .08306 .27857 L F
.82935 .28461 m .83307 .27857 L .83571 .28249 L F
.82935 .28461 m .8267 .28069 L .83307 .27857 L F
.64243 .28463 m .64557 .27858 L .64859 .2825 L .665 .742 .908 r
F
.64243 .28463 m .6394 .28072 L .64557 .27858 L F
.26859 .28463 m .27056 .27858 L .27434 .2825 L .664 .741 .908 r
F
.26859 .28463 m .26481 .28071 L .27056 .27858 L F
.56967 .32502 m .56678 .34264 L .57351 .3804 L .837 .517 .449 r
F
.74356 .28445 m .74701 .2784 L .74983 .28233 L .663 .741 .908 r
F
.74356 .28445 m .74074 .28053 L .74701 .2784 L F
.18276 .28445 m .18446 .2784 L .18841 .28233 L .664 .741 .908 r
F
.18276 .28445 m .1788 .28054 L .18446 .2784 L F
.38561 .38178 m .38731 .39123 L .39186 .3719 L .151 0 .283 r
F
.39186 .3719 m .38731 .39123 L .39528 .34013 L .96 .807 .369 r
F
.38731 .39123 m .39063 .36301 L .39528 .34013 L .997 .815 .54 r
F
.09691 .28428 m .09834 .27823 L .10247 .28216 L .664 .741 .908 r
F
.09691 .28428 m .09277 .28036 L .09834 .27823 L F
.84471 .28428 m .84848 .27824 L .85109 .28216 L F
.84471 .28428 m .84209 .28037 L .84848 .27824 L F
.65776 .28428 m .66094 .27824 L .66393 .28216 L .664 .742 .908 r
F
.65776 .28428 m .65476 .28037 L .66094 .27824 L F
.28386 .28429 m .28588 .27824 L .28963 .28216 L .664 .741 .908 r
F
.28386 .28429 m .2801 .28037 L .28588 .27824 L F
.19801 .28412 m .19976 .27807 L .20368 .282 L .663 .741 .908 r
F
.19801 .28412 m .19408 .2802 L .19976 .27807 L F
.75891 .28412 m .76241 .27808 L .76519 .282 L F
.75891 .28412 m .75611 .2802 L .76241 .27808 L F
.48059 .31512 m .48286 .33633 L .48651 .31808 L .899 .592 .094 r
F
.11215 .28396 m .11363 .27791 L .11773 .28184 L .664 .741 .908 r
F
.11215 .28396 m .10804 .28004 L .11363 .27791 L F
.29913 .28396 m .30119 .27793 L .30491 .28186 L .663 .741 .908 r
F
.29913 .28396 m .2954 .28004 L .30119 .27793 L F
.67309 .28397 m .67632 .27792 L .67928 .28185 L F
.67309 .28397 m .67012 .28005 L .67632 .27792 L F
.36959 .47579 m .36692 .45081 L .37717 .35762 L .898 .643 .544 r
F
.37717 .35762 m .37643 .41842 L .38084 .40498 L .786 .487 .483 r
F
.36692 .45081 m .37221 .38326 L .37717 .35762 L .827 .589 .579 r
F
.37717 .35762 m .37221 .38326 L .37643 .41842 L .786 .487 .483 r
F
.21327 .28379 m .21506 .27775 L .21896 .28168 L .663 .741 .908 r
F
.21327 .28379 m .20937 .27987 L .21506 .27775 L F
.77426 .2838 m .77781 .27775 L .78056 .28168 L .663 .742 .908 r
F
.77426 .2838 m .77149 .27988 L .77781 .27775 L F
.12739 .28363 m .12892 .27759 L .13299 .28151 L .663 .741 .908 r
F
.12739 .28363 m .12332 .27971 L .12892 .27759 L F
.68843 .28364 m .69171 .27759 L .69464 .28152 L .664 .741 .908 r
F
.68843 .28364 m .68549 .27972 L .69171 .27759 L F
.3144 .28365 m .31651 .27761 L .3202 .28153 L .663 .741 .908 r
F
.3144 .28365 m .31071 .27973 L .31651 .27761 L F
.22853 .28347 m .23037 .27742 L .23424 .28135 L .664 .741 .908 r
F
.22853 .28347 m .22466 .27955 L .23037 .27742 L F
.78961 .28347 m .79321 .27742 L .79594 .28134 L F
.78961 .28347 m .78688 .27955 L .79321 .27742 L F
.60604 .42773 m .60243 .40788 L .60585 .29371 L .939 .665 .493 r
F
.60585 .29371 m .60271 .28827 L .6087 .28141 L .811 .721 .765 r
F
.60243 .40788 m .60271 .28827 L .60585 .29371 L .935 .663 .5 r
F
.70377 .2833 m .7071 .27725 L .71 .28118 L .664 .742 .908 r
F
.70377 .2833 m .70086 .27939 L .7071 .27725 L F
.14264 .2833 m .14421 .27725 L .14825 .28118 L .664 .741 .908 r
F
.14264 .2833 m .13859 .27938 L .14421 .27725 L F
.32968 .28331 m .33184 .27734 L .33549 .28134 L .658 .74 .91 r
F
.32968 .28331 m .32602 .27939 L .33184 .27734 L F
.2438 .28314 m .24569 .27709 L .24952 .28102 L .663 .741 .908 r
F
.2438 .28314 m .23995 .27922 L .24569 .27709 L F
.80497 .28314 m .80862 .27709 L .81131 .28102 L F
.80497 .28314 m .80227 .27922 L .80862 .27709 L F
.61791 .28314 m .62098 .2771 L .62405 .28102 L F
.61791 .28314 m .61483 .27922 L .62098 .2771 L F
.15789 .28298 m .15951 .27693 L .16352 .28086 L F
.15789 .28298 m .15388 .27906 L .15951 .27693 L F
.71912 .28298 m .7225 .27693 L .72537 .28086 L F
.71912 .28298 m .71624 .27906 L .7225 .27693 L F
.82034 .28282 m .82404 .27676 L .8267 .28069 L .664 .741 .908 r
F
.82034 .28282 m .81767 .2789 L .82404 .27676 L F
.25907 .28283 m .261 .27678 L .26481 .28071 L .663 .741 .908 r
F
.25907 .28283 m .25526 .27891 L .261 .27678 L F
.63325 .28283 m .63636 .27679 L .6394 .28072 L .662 .741 .908 r
F
.63325 .28283 m .6302 .2789 L .63636 .27679 L F
.73447 .28265 m .7379 .2766 L .74074 .28053 L .663 .741 .908 r
F
.73447 .28265 m .73163 .27873 L .7379 .2766 L F
.17315 .28267 m .17482 .2766 L .1788 .28054 L .664 .741 .908 r
F
.17315 .28267 m .16916 .27874 L .17482 .2766 L F
.43452 .32284 m .43658 .33232 L .44062 .31476 L .349 .035 .285 r
F
.83571 .28249 m .83946 .27643 L .84209 .28037 L .664 .742 .908 r
F
.83571 .28249 m .83307 .27857 L .83946 .27643 L F
.08722 .28249 m .08862 .27643 L .09277 .28036 L .664 .741 .908 r
F
.08722 .28249 m .08306 .27857 L .08862 .27643 L F
.27434 .2825 m .27633 .27644 L .2801 .28037 L F
.27434 .2825 m .27056 .27858 L .27633 .27644 L F
.64859 .2825 m .65175 .27644 L .65476 .28037 L F
.64859 .2825 m .64557 .27858 L .65175 .27644 L F
.18841 .28233 m .19013 .27627 L .19408 .2802 L F
.18841 .28233 m .18446 .2784 L .19013 .27627 L F
.74983 .28233 m .75331 .27627 L .75611 .2802 L F
.74983 .28233 m .74701 .2784 L .75331 .27627 L F
.10247 .28216 m .10392 .2761 L .10804 .28004 L .663 .741 .908 r
F
.10247 .28216 m .09834 .27823 L .10392 .2761 L F
.28963 .28216 m .29166 .27611 L .2954 .28004 L F
.28963 .28216 m .28588 .27824 L .29166 .27611 L F
.66393 .28216 m .66714 .27611 L .67012 .28005 L F
.66393 .28216 m .66094 .27824 L .66714 .27611 L F
.45361 .35867 m .45622 .34992 L .45969 .35075 L .225 .181 .596 r
F
.20368 .282 m .20545 .27594 L .20937 .27987 L .663 .741 .908 r
F
.20368 .282 m .19976 .27807 L .20545 .27594 L F
.76519 .282 m .76872 .27595 L .77149 .27988 L F
.76519 .282 m .76241 .27808 L .76872 .27595 L F
.11773 .28184 m .11922 .27578 L .12332 .27971 L F
.11773 .28184 m .11363 .27791 L .11922 .27578 L F
.67928 .28185 m .68254 .27579 L .68549 .27972 L .664 .742 .908 r
F
.67928 .28185 m .67632 .27792 L .68254 .27579 L F
.30491 .28186 m .30699 .27579 L .31071 .27973 L .664 .741 .908 r
F
.30491 .28186 m .30119 .27793 L .30699 .27579 L F
.21896 .28168 m .22077 .27562 L .22466 .27955 L F
.21896 .28168 m .21506 .27775 L .22077 .27562 L F
.78056 .28168 m .78413 .27561 L .78688 .27955 L .664 .742 .908 r
F
.78056 .28168 m .77781 .27775 L .78413 .27561 L F
.13299 .28151 m .13453 .27545 L .13859 .27938 L .664 .741 .908 r
F
.13299 .28151 m .12892 .27759 L .13453 .27545 L F
.69464 .28152 m .69794 .27545 L .70086 .27939 L F
.69464 .28152 m .69171 .27759 L .69794 .27545 L F
.3202 .28153 m .32234 .27546 L .32602 .27939 L .664 .742 .908 r
F
.3202 .28153 m .31651 .27761 L .32234 .27546 L F
.79594 .28134 m .79956 .27528 L .80227 .27922 L .663 .741 .908 r
F
.79594 .28134 m .79321 .27742 L .79956 .27528 L F
.23424 .28135 m .2361 .27528 L .23995 .27922 L .664 .741 .908 r
F
.23424 .28135 m .23037 .27742 L .2361 .27528 L F
.6087 .28141 m .61174 .27528 L .61483 .27922 L .667 .742 .906 r
F
.6087 .28141 m .6056 .27747 L .61174 .27528 L F
.60271 .28827 m .6056 .27747 L .6087 .28141 L .792 .728 .793 r
F
.14825 .28118 m .14985 .27512 L .15388 .27906 L .663 .741 .908 r
F
.14825 .28118 m .14421 .27725 L .14985 .27512 L F
.71 .28118 m .71335 .27512 L .71624 .27906 L .664 .741 .908 r
F
.71 .28118 m .7071 .27725 L .71335 .27512 L F
.33549 .28134 m .33184 .27734 L .33728 .2818 L 0 .151 .661 r
F
.81131 .28102 m .81499 .27496 L .81767 .2789 L .664 .741 .908 r
F
.81131 .28102 m .80862 .27709 L .81499 .27496 L F
.24952 .28102 m .25143 .27497 L .25526 .27891 L .663 .741 .908 r
F
.24952 .28102 m .24569 .27709 L .25143 .27497 L F
.62405 .28102 m .62713 .27496 L .6302 .2789 L .664 .742 .908 r
F
.62405 .28102 m .62098 .2771 L .62713 .27496 L F
.45887 .34029 m .45543 .33706 L .46192 .31089 L .951 .75 .596 r
F
.46295 .30632 m .46299 .30562 L .46461 .29898 L .736 .73 .207 r
F
.45812 .32558 m .46121 .29507 L .46461 .29898 L .983 .784 .558 r
F
.46461 .29898 m .46121 .29507 L .46664 .32283 L .948 .591 .26 r
F
.46305 .30448 m .46347 .30516 L .46664 .32283 L .486 .124 .278 r
F
.46121 .29507 m .46311 .30352 L .46305 .30448 L F
.46311 .30352 m .46347 .30516 L .46305 .30448 L F
.46192 .31089 m .45812 .32558 L .46299 .30562 L .736 .73 .207 r
F
.46192 .31089 m .46299 .30562 L .46295 .30632 L F
.43452 .32284 m .43054 .33648 L .43658 .33232 L .349 .035 .285 r
F
.49855 .3121 m .49535 .29361 L .50133 .29527 L .506 .381 .644 r
F
.49231 .33621 m .49535 .29361 L .49855 .3121 L .803 .581 .601 r
F
.49231 .33621 m .48911 .31711 L .49535 .29361 L F
.4957 .33623 m .49231 .33621 L .49855 .3121 L .983 .804 .584 r
F
.49535 .29361 m .49778 .31615 L .50133 .29527 L .871 .497 .334 r
F
.48911 .31711 m .49193 .29728 L .49535 .29361 L .494 .356 .622 r
F
.49535 .29361 m .49193 .29728 L .49778 .31615 L .871 .497 .334 r
F
.72537 .28086 m .72877 .2748 L .73163 .27873 L .663 .741 .908 r
F
.72537 .28086 m .7225 .27693 L .72877 .2748 L F
.16352 .28086 m .16516 .2748 L .16916 .27874 L F
.16352 .28086 m .15951 .27693 L .16516 .2748 L F
.07751 .28069 m .07888 .27463 L .08306 .27857 L F
.07751 .28069 m .07333 .27676 L .07888 .27463 L F
.8267 .28069 m .83042 .27463 L .83307 .27857 L F
.8267 .28069 m .82404 .27676 L .83042 .27463 L F
.26481 .28071 m .26677 .27464 L .27056 .27858 L .664 .741 .908 r
F
.26481 .28071 m .261 .27678 L .26677 .27464 L F
.6394 .28072 m .64254 .27464 L .64557 .27858 L .665 .742 .908 r
F
.6394 .28072 m .63636 .27679 L .64254 .27464 L F
.74074 .28053 m .74419 .27446 L .74701 .2784 L .664 .741 .908 r
F
.74074 .28053 m .7379 .2766 L .74419 .27446 L F
.1788 .28054 m .18049 .27446 L .18446 .2784 L F
.1788 .28054 m .17482 .2766 L .18049 .27446 L F
.60271 .28827 m .59956 .28319 L .6056 .27747 L .792 .728 .793 r
F
.09277 .28036 m .0942 .27429 L .09834 .27823 L .664 .741 .908 r
F
.09277 .28036 m .08862 .27643 L .0942 .27429 L F
.84209 .28037 m .84586 .2743 L .84848 .27824 L .663 .741 .908 r
F
.84209 .28037 m .83946 .27643 L .84586 .2743 L F
.65476 .28037 m .65794 .27429 L .66094 .27824 L .664 .742 .908 r
F
.65476 .28037 m .65175 .27644 L .65794 .27429 L F
.2801 .28037 m .28211 .27429 L .28588 .27824 L .664 .741 .908 r
F
.2801 .28037 m .27633 .27644 L .28211 .27429 L F
.75611 .2802 m .75961 .27413 L .76241 .27808 L .663 .741 .908 r
F
.75611 .2802 m .75331 .27627 L .75961 .27413 L F
.19408 .2802 m .19582 .27413 L .19976 .27807 L F
.19408 .2802 m .19013 .27627 L .19582 .27413 L F
.10804 .28004 m .10951 .27397 L .11363 .27791 L .664 .741 .908 r
F
.10804 .28004 m .10392 .2761 L .10951 .27397 L F
.2954 .28004 m .29746 .27399 L .30119 .27793 L .663 .741 .908 r
F
.2954 .28004 m .29166 .27611 L .29746 .27399 L F
.67012 .28005 m .67335 .27398 L .67632 .27792 L F
.67012 .28005 m .66714 .27611 L .67335 .27398 L F
.20937 .27987 m .21115 .27381 L .21506 .27775 L F
.20937 .27987 m .20545 .27594 L .21115 .27381 L F
.77149 .27988 m .77504 .27381 L .77781 .27775 L .664 .742 .908 r
F
.77149 .27988 m .76872 .27595 L .77504 .27381 L F
.12332 .27971 m .12483 .27364 L .12892 .27759 L .663 .741 .908 r
F
.12332 .27971 m .11922 .27578 L .12483 .27364 L F
.68549 .27972 m .68877 .27365 L .69171 .27759 L .664 .742 .908 r
F
.68549 .27972 m .68254 .27579 L .68877 .27365 L F
.31071 .27973 m .31281 .27366 L .31651 .27761 L .663 .741 .908 r
F
.31071 .27973 m .30699 .27579 L .31281 .27366 L F
.40025 .46204 m .403 .44667 L .40597 .46504 L .744 .709 .174 r
F
.40025 .46204 m .3957 .48455 L .403 .44667 L F
.78688 .27955 m .79048 .27347 L .79321 .27742 L .664 .741 .908 r
F
.78688 .27955 m .78413 .27561 L .79048 .27347 L F
.22466 .27955 m .22649 .27347 L .23037 .27742 L F
.22466 .27955 m .22077 .27562 L .22649 .27347 L F
.13859 .27938 m .14016 .27331 L .14421 .27725 L F
.13859 .27938 m .13453 .27545 L .14016 .27331 L F
.70086 .27939 m .70419 .27331 L .7071 .27725 L .664 .742 .908 r
F
.70086 .27939 m .69794 .27545 L .70419 .27331 L F
.32602 .27939 m .32817 .27335 L .33184 .27734 L .661 .741 .909 r
F
.32602 .27939 m .32234 .27546 L .32817 .27335 L F
.40652 .31146 m .40208 .33114 L .40759 .34126 L .66 .349 .434 r
F
.23995 .27922 m .24184 .27315 L .24569 .27709 L .663 .741 .908 r
F
.23995 .27922 m .2361 .27528 L .24184 .27315 L F
.80227 .27922 m .80592 .27315 L .80862 .27709 L F
.80227 .27922 m .79956 .27528 L .80592 .27315 L F
.61483 .27922 m .61789 .27316 L .62098 .2771 L F
.61483 .27922 m .61174 .27528 L .61789 .27316 L F
.15388 .27906 m .15549 .27298 L .15951 .27693 L F
.15388 .27906 m .14985 .27512 L .15549 .27298 L F
.71624 .27906 m .71962 .27298 L .7225 .27693 L F
.71624 .27906 m .71335 .27512 L .71962 .27298 L F
.81767 .2789 m .82136 .27282 L .82404 .27676 L F
.81767 .2789 m .81499 .27496 L .82136 .27282 L F
.6302 .2789 m .63331 .27284 L .63636 .27679 L .662 .741 .908 r
F
.6302 .2789 m .62713 .27496 L .63331 .27284 L F
.25526 .27891 m .25719 .27283 L .261 .27678 L .663 .741 .908 r
F
.25526 .27891 m .25143 .27497 L .25719 .27283 L F
.73163 .27873 m .73505 .27266 L .7379 .2766 L .664 .742 .908 r
F
.73163 .27873 m .72877 .2748 L .73505 .27266 L F
.16916 .27874 m .17083 .27265 L .17482 .2766 L .664 .741 .908 r
F
.16916 .27874 m .16516 .2748 L .17083 .27265 L F
.08306 .27857 m .08445 .27248 L .08862 .27643 L F
.08306 .27857 m .07888 .27463 L .08445 .27248 L F
.83307 .27857 m .83681 .27248 L .83946 .27643 L .664 .742 .908 r
F
.83307 .27857 m .83042 .27463 L .83681 .27248 L F
.27056 .27858 m .27254 .27249 L .27633 .27644 L .664 .741 .908 r
F
.27056 .27858 m .26677 .27464 L .27254 .27249 L F
.64557 .27858 m .64872 .27249 L .65175 .27644 L .664 .742 .908 r
F
.64557 .27858 m .64254 .27464 L .64872 .27249 L F
.51718 .32891 m .51394 .30679 L .51996 .31446 L .374 .273 .611 r
F
.51108 .34212 m .51394 .30679 L .51718 .32891 L .613 .423 .602 r
F
.51108 .34212 m .5079 .31263 L .51394 .30679 L F
.51394 .30679 m .5167 .2953 L .51996 .31446 L .508 .428 .7 r
F
.74701 .2784 m .75049 .27232 L .75331 .27627 L .664 .742 .908 r
F
.74701 .2784 m .74419 .27446 L .75049 .27232 L F
.18446 .2784 m .18617 .27232 L .19013 .27627 L .664 .741 .908 r
F
.18446 .2784 m .18049 .27446 L .18617 .27232 L F
.45543 .33706 m .45542 .33699 L .45812 .32558 L .336 .262 .624 r
F
.45542 .33699 m .45234 .31838 L .45666 .32377 L F
.45542 .33699 m .45666 .32377 L .45812 .32558 L F
.45234 .31838 m .45459 .32603 L .45812 .32558 L 0 0 .244 r
F
.45459 .32603 m .4575 .30497 L .45874 .30164 L .564 .414 .636 r
F
.45791 .31049 m .45874 .30164 L .46121 .29507 L F
.45459 .32603 m .45874 .30164 L .45791 .31049 L F
.45234 .31838 m .44925 .3002 L .45459 .32603 L 0 0 .244 r
F
.44925 .3002 m .45151 .30612 L .45459 .32603 L .753 .236 0 r
F
.44925 .3002 m .44574 .29917 L .45151 .30612 L F
.50837 .34337 m .51108 .34212 L .51436 .35772 L 0 0 0 r
F
.50837 .34337 m .50498 .35165 L .51108 .34212 L F
.50498 .35165 m .5079 .31263 L .51108 .34212 L .86 .638 .601 r
F
.50498 .35165 m .50171 .33855 L .5079 .31263 L F
.09834 .27823 m .09978 .27215 L .10392 .2761 L .663 .741 .908 r
F
.09834 .27823 m .0942 .27429 L .09978 .27215 L F
.28588 .27824 m .2879 .27216 L .29166 .27611 L F
.28588 .27824 m .28211 .27429 L .2879 .27216 L F
.66094 .27824 m .66415 .27216 L .66714 .27611 L F
.66094 .27824 m .65794 .27429 L .66415 .27216 L F
.19976 .27807 m .20152 .27199 L .20545 .27594 L F
.19976 .27807 m .19582 .27413 L .20152 .27199 L F
.76241 .27808 m .76593 .272 L .76872 .27595 L F
.76241 .27808 m .75961 .27413 L .76593 .272 L F
.11363 .27791 m .11511 .27183 L .11922 .27578 L F
.11363 .27791 m .10951 .27397 L .11511 .27183 L F
.67632 .27792 m .67958 .27184 L .68254 .27579 L F
.67632 .27792 m .67335 .27398 L .67958 .27184 L F
.30119 .27793 m .30327 .27184 L .30699 .27579 L .664 .741 .908 r
F
.30119 .27793 m .29746 .27399 L .30327 .27184 L F
.21506 .27775 m .21687 .27166 L .22077 .27562 L F
.21506 .27775 m .21115 .27381 L .21687 .27166 L F
.77781 .27775 m .78138 .27166 L .78413 .27561 L F
.77781 .27775 m .77504 .27381 L .78138 .27166 L F
.12892 .27759 m .13045 .27149 L .13453 .27545 L F
.12892 .27759 m .12483 .27364 L .13045 .27149 L F
.69171 .27759 m .69501 .2715 L .69794 .27545 L F
.69171 .27759 m .68877 .27365 L .69501 .2715 L F
.31651 .27761 m .31864 .2715 L .32234 .27546 L .665 .742 .908 r
F
.31651 .27761 m .31281 .27366 L .31864 .2715 L F
.79321 .27742 m .79683 .27133 L .79956 .27528 L .664 .741 .908 r
F
.79321 .27742 m .79048 .27347 L .79683 .27133 L F
.23037 .27742 m .23223 .27133 L .2361 .27528 L F
.23037 .27742 m .22649 .27347 L .23223 .27133 L F
.6056 .27747 m .60863 .27133 L .61174 .27528 L .667 .742 .906 r
F
.6056 .27747 m .60248 .27352 L .60863 .27133 L F
.59956 .28319 m .60248 .27352 L .6056 .27747 L .772 .732 .816 r
F
.59956 .28319 m .59641 .27835 L .60248 .27352 L F
.5953 .36962 m .59641 .27835 L .59956 .28319 L .922 .657 .518 r
F
.14421 .27725 m .1458 .27116 L .14985 .27512 L .663 .741 .908 r
F
.14421 .27725 m .14016 .27331 L .1458 .27116 L F
.7071 .27725 m .71045 .27117 L .71335 .27512 L F
.7071 .27725 m .70419 .27331 L .71045 .27117 L F
.48911 .31711 m .48597 .29481 L .49193 .29728 L .494 .356 .622 r
F
.48286 .33633 m .48597 .29481 L .48911 .31711 L .966 .741 .546 r
F
.48286 .33633 m .47945 .33392 L .48597 .29481 L F
.48597 .29481 m .48832 .31547 L .49193 .29728 L .941 .578 .199 r
F
.47945 .33392 m .48263 .28969 L .48597 .29481 L .733 .517 .599 r
F
.48597 .29481 m .48263 .28969 L .48832 .31547 L .941 .578 .199 r
F
.33184 .27734 m .33376 .27529 L .33728 .2818 L .167 .497 .907 r
F
.33184 .27734 m .32817 .27335 L .33376 .27529 L F
.24569 .27709 m .24759 .27101 L .25143 .27497 L .663 .741 .908 r
F
.24569 .27709 m .24184 .27315 L .24759 .27101 L F
.80862 .27709 m .81229 .271 L .81499 .27496 L .664 .741 .908 r
F
.80862 .27709 m .80592 .27315 L .81229 .271 L F
.62098 .2771 m .62406 .27101 L .62713 .27496 L .664 .742 .908 r
F
.62098 .2771 m .61789 .27316 L .62406 .27101 L F
.7225 .27693 m .7259 .27085 L .72877 .2748 L .663 .741 .908 r
F
.7225 .27693 m .71962 .27298 L .7259 .27085 L F
.15951 .27693 m .16115 .27085 L .16516 .2748 L F
.15951 .27693 m .15549 .27298 L .16115 .27085 L F
.07333 .27676 m .07469 .27067 L .07888 .27463 L F
.07333 .27676 m .06913 .27281 L .07469 .27067 L F
.82404 .27676 m .82776 .27067 L .83042 .27463 L F
.82404 .27676 m .82136 .27282 L .82776 .27067 L F
.261 .27678 m .26296 .27068 L .26677 .27464 L .664 .741 .908 r
F
.261 .27678 m .25719 .27283 L .26296 .27068 L F
.63636 .27679 m .63949 .27068 L .64254 .27464 L F
.63636 .27679 m .63331 .27284 L .63949 .27068 L F
.7379 .2766 m .74135 .27051 L .74419 .27446 L .664 .742 .908 r
F
.7379 .2766 m .73505 .27266 L .74135 .27051 L F
.17482 .2766 m .1765 .2705 L .18049 .27446 L .664 .741 .908 r
F
.17482 .2766 m .17083 .27265 L .1765 .2705 L F
.08862 .27643 m .09003 .27034 L .0942 .27429 L F
.08862 .27643 m .08445 .27248 L .09003 .27034 L F
.83946 .27643 m .84322 .27034 L .84586 .2743 L .663 .741 .908 r
F
.83946 .27643 m .83681 .27248 L .84322 .27034 L F
.65175 .27644 m .65493 .27034 L .65794 .27429 L .664 .741 .908 r
F
.65175 .27644 m .64872 .27249 L .65493 .27034 L F
.27633 .27644 m .27833 .27034 L .28211 .27429 L F
.27633 .27644 m .27254 .27249 L .27833 .27034 L F
.50133 .29527 m .50388 .31216 L .50733 .2983 L .428 .145 .38 r
F
.4957 .33623 m .49855 .3121 L .50171 .33855 L .983 .804 .584 r
F
.50133 .29527 m .49778 .31615 L .50388 .31216 L .428 .145 .38 r
F
.75331 .27627 m .7568 .27018 L .75961 .27413 L .663 .741 .908 r
F
.75331 .27627 m .75049 .27232 L .7568 .27018 L F
.19013 .27627 m .19186 .27017 L .19582 .27413 L F
.19013 .27627 m .18617 .27232 L .19186 .27017 L F
.41484 .30371 m .41187 .28498 L .41767 .28666 L .498 .372 .64 r
F
.40759 .34126 m .41187 .28498 L .41484 .30371 L .712 .488 .584 r
F
.40759 .34126 m .40522 .30614 L .41187 .28498 L F
.41187 .28498 m .41351 .30082 L .41767 .28666 L .753 .368 .324 r
F
.40522 .30614 m .40797 .29124 L .41187 .28498 L .295 .198 .572 r
F
.41187 .28498 m .40797 .29124 L .41351 .30082 L .753 .368 .324 r
F
.10392 .2761 m .10538 .27001 L .10951 .27397 L .664 .741 .908 r
F
.10392 .2761 m .09978 .27215 L .10538 .27001 L F
.66714 .27611 m .67037 .27002 L .67335 .27398 L .663 .741 .908 r
F
.66714 .27611 m .66415 .27216 L .67037 .27002 L F
.29166 .27611 m .29371 .27003 L .29746 .27399 L F
.29166 .27611 m .2879 .27216 L .29371 .27003 L F
.40522 .30614 m .40254 .28051 L .40797 .29124 L .295 .198 .572 r
F
.39795 .34137 m .40254 .28051 L .40522 .30614 L .918 .676 .557 r
F
.39795 .34137 m .39466 .3304 L .40254 .28051 L F
.40254 .28051 m .40342 .31359 L .40797 .29124 L .9 .559 .391 r
F
.40254 .28051 m .39868 .28453 L .40342 .31359 L F
.20545 .27594 m .20723 .26985 L .21115 .27381 L .663 .741 .908 r
F
.20545 .27594 m .20152 .27199 L .20723 .26985 L F
.76872 .27595 m .77226 .26984 L .77504 .27381 L .664 .741 .908 r
F
.76872 .27595 m .76593 .272 L .77226 .26984 L F
.11922 .27578 m .12073 .26968 L .12483 .27364 L .663 .741 .908 r
F
.11922 .27578 m .11511 .27183 L .12073 .26968 L F
.68254 .27579 m .68582 .26969 L .68877 .27365 L .664 .742 .908 r
F
.68254 .27579 m .67958 .27184 L .68582 .26969 L F
.30699 .27579 m .30909 .26971 L .31281 .27366 L .663 .741 .908 r
F
.30699 .27579 m .30327 .27184 L .30909 .26971 L F
.78413 .27561 m .78773 .26951 L .79048 .27347 L F
.78413 .27561 m .78138 .27166 L .78773 .26951 L F
.22077 .27562 m .2226 .26951 L .22649 .27347 L .664 .741 .908 r
F
.22077 .27562 m .21687 .27166 L .2226 .26951 L F
.13453 .27545 m .13609 .26934 L .14016 .27331 L F
.13453 .27545 m .13045 .27149 L .13609 .26934 L F
.69794 .27545 m .70127 .26935 L .70419 .27331 L F
.69794 .27545 m .69501 .2715 L .70127 .26935 L F
.32234 .27546 m .32448 .26936 L .32817 .27335 L .663 .741 .908 r
F
.32234 .27546 m .31864 .2715 L .32448 .26936 L F
.2361 .27528 m .23797 .26918 L .24184 .27315 L F
.2361 .27528 m .23223 .27133 L .23797 .26918 L F
.61174 .27528 m .61479 .2692 L .61789 .27316 L .662 .741 .908 r
F
.61174 .27528 m .60863 .27133 L .61479 .2692 L F
.79956 .27528 m .8032 .26918 L .80592 .27315 L .663 .741 .908 r
F
.79956 .27528 m .79683 .27133 L .8032 .26918 L F
.71335 .27512 m .71673 .26902 L .71962 .27298 L F
.71335 .27512 m .71045 .27117 L .71673 .26902 L F
.14985 .27512 m .15145 .26902 L .15549 .27298 L F
.14985 .27512 m .1458 .27116 L .15145 .26902 L F
.81499 .27496 m .81868 .26886 L .82136 .27282 L F
.81499 .27496 m .81229 .271 L .81868 .26886 L F
.62713 .27496 m .63024 .26887 L .63331 .27284 L F
.62713 .27496 m .62406 .27101 L .63024 .26887 L F
.25143 .27497 m .25335 .26887 L .25719 .27283 L F
.25143 .27497 m .24759 .27101 L .25335 .26887 L F
.47945 .33392 m .47638 .30806 L .48263 .28969 L .733 .517 .599 r
F
.47638 .30806 m .47899 .30439 L .48263 .28969 L 0 0 .481 r
F
.47638 .30806 m .47332 .2835 L .47899 .30439 L F
.47016 .32135 m .46664 .32283 L .47332 .2835 L .987 .773 .527 r
F
.47332 .2835 m .47529 .3189 L .47899 .30439 L .929 .585 .362 r
F
.47332 .2835 m .46984 .28503 L .47529 .3189 L F
.72877 .2748 m .73219 .2687 L .73505 .27266 L .664 .742 .908 r
F
.72877 .2748 m .7259 .27085 L .73219 .2687 L F
.16516 .2748 m .16682 .26869 L .17083 .27265 L .664 .741 .908 r
F
.16516 .2748 m .16115 .27085 L .16682 .26869 L F
.45812 .32558 m .45459 .32603 L .46121 .29507 L .983 .784 .558 r
F
.46121 .29507 m .4575 .30497 L .46347 .30516 L .486 .124 .278 r
F
.07888 .27463 m .08027 .26852 L .08445 .27248 L .664 .741 .908 r
F
.07888 .27463 m .07469 .27067 L .08027 .26852 L F
.83042 .27463 m .83416 .26852 L .83681 .27248 L F
.83042 .27463 m .82776 .27067 L .83416 .26852 L F
.26677 .27464 m .26874 .26853 L .27254 .27249 L F
.26677 .27464 m .26296 .27068 L .26874 .26853 L F
.64254 .27464 m .64569 .26852 L .64872 .27249 L .664 .742 .908 r
F
.64254 .27464 m .63949 .27068 L .64569 .26852 L F
.58251 .35621 m .58648 .40295 L .58954 .39916 L .825 .501 .44 r
F
.56897 .29463 m .56562 .27912 L .57199 .3011 L 0 0 .354 r
F
.56309 .31481 m .56562 .27912 L .56897 .29463 L .696 .494 .611 r
F
.56562 .27912 m .56864 .28091 L .57209 .30147 L 0 .199 .61 r
F
.56244 .27718 m .56533 .26978 L .56864 .28091 L 0 0 0 r
F
.56562 .27912 m .56244 .27718 L .56567 .27913 L 0 .199 .61 r
F
.55964 .2912 m .56244 .27718 L .56562 .27912 L .607 .497 .703 r
F
.55964 .2912 m .55634 .27918 L .56244 .27718 L F
.56244 .27718 m .5594 .28892 L .5624 .27923 L 0 0 0 r
F
.56375 .27412 m .5624 .27923 L .56463 .27205 L F
.56244 .27718 m .5624 .27923 L .56375 .27412 L F
.5609 .27769 m .5594 .28892 L .56244 .27718 L .725 .27 .17 r
F
.55634 .27918 m .5594 .28892 L .5609 .27769 L F
.5508 .31392 m .55393 .33536 L .5548 .34082 L .465 .191 .413 r
F
.55504 .34161 m .5548 .34082 L .55737 .3568 L F
.5508 .31392 m .5548 .34082 L .55504 .34161 L F
.55393 .33536 m .55634 .27918 L .55964 .2912 L .784 .55 .582 r
F
.55393 .33536 m .55046 .30807 L .55634 .27918 L F
.55046 .30807 m .55317 .28235 L .55634 .27918 L .585 .418 .622 r
F
.55634 .27918 m .55317 .28235 L .5594 .28892 L .725 .27 .17 r
F
.55909 .2886 m .55641 .31087 L .5594 .28892 L .69 .364 .42 r
F
.55317 .28235 m .55641 .31087 L .55909 .2886 L F
.5508 .31392 m .54777 .33861 L .55393 .33536 L .465 .191 .413 r
F
.55046 .30807 m .54706 .28492 L .55317 .28235 L .585 .418 .622 r
F
.54777 .33861 m .55046 .30807 L .55393 .33536 L .9 .762 .267 r
F
.5501 .29922 m .55339 .3364 L .55641 .31087 L .675 .367 .446 r
F
.55641 .31087 m .55416 .32986 L .55437 .32782 L .799 .693 .15 r
F
.55317 .28235 m .5501 .29922 L .55641 .31087 L .69 .364 .42 r
F
.55641 .31087 m .55437 .32782 L .55755 .29625 L .799 .693 .15 r
F
.55641 .31087 m .55755 .29625 L .5578 .29487 L F
.55416 .32986 m .55341 .33621 L .55848 .287 L F
.55848 .287 m .55341 .33621 L .55908 .28012 L F
.55341 .33621 m .55341 .3362 L .55908 .28012 L F
.5594 .28892 m .55641 .31087 L .55788 .30032 L 0 0 0 r
F
.55952 .28854 m .5612 .2764 L .56295 .27747 L F
.56244 .27718 m .56463 .27205 L .56491 .27086 L F
.56118 .27639 m .56216 .26954 L .56295 .27747 L F
.56309 .31481 m .55964 .2912 L .56562 .27912 L .696 .494 .611 r
F
.55737 .3568 m .55964 .2912 L .56309 .31481 L .864 .615 .561 r
F
.56068 .36502 m .56309 .31481 L .56662 .34269 L .937 .697 .548 r
F
.56068 .36502 m .55737 .3568 L .56309 .31481 L F
.56381 .3587 m .56068 .36502 L .56662 .34269 L .945 .86 .436 r
F
.55958 .28855 m .56338 .38877 L .56699 .41377 L .907 .594 .443 r
F
.55737 .3568 m .55393 .33536 L .55964 .2912 L .864 .615 .561 r
F
.55945 .28951 m .5634 .3893 L .55958 .28855 L .907 .594 .443 r
F
.5594 .28892 m .55788 .30032 L .561 .27788 L 0 0 0 r
F
.56139 .27493 m .561 .27788 L .56216 .26954 L F
.5594 .28892 m .561 .27788 L .56139 .27493 L F
.56336 .38876 m .55977 .36359 L .5634 .3893 L .793 .481 .46 r
F
.55641 .31087 m .55756 .29764 L .55824 .29507 L .799 .693 .15 r
F
.55859 .29523 m .55824 .29507 L .55902 .29207 L F
.55641 .31087 m .55824 .29507 L .55859 .29523 L F
.55339 .3364 m .55605 .29998 L .55908 .28012 L .898 .749 .248 r
F
.55631 .30313 m .55935 .35616 L .56181 .36996 L .793 .481 .46 r
F
.55902 .29207 m .55908 .28012 L .56216 .26954 L .799 .693 .15 r
F
.55908 .28012 m .55945 .28951 L .55958 .28855 L .907 .594 .443 r
F
.55626 .30345 m .55973 .36286 L .55631 .30313 L .793 .481 .46 r
F
.55973 .36286 m .55977 .36359 L .55973 .36287 L F
.55973 .36286 m .55973 .36287 L .55631 .30313 L F
.54462 .35631 m .54706 .28492 L .55046 .30807 L .975 .722 .489 r
F
.5501 .29922 m .54701 .32288 L .55339 .3364 L .675 .367 .446 r
F
.54701 .32288 m .55026 .35733 L .55339 .3364 L .7 .381 .434 r
F
.55339 .3364 m .55026 .35733 L .55605 .29998 L .898 .749 .248 r
F
.55026 .35733 m .55302 .32627 L .55605 .29998 L .982 .809 .406 r
F
.55605 .29998 m .55302 .32627 L .55953 .36227 L .793 .481 .46 r
F
.5597 .36241 m .55953 .36227 L .55977 .36359 L F
.55605 .29998 m .55953 .36227 L .5597 .36241 L F
.55341 .33621 m .55339 .3364 L .55341 .3362 L .799 .693 .15 r
F
.54462 .35631 m .54131 .3542 L .54706 .28492 L .975 .722 .489 r
F
.54701 .32288 m .54383 .34285 L .55026 .35733 L .7 .381 .434 r
F
.54383 .34285 m .54698 .36637 L .55026 .35733 L .832 .456 .34 r
F
.55026 .35733 m .54698 .36637 L .55302 .32627 L .982 .809 .406 r
F
.55302 .32627 m .55619 .3392 L .55977 .36359 L .225 .002 .351 r
F
.55302 .32627 m .54993 .35517 L .55619 .3392 L F
.54698 .36637 m .54993 .35517 L .55302 .32627 L .727 .664 .788 r
F
.55016 .35458 m .55265 .31685 L .55619 .3392 L .85 .716 .189 r
F
.54993 .35517 m .54998 .35444 L .55016 .35458 L F
.54998 .35444 m .55265 .31685 L .55016 .35458 L F
.55619 .3392 m .55265 .31685 L .55279 .31498 L .911 .645 .52 r
F
.55605 .29998 m .55626 .30345 L .55631 .30313 L .793 .481 .46 r
F
.5578 .29487 m .55755 .29625 L .55848 .287 L .799 .693 .15 r
F
.55756 .29764 m .55908 .28012 L .55902 .29207 L F
.55908 .28012 m .55605 .29998 L .5634 .3893 L .907 .594 .443 r
F
.5562 .33853 m .55279 .31498 L .5582 .24028 L .911 .645 .52 r
F
.55619 .3392 m .55279 .31498 L .5562 .33853 L F
.56662 .34269 m .56309 .31481 L .56897 .29463 L .735 .514 .593 r
F
.56678 .34264 m .56381 .3587 L .57013 .36664 L .651 .328 .413 r
F
.56381 .3587 m .56662 .34269 L .57013 .36664 L .945 .86 .436 r
F
.56216 .26954 m .55908 .28012 L .56706 .41487 L .948 .64 .419 r
F
.55622 .33863 m .5582 .24028 L .56148 .24546 L .911 .645 .52 r
F
.55619 .3392 m .5562 .33853 L .55622 .33863 L F
.5562 .33853 m .5582 .24028 L .55622 .33863 L F
.56181 .36996 m .55977 .36359 L .56336 .38876 L .793 .481 .46 r
F
.55935 .35616 m .55977 .36359 L .56181 .36996 L F
.55977 .36359 m .5579 .35088 L .55792 .35055 L .919 .647 .51 r
F
.55977 .36359 m .55792 .35055 L .56148 .24546 L F
.5579 .35088 m .55619 .3392 L .5562 .33905 L F
.5579 .35088 m .5562 .33905 L .56148 .24546 L F
.56699 .41377 m .5634 .3893 L .56706 .41487 L .907 .594 .443 r
F
.56338 .38877 m .5634 .3893 L .56699 .41377 L F
.56491 .27086 m .56463 .27205 L .56533 .26978 L 0 0 0 r
F
.5627 .28022 m .56706 .41487 L .57071 .43814 L .948 .64 .419 r
F
.56216 .26954 m .56254 .28089 L .5627 .28022 L F
.56254 .28089 m .56706 .41487 L .5627 .28022 L F
.56295 .27747 m .56216 .26954 L .56533 .26978 L 0 0 0 r
F
.56702 .27995 m .56567 .27913 L .56843 .28079 L 0 .199 .61 r
F
.56562 .27912 m .56567 .27913 L .56702 .27995 L F
.56853 .28085 m .56843 .28079 L .56864 .28091 L F
.56562 .27912 m .56843 .28079 L .56853 .28085 L F
.56662 .34269 m .56897 .29463 L .57249 .32009 L .735 .514 .593 r
F
.56678 .34264 m .57013 .36664 L .57351 .3804 L .651 .328 .413 r
F
.57013 .36664 m .56662 .34269 L .57249 .32009 L .769 .546 .595 r
F
.56578 .27917 m .57071 .43814 L .57432 .45663 L .967 .664 .395 r
F
.56536 .27032 m .56564 .27908 L .56578 .27917 L F
.56564 .27908 m .57071 .43814 L .56578 .27917 L F
.56533 .26978 m .56535 .27027 L .56536 .27032 L F
.56535 .27027 m .57071 .43814 L .56536 .27032 L F
.57204 .30135 m .57199 .3011 L .57209 .30147 L 0 0 .354 r
F
.56897 .29463 m .57199 .3011 L .57204 .30135 L F
.18049 .27446 m .18219 .26835 L .18617 .27232 L .664 .741 .908 r
F
.18049 .27446 m .1765 .2705 L .18219 .26835 L F
.74419 .27446 m .74766 .26835 L .75049 .27232 L .664 .742 .908 r
F
.74419 .27446 m .74135 .27051 L .74766 .26835 L F
.0942 .27429 m .09563 .26819 L .09978 .27215 L .663 .741 .908 r
F
.0942 .27429 m .09003 .27034 L .09563 .26819 L F
.65794 .27429 m .66114 .26819 L .66415 .27216 L F
.65794 .27429 m .65493 .27034 L .66114 .26819 L F
.28211 .27429 m .28413 .2682 L .2879 .27216 L F
.28211 .27429 m .27833 .27034 L .28413 .2682 L F
.5177 .34993 m .52046 .34564 L .52375 .34696 L 0 0 0 r
F
.5177 .34993 m .51436 .35772 L .52046 .34564 L F
.42396 .3158 m .42108 .29287 L .42708 .28929 L .598 .426 .62 r
F
.41753 .33148 m .42108 .29287 L .42396 .3158 L .666 .464 .602 r
F
.41753 .33148 m .41484 .30371 L .42108 .29287 L F
.42108 .29287 m .42373 .28106 L .42708 .28929 L .766 .682 .77 r
F
.42108 .29287 m .41767 .28666 L .42373 .28106 L F
.41484 .30371 m .41767 .28666 L .42108 .29287 L .498 .372 .64 r
F
.19582 .27413 m .19757 .26802 L .20152 .27199 L .663 .741 .908 r
F
.19582 .27413 m .19186 .27017 L .19757 .26802 L F
.75961 .27413 m .76313 .26802 L .76593 .272 L .664 .741 .908 r
F
.75961 .27413 m .7568 .27018 L .76313 .26802 L F
.48263 .28969 m .48476 .32444 L .48832 .31547 L .777 .447 .43 r
F
.48263 .28969 m .47899 .30439 L .48476 .32444 L F
.10951 .27397 m .11099 .26786 L .11511 .27183 L .663 .741 .908 r
F
.10951 .27397 m .10538 .27001 L .11099 .26786 L F
.67335 .27398 m .6766 .26788 L .67958 .27184 L F
.67335 .27398 m .67037 .27002 L .6766 .26788 L F
.29746 .27399 m .29953 .26787 L .30327 .27184 L .664 .741 .908 r
F
.29746 .27399 m .29371 .27003 L .29953 .26787 L F
.5953 .36962 m .59178 .35156 L .59641 .27835 L .922 .657 .518 r
F
.59641 .27835 m .59935 .26956 L .60248 .27352 L .751 .734 .837 r
F
.59641 .27835 m .59325 .27367 L .59935 .26956 L F
.59178 .35156 m .59325 .27367 L .59641 .27835 L .914 .654 .531 r
F
.21115 .27381 m .21295 .2677 L .21687 .27166 L .664 .741 .908 r
F
.21115 .27381 m .20723 .26985 L .21295 .2677 L F
.77504 .27381 m .77861 .26769 L .78138 .27166 L .663 .741 .908 r
F
.77504 .27381 m .77226 .26984 L .77861 .26769 L F
.12483 .27364 m .12636 .26752 L .13045 .27149 L .664 .741 .908 r
F
.12483 .27364 m .12073 .26968 L .12636 .26752 L F
.68877 .27365 m .69207 .26753 L .69501 .2715 L F
.68877 .27365 m .68582 .26969 L .69207 .26753 L F
.31281 .27366 m .31493 .26754 L .31864 .2715 L .665 .742 .907 r
F
.31281 .27366 m .30909 .26971 L .31493 .26754 L F
.79048 .27347 m .7941 .26736 L .79683 .27133 L .664 .742 .908 r
F
.79048 .27347 m .78773 .26951 L .7941 .26736 L F
.22649 .27347 m .22834 .26736 L .23223 .27133 L .664 .741 .908 r
F
.22649 .27347 m .2226 .26951 L .22834 .26736 L F
.60248 .27352 m .60551 .26736 L .60863 .27133 L .666 .742 .907 r
F
.60248 .27352 m .59935 .26956 L .60551 .26736 L F
.14016 .27331 m .14173 .26719 L .1458 .27116 L .663 .741 .908 r
F
.14016 .27331 m .13609 .26934 L .14173 .26719 L F
.70419 .27331 m .70754 .2672 L .71045 .27117 L F
.70419 .27331 m .70127 .26935 L .70754 .2672 L F
.32817 .27335 m .33018 .26972 L .33376 .27529 L .42 .64 .948 r
F
.32817 .27335 m .32448 .26936 L .33018 .26972 L F
.34405 .29874 m .34071 .28953 L .33903 .41908 L .969 .684 .436 r
F
.80592 .27315 m .80959 .26703 L .81229 .271 L .664 .741 .908 r
F
.80592 .27315 m .8032 .26918 L .80959 .26703 L F
.24184 .27315 m .24373 .26704 L .24759 .27101 L .663 .741 .908 r
F
.24184 .27315 m .23797 .26918 L .24373 .26704 L F
.61789 .27316 m .62097 .26704 L .62406 .27101 L .664 .741 .908 r
F
.61789 .27316 m .61479 .2692 L .62097 .26704 L F
.71962 .27298 m .72302 .26688 L .7259 .27085 L .663 .741 .908 r
F
.71962 .27298 m .71673 .26902 L .72302 .26688 L F
.15549 .27298 m .15711 .26687 L .16115 .27085 L F
.15549 .27298 m .15145 .26902 L .15711 .26687 L F
.42987 .31561 m .42708 .28929 L .43257 .3029 L .227 .149 .555 r
F
.42396 .3158 m .42708 .28929 L .42987 .31561 L .598 .426 .62 r
F
.42708 .28929 m .42956 .28302 L .43257 .3029 L .412 .446 .786 r
F
.42708 .28929 m .42373 .28106 L .42956 .28302 L F
.37221 .38326 m .37272 .41582 L .37643 .41842 L .581 .293 .444 r
F
.37221 .38326 m .36706 .41068 L .37272 .41582 L F
.36983 .3958 m .37533 .3236 L .37764 .3548 L .796 .557 .576 r
F
.36983 .3958 m .36759 .36315 L .37533 .3236 L F
.06913 .27281 m .07048 .2667 L .07469 .27067 L .664 .741 .908 r
F
.06913 .27281 m .06491 .26885 L .07048 .2667 L F
.82136 .27282 m .82508 .2667 L .82776 .27067 L .664 .742 .908 r
F
.82136 .27282 m .81868 .26886 L .82508 .2667 L F
.25719 .27283 m .25913 .26671 L .26296 .27068 L .664 .741 .908 r
F
.25719 .27283 m .25335 .26887 L .25913 .26671 L F
.63331 .27284 m .63643 .26671 L .63949 .27068 L F
.63331 .27284 m .63024 .26887 L .63643 .26671 L F
.52375 .34696 m .52046 .34564 L .52654 .34686 L 0 .531 .823 r
F
.17083 .27265 m .1725 .26653 L .1765 .2705 L .664 .741 .908 r
F
.17083 .27265 m .16682 .26869 L .1725 .26653 L F
.73505 .27266 m .7385 .26654 L .74135 .27051 L .664 .742 .908 r
F
.73505 .27266 m .73219 .2687 L .7385 .26654 L F
.44574 .29917 m .44849 .28468 L .45151 .30612 L .822 .779 .274 r
F
.44495 .28416 m .44738 .28272 L .44751 .28357 L 0 0 .072 r
F
.44574 .29917 m .445 .30184 L .44849 .28468 L .822 .779 .274 r
F
.445 .30184 m .44573 .29652 L .44849 .28468 L F
.44181 .31335 m .44495 .28416 L .44849 .28468 L .996 .822 .464 r
F
.44849 .28468 m .44495 .28416 L .44894 .29782 L .911 .523 .261 r
F
.45002 .29892 m .44894 .29782 L .45045 .30299 L F
.44849 .28468 m .44894 .29782 L .45002 .29892 L F
.44495 .28416 m .44751 .28357 L .44664 .28992 L 0 0 .072 r
F
.43911 .32564 m .43868 .32535 L .44181 .31335 L .915 .831 .749 r
F
.43794 .32487 m .43714 .32083 L .43963 .31684 L F
.43868 .32535 m .43794 .32487 L .43963 .31684 L F
.43794 .32487 m .43558 .32332 L .43714 .32083 L F
.43868 .32535 m .43963 .31684 L .44181 .31335 L F
.43558 .32332 m .43798 .322 L .44181 .31335 L 0 0 .455 r
F
.43593 .31476 m .43474 .30874 L .43798 .322 L 0 0 .277 r
F
.43257 .3029 m .43472 .3087 L .43593 .31476 L F
.43472 .3087 m .43474 .30874 L .43593 .31476 L F
.43798 .322 m .44089 .30238 L .44163 .29907 L .693 .539 .674 r
F
.44073 .30709 m .44163 .29907 L .44495 .28416 L F
.43798 .322 m .44163 .29907 L .44073 .30709 L F
.44181 .31335 m .43798 .322 L .44495 .28416 L .996 .822 .464 r
F
.44495 .28416 m .44089 .30238 L .4466 .28508 L 0 0 .072 r
F
.44653 .28322 m .4466 .28508 L .44738 .28272 L F
.44495 .28416 m .4466 .28508 L .44653 .28322 L F
.44406 .29279 m .44406 .27298 L .44738 .28272 L .994 .822 .454 r
F
.44406 .27298 m .44603 .28967 L .44695 .29433 L .685 .316 .341 r
F
.44664 .28992 m .44751 .28357 L .45045 .30299 L 0 0 .072 r
F
.4468 .29046 m .44695 .29433 L .44923 .30593 L .685 .316 .341 r
F
.44406 .27298 m .44695 .29433 L .4468 .29046 L F
.44089 .30238 m .44214 .29081 L .44406 .29279 L .994 .822 .454 r
F
.44214 .29081 m .44406 .27298 L .44406 .29279 L F
.445 .30184 m .44181 .31335 L .44573 .29652 L .822 .779 .274 r
F
.43911 .32564 m .44181 .31335 L .44574 .29917 L .915 .831 .749 r
F
.33728 .2818 m .33438 .36089 L .3367 .38969 L .966 .673 .421 r
F
.3367 .38969 m .33438 .36089 L .33439 .36088 L .604 .416 .6 r
F
.34043 .31146 m .3367 .38969 L .33903 .41883 L .967 .679 .431 r
F
.34071 .28953 m .33954 .3187 L .34043 .31146 L F
.33954 .3187 m .3367 .38969 L .34043 .31146 L F
.34071 .28953 m .33728 .2818 L .3367 .38969 L F
.3367 .38969 m .33439 .36088 L .3406 .35557 L .604 .416 .6 r
F
.33439 .36088 m .33495 .38335 L .3406 .35557 L .859 .628 .092 r
F
.33438 .36089 m .33438 .36096 L .33439 .36088 L F
.33438 .36096 m .33495 .38335 L .33439 .36088 L F
.33903 .41883 m .3367 .38969 L .33903 .41908 L .967 .679 .431 r
F
.08445 .27248 m .08585 .26636 L .09003 .27034 L .664 .741 .908 r
F
.08445 .27248 m .08027 .26852 L .08585 .26636 L F
.83681 .27248 m .84058 .26637 L .84322 .27034 L .663 .741 .908 r
F
.83681 .27248 m .83416 .26852 L .84058 .26637 L F
.64872 .27249 m .6519 .26636 L .65493 .27034 L .664 .741 .908 r
F
.64872 .27249 m .64569 .26852 L .6519 .26636 L F
.27254 .27249 m .27454 .26636 L .27833 .27034 L F
.27254 .27249 m .26874 .26853 L .27454 .26636 L F
.75049 .27232 m .75398 .2662 L .7568 .27018 L .663 .741 .908 r
F
.75049 .27232 m .74766 .26835 L .75398 .2662 L F
.18617 .27232 m .18789 .2662 L .19186 .27017 L F
.18617 .27232 m .18219 .26835 L .18789 .2662 L F
.49193 .29728 m .49424 .33024 L .49778 .31615 L .713 .394 .436 r
F
.49193 .29728 m .48832 .31547 L .49424 .33024 L F
.09978 .27215 m .10123 .26603 L .10538 .27001 L .664 .741 .908 r
F
.09978 .27215 m .09563 .26819 L .10123 .26603 L F
.66415 .27216 m .66737 .26604 L .67037 .27002 L .663 .741 .908 r
F
.66415 .27216 m .66114 .26819 L .66737 .26604 L F
.2879 .27216 m .28994 .26606 L .29371 .27003 L F
.2879 .27216 m .28413 .2682 L .28994 .26606 L F
.38561 .38178 m .38084 .40498 L .38731 .39123 L .151 0 .283 r
F
.20152 .27199 m .20329 .26587 L .20723 .26985 L .663 .741 .908 r
F
.20152 .27199 m .19757 .26802 L .20329 .26587 L F
.76593 .272 m .76948 .26587 L .77226 .26984 L .664 .741 .908 r
F
.76593 .272 m .76313 .26802 L .76948 .26587 L F
.11511 .27183 m .11661 .26571 L .12073 .26968 L F
.11511 .27183 m .11099 .26786 L .11661 .26571 L F
.30327 .27184 m .30536 .26573 L .30909 .26971 L .663 .741 .908 r
F
.30327 .27184 m .29953 .26787 L .30536 .26573 L F
.67958 .27184 m .68285 .26571 L .68582 .26969 L .664 .742 .908 r
F
.67958 .27184 m .6766 .26788 L .68285 .26571 L F
.45459 .32603 m .45151 .30612 L .45398 .30564 L .564 .414 .636 r
F
.45624 .31407 m .45398 .30564 L .4575 .30497 L F
.45459 .32603 m .45398 .30564 L .45624 .31407 L F
.45151 .30612 m .45379 .31256 L .4575 .30497 L 0 0 .28 r
F
.45151 .30612 m .4504 .29828 L .45379 .31256 L F
.4504 .29828 m .44849 .28468 L .45105 .29815 L F
.4504 .29828 m .45105 .29815 L .45379 .31256 L F
.44879 .28626 m .45045 .30299 L .45379 .31256 L .911 .523 .261 r
F
.45379 .31256 m .45045 .30299 L .45556 .28701 L .869 .666 .626 r
F
.45647 .28697 m .45556 .28701 L .4569 .28284 L F
.45379 .31256 m .45556 .28701 L .45647 .28697 L F
.45045 .30299 m .45301 .29801 L .45308 .29771 L .028 .035 .529 r
F
.45207 .29793 m .45308 .29771 L .4569 .28284 L F
.45045 .30299 m .45308 .29771 L .45207 .29793 L F
.44857 .28545 m .45045 .30299 L .44879 .28626 L .911 .523 .261 r
F
.45045 .30299 m .44738 .28272 L .45301 .29801 L .028 .035 .529 r
F
.44907 .28732 m .44923 .30593 L .45301 .29801 L .941 .612 .177 r
F
.44738 .28272 m .44775 .28738 L .44907 .28732 L F
.44775 .28738 m .44923 .30593 L .44907 .28732 L F
.44849 .28468 m .44857 .28545 L .44879 .28626 L .911 .523 .261 r
F
.78138 .27166 m .78497 .26554 L .78773 .26951 L .663 .741 .908 r
F
.78138 .27166 m .77861 .26769 L .78497 .26554 L F
.42594 .28292 m .42176 .29928 L .42573 .28398 L 0 0 0 r
F
.42615 .28188 m .42594 .28292 L .42956 .28302 L 0 0 .118 r
F
.43257 .3029 m .42956 .28302 L .43173 .29382 L 0 0 .277 r
F
.43273 .30332 m .43173 .29382 L .43474 .30874 L F
.43257 .3029 m .43173 .29382 L .43273 .30332 L F
.42594 .28292 m .42855 .27314 L .43009 .27807 L 0 0 0 r
F
.42956 .28302 m .43185 .28371 L .43474 .30874 L .155 0 0 r
F
.42855 .27314 m .43113 .26446 L .43309 .28438 L .681 .721 .205 r
F
.42956 .28302 m .42609 .28293 L .43185 .28371 L .155 0 0 r
F
.42609 .28293 m .42631 .28297 L .43185 .28371 L F
.43066 .28355 m .43009 .27807 L .43185 .28371 L 0 0 0 r
F
.42609 .28293 m .42594 .28292 L .42631 .28297 L .155 0 0 r
F
.42594 .28292 m .43009 .27807 L .43066 .28355 L 0 0 0 r
F
.43798 .322 m .43474 .30874 L .43587 .30757 L .693 .539 .674 r
F
.43806 .32146 m .43587 .30757 L .44087 .30241 L F
.43806 .32146 m .44087 .30241 L .44086 .30264 L F
.43798 .322 m .43587 .30757 L .43806 .32146 L F
.43474 .30874 m .43702 .3117 L .44089 .30238 L 0 0 .339 r
F
.43702 .3117 m .44021 .2822 L .44238 .27701 L .708 .518 .629 r
F
.44192 .28474 m .44238 .27701 L .44406 .27298 L F
.43702 .3117 m .44238 .27701 L .44192 .28474 L F
.44086 .30264 m .44087 .30241 L .44089 .30238 L .693 .539 .674 r
F
.43362 .2933 m .43392 .29282 L .43702 .3117 L .759 .449 0 r
F
.43185 .28371 m .4327 .28744 L .43362 .2933 L F
.4327 .28744 m .43392 .29282 L .43362 .2933 L F
.43474 .30874 m .43185 .28371 L .43702 .3117 L 0 0 .339 r
F
.43185 .28371 m .42855 .27314 L .43392 .29282 L .759 .449 0 r
F
.43153 .28406 m .43309 .28438 L .43392 .29282 L .681 .721 .205 r
F
.42855 .27314 m .43309 .28438 L .43153 .28406 L F
.42594 .28292 m .42573 .28398 L .42855 .27314 L 0 0 0 r
F
.42373 .28106 m .42594 .28292 L .42615 .28188 L 0 0 .118 r
F
.42373 .28106 m .41956 .29704 L .42594 .28292 L F
.41767 .28666 m .41956 .29704 L .42373 .28106 L .362 .047 .289 r
F
.21687 .27166 m .21869 .26554 L .2226 .26951 L .664 .741 .908 r
F
.21687 .27166 m .21295 .2677 L .21869 .26554 L F
.41767 .28666 m .41351 .30082 L .41956 .29704 L .362 .047 .289 r
F
.13045 .27149 m .132 .26537 L .13609 .26934 L .664 .741 .908 r
F
.13045 .27149 m .12636 .26752 L .132 .26537 L F
.69501 .2715 m .69833 .26537 L .70127 .26935 L F
.69501 .2715 m .69207 .26753 L .69833 .26537 L F
.31864 .2715 m .32078 .26537 L .32448 .26936 L F
.31864 .2715 m .31493 .26754 L .32078 .26537 L F
.60863 .27133 m .61168 .26522 L .61479 .2692 L .663 .741 .908 r
F
.60863 .27133 m .60551 .26736 L .61168 .26522 L F
.23223 .27133 m .23409 .26521 L .23797 .26918 L F
.23223 .27133 m .22834 .26736 L .23409 .26521 L F
.79683 .27133 m .80048 .2652 L .8032 .26918 L .664 .741 .908 r
F
.79683 .27133 m .7941 .26736 L .80048 .2652 L F
.57249 .32009 m .56897 .29463 L .57567 .32853 L 0 0 .34 r
F
.56897 .29463 m .57209 .30147 L .57567 .32853 L 0 0 .354 r
F
.1458 .27116 m .14739 .26504 L .15145 .26902 L .663 .741 .908 r
F
.1458 .27116 m .14173 .26719 L .14739 .26504 L F
.71045 .27117 m .71382 .26504 L .71673 .26902 L F
.71045 .27117 m .70754 .2672 L .71382 .26504 L F
.52046 .34564 m .51718 .32891 L .52324 .33616 L .322 .268 .64 r
F
.51436 .35772 m .51718 .32891 L .52046 .34564 L .759 .565 .636 r
F
.51436 .35772 m .51108 .34212 L .51718 .32891 L F
.51718 .32891 m .51996 .31446 L .52324 .33616 L .374 .273 .611 r
F
.81229 .271 m .81598 .26488 L .81868 .26886 L .663 .741 .908 r
F
.81229 .271 m .80959 .26703 L .81598 .26488 L F
.62406 .27101 m .62716 .26488 L .63024 .26887 L .664 .742 .908 r
F
.62406 .27101 m .62097 .26704 L .62716 .26488 L F
.24759 .27101 m .2495 .26489 L .25335 .26887 L .663 .741 .908 r
F
.24759 .27101 m .24373 .26704 L .2495 .26489 L F
.33728 .2818 m .33376 .27529 L .33438 .36089 L .966 .673 .421 r
F
.41075 .35625 m .41484 .30371 L .41753 .33148 L .877 .642 .579 r
F
.41075 .35625 m .40759 .34126 L .41484 .30371 L F
.16115 .27085 m .16279 .26471 L .16682 .26869 L .664 .741 .908 r
F
.16115 .27085 m .15711 .26687 L .16279 .26471 L F
.7259 .27085 m .72932 .26472 L .73219 .2687 L F
.7259 .27085 m .72302 .26688 L .72932 .26472 L F
.07469 .27067 m .07606 .26454 L .08027 .26852 L F
.07469 .27067 m .07048 .2667 L .07606 .26454 L F
.82776 .27067 m .8315 .26454 L .83416 .26852 L F
.82776 .27067 m .82508 .2667 L .8315 .26454 L F
.26296 .27068 m .26492 .26455 L .26874 .26853 L F
.26296 .27068 m .25913 .26671 L .26492 .26455 L F
.63949 .27068 m .64264 .26454 L .64569 .26852 L .664 .742 .908 r
F
.63949 .27068 m .63643 .26671 L .64264 .26454 L F
.42468 .33506 m .42696 .33547 L .43054 .33648 L 0 0 0 r
F
.42468 .33506 m .42074 .34459 L .42696 .33547 L F
.1765 .2705 m .17819 .26437 L .18219 .26835 L .664 .741 .908 r
F
.1765 .2705 m .1725 .26653 L .17819 .26437 L F
.74135 .27051 m .74482 .26437 L .74766 .26835 L .664 .742 .908 r
F
.74135 .27051 m .7385 .26654 L .74482 .26437 L F
.59178 .35156 m .58829 .33433 L .59325 .27367 L .914 .654 .531 r
F
.59325 .27367 m .59621 .26557 L .59935 .26956 L .73 .734 .854 r
F
.59325 .27367 m .59009 .26911 L .59621 .26557 L F
.58829 .33433 m .59009 .26911 L .59325 .27367 L .903 .649 .545 r
F
.09003 .27034 m .09145 .26421 L .09563 .26819 L .663 .741 .908 r
F
.09003 .27034 m .08585 .26636 L .09145 .26421 L F
.27833 .27034 m .28034 .26422 L .28413 .2682 L F
.27833 .27034 m .27454 .26636 L .28034 .26422 L F
.65493 .27034 m .65812 .26421 L .66114 .26819 L F
.65493 .27034 m .6519 .26636 L .65812 .26421 L F
.19186 .27017 m .1936 .26404 L .19757 .26802 L F
.19186 .27017 m .18789 .2662 L .1936 .26404 L F
.7568 .27018 m .76032 .26404 L .76313 .26802 L .664 .741 .908 r
F
.7568 .27018 m .75398 .2662 L .76032 .26404 L F
.10538 .27001 m .10685 .26388 L .11099 .26786 L .663 .741 .908 r
F
.10538 .27001 m .10123 .26603 L .10685 .26388 L F
.67037 .27002 m .67362 .26389 L .6766 .26788 L F
.67037 .27002 m .66737 .26604 L .67362 .26389 L F
.29371 .27003 m .29577 .26389 L .29953 .26787 L .664 .742 .908 r
F
.29371 .27003 m .28994 .26606 L .29577 .26389 L F
.77226 .26984 m .77583 .26371 L .77861 .26769 L .663 .741 .908 r
F
.77226 .26984 m .76948 .26587 L .77583 .26371 L F
.20723 .26985 m .20902 .26371 L .21295 .2677 L .664 .741 .908 r
F
.20723 .26985 m .20329 .26587 L .20902 .26371 L F
.12073 .26968 m .12225 .26354 L .12636 .26752 L F
.12073 .26968 m .11661 .26571 L .12225 .26354 L F
.68582 .26969 m .68911 .26354 L .69207 .26753 L F
.68582 .26969 m .68285 .26571 L .68911 .26354 L F
.30909 .26971 m .3112 .26355 L .31493 .26754 L .665 .742 .907 r
F
.30909 .26971 m .30536 .26573 L .3112 .26355 L F
.2226 .26951 m .22444 .26337 L .22834 .26736 L .664 .741 .908 r
F
.2226 .26951 m .21869 .26554 L .22444 .26337 L F
.78773 .26951 m .79135 .26337 L .7941 .26736 L F
.78773 .26951 m .78497 .26554 L .79135 .26337 L F
.59935 .26956 m .60238 .26337 L .60551 .26736 L .666 .741 .907 r
F
.59935 .26956 m .59621 .26557 L .60238 .26337 L F
.13609 .26934 m .13765 .26321 L .14173 .26719 L .663 .741 .908 r
F
.13609 .26934 m .132 .26537 L .13765 .26321 L F
.70127 .26935 m .70462 .26321 L .70754 .2672 L F
.70127 .26935 m .69833 .26537 L .70462 .26321 L F
.32448 .26936 m .32654 .26477 L .33018 .26972 L .533 .693 .941 r
F
.32448 .26936 m .32078 .26537 L .32654 .26477 L F
.8032 .26918 m .80687 .26304 L .80959 .26703 L .663 .741 .908 r
F
.8032 .26918 m .80048 .2652 L .80687 .26304 L F
.23797 .26918 m .23986 .26305 L .24373 .26704 L F
.23797 .26918 m .23409 .26521 L .23986 .26305 L F
.61479 .2692 m .61787 .26306 L .62097 .26704 L F
.61479 .2692 m .61168 .26522 L .61787 .26306 L F
.71673 .26902 m .72012 .26289 L .72302 .26688 L F
.71673 .26902 m .71382 .26504 L .72012 .26289 L F
.15145 .26902 m .15306 .26289 L .15711 .26687 L F
.15145 .26902 m .14739 .26504 L .15306 .26289 L F
.06491 .26885 m .06625 .26271 L .07048 .2667 L .664 .741 .908 r
F
.06491 .26885 m .06068 .26487 L .06625 .26271 L F
.81868 .26886 m .8224 .26271 L .82508 .2667 L .664 .742 .908 r
F
.81868 .26886 m .81598 .26488 L .8224 .26271 L F
.25335 .26887 m .25529 .26272 L .25913 .26671 L .664 .741 .908 r
F
.25335 .26887 m .2495 .26489 L .25529 .26272 L F
.63024 .26887 m .63336 .26273 L .63643 .26671 L .663 .741 .908 r
F
.63024 .26887 m .62716 .26488 L .63336 .26273 L F
.16682 .26869 m .16848 .26254 L .1725 .26653 L .664 .741 .908 r
F
.16682 .26869 m .16279 .26471 L .16848 .26254 L F
.73219 .2687 m .73564 .26255 L .7385 .26654 L F
.73219 .2687 m .72932 .26472 L .73564 .26255 L F
.33376 .27529 m .3319 .33538 L .33438 .36089 L .965 .664 .407 r
F
.33376 .27529 m .33018 .26972 L .3319 .33538 L F
.08027 .26852 m .08166 .26237 L .08585 .26636 L .664 .741 .908 r
F
.08027 .26852 m .07606 .26454 L .08166 .26237 L F
.83416 .26852 m .83793 .26238 L .84058 .26637 L .663 .741 .908 r
F
.83416 .26852 m .8315 .26454 L .83793 .26238 L F
.64569 .26852 m .64886 .26237 L .6519 .26636 L .664 .741 .908 r
F
.64569 .26852 m .64264 .26454 L .64886 .26237 L F
.26874 .26853 m .27072 .26237 L .27454 .26636 L F
.26874 .26853 m .26492 .26455 L .27072 .26237 L F
.74766 .26835 m .75115 .26221 L .75398 .2662 L .663 .741 .908 r
F
.74766 .26835 m .74482 .26437 L .75115 .26221 L F
.18219 .26835 m .1839 .26221 L .18789 .2662 L F
.18219 .26835 m .17819 .26437 L .1839 .26221 L F
.09563 .26819 m .09706 .26204 L .10123 .26603 L .664 .741 .908 r
F
.09563 .26819 m .09145 .26421 L .09706 .26204 L F
.66114 .26819 m .66436 .26205 L .66737 .26604 L .663 .741 .908 r
F
.66114 .26819 m .65812 .26421 L .66436 .26205 L F
.28413 .2682 m .28616 .26207 L .28994 .26606 L F
.28413 .2682 m .28034 .26422 L .28616 .26207 L F
.19757 .26802 m .19933 .26188 L .20329 .26587 L F
.19757 .26802 m .1936 .26404 L .19933 .26188 L F
.76313 .26802 m .76668 .26188 L .76948 .26587 L F
.76313 .26802 m .76032 .26404 L .76668 .26188 L F
.11099 .26786 m .11248 .26171 L .11661 .26571 L .664 .741 .908 r
F
.11099 .26786 m .10685 .26388 L .11248 .26171 L F
.29953 .26787 m .30161 .26174 L .30536 .26573 L .662 .741 .908 r
F
.29953 .26787 m .29577 .26389 L .30161 .26174 L F
.6766 .26788 m .67987 .26172 L .68285 .26571 L .664 .741 .908 r
F
.6766 .26788 m .67362 .26389 L .67987 .26172 L F
.77861 .26769 m .7822 .26154 L .78497 .26554 L .664 .742 .908 r
F
.77861 .26769 m .77583 .26371 L .7822 .26154 L F
.21295 .2677 m .21476 .26154 L .21869 .26554 L .664 .741 .908 r
F
.21295 .2677 m .20902 .26371 L .21476 .26154 L F
.35695 .45702 m .36556 .32725 L .36759 .36315 L .981 .732 .48 r
F
.35695 .45702 m .35231 .4698 L .36556 .32725 L F
.46664 .32283 m .46347 .30516 L .46828 .28995 L .795 .58 .611 r
F
.46938 .29048 m .46828 .28995 L .46984 .28503 L F
.46664 .32283 m .46828 .28995 L .46938 .29048 L F
.46347 .30516 m .46592 .30807 L .46984 .28503 L 0 0 .373 r
F
.46347 .30516 m .46038 .28484 L .46405 .30023 L F
.46439 .30625 m .46405 .30023 L .46592 .30807 L F
.46347 .30516 m .46405 .30023 L .46439 .30625 L F
.4575 .30497 m .46038 .28484 L .46347 .30516 L .98 .852 .465 r
F
.46073 .2863 m .46213 .3207 L .46592 .30807 L .951 .613 .337 r
F
.46038 .28484 m .46044 .28617 L .46073 .2863 L F
.46044 .28617 m .46213 .3207 L .46073 .2863 L F
.4575 .30497 m .45379 .31256 L .45864 .29214 L .98 .852 .465 r
F
.45908 .29387 m .45864 .29214 L .46038 .28484 L F
.4575 .30497 m .45864 .29214 L .45908 .29387 L F
.45379 .31256 m .4569 .28284 L .46038 .28484 L .869 .666 .626 r
F
.45765 .28827 m .45897 .30117 L .46213 .3207 L .57 .242 .374 r
F
.4569 .28284 m .45741 .28732 L .45765 .28827 L F
.45741 .28732 m .45897 .30117 L .45765 .28827 L F
.46038 .28484 m .4569 .28284 L .46213 .3207 L .951 .613 .337 r
F
.45897 .30117 m .46204 .27302 L .46247 .27232 L .471 .312 .583 r
F
.46295 .28089 m .46247 .27232 L .46569 .26696 L F
.45897 .30117 m .46247 .27232 L .46295 .28089 L F
.46984 .28503 m .47191 .31139 L .47529 .3189 L .562 .265 .422 r
F
.46984 .28503 m .46592 .30807 L .47191 .31139 L F
.12636 .26752 m .1279 .26137 L .132 .26537 L .664 .741 .908 r
F
.12636 .26752 m .12225 .26354 L .1279 .26137 L F
.69207 .26753 m .69539 .26137 L .69833 .26537 L F
.69207 .26753 m .68911 .26354 L .69539 .26137 L F
.31493 .26754 m .31706 .26137 L .32078 .26537 L .664 .742 .908 r
F
.31493 .26754 m .3112 .26355 L .31706 .26137 L F
.22834 .26736 m .2302 .26121 L .23409 .26521 L .663 .741 .908 r
F
.22834 .26736 m .22444 .26337 L .2302 .26121 L F
.60551 .26736 m .60856 .26122 L .61168 .26522 L F
.60551 .26736 m .60238 .26337 L .60856 .26122 L F
.7941 .26736 m .79774 .26121 L .80048 .2652 L .664 .741 .908 r
F
.7941 .26736 m .79135 .26337 L .79774 .26121 L F
.14173 .26719 m .14332 .26105 L .14739 .26504 L .663 .741 .908 r
F
.14173 .26719 m .13765 .26321 L .14332 .26105 L F
.70754 .2672 m .71091 .26105 L .71382 .26504 L F
.70754 .2672 m .70462 .26321 L .71091 .26105 L F
.52046 .34564 m .52324 .33616 L .52654 .34686 L .322 .268 .64 r
F
.39868 .28453 m .39924 .32444 L .40342 .31359 L .674 .372 .454 r
F
.39868 .28453 m .39389 .31009 L .39924 .32444 L F
.80959 .26703 m .81328 .26088 L .81598 .26488 L .663 .741 .908 r
F
.80959 .26703 m .80687 .26304 L .81328 .26088 L F
.62097 .26704 m .62407 .26088 L .62716 .26488 L .665 .742 .908 r
F
.62097 .26704 m .61787 .26306 L .62407 .26088 L F
.24373 .26704 m .24564 .26089 L .2495 .26489 L .663 .741 .908 r
F
.24373 .26704 m .23986 .26305 L .24564 .26089 L F
.15711 .26687 m .15875 .26071 L .16279 .26471 L .664 .741 .908 r
F
.15711 .26687 m .15306 .26289 L .15875 .26071 L F
.72302 .26688 m .72644 .26071 L .72932 .26472 L F
.72302 .26688 m .72012 .26289 L .72644 .26071 L F
.58829 .33433 m .58484 .31805 L .59009 .26911 L .903 .649 .545 r
F
.59009 .26911 m .59306 .26156 L .59621 .26557 L .711 .733 .868 r
F
.59009 .26911 m .58691 .26466 L .59306 .26156 L F
.58484 .31805 m .58691 .26466 L .59009 .26911 L .889 .644 .563 r
F
.07048 .2667 m .07184 .26054 L .07606 .26454 L .664 .741 .908 r
F
.07048 .2667 m .06625 .26271 L .07184 .26054 L F
.82508 .2667 m .82882 .26054 L .8315 .26454 L .663 .741 .908 r
F
.82508 .2667 m .8224 .26271 L .82882 .26054 L F
.25913 .26671 m .26109 .26055 L .26492 .26455 L .664 .741 .908 r
F
.25913 .26671 m .25529 .26272 L .26109 .26055 L F
.63643 .26671 m .63958 .26055 L .64264 .26454 L .664 .742 .908 r
F
.63643 .26671 m .63336 .26273 L .63958 .26055 L F
.1725 .26653 m .17418 .26037 L .17819 .26437 L .664 .741 .908 r
F
.1725 .26653 m .16848 .26254 L .17418 .26037 L F
.7385 .26654 m .74197 .26037 L .74482 .26437 L F
.7385 .26654 m .73564 .26255 L .74197 .26037 L F
.40208 .33114 m .40522 .30614 L .40759 .34126 L .987 .836 .455 r
F
.08585 .26636 m .08726 .26021 L .09145 .26421 L .663 .741 .908 r
F
.08585 .26636 m .08166 .26237 L .08726 .26021 L F
.27454 .26636 m .27654 .26022 L .28034 .26422 L F
.27454 .26636 m .27072 .26237 L .27654 .26022 L F
.6519 .26636 m .65509 .26021 L .65812 .26421 L F
.6519 .26636 m .64886 .26237 L .65509 .26021 L F
.42696 .33547 m .42396 .3158 L .42987 .31561 L .544 .401 .637 r
F
.42074 .34459 m .42396 .3158 L .42696 .33547 L .802 .606 .637 r
F
.42074 .34459 m .41753 .33148 L .42396 .3158 L F
.38539 .3212 m .38114 .33702 L .3886 .28557 L .989 .804 .417 r
F
.38114 .33702 m .38083 .33815 L .38118 .33578 L F
.38114 .33702 m .38118 .33578 L .3886 .28557 L F
.38539 .3212 m .3886 .28557 L .38884 .28546 L F
.38083 .33815 m .38569 .27695 L .38925 .28117 L .951 .712 .539 r
F
.38083 .33815 m .37721 .3335 L .38569 .27695 L F
.38569 .27695 m .38123 .29179 L .38612 .31451 L .791 .466 .438 r
F
.3826 .29817 m .38378 .28162 L .38612 .31451 L .687 .702 .173 r
F
.38123 .29179 m .38313 .2842 L .3826 .29817 L F
.38313 .2842 m .38378 .28162 L .3826 .29817 L F
.3864 .28661 m .38612 .31451 L .38937 .32726 L .791 .466 .438 r
F
.38569 .27695 m .3858 .28689 L .3864 .28661 L F
.3858 .28689 m .38612 .31451 L .3864 .28661 L F
.38884 .28546 m .3886 .28557 L .38925 .28117 L .989 .804 .417 r
F
.38925 .28117 m .38937 .32726 L .39389 .31009 L .962 .646 .373 r
F
.38925 .28117 m .38569 .27695 L .38937 .32726 L F
.18789 .2662 m .18962 .26004 L .1936 .26404 L .663 .741 .908 r
F
.18789 .2662 m .1839 .26221 L .18962 .26004 L F
.43054 .33648 m .43289 .33541 L .43658 .33232 L .195 .701 .904 r
F
.43054 .33648 m .42696 .33547 L .43289 .33541 L F
.75398 .2662 m .7575 .26004 L .76032 .26404 L .663 .741 .908 r
F
.75398 .2662 m .75115 .26221 L .7575 .26004 L F
.10123 .26603 m .10269 .25988 L .10685 .26388 L F
.10123 .26603 m .09706 .26204 L .10269 .25988 L F
.66737 .26604 m .67062 .25989 L .67362 .26389 L F
.66737 .26604 m .66436 .26205 L .67062 .25989 L F
.28994 .26606 m .292 .25989 L .29577 .26389 L .664 .742 .908 r
F
.28994 .26606 m .28616 .26207 L .292 .25989 L F
.76948 .26587 m .77304 .25971 L .77583 .26371 L .663 .741 .908 r
F
.76948 .26587 m .76668 .26188 L .77304 .25971 L F
.20329 .26587 m .20507 .25971 L .20902 .26371 L .664 .741 .908 r
F
.20329 .26587 m .19933 .26188 L .20507 .25971 L F
.40797 .29124 m .40924 .31674 L .41351 .30082 L .558 .258 .415 r
F
.40797 .29124 m .40342 .31359 L .40924 .31674 L F
.11661 .26571 m .11812 .25954 L .12225 .26354 L .664 .741 .908 r
F
.11661 .26571 m .11248 .26171 L .11812 .25954 L F
.68285 .26571 m .68615 .25954 L .68911 .26354 L .664 .742 .908 r
F
.68285 .26571 m .67987 .26172 L .68615 .25954 L F
.30536 .26573 m .30746 .25955 L .3112 .26355 L .665 .742 .907 r
F
.30536 .26573 m .30161 .26174 L .30746 .25955 L F
.33018 .26972 m .3292 .31418 L .3319 .33538 L .963 .651 .384 r
F
.33018 .26972 m .32654 .26477 L .3292 .31418 L F
.21869 .26554 m .22052 .25937 L .22444 .26337 L .664 .741 .908 r
F
.21869 .26554 m .21476 .26154 L .22052 .25937 L F
.78497 .26554 m .78859 .25937 L .79135 .26337 L F
.78497 .26554 m .7822 .26154 L .78859 .25937 L F
.59621 .26557 m .59923 .25937 L .60238 .26337 L .665 .741 .907 r
F
.59621 .26557 m .59306 .26156 L .59923 .25937 L F
.132 .26537 m .13356 .25921 L .13765 .26321 L .663 .741 .908 r
F
.132 .26537 m .1279 .26137 L .13356 .25921 L F
.69833 .26537 m .70168 .25921 L .70462 .26321 L F
.69833 .26537 m .69539 .26137 L .70168 .25921 L F
.32078 .26537 m .32287 .26018 L .32654 .26477 L .588 .715 .931 r
F
.32078 .26537 m .31706 .26137 L .32287 .26018 L F
.43658 .33232 m .43289 .33541 L .43911 .32564 L .875 .968 .646 r
F
.80048 .2652 m .80414 .25905 L .80687 .26304 L .663 .741 .908 r
F
.80048 .2652 m .79774 .26121 L .80414 .25905 L F
.23409 .26521 m .23597 .25905 L .23986 .26305 L F
.23409 .26521 m .2302 .26121 L .23597 .25905 L F
.61168 .26522 m .61475 .25907 L .61787 .26306 L .662 .741 .908 r
F
.61168 .26522 m .60856 .26122 L .61475 .25907 L F
.54131 .3542 m .54377 .27428 L .54706 .28492 L .876 .62 .548 r
F
.54706 .28492 m .54377 .27428 L .5501 .29922 L .797 .482 0 r
F
.54131 .3542 m .53789 .3303 L .54377 .27428 L .876 .62 .548 r
F
.54377 .27428 m .54701 .32288 L .5501 .29922 L .922 .586 .385 r
F
.54377 .27428 m .54055 .27938 L .54701 .32288 L F
.71382 .26504 m .71722 .25888 L .72012 .26289 L .664 .741 .908 r
F
.71382 .26504 m .71091 .26105 L .71722 .25888 L F
.14739 .26504 m .149 .25888 L .15306 .26289 L .663 .741 .908 r
F
.14739 .26504 m .14332 .26105 L .149 .25888 L F
.54706 .28492 m .5501 .29922 L .55317 .28235 L .797 .482 0 r
F
.81598 .26488 m .8197 .2587 L .8224 .26271 L .664 .741 .908 r
F
.81598 .26488 m .81328 .26088 L .8197 .2587 L F
.62716 .26488 m .63028 .25872 L .63336 .26273 L .663 .741 .908 r
F
.62716 .26488 m .62407 .26088 L .63028 .25872 L F
.2495 .26489 m .25143 .25872 L .25529 .26272 L .664 .741 .908 r
F
.2495 .26489 m .24564 .26089 L .25143 .25872 L F
.16279 .26471 m .16444 .25854 L .16848 .26254 L F
.16279 .26471 m .15875 .26071 L .16444 .25854 L F
.72932 .26472 m .73276 .25854 L .73564 .26255 L F
.72932 .26472 m .72644 .26071 L .73276 .25854 L F
.07606 .26454 m .07744 .25837 L .08166 .26237 L F
.07606 .26454 m .07184 .26054 L .07744 .25837 L F
.8315 .26454 m .83526 .25837 L .83793 .26238 L F
.8315 .26454 m .82882 .26054 L .83526 .25837 L F
.64264 .26454 m .64581 .25837 L .64886 .26237 L .664 .742 .908 r
F
.64264 .26454 m .63958 .26055 L .64581 .25837 L F
.26492 .26455 m .2669 .25837 L .27072 .26237 L F
.26492 .26455 m .26109 .26055 L .2669 .25837 L F
.17819 .26437 m .1799 .2582 L .1839 .26221 L .663 .741 .908 r
F
.17819 .26437 m .17418 .26037 L .1799 .2582 L F
.74482 .26437 m .74831 .2582 L .75115 .26221 L F
.74482 .26437 m .74197 .26037 L .74831 .2582 L F
.09145 .26421 m .09288 .25803 L .09706 .26204 L .664 .741 .908 r
F
.09145 .26421 m .08726 .26021 L .09288 .25803 L F
.65812 .26421 m .66134 .25804 L .66436 .26205 L F
.65812 .26421 m .65509 .26021 L .66134 .25804 L F
.28034 .26422 m .28237 .25806 L .28616 .26207 L .663 .741 .908 r
F
.28034 .26422 m .27654 .26022 L .28237 .25806 L F
.38731 .39123 m .38335 .39581 L .39063 .36301 L .997 .815 .54 r
F
.38335 .39581 m .38629 .37669 L .39063 .36301 L .674 .525 .675 r
F
.76032 .26404 m .76387 .25788 L .76668 .26188 L .663 .741 .908 r
F
.76032 .26404 m .7575 .26004 L .76387 .25788 L F
.1936 .26404 m .19535 .25788 L .19933 .26188 L F
.1936 .26404 m .18962 .26004 L .19535 .25788 L F
.57013 .36664 m .57249 .32009 L .5761 .34961 L .769 .546 .595 r
F
.57351 .3804 m .57013 .36664 L .5761 .34961 L .808 .606 .628 r
F
.56864 .28091 m .56533 .26978 L .57432 .45663 L .977 .678 .37 r
F
.56533 .26978 m .56216 .26954 L .57071 .43814 L .967 .664 .395 r
F
.41496 .34103 m .41753 .33148 L .42074 .34459 L .692 .716 .195 r
F
.41496 .34103 m .41075 .35625 L .41753 .33148 L F
.10685 .26388 m .10832 .2577 L .11248 .26171 L .664 .741 .908 r
F
.10685 .26388 m .10269 .25988 L .10832 .2577 L F
.29577 .26389 m .29784 .25773 L .30161 .26174 L .662 .741 .908 r
F
.29577 .26389 m .292 .25989 L .29784 .25773 L F
.67362 .26389 m .67688 .25771 L .67987 .26172 L .664 .741 .908 r
F
.67362 .26389 m .67062 .25989 L .67688 .25771 L F
.20902 .26371 m .21082 .25753 L .21476 .26154 L F
.20902 .26371 m .20507 .25971 L .21082 .25753 L F
.77583 .26371 m .77942 .25753 L .7822 .26154 L F
.77583 .26371 m .77304 .25971 L .77942 .25753 L F
.12225 .26354 m .12377 .25736 L .1279 .26137 L F
.12225 .26354 m .11812 .25954 L .12377 .25736 L F
.68911 .26354 m .69243 .25736 L .69539 .26137 L F
.68911 .26354 m .68615 .25954 L .69243 .25736 L F
.3112 .26355 m .31333 .25736 L .31706 .26137 L F
.3112 .26355 m .30746 .25955 L .31333 .25736 L F
.57209 .30147 m .56864 .28091 L .57709 .45308 L .98 .687 .341 r
F
.57728 .45392 m .57709 .45308 L .57761 .46354 L F
.57209 .30147 m .57709 .45308 L .57728 .45392 L F
.56864 .28091 m .57432 .45663 L .57783 .46809 L .977 .678 .37 r
F
.56723 .40895 m .56804 .25838 L .57135 .26689 L .934 .657 .492 r
F
.56706 .41487 m .5671 .40836 L .56723 .40895 L F
.5671 .40836 m .56804 .25838 L .56723 .40895 L F
.57209 .30147 m .57761 .46354 L .57769 .46392 L .98 .687 .341 r
F
.57567 .32853 m .57209 .30147 L .58118 .47071 L .977 .688 .304 r
F
.58118 .47075 m .58118 .47071 L .5812 .47105 L F
.57567 .32853 m .58118 .47071 L .58118 .47075 L F
.57209 .30147 m .57783 .46809 L .5812 .47105 L .98 .687 .341 r
F
.57136 .41165 m .57135 .26689 L .57467 .27714 L .943 .665 .483 r
F
.57088 .43139 m .57094 .40911 L .57136 .41165 L F
.57094 .40911 m .57135 .26689 L .57136 .41165 L F
.57071 .43814 m .57074 .43073 L .57088 .43139 L F
.57074 .43073 m .57135 .26689 L .57088 .43139 L F
.57769 .46392 m .57761 .46354 L .57783 .46809 L .98 .687 .341 r
F
.22444 .26337 m .22628 .2572 L .2302 .26121 L .663 .741 .908 r
F
.22444 .26337 m .22052 .25937 L .22628 .2572 L F
.79135 .26337 m .79499 .2572 L .79774 .26121 L F
.79135 .26337 m .78859 .25937 L .79499 .2572 L F
.60238 .26337 m .60542 .2572 L .60856 .26122 L F
.60238 .26337 m .59923 .25937 L .60542 .2572 L F
.13765 .26321 m .13923 .25704 L .14332 .26105 L F
.13765 .26321 m .13356 .25921 L .13923 .25704 L F
.70462 .26321 m .70798 .25704 L .71091 .26105 L F
.70462 .26321 m .70168 .25921 L .70798 .25704 L F
.58484 .31805 m .58142 .30288 L .58691 .26466 L .889 .644 .563 r
F
.58691 .26466 m .58989 .25755 L .59306 .26156 L .695 .733 .88 r
F
.58691 .26466 m .58373 .2603 L .58989 .25755 L F
.58142 .30288 m .58373 .2603 L .58691 .26466 L .872 .641 .585 r
F
.80687 .26304 m .81056 .25687 L .81328 .26088 L .664 .742 .908 r
F
.80687 .26304 m .80414 .25905 L .81056 .25687 L F
.23986 .26305 m .24176 .25688 L .24564 .26089 L .663 .741 .908 r
F
.23986 .26305 m .23597 .25905 L .24176 .25688 L F
.61787 .26306 m .62096 .25687 L .62407 .26088 L .665 .742 .908 r
F
.61787 .26306 m .61475 .25907 L .62096 .25687 L F
.43289 .33541 m .42987 .31561 L .43558 .32332 L .326 .248 .613 r
F
.42696 .33547 m .42987 .31561 L .43289 .33541 L .544 .401 .637 r
F
.42987 .31561 m .43257 .3029 L .43558 .32332 L .227 .149 .555 r
F
.15306 .26289 m .15469 .2567 L .15875 .26071 L .664 .741 .908 r
F
.15306 .26289 m .149 .25888 L .15469 .2567 L F
.72012 .26289 m .72354 .2567 L .72644 .26071 L F
.72012 .26289 m .71722 .25888 L .72354 .2567 L F
.8224 .26271 m .82614 .25653 L .82882 .26054 L .663 .741 .908 r
F
.8224 .26271 m .8197 .2587 L .82614 .25653 L F
.25529 .26272 m .25724 .25654 L .26109 .26055 L .664 .741 .908 r
F
.25529 .26272 m .25143 .25872 L .25724 .25654 L F
.63336 .26273 m .6365 .25653 L .63958 .26055 L F
.63336 .26273 m .63028 .25872 L .6365 .25653 L F
.38629 .37669 m .38276 .37111 L .39002 .33926 L .93 .714 .589 r
F
.38276 .37111 m .38541 .35873 L .39002 .33926 L .232 .158 .563 r
F
.16848 .26254 m .17015 .25636 L .17418 .26037 L .664 .741 .908 r
F
.16848 .26254 m .16444 .25854 L .17015 .25636 L F
.73564 .26255 m .7391 .25636 L .74197 .26037 L F
.73564 .26255 m .73276 .25854 L .7391 .25636 L F
.08166 .26237 m .08306 .25619 L .08726 .26021 L .663 .741 .908 r
F
.08166 .26237 m .07744 .25837 L .08306 .25619 L F
.27072 .26237 m .27272 .2562 L .27654 .26022 L F
.27072 .26237 m .2669 .25837 L .27272 .2562 L F
.64886 .26237 m .65205 .2562 L .65509 .26021 L F
.64886 .26237 m .64581 .25837 L .65205 .2562 L F
.32654 .26477 m .32628 .29688 L .3292 .31418 L .959 .633 .351 r
F
.32654 .26477 m .32287 .26018 L .32628 .29688 L F
.1839 .26221 m .18562 .25603 L .18962 .26004 L .663 .741 .908 r
F
.1839 .26221 m .1799 .2582 L .18562 .25603 L F
.75115 .26221 m .75467 .25603 L .7575 .26004 L F
.75115 .26221 m .74831 .2582 L .75467 .25603 L F
.09706 .26204 m .09851 .25586 L .10269 .25988 L F
.09706 .26204 m .09288 .25803 L .09851 .25586 L F
.66436 .26205 m .66761 .25586 L .67062 .25989 L F
.66436 .26205 m .66134 .25804 L .66761 .25586 L F
.28616 .26207 m .28821 .25587 L .292 .25989 L .664 .742 .908 r
F
.28616 .26207 m .28237 .25806 L .28821 .25587 L F
.76668 .26188 m .77024 .25569 L .77304 .25971 L F
.76668 .26188 m .76387 .25788 L .77024 .25569 L F
.19933 .26188 m .2011 .2557 L .20507 .25971 L .664 .741 .908 r
F
.19933 .26188 m .19535 .25788 L .2011 .2557 L F
.11248 .26171 m .11397 .25552 L .11812 .25954 L F
.11248 .26171 m .10832 .2577 L .11397 .25552 L F
.67987 .26172 m .68317 .25552 L .68615 .25954 L F
.67987 .26172 m .67688 .25771 L .68317 .25552 L F
.30161 .26174 m .3037 .25553 L .30746 .25955 L .665 .742 .907 r
F
.30161 .26174 m .29784 .25773 L .3037 .25553 L F
.21476 .26154 m .21658 .25535 L .22052 .25937 L .664 .741 .908 r
F
.21476 .26154 m .21082 .25753 L .21658 .25535 L F
.7822 .26154 m .78582 .25535 L .78859 .25937 L F
.7822 .26154 m .77942 .25753 L .78582 .25535 L F
.59306 .26156 m .59607 .25536 L .59923 .25937 L .664 .741 .907 r
F
.59306 .26156 m .58989 .25755 L .59607 .25536 L F
.31706 .26137 m .31916 .2558 L .32287 .26018 L .619 .727 .923 r
F
.31706 .26137 m .31333 .25736 L .31916 .2558 L F
.1279 .26137 m .12944 .25519 L .13356 .25921 L .663 .741 .908 r
F
.1279 .26137 m .12377 .25736 L .12944 .25519 L F
.69539 .26137 m .69873 .25519 L .70168 .25921 L F
.69539 .26137 m .69243 .25736 L .69873 .25519 L F
.79774 .26121 m .8014 .25503 L .80414 .25905 L F
.79774 .26121 m .79499 .2572 L .8014 .25503 L F
.2302 .26121 m .23207 .25503 L .23597 .25905 L F
.2302 .26121 m .22628 .2572 L .23207 .25503 L F
.60856 .26122 m .61163 .25505 L .61475 .25907 L .662 .74 .908 r
F
.60856 .26122 m .60542 .2572 L .61163 .25505 L F
.14332 .26105 m .14491 .25486 L .149 .25888 L .664 .741 .908 r
F
.14332 .26105 m .13923 .25704 L .14491 .25486 L F
.48781 .28912 m .48463 .26835 L .49064 .27126 L .476 .349 .628 r
F
.48149 .30931 m .48463 .26835 L .48781 .28912 L .698 .489 .601 r
F
.48149 .30931 m .47841 .2825 L .48463 .26835 L F
.48463 .26835 m .48719 .27193 L .49064 .27126 L .302 0 0 r
F
.47841 .2825 m .48112 .27314 L .48463 .26835 L .423 .378 .703 r
F
.48463 .26835 m .48112 .27314 L .48719 .27193 L .302 0 0 r
F
.71091 .26105 m .7143 .25486 L .71722 .25888 L .664 .741 .908 r
F
.71091 .26105 m .70798 .25704 L .7143 .25486 L F
.43558 .32332 m .43257 .3029 L .43798 .322 L 0 0 .455 r
F
.62407 .26088 m .62718 .25469 L .63028 .25872 L .664 .742 .908 r
F
.62407 .26088 m .62096 .25687 L .62718 .25469 L F
.81328 .26088 m .81699 .25468 L .8197 .2587 L .664 .741 .908 r
F
.81328 .26088 m .81056 .25687 L .81699 .25468 L F
.24564 .26089 m .24756 .2547 L .25143 .25872 L F
.24564 .26089 m .24176 .25688 L .24756 .2547 L F
.15875 .26071 m .16039 .25452 L .16444 .25854 L F
.15875 .26071 m .15469 .2567 L .16039 .25452 L F
.72644 .26071 m .72988 .25451 L .73276 .25854 L F
.72644 .26071 m .72354 .2567 L .72988 .25451 L F
.82882 .26054 m .83259 .25435 L .83526 .25837 L F
.82882 .26054 m .82614 .25653 L .83259 .25435 L F
.63958 .26055 m .64274 .25434 L .64581 .25837 L .664 .742 .908 r
F
.63958 .26055 m .6365 .25653 L .64274 .25434 L F
.26109 .26055 m .26306 .25434 L .2669 .25837 L F
.26109 .26055 m .25724 .25654 L .26306 .25434 L F
.41956 .29704 m .42176 .29928 L .42594 .28292 L 0 0 .143 r
F
.17418 .26037 m .17588 .25418 L .1799 .2582 L .663 .741 .908 r
F
.17418 .26037 m .17015 .25636 L .17588 .25418 L F
.74197 .26037 m .74546 .25418 L .74831 .2582 L F
.74197 .26037 m .7391 .25636 L .74546 .25418 L F
.08726 .26021 m .08868 .25401 L .09288 .25803 L F
.08726 .26021 m .08306 .25619 L .08868 .25401 L F
.65509 .26021 m .65831 .25402 L .66134 .25804 L .664 .741 .908 r
F
.65509 .26021 m .65205 .2562 L .65831 .25402 L F
.27654 .26022 m .27856 .25404 L .28237 .25806 L .663 .741 .908 r
F
.27654 .26022 m .27272 .2562 L .27856 .25404 L F
.7575 .26004 m .76104 .25385 L .76387 .25788 L F
.7575 .26004 m .75467 .25603 L .76104 .25385 L F
.18962 .26004 m .19136 .25385 L .19535 .25788 L F
.18962 .26004 m .18562 .25603 L .19136 .25385 L F
.38017 .38216 m .37764 .3548 L .38276 .37111 L .146 .086 .526 r
F
.37272 .41582 m .37764 .3548 L .38017 .38216 L .855 .617 .579 r
F
.37272 .41582 m .36983 .3958 L .37764 .3548 L F
.37764 .3548 m .38008 .34654 L .38276 .37111 L .009 0 .464 r
F
.10269 .25988 m .10416 .25368 L .10832 .2577 L .664 .741 .908 r
F
.10269 .25988 m .09851 .25586 L .10416 .25368 L F
.67062 .25989 m .67388 .25368 L .67688 .25771 L .663 .741 .908 r
F
.67062 .25989 m .66761 .25586 L .67388 .25368 L F
.292 .25989 m .29406 .25371 L .29784 .25773 L .662 .741 .908 r
F
.292 .25989 m .28821 .25587 L .29406 .25371 L F
.20507 .25971 m .20686 .25351 L .21082 .25753 L .664 .741 .908 r
F
.20507 .25971 m .2011 .2557 L .20686 .25351 L F
.77304 .25971 m .77663 .25351 L .77942 .25753 L F
.77304 .25971 m .77024 .25569 L .77663 .25351 L F
.43289 .33541 m .43558 .32332 L .43911 .32564 L .326 .248 .613 r
F
.11812 .25954 m .11964 .25334 L .12377 .25736 L .664 .741 .908 r
F
.11812 .25954 m .11397 .25552 L .11964 .25334 L F
.68615 .25954 m .68946 .25334 L .69243 .25736 L F
.68615 .25954 m .68317 .25552 L .68946 .25334 L F
.30746 .25955 m .30958 .25334 L .31333 .25736 L F
.30746 .25955 m .3037 .25553 L .30958 .25334 L F
.4569 .28284 m .45301 .29801 L .45897 .30117 L .57 .242 .374 r
F
.22052 .25937 m .22236 .25317 L .22628 .2572 L .663 .741 .908 r
F
.22052 .25937 m .21658 .25535 L .22236 .25317 L F
.78859 .25937 m .79223 .25317 L .79499 .2572 L F
.78859 .25937 m .78582 .25535 L .79223 .25317 L F
.59923 .25937 m .60227 .25317 L .60542 .2572 L F
.59923 .25937 m .59607 .25536 L .60227 .25317 L F
.58142 .30288 m .57803 .28917 L .58373 .2603 L .872 .641 .585 r
F
.58373 .2603 m .58671 .25351 L .58989 .25755 L .681 .733 .89 r
F
.58373 .2603 m .58053 .25601 L .58671 .25351 L F
.57803 .28917 m .58053 .25601 L .58373 .2603 L .854 .641 .613 r
F
.13356 .25921 m .13512 .25301 L .13923 .25704 L .663 .741 .908 r
F
.13356 .25921 m .12944 .25519 L .13512 .25301 L F
.70168 .25921 m .70504 .25301 L .70798 .25704 L F
.70168 .25921 m .69873 .25519 L .70504 .25301 L F
.80414 .25905 m .80783 .25283 L .81056 .25687 L .664 .741 .908 r
F
.80414 .25905 m .8014 .25503 L .80783 .25283 L F
.23597 .25905 m .23786 .25285 L .24176 .25688 L .663 .741 .908 r
F
.23597 .25905 m .23207 .25503 L .23786 .25285 L F
.61475 .25907 m .61784 .25285 L .62096 .25687 L .664 .742 .908 r
F
.61475 .25907 m .61163 .25505 L .61784 .25285 L F
.52835 .31676 m .52502 .32986 L .53013 .27897 L .989 .781 .39 r
F
.52835 .31676 m .53013 .27897 L .53058 .27833 L F
.52502 .32986 m .52781 .26283 L .53112 .26912 L .957 .705 .514 r
F
.52502 .32986 m .52165 .32343 L .52781 .26283 L F
.52541 .28561 m .52738 .32552 L .53077 .33016 L .734 .423 .455 r
F
.5245 .27809 m .52499 .2862 L .52541 .28561 L F
.52499 .2862 m .52738 .32552 L .52541 .28561 L F
.53058 .27833 m .53013 .27897 L .53112 .26912 L .989 .781 .39 r
F
.53112 .26912 m .5341 .31773 L .53735 .29692 L .967 .642 .304 r
F
.53112 .26912 m .52781 .26283 L .5341 .31773 L F
.71722 .25888 m .72063 .25267 L .72354 .2567 L .664 .741 .908 r
F
.71722 .25888 m .7143 .25486 L .72063 .25267 L F
.149 .25888 m .15061 .25267 L .15469 .2567 L F
.149 .25888 m .14491 .25486 L .15061 .25267 L F
.8197 .2587 m .82344 .2525 L .82614 .25653 L F
.8197 .2587 m .81699 .25468 L .82344 .2525 L F
.25143 .25872 m .25337 .25251 L .25724 .25654 L F
.25143 .25872 m .24756 .2547 L .25337 .25251 L F
.63028 .25872 m .63342 .2525 L .6365 .25653 L F
.63028 .25872 m .62718 .25469 L .63342 .2525 L F
.32287 .26018 m .32318 .28242 L .32628 .29688 L .952 .604 .297 r
F
.32287 .26018 m .31916 .2558 L .32318 .28242 L F
.16444 .25854 m .16611 .25233 L .17015 .25636 L .664 .741 .908 r
F
.16444 .25854 m .16039 .25452 L .16611 .25233 L F
.73276 .25854 m .73623 .25233 L .7391 .25636 L F
.73276 .25854 m .72988 .25451 L .73623 .25233 L F
.51891 .28211 m .51561 .27071 L .52165 .32343 L .96 .646 .24 r
F
.50934 .30868 m .51223 .27839 L .51561 .27071 L .987 .813 .421 r
F
.51561 .27071 m .51223 .27839 L .51647 .2921 L .834 .474 .374 r
F
.50388 .31216 m .50043 .31953 L .50657 .31601 L .23 0 .096 r
F
.50749 .30798 m .50875 .29708 L .51162 .28167 L .718 .557 .67 r
F
.50749 .30798 m .51162 .28167 L .51169 .28174 L F
.50657 .31601 m .50402 .31718 L .5074 .31178 L .904 .982 .722 r
F
.50735 .31393 m .5074 .31178 L .50934 .30868 L F
.50657 .31601 m .5074 .31178 L .50735 .31393 L F
.50402 .31718 m .50403 .31631 L .50934 .30868 L F
.50333 .31787 m .50402 .31718 L .50657 .31601 L .017 .147 .658 r
F
.50402 .31718 m .50315 .31758 L .50403 .31631 L .904 .982 .722 r
F
.50114 .31913 m .50315 .31758 L .50402 .31718 L .017 .147 .658 r
F
.50114 .31913 m .50402 .31718 L .50333 .31787 L F
.50315 .31758 m .50588 .31799 L .50934 .30868 L 0 0 .479 r
F
.50934 .30868 m .50588 .31799 L .51169 .28174 L .987 .813 .421 r
F
.51183 .28253 m .51169 .28174 L .51223 .27839 L F
.50934 .30868 m .51169 .28174 L .51183 .28253 L F
.51169 .28174 m .51162 .28167 L .51223 .27839 L .718 .557 .67 r
F
.51775 .2924 m .51647 .2921 L .51831 .29803 L .834 .474 .374 r
F
.51561 .27071 m .51647 .2921 L .51775 .2924 L F
.51223 .27839 m .51502 .26849 L .51831 .29803 L 0 0 0 r
F
.51223 .27839 m .50875 .29708 L .51502 .26849 L F
.51017 .2906 m .51171 .25351 L .51502 .26849 L .99 .788 .402 r
F
.50921 .29037 m .51171 .25351 L .51017 .2906 L F
.51043 .28054 m .51092 .28802 L .51427 .3135 L .54 .244 .414 r
F
.50588 .31799 m .50254 .30491 L .50562 .30102 L .718 .557 .67 r
F
.50746 .30648 m .50562 .30102 L .50875 .29708 L F
.50588 .31799 m .50562 .30102 L .50746 .30648 L F
.49664 .27719 m .49933 .2768 L .50172 .29776 L 0 0 .549 r
F
.50136 .29937 m .50172 .29776 L .50254 .30491 L F
.49664 .27719 m .50172 .29776 L .50136 .29937 L F
.50254 .30491 m .50525 .30921 L .50875 .29708 L 0 0 .354 r
F
.50254 .30491 m .50172 .29776 L .50434 .30624 L F
.50172 .29776 m .49933 .2768 L .50255 .29443 L F
.50172 .29776 m .50255 .29443 L .50525 .30921 L F
.50431 .30771 m .50434 .30624 L .50525 .30921 L F
.50254 .30491 m .50434 .30624 L .50431 .30771 L F
.50255 .29443 m .50185 .30092 L .50525 .30921 L .795 .556 0 r
F
.50154 .2889 m .50185 .30092 L .50255 .29443 L F
.50525 .30921 m .50185 .30092 L .50751 .26666 L .933 .697 .557 r
F
.50804 .26572 m .50751 .26666 L .50828 .26203 L F
.50525 .30921 m .50751 .26666 L .50804 .26572 L F
.50185 .30092 m .50471 .28594 L .50477 .28553 L .305 .209 .579 r
F
.50429 .28745 m .50477 .28553 L .50539 .28136 L F
.50185 .30092 m .50477 .28553 L .50429 .28745 L F
.50422 .28658 m .50539 .28136 L .50828 .26203 L F
.50185 .30092 m .50539 .28136 L .50422 .28658 L F
.49933 .2768 m .50017 .28483 L .50154 .2889 L .795 .556 0 r
F
.50017 .28483 m .50185 .30092 L .50154 .2889 L F
.49986 .30087 m .50254 .30491 L .50411 .31104 L 0 0 .364 r
F
.49986 .30087 m .50411 .31104 L .50409 .31244 L F
.49986 .30087 m .49664 .27719 L .50254 .30491 L F
.49664 .27719 m .49334 .26469 L .4987 .27553 L 0 0 .549 r
F
.49886 .27686 m .4987 .27553 L .49933 .2768 L F
.49664 .27719 m .4987 .27553 L .49886 .27686 L F
.49334 .26469 m .4961 .25461 L .49933 .2768 L .852 .863 .413 r
F
.49772 .26769 m .4986 .27479 L .50185 .30092 L .911 .521 .257 r
F
.4961 .25461 m .49726 .26401 L .49772 .26769 L F
.49726 .26401 m .4986 .27479 L .49772 .26769 L F
.49933 .2768 m .49808 .26828 L .50185 .30092 L .795 .556 0 r
F
.49808 .26828 m .4961 .25461 L .49773 .26777 L F
.49808 .26828 m .49773 .26777 L .50185 .30092 L F
.49064 .27126 m .48719 .27193 L .49334 .26469 L .884 .99 .798 r
F
.49115 .26727 m .48982 .2716 L .49334 .26469 L 0 0 .056 r
F
.48971 .26896 m .48982 .2716 L .49115 .26727 L F
.48924 .27167 m .48982 .2716 L .48971 .26896 L F
.48719 .27193 m .48356 .28496 L .48982 .2716 L F
.48356 .28496 m .48615 .28798 L .48982 .2716 L .124 0 .062 r
F
.48982 .2716 m .48849 .27598 L .49266 .25455 L .797 .743 .22 r
F
.48849 .27598 m .48898 .27383 L .49266 .25455 L .955 .887 .493 r
F
.48982 .2716 m .48615 .28798 L .48849 .27598 L .797 .743 .22 r
F
.48615 .28798 m .48807 .2784 L .48849 .27598 L .955 .887 .493 r
F
.48807 .2784 m .48898 .27383 L .48849 .27598 L F
.48719 .27193 m .48924 .27167 L .48971 .26896 L 0 0 .056 r
F
.49334 .26469 m .49107 .26916 L .4961 .25461 L .852 .863 .413 r
F
.49107 .26916 m .48982 .2716 L .49177 .26635 L F
.49107 .26916 m .49177 .26635 L .4961 .25461 L F
.49266 .25455 m .49538 .24893 L .49562 .25082 L 0 0 .025 r
F
.48982 .2716 m .49266 .25455 L .4961 .25461 L .797 .743 .22 r
F
.4961 .25461 m .49609 .25461 L .4986 .27479 L .911 .521 .257 r
F
.49469 .25459 m .49266 .25455 L .49376 .25831 L F
.49376 .25831 m .49562 .25082 L .4986 .27479 L 0 0 .025 r
F
.49266 .25455 m .49562 .25082 L .49376 .25831 L F
.4986 .27479 m .49731 .26441 L .50096 .30274 L .808 .576 .016 r
F
.4986 .27479 m .50096 .30274 L .501 .30302 L F
.49731 .26441 m .49695 .26401 L .5011 .30423 L F
.50185 .30092 m .4986 .27479 L .50471 .28594 L .305 .209 .579 r
F
.4986 .27479 m .49918 .28157 L .50076 .27874 L .808 .576 .016 r
F
.49918 .28157 m .5011 .30423 L .50076 .27874 L F
.49778 .31615 m .50043 .31953 L .50388 .31216 L .053 0 .18 r
F
.49986 .30087 m .50534 .31587 L .50519 .31602 L 0 0 .364 r
F
.50315 .31758 m .49986 .30087 L .50519 .31602 L 0 0 .479 r
F
.4971 .30952 m .49389 .28775 L .49986 .30087 L .182 .139 .571 r
F
.49389 .28775 m .49664 .27719 L .49986 .30087 L .354 .29 .646 r
F
.4971 .30952 m .49986 .30087 L .50315 .31758 L .182 .139 .571 r
F
.49538 .24893 m .49764 .29861 L .5011 .30423 L .968 .647 .311 r
F
.49882 .28746 m .50092 .23311 L .50435 .23498 L .811 .567 .569 r
F
.49764 .29861 m .49837 .28422 L .49882 .28746 L F
.49837 .28422 m .50092 .23311 L .49882 .28746 L F
.501 .30302 m .50096 .30274 L .5011 .30423 L .808 .576 .016 r
F
.49731 .26441 m .49538 .24893 L .49695 .26401 L F
.49389 .28775 m .49064 .27126 L .49664 .27719 L .354 .29 .646 r
F
.49064 .27126 m .49334 .26469 L .49664 .27719 L .884 .99 .798 r
F
.49266 .25455 m .48898 .27383 L .49372 .2554 L 0 0 .025 r
F
.49367 .25246 m .49372 .2554 L .49538 .24893 L F
.49266 .25455 m .49372 .2554 L .49367 .25246 L F
.4938 .26011 m .4944 .27012 L .49764 .29861 L .705 .369 .406 r
F
.48898 .27383 m .492 .24207 L .49538 .24893 L .931 .783 .312 r
F
.492 .24207 m .49386 .26383 L .4938 .26011 L .705 .369 .406 r
F
.49386 .26383 m .4944 .27012 L .4938 .26011 L F
.49538 .24893 m .492 .24207 L .49764 .29861 L .968 .647 .311 r
F
.49571 .26268 m .49732 .24936 L .50092 .23311 L .352 .227 .568 r
F
.4954 .26444 m .49563 .26259 L .49571 .26268 L F
.49563 .26259 m .49732 .24936 L .49571 .26268 L F
.4944 .27012 m .49523 .26419 L .4954 .26444 L F
.49523 .26419 m .49732 .24936 L .4954 .26444 L F
.50076 .27874 m .5011 .30423 L .50471 .28594 L .808 .576 .016 r
F
.50471 .28594 m .5011 .30423 L .50499 .27586 L .904 .771 .281 r
F
.50479 .28515 m .50499 .27586 L .50765 .2564 L F
.50471 .28594 m .50499 .27586 L .50479 .28515 L F
.50875 .29708 m .50525 .30921 L .50969 .27093 L .99 .788 .402 r
F
.51028 .27449 m .50969 .27093 L .51171 .25351 L F
.50875 .29708 m .50969 .27093 L .51028 .27449 L F
.50525 .30921 m .50828 .26203 L .51171 .25351 L .933 .697 .557 r
F
.50846 .26355 m .51013 .28025 L .51043 .28054 L .54 .244 .414 r
F
.50828 .26203 m .5084 .26321 L .50846 .26355 L F
.5084 .26321 m .51013 .28025 L .50846 .26355 L F
.51013 .28025 m .51092 .28802 L .51043 .28054 L F
.50588 .31799 m .50753 .30597 L .50749 .30798 L .718 .557 .67 r
F
.50753 .30597 m .50875 .29708 L .50749 .30798 L F
.50409 .31244 m .50411 .31104 L .50534 .31587 L 0 0 .364 r
F
.50519 .31602 m .50534 .31587 L .50588 .31799 L F
.50043 .31953 m .50315 .31758 L .50114 .31913 L .017 .147 .658 r
F
.50315 .31758 m .50519 .31602 L .50588 .31799 L 0 0 .479 r
F
.50875 .29708 m .50921 .29037 L .51017 .2906 L .99 .788 .402 r
F
.47899 .30439 m .48149 .30931 L .48476 .32444 L .119 0 .208 r
F
.47899 .30439 m .47529 .3189 L .48149 .30931 L F
.2669 .25837 m .26889 .25217 L .27272 .2562 L .663 .741 .908 r
F
.2669 .25837 m .26306 .25434 L .26889 .25217 L F
.64581 .25837 m .649 .25217 L .65205 .2562 L F
.64581 .25837 m .64274 .25434 L .649 .25217 L F
.1799 .2582 m .18161 .252 L .18562 .25603 L F
.1799 .2582 m .17588 .25418 L .18161 .252 L F
.74831 .2582 m .75183 .252 L .75467 .25603 L F
.74831 .2582 m .74546 .25418 L .75183 .252 L F
.09288 .25803 m .09432 .25183 L .09851 .25586 L F
.09288 .25803 m .08868 .25401 L .09432 .25183 L F
.66134 .25804 m .66458 .25183 L .66761 .25586 L .664 .741 .908 r
F
.66134 .25804 m .65831 .25402 L .66458 .25183 L F
.28237 .25806 m .28441 .25184 L .28821 .25587 L .665 .742 .908 r
F
.28237 .25806 m .27856 .25404 L .28441 .25184 L F
.76387 .25788 m .76743 .25166 L .77024 .25569 L .664 .742 .908 r
F
.76387 .25788 m .76104 .25385 L .76743 .25166 L F
.19535 .25788 m .19712 .25166 L .2011 .2557 L .664 .741 .908 r
F
.19535 .25788 m .19136 .25385 L .19712 .25166 L F
.10832 .2577 m .10981 .25149 L .11397 .25552 L F
.10832 .2577 m .10416 .25368 L .10981 .25149 L F
.67688 .25771 m .68017 .25149 L .68317 .25552 L F
.67688 .25771 m .67388 .25368 L .68017 .25149 L F
.29784 .25773 m .29993 .2515 L .3037 .25553 L .665 .742 .907 r
F
.29784 .25773 m .29406 .25371 L .29993 .2515 L F
.77942 .25753 m .78304 .25132 L .78582 .25535 L .663 .741 .908 r
F
.77942 .25753 m .77663 .25351 L .78304 .25132 L F
.21082 .25753 m .21263 .25132 L .21658 .25535 L .664 .741 .908 r
F
.21082 .25753 m .20686 .25351 L .21263 .25132 L F
.58989 .25755 m .5929 .25132 L .59607 .25536 L F
.58989 .25755 m .58671 .25351 L .5929 .25132 L F
.12377 .25736 m .12531 .25115 L .12944 .25519 L .663 .741 .908 r
F
.12377 .25736 m .11964 .25334 L .12531 .25115 L F
.69243 .25736 m .69577 .25115 L .69873 .25519 L F
.69243 .25736 m .68946 .25334 L .69577 .25115 L F
.31333 .25736 m .31544 .25151 L .31916 .2558 L .639 .734 .917 r
F
.31333 .25736 m .30958 .25334 L .31544 .25151 L F
.79499 .2572 m .79865 .25099 L .8014 .25503 L .663 .741 .908 r
F
.79499 .2572 m .79223 .25317 L .79865 .25099 L F
.22628 .2572 m .22815 .25099 L .23207 .25503 L F
.22628 .2572 m .22236 .25317 L .22815 .25099 L F
.60542 .2572 m .60849 .25101 L .61163 .25505 L .662 .741 .908 r
F
.60542 .2572 m .60227 .25317 L .60849 .25101 L F
.13923 .25704 m .14081 .25082 L .14491 .25486 L .664 .741 .908 r
F
.13923 .25704 m .13512 .25301 L .14081 .25082 L F
.70798 .25704 m .71137 .25082 L .7143 .25486 L F
.70798 .25704 m .70504 .25301 L .71137 .25082 L F
.49778 .31615 m .49424 .33024 L .50043 .31953 L .053 0 .18 r
F
.47841 .2825 m .47513 .27021 L .48112 .27314 L .423 .378 .703 r
F
.47191 .31139 m .47513 .27021 L .47841 .2825 L .71 .499 .601 r
F
.47191 .31139 m .46885 .28538 L .47513 .27021 L F
.47529 .3189 m .47841 .2825 L .48149 .30931 L .919 .7 .59 r
F
.47529 .3189 m .47191 .31139 L .47841 .2825 L F
.47513 .27021 m .47735 .29272 L .48112 .27314 L .711 .363 .385 r
F
.47513 .27021 m .47144 .28209 L .47735 .29272 L F
.46885 .28538 m .47144 .28209 L .47513 .27021 L 0 .012 .525 r
F
.81056 .25687 m .81428 .25065 L .81699 .25468 L .663 .741 .908 r
F
.81056 .25687 m .80783 .25283 L .81428 .25065 L F
.62096 .25687 m .62407 .25065 L .62718 .25469 L .665 .742 .908 r
F
.62096 .25687 m .61784 .25285 L .62407 .25065 L F
.24176 .25688 m .24367 .25066 L .24756 .2547 L .664 .741 .908 r
F
.24176 .25688 m .23786 .25285 L .24367 .25066 L F
.72354 .2567 m .72698 .25048 L .72988 .25451 L F
.72354 .2567 m .72063 .25267 L .72698 .25048 L F
.15469 .2567 m .15632 .25048 L .16039 .25452 L F
.15469 .2567 m .15061 .25267 L .15632 .25048 L F
.42855 .27314 m .42758 .27638 L .43113 .26446 L .681 .721 .205 r
F
.42758 .27638 m .42846 .27337 L .43113 .26446 L F
.42447 .28674 m .42762 .26029 L .43113 .26446 L .947 .81 .361 r
F
.43113 .26446 m .42762 .26029 L .43134 .27702 L .94 .571 .221 r
F
.43242 .27884 m .43134 .27702 L .43288 .28398 L F
.43113 .26446 m .43134 .27702 L .43242 .27884 L F
.42762 .26029 m .42991 .26127 L .43056 .26627 L 0 0 .136 r
F
.42762 .26029 m .43056 .26627 L .42964 .26939 L F
.41956 .29704 m .41522 .31602 L .42176 .29928 L 0 0 .143 r
F
.42176 .29928 m .42174 .29932 L .42447 .28674 L .914 .872 .44 r
F
.41351 .30082 m .41522 .31602 L .41956 .29704 L .475 .158 .347 r
F
.41465 .29111 m .41684 .29349 L .41873 .29843 L 0 0 .331 r
F
.42174 .29932 m .41953 .30386 L .4223 .29346 L .914 .872 .44 r
F
.41953 .30386 m .41934 .30261 L .4223 .29346 L F
.4178 .30741 m .41465 .29111 L .41952 .30095 L .059 .086 .574 r
F
.41608 .31382 m .4178 .30741 L .42174 .29932 L .696 .683 .834 r
F
.41953 .30386 m .4178 .30741 L .41934 .30261 L .914 .872 .44 r
F
.42174 .29932 m .4223 .29346 L .42447 .28674 L F
.4178 .30741 m .42026 .30243 L .42447 .28674 L .059 .086 .574 r
F
.4178 .30741 m .41952 .30095 L .42026 .30243 L F
.41522 .31602 m .4178 .30741 L .41608 .31382 L .696 .683 .834 r
F
.42174 .29933 m .42174 .29932 L .42176 .29928 L F
.41522 .31602 m .42174 .29932 L .42174 .29933 L F
.42132 .29635 m .4234 .28183 L .42286 .28754 L .807 .649 .686 r
F
.42026 .30243 m .42126 .29589 L .42132 .29635 L F
.42126 .29589 m .4234 .28183 L .42132 .29635 L F
.41892 .29973 m .41873 .29843 L .42026 .30243 L 0 0 .331 r
F
.41465 .29111 m .41873 .29843 L .41892 .29973 L F
.42026 .30243 m .42322 .28276 L .4234 .28183 L .807 .649 .686 r
F
.42286 .28754 m .4234 .28183 L .42762 .26029 L F
.42447 .28674 m .42026 .30243 L .42762 .26029 L .947 .81 .361 r
F
.42762 .26029 m .42322 .28276 L .4288 .26482 L 0 0 .136 r
F
.4285 .26067 m .4288 .26482 L .42991 .26127 L F
.42762 .26029 m .4288 .26482 L .4285 .26067 L F
.42718 .27004 m .42653 .25178 L .42991 .26127 L .977 .814 .403 r
F
.42653 .25178 m .42835 .26822 L .42959 .27585 L .574 .228 .345 r
F
.42929 .27169 m .42959 .27585 L .43147 .28736 L F
.42653 .25178 m .42959 .27585 L .42929 .27169 L F
.42322 .28276 m .42497 .26635 L .42718 .27004 L .977 .814 .403 r
F
.42497 .26635 m .42653 .25178 L .42718 .27004 L F
.42964 .26939 m .43056 .26627 L .43288 .28398 L 0 0 .136 r
F
.42758 .27638 m .42447 .28674 L .42846 .27337 L .681 .721 .205 r
F
.42176 .29928 m .42447 .28674 L .42855 .27314 L .914 .872 .44 r
F
.38084 .40498 m .38335 .39581 L .38731 .39123 L .742 .765 .261 r
F
.44738 .28272 m .44406 .27298 L .44923 .30593 L .941 .612 .177 r
F
.82614 .25653 m .8299 .25031 L .83259 .25435 L .664 .741 .908 r
F
.82614 .25653 m .82344 .2525 L .8299 .25031 L F
.6365 .25653 m .63967 .25031 L .64274 .25434 L F
.6365 .25653 m .63342 .2525 L .63967 .25031 L F
.25724 .25654 m .2592 .25031 L .26306 .25434 L .664 .742 .908 r
F
.25724 .25654 m .25337 .25251 L .2592 .25031 L F
.7391 .25636 m .74259 .25014 L .74546 .25418 L .663 .741 .908 r
F
.7391 .25636 m .73623 .25233 L .74259 .25014 L F
.17015 .25636 m .17184 .25014 L .17588 .25418 L F
.17015 .25636 m .16611 .25233 L .17184 .25014 L F
.52781 .26283 m .53077 .33016 L .5341 .31773 L .882 .561 .437 r
F
.52781 .26283 m .5245 .27809 L .53077 .33016 L F
.41351 .30082 m .40924 .31674 L .41522 .31602 L .475 .158 .347 r
F
.44089 .30238 m .43702 .3117 L .44353 .27587 L .994 .822 .454 r
F
.44089 .30238 m .44353 .27587 L .44369 .27643 L F
.44369 .27643 m .44353 .27587 L .44406 .27298 L F
.44406 .27298 m .44021 .2822 L .44603 .28967 L .685 .316 .341 r
F
.44021 .2822 m .44305 .26537 L .44603 .28967 L .92 .837 .384 r
F
.43702 .3117 m .43392 .29282 L .43705 .28753 L .708 .518 .629 r
F
.43893 .29401 m .43705 .28753 L .44021 .2822 L F
.43702 .3117 m .43705 .28753 L .43893 .29401 L F
.43392 .29282 m .43628 .29298 L .44021 .2822 L 0 0 .376 r
F
.43392 .29282 m .43262 .27967 L .43628 .29298 L F
.43262 .27967 m .43113 .26446 L .4336 .27817 L F
.43262 .27967 m .4336 .27817 L .43628 .29298 L F
.43239 .27144 m .43288 .28398 L .43628 .29298 L .94 .571 .221 r
F
.43628 .29298 m .43288 .28398 L .43805 .2666 L .886 .678 .617 r
F
.43903 .26649 m .43805 .2666 L .43954 .26157 L F
.43628 .29298 m .43805 .2666 L .43903 .26649 L F
.43288 .28398 m .4354 .27891 L .43671 .27344 L 0 0 .497 r
F
.43288 .28398 m .43671 .27344 L .43544 .27537 L F
.43113 .26446 m .43147 .26828 L .43239 .27144 L .94 .571 .221 r
F
.43147 .26828 m .43288 .28398 L .43239 .27144 L F
.43288 .28398 m .42991 .26127 L .4354 .27891 L 0 0 .497 r
F
.43178 .26728 m .43147 .28736 L .4354 .27891 L .952 .625 .213 r
F
.42991 .26127 m .43027 .26744 L .43178 .26728 L F
.43027 .26744 m .43147 .28736 L .43178 .26728 L F
.43544 .27537 m .43671 .27344 L .43954 .26157 L 0 0 .497 r
F
.44021 .2822 m .43628 .29298 L .4416 .27131 L .92 .837 .384 r
F
.44194 .27196 m .4416 .27131 L .44305 .26537 L F
.44021 .2822 m .4416 .27131 L .44194 .27196 L F
.43628 .29298 m .43954 .26157 L .44305 .26537 L .886 .678 .617 r
F
.44071 .26963 m .44146 .27921 L .44465 .29672 L .501 .185 .363 r
F
.43955 .26162 m .44034 .26893 L .44071 .26963 L F
.44034 .26893 m .44146 .27921 L .44071 .26963 L F
.43954 .26157 m .43954 .26161 L .43955 .26162 L F
.43954 .26161 m .44146 .27921 L .43955 .26162 L F
.65205 .2562 m .65526 .24998 L .65831 .25402 L .663 .741 .908 r
F
.65205 .2562 m .649 .25217 L .65526 .24998 L F
.27272 .2562 m .27473 .25 L .27856 .25404 L .662 .741 .908 r
F
.27272 .2562 m .26889 .25217 L .27473 .25 L F
.18562 .25603 m .18736 .24981 L .19136 .25385 L .663 .741 .908 r
F
.18562 .25603 m .18161 .252 L .18736 .24981 L F
.75467 .25603 m .75821 .24981 L .76104 .25385 L F
.75467 .25603 m .75183 .252 L .75821 .24981 L F
.46885 .28538 m .46569 .26696 L .47144 .28209 L 0 .012 .525 r
F
.46213 .3207 m .46569 .26696 L .46885 .28538 L .845 .608 .58 r
F
.46213 .3207 m .45897 .30117 L .46569 .26696 L F
.46592 .30807 m .46885 .28538 L .47191 .31139 L .94 .817 .366 r
F
.46592 .30807 m .46213 .3207 L .46885 .28538 L F
.46569 .26696 m .4676 .29924 L .47144 .28209 L .878 .528 .383 r
F
.46569 .26696 m .46204 .27302 L .4676 .29924 L F
.66761 .25586 m .67087 .24964 L .67388 .25368 L .663 .741 .908 r
F
.66761 .25586 m .66458 .25183 L .67087 .24964 L F
.09851 .25586 m .09997 .24963 L .10416 .25368 L .664 .741 .908 r
F
.09851 .25586 m .09432 .25183 L .09997 .24963 L F
.28821 .25587 m .29027 .24967 L .29406 .25371 L .662 .741 .908 r
F
.28821 .25587 m .28441 .25184 L .29027 .24967 L F
.77024 .25569 m .77383 .24946 L .77663 .25351 L .664 .741 .908 r
F
.77024 .25569 m .76743 .25166 L .77383 .24946 L F
.2011 .2557 m .20288 .24947 L .20686 .25351 L F
.2011 .2557 m .19712 .25166 L .20288 .24947 L F
.48781 .28912 m .49064 .27126 L .49389 .28775 L .476 .349 .628 r
F
.11397 .25552 m .11548 .24929 L .11964 .25334 L .664 .741 .908 r
F
.11397 .25552 m .10981 .25149 L .11548 .24929 L F
.68317 .25552 m .68648 .24929 L .68946 .25334 L F
.68317 .25552 m .68017 .25149 L .68648 .24929 L F
.3037 .25553 m .30581 .2493 L .30958 .25334 L F
.3037 .25553 m .29993 .2515 L .30581 .2493 L F
.57803 .28917 m .57467 .27714 L .58053 .25601 L .854 .641 .613 r
F
.58053 .25601 m .58351 .24947 L .58671 .25351 L .672 .735 .897 r
F
.58053 .25601 m .57733 .25181 L .58351 .24947 L F
.57467 .27714 m .57733 .25181 L .58053 .25601 L .835 .646 .646 r
F
.54055 .27938 m .54383 .34285 L .54701 .32288 L .859 .538 .444 r
F
.54055 .27938 m .53735 .29692 L .54383 .34285 L F
.21658 .25535 m .21841 .24913 L .22236 .25317 L .663 .741 .908 r
F
.21658 .25535 m .21263 .25132 L .21841 .24913 L F
.78582 .25535 m .78946 .24913 L .79223 .25317 L F
.78582 .25535 m .78304 .25132 L .78946 .24913 L F
.59607 .25536 m .59911 .24913 L .60227 .25317 L F
.59607 .25536 m .5929 .25132 L .59911 .24913 L F
.12944 .25519 m .131 .24896 L .13512 .25301 L F
.12944 .25519 m .12531 .25115 L .131 .24896 L F
.69873 .25519 m .70209 .24896 L .70504 .25301 L F
.69873 .25519 m .69577 .25115 L .70209 .24896 L F
.8014 .25503 m .80509 .24879 L .80783 .25283 L .664 .741 .908 r
F
.8014 .25503 m .79865 .25099 L .80509 .24879 L F
.23207 .25503 m .23395 .2488 L .23786 .25285 L .663 .741 .908 r
F
.23207 .25503 m .22815 .25099 L .23395 .2488 L F
.61163 .25505 m .61471 .24882 L .61784 .25285 L F
.61163 .25505 m .60849 .25101 L .61471 .24882 L F
.14491 .25486 m .14652 .24862 L .15061 .25267 L .664 .741 .908 r
F
.14491 .25486 m .14081 .25082 L .14652 .24862 L F
.7143 .25486 m .71771 .24862 L .72063 .25267 L F
.7143 .25486 m .71137 .25082 L .71771 .24862 L F
.31916 .2558 m .31998 .26984 L .32318 .28242 L .931 .549 .2 r
F
.31916 .2558 m .31544 .25151 L .31998 .26984 L F
.81699 .25468 m .82073 .24845 L .82344 .2525 L .664 .742 .908 r
F
.81699 .25468 m .81428 .25065 L .82073 .24845 L F
.62718 .25469 m .63032 .24846 L .63342 .2525 L .664 .741 .908 r
F
.62718 .25469 m .62407 .25065 L .63032 .24846 L F
.24756 .2547 m .24949 .24846 L .25337 .25251 L F
.24756 .2547 m .24367 .25066 L .24949 .24846 L F
.72988 .25451 m .73334 .24828 L .73623 .25233 L F
.72988 .25451 m .72698 .25048 L .73334 .24828 L F
.16039 .25452 m .16205 .24828 L .16611 .25233 L F
.16039 .25452 m .15632 .25048 L .16205 .24828 L F
.49092 .31864 m .48781 .28912 L .49389 .28775 L .557 .381 .599 r
F
.48832 .31547 m .49092 .31864 L .49424 .33024 L .125 0 .1 r
F
.48832 .31547 m .48476 .32444 L .49092 .31864 L F
.48476 .32444 m .48781 .28912 L .49092 .31864 L .816 .604 .615 r
F
.48476 .32444 m .48149 .30931 L .48781 .28912 L F
.64274 .25434 m .64593 .24812 L .649 .25217 L .663 .741 .908 r
F
.64274 .25434 m .63967 .25031 L .64593 .24812 L F
.26306 .25434 m .26503 .24812 L .26889 .25217 L F
.26306 .25434 m .2592 .25031 L .26503 .24812 L F
.17588 .25418 m .17758 .24795 L .18161 .252 L F
.17588 .25418 m .17184 .25014 L .17758 .24795 L F
.74546 .25418 m .74897 .24795 L .75183 .252 L F
.74546 .25418 m .74259 .25014 L .74897 .24795 L F
.65831 .25402 m .66155 .24778 L .66458 .25183 L .664 .742 .908 r
F
.65831 .25402 m .65526 .24998 L .66155 .24778 L F
.27856 .25404 m .28059 .24779 L .28441 .25184 L .665 .742 .907 r
F
.27856 .25404 m .27473 .25 L .28059 .24779 L F
.19136 .25385 m .19312 .24762 L .19712 .25166 L .664 .741 .908 r
F
.19136 .25385 m .18736 .24981 L .19312 .24762 L F
.76104 .25385 m .7646 .24761 L .76743 .25166 L .664 .742 .908 r
F
.76104 .25385 m .75821 .24981 L .7646 .24761 L F
.10416 .25368 m .10563 .24744 L .10981 .25149 L .664 .741 .908 r
F
.10416 .25368 m .09997 .24963 L .10563 .24744 L F
.67388 .25368 m .67717 .24744 L .68017 .25149 L F
.67388 .25368 m .67087 .24964 L .67717 .24744 L F
.29406 .25371 m .29614 .24745 L .29993 .2515 L .665 .742 .907 r
F
.29406 .25371 m .29027 .24967 L .29614 .24745 L F
.40298 .2853 m .40011 .26363 L .4062 .25865 L .621 .446 .624 r
F
.39619 .30668 m .40011 .26363 L .40298 .2853 L .66 .452 .592 r
F
.39619 .30668 m .39373 .27534 L .40011 .26363 L F
.40011 .26363 m .40218 .26608 L .4062 .25865 L .204 0 0 r
F
.39373 .27534 m .3962 .26755 L .40011 .26363 L .255 .239 .648 r
F
.40011 .26363 m .3962 .26755 L .40218 .26608 L .204 0 0 r
F
.77663 .25351 m .78025 .24727 L .78304 .25132 L .663 .741 .908 r
F
.77663 .25351 m .77383 .24946 L .78025 .24727 L F
.20686 .25351 m .20866 .24727 L .21263 .25132 L .664 .741 .908 r
F
.20686 .25351 m .20288 .24947 L .20866 .24727 L F
.58671 .25351 m .58972 .24727 L .5929 .25132 L F
.58671 .25351 m .58351 .24947 L .58972 .24727 L F
.11964 .25334 m .12116 .2471 L .12531 .25115 L .663 .741 .908 r
F
.11964 .25334 m .11548 .24929 L .12116 .2471 L F
.68946 .25334 m .6928 .2471 L .69577 .25115 L F
.68946 .25334 m .68648 .24929 L .6928 .2471 L F
.30958 .25334 m .31169 .24728 L .31544 .25151 L .652 .738 .913 r
F
.30958 .25334 m .30581 .2493 L .31169 .24728 L F
.40906 .28125 m .4062 .25865 L .41188 .26513 L .38 .271 .603 r
F
.40298 .2853 m .4062 .25865 L .40906 .28125 L .621 .446 .624 r
F
.40706 .25963 m .40845 .25741 L .41188 .26513 L 0 0 0 r
F
.41188 .26513 m .40896 .25857 L .41409 .26594 L 0 0 .554 r
F
.40896 .25857 m .40845 .25741 L .40903 .25829 L F
.40896 .25857 m .40903 .25829 L .41409 .26594 L F
.40903 .25829 m .41088 .25191 L .41409 .26594 L 0 0 0 r
F
.40845 .25741 m .41088 .25191 L .40903 .25829 L F
.40984 .25519 m .40985 .25518 L .41088 .25191 L F
.40845 .25741 m .40984 .25519 L .41088 .25191 L F
.41088 .25191 m .40963 .25589 L .41236 .24677 L .698 .736 .224 r
F
.41088 .25191 m .41236 .24677 L .41344 .24318 L F
.40845 .25741 m .40408 .2735 L .40985 .25518 L 0 0 0 r
F
.4099 .255 m .40661 .26554 L .41088 .25191 L F
.40408 .2735 m .40661 .26554 L .4099 .255 L F
.39974 .28757 m .40217 .28219 L .40661 .26554 L .134 .174 .638 r
F
.40661 .26554 m .40217 .28219 L .40327 .27624 L .93 .808 .346 r
F
.4062 .25865 m .40845 .25741 L .40706 .25963 L 0 0 0 r
F
.4062 .25865 m .40218 .26608 L .40845 .25741 L F
.40218 .26608 m .40408 .2735 L .40845 .25741 L .038 0 .237 r
F
.40218 .26608 m .3974 .29094 L .40408 .2735 L F
.40408 .2735 m .4027 .27799 L .40661 .26554 L 0 0 0 r
F
.4027 .27799 m .40012 .28635 L .4029 .27743 L F
.40012 .28635 m .40024 .28596 L .4029 .27743 L F
.3962 .26755 m .3974 .29094 L .40218 .26608 L .538 .232 .397 r
F
.39389 .31009 m .39619 .30668 L .39924 .32444 L 0 0 0 r
F
.39389 .31009 m .38937 .32726 L .39619 .30668 L F
.38937 .32726 m .39373 .27534 L .39619 .30668 L .895 .66 .575 r
F
.38937 .32726 m .38612 .31451 L .39373 .27534 L F
.3962 .26755 m .39151 .28881 L .3974 .29094 L .538 .232 .397 r
F
.3974 .29094 m .39974 .28757 L .40408 .2735 L .582 .806 .407 r
F
.39879 .27112 m .39618 .24175 L .39912 .26509 L 0 0 .229 r
F
.39848 .27688 m .39879 .27112 L .3988 .27114 L 0 0 .403 r
F
.39849 .27689 m .3988 .27114 L .40182 .28105 L F
.39848 .27688 m .3988 .27114 L .39849 .27689 L F
.39618 .24175 m .39809 .24834 L .3993 .2618 L .699 .393 0 r
F
.4027 .27799 m .4029 .27743 L .40661 .26554 L 0 0 0 r
F
.40661 .26554 m .40327 .27624 L .40977 .24114 L .93 .808 .346 r
F
.40321 .2766 m .40496 .26791 L .40977 .24114 L .641 .533 .716 r
F
.40217 .28219 m .40333 .27625 L .40321 .2766 L F
.40333 .27625 m .40496 .26791 L .40321 .2766 L F
.40217 .28219 m .39879 .27112 L .40356 .26864 L F
.4026 .27998 m .40356 .26864 L .40496 .26791 L F
.40217 .28219 m .40356 .26864 L .4026 .27998 L F
.39879 .27112 m .40074 .27794 L .40496 .26791 L 0 0 .229 r
F
.40074 .27794 m .404 .25222 L .40546 .24605 L .461 .307 .585 r
F
.40468 .25521 m .40546 .24605 L .40855 .23296 L F
.40074 .27794 m .40546 .24605 L .40468 .25521 L F
.39912 .26509 m .3993 .2618 L .40074 .27794 L .699 .393 0 r
F
.39618 .24175 m .3993 .2618 L .39912 .26509 L F
.39879 .27112 m .39912 .26509 L .40074 .27794 L 0 0 .229 r
F
.39646 .27436 m .39879 .27112 L .39848 .27688 L 0 0 .403 r
F
.40167 .28151 m .40182 .28105 L .40217 .28219 L F
.39646 .27436 m .40182 .28105 L .40167 .28151 L F
.40012 .28635 m .39974 .28757 L .40024 .28596 L 0 0 0 r
F
.40963 .25589 m .40661 .26554 L .40996 .25457 L .698 .736 .224 r
F
.40963 .25589 m .40996 .25457 L .41344 .24318 L F
.79223 .25317 m .79589 .24693 L .79865 .25099 L .664 .741 .908 r
F
.79223 .25317 m .78946 .24913 L .79589 .24693 L F
.22236 .25317 m .22421 .24694 L .22815 .25099 L .663 .741 .908 r
F
.22236 .25317 m .21841 .24913 L .22421 .24694 L F
.60227 .25317 m .60533 .24695 L .60849 .25101 L F
.60227 .25317 m .59911 .24913 L .60533 .24695 L F
.13512 .25301 m .1367 .24677 L .14081 .25082 L .664 .741 .908 r
F
.13512 .25301 m .131 .24896 L .1367 .24677 L F
.70504 .25301 m .70843 .24677 L .71137 .25082 L .663 .741 .908 r
F
.70504 .25301 m .70209 .24896 L .70843 .24677 L F
.80783 .25283 m .81155 .2466 L .81428 .25065 L F
.80783 .25283 m .80509 .24879 L .81155 .2466 L F
.23786 .25285 m .23976 .2466 L .24367 .25066 L .664 .741 .908 r
F
.23786 .25285 m .23395 .2488 L .23976 .2466 L F
.61784 .25285 m .62095 .2466 L .62407 .25065 L .665 .742 .908 r
F
.61784 .25285 m .61471 .24882 L .62095 .2466 L F
.72063 .25267 m .72407 .24642 L .72698 .25048 L .664 .741 .908 r
F
.72063 .25267 m .71771 .24862 L .72407 .24642 L F
.15061 .25267 m .15224 .24642 L .15632 .25048 L F
.15061 .25267 m .14652 .24862 L .15224 .24642 L F
.82344 .2525 m .8272 .24625 L .8299 .25031 L F
.82344 .2525 m .82073 .24845 L .8272 .24625 L F
.63342 .2525 m .63658 .24625 L .63967 .25031 L F
.63342 .2525 m .63032 .24846 L .63658 .24625 L F
.25337 .25251 m .25532 .24625 L .2592 .25031 L .664 .742 .908 r
F
.25337 .25251 m .24949 .24846 L .25532 .24625 L F
.73623 .25233 m .73971 .24608 L .74259 .25014 L .663 .741 .908 r
F
.73623 .25233 m .73334 .24828 L .73971 .24608 L F
.16611 .25233 m .16778 .24608 L .17184 .25014 L F
.16611 .25233 m .16205 .24828 L .16778 .24608 L F
.39373 .27534 m .39058 .261 L .3962 .26755 L .255 .239 .648 r
F
.38612 .31451 m .39058 .261 L .39373 .27534 L .717 .493 .585 r
F
.38612 .31451 m .38378 .28162 L .39058 .261 L F
.39058 .261 m .39151 .28881 L .3962 .26755 L .723 .388 .412 r
F
.39058 .261 m .38615 .27549 L .39151 .28881 L F
.38378 .28162 m .38615 .27549 L .39058 .261 L 0 0 .485 r
F
.649 .25217 m .65221 .24593 L .65526 .24998 L .663 .741 .908 r
F
.649 .25217 m .64593 .24812 L .65221 .24593 L F
.26889 .25217 m .27089 .24594 L .27473 .25 L .662 .741 .908 r
F
.26889 .25217 m .26503 .24812 L .27089 .24594 L F
.18161 .252 m .18333 .24576 L .18736 .24981 L .663 .741 .908 r
F
.18161 .252 m .17758 .24795 L .18333 .24576 L F
.75183 .252 m .75536 .24575 L .75821 .24981 L F
.75183 .252 m .74897 .24795 L .75536 .24575 L F
.45897 .30117 m .45613 .26857 L .46204 .27302 L .471 .312 .583 r
F
.45301 .29801 m .45613 .26857 L .45897 .30117 L .997 .82 .467 r
F
.45301 .29801 m .44923 .30593 L .45613 .26857 L F
.45613 .26857 m .45813 .29007 L .46204 .27302 L .933 .599 .155 r
F
.44923 .30593 m .45278 .25936 L .45613 .26857 L .853 .622 .588 r
F
.45613 .26857 m .45278 .25936 L .45813 .29007 L .933 .599 .155 r
F
.36192 .43635 m .36759 .36315 L .36983 .3958 L .998 .775 .446 r
F
.36192 .43635 m .35695 .45702 L .36759 .36315 L F
.66458 .25183 m .66784 .24558 L .67087 .24964 L .664 .741 .908 r
F
.66458 .25183 m .66155 .24778 L .66784 .24558 L F
.28441 .25184 m .28646 .24561 L .29027 .24967 L .662 .741 .909 r
F
.28441 .25184 m .28059 .24779 L .28646 .24561 L F
.49092 .31864 m .49389 .28775 L .4971 .30952 L .557 .381 .599 r
F
.76743 .25166 m .77102 .24541 L .77383 .24946 L .664 .741 .908 r
F
.76743 .25166 m .7646 .24761 L .77102 .24541 L F
.19712 .25166 m .19889 .24541 L .20288 .24947 L F
.19712 .25166 m .19312 .24762 L .19889 .24541 L F
.38084 .40498 m .37643 .41842 L .38335 .39581 L .742 .765 .261 r
F
.57467 .27714 m .57135 .26689 L .57733 .25181 L .835 .646 .646 r
F
.57733 .25181 m .58031 .24541 L .58351 .24947 L .666 .737 .903 r
F
.57733 .25181 m .57411 .24766 L .58031 .24541 L F
.57135 .26689 m .57411 .24766 L .57733 .25181 L .817 .658 .687 r
F
.10981 .25149 m .11131 .24523 L .11548 .24929 L .664 .741 .908 r
F
.10981 .25149 m .10563 .24744 L .11131 .24523 L F
.68017 .25149 m .68348 .24523 L .68648 .24929 L F
.68017 .25149 m .67717 .24744 L .68348 .24523 L F
.29993 .2515 m .30203 .24524 L .30581 .2493 L F
.29993 .2515 m .29614 .24745 L .30203 .24524 L F
.48112 .27314 m .48356 .28496 L .48719 .27193 L .303 .03 .322 r
F
.48112 .27314 m .47735 .29272 L .48356 .28496 L F
.38378 .28162 m .38108 .2577 L .38615 .27549 L 0 0 .485 r
F
.38108 .2577 m .38128 .29826 L .38615 .27549 L .922 .591 .397 r
F
.38108 .2577 m .37713 .26053 L .38128 .29826 L F
.21263 .25132 m .21445 .24507 L .21841 .24913 L .663 .741 .908 r
F
.21263 .25132 m .20866 .24727 L .21445 .24507 L F
.78304 .25132 m .78668 .24507 L .78946 .24913 L F
.78304 .25132 m .78025 .24727 L .78668 .24507 L F
.5929 .25132 m .59593 .24507 L .59911 .24913 L F
.5929 .25132 m .58972 .24727 L .59593 .24507 L F
.69577 .25115 m .69913 .2449 L .70209 .24896 L F
.69577 .25115 m .6928 .2471 L .69913 .2449 L F
.12531 .25115 m .12686 .2449 L .131 .24896 L F
.12531 .25115 m .12116 .2471 L .12686 .2449 L F
.44923 .30593 m .44603 .28967 L .45209 .26249 L .853 .622 .588 r
F
.45257 .26215 m .45209 .26249 L .45278 .25936 L F
.44923 .30593 m .45209 .26249 L .45257 .26215 L F
.44603 .28967 m .4487 .28023 L .45278 .25936 L .146 .099 .543 r
F
.44603 .28967 m .44305 .26537 L .4487 .28023 L F
.44406 .26803 m .44465 .29672 L .4487 .28023 L .955 .613 .304 r
F
.44305 .26537 m .44322 .26861 L .44406 .26803 L F
.44322 .26861 m .44465 .29672 L .44406 .26803 L F
.45278 .25936 m .45453 .29011 L .45813 .29007 L .65 .336 .428 r
F
.45278 .25936 m .4487 .28023 L .45453 .29011 L F
.79865 .25099 m .80234 .24473 L .80509 .24879 L .663 .741 .908 r
F
.79865 .25099 m .79589 .24693 L .80234 .24473 L F
.22815 .25099 m .23002 .24474 L .23395 .2488 L F
.22815 .25099 m .22421 .24694 L .23002 .24474 L F
.60849 .25101 m .61157 .24476 L .61471 .24882 L F
.60849 .25101 m .60533 .24695 L .61157 .24476 L F
.31544 .25151 m .31668 .25874 L .31998 .26984 L .854 .417 0 r
F
.31544 .25151 m .31169 .24728 L .3151 .25511 L F
.30581 .2493 m .30793 .24311 L .31169 .24728 L .659 .74 .91 r
F
.31644 .25737 m .3151 .25511 L .31668 .25874 L .854 .417 0 r
F
.31544 .25151 m .3151 .25511 L .31644 .25737 L F
.31169 .24728 m .31327 .24917 L .31668 .25874 L .541 .057 0 r
F
.31169 .24728 m .30793 .24311 L .31327 .24917 L F
.308 .24319 m .30975 .24129 L .31327 .24917 L .091 .448 .882 r
F
.30793 .24311 m .30794 .2431 L .308 .24319 L F
.30794 .2431 m .30975 .24129 L .308 .24319 L F
.14081 .25082 m .14241 .24456 L .14652 .24862 L .664 .741 .908 r
F
.14081 .25082 m .1367 .24677 L .14241 .24456 L F
.71137 .25082 m .71478 .24456 L .71771 .24862 L F
.71137 .25082 m .70843 .24677 L .71478 .24456 L F
.62407 .25065 m .62721 .24439 L .63032 .24846 L F
.62407 .25065 m .62095 .2466 L .62721 .24439 L F
.81428 .25065 m .81801 .24439 L .82073 .24845 L .664 .742 .908 r
F
.81428 .25065 m .81155 .2466 L .81801 .24439 L F
.24367 .25066 m .24559 .2444 L .24949 .24846 L .664 .741 .908 r
F
.24367 .25066 m .23976 .2466 L .24559 .2444 L F
.72698 .25048 m .73044 .24422 L .73334 .24828 L F
.72698 .25048 m .72407 .24642 L .73044 .24422 L F
.15632 .25048 m .15797 .24422 L .16205 .24828 L F
.15632 .25048 m .15224 .24642 L .15797 .24422 L F
.63967 .25031 m .64285 .24405 L .64593 .24812 L .663 .741 .908 r
F
.63967 .25031 m .63658 .24625 L .64285 .24405 L F
.2592 .25031 m .26117 .24406 L .26503 .24812 L F
.2592 .25031 m .25532 .24625 L .26117 .24406 L F
.17184 .25014 m .17353 .24388 L .17758 .24795 L F
.17184 .25014 m .16778 .24608 L .17353 .24388 L F
.74259 .25014 m .7461 .24389 L .74897 .24795 L F
.74259 .25014 m .73971 .24608 L .7461 .24389 L F
.65526 .24998 m .6585 .24372 L .66155 .24778 L .664 .742 .908 r
F
.65526 .24998 m .65221 .24593 L .6585 .24372 L F
.27473 .25 m .27675 .24372 L .28059 .24779 L F
.27473 .25 m .27089 .24594 L .27675 .24372 L F
.18736 .24981 m .1891 .24355 L .19312 .24762 L .664 .741 .908 r
F
.18736 .24981 m .18333 .24576 L .1891 .24355 L F
.75821 .24981 m .76177 .24354 L .7646 .24761 L F
.75821 .24981 m .75536 .24575 L .76177 .24354 L F
.67087 .24964 m .67415 .24337 L .67717 .24744 L F
.67087 .24964 m .66784 .24558 L .67415 .24337 L F
.29027 .24967 m .29234 .24338 L .29614 .24745 L .665 .742 .907 r
F
.29027 .24967 m .28646 .24561 L .29234 .24338 L F
.77383 .24946 m .77744 .2432 L .78025 .24727 L .664 .741 .908 r
F
.77383 .24946 m .77102 .24541 L .77744 .2432 L F
.20288 .24947 m .20468 .2432 L .20866 .24727 L F
.20288 .24947 m .19889 .24541 L .20468 .2432 L F
.38335 .39581 m .38017 .38216 L .38629 .37669 L .674 .525 .675 r
F
.37643 .41842 m .38017 .38216 L .38335 .39581 L .953 .742 .58 r
F
.37643 .41842 m .37272 .41582 L .38017 .38216 L F
.38017 .38216 m .38276 .37111 L .38629 .37669 L .146 .086 .526 r
F
.58351 .24947 m .58652 .2432 L .58972 .24727 L .664 .741 .908 r
F
.58351 .24947 m .58031 .24541 L .58652 .2432 L F
.68648 .24929 m .68981 .24303 L .6928 .2471 L .663 .741 .908 r
F
.68648 .24929 m .68348 .24523 L .68981 .24303 L F
.11548 .24929 m .117 .24303 L .12116 .2471 L F
.11548 .24929 m .11131 .24523 L .117 .24303 L F
.30581 .2493 m .30203 .24524 L .30793 .24311 L .659 .74 .91 r
F
.21841 .24913 m .22026 .24287 L .22421 .24694 L .663 .741 .908 r
F
.21841 .24913 m .21445 .24507 L .22026 .24287 L F
.78946 .24913 m .79312 .24286 L .79589 .24693 L .664 .741 .908 r
F
.78946 .24913 m .78668 .24507 L .79312 .24286 L F
.59911 .24913 m .60217 .24287 L .60533 .24695 L .663 .741 .908 r
F
.59911 .24913 m .59593 .24507 L .60217 .24287 L F
.70209 .24896 m .70548 .24269 L .70843 .24677 L F
.70209 .24896 m .69913 .2449 L .70548 .24269 L F
.131 .24896 m .13256 .24269 L .1367 .24677 L .664 .741 .908 r
F
.131 .24896 m .12686 .2449 L .13256 .24269 L F
.80509 .24879 m .8088 .24252 L .81155 .2466 L .664 .742 .908 r
F
.80509 .24879 m .80234 .24473 L .8088 .24252 L F
.23395 .2488 m .23584 .24253 L .23976 .2466 L .664 .741 .908 r
F
.23395 .2488 m .23002 .24474 L .23584 .24253 L F
.61471 .24882 m .61782 .24253 L .62095 .2466 L .665 .742 .908 r
F
.61471 .24882 m .61157 .24476 L .61782 .24253 L F
.71771 .24862 m .72115 .24235 L .72407 .24642 L .664 .741 .908 r
F
.71771 .24862 m .71478 .24456 L .72115 .24235 L F
.14652 .24862 m .14813 .24235 L .15224 .24642 L F
.14652 .24862 m .14241 .24456 L .14813 .24235 L F
.82073 .24845 m .82449 .24218 L .8272 .24625 L .663 .741 .908 r
F
.82073 .24845 m .81801 .24439 L .82449 .24218 L F
.63032 .24846 m .63347 .24218 L .63658 .24625 L .664 .741 .908 r
F
.63032 .24846 m .62721 .24439 L .63347 .24218 L F
.24949 .24846 m .25143 .24218 L .25532 .24625 L .664 .742 .908 r
F
.24949 .24846 m .24559 .2444 L .25143 .24218 L F
.73334 .24828 m .73682 .24201 L .73971 .24608 L .663 .741 .908 r
F
.73334 .24828 m .73044 .24422 L .73682 .24201 L F
.16205 .24828 m .16371 .24201 L .16778 .24608 L F
.16205 .24828 m .15797 .24422 L .16371 .24201 L F
.64593 .24812 m .64914 .24186 L .65221 .24593 L F
.64593 .24812 m .64285 .24405 L .64914 .24186 L F
.26503 .24812 m .26703 .24187 L .27089 .24594 L .662 .741 .908 r
F
.26503 .24812 m .26117 .24406 L .26703 .24187 L F
.17758 .24795 m .17929 .24168 L .18333 .24576 L .663 .741 .908 r
F
.17758 .24795 m .17353 .24388 L .17929 .24168 L F
.74897 .24795 m .7525 .24167 L .75536 .24575 L .664 .741 .908 r
F
.74897 .24795 m .7461 .24389 L .7525 .24167 L F
.66155 .24778 m .6648 .2415 L .66784 .24558 L .664 .742 .908 r
F
.66155 .24778 m .6585 .24372 L .6648 .2415 L F
.28059 .24779 m .28263 .24153 L .28646 .24561 L .662 .741 .908 r
F
.28059 .24779 m .27675 .24372 L .28263 .24153 L F
.7646 .24761 m .76819 .24133 L .77102 .24541 L .664 .741 .908 r
F
.7646 .24761 m .76177 .24354 L .76819 .24133 L F
.19312 .24762 m .19488 .24133 L .19889 .24541 L F
.19312 .24762 m .1891 .24355 L .19488 .24133 L F
.57135 .26689 m .56804 .25838 L .57411 .24766 L .817 .658 .687 r
F
.57411 .24766 m .57709 .24134 L .58031 .24541 L .664 .74 .906 r
F
.57411 .24766 m .57088 .24356 L .57709 .24134 L F
.56804 .25838 m .57088 .24356 L .57411 .24766 L .799 .679 .732 r
F
.67717 .24744 m .68048 .24116 L .68348 .24523 L .664 .741 .908 r
F
.67717 .24744 m .67415 .24337 L .68048 .24116 L F
.29614 .24745 m .29824 .24116 L .30203 .24524 L F
.29614 .24745 m .29234 .24338 L .29824 .24116 L F
.20866 .24727 m .21048 .24099 L .21445 .24507 L .663 .741 .908 r
F
.20866 .24727 m .20468 .2432 L .21048 .24099 L F
.78025 .24727 m .78388 .24099 L .78668 .24507 L F
.78025 .24727 m .77744 .2432 L .78388 .24099 L F
.58972 .24727 m .59275 .241 L .59593 .24507 L F
.58972 .24727 m .58652 .2432 L .59275 .241 L F
.6928 .2471 m .69615 .24082 L .69913 .2449 L .664 .741 .908 r
F
.6928 .2471 m .68981 .24303 L .69615 .24082 L F
.12116 .2471 m .1227 .24082 L .12686 .2449 L F
.12116 .2471 m .117 .24303 L .1227 .24082 L F
.79589 .24693 m .79958 .24066 L .80234 .24473 L .663 .741 .908 r
F
.79589 .24693 m .79312 .24286 L .79958 .24066 L F
.22421 .24694 m .22607 .24066 L .23002 .24474 L F
.22421 .24694 m .22026 .24287 L .22607 .24066 L F
.60533 .24695 m .60841 .24068 L .61157 .24476 L .662 .74 .908 r
F
.60533 .24695 m .60217 .24287 L .60841 .24068 L F
.1367 .24677 m .13828 .24048 L .14241 .24456 L .664 .741 .908 r
F
.1367 .24677 m .13256 .24269 L .13828 .24048 L F
.70843 .24677 m .71184 .24048 L .71478 .24456 L F
.70843 .24677 m .70548 .24269 L .71184 .24048 L F
.62095 .2466 m .62408 .24031 L .62721 .24439 L .664 .742 .908 r
F
.62095 .2466 m .61782 .24253 L .62408 .24031 L F
.81155 .2466 m .81528 .24031 L .81801 .24439 L .664 .741 .908 r
F
.81155 .2466 m .8088 .24252 L .81528 .24031 L F
.23976 .2466 m .24168 .24032 L .24559 .2444 L F
.23976 .2466 m .23584 .24253 L .24168 .24032 L F
.57567 .32853 m .5812 .47105 L .58439 .46533 L .977 .688 .304 r
F
.4057 .31145 m .40298 .2853 L .40906 .28125 L .595 .414 .608 r
F
.40342 .31359 m .4057 .31145 L .40924 .31674 L 0 0 0 r
F
.40342 .31359 m .39924 .32444 L .4057 .31145 L F
.39924 .32444 m .40298 .2853 L .4057 .31145 L .801 .585 .609 r
F
.39924 .32444 m .39619 .30668 L .40298 .2853 L F
.72407 .24642 m .72753 .24014 L .73044 .24422 L .664 .741 .908 r
F
.72407 .24642 m .72115 .24235 L .72753 .24014 L F
.15224 .24642 m .15387 .24014 L .15797 .24422 L F
.15224 .24642 m .14813 .24235 L .15387 .24014 L F
.25532 .24625 m .25729 .23998 L .26117 .24406 L .663 .741 .908 r
F
.25532 .24625 m .25143 .24218 L .25729 .23998 L F
.63658 .24625 m .63976 .23997 L .64285 .24405 L F
.63658 .24625 m .63347 .24218 L .63976 .23997 L F
.16778 .24608 m .16947 .2398 L .17353 .24388 L F
.16778 .24608 m .16371 .24201 L .16947 .2398 L F
.73971 .24608 m .74322 .2398 L .7461 .24389 L F
.73971 .24608 m .73682 .24201 L .74322 .2398 L F
.51502 .26849 m .51171 .25351 L .51769 .31894 L .962 .66 .243 r
F
.51171 .25351 m .51427 .3135 L .51769 .31894 L .913 .586 .411 r
F
.51171 .25351 m .50828 .26203 L .51427 .3135 L F
.65221 .24593 m .65544 .23965 L .6585 .24372 L .663 .741 .908 r
F
.65221 .24593 m .64914 .24186 L .65544 .23965 L F
.27089 .24594 m .2729 .23964 L .27675 .24372 L .664 .742 .908 r
F
.27089 .24594 m .26703 .24187 L .2729 .23964 L F
.75536 .24575 m .75892 .23946 L .76177 .24354 L .664 .741 .908 r
F
.75536 .24575 m .7525 .24167 L .75892 .23946 L F
.18333 .24576 m .18507 .23947 L .1891 .24355 L F
.18333 .24576 m .17929 .24168 L .18507 .23947 L F
.57432 .45663 m .57467 .27714 L .57803 .28917 L .953 .675 .472 r
F
.57432 .45663 m .57071 .43814 L .57467 .27714 L F
.66784 .24558 m .67112 .23929 L .67415 .24337 L .664 .741 .908 r
F
.66784 .24558 m .6648 .2415 L .67112 .23929 L F
.28646 .24561 m .28852 .23929 L .29234 .24338 L .665 .742 .907 r
F
.28646 .24561 m .28263 .24153 L .28852 .23929 L F
.41465 .29111 m .41188 .26513 L .41684 .29349 L 0 0 .331 r
F
.40906 .28125 m .41188 .26513 L .41465 .29111 L .38 .271 .603 r
F
.41188 .26513 m .41409 .26594 L .41684 .29349 L 0 0 .554 r
F
.57071 .43814 m .56706 .41487 L .57135 .26689 L .943 .665 .483 r
F
.4117 .31048 m .40906 .28125 L .41465 .29111 L .347 .227 .57 r
F
.4057 .31145 m .40906 .28125 L .4117 .31048 L .595 .414 .608 r
F
.46204 .27302 m .46411 .29538 L .4676 .29924 L .603 .279 .395 r
F
.46204 .27302 m .45813 .29007 L .46411 .29538 L F
.77102 .24541 m .77463 .23911 L .77744 .2432 L .664 .741 .908 r
F
.77102 .24541 m .76819 .24133 L .77463 .23911 L F
.19889 .24541 m .20068 .23911 L .20468 .2432 L F
.19889 .24541 m .19488 .24133 L .20068 .23911 L F
.58031 .24541 m .58331 .23911 L .58652 .2432 L .664 .742 .908 r
F
.58031 .24541 m .57709 .24134 L .58331 .23911 L F
.68348 .24523 m .68681 .23894 L .68981 .24303 L .663 .741 .908 r
F
.68348 .24523 m .68048 .24116 L .68681 .23894 L F
.30203 .24524 m .30415 .23898 L .30793 .24311 L .662 .741 .909 r
F
.30203 .24524 m .29824 .24116 L .30415 .23898 L F
.21445 .24507 m .21629 .23878 L .22026 .24287 L .663 .741 .908 r
F
.21445 .24507 m .21048 .24099 L .21629 .23878 L F
.78668 .24507 m .79034 .23877 L .79312 .24286 L .664 .741 .908 r
F
.78668 .24507 m .78388 .24099 L .79034 .23877 L F
.59593 .24507 m .59899 .23878 L .60217 .24287 L .663 .741 .908 r
F
.59593 .24507 m .59275 .241 L .59899 .23878 L F
.69913 .2449 m .70251 .23861 L .70548 .24269 L F
.69913 .2449 m .69615 .24082 L .70251 .23861 L F
.12686 .2449 m .12841 .23861 L .13256 .24269 L .664 .741 .908 r
F
.12686 .2449 m .1227 .24082 L .12841 .23861 L F
.50043 .31953 m .4971 .30952 L .50315 .31758 L .017 .147 .658 r
F
.49424 .33024 m .4971 .30952 L .50043 .31953 L .752 .59 .675 r
F
.80234 .24473 m .80605 .23843 L .8088 .24252 L .664 .742 .908 r
F
.80234 .24473 m .79958 .24066 L .80605 .23843 L F
.23002 .24474 m .2319 .23844 L .23584 .24253 L .664 .741 .908 r
F
.23002 .24474 m .22607 .24066 L .2319 .23844 L F
.61157 .24476 m .61467 .23844 L .61782 .24253 L .665 .742 .907 r
F
.61157 .24476 m .60841 .24068 L .61467 .23844 L F
.49424 .33024 m .49092 .31864 L .4971 .30952 L .752 .59 .675 r
F
.57932 .35795 m .58439 .46533 L .5874 .45179 L .963 .681 .253 r
F
.57783 .46809 m .57803 .28917 L .58142 .30288 L .964 .687 .46 r
F
.57783 .46809 m .57432 .45663 L .57803 .28917 L F
.14241 .24456 m .14401 .23827 L .14813 .24235 L .664 .741 .908 r
F
.14241 .24456 m .13828 .24048 L .14401 .23827 L F
.71478 .24456 m .71821 .23827 L .72115 .24235 L F
.71478 .24456 m .71184 .24048 L .71821 .23827 L F
.81801 .24439 m .82177 .23809 L .82449 .24218 L .663 .741 .908 r
F
.81801 .24439 m .81528 .24031 L .82177 .23809 L F
.62721 .24439 m .63036 .23809 L .63347 .24218 L .664 .741 .908 r
F
.62721 .24439 m .62408 .24031 L .63036 .23809 L F
.24559 .2444 m .24753 .23809 L .25143 .24218 L .664 .742 .908 r
F
.24559 .2444 m .24168 .24032 L .24753 .23809 L F
.56706 .41487 m .5634 .3893 L .56804 .25838 L .934 .657 .492 r
F
.56804 .25838 m .56476 .25135 L .57088 .24356 L .799 .679 .732 r
F
.5634 .3893 m .56476 .25135 L .56804 .25838 L .926 .651 .501 r
F
.44305 .26537 m .43954 .26157 L .44465 .29672 L .955 .613 .304 r
F
.35526 .34056 m .357 .34508 L .362 .32436 L 0 0 .165 r
F
.362 .32436 m .357 .34508 L .36544 .29615 L .94 .806 .351 r
F
.357 .34508 m .36017 .32286 L .36544 .29615 L .993 .834 .58 r
F
.73044 .24422 m .73392 .23792 L .73682 .24201 L .663 .741 .908 r
F
.73044 .24422 m .72753 .24014 L .73392 .23792 L F
.15797 .24422 m .15962 .23792 L .16371 .24201 L F
.15797 .24422 m .15387 .24014 L .15962 .23792 L F
.64285 .24405 m .64605 .23776 L .64914 .24186 L F
.64285 .24405 m .63976 .23997 L .64605 .23776 L F
.26117 .24406 m .26315 .23778 L .26703 .24187 L .662 .741 .908 r
F
.26117 .24406 m .25729 .23998 L .26315 .23778 L F
.17353 .24388 m .17524 .23759 L .17929 .24168 L .663 .741 .908 r
F
.17353 .24388 m .16947 .2398 L .17524 .23759 L F
.7461 .24389 m .74963 .23758 L .7525 .24167 L .664 .741 .908 r
F
.7461 .24389 m .74322 .2398 L .74963 .23758 L F
.34553 .26799 m .34261 .25041 L .3481 .25618 L .336 .265 .628 r
F
.33816 .29373 m .34261 .25041 L .34553 .26799 L .667 .458 .592 r
F
.33816 .29373 m .33604 .26288 L .34261 .25041 L F
.34261 .25041 m .34498 .24198 L .3481 .25618 L .944 .962 .709 r
F
.34261 .25041 m .33852 .25255 L .34498 .24198 L F
.33604 .26288 m .33852 .25255 L .34261 .25041 L .322 .27 .643 r
F
.6585 .24372 m .66175 .23741 L .6648 .2415 L .664 .742 .908 r
F
.6585 .24372 m .65544 .23965 L .66175 .23741 L F
.27675 .24372 m .27879 .23744 L .28263 .24153 L .663 .741 .908 r
F
.27675 .24372 m .2729 .23964 L .27879 .23744 L F
.76177 .24354 m .76535 .23724 L .76819 .24133 L .664 .741 .908 r
F
.76177 .24354 m .75892 .23946 L .76535 .23724 L F
.1891 .24355 m .19086 .23724 L .19488 .24133 L .664 .742 .908 r
F
.1891 .24355 m .18507 .23947 L .19086 .23724 L F
.57088 .24356 m .57385 .23725 L .57709 .24134 L .665 .742 .908 r
F
.57088 .24356 m .56764 .23948 L .57385 .23725 L F
.56476 .25135 m .56764 .23948 L .57088 .24356 L .783 .704 .777 r
F
.67415 .24337 m .67746 .23706 L .68048 .24116 L .664 .741 .908 r
F
.67415 .24337 m .67112 .23929 L .67746 .23706 L F
.29234 .24338 m .29443 .23707 L .29824 .24116 L F
.29234 .24338 m .28852 .23929 L .29443 .23707 L F
.20468 .2432 m .20648 .2369 L .21048 .24099 L .663 .741 .908 r
F
.20468 .2432 m .20068 .23911 L .20648 .2369 L F
.77744 .2432 m .78108 .2369 L .78388 .24099 L .664 .741 .908 r
F
.77744 .2432 m .77463 .23911 L .78108 .2369 L F
.58652 .2432 m .58954 .2369 L .59275 .241 L .663 .741 .908 r
F
.58652 .2432 m .58331 .23911 L .58954 .2369 L F
.52165 .32343 m .51831 .29803 L .52348 .2814 L .746 .526 .596 r
F
.52423 .28236 m .52348 .2814 L .5245 .27809 L F
.52165 .32343 m .52348 .2814 L .52423 .28236 L F
.51831 .29803 m .52112 .30289 L .5245 .27809 L 0 0 .354 r
F
.51831 .29803 m .51502 .26849 L .52112 .30289 L F
.51551 .27125 m .51769 .31894 L .52112 .30289 L .962 .66 .243 r
F
.51502 .26849 m .51514 .27078 L .51551 .27125 L F
.51514 .27078 m .51769 .31894 L .51551 .27125 L F
.68981 .24303 m .69317 .23673 L .69615 .24082 L .663 .741 .908 r
F
.68981 .24303 m .68681 .23894 L .69317 .23673 L F
.30793 .24311 m .30415 .23898 L .30975 .24129 L .091 .448 .882 r
F
.33604 .26288 m .33304 .24715 L .33852 .25255 L .322 .27 .643 r
F
.3292 .31418 m .32628 .29688 L .32443 .41748 L .98 .699 .411 r
F
.32456 .41785 m .32443 .41748 L .32435 .42248 L F
.3292 .31418 m .32443 .41748 L .32456 .41785 L F
.32628 .29688 m .32318 .28242 L .3199 .42679 L .975 .693 .428 r
F
.32318 .28242 m .31628 .41756 L .3199 .42679 L .972 .69 .433 r
F
.32628 .29688 m .3199 .42679 L .32435 .42248 L .975 .693 .428 r
F
.31807 .39931 m .32888 .24974 L .33304 .24715 L .929 .667 .519 r
F
.31628 .41756 m .31772 .39831 L .31807 .39931 L F
.31772 .39831 m .32888 .24974 L .31807 .39931 L F
.3319 .33538 m .3292 .31418 L .32945 .40681 L .985 .706 .36 r
F
.3292 .31418 m .32435 .42248 L .32945 .40681 L .98 .699 .411 r
F
.3199 .42679 m .33304 .24715 L .33604 .26288 L .951 .69 .505 r
F
.3199 .42679 m .31628 .41756 L .33304 .24715 L F
.33304 .24715 m .33327 .27296 L .33852 .25255 L .895 .541 .364 r
F
.33304 .24715 m .32888 .24974 L .33327 .27296 L F
.79312 .24286 m .79681 .23656 L .79958 .24066 L .663 .741 .908 r
F
.79312 .24286 m .79034 .23877 L .79681 .23656 L F
.22026 .24287 m .22211 .23656 L .22607 .24066 L F
.22026 .24287 m .21629 .23878 L .22211 .23656 L F
.60217 .24287 m .60524 .23659 L .60841 .24068 L .662 .741 .908 r
F
.60217 .24287 m .59899 .23878 L .60524 .23659 L F
.47144 .28209 m .47371 .29988 L .47735 .29272 L .513 .198 .37 r
F
.47144 .28209 m .4676 .29924 L .47371 .29988 L F
.13256 .24269 m .13414 .23639 L .13828 .24048 L .663 .741 .908 r
F
.13256 .24269 m .12841 .23861 L .13414 .23639 L F
.70548 .24269 m .70888 .23639 L .71184 .24048 L F
.70548 .24269 m .70251 .23861 L .70888 .23639 L F
.8088 .24252 m .81254 .23621 L .81528 .24031 L .664 .741 .908 r
F
.8088 .24252 m .80605 .23843 L .81254 .23621 L F
.61782 .24253 m .62094 .23621 L .62408 .24031 L .664 .742 .908 r
F
.61782 .24253 m .61467 .23844 L .62094 .23621 L F
.23584 .24253 m .23775 .23622 L .24168 .24032 L .664 .741 .908 r
F
.23584 .24253 m .2319 .23844 L .23775 .23622 L F
.58297 .38512 m .5874 .45179 L .59024 .43237 L .925 .652 .169 r
F
.5812 .47105 m .58142 .30288 L .58484 .31805 L .975 .7 .445 r
F
.5812 .47105 m .57783 .46809 L .58142 .30288 L F
.72115 .24235 m .7246 .23604 L .72753 .24014 L .664 .742 .908 r
F
.72115 .24235 m .71821 .23827 L .7246 .23604 L F
.14813 .24235 m .14976 .23604 L .15387 .24014 L .664 .741 .908 r
F
.14813 .24235 m .14401 .23827 L .14976 .23604 L F
.25143 .24218 m .25339 .23588 L .25729 .23998 L .663 .741 .908 r
F
.25143 .24218 m .24753 .23809 L .25339 .23588 L F
.63347 .24218 m .63665 .23587 L .63976 .23997 L F
.63347 .24218 m .63036 .23809 L .63665 .23587 L F
.5634 .3893 m .55977 .36359 L .56476 .25135 L .926 .651 .501 r
F
.56476 .25135 m .56148 .24546 L .56764 .23948 L .783 .704 .777 r
F
.55977 .36359 m .56148 .24546 L .56476 .25135 L .919 .647 .51 r
F
.16371 .24201 m .16539 .2357 L .16947 .2398 L .663 .741 .908 r
F
.16371 .24201 m .15962 .23792 L .16539 .2357 L F
.73682 .24201 m .74033 .2357 L .74322 .2398 L .664 .741 .908 r
F
.73682 .24201 m .73392 .23792 L .74033 .2357 L F
.64914 .24186 m .65236 .23555 L .65544 .23965 L .663 .741 .908 r
F
.64914 .24186 m .64605 .23776 L .65236 .23555 L F
.26703 .24187 m .26903 .23554 L .2729 .23964 L .664 .741 .908 r
F
.26703 .24187 m .26315 .23778 L .26903 .23554 L F
.7525 .24167 m .75606 .23536 L .75892 .23946 L .663 .741 .908 r
F
.7525 .24167 m .74963 .23758 L .75606 .23536 L F
.17929 .24168 m .18102 .23537 L .18507 .23947 L .664 .741 .908 r
F
.17929 .24168 m .17524 .23759 L .18102 .23537 L F
.6648 .2415 m .66808 .23519 L .67112 .23929 L .664 .742 .908 r
F
.6648 .2415 m .66175 .23741 L .66808 .23519 L F
.28263 .24153 m .28469 .23519 L .28852 .23929 L .665 .742 .907 r
F
.28263 .24153 m .27879 .23744 L .28469 .23519 L F
.76819 .24133 m .7718 .23501 L .77463 .23911 L .664 .741 .908 r
F
.76819 .24133 m .76535 .23724 L .7718 .23501 L F
.19488 .24133 m .19666 .23501 L .20068 .23911 L F
.19488 .24133 m .19086 .23724 L .19666 .23501 L F
.57709 .24134 m .58008 .23501 L .58331 .23911 L .664 .742 .908 r
F
.57709 .24134 m .57385 .23725 L .58008 .23501 L F
.68048 .24116 m .6838 .23484 L .68681 .23894 L .663 .741 .908 r
F
.68048 .24116 m .67746 .23706 L .6838 .23484 L F
.29824 .24116 m .30034 .23486 L .30415 .23898 L F
.29824 .24116 m .29443 .23707 L .30034 .23486 L F
.78388 .24099 m .78754 .23467 L .79034 .23877 L F
.78388 .24099 m .78108 .2369 L .78754 .23467 L F
.21048 .24099 m .2123 .23468 L .21629 .23878 L F
.21048 .24099 m .20648 .2369 L .2123 .23468 L F
.59275 .241 m .59579 .23468 L .59899 .23878 L F
.59275 .241 m .58954 .2369 L .59579 .23468 L F
.69615 .24082 m .69953 .2345 L .70251 .23861 L F
.69615 .24082 m .69317 .23673 L .69953 .2345 L F
.79958 .24066 m .80329 .23433 L .80605 .23843 L .664 .742 .908 r
F
.79958 .24066 m .79681 .23656 L .80329 .23433 L F
.22607 .24066 m .22795 .23434 L .2319 .23844 L .664 .741 .908 r
F
.22607 .24066 m .22211 .23656 L .22795 .23434 L F
.60841 .24068 m .61151 .23434 L .61467 .23844 L .665 .742 .907 r
F
.60841 .24068 m .60524 .23659 L .61151 .23434 L F
.13828 .24048 m .13988 .23416 L .14401 .23827 L .664 .741 .908 r
F
.13828 .24048 m .13414 .23639 L .13988 .23416 L F
.71184 .24048 m .71527 .23416 L .71821 .23827 L F
.71184 .24048 m .70888 .23639 L .71527 .23416 L F
.81528 .24031 m .81904 .23398 L .82177 .23809 L F
.81528 .24031 m .81254 .23621 L .81904 .23398 L F
.62408 .24031 m .62723 .23398 L .63036 .23809 L F
.62408 .24031 m .62094 .23621 L .62723 .23398 L F
.24168 .24032 m .2436 .23398 L .24753 .23809 L .664 .742 .908 r
F
.24168 .24032 m .23775 .23622 L .2436 .23398 L F
.72753 .24014 m .73101 .23382 L .73392 .23792 L .663 .741 .908 r
F
.72753 .24014 m .7246 .23604 L .73101 .23382 L F
.15387 .24014 m .15552 .23381 L .15962 .23792 L F
.15387 .24014 m .14976 .23604 L .15552 .23381 L F
.36713 .26573 m .36408 .24973 L .36727 .2894 L .95 .659 .213 r
F
.36713 .26573 m .36727 .2894 L .36761 .29053 L F
.36408 .24973 m .3643 .28408 L .36769 .29468 L .849 .511 .412 r
F
.36483 .28139 m .36844 .24289 L .37229 .24361 L .692 .481 .598 r
F
.3643 .28408 m .36463 .28074 L .36483 .28139 L F
.36463 .28074 m .36844 .24289 L .36483 .28139 L F
.36761 .29053 m .36727 .2894 L .36769 .29468 L .95 .659 .213 r
F
.43954 .26157 m .4354 .27891 L .44146 .27921 L .501 .185 .363 r
F
.5245 .27809 m .52112 .30289 L .52738 .32552 L .734 .423 .455 r
F
.63976 .23997 m .64296 .23365 L .64605 .23776 L .663 .741 .908 r
F
.63976 .23997 m .63665 .23587 L .64296 .23365 L F
.25729 .23998 m .25926 .23367 L .26315 .23778 L .662 .741 .908 r
F
.25729 .23998 m .25339 .23588 L .25926 .23367 L F
.74322 .2398 m .74675 .23347 L .74963 .23758 L .664 .741 .908 r
F
.74322 .2398 m .74033 .2357 L .74675 .23347 L F
.16947 .2398 m .17116 .23349 L .17524 .23759 L .663 .741 .908 r
F
.16947 .2398 m .16539 .2357 L .17116 .23349 L F
.40924 .31674 m .4117 .31048 L .41522 .31602 L .581 .646 .879 r
F
.40924 .31674 m .4057 .31145 L .4117 .31048 L F
.2729 .23964 m .27493 .23333 L .27879 .23744 L .663 .741 .908 r
F
.2729 .23964 m .26903 .23554 L .27493 .23333 L F
.65544 .23965 m .65869 .23331 L .66175 .23741 L .664 .742 .908 r
F
.65544 .23965 m .65236 .23555 L .65869 .23331 L F
.33438 .36089 m .3319 .33538 L .33495 .38335 L .859 .628 .092 r
F
.3319 .33538 m .32945 .40681 L .33495 .38335 L .985 .706 .36 r
F
.32435 .42248 m .33604 .26288 L .33816 .29373 L .969 .712 .492 r
F
.32435 .42248 m .3199 .42679 L .33604 .26288 L F
.58439 .46533 m .58484 .31805 L .58829 .33433 L .984 .715 .427 r
F
.58439 .46533 m .5812 .47105 L .58484 .31805 L F
.75892 .23946 m .7625 .23313 L .76535 .23724 L .664 .741 .908 r
F
.75892 .23946 m .75606 .23536 L .7625 .23313 L F
.18507 .23947 m .18682 .23313 L .19086 .23724 L .664 .742 .908 r
F
.18507 .23947 m .18102 .23537 L .18682 .23313 L F
.56764 .23948 m .57061 .23314 L .57385 .23725 L .666 .743 .908 r
F
.56764 .23948 m .56438 .2354 L .57061 .23314 L F
.56148 .24546 m .56438 .2354 L .56764 .23948 L .767 .725 .813 r
F
.67112 .23929 m .67442 .23295 L .67746 .23706 L .664 .741 .908 r
F
.67112 .23929 m .66808 .23519 L .67442 .23295 L F
.28852 .23929 m .2906 .23296 L .29443 .23707 L F
.28852 .23929 m .28469 .23519 L .2906 .23296 L F
.34771 .29867 m .34553 .26799 L .35024 .28817 L .048 .001 .475 r
F
.34 .33004 m .34553 .26799 L .34771 .29867 L .731 .501 .578 r
F
.34 .33004 m .33816 .29373 L .34553 .26799 L F
.34553 .26799 m .3481 .25618 L .35024 .28817 L .336 .265 .628 r
F
.56148 .24546 m .5582 .24028 L .56438 .2354 L .767 .725 .813 r
F
.20068 .23911 m .20247 .23279 L .20648 .2369 L .663 .741 .908 r
F
.20068 .23911 m .19666 .23501 L .20247 .23279 L F
.77463 .23911 m .77826 .23278 L .78108 .2369 L .664 .741 .908 r
F
.77463 .23911 m .7718 .23501 L .77826 .23278 L F
.58331 .23911 m .58633 .23279 L .58954 .2369 L .663 .741 .908 r
F
.58331 .23911 m .58008 .23501 L .58633 .23279 L F
.3481 .25618 m .34498 .24198 L .3469 .25671 L .9 .606 .105 r
F
.34847 .26282 m .3469 .25671 L .34905 .2732 L F
.3481 .25618 m .3469 .25671 L .34847 .26282 L F
.34498 .24198 m .34678 .24361 L .34905 .2732 L 0 0 0 r
F
.34498 .24198 m .34366 .24473 L .34678 .24361 L F
.34366 .24473 m .34045 .25142 L .34396 .24709 L F
.34366 .24473 m .34396 .24709 L .34678 .24361 L F
.33327 .27296 m .33489 .2769 L .34045 .25142 L 0 0 .141 r
F
.33852 .25255 m .34045 .25142 L .34153 .24797 L 0 0 .004 r
F
.33852 .25255 m .34366 .24473 L .34357 .24429 L F
.33852 .25255 m .33327 .27296 L .34045 .25142 L F
.34045 .25142 m .33913 .25563 L .34333 .23461 L .789 .74 .216 r
F
.34153 .24797 m .34045 .25142 L .34366 .24473 L 0 0 .004 r
F
.34357 .24429 m .34366 .24473 L .34498 .24198 L F
.34045 .25142 m .34249 .23955 L .34385 .24483 L .789 .74 .216 r
F
.34396 .24709 m .34385 .24483 L .34431 .24665 L F
.34045 .25142 m .34385 .24483 L .34396 .24709 L F
.34249 .23955 m .34333 .23461 L .34431 .24665 L F
.34431 .24665 m .34333 .23461 L .34678 .24361 L F
.34678 .24361 m .34333 .23461 L .34589 .27329 L .973 .66 .328 r
F
.34333 .23461 m .34443 .24812 L .34448 .2489 L .426 .096 .302 r
F
.34333 .23461 m .34448 .2489 L .34437 .24834 L F
.34333 .23461 m .34474 .25334 L .34438 .25046 L F
.33489 .2769 m .33842 .24975 L .33851 .24945 L .915 .796 .32 r
F
.33873 .25764 m .33851 .24945 L .34333 .23461 L F
.33489 .2769 m .33851 .24945 L .33873 .25764 L F
.34333 .23461 m .33851 .24945 L .34443 .24812 L .426 .096 .302 r
F
.33851 .24945 m .33842 .24975 L .33855 .24971 L F
.33851 .24945 m .33855 .24971 L .34443 .24812 L F
.33842 .24975 m .33972 .23983 L .3414 .24894 L .902 .79 .306 r
F
.32888 .24974 m .32739 .30192 L .33327 .27296 L .822 .507 .457 r
F
.33842 .24975 m .33282 .27482 L .33847 .24279 L .902 .79 .306 r
F
.3385 .24908 m .33847 .24279 L .34188 .22348 L F
.33842 .24975 m .33847 .24279 L .3385 .24908 L F
.3414 .24894 m .34188 .22348 L .34443 .24812 L F
.33972 .23983 m .34188 .22348 L .3414 .24894 L F
.34045 .25142 m .33857 .26002 L .33913 .25563 L .789 .74 .216 r
F
.33282 .27482 m .33759 .22778 L .34188 .22348 L .999 .794 .467 r
F
.34188 .22348 m .33759 .22778 L .3412 .26415 L .912 .581 .404 r
F
.34131 .26444 m .3412 .26415 L .3413 .26513 L F
.34188 .22348 m .3412 .26415 L .34131 .26444 L F
.33844 .23631 m .33964 .24402 L .33947 .24667 L 0 0 .199 r
F
.33806 .2325 m .33843 .23521 L .33844 .23631 L F
.33843 .23521 m .33964 .24402 L .33844 .23631 L F
.33759 .22778 m .33803 .23121 L .33806 .2325 L F
.33803 .23121 m .33964 .24402 L .33806 .2325 L F
.33759 .22778 m .33899 .23569 L .33964 .24402 L F
.33282 .27482 m .32788 .28792 L .33759 .22778 L .999 .794 .467 r
F
.32788 .28792 m .33193 .2534 L .33759 .22778 L .86 .649 .616 r
F
.33759 .22778 m .33193 .2534 L .33899 .23569 L 0 0 .199 r
F
.33466 .24654 m .33663 .208 L .33899 .23569 L .993 .802 .427 r
F
.33193 .2534 m .33308 .24227 L .33466 .24654 L F
.33308 .24227 m .33663 .208 L .33466 .24654 L F
.34652 .27669 m .34589 .27329 L .34648 .28212 L .973 .66 .328 r
F
.34678 .24361 m .34589 .27329 L .34652 .27669 L F
.33947 .24667 m .33964 .24402 L .3413 .26513 L 0 0 .199 r
F
.33857 .26002 m .33489 .2769 L .33873 .25764 L .789 .74 .216 r
F
.33857 .26002 m .33873 .25764 L .33913 .25563 L F
.34437 .24834 m .34448 .2489 L .34474 .25334 L .426 .096 .302 r
F
.35024 .28817 m .34983 .28208 L .35131 .30387 L 0 0 .051 r
F
.34983 .28208 m .3481 .25618 L .34961 .2785 L F
.34983 .28208 m .34961 .2785 L .35131 .30387 L F
.3481 .25618 m .34905 .2732 L .34919 .27508 L .9 .606 .105 r
F
.34771 .29867 m .35024 .28817 L .3524 .32067 L .048 .001 .475 r
F
.34961 .2785 m .34919 .27508 L .35131 .30387 L .9 .606 .105 r
F
.3481 .25618 m .34919 .27508 L .34961 .2785 L F
.34905 .2732 m .34678 .24361 L .34837 .27279 L .827 .615 .064 r
F
.34909 .27478 m .34837 .27279 L .34968 .29672 L F
.34905 .2732 m .34837 .27279 L .34909 .27478 L F
.34678 .24361 m .34648 .28212 L .34968 .29672 L .973 .66 .328 r
F
.34614 .27646 m .34443 .24812 L .35008 .25317 L .445 .284 .568 r
F
.34438 .25046 m .34474 .25334 L .34614 .27646 L .426 .096 .302 r
F
.34438 .25046 m .34614 .27646 L .34616 .27732 L F
.34443 .24812 m .34503 .27085 L .35008 .25317 L .862 .626 .091 r
F
.34839 .25909 m .34619 .26679 L .34824 .2566 L .908 .814 .343 r
F
.34619 .26679 m .3459 .26779 L .34614 .26665 L F
.34619 .26679 m .34614 .26665 L .34824 .2566 L F
.34648 .28212 m .34614 .27646 L .35008 .25317 L .445 .284 .568 r
F
.3459 .26779 m .34588 .26688 L .34736 .26 L .908 .814 .343 r
F
.34443 .24812 m .34188 .22348 L .34455 .26356 L .862 .626 .091 r
F
.34489 .26546 m .34455 .26356 L .34503 .27085 L F
.34443 .24812 m .34455 .26356 L .34489 .26546 L F
.34188 .22348 m .3413 .26513 L .34503 .27085 L .912 .581 .404 r
F
.34309 .25544 m .34552 .22627 L .35004 .21779 L .642 .44 .594 r
F
.3413 .26513 m .34263 .25289 L .34309 .25544 L F
.34263 .25289 m .34552 .22627 L .34309 .25544 L F
.34503 .27085 m .3413 .26513 L .35004 .21779 L .946 .711 .552 r
F
.34552 .22627 m .34645 .24348 L .34699 .2448 L .489 .159 .333 r
F
.34742 .26051 m .34736 .26 L .35181 .23927 L .908 .814 .343 r
F
.34742 .26051 m .35181 .23927 L .35186 .23921 L F
.35008 .25317 m .34839 .25909 L .35318 .23287 L F
.34839 .25909 m .34824 .2566 L .35318 .23287 L F
.34503 .27085 m .35004 .21779 L .35318 .23287 L .946 .711 .552 r
F
.34844 .24313 m .34699 .2448 L .35002 .25226 L .489 .159 .333 r
F
.34552 .22627 m .34699 .2448 L .34844 .24313 L F
.35186 .23921 m .35181 .23927 L .35318 .23287 L .908 .814 .343 r
F
.3459 .26779 m .34736 .26 L .34742 .26051 L F
.3459 .26779 m .34503 .27085 L .34588 .26688 L F
.34616 .27732 m .34614 .27646 L .34648 .28212 L .426 .096 .302 r
F
.68681 .23894 m .69017 .23262 L .69317 .23673 L .663 .741 .908 r
F
.68681 .23894 m .6838 .23484 L .69017 .23262 L F
.30415 .23898 m .3061 .23504 L .30975 .24129 L .435 .648 .948 r
F
.30415 .23898 m .30034 .23486 L .3061 .23504 L F
.36706 .41068 m .36983 .3958 L .37272 .41582 L .724 .697 .159 r
F
.36706 .41068 m .36192 .43635 L .36983 .3958 L F
.79034 .23877 m .79402 .23245 L .79681 .23656 L .663 .741 .908 r
F
.79034 .23877 m .78754 .23467 L .79402 .23245 L F
.21629 .23878 m .21813 .23245 L .22211 .23656 L F
.21629 .23878 m .2123 .23468 L .21813 .23245 L F
.59899 .23878 m .60206 .23247 L .60524 .23659 L .662 .741 .908 r
F
.59899 .23878 m .59579 .23468 L .60206 .23247 L F
.70251 .23861 m .70591 .23227 L .70888 .23639 L .663 .741 .908 r
F
.70251 .23861 m .69953 .2345 L .70591 .23227 L F
.80605 .23843 m .80979 .2321 L .81254 .23621 L F
.80605 .23843 m .80329 .23433 L .80979 .2321 L F
.61467 .23844 m .61779 .2321 L .62094 .23621 L .664 .742 .908 r
F
.61467 .23844 m .61151 .23434 L .61779 .2321 L F
.2319 .23844 m .2338 .23211 L .23775 .23622 L .664 .741 .908 r
F
.2319 .23844 m .22795 .23434 L .2338 .23211 L F
.14401 .23827 m .14563 .23192 L .14976 .23604 L F
.14401 .23827 m .13988 .23416 L .14563 .23192 L F
.71821 .23827 m .72167 .23192 L .7246 .23604 L F
.71821 .23827 m .71527 .23416 L .72167 .23192 L F
.24753 .23809 m .24947 .23176 L .25339 .23588 L .663 .741 .908 r
F
.24753 .23809 m .2436 .23398 L .24947 .23176 L F
.63036 .23809 m .63353 .23176 L .63665 .23587 L F
.63036 .23809 m .62723 .23398 L .63353 .23176 L F
.15962 .23792 m .16129 .23159 L .16539 .2357 L F
.15962 .23792 m .15552 .23381 L .16129 .23159 L F
.73392 .23792 m .73743 .23158 L .74033 .2357 L .664 .741 .908 r
F
.73392 .23792 m .73101 .23382 L .73743 .23158 L F
.64605 .23776 m .64928 .23143 L .65236 .23555 L .663 .741 .908 r
F
.64605 .23776 m .64296 .23365 L .64928 .23143 L F
.26315 .23778 m .26515 .23143 L .26903 .23554 L .664 .741 .908 r
F
.26315 .23778 m .25926 .23367 L .26515 .23143 L F
.53735 .29692 m .54051 .34907 L .54383 .34285 L .797 .478 .449 r
F
.53735 .29692 m .5341 .31773 L .54051 .34907 L F
.74963 .23758 m .75319 .23124 L .75606 .23536 L .663 .741 .908 r
F
.74963 .23758 m .74675 .23347 L .75319 .23124 L F
.17524 .23759 m .17695 .23125 L .18102 .23537 L .664 .741 .908 r
F
.17524 .23759 m .17116 .23349 L .17695 .23125 L F
.66175 .23741 m .66503 .23107 L .66808 .23519 L .664 .742 .908 r
F
.66175 .23741 m .65869 .23331 L .66503 .23107 L F
.27879 .23744 m .28084 .23108 L .28469 .23519 L .665 .742 .907 r
F
.27879 .23744 m .27493 .23333 L .28084 .23108 L F
.76535 .23724 m .76896 .23089 L .7718 .23501 L .664 .741 .908 r
F
.76535 .23724 m .7625 .23313 L .76896 .23089 L F
.19086 .23724 m .19262 .23089 L .19666 .23501 L F
.19086 .23724 m .18682 .23313 L .19262 .23089 L F
.57385 .23725 m .57685 .23089 L .58008 .23501 L .664 .742 .908 r
F
.57385 .23725 m .57061 .23314 L .57685 .23089 L F
.42991 .26127 m .42653 .25178 L .43147 .28736 L .952 .625 .213 r
F
.67746 .23706 m .68078 .23073 L .6838 .23484 L .663 .741 .908 r
F
.67746 .23706 m .67442 .23295 L .68078 .23073 L F
.29443 .23707 m .29652 .23074 L .30034 .23486 L F
.29443 .23707 m .2906 .23296 L .29652 .23074 L F
.42026 .30243 m .4187 .29836 L .42322 .28276 L .807 .649 .686 r
F
.4187 .29836 m .41684 .29349 L .41786 .29178 L F
.4187 .29836 m .41786 .29178 L .42322 .28276 L F
.41684 .29349 m .41903 .29659 L .42322 .28276 L 0 0 .315 r
F
.41631 .2797 m .41602 .27543 L .41903 .29659 L .719 .456 0 r
F
.41409 .26594 m .41532 .27198 L .41631 .2797 L F
.41532 .27198 m .41602 .27543 L .41631 .2797 L F
.41684 .29349 m .41409 .26594 L .41903 .29659 L 0 0 .315 r
F
.41409 .26594 m .41088 .25191 L .41602 .27543 L .719 .456 0 r
F
.41088 .25191 m .41344 .24318 L .41602 .27543 L .698 .736 .224 r
F
.78108 .2369 m .78473 .23055 L .78754 .23467 L .663 .741 .908 r
F
.78108 .2369 m .77826 .23278 L .78473 .23055 L F
.20648 .2369 m .2083 .23056 L .2123 .23468 L F
.20648 .2369 m .20247 .23279 L .2083 .23056 L F
.58954 .2369 m .59259 .23056 L .59579 .23468 L F
.58954 .2369 m .58633 .23279 L .59259 .23056 L F
.69317 .23673 m .69654 .23039 L .69953 .2345 L F
.69317 .23673 m .69017 .23262 L .69654 .23039 L F
.41522 .31602 m .4117 .31048 L .4178 .30741 L .696 .683 .834 r
F
.42322 .28276 m .42021 .29272 L .42296 .27488 L .977 .814 .403 r
F
.42325 .28244 m .42296 .27488 L .42653 .25178 L F
.42322 .28276 m .42296 .27488 L .42325 .28244 L F
.42021 .29272 m .4207 .28664 L .42653 .25178 L F
.41903 .29659 m .42241 .26482 L .42653 .25178 L .694 .499 .62 r
F
.42653 .25178 m .42241 .26482 L .42835 .26822 L .574 .228 .345 r
F
.42247 .26486 m .42542 .24384 L .42835 .26822 L .951 .835 .401 r
F
.42255 .26383 m .42542 .24384 L .42247 .26486 L F
.41903 .29659 m .41602 .27543 L .4187 .27099 L .694 .499 .62 r
F
.42072 .28071 m .4187 .27099 L .42241 .26482 L F
.41903 .29659 m .4187 .27099 L .42072 .28071 L F
.41602 .27543 m .41828 .27641 L .42241 .26482 L 0 0 .336 r
F
.41602 .27543 m .4143 .25399 L .41828 .27641 L F
.4143 .25399 m .41344 .24318 L .41509 .25449 L F
.4143 .25399 m .41509 .25449 L .41828 .27641 L F
.41468 .25168 m .41501 .2623 L .41828 .27641 L .927 .546 .247 r
F
.41828 .27641 m .41501 .2623 L .41901 .25187 L .809 .605 .626 r
F
.42066 .25429 m .41901 .25187 L .42166 .24492 L F
.41828 .27641 m .41901 .25187 L .42066 .25429 L F
.41501 .2623 m .41725 .26419 L .41891 .25694 L 0 0 .338 r
F
.41501 .2623 m .41891 .25694 L .41743 .25599 L F
.41344 .24318 m .41378 .2474 L .41468 .25168 L .927 .546 .247 r
F
.41378 .2474 m .41501 .2623 L .41468 .25168 L F
.40661 .26554 m .40977 .24114 L .41344 .24318 L .93 .808 .346 r
F
.41344 .24318 m .40977 .24114 L .41281 .25343 L .927 .546 .247 r
F
.41437 .25453 m .41281 .25343 L .41501 .2623 L F
.41344 .24318 m .41281 .25343 L .41437 .25453 L F
.40977 .24114 m .41218 .23674 L .41501 .2623 L 0 0 .045 r
F
.40977 .24114 m .40885 .24628 L .41218 .23674 L F
.40885 .24628 m .40496 .26791 L .40974 .24726 L F
.40885 .24628 m .40974 .24726 L .41218 .23674 L F
.40895 .25071 m .40855 .23296 L .41218 .23674 L .997 .811 .458 r
F
.41218 .23674 m .40855 .23296 L .41262 .26025 L .953 .606 .296 r
F
.41326 .26199 m .41262 .26025 L .41341 .26551 L F
.41218 .23674 m .41262 .26025 L .41326 .26199 L F
.40855 .23296 m .41054 .23996 L .41158 .24927 L .085 0 .214 r
F
.40855 .23296 m .41158 .24927 L .41087 .24849 L F
.40688 .24925 m .40855 .23296 L .40895 .25071 L .997 .811 .458 r
F
.40496 .26791 m .40074 .27794 L .40855 .23296 L F
.40855 .23296 m .404 .25222 L .41054 .23996 L .085 0 .214 r
F
.40738 .24588 m .40743 .22173 L .41054 .23996 L 1 .817 .499 r
F
.404 .25222 m .40534 .24029 L .40738 .24588 L F
.40534 .24029 m .40743 .22173 L .40738 .24588 L F
.41087 .24849 m .41158 .24927 L .41341 .26551 L .085 0 .214 r
F
.40496 .26791 m .40688 .24925 L .40895 .25071 L .997 .811 .458 r
F
.41501 .2623 m .41218 .23674 L .41698 .26274 L 0 0 .338 r
F
.41704 .26402 m .41698 .26274 L .41725 .26419 L F
.41501 .2623 m .41698 .26274 L .41704 .26402 L F
.41631 .24885 m .41709 .22667 L .42102 .22182 L .696 .488 .602 r
F
.41347 .24376 m .41341 .26551 L .41725 .26419 L .953 .606 .296 r
F
.41341 .26551 m .41586 .23963 L .41631 .24885 L .696 .488 .602 r
F
.41586 .23963 m .41709 .22667 L .41631 .24885 L F
.41218 .23674 m .41241 .2422 L .41347 .24376 L .953 .606 .296 r
F
.41241 .2422 m .41341 .26551 L .41347 .24376 L F
.41743 .25599 m .41891 .25694 L .42166 .24492 L 0 0 .338 r
F
.42241 .26482 m .41828 .27641 L .42253 .25703 L .951 .835 .401 r
F
.42254 .26393 m .42253 .25703 L .42542 .24384 L F
.42241 .26482 m .42253 .25703 L .42254 .26393 L F
.41828 .27641 m .42166 .24492 L .42542 .24384 L .809 .605 .626 r
F
.42542 .24384 m .42166 .24492 L .42679 .27421 L .924 .57 .342 r
F
.42251 .24979 m .42382 .25002 L .42679 .27421 L .009 0 .187 r
F
.42186 .24603 m .42251 .24736 L .42251 .24979 L F
.42251 .24736 m .42382 .25002 L .42251 .24979 L F
.42166 .24492 m .42183 .24532 L .42186 .24603 L F
.42183 .24532 m .42382 .25002 L .42186 .24603 L F
.42241 .26482 m .42255 .26383 L .42247 .26486 L .951 .835 .401 r
F
.42021 .29272 m .41903 .29659 L .4207 .28664 L .977 .814 .403 r
F
.79681 .23656 m .80051 .23021 L .80329 .23433 L .664 .741 .908 r
F
.79681 .23656 m .79402 .23245 L .80051 .23021 L F
.22211 .23656 m .22398 .23022 L .22795 .23434 L F
.22211 .23656 m .21813 .23245 L .22398 .23022 L F
.60524 .23659 m .60834 .23022 L .61151 .23434 L .664 .741 .907 r
F
.60524 .23659 m .60206 .23247 L .60834 .23022 L F
.38615 .27549 m .38732 .29705 L .39151 .28881 L .475 .179 .383 r
F
.38615 .27549 m .38128 .29826 L .38732 .29705 L F
.70888 .23639 m .71231 .23004 L .71527 .23416 L .664 .741 .908 r
F
.70888 .23639 m .70591 .23227 L .71231 .23004 L F
.81254 .23621 m .8163 .22986 L .81904 .23398 L F
.81254 .23621 m .80979 .2321 L .8163 .22986 L F
.62094 .23621 m .62409 .22986 L .62723 .23398 L F
.62094 .23621 m .61779 .2321 L .62409 .22986 L F
.23775 .23622 m .23967 .22986 L .2436 .23398 L .664 .742 .908 r
F
.23775 .23622 m .2338 .23211 L .23967 .22986 L F
.47047 .28185 m .4674 .2555 L .47337 .26209 L .409 .281 .594 r
F
.46411 .29538 m .4674 .2555 L .47047 .28185 L .711 .501 .603 r
F
.46411 .29538 m .46104 .27025 L .4674 .2555 L F
.4674 .2555 m .47009 .24726 L .47337 .26209 L .482 .467 .765 r
F
.4674 .2555 m .46404 .24624 L .47009 .24726 L F
.46104 .27025 m .46404 .24624 L .4674 .2555 L .625 .459 .636 r
F
.14976 .23604 m .1514 .22969 L .15552 .23381 L .663 .741 .908 r
F
.14976 .23604 m .14563 .23192 L .1514 .22969 L F
.7246 .23604 m .72808 .22969 L .73101 .23382 L F
.7246 .23604 m .72167 .23192 L .72808 .22969 L F
.31998 .26984 m .31668 .25874 L .31347 .39588 L .971 .687 .433 r
F
.31668 .25874 m .31122 .36637 L .31347 .39588 L .97 .683 .429 r
F
.31668 .25874 m .31327 .24917 L .31122 .36637 L F
.46104 .27025 m .45788 .25093 L .46404 .24624 L .625 .459 .636 r
F
.45453 .29011 m .45788 .25093 L .46104 .27025 L .739 .527 .606 r
F
.45453 .29011 m .45145 .26753 L .45788 .25093 L F
.45788 .25093 m .46023 .25804 L .46404 .24624 L .539 .089 .131 r
F
.45145 .26753 m .45419 .25592 L .45788 .25093 L .309 .238 .613 r
F
.45788 .25093 m .45419 .25592 L .46023 .25804 L .539 .089 .131 r
F
.63665 .23587 m .63985 .22953 L .64296 .23365 L .663 .741 .908 r
F
.63665 .23587 m .63353 .23176 L .63985 .22953 L F
.25339 .23588 m .25535 .22954 L .25926 .23367 L .662 .741 .908 r
F
.25339 .23588 m .24947 .23176 L .25535 .22954 L F
.5582 .24028 m .56111 .23129 L .56438 .2354 L .751 .736 .839 r
F
.5582 .24028 m .55491 .23549 L .56111 .23129 L F
.55265 .31685 m .55491 .23549 L .5582 .24028 L .903 .642 .533 r
F
.5874 .45179 m .58829 .33433 L .59178 .35156 L .991 .732 .4 r
F
.5874 .45179 m .58439 .46533 L .58829 .33433 L F
.74033 .2357 m .74386 .22935 L .74675 .23347 L .663 .741 .908 r
F
.74033 .2357 m .73743 .23158 L .74386 .22935 L F
.16539 .2357 m .16707 .22936 L .17116 .23349 L F
.16539 .2357 m .16129 .23159 L .16707 .22936 L F
.4117 .31048 m .41465 .29111 L .4178 .30741 L .347 .227 .57 r
F
.32318 .28242 m .31998 .26984 L .31628 .41756 L .972 .69 .433 r
F
.31998 .26984 m .31347 .39588 L .31628 .41756 L .971 .687 .433 r
F
.33903 .41908 m .3367 .38969 L .34622 .32692 L .858 .607 .559 r
F
.34622 .32692 m .34568 .37087 L .35011 .36282 L .67 .372 .459 r
F
.34584 .32938 m .3406 .35557 L .34622 .32692 L .604 .416 .6 r
F
.3367 .38969 m .3406 .35557 L .34584 .32938 L F
.3406 .35557 m .33495 .38335 L .33524 .38238 L 0 0 .148 r
F
.34622 .32692 m .3406 .35557 L .34568 .37087 L .67 .372 .459 r
F
.3406 .35557 m .34233 .3591 L .34568 .37087 L 0 0 .148 r
F
.3406 .35557 m .33524 .38238 L .34233 .3591 L F
.26903 .23554 m .27105 .2292 L .27493 .23333 L .663 .741 .908 r
F
.26903 .23554 m .26515 .23143 L .27105 .2292 L F
.65236 .23555 m .65561 .22919 L .65869 .23331 L .664 .742 .908 r
F
.65236 .23555 m .64928 .23143 L .65561 .22919 L F
.30975 .24129 m .3069 .30679 L .30913 .33515 L .966 .667 .409 r
F
.30913 .33515 m .3069 .30679 L .30701 .30719 L .104 .047 .502 r
F
.31327 .24917 m .30913 .33515 L .31127 .36341 L .969 .677 .421 r
F
.31327 .24917 m .30975 .24129 L .30913 .33515 L F
.31127 .36341 m .30913 .33515 L .31122 .36637 L F
.31122 .36637 m .30913 .33515 L .31785 .29412 L .809 .566 .572 r
F
.30913 .33515 m .31174 .32307 L .31785 .29412 L .104 .047 .502 r
F
.30913 .33515 m .30701 .30719 L .31174 .32307 L F
.46404 .24624 m .46648 .25059 L .47009 .24726 L .117 0 .15 r
F
.46404 .24624 m .46023 .25804 L .46648 .25059 L F
.75606 .23536 m .75964 .229 L .7625 .23313 L .664 .741 .908 r
F
.75606 .23536 m .75319 .23124 L .75964 .229 L F
.18102 .23537 m .18276 .22901 L .18682 .23313 L F
.18102 .23537 m .17695 .23125 L .18276 .22901 L F
.56438 .2354 m .56735 .22901 L .57061 .23314 L .666 .743 .907 r
F
.56438 .2354 m .56111 .23129 L .56735 .22901 L F
.66808 .23519 m .67138 .22883 L .67442 .23295 L .664 .741 .908 r
F
.66808 .23519 m .66503 .23107 L .67138 .22883 L F
.28469 .23519 m .28676 .22883 L .2906 .23296 L .664 .742 .908 r
F
.28469 .23519 m .28084 .23108 L .28676 .22883 L F
.19666 .23501 m .19845 .22866 L .20247 .23279 L .663 .741 .908 r
F
.19666 .23501 m .19262 .23089 L .19845 .22866 L F
.58008 .23501 m .5831 .22866 L .58633 .23279 L F
.58008 .23501 m .57685 .23089 L .5831 .22866 L F
.7718 .23501 m .77543 .22865 L .77826 .23278 L .664 .741 .908 r
F
.7718 .23501 m .76896 .23089 L .77543 .22865 L F
.6838 .23484 m .68715 .22849 L .69017 .23262 L .663 .741 .908 r
F
.6838 .23484 m .68078 .23073 L .68715 .22849 L F
.30034 .23486 m .30236 .22994 L .3061 .23504 L .546 .699 .94 r
F
.30034 .23486 m .29652 .23074 L .30236 .22994 L F
.45145 .26753 m .44832 .24815 L .45419 .25592 L .309 .238 .613 r
F
.44465 .29672 m .44832 .24815 L .45145 .26753 L .849 .616 .585 r
F
.44465 .29672 m .44146 .27921 L .44832 .24815 L F
.44832 .24815 m .45018 .27223 L .45419 .25592 L .862 .491 .343 r
F
.44146 .27921 m .44458 .25281 L .44832 .24815 L .444 .291 .578 r
F
.44832 .24815 m .44458 .25281 L .45018 .27223 L .862 .491 .343 r
F
.78754 .23467 m .79122 .22832 L .79402 .23245 L .663 .741 .908 r
F
.78754 .23467 m .78473 .23055 L .79122 .22832 L F
.2123 .23468 m .21414 .22832 L .21813 .23245 L .664 .741 .908 r
F
.2123 .23468 m .2083 .23056 L .21414 .22832 L F
.59579 .23468 m .59886 .22833 L .60206 .23247 L .663 .741 .908 r
F
.59579 .23468 m .59259 .23056 L .59886 .22833 L F
.31628 .41756 m .31347 .39588 L .32888 .24974 L .929 .667 .519 r
F
.31347 .39588 m .32369 .26758 L .32888 .24974 L .895 .636 .538 r
F
.32888 .24974 m .32369 .26758 L .32739 .30192 L .822 .507 .457 r
F
.69953 .2345 m .70293 .22814 L .70591 .23227 L .664 .742 .908 r
F
.69953 .2345 m .69654 .23039 L .70293 .22814 L F
.80329 .23433 m .80702 .22797 L .80979 .2321 L .663 .741 .908 r
F
.80329 .23433 m .80051 .23021 L .80702 .22797 L F
.22795 .23434 m .22984 .22798 L .2338 .23211 L F
.22795 .23434 m .22398 .23022 L .22984 .22798 L F
.61151 .23434 m .61463 .22797 L .61779 .2321 L .665 .742 .908 r
F
.61151 .23434 m .60834 .23022 L .61463 .22797 L F
.71527 .23416 m .71872 .22779 L .72167 .23192 L .664 .741 .908 r
F
.71527 .23416 m .71231 .23004 L .71872 .22779 L F
.2436 .23398 m .24554 .22763 L .24947 .23176 L .663 .741 .908 r
F
.2436 .23398 m .23967 .22986 L .24554 .22763 L F
.62723 .23398 m .6304 .22763 L .63353 .23176 L F
.62723 .23398 m .62409 .22986 L .6304 .22763 L F
.50828 .26203 m .50471 .28594 L .51092 .28802 L .54 .244 .414 r
F
.15552 .23381 m .15717 .22745 L .16129 .23159 L .663 .741 .908 r
F
.15552 .23381 m .1514 .22969 L .15717 .22745 L F
.73101 .23382 m .73451 .22745 L .73743 .23158 L .664 .741 .908 r
F
.73101 .23382 m .72808 .22969 L .73451 .22745 L F
.30975 .24129 m .3061 .23504 L .3069 .30679 L .966 .667 .409 r
F
.48356 .28496 m .47994 .29306 L .48615 .28798 L .124 0 .062 r
F
.47742 .29262 m .47994 .29306 L .48356 .28496 L 0 0 0 r
F
.47994 .29306 m .48256 .29363 L .48615 .28798 L 0 0 .563 r
F
.47994 .29306 m .47656 .28352 L .48249 .29351 L F
.47994 .29306 m .48249 .29351 L .48256 .29363 L F
.47735 .29272 m .47994 .29306 L .47742 .29262 L 0 0 0 r
F
.64296 .23365 m .64618 .2273 L .64928 .23143 L .663 .741 .908 r
F
.64296 .23365 m .63985 .22953 L .64618 .2273 L F
.25926 .23367 m .26125 .2273 L .26515 .23143 L .664 .741 .908 r
F
.25926 .23367 m .25535 .22954 L .26125 .2273 L F
.74675 .23347 m .75031 .22711 L .75319 .23124 L .663 .741 .908 r
F
.74675 .23347 m .74386 .22935 L .75031 .22711 L F
.17116 .23349 m .17287 .22712 L .17695 .23125 L .664 .741 .908 r
F
.17116 .23349 m .16707 .22936 L .17287 .22712 L F
.65869 .23331 m .66196 .22693 L .66503 .23107 L .664 .742 .908 r
F
.65869 .23331 m .65561 .22919 L .66196 .22693 L F
.27493 .23333 m .27697 .22694 L .28084 .23108 L .664 .741 .907 r
F
.27493 .23333 m .27105 .2292 L .27697 .22694 L F
.7625 .23313 m .76611 .22676 L .76896 .23089 L .664 .741 .908 r
F
.7625 .23313 m .75964 .229 L .76611 .22676 L F
.18682 .23313 m .18857 .22676 L .19262 .23089 L F
.18682 .23313 m .18276 .22901 L .18857 .22676 L F
.57061 .23314 m .5736 .22676 L .57685 .23089 L F
.57061 .23314 m .56735 .22901 L .5736 .22676 L F
.67442 .23295 m .67775 .22659 L .68078 .23073 L .663 .741 .908 r
F
.67442 .23295 m .67138 .22883 L .67775 .22659 L F
.2906 .23296 m .29269 .2266 L .29652 .23074 L F
.2906 .23296 m .28676 .22883 L .29269 .2266 L F
.77826 .23278 m .78192 .22642 L .78473 .23055 L F
.77826 .23278 m .77543 .22865 L .78192 .22642 L F
.20247 .23279 m .20428 .22642 L .2083 .23056 L F
.20247 .23279 m .19845 .22866 L .20428 .22642 L F
.58633 .23279 m .58937 .22642 L .59259 .23056 L F
.58633 .23279 m .5831 .22866 L .58937 .22642 L F
.69017 .23262 m .69354 .22625 L .69654 .23039 L F
.69017 .23262 m .68715 .22849 L .69354 .22625 L F
.79402 .23245 m .79773 .22607 L .80051 .23021 L .664 .741 .908 r
F
.79402 .23245 m .79122 .22832 L .79773 .22607 L F
.21813 .23245 m .21999 .22607 L .22398 .23022 L F
.21813 .23245 m .21414 .22832 L .21999 .22607 L F
.60206 .23247 m .60515 .22609 L .60834 .23022 L F
.60206 .23247 m .59886 .22833 L .60515 .22609 L F
.47735 .29272 m .47371 .29988 L .47994 .29306 L 0 0 0 r
F
.70591 .23227 m .70934 .2259 L .71231 .23004 L .664 .741 .908 r
F
.70591 .23227 m .70293 .22814 L .70934 .2259 L F
.44146 .27921 m .43869 .24713 L .44458 .25281 L .444 .291 .578 r
F
.4354 .27891 m .43869 .24713 L .44146 .27921 L .998 .815 .465 r
F
.4354 .27891 m .43147 .28736 L .43869 .24713 L F
.43869 .24713 m .4405 .26861 L .44458 .25281 L .945 .59 .202 r
F
.43147 .28736 m .43522 .24089 L .43869 .24713 L .824 .594 .592 r
F
.43869 .24713 m .43522 .24089 L .4405 .26861 L .945 .59 .202 r
F
.39067 .26951 m .38818 .23938 L .39387 .24533 L .425 .279 .578 r
F
.3844 .27621 m .38818 .23938 L .39067 .26951 L .625 .429 .596 r
F
.3844 .27621 m .38191 .2469 L .38818 .23938 L F
.38818 .23938 m .39051 .2347 L .39387 .24533 L .791 .99 .75 r
F
.38818 .23938 m .38426 .24136 L .39051 .2347 L F
.38191 .2469 m .38426 .24136 L .38818 .23938 L .457 .55 .862 r
F
.55265 .31685 m .54916 .29671 L .55491 .23549 L .903 .642 .533 r
F
.55491 .23549 m .55783 .22716 L .56111 .23129 L .732 .737 .856 r
F
.55491 .23549 m .55161 .23083 L .55783 .22716 L F
.54916 .29671 m .55161 .23083 L .55491 .23549 L .893 .639 .548 r
F
.61779 .2321 m .62093 .22572 L .62409 .22986 L .664 .741 .908 r
F
.61779 .2321 m .61463 .22797 L .62093 .22572 L F
.80979 .2321 m .81355 .22572 L .8163 .22986 L F
.80979 .2321 m .80702 .22797 L .81355 .22572 L F
.2338 .23211 m .23571 .22572 L .23967 .22986 L .664 .742 .908 r
F
.2338 .23211 m .22984 .22798 L .23571 .22572 L F
.52682 .24913 m .52347 .23754 L .52963 .24606 L .072 .156 .647 r
F
.52682 .24913 m .52963 .24606 L .52965 .24616 L F
.52061 .27201 m .52347 .23754 L .52682 .24913 L .647 .453 .606 r
F
.52347 .23754 m .52631 .22993 L .52968 .24613 L .752 .834 .376 r
F
.5302 .27593 m .52682 .24913 L .53309 .27374 L 0 0 .463 r
F
.52397 .30321 m .52682 .24913 L .5302 .27593 L .737 .509 .583 r
F
.52397 .30321 m .52061 .27201 L .52682 .24913 L F
.52682 .24913 m .52968 .24613 L .53309 .27374 L .072 .156 .647 r
F
.52738 .32552 m .5302 .27593 L .53363 .30907 L .805 .573 .587 r
F
.52738 .32552 m .52397 .30321 L .5302 .27593 L F
.53077 .33016 m .52738 .32552 L .53363 .30907 L .923 .755 .656 r
F
.52649 .23474 m .52939 .38693 L .53297 .40576 L .968 .665 .393 r
F
.52631 .22993 m .5264 .2344 L .52649 .23474 L F
.5264 .2344 m .52939 .38693 L .52649 .23474 L F
.52965 .24616 m .52963 .24606 L .52968 .24613 L .072 .156 .647 r
F
.52061 .27201 m .51728 .24599 L .52347 .23754 L .647 .453 .606 r
F
.52033 .24182 m .52009 .24401 L .52347 .23754 L .038 .196 .7 r
F
.51728 .24599 m .52009 .24401 L .52033 .24182 L F
.51427 .3135 m .51728 .24599 L .52061 .27201 L .841 .592 .563 r
F
.52009 .24401 m .51664 .26483 L .51985 .24622 L 0 0 0 r
F
.52347 .23754 m .52009 .24401 L .52631 .22993 L .752 .834 .376 r
F
.52009 .24401 m .52294 .22833 L .52631 .22993 L 0 0 0 r
F
.52009 .24401 m .51985 .24622 L .52294 .22833 L F
.72167 .23192 m .72514 .22555 L .72808 .22969 L .663 .741 .908 r
F
.72167 .23192 m .71872 .22779 L .72514 .22555 L F
.63353 .23176 m .63672 .22538 L .63985 .22953 L F
.63353 .23176 m .6304 .22763 L .63672 .22538 L F
.24947 .23176 m .25143 .2254 L .25535 .22954 L .662 .741 .908 r
F
.24947 .23176 m .24554 .22763 L .25143 .2254 L F
.73743 .23158 m .74095 .22521 L .74386 .22935 L .663 .741 .908 r
F
.73743 .23158 m .73451 .22745 L .74095 .22521 L F
.16129 .23159 m .16297 .22522 L .16707 .22936 L F
.16129 .23159 m .15717 .22745 L .16297 .22522 L F
.59024 .43237 m .59178 .35156 L .5953 .36962 L .984 .75 .352 r
F
.59024 .43237 m .5874 .45179 L .59178 .35156 L F
.26515 .23143 m .26716 .22505 L .27105 .2292 L .663 .741 .908 r
F
.26515 .23143 m .26125 .2273 L .26716 .22505 L F
.64928 .23143 m .65252 .22504 L .65561 .22919 L .664 .741 .908 r
F
.64928 .23143 m .64618 .2273 L .65252 .22504 L F
.75319 .23124 m .75677 .22486 L .75964 .229 L .664 .742 .908 r
F
.75319 .23124 m .75031 .22711 L .75677 .22486 L F
.17695 .23125 m .17868 .22486 L .18276 .22901 L .664 .741 .908 r
F
.17695 .23125 m .17287 .22712 L .17868 .22486 L F
.56111 .23129 m .56407 .22486 L .56735 .22901 L .667 .743 .907 r
F
.56111 .23129 m .55783 .22716 L .56407 .22486 L F
.4487 .28023 m .45145 .26753 L .45453 .29011 L .732 .722 .196 r
F
.4487 .28023 m .44465 .29672 L .45145 .26753 L F
.66503 .23107 m .66832 .22468 L .67138 .22883 L .664 .741 .908 r
F
.66503 .23107 m .66196 .22693 L .66832 .22468 L F
.28084 .23108 m .2829 .22468 L .28676 .22883 L .664 .742 .908 r
F
.28084 .23108 m .27697 .22694 L .2829 .22468 L F
.3061 .23504 m .30436 .28338 L .3069 .30679 L .963 .654 .39 r
F
.3061 .23504 m .30236 .22994 L .30436 .28338 L F
.47337 .26209 m .47009 .24726 L .47611 .25247 L .347 .3 .663 r
F
.47009 .24726 m .47279 .23921 L .47611 .25247 L .899 .953 .609 r
F
.47009 .24726 m .46648 .25059 L .47279 .23921 L F
.37741 .29819 m .38191 .2469 L .3844 .27621 L .758 .531 .588 r
F
.37741 .29819 m .37484 .2707 L .38191 .2469 L F
.38191 .2469 m .37835 .24072 L .38426 .24136 L .457 .55 .862 r
F
.37484 .2707 m .37835 .24072 L .38191 .2469 L .573 .394 .602 r
F
.19262 .23089 m .1944 .22451 L .19845 .22866 L .663 .741 .908 r
F
.19262 .23089 m .18857 .22676 L .1944 .22451 L F
.76896 .23089 m .77259 .22451 L .77543 .22865 L .664 .741 .908 r
F
.76896 .23089 m .76611 .22676 L .77259 .22451 L F
.57685 .23089 m .57986 .22452 L .5831 .22866 L .663 .741 .908 r
F
.57685 .23089 m .5736 .22676 L .57986 .22452 L F
.68078 .23073 m .68413 .22435 L .68715 .22849 L F
.68078 .23073 m .67775 .22659 L .68413 .22435 L F
.29652 .23074 m .29856 .22541 L .30236 .22994 L .583 .714 .933 r
F
.29652 .23074 m .29269 .2266 L .29856 .22541 L F
.78473 .23055 m .78842 .22417 L .79122 .22832 L .664 .741 .908 r
F
.78473 .23055 m .78192 .22642 L .78842 .22417 L F
.2083 .23056 m .21013 .22417 L .21414 .22832 L F
.2083 .23056 m .20428 .22642 L .21013 .22417 L F
.59259 .23056 m .59565 .22418 L .59886 .22833 L .663 .741 .908 r
F
.59259 .23056 m .58937 .22642 L .59565 .22418 L F
.69654 .23039 m .69994 .224 L .70293 .22814 L .664 .742 .908 r
F
.69654 .23039 m .69354 .22625 L .69994 .224 L F
.45813 .29007 m .46104 .27025 L .46411 .29538 L .983 .83 .615 r
F
.45813 .29007 m .45453 .29011 L .46104 .27025 L F
.80051 .23021 m .80425 .22382 L .80702 .22797 L .663 .741 .908 r
F
.80051 .23021 m .79773 .22607 L .80425 .22382 L F
.22398 .23022 m .22586 .22383 L .22984 .22798 L F
.22398 .23022 m .21999 .22607 L .22586 .22383 L F
.60834 .23022 m .61145 .22382 L .61463 .22797 L .665 .742 .908 r
F
.60834 .23022 m .60515 .22609 L .61145 .22382 L F
.51427 .3135 m .51092 .28802 L .51728 .24599 L .841 .592 .563 r
F
.51728 .24599 m .51392 .23728 L .52009 .24401 L .038 .196 .7 r
F
.51092 .28802 m .51392 .23728 L .51728 .24599 L .713 .49 .586 r
F
.48615 .28798 m .48608 .28809 L .48898 .27383 L .955 .887 .493 r
F
.48608 .28809 m .48256 .29363 L .48459 .28737 L F
.48608 .28809 m .48459 .28737 L .48898 .27383 L F
.48256 .29363 m .48525 .29158 L .48898 .27383 L 0 .009 .539 r
F
.48256 .29363 m .4806 .28436 L .48181 .28379 L F
.48304 .29327 m .48181 .28379 L .48525 .29158 L F
.48256 .29363 m .48181 .28379 L .48304 .29327 L F
.4806 .28436 m .47925 .27798 L .48141 .28288 L F
.4806 .28436 m .48141 .28288 L .48181 .28379 L F
.47925 .27798 m .48162 .28592 L .48306 .28662 L 0 0 .263 r
F
.48162 .28592 m .48177 .28644 L .48306 .28662 L F
.48306 .28662 m .48177 .28644 L .48525 .29158 L F
.48525 .29158 m .48177 .28644 L .48606 .26763 L .945 .731 .582 r
F
.48744 .26749 m .48606 .26763 L .48833 .25766 L F
.48525 .29158 m .48606 .26763 L .48744 .26749 L F
.48177 .28644 m .48453 .27952 L .48512 .27614 L .034 .01 .494 r
F
.48341 .27925 m .48512 .27614 L .48833 .25766 L F
.48177 .28644 m .48512 .27614 L .48341 .27925 L F
.47925 .27798 m .47611 .25247 L .48176 .2864 L 0 0 .263 r
F
.48177 .28643 m .48176 .2864 L .48177 .28644 L F
.47925 .27798 m .48176 .2864 L .48177 .28643 L F
.47611 .25247 m .47279 .23921 L .47862 .25858 L 0 0 .294 r
F
.47279 .23921 m .47551 .23099 L .47862 .25858 L .733 .791 .306 r
F
.47611 .25247 m .47862 .25858 L .48177 .28644 L 0 0 .294 r
F
.4789 .26172 m .47773 .25229 L .48089 .28417 L .766 .553 0 r
F
.47773 .25229 m .47781 .25373 L .48089 .28417 L F
.47875 .26007 m .47831 .25664 L .4789 .26172 L F
.47831 .25664 m .47736 .24923 L .4789 .26172 L F
.48177 .28644 m .47862 .25858 L .48399 .27759 L .034 .01 .494 r
F
.48403 .28078 m .48399 .27759 L .48453 .27952 L F
.48177 .28644 m .48399 .27759 L .48403 .28078 L F
.48376 .26007 m .48421 .23696 L .48788 .22544 L .804 .574 .59 r
F
.48131 .26809 m .48089 .28417 L .48453 .27952 L .766 .553 0 r
F
.48089 .28417 m .48358 .24593 L .48376 .26007 L .804 .574 .59 r
F
.48358 .24593 m .48421 .23696 L .48376 .26007 L F
.47862 .25858 m .47948 .26827 L .48131 .26809 L .766 .553 0 r
F
.47862 .25858 m .47736 .24923 L .47875 .26007 L F
.47551 .23099 m .47762 .26268 L .48089 .28417 L .954 .606 .282 r
F
.47948 .26827 m .48089 .28417 L .48131 .26809 L .766 .553 0 r
F
.48089 .28417 m .47762 .26268 L .48302 .24159 L .804 .574 .59 r
F
.48384 .24217 m .48302 .24159 L .48421 .23696 L F
.48089 .28417 m .48302 .24159 L .48384 .24217 L F
.47818 .26052 m .48031 .26048 L .48421 .23696 L 0 0 .412 r
F
.47762 .26268 m .47827 .26216 L .47818 .26052 L F
.47827 .26216 m .48031 .26048 L .47818 .26052 L F
.47773 .25229 m .47736 .24923 L .47781 .25373 L .766 .553 0 r
F
.47862 .25858 m .47551 .23099 L .47736 .24923 L F
.47656 .28352 m .47337 .26209 L .47925 .27798 L .045 .043 .53 r
F
.47337 .26209 m .47611 .25247 L .47925 .27798 L .347 .3 .663 r
F
.47074 .2429 m .46908 .24826 L .47279 .23921 L 0 0 0 r
F
.46648 .25059 m .46856 .24872 L .46934 .24544 L F
.46648 .25059 m .46262 .26461 L .46908 .24826 L F
.46262 .26461 m .46513 .26658 L .46908 .24826 L .105 0 0 r
F
.46739 .25369 m .46806 .2484 L .47202 .2272 L .995 .869 .561 r
F
.46513 .26658 m .46682 .2561 L .46739 .25369 L F
.46682 .2561 m .46806 .2484 L .46739 .25369 L F
.46934 .24544 m .46908 .24826 L .47074 .2429 L 0 0 0 r
F
.46856 .24872 m .46908 .24826 L .46934 .24544 L F
.46908 .24826 m .46513 .26658 L .46739 .25369 L .842 .758 .245 r
F
.46908 .24826 m .46739 .25369 L .47202 .2272 L F
.47279 .23921 m .47134 .24275 L .47551 .23099 L .733 .791 .306 r
F
.47134 .24275 m .46908 .24826 L .47211 .24012 L F
.47134 .24275 m .47211 .24012 L .47551 .23099 L F
.46908 .24826 m .47202 .2272 L .47551 .23099 L .842 .758 .245 r
F
.47551 .23099 m .47202 .2272 L .47602 .25255 L .954 .606 .282 r
F
.47202 .2272 m .47455 .23075 L .47462 .23151 L 0 0 .191 r
F
.47202 .2272 m .47462 .23151 L .47338 .23578 L F
.47202 .2272 m .46806 .2484 L .47455 .23075 L F
.47113 .24005 m .47126 .21404 L .47455 .23075 L .915 .77 .285 r
F
.46806 .2484 m .46928 .23531 L .47113 .24005 L F
.46928 .23531 m .47126 .21404 L .47113 .24005 L F
.47714 .25539 m .47602 .25255 L .47762 .26268 L .954 .606 .282 r
F
.47551 .23099 m .47602 .25255 L .47714 .25539 L F
.47338 .23578 m .47462 .23151 L .47762 .26268 L 0 0 .191 r
F
.47762 .26268 m .47455 .23075 L .48031 .26048 L 0 0 .412 r
F
.47565 .23641 m .47649 .27422 L .48031 .26048 L .951 .656 .214 r
F
.47455 .23075 m .47478 .2358 L .47565 .23641 L F
.47478 .2358 m .47649 .27422 L .47565 .23641 L F
.48898 .27383 m .48637 .28624 L .492 .24207 L .931 .783 .312 r
F
.48637 .28624 m .48686 .27972 L .492 .24207 L F
.48525 .29158 m .48833 .25766 L .492 .24207 L .945 .731 .582 r
F
.492 .24207 m .48833 .25766 L .4944 .27012 L .705 .369 .406 r
F
.48851 .25801 m .49123 .2386 L .4944 .27012 L .746 .694 .152 r
F
.48833 .25766 m .48874 .25501 L .48851 .25801 L F
.48874 .25501 m .49123 .2386 L .48851 .25801 L F
.48637 .28624 m .48525 .29158 L .48686 .27972 L .931 .783 .312 r
F
.71231 .23004 m .71576 .22364 L .71872 .22779 L .664 .741 .908 r
F
.71231 .23004 m .70934 .2259 L .71576 .22364 L F
.37484 .2707 m .37229 .24361 L .37835 .24072 L .573 .394 .602 r
F
.36769 .29468 m .37229 .24361 L .37484 .2707 L .911 .677 .57 r
F
.36769 .29468 m .3643 .28408 L .37229 .24361 L F
.37229 .24361 m .37349 .26074 L .37835 .24072 L .908 .517 .258 r
F
.37229 .24361 m .36844 .24289 L .37349 .26074 L F
.35526 .34056 m .35011 .36282 L .357 .34508 L 0 0 .165 r
F
.23967 .22986 m .2416 .22348 L .24554 .22763 L .663 .741 .908 r
F
.23967 .22986 m .23571 .22572 L .2416 .22348 L F
.62409 .22986 m .62725 .22348 L .6304 .22763 L F
.62409 .22986 m .62093 .22572 L .62725 .22348 L F
.72808 .22969 m .73158 .2233 L .73451 .22745 L .664 .741 .908 r
F
.72808 .22969 m .72514 .22555 L .73158 .2233 L F
.63985 .22953 m .64306 .22314 L .64618 .2273 L .663 .741 .908 r
F
.63985 .22953 m .63672 .22538 L .64306 .22314 L F
.43147 .28736 m .42835 .26822 L .43351 .24765 L .824 .594 .592 r
F
.43465 .2479 m .43351 .24765 L .43522 .24089 L F
.43147 .28736 m .43351 .24765 L .43465 .2479 L F
.42835 .26822 m .43086 .26326 L .43296 .25249 L 0 0 .476 r
F
.43068 .25893 m .43296 .25249 L .43522 .24089 L F
.42835 .26822 m .43296 .25249 L .43068 .25893 L F
.43522 .24089 m .43686 .26651 L .4405 .26861 L .554 .248 .404 r
F
.43522 .24089 m .43086 .26326 L .43686 .26651 L F
.43382 .24376 m .43649 .23426 L .43986 .23294 L .303 .262 .646 r
F
.43944 .23414 m .43986 .23294 L .44022 .2328 L F
.43382 .24376 m .43986 .23294 L .43944 .23414 L F
.42835 .26822 m .42652 .25305 L .43086 .26326 L 0 0 .476 r
F
.42652 .25305 m .42542 .24384 L .42702 .24956 L F
.42652 .25305 m .42702 .24956 L .43086 .26326 L F
.42542 .24384 m .42551 .24593 L .42604 .24605 L .924 .57 .342 r
F
.42382 .25002 m .42662 .23595 L .4299 .22947 L .214 .132 .542 r
F
.42967 .2311 m .4299 .22947 L .43059 .2281 L F
.42382 .25002 m .4299 .22947 L .42967 .2311 L F
.42604 .24605 m .42679 .27421 L .43086 .26326 L .924 .57 .342 r
F
.42551 .24593 m .42679 .27421 L .42604 .24605 L F
.25535 .22954 m .25734 .22315 L .26125 .2273 L .664 .741 .908 r
F
.25535 .22954 m .25143 .2254 L .25734 .22315 L F
.74386 .22935 m .74741 .22296 L .75031 .22711 L .663 .741 .908 r
F
.74386 .22935 m .74095 .22521 L .74741 .22296 L F
.16707 .22936 m .16877 .22296 L .17287 .22712 L .664 .741 .908 r
F
.16707 .22936 m .16297 .22522 L .16877 .22296 L F
.65561 .22919 m .65888 .22278 L .66196 .22693 L .664 .742 .908 r
F
.65561 .22919 m .65252 .22504 L .65888 .22278 L F
.27105 .2292 m .27308 .22279 L .27697 .22694 L .664 .741 .908 r
F
.27105 .2292 m .26716 .22505 L .27308 .22279 L F
.51092 .28802 m .50765 .2564 L .51392 .23728 L .713 .49 .586 r
F
.51045 .24983 m .5131 .29108 L .51664 .26483 L .672 .365 .444 r
F
.51664 .26483 m .5131 .29108 L .51367 .28669 L .731 .666 .114 r
F
.51392 .23728 m .51664 .26483 L .51955 .24342 L .752 .403 .392 r
F
.51392 .23728 m .51045 .24983 L .51664 .26483 L F
.51664 .26483 m .51367 .28669 L .51671 .26325 L .731 .666 .114 r
F
.52112 .30289 m .52397 .30321 L .52738 .32552 L 0 0 .131 r
F
.52112 .30289 m .51769 .31894 L .52397 .30321 L F
.51769 .31894 m .52061 .27201 L .52397 .30321 L .955 .719 .542 r
F
.51769 .31894 m .51427 .3135 L .52061 .27201 L F
.5131 .29108 m .51603 .26661 L .51953 .24147 L .818 .728 .199 r
F
.51603 .26661 m .51243 .2985 L .51883 .30814 L .61 .315 .444 r
F
.51883 .30814 m .51537 .28264 L .51543 .28191 L .903 .635 .522 r
F
.5205 .31543 m .51883 .30814 L .52226 .33462 L .61 .315 .444 r
F
.51607 .26705 m .51837 .30136 L .5205 .31543 L F
.51837 .30136 m .51883 .30814 L .5205 .31543 L F
.51603 .26661 m .51607 .2671 L .51607 .26705 L F
.51607 .2671 m .51883 .30814 L .51607 .26705 L F
.51721 .26022 m .51671 .26325 L .51953 .24147 L .731 .666 .114 r
F
.51664 .26483 m .51671 .26325 L .51721 .26022 L F
.51955 .24342 m .51664 .26483 L .52009 .24401 L .752 .403 .392 r
F
.51664 .26483 m .51953 .24147 L .52294 .22833 L .731 .666 .114 r
F
.51953 .24147 m .51603 .26661 L .52232 .33527 L .869 .554 .452 r
F
.50471 .28594 m .50765 .2564 L .51092 .28802 L .904 .771 .281 r
F
.51045 .24983 m .50686 .27622 L .5131 .29108 L .672 .365 .444 r
F
.50686 .27622 m .5095 .31194 L .5131 .29108 L .65 .339 .432 r
F
.5131 .29108 m .5095 .31194 L .51603 .26661 L .818 .728 .199 r
F
.5095 .31194 m .51243 .2985 L .51603 .26661 L .917 .875 .446 r
F
.51543 .28191 m .51846 .19983 L .52188 .20491 L .891 .63 .536 r
F
.51537 .28264 m .51541 .28173 L .51543 .28191 L F
.51541 .28173 m .51846 .19983 L .51543 .28191 L F
.52294 .22833 m .51953 .24147 L .52584 .36238 L .939 .629 .425 r
F
.51953 .24147 m .52232 .33527 L .52584 .36238 L .869 .554 .452 r
F
.51883 .30814 m .51543 .28191 L .52188 .20491 L .903 .635 .522 r
F
.52226 .33462 m .51883 .30814 L .52232 .33527 L .61 .315 .444 r
F
.50765 .2564 m .51045 .24983 L .51392 .23728 L .1 .083 .55 r
F
.75964 .229 m .76324 .2226 L .76611 .22676 L .664 .741 .908 r
F
.75964 .229 m .75677 .22486 L .76324 .2226 L F
.18276 .22901 m .18451 .2226 L .18857 .22676 L F
.18276 .22901 m .17868 .22486 L .18451 .2226 L F
.56735 .22901 m .57033 .2226 L .5736 .22676 L F
.56735 .22901 m .56407 .22486 L .57033 .2226 L F
.67138 .22883 m .6747 .22244 L .67775 .22659 L .663 .741 .908 r
F
.67138 .22883 m .66832 .22468 L .6747 .22244 L F
.28676 .22883 m .28884 .22245 L .29269 .2266 L .662 .741 .908 r
F
.28676 .22883 m .2829 .22468 L .28884 .22245 L F
.77543 .22865 m .77908 .22226 L .78192 .22642 L .663 .741 .908 r
F
.77543 .22865 m .77259 .22451 L .77908 .22226 L F
.19845 .22866 m .20024 .22227 L .20428 .22642 L F
.19845 .22866 m .1944 .22451 L .20024 .22227 L F
.5831 .22866 m .58614 .22227 L .58937 .22642 L F
.5831 .22866 m .57986 .22452 L .58614 .22227 L F
.68715 .22849 m .69053 .2221 L .69354 .22625 L F
.68715 .22849 m .68413 .22435 L .69053 .2221 L F
.54916 .29671 m .5457 .27862 L .55161 .23083 L .893 .639 .548 r
F
.55161 .23083 m .55453 .22301 L .55783 .22716 L .712 .734 .868 r
F
.55161 .23083 m .5483 .22622 L .55453 .22301 L F
.5457 .27862 m .5483 .22622 L .55161 .23083 L .879 .636 .567 r
F
.79122 .22832 m .79493 .22191 L .79773 .22607 L .664 .741 .908 r
F
.79122 .22832 m .78842 .22417 L .79493 .22191 L F
.21414 .22832 m .21599 .22192 L .21999 .22607 L F
.21414 .22832 m .21013 .22417 L .21599 .22192 L F
.59886 .22833 m .60195 .22193 L .60515 .22609 L .663 .741 .908 r
F
.59886 .22833 m .59565 .22418 L .60195 .22193 L F
.47047 .28185 m .47337 .26209 L .47656 .28352 L .409 .281 .594 r
F
.37835 .24072 m .37909 .26896 L .38426 .24136 L .631 .311 .412 r
F
.37835 .24072 m .37349 .26074 L .37909 .26896 L F
.70293 .22814 m .70636 .22174 L .70934 .2259 L .664 .741 .908 r
F
.70293 .22814 m .69994 .224 L .70636 .22174 L F
.61463 .22797 m .61777 .22156 L .62093 .22572 L .664 .742 .908 r
F
.61463 .22797 m .61145 .22382 L .61777 .22156 L F
.80702 .22797 m .81078 .22156 L .81355 .22572 L .664 .741 .908 r
F
.80702 .22797 m .80425 .22382 L .81078 .22156 L F
.22984 .22798 m .23174 .22156 L .23571 .22572 L F
.22984 .22798 m .22586 .22383 L .23174 .22156 L F
.71872 .22779 m .72219 .22139 L .72514 .22555 L F
.71872 .22779 m .71576 .22364 L .72219 .22139 L F
.24554 .22763 m .24749 .22124 L .25143 .2254 L .662 .741 .908 r
F
.24554 .22763 m .2416 .22348 L .24749 .22124 L F
.6304 .22763 m .63359 .22123 L .63672 .22538 L .663 .741 .908 r
F
.6304 .22763 m .62725 .22348 L .63359 .22123 L F
.30236 .22994 m .30151 .26473 L .30436 .28338 L .959 .636 .359 r
F
.30236 .22994 m .29856 .22541 L .30151 .26473 L F
.73451 .22745 m .73804 .22105 L .74095 .22521 L .663 .741 .908 r
F
.73451 .22745 m .73158 .2233 L .73804 .22105 L F
.50765 .2564 m .50435 .23498 L .51045 .24983 L .1 .083 .55 r
F
.5011 .30423 m .50435 .23498 L .50765 .2564 L .962 .709 .508 r
F
.5011 .30423 m .49764 .29861 L .50435 .23498 L F
.50435 .23498 m .50686 .27622 L .51045 .24983 L .953 .613 .323 r
F
.50435 .23498 m .50092 .23311 L .50686 .27622 L F
.26125 .2273 m .26325 .22089 L .26716 .22505 L .664 .741 .908 r
F
.26125 .2273 m .25734 .22315 L .26325 .22089 L F
.64618 .2273 m .64942 .22088 L .65252 .22504 L F
.64618 .2273 m .64306 .22314 L .64942 .22088 L F
.75031 .22711 m .75388 .22069 L .75677 .22486 L .664 .742 .908 r
F
.75031 .22711 m .74741 .22296 L .75388 .22069 L F
.17287 .22712 m .17459 .2207 L .17868 .22486 L .664 .741 .908 r
F
.17287 .22712 m .16877 .22296 L .17459 .2207 L F
.55783 .22716 m .56079 .2207 L .56407 .22486 L .667 .742 .907 r
F
.55783 .22716 m .55453 .22301 L .56079 .2207 L F
.66196 .22693 m .66525 .22052 L .66832 .22468 L .664 .742 .908 r
F
.66196 .22693 m .65888 .22278 L .66525 .22052 L F
.27697 .22694 m .27902 .22052 L .2829 .22468 L F
.27697 .22694 m .27308 .22279 L .27902 .22052 L F
.59296 .40953 m .59024 .43237 L .5953 .36962 L .881 .729 .216 r
F
.18857 .22676 m .19034 .22035 L .1944 .22451 L .663 .741 .908 r
F
.18857 .22676 m .18451 .2226 L .19034 .22035 L F
.76611 .22676 m .76974 .22035 L .77259 .22451 L F
.76611 .22676 m .76324 .2226 L .76974 .22035 L F
.5736 .22676 m .5766 .22035 L .57986 .22452 L F
.5736 .22676 m .57033 .2226 L .5766 .22035 L F
.67775 .22659 m .68109 .22019 L .68413 .22435 L F
.67775 .22659 m .6747 .22244 L .68109 .22019 L F
.28884 .22245 m .29089 .21653 L .29473 .22099 L .627 .73 .921 r
F
.29473 .22099 m .29089 .21653 L .2909 .21655 L .935 .558 .214 r
F
.29269 .2266 m .29473 .22099 L .29855 .22541 L .605 .722 .927 r
F
.29269 .2266 m .28884 .22245 L .29473 .22099 L F
.29473 .22099 m .2909 .21655 L .29524 .236 L .935 .558 .214 r
F
.29855 .22541 m .29473 .22099 L .29856 .22541 L .605 .722 .927 r
F
.32945 .40681 m .33816 .29373 L .34 .33004 L .987 .743 .474 r
F
.32945 .40681 m .32435 .42248 L .33816 .29373 L F
.78192 .22642 m .78559 .22 L .78842 .22417 L .664 .741 .908 r
F
.78192 .22642 m .77908 .22226 L .78559 .22 L F
.20428 .22642 m .2061 .22001 L .21013 .22417 L F
.20428 .22642 m .20024 .22227 L .2061 .22001 L F
.58937 .22642 m .59243 .22002 L .59565 .22418 L .663 .741 .908 r
F
.58937 .22642 m .58614 .22227 L .59243 .22002 L F
.53363 .30907 m .5302 .27593 L .53656 .30692 L 0 0 .439 r
F
.5302 .27593 m .53309 .27374 L .53656 .30692 L 0 0 .463 r
F
.5341 .31773 m .53077 .33016 L .53709 .33674 L .644 .295 .365 r
F
.5341 .31773 m .53709 .33674 L .54051 .34907 L F
.53077 .33016 m .53363 .30907 L .53709 .33674 L .923 .755 .656 r
F
.52968 .24613 m .52631 .22993 L .53297 .40576 L .979 .684 .356 r
F
.52631 .22993 m .52294 .22833 L .52939 .38693 L .968 .665 .393 r
F
.34992 .32989 m .34771 .29867 L .3524 .32067 L .005 0 .459 r
F
.34233 .3591 m .34771 .29867 L .34992 .32989 L .785 .551 .582 r
F
.34233 .3591 m .34 .33004 L .34771 .29867 L F
.69354 .22625 m .69694 .21983 L .69994 .224 L .664 .742 .908 r
F
.69354 .22625 m .69053 .2221 L .69694 .21983 L F
.79773 .22607 m .80146 .21965 L .80425 .22382 L .664 .741 .908 r
F
.79773 .22607 m .79493 .22191 L .80146 .21965 L F
.21999 .22607 m .22186 .21966 L .22586 .22383 L .663 .741 .908 r
F
.21999 .22607 m .21599 .22192 L .22186 .21966 L F
.60515 .22609 m .60826 .21966 L .61145 .22382 L .665 .742 .908 r
F
.60515 .22609 m .60195 .22193 L .60826 .21966 L F
.45419 .25592 m .45634 .27067 L .46023 .25804 L .449 .132 .335 r
F
.45419 .25592 m .45018 .27223 L .45634 .27067 L F
.3643 .28408 m .3618 .25664 L .36844 .24289 L .692 .481 .598 r
F
.3618 .25664 m .36344 .26355 L .36844 .24289 L 0 0 .188 r
F
.3618 .25664 m .35905 .23452 L .36344 .26355 L F
.35131 .30387 m .34905 .2732 L .35445 .28278 L .345 .218 .561 r
F
.34905 .2732 m .34968 .29672 L .35445 .28278 L .827 .615 .064 r
F
.35445 .28278 m .34968 .29672 L .35779 .24288 L .999 .793 .456 r
F
.35445 .28278 m .35779 .24288 L .3582 .24347 L F
.34968 .29672 m .35513 .23416 L .35905 .23452 L .9 .657 .562 r
F
.35561 .2397 m .35559 .26163 L .35879 .27628 L .637 .313 .406 r
F
.35513 .23416 m .35521 .23912 L .35561 .2397 L F
.35521 .23912 m .35559 .26163 L .35561 .2397 L F
.3582 .24347 m .35779 .24288 L .35905 .23452 L .999 .793 .456 r
F
.35905 .23452 m .35879 .27628 L .36344 .26355 L .943 .616 .382 r
F
.35905 .23452 m .35513 .23416 L .35879 .27628 L F
.47371 .29988 m .47047 .28185 L .47656 .28352 L .496 .377 .648 r
F
.4676 .29924 m .47047 .28185 L .47371 .29988 L .916 .774 .689 r
F
.4676 .29924 m .46411 .29538 L .47047 .28185 L F
.70934 .2259 m .71279 .21948 L .71576 .22364 L .664 .741 .908 r
F
.70934 .2259 m .70636 .22174 L .71279 .21948 L F
.62093 .22572 m .6241 .21931 L .62725 .22348 L .663 .741 .908 r
F
.62093 .22572 m .61777 .22156 L .6241 .21931 L F
.23571 .22572 m .23763 .21931 L .2416 .22348 L F
.23571 .22572 m .23174 .22156 L .23763 .21931 L F
.72514 .22555 m .72864 .21913 L .73158 .2233 L F
.72514 .22555 m .72219 .22139 L .72864 .21913 L F
.63672 .22538 m .63994 .21897 L .64306 .22314 L F
.63672 .22538 m .63359 .22123 L .63994 .21897 L F
.25143 .2254 m .2534 .21898 L .25734 .22315 L F
.25143 .2254 m .24749 .22124 L .2534 .21898 L F
.74095 .22521 m .7445 .21879 L .74741 .22296 L .664 .742 .908 r
F
.74095 .22521 m .73804 .22105 L .7445 .21879 L F
.65252 .22504 m .65579 .21861 L .65888 .22278 L .664 .741 .908 r
F
.65252 .22504 m .64942 .22088 L .65579 .21861 L F
.26716 .22505 m .26919 .21862 L .27308 .22279 L F
.26716 .22505 m .26325 .22089 L .26919 .21862 L F
.44458 .25281 m .44651 .27252 L .45018 .27223 L .578 .246 .371 r
F
.44458 .25281 m .4405 .26861 L .44651 .27252 L F
.75677 .22486 m .76037 .21843 L .76324 .2226 L .664 .741 .908 r
F
.75677 .22486 m .75388 .22069 L .76037 .21843 L F
.17868 .22486 m .18042 .21843 L .18451 .2226 L F
.17868 .22486 m .17459 .2207 L .18042 .21843 L F
.56407 .22486 m .56705 .21843 L .57033 .2226 L F
.56407 .22486 m .56079 .2207 L .56705 .21843 L F
.39387 .24533 m .39051 .2347 L .39618 .24175 L .06 .166 .662 r
F
.39051 .2347 m .3928 .23127 L .39194 .23648 L 0 0 0 r
F
.39051 .2347 m .38586 .25263 L .3928 .23127 L F
.38586 .25263 m .38813 .24985 L .3928 .23127 L F
.39123 .22854 m .39417 .21061 L .39504 .2175 L .709 .672 .125 r
F
.3928 .23127 m .38851 .24835 L .39366 .22603 L .761 .74 .218 r
F
.38851 .24835 m .3888 .24696 L .39366 .22603 L F
.3928 .23127 m .39366 .22603 L .39553 .21799 L F
.39194 .23648 m .3928 .23127 L .39618 .24175 L 0 0 0 r
F
.39387 .24533 m .39618 .24175 L .39879 .27112 L .06 .166 .662 r
F
.39618 .24175 m .3928 .23127 L .39809 .24834 L .699 .393 0 r
F
.3928 .23127 m .39553 .21799 L .39809 .24834 L .761 .74 .218 r
F
.40074 .27794 m .39809 .24834 L .39903 .24896 L .461 .307 .585 r
F
.40109 .26712 m .39903 .24896 L .40314 .25165 L F
.40074 .27794 m .39903 .24896 L .40157 .27136 L F
.40109 .26712 m .40314 .25165 L .404 .25222 L F
.39809 .24834 m .3999 .2585 L .404 .25222 L 0 0 .172 r
F
.3999 .2585 m .40313 .23368 L .40692 .22315 L .525 .366 .608 r
F
.40651 .22618 m .40692 .22315 L .40743 .22173 L F
.3999 .2585 m .40692 .22315 L .40651 .22618 L F
.40157 .27136 m .40109 .26712 L .404 .25222 L .461 .307 .585 r
F
.39797 .24693 m .39553 .21799 L .39803 .24121 L 0 0 .172 r
F
.39797 .24693 m .39803 .24121 L .39948 .25465 L F
.39944 .25576 m .39948 .25465 L .3999 .2585 L F
.39797 .24693 m .39948 .25465 L .39944 .25576 L F
.39566 .21922 m .39706 .23366 L .39722 .23366 L .621 .251 .32 r
F
.3999 .2585 m .39706 .23366 L .40313 .23368 L .525 .366 .608 r
F
.39809 .24834 m .39797 .24693 L .3999 .2585 L 0 0 .172 r
F
.39706 .23366 m .39857 .25058 L .40313 .23368 L .767 .547 0 r
F
.40313 .23368 m .3998 .24605 L .40607 .21597 L .856 .788 .291 r
F
.3998 .24605 m .39857 .25058 L .39985 .24471 L F
.3998 .24605 m .39985 .24471 L .40607 .21597 L F
.39557 .21841 m .39706 .23366 L .39566 .21922 L .621 .251 .32 r
F
.38426 .24136 m .38586 .25263 L .39051 .2347 L .118 0 .274 r
F
.38813 .24985 m .39123 .22854 L .39553 .21799 L .936 .826 .376 r
F
.39553 .21799 m .39123 .22854 L .39706 .23366 L .621 .251 .32 r
F
.39247 .22963 m .39504 .2175 L .39706 .23366 L .709 .672 .125 r
F
.39706 .23366 m .3953 .21963 L .39701 .23581 L .767 .547 0 r
F
.3953 .21963 m .39526 .22047 L .39857 .25058 L F
.39123 .22854 m .39504 .2175 L .39247 .22963 L .709 .672 .125 r
F
.39417 .21061 m .39521 .23774 L .39857 .25058 L .777 .423 .385 r
F
.39625 .23265 m .39828 .21697 L .39822 .22304 L .377 .248 .575 r
F
.39521 .23774 m .39607 .2319 L .39625 .23265 L F
.39607 .2319 m .39828 .21697 L .39625 .23265 L F
.39739 .23738 m .39701 .23581 L .39857 .25058 L .767 .547 0 r
F
.39706 .23366 m .39701 .23581 L .39739 .23738 L F
.3953 .21963 m .39417 .21061 L .39526 .22047 L F
.39553 .21799 m .39557 .21841 L .39566 .21922 L .621 .251 .32 r
F
.38586 .25263 m .38121 .26909 L .38813 .24985 L 0 0 0 r
F
.38138 .26862 m .38358 .26408 L .38713 .25297 L .032 .073 .572 r
F
.38138 .26862 m .38713 .25297 L .38729 .25217 L F
.38426 .24136 m .37909 .26896 L .38586 .25263 L .118 0 .274 r
F
.37909 .26896 m .38121 .26909 L .38586 .25263 L 0 0 0 r
F
.38358 .26408 m .38226 .25567 L .38409 .25472 L 0 0 .497 r
F
.38226 .25567 m .38054 .24481 L .38306 .25185 L F
.38226 .25567 m .38306 .25185 L .38409 .25472 L F
.38054 .24481 m .3822 .25525 L .38251 .25564 L 0 0 .153 r
F
.38054 .24481 m .38251 .25564 L .38404 .25475 L F
.38713 .25297 m .38358 .26408 L .38581 .25373 L .936 .826 .376 r
F
.38713 .25297 m .38581 .25373 L .39123 .22854 L F
.38358 .26408 m .38593 .25986 L .39123 .22854 L 0 0 .497 r
F
.38358 .26408 m .38409 .25472 L .3858 .25949 L F
.38358 .26408 m .3858 .25949 L .38593 .25986 L F
.38054 .24481 m .38577 .25966 L .3858 .25949 L 0 0 .153 r
F
.3822 .25525 m .38494 .24267 L .38572 .23928 L .01 0 .436 r
F
.3845 .24504 m .38572 .23928 L .38982 .22152 L F
.3822 .25525 m .38572 .23928 L .3845 .24504 L F
.38404 .25475 m .38251 .25564 L .38577 .25966 L 0 0 .153 r
F
.38729 .25217 m .38713 .25297 L .38813 .24985 L .032 .073 .572 r
F
.38813 .24985 m .38713 .25297 L .39123 .22854 L .936 .826 .376 r
F
.3858 .25949 m .38577 .25966 L .38593 .25986 L 0 0 .153 r
F
.38121 .26909 m .38358 .26408 L .38138 .26862 L .032 .073 .572 r
F
.39123 .22854 m .38828 .24598 L .39417 .21061 L .709 .672 .125 r
F
.38828 .24598 m .38671 .25528 L .38903 .24138 L F
.38828 .24598 m .38903 .24138 L .39417 .21061 L F
.38671 .25528 m .3872 .25231 L .39093 .22998 L F
.39091 .23015 m .39093 .22998 L .39417 .21061 L F
.38671 .25528 m .39093 .22998 L .39091 .23015 L F
.38593 .25986 m .38982 .22152 L .39417 .21061 L .949 .73 .573 r
F
.39417 .21061 m .38997 .22113 L .39521 .23774 L .777 .423 .385 r
F
.38997 .22113 m .38982 .22152 L .3906 .22389 L F
.38997 .22113 m .3906 .22389 L .39521 .23774 L F
.38982 .22152 m .39252 .20945 L .39316 .21612 L .699 .698 .165 r
F
.38982 .22152 m .39316 .21612 L .39146 .22647 L F
.38982 .22152 m .38494 .24267 L .39044 .21855 L F
.38999 .22075 m .39044 .21855 L .39252 .20945 L F
.38982 .22152 m .39044 .21855 L .38999 .22075 L F
.39146 .22647 m .39316 .21612 L .39521 .23774 L F
.38494 .24267 m .38876 .20614 L .39252 .20945 L .877 .659 .604 r
F
.39252 .20945 m .38876 .20614 L .39385 .22963 L .936 .562 .235 r
F
.38876 .20614 m .39074 .21062 L .39133 .21425 L 0 0 .147 r
F
.39109 .21543 m .39133 .21425 L .39234 .22041 L F
.38876 .20614 m .39133 .21425 L .39109 .21543 L F
.39214 .22176 m .39234 .22041 L .39385 .22963 L F
.38876 .20614 m .39234 .22041 L .39214 .22176 L F
.39521 .23774 m .39316 .21612 L .39831 .21681 L .377 .248 .575 r
F
.39316 .21612 m .39252 .20945 L .39395 .21127 L F
.39316 .21612 m .39395 .21127 L .39831 .21681 L F
.38671 .25528 m .38593 .25986 L .3872 .25231 L .709 .672 .125 r
F
.39831 .21681 m .39495 .22645 L .39509 .22658 L 0 0 0 r
F
.39495 .22645 m .39385 .22963 L .39493 .22699 L F
.39495 .22645 m .39493 .22699 L .39509 .22658 L F
.39822 .22304 m .39831 .21681 L .40148 .20717 L .377 .248 .575 r
F
.39828 .21697 m .39831 .21681 L .39822 .22304 L F
.39857 .25058 m .39521 .23774 L .40285 .20048 L .898 .661 .572 r
F
.40148 .20717 m .39831 .21681 L .40285 .20048 L .377 .248 .575 r
F
.39857 .25058 m .40285 .20048 L .40607 .21597 L .898 .661 .572 r
F
.40285 .20048 m .39831 .21681 L .40419 .2231 L .613 .275 .374 r
F
.39831 .21681 m .40071 .21287 L .40419 .2231 L 0 0 0 r
F
.39831 .21681 m .39509 .22658 L .40071 .21287 L F
.38851 .24835 m .38813 .24985 L .3888 .24696 L .761 .74 .218 r
F
.66832 .22468 m .67164 .21826 L .6747 .22244 L .663 .741 .908 r
F
.66832 .22468 m .66525 .22052 L .67164 .21826 L F
.2829 .22468 m .28497 .21828 L .28884 .22245 L .662 .741 .908 r
F
.2829 .22468 m .27902 .22052 L .28497 .21828 L F
.39646 .27436 m .39387 .24533 L .39879 .27112 L 0 0 .403 r
F
.39067 .26951 m .39387 .24533 L .39646 .27436 L .425 .279 .578 r
F
.5457 .27862 m .54226 .26247 L .5483 .22622 L .879 .636 .567 r
F
.5483 .22622 m .55122 .21883 L .55453 .22301 L .693 .73 .879 r
F
.5483 .22622 m .54497 .22164 L .55122 .21883 L F
.54226 .26247 m .54497 .22164 L .5483 .22622 L .861 .633 .591 r
F
.77259 .22451 m .77624 .21809 L .77908 .22226 L .663 .741 .908 r
F
.77259 .22451 m .76974 .22035 L .77624 .21809 L F
.1944 .22451 m .19619 .2181 L .20024 .22227 L F
.1944 .22451 m .19034 .22035 L .19619 .2181 L F
.57986 .22452 m .58289 .2181 L .58614 .22227 L F
.57986 .22452 m .5766 .22035 L .58289 .2181 L F
.68413 .22435 m .6875 .21793 L .69053 .2221 L F
.68413 .22435 m .68109 .22019 L .6875 .21793 L F
.39151 .28881 m .39334 .29673 L .3974 .29094 L .434 .041 .193 r
F
.39151 .28881 m .38732 .29705 L .39334 .29673 L F
.78842 .22417 m .79212 .21774 L .79493 .22191 L .663 .741 .908 r
F
.78842 .22417 m .78559 .22 L .79212 .21774 L F
.21013 .22417 m .21197 .21774 L .21599 .22192 L .664 .741 .908 r
F
.21013 .22417 m .2061 .22001 L .21197 .21774 L F
.59565 .22418 m .59874 .21776 L .60195 .22193 L .663 .741 .908 r
F
.59565 .22418 m .59243 .22002 L .59874 .21776 L F
.69994 .224 m .70336 .21756 L .70636 .22174 L .664 .741 .908 r
F
.69994 .224 m .69694 .21983 L .70336 .21756 L F
.80425 .22382 m .808 .21739 L .81078 .22156 L F
.80425 .22382 m .80146 .21965 L .808 .21739 L F
.61145 .22382 m .61459 .21739 L .61777 .22156 L .664 .742 .908 r
F
.61145 .22382 m .60826 .21966 L .61459 .21739 L F
.22586 .22383 m .22775 .21739 L .23174 .22156 L .664 .741 .908 r
F
.22586 .22383 m .22186 .21966 L .22775 .21739 L F
.36844 .24289 m .36877 .27666 L .37349 .26074 L .683 .363 .428 r
F
.36844 .24289 m .36344 .26355 L .36877 .27666 L F
.71576 .22364 m .71923 .21721 L .72219 .22139 L .664 .741 .908 r
F
.71576 .22364 m .71279 .21948 L .71923 .21721 L F
.29856 .22541 m .29844 .2494 L .30151 .26473 L .953 .609 .308 r
F
.29856 .22541 m .29473 .22099 L .29844 .2494 L F
.2416 .22348 m .24354 .21706 L .24749 .22124 L .662 .741 .908 r
F
.2416 .22348 m .23763 .21931 L .24354 .21706 L F
.62725 .22348 m .63044 .21705 L .63359 .22123 L .663 .741 .908 r
F
.62725 .22348 m .6241 .21931 L .63044 .21705 L F
.73158 .2233 m .73511 .21688 L .73804 .22105 L F
.73158 .2233 m .72864 .21913 L .73511 .21688 L F
.64306 .22314 m .6463 .2167 L .64942 .22088 L .664 .741 .908 r
F
.64306 .22314 m .63994 .21897 L .6463 .2167 L F
.25734 .22315 m .25933 .21671 L .26325 .22089 L .664 .742 .908 r
F
.25734 .22315 m .2534 .21898 L .25933 .21671 L F
.74741 .22296 m .75099 .21652 L .75388 .22069 L F
.74741 .22296 m .7445 .21879 L .75099 .21652 L F
.37226 .28126 m .37484 .2707 L .37741 .29819 L .792 .793 .298 r
F
.55453 .22301 m .55748 .21652 L .56079 .2207 L .666 .742 .907 r
F
.55453 .22301 m .55122 .21883 L .55748 .21652 L F
.65888 .22278 m .66217 .21634 L .66525 .22052 L .664 .742 .908 r
F
.65888 .22278 m .65579 .21861 L .66217 .21634 L F
.27308 .22279 m .27513 .21634 L .27902 .22052 L F
.27308 .22279 m .26919 .21862 L .27513 .21634 L F
.53709 .33674 m .53363 .30907 L .53992 .33742 L 0 0 .418 r
F
.53999 .33805 m .53992 .33742 L .54007 .33808 L F
.53709 .33674 m .53992 .33742 L .53999 .33805 L F
.53656 .30692 m .53309 .27374 L .53365 .28511 L .962 .686 .253 r
F
.53363 .30907 m .53656 .30692 L .54007 .33808 L 0 0 .439 r
F
.54383 .34285 m .54051 .34907 L .54698 .36637 L .832 .456 .34 r
F
.54335 .35665 m .54356 .35964 L .54698 .36637 L 0 0 .201 r
F
.54051 .34907 m .54356 .35964 L .54335 .35665 L F
.54267 .35649 m .54007 .33808 L .54356 .35964 L 0 0 .418 r
F
.54308 .35799 m .54273 .35671 L .54356 .35964 L 0 0 .201 r
F
.54051 .34907 m .54273 .35671 L .54308 .35799 L F
.54356 .35964 m .54007 .33808 L .54378 .36267 L .747 .513 0 r
F
.54356 .35964 m .54378 .36267 L .54674 .38231 L F
.53709 .33674 m .53999 .33805 L .54267 .35649 L 0 0 .418 r
F
.53687 .31678 m .53595 .33202 L .53755 .33785 L .962 .686 .253 r
F
.53667 .31029 m .53653 .31443 L .53687 .31678 L F
.53653 .31443 m .53595 .33202 L .53687 .31678 L F
.53999 .33805 m .54007 .33808 L .54186 .35077 L 0 0 .418 r
F
.53999 .33805 m .54186 .35077 L .54267 .35649 L F
.54007 .33808 m .53656 .30692 L .53747 .31975 L .916 .654 .159 r
F
.54007 .33808 m .53747 .31975 L .53918 .34369 L F
.54051 .34907 m .53709 .33674 L .54267 .35649 L 0 0 .201 r
F
.54051 .34907 m .54267 .35649 L .5427 .35659 L F
.54063 .34901 m .53918 .34369 L .54344 .40341 L .916 .654 .159 r
F
.54007 .33808 m .53918 .34369 L .54063 .34901 L F
.5427 .35659 m .54267 .35649 L .54273 .35671 L 0 0 .201 r
F
.53667 .31029 m .53365 .28511 L .53595 .33202 L .962 .686 .253 r
F
.53755 .33785 m .53595 .33202 L .54003 .41515 L F
.53656 .30692 m .53365 .28511 L .53667 .31029 L F
.53309 .27374 m .52968 .24613 L .5359 .40044 L .978 .691 .312 r
F
.53612 .40171 m .5359 .40044 L .53636 .41184 L F
.53309 .27374 m .5359 .40044 L .53612 .40171 L F
.52968 .24613 m .53297 .40576 L .53652 .41583 L .979 .684 .356 r
F
.52294 .22833 m .52584 .36238 L .52939 .38693 L .939 .629 .425 r
F
.52656 .34656 m .52867 .21741 L .53206 .22574 L .926 .651 .499 r
F
.52584 .36238 m .52619 .34443 L .52656 .34656 L F
.52619 .34443 m .52867 .21741 L .52656 .34656 L F
.53309 .27374 m .53636 .41184 L .53644 .41231 L .978 .691 .312 r
F
.53309 .27374 m .53652 .41583 L .54003 .41515 L F
.52997 .37251 m .53206 .22574 L .53545 .23596 L .938 .661 .488 r
F
.52939 .38693 m .52966 .37061 L .52997 .37251 L F
.52966 .37061 m .53206 .22574 L .52997 .37251 L F
.53644 .41231 m .53636 .41184 L .53652 .41583 L .978 .691 .312 r
F
.18451 .2226 m .18626 .21617 L .19034 .22035 L .663 .741 .908 r
F
.18451 .2226 m .18042 .21843 L .18626 .21617 L F
.76324 .2226 m .76687 .21617 L .76974 .22035 L F
.76324 .2226 m .76037 .21843 L .76687 .21617 L F
.57033 .2226 m .57334 .21617 L .5766 .22035 L F
.57033 .2226 m .56705 .21843 L .57334 .21617 L F
.6747 .22244 m .67804 .216 L .68109 .22019 L F
.6747 .22244 m .67164 .21826 L .67804 .216 L F
.28884 .22245 m .28497 .21828 L .29089 .21653 L .627 .73 .921 r
F
.77908 .22226 m .78276 .21582 L .78559 .22 L .664 .741 .908 r
F
.77908 .22226 m .77624 .21809 L .78276 .21582 L F
.20024 .22227 m .20205 .21583 L .2061 .22001 L F
.20024 .22227 m .19619 .2181 L .20205 .21583 L F
.58614 .22227 m .58919 .21583 L .59243 .22002 L .663 .741 .908 r
F
.58614 .22227 m .58289 .2181 L .58919 .21583 L F
.69053 .2221 m .69392 .21565 L .69694 .21983 L .664 .742 .908 r
F
.69053 .2221 m .6875 .21793 L .69392 .21565 L F
.46023 .25804 m .46262 .26461 L .46648 .25059 L .222 0 .205 r
F
.79493 .22191 m .79866 .21547 L .80146 .21965 L .664 .741 .908 r
F
.79493 .22191 m .79212 .21774 L .79866 .21547 L F
.21599 .22192 m .21785 .21548 L .22186 .21966 L .663 .741 .908 r
F
.21599 .22192 m .21197 .21774 L .21785 .21548 L F
.60195 .22193 m .60506 .21548 L .60826 .21966 L .664 .742 .908 r
F
.60195 .22193 m .59874 .21776 L .60506 .21548 L F
.47371 .29988 m .47656 .28352 L .47994 .29306 L .496 .377 .648 r
F
.49764 .29861 m .4944 .27012 L .50092 .23311 L .811 .567 .569 r
F
.50092 .23311 m .50319 .30044 L .50686 .27622 L .876 .553 .436 r
F
.50092 .23311 m .49732 .24936 L .50319 .30044 L F
.70636 .22174 m .7098 .21529 L .71279 .21948 L .664 .741 .908 r
F
.70636 .22174 m .70336 .21756 L .7098 .21529 L F
.61777 .22156 m .62093 .21512 L .6241 .21931 L .663 .741 .908 r
F
.61777 .22156 m .61459 .21739 L .62093 .21512 L F
.23174 .22156 m .23365 .21512 L .23763 .21931 L F
.23174 .22156 m .22775 .21739 L .23365 .21512 L F
.72219 .22139 m .72569 .21495 L .72864 .21913 L F
.72219 .22139 m .71923 .21721 L .72569 .21495 L F
.63359 .22123 m .6368 .21478 L .63994 .21897 L F
.63359 .22123 m .63044 .21705 L .6368 .21478 L F
.24749 .22124 m .24946 .2148 L .2534 .21898 L F
.24749 .22124 m .24354 .21706 L .24946 .2148 L F
.47656 .28352 m .47925 .27798 L .48256 .29363 L .045 .043 .53 r
F
.73804 .22105 m .74158 .2146 L .7445 .21879 L .664 .742 .908 r
F
.73804 .22105 m .73511 .21688 L .74158 .2146 L F
.46023 .25804 m .45634 .27067 L .46262 .26461 L .222 0 .205 r
F
.64942 .22088 m .65268 .21443 L .65579 .21861 L .664 .741 .908 r
F
.64942 .22088 m .6463 .2167 L .65268 .21443 L F
.26325 .22089 m .26527 .21443 L .26919 .21862 L F
.26325 .22089 m .25933 .21671 L .26527 .21443 L F
.357 .34508 m .3529 .34799 L .36017 .32286 L .993 .834 .58 r
F
.3529 .34799 m .35561 .33463 L .36017 .32286 L .389 .301 .635 r
F
.75388 .22069 m .75748 .21424 L .76037 .21843 L .664 .741 .908 r
F
.75388 .22069 m .75099 .21652 L .75748 .21424 L F
.56079 .2207 m .56376 .21424 L .56705 .21843 L F
.56079 .2207 m .55748 .21652 L .56376 .21424 L F
.54226 .26247 m .53885 .24822 L .54497 .22164 L .861 .633 .591 r
F
.54497 .22164 m .5479 .21463 L .55122 .21883 L .677 .729 .89 r
F
.54497 .22164 m .54164 .21715 L .5479 .21463 L F
.53885 .24822 m .54164 .21715 L .54497 .22164 L .841 .633 .622 r
F
.66525 .22052 m .66857 .21407 L .67164 .21826 L .663 .741 .908 r
F
.66525 .22052 m .66217 .21634 L .66857 .21407 L F
.27902 .22052 m .28109 .21409 L .28497 .21828 L .662 .741 .908 r
F
.27902 .22052 m .27513 .21634 L .28109 .21409 L F
.76974 .22035 m .77339 .2139 L .77624 .21809 L .664 .741 .908 r
F
.76974 .22035 m .76687 .21617 L .77339 .2139 L F
.19034 .22035 m .19212 .21391 L .19619 .2181 L .663 .741 .908 r
F
.19034 .22035 m .18626 .21617 L .19212 .21391 L F
.5766 .22035 m .57963 .21391 L .58289 .2181 L F
.5766 .22035 m .57334 .21617 L .57963 .21391 L F
.68109 .22019 m .68446 .21374 L .6875 .21793 L F
.68109 .22019 m .67804 .216 L .68446 .21374 L F
.78559 .22 m .7893 .21355 L .79212 .21774 L F
.78559 .22 m .78276 .21582 L .7893 .21355 L F
.2061 .22001 m .20793 .21355 L .21197 .21774 L .664 .742 .908 r
F
.2061 .22001 m .20205 .21583 L .20793 .21355 L F
.59243 .22002 m .59551 .21356 L .59874 .21776 L .663 .741 .908 r
F
.59243 .22002 m .58919 .21583 L .59551 .21356 L F
.69694 .21983 m .70035 .21337 L .70336 .21756 L .664 .741 .908 r
F
.69694 .21983 m .69392 .21565 L .70035 .21337 L F
.80146 .21965 m .80521 .21319 L .808 .21739 L F
.80146 .21965 m .79866 .21547 L .80521 .21319 L F
.60826 .21966 m .61139 .21319 L .61459 .21739 L .664 .742 .908 r
F
.60826 .21966 m .60506 .21548 L .61139 .21319 L F
.22186 .21966 m .22375 .2132 L .22775 .21739 L .664 .741 .908 r
F
.22186 .21966 m .21785 .21548 L .22375 .2132 L F
.29473 .22099 m .29524 .236 L .29844 .2494 L .935 .558 .214 r
F
.71279 .21948 m .71625 .21302 L .71923 .21721 L .664 .741 .908 r
F
.71279 .21948 m .7098 .21529 L .71625 .21302 L F
.39334 .29673 m .39067 .26951 L .39646 .27436 L .438 .297 .591 r
F
.38732 .29705 m .39067 .26951 L .39334 .29673 L .648 .468 .627 r
F
.38732 .29705 m .3844 .27621 L .39067 .26951 L F
.34968 .29672 m .34648 .28212 L .35513 .23416 L .9 .657 .562 r
F
.34648 .28212 m .35008 .25317 L .35513 .23416 L .445 .284 .568 r
F
.35513 .23416 m .35008 .25317 L .35559 .26163 L .637 .313 .406 r
F
.23763 .21931 m .23956 .21287 L .24354 .21706 L .662 .741 .908 r
F
.23763 .21931 m .23365 .21512 L .23956 .21287 L F
.6241 .21931 m .62728 .21286 L .63044 .21705 L .663 .741 .908 r
F
.6241 .21931 m .62093 .21512 L .62728 .21286 L F
.3974 .29094 m .39334 .29673 L .39974 .28757 L .582 .806 .407 r
F
.72864 .21913 m .73216 .21268 L .73511 .21688 L .663 .741 .908 r
F
.72864 .21913 m .72569 .21495 L .73216 .21268 L F
.63994 .21897 m .64317 .2125 L .6463 .2167 L .664 .741 .908 r
F
.63994 .21897 m .6368 .21478 L .64317 .2125 L F
.2534 .21898 m .25539 .21252 L .25933 .21671 L .664 .742 .908 r
F
.2534 .21898 m .24946 .2148 L .25539 .21252 L F
.38128 .29826 m .3844 .27621 L .38732 .29705 L .977 .811 .612 r
F
.38128 .29826 m .37741 .29819 L .3844 .27621 L F
.7445 .21879 m .74808 .21232 L .75099 .21652 L .664 .741 .908 r
F
.7445 .21879 m .74158 .2146 L .74808 .21232 L F
.55122 .21883 m .55417 .21233 L .55748 .21652 L .666 .741 .907 r
F
.55122 .21883 m .5479 .21463 L .55417 .21233 L F
.65579 .21861 m .65907 .21214 L .66217 .21634 L .664 .741 .908 r
F
.65579 .21861 m .65268 .21443 L .65907 .21214 L F
.26919 .21862 m .27122 .21215 L .27513 .21634 L .664 .742 .908 r
F
.26919 .21862 m .26527 .21443 L .27122 .21215 L F
.76037 .21843 m .76399 .21197 L .76687 .21617 L .663 .741 .908 r
F
.76037 .21843 m .75748 .21424 L .76399 .21197 L F
.56705 .21843 m .57005 .21198 L .57334 .21617 L F
.56705 .21843 m .56376 .21424 L .57005 .21198 L F
.67164 .21826 m .67498 .2118 L .67804 .216 L F
.67164 .21826 m .66857 .21407 L .67498 .2118 L F
.28497 .21828 m .28704 .21207 L .29089 .21653 L .646 .736 .914 r
F
.28497 .21828 m .28109 .21409 L .28704 .21207 L F
.77624 .21809 m .77992 .21162 L .78276 .21582 L .664 .741 .908 r
F
.77624 .21809 m .77339 .2139 L .77992 .21162 L F
.58289 .2181 m .58594 .21163 L .58919 .21583 L F
.58289 .2181 m .57963 .21391 L .58594 .21163 L F
.19619 .2181 m .19799 .21164 L .20205 .21583 L F
.19619 .2181 m .19212 .21391 L .19799 .21164 L F
.6875 .21793 m .69089 .21145 L .69392 .21565 L F
.6875 .21793 m .68446 .21374 L .69089 .21145 L F
.79212 .21774 m .79585 .21127 L .79866 .21547 L .664 .742 .908 r
F
.79212 .21774 m .7893 .21355 L .79585 .21127 L F
.21197 .21774 m .21382 .21128 L .21785 .21548 L .663 .741 .908 r
F
.21197 .21774 m .20793 .21355 L .21382 .21128 L F
.59874 .21776 m .60184 .21128 L .60506 .21548 L .664 .741 .908 r
F
.59874 .21776 m .59551 .21356 L .60184 .21128 L F
.70336 .21756 m .7068 .21109 L .7098 .21529 L F
.70336 .21756 m .70035 .21337 L .7068 .21109 L F
.61459 .21739 m .61774 .21092 L .62093 .21512 L .663 .741 .908 r
F
.61459 .21739 m .61139 .21319 L .61774 .21092 L F
.22775 .21739 m .22965 .21092 L .23365 .21512 L F
.22775 .21739 m .22375 .2132 L .22965 .21092 L F
.71923 .21721 m .72272 .21075 L .72569 .21495 L F
.71923 .21721 m .71625 .21302 L .72272 .21075 L F
.63044 .21705 m .63365 .21058 L .6368 .21478 L .664 .741 .908 r
F
.63044 .21705 m .62728 .21286 L .63365 .21058 L F
.24354 .21706 m .24549 .2106 L .24946 .2148 L .663 .741 .908 r
F
.24354 .21706 m .23956 .21287 L .24549 .2106 L F
.35011 .36282 m .3529 .34799 L .357 .34508 L .964 .884 .497 r
F
.42166 .24492 m .41725 .26419 L .42382 .25002 L .009 0 .187 r
F
.73511 .21688 m .73865 .21039 L .74158 .2146 L .664 .741 .908 r
F
.73511 .21688 m .73216 .21268 L .73865 .21039 L F
.48453 .27952 m .48788 .22544 L .49123 .2386 L .994 .762 .47 r
F
.48833 .25766 m .48453 .27952 L .49039 .24373 L .746 .694 .152 r
F
.49069 .2421 m .49039 .24373 L .49123 .2386 L F
.48833 .25766 m .49039 .24373 L .49069 .2421 L F
.48699 .2617 m .48634 .28068 L .48986 .28727 L .724 .406 .441 r
F
.48453 .27952 m .48089 .28417 L .48788 .22544 L .994 .762 .47 r
F
.48421 .23696 m .48574 .2683 L .48699 .2617 L .724 .406 .441 r
F
.48574 .2683 m .48634 .28068 L .48699 .2617 L F
.49123 .2386 m .48788 .22544 L .49358 .27271 L .943 .633 .186 r
F
.48788 .22544 m .48986 .28727 L .49358 .27271 L .897 .57 .42 r
F
.48788 .22544 m .48421 .23696 L .48986 .28727 L F
.6463 .2167 m .64956 .21022 L .65268 .21443 L .664 .741 .908 r
F
.6463 .2167 m .64317 .2125 L .64956 .21022 L F
.25933 .21671 m .26134 .21023 L .26527 .21443 L F
.25933 .21671 m .25539 .21252 L .26134 .21023 L F
.53885 .24822 m .53545 .23596 L .54164 .21715 L .841 .633 .622 r
F
.54164 .21715 m .54456 .21042 L .5479 .21463 L .667 .732 .899 r
F
.54164 .21715 m .53829 .21276 L .54456 .21042 L F
.53545 .23596 m .53829 .21276 L .54164 .21715 L .819 .64 .66 r
F
.75099 .21652 m .75458 .21004 L .75748 .21424 L .663 .741 .908 r
F
.75099 .21652 m .74808 .21232 L .75458 .21004 L F
.55748 .21652 m .56046 .21004 L .56376 .21424 L .664 .742 .908 r
F
.55748 .21652 m .55417 .21233 L .56046 .21004 L F
.66217 .21634 m .66548 .20987 L .66857 .21407 L .663 .741 .908 r
F
.66217 .21634 m .65907 .21214 L .66548 .20987 L F
.27513 .21634 m .27719 .20988 L .28109 .21409 L .662 .741 .908 r
F
.27513 .21634 m .27122 .21215 L .27719 .20988 L F
.31347 .39588 m .31122 .36637 L .32369 .26758 L .895 .636 .538 r
F
.32369 .26758 m .32183 .32446 L .32739 .30192 L .764 .458 .467 r
F
.31122 .36637 m .31785 .29412 L .32369 .26758 L .809 .566 .572 r
F
.32369 .26758 m .31785 .29412 L .32183 .32446 L .764 .458 .467 r
F
.76687 .21617 m .77052 .20969 L .77339 .2139 L .664 .741 .908 r
F
.76687 .21617 m .76399 .21197 L .77052 .20969 L F
.57334 .21617 m .57636 .2097 L .57963 .21391 L .663 .741 .908 r
F
.57334 .21617 m .57005 .21198 L .57636 .2097 L F
.67804 .216 m .6814 .20952 L .68446 .21374 L F
.67804 .216 m .67498 .2118 L .6814 .20952 L F
.33327 .27296 m .32739 .30192 L .33489 .2769 L 0 0 .141 r
F
.78276 .21582 m .78647 .20934 L .7893 .21355 L .663 .741 .908 r
F
.78276 .21582 m .77992 .21162 L .78647 .20934 L F
.20205 .21583 m .20388 .20934 L .20793 .21355 L .665 .742 .908 r
F
.20205 .21583 m .19799 .21164 L .20388 .20934 L F
.58919 .21583 m .59227 .20935 L .59551 .21356 L .663 .741 .908 r
F
.58919 .21583 m .58594 .21163 L .59227 .20935 L F
.69392 .21565 m .69733 .20916 L .70035 .21337 L .664 .741 .908 r
F
.69392 .21565 m .69089 .21145 L .69733 .20916 L F
.29089 .21653 m .29194 .22395 L .29524 .236 L .86 .427 .002 r
F
.29089 .21653 m .28704 .21207 L .29194 .22395 L F
.79866 .21547 m .80241 .20898 L .80521 .21319 L .664 .741 .908 r
F
.79866 .21547 m .79585 .21127 L .80241 .20898 L F
.60506 .21548 m .60818 .20898 L .61139 .21319 L .664 .742 .908 r
F
.60506 .21548 m .60184 .21128 L .60818 .20898 L F
.21785 .21548 m .21972 .20899 L .22375 .2132 L .664 .741 .908 r
F
.21785 .21548 m .21382 .21128 L .21972 .20899 L F
.7098 .21529 m .71327 .20881 L .71625 .21302 L .663 .741 .908 r
F
.7098 .21529 m .7068 .21109 L .71327 .20881 L F
.23365 .21512 m .23558 .20865 L .23956 .21287 L F
.23365 .21512 m .22965 .21092 L .23558 .20865 L F
.62093 .21512 m .62411 .20864 L .62728 .21286 L F
.62093 .21512 m .61774 .21092 L .62411 .20864 L F
.4944 .27012 m .49123 .2386 L .49732 .24936 L .352 .227 .568 r
F
.49123 .2386 m .49358 .27271 L .49732 .24936 L .943 .633 .186 r
F
.72569 .21495 m .72921 .20847 L .73216 .21268 L .663 .741 .908 r
F
.72569 .21495 m .72272 .21075 L .72921 .20847 L F
.6368 .21478 m .64003 .20829 L .64317 .2125 L .664 .741 .908 r
F
.6368 .21478 m .63365 .21058 L .64003 .20829 L F
.24946 .2148 m .25143 .2083 L .25539 .21252 L .664 .742 .908 r
F
.24946 .2148 m .24549 .2106 L .25143 .2083 L F
.74158 .2146 m .74515 .2081 L .74808 .21232 L .664 .741 .908 r
F
.74158 .2146 m .73865 .21039 L .74515 .2081 L F
.5479 .21463 m .55084 .20811 L .55417 .21233 L .665 .741 .907 r
F
.5479 .21463 m .54456 .21042 L .55084 .20811 L F
.42382 .25002 m .42102 .22182 L .42662 .23595 L .214 .132 .542 r
F
.41725 .26419 m .42102 .22182 L .42382 .25002 L .985 .765 .523 r
F
.41725 .26419 m .41341 .26551 L .42102 .22182 L F
.42102 .22182 m .42245 .24847 L .42662 .23595 L .871 .506 .353 r
F
.42102 .22182 m .41709 .22667 L .42245 .24847 L F
.65268 .21443 m .65596 .20793 L .65907 .21214 L .664 .741 .908 r
F
.65268 .21443 m .64956 .21022 L .65596 .20793 L F
.26527 .21443 m .2673 .20793 L .27122 .21215 L .664 .742 .908 r
F
.26527 .21443 m .26134 .21023 L .2673 .20793 L F
.75748 .21424 m .76111 .20776 L .76399 .21197 L .663 .741 .908 r
F
.75748 .21424 m .75458 .21004 L .76111 .20776 L F
.56376 .21424 m .56676 .20776 L .57005 .21198 L F
.56376 .21424 m .56046 .21004 L .56676 .20776 L F
.44973 .24233 m .44648 .22625 L .45246 .23169 L .345 .287 .649 r
F
.44338 .25169 m .44648 .22625 L .44973 .24233 L .655 .481 .636 r
F
.44338 .25169 m .44022 .2328 L .44648 .22625 L F
.44648 .22625 m .44903 .22263 L .44765 .22731 L .66 .94 .679 r
F
.44648 .22625 m .44276 .22864 L .44903 .22263 L F
.44022 .2328 m .44276 .22864 L .44648 .22625 L .731 .985 .781 r
F
.44276 .22864 m .44504 .23484 L .44903 .22263 L .196 0 .18 r
F
.44903 .22263 m .44504 .23484 L .45042 .21792 L .696 .74 .232 r
F
.44903 .22263 m .45042 .21792 L .45172 .21383 L F
.44765 .22731 m .44903 .22263 L .45246 .23169 L .66 .94 .679 r
F
.66857 .21407 m .6719 .20758 L .67498 .2118 L .663 .741 .908 r
F
.66857 .21407 m .66548 .20987 L .6719 .20758 L F
.28109 .21409 m .28316 .20767 L .28704 .21207 L .659 .74 .91 r
F
.28109 .21409 m .27719 .20988 L .28316 .20767 L F
.77339 .2139 m .77706 .20741 L .77992 .21162 L .663 .741 .908 r
F
.77339 .2139 m .77052 .20969 L .77706 .20741 L F
.57963 .21391 m .58268 .20742 L .58594 .21163 L F
.57963 .21391 m .57636 .2097 L .58268 .20742 L F
.68446 .21374 m .68784 .20723 L .69089 .21145 L .664 .741 .908 r
F
.68446 .21374 m .6814 .20952 L .68784 .20723 L F
.43686 .26651 m .44022 .2328 L .44338 .25169 L .688 .49 .613 r
F
.43686 .26651 m .43382 .24376 L .44022 .2328 L F
.44022 .2328 m .43649 .23426 L .44276 .22864 L .731 .985 .781 r
F
.20793 .21355 m .20977 .20706 L .21382 .21128 L .663 .741 .908 r
F
.20793 .21355 m .20388 .20934 L .20977 .20706 L F
.7893 .21355 m .79303 .20705 L .79585 .21127 L .664 .742 .908 r
F
.7893 .21355 m .78647 .20934 L .79303 .20705 L F
.59551 .21356 m .59861 .20706 L .60184 .21128 L .664 .741 .908 r
F
.59551 .21356 m .59227 .20935 L .59861 .20706 L F
.43382 .24376 m .43059 .2281 L .43649 .23426 L .303 .262 .646 r
F
.42679 .27421 m .43059 .2281 L .43382 .24376 L .766 .542 .594 r
F
.42679 .27421 m .42382 .25002 L .43059 .2281 L F
.43059 .2281 m .43241 .24651 L .43649 .23426 L .745 .364 .33 r
F
.43059 .2281 m .42662 .23595 L .43241 .24651 L F
.70035 .21337 m .70379 .20687 L .7068 .21109 L .664 .741 .908 r
F
.70035 .21337 m .69733 .20916 L .70379 .20687 L F
.61139 .21319 m .61454 .2067 L .61774 .21092 L .663 .741 .908 r
F
.61139 .21319 m .60818 .20898 L .61454 .2067 L F
.22375 .2132 m .22564 .2067 L .22965 .21092 L F
.22375 .2132 m .21972 .20899 L .22564 .2067 L F
.3529 .34799 m .34992 .32989 L .35561 .33463 L .389 .301 .635 r
F
.34568 .37087 m .34992 .32989 L .3529 .34799 L .878 .657 .6 r
F
.34568 .37087 m .34233 .3591 L .34992 .32989 L F
.34992 .32989 m .3524 .32067 L .35561 .33463 L .005 0 .459 r
F
.71625 .21302 m .71975 .20653 L .72272 .21075 L .663 .741 .908 r
F
.71625 .21302 m .71327 .20881 L .71975 .20653 L F
.62728 .21286 m .63048 .20635 L .63365 .21058 L .664 .741 .908 r
F
.62728 .21286 m .62411 .20864 L .63048 .20635 L F
.23956 .21287 m .24151 .20638 L .24549 .2106 L .663 .741 .908 r
F
.23956 .21287 m .23558 .20865 L .24151 .20638 L F
.73216 .21268 m .73571 .20617 L .73865 .21039 L .664 .741 .908 r
F
.73216 .21268 m .72921 .20847 L .73571 .20617 L F
.39974 .28757 m .39646 .27436 L .40217 .28219 L .134 .174 .638 r
F
.39334 .29673 m .39646 .27436 L .39974 .28757 L .438 .297 .591 r
F
.53545 .23596 m .53206 .22574 L .53829 .21276 L .819 .64 .66 r
F
.53829 .21276 m .5412 .2062 L .54456 .21042 L .662 .736 .905 r
F
.53829 .21276 m .53493 .20847 L .5412 .2062 L F
.53206 .22574 m .53493 .20847 L .53829 .21276 L .797 .657 .707 r
F
.64317 .2125 m .64643 .206 L .64956 .21022 L .664 .741 .908 r
F
.64317 .2125 m .64003 .20829 L .64643 .206 L F
.25539 .21252 m .25739 .206 L .26134 .21023 L .664 .742 .908 r
F
.25539 .21252 m .25143 .2083 L .25739 .206 L F
.74808 .21232 m .75167 .20582 L .75458 .21004 L .663 .741 .908 r
F
.74808 .21232 m .74515 .2081 L .75167 .20582 L F
.55417 .21233 m .55714 .20582 L .56046 .21004 L .664 .742 .908 r
F
.55417 .21233 m .55084 .20811 L .55714 .20582 L F
.65907 .21214 m .66238 .20564 L .66548 .20987 L .663 .741 .908 r
F
.65907 .21214 m .65596 .20793 L .66238 .20564 L F
.27122 .21215 m .27327 .20566 L .27719 .20988 L .662 .741 .908 r
F
.27122 .21215 m .2673 .20793 L .27327 .20566 L F
.76399 .21197 m .76764 .20546 L .77052 .20969 L .664 .741 .908 r
F
.76399 .21197 m .76111 .20776 L .76764 .20546 L F
.57005 .21198 m .57307 .20548 L .57636 .2097 L .663 .741 .908 r
F
.57005 .21198 m .56676 .20776 L .57307 .20548 L F
.67498 .2118 m .67834 .2053 L .6814 .20952 L F
.67498 .2118 m .6719 .20758 L .67834 .2053 L F
.77992 .21162 m .78362 .20512 L .78647 .20934 L F
.77992 .21162 m .77706 .20741 L .78362 .20512 L F
.28704 .21207 m .28852 .21351 L .29194 .22395 L 0 0 .495 r
F
.28704 .21207 m .28316 .20767 L .28852 .21351 L F
.58594 .21163 m .58902 .20512 L .59227 .20935 L .664 .741 .908 r
F
.58594 .21163 m .58268 .20742 L .58902 .20512 L F
.37208 .25182 m .36983 .21833 L .37566 .22117 L .48 .312 .575 r
F
.36554 .26224 m .36983 .21833 L .37208 .25182 L .665 .454 .589 r
F
.36554 .26224 m .36322 .23089 L .36983 .21833 L F
.36983 .21833 m .37207 .21438 L .37566 .22117 L .73 .981 .76 r
F
.36983 .21833 m .36579 .22025 L .37207 .21438 L F
.36322 .23089 m .36579 .22025 L .36983 .21833 L .433 .378 .697 r
F
.69089 .21145 m .6943 .20494 L .69733 .20916 L .664 .741 .908 r
F
.69089 .21145 m .68784 .20723 L .6943 .20494 L F
.79585 .21127 m .7996 .20476 L .80241 .20898 L .663 .741 .908 r
F
.79585 .21127 m .79303 .20705 L .7996 .20476 L F
.21382 .21128 m .21569 .20476 L .21972 .20899 L .664 .741 .908 r
F
.21382 .21128 m .20977 .20706 L .21569 .20476 L F
.60184 .21128 m .60496 .20476 L .60818 .20898 L .664 .742 .908 r
F
.60184 .21128 m .59861 .20706 L .60496 .20476 L F
.7068 .21109 m .71027 .20458 L .71327 .20881 L .663 .741 .908 r
F
.7068 .21109 m .70379 .20687 L .71027 .20458 L F
.22965 .21092 m .23157 .20442 L .23558 .20865 L F
.22965 .21092 m .22564 .2067 L .23157 .20442 L F
.61774 .21092 m .62092 .20441 L .62411 .20864 L F
.61774 .21092 m .61454 .2067 L .62092 .20441 L F
.72272 .21075 m .72624 .20424 L .72921 .20847 L F
.72272 .21075 m .71975 .20653 L .72624 .20424 L F
.63365 .21058 m .63688 .20406 L .64003 .20829 L .664 .741 .908 r
F
.63365 .21058 m .63048 .20635 L .63688 .20406 L F
.24549 .2106 m .24746 .20407 L .25143 .2083 L F
.24549 .2106 m .24151 .20638 L .24746 .20407 L F
.45285 .26415 m .44973 .24233 L .45557 .25471 L .175 .132 .566 r
F
.44651 .27252 m .44973 .24233 L .45285 .26415 L .681 .491 .623 r
F
.44651 .27252 m .44338 .25169 L .44973 .24233 L F
.44973 .24233 m .45246 .23169 L .45557 .25471 L .345 .287 .649 r
F
.73865 .21039 m .74222 .20387 L .74515 .2081 L .664 .741 .908 r
F
.73865 .21039 m .73571 .20617 L .74222 .20387 L F
.54456 .21042 m .5475 .20388 L .55084 .20811 L .665 .741 .907 r
F
.54456 .21042 m .5412 .2062 L .5475 .20388 L F
.64956 .21022 m .65284 .2037 L .65596 .20793 L .664 .741 .908 r
F
.64956 .21022 m .64643 .206 L .65284 .2037 L F
.26134 .21023 m .26336 .2037 L .2673 .20793 L F
.26134 .21023 m .25739 .206 L .26336 .2037 L F
.43086 .26326 m .43382 .24376 L .43686 .26651 L .944 .838 .4 r
F
.43086 .26326 m .42679 .27421 L .43382 .24376 L F
.56046 .21004 m .56345 .20353 L .56676 .20776 L .663 .741 .908 r
F
.56046 .21004 m .55714 .20582 L .56345 .20353 L F
.75458 .21004 m .75821 .20352 L .76111 .20776 L F
.75458 .21004 m .75167 .20582 L .75821 .20352 L F
.33495 .38335 m .34 .33004 L .34233 .3591 L .992 .796 .417 r
F
.33495 .38335 m .32945 .40681 L .34 .33004 L F
.66548 .20987 m .66881 .20335 L .6719 .20758 L .663 .741 .908 r
F
.66548 .20987 m .66238 .20564 L .66881 .20335 L F
.27719 .20988 m .27926 .20337 L .28316 .20767 L F
.27719 .20988 m .27327 .20566 L .27926 .20337 L F
.32739 .30192 m .32929 .30137 L .33489 .2769 L 0 0 .022 r
F
.33489 .2769 m .32929 .30137 L .33842 .24975 L .915 .796 .32 r
F
.32929 .30137 m .33282 .27482 L .33842 .24975 L .999 .83 .534 r
F
.77052 .20969 m .7742 .20317 L .77706 .20741 L .663 .741 .908 r
F
.77052 .20969 m .76764 .20546 L .7742 .20317 L F
.57636 .2097 m .5794 .20318 L .58268 .20742 L F
.57636 .2097 m .57307 .20548 L .5794 .20318 L F
.6814 .20952 m .68479 .203 L .68784 .20723 L .664 .741 .908 r
F
.6814 .20952 m .67834 .2053 L .68479 .203 L F
.78647 .20934 m .79019 .20281 L .79303 .20705 L F
.78647 .20934 m .78362 .20512 L .79019 .20281 L F
.35011 .36282 m .34568 .37087 L .3529 .34799 L .964 .884 .497 r
F
.59227 .20935 m .59536 .20283 L .59861 .20706 L .664 .741 .908 r
F
.59227 .20935 m .58902 .20512 L .59536 .20283 L F
.69733 .20916 m .70077 .20264 L .70379 .20687 L F
.69733 .20916 m .6943 .20494 L .70077 .20264 L F
.60818 .20898 m .61133 .20246 L .61454 .2067 L .663 .741 .908 r
F
.60818 .20898 m .60496 .20476 L .61133 .20246 L F
.21972 .20899 m .22161 .20246 L .22564 .2067 L F
.21972 .20899 m .21569 .20476 L .22161 .20246 L F
.71327 .20881 m .71676 .20229 L .71975 .20653 L F
.71327 .20881 m .71027 .20458 L .71676 .20229 L F
.62411 .20864 m .62731 .20212 L .63048 .20635 L F
.62411 .20864 m .62092 .20441 L .62731 .20212 L F
.23558 .20865 m .23751 .20214 L .24151 .20638 L F
.23558 .20865 m .23157 .20442 L .23751 .20214 L F
.45018 .27223 m .45285 .26415 L .45634 .27067 L .921 .964 .786 r
F
.45018 .27223 m .44651 .27252 L .45285 .26415 L F
.36322 .23089 m .35995 .218 L .36579 .22025 L .433 .378 .697 r
F
.35559 .26163 m .35995 .218 L .36322 .23089 L .695 .48 .593 r
F
.35559 .26163 m .35318 .23287 L .35995 .218 L F
.36344 .26355 m .36554 .26224 L .36877 .27666 L 0 0 0 r
F
.36344 .26355 m .35879 .27628 L .36554 .26224 L F
.35879 .27628 m .36322 .23089 L .36554 .26224 L .866 .637 .59 r
F
.35879 .27628 m .35559 .26163 L .36322 .23089 L F
.35995 .218 m .36026 .24943 L .36579 .22025 L .729 .395 .414 r
F
.35995 .218 m .35508 .23409 L .36026 .24943 L F
.35318 .23287 m .35508 .23409 L .35995 .218 L 0 0 .371 r
F
.53206 .22574 m .52867 .21741 L .53493 .20847 L .797 .657 .707 r
F
.53493 .20847 m .53784 .20196 L .5412 .2062 L .662 .741 .908 r
F
.53493 .20847 m .53155 .20423 L .53784 .20196 L F
.52867 .21741 m .53155 .20423 L .53493 .20847 L .777 .682 .759 r
F
.72921 .20847 m .73275 .20193 L .73571 .20617 L .664 .741 .908 r
F
.72921 .20847 m .72624 .20424 L .73275 .20193 L F
.37349 .26074 m .37466 .27962 L .37909 .26896 L .554 .221 .359 r
F
.37349 .26074 m .36877 .27666 L .37466 .27962 L F
.64003 .20829 m .64328 .20176 L .64643 .206 L .664 .741 .908 r
F
.64003 .20829 m .63688 .20406 L .64328 .20176 L F
.25143 .2083 m .25342 .20176 L .25739 .206 L .664 .742 .908 r
F
.25143 .2083 m .24746 .20407 L .25342 .20176 L F
.4405 .26861 m .44338 .25169 L .44651 .27252 L .95 .817 .677 r
F
.4405 .26861 m .43686 .26651 L .44338 .25169 L F
.74515 .2081 m .74875 .20157 L .75167 .20582 L .664 .741 .908 r
F
.74515 .2081 m .74222 .20387 L .74875 .20157 L F
.55084 .20811 m .5538 .20157 L .55714 .20582 L .664 .742 .908 r
F
.55084 .20811 m .5475 .20388 L .5538 .20157 L F
.53656 .30692 m .54003 .41515 L .54344 .40341 L .962 .686 .253 r
F
.53297 .40576 m .53545 .23596 L .53885 .24822 L .951 .674 .476 r
F
.53297 .40576 m .52939 .38693 L .53545 .23596 L F
.65596 .20793 m .65927 .2014 L .66238 .20564 L .663 .741 .908 r
F
.65596 .20793 m .65284 .2037 L .65927 .2014 L F
.2673 .20793 m .26934 .20142 L .27327 .20566 L .662 .741 .908 r
F
.2673 .20793 m .26336 .2037 L .26934 .20142 L F
.52939 .38693 m .52584 .36238 L .53206 .22574 L .938 .661 .488 r
F
.76111 .20776 m .76475 .20122 L .76764 .20546 L .664 .741 .908 r
F
.76111 .20776 m .75821 .20352 L .76475 .20122 L F
.56676 .20776 m .56977 .20123 L .57307 .20548 L .663 .741 .908 r
F
.56676 .20776 m .56345 .20353 L .56977 .20123 L F
.6719 .20758 m .67526 .20105 L .67834 .2053 L F
.6719 .20758 m .66881 .20335 L .67526 .20105 L F
.28316 .20767 m .28494 .20515 L .28852 .21351 L .185 .506 .91 r
F
.28316 .20767 m .27926 .20337 L .28494 .20515 L F
.77706 .20741 m .78076 .20087 L .78362 .20512 L .664 .742 .908 r
F
.77706 .20741 m .7742 .20317 L .78076 .20087 L F
.58268 .20742 m .58575 .20088 L .58902 .20512 L F
.58268 .20742 m .5794 .20318 L .58575 .20088 L F
.68784 .20723 m .69125 .20069 L .6943 .20494 L .664 .741 .908 r
F
.68784 .20723 m .68479 .203 L .69125 .20069 L F
.47455 .23075 m .47126 .21404 L .47649 .27422 L .951 .656 .214 r
F
.46262 .26461 m .45889 .26959 L .46513 .26658 L .105 0 0 r
F
.459 .26953 m .46144 .26975 L .46513 .26658 L 0 0 .478 r
F
.45889 .26959 m .46144 .26975 L .459 .26953 L F
.45672 .27031 m .45889 .26959 L .46262 .26461 L 0 .216 .737 r
F
.45634 .27067 m .45889 .26959 L .45672 .27031 L F
.45889 .26959 m .45557 .25471 L .46109 .26886 L 0 0 .478 r
F
.45889 .26959 m .46109 .26886 L .46144 .26975 L F
.46079 .26275 m .45823 .24861 L .46016 .25588 L 0 0 .412 r
F
.46144 .26975 m .46056 .26399 L .46079 .26275 L F
.46056 .26399 m .45823 .24861 L .46079 .26275 L F
.46513 .26658 m .46144 .26975 L .46396 .26162 L .995 .869 .561 r
F
.46584 .26221 m .46396 .26162 L .46806 .2484 L F
.46513 .26658 m .46396 .26162 L .46584 .26221 L F
.46144 .26975 m .464 .27037 L .46806 .2484 L 0 0 .412 r
F
.46172 .26978 m .46139 .26687 L .46369 .26995 L F
.46097 .26311 m .46016 .25588 L .46147 .26083 L F
.46144 .26975 m .46016 .25588 L .46172 .26978 L F
.46144 .26975 m .4639 .26997 L .464 .27037 L F
.46016 .26648 m .45823 .24861 L .46144 .26975 L .027 .021 .512 r
F
.45557 .25471 m .45823 .24861 L .46016 .26648 L F
.45823 .24861 m .45519 .22137 L .45631 .23081 L 0 0 .11 r
F
.45823 .24861 m .45974 .26028 L .46147 .26083 L F
.45974 .26028 m .46043 .26558 L .46147 .26083 L F
.45823 .24861 m .45631 .23081 L .46041 .26539 L F
.45519 .22137 m .45744 .23369 L .4604 .26527 L .862 .495 0 r
F
.46041 .26539 m .4604 .26527 L .46043 .26558 L F
.45519 .22137 m .4604 .26527 L .46041 .26539 L F
.45847 .22897 m .45947 .2057 L .46334 .19604 L .616 .415 .588 r
F
.45246 .23169 m .45519 .22137 L .45823 .24861 L .586 .536 .765 r
F
.45246 .23169 m .44903 .22263 L .45519 .22137 L F
.44931 .22257 m .45172 .21383 L .45519 .22137 L .696 .74 .232 r
F
.44903 .22263 m .45172 .21383 L .44931 .22257 L F
.45519 .22137 m .45172 .21383 L .45384 .2212 L .862 .495 0 r
F
.45172 .21383 m .44762 .23081 L .45121 .21662 L 0 0 0 r
F
.45578 .22457 m .45384 .2212 L .45744 .23369 L .862 .495 0 r
F
.45519 .22137 m .45384 .2212 L .45578 .22457 L F
.45172 .21383 m .45445 .20383 L .45744 .23369 L 0 0 0 r
F
.45172 .21383 m .45121 .21662 L .45414 .20505 L F
.45172 .21383 m .45414 .20505 L .45445 .20383 L F
.45143 .21476 m .44762 .23081 L .45172 .21383 L F
.44504 .23484 m .44637 .23276 L .44728 .2278 L F
.44504 .23484 m .4409 .25046 L .44567 .23652 L F
.44637 .23276 m .44567 .23652 L .44762 .23081 L F
.44504 .23484 m .44567 .23652 L .44637 .23276 L F
.4409 .25046 m .44341 .24921 L .44762 .23081 L 0 .289 .789 r
F
.44418 .24441 m .44643 .22905 L .45079 .20327 L .865 .705 .682 r
F
.44374 .24715 m .44403 .24525 L .44418 .24441 L F
.44403 .24525 m .44643 .22905 L .44418 .24441 L F
.44341 .24921 m .44362 .24782 L .44374 .24715 L F
.44362 .24782 m .44643 .22905 L .44374 .24715 L F
.44728 .2278 m .44762 .23081 L .45143 .21476 L 0 0 0 r
F
.44637 .23276 m .44762 .23081 L .44728 .2278 L F
.44762 .23081 m .44341 .24921 L .44374 .24715 L .913 .787 .306 r
F
.44762 .23081 m .44374 .24715 L .45079 .20327 L F
.45121 .21662 m .45079 .20327 L .45445 .20383 L F
.44762 .23081 m .44958 .21379 L .45121 .21662 L F
.44958 .21379 m .45079 .20327 L .45121 .21662 L F
.45744 .23369 m .45553 .21463 L .45833 .24813 L .78 .569 0 r
F
.45744 .23369 m .45833 .24813 L .45865 .25057 L F
.46147 .26083 m .46043 .26558 L .464 .27037 L 0 0 .11 r
F
.464 .27037 m .46043 .26558 L .4659 .23353 L .958 .725 .544 r
F
.46043 .26558 m .45744 .23369 L .46025 .24094 L .241 .144 .54 r
F
.46688 .23226 m .4659 .23353 L .46747 .22434 L .958 .725 .544 r
F
.464 .27037 m .4659 .23353 L .46688 .23226 L F
.46227 .25477 m .46335 .24893 L .46747 .22434 L .241 .144 .54 r
F
.46043 .26558 m .46323 .2496 L .46227 .25477 L F
.46323 .2496 m .46335 .24893 L .46227 .25477 L F
.46043 .26558 m .46025 .24094 L .46335 .24893 L F
.45823 .24861 m .46041 .26539 L .46041 .26546 L 0 0 .11 r
F
.46025 .24094 m .45941 .26109 L .46335 .24893 L .78 .569 0 r
F
.45744 .23369 m .45816 .24368 L .46025 .24094 L F
.45816 .24368 m .45941 .26109 L .46025 .24094 L F
.45746 .23575 m .45822 .22439 L .45847 .22897 L .616 .415 .588 r
F
.45822 .22439 m .45947 .2057 L .45847 .22897 L F
.45865 .25057 m .45833 .24813 L .45941 .26109 L .78 .569 0 r
F
.45553 .21463 m .4549 .20897 L .45941 .26109 L F
.45557 .25471 m .45246 .23169 L .45823 .24861 L .027 .021 .512 r
F
.45445 .20383 m .45604 .24542 L .45941 .26109 L .947 .607 .342 r
F
.45705 .23855 m .45715 .23256 L .45746 .23575 L .616 .415 .588 r
F
.45604 .24542 m .4568 .23663 L .45705 .23855 L F
.4568 .23663 m .45715 .23256 L .45705 .23855 L F
.45715 .23256 m .45947 .2057 L .45746 .23575 L F
.46041 .26546 m .46041 .26539 L .46043 .26558 L 0 0 .11 r
F
.45553 .21463 m .45445 .20383 L .4549 .20897 L .78 .569 0 r
F
.46864 .24218 m .4684 .23624 L .47126 .21404 L .915 .77 .285 r
F
.464 .27037 m .46747 .22434 L .47126 .21404 L .958 .725 .544 r
F
.47126 .21404 m .46747 .22434 L .47301 .26451 L .886 .551 .41 r
F
.46811 .22896 m .46985 .23637 L .47301 .26451 L .206 0 .302 r
F
.46747 .22434 m .46804 .2272 L .46811 .22896 L F
.46804 .2272 m .46985 .23637 L .46811 .22896 L F
.46806 .2484 m .464 .27037 L .4684 .23624 L .915 .77 .285 r
F
.46806 .2484 m .4684 .23624 L .46864 .24218 L F
.47126 .21404 m .47301 .26451 L .47649 .27422 L .886 .551 .41 r
F
.79303 .20705 m .79678 .20051 L .7996 .20476 L .663 .741 .908 r
F
.79303 .20705 m .79019 .20281 L .79678 .20051 L F
.59861 .20706 m .60173 .20051 L .60496 .20476 L .664 .742 .908 r
F
.59861 .20706 m .59536 .20283 L .60173 .20051 L F
.53652 .41583 m .53885 .24822 L .54226 .26247 L .965 .689 .461 r
F
.53652 .41583 m .53297 .40576 L .53885 .24822 L F
.70379 .20687 m .70725 .20034 L .71027 .20458 L .663 .741 .908 r
F
.70379 .20687 m .70077 .20264 L .70725 .20034 L F
.61454 .2067 m .61772 .20016 L .62092 .20441 L F
.61454 .2067 m .61133 .20246 L .61772 .20016 L F
.22564 .2067 m .22755 .20017 L .23157 .20442 L F
.22564 .2067 m .22161 .20246 L .22755 .20017 L F
.71975 .20653 m .72326 .19999 L .72624 .20424 L .664 .741 .908 r
F
.71975 .20653 m .71676 .20229 L .72326 .19999 L F
.63048 .20635 m .63371 .19981 L .63688 .20406 L F
.63048 .20635 m .62731 .20212 L .63371 .19981 L F
.52584 .36238 m .52232 .33527 L .52867 .21741 L .926 .651 .499 r
F
.52867 .21741 m .52528 .21062 L .53155 .20423 L .777 .682 .759 r
F
.52232 .33527 m .52528 .21062 L .52867 .21741 L .915 .642 .51 r
F
.24151 .20638 m .24347 .19983 L .24746 .20407 L .664 .741 .908 r
F
.24151 .20638 m .23751 .20214 L .24347 .19983 L F
.73571 .20617 m .73927 .19962 L .74222 .20387 L F
.73571 .20617 m .73275 .20193 L .73927 .19962 L F
.5412 .2062 m .54414 .19964 L .5475 .20388 L .665 .742 .907 r
F
.5412 .2062 m .53784 .20196 L .54414 .19964 L F
.31803 .22174 m .31483 .2082 L .32016 .21634 L .069 .122 .611 r
F
.31085 .24048 m .31483 .2082 L .31803 .22174 L .648 .456 .609 r
F
.31085 .24048 m .3084 .2163 L .31483 .2082 L F
.31512 .20864 m .31677 .2055 L .32016 .21634 L 0 0 0 r
F
.31803 .22174 m .32016 .21634 L .32233 .24583 L .069 .122 .611 r
F
.32 .25375 m .31803 .22174 L .32233 .24583 L 0 0 .413 r
F
.32 .25375 m .32233 .24583 L .32376 .26598 L F
.32329 .2702 m .32376 .26598 L .32449 .27621 L F
.32 .25375 m .32376 .26598 L .32329 .2702 L F
.32788 .28792 m .32449 .27621 L .3276 .26668 L .86 .649 .616 r
F
.32965 .27281 m .3276 .26668 L .33193 .2534 L F
.32788 .28792 m .3276 .26668 L .32965 .27281 L F
.32376 .26598 m .32233 .24583 L .32446 .25897 L 0 0 .366 r
F
.32449 .27621 m .3266 .27216 L .33193 .2534 L F
.32376 .26598 m .32446 .25897 L .3266 .27216 L F
.32395 .2558 m .32308 .26215 L .3266 .27216 L .759 .57 0 r
F
.32233 .24583 m .32261 .2518 L .32395 .2558 L F
.32261 .2518 m .32308 .26215 L .32395 .2558 L F
.32449 .27621 m .32376 .26598 L .3266 .27216 L 0 0 .366 r
F
.32308 .26215 m .32648 .23838 L .32657 .23795 L .36 .222 .555 r
F
.32618 .2418 m .32657 .23795 L .32734 .23417 L F
.32308 .26215 m .32657 .23795 L .32618 .2418 L F
.32626 .24424 m .32827 .22966 L .33248 .20912 L F
.33193 .2534 m .3266 .27216 L .33471 .22025 L .993 .802 .427 r
F
.3352 .22177 m .33471 .22025 L .33663 .208 L F
.33193 .2534 m .33471 .22025 L .3352 .22177 L F
.3266 .27216 m .33248 .20912 L .33663 .208 L .928 .685 .551 r
F
.3331 .21527 m .3332 .22718 L .33619 .24559 L .257 0 .317 r
F
.33248 .20912 m .33267 .21393 L .3331 .21527 L F
.33267 .21393 m .3332 .22718 L .3331 .21527 L F
.33663 .208 m .33248 .20912 L .33619 .24559 L .93 .595 .379 r
F
.3266 .27216 m .32308 .26215 L .33248 .20912 L .928 .685 .551 r
F
.32612 .245 m .32734 .23417 L .32827 .22966 L .36 .222 .555 r
F
.32612 .245 m .32827 .22966 L .32626 .24424 L F
.32308 .26215 m .32734 .23417 L .32612 .245 L F
.33248 .20912 m .32648 .23838 L .3332 .22718 L .257 0 .317 r
F
.3332 .22718 m .33128 .20781 L .33636 .20676 L .408 .277 .589 r
F
.33128 .20781 m .33068 .20182 L .33195 .20292 L F
.33128 .20781 m .33195 .20292 L .33636 .20676 L F
.32233 .24583 m .32016 .21634 L .32258 .25425 L .759 .57 0 r
F
.32295 .25918 m .32258 .25425 L .32308 .26215 L F
.32233 .24583 m .32258 .25425 L .32295 .25918 L F
.32016 .21634 m .32105 .2298 L .32301 .26092 L .9 .576 .087 r
F
.32303 .26134 m .32301 .26092 L .32308 .26215 L F
.32016 .21634 m .32301 .26092 L .32303 .26134 L F
.32096 .22741 m .32213 .20544 L .32722 .19139 L .512 .32 .557 r
F
.32016 .21634 m .31993 .21559 L .32105 .2298 L .9 .576 .087 r
F
.31973 .21497 m .31677 .2055 L .31859 .21585 L F
.32006 .21973 m .31859 .21585 L .32056 .22698 L F
.31973 .21497 m .31859 .21585 L .32006 .21973 L F
.31677 .2055 m .31868 .20171 L .32056 .22698 L 0 0 0 r
F
.31868 .20171 m .31881 .20145 L .32056 .22698 L F
.31677 .2055 m .31461 .21084 L .31843 .20234 L F
.31461 .21084 m .31174 .21793 L .31498 .21038 L F
.31461 .21084 m .31498 .21038 L .31843 .20234 L F
.31677 .2055 m .31843 .20234 L .31881 .20145 L F
.31483 .2082 m .31677 .2055 L .31512 .20864 L F
.31483 .2082 m .30994 .21872 L .31677 .2055 L F
.31419 .2105 m .31174 .21793 L .31677 .2055 L 0 0 .022 r
F
.30994 .21872 m .31174 .21793 L .31419 .2105 L F
.30436 .28338 m .30151 .26473 L .2999 .37137 L .983 .701 .392 r
F
.30151 .26473 m .29479 .38212 L .2999 .37137 L .977 .694 .42 r
F
.3069 .30679 m .30436 .28338 L .30567 .35011 L .969 .698 .277 r
F
.30436 .28338 m .2999 .37137 L .30567 .35011 L .983 .701 .392 r
F
.29479 .38212 m .3084 .2163 L .31085 .24048 L .959 .699 .5 r
F
.30151 .26473 m .29844 .2494 L .29537 .36105 L .977 .694 .42 r
F
.29597 .36161 m .29537 .36105 L .29479 .38212 L F
.30151 .26473 m .29537 .36105 L .29597 .36161 L F
.29844 .2494 m .29524 .236 L .2907 .37824 L .974 .691 .429 r
F
.29524 .236 m .28769 .3596 L .2907 .37824 L .972 .688 .429 r
F
.29844 .2494 m .2907 .37824 L .29479 .38212 L .974 .691 .429 r
F
.28828 .35436 m .29986 .21859 L .30478 .20871 L .907 .645 .53 r
F
.28769 .3596 m .28815 .35423 L .28828 .35436 L F
.28815 .35423 m .29986 .21859 L .28828 .35436 L F
.29479 .38212 m .2907 .37824 L .3084 .2163 L .959 .699 .5 r
F
.2907 .37824 m .30478 .20871 L .3084 .2163 L .936 .673 .513 r
F
.30994 .21872 m .30375 .24655 L .31174 .21793 L 0 0 .022 r
F
.30375 .24655 m .30572 .24338 L .31174 .21793 L 0 0 0 r
F
.30965 .21269 m .30918 .21438 L .31376 .17921 L .971 .815 .395 r
F
.3084 .2163 m .30994 .21872 L .31483 .2082 L 0 0 .359 r
F
.3084 .2163 m .30478 .20871 L .30994 .21872 L F
.30478 .20871 m .30375 .24655 L .30994 .21872 L .851 .516 .419 r
F
.2907 .37824 m .28769 .3596 L .30478 .20871 L .936 .673 .513 r
F
.30478 .20871 m .29986 .21859 L .30375 .24655 L .851 .516 .419 r
F
.30918 .21438 m .30391 .2334 L .30912 .20475 L .971 .815 .395 r
F
.30918 .21438 m .30912 .20475 L .31376 .17921 L F
.31174 .21793 m .30906 .22924 L .30925 .22547 L .869 .783 .286 r
F
.31174 .21793 m .30925 .22547 L .31499 .19642 L F
.31174 .21793 m .31392 .20352 L .3158 .20847 L F
.3158 .20847 m .31499 .19642 L .31881 .20145 L F
.31392 .20352 m .31499 .19642 L .3158 .20847 L F
.31262 .275 m .31803 .22174 L .32 .25375 L .699 .475 .58 r
F
.31262 .275 m .31085 .24048 L .31803 .22174 L F
.31881 .20145 m .31499 .19642 L .31682 .23385 L .963 .648 .37 r
F
.31774 .23846 m .31682 .23385 L .31749 .24742 L F
.31881 .20145 m .31682 .23385 L .31774 .23846 L F
.31621 .20846 m .31613 .20544 L .31624 .20881 L .187 0 .198 r
F
.31499 .19642 m .31613 .20544 L .31621 .20846 L F
.31499 .19642 m .31624 .20881 L .31563 .20957 L F
.31499 .19642 m .31563 .206 L .31613 .20544 L F
.30572 .24338 m .30965 .21269 L .31499 .19642 L .968 .82 .398 r
F
.31499 .19642 m .30965 .21269 L .31563 .206 L .187 0 .198 r
F
.31205 .21001 m .31376 .17921 L .31613 .20544 L .971 .815 .395 r
F
.30965 .21269 m .31076 .20361 L .31205 .21001 L F
.31076 .20361 m .31376 .17921 L .31205 .21001 L F
.30391 .2334 m .30871 .19086 L .31376 .17921 L .997 .792 .501 r
F
.31376 .17921 m .30871 .19086 L .31225 .22603 L .862 .533 .427 r
F
.30904 .19251 m .31015 .19521 L .31045 .19964 L 0 0 .107 r
F
.30871 .19086 m .30903 .19184 L .30904 .19251 L F
.30903 .19184 m .31015 .19521 L .30904 .19251 L F
.31018 .20544 m .31045 .19964 L .31225 .22603 L F
.30871 .19086 m .31045 .19964 L .31018 .20544 L F
.30906 .22924 m .30572 .24338 L .30923 .22557 L .869 .783 .286 r
F
.30906 .22924 m .30923 .22557 L .30925 .22547 L F
.32051 .22003 m .32213 .20544 L .32096 .22741 L .512 .32 .557 r
F
.32056 .22698 m .31881 .20145 L .32105 .2298 L 0 0 0 r
F
.32105 .2298 m .31881 .20145 L .32025 .24686 L .912 .67 .17 r
F
.32186 .28832 m .32 .25375 L .32449 .27621 L .026 0 .452 r
F
.32086 .24933 m .32025 .24686 L .32073 .26209 L .912 .67 .17 r
F
.32105 .2298 m .32025 .24686 L .32086 .24933 L F
.31785 .29412 m .31745 .32759 L .32183 .32446 L .558 .262 .421 r
F
.31785 .29412 m .31174 .32307 L .31745 .32759 L F
.31454 .30843 m .32 .25375 L .32186 .28832 L .719 .492 .582 r
F
.31454 .30843 m .31262 .275 L .32 .25375 L F
.31881 .20145 m .31749 .24742 L .32073 .26209 L .963 .648 .37 r
F
.31869 .24051 m .32051 .22003 L .32096 .22741 L .512 .32 .557 r
F
.31749 .24742 m .31838 .23929 L .31869 .24051 L F
.31838 .23929 m .32051 .22003 L .31869 .24051 L F
.32308 .26215 m .32105 .2298 L .32648 .23838 L .36 .222 .555 r
F
.32105 .2298 m .32073 .26209 L .32648 .23838 L .912 .67 .17 r
F
.32073 .26209 m .32722 .19139 L .33068 .20182 L .911 .663 .55 r
F
.32073 .26209 m .31749 .24742 L .32722 .19139 L F
.32722 .19139 m .32213 .20544 L .32702 .22282 L .761 .418 .404 r
F
.31749 .24742 m .31613 .20544 L .32213 .20544 L .512 .32 .557 r
F
.32213 .20544 m .32409 .2033 L .32702 .22282 L 0 0 0 r
F
.32213 .20544 m .31756 .22294 L .32409 .2033 L F
.31615 .22015 m .31664 .22111 L .31749 .24742 L .187 0 .198 r
F
.31756 .22294 m .31643 .2273 L .31772 .22325 L 0 0 0 r
F
.31756 .22294 m .31772 .22325 L .32409 .2033 L F
.31563 .20957 m .31624 .20881 L .31664 .22111 L .187 0 .198 r
F
.31563 .20957 m .31664 .22111 L .31615 .22015 L F
.64643 .206 m .64971 .19945 L .65284 .2037 L .664 .741 .908 r
F
.64643 .206 m .64328 .20176 L .64971 .19945 L F
.25739 .206 m .2594 .19945 L .26336 .2037 L F
.25739 .206 m .25342 .20176 L .2594 .19945 L F
.37802 .25335 m .37566 .22117 L .38054 .24481 L 0 0 .444 r
F
.37208 .25182 m .37566 .22117 L .37802 .25335 L .48 .312 .575 r
F
.37566 .22117 m .37809 .21397 L .38054 .24481 L .539 .574 .838 r
F
.37566 .22117 m .37207 .21438 L .37809 .21397 L F
.45634 .27067 m .45285 .26415 L .45889 .26959 L 0 .216 .737 r
F
.55714 .20582 m .56012 .19928 L .56345 .20353 L .663 .741 .908 r
F
.55714 .20582 m .5538 .20157 L .56012 .19928 L F
.75167 .20582 m .75529 .19927 L .75821 .20352 L F
.75167 .20582 m .74875 .20157 L .75529 .19927 L F
.43649 .23426 m .43872 .241 L .44276 .22864 L .228 0 .19 r
F
.43649 .23426 m .43241 .24651 L .43872 .241 L F
.66238 .20564 m .66571 .1991 L .66881 .20335 L .664 .741 .908 r
F
.66238 .20564 m .65927 .2014 L .66571 .1991 L F
.27327 .20566 m .27533 .19911 L .27926 .20337 L .663 .741 .908 r
F
.27327 .20566 m .26934 .20142 L .27533 .19911 L F
.44276 .22864 m .43872 .241 L .44504 .23484 L .196 0 .18 r
F
.35318 .23287 m .35004 .21779 L .35508 .23409 L 0 0 .371 r
F
.35008 .25317 m .35318 .23287 L .35559 .26163 L .908 .814 .343 r
F
.35004 .21779 m .35002 .25226 L .35508 .23409 L .855 .512 .403 r
F
.35004 .21779 m .34552 .22627 L .35002 .25226 L F
.76764 .20546 m .77132 .19892 L .7742 .20317 L .663 .741 .908 r
F
.76764 .20546 m .76475 .20122 L .77132 .19892 L F
.57307 .20548 m .57611 .19893 L .5794 .20318 L F
.57307 .20548 m .56977 .20123 L .57611 .19893 L F
.67834 .2053 m .68172 .19874 L .68479 .203 L .664 .741 .908 r
F
.67834 .2053 m .67526 .20105 L .68172 .19874 L F
.78362 .20512 m .78734 .19856 L .79019 .20281 L F
.78362 .20512 m .78076 .20087 L .78734 .19856 L F
.58902 .20512 m .59211 .19857 L .59536 .20283 L .663 .741 .908 r
F
.58902 .20512 m .58575 .20088 L .59211 .19857 L F
.6943 .20494 m .69773 .19838 L .70077 .20264 L .664 .741 .908 r
F
.6943 .20494 m .69125 .20069 L .69773 .19838 L F
.60496 .20476 m .60811 .1982 L .61133 .20246 L F
.60496 .20476 m .60173 .20051 L .60811 .1982 L F
.54007 .33808 m .54344 .40341 L .54674 .38231 L .916 .654 .159 r
F
.54003 .41515 m .54226 .26247 L .5457 .27862 L .979 .708 .442 r
F
.54003 .41515 m .53652 .41583 L .54226 .26247 L F
.71027 .20458 m .71375 .19803 L .71676 .20229 L .663 .741 .908 r
F
.71027 .20458 m .70725 .20034 L .71375 .19803 L F
.62092 .20441 m .62411 .19786 L .62731 .20212 L F
.62092 .20441 m .61772 .20016 L .62411 .19786 L F
.23157 .20442 m .2335 .19788 L .23751 .20214 L F
.23157 .20442 m .22755 .20017 L .2335 .19788 L F
.41341 .26551 m .41054 .23996 L .41709 .22667 L .696 .488 .602 r
F
.41054 .23996 m .41218 .24854 L .41709 .22667 L 0 0 .143 r
F
.41218 .24854 m .41245 .24996 L .41298 .24729 L F
.41218 .24854 m .41298 .24729 L .41709 .22667 L F
.41709 .22667 m .41893 .24024 L .42245 .24847 L .259 0 .307 r
F
.41926 .23755 m .41589 .21875 L .42216 .21414 L .612 .439 .624 r
F
.41709 .22667 m .41245 .24996 L .41893 .24024 L .259 0 .307 r
F
.41893 .24024 m .41868 .23846 L .41926 .23755 L .612 .439 .624 r
F
.41868 .23846 m .41589 .21875 L .41926 .23755 L F
.41054 .23996 m .40743 .22173 L .41245 .24996 L 0 0 .143 r
F
.404 .25222 m .3999 .2585 L .40743 .22173 L 1 .817 .499 r
F
.40743 .22173 m .40872 .24705 L .41245 .24996 L .741 .388 .383 r
F
.40743 .22173 m .40313 .23368 L .40872 .24705 L F
.53155 .20423 m .53446 .1977 L .53784 .20196 L .664 .743 .909 r
F
.53155 .20423 m .52816 .20001 L .53446 .1977 L F
.52528 .21062 m .52816 .20001 L .53155 .20423 L .758 .708 .805 r
F
.72624 .20424 m .72978 .19767 L .73275 .20193 L .664 .741 .908 r
F
.72624 .20424 m .72326 .19999 L .72978 .19767 L F
.49732 .24936 m .4996 .30636 L .50319 .30044 L .794 .475 .45 r
F
.49732 .24936 m .49358 .27271 L .4996 .30636 L F
.63688 .20406 m .64013 .1975 L .64328 .20176 L .664 .741 .908 r
F
.63688 .20406 m .63371 .19981 L .64013 .1975 L F
.24746 .20407 m .24944 .1975 L .25342 .20176 L .665 .742 .908 r
F
.24746 .20407 m .24347 .19983 L .24944 .1975 L F
.74222 .20387 m .74581 .19732 L .74875 .20157 L .664 .741 .908 r
F
.74222 .20387 m .73927 .19962 L .74581 .19732 L F
.5475 .20388 m .55045 .19731 L .5538 .20157 L .664 .742 .908 r
F
.5475 .20388 m .54414 .19964 L .55045 .19731 L F
.52232 .33527 m .51883 .30814 L .52528 .21062 L .915 .642 .51 r
F
.52528 .21062 m .52188 .20491 L .52816 .20001 L .758 .708 .805 r
F
.51883 .30814 m .52188 .20491 L .52528 .21062 L .903 .635 .522 r
F
.65284 .2037 m .65614 .19714 L .65927 .2014 L .663 .741 .908 r
F
.65284 .2037 m .64971 .19945 L .65614 .19714 L F
.26336 .2037 m .26539 .19716 L .26934 .20142 L F
.26336 .2037 m .2594 .19945 L .26539 .19716 L F
.75821 .20352 m .76185 .19696 L .76475 .20122 L .664 .741 .908 r
F
.75821 .20352 m .75529 .19927 L .76185 .19696 L F
.56345 .20353 m .56646 .19697 L .56977 .20123 L .663 .741 .908 r
F
.56345 .20353 m .56012 .19928 L .56646 .19697 L F
.37207 .21438 m .37419 .21339 L .37428 .21423 L 0 0 .045 r
F
.37207 .21438 m .36692 .23772 L .37225 .21989 L F
.37324 .21384 m .37225 .21989 L .37419 .21339 L F
.37207 .21438 m .37225 .21989 L .37324 .21384 L F
.36692 .23772 m .36891 .23924 L .37419 .21339 L 0 0 0 r
F
.37419 .21339 m .36891 .23924 L .3741 .21255 L .745 .71 .175 r
F
.37419 .21339 m .3741 .21255 L .37706 .19728 L F
.37565 .20457 m .37576 .20449 L .37706 .19728 L .958 .923 .577 r
F
.37419 .21339 m .37706 .19728 L .38018 .21412 L .745 .71 .175 r
F
.37809 .21397 m .38018 .21412 L .3822 .25525 L 0 .516 .722 r
F
.37809 .21397 m .3764 .21372 L .38018 .21412 L F
.3764 .21372 m .37419 .21339 L .37742 .21378 L F
.3764 .21372 m .37742 .21378 L .38018 .21412 L F
.37706 .19728 m .37908 .19894 L .3802 .21396 L 0 0 .122 r
F
.3822 .25525 m .38087 .22823 L .38494 .24267 L .01 0 .436 r
F
.38087 .22823 m .38018 .21412 L .38207 .22543 L F
.38087 .22823 m .38207 .22543 L .38494 .24267 L F
.38018 .21412 m .3815 .2313 L .38494 .24267 L .852 .581 .044 r
F
.38494 .24267 m .3815 .2313 L .38633 .21456 L .877 .659 .604 r
F
.38775 .21576 m .38633 .21456 L .38876 .20614 L F
.38494 .24267 m .38633 .21456 L .38775 .21576 L F
.3815 .2313 m .38385 .22709 L .38688 .21417 L 0 0 .383 r
F
.3815 .2313 m .38688 .21417 L .38554 .21731 L F
.38018 .21412 m .38015 .21395 L .3815 .2313 L .852 .581 .044 r
F
.38015 .21395 m .37706 .19728 L .3796 .21674 L F
.3808 .22228 m .3796 .21674 L .3815 .2313 L F
.38015 .21395 m .3796 .21674 L .3808 .22228 L F
.37706 .19728 m .3802 .21396 L .37923 .2139 L 0 0 .122 r
F
.37706 .19728 m .37576 .20449 L .37908 .19894 L F
.37576 .20449 m .37662 .20836 L .37908 .19894 L F
.37726 .20592 m .37539 .19328 L .37908 .19894 L .943 .795 .337 r
F
.37428 .21423 m .37419 .21339 L .37809 .21397 L 0 0 .045 r
F
.37576 .20449 m .37158 .2277 L .37662 .20836 L 0 0 .122 r
F
.37002 .23354 m .37158 .2277 L .37576 .20449 L .958 .923 .577 r
F
.37002 .23354 m .37576 .20449 L .37565 .20457 L F
.37158 .2277 m .37509 .19594 L .37726 .20592 L .943 .795 .337 r
F
.37509 .19594 m .37539 .19328 L .37726 .20592 L F
.37923 .2139 m .3802 .21396 L .3815 .2313 L 0 0 .122 r
F
.3815 .2313 m .37908 .19894 L .38385 .22709 L 0 0 .383 r
F
.38095 .20999 m .37971 .23018 L .38385 .22709 L .96 .623 .294 r
F
.37908 .19894 m .37927 .20856 L .38095 .20999 L F
.37927 .20856 m .37971 .23018 L .38095 .20999 L F
.38554 .21731 m .38688 .21417 L .38876 .20614 L 0 0 .383 r
F
.38054 .24481 m .37809 .21397 L .3822 .25525 L 0 0 .153 r
F
.37908 .19894 m .37539 .19328 L .37892 .22339 L .96 .623 .294 r
F
.37962 .22552 m .37892 .22339 L .37971 .23018 L F
.37908 .19894 m .37892 .22339 L .37962 .22552 L F
.37539 .19328 m .37703 .20269 L .37712 .20355 L .074 0 .227 r
F
.37539 .19328 m .37712 .20355 L .37663 .20388 L F
.36891 .23924 m .36951 .23665 L .37002 .23354 L .958 .923 .577 r
F
.36951 .23665 m .37158 .2277 L .37002 .23354 L F
.36692 .23772 m .36225 .25037 L .36891 .23924 L 0 0 0 r
F
.36579 .22025 m .36026 .24943 L .36692 .23772 L .257 .003 .324 r
F
.36232 .21155 m .36388 .2206 L .36504 .23485 L 0 0 .143 r
F
.36891 .23924 m .36492 .24364 L .37133 .22829 L .958 .923 .577 r
F
.36492 .24364 m .36492 .24329 L .37133 .22829 L F
.36026 .24943 m .36225 .25037 L .36692 .23772 L 0 0 0 r
F
.36402 .24741 m .36464 .24395 L .36891 .23924 L 0 0 .474 r
F
.36225 .25037 m .36464 .24395 L .36402 .24741 L F
.36464 .24395 m .36232 .21155 L .36527 .24046 L 0 0 .193 r
F
.36492 .24364 m .36464 .24395 L .36492 .24329 L .958 .923 .577 r
F
.37139 .22852 m .37133 .22829 L .37158 .2277 L F
.36891 .23924 m .37133 .22829 L .37139 .22852 L F
.36464 .24395 m .36635 .25107 L .37158 .2277 L 0 0 .193 r
F
.36464 .24395 m .36527 .24046 L .36635 .25107 L F
.365 .23779 m .36504 .23485 L .36635 .25107 L 0 0 .143 r
F
.36232 .21155 m .36504 .23485 L .365 .23779 L F
.36579 .22025 m .36692 .23772 L .37207 .21438 L .257 .003 .324 r
F
.37041 .22513 m .37016 .21765 L .37539 .19328 L .561 .376 .589 r
F
.36635 .25107 m .36962 .22239 L .37041 .22513 L F
.36962 .22239 m .37016 .21765 L .37041 .22513 L F
.37158 .2277 m .36635 .25107 L .37539 .19328 L .943 .795 .337 r
F
.37539 .19328 m .37016 .21765 L .37703 .20269 L .074 0 .227 r
F
.37416 .20893 m .37391 .1848 L .37703 .20269 L 1 .81 .505 r
F
.37016 .21765 m .37193 .20215 L .37416 .20893 L F
.37193 .20215 m .37391 .1848 L .37416 .20893 L F
.37663 .20388 m .37712 .20355 L .37835 .21617 L .074 0 .227 r
F
.37776 .21352 m .37835 .21617 L .37971 .23018 L F
.37663 .20388 m .37835 .21617 L .37776 .21352 L F
.66881 .20335 m .67217 .19679 L .67526 .20105 L .664 .741 .908 r
F
.66881 .20335 m .66571 .1991 L .67217 .19679 L F
.27926 .20337 m .28118 .19886 L .28494 .20515 L .481 .67 .947 r
F
.27926 .20337 m .27533 .19911 L .28118 .19886 L F
.45285 .26415 m .45557 .25471 L .45889 .26959 L .175 .132 .566 r
F
.7742 .20317 m .77789 .19661 L .78076 .20087 L .664 .742 .908 r
F
.7742 .20317 m .77132 .19892 L .77789 .19661 L F
.5794 .20318 m .58247 .19661 L .58575 .20088 L F
.5794 .20318 m .57611 .19893 L .58247 .19661 L F
.68479 .203 m .68819 .19643 L .69125 .20069 L .664 .741 .908 r
F
.68479 .203 m .68172 .19874 L .68819 .19643 L F
.79019 .20281 m .79394 .19625 L .79678 .20051 L F
.79019 .20281 m .78734 .19856 L .79394 .19625 L F
.59536 .20283 m .59848 .19625 L .60173 .20051 L .664 .742 .908 r
F
.59536 .20283 m .59211 .19857 L .59848 .19625 L F
.70077 .20264 m .70423 .19607 L .70725 .20034 L .663 .741 .908 r
F
.70077 .20264 m .69773 .19838 L .70423 .19607 L F
.61133 .20246 m .6145 .1959 L .61772 .20016 L F
.61133 .20246 m .60811 .1982 L .6145 .1959 L F
.71676 .20229 m .72027 .19572 L .72326 .19999 L .664 .741 .908 r
F
.71676 .20229 m .71375 .19803 L .72027 .19572 L F
.48421 .23696 m .48031 .26048 L .48634 .28068 L .724 .406 .441 r
F
.62731 .20212 m .63053 .19554 L .63371 .19981 L .664 .741 .908 r
F
.62731 .20212 m .62411 .19786 L .63053 .19554 L F
.23751 .20214 m .23946 .19556 L .24347 .19983 L F
.23751 .20214 m .2335 .19788 L .23946 .19556 L F
.73275 .20193 m .73631 .19536 L .73927 .19962 L .663 .741 .908 r
F
.73275 .20193 m .72978 .19767 L .73631 .19536 L F
.53784 .20196 m .54077 .19537 L .54414 .19964 L .664 .742 .908 r
F
.53784 .20196 m .53446 .1977 L .54077 .19537 L F
.64328 .20176 m .64656 .19518 L .64971 .19945 L .664 .741 .908 r
F
.64328 .20176 m .64013 .1975 L .64656 .19518 L F
.25342 .20176 m .25543 .19518 L .2594 .19945 L F
.25342 .20176 m .24944 .1975 L .25543 .19518 L F
.3413 .26513 m .33899 .23569 L .34552 .22627 L .642 .44 .594 r
F
.33899 .23569 m .34046 .24299 L .34552 .22627 L 0 0 .164 r
F
.33866 .23185 m .33663 .208 L .33849 .22504 L F
.33899 .23569 m .33866 .23185 L .34046 .24299 L F
.33866 .23185 m .33849 .22504 L .34046 .24299 L F
.33663 .208 m .33619 .24559 L .34046 .24299 L .93 .595 .379 r
F
.3332 .22718 m .33636 .20676 L .33796 .2039 L .408 .277 .589 r
F
.33809 .20913 m .33796 .2039 L .34097 .19851 L F
.3332 .22718 m .33796 .2039 L .33809 .20913 L F
.5538 .20157 m .55678 .19501 L .56012 .19928 L .663 .741 .908 r
F
.5538 .20157 m .55045 .19731 L .55678 .19501 L F
.74875 .20157 m .75237 .195 L .75529 .19927 L F
.74875 .20157 m .74581 .19732 L .75237 .195 L F
.65927 .2014 m .66259 .19483 L .66571 .1991 L .664 .741 .908 r
F
.65927 .2014 m .65614 .19714 L .66259 .19483 L F
.26934 .20142 m .27139 .19486 L .27533 .19911 L .662 .741 .908 r
F
.26934 .20142 m .26539 .19716 L .27139 .19486 L F
.42662 .23595 m .42864 .2469 L .43241 .24651 L .414 .069 .267 r
F
.42662 .23595 m .42245 .24847 L .42864 .2469 L F
.76475 .20122 m .76842 .19465 L .77132 .19892 L .663 .741 .908 r
F
.76475 .20122 m .76185 .19696 L .76842 .19465 L F
.56977 .20123 m .57281 .19466 L .57611 .19893 L F
.56977 .20123 m .56646 .19697 L .57281 .19466 L F
.67526 .20105 m .67864 .19447 L .68172 .19874 L .664 .741 .908 r
F
.67526 .20105 m .67217 .19679 L .67864 .19447 L F
.54698 .36637 m .54356 .35964 L .54993 .35517 L .727 .664 .788 r
F
.54356 .35964 m .54674 .38231 L .54993 .35517 L .747 .513 0 r
F
.54344 .40341 m .5457 .27862 L .54916 .29671 L .99 .729 .414 r
F
.54344 .40341 m .54003 .41515 L .5457 .27862 L F
.78076 .20087 m .78449 .19429 L .78734 .19856 L .664 .741 .908 r
F
.78076 .20087 m .77789 .19661 L .78449 .19429 L F
.58575 .20088 m .58883 .1943 L .59211 .19857 L F
.58575 .20088 m .58247 .19661 L .58883 .1943 L F
.69125 .20069 m .69468 .19411 L .69773 .19838 L F
.69125 .20069 m .68819 .19643 L .69468 .19411 L F
.52188 .20491 m .52476 .19578 L .52816 .20001 L .74 .727 .84 r
F
.52188 .20491 m .51846 .19983 L .52476 .19578 L F
.60173 .20051 m .60487 .19393 L .60811 .1982 L .664 .741 .908 r
F
.60173 .20051 m .59848 .19625 L .60487 .19393 L F
.70725 .20034 m .71074 .19376 L .71375 .19803 L .663 .741 .908 r
F
.70725 .20034 m .70423 .19607 L .71074 .19376 L F
.61772 .20016 m .62091 .19358 L .62411 .19786 L F
.61772 .20016 m .6145 .1959 L .62091 .19358 L F
.72326 .19999 m .7268 .1934 L .72978 .19767 L .664 .741 .908 r
F
.72326 .19999 m .72027 .19572 L .7268 .1934 L F
.52816 .20001 m .53106 .19342 L .53446 .1977 L .666 .744 .908 r
F
.52816 .20001 m .52476 .19578 L .53106 .19342 L F
.29524 .236 m .29194 .22395 L .28769 .3596 L .972 .688 .429 r
F
.29194 .22395 m .28543 .33125 L .28769 .3596 L .971 .685 .426 r
F
.29194 .22395 m .28852 .21351 L .28543 .33125 L F
.28494 .20515 m .28122 .27256 L .28341 .30048 L .966 .667 .409 r
F
.28341 .30048 m .28122 .27256 L .28134 .27259 L .488 .328 .59 r
F
.28852 .21351 m .28341 .30048 L .2855 .32868 L .969 .678 .419 r
F
.28852 .21351 m .28494 .20515 L .28341 .30048 L F
.28341 .30048 m .28134 .27259 L .28712 .27405 L .488 .328 .59 r
F
.2855 .32868 m .28341 .30048 L .28543 .33125 L .969 .678 .419 r
F
.63371 .19981 m .63695 .19322 L .64013 .1975 L .664 .741 .908 r
F
.63371 .19981 m .63053 .19554 L .63695 .19322 L F
.24347 .19983 m .24544 .19322 L .24944 .1975 L .665 .742 .907 r
F
.24347 .19983 m .23946 .19556 L .24544 .19322 L F
.73927 .19962 m .74286 .19304 L .74581 .19732 L .664 .741 .908 r
F
.73927 .19962 m .73631 .19536 L .74286 .19304 L F
.54414 .19964 m .54709 .19304 L .55045 .19731 L .664 .742 .908 r
F
.54414 .19964 m .54077 .19537 L .54709 .19304 L F
.64971 .19945 m .653 .19286 L .65614 .19714 L .663 .741 .908 r
F
.64971 .19945 m .64656 .19518 L .653 .19286 L F
.2594 .19945 m .26142 .19288 L .26539 .19716 L F
.2594 .19945 m .25543 .19518 L .26142 .19288 L F
.75529 .19927 m .75893 .19268 L .76185 .19696 L .664 .741 .908 r
F
.75529 .19927 m .75237 .195 L .75893 .19268 L F
.56012 .19928 m .56313 .19269 L .56646 .19697 L F
.56012 .19928 m .55678 .19501 L .56313 .19269 L F
.37909 .26896 m .37466 .27962 L .38121 .26909 L 0 0 0 r
F
.66571 .1991 m .66906 .1925 L .67217 .19679 L .664 .741 .908 r
F
.66571 .1991 m .66259 .19483 L .66906 .1925 L F
.27533 .19911 m .27729 .19394 L .28118 .19886 L .551 .702 .94 r
F
.27533 .19911 m .27139 .19486 L .27729 .19394 L F
.77132 .19892 m .77501 .19232 L .77789 .19661 L .664 .742 .908 r
F
.77132 .19892 m .76842 .19465 L .77501 .19232 L F
.57611 .19893 m .57917 .19233 L .58247 .19661 L F
.57611 .19893 m .57281 .19466 L .57917 .19233 L F
.68172 .19874 m .68512 .19215 L .68819 .19643 L .664 .741 .908 r
F
.68172 .19874 m .67864 .19447 L .68512 .19215 L F
.78734 .19856 m .79109 .19197 L .79394 .19625 L F
.78734 .19856 m .78449 .19429 L .79109 .19197 L F
.59211 .19857 m .59522 .19197 L .59848 .19625 L F
.59211 .19857 m .58883 .1943 L .59522 .19197 L F
.69773 .19838 m .70119 .19179 L .70423 .19607 L .663 .741 .908 r
F
.69773 .19838 m .69468 .19411 L .70119 .19179 L F
.28494 .20515 m .28118 .19886 L .28122 .27256 L .966 .667 .409 r
F
.60811 .1982 m .61127 .19161 L .6145 .1959 L .663 .741 .908 r
F
.60811 .1982 m .60487 .19393 L .61127 .19161 L F
.71375 .19803 m .71726 .19143 L .72027 .19572 L .664 .741 .908 r
F
.71375 .19803 m .71074 .19376 L .71726 .19143 L F
.62411 .19786 m .62733 .19125 L .63053 .19554 L F
.62411 .19786 m .62091 .19358 L .62733 .19125 L F
.72978 .19767 m .73334 .19107 L .73631 .19536 L .663 .741 .908 r
F
.72978 .19767 m .7268 .1934 L .73334 .19107 L F
.53446 .1977 m .53738 .19109 L .54077 .19537 L .664 .742 .908 r
F
.53446 .1977 m .53106 .19342 L .53738 .19109 L F
.64013 .1975 m .6434 .19089 L .64656 .19518 L .664 .741 .908 r
F
.64013 .1975 m .63695 .19322 L .6434 .19089 L F
.24944 .1975 m .25144 .1909 L .25543 .19518 L F
.24944 .1975 m .24544 .19322 L .25144 .1909 L F
.55045 .19731 m .55343 .19073 L .55678 .19501 L .663 .741 .908 r
F
.55045 .19731 m .54709 .19304 L .55343 .19073 L F
.74581 .19732 m .74943 .19071 L .75237 .195 L .664 .741 .908 r
F
.74581 .19732 m .74286 .19304 L .74943 .19071 L F
.65614 .19714 m .65947 .19054 L .66259 .19483 L F
.65614 .19714 m .653 .19286 L .65947 .19054 L F
.26539 .19716 m .26743 .19059 L .27139 .19486 L .661 .74 .909 r
F
.26539 .19716 m .26142 .19288 L .26743 .19059 L F
.76185 .19696 m .76552 .19037 L .76842 .19465 L .663 .741 .908 r
F
.76185 .19696 m .75893 .19268 L .76552 .19037 L F
.56646 .19697 m .56949 .19038 L .57281 .19466 L F
.56646 .19697 m .56313 .19269 L .56949 .19038 L F
.51537 .28264 m .51194 .25965 L .51846 .19983 L .891 .63 .536 r
F
.51846 .19983 m .52134 .1915 L .52476 .19578 L .722 .734 .861 r
F
.51846 .19983 m .51503 .19502 L .52134 .1915 L F
.51194 .25965 m .51503 .19502 L .51846 .19983 L .877 .625 .553 r
F
.67217 .19679 m .67554 .19018 L .67864 .19447 L .664 .741 .908 r
F
.67217 .19679 m .66906 .1925 L .67554 .19018 L F
.77789 .19661 m .78161 .19 L .78449 .19429 L .663 .741 .908 r
F
.77789 .19661 m .77501 .19232 L .78161 .19 L F
.58247 .19661 m .58555 .19001 L .58883 .1943 L .664 .741 .908 r
F
.58247 .19661 m .57917 .19233 L .58555 .19001 L F
.45445 .20383 m .45079 .20327 L .45521 .23878 L .947 .607 .342 r
F
.45586 .24068 m .45521 .23878 L .45604 .24542 L F
.45445 .20383 m .45521 .23878 L .45586 .24068 L F
.45079 .20327 m .45306 .21331 L .45604 .24542 L .119 0 .272 r
F
.45079 .20327 m .44643 .22905 L .45306 .21331 L F
.44947 .22185 m .44991 .19048 L .45306 .21331 L .949 .785 .33 r
F
.44643 .22905 m .44758 .2163 L .44947 .22185 L F
.44758 .2163 m .44991 .19048 L .44947 .22185 L F
.37466 .27962 m .37208 .25182 L .37802 .25335 L .498 .338 .594 r
F
.36877 .27666 m .37208 .25182 L .37466 .27962 L .741 .562 .652 r
F
.36877 .27666 m .36554 .26224 L .37208 .25182 L F
.68819 .19643 m .69162 .18982 L .69468 .19411 L .664 .741 .908 r
F
.68819 .19643 m .68512 .19215 L .69162 .18982 L F
.59848 .19625 m .60162 .18964 L .60487 .19393 L F
.59848 .19625 m .59522 .19197 L .60162 .18964 L F
.48977 .22105 m .48645 .20252 L .49255 .21532 L .079 .086 .564 r
F
.4831 .25299 m .48645 .20252 L .48977 .22105 L .683 .463 .581 r
F
.4831 .25299 m .48 .21873 L .48645 .20252 L F
.48645 .20252 m .48922 .19585 L .49255 .21532 L .873 .991 .741 r
F
.48645 .20252 m .48287 .20397 L .48922 .19585 L F
.48 .21873 m .48287 .20397 L .48645 .20252 L .383 .285 .619 r
F
.54674 .38231 m .54916 .29671 L .55265 .31685 L .986 .752 .359 r
F
.54674 .38231 m .54344 .40341 L .54916 .29671 L F
.70423 .19607 m .70771 .18947 L .71074 .19376 L .663 .741 .908 r
F
.70423 .19607 m .70119 .19179 L .70771 .18947 L F
.6145 .1959 m .61769 .18929 L .62091 .19358 L F
.6145 .1959 m .61127 .19161 L .61769 .18929 L F
.48 .21873 m .47673 .19827 L .48287 .20397 L .383 .285 .619 r
F
.47301 .26451 m .47673 .19827 L .48 .21873 L .818 .571 .565 r
F
.47301 .26451 m .46985 .23637 L .47673 .19827 L F
.47902 .2219 m .47497 .24726 L .47606 .2411 L 0 0 0 r
F
.48191 .20308 m .47902 .2219 L .48287 .20397 L .839 .458 .33 r
F
.48031 .26048 m .4831 .25299 L .48634 .28068 L 0 0 0 r
F
.48031 .26048 m .47649 .27422 L .4831 .25299 L F
.47649 .27422 m .48 .21873 L .4831 .25299 L .934 .689 .544 r
F
.47649 .27422 m .47301 .26451 L .48 .21873 L F
.48287 .20397 m .48569 .19331 L .48922 .19585 L 0 0 0 r
F
.48287 .20397 m .47902 .2219 L .48569 .19331 L F
.47902 .2219 m .4819 .20817 L .48569 .19331 L F
.47902 .2219 m .47606 .2411 L .4819 .20817 L F
.47673 .19827 m .47902 .2219 L .48191 .20308 L .839 .458 .33 r
F
.46985 .23637 m .47304 .20415 L .47673 .19827 L .581 .398 .598 r
F
.47673 .19827 m .47304 .20415 L .47902 .2219 L .839 .458 .33 r
F
.72027 .19572 m .7238 .1891 L .7268 .1934 L .664 .741 .908 r
F
.72027 .19572 m .71726 .19143 L .7238 .1891 L F
.52476 .19578 m .52765 .18913 L .53106 .19342 L .667 .743 .907 r
F
.52476 .19578 m .52134 .1915 L .52765 .18913 L F
.63053 .19554 m .63377 .18892 L .63695 .19322 L .664 .741 .908 r
F
.63053 .19554 m .62733 .19125 L .63377 .18892 L F
.3069 .30679 m .30567 .35011 L .31174 .32307 L .969 .698 .277 r
F
.2999 .37137 m .31085 .24048 L .31262 .275 L .979 .729 .484 r
F
.2999 .37137 m .29479 .38212 L .31085 .24048 L F
.28118 .19886 m .27872 .24911 L .28122 .27256 L .962 .653 .392 r
F
.28118 .19886 m .27729 .19394 L .27872 .24911 L F
.73631 .19536 m .7399 .18874 L .74286 .19304 L .664 .741 .908 r
F
.73631 .19536 m .73334 .19107 L .7399 .18874 L F
.54077 .19537 m .54372 .18874 L .54709 .19304 L .665 .742 .908 r
F
.54077 .19537 m .53738 .19109 L .54372 .18874 L F
.64656 .19518 m .64985 .18857 L .653 .19286 L .663 .741 .908 r
F
.64656 .19518 m .6434 .19089 L .64985 .18857 L F
.25543 .19518 m .25744 .18858 L .26142 .19288 L F
.25543 .19518 m .25144 .1909 L .25744 .18858 L F
.75237 .195 m .75601 .18839 L .75893 .19268 L F
.75237 .195 m .74943 .19071 L .75601 .18839 L F
.55678 .19501 m .55979 .18839 L .56313 .19269 L .664 .741 .908 r
F
.55678 .19501 m .55343 .19073 L .55979 .18839 L F
.66259 .19483 m .66594 .18821 L .66906 .1925 L F
.66259 .19483 m .65947 .19054 L .66594 .18821 L F
.26743 .19059 m .26942 .18484 L .27336 .18946 L .598 .719 .929 r
F
.27336 .18946 m .26942 .18484 L .26943 .18495 L .952 .606 .299 r
F
.27139 .19486 m .27336 .18946 L .27727 .19394 L .57 .709 .936 r
F
.27139 .19486 m .26743 .19059 L .27336 .18946 L F
.27336 .18946 m .26943 .18495 L .27297 .21261 L .952 .606 .299 r
F
.27727 .19394 m .27336 .18946 L .27729 .19394 L .57 .709 .936 r
F
.76842 .19465 m .77212 .18803 L .77501 .19232 L .664 .741 .908 r
F
.76842 .19465 m .76552 .19037 L .77212 .18803 L F
.57281 .19466 m .57586 .18804 L .57917 .19233 L .664 .742 .908 r
F
.57281 .19466 m .56949 .19038 L .57586 .18804 L F
.67864 .19447 m .68204 .18785 L .68512 .19215 L .664 .741 .908 r
F
.67864 .19447 m .67554 .19018 L .68204 .18785 L F
.78449 .19429 m .78823 .18767 L .79109 .19197 L F
.78449 .19429 m .78161 .19 L .78823 .18767 L F
.58883 .1943 m .59194 .18767 L .59522 .19197 L F
.58883 .1943 m .58555 .19001 L .59194 .18767 L F
.69468 .19411 m .69814 .18749 L .70119 .19179 L .663 .741 .908 r
F
.69468 .19411 m .69162 .18982 L .69814 .18749 L F
.60487 .19393 m .60803 .18731 L .61127 .19161 L F
.60487 .19393 m .60162 .18964 L .60803 .18731 L F
.71074 .19376 m .71425 .18713 L .71726 .19143 L .664 .741 .908 r
F
.71074 .19376 m .70771 .18947 L .71425 .18713 L F
.62091 .19358 m .62412 .18695 L .62733 .19125 L F
.62091 .19358 m .61769 .18929 L .62412 .18695 L F
.40872 .24705 m .40607 .21597 L .41237 .21068 L .593 .4 .59 r
F
.40607 .21597 m .40823 .21886 L .41237 .21068 L 0 0 .345 r
F
.40607 .21597 m .40285 .20048 L .40823 .21886 L F
.40313 .23368 m .40607 .21597 L .40872 .24705 L .856 .788 .291 r
F
.40285 .20048 m .40419 .2231 L .40823 .21886 L .613 .275 .374 r
F
.7268 .1934 m .73036 .18677 L .73334 .19107 L .663 .741 .908 r
F
.7268 .1934 m .7238 .1891 L .73036 .18677 L F
.53106 .19342 m .53398 .18678 L .53738 .19109 L .664 .741 .908 r
F
.53106 .19342 m .52765 .18913 L .53398 .18678 L F
.46747 .22434 m .46335 .24893 L .46985 .23637 L .206 0 .302 r
F
.63695 .19322 m .64022 .18659 L .6434 .19089 L .664 .741 .908 r
F
.63695 .19322 m .63377 .18892 L .64022 .18659 L F
.54709 .19304 m .55006 .18642 L .55343 .19073 L .663 .741 .908 r
F
.54709 .19304 m .54372 .18874 L .55006 .18642 L F
.74286 .19304 m .74648 .18641 L .74943 .19071 L .664 .741 .908 r
F
.74286 .19304 m .7399 .18874 L .74648 .18641 L F
.51194 .25965 m .50852 .23955 L .51503 .19502 L .877 .625 .553 r
F
.51503 .19502 m .5179 .1872 L .52134 .1915 L .704 .734 .874 r
F
.51503 .19502 m .51159 .19031 L .5179 .1872 L F
.50852 .23955 m .51159 .19031 L .51503 .19502 L .862 .623 .576 r
F
.653 .19286 m .65632 .18623 L .65947 .19054 L .664 .741 .908 r
F
.653 .19286 m .64985 .18857 L .65632 .18623 L F
.26142 .19288 m .26346 .18629 L .26743 .19059 L .66 .74 .909 r
F
.26142 .19288 m .25744 .18858 L .26346 .18629 L F
.34552 .22627 m .34046 .24299 L .34645 .24348 L .489 .159 .333 r
F
.75893 .19268 m .7626 .18606 L .76552 .19037 L .663 .741 .908 r
F
.75893 .19268 m .75601 .18839 L .7626 .18606 L F
.56313 .19269 m .56615 .18607 L .56949 .19038 L F
.56313 .19269 m .55979 .18839 L .56615 .18607 L F
.66906 .1925 m .67243 .18587 L .67554 .19018 L .664 .741 .908 r
F
.66906 .1925 m .66594 .18821 L .67243 .18587 L F
.77501 .19232 m .77873 .18569 L .78161 .19 L .663 .741 .908 r
F
.77501 .19232 m .77212 .18803 L .77873 .18569 L F
.57917 .19233 m .58225 .1857 L .58555 .19001 L .664 .741 .908 r
F
.57917 .19233 m .57586 .18804 L .58225 .1857 L F
.68512 .19215 m .68855 .18551 L .69162 .18982 L F
.68512 .19215 m .68204 .18785 L .68855 .18551 L F
.59522 .19197 m .59835 .18533 L .60162 .18964 L F
.59522 .19197 m .59194 .18767 L .59835 .18533 L F
.70119 .19179 m .70467 .18516 L .70771 .18947 L .663 .741 .908 r
F
.70119 .19179 m .69814 .18749 L .70467 .18516 L F
.38121 .26909 m .37802 .25335 L .38358 .26408 L .032 .073 .572 r
F
.37466 .27962 m .37802 .25335 L .38121 .26909 L .498 .338 .594 r
F
.37802 .25335 m .38054 .24481 L .38358 .26408 L 0 0 .444 r
F
.41245 .24996 m .41589 .21875 L .41893 .24024 L .961 .757 .584 r
F
.41245 .24996 m .40872 .24705 L .41589 .21875 L F
.41589 .21875 m .41842 .21243 L .42216 .21414 L .401 .456 .802 r
F
.41589 .21875 m .41237 .21068 L .41842 .21243 L F
.40872 .24705 m .41237 .21068 L .41589 .21875 L .593 .4 .59 r
F
.61127 .19161 m .61446 .18498 L .61769 .18929 L .663 .741 .908 r
F
.61127 .19161 m .60803 .18731 L .61446 .18498 L F
.27729 .19394 m .27595 .22945 L .27872 .24911 L .959 .635 .36 r
F
.27729 .19394 m .27336 .18946 L .27595 .22945 L F
.71726 .19143 m .7208 .18479 L .7238 .1891 L .664 .741 .908 r
F
.71726 .19143 m .71425 .18713 L .7208 .18479 L F
.52134 .1915 m .52423 .18481 L .52765 .18913 L .666 .742 .907 r
F
.52134 .1915 m .5179 .1872 L .52423 .18481 L F
.62733 .19125 m .63057 .18461 L .63377 .18892 L .664 .741 .908 r
F
.62733 .19125 m .62412 .18695 L .63057 .18461 L F
.73334 .19107 m .73693 .18443 L .7399 .18874 L F
.73334 .19107 m .73036 .18677 L .73693 .18443 L F
.53738 .19109 m .54032 .18443 L .54372 .18874 L .665 .742 .908 r
F
.53738 .19109 m .53398 .18678 L .54032 .18443 L F
.43159 .22887 m .42848 .208 L .43432 .21828 L .218 .165 .582 r
F
.42539 .23046 m .42848 .208 L .43159 .22887 L .664 .5 .653 r
F
.42539 .23046 m .42216 .21414 L .42848 .208 L F
.42848 .208 m .43117 .19826 L .43432 .21828 L .682 .651 .813 r
F
.42848 .208 m .42493 .20141 L .43117 .19826 L F
.42216 .21414 m .42493 .20141 L .42848 .208 L .938 .859 .736 r
F
.49296 .25427 m .48977 .22105 L .49579 .24645 L .018 0 .471 r
F
.48634 .28068 m .48977 .22105 L .49296 .25427 L .798 .557 .574 r
F
.48634 .28068 m .4831 .25299 L .48977 .22105 L F
.48977 .22105 m .49255 .21532 L .49579 .24645 L .079 .086 .564 r
F
.6434 .19089 m .64669 .18425 L .64985 .18857 L .663 .741 .908 r
F
.6434 .19089 m .64022 .18659 L .64669 .18425 L F
.35508 .23409 m .35572 .25859 L .36026 .24943 L .607 .278 .386 r
F
.35508 .23409 m .35002 .25226 L .35572 .25859 L F
.41893 .24024 m .42216 .21414 L .42539 .23046 L .612 .439 .624 r
F
.42216 .21414 m .41842 .21243 L .42493 .20141 L .938 .859 .736 r
F
.35336 .22827 m .35113 .19637 L .35713 .19628 L .519 .342 .581 r
F
.34645 .24348 m .35113 .19637 L .35336 .22827 L .726 .503 .589 r
F
.34645 .24348 m .34404 .21518 L .35113 .19637 L F
.35662 .19628 m .35651 .19669 L .35713 .19628 L .156 0 0 r
F
.35713 .19628 m .35962 .18715 L .36232 .21155 L .945 .956 .665 r
F
.35113 .19637 m .35293 .19913 L .35651 .19669 L .156 0 0 r
F
.35113 .19637 m .35651 .19669 L .35662 .19628 L F
.35713 .19628 m .35293 .19913 L .35962 .18715 L .945 .956 .665 r
F
.36232 .21155 m .35995 .19012 L .36388 .2206 L 0 0 .143 r
F
.35995 .19012 m .35962 .18715 L .35995 .18973 L F
.35995 .19012 m .35995 .18973 L .36388 .2206 L F
.35744 .19104 m .35467 .20343 L .35962 .18715 L 0 0 .134 r
F
.35293 .19913 m .35467 .20343 L .35744 .19104 L F
.34404 .21518 m .34679 .20124 L .35113 .19637 L .432 .34 .651 r
F
.34679 .20124 m .34736 .22488 L .35293 .19913 L .424 .134 .365 r
F
.34404 .21518 m .34097 .19851 L .34679 .20124 L .432 .34 .651 r
F
.33619 .24559 m .34097 .19851 L .34404 .21518 L .835 .605 .59 r
F
.34046 .24299 m .34404 .21518 L .34645 .24348 L .992 .81 .56 r
F
.34046 .24299 m .33619 .24559 L .34404 .21518 L F
.34679 .20124 m .34109 .22817 L .34736 .22488 L .424 .134 .365 r
F
.35293 .19913 m .34736 .22488 L .35467 .20343 L 0 0 .134 r
F
.34788 .22335 m .34917 .22787 L .35467 .20343 L .276 0 0 r
F
.34736 .22488 m .34917 .22787 L .34788 .22335 L F
.35085 .2204 m .34917 .22787 L .35049 .22202 L 0 0 0 r
F
.35661 .1967 m .35732 .19174 L .35995 .18513 L F
.35467 .20343 m .35732 .19174 L .35661 .1967 L F
.35962 .18715 m .36202 .17993 L .36388 .2206 L F
.35962 .18715 m .35522 .2016 L .36202 .17993 L F
.35522 .2016 m .35467 .20343 L .35514 .20192 L F
.35522 .2016 m .35514 .20192 L .36202 .17993 L F
.35467 .20343 m .35995 .18513 L .35995 .18655 L F
.35002 .25226 m .34645 .24348 L .35336 .22827 L .853 .673 .658 r
F
.34917 .22787 m .35083 .23393 L .35715 .19249 L 0 0 .191 r
F
.35467 .20343 m .35184 .21603 L .35732 .19174 L 0 0 0 r
F
.35732 .19174 m .35325 .2182 L .35817 .18578 L .71 .665 .115 r
F
.35325 .2182 m .35435 .21085 L .35817 .18578 L F
.35732 .19174 m .35817 .18578 L .36051 .17049 L F
.35995 .18655 m .35995 .18513 L .36202 .17993 L 0 0 0 r
F
.36635 .25107 m .36388 .2206 L .36524 .21996 L .561 .376 .589 r
F
.36714 .24416 m .36524 .21996 L .37016 .21765 L F
.36635 .25107 m .36524 .21996 L .36714 .24416 L F
.36388 .2206 m .36579 .2237 L .37016 .21765 L 0 0 .244 r
F
.36287 .18984 m .36336 .19279 L .36579 .2237 L .492 .125 .27 r
F
.36202 .17993 m .36233 .1829 L .36287 .18984 L F
.36233 .1829 m .36336 .19279 L .36287 .18984 L F
.36388 .2206 m .36202 .17993 L .36498 .21425 L 0 0 .244 r
F
.36466 .22186 m .36498 .21425 L .36579 .2237 L F
.36388 .2206 m .36498 .21425 L .36466 .22186 L F
.36287 .18807 m .36191 .19253 L .36336 .19279 L .492 .125 .27 r
F
.36202 .17993 m .36191 .19253 L .36287 .18807 L F
.36202 .17993 m .35732 .19174 L .36191 .19253 L F
.35732 .19174 m .36051 .17049 L .36336 .19279 L .71 .665 .115 r
F
.36336 .19279 m .36051 .17049 L .36294 .20022 L .867 .617 .085 r
F
.36374 .20312 m .36294 .20022 L .36421 .21563 L F
.36336 .19279 m .36294 .20022 L .36374 .20312 L F
.36051 .17049 m .36115 .19608 L .36421 .21563 L .625 .287 .379 r
F
.35467 .20343 m .35085 .2204 L .35184 .21603 L 0 0 0 r
F
.35083 .23393 m .35542 .18838 L .36051 .17049 L .947 .718 .559 r
F
.36051 .17049 m .35542 .18838 L .36115 .19608 L .625 .287 .379 r
F
.36115 .19608 m .35854 .16874 L .36447 .1726 L .436 .291 .585 r
F
.36057 .17295 m .36034 .17297 L .36058 .17327 L .761 .261 .028 r
F
.36057 .17295 m .36058 .17327 L .36117 .17404 L F
.36447 .1726 m .36057 .17295 L .36117 .17404 L F
.36144 .19473 m .36447 .1726 L .36637 .17178 L .436 .291 .585 r
F
.36137 .19449 m .36447 .1726 L .36144 .19473 L F
.36115 .19608 m .36684 .1696 L .36659 .17555 L F
.36579 .2237 m .36336 .19279 L .36909 .20037 L .374 .237 .563 r
F
.36336 .19279 m .36421 .21563 L .36909 .20037 L .867 .617 .085 r
F
.36421 .21563 m .36115 .19608 L .36884 .16706 L .833 .599 .585 r
F
.36447 .1726 m .36117 .17404 L .36613 .18047 L .761 .261 .028 r
F
.36637 .17178 m .36447 .1726 L .36684 .1696 L .436 .291 .585 r
F
.36115 .19608 m .36137 .19449 L .36144 .19473 L F
.36659 .17555 m .36684 .1696 L .36884 .16706 L F
.35542 .18838 m .35854 .16874 L .35936 .17738 L .861 .785 .286 r
F
.35733 .19094 m .35936 .17738 L .36115 .19608 L F
.35542 .18838 m .35936 .17738 L .35733 .19094 L F
.35325 .2182 m .35083 .23393 L .35435 .21085 L .71 .665 .115 r
F
.35113 .19637 m .34679 .20124 L .35293 .19913 L .156 0 0 r
F
.34827 .22216 m .35009 .20925 L .35542 .18838 L .022 0 .414 r
F
.349 .22709 m .34589 .21304 L .34865 .2247 L 0 0 .191 r
F
.34109 .22817 m .34303 .22811 L .3462 .22574 L 0 0 0 r
F
.34613 .22552 m .3462 .22574 L .34736 .22488 L F
.34109 .22817 m .3462 .22574 L .34613 .22552 L F
.34736 .22488 m .34303 .22811 L .34917 .22787 L .276 0 0 r
F
.3465 .22797 m .34589 .21304 L .34917 .22787 L .154 .075 .507 r
F
.34303 .22811 m .34589 .21304 L .3465 .22797 L F
.34097 .19851 m .34109 .22817 L .34679 .20124 L .836 .483 .385 r
F
.34589 .21304 m .344 .17537 L .34529 .19812 L 0 0 .071 r
F
.34917 .22787 m .349 .22709 L .35048 .23244 L 0 0 .191 r
F
.349 .22709 m .34865 .2247 L .35048 .23244 L F
.34589 .21304 m .34858 .23061 L .34929 .22741 L 0 0 .071 r
F
.34589 .21304 m .34529 .19812 L .34626 .21548 L F
.34589 .21304 m .34698 .22825 L .34858 .23061 L F
.34589 .21304 m .34626 .21548 L .34697 .22801 L F
.34697 .228 m .34697 .22801 L .34698 .22825 L F
.34589 .21304 m .34697 .22801 L .34697 .228 L F
.34698 .22825 m .34813 .22121 L .34827 .22216 L .022 0 .414 r
F
.34813 .22121 m .35009 .20925 L .34827 .22216 L F
.34917 .22787 m .35048 .23244 L .35083 .23393 L 0 0 .191 r
F
.34929 .22741 m .34858 .23061 L .35083 .23393 L 0 0 .071 r
F
.35085 .2204 m .35049 .22202 L .35184 .21603 L 0 0 0 r
F
.74943 .19071 m .75307 .18407 L .75601 .18839 L .663 .741 .908 r
F
.74943 .19071 m .74648 .18641 L .75307 .18407 L F
.55343 .19073 m .55643 .18408 L .55979 .18839 L .664 .741 .908 r
F
.55343 .19073 m .55006 .18642 L .55643 .18408 L F
.43872 .241 m .4409 .25046 L .44504 .23484 L .718 .252 .143 r
F
.43489 .24396 m .43159 .22887 L .43637 .24229 L 0 0 .435 r
F
.43343 .24562 m .43489 .24396 L .43872 .241 L .52 .918 .87 r
F
.43872 .241 m .43489 .24396 L .4409 .25046 L .718 .252 .143 r
F
.43489 .24396 m .43637 .24229 L .4373 .2449 L 0 0 .435 r
F
.43241 .24651 m .43489 .24396 L .43343 .24562 L .52 .918 .87 r
F
.43241 .24651 m .42864 .2469 L .43489 .24396 L F
.65947 .19054 m .66281 .18389 L .66594 .18821 L .664 .741 .908 r
F
.65947 .19054 m .65632 .18623 L .66281 .18389 L F
.26743 .19059 m .26346 .18629 L .26942 .18484 L .598 .719 .929 r
F
.76552 .19037 m .76921 .18371 L .77212 .18803 L .664 .741 .908 r
F
.76552 .19037 m .7626 .18606 L .76921 .18371 L F
.56949 .19038 m .57254 .18372 L .57586 .18804 L .664 .742 .908 r
F
.56949 .19038 m .56615 .18607 L .57254 .18372 L F
.32739 .30192 m .32183 .32446 L .32929 .30137 L 0 0 .022 r
F
.67554 .19018 m .67894 .18353 L .68204 .18785 L .664 .741 .908 r
F
.67554 .19018 m .67243 .18587 L .67894 .18353 L F
.54993 .35517 m .54674 .38231 L .55265 .31685 L .85 .716 .189 r
F
.78161 .19 m .78536 .18335 L .78823 .18767 L .664 .741 .908 r
F
.78161 .19 m .77873 .18569 L .78536 .18335 L F
.58555 .19001 m .58865 .18335 L .59194 .18767 L F
.58555 .19001 m .58225 .1857 L .58865 .18335 L F
.41237 .21068 m .41431 .22063 L .41842 .21243 L .52 .118 .218 r
F
.41237 .21068 m .40823 .21886 L .41431 .22063 L F
.69162 .18982 m .69508 .18317 L .69814 .18749 L .663 .741 .908 r
F
.69162 .18982 m .68855 .18551 L .69508 .18317 L F
.50686 .27622 m .50319 .30044 L .5095 .31194 L .65 .339 .432 r
F
.49358 .27271 m .48986 .28727 L .49619 .28817 L .508 .172 .333 r
F
.49358 .27271 m .49619 .28817 L .4996 .30636 L F
.48986 .28727 m .49296 .25427 L .49619 .28817 L .93 .718 .594 r
F
.48986 .28727 m .48634 .28068 L .49296 .25427 L F
.49255 .21532 m .48922 .19585 L .49373 .35366 L .981 .687 .346 r
F
.49255 .21532 m .49373 .35366 L .49384 .35417 L F
.48922 .19585 m .49037 .33921 L .49389 .35933 L .968 .664 .39 r
F
.49619 .28817 m .49296 .25427 L .49905 .28036 L .018 0 .47 r
F
.49296 .25427 m .49579 .24645 L .49905 .28036 L .018 0 .471 r
F
.49579 .24645 m .49255 .21532 L .4939 .2576 L .975 .694 .295 r
F
.50319 .30044 m .4996 .30636 L .50414 .31507 L .785 .387 .298 r
F
.5047 .31044 m .50414 .31507 L .50591 .31848 L F
.50319 .30044 m .50414 .31507 L .5047 .31044 L F
.4996 .30636 m .49619 .28817 L .50195 .3056 L 0 0 .454 r
F
.49619 .28817 m .49905 .28036 L .50056 .2923 L .018 0 .47 r
F
.50228 .30661 m .50056 .2923 L .50242 .30702 L F
.49619 .28817 m .50056 .2923 L .50228 .30661 L F
.49588 .25344 m .49691 .35189 L .49716 .35355 L .975 .694 .295 r
F
.49579 .24645 m .49586 .2533 L .49588 .25344 L F
.49586 .2533 m .49691 .35189 L .49588 .25344 L F
.49925 .28877 m .49704 .27496 L .50022 .34729 L .952 .683 .231 r
F
.50059 .34425 m .50022 .34729 L .50121 .36969 L F
.4996 .30636 m .50195 .3056 L .50211 .30659 L 0 0 .454 r
F
.4996 .30636 m .50228 .30661 L .50235 .30701 L F
.50414 .31507 m .50242 .30702 L .50591 .31848 L F
.4996 .30636 m .50216 .30696 L .50414 .31507 L F
.50216 .30696 m .50242 .30702 L .50414 .31507 L F
.49942 .29567 m .50022 .34729 L .50059 .34425 L .952 .683 .231 r
F
.49925 .28877 m .49936 .29544 L .49942 .29567 L F
.49936 .29544 m .50022 .34729 L .49942 .29567 L F
.50211 .30659 m .50195 .3056 L .50228 .30661 L 0 0 .454 r
F
.49905 .28036 m .49579 .24645 L .49704 .27496 L .952 .683 .231 r
F
.49905 .28036 m .49704 .27496 L .49925 .28877 L F
.49604 .27011 m .4939 .2576 L .49691 .35189 L .975 .694 .295 r
F
.49579 .24645 m .4939 .2576 L .49604 .27011 L F
.50235 .30701 m .50228 .30661 L .50242 .30702 L 0 0 .454 r
F
.48922 .19585 m .48569 .19331 L .49037 .33921 L .968 .664 .39 r
F
.48569 .19331 m .48694 .31372 L .49037 .33921 L .93 .617 .427 r
F
.49255 .21532 m .49389 .35933 L .4975 .3705 L .981 .687 .346 r
F
.48813 .29457 m .49128 .1801 L .49476 .18765 L .92 .645 .504 r
F
.48694 .31372 m .48766 .29151 L .48813 .29457 L F
.48766 .29151 m .49128 .1801 L .48813 .29457 L F
.49716 .35355 m .49691 .35189 L .4973 .36413 L .975 .694 .295 r
F
.49743 .36502 m .4973 .36413 L .4975 .3705 L F
.49579 .24645 m .4973 .36413 L .49743 .36502 L F
.49131 .32228 m .49476 .18765 L .49823 .19687 L .933 .657 .493 r
F
.49039 .33883 m .49094 .31975 L .49131 .32228 L F
.49094 .31975 m .49476 .18765 L .49131 .32228 L F
.49037 .33921 m .49038 .33879 L .49039 .33883 L F
.49038 .33879 m .49476 .18765 L .49039 .33883 L F
.49384 .35417 m .49373 .35366 L .49389 .35933 L .981 .687 .346 r
F
.60162 .18964 m .60477 .18299 L .60803 .18731 L .663 .741 .908 r
F
.60162 .18964 m .59835 .18533 L .60477 .18299 L F
.70771 .18947 m .71122 .18281 L .71425 .18713 L .664 .741 .908 r
F
.70771 .18947 m .70467 .18516 L .71122 .18281 L F
.61769 .18929 m .6209 .18263 L .62412 .18695 L F
.61769 .18929 m .61446 .18498 L .6209 .18263 L F
.7238 .1891 m .72736 .18245 L .73036 .18677 L F
.7238 .1891 m .7208 .18479 L .72736 .18245 L F
.52765 .18913 m .53057 .18246 L .53398 .18678 L F
.52765 .18913 m .52423 .18481 L .53057 .18246 L F
.63377 .18892 m .63703 .18226 L .64022 .18659 L F
.63377 .18892 m .63057 .18461 L .63703 .18226 L F
.50852 .23955 m .5051 .22246 L .51159 .19031 L .862 .623 .576 r
F
.51159 .19031 m .51445 .18286 L .5179 .1872 L .687 .732 .884 r
F
.51159 .19031 m .50813 .18565 L .51445 .18286 L F
.5051 .22246 m .50813 .18565 L .51159 .19031 L .846 .626 .604 r
F
.54372 .18874 m .54668 .1821 L .55006 .18642 L .663 .741 .908 r
F
.54372 .18874 m .54032 .18443 L .54668 .1821 L F
.7399 .18874 m .74351 .18208 L .74648 .18641 L .664 .741 .908 r
F
.7399 .18874 m .73693 .18443 L .74351 .18208 L F
.28769 .3596 m .28543 .33125 L .29986 .21859 L .907 .645 .53 r
F
.29986 .21859 m .29736 .27566 L .30375 .24655 L .787 .474 .459 r
F
.28543 .33125 m .29383 .24254 L .29986 .21859 L .85 .598 .557 r
F
.29986 .21859 m .29383 .24254 L .29736 .27566 L .787 .474 .459 r
F
.64985 .18857 m .65317 .18191 L .65632 .18623 L .664 .741 .908 r
F
.64985 .18857 m .64669 .18425 L .65317 .18191 L F
.75601 .18839 m .75967 .18173 L .7626 .18606 L .663 .741 .908 r
F
.75601 .18839 m .75307 .18407 L .75967 .18173 L F
.55979 .18839 m .56281 .18174 L .56615 .18607 L F
.55979 .18839 m .55643 .18408 L .56281 .18174 L F
.42714 .20624 m .42256 .22915 L .4261 .21279 L 0 0 0 r
F
.42816 .19978 m .42714 .20624 L .43117 .19826 L .093 0 .13 r
F
.43117 .19826 m .42714 .20624 L .43386 .18868 L .836 .859 .406 r
F
.42926 .2007 m .42988 .19534 L .43386 .18868 L 0 0 0 r
F
.42714 .20624 m .42988 .19534 L .42926 .2007 L F
.42714 .20624 m .4261 .21279 L .42988 .19534 L F
.42256 .22915 m .42526 .22 L .42988 .19534 L .933 .958 .647 r
F
.42988 .19534 m .42526 .22 L .43047 .19014 L .759 .707 .17 r
F
.42988 .19534 m .43047 .19014 L .43048 .19011 L F
.42988 .19534 m .4305 .18995 L .43287 .17633 L F
.43159 .22887 m .43432 .21828 L .4373 .2449 L .218 .165 .582 r
F
.43117 .19826 m .43386 .18868 L .43693 .21182 L .836 .859 .406 r
F
.43432 .21828 m .43117 .19826 L .43496 .20717 L .056 .057 .541 r
F
.43536 .2157 m .43496 .20717 L .43693 .21182 L F
.43432 .21828 m .43496 .20717 L .43536 .2157 L F
.4373 .2449 m .43432 .21828 L .43983 .24208 L 0 0 .423 r
F
.43982 .24217 m .43983 .24208 L .43984 .24215 L F
.4373 .2449 m .43983 .24208 L .43982 .24217 L F
.43432 .21828 m .43693 .21182 L .43984 .24215 L .056 .057 .541 r
F
.4409 .25046 m .4373 .2449 L .44341 .24921 L 0 .289 .789 r
F
.43914 .2462 m .43984 .24215 L .44341 .24921 L 0 0 .423 r
F
.4373 .2449 m .43984 .24215 L .43914 .2462 L F
.43984 .24215 m .43983 .24204 L .43985 .2421 L 0 0 .249 r
F
.44341 .24921 m .43984 .24215 L .44224 .23738 L .865 .705 .682 r
F
.44431 .24325 m .44224 .23738 L .44643 .22905 L F
.44341 .24921 m .44224 .23738 L .44431 .24325 L F
.43983 .24204 m .43693 .21182 L .44009 .23471 L 0 0 .249 r
F
.43984 .24215 m .44213 .24954 L .44643 .22905 L F
.43983 .24204 m .44009 .23471 L .44213 .24954 L F
.4393 .22904 m .43866 .23746 L .44213 .24954 L .84 .595 .049 r
F
.43693 .21182 m .43781 .22478 L .4393 .22904 L F
.43781 .22478 m .43866 .23746 L .4393 .22904 L F
.43984 .24215 m .43985 .2421 L .44213 .24954 L 0 0 .249 r
F
.43693 .21182 m .43628 .20686 L .43866 .23746 L .84 .595 .049 r
F
.43428 .19294 m .43589 .20191 L .43728 .2197 L .68 .267 .255 r
F
.43669 .21748 m .43728 .2197 L .43866 .23746 L F
.43428 .19294 m .43728 .2197 L .43669 .21748 L F
.43866 .23746 m .43589 .20191 L .44185 .21238 L .357 .218 .552 r
F
.43884 .22566 m .43754 .23014 L .43817 .22863 L 0 0 .092 r
F
.44185 .21238 m .43873 .22523 L .43884 .22566 L F
.43873 .22523 m .43754 .23014 L .43884 .22566 L F
.44047 .22365 m .44185 .21238 L .44208 .21135 L .357 .218 .552 r
F
.44049 .22306 m .44185 .21238 L .44047 .22365 L F
.44137 .22111 m .4421 .21119 L .44614 .19229 L F
.43866 .23746 m .4421 .21119 L .44137 .22111 L F
.44213 .24954 m .43866 .23746 L .44614 .19229 L .92 .674 .55 r
F
.44208 .21135 m .44185 .21238 L .4421 .21119 L .357 .218 .552 r
F
.44643 .22905 m .44317 .2446 L .4495 .19363 L .949 .785 .33 r
F
.44317 .2446 m .44315 .2418 L .4495 .19363 L F
.44643 .22905 m .4495 .19363 L .44967 .19314 L F
.44213 .24954 m .44614 .19229 L .44991 .19048 L .92 .674 .55 r
F
.44614 .19229 m .44185 .21238 L .44741 .24127 L .791 .462 .432 r
F
.443 .21834 m .44431 .21381 L .44741 .24127 L 0 0 .092 r
F
.44185 .21238 m .44296 .21302 L .443 .21834 L F
.44296 .21302 m .44431 .21381 L .443 .21834 L F
.44317 .2446 m .44213 .24954 L .44315 .2418 L .949 .785 .33 r
F
.44967 .19314 m .4495 .19363 L .44991 .19048 L F
.44694 .20082 m .44741 .24127 L .4511 .24541 L .791 .462 .432 r
F
.44614 .19229 m .4464 .20234 L .44694 .20082 L F
.4464 .20234 m .44741 .24127 L .44694 .20082 L F
.44185 .21238 m .43817 .22863 L .44431 .21381 L 0 0 .092 r
F
.43866 .23746 m .44049 .22306 L .44047 .22365 L .357 .218 .552 r
F
.43484 .19609 m .43386 .18868 L .43428 .19294 L .84 .595 .049 r
F
.43386 .18868 m .43417 .19073 L .43428 .19294 L .68 .267 .255 r
F
.43417 .19073 m .43589 .20191 L .43428 .19294 L F
.43386 .18868 m .42988 .19534 L .43589 .20191 L F
.42988 .19534 m .43287 .17633 L .43589 .20191 L .759 .707 .17 r
F
.42493 .20141 m .42714 .20624 L .42816 .19978 L .093 0 .13 r
F
.42493 .20141 m .42071 .21401 L .42714 .20624 L F
.42071 .21401 m .42256 .22915 L .42714 .20624 L .528 .174 .31 r
F
.42526 .22 m .42894 .18073 L .43287 .17633 L .999 .799 .46 r
F
.43 .19099 m .43066 .20289 L .43377 .22748 L .466 .161 .364 r
F
.42894 .18073 m .42977 .19141 L .43 .19099 L F
.42977 .19141 m .43066 .20289 L .43 .19099 L F
.43048 .19011 m .43047 .19014 L .4305 .18995 L .759 .707 .17 r
F
.41842 .21243 m .42071 .21401 L .42493 .20141 L 0 0 0 r
F
.66594 .18821 m .66931 .18154 L .67243 .18587 L .664 .741 .908 r
F
.66594 .18821 m .66281 .18389 L .66931 .18154 L F
.77212 .18803 m .77584 .18136 L .77873 .18569 L .663 .741 .908 r
F
.77212 .18803 m .76921 .18371 L .77584 .18136 L F
.57586 .18804 m .57894 .18137 L .58225 .1857 L .664 .741 .908 r
F
.57586 .18804 m .57254 .18372 L .57894 .18137 L F
.68204 .18785 m .68546 .18118 L .68855 .18551 L F
.68204 .18785 m .67894 .18353 L .68546 .18118 L F
.59194 .18767 m .59507 .181 L .59835 .18533 L .663 .741 .908 r
F
.59194 .18767 m .58865 .18335 L .59507 .181 L F
.69814 .18749 m .70162 .18083 L .70467 .18516 L F
.69814 .18749 m .69508 .18317 L .70162 .18083 L F
.27336 .18946 m .27297 .21261 L .27595 .22945 L .952 .606 .299 r
F
.60803 .18731 m .61121 .18065 L .61446 .18498 L .663 .741 .908 r
F
.60803 .18731 m .60477 .18299 L .61121 .18065 L F
.71425 .18713 m .71778 .18046 L .7208 .18479 L .664 .741 .908 r
F
.71425 .18713 m .71122 .18281 L .71778 .18046 L F
.38593 .25986 m .3822 .25525 L .38982 .22152 L .949 .73 .573 r
F
.5179 .1872 m .52079 .18048 L .52423 .18481 L .666 .741 .907 r
F
.5179 .1872 m .51445 .18286 L .52079 .18048 L F
.42864 .2469 m .42539 .23046 L .43159 .22887 L .57 .438 .661 r
F
.42245 .24847 m .42539 .23046 L .42864 .2469 L .81 .664 .702 r
F
.42245 .24847 m .41893 .24024 L .42539 .23046 L F
.3595 .22646 m .35713 .19628 L .36232 .21155 L .174 .092 .517 r
F
.35336 .22827 m .35713 .19628 L .3595 .22646 L .519 .342 .581 r
F
.62412 .18695 m .62736 .18028 L .63057 .18461 L .664 .741 .908 r
F
.62412 .18695 m .6209 .18263 L .62736 .18028 L F
.45941 .26109 m .46334 .19604 L .46674 .20795 L .907 .655 .547 r
F
.46335 .24893 m .46674 .20795 L .46985 .23637 L .99 .796 .411 r
F
.46335 .24893 m .45941 .26109 L .46674 .20795 L F
.46674 .20795 m .46334 .19604 L .4689 .23193 L .916 .599 .122 r
F
.45941 .26109 m .45604 .24542 L .46334 .19604 L .907 .655 .547 r
F
.46334 .19604 m .46464 .26134 L .4689 .23193 L .913 .586 .411 r
F
.46334 .19604 m .45947 .2057 L .46464 .26134 L F
.73036 .18677 m .73394 .1801 L .73693 .18443 L .664 .741 .908 r
F
.73036 .18677 m .72736 .18245 L .73394 .1801 L F
.53398 .18678 m .53692 .1801 L .54032 .18443 L .665 .742 .908 r
F
.53398 .18678 m .53057 .18246 L .53692 .1801 L F
.64022 .18659 m .64351 .17992 L .64669 .18425 L .663 .741 .908 r
F
.64022 .18659 m .63703 .18226 L .64351 .17992 L F
.74648 .18641 m .75012 .17974 L .75307 .18407 L F
.74648 .18641 m .74351 .18208 L .75012 .17974 L F
.55006 .18642 m .55306 .17975 L .55643 .18408 L .664 .741 .908 r
F
.55006 .18642 m .54668 .1821 L .55306 .17975 L F
.32929 .30137 m .32479 .30726 L .33282 .27482 L .999 .83 .534 r
F
.32479 .30726 m .32788 .28792 L .33282 .27482 L .535 .398 .641 r
F
.65632 .18623 m .65967 .17956 L .66281 .18389 L .664 .741 .908 r
F
.65632 .18623 m .65317 .18191 L .65967 .17956 L F
.33619 .24559 m .3332 .22718 L .34097 .19851 L .835 .605 .59 r
F
.34097 .19851 m .33636 .20676 L .34109 .22817 L .836 .483 .385 r
F
.7626 .18606 m .76629 .17937 L .76921 .18371 L .664 .741 .908 r
F
.7626 .18606 m .75967 .18173 L .76629 .17937 L F
.56615 .18607 m .5692 .17939 L .57254 .18372 L F
.56615 .18607 m .56281 .18174 L .5692 .17939 L F
.46985 .23637 m .46674 .20795 L .47304 .20415 L .581 .398 .598 r
F
.46674 .20795 m .4689 .23193 L .47304 .20415 L .916 .599 .122 r
F
.67243 .18587 m .67583 .17919 L .67894 .18353 L .664 .741 .908 r
F
.67243 .18587 m .66931 .18154 L .67583 .17919 L F
.77873 .18569 m .78248 .17901 L .78536 .18335 L F
.77873 .18569 m .77584 .18136 L .78248 .17901 L F
.58225 .1857 m .58535 .17901 L .58865 .18335 L F
.58225 .1857 m .57894 .18137 L .58535 .17901 L F
.68855 .18551 m .692 .17883 L .69508 .18317 L .663 .741 .908 r
F
.68855 .18551 m .68546 .18118 L .692 .17883 L F
.59835 .18533 m .6015 .17865 L .60477 .18299 L .664 .741 .908 r
F
.59835 .18533 m .59507 .181 L .6015 .17865 L F
.70467 .18516 m .70817 .17847 L .71122 .18281 L F
.70467 .18516 m .70162 .18083 L .70817 .17847 L F
.61446 .18498 m .61766 .17829 L .6209 .18263 L F
.61446 .18498 m .61121 .18065 L .61766 .17829 L F
.41842 .21243 m .41431 .22063 L .42071 .21401 L 0 0 0 r
F
.5051 .22246 m .50167 .20832 L .50813 .18565 L .846 .626 .604 r
F
.50813 .18565 m .51099 .17851 L .51445 .18286 L .674 .731 .893 r
F
.50813 .18565 m .50466 .18106 L .51099 .17851 L F
.50167 .20832 m .50466 .18106 L .50813 .18565 L .831 .636 .639 r
F
.7208 .18479 m .72435 .17811 L .72736 .18245 L .664 .741 .908 r
F
.7208 .18479 m .71778 .18046 L .72435 .17811 L F
.52423 .18481 m .52714 .17812 L .53057 .18246 L F
.52423 .18481 m .52079 .18048 L .52714 .17812 L F
.47304 .20415 m .47497 .24726 L .47902 .2219 L .669 .358 .439 r
F
.47304 .20415 m .4689 .23193 L .47497 .24726 L F
.63057 .18461 m .63383 .17792 L .63703 .18226 L .664 .741 .908 r
F
.63057 .18461 m .62736 .18028 L .63383 .17792 L F
.54032 .18443 m .54329 .17776 L .54668 .1821 L .662 .741 .908 r
F
.54032 .18443 m .53692 .1801 L .54329 .17776 L F
.73693 .18443 m .74054 .17774 L .74351 .18208 L .664 .741 .908 r
F
.73693 .18443 m .73394 .1801 L .74054 .17774 L F
.42864 .2469 m .43159 .22887 L .43489 .24396 L .57 .438 .661 r
F
.64669 .18425 m .65 .17756 L .65317 .18191 L .663 .741 .908 r
F
.64669 .18425 m .64351 .17992 L .65 .17756 L F
.48569 .19331 m .4819 .20817 L .48694 .31372 L .93 .617 .427 r
F
.39252 .20945 m .39385 .22963 L .39831 .21681 L .936 .562 .235 r
F
.75307 .18407 m .75673 .17739 L .75967 .18173 L .663 .741 .908 r
F
.75307 .18407 m .75012 .17974 L .75673 .17739 L F
.55643 .18408 m .55945 .1774 L .56281 .18174 L F
.55643 .18408 m .55306 .17975 L .55945 .1774 L F
.66281 .18389 m .66618 .1772 L .66931 .18154 L .664 .741 .908 r
F
.66281 .18389 m .65967 .17956 L .66618 .1772 L F
.76921 .18371 m .77293 .17702 L .77584 .18136 L .663 .741 .908 r
F
.76921 .18371 m .76629 .17937 L .77293 .17702 L F
.57254 .18372 m .57561 .17702 L .57894 .18137 L .664 .742 .908 r
F
.57254 .18372 m .5692 .17939 L .57561 .17702 L F
.67894 .18353 m .68236 .17683 L .68546 .18118 L .664 .741 .908 r
F
.67894 .18353 m .67583 .17919 L .68236 .17683 L F
.58865 .18335 m .59178 .17666 L .59507 .181 L .663 .741 .908 r
F
.58865 .18335 m .58535 .17901 L .59178 .17666 L F
.69508 .18317 m .69855 .17648 L .70162 .18083 L F
.69508 .18317 m .692 .17883 L .69855 .17648 L F
.60477 .18299 m .60795 .1763 L .61121 .18065 L F
.60477 .18299 m .6015 .17865 L .60795 .1763 L F
.71122 .18281 m .71474 .17611 L .71778 .18046 L .664 .741 .908 r
F
.71122 .18281 m .70817 .17847 L .71474 .17611 L F
.51445 .18286 m .51733 .17613 L .52079 .18048 L .665 .741 .907 r
F
.51445 .18286 m .51099 .17851 L .51733 .17613 L F
.6209 .18263 m .62413 .17593 L .62736 .18028 L .664 .741 .908 r
F
.6209 .18263 m .61766 .17829 L .62413 .17593 L F
.72736 .18245 m .73094 .17575 L .73394 .1801 L F
.72736 .18245 m .72435 .17811 L .73094 .17575 L F
.53057 .18246 m .5335 .17574 L .53692 .1801 L .665 .742 .908 r
F
.53057 .18246 m .52714 .17812 L .5335 .17574 L F
.63703 .18226 m .64032 .17557 L .64351 .17992 L .663 .741 .908 r
F
.63703 .18226 m .63383 .17792 L .64032 .17557 L F
.74351 .18208 m .74715 .17539 L .75012 .17974 L F
.74351 .18208 m .74054 .17774 L .74715 .17539 L F
.54668 .1821 m .54967 .17539 L .55306 .17975 L .664 .741 .908 r
F
.54668 .1821 m .54329 .17776 L .54967 .17539 L F
.65317 .18191 m .65651 .17521 L .65967 .17956 L .663 .741 .908 r
F
.65317 .18191 m .65 .17756 L .65651 .17521 L F
.75967 .18173 m .76336 .17502 L .76629 .17937 L .664 .741 .908 r
F
.75967 .18173 m .75673 .17739 L .76336 .17502 L F
.56281 .18174 m .56585 .17503 L .5692 .17939 L F
.56281 .18174 m .55945 .1774 L .56585 .17503 L F
.66931 .18154 m .6727 .17484 L .67583 .17919 L F
.66931 .18154 m .66618 .1772 L .6727 .17484 L F
.43489 .24396 m .4373 .2449 L .4409 .25046 L 0 0 .435 r
F
.77584 .18136 m .77958 .17465 L .78248 .17901 L .664 .741 .908 r
F
.77584 .18136 m .77293 .17702 L .77958 .17465 L F
.57894 .18137 m .58203 .17466 L .58535 .17901 L F
.57894 .18137 m .57561 .17702 L .58203 .17466 L F
.68546 .18118 m .68891 .17448 L .692 .17883 L .663 .741 .908 r
F
.68546 .18118 m .68236 .17683 L .68891 .17448 L F
.59507 .181 m .59822 .17429 L .6015 .17865 L .664 .741 .908 r
F
.59507 .181 m .59178 .17666 L .59822 .17429 L F
.70162 .18083 m .70512 .17411 L .70817 .17847 L F
.70162 .18083 m .69855 .17648 L .70512 .17411 L F
.50167 .20832 m .49823 .19687 L .50466 .18106 L .831 .636 .639 r
F
.50466 .18106 m .50751 .17415 L .51099 .17851 L .666 .734 .901 r
F
.50466 .18106 m .50117 .17656 L .50751 .17415 L F
.49823 .19687 m .50117 .17656 L .50466 .18106 L .815 .653 .682 r
F
.61121 .18065 m .61441 .17393 L .61766 .17829 L .664 .741 .908 r
F
.61121 .18065 m .60795 .1763 L .61441 .17393 L F
.32648 .23838 m .33068 .20182 L .3332 .22718 L .963 .806 .371 r
F
.32648 .23838 m .32073 .26209 L .33068 .20182 L F
.33068 .20182 m .33121 .22275 L .33636 .20676 L .948 .623 .197 r
F
.33068 .20182 m .32722 .19139 L .32914 .20651 L F
.32722 .19139 m .32702 .22282 L .33121 .22275 L .761 .418 .404 r
F
.32431 .20251 m .32744 .18053 L .33197 .17496 L .529 .376 .617 r
F
.32409 .2033 m .32422 .20244 L .32431 .20251 L F
.32422 .20244 m .32744 .18053 L .32431 .20251 L F
.33083 .2079 m .32914 .20651 L .33121 .22275 L .948 .623 .197 r
F
.33068 .20182 m .32914 .20651 L .33083 .2079 L F
.71778 .18046 m .72133 .17375 L .72435 .17811 L .664 .741 .908 r
F
.71778 .18046 m .71474 .17611 L .72133 .17375 L F
.52079 .18048 m .52369 .17376 L .52714 .17812 L F
.52079 .18048 m .51733 .17613 L .52369 .17376 L F
.62736 .18028 m .63061 .17356 L .63383 .17792 L F
.62736 .18028 m .62413 .17593 L .63061 .17356 L F
.53692 .1801 m .53988 .1734 L .54329 .17776 L .662 .741 .908 r
F
.53692 .1801 m .5335 .17574 L .53988 .1734 L F
.73394 .1801 m .73755 .17338 L .74054 .17774 L .664 .741 .908 r
F
.73394 .1801 m .73094 .17575 L .73755 .17338 L F
.45604 .24542 m .45306 .21331 L .45947 .2057 L .616 .415 .588 r
F
.45306 .21331 m .45527 .22812 L .45947 .2057 L 0 0 .113 r
F
.45306 .21331 m .44991 .19048 L .45527 .22812 L F
.44991 .19048 m .4511 .24541 L .45527 .22812 L .944 .614 .373 r
F
.44991 .19048 m .44614 .19229 L .4511 .24541 L F
.64351 .17992 m .64682 .1732 L .65 .17756 L .663 .741 .908 r
F
.64351 .17992 m .64032 .17557 L .64682 .1732 L F
.32183 .32446 m .32479 .30726 L .32929 .30137 L .992 .871 .606 r
F
.30567 .35011 m .31262 .275 L .31454 .30843 L .998 .776 .452 r
F
.30567 .35011 m .2999 .37137 L .31262 .275 L F
.75012 .17974 m .75378 .17302 L .75673 .17739 L .664 .741 .908 r
F
.75012 .17974 m .74715 .17539 L .75378 .17302 L F
.55306 .17975 m .55607 .17304 L .55945 .1774 L .663 .741 .908 r
F
.55306 .17975 m .54967 .17539 L .55607 .17304 L F
.65967 .17956 m .66303 .17284 L .66618 .1772 L .664 .741 .908 r
F
.65967 .17956 m .65651 .17521 L .66303 .17284 L F
.76629 .17937 m .77001 .17266 L .77293 .17702 L .663 .741 .908 r
F
.76629 .17937 m .76336 .17502 L .77001 .17266 L F
.5692 .17939 m .57227 .17266 L .57561 .17702 L .664 .742 .908 r
F
.5692 .17939 m .56585 .17503 L .57227 .17266 L F
.67583 .17919 m .67925 .17247 L .68236 .17683 L .664 .741 .908 r
F
.67583 .17919 m .6727 .17484 L .67925 .17247 L F
.38876 .20614 m .38385 .22709 L .39074 .21062 L 0 0 .147 r
F
.58535 .17901 m .58847 .17229 L .59178 .17666 L .663 .741 .908 r
F
.58535 .17901 m .58203 .17466 L .58847 .17229 L F
.692 .17883 m .69547 .17211 L .69855 .17648 L F
.692 .17883 m .68891 .17448 L .69547 .17211 L F
.6015 .17865 m .60468 .17193 L .60795 .1763 L F
.6015 .17865 m .59822 .17429 L .60468 .17193 L F
.70817 .17847 m .7117 .17175 L .71474 .17611 L F
.70817 .17847 m .70512 .17411 L .7117 .17175 L F
.51099 .17851 m .51387 .17176 L .51733 .17613 L .665 .742 .907 r
F
.51099 .17851 m .50751 .17415 L .51387 .17176 L F
.61766 .17829 m .62089 .17156 L .62413 .17593 L .664 .741 .908 r
F
.61766 .17829 m .61441 .17393 L .62089 .17156 L F
.72435 .17811 m .72793 .17138 L .73094 .17575 L F
.72435 .17811 m .72133 .17375 L .72793 .17138 L F
.52714 .17812 m .53007 .17138 L .5335 .17574 L .665 .742 .907 r
F
.52714 .17812 m .52369 .17376 L .53007 .17138 L F
.31613 .20544 m .31376 .17921 L .31643 .2273 L .856 .628 .09 r
F
.31376 .17921 m .31225 .22603 L .31643 .2273 L .862 .533 .427 r
F
.63383 .17792 m .63711 .1712 L .64032 .17557 L .663 .741 .908 r
F
.63383 .17792 m .63061 .17356 L .63711 .1712 L F
.74054 .17774 m .74417 .17102 L .74715 .17539 L F
.74054 .17774 m .73755 .17338 L .74417 .17102 L F
.54329 .17776 m .54627 .17102 L .54967 .17539 L .664 .741 .908 r
F
.54329 .17776 m .53988 .1734 L .54627 .17102 L F
.65 .17756 m .65334 .17084 L .65651 .17521 L .663 .741 .908 r
F
.65 .17756 m .64682 .1732 L .65334 .17084 L F
.75673 .17739 m .76042 .17065 L .76336 .17502 L .664 .741 .908 r
F
.75673 .17739 m .75378 .17302 L .76042 .17065 L F
.55945 .1774 m .56248 .17066 L .56585 .17503 L F
.55945 .1774 m .55607 .17304 L .56248 .17066 L F
.40823 .21886 m .41038 .22249 L .41431 .22063 L .3 0 0 r
F
.40823 .21886 m .40419 .2231 L .41038 .22249 L F
.66618 .1772 m .66957 .17047 L .6727 .17484 L .664 .741 .908 r
F
.66618 .1772 m .66303 .17284 L .66957 .17047 L F
.77293 .17702 m .77667 .17028 L .77958 .17465 L F
.77293 .17702 m .77001 .17266 L .77667 .17028 L F
.57561 .17702 m .5787 .17028 L .58203 .17466 L F
.57561 .17702 m .57227 .17266 L .5787 .17028 L F
.36026 .24943 m .35572 .25859 L .36225 .25037 L 0 0 0 r
F
.68236 .17683 m .6858 .1701 L .68891 .17448 L .663 .741 .908 r
F
.68236 .17683 m .67925 .17247 L .6858 .1701 L F
.59178 .17666 m .59492 .16992 L .59822 .17429 L .664 .741 .908 r
F
.59178 .17666 m .58847 .17229 L .59492 .16992 L F
.35572 .25859 m .35336 .22827 L .3595 .22646 L .547 .366 .588 r
F
.35002 .25226 m .35336 .22827 L .35572 .25859 L .853 .673 .658 r
F
.69855 .17648 m .70205 .16974 L .70512 .17411 L .664 .741 .908 r
F
.69855 .17648 m .69547 .17211 L .70205 .16974 L F
.49823 .19687 m .49476 .18765 L .50117 .17656 L .815 .653 .682 r
F
.50117 .17656 m .50402 .16978 L .50751 .17415 L .662 .738 .906 r
F
.50117 .17656 m .49767 .17213 L .50402 .16978 L F
.49476 .18765 m .49767 .17213 L .50117 .17656 L .796 .675 .73 r
F
.60795 .1763 m .61115 .16956 L .61441 .17393 L .664 .741 .908 r
F
.60795 .1763 m .60468 .17193 L .61115 .16956 L F
.71474 .17611 m .7183 .16937 L .72133 .17375 L F
.71474 .17611 m .7117 .17175 L .7183 .16937 L F
.51733 .17613 m .52023 .16939 L .52369 .17376 L F
.51733 .17613 m .51387 .17176 L .52023 .16939 L F
.62413 .17593 m .62738 .16918 L .63061 .17356 L F
.62413 .17593 m .62089 .17156 L .62738 .16918 L F
.5335 .17574 m .53645 .16902 L .53988 .1734 L .662 .741 .908 r
F
.5335 .17574 m .53007 .17138 L .53645 .16902 L F
.73094 .17575 m .73455 .169 L .73755 .17338 L .664 .741 .908 r
F
.73094 .17575 m .72793 .17138 L .73455 .169 L F
.64032 .17557 m .64362 .16882 L .64682 .1732 L .663 .741 .908 r
F
.64032 .17557 m .63711 .1712 L .64362 .16882 L F
.74715 .17539 m .75081 .16864 L .75378 .17302 L .664 .741 .908 r
F
.74715 .17539 m .74417 .17102 L .75081 .16864 L F
.54967 .17539 m .55268 .16865 L .55607 .17304 L .663 .741 .908 r
F
.54967 .17539 m .54627 .17102 L .55268 .16865 L F
.65651 .17521 m .65987 .16846 L .66303 .17284 L .664 .741 .908 r
F
.65651 .17521 m .65334 .17084 L .65987 .16846 L F
.76336 .17502 m .76708 .16827 L .77001 .17266 L .663 .741 .908 r
F
.76336 .17502 m .76042 .17065 L .76708 .16827 L F
.56585 .17503 m .56891 .16828 L .57227 .17266 L .664 .742 .908 r
F
.56585 .17503 m .56248 .17066 L .56891 .16828 L F
.6727 .17484 m .67612 .16809 L .67925 .17247 L .664 .741 .908 r
F
.6727 .17484 m .66957 .17047 L .67612 .16809 L F
.58203 .17466 m .58515 .16791 L .58847 .17229 L .663 .741 .908 r
F
.58203 .17466 m .5787 .17028 L .58515 .16791 L F
.39074 .21062 m .38792 .18557 L .39368 .19377 L .325 .22 .578 r
F
.38385 .22709 m .38792 .18557 L .39074 .21062 L .991 .777 .515 r
F
.38385 .22709 m .37971 .23018 L .38779 .18627 L F
.38385 .22709 m .38779 .18627 L .38785 .18625 L F
.37971 .23018 m .38388 .18748 L .38792 .18557 L .703 .487 .593 r
F
.38398 .18764 m .38559 .19728 L .38962 .19616 L .288 0 .226 r
F
.38388 .18748 m .38391 .18766 L .38398 .18764 L F
.38391 .18766 m .38559 .19728 L .38398 .18764 L F
.38785 .18625 m .38779 .18627 L .38792 .18557 L .991 .777 .515 r
F
.38792 .18557 m .38962 .19616 L .39368 .19377 L .782 .322 .152 r
F
.38792 .18557 m .38388 .18748 L .38962 .19616 L F
.68891 .17448 m .69238 .16772 L .69547 .17211 L .664 .741 .908 r
F
.68891 .17448 m .6858 .1701 L .69238 .16772 L F
.59822 .17429 m .60139 .16755 L .60468 .17193 L .663 .741 .908 r
F
.59822 .17429 m .59492 .16992 L .60139 .16755 L F
.32479 .30726 m .32186 .28832 L .32788 .28792 L .535 .398 .641 r
F
.31745 .32759 m .32186 .28832 L .32479 .30726 L .786 .571 .609 r
F
.31745 .32759 m .31454 .30843 L .32186 .28832 L F
.32186 .28832 m .32449 .27621 L .32788 .28792 L .026 0 .452 r
F
.70512 .17411 m .70864 .16736 L .7117 .17175 L .663 .741 .908 r
F
.70512 .17411 m .70205 .16974 L .70864 .16736 L F
.50751 .17415 m .51038 .16738 L .51387 .17176 L .665 .742 .907 r
F
.50751 .17415 m .50402 .16978 L .51038 .16738 L F
.61441 .17393 m .61764 .16717 L .62089 .17156 L .664 .741 .908 r
F
.61441 .17393 m .61115 .16956 L .61764 .16717 L F
.36225 .25037 m .3595 .22646 L .36464 .24395 L 0 0 .474 r
F
.35572 .25859 m .3595 .22646 L .36225 .25037 L .547 .366 .588 r
F
.3595 .22646 m .36232 .21155 L .36464 .24395 L .174 .092 .517 r
F
.49579 .24645 m .4975 .3705 L .50121 .36969 L .975 .694 .295 r
F
.49389 .35933 m .49823 .19687 L .50167 .20832 L .948 .671 .481 r
F
.49389 .35933 m .49037 .33921 L .49823 .19687 L F
.72133 .17375 m .72491 .16699 L .72793 .17138 L .664 .741 .908 r
F
.72133 .17375 m .7183 .16937 L .72491 .16699 L F
.52369 .17376 m .52662 .16699 L .53007 .17138 L .665 .742 .907 r
F
.52369 .17376 m .52023 .16939 L .52662 .16699 L F
.63061 .17356 m .63389 .16681 L .63711 .1712 L .663 .741 .908 r
F
.63061 .17356 m .62738 .16918 L .63389 .16681 L F
.50242 .30702 m .49905 .28036 L .50497 .35573 L .906 .642 .139 r
F
.49905 .28036 m .50121 .36969 L .50497 .35573 L .952 .683 .231 r
F
.4975 .3705 m .50167 .20832 L .5051 .22246 L .963 .688 .466 r
F
.4975 .3705 m .49389 .35933 L .50167 .20832 L F
.73755 .17338 m .74118 .16663 L .74417 .17102 L .663 .741 .908 r
F
.73755 .17338 m .73455 .169 L .74118 .16663 L F
.53988 .1734 m .54286 .16663 L .54627 .17102 L .664 .741 .908 r
F
.53988 .1734 m .53645 .16902 L .54286 .16663 L F
.33636 .20676 m .33676 .23106 L .34109 .22817 L .646 .303 .378 r
F
.33636 .20676 m .33121 .22275 L .33676 .23106 L F
.64682 .1732 m .65015 .16645 L .65334 .17084 L .663 .741 .908 r
F
.64682 .1732 m .64362 .16882 L .65015 .16645 L F
.45947 .2057 m .46072 .26965 L .46464 .26134 L .825 .503 .444 r
F
.45947 .2057 m .45527 .22812 L .46072 .26965 L F
.75378 .17302 m .75746 .16626 L .76042 .17065 L .664 .741 .908 r
F
.75378 .17302 m .75081 .16864 L .75746 .16626 L F
.55607 .17304 m .5591 .16627 L .56248 .17066 L F
.55607 .17304 m .55268 .16865 L .5591 .16627 L F
.49037 .33921 m .48694 .31372 L .49476 .18765 L .933 .657 .493 r
F
.49476 .18765 m .49128 .1801 L .49767 .17213 L .796 .675 .73 r
F
.66303 .17284 m .66642 .16608 L .66957 .17047 L .664 .741 .908 r
F
.66303 .17284 m .65987 .16846 L .66642 .16608 L F
.77001 .17266 m .77375 .16589 L .77667 .17028 L F
.77001 .17266 m .76708 .16827 L .77375 .16589 L F
.57227 .17266 m .57535 .16589 L .5787 .17028 L F
.57227 .17266 m .56891 .16828 L .57535 .16589 L F
.42071 .21401 m .4164 .22713 L .42256 .22915 L .528 .174 .31 r
F
.41431 .22063 m .4164 .22713 L .42071 .21401 L .65 .135 .004 r
F
.67925 .17247 m .68269 .16571 L .6858 .1701 L .663 .741 .908 r
F
.67925 .17247 m .67612 .16809 L .68269 .16571 L F
.58847 .17229 m .59161 .16553 L .59492 .16992 L .664 .741 .908 r
F
.58847 .17229 m .58515 .16791 L .59161 .16553 L F
.69547 .17211 m .69896 .16534 L .70205 .16974 L F
.69547 .17211 m .69238 .16772 L .69896 .16534 L F
.41431 .22063 m .41038 .22249 L .4164 .22713 L .65 .135 .004 r
F
.49767 .17213 m .50051 .16538 L .50402 .16978 L .662 .741 .908 r
F
.49767 .17213 m .49416 .16775 L .50051 .16538 L F
.49128 .1801 m .49416 .16775 L .49767 .17213 L .772 .694 .777 r
F
.60468 .17193 m .60787 .16516 L .61115 .16956 L .664 .741 .908 r
F
.60468 .17193 m .60139 .16755 L .60787 .16516 L F
.7117 .17175 m .71525 .16498 L .7183 .16937 L F
.7117 .17175 m .70864 .16736 L .71525 .16498 L F
.51387 .17176 m .51676 .16499 L .52023 .16939 L F
.51387 .17176 m .51038 .16738 L .51676 .16499 L F
.43589 .20191 m .43287 .17633 L .43502 .20114 L .84 .601 .055 r
F
.43287 .17633 m .43377 .22748 L .43754 .23014 L .928 .593 .383 r
F
.43287 .17633 m .42894 .18073 L .43377 .22748 L F
.43264 .19225 m .434 .17405 L .43815 .16265 L .492 .326 .584 r
F
.43066 .20289 m .43212 .1903 L .43264 .19225 L F
.43212 .1903 m .434 .17405 L .43264 .19225 L F
.43607 .20505 m .43502 .20114 L .43754 .23014 L .84 .601 .055 r
F
.43589 .20191 m .43502 .20114 L .43607 .20505 L F
.62089 .17156 m .62414 .16479 L .62738 .16918 L .664 .741 .908 r
F
.62089 .17156 m .61764 .16717 L .62414 .16479 L F
.53007 .17138 m .53301 .16462 L .53645 .16902 L .662 .741 .908 r
F
.53007 .17138 m .52662 .16699 L .53301 .16462 L F
.72793 .17138 m .73154 .1646 L .73455 .169 L .663 .741 .908 r
F
.72793 .17138 m .72491 .16699 L .73154 .1646 L F
.63711 .1712 m .64041 .16442 L .64362 .16882 L F
.63711 .1712 m .63389 .16681 L .64041 .16442 L F
.50319 .30044 m .50591 .31848 L .5095 .31194 L .785 .387 .298 r
F
.50591 .31848 m .50242 .30702 L .50872 .33041 L .752 .446 0 r
F
.50242 .30702 m .50497 .35573 L .50872 .33041 L .906 .642 .139 r
F
.50121 .36969 m .5051 .22246 L .50852 .23955 L .979 .709 .446 r
F
.50121 .36969 m .4975 .3705 L .5051 .22246 L F
.74417 .17102 m .74783 .16424 L .75081 .16864 L .664 .741 .908 r
F
.74417 .17102 m .74118 .16663 L .74783 .16424 L F
.54627 .17102 m .54927 .16425 L .55268 .16865 L .663 .741 .908 r
F
.54627 .17102 m .54286 .16663 L .54927 .16425 L F
.65334 .17084 m .65669 .16406 L .65987 .16846 L .664 .741 .908 r
F
.65334 .17084 m .65015 .16645 L .65669 .16406 L F
.76042 .17065 m .76413 .16387 L .76708 .16827 L F
.76042 .17065 m .75746 .16626 L .76413 .16387 L F
.48694 .31366 m .48357 .28608 L .48694 .31372 L .824 .507 .453 r
F
.4819 .20817 m .48336 .27617 L .48579 .28975 L F
.4819 .20817 m .47784 .23612 L .48357 .28608 L F
.48348 .28529 m .48023 .25883 L .48357 .28608 L .334 .079 .37 r
F
.47784 .23612 m .48023 .25883 L .48348 .28529 L F
.47497 .24726 m .47784 .23612 L .4819 .20817 L 0 0 0 r
F
.47497 .24726 m .4709 .26919 L .47784 .23612 L F
.47784 .23612 m .47361 .26933 L .48023 .25883 L .334 .079 .37 r
F
.4709 .26919 m .47361 .26933 L .47784 .23612 L 0 0 0 r
F
.48023 .25883 m .4769 .23366 L .47702 .23262 L .892 .627 .53 r
F
.48023 .25883 m .47702 .23262 L .48424 .16786 L F
.48024 .25878 m .48424 .16786 L .48777 .17364 L F
.48023 .25883 m .48024 .25877 L .48024 .25878 L F
.48024 .25877 m .48424 .16786 L .48024 .25878 L F
.48579 .28975 m .48357 .28608 L .48694 .31366 L .824 .507 .453 r
F
.48336 .27617 m .48357 .28608 L .48579 .28975 L F
.48357 .28608 m .48023 .25883 L .48024 .25878 L .906 .635 .517 r
F
.48357 .28608 m .48024 .25878 L .48777 .17364 L F
.48694 .31372 m .48357 .28608 L .49128 .1801 L .92 .645 .504 r
F
.49128 .1801 m .48777 .17364 L .49416 .16775 L .772 .694 .777 r
F
.48357 .28608 m .48777 .17364 L .49128 .1801 L .906 .635 .517 r
F
.56248 .17066 m .56554 .16388 L .56891 .16828 L .664 .742 .908 r
F
.56248 .17066 m .5591 .16627 L .56554 .16388 L F
.66957 .17047 m .67298 .16368 L .67612 .16809 L .664 .741 .908 r
F
.66957 .17047 m .66642 .16608 L .67298 .16368 L F
.5787 .17028 m .58181 .16351 L .58515 .16791 L .663 .741 .908 r
F
.5787 .17028 m .57535 .16589 L .58181 .16351 L F
.6858 .1701 m .68927 .16332 L .69238 .16772 L .664 .741 .908 r
F
.6858 .1701 m .68269 .16571 L .68927 .16332 L F
.59492 .16992 m .59809 .16314 L .60139 .16755 L .663 .741 .908 r
F
.59492 .16992 m .59161 .16553 L .59809 .16314 L F
.70205 .16974 m .70557 .16296 L .70864 .16736 L F
.70205 .16974 m .69896 .16534 L .70557 .16296 L F
.50402 .16978 m .50689 .16297 L .51038 .16738 L .665 .742 .907 r
F
.50402 .16978 m .50051 .16538 L .50689 .16297 L F
.61115 .16956 m .61437 .16277 L .61764 .16717 L .664 .741 .908 r
F
.61115 .16956 m .60787 .16516 L .61437 .16277 L F
.41006 .18945 m .40672 .17548 L .4129 .17494 L .541 .439 .687 r
F
.40372 .19408 m .40672 .17548 L .41006 .18945 L .882 .733 .692 r
F
.40372 .19408 m .40006 .18824 L .40672 .17548 L F
.40696 .21045 m .40372 .19408 L .41006 .18945 L .635 .481 .656 r
F
.40071 .21287 m .40372 .19408 L .40696 .21045 L .656 .513 .677 r
F
.40886 .17927 m .40387 .20616 L .40828 .18334 L 0 0 0 r
F
.40943 .17525 m .40886 .17927 L .4129 .17494 L 0 0 .126 r
F
.41006 .18945 m .4129 .17494 L .41573 .20348 L .541 .439 .687 r
F
.41573 .20348 m .41451 .1912 L .41804 .20476 L 0 0 .33 r
F
.41451 .1912 m .4129 .17494 L .41461 .18488 L F
.41451 .1912 m .41461 .18488 L .41804 .20476 L F
.40886 .17927 m .41168 .16572 L .41482 .17235 L 0 0 0 r
F
.41479 .17379 m .41482 .17235 L .41528 .17334 L F
.4129 .17494 m .41528 .17334 L .41804 .20476 L F
.4129 .17494 m .40886 .17927 L .41479 .17367 L F
.41479 .17367 m .40886 .17927 L .41528 .17334 L F
.40886 .17927 m .41482 .17235 L .41479 .17379 L F
.40886 .17927 m .40828 .18334 L .41168 .16572 L F
.40672 .17548 m .40886 .17927 L .40943 .17525 L 0 0 .126 r
F
.39738 .19895 m .39971 .18963 L .40372 .19408 L .785 .739 .81 r
F
.39971 .18963 m .40006 .18824 L .40034 .1887 L F
.39971 .18963 m .40034 .1887 L .40372 .19408 L F
.40788 .17753 m .40207 .19403 L .40886 .17927 L 0 0 .126 r
F
.40672 .17548 m .40522 .18146 L .40788 .17753 L F
.40522 .18146 m .40207 .19403 L .40788 .17753 L F
.40006 .18824 m .40207 .19403 L .40672 .17548 L .31 0 .082 r
F
.7183 .16937 m .72187 .16258 L .72491 .16699 L .664 .741 .908 r
F
.7183 .16937 m .71525 .16498 L .72187 .16258 L F
.52023 .16939 m .52315 .16258 L .52662 .16699 L .665 .742 .907 r
F
.52023 .16939 m .51676 .16499 L .52315 .16258 L F
.62738 .16918 m .63066 .1624 L .63389 .16681 L .663 .741 .908 r
F
.62738 .16918 m .62414 .16479 L .63066 .1624 L F
.73455 .169 m .73818 .16222 L .74118 .16663 L F
.73455 .169 m .73154 .1646 L .73818 .16222 L F
.53645 .16902 m .53943 .16223 L .54286 .16663 L .664 .741 .908 r
F
.53645 .16902 m .53301 .16462 L .53943 .16223 L F
.3345 .20038 m .33197 .17496 L .33803 .17421 L .529 .364 .601 r
F
.32702 .22282 m .33197 .17496 L .3345 .20038 L .828 .597 .589 r
F
.32702 .22282 m .32409 .2033 L .33197 .17496 L F
.33197 .17496 m .33299 .18819 L .33803 .17421 L .717 .297 .249 r
F
.33197 .17496 m .32744 .18053 L .33299 .18819 L F
.32183 .32446 m .31745 .32759 L .32479 .30726 L .992 .871 .606 r
F
.40071 .21287 m .39738 .19895 L .40372 .19408 L .656 .513 .677 r
F
.39385 .22963 m .39738 .19895 L .40071 .21287 L .719 .524 .625 r
F
.39385 .22963 m .39074 .21062 L .39738 .19895 L F
.39738 .19895 m .39368 .19377 L .40006 .18824 L .785 .739 .81 r
F
.39074 .21062 m .39368 .19377 L .39738 .19895 L .325 .22 .578 r
F
.64362 .16882 m .64695 .16204 L .65015 .16645 L .663 .741 .908 r
F
.64362 .16882 m .64041 .16442 L .64695 .16204 L F
.75081 .16864 m .75449 .16185 L .75746 .16626 L .664 .741 .908 r
F
.75081 .16864 m .74783 .16424 L .75449 .16185 L F
.55268 .16865 m .55571 .16186 L .5591 .16627 L .663 .741 .908 r
F
.55268 .16865 m .54927 .16425 L .55571 .16186 L F
.65987 .16846 m .66325 .16167 L .66642 .16608 L .664 .741 .908 r
F
.65987 .16846 m .65669 .16406 L .66325 .16167 L F
.76708 .16827 m .77081 .16148 L .77375 .16589 L F
.76708 .16827 m .76413 .16387 L .77081 .16148 L F
.56891 .16828 m .57199 .16148 L .57535 .16589 L F
.56891 .16828 m .56554 .16388 L .57199 .16148 L F
.67612 .16809 m .67956 .1613 L .68269 .16571 L .663 .741 .908 r
F
.67612 .16809 m .67298 .16368 L .67956 .1613 L F
.58515 .16791 m .58828 .16111 L .59161 .16553 L .664 .741 .908 r
F
.58515 .16791 m .58181 .16351 L .58828 .16111 L F
.69238 .16772 m .69587 .16093 L .69896 .16534 L F
.69238 .16772 m .68927 .16332 L .69587 .16093 L F
.49416 .16775 m .49699 .16097 L .50051 .16538 L .663 .742 .909 r
F
.49416 .16775 m .49062 .16336 L .49699 .16097 L F
.48777 .17364 m .49062 .16336 L .49416 .16775 L .744 .708 .817 r
F
.48777 .17364 m .48424 .16786 L .49062 .16336 L F
.60139 .16755 m .60458 .16075 L .60787 .16516 L .664 .741 .908 r
F
.60139 .16755 m .59809 .16314 L .60458 .16075 L F
.31613 .20544 m .31643 .2273 L .32213 .20544 L .856 .628 .09 r
F
.70864 .16736 m .71219 .16056 L .71525 .16498 L .664 .741 .908 r
F
.70864 .16736 m .70557 .16296 L .71219 .16056 L F
.51038 .16738 m .51327 .16058 L .51676 .16499 L F
.51038 .16738 m .50689 .16297 L .51327 .16058 L F
.41288 .21746 m .41006 .18945 L .41573 .20348 L .195 .118 .536 r
F
.40696 .21045 m .41006 .18945 L .41288 .21746 L .635 .481 .656 r
F
.61764 .16717 m .62088 .16037 L .62414 .16479 L .664 .741 .908 r
F
.61764 .16717 m .61437 .16277 L .62088 .16037 L F
.40419 .2231 m .40696 .21045 L .41038 .22249 L .62 .537 .739 r
F
.40419 .2231 m .40071 .21287 L .40696 .21045 L F
.52662 .16699 m .52956 .16021 L .53301 .16462 L .662 .741 .908 r
F
.52662 .16699 m .52315 .16258 L .52956 .16021 L F
.72491 .16699 m .72851 .16019 L .73154 .1646 L .663 .741 .908 r
F
.72491 .16699 m .72187 .16258 L .72851 .16019 L F
.5095 .31194 m .50591 .31848 L .51243 .2985 L .917 .875 .446 r
F
.50591 .31848 m .50872 .33041 L .51243 .2985 L .752 .446 0 r
F
.50497 .35573 m .50852 .23955 L .51194 .25965 L .992 .736 .412 r
F
.50497 .35573 m .50121 .36969 L .50852 .23955 L F
.63389 .16681 m .63719 .16001 L .64041 .16442 L .663 .741 .908 r
F
.63389 .16681 m .63066 .1624 L .63719 .16001 L F
.74118 .16663 m .74484 .15982 L .74783 .16424 L .664 .741 .908 r
F
.74118 .16663 m .73818 .16222 L .74484 .15982 L F
.54286 .16663 m .54585 .15983 L .54927 .16425 L .663 .741 .908 r
F
.54286 .16663 m .53943 .16223 L .54585 .15983 L F
.30375 .24655 m .29736 .27566 L .30572 .24338 L 0 0 0 r
F
.30572 .24338 m .30002 .26302 L .30965 .21269 L .968 .82 .398 r
F
.30002 .26302 m .30391 .2334 L .30965 .21269 L .956 .761 .601 r
F
.65015 .16645 m .6535 .15964 L .65669 .16406 L .664 .741 .908 r
F
.65015 .16645 m .64695 .16204 L .6535 .15964 L F
.75746 .16626 m .76117 .15945 L .76413 .16387 L F
.75746 .16626 m .75449 .16185 L .76117 .15945 L F
.5591 .16627 m .56215 .15946 L .56554 .16388 L .664 .742 .908 r
F
.5591 .16627 m .55571 .16186 L .56215 .15946 L F
.31174 .32307 m .31454 .30843 L .31745 .32759 L .755 .726 .197 r
F
.31174 .32307 m .30567 .35011 L .31454 .30843 L F
.66642 .16608 m .66982 .15926 L .67298 .16368 L .664 .741 .908 r
F
.66642 .16608 m .66325 .16167 L .66982 .15926 L F
.37971 .23018 m .37703 .20269 L .38388 .18748 L .703 .487 .593 r
F
.38388 .18748 m .3792 .20194 L .38559 .19728 L .288 0 .226 r
F
.37703 .20269 m .3792 .20194 L .38388 .18748 L 0 0 .417 r
F
.57535 .16589 m .57846 .15909 L .58181 .16351 L .663 .741 .908 r
F
.57535 .16589 m .57199 .16148 L .57846 .15909 L F
.68269 .16571 m .68615 .1589 L .68927 .16332 L .664 .741 .908 r
F
.68269 .16571 m .67956 .1613 L .68615 .1589 L F
.28543 .33125 m .28341 .30048 L .29383 .24254 L .85 .598 .557 r
F
.29383 .24254 m .29206 .28865 L .29736 .27566 L .65 .345 .443 r
F
.29346 .24462 m .28712 .27405 L .29383 .24254 L .488 .328 .59 r
F
.28341 .30048 m .28712 .27405 L .29346 .24462 L F
.28712 .27405 m .28031 .3053 L .28061 .30427 L 0 0 .081 r
F
.29383 .24254 m .28712 .27405 L .29206 .28865 L .65 .345 .443 r
F
.28712 .27405 m .28857 .2771 L .29206 .28865 L 0 0 .081 r
F
.28712 .27405 m .28061 .30427 L .28857 .2771 L F
.59161 .16553 m .59477 .15872 L .59809 .16314 L .663 .741 .908 r
F
.59161 .16553 m .58828 .16111 L .59477 .15872 L F
.34075 .19723 m .33803 .17421 L .344 .17537 L .49 .344 .61 r
F
.3345 .20038 m .33803 .17421 L .34075 .19723 L .529 .364 .601 r
F
.33847 .17429 m .34027 .16882 L .344 .17537 L 0 0 0 r
F
.344 .17537 m .34027 .16882 L .34595 .17517 L 0 .066 .628 r
F
.34027 .16882 m .34269 .16052 L .34595 .17517 L 0 0 0 r
F
.34027 .16882 m .33424 .19845 L .34207 .1633 L F
.34027 .16882 m .34207 .1633 L .34269 .16052 L F
.33803 .17421 m .34027 .16882 L .33847 .17429 L F
.33803 .17421 m .33299 .18819 L .34027 .16882 L F
.69896 .16534 m .70248 .15853 L .70557 .16296 L .663 .741 .908 r
F
.69896 .16534 m .69587 .16093 L .70248 .15853 L F
.50051 .16538 m .50337 .15855 L .50689 .16297 L .665 .742 .907 r
F
.50051 .16538 m .49699 .16097 L .50337 .15855 L F
.60787 .16516 m .61109 .15834 L .61437 .16277 L .664 .741 .908 r
F
.60787 .16516 m .60458 .16075 L .61109 .15834 L F
.39368 .19377 m .39581 .19576 L .40006 .18824 L .203 0 0 r
F
.39368 .19377 m .38962 .19616 L .39581 .19576 L F
.71525 .16498 m .71882 .15816 L .72187 .16258 L .664 .741 .908 r
F
.71525 .16498 m .71219 .16056 L .71882 .15816 L F
.51676 .16499 m .51967 .15816 L .52315 .16258 L .665 .742 .907 r
F
.51676 .16499 m .51327 .16058 L .51967 .15816 L F
.62414 .16479 m .62741 .15797 L .63066 .1624 L .663 .741 .908 r
F
.62414 .16479 m .62088 .16037 L .62741 .15797 L F
.40006 .18824 m .39581 .19576 L .40207 .19403 L .31 0 .082 r
F
.73154 .1646 m .73516 .15779 L .73818 .16222 L .663 .741 .908 r
F
.73154 .1646 m .72851 .16019 L .73516 .15779 L F
.53301 .16462 m .53598 .1578 L .53943 .16223 L .664 .742 .908 r
F
.53301 .16462 m .52956 .16021 L .53598 .1578 L F
.64041 .16442 m .64374 .15761 L .64695 .16204 L .663 .741 .908 r
F
.64041 .16442 m .63719 .16001 L .64374 .15761 L F
.41038 .22249 m .40696 .21045 L .41288 .21746 L .125 .19 .66 r
F
.37703 .20269 m .37391 .1848 L .3792 .20194 L 0 0 .417 r
F
.37016 .21765 m .36579 .2237 L .37391 .1848 L 1 .81 .505 r
F
.37391 .1848 m .37547 .19591 L .3792 .20194 L .311 0 .246 r
F
.36579 .2237 m .36909 .20037 L .37061 .19546 L .374 .237 .563 r
F
.36949 .20596 m .37061 .19546 L .37391 .1848 L F
.36579 .2237 m .37061 .19546 L .36949 .20596 L F
.37391 .1848 m .36909 .20037 L .37547 .19591 L .311 0 .246 r
F
.37547 .19591 m .37265 .17625 L .37829 .18197 L .313 .231 .6 r
F
.37265 .17625 m .37248 .17503 L .37275 .17535 L F
.37265 .17625 m .37275 .17535 L .37829 .18197 L F
.74783 .16424 m .75151 .15742 L .75449 .16185 L .663 .741 .908 r
F
.74783 .16424 m .74484 .15982 L .75151 .15742 L F
.54927 .16425 m .5523 .15744 L .55571 .16186 L F
.54927 .16425 m .54585 .15983 L .5523 .15744 L F
.48424 .16786 m .48708 .15895 L .49062 .16336 L .717 .717 .849 r
F
.48424 .16786 m .4807 .16255 L .48708 .15895 L F
.4769 .23366 m .4807 .16255 L .48424 .16786 L .876 .62 .547 r
F
.65669 .16406 m .66007 .15724 L .66325 .16167 L .664 .741 .908 r
F
.65669 .16406 m .6535 .15964 L .66007 .15724 L F
.76413 .16387 m .76787 .15705 L .77081 .16148 L F
.76413 .16387 m .76117 .15945 L .76787 .15705 L F
.56554 .16388 m .56862 .15705 L .57199 .16148 L F
.56554 .16388 m .56215 .15946 L .56862 .15705 L F
.67298 .16368 m .67641 .15686 L .67956 .1613 L .663 .741 .908 r
F
.67298 .16368 m .66982 .15926 L .67641 .15686 L F
.41038 .22249 m .41288 .21746 L .4164 .22713 L .125 .19 .66 r
F
.58181 .16351 m .58494 .15668 L .58828 .16111 L .664 .741 .908 r
F
.58181 .16351 m .57846 .15909 L .58494 .15668 L F
.68927 .16332 m .69276 .15649 L .69587 .16093 L .663 .741 .908 r
F
.68927 .16332 m .68615 .1589 L .69276 .15649 L F
.49062 .16336 m .49345 .15654 L .49699 .16097 L .664 .742 .908 r
F
.49062 .16336 m .48708 .15895 L .49345 .15654 L F
.59809 .16314 m .60127 .15631 L .60458 .16075 L .664 .741 .908 r
F
.59809 .16314 m .59477 .15872 L .60127 .15631 L F
.70557 .16296 m .70911 .15612 L .71219 .16056 L F
.70557 .16296 m .70248 .15853 L .70911 .15612 L F
.50689 .16297 m .50977 .15614 L .51327 .16058 L F
.50689 .16297 m .50337 .15855 L .50977 .15614 L F
.61437 .16277 m .61761 .15594 L .62088 .16037 L F
.61437 .16277 m .61109 .15834 L .61761 .15594 L F
.30391 .2334 m .29901 .24145 L .30871 .19086 L .997 .792 .501 r
F
.29901 .24145 m .30235 .21953 L .30871 .19086 L .73 .566 .669 r
F
.30871 .19086 m .30235 .21953 L .31015 .19521 L 0 0 .107 r
F
.52315 .16258 m .52609 .15577 L .52956 .16021 L .662 .741 .908 r
F
.52315 .16258 m .51967 .15816 L .52609 .15577 L F
.72187 .16258 m .72547 .15575 L .72851 .16019 L .663 .741 .908 r
F
.72187 .16258 m .71882 .15816 L .72547 .15575 L F
.63066 .1624 m .63395 .15557 L .63719 .16001 L F
.63066 .1624 m .62741 .15797 L .63395 .15557 L F
.73818 .16222 m .74183 .15538 L .74484 .15982 L .664 .741 .908 r
F
.73818 .16222 m .73516 .15779 L .74183 .15538 L F
.53943 .16223 m .54242 .1554 L .54585 .15983 L .663 .741 .908 r
F
.53943 .16223 m .53598 .1578 L .54242 .1554 L F
.64695 .16204 m .6503 .1552 L .6535 .15964 L .664 .741 .908 r
F
.64695 .16204 m .64374 .15761 L .6503 .1552 L F
.75449 .16185 m .7582 .15501 L .76117 .15945 L F
.75449 .16185 m .75151 .15742 L .7582 .15501 L F
.55571 .16186 m .55875 .15502 L .56215 .15946 L .664 .742 .908 r
F
.55571 .16186 m .5523 .15744 L .55875 .15502 L F
.66325 .16167 m .66666 .15482 L .66982 .15926 L .664 .741 .908 r
F
.66325 .16167 m .66007 .15724 L .66666 .15482 L F
.43589 .20191 m .43754 .23014 L .44185 .21238 L .84 .601 .055 r
F
.57199 .16148 m .57509 .15464 L .57846 .15909 L .663 .741 .908 r
F
.57199 .16148 m .56862 .15705 L .57509 .15464 L F
.32409 .2033 m .32138 .18115 L .32744 .18053 L .529 .376 .617 r
F
.31643 .2273 m .32138 .18115 L .32409 .2033 L .969 .745 .545 r
F
.31643 .2273 m .31225 .22603 L .32138 .18115 L F
.32138 .18115 m .32208 .19768 L .32744 .18053 L .935 .561 .198 r
F
.31225 .22603 m .3175 .17616 L .32138 .18115 L .716 .491 .583 r
F
.32138 .18115 m .3175 .17616 L .32208 .19768 L .935 .561 .198 r
F
.67956 .1613 m .68302 .15445 L .68615 .1589 L .664 .741 .908 r
F
.67956 .1613 m .67641 .15686 L .68302 .15445 L F
.4164 .22713 m .4186 .232 L .42256 .22915 L 0 0 .292 r
F
.42256 .22915 m .42254 .22916 L .42526 .22 L .933 .958 .647 r
F
.41901 .19043 m .42011 .17026 L .4244 .158 L .601 .408 .592 r
F
.41573 .20348 m .41804 .20476 L .42007 .22028 L 0 0 .33 r
F
.42254 .22916 m .41938 .23144 L .42242 .22511 L .933 .958 .647 r
F
.41938 .23144 m .41953 .23032 L .42242 .22511 L F
.42254 .22916 m .42242 .22511 L .42526 .22 L F
.4186 .232 m .42111 .22827 L .42526 .22 L 0 0 .414 r
F
.42111 .22827 m .41804 .20476 L .42079 .20436 L .538 .38 .614 r
F
.4229 .21477 m .42079 .20436 L .42434 .20385 L F
.42111 .22827 m .42079 .20436 L .4229 .21477 L F
.41804 .20476 m .41997 .21768 L .42434 .20385 L 0 0 .147 r
F
.41804 .20476 m .41528 .17334 L .41872 .20583 L F
.41899 .21111 m .41872 .20583 L .41997 .21768 L F
.41804 .20476 m .41872 .20583 L .41899 .21111 L F
.41612 .18128 m .41647 .20576 L .41997 .21768 L .96 .627 .257 r
F
.41528 .17334 m .41545 .17796 L .41612 .18128 L F
.41545 .17796 m .41647 .20576 L .41612 .18128 L F
.41819 .19539 m .41876 .18334 L .41901 .19043 L .601 .408 .592 r
F
.41647 .20576 m .41797 .19109 L .41819 .19539 L F
.41797 .19109 m .41876 .18334 L .41819 .19539 L F
.41876 .18334 m .42011 .17026 L .41901 .19043 L F
.42013 .22193 m .42007 .22028 L .42048 .22341 L 0 0 .33 r
F
.41573 .20348 m .42007 .22028 L .42013 .22193 L F
.42031 .22459 m .42048 .22341 L .42111 .22827 L F
.41573 .20348 m .42048 .22341 L .42031 .22459 L F
.41938 .23144 m .4186 .232 L .41953 .23032 L .933 .958 .647 r
F
.42231 .22101 m .42389 .20759 L .42894 .18073 L .538 .38 .614 r
F
.42389 .20759 m .42456 .20271 L .42894 .18073 L F
.42526 .22 m .42111 .22827 L .42894 .18073 L .999 .799 .46 r
F
.42389 .20759 m .42434 .20385 L .42456 .20271 L .538 .38 .614 r
F
.42894 .18073 m .42434 .20385 L .43066 .20289 L .466 .161 .364 r
F
.43066 .20289 m .42816 .17649 L .434 .17405 L .492 .326 .584 r
F
.42816 .17649 m .42778 .17247 L .42868 .1727 L F
.42816 .17649 m .42868 .1727 L .434 .17405 L F
.42111 .22827 m .42227 .21953 L .42231 .22101 L .538 .38 .614 r
F
.42227 .21953 m .42434 .20385 L .42231 .22101 L F
.58828 .16111 m .59144 .15427 L .59477 .15872 L .663 .741 .908 r
F
.58828 .16111 m .58494 .15668 L .59144 .15427 L F
.69587 .16093 m .69938 .15409 L .70248 .15853 L F
.69587 .16093 m .69276 .15649 L .69938 .15409 L F
.49699 .16097 m .49984 .15411 L .50337 .15855 L .665 .742 .907 r
F
.49699 .16097 m .49345 .15654 L .49984 .15411 L F
.45152 .17818 m .44814 .16379 L .45427 .16951 L .285 .266 .661 r
F
.44431 .21381 m .44814 .16379 L .45152 .17818 L .681 .459 .579 r
F
.44431 .21381 m .44145 .17976 L .44814 .16379 L F
.44814 .16379 m .45082 .15721 L .45427 .16951 L .737 .846 .405 r
F
.44814 .16379 m .44419 .17054 L .45082 .15721 L F
.44145 .17976 m .44419 .17054 L .44814 .16379 L .233 .203 .618 r
F
.51243 .2985 m .51537 .28264 L .51883 .30814 L 0 0 .014 r
F
.51243 .2985 m .50872 .33041 L .51537 .28264 L F
.50872 .33041 m .51194 .25965 L .51537 .28264 L .972 .759 .331 r
F
.50872 .33041 m .50497 .35573 L .51194 .25965 L F
.60458 .16075 m .60779 .1539 L .61109 .15834 L .664 .741 .908 r
F
.60458 .16075 m .60127 .15631 L .60779 .1539 L F
.34075 .19723 m .344 .17537 L .34589 .21304 L .49 .344 .61 r
F
.344 .17537 m .34595 .17517 L .34698 .22825 L 0 .066 .628 r
F
.71219 .16056 m .71575 .15371 L .71882 .15816 L .664 .741 .908 r
F
.71219 .16056 m .70911 .15612 L .71575 .15371 L F
.51327 .16058 m .51618 .15371 L .51967 .15816 L .665 .742 .907 r
F
.51327 .16058 m .50977 .15614 L .51618 .15371 L F
.27595 .22945 m .27297 .21261 L .26862 .33938 L .979 .697 .413 r
F
.4769 .23366 m .47356 .21124 L .4807 .16255 L .876 .62 .547 r
F
.4807 .16255 m .48351 .15451 L .48708 .15895 L .695 .725 .873 r
F
.4807 .16255 m .47713 .15756 L .48351 .15451 L F
.47356 .21124 m .47713 .15756 L .4807 .16255 L .858 .614 .569 r
F
.62088 .16037 m .62415 .15353 L .62741 .15797 L .663 .741 .908 r
F
.62088 .16037 m .61761 .15594 L .62415 .15353 L F
.72851 .16019 m .73213 .15335 L .73516 .15779 L F
.72851 .16019 m .72547 .15575 L .73213 .15335 L F
.52956 .16021 m .53252 .15335 L .53598 .1578 L .664 .741 .908 r
F
.52956 .16021 m .52609 .15577 L .53252 .15335 L F
.63719 .16001 m .64051 .15316 L .64374 .15761 L .663 .741 .908 r
F
.63719 .16001 m .63395 .15557 L .64051 .15316 L F
.74484 .15982 m .74852 .15297 L .75151 .15742 L F
.74484 .15982 m .74183 .15538 L .74852 .15297 L F
.54585 .15983 m .54887 .15299 L .5523 .15744 L F
.54585 .15983 m .54242 .1554 L .54887 .15299 L F
.6535 .15964 m .65688 .15279 L .66007 .15724 L .664 .741 .908 r
F
.6535 .15964 m .6503 .1552 L .65688 .15279 L F
.76117 .15945 m .76491 .1526 L .76787 .15705 L F
.76117 .15945 m .7582 .15501 L .76491 .1526 L F
.56215 .15946 m .56523 .1526 L .56862 .15705 L F
.56215 .15946 m .55875 .15502 L .56523 .1526 L F
.66982 .15926 m .67325 .15241 L .67641 .15686 L .663 .741 .908 r
F
.66982 .15926 m .66666 .15482 L .67325 .15241 L F
.29358 .23338 m .29205 .19678 L .29567 .22817 L 0 0 .324 r
F
.28655 .24659 m .29205 .19678 L .29358 .23338 L .663 .444 .577 r
F
.28655 .24659 m .28498 .21103 L .29205 .19678 L F
.57846 .15909 m .58159 .15223 L .58494 .15668 L .664 .741 .908 r
F
.57846 .15909 m .57509 .15464 L .58159 .15223 L F
.33676 .23106 m .3345 .20038 L .34075 .19723 L .561 .375 .586 r
F
.33121 .22275 m .3345 .20038 L .33676 .23106 L .978 .815 .611 r
F
.33121 .22275 m .32702 .22282 L .3345 .20038 L F
.68615 .1589 m .68964 .15204 L .69276 .15649 L .663 .741 .908 r
F
.68615 .1589 m .68302 .15445 L .68964 .15204 L F
.48708 .15895 m .4899 .15209 L .49345 .15654 L .664 .741 .908 r
F
.48708 .15895 m .48351 .15451 L .4899 .15209 L F
.4689 .23193 m .4709 .26919 L .47497 .24726 L .594 .292 .427 r
F
.4689 .23193 m .46464 .26134 L .4709 .26919 L F
.59477 .15872 m .59795 .15186 L .60127 .15631 L .663 .741 .908 r
F
.59477 .15872 m .59144 .15427 L .59795 .15186 L F
.70248 .15853 m .70602 .15167 L .70911 .15612 L .664 .741 .908 r
F
.70248 .15853 m .69938 .15409 L .70602 .15167 L F
.50337 .15855 m .50625 .15169 L .50977 .15614 L .664 .742 .908 r
F
.50337 .15855 m .49984 .15411 L .50625 .15169 L F
.45447 .21141 m .45152 .17818 L .45733 .1995 L .088 .03 .489 r
F
.44741 .24127 m .45152 .17818 L .45447 .21141 L .815 .569 .567 r
F
.44741 .24127 m .44431 .21381 L .45152 .17818 L F
.45152 .17818 m .45427 .16951 L .45733 .1995 L .285 .266 .661 r
F
.61109 .15834 m .61432 .15148 L .61761 .15594 L .664 .741 .908 r
F
.61109 .15834 m .60779 .1539 L .61432 .15148 L F
.44145 .17976 m .43815 .16265 L .44419 .17054 L .233 .203 .618 r
F
.43377 .22748 m .43815 .16265 L .44145 .17976 L .844 .594 .562 r
F
.43377 .22748 m .43066 .20289 L .43815 .16265 L F
.43754 .23014 m .44145 .17976 L .44431 .21381 L .972 .737 .522 r
F
.43754 .23014 m .43377 .22748 L .44145 .17976 L F
.43815 .16265 m .43979 .19181 L .44419 .17054 L .784 .424 .374 r
F
.43815 .16265 m .434 .17405 L .43979 .19181 L F
.51967 .15816 m .52261 .15131 L .52609 .15577 L .662 .741 .908 r
F
.51967 .15816 m .51618 .15371 L .52261 .15131 L F
.71882 .15816 m .72242 .1513 L .72547 .15575 L .663 .741 .908 r
F
.71882 .15816 m .71575 .15371 L .72242 .1513 L F
.62741 .15797 m .6307 .15111 L .63395 .15557 L F
.62741 .15797 m .62415 .15353 L .6307 .15111 L F
.73516 .15779 m .73881 .15092 L .74183 .15538 L .664 .741 .908 r
F
.73516 .15779 m .73213 .15335 L .73881 .15092 L F
.53598 .1578 m .53897 .15094 L .54242 .1554 L .663 .741 .908 r
F
.53598 .1578 m .53252 .15335 L .53897 .15094 L F
.32744 .18053 m .32738 .20979 L .33299 .18819 L .687 .347 .394 r
F
.32744 .18053 m .32208 .19768 L .32738 .20979 L F
.33299 .18819 m .33424 .19845 L .34027 .16882 L .123 0 .215 r
F
.64374 .15761 m .64708 .15075 L .6503 .1552 L .664 .741 .908 r
F
.64374 .15761 m .64051 .15316 L .64708 .15075 L F
.75151 .15742 m .75522 .15055 L .7582 .15501 L F
.75151 .15742 m .74852 .15297 L .75522 .15055 L F
.5523 .15744 m .55534 .15056 L .55875 .15502 L .664 .742 .908 r
F
.5523 .15744 m .54887 .15299 L .55534 .15056 L F
.31225 .22603 m .31015 .19521 L .3175 .17616 L .716 .491 .583 r
F
.66007 .15724 m .66347 .15036 L .66666 .15482 L .664 .741 .908 r
F
.66007 .15724 m .65688 .15279 L .66347 .15036 L F
.29736 .27566 m .30002 .26302 L .30572 .24338 L .884 .85 .393 r
F
.34303 .22811 m .34075 .19723 L .34589 .21304 L .154 .075 .507 r
F
.34109 .22817 m .33676 .23106 L .34303 .22811 L 0 0 0 r
F
.33676 .23106 m .34075 .19723 L .34303 .22811 L .561 .375 .586 r
F
.56862 .15705 m .57171 .15018 L .57509 .15464 L .663 .741 .908 r
F
.56862 .15705 m .56523 .1526 L .57171 .15018 L F
.67641 .15686 m .67987 .14999 L .68302 .15445 L .664 .741 .908 r
F
.67641 .15686 m .67325 .15241 L .67987 .14999 L F
.58494 .15668 m .58809 .14981 L .59144 .15427 L .663 .741 .908 r
F
.58494 .15668 m .58159 .15223 L .58809 .14981 L F
.69276 .15649 m .69627 .14963 L .69938 .15409 L F
.69276 .15649 m .68964 .15204 L .69627 .14963 L F
.4164 .22713 m .41288 .21746 L .4186 .232 L 0 0 .292 r
F
.49345 .15654 m .4963 .14965 L .49984 .15411 L .665 .742 .907 r
F
.49345 .15654 m .4899 .15209 L .4963 .14965 L F
.27872 .24911 m .27595 .22945 L .27398 .32897 L .984 .703 .381 r
F
.27595 .22945 m .26862 .33938 L .27398 .32897 L .979 .697 .413 r
F
.47356 .21124 m .47019 .19204 L .47713 .15756 L .858 .614 .569 r
F
.47713 .15756 m .47993 .15004 L .48351 .15451 L .681 .731 .888 r
F
.47713 .15756 m .47355 .15278 L .47993 .15004 L F
.47019 .19204 m .47355 .15278 L .47713 .15756 L .84 .616 .598 r
F
.60127 .15631 m .60448 .14944 L .60779 .1539 L .664 .741 .908 r
F
.60127 .15631 m .59795 .15186 L .60448 .14944 L F
.70911 .15612 m .71268 .14925 L .71575 .15371 L F
.70911 .15612 m .70602 .15167 L .71268 .14925 L F
.50977 .15614 m .51267 .14925 L .51618 .15371 L .665 .742 .907 r
F
.50977 .15614 m .50625 .15169 L .51267 .14925 L F
.38962 .19616 m .39154 .20252 L .39581 .19576 L .676 .151 0 r
F
.38962 .19616 m .38559 .19728 L .39154 .20252 L F
.61761 .15594 m .62087 .14906 L .62415 .15353 L .663 .741 .908 r
F
.61761 .15594 m .61432 .15148 L .62087 .14906 L F
.72547 .15575 m .72909 .14888 L .73213 .15335 L F
.72547 .15575 m .72242 .1513 L .72909 .14888 L F
.52609 .15577 m .52905 .14889 L .53252 .15335 L .664 .741 .908 r
F
.52609 .15577 m .52261 .15131 L .52905 .14889 L F
.41288 .21746 m .41573 .20348 L .4186 .232 L .195 .118 .536 r
F
.63395 .15557 m .63727 .1487 L .64051 .15316 L .663 .741 .908 r
F
.63395 .15557 m .6307 .15111 L .63727 .1487 L F
.41528 .17334 m .41168 .16572 L .41601 .20197 L .96 .627 .257 r
F
.41638 .2035 m .41601 .20197 L .41647 .20576 L F
.41528 .17334 m .41601 .20197 L .41638 .2035 L F
.41168 .16572 m .41361 .17629 L .41647 .20576 L .226 0 .245 r
F
.40207 .19403 m .40387 .20616 L .40886 .17927 L .171 0 .267 r
F
.40387 .20616 m .40705 .18413 L .41168 .16572 L .99 .853 .49 r
F
.41168 .16572 m .40705 .18413 L .41318 .1768 L .226 0 .245 r
F
.41336 .17493 m .41318 .1768 L .41361 .17629 L F
.41168 .16572 m .41318 .1768 L .41336 .17493 L F
.40705 .18413 m .4085 .17096 L .41065 .17983 L .954 .802 .357 r
F
.40207 .19403 m .39709 .21856 L .40387 .20616 L .171 0 .267 r
F
.40705 .18413 m .40236 .20194 L .4096 .15782 L .954 .802 .357 r
F
.40999 .15733 m .4096 .15782 L .41062 .15158 L F
.40705 .18413 m .4096 .15782 L .40999 .15733 L F
.40236 .20194 m .40674 .15024 L .41062 .15158 L .949 .71 .542 r
F
.40731 .16065 m .40723 .1972 L .40997 .20981 L .757 .427 .427 r
F
.40674 .15024 m .40686 .16121 L .40731 .16065 L F
.40686 .16121 m .40723 .1972 L .40731 .16065 L F
.41026 .2068 m .40997 .20981 L .41064 .21289 L F
.40674 .15024 m .40997 .20981 L .41026 .2068 L F
.41065 .17983 m .41062 .15158 L .41361 .17629 L .954 .802 .357 r
F
.4085 .17096 m .41062 .15158 L .41065 .17983 L F
.74183 .15538 m .74551 .14851 L .74852 .15297 L .663 .741 .908 r
F
.74183 .15538 m .73881 .15092 L .74551 .14851 L F
.54242 .1554 m .54543 .14852 L .54887 .15299 L F
.54242 .1554 m .53897 .15094 L .54543 .14852 L F
.6503 .1552 m .65367 .14832 L .65688 .15279 L .664 .741 .908 r
F
.6503 .1552 m .64708 .15075 L .65367 .14832 L F
.7582 .15501 m .76193 .14813 L .76491 .1526 L F
.7582 .15501 m .75522 .15055 L .76193 .14813 L F
.55875 .15502 m .56182 .14813 L .56523 .1526 L F
.55875 .15502 m .55534 .15056 L .56182 .14813 L F
.66666 .15482 m .67008 .14794 L .67325 .15241 L .663 .741 .908 r
F
.66666 .15482 m .66347 .15036 L .67008 .14794 L F
.57509 .15464 m .57822 .14776 L .58159 .15223 L .664 .741 .908 r
F
.57509 .15464 m .57171 .15018 L .57822 .14776 L F
.68302 .15445 m .6865 .14757 L .68964 .15204 L .663 .741 .908 r
F
.68302 .15445 m .67987 .14999 L .6865 .14757 L F
.48351 .15451 m .48633 .14761 L .4899 .15209 L .664 .741 .908 r
F
.48351 .15451 m .47993 .15004 L .48633 .14761 L F
.59144 .15427 m .59462 .14739 L .59795 .15186 L .663 .741 .908 r
F
.59144 .15427 m .58809 .14981 L .59462 .14739 L F
.69938 .15409 m .70292 .1472 L .70602 .15167 L .664 .741 .908 r
F
.69938 .15409 m .69627 .14963 L .70292 .1472 L F
.49984 .15411 m .50272 .14721 L .50625 .15169 L .664 .742 .908 r
F
.49984 .15411 m .4963 .14965 L .50272 .14721 L F
.60779 .1539 m .61102 .14701 L .61432 .15148 L .664 .741 .908 r
F
.60779 .1539 m .60448 .14944 L .61102 .14701 L F
.45527 .22812 m .4511 .24541 L .45739 .24891 L .557 .224 .36 r
F
.45527 .22812 m .45739 .24891 L .46072 .26965 L F
.4511 .24541 m .45447 .21141 L .45739 .24891 L .958 .746 .575 r
F
.4511 .24541 m .44741 .24127 L .45447 .21141 L F
.45427 .16951 m .45082 .15721 L .4537 .30717 L .977 .679 .368 r
F
.45082 .15721 m .45031 .28437 L .4537 .30717 L .949 .639 .413 r
F
.44419 .17054 m .44685 .16515 L .45082 .15721 L 0 0 0 r
F
.45082 .15721 m .44685 .16515 L .45031 .28437 L .949 .639 .413 r
F
.4186 .232 m .41573 .20348 L .42111 .22827 L 0 0 .414 r
F
.71575 .15371 m .71935 .14682 L .72242 .1513 L .663 .741 .908 r
F
.71575 .15371 m .71268 .14925 L .71935 .14682 L F
.51618 .15371 m .51911 .14684 L .52261 .15131 L .662 .741 .908 r
F
.51618 .15371 m .51267 .14925 L .51911 .14684 L F
.28122 .27256 m .27872 .24911 L .28031 .3053 L .949 .685 .228 r
F
.27872 .24911 m .27398 .32897 L .28031 .3053 L .984 .703 .381 r
F
.28122 .27256 m .28031 .3053 L .28712 .27405 L .949 .685 .228 r
F
.27398 .32897 m .28498 .21103 L .28655 .24659 L .981 .733 .485 r
F
.27398 .32897 m .26862 .33938 L .28498 .21103 L F
.62415 .15353 m .62744 .14664 L .6307 .15111 L .663 .741 .908 r
F
.62415 .15353 m .62087 .14906 L .62744 .14664 L F
.73213 .15335 m .73578 .14645 L .73881 .15092 L .664 .741 .908 r
F
.73213 .15335 m .72909 .14888 L .73578 .14645 L F
.53252 .15335 m .53551 .14646 L .53897 .15094 L .663 .741 .908 r
F
.53252 .15335 m .52905 .14889 L .53551 .14646 L F
.64051 .15316 m .64385 .14627 L .64708 .15075 L .664 .741 .908 r
F
.64051 .15316 m .63727 .1487 L .64385 .14627 L F
.74852 .15297 m .75222 .14607 L .75522 .15055 L F
.74852 .15297 m .74551 .14851 L .75222 .14607 L F
.54887 .15299 m .55191 .14608 L .55534 .15056 L .664 .742 .908 r
F
.54887 .15299 m .54543 .14852 L .55191 .14608 L F
.45739 .24891 m .45447 .21141 L .46028 .23652 L .067 .007 .472 r
F
.45447 .21141 m .45733 .1995 L .46028 .23652 L .088 .03 .489 r
F
.45733 .1995 m .45427 .16951 L .45678 .29525 L .978 .696 .308 r
F
.45427 .16951 m .4537 .30717 L .4573 .32165 L .977 .679 .368 r
F
.44685 .16515 m .44708 .25618 L .45031 .28437 L .875 .555 .442 r
F
.44814 .24357 m .45255 .14068 L .45616 .14739 L .901 .63 .517 r
F
.44708 .25618 m .44778 .24144 L .44814 .24357 L F
.44778 .24144 m .45255 .14068 L .44814 .24357 L F
.4571 .29717 m .45678 .29525 L .45707 .3098 L .978 .696 .308 r
F
.45733 .1995 m .45678 .29525 L .4571 .29717 L F
.45726 .31104 m .45707 .3098 L .45725 .31915 L F
.45733 .1995 m .45707 .3098 L .45726 .31104 L F
.45121 .27201 m .45616 .14739 L .45975 .15495 L .921 .646 .503 r
F
.45031 .28437 m .45092 .27012 L .45121 .27201 L F
.45092 .27012 m .45616 .14739 L .45121 .27201 L F
.45733 .1995 m .45725 .31915 L .4573 .3195 L .978 .696 .308 r
F
.46028 .23652 m .45733 .1995 L .4582 .22863 L .952 .688 .235 r
F
.46072 .26965 m .45739 .24891 L .463 .26483 L 0 0 .494 r
F
.46464 .26134 m .46072 .26965 L .46542 .27561 L .692 .297 .294 r
F
.46576 .26905 m .46542 .27561 L .467 .2776 L F
.46464 .26134 m .46542 .27561 L .46576 .26905 L F
.45739 .24891 m .46028 .23652 L .46175 .26128 L .067 .007 .472 r
F
.46321 .26642 m .463 .26483 L .46345 .26611 L 0 0 .494 r
F
.46072 .26965 m .463 .26483 L .46321 .26642 L F
.46542 .27561 m .46345 .26611 L .467 .2776 L F
.46072 .26965 m .46345 .26611 L .46542 .27561 L F
.46345 .26611 m .46028 .23652 L .46147 .2566 L .914 .656 .159 r
F
.46345 .26611 m .46147 .2566 L .46411 .30124 L F
.4644 .29563 m .46411 .30124 L .46514 .31854 L F
.46345 .26611 m .46411 .30124 L .4644 .29563 L F
.46036 .24494 m .4582 .22863 L .46112 .32593 L .952 .688 .235 r
F
.46028 .23652 m .4582 .22863 L .46036 .24494 L F
.45733 .1995 m .4573 .32165 L .46112 .32593 L .978 .696 .308 r
F
.45428 .29857 m .45975 .15495 L .46329 .16427 L .94 .664 .488 r
F
.4537 .30717 m .4541 .29729 L .45428 .29857 L F
.4541 .29729 m .45975 .15495 L .45428 .29857 L F
.4573 .3195 m .45725 .31915 L .4573 .32165 L .978 .696 .308 r
F
.65688 .15279 m .66028 .14589 L .66347 .15036 L .664 .741 .908 r
F
.65688 .15279 m .65367 .14832 L .66028 .14589 L F
.56523 .1526 m .56832 .1457 L .57171 .15018 L .663 .741 .908 r
F
.56523 .1526 m .56182 .14813 L .56832 .1457 L F
.67325 .15241 m .67671 .14551 L .67987 .14999 L .664 .741 .908 r
F
.67325 .15241 m .67008 .14794 L .67671 .14551 L F
.39581 .19576 m .39709 .21856 L .40207 .19403 L .815 .435 .335 r
F
.39581 .19576 m .39154 .20252 L .39709 .21856 L F
.58159 .15223 m .58473 .14533 L .58809 .14981 L .664 .741 .908 r
F
.58159 .15223 m .57822 .14776 L .58473 .14533 L F
.47019 .19204 m .46677 .1764 L .47355 .15278 L .84 .616 .598 r
F
.47355 .15278 m .47634 .14555 L .47993 .15004 L .672 .735 .898 r
F
.47355 .15278 m .46995 .14813 L .47634 .14555 L F
.46677 .1764 m .46995 .14813 L .47355 .15278 L .827 .63 .635 r
F
.36909 .20037 m .37248 .17503 L .37547 .19591 L .954 .824 .386 r
F
.36909 .20037 m .36421 .21563 L .37248 .17503 L F
.37248 .17503 m .37474 .17189 L .37829 .18197 L .07 .256 .747 r
F
.37248 .17503 m .36884 .16706 L .37474 .17189 L F
.36421 .21563 m .36884 .16706 L .37248 .17503 L .833 .599 .585 r
F
.68964 .15204 m .69315 .14514 L .69627 .14963 L .663 .741 .908 r
F
.68964 .15204 m .6865 .14757 L .69315 .14514 L F
.4899 .15209 m .49274 .14517 L .4963 .14965 L .665 .742 .907 r
F
.4899 .15209 m .48633 .14761 L .49274 .14517 L F
.59795 .15186 m .60115 .14495 L .60448 .14944 L .664 .741 .908 r
F
.59795 .15186 m .59462 .14739 L .60115 .14495 L F
.34698 .22825 m .34595 .17517 L .35009 .20925 L .022 0 .414 r
F
.34595 .17517 m .34269 .16052 L .34715 .18814 L .835 .552 .007 r
F
.70602 .15167 m .70959 .14476 L .71268 .14925 L .664 .741 .908 r
F
.70602 .15167 m .70292 .1472 L .70959 .14476 L F
.50625 .15169 m .50915 .14476 L .51267 .14925 L .665 .742 .908 r
F
.50625 .15169 m .50272 .14721 L .50915 .14476 L F
.61432 .15148 m .61758 .14458 L .62087 .14906 L .663 .741 .908 r
F
.61432 .15148 m .61102 .14701 L .61758 .14458 L F
.72242 .1513 m .72604 .1444 L .72909 .14888 L F
.72242 .1513 m .71935 .14682 L .72604 .1444 L F
.52261 .15131 m .52556 .1444 L .52905 .14889 L .664 .741 .908 r
F
.52261 .15131 m .51911 .14684 L .52556 .1444 L F
.6307 .15111 m .63402 .14421 L .63727 .1487 L .663 .741 .908 r
F
.6307 .15111 m .62744 .14664 L .63402 .14421 L F
.73881 .15092 m .74249 .14402 L .74551 .14851 L F
.73881 .15092 m .73578 .14645 L .74249 .14402 L F
.53897 .15094 m .54198 .14404 L .54543 .14852 L F
.53897 .15094 m .53551 .14646 L .54198 .14404 L F
.64708 .15075 m .65045 .14383 L .65367 .14832 L .664 .741 .908 r
F
.64708 .15075 m .64385 .14627 L .65045 .14383 L F
.75522 .15055 m .75895 .14364 L .76193 .14813 L F
.75522 .15055 m .75222 .14607 L .75895 .14364 L F
.55534 .15056 m .5584 .14364 L .56182 .14813 L .664 .742 .908 r
F
.55534 .15056 m .55191 .14608 L .5584 .14364 L F
.41997 .21768 m .4244 .158 L .42778 .17247 L .925 .677 .544 r
F
.42434 .20385 m .42778 .17247 L .43066 .20289 L .971 .812 .391 r
F
.42434 .20385 m .41997 .21768 L .42725 .17549 L F
.42749 .17505 m .42725 .17549 L .42778 .17247 L F
.42434 .20385 m .42725 .17549 L .42749 .17505 L F
.41997 .21768 m .41647 .20576 L .4244 .158 L .925 .677 .544 r
F
.42141 .18626 m .42077 .22079 L .42459 .22522 L .721 .401 .436 r
F
.42011 .17026 m .42034 .18823 L .42141 .18626 L F
.42034 .18823 m .42077 .22079 L .42141 .18626 L F
.42778 .17247 m .4244 .158 L .42922 .2034 L .937 .634 .176 r
F
.4244 .158 m .42459 .22522 L .42922 .2034 L .901 .573 .418 r
F
.4244 .158 m .42011 .17026 L .42459 .22522 L F
.66347 .15036 m .6669 .14346 L .67008 .14794 L .663 .741 .908 r
F
.66347 .15036 m .66028 .14589 L .6669 .14346 L F
.57171 .15018 m .57483 .14327 L .57822 .14776 L .664 .741 .908 r
F
.57171 .15018 m .56832 .1457 L .57483 .14327 L F
.36884 .16706 m .37073 .17087 L .37474 .17189 L .227 0 0 r
F
.36884 .16706 m .36447 .1726 L .37073 .17087 L F
.67987 .14999 m .68335 .14308 L .6865 .14757 L .663 .741 .908 r
F
.67987 .14999 m .67671 .14551 L .68335 .14308 L F
.47993 .15004 m .48275 .14312 L .48633 .14761 L F
.47993 .15004 m .47634 .14555 L .48275 .14312 L F
.58809 .14981 m .59127 .1429 L .59462 .14739 L F
.58809 .14981 m .58473 .14533 L .59127 .1429 L F
.69627 .14963 m .69981 .1427 L .70292 .1472 L .664 .741 .908 r
F
.69627 .14963 m .69315 .14514 L .69981 .1427 L F
.4963 .14965 m .49917 .14272 L .50272 .14721 L .664 .742 .908 r
F
.4963 .14965 m .49274 .14517 L .49917 .14272 L F
.60448 .14944 m .60771 .14251 L .61102 .14701 L .664 .741 .908 r
F
.60448 .14944 m .60115 .14495 L .60771 .14251 L F
.71268 .14925 m .71627 .14233 L .71935 .14682 L .663 .741 .908 r
F
.71268 .14925 m .70959 .14476 L .71627 .14233 L F
.51267 .14925 m .51559 .14234 L .51911 .14684 L F
.51267 .14925 m .50915 .14476 L .51559 .14234 L F
.34595 .17517 m .34715 .18814 L .35009 .20925 L .835 .552 .007 r
F
.62087 .14906 m .62416 .14214 L .62744 .14664 L .663 .741 .908 r
F
.62087 .14906 m .61758 .14458 L .62416 .14214 L F
.72909 .14888 m .73274 .14195 L .73578 .14645 L .664 .741 .908 r
F
.72909 .14888 m .72604 .1444 L .73274 .14195 L F
.52905 .14889 m .53203 .14197 L .53551 .14646 L .663 .741 .908 r
F
.52905 .14889 m .52556 .1444 L .53203 .14197 L F
.63727 .1487 m .64061 .14177 L .64385 .14627 L .664 .741 .908 r
F
.63727 .1487 m .63402 .14421 L .64061 .14177 L F
.44419 .17054 m .43979 .19181 L .44685 .16515 L 0 0 0 r
F
.3792 .20194 m .38182 .19216 L .38559 .19728 L .712 .688 .826 r
F
.3792 .20194 m .37547 .19591 L .38182 .19216 L F
.74551 .14851 m .74921 .14158 L .75222 .14607 L .664 .741 .908 r
F
.74551 .14851 m .74249 .14402 L .74921 .14158 L F
.54543 .14852 m .54846 .14158 L .55191 .14608 L .664 .742 .908 r
F
.54543 .14852 m .54198 .14404 L .54846 .14158 L F
.33299 .18819 m .32738 .20979 L .33424 .19845 L .123 0 .215 r
F
.65367 .14832 m .65707 .14139 L .66028 .14589 L .664 .741 .908 r
F
.65367 .14832 m .65045 .14383 L .65707 .14139 L F
.56182 .14813 m .56491 .14121 L .56832 .1457 L .663 .741 .908 r
F
.56182 .14813 m .5584 .14364 L .56491 .14121 L F
.42778 .17247 m .42922 .2034 L .434 .17405 L .937 .634 .176 r
F
.67008 .14794 m .67353 .14101 L .67671 .14551 L .664 .741 .908 r
F
.67008 .14794 m .6669 .14346 L .67353 .14101 L F
.46677 .1764 m .46329 .16427 L .46995 .14813 L .827 .63 .635 r
F
.46995 .14813 m .47273 .14105 L .47634 .14555 L .667 .738 .903 r
F
.46995 .14813 m .46633 .14355 L .47273 .14105 L F
.46329 .16427 m .46633 .14355 L .46995 .14813 L .819 .656 .681 r
F
.38559 .19728 m .388 .19239 L .39154 .20252 L .451 .613 .918 r
F
.38559 .19728 m .38182 .19216 L .388 .19239 L F
.57822 .14776 m .58136 .14083 L .58473 .14533 L .664 .741 .908 r
F
.57822 .14776 m .57483 .14327 L .58136 .14083 L F
.39135 .16696 m .388 .15283 L .39421 .15247 L .531 .431 .687 r
F
.38502 .17018 m .388 .15283 L .39135 .16696 L .782 .646 .711 r
F
.38502 .17018 m .38143 .16128 L .388 .15283 L F
.388 .19239 m .38502 .17018 L .39135 .16696 L .581 .413 .62 r
F
.38182 .19216 m .38502 .17018 L .388 .19239 L .808 .639 .673 r
F
.39135 .16696 m .39421 .15247 L .39684 .18382 L .531 .431 .687 r
F
.39961 .21305 m .39684 .18382 L .39777 .1869 L .073 .026 .493 r
F
.39906 .19932 m .39777 .1869 L .39978 .19346 L F
.39906 .19932 m .39978 .19346 L .40236 .20194 L F
.39961 .21305 m .39777 .1869 L .40023 .21056 L F
.39684 .18382 m .39864 .1951 L .40236 .20194 L 0 0 .151 r
F
.39864 .1951 m .40187 .17253 L .40291 .16775 L .415 .277 .583 r
F
.40153 .17909 m .40291 .16775 L .40674 .15024 L F
.39864 .1951 m .40291 .16775 L .40153 .17909 L F
.40023 .21056 m .39906 .19932 L .40236 .20194 L .073 .026 .493 r
F
.40236 .20194 m .39864 .1951 L .40674 .15024 L .949 .71 .542 r
F
.40387 .20616 m .39961 .21305 L .40705 .18413 L .99 .853 .49 r
F
.39961 .21305 m .40236 .20194 L .40705 .18413 L .073 .026 .493 r
F
.40674 .15024 m .40187 .17253 L .40723 .1972 L .757 .427 .427 r
F
.39864 .1951 m .39579 .1676 L .40187 .17253 L .415 .277 .583 r
F
.40187 .17253 m .40463 .16137 L .40723 .1972 L 0 0 0 r
F
.40187 .17253 m .39811 .18993 L .40463 .16137 L F
.39797 .18869 m .39799 .18885 L .39864 .1951 L .868 .444 .205 r
F
.39684 .18382 m .39421 .15247 L .39797 .18869 L 0 0 .151 r
F
.39771 .1893 m .39797 .18869 L .39864 .1951 L F
.39684 .18382 m .39797 .18869 L .39771 .1893 L F
.39359 .2069 m .39684 .18382 L .39961 .21305 L .243 .124 .511 r
F
.39811 .18993 m .39686 .19573 L .39813 .19011 L 0 0 0 r
F
.39811 .18993 m .39813 .19011 L .40463 .16137 L F
.39465 .15673 m .39579 .1676 L .39799 .18885 L .868 .444 .205 r
F
.39465 .15673 m .39799 .18885 L .39797 .18869 L F
.39421 .15247 m .39435 .15389 L .39465 .15673 L F
.39435 .15389 m .39579 .1676 L .39465 .15673 L F
.39421 .15247 m .39018 .15316 L .39579 .1676 L F
.3898 .15273 m .39018 .15316 L .39421 .15247 L 0 0 .1 r
F
.39018 .15316 m .39279 .14438 L .39579 .1676 L 0 0 0 r
F
.39018 .15316 m .38507 .17639 L .39057 .15359 L F
.39018 .15316 m .39057 .15359 L .39279 .14438 L F
.388 .15283 m .39018 .15316 L .3898 .15273 L 0 0 .1 r
F
.38182 .19216 m .37829 .18197 L .38502 .17018 L .808 .639 .673 r
F
.37829 .18197 m .38143 .16128 L .38502 .17018 L .796 .635 .682 r
F
.388 .15283 m .38248 .18477 L .39018 .15316 L 0 0 .1 r
F
.38143 .16128 m .38248 .18477 L .388 .15283 L .629 .281 .362 r
F
.6865 .14757 m .69001 .14064 L .69315 .14514 L .663 .741 .908 r
F
.6865 .14757 m .68335 .14308 L .69001 .14064 L F
.48633 .14761 m .48917 .14067 L .49274 .14517 L .665 .742 .908 r
F
.48633 .14761 m .48275 .14312 L .48917 .14067 L F
.59462 .14739 m .59782 .14045 L .60115 .14495 L .664 .741 .908 r
F
.59462 .14739 m .59127 .1429 L .59782 .14045 L F
.70292 .1472 m .70648 .14026 L .70959 .14476 L F
.70292 .1472 m .69981 .1427 L .70648 .14026 L F
.50272 .14721 m .50561 .14026 L .50915 .14476 L .664 .742 .908 r
F
.50272 .14721 m .49917 .14272 L .50561 .14026 L F
.61102 .14701 m .61428 .14007 L .61758 .14458 L .663 .741 .908 r
F
.61102 .14701 m .60771 .14251 L .61428 .14007 L F
.71935 .14682 m .72297 .13989 L .72604 .1444 L F
.71935 .14682 m .71627 .14233 L .72297 .13989 L F
.51911 .14684 m .52206 .1399 L .52556 .1444 L .664 .741 .908 r
F
.51911 .14684 m .51559 .14234 L .52206 .1399 L F
.62744 .14664 m .63075 .1397 L .63402 .14421 L .663 .741 .908 r
F
.62744 .14664 m .62416 .14214 L .63075 .1397 L F
.73578 .14645 m .73946 .13952 L .74249 .14402 L F
.73578 .14645 m .73274 .14195 L .73946 .13952 L F
.53551 .14646 m .53851 .13953 L .54198 .14404 L F
.53551 .14646 m .53203 .14197 L .53851 .13953 L F
.64385 .14627 m .64722 .13933 L .65045 .14383 L .664 .741 .908 r
F
.64385 .14627 m .64061 .14177 L .64722 .13933 L F
.75222 .14607 m .75595 .13913 L .75895 .14364 L F
.75222 .14607 m .74921 .14158 L .75595 .13913 L F
.55191 .14608 m .55497 .13913 L .5584 .14364 L .664 .742 .908 r
F
.55191 .14608 m .54846 .14158 L .55497 .13913 L F
.37829 .18197 m .37474 .17189 L .38143 .16128 L .796 .635 .682 r
F
.38143 .16128 m .37661 .17729 L .38248 .18477 L .629 .281 .362 r
F
.37474 .17189 m .37661 .17729 L .38143 .16128 L .709 .172 0 r
F
.66028 .14589 m .6637 .13895 L .6669 .14346 L .663 .741 .908 r
F
.66028 .14589 m .65707 .14139 L .6637 .13895 L F
.56832 .1457 m .57143 .13876 L .57483 .14327 L .664 .741 .908 r
F
.56832 .1457 m .56491 .14121 L .57143 .13876 L F
.67671 .14551 m .68019 .13857 L .68335 .14308 L .663 .741 .908 r
F
.67671 .14551 m .67353 .14101 L .68019 .13857 L F
.35542 .18838 m .35009 .20925 L .35854 .16874 L .861 .785 .286 r
F
.35854 .16874 m .36034 .17297 L .36447 .1726 L .267 0 0 r
F
.35009 .20925 m .35411 .17424 L .35854 .16874 L .728 .521 .612 r
F
.35854 .16874 m .35411 .17424 L .36034 .17297 L .267 0 0 r
F
.47634 .14555 m .47915 .13861 L .48275 .14312 L .663 .741 .908 r
F
.47634 .14555 m .47273 .14105 L .47915 .13861 L F
.39359 .2069 m .39135 .16696 L .39684 .18382 L .243 .124 .511 r
F
.388 .19239 m .39135 .16696 L .39359 .2069 L .581 .413 .62 r
F
.58473 .14533 m .5879 .13838 L .59127 .1429 L .663 .741 .908 r
F
.58473 .14533 m .58136 .14083 L .5879 .13838 L F
.37547 .19591 m .37829 .18197 L .38182 .19216 L .313 .231 .6 r
F
.30002 .26302 m .29588 .26052 L .30391 .2334 L .956 .761 .601 r
F
.29588 .26052 m .29901 .24145 L .30391 .2334 L .326 .21 .565 r
F
.69315 .14514 m .69668 .13819 L .69981 .1427 L .664 .741 .908 r
F
.69315 .14514 m .69001 .14064 L .69668 .13819 L F
.49274 .14517 m .4956 .13821 L .49917 .14272 L .664 .742 .908 r
F
.49274 .14517 m .48917 .14067 L .4956 .13821 L F
.60115 .14495 m .60438 .138 L .60771 .14251 L .664 .741 .908 r
F
.60115 .14495 m .59782 .14045 L .60438 .138 L F
.70959 .14476 m .71318 .13782 L .71627 .14233 L .663 .741 .908 r
F
.70959 .14476 m .70648 .14026 L .71318 .13782 L F
.50915 .14476 m .51206 .13783 L .51559 .14234 L F
.50915 .14476 m .50561 .14026 L .51206 .13783 L F
.61758 .14458 m .62086 .13763 L .62416 .14214 L F
.61758 .14458 m .61428 .14007 L .62086 .13763 L F
.72604 .1444 m .72968 .13744 L .73274 .14195 L .664 .741 .908 r
F
.72604 .1444 m .72297 .13989 L .72968 .13744 L F
.52556 .1444 m .52853 .13746 L .53203 .14197 L .663 .741 .908 r
F
.52556 .1444 m .52206 .1399 L .52853 .13746 L F
.63402 .14421 m .63735 .13726 L .64061 .14177 L F
.63402 .14421 m .63075 .1397 L .63735 .13726 L F
.74249 .14402 m .74619 .13706 L .74921 .14158 L .664 .741 .908 r
F
.74249 .14402 m .73946 .13952 L .74619 .13706 L F
.54198 .14404 m .54501 .13707 L .54846 .14158 L .665 .742 .908 r
F
.54198 .14404 m .53851 .13953 L .54501 .13707 L F
.65045 .14383 m .65385 .13687 L .65707 .14139 L .664 .741 .908 r
F
.65045 .14383 m .64722 .13933 L .65385 .13687 L F
.41361 .17629 m .41062 .15158 L .41519 .19781 L .796 .57 .005 r
F
.41062 .15158 m .41064 .21289 L .41519 .19781 L .957 .635 .367 r
F
.41062 .15158 m .40674 .15024 L .41064 .21289 L F
.5584 .14364 m .56148 .13669 L .56491 .14121 L .663 .741 .908 r
F
.5584 .14364 m .55497 .13913 L .56148 .13669 L F
.35083 .23393 m .34698 .22825 L .35542 .18838 L .947 .718 .559 r
F
.6669 .14346 m .67035 .1365 L .67353 .14101 L .664 .741 .908 r
F
.6669 .14346 m .6637 .13895 L .67035 .1365 L F
.46329 .16427 m .45975 .15495 L .46633 .14355 L .819 .656 .681 r
F
.46633 .14355 m .46911 .13653 L .47273 .14105 L .665 .74 .906 r
F
.46633 .14355 m .4627 .13901 L .46911 .13653 L F
.45975 .15495 m .4627 .13901 L .46633 .14355 L .805 .682 .729 r
F
.57483 .14327 m .57797 .13631 L .58136 .14083 L .664 .741 .908 r
F
.57483 .14327 m .57143 .13876 L .57797 .13631 L F
.68335 .14308 m .68685 .13612 L .69001 .14064 L .663 .741 .908 r
F
.68335 .14308 m .68019 .13857 L .68685 .13612 L F
.48275 .14312 m .48558 .13615 L .48917 .14067 L .665 .742 .908 r
F
.48275 .14312 m .47915 .13861 L .48558 .13615 L F
.59127 .1429 m .59446 .13593 L .59782 .14045 L .664 .741 .908 r
F
.59127 .1429 m .5879 .13838 L .59446 .13593 L F
.434 .17405 m .43518 .21762 L .43979 .19181 L .651 .338 .43 r
F
.434 .17405 m .42922 .2034 L .43518 .21762 L F
.69981 .1427 m .70337 .13574 L .70648 .14026 L .664 .741 .908 r
F
.69981 .1427 m .69668 .13819 L .70337 .13574 L F
.49917 .14272 m .50205 .13574 L .50561 .14026 L .664 .742 .908 r
F
.49917 .14272 m .4956 .13821 L .50205 .13574 L F
.37474 .17189 m .37073 .17087 L .37661 .17729 L .709 .172 0 r
F
.60771 .14251 m .61096 .13555 L .61428 .14007 L .663 .741 .908 r
F
.60771 .14251 m .60438 .138 L .61096 .13555 L F
.71627 .14233 m .71988 .13537 L .72297 .13989 L F
.71627 .14233 m .71318 .13782 L .71988 .13537 L F
.51559 .14234 m .51854 .13537 L .52206 .1399 L .664 .741 .908 r
F
.51559 .14234 m .51206 .13783 L .51854 .13537 L F
.62416 .14214 m .62746 .13518 L .63075 .1397 L .663 .741 .908 r
F
.62416 .14214 m .62086 .13763 L .62746 .13518 L F
.73274 .14195 m .73641 .13499 L .73946 .13952 L F
.73274 .14195 m .72968 .13744 L .73641 .13499 L F
.53203 .14197 m .53502 .13501 L .53851 .13953 L F
.53203 .14197 m .52853 .13746 L .53502 .13501 L F
.29588 .26052 m .29358 .23338 L .29901 .24145 L .326 .21 .565 r
F
.28857 .2771 m .29358 .23338 L .29588 .26052 L .673 .46 .589 r
F
.28857 .2771 m .28655 .24659 L .29358 .23338 L F
.29358 .23338 m .29567 .22817 L .29901 .24145 L 0 0 .324 r
F
.64061 .14177 m .64397 .1348 L .64722 .13933 L .664 .741 .908 r
F
.64061 .14177 m .63735 .13726 L .64397 .1348 L F
.74921 .14158 m .75294 .1346 L .75595 .13913 L F
.74921 .14158 m .74619 .13706 L .75294 .1346 L F
.54846 .14158 m .55152 .1346 L .55497 .13913 L F
.54846 .14158 m .54501 .13707 L .55152 .1346 L F
.65707 .14139 m .66049 .13442 L .6637 .13895 L .663 .741 .908 r
F
.65707 .14139 m .65385 .13687 L .66049 .13442 L F
.56491 .14121 m .56802 .13423 L .57143 .13876 L .664 .741 .908 r
F
.56491 .14121 m .56148 .13669 L .56802 .13423 L F
.67353 .14101 m .67701 .13404 L .68019 .13857 L .663 .741 .908 r
F
.67353 .14101 m .67035 .1365 L .67701 .13404 L F
.47273 .14105 m .47553 .13409 L .47915 .13861 L F
.47273 .14105 m .46911 .13653 L .47553 .13409 L F
.58136 .14083 m .58452 .13385 L .5879 .13838 L F
.58136 .14083 m .57797 .13631 L .58452 .13385 L F
.44685 .16515 m .4424 .18846 L .44708 .25618 L .875 .555 .442 r
F
.43979 .19181 m .4424 .18846 L .44685 .16515 L 0 0 .057 r
F
.46028 .23652 m .46112 .32593 L .46514 .31854 L .952 .688 .235 r
F
.4573 .32165 m .46329 .16427 L .46677 .1764 L .957 .682 .474 r
F
.4573 .32165 m .4537 .30717 L .46329 .16427 L F
.69001 .14064 m .69354 .13366 L .69668 .13819 L .664 .741 .908 r
F
.69001 .14064 m .68685 .13612 L .69354 .13366 L F
.48917 .14067 m .49202 .13367 L .4956 .13821 L .665 .742 .908 r
F
.48917 .14067 m .48558 .13615 L .49202 .13367 L F
.59782 .14045 m .60104 .13347 L .60438 .138 L .664 .741 .908 r
F
.59782 .14045 m .59446 .13593 L .60104 .13347 L F
.70648 .14026 m .71007 .13328 L .71318 .13782 L .663 .741 .908 r
F
.70648 .14026 m .70337 .13574 L .71007 .13328 L F
.50561 .14026 m .50852 .13329 L .51206 .13783 L F
.50561 .14026 m .50205 .13574 L .50852 .13329 L F
.39154 .20252 m .39359 .2069 L .39709 .21856 L 0 0 .296 r
F
.39154 .20252 m .388 .19239 L .39359 .2069 L F
.61428 .14007 m .61755 .13309 L .62086 .13763 L .663 .741 .908 r
F
.61428 .14007 m .61096 .13555 L .61755 .13309 L F
.72297 .13989 m .72661 .1329 L .72968 .13744 L .664 .741 .908 r
F
.72297 .13989 m .71988 .13537 L .72661 .1329 L F
.52206 .1399 m .52502 .13292 L .52853 .13746 L .663 .741 .908 r
F
.52206 .1399 m .51854 .13537 L .52502 .13292 L F
.46464 .26134 m .467 .2776 L .4709 .26919 L .692 .297 .294 r
F
.467 .2776 m .46345 .26611 L .46933 .2989 L .898 .575 .084 r
F
.46345 .26611 m .46514 .31854 L .46933 .2989 L .914 .656 .159 r
F
.46112 .32593 m .46677 .1764 L .47019 .19204 L .972 .701 .458 r
F
.46112 .32593 m .4573 .32165 L .46677 .1764 L F
.63075 .1397 m .63408 .13272 L .63735 .13726 L .663 .741 .908 r
F
.63075 .1397 m .62746 .13518 L .63408 .13272 L F
.4537 .30717 m .45031 .28437 L .45975 .15495 L .94 .664 .488 r
F
.45975 .15495 m .45616 .14739 L .4627 .13901 L .805 .682 .729 r
F
.73946 .13952 m .74315 .13252 L .74619 .13706 L .664 .741 .908 r
F
.73946 .13952 m .73641 .13499 L .74315 .13252 L F
.53851 .13953 m .54153 .13253 L .54501 .13707 L .665 .742 .908 r
F
.53851 .13953 m .53502 .13501 L .54153 .13253 L F
.29736 .27566 m .29206 .28865 L .30002 .26302 L .884 .85 .393 r
F
.64722 .13933 m .65061 .13233 L .65385 .13687 L .664 .741 .908 r
F
.64722 .13933 m .64397 .1348 L .65061 .13233 L F
.55497 .13913 m .55805 .13215 L .56148 .13669 L .663 .741 .908 r
F
.55497 .13913 m .55152 .1346 L .55805 .13215 L F
.6637 .13895 m .66714 .13196 L .67035 .1365 L .664 .741 .908 r
F
.6637 .13895 m .66049 .13442 L .66714 .13196 L F
.4627 .13901 m .46547 .13199 L .46911 .13653 L .665 .741 .907 r
F
.4627 .13901 m .45905 .13447 L .46547 .13199 L F
.45616 .14739 m .45905 .13447 L .4627 .13901 L .776 .693 .772 r
F
.57143 .13876 m .57457 .13177 L .57797 .13631 L .664 .741 .908 r
F
.57143 .13876 m .56802 .13423 L .57457 .13177 L F
.36447 .1726 m .36613 .18047 L .37073 .17087 L .761 .261 .028 r
F
.68019 .13857 m .68369 .13158 L .68685 .13612 L .663 .741 .908 r
F
.68019 .13857 m .67701 .13404 L .68369 .13158 L F
.47915 .13861 m .48197 .1316 L .48558 .13615 L .665 .742 .908 r
F
.47915 .13861 m .47553 .13409 L .48197 .1316 L F
.5879 .13838 m .59109 .13139 L .59446 .13593 L .664 .741 .908 r
F
.5879 .13838 m .58452 .13385 L .59109 .13139 L F
.69668 .13819 m .70023 .1312 L .70337 .13574 L F
.69668 .13819 m .69354 .13366 L .70023 .1312 L F
.4956 .13821 m .49848 .1312 L .50205 .13574 L .664 .742 .908 r
F
.4956 .13821 m .49202 .13367 L .49848 .1312 L F
.60438 .138 m .60763 .13101 L .61096 .13555 L .663 .741 .908 r
F
.60438 .138 m .60104 .13347 L .60763 .13101 L F
.71318 .13782 m .71679 .13082 L .71988 .13537 L F
.71318 .13782 m .71007 .13328 L .71679 .13082 L F
.51206 .13783 m .515 .13083 L .51854 .13537 L .664 .741 .908 r
F
.51206 .13783 m .50852 .13329 L .515 .13083 L F
.62086 .13763 m .62416 .13063 L .62746 .13518 L .663 .741 .908 r
F
.62086 .13763 m .61755 .13309 L .62416 .13063 L F
.72968 .13744 m .73335 .13044 L .73641 .13499 L F
.72968 .13744 m .72661 .1329 L .73335 .13044 L F
.52853 .13746 m .53152 .13046 L .53502 .13501 L F
.52853 .13746 m .52502 .13292 L .53152 .13046 L F
.63735 .13726 m .64071 .13025 L .64397 .1348 L .664 .741 .908 r
F
.63735 .13726 m .63408 .13272 L .64071 .13025 L F
.45031 .28437 m .44708 .25618 L .45616 .14739 L .921 .646 .503 r
F
.45616 .14739 m .45255 .14068 L .45905 .13447 L .776 .693 .772 r
F
.74619 .13706 m .74991 .13006 L .75294 .1346 L .664 .741 .908 r
F
.74619 .13706 m .74315 .13252 L .74991 .13006 L F
.54501 .13707 m .54805 .13006 L .55152 .1346 L F
.54501 .13707 m .54153 .13253 L .54805 .13006 L F
.65385 .13687 m .65726 .12987 L .66049 .13442 L .663 .741 .908 r
F
.65385 .13687 m .65061 .13233 L .65726 .12987 L F
.28031 .3053 m .28655 .24659 L .28857 .2771 L .996 .794 .434 r
F
.28031 .3053 m .27398 .32897 L .28655 .24659 L F
.56148 .13669 m .56459 .12968 L .56802 .13423 L .663 .741 .908 r
F
.56148 .13669 m .55805 .13215 L .56459 .12968 L F
.4709 .26919 m .467 .2776 L .47361 .26933 L 0 0 0 r
F
.467 .2776 m .46933 .2989 L .47361 .26933 L .898 .575 .084 r
F
.46514 .31854 m .47019 .19204 L .47356 .21124 L .987 .725 .436 r
F
.46514 .31854 m .46112 .32593 L .47019 .19204 L F
.29206 .28865 m .29588 .26052 L .30002 .26302 L .83 .637 .642 r
F
.67035 .1365 m .67382 .12949 L .67701 .13404 L .663 .741 .908 r
F
.67035 .1365 m .66714 .13196 L .67382 .12949 L F
.46911 .13653 m .4719 .12954 L .47553 .13409 L .662 .741 .908 r
F
.46911 .13653 m .46547 .13199 L .4719 .12954 L F
.57797 .13631 m .58113 .1293 L .58452 .13385 L .663 .741 .908 r
F
.57797 .13631 m .57457 .13177 L .58113 .1293 L F
.68685 .13612 m .69038 .12911 L .69354 .13366 L .664 .741 .908 r
F
.68685 .13612 m .68369 .13158 L .69038 .12911 L F
.48558 .13615 m .48843 .12912 L .49202 .13367 L .664 .742 .908 r
F
.48558 .13615 m .48197 .1316 L .48843 .12912 L F
.59446 .13593 m .59768 .12892 L .60104 .13347 L .664 .741 .908 r
F
.59446 .13593 m .59109 .13139 L .59768 .12892 L F
.37073 .17087 m .37182 .1911 L .37661 .17729 L .724 .343 .328 r
F
.37073 .17087 m .36613 .18047 L .37182 .1911 L F
.70337 .13574 m .70695 .12873 L .71007 .13328 L .663 .741 .908 r
F
.70337 .13574 m .70023 .1312 L .70695 .12873 L F
.50205 .13574 m .50496 .12874 L .50852 .13329 L F
.50205 .13574 m .49848 .1312 L .50496 .12874 L F
.38248 .18477 m .38507 .17639 L .39018 .15316 L 0 0 0 r
F
.29901 .24145 m .29567 .22817 L .30235 .21953 L .73 .566 .669 r
F
.61096 .13555 m .61423 .12854 L .61755 .13309 L .664 .741 .908 r
F
.61096 .13555 m .60763 .13101 L .61423 .12854 L F
.71988 .13537 m .72352 .12835 L .72661 .1329 L F
.71988 .13537 m .71679 .13082 L .72352 .12835 L F
.51854 .13537 m .5215 .12837 L .52502 .13292 L .663 .741 .908 r
F
.51854 .13537 m .515 .13083 L .5215 .12837 L F
.62746 .13518 m .63079 .12816 L .63408 .13272 L F
.62746 .13518 m .62416 .13063 L .63079 .12816 L F
.73641 .13499 m .74011 .12797 L .74315 .13252 L .664 .741 .908 r
F
.73641 .13499 m .73335 .13044 L .74011 .12797 L F
.53502 .13501 m .53804 .12797 L .54153 .13253 L .665 .742 .908 r
F
.53502 .13501 m .53152 .13046 L .53804 .12797 L F
.64397 .1348 m .64736 .12778 L .65061 .13233 L .664 .741 .908 r
F
.64397 .1348 m .64071 .13025 L .64736 .12778 L F
.55152 .1346 m .55459 .12759 L .55805 .13215 L .663 .741 .908 r
F
.55152 .1346 m .54805 .13006 L .55459 .12759 L F
.66049 .13442 m .66393 .1274 L .66714 .13196 L .664 .741 .908 r
F
.66049 .13442 m .65726 .12987 L .66393 .1274 L F
.45905 .13447 m .46181 .12743 L .46547 .13199 L .665 .742 .907 r
F
.45905 .13447 m .45538 .12992 L .46181 .12743 L F
.45255 .14068 m .45538 .12992 L .45905 .13447 L .737 .696 .811 r
F
.41647 .20576 m .41361 .17629 L .42011 .17026 L .601 .408 .592 r
F
.42011 .17026 m .41519 .19781 L .42077 .22079 L .721 .401 .436 r
F
.41361 .17629 m .41519 .19781 L .42011 .17026 L .796 .57 .005 r
F
.56802 .13423 m .57115 .12721 L .57457 .13177 L .664 .741 .908 r
F
.56802 .13423 m .56459 .12968 L .57115 .12721 L F
.44701 .25511 m .44393 .22669 L .44708 .25618 L .587 .28 .416 r
F
.4424 .18846 m .44393 .22669 L .44701 .25511 L F
.4424 .18846 m .43767 .21874 L .44393 .22669 L F
.44393 .22669 m .44076 .19961 L .44089 .19858 L .886 .62 .531 r
F
.43979 .19181 m .43518 .21762 L .4424 .18846 L 0 0 .057 r
F
.43518 .21762 m .43767 .21874 L .4424 .18846 L 0 0 .083 r
F
.44393 .22669 m .44089 .19858 L .44891 .13446 L .886 .62 .531 r
F
.44708 .25618 m .44393 .22669 L .45255 .14068 L .901 .63 .517 r
F
.45255 .14068 m .44891 .13446 L .45538 .12992 L .737 .696 .811 r
F
.44393 .22669 m .44891 .13446 L .45255 .14068 L .886 .62 .531 r
F
.35009 .20925 m .34715 .18814 L .35411 .17424 L .728 .521 .612 r
F
.67701 .13404 m .68051 .12702 L .68369 .13158 L .663 .741 .908 r
F
.67701 .13404 m .67382 .12949 L .68051 .12702 L F
.47553 .13409 m .47835 .12704 L .48197 .1316 L .665 .742 .907 r
F
.47553 .13409 m .4719 .12954 L .47835 .12704 L F
.58452 .13385 m .58771 .12683 L .59109 .13139 L .664 .741 .908 r
F
.58452 .13385 m .58113 .1293 L .58771 .12683 L F
.69354 .13366 m .69709 .12663 L .70023 .1312 L F
.69354 .13366 m .69038 .12911 L .69709 .12663 L F
.49202 .13367 m .4949 .12664 L .49848 .1312 L .664 .742 .908 r
F
.49202 .13367 m .48843 .12912 L .4949 .12664 L F
.60104 .13347 m .60428 .12644 L .60763 .13101 L .663 .741 .908 r
F
.60104 .13347 m .59768 .12892 L .60428 .12644 L F
.71007 .13328 m .71368 .12626 L .71679 .13082 L F
.71007 .13328 m .70695 .12873 L .71368 .12626 L F
.50852 .13329 m .51145 .12626 L .515 .13083 L .664 .741 .908 r
F
.50852 .13329 m .50496 .12874 L .51145 .12626 L F
.61755 .13309 m .62085 .12607 L .62416 .13063 L .663 .741 .908 r
F
.61755 .13309 m .61423 .12854 L .62085 .12607 L F
.72661 .1329 m .73028 .12588 L .73335 .13044 L F
.72661 .1329 m .72352 .12835 L .73028 .12588 L F
.52502 .13292 m .52801 .1259 L .53152 .13046 L F
.52502 .13292 m .5215 .12837 L .52801 .1259 L F
.63408 .13272 m .63743 .12569 L .64071 .13025 L .664 .741 .908 r
F
.63408 .13272 m .63079 .12816 L .63743 .12569 L F
.74315 .13252 m .74688 .12549 L .74991 .13006 L F
.74315 .13252 m .74011 .12797 L .74688 .12549 L F
.54153 .13253 m .54457 .12549 L .54805 .13006 L F
.54153 .13253 m .53804 .12797 L .54457 .12549 L F
.65061 .13233 m .65402 .1253 L .65726 .12987 L .663 .741 .908 r
F
.65061 .13233 m .64736 .12778 L .65402 .1253 L F
.55805 .13215 m .56115 .12512 L .56459 .12968 L F
.55805 .13215 m .55459 .12759 L .56115 .12512 L F
.66714 .13196 m .67061 .12492 L .67382 .12949 L F
.66714 .13196 m .66393 .1274 L .67061 .12492 L F
.46547 .13199 m .46825 .12498 L .4719 .12954 L .662 .741 .908 r
F
.46547 .13199 m .46181 .12743 L .46825 .12498 L F
.57457 .13177 m .57772 .12473 L .58113 .1293 L .664 .741 .908 r
F
.57457 .13177 m .57115 .12721 L .57772 .12473 L F
.68369 .13158 m .68721 .12454 L .69038 .12911 L F
.68369 .13158 m .68051 .12702 L .68721 .12454 L F
.48197 .1316 m .48482 .12455 L .48843 .12912 L .664 .742 .908 r
F
.48197 .1316 m .47835 .12704 L .48482 .12455 L F
.59109 .13139 m .59431 .12434 L .59768 .12892 L .664 .741 .908 r
F
.59109 .13139 m .58771 .12683 L .59431 .12434 L F
.70023 .1312 m .70382 .12416 L .70695 .12873 L .663 .741 .908 r
F
.70023 .1312 m .69709 .12663 L .70382 .12416 L F
.49848 .1312 m .50138 .12417 L .50496 .12874 L F
.49848 .1312 m .4949 .12664 L .50138 .12417 L F
.60763 .13101 m .61089 .12396 L .61423 .12854 L .664 .741 .908 r
F
.60763 .13101 m .60428 .12644 L .61089 .12396 L F
.46933 .2989 m .47356 .21124 L .4769 .23366 L .992 .756 .389 r
F
.46933 .2989 m .46514 .31854 L .47356 .21124 L F
.44891 .13446 m .4517 .12535 L .45538 .12992 L .702 .703 .848 r
F
.44891 .13446 m .44525 .12877 L .4517 .12535 L F
.44076 .19961 m .44525 .12877 L .44891 .13446 L .874 .617 .547 r
F
.71679 .13082 m .72043 .12377 L .72352 .12835 L .664 .741 .908 r
F
.71679 .13082 m .71368 .12626 L .72043 .12377 L F
.515 .13083 m .51796 .1238 L .5215 .12837 L .663 .741 .908 r
F
.515 .13083 m .51145 .12626 L .51796 .1238 L F
.29206 .28865 m .28857 .2771 L .29588 .26052 L .83 .637 .642 r
F
.62416 .13063 m .62749 .12359 L .63079 .12816 L .663 .741 .908 r
F
.62416 .13063 m .62085 .12607 L .62749 .12359 L F
.73335 .13044 m .73704 .12339 L .74011 .12797 L .664 .741 .908 r
F
.73335 .13044 m .73028 .12588 L .73704 .12339 L F
.53152 .13046 m .53454 .1234 L .53804 .12797 L .665 .742 .908 r
F
.53152 .13046 m .52801 .1259 L .53454 .1234 L F
.64071 .13025 m .64409 .1232 L .64736 .12778 L .664 .741 .908 r
F
.64071 .13025 m .63743 .12569 L .64409 .1232 L F
.54805 .13006 m .55112 .12301 L .55459 .12759 L .663 .741 .908 r
F
.54805 .13006 m .54457 .12549 L .55112 .12301 L F
.39579 .1676 m .39279 .14438 L .39686 .19573 L .878 .623 .1 r
F
.65726 .12987 m .6607 .12282 L .66393 .1274 L .664 .741 .908 r
F
.65726 .12987 m .65402 .1253 L .6607 .12282 L F
.45538 .12992 m .45814 .12285 L .46181 .12743 L .665 .741 .907 r
F
.45538 .12992 m .4517 .12535 L .45814 .12285 L F
.56459 .12968 m .56771 .12263 L .57115 .12721 L .664 .741 .908 r
F
.56459 .12968 m .56115 .12512 L .56771 .12263 L F
.67382 .12949 m .67731 .12244 L .68051 .12702 L .663 .741 .908 r
F
.67382 .12949 m .67061 .12492 L .67731 .12244 L F
.4719 .12954 m .47471 .12246 L .47835 .12704 L .666 .742 .907 r
F
.4719 .12954 m .46825 .12498 L .47471 .12246 L F
.39709 .21856 m .39961 .21305 L .40387 .20616 L .158 .223 .681 r
F
.58113 .1293 m .58431 .12225 L .58771 .12683 L .664 .741 .908 r
F
.58113 .1293 m .57772 .12473 L .58431 .12225 L F
.69038 .12911 m .69393 .12205 L .69709 .12663 L F
.69038 .12911 m .68721 .12454 L .69393 .12205 L F
.48843 .12912 m .4913 .12206 L .4949 .12664 L .664 .742 .908 r
F
.48843 .12912 m .48482 .12455 L .4913 .12206 L F
.59768 .12892 m .60092 .12186 L .60428 .12644 L .663 .741 .908 r
F
.59768 .12892 m .59431 .12434 L .60092 .12186 L F
.70695 .12873 m .71056 .12167 L .71368 .12626 L F
.70695 .12873 m .70382 .12416 L .71056 .12167 L F
.50496 .12874 m .50788 .12168 L .51145 .12626 L F
.50496 .12874 m .50138 .12417 L .50788 .12168 L F
.61423 .12854 m .61753 .12148 L .62085 .12607 L F
.61423 .12854 m .61089 .12396 L .61753 .12148 L F
.72352 .12835 m .72719 .12129 L .73028 .12588 L F
.72352 .12835 m .72043 .12377 L .72719 .12129 L F
.5215 .12837 m .52448 .12131 L .52801 .1259 L .664 .741 .908 r
F
.5215 .12837 m .51796 .1238 L .52448 .12131 L F
.63079 .12816 m .63414 .1211 L .63743 .12569 L F
.63079 .12816 m .62749 .12359 L .63414 .1211 L F
.74011 .12797 m .74383 .1209 L .74688 .12549 L F
.74011 .12797 m .73704 .12339 L .74383 .1209 L F
.53804 .12797 m .54108 .1209 L .54457 .12549 L F
.53804 .12797 m .53454 .1234 L .54108 .1209 L F
.64736 .12778 m .65076 .12072 L .65402 .1253 L .663 .741 .908 r
F
.64736 .12778 m .64409 .1232 L .65076 .12072 L F
.55459 .12759 m .55769 .12053 L .56115 .12512 L F
.55459 .12759 m .55112 .12301 L .55769 .12053 L F
.66393 .1274 m .66739 .12033 L .67061 .12492 L F
.66393 .1274 m .6607 .12282 L .66739 .12033 L F
.46181 .12743 m .46459 .12039 L .46825 .12498 L .661 .74 .908 r
F
.46181 .12743 m .45814 .12285 L .46459 .12039 L F
.57115 .12721 m .5743 .12014 L .57772 .12473 L .664 .741 .908 r
F
.57115 .12721 m .56771 .12263 L .5743 .12014 L F
.37661 .17729 m .37705 .21241 L .38248 .18477 L .79 .441 .397 r
F
.37661 .17729 m .37182 .1911 L .37705 .21241 L F
.44076 .19961 m .43751 .17673 L .44525 .12877 L .874 .617 .547 r
F
.44525 .12877 m .448 .12075 L .4517 .12535 L .682 .72 .878 r
F
.44525 .12877 m .44155 .12363 L .448 .12075 L F
.43751 .17673 m .44155 .12363 L .44525 .12877 L .863 .619 .568 r
F
.68051 .12702 m .68403 .11995 L .68721 .12454 L .664 .741 .908 r
F
.68051 .12702 m .67731 .12244 L .68403 .11995 L F
.47835 .12704 m .48119 .11996 L .48482 .12455 L F
.47835 .12704 m .47471 .12246 L .48119 .11996 L F
.58771 .12683 m .59092 .11975 L .59431 .12434 L F
.58771 .12683 m .58431 .12225 L .59092 .11975 L F
.69709 .12663 m .70067 .11956 L .70382 .12416 L .663 .741 .908 r
F
.69709 .12663 m .69393 .12205 L .70067 .11956 L F
.4949 .12664 m .49779 .11957 L .50138 .12417 L F
.4949 .12664 m .4913 .12206 L .49779 .11957 L F
.60428 .12644 m .60754 .11937 L .61089 .12396 L .664 .741 .908 r
F
.60428 .12644 m .60092 .12186 L .60754 .11937 L F
.71368 .12626 m .71731 .11918 L .72043 .12377 L F
.71368 .12626 m .71056 .12167 L .71731 .11918 L F
.51145 .12626 m .5144 .1192 L .51796 .1238 L .663 .741 .908 r
F
.51145 .12626 m .50788 .12168 L .5144 .1192 L F
.62085 .12607 m .62417 .11899 L .62749 .12359 L F
.62085 .12607 m .61753 .12148 L .62417 .11899 L F
.73028 .12588 m .73397 .11879 L .73704 .12339 L .664 .741 .908 r
F
.73028 .12588 m .72719 .12129 L .73397 .11879 L F
.52801 .1259 m .53102 .1188 L .53454 .1234 L .665 .742 .908 r
F
.52801 .1259 m .52448 .12131 L .53102 .1188 L F
.63743 .12569 m .64081 .1186 L .64409 .1232 L .664 .741 .908 r
F
.63743 .12569 m .63414 .1211 L .64081 .1186 L F
.54457 .12549 m .54764 .11842 L .55112 .12301 L .663 .741 .908 r
F
.54457 .12549 m .54108 .1209 L .54764 .11842 L F
.39709 .21856 m .39359 .2069 L .39961 .21305 L .158 .223 .681 r
F
.65402 .1253 m .65745 .11822 L .6607 .12282 L .664 .741 .908 r
F
.65402 .1253 m .65076 .12072 L .65745 .11822 L F
.4517 .12535 m .45445 .11824 L .45814 .12285 L .665 .741 .907 r
F
.4517 .12535 m .448 .12075 L .45445 .11824 L F
.56115 .12512 m .56427 .11804 L .56771 .12263 L .663 .741 .908 r
F
.56115 .12512 m .55769 .12053 L .56427 .11804 L F
.67061 .12492 m .6741 .11784 L .67731 .12244 L F
.67061 .12492 m .66739 .12033 L .6741 .11784 L F
.46825 .12498 m .47106 .11786 L .47471 .12246 L .666 .742 .907 r
F
.46825 .12498 m .46459 .12039 L .47106 .11786 L F
.57772 .12473 m .5809 .11765 L .58431 .12225 L .664 .741 .908 r
F
.57772 .12473 m .5743 .12014 L .5809 .11765 L F
.68721 .12454 m .69076 .11745 L .69393 .12205 L F
.68721 .12454 m .68403 .11995 L .69076 .11745 L F
.48482 .12455 m .48768 .11745 L .4913 .12206 L .664 .742 .908 r
F
.48482 .12455 m .48119 .11996 L .48768 .11745 L F
.59431 .12434 m .59754 .11726 L .60092 .12186 L .663 .741 .908 r
F
.59431 .12434 m .59092 .11975 L .59754 .11726 L F
.70382 .12416 m .70742 .11707 L .71056 .12167 L F
.70382 .12416 m .70067 .11956 L .70742 .11707 L F
.50138 .12417 m .5043 .11708 L .50788 .12168 L F
.50138 .12417 m .49779 .11957 L .5043 .11708 L F
.61089 .12396 m .61419 .11688 L .61753 .12148 L F
.61089 .12396 m .60754 .11937 L .61419 .11688 L F
.72043 .12377 m .72409 .11669 L .72719 .12129 L F
.72043 .12377 m .71731 .11918 L .72409 .11669 L F
.51796 .1238 m .52093 .1167 L .52448 .12131 L .664 .741 .908 r
F
.51796 .1238 m .5144 .1192 L .52093 .1167 L F
.62749 .12359 m .63084 .11649 L .63414 .1211 L .663 .741 .908 r
F
.62749 .12359 m .62417 .11899 L .63084 .11649 L F
.41501 .15948 m .41195 .13566 L .4181 .1402 L .408 .285 .599 r
F
.40723 .1972 m .41195 .13566 L .41501 .15948 L .735 .496 .567 r
F
.40723 .1972 m .40463 .16137 L .41195 .13566 L F
.73704 .12339 m .74076 .1163 L .74383 .1209 L .664 .741 .908 r
F
.73704 .12339 m .73397 .11879 L .74076 .1163 L F
.53454 .1234 m .53757 .1163 L .54108 .1209 L F
.53454 .1234 m .53102 .1188 L .53757 .1163 L F
.64409 .1232 m .6475 .11611 L .65076 .12072 L .663 .741 .908 r
F
.64409 .1232 m .64081 .1186 L .6475 .11611 L F
.47361 .26933 m .4769 .23366 L .48023 .25883 L .852 .73 .208 r
F
.47361 .26933 m .46933 .2989 L .4769 .23366 L F
.55112 .12301 m .55421 .11592 L .55769 .12053 L .663 .741 .908 r
F
.55112 .12301 m .54764 .11842 L .55421 .11592 L F
.43751 .17673 m .43416 .15806 L .44155 .12363 L .863 .619 .568 r
F
.44155 .12363 m .44428 .11614 L .448 .12075 L .674 .735 .896 r
F
.44155 .12363 m .43783 .11884 L .44428 .11614 L F
.43416 .15806 m .43783 .11884 L .44155 .12363 L .849 .624 .597 r
F
.6607 .12282 m .66416 .11572 L .66739 .12033 L .663 .741 .908 r
F
.6607 .12282 m .65745 .11822 L .66416 .11572 L F
.45814 .12285 m .46091 .11578 L .46459 .12039 L .661 .74 .909 r
F
.45814 .12285 m .45445 .11824 L .46091 .11578 L F
.56771 .12263 m .57086 .11553 L .5743 .12014 L .664 .741 .908 r
F
.56771 .12263 m .56427 .11804 L .57086 .11553 L F
.67731 .12244 m .68083 .11534 L .68403 .11995 L F
.67731 .12244 m .6741 .11784 L .68083 .11534 L F
.47471 .12246 m .47754 .11535 L .48119 .11996 L F
.47471 .12246 m .47106 .11786 L .47754 .11535 L F
.58431 .12225 m .58752 .11514 L .59092 .11975 L F
.58431 .12225 m .5809 .11765 L .58752 .11514 L F
.69393 .12205 m .69751 .11495 L .70067 .11956 L .663 .741 .908 r
F
.69393 .12205 m .69076 .11745 L .69751 .11495 L F
.4913 .12206 m .49418 .11496 L .49779 .11957 L F
.4913 .12206 m .48768 .11745 L .49418 .11496 L F
.60092 .12186 m .60418 .11476 L .60754 .11937 L .664 .741 .908 r
F
.60092 .12186 m .59754 .11726 L .60418 .11476 L F
.71056 .12167 m .71419 .11457 L .71731 .11918 L F
.71056 .12167 m .70742 .11707 L .71419 .11457 L F
.50788 .12168 m .51083 .11459 L .5144 .1192 L .663 .741 .908 r
F
.50788 .12168 m .5043 .11708 L .51083 .11459 L F
.61753 .12148 m .62084 .11438 L .62417 .11899 L F
.61753 .12148 m .61419 .11688 L .62084 .11438 L F
.39579 .1676 m .39686 .19573 L .40187 .17253 L .878 .623 .1 r
F
.72719 .12129 m .73088 .11418 L .73397 .11879 L .664 .741 .908 r
F
.72719 .12129 m .72409 .11669 L .73088 .11418 L F
.52448 .12131 m .52748 .11418 L .53102 .1188 L .665 .742 .907 r
F
.52448 .12131 m .52093 .1167 L .52748 .11418 L F
.63414 .1211 m .63752 .11399 L .64081 .1186 L .664 .741 .908 r
F
.63414 .1211 m .63084 .11649 L .63752 .11399 L F
.54108 .1209 m .54414 .1138 L .54764 .11842 L .663 .741 .908 r
F
.54108 .1209 m .53757 .1163 L .54414 .1138 L F
.65076 .12072 m .6542 .1136 L .65745 .11822 L .664 .741 .908 r
F
.65076 .12072 m .6475 .11611 L .6542 .1136 L F
.448 .12075 m .45074 .11362 L .45445 .11824 L .665 .742 .907 r
F
.448 .12075 m .44428 .11614 L .45074 .11362 L F
.55769 .12053 m .5608 .11342 L .56427 .11804 L .663 .741 .908 r
F
.55769 .12053 m .55421 .11592 L .5608 .11342 L F
.66739 .12033 m .67088 .11322 L .6741 .11784 L F
.66739 .12033 m .66416 .11572 L .67088 .11322 L F
.46459 .12039 m .46739 .11323 L .47106 .11786 L .666 .743 .907 r
F
.46459 .12039 m .46091 .11578 L .46739 .11323 L F
.5743 .12014 m .57747 .11303 L .5809 .11765 L .664 .741 .908 r
F
.5743 .12014 m .57086 .11553 L .57747 .11303 L F
.68403 .11995 m .68757 .11283 L .69076 .11745 L F
.68403 .11995 m .68083 .11534 L .68757 .11283 L F
.48119 .11996 m .48404 .11283 L .48768 .11745 L .664 .742 .908 r
F
.48119 .11996 m .47754 .11535 L .48404 .11283 L F
.59092 .11975 m .59415 .11264 L .59754 .11726 L .663 .741 .908 r
F
.59092 .11975 m .58752 .11514 L .59415 .11264 L F
.70067 .11956 m .70427 .11245 L .70742 .11707 L F
.70067 .11956 m .69751 .11495 L .70427 .11245 L F
.49779 .11957 m .5007 .11246 L .5043 .11708 L F
.49779 .11957 m .49418 .11496 L .5007 .11246 L F
.60754 .11937 m .61083 .11225 L .61419 .11688 L F
.60754 .11937 m .60418 .11476 L .61083 .11225 L F
.71731 .11918 m .72097 .11206 L .72409 .11669 L F
.71731 .11918 m .71419 .11457 L .72097 .11206 L F
.5144 .1192 m .51737 .11208 L .52093 .1167 L .664 .742 .908 r
F
.5144 .1192 m .51083 .11459 L .51737 .11208 L F
.62417 .11899 m .62752 .11187 L .63084 .11649 L .664 .741 .908 r
F
.62417 .11899 m .62084 .11438 L .62752 .11187 L F
.73397 .11879 m .73768 .11167 L .74076 .1163 L F
.73397 .11879 m .73088 .11418 L .73768 .11167 L F
.53102 .1188 m .53404 .11167 L .53757 .1163 L F
.53102 .1188 m .52748 .11418 L .53404 .11167 L F
.64081 .1186 m .64421 .11148 L .6475 .11611 L .663 .741 .908 r
F
.64081 .1186 m .63752 .11399 L .64421 .11148 L F
.43416 .15806 m .43072 .14297 L .43783 .11884 L .849 .624 .597 r
F
.54764 .11842 m .55072 .11129 L .55421 .11592 L .663 .741 .908 r
F
.54764 .11842 m .54414 .1138 L .55072 .11129 L F
.65745 .11822 m .66091 .11109 L .66416 .11572 L F
.65745 .11822 m .6542 .1136 L .66091 .11109 L F
.45445 .11824 m .45721 .11116 L .46091 .11578 L .661 .74 .909 r
F
.45445 .11824 m .45074 .11362 L .45721 .11116 L F
.56427 .11804 m .56741 .1109 L .57086 .11553 L .664 .741 .908 r
F
.56427 .11804 m .5608 .11342 L .56741 .1109 L F
.6741 .11784 m .67762 .1107 L .68083 .11534 L F
.6741 .11784 m .67088 .11322 L .67762 .1107 L F
.47106 .11786 m .47388 .11072 L .47754 .11535 L F
.47106 .11786 m .46739 .11323 L .47388 .11072 L F
.38248 .18477 m .37705 .21241 L .38507 .17639 L 0 0 0 r
F
.5809 .11765 m .5841 .11051 L .58752 .11514 L .664 .741 .908 r
F
.5809 .11765 m .57747 .11303 L .5841 .11051 L F
.69076 .11745 m .69433 .11032 L .69751 .11495 L .663 .741 .908 r
F
.69076 .11745 m .68757 .11283 L .69433 .11032 L F
.48768 .11745 m .49056 .11033 L .49418 .11496 L F
.48768 .11745 m .48404 .11283 L .49056 .11033 L F
.59754 .11726 m .60079 .11012 L .60418 .11476 L .664 .741 .908 r
F
.59754 .11726 m .59415 .11264 L .60079 .11012 L F
.70742 .11707 m .71105 .10993 L .71419 .11457 L F
.70742 .11707 m .70427 .11245 L .71105 .10993 L F
.5043 .11708 m .50724 .10996 L .51083 .11459 L .663 .741 .908 r
F
.5043 .11708 m .5007 .11246 L .50724 .10996 L F
.61419 .11688 m .6175 .10974 L .62084 .11438 L F
.61419 .11688 m .61083 .11225 L .6175 .10974 L F
.72409 .11669 m .72777 .10954 L .73088 .11418 L .664 .741 .908 r
F
.72409 .11669 m .72097 .11206 L .72777 .10954 L F
.52093 .1167 m .52393 .10954 L .52748 .11418 L .665 .742 .907 r
F
.52093 .1167 m .51737 .11208 L .52393 .10954 L F
.63084 .11649 m .63421 .10935 L .63752 .11399 L .664 .741 .908 r
F
.63084 .11649 m .62752 .11187 L .63421 .10935 L F
.53757 .1163 m .54062 .10916 L .54414 .1138 L .663 .741 .908 r
F
.53757 .1163 m .53404 .11167 L .54062 .10916 L F
.6475 .11611 m .65092 .10896 L .6542 .1136 L .664 .741 .908 r
F
.6475 .11611 m .64421 .11148 L .65092 .10896 L F
.41501 .15948 m .4181 .1402 L .42073 .17758 L .408 .285 .599 r
F
.41776 .19311 m .41501 .15948 L .42073 .17758 L .147 .068 .502 r
F
.41519 .19781 m .41776 .19311 L .42077 .22079 L 0 0 0 r
F
.42077 .22079 m .41776 .19311 L .42337 .21671 L 0 0 .421 r
F
.41776 .19311 m .42073 .17758 L .42337 .21671 L .147 .068 .502 r
F
.42073 .17758 m .4181 .1402 L .41949 .28612 L .97 .7 .28 r
F
.55421 .11592 m .55732 .10878 L .5608 .11342 L .663 .741 .908 r
F
.55421 .11592 m .55072 .11129 L .55732 .10878 L F
.66416 .11572 m .66764 .10858 L .67088 .11322 L F
.66416 .11572 m .66091 .11109 L .66764 .10858 L F
.46091 .11578 m .4637 .10859 L .46739 .11323 L .667 .743 .907 r
F
.46091 .11578 m .45721 .11116 L .4637 .10859 L F
.57086 .11553 m .57403 .10838 L .57747 .11303 L .664 .741 .908 r
F
.57086 .11553 m .56741 .1109 L .57403 .10838 L F
.68083 .11534 m .68437 .10818 L .68757 .11283 L F
.68083 .11534 m .67762 .1107 L .68437 .10818 L F
.47754 .11535 m .4804 .10819 L .48404 .11283 L .665 .742 .908 r
F
.47754 .11535 m .47388 .11072 L .4804 .10819 L F
.58752 .11514 m .59074 .10799 L .59415 .11264 L .663 .741 .908 r
F
.58752 .11514 m .5841 .11051 L .59074 .10799 L F
.69751 .11495 m .70111 .1078 L .70427 .11245 L F
.69751 .11495 m .69433 .11032 L .70111 .1078 L F
.49418 .11496 m .49709 .10781 L .5007 .11246 L F
.49418 .11496 m .49056 .11033 L .49709 .10781 L F
.42922 .2034 m .43066 .23702 L .43518 .21762 L .657 .328 .403 r
F
.42922 .2034 m .42459 .22522 L .43066 .23702 L F
.60418 .11476 m .60746 .10761 L .61083 .11225 L .664 .741 .908 r
F
.60418 .11476 m .60079 .11012 L .60746 .10761 L F
.71419 .11457 m .71785 .10741 L .72097 .11206 L .663 .741 .908 r
F
.71419 .11457 m .71105 .10993 L .71785 .10741 L F
.51083 .11459 m .51379 .10743 L .51737 .11208 L .664 .742 .908 r
F
.51083 .11459 m .50724 .10996 L .51379 .10743 L F
.41519 .19781 m .41064 .21289 L .41776 .19311 L 0 0 0 r
F
.41064 .21289 m .41501 .15948 L .41776 .19311 L .888 .645 .565 r
F
.41064 .21289 m .40723 .1972 L .41501 .15948 L F
.62084 .11438 m .62418 .10722 L .62752 .11187 L .664 .741 .908 r
F
.62084 .11438 m .6175 .10974 L .62418 .10722 L F
.73088 .11418 m .73459 .10702 L .73768 .11167 L F
.73088 .11418 m .72777 .10954 L .73459 .10702 L F
.52748 .11418 m .5305 .10702 L .53404 .11167 L F
.52748 .11418 m .52393 .10954 L .5305 .10702 L F
.63752 .11399 m .64091 .10683 L .64421 .11148 L .663 .741 .908 r
F
.63752 .11399 m .63421 .10935 L .64091 .10683 L F
.54414 .1138 m .54722 .10664 L .55072 .11129 L F
.54414 .1138 m .54062 .10916 L .54722 .10664 L F
.6542 .1136 m .65765 .10644 L .66091 .11109 L F
.6542 .1136 m .65092 .10896 L .65765 .10644 L F
.5608 .11342 m .56394 .10625 L .56741 .1109 L .664 .741 .908 r
F
.5608 .11342 m .55732 .10878 L .56394 .10625 L F
.67088 .11322 m .67439 .10605 L .67762 .1107 L F
.67088 .11322 m .66764 .10858 L .67439 .10605 L F
.46739 .11323 m .47021 .10607 L .47388 .11072 L .663 .741 .908 r
F
.46739 .11323 m .4637 .10859 L .47021 .10607 L F
.57747 .11303 m .58067 .10586 L .5841 .11051 L .664 .741 .908 r
F
.57747 .11303 m .57403 .10838 L .58067 .10586 L F
.68757 .11283 m .69114 .10566 L .69433 .11032 L .663 .741 .908 r
F
.68757 .11283 m .68437 .10818 L .69114 .10566 L F
.48404 .11283 m .48692 .10567 L .49056 .11033 L F
.48404 .11283 m .4804 .10819 L .48692 .10567 L F
.59415 .11264 m .5974 .10547 L .60079 .11012 L .664 .741 .908 r
F
.59415 .11264 m .59074 .10799 L .5974 .10547 L F
.70427 .11245 m .7079 .10527 L .71105 .10993 L F
.70427 .11245 m .70111 .1078 L .7079 .10527 L F
.5007 .11246 m .50364 .1053 L .50724 .10996 L .663 .741 .908 r
F
.5007 .11246 m .49709 .10781 L .50364 .1053 L F
.61083 .11225 m .61414 .10508 L .6175 .10974 L .664 .741 .908 r
F
.61083 .11225 m .60746 .10761 L .61414 .10508 L F
.72097 .11206 m .72466 .10488 L .72777 .10954 L F
.72097 .11206 m .71785 .10741 L .72466 .10488 L F
.51737 .11208 m .52036 .10489 L .52393 .10954 L .665 .742 .907 r
F
.51737 .11208 m .51379 .10743 L .52036 .10489 L F
.62752 .11187 m .63088 .10469 L .63421 .10935 L .664 .741 .908 r
F
.62752 .11187 m .62418 .10722 L .63088 .10469 L F
.53404 .11167 m .53709 .1045 L .54062 .10916 L .663 .741 .908 r
F
.53404 .11167 m .5305 .10702 L .53709 .1045 L F
.64421 .11148 m .64764 .1043 L .65092 .10896 L .664 .741 .908 r
F
.64421 .11148 m .64091 .10683 L .64764 .1043 L F
.55072 .11129 m .55383 .10412 L .55732 .10878 L .663 .741 .908 r
F
.55072 .11129 m .54722 .10664 L .55383 .10412 L F
.66091 .11109 m .66439 .10392 L .66764 .10858 L F
.66091 .11109 m .65765 .10644 L .66439 .10392 L F
.56741 .1109 m .57057 .10372 L .57403 .10838 L .664 .741 .908 r
F
.56741 .1109 m .56394 .10625 L .57057 .10372 L F
.67762 .1107 m .68116 .10352 L .68437 .10818 L F
.67762 .1107 m .67439 .10605 L .68116 .10352 L F
.47388 .11072 m .47673 .10352 L .4804 .10819 L .665 .742 .908 r
F
.47388 .11072 m .47021 .10607 L .47673 .10352 L F
.5841 .11051 m .58732 .10333 L .59074 .10799 L .663 .741 .908 r
F
.5841 .11051 m .58067 .10586 L .58732 .10333 L F
.69433 .11032 m .69793 .10314 L .70111 .1078 L F
.69433 .11032 m .69114 .10566 L .69793 .10314 L F
.49056 .11033 m .49346 .10315 L .49709 .10781 L F
.49056 .11033 m .48692 .10567 L .49346 .10315 L F
.60079 .11012 m .60407 .10294 L .60746 .10761 L .664 .741 .908 r
F
.60079 .11012 m .5974 .10547 L .60407 .10294 L F
.71105 .10993 m .7147 .10275 L .71785 .10741 L .663 .741 .908 r
F
.71105 .10993 m .7079 .10527 L .7147 .10275 L F
.50724 .10996 m .5102 .10276 L .51379 .10743 L .664 .742 .908 r
F
.50724 .10996 m .50364 .1053 L .5102 .10276 L F
.6175 .10974 m .62083 .10255 L .62418 .10722 L .664 .741 .908 r
F
.6175 .10974 m .61414 .10508 L .62083 .10255 L F
.72777 .10954 m .73149 .10235 L .73459 .10702 L F
.72777 .10954 m .72466 .10488 L .73149 .10235 L F
.52393 .10954 m .52695 .10235 L .5305 .10702 L F
.52393 .10954 m .52036 .10489 L .52695 .10235 L F
.63421 .10935 m .6376 .10216 L .64091 .10683 L .663 .741 .908 r
F
.63421 .10935 m .63088 .10469 L .6376 .10216 L F
.54062 .10916 m .5437 .10197 L .54722 .10664 L F
.54062 .10916 m .53709 .1045 L .5437 .10197 L F
.65092 .10896 m .65437 .10177 L .65765 .10644 L F
.65092 .10896 m .64764 .1043 L .65437 .10177 L F
.55732 .10878 m .56045 .10158 L .56394 .10625 L .664 .741 .908 r
F
.55732 .10878 m .55383 .10412 L .56045 .10158 L F
.66764 .10858 m .67115 .10138 L .67439 .10605 L F
.66764 .10858 m .66439 .10392 L .67115 .10138 L F
.57403 .10838 m .57722 .10118 L .58067 .10586 L F
.57403 .10838 m .57057 .10372 L .57722 .10118 L F
.68437 .10818 m .68794 .10099 L .69114 .10566 L .663 .741 .908 r
F
.68437 .10818 m .68116 .10352 L .68794 .10099 L F
.4804 .10819 m .48327 .101 L .48692 .10567 L F
.4804 .10819 m .47673 .10352 L .48327 .101 L F
.59074 .10799 m .59399 .1008 L .5974 .10547 L F
.59074 .10799 m .58732 .10333 L .59399 .1008 L F
.70111 .1078 m .70473 .1006 L .7079 .10527 L .664 .741 .908 r
F
.70111 .1078 m .69793 .10314 L .70473 .1006 L F
.49709 .10781 m .50002 .10063 L .50364 .1053 L .663 .741 .908 r
F
.49709 .10781 m .49346 .10315 L .50002 .10063 L F
.60746 .10761 m .61076 .1004 L .61414 .10508 L .664 .741 .908 r
F
.60746 .10761 m .60407 .10294 L .61076 .1004 L F
.71785 .10741 m .72153 .10021 L .72466 .10488 L F
.71785 .10741 m .7147 .10275 L .72153 .10021 L F
.51379 .10743 m .51678 .10021 L .52036 .10489 L .665 .742 .907 r
F
.51379 .10743 m .5102 .10276 L .51678 .10021 L F
.62418 .10722 m .62755 .10001 L .63088 .10469 L .664 .741 .908 r
F
.62418 .10722 m .62083 .10255 L .62755 .10001 L F
.5305 .10702 m .53355 .09983 L .53709 .1045 L .663 .741 .908 r
F
.5305 .10702 m .52695 .10235 L .53355 .09983 L F
.64091 .10683 m .64433 .09962 L .64764 .1043 L .664 .741 .908 r
F
.64091 .10683 m .6376 .10216 L .64433 .09962 L F
.54722 .10664 m .55032 .09944 L .55383 .10412 L .663 .741 .908 r
F
.54722 .10664 m .5437 .10197 L .55032 .09944 L F
.65765 .10644 m .66113 .09924 L .66439 .10392 L F
.65765 .10644 m .65437 .10177 L .66113 .09924 L F
.56394 .10625 m .5671 .09904 L .57057 .10372 L .664 .741 .908 r
F
.56394 .10625 m .56045 .10158 L .5671 .09904 L F
.67439 .10605 m .67793 .09884 L .68116 .10352 L F
.67439 .10605 m .67115 .10138 L .67793 .09884 L F
.58067 .10586 m .58388 .09865 L .58732 .10333 L .663 .741 .908 r
F
.58067 .10586 m .57722 .10118 L .58388 .09865 L F
.69114 .10566 m .69474 .09845 L .69793 .10314 L F
.69114 .10566 m .68794 .10099 L .69474 .09845 L F
.48692 .10567 m .48982 .09846 L .49346 .10315 L F
.48692 .10567 m .48327 .101 L .48982 .09846 L F
.42715 .23019 m .42664 .23881 L .43066 .23702 L .895 .487 .077 r
F
.42459 .22522 m .42664 .23881 L .42715 .23019 L F
.42459 .22522 m .42077 .22079 L .42545 .23516 L F
.42594 .2342 m .42545 .23516 L .42664 .23881 L F
.42459 .22522 m .42545 .23516 L .42594 .2342 L F
.42545 .23516 m .42337 .21671 L .42664 .23881 L 0 0 .421 r
F
.42077 .22079 m .42337 .21671 L .42545 .23516 L F
.42337 .21671 m .42073 .17758 L .4213 .19832 L .924 .676 .187 r
F
.42337 .21671 m .4213 .19832 L .42248 .24093 L F
.42347 .23901 m .42248 .24093 L .42367 .2839 L F
.42337 .21671 m .42248 .24093 L .42347 .23901 L F
.42664 .23881 m .42337 .21671 L .42612 .24756 L .89 .624 .109 r
F
.42664 .23881 m .42612 .24756 L .42816 .27054 L F
.43066 .23702 m .42664 .23881 L .43287 .24791 L .779 .308 .119 r
F
.42337 .21671 m .42367 .2839 L .42816 .27054 L .924 .676 .187 r
F
.42664 .23881 m .42816 .27054 L .43287 .24791 L .89 .624 .109 r
F
.42367 .2839 m .43072 .14297 L .43416 .15806 L .98 .714 .45 r
F
.42073 .17758 m .41949 .28612 L .42367 .2839 L .97 .7 .28 r
F
.42367 .2839 m .41949 .28612 L .43072 .14297 L .98 .714 .45 r
F
.5974 .10547 m .60067 .09826 L .60407 .10294 L .664 .741 .908 r
F
.5974 .10547 m .59399 .1008 L .60067 .09826 L F
.7079 .10527 m .71155 .09806 L .7147 .10275 L .663 .741 .908 r
F
.7079 .10527 m .70473 .1006 L .71155 .09806 L F
.50364 .1053 m .50659 .09807 L .5102 .10276 L .664 .742 .908 r
F
.50364 .1053 m .50002 .10063 L .50659 .09807 L F
.61414 .10508 m .61747 .09786 L .62083 .10255 L .664 .741 .908 r
F
.61414 .10508 m .61076 .1004 L .61747 .09786 L F
.72466 .10488 m .72837 .09766 L .73149 .10235 L F
.72466 .10488 m .72153 .10021 L .72837 .09766 L F
.52036 .10489 m .52337 .09766 L .52695 .10235 L F
.52036 .10489 m .51678 .10021 L .52337 .09766 L F
.63088 .10469 m .63427 .09747 L .6376 .10216 L .663 .741 .908 r
F
.63088 .10469 m .62755 .10001 L .63427 .09747 L F
.53709 .1045 m .54016 .09728 L .5437 .10197 L F
.53709 .1045 m .53355 .09983 L .54016 .09728 L F
.64764 .1043 m .65108 .09708 L .65437 .10177 L .664 .741 .908 r
F
.64764 .1043 m .64433 .09962 L .65108 .09708 L F
.55383 .10412 m .55695 .09689 L .56045 .10158 L F
.55383 .10412 m .55032 .09944 L .55695 .09689 L F
.66439 .10392 m .6679 .09669 L .67115 .10138 L F
.66439 .10392 m .66113 .09924 L .6679 .09669 L F
.57057 .10372 m .57375 .09649 L .57722 .10118 L F
.57057 .10372 m .5671 .09904 L .57375 .09649 L F
.68116 .10352 m .68472 .09629 L .68794 .10099 L .663 .741 .908 r
F
.68116 .10352 m .67793 .09884 L .68472 .09629 L F
.58732 .10333 m .59056 .0961 L .59399 .1008 L F
.58732 .10333 m .58388 .09865 L .59056 .0961 L F
.69793 .10314 m .70155 .0959 L .70473 .1006 L .664 .741 .908 r
F
.69793 .10314 m .69474 .09845 L .70155 .0959 L F
.49346 .10315 m .49638 .09593 L .50002 .10063 L .663 .741 .908 r
F
.49346 .10315 m .48982 .09846 L .49638 .09593 L F
.60407 .10294 m .60737 .09571 L .61076 .1004 L .664 .741 .908 r
F
.60407 .10294 m .60067 .09826 L .60737 .09571 L F
.7147 .10275 m .71838 .09551 L .72153 .10021 L F
.7147 .10275 m .71155 .09806 L .71838 .09551 L F
.5102 .10276 m .51318 .09551 L .51678 .10021 L F
.5102 .10276 m .50659 .09807 L .51318 .09551 L F
.43518 .21762 m .43066 .23702 L .43767 .21874 L 0 0 .083 r
F
.43066 .23702 m .43287 .24791 L .43767 .21874 L .779 .308 .119 r
F
.42816 .27054 m .43416 .15806 L .43751 .17673 L .992 .739 .425 r
F
.42816 .27054 m .42367 .2839 L .43416 .15806 L F
.62083 .10255 m .62419 .09531 L .62755 .10001 L .664 .741 .908 r
F
.62083 .10255 m .61747 .09786 L .62419 .09531 L F
.52695 .10235 m .52998 .09513 L .53355 .09983 L .663 .741 .908 r
F
.52695 .10235 m .52337 .09766 L .52998 .09513 L F
.6376 .10216 m .64102 .09492 L .64433 .09962 L .664 .741 .908 r
F
.6376 .10216 m .63427 .09747 L .64102 .09492 L F
.5437 .10197 m .54679 .09474 L .55032 .09944 L .663 .741 .908 r
F
.5437 .10197 m .54016 .09728 L .54679 .09474 L F
.65437 .10177 m .65785 .09453 L .66113 .09924 L F
.65437 .10177 m .65108 .09708 L .65785 .09453 L F
.56045 .10158 m .56361 .09434 L .5671 .09904 L .664 .741 .908 r
F
.56045 .10158 m .55695 .09689 L .56361 .09434 L F
.67115 .10138 m .67469 .09413 L .67793 .09884 L F
.67115 .10138 m .6679 .09669 L .67469 .09413 L F
.57722 .10118 m .58043 .09394 L .58388 .09865 L .663 .741 .908 r
F
.57722 .10118 m .57375 .09649 L .58043 .09394 L F
.68794 .10099 m .69153 .09374 L .69474 .09845 L F
.68794 .10099 m .68472 .09629 L .69153 .09374 L F
.59399 .1008 m .59726 .09355 L .60067 .09826 L .664 .741 .908 r
F
.59399 .1008 m .59056 .0961 L .59726 .09355 L F
.70473 .1006 m .70838 .09335 L .71155 .09806 L .663 .741 .908 r
F
.70473 .1006 m .70155 .0959 L .70838 .09335 L F
.50002 .10063 m .50297 .09336 L .50659 .09807 L .665 .742 .908 r
F
.50002 .10063 m .49638 .09593 L .50297 .09336 L F
.61076 .1004 m .61409 .09315 L .61747 .09786 L .664 .741 .908 r
F
.61076 .1004 m .60737 .09571 L .61409 .09315 L F
.72153 .10021 m .72523 .09295 L .72837 .09766 L F
.72153 .10021 m .71838 .09551 L .72523 .09295 L F
.51678 .10021 m .51979 .09296 L .52337 .09766 L .663 .741 .908 r
F
.51678 .10021 m .51318 .09551 L .51979 .09296 L F
.62755 .10001 m .63093 .09276 L .63427 .09747 L F
.62755 .10001 m .62419 .09531 L .63093 .09276 L F
.53355 .09983 m .53661 .09257 L .54016 .09728 L F
.53355 .09983 m .52998 .09513 L .53661 .09257 L F
.64433 .09962 m .64778 .09237 L .65108 .09708 L .664 .741 .908 r
F
.64433 .09962 m .64102 .09492 L .64778 .09237 L F
.55032 .09944 m .55344 .09218 L .55695 .09689 L F
.55032 .09944 m .54679 .09474 L .55344 .09218 L F
.66113 .09924 m .66463 .09197 L .6679 .09669 L F
.66113 .09924 m .65785 .09453 L .66463 .09197 L F
.5671 .09904 m .57028 .09177 L .57375 .09649 L F
.5671 .09904 m .56361 .09434 L .57028 .09177 L F
.67793 .09884 m .68149 .09158 L .68472 .09629 L .663 .741 .908 r
F
.67793 .09884 m .67469 .09413 L .68149 .09158 L F
.58388 .09865 m .58712 .09138 L .59056 .0961 L F
.58388 .09865 m .58043 .09394 L .58712 .09138 L F
.69474 .09845 m .69835 .09118 L .70155 .0959 L .664 .741 .908 r
F
.69474 .09845 m .69153 .09374 L .69835 .09118 L F
.60067 .09826 m .60397 .09099 L .60737 .09571 L F
.60067 .09826 m .59726 .09355 L .60397 .09099 L F
.71155 .09806 m .71522 .09079 L .71838 .09551 L F
.71155 .09806 m .70838 .09335 L .71522 .09079 L F
.50659 .09807 m .50957 .09079 L .51318 .09551 L F
.50659 .09807 m .50297 .09336 L .50957 .09079 L F
.61747 .09786 m .62082 .09059 L .62419 .09531 L F
.61747 .09786 m .61409 .09315 L .62082 .09059 L F
.52337 .09766 m .52641 .09041 L .52998 .09513 L .663 .741 .908 r
F
.52337 .09766 m .51979 .09296 L .52641 .09041 L F
.63427 .09747 m .63769 .0902 L .64102 .09492 L .664 .741 .908 r
F
.63427 .09747 m .63093 .09276 L .63769 .0902 L F
.43287 .24791 m .43751 .17673 L .44076 .19961 L .987 .769 .373 r
F
.43287 .24791 m .42816 .27054 L .43751 .17673 L F
.54016 .09728 m .54325 .09001 L .54679 .09474 L .663 .741 .908 r
F
.54016 .09728 m .53661 .09257 L .54325 .09001 L F
.65108 .09708 m .65455 .08981 L .65785 .09453 L F
.65108 .09708 m .64778 .09237 L .65455 .08981 L F
.55695 .09689 m .5601 .08961 L .56361 .09434 L .664 .741 .908 r
F
.55695 .09689 m .55344 .09218 L .5601 .08961 L F
.6679 .09669 m .67143 .08941 L .67469 .09413 L F
.6679 .09669 m .66463 .09197 L .67143 .08941 L F
.57375 .09649 m .57696 .08921 L .58043 .09394 L .663 .741 .908 r
F
.57375 .09649 m .57028 .09177 L .57696 .08921 L F
.68472 .09629 m .68831 .08902 L .69153 .09374 L F
.68472 .09629 m .68149 .09158 L .68831 .08902 L F
.59056 .0961 m .59383 .08882 L .59726 .09355 L F
.59056 .0961 m .58712 .09138 L .59383 .08882 L F
.70155 .0959 m .70519 .08862 L .70838 .09335 L F
.70155 .0959 m .69835 .09118 L .70519 .08862 L F
.60737 .09571 m .6107 .08842 L .61409 .09315 L .664 .741 .908 r
F
.60737 .09571 m .60397 .09099 L .6107 .08842 L F
.71838 .09551 m .72209 .08822 L .72523 .09295 L F
.71838 .09551 m .71522 .09079 L .72209 .08822 L F
.51318 .09551 m .51618 .08823 L .51979 .09296 L .663 .741 .908 r
F
.51318 .09551 m .50957 .09079 L .51618 .08823 L F
.62419 .09531 m .62757 .08803 L .63093 .09276 L F
.62419 .09531 m .62082 .09059 L .62757 .08803 L F
.52998 .09513 m .53304 .08784 L .53661 .09257 L .664 .741 .908 r
F
.52998 .09513 m .52641 .09041 L .53304 .08784 L F
.64102 .09492 m .64446 .08763 L .64778 .09237 L F
.64102 .09492 m .63769 .0902 L .64446 .08763 L F
.54679 .09474 m .54991 .08745 L .55344 .09218 L F
.54679 .09474 m .54325 .09001 L .54991 .08745 L F
.65785 .09453 m .66135 .08724 L .66463 .09197 L F
.65785 .09453 m .65455 .08981 L .66135 .08724 L F
.56361 .09434 m .56678 .08704 L .57028 .09177 L .664 .742 .908 r
F
.56361 .09434 m .5601 .08961 L .56678 .08704 L F
.67469 .09413 m .67824 .08684 L .68149 .09158 L .663 .741 .908 r
F
.67469 .09413 m .67143 .08941 L .67824 .08684 L F
.58043 .09394 m .58366 .08665 L .58712 .09138 L F
.58043 .09394 m .57696 .08921 L .58366 .08665 L F
.69153 .09374 m .69514 .08644 L .69835 .09118 L .664 .741 .908 r
F
.69153 .09374 m .68831 .08902 L .69514 .08644 L F
.59726 .09355 m .60055 .08625 L .60397 .09099 L F
.59726 .09355 m .59383 .08882 L .60055 .08625 L F
.70838 .09335 m .71205 .08605 L .71522 .09079 L F
.70838 .09335 m .70519 .08862 L .71205 .08605 L F
.61409 .09315 m .61744 .08585 L .62082 .09059 L F
.61409 .09315 m .6107 .08842 L .61744 .08585 L F
.51979 .09296 m .52281 .08566 L .52641 .09041 L .663 .741 .908 r
F
.51979 .09296 m .51618 .08823 L .52281 .08566 L F
.63093 .09276 m .63434 .08546 L .63769 .0902 L F
.63093 .09276 m .62757 .08803 L .63434 .08546 L F
.53661 .09257 m .53969 .08527 L .54325 .09001 L F
.53661 .09257 m .53304 .08784 L .53969 .08527 L F
.64778 .09237 m .65124 .08506 L .65455 .08981 L F
.64778 .09237 m .64446 .08763 L .65124 .08506 L F
.55344 .09218 m .55658 .08487 L .5601 .08961 L .664 .741 .908 r
F
.55344 .09218 m .54991 .08745 L .55658 .08487 L F
.66463 .09197 m .66816 .08466 L .67143 .08941 L F
.66463 .09197 m .66135 .08724 L .66816 .08466 L F
.57028 .09177 m .57348 .08447 L .57696 .08921 L .663 .741 .908 r
F
.57028 .09177 m .56678 .08704 L .57348 .08447 L F
.68149 .09158 m .68507 .08427 L .68831 .08902 L F
.68149 .09158 m .67824 .08684 L .68507 .08427 L F
.58712 .09138 m .59038 .08407 L .59383 .08882 L F
.58712 .09138 m .58366 .08665 L .59038 .08407 L F
.69835 .09118 m .702 .08387 L .70519 .08862 L F
.69835 .09118 m .69514 .08644 L .702 .08387 L F
.60397 .09099 m .60729 .08367 L .6107 .08842 L .664 .741 .908 r
F
.60397 .09099 m .60055 .08625 L .60729 .08367 L F
.71522 .09079 m .71893 .08347 L .72209 .08822 L F
.71522 .09079 m .71205 .08605 L .71893 .08347 L F
.62082 .09059 m .6242 .08328 L .62757 .08803 L .663 .741 .908 r
F
.62082 .09059 m .61744 .08585 L .6242 .08328 L F
.52641 .09041 m .52946 .08308 L .53304 .08784 L .664 .741 .908 r
F
.52641 .09041 m .52281 .08566 L .52946 .08308 L F
.63769 .0902 m .64112 .08288 L .64446 .08763 L F
.63769 .0902 m .63434 .08546 L .64112 .08288 L F
.54325 .09001 m .54636 .08269 L .54991 .08745 L F
.54325 .09001 m .53969 .08527 L .54636 .08269 L F
.65455 .08981 m .65805 .08248 L .66135 .08724 L F
.65455 .08981 m .65124 .08506 L .65805 .08248 L F
.5601 .08961 m .56327 .08228 L .56678 .08704 L F
.5601 .08961 m .55658 .08487 L .56327 .08228 L F
.67143 .08941 m .67498 .08208 L .67824 .08684 L .663 .741 .908 r
F
.67143 .08941 m .66816 .08466 L .67498 .08208 L F
.57696 .08921 m .58019 .08189 L .58366 .08665 L F
.57696 .08921 m .57348 .08447 L .58019 .08189 L F
.43767 .21874 m .44076 .19961 L .44393 .22669 L .705 .667 .119 r
F
.43767 .21874 m .43287 .24791 L .44076 .19961 L F
.68831 .08902 m .69192 .08168 L .69514 .08644 L .664 .741 .908 r
F
.68831 .08902 m .68507 .08427 L .69192 .08168 L F
.59383 .08882 m .59711 .08149 L .60055 .08625 L F
.59383 .08882 m .59038 .08407 L .59711 .08149 L F
.70519 .08862 m .70887 .08129 L .71205 .08605 L F
.70519 .08862 m .702 .08387 L .70887 .08129 L F
.6107 .08842 m .61404 .08109 L .61744 .08585 L F
.6107 .08842 m .60729 .08367 L .61404 .08109 L F
.62757 .08803 m .63098 .0807 L .63434 .08546 L .663 .741 .908 r
F
.62757 .08803 m .6242 .08328 L .63098 .0807 L F
.53304 .08784 m .53612 .0805 L .53969 .08527 L F
.53304 .08784 m .52946 .08308 L .53612 .0805 L F
.64446 .08763 m .64792 .08029 L .65124 .08506 L .664 .741 .908 r
F
.64446 .08763 m .64112 .08288 L .64792 .08029 L F
.54991 .08745 m .55305 .0801 L .55658 .08487 L F
.54991 .08745 m .54636 .08269 L .55305 .0801 L F
.66135 .08724 m .66487 .07989 L .66816 .08466 L F
.66135 .08724 m .65805 .08248 L .66487 .07989 L F
.56678 .08704 m .56998 .0797 L .57348 .08447 L .663 .741 .908 r
F
.56678 .08704 m .56327 .08228 L .56998 .0797 L F
.67824 .08684 m .68182 .0795 L .68507 .08427 L F
.67824 .08684 m .67498 .08208 L .68182 .0795 L F
.58366 .08665 m .58692 .07931 L .59038 .08407 L F
.58366 .08665 m .58019 .08189 L .58692 .07931 L F
.69514 .08644 m .69878 .0791 L .702 .08387 L F
.69514 .08644 m .69192 .08168 L .69878 .0791 L F
.60055 .08625 m .60386 .0789 L .60729 .08367 L .664 .741 .908 r
F
.60055 .08625 m .59711 .08149 L .60386 .0789 L F
.71205 .08605 m .71575 .0787 L .71893 .08347 L F
.71205 .08605 m .70887 .08129 L .71575 .0787 L F
.61744 .08585 m .62081 .0785 L .6242 .08328 L .663 .741 .908 r
F
.61744 .08585 m .61404 .08109 L .62081 .0785 L F
.63434 .08546 m .63777 .0781 L .64112 .08288 L .664 .741 .908 r
F
.63434 .08546 m .63098 .0807 L .63777 .0781 L F
.53969 .08527 m .5428 .07791 L .54636 .08269 L F
.53969 .08527 m .53612 .0805 L .5428 .07791 L F
.65124 .08506 m .65474 .0777 L .65805 .08248 L F
.65124 .08506 m .64792 .08029 L .65474 .0777 L F
.55658 .08487 m .55975 .0775 L .56327 .08228 L F
.55658 .08487 m .55305 .0801 L .55975 .0775 L F
.66816 .08466 m .67171 .0773 L .67498 .08208 L .663 .741 .908 r
F
.66816 .08466 m .66487 .07989 L .67171 .0773 L F
.57348 .08447 m .5767 .07711 L .58019 .08189 L F
.57348 .08447 m .56998 .0797 L .5767 .07711 L F
.68507 .08427 m .68868 .0769 L .69192 .08168 L .664 .741 .908 r
F
.68507 .08427 m .68182 .0795 L .68868 .0769 L F
.59038 .08407 m .59366 .07671 L .59711 .08149 L .664 .742 .908 r
F
.59038 .08407 m .58692 .07931 L .59366 .07671 L F
.702 .08387 m .70566 .0765 L .70887 .08129 L .664 .741 .908 r
F
.702 .08387 m .69878 .0791 L .70566 .0765 L F
.60729 .08367 m .61063 .0763 L .61404 .08109 L F
.60729 .08367 m .60386 .0789 L .61063 .0763 L F
.6242 .08328 m .6276 .07591 L .63098 .0807 L .663 .741 .908 r
F
.6242 .08328 m .62081 .0785 L .6276 .07591 L F
.64112 .08288 m .64458 .07551 L .64792 .08029 L .664 .741 .908 r
F
.64112 .08288 m .63777 .0781 L .64458 .07551 L F
.54636 .08269 m .5495 .07531 L .55305 .0801 L F
.54636 .08269 m .5428 .07791 L .5495 .07531 L F
.65805 .08248 m .66157 .0751 L .66487 .07989 L F
.65805 .08248 m .65474 .0777 L .66157 .0751 L F
.56327 .08228 m .56646 .07491 L .56998 .0797 L .663 .741 .908 r
F
.56327 .08228 m .55975 .0775 L .56646 .07491 L F
.67498 .08208 m .67856 .07471 L .68182 .0795 L F
.67498 .08208 m .67171 .0773 L .67856 .07471 L F
.58019 .08189 m .58344 .07452 L .58692 .07931 L F
.58019 .08189 m .5767 .07711 L .58344 .07452 L F
.69192 .08168 m .69556 .07431 L .69878 .0791 L F
.69192 .08168 m .68868 .0769 L .69556 .07431 L F
.59711 .08149 m .60042 .0741 L .60386 .0789 L .664 .741 .908 r
F
.59711 .08149 m .59366 .07671 L .60042 .0741 L F
.70887 .08129 m .71256 .0739 L .71575 .0787 L F
.70887 .08129 m .70566 .0765 L .71256 .0739 L F
.61404 .08109 m .61741 .07371 L .62081 .0785 L .663 .741 .908 r
F
.61404 .08109 m .61063 .0763 L .61741 .07371 L F
.63098 .0807 m .63441 .07331 L .63777 .0781 L .664 .741 .908 r
F
.63098 .0807 m .6276 .07591 L .63441 .07331 L F
.64792 .08029 m .65141 .0729 L .65474 .0777 L F
.64792 .08029 m .64458 .07551 L .65141 .0729 L F
.55305 .0801 m .55621 .0727 L .55975 .0775 L F
.55305 .0801 m .5495 .07531 L .55621 .0727 L F
.66487 .07989 m .66842 .0725 L .67171 .0773 L .663 .741 .908 r
F
.66487 .07989 m .66157 .0751 L .66842 .0725 L F
.56998 .0797 m .5732 .07231 L .5767 .07711 L F
.56998 .0797 m .56646 .07491 L .5732 .07231 L F
.68182 .0795 m .68543 .0721 L .68868 .0769 L .664 .741 .908 r
F
.68182 .0795 m .67856 .07471 L .68543 .0721 L F
.58692 .07931 m .5902 .07191 L .59366 .07671 L .664 .742 .908 r
F
.58692 .07931 m .58344 .07452 L .5902 .07191 L F
.69878 .0791 m .70245 .0717 L .70566 .0765 L .664 .741 .908 r
F
.69878 .0791 m .69556 .07431 L .70245 .0717 L F
.60386 .0789 m .6072 .0715 L .61063 .0763 L F
.60386 .0789 m .60042 .0741 L .6072 .0715 L F
.62081 .0785 m .62421 .0711 L .6276 .07591 L .663 .741 .908 r
F
.62081 .0785 m .61741 .07371 L .62421 .0711 L F
.63777 .0781 m .64123 .0707 L .64458 .07551 L .664 .741 .908 r
F
.63777 .0781 m .63441 .07331 L .64123 .0707 L F
.65474 .0777 m .65825 .07029 L .66157 .0751 L F
.65474 .0777 m .65141 .0729 L .65825 .07029 L F
.55975 .0775 m .56293 .07009 L .56646 .07491 L F
.55975 .0775 m .55621 .0727 L .56293 .07009 L F
.67171 .0773 m .67528 .0699 L .67856 .07471 L .663 .741 .908 r
F
.67171 .0773 m .66842 .0725 L .67528 .0699 L F
.5767 .07711 m .57995 .0697 L .58344 .07452 L F
.5767 .07711 m .5732 .07231 L .57995 .0697 L F
.68868 .0769 m .69232 .06949 L .69556 .07431 L F
.68868 .0769 m .68543 .0721 L .69232 .06949 L F
.59366 .07671 m .59697 .06929 L .60042 .0741 L .664 .742 .908 r
F
.59366 .07671 m .5902 .07191 L .59697 .06929 L F
.70566 .0765 m .70936 .06908 L .71256 .0739 L .664 .741 .908 r
F
.70566 .0765 m .70245 .0717 L .70936 .06908 L F
.61063 .0763 m .61399 .06889 L .61741 .07371 L .663 .741 .908 r
F
.61063 .0763 m .6072 .0715 L .61399 .06889 L F
.6276 .07591 m .63103 .06849 L .63441 .07331 L .664 .741 .908 r
F
.6276 .07591 m .62421 .0711 L .63103 .06849 L F
.64458 .07551 m .64807 .06808 L .65141 .0729 L F
.64458 .07551 m .64123 .0707 L .64807 .06808 L F
.66157 .0751 m .66511 .06768 L .66842 .0725 L F
.66157 .0751 m .65825 .07029 L .66511 .06768 L F
.56646 .07491 m .56968 .06748 L .5732 .07231 L .663 .741 .908 r
F
.56646 .07491 m .56293 .07009 L .56968 .06748 L F
.67856 .07471 m .68216 .06728 L .68543 .0721 L .664 .741 .908 r
F
.67856 .07471 m .67528 .0699 L .68216 .06728 L F
.58344 .07452 m .58671 .06708 L .5902 .07191 L .664 .742 .908 r
F
.58344 .07452 m .57995 .0697 L .58671 .06708 L F
.69556 .07431 m .69922 .06687 L .70245 .0717 L .664 .741 .908 r
F
.69556 .07431 m .69232 .06949 L .69922 .06687 L F
.60042 .0741 m .60376 .06667 L .6072 .0715 L F
.60042 .0741 m .59697 .06929 L .60376 .06667 L F
.61741 .07371 m .6208 .06628 L .62421 .0711 L .663 .741 .908 r
F
.61741 .07371 m .61399 .06889 L .6208 .06628 L F
.63441 .07331 m .63786 .06586 L .64123 .0707 L .664 .741 .908 r
F
.63441 .07331 m .63103 .06849 L .63786 .06586 L F
.65141 .0729 m .65492 .06546 L .65825 .07029 L F
.65141 .0729 m .64807 .06808 L .65492 .06546 L F
.66842 .0725 m .67199 .06506 L .67528 .0699 L .663 .741 .908 r
F
.66842 .0725 m .66511 .06768 L .67199 .06506 L F
.5732 .07231 m .57644 .06487 L .57995 .0697 L F
.5732 .07231 m .56968 .06748 L .57644 .06487 L F
.68543 .0721 m .68906 .06465 L .69232 .06949 L .664 .741 .908 r
F
.68543 .0721 m .68216 .06728 L .68906 .06465 L F
.5902 .07191 m .5935 .06445 L .59697 .06929 L .664 .742 .908 r
F
.5902 .07191 m .58671 .06708 L .5935 .06445 L F
.70245 .0717 m .70614 .06425 L .70936 .06908 L .664 .741 .908 r
F
.70245 .0717 m .69922 .06687 L .70614 .06425 L F
.6072 .0715 m .61056 .06405 L .61399 .06889 L .663 .741 .908 r
F
.6072 .0715 m .60376 .06667 L .61056 .06405 L F
.62421 .0711 m .62763 .06365 L .63103 .06849 L .664 .741 .908 r
F
.62421 .0711 m .6208 .06628 L .62763 .06365 L F
.64123 .0707 m .64471 .06324 L .64807 .06808 L .663 .741 .908 r
F
.64123 .0707 m .63786 .06586 L .64471 .06324 L F
.65825 .07029 m .66179 .06283 L .66511 .06768 L .664 .741 .908 r
F
.65825 .07029 m .65492 .06546 L .66179 .06283 L F
.67528 .0699 m .67888 .06243 L .68216 .06728 L F
.67528 .0699 m .67199 .06506 L .67888 .06243 L F
.57995 .0697 m .58322 .06224 L .58671 .06708 L F
.57995 .0697 m .57644 .06487 L .58322 .06224 L F
.69232 .06949 m .69598 .06202 L .69922 .06687 L F
.69232 .06949 m .68906 .06465 L .69598 .06202 L F
.59697 .06929 m .6003 .06182 L .60376 .06667 L F
.59697 .06929 m .5935 .06445 L .6003 .06182 L F
.61399 .06889 m .61738 .06142 L .6208 .06628 L .663 .741 .908 r
F
.61399 .06889 m .61056 .06405 L .61738 .06142 L F
.63103 .06849 m .63447 .06101 L .63786 .06586 L .664 .742 .908 r
F
.63103 .06849 m .62763 .06365 L .63447 .06101 L F
.64807 .06808 m .65157 .0606 L .65492 .06546 L .664 .741 .908 r
F
.64807 .06808 m .64471 .06324 L .65157 .0606 L F
.66511 .06768 m .66868 .0602 L .67199 .06506 L .663 .741 .908 r
F
.66511 .06768 m .66179 .06283 L .66868 .0602 L F
.68216 .06728 m .68579 .0598 L .68906 .06465 L .664 .741 .908 r
F
.68216 .06728 m .67888 .06243 L .68579 .0598 L F
.58671 .06708 m .59001 .05959 L .5935 .06445 L .664 .742 .908 r
F
.58671 .06708 m .58322 .06224 L .59001 .05959 L F
.69922 .06687 m .70291 .05939 L .70614 .06425 L .664 .741 .908 r
F
.69922 .06687 m .69598 .06202 L .70291 .05939 L F
.60376 .06667 m .60711 .05919 L .61056 .06405 L .663 .741 .908 r
F
.60376 .06667 m .6003 .06182 L .60711 .05919 L F
.6208 .06628 m .62422 .05879 L .62763 .06365 L .664 .741 .908 r
F
.6208 .06628 m .61738 .06142 L .62422 .05879 L F
.63786 .06586 m .64133 .05837 L .64471 .06324 L .663 .741 .908 r
F
.63786 .06586 m .63447 .06101 L .64133 .05837 L F
.65492 .06546 m .65846 .05797 L .66179 .06283 L .664 .741 .908 r
F
.65492 .06546 m .65157 .0606 L .65846 .05797 L F
.67199 .06506 m .67558 .05756 L .67888 .06243 L F
.67199 .06506 m .66868 .0602 L .67558 .05756 L F
.68906 .06465 m .69272 .05715 L .69598 .06202 L F
.68906 .06465 m .68579 .0598 L .69272 .05715 L F
.5935 .06445 m .59682 .05695 L .6003 .06182 L F
.5935 .06445 m .59001 .05959 L .59682 .05695 L F
.61056 .06405 m .61394 .05655 L .61738 .06142 L .663 .741 .908 r
F
.61056 .06405 m .60711 .05919 L .61394 .05655 L F
.62763 .06365 m .63107 .05614 L .63447 .06101 L .664 .742 .908 r
F
.62763 .06365 m .62422 .05879 L .63107 .05614 L F
.64471 .06324 m .64821 .05573 L .65157 .0606 L .664 .741 .908 r
F
.64471 .06324 m .64133 .05837 L .64821 .05573 L F
.66179 .06283 m .66535 .05532 L .66868 .0602 L .663 .741 .908 r
F
.66179 .06283 m .65846 .05797 L .66535 .05532 L F
.67888 .06243 m .6825 .05491 L .68579 .0598 L .664 .741 .908 r
F
.67888 .06243 m .67558 .05756 L .6825 .05491 L F
.69598 .06202 m .69966 .0545 L .70291 .05939 L F
.69598 .06202 m .69272 .05715 L .69966 .0545 L F
.6003 .06182 m .60365 .0543 L .60711 .05919 L .663 .741 .908 r
F
.6003 .06182 m .59682 .05695 L .60365 .0543 L F
.61738 .06142 m .62079 .0539 L .62422 .05879 L F
.61738 .06142 m .61394 .05655 L .62079 .0539 L F
.63447 .06101 m .63795 .05349 L .64133 .05837 L F
.63447 .06101 m .63107 .05614 L .63795 .05349 L F
.65157 .0606 m .65511 .05308 L .65846 .05797 L .664 .741 .908 r
F
.65157 .0606 m .64821 .05573 L .65511 .05308 L F
.66868 .0602 m .67227 .05268 L .67558 .05756 L .663 .741 .908 r
F
.66868 .0602 m .66535 .05532 L .67227 .05268 L F
.68579 .0598 m .68944 .05226 L .69272 .05715 L F
.68579 .0598 m .6825 .05491 L .68944 .05226 L F
.60711 .05919 m .61049 .05165 L .61394 .05655 L F
.60711 .05919 m .60365 .0543 L .61049 .05165 L F
.62422 .05879 m .62766 .05124 L .63107 .05614 L .664 .742 .908 r
F
.62422 .05879 m .62079 .0539 L .62766 .05124 L F
.64133 .05837 m .64483 .05083 L .64821 .05573 L .664 .741 .908 r
F
.64133 .05837 m .63795 .05349 L .64483 .05083 L F
.65846 .05797 m .66202 .05042 L .66535 .05532 L .663 .741 .908 r
F
.65846 .05797 m .65511 .05308 L .66202 .05042 L F
.67558 .05756 m .6792 .05001 L .6825 .05491 L .664 .741 .908 r
F
.67558 .05756 m .67227 .05268 L .6792 .05001 L F
.69272 .05715 m .6964 .0496 L .69966 .0545 L F
.69272 .05715 m .68944 .05226 L .6964 .0496 L F
.61394 .05655 m .61735 .049 L .62079 .0539 L .663 .741 .908 r
F
.61394 .05655 m .61049 .05165 L .61735 .049 L F
.63107 .05614 m .63454 .04858 L .63795 .05349 L .664 .741 .908 r
F
.63107 .05614 m .62766 .05124 L .63454 .04858 L F
.64821 .05573 m .65174 .04817 L .65511 .05308 L F
.64821 .05573 m .64483 .05083 L .65174 .04817 L F
.66535 .05532 m .66894 .04776 L .67227 .05268 L .663 .741 .908 r
F
.66535 .05532 m .66202 .05042 L .66894 .04776 L F
.6825 .05491 m .68615 .04735 L .68944 .05226 L F
.6825 .05491 m .6792 .05001 L .68615 .04735 L F
.62079 .0539 m .62423 .04632 L .62766 .05124 L .664 .742 .908 r
F
.62079 .0539 m .61735 .049 L .62423 .04632 L F
.63795 .05349 m .64144 .04591 L .64483 .05083 L .664 .741 .908 r
F
.63795 .05349 m .63454 .04858 L .64144 .04591 L F
.65511 .05308 m .65866 .0455 L .66202 .05042 L .663 .741 .908 r
F
.65511 .05308 m .65174 .04817 L .65866 .0455 L F
.67227 .05268 m .67589 .04509 L .6792 .05001 L .664 .742 .908 r
F
.67227 .05268 m .66894 .04776 L .67589 .04509 L F
.68944 .05226 m .69312 .04467 L .6964 .0496 L .664 .741 .908 r
F
.68944 .05226 m .68615 .04735 L .69312 .04467 L F
.62766 .05124 m .63112 .04365 L .63454 .04858 L F
.62766 .05124 m .62423 .04632 L .63112 .04365 L F
.64483 .05083 m .64836 .04324 L .65174 .04817 L .663 .741 .908 r
F
.64483 .05083 m .64144 .04591 L .64836 .04324 L F
.66202 .05042 m .6656 .04283 L .66894 .04776 L F
.66202 .05042 m .65866 .0455 L .6656 .04283 L F
.6792 .05001 m .68285 .04241 L .68615 .04735 L F
.6792 .05001 m .67589 .04509 L .68285 .04241 L F
.63454 .04858 m .63804 .04097 L .64144 .04591 L .664 .741 .908 r
F
.63454 .04858 m .63112 .04365 L .63804 .04097 L F
.65174 .04817 m .65529 .04055 L .65866 .0455 L F
.65174 .04817 m .64836 .04324 L .65529 .04055 L F
.66894 .04776 m .67256 .04014 L .67589 .04509 L .664 .742 .908 r
F
.66894 .04776 m .6656 .04283 L .67256 .04014 L F
.68615 .04735 m .68983 .03973 L .69312 .04467 L .664 .741 .908 r
F
.68615 .04735 m .68285 .04241 L .68983 .03973 L F
.64144 .04591 m .64496 .03828 L .64836 .04324 L .663 .741 .908 r
F
.64144 .04591 m .63804 .04097 L .64496 .03828 L F
.65866 .0455 m .66225 .03787 L .6656 .04283 L F
.65866 .0455 m .65529 .04055 L .66225 .03787 L F
.67589 .04509 m .67953 .03745 L .68285 .04241 L F
.67589 .04509 m .67256 .04014 L .67953 .03745 L F
.64836 .04324 m .65191 .03559 L .65529 .04055 L .664 .741 .908 r
F
.64836 .04324 m .64496 .03828 L .65191 .03559 L F
.6656 .04283 m .66921 .03517 L .67256 .04014 L .664 .742 .908 r
F
.6656 .04283 m .66225 .03787 L .66921 .03517 L F
.68285 .04241 m .68652 .03475 L .68983 .03973 L .664 .741 .908 r
F
.68285 .04241 m .67953 .03745 L .68652 .03475 L F
.65529 .04055 m .65887 .03289 L .66225 .03787 L .663 .741 .908 r
F
.65529 .04055 m .65191 .03559 L .65887 .03289 L F
.67256 .04014 m .6762 .03247 L .67953 .03745 L F
.67256 .04014 m .66921 .03517 L .6762 .03247 L F
.66225 .03787 m .66585 .03018 L .66921 .03517 L .664 .741 .908 r
F
.66225 .03787 m .65887 .03289 L .66585 .03018 L F
.67953 .03745 m .6832 .02976 L .68652 .03475 L F
.67953 .03745 m .6762 .03247 L .6832 .02976 L F
.66921 .03517 m .67285 .02747 L .6762 .03247 L F
.66921 .03517 m .66585 .03018 L .67285 .02747 L F
.6762 .03247 m .67986 .02474 L .6832 .02976 L F
.6762 .03247 m .67285 .02747 L .67986 .02474 L F
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.12392 .22116 m
.12858 .22578 L
s
[(-0.5)] .1146 .21193 1 .99103 Mshowa
.34276 .13547 m
.34705 .14044 L
s
[(0)] .33419 .12554 .86243 1 Mshowa
.58123 .0421 m
.58505 .04743 L
s
[(0.5)] .57359 .03143 .71581 1 Mshowa
.125 Mabswid
.16624 .20459 m
.16899 .20741 L
s
.20926 .18775 m
.21197 .1906 L
s
.25301 .17062 m
.25568 .17351 L
s
.2975 .15319 m
.30012 .15613 L
s
.3888 .11744 m
.39132 .12047 L
s
.43565 .0991 m
.43812 .10217 L
s
.48332 .08043 m
.48573 .08355 L
s
.53184 .06144 m
.53419 .06459 L
s
.0823 .23746 m
.08513 .24019 L
s
.04135 .2535 m
.04422 .25619 L
s
.63151 .02241 m
.63374 .02565 L
s
.68271 .00236 m
.68488 .00565 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[58]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00W?ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001cooooo0_l0001Hooooo`00Voooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000006?ooool5o`0005Sooooo002K
ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool05?ooool2o`0000Cooooo0_l0
001Gooooo`00Voooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo017ooooo0ol0
0006ooooo`03o`000?oooooo000005Kooooo002Kooooo`04o`000?ooooooooooo`0000Oooooo1?l0
000Aooooo`?o00002Oooool01?l0003oooooo`000?l0001Eooooo`00Voooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00oooooo0ol0000<ooooo`04o`000?ooooooooooo`0005Go
oooo002Looooo`;o00002?ooool5o`0000_ooooo1?l0000=ooooo`05o`000?ooooooooooooooool0
0000E?ooool00;Cooooo0_l0000>ooooo`;oZKgX00?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`1Booooo`00/Oooool3o`0000gooooo1OnY_NP00ooooooo0000ooooo`03ooooo`03o`000?oo
oooooooo057ooooo002_ooooo`;o00003_ooool8ojVmj003ooooool0003ooooo00?ooooo00?o0000
ooooooooool0D?ooool00:cooooo0ol0000>ooooo`_oZKgX00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1@ooooo`00ZOooool3o`0000gooooo3onY_NP00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00gooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000<oooool00:Oo
oooo0_l00003ooooo`03o`000?oooooooooo00Wooooo4?nY_NP00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00_ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000c
ooooo`00Y?ooool3o`0000gooooo5?nY_NP00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0<oooool0
0:;ooooo0_l0000>oooooaKoZKgX00?o0000ojVmj?ooool01Oooool00ol0003oooooooooo`0:oooo
o`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0<_ooool009oooooo0ol0000=oooo
oaWoZKgX00?o0000ojVmj?nY_NP01_ooool00ol0003oooooooooo`09ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000cooooo`00W?ooool4o`0000gooooo6onY_NP0
1?l0003oZKgXojVmj?nY_NP5ooooo`;o00002_ooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool00000<oooool009[ooooo0_l0000=oooooaooZKgX00Co0000ojVmj?nY_NSo
ZKgX1Oooool2o`0000_ooooo0_l00009ooooo`?o0000=?ooool009Oooooo0ol0000>ooooob3oZKgX
00?o0000ojVmj?nY_NP00_nY_NP6ooooo`03o`000?oooooooooo04[ooooo002Eooooo`;o00003Ooo
oolTojVmj003o`000?nY_NSoZKgX00?oZKgX1Oooool00ol0003oooooooooo`1:ooooo`00T_ooool3
o`0000gooooo9_nY_NP00ol0003oZKgXojVmj003ojVmj0Kooooo00?o0000ooooooooool0BOooool0
093ooooo0ol0000>ooooobOoZKgX00?o0000ojVmj?nY_NP01?nY_NP6ooooo`03o`000?oooooooooo
04Sooooo002=ooooo`?o00003Oooool[ojVmj003o`000?nY_NSoZKgX00CoZKgX1_ooool00ol0003o
ooooooooo`18ooooo`00R_ooool3o`0000kooooo;OnY_NP00ol0003oZKgXojVmj005ojVmj0Kooooo
00?o0000ooooooooool0Aoooool006Oooooo0_l0000Oooooo`;o00003_ooool`ojVmj003o`000?nY
_NSoZKgX00KoZKgX1_ooool00ol0003oooooooooo`16ooooo`00I_ooool01?l0003oooooooooool0
000Kooooo`?o00003_ooool2ojZmj37oZKgX00?o0000ojVmj?nY_NP01_nY_NP5ooooo`03o`000?oo
oooooooo04Kooooo001Vooooo`04o`000?ooooooooooo`0001Wooooo0_l000000ooooooo0000oooo
o`0;ooooo`?oZKgX00?oZ[gXojVmj?nY_NP0<?nY_NP00ol0003oZKgXojVmj007ojVmj0Gooooo00?o
0000ooooooooool0AOooool006Kooooo00Co0000oooooooooooo00005_ooool3o`0000kooooo2?nY
_NP2ojZmj2koZKgX00?o0000ojVmj?nY_NP01onY_NP6ooooo`03o`000?oooooooooo04Cooooo001V
ooooo`04o`000?ooooooooooo`0001Cooooo0_l0000>ooooo`03ojVmj?nZ_NSoZ[gX00WoZKgX0_nZ
_NP]ojVmj003o`000?nY_NSoZKgX00OoZKgX1_ooool2o`0004Gooooo001Vooooo`04o`000?oooooo
ooooo`00017ooooo0ol0000>ooooo`;oZ[kX00CoZKgXojZmj?nZ_NSoZ[gX2OnY_NP2ojZmj2coZKgX
00?o0000ojVmj?nY_NP02?nY_NP5ooooo`;o0000AOooool006Oooooo0_l0000?ooooo`?o00003_oo
ool00onZ_NSoZKgXojVmj003ojZnj003ojVmj?nZ_NSoZKgX00[oZKgX00?oZ[gXojVmj?nY_NP0:_nY
_NP00ol0003oZKgXojVmj009ojVmj0Gooooo00?o0000ooooooooool0@oooool007Kooooo0_l00002
ooooo`03o`000?oooooooooo00[ooooo0_n/_>D01_nZ_NSoZKgXojVmj?nY_NSoZ[kXojZmj0koZKgX
00?oZ[gXojVmj?nY_NP0:OnY_NP00ol0003oZKgXojVmj00:ojVmj0Gooooo00?o0000ooooooooool0
@_ooool007?ooooo0ol0000@ooooo`03omVOV?n/_>Go[[SP00;oZ[gX0onY_NP2ojZmj0goZKgX0_nZ
_NPZojVmj003o`000?nY_NSoZKgX00_oZKgX1Oooool00ol0003oooooooooo`11ooooo`00LOooool2
o`0001?ooooo00CofInHombNTOn^^>3o/k?I0_nZ_NP3ojVmj003ojZmj?nY_NSoZKgX00_oZKgX0onZ
_NPYojVmj003o`000?nY_NSoZKgX00_oZKgX1Oooool00ol0003oooooooooo`11ooooo`00K_ooool3
o`0001Cooooo0_oIWiP00ooLWY7o/k?Iok>cf@03ojZmj0;oZKgX0_nZ_NP=ojVmj0?oZ[gX:?nY_NP0
0ol0003oZKgXojVmj00;ojVmj0Kooooo00?o0000ooooooooool0@?ooool006cooooo0_l0000Goooo
o`;ofInH00Cog9jAomnMS?nc/mWo_;;?0onZ_NP2ojVmj0;oZ[gX00?oZKgXojZmj?nY_NP02_nY_NP3
ojZmj2OoZKgX00?o0000ojVmj?nY_NP03?nY_NP6ooooo`03o`000?oooooooooo03oooooo001Yoooo
o`?o00000_ooool00ol0003oooooooooo`0>ooooo`;oJ4RI1?ooool02?oIWiSog9jAombNTOoOWHco
hYj7okbbcoo6/LGoZ[gX0_nZ_NL2ojVmj0CoZ[gX2onY_NP3ojZmj2KoZKgX00?o0000ojVmj?nY_NP0
3OnY_NP5ooooo`03o`000?oooooooooo03oooooo001Vooooo`?o00005_ooool2ofQ8V@?ooooo0_oI
WiP2ombNT@07omnMS?oRWXOoa[75olJaaOo>[[[oZ[gWojZli`03ojVmj0;oZ[gX3OnY_NP00onZ_NSo
ZKgXojVmj00UojVmj003o`000?nY_NSoZKgX00koZKgX1Oooool00ol0003oooooooooo`0nooooo`00
I?ooool2o`0001Wooooo0_mXB9T3ooooo`;ofInH00Sog9jAomnMS?oOWHcohYj7onJQQ?o6/LGocZjj
om6W[P;oZ[cW0onY_NP00onZ_NSoZKgXojVmj002ojVmj003ojZmj?nY_NSoZKgX02koZKgX00?o0000
ojVmj?nY_NP03onY_NP5ooooo`03o`000?oooooooooo03gooooo001Qooooo`?o00006_ooool2okan
T@04ofQ8VOooooooooooooooo`;ofInH00Gog9jAomnMS?oOWHcohYj7onJQQ002olj^^P04om6W[_oC
XJ;o[;cUojbli@;oZKgX0_nZ_NP3ojVmj003ojZmj?nY_NSoZKgX02koZKgX00?o0000ojVmj?nY_NP0
3onY_NP5ooooo`03o`000?oooooooooo03gooooo001Oooooo`Co00005_ooool00ol0003ooooooooo
o`02ooooo`;o_7jA00OoJ4RIooooooooooooooooooZfLooIWiSog9jA00;ogif<00?ohYj7onJQQ?o[
YH000_oAYjh01?oCXJ;o[[_Sojjkhon^^n<2ojVmj0;oZ[gX0onY_NP00onZ_NSoZKgXojVmj00]ojVm
j003o`000?nY_NSoZKgX00ooZKgX1_ooool2o`0003gooooo001Looooo`?o00006_ooool00ol0003o
h9lIooooo`02ooooo`;o_7jA00GoJ4RIooooooooooooooooooZfL`02ombNT@05omnMS?oRWXOohYj7
onJQQ?o[YH000_oAYjh00ooCXJ;oeifIojjkh`02ok6ig`04ojVmj?nZ_NSoZ[gXojZmj0?oZKgX00?o
Z[gXojVmj?nY_NP0;OnY_NP00ol0003oZKgXojVmj00?ojVmj0Kooooo00?o0000ooooooooool0>ooo
ool005[ooooo0_l0000Looooo`03oj57G?l0003oh9lI00;ooooo0onlOY401OmXB9Wooooooooooooo
oooon[Ic00;og9jA00Kogif<on:NQooVXHCoiZ64on^UP?o`ZG`2om>QXP03omNMVOoKWI7o/KWO00;o
]kOI00CoZKgXojZmj?nZ_NSoZ[gX0_nY_NP2ojZmj2koZKgX00?o0000ojVmj?nY_NP04?nY_NP5oooo
o`03o`000?oooooooooo03_ooooo001Gooooo`?o00007Oooool01?nQAeco000IolRU]_oPWaT2oooo
o`?o_7jA00GoJ4RIooooooooooooooooooZfL`02ombNT@07omnMS?oRWXOoiZ64onJQQ?o[YH3ol:Ul
om>QXP02omNMV@03om^MTOoPWXco]kOI00;o_[GA00GoZKgXojZmj?nZ_NSoZ[gXojVmj003ojZmj2go
ZKgX00?o0000ojVmj?nY_NP04OnY_NP5ooooo`03o`000?oooooooooo03[ooooo001Dooooo`?o0000
5Oooool00ol0003oeHd1ooooo`05ooooo`07ocX00?oooooo]B`0oj57G?l0003oU6VNon2O6@02oooo
o`?o_7jA00Wo9A60onJBJoo_XRgoooooooZfLoom_Fcog9jAomnMS?oRWXL00_oVXH@00oo[YH3ol:Ul
om>QXP02omNMV@03om^MTOoPWXco_[GA00;o_[GA00?oaK76ojVmj?nZ_NP00_nZ_NP01?nY_NSoZ[gX
ojZmj?nZ_NP/ojVmj003o`000?nY_NSoZKgX017oZKgX1_ooool00ol0003oooooooooo`0iooooo`00
D_ooool2o`0000;ooooo00?o0000ooooooooool04oooool00ol0003oeHd1ooooo`02ooooo`;oA000
00[oKdZEokUGDone;03o]B`0oj57G?l0003oU6VNohM^[ooPWaWo00000_nlOY401?oSYI3o9A60onJB
JooVTV/2ooZfL`05oofmK?oOWHcogif<on:NQooVXH@00_o[YH000oo`ZGcodj6RomNMV@02om^MT@03
on2NS?oTX8Oo_[GA00;oaK760_nY_>L2ojZmj0;oZKgX0onZ_NP[ojVmj003o`000?nY_NSoZKgX01;o
ZKgX1Oooool00ol0003oooooooooo`0iooooo`00Coooool3o`0001Sooooo0_ngC3l01_mmF9co012P
oooooooooooo^XFLofm:U@;o`T870_niEe<2oj57G0;oU6VN00?o?Qn2on2O6Ol000000_nlOY42on>U
T0;oiY9[0_oj]W<01Oom_Fcogif<omnMS?oRWXOoiZ6400;ojjF000?ol:UlomNMVOoGWIT00_oKWI40
0ooPWXcoi:27olFaaP02olFaaP03ojVlionZ^nKoZ[_V00;oZ[gX0_nY_NP2ojZmj2_oZKgX00?o0000
ojVmj?nY_NP04onY_NP5ooooo`03o`000?oooooooooo03Sooooo000Qooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00007_ooool2o`0001Oooooo00SokhlboooooooooooooooookM<?olO
03OoOERLo`0@X0;ooooo00?o^XFLofm:UOm_BYD00oniEe<2oj57G0;oU6VN00Go?Qn2on2O6OmZAYGo
0000okanT@02on>UT0;oiY9[0_oj]W<02?om_Fcogif<omnMS?oRWXOoiZ64on^UP?ooooool:Ul0_oG
WIT02OoKWI7oh9j<on2NS?oTX8Ooij:4olFaa_o;[;[od:N^ojZkiP02ojbki0;oZ[gX0_nY_NP2ojZm
j2[oZKgX00?o0000ojVmj?nY_NP05?nY_NP5ooooo`03o`000?oooooooooo03Oooooo000Pooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Jooooo`?o00006Oooool0
0ongOIGokhlbonn?<P02okM<?`09oal0=ommF9co012PoooooonjQIcog<Q9oim9HOm_BYGoeIVE00;o
^EMC00WobW1Uo`000?o>XjcoU6VNochOP_oPWaWoooooo`000?nlOY400_oSYI02onJBJ`03ooZfLoom
_FcooKe/00;ogif<00?ohYj7onJQQ?o[YH000_o`ZG`2omNMV@05om^MTOoPWXcoh9j<onBPQooWXX@0
0_o;[;X00oo@Yjkoe::Sojbki002ojnkhP04ojZmj?nY_NSoZKgXojVmj0;oZ[gX:OnY_NP00ol0003o
ZKgXojVmj00DojVmj0Gooooo00?o0000ooooooooool0=oooool001Wooooo1Ol00002ooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool05Oooool5o`0000cooooo00?oZ;gXoiVhkOoc
Vd`02Oooool00ooLR6gooooookMmU@02onn?<P07ojmHI?ngC3oo0000ogeHW?l04:3ooooookZ5W002
omc8B@03ofm:UOoEVIGoeIVE00;obW1U00So0000oljS[?nDJIko?Qn2on2O6Oob]H[o0000okanT@;o
hjF@00?ok:d_onJBJooj]W<00_om_F`2omnMS0;oiZ6400OojjF0oo2YO?o`ZGcon;=eomNMVOoKWI7o
h9j<00;oi:2700Soij:4on^UPOo@Yjkod:N^omBRXooHX9[o[k_RokBkg`;oZ[gX0onY_NP2ojZmj2So
ZKgX00?o0000ojVmj?nY_NP05?nY_NP6ooooo`03o`000?oooooooooo03Kooooo000Pooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool04oooool2o`0000kooooo0onY_NP01?nX_NSo
ZKgXoo>KC?oeXU`8ooooo`03omb8KOngOIGo]gfE00;okhlb00Go[eQToal0=ol0003oOERLo`0@X002
okZ5W005oo:gSooLb4WoooooomFIUOoddV800_o:L6D2oljS[003oiAYW_ln7h;o4PIn00;ol[F:0ooS
YI000oo/[BooiY9[ooZfL`02oofmK008ooc4GooRWXOoiZ64onJQQ?o[YH3ol:UlooB^NOoh/gD2om^M
T@05on2NS?oTX8Ooi:27onNRQ?o[YH400_o@Yjh00ooDXZ?of:2JombOT`02okBkg`04ojZmj?nZ_^So
ZKgXojVmj0;oZ[gX:?nY_NP00ol0003oZKgXojVmj00EojVmj0Kooooo00?o0000ooooooooool0=Ooo
ool0023ooooo00Co0000oooooooooooo00001oooool4o`0001?ooooo0ol0000>ooooo`;oZ[gX1OnY
_NP00oocVdcomJ9LooJWI007ooooo`04o`006ongOIGo]gfEooRnR`;o[eQT00Co7`0gohMMVOmmF9co
012P0_njQI`01Oob]hooooooomFIUOoEVIGom=9R00;obW1U00Oo][3Cog>LjonDJIko?Qn2oc<00?ob
]H[om<eK00?ohjF@00?ok:d_onJBJooj]W<00_om_F`02?ola5oohYj7onJQQ?oVXHCojjF0oo2YO?od
[WWon;=e0_oKWI401_oPWXcoi:27onBPQooWXXCojjF1onjXOP;oe::S00?of:2JombOTonh^m`00_nh
^m`2ojZnj0;oZKgX00?oZ[gXojVmj?nY_NP09_nY_NP00ol0003oZKgXojVmj00FojVmj0Gooooo0_l0
000fooooo`008?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01;ooooo0_l0
000>ooooo`?oZKgX0onZ_NP5ojVmj003ooFRG?ofYfCooooo00Kooooo00Co000KokMmUOoh_X_on;j;
0_n_F6@02?lO03OoQefIogeHW?l04:3o1@1YokZ5W?ob]hoolOBZ0_oEVID01_oddV;obW1UolY`IOnf
/=?o/gbGo`00B`;o?Qn200?o4PInoj9kYooSYI000_oSYI001?lU4H3oiY9[ooZfLoom_F`2ooc4G`07
on:NQooVXHCoiZ64on^UP?o`ZGcom:iiooRcM@02om^MT@06on2NS?oTX8Ooij:4onNRQ?o[YH7okZQn
0_oDXZ<01_oHX9[og9nCon2OSOnh^mco_K[GojZnj0;oZKkX:_nY_NP00ol0003oZKgXojVmj00GojVm
j0Gooooo00?o0000ooooooooool0=?ooool0027ooooo0_l00008ooooo`Go00003Oooool3o`0000go
oooo1onY_NP00onZ_NSoZKgXojVmj004ojVmj003ooFRG?ofYfComjYX00Gooooo0_l001/01?ngOIGo
n;j;ooRnRooCV9H2oal0=`04ohmOU_lW4h7oOERLo`D0J@;ol[N?00?olOBZomFIUOoEVID00_ooch40
1?l0003o/gbGoog6PoomaX<2ochOPP09oa86O_nWPjgohjF@on>UT?l0003o9A60onJBJooj]W?ooKe/
00;oo<AO00_ohYj7onJQQ?oVXHCojjF0oo2YO?od[WWon;=eoobiKooKWI7oh9j<onBPQ`02onNRQ004
on^UPOo^Z7kolZ]komRPVP;og9nC00Goh9n=onBQROnm^]Oo`[G>ojVnj002ojVmj0;oZ[gX9onY_NP0
0ol0003oZKgXojVmj00GojVmj0Kooooo00?o0000ooooooooool0<oooool003_ooooo0_l00003oooo
o`03o`000?oooooooooo00Sooooo4?nY_NP01OoeXUcomZMTooNZJ?ooooooZG6C00?ooooo00?o000K
omb8KOngOID00_oh_X/04?oCV9Ko7`0gom>HU_n?GiKo9a>1ogeHW?l506Wol[N?okFZ7Ol/5hCoGcb@
omFIUOoooooooln1o`000?ncO9L2oog6P`;o?Qn200Wo4PInojN3[OnRNjOohjF@o`000?l006_oiY9[
ooZfLoom_F`00_ola5l02?oRWXOoiZ64on^UP?o[YH3ol:UlooB^NOoh/gGoo;U_0_oPWX`01ooTX8Oo
ij:4onNRQ?o[YH7okZQnoo:[NooHX9X00_oLWi<01_oPWhgoi:69ol:ec_o2]LkoaZk2ojVmj0;oZKcW
00?oZ[gXojVmj?nY_NP09OnY_NP00ol0003oZKgXojVmj00HojVmj0Gooooo00?o0000ooooooooool0
<oooool003Sooooo0ol0000=ooooo`;oZ[gX4OnY_NP01OocVdcomZMTooNZJ?oh[F_oZG6C00?ooooo
00?o000KoooooongOID00_oh_X/2om>HUP0<oo[@W?n?GiKo9a>1obLCPOl506Wol[N?ohAGU?l/5hCo
0000ooCBH_oooooolL]F0_ncO9L2oog6P`;o:3V^00WooMYmoij9_OnRNjOohjF@o`00E?l006_oiY9[
ooZfLoom_F`00_ola5l02?oRWXOoiZ64on^UP?o[YH3ol:UlooB^NOoh/gGoo;U_0_oPWX`02?oTX8Oo
ij:4onNRQ?o[YH7okZQnoo:[NooHX9[og9nC0_oPWhd01ooTXHWoij:5ol:ec_o6[/;oc:RdojVlionZ
^nH00_nZ_NPVojVmj003o`000?nY_NSoZKgX01WoZKgX1Oooool00ol0003oooooooooo`0booooo`00
=Oooool3o`0000gooooo0onY_NP00onZ_NSoZKgXojVmj00@ojVmj003oo>KC?ofYfComjYX00;oZG6C
00_o001BooooooooooooolZ0ooOAIOngOIGon;j;oh=AS_oYZHcodiRFoo[@W002ohmOUP09obLCPOl5
06Wol[N?ohAGU?l/5hCo000ToellT?ooch7olL]F00;o/gbG0_omaX<03onhQYoo:3V^oij9_OnNRKgo
7c2Xoc4NROn57SOo001[onJBJooj]W?ooKe/ooc4GondZQkohYj7onJQQ002on^UP004oo2YO?od[WWo
n;=eoobiK`;oh9j<00Soi:27onNRQ?o[YH7ojjF1onjXO_obZg_of:2JombOT`;oh9n=00Koi:69onNR
QOoZY8;oaZk2olbX]?oAXjP2ojZkiP;oZ[gX9OnY_NP00ol0003oZKgXojVmj00JojVmj0Gooooo00?o
0000ooooooooool01_ooool2o`0002Wooooo000cooooo`;o00003ooooolGojVmj003oo>KC?ofYfCo
mjYX00;oZG6C00_o001Booooool001_oolZ0ooOAIOngOIGon;j;oh=AS_oYZHcodiRFoo[@W002ohmO
UP0;obLCPOl506Wol[N?ohAGU?l/5hCo000Tooo?POn?H9KolL]FooFOBoncO9L00_omaX<00onhQYoo
:3V^o`000002oij9_@;o<Aj900Ko001[ooZfLooj]W?ooKe/ooc4GondZQh2onJQQ003on^UP?oj/Tko
l:Ul00;on;=e00Goo;U_on2NS?oPWXcoi:27onNRQ002on^UP@04onjXO_obZg_of:2JombOT`;oh9n=
00?oi:69onNRQOoZY8800_o<Z;@00ooAXjSoej:Oojfjh`03ojZmj2GoZKgX00?o0000ojVmj?nY_NP0
6OnY_NP5ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000:?ooool0033ooooo
0ol00002ooooo`03o`000?oooooooooo00Wooooo6_nY_NP00ooj/VWomZMTooNZJ002ojUaT`05o`00
D_oooooo^Y2[ooS@IOogdFD00_oh_X/01?n3DHkojJV<oo[@W?ojd9`2ohmOUP0@obLCPOob]hool[N?
ohAGU?l/5hCo000Tooo?POm105;oNTnCoa80>_ncO9OooLJ3ok:b:_nhQYookhllonFYTP;oWXVm00?o
7c2Xoc4NROl006/00_oj]W<00oom_Fcoo<AOokBZ7P02onJQQ003on^UP?oj/Tkol:Ul00;on;=e00Wo
o;U_on2NS?oTX8Ooi:27onNRQ?o[YH7oooooonjXO_obZg/00_oLWi<01_oPWhgoi:69onBQROoWXXGo
jZB2olbX]0;odJ>X00?oej:Ook6jhOna^^400onZ_NP:ojVmj0;oZ[gX6?nY_NP00ol0003oZKgXojVm
j00JojVmj0Gooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Xooooo`00;_oo
ool2o`0000kooooo7OnY_NP00ooj/VWomZMTooNZJ002ojUaT`07o`00D_oooooo^Y2[ooC2VOl000Go
n;j;oh=ASP02onVYS005ooK>G_ojd9coSenFohmOU_lW4h400_ob]hl01on4EiCo;1N4o`00<On?H9Ko
lL]FogY?TooeWd/00_omaX<00oob^Y;o^8JOof0oT`02onFYTP;oUfJG00?o<Aj9ooo<MOoj]W<00_om
_F`01Oola5oon;b5onJQQ?oVXHCojjF000;ol:Ul0_oh/gD01_ol^FoooL5SonBPQooTX8Ooij:4on^U
P@;okZQn00ColZ]kombOTooLWi?oh9n=0_oTXHT01?oWXXGojZB2om6SZ?oAXjP2omNRW`04ombRUona
^^7o][_NojZmj0;oZ[kX2_nY_NP2ojZmj1OoZKgX00?o0000ojVmj?nY_NP06_nY_NP6ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo0000:?ooool002_ooooo0ol0000>oooooaooZKgX
00?on[9YooJWI?ogZVP00_nYLI<01ol005;o^Y2[okZ@ZoogdFGomK9oojEdVon3DHh00_oYZH`2ooK>
GP06ohmOU_omchoooLn?oo:gSoneZQgoS5fF0_l/5h@02on?H9KolL]FogY?Tol002OooLJ3on2XV_oo
oooo^8JOof0oTooUZI;oflU:00;oUfJG00Com/6Eo`00JOoj]W?ooKe/0_ola5l01?oh_8GoiZ64onJQ
Q?o[YH02oo2YO0;on;=e00Koo;U_oog1HooTX8Ooi:27onNRQ?o[YH42onjXOP05oo:[NooLWi?og9nC
on2OSOoTXHT00_oWXXD00ooZY8;ol:Ulom6SZ002omNRW`04ombRUooQXY7o][_Nok^lf`?oZ[kX2OnY
_NP3ojZmj1KoZKgX00?o0000ojVmj?nY_NP06onY_NP5ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo0000:?ooool002Wooooo0_l0000>ooooob;oZKgX00?on[9YooJWI?ok^g`00_nY
LI<01ol005;o^Y2[ooo:P?ogdFGomK9oojEdVon3DHh00_oYZH`2ooK>GP03omFJUoomchoooLn?00;o
^H2F00_oS5fFo`00NOl/5hCo@@1Boo7;E_mjCi?o001aon2XV_ob^Y;o]J`OolI/HP02onFYTP07om_9
B_nGIYOom/6EooK1UOoh/dOon[IcoofmK002ooc4G`04on^/S?oVXHCoiZ64on^UP0;ol:Ul00Con;=e
oobiKool^FoooL5S0_oTX8L01_oWXXCojjF1onjXO_oooooolZ]kooZeLP;oh9n=00Ooi:69onNRQOoW
XXGojZB2oo2YO?oAXjSoej:O00;og::G00CohJ:Aok^lfoo0_=Ko`;cF0_nZ_^P:ojVmj003ojZmj?nY
_NSoZKgX01GoZKgX00?o0000ojVmj?nY_NP06onY_NP6ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo0000:?ooool002Kooooo1Ol0000;ooooobGoZKgX00?on[9YooJWI?ok^g`00_nY
LI<02?mC=I3o001Booo:P?oNb4WomK9oojEdVon3DHkojJV<0_ofcUh04OoncFgoeIZGoog?Soomchoo
^H2FomZ/Z?n<GIKo001iob`GQ?l0003oZWBFogY?Tol0077o0P1_oo:jT_ne[1oo`[dg00;oiJVB00[o
flU:oiMVUoof`IGom/6EooRcAooj]W?ooKe/ooc4GondZQkojjb<0_oVXH@01?o[YH3ol:Uloo>`??oh
/gD2oobiK`06oog1HooTX8Ooi:27onNRQ?o[YH7okZQn0_obZg/01?oj]G;oh9n=on2OSOoTXHT2onNR
Q@04onZTP_o`ZGcoej:OomNRW`;og::G00?ohJ:AonNTR?o0_=H00_o4^M000onZ_^SoZKgXojVmj007
ojVmj0;oZ[gX5onY_NP00ol0003oZKgXojVmj00LojVmj0Cooooo0ol00004ooooo`;o0000:Oooool0
02?ooooo0ol0000=ooooobSoZKgX00Gon[9YooJWI?ok^gcoZG6CojaeUP03oe<eT009o`000?oe/Woo
/WVDooJUG_oYZHcom/iNonf_SOoncFgoeIZG00;ooLn?00go^H2FomZ/Z?n<GIKoS5fFo`00NOoek9?o
ZWBFogY?Tol0077o0P1_oo:jT_o_df3o3bZY00;oiJVB00_oom5ooiMVUoof`IGom/6EooRcAooj]W?o
oKe/ooc4GonnGECojjb<o`00?`02on^UP003oo2YO?od[WWon;=e00;oo;U_00KooL5SonBPQooWXXCo
ij:4on^UPOo^Z7h2oo:[N`05ooZeL_oPWhgoh9n=onBQROoWXXD00_oZY8801?o`ZGcoljaiomNRWooL
XYL2on6RT@06onNTR?o4^M3oa;W@olBid?o8]<KoZ[gX2OnY_NP2ojZmj1KoZKgX00?o0000ojVmj?nY
_NP07OnY_NP5ooooo`03o`000?oooooooooo02gooooo000Qooooo`;o00003ooooolYojVmj005ooZb
JOofYfConk]lojUaTon/MIH00_mC=I001?od`YWomK9oooFbOonbNI@2onVYS004ooK>G_o][hgoo/e]
oog?S`;oY72H0_oJ[:P2ohaMUP0<o`00NOoabeKoZWBFogY?Tol0077o0P1_oo:jT_ne[1oo3bZYohIM
VooUZI;oom5o0oof`ID01ooh/dOon[IcoofmK?ola5ooQN_No`00?ooM]:h00_o[YH001?o`ZGcom:ii
ooRcMOol^Fl2oog1H`05onBPQooWXXCoij:4on^UPOo^Z7h00_obZg/01Ooj]G;oh9n=on2OSOoTXHWo
ij:500;ojZB200Col:Uloo>/NOoLXYOog::G0_oQXY400ooWY8SojJF5olBid002olRdaP;oZKgW2?nY
_NP3ojZmj1CoZKgX0_l0000PojVmj0Gooooo00?o0000ooooooooool0;?ooool001kooooo0ol0000>
ooooobcoZKgX00?on[9YooJWI?ok^g`00on/MIH01OmC=I3om<:IooFbOooe/Woo/WVD00;ojJV<00Co
G3R>onf_SOoncFgool]g0_nTL9P01Oob]XgofZbXohaMU_n<GIKo001i00;oZWBF013oNTnCo`00LOl2
06ool[ZBofa7Tol?:ZWo000/ohIMVooodGoo000;ooK1UOol`hGon;=7ooZfLoom_Fcoo<AO0_n`OI`0
1ooM]:kojjF0on^UP?o`ZGcom:iiooRcMOol^Fl00_om`F<01OoJ^SGoij:4onNRQ?o[YH7okZQn00;o
lZ]k00Gon[EbooflJOoTXHWoi:69onNRQ@02onZTPP0<oo2YO?oc[7Wog::GombRUooQXY7oi:><onNT
R?oYYHGojjF2olRda_o<[K_odJR_0_nZ_>L8ojVmj0?oZ[gX4?nY_NP3o`000003ojVmj?l0003oZKgX
01ooZKgX1_ooool00ol0003oooooooooo`0[ooooo`007Oooool3o`0000cooooo;onY_NP00ooj/VWo
mZMToo^kO003ojaeUP05oe<eT?od`YWomK9oooFbOonbNI@00_oYZH`02?mL>8kokJn=ook=KOoURUgo
DTFTonVDIoob]XgofZbX0_n<GIH04ooMXiOoZWBFojYdU_moEYSo001aoo:jT_o_df3oK4NCo`00Iomf
CYGoom5oooo?MOl000_oli];ooc3QOoh/dOon[IcoofmK?ola5l00_n`OI`01on^OIoojjF0on^UP?o`
ZGcom:iiooRcMOol^Fl00_om`F<02OoJ^SGoij:4onNRQ?o[YH7okZQnoo:[Noof/7Oon[EbooflJ@02
onBQR@05onNRQOoZY8;okJIooo2YO?oc[7T00_oLXYL01OoQXY7oi:><onNTR?oYYHGojjF200;oc:fk
00CodJR_omFUYOn/_>Go[;cU2?nY_NP2ojZmj0goZKgX0ol00005ojVmj003o`000?nY_NSoZKgX01ko
ZKgX1Oooool00ol0003oooooooooo`0[ooooo`007Oooool3o`0000Wooooo<_nY_NP00ooj/VWomZMT
oo^kO003ojaeUP04oe<eT?l0003omK9oooFbO`;o/WVD00[om/iNoe`hS_o][hgog:JMonK:C_mBAJCo
jIAWoo:fSOoXd5OoS5fF0_oMXiL2ojYdUP0?ogmFV?l0077o001ao`00OonOKISo001WogI>UOoodGoo
oooook:l>OocVd_oo<>5ooRcAooj]W?ooKe/00;olMIV00Wo/7fLojimWoo[YH3ojjF0oo2YO?od[WWo
n;=eoobiKoom`F<00_oJ^SD2onNRQ006on^UPOo^Z7kolZ]kooJ`Mooj]G;ooKaY0_oTXHT03OoWXXGo
jZB2onfVOoo`ZGcoljaiooN`M_oLXYOohJ:AonBSS?oWY8SojJF5on^UP_o]YX000_oAZ:l01?oEYJGo
[[_Sojjkhon^^n<8ojVmj003ojZmj?nY_NSoZKgX00SoZKgX0ol00009ojVmj003o`000?nY_NSoZKgX
01koZKgX1Oooool00ol0003oooooooooo`0Zooooo`005_ooool2o`0000Gooooo00Co0000oooooooo
oooo00001_ooooldojVmj003ooZbJOofYfConk]l00?o[7FF00Com<:Ionn/Pooe/Woon[Yk0_nbNI@0
1_l006WokJn=onf_SOoLYYgoomB8ojYeU`;ol[J=00coiZR?omfSUooMXiOogJ>GojYdU_nmSjKoOeJH
o`PBT_l0077okm=Poim]V?m/Ai<2ogI>U@07oc@00?nb_3Woo<>5ooc3QOoh/dOon[Icooc4G`02oo7F
IP09ok1mW?n^OIoojjF0oo:SJOo`ZGcom:iiooRcMOol^FoooL5S00;of[Xe0_oWXX@01_o[YH7okZQn
oo:[Noof/7Oon[EbooflJ@;oi:6900Koij:5onZTP_o]YWool:Uloo>/NOog/7H2on6RT@05onBSS?oW
Y8SojJF5on^UP_o]YX000_oAZ:l01OoEYJGofZBLojjkhona^n7oZKgX00;oZ[gX1?nY_NP2ojZmj0Oo
ZKgX0ol0000=ojVmj003o`000?nY_NSoZKgX01goZKgX1_ooool00ol0003oooooooooo`0Yooooo`00
5Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000000_oooolgojVm
j004ooZbJOok^gcoo/]_ook;K`;o[7FF00ooe:>Tonn/Pooe/Woon[Ykok9iU?nhOIColiY<onf_SOon
cFgool]goooDR?nZMIOol[J=ombP5ooVZ8l00ooMXiL2okf?YP;oOeJH00So21:Boim]V?nOKISoK4NC
o`00Iold003o000;of55VP;oo<>500Gon;=7ooZfLoola5oodYRGooo@M`02oo?A[@07on^UP?obXfWo
l:UlooB^NOoh/gGoo;U_oog1H`02omZj=@05onNRQ?o[YH7ojjF1onjXO_obZg/00_oj]G802Oom_6Wo
i:69onBQROoWXXGojZB2onfVOoo`ZGcoljaiooN`MP02on6RT@06onBSS?oWY8SojJF5on^UP_o]YX3o
kjQm0_oEYJD01?oJY9cogjBEok6khOnf^mh3ojZmj0CoZKgX00?oZ[gXojVmj?nY_NP00_nY_NP3o`00
013oZKgX00?o0000ojVmj?nY_NP07_nY_NP5ooooo`03o`000?oooooooooo02Wooooo000Eooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooojVmj00fojVm
j004ooZbJOok^gcoo/]_ook;K`;o[7FF00_oe:>Tonn/Pooe/Woon[Ykok9iU?nhOICo1P1co`00GOoL
YYgool]gon[;D@02ojYeU`03og58TOoVZ8oogJ>G00;ogJ>G0_nmSjH2ogmFV00>o`PBT_nOKISoWffH
ofa7Tol006OoMTjEojB8]omQAI[o002=olnJX?oj]W?ooKe/olB:V?oBV9L2ooo@M`0;oo?A[Oo[YH3o
l:Uloo2YO?od[WWon;=eoobiKoom`F?of[Xeonn`RooWXX@00_o[YH401_o^Z7kolZ]kooZeL_oj]G;o
oKaYonBQR@;oij:500GojZB2onfVOoo`ZGcoljaiooN`MP02on6RT@06onBSS?oWY8SojJF5on^UP_o]
YX3okjQm0_oEYJD01OoJY9cogjBEon>TT?nf^mko^[_J00;oZ[gX1_nY_NP3o`0001CoZKgX00?o0000
ojVmj?nY_NP07_nY_NP5ooooo`03o`000?oooooooooo02Sooooo000Eooooo`04o`000?oooooooooo
o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo03GoZKgX00Gon[9Yoo^kO?onbfooo/]_ojae
UP02omBSY0;omK9o00Oon[Ykok9iU?nhOICo^7fDo`00GOoLYYgoomB800?oZWFG00OoLDRAonJXSooo
bgCogJ>Go`001ol0003o_HnV00;oOeJH00co`XNFoim]V?nOKISoL4bGo`00IooocgGoY8Rgof55V_l0
08go001FooZfLoom_F`2om:HU`;oom1g00ooLDZCojimWoo`ZGcol:UlooB^NOoh/gGoo;U_oog1Hol;
2hOokk2;oeDDG_o[YH7omjUSonjXO_obZg/00_oj]G802oom_6Won<9DonNRQOoWXXGojZB2onfVOoo`
ZGcoljaiooN`M_oj]G7oi:><00;oijB800GojJF5on^UP_o]YX3okjQmoo6ZN`02omZTW003omnTUOoS
Y93o^[_J00;o`;_F00CoZ[gXojZmionY_NSoZKgX0ol0000HojVmj003o`000?nY_NSoZKgX01goZKgX
1_ooool00ol0003oooooooooo`0Wooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0=?nY_NP01ooj/VWonk]look;Koonbfoo[7FFomBS
Y?o_[8<00_oe/Wl01ooj^W_o^7fDokQmU?nhOICo001MombVWOooe8P00onZMIL2onJXS`05ooo;M?oM
XiOool]bomV2JOnmSjH00_moEYP03?o2QiKoWffHojEgX?m`C9Oo8RbSooo?MOo^cUSoHDFJo`00SOna
Oikon[IcoofmK0;odYRG0_ood7L2omVMU@;ol:Ul00com:iiooRcMOol^FoooL5SofQ7V?l;2hOoo/=h
on^UPOogZF?okZQnoo:[Nooj]G82ooflJ@0:ooS2E?oWXXGoij:5onZTP_o]YWool:Uloo>/NOog/7Ko
n[EaonBSS0;oijB800KojJF5on^UP_o]YX3okjQmoo6ZNooJY9`2omnTU@03on>TT?oYYhOo`;_F00;o
aK_@0ol00006ojVmj003ojZmj?nY_NSoZKgX01?oZKgX00?o0000ojVmj?nY_NP07OnY_NP5ooooo`;o
0000:?ooool001Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03;oZKgX0_oj/VT00ook^gcoo/]_ook;K`02omBSY004onn/Pooe/WoomK9oooZj
N`?o^7fD0_oLYYd01?ooe8Son;ImojYeUonkP9<2onJXS`03ooo;M?o[[Y3ool]b00;ojJfA00?oOeJH
ol:7U_o2QiH00_nUMj001?m`C9Oo8RbSob8/XonNLYl2of55VP07ok5oW_oj]W?ooKe/o`000?oBV9Oo
001oon_FHP02omVMU@;ol:Ul00com:iiooRcMOol^FoooL5SofQ7V?l;2hOoo/=hon^UPOogZF?okZQn
oo:[Nooj]G82ooflJ@0:ooS2E?oWXXGoij:5onZTP_o]YWool:Uloo>/NOog/7Kon[EaonBSS0;oijB8
00OojJF5on^UP_o]YX3okjQmoo6ZNooJY9cogjBE00;ohjB@00OojJN7o`000?l0003o0000olZjbonZ
_NOoZkgW00KoZKgX0_nZ_NPDojVmj003o`000?nY_NSoZKgX01koZKgX1Oooool00ol0003ooooooooo
o`0Vooooo`005_ooool2o`0000Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0a
ojVmj003ooZbJOok/f7onk]l00;oo/]_00?o000DomBSY?o_[8<00_oe/Wl02_oj^W_o^7fDokQmU?nh
OICo1P1combVWOooe8Son;ImojYeUonkP9<2onJXS`;ojjj@00Co0000onV]TOoY[I7ob/]<0_o2QiH2
ojEgX0;oL4bG00_o8RbSoiibWomQAI[oHDFJok5oW_oj]W?ojMm`ofUbbOood7OohZfMokF4X@02omVM
U@0>oo2YO?oj[Ekom:iiooRcMOol^FoooL5SogiPYOl;2hOoo/=hon^UPOogZF?okZQnoo:[Nooj]G82
ooflJ@0;ooS2E?oWXXGoij:5onZTP_o]YWool:Uloo>/NOog/7Kon[EaonBSS?oWY8P00_oYYHD01_o[
YH;okJJ0onnXOOoaZW_ofZBLomnTU@?o000000Cok:R4olZjboo:^/_ob[[;0_n[_NL6ojVmj003ojZm
j?nY_NSoZKgX01CoZKgX00?o0000ojVmj?nY_NP07_nY_NP5ooooo`03o`000?oooooooooo02Gooooo
000Looooo`;o00002Oooool00ol0003oooooooooo`0`ojVmj003ooZbJOok/f7onk]l00;oo/]_00Co
fIV>onRUQoo_[8?omK9o0_oj^W/3okQmU00?o`H0Loooe8SoomB8ooRfOOnZMIOo^h2ConJXSooobgCo
jjj@ooo;L_oEWigojJfAoo>X=_o:bdco`XNF00;on/nL01[oYGNPog1<Uom`C9Oo8RbSoiQYVomH>Y7o
HDFJo`00D?naOikojMm`ofUbbOn^^3CohZfMokF4XOodW4go^kPboo2YO?oj[Ekom:iiooRcMOol^Foo
oL5SogiPYOl0093o2`^7on^UP@;okZQn00?olZ]kooZeL_om_6T00_oh`U@2onNRQ@08onZTP_o]YWoo
l:Uloo>/NOog/7Kon[EaoofjJOoWY8P2onVUQ@03on^UP_o]YX3okjQm00?o000000SohjB@onNVRooY
YhOok:R4onfXP_o:^/_ockS3om>f_0;oZkgW7OnY_NP00ol0003oZKgXojVmj00MojVmj0Gooooo00?o
0000ooooooooool09Oooool001_ooooo0_l0000;ooooo`03o`000?oooooooooo02ooZKgX00Con[9Y
oo^cHOonbfooo/]_0_oIVHh00ooXYHOokjb3ooFbO`02ooZjN`04ooo6LonhOICo^7fDohQUY0;oomB8
00con;Imok^0TonkP9?o301iooo;M?o[[Y3ool]bomFOWOocZ3Ko:aR6omRKUOo2QiH2oo[?W005ojEg
X?m`C9OoL4bGojQcUonHJI/00_mH>Y42o`00D009o`009?mYL/WoooooooooooneQ:7ooooook^h<_o`
ZGcom:ii00;on;=e00Koo;U_on[6/?mnH:GoOV2Uo`00T?o[YH42onjXOP03oo:[Nooj]G;ooKaY00;o
n<9D00[oij:5onZTP_oZY8;okJIooo2YO?oc[7Womk1fooZeLOom^VWoijB80_oYYHD3o`00000<oo6Z
NooOY9GogjBEon>TT?oWYX_ojJN7onbXQ?o]Z8;okjUoolnh`ooC][cof;>d0_n[_NLLojVmj003o`00
0?nY_NSoZKgX01koZKgX1Oooool00ol0003oooooooooo`0Tooooo`006oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02koZKgX00Gon[9Yoo^cHOonbfooo/]_omVISP02onRUQ`03onn/
Pooe/Woon[Yk00;oolIc0_nhOI@01?n8IJCoomB8ooRfOOoh]Wd2ok^0T`06o``0NOmH=hoojjj@onVB
H_oobGSokLU@0_oHViD02?o2QiKon/nLoo[?W?nUMj3oL4bGojQcUoo=UI_oV6VK0_mH>Y401Ol005Co
cZJ_o`000?mYL/Wo001F00;o]HBQ00CoooooomZOU_o`ZGcom:ii0_oh/gD01_ol^Fooj/J`ogiPYOmn
H:Go/WfIon^UP@;okZQn00?olZ]kooZeL_om_6T00_oh`U@02_l000?ojZB2onZTP_ogZVCol:Uloo>/
NOog/7Kon[EaoofjJOoWY8P2o`000004on^UP_o]YX3okjQmoo6ZN`;ogjBE00KohjB@onNVRooYYhOo
k:R4onfXP_o_ZGl2om>f_003omRc]?oK/:co[;gV01goZKgX00?o0000ojVmj?nY_NP07_nY_NP5oooo
o`03o`000?oooooooooo02?ooooo000Kooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0;OnY_NP01Ooj/VWonk]look;KoonbfoofIV>00;oj:F700?okjb3ooFbOooj^W/00_ooaW<01?nh
OICobI:KohQUY?ooe8P2ooRfO@;o^h2C00Ko301ion^^T?o[[Y3ojI9Rooo9N?nVLiT2omRKU@03oo_1
Pon_/bco]gjE00;oiJRC00GoZ7>GolfEVonHJI_oV6VKoePjT@02o`lFTP0GoiU]W_lj9Xko0016okF4
XOondWCoo]9fom;7A_oJWiKom:iiooRcMOol^FoooL5Son[6/?mnH:Gojk>Gok9mVOoBPG?okZQnoo^_
F?obZg_on[EbooflJOoh`U@00_l000<2onZTPP;ol:Ul00?oljaiooN`M_l000000_l000001ooYYHGo
jjF2on^UP_o]YX3okjQmoo6ZNoof[gD00_oSY9001_oWYX_ojJN7onbXQ?o]Z8;okjUooo2ZOP;of;>d
00?ofk2/omj^YOn]_NH07OnY_NP00ol0003oZKgXojVmj00MojVmj0Gooooo00?o0000ooooooooool0
8oooool001_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ojVmj005ooZbJOok
^gcoo/]_ojVmj?oIVHh00_oXYHL2ooFbO`07ooZjNoooaW?oolIcokQmU?o9TY_oR6FToooDR002ooRf
O@;o^h2C00Oo301ion^^T?o[[Y3oeInMooo9N?nVLiWocWQZ00;onl6300Ko[k</okMnUOoUZ9?oiJRC
ojQcUoo=UI/2oiQYV`;oF3ZA00kojMm`oiU]W_nIKIko0016ooooooondWCoo]9fom?:BooodGOom:ii
ooRcMOol^FoooL5Soo3AG@;ojk>G00[o/WfIom2JWOo^Z7konjmHoo:[Nooj]G;ooKaYooS2E?oA^S;o
00030_oZY8802?o`ZGco0000o`000?l0003on[EaoofjJOoWY8SojJF50_o[YH801?o]YX3okjQmoo6Z
Noof[gD2on>TT007onNVRooYYhOok:R4onfXP_o_ZGool:YnomRc]002om^`[003omj^YOn^_NGo[[gU
01goZKgX00?o0000ojVmj?nY_NP07OnY_NP5ooooo`03o`000?oooooooooo02;ooooo000Kooooo`;o
00003oooool00ol0003oooooooooo`0[ojVmj007ooZbJOok^gcoo/]_ojVmj?oIVHkoj:F7onn/P`02
ooFbO`07ooZjNoooaW?oolIcokQmU?o9TY_oomB8oogNV`02ooRfO@;o^h2C00Go0@1eo``0NOo[[Y3o
eInMooo9N002ojIcV@;onl6300ColkJ9okMnUOoUZ9?oiJRC0_o=UI/2oiQYV`;oF3ZA00ko000ToiU]
W_nIKIko0016o`00E_ondWCoo]9fo`000?oNZZ3om:iiooRcMOol^FoooL5Soo3AG@;ojk>G00[o/WfI
om2JWOo^Z7konjmHoo:[Nooj]G;ooKaYooS2E?moGJ7om;R:0ol000001oo`ZGcoljaiooN`M_oj]G7o
oKYYooc0FooYYHD00_o[YH801?o]YX3okjQmoo6ZNoof[gD2on>TT006onNVRooYYhOok:R4onfXP_o_
ZGool:Yn0_oK/:`2omj^Y@03onF]V?n`_NCo/;gT01coZKgX00?o0000ojVmj?nY_NP07_nY_NP5oooo
o`03o`000?oooooooooo027ooooo000Kooooo`03o`000?oooooooooo00oooooo0_l000000ooooooo
ZKgXojVmj00XojVmj007ooZbJOok^gcoo/]_ojVmj?oIVHkoj:F7onn/P`02ooFbO`03ooZjNoooaW?o
olIc00;obI:K00CooMjKoo>`POoh]Wgon;Im0_nkP9<01Ol107Go301iooo;L_oEWigoolUh00;oYW>I
00?onl63okEoVOoc]XT00ooUZ9<2olfEV`;oV6VK00?oF3ZAok:^eOnZMYX00_nIKIh02ol007Co/HV/
ookBM?oZe;oo62n[oi1YX_od[WWon;=eoobiKoom`F?oo<F600;ojk>G0_o@VYd01Oo^Z7kolZ]koo:[
Nooj]G;ooKaY00?o000000[ojZB2onfVOoo`ZGconZmKoo>/NOog/7Kon[EaoofjJOol`5_ojJF50_o[
YH801?o]YX3okjQmoo6ZNoof[gD2on>TT0;ojJN700_ok:R4onfXP_o_ZGool:Ynoo:[N_oK/:cogZjU
on:]W_oU[ISoijfCok:mh`09ojVmj0;oZ[gX4_nY_NP00ol0003oZKgXojVmj00MojVmj0Gooooo00?o
0000ooooooooool08Oooool001[ooooo00?o0000ooooooooool04_ooool00ol0003oooooojVmj00X
ojVmj008ooZbJOok^gcoZKgXojVmj?oIVHkoj:F7onn/Pooe/Wl2ooZjN`;oolIc0_o9TY/02?omgY_o
lk21ooRfOOol_WWo^h2ColR=U?l107Go301i0_oEWid00olJ04CoYW>Iokj3U002okEoV@04oo>fROoU
Z9?oiJRConFXT`;ocIFK00Go]WbEoiBUhOnDYN7o/ZkEojYfVP02oiU]WP0;ocXVS_naRJco/HV/o`00
3OlH;j_oT6VRooB^NOoh/gGoo;U_oo:G@_olaHH00_o[/iL2om2JW@03onjXO_obZg_o000000;o0000
00kon<9Doia/V_od^8[ojZB2onfVOoo`ZGconZmKoo>/NOog/7Kon[EaoofjJOol`5_ojJF5on^UPP;o
kJJ000GokjQmoo6ZNoof[gGonK=aonNVR`02onVWQ`05onbXQ?o]Z8;okjUooo2ZO_obZgX00_oN[ZD0
1OoR[IkoiJfHonN]TooZ[Hoo];gQ00SoZKgX00?oZ[gXojVmj?nY_NP04_nY_NP00ol0003oZKgXojVm
j00MojVmj0Cooooo0_l0000Rooooo`006_ooool3o`0001?ooooo00?o0000oooooonY_NP09onY_NP0
2?oj/VWoo/]_ojVmj?nY_NSofIV>onRUQoo_[8?omK9o0_oj^W/2ooo6L`07olVBVoomgY_ooMjKoo>`
POoh]Wgoo;iiok^0T`02olR=U006o`40MOoEWigoolUhomc4@onVLiWo_X>D0_neOiT01_oc]XWoiJRC
onFXTooPRfco0000olfEV`;o]WbE0_oPY9@03?nZMY[oRfJSoh]VXolj9Xko0016ookBM_nDKJ?o62n[
ok1J0?n@JJ;on;=eoobiK`;oo<F600?ooooook^4VOnkQ9T00ol000001?obZg_on[EbooflJOoh`U@2
oia/VP03onZTP_o]YWool:Ul00;oljai00Komk1fooZeLOom^VWoo<1KonVUQOo[YH82onfVP006onnX
OOoaZW_omZmeooVcLOoWYX_ojJN70_o/Z8@02_o]Z8;okjUooo2ZO_obZg[oljaiomj^YOoR[IkoiJfH
onN]TooZ[Hl2okNmgPKoZKgX0onZ_NPDojVmj003o`000?nY_NSoZKgX01goZKgX1Oooool00ol0003o
ooooooooo`0Oooooo`006_ooool00ol0003oooooooooo`0Dooooo`03o`000?ooooooZKgX02KoZKgX
00Con[9Yook;KonY_NSoZKgX0_oXYHL02?o_[8?omK9oooZjNooj^W_oolIcol6i<_o9TY_ooMjK0_oc
/8400ooh]Wgoo;iiok^0T`02olR=U005o`40MOoEWigoolUhooNeO_nVLiT00_nnPi@01ooooooolkJ9
ooNkQooUZ9?o0000ooR[AOoleW@00_nfO9D2on2TU00>ojYfV_n;IZ?oRfJSoe<oW?l007Coj]BooiA]
Xol?2HCo/5X0oi1YX_oh/gGoo;U_ooc5Q_ncR:L3o`000007om2JWOo^Z7kolZ]koo:[Nooj]G;ooKaY
ooS2E002oia/VP03oia@LOo]YWool:Ul00;oljai00Komk1fooZeLOom^VWoo<1KonVUQOo[YH82onfV
P006onnXOOoaZW_omZmeooVcLOoWYX_ojJN70_o/Z8@01_o]Z8;okjUooo2ZO_obZg[oljaion:]WP;o
iJfH00?oijfConZ]Sonk_M`00_nk_M`6ojVmj003ojZmj?nY_NSoZKgX01?oZKgX00?o0000ojVmj?nY
_NP07OnY_NP5ooooo`03o`000?oooooooooo01oooooo0005ooooo`Go00000oooool2o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooonY_NP09OnY_NP01?oj/VWoZKgX
ojVmj?nY_NP2onRUQ`08onn/Pooe/Woon[YkooZjNoooaW?oci2BolVBVoo]ZX@2oo>`P@03ooRfOOol
_WWo^h2C00;ob8fD00Co0@1eomFOWOoobGSomkEn0onnPi@2oo>fR@04ooNkQooUZ9?o0000on^]SP;o
o=Id00Go]WbEon2TU?oPY9CoZWJJolfKX`02oh]VX`07oe<oW?mI24SoWg6No`l9Q?n`FP3onlR>oo>o
V003o`000009ooO3Tol001Comkf;ooNmRol001kolZ]kooJ`Mooj]G;ooKaY00?oW6bJ00?oGdFLonfV
Ooo`ZG`00_oc[7T01_og/7Kon[EaoofjJOol`5_ojJF5on^UPP;okJJ000KokjQmoo6ZNoof[gGonK=a
onNVRooYYhL2onbXQ006onfXP_o_ZGool:Ynoo:[N_oc[7Wom:eh0_oU[IP01?oW[I?ojZf?onf]ROnk
_M`2oknnfAcoZKgX00?o0000ojVmj?nY_NP07OnY_NP5ooooo`03o`000?oooooooooo01kooooo0006
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?nY_NP01?ok^gco
ZKgXojVmj?nY_NP2onRUQ`03onn/Pooe/Woon[Yk00;oolIc00Coci2BonFRROo]ZXColk210_oh]Wd0
2?ol_WWob8fDolR=U?o8SICo0@1eomFOWOoobGSomkEn0onnPi@01_oc]XWooLeZooNkQoombfWooooo
on^]SP;oo=Id00?o]WbEon2TU?oPY9@00_o=Vj<2oh]VX`04oe<oW?nOLIkoWg6NoiA]X`?o000000go
n]9[oo3DHOl0003oml>Cokj?YOog_H_oiYLHon:WUOobZg_om[1gooZeL_om_6Wog:>I00;oW6bJ00?o
GdFLonfVOoo`ZG`00_oc[7T01oog/7Kon[Eaooc0Fool`5_ofKL`on^UP_o]YX000_o_Z7d01_oaZW_o
mZmeooVcLOok]fgojJN7onbXQ0;okJR200KokjUooo2ZO_obZg[oljaiooB]N?oU[IP2onN]T`06onZ]
Soo][HWokjf6oknnfOo3_mKoal3C7?nY_NP00ol0003oZKgXojVmj00LojVmj0Gooooo00?o0000oooo
ooooool07_ooool000Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0S
ojVmj004oo^kO?nY_NSoZKgXojVmj0;oj:F70_oe/Wl01ooj^W_oolIcol6i<_o?T9;oiJ:9onfZQ?oc
/8400_oh]Wd02?ol_WWob8fDolR=U?o8SICoHdfRooo9N?oneIComkEn0onnPi@02Ooc]XWo/WnLooNk
Qoo^V63oolYdon^]S_ohZdGoo=IdokIlU@02on2TU0;ocI^S0_n;IZ<02_mC?ico0000o`000?l0003o
3`V4oeI3Wooc_iSon<fNoo3DHOn[`482ooooo`08ooNmRooRYiGoolb1oo:[Noof/7Oon[EbooflJOoL
XiT2oia/VP04oe94Xoo]YWool:Uloo>/N@;omk1f00Kon[Eaooc0Fool`5_ofKL`on^UP_o]YX02onnX
O@06oo6ZNoof[gGonK=aoo^gKOoYYhOok:R40_o]Z8801_o_ZGool:Ynoo:[N_oc[7Wom:ehonF]V0;o
ijfC00Sok:f<onf]ROo_[HKol:f4ol>oe_o7`=?obl7@ojZmj0OoZKgX00?oZ[gXojVmj?nY_NP04OnY
_NP00ol0003oZKgXojVmj00LojVmj0Gooooo00?o0000ooooooooool07Oooool000Sooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
oooo0ol0000Iooooo`03o`000?oooooooooo02KoZKgX0_oXYHL2ooFbO`07ooZjNoooaW?oci2Boln@
T_oUXXWokJZ4oo>`P@02ooRfO@04oobnNOo8SICob8fDolR=U0;oHdfR00goo]FDooNeO_nnPiCo_X>D
ol^>Tol207Ko/WnLooNkQoo^V63oolYdoocFM?ohZdGo`XZI00?oh:BD0_o=Vj<3o`0000;oWg6N00go
Ne^Qo`l9Q?oc_iSon]9[ooS=W_o3Ykco`D/0okj?YOooooooi[BQon:WUOooc87olZ]k00;on[Eb00So
n<9DombSVOnLK9[o`Y2Roe94Xoo]YWool:Uloo>/N@;omk1f00Kon[Eaooc0FooI]c3ofKL`on^UP_o]
YX02onnXO@06oo6ZNoof[gGonK=aoo^gKOoYYhOok:R40_o]Z8804Oo_ZGool:Ynoo:[N_oc[7Wom:eh
ooF^M_oW[I?ojZf?onb]S?o][HWokjf6oo2]Q?oa[X7oal3Col_1d?o?`LkoZ[gX00GoZKgX00?oZ[kX
ojVmj?nY_NP04_nY_NP00ol0003oZKgXojVmj00MojVmj0Gooooo00?o0000ooooooooool07?ooool0
00Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02GoZKgX
00Koj:F7ooR`KOoe/WoomK9oooZjNoooaW<2oln@TP03onFRROo]ZXColk2100;on;Im00Koo;iiolR=
U?o8SICob8fDon2XVOmSCJ82ooNeOP;o_X>D00OobhjCo`80M_nbOicomk^7onjfU_oobWCoo=Id00;o
`XZI0_oPY9@01?na]c7o0000o`000?o]/I02ol^@UP;oWg6N01OoNe^Qo`l9Q?m?@J;oCd6Roo3DHOo3
Ykco001:okj?YOomc8_oi[BQooo@POooc87olZ]kooZeL_om_6Won<9DombSVOnLK9[o`Y2Roe94Xoo]
YWool:Uloo>/N@02ooN`MP0>ooZeLOol`5_ofKL`omVg<?o[YH;okJJ0onnXOOoj[EkolJYkooJ_MOoi
/g7onkM]onVWQoo/Z8@2onfXPP0>onnYOoo`ZWkolZ]joo>/NOod[GSomJifonN]TooZ[Hook:f<onf]
ROo_[HKol:f4oo6^POo;`M02olo1cP;oZ[gX1?nY_NP2ojZnj1CoZKgX00?o0000ojVmj?nY_NP07?nY
_NP5ooooo`03o`000?oooooooooo01cooooo0005ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0UojVmj005onn/Pooe/Woon[YkooZjNoooaW<00_o?T9800ooU
XXWokJZ4oo>`P@02ooRfO@03oobnNOombf[ob8fD00;oh:RI00koo]FDooNeO_og]Gkonk]jokj3U?o;
SY?o0P1fok9oW?og^hOok[JFooo:M?n[NYkob7=/ol::V@?o000000?ocI^SonfaT?o]/I000_o;T9H0
1onOLIko/h>Rog]KXOli;YSo3`V4ooS=W_o`e6400_o3Yk`02_l002gooLb;onJdXOood87oolb1oo:[
Nooj]G;ooKaYooS2E?oLXiT2ol:@XP08oe94Xoo]YWool:Uloo>/NOog/7Kon[EaoofjJOol`5/2omVg
<003on^UP_o]YX3okjQm00;olJYk00KomZmeooVcLOok]fgooK]VonbXQ?o]Z882onnYO`0@oo2ZO_ob
Zg[oljaiooB]N?oe[WKomZmeonZ]Soo/[HcokJf9onn]Q_o`[HColJj1oo>_OOo?`Lkod/;;omG3b0;o
Z[gW1?nY_NP00onZ_^SoZKgXojVmj00CojVmj003o`000?nY_NSoZKgX01coZKgX1Oooool00ol0003o
ooooooooo`0Kooooo`001_ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02CoZKgX00Gokjb3ooFbOooj^W_on[YkojVmj002oln@TP;o
kJZ400Kolk21ooRfOOol_WWoo;iioog;J_o8SI@2on2XV@0;ooKROoog]GkomkEnoo^kN_nnPiCobhjC
o`80M_og^hOohI5eonjfU_oobW@00ol00002on2TU0;od9>D0_o]/I02ol^@UP;o/h>R0_mkFj400oli
;YSon<fNoiacY002ogeQYP0:ol5;0?m5>Yooi[BQooo@POoWf6ConjmHooZeL_om_6Wog:>IokVg<0;o
`Y2R01Go0000oljDUoo`ZGcoljaiooN`M_oj]G7ooKYYooc0FooI]c3oNEbUon^UP_o]YX3okjQmoo6Z
Nooj[eOomZmeooVcLOok]fgooK]VonbXQ?o]Z8800_o_ZGl01oo`ZWkolZ]joo>/NOod[GSomJifooJ_
MOoZ[Hl00_o][HT02Oo_[HKol:f4oo6^POoc[ggom:mlom;2booE`lSoel;6ojZmi`03ojVmj003ojZn
j?nY_NSoZKgX01GoZKgX00?o0000ojVmj?nY_NP06?nY_NP01?nZ_NSoZKgXojVmj?nY_NP4ooooo`;o
00007?ooool001Wooooo0_l0000Nooooo`03o`000?oooooooooo02?oZKgX00Cokjb3ooFbOooj^W_o
n[Yk0_nY_NP01Oo?T9;okJZ4onfZQ?oc/87on;Im00;oo;ii00GooL]ZolR=U?oPZ9Woh:RIooKRO`02
ooNeOP05oo^kN_nnPiCobhjCo`80M_og^hL00ol000001on[NYkob7=/oo2bRooocGCoh:BDooRkQ?o@
Ti@00_o]/I02ol^@UP;o/h>R0_mkFj42ocT^V00ToiacY?mmHJKoOF6Vo`00B_m5>Yooom21ook>S?of
eV_onjmHooZeL_om_6WomKV;okVg<?l0003o`Y2RonZaUOo>U9Ool:Uloo>/NOog/7Kon[EaoofjJOol
`5_ofKL`omaY6Oo[YH;okJJ0onnXOOoaZW_onZmGooJ_MOoi/g7onkM]oofkI_o/Z8CokJR20_o_ZGl0
1oo`ZWkolZ]joo>/NOod[GSomJifooJ_MOoZ[Hl00_o][HT02_o_[HKol:f4oo6^POoc[ggom:mlooF`
N_oE`lSoel;6omW2`onZ_^P5ojVmj0?oZ[gX4_nY_NP00ol0003oZKgXojVmj00LojVmj0Gooooo00?o
0000ooooooooool06_ooool001Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0R
ojVmj004onn/Pooe/Woon[YkooZjN`;oZKgX00KoiJ:9onfZQ?o]ZXColk21ooRfOOol_WT2oog;JP;o
h:RI00?om^9oooZcJOog]Gh00_ok^gX03_o;SY?o0000o`000?l0003ok[JFooo:M?oecUkoZgZNol>9
Uoo`/X_ooledomRMU_l=03Wod9>D0_o]/I02ol^@UP06ooS4T_ncPj;oNe^Qog]KXOli;YSojNO=0_nL
Lj@08ommHJKoooooonJdXOood87oo/j<ooKFJol004oon[EbooflJOni]c3ol[N?onZaUOl0003oj[6E
oljDUoo`ZGcoljaiooN`M_oj]G7ooKYYooc0Fol004_og6TIon^UP_o]YX3okjQmoo6ZNooj[eOomZme
ooVcLOok]fgooK]VonbXQ?o]Z8;okjUo00;ol:Yn00KolZ]joo>/NOod[GSomJifooJ_MOo/[H`2onf]
R@07onn]Q_o`[HColJj1oo>_OOod[gcomK1jomO2aP02omW2``;oZ[kX1?nY_NP00onZ_NSoZ[kXojVm
j00CojVmj003o`000?nY_NSoZKgX01coZKgX1Oooool00ol0003oooooooooo`0Iooooo`006?ooool0
0ol0003oooooooooo`0Pooooo`04o`000?ooooooooooooooob3oZKgX00Cokjb3ooFbOooj^W_on[Yk
0_nY_NP01_oUXXWokJZ4oo>`POoc/87on;ImoobnN@;ooL]Z0_oPZ9T00oofhWoolk21ooNeOP03o`00
0006ol^>Tol207Ko>bR@onjfU_oobWComLiN0_o3RIL01?o`/X_ooledomRMU_oh^h@2onfaT005o`00
0?o;T9Kon<BBooS4T_ncPj800om^N<`03_o3RiWoW7>ToiacY?mmHJKo001ioa`KT_ood87oo/j<ojG3
B_n3IJSon[EbooflJOo?VIgol[N?0_oZ/ID2omSLJ00Doo2YO?oc[7Womk1fooZeLOom^VWoo<1Ko`00
8onmIFKokk:<onfVP?o_Z7golJYkooZ_Eoof[gGonK=aoo^gKOom^fKonkmJonfXP_o_ZGl2oo2ZOP07
oo:[N_oc[7Wom:ehooF^M_of[gGok:f<onf]R@02onn]QP09oo2]Q?oa[X7oljmmooB_O?oe/7[om[5h
omW2`ooMa<7ohLRo00;oZ[gX6_nY_NP00ol0003oZKgXojVmj00LojVmj0Gooooo00?o0000oooooooo
ool06?ooool001Sooooo00?o0000ooooooooool08Oooool01?l0003ooooooooooooooolOojVmj004
onn/Pooe/Woon[Ykooo6L`;oZKgX00KoiJ:9onfZQ?oc/87olk21ooRfOOol_WT2oog;JP03o`009OoP
Z9Wo000000;o00000_ok^gX2ol^>T`06obDFQ_lk:93ok[JFooo:M?oecUko`hVG0_o=T9@00ooPXaco
ooooooRkQ002onfaT007o`000?o;T9Kon<BBooS4T_ncPj;oi=[<ofihc002ol>;V@;oW7>T02?oOF6V
o`00NOlL6i;o71^Book>S?nU`d[oc4h5ooZeL_om_6WoK`P/oo:gSooodh3oj[6Eom6GV?oHg6Sol:Ul
oo>/NOog/7Kon[EaoofjJOol`5_o001oooo8M?o?[[SokJJ0onnXOOoaZW_oljahooJ_MOoi/g7onkM]
oofkI_ok_e[okJR2onnYO`02oo2ZOP07oo:[N_oc[7Wom:ehooF^M_of[gGok:f<onf]R@02onn]QP05
oo2]Q?oa[X7oljmmooB_O?oe/7X00_of/GP01?oMa<7ohLRoon77_onZ_NLJojVmj003o`000?nY_NSo
ZKgX01coZKgX1Oooool00ol0003oooooooooo`07ooooo`;o00001?ooool01?l0003ooooooooooooo
ool5o`0000;ooooo000Hooooo`03o`000?oooooooooo02;ooooo0_l00002oooooakoZKgX0_oe/Wl0
1_oj^W_oZKgXojVmj?nY_NSoiJ:9onfZQ0;olk2100?on;ImoobnNOombfX00ol000000oo_[8ComkEn
ooNeOP02oo^kNP;obhjC00KofYfDonjfU_o^]YKoolYdooFcOoo3RIL2olf@U003omRMU_oooooon;^4
00;okK6@00Gogj6Bol^@U_oha9;on<BBolR>U`02on2ST`;o`h^I00goW7>Toj=jYOmFA:3o001ioa`K
T_o9Wjgom]I[o`000?o<CPGon[EboooooooIZJKol[N?00;oom>0023odINHokQSJOo`ZGcoljaiooN`
M_oj]G7ooKYYooc0Fol007ooolQdoocFMOo]YX3okjQmoo6ZNooc[7SomZmeooVcLOok]fgooK]Voo^o
F_o]Z8;okjUooo2ZO_oaZgcolZ]joo>/NOod[GSomJifooJ_MOoh/G7okJf9onn]QP;ol:f400ColJj1
oo>_OOod[gcomK1j0_of/GP01_og/GOohLRoon77_ooOaKkoZkgWoj^nj1WoZKgX00?o0000ojVmj?nY
_NP07?nY_NP5ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00002ooooo`006?ooool2o`0002Gooooo00?o0000ooooooooool07OnY_NP00ooe
/Woon[YkooZjN`03ojVmj004onFRROo]ZXColk21ooRfO@?o000000Cofi^?onVVR?oYYXSokjb40_og
]Gh2oo^kNP08ol^>TooJWICofYfDonjfU_oobWCo[8J/ooFcOoo3RIL2olf@U007omRMU_oooooon;^4
ooBhR_ona7Wogj6Bol^@UP02ooS4TP03olR>UooPXi?oh:>C00;o`h^I0onSNZD03?m7?:7obIn]ook>
S?ofeV_oW/;bom[<booS[ioooln9omVYY_og`Y7oom>0ooooo`;odINH01kol:Uloo>/NOog/7Kon[Ea
oofjJOmoH:Co001io`@9ROl0003okJJ0onnXOOoaZW_oljahooJ_MOoi/g7onkM]oofkI_ok_e[okJR2
onnYOoo`ZWkolJ]loo:[N_oc[7Wom:ehooF^M_of[gGon;5aonf]ROo_[HH2oo2]Q004oo6^POoc[ggo
m:mlooF`NP;om[5h00Gomk5gon77_ooOaKkoglFnoj^nj002ojZnj0?oZKgX0_nZ_NPDojVmj003o`00
0?nY_NSoZKgX01_oZKgX1_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool00_ooool001Sooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0LojVmj003ooFbOooj^W_on[Yk00?oZKgX00SoiJ:9o`000?l0003o0000ooRfOOol_WWooL]Z
om^KS`;ojJJ800?okjb4ooNeO_og]Gh00_ok^gX02?o;SY?ofYfDomZMU?lU5XKoolYdooo@R_oe/goo
`hVG0_o=T9@01_oHWIKon;^4oog<JOod^8[oo/AiomnQTP;on<BB00Com=EWolR>UooPXi?oh:>C0_o3
RiT3oj=jY@;oAcbQ02_oo/j<onGGHOnJQ;[oLfbkol]i0?oochWoooooooO2TOooooooj;>LoeD0=?oA
UiSoiZnIoo>/NOog/7Kon[EaoofjJOn9NkgoVDUZoln^^?oOY9KokJJ0onnXOOoaZW_oljahooJ_MOoi
/g7onkM]oofkI_ok_e[okJR2onnYOoo`ZWkolJ]loo:[N_oc[7Wom:ehooF^M_of[gGon;5aooZcKoo_
[HKol:f400;olJj100?oljmmooB_O?oe/7X00_of/GP01oog/GOonK=como5__oQa[coiLZlojZnj?nZ
_NL06_nY_NP00ol0003oZKgXojVmj00KojVmj0Gooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo007ooooo000Hooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07?nY_NP00ooj^W_oZKgXojVmj003o`000003onfZQ?oc/87on;Im00;o
o;ii00GooL]Zom^KSooYYXSojJJ8onn/Q002ooNeOP;onk]j00SobhjComZMU?oJWICo9AJ6ojb6[?oo
d8[omK=ool>9U`;ocI2D00Ko40V3ooRkQ?omc6Wom;R:ook4NOoOXI82ooJiR@04ooCEIooPXi?oh:>C
on2ST`;o`h^I00CohJVJoj=jYOnSNZGoETBP0_m7?:404?l0003oVXBjoiZ4^_l002ooCdNYooO2TOoo
cXKooMn7onRcW?oiai?ol;B>onJ_VOoc[7Womk1fooZeLOom^VT2ohUk_@0Ho`000?oOY9Ko_h^MonnX
OOoaZW_oljahooJ_MOoi/g7onkM]oofkI_ok_e[ohKXgonnYOoo`ZWkolJ]loo:[N_oc[7Wom:ehooF^
M_of[gGon;5aooZcKoo_[HKol:f40_oa[X400ooc[ggom:mlooF`NP02ooJaN008ooNaMooi/g?on;=d
on76_?oUb[coiLbmojZmion[_^LIojVmj003o`000?nY_NSoZKgX01coZKgX1Oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002oooo
o`006?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_oZKgX0ol00002ojVmj0;o
kJZ400Colk21ooRfOOol_WWoo;ii0_oKVhl2onVVR006onn/Q?og]GkomkEnoo^kN_ooaW;obhjC0_oJ
WI@2ojb6[003ooG>G_oe/goocI2D00;ocI2D00Ko40V3ooRkQ?o2SYoom;R:ook4NOoobG42ooJiR@03
ol::V_oPXi?oh:>C00;on/R@00Go`h^Ion6YV_nSNZGo/9BjoeI4X002odLlX@0@oj]mX_nJQ;[oVXBj
o`00CooIZJKoml:Aooo>Q_omghOoN]NGooW7Too`]8koom1koo>/NOog/7Kon[Eaooc0F`;odYRI0_oO
Y9H06onoRigokjQmoo6ZNooc[7SomZmeooVcLOok]fgooK]Voo^oF_oQ^SOokjUooo2ZO_oaZgcolZ]j
oo>/NOod[GSomJifooJ_MOoh/G7on[=_onn]Q_o`[HColJj1oo:^Oooc[ggom:mlooF`NP02ooJaN009
ooNaMooi/g?on;=dooVcM?oUb[coiLbmon?:_on[_^OoZkkX01WoZKgX00?o0000ojVmj?nY_NP07?nY
_NP5ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000;ooooo000Gooooo`?o0000:Oooool00ol0003oooooooooo`0GojVmj0?o0000
1OnY_NP2onfZQ004oo>`POoh]Wgoo;iioobnN@;ofi^?0_oYYXP01_o_[8ComkEnooNeO_ok^g[oolIb
ol^>T`;ofYfD0_n/QZ`00ooe/goon;Mmolf@U002olf@U006o`00N?o2SYoo`XjOooBhR_o^WFcoolUa
0_of^HT00oo2RY[oh:>Con2ST`02oo[8T0;ohJVJ0_n`U;X01?m3BkCoAcbQonGGHOn[OJ82oiIf[P0?
og=/^omHBjSoml:AoogOQooe`YSoo/j9ooW7Too`]8koom1koo>/NOog/7Kon[Eaooc0FooibiOodYRI
00;ogjBF01_o_h^MonnXOOoaZW_oljahooJ_MOoi/g7onkM]oofkI_ok_e[ohKXgonnYOoo`ZWkolJ]l
oo:[N_oc[7Wom:ehooF^M_of[gGon;5aooZcKoo_[HKol:f4oo6^POob[WooljmmooB_O?oe/7X00_of
/GP01Oog/GOonK=cooRcM?oi/gCoiLbm00;ohlZo00?oZkkXojZmj?nY_NP06OnY_NP00ol0003oZKgX
ojVmj00KojVmj0Cooooo0_l00005ooooo`;o00002Oooool3o`0000?ooooo0004ooooo`?o00000ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05?nY
_NP2o`0000SoZKgX0_o]ZX@01?oc/87on;ImoobnNOol_WT2om^KS`03onVVR?o_[8ConK5]00;omkEn
00?onk]jooo6L_oJWI@00_oJWI@01?oc_ICo[8J/ooFcOooh]gd2olf@U0;oeINC0_o2SYl01?ona7Wo
gZRMooo9LOomcVd2ol::VP;oh:>C0_ojb902on6YVP06ooSSQOn`U;[o@d^doh?YiooMXYKoZgfR0_nF
MZh03_l[;Z7oF4^XoeQ;Z?o?Xj_omL:Hook>ROoII0goaiZYooo@Nooc[7Womk1fooZeLOol`5_onL^G
0ooOY9H01?noRigokjQmoo6ZNooc[7P2ooVcL@0Eoo^gKOom^fKonkmJon6j=oo_ZGool:Ynoo6[O?ob
Zg[oljaiooB]N?oe[WKomZmeooRaLOoj/foonkE^oo2]Q?oa[X7olZiooo>_OOod[gcomK1j00;om[5h
00Gomk5gooVcLooh/gConK=dooZeL002on?:_`03onC>`OnZ_NSoZ[gW01[oZKgX00?o0000ojVmj?nY
_NP06onY_NP5ooooo`03o`000?oooooooooo01?ooooo0005ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0@ojVmj0?o00002_nY_NP2onfZQ004oo>`POoh]Wgoo;ii
oog;JP;ofi^?00?ojJJ8onn/Q?oi/Fd00_og]Gh01?ok^g[oolIbomZMU?oJWI@2oo>mU003ooo@R_oe
/goon;Mm00;ocI2D0_oEUi<01_l004Gom;R:ook4NOol`hCoolUaooO=G`;o`XZJ00GojJZ>on2STooj
b93on/R@on6YVP02ooSSQ@0Eok2D^_o@UYSogJ:FomfRU_n[OJ;o`XjNoiIf[_l[;Z7o001?oeQ;Z?o?
Xj_oo/j9ooooooobjH[oaiZYonF_W?oc[7Womk1fooZeLOol`5_onL^G00;ogjBF00GojK:Iokn;WOo_
Z7golJYkoo>/N002ooVcL@0Eoo^gKOom^fKohKXgon6j=oo_ZGool:Ynoo6[O?obZg[oljaiooB]N?oe
[WKomZmeooRaLOoj/foonkE^oo2]Q?oa[X7olZiooo>_OOod[gcomK1j00;om[5h00Womk5gooVcLooh
/gConK=dooZeL?oj]G7ohlZoonC>`OoSd<@00_n[_^PIojVmj003o`000?nY_NSoZKgX01OoZKgX00?o
Z[kXojVmj?nY_NP00_nY_NP5ooooo`03o`000?oooooooooo01;ooooo0002ooooo`Go00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
;?ooool00ol0003oooooojVmj00<ojVmj0?o00003OnY_NP2onfZQ004oo>`POoh]Wgoo;iioog;JP;o
fi^?00?ojJJ8onn/Q?oi/Fd00_og]Gh01?ok^g[oolIbomZMU?oJWI@2oo>mU003okg3@_oe/goon;Mm
00;ocI2D0_oEUi<02Ol004Gom;R:ook4NOol`hCoolUaooO=Goo6TYoo`XZJonVZSP02oo[8T004olfC
V?oQZI[on>>5oo6dS@;od9JH0_oMXYH2ol:>WP0=oiIf[_l[;Z7o0023oeQ;Z?o?Xj_oo/j9oooHPoob
jH[o2@00onF_W?oc_IComk1fooZeL@02ooW;U`;ogjBF00GojK:Iom2HVoo_Z7golJYkoo>/N002ooVc
L@0Boo^gKOom^fKohKXgoo[4F_l404Kol:Ynoo6[O?obZg[oljaiooB]N?oe[WKomZmeooRaLOoj/foo
nkE^oo2]Q?oa[X7olZio0_od[g`03Ooe/7[om[5hooJaN?og/GOonK=cooRcM?oi/gCon[E`ooZeLOoT
c/7ohm34omo>aooNclT00_nZ_^PIojVmj003o`000?nY_NSoZKgX01GoZKgX00?oZ[kXojVmj?nY_NP0
0onY_NP5ooooo`03o`000?oooooooooo01;ooooo0002ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`;o0000;_ooool00ol0
003oooooojVmj008ojVmj0?o00004?nY_NP01_o]ZXColk21oo>`POoh]Wgoo;iiojVmj0;ofi^?00Co
jJJ8onn/Q?oc/87omkEn0_ok^gX00oooaW;ofYfDomZMU002oo>mU003oo>`POoe/goon;Mm00;ocI2D
0_oEUi<01omE?ISom;R:ook4NOol`hCon/aRooO=Goo6TYl00_oYZXh01_oi^h?o0009onf_S?oQZI[o
hjFAoo6dS@;od9JH0_oMXYH2ol:>WP08oi=d[Ol<5iKo:bjQolnSZooe`YSoo/j9oo;YR_oodhP2onF_
W008oo>mU?og/7Kon[Eaoo[6S_okj9[o_hjRomnTU_oY/YT2om2HV`03oo6ZNooc[7SonK=a00;onkM]
017ooK]Von6j=ooja5[ooM1^oo2ZO_oaZgcolZ]joo>/NOod[GSomJifooJ_MOoh/G7on[=_oo^eK_ok
]VgolJj1oo:^O`02ooB_O00?ooF`N_of/GSom[5hooNaMooi/g?on;=dooVcM?oj]G3on[Eaoo^fKool
^6goglk7omk?bOoMd/goZ[gW01[oZKgX00?o0000ojVmj?nY_NP06onY_NP5ooooo`03o`000?oooooo
oooo017ooooo0003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01?nY
_NP3o`0001?oZKgX00GokJZ4oo>`POoc/87on;ImoobnN@02ojVmj0;ojJJ800?okjb4oo>`POog]Gh0
0_ok^gX02_ooaW;o^K8XomZMU?oc_ICol:f3oo>`POoe/goon;MmoobmN_o=T9@2omFGT`07on:FNOmE
?ISogZRMooc3Q?ooc8CokLaDolJBW`02onVZSP03ooVkPooCVYWokJn<00;ohjFA00?olKB=om2FV?o@
UYP00_oMXYH2ol:>WP0@om>MWOnCM:go:bjQo`00Pooe`YSoomR3oo[=V?oodhSoiJnLo`00C_oc_ICo
mk1fooZeLOojaXkonnRJokn>XP;ojK:I0_o@V9/05ooaZW_oljahooVcLOok]fgooK]Voo^oF_oQ^SOo
n/AJoog@K_o`ZWkolJ]loo:[N_oc[7Wom:ehooF^M_of[gGon;5aooZcKook]FkonkI]oo6^POob[Woo
m:ml00;omK1j0_of/GP02oog/GOonK=cooRcM?oi/gCon[E`ooZeLOok]Vooo;Q]oo^gKooNclWogM;=
00;oZ[kX1?nY_NP2ojZmj1CoZKgX00?o0000ojVmj?nY_NP02_nY_NP00onZ_NSoZKgXojVmj008ojVm
j0;oZ[gX1?nY_NP5ooooo`03o`000?oooooooooo013ooooo0004ooooo`;o00000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`03o`0001OoZKgX0_oc/8401?oh]Wgoo;iiojVmj?nY_NP2onVVR003onn/Q?oc
/87omkEn00;onk]j0_ni/RP02?oJWIColkfDoo2]Pooc/87omK=oooRgOOol_G[ocI2D0_oEUi<02?l0
07SoECfHomjXWOol`hCooLi]ooBbP?of/goojJZ>0_oi^h<01ooCVYWokJn<on>UTOoSYI7olKB=ook=
Qoo@UYP00_oMXYH02oo2SYkodifMom>MWOnCM:go31NFo`00PooncXWogkN_oo[=V?onfH;oho2A00;o
lkfD00Gomk1fooZeLOoX/9WoXhjoon2UUP02onVbV@0IooKF[?o@V9_olJYkoo>/N?oi/g7onkM]oofk
I_ok_e[oo/I[oobnNoomd6kol:Ynoo6[O?obZg[oljaiooZ]G_oe[WKomZmeooRaLOoj/foonkE^oo^f
KOoa[X7olZioooB_O002ooF`NP;om[5h00gomk5gooVcLooh/gConK=dooZeL?oj]G7onkI_oobhKOok
]foogM;=omS@dOoDd=CoZ[kX01[oZKgX00?o0000ojVmj?nY_NP02_nY_NP00onZ_NSoZKgXojVmj00>
ojVmj0Gooooo00?o0000ooooooooool04?ooool000Gooooo00?o0000ooooooooool00_ooool2o`00
00Cooooo0_l00004ooooo`03o`000?oooooooooo033ooooo0ol000000oooooooZKgXojVmj00GojVm
j004oo>`POoh]Wgoo;iioobnN@;oZKgX0_oYYXP01oo_[8ComkEnooNeO_ok^g[oolIbodH_TOoUY8/0
0_oc_I@01Oo`[H?omK=oooFcOooh]ggoo;ej00?oeINC00co6Q25oeDmV?oNZ9goo<>4oog>KOod/X3o
m[=oonVZS_oi^h?oolaaom>JVOo][h`2on>UT@06oo6dSOoncHOogJ:FomfRU_oY/9Oo`XjN0_oCWId0
4?nCN[?o31NFoga/]OmlK;GogkN_oooCR?onfH;oo]n@ookMT_olc8ooa:FjooZeLOoX/9Wog;:/ojPe
;?oPYIH2ooKF[00JomfVW?oaZW_oljahooVcLOok]fgooK]Voo^oF_onaV_oo<fCook=R?o`ZWkolJ]l
oo:[N_oc[7Wom:ehooF^M_of[gGon;5aooZcKook]FkonkI]oobgK?ob[Woom:mlooF`N_of/GT2ooJa
N00?ooNaMooi/g?on;=dooVcM?oj]G3on[Eaoo^fKool^6gonkM_oofjJoom^fgoe=3Dom7@f?nY_NSo
Z[gX01WoZKgX00?o0000ojVmj?nY_NP06onY_NP5ooooo`03o`000?oooooooooo00oooooo000Foooo
o`03o`000?oooooooooo02gooooo0ol00002ooooo`03o`000?oooooooooo01SoZKgX00?olk21ooRf
OOol_WT00onY_NP2onVVR00:onn/Q?og]GkomkEnoo^kN_ooaW;odiJDonFTRoo/ZHKol:f3ooVaK`;o
mK=o00?on;MmoobmN_oEUi<00_oEUi<03?lJ48GogZRMomjXWOoobG7ooLi]ooBbP?of/goodYRIooVk
PooHVPoodiZIonf_S0;ohjFA0_oncHL2omfRUP0>onV`Uoo2SYkodifMom>MWOoT/IooTgZco``GU_ml
K;GogkN_oooCR?ojhH?oo]fBoogIV_o4YKX2on2_X`03onR`VOo`]i;ok;^O00;ok[:>01_om;V:omfV
W?oaZW_oljahooVcLOok]fgooK]Voo^oF_onaV_oo<fCooo=PonnKWColJ]loo:[N_oc[7Wom:ehooF^
M_of[gGon;5aooZcKook]FkonkI]oobgK?ob[Woom:mlooF`N_of/GT00_of/GP03?og/GOonK=cooRc
M?oi/gCon[E`ooZeLOok]Vooo;Q]oo^gKoom^V_ooK]]om7@f0;oc<kK00?oZ[gXojVmj?nY_NP00onY
_NP00onZ_^SoZKgXojVmj009ojVmj003ojVnj?nY_NSoZKgX00KoZKgX00?o0000ojVmj?nY_^P06onY
_NP4ooooo`;o00004?ooool001Kooooo0_l0000[ooooo`?o00001_ooool00ol0003oooooooooo`0G
ojVmj003oo>`POoh]Wgoo;ii00?oZKgX0_oYYXP02_o_[8ComkEnooNeO_ok^g[oolIbom>FU?oUY8_o
k:V6oo2]Pooi/Fl2ooFcO`0CooRgOOol_G[oeINComFGTooNXI?o6Q25omjXWOol`hCoolUaooO=Good
/X3om[=oom:HVOoi^h?odiZIom^OU?o][hcoo<1moo6dS@02ook=Q`;ogJ:F00?ojK2Gom>MWOoCWId0
0_oT/Il01onCN[?o6BRSomng[oojcISoo]V2ookOT?ongI800_oidj<01OoP[j?oj;2Ioo6D>?oooooo
nL6<00;ok[:>0_oe^h`06OoaZW_oljahooVcLOok]fgooK]Voo^oF_oVP3goo<fCooo=PooncHSolJ]l
oo:[N_oc[7Wom:ehooF^M_of[gGon;5aooZcKook]FkonkI]oobgK?ob[Woom:mlooF`N_of/GT00_of
/GP03_og/GOonK=cooRcM?oi/gCon[E`ooZeLOok]Vooo;Q]oo^gKoom^V_ooK]]oojmK?o<c]_oalgO
4OnY_NP00onY_^SoZKgXojVmj007ojVmj003o`000?nY_NSoZKgX01_oZKgX1Oooool00ol0003ooooo
ooooo`0>ooooo`005_ooool00ol0003oooooooooo`0Wooooo`?o00002_ooool2o`000003oooooonY
_NSoZKgX01GoZKgX00?on;ImojVmj?nY_NP00_nY_NP2onVVR00:onn/Q?og]GkomkEnoo^kN_ooaW;o
diJDonFTRoo/ZHKol:f3oo>`P@;omK=o0_ol_GX2omFGT`0?omjQTolJ48Go6Q25ooc3Q?ooc8ComleO
ooBbP?of/goodYRIomRLU_oCVYWofinDoooooool`7golKB=00;oo/f70_oMXYH00ooY/9OodifMom>M
W@02onBaW`0@oiF9aOmUKlWoIFo9oooCR?ogh[;oo]n@ookMT_oidj?ollnZon2_XooX/9Wol;NBoooo
ooolah_ok[:>ooBiRP;omK^<00KolJYkoo>/N?oi/g7onkM]oofkI_ok_eX2ooc=T`0Aooo=Poo`h[oo
lJ]loo:[N_oc[7Wom:ehooF^M_of[gGon;5aooZcKook]FkonkI]oobgK?ol^F_om:mlooF`N_of/GT0
0_of/GP03_og/GOonK=cooRcM?oi/gCon[E`ooZeLOok]Vooo;Q]oo^gKoom^V_ooK]]oojmK?on_fgo
`/[Q0_nmb><6ojVmj003ojZmj?nZ_^SoZ[kX017oZKgX00?o0000ojVmj?nY_NP06onY_NP5ooooo`03
o`000?oooooooooo00gooooo000Fooooo`03o`000?oooooooooo02Cooooo0ol0000?ooooo`03o`00
0?ooooooZKgX01[oZKgX00?ojJJ8ooR`Koo_[8@00_og]Gh02Ook^g[o^K8Xom>FU?oUY8_ok:V6oo2]
Pooc/87omK=oooRgO@02oobmNP;oeINC00GogZ6CogiPY_mnH:Koo<>4ooo<Q002ooBbP00?ooJcOooB
V9Wof9bFom^OU?o][hcoooooooc0OOoIXigoo/f7ooVkPooBVIWogJ:FonV`UoojdIcodifM00;oi;6O
0_nERLD05_mUKlWoc/OCooOR/_ongI;oe_[QomO]hooAknSob>O/onR`VOo`]i;onL6<ooc7RooZ]9[o
m;V:ooFkS?od_I;ojKNPoo>/N?oi/g7onkM]oofkI_ok_eX2oe6Yn@0AonGae?o`h[oolJ]loo:[N_oc
[7Wom:ehooF^M_of[gGon;5aooZcKook]FkonkI]oobgK?ol^F_om:mlooF`N_of/GT00_of/GP04?og
/GOonK=cooRcM?oi/gCon[E`ooZeLOok]Vooo;Q]oo^gKoom^V_ooK]]oojmK?on_fgoo/=aokg8honi
anD6ojVmj003ojZmj?nZ_^SoZKgX00SoZKgX0_nY_^P8ojVmj003o`000?nY_NSoZKgX01OoZKgX00Co
Z[gXojVmj?nY_NSoZKgX0oooool3o`0000kooooo000Eooooo`03o`000?oooooooooo02;ooooo0ol0
000Cooooo`03o`000?ooooooZKgX01[oZKgX0_o_[8@2ooNeOP09oo^kN_nY_NSodiJDonFTRoo/ZHKo
l:f3oo>`POoe/goon;Mm00;oo;ej00?oolMaomFGTooNXI<00omnH:H01?ooc8Com;:0ooBbP?of/gl2
omRLUP08om^OU?o][hcomkR3ooo;MOoIXigomKR7ooVkPooBVIT2onV`U`05oo[AW?oT/Iooi;6OooOA
Y_nERLD00_nH[nP02_ogh[;ooN:IomZe/ooJ]K?ohkZ]onW0Z_o8incoj;2Ioo2gT_oi`H`2oo>mU@0:
onbfVOoe^hcom;fBooBmT_oc[7SonK=aoo^gKOom^fKonkmJoo_3QP;o8jSS013omM^boo6[O?obZg[o
ljaiooB]N?oe[WKomZmeooRaLOoj/foonkE^oo^fKOol]fcoo;U[ooB_O?oe/7[om[5i0_of/GP04Oog
/GOonK=cooRcM?oi/gCon[E`ooZeLOok]Vooo;Q]oo^gKoom^V_ooK]]oojmK?on_fgoo/=aooo6L_ni
anGo]LCU00GoZKgX00?oZ[kXojVmj?nY_NP00_nZ_^PAojVmj003o`000?nY_NSoZKgX01KoZKgX00Co
ZKkXoooooooooooooooo0ol00002ooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00008Ooo
ool2o`0001Oooooo00?o0000ooooooooool06OnY_NP2onn/Q0;omkEn00Wonk]jojVmj?oCUYCoiJB;
onbYQ_o`[H?olk21ooFcOooh]gd00_ol_GX02?ooag7oeINComjQToo[/ICoOV2VonFeY?omcVgom;:0
0_of/gl2omRLUP09om^OU?o][hcomkR3ooo;MOoIXigomKR7ooVkPooooooojK2G00;on]6L0_oT/Il0
2?ogdJKoco2CoiR_j?n3hO[ojjnAonjbT?oa]HkohkZ]0_oY`:X08_o_b:co_[gIoo2gT_oi`HcolkfE
onbcUoo/]YWom/:EooBmT_ohb9SoljahooVcLOok]fgooK]Voo^oF_oi`XcokKBDooNnS?oocG_oEYO`
oo:[N_oc[7Wom:ehooF^M_of[gGon;5aooZcKook]FkonkI]oobgK?ol^F_om:mlooF`N_of/GT2ooJa
N00BooRbM?oi/g?on;=dooVcM?oj]G3on[Eaoo^fKool^6gonkM_oofjJoom^fgoo[e/oojoKOon`g7o
olIbooo8NOnea>Go/l?V1onY_NP00onZ_^SoZKgXojVmj00@ojVmj003o`000?nY_NSoZKgX01?oZKgX
00CoZ[kXoooooooooooooooo0ol00005ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`00
0?oooooooooo01gooooo0ol0000Jooooo`03o`000?oooooooooo01SoZKgX00Kokjb4ojVmj?og]Gko
mkEnoo^kN_nY_NP2onFTR`05onbYQ_o`[H?olk21ooFcOooh]gd00_ol_GX02?ooag7ogZ6ComjQToo[
/ICoOV2VonFeY?omcVgom;:00_of/gl2omRLUP09om^OU?o][hcomkR3ooF/M?oIXigomKR7ooVkPook
_X3oiJR@00;on]6L00Com[R6onBaWoogdJKoi:ZG0_oX[I<02?o[[i7ok[:@oo6eS_oS^ZgojL2Zonc4
Z_o_b:com=>^0_oi`H`07_oc_IGok;>Goo>lT_of`YGonLRDooS8V?oc[7SonK=aoo^gKOom^fKonkmJ
ooW2S?o]]9Comkj<ooo=NooooooolZ]joo>/NOod[GSomJifooJ_MOoh/G7on[=_oo^eK_ok]Vgoo;M/
oobiJood[gcomK1jooJaN@;om[5h01;on;9dooVcLooooooonK=dooZeL?oj]G7onkI_oobhKOok]foo
oKY[oofkKOon_Fcoo[m]ook3LOooaW;oolQiok?3i_n``NH6ojVmj0;oZ[kX2OnY_NP00onY_^SoZKgX
ojVmj007ojVmj003o`000?nY_NSoZKgX013oZKgX0_ooool4o`0000Sooooo00?o0000ooooooooool0
3?ooool001Gooooo00?o0000ooooooooool06_ooool3o`0001kooooo00?o0000ooooooooool05onY
_NP01_o_[8ConK5]ooNeO_og]Gkonk]jojVmj0;oiJB;00Kok:V6oo2]Pooc/87omK=oooRgOOol_GX2
ooo7L@;ogZ6C00Gojk6DogiPY_ooc8Colk21ooBbP002ooJcO`;of9bF00oofinDomnRToog^8?omJad
ooF]M?oe^8OonK^3oo^nP?o`XFcokZn;oo>dR?of^8Kon;f7oo_5R?oTZYL00_oX[I<0:?o[[i7ok[:@
oo6eS_ob]hgojL2Zonc4Z_o_b:com=>^okPn0?olah_o02fYonbcUooc_9;onlR>oo:nV?o`_Y_oljah
ooVcLOok]fgooK]Voo^oF_oi`XcokKBDooooooojb97on<RGoo:[N_oc[7Wom:ehooF^M_og/7?on;5a
ooZcKook]FkonkI]oobgK?ol^F_oo[i[ooF`N_of/GT2ooJaN00CooRbM?oi/g?on;=dooVcM?oj]G3o
n[Eaoo^fKool^6gonkM_oofjJoom^fgoo[e/oojoKOon`g7oolIbooo8NOood8?ooM2Bojo1i`05ojVm
j003ojVnj?nY_NSoZKgX01?oZKgX00?o0000ojVmj?nY_NP03?nY_NP2ooooo`?o00003?ooool00ol0
003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0Gooooo`?o00008_ooool00ol0003o
ooooooooo`0FojVmj006onn/Q?oc/87omkEnooNeO_ooaW;oZKgX0_oUY8/01_o/ZHKol:f3oo>`POoe
/goon;MmoobmNP;oolMa0_oNXI<01Oo[/ICoo]B?ooo<Q?oc/87om;:000;om[=o00[on;MnomRLU_oK
WiCogj:Co`00M_oIXigok[:?ooFhQooi^h?onkj00_o^[h/01_oc]8Som[R6ooRmQookaHSoomB;onR]
T`;ojjnA00Cok[:@oo6eS_ob]hgom;V<0_o_b:`02?oddjkom=jfokPn0?ni]=Cok;>Goo>lT_okb8ko
l[jH0_oY]Yh01?oi/g7onkM]oofkI_ok`hH2onfdU00Aooo=Noojb97on<RGoo:[N_oc[7Wom:ehooF^
M_og/7?on;5aooZcKook]FkonkI]oobgK?ol^F_oo[i[ooF`N_of/GT00_of/GP04_oh/WConK=cooRc
M?oi/gCon[E`ooZeLOok]Vooo;Q]oo^gKoom^V_ooK]]oojmK?on_fgoo/=aooo6L_oob7Woom23oog@
TP;o[[oW1onY_NP00onZ_^SoZKgXojVmj00AojVmj005o`000?nY_NSoZKgXojVmj?nY_^P01_nY_NP0
0ooooooo0000o`000002o`00013ooooo00?o0000ooooooooool02oooool001Gooooo00?o0000oooo
ooooool05?ooool3o`0002Kooooo00?o0000oooooonY_NP05OnY_NP01?o_[8Colk21ooNeO_ok^gX2
ojVmj0;oiJB;00Kok:V6oo2]Pooc/87omK=oooRgOOol_GX2ooo7L@0:omjQToo[/ICojk6DookDSol0
003olk21ooBbP?of/goomkEnooRgOP;ofinD00Oogj:Co`00GOoIXigomJedooFhQooi^h?onkj000;o
kZn;00KolkB8ooRmQooh_HOonlF8oooDRooX[I<2on^_T@;olKF>00Gol[N=ooBiS?oe^hcom=>^ooCN
]P02onKRc`04okBUb?nF8@3olkbBoo:nV0;oiZjI00GolKnKooVcLOok]fgooK]Vogb1c@02onfdU00A
ooo=Nooooooon<RGoo:[N_oc[7Wom:ehooF^M_og/7?on;5aooZcKook]FkonkI]oobgK?ol^F_oo[i[
ooF`N_of/GT00_of/GP05Ooh/WConK=cooRcM?oi/gCon[E`ooZeLOok]Vooo;Q]oo^gKoom^V_ooK]]
oojmK?on_fgoo/=aooo6L_oobh3oom23oog@T_ojf:?o[KoWojg0j005ojVmj003ojZnj?nY_NSoZKgX
01;oZKgX00Co0000ojVmj?nY_NSoZKkX1?nY_NP01?oooooo0000o`000?l0000Dooooo`03o`000?oo
oooooooo00_ooooo000Dooooo`?o00004_ooool3o`0002[ooooo00?o0000oooooonY_NP05OnY_NP2
ooNeOP03oo^kN_nY_NSoZKgX00;oiJB;00Kok:V6oo2]Pooc/87omK=oooRgOOol_GX2ooo7L@0:okje
;?o[/ICojk6DookDSoob[h;olk21ooBbP?of/goomkEnooRgOP;ofinD00Sogj:Con:UT_oIXigomJed
ooFhQooi^h?onkj0onj_R`;olkB80_oh_HL04ookaHSoomB;onR]Too[[i7ok[:@oo6eS_ob]hkol[N=
ooBiS?oe^hcom[^;oo_1Q_ok`hOo^NSeokBUb?niYLGonlR>ogJTkooV[YT00_oa^I<05ooi/g7onkM]
oofkI_oha9;oO87=ooNnS?oocG_oeZ:QooS8UoobZg[oljaiooB]N?oe[WKomk1cooRaLOoj/foonkE^
oo^fKOol]fcoo;U[oojnJoon`Vgom[5i00;om[5h01Kon;9dooVcLooh/gConK=dooZeL?oj]G7onkI_
oobhKOok]foooKY[oofkKOon_Fcoo/5^ooo6L_oob7Wool^0ooo@PoomeiKon]RSooKJ[on]`>SoZkkW
6_nY_NP01Ol0003oZKgXojVmj?nY_NSooooo00?o00005oooool00ol0003oooooooooo`0;ooooo`00
00Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00oo
oooo0ol0000^ooooo`03o`000?oooooooooo01CoZKgX0_og]Gh01?ok^g[oZKgXojVmj?oUY8/2onbY
QP06oo2]Pooe/goomK=oooRgOOol_G[oolMa0_nn]B`02Oo[/ICoo]B?oo2^Poob[h;olk21ooBbP?of
/goomkEnooRgOP02om^OU008omnRTooRYI;o001fooF]M?oi^h?onkj0ooc1Ooo^[h/2oo>dR00@ooRm
QookaHSoomB;oooDRoo/kY7ojjnAonjbT?oa]Hkol[N>oo:gSOod^HcomK^<ooJkRook`HKonl>7ook8
Q0?o^JG500SofjfXonJ^VOoa^I?onL>>ooVcLOok]fgooK]VooK1U0;oR833017odlS?omJRXOod_I?o
nl>6oo>/NOod[GSomJifooN`Looh/G7on[=_oo^eK_ok]Vgoo;M/oobiJoon_V_oo/9]ooJaN@02ooJa
N00FooRbM?oi/g?on;=dooVcM?oj]G3on[Eaoo^fKool^6gonkM_oofjJoom_6goo[e/ook1K_ooaW;o
olQiooo@Poomd9;ooMNFoo[HXooffZooZkkWoj^oj1WoZKgX0_ooool4o`0001[ooooo00?o0000oooo
ooooool02oooool00005o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03?ooool3o`0003;ooooo00?o
0000ooooooooool04onY_NP2ooNeOP04oo^kN_nY_NSoZKgXojVmj0;ok:V6017ol:f3ooFcOooe/goo
n;MmoobmN_ooag7oe9VFonFUSOo[/ICoo]B?oo2^Poob[h;olk21ooBbP?of/goomkEnooRgOP02om^O
U00homnRTooRYI;o001MooFhQooi^h?onkj0ooc1Ooo//I;olkB8ooJhQ_oh_HOonlF8oooDRonMX=Oo
H`00on^_TOo^/Y3olKF>oo:gS_ob]hgom;V<ooFkS?of^h_onl66oo_3Qoonb8Co001WokVUaOniXl;o
fjfXomb[Y?oa^I?onL>>ooVcLOok]fgokKRJooK1U?o_ScOoR833omne[?oFXZ7om;fCoo6fS_oc[7Wo
m:ehooF^M_og/7?on;5aooZcKook]FkonkI]oobgK?ol^F_oo[i[ook2KOof/GT2ooJaN00GooRbM?oi
/g?on;=dooVcM?oj]G3on[Eaoo^fKool^6goo;Q^oofjJoom_6goo[e/ook1K_ooaW;oolQiooo@Poom
d9;on]RSooKJ[oochKWoj=c7on?Rd_nZ_^P05OnY_NP2ooooo`?o000000?oooooo`000?ooool06ooo
ool00ol0003oooooooooo`0;ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`?o
0000=_ooool00ol0003oooooooooo`0BojVmj0;omkEn1?nY_NP2onbYQP0`oo2]Pooe/goomK=oooRg
OOol_G[oolMaomBIU_oUYHgojk6DookDSoo`[X?olZn2oo>`POod/X3om[=oooNeO_oh]gkonKUmom^O
U?oOXY?ohZFBo`00Cooe^8OonK^3oo^nP?ol`Gook;6Boo>dR?of^8Kon;f7oo_5R?oe]XGom[N4oifP
eomS003ok[:@oo6eS_ob]hkol[N=ooBiS?oe^hcom[^;oo_1Q_ok`hOoo/R4ookJQOl007Ko^J?20_oL
Zj@02?oKZJ?onL>>ooVcLOok]fgon<BBooK1U?ob_YSogkF/0_oFXZ403ood_I?olKJ>oo>/NOod[GSo
mJifooN`Looh/G7on[=_oo^eK_ok]Vgoo;M/oobiJoon_V_oo/9]ooo6LP02ooJaN00FooRbM?oi/g?o
n;=dooVcM?oj]G3on[Eaoo^fKool^6goo;Q^oofjJoom_6goo[e/ook1K_ooaW;ool^0oo^eK?ol]VWo
oKQToofjH_ochKWoj=c7om?Hg0;oZ[gX4OnY_NP2ooooo`?o00001?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00_ooooo0004o`0000?ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Kooooo0ol0000jooooo`03o`000?oo
oooooooo017oZKgX00?omkEnojVmj?nY_NP00onY_NP2onbYQP0Boo2]Pooe/goon;MmooRgOOol_G[o
olMaomBIU_oUYHgoo]B?onj/QOo`[X?olZn2oo>`POod/X3om[=oooNeO_oh]gkonKUm0_oOXY<03ooR
YI;oiJRBooFhQooi^h?onkj0on2YW?o//I;olKF<ooJhQ_oh_HOonlF8ooFfQOof]hColkB7olJca`02
oo6eSP;ol[N=00Som;V<ooJkRooh_XWonl66oo_3Qoood7ooo]Z5o`00I`;o[YBk00Wog:^Tom^YXoo[
/YKok;:Coo^gKOolaXSolknFonf<;?ondXh00_oFXZ403ook`hKolKJ>oo>/NOod[GSomJifooN`Looh
/G7on[=_oo^eK_ok]Vgoo;M/oobiJoon_V_oo/9]ooo6LP02ooJaN00HooRbM?oi/g?on;=dooVcM?oj
]G3on[Eaoo^fKool^6goo;Q^oofjJoom_6goo[e/ook1K_ooaW;onkE[oo^eK?ol]VWooKQToofjH_ol
^eSonKiBom?Hg?o8dn?oZ[kX2onY_NP01?nY_^SoZKgXojVmj?ooool4o`0000Sooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0;ooooo`0000?o0000ooooooooool01?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo0_l00004ooooo`?o0000?_ooool0
0ol0003oooooooooo`0FojVmj004onbYQ_o`[H?oZKgXooFcO`;on;Mm00Koo;ejooo7LOoDVIKoiJF=
on^YR?o`[X<2oo:_PP07oo>`POod/X3om[=oooNeO_oh]gkonKUmomnRT`02on:UTP0>onFXT_oe[GCo
AC^QokbAZOoPZIcolKF<ooFhQoog^HGom;J6ooFfQOof]hCooooooo>dQoob/XP2oo6eSP0<oo:gSOod
^Hcom;V<ooJkRooh_XWonl66oo_3Qoood7ooo]Z5omkYP_l00Y3o[YBk0_oKZJ<01?oHYJ7ok;:Cooc6
R?of_i82oo>oUP0ZojFOd?oFXZ7om;fCo`00POo_U2SoljaiooB]N?oe[WKomk1cooRaLOoj/foonkE^
oo^fKOol]fcoo;U[oojnJoon`VgoolIbooo>M_of/GSon;9dooVcLooh/gConK=dooZeL?oj]G7onkI_
oobhKOol^6kooKY[ooflKOon_Fcoo/5^ooZcL?ok]F_onkE/oobfJOom^6CooKYRoobkF?oi_U;ob=?S
0_nncNH:ojVmj003ojVnj?oooooo000000;o00003Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00000ooooooo0000ooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooooooool3o`0004;ooooo00?o0000oooo
ooooool05OnY_NP01?o/ZHKol:f3ojVmj?oe/gl2ooRgO@0@oobmN_oDVIKoe9VFonFUSOo[ZHSol:j3
oo:_P_oh/7;olk21ooBbP?of/goomkEnooRgO_oi^Ggogj:Con:UTP;oiJRB01Co001?odDkXOoPZIco
k;6Boo6eS?oe^8OomkV5ooBfQ_oe]XGom[N4o`1;a_oc]8Ool[:8oo6eS_ob]hkol[N=ooBiS?oe^hco
m[^;ooRnR@;onl>700Coo]Z5omkYP_o/Rd?o00:@0_n_TKL2omRUX@03onbbToolaXSom[nB00;olknF
0_o1Vk402_od_I?oiY0Eooo9MOoicF;om:ehooF^M_og/7?on;5aooZcKook]Fh2oobgK00PoobiJoon
_V_oo/9]ooo6L_oocWKom[5hooRbM?oi/g?on;=dooVcM?oj]G3on[Eaoo^fKool^6goo;Q^oofjJoom
_6goo[e/ook1K_oj/g3onkE[oo^eK?ol]VWooKQToofjH_ol^eSonKiBoo[4FoolbFGo]LGVojVmj?nZ
_NP5ojVmj0;ooooo0ol0000Aooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_oo
ool000;ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo1?l00016ooooo`;o000000?ooooo
ojVmj?nY_NP04_nY_NP01?o/ZHKol:f3ojVmj?oe/gl2ooRgO@07oobmN_oDVIKoiJF=onFUSOo[ZHSo
l:j3oo:_PP02oo>`P@07ooBbP?of/goon;MnooRgO_oi^Ggogj:Con:UTP02onFXTP0Jo`00ConlTJWo
h:VLonbaT_oa]HcomKR7ooNiQOod]XKomKJ5ooJgQ?odZg?olkB7oo:bR?oc]8Ool[N>oo:gSOod^Hco
mK^<ooJkRook`HKonl>7ook8Q?onfXGokk:=oo^nOooeWTH2ojnA]`;of:FQ037og:ZRooc6R?oc_iKo
lknFoc@n[omffjSoe9nOooBmTooa]XkoolUeooW=H_od[GSomJifooN`Looh/G7on[=_oo^eK_ol]fco
o;U[oofkJoon_V_oo/9]ooo6L_oocWKon=ehooRbM?oi/g?on;=dooVcM?oj]G3on[Eaoo^fKool^6go
o;Q^oofjJoom_6goo[e/ooRbLooj/g3onkE[oo^eK?ol]VWooKQToofjH_ol^eSonKiBoo[4FoolbFGo
//CW00;o[koV0_nY_NP00ooooooo0000o`000002o`0001Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0:ooooo`004oooool2o`0004[ooooo00?o0000oooooonY_NP04_nY_NP01?o/
ZHKol:f3ojVmj?oe/gl2ooRgO@07ooo7LOnY_NSoiJF=onFUSOo[ZHSol:j3oo:_PP02oo>`P@07ooBb
P?of/goon;MnooRgO_oi^Ggonkamon:UTP02onFXTP0;onR/T_nlTJWoh:VLonbaT_oa]HcomKR7ooNi
QOod]XKomKJ5ooJgQ?odZg<00ooc]8L03ooc/hOol[N=ooBiS?oe^hcom[^;oo_1Q_ok`hOoo/R4onfb
T_o_/Xgonkioonb;@on_TKOo]IRiomRUX@02ombZXP;ofJBO00?olknFokB>[_ndSZh00_oDWil0:ooa
]XkoolUeok:=[_od[GSomJifooN`Looh/G7on[=_oo^eK_ol]fcoo;U[oofkJooWTQOoo/9]ooo6L_nj
`^3on=ehooRbM?oi/g?on;=dooVcM?oj]G3on[Eaoo^fKool^6goo;Q^oofjJoom_6goo[e/ooRbLooj
/g3onkE[oo^eK?ol]VWooKQToofjH_ol^eSonKiBoo[4FoolbFGoomF0ojnoi_ooool00ol0000Ioooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool001Gooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooojVmj00BojVmj007oo2]Pooc/87omK=oooRgOOol_G[oolMaojVmj002
onFUS@03on^YR?o`[X?olZn200;olk2100Oom;:0ooJcOooh]gkon;MnooViOOok_7gohZFB00;oiJRB
00_oj:bBon2YW?oPZIcok;6Boo6eS?og^HGom[R5ooBfQ_oe]XGom[N4ooB[L`02oo>dQ`;olk>700_o
lK:8ooBiS?of^h_on;j9oo_1Q_ok`hOoom1oonfbT_o_/Xgonkiooog2N`03okFH^@;og:ZR033ofJBO
omfVW?oMYYcoi[2KomZVWooDWiooo/^7oo>nUOoobGGol/2KooB]N?oe[WKomk1cooRaLOoj/foonkE^
oobgK?ol^F_ooK][onNB5oooaW;oolifooSMN?oAm9kon;9dooVcLooh/gConK=dooZeL?oj]G7onkI_
oobhKOol^6kooKY[ooflKOon_Fcon;9cooZcL?ok]F_onkE/oobfJOom^6CooKYRoobkF?oi_U;on/AK
ooc9IOooeH02o`0001gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`00
5_ooool00ol0003oooooooooo`18ooooo`03o`000?ooooooZKgX017oZKgX00Sol:f3oo>`POoe/goo
n;MmoobmN_ooag7oZKgXonFUS@;ojjV800?ol:j3oo:_P_oc/8400_od/X001oof/goon;MnooViOOoi
^Ggonkamon:UT_oUZ9800_oX[9802OoZ[i?oh:VLonbaT_oa]HcomkV5ooJhQOod]XKomKJ5ooJgQ003
oo>dQ`;olk>700kolK:8ooBfQoof^h_on;j9oo_1Q_ok`hOogjVMonfbT_oooooonkiooog2NoodY3So
]IRiojVB_@;og:ZR033og[:ZomfVW?oMYYcoi[2KomZVWooNYi_oo/^7oo>nUOokfGOol/2Kook7P_oe
[WKomk1cooRaLOoj/foonkE^oobgK?ol^F_ooK][onNB5oooaW;oolifoh2Fgoo>]/;o01nGooVcLooh
/gConK=dooZeL?oj]G7onkI_oobhKOol^6kooKY[ooflKOoe/7Won;9cooZcL?ok]F_onkE/oobfJOom
^6CooKYRoobkF?oi_U;on/AKooc9IOooeH0Oooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02_ooool001Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0@ojVmj005
oo2]Pooc/87omK=oooRgOOol_GX00_nY_NP01_oUYHgojjV8on^YR?o`[X?olZn2oo>`P@;om;:000Oo
m[=oooRgO_oi^GgonKUmoo^lOOoRYI;oiJRB00;oj:bB00gojZnConbaT_o//I;olKF<ooNiQOof^8Go
m;J6ooFfQOof]hColkB7oo:bR?oc]8Oolk>700;olK:800_om;J7om^UWOn@P/3onl66oi22`?oOZIgo
kk:=ooBfQook_WoooL9ko`00@@03ojVB_@;og[:Z0_oMYY`04ooV/9_ofZJOomjWVoonbhOonmUgom2S
Z_oFWigoo/N2ooF^M_og/7?on;5aooZcKook]Fkoo;M/oobiJoom^f_oii8Gooo6L_l007H00_o>]/80
6?o_bjgoWA@0ooRcM?oi/gCon[E`ooZeLOok]Vooo;Q]oobhK_om^V_om:mkooF`NOoh/W?on[=`oo^e
Jook]Fcoo;IYoofhI?om^V;oo;]HooVnD_oja5_oo<UUoooEP23ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0:ooooo`006?ooool2o`0004Wooooo00?o0000ooooooooool03onY_NP0
1Oo`[H?olk21ooZbK?oh]ggoo;ej00;oZKgX00OoiJF=on^YR?o[ZHSol:j3oo:_P_oc/87om;:000;o
m[=o00Con;MnooViOOoi^Ggonkam0_oUZ982onR/TP0=onZ_Too//I;olKF<oo6eS?og^HGom[R5ooBf
Q_oe]XGom[N4oo>dQoob/XSolkB7oo>cQ`02oo6bR00>ooBfQooKYIgohZNFoi22`?o6VZ_ogjVMonnb
SOod]XOonkiooog2Nol004SoOfR^ojVB_On]WLL2omjbZP03om^j]ooV/9_oi[2K00;ogZNK02WohX]V
oogLW?oFWigoeYnMooBjSOoe[WKomk1cooRaLOoj/foonkE^oobgK?ol^F_ooK][ook2KOooaW;oYH:]
oljf`_oS_kCokl^]oo?>Z_oh/gConK=dooZeL?oj]G7onkI_oobhKOol^6kooKY[ooB_Nooe/7Won;9c
ooZcL?ok]F_onkE/oobfJOom^6CooKYRoobkF?oi_U;oo<UUoooEP00Rooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool02Oooool001[ooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooojVmj00>ojVmj005oo2]Pooe/goon[9/ooRgOOol_GX00_nY_NP01ooUYHgojjV8on^YR?o`[X?o
lZn2oo>`POod/X000_of/gl01?oh]gkonKUmoo^lOOok_7d2onFXTP07onR/T_oZ[i?ojZnCo`00I_oa
]HcomKR7ooNiQ@02ooBfQP06ooFfQOof]hColkB7oo:bR?oc]8Oolk>70_oa/XP00ood]XOomKR7on:W
UP02olJJZ`07omnYWOo_/Xgom;J7oo^nOoom`W_odKlkogmX[P02ojfMa`05omjbZ_oK^[OofkZgonJ`
VooldiL00_oNYi/00oolaX[ooMbLomJOW@02ooBjS@0:ooF^M_og/7?on;5aooZcKook]Fkoo;M/oobi
Joom^f_oo/9]ooo6LP;oYH:]0_o_bjd05_occZ[oklV/ooVcM?oj]G3on[Eaoo^fKool^6goo;Q^onj[
Q?od[g_omK1iooRbLooj/g3onkE[oo^eK?ol]VWooKQToofjH_ol^eSonKiBooc9IOooeH0Sooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool0
Aoooool00ol0003oooooojVmj00>ojVmj004ooFcOooj/Vcon;MmoobmNP?oZKgX0_o[ZHP02?o`[X?o
lZn2oo>`POod/X3om[=oooNeO_oh]gkonKUm0_ok_7d2onFXTP0?onR/T_oZ[i?ojZnCo`0V/?oa]Hco
mKR7ooNiQOod]XKomKJ5ooJgQ?oe]hGolkB7oo:bR?oc]8Oolk>700;olK:800_om;J7ooFhQooRYiKo
iZVAomnYWOo]/Y;okk:=ooBfQook_WooolYaolVFW`02ogmX[P08ojfMaonlan?ofkZgoiSacOoV/9_o
o=>Go`000?oNYi/2oogLW00=omJOWOod^Xgoo=AaooF^M_og/7?on;5aooZcKook]Fkoo;M/oobiJoom
^f_oo/9]ohm/YP02oj6:_00Hom6OY?occZ[oklV/ono9[?lcBkcon[E`ooZeLOok]Vooo;Q]onf/R?o^
ZhCom:mkooF`NOoh/W?onJaNoo^eJook]Fcoo;IYoofhI?om^V;oo;]Hoo_1F_olbFGoo;MX8oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo000Looooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool03OnY_NP01?oe/goon;MmooRgOOol_GX3ojVmj0;ojjV800Sol:j3
oo:_P_oc/87om;:0ooJcOoog]Gkon;MnooViO@;onkam017oolYlonR/T_oX[9;ojZnConbbToo_]i?o
02J`ooFhQoog^HGom;J6ooFfQOof]hComKN5oo>dQoob/XSolkB7oo>cQ`02oo6bR00<ooBfQooe^8Oo
mk^8onJYTOoOZIgoljE[oo6bR?ok_WoofY<:om6o>oo9UYooOfR^0_nbTkH05Onlan?oj]IRook6O_oV
/9_o0000oi5`Z_olaX[ooMbLol>BXolf03gom;Z=oocDLOl0003omk1cooRaLOoj/foonkE^oobgK?ol
^F_ooK][olJ00002ohm/YP;oXHZl00ColljZono9[?o_bJco<d^l0_nSU<D04Ook]VoogjBGonf/R?o^
ZhCom:mkooF`NOoh/W?onJaNooZdKOok]Fcoo;IYoofhI?om^V;oo;]Hoo_1F_olbFGoo;MX02Cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`007Oooool2o`0004Sooooo00?o
0000ooooooooool03?nY_NP00ooe/goon;MmooRgO@04ojVmj00=on^YR?o^[8Gol:j3oo:_P_oc/87o
m;:0ooJcOoog]Gkon;MnooViOOok_7gooL9mooo:O002onR/TP03onZ_Too//Y?okkNC00;oHXCN00Wo
mkV5ooBfQ_oe]XGom[N4ooFgQOoc]8Ool[:8oo>dQooc/hL00_oa/XP02ood]XOomKR7ooNkR?oVZI7o
gjVMoo>UJoo_/XgonkioomZC2_lj<Ygoh:BD00?o/Y>f00GonmBMooBnToogbE[od[ljo`0CWP02oi5`
ZP;o`i:S01?obYFNooBjSOo6Tj7oaY>QooN`Looh/G7on[=_oo^eK_ol]fcoo;U[oofkJol702Cooooo
ohm/Y_o/g/?o001Rom6OY?o_bJcok<jf00?oXiC5017od9jSomnTUoo][8SokZ^4ooB_Nooe/7Won;9c
ooZcL?oj]6gonkE/oobfJOom^6CooKYRoobkF?ok`E[on[A`oobgJ00Uooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02Oooool001oooooo00?o0000ooooooooool0A_ooool01Ol0003o
oooooooooonY_NSoZ[gX00WoZKgX00?omK=oooRgOOoh]gd01?nY_NP03Oo[ZHSokZb5oo2^Poob[h;o
lk21ooBbP?of/goomkEnooRgO_oi^Ggonkamoog2OOoobW`00_oX[9802_oZ[i?ok;:ConngToob^YCo
HXCNokN[cOoA/k_omKJ5ooJgQ?oe]hD3oo>dQ`03oo>cQooa/XSolK:800;omKR7017omk^8on^/SOo^
[h_oljE[onnbSOok_WoooL9kolVFWooPY9Co001hok:C]_oC[;3oj]IRooBnTooB_c[onkioo`00C@02
oi=aZ0;o`i:S0_o:UIh09Oo6Tj7ohJZJooN`Looh/G7on[=_oo^eK_ol]fcoo;U[oofkJol702Co001g
ohm/Y_o]aD_ocg40obhWU_n<Ij?omKjAomgdgOnSU<GobjJcom2NXooOY9OokJb8onj[Q?od[g_omK1i
ooRbLooj/g3on[A]oo^eK?ol]VWooKQToofjH_ol^eSonl5JooZdL?ol]fP09_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Wooooo000Pooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool02onY_NP00ooh]ggoZKgXojVmj003ojVmj00>on^YR?o^[8Gol:j3oo:_P_oc/87o
m;:0ooJcOoog]Gkon;MnooViOOok_7gooL9mooo:O?olfGT2onZ_T`09onbbToo_]i?ol[ZDoo6jUOng
ZlgodK>kon;0]_o/b[;ojlF^00?olkB700Colk>7oo6bR?oa/XSomKR70_og^hP02Oo[[8gokZn;onnb
SOo_/Xgonkiooog2Noo9UYooh:BDobhaX`02om>//005omg3@OoiZUSod[ljoo^nOol004d00onCLJP0
5Oo3TZ?obYFNolZEW_o__YgohJZJooN`Looh/G7on[=_oo^eK_ol]fcoo;U[oofkJol702Co<4JhoncN
`oo]aD_o001Yo`00Holo=iooS6NSojn5Z002ol^V/`0Aom2NXooOY9OokJb8onj[Q?od[g_omK1iooRb
Looj/g3on[A]oo^eK?ol]VWooKQToofjH_ol^eSonl5JooZdL?ol]fP09_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool04OnY_NP03Oo^[8Gol:j3oo:_P_oc/87om;:0ooJcOoog]Gkon;MnooViOOok_7gooL9m
ooo:O?olfGT00_oZ[i<02oo//Y?okkNCoo:jU?oa^YGol;ZGom6c^ooR`;Kok<Zbon_5[_oV_:_olkB7
00;olk>700?olK:8ooBfQooe^8L00_og^hP04Oo[[8gokZn;onnbSOod]XOonkiooog2Noo9UYooh:BD
onn`R_l^<J?onmBMoo_EWoonaWko]HFRoo^nOom`7E7oCCVJ00;oTg6X00oo`i:SolZEW_o:UIkokkjM
on6ZV_og/7?on;5aooZcKook]Fkoo;M/oobiJonbR:SoXDMLoaD@R?oi`hd00_l000001Ol006;o?cNO
ohaWXonbV;codY^M00;od9jS013ogjBGonf/R?o^ZhCom:mkooF`NOoh/W?on[=`ooZdKOok]Fcoo;IY
oofhI?o_XW;oo;]Hoo_1F_oj]73oo;MX9oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Sooooo000Rooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04?nY_NP2oo2^
P`0=oo:_P_oc/87om;:0ooJcOoog]Gkon;MnooViOOok_7gooL9mooo:O?olfGWojZnConbbT`02onng
T`05oo:jU?oa^YGol;ZGoo6mV?o/b[800_o[aJh00ooV_:_olkB7oo>cQ`02oo6bR00GooBfQooe^8Oo
mk^8ooNkR?o[[8gokZn;onnbSOod]XOonkiooog2Noo9UYookk2:ooRiPol^<J?o^JG5okZD/?onaWko
hjNCoo^nOoonafcoM5BOoi=aZ?nRQ;<00_o:X:d2onnnW@0Con6ZV_og/7?on;5aooZcKook]Fkoo;M/
oobiJooPYiWo0000oj>5]?oi`hgoo/j;omK4@_lN6Y3o;RNFohaWXon^R[3o/YRlom2NX`02omnTU`0?
onf/R?o^ZhCom:mkooF`NOoh/W?on[=`ooZdKOok]Fcoo;IYoofhI?o_XW;oo;]Hoo>^O?oj]73oo;MX
02Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`008oooool2o`0004Oo
oooo00?o0000ooooooooool03onY_NP2oo2^P`0>oo:_P_oc/87om;:0ooJcOoog]Gkon;MnooViOOok
_7golj<dooo:O?olfGWoejNUonbbToo_]i<2oo:jU005oo6jUOo`^YOolKfHonc:/_o[aJh00_oV_:/0
4Ooc]8Oolk>7oo6bR?oa/XSom;J7ooFhQoog^hSoo<F5oogHO?o^[h_olK:8ooBfQook_WoooL9kon2T
U?o_/8[on;V300;o^JG500KofKlkook6O_oSYi?onkioook7K?mdE9l3oj:4/`0BolZP[Oo__YgokkjM
o`002On`PZ;on;5aooZcKook]Fkoo;M/olQcK_oPYiWo_HVMo`03R_oi`hgoo/j;omK4@_lN6Y3o;RNF
0_n^R[004oooooooce<6omnTUoo][X_okJb8onj[Q?od[g_omK1iooRbLooj/g3on[A]oo^eK?ol]VWo
oKQTonRLMool^eSoljilooZdL?ol]fP0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Sooooo000Uooooo`03o`000?oooooooooo04Gooooo0_l000000oooooooZKgXojVmj00<ojVm
j00<oo2^Poob[h;olZn2oo>`POod/X3om[=oooNeO_oh]gkonKUmoo^lOOocXcCoo=Ui0_oGYjD01?o/
/Y?okkNCoo:jU?ob^Y@2oo2jU`07oo6mV?oa_YWojlF^onJlZooX_jcokLbboo>cQ`02oo6bR00FooBf
Qooe^8Oomk^8ooc5QOomf7cokZn;oo6bR?oe]hKonkioooSDJooPY9Cokk2:ooRiPoom`WconmFOooBn
ToogbE[ohjNCoo^nOoonafco001=ogADW`;oXXBc00kobZ2]oooooon7I:?oQfBSok22X_oh/G7on[=_
oo^eK_o2T:;ogjVLoo>L>?nmRIgogj^Oo`00<0;ooooo00Cocg40o`00H_n^R[3o[XZ`0_ooool02_oO
Y9OokJj;onf/R?o^ZhCom:mkooF`NOoh/W?on[=`ooZdKOok]F`2oobfJ@05onRLMool^eSoljilooZd
L?ol]fP0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03
o`000?oooooooooo04Kooooo00?o0000oooooonY_NP03?nY_NP04oo`[X?olZn2ooN`L_oc/87om;:0
ooJcOoog]Gkon;MnooViOOok_7gonZeDoocINOoGYjGoi:bHon^_TOo_]i?ol[ZDoo6jUOo`^YL00_oa
_IP01_oa_YWok[VJonJlZooX_jcokLbbon_@^P;olK:801[om;J7ooFhQoog^hSoo<F5oogHO?o^[h_o
lK:8ooFgQ_om`h7on=A[on2TU?o_/8[on;V3oog2O?o4SI_om;jCokF5X_oSYi?onkioook7K?l004[o
M5BOoj:4/oom`h3o000SolAj00;oSVVT0_nfR:@02?oj/foonkE^omnYW?oOZIcoli`hokf9WOonagco
kLE;0_ooool00omiFZ7o7QZ@ojj:/003ooooo`0AomnTUoo][X_okJb8onj[Q?od[g_omK1iooRbLooj
/g3on[A]oo^eK?oBQG_oo;IYonRLMool^eSoljilooZdL?ol]fP0:_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
oonY_NP02onY_NP06?o`[X?olZn2ooN`L_oc/87om;:0ooJcOoog]Gkon;MnooViOOok_7goolYloocI
NOoGYjGoi:bHon^_TOo`/hcol[ZDoo6jUOo`^YOolKfHoo?0V?oa_YWok[VJonjjVP;okLbb00Kojm2j
on;?aOoa/XSom;J7ooFhQoog^hP2oogHO00Eo`005ooa/XSomKN6oog3POoj^GSoFA5Fonn`R_oh^H?o
oL9lolB=Vood_Y?o]HFRon>WTol002;ogi=ko`00L?mdE9oo/8Z]oog3P?oIWYKoa7X000;oSVVT0_nf
R:@2on2]X@;ogjVL00Co0000ooooooonagcoo/j;0_ooool00omiFZ7o7QZ@ooooo`03ooooo`0AonN5
BOo][X_okJb8onj[Q?od[g_omK1iooRbLooj/g3on[A]oo^eJook]Fcoo;IYonRLMool^eSoljilooZd
L?ok]V/0:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo000Xooooo`;o
0000Aoooool00ol0003oooooooooo`0:ojVmj00;oo2^Poob[h;olk21oo>`POod/X3om[=oooNeO_oh
]gkonKUmoo^lOOoobW`00_nY_NP04OoT[9SojjnAoo2cS?ob]8_olKZEoo2jUooa_ISoll2Hoo6nVOo^
^I[ok[ZJoo6mVOo`_9Wojm2joloYj?oa/XSomKR700;omk^801SooMQloo6_Q?oe/WoolK:8oog3POoh
e6_on[UhojimW_o_/8[on;V3oog2O?o4SI_ofYfDokF5X_ok_WoonJYHom>IUoo/[Hco/8Z]ookIU?om
`h3ofIjFolAj0?m7<iH2ohiYY003okJ8Y?oP[J7oh:fQ00;ogjVL00?o_HVMooooooonag`01?ooool0
0ooieVkoooooooooo`03ooooo`0@onf^Roo][8SoljmmooB_Nooe/7Won;9cooZcL?oj]6gonkE[oo^e
K?ol]VWoj9agoobkF?oc[Wcooooooo^fJbcooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`08ooooo`00:_ooool00ol0003oooooooooo`15ooooo`03o`000?ooooooZKgX00WoZKgX00Ko
l:j3oo:_P_oc/87olk21ooBbP?of/gl2ooRgOP03oo^lOOom`WgoolYl00;oZKgX00Coi:bHon^_TOo`
/hcol[B;0_o`^YL02?oa_ISolKjIoo6nVOo^^I[ok[ZJoo6mVOo`_9Wol[bF0_o?jNP06ooe^8Oomk^8
ooc5QOomf7colJn4ooFbOood/X3ooL>1ooRfNooj^GSo[WfNonn`R_oh^H?oeIVFon6VU?oJWICohjNC
oo^nOoonafcodiVGonb]S?n`RZgoJ6_2oo;6D?oIWYKom:@iofU;V`02ohiYY007okJ8Y?oP[J7oh:fQ
o`003?oooooo0006ook7O005ooooo`03ogUJXOoooooooooo00?ooooo013okJj;onf/R?oc[ggom:mk
ooF`NOofZFWonK=aooZcL?ok]F_onkE/oobfJOom^F;oo;]Hoo>^O?oj]73onkI[;?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo000[ooooo`03o`000?oooooooooo04Gooooo
00Co0000oooooonY_NSoZKgX0_nZ_NP5ojVmj003oo2^Poob[h;olk2100;om;:000Gom[=oooRgO_oi
^Ggonkamoog2O@03ojVmj0;ojjnA00?ol;><oo:dRooe[7@00_oa_IP09_oa_YWok[VJonjiV_o^^Y[o
lKfIoo2lVOob_9Koml:AooO1TOoe^8Oomk^8ooc5QOo`[XKolJn4ooFbOood/X3ooL>1ooRfNooj^GSo
[WfNonn`R_oh^H?oeIVFon6VU?oJWICohjNCoo^nOoonafcodiVGonb]S?n`RZgooL>0oo;6D?oIWYKo
m:@iofU;Von>JJCoYh^g0_o;d=d3ooooo`03o`001_onagcooooo00_ooooo00ookJb8oo>_OOod[g_o
mK1iooNaMOogZVOon[=`oo^eJook]Fcoo;IYoofiH_ol^eSoljilooZdL?ok]V/0;Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo000/ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool02?nY_NP02Oob[h;olk21ooBbP?od/X3om[=oooRgO_oi^Ggonkamoog2O@03
ojVmj00;on^_TOo`/hcol;><oo:dRooe[7Com;F7oo?0V?oa_YWok[VJonjjV_oa_IT00_o`_9T05_ob
_9Koml:AooO1TOo`YWSoolamon^[R_o`[XKolJn4ooFbOood/X3omkElooRfNooj^GSojZDWojimW_oh
^H?oeIVFon6VU?oJWICohjNCoo^nOoonaf`2onb]S006ofQ[`_om`h3oT6RPomVNU_ooooooJD^K0_nW
RkL6ooooo`03ook7O?oooooooooo00[ooooo00ookJb8oo>_OOod[g_omK1iooNaMOogZVOon[=`oo^e
Jook]Fcoo;IYoofiH_ol^eSoljilooZdL?ok]V/0;_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo000]ooooo`;o0000A_ooool00ol0003oooooooooo`02ojVmj003ojZmj?nY
_NSoZKgX00;oZKgX00SolZn2oo>`POod/X3om[=oooNeO_oh]gkonKUmoo^lO@CoZKgX01gojjnAoo2c
S?ob]8_ol[B;ooF/M?od]HOomKN6ooFhQoo^^I[ok[ZJoo6mVOo`_9Wok[RHoo:lU_og`Y7on<6>oo2V
N?ooc7gojj^:oo2^Q_oa[hComK9oooBbP?og]Gcon;IkooZiN?oZYBOo[WfNomFIUP02on6VU004omZM
U?oXZHkonkioook7K0;ok:f<00GoDCnNoog3P?oIWYKofIjFooooo`02ofU;V`03ojN;]ooooooooooo
017ooooo00ookJb8oo>_OOod[g_omK1iooNaMOogZVOon[=`oo^eJook]Fcoo;IYoofiH_ol^eSoljil
ooZdL?ok]V/0;_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo000_oooo
o`03o`000?oooooooooo04Cooooo00?o0000oooooonY_NP01_nY_NP02?ob[h;olk21ooBbP?of/goo
mkEnooRgO_oi^Ggonkam1OnY_NP07?o`/hcol[B;oo6cR_oe[7Com;F7ooFgQ_oe^8Oom[V7onjjV_oh
Z5_ol;bIonjhV?ob_9Koml6AooS1S_oobh7oolamon^[R_o`[XKol[23ooFbOood/X3omkElooRfNooj
^GSonkYiooBYLOoEVIH2on6VU00;omZMU?oXZHkonkioooRkQOo/[Hcogi=konbLKoom`h3ofIjFoo^m
Ooooool00_mYBi/Dooooo`0?oo2NIooc[ggom:mkooF`NOog/GGomjYWooZcL?ok]F_onkE/oobfJOom
^F;oo;]Hoo>^O?oj]73onkI[02oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`00<?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00KoZKgX00Oolk21ooBb
P?of/goomkEnooRgO_oi^Ggonkam00KoZKgX00Ool[B;oo6cR_ob/hWom;F7ooFgQ_oe^8Oom[V700;o
lKfI013ol;bIoo:lU_ob_9Koml6AonjTN?oobh7oolamon^[R_o`[XKol[23ooFbOood/X3omkElooRf
Nooj^GSonkYi0_nePYh2on6VU009omZMU?oXZHkon;^5ooRkQOo/[Hcogi=kolNc:?om`h3ofIjF00;o
oooo00?oJD^KolR/_Oooool04oooool03oo_VV;oljmmooB_Nooe/7Womk5eooNZIooj/g3onkE[oo^e
K?ol]VWooKURohaSW_oc[Wcon[A`oo^fJ`0`ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool0037ooooo00?o0000ooooooooool0A?ooool01Ol0003ooooooooooonY_NSoZ[gX
00?oZKgX00Kolk21ooBbP?of/goomkEnooRgO_oi^Gd7ojVmj00Io`000?oa/h[ol[>9ooBeQooe]hKo
mKR7ooJiQooj`8Sol;bIonjhV?ob_9Kom:]bonVLMOonbHCool^1ooo<OOo[Zh[olJn4oo:`Pooe/Woo
m;:0ooNeO?oh]W_on[Uhoo^jN@02okF2WP;ohJJD00WohjZHonRYS_oh^hGol/eJonb]S?ok_Woooooo
olNc:?oIWYH00_ooool2olR/_AGooooo00ooljmmooB_Nooe/7Womk5eooNZIooooooonkE[oo^eK?ol
]VWooKURohaSW_oc[Wcon[A`oo^fJool]fP0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo000booooo`;o0000AOooool01?l0003ooooooooooonZ_NP3ojVmj006oo>`POod
/X3om[=oooNeO_oh]gkonKUm0onY_NP3o`0000;ooooo00?olK>:oo:cROod]HL00_oe^8L04oof^HOo
n/28oo_7SOo^^9Sol[bFonBBL?og`I7oo/V4ooo;POoQYICojj^:oo6_Q?ob/8?omK9oooBbP?og]Gco
n;IkooZiN?ok^WT00_nePYh2on6VU006on>ZV?oXZHkon;^5oo;=F_o/[Hconkio0_ooool00ooIWYKo
ooooooooo`0Gooooo`0?oo>_OOod[g_omK1iooNaMOofZFWomjYWoo^eJook]Fcoo;IYoofiH_n<Hiko
ljilooZdL?ok]V_oo;MX033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`00=?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00CoZKgX00Gom;:0ooJcOoog
]Gkon;MnojZmj003o`0000Kooooo01Ool[>9ooBeQooe^8Oom[V7ooRlQooj`8SonlN=ookIT_ob_9Ko
ml6AooS1S_onbHCoe9jMon6UU?o[Zh[olJn4oo:`Pooe/Woom;:0ooNeO?oh]W_on[Uhoo^jN@02okF2
WP08on6VU?oSZYSohjZHonRYS_oh^hGol/eJonb]S?ok_Wl2ooooo`03omVNU_oooooooooo01Oooooo
00ooljmmooB_Nooe/7Womk5eooJYJOogZVOonkE[oo^eK?ol]VWooKURomNJTooc[Wcon[A`oo^fJool
]fP0<Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo000eooooo`03o`00
0?oooooooooo04?ooooo00Co0000ooooooooooooZ[kX0onY_NP00oof/goomkEno`00000;ooooo`06
ooBeQooe^8Oom[V7ooRlQooj`8SonlN=0_ooool03_l0003on<6>ojj5ZOoDWYgohJFDon^[R_oa[hCo
l[23ooFbOood/X3omkElooRfNooj^GSom:Yc0_nePYh02?o2Sj3ohjZHon>ZV?oXZHkon;^5ooooooo/
[Hconkio0_ooool00ooIWYKoooooooooo`0Gooooo`0?oo>_OOod[g_omK1iooNaMOofZFWomjYWoo^e
Jook]Fcoo;IYoofiH_oGVY?oj:F8ooNaM_oj]73oo;MX03;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`00=_ooool00ol0003oooooooooo`13ooooo`04o`000?oooooooooo
ojVmj0;o00003oooool01?oe^8Oom[V7ooRlQooj`8P3ooooo`0?om5dG_m3?JCo[XFYomBNWOoWZHko
jj^:oo6_Q?ob/8?omK9oooBbP?og]Gcon;IkooZiN?odZW?o]H:N00;o`XnP0_oSZYP01OoofY7on;^5
oooooooooooonkio01cooooo00ooljmmooB_Nooe/7Womk5eooJYJOogZVOonkE[oo^eK?ol]VWooKUR
omNJToocYVkoljilooZdL?ol]fP0<oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo000gooooo`;o0000A?ooool2o`0001[ooooo00ko[XFYomBNWOoQYICoijV>on^[R_oa[hCo
l[23ooFbOood/X3omkElooRfNooj^GSom:YcokF2WP;o`XnP00CohjZHoooJTOoofY7om;:08?ooool0
3_od[g_omK1iooNaMOoh/W?on[=`ooZdKOok]Fcoo;IYoooooooGVY?oj:F8oo>^O?oj]73oo;MX<ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000iooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool06Oooool03On^QJWoe9jMon6UU?oWZHkojj^:oo6_Q?ob/8?o
mK9oooBbP?og]Gcon;IkooZiN?odZW<00oo2Sj001?oSZYSoomZAofHKFOod/X0Pooooo`0>ooB_Nooe
/7Womk5eooRbLooj/g3on[A]oo^eK?ol]VWoooooomNJTooXYHSoljilooZdL?ol]fPdooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool003[ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`0Iooooo`0:ojj5ZOoDWYgohJFDonNYS_o[Zh[olJn4oo:`Pooe/WoomkAm
ooRfN`;on[Uh00Soo/5aol:?X?o2Sj3odIbOon>ZV?nk[bCol[63ooBbP23ooooo00kom:mkooF`NOog
/GGon;9cooZcL?oj]6gonkE/oobfJOooooooeiZConRUR?oc[Wcon[A`oobgJ3Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`00>oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo01Wooooo0_oDWYd04_oQYICoijV>on^[R_oa[hCol[23ooBbP?og]7gon;IkooZi
N?ok^WWoo/5aook:KOo2Sj3odIbOooO6V?nk[bCol[63ooBbP27ooooo00gomK1iooNaMOoh/W?on[=`
ooZdKOok]Fcoo;IYoooooooGVY?oj:F8oo>^O?oj]73oo;MX03Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`00??ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo01Wooooo0_oDWYd04_oQYICoijV>oo2^Q_oa[hCol[23ooBbP?og]7gon;IkooZiN?ok^WWoo/5a
ook:KOo2Sj3odIbOooO6V?oOXI7ol[63ooBbP27ooooo00gomK1iooNaMOoh/W?on[=`ooZdKOok]Fco
o;IYoooooooGVY?oj:F8oo>^O?oj]73oo;MX03Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`00?Oooool2o`0003kooooo00?o0000ooooooooool06Oooool2omBNW@0<on6U
U?o[Zh[ol:j6oo6_Q?oe/Woom;:0ooNdOOoh]W_on[Uhoo^jNOon`G7oo/Y]0_oAW9l01?ogaYSogj6A
oo:aPood/X0Qooooo`07ooF`NOog/GGon;9cooZcL?oj]6gonkE/oobfJ@02ooooo`04onRUR?oc[Wco
n[A`oobgJ3Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`00?oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo0_oQYI@02Oo[Zh[ol:j6oo6_Q?oe
/Woom;:0ooNdOOoh]W_on[Uhoo^jN@02ook:K@;odIbO00Coo=IeomnQTOob/H?om;:08_ooool01Oog
/GGon;9cooZcL?oj]6gonkE/00?ooooo00Coj:F8oo>^O?oj]73oo;MX>?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo0010ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool06_ooool2on6UU009on^[R_o`[XKolJn4ooFbOood/X3omkAmooRfNooj^GSonkYi00;o
o/Y]00KoF3jGooO6V?oleWGogj6Aoo:aPood/X0Rooooo`05ooNaMOoh/W?on[=`ooZdKOok]F`00ooo
ool01?oXYHSoljilooNZI_ok]V/hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool0047ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Jooooo`0Con6UU?oW
ZHkojj^:oo2^Q_oa[hComK9oooBbP?og]7gon;IkooZiN?ok^WWoo/Y]oooooomH?YOomlJHoocFMOoO
XI7ol[63ooBbP00Sooooo`04ooRbLooj/g3on[A]oo^eK0?ooooo00Coj:F8oo>^O?oj]73onkI[>Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo0012ooooo`;o0000>Oooool00ol0003ooooooooo
o`0Kooooo`0;onNYS_o[Zh[ol:j6oo6_Q?oe/Woom;:0ooNdOOoh]W_on[Uhoo^jNOonbVd00_ooool2
oePnU`03omnQTOob/H?om;:002Cooooo00?on[=`ooZdKOooool00oooool01?oXYHSoljilooZdL?ok
]V/jooooo`04o`000?ooooooooooo`0000Oooooo0014ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool06oooool02ooWZHkojj^:oo2^Q_oa[hComK9oooBbP?og]7gon;IkooZiN?ok^WWo
o/Y]00;ooooo00GoF3jGokb7W?oOXI7ol[63ooVfN`0Tooooo`03ooZcL?oj]6gooooo00Cooooo00?o
ljilooZdL?ok]V/0>oooool00ol0003oooooo`000007ooooo`00AOooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo01_ooooo00[oijV>on^[R_o`[XKolJn4ooFbOood/X3omkAmooRfNooj
^GSom:]e0oooool01OmH?YOo_8NLomnQTOod/X3onKIk02_ooooo00?oljilooZdL?ok]V/0>oooool0
1?l0003oooooooooool00006ooooo`00A_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo01_ooooo00[oijV>on^[R_o`[XKolJn4ooFbOood/X3omkAmooRfNooj^GSom:]e0oooool01OmH
?YOo_8NLomnQTOod/X3onKIk02_ooooo00?oljilooZdL?ok]V/0??ooool00ol0003oooooo`000006
ooooo`00Aoooool2o`0003Cooooo00?o0000ooooooooool07?ooool02Oo[Zh[ol:j6oo6_Q?oe/Woo
m;:0ooNdOOoh]W_on[UhooB[M@03ooooo`;o_8NL00?ojjZ:ooBbP?oi]W/0:oooool00ooc[Wcon[A`
oo^fJ`0mooooo`;o00001_ooool004Wooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0Looooo`09on^[R_oa[hCol[23ooFbOood/X3omkAmooRfNooj^GSoo/5a00?ooooo0_nlQi`00oo[
ZX[om;:0ooVfN`0/ooooo`03ooZdL?ok]V_ooooo03_ooooo0ol00006ooooo`00B_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo01gooooo00Sojj^:oo6_Q?ob/8?omK9oooBbP?og]Gco
n;IkooZiN0Cooooo00Go_8NLomnQTOo[ZX[om;:0ooVfN`0/ooooo`03ooZdL?ok]V_ooooo03Oooooo
1?l00009ooooo`00Boooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01gooooo00So
jj^:oo6_Q?ob/8?omK9oooBbP?og]Gcon;IkooZiN0Gooooo00Cogj6Aon^ZR_od/X3onKIk;?ooool0
0ooj]73onkI[ooooo`0cooooo`Co00003Oooool004cooooo0_l0000^ooooo`03o`000?oooooooooo
01kooooo00OolJn4oo:`Pooe/Woom;:0ooNeO?oh]W_on[Uh00Gooooo00Cogj6Aon^ZR_od/X3onKIk
;?ooool00ooj]73onkI[ooooo`0`ooooo`?o00004Oooool004kooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0Nooooo`07oo6_Q?ob/8?omK9oooBbP?og]Gcon;IkooZiN005ooooo`04
omnQTOo[ZX[om;:0ooVfNe_ooooo1?l0000Dooooo`00Coooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo01kooooo00OolJn4oo:`Pooe/Woom;:0ooNeO?oh]W_on[Uh00Gooooo00Cogj6A
on^ZR_od/X3onKIkEoooool4o`0001Sooooo001@ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool07_ooool01ooa[hCol[23ooFbOood/X3omkElooRfNooj^GP01Oooool01?oOXI7ojjZ:
ooBbP?oi]W]Cooooo`Co00007?ooool0057ooooo0_l0000Yooooo`03o`000?oooooooooo01kooooo
00OolJn4oo:`Pooe/Woom;:0ooNeO?oh]W_on[Uh00Gooooo00Cogj6Aon^ZR_od/X3onKIkCoooool4
o`00023ooooo001Cooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool01_oa
[hCol[23ooFbOood/X3omkElooRfN`Oooooo00?ojjZ:ooBbP?oi]W/0Boooool4o`0002Cooooo001D
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07oooool01Oob/8?omK9oooBbP?og
]Gcon;Ik00Oooooo00?ojjZ:ooBbP?oi]W/0Aoooool4o`0002Sooooo001Eooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool07oooool01Oob/8?omK9oooBbP?og]Gcon;Ik00Oooooo00?o
jjZ:ooBbP?oi]W/0A?ooool3o`0002cooooo001Fooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool08?ooool00ooe/Woom;:0ooNeO008ooooo`03on^ZR_od/X3onKIk043ooooo1?l0000_
ooooo`00Eoooool2o`0002?ooooo00?o0000ooooooooool08Oooool00ood/X3oooooooooo`07oooo
o`03on^ZR_od/X3onKIk03cooooo1?l0000cooooo`00FOooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02cooooo00?om;:0ooVfNoooool0=oooool4o`0003Oooooo001Jooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0;?ooool00ood/X3onKIkooooo`0cooooo`Co0000
>oooool005_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0/ooooo`03ooBbP?oi
]W_ooooo02oooooo1?l0000oooooo`00G?ooool2o`0001kooooo00?o0000ooooooooool0;?ooool0
0ood/X3onKIkooooo`0[ooooo`Co0000@oooool005kooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0]ooooo`03ooVfNooooooooooo02Oooooo0ol00017ooooo`00Goooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo05?ooooo1?l0001:ooooo`00H?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo04oooooo1?l0001>ooooo`00HOooool2o`0001Wooooo00?o
0000ooooooooool0Boooool4o`0005;ooooo001Sooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0Aoooool4o`0005Kooooo001Tooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0@oooool4o`0005[ooooo001Uooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0?oooool4o`0005kooooo001Vooooo`;o00005?ooool00ol0003oooooooooo`0looooo`?o0000
H_ooool006Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0hooooo`Co0000IOoo
ool006Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`Co0000JOooool0
06[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`Co0000KOooool006_o
oooo0_l0000>ooooo`03o`000?oooooooooo02gooooo1?l0001aooooo`00KOooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02Wooooo1?l0001eooooo`00K_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02Gooooo1?l0001iooooo`00Koooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02;ooooo0ol0001mooooo`00L?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01kooooo1?l00020ooooo`00LOooool2o`0000Sooooo00?o0000oooooooo
ool06_ooool4o`0008Cooooo001cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5_ooool4o`0008Sooooo001dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool4o`0008cooooo001eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4
o`00093ooooo001fooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000U?ooool007So
oooo00Co0000oooooooooooo00002Oooool3o`0009Sooooo001iooooo`03o`000?oooooo000000Go
oooo1?l0002Kooooo`00N_ooool2o`000003ooooool0003o000000;o0000Woooool007_ooooo0_l0
002Sooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00Hooo
ool3o`00057ooooo0ol0001Vooooo`00I?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo06Gooooo000iooooo`?o00001?ooool3o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o00000_ooool3o`0000Cooooo0ol00003
ooooo`Co00000_ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_oo
ool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l00002ooooo`Go00000ooo
ool2o`0000Cooooo00?o0000ooooooooool01oooool3o`0000Gooooo0_l000000ooooooo0000o`00
0002o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o0000
0_ooool3o`000003ooooool0003o000002gooooo000jooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00Co
0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0002kooooo000jooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool5o`0000;ooooo0ol00002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0/ooooo`00>_ooool3o`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0:ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`;o00000oooool01ol0
003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooooooo
o`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000002Oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0/ooooo`00>_oo
ool01?l0003oooooooooool00002ooooo`?o00000_ooool3o`0000?ooooo1?l00002ooooo`Co0000
2Oooool00ol0003oooooooooo`02ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo
0ol00003ooooo`;o00001?ooool3o`0000[ooooo00Co0000oooooooooooooooo1?l00002ooooo`Co
00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0003o00000oooool4o`00
00;ooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oooooooooo00;ooooo0_l000001?oo
oooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co00000_ooool3o`0000Cooooo0ol00002
ooooo`Co0000;oooool003[ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`09
ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
ool0000Dooooo`03o`000?oooooooooo047ooooo000iooooo`Co00002_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo0ol0000Kooooo`;o00002?ooool5o`0000Sooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo1Ol0
000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0727597, 0.0480907, \
0.00364557, 0.00364557}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-1.2464337861714014`\)\), 
        ",", \(BackFocalLength \[Rule] 39.485013802263495`\), 
        ",", \(BackFocalPoint \[Rule] {57.847139891996214`, \
\(-14.815427008975622`\), 0}\), ",", \(ColorFunction \[Rule] Automatic\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] {1.3542547064519408`, 
            0.5069006318673106`}\), ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-57.42551421082294`\), \
\(-57.42551421082294`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-14.85946576992335`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {14.537193111455208`, \
\(-3.077944022847568`\), 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] \
{{\(-0.9783119619871903`\), 0.2071369233931379`, 
              0}, {\(-0.2071369233931379`\), \(-0.9783119619871903`\), 
              0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] 0\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {19.817012764638733`, \
\(-4.195834472443554`\), 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{0.9631534464647291`, \
\(-0.2689524838389013`\), 0}, {0.26895248383890136`, 0.963153446464729`, 
              0}, {0, 0, 1}}\), ",", \(FieldStopPosition \[Rule] 2\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 2, 
            SurfaceNumber \[Rule] 2, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] False\), 
        ",", \(FindPupils \[Rule] True\), ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 45.79737407145489`\), 
        ",", \(FrequencyCutoff \[Rule] {383.5503719591895`, 
            388.81008823729053`}\), 
        ",", \(FrontFocalLength \[Rule] 38.259408199433885`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-36.31607577162287`\), 
            12.038478156339174`, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {0.9631534464647278`, \
\(-0.26895248383890547`\), 0}\), 
        ",", \(ImagePoint \[Rule] {97.5653867211063`, \
\(-25.906412273284403`\), 0}\), 
        ",", \(ImageSampleSize \[Rule] {0.0013238071421817603`, 
            0.0013064449274930686`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(BiConvexLens[50, 50, 20]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-54\), \(-54\)}, {108, 54, 
                        54}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(IntensityTransform \[Rule] True\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.8621676373989785`, 
              10.290804067447606`}, {\(-0.021835313056153834`\), 
              0.8992416763944976`}}\), ",", \(Mesh \[Rule] False\), 
        ",", \(NormalizePlot \[Rule] False\), 
        ",", \(NumberOfPoints \[Rule] 1024\), 
        ",", \(NumberOfRays \[Rule] 32\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              
              TagBox[\(Move[
                  PointOfRays[{10, 10}], {\(-90.5`\), 
                    30.`}, \(-18.33993103355537`\)]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 126.14743656048276`\), 
        ",", \(OpticalLengthFunction \[Rule] OpticalLengthFunction\), 
        ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(CompiledFunction[
              If[#1 == 0 && #2 == 
                    0, \(-0.14468965453213384`\), \(-41.81222881467531`\) + 
                  5.286759552523686`\ Cos[
                      ArcTan[#1, #2]]\ \@\(#1\^2 + #2\^2\) - 
                  0.8262068197984601`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) - 
                  0.0006154026086115438`\ Cos[
                      3\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(3/2\) - 
                  2.6998584699791614`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                  6.309760668030093`*^-8\ Cos[
                      5\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(5/2\) + 
                  4.88201915501478`*^-10\ Cos[
                      6\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^3 - 
                  64.23701951299245`\ \((\(-1\) + 
                        0.014389200066149941`\ \((#1\^2 + #2\^2)\))\) + 
                  26.68824308587652`\ Cos[
                      ArcTan[#1, #2]]\ \((\(-0.16964197632749944`\)\ \
\@\(#1\^2 + #2\^2\) + 
                        0.001830759252745096`\ \((#1\^2 + \
#2\^2)\)\^\(3/2\))\) - 
                  3.5305818622228062`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.021583800099224913`\)\ \
\((#1\^2 + #2\^2)\) + 0.00020704907854368946`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  23.556360680470743`\ \((1 - 
                        0.043167600198449826`\ \((#1\^2 + #2\^2)\) + 
                        0.00031057361781553416`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  0.22959942799387434`\ Cos[
                      3\ ArcTan[#1, #2]]\ \((\(-0.0024410123369934616`\)\ \
\((#1\^2 + #2\^2)\)\^\(3/2\) + 
                        0.00002195263430058696`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) - 
                  0.66407306357805`\ Cos[
                      ArcTan[#1, #2]]\ \((0.25446296449124917`\ \@\(#1\^2 + \
#2\^2\) - 0.007323037010980384`\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                        0.00004390526860117392`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) - 
                  0.0034590346973042974`\ Cos[
                      4\ ArcTan[#1, #2]]\ \((\(-0.00025881134817961184`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 2.2344529610078553`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  0.19458305985080682`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((0.043167600198449826`\ \((#1\^2 \
+ #2\^2)\) - 0.0010352453927184473`\ \((#1\^2 + #2\^2)\)\^2 + 
                        5.586132402519639`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  1.0438584511633542`\ \((\(-1\) + 
                        0.08633520039689965`\ \((#1\^2 + #2\^2)\) - 
                        0.001552868089077671`\ \((#1\^2 + #2\^2)\)\^2 + 
                        7.4481765366928515`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) + 
                  0.002152369645692566`\ Cos[
                      5\ ArcTan[#1, #2]]\ \((\(-0.00002634316116070435`\)\ \
\((#1\^2 + #2\^2)\)\^\(5/2\) + 
                        2.2111659285111997`*^-7\ \((#1\^2 + \
#2\^2)\)\^\(7/2\))\) - 
                  0.015095522870502115`\ Cos[
                      3\ ArcTan[#1, #2]]\ \((0.006102530842483654`\ \((#1\^2 \
+ #2\^2)\)\^\(3/2\) - 0.00013171580580352178`\ \((#1\^2 + #2\^2)\)\^\(5/2\) + 
                        6.633497785533599`*^-7\ \((#1\^2 + #2\^2)\)\^\(7/2\))\
\) - 0.11237987953768676`\ Cos[
                      ArcTan[#1, #2]]\ \((\(-0.3392839526549989`\)\ \@\(#1\^2 \
+ #2\^2\) + 0.018307592527450962`\ \((#1\^2 + #2\^2)\)\^\(3/2\) - 
                        0.00026343161160704355`\ \((#1\^2 + #2\^2)\)\^\(5/2\) \
+ 1.1055829642555997`*^-6\ \((#1\^2 + #2\^2)\)\^\(7/2\))\) + 
                  0.0008092927273675535`\ Cos[
                      6\ ArcTan[#1, #2]]\ \((\(-2.606861787842498`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 2.1434660462895443`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  0.0029519028568969798`\ Cos[
                      4\ ArcTan[#1, #2]]\ \((0.0007764340445388355`\ \((#1\^2 \
+ #2\^2)\)\^2 - 0.00001564117072705499`\ \((#1\^2 + #2\^2)\)\^3 + 
                        7.502131162013405`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.014161938867187968`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.0719460003307497`\)\ \
\((#1\^2 + #2\^2)\) + 0.003105736178155342`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00003910292681763747`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.500426232402681`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.056978123541884404`\ \((1 - 
                        0.1438920006614994`\ \((#1\^2 + #2\^2)\) + 
                        0.004658604267233013`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00005213723575684996`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.8755327905033514`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
              "-CompiledCode-"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {126.04534870668152`, 
            126.16250779516548`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      SurfaceGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      SurfaceGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics3D  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PaddingFactor \[Rule] Automatic\), 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.6764654496548795`\), 
                  0.6777892567970613`}, {\(-0.667593357948958`\), 
                  0.6688998028764511`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] False\), 
        ",", \(PlotPoints \[Rule] 100\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.6764654496548795`\), 
                  0.6777892567970613`}, {\(-0.667593357948958`\), 
                  0.6688998028764511`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{7.155085576474569`, \
\(-2.37185157231203`\), 0}, {13.737241216040012`, \(-2.4981094991585326`\), 
              0}}\), ",", \(PrinciplePointSeparation \[Rule] 
          6.583366458549512`\), 
        ",", \(RayBoundary \[Rule] {{\(-8.27888791350559`\), 
              8.27888791350559`}, {\(-8.393637353128023`\), 
              8.393637353128023`}}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {PointSpreadFunction, 
            OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), 
        ",", \(ResidualFitError \[Rule] 0.0015864140329534746`\), 
        ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
              532.6080819683433`, Astigmatism \[Rule] 221.09466067514762`, 
            FieldCurvature \[Rule] \(-232.7031345366057`\), 
            Distortion \[Rule] 7.707833514159915`, 
            Coma \[Rule] 83.16975223784266`}\), 
        ",", \(ShowPerfectCase \[Rule] False\), 
        ",", \(SignalPlotCutoff \[Rule] 0.01`\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 1351\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.00005198495614589626`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.1369978533943406`\), \
\(-19.106322781000188`\)}, {\(-0.021835313056153834`\), \
\(-1.2464337861714014`\)}}\), 
        ",", \(TransverseMagnification \[Rule] \(-1.1369978533943406`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-11.169418215034558`\), 
                  11.169418215034558`}, {\(-11.28416765465699`\), 
                  11.28416765465699`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[58]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
PSF[sys3D, FindImagePoint->True, FocalFraction->0, NumberOfPoints->128]\
\>", "Input",
  CellLabel->"In[59]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0563124 -1.06544 5.06363 [
[.07766 -0.0125 -12 -9 ]
[.07766 -0.0125 12 0 ]
[.21844 -0.0125 -6 -9 ]
[.21844 -0.0125 6 0 ]
[.35922 -0.0125 -12 -9 ]
[.35922 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64078 -0.0125 -9 -9 ]
[.64078 -0.0125 9 0 ]
[.78156 -0.0125 -3 -9 ]
[.78156 -0.0125 3 0 ]
[.92234 -0.0125 -9 -9 ]
[.92234 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04855 -24 -4.5 ]
[-0.0125 .04855 0 4.5 ]
[-0.0125 .14983 -24 -4.5 ]
[-0.0125 .14983 0 4.5 ]
[-0.0125 .2511 -24 -4.5 ]
[-0.0125 .2511 0 4.5 ]
[-0.0125 .35237 -24 -4.5 ]
[-0.0125 .35237 0 4.5 ]
[-0.0125 .45364 -18 -4.5 ]
[-0.0125 .45364 0 4.5 ]
[-0.0125 .55492 -24 -4.5 ]
[-0.0125 .55492 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -60 0 ]
[.5 .63053 60 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07766 0 m
.07766 .00625 L
s
[(-7.5)] .07766 -0.0125 0 1 Mshowa
.21844 0 m
.21844 .00625 L
s
[(-5)] .21844 -0.0125 0 1 Mshowa
.35922 0 m
.35922 .00625 L
s
[(-2.5)] .35922 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64078 0 m
.64078 .00625 L
s
[(2.5)] .64078 -0.0125 0 1 Mshowa
.78156 0 m
.78156 .00625 L
s
[(5)] .78156 -0.0125 0 1 Mshowa
.92234 0 m
.92234 .00625 L
s
[(7.5)] .92234 -0.0125 0 1 Mshowa
.125 Mabswid
.10581 0 m
.10581 .00375 L
s
.13397 0 m
.13397 .00375 L
s
.16213 0 m
.16213 .00375 L
s
.19028 0 m
.19028 .00375 L
s
.24659 0 m
.24659 .00375 L
s
.27475 0 m
.27475 .00375 L
s
.30291 0 m
.30291 .00375 L
s
.33106 0 m
.33106 .00375 L
s
.38738 0 m
.38738 .00375 L
s
.41553 0 m
.41553 .00375 L
s
.44369 0 m
.44369 .00375 L
s
.47184 0 m
.47184 .00375 L
s
.52816 0 m
.52816 .00375 L
s
.55631 0 m
.55631 .00375 L
s
.58447 0 m
.58447 .00375 L
s
.61262 0 m
.61262 .00375 L
s
.66894 0 m
.66894 .00375 L
s
.69709 0 m
.69709 .00375 L
s
.72525 0 m
.72525 .00375 L
s
.75341 0 m
.75341 .00375 L
s
.80972 0 m
.80972 .00375 L
s
.83787 0 m
.83787 .00375 L
s
.86603 0 m
.86603 .00375 L
s
.89419 0 m
.89419 .00375 L
s
.0495 0 m
.0495 .00375 L
s
.02134 0 m
.02134 .00375 L
s
.9505 0 m
.9505 .00375 L
s
.97866 0 m
.97866 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04855 m
.00625 .04855 L
s
[(0.22)] -0.0125 .04855 1 0 Mshowa
0 .14983 m
.00625 .14983 L
s
[(0.24)] -0.0125 .14983 1 0 Mshowa
0 .2511 m
.00625 .2511 L
s
[(0.26)] -0.0125 .2511 1 0 Mshowa
0 .35237 m
.00625 .35237 L
s
[(0.28)] -0.0125 .35237 1 0 Mshowa
0 .45364 m
.00625 .45364 L
s
[(0.3)] -0.0125 .45364 1 0 Mshowa
0 .55492 m
.00625 .55492 L
s
[(0.32)] -0.0125 .55492 1 0 Mshowa
.125 Mabswid
0 .07387 m
.00375 .07387 L
s
0 .09919 m
.00375 .09919 L
s
0 .12451 m
.00375 .12451 L
s
0 .17514 m
.00375 .17514 L
s
0 .20046 m
.00375 .20046 L
s
0 .22578 m
.00375 .22578 L
s
0 .27642 m
.00375 .27642 L
s
0 .30174 m
.00375 .30174 L
s
0 .32705 m
.00375 .32705 L
s
0 .37769 m
.00375 .37769 L
s
0 .40301 m
.00375 .40301 L
s
0 .42833 m
.00375 .42833 L
s
0 .47896 m
.00375 .47896 L
s
0 .50428 m
.00375 .50428 L
s
0 .5296 m
.00375 .5296 L
s
0 .02324 m
.00375 .02324 L
s
0 .58024 m
.00375 .58024 L
s
0 .60555 m
.00375 .60555 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07766 .61178 m
.07766 .61803 L
s
.21844 .61178 m
.21844 .61803 L
s
.35922 .61178 m
.35922 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64078 .61178 m
.64078 .61803 L
s
.78156 .61178 m
.78156 .61803 L
s
.92234 .61178 m
.92234 .61803 L
s
.125 Mabswid
.10581 .61428 m
.10581 .61803 L
s
.13397 .61428 m
.13397 .61803 L
s
.16213 .61428 m
.16213 .61803 L
s
.19028 .61428 m
.19028 .61803 L
s
.24659 .61428 m
.24659 .61803 L
s
.27475 .61428 m
.27475 .61803 L
s
.30291 .61428 m
.30291 .61803 L
s
.33106 .61428 m
.33106 .61803 L
s
.38738 .61428 m
.38738 .61803 L
s
.41553 .61428 m
.41553 .61803 L
s
.44369 .61428 m
.44369 .61803 L
s
.47184 .61428 m
.47184 .61803 L
s
.52816 .61428 m
.52816 .61803 L
s
.55631 .61428 m
.55631 .61803 L
s
.58447 .61428 m
.58447 .61803 L
s
.61262 .61428 m
.61262 .61803 L
s
.66894 .61428 m
.66894 .61803 L
s
.69709 .61428 m
.69709 .61803 L
s
.72525 .61428 m
.72525 .61803 L
s
.75341 .61428 m
.75341 .61803 L
s
.80972 .61428 m
.80972 .61803 L
s
.83787 .61428 m
.83787 .61803 L
s
.86603 .61428 m
.86603 .61803 L
s
.89419 .61428 m
.89419 .61803 L
s
.0495 .61428 m
.0495 .61803 L
s
.02134 .61428 m
.02134 .61803 L
s
.9505 .61428 m
.9505 .61803 L
s
.97866 .61428 m
.97866 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04855 m
1 .04855 L
s
.99375 .14983 m
1 .14983 L
s
.99375 .2511 m
1 .2511 L
s
.99375 .35237 m
1 .35237 L
s
.99375 .45364 m
1 .45364 L
s
.99375 .55492 m
1 .55492 L
s
.125 Mabswid
.99625 .07387 m
1 .07387 L
s
.99625 .09919 m
1 .09919 L
s
.99625 .12451 m
1 .12451 L
s
.99625 .17514 m
1 .17514 L
s
.99625 .20046 m
1 .20046 L
s
.99625 .22578 m
1 .22578 L
s
.99625 .27642 m
1 .27642 L
s
.99625 .30174 m
1 .30174 L
s
.99625 .32705 m
1 .32705 L
s
.99625 .37769 m
1 .37769 L
s
.99625 .40301 m
1 .40301 L
s
.99625 .42833 m
1 .42833 L
s
.99625 .47896 m
1 .47896 L
s
.99625 .50428 m
1 .50428 L
s
.99625 .5296 m
1 .5296 L
s
.99625 .02324 m
1 .02324 L
s
.99625 .58024 m
1 .58024 L
s
.99625 .60555 m
1 .60555 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Wave Front Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.03853 .23222 L
.04619 .32714 L
.05458 .40784 L
.06247 .46923 L
.06965 .50997 L
.07139 .51981 L
.07323 .53025 L
.07369 .53287 L
.07419 .53517 L
.07447 .53598 L
.07474 .53672 L
.07525 .53817 L
.07711 .54346 L
.08121 .55509 L
.08509 .56609 L
.08689 .5712 L
.08859 .57602 L
.08904 .57731 L
.08953 .57817 L
.08978 .57847 L
.09006 .5788 L
.09054 .57938 L
.09232 .58148 L
.09641 .58633 L
.10021 .59083 L
.10204 .59299 L
.10301 .59413 L
.10353 .59476 L
.10403 .59534 L
.10446 .59583 L
.10492 .59602 L
.10591 .59641 L
.10765 .59711 L
.11181 .59879 L
.11561 .60033 L
.11738 .60104 L
.11834 .60143 L
.11926 .60179 L
.11951 .6019 L
.11978 .60196 L
.12007 .60199 L
.12034 .60201 L
.12133 .6021 L
.12325 .60227 L
.12712 .60261 L
.13129 .60297 L
.13328 .60315 L
.13376 .60319 L
.13427 .60324 L
Mistroke
.13475 .60328 L
.13518 .60328 L
.1356 .60328 L
.13606 .60328 L
.13689 .60327 L
.13874 .60325 L
.14572 .60319 L
.14747 .60317 L
.14844 .60316 L
.14935 .60315 L
.1496 .60315 L
.14987 .60315 L
.15016 .60314 L
.15043 .60313 L
.15141 .60309 L
.15333 .60302 L
.16136 .60269 L
.17576 .60211 L
.1911 .60142 L
.20585 .60084 L
.22155 .60022 L
.23666 .59969 L
.2512 .59918 L
.26667 .5987 L
.28156 .59823 L
.29739 .59781 L
.31264 .59739 L
.32732 .59706 L
.34292 .5967 L
.35796 .59643 L
.37241 .59615 L
.3878 .59592 L
.40261 .5957 L
.41835 .59553 L
.42217 .5955 L
.42309 .59549 L
.42358 .59549 L
.42385 .59549 L
.4241 .59549 L
.42437 .59548 L
.42467 .59548 L
.42519 .59547 L
.42623 .59546 L
.43352 .59536 L
.43526 .59534 L
.43714 .59531 L
.43801 .5953 L
.43848 .5953 L
.43892 .59529 L
.4393 .59529 L
Mistroke
.43971 .59529 L
.44057 .59528 L
.44452 .59527 L
.44811 .59526 L
.45196 .59524 L
.45302 .59524 L
.45359 .59524 L
.45388 .59524 L
.45414 .59524 L
.45439 .59524 L
.45465 .59523 L
.4552 .59523 L
.45616 .59522 L
.46382 .59515 L
.46743 .59511 L
.46847 .5951 L
.46899 .5951 L
.46946 .59509 L
.46989 .59509 L
.47034 .59509 L
.47131 .59509 L
.47829 .5951 L
.48186 .5951 L
.48284 .5951 L
.48387 .5951 L
.4843 .5951 L
.48475 .5951 L
.48525 .5951 L
.48571 .5951 L
.49268 .59506 L
.49659 .59504 L
.49766 .59503 L
.49879 .59502 L
.49925 .59502 L
.49976 .59502 L
.50004 .59502 L
.5003 .59502 L
.50082 .59502 L
.5085 .59506 L
.51201 .59507 L
.51294 .59508 L
.51394 .59508 L
.5144 .59508 L
.51488 .59508 L
.5153 .59509 L
.51575 .59508 L
.5179 .59508 L
.51985 .59508 L
.52365 .59507 L
.52566 .59507 L
Mistroke
.52755 .59506 L
.52926 .59506 L
.52972 .59506 L
.53022 .59506 L
.53064 .59506 L
.5311 .59506 L
.53908 .59513 L
.54287 .59516 L
.54377 .59517 L
.54473 .59518 L
.5452 .59518 L
.54564 .59519 L
.54604 .59519 L
.54647 .59519 L
.54845 .59519 L
.55062 .5952 L
.55442 .5952 L
.55804 .59521 L
.55903 .59521 L
.55958 .59521 L
.56009 .59522 L
.56058 .59522 L
.56085 .59522 L
.5611 .59522 L
.56201 .59523 L
.57004 .59533 L
.57346 .59537 L
.57525 .5954 L
.57569 .5954 L
.57616 .59541 L
.57642 .59541 L
.57667 .59541 L
.57714 .59541 L
.57925 .59542 L
.58119 .59544 L
.58499 .59546 L
.58854 .59548 L
.59033 .59549 L
.59082 .59549 L
.59109 .59549 L
.59134 .59549 L
.59184 .5955 L
.5923 .59551 L
.59642 .59558 L
.60022 .59564 L
.61478 .59582 L
.63028 .59607 L
.6452 .59635 L
.66106 .59665 L
.67634 .59698 L
Mistroke
.69104 .59732 L
.70667 .59771 L
.72173 .59812 L
.73621 .59855 L
.75163 .59903 L
.76647 .59953 L
.78224 .60009 L
.79743 .60067 L
.81205 .60125 L
.8276 .60191 L
.84257 .60254 L
.85697 .60306 L
.86057 .60318 L
.86253 .60324 L
.86348 .60327 L
.86435 .6033 L
.86485 .60331 L
.86531 .60332 L
.8658 .60331 L
.86633 .6033 L
.8685 .60325 L
.8723 .60317 L
.87622 .60308 L
.87814 .60304 L
.87897 .60302 L
.87988 .60301 L
.88038 .60299 L
.88083 .6029 L
.88173 .60273 L
.88371 .60235 L
.8879 .60153 L
.89132 .60087 L
.89311 .60052 L
.89409 .60033 L
.895 .60016 L
.89549 .60006 L
.89576 .59992 L
.89601 .59975 L
.89711 .59899 L
.89905 .59767 L
.90285 .59508 L
.90639 .59266 L
.90833 .59133 L
.90927 .59068 L
.91014 .59009 L
.91063 .58976 L
.91109 .5891 L
.9121 .58726 L
.91426 .58335 L
.91806 .57646 L
Mistroke
.92171 .56983 L
.92372 .5662 L
.9247 .56441 L
.92513 .56363 L
.92561 .56277 L
.92605 .56185 L
.92647 .56019 L
.92737 .55658 L
.92928 .54896 L
.93261 .53568 L
.94744 .45539 L
.95131 .42676 L
.95336 .41165 L
.95553 .39561 L
.95742 .37741 L
.95951 .35317 L
.9632 .31043 L
.97619 .14203 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[59]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Joooo
o`?o00006Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo0_l0000Ioooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006_ooool3o`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00005?ooool0033ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00000I
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`00
0?ooooooooooo`0001Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Sooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Cooooo`00:?ooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003oooooooooo`0@ooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo000aooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04Oooool003;ooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo1?l0000Iooooo`05o`000?ooooooooooooooool000001oooool4o`0001Kooooo
00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Ioooo
o`Co00007Oooool00ol0003oooooooooo`05ooooo`Co00005?ooool002kooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
000Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Go
oooo000^ooooo`Go00001oooool5o`0001Sooooo1Ol0000Iooooo`?o00002?ooool5o`0001Kooooo
0_l0000Jooooo`?o00002?ooool5o`0001Sooooo1Ol0000Hooooo`Go00001oooool5o`0001?ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000QooooooSo0000
1oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001?ooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo07Sooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol000000ooooooo0000o`000003o`00
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Ooo
ool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool0N?ooool2o`0000Oooooo0007ooooo`04o`000?oooooo
ooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00007ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool01Oooool000Sooooo0_l00009ooooo`?o00000oooool3o`0000Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
1Oooool0027ooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0N?oo
ool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001Oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo07Sooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool2o`00
00Gooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1hooooo`;o00001oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool01Oooool000Sooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00000ooo
ool3o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00009ooooo`04o`00
0?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo0007ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000000oooool2o`0000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool0027ooooo0_l00006ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00001oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001ooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool00ooo
ool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`008Oooool2o`0000Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`002?oo
ool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00009oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`04o`0000Gooooo0_l00007ooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`04ooooo`;o00001oooool000Oooooo00Co0000oooo
oooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Wooooo0ol00004ooooo`;o0000
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`008Oooool2o`0000Sooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`008Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo0_l00008ooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05ooooo`;o
00001oooool0027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo000Qooooo`;o00002Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool01Oooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0008ooooo`;o
00001?ooool01?l0003oooooooooooooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool0000:ooooo`04o`00
0?ooooooooooooooo`?o00001Oooool2o`0000[ooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`001oooool01?l0003ooooo
ooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`001oooool01?l0
003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`002?oo
ool2o`0000Wooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`008Oooool2o`0000[o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Ko
oooo0_l00007ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool0027ooooo0_l0000;ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`07ooooo`;o00001oooool0027ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo06_ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01Oooool0027ooooo0_l0000<ooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`08ooooo`;o00001oooool0027ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool000gooooo
00Co0000oooooooooooo00002Oooool2o`0000Gooooo0_l0000<ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`09ooooo`;o00001oooool000gooooo
00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05oooo
o`003_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0Jooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00003Oooool0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02_ooool2
o`0000Oooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05
ooooo`008Oooool2o`0000oooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo00_ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1Oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`008Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`05ooooo`008Oooool2o`00013ooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo00gooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0I_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00002oooo
o`Go00001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`001oooool0
1?l0003oooooooooool0000;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo
0_l00005ooooo`03o`000?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0>ooooo`;o00001oooool000Oooooo00Co
0000oooooooooooo00002oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003ooooooooo
ool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
06Kooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo0008ooooo`;o00002Oooool3o`0000?o
oooo0ol00005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo06Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00005?ooool2o`0006?ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`0@ooooo`;o00001oooool0027ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`1Rooooo`;o00005Oooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0Fooooo`?o0000:ooooom^o`0002Wooooo0_l0000Gooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Wooooo0ol0000;oooooago0000=?ooool0
0ol0003oooooooooo`0goooooa[o00003?ooool4o`0001Sooooo00?o0000ooooooooool01Oooool0
027ooooo0_l0000Looooo`co0000DOooool00ol0003oooooooooo`1Aooooo`co00006oooool2o`00
00Oooooo000Qooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`05ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`008Ooooooho`0000Oooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003Booooo`?o0000Boooool00=?ooooo00?o
0000ooooooooool0B_ooool0067ooooo00?o0000ooooool000000oooool4o`0000?ooooo00?o0000
ooooooooool00_ooool3o`0000Sooooo0ol00003ooooo`?o00001?ooool3o`0000;ooooo0ol00000
0ooooooo0000o`000002ooooo`;o00002?ooool5o`000005ooooool0003o0000o`000?ooool00_l0
0002ooooo`;o00000oooool3o`0000;ooooo0ol000000ooooooo0000o`000004o`0000;ooooo1Ol0
0003ooooo`;o00001?ooool00ol0003oooooooooo`19ooooo`00HOooool00ol0003oooooo`000002
ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Ko
oooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`19ooooo`00HOooool00ol0003oooooo`000003
ooooo`?o00000oooool00ol0003oooooo`000002ooooo`Go00002?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooo
oooo00000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000004[ooooo001Pooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool0
00002?ooool3o`0000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool00000B_ooool0063ooooo00Go0000ooooool0
003oooooo`000002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0ol00009oooo
o`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`00
00;ooooo1?l0000:ooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`0000?ooooo0ol00002
ooooo`Co00000oooool4o`000004ooooool0003o0000o`0000?ooooo1?l00002ooooo`;o000000?o
ooooo`000?l00000BOooool0063ooooo00Go0000ooooool0003oooooo`00000Jooooo`04o`000?oo
ooooooooo`0001Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0D?ooool0063ooooo1_l0000Hooooo`Go00005?oo
ool00ol0003oooooooooo`08ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0D?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.2786, 0.20075, \
0.0718464, 0.000799001}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0563124 0.603316 0.114984 [
[.07766 -0.0125 -12 -9 ]
[.07766 -0.0125 12 0 ]
[.21844 -0.0125 -6 -9 ]
[.21844 -0.0125 6 0 ]
[.35922 -0.0125 -12 -9 ]
[.35922 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64078 -0.0125 -9 -9 ]
[.64078 -0.0125 9 0 ]
[.78156 -0.0125 -3 -9 ]
[.78156 -0.0125 3 0 ]
[.92234 -0.0125 -9 -9 ]
[.92234 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0284 -12 -4.5 ]
[-0.0125 .0284 0 4.5 ]
[-0.0125 .14338 -12 -4.5 ]
[-0.0125 .14338 0 4.5 ]
[-0.0125 .25836 -12 -4.5 ]
[-0.0125 .25836 0 4.5 ]
[-0.0125 .37335 -12 -4.5 ]
[-0.0125 .37335 0 4.5 ]
[-0.0125 .48833 -12 -4.5 ]
[-0.0125 .48833 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07766 0 m
.07766 .00625 L
s
[(-7.5)] .07766 -0.0125 0 1 Mshowa
.21844 0 m
.21844 .00625 L
s
[(-5)] .21844 -0.0125 0 1 Mshowa
.35922 0 m
.35922 .00625 L
s
[(-2.5)] .35922 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64078 0 m
.64078 .00625 L
s
[(2.5)] .64078 -0.0125 0 1 Mshowa
.78156 0 m
.78156 .00625 L
s
[(5)] .78156 -0.0125 0 1 Mshowa
.92234 0 m
.92234 .00625 L
s
[(7.5)] .92234 -0.0125 0 1 Mshowa
.125 Mabswid
.10581 0 m
.10581 .00375 L
s
.13397 0 m
.13397 .00375 L
s
.16213 0 m
.16213 .00375 L
s
.19028 0 m
.19028 .00375 L
s
.24659 0 m
.24659 .00375 L
s
.27475 0 m
.27475 .00375 L
s
.30291 0 m
.30291 .00375 L
s
.33106 0 m
.33106 .00375 L
s
.38738 0 m
.38738 .00375 L
s
.41553 0 m
.41553 .00375 L
s
.44369 0 m
.44369 .00375 L
s
.47184 0 m
.47184 .00375 L
s
.52816 0 m
.52816 .00375 L
s
.55631 0 m
.55631 .00375 L
s
.58447 0 m
.58447 .00375 L
s
.61262 0 m
.61262 .00375 L
s
.66894 0 m
.66894 .00375 L
s
.69709 0 m
.69709 .00375 L
s
.72525 0 m
.72525 .00375 L
s
.75341 0 m
.75341 .00375 L
s
.80972 0 m
.80972 .00375 L
s
.83787 0 m
.83787 .00375 L
s
.86603 0 m
.86603 .00375 L
s
.89419 0 m
.89419 .00375 L
s
.0495 0 m
.0495 .00375 L
s
.02134 0 m
.02134 .00375 L
s
.9505 0 m
.9505 .00375 L
s
.97866 0 m
.97866 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0284 m
.00625 .0284 L
s
[(-5)] -0.0125 .0284 1 0 Mshowa
0 .14338 m
.00625 .14338 L
s
[(-4)] -0.0125 .14338 1 0 Mshowa
0 .25836 m
.00625 .25836 L
s
[(-3)] -0.0125 .25836 1 0 Mshowa
0 .37335 m
.00625 .37335 L
s
[(-2)] -0.0125 .37335 1 0 Mshowa
0 .48833 m
.00625 .48833 L
s
[(-1)] -0.0125 .48833 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .05139 m
.00375 .05139 L
s
0 .07439 m
.00375 .07439 L
s
0 .09739 m
.00375 .09739 L
s
0 .12038 m
.00375 .12038 L
s
0 .16638 m
.00375 .16638 L
s
0 .18937 m
.00375 .18937 L
s
0 .21237 m
.00375 .21237 L
s
0 .23537 m
.00375 .23537 L
s
0 .28136 m
.00375 .28136 L
s
0 .30436 m
.00375 .30436 L
s
0 .32736 m
.00375 .32736 L
s
0 .35035 m
.00375 .35035 L
s
0 .39635 m
.00375 .39635 L
s
0 .41934 m
.00375 .41934 L
s
0 .44234 m
.00375 .44234 L
s
0 .46534 m
.00375 .46534 L
s
0 .51133 m
.00375 .51133 L
s
0 .53433 m
.00375 .53433 L
s
0 .55732 m
.00375 .55732 L
s
0 .58032 m
.00375 .58032 L
s
0 .0054 m
.00375 .0054 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07766 .61178 m
.07766 .61803 L
s
.21844 .61178 m
.21844 .61803 L
s
.35922 .61178 m
.35922 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64078 .61178 m
.64078 .61803 L
s
.78156 .61178 m
.78156 .61803 L
s
.92234 .61178 m
.92234 .61803 L
s
.125 Mabswid
.10581 .61428 m
.10581 .61803 L
s
.13397 .61428 m
.13397 .61803 L
s
.16213 .61428 m
.16213 .61803 L
s
.19028 .61428 m
.19028 .61803 L
s
.24659 .61428 m
.24659 .61803 L
s
.27475 .61428 m
.27475 .61803 L
s
.30291 .61428 m
.30291 .61803 L
s
.33106 .61428 m
.33106 .61803 L
s
.38738 .61428 m
.38738 .61803 L
s
.41553 .61428 m
.41553 .61803 L
s
.44369 .61428 m
.44369 .61803 L
s
.47184 .61428 m
.47184 .61803 L
s
.52816 .61428 m
.52816 .61803 L
s
.55631 .61428 m
.55631 .61803 L
s
.58447 .61428 m
.58447 .61803 L
s
.61262 .61428 m
.61262 .61803 L
s
.66894 .61428 m
.66894 .61803 L
s
.69709 .61428 m
.69709 .61803 L
s
.72525 .61428 m
.72525 .61803 L
s
.75341 .61428 m
.75341 .61803 L
s
.80972 .61428 m
.80972 .61803 L
s
.83787 .61428 m
.83787 .61803 L
s
.86603 .61428 m
.86603 .61803 L
s
.89419 .61428 m
.89419 .61803 L
s
.0495 .61428 m
.0495 .61803 L
s
.02134 .61428 m
.02134 .61803 L
s
.9505 .61428 m
.9505 .61803 L
s
.97866 .61428 m
.97866 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0284 m
1 .0284 L
s
.99375 .14338 m
1 .14338 L
s
.99375 .25836 m
1 .25836 L
s
.99375 .37335 m
1 .37335 L
s
.99375 .48833 m
1 .48833 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .05139 m
1 .05139 L
s
.99625 .07439 m
1 .07439 L
s
.99625 .09739 m
1 .09739 L
s
.99625 .12038 m
1 .12038 L
s
.99625 .16638 m
1 .16638 L
s
.99625 .18937 m
1 .18937 L
s
.99625 .21237 m
1 .21237 L
s
.99625 .23537 m
1 .23537 L
s
.99625 .28136 m
1 .28136 L
s
.99625 .30436 m
1 .30436 L
s
.99625 .32736 m
1 .32736 L
s
.99625 .35035 m
1 .35035 L
s
.99625 .39635 m
1 .39635 L
s
.99625 .41934 m
1 .41934 L
s
.99625 .44234 m
1 .44234 L
s
.99625 .46534 m
1 .46534 L
s
.99625 .51133 m
1 .51133 L
s
.99625 .53433 m
1 .53433 L
s
.99625 .55732 m
1 .55732 L
s
.99625 .58032 m
1 .58032 L
s
.99625 .0054 m
1 .0054 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.03853 .08449 L
.05458 .15328 L
.06965 .2114 L
.08415 .26178 L
.09958 .30988 L
.11444 .35118 L
.13023 .39012 L
.14544 .42318 L
.16007 .45119 L
.17564 .47725 L
.19063 .49903 L
.20504 .51718 L
.22039 .53378 L
.23516 .54736 L
.25087 .55951 L
.26599 .56923 L
.28054 .57695 L
.29603 .58365 L
.31093 .5888 L
.32678 .59309 L
.34204 .59624 L
.35672 .59853 L
.36417 .59945 L
.37234 .6003 L
.38739 .60149 L
.39482 .60193 L
.40279 .6023 L
.41088 .6026 L
.41854 .60282 L
.42613 .60298 L
.43315 .60309 L
.44026 .60317 L
.4443 .60321 L
.4481 .60324 L
.45185 .60326 L
.45579 .60327 L
.45916 .60329 L
.46284 .6033 L
.46676 .6033 L
.47031 .60331 L
.47228 .60331 L
.47442 .60331 L
.47642 .60332 L
.47829 .60332 L
.48003 .60332 L
.4819 .60332 L
.48296 .60332 L
.48397 .60332 L
.48587 .60332 L
Mistroke
.48683 .60332 L
.48786 .60332 L
.48874 .60332 L
.4897 .60332 L
.49083 .60332 L
.4919 .60332 L
.49293 .60332 L
.49342 .60332 L
.49388 .60332 L
.49433 .60332 L
.49482 .60332 L
.49568 .60332 L
.49616 .60332 L
.49668 .60332 L
.49712 .60332 L
.4976 .60332 L
.49805 .60332 L
.49846 .60332 L
.49891 .60332 L
.49939 .60332 L
.49981 .60332 L
.50019 .60332 L
.50062 .60332 L
.50107 .60332 L
.50133 .60332 L
.5016 .60332 L
.50209 .60332 L
.50262 .60332 L
.50319 .60332 L
.50369 .60332 L
.50423 .60332 L
.5052 .60332 L
.50568 .60332 L
.5062 .60332 L
.50716 .60332 L
.50809 .60332 L
.50895 .60332 L
.50986 .60332 L
.51071 .60332 L
.51161 .60332 L
.51261 .60332 L
.51428 .60332 L
.51605 .60332 L
.51801 .60332 L
.52011 .60332 L
.52209 .60332 L
.52389 .60331 L
.52573 .60331 L
.52769 .60331 L
.53119 .60331 L
Mistroke
.53496 .6033 L
.53911 .60329 L
.54298 .60328 L
.54651 .60326 L
.55059 .60324 L
.55447 .60322 L
.56202 .60315 L
.56902 .60306 L
.57685 .60292 L
.58394 .60275 L
.59127 .60253 L
.59921 .60222 L
.60681 .60184 L
.61484 .60134 L
.62931 .60014 L
.64472 .59833 L
.65955 .59596 L
.67531 .59259 L
.6905 .58835 L
.70511 .58321 L
.72065 .57638 L
.73562 .56828 L
.75001 .5589 L
.76533 .54695 L
.78007 .53331 L
.79575 .51624 L
.81086 .49701 L
.82538 .47565 L
.84084 .44954 L
.85572 .4208 L
.87154 .38601 L
.88678 .34798 L
.90144 .30686 L
.91703 .25785 L
.93205 .20512 L
.94649 .1489 L
.96187 .08269 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[59]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Joooo
o`?o00006Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo0_l0000Ioooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006_ooool3o`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00006_ooool002[ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00000I
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`00
0?ooooooooooo`0001Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Sooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Iooooo`008_ooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003oooooooooo`0@ooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo000[ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool05oooool002cooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo1?l0000Iooooo`05o`000?ooooooooooooooool000001oooool4o`0001Kooooo
00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Ioooo
o`Co00007Oooool00ol0003oooooooooo`05ooooo`Co00006_ooool002Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
000Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01_o
oooo000Xooooo`Go00001oooool5o`0001Sooooo1Ol0000Iooooo`?o00002?ooool5o`0001Kooooo
0_l0000Jooooo`?o00002?ooool5o`0001Sooooo1Ol0000Hooooo`Go00001oooool5o`0001Wooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000KooooooSo0000
3Oooool001_ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo
0_l0000=ooooo`006oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`004oooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;oooo
o`004_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`003?ooool5o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00_ooooo000Fooooo`03o`000?oooooooooo00;ooooo
0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`03ooooo`;o00003Oooool001;ooooo1?l00005ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02oooool001;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00_ooooo000Booooo`Go00001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02oooool001_ooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`04ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00001_ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01Oooool2o`0000gooooo000K
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`006oooool2
o`0000Sooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo
oooo00Kooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00002Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01oooool2o`0000gooooo000Koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo000Dooooo`?o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00_ooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0;ooooo`003?ooool5o`000003ooooool0003o000000?o00001?ooool2o`00
00[ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
00Wooooo0_l0000=ooooo`004_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool001?ooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o00001Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00003?ooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02_ooool2o`0000gooooo000Kooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
01_ooooo0_l0000=ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`0<ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`1Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Sooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00_ooooo000Kooooo`;o00003oooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool03Oooool2o`0000gooooo000Kooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo06Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`1Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`006oooool2o`00017ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00oooooo
0_l0000=ooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1V
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool001?ooooo0ol00005oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool001;ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool000co
oooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0;ooooo`005?ooool2o`0000Gooooo0_l0000Cooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`0@ooooo`;o00003Oooool001Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo000B
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00_ooooo000Cooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool001_o
oooo0_l0000Eooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`0Booooo`;o00003Oooool001_ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00_ooooo000Kooooo`;o00005oooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool05?ooool2o`0000gooooo000Kooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`006oooool2o`0001Sooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Kooooo0_l0
000=ooooo`006oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`;o00006_ooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool06?ooool2o`0000gooooo000Kooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0;ooooo`004_ooool5o`0000Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02oooool000cooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`005Oooool00ol0003ooooooooo
o`03ooooo`;o00007?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool06_ooool2o`0000gooooo000Booooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo000Booooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo000C
ooooo`?o00001Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0;ooooo`006oooool2o`0001oooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01gooooo0_l0000=ooooo`006ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00_o
oooo000Kooooo`;o00008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool07oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo000Kooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0;ooooo`006oooool2o`0002Cooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02;ooooo0_l0000=ooooo`006oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Doooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02oooool001_ooooo0_l0000W
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0U
ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo000Cooooo`?o0000
1Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo000Dooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`003?ooool5
o`0000?ooooo00?o0000ooooooooool01?ooool2o`0002[ooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Wooooo0_l0000=ooooo`005?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool001Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_o
oooo000Cooooo`;o00001_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo
000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`;o0000<?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0;Oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0;ooooo`006oooool2o`0003Cooooo0_l00013ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0<oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`0gooooo`;o0000?oooool00ol0003oooooooooo`0n
ooooo`;o0000>Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00_ooooo000Kooooo`;o0000>oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0>Oooool2o`0000gooooo000Kooooo`03o`00
0?oooooooooo03_ooooo0_l0000kooooo`03o`000?oooooooooo03[ooooo0_l0000mooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03gooooo0_l0000iooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`0oooooo`;o0000=oooool00ol0003oooooooooo`0gooooo`;o0000@?ooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0=Oooool2o`0004;ooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool0@_ooool2o`0003Cooooo00?o0000ooooooooool0<oooool2o`0004Co
oooo00?o0000ooooooooool02oooool001_ooooo0_l00015ooooo`;o0000<_ooool00ol0003ooooo
ooooo`0aooooo`;o0000AOooool2o`0000gooooo000Kooooo`03o`000?oooooooooo04Kooooo0ol0
000_ooooo`03o`000?oooooooooo02oooooo0_l00018ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo04Wooooo1?l0000[ooooo`03o`000?oooooooooo02_ooooo1?l0001:
ooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`1=oooo
o`Co00009oooool00ol0003oooooooooo`0Wooooo`Co0000C_ooool00ol0003oooooooooo`0;oooo
o`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo057ooooo0ol0000Toooo
o`03o`000?oooooooooo02?ooooo1?l0001Booooo`03o`000?oooooooooo00_ooooo000Cooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0E?ooool<o`0001Sooooo00?o0000oooo
ooooool05Oooool>o`0005Kooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooo
oooo00001?ooool2o`00067ooooo<?l0001Sooooo`;o00003Oooool001?ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool02oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;oooo
o`005?ooool2o`0000Gooooon?l0000=ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00;Oooool3o`0008[ooooo00?o0000ooooooooool0:oooool3o`0001Gooooo00?o0000oooo
ooooool07Oooool002kooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool07?ooool002Sooooo0ol00003ooooo`?o0000
1?ooool2o`0000;ooooo1Ol00002ooooo`?o00000oooool4o`000003ooooool0003o000000?o0000
1oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6o`0000Kooooo1?l00002ooooo`Go0000
00?oooooo`000?l000000ol000000ooooooo0000o`000003o`0000;ooooo0ol00002ooooo`?o0000
1?ooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`0000?ooooo0ol00009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool4o`0000?ooooo00?o0000oooooooo
ool00_ooool3o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000004ooooool0003o0000oooo
o`Co00000oooool2o`0000;ooooo2_l00005ooooo`03o`000?oooooooooo01_ooooo000Wooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ool000003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01_ooooo000Wooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?o
oooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooooooool5o`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Ko
0000oooooooooooo0000ooooool00005ooooo`Go00002?ooool00ol0003oooooooooo`02ooooo`05
o`000?oooooo0000ooooool000000_ooool3o`0000?ooooo00?o0000ooooool000000_ooool5o`00
00?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000;ooooo0ol00005oooo
o`03o`000?oooooooooo01_ooooo000Wooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
000000?ooooo00Co0000oooooooooooo00001Oooool01_l0003oooooooooool0003oooooo`0000So
oooo00?o0000ooooooooool06oooool002Oooooo00Ko0000ooooooooooooooooo`000?ooool4o`00
00;ooooo1?l00002ooooo`?o00001?ooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002Oooool0
1Ol0003oooooooooool0003ooooo00?o00001?ooool4o`0000;ooooo1?l00002ooooo`?o00000_oo
ool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`Co00000oooool3o`0000?ooooo0ol0
0009ooooo`03o`000?oooooooooo00;ooooo1_l000000ooooooo0000o`000003ooooo`;o000000?o
ooooo`000?l000000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1?l0
0003ooooo`Wo00000oooool3o`0000?ooooo1?l00004ooooo`03o`000?oooooooooo01_ooooo000W
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`00
:?ooool3o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`?o0000
2Oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`0000[ooooo1?l00004ooooo`03o`00
0?oooooooooo00Cooooo0_l00004ooooo`;o0000;_ooool00ol0003oooooooooo`0Hooooo`?o0000
5_ooool00ol0003oooooooooo`02ooooo`;o00002oooool00ol0003oooooooooo`0Mooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.8475, -5.67237, \
0.0718464, 0.0351862}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 7.54691 0.00938218 4.56135e-06 [
[.04719 -0.00312 -15 -9 ]
[.04719 -0.00312 15 0 ]
[.19812 -0.00312 -15 -9 ]
[.19812 -0.00312 15 0 ]
[.34906 -0.00312 -15 -9 ]
[.34906 -0.00312 15 0 ]
[.5 -0.00312 -3 -9 ]
[.5 -0.00312 3 0 ]
[.65094 -0.00312 -12 -9 ]
[.65094 -0.00312 12 0 ]
[.80188 -0.00312 -12 -9 ]
[.80188 -0.00312 12 0 ]
[.95281 -0.00312 -12 -9 ]
[.95281 -0.00312 12 0 ]
[.01131 .10061 -30 -4.5 ]
[.01131 .10061 0 4.5 ]
[.01131 .19184 -30 -4.5 ]
[.01131 .19184 0 4.5 ]
[.01131 .28306 -30 -4.5 ]
[.01131 .28306 0 4.5 ]
[.01131 .37429 -30 -4.5 ]
[.01131 .37429 0 4.5 ]
[.01131 .46552 -36 -4.5 ]
[.01131 .46552 0 4.5 ]
[.01131 .55674 -36 -4.5 ]
[.01131 .55674 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04719 .00938 m
.04719 .01563 L
s
[(-0.06)] .04719 -0.00312 0 1 Mshowa
.19812 .00938 m
.19812 .01563 L
s
[(-0.04)] .19812 -0.00312 0 1 Mshowa
.34906 .00938 m
.34906 .01563 L
s
[(-0.02)] .34906 -0.00312 0 1 Mshowa
.5 .00938 m
.5 .01563 L
s
[(0)] .5 -0.00312 0 1 Mshowa
.65094 .00938 m
.65094 .01563 L
s
[(0.02)] .65094 -0.00312 0 1 Mshowa
.80188 .00938 m
.80188 .01563 L
s
[(0.04)] .80188 -0.00312 0 1 Mshowa
.95281 .00938 m
.95281 .01563 L
s
[(0.06)] .95281 -0.00312 0 1 Mshowa
.125 Mabswid
.08492 .00938 m
.08492 .01313 L
s
.12265 .00938 m
.12265 .01313 L
s
.16039 .00938 m
.16039 .01313 L
s
.23586 .00938 m
.23586 .01313 L
s
.27359 .00938 m
.27359 .01313 L
s
.31133 .00938 m
.31133 .01313 L
s
.3868 .00938 m
.3868 .01313 L
s
.42453 .00938 m
.42453 .01313 L
s
.46227 .00938 m
.46227 .01313 L
s
.53773 .00938 m
.53773 .01313 L
s
.57547 .00938 m
.57547 .01313 L
s
.6132 .00938 m
.6132 .01313 L
s
.68867 .00938 m
.68867 .01313 L
s
.72641 .00938 m
.72641 .01313 L
s
.76414 .00938 m
.76414 .01313 L
s
.83961 .00938 m
.83961 .01313 L
s
.87735 .00938 m
.87735 .01313 L
s
.91508 .00938 m
.91508 .01313 L
s
.00945 .00938 m
.00945 .01313 L
s
.99055 .00938 m
.99055 .01313 L
s
.25 Mabswid
0 .00938 m
1 .00938 L
s
.02381 .10061 m
.03006 .10061 L
s
[(20000)] .01131 .10061 1 0 Mshowa
.02381 .19184 m
.03006 .19184 L
s
[(40000)] .01131 .19184 1 0 Mshowa
.02381 .28306 m
.03006 .28306 L
s
[(60000)] .01131 .28306 1 0 Mshowa
.02381 .37429 m
.03006 .37429 L
s
[(80000)] .01131 .37429 1 0 Mshowa
.02381 .46552 m
.03006 .46552 L
s
[(100000)] .01131 .46552 1 0 Mshowa
.02381 .55674 m
.03006 .55674 L
s
[(120000)] .01131 .55674 1 0 Mshowa
.125 Mabswid
.02381 .03219 m
.02756 .03219 L
s
.02381 .055 m
.02756 .055 L
s
.02381 .0778 m
.02756 .0778 L
s
.02381 .12342 m
.02756 .12342 L
s
.02381 .14622 m
.02756 .14622 L
s
.02381 .16903 m
.02756 .16903 L
s
.02381 .21464 m
.02756 .21464 L
s
.02381 .23745 m
.02756 .23745 L
s
.02381 .26026 m
.02756 .26026 L
s
.02381 .30587 m
.02756 .30587 L
s
.02381 .32868 m
.02756 .32868 L
s
.02381 .35148 m
.02756 .35148 L
s
.02381 .3971 m
.02756 .3971 L
s
.02381 .4199 m
.02756 .4199 L
s
.02381 .44271 m
.02756 .44271 L
s
.02381 .48832 m
.02756 .48832 L
s
.02381 .51113 m
.02756 .51113 L
s
.02381 .53394 m
.02756 .53394 L
s
.02381 .57955 m
.02756 .57955 L
s
.02381 .60236 m
.02756 .60236 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02723 .01476 L
.03097 .01481 L
.03286 .01483 L
.0339 .01484 L
.03488 .01486 L
.0358 .01487 L
.03605 .01487 L
.03632 .01487 L
.03679 .01492 L
.03853 .01509 L
.04221 .01546 L
.04617 .01585 L
.04733 .01596 L
.0479 .01602 L
.04843 .01607 L
.04891 .01612 L
.04918 .01611 L
.04943 .01611 L
.05051 .0161 L
.05458 .01607 L
.05644 .01605 L
.0584 .01603 L
.06007 .01602 L
.06053 .01602 L
.06102 .01601 L
.06149 .01602 L
.06191 .01605 L
.06603 .01637 L
.06984 .01668 L
.07166 .01682 L
.07255 .01689 L
.07337 .01696 L
.07379 .01699 L
.07422 .01699 L
.07467 .01697 L
.07515 .01695 L
.07711 .01688 L
.08126 .01672 L
.08502 .01658 L
.08592 .01655 L
.08637 .01653 L
.08687 .01653 L
.08712 .01653 L
.0874 .01653 L
.08791 .01653 L
.08886 .01653 L
.09249 .01654 L
.09463 .01654 L
.09666 .01654 L
Mistroke
.09755 .01654 L
.09803 .01655 L
.09849 .01655 L
.09875 .01655 L
.09903 .01655 L
.09952 .01654 L
.10047 .01651 L
.10793 .01634 L
.10998 .0163 L
.11052 .01628 L
.1111 .01627 L
.11137 .01626 L
.11166 .01625 L
.1119 .01624 L
.11217 .01623 L
.11423 .01613 L
.11611 .01603 L
.11986 .01585 L
.12182 .01575 L
.12289 .0157 L
.12341 .01567 L
.12389 .01565 L
.12434 .01565 L
.12477 .01567 L
.12571 .01571 L
.12769 .01579 L
.13118 .01594 L
.13489 .0161 L
.13579 .01614 L
.13629 .01616 L
.13676 .01616 L
.13703 .01616 L
.13732 .01615 L
.13782 .01614 L
.13882 .01611 L
.14244 .01601 L
.14585 .01591 L
.14757 .01587 L
.14804 .01585 L
.14854 .01584 L
.14896 .01583 L
.14942 .01586 L
.14969 .01589 L
.14994 .01592 L
.15041 .01597 L
.15147 .01609 L
.15337 .0163 L
.15726 .01673 L
.15938 .01697 L
.16042 .01709 L
Mistroke
.16088 .01714 L
.16137 .01719 L
.16184 .01723 L
.16227 .01725 L
.16312 .01729 L
.165 .01738 L
.16899 .01756 L
.17236 .01772 L
.17329 .01776 L
.1738 .01779 L
.17427 .01782 L
.17467 .01786 L
.1751 .01791 L
.17602 .01801 L
.18005 .01846 L
.18384 .01889 L
.19093 .0197 L
.19481 .02015 L
.19685 .02039 L
.19798 .02052 L
.19852 .02058 L
.19903 .02064 L
.19947 .02067 L
.19994 .02067 L
.20092 .02068 L
.20301 .02071 L
.20669 .02075 L
.20857 .02077 L
.21033 .02079 L
.21081 .0208 L
.21131 .0208 L
.21157 .0208 L
.21186 .02082 L
.21212 .02084 L
.21237 .02087 L
.21422 .02106 L
.21757 .02141 L
.22122 .02179 L
.22222 .0219 L
.22328 .02201 L
.2238 .02206 L
.22428 .02211 L
.22472 .02209 L
.22519 .02206 L
.22895 .02181 L
.23261 .02156 L
.23439 .02144 L
.23602 .02134 L
.23645 .02131 L
.23692 .02128 L
Mistroke
.23736 .0213 L
.23777 .02131 L
.23965 .02137 L
.24363 .0215 L
.24563 .02156 L
.24778 .02163 L
.24882 .02166 L
.24907 .02167 L
.24933 .02168 L
.24981 .02168 L
.2507 .02169 L
.25166 .0217 L
.25879 .02178 L
.26665 .02184 L
.27057 .02187 L
.27164 .02188 L
.27277 .02188 L
.27374 .02189 L
.27401 .02189 L
.27429 .02189 L
.27456 .02192 L
.2748 .02196 L
.28249 .02336 L
.28601 .024 L
.28643 .02407 L
.28687 .02415 L
.28735 .02421 L
.28779 .02424 L
.2888 .02433 L
.28975 .02441 L
.29386 .02477 L
.29585 .02494 L
.29766 .02509 L
.29856 .02517 L
.29903 .02521 L
.29953 .02526 L
.29997 .02537 L
.30045 .0255 L
.30129 .02572 L
.30518 .02673 L
.31217 .02855 L
.32754 .03194 L
.34232 .03465 L
.35804 .03728 L
.36 .03743 L
.36096 .03749 L
.36138 .03752 L
.36185 .03756 L
.36234 .03762 L
.36261 .03767 L
Mistroke
.36287 .03773 L
.36397 .03795 L
.3659 .03835 L
.36971 .03913 L
.37318 .03984 L
.37402 .04002 L
.37448 .04011 L
.37492 .04024 L
.37538 .04041 L
.37589 .0406 L
.3768 .04094 L
.38022 .04222 L
.38775 .04495 L
.3948 .04653 L
.39673 .04697 L
.39779 .0472 L
.39879 .04743 L
.39925 .04753 L
.39973 .04764 L
.39998 .04777 L
.40025 .04792 L
.40074 .04818 L
.4025 .04913 L
.41015 .05326 L
.4143 .05639 L
.41819 .06017 L
.42009 .06202 L
.42216 .06403 L
.42311 .06496 L
.42412 .06594 L
.42453 .06634 L
.42498 .06702 L
.42547 .0682 L
.42593 .06931 L
.433 .08635 L
.43475 .09058 L
.43572 .09291 L
.43663 .09512 L
.43688 .09572 L
.43715 .09637 L
.43744 .09741 L
.43771 .09898 L
.4387 .10469 L
.44062 .11586 L
.44449 .13837 L
.44865 .16257 L
.45254 .19396 L
.45609 .22637 L
.46307 .29111 L
.4782 .45422 L
Mistroke
.48213 .49429 L
.48583 .53203 L
.48667 .54056 L
.48707 .54472 L
.48745 .54851 L
.48784 .55038 L
.48826 .55225 L
.48915 .55621 L
.49103 .56451 L
.49275 .57215 L
.49634 .58807 L
.49823 .59647 L
.49873 .59868 L
.49927 .60107 L
.49952 .60216 L
.49978 .60332 L
.50025 .6032 L
.50073 .60106 L
.50126 .59872 L
.50238 .59376 L
.50435 .58503 L
.50824 .56782 L
.51025 .5589 L
.51124 .55452 L
.51167 .55259 L
.51215 .55048 L
.51258 .5483 L
.51298 .54421 L
.51386 .53526 L
.51571 .51639 L
.52369 .43498 L
.53848 .27563 L
.54601 .20715 L
.55421 .14599 L
.55802 .1239 L
.56011 .11179 L
.56113 .10585 L
.56207 .10039 L
.56254 .0977 L
.56297 .09625 L
.56342 .09516 L
.56391 .09396 L
.5659 .08914 L
.56936 .08075 L
.57128 .07611 L
.57335 .07106 L
.57431 .06875 L
.57483 .06749 L
.57532 .06649 L
.57573 .06608 L
Mistroke
.57618 .06565 L
.57713 .06472 L
.58421 .05781 L
.59225 .05194 L
.59595 .04995 L
.59785 .04893 L
.59892 .04836 L
.5999 .04783 L
.60037 .04761 L
.60064 .04755 L
.60089 .04749 L
.60194 .04725 L
.60385 .0468 L
.60744 .04597 L
.61444 .04412 L
.62153 .04153 L
.62925 .03935 L
.63345 .0385 L
.6353 .03813 L
.63628 .03793 L
.6368 .03783 L
.63734 .03772 L
.63782 .03762 L
.63809 .0376 L
.63834 .03758 L
.63925 .03751 L
.64105 .03738 L
.645 .03709 L
.64692 .03695 L
.64793 .03687 L
.64901 .03679 L
.64946 .03676 L
.64994 .03672 L
.65022 .0367 L
.65047 .03666 L
.65097 .03653 L
.65279 .03603 L
.65987 .0341 L
.66711 .0327 L
.67125 .03213 L
.67321 .03186 L
.675 .03161 L
.67591 .03144 L
.67686 .03121 L
.67887 .03072 L
.68251 .02983 L
.6905 .02784 L
.69439 .02683 L
.69807 .02587 L
.69968 .02546 L
Mistroke
.70007 .02536 L
.70049 .02525 L
.70095 .0252 L
.70138 .02516 L
.70325 .02499 L
.70497 .02483 L
.7086 .0245 L
.71058 .02432 L
.71241 .02415 L
.71291 .02411 L
.71338 .02404 L
.71391 .02394 L
.7144 .02386 L
.71657 .02347 L
.72038 .0228 L
.72409 .02214 L
.72499 .02198 L
.72525 .02194 L
.7255 .02189 L
.72596 .02188 L
.72623 .02188 L
.72647 .02188 L
.72702 .02187 L
.72802 .02186 L
.73505 .02181 L
.74999 .02169 L
.75762 .02148 L
.75971 .02143 L
.76085 .02139 L
.76191 .02136 L
.76238 .02135 L
.76282 .02134 L
.76307 .02133 L
.76333 .02134 L
.7638 .02137 L
.76586 .0215 L
.76972 .02175 L
.77183 .02188 L
.77381 .02201 L
.77467 .02206 L
.7751 .02209 L
.77549 .02212 L
.77594 .0221 L
.77644 .02205 L
.7773 .02197 L
.78115 .02158 L
.78518 .02118 L
.78614 .02108 L
.78715 .02098 L
.78757 .02094 L
Mistroke
.78802 .02089 L
.78851 .02087 L
.78897 .02086 L
.79237 .02081 L
.79606 .02075 L
.79793 .02072 L
.79896 .0207 L
.79993 .02069 L
.80043 .02068 L
.80071 .02068 L
.80097 .02065 L
.80212 .02052 L
.80415 .02028 L
.81181 .01939 L
.81963 .0185 L
.82344 .01807 L
.82432 .01797 L
.82524 .01787 L
.82562 .01782 L
.82603 .01779 L
.82648 .01777 L
.8269 .01775 L
.82864 .01766 L
.83051 .01757 L
.83392 .0174 L
.83593 .0173 L
.83692 .01725 L
.8374 .01722 L
.83784 .0172 L
.83827 .01718 L
.83867 .01714 L
.83955 .01704 L
.84142 .01684 L
.84515 .01644 L
.84718 .01621 L
.84908 .01601 L
.84992 .01592 L
.85033 .01587 L
.8507 .01583 L
.85114 .01582 L
.85161 .01583 L
.85244 .01585 L
.85612 .01594 L
.85955 .01602 L
.86135 .01606 L
.86234 .01609 L
.86281 .0161 L
.86325 .01611 L
.86374 .0161 L
.864 .01609 L
Mistroke
.86426 .01608 L
.86536 .01604 L
.8673 .01596 L
.8711 .01581 L
.87302 .01574 L
.87481 .01567 L
.87528 .01565 L
.87572 .01563 L
.87596 .01563 L
.87622 .01564 L
.87668 .01566 L
.87874 .01576 L
.88577 .0161 L
.88749 .01619 L
.88796 .01621 L
.88839 .01623 L
.88885 .01624 L
.88935 .01626 L
.89041 .01628 L
.89138 .01631 L
.89329 .01635 L
.89741 .01646 L
.89943 .0165 L
.90032 .01653 L
.90079 .01654 L
.90105 .01654 L
.90129 .01654 L
.90223 .01654 L
.90311 .01654 L
.90503 .01655 L
.90908 .01655 L
.91081 .01655 L
.91173 .01655 L
.91223 .01655 L
.91271 .01655 L
.91316 .01655 L
.91364 .01655 L
.91409 .01657 L
.91449 .01659 L
.91615 .01665 L
.91962 .01677 L
.92333 .01691 L
.92442 .01695 L
.92496 .01697 L
.92546 .01699 L
.92591 .017 L
.92639 .01699 L
.92687 .01695 L
.9274 .01691 L
.9312 .01662 L
Mistroke
.9348 .01635 L
.93676 .0162 L
.93771 .01613 L
.93813 .0161 L
.93858 .01606 L
.93907 .01607 L
.93954 .01607 L
.94056 .01607 L
.94272 .01609 L
.94652 .01611 L
.94826 .01612 L
.94922 .01612 L
.95013 .01613 L
.95065 .01613 L
.95094 .01613 L
.9512 .01613 L
.95168 .01608 L
.95218 .01603 L
.9541 .01585 L
.95796 .01547 L
.95998 .01527 L
.96212 .01507 L
.96299 .01498 L
.96347 .01494 L
.96392 .01491 L
.96418 .01491 L
.96446 .01491 L
.96494 .0149 L
.9659 .01488 L
.96937 .01483 L
.97619 .01473 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[59]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`009oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000Boooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool3o`00017ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00005oooool2o`0001[ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00004Oooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0ol0000Aooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000oooool3o`0000Gooooo000Vooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo00Co
0000oooooooooooo00006?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`007oooool5o`00
00;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool01oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01Ol0003o
ooooooooool0003ooooo00Go00002Oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000
6?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool04?ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01Ol0
000@ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00;ooooo000Vooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
oooooooo0000ooooo`04o`00017ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0
000Hooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0002ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
ooooool0003ooooo00Co00001Oooool002Kooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0001Cooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooo0000017ooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0
000Hooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo0000017ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0000Sooooo000Vooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000oooool2o`00017ooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0
000Hooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`;o00004Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01Oooool002Oooooo0_l0000:ooooo`;o00001?ooool2o`0001;ooooo
0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`;o00002_ooool2o`0000?ooooo
0ol0000Hooooo`;o00006_ooool2o`0000[ooooo0_l00003ooooo`?o00004_ooool2o`0000[ooooo
0_l00005ooooo`03o`000?oooooooooo013ooooo0_l0000:ooooo`;o00001?ooool2o`0000Gooooo
003oooooob7ooooo000Xooooo`03o`000?oooooooooo0?Gooooo000Xooooo`03o`000?oooooooooo
0?Gooooo000Xooooo`03o`000?oooooooooo0?Gooooo000Rooooooco00000_ooool002Cooooo00Co
0000oooooooooooooooo3?l00003oooooaCo00002Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo5?l00004ooooo`_o00000oooool00ol0003oooooooooo`02ooooo`00:?oo
ool00ol0003oooooooooo`09ooooo`Co00004_ooool;o`0009Kooooo2ol0000Aooooo`Ko00004ooo
ool002Sooooo00?o0000ooooooooool0:OoooolHo`0006Sooooo6?l0000dooooo`00:?ooool00ol0
003oooooooooo`11ooooo`Co0000G_ooool6o`0004cooooo000Xooooo`;o0000A_ooool7o`0005?o
oooo1?l0001Booooo`00:?ooool00ol0003oooooooooo`1<ooooo`Co0000Boooool4o`0005Kooooo
000Xooooo`03o`000?oooooooooo053ooooo1_l0000nooooo`Oo0000F_ooool002Sooooo00?o0000
ooooooooool0EOooool3o`0003Sooooo1?l0001Qooooo`00:?ooool00ol0003oooooooooo`1Hoooo
o`Go0000<?ooool3o`0006Gooooo000Xooooo`03o`000?oooooooooo05cooooo0_l0000^ooooo`;o
0000Ioooool002Sooooo0_l0001Oooooo`;o0000:oooool00ol0003oooooooooo`1Wooooo`00:?oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0J?oo
ool002Sooooo00?o0000ooooooooool0H?ooool2o`0002Oooooo00?o0000ooooooooool0JOooool0
02Sooooo00?o0000ooooooooool0HOooool2o`0002Cooooo0_l0001/ooooo`00:?ooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Joooool002Sooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06cooooo
000Xooooo`;o0000I?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06cooooo000X
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1/
ooooo`00:?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0K?ooool000Oooooo1Ol00003ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o
00001Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0KOooool000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo06Cooooo0_l0000Nooooo`;o0000Koooool000Wooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1^ooooo`002_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool3o`0006Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1^ooooo`001oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0K_ooool000Oooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06kooooo0008
ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000
ooooooooool0I_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06kooooo000Xoooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1_oooo
o`00:?ooool2o`0006Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1_ooooo`00
:?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
Koooool002Sooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo06oooooo000Xooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1_ooooo`00:?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0L?ooool002Sooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo073ooooo000Xooooo`;o0000J?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo073ooooo000Xooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1`ooooo`00:?ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0L?ooool002Sooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo073ooooo000Xooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1`ooooo`00
:?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
LOooool002Sooooo0_l0001Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOoo
ool002Sooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo077ooooo000Xooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`1aooooo`002Oooool3o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`1aooooo`002_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0LOooool000Oooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo0ol0001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0LOooool000Oo
oooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo06Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1booooo`00
2?ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07;ooooo0009
ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1booooo`002_ooool00ol0003o
ooooooooo`02ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0L_ooool002Sooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07;ooooo
000Xooooo`;o0000J_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07;ooooo000X
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1b
ooooo`00:?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0L_ooool002Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo07?ooooo000Xooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`1cooooo`00:?ooool00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0Loooool002Sooooo0_l0001Zooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0Loooool002Sooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo07?ooooo000Xooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1cooooo`00:?ooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Loooool002Sooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07?ooooo000X
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1c
ooooo`00:?ooool2o`0006_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1doooo
o`00:?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0M?ooool002Sooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo07Cooooo0008ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo07Cooooo0007ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1dooooo`001oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool3o`0006_ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1dooooo`001oooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
M?ooool000Oooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1d
ooooo`002?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07Co
oooo0009ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo
00?o0000ooooooooool0Joooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Gooooo
000Xooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1eooooo`00:?ooool2o`0006cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1e
ooooo`00:?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0MOooool002Sooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo07Gooooo000Xooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1eooooo`00:?ooool00ol0003oooooooooo`1/ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0MOooool002Sooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07Gooooo000Xooooo`;o0000KOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo07Gooooo000Xooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1eooooo`00:?ooool00ol0003ooooo
ooooo`1/ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0M_ooool002Sooooo00?o
0000ooooooooool0K?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Kooooo000X
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1f
ooooo`00:?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0M_ooool002Sooooo0_l0001^ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0M_ooool002Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo07Kooooo000Xooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1fooooo`002?ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1fooooo`001oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0M_ooool000Oooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo0ol0001]ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0M_ooool000Sooooo0ol00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo07Oooooo0007ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1gooooo`001oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0Moooool000Sooooo0ol00004ooooo`;o00001?ooool2o`0000Co
oooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Moooool002Sooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo07Oooooo000Xooooo`;o0000Koooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo07Oooooo000Xooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1gooooo`00:?ooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Moooool002Sooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Oooooo000Xooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1gooooo`00:?oo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0N?oo
ool002Sooooo0_l0001_ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0N?ooool0
02Sooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
07Sooooo000Xooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1hooooo`00:?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0N?ooool002Sooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo07Sooooo000Xooooo`;o0000L?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo07Sooooo000Xooooo`03o`000?oooooooooo06oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1hooooo`00:?ooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0N?ooool002Sooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07Sooooo0002ooooo`?o00001?oo
ool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1iooooo`000oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0NOooool000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo0ol0001_ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0NOooool000?ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Wooooo0003ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1iooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1iooooo`000oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2
o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo000Xooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1iooooo`00:?ooool2o`00077o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1iooooo`00:?ooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0NOooool002Sooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo000X
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1j
ooooo`00:?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0N_ooool002Sooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo07[ooooo000Xooooo`;o0000LOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07[ooooo000Xooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1jooooo`00:?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0N_ooool002Sooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07[ooooo000Xooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1jooooo`00:?ooool2o`0007;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1jooooo`00:?ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_ooool002Sooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07[ooooo0002oooo
o`?o00000_ooool5o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1joooo
o`000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0N_ooool000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07_ooooo0003ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo0ol0001booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Noooool000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Noooool000;ooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1kooooo`000oooool00ol0003ooooooooo
o`02ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07_ooooo000X
ooooo`03o`000?oooooooooo07?ooooo00Go0000ooooooooooooooooo`00001mooooo`00:?ooool0
0ol0003oooooooooo`1cooooo`05o`000?ooooooooooooooool00000OOooool002Sooooo0_l0001d
ooooo`04o`000?ooooooooooo`0007kooooo000Xooooo`03o`000?oooooooooo07Cooooo00?o0000
ooooool00000O_ooool002Sooooo00?o0000ooooooooool0M?ooool00ol0003oooooo`00001noooo
o`00:?ooool00ol0003oooooooooo`1dooooo`;o0000Ooooool002Sooooo00?o0000ooooooooool0
M?ooool2o`0007oooooo000Xooooo`;o0000MOooool2o`0007oooooo000Xooooo`03o`000?oooooo
oooo07Cooooo0_l0001oooooo`00:?ooool00ol0003oooooooooo`3eooooo`00:?ooool00ol0003o
ooooooooo`3eooooo`00:?ooool00ol0003oooooooooo`3eooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00KOooool3o`00057ooooo0ol0001Looooo`00K_ooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo05_ooooo0013ooooo`?o00001?ooool3o`0000;ooooo1Ol0
00001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o0000
0_ooool3o`0000Cooooo0ol00003ooooo`Co00000_ooool4o`0000Oooooo1Ol000001Ooooooo0000
o`000?l0003ooooo00;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l0
00001?l00002ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool01oooool3o`0000Go
oooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o00001?ooool2o`00
00;ooooo1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o000002?ooooo0014ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooooooo
ool0003oooooo`0000Kooooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo
000000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002Cooooo0014ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool5o`0000;ooooo0ol00002ooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0
003oooooo`0000Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Rooooo`00A?ooool3o`0000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0:ooooo`;o00000oooool01?l0003oooooooooool0
0002ooooo`;o00000oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`06o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000002Oooool3o`0000?ooooo00Co0000oooooooo
oooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo0000
1_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0Rooooo`00A?ooool01?l0003oooooooooool00002ooooo`?o00000_ooool3o`00
00?ooooo1?l00002ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`Co00000_ooool2o`00
0003ooooool0003o000000;ooooo0ol00003ooooo`;o00001?ooool3o`0000[ooooo00Co0000oooo
oooooooooooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Cooooo
o`000?l0003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oo
oooooooo00;ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co0000
0_ooool3o`0000Cooooo0ol00002ooooo`Co00009Oooool004Cooooo00Co0000oooooooooooo0000
5?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0001cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool03oooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo03Oooooo0013ooooo`Co
00002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0ol0000Kooooo`;o
00002?ooool5o`0000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0<?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0845236, -10608, \
0.000528273, 874.045}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 5\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] {0.1261948886085015`, 
            0.12624689038504655`}\), ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FindPupils \[Rule] True\), ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrequencyCutoff \[Rule] {304.0619384331368`, 
            303.93423730280796`}\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {207.28232192993164`, 0, 0}\), 
        ",", \(ImageSampleSize \[Rule] {0.0016604590606381776`, 
            0.001661143294540086`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(IntensityTransform \[Rule] True\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", \(NormalizePlot \[Rule] False\), 
        ",", \(NumberOfPoints \[Rule] 128\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 112.44620808978891`\), 
        ",", \(OpticalLengthFunction \[Rule] OpticalLengthFunction\), 
        ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(CompiledFunction[
              If[#1 == 0 && #2 == 0, 
                0.000022271117373179214`, \(-6.853627285348719`\) - 
                  3.532109641994116`*^-9\ Cos[
                      2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                  1.9515319104050795`*^-10\ Cos[
                      4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                  10.310895376241149`\ \((\(-1\) + 
                        0.013990424917235709`\ \((#1\^2 + #2\^2)\))\) - 
                  5.251099192578527`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.020985637375853565`\)\ \
\((#1\^2 + #2\^2)\) + 0.0001957319893648098`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  3.4781206500308235`\ \((1 - 
                        0.04197127475170713`\ \((#1\^2 + #2\^2)\) + 
                        0.0002935979840472147`\ \((#1\^2 + #2\^2)\)\^2)\) + 
                  4.27139394586925`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((\(-0.00024466498670601227`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 2.0537802758321623`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  3.396256590938641`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((0.04197127475170713`\ \((#1\^2 + \
#2\^2)\) - 0.000978659946824049`\ \((#1\^2 + #2\^2)\)\^2 + 
                        5.134450689580406`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  0.02108223618211115`\ \((\(-1\) + 
                        0.08394254950341426`\ \((#1\^2 + #2\^2)\) - 
                        0.0014679899202360734`\ \((#1\^2 + #2\^2)\)\^2 + 
                        6.845934252773875`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  7.380096153526266`*^-8\ Cos[
                      6\ ArcTan[#1, #2]]\ \((\(-2.396076988470856`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 1.9155505830353006`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  3.180054365542885`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((0.0007339949601180367`\ \((#1\^2 \
+ #2\^2)\)\^2 - 0.000014376461930825136`\ \((#1\^2 + #2\^2)\)\^3 + 
                        6.704427040623552`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  1.291385970907799`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.06995212458617854`\)\ \((#1\
\^2 + #2\^2)\) + 0.0029359798404721468`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00003594115482706284`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.3408854081247104`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.0002074059263440704`\ \((1 - 
                        0.13990424917235708`\ \((#1\^2 + #2\^2)\) + 
                        0.00440396976070822`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00004792153976941712`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.6761067601558881`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
              "-CompiledCode-"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {112.43537240553266`, 
            112.44620808978891`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PaddingFactor \[Rule] Automatic\), 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.10460892082020519`\), 
                  0.10626937988084338`}, {\(-0.10465202755602541`\), 
                  0.1063131708505655`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] True\), 
        ",", \(PlotPoints \[Rule] 64\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.10460892082020519`\), 
                  0.10626937988084338`}, {\(-0.10465202755602541`\), 
                  0.1063131708505655`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(RayBoundary \[Rule] {{\(-8.4562214163056`\), 
              8.4562214163056`}, {\(-8.452646568455712`\), 
              8.452646568455712`}}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {PointSpreadFunction, 
            OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), 
        ",", \(ResidualFitError \[Rule] 7.313862904893167`*^-7\), 
        ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
              82.9255011275954`, Astigmatism \[Rule] 0.0000417323567305451`, 
            FieldCurvature \[Rule] \(-0.24683256227325023`\), 
            Distortion \[Rule] \(-3.777962952267033`*^-13\), 
            Coma \[Rule] 1.3460273542456333`*^-12}\), 
        ",", \(ShowPerfectCase \[Rule] False\), 
        ",", \(SignalPlotCutoff \[Rule] 0.01`\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 584\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.015686737510906584`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-11.347295107870586`\), 
                  11.347295107870586`}, {\(-11.343720260020696`\), 
                  11.343720260020696`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[59]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["PSF[sys, NumberOfPoints->2048, NumberOfRays->128]", "Input",
  CellLabel->"In[66]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0209945 -1269.24 21.651 [
[.08011 -0.0125 -9 -9 ]
[.08011 -0.0125 9 0 ]
[.29006 -0.0125 -9 -9 ]
[.29006 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70994 -0.0125 -6 -9 ]
[.70994 -0.0125 6 0 ]
[.91989 -0.0125 -6 -9 ]
[.91989 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04885 -36 -4.5 ]
[-0.0125 .04885 0 4.5 ]
[-0.0125 .1571 -30 -4.5 ]
[-0.0125 .1571 0 4.5 ]
[-0.0125 .26536 -36 -4.5 ]
[-0.0125 .26536 0 4.5 ]
[-0.0125 .37361 -30 -4.5 ]
[-0.0125 .37361 0 4.5 ]
[-0.0125 .48187 -36 -4.5 ]
[-0.0125 .48187 0 4.5 ]
[-0.0125 .59012 -30 -4.5 ]
[-0.0125 .59012 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08011 0 m
.08011 .00625 L
s
[(-20)] .08011 -0.0125 0 1 Mshowa
.29006 0 m
.29006 .00625 L
s
[(-10)] .29006 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70994 0 m
.70994 .00625 L
s
[(10)] .70994 -0.0125 0 1 Mshowa
.91989 0 m
.91989 .00625 L
s
[(20)] .91989 -0.0125 0 1 Mshowa
.125 Mabswid
.1221 0 m
.1221 .00375 L
s
.16409 0 m
.16409 .00375 L
s
.20608 0 m
.20608 .00375 L
s
.24807 0 m
.24807 .00375 L
s
.33204 0 m
.33204 .00375 L
s
.37403 0 m
.37403 .00375 L
s
.41602 0 m
.41602 .00375 L
s
.45801 0 m
.45801 .00375 L
s
.54199 0 m
.54199 .00375 L
s
.58398 0 m
.58398 .00375 L
s
.62597 0 m
.62597 .00375 L
s
.66796 0 m
.66796 .00375 L
s
.75193 0 m
.75193 .00375 L
s
.79392 0 m
.79392 .00375 L
s
.83591 0 m
.83591 .00375 L
s
.8779 0 m
.8779 .00375 L
s
.03812 0 m
.03812 .00375 L
s
.96188 0 m
.96188 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04885 m
.00625 .04885 L
s
[(58.625)] -0.0125 .04885 1 0 Mshowa
0 .1571 m
.00625 .1571 L
s
[(58.63)] -0.0125 .1571 1 0 Mshowa
0 .26536 m
.00625 .26536 L
s
[(58.635)] -0.0125 .26536 1 0 Mshowa
0 .37361 m
.00625 .37361 L
s
[(58.64)] -0.0125 .37361 1 0 Mshowa
0 .48187 m
.00625 .48187 L
s
[(58.645)] -0.0125 .48187 1 0 Mshowa
0 .59012 m
.00625 .59012 L
s
[(58.65)] -0.0125 .59012 1 0 Mshowa
.125 Mabswid
0 .0705 m
.00375 .0705 L
s
0 .09215 m
.00375 .09215 L
s
0 .1138 m
.00375 .1138 L
s
0 .13545 m
.00375 .13545 L
s
0 .17875 m
.00375 .17875 L
s
0 .2004 m
.00375 .2004 L
s
0 .22205 m
.00375 .22205 L
s
0 .2437 m
.00375 .2437 L
s
0 .28701 m
.00375 .28701 L
s
0 .30866 m
.00375 .30866 L
s
0 .33031 m
.00375 .33031 L
s
0 .35196 m
.00375 .35196 L
s
0 .39526 m
.00375 .39526 L
s
0 .41691 m
.00375 .41691 L
s
0 .43856 m
.00375 .43856 L
s
0 .46021 m
.00375 .46021 L
s
0 .50352 m
.00375 .50352 L
s
0 .52517 m
.00375 .52517 L
s
0 .54682 m
.00375 .54682 L
s
0 .56847 m
.00375 .56847 L
s
0 .02719 m
.00375 .02719 L
s
0 .00554 m
.00375 .00554 L
s
0 .61177 m
.00375 .61177 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08011 .61178 m
.08011 .61803 L
s
.29006 .61178 m
.29006 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.70994 .61178 m
.70994 .61803 L
s
.91989 .61178 m
.91989 .61803 L
s
.125 Mabswid
.1221 .61428 m
.1221 .61803 L
s
.16409 .61428 m
.16409 .61803 L
s
.20608 .61428 m
.20608 .61803 L
s
.24807 .61428 m
.24807 .61803 L
s
.33204 .61428 m
.33204 .61803 L
s
.37403 .61428 m
.37403 .61803 L
s
.41602 .61428 m
.41602 .61803 L
s
.45801 .61428 m
.45801 .61803 L
s
.54199 .61428 m
.54199 .61803 L
s
.58398 .61428 m
.58398 .61803 L
s
.62597 .61428 m
.62597 .61803 L
s
.66796 .61428 m
.66796 .61803 L
s
.75193 .61428 m
.75193 .61803 L
s
.79392 .61428 m
.79392 .61803 L
s
.83591 .61428 m
.83591 .61803 L
s
.8779 .61428 m
.8779 .61803 L
s
.03812 .61428 m
.03812 .61803 L
s
.96188 .61428 m
.96188 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04885 m
1 .04885 L
s
.99375 .1571 m
1 .1571 L
s
.99375 .26536 m
1 .26536 L
s
.99375 .37361 m
1 .37361 L
s
.99375 .48187 m
1 .48187 L
s
.99375 .59012 m
1 .59012 L
s
.125 Mabswid
.99625 .0705 m
1 .0705 L
s
.99625 .09215 m
1 .09215 L
s
.99625 .1138 m
1 .1138 L
s
.99625 .13545 m
1 .13545 L
s
.99625 .17875 m
1 .17875 L
s
.99625 .2004 m
1 .2004 L
s
.99625 .22205 m
1 .22205 L
s
.99625 .2437 m
1 .2437 L
s
.99625 .28701 m
1 .28701 L
s
.99625 .30866 m
1 .30866 L
s
.99625 .33031 m
1 .33031 L
s
.99625 .35196 m
1 .35196 L
s
.99625 .39526 m
1 .39526 L
s
.99625 .41691 m
1 .41691 L
s
.99625 .43856 m
1 .43856 L
s
.99625 .46021 m
1 .46021 L
s
.99625 .50352 m
1 .50352 L
s
.99625 .52517 m
1 .52517 L
s
.99625 .54682 m
1 .54682 L
s
.99625 .56847 m
1 .56847 L
s
.99625 .02719 m
1 .02719 L
s
.99625 .00554 m
1 .00554 L
s
.99625 .61177 m
1 .61177 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .30239 Mdot
.03144 .34844 Mdot
.03907 .38986 Mdot
.04669 .42689 Mdot
.05431 .45975 Mdot
.06191 .48865 Mdot
.06951 .51382 Mdot
.0771 .53545 Mdot
.08469 .55374 Mdot
.09227 .56887 Mdot
.09984 .58102 Mdot
.10741 .59038 Mdot
.11497 .59711 Mdot
.12253 .60137 Mdot
.13008 .60332 Mdot
.13762 .60311 Mdot
.14516 .6009 Mdot
.1527 .59681 Mdot
.16023 .59099 Mdot
.16776 .58358 Mdot
.17528 .57468 Mdot
.1828 .56444 Mdot
.19031 .55297 Mdot
.19782 .54038 Mdot
.20533 .52678 Mdot
.21283 .51229 Mdot
.22033 .49699 Mdot
.22783 .48099 Mdot
.23532 .46439 Mdot
.24281 .44727 Mdot
.2503 .42973 Mdot
.25778 .41185 Mdot
.26526 .39371 Mdot
.27274 .37538 Mdot
.28021 .35695 Mdot
.28769 .33849 Mdot
.29516 .32006 Mdot
.30262 .30173 Mdot
.31009 .28356 Mdot
.31755 .26562 Mdot
.32502 .24796 Mdot
.33248 .23063 Mdot
.33993 .2137 Mdot
.34739 .1972 Mdot
.35484 .18119 Mdot
.3623 .16571 Mdot
.36975 .15081 Mdot
.3772 .13651 Mdot
.38465 .12287 Mdot
.3921 .10991 Mdot
.39954 .09768 Mdot
.40699 .08618 Mdot
.41443 .07547 Mdot
.42188 .06556 Mdot
.42932 .05647 Mdot
.43676 .04824 Mdot
.4442 .04087 Mdot
.45164 .03438 Mdot
.45908 .02879 Mdot
.46652 .02412 Mdot
.47396 .02037 Mdot
.4814 .01754 Mdot
.48884 .01566 Mdot
.49628 .01472 Mdot
.50372 .01472 Mdot
.51116 .01566 Mdot
.5186 .01754 Mdot
.52604 .02037 Mdot
.53348 .02412 Mdot
.54092 .02879 Mdot
.54836 .03438 Mdot
.5558 .04087 Mdot
.56324 .04824 Mdot
.57068 .05647 Mdot
.57812 .06556 Mdot
.58557 .07547 Mdot
.59301 .08618 Mdot
.60046 .09768 Mdot
.6079 .10991 Mdot
.61535 .12287 Mdot
.6228 .13651 Mdot
.63025 .15081 Mdot
.6377 .16571 Mdot
.64516 .18119 Mdot
.65261 .1972 Mdot
.66007 .2137 Mdot
.66752 .23063 Mdot
.67498 .24796 Mdot
.68245 .26562 Mdot
.68991 .28356 Mdot
.69738 .30173 Mdot
.70484 .32006 Mdot
.71231 .33849 Mdot
.71979 .35695 Mdot
.72726 .37538 Mdot
.73474 .39371 Mdot
.74222 .41185 Mdot
.7497 .42973 Mdot
.75719 .44727 Mdot
.76468 .46439 Mdot
.77217 .48099 Mdot
.77967 .49699 Mdot
.78717 .51229 Mdot
.79467 .52678 Mdot
.80218 .54038 Mdot
.80969 .55297 Mdot
.8172 .56444 Mdot
.82472 .57468 Mdot
.83224 .58358 Mdot
.83977 .59099 Mdot
.8473 .59681 Mdot
.85484 .6009 Mdot
.86238 .60311 Mdot
.86992 .60332 Mdot
.87747 .60137 Mdot
.88503 .59711 Mdot
.89259 .59038 Mdot
.90016 .58102 Mdot
.90773 .56887 Mdot
.91531 .55374 Mdot
.9229 .53545 Mdot
.93049 .51382 Mdot
.93809 .48865 Mdot
.94569 .45975 Mdot
.95331 .42689 Mdot
.96093 .38986 Mdot
.96856 .34844 Mdot
.97619 .30239 Mdot
.5 Mabswid
.02381 .30239 m
.03853 .3869 L
.05458 .46079 L
.06965 .51423 L
.08415 .55245 L
.09161 .56755 L
.09958 .58061 L
.1077 .59064 L
.11142 .59395 L
.11346 .59577 L
.11446 .59665 L
.11537 .59733 L
.11712 .59832 L
.11899 .59938 L
.1209 .60045 L
.12191 .60102 L
.12217 .60117 L
.12246 .60133 L
.12273 .60142 L
.12298 .60149 L
.12396 .60174 L
.12485 .60197 L
.12658 .60242 L
.12837 .60288 L
.12916 .60308 L
.12957 .60319 L
.13001 .6033 L
.13048 .60331 L
.13093 .6033 L
.1318 .60327 L
.13372 .60322 L
.13538 .60317 L
.13626 .60315 L
.13673 .60314 L
.13718 .60312 L
.13766 .6031 L
.13791 .60303 L
.13818 .60295 L
.13911 .60268 L
.14092 .60214 L
.14307 .60151 L
.14401 .60123 L
.14451 .60109 L
.14479 .60101 L
.14505 .60093 L
.14529 .60083 L
.14556 .60068 L
.14603 .60043 L
.14694 .59993 L
.14895 .59884 L
Mistroke
.15318 .59644 L
.16086 .59038 L
.17636 .57321 L
.19129 .55134 L
.20715 .52327 L
.22243 .49251 L
.23714 .46024 L
.25278 .4238 L
.26784 .38738 L
.28233 .35173 L
.29775 .3137 L
.31259 .27756 L
.32836 .24018 L
.34356 .20567 L
.35819 .17425 L
.37374 .14315 L
.38872 .11579 L
.40312 .09215 L
.41846 .07011 L
.43321 .05216 L
.44891 .03677 L
.45674 .03055 L
.46402 .02569 L
.4715 .02161 L
.47856 .01862 L
.48231 .01731 L
.48637 .01629 L
.48816 .01583 L
.4886 .01572 L
.48906 .01563 L
.48933 .0156 L
.48958 .01557 L
.49006 .0155 L
.49345 .01507 L
.49528 .01484 L
.49572 .01479 L
.4962 .01472 L
.49648 .01472 L
.49673 .01472 L
.49722 .01472 L
.50071 .01472 L
.50255 .01472 L
.50306 .01472 L
.50333 .01472 L
.50359 .01472 L
.50384 .01473 L
.5041 .01476 L
.50456 .01482 L
.50862 .01534 L
.51035 .01556 L
Mistroke
.51085 .01562 L
.51133 .0157 L
.51175 .01581 L
.51222 .01593 L
.51427 .01645 L
.51618 .01693 L
.5242 .01967 L
.5317 .02322 L
.53969 .02802 L
.55554 .04064 L
.57081 .05663 L
.5855 .07538 L
.60113 .09878 L
.61618 .12439 L
.63065 .15161 L
.64606 .18313 L
.66089 .21557 L
.67665 .25191 L
.69184 .28826 L
.70645 .32402 L
.72199 .36239 L
.73696 .39909 L
.75135 .43358 L
.76667 .4688 L
.78142 .50056 L
.7971 .53118 L
.8122 .55681 L
.82672 .57705 L
.83483 .58612 L
.84218 .59286 L
.84586 .5957 L
.84984 .59819 L
.85357 .60021 L
.85707 .60155 L
.86067 .60261 L
.86166 .6029 L
.86214 .60304 L
.86259 .60312 L
.86284 .60313 L
.8631 .60313 L
.86366 .60315 L
.86464 .60317 L
.86681 .60323 L
.86788 .60326 L
.86885 .60329 L
.86931 .6033 L
.86974 .60331 L
.87019 .60325 L
.87068 .60312 L
.87266 .60261 L
Mistroke
.87458 .60212 L
.87559 .60186 L
.87666 .60158 L
.87711 .60146 L
.87759 .6013 L
.87787 .60115 L
.87812 .601 L
.87862 .60072 L
.88044 .5997 L
.88751 .5949 L
.89126 .59157 L
.89474 .58773 L
.90263 .57705 L
.91045 .56345 L
.91753 .54838 L
.93279 .50619 L
.94747 .45206 L
.96309 .37811 L
.97619 .30239 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[66]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00>?ooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00004_ooool003Wooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`00017ooooo000booooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00017ooooo000kooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool03oooool003Sooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Aoooo
o`00>?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Aooooo`00>Oooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Booooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`009ooooooho`00007ooooo000Wooooo`;o00001oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Gooooo0_l00001ooooo`009oooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo07Wooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1eooooo`So0000Mooo
ool1o`00007ooooo000Wooooo`03o`000?oooooooooo077ooooo3ol0001dooooo`7o00000Oooool0
02Oooooo00?o0000ooooooooool0L?ooool5o`0000?ooooo00Co0000oooooooooooooooo1_l0001b
ooooo`7o00000Oooool002Oooooo0_l0001_ooooo`Co00001_ooool00ol0003oooooooooo`05oooo
o`Co0000Koooool2o`00007ooooo000Wooooo`03o`000?oooooooooo06kooooo0_l00008ooooo`03
o`000?oooooooooo00Oooooo0_l0001`ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0
K?ooool2o`0000[ooooo00?o0000ooooooooool02Oooool2o`0006kooooo0Ol00001ooooo`0000Co
ooooo`000?l0003o00000oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000;ooooo
1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`1Zooooo`Co00002_ooool00ol0003ooooo
ooooo`09ooooo`Co0000K?ooool1o`00007ooooo00001ol0003ooooooooooooooooo0000ooooool0
00000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Zooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`;o0000K?ooool1o`00007ooooo0004
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo06Sooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo0_l0001[ooooo`7o00000Ooo
ool000Cooooo00?o0000ooooooooool00ol00008ooooo`Co00001Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo0_l0001Yooooo`;o00003_ooool00ol0003oooooooooo`0<
ooooo`;o0000J_ooool2o`00007ooooo0004o`0000;ooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Gooooo
00?o0000ooooooooool0I_ooool3o`0000oooooo00?o0000ooooooooool03_ooool2o`0006Wooooo
0Ol00001ooooo`0000?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0
003oooooooooo`1Vooooo`;o00004?ooool00ol0003oooooooooo`0>ooooo`;o0000JOooool1o`00
007ooooo0005o`0000;ooooo0ol0000:ooooo`;o00000oooool3o`0000;ooooo1Ol00004ooooo`03
o`000?oooooooooo06Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo06Kooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1Tooooo`;o0000
4_ooool00ol0003oooooooooo`0@ooooo`;o0000Ioooool1o`00007ooooo000Wooooo`;o0000IOoo
ool2o`0001;ooooo00?o0000ooooooooool04?ooool3o`0006Gooooo0_l00001ooooo`009oooool0
0ol0003oooooooooo`1Sooooo`;o00004oooool00ol0003oooooooooo`0Booooo`;o0000IOooool1
o`00007ooooo000Wooooo`03o`000?oooooooooo06?ooooo0_l0000Cooooo`03o`000?oooooooooo
01;ooooo0_l0001Uooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0H_ooool1o`00007o
oooo000Wooooo`03o`000?oooooooooo067ooooo0_l0000Eooooo`03o`000?oooooooooo01Cooooo
0_l0001Sooooo`7o00000Oooool002Oooooo0_l0001Rooooo`;o00005Oooool00ol0003ooooooooo
o`0Dooooo`;o0000H_ooool2o`00007ooooo000Wooooo`03o`000?oooooooooo05oooooo0ol0000F
ooooo`03o`000?oooooooooo01Gooooo0ol0001Qooooo`7o00000Oooool002Oooooo00?o0000oooo
ooooool0Goooool2o`0001Oooooo00?o0000ooooooooool05_ooool2o`00067ooooo0Ol00001oooo
o`009oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`1Pooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
Goooool1o`00007ooooo000Wooooo`03o`000?oooooooooo05gooooo0_l0000Iooooo`03o`000?oo
oooooooo01Oooooo0_l0001Pooooo`7o00000Oooool002Oooooo0_l0001Nooooo`;o00006Oooool0
0ol0003oooooooooo`0Gooooo`;o0000Goooool2o`00007ooooo000Wooooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
05gooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1Kooooo`;o00006oooool00ol0003o
ooooooooo`0Iooooo`;o0000G_ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo05_ooooo
0_l0000Kooooo`03o`000?oooooooooo01Wooooo0_l0001Nooooo`7o00000Oooool002Oooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0Foooool1o`00007ooooo000Wooooo`;o0000F_ooool2o`0001gooooo00?o0000
ooooooooool06oooool2o`0005_ooooo0_l00001ooooo`009oooool00ol0003oooooooooo`1Ioooo
o`;o00007Oooool00ol0003oooooooooo`0Kooooo`;o0000G?ooool1o`00007ooooo000Wooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo05Wooooo0Ol00001ooooo`001oooool3o`0000?ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Iooooo`7o0000
0Oooool000Kooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000oooooooo
ool01Oooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05Sooooo0_l0000Nooooo`03o`000?oooooooooo01gooooo0_l0001J
ooooo`7o00000Oooool000[ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`;o0000FOooool2
o`0001kooooo00?o0000ooooooooool07Oooool2o`0005Wooooo0_l00001ooooo`002_ooool00ol0
003oooooooooo`03o`0000Sooooo1?l00004ooooo`;o00001Oooool00ol0003oooooooooo`1Goooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Goooo
o`7o00000Oooool000Kooooo1?l00002ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E_ooool2o`00
023ooooo00?o0000ooooooooool07oooool2o`0005Sooooo0Ol00001ooooo`001_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Fooooo`;o00008?ooool0
0ol0003oooooooooo`0Oooooo`;o0000F?ooool1o`00007ooooo0006ooooo`Go00000_ooool3o`00
00[ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Fooooo`7o00000Oooool002Oo
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0EOooool1o`00007ooooo000Wooooo`;o0000EOooool2o`0002;ooooo
00?o0000ooooooooool08Oooool2o`0005Gooooo0_l00001ooooo`009oooool00ol0003ooooooooo
o`1Dooooo`;o00008_ooool00ol0003oooooooooo`0Qooooo`;o0000E_ooool1o`00007ooooo000W
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo05Cooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Coooo
o`7o00000Oooool002Oooooo00?o0000ooooooooool0D_ooool2o`0002Cooooo00?o0000oooooooo
ool08oooool2o`0005Cooooo0Ol00001ooooo`009oooool2o`0005?ooooo0_l0000Tooooo`03o`00
0?oooooooooo02?ooooo0_l0001Cooooo`;o00000Oooool002Oooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oo
ool1o`00007ooooo000Wooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo0Ol00001ooooo`009oooool00ol0
003oooooooooo`1@ooooo`;o00009_ooool00ol0003oooooooooo`0Tooooo`;o0000Doooool1o`00
007ooooo000Wooooo`03o`000?oooooooooo053ooooo0_l0000Vooooo`03o`000?oooooooooo02Co
oooo0_l0001Cooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DOooool1o`00007ooooo
000Wooooo`;o0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0Coooool2o`00007ooooo000Wooooo`03o`000?oooooooooo04kooooo0ol0000W
ooooo`03o`000?oooooooooo02Kooooo0_l0001Aooooo`7o00000Oooool002Oooooo00?o0000oooo
ooooool0C_ooool2o`0002Sooooo00?o0000ooooooooool09_ooool2o`00057ooooo0Ol00001oooo
o`009oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`1?ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
Coooool1o`00007ooooo000Wooooo`;o0000Coooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0COooool2o`00007ooooo000Wooooo`03o`000?oooooo
oooo04gooooo0_l0000Yooooo`03o`000?oooooooooo02Sooooo0_l0001?ooooo`7o00000Oooool0
02Oooooo00?o0000ooooooooool0COooool2o`0002Wooooo00?o0000ooooooooool0:?ooool2o`00
04oooooo0Ol00001ooooo`0000Coooooo`000?l0003o00000oooool3o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000?ooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1=oooo
o`7o00000Oooool00007o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04cooooo0Ol00001ooooo`001?oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0004cooooo
0_l0000[ooooo`03o`000?oooooooooo02[ooooo0_l0001<ooooo`;o00000Oooool000Cooooo00?o
0000ooooooooool00ol00008ooooo`Co00001?ooool2o`0000Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1;ooooo`;o0000:oooool00ol0003oooooooooo`0Zooooo`;o0000COoo
ool1o`00007ooooo0004o`0000;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool00_ooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`1;ooooo`7o00000Oooool000Go00000_ooool3o`0000[ooooo0_l00003ooooo`?o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0BOooool2o`0002gooooo00?o0000ooooooooool0
;?ooool2o`0004_ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`19ooooo`;o0000;Ooo
ool00ol0003oooooooooo`0/ooooo`;o0000Boooool1o`00007ooooo000Wooooo`;o0000B_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0B?ooool2
o`00007ooooo000Wooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo04Wooooo0Ol00001ooooo`009oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`18ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool00_ooool2o`0004?ooooo
0_l0000_ooooo`03o`000?oooooooooo02kooooo0_l00012ooooo`;o00001Oooool1o`00007ooooo
000Wooooo`03o`000?oooooooooo00;ooooo0_l00013ooooo`;o0000;oooool00ol0003ooooooooo
o`0^ooooo`;o0000@_ooool2o`0000Gooooo0Ol00001ooooo`009oooool2o`0000Cooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`;o00000Oooool002Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`009oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo0_l0000aooooo`03
o`000?oooooooooo02oooooo0_l00011ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00
9oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo0_l0000aooooo`03o`00
0?oooooooooo02oooooo0_l00011ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`009ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01?oo
ool1o`00007ooooo000Wooooo`;o00001Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo00?ooooo0_l00001ooooo`009oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool01?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0??ooool2o`0003?ooooo00?o0000ooooooooool0<Oooool2o`0003oo
oooo00?o0000ooooooooool01?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0??ooool2o`0003?ooooo00?o0000ooooooooool0<Oooool2o`0003kooooo
00?o0000ooooooooool01Oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Cooooo0_l0
000nooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0kooooo`;o00001_ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Cooooo0_l0000m
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0k
ooooo`;o00001_ooool1o`00007ooooo000Wooooo`;o00001_ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00Cooooo0_l00001ooooo`009oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03Wooooo0ol0000dooooo`03o`000?oooooooooo03?ooooo0_l0000looooo`03
o`000?oooooooooo00Gooooo0Ol00001ooooo`001oooool3o`0000?ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00004ooooo`?o00001?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03Wooooo0_l0000eooooo`03o`000?oooooooooo03?ooooo0_l0000looooo`03o`00
0?oooooooooo00Gooooo0Ol00001ooooo`001_ooool01ol0003ooooooooooooooooo0000ooooool0
00000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`05ooooo`7o00000Oooool000[ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`05ooooo`06o`000?ooooooooooooooool0003ooooo1Ol00004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool0
00[ooooo00?o0000ooooooooool00ol00008ooooo`Co00000_ooool01?l0003oooooooooool00005
ooooo`;o00001oooool00ol0003oooooooooo`0gooooo`;o0000=_ooool00ol0003oooooooooo`0e
ooooo`;o0000>Oooool00ol0003oooooooooo`05ooooo`;o00000Oooool000Kooooo1?l00002oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`;o0000=_ooool0
0ol0003oooooooooo`0eooooo`;o0000>Oooool00ol0003oooooooooo`06ooooo`7o00000Oooool0
00Kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`001_ooool5o`0000;ooooo0ol0000:oooo
o`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`06ooooo`7o00000Oooool002Oooooo00?o0000oooooooo
ool01_ooool2o`0003Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Gooooo0_l00008ooooo`7o00000Oooool002Oooooo0_l00007ooooo`;o0000
=_ooool2o`0003Sooooo00?o0000ooooooooool0=oooool2o`0003Kooooo0_l00007ooooo`;o0000
0Oooool002Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0dooooo`;o0000>?oo
ool00ol0003oooooooooo`0gooooo`;o0000=_ooool00ol0003oooooooooo`07ooooo`7o00000Ooo
ool002Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo00Oooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool01oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0<_ooool2o`0003[ooooo00?o0000ooooooooool0>Oooool2o`0003?o
oooo00?o0000ooooooooool02?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<_ooool2o`0003[ooooo00?o0000ooooooooool0>Oooool2o`0003?ooooo
00?o0000ooooooooool02?ooool1o`00007ooooo000Wooooo`;o00002Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo0_l00001ooooo`009oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02?ooool1o`00007ooooo000Woooo
o`03o`000?oooooooooo00Sooooo0_l0000aooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0_ooooo`;o00002_ooool1o`00007ooooo000Wooooo`03
o`000?oooooooooo00Sooooo0_l0000`ooooo`;o0000??ooool00ol0003oooooooooo`0kooooo`;o
0000<?ooool2o`0000[ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02oooooo0_l0000looooo`03o`000?oooooooooo03_ooooo0_l0000`ooooo`03o`00
0?oooooooooo00Wooooo0Ol00001ooooo`009oooool2o`0000[ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`08ooooo`;o00000Oooool002Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`009oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02cooooo0_l0000nooooo`03o`000?oooooooooo
03cooooo0_l0000^ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`009oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02cooooo0_l0000nooooo`03o`000?oooooooooo03co
oooo0_l0000^ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`009oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_ooool1o`00007ooooo
000Wooooo`;o00002oooool2o`0002cooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo02[ooooo0_l0000;ooooo`;o00000Oooool002Oooooo00?o0000
ooooooooool02_ooool2o`0002[ooooo0ol0000oooooo`03o`000?oooooooooo03kooooo0_l0000[
ooooo`;o00003?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:Oooool2o`00043ooooo00?o0000ooooooooool0?_ooool2o`0002_ooooo00?o0000oooo
ooooool02oooool1o`00007ooooo00001?oooooo0000o`000?l00003ooooo`?o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001?ooool3o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`7o00000Oooool00007
o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
3?ooool1o`00007ooooo0004ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Ooo
ool01_l0003ooooooooooooooooo0000ooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool09oooool2o`00047ooooo00?o0000oooooooo
ool0@?ooool2o`0002Sooooo00?o0000ooooooooool03?ooool1o`00007ooooo0004ooooo`03o`00
0?oooooooooo00?o00002?ooool4o`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooooooo`02ooooo`;o00003?ooool00ol0003oooooooooo`0Wooooo`;o0000@Oooool00ol0003o
ooooooooo`10ooooo`;o0000:?ooool00ol0003oooooooooo`0;ooooo`;o00000Oooool000Co0000
0_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`000002ooooo`Co00001Oooool00ol0003oooooooooo`0<ooooo`;o00009oooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool09Oooool2o`0000ko
oooo0Ol00001ooooo`0000?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool01?ooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0<ooooo`;o00009_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool09?ooool2o`0000kooooo0Ol00001ooooo`001Ol00002ooooo`?o0000
2_ooool2o`0000Gooooo00?o0000ooooooooool01Ol00004ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool09?ooool2o`0004?ooooo00?o0000ooooooooool0@_ooool2o`0002Gooooo
00?o0000ooooooooool03Oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool08oooool2o`0004?ooooo00?o0000ooooooooool0@_ooool2o`0002Gooooo00?o
0000ooooooooool03Oooool1o`00007ooooo000Wooooo`;o00003_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00gooooo0_l00001ooooo`009oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool1o`00007ooooo000Wooooo`03
o`000?oooooooooo00gooooo0_l0000Rooooo`;o0000AOooool00ol0003oooooooooo`14ooooo`;o
00008Oooool2o`00013ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`0=ooooo`;o0000
8_ooool2o`0004Gooooo00?o0000ooooooooool0A?ooool2o`00027ooooo0_l0000@ooooo`7o0000
0Oooool002Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00oooooo0Ol00001ooooo`009oooool2o`00013ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0>ooooo`;o00000Oooool002Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Mooooo`;o0000Aoooool00ol0003oooooooooo`16ooooo`;o00007oooool00ol0
003oooooooooo`0?ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Looooo`;o0000Aoooool00ol0003oooooooooo`16ooooo`;o00007_ooool00ol0003o
ooooooooo`0@ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool03oooool2o`0001kooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01_ooooo
0_l0000Booooo`7o00000Oooool002Oooooo00?o0000ooooooooool03oooool2o`0001cooooo0_l0
0019ooooo`03o`000?oooooooooo04Oooooo0_l0000Looooo`;o00004_ooool1o`00007ooooo000W
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06Oooool2o`0004Wooooo00?o0000
ooooooooool0Aoooool3o`0001_ooooo00?o0000ooooooooool04Oooool1o`00007ooooo000Woooo
o`;o00004_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo013ooooo0_l00001oooo
o`009oooool00ol0003oooooooooo`0Aooooo`;o00006?ooool2o`0004_ooooo00?o0000oooooooo
ool0BOooool2o`0001Sooooo0ol0000Cooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0
4Oooool2o`0001Sooooo0_l0001;ooooo`03o`000?oooooooooo04Wooooo0ol0000Gooooo`;o0000
5?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Booooo`7o00000Oooool002Oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Cooooo`;o0000COooool00ol0003oooooooooo`1;ooooo`;o00005_ooool0
0ol0003oooooooooo`0Cooooo`7o00000Oooool002Oooooo0_l0000Dooooo`;o00005?ooool2o`00
04gooooo00?o0000ooooooooool0Boooool3o`0001Cooooo0_l0000Dooooo`;o00000Oooool002Oo
oooo00?o0000ooooooooool04oooool2o`0001?ooooo0_l0001>ooooo`03o`000?oooooooooo04go
oooo0_l0000Cooooo`;o00005Oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool04?ooool2o`0004kooooo00?o0000ooooooooool0COooool2o`0001;ooooo
00?o0000ooooooooool05Oooool1o`00007ooooo0007ooooo`?o00000oooool3o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo01Gooooo0_l0
000@ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`0?ooooo`;o00005oooool1o`00007ooooo0006ooooo`07o`000?ooooooooooooooool0003ooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`;o00003oooool2o`00
053ooooo00?o0000ooooooooool0Coooool2o`0000oooooo0_l0000Gooooo`7o00000Oooool000[o
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo0_l0000;oooo
o`Co0000D?ooool00ol0003oooooooooo`1?ooooo`Co00002oooool2o`0001Wooooo0Ol00001oooo
o`002_ooool00ol0003oooooooooo`03o`0000Sooooo1?l00006ooooo`03o`000?oooooooooo00;o
oooo0_l0000Hooooo`;o00002oooool2o`0005;ooooo00?o0000ooooooooool0DOooool2o`0000_o
oooo0_l0000Hooooo`;o00000Oooool000Kooooo1?l00002ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`03ooooo`Co00001Oooool00ol0003oooooooooo`0Iooooo`;o
00001oooool2o`0005Cooooo00?o0000ooooooooool0Doooool2o`0000Oooooo0_l0000Kooooo`7o
00000Oooool000Kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wo
oooo2ol0001Dooooo`03o`000?oooooooooo05?ooooo2ol0000Kooooo`7o00000Oooool000Kooooo
1Ol00002ooooo`?o00002_ooool2o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo01[ooooo
2?l0001Fooooo`03o`000?oooooooooo05Gooooo1ol0000Mooooo`7o00000Oooool002Oooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o00000Oooool002Oooooo0_l00007
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool2o`00007ooooo000Woooo
ooSo00000Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool003?ooooo0ol0001H
ooooo`?o00005oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00_ooooo000doooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo00[ooooo000^ooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go
00000_ooool3o`0000?ooooo1?l000000ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co
00000oooool2o`0000;ooooo1_l00006ooooo`Go00000_ooool3o`0000;ooooo0ol000001?oooooo
0000o`000?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool00ol0003oooooooooo`03oooo
o`Co000000?oooooo`000?l000000_l00002ooooo`Co00000oooool3o`0000;ooooo1Ol00003oooo
o`;o000000Coooooo`000?oooooooooo0_l00003ooooo`?o00002Oooool4o`000003ooooool0003o
000000?o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool4o`000005ooooool0003o
0000o`000?ooool00_l000001?oooooo0000o`000?l00003ooooo`?o00001Oooool00ol0003ooooo
ooooo`09ooooo`00;Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00000_ooool01_l0003o
ooooooooool0003oooooo`0000_ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooool000000oooool00ol0003oooooo`000008ooooo`03
o`000?oooooooooo00Wooooo000]ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00003
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo0ol00003
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00002ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool5o`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooo
o`?o00000oooool00ol0003oooooooooo`03ooooo`?o00000oooool01_l0003oooooooooool0003o
ooooo`0000Gooooo1Ol00004ooooo`03o`000?oooooooooo00Wooooo000]ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`?o00000_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000Go
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`09ooooo`00;Oooool01_l0003ooooooooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo
0ol00004ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?o
oooo0ol00002ooooo`Co00000oooool9o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`?o00000oooool4o`0000;ooooo0ol00004ooooo`04o`000?oooooooooooooo
o`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`?o00002Oooool3o`0000;ooooo0ol00004
ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00000oooool4o`0000?ooooo0ol00003
ooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`00;Oooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00[ooooo000^ooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00gooooo0ol00009ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool3
o`0001Kooooo00?o0000ooooooooool00_ooool2o`0000gooooo00?o0000ooooooooool01_ooool2
o`00013ooooo0ol0000:ooooo`03o`000?oooooooooo013ooooo0_l00004ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-31.4083, 58.6204, 0.19271, \
0.000186866}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0209945 -1.35423 0.887842 [
[.08011 -0.0125 -9 -9 ]
[.08011 -0.0125 9 0 ]
[.29006 -0.0125 -9 -9 ]
[.29006 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70994 -0.0125 -6 -9 ]
[.70994 -0.0125 6 0 ]
[.91989 -0.0125 -6 -9 ]
[.91989 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06632 -18 -4.5 ]
[-0.0125 .06632 0 4.5 ]
[-0.0125 .1551 -18 -4.5 ]
[-0.0125 .1551 0 4.5 ]
[-0.0125 .24389 -18 -4.5 ]
[-0.0125 .24389 0 4.5 ]
[-0.0125 .33267 -18 -4.5 ]
[-0.0125 .33267 0 4.5 ]
[-0.0125 .42146 -6 -4.5 ]
[-0.0125 .42146 0 4.5 ]
[-0.0125 .51024 -18 -4.5 ]
[-0.0125 .51024 0 4.5 ]
[-0.0125 .59902 -18 -4.5 ]
[-0.0125 .59902 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08011 0 m
.08011 .00625 L
s
[(-20)] .08011 -0.0125 0 1 Mshowa
.29006 0 m
.29006 .00625 L
s
[(-10)] .29006 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70994 0 m
.70994 .00625 L
s
[(10)] .70994 -0.0125 0 1 Mshowa
.91989 0 m
.91989 .00625 L
s
[(20)] .91989 -0.0125 0 1 Mshowa
.125 Mabswid
.1221 0 m
.1221 .00375 L
s
.16409 0 m
.16409 .00375 L
s
.20608 0 m
.20608 .00375 L
s
.24807 0 m
.24807 .00375 L
s
.33204 0 m
.33204 .00375 L
s
.37403 0 m
.37403 .00375 L
s
.41602 0 m
.41602 .00375 L
s
.45801 0 m
.45801 .00375 L
s
.54199 0 m
.54199 .00375 L
s
.58398 0 m
.58398 .00375 L
s
.62597 0 m
.62597 .00375 L
s
.66796 0 m
.66796 .00375 L
s
.75193 0 m
.75193 .00375 L
s
.79392 0 m
.79392 .00375 L
s
.83591 0 m
.83591 .00375 L
s
.8779 0 m
.8779 .00375 L
s
.03812 0 m
.03812 .00375 L
s
.96188 0 m
.96188 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06632 m
.00625 .06632 L
s
[(1.6)] -0.0125 .06632 1 0 Mshowa
0 .1551 m
.00625 .1551 L
s
[(1.7)] -0.0125 .1551 1 0 Mshowa
0 .24389 m
.00625 .24389 L
s
[(1.8)] -0.0125 .24389 1 0 Mshowa
0 .33267 m
.00625 .33267 L
s
[(1.9)] -0.0125 .33267 1 0 Mshowa
0 .42146 m
.00625 .42146 L
s
[(2)] -0.0125 .42146 1 0 Mshowa
0 .51024 m
.00625 .51024 L
s
[(2.1)] -0.0125 .51024 1 0 Mshowa
0 .59902 m
.00625 .59902 L
s
[(2.2)] -0.0125 .59902 1 0 Mshowa
.125 Mabswid
0 .08408 m
.00375 .08408 L
s
0 .10183 m
.00375 .10183 L
s
0 .11959 m
.00375 .11959 L
s
0 .13735 m
.00375 .13735 L
s
0 .17286 m
.00375 .17286 L
s
0 .19062 m
.00375 .19062 L
s
0 .20837 m
.00375 .20837 L
s
0 .22613 m
.00375 .22613 L
s
0 .26164 m
.00375 .26164 L
s
0 .2794 m
.00375 .2794 L
s
0 .29716 m
.00375 .29716 L
s
0 .31491 m
.00375 .31491 L
s
0 .35043 m
.00375 .35043 L
s
0 .36818 m
.00375 .36818 L
s
0 .38594 m
.00375 .38594 L
s
0 .4037 m
.00375 .4037 L
s
0 .43921 m
.00375 .43921 L
s
0 .45697 m
.00375 .45697 L
s
0 .47473 m
.00375 .47473 L
s
0 .49248 m
.00375 .49248 L
s
0 .528 m
.00375 .528 L
s
0 .54575 m
.00375 .54575 L
s
0 .56351 m
.00375 .56351 L
s
0 .58127 m
.00375 .58127 L
s
0 .04856 m
.00375 .04856 L
s
0 .0308 m
.00375 .0308 L
s
0 .01305 m
.00375 .01305 L
s
0 .61678 m
.00375 .61678 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08011 .61178 m
.08011 .61803 L
s
.29006 .61178 m
.29006 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.70994 .61178 m
.70994 .61803 L
s
.91989 .61178 m
.91989 .61803 L
s
.125 Mabswid
.1221 .61428 m
.1221 .61803 L
s
.16409 .61428 m
.16409 .61803 L
s
.20608 .61428 m
.20608 .61803 L
s
.24807 .61428 m
.24807 .61803 L
s
.33204 .61428 m
.33204 .61803 L
s
.37403 .61428 m
.37403 .61803 L
s
.41602 .61428 m
.41602 .61803 L
s
.45801 .61428 m
.45801 .61803 L
s
.54199 .61428 m
.54199 .61803 L
s
.58398 .61428 m
.58398 .61803 L
s
.62597 .61428 m
.62597 .61803 L
s
.66796 .61428 m
.66796 .61803 L
s
.75193 .61428 m
.75193 .61803 L
s
.79392 .61428 m
.79392 .61803 L
s
.83591 .61428 m
.83591 .61803 L
s
.8779 .61428 m
.8779 .61803 L
s
.03812 .61428 m
.03812 .61803 L
s
.96188 .61428 m
.96188 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06632 m
1 .06632 L
s
.99375 .1551 m
1 .1551 L
s
.99375 .24389 m
1 .24389 L
s
.99375 .33267 m
1 .33267 L
s
.99375 .42146 m
1 .42146 L
s
.99375 .51024 m
1 .51024 L
s
.99375 .59902 m
1 .59902 L
s
.125 Mabswid
.99625 .08408 m
1 .08408 L
s
.99625 .10183 m
1 .10183 L
s
.99625 .11959 m
1 .11959 L
s
.99625 .13735 m
1 .13735 L
s
.99625 .17286 m
1 .17286 L
s
.99625 .19062 m
1 .19062 L
s
.99625 .20837 m
1 .20837 L
s
.99625 .22613 m
1 .22613 L
s
.99625 .26164 m
1 .26164 L
s
.99625 .2794 m
1 .2794 L
s
.99625 .29716 m
1 .29716 L
s
.99625 .31491 m
1 .31491 L
s
.99625 .35043 m
1 .35043 L
s
.99625 .36818 m
1 .36818 L
s
.99625 .38594 m
1 .38594 L
s
.99625 .4037 m
1 .4037 L
s
.99625 .43921 m
1 .43921 L
s
.99625 .45697 m
1 .45697 L
s
.99625 .47473 m
1 .47473 L
s
.99625 .49248 m
1 .49248 L
s
.99625 .528 m
1 .528 L
s
.99625 .54575 m
1 .54575 L
s
.99625 .56351 m
1 .56351 L
s
.99625 .58127 m
1 .58127 L
s
.99625 .04856 m
1 .04856 L
s
.99625 .0308 m
1 .0308 L
s
.99625 .01305 m
1 .01305 L
s
.99625 .61678 m
1 .61678 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06632 m
1 .06632 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01666 m
.02558 .18128 L
.02723 .29055 L
.02816 .35218 L
.02862 .38247 L
.02904 .40149 L
.02952 .4162 L
.03005 .43216 L
.03097 .46007 L
.03181 .4855 L
.03228 .49953 L
.03272 .50895 L
.03297 .51145 L
.03324 .51418 L
.03371 .51898 L
.03464 .52837 L
.03562 .53823 L
.03587 .54083 L
.03615 .54365 L
.03641 .54513 L
.03666 .54575 L
.03764 .54827 L
.03853 .55056 L
.03946 .55294 L
.03972 .55363 L
.03998 .55428 L
.04045 .55463 L
.04225 .55582 L
.0432 .55645 L
.04345 .55661 L
.04372 .55679 L
.0442 .55693 L
.04473 .55708 L
.04531 .55724 L
.04633 .55753 L
.05458 .55954 L
.07025 .56311 L
.08535 .56635 L
.09986 .56928 L
.11532 .57223 L
.13019 .5749 L
.146 .57758 L
.16123 .57999 L
.17588 .58216 L
.19147 .58434 L
.20648 .58629 L
.22092 .58803 L
.23628 .58979 L
.25107 .59134 L
.2668 .5929 L
Mistroke
.28194 .59428 L
.29651 .59548 L
.31202 .59668 L
.32694 .59772 L
.34281 .59873 L
.35809 .59959 L
.37279 .60034 L
.38843 .60101 L
.4035 .60158 L
.41798 .60207 L
.4334 .60248 L
.44052 .60265 L
.44824 .6028 L
.45635 .60292 L
.46402 .60303 L
.47157 .60312 L
.47246 .6031 L
.47291 .60309 L
.4734 .60309 L
.47366 .6031 L
.47394 .60311 L
.47443 .60313 L
.47538 .60317 L
.47596 .60319 L
.47651 .60321 L
.47701 .60323 L
.47729 .60322 L
.47755 .60321 L
.47861 .60319 L
.47958 .60317 L
.48002 .60316 L
.48049 .60315 L
.48095 .60316 L
.48136 .60317 L
.48227 .6032 L
.48328 .60324 L
.4837 .60325 L
.48414 .60327 L
.48457 .60328 L
.48496 .60327 L
.48674 .60323 L
.4872 .60322 L
.48769 .6032 L
.48815 .60319 L
.48857 .60321 L
.49057 .60327 L
.49105 .60328 L
.49157 .6033 L
.49183 .60331 L
.49213 .6033 L
Mistroke
.4924 .6033 L
.49265 .60329 L
.49366 .60327 L
.49461 .60324 L
.49508 .60323 L
.49552 .60322 L
.49577 .60322 L
.49604 .60323 L
.4965 .60324 L
.49751 .60327 L
.49857 .6033 L
.49902 .60331 L
.4995 .60332 L
.49978 .60331 L
.50003 .6033 L
.50053 .60329 L
.50146 .60326 L
.50233 .60324 L
.50276 .60323 L
.50317 .60322 L
.50359 .60323 L
.50406 .60324 L
.50505 .60327 L
.50595 .60329 L
.50637 .6033 L
.50676 .60331 L
.50716 .6033 L
.5076 .60329 L
.50939 .60324 L
.50987 .60322 L
.51014 .60321 L
.51039 .60321 L
.51083 .60321 L
.51131 .60322 L
.5124 .60324 L
.5134 .60326 L
.51385 .60327 L
.51434 .60328 L
.5148 .60327 L
.51522 .60326 L
.51623 .60322 L
.51718 .60319 L
.51761 .60318 L
.51805 .60316 L
.51854 .60317 L
.51899 .60318 L
.52062 .60321 L
.52105 .60322 L
.52152 .60323 L
.52196 .60323 L
Mistroke
.52236 .60322 L
.52327 .60318 L
.52427 .60315 L
.52472 .60313 L
.52522 .60312 L
.52568 .60311 L
.52611 .60311 L
.52704 .60313 L
.52806 .60315 L
.52851 .60316 L
.52899 .60316 L
.52944 .60316 L
.52985 .60315 L
.53156 .60308 L
.53205 .60306 L
.53258 .60304 L
.53302 .60303 L
.53352 .60303 L
.53454 .60305 L
.53563 .60306 L
.53617 .60307 L
.53643 .60307 L
.53667 .60308 L
.53713 .60306 L
.53762 .60304 L
.53859 .603 L
.53947 .60297 L
.53992 .60295 L
.54033 .60293 L
.54076 .60293 L
.54124 .60294 L
.54223 .60295 L
.54314 .60296 L
.54355 .60296 L
.54399 .60297 L
.54442 .60296 L
.5448 .60294 L
.54658 .60287 L
.54703 .60285 L
.54752 .60283 L
.54798 .60281 L
.5484 .60281 L
.55039 .60283 L
.55087 .60283 L
.55138 .60284 L
.55168 .60284 L
.55194 .60283 L
.55246 .6028 L
.5534 .60276 L
.55443 .60271 L
Mistroke
.55489 .60269 L
.55539 .60267 L
.55586 .60267 L
.55629 .60267 L
.55723 .60268 L
.55773 .60268 L
.55825 .60268 L
.5587 .60269 L
.55919 .60269 L
.55964 .60266 L
.56006 .60264 L
.56177 .60256 L
.56227 .60254 L
.56274 .60251 L
.56323 .60251 L
.56349 .60251 L
.56377 .60251 L
.56464 .60251 L
.56559 .60251 L
.56587 .60252 L
.56617 .60252 L
.56642 .60252 L
.5667 .60251 L
.56696 .6025 L
.56724 .60248 L
.56775 .60246 L
.56868 .60241 L
.56921 .60238 L
.56971 .60236 L
.57017 .60234 L
.57044 .60233 L
.57068 .60233 L
.57171 .60233 L
.57268 .60233 L
.57357 .60233 L
.57405 .60233 L
.57431 .60231 L
.57455 .6023 L
.57562 .60224 L
.57675 .60218 L
.57724 .60216 L
.5775 .60214 L
.57778 .60213 L
.57826 .60212 L
.5787 .60212 L
.57967 .60212 L
.58022 .60212 L
.58074 .60212 L
.58121 .60211 L
.58148 .60211 L
Mistroke
.58172 .6021 L
.58366 .60199 L
.58451 .60195 L
.58496 .60192 L
.58545 .6019 L
.58593 .6019 L
.58639 .6019 L
.58738 .60189 L
.58794 .60189 L
.58848 .60188 L
.58895 .60188 L
.58922 .60187 L
.58947 .60185 L
.59327 .60165 L
.60036 .60139 L
.61532 .6008 L
.6297 .60015 L
.64502 .59935 L
.65976 .5985 L
.67544 .59751 L
.69053 .59644 L
.70505 .59531 L
.72051 .59402 L
.73539 .59266 L
.7512 .59112 L
.76643 .5895 L
.78109 .58781 L
.79668 .5859 L
.81169 .58392 L
.82613 .58188 L
.8415 .57958 L
.85629 .57721 L
.87202 .57455 L
.88717 .57181 L
.90174 .569 L
.91725 .56585 L
.93218 .56261 L
.9398 .5609 L
.94804 .55898 L
.95192 .55804 L
.95404 .55747 L
.95601 .55676 L
.9577 .556 L
.95818 .55579 L
.95864 .55558 L
.95905 .55506 L
.9595 .55434 L
.96047 .5528 L
.96149 .55117 L
.96191 .5505 L
Mistroke
.96236 .54977 L
.96286 .54716 L
.96333 .5441 L
.96485 .5341 L
.96525 .53146 L
.96569 .5286 L
.9661 .52591 L
.96648 .51967 L
.96741 .49935 L
.96826 .48091 L
.96912 .46229 L
.96954 .4532 L
.96992 .4449 L
.97028 .42731 L
.97062 .40926 L
.97137 .36948 L
.97297 .28506 L
.97451 .17094 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[66]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;oooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00006oooool0033ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001[ooooo000Yooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001[ooooo000booooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool06?ooool002oooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Joooo
o`00;oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Jooooo`00<?ooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Kooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`007_oooooho`0000[ooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`08ooooo`007_oo
ool2o`0007Wooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo000:ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool000_ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000000Cooooon?l0000:ooooo`002oooool00ol0003oooooooooo`07ooooo`Co00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo000:ooooo`;o00002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool02Oooool2o`0000Gooooo0_l0
0004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000
1?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0_ooool2o`0000[ooooo000:ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool000_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool000[ooooo0_l00009ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oo
oooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool00_ooool2o`0000[ooooo000:ooooo`?o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000;oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`002oooool00ol0003oooooooooo`08ooooo`?o00001Oooool2o`0000Gooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo0_l0000:oooo
o`002oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000:ooooo`;o00002Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`002oooool00ol0003oooooooooo`08ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo
0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`03ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o
00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002_ooool3o`0000Cooooo
00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`002oooool00ol0003oooooooooo`08ooooo`Co00001?ooool2o`0000Gooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo0_l0000:oooo
o`002oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000:ooooo`;o00002Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`002oooool00ol0003oooooooooo`08ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo
0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`03ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o
00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`005Oooool5o`0000Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`005_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000H
ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001Gooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
01Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool001Kooooo0ol00005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool001kooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Ko
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?o
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Kooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Kooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`Go00000oooool00ol0003o
ooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0
000:ooooo`002Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`05o`000?oooooo
ooooooooool000002?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`002_ooool3o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001_ooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool01?ooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool0
01kooooo0_l00007ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`05ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01_ooool2o`00073o
oooo00?o0000ooooooooool0Koooool2o`0000Sooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool01oooool3o`0006kooooo00?o0000ooooooooool0K_ooool2o`0000Wooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02_ooool3o`0006_ooooo00?o
0000ooooooooool0JOooool5o`0000_ooooo00?o0000ooooooooool02?ooool001kooooo0_l0000>
ooooo`Co0000Ioooool00ol0003oooooooooo`1Wooooo`;o00003oooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo017ooooo2?l0001Oooooo`03o`000?oooooooooo05oooooo2?l0000Boooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo01Wooooo0ol0001Looooo`03
o`000?oooooooooo05_ooooo1?l0000Jooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo01cooooo2?l0001Dooooo`03o`000?oooooooooo05Cooooo1ol0000Nooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`;o00009Oooool4o`00053ooooo00?o0000ooooooooool0COoo
ool7o`0002Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Xooooo`Oo0000BOooool0
0ol0003oooooooooo`15ooooo`So0000;?ooool00ol0003oooooooooo`08ooooo`002Oooool5o`00
00?ooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo02oooooo2ol0000n
ooooo`03o`000?oooooooooo03kooooo1ol0000dooooo`03o`000?oooooooooo00Sooooo000:oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0jooooo`So0000=_ooool00ol0003oooooooooo`0booooo`co0000>oooool00ol0003ooooooooo
o`08ooooo`002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0@_ooool?o`0002Oooooo00?o0000ooooooooool09oooool;o`0004Oooooo00?o0000
ooooooooool02?ooool000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03oooo
o`;o0000D_oooolFo`00017ooooo00?o0000ooooooooool04?oooolGo`00057ooooo0_l0000:oooo
o`002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo06Oooooo9Ol0001Xooooo`03o`000?oooooooooo00Sooooo0009oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Sooooo000:
ooooo`?o00002Oooool3o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooon?l0000:oooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00c?ooool3o`00057ooooo003=oooo
o`03o`000?oooooooooo053ooooo001Qooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`03
o`000?oooooooooo00;ooooo0ol00002ooooo`?o00000oooool3o`0000Cooooo0ol00002ooooo`?o
000000?oooooo`000?l000000_ooool2o`0000Sooooo1Ol000001Ooooooo0000o`000?l0003ooooo
00;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l00002oooo
o`Go00000oooool2o`0000Cooooo00?o0000ooooooooool0Coooool0067ooooo00?o0000ooooool0
00000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0006ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Coooool0067ooooo00?o0000ooooool0
00000oooool3o`0000?ooooo00?o0000ooooool000000_ooool5o`0000;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`00001@ooooo`00H?ooool01ol0003oooooo`000?oooooo0000ooooool0
00000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo0ol00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000053ooooo001Pooooo`05o`000?oo
oooo0000ooooool000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o0000
0oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo
1?l00002ooooo`Co00002_ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00003ooooo`?o
00000_ooool4o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co00000_ooool2o`00
0003ooooool0003o000004oooooo001Pooooo`05o`000?oooooo0000ooooool000005?ooool01?l0
003oooooooooool0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo001Pooooo`Ko00004_ooool5o`00
01Cooooo00?o0000ooooooooool02?ooool5o`0000Sooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.6739, 1.47021, 0.19271, \
0.00455694}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0209945 0.0147151 0.0115183 [
[.08011 -0.0125 -9 -9 ]
[.08011 -0.0125 9 0 ]
[.29006 -0.0125 -9 -9 ]
[.29006 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70994 -0.0125 -6 -9 ]
[.70994 -0.0125 6 0 ]
[.91989 -0.0125 -6 -9 ]
[.91989 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1299 -12 -4.5 ]
[-0.0125 .1299 0 4.5 ]
[-0.0125 .24508 -12 -4.5 ]
[-0.0125 .24508 0 4.5 ]
[-0.0125 .36026 -12 -4.5 ]
[-0.0125 .36026 0 4.5 ]
[-0.0125 .47545 -12 -4.5 ]
[-0.0125 .47545 0 4.5 ]
[-0.0125 .59063 -12 -4.5 ]
[-0.0125 .59063 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08011 0 m
.08011 .00625 L
s
[(-20)] .08011 -0.0125 0 1 Mshowa
.29006 0 m
.29006 .00625 L
s
[(-10)] .29006 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70994 0 m
.70994 .00625 L
s
[(10)] .70994 -0.0125 0 1 Mshowa
.91989 0 m
.91989 .00625 L
s
[(20)] .91989 -0.0125 0 1 Mshowa
.125 Mabswid
.1221 0 m
.1221 .00375 L
s
.16409 0 m
.16409 .00375 L
s
.20608 0 m
.20608 .00375 L
s
.24807 0 m
.24807 .00375 L
s
.33204 0 m
.33204 .00375 L
s
.37403 0 m
.37403 .00375 L
s
.41602 0 m
.41602 .00375 L
s
.45801 0 m
.45801 .00375 L
s
.54199 0 m
.54199 .00375 L
s
.58398 0 m
.58398 .00375 L
s
.62597 0 m
.62597 .00375 L
s
.66796 0 m
.66796 .00375 L
s
.75193 0 m
.75193 .00375 L
s
.79392 0 m
.79392 .00375 L
s
.83591 0 m
.83591 .00375 L
s
.8779 0 m
.8779 .00375 L
s
.03812 0 m
.03812 .00375 L
s
.96188 0 m
.96188 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1299 m
.00625 .1299 L
s
[(10)] -0.0125 .1299 1 0 Mshowa
0 .24508 m
.00625 .24508 L
s
[(20)] -0.0125 .24508 1 0 Mshowa
0 .36026 m
.00625 .36026 L
s
[(30)] -0.0125 .36026 1 0 Mshowa
0 .47545 m
.00625 .47545 L
s
[(40)] -0.0125 .47545 1 0 Mshowa
0 .59063 m
.00625 .59063 L
s
[(50)] -0.0125 .59063 1 0 Mshowa
.125 Mabswid
0 .03775 m
.00375 .03775 L
s
0 .06079 m
.00375 .06079 L
s
0 .08383 m
.00375 .08383 L
s
0 .10686 m
.00375 .10686 L
s
0 .15293 m
.00375 .15293 L
s
0 .17597 m
.00375 .17597 L
s
0 .19901 m
.00375 .19901 L
s
0 .22204 m
.00375 .22204 L
s
0 .26812 m
.00375 .26812 L
s
0 .29115 m
.00375 .29115 L
s
0 .31419 m
.00375 .31419 L
s
0 .33723 m
.00375 .33723 L
s
0 .3833 m
.00375 .3833 L
s
0 .40634 m
.00375 .40634 L
s
0 .42937 m
.00375 .42937 L
s
0 .45241 m
.00375 .45241 L
s
0 .49848 m
.00375 .49848 L
s
0 .52152 m
.00375 .52152 L
s
0 .54456 m
.00375 .54456 L
s
0 .56759 m
.00375 .56759 L
s
0 .61367 m
.00375 .61367 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08011 .61178 m
.08011 .61803 L
s
.29006 .61178 m
.29006 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.70994 .61178 m
.70994 .61803 L
s
.91989 .61178 m
.91989 .61803 L
s
.125 Mabswid
.1221 .61428 m
.1221 .61803 L
s
.16409 .61428 m
.16409 .61803 L
s
.20608 .61428 m
.20608 .61803 L
s
.24807 .61428 m
.24807 .61803 L
s
.33204 .61428 m
.33204 .61803 L
s
.37403 .61428 m
.37403 .61803 L
s
.41602 .61428 m
.41602 .61803 L
s
.45801 .61428 m
.45801 .61803 L
s
.54199 .61428 m
.54199 .61803 L
s
.58398 .61428 m
.58398 .61803 L
s
.62597 .61428 m
.62597 .61803 L
s
.66796 .61428 m
.66796 .61803 L
s
.75193 .61428 m
.75193 .61803 L
s
.79392 .61428 m
.79392 .61803 L
s
.83591 .61428 m
.83591 .61803 L
s
.8779 .61428 m
.8779 .61803 L
s
.03812 .61428 m
.03812 .61803 L
s
.96188 .61428 m
.96188 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1299 m
1 .1299 L
s
.99375 .24508 m
1 .24508 L
s
.99375 .36026 m
1 .36026 L
s
.99375 .47545 m
1 .47545 L
s
.99375 .59063 m
1 .59063 L
s
.125 Mabswid
.99625 .03775 m
1 .03775 L
s
.99625 .06079 m
1 .06079 L
s
.99625 .08383 m
1 .08383 L
s
.99625 .10686 m
1 .10686 L
s
.99625 .15293 m
1 .15293 L
s
.99625 .17597 m
1 .17597 L
s
.99625 .19901 m
1 .19901 L
s
.99625 .22204 m
1 .22204 L
s
.99625 .26812 m
1 .26812 L
s
.99625 .29115 m
1 .29115 L
s
.99625 .31419 m
1 .31419 L
s
.99625 .33723 m
1 .33723 L
s
.99625 .3833 m
1 .3833 L
s
.99625 .40634 m
1 .40634 L
s
.99625 .42937 m
1 .42937 L
s
.99625 .45241 m
1 .45241 L
s
.99625 .49848 m
1 .49848 L
s
.99625 .52152 m
1 .52152 L
s
.99625 .54456 m
1 .54456 L
s
.99625 .56759 m
1 .56759 L
s
.99625 .61367 m
1 .61367 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .30239 Mdot
.03144 .34844 Mdot
.03907 .38986 Mdot
.04669 .42689 Mdot
.05431 .45975 Mdot
.06191 .48865 Mdot
.06951 .51382 Mdot
.0771 .53545 Mdot
.08469 .55374 Mdot
.09227 .56887 Mdot
.09984 .58102 Mdot
.10741 .59038 Mdot
.11497 .59711 Mdot
.12253 .60137 Mdot
.13008 .60332 Mdot
.13762 .60311 Mdot
.14516 .6009 Mdot
.1527 .59681 Mdot
.16023 .59099 Mdot
.16776 .58358 Mdot
.17528 .57468 Mdot
.1828 .56444 Mdot
.19031 .55297 Mdot
.19782 .54038 Mdot
.20533 .52678 Mdot
.21283 .51229 Mdot
.22033 .49699 Mdot
.22783 .48099 Mdot
.23532 .46439 Mdot
.24281 .44727 Mdot
.2503 .42973 Mdot
.25778 .41185 Mdot
.26526 .39371 Mdot
.27274 .37538 Mdot
.28021 .35695 Mdot
.28769 .33849 Mdot
.29516 .32006 Mdot
.30262 .30173 Mdot
.31009 .28356 Mdot
.31755 .26562 Mdot
.32502 .24796 Mdot
.33248 .23063 Mdot
.33993 .2137 Mdot
.34739 .1972 Mdot
.35484 .18119 Mdot
.3623 .16571 Mdot
.36975 .15081 Mdot
.3772 .13651 Mdot
.38465 .12287 Mdot
.3921 .10991 Mdot
.39954 .09768 Mdot
.40699 .08618 Mdot
.41443 .07547 Mdot
.42188 .06556 Mdot
.42932 .05647 Mdot
.43676 .04824 Mdot
.4442 .04087 Mdot
.45164 .03438 Mdot
.45908 .02879 Mdot
.46652 .02412 Mdot
.47396 .02037 Mdot
.4814 .01754 Mdot
.48884 .01566 Mdot
.49628 .01472 Mdot
.50372 .01472 Mdot
.51116 .01566 Mdot
.5186 .01754 Mdot
.52604 .02037 Mdot
.53348 .02412 Mdot
.54092 .02879 Mdot
.54836 .03438 Mdot
.5558 .04087 Mdot
.56324 .04824 Mdot
.57068 .05647 Mdot
.57812 .06556 Mdot
.58557 .07547 Mdot
.59301 .08618 Mdot
.60046 .09768 Mdot
.6079 .10991 Mdot
.61535 .12287 Mdot
.6228 .13651 Mdot
.63025 .15081 Mdot
.6377 .16571 Mdot
.64516 .18119 Mdot
.65261 .1972 Mdot
.66007 .2137 Mdot
.66752 .23063 Mdot
.67498 .24796 Mdot
.68245 .26562 Mdot
.68991 .28356 Mdot
.69738 .30173 Mdot
.70484 .32006 Mdot
.71231 .33849 Mdot
.71979 .35695 Mdot
.72726 .37538 Mdot
.73474 .39371 Mdot
.74222 .41185 Mdot
.7497 .42973 Mdot
.75719 .44727 Mdot
.76468 .46439 Mdot
.77217 .48099 Mdot
.77967 .49699 Mdot
.78717 .51229 Mdot
.79467 .52678 Mdot
.80218 .54038 Mdot
.80969 .55297 Mdot
.8172 .56444 Mdot
.82472 .57468 Mdot
.83224 .58358 Mdot
.83977 .59099 Mdot
.8473 .59681 Mdot
.85484 .6009 Mdot
.86238 .60311 Mdot
.86992 .60332 Mdot
.87747 .60137 Mdot
.88503 .59711 Mdot
.89259 .59038 Mdot
.90016 .58102 Mdot
.90773 .56887 Mdot
.91531 .55374 Mdot
.9229 .53545 Mdot
.93049 .51382 Mdot
.93809 .48865 Mdot
.94569 .45975 Mdot
.95331 .42689 Mdot
.96093 .38986 Mdot
.96856 .34844 Mdot
.97619 .30239 Mdot
.5 Mabswid
.02381 .30239 m
.03853 .3869 L
.05458 .46079 L
.06965 .51423 L
.08415 .55245 L
.09161 .56755 L
.09958 .58061 L
.1077 .59064 L
.11142 .59395 L
.11346 .59577 L
.11446 .59665 L
.11537 .59733 L
.11712 .59832 L
.11899 .59938 L
.1209 .60045 L
.12191 .60102 L
.12217 .60117 L
.12246 .60133 L
.12273 .60142 L
.12298 .60149 L
.12396 .60174 L
.12485 .60197 L
.12658 .60242 L
.12837 .60288 L
.12916 .60308 L
.12957 .60319 L
.13001 .6033 L
.13048 .60331 L
.13093 .6033 L
.1318 .60327 L
.13372 .60322 L
.13538 .60317 L
.13626 .60315 L
.13673 .60314 L
.13718 .60312 L
.13766 .6031 L
.13791 .60303 L
.13818 .60295 L
.13911 .60268 L
.14092 .60214 L
.14307 .60151 L
.14401 .60123 L
.14451 .60109 L
.14479 .60101 L
.14505 .60093 L
.14529 .60083 L
.14556 .60068 L
.14603 .60043 L
.14694 .59993 L
.14895 .59884 L
Mistroke
.15318 .59644 L
.16086 .59038 L
.17636 .57321 L
.19129 .55134 L
.20715 .52327 L
.22243 .49251 L
.23714 .46024 L
.25278 .4238 L
.26784 .38738 L
.28233 .35173 L
.29775 .3137 L
.31259 .27756 L
.32836 .24018 L
.34356 .20567 L
.35819 .17425 L
.37374 .14315 L
.38872 .11579 L
.40312 .09215 L
.41846 .07011 L
.43321 .05216 L
.44891 .03677 L
.45674 .03055 L
.46402 .02569 L
.4715 .02161 L
.47856 .01862 L
.48231 .01731 L
.48637 .01629 L
.48816 .01583 L
.4886 .01572 L
.48906 .01563 L
.48933 .0156 L
.48958 .01557 L
.49006 .0155 L
.49345 .01507 L
.49528 .01484 L
.49572 .01479 L
.4962 .01472 L
.49648 .01472 L
.49673 .01472 L
.49722 .01472 L
.50071 .01472 L
.50255 .01472 L
.50306 .01472 L
.50333 .01472 L
.50359 .01472 L
.50384 .01473 L
.5041 .01476 L
.50456 .01482 L
.50862 .01534 L
.51035 .01556 L
Mistroke
.51085 .01562 L
.51133 .0157 L
.51175 .01581 L
.51222 .01593 L
.51427 .01645 L
.51618 .01693 L
.5242 .01967 L
.5317 .02322 L
.53969 .02802 L
.55554 .04064 L
.57081 .05663 L
.5855 .07538 L
.60113 .09878 L
.61618 .12439 L
.63065 .15161 L
.64606 .18313 L
.66089 .21557 L
.67665 .25191 L
.69184 .28826 L
.70645 .32402 L
.72199 .36239 L
.73696 .39909 L
.75135 .43358 L
.76667 .4688 L
.78142 .50056 L
.7971 .53118 L
.8122 .55681 L
.82672 .57705 L
.83483 .58612 L
.84218 .59286 L
.84586 .5957 L
.84984 .59819 L
.85357 .60021 L
.85707 .60155 L
.86067 .60261 L
.86166 .6029 L
.86214 .60304 L
.86259 .60312 L
.86284 .60313 L
.8631 .60313 L
.86366 .60315 L
.86464 .60317 L
.86681 .60323 L
.86788 .60326 L
.86885 .60329 L
.86931 .6033 L
.86974 .60331 L
.87019 .60325 L
.87068 .60312 L
.87266 .60261 L
Mistroke
.87458 .60212 L
.87559 .60186 L
.87666 .60158 L
.87711 .60146 L
.87759 .6013 L
.87787 .60115 L
.87812 .601 L
.87862 .60072 L
.88044 .5997 L
.88751 .5949 L
.89126 .59157 L
.89474 .58773 L
.90263 .57705 L
.91045 .56345 L
.91753 .54838 L
.93279 .50619 L
.94747 .45206 L
.96309 .37811 L
.97619 .30239 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[66]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;?ooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00007_ooool002gooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001gooooo000Vooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001gooooo000_ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool06oooool002cooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Moooo
o`00;?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Mooooo`00;Oooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Nooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`006ooooooho`0000gooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`00
4oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004ooooo`;o
0000M_ooool8o`0007Kooooo0_l0000=ooooo`004oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo077ooooo3ol0001dooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0L?ooool5o`0000?ooooo00Co0000oooooooo
oooooooo1_l0001booooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0K_ooool4o`0000Kooooo00?o0000ooooooooool01Oooool4o`00
073ooooo00?o0000ooooooooool02oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo06ko
oooo0_l00008ooooo`03o`000?oooooooooo00Oooooo0_l0001`ooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo06cooooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo
0_l0001^ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o0000Joooool4o`0000[ooooo00?o
0000ooooooooool02Oooool4o`0006_ooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1Z
ooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`;o0000K?ooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`1Xooooo`?o00003Oooool00ol0003oooooooooo`0<oooo
o`;o0000Joooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Xooooo`;o
00003_ooool00ol0003oooooooooo`0<ooooo`;o0000Joooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`1Vooooo`?o00003oooool00ol0003oooooooooo`0>ooooo`;o0000
JOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Vooooo`;o00004?oo
ool00ol0003oooooooooo`0>ooooo`;o0000JOooool00ol0003oooooooooo`0;ooooo`006oooool2
o`0006Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo06Gooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1Tooooo`;o00004_ooool00ol0
003oooooooooo`0@ooooo`;o0000Ioooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003o
ooooooooo`1Tooooo`;o00004_ooool00ol0003oooooooooo`0@ooooo`?o0000I_ooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Sooooo`;o00004oooool00ol0003ooooo
ooooo`0Booooo`;o0000IOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`1Sooooo`;o00004oooool00ol0003oooooooooo`0Booooo`;o0000IOooool00ol0003ooooooooo
o`0;ooooo`006oooool2o`0006?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo067ooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1Qoooo
o`;o00005Oooool00ol0003oooooooooo`0Dooooo`;o0000Hoooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`1Qooooo`;o00005Oooool00ol0003oooooooooo`0Dooooo`;o
0000Hoooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Oooooo`?o0000
5_ooool00ol0003oooooooooo`0Eooooo`?o0000HOooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`1Oooooo`;o00005oooool00ol0003oooooooooo`0Fooooo`;o0000HOoo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`;o0000H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0G_ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo05go
oooo0_l0000Iooooo`03o`000?oooooooooo01Oooooo0_l0001Pooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo05gooooo0_l0000Iooooo`03o`000?oooooooooo01Oooooo
0_l0001Pooooo`03o`000?oooooooooo00_ooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0;ooooo`003_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Foooool2o`0001_ooooo00?o
0000ooooooooool06Oooool2o`0005kooooo00?o0000ooooooooool02oooool000kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05_ooooo0_l0
000Kooooo`03o`000?oooooooooo01Wooooo0_l0001Nooooo`03o`000?oooooooooo00_ooooo000>
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool2o`0005cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05[ooooo0_l0
000=ooooo`003_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0FOooool2o`0001gooooo00?o0000ooooooooool06oooool2o`0005cooooo00?o
0000ooooooooool02oooool000gooooo0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0FOooool2o`0001gooooo00?o0000ooooooooool06oooool2o`0005cooooo00?o
0000ooooooooool02oooool000kooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo00_ooooo000Kooooo`;o0000FOooool2o`0001kooooo00?o0000oooooooo
ool07Oooool2o`0005Wooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1Hooooo`;o0000
7_ooool00ol0003oooooooooo`0Mooooo`;o0000F_ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo05Kooooo0_l0000Pooooo`03o`000?oooooooooo01oooooo0_l0001Hooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo05Kooooo0_l0000Pooooo`03o`000?oooooooooo
01oooooo0_l0001Hooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool02oooool001_ooooo0_l0001Fooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Dooooo`;o00003Oooool001_ooooo00?o
0000ooooooooool0E?ooool2o`0002;ooooo00?o0000ooooooooool08Oooool2o`0005Kooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0E?ooool2o`0002;ooooo00?o0000
ooooooooool08Oooool2o`0005Kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05;ooooo0_l0000Tooooo`03o`00
0?oooooooooo02?ooooo0_l0001Dooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o0000Dooo
ool2o`0002Cooooo00?o0000ooooooooool08oooool2o`0005?ooooo0_l0000=ooooo`006oooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0D?ooool2o`0002Ko
oooo00?o0000ooooooooool09?ooool2o`0005?ooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool0D?ooool2o`0002Kooooo00?o0000ooooooooool09?ooool2o`0005?ooooo
00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DOooool00ol0003ooooooooo
o`0;ooooo`006oooool2o`00057ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo04oooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1>oooo
o`?o00009oooool00ol0003oooooooooo`0Vooooo`;o0000DOooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`1>ooooo`;o0000:?ooool00ol0003oooooooooo`0Vooooo`;o
0000DOooool00ol0003oooooooooo`0;ooooo`003?ooool5o`0000?ooooo0_l00005ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool02oooool000kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`;o
0000Coooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0COooool2o`0000gooooo000?ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04gooooo0_l0000Yooooo`03o`000?oooooooooo02So
oooo0_l0001?ooooo`03o`000?oooooooooo00_ooooo000<ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04gooooo0_l0000Yoooo
o`03o`000?oooooooooo02Sooooo0_l0001?ooooo`03o`000?oooooooooo00_ooooo000<ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool02oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo04_o
oooo0_l0000[ooooo`03o`000?oooooooooo02[ooooo0_l0001=ooooo`03o`000?oooooooooo00_o
oooo000Kooooo`;o0000C?ooool2o`0002_ooooo00?o0000ooooooooool0:_ooool2o`0004cooooo
0_l0000=ooooo`006oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool0BOooool2o`0002gooooo00?o0000ooooooooool0;?ooool2o`0004_ooooo00?o0000oooo
ooooool02oooool001_ooooo00?o0000ooooooooool0BOooool2o`0002gooooo00?o0000oooooooo
ool0;?ooool2o`0004_ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0;ooooo`006oooool2o`0004Wooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Sooooo0_l0000=ooooo`006oooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
00;ooooo0_l00013ooooo`;o0000;oooool00ol0003oooooooooo`0^ooooo`;o0000@_ooool2o`00
00Gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool00_ooool2o`0004?o
oooo0_l0000_ooooo`03o`000?oooooooooo02kooooo0_l00012ooooo`;o00001Oooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`006oooool2o`0000Cooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`;o00003Oooool001_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0nooooo`;o0000<Oooool00ol0003oooooooooo`0_
ooooo`;o0000@Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool2o`00037ooooo00?o0000oooo
ooooool0;oooool2o`00047ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0;ooooo`006oooool2o`0000Gooooo00?o0000ooooooooool0??ooool2
o`0003?ooooo00?o0000ooooooooool0<Oooool2o`0003oooooo00?o0000ooooooooool00oooool2
o`0000gooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0??ooool2o`00
03?ooooo00?o0000ooooooooool0<Oooool2o`0003kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`04ooooo`;o0000?_ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0>oooool2o`0000Ko
oooo00?o0000ooooooooool02oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`04ooooo`;o0000?Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0>oooool2o`0000Kooooo00?o0000ooooooooool02oooool000cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool3o`0003Cooooo00?o0000oooooooo
ool0<oooool2o`0003cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`00
3_ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool2o`0000Kooooo00?o0000oooooooo
ool0>Oooool2o`0003Gooooo00?o0000ooooooooool0<oooool2o`0003cooooo00?o0000oooooooo
ool01?ooool2o`0000gooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0;ooooo`003?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`003Oooool3o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool2o`0003Ko
oooo00?o0000ooooooooool0=Oooool2o`0003Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo
0_l0000fooooo`03o`000?oooooooooo03Gooooo0_l0000iooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02oooool001_ooooo0_l00007ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool01Oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo00Kooooo0_l0000gooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0eooooo`;o00002?ooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`06ooooo`;o0000=_ooool2o`0003Sooooo00?o0000oooooooo
ool0=oooool2o`0003Kooooo0_l00008ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0=?ooool2o`0003Sooooo00?o0000ooooooooool0
=oooool2o`0003Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0;ooooo`006oooool2o`0000Sooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`06ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0booooo`;o0000>_ooool00ol0003oooooooooo`0iooooo`;o0000<oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0<_ooool2o`0003[ooooo00?o0000ooooooooool0>Oooool2o`0003?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`08
ooooo`;o0000<Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0;oooool2o`0000[ooooo00?o0000ooooooooool02oooool001_ooooo0_l00009oooo
o`;o0000<?ooool2o`0003cooooo00?o0000ooooooooool0>oooool2o`00033ooooo0_l00009oooo
o`;o00003Oooool001_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`;o
0000??ooool00ol0003oooooooooo`0kooooo`;o0000<?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool2
o`0003kooooo00?o0000ooooooooool0??ooool2o`0002kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`006oooool2o`0000[ooooo00?o0000ooooooooool0;?ooool2o`00
03kooooo00?o0000ooooooooool0??ooool2o`0002kooooo00?o0000ooooooooool02Oooool2o`00
00gooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00[ooooo
0_l0000/ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0Zooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`0:ooooo`;o0000:_ooool3o`0003oooooo00?o0000ooooooooool0?_ooool2o`0002_ooooo0_l0
000<ooooo`03o`000?oooooooooo00_ooooo000>ooooo`?o00000oooool2o`0000Gooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`;o0000@?ooool00ol0003oooooooooo`0n
ooooo`;o0000:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo000?oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo000<ooooo`Go00000_ooool01?l0003oooooooooool00004ooooo`;o00003?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo0_l0000=ooooo`003?ooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Wooooo`;o0000@Oooool00ol0003oooooooooo`10ooooo`;o0000:?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo000=ooooo`03o`000?oooooo
000000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo02Oooooo0_l00011ooooo`03o`000?oooooooooo043ooooo0_l0000Xooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool000kooooo0_l00003ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool03?ooool2o`0002Oooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02Gooooo0_l0000>ooooo`03o`000?oo
oooooooo00_ooooo000?ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooo
oooo00cooooo0_l0000Vooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0Tooooo`;o00003_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Cooooo0_l00013ooooo`03o`000?oooooooooo
04;ooooo0_l0000Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool001_o
oooo0_l0000>ooooo`03o`000?oooooooooo02?ooooo0_l00013ooooo`03o`000?oooooooooo04;o
oooo0_l0000Uooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`006oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0=
ooooo`;o00008_ooool2o`0004Gooooo00?o0000ooooooooool0A?ooool2o`00027ooooo0_l0000@
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00gooooo0_l0000Roooo
o`;o0000AOooool00ol0003oooooooooo`14ooooo`;o00008Oooool2o`00013ooooo00?o0000oooo
ooooool02oooool001_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool001_ooooo0_l0000@ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool03_ooool2o`0000gooooo000Kooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool07Oooool2o`0004Oooooo00?o0000ooooooooool0A_oo
ool2o`0001oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01cooooo0_l00017ooooo`03o`000?oooooo
oooo04Kooooo0_l0000Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool0
01_ooooo00?o0000ooooooooool03oooool2o`0001kooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo01_ooooo0_l0000Booooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo00oooooo0_l0000Looooo`;o0000BOooool00ol0003o
ooooooooo`17ooooo`;o00007?ooool2o`0001;ooooo00?o0000ooooooooool02oooool001_ooooo
0_l0000Booooo`03o`000?oooooooooo01Wooooo0_l00019ooooo`03o`000?oooooooooo04Oooooo
0ol0000Kooooo`03o`000?oooooooooo013ooooo0_l0000=ooooo`006oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`0Aooooo`;o00006?ooool2o`0004_ooooo00?o0000
ooooooooool0BOooool2o`0001Sooooo0ol0000Cooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo017ooooo0_l0000Hooooo`;o0000Boooool00ol0003oooooooooo`19oooo
o`?o00005oooool2o`0001Cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`;o0000
COooool00ol0003oooooooooo`1;ooooo`;o00005_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`;o00005?ooool2o`0001Cooooo0_l0001=ooooo`03o`000?oo
oooooooo04_ooooo0ol0000Dooooo`;o00005?ooool2o`0000gooooo000Kooooo`03o`000?oooooo
oooo01?ooooo0_l0000Cooooo`;o0000C_ooool00ol0003oooooooooo`1=ooooo`;o00004oooool2
o`0001Gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0@ooooo`;o0000C_ooool00ol0003oooooooooo`1=ooooo`;o00004_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo000=ooooo`?o00001?ooool2o`0000Go
oooo00?o0000ooooooooool05Oooool2o`00013ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo00oooooo0_l0000Gooooo`03o`000?oooooooooo00_o
oooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo01Gooooo0_l0000?ooooo`;o0000D?ooool00ol0003oooooooooo`1?oooo
o`;o00003oooool2o`0001Oooooo00?o0000ooooooooool02oooool0013ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo0_l0000;oooo
o`Co0000D?ooool00ol0003oooooooooo`1?ooooo`Co00002oooool2o`0001Wooooo00?o0000oooo
ooooool02oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`;o00006?ooool2o`0000_ooooo0_l0001Booooo`03o`000?oooooooooo057ooooo0_l0000;oooo
o`;o00006?ooool2o`0000gooooo000<ooooo`Co00000oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo01Wooooo0_l00007ooooo`;o0000E?ooool00ol0003oooooooooo`1Coooo
o`;o00001oooool2o`0001_ooooo00?o0000ooooooooool02oooool000cooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Wooooo2ol0001Doooo
o`03o`000?oooooooooo05?ooooo2ol0000Kooooo`03o`000?oooooooooo00_ooooo000<ooooo`Go
00000oooool2o`0000Gooooo00?o0000ooooooooool06_ooool8o`0005Kooooo00?o0000oooooooo
ool0EOooool7o`0001gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00001ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`006ooooooh
o`0000gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000]ooooo`?o0000R_oo
ool00ol0003oooooooooo`0[ooooo`?o00005Oooool00ol0003oooooooooo`0Mooooo`00;_ooool0
0ol0003oooooooooo`28ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Looooo`00:?ooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`00
00;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000ol00007ooooo`?o00001?ooool4o`00
00?ooooo0_l00002ooooo`Ko00001_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003o`00
0003ooooool0003o000000?o00000_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3o`00
0004ooooool0003o0000ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool5
o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_oo
ool:o`0000Gooooo00?o0000ooooooooool06oooool002Oooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00000<ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06oooool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go
00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01_l0003oooooooooool0003ooooo
o`0000Gooooo1Ol00008ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`00
0002ooooo`?o00000oooool00ol0003oooooo`000002ooooo`Go00000oooool01?l0003ooooooooo
ooooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00000_ooool3o`0000Gooooo00?o0000ooooooooool06ooo
ool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool0
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000oooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooool00005ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`0K
ooooo`009oooool01_l0003ooooooooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo0ol0
0004ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ool00002ooooo`;o00000oooool4o`0000?ooooo0ol00009ooooo`05o`000?ooooooooooo`000?oo
ool00ol00004ooooo`Co00000_ooool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l0
00000_ooool3o`0000;ooooo1?l00003ooooo`?o00000oooool3o`0000Wooooo00?o0000oooooooo
ool00_ooool6o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`?o
00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o
00000oooool4o`0000Cooooo00?o0000ooooooooool06oooool002Oooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo000Xooooo`?o00002Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0ol00009ooooo`Co00002Oooool00ol0
003oooooooooo`02ooooo`;o00002_ooool4o`0000Cooooo00?o0000ooooooooool01?ooool2o`00
00Cooooo0_l0000^ooooo`03o`000?oooooooooo01Sooooo0ol0000Fooooo`03o`000?oooooooooo
00;ooooo0_l0000;ooooo`03o`000?oooooooooo01gooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.0958, -5.52433, 0.19271, \
0.351254}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.776589 0.0145034 0.000588501 [
[.03405 .002 -12 -9 ]
[.03405 .002 12 0 ]
[.18936 .002 -12 -9 ]
[.18936 .002 12 0 ]
[.34468 .002 -12 -9 ]
[.34468 .002 12 0 ]
[.5 .002 -3 -9 ]
[.5 .002 3 0 ]
[.65532 .002 -9 -9 ]
[.65532 .002 9 0 ]
[.81064 .002 -9 -9 ]
[.81064 .002 9 0 ]
[.96595 .002 -9 -9 ]
[.96595 .002 9 0 ]
[.01131 .1322 -18 -4.5 ]
[.01131 .1322 0 4.5 ]
[.01131 .2499 -18 -4.5 ]
[.01131 .2499 0 4.5 ]
[.01131 .3676 -18 -4.5 ]
[.01131 .3676 0 4.5 ]
[.01131 .4853 -18 -4.5 ]
[.01131 .4853 0 4.5 ]
[.01131 .603 -24 -4.5 ]
[.01131 .603 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03405 .0145 m
.03405 .02075 L
s
[(-0.6)] .03405 .002 0 1 Mshowa
.18936 .0145 m
.18936 .02075 L
s
[(-0.4)] .18936 .002 0 1 Mshowa
.34468 .0145 m
.34468 .02075 L
s
[(-0.2)] .34468 .002 0 1 Mshowa
.5 .0145 m
.5 .02075 L
s
[(0)] .5 .002 0 1 Mshowa
.65532 .0145 m
.65532 .02075 L
s
[(0.2)] .65532 .002 0 1 Mshowa
.81064 .0145 m
.81064 .02075 L
s
[(0.4)] .81064 .002 0 1 Mshowa
.96595 .0145 m
.96595 .02075 L
s
[(0.6)] .96595 .002 0 1 Mshowa
.125 Mabswid
.07288 .0145 m
.07288 .01825 L
s
.11171 .0145 m
.11171 .01825 L
s
.15054 .0145 m
.15054 .01825 L
s
.22819 .0145 m
.22819 .01825 L
s
.26702 .0145 m
.26702 .01825 L
s
.30585 .0145 m
.30585 .01825 L
s
.38351 .0145 m
.38351 .01825 L
s
.42234 .0145 m
.42234 .01825 L
s
.46117 .0145 m
.46117 .01825 L
s
.53883 .0145 m
.53883 .01825 L
s
.57766 .0145 m
.57766 .01825 L
s
.61649 .0145 m
.61649 .01825 L
s
.69415 .0145 m
.69415 .01825 L
s
.73298 .0145 m
.73298 .01825 L
s
.77181 .0145 m
.77181 .01825 L
s
.84946 .0145 m
.84946 .01825 L
s
.88829 .0145 m
.88829 .01825 L
s
.92712 .0145 m
.92712 .01825 L
s
.25 Mabswid
0 .0145 m
1 .0145 L
s
.02381 .1322 m
.03006 .1322 L
s
[(200)] .01131 .1322 1 0 Mshowa
.02381 .2499 m
.03006 .2499 L
s
[(400)] .01131 .2499 1 0 Mshowa
.02381 .3676 m
.03006 .3676 L
s
[(600)] .01131 .3676 1 0 Mshowa
.02381 .4853 m
.03006 .4853 L
s
[(800)] .01131 .4853 1 0 Mshowa
.02381 .603 m
.03006 .603 L
s
[(1000)] .01131 .603 1 0 Mshowa
.125 Mabswid
.02381 .04393 m
.02756 .04393 L
s
.02381 .07335 m
.02756 .07335 L
s
.02381 .10278 m
.02756 .10278 L
s
.02381 .16163 m
.02756 .16163 L
s
.02381 .19105 m
.02756 .19105 L
s
.02381 .22048 m
.02756 .22048 L
s
.02381 .27933 m
.02756 .27933 L
s
.02381 .30875 m
.02756 .30875 L
s
.02381 .33818 m
.02756 .33818 L
s
.02381 .39703 m
.02756 .39703 L
s
.02381 .42645 m
.02756 .42645 L
s
.02381 .45588 m
.02756 .45588 L
s
.02381 .51473 m
.02756 .51473 L
s
.02381 .54415 m
.02756 .54415 L
s
.02381 .57358 m
.02756 .57358 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .02043 m
.0243 .02032 L
.02478 .02047 L
.02527 .02041 L
.02575 .02041 L
.02624 .02049 L
.02672 .02051 L
.02721 .02046 L
.0277 .02047 L
.02818 .02047 L
.02867 .02054 L
.02915 .02033 L
.02964 .02052 L
.03013 .02046 L
.03061 .02056 L
.0311 .02042 L
.03158 .02065 L
.03207 .02062 L
.03256 .02077 L
.03304 .02062 L
.03353 .02093 L
.03401 .02068 L
.0345 .02101 L
.03499 .02079 L
.03547 .02109 L
.03596 .02088 L
.03644 .0211 L
.03693 .02116 L
.03741 .02113 L
.0379 .02129 L
.03839 .02133 L
.03887 .02154 L
.03936 .02148 L
.03984 .02162 L
.04033 .02195 L
.04082 .02186 L
.0413 .02222 L
.04179 .02208 L
.04227 .02263 L
.04276 .02243 L
.04325 .02284 L
.04373 .02273 L
.04422 .02309 L
.0447 .02287 L
.04519 .02332 L
.04568 .02311 L
.04616 .0235 L
.04665 .02322 L
.04713 .02384 L
.04762 .02337 L
Mistroke
.0481 .02395 L
.04859 .02354 L
.04908 .02418 L
.04956 .02379 L
.05005 .02409 L
.05053 .02387 L
.05102 .02444 L
.05151 .0239 L
.05199 .02453 L
.05248 .02407 L
.05296 .0247 L
.05345 .02418 L
.05394 .02483 L
.05442 .02436 L
.05491 .02501 L
.05539 .02457 L
.05588 .02513 L
.05637 .0249 L
.05685 .02523 L
.05734 .02498 L
.05782 .02564 L
.05831 .02501 L
.05879 .02564 L
.05928 .02487 L
.05977 .02584 L
.06025 .0248 L
.06074 .02556 L
.06122 .02485 L
.06171 .02536 L
.0622 .02485 L
.06268 .02513 L
.06317 .02463 L
.06365 .02512 L
.06414 .02453 L
.06463 .02473 L
.06511 .0245 L
.0656 .0246 L
.06608 .02399 L
.06657 .02469 L
.06706 .02375 L
.06754 .02421 L
.06803 .02355 L
.06851 .02376 L
.069 .02331 L
.06948 .02341 L
.06997 .02281 L
.07046 .02315 L
.07094 .0226 L
.07143 .0228 L
.07191 .02212 L
Mistroke
.0724 .02251 L
.07289 .02204 L
.07337 .02192 L
.07386 .02184 L
.07434 .02173 L
.07483 .02143 L
.07532 .0215 L
.0758 .02135 L
.07629 .02114 L
.07677 .02123 L
.07726 .02097 L
.07775 .02102 L
.07823 .02107 L
.07872 .02083 L
.0792 .02093 L
.07969 .02087 L
.08017 .02101 L
.08066 .02082 L
.08115 .02065 L
.08163 .02108 L
.08212 .0205 L
.0826 .02083 L
.08309 .02057 L
.08358 .0206 L
.08406 .02048 L
.08455 .02055 L
.08503 .02033 L
.08552 .02045 L
.08601 .02028 L
.08649 .02041 L
.08698 .02019 L
.08746 .02052 L
.08795 .02025 L
.08844 .02037 L
.08892 .02024 L
.08941 .02079 L
.08989 .02004 L
.09038 .02076 L
.09086 .02029 L
.09135 .02079 L
.09184 .02044 L
.09232 .02084 L
.09281 .02062 L
.09329 .02099 L
.09378 .02077 L
.09427 .02133 L
.09475 .02076 L
.09524 .02165 L
.09572 .02113 L
.09621 .02156 L
Mistroke
.0967 .02156 L
.09718 .02187 L
.09767 .02166 L
.09815 .022 L
.09864 .02203 L
.09913 .02248 L
.09961 .02201 L
.1001 .02278 L
.10058 .02252 L
.10107 .02296 L
.10155 .02292 L
.10204 .0233 L
.10253 .02311 L
.10301 .02367 L
.1035 .02355 L
.10398 .02375 L
.10447 .02377 L
.10496 .0239 L
.10544 .02413 L
.10593 .0236 L
.10641 .02436 L
.1069 .02391 L
.10739 .02396 L
.10787 .02397 L
.10836 .02406 L
.10884 .02407 L
.10933 .0239 L
.10982 .02391 L
.1103 .02418 L
.11079 .02363 L
.11127 .02432 L
.11176 .02361 L
.11224 .02402 L
.11273 .02373 L
.11322 .02407 L
.1137 .02363 L
.11419 .0239 L
.11467 .02373 L
.11516 .02403 L
.11565 .02338 L
.11613 .02413 L
.11662 .02363 L
.1171 .0238 L
.11759 .02344 L
.11808 .02385 L
.11856 .0234 L
.11905 .02362 L
.11953 .02308 L
.12002 .02363 L
.12051 .02274 L
Mistroke
.12099 .02354 L
.12148 .02276 L
.12196 .02308 L
.12245 .02269 L
.12293 .02307 L
.12342 .02259 L
.12391 .02277 L
.12439 .02239 L
.12488 .02293 L
.12536 .02191 L
.12585 .02261 L
.12634 .02204 L
.12682 .02223 L
.12731 .02182 L
.12779 .02178 L
.12828 .02198 L
.12877 .02148 L
.12925 .02172 L
.12974 .02147 L
.13022 .02142 L
.13071 .02136 L
.1312 .02144 L
.13168 .02126 L
.13217 .02122 L
.13265 .02111 L
.13314 .02146 L
.13362 .02101 L
.13411 .02127 L
.1346 .02127 L
.13508 .02148 L
.13557 .02115 L
.13605 .02159 L
.13654 .02138 L
.13703 .022 L
.13751 .02118 L
.138 .02216 L
.13848 .02146 L
.13897 .02212 L
.13946 .02172 L
.13994 .02216 L
.14043 .0219 L
.14091 .02212 L
.1414 .02211 L
.14189 .02261 L
.14237 .02201 L
.14286 .02278 L
.14334 .02244 L
.14383 .02296 L
.14431 .0226 L
.1448 .02294 L
Mistroke
.14529 .02331 L
.14577 .02297 L
.14626 .02326 L
.14674 .02328 L
.14723 .0236 L
.14772 .02356 L
.1482 .02363 L
.14869 .02385 L
.14917 .02392 L
.14966 .02377 L
.15015 .02436 L
.15063 .02389 L
.15112 .02435 L
.1516 .02385 L
.15209 .02459 L
.15258 .02403 L
.15306 .02434 L
.15355 .02416 L
.15403 .02478 L
.15452 .02409 L
.155 .02465 L
.15549 .02424 L
.15598 .02501 L
.15646 .02426 L
.15695 .0246 L
.15743 .02448 L
.15792 .02443 L
.15841 .0243 L
.15889 .0243 L
.15938 .02408 L
.15986 .02419 L
.16035 .02347 L
.16084 .02429 L
.16132 .02319 L
.16181 .0238 L
.16229 .02295 L
.16278 .02353 L
.16327 .02292 L
.16375 .02268 L
.16424 .02286 L
.16472 .02268 L
.16521 .02261 L
.16569 .02233 L
.16618 .02239 L
.16667 .02245 L
.16715 .02234 L
.16764 .02211 L
.16812 .02244 L
.16861 .022 L
.1691 .02227 L
Mistroke
.16958 .02179 L
.17007 .02246 L
.17055 .02162 L
.17104 .0222 L
.17153 .0219 L
.17201 .02216 L
.1725 .02186 L
.17298 .02219 L
.17347 .02182 L
.17396 .02278 L
.17444 .02181 L
.17493 .02237 L
.17541 .02235 L
.1759 .02262 L
.17638 .02232 L
.17687 .02277 L
.17736 .02268 L
.17784 .02283 L
.17833 .02293 L
.17881 .02297 L
.1793 .02291 L
.17979 .02343 L
.18027 .02286 L
.18076 .0233 L
.18124 .02354 L
.18173 .02291 L
.18222 .02361 L
.1827 .023 L
.18319 .02419 L
.18367 .02307 L
.18416 .02372 L
.18465 .02379 L
.18513 .02382 L
.18562 .02369 L
.1861 .02421 L
.18659 .0235 L
.18707 .02432 L
.18756 .0241 L
.18805 .02379 L
.18853 .0238 L
.18902 .02486 L
.1895 .02299 L
.18999 .02448 L
.19048 .02406 L
.19096 .02331 L
.19145 .02374 L
.19193 .02367 L
.19242 .02315 L
.19291 .02368 L
.19339 .02308 L
Mistroke
.19388 .02307 L
.19436 .02332 L
.19485 .02288 L
.19534 .02325 L
.19582 .02213 L
.19631 .02333 L
.19679 .0227 L
.19728 .02231 L
.19776 .02255 L
.19825 .02304 L
.19874 .02177 L
.19922 .02283 L
.19971 .02257 L
.20019 .02213 L
.20068 .02259 L
.20117 .02273 L
.20165 .02206 L
.20214 .02331 L
.20262 .02242 L
.20311 .02321 L
.2036 .02274 L
.20408 .02357 L
.20457 .02403 L
.20505 .02282 L
.20554 .0242 L
.20603 .02455 L
.20651 .02351 L
.207 .0248 L
.20748 .02459 L
.20797 .02439 L
.20845 .02495 L
.20894 .02486 L
.20943 .02495 L
.20991 .02477 L
.2104 .02525 L
.21088 .02493 L
.21137 .02503 L
.21186 .02475 L
.21234 .02615 L
.21283 .02382 L
.21331 .02533 L
.2138 .02543 L
.21429 .02449 L
.21477 .02458 L
.21526 .02489 L
.21574 .02424 L
.21623 .02472 L
.21672 .02368 L
.2172 .02463 L
.21769 .02355 L
Mistroke
.21817 .0234 L
.21866 .0244 L
.21914 .02277 L
.21963 .02315 L
.22012 .0237 L
.2206 .02262 L
.22109 .02279 L
.22157 .02291 L
.22206 .02287 L
.22255 .02285 L
.22303 .02176 L
.22352 .02337 L
.224 .0224 L
.22449 .02226 L
.22498 .02241 L
.22546 .02287 L
.22595 .02172 L
.22643 .023 L
.22692 .02226 L
.22741 .02242 L
.22789 .02238 L
.22838 .02236 L
.22886 .02323 L
.22935 .02192 L
.22983 .02277 L
.23032 .02365 L
.23081 .02214 L
.23129 .02316 L
.23178 .02344 L
.23226 .02325 L
.23275 .02367 L
.23324 .0227 L
.23372 .02465 L
.23421 .02333 L
.23469 .02367 L
.23518 .02442 L
.23567 .02379 L
.23615 .02374 L
.23664 .02473 L
.23712 .024 L
.23761 .02454 L
.2381 .02374 L
.23858 .02508 L
.23907 .02459 L
.23955 .02382 L
.24004 .02482 L
.24052 .02514 L
.24101 .02378 L
.2415 .02462 L
.24198 .02436 L
Mistroke
.24247 .02472 L
.24295 .02423 L
.24344 .02365 L
.24393 .02513 L
.24441 .02346 L
.2449 .02419 L
.24538 .02457 L
.24587 .02397 L
.24636 .02388 L
.24684 .0246 L
.24733 .02418 L
.24781 .02532 L
.2483 .0232 L
.24879 .02599 L
.24927 .02494 L
.24976 .02438 L
.25024 .02551 L
.25073 .02511 L
.25121 .02605 L
.2517 .02486 L
.25219 .02535 L
.25267 .02644 L
.25316 .0253 L
.25364 .02562 L
.25413 .0264 L
.25462 .02532 L
.2551 .02597 L
.25559 .02534 L
.25607 .02635 L
.25656 .02536 L
.25705 .02483 L
.25753 .02531 L
.25802 .02574 L
.2585 .02362 L
.25899 .02487 L
.25948 .02387 L
.25996 .02441 L
.26045 .02319 L
.26093 .02268 L
.26142 .0241 L
.2619 .02238 L
.26239 .02256 L
.26288 .02261 L
.26336 .0222 L
.26385 .02236 L
.26433 .02181 L
.26482 .02214 L
.26531 .02277 L
.26579 .02075 L
.26628 .02269 L
Mistroke
.26676 .02183 L
.26725 .02218 L
.26774 .02183 L
.26822 .02183 L
.26871 .02316 L
.26919 .02222 L
.26968 .02194 L
.27017 .0234 L
.27065 .02298 L
.27114 .02345 L
.27162 .02311 L
.27211 .0235 L
.27259 .02475 L
.27308 .02315 L
.27357 .0247 L
.27405 .02455 L
.27454 .02459 L
.27502 .0244 L
.27551 .02493 L
.276 .0254 L
.27648 .02547 L
.27697 .02437 L
.27745 .0264 L
.27794 .02574 L
.27843 .02561 L
.27891 .02567 L
.2794 .02564 L
.27988 .02727 L
.28037 .02556 L
.28086 .02514 L
.28134 .02729 L
.28183 .02533 L
.28231 .02596 L
.2828 .02618 L
.28328 .02548 L
.28377 .0263 L
.28426 .02517 L
.28474 .02636 L
.28523 .0245 L
.28571 .02798 L
.2862 .02457 L
.28669 .02421 L
.28717 .02992 L
.28766 .02417 L
.28814 .02321 L
.28863 .03137 L
.28912 .02358 L
.2896 .02384 L
.29009 .03352 L
.29057 .02164 L
Mistroke
.29106 .02444 L
.29155 .03834 L
.29203 .0216 L
.29252 .02463 L
.293 .04903 L
.29349 .02194 L
.29397 .02844 L
.29446 .06224 L
.29495 .02475 L
.29543 .03648 L
.29592 .08385 L
.2964 .03282 L
.29689 .05546 L
.29738 .11645 L
.29786 .05047 L
.29835 .08556 L
.29883 .16643 L
.29932 .08603 L
.29981 .13119 L
.30029 .23551 L
.30078 .13797 L
.30126 .19422 L
.30175 .32389 L
.30224 .211 L
.30272 .28127 L
.30321 .44091 L
.30369 .30137 L
.30418 .37454 L
.30466 .54446 L
.30515 .36774 L
.30564 .42946 L
.30612 .60321 L
.30661 .39581 L
.30709 .43405 L
.30758 .59645 L
.30807 .36566 L
.30855 .37617 L
.30904 .51156 L
.30952 .27979 L
.31001 .26109 L
.3105 .35396 L
.31098 .15117 L
.31147 .11484 L
.31195 .1596 L
.31244 .0445 L
.31293 .02439 L
.31341 .03492 L
.3139 .03822 L
.31438 .05222 L
.31487 .0251 L
Mistroke
.31535 .13817 L
.31584 .1851 L
.31633 .10596 L
.31681 .28238 L
.3173 .33046 L
.31778 .18409 L
.31827 .35304 L
.31876 .38109 L
.31924 .17854 L
.31973 .2852 L
.32021 .27967 L
.3207 .08407 L
.32119 .12525 L
.32167 .1103 L
.32216 .01815 L
.32264 .02455 L
.32313 .02365 L
.32362 .08747 L
.3241 .07709 L
.32459 .07945 L
.32507 .26194 L
.32556 .21225 L
.32604 .16963 L
.32653 .35563 L
.32702 .2538 L
.3275 .14753 L
.32799 .25558 L
.32847 .14553 L
.32896 .04189 L
.32945 .07439 L
.32993 .03711 L
.33042 .03008 L
.3309 .01898 L
.33139 .06915 L
.33188 .17398 L
.33236 .11445 L
.33285 .17967 L
.33333 .32117 L
.33382 .18552 L
.33431 .17532 L
.33479 .25527 L
.33528 .10283 L
.33576 .04891 L
.33625 .06987 L
.33673 .0307 L
.33722 .03997 L
.33771 .02232 L
.33819 .12221 L
.33868 .20546 L
.33916 .11119 L
Mistroke
.33965 .22577 L
.34014 .28854 L
.34062 .11645 L
.34111 .14633 L
.34159 .15795 L
.34208 .03291 L
.34257 .0225 L
.34305 .02255 L
.34354 .07649 L
.34402 .10039 L
.34451 .0684 L
.345 .22345 L
.34548 .24357 L
.34597 .1135 L
.34645 .20108 L
.34694 .18444 L
.34742 .03897 L
.34791 .04579 L
.3484 .03528 L
.34888 .05425 L
.34937 .06275 L
.34985 .05906 L
.35034 .22728 L
.35083 .20971 L
.35131 .11203 L
.3518 .23392 L
.35228 .16364 L
.35277 .03068 L
.35326 .05336 L
.35374 .03534 L
.35423 .06867 L
.35471 .0517 L
.3552 .08746 L
.35569 .24796 L
.35617 .16119 L
.35666 .11274 L
.35714 .21453 L
.35763 .10056 L
.35811 .02123 L
.3586 .03589 L
.35909 .03846 L
.35957 .09594 L
.36006 .05996 L
.36054 .13334 L
.36103 .2611 L
.36152 .13381 L
.362 .10707 L
.36249 .15713 L
.36297 .04807 L
.36346 .01734 L
Mistroke
.36395 .01472 L
.36443 .08374 L
.36492 .16996 L
.3654 .08913 L
.36589 .1731 L
.36638 .23974 L
.36686 .07681 L
.36735 .05804 L
.36783 .06466 L
.36832 .03661 L
.3688 .0602 L
.36929 .03844 L
.36978 .17509 L
.37026 .23271 L
.37075 .09427 L
.37123 .1345 L
.37172 .13151 L
.37221 .02708 L
.37269 .01863 L
.37318 .01907 L
.37366 .12057 L
.37415 .16346 L
.37464 .08465 L
.37512 .18283 L
.37561 .18167 L
.37609 .03807 L
.37658 .03415 L
.37707 .03019 L
.37755 .07501 L
.37804 .09732 L
.37852 .06585 L
.37901 .21209 L
.37949 .20418 L
.37998 .05557 L
.38047 .07693 L
.38095 .05068 L
.38144 .04725 L
.38192 .05681 L
.38241 .06089 L
.3829 .21325 L
.38338 .18244 L
.38387 .06644 L
.38435 .10871 L
.38484 .06276 L
.38533 .02953 L
.38581 .03268 L
.3863 .05473 L
.38678 .20531 L
.38727 .16327 L
.38776 .07337 L
Mistroke
.38824 .13674 L
.38873 .07253 L
.38921 .02529 L
.3897 .02255 L
.39018 .05843 L
.39067 .20907 L
.39116 .14473 L
.39164 .07579 L
.39213 .15247 L
.39261 .06972 L
.3931 .02401 L
.39359 .01917 L
.39407 .06862 L
.39456 .20804 L
.39504 .12344 L
.39553 .0783 L
.39602 .14639 L
.3965 .05942 L
.39699 .02486 L
.39747 .0193 L
.39796 .07812 L
.39845 .21732 L
.39893 .1264 L
.39942 .07614 L
.3999 .12506 L
.40039 .04793 L
.40087 .03819 L
.40136 .02884 L
.40185 .09391 L
.40233 .2296 L
.40282 .12094 L
.4033 .05917 L
.40379 .08602 L
.40428 .03586 L
.40476 .06547 L
.40525 .04622 L
.40573 .11263 L
.40622 .22072 L
.40671 .09718 L
.40719 .03516 L
.40768 .04539 L
.40816 .04241 L
.40865 .10333 L
.40914 .07021 L
.40962 .11427 L
.41011 .20021 L
.41059 .07877 L
.41108 .01647 L
.41156 .01842 L
.41205 .06345 L
Mistroke
.41254 .1655 L
.41302 .09379 L
.41351 .09612 L
.41399 .15046 L
.41448 .05004 L
.41497 .02438 L
.41545 .0175 L
.41594 .09574 L
.41642 .21485 L
.41691 .09925 L
.4174 .06025 L
.41788 .08307 L
.41837 .04083 L
.41885 .08043 L
.41934 .05078 L
.41983 .11946 L
.42031 .218 L
.4208 .08079 L
.42128 .01829 L
.42177 .02211 L
.42225 .06471 L
.42274 .1765 L
.42323 .09515 L
.42371 .09011 L
.4242 .14364 L
.42468 .04633 L
.42517 .04075 L
.42566 .02625 L
.42614 .10678 L
.42663 .22435 L
.42711 .09115 L
.4276 .03157 L
.42809 .04251 L
.42857 .05116 L
.42906 .132 L
.42954 .07965 L
.43003 .1013 L
.43052 .16257 L
.431 .05517 L
.43149 .02449 L
.43197 .02001 L
.43246 .09077 L
.43294 .20624 L
.43343 .10018 L
.43392 .0353 L
.4344 .04834 L
.43489 .04317 L
.43537 .11348 L
.43586 .07833 L
.43635 .08803 L
Mistroke
.43683 .15868 L
.43732 .06127 L
.4378 .02454 L
.43829 .02318 L
.43878 .08283 L
.43926 .21543 L
.43975 .11728 L
.44023 .02739 L
.44072 .03535 L
.44121 .04042 L
.44169 .14478 L
.44218 .11277 L
.44266 .06761 L
.44315 .12934 L
.44363 .05948 L
.44412 .04914 L
.44461 .04998 L
.44509 .06735 L
.44558 .2038 L
.44606 .12198 L
.44655 .01568 L
.44704 .0187 L
.44752 .0413 L
.44801 .1825 L
.44849 .14662 L
.44898 .04142 L
.44947 .06698 L
.44995 .04041 L
.45044 .0974 L
.45092 .10848 L
.45141 .06195 L
.4519 .14277 L
.45238 .09097 L
.45287 .03415 L
.45335 .04523 L
.45384 .0444 L
.45432 .17854 L
.45481 .1563 L
.4553 .02493 L
.45578 .01918 L
.45627 .02427 L
.45675 .14587 L
.45724 .17001 L
.45773 .04657 L
.45821 .0556 L
.4587 .0419 L
.45918 .08475 L
.45967 .13205 L
.46016 .05816 L
.46064 .10472 L
Mistroke
.46113 .09518 L
.46161 .04404 L
.4621 .07543 L
.46259 .04504 L
.46307 .13259 L
.46356 .16693 L
.46404 .04095 L
.46453 .02863 L
.46501 .02118 L
.4655 .12198 L
.46599 .21125 L
.46647 .06676 L
.46696 .01753 L
.46744 .01569 L
.46793 .08268 L
.46842 .20076 L
.4689 .09671 L
.46939 .03146 L
.46987 .03569 L
.47036 .04912 L
.47085 .15728 L
.47133 .11037 L
.47182 .05017 L
.4723 .07726 L
.47279 .04406 L
.47328 .10417 L
.47376 .09546 L
.47425 .05883 L
.47473 .12485 L
.47522 .06558 L
.4757 .05866 L
.47619 .06638 L
.47668 .05422 L
.47716 .1572 L
.47765 .10423 L
.47813 .03248 L
.47862 .04216 L
.47911 .041 L
.47959 .16905 L
.48008 .15465 L
.48056 .02907 L
.48105 .0261 L
.48154 .02466 L
.48202 .1554 L
.48251 .19365 L
.48299 .04232 L
.48348 .01865 L
.48397 .01545 L
.48445 .1187 L
.48494 .20276 L
Mistroke
.48542 .06464 L
.48591 .01803 L
.48639 .01786 L
.48688 .08063 L
.48737 .19794 L
.48785 .09572 L
.48834 .0221 L
.48882 .02575 L
.48931 .05496 L
.4898 .18932 L
.49028 .12541 L
.49077 .02852 L
.49125 .03539 L
.49174 .03941 L
.49223 .16597 L
.49271 .13991 L
.4932 .03468 L
.49368 .04475 L
.49417 .03127 L
.49466 .13057 L
.49514 .14971 L
.49563 .04418 L
.49611 .04984 L
.4966 .03206 L
.49708 .1009 L
.49757 .16734 L
.49806 .06096 L
.49854 .04787 L
.49903 .03993 L
.49951 .08028 L
.5 .1783 L
.50049 .08027 L
.50097 .03993 L
.50146 .04785 L
.50194 .06096 L
.50243 .16732 L
.50292 .1009 L
.5034 .03205 L
.50389 .04984 L
.50437 .04418 L
.50486 .1497 L
.50534 .13059 L
.50583 .03127 L
.50632 .04477 L
.5068 .03468 L
.50729 .13992 L
.50777 .16597 L
.50826 .03941 L
.50875 .03539 L
.50923 .02852 L
Mistroke
.50972 .12542 L
.5102 .1893 L
.51069 .05496 L
.51118 .02574 L
.51166 .0221 L
.51215 .09571 L
.51263 .19793 L
.51312 .08065 L
.51361 .01786 L
.51409 .01804 L
.51458 .06464 L
.51506 .20279 L
.51555 .1187 L
.51603 .01545 L
.51652 .01865 L
.51701 .04233 L
.51749 .19366 L
.51798 .15538 L
.51846 .02466 L
.51895 .0261 L
.51944 .02908 L
.51992 .15462 L
.52041 .16904 L
.52089 .04101 L
.52138 .04216 L
.52187 .03248 L
.52235 .10421 L
.52284 .15722 L
.52332 .05423 L
.52381 .06637 L
.5243 .05866 L
.52478 .06559 L
.52527 .12487 L
.52575 .05882 L
.52624 .09544 L
.52672 .10418 L
.52721 .04407 L
.5277 .07724 L
.52818 .05015 L
.52867 .11038 L
.52915 .15729 L
.52964 .04911 L
.53013 .03568 L
.53061 .03147 L
.5311 .09672 L
.53158 .20076 L
.53207 .08267 L
.53256 .01569 L
.53304 .01753 L
.53353 .06675 L
Mistroke
.53401 .21124 L
.5345 .12197 L
.53499 .02118 L
.53547 .02864 L
.53596 .04095 L
.53644 .16693 L
.53693 .13259 L
.53741 .04505 L
.5379 .07545 L
.53839 .04403 L
.53887 .09517 L
.53936 .10472 L
.53984 .05817 L
.54033 .13204 L
.54082 .08473 L
.5413 .0419 L
.54179 .0556 L
.54227 .04657 L
.54276 .16999 L
.54325 .14588 L
.54373 .02428 L
.54422 .01918 L
.5447 .02492 L
.54519 .1563 L
.54568 .17856 L
.54616 .04441 L
.54665 .04524 L
.54713 .03415 L
.54762 .09098 L
.5481 .14276 L
.54859 .06195 L
.54908 .10848 L
.54956 .09738 L
.55005 .04041 L
.55053 .06696 L
.55102 .04142 L
.55151 .1466 L
.55199 .1825 L
.55248 .04131 L
.55296 .0187 L
.55345 .01568 L
.55394 .12198 L
.55442 .20383 L
.55491 .06735 L
.55539 .04999 L
.55588 .04914 L
.55637 .05949 L
.55685 .12934 L
.55734 .06759 L
.55782 .11277 L
Mistroke
.55831 .14477 L
.55879 .04042 L
.55928 .03535 L
.55977 .02739 L
.56025 .11727 L
.56074 .21543 L
.56122 .08284 L
.56171 .02318 L
.5622 .02454 L
.56268 .06127 L
.56317 .15869 L
.56365 .08804 L
.56414 .07832 L
.56463 .11348 L
.56511 .04317 L
.5656 .04835 L
.56608 .0353 L
.56657 .10018 L
.56706 .20625 L
.56754 .09077 L
.56803 .02002 L
.56851 .02449 L
.569 .05517 L
.56948 .16257 L
.56997 .1013 L
.57046 .07966 L
.57094 .13198 L
.57143 .05116 L
.57191 .04251 L
.5724 .03157 L
.57289 .09114 L
.57337 .22434 L
.57386 .1068 L
.57434 .02625 L
.57483 .04075 L
.57532 .04633 L
.5758 .14365 L
.57629 .09011 L
.57677 .09515 L
.57726 .17651 L
.57775 .0647 L
.57823 .02211 L
.57872 .01829 L
.5792 .08079 L
.57969 .21799 L
.58017 .11945 L
.58066 .05078 L
.58115 .08042 L
.58163 .04082 L
.58212 .08306 L
Mistroke
.5826 .06025 L
.58309 .09925 L
.58358 .21485 L
.58406 .09575 L
.58455 .0175 L
.58503 .02438 L
.58552 .05004 L
.58601 .15047 L
.58649 .09612 L
.58698 .09378 L
.58746 .16551 L
.58795 .06346 L
.58844 .01842 L
.58892 .01647 L
.58941 .07878 L
.58989 .20021 L
.59038 .11426 L
.59086 .07022 L
.59135 .10333 L
.59184 .0424 L
.59232 .04538 L
.59281 .03516 L
.59329 .09717 L
.59378 .22071 L
.59427 .11264 L
.59475 .04622 L
.59524 .06546 L
.59572 .03586 L
.59621 .08602 L
.5967 .05917 L
.59718 .12094 L
.59767 .22961 L
.59815 .09391 L
.59864 .02883 L
.59913 .03819 L
.59961 .04793 L
.6001 .12507 L
.60058 .07613 L
.60107 .12641 L
.60155 .21732 L
.60204 .07811 L
.60253 .0193 L
.60301 .02485 L
.6035 .05942 L
.60398 .14638 L
.60447 .07831 L
.60496 .12343 L
.60544 .20803 L
.60593 .06862 L
.60641 .01916 L
Mistroke
.6069 .02401 L
.60739 .06972 L
.60787 .15248 L
.60836 .07579 L
.60884 .14472 L
.60933 .20908 L
.60982 .05844 L
.6103 .02255 L
.61079 .0253 L
.61127 .07254 L
.61176 .13674 L
.61224 .07336 L
.61273 .16329 L
.61322 .20531 L
.6137 .05472 L
.61419 .03269 L
.61467 .02953 L
.61516 .06275 L
.61565 .1087 L
.61613 .06645 L
.61662 .18243 L
.6171 .21323 L
.61759 .0609 L
.61808 .05681 L
.61856 .04724 L
.61905 .05068 L
.61953 .07694 L
.62002 .05557 L
.62051 .20417 L
.62099 .21211 L
.62148 .06585 L
.62196 .09732 L
.62245 .07502 L
.62293 .0302 L
.62342 .03415 L
.62391 .03807 L
.62439 .18169 L
.62488 .18282 L
.62536 .08465 L
.62585 .16348 L
.62634 .12056 L
.62682 .01907 L
.62731 .01863 L
.62779 .02708 L
.62828 .1315 L
.62877 .13449 L
.62925 .09428 L
.62974 .23269 L
.63022 .17509 L
.63071 .03845 L
Mistroke
.6312 .06019 L
.63168 .03661 L
.63217 .06466 L
.63265 .05805 L
.63314 .0768 L
.63362 .23974 L
.63411 .17312 L
.6346 .08912 L
.63508 .16997 L
.63557 .08375 L
.63605 .01472 L
.63654 .01734 L
.63703 .04807 L
.63751 .15714 L
.638 .10706 L
.63848 .13382 L
.63897 .2611 L
.63946 .13332 L
.63994 .05997 L
.64043 .09594 L
.64091 .03845 L
.6414 .03588 L
.64189 .02123 L
.64237 .10056 L
.64286 .21451 L
.64334 .11275 L
.64383 .16119 L
.64431 .24795 L
.6448 .08747 L
.64529 .05169 L
.64577 .06867 L
.64626 .03534 L
.64674 .05337 L
.64723 .03068 L
.64772 .16364 L
.6482 .23392 L
.64869 .11202 L
.64917 .20971 L
.64966 .22729 L
.65015 .05906 L
.65063 .06276 L
.65112 .05425 L
.6516 .03528 L
.65209 .04579 L
.65258 .03897 L
.65306 .18444 L
.65355 .20107 L
.65403 .1135 L
.65452 .24357 L
.655 .22344 L
Mistroke
.65549 .0684 L
.65598 .10039 L
.65646 .07649 L
.65695 .02255 L
.65743 .0225 L
.65792 .0329 L
.65841 .15795 L
.65889 .14634 L
.65938 .11644 L
.65986 .28854 L
.66035 .22578 L
.66084 .11119 L
.66132 .20547 L
.66181 .12221 L
.66229 .02232 L
.66278 .03998 L
.66327 .0307 L
.66375 .06987 L
.66424 .0489 L
.66472 .10284 L
.66521 .25526 L
.66569 .17531 L
.66618 .18553 L
.66667 .32116 L
.66715 .17966 L
.66764 .11446 L
.66812 .17396 L
.66861 .06914 L
.6691 .01898 L
.66958 .03007 L
.67007 .0371 L
.67055 .07439 L
.67104 .0419 L
.67153 .1455 L
.67201 .25559 L
.6725 .14754 L
.67298 .25377 L
.67347 .35566 L
.67396 .16963 L
.67444 .21223 L
.67493 .26197 L
.67541 .07945 L
.6759 .07709 L
.67638 .08749 L
.67687 .02366 L
.67736 .02455 L
.67784 .01816 L
.67833 .11033 L
.67881 .12524 L
.6793 .08406 L
Mistroke
.67979 .27972 L
.68027 .28516 L
.68076 .17855 L
.68124 .38113 L
.68173 .35298 L
.68222 .18411 L
.6827 .33046 L
.68319 .28232 L
.68367 .10599 L
.68416 .18508 L
.68465 .13813 L
.68513 .02511 L
.68562 .0522 L
.6861 .0382 L
.68659 .03491 L
.68707 .0244 L
.68756 .04448 L
.68805 .15958 L
.68853 .11488 L
.68902 .15112 L
.6895 .35396 L
.68999 .26115 L
.69048 .27971 L
.69096 .5116 L
.69145 .37622 L
.69193 .36558 L
.69242 .59654 L
.69291 .43405 L
.69339 .39574 L
.69388 .60332 L
.69436 .42942 L
.69485 .36771 L
.69534 .54457 L
.69582 .37446 L
.69631 .30139 L
.69679 .44098 L
.69728 .28118 L
.69776 .21106 L
.69825 .3239 L
.69874 .19414 L
.69922 .13803 L
.69971 .23548 L
.70019 .13115 L
.70068 .08608 L
.70117 .16638 L
.70165 .08554 L
.70214 .05049 L
.70262 .11639 L
.70311 .05545 L
.7036 .03282 L
Mistroke
.70408 .0838 L
.70457 .03649 L
.70505 .02473 L
.70554 .06221 L
.70603 .02845 L
.70651 .02192 L
.707 .04902 L
.70748 .02465 L
.70797 .02159 L
.70845 .03835 L
.70894 .02446 L
.70943 .02164 L
.70991 .03353 L
.7104 .02386 L
.71088 .0236 L
.71137 .03139 L
.71186 .02323 L
.71234 .02419 L
.71283 .02994 L
.71331 .02423 L
.7138 .02459 L
.71429 .028 L
.71477 .02451 L
.71526 .02637 L
.71574 .02518 L
.71623 .02631 L
.71672 .02548 L
.7172 .02618 L
.71769 .02596 L
.71817 .02532 L
.71866 .02728 L
.71914 .02512 L
.71963 .02555 L
.72012 .02725 L
.7206 .02561 L
.72109 .02565 L
.72157 .02559 L
.72206 .02571 L
.72255 .02637 L
.72303 .02435 L
.72352 .02544 L
.724 .02538 L
.72449 .02491 L
.72498 .02438 L
.72546 .02458 L
.72595 .02454 L
.72643 .02469 L
.72692 .02315 L
.72741 .02475 L
.72789 .0235 L
Mistroke
.72838 .02311 L
.72886 .02346 L
.72935 .02299 L
.72983 .02342 L
.73032 .02195 L
.73081 .02224 L
.73129 .02318 L
.73178 .02185 L
.73226 .02185 L
.73275 .0222 L
.73324 .02184 L
.73372 .02271 L
.73421 .02076 L
.73469 .02279 L
.73518 .02216 L
.73567 .02182 L
.73615 .02237 L
.73664 .02221 L
.73712 .02261 L
.73761 .02256 L
.7381 .02237 L
.73858 .02409 L
.73907 .02267 L
.73955 .02318 L
.74004 .0244 L
.74052 .02385 L
.74101 .02485 L
.7415 .0236 L
.74198 .02572 L
.74247 .02529 L
.74295 .02481 L
.74344 .02534 L
.74393 .02633 L
.74441 .02532 L
.7449 .02595 L
.74538 .02531 L
.74587 .02638 L
.74636 .02561 L
.74684 .02529 L
.74733 .02643 L
.74781 .02535 L
.7483 .02486 L
.74879 .02605 L
.74927 .02512 L
.74976 .02552 L
.75024 .02439 L
.75073 .02495 L
.75121 .02601 L
.7517 .02321 L
.75219 .02534 L
Mistroke
.75267 .0242 L
.75316 .02462 L
.75364 .0239 L
.75413 .02399 L
.75462 .02459 L
.7551 .02421 L
.75559 .02348 L
.75607 .02515 L
.75656 .02366 L
.75705 .02424 L
.75753 .02473 L
.75802 .02437 L
.7585 .02463 L
.75899 .02378 L
.75948 .02514 L
.75996 .02482 L
.76045 .02382 L
.76093 .02459 L
.76142 .02507 L
.7619 .02373 L
.76239 .02453 L
.76288 .02399 L
.76336 .02472 L
.76385 .02373 L
.76433 .02377 L
.76482 .0244 L
.76531 .02366 L
.76579 .02331 L
.76628 .02463 L
.76676 .02268 L
.76725 .02365 L
.76774 .02323 L
.76822 .02342 L
.76871 .02315 L
.76919 .02213 L
.76968 .02364 L
.77017 .02276 L
.77065 .02192 L
.77114 .02323 L
.77162 .02236 L
.77211 .02238 L
.77259 .02242 L
.77308 .02227 L
.77357 .023 L
.77405 .02173 L
.77454 .02287 L
.77502 .02242 L
.77551 .02227 L
.776 .02241 L
.77648 .02338 L
Mistroke
.77697 .02177 L
.77745 .02286 L
.77794 .02288 L
.77843 .02293 L
.77891 .02281 L
.7794 .02263 L
.77988 .02371 L
.78037 .02317 L
.78086 .02278 L
.78134 .0244 L
.78183 .02341 L
.78231 .02356 L
.7828 .02463 L
.78328 .02369 L
.78377 .02473 L
.78426 .02424 L
.78474 .02489 L
.78523 .02458 L
.78571 .02448 L
.7862 .02542 L
.78669 .02532 L
.78717 .02381 L
.78766 .02614 L
.78814 .02474 L
.78863 .02502 L
.78912 .02492 L
.7896 .02523 L
.79009 .02476 L
.79057 .02494 L
.79106 .02485 L
.79155 .02493 L
.79203 .02437 L
.79252 .02457 L
.793 .02479 L
.79349 .0235 L
.79397 .02454 L
.79446 .02419 L
.79495 .02281 L
.79543 .02402 L
.79592 .02357 L
.7964 .02274 L
.79689 .02321 L
.79738 .02242 L
.79786 .02331 L
.79835 .02206 L
.79883 .02273 L
.79932 .02259 L
.79981 .02213 L
.80029 .02258 L
.80078 .02284 L
Mistroke
.80126 .02178 L
.80175 .02305 L
.80224 .02256 L
.80272 .02232 L
.80321 .02271 L
.80369 .02334 L
.80418 .02214 L
.80466 .02326 L
.80515 .02289 L
.80564 .02333 L
.80612 .02308 L
.80661 .02309 L
.80709 .02369 L
.80758 .02316 L
.80807 .02368 L
.80855 .02375 L
.80904 .02332 L
.80952 .02407 L
.81001 .02448 L
.8105 .02299 L
.81098 .02486 L
.81147 .0238 L
.81195 .02379 L
.81244 .0241 L
.81293 .02432 L
.81341 .02349 L
.8139 .02421 L
.81438 .02368 L
.81487 .02381 L
.81535 .02379 L
.81584 .02371 L
.81633 .02307 L
.81681 .02418 L
.8173 .023 L
.81778 .02361 L
.81827 .0229 L
.81876 .02353 L
.81924 .02329 L
.81973 .02285 L
.82021 .02342 L
.8207 .02291 L
.82119 .02297 L
.82167 .02292 L
.82216 .02283 L
.82264 .02267 L
.82313 .02276 L
.82362 .02232 L
.8241 .02262 L
.82459 .02235 L
.82507 .02236 L
Mistroke
.82556 .02181 L
.82604 .02278 L
.82653 .02182 L
.82702 .02219 L
.8275 .02186 L
.82799 .02216 L
.82847 .0219 L
.82896 .0222 L
.82945 .02163 L
.82993 .02246 L
.83042 .02179 L
.8309 .02228 L
.83139 .02201 L
.83188 .02244 L
.83236 .02212 L
.83285 .02235 L
.83333 .02245 L
.83382 .0224 L
.83431 .02233 L
.83479 .02261 L
.83528 .02269 L
.83576 .02286 L
.83625 .02269 L
.83673 .02292 L
.83722 .02354 L
.83771 .02296 L
.83819 .0238 L
.83868 .0232 L
.83916 .02429 L
.83965 .02347 L
.84014 .02419 L
.84062 .02408 L
.84111 .0243 L
.84159 .02431 L
.84208 .02444 L
.84257 .02448 L
.84305 .0246 L
.84354 .02426 L
.84402 .02501 L
.84451 .02424 L
.845 .02465 L
.84548 .02409 L
.84597 .02478 L
.84645 .02415 L
.84694 .02434 L
.84742 .02403 L
.84791 .02458 L
.8484 .02385 L
.84888 .02434 L
.84937 .02389 L
Mistroke
.84985 .02435 L
.85034 .02377 L
.85083 .02392 L
.85131 .02384 L
.8518 .02363 L
.85228 .02356 L
.85277 .02359 L
.85326 .02328 L
.85374 .02325 L
.85423 .02297 L
.85471 .0233 L
.8552 .02294 L
.85569 .02259 L
.85617 .02296 L
.85666 .02244 L
.85714 .02278 L
.85763 .02201 L
.85811 .0226 L
.8586 .02211 L
.85909 .02212 L
.85957 .0219 L
.86006 .02216 L
.86054 .02172 L
.86103 .02212 L
.86152 .02146 L
.862 .02216 L
.86249 .02119 L
.86297 .022 L
.86346 .02139 L
.86395 .02159 L
.86443 .02115 L
.86492 .02148 L
.8654 .02127 L
.86589 .02127 L
.86638 .02101 L
.86686 .02146 L
.86735 .02111 L
.86783 .02123 L
.86832 .02127 L
.8688 .02144 L
.86929 .02136 L
.86978 .02143 L
.87026 .02147 L
.87075 .02172 L
.87123 .02148 L
.87172 .02198 L
.87221 .02178 L
.87269 .02182 L
.87318 .02224 L
.87366 .02204 L
Mistroke
.87415 .02261 L
.87464 .02191 L
.87512 .02294 L
.87561 .02239 L
.87609 .02277 L
.87658 .02259 L
.87707 .02307 L
.87755 .02269 L
.87804 .02308 L
.87852 .02277 L
.87901 .02354 L
.87949 .02274 L
.87998 .02363 L
.88047 .02308 L
.88095 .02362 L
.88144 .0234 L
.88192 .02385 L
.88241 .02344 L
.8829 .0238 L
.88338 .02363 L
.88387 .02413 L
.88435 .02338 L
.88484 .02403 L
.88533 .02373 L
.88581 .02389 L
.8863 .02363 L
.88678 .02407 L
.88727 .02372 L
.88776 .02402 L
.88824 .02361 L
.88873 .02432 L
.88921 .02363 L
.8897 .02417 L
.89018 .02391 L
.89067 .0239 L
.89116 .02407 L
.89164 .02405 L
.89213 .02397 L
.89261 .02395 L
.8931 .02391 L
.89359 .02435 L
.89407 .0236 L
.89456 .02413 L
.89504 .02389 L
.89553 .02376 L
.89602 .02375 L
.8965 .02355 L
.89699 .02366 L
.89747 .02311 L
.89796 .0233 L
Mistroke
.89845 .02292 L
.89893 .02296 L
.89942 .02251 L
.8999 .02277 L
.90039 .02201 L
.90087 .02248 L
.90136 .02203 L
.90185 .022 L
.90233 .02166 L
.90282 .02187 L
.9033 .02155 L
.90379 .02156 L
.90428 .02113 L
.90476 .02165 L
.90525 .02076 L
.90573 .02133 L
.90622 .02077 L
.90671 .02099 L
.90719 .02062 L
.90768 .02084 L
.90816 .02044 L
.90865 .02079 L
.90914 .02029 L
.90962 .02076 L
.91011 .02005 L
.91059 .02079 L
.91108 .02024 L
.91156 .02037 L
.91205 .02025 L
.91254 .02052 L
.91302 .02019 L
.91351 .02041 L
.91399 .02028 L
.91448 .02045 L
.91497 .02033 L
.91545 .02055 L
.91594 .02048 L
.91642 .0206 L
.91691 .02057 L
.9174 .02083 L
.91788 .0205 L
.91837 .02108 L
.91885 .02065 L
.91934 .02082 L
.91983 .02101 L
.92031 .02087 L
.9208 .02093 L
.92128 .02084 L
.92177 .02107 L
.92225 .02102 L
Mistroke
.92274 .02097 L
.92323 .02124 L
.92371 .02114 L
.9242 .02135 L
.92468 .0215 L
.92517 .02143 L
.92566 .02173 L
.92614 .02184 L
.92663 .02193 L
.92711 .02204 L
.9276 .02251 L
.92809 .02212 L
.92857 .02281 L
.92906 .02261 L
.92954 .02315 L
.93003 .02282 L
.93052 .02341 L
.931 .02331 L
.93149 .02376 L
.93197 .02355 L
.93246 .02421 L
.93294 .02376 L
.93343 .0247 L
.93392 .02399 L
.9344 .0246 L
.93489 .0245 L
.93537 .02473 L
.93586 .02453 L
.93635 .02512 L
.93683 .02463 L
.93732 .02513 L
.9378 .02486 L
.93829 .02536 L
.93878 .02485 L
.93926 .02556 L
.93975 .0248 L
.94023 .02584 L
.94072 .02487 L
.94121 .02564 L
.94169 .02501 L
.94218 .02564 L
.94266 .02498 L
.94315 .02523 L
.94363 .0249 L
.94412 .02513 L
.94461 .02457 L
.94509 .02501 L
.94558 .02436 L
.94606 .02483 L
.94655 .02418 L
Mistroke
.94704 .02469 L
.94752 .02407 L
.94801 .02453 L
.94849 .0239 L
.94898 .02444 L
.94947 .02387 L
.94995 .02409 L
.95044 .02379 L
.95092 .02418 L
.95141 .02354 L
.9519 .02394 L
.95238 .02337 L
.95287 .02384 L
.95335 .02322 L
.95384 .0235 L
.95432 .02311 L
.95481 .02331 L
.9553 .02287 L
.95578 .02309 L
.95627 .02273 L
.95675 .02283 L
.95724 .02242 L
.95773 .02263 L
.95821 .02208 L
.9587 .02221 L
.95918 .02186 L
.95967 .02194 L
.96016 .02161 L
.96064 .02147 L
.96113 .02153 L
.96161 .02133 L
.9621 .02129 L
.96259 .02113 L
.96307 .02116 L
.96356 .0211 L
.96404 .02088 L
.96453 .02108 L
.96501 .02079 L
.9655 .02101 L
.96599 .02067 L
.96647 .02093 L
.96696 .02062 L
.96744 .02076 L
.96793 .02061 L
.96842 .02064 L
.9689 .02042 L
.96939 .02055 L
.96987 .02046 L
.97036 .02052 L
.97085 .02033 L
Mistroke
.97133 .02053 L
.97182 .02047 L
.9723 .02046 L
.97279 .02046 L
.97328 .02051 L
.97376 .02048 L
.97425 .02041 L
.97473 .02041 L
.97522 .02046 L
.9757 .02032 L
.97619 .02042 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[66]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001Wooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0ol0000Hooooo`;o00001?ooool01?l0003oooooooooooooool5
o`0001_ooooo0_l0000Pooooo`;o00001?ooool01?l0003oooooooooooooool5o`0001Sooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0ol0000Hooooo`;o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00002_ooool001oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000001Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Fooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00006_ooool01?l0003oooooooooool0
000Nooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00005oooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Wooooo000Hooooo`Go00000_ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000004?ooool5o`0000;ooooo00Co0000oooooooooooo
00001oooool5o`00013ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool06_ooool01?l0003oooooooooool0000Nooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool05oooool01?l0003oooooooooool00007ooooo`Go00005oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000002Oooool001oooooo00Co0000oooooooo
oooo00001oooool4o`0001Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
000Hooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool06Oooool01?l0003ooooo
ooooool0000Nooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool05_ooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0001Sooooo00Co0000oooooooooooo0000
1oooool4o`0000[ooooo000Oooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
6Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000001Sooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000001[ooooo00Co0000oooooooooooo00007_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000005oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000001Sooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0;ooooo`007oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo01Sooooo00Co0000oooooooooooo00002Oooool2o`0001Sooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000001[ooooo00Co0000oooooooooooo00007_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000005oooool01?l0003ooooooooo
ool00009ooooo`;o00006?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00[o
oooo000Pooooo`;o00002_ooool2o`0001Wooooo0_l0000;ooooo`03o`000?oooooooooo01Oooooo
0_l00009ooooo`?o00007?ooool2o`00023ooooo0_l00009ooooo`?o00006Oooool2o`0000_ooooo
00?o0000ooooooooool05oooool2o`0000[ooooo0_l0000:ooooo`008Oooool00ol0003ooooooooo
o`3looooo`008Oooool00ol0003oooooooooo`3looooo`008Oooool00ol0003oooooooooo`3loooo
o`008Oooool00ol0003oooooooooo`3looooo`006oooooono`0000Oooooo000Qooooo`Go00001ooo
ool7o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
ooooo`000?oooooo000000;ooooo00Co0000ooooool0003o00000oooool4o`000003ooooool0003o
oooo00;ooooo00Co0000ooooool0003ooooo0_l00003ooooo`;o00000_ooool01?l0003ooooooooo
ooooool2o`0000?ooooo0_l000001?oooooo0000ooooool00003ooooo`04o`000?oooooo0000oooo
o`;o00000_ooool2o`0000;ooooo00Go0000ooooool0003o0000ooooo`02o`0000?ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03o`0000Cooooo
00Co0000oooooooooooooooo1_l00008ooooo`Go00003Oooool0027ooooo00Co0000oooooooooooo
oooo2_l00004ooooocCo00000oooool4o`000005ooooool0003o0000ooooool000000_ooool01Ol0
003oooooo`000?oooooo000000?ooooo0ol00003ooooo`Co000000Soooooo`000?oooooo0000oooo
ool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00005ooooo`?o00000oooool03Ol0
003oooooo`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l00002oooo
o`?o00000oooool2o`000003ooooool0003o000000?ooooo0_l000001Ooooooo0000ooooool0003o
oooo00;o00000ooooolYo`000003ooooool0003o000000So00001?ooool:o`00017ooooo000Qoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06oooo
o`?o00001?ooool6o`0000?ooooo1ol000002Ooooooo0000oooooooooooo0000ooooool0003ooooo
o`000003ooooo`Co00000_ooool6o`000007ooooool0003oooooo`000?oooooo0000ooooo`02o`00
00;ooooo1?l00004ooooo`?o00000oooool01Ol0003oooooo`000?l0003ooooo00?o000000Gooooo
o`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0
003o000000?ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o00000oooool6o`0000Cooooo
0ol00008ooooo`03o`000?oooooooooo02?ooooo0_l0000Fooooo`008Oooool00ol0003ooooooooo
o`10ooooo`?o00000oooool9o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo
1Ol00002ooooo`Ko000000Ooooooo`000?oooooo0000ooooool0003ooooo00?o000000?oooooo`00
0?l000002_l000001?oooooo0000o`000?ooool2o`000005ooooool0003o0000o`000?ooool00ol0
00001?oooooo0000o`000?ooool5o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo
0000ooooo`04o`000003ooooool0003ooooo00;o00000oooool3o`00053ooooo000Qooooo`03o`00
0?oooooooooo043ooooo0ol00003oooooa7o000000?oooooo`000?l000003Ol000001Ooooooo0000
o`000?l0003ooooo00?o000000?oooooo`000?l000002_l000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000Go000000?oooooo`000?l000001_l000000ooooooo0000o`00000;o`00
0003ooooool0003ooooo00;o00000oooool2o`00057ooooo000Qooooo`03o`000?oooooooooo047o
oooo0_l00003oooooa7o000000?oooooo`000?l000004Ol000001Ooooooo0000o`000?l0003ooooo
00co000000Coooooo`000?l0003ooooo4ol000000ooooooo0000o`00000;o`000003ooooool0003o
oooo00;o00000oooool2o`00057ooooo000Qooooo`;o0000@_ooool2o`0000?ooooo4Ol000000ooo
oooo0000o`00000Eo`000003ooooool0003o0000027o000000?oooooo`000?l000003Ol000000ooo
oooo0000o`000003ooooo`;o0000DOooool0027ooooo00?o0000ooooooooool0@Oooool2o`0000?o
oooo:Ol000000ooooooo0000o`00000ao`000003ooooool0003o000000?ooooo0_l0001Aooooo`00
8Oooool00ol0003oooooooooo`11ooooo`;o00000ooooolYo`000003ooooool0003o0000037o0000
00?oooooo`000?l000000_ooool2o`0005;ooooo000Qooooo`03o`000?oooooooooo047ooooo0_l0
0003oooooego000000?oooooo`000?l000000_ooool2o`0005;ooooo000Qooooo`03o`000?oooooo
oooo047ooooo0_l00003oooooego000000?oooooo`000?l000000_ooool2o`0005;ooooo000Qoooo
o`03o`000?oooooooooo047ooooo0_l00003oooooego000000?oooooo`000?l000000_ooool2o`00
05;ooooo000Qooooo`03o`000?oooooooooo04;ooooo00Co0000ooooooooooooooooGOl000000ooo
oooo0000o`000002ooooo`;o0000D_ooool0027ooooo00?o0000ooooooooool0@_ooool01?l0003o
oooooooooooooomMo`000003ooooool0003o000000;ooooo0_l0001Booooo`008Oooool2o`0004?o
oooo00Co0000ooooooooooooooooGOl000000ooooooo0000o`000002ooooo`;o0000D_ooool0027o
oooo00?o0000ooooooooool0@_ooool01?l0003ooooooooooooooomMo`000003ooooool0003o0000
00;ooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`12ooooo`04o`000?oooooooooooooo
of3o00000_ooool2o`0005;ooooo000Qooooo`03o`000?oooooooooo04;ooooo0_l00002ooooof3o
00000_ooool2o`0005;ooooo000Qooooo`03o`000?oooooooooo04;ooooo0_l00002ooooof3o0000
0_ooool2o`0005;ooooo000Qooooo`03o`000?oooooooooo04;ooooo0_l00002ooooof3o00000_oo
ool2o`0005;ooooo000Qooooo`03o`000?oooooooooo04;ooooo0_l00002ooooof3o00000_ooool2
o`0005;ooooo000Qooooo`;o0000@oooool2o`0000;oooooH?l00002ooooo`;o0000D_ooool0027o
oooo00?o0000ooooooooool0@_ooool2o`0000;oooooH?l00002ooooo`;o0000D_ooool0027ooooo
00?o0000ooooooooool0@_ooool2o`0000;oooooH?l00002ooooo`;o0000D_ooool0027ooooo00?o
0000ooooooooool0@_ooool2o`0000;oooooH?l00002ooooo`;o0000D_ooool0027ooooo00?o0000
ooooooooool0@_ooool2o`0000;oooooH?l00002ooooo`03o`000?oooooooooo057ooooo000<oooo
o`Go00000oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo04;ooooo0_l00002oooo
of3o00000_ooool00ol0003oooooooooo`1Aooooo`003Oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`12ooooo`;o00000_oooomPo`0000;ooooo00?o0000ooooooooool0DOooool000kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
0ol00013ooooo`03o`000?oooooooooo02Wo000000?oooooo`000?l000002_l000000ooooooo0000
o`00000Wo`0000;ooooo00?o0000ooooooooool0DOooool000oooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo02Wo000000?oooooo`000?l000002_l000000ooooooo
0000o`00000Wo`0000;ooooo00?o0000ooooooooool0DOooool000cooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo02Wo000000?oooooo`000?l000002_l00000
0ooooooo0000o`00000Wo`0000;ooooo00?o0000ooooooooool0DOooool000cooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02Wo000000?oooooo`000?l00000
2_l000000ooooooo0000o`00000Wo`0000;ooooo00?o0000ooooooooool0DOooool000gooooo0ol0
0004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0So`000003ooooool0003o000000?o000000?oooooo`000?l000002_l000000ooooooo0000o`00
000Wo`0000;ooooo00?o0000ooooooooool0DOooool0027ooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`0Qo`000003ooooool0003ooooo00Go000000?oooooo`000?l000002_l00000
0ooooooo0000o`000005o`000003ooooool0003o000001oo00000_ooool00ol0003oooooooooo`1A
ooooo`008Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo027o000000?oooooo`00
0?ooool01Ol000000ooooooo0000o`000002o`000003ooooool0003o000000Go000000?oooooo`00
0?l000001Ol000000ooooooo0000o`00000Oo`0000;ooooo00?o0000ooooooooool0DOooool0027o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Qo`000003ooooool0003ooooo00Go
000000?oooooo`000?l000000_l000000ooooooo0000o`000005o`000003ooooool0003o000000Go
000000?oooooo`000?l000007ol00002ooooo`03o`000?oooooooooo057ooooo000Qooooo`;o0000
A?ooool00ol0003oooooooooo`0Oo`000005ooooool0003oooooo`000?ooool01?l00002ooooo`Co
000000?oooooo`000?l000001Ol000000ooooooo0000o`000005o`000003ooooool0003o000001oo
00000_ooool00ol0003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo01oo000000Goooooo`000?oooooo0000ooooo`04o`0000;ooooo1?l000000ooooooo
0000o`000005o`000003ooooool0003o000000?o000000?oooooo`000?ooool00_l000000ooooooo
0000o`00000Lo`0000;ooooo00?o0000ooooooooool0DOooool0027ooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`0Oo`000005ooooool0003oooooo`000?ooool00_l000001?oooooo
0000ooooooooool4o`000004ooooool0003oooooooooo`Co000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000ooooo`02o`000003ooooool0003o000001co00000_ooool00ol0003ooooooooo
o`1Aooooo`008Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01oo000000Kooooo
o`000?oooooo0000ooooool00002ooooo`04o`000?ooooooooooooooo`?o000000Coooooo`000?oo
oooooooo0ol00002ooooo`;o00000_ooool01?l0003oooooo`000?ooool2o`000003ooooool0003o
000001co00000_ooool00ol0003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01oo000000Koooooo`000?oooooo0000ooooool00002ooooo`04o`000?oo
ooooooooooooo`?o000000Coooooo`000?oooooooooo0ol00002ooooo`;o00000_ooool01?l0003o
ooooo`000?ooool2o`000003ooooool0003o000001co00000_ooool00ol0003oooooooooo`1Aoooo
o`008Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01co000000Ooooooo`000?l0
003oooooo`000?oooooo000000Cooooo00Co0000oooooooooooooooo0ol00004ooooo`?o00000_oo
ool2o`0000Cooooo00Oo0000ooooool0003o0000ooooool0003ooooo01co00000_ooool00ol0003o
ooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo013o0000
00?oooooo`000?l000002Ol000001ooooooo0000o`000?oooooo0000ooooool000001?ooool01?l0
003oooooooooooooool3o`0000Cooooo0ol00002ooooo`;o00001?ooool01ol0003oooooo`000?l0
003oooooo`000?ooool02ol000000ooooooo0000o`00000>o`0000;ooooo00?o0000ooooooooool0
DOooool0027ooooo0_l00014ooooo`03o`000?oooooooooo013o000000?oooooo`000?l000002Ol0
00001ooooooo0000o`000?oooooo0000ooooool000001?ooool01?l0003oooooooooooooool3o`00
00Cooooo0ol00002ooooo`;o00001?ooool01ol0003oooooo`000?l0003oooooo`000?ooool02ol0
00000ooooooo0000o`00000>o`0000;ooooo00?o0000ooooooooool0DOooool0027ooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`0@o`000003ooooool0003o000000Wo000000Oooooo
o`000?l0003oooooo`000?oooooo000000Cooooo00Co0000oooooooooooooooo0_l00006ooooo`;o
00000_ooool2o`0000Cooooo00Oo0000ooooool0003o0000ooooool0003ooooo00_o000000?ooooo
o`000?l000003_l00002ooooo`03o`000?oooooooooo057ooooo000Qooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool04?l000000ooooooo0000o`000009o`000007ooooool0003o0000
ooooool0003oooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooooooool2o`0000Cooooo00Oo0000ooooool0003o0000ooooool0003ooooo
00_o000000?oooooo`000?l000003_l00002ooooo`03o`000?oooooooooo057ooooo000Qooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool04?l000000ooooooo0000o`000009o`000007
ooooool0003o0000ooooool0003oooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooooooool2o`0000Cooooo00Oo0000ooooool0003o0000
ooooool0003ooooo00_o000000Coooooo`000?l0003ooooo3Ol00002ooooo`03o`000?oooooooooo
057ooooo000Qooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool02Ol000000ooooooo
0000o`000004o`000003ooooool0003o000000Ko000000Coooooo`000?l0003ooooo0_l000001?oo
oooo0000ooooool00004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool0
1ol0003oooooo`000?l0003oooooo`000?ooool00_l000000ooooooo0000o`000006o`000004oooo
ool0003o0000ooooo`go00000_ooool00ol0003oooooooooo`1Aooooo`008Oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo00Wo000000Goooooo`000?l0003o0000ooooo`02o`000004
ooooool0003o0000ooooo`Go000000Goooooo`000?l0003oooooo`000002ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooo`000?ooool00_l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000002ol000000ooooooo0000o`00001Cooooo`008Oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo00Wo000000Goooooo`000?l0003o0000ooooo`02o`000003oooo
ool0003o000000?ooooo0ol000001Ooooooo0000o`000?oooooo000000;ooooo00?o0000oooooooo
ool07?ooool01Ol0003oooooooooool0003ooooo00;o000000Coooooo`000?l0003o00000oooool2
o`000004ooooool0003o0000ooooo`go000000?oooooo`000?l00000Doooool0027ooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`09o`000005ooooool0003o0000o`000?ooool00_l0
0006ooooo`?o00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo01cooooo00Ko
0000oooooooooooo0000ooooool00002ooooo`?o00001_ooool2o`000003ooooool0003o000000_o
000000?oooooo`000?l00000Doooool0027ooooo0_l00014ooooo`03o`000?oooooooooo00Wo0000
00Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0_l00004ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool00_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000;o`000003
ooooool0003o000005?ooooo000Qooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
2Ol000001Ooooooo0000o`000?l0003ooooo00;o00001oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`;o
000000?oooooo`000?l000002ol000000ooooooo0000o`00001Cooooo`008Oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo00Wo000000Goooooo`000?l0003o0000ooooo`02o`0000Oo
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`000?l0
00002ol000000ooooooo0000o`00001Cooooo`008Oooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo00Wo000000Goooooo`000?l0003o0000ooooo`02o`00043ooooo0_l000000ooooooo
0000o`00000;o`000003ooooool0003o000005?ooooo000Qooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool02Ol00002ooooo`;o000000?oooooo`000?ooool0@Oooool01ol0003ooooo
o`000?l0003oooooo`000?ooool02?l000000ooooooo0000o`00001Cooooo`003_ooool3o`0000?o
oooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Wo
00000_ooool2o`000003ooooool0003ooooo047ooooo00Oo0000ooooool0003o0000ooooool0003o
oooo00So000000?oooooo`000?l00000Doooool000oooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo00Wo00000_ooool2o`0004Kooooo0_l000000ooooooo0000oooo
o`08o`000003ooooool0003o000005?ooooo000<ooooo`Go00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo0ol00013ooooo`03o`000?oooooooooo00So0000
0oooool2o`0004Kooooo0_l00003ooooo`So000000?oooooo`000?l00000Doooool000cooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`08o`0000Cooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`02ooooo`So000000?oooooo`000?l00000Doooool000go
oooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0@oooool01?l0003oooooo`000?ooool7o`0000Cooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`02ooooo`So000000?oooooo`000?l00000Dooo
ool000kooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`13ooooo`04o`000?oooooo0000ooooo`Go000000?oooooo`000?oo
ool00oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
00001Ol000000ooooooo0000o`00001Cooooo`003oooool00ol0003oooooooooo`02ooooo`;o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0@oooool01?l0003oooooo`000?ooool2o`000005
ooooool0003o0000ooooool00000D?ooool01Ol0003oooooo`000?l0003ooooo00?o000000?ooooo
o`000?l00000Doooool0027ooooo00?o0000ooooooooool0@oooool01?l0003oooooo`000?ooool2
o`000005ooooool0003o0000ooooool00000D?ooool01Ol0003oooooo`000?l0003ooooo00?o0000
00?oooooo`000?l00000Doooool0027ooooo00?o0000ooooooooool0@oooool01?l0003oooooo`00
0?ooool2o`000005ooooool0003o0000ooooool00000D?ooool01Ol0003oooooo`000?l0003ooooo
00Ko0000Doooool0027ooooo00?o0000ooooooooool0@oooool01?l0003oooooo`000?ooool2o`00
0005ooooool0003o0000ooooool00000D?ooool01Ol0003oooooo`000?l0003ooooo00Ko0000Dooo
ool0027ooooo0_l00014ooooo`04o`000?oooooo0000ooooo`;o000000Goooooo`000?l0003ooooo
o`00001@ooooo`05o`000?oooooo0000o`000?ooool01_l0001Cooooo`008Oooool00ol0003ooooo
ooooo`13ooooo`04o`000?oooooo0000ooooo`;o000000Goooooo`000?l0003oooooo`00001@oooo
o`05o`000?oooooo0000o`000?ooool01_l0001Cooooo`008Oooool00ol0003oooooooooo`13oooo
o`04o`000?oooooo0000ooooo`;o000000Goooooo`000?l0003oooooo`00001@ooooo`05o`000?oo
oooo0000o`000?ooool01_l0001Cooooo`008Oooool00ol0003oooooooooo`13ooooo`04o`000?oo
oooo0000ooooo`;o000000?oooooo`000?l00000E?ooool2o`000003ooooool0003o000000Co0000
Doooool0027ooooo00?o0000ooooooooool0@oooool01?l0003oooooo`000?ooool2o`000003oooo
ool0003o000005Cooooo0_l000000ooooooo0000o`000004o`0005?ooooo000Qooooo`03o`000?oo
oooooooo04?ooooo0ol000001?oooooo0000o`000?ooool2o`0005Cooooo0_l000000ooooooo0000
o`000004o`0005?ooooo000Qooooo`03o`000?oooooooooo04?ooooo0ol000001?oooooo0000o`00
0?ooool2o`0005Cooooo0_l000000ooooooo0000o`000004o`0005?ooooo000Qooooo`;o0000A?oo
ool3o`000004ooooool0003o0000ooooo`;o0000E?ooool2o`000003ooooool0003o000000Co0000
Doooool0027ooooo00?o0000ooooooooool0@oooool3o`000004ooooool0003o0000ooooo`;o0000
E?ooool2o`000003ooooool0003o000000Co0000Doooool0027ooooo00?o0000ooooooooool0@ooo
ool3o`000004ooooool0003o0000ooooo`;o0000E?ooool2o`000003ooooool0003o000000Co0000
Doooool0027ooooo00?o0000ooooooooool0@oooool3o`000004ooooool0003o0000ooooo`;o0000
E?ooool2o`000003ooooool0003o000000Co0000Doooool0027ooooo00?o0000ooooooooool0@ooo
ool3o`000005ooooool0003o0000ooooool00000E_ooool00ol0003oooooo`000005o`0005?ooooo
000Qooooo`03o`000?oooooooooo04?ooooo0ol000001Ooooooo0000o`000?oooooo000005Kooooo
00?o0000ooooool000001?l0001Dooooo`008Oooool00ol0003oooooooooo`13ooooo`?o000000Go
ooooo`000?l0003oooooo`00001Fooooo`03o`000?oooooo000000Co0000E?ooool0027ooooo00?o
0000ooooooooool0@oooool3o`000005ooooool0003o0000ooooool00000E_ooool01?l0003ooooo
o`000?ooool3o`0005Cooooo000Qooooo`;o0000A?ooool3o`000005ooooool0003o0000ooooool0
0000E_ooool01?l0003oooooo`000?ooool3o`0005Cooooo000Qooooo`03o`000?oooooooooo04?o
oooo0ol000001Ooooooo0000o`000?oooooo000005Kooooo00Co0000ooooool0003ooooo0ol0001D
ooooo`008Oooool00ol0003oooooooooo`13ooooo`?o000000Goooooo`000?l0003oooooo`00001F
ooooo`04o`000?oooooo0000ooooo`?o0000E?ooool0027ooooo00?o0000ooooooooool0@oooool3
o`000005ooooool0003o0000ooooool00000E_ooool01?l0003oooooo`000?ooool3o`0005Cooooo
000Qooooo`03o`000?oooooooooo04?ooooo0ol000001Ooooooo0000o`000?oooooo000005Kooooo
00Co0000ooooool0003ooooo0ol0001Dooooo`003Oooool3o`0000Cooooo0_l00004ooooo`;o0000
1Oooool00ol0003oooooooooo`13ooooo`?o000000?oooooo`000?l00000F_ooool00ol0003ooooo
ooooo`02o`0005Cooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0A?ooool2o`00
0003ooooool0003o000005[ooooo00?o0000ooooooooool00_l0001Dooooo`003?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`?o0000A?ooool2o`0000;ooooo00?o0000ooooooooool0F?ooool00ol0003ooooooooo
o`02o`0005Cooooo000<ooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0A?ooool2o`0000;ooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`02o`0005Cooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Co
oooo0_l00002ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool00_l0001Dooooo`00
3Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`14ooooo`;o00000_ooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo00;o0000E?ooool000kooooo0_l00004ooooo`;o00001?ooool2o`0000Go
oooo00?o0000ooooooooool0A?ooool2o`00063ooooo0_l0001Dooooo`008Oooool00ol0003ooooo
ooooo`14ooooo`;o0000H?ooool2o`0005Cooooo000Qooooo`03o`000?oooooooooo04Cooooo0_l0
001Pooooo`;o0000E?ooool0027ooooo0_l00015ooooo`;o0000H?ooool2o`0005Cooooo000Qoooo
o`03o`000?oooooooooo04Cooooo0_l0001Pooooo`;o0000E?ooool0027ooooo00?o0000oooooooo
ool0A?ooool2o`00063ooooo0_l0001Dooooo`008Oooool00ol0003oooooooooo`14ooooo`;o0000
H?ooool2o`0005Cooooo000Qooooo`03o`000?oooooooooo04Cooooo0_l0001Pooooo`;o0000E?oo
ool0027ooooo00?o0000ooooooooool0A?ooool2o`00063ooooo0_l0001Dooooo`008Oooool00ol0
003oooooooooo`14ooooo`;o0000H?ooool2o`0005Cooooo000Qooooo`03o`000?oooooooooo04Co
oooo0_l0001Pooooo`;o0000E?ooool0027ooooo0_l00015ooooo`;o0000H?ooool2o`0005Cooooo
000Qooooo`03o`000?oooooooooo04Cooooo0_l0001Pooooo`;o0000E?ooool0027ooooo00?o0000
ooooooooool0A?ooool2o`00063ooooo0_l0001Dooooo`008Oooool00ol0003oooooooooo`14oooo
o`;o0000H?ooool2o`0005Cooooo000Qooooo`03o`000?oooooooooo04Cooooo0_l0001Pooooo`;o
0000E?ooool0027ooooo00?o0000ooooooooool0A?ooool2o`00063ooooo0_l0001Dooooo`008Ooo
ool00ol0003oooooooooo`14ooooo`;o0000H?ooool2o`0005Cooooo000Qooooo`;o0000AOooool2
o`00063ooooo0_l0001Dooooo`008Oooool00ol0003oooooooooo`14ooooo`;o0000H?ooool2o`00
05Cooooo000Qooooo`03o`000?oooooooooo04Cooooo0_l0001Pooooo`;o0000E?ooool0027ooooo
00?o0000ooooooooool0A?ooool2o`00063ooooo0_l0001Dooooo`008Oooool00ol0003ooooooooo
o`14ooooo`;o0000H?ooool2o`0005Cooooo000=ooooo`?o00001?ooool2o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo04Cooooo0_l0001Pooooo`;o0000E?ooool000cooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`14ooooo`;o0000H?ooool2o`0005Cooooo000<ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0A?ooool2o`00063ooooo0_l0001Dooooo`003Oooool3o`0000?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`?o0000A?ooool2
o`00063ooooo0_l0001Dooooo`003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04Cooooo
0_l0001Pooooo`;o0000E?ooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`14oooo
o`;o0000H?ooool2o`0005Cooooo000=ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo04Cooooo0_l0001Pooooo`;o0000E?ooool0027ooooo00?o0000ooooooooool0
A?ooool2o`00063ooooo0_l0001Dooooo`008Oooool00ol0003oooooooooo`14ooooo`;o0000H?oo
ool2o`0005Cooooo000Qooooo`03o`000?oooooooooo04Cooooo0_l0001Pooooo`;o0000E?ooool0
027ooooo0_l00015ooooo`;o0000H?ooool2o`0005Cooooo000Qooooo`03o`000?oooooooooo04Co
oooo0_l0001Pooooo`;o0000E?ooool0027ooooo00?o0000ooooooooool0A?ooool2o`00063ooooo
0_l0001Dooooo`008Oooool00ol0003oooooooooo`14ooooo`;o0000H?ooool2o`0005Cooooo000Q
ooooo`03o`000?oooooooooo04Cooooo0_l0001Pooooo`;o0000E?ooool0027ooooo00?o0000oooo
ooooool0A?ooool2o`00063ooooo0_l0001Dooooo`008Oooool00ol0003oooooooooo`14ooooo`;o
0000H?ooool2o`0005Cooooo000Qooooo`03o`000?oooooooooo04Cooooo0_l0001Pooooo`;o0000
E?ooool0027ooooo0_l00015ooooo`;o0000H?ooool2o`0005Cooooo000Qooooo`03o`000?oooooo
oooo04Cooooo0_l0001Pooooo`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo
04Cooooo0_l0001Pooooo`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo04Co
oooo0_l0001Pooooo`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo04Cooooo
0_l0001Pooooo`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo04Cooooo0_l0
001Pooooo`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo04Cooooo0_l0001P
ooooo`03o`000?oooooooooo05?ooooo000Qooooo`;o0000AOooool2o`00063ooooo00?o0000oooo
ooooool0Doooool0027ooooo00?o0000ooooooooool0A?ooool2o`00063ooooo00?o0000oooooooo
ool0Doooool0027ooooo00?o0000ooooooooool0A?ooool2o`00063ooooo00?o0000ooooooooool0
Doooool0027ooooo00?o0000ooooooooool0A?ooool2o`00063ooooo00?o0000ooooooooool0Dooo
ool0027ooooo00?o0000ooooooooool0A?ooool2o`00063ooooo00?o0000ooooooooool0Doooool0
00Oooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo
04Cooooo0_l0001Pooooo`03o`000?oooooooooo05?ooooo0008ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0A?ooool2o`00063ooooo00?o0000ooooooooool0Dooo
ool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool0Doooool000Sooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool3o`0004Cooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1C
ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?cooooo
0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3looooo`002?ooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo0?co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo001Vooooo`?o0000DOooool3o`00
06?ooooo001Wooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0H_ooool003cooooo
0ol00004ooooo`?o00000_ooool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o
00002Oooool3o`0000?ooooo0ol00002ooooo`?o00001?ooool3o`0000?ooooo1?l00002ooooo`Co
00001oooool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00000oooool3o`00
00;ooooo0ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003ooooo`;o00001?ooool00ol0
003oooooooooo`07ooooo`?o00001Oooool2o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?ooooo
o`000?l00000:_ooool003gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005
ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo0000:oooool003gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`Go0000
0_ooool3o`0000;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooo
oooooooo00000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo02Wooooo000mooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`07o`000?ooooooooooooooool0
003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000009oooo
o`?o00000oooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool01?l0003oooooooooool00006ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo02Wooooo000mooooo`04o`000?oooooooooo
o`0000;ooooo0ol00002ooooo`?o00000oooool4o`0000;ooooo1?l00009ooooo`03o`000?oooooo
oooo00;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo0_l00004
ooooo`?o00002_ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_oo
ool4o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co00000_ooool2o`000003oooo
ool0003o000000Sooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Co
00000oooool3o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l0000/ooooo`00
?Oooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooo
oooo00007?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000
ooooooooool0?_ooool003cooooo1?l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02_ooool3o`0001_ooooo0_l00008ooooo`Go00002?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool5o`0001Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0gooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783576, -81.7298, \
0.00509229, 6.71981}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] 0.49966958432041564`\), 
        ",", \(BackFocalLength \[Rule] 93.35095557506479`\), 
        ",", \(BackFocalPoint \[Rule] {153.3509555750648`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] 1.2263648735485946`\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] 0\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {50.`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.583004929987583`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {53.41699507001242`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 1\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 1, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] False\), 
        ",", \(FindPupils \[Rule] True\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 99.93396050505237`\), 
        ",", \(FrequencyCutoff \[Rule] 859.4809545650826`\), 
        ",", \(FrontFocalLength \[Rule] 99.93396050505234`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-49.93396050505234`\), 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {150.`, 0.`, 0.`}\), 
        ",", \(ImageSampleSize \[Rule] 0.0006256963640554054`\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[100, 50, 10], 50.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[Screen[50], {x, 150.`}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(IntensityTransform \[Rule] True\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.9341264481391712`, 
              6.583004929987581`}, {\(-0.010006608313591684`\), 
              0.9999999999999998`}}\), ",", \(NormalizePlot \[Rule] False\), 
        ",", \(NumberOfPoints \[Rule] 2048\), 
        ",", \(NumberOfRays \[Rule] 128\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(LineOfRays[45, NumberOfRays \[Rule] 11]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 58.62342361805182`\), ",", 
        RowBox[{"OpticalLengthFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-22.681712035282395`\), 
                  22.681712035282395`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-22.681712035282395`\), 
                  22.681712035282395`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {58.62342361805182`, 
            58.65060962220028`}\), ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PaddingFactor \[Rule] Automatic\), 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.6400873804286797`\), 
                  0.6407130767927351`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] True\), 
        ",", \(PlotPoints \[Rule] 64\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.6400873804286797`\), 
                  0.6407130767927351`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{50.00000000000003`, 0, 
              0}, {53.41699507001243`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 3.4169950700124048`\), 
        ",", \(RayBoundary \[Rule] {\(-22.681712035282395`\), 
            22.681712035282395`}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {PointSpreadFunction, 
            OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] True\), 
        ",", \(ShowPerfectCase \[Rule] False\), 
        ",", \(SignalPlotCutoff \[Rule] 0.01`\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 2190\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.012646791897776873`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{0.033531699915919685`, 
              98.25958992578354`}, {\(-0.010006608313591682`\), 
              0.49966958432041564`}}\), 
        ",", \(TransverseMagnification \[Rule] 0.033531699915919685`\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-24.045541711140054`\), 
                  23.986319069457963`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[66]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.6 OpticalTransferFunction", "Subsection",
  CellTags->{"AOG0.", "5.6", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{

Cell["?OpticalTransferFunction", "Input",
  CellLabel->"In[63]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[BoxData[
    \("OpticalTransferFunction[system, options] calculates the modulation and \
phase transfer functions of the optical system for a given object source \
input. \n\nOpticalTransferFunction works together with either \
GeometricPointSpreadFunction, FindIntensity, and PointSpreadFunction. \
OpticalTransferFunction first calls either GeometricPointSpreadFunction or \
PointSpreadFunction to find the point spread function of the imaging system. \
Finally, OpticalTransferFunction calculates a modulation and phase transfer \
function by using the Fourier transform of the point spread function. As \
input, OpticalTransferFunction takes either an optical system or the returned \
output from either GeometricPointSpreadFunction, FindIntensity, or \
PointSpreadFunction. The optical system must contain a light source followed \
by the imaging optics with the approximate focal surface as its last element. \
For FindImagePoint->True, the last system element need not be the exact focal \
surface, since the exact focal surface position is automatically determined. \
When the default FindImagePoint->False is given, the last system element is \
assumed to be the exact focal surface. In addition, the light source need \
only contain a small number of rays (since the actual number of rays is \
internally specified). When FindPupils->False is used, the optical surface \
preceding the image surface is taken as the field stop. The user can also \
give as input a specific focal point or exit pupil position with the \
FocalPoint and ExitPupilPosition options. \n\nNote: OpticalTransferFunction \
works equally well for both point sources and planar sources, as long as the \
described imaging system contains a focus. If a one-dimensional light source \
is used (ie. WedgeOfRays or LineOfRays), then a one-dimensional modulation \
transfer function is calculated. If a two-dimensional light source is used \
(ie. PointOfRays or GridOfRays), then the optical transfer function \
calculations are carried out in two-dimensions. Warning: in general, most \
one-dimensional and two-dimensional results are not fully equivalent to each \
other. \n\nOpticalTransferFunction is also a label used with the \
RenderedParameters option. See also: IntensityTransform, FindLensParameters, \
PupilFunction, PointSpreadFunction, ModulationTransferFunction, \
PhaseTransferFunction, OTF, MTF, FindIntensity, and \
GeometricPointSpreadFunction."\)], "Print",
  CellTags->{"Info3313758703-7146727", "AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?MTF", "Input",
  CellLabel->"In[64]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[BoxData[
    \("MTF[system, options] is an alias to ModulationTransferFunction[system, \
options]."\)], "Print",
  CellTags->{"Info3313758707-6863980", "AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["MTF[sys, NumberOfPoints->2048, NumberOfRays->128]", "Input",
  CellLabel->"In[68]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0209945 -1269.24 21.651 [
[.08011 -0.0125 -9 -9 ]
[.08011 -0.0125 9 0 ]
[.29006 -0.0125 -9 -9 ]
[.29006 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70994 -0.0125 -6 -9 ]
[.70994 -0.0125 6 0 ]
[.91989 -0.0125 -6 -9 ]
[.91989 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04885 -36 -4.5 ]
[-0.0125 .04885 0 4.5 ]
[-0.0125 .1571 -30 -4.5 ]
[-0.0125 .1571 0 4.5 ]
[-0.0125 .26536 -36 -4.5 ]
[-0.0125 .26536 0 4.5 ]
[-0.0125 .37361 -30 -4.5 ]
[-0.0125 .37361 0 4.5 ]
[-0.0125 .48187 -36 -4.5 ]
[-0.0125 .48187 0 4.5 ]
[-0.0125 .59012 -30 -4.5 ]
[-0.0125 .59012 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08011 0 m
.08011 .00625 L
s
[(-20)] .08011 -0.0125 0 1 Mshowa
.29006 0 m
.29006 .00625 L
s
[(-10)] .29006 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70994 0 m
.70994 .00625 L
s
[(10)] .70994 -0.0125 0 1 Mshowa
.91989 0 m
.91989 .00625 L
s
[(20)] .91989 -0.0125 0 1 Mshowa
.125 Mabswid
.1221 0 m
.1221 .00375 L
s
.16409 0 m
.16409 .00375 L
s
.20608 0 m
.20608 .00375 L
s
.24807 0 m
.24807 .00375 L
s
.33204 0 m
.33204 .00375 L
s
.37403 0 m
.37403 .00375 L
s
.41602 0 m
.41602 .00375 L
s
.45801 0 m
.45801 .00375 L
s
.54199 0 m
.54199 .00375 L
s
.58398 0 m
.58398 .00375 L
s
.62597 0 m
.62597 .00375 L
s
.66796 0 m
.66796 .00375 L
s
.75193 0 m
.75193 .00375 L
s
.79392 0 m
.79392 .00375 L
s
.83591 0 m
.83591 .00375 L
s
.8779 0 m
.8779 .00375 L
s
.03812 0 m
.03812 .00375 L
s
.96188 0 m
.96188 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04885 m
.00625 .04885 L
s
[(58.625)] -0.0125 .04885 1 0 Mshowa
0 .1571 m
.00625 .1571 L
s
[(58.63)] -0.0125 .1571 1 0 Mshowa
0 .26536 m
.00625 .26536 L
s
[(58.635)] -0.0125 .26536 1 0 Mshowa
0 .37361 m
.00625 .37361 L
s
[(58.64)] -0.0125 .37361 1 0 Mshowa
0 .48187 m
.00625 .48187 L
s
[(58.645)] -0.0125 .48187 1 0 Mshowa
0 .59012 m
.00625 .59012 L
s
[(58.65)] -0.0125 .59012 1 0 Mshowa
.125 Mabswid
0 .0705 m
.00375 .0705 L
s
0 .09215 m
.00375 .09215 L
s
0 .1138 m
.00375 .1138 L
s
0 .13545 m
.00375 .13545 L
s
0 .17875 m
.00375 .17875 L
s
0 .2004 m
.00375 .2004 L
s
0 .22205 m
.00375 .22205 L
s
0 .2437 m
.00375 .2437 L
s
0 .28701 m
.00375 .28701 L
s
0 .30866 m
.00375 .30866 L
s
0 .33031 m
.00375 .33031 L
s
0 .35196 m
.00375 .35196 L
s
0 .39526 m
.00375 .39526 L
s
0 .41691 m
.00375 .41691 L
s
0 .43856 m
.00375 .43856 L
s
0 .46021 m
.00375 .46021 L
s
0 .50352 m
.00375 .50352 L
s
0 .52517 m
.00375 .52517 L
s
0 .54682 m
.00375 .54682 L
s
0 .56847 m
.00375 .56847 L
s
0 .02719 m
.00375 .02719 L
s
0 .00554 m
.00375 .00554 L
s
0 .61177 m
.00375 .61177 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08011 .61178 m
.08011 .61803 L
s
.29006 .61178 m
.29006 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.70994 .61178 m
.70994 .61803 L
s
.91989 .61178 m
.91989 .61803 L
s
.125 Mabswid
.1221 .61428 m
.1221 .61803 L
s
.16409 .61428 m
.16409 .61803 L
s
.20608 .61428 m
.20608 .61803 L
s
.24807 .61428 m
.24807 .61803 L
s
.33204 .61428 m
.33204 .61803 L
s
.37403 .61428 m
.37403 .61803 L
s
.41602 .61428 m
.41602 .61803 L
s
.45801 .61428 m
.45801 .61803 L
s
.54199 .61428 m
.54199 .61803 L
s
.58398 .61428 m
.58398 .61803 L
s
.62597 .61428 m
.62597 .61803 L
s
.66796 .61428 m
.66796 .61803 L
s
.75193 .61428 m
.75193 .61803 L
s
.79392 .61428 m
.79392 .61803 L
s
.83591 .61428 m
.83591 .61803 L
s
.8779 .61428 m
.8779 .61803 L
s
.03812 .61428 m
.03812 .61803 L
s
.96188 .61428 m
.96188 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04885 m
1 .04885 L
s
.99375 .1571 m
1 .1571 L
s
.99375 .26536 m
1 .26536 L
s
.99375 .37361 m
1 .37361 L
s
.99375 .48187 m
1 .48187 L
s
.99375 .59012 m
1 .59012 L
s
.125 Mabswid
.99625 .0705 m
1 .0705 L
s
.99625 .09215 m
1 .09215 L
s
.99625 .1138 m
1 .1138 L
s
.99625 .13545 m
1 .13545 L
s
.99625 .17875 m
1 .17875 L
s
.99625 .2004 m
1 .2004 L
s
.99625 .22205 m
1 .22205 L
s
.99625 .2437 m
1 .2437 L
s
.99625 .28701 m
1 .28701 L
s
.99625 .30866 m
1 .30866 L
s
.99625 .33031 m
1 .33031 L
s
.99625 .35196 m
1 .35196 L
s
.99625 .39526 m
1 .39526 L
s
.99625 .41691 m
1 .41691 L
s
.99625 .43856 m
1 .43856 L
s
.99625 .46021 m
1 .46021 L
s
.99625 .50352 m
1 .50352 L
s
.99625 .52517 m
1 .52517 L
s
.99625 .54682 m
1 .54682 L
s
.99625 .56847 m
1 .56847 L
s
.99625 .02719 m
1 .02719 L
s
.99625 .00554 m
1 .00554 L
s
.99625 .61177 m
1 .61177 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .30239 Mdot
.03144 .34844 Mdot
.03907 .38986 Mdot
.04669 .42689 Mdot
.05431 .45975 Mdot
.06191 .48865 Mdot
.06951 .51382 Mdot
.0771 .53545 Mdot
.08469 .55374 Mdot
.09227 .56887 Mdot
.09984 .58102 Mdot
.10741 .59038 Mdot
.11497 .59711 Mdot
.12253 .60137 Mdot
.13008 .60332 Mdot
.13762 .60311 Mdot
.14516 .6009 Mdot
.1527 .59681 Mdot
.16023 .59099 Mdot
.16776 .58358 Mdot
.17528 .57468 Mdot
.1828 .56444 Mdot
.19031 .55297 Mdot
.19782 .54038 Mdot
.20533 .52678 Mdot
.21283 .51229 Mdot
.22033 .49699 Mdot
.22783 .48099 Mdot
.23532 .46439 Mdot
.24281 .44727 Mdot
.2503 .42973 Mdot
.25778 .41185 Mdot
.26526 .39371 Mdot
.27274 .37538 Mdot
.28021 .35695 Mdot
.28769 .33849 Mdot
.29516 .32006 Mdot
.30262 .30173 Mdot
.31009 .28356 Mdot
.31755 .26562 Mdot
.32502 .24796 Mdot
.33248 .23063 Mdot
.33993 .2137 Mdot
.34739 .1972 Mdot
.35484 .18119 Mdot
.3623 .16571 Mdot
.36975 .15081 Mdot
.3772 .13651 Mdot
.38465 .12287 Mdot
.3921 .10991 Mdot
.39954 .09768 Mdot
.40699 .08618 Mdot
.41443 .07547 Mdot
.42188 .06556 Mdot
.42932 .05647 Mdot
.43676 .04824 Mdot
.4442 .04087 Mdot
.45164 .03438 Mdot
.45908 .02879 Mdot
.46652 .02412 Mdot
.47396 .02037 Mdot
.4814 .01754 Mdot
.48884 .01566 Mdot
.49628 .01472 Mdot
.50372 .01472 Mdot
.51116 .01566 Mdot
.5186 .01754 Mdot
.52604 .02037 Mdot
.53348 .02412 Mdot
.54092 .02879 Mdot
.54836 .03438 Mdot
.5558 .04087 Mdot
.56324 .04824 Mdot
.57068 .05647 Mdot
.57812 .06556 Mdot
.58557 .07547 Mdot
.59301 .08618 Mdot
.60046 .09768 Mdot
.6079 .10991 Mdot
.61535 .12287 Mdot
.6228 .13651 Mdot
.63025 .15081 Mdot
.6377 .16571 Mdot
.64516 .18119 Mdot
.65261 .1972 Mdot
.66007 .2137 Mdot
.66752 .23063 Mdot
.67498 .24796 Mdot
.68245 .26562 Mdot
.68991 .28356 Mdot
.69738 .30173 Mdot
.70484 .32006 Mdot
.71231 .33849 Mdot
.71979 .35695 Mdot
.72726 .37538 Mdot
.73474 .39371 Mdot
.74222 .41185 Mdot
.7497 .42973 Mdot
.75719 .44727 Mdot
.76468 .46439 Mdot
.77217 .48099 Mdot
.77967 .49699 Mdot
.78717 .51229 Mdot
.79467 .52678 Mdot
.80218 .54038 Mdot
.80969 .55297 Mdot
.8172 .56444 Mdot
.82472 .57468 Mdot
.83224 .58358 Mdot
.83977 .59099 Mdot
.8473 .59681 Mdot
.85484 .6009 Mdot
.86238 .60311 Mdot
.86992 .60332 Mdot
.87747 .60137 Mdot
.88503 .59711 Mdot
.89259 .59038 Mdot
.90016 .58102 Mdot
.90773 .56887 Mdot
.91531 .55374 Mdot
.9229 .53545 Mdot
.93049 .51382 Mdot
.93809 .48865 Mdot
.94569 .45975 Mdot
.95331 .42689 Mdot
.96093 .38986 Mdot
.96856 .34844 Mdot
.97619 .30239 Mdot
.5 Mabswid
.02381 .30239 m
.03853 .3869 L
.05458 .46079 L
.06965 .51423 L
.08415 .55245 L
.09161 .56755 L
.09958 .58061 L
.1077 .59064 L
.11142 .59395 L
.11346 .59577 L
.11446 .59665 L
.11537 .59733 L
.11712 .59832 L
.11899 .59938 L
.1209 .60045 L
.12191 .60102 L
.12217 .60117 L
.12246 .60133 L
.12273 .60142 L
.12298 .60149 L
.12396 .60174 L
.12485 .60197 L
.12658 .60242 L
.12837 .60288 L
.12916 .60308 L
.12957 .60319 L
.13001 .6033 L
.13048 .60331 L
.13093 .6033 L
.1318 .60327 L
.13372 .60322 L
.13538 .60317 L
.13626 .60315 L
.13673 .60314 L
.13718 .60312 L
.13766 .6031 L
.13791 .60303 L
.13818 .60295 L
.13911 .60268 L
.14092 .60214 L
.14307 .60151 L
.14401 .60123 L
.14451 .60109 L
.14479 .60101 L
.14505 .60093 L
.14529 .60083 L
.14556 .60068 L
.14603 .60043 L
.14694 .59993 L
.14895 .59884 L
Mistroke
.15318 .59644 L
.16086 .59038 L
.17636 .57321 L
.19129 .55134 L
.20715 .52327 L
.22243 .49251 L
.23714 .46024 L
.25278 .4238 L
.26784 .38738 L
.28233 .35173 L
.29775 .3137 L
.31259 .27756 L
.32836 .24018 L
.34356 .20567 L
.35819 .17425 L
.37374 .14315 L
.38872 .11579 L
.40312 .09215 L
.41846 .07011 L
.43321 .05216 L
.44891 .03677 L
.45674 .03055 L
.46402 .02569 L
.4715 .02161 L
.47856 .01862 L
.48231 .01731 L
.48637 .01629 L
.48816 .01583 L
.4886 .01572 L
.48906 .01563 L
.48933 .0156 L
.48958 .01557 L
.49006 .0155 L
.49345 .01507 L
.49528 .01484 L
.49572 .01479 L
.4962 .01472 L
.49648 .01472 L
.49673 .01472 L
.49722 .01472 L
.50071 .01472 L
.50255 .01472 L
.50306 .01472 L
.50333 .01472 L
.50359 .01472 L
.50384 .01473 L
.5041 .01476 L
.50456 .01482 L
.50862 .01534 L
.51035 .01556 L
Mistroke
.51085 .01562 L
.51133 .0157 L
.51175 .01581 L
.51222 .01593 L
.51427 .01645 L
.51618 .01693 L
.5242 .01967 L
.5317 .02322 L
.53969 .02802 L
.55554 .04064 L
.57081 .05663 L
.5855 .07538 L
.60113 .09878 L
.61618 .12439 L
.63065 .15161 L
.64606 .18313 L
.66089 .21557 L
.67665 .25191 L
.69184 .28826 L
.70645 .32402 L
.72199 .36239 L
.73696 .39909 L
.75135 .43358 L
.76667 .4688 L
.78142 .50056 L
.7971 .53118 L
.8122 .55681 L
.82672 .57705 L
.83483 .58612 L
.84218 .59286 L
.84586 .5957 L
.84984 .59819 L
.85357 .60021 L
.85707 .60155 L
.86067 .60261 L
.86166 .6029 L
.86214 .60304 L
.86259 .60312 L
.86284 .60313 L
.8631 .60313 L
.86366 .60315 L
.86464 .60317 L
.86681 .60323 L
.86788 .60326 L
.86885 .60329 L
.86931 .6033 L
.86974 .60331 L
.87019 .60325 L
.87068 .60312 L
.87266 .60261 L
Mistroke
.87458 .60212 L
.87559 .60186 L
.87666 .60158 L
.87711 .60146 L
.87759 .6013 L
.87787 .60115 L
.87812 .601 L
.87862 .60072 L
.88044 .5997 L
.88751 .5949 L
.89126 .59157 L
.89474 .58773 L
.90263 .57705 L
.91045 .56345 L
.91753 .54838 L
.93279 .50619 L
.94747 .45206 L
.96309 .37811 L
.97619 .30239 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00>?ooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00004_ooool003Wooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`00017ooooo000booooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00017ooooo000kooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool03oooool003Sooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Aoooo
o`00>?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Aooooo`00>Oooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Booooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`009ooooooho`00007ooooo000Wooooo`;o00001oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Gooooo0_l00001ooooo`009oooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo07Wooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1eooooo`So0000Mooo
ool1o`00007ooooo000Wooooo`03o`000?oooooooooo077ooooo3ol0001dooooo`7o00000Oooool0
02Oooooo00?o0000ooooooooool0L?ooool5o`0000?ooooo00Co0000oooooooooooooooo1_l0001b
ooooo`7o00000Oooool002Oooooo0_l0001_ooooo`Co00001_ooool00ol0003oooooooooo`05oooo
o`Co0000Koooool2o`00007ooooo000Wooooo`03o`000?oooooooooo06kooooo0_l00008ooooo`03
o`000?oooooooooo00Oooooo0_l0001`ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0
K?ooool2o`0000[ooooo00?o0000ooooooooool02Oooool2o`0006kooooo0Ol00001ooooo`0000Co
ooooo`000?l0003o00000oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000;ooooo
1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`1Zooooo`Co00002_ooool00ol0003ooooo
ooooo`09ooooo`Co0000K?ooool1o`00007ooooo00001ol0003ooooooooooooooooo0000ooooool0
00000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Zooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`;o0000K?ooool1o`00007ooooo0004
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo06Sooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo0_l0001[ooooo`7o00000Ooo
ool000Cooooo00?o0000ooooooooool00ol00008ooooo`Co00001Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo0_l0001Yooooo`;o00003_ooool00ol0003oooooooooo`0<
ooooo`;o0000J_ooool2o`00007ooooo0004o`0000;ooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Gooooo
00?o0000ooooooooool0I_ooool3o`0000oooooo00?o0000ooooooooool03_ooool2o`0006Wooooo
0Ol00001ooooo`0000?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0
003oooooooooo`1Vooooo`;o00004?ooool00ol0003oooooooooo`0>ooooo`;o0000JOooool1o`00
007ooooo0005o`0000;ooooo0ol0000:ooooo`;o00000oooool3o`0000;ooooo1Ol00004ooooo`03
o`000?oooooooooo06Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo06Kooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1Tooooo`;o0000
4_ooool00ol0003oooooooooo`0@ooooo`;o0000Ioooool1o`00007ooooo000Wooooo`;o0000IOoo
ool2o`0001;ooooo00?o0000ooooooooool04?ooool3o`0006Gooooo0_l00001ooooo`009oooool0
0ol0003oooooooooo`1Sooooo`;o00004oooool00ol0003oooooooooo`0Booooo`;o0000IOooool1
o`00007ooooo000Wooooo`03o`000?oooooooooo06?ooooo0_l0000Cooooo`03o`000?oooooooooo
01;ooooo0_l0001Uooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0H_ooool1o`00007o
oooo000Wooooo`03o`000?oooooooooo067ooooo0_l0000Eooooo`03o`000?oooooooooo01Cooooo
0_l0001Sooooo`7o00000Oooool002Oooooo0_l0001Rooooo`;o00005Oooool00ol0003ooooooooo
o`0Dooooo`;o0000H_ooool2o`00007ooooo000Wooooo`03o`000?oooooooooo05oooooo0ol0000F
ooooo`03o`000?oooooooooo01Gooooo0ol0001Qooooo`7o00000Oooool002Oooooo00?o0000oooo
ooooool0Goooool2o`0001Oooooo00?o0000ooooooooool05_ooool2o`00067ooooo0Ol00001oooo
o`009oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`1Pooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
Goooool1o`00007ooooo000Wooooo`03o`000?oooooooooo05gooooo0_l0000Iooooo`03o`000?oo
oooooooo01Oooooo0_l0001Pooooo`7o00000Oooool002Oooooo0_l0001Nooooo`;o00006Oooool0
0ol0003oooooooooo`0Gooooo`;o0000Goooool2o`00007ooooo000Wooooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
05gooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1Kooooo`;o00006oooool00ol0003o
ooooooooo`0Iooooo`;o0000G_ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo05_ooooo
0_l0000Kooooo`03o`000?oooooooooo01Wooooo0_l0001Nooooo`7o00000Oooool002Oooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0Foooool1o`00007ooooo000Wooooo`;o0000F_ooool2o`0001gooooo00?o0000
ooooooooool06oooool2o`0005_ooooo0_l00001ooooo`009oooool00ol0003oooooooooo`1Ioooo
o`;o00007Oooool00ol0003oooooooooo`0Kooooo`;o0000G?ooool1o`00007ooooo000Wooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo05Wooooo0Ol00001ooooo`001oooool3o`0000?ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Iooooo`7o0000
0Oooool000Kooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000oooooooo
ool01Oooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05Sooooo0_l0000Nooooo`03o`000?oooooooooo01gooooo0_l0001J
ooooo`7o00000Oooool000[ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`;o0000FOooool2
o`0001kooooo00?o0000ooooooooool07Oooool2o`0005Wooooo0_l00001ooooo`002_ooool00ol0
003oooooooooo`03o`0000Sooooo1?l00004ooooo`;o00001Oooool00ol0003oooooooooo`1Goooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Goooo
o`7o00000Oooool000Kooooo1?l00002ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E_ooool2o`00
023ooooo00?o0000ooooooooool07oooool2o`0005Sooooo0Ol00001ooooo`001_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Fooooo`;o00008?ooool0
0ol0003oooooooooo`0Oooooo`;o0000F?ooool1o`00007ooooo0006ooooo`Go00000_ooool3o`00
00[ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Fooooo`7o00000Oooool002Oo
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0EOooool1o`00007ooooo000Wooooo`;o0000EOooool2o`0002;ooooo
00?o0000ooooooooool08Oooool2o`0005Gooooo0_l00001ooooo`009oooool00ol0003ooooooooo
o`1Dooooo`;o00008_ooool00ol0003oooooooooo`0Qooooo`;o0000E_ooool1o`00007ooooo000W
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo05Cooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Coooo
o`7o00000Oooool002Oooooo00?o0000ooooooooool0D_ooool2o`0002Cooooo00?o0000oooooooo
ool08oooool2o`0005Cooooo0Ol00001ooooo`009oooool2o`0005?ooooo0_l0000Tooooo`03o`00
0?oooooooooo02?ooooo0_l0001Cooooo`;o00000Oooool002Oooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D_oo
ool1o`00007ooooo000Wooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;ooooo0Ol00001ooooo`009oooool00ol0
003oooooooooo`1@ooooo`;o00009_ooool00ol0003oooooooooo`0Tooooo`;o0000Doooool1o`00
007ooooo000Wooooo`03o`000?oooooooooo053ooooo0_l0000Vooooo`03o`000?oooooooooo02Co
oooo0_l0001Cooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DOooool1o`00007ooooo
000Wooooo`;o0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0Coooool2o`00007ooooo000Wooooo`03o`000?oooooooooo04kooooo0ol0000W
ooooo`03o`000?oooooooooo02Kooooo0_l0001Aooooo`7o00000Oooool002Oooooo00?o0000oooo
ooooool0C_ooool2o`0002Sooooo00?o0000ooooooooool09_ooool2o`00057ooooo0Ol00001oooo
o`009oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`1?ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
Coooool1o`00007ooooo000Wooooo`;o0000Coooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0COooool2o`00007ooooo000Wooooo`03o`000?oooooo
oooo04gooooo0_l0000Yooooo`03o`000?oooooooooo02Sooooo0_l0001?ooooo`7o00000Oooool0
02Oooooo00?o0000ooooooooool0COooool2o`0002Wooooo00?o0000ooooooooool0:?ooool2o`00
04oooooo0Ol00001ooooo`0000Coooooo`000?l0003o00000oooool3o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000?ooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1=oooo
o`7o00000Oooool00007o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04cooooo0Ol00001ooooo`001?oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0004cooooo
0_l0000[ooooo`03o`000?oooooooooo02[ooooo0_l0001<ooooo`;o00000Oooool000Cooooo00?o
0000ooooooooool00ol00008ooooo`Co00001?ooool2o`0000Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1;ooooo`;o0000:oooool00ol0003oooooooooo`0Zooooo`;o0000COoo
ool1o`00007ooooo0004o`0000;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool00_ooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`1;ooooo`7o00000Oooool000Go00000_ooool3o`0000[ooooo0_l00003ooooo`?o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0BOooool2o`0002gooooo00?o0000ooooooooool0
;?ooool2o`0004_ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`19ooooo`;o0000;Ooo
ool00ol0003oooooooooo`0/ooooo`;o0000Boooool1o`00007ooooo000Wooooo`;o0000B_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0B?ooool2
o`00007ooooo000Wooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo04Wooooo0Ol00001ooooo`009oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`18ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool00_ooool2o`0004?ooooo
0_l0000_ooooo`03o`000?oooooooooo02kooooo0_l00012ooooo`;o00001Oooool1o`00007ooooo
000Wooooo`03o`000?oooooooooo00;ooooo0_l00013ooooo`;o0000;oooool00ol0003ooooooooo
o`0^ooooo`;o0000@_ooool2o`0000Gooooo0Ol00001ooooo`009oooool2o`0000Cooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`;o00000Oooool002Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`009oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo0_l0000aooooo`03
o`000?oooooooooo02oooooo0_l00011ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00
9oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo0_l0000aooooo`03o`00
0?oooooooooo02oooooo0_l00011ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`009ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01?oo
ool1o`00007ooooo000Wooooo`;o00001Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo00?ooooo0_l00001ooooo`009oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool01?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0??ooool2o`0003?ooooo00?o0000ooooooooool0<Oooool2o`0003oo
oooo00?o0000ooooooooool01?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0??ooool2o`0003?ooooo00?o0000ooooooooool0<Oooool2o`0003kooooo
00?o0000ooooooooool01Oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Cooooo0_l0
000nooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0kooooo`;o00001_ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Cooooo0_l0000m
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0k
ooooo`;o00001_ooool1o`00007ooooo000Wooooo`;o00001_ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00Cooooo0_l00001ooooo`009oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03Wooooo0ol0000dooooo`03o`000?oooooooooo03?ooooo0_l0000looooo`03
o`000?oooooooooo00Gooooo0Ol00001ooooo`001oooool3o`0000?ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00004ooooo`?o00001?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03Wooooo0_l0000eooooo`03o`000?oooooooooo03?ooooo0_l0000looooo`03o`00
0?oooooooooo00Gooooo0Ol00001ooooo`001_ooool01ol0003ooooooooooooooooo0000ooooool0
00000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`05ooooo`7o00000Oooool000[ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`05ooooo`06o`000?ooooooooooooooool0003ooooo1Ol00004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool0
00[ooooo00?o0000ooooooooool00ol00008ooooo`Co00000_ooool01?l0003oooooooooool00005
ooooo`;o00001oooool00ol0003oooooooooo`0gooooo`;o0000=_ooool00ol0003oooooooooo`0e
ooooo`;o0000>Oooool00ol0003oooooooooo`05ooooo`;o00000Oooool000Kooooo1?l00002oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`;o0000=_ooool0
0ol0003oooooooooo`0eooooo`;o0000>Oooool00ol0003oooooooooo`06ooooo`7o00000Oooool0
00Kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`001_ooool5o`0000;ooooo0ol0000:oooo
o`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`06ooooo`7o00000Oooool002Oooooo00?o0000oooooooo
ool01_ooool2o`0003Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Gooooo0_l00008ooooo`7o00000Oooool002Oooooo0_l00007ooooo`;o0000
=_ooool2o`0003Sooooo00?o0000ooooooooool0=oooool2o`0003Kooooo0_l00007ooooo`;o0000
0Oooool002Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0dooooo`;o0000>?oo
ool00ol0003oooooooooo`0gooooo`;o0000=_ooool00ol0003oooooooooo`07ooooo`7o00000Ooo
ool002Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo00Oooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool01oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0<_ooool2o`0003[ooooo00?o0000ooooooooool0>Oooool2o`0003?o
oooo00?o0000ooooooooool02?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<_ooool2o`0003[ooooo00?o0000ooooooooool0>Oooool2o`0003?ooooo
00?o0000ooooooooool02?ooool1o`00007ooooo000Wooooo`;o00002Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo0_l00001ooooo`009oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02?ooool1o`00007ooooo000Woooo
o`03o`000?oooooooooo00Sooooo0_l0000aooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0_ooooo`;o00002_ooool1o`00007ooooo000Wooooo`03
o`000?oooooooooo00Sooooo0_l0000`ooooo`;o0000??ooool00ol0003oooooooooo`0kooooo`;o
0000<?ooool2o`0000[ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02oooooo0_l0000looooo`03o`000?oooooooooo03_ooooo0_l0000`ooooo`03o`00
0?oooooooooo00Wooooo0Ol00001ooooo`009oooool2o`0000[ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`08ooooo`;o00000Oooool002Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`009oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02cooooo0_l0000nooooo`03o`000?oooooooooo
03cooooo0_l0000^ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`009oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02cooooo0_l0000nooooo`03o`000?oooooooooo03co
oooo0_l0000^ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`009oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_ooool1o`00007ooooo
000Wooooo`;o00002oooool2o`0002cooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo02[ooooo0_l0000;ooooo`;o00000Oooool002Oooooo00?o0000
ooooooooool02_ooool2o`0002[ooooo0ol0000oooooo`03o`000?oooooooooo03kooooo0_l0000[
ooooo`;o00003?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:Oooool2o`00043ooooo00?o0000ooooooooool0?_ooool2o`0002_ooooo00?o0000oooo
ooooool02oooool1o`00007ooooo00001?oooooo0000o`000?l00003ooooo`?o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001?ooool3o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`7o00000Oooool00007
o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
3?ooool1o`00007ooooo0004ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Ooo
ool01_l0003ooooooooooooooooo0000ooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool09oooool2o`00047ooooo00?o0000oooooooo
ool0@?ooool2o`0002Sooooo00?o0000ooooooooool03?ooool1o`00007ooooo0004ooooo`03o`00
0?oooooooooo00?o00002?ooool4o`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooooooo`02ooooo`;o00003?ooool00ol0003oooooooooo`0Wooooo`;o0000@Oooool00ol0003o
ooooooooo`10ooooo`;o0000:?ooool00ol0003oooooooooo`0;ooooo`;o00000Oooool000Co0000
0_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`000002ooooo`Co00001Oooool00ol0003oooooooooo`0<ooooo`;o00009oooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool09Oooool2o`0000ko
oooo0Ol00001ooooo`0000?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool01?ooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0<ooooo`;o00009_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool09?ooool2o`0000kooooo0Ol00001ooooo`001Ol00002ooooo`?o0000
2_ooool2o`0000Gooooo00?o0000ooooooooool01Ol00004ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool09?ooool2o`0004?ooooo00?o0000ooooooooool0@_ooool2o`0002Gooooo
00?o0000ooooooooool03Oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool08oooool2o`0004?ooooo00?o0000ooooooooool0@_ooool2o`0002Gooooo00?o
0000ooooooooool03Oooool1o`00007ooooo000Wooooo`;o00003_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00gooooo0_l00001ooooo`009oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool1o`00007ooooo000Wooooo`03
o`000?oooooooooo00gooooo0_l0000Rooooo`;o0000AOooool00ol0003oooooooooo`14ooooo`;o
00008Oooool2o`00013ooooo0Ol00001ooooo`009oooool00ol0003oooooooooo`0=ooooo`;o0000
8_ooool2o`0004Gooooo00?o0000ooooooooool0A?ooool2o`00027ooooo0_l0000@ooooo`7o0000
0Oooool002Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00oooooo0Ol00001ooooo`009oooool2o`00013ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0>ooooo`;o00000Oooool002Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Mooooo`;o0000Aoooool00ol0003oooooooooo`16ooooo`;o00007oooool00ol0
003oooooooooo`0?ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Looooo`;o0000Aoooool00ol0003oooooooooo`16ooooo`;o00007_ooool00ol0003o
ooooooooo`0@ooooo`7o00000Oooool002Oooooo00?o0000ooooooooool03oooool2o`0001kooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01_ooooo
0_l0000Booooo`7o00000Oooool002Oooooo00?o0000ooooooooool03oooool2o`0001cooooo0_l0
0019ooooo`03o`000?oooooooooo04Oooooo0_l0000Looooo`;o00004_ooool1o`00007ooooo000W
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06Oooool2o`0004Wooooo00?o0000
ooooooooool0Aoooool3o`0001_ooooo00?o0000ooooooooool04Oooool1o`00007ooooo000Woooo
o`;o00004_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo013ooooo0_l00001oooo
o`009oooool00ol0003oooooooooo`0Aooooo`;o00006?ooool2o`0004_ooooo00?o0000oooooooo
ool0BOooool2o`0001Sooooo0ol0000Cooooo`7o00000Oooool002Oooooo00?o0000ooooooooool0
4Oooool2o`0001Sooooo0_l0001;ooooo`03o`000?oooooooooo04Wooooo0ol0000Gooooo`;o0000
5?ooool1o`00007ooooo000Wooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Booooo`7o00000Oooool002Oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Cooooo`;o0000COooool00ol0003oooooooooo`1;ooooo`;o00005_ooool0
0ol0003oooooooooo`0Cooooo`7o00000Oooool002Oooooo0_l0000Dooooo`;o00005?ooool2o`00
04gooooo00?o0000ooooooooool0Boooool3o`0001Cooooo0_l0000Dooooo`;o00000Oooool002Oo
oooo00?o0000ooooooooool04oooool2o`0001?ooooo0_l0001>ooooo`03o`000?oooooooooo04go
oooo0_l0000Cooooo`;o00005Oooool1o`00007ooooo000Wooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool04?ooool2o`0004kooooo00?o0000ooooooooool0COooool2o`0001;ooooo
00?o0000ooooooooool05Oooool1o`00007ooooo0007ooooo`?o00000oooool3o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo01Gooooo0_l0
000@ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`0?ooooo`;o00005oooool1o`00007ooooo0006ooooo`07o`000?ooooooooooooooool0003ooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`;o00003oooool2o`00
053ooooo00?o0000ooooooooool0Coooool2o`0000oooooo0_l0000Gooooo`7o00000Oooool000[o
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo0_l0000;oooo
o`Co0000D?ooool00ol0003oooooooooo`1?ooooo`Co00002oooool2o`0001Wooooo0Ol00001oooo
o`002_ooool00ol0003oooooooooo`03o`0000Sooooo1?l00006ooooo`03o`000?oooooooooo00;o
oooo0_l0000Hooooo`;o00002oooool2o`0005;ooooo00?o0000ooooooooool0DOooool2o`0000_o
oooo0_l0000Hooooo`;o00000Oooool000Kooooo1?l00002ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`03ooooo`Co00001Oooool00ol0003oooooooooo`0Iooooo`;o
00001oooool2o`0005Cooooo00?o0000ooooooooool0Doooool2o`0000Oooooo0_l0000Kooooo`7o
00000Oooool000Kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wo
oooo2ol0001Dooooo`03o`000?oooooooooo05?ooooo2ol0000Kooooo`7o00000Oooool000Kooooo
1Ol00002ooooo`?o00002_ooool2o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo01[ooooo
2?l0001Fooooo`03o`000?oooooooooo05Gooooo1ol0000Mooooo`7o00000Oooool002Oooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`7o00000Oooool002Oooooo0_l00007
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool2o`00007ooooo000Woooo
ooSo00000Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool003?ooooo0ol0001H
ooooo`?o00005oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00_ooooo000doooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo00[ooooo000^ooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go
00000_ooool3o`0000?ooooo1?l000000ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co
00000oooool2o`0000;ooooo1_l00006ooooo`Go00000_ooool3o`0000;ooooo0ol000001?oooooo
0000o`000?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool00ol0003oooooooooo`03oooo
o`Co000000?oooooo`000?l000000_l00002ooooo`Co00000oooool3o`0000;ooooo1Ol00003oooo
o`;o000000Coooooo`000?oooooooooo0_l00003ooooo`?o00002Oooool4o`000003ooooool0003o
000000?o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool4o`000005ooooool0003o
0000o`000?ooool00_l000001?oooooo0000o`000?l00003ooooo`?o00001Oooool00ol0003ooooo
ooooo`09ooooo`00;Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00000_ooool01_l0003o
ooooooooool0003oooooo`0000_ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooool000000oooool00ol0003oooooo`000008ooooo`03
o`000?oooooooooo00Wooooo000]ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00003
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo0ol00003
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00002ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool5o`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooo
o`?o00000oooool00ol0003oooooooooo`03ooooo`?o00000oooool01_l0003oooooooooool0003o
ooooo`0000Gooooo1Ol00004ooooo`03o`000?oooooooooo00Wooooo000]ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`?o00000_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000Go
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`09ooooo`00;Oooool01_l0003ooooooooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo
0ol00004ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?o
oooo0ol00002ooooo`Co00000oooool9o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`?o00000oooool4o`0000;ooooo0ol00004ooooo`04o`000?oooooooooooooo
o`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`?o00002Oooool3o`0000;ooooo0ol00004
ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00000oooool4o`0000?ooooo0ol00003
ooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`00;Oooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00[ooooo000^ooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00gooooo0ol00009ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool3
o`0001Kooooo00?o0000ooooooooool00_ooool2o`0000gooooo00?o0000ooooooooool01_ooool2
o`00013ooooo0ol0000:ooooo`03o`000?oooooooooo013ooooo0_l00004ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-31.4083, 58.6204, 0.19271, \
0.000186866}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0209945 -1.35423 0.887842 [
[.08011 -0.0125 -9 -9 ]
[.08011 -0.0125 9 0 ]
[.29006 -0.0125 -9 -9 ]
[.29006 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70994 -0.0125 -6 -9 ]
[.70994 -0.0125 6 0 ]
[.91989 -0.0125 -6 -9 ]
[.91989 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06632 -18 -4.5 ]
[-0.0125 .06632 0 4.5 ]
[-0.0125 .1551 -18 -4.5 ]
[-0.0125 .1551 0 4.5 ]
[-0.0125 .24389 -18 -4.5 ]
[-0.0125 .24389 0 4.5 ]
[-0.0125 .33267 -18 -4.5 ]
[-0.0125 .33267 0 4.5 ]
[-0.0125 .42146 -6 -4.5 ]
[-0.0125 .42146 0 4.5 ]
[-0.0125 .51024 -18 -4.5 ]
[-0.0125 .51024 0 4.5 ]
[-0.0125 .59902 -18 -4.5 ]
[-0.0125 .59902 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08011 0 m
.08011 .00625 L
s
[(-20)] .08011 -0.0125 0 1 Mshowa
.29006 0 m
.29006 .00625 L
s
[(-10)] .29006 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70994 0 m
.70994 .00625 L
s
[(10)] .70994 -0.0125 0 1 Mshowa
.91989 0 m
.91989 .00625 L
s
[(20)] .91989 -0.0125 0 1 Mshowa
.125 Mabswid
.1221 0 m
.1221 .00375 L
s
.16409 0 m
.16409 .00375 L
s
.20608 0 m
.20608 .00375 L
s
.24807 0 m
.24807 .00375 L
s
.33204 0 m
.33204 .00375 L
s
.37403 0 m
.37403 .00375 L
s
.41602 0 m
.41602 .00375 L
s
.45801 0 m
.45801 .00375 L
s
.54199 0 m
.54199 .00375 L
s
.58398 0 m
.58398 .00375 L
s
.62597 0 m
.62597 .00375 L
s
.66796 0 m
.66796 .00375 L
s
.75193 0 m
.75193 .00375 L
s
.79392 0 m
.79392 .00375 L
s
.83591 0 m
.83591 .00375 L
s
.8779 0 m
.8779 .00375 L
s
.03812 0 m
.03812 .00375 L
s
.96188 0 m
.96188 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06632 m
.00625 .06632 L
s
[(1.6)] -0.0125 .06632 1 0 Mshowa
0 .1551 m
.00625 .1551 L
s
[(1.7)] -0.0125 .1551 1 0 Mshowa
0 .24389 m
.00625 .24389 L
s
[(1.8)] -0.0125 .24389 1 0 Mshowa
0 .33267 m
.00625 .33267 L
s
[(1.9)] -0.0125 .33267 1 0 Mshowa
0 .42146 m
.00625 .42146 L
s
[(2)] -0.0125 .42146 1 0 Mshowa
0 .51024 m
.00625 .51024 L
s
[(2.1)] -0.0125 .51024 1 0 Mshowa
0 .59902 m
.00625 .59902 L
s
[(2.2)] -0.0125 .59902 1 0 Mshowa
.125 Mabswid
0 .08408 m
.00375 .08408 L
s
0 .10183 m
.00375 .10183 L
s
0 .11959 m
.00375 .11959 L
s
0 .13735 m
.00375 .13735 L
s
0 .17286 m
.00375 .17286 L
s
0 .19062 m
.00375 .19062 L
s
0 .20837 m
.00375 .20837 L
s
0 .22613 m
.00375 .22613 L
s
0 .26164 m
.00375 .26164 L
s
0 .2794 m
.00375 .2794 L
s
0 .29716 m
.00375 .29716 L
s
0 .31491 m
.00375 .31491 L
s
0 .35043 m
.00375 .35043 L
s
0 .36818 m
.00375 .36818 L
s
0 .38594 m
.00375 .38594 L
s
0 .4037 m
.00375 .4037 L
s
0 .43921 m
.00375 .43921 L
s
0 .45697 m
.00375 .45697 L
s
0 .47473 m
.00375 .47473 L
s
0 .49248 m
.00375 .49248 L
s
0 .528 m
.00375 .528 L
s
0 .54575 m
.00375 .54575 L
s
0 .56351 m
.00375 .56351 L
s
0 .58127 m
.00375 .58127 L
s
0 .04856 m
.00375 .04856 L
s
0 .0308 m
.00375 .0308 L
s
0 .01305 m
.00375 .01305 L
s
0 .61678 m
.00375 .61678 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08011 .61178 m
.08011 .61803 L
s
.29006 .61178 m
.29006 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.70994 .61178 m
.70994 .61803 L
s
.91989 .61178 m
.91989 .61803 L
s
.125 Mabswid
.1221 .61428 m
.1221 .61803 L
s
.16409 .61428 m
.16409 .61803 L
s
.20608 .61428 m
.20608 .61803 L
s
.24807 .61428 m
.24807 .61803 L
s
.33204 .61428 m
.33204 .61803 L
s
.37403 .61428 m
.37403 .61803 L
s
.41602 .61428 m
.41602 .61803 L
s
.45801 .61428 m
.45801 .61803 L
s
.54199 .61428 m
.54199 .61803 L
s
.58398 .61428 m
.58398 .61803 L
s
.62597 .61428 m
.62597 .61803 L
s
.66796 .61428 m
.66796 .61803 L
s
.75193 .61428 m
.75193 .61803 L
s
.79392 .61428 m
.79392 .61803 L
s
.83591 .61428 m
.83591 .61803 L
s
.8779 .61428 m
.8779 .61803 L
s
.03812 .61428 m
.03812 .61803 L
s
.96188 .61428 m
.96188 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06632 m
1 .06632 L
s
.99375 .1551 m
1 .1551 L
s
.99375 .24389 m
1 .24389 L
s
.99375 .33267 m
1 .33267 L
s
.99375 .42146 m
1 .42146 L
s
.99375 .51024 m
1 .51024 L
s
.99375 .59902 m
1 .59902 L
s
.125 Mabswid
.99625 .08408 m
1 .08408 L
s
.99625 .10183 m
1 .10183 L
s
.99625 .11959 m
1 .11959 L
s
.99625 .13735 m
1 .13735 L
s
.99625 .17286 m
1 .17286 L
s
.99625 .19062 m
1 .19062 L
s
.99625 .20837 m
1 .20837 L
s
.99625 .22613 m
1 .22613 L
s
.99625 .26164 m
1 .26164 L
s
.99625 .2794 m
1 .2794 L
s
.99625 .29716 m
1 .29716 L
s
.99625 .31491 m
1 .31491 L
s
.99625 .35043 m
1 .35043 L
s
.99625 .36818 m
1 .36818 L
s
.99625 .38594 m
1 .38594 L
s
.99625 .4037 m
1 .4037 L
s
.99625 .43921 m
1 .43921 L
s
.99625 .45697 m
1 .45697 L
s
.99625 .47473 m
1 .47473 L
s
.99625 .49248 m
1 .49248 L
s
.99625 .528 m
1 .528 L
s
.99625 .54575 m
1 .54575 L
s
.99625 .56351 m
1 .56351 L
s
.99625 .58127 m
1 .58127 L
s
.99625 .04856 m
1 .04856 L
s
.99625 .0308 m
1 .0308 L
s
.99625 .01305 m
1 .01305 L
s
.99625 .61678 m
1 .61678 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06632 m
1 .06632 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01666 m
.02558 .18128 L
.02723 .29055 L
.02816 .35218 L
.02862 .38247 L
.02904 .40149 L
.02952 .4162 L
.03005 .43216 L
.03097 .46007 L
.03181 .4855 L
.03228 .49953 L
.03272 .50895 L
.03297 .51145 L
.03324 .51418 L
.03371 .51898 L
.03464 .52837 L
.03562 .53823 L
.03587 .54083 L
.03615 .54365 L
.03641 .54513 L
.03666 .54575 L
.03764 .54827 L
.03853 .55056 L
.03946 .55294 L
.03972 .55363 L
.03998 .55428 L
.04045 .55463 L
.04225 .55582 L
.0432 .55645 L
.04345 .55661 L
.04372 .55679 L
.0442 .55693 L
.04473 .55708 L
.04531 .55724 L
.04633 .55753 L
.05458 .55954 L
.07025 .56311 L
.08535 .56635 L
.09986 .56928 L
.11532 .57223 L
.13019 .5749 L
.146 .57758 L
.16123 .57999 L
.17588 .58216 L
.19147 .58434 L
.20648 .58629 L
.22092 .58803 L
.23628 .58979 L
.25107 .59134 L
.2668 .5929 L
Mistroke
.28194 .59428 L
.29651 .59548 L
.31202 .59668 L
.32694 .59772 L
.34281 .59873 L
.35809 .59959 L
.37279 .60034 L
.38843 .60101 L
.4035 .60158 L
.41798 .60207 L
.4334 .60248 L
.44052 .60265 L
.44824 .6028 L
.45635 .60292 L
.46402 .60303 L
.47157 .60312 L
.47246 .6031 L
.47291 .60309 L
.4734 .60309 L
.47366 .6031 L
.47394 .60311 L
.47443 .60313 L
.47538 .60317 L
.47596 .60319 L
.47651 .60321 L
.47701 .60323 L
.47729 .60322 L
.47755 .60321 L
.47861 .60319 L
.47958 .60317 L
.48002 .60316 L
.48049 .60315 L
.48095 .60316 L
.48136 .60317 L
.48227 .6032 L
.48328 .60324 L
.4837 .60325 L
.48414 .60327 L
.48457 .60328 L
.48496 .60327 L
.48674 .60323 L
.4872 .60322 L
.48769 .6032 L
.48815 .60319 L
.48857 .60321 L
.49057 .60327 L
.49105 .60328 L
.49157 .6033 L
.49183 .60331 L
.49213 .6033 L
Mistroke
.4924 .6033 L
.49265 .60329 L
.49366 .60327 L
.49461 .60324 L
.49508 .60323 L
.49552 .60322 L
.49577 .60322 L
.49604 .60323 L
.4965 .60324 L
.49751 .60327 L
.49857 .6033 L
.49902 .60331 L
.4995 .60332 L
.49978 .60331 L
.50003 .6033 L
.50053 .60329 L
.50146 .60326 L
.50233 .60324 L
.50276 .60323 L
.50317 .60322 L
.50359 .60323 L
.50406 .60324 L
.50505 .60327 L
.50595 .60329 L
.50637 .6033 L
.50676 .60331 L
.50716 .6033 L
.5076 .60329 L
.50939 .60324 L
.50987 .60322 L
.51014 .60321 L
.51039 .60321 L
.51083 .60321 L
.51131 .60322 L
.5124 .60324 L
.5134 .60326 L
.51385 .60327 L
.51434 .60328 L
.5148 .60327 L
.51522 .60326 L
.51623 .60322 L
.51718 .60319 L
.51761 .60318 L
.51805 .60316 L
.51854 .60317 L
.51899 .60318 L
.52062 .60321 L
.52105 .60322 L
.52152 .60323 L
.52196 .60323 L
Mistroke
.52236 .60322 L
.52327 .60318 L
.52427 .60315 L
.52472 .60313 L
.52522 .60312 L
.52568 .60311 L
.52611 .60311 L
.52704 .60313 L
.52806 .60315 L
.52851 .60316 L
.52899 .60316 L
.52944 .60316 L
.52985 .60315 L
.53156 .60308 L
.53205 .60306 L
.53258 .60304 L
.53302 .60303 L
.53352 .60303 L
.53454 .60305 L
.53563 .60306 L
.53617 .60307 L
.53643 .60307 L
.53667 .60308 L
.53713 .60306 L
.53762 .60304 L
.53859 .603 L
.53947 .60297 L
.53992 .60295 L
.54033 .60293 L
.54076 .60293 L
.54124 .60294 L
.54223 .60295 L
.54314 .60296 L
.54355 .60296 L
.54399 .60297 L
.54442 .60296 L
.5448 .60294 L
.54658 .60287 L
.54703 .60285 L
.54752 .60283 L
.54798 .60281 L
.5484 .60281 L
.55039 .60283 L
.55087 .60283 L
.55138 .60284 L
.55168 .60284 L
.55194 .60283 L
.55246 .6028 L
.5534 .60276 L
.55443 .60271 L
Mistroke
.55489 .60269 L
.55539 .60267 L
.55586 .60267 L
.55629 .60267 L
.55723 .60268 L
.55773 .60268 L
.55825 .60268 L
.5587 .60269 L
.55919 .60269 L
.55964 .60266 L
.56006 .60264 L
.56177 .60256 L
.56227 .60254 L
.56274 .60251 L
.56323 .60251 L
.56349 .60251 L
.56377 .60251 L
.56464 .60251 L
.56559 .60251 L
.56587 .60252 L
.56617 .60252 L
.56642 .60252 L
.5667 .60251 L
.56696 .6025 L
.56724 .60248 L
.56775 .60246 L
.56868 .60241 L
.56921 .60238 L
.56971 .60236 L
.57017 .60234 L
.57044 .60233 L
.57068 .60233 L
.57171 .60233 L
.57268 .60233 L
.57357 .60233 L
.57405 .60233 L
.57431 .60231 L
.57455 .6023 L
.57562 .60224 L
.57675 .60218 L
.57724 .60216 L
.5775 .60214 L
.57778 .60213 L
.57826 .60212 L
.5787 .60212 L
.57967 .60212 L
.58022 .60212 L
.58074 .60212 L
.58121 .60211 L
.58148 .60211 L
Mistroke
.58172 .6021 L
.58366 .60199 L
.58451 .60195 L
.58496 .60192 L
.58545 .6019 L
.58593 .6019 L
.58639 .6019 L
.58738 .60189 L
.58794 .60189 L
.58848 .60188 L
.58895 .60188 L
.58922 .60187 L
.58947 .60185 L
.59327 .60165 L
.60036 .60139 L
.61532 .6008 L
.6297 .60015 L
.64502 .59935 L
.65976 .5985 L
.67544 .59751 L
.69053 .59644 L
.70505 .59531 L
.72051 .59402 L
.73539 .59266 L
.7512 .59112 L
.76643 .5895 L
.78109 .58781 L
.79668 .5859 L
.81169 .58392 L
.82613 .58188 L
.8415 .57958 L
.85629 .57721 L
.87202 .57455 L
.88717 .57181 L
.90174 .569 L
.91725 .56585 L
.93218 .56261 L
.9398 .5609 L
.94804 .55898 L
.95192 .55804 L
.95404 .55747 L
.95601 .55676 L
.9577 .556 L
.95818 .55579 L
.95864 .55558 L
.95905 .55506 L
.9595 .55434 L
.96047 .5528 L
.96149 .55117 L
.96191 .5505 L
Mistroke
.96236 .54977 L
.96286 .54716 L
.96333 .5441 L
.96485 .5341 L
.96525 .53146 L
.96569 .5286 L
.9661 .52591 L
.96648 .51967 L
.96741 .49935 L
.96826 .48091 L
.96912 .46229 L
.96954 .4532 L
.96992 .4449 L
.97028 .42731 L
.97062 .40926 L
.97137 .36948 L
.97297 .28506 L
.97451 .17094 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;oooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00006oooool0033ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001[ooooo000Yooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001[ooooo000booooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool06?ooool002oooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Joooo
o`00;oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Jooooo`00<?ooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Kooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`007_oooooho`0000[ooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`08ooooo`007_oo
ool2o`0007Wooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo000:ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool000_ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000000Cooooon?l0000:ooooo`002oooool00ol0003oooooooooo`07ooooo`Co00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo000:ooooo`;o00002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool02Oooool2o`0000Gooooo0_l0
0004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000
1?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0_ooool2o`0000[ooooo000:ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool000_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool000[ooooo0_l00009ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oo
oooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool00_ooool2o`0000[ooooo000:ooooo`?o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000;oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`002oooool00ol0003oooooooooo`08ooooo`?o00001Oooool2o`0000Gooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo0_l0000:oooo
o`002oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000:ooooo`;o00002Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`002oooool00ol0003oooooooooo`08ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo
0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`03ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o
00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002_ooool3o`0000Cooooo
00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`002oooool00ol0003oooooooooo`08ooooo`Co00001?ooool2o`0000Gooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo0_l0000:oooo
o`002oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000:ooooo`;o00002Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`002oooool00ol0003oooooooooo`08ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo
0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`03ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o
00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`005Oooool5o`0000Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`005_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000H
ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001Gooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
01Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool001Kooooo0ol00005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool001kooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Ko
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?o
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Kooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Kooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`Go00000oooool00ol0003o
ooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0
000:ooooo`002Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`05o`000?oooooo
ooooooooool000002?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`002_ooool3o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001_ooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool01?ooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool0
01kooooo0_l00007ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`05ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01_ooool2o`00073o
oooo00?o0000ooooooooool0Koooool2o`0000Sooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool01oooool3o`0006kooooo00?o0000ooooooooool0K_ooool2o`0000Wooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02_ooool3o`0006_ooooo00?o
0000ooooooooool0JOooool5o`0000_ooooo00?o0000ooooooooool02?ooool001kooooo0_l0000>
ooooo`Co0000Ioooool00ol0003oooooooooo`1Wooooo`;o00003oooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo017ooooo2?l0001Oooooo`03o`000?oooooooooo05oooooo2?l0000Boooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo01Wooooo0ol0001Looooo`03
o`000?oooooooooo05_ooooo1?l0000Jooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo01cooooo2?l0001Dooooo`03o`000?oooooooooo05Cooooo1ol0000Nooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`;o00009Oooool4o`00053ooooo00?o0000ooooooooool0COoo
ool7o`0002Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Xooooo`Oo0000BOooool0
0ol0003oooooooooo`15ooooo`So0000;?ooool00ol0003oooooooooo`08ooooo`002Oooool5o`00
00?ooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo02oooooo2ol0000n
ooooo`03o`000?oooooooooo03kooooo1ol0000dooooo`03o`000?oooooooooo00Sooooo000:oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0jooooo`So0000=_ooool00ol0003oooooooooo`0booooo`co0000>oooool00ol0003ooooooooo
o`08ooooo`002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0@_ooool?o`0002Oooooo00?o0000ooooooooool09oooool;o`0004Oooooo00?o0000
ooooooooool02?ooool000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03oooo
o`;o0000D_oooolFo`00017ooooo00?o0000ooooooooool04?oooolGo`00057ooooo0_l0000:oooo
o`002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo06Oooooo9Ol0001Xooooo`03o`000?oooooooooo00Sooooo0009oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Sooooo000:
ooooo`?o00002Oooool3o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001kooooon?l0000:oooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00c?ooool3o`00057ooooo003=oooo
o`03o`000?oooooooooo053ooooo001Qooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`03
o`000?oooooooooo00;ooooo0ol00002ooooo`?o00000oooool3o`0000Cooooo0ol00002ooooo`?o
000000?oooooo`000?l000000_ooool2o`0000Sooooo1Ol000001Ooooooo0000o`000?l0003ooooo
00;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l00002oooo
o`Go00000oooool2o`0000Cooooo00?o0000ooooooooool0Coooool0067ooooo00?o0000ooooool0
00000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0006ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Coooool0067ooooo00?o0000ooooool0
00000oooool3o`0000?ooooo00?o0000ooooool000000_ooool5o`0000;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`00001@ooooo`00H?ooool01ol0003oooooo`000?oooooo0000ooooool0
00000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo0ol00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000053ooooo001Pooooo`05o`000?oo
oooo0000ooooool000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o0000
0oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo
1?l00002ooooo`Co00002_ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00003ooooo`?o
00000_ooool4o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co00000_ooool2o`00
0003ooooool0003o000004oooooo001Pooooo`05o`000?oooooo0000ooooool000005?ooool01?l0
003oooooooooool0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo001Pooooo`Ko00004_ooool5o`00
01Cooooo00?o0000ooooooooool02?ooool5o`0000Sooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.6739, 1.47021, 0.19271, \
0.00455694}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0209945 0.0147151 0.0115183 [
[.08011 -0.0125 -9 -9 ]
[.08011 -0.0125 9 0 ]
[.29006 -0.0125 -9 -9 ]
[.29006 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70994 -0.0125 -6 -9 ]
[.70994 -0.0125 6 0 ]
[.91989 -0.0125 -6 -9 ]
[.91989 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1299 -12 -4.5 ]
[-0.0125 .1299 0 4.5 ]
[-0.0125 .24508 -12 -4.5 ]
[-0.0125 .24508 0 4.5 ]
[-0.0125 .36026 -12 -4.5 ]
[-0.0125 .36026 0 4.5 ]
[-0.0125 .47545 -12 -4.5 ]
[-0.0125 .47545 0 4.5 ]
[-0.0125 .59063 -12 -4.5 ]
[-0.0125 .59063 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08011 0 m
.08011 .00625 L
s
[(-20)] .08011 -0.0125 0 1 Mshowa
.29006 0 m
.29006 .00625 L
s
[(-10)] .29006 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70994 0 m
.70994 .00625 L
s
[(10)] .70994 -0.0125 0 1 Mshowa
.91989 0 m
.91989 .00625 L
s
[(20)] .91989 -0.0125 0 1 Mshowa
.125 Mabswid
.1221 0 m
.1221 .00375 L
s
.16409 0 m
.16409 .00375 L
s
.20608 0 m
.20608 .00375 L
s
.24807 0 m
.24807 .00375 L
s
.33204 0 m
.33204 .00375 L
s
.37403 0 m
.37403 .00375 L
s
.41602 0 m
.41602 .00375 L
s
.45801 0 m
.45801 .00375 L
s
.54199 0 m
.54199 .00375 L
s
.58398 0 m
.58398 .00375 L
s
.62597 0 m
.62597 .00375 L
s
.66796 0 m
.66796 .00375 L
s
.75193 0 m
.75193 .00375 L
s
.79392 0 m
.79392 .00375 L
s
.83591 0 m
.83591 .00375 L
s
.8779 0 m
.8779 .00375 L
s
.03812 0 m
.03812 .00375 L
s
.96188 0 m
.96188 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1299 m
.00625 .1299 L
s
[(10)] -0.0125 .1299 1 0 Mshowa
0 .24508 m
.00625 .24508 L
s
[(20)] -0.0125 .24508 1 0 Mshowa
0 .36026 m
.00625 .36026 L
s
[(30)] -0.0125 .36026 1 0 Mshowa
0 .47545 m
.00625 .47545 L
s
[(40)] -0.0125 .47545 1 0 Mshowa
0 .59063 m
.00625 .59063 L
s
[(50)] -0.0125 .59063 1 0 Mshowa
.125 Mabswid
0 .03775 m
.00375 .03775 L
s
0 .06079 m
.00375 .06079 L
s
0 .08383 m
.00375 .08383 L
s
0 .10686 m
.00375 .10686 L
s
0 .15293 m
.00375 .15293 L
s
0 .17597 m
.00375 .17597 L
s
0 .19901 m
.00375 .19901 L
s
0 .22204 m
.00375 .22204 L
s
0 .26812 m
.00375 .26812 L
s
0 .29115 m
.00375 .29115 L
s
0 .31419 m
.00375 .31419 L
s
0 .33723 m
.00375 .33723 L
s
0 .3833 m
.00375 .3833 L
s
0 .40634 m
.00375 .40634 L
s
0 .42937 m
.00375 .42937 L
s
0 .45241 m
.00375 .45241 L
s
0 .49848 m
.00375 .49848 L
s
0 .52152 m
.00375 .52152 L
s
0 .54456 m
.00375 .54456 L
s
0 .56759 m
.00375 .56759 L
s
0 .61367 m
.00375 .61367 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08011 .61178 m
.08011 .61803 L
s
.29006 .61178 m
.29006 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.70994 .61178 m
.70994 .61803 L
s
.91989 .61178 m
.91989 .61803 L
s
.125 Mabswid
.1221 .61428 m
.1221 .61803 L
s
.16409 .61428 m
.16409 .61803 L
s
.20608 .61428 m
.20608 .61803 L
s
.24807 .61428 m
.24807 .61803 L
s
.33204 .61428 m
.33204 .61803 L
s
.37403 .61428 m
.37403 .61803 L
s
.41602 .61428 m
.41602 .61803 L
s
.45801 .61428 m
.45801 .61803 L
s
.54199 .61428 m
.54199 .61803 L
s
.58398 .61428 m
.58398 .61803 L
s
.62597 .61428 m
.62597 .61803 L
s
.66796 .61428 m
.66796 .61803 L
s
.75193 .61428 m
.75193 .61803 L
s
.79392 .61428 m
.79392 .61803 L
s
.83591 .61428 m
.83591 .61803 L
s
.8779 .61428 m
.8779 .61803 L
s
.03812 .61428 m
.03812 .61803 L
s
.96188 .61428 m
.96188 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1299 m
1 .1299 L
s
.99375 .24508 m
1 .24508 L
s
.99375 .36026 m
1 .36026 L
s
.99375 .47545 m
1 .47545 L
s
.99375 .59063 m
1 .59063 L
s
.125 Mabswid
.99625 .03775 m
1 .03775 L
s
.99625 .06079 m
1 .06079 L
s
.99625 .08383 m
1 .08383 L
s
.99625 .10686 m
1 .10686 L
s
.99625 .15293 m
1 .15293 L
s
.99625 .17597 m
1 .17597 L
s
.99625 .19901 m
1 .19901 L
s
.99625 .22204 m
1 .22204 L
s
.99625 .26812 m
1 .26812 L
s
.99625 .29115 m
1 .29115 L
s
.99625 .31419 m
1 .31419 L
s
.99625 .33723 m
1 .33723 L
s
.99625 .3833 m
1 .3833 L
s
.99625 .40634 m
1 .40634 L
s
.99625 .42937 m
1 .42937 L
s
.99625 .45241 m
1 .45241 L
s
.99625 .49848 m
1 .49848 L
s
.99625 .52152 m
1 .52152 L
s
.99625 .54456 m
1 .54456 L
s
.99625 .56759 m
1 .56759 L
s
.99625 .61367 m
1 .61367 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .30239 Mdot
.03144 .34844 Mdot
.03907 .38986 Mdot
.04669 .42689 Mdot
.05431 .45975 Mdot
.06191 .48865 Mdot
.06951 .51382 Mdot
.0771 .53545 Mdot
.08469 .55374 Mdot
.09227 .56887 Mdot
.09984 .58102 Mdot
.10741 .59038 Mdot
.11497 .59711 Mdot
.12253 .60137 Mdot
.13008 .60332 Mdot
.13762 .60311 Mdot
.14516 .6009 Mdot
.1527 .59681 Mdot
.16023 .59099 Mdot
.16776 .58358 Mdot
.17528 .57468 Mdot
.1828 .56444 Mdot
.19031 .55297 Mdot
.19782 .54038 Mdot
.20533 .52678 Mdot
.21283 .51229 Mdot
.22033 .49699 Mdot
.22783 .48099 Mdot
.23532 .46439 Mdot
.24281 .44727 Mdot
.2503 .42973 Mdot
.25778 .41185 Mdot
.26526 .39371 Mdot
.27274 .37538 Mdot
.28021 .35695 Mdot
.28769 .33849 Mdot
.29516 .32006 Mdot
.30262 .30173 Mdot
.31009 .28356 Mdot
.31755 .26562 Mdot
.32502 .24796 Mdot
.33248 .23063 Mdot
.33993 .2137 Mdot
.34739 .1972 Mdot
.35484 .18119 Mdot
.3623 .16571 Mdot
.36975 .15081 Mdot
.3772 .13651 Mdot
.38465 .12287 Mdot
.3921 .10991 Mdot
.39954 .09768 Mdot
.40699 .08618 Mdot
.41443 .07547 Mdot
.42188 .06556 Mdot
.42932 .05647 Mdot
.43676 .04824 Mdot
.4442 .04087 Mdot
.45164 .03438 Mdot
.45908 .02879 Mdot
.46652 .02412 Mdot
.47396 .02037 Mdot
.4814 .01754 Mdot
.48884 .01566 Mdot
.49628 .01472 Mdot
.50372 .01472 Mdot
.51116 .01566 Mdot
.5186 .01754 Mdot
.52604 .02037 Mdot
.53348 .02412 Mdot
.54092 .02879 Mdot
.54836 .03438 Mdot
.5558 .04087 Mdot
.56324 .04824 Mdot
.57068 .05647 Mdot
.57812 .06556 Mdot
.58557 .07547 Mdot
.59301 .08618 Mdot
.60046 .09768 Mdot
.6079 .10991 Mdot
.61535 .12287 Mdot
.6228 .13651 Mdot
.63025 .15081 Mdot
.6377 .16571 Mdot
.64516 .18119 Mdot
.65261 .1972 Mdot
.66007 .2137 Mdot
.66752 .23063 Mdot
.67498 .24796 Mdot
.68245 .26562 Mdot
.68991 .28356 Mdot
.69738 .30173 Mdot
.70484 .32006 Mdot
.71231 .33849 Mdot
.71979 .35695 Mdot
.72726 .37538 Mdot
.73474 .39371 Mdot
.74222 .41185 Mdot
.7497 .42973 Mdot
.75719 .44727 Mdot
.76468 .46439 Mdot
.77217 .48099 Mdot
.77967 .49699 Mdot
.78717 .51229 Mdot
.79467 .52678 Mdot
.80218 .54038 Mdot
.80969 .55297 Mdot
.8172 .56444 Mdot
.82472 .57468 Mdot
.83224 .58358 Mdot
.83977 .59099 Mdot
.8473 .59681 Mdot
.85484 .6009 Mdot
.86238 .60311 Mdot
.86992 .60332 Mdot
.87747 .60137 Mdot
.88503 .59711 Mdot
.89259 .59038 Mdot
.90016 .58102 Mdot
.90773 .56887 Mdot
.91531 .55374 Mdot
.9229 .53545 Mdot
.93049 .51382 Mdot
.93809 .48865 Mdot
.94569 .45975 Mdot
.95331 .42689 Mdot
.96093 .38986 Mdot
.96856 .34844 Mdot
.97619 .30239 Mdot
.5 Mabswid
.02381 .30239 m
.03853 .3869 L
.05458 .46079 L
.06965 .51423 L
.08415 .55245 L
.09161 .56755 L
.09958 .58061 L
.1077 .59064 L
.11142 .59395 L
.11346 .59577 L
.11446 .59665 L
.11537 .59733 L
.11712 .59832 L
.11899 .59938 L
.1209 .60045 L
.12191 .60102 L
.12217 .60117 L
.12246 .60133 L
.12273 .60142 L
.12298 .60149 L
.12396 .60174 L
.12485 .60197 L
.12658 .60242 L
.12837 .60288 L
.12916 .60308 L
.12957 .60319 L
.13001 .6033 L
.13048 .60331 L
.13093 .6033 L
.1318 .60327 L
.13372 .60322 L
.13538 .60317 L
.13626 .60315 L
.13673 .60314 L
.13718 .60312 L
.13766 .6031 L
.13791 .60303 L
.13818 .60295 L
.13911 .60268 L
.14092 .60214 L
.14307 .60151 L
.14401 .60123 L
.14451 .60109 L
.14479 .60101 L
.14505 .60093 L
.14529 .60083 L
.14556 .60068 L
.14603 .60043 L
.14694 .59993 L
.14895 .59884 L
Mistroke
.15318 .59644 L
.16086 .59038 L
.17636 .57321 L
.19129 .55134 L
.20715 .52327 L
.22243 .49251 L
.23714 .46024 L
.25278 .4238 L
.26784 .38738 L
.28233 .35173 L
.29775 .3137 L
.31259 .27756 L
.32836 .24018 L
.34356 .20567 L
.35819 .17425 L
.37374 .14315 L
.38872 .11579 L
.40312 .09215 L
.41846 .07011 L
.43321 .05216 L
.44891 .03677 L
.45674 .03055 L
.46402 .02569 L
.4715 .02161 L
.47856 .01862 L
.48231 .01731 L
.48637 .01629 L
.48816 .01583 L
.4886 .01572 L
.48906 .01563 L
.48933 .0156 L
.48958 .01557 L
.49006 .0155 L
.49345 .01507 L
.49528 .01484 L
.49572 .01479 L
.4962 .01472 L
.49648 .01472 L
.49673 .01472 L
.49722 .01472 L
.50071 .01472 L
.50255 .01472 L
.50306 .01472 L
.50333 .01472 L
.50359 .01472 L
.50384 .01473 L
.5041 .01476 L
.50456 .01482 L
.50862 .01534 L
.51035 .01556 L
Mistroke
.51085 .01562 L
.51133 .0157 L
.51175 .01581 L
.51222 .01593 L
.51427 .01645 L
.51618 .01693 L
.5242 .01967 L
.5317 .02322 L
.53969 .02802 L
.55554 .04064 L
.57081 .05663 L
.5855 .07538 L
.60113 .09878 L
.61618 .12439 L
.63065 .15161 L
.64606 .18313 L
.66089 .21557 L
.67665 .25191 L
.69184 .28826 L
.70645 .32402 L
.72199 .36239 L
.73696 .39909 L
.75135 .43358 L
.76667 .4688 L
.78142 .50056 L
.7971 .53118 L
.8122 .55681 L
.82672 .57705 L
.83483 .58612 L
.84218 .59286 L
.84586 .5957 L
.84984 .59819 L
.85357 .60021 L
.85707 .60155 L
.86067 .60261 L
.86166 .6029 L
.86214 .60304 L
.86259 .60312 L
.86284 .60313 L
.8631 .60313 L
.86366 .60315 L
.86464 .60317 L
.86681 .60323 L
.86788 .60326 L
.86885 .60329 L
.86931 .6033 L
.86974 .60331 L
.87019 .60325 L
.87068 .60312 L
.87266 .60261 L
Mistroke
.87458 .60212 L
.87559 .60186 L
.87666 .60158 L
.87711 .60146 L
.87759 .6013 L
.87787 .60115 L
.87812 .601 L
.87862 .60072 L
.88044 .5997 L
.88751 .5949 L
.89126 .59157 L
.89474 .58773 L
.90263 .57705 L
.91045 .56345 L
.91753 .54838 L
.93279 .50619 L
.94747 .45206 L
.96309 .37811 L
.97619 .30239 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;?ooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00007_ooool002gooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001gooooo000Vooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001gooooo000_ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool06oooool002cooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Moooo
o`00;?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Mooooo`00;Oooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Nooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`006ooooooho`0000gooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`00
4oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004ooooo`;o
0000M_ooool8o`0007Kooooo0_l0000=ooooo`004oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo077ooooo3ol0001dooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0L?ooool5o`0000?ooooo00Co0000oooooooo
oooooooo1_l0001booooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0K_ooool4o`0000Kooooo00?o0000ooooooooool01Oooool4o`00
073ooooo00?o0000ooooooooool02oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo06ko
oooo0_l00008ooooo`03o`000?oooooooooo00Oooooo0_l0001`ooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo06cooooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo
0_l0001^ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o0000Joooool4o`0000[ooooo00?o
0000ooooooooool02Oooool4o`0006_ooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1Z
ooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`;o0000K?ooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`1Xooooo`?o00003Oooool00ol0003oooooooooo`0<oooo
o`;o0000Joooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Xooooo`;o
00003_ooool00ol0003oooooooooo`0<ooooo`;o0000Joooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`1Vooooo`?o00003oooool00ol0003oooooooooo`0>ooooo`;o0000
JOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Vooooo`;o00004?oo
ool00ol0003oooooooooo`0>ooooo`;o0000JOooool00ol0003oooooooooo`0;ooooo`006oooool2
o`0006Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo06Gooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1Tooooo`;o00004_ooool00ol0
003oooooooooo`0@ooooo`;o0000Ioooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003o
ooooooooo`1Tooooo`;o00004_ooool00ol0003oooooooooo`0@ooooo`?o0000I_ooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Sooooo`;o00004oooool00ol0003ooooo
ooooo`0Booooo`;o0000IOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`1Sooooo`;o00004oooool00ol0003oooooooooo`0Booooo`;o0000IOooool00ol0003ooooooooo
o`0;ooooo`006oooool2o`0006?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo067ooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1Qoooo
o`;o00005Oooool00ol0003oooooooooo`0Dooooo`;o0000Hoooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`1Qooooo`;o00005Oooool00ol0003oooooooooo`0Dooooo`;o
0000Hoooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Oooooo`?o0000
5_ooool00ol0003oooooooooo`0Eooooo`?o0000HOooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`1Oooooo`;o00005oooool00ol0003oooooooooo`0Fooooo`;o0000HOoo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`;o0000H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0G_ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo05go
oooo0_l0000Iooooo`03o`000?oooooooooo01Oooooo0_l0001Pooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo05gooooo0_l0000Iooooo`03o`000?oooooooooo01Oooooo
0_l0001Pooooo`03o`000?oooooooooo00_ooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0;ooooo`003_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Foooool2o`0001_ooooo00?o
0000ooooooooool06Oooool2o`0005kooooo00?o0000ooooooooool02oooool000kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05_ooooo0_l0
000Kooooo`03o`000?oooooooooo01Wooooo0_l0001Nooooo`03o`000?oooooooooo00_ooooo000>
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool2o`0005cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05[ooooo0_l0
000=ooooo`003_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0FOooool2o`0001gooooo00?o0000ooooooooool06oooool2o`0005cooooo00?o
0000ooooooooool02oooool000gooooo0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0FOooool2o`0001gooooo00?o0000ooooooooool06oooool2o`0005cooooo00?o
0000ooooooooool02oooool000kooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo00_ooooo000Kooooo`;o0000FOooool2o`0001kooooo00?o0000oooooooo
ool07Oooool2o`0005Wooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1Hooooo`;o0000
7_ooool00ol0003oooooooooo`0Mooooo`;o0000F_ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo05Kooooo0_l0000Pooooo`03o`000?oooooooooo01oooooo0_l0001Hooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo05Kooooo0_l0000Pooooo`03o`000?oooooooooo
01oooooo0_l0001Hooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool02oooool001_ooooo0_l0001Fooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Dooooo`;o00003Oooool001_ooooo00?o
0000ooooooooool0E?ooool2o`0002;ooooo00?o0000ooooooooool08Oooool2o`0005Kooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0E?ooool2o`0002;ooooo00?o0000
ooooooooool08Oooool2o`0005Kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05;ooooo0_l0000Tooooo`03o`00
0?oooooooooo02?ooooo0_l0001Dooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o0000Dooo
ool2o`0002Cooooo00?o0000ooooooooool08oooool2o`0005?ooooo0_l0000=ooooo`006oooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0D?ooool2o`0002Ko
oooo00?o0000ooooooooool09?ooool2o`0005?ooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool0D?ooool2o`0002Kooooo00?o0000ooooooooool09?ooool2o`0005?ooooo
00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DOooool00ol0003ooooooooo
o`0;ooooo`006oooool2o`00057ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo04oooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1>oooo
o`?o00009oooool00ol0003oooooooooo`0Vooooo`;o0000DOooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`1>ooooo`;o0000:?ooool00ol0003oooooooooo`0Vooooo`;o
0000DOooool00ol0003oooooooooo`0;ooooo`003?ooool5o`0000?ooooo0_l00005ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool02oooool000kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`;o
0000Coooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0COooool2o`0000gooooo000?ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04gooooo0_l0000Yooooo`03o`000?oooooooooo02So
oooo0_l0001?ooooo`03o`000?oooooooooo00_ooooo000<ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04gooooo0_l0000Yoooo
o`03o`000?oooooooooo02Sooooo0_l0001?ooooo`03o`000?oooooooooo00_ooooo000<ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool02oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo04_o
oooo0_l0000[ooooo`03o`000?oooooooooo02[ooooo0_l0001=ooooo`03o`000?oooooooooo00_o
oooo000Kooooo`;o0000C?ooool2o`0002_ooooo00?o0000ooooooooool0:_ooool2o`0004cooooo
0_l0000=ooooo`006oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool0BOooool2o`0002gooooo00?o0000ooooooooool0;?ooool2o`0004_ooooo00?o0000oooo
ooooool02oooool001_ooooo00?o0000ooooooooool0BOooool2o`0002gooooo00?o0000oooooooo
ool0;?ooool2o`0004_ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0;ooooo`006oooool2o`0004Wooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Sooooo0_l0000=ooooo`006oooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
00;ooooo0_l00013ooooo`;o0000;oooool00ol0003oooooooooo`0^ooooo`;o0000@_ooool2o`00
00Gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool00_ooool2o`0004?o
oooo0_l0000_ooooo`03o`000?oooooooooo02kooooo0_l00012ooooo`;o00001Oooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`006oooool2o`0000Cooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`;o00003Oooool001_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0nooooo`;o0000<Oooool00ol0003oooooooooo`0_
ooooo`;o0000@Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool2o`00037ooooo00?o0000oooo
ooooool0;oooool2o`00047ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0;ooooo`006oooool2o`0000Gooooo00?o0000ooooooooool0??ooool2
o`0003?ooooo00?o0000ooooooooool0<Oooool2o`0003oooooo00?o0000ooooooooool00oooool2
o`0000gooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0??ooool2o`00
03?ooooo00?o0000ooooooooool0<Oooool2o`0003kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`04ooooo`;o0000?_ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0>oooool2o`0000Ko
oooo00?o0000ooooooooool02oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`04ooooo`;o0000?Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0>oooool2o`0000Kooooo00?o0000ooooooooool02oooool000cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool3o`0003Cooooo00?o0000oooooooo
ool0<oooool2o`0003cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`00
3_ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool2o`0000Kooooo00?o0000oooooooo
ool0>Oooool2o`0003Gooooo00?o0000ooooooooool0<oooool2o`0003cooooo00?o0000oooooooo
ool01?ooool2o`0000gooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0;ooooo`003?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`003Oooool3o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool2o`0003Ko
oooo00?o0000ooooooooool0=Oooool2o`0003Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo
0_l0000fooooo`03o`000?oooooooooo03Gooooo0_l0000iooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02oooool001_ooooo0_l00007ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool01Oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo00Kooooo0_l0000gooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0eooooo`;o00002?ooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`06ooooo`;o0000=_ooool2o`0003Sooooo00?o0000oooooooo
ool0=oooool2o`0003Kooooo0_l00008ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0=?ooool2o`0003Sooooo00?o0000ooooooooool0
=oooool2o`0003Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0;ooooo`006oooool2o`0000Sooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`06ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0booooo`;o0000>_ooool00ol0003oooooooooo`0iooooo`;o0000<oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0<_ooool2o`0003[ooooo00?o0000ooooooooool0>Oooool2o`0003?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`08
ooooo`;o0000<Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0;oooool2o`0000[ooooo00?o0000ooooooooool02oooool001_ooooo0_l00009oooo
o`;o0000<?ooool2o`0003cooooo00?o0000ooooooooool0>oooool2o`00033ooooo0_l00009oooo
o`;o00003Oooool001_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`;o
0000??ooool00ol0003oooooooooo`0kooooo`;o0000<?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool2
o`0003kooooo00?o0000ooooooooool0??ooool2o`0002kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`006oooool2o`0000[ooooo00?o0000ooooooooool0;?ooool2o`00
03kooooo00?o0000ooooooooool0??ooool2o`0002kooooo00?o0000ooooooooool02Oooool2o`00
00gooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00[ooooo
0_l0000/ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0Zooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`0:ooooo`;o0000:_ooool3o`0003oooooo00?o0000ooooooooool0?_ooool2o`0002_ooooo0_l0
000<ooooo`03o`000?oooooooooo00_ooooo000>ooooo`?o00000oooool2o`0000Gooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`;o0000@?ooool00ol0003oooooooooo`0n
ooooo`;o0000:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo000?oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo000<ooooo`Go00000_ooool01?l0003oooooooooool00004ooooo`;o00003?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo0_l0000=ooooo`003?ooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Wooooo`;o0000@Oooool00ol0003oooooooooo`10ooooo`;o0000:?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo000=ooooo`03o`000?oooooo
000000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo02Oooooo0_l00011ooooo`03o`000?oooooooooo043ooooo0_l0000Xooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool000kooooo0_l00003ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool03?ooool2o`0002Oooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02Gooooo0_l0000>ooooo`03o`000?oo
oooooooo00_ooooo000?ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooo
oooo00cooooo0_l0000Vooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0Tooooo`;o00003_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Cooooo0_l00013ooooo`03o`000?oooooooooo
04;ooooo0_l0000Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool001_o
oooo0_l0000>ooooo`03o`000?oooooooooo02?ooooo0_l00013ooooo`03o`000?oooooooooo04;o
oooo0_l0000Uooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`006oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0=
ooooo`;o00008_ooool2o`0004Gooooo00?o0000ooooooooool0A?ooool2o`00027ooooo0_l0000@
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00gooooo0_l0000Roooo
o`;o0000AOooool00ol0003oooooooooo`14ooooo`;o00008Oooool2o`00013ooooo00?o0000oooo
ooooool02oooool001_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool001_ooooo0_l0000@ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool03_ooool2o`0000gooooo000Kooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool07Oooool2o`0004Oooooo00?o0000ooooooooool0A_oo
ool2o`0001oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01cooooo0_l00017ooooo`03o`000?oooooo
oooo04Kooooo0_l0000Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool0
01_ooooo00?o0000ooooooooool03oooool2o`0001kooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo01_ooooo0_l0000Booooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo00oooooo0_l0000Looooo`;o0000BOooool00ol0003o
ooooooooo`17ooooo`;o00007?ooool2o`0001;ooooo00?o0000ooooooooool02oooool001_ooooo
0_l0000Booooo`03o`000?oooooooooo01Wooooo0_l00019ooooo`03o`000?oooooooooo04Oooooo
0ol0000Kooooo`03o`000?oooooooooo013ooooo0_l0000=ooooo`006oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`0Aooooo`;o00006?ooool2o`0004_ooooo00?o0000
ooooooooool0BOooool2o`0001Sooooo0ol0000Cooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo017ooooo0_l0000Hooooo`;o0000Boooool00ol0003oooooooooo`19oooo
o`?o00005oooool2o`0001Cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`;o0000
COooool00ol0003oooooooooo`1;ooooo`;o00005_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`;o00005?ooool2o`0001Cooooo0_l0001=ooooo`03o`000?oo
oooooooo04_ooooo0ol0000Dooooo`;o00005?ooool2o`0000gooooo000Kooooo`03o`000?oooooo
oooo01?ooooo0_l0000Cooooo`;o0000C_ooool00ol0003oooooooooo`1=ooooo`;o00004oooool2
o`0001Gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0@ooooo`;o0000C_ooool00ol0003oooooooooo`1=ooooo`;o00004_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo000=ooooo`?o00001?ooool2o`0000Go
oooo00?o0000ooooooooool05Oooool2o`00013ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo00oooooo0_l0000Gooooo`03o`000?oooooooooo00_o
oooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo01Gooooo0_l0000?ooooo`;o0000D?ooool00ol0003oooooooooo`1?oooo
o`;o00003oooool2o`0001Oooooo00?o0000ooooooooool02oooool0013ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo0_l0000;oooo
o`Co0000D?ooool00ol0003oooooooooo`1?ooooo`Co00002oooool2o`0001Wooooo00?o0000oooo
ooooool02oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`;o00006?ooool2o`0000_ooooo0_l0001Booooo`03o`000?oooooooooo057ooooo0_l0000;oooo
o`;o00006?ooool2o`0000gooooo000<ooooo`Co00000oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo01Wooooo0_l00007ooooo`;o0000E?ooool00ol0003oooooooooo`1Coooo
o`;o00001oooool2o`0001_ooooo00?o0000ooooooooool02oooool000cooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Wooooo2ol0001Doooo
o`03o`000?oooooooooo05?ooooo2ol0000Kooooo`03o`000?oooooooooo00_ooooo000<ooooo`Go
00000oooool2o`0000Gooooo00?o0000ooooooooool06_ooool8o`0005Kooooo00?o0000oooooooo
ool0EOooool7o`0001gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00001ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`006ooooooh
o`0000gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000]ooooo`?o0000R_oo
ool00ol0003oooooooooo`0[ooooo`?o00005Oooool00ol0003oooooooooo`0Mooooo`00;_ooool0
0ol0003oooooooooo`28ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Looooo`00:?ooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`00
00;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000ol00007ooooo`?o00001?ooool4o`00
00?ooooo0_l00002ooooo`Ko00001_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003o`00
0003ooooool0003o000000?o00000_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3o`00
0004ooooool0003o0000ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool5
o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_oo
ool:o`0000Gooooo00?o0000ooooooooool06oooool002Oooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00000<ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06oooool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go
00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01_l0003oooooooooool0003ooooo
o`0000Gooooo1Ol00008ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`00
0002ooooo`?o00000oooool00ol0003oooooo`000002ooooo`Go00000oooool01?l0003ooooooooo
ooooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00000_ooool3o`0000Gooooo00?o0000ooooooooool06ooo
ool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool0
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000oooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooool00005ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`0K
ooooo`009oooool01_l0003ooooooooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo0ol0
0004ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ool00002ooooo`;o00000oooool4o`0000?ooooo0ol00009ooooo`05o`000?ooooooooooo`000?oo
ool00ol00004ooooo`Co00000_ooool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l0
00000_ooool3o`0000;ooooo1?l00003ooooo`?o00000oooool3o`0000Wooooo00?o0000oooooooo
ool00_ooool6o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`?o
00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o
00000oooool4o`0000Cooooo00?o0000ooooooooool06oooool002Oooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo000Xooooo`?o00002Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0ol00009ooooo`Co00002Oooool00ol0
003oooooooooo`02ooooo`;o00002_ooool4o`0000Cooooo00?o0000ooooooooool01?ooool2o`00
00Cooooo0_l0000^ooooo`03o`000?oooooooooo01Sooooo0ol0000Fooooo`03o`000?oooooooooo
00;ooooo0_l0000;ooooo`03o`000?oooooooooo01gooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.0958, -5.52433, 0.19271, \
0.351254}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.776589 0.0147151 0.588604 [
[.03405 .00222 -12 -9 ]
[.03405 .00222 12 0 ]
[.18936 .00222 -12 -9 ]
[.18936 .00222 12 0 ]
[.34468 .00222 -12 -9 ]
[.34468 .00222 12 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.65532 .00222 -9 -9 ]
[.65532 .00222 9 0 ]
[.81064 .00222 -9 -9 ]
[.81064 .00222 9 0 ]
[.96595 .00222 -9 -9 ]
[.96595 .00222 9 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03405 .01472 m
.03405 .02097 L
s
[(-0.6)] .03405 .00222 0 1 Mshowa
.18936 .01472 m
.18936 .02097 L
s
[(-0.4)] .18936 .00222 0 1 Mshowa
.34468 .01472 m
.34468 .02097 L
s
[(-0.2)] .34468 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0)] .5 .00222 0 1 Mshowa
.65532 .01472 m
.65532 .02097 L
s
[(0.2)] .65532 .00222 0 1 Mshowa
.81064 .01472 m
.81064 .02097 L
s
[(0.4)] .81064 .00222 0 1 Mshowa
.96595 .01472 m
.96595 .02097 L
s
[(0.6)] .96595 .00222 0 1 Mshowa
.125 Mabswid
.07288 .01472 m
.07288 .01847 L
s
.11171 .01472 m
.11171 .01847 L
s
.15054 .01472 m
.15054 .01847 L
s
.22819 .01472 m
.22819 .01847 L
s
.26702 .01472 m
.26702 .01847 L
s
.30585 .01472 m
.30585 .01847 L
s
.38351 .01472 m
.38351 .01847 L
s
.42234 .01472 m
.42234 .01847 L
s
.46117 .01472 m
.46117 .01847 L
s
.53883 .01472 m
.53883 .01847 L
s
.57766 .01472 m
.57766 .01847 L
s
.61649 .01472 m
.61649 .01847 L
s
.69415 .01472 m
.69415 .01847 L
s
.73298 .01472 m
.73298 .01847 L
s
.77181 .01472 m
.77181 .01847 L
s
.84946 .01472 m
.84946 .01847 L
s
.88829 .01472 m
.88829 .01847 L
s
.92712 .01472 m
.92712 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .02064 m
.0243 .02053 L
.02478 .02068 L
.02527 .02062 L
.02575 .02062 L
.02624 .0207 L
.02672 .02072 L
.02721 .02067 L
.0277 .02068 L
.02818 .02068 L
.02867 .02075 L
.02915 .02054 L
.02964 .02073 L
.03013 .02067 L
.03061 .02077 L
.0311 .02063 L
.03158 .02086 L
.03207 .02082 L
.03256 .02098 L
.03304 .02083 L
.03353 .02114 L
.03401 .02089 L
.0345 .02122 L
.03499 .021 L
.03547 .0213 L
.03596 .02109 L
.03644 .02131 L
.03693 .02137 L
.03741 .02134 L
.0379 .0215 L
.03839 .02154 L
.03887 .02175 L
.03936 .02169 L
.03984 .02182 L
.04033 .02216 L
.04082 .02207 L
.0413 .02243 L
.04179 .02229 L
.04227 .02284 L
.04276 .02263 L
.04325 .02305 L
.04373 .02294 L
.04422 .0233 L
.0447 .02308 L
.04519 .02352 L
.04568 .02332 L
.04616 .02371 L
.04665 .02343 L
.04713 .02405 L
.04762 .02358 L
Mistroke
.0481 .02415 L
.04859 .02375 L
.04908 .02439 L
.04956 .024 L
.05005 .0243 L
.05053 .02408 L
.05102 .02465 L
.05151 .02411 L
.05199 .02474 L
.05248 .02428 L
.05296 .0249 L
.05345 .02439 L
.05394 .02504 L
.05442 .02457 L
.05491 .02522 L
.05539 .02478 L
.05588 .02533 L
.05637 .02511 L
.05685 .02543 L
.05734 .02519 L
.05782 .02585 L
.05831 .02521 L
.05879 .02584 L
.05928 .02508 L
.05977 .02605 L
.06025 .02501 L
.06074 .02577 L
.06122 .02506 L
.06171 .02557 L
.0622 .02506 L
.06268 .02534 L
.06317 .02484 L
.06365 .02533 L
.06414 .02474 L
.06463 .02494 L
.06511 .02471 L
.0656 .02481 L
.06608 .02419 L
.06657 .0249 L
.06706 .02396 L
.06754 .02442 L
.06803 .02375 L
.06851 .02397 L
.069 .02352 L
.06948 .02362 L
.06997 .02302 L
.07046 .02336 L
.07094 .02281 L
.07143 .02301 L
.07191 .02232 L
Mistroke
.0724 .02272 L
.07289 .02225 L
.07337 .02213 L
.07386 .02205 L
.07434 .02194 L
.07483 .02164 L
.07532 .02171 L
.0758 .02155 L
.07629 .02135 L
.07677 .02144 L
.07726 .02118 L
.07775 .02123 L
.07823 .02128 L
.07872 .02104 L
.0792 .02114 L
.07969 .02108 L
.08017 .02122 L
.08066 .02102 L
.08115 .02086 L
.08163 .02129 L
.08212 .02071 L
.0826 .02103 L
.08309 .02078 L
.08358 .02081 L
.08406 .02069 L
.08455 .02076 L
.08503 .02054 L
.08552 .02066 L
.08601 .02049 L
.08649 .02062 L
.08698 .0204 L
.08746 .02073 L
.08795 .02046 L
.08844 .02058 L
.08892 .02045 L
.08941 .021 L
.08989 .02025 L
.09038 .02097 L
.09086 .0205 L
.09135 .021 L
.09184 .02065 L
.09232 .02105 L
.09281 .02083 L
.09329 .02119 L
.09378 .02098 L
.09427 .02154 L
.09475 .02097 L
.09524 .02186 L
.09572 .02134 L
.09621 .02177 L
Mistroke
.0967 .02176 L
.09718 .02208 L
.09767 .02187 L
.09815 .02221 L
.09864 .02224 L
.09913 .02269 L
.09961 .02222 L
.1001 .02298 L
.10058 .02272 L
.10107 .02317 L
.10155 .02313 L
.10204 .02351 L
.10253 .02332 L
.10301 .02387 L
.1035 .02376 L
.10398 .02396 L
.10447 .02397 L
.10496 .02411 L
.10544 .02434 L
.10593 .02381 L
.10641 .02456 L
.1069 .02412 L
.10739 .02417 L
.10787 .02418 L
.10836 .02427 L
.10884 .02428 L
.10933 .02411 L
.10982 .02412 L
.1103 .02439 L
.11079 .02384 L
.11127 .02453 L
.11176 .02382 L
.11224 .02423 L
.11273 .02393 L
.11322 .02428 L
.1137 .02384 L
.11419 .0241 L
.11467 .02394 L
.11516 .02424 L
.11565 .02359 L
.11613 .02434 L
.11662 .02384 L
.1171 .02401 L
.11759 .02365 L
.11808 .02406 L
.11856 .02361 L
.11905 .02383 L
.11953 .02328 L
.12002 .02384 L
.12051 .02295 L
Mistroke
.12099 .02375 L
.12148 .02297 L
.12196 .02328 L
.12245 .0229 L
.12293 .02328 L
.12342 .0228 L
.12391 .02298 L
.12439 .0226 L
.12488 .02314 L
.12536 .02212 L
.12585 .02282 L
.12634 .02225 L
.12682 .02244 L
.12731 .02203 L
.12779 .02199 L
.12828 .02219 L
.12877 .02169 L
.12925 .02193 L
.12974 .02168 L
.13022 .02163 L
.13071 .02157 L
.1312 .02165 L
.13168 .02147 L
.13217 .02143 L
.13265 .02131 L
.13314 .02167 L
.13362 .02122 L
.13411 .02148 L
.1346 .02147 L
.13508 .02169 L
.13557 .02136 L
.13605 .0218 L
.13654 .02159 L
.13703 .0222 L
.13751 .02139 L
.138 .02237 L
.13848 .02167 L
.13897 .02233 L
.13946 .02193 L
.13994 .02237 L
.14043 .02211 L
.14091 .02233 L
.1414 .02232 L
.14189 .02281 L
.14237 .02222 L
.14286 .02299 L
.14334 .02265 L
.14383 .02317 L
.14431 .02281 L
.1448 .02315 L
Mistroke
.14529 .02352 L
.14577 .02318 L
.14626 .02347 L
.14674 .02349 L
.14723 .0238 L
.14772 .02377 L
.1482 .02384 L
.14869 .02405 L
.14917 .02413 L
.14966 .02398 L
.15015 .02457 L
.15063 .0241 L
.15112 .02455 L
.1516 .02406 L
.15209 .02479 L
.15258 .02424 L
.15306 .02455 L
.15355 .02436 L
.15403 .02499 L
.15452 .0243 L
.155 .02486 L
.15549 .02445 L
.15598 .02522 L
.15646 .02447 L
.15695 .02481 L
.15743 .02468 L
.15792 .02464 L
.15841 .02451 L
.15889 .02451 L
.15938 .02429 L
.15986 .0244 L
.16035 .02368 L
.16084 .02449 L
.16132 .0234 L
.16181 .02401 L
.16229 .02316 L
.16278 .02374 L
.16327 .02313 L
.16375 .02289 L
.16424 .02307 L
.16472 .02289 L
.16521 .02282 L
.16569 .02254 L
.16618 .0226 L
.16667 .02266 L
.16715 .02255 L
.16764 .02232 L
.16812 .02265 L
.16861 .02221 L
.1691 .02248 L
Mistroke
.16958 .02199 L
.17007 .02267 L
.17055 .02183 L
.17104 .02241 L
.17153 .0221 L
.17201 .02237 L
.1725 .02207 L
.17298 .02239 L
.17347 .02203 L
.17396 .02299 L
.17444 .02202 L
.17493 .02258 L
.17541 .02256 L
.1759 .02283 L
.17638 .02253 L
.17687 .02298 L
.17736 .02289 L
.17784 .02304 L
.17833 .02314 L
.17881 .02318 L
.1793 .02312 L
.17979 .02364 L
.18027 .02307 L
.18076 .02351 L
.18124 .02375 L
.18173 .02311 L
.18222 .02382 L
.1827 .02321 L
.18319 .0244 L
.18367 .02328 L
.18416 .02393 L
.18465 .024 L
.18513 .02402 L
.18562 .02389 L
.1861 .02442 L
.18659 .0237 L
.18707 .02453 L
.18756 .02431 L
.18805 .024 L
.18853 .02401 L
.18902 .02507 L
.1895 .0232 L
.18999 .02469 L
.19048 .02427 L
.19096 .02352 L
.19145 .02395 L
.19193 .02388 L
.19242 .02336 L
.19291 .02389 L
.19339 .02329 L
Mistroke
.19388 .02328 L
.19436 .02353 L
.19485 .02308 L
.19534 .02346 L
.19582 .02234 L
.19631 .02354 L
.19679 .02291 L
.19728 .02252 L
.19776 .02276 L
.19825 .02325 L
.19874 .02198 L
.19922 .02304 L
.19971 .02278 L
.20019 .02234 L
.20068 .0228 L
.20117 .02294 L
.20165 .02227 L
.20214 .02352 L
.20262 .02263 L
.20311 .02342 L
.2036 .02295 L
.20408 .02378 L
.20457 .02423 L
.20505 .02302 L
.20554 .02441 L
.20603 .02476 L
.20651 .02372 L
.207 .02501 L
.20748 .0248 L
.20797 .02459 L
.20845 .02516 L
.20894 .02507 L
.20943 .02516 L
.20991 .02498 L
.2104 .02545 L
.21088 .02513 L
.21137 .02524 L
.21186 .02495 L
.21234 .02636 L
.21283 .02403 L
.21331 .02554 L
.2138 .02563 L
.21429 .02469 L
.21477 .02479 L
.21526 .0251 L
.21574 .02445 L
.21623 .02493 L
.21672 .02389 L
.2172 .02483 L
.21769 .02376 L
Mistroke
.21817 .02361 L
.21866 .0246 L
.21914 .02298 L
.21963 .02336 L
.22012 .0239 L
.2206 .02282 L
.22109 .023 L
.22157 .02312 L
.22206 .02308 L
.22255 .02305 L
.22303 .02197 L
.22352 .02358 L
.224 .02261 L
.22449 .02247 L
.22498 .02262 L
.22546 .02308 L
.22595 .02193 L
.22643 .02321 L
.22692 .02247 L
.22741 .02263 L
.22789 .02259 L
.22838 .02257 L
.22886 .02344 L
.22935 .02213 L
.22983 .02297 L
.23032 .02386 L
.23081 .02235 L
.23129 .02337 L
.23178 .02364 L
.23226 .02346 L
.23275 .02388 L
.23324 .0229 L
.23372 .02486 L
.23421 .02354 L
.23469 .02388 L
.23518 .02462 L
.23567 .02399 L
.23615 .02395 L
.23664 .02494 L
.23712 .02421 L
.23761 .02475 L
.2381 .02395 L
.23858 .02529 L
.23907 .0248 L
.23955 .02403 L
.24004 .02503 L
.24052 .02535 L
.24101 .02398 L
.2415 .02483 L
.24198 .02456 L
Mistroke
.24247 .02493 L
.24295 .02444 L
.24344 .02385 L
.24393 .02534 L
.24441 .02367 L
.2449 .0244 L
.24538 .02478 L
.24587 .02418 L
.24636 .02409 L
.24684 .02481 L
.24733 .02439 L
.24781 .02553 L
.2483 .0234 L
.24879 .0262 L
.24927 .02515 L
.24976 .02458 L
.25024 .02572 L
.25073 .02532 L
.25121 .02626 L
.2517 .02507 L
.25219 .02556 L
.25267 .02665 L
.25316 .02551 L
.25364 .02583 L
.25413 .02661 L
.25462 .02553 L
.2551 .02618 L
.25559 .02555 L
.25607 .02656 L
.25656 .02557 L
.25705 .02504 L
.25753 .02552 L
.25802 .02595 L
.2585 .02383 L
.25899 .02507 L
.25948 .02408 L
.25996 .02462 L
.26045 .02339 L
.26093 .02288 L
.26142 .02431 L
.2619 .02259 L
.26239 .02277 L
.26288 .02282 L
.26336 .02241 L
.26385 .02257 L
.26433 .02202 L
.26482 .02235 L
.26531 .02298 L
.26579 .02096 L
.26628 .0229 L
Mistroke
.26676 .02204 L
.26725 .02239 L
.26774 .02204 L
.26822 .02204 L
.26871 .02337 L
.26919 .02243 L
.26968 .02215 L
.27017 .02361 L
.27065 .02319 L
.27114 .02366 L
.27162 .02332 L
.27211 .02371 L
.27259 .02496 L
.27308 .02336 L
.27357 .02491 L
.27405 .02476 L
.27454 .0248 L
.27502 .02461 L
.27551 .02514 L
.276 .02561 L
.27648 .02567 L
.27697 .02458 L
.27745 .0266 L
.27794 .02594 L
.27843 .02582 L
.27891 .02588 L
.2794 .02584 L
.27988 .02748 L
.28037 .02577 L
.28086 .02535 L
.28134 .0275 L
.28183 .02554 L
.28231 .02617 L
.2828 .02639 L
.28328 .02569 L
.28377 .02651 L
.28426 .02537 L
.28474 .02656 L
.28523 .0247 L
.28571 .02819 L
.2862 .02478 L
.28669 .02442 L
.28717 .03012 L
.28766 .02438 L
.28814 .02342 L
.28863 .03157 L
.28912 .02379 L
.2896 .02405 L
.29009 .03372 L
.29057 .02184 L
Mistroke
.29106 .02465 L
.29155 .03854 L
.29203 .02181 L
.29252 .02484 L
.293 .04923 L
.29349 .02215 L
.29397 .02864 L
.29446 .06244 L
.29495 .02495 L
.29543 .03669 L
.29592 .08404 L
.2964 .03302 L
.29689 .05566 L
.29738 .11662 L
.29786 .05067 L
.29835 .08575 L
.29883 .16659 L
.29932 .08622 L
.29981 .13136 L
.30029 .23564 L
.30078 .13814 L
.30126 .19436 L
.30175 .32399 L
.30224 .21114 L
.30272 .28139 L
.30321 .44097 L
.30369 .30148 L
.30418 .37462 L
.30466 .54449 L
.30515 .36782 L
.30564 .42953 L
.30612 .60321 L
.30661 .39588 L
.30709 .43411 L
.30758 .59645 L
.30807 .36574 L
.30855 .37625 L
.30904 .5116 L
.30952 .2799 L
.31001 .26122 L
.3105 .35405 L
.31098 .15133 L
.31147 .11501 L
.31195 .15976 L
.31244 .0447 L
.31293 .0246 L
.31341 .03512 L
.3139 .03842 L
.31438 .05242 L
.31487 .02531 L
Mistroke
.31535 .13833 L
.31584 .18525 L
.31633 .10614 L
.31681 .28249 L
.3173 .33056 L
.31778 .18424 L
.31827 .35313 L
.31876 .38117 L
.31924 .17869 L
.31973 .28531 L
.32021 .27979 L
.3207 .08426 L
.32119 .12542 L
.32167 .11048 L
.32216 .01837 L
.32264 .02476 L
.32313 .02386 L
.32362 .08766 L
.3241 .07728 L
.32459 .07964 L
.32507 .26206 L
.32556 .2124 L
.32604 .16979 L
.32653 .35572 L
.32702 .25393 L
.3275 .1477 L
.32799 .25571 L
.32847 .14569 L
.32896 .04209 L
.32945 .07458 L
.32993 .03731 L
.33042 .03028 L
.3309 .01919 L
.33139 .06934 L
.33188 .17414 L
.33236 .11462 L
.33285 .17982 L
.33333 .32127 L
.33382 .18567 L
.33431 .17548 L
.33479 .25539 L
.33528 .10301 L
.33576 .0491 L
.33625 .07006 L
.33673 .0309 L
.33722 .04018 L
.33771 .02253 L
.33819 .12238 L
.33868 .2056 L
.33916 .11137 L
Mistroke
.33965 .22591 L
.34014 .28865 L
.34062 .11663 L
.34111 .14649 L
.34159 .15811 L
.34208 .03311 L
.34257 .02271 L
.34305 .02276 L
.34354 .07668 L
.34402 .10057 L
.34451 .06859 L
.345 .22359 L
.34548 .2437 L
.34597 .11367 L
.34645 .20123 L
.34694 .18459 L
.34742 .03917 L
.34791 .04599 L
.3484 .03548 L
.34888 .05444 L
.34937 .06295 L
.34985 .05926 L
.35034 .22742 L
.35083 .20985 L
.35131 .11221 L
.3518 .23405 L
.35228 .1638 L
.35277 .03089 L
.35326 .05356 L
.35374 .03554 L
.35423 .06887 L
.35471 .0519 L
.3552 .08765 L
.35569 .24809 L
.35617 .16135 L
.35666 .11292 L
.35714 .21467 L
.35763 .10074 L
.35811 .02144 L
.3586 .03609 L
.35909 .03866 L
.35957 .09612 L
.36006 .06016 L
.36054 .13351 L
.36103 .26122 L
.36152 .13398 L
.362 .10725 L
.36249 .15729 L
.36297 .04826 L
.36346 .01755 L
Mistroke
.36395 .01493 L
.36443 .08393 L
.36492 .17012 L
.3654 .08932 L
.36589 .17325 L
.36638 .23988 L
.36686 .077 L
.36735 .05824 L
.36783 .06485 L
.36832 .03682 L
.3688 .0604 L
.36929 .03865 L
.36978 .17524 L
.37026 .23284 L
.37075 .09445 L
.37123 .13467 L
.37172 .13168 L
.37221 .02728 L
.37269 .01884 L
.37318 .01928 L
.37366 .12075 L
.37415 .16362 L
.37464 .08484 L
.37512 .18298 L
.37561 .18182 L
.37609 .03828 L
.37658 .03436 L
.37707 .0304 L
.37755 .0752 L
.37804 .0975 L
.37852 .06604 L
.37901 .21223 L
.37949 .20433 L
.37998 .05577 L
.38047 .07712 L
.38095 .05088 L
.38144 .04745 L
.38192 .05701 L
.38241 .06108 L
.3829 .21339 L
.38338 .18259 L
.38387 .06663 L
.38435 .10889 L
.38484 .06295 L
.38533 .02974 L
.38581 .03289 L
.3863 .05493 L
.38678 .20545 L
.38727 .16343 L
.38776 .07356 L
Mistroke
.38824 .13691 L
.38873 .07272 L
.38921 .0255 L
.3897 .02276 L
.39018 .05863 L
.39067 .20921 L
.39116 .14489 L
.39164 .07598 L
.39213 .15264 L
.39261 .06992 L
.3931 .02422 L
.39359 .01938 L
.39407 .06881 L
.39456 .20818 L
.39504 .12361 L
.39553 .07849 L
.39602 .14655 L
.3965 .05962 L
.39699 .02506 L
.39747 .01951 L
.39796 .07831 L
.39845 .21746 L
.39893 .12657 L
.39942 .07633 L
.3999 .12524 L
.40039 .04812 L
.40087 .03839 L
.40136 .02904 L
.40185 .0941 L
.40233 .22973 L
.40282 .12112 L
.4033 .05936 L
.40379 .0862 L
.40428 .03607 L
.40476 .06566 L
.40525 .04642 L
.40573 .11281 L
.40622 .22086 L
.40671 .09736 L
.40719 .03537 L
.40768 .04559 L
.40816 .04261 L
.40865 .10351 L
.40914 .07041 L
.40962 .11445 L
.41011 .20036 L
.41059 .07896 L
.41108 .01669 L
.41156 .01863 L
.41205 .06365 L
Mistroke
.41254 .16566 L
.41302 .09398 L
.41351 .0963 L
.41399 .15063 L
.41448 .05024 L
.41497 .02459 L
.41545 .01771 L
.41594 .09593 L
.41642 .21499 L
.41691 .09943 L
.4174 .06044 L
.41788 .08325 L
.41837 .04103 L
.41885 .08061 L
.41934 .05098 L
.41983 .11963 L
.42031 .21814 L
.4208 .08098 L
.42128 .0185 L
.42177 .02232 L
.42225 .0649 L
.42274 .17665 L
.42323 .09533 L
.42371 .09029 L
.4242 .1438 L
.42468 .04653 L
.42517 .04095 L
.42566 .02646 L
.42614 .10696 L
.42663 .22449 L
.42711 .09134 L
.4276 .03177 L
.42809 .04271 L
.42857 .05136 L
.42906 .13217 L
.42954 .07984 L
.43003 .10148 L
.43052 .16273 L
.431 .05537 L
.43149 .0247 L
.43197 .02022 L
.43246 .09095 L
.43294 .20639 L
.43343 .10036 L
.43392 .03551 L
.4344 .04854 L
.43489 .04337 L
.43537 .11366 L
.43586 .07852 L
.43635 .08822 L
Mistroke
.43683 .15884 L
.43732 .06146 L
.4378 .02475 L
.43829 .02338 L
.43878 .08302 L
.43926 .21557 L
.43975 .11745 L
.44023 .0276 L
.44072 .03556 L
.44121 .04062 L
.44169 .14494 L
.44218 .11295 L
.44266 .0678 L
.44315 .12951 L
.44363 .05968 L
.44412 .04934 L
.44461 .05018 L
.44509 .06754 L
.44558 .20394 L
.44606 .12215 L
.44655 .01589 L
.44704 .01891 L
.44752 .04151 L
.44801 .18265 L
.44849 .14679 L
.44898 .04162 L
.44947 .06717 L
.44995 .04061 L
.45044 .09758 L
.45092 .10866 L
.45141 .06214 L
.4519 .14293 L
.45238 .09116 L
.45287 .03436 L
.45335 .04543 L
.45384 .04461 L
.45432 .17869 L
.45481 .15646 L
.4553 .02514 L
.45578 .01939 L
.45627 .02448 L
.45675 .14604 L
.45724 .17017 L
.45773 .04677 L
.45821 .05579 L
.4587 .0421 L
.45918 .08493 L
.45967 .13222 L
.46016 .05835 L
.46064 .1049 L
Mistroke
.46113 .09536 L
.46161 .04424 L
.4621 .07562 L
.46259 .04524 L
.46307 .13276 L
.46356 .16709 L
.46404 .04115 L
.46453 .02884 L
.46501 .02139 L
.4655 .12215 L
.46599 .21139 L
.46647 .06695 L
.46696 .01774 L
.46744 .0159 L
.46793 .08286 L
.46842 .20091 L
.4689 .09689 L
.46939 .03166 L
.46987 .0359 L
.47036 .04932 L
.47085 .15744 L
.47133 .11055 L
.47182 .05036 L
.4723 .07745 L
.47279 .04426 L
.47328 .10435 L
.47376 .09564 L
.47425 .05903 L
.47473 .12502 L
.47522 .06577 L
.4757 .05886 L
.47619 .06657 L
.47668 .05441 L
.47716 .15736 L
.47765 .10441 L
.47813 .03269 L
.47862 .04236 L
.47911 .0412 L
.47959 .16921 L
.48008 .15481 L
.48056 .02928 L
.48105 .02631 L
.48154 .02487 L
.48202 .15556 L
.48251 .19379 L
.48299 .04252 L
.48348 .01886 L
.48397 .01566 L
.48445 .11887 L
.48494 .20291 L
Mistroke
.48542 .06483 L
.48591 .01824 L
.48639 .01807 L
.48688 .08082 L
.48737 .19808 L
.48785 .09591 L
.48834 .02231 L
.48882 .02595 L
.48931 .05516 L
.4898 .18947 L
.49028 .12559 L
.49077 .02873 L
.49125 .03559 L
.49174 .03961 L
.49223 .16612 L
.49271 .14007 L
.4932 .03489 L
.49368 .04495 L
.49417 .03147 L
.49466 .13074 L
.49514 .14987 L
.49563 .04438 L
.49611 .05004 L
.4966 .03227 L
.49708 .10108 L
.49757 .1675 L
.49806 .06116 L
.49854 .04807 L
.49903 .04014 L
.49951 .08047 L
.5 .17845 L
.50049 .08046 L
.50097 .04014 L
.50146 .04805 L
.50194 .06115 L
.50243 .16748 L
.50292 .10108 L
.5034 .03226 L
.50389 .05003 L
.50437 .04438 L
.50486 .14987 L
.50534 .13076 L
.50583 .03147 L
.50632 .04497 L
.5068 .03489 L
.50729 .14009 L
.50777 .16613 L
.50826 .03961 L
.50875 .0356 L
.50923 .02872 L
Mistroke
.50972 .12559 L
.5102 .18944 L
.51069 .05516 L
.51118 .02594 L
.51166 .02231 L
.51215 .09589 L
.51263 .19808 L
.51312 .08083 L
.51361 .01807 L
.51409 .01825 L
.51458 .06483 L
.51506 .20293 L
.51555 .11888 L
.51603 .01566 L
.51652 .01886 L
.51701 .04253 L
.51749 .19381 L
.51798 .15554 L
.51846 .02487 L
.51895 .02631 L
.51944 .02928 L
.51992 .15478 L
.52041 .16919 L
.52089 .04122 L
.52138 .04236 L
.52187 .03268 L
.52235 .10439 L
.52284 .15738 L
.52332 .05443 L
.52381 .06657 L
.5243 .05885 L
.52478 .06579 L
.52527 .12504 L
.52575 .05901 L
.52624 .09563 L
.52672 .10436 L
.52721 .04428 L
.5277 .07743 L
.52818 .05035 L
.52867 .11056 L
.52915 .15745 L
.52964 .04931 L
.53013 .03589 L
.53061 .03167 L
.5311 .0969 L
.53158 .2009 L
.53207 .08286 L
.53256 .0159 L
.53304 .01774 L
.53353 .06695 L
Mistroke
.53401 .21138 L
.5345 .12215 L
.53499 .02139 L
.53547 .02884 L
.53596 .04116 L
.53644 .16709 L
.53693 .13276 L
.53741 .04525 L
.5379 .07564 L
.53839 .04423 L
.53887 .09536 L
.53936 .1049 L
.53984 .05837 L
.54033 .13221 L
.54082 .08491 L
.5413 .0421 L
.54179 .05579 L
.54227 .04677 L
.54276 .17014 L
.54325 .14604 L
.54373 .02449 L
.54422 .01939 L
.5447 .02513 L
.54519 .15646 L
.54568 .17871 L
.54616 .04461 L
.54665 .04544 L
.54713 .03436 L
.54762 .09117 L
.5481 .14293 L
.54859 .06214 L
.54908 .10866 L
.54956 .09756 L
.55005 .04061 L
.55053 .06716 L
.55102 .04162 L
.55151 .14677 L
.55199 .18265 L
.55248 .04152 L
.55296 .01891 L
.55345 .01589 L
.55394 .12215 L
.55442 .20397 L
.55491 .06754 L
.55539 .05019 L
.55588 .04934 L
.55637 .05969 L
.55685 .12951 L
.55734 .06778 L
.55782 .11295 L
Mistroke
.55831 .14494 L
.55879 .04062 L
.55928 .03555 L
.55977 .0276 L
.56025 .11745 L
.56074 .21557 L
.56122 .08303 L
.56171 .02339 L
.5622 .02475 L
.56268 .06146 L
.56317 .15885 L
.56365 .08822 L
.56414 .07851 L
.56463 .11365 L
.56511 .04338 L
.5656 .04854 L
.56608 .0355 L
.56657 .10036 L
.56706 .20639 L
.56754 .09095 L
.56803 .02023 L
.56851 .0247 L
.569 .05537 L
.56948 .16273 L
.56997 .10148 L
.57046 .07984 L
.57094 .13215 L
.57143 .05135 L
.57191 .04271 L
.5724 .03177 L
.57289 .09133 L
.57337 .22448 L
.57386 .10698 L
.57434 .02646 L
.57483 .04095 L
.57532 .04653 L
.5758 .14382 L
.57629 .09029 L
.57677 .09533 L
.57726 .17666 L
.57775 .0649 L
.57823 .02232 L
.57872 .0185 L
.5792 .08098 L
.57969 .21813 L
.58017 .11962 L
.58066 .05098 L
.58115 .08061 L
.58163 .04102 L
.58212 .08325 L
Mistroke
.5826 .06045 L
.58309 .09943 L
.58358 .21499 L
.58406 .09593 L
.58455 .01771 L
.58503 .02459 L
.58552 .05024 L
.58601 .15064 L
.58649 .0963 L
.58698 .09397 L
.58746 .16567 L
.58795 .06365 L
.58844 .01863 L
.58892 .01668 L
.58941 .07896 L
.58989 .20036 L
.59038 .11444 L
.59086 .07041 L
.59135 .10351 L
.59184 .04261 L
.59232 .04559 L
.59281 .03537 L
.59329 .09735 L
.59378 .22085 L
.59427 .11281 L
.59475 .04642 L
.59524 .06566 L
.59572 .03607 L
.59621 .08621 L
.5967 .05937 L
.59718 .12111 L
.59767 .22975 L
.59815 .0941 L
.59864 .02904 L
.59913 .0384 L
.59961 .04813 L
.6001 .12524 L
.60058 .07632 L
.60107 .12658 L
.60155 .21746 L
.60204 .0783 L
.60253 .01951 L
.60301 .02506 L
.6035 .05961 L
.60398 .14654 L
.60447 .07849 L
.60496 .12361 L
.60544 .20817 L
.60593 .06882 L
.60641 .01937 L
Mistroke
.6069 .02422 L
.60739 .06991 L
.60787 .15264 L
.60836 .07598 L
.60884 .14488 L
.60933 .20922 L
.60982 .05863 L
.6103 .02276 L
.61079 .02551 L
.61127 .07273 L
.61176 .13691 L
.61224 .07355 L
.61273 .16345 L
.61322 .20545 L
.6137 .05492 L
.61419 .03289 L
.61467 .02973 L
.61516 .06295 L
.61565 .10888 L
.61613 .06664 L
.61662 .18258 L
.6171 .21337 L
.61759 .06109 L
.61808 .057 L
.61856 .04744 L
.61905 .05088 L
.61953 .07713 L
.62002 .05577 L
.62051 .20432 L
.62099 .21225 L
.62148 .06604 L
.62196 .0975 L
.62245 .07521 L
.62293 .0304 L
.62342 .03436 L
.62391 .03828 L
.62439 .18184 L
.62488 .18298 L
.62536 .08483 L
.62585 .16364 L
.62634 .12074 L
.62682 .01928 L
.62731 .01884 L
.62779 .02728 L
.62828 .13167 L
.62877 .13466 L
.62925 .09446 L
.62974 .23282 L
.63022 .17524 L
.63071 .03865 L
Mistroke
.6312 .06039 L
.63168 .03681 L
.63217 .06485 L
.63265 .05825 L
.63314 .07699 L
.63362 .23988 L
.63411 .17327 L
.6346 .08931 L
.63508 .17013 L
.63557 .08393 L
.63605 .01493 L
.63654 .01755 L
.63703 .04827 L
.63751 .1573 L
.638 .10724 L
.63848 .13398 L
.63897 .26123 L
.63946 .13349 L
.63994 .06016 L
.64043 .09613 L
.64091 .03866 L
.6414 .03609 L
.64189 .02144 L
.64237 .10074 L
.64286 .21465 L
.64334 .11292 L
.64383 .16135 L
.64431 .24808 L
.6448 .08766 L
.64529 .05189 L
.64577 .06886 L
.64626 .03554 L
.64674 .05356 L
.64723 .03089 L
.64772 .1638 L
.6482 .23406 L
.64869 .1122 L
.64917 .20985 L
.64966 .22743 L
.65015 .05925 L
.65063 .06295 L
.65112 .05445 L
.6516 .03548 L
.65209 .04599 L
.65258 .03917 L
.65306 .18459 L
.65355 .20122 L
.65403 .11367 L
.65452 .2437 L
.655 .22358 L
Mistroke
.65549 .06859 L
.65598 .10057 L
.65646 .07668 L
.65695 .02276 L
.65743 .02271 L
.65792 .03311 L
.65841 .15811 L
.65889 .1465 L
.65938 .11662 L
.65986 .28865 L
.66035 .22592 L
.66084 .11136 L
.66132 .20561 L
.66181 .12239 L
.66229 .02252 L
.66278 .04018 L
.66327 .03091 L
.66375 .07007 L
.66424 .0491 L
.66472 .10302 L
.66521 .25538 L
.66569 .17546 L
.66618 .18568 L
.66667 .32126 L
.66715 .17981 L
.66764 .11463 L
.66812 .17411 L
.66861 .06933 L
.6691 .01919 L
.66958 .03028 L
.67007 .0373 L
.67055 .07458 L
.67104 .0421 L
.67153 .14567 L
.67201 .25571 L
.6725 .14771 L
.67298 .25389 L
.67347 .35575 L
.67396 .16979 L
.67444 .21237 L
.67493 .26209 L
.67541 .07963 L
.6759 .07728 L
.67638 .08768 L
.67687 .02387 L
.67736 .02476 L
.67784 .01837 L
.67833 .11051 L
.67881 .12541 L
.6793 .08425 L
Mistroke
.67979 .27983 L
.68027 .28527 L
.68076 .1787 L
.68124 .38121 L
.68173 .35307 L
.68222 .18426 L
.6827 .33056 L
.68319 .28244 L
.68367 .10617 L
.68416 .18523 L
.68465 .1383 L
.68513 .02532 L
.68562 .0524 L
.6861 .0384 L
.68659 .03511 L
.68707 .0246 L
.68756 .04468 L
.68805 .15974 L
.68853 .11505 L
.68902 .15128 L
.6895 .35405 L
.68999 .26128 L
.69048 .27983 L
.69096 .51164 L
.69145 .3763 L
.69193 .36566 L
.69242 .59655 L
.69291 .43411 L
.69339 .39582 L
.69388 .60332 L
.69436 .42948 L
.69485 .36779 L
.69534 .54459 L
.69582 .37454 L
.69631 .3015 L
.69679 .44104 L
.69728 .2813 L
.69776 .2112 L
.69825 .324 L
.69874 .19429 L
.69922 .1382 L
.69971 .23561 L
.70019 .13132 L
.70068 .08626 L
.70117 .16653 L
.70165 .08573 L
.70214 .05069 L
.70262 .11656 L
.70311 .05565 L
.7036 .03302 L
Mistroke
.70408 .08399 L
.70457 .03669 L
.70505 .02494 L
.70554 .06241 L
.70603 .02865 L
.70651 .02213 L
.707 .04922 L
.70748 .02485 L
.70797 .0218 L
.70845 .03855 L
.70894 .02467 L
.70943 .02185 L
.70991 .03374 L
.7104 .02407 L
.71088 .0238 L
.71137 .0316 L
.71186 .02344 L
.71234 .0244 L
.71283 .03015 L
.71331 .02444 L
.7138 .0248 L
.71429 .02821 L
.71477 .02472 L
.71526 .02658 L
.71574 .02538 L
.71623 .02652 L
.71672 .02569 L
.7172 .02639 L
.71769 .02616 L
.71817 .02553 L
.71866 .02749 L
.71914 .02533 L
.71963 .02576 L
.72012 .02746 L
.7206 .02582 L
.72109 .02586 L
.72157 .0258 L
.72206 .02592 L
.72255 .02658 L
.72303 .02456 L
.72352 .02565 L
.724 .02559 L
.72449 .02512 L
.72498 .02459 L
.72546 .02479 L
.72595 .02475 L
.72643 .0249 L
.72692 .02336 L
.72741 .02496 L
.72789 .02371 L
Mistroke
.72838 .02332 L
.72886 .02367 L
.72935 .0232 L
.72983 .02362 L
.73032 .02216 L
.73081 .02245 L
.73129 .02339 L
.73178 .02205 L
.73226 .02206 L
.73275 .02241 L
.73324 .02205 L
.73372 .02292 L
.73421 .02097 L
.73469 .023 L
.73518 .02236 L
.73567 .02203 L
.73615 .02257 L
.73664 .02241 L
.73712 .02282 L
.73761 .02277 L
.7381 .02258 L
.73858 .0243 L
.73907 .02288 L
.73955 .02338 L
.74004 .0246 L
.74052 .02406 L
.74101 .02506 L
.7415 .02381 L
.74198 .02593 L
.74247 .0255 L
.74295 .02502 L
.74344 .02555 L
.74393 .02653 L
.74441 .02553 L
.7449 .02616 L
.74538 .02551 L
.74587 .02659 L
.74636 .02581 L
.74684 .0255 L
.74733 .02664 L
.74781 .02556 L
.7483 .02507 L
.74879 .02626 L
.74927 .02533 L
.74976 .02573 L
.75024 .02459 L
.75073 .02516 L
.75121 .02622 L
.7517 .02342 L
.75219 .02554 L
Mistroke
.75267 .02441 L
.75316 .02483 L
.75364 .02411 L
.75413 .0242 L
.75462 .0248 L
.7551 .02442 L
.75559 .02369 L
.75607 .02536 L
.75656 .02387 L
.75705 .02445 L
.75753 .02494 L
.75802 .02457 L
.7585 .02484 L
.75899 .02399 L
.75948 .02535 L
.75996 .02503 L
.76045 .02403 L
.76093 .02479 L
.76142 .02528 L
.7619 .02394 L
.76239 .02474 L
.76288 .0242 L
.76336 .02492 L
.76385 .02394 L
.76433 .02398 L
.76482 .02461 L
.76531 .02387 L
.76579 .02352 L
.76628 .02484 L
.76676 .02289 L
.76725 .02386 L
.76774 .02344 L
.76822 .02363 L
.76871 .02336 L
.76919 .02234 L
.76968 .02385 L
.77017 .02296 L
.77065 .02213 L
.77114 .02344 L
.77162 .02257 L
.77211 .02259 L
.77259 .02263 L
.77308 .02247 L
.77357 .02321 L
.77405 .02193 L
.77454 .02308 L
.77502 .02263 L
.77551 .02248 L
.776 .02262 L
.77648 .02359 L
Mistroke
.77697 .02198 L
.77745 .02307 L
.77794 .02309 L
.77843 .02314 L
.77891 .02302 L
.7794 .02284 L
.77988 .02392 L
.78037 .02337 L
.78086 .02299 L
.78134 .02461 L
.78183 .02362 L
.78231 .02377 L
.7828 .02484 L
.78328 .0239 L
.78377 .02493 L
.78426 .02445 L
.78474 .0251 L
.78523 .02479 L
.78571 .02469 L
.7862 .02563 L
.78669 .02553 L
.78717 .02402 L
.78766 .02634 L
.78814 .02494 L
.78863 .02522 L
.78912 .02512 L
.7896 .02544 L
.79009 .02496 L
.79057 .02515 L
.79106 .02505 L
.79155 .02514 L
.79203 .02458 L
.79252 .02478 L
.793 .025 L
.79349 .02371 L
.79397 .02475 L
.79446 .0244 L
.79495 .02302 L
.79543 .02423 L
.79592 .02378 L
.7964 .02295 L
.79689 .02342 L
.79738 .02263 L
.79786 .02352 L
.79835 .02227 L
.79883 .02294 L
.79932 .0228 L
.79981 .02234 L
.80029 .02278 L
.80078 .02304 L
Mistroke
.80126 .02198 L
.80175 .02326 L
.80224 .02277 L
.80272 .02253 L
.80321 .02292 L
.80369 .02355 L
.80418 .02235 L
.80466 .02347 L
.80515 .02309 L
.80564 .02354 L
.80612 .02329 L
.80661 .0233 L
.80709 .0239 L
.80758 .02337 L
.80807 .02389 L
.80855 .02396 L
.80904 .02353 L
.80952 .02427 L
.81001 .02469 L
.8105 .0232 L
.81098 .02507 L
.81147 .02401 L
.81195 .024 L
.81244 .02431 L
.81293 .02453 L
.81341 .0237 L
.8139 .02442 L
.81438 .02389 L
.81487 .02402 L
.81535 .024 L
.81584 .02392 L
.81633 .02328 L
.81681 .02439 L
.8173 .0232 L
.81778 .02381 L
.81827 .02311 L
.81876 .02374 L
.81924 .0235 L
.81973 .02306 L
.82021 .02363 L
.8207 .02312 L
.82119 .02317 L
.82167 .02313 L
.82216 .02303 L
.82264 .02288 L
.82313 .02297 L
.82362 .02253 L
.8241 .02283 L
.82459 .02256 L
.82507 .02257 L
Mistroke
.82556 .02202 L
.82604 .02299 L
.82653 .02203 L
.82702 .02239 L
.8275 .02207 L
.82799 .02237 L
.82847 .02211 L
.82896 .02241 L
.82945 .02184 L
.82993 .02267 L
.83042 .022 L
.8309 .02249 L
.83139 .02221 L
.83188 .02265 L
.83236 .02233 L
.83285 .02256 L
.83333 .02266 L
.83382 .02261 L
.83431 .02254 L
.83479 .02282 L
.83528 .0229 L
.83576 .02307 L
.83625 .0229 L
.83673 .02313 L
.83722 .02375 L
.83771 .02317 L
.83819 .02401 L
.83868 .02341 L
.83916 .0245 L
.83965 .02368 L
.84014 .0244 L
.84062 .02429 L
.84111 .02451 L
.84159 .02452 L
.84208 .02464 L
.84257 .02469 L
.84305 .02481 L
.84354 .02447 L
.84402 .02522 L
.84451 .02445 L
.845 .02486 L
.84548 .0243 L
.84597 .02499 L
.84645 .02436 L
.84694 .02455 L
.84742 .02424 L
.84791 .02479 L
.8484 .02405 L
.84888 .02455 L
.84937 .02409 L
Mistroke
.84985 .02456 L
.85034 .02398 L
.85083 .02413 L
.85131 .02405 L
.8518 .02384 L
.85228 .02377 L
.85277 .0238 L
.85326 .02349 L
.85374 .02346 L
.85423 .02317 L
.85471 .02351 L
.8552 .02315 L
.85569 .0228 L
.85617 .02316 L
.85666 .02264 L
.85714 .02299 L
.85763 .02222 L
.85811 .02281 L
.8586 .02232 L
.85909 .02233 L
.85957 .02211 L
.86006 .02237 L
.86054 .02193 L
.86103 .02233 L
.86152 .02167 L
.862 .02237 L
.86249 .02139 L
.86297 .02221 L
.86346 .0216 L
.86395 .0218 L
.86443 .02136 L
.86492 .02169 L
.8654 .02148 L
.86589 .02148 L
.86638 .02122 L
.86686 .02167 L
.86735 .02132 L
.86783 .02144 L
.86832 .02147 L
.8688 .02165 L
.86929 .02157 L
.86978 .02163 L
.87026 .02168 L
.87075 .02193 L
.87123 .02169 L
.87172 .02219 L
.87221 .02199 L
.87269 .02203 L
.87318 .02245 L
.87366 .02225 L
Mistroke
.87415 .02282 L
.87464 .02212 L
.87512 .02314 L
.87561 .0226 L
.87609 .02298 L
.87658 .0228 L
.87707 .02328 L
.87755 .0229 L
.87804 .02329 L
.87852 .02297 L
.87901 .02375 L
.87949 .02295 L
.87998 .02384 L
.88047 .02328 L
.88095 .02383 L
.88144 .02361 L
.88192 .02406 L
.88241 .02365 L
.8829 .02401 L
.88338 .02383 L
.88387 .02434 L
.88435 .02359 L
.88484 .02424 L
.88533 .02394 L
.88581 .0241 L
.8863 .02384 L
.88678 .02428 L
.88727 .02393 L
.88776 .02423 L
.88824 .02382 L
.88873 .02453 L
.88921 .02384 L
.8897 .02438 L
.89018 .02411 L
.89067 .0241 L
.89116 .02428 L
.89164 .02426 L
.89213 .02418 L
.89261 .02416 L
.8931 .02412 L
.89359 .02456 L
.89407 .02381 L
.89456 .02433 L
.89504 .0241 L
.89553 .02397 L
.89602 .02395 L
.8965 .02376 L
.89699 .02387 L
.89747 .02332 L
.89796 .02351 L
Mistroke
.89845 .02313 L
.89893 .02317 L
.89942 .02272 L
.8999 .02298 L
.90039 .02222 L
.90087 .02269 L
.90136 .02224 L
.90185 .02221 L
.90233 .02187 L
.90282 .02208 L
.9033 .02176 L
.90379 .02177 L
.90428 .02134 L
.90476 .02186 L
.90525 .02097 L
.90573 .02154 L
.90622 .02098 L
.90671 .02119 L
.90719 .02083 L
.90768 .02105 L
.90816 .02065 L
.90865 .021 L
.90914 .0205 L
.90962 .02097 L
.91011 .02026 L
.91059 .021 L
.91108 .02045 L
.91156 .02058 L
.91205 .02046 L
.91254 .02073 L
.91302 .0204 L
.91351 .02062 L
.91399 .02049 L
.91448 .02066 L
.91497 .02054 L
.91545 .02076 L
.91594 .02069 L
.91642 .02081 L
.91691 .02078 L
.9174 .02104 L
.91788 .02071 L
.91837 .02129 L
.91885 .02086 L
.91934 .02103 L
.91983 .02122 L
.92031 .02108 L
.9208 .02114 L
.92128 .02105 L
.92177 .02128 L
.92225 .02123 L
Mistroke
.92274 .02118 L
.92323 .02144 L
.92371 .02135 L
.9242 .02156 L
.92468 .02171 L
.92517 .02164 L
.92566 .02194 L
.92614 .02205 L
.92663 .02214 L
.92711 .02225 L
.9276 .02272 L
.92809 .02233 L
.92857 .02301 L
.92906 .02282 L
.92954 .02336 L
.93003 .02303 L
.93052 .02362 L
.931 .02352 L
.93149 .02397 L
.93197 .02376 L
.93246 .02442 L
.93294 .02396 L
.93343 .0249 L
.93392 .0242 L
.9344 .02481 L
.93489 .02471 L
.93537 .02494 L
.93586 .02474 L
.93635 .02533 L
.93683 .02484 L
.93732 .02534 L
.9378 .02506 L
.93829 .02557 L
.93878 .02506 L
.93926 .02577 L
.93975 .02501 L
.94023 .02605 L
.94072 .02508 L
.94121 .02584 L
.94169 .02521 L
.94218 .02585 L
.94266 .02519 L
.94315 .02543 L
.94363 .02511 L
.94412 .02533 L
.94461 .02477 L
.94509 .02522 L
.94558 .02457 L
.94606 .02504 L
.94655 .02439 L
Mistroke
.94704 .0249 L
.94752 .02427 L
.94801 .02474 L
.94849 .02411 L
.94898 .02465 L
.94947 .02407 L
.94995 .0243 L
.95044 .024 L
.95092 .02438 L
.95141 .02375 L
.9519 .02415 L
.95238 .02358 L
.95287 .02405 L
.95335 .02342 L
.95384 .02371 L
.95432 .02332 L
.95481 .02352 L
.9553 .02308 L
.95578 .0233 L
.95627 .02294 L
.95675 .02304 L
.95724 .02263 L
.95773 .02283 L
.95821 .02229 L
.9587 .02242 L
.95918 .02207 L
.95967 .02215 L
.96016 .02182 L
.96064 .02168 L
.96113 .02174 L
.96161 .02154 L
.9621 .0215 L
.96259 .02134 L
.96307 .02137 L
.96356 .0213 L
.96404 .02109 L
.96453 .02129 L
.96501 .021 L
.9655 .02122 L
.96599 .02088 L
.96647 .02114 L
.96696 .02083 L
.96744 .02097 L
.96793 .02082 L
.96842 .02085 L
.9689 .02063 L
.96939 .02076 L
.96987 .02067 L
.97036 .02073 L
.97085 .02054 L
Mistroke
.97133 .02074 L
.97182 .02068 L
.9723 .02067 L
.97279 .02067 L
.97328 .02072 L
.97376 .02069 L
.97425 .02062 L
.97473 .02062 L
.97522 .02067 L
.9757 .02053 L
.97619 .02063 L
Mfstroke
1 0 0 r
.02381 .01472 m
.0243 .01472 L
.02478 .01472 L
.02527 .01472 L
.02575 .01472 L
.02624 .01472 L
.02672 .01472 L
.02721 .01472 L
.0277 .01472 L
.02818 .01472 L
.02867 .01472 L
.02915 .01472 L
.02964 .01472 L
.03013 .01472 L
.03061 .01472 L
.0311 .01472 L
.03158 .01472 L
.03207 .01472 L
.03256 .01472 L
.03304 .01472 L
.03353 .01472 L
.03401 .01472 L
.0345 .01472 L
.03499 .01472 L
.03547 .01472 L
.03596 .01472 L
.03644 .01472 L
.03693 .01472 L
.03741 .01472 L
.0379 .01472 L
.03839 .01472 L
.03887 .01472 L
.03936 .01472 L
.03984 .01472 L
.04033 .01472 L
.04082 .01472 L
.0413 .01472 L
.04179 .01472 L
.04227 .01472 L
.04276 .01472 L
.04325 .01472 L
.04373 .01472 L
.04422 .01472 L
.0447 .01472 L
.04519 .01472 L
.04568 .01472 L
.04616 .01472 L
.04665 .01472 L
.04713 .01472 L
.04762 .01472 L
Mistroke
.0481 .01472 L
.04859 .01472 L
.04908 .01472 L
.04956 .01472 L
.05005 .01472 L
.05053 .01472 L
.05102 .01472 L
.05151 .01472 L
.05199 .01472 L
.05248 .01472 L
.05296 .01472 L
.05345 .01472 L
.05394 .01472 L
.05442 .01472 L
.05491 .01472 L
.05539 .01472 L
.05588 .01472 L
.05637 .01472 L
.05685 .01472 L
.05734 .01472 L
.05782 .01472 L
.05831 .01472 L
.05879 .01472 L
.05928 .01472 L
.05977 .01472 L
.06025 .01472 L
.06074 .01472 L
.06122 .01472 L
.06171 .01472 L
.0622 .01472 L
.06268 .01472 L
.06317 .01472 L
.06365 .01472 L
.06414 .01472 L
.06463 .01472 L
.06511 .01472 L
.0656 .01472 L
.06608 .01472 L
.06657 .01472 L
.06706 .01472 L
.06754 .01472 L
.06803 .01472 L
.06851 .01472 L
.069 .01472 L
.06948 .01472 L
.06997 .01472 L
.07046 .01472 L
.07094 .01472 L
.07143 .01472 L
.07191 .01472 L
Mistroke
.0724 .01472 L
.07289 .01472 L
.07337 .01472 L
.07386 .01472 L
.07434 .01472 L
.07483 .01472 L
.07532 .01472 L
.0758 .01472 L
.07629 .01472 L
.07677 .01472 L
.07726 .01472 L
.07775 .01472 L
.07823 .01472 L
.07872 .01472 L
.0792 .01472 L
.07969 .01472 L
.08017 .01472 L
.08066 .01472 L
.08115 .01472 L
.08163 .01472 L
.08212 .01472 L
.0826 .01472 L
.08309 .01472 L
.08358 .01472 L
.08406 .01472 L
.08455 .01472 L
.08503 .01472 L
.08552 .01472 L
.08601 .01472 L
.08649 .01472 L
.08698 .01472 L
.08746 .01472 L
.08795 .01472 L
.08844 .01472 L
.08892 .01472 L
.08941 .01472 L
.08989 .01472 L
.09038 .01472 L
.09086 .01472 L
.09135 .01472 L
.09184 .01472 L
.09232 .01472 L
.09281 .01472 L
.09329 .01472 L
.09378 .01472 L
.09427 .01472 L
.09475 .01472 L
.09524 .01472 L
.09572 .01472 L
.09621 .01472 L
Mistroke
.0967 .01472 L
.09718 .01472 L
.09767 .01472 L
.09815 .01472 L
.09864 .01472 L
.09913 .01472 L
.09961 .01472 L
.1001 .01472 L
.10058 .01472 L
.10107 .01472 L
.10155 .01472 L
.10204 .01472 L
.10253 .01472 L
.10301 .01472 L
.1035 .01472 L
.10398 .01472 L
.10447 .01472 L
.10496 .01472 L
.10544 .01472 L
.10593 .01472 L
.10641 .01472 L
.1069 .01472 L
.10739 .01472 L
.10787 .01472 L
.10836 .01472 L
.10884 .01472 L
.10933 .01472 L
.10982 .01472 L
.1103 .01472 L
.11079 .01472 L
.11127 .01472 L
.11176 .01472 L
.11224 .01472 L
.11273 .01472 L
.11322 .01472 L
.1137 .01472 L
.11419 .01472 L
.11467 .01472 L
.11516 .01472 L
.11565 .01472 L
.11613 .01472 L
.11662 .01472 L
.1171 .01472 L
.11759 .01472 L
.11808 .01472 L
.11856 .01472 L
.11905 .01472 L
.11953 .01472 L
.12002 .01472 L
.12051 .01472 L
Mistroke
.12099 .01472 L
.12148 .01472 L
.12196 .01472 L
.12245 .01472 L
.12293 .01472 L
.12342 .01472 L
.12391 .01472 L
.12439 .01472 L
.12488 .01472 L
.12536 .01472 L
.12585 .01472 L
.12634 .01472 L
.12682 .01472 L
.12731 .01472 L
.12779 .01472 L
.12828 .01472 L
.12877 .01472 L
.12925 .01472 L
.12974 .01472 L
.13022 .01472 L
.13071 .01472 L
.1312 .01472 L
.13168 .01472 L
.13217 .01472 L
.13265 .01472 L
.13314 .01472 L
.13362 .01472 L
.13411 .01472 L
.1346 .01472 L
.13508 .01472 L
.13557 .01472 L
.13605 .01472 L
.13654 .01472 L
.13703 .01472 L
.13751 .01472 L
.138 .01472 L
.13848 .01472 L
.13897 .01472 L
.13946 .01472 L
.13994 .01472 L
.14043 .01472 L
.14091 .01472 L
.1414 .01472 L
.14189 .01472 L
.14237 .01472 L
.14286 .01472 L
.14334 .01472 L
.14383 .01472 L
.14431 .01472 L
.1448 .01472 L
Mistroke
.14529 .01472 L
.14577 .01472 L
.14626 .01472 L
.14674 .01472 L
.14723 .01472 L
.14772 .01472 L
.1482 .01472 L
.14869 .01472 L
.14917 .01472 L
.14966 .01472 L
.15015 .01472 L
.15063 .01472 L
.15112 .01472 L
.1516 .01472 L
.15209 .01472 L
.15258 .01472 L
.15306 .01472 L
.15355 .01472 L
.15403 .01472 L
.15452 .01472 L
.155 .01472 L
.15549 .01472 L
.15598 .01472 L
.15646 .01472 L
.15695 .01472 L
.15743 .01472 L
.15792 .01472 L
.15841 .01472 L
.15889 .01472 L
.15938 .01472 L
.15986 .01472 L
.16035 .01472 L
.16084 .01472 L
.16132 .01472 L
.16181 .01472 L
.16229 .01472 L
.16278 .01472 L
.16327 .01472 L
.16375 .01472 L
.16424 .01472 L
.16472 .01472 L
.16521 .01472 L
.16569 .01472 L
.16618 .01472 L
.16667 .01472 L
.16715 .01472 L
.16764 .01472 L
.16812 .01472 L
.16861 .01472 L
.1691 .01472 L
Mistroke
.16958 .01472 L
.17007 .01472 L
.17055 .01472 L
.17104 .01472 L
.17153 .01472 L
.17201 .01472 L
.1725 .01472 L
.17298 .01472 L
.17347 .01472 L
.17396 .01472 L
.17444 .01472 L
.17493 .01472 L
.17541 .01472 L
.1759 .01472 L
.17638 .01472 L
.17687 .01472 L
.17736 .01472 L
.17784 .01472 L
.17833 .01472 L
.17881 .01472 L
.1793 .01472 L
.17979 .01472 L
.18027 .01472 L
.18076 .01472 L
.18124 .01472 L
.18173 .01472 L
.18222 .01472 L
.1827 .01472 L
.18319 .01472 L
.18367 .01472 L
.18416 .01472 L
.18465 .01472 L
.18513 .01472 L
.18562 .01472 L
.1861 .01472 L
.18659 .01472 L
.18707 .01472 L
.18756 .01472 L
.18805 .01472 L
.18853 .01472 L
.18902 .01472 L
.1895 .01472 L
.18999 .01472 L
.19048 .01472 L
.19096 .01472 L
.19145 .01472 L
.19193 .01472 L
.19242 .01472 L
.19291 .01472 L
.19339 .01472 L
Mistroke
.19388 .01472 L
.19436 .01472 L
.19485 .01472 L
.19534 .01472 L
.19582 .01472 L
.19631 .01472 L
.19679 .01472 L
.19728 .01472 L
.19776 .01472 L
.19825 .01472 L
.19874 .01472 L
.19922 .01472 L
.19971 .01472 L
.20019 .01472 L
.20068 .01472 L
.20117 .01472 L
.20165 .01472 L
.20214 .01472 L
.20262 .01472 L
.20311 .01472 L
.2036 .01472 L
.20408 .01472 L
.20457 .01472 L
.20505 .01472 L
.20554 .01472 L
.20603 .01472 L
.20651 .01472 L
.207 .01472 L
.20748 .01472 L
.20797 .01472 L
.20845 .01472 L
.20894 .01472 L
.20943 .01472 L
.20991 .01472 L
.2104 .01472 L
.21088 .01472 L
.21137 .01472 L
.21186 .01472 L
.21234 .01472 L
.21283 .01472 L
.21331 .01472 L
.2138 .01472 L
.21429 .01472 L
.21477 .01472 L
.21526 .01472 L
.21574 .01472 L
.21623 .01472 L
.21672 .01472 L
.2172 .01472 L
.21769 .01472 L
Mistroke
.21817 .01472 L
.21866 .01472 L
.21914 .01472 L
.21963 .01472 L
.22012 .01472 L
.2206 .01472 L
.22109 .01472 L
.22157 .01472 L
.22206 .01472 L
.22255 .01472 L
.22303 .01472 L
.22352 .01472 L
.224 .01472 L
.22449 .01472 L
.22498 .01472 L
.22546 .01472 L
.22595 .01472 L
.22643 .01472 L
.22692 .01472 L
.22741 .01472 L
.22789 .01472 L
.22838 .01472 L
.22886 .01472 L
.22935 .01472 L
.22983 .01472 L
.23032 .01472 L
.23081 .01472 L
.23129 .01472 L
.23178 .01472 L
.23226 .01472 L
.23275 .01472 L
.23324 .01472 L
.23372 .01472 L
.23421 .01472 L
.23469 .01472 L
.23518 .01472 L
.23567 .01472 L
.23615 .01472 L
.23664 .01472 L
.23712 .01472 L
.23761 .01472 L
.2381 .01472 L
.23858 .01472 L
.23907 .01472 L
.23955 .01472 L
.24004 .01472 L
.24052 .01472 L
.24101 .01472 L
.2415 .01472 L
.24198 .01472 L
Mistroke
.24247 .01472 L
.24295 .01472 L
.24344 .01472 L
.24393 .01472 L
.24441 .01472 L
.2449 .01472 L
.24538 .01472 L
.24587 .01472 L
.24636 .01472 L
.24684 .01472 L
.24733 .01472 L
.24781 .01472 L
.2483 .01472 L
.24879 .01472 L
.24927 .01472 L
.24976 .01472 L
.25024 .01472 L
.25073 .01472 L
.25121 .01472 L
.2517 .01472 L
.25219 .01472 L
.25267 .01472 L
.25316 .01472 L
.25364 .01472 L
.25413 .01472 L
.25462 .01472 L
.2551 .01472 L
.25559 .01472 L
.25607 .01472 L
.25656 .01472 L
.25705 .01472 L
.25753 .01472 L
.25802 .01472 L
.2585 .01472 L
.25899 .01472 L
.25948 .01472 L
.25996 .01472 L
.26045 .01472 L
.26093 .01472 L
.26142 .01472 L
.2619 .01472 L
.26239 .01472 L
.26288 .01472 L
.26336 .01472 L
.26385 .01472 L
.26433 .01472 L
.26482 .01472 L
.26531 .01472 L
.26579 .01472 L
.26628 .01472 L
Mistroke
.26676 .01472 L
.26725 .01472 L
.26774 .01472 L
.26822 .01472 L
.26871 .01472 L
.26919 .01472 L
.26968 .01472 L
.27017 .01472 L
.27065 .01472 L
.27114 .01472 L
.27162 .01472 L
.27211 .01472 L
.27259 .01472 L
.27308 .01472 L
.27357 .01472 L
.27405 .01472 L
.27454 .01472 L
.27502 .01472 L
.27551 .01472 L
.276 .01472 L
.27648 .01472 L
.27697 .01472 L
.27745 .01472 L
.27794 .01472 L
.27843 .01472 L
.27891 .01472 L
.2794 .01472 L
.27988 .01472 L
.28037 .01472 L
.28086 .01472 L
.28134 .01472 L
.28183 .01472 L
.28231 .01472 L
.2828 .01472 L
.28328 .01472 L
.28377 .01472 L
.28426 .01472 L
.28474 .01472 L
.28523 .01472 L
.28571 .01472 L
.2862 .01472 L
.28669 .01472 L
.28717 .01472 L
.28766 .01472 L
.28814 .01472 L
.28863 .01472 L
.28912 .01472 L
.2896 .01472 L
.29009 .01472 L
.29057 .01472 L
Mistroke
.29106 .01472 L
.29155 .01472 L
.29203 .01472 L
.29252 .01472 L
.293 .01472 L
.29349 .01472 L
.29397 .01472 L
.29446 .01472 L
.29495 .01472 L
.29543 .01472 L
.29592 .01472 L
.2964 .01472 L
.29689 .01472 L
.29738 .01472 L
.29786 .01472 L
.29835 .01472 L
.29883 .01472 L
.29932 .01472 L
.29981 .01472 L
.30029 .01472 L
.30078 .01472 L
.30126 .01472 L
.30175 .01472 L
.30224 .01472 L
.30272 .01472 L
.30321 .01472 L
.30369 .01472 L
.30418 .01472 L
.30466 .01472 L
.30515 .01472 L
.30564 .01472 L
.30612 .01472 L
.30661 .01472 L
.30709 .01472 L
.30758 .01472 L
.30807 .01472 L
.30855 .01472 L
.30904 .01472 L
.30952 .01472 L
.31001 .01472 L
.3105 .01472 L
.31098 .01472 L
.31147 .01472 L
.31195 .01472 L
.31244 .01472 L
.31293 .01472 L
.31341 .01472 L
.3139 .01472 L
.31438 .01472 L
.31487 .01472 L
Mistroke
.31535 .01472 L
.31584 .01472 L
.31633 .01472 L
.31681 .01472 L
.3173 .01472 L
.31778 .01472 L
.31827 .01472 L
.31876 .01472 L
.31924 .01472 L
.31973 .01472 L
.32021 .01472 L
.3207 .01472 L
.32119 .01472 L
.32167 .01472 L
.32216 .01472 L
.32264 .01472 L
.32313 .01472 L
.32362 .01472 L
.3241 .01472 L
.32459 .01472 L
.32507 .01472 L
.32556 .01472 L
.32604 .01472 L
.32653 .01472 L
.32702 .01472 L
.3275 .01472 L
.32799 .01472 L
.32847 .01472 L
.32896 .01472 L
.32945 .01472 L
.32993 .01472 L
.33042 .01472 L
.3309 .01472 L
.33139 .01472 L
.33188 .01472 L
.33236 .01472 L
.33285 .01472 L
.33333 .01472 L
.33382 .01472 L
.33431 .01472 L
.33479 .01472 L
.33528 .01472 L
.33576 .01472 L
.33625 .01472 L
.33673 .01472 L
.33722 .01472 L
.33771 .01472 L
.33819 .01472 L
.33868 .01472 L
.33916 .01472 L
Mistroke
.33965 .01472 L
.34014 .01472 L
.34062 .01472 L
.34111 .01472 L
.34159 .01472 L
.34208 .01472 L
.34257 .01472 L
.34305 .01472 L
.34354 .01472 L
.34402 .01472 L
.34451 .01472 L
.345 .01472 L
.34548 .01472 L
.34597 .01472 L
.34645 .01472 L
.34694 .01472 L
.34742 .01472 L
.34791 .01472 L
.3484 .01472 L
.34888 .01472 L
.34937 .01472 L
.34985 .01472 L
.35034 .01472 L
.35083 .01472 L
.35131 .01472 L
.3518 .01472 L
.35228 .01472 L
.35277 .01472 L
.35326 .01472 L
.35374 .01472 L
.35423 .01472 L
.35471 .01472 L
.3552 .01472 L
.35569 .01472 L
.35617 .01472 L
.35666 .01472 L
.35714 .01472 L
.35763 .01472 L
.35811 .01472 L
.3586 .01472 L
.35909 .01472 L
.35957 .01472 L
.36006 .01472 L
.36054 .01472 L
.36103 .01472 L
.36152 .01472 L
.362 .01472 L
.36249 .01472 L
.36297 .01472 L
.36346 .01472 L
Mistroke
.36395 .01472 L
.36443 .01472 L
.36492 .01472 L
.3654 .01472 L
.36589 .01472 L
.36638 .01472 L
.36686 .01472 L
.36735 .01472 L
.36783 .01472 L
.36832 .01472 L
.3688 .01472 L
.36929 .01472 L
.36978 .01472 L
.37026 .01472 L
.37075 .01472 L
.37123 .01472 L
.37172 .01472 L
.37221 .01472 L
.37269 .01472 L
.37318 .01472 L
.37366 .01472 L
.37415 .01472 L
.37464 .01472 L
.37512 .01472 L
.37561 .01472 L
.37609 .01472 L
.37658 .01472 L
.37707 .01472 L
.37755 .01472 L
.37804 .01472 L
.37852 .01472 L
.37901 .01472 L
.37949 .01472 L
.37998 .01472 L
.38047 .01472 L
.38095 .01472 L
.38144 .01472 L
.38192 .01472 L
.38241 .01472 L
.3829 .01472 L
.38338 .01472 L
.38387 .01472 L
.38435 .01472 L
.38484 .01472 L
.38533 .01472 L
.38581 .01472 L
.3863 .01472 L
.38678 .01472 L
.38727 .01472 L
.38776 .01472 L
Mistroke
.38824 .01472 L
.38873 .01472 L
.38921 .01472 L
.3897 .01472 L
.39018 .01472 L
.39067 .01472 L
.39116 .01472 L
.39164 .01472 L
.39213 .01472 L
.39261 .01472 L
.3931 .01472 L
.39359 .01472 L
.39407 .01472 L
.39456 .01472 L
.39504 .01472 L
.39553 .01472 L
.39602 .01472 L
.3965 .01472 L
.39699 .01472 L
.39747 .01472 L
.39796 .01472 L
.39845 .01472 L
.39893 .01472 L
.39942 .01472 L
.3999 .01472 L
.40039 .01472 L
.40087 .01472 L
.40136 .01472 L
.40185 .01472 L
.40233 .01472 L
.40282 .01472 L
.4033 .01472 L
.40379 .01472 L
.40428 .01472 L
.40476 .01472 L
.40525 .01472 L
.40573 .01472 L
.40622 .01472 L
.40671 .01472 L
.40719 .01472 L
.40768 .01472 L
.40816 .01472 L
.40865 .01472 L
.40914 .01472 L
.40962 .01472 L
.41011 .01472 L
.41059 .01472 L
.41108 .01472 L
.41156 .01472 L
.41205 .01472 L
Mistroke
.41254 .01472 L
.41302 .01472 L
.41351 .01472 L
.41399 .01472 L
.41448 .01472 L
.41497 .01472 L
.41545 .01472 L
.41594 .01472 L
.41642 .01472 L
.41691 .01472 L
.4174 .01472 L
.41788 .01472 L
.41837 .01472 L
.41885 .01472 L
.41934 .01472 L
.41983 .01472 L
.42031 .01472 L
.4208 .01472 L
.42128 .01472 L
.42177 .01472 L
.42225 .01472 L
.42274 .01472 L
.42323 .01472 L
.42371 .01472 L
.4242 .01472 L
.42468 .01472 L
.42517 .01472 L
.42566 .01472 L
.42614 .01472 L
.42663 .01472 L
.42711 .01472 L
.4276 .01472 L
.42809 .01472 L
.42857 .01472 L
.42906 .01472 L
.42954 .01472 L
.43003 .01472 L
.43052 .01472 L
.431 .01472 L
.43149 .01472 L
.43197 .01472 L
.43246 .01472 L
.43294 .01472 L
.43343 .01472 L
.43392 .01472 L
.4344 .01472 L
.43489 .01472 L
.43537 .01473 L
.43586 .01472 L
.43635 .01473 L
Mistroke
.43683 .01472 L
.43732 .01473 L
.4378 .01472 L
.43829 .01473 L
.43878 .01472 L
.43926 .01473 L
.43975 .01472 L
.44023 .01473 L
.44072 .01472 L
.44121 .01473 L
.44169 .01472 L
.44218 .01473 L
.44266 .01472 L
.44315 .01473 L
.44363 .01472 L
.44412 .01473 L
.44461 .01472 L
.44509 .01473 L
.44558 .01472 L
.44606 .01473 L
.44655 .01472 L
.44704 .01473 L
.44752 .01472 L
.44801 .01473 L
.44849 .01472 L
.44898 .01473 L
.44947 .01472 L
.44995 .01473 L
.45044 .01472 L
.45092 .01473 L
.45141 .01472 L
.4519 .01473 L
.45238 .01472 L
.45287 .01473 L
.45335 .01472 L
.45384 .01474 L
.45432 .01472 L
.45481 .01474 L
.4553 .01472 L
.45578 .01474 L
.45627 .01472 L
.45675 .01474 L
.45724 .01472 L
.45773 .01474 L
.45821 .01472 L
.4587 .01474 L
.45918 .01472 L
.45967 .01474 L
.46016 .01472 L
.46064 .01474 L
Mistroke
.46113 .01472 L
.46161 .01475 L
.4621 .01472 L
.46259 .01475 L
.46307 .01472 L
.46356 .01475 L
.46404 .01472 L
.46453 .01475 L
.46501 .01472 L
.4655 .01475 L
.46599 .01472 L
.46647 .01476 L
.46696 .01472 L
.46744 .01476 L
.46793 .01472 L
.46842 .01476 L
.4689 .01472 L
.46939 .01477 L
.46987 .01472 L
.47036 .01477 L
.47085 .01472 L
.47133 .01477 L
.47182 .01472 L
.4723 .01478 L
.47279 .01472 L
.47328 .01478 L
.47376 .01472 L
.47425 .01479 L
.47473 .01472 L
.47522 .0148 L
.4757 .01472 L
.47619 .0148 L
.47668 .01472 L
.47716 .01481 L
.47765 .01472 L
.47813 .01482 L
.47862 .01472 L
.47911 .01483 L
.47959 .01472 L
.48008 .01485 L
.48056 .01472 L
.48105 .01486 L
.48154 .01472 L
.48202 .01488 L
.48251 .01472 L
.48299 .0149 L
.48348 .01472 L
.48397 .01492 L
.48445 .01472 L
.48494 .01495 L
Mistroke
.48542 .01472 L
.48591 .01498 L
.48639 .01472 L
.48688 .01503 L
.48737 .01472 L
.48785 .01508 L
.48834 .01472 L
.48882 .01515 L
.48931 .01472 L
.4898 .01524 L
.49028 .01472 L
.49077 .01536 L
.49125 .01472 L
.49174 .01552 L
.49223 .01472 L
.49271 .01575 L
.4932 .01472 L
.49368 .01609 L
.49417 .01472 L
.49466 .01665 L
.49514 .01472 L
.49563 .0176 L
.49611 .01472 L
.4966 .0195 L
.49708 .01472 L
.49757 .02411 L
.49806 .01472 L
.49854 .04092 L
.49903 .01472 L
.49951 .25476 L
.5 .60332 L
.50049 .25476 L
.50097 .01472 L
.50146 .04092 L
.50194 .01472 L
.50243 .02411 L
.50292 .01472 L
.5034 .0195 L
.50389 .01472 L
.50437 .0176 L
.50486 .01472 L
.50534 .01665 L
.50583 .01472 L
.50632 .01609 L
.5068 .01472 L
.50729 .01575 L
.50777 .01472 L
.50826 .01552 L
.50875 .01472 L
.50923 .01536 L
Mistroke
.50972 .01472 L
.5102 .01524 L
.51069 .01472 L
.51118 .01515 L
.51166 .01472 L
.51215 .01508 L
.51263 .01472 L
.51312 .01503 L
.51361 .01472 L
.51409 .01498 L
.51458 .01472 L
.51506 .01495 L
.51555 .01472 L
.51603 .01492 L
.51652 .01472 L
.51701 .0149 L
.51749 .01472 L
.51798 .01488 L
.51846 .01472 L
.51895 .01486 L
.51944 .01472 L
.51992 .01485 L
.52041 .01472 L
.52089 .01483 L
.52138 .01472 L
.52187 .01482 L
.52235 .01472 L
.52284 .01481 L
.52332 .01472 L
.52381 .0148 L
.5243 .01472 L
.52478 .0148 L
.52527 .01472 L
.52575 .01479 L
.52624 .01472 L
.52672 .01478 L
.52721 .01472 L
.5277 .01478 L
.52818 .01472 L
.52867 .01477 L
.52915 .01472 L
.52964 .01477 L
.53013 .01472 L
.53061 .01477 L
.5311 .01472 L
.53158 .01476 L
.53207 .01472 L
.53256 .01476 L
.53304 .01472 L
.53353 .01476 L
Mistroke
.53401 .01472 L
.5345 .01475 L
.53499 .01472 L
.53547 .01475 L
.53596 .01472 L
.53644 .01475 L
.53693 .01472 L
.53741 .01475 L
.5379 .01472 L
.53839 .01475 L
.53887 .01472 L
.53936 .01474 L
.53984 .01472 L
.54033 .01474 L
.54082 .01472 L
.5413 .01474 L
.54179 .01472 L
.54227 .01474 L
.54276 .01472 L
.54325 .01474 L
.54373 .01472 L
.54422 .01474 L
.5447 .01472 L
.54519 .01474 L
.54568 .01472 L
.54616 .01474 L
.54665 .01472 L
.54713 .01473 L
.54762 .01472 L
.5481 .01473 L
.54859 .01472 L
.54908 .01473 L
.54956 .01472 L
.55005 .01473 L
.55053 .01472 L
.55102 .01473 L
.55151 .01472 L
.55199 .01473 L
.55248 .01472 L
.55296 .01473 L
.55345 .01472 L
.55394 .01473 L
.55442 .01472 L
.55491 .01473 L
.55539 .01472 L
.55588 .01473 L
.55637 .01472 L
.55685 .01473 L
.55734 .01472 L
.55782 .01473 L
Mistroke
.55831 .01472 L
.55879 .01473 L
.55928 .01472 L
.55977 .01473 L
.56025 .01472 L
.56074 .01473 L
.56122 .01472 L
.56171 .01473 L
.5622 .01472 L
.56268 .01473 L
.56317 .01472 L
.56365 .01473 L
.56414 .01472 L
.56463 .01473 L
.56511 .01472 L
.5656 .01472 L
.56608 .01472 L
.56657 .01472 L
.56706 .01472 L
.56754 .01472 L
.56803 .01472 L
.56851 .01472 L
.569 .01472 L
.56948 .01472 L
.56997 .01472 L
.57046 .01472 L
.57094 .01472 L
.57143 .01472 L
.57191 .01472 L
.5724 .01472 L
.57289 .01472 L
.57337 .01472 L
.57386 .01472 L
.57434 .01472 L
.57483 .01472 L
.57532 .01472 L
.5758 .01472 L
.57629 .01472 L
.57677 .01472 L
.57726 .01472 L
.57775 .01472 L
.57823 .01472 L
.57872 .01472 L
.5792 .01472 L
.57969 .01472 L
.58017 .01472 L
.58066 .01472 L
.58115 .01472 L
.58163 .01472 L
.58212 .01472 L
Mistroke
.5826 .01472 L
.58309 .01472 L
.58358 .01472 L
.58406 .01472 L
.58455 .01472 L
.58503 .01472 L
.58552 .01472 L
.58601 .01472 L
.58649 .01472 L
.58698 .01472 L
.58746 .01472 L
.58795 .01472 L
.58844 .01472 L
.58892 .01472 L
.58941 .01472 L
.58989 .01472 L
.59038 .01472 L
.59086 .01472 L
.59135 .01472 L
.59184 .01472 L
.59232 .01472 L
.59281 .01472 L
.59329 .01472 L
.59378 .01472 L
.59427 .01472 L
.59475 .01472 L
.59524 .01472 L
.59572 .01472 L
.59621 .01472 L
.5967 .01472 L
.59718 .01472 L
.59767 .01472 L
.59815 .01472 L
.59864 .01472 L
.59913 .01472 L
.59961 .01472 L
.6001 .01472 L
.60058 .01472 L
.60107 .01472 L
.60155 .01472 L
.60204 .01472 L
.60253 .01472 L
.60301 .01472 L
.6035 .01472 L
.60398 .01472 L
.60447 .01472 L
.60496 .01472 L
.60544 .01472 L
.60593 .01472 L
.60641 .01472 L
Mistroke
.6069 .01472 L
.60739 .01472 L
.60787 .01472 L
.60836 .01472 L
.60884 .01472 L
.60933 .01472 L
.60982 .01472 L
.6103 .01472 L
.61079 .01472 L
.61127 .01472 L
.61176 .01472 L
.61224 .01472 L
.61273 .01472 L
.61322 .01472 L
.6137 .01472 L
.61419 .01472 L
.61467 .01472 L
.61516 .01472 L
.61565 .01472 L
.61613 .01472 L
.61662 .01472 L
.6171 .01472 L
.61759 .01472 L
.61808 .01472 L
.61856 .01472 L
.61905 .01472 L
.61953 .01472 L
.62002 .01472 L
.62051 .01472 L
.62099 .01472 L
.62148 .01472 L
.62196 .01472 L
.62245 .01472 L
.62293 .01472 L
.62342 .01472 L
.62391 .01472 L
.62439 .01472 L
.62488 .01472 L
.62536 .01472 L
.62585 .01472 L
.62634 .01472 L
.62682 .01472 L
.62731 .01472 L
.62779 .01472 L
.62828 .01472 L
.62877 .01472 L
.62925 .01472 L
.62974 .01472 L
.63022 .01472 L
.63071 .01472 L
Mistroke
.6312 .01472 L
.63168 .01472 L
.63217 .01472 L
.63265 .01472 L
.63314 .01472 L
.63362 .01472 L
.63411 .01472 L
.6346 .01472 L
.63508 .01472 L
.63557 .01472 L
.63605 .01472 L
.63654 .01472 L
.63703 .01472 L
.63751 .01472 L
.638 .01472 L
.63848 .01472 L
.63897 .01472 L
.63946 .01472 L
.63994 .01472 L
.64043 .01472 L
.64091 .01472 L
.6414 .01472 L
.64189 .01472 L
.64237 .01472 L
.64286 .01472 L
.64334 .01472 L
.64383 .01472 L
.64431 .01472 L
.6448 .01472 L
.64529 .01472 L
.64577 .01472 L
.64626 .01472 L
.64674 .01472 L
.64723 .01472 L
.64772 .01472 L
.6482 .01472 L
.64869 .01472 L
.64917 .01472 L
.64966 .01472 L
.65015 .01472 L
.65063 .01472 L
.65112 .01472 L
.6516 .01472 L
.65209 .01472 L
.65258 .01472 L
.65306 .01472 L
.65355 .01472 L
.65403 .01472 L
.65452 .01472 L
.655 .01472 L
Mistroke
.65549 .01472 L
.65598 .01472 L
.65646 .01472 L
.65695 .01472 L
.65743 .01472 L
.65792 .01472 L
.65841 .01472 L
.65889 .01472 L
.65938 .01472 L
.65986 .01472 L
.66035 .01472 L
.66084 .01472 L
.66132 .01472 L
.66181 .01472 L
.66229 .01472 L
.66278 .01472 L
.66327 .01472 L
.66375 .01472 L
.66424 .01472 L
.66472 .01472 L
.66521 .01472 L
.66569 .01472 L
.66618 .01472 L
.66667 .01472 L
.66715 .01472 L
.66764 .01472 L
.66812 .01472 L
.66861 .01472 L
.6691 .01472 L
.66958 .01472 L
.67007 .01472 L
.67055 .01472 L
.67104 .01472 L
.67153 .01472 L
.67201 .01472 L
.6725 .01472 L
.67298 .01472 L
.67347 .01472 L
.67396 .01472 L
.67444 .01472 L
.67493 .01472 L
.67541 .01472 L
.6759 .01472 L
.67638 .01472 L
.67687 .01472 L
.67736 .01472 L
.67784 .01472 L
.67833 .01472 L
.67881 .01472 L
.6793 .01472 L
Mistroke
.67979 .01472 L
.68027 .01472 L
.68076 .01472 L
.68124 .01472 L
.68173 .01472 L
.68222 .01472 L
.6827 .01472 L
.68319 .01472 L
.68367 .01472 L
.68416 .01472 L
.68465 .01472 L
.68513 .01472 L
.68562 .01472 L
.6861 .01472 L
.68659 .01472 L
.68707 .01472 L
.68756 .01472 L
.68805 .01472 L
.68853 .01472 L
.68902 .01472 L
.6895 .01472 L
.68999 .01472 L
.69048 .01472 L
.69096 .01472 L
.69145 .01472 L
.69193 .01472 L
.69242 .01472 L
.69291 .01472 L
.69339 .01472 L
.69388 .01472 L
.69436 .01472 L
.69485 .01472 L
.69534 .01472 L
.69582 .01472 L
.69631 .01472 L
.69679 .01472 L
.69728 .01472 L
.69776 .01472 L
.69825 .01472 L
.69874 .01472 L
.69922 .01472 L
.69971 .01472 L
.70019 .01472 L
.70068 .01472 L
.70117 .01472 L
.70165 .01472 L
.70214 .01472 L
.70262 .01472 L
.70311 .01472 L
.7036 .01472 L
Mistroke
.70408 .01472 L
.70457 .01472 L
.70505 .01472 L
.70554 .01472 L
.70603 .01472 L
.70651 .01472 L
.707 .01472 L
.70748 .01472 L
.70797 .01472 L
.70845 .01472 L
.70894 .01472 L
.70943 .01472 L
.70991 .01472 L
.7104 .01472 L
.71088 .01472 L
.71137 .01472 L
.71186 .01472 L
.71234 .01472 L
.71283 .01472 L
.71331 .01472 L
.7138 .01472 L
.71429 .01472 L
.71477 .01472 L
.71526 .01472 L
.71574 .01472 L
.71623 .01472 L
.71672 .01472 L
.7172 .01472 L
.71769 .01472 L
.71817 .01472 L
.71866 .01472 L
.71914 .01472 L
.71963 .01472 L
.72012 .01472 L
.7206 .01472 L
.72109 .01472 L
.72157 .01472 L
.72206 .01472 L
.72255 .01472 L
.72303 .01472 L
.72352 .01472 L
.724 .01472 L
.72449 .01472 L
.72498 .01472 L
.72546 .01472 L
.72595 .01472 L
.72643 .01472 L
.72692 .01472 L
.72741 .01472 L
.72789 .01472 L
Mistroke
.72838 .01472 L
.72886 .01472 L
.72935 .01472 L
.72983 .01472 L
.73032 .01472 L
.73081 .01472 L
.73129 .01472 L
.73178 .01472 L
.73226 .01472 L
.73275 .01472 L
.73324 .01472 L
.73372 .01472 L
.73421 .01472 L
.73469 .01472 L
.73518 .01472 L
.73567 .01472 L
.73615 .01472 L
.73664 .01472 L
.73712 .01472 L
.73761 .01472 L
.7381 .01472 L
.73858 .01472 L
.73907 .01472 L
.73955 .01472 L
.74004 .01472 L
.74052 .01472 L
.74101 .01472 L
.7415 .01472 L
.74198 .01472 L
.74247 .01472 L
.74295 .01472 L
.74344 .01472 L
.74393 .01472 L
.74441 .01472 L
.7449 .01472 L
.74538 .01472 L
.74587 .01472 L
.74636 .01472 L
.74684 .01472 L
.74733 .01472 L
.74781 .01472 L
.7483 .01472 L
.74879 .01472 L
.74927 .01472 L
.74976 .01472 L
.75024 .01472 L
.75073 .01472 L
.75121 .01472 L
.7517 .01472 L
.75219 .01472 L
Mistroke
.75267 .01472 L
.75316 .01472 L
.75364 .01472 L
.75413 .01472 L
.75462 .01472 L
.7551 .01472 L
.75559 .01472 L
.75607 .01472 L
.75656 .01472 L
.75705 .01472 L
.75753 .01472 L
.75802 .01472 L
.7585 .01472 L
.75899 .01472 L
.75948 .01472 L
.75996 .01472 L
.76045 .01472 L
.76093 .01472 L
.76142 .01472 L
.7619 .01472 L
.76239 .01472 L
.76288 .01472 L
.76336 .01472 L
.76385 .01472 L
.76433 .01472 L
.76482 .01472 L
.76531 .01472 L
.76579 .01472 L
.76628 .01472 L
.76676 .01472 L
.76725 .01472 L
.76774 .01472 L
.76822 .01472 L
.76871 .01472 L
.76919 .01472 L
.76968 .01472 L
.77017 .01472 L
.77065 .01472 L
.77114 .01472 L
.77162 .01472 L
.77211 .01472 L
.77259 .01472 L
.77308 .01472 L
.77357 .01472 L
.77405 .01472 L
.77454 .01472 L
.77502 .01472 L
.77551 .01472 L
.776 .01472 L
.77648 .01472 L
Mistroke
.77697 .01472 L
.77745 .01472 L
.77794 .01472 L
.77843 .01472 L
.77891 .01472 L
.7794 .01472 L
.77988 .01472 L
.78037 .01472 L
.78086 .01472 L
.78134 .01472 L
.78183 .01472 L
.78231 .01472 L
.7828 .01472 L
.78328 .01472 L
.78377 .01472 L
.78426 .01472 L
.78474 .01472 L
.78523 .01472 L
.78571 .01472 L
.7862 .01472 L
.78669 .01472 L
.78717 .01472 L
.78766 .01472 L
.78814 .01472 L
.78863 .01472 L
.78912 .01472 L
.7896 .01472 L
.79009 .01472 L
.79057 .01472 L
.79106 .01472 L
.79155 .01472 L
.79203 .01472 L
.79252 .01472 L
.793 .01472 L
.79349 .01472 L
.79397 .01472 L
.79446 .01472 L
.79495 .01472 L
.79543 .01472 L
.79592 .01472 L
.7964 .01472 L
.79689 .01472 L
.79738 .01472 L
.79786 .01472 L
.79835 .01472 L
.79883 .01472 L
.79932 .01472 L
.79981 .01472 L
.80029 .01472 L
.80078 .01472 L
Mistroke
.80126 .01472 L
.80175 .01472 L
.80224 .01472 L
.80272 .01472 L
.80321 .01472 L
.80369 .01472 L
.80418 .01472 L
.80466 .01472 L
.80515 .01472 L
.80564 .01472 L
.80612 .01472 L
.80661 .01472 L
.80709 .01472 L
.80758 .01472 L
.80807 .01472 L
.80855 .01472 L
.80904 .01472 L
.80952 .01472 L
.81001 .01472 L
.8105 .01472 L
.81098 .01472 L
.81147 .01472 L
.81195 .01472 L
.81244 .01472 L
.81293 .01472 L
.81341 .01472 L
.8139 .01472 L
.81438 .01472 L
.81487 .01472 L
.81535 .01472 L
.81584 .01472 L
.81633 .01472 L
.81681 .01472 L
.8173 .01472 L
.81778 .01472 L
.81827 .01472 L
.81876 .01472 L
.81924 .01472 L
.81973 .01472 L
.82021 .01472 L
.8207 .01472 L
.82119 .01472 L
.82167 .01472 L
.82216 .01472 L
.82264 .01472 L
.82313 .01472 L
.82362 .01472 L
.8241 .01472 L
.82459 .01472 L
.82507 .01472 L
Mistroke
.82556 .01472 L
.82604 .01472 L
.82653 .01472 L
.82702 .01472 L
.8275 .01472 L
.82799 .01472 L
.82847 .01472 L
.82896 .01472 L
.82945 .01472 L
.82993 .01472 L
.83042 .01472 L
.8309 .01472 L
.83139 .01472 L
.83188 .01472 L
.83236 .01472 L
.83285 .01472 L
.83333 .01472 L
.83382 .01472 L
.83431 .01472 L
.83479 .01472 L
.83528 .01472 L
.83576 .01472 L
.83625 .01472 L
.83673 .01472 L
.83722 .01472 L
.83771 .01472 L
.83819 .01472 L
.83868 .01472 L
.83916 .01472 L
.83965 .01472 L
.84014 .01472 L
.84062 .01472 L
.84111 .01472 L
.84159 .01472 L
.84208 .01472 L
.84257 .01472 L
.84305 .01472 L
.84354 .01472 L
.84402 .01472 L
.84451 .01472 L
.845 .01472 L
.84548 .01472 L
.84597 .01472 L
.84645 .01472 L
.84694 .01472 L
.84742 .01472 L
.84791 .01472 L
.8484 .01472 L
.84888 .01472 L
.84937 .01472 L
Mistroke
.84985 .01472 L
.85034 .01472 L
.85083 .01472 L
.85131 .01472 L
.8518 .01472 L
.85228 .01472 L
.85277 .01472 L
.85326 .01472 L
.85374 .01472 L
.85423 .01472 L
.85471 .01472 L
.8552 .01472 L
.85569 .01472 L
.85617 .01472 L
.85666 .01472 L
.85714 .01472 L
.85763 .01472 L
.85811 .01472 L
.8586 .01472 L
.85909 .01472 L
.85957 .01472 L
.86006 .01472 L
.86054 .01472 L
.86103 .01472 L
.86152 .01472 L
.862 .01472 L
.86249 .01472 L
.86297 .01472 L
.86346 .01472 L
.86395 .01472 L
.86443 .01472 L
.86492 .01472 L
.8654 .01472 L
.86589 .01472 L
.86638 .01472 L
.86686 .01472 L
.86735 .01472 L
.86783 .01472 L
.86832 .01472 L
.8688 .01472 L
.86929 .01472 L
.86978 .01472 L
.87026 .01472 L
.87075 .01472 L
.87123 .01472 L
.87172 .01472 L
.87221 .01472 L
.87269 .01472 L
.87318 .01472 L
.87366 .01472 L
Mistroke
.87415 .01472 L
.87464 .01472 L
.87512 .01472 L
.87561 .01472 L
.87609 .01472 L
.87658 .01472 L
.87707 .01472 L
.87755 .01472 L
.87804 .01472 L
.87852 .01472 L
.87901 .01472 L
.87949 .01472 L
.87998 .01472 L
.88047 .01472 L
.88095 .01472 L
.88144 .01472 L
.88192 .01472 L
.88241 .01472 L
.8829 .01472 L
.88338 .01472 L
.88387 .01472 L
.88435 .01472 L
.88484 .01472 L
.88533 .01472 L
.88581 .01472 L
.8863 .01472 L
.88678 .01472 L
.88727 .01472 L
.88776 .01472 L
.88824 .01472 L
.88873 .01472 L
.88921 .01472 L
.8897 .01472 L
.89018 .01472 L
.89067 .01472 L
.89116 .01472 L
.89164 .01472 L
.89213 .01472 L
.89261 .01472 L
.8931 .01472 L
.89359 .01472 L
.89407 .01472 L
.89456 .01472 L
.89504 .01472 L
.89553 .01472 L
.89602 .01472 L
.8965 .01472 L
.89699 .01472 L
.89747 .01472 L
.89796 .01472 L
Mistroke
.89845 .01472 L
.89893 .01472 L
.89942 .01472 L
.8999 .01472 L
.90039 .01472 L
.90087 .01472 L
.90136 .01472 L
.90185 .01472 L
.90233 .01472 L
.90282 .01472 L
.9033 .01472 L
.90379 .01472 L
.90428 .01472 L
.90476 .01472 L
.90525 .01472 L
.90573 .01472 L
.90622 .01472 L
.90671 .01472 L
.90719 .01472 L
.90768 .01472 L
.90816 .01472 L
.90865 .01472 L
.90914 .01472 L
.90962 .01472 L
.91011 .01472 L
.91059 .01472 L
.91108 .01472 L
.91156 .01472 L
.91205 .01472 L
.91254 .01472 L
.91302 .01472 L
.91351 .01472 L
.91399 .01472 L
.91448 .01472 L
.91497 .01472 L
.91545 .01472 L
.91594 .01472 L
.91642 .01472 L
.91691 .01472 L
.9174 .01472 L
.91788 .01472 L
.91837 .01472 L
.91885 .01472 L
.91934 .01472 L
.91983 .01472 L
.92031 .01472 L
.9208 .01472 L
.92128 .01472 L
.92177 .01472 L
.92225 .01472 L
Mistroke
.92274 .01472 L
.92323 .01472 L
.92371 .01472 L
.9242 .01472 L
.92468 .01472 L
.92517 .01472 L
.92566 .01472 L
.92614 .01472 L
.92663 .01472 L
.92711 .01472 L
.9276 .01472 L
.92809 .01472 L
.92857 .01472 L
.92906 .01472 L
.92954 .01472 L
.93003 .01472 L
.93052 .01472 L
.931 .01472 L
.93149 .01472 L
.93197 .01472 L
.93246 .01472 L
.93294 .01472 L
.93343 .01472 L
.93392 .01472 L
.9344 .01472 L
.93489 .01472 L
.93537 .01472 L
.93586 .01472 L
.93635 .01472 L
.93683 .01472 L
.93732 .01472 L
.9378 .01472 L
.93829 .01472 L
.93878 .01472 L
.93926 .01472 L
.93975 .01472 L
.94023 .01472 L
.94072 .01472 L
.94121 .01472 L
.94169 .01472 L
.94218 .01472 L
.94266 .01472 L
.94315 .01472 L
.94363 .01472 L
.94412 .01472 L
.94461 .01472 L
.94509 .01472 L
.94558 .01472 L
.94606 .01472 L
.94655 .01472 L
Mistroke
.94704 .01472 L
.94752 .01472 L
.94801 .01472 L
.94849 .01472 L
.94898 .01472 L
.94947 .01472 L
.94995 .01472 L
.95044 .01472 L
.95092 .01472 L
.95141 .01472 L
.9519 .01472 L
.95238 .01472 L
.95287 .01472 L
.95335 .01472 L
.95384 .01472 L
.95432 .01472 L
.95481 .01472 L
.9553 .01472 L
.95578 .01472 L
.95627 .01472 L
.95675 .01472 L
.95724 .01472 L
.95773 .01472 L
.95821 .01472 L
.9587 .01472 L
.95918 .01472 L
.95967 .01472 L
.96016 .01472 L
.96064 .01472 L
.96113 .01472 L
.96161 .01472 L
.9621 .01472 L
.96259 .01472 L
.96307 .01472 L
.96356 .01472 L
.96404 .01472 L
.96453 .01472 L
.96501 .01472 L
.9655 .01472 L
.96599 .01472 L
.96647 .01472 L
.96696 .01472 L
.96744 .01472 L
.96793 .01472 L
.96842 .01472 L
.9689 .01472 L
.96939 .01472 L
.96987 .01472 L
.97036 .01472 L
.97085 .01472 L
Mistroke
.97133 .01472 L
.97182 .01472 L
.9723 .01472 L
.97279 .01472 L
.97328 .01472 L
.97376 .01472 L
.97425 .01472 L
.97473 .01472 L
.97522 .01472 L
.9757 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`007Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001Wooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0ol0000Hooooo`;o00001?ooool01?l0003oooooooooooooool5
o`0001_ooooo0_l0000Pooooo`;o00001?ooool01?l0003oooooooooooooool5o`0001Sooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0ol0000Hooooo`;o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00003Oooool001cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000001Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Fooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00006_ooool01?l0003oooooooooool0
000Nooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00005oooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000cooooo000Eooooo`Go00000_ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000004?ooool5o`0000;ooooo00Co0000oooooooooooo
00001oooool5o`00013ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool06_ooool01?l0003oooooooooool0000Nooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool05oooool01?l0003oooooooooool00007ooooo`Go00005oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000003?ooool001cooooo00Co0000oooooooo
oooo00001oooool4o`0001Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
000Hooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool06Oooool01?l0003ooooo
ooooool0000Nooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool05_ooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0001Sooooo00Co0000oooooooooooo0000
1oooool4o`0000gooooo000Looooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
6Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000001Sooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000001[ooooo00Co0000oooooooooooo00007_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000005oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000001Sooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0>ooooo`007?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo01Sooooo00Co0000oooooooooooo00002Oooool2o`0001Sooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000001[ooooo00Co0000oooooooooooo00007_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000005oooool01?l0003ooooooooo
ool00009ooooo`;o00006?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00go
oooo000Mooooo`;o00002_ooool2o`0001Wooooo0_l0000;ooooo`03o`000?oooooooooo01Oooooo
0_l00009ooooo`?o00007?ooool2o`00023ooooo0_l00009ooooo`?o00006Oooool2o`0000_ooooo
00?o0000ooooooooool05oooool2o`0000[ooooo0_l0000=ooooo`007_ooool00ol0003ooooooooo
o`3oooooo`007_ooool00ol0003oooooooooo`3oooooo`007_ooool00ol0003oooooooooo`3ooooo
o`007_ooool00ol0003oooooooooo`3oooooo`006?ooool6o`000?;oo`001_l0000:ooooo`007_oo
ool5o`0000Oooooo1ol00003ooooo`04o`000?ooooooooooooooo`Co00000_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`05o`000?oooooo0000ooooool000000_ooool01?l0003oooooo`000?l00003ooooo`Co000000?o
ooooo`000?ooool00_ooool01?l0003oooooo`000?ooool2o`0000?ooooo0_l00002ooooo`;oo`00
0_ooool2o`0000?ooooo0_l000001?oooooo0000ooooool00003ooooo`04o`000?oooooo0000oooo
o`;o00000_ooool2o`0000;ooooo00Go0000ooooool0003o0000ooooo`02o`0000?ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03o`0000Cooooo
00Co0000oooooooooooooooo1_l00008ooooo`Go00004?ooool001kooooo00Co0000oooooooooooo
oooo2_l00004ooooocCo00000oooool4o`000005ooooool0003o0000ooooool000000_ooool01Ol0
003oooooo`000?oooooo000000?ooooo0ol00003ooooo`Co000000Soooooo`000?oooooo0000oooo
ool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00002ooooo`;oo`0000Coooooo`00
0?l0003o00000oooool03Ol0003oooooo`000?l0003oooooo`000?oooooo0000ooooool0003ooooo
o`000?ooool00_l00002ooooo`?o00000oooool2o`000003ooooool0003o000000?ooooo0_l00000
1Ooooooo0000ooooool0003ooooo00;o00000ooooolYo`000003ooooool0003o000000So00001?oo
ool:o`0001Cooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`06ooooo`?o00001?ooool6o`0000?ooooo1ol000002Ooooooo0000oooooooo
oooo0000ooooool0003oooooo`000003ooooo`Co00000_ooool6o`000007ooooool0003oooooo`00
0?oooooo0000ooooo`02o`0000;ooooo1?l000001?ooooooo`00ool00?ooool3o`0000?ooooo00Go
0000ooooool0003o0000ooooo`03o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo
0000o`000002o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o000000Goooooo`000?oo
oooo0000ooooo`02o`0000?ooooo1_l00004ooooo`?o00002?ooool00ol0003oooooooooo`0Soooo
o`;o00006Oooool001kooooo00?o0000ooooooooool0@?ooool3o`0000?ooooo2Ol000000ooooooo
0000o`000002o`000004ooooool0003o0000ooooo`Go00000_ooool6o`000007ooooool0003ooooo
o`000?oooooo0000ooooo`03o`000003ooooool0003o000000?o00000_oo0005o`000004ooooool0
003o0000ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`000004ooooool0003o0000oooo
o`Go000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003ooooo00Co000000?ooooo
o`000?ooool00_l00003ooooo`?o0000Doooool001kooooo00?o0000ooooooooool0@?ooool3o`00
00?ooooo4Ol000000ooooooo0000o`00000=o`000005ooooool0003o0000o`000?ooool00ol00000
0ooooooo0000o`000003o`0000;oo`001Ol000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000000Go000000?oooooo`000?l000001_l000000ooooooo0000o`00000;o`000003ooooool0
003ooooo00;o00000oooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00003
oooooa7o000000?oooooo`000?l000004Ol000001Ooooooo0000o`000?l0003ooooo00Go00000_oo
0005o`000004ooooool0003o0000oooooa?o000000?oooooo`000?l000002ol000000ooooooo0000
ooooo`02o`0000?ooooo0_l0001Dooooo`007_ooool2o`0004;ooooo0_l00003oooooa7o000000?o
ooooo`000?l000005Ol000000ooooooo0000o`000003o`0000;oo`007?l000000ooooooo0000o`00
000=o`000003ooooool0003o000000?ooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`11
ooooo`;o00000ooooolYo`000003ooooool0003o000000?o00000_oo000/o`000003ooooool0003o
000000?ooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00000ooooolYo`00
0003ooooool0003o000000?o00000_oo000/o`000003ooooool0003o000000?ooooo00?o0000oooo
ooooool0Doooool001kooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo;ol00002ool002co
000000?oooooo`000?l000000oooool00ol0003oooooooooo`1Cooooo`007_ooool00ol0003ooooo
ooooo`11ooooo`;o00000oooool_o`0000;oo`00;?l000000ooooooo0000o`000003ooooo`03o`00
0?oooooooooo05?ooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00003oooooboo00000_oo
000/o`000003ooooool0003o000000?ooooo00?o0000ooooooooool0Doooool001kooooo00?o0000
ooooooooool0@_ooool01?l0003oooooooooooooool_o`0000;oo`00;?l000000ooooooo0000o`00
0003ooooo`03o`000?oooooooooo05?ooooo000Nooooo`03o`000?oooooooooo04;ooooo00Co0000
oooooooooooooooo;ol00002ool002co000000?oooooo`000?l000000_ooool2o`0005Gooooo000N
ooooo`;o0000@oooool01?l0003oooooooooooooool_o`0000;oo`00;?l000000ooooooo0000o`00
0002ooooo`;o0000EOooool001kooooo00?o0000ooooooooool0@_ooool01?l0003ooooooooooooo
ool_o`0000;oo`00;?l000000ooooooo0000o`000002ooooo`;o0000EOooool001kooooo00?o0000
ooooooooool0@_ooool01?l0003oooooooooooooool_o`0000;oo`00;ol00002ooooo`;o0000EOoo
ool001kooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo;ol00002ool002oo00000_ooool2
o`0005Gooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l00002oooooboo00000_oo000_o`00
00;ooooo0_l0001Eooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00000_ooool_o`0000;o
o`00;ol00002ooooo`;o0000EOooool001kooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo
;ol00002ool002oo00000_ooool2o`0005Gooooo000Nooooo`;o0000@oooool2o`0000;ooooo;ol0
0002ool002oo00000_ooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l00002
oooooboo00000_oo000_o`0000;ooooo0_l0001Eooooo`007_ooool00ol0003oooooooooo`12oooo
o`;o00000_ooool_o`0000;oo`00;ol00002ooooo`;o0000EOooool001kooooo00?o0000oooooooo
ool0@_ooool2o`0000;ooooo;ol00002ool002oo00000_ooool2o`0005Gooooo000Nooooo`03o`00
0?oooooooooo04;ooooo0_l00002oooooboo00000_oo000_o`0000;ooooo00?o0000ooooooooool0
E?ooool000_ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003ooooo
ooooo`12ooooo`;o00000_ooool_o`0000;oo`00;ol00002ooooo`03o`000?oooooooooo05Cooooo
000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`12ooooo`;o00000_ooool_o`0000;oo`00;ol00002ooooo`03o`000?oooooooooo05Co
oooo000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`12ooooo`;o00000_oooolYo`000003ooooool0003o000000?o00000_oo0005o`000003
ooooool0003o000002Oo00000_ooool00ol0003oooooooooo`1Dooooo`002_ooool01?l0003ooooo
ooooool0000:ooooo`03o`000?oooooooooo00?ooooo0ol00012ooooo`;o00000_oooolYo`000003
ooooool0003o000000?o00000_oo0005o`000003ooooool0003o000002Oo00000_ooool00ol0003o
ooooooooo`1Dooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`12ooooo`;o00000_oooolYo`000003ooooool0003o0000
00?o00000_oo0005o`000003ooooool0003o000002Oo00000_ooool00ol0003oooooooooo`1Doooo
o`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`12ooooo`;o00000_oooolYo`000003ooooool0003o000000?o00000_oo0005
o`000003ooooool0003o000002Oo00000_ooool00ol0003oooooooooo`1Dooooo`002oooool2o`00
00Wooooo0ol00005ooooo`03o`000?oooooooooo04;ooooo0_l00002ooooob?o000000?oooooo`00
0?l000000ol000000ooooooo0000o`000003o`0000;oo`001Ol000000ooooooo0000o`00000Wo`00
00;ooooo00?o0000ooooooooool0E?ooool001kooooo00?o0000ooooooooool0@_ooool2o`0000;o
oooo8Ol000000ooooooo0000ooooo`05o`000003ooooool0003o000000?o00000_oo0005o`000003
ooooool0003o000000Go000000?oooooo`000?l000007ol00002ooooo`03o`000?oooooooooo05Co
oooo000Nooooo`03o`000?oooooooooo04;ooooo0_l00002ooooob7o000000?oooooo`000?ooool0
1Ol000000ooooooo0000o`000002o`000003oooooooo003oo`0000Go000000?oooooo`000?l00000
1Ol000000ooooooo0000o`00000Oo`0000;ooooo00?o0000ooooooooool0E?ooool001kooooo00?o
0000ooooooooool0@_ooool2o`0000;ooooo8Ol000000ooooooo0000ooooo`05o`000003ooooool0
003o000000;o000000?oooooool00?oo00001Ol000000ooooooo0000o`000005o`000003ooooool0
003o000001oo00000_ooool00ol0003oooooooooo`1Dooooo`007_ooool2o`0004?ooooo0_l00002
oooooaoo000000Goooooo`000?oooooo0000ooooo`04o`0000;ooooo1?l000000oooooooo`00ool0
0005o`000003ooooool0003o000000Go000000?oooooo`000?l000007ol00002ooooo`03o`000?oo
oooooooo05Cooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l00002oooooaoo000000Gooooo
o`000?oooooo0000ooooo`04o`0000;ooooo1?l000000oooooooo`00ool00005o`000003ooooool0
003o000000?o000000?oooooo`000?ooool00_l000000ooooooo0000o`00000Lo`0000;ooooo00?o
0000ooooooooool0E?ooool001kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0O
o`000005ooooool0003oooooo`000?ooool00_l000001?oooooo0000ooooooooool4o`000004oooo
oooo003oo`00ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000ooooo`02o`00
0003ooooool0003o000001co00000_ooool00ol0003oooooooooo`1Dooooo`007_ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo01oo000000Koooooo`000?oooooo0000ooooool00002
ooooo`04o`000?ooooooooooooooo`?o000000Coooooool00?oo003ooooo0ol00002ooooo`;o0000
0_ooool01?l0003oooooo`000?ooool2o`000003ooooool0003o000001co00000_ooool00ol0003o
ooooooooo`1Dooooo`007_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01oo0000
00Koooooo`000?oooooo0000ooooool00002ooooo`04o`000?ooooooooooooooo`?o000000Cooooo
ool00?oo003ooooo0ol00002ooooo`;o00000_ooool01?l0003oooooo`000?ooool2o`000003oooo
ool0003o000001co00000_ooool00ol0003oooooooooo`1Dooooo`007_ooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo01co000000Ooooooo`000?l0003oooooo`000?oooooo000000Co
oooo00Co0000oooooooooooooooo0ol000001?ooooooo`00ool00?ooool3o`0000;ooooo0_l00004
ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`0Lo`0000;ooooo00?o0000ooooooooool0
E?ooool001kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@o`000003ooooool0
003o000000Wo000000Ooooooo`000?l0003oooooo`000?oooooo000000Cooooo00Co0000oooooooo
oooooooo0ol000001?ooooooo`00ool00?ooool3o`0000;ooooo0_l00004ooooo`07o`000?oooooo
0000o`000?oooooo0000ooooo`0;o`000003ooooool0003o000000ko00000_ooool00ol0003ooooo
ooooo`1Dooooo`007_ooool2o`0004Cooooo00?o0000ooooooooool04?l000000ooooooo0000o`00
0009o`000007ooooool0003o0000ooooool0003oooooo`000004ooooo`04o`000?oooooooooooooo
o`?o000000Coooooool00?oo003ooooo0ol00002ooooo`;o00001?ooool01ol0003oooooo`000?l0
003oooooo`000?ooool02ol000000ooooooo0000o`00000>o`0000;ooooo00?o0000ooooooooool0
E?ooool001kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@o`000003ooooool0
003o000000Wo000000Ooooooo`000?l0003oooooo`000?oooooo000000Cooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;oo`000_ooool2o`0000;ooooo0_l00004ooooo`07o`000?oooooo0000
o`000?oooooo0000ooooo`0;o`000003ooooool0003o000000ko00000_ooool00ol0003ooooooooo
o`1Dooooo`007_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo013o000000?ooooo
o`000?l000002Ol000001ooooooo0000o`000?oooooo0000ooooool000001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;oo`000_ooool01?l0003oooooooooooooool2o`0000Co
oooo00Oo0000ooooool0003o0000ooooool0003ooooo00_o000000?oooooo`000?l000003_l00002
ooooo`03o`000?oooooooooo05Cooooo000Nooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool04?l000000ooooooo0000o`000009o`000007ooooool0003o0000ooooool0003oooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo0002ooooo`04o`000?oo
ooooooooooooo`;o00001?ooool01ol0003oooooo`000?l0003oooooo`000?ooool02ol000001?oo
oooo0000o`000?ooool=o`0000;ooooo00?o0000ooooooooool0E?ooool001kooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`09o`000003ooooool0003o000000Co000000?oooooo`00
0?l000001_l000001?oooooo0000o`000?ooool2o`000004ooooool0003oooooo`0000Cooooo00?o
0000ooooooooool01Oooool2ool000Oooooo00?o0000ooooooooool00_ooool01ol0003oooooo`00
0?l0003oooooo`000?ooool00_l000000ooooooo0000o`000006o`000004ooooool0003o0000oooo
o`go00000_ooool00ol0003oooooooooo`1Dooooo`007_ooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo00Wo000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003o0000
ooooo`Go000000Goooooo`000?l0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool2ool000Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
ool0003ooooo00;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?ooool2o`000003
ooooool0003o000000_o000000?oooooo`000?l00000E_ooool001kooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`09o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo
0000o`000003ooooo`?o000000Goooooo`000?l0003oooooo`000002ooooo`03o`000?oooooooooo
00cooooo0_oo000>ooooo`05o`000?ooooooooooo`000?ooool00_l000001?oooooo0000o`000?l0
0003ooooo`;o000000Coooooo`000?l0003ooooo3Ol000000ooooooo0000o`00001Fooooo`007_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Wo000000Goooooo`000?l0003o0000
ooooo`02o`0000Kooooo0ol00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
3?ooool2ool000kooooo00Ko0000oooooooooooo0000ooooool00002ooooo`?o00001_ooool2o`00
0003ooooool0003o000000_o000000?oooooo`000?l00000E_ooool001kooooo0_l00014ooooo`03
o`000?oooooooooo00Wo000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0_l00004oooo
o`03o`000?oooooooooo00oooooo0_oo000Aooooo`03o`000?oooooooooo00;ooooo0_l00007oooo
o`;o000000?oooooo`000?l000002ol000000ooooooo0000o`00001Fooooo`007_ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo00Wo000000Goooooo`000?l0003o0000ooooo`02o`00
00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;oo`004Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000o`00000;o`00
0003ooooool0003o000005Kooooo000Nooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool02Ol000001Ooooooo0000o`000?l0003ooooo00;o00001oooool00ol0003oooooooooo`0Eoooo
o`;oo`005oooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`000?l000002ol000000ooo
oooo0000o`00001Fooooo`007_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Wo
000000Goooooo`000?l0003o0000ooooo`02o`0001oooooo0_oo000Oooooo`;o000000?oooooo`00
0?l000002ol000000ooooooo0000o`00001Fooooo`007_ooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo00Wo00000_ooool2o`000003ooooool0003ooooo01oooooo0_oo000Pooooo`07
o`000?oooooo0000o`000?oooooo0000ooooo`08o`000003ooooool0003o000005Kooooo000;oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo00Wo00000_ooool2o`000003ooooool0003ooooo01oooooo0_oo000Poooo
o`07o`000?oooooo0000o`000?oooooo0000ooooo`08o`000003ooooool0003o000005Kooooo000:
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo00Wo00000_ooool2o`0002;ooooo0_oo000Rooooo`;o000000?o
ooooo`000?ooool02?l000000ooooooo0000o`00001Fooooo`002_ooool01?l0003oooooooooool0
0007ooooo`Go00001?ooool3o`0004?ooooo00?o0000ooooooooool02?l00003ooooo`;o00008_oo
ool2ool002;ooooo0_l00003ooooo`So000000?oooooo`000?l00000E_ooool000[ooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool02?l00004ooooo`03o`000?oooooooooo023ooooo0_oo000Rooooo`03o`00
0?oooooooooo00;ooooo2?l000000ooooooo0000o`00001Fooooo`002_ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0@oooool01?l0003ooooo
o`000?ooool7o`0000Cooooo00?o0000ooooooooool08?ooool2ool002;ooooo00?o0000oooooooo
ool00_ooool8o`000003ooooool0003o000005Kooooo000:ooooo`04o`000?ooooooooooo`0000Wo
oooo0_l00005ooooo`03o`000?oooooooooo04?ooooo00Co0000ooooool0003ooooo1Ol000000ooo
oooo0000ooooo`03ooooo`03o`000?oooooooooo023ooooo0_oo000Rooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000001Ol000000ooooooo0000o`00001Fooooo`002oooool2o`0000_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`04o`000?oooooo0000oooo
o`Go000000?oooooo`000?ooool09_ooool2ool002Oooooo00Go0000ooooool0003o0000ooooo`03
o`000003ooooool0003o000005Kooooo000Nooooo`03o`000?oooooooooo04?ooooo00Co0000oooo
ool0003ooooo1Ol000000ooooooo0000ooooo`0Vooooo`;oo`009oooool01Ol0003oooooo`000?l0
003ooooo00?o000000?oooooo`000?l00000E_ooool001kooooo00?o0000ooooooooool0@oooool0
1?l0003oooooo`000?ooool5o`000003ooooool0003ooooo02Kooooo0_oo000Wooooo`05o`000?oo
oooo0000o`000?ooool01_l0001Fooooo`007_ooool00ol0003oooooooooo`13ooooo`04o`000?oo
oooo0000ooooo`Go000000?oooooo`000?ooool09_ooool2ool002Oooooo00Go0000ooooool0003o
0000ooooo`06o`0005Kooooo000Nooooo`;o0000A?ooool01?l0003oooooo`000?ooool5o`000003
ooooool0003ooooo02Kooooo0_oo000Wooooo`05o`000?oooooo0000o`000?ooool01_l0001Foooo
o`007_ooool00ol0003oooooooooo`13ooooo`04o`000?oooooo0000ooooo`Go000000?oooooo`00
0?ooool09_ooool2ool002Oooooo00Go0000ooooool0003o0000ooooo`06o`0005Kooooo000Noooo
o`03o`000?oooooooooo04?ooooo00Co0000ooooool0003ooooo1Ol000000ooooooo0000ooooo`0V
ooooo`;oo`009oooool01Ol0003oooooo`000?l0003ooooo00Ko0000E_ooool001kooooo00?o0000
ooooooooool0@oooool01?l0003oooooo`000?ooool5o`0002Wooooo0_oo000Yooooo`;o000000?o
ooooo`000?l000001?l0001Fooooo`007_ooool00ol0003oooooooooo`13ooooo`04o`000?oooooo
0000ooooo`Go0000:Oooool2ool002Wooooo0_l000000ooooooo0000o`000004o`0005Kooooo000N
ooooo`03o`000?oooooooooo04?ooooo0ol000000ooooooo0000o`000003o`0002Wooooo0_oo000Y
ooooo`;o000000?oooooo`000?l000001?l0001Fooooo`007_ooool00ol0003oooooooooo`13oooo
o`?o000000?oooooo`000?l000000ol0000Yooooo`;oo`00:Oooool2o`000003ooooool0003o0000
00Co0000E_ooool001kooooo0_l00014ooooo`?o000000Koooooo`000?l0003o0000ooooool0000Y
ooooo`;oo`00:Oooool2o`000003ooooool0003o000000Co0000E_ooool001kooooo00?o0000oooo
ooooool0@oooool3o`000006ooooool0003o0000o`000?oooooo0000:Oooool2ool002Wooooo0_l0
00000ooooooo0000o`000004o`0005Kooooo000Nooooo`03o`000?oooooooooo04?ooooo0ol00000
1_oooooo0000o`000?l0003oooooo`0002Wooooo0_oo000Yooooo`;o000000?oooooo`000?l00000
1?l0001Fooooo`007_ooool00ol0003oooooooooo`13ooooo`?o000000Koooooo`000?l0003o0000
ooooool0000Yooooo`;oo`00:Oooool2o`000003ooooool0003o000000Co0000E_ooool001kooooo
00?o0000ooooooooool0@oooool3o`000004ooooool0003o0000o`0002_ooooo0_oo000Zooooo`03
o`000?oooooo000000Go0000E_ooool001kooooo00?o0000ooooooooool0@oooool3o`000004oooo
ool0003o0000o`0002_ooooo0_oo000Zooooo`03o`000?oooooo000000Co0000Eoooool001kooooo
00?o0000ooooooooool0@oooool3o`000004ooooool0003o0000o`0002_ooooo0_oo000Zooooo`03
o`000?oooooo000000Co0000Eoooool001kooooo00?o0000ooooooooool0@oooool3o`000004oooo
ool0003o0000o`0002_ooooo0_oo000Zooooo`04o`000?oooooo0000ooooo`?o0000Eoooool001ko
oooo0_l00014ooooo`?o000000Coooooo`000?l0003o0000:oooool2ool002[ooooo00Co0000oooo
ool0003ooooo0ol0001Gooooo`007_ooool00ol0003oooooooooo`13ooooo`?o000000Coooooo`00
0?l0003o0000:oooool2ool002[ooooo00Co0000ooooool0003ooooo0ol0001Gooooo`007_ooool0
0ol0003oooooooooo`13ooooo`?o000000Coooooo`000?l0003o0000:oooool2ool002[ooooo00Co
0000ooooool0003ooooo0ol0001Gooooo`007_ooool00ol0003oooooooooo`13ooooo`?o000000Co
ooooo`000?l0003o0000:oooool2ool002[ooooo00Co0000ooooool0003ooooo0ol0001Gooooo`00
7_ooool00ol0003oooooooooo`13ooooo`?o000000Coooooo`000?l0003o0000:oooool2ool002[o
oooo00Co0000ooooool0003ooooo0ol0001Gooooo`002oooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool0@oooool3o`000003ooooool0003o000002co
oooo0_oo000/ooooo`03o`000?oooooooooo00;o0000Eoooool000[ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0A?ooool2o`00
0003ooooool0003o000002cooooo0_oo000/ooooo`03o`000?oooooooooo00;o0000Eoooool000[o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo0ol00014
ooooo`;o00000_ooool00ol0003oooooooooo`0Zooooo`;oo`00;?ooool00ol0003oooooooooo`02
o`0005Oooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooo
oooo04Cooooo0_l00002ooooo`03o`000?oooooooooo02[ooooo0_oo000/ooooo`03o`000?oooooo
oooo00;o0000Eoooool000[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo04Cooooo0_l00002ooooo`03o`000?oooooooooo02[ooooo0_oo000/
ooooo`03o`000?oooooooooo00;o0000Eoooool000[ooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo0_l00002ooooo`03o`000?oooooo
oooo02[ooooo0_oo000/ooooo`03o`000?oooooooooo00;o0000Eoooool000_ooooo0_l0000:oooo
o`;o00001Oooool00ol0003oooooooooo`14ooooo`;o0000;oooool2ool002oooooo0_l0001Goooo
o`007_ooool00ol0003oooooooooo`14ooooo`;o0000;oooool2ool002oooooo0_l0001Gooooo`00
7_ooool00ol0003oooooooooo`14ooooo`;o0000;oooool2ool002oooooo0_l0001Gooooo`007_oo
ool00ol0003oooooooooo`14ooooo`;o0000;oooool2ool002oooooo0_l0001Gooooo`007_ooool2
o`0004Gooooo0_l0000_ooooo`;oo`00;oooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo
04Cooooo0_l0000_ooooo`;oo`00;oooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo04Co
oooo0_l0000_ooooo`;oo`00;oooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo04Cooooo
0_l0000_ooooo`;oo`00;oooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0
000_ooooo`;oo`00;oooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000_
ooooo`;oo`00;oooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000_oooo
o`;oo`00;oooool2o`0005Oooooo000Nooooo`;o0000AOooool2o`0002oooooo0_oo000_ooooo`;o
0000Eoooool001kooooo00?o0000ooooooooool0A?ooool2o`0002oooooo00?oo`00ooooooooool0
;_ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000_ooooo`03ool00?oo
oooooooo02kooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`14ooooo`;o0000;oooool0
0ooo003oooooooooo`0^ooooo`;o0000Eoooool001kooooo00?o0000ooooooooool0A?ooool2o`00
02oooooo00?oo`00ooooooooool0;_ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo04Co
oooo0_l0000_ooooo`03ool00?oooooooooo02kooooo0_l0001Gooooo`007_ooool00ol0003ooooo
ooooo`14ooooo`;o0000;oooool00ooo003oooooooooo`0^ooooo`;o0000Eoooool001kooooo0_l0
0015ooooo`;o0000;oooool00ooo003oooooooooo`0^ooooo`;o0000Eoooool001kooooo00?o0000
ooooooooool0A?ooool2o`0002oooooo00?oo`00ooooooooool0;_ooool2o`0005Oooooo000Noooo
o`03o`000?oooooooooo04Cooooo0_l0000_ooooo`03ool00?oooooooooo02kooooo0_l0001Goooo
o`007_ooool00ol0003oooooooooo`14ooooo`;o0000;oooool00ooo003oooooooooo`0^ooooo`;o
0000Eoooool001kooooo00?o0000ooooooooool0A?ooool2o`0002oooooo00?oo`00ooooooooool0
;_ooool2o`0005Oooooo000;ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Ooo
ool00ol0003oooooooooo`14ooooo`;o0000;oooool00ooo003oooooooooo`0^ooooo`;o0000Eooo
ool000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0A?ooool2o`0002oooooo00?oo`00ooooooooool0;_ooool2o`0005Oooooo
000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo04Cooooo0_l0000_ooooo`03ool00?oooooooooo02kooooo0_l0001Gooooo`00
2_ooool01?l0003oooooooooool00008ooooo`?o00001Oooool3o`0004Cooooo0_l0000_ooooo`03
ool00?oooooooooo02kooooo0_l0001Gooooo`002_ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`14ooooo`;o0000;oooool00ooo
003oooooooooo`0^ooooo`;o0000Eoooool000[ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0A?ooool2o`0002oooooo00?oo`00
ooooooooool0;_ooool2o`0005Oooooo000;ooooo`;o00002Oooool3o`0000Gooooo00?o0000oooo
ooooool0A?ooool2o`0002oooooo00?oo`00ooooooooool0;_ooool2o`0005Oooooo000Nooooo`03
o`000?oooooooooo04Cooooo0_l0000_ooooo`03ool00?oooooooooo02kooooo0_l0001Gooooo`00
7_ooool00ol0003oooooooooo`14ooooo`;o0000;oooool00ooo003oooooooooo`0^ooooo`;o0000
Eoooool001kooooo00?o0000ooooooooool0A?ooool2o`0002oooooo00?oo`00ooooooooool0;_oo
ool2o`0005Oooooo000Nooooo`;o0000AOooool2o`0002oooooo00?oo`00ooooooooool0;_ooool2
o`0005Oooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000_ooooo`03ool00?oooooooooo
02kooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`14ooooo`;o0000;oooool00ooo003o
ooooooooo`0^ooooo`;o0000Eoooool001kooooo00?o0000ooooooooool0A?ooool2o`0002oooooo
00?oo`00ooooooooool0;_ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0
000_ooooo`03ool00?oooooooooo02kooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`14
ooooo`;o0000;oooool00ooo003oooooooooo`0^ooooo`;o0000Eoooool001kooooo00?o0000oooo
ooooool0A?ooool2o`0002oooooo00?oo`00ooooooooool0;_ooool2o`0005Oooooo000Nooooo`03
o`000?oooooooooo04Cooooo0_l0000_ooooo`03ool00?oooooooooo02kooooo0_l0001Gooooo`00
7_ooool2o`0004Gooooo0_l0000_ooooo`03ool00?oooooooooo02kooooo0_l0001Gooooo`007_oo
ool00ol0003oooooooooo`14ooooo`;o0000;oooool00ooo003oooooooooo`0^ooooo`03o`000?oo
oooooooo05Kooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000_ooooo`03ool00?oooooo
oooo02kooooo00?o0000ooooooooool0E_ooool001kooooo00?o0000ooooooooool0A?ooool2o`00
02oooooo00?oo`00ooooooooool0;_ooool00ol0003oooooooooo`1Fooooo`007_ooool00ol0003o
ooooooooo`14ooooo`;o0000;oooool00ooo003oooooooooo`0^ooooo`03o`000?oooooooooo05Ko
oooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000_ooooo`03ool00?oooooooooo02kooooo
00?o0000ooooooooool0E_ooool001kooooo00?o0000ooooooooool0A?ooool2o`0002oooooo00?o
o`00ooooooooool0;_ooool00ol0003oooooooooo`1Fooooo`007_ooool2o`0004Gooooo0_l0000_
ooooo`03ool00?oooooooooo02kooooo00?o0000ooooooooool0E_ooool001kooooo00?o0000oooo
ooooool0A?ooool2o`0002oooooo00?oo`00ooooooooool0;_ooool00ol0003oooooooooo`1Foooo
o`007_ooool00ol0003oooooooooo`14ooooo`;o0000;oooool00ooo003oooooooooo`0^ooooo`03
o`000?oooooooooo05Kooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000_ooooo`03ool0
0?oooooooooo02kooooo00?o0000ooooooooool0E_ooool001kooooo00?o0000ooooooooool0A?oo
ool2o`0002oooooo00?oo`00ooooooooool0;_ooool00ol0003oooooooooo`1Fooooo`005_ooool3
o`0000Gooooo00?o0000ooooooooool0A?ooool2o`0002oooooo00?oo`00ooooooooool0;_ooool0
0ol0003oooooooooo`1Fooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04Cooooo0_l0000_ooooo`03ool00?oooooooooo02kooooo00?o0000ooooooooool0E_ooool001Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo02ko
oooo00?oo`00ooooooooool0;_ooool00ol0003oooooooooo`1Fooooo`005oooool00ol0003ooooo
ooooo`04ooooo`?o0000A?ooool00ol0003oooooooooo`0^ooooo`03ool00?oooooooooo02kooooo
00?o0000ooooooooool0E_ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooo`005_ooool2o`0000Kooooo00?o0000ooooooooool0ooooool001Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00Hoooool3o`00057ooooo0ol0001Vooooo`00I?ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo06Gooooo000iooooo`?o00001?ooool3o`0000;ooooo1Ol000001Ooooooo
0000o`000?l0003ooooo00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o00000_ooool3o`00
00Cooooo0ol00003ooooo`Co00000_ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l00002
ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool01oooool3o`0000Gooooo0_l00000
0ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000;ooooo1Ol0
0002ooooo`?o00000_ooool3o`000003ooooool0003o000002gooooo000jooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003ooooo
o`0000Kooooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Cooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0002kooooo000jooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool5o`0000;ooooo0ol00002ooooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`00
00Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0/ooooo`00>_ooool3o`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0:ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`;o
00000oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`06
o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000002Oooool3o`0000?ooooo00Co0000oooooooooooo00000_oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`0/ooooo`00>_ooool01?l0003oooooooooool00002ooooo`?o00000_ooool3o`0000?ooooo1?l0
0002ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`Co00000_ooool2o`000003ooooool0
003o000000;ooooo0ol00003ooooo`;o00001?ooool3o`0000[ooooo00Co0000oooooooooooooooo
1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0003o
00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oooooooooo00;o
oooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co00000_ooool3o`00
00Cooooo0ol00002ooooo`Co0000;oooool003[ooooo00Co0000oooooooooooo00005?ooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool0
1?l0003oooooooooool0000Dooooo`03o`000?oooooooooo047ooooo000iooooo`Co00002_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0ol0000Kooooo`;o00002?ooool5
o`0000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00kooooo1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.768035, -0.0816802, \
0.0050905, 0.00671628}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00221618 0.0280925 0.561849 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.24543 -0.0125 -9 -9 ]
[.24543 -0.0125 9 0 ]
[.46704 -0.0125 -9 -9 ]
[.46704 -0.0125 9 0 ]
[.68866 -0.0125 -9 -9 ]
[.68866 -0.0125 9 0 ]
[.91028 -0.0125 -9 -9 ]
[.91028 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .14046 -18 -4.5 ]
[-0.0125 .14046 0 4.5 ]
[-0.0125 .25283 -18 -4.5 ]
[-0.0125 .25283 0 4.5 ]
[-0.0125 .3652 -18 -4.5 ]
[-0.0125 .3652 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -84 0 ]
[.5 .63053 84 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.24543 0 m
.24543 .00625 L
s
[(100)] .24543 -0.0125 0 1 Mshowa
.46704 0 m
.46704 .00625 L
s
[(200)] .46704 -0.0125 0 1 Mshowa
.68866 0 m
.68866 .00625 L
s
[(300)] .68866 -0.0125 0 1 Mshowa
.91028 0 m
.91028 .00625 L
s
[(400)] .91028 -0.0125 0 1 Mshowa
.125 Mabswid
.06813 0 m
.06813 .00375 L
s
.11246 0 m
.11246 .00375 L
s
.15678 0 m
.15678 .00375 L
s
.2011 0 m
.2011 .00375 L
s
.28975 0 m
.28975 .00375 L
s
.33407 0 m
.33407 .00375 L
s
.3784 0 m
.3784 .00375 L
s
.42272 0 m
.42272 .00375 L
s
.51137 0 m
.51137 .00375 L
s
.55569 0 m
.55569 .00375 L
s
.60002 0 m
.60002 .00375 L
s
.64434 0 m
.64434 .00375 L
s
.73299 0 m
.73299 .00375 L
s
.77731 0 m
.77731 .00375 L
s
.82163 0 m
.82163 .00375 L
s
.86596 0 m
.86596 .00375 L
s
.9546 0 m
.9546 .00375 L
s
.99893 0 m
.99893 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .14046 m
.00625 .14046 L
s
[(0.2)] -0.0125 .14046 1 0 Mshowa
0 .25283 m
.00625 .25283 L
s
[(0.4)] -0.0125 .25283 1 0 Mshowa
0 .3652 m
.00625 .3652 L
s
[(0.6)] -0.0125 .3652 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(0.8)] -0.0125 .47757 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(1)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.24543 .61178 m
.24543 .61803 L
s
.46704 .61178 m
.46704 .61803 L
s
.68866 .61178 m
.68866 .61803 L
s
.91028 .61178 m
.91028 .61803 L
s
.125 Mabswid
.06813 .61428 m
.06813 .61803 L
s
.11246 .61428 m
.11246 .61803 L
s
.15678 .61428 m
.15678 .61803 L
s
.2011 .61428 m
.2011 .61803 L
s
.28975 .61428 m
.28975 .61803 L
s
.33407 .61428 m
.33407 .61803 L
s
.3784 .61428 m
.3784 .61803 L
s
.42272 .61428 m
.42272 .61803 L
s
.51137 .61428 m
.51137 .61803 L
s
.55569 .61428 m
.55569 .61803 L
s
.60002 .61428 m
.60002 .61803 L
s
.64434 .61428 m
.64434 .61803 L
s
.73299 .61428 m
.73299 .61803 L
s
.77731 .61428 m
.77731 .61803 L
s
.82163 .61428 m
.82163 .61803 L
s
.86596 .61428 m
.86596 .61803 L
s
.9546 .61428 m
.9546 .61803 L
s
.99893 .61428 m
.99893 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .14046 m
1 .14046 L
s
.99375 .25283 m
1 .25283 L
s
.99375 .3652 m
1 .3652 L
s
.99375 .47757 m
1 .47757 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(Modulation Transfer Function)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .58994 m
.02427 .51021 L
.02474 .32574 L
.02521 .13796 L
.02567 .05901 L
.02614 .15766 L
.0266 .21079 L
.02707 .19319 L
.02753 .10713 L
.028 .05502 L
.02846 .13032 L
.02893 .15923 L
.02939 .14599 L
.02986 .09342 L
.03032 .04195 L
.03079 .11346 L
.03125 .14348 L
.03172 .12604 L
.03218 .07786 L
.03265 .03894 L
.03311 .09579 L
.03358 .1282 L
.03405 .11971 L
.03451 .0743 L
.03498 .04127 L
.03544 .09041 L
.03591 .11477 L
.03637 .10824 L
.03684 .07249 L
.0373 .03624 L
.03777 .08482 L
.03823 .11006 L
.0387 .10291 L
.03916 .06764 L
.03963 .03672 L
.04009 .07892 L
.04056 .10109 L
.04102 .09747 L
.04149 .06897 L
.04195 .03257 L
.04242 .07739 L
.04289 .1009 L
.04335 .09318 L
.04382 .06165 L
.04428 .03414 L
.04475 .06919 L
.04521 .09079 L
.04568 .09071 L
.04614 .06605 L
.04661 .03022 L
Mistroke
.04707 .06814 L
.04754 .08904 L
.048 .08702 L
.04847 .06402 L
.04893 .02816 L
.0494 .06333 L
.04986 .08432 L
.05033 .0838 L
.05079 .0634 L
.05126 .0308 L
.05172 .05915 L
.05219 .08164 L
.05266 .08342 L
.05312 .0634 L
.05359 .02971 L
.05405 .06069 L
.05452 .08259 L
.05498 .08386 L
.05545 .06412 L
.05591 .03156 L
.05638 .05714 L
.05684 .07794 L
.05731 .08033 L
.05777 .06381 L
.05824 .03441 L
.0587 .05293 L
.05917 .0741 L
.05963 .07783 L
.0601 .06307 L
.06056 .03497 L
.06103 .05249 L
.0615 .0747 L
.06196 .07893 L
.06243 .06389 L
.06289 .03581 L
.06336 .05106 L
.06382 .07335 L
.06429 .07901 L
.06475 .06598 L
.06522 .03962 L
.06568 .04599 L
.06615 .06774 L
.06661 .07423 L
.06708 .0633 L
.06754 .03928 L
.06801 .04475 L
.06847 .06624 L
.06894 .07406 L
.0694 .06546 L
.06987 .04304 L
Mistroke
.07034 .04136 L
.0708 .0645 L
.07127 .07403 L
.07173 .06735 L
.0722 .04742 L
.07266 .03528 L
.07313 .05921 L
.07359 .07127 L
.07406 .06654 L
.07452 .04735 L
.07499 .03467 L
.07545 .05788 L
.07592 .07057 L
.07638 .06803 L
.07685 .05086 L
.07731 .03063 L
.07778 .05454 L
.07824 .06867 L
.07871 .06825 L
.07918 .05318 L
.07964 .02857 L
.08011 .05251 L
.08057 .06829 L
.08104 .06953 L
.0815 .05628 L
.08197 .03319 L
.08243 .0479 L
.0829 .06551 L
.08336 .06939 L
.08383 .05855 L
.08429 .03733 L
.08476 .04309 L
.08522 .06204 L
.08569 .06884 L
.08615 .06098 L
.08662 .04168 L
.08708 .03806 L
.08755 .05779 L
.08801 .06709 L
.08848 .06256 L
.08895 .04567 L
.08941 .03335 L
.08988 .05368 L
.09034 .06461 L
.09081 .06269 L
.09127 .04848 L
.09174 .02936 L
.0922 .05053 L
.09267 .06343 L
.09313 .06382 L
Mistroke
.0936 .052 L
.09406 .03201 L
.09453 .0455 L
.09499 .0604 L
.09546 .06337 L
.09592 .0537 L
.09639 .03521 L
.09685 .04197 L
.09732 .05847 L
.09779 .0645 L
.09825 .05762 L
.09872 .04041 L
.09918 .03693 L
.09965 .05485 L
.10011 .06377 L
.10058 .06063 L
.10104 .0463 L
.10151 .03036 L
.10197 .04964 L
.10244 .06117 L
.1029 .06133 L
.10337 .05013 L
.10383 .03138 L
.1043 .04459 L
.10476 .0585 L
.10523 .06193 L
.10569 .05389 L
.10616 .03706 L
.10663 .03907 L
.10709 .05509 L
.10756 .06162 L
.10802 .05673 L
.10849 .04235 L
.10895 .03305 L
.10942 .05084 L
.10988 .06105 L
.11035 .06003 L
.11081 .0483 L
.11128 .03008 L
.11174 .04484 L
.11221 .05805 L
.11267 .06127 L
.11314 .05336 L
.1136 .03718 L
.11407 .03789 L
.11453 .05346 L
.115 .06086 L
.11547 .05761 L
.11593 .04467 L
.1164 .02959 L
Mistroke
.11686 .04652 L
.11733 .05683 L
.11779 .05738 L
.11826 .04798 L
.11872 .03165 L
.11919 .04223 L
.11965 .0553 L
.12012 .05962 L
.12058 .05396 L
.12105 .04003 L
.12151 .03404 L
.12198 .04996 L
.12244 .05859 L
.12291 .05728 L
.12337 .04664 L
.12384 .02998 L
.12431 .04373 L
.12477 .0564 L
.12524 .06006 L
.1257 .05376 L
.12617 .03975 L
.12663 .03379 L
.1271 .04922 L
.12756 .05776 L
.12803 .05662 L
.12849 .04631 L
.12896 .03026 L
.12942 .04278 L
.12989 .05537 L
.13035 .05967 L
.13082 .05426 L
.13128 .04097 L
.13175 .03203 L
.13221 .04726 L
.13268 .05634 L
.13314 .05644 L
.13361 .04747 L
.13408 .03238 L
.13454 .04017 L
.13501 .05284 L
.13547 .05808 L
.13594 .0542 L
.1364 .04233 L
.13687 .02997 L
.13733 .04532 L
.1378 .05536 L
.13826 .05717 L
.13873 .05011 L
.13919 .03627 L
.13966 .03619 L
Mistroke
.14012 .04986 L
.14059 .05696 L
.14105 .05545 L
.14152 .04564 L
.14198 .0304 L
.14245 .04168 L
.14292 .05333 L
.14338 .05745 L
.14385 .05295 L
.14431 .04101 L
.14478 .03116 L
.14524 .04624 L
.14571 .05577 L
.14617 .05712 L
.14664 .0501 L
.1471 .0367 L
.14757 .03547 L
.14803 .04924 L
.1485 .05659 L
.14896 .05551 L
.14943 .04656 L
.14989 .0323 L
.15036 .03937 L
.15082 .0515 L
.15129 .05662 L
.15176 .0534 L
.15222 .04291 L
.15269 .02811 L
.15315 .04302 L
.15362 .05369 L
.15408 .05696 L
.15455 .05209 L
.15501 .04065 L
.15548 .03039 L
.15594 .04457 L
.15641 .05397 L
.15687 .05586 L
.15734 .04994 L
.1578 .0381 L
.15827 .03253 L
.15873 .04567 L
.1592 .05374 L
.15966 .05445 L
.16013 .0478 L
.1606 .03581 L
.16106 .03445 L
.16153 .04684 L
.16199 .05406 L
.16246 .05408 L
.16292 .04712 L
Mistroke
.16339 .03524 L
.16385 .03461 L
.16432 .04655 L
.16478 .05351 L
.16525 .05356 L
.16571 .04689 L
.16618 .03547 L
.16664 .03391 L
.16711 .04552 L
.16757 .05244 L
.16804 .05282 L
.1685 .04674 L
.16897 .03595 L
.16943 .03304 L
.1699 .04464 L
.17037 .05192 L
.17083 .05291 L
.1713 .04748 L
.17176 .03719 L
.17223 .03162 L
.17269 .04349 L
.17316 .05149 L
.17362 .05345 L
.17409 .04897 L
.17455 .03927 L
.17502 .02951 L
.17548 .04193 L
.17595 .05091 L
.17641 .05406 L
.17688 .05067 L
.17734 .04171 L
.17781 .0293 L
.17827 .03978 L
.17874 .04981 L
.17921 .05435 L
.17967 .05235 L
.18014 .04442 L
.1806 .03245 L
.18107 .03687 L
.18153 .0478 L
.182 .05372 L
.18246 .05329 L
.18293 .04681 L
.18339 .03581 L
.18386 .03327 L
.18432 .04479 L
.18479 .05202 L
.18525 .05334 L
.18572 .04865 L
.18618 .03908 L
Mistroke
.18665 .02928 L
.18711 .041 L
.18758 .04939 L
.18805 .05261 L
.18851 .05015 L
.18898 .0426 L
.18944 .03168 L
.18991 .03612 L
.19037 .04564 L
.19084 .05103 L
.1913 .05126 L
.19177 .04632 L
.19223 .03728 L
.1927 .02988 L
.19316 .04023 L
.19363 .0478 L
.19409 .05109 L
.19456 .04935 L
.19502 .04289 L
.19549 .0332 L
.19595 .0337 L
.19642 .04318 L
.19689 .0495 L
.19735 .0512 L
.19782 .0478 L
.19828 .04007 L
.19875 .02975 L
.19921 .03722 L
.19968 .04622 L
.20014 .05142 L
.20061 .05154 L
.20107 .04658 L
.20154 .03767 L
.202 .02955 L
.20247 .04041 L
.20293 .04867 L
.2034 .05245 L
.20386 .05103 L
.20433 .0448 L
.20479 .03504 L
.20526 .0324 L
.20572 .04265 L
.20619 .04966 L
.20666 .05206 L
.20712 .04949 L
.20759 .04249 L
.20805 .03252 L
.20852 .03442 L
.20898 .04364 L
.20945 .0496 L
Mistroke
.20991 .05126 L
.21038 .04829 L
.21084 .04129 L
.21131 .0318 L
.21177 .03438 L
.21224 .04307 L
.2127 .0489 L
.21317 .05075 L
.21363 .04824 L
.2141 .04198 L
.21456 .03329 L
.21503 .03247 L
.2155 .04127 L
.21596 .04761 L
.21643 .05024 L
.21689 .04875 L
.21736 .04353 L
.21782 .03545 L
.21829 .03029 L
.21875 .03949 L
.21922 .04654 L
.21968 .05018 L
.22015 .04983 L
.22061 .04546 L
.22108 .03779 L
.22154 .02828 L
.22201 .03742 L
.22247 .04528 L
.22294 .05015 L
.2234 .05106 L
.22387 .04779 L
.22434 .04104 L
.2248 .03211 L
.22527 .03366 L
.22573 .0423 L
.2262 .04841 L
.22666 .05089 L
.22713 .04944 L
.22759 .04445 L
.22806 .03671 L
.22852 .0287 L
.22899 .03775 L
.22945 .04503 L
.22992 .04941 L
.23038 .05026 L
.23085 .04741 L
.23131 .04126 L
.23178 .03294 L
.23224 .03228 L
.23271 .04058 L
Mistroke
.23318 .0469 L
.23364 .05014 L
.23411 .0497 L
.23457 .04575 L
.23504 .03904 L
.2355 .03062 L
.23597 .0344 L
.23643 .04216 L
.2369 .04756 L
.23736 .04986 L
.23783 .04883 L
.23829 .04461 L
.23876 .03785 L
.23922 .02969 L
.23969 .03472 L
.24015 .04186 L
.24062 .04697 L
.24108 .04926 L
.24155 .04837 L
.24202 .04455 L
.24248 .03848 L
.24295 .03095 L
.24341 .03322 L
.24388 .04047 L
.24434 .04589 L
.24481 .0488 L
.24527 .0489 L
.24574 .04611 L
.2462 .04073 L
.24667 .0336 L
.24713 .03041 L
.2476 .0379 L
.24806 .04411 L
.24853 .04811 L
.24899 .04926 L
.24946 .04747 L
.24992 .04307 L
.25039 .03659 L
.25085 .02885 L
.25132 .03522 L
.25179 .04209 L
.25225 .04709 L
.25272 .04962 L
.25318 .04927 L
.25365 .04602 L
.25411 .04039 L
.25458 .03321 L
.25504 .03081 L
.25551 .03835 L
.25597 .04453 L
Mistroke
.25644 .04851 L
.2569 .04986 L
.25737 .04857 L
.25783 .04477 L
.2583 .03893 L
.25876 .03189 L
.25923 .03155 L
.25969 .03822 L
.26016 .04361 L
.26063 .04708 L
.26109 .04821 L
.26156 .04702 L
.26202 .04376 L
.26249 .03878 L
.26295 .03256 L
.26342 .03033 L
.26388 .03673 L
.26435 .04218 L
.26481 .04618 L
.26528 .04818 L
.26574 .04789 L
.26621 .04538 L
.26667 .04098 L
.26714 .03512 L
.2676 .02838 L
.26807 .03458 L
.26853 .04056 L
.269 .04515 L
.26947 .04794 L
.26993 .04863 L
.2704 .04711 L
.27086 .04367 L
.27133 .03879 L
.27179 .03292 L
.27226 .02962 L
.27272 .03578 L
.27319 .04111 L
.27365 .04519 L
.27412 .04773 L
.27458 .04841 L
.27505 .04708 L
.27551 .04389 L
.27598 .0392 L
.27644 .03337 L
.27691 .02929 L
.27737 .0357 L
.27784 .04132 L
.27831 .04563 L
.27877 .04829 L
.27924 .04899 L
Mistroke
.2797 .04762 L
.28017 .04444 L
.28063 .03985 L
.2811 .03427 L
.28156 .02817 L
.28203 .03402 L
.28249 .03935 L
.28296 .04361 L
.28342 .04654 L
.28389 .04786 L
.28435 .04742 L
.28482 .04535 L
.28528 .04193 L
.28575 .03739 L
.28621 .03208 L
.28668 .02967 L
.28714 .03497 L
.28761 .03964 L
.28808 .04343 L
.28854 .04605 L
.28901 .0473 L
.28947 .0472 L
.28994 .04588 L
.2904 .04336 L
.29087 .03973 L
.29133 .03526 L
.2918 .0303 L
.29226 .0311 L
.29273 .03624 L
.29319 .04087 L
.29366 .04452 L
.29412 .04693 L
.29459 .04794 L
.29505 .04739 L
.29552 .0453 L
.29598 .04194 L
.29645 .0377 L
.29692 .03289 L
.29738 .02837 L
.29785 .03331 L
.29831 .03776 L
.29878 .04155 L
.29924 .04457 L
.29971 .04663 L
.30017 .04755 L
.30064 .04732 L
.3011 .04599 L
.30157 .04352 L
.30203 .03997 L
.3025 .0356 L
Mistroke
.30296 .03078 L
.30343 .03039 L
.30389 .03525 L
.30436 .0396 L
.30482 .04312 L
.30529 .04568 L
.30576 .04724 L
.30622 .04771 L
.30669 .04706 L
.30715 .04542 L
.30762 .04296 L
.30808 .03975 L
.30855 .03589 L
.30901 .03164 L
.30948 .02892 L
.30994 .03322 L
.31041 .03725 L
.31087 .04071 L
.31134 .04336 L
.3118 .04516 L
.31227 .04615 L
.31273 .04629 L
.3132 .04558 L
.31366 .04419 L
.31413 .04225 L
.3146 .03981 L
.31506 .03685 L
.31553 .03351 L
.31599 .02993 L
.31646 .03 L
.31692 .03386 L
.31739 .03757 L
.31785 .04087 L
.31832 .04363 L
.31878 .04575 L
.31925 .04709 L
.31971 .04753 L
.32018 .04713 L
.32064 .04601 L
.32111 .04419 L
.32157 .0417 L
.32204 .03872 L
.3225 .03541 L
.32297 .03184 L
.32343 .02812 L
.3239 .03189 L
.32437 .03545 L
.32483 .0387 L
.3253 .04156 L
.32576 .04384 L
Mistroke
.32623 .04543 L
.32669 .04637 L
.32716 .04674 L
.32762 .04654 L
.32809 .04576 L
.32855 .04451 L
.32902 .04291 L
.32948 .04094 L
.32995 .03854 L
.33041 .0358 L
.33088 .03282 L
.33134 .02963 L
.33181 .0299 L
.33227 .03321 L
.33274 .03626 L
.33321 .03898 L
.33367 .04133 L
.33414 .0432 L
.3346 .04453 L
.33507 .04536 L
.33553 .0458 L
.336 .04583 L
.33646 .04544 L
.33693 .04471 L
.33739 .04368 L
.33786 .04233 L
.33832 .04063 L
.33879 .03867 L
.33925 .03656 L
.33972 .03433 L
.34018 .03198 L
.34065 .02961 L
.34111 .02889 L
.34158 .03119 L
.34205 .03351 L
.34251 .03579 L
.34298 .03796 L
.34344 .04007 L
.34391 .0421 L
.34437 .04394 L
.34484 .04542 L
.3453 .04654 L
.34577 .04729 L
.34623 .04759 L
.3467 .04737 L
.34716 .04671 L
.34763 .04575 L
.34809 .04452 L
.34856 .04306 L
.34902 .04148 L
Mistroke
.34949 .03989 L
.34995 .03824 L
.35042 .03646 L
.35089 .03459 L
.35135 .03267 L
.35182 .03069 L
.35228 .02859 L
.35275 .02971 L
.35321 .03175 L
.35368 .0337 L
.35414 .03555 L
.35461 .03724 L
.35507 .03872 L
.35554 .04005 L
.356 .04128 L
.35647 .04237 L
.35693 .04329 L
.3574 .04408 L
.35786 .0448 L
.35833 .04539 L
.35879 .04579 L
.35926 .04599 L
.35973 .04604 L
.36019 .04589 L
.36066 .0455 L
.36112 .04497 L
.36159 .0444 L
.36205 .04376 L
.36252 .04306 L
.36298 .04237 L
.36345 .04174 L
.36391 .0411 L
.36438 .04035 L
.36484 .03953 L
.36531 .03867 L
.36577 .03774 L
.36624 .03669 L
.3667 .03558 L
.36717 .03448 L
.36763 .03336 L
.3681 .03218 L
.36856 .03102 L
.36903 .02994 L
.3695 .02887 L
.36996 .02846 L
.37043 .02965 L
.37089 .03081 L
.37136 .03198 L
.37182 .03323 L
.37229 .03446 L
Mistroke
.37275 .03558 L
.37322 .0366 L
.37368 .03755 L
.37415 .03839 L
.37461 .03908 L
.37508 .0397 L
.37554 .04031 L
.37601 .04087 L
.37647 .04132 L
.37694 .04173 L
.3774 .04217 L
.37787 .04262 L
.37834 .043 L
.3788 .04336 L
.37927 .04373 L
.37973 .04408 L
.3802 .04433 L
.38066 .0445 L
.38113 .04465 L
.38159 .04475 L
.38206 .04477 L
.38252 .04477 L
.38299 .04481 L
.38345 .04486 L
.38392 .04489 L
.38438 .04494 L
.38485 .04508 L
.38531 .04524 L
.38578 .04533 L
.38624 .04536 L
.38671 .04534 L
.38718 .04524 L
.38764 .04502 L
.38811 .04477 L
.38857 .04455 L
.38904 .04437 L
.3895 .04421 L
.38997 .04413 L
.39043 .04416 L
.3909 .04425 L
.39136 .04434 L
.39183 .04446 L
.39229 .04463 L
.39276 .0448 L
.39322 .04489 L
.39369 .04492 L
.39415 .04496 L
.39462 .04499 L
.39508 .04496 L
.39555 .0449 L
Mistroke
.39602 .04485 L
.39648 .04477 L
.39695 .04464 L
.39741 .04451 L
.39788 .04444 L
.39834 .04441 L
.39881 .04438 L
.39927 .04438 L
.39974 .04444 L
.4002 .04447 L
.40067 .04438 L
.40113 .04422 L
.4016 .04405 L
.40206 .04382 L
.40253 .04348 L
.40299 .04309 L
.40346 .04269 L
.40392 .04231 L
.40439 .0419 L
.40485 .0415 L
.40532 .04111 L
.40579 .04064 L
.40625 .04004 L
.40672 .03932 L
.40718 .03852 L
.40765 .03759 L
.40811 .03653 L
.40858 .03541 L
.40904 .03429 L
.40951 .03312 L
.40997 .03187 L
.41044 .03062 L
.4109 .02945 L
.41137 .02834 L
.41183 .02895 L
.4123 .03001 L
.41276 .03097 L
.41323 .03186 L
.41369 .03273 L
.41416 .03357 L
.41463 .03438 L
.41509 .03525 L
.41556 .03623 L
.41602 .03727 L
.41649 .03832 L
.41695 .03936 L
.41742 .04039 L
.41788 .04133 L
.41835 .04212 L
.41881 .04283 L
Mistroke
.41928 .04347 L
.41974 .04399 L
.42021 .04431 L
.42067 .04449 L
.42114 .04459 L
.4216 .04458 L
.42207 .04441 L
.42253 .04408 L
.423 .04365 L
.42347 .0431 L
.42393 .04241 L
.4244 .04163 L
.42486 .04077 L
.42533 .03977 L
.42579 .03857 L
.42626 .03717 L
.42672 .03561 L
.42719 .03387 L
.42765 .03197 L
.42812 .03 L
.42858 .02817 L
.42905 .03019 L
.42951 .03223 L
.42998 .03421 L
.43044 .03604 L
.43091 .03775 L
.43137 .0394 L
.43184 .04091 L
.43231 .04219 L
.43277 .04322 L
.43324 .04404 L
.4337 .0446 L
.43417 .04486 L
.43463 .04486 L
.4351 .04465 L
.43556 .04418 L
.43603 .04337 L
.43649 .04222 L
.43696 .04078 L
.43742 .03907 L
.43789 .0371 L
.43835 .03492 L
.43882 .03261 L
.43928 .03021 L
.43975 .02843 L
.44021 .03084 L
.44068 .03311 L
.44114 .03527 L
.44161 .03731 L
.44208 .03912 L
Mistroke
.44254 .04061 L
.44301 .04181 L
.44347 .04274 L
.44394 .04335 L
.4444 .0436 L
.44487 .04354 L
.44533 .04316 L
.4458 .04237 L
.44626 .04107 L
.44673 .03933 L
.44719 .03724 L
.44766 .03484 L
.44812 .03214 L
.44859 .02925 L
.44905 .02985 L
.44952 .03271 L
.44998 .03547 L
.45045 .03804 L
.45092 .0403 L
.45138 .04219 L
.45185 .04365 L
.45231 .04457 L
.45278 .04485 L
.45324 .04451 L
.45371 .04361 L
.45417 .04216 L
.45464 .04017 L
.4551 .03771 L
.45557 .03485 L
.45603 .03167 L
.4565 .02829 L
.45696 .03129 L
.45743 .03453 L
.45789 .03754 L
.45836 .04019 L
.45882 .04231 L
.45929 .04377 L
.45976 .04457 L
.46022 .04476 L
.46069 .04425 L
.46115 .04303 L
.46162 .04115 L
.46208 .03876 L
.46255 .03592 L
.46301 .03276 L
.46348 .02945 L
.46394 .03001 L
.46441 .03321 L
.46487 .03627 L
.46534 .039 L
Mistroke
.4658 .04118 L
.46627 .04271 L
.46673 .04353 L
.4672 .04355 L
.46766 .04266 L
.46813 .04092 L
.4686 .03849 L
.46906 .0355 L
.46953 .03208 L
.46999 .02845 L
.47046 .03138 L
.47092 .03484 L
.47139 .03796 L
.47185 .04053 L
.47232 .04232 L
.47278 .04327 L
.47325 .04338 L
.47371 .04263 L
.47418 .04098 L
.47464 .03846 L
.47511 .03517 L
.47557 .03128 L
.47604 .02919 L
.4765 .03355 L
.47697 .03764 L
.47744 .04113 L
.4779 .04375 L
.47837 .04524 L
.47883 .04548 L
.4793 .0445 L
.47976 .04238 L
.48023 .03925 L
.48069 .03529 L
.48116 .03081 L
.48162 .02998 L
.48209 .03436 L
.48255 .03822 L
.48302 .04128 L
.48348 .04332 L
.48395 .04424 L
.48441 .04393 L
.48488 .04235 L
.48534 .03955 L
.48581 .03577 L
.48627 .03131 L
.48674 .02971 L
.48721 .03451 L
.48767 .03879 L
.48814 .04216 L
.4886 .04436 L
Mistroke
.48907 .04527 L
.48953 .04479 L
.49 .0429 L
.49046 .03979 L
.49093 .03573 L
.49139 .0311 L
.49186 .02989 L
.49232 .0344 L
.49279 .03827 L
.49325 .04122 L
.49372 .04301 L
.49418 .04343 L
.49465 .04237 L
.49511 .03995 L
.49558 .03639 L
.49605 .03196 L
.49651 .02913 L
.49698 .03397 L
.49744 .03817 L
.49791 .04135 L
.49837 .04325 L
.49884 .04366 L
.4993 .04249 L
.49977 .03985 L
.50023 .03601 L
.5007 .03136 L
.50116 .02978 L
.50163 .0345 L
.50209 .03847 L
.50256 .04134 L
.50302 .04279 L
.50349 .04257 L
.50395 .04059 L
.50442 .03703 L
.50489 .03229 L
.50535 .02934 L
.50582 .03484 L
.50628 .03964 L
.50675 .04304 L
.50721 .04462 L
.50768 .04422 L
.50814 .04187 L
.50861 .03779 L
.50907 .03248 L
.50954 .02954 L
.51 .03517 L
.51047 .03985 L
.51093 .04297 L
.5114 .04413 L
.51186 .04326 L
Mistroke
.51233 .04048 L
.51279 .03606 L
.51326 .03048 L
.51373 .0317 L
.51419 .03733 L
.51466 .04186 L
.51512 .04465 L
.51559 .04522 L
.51605 .04342 L
.51652 .03954 L
.51698 .03418 L
.51745 .02814 L
.51791 .03424 L
.51838 .03946 L
.51884 .04301 L
.51931 .04439 L
.51977 .04345 L
.52024 .04035 L
.5207 .03555 L
.52117 .02976 L
.52163 .03238 L
.5221 .03772 L
.52256 .0417 L
.52303 .04369 L
.5235 .04333 L
.52396 .04065 L
.52443 .03599 L
.52489 .03001 L
.52536 .03254 L
.52582 .03825 L
.52629 .04237 L
.52675 .04432 L
.52722 .04385 L
.52768 .04096 L
.52815 .03607 L
.52861 .03001 L
.52908 .03235 L
.52954 .03769 L
.53001 .04142 L
.53047 .04298 L
.53094 .04212 L
.5314 .03898 L
.53187 .03407 L
.53234 .02814 L
.5328 .03411 L
.53327 .03925 L
.53373 .0425 L
.5342 .04319 L
.53466 .04116 L
.53513 .03675 L
Mistroke
.53559 .03071 L
.53606 .03206 L
.53652 .038 L
.53699 .04222 L
.53745 .04389 L
.53792 .04262 L
.53838 .03866 L
.53885 .03279 L
.53931 .03004 L
.53978 .03627 L
.54024 .04096 L
.54071 .04317 L
.54118 .04241 L
.54164 .03881 L
.54211 .03301 L
.54257 .03013 L
.54304 .03686 L
.5435 .0419 L
.54397 .04411 L
.54443 .04302 L
.5449 .03889 L
.54536 .03251 L
.54583 .03111 L
.54629 .03805 L
.54676 .04302 L
.54722 .04495 L
.54769 .04351 L
.54815 .03902 L
.54862 .03238 L
.54908 .03125 L
.54955 .03798 L
.55002 .04267 L
.55048 .04439 L
.55095 .04273 L
.55141 .03795 L
.55188 .03101 L
.55234 .03278 L
.55281 .03938 L
.55327 .0435 L
.55374 .04423 L
.5542 .04141 L
.55467 .03565 L
.55513 .02818 L
.5556 .03557 L
.55606 .04153 L
.55653 .04449 L
.55699 .0438 L
.55746 .0397 L
.55792 .03314 L
.55839 .03068 L
Mistroke
.55886 .03776 L
.55932 .0427 L
.55979 .04437 L
.56025 .0424 L
.56072 .03718 L
.56118 .02984 L
.56165 .03413 L
.56211 .04043 L
.56258 .04371 L
.56304 .04328 L
.56351 .0393 L
.56397 .03267 L
.56444 .03124 L
.5649 .03816 L
.56537 .04253 L
.56583 .04332 L
.5663 .04047 L
.56676 .03468 L
.56723 .02888 L
.56769 .03605 L
.56816 .04128 L
.56863 .04332 L
.56909 .04166 L
.56956 .0366 L
.57002 .02927 L
.57049 .03468 L
.57095 .04083 L
.57142 .04378 L
.57188 .0428 L
.57235 .03813 L
.57281 .03088 L
.57328 .03328 L
.57374 .03987 L
.57421 .04337 L
.57467 .04293 L
.57514 .03872 L
.5756 .03186 L
.57607 .03204 L
.57653 .0386 L
.577 .04231 L
.57747 .04222 L
.57793 .0383 L
.5784 .03151 L
.57886 .03249 L
.57933 .0391 L
.57979 .04258 L
.58026 .04191 L
.58072 .03726 L
.58119 .02989 L
.58165 .0343 L
Mistroke
.58212 .04062 L
.58258 .04338 L
.58305 .04175 L
.58351 .03614 L
.58398 .02816 L
.58444 .03609 L
.58491 .04193 L
.58537 .04389 L
.58584 .04139 L
.58631 .03501 L
.58677 .02971 L
.58724 .03795 L
.5877 .04341 L
.58817 .04439 L
.58863 .04054 L
.5891 .03296 L
.58956 .0323 L
.59003 .04016 L
.59049 .04443 L
.59096 .0438 L
.59142 .03845 L
.59189 .02997 L
.59235 .03521 L
.59282 .04196 L
.59328 .04444 L
.59375 .04195 L
.59421 .03528 L
.59468 .0298 L
.59515 .03826 L
.59561 .04365 L
.59608 .0442 L
.59654 .03965 L
.59701 .03138 L
.59747 .03422 L
.59794 .04179 L
.5984 .04511 L
.59887 .04308 L
.59933 .0363 L
.5998 .02929 L
.60026 .0384 L
.60073 .0443 L
.60119 .04509 L
.60166 .04054 L
.60212 .03213 L
.60259 .03367 L
.60305 .04154 L
.60352 .04525 L
.60398 .04355 L
.60445 .03691 L
.60492 .02878 L
Mistroke
.60538 .03806 L
.60585 .04409 L
.60631 .04493 L
.60678 .04032 L
.60724 .03178 L
.60771 .03406 L
.60817 .04166 L
.60864 .04476 L
.6091 .04235 L
.60957 .03529 L
.61003 .03022 L
.6105 .03868 L
.61096 .04351 L
.61143 .04319 L
.61189 .03787 L
.61236 .02927 L
.61282 .03597 L
.61329 .04236 L
.61376 .04385 L
.61422 .0399 L
.61469 .03188 L
.61515 .03365 L
.61562 .04111 L
.61608 .04409 L
.61655 .04154 L
.61701 .03435 L
.61748 .03118 L
.61794 .03945 L
.61841 .0438 L
.61887 .04274 L
.61934 .03664 L
.6198 .02858 L
.62027 .0375 L
.62073 .04329 L
.6212 .0439 L
.62166 .03902 L
.62213 .03025 L
.6226 .03552 L
.62306 .04252 L
.62353 .04447 L
.62399 .04072 L
.62446 .03256 L
.62492 .03334 L
.62539 .04116 L
.62585 .04432 L
.62632 .04175 L
.62678 .03442 L
.62725 .03123 L
.62771 .03953 L
.62818 .04377 L
Mistroke
.62864 .04249 L
.62911 .03613 L
.62957 .02924 L
.63004 .038 L
.6305 .04316 L
.63097 .04282 L
.63144 .03712 L
.6319 .02821 L
.63237 .03683 L
.63283 .0424 L
.6333 .04269 L
.63376 .0376 L
.63423 .02903 L
.63469 .03599 L
.63516 .04182 L
.63562 .04258 L
.63609 .03805 L
.63655 .02989 L
.63702 .03513 L
.63748 .04138 L
.63795 .04267 L
.63841 .03849 L
.63888 .0304 L
.63934 .03473 L
.63981 .04117 L
.64027 .04265 L
.64074 .0386 L
.64121 .03054 L
.64167 .03466 L
.64214 .04124 L
.6426 .04289 L
.64307 .03898 L
.64353 .03097 L
.644 .03432 L
.64446 .04114 L
.64493 .04316 L
.64539 .0396 L
.64586 .0317 L
.64632 .0338 L
.64679 .04096 L
.64725 .0432 L
.64772 .03968 L
.64818 .03178 L
.64865 .03371 L
.64911 .0409 L
.64958 .04322 L
.65005 .03975 L
.65051 .03182 L
.65098 .03371 L
.65144 .04092 L
Mistroke
.65191 .04329 L
.65237 .03994 L
.65284 .03207 L
.6533 .03357 L
.65377 .041 L
.65423 .04355 L
.6547 .0402 L
.65516 .03218 L
.65563 .03365 L
.65609 .0412 L
.65656 .04377 L
.65702 .04041 L
.65749 .03238 L
.65795 .03347 L
.65842 .04111 L
.65889 .0438 L
.65935 .04052 L
.65982 .03256 L
.66028 .03322 L
.66075 .04086 L
.66121 .04367 L
.66168 .04051 L
.66214 .03253 L
.66261 .0334 L
.66307 .04113 L
.66354 .04389 L
.664 .04065 L
.66447 .03263 L
.66493 .03334 L
.6654 .04115 L
.66586 .044 L
.66633 .04081 L
.66679 .03283 L
.66726 .0331 L
.66773 .04092 L
.66819 .04386 L
.66866 .0408 L
.66912 .03285 L
.66959 .03318 L
.67005 .04117 L
.67052 .04427 L
.67098 .04125 L
.67145 .03324 L
.67191 .03291 L
.67238 .04108 L
.67284 .04441 L
.67331 .04164 L
.67377 .03378 L
.67424 .03241 L
.6747 .04077 L
Mistroke
.67517 .04435 L
.67563 .04183 L
.6761 .03415 L
.67657 .03208 L
.67703 .04079 L
.6775 .04488 L
.67796 .04278 L
.67843 .03527 L
.67889 .03106 L
.67936 .04011 L
.67982 .04478 L
.68029 .04335 L
.68075 .0363 L
.68122 .02995 L
.68168 .03933 L
.68215 .0446 L
.68261 .04387 L
.68308 .03738 L
.68354 .02872 L
.68401 .03849 L
.68447 .04461 L
.68494 .04488 L
.6854 .03924 L
.68587 .0297 L
.68634 .03652 L
.6868 .04346 L
.68727 .04487 L
.68773 .04029 L
.6882 .03135 L
.68866 .03495 L
.68913 .04267 L
.68959 .04527 L
.69006 .04186 L
.69052 .0337 L
.69099 .0325 L
.69145 .04091 L
.69192 .04485 L
.69238 .04296 L
.69285 .03596 L
.69331 .02985 L
.69378 .03874 L
.69424 .04385 L
.69471 .04345 L
.69518 .03768 L
.69564 .02851 L
.69611 .03706 L
.69657 .0434 L
.69704 .04455 L
.6975 .04019 L
.69797 .0318 L
Mistroke
.69843 .03395 L
.6989 .04144 L
.69936 .04431 L
.69983 .04159 L
.70029 .03417 L
.70076 .03175 L
.70122 .0406 L
.70169 .04562 L
.70215 .04507 L
.70262 .03905 L
.70308 .02948 L
.70355 .03678 L
.70402 .04412 L
.70448 .04633 L
.70495 .04266 L
.70541 .03423 L
.70588 .03255 L
.70634 .0421 L
.70681 .0477 L
.70727 .04763 L
.70774 .04187 L
.7082 .03214 L
.70867 .03475 L
.70913 .04321 L
.7096 .04685 L
.71006 .04459 L
.71053 .03715 L
.71099 .02931 L
.71146 .03926 L
.71192 .04587 L
.71239 .04716 L
.71286 .04274 L
.71332 .03383 L
.71379 .03316 L
.71425 .04275 L
.71472 .04834 L
.71518 .04828 L
.71565 .0425 L
.71611 .03262 L
.71658 .0347 L
.71704 .04393 L
.71751 .04873 L
.71797 .04783 L
.71844 .04153 L
.7189 .03159 L
.71937 .03544 L
.71983 .0443 L
.7203 .04888 L
.72076 .04803 L
.72123 .04196 L
Mistroke
.72169 .03225 L
.72216 .0347 L
.72263 .04368 L
.72309 .04865 L
.72356 .04847 L
.72402 .04332 L
.72449 .03456 L
.72495 .0318 L
.72542 .04097 L
.72588 .04707 L
.72635 .04882 L
.72681 .0459 L
.72728 .03899 L
.72774 .02967 L
.72821 .03614 L
.72867 .04391 L
.72914 .04821 L
.7296 .04822 L
.73007 .04409 L
.73053 .03681 L
.731 .02832 L
.73147 .03721 L
.73193 .04439 L
.7324 .04851 L
.73286 .0488 L
.73333 .04518 L
.73379 .0383 L
.73426 .0294 L
.73472 .036 L
.73519 .04377 L
.73565 .04872 L
.73612 .05015 L
.73658 .04792 L
.73705 .04242 L
.73751 .03449 L
.73798 .03077 L
.73844 .03956 L
.73891 .04668 L
.73937 .05103 L
.73984 .05188 L
.74031 .04909 L
.74077 .04319 L
.74124 .03521 L
.7417 .02986 L
.74217 .03853 L
.74263 .04595 L
.7431 .05122 L
.74356 .0537 L
.74403 .05304 L
.74449 .04931 L
Mistroke
.74496 .04299 L
.74542 .03492 L
.74589 .03006 L
.74635 .03851 L
.74682 .04574 L
.74728 .05117 L
.74775 .05448 L
.74821 .05555 L
.74868 .05436 L
.74915 .05102 L
.74961 .04595 L
.75008 .03973 L
.75054 .03296 L
.75101 .0301 L
.75147 .03674 L
.75194 .04292 L
.7524 .04855 L
.75287 .05362 L
.75333 .058 L
.7538 .06138 L
.75426 .06347 L
.75473 .06416 L
.75519 .06363 L
.75566 .06212 L
.75612 .05986 L
.75659 .05711 L
.75705 .0541 L
.75752 .05101 L
.75798 .04795 L
.75845 .04505 L
.75892 .04246 L
.75938 .04033 L
.75985 .03868 L
.76031 .03739 L
.76078 .0362 L
.76124 .03494 L
.76171 .03361 L
.76217 .03237 L
.76264 .03133 L
.7631 .03051 L
.76357 .02992 L
.76403 .02953 L
.7645 .02922 L
.76496 .02878 L
.76543 .02817 L
.76589 .02864 L
.76636 .029 L
.76682 .02896 L
.76729 .02858 L
.76776 .02817 L
Mistroke
.76822 .02878 L
.76869 .02928 L
.76915 .02954 L
.76962 .02949 L
.77008 .02918 L
.77055 .02875 L
.77101 .02834 L
.77148 .0282 L
.77194 .02856 L
.77241 .02898 L
.77287 .02937 L
.77334 .02956 L
.7738 .02949 L
.77427 .02917 L
.77473 .02867 L
.7752 .02815 L
.77566 .0288 L
.77613 .02924 L
.7766 .02928 L
.77706 .02895 L
.77753 .02849 L
.77799 .02813 L
.77846 .02818 L
.77892 .02813 L
.77939 .02846 L
.77985 .02888 L
.78032 .02927 L
.78078 .02943 L
.78125 .02922 L
.78171 .0286 L
.78218 .02844 L
.78264 .02923 L
.78311 .02978 L
.78357 .03007 L
.78404 .03011 L
.7845 .02985 L
.78497 .02932 L
.78544 .02869 L
.7859 .02819 L
.78637 .0282 L
.78683 .02812 L
.7873 .02831 L
.78776 .02857 L
.78823 .02876 L
.78869 .02888 L
.78916 .02888 L
.78962 .02868 L
.79009 .02824 L
.79055 .02851 L
.79102 .02899 L
Mistroke
.79148 .02926 L
.79195 .02937 L
.79241 .02939 L
.79288 .02927 L
.79334 .02896 L
.79381 .02845 L
.79428 .02832 L
.79474 .02882 L
.79521 .02912 L
.79567 .02922 L
.79614 .02919 L
.7966 .02912 L
.79707 .02898 L
.79753 .02871 L
.798 .02835 L
.79846 .02811 L
.79893 .02816 L
.79939 .02813 L
.79986 .02827 L
.80032 .02841 L
.80079 .0285 L
.80125 .02858 L
.80172 .02865 L
.80218 .0287 L
.80265 .02865 L
.80311 .02843 L
.80358 .0281 L
.80405 .02842 L
.80451 .02859 L
.80498 .02867 L
.80544 .02873 L
.80591 .02878 L
.80637 .02876 L
.80684 .02865 L
.8073 .02842 L
.80777 .02811 L
.80823 .02845 L
.8087 .02863 L
.80916 .02858 L
.80963 .02844 L
.81009 .02835 L
.81056 .0283 L
.81102 .02824 L
.81149 .02814 L
.81195 .0282 L
.81242 .02837 L
.81289 .02847 L
.81335 .02838 L
.81382 .0281 L
.81428 .02838 L
Mistroke
.81475 .02855 L
.81521 .02862 L
.81568 .02866 L
.81614 .02869 L
.81661 .02869 L
.81707 .0287 L
.81754 .02874 L
.818 .02868 L
.81847 .02845 L
.81893 .02813 L
.8194 .02829 L
.81986 .02838 L
.82033 .02839 L
.82079 .02832 L
.82126 .02817 L
.82173 .02818 L
.82219 .02822 L
.82266 .02818 L
.82312 .02818 L
.82359 .02832 L
.82405 .02851 L
.82452 .02868 L
.82498 .02886 L
.82545 .02904 L
.82591 .0291 L
.82638 .02897 L
.82684 .02868 L
.82731 .02838 L
.82777 .02811 L
.82824 .02834 L
.8287 .02858 L
.82917 .0287 L
.82963 .02868 L
.8301 .02858 L
.83057 .02851 L
.83103 .02846 L
.8315 .02835 L
.83196 .02817 L
.83243 .02816 L
.83289 .02821 L
.83336 .02821 L
.83382 .02828 L
.83429 .02838 L
.83475 .02841 L
.83522 .02833 L
.83568 .02825 L
.83615 .02826 L
.83661 .02827 L
.83708 .02816 L
.83754 .02819 L
Mistroke
.83801 .02829 L
.83847 .02831 L
.83894 .02832 L
.8394 .02841 L
.83987 .02851 L
.84034 .02855 L
.8408 .02851 L
.84127 .02847 L
.84173 .02846 L
.8422 .02849 L
.84266 .02848 L
.84313 .0284 L
.84359 .02826 L
.84406 .02819 L
.84452 .02818 L
.84499 .02819 L
.84545 .02811 L
.84592 .02822 L
.84638 .02834 L
.84685 .02837 L
.84731 .02832 L
.84778 .02827 L
.84824 .02828 L
.84871 .02835 L
.84918 .0284 L
.84964 .02836 L
.85011 .02824 L
.85057 .02815 L
.85104 .02817 L
.8515 .02825 L
.85197 .02828 L
.85243 .02824 L
.8529 .02814 L
.85336 .02815 L
.85383 .02821 L
.85429 .02817 L
.85476 .02814 L
.85522 .02824 L
.85569 .02824 L
.85615 .02814 L
.85662 .0282 L
.85708 .02835 L
.85755 .02846 L
.85802 .0285 L
.85848 .02847 L
.85895 .02843 L
.85941 .02842 L
.85988 .0284 L
.86034 .02838 L
.86081 .02839 L
Mistroke
.86127 .02845 L
.86174 .02848 L
.8622 .02846 L
.86267 .02845 L
.86313 .02846 L
.8636 .02846 L
.86406 .02843 L
.86453 .02844 L
.86499 .02847 L
.86546 .02848 L
.86592 .02845 L
.86639 .02844 L
.86686 .02848 L
.86732 .0285 L
.86779 .02844 L
.86825 .02841 L
.86872 .02845 L
.86918 .0285 L
.86965 .02845 L
.87011 .02838 L
.87058 .02839 L
.87104 .02843 L
.87151 .0284 L
.87197 .02832 L
.87244 .02829 L
.8729 .02834 L
.87337 .02835 L
.87383 .02827 L
.8743 .02821 L
.87476 .02824 L
.87523 .0283 L
.87569 .02829 L
.87616 .02821 L
.87663 .02819 L
.87709 .02824 L
.87756 .02831 L
.87802 .02832 L
.87849 .02825 L
.87895 .02817 L
.87942 .02814 L
.87988 .02816 L
.88035 .02812 L
.88081 .02821 L
.88128 .02838 L
.88174 .02848 L
.88221 .02847 L
.88267 .0284 L
.88314 .02831 L
.8836 .02827 L
.88407 .02829 L
Mistroke
.88453 .02837 L
.885 .02843 L
.88547 .0284 L
.88593 .02834 L
.8864 .0283 L
.88686 .02826 L
.88733 .02818 L
.88779 .02811 L
.88826 .02814 L
.88872 .02818 L
.88919 .02824 L
.88965 .0283 L
.89012 .02834 L
.89058 .02836 L
.89105 .0284 L
.89151 .02842 L
.89198 .0284 L
.89244 .02835 L
.89291 .0283 L
.89337 .02823 L
.89384 .02812 L
.89431 .02817 L
.89477 .02824 L
.89524 .02829 L
.8957 .02837 L
.89617 .02842 L
.89663 .0284 L
.8971 .02834 L
.89756 .0283 L
.89803 .02825 L
.89849 .02813 L
.89896 .0282 L
.89942 .02828 L
.89989 .02832 L
.90035 .02836 L
.90082 .02842 L
.90128 .02838 L
.90175 .02825 L
.90221 .02812 L
.90268 .02814 L
.90315 .02822 L
.90361 .02834 L
.90408 .0284 L
.90454 .02834 L
.90501 .02821 L
.90547 .02815 L
.90594 .02815 L
.9064 .02814 L
.90687 .02813 L
.90733 .02827 L
Mistroke
.9078 .02838 L
.90826 .0284 L
.90873 .02831 L
.90919 .02816 L
.90966 .02817 L
.91012 .02828 L
.91059 .02834 L
.91105 .02835 L
.91152 .0283 L
.91199 .0282 L
.91245 .02812 L
.91292 .02826 L
.91338 .02835 L
.91385 .02836 L
.91431 .0283 L
.91478 .0282 L
.91524 .02809 L
.91571 .0282 L
.91617 .02831 L
.91664 .02836 L
.9171 .02828 L
.91757 .02813 L
.91803 .02821 L
.9185 .02831 L
.91896 .02835 L
.91943 .0283 L
.91989 .02816 L
.92036 .0282 L
.92082 .02832 L
.92129 .02834 L
.92176 .0283 L
.92222 .0282 L
.92269 .02816 L
.92315 .02832 L
.92362 .02836 L
.92408 .02826 L
.92455 .0281 L
.92501 .02825 L
.92548 .02835 L
.92594 .02834 L
.92641 .02818 L
.92687 .02825 L
.92734 .02839 L
.9278 .02833 L
.92827 .02815 L
.92873 .02819 L
.9292 .02827 L
.92966 .02829 L
.93013 .02824 L
.9306 .02812 L
Mistroke
.93106 .02823 L
.93153 .02832 L
.93199 .02827 L
.93246 .02811 L
.93292 .02829 L
.93339 .02835 L
.93385 .02822 L
.93432 .02818 L
.93478 .02833 L
.93525 .02832 L
.93571 .02816 L
.93618 .02823 L
.93664 .02834 L
.93711 .02828 L
.93757 .0281 L
.93804 .02828 L
.9385 .02831 L
.93897 .02819 L
.93944 .02818 L
.9399 .02831 L
.94037 .02827 L
.94083 .02812 L
.9413 .02832 L
.94176 .02832 L
.94223 .0281 L
.94269 .0283 L
.94316 .02832 L
.94362 .02815 L
.94409 .02823 L
.94455 .02832 L
.94502 .02823 L
.94548 .02818 L
.94595 .02834 L
.94641 .02826 L
.94688 .02821 L
.94734 .02837 L
.94781 .0282 L
.94828 .02827 L
.94874 .02834 L
.94921 .02813 L
.94967 .02827 L
.95014 .02829 L
.9506 .02812 L
.95107 .02825 L
.95153 .02829 L
.952 .02813 L
.95246 .02828 L
.95293 .02831 L
.95339 .02811 L
.95386 .02832 L
Mistroke
.95432 .02823 L
.95479 .02824 L
.95525 .02832 L
.95572 .02811 L
.95618 .02831 L
.95665 .02824 L
.95711 .0282 L
.95758 .02831 L
.95805 .02813 L
.95851 .02828 L
.95898 .02827 L
.95944 .02816 L
.95991 .02833 L
.96037 .02818 L
.96084 .02829 L
.9613 .02828 L
.96177 .02819 L
.96223 .02833 L
.9627 .0281 L
.96316 .02834 L
.96363 .02817 L
.96409 .02831 L
.96456 .02825 L
.96502 .02826 L
.96549 .02831 L
.96595 .02819 L
.96642 .02833 L
.96689 .02811 L
.96735 .02832 L
.96782 .02815 L
.96828 .02828 L
.96875 .0282 L
.96921 .02822 L
.96968 .0282 L
.97014 .02819 L
.97061 .02821 L
.97107 .02816 L
.97154 .02822 L
.972 .02813 L
.97247 .02822 L
.97293 .0281 L
.9734 .02822 L
.97386 .02811 L
.97433 .02822 L
.97479 .02815 L
.97526 .02821 L
.97573 .0282 L
.97619 .0282 L
Mfstroke
1 0 0 r
.02381 .58994 m
.02427 .58984 L
.02474 .58961 L
.02521 .58938 L
.02567 .58918 L
.02614 .58897 L
.0266 .58874 L
.02707 .5885 L
.02753 .58827 L
.028 .58804 L
.02846 .58779 L
.02893 .58754 L
.02939 .5873 L
.02986 .58705 L
.03032 .58679 L
.03079 .58653 L
.03125 .58628 L
.03172 .58602 L
.03218 .58576 L
.03265 .58549 L
.03311 .58523 L
.03358 .58497 L
.03405 .5847 L
.03451 .58443 L
.03498 .58417 L
.03544 .5839 L
.03591 .58363 L
.03637 .58336 L
.03684 .58309 L
.0373 .58283 L
.03777 .58256 L
.03823 .58228 L
.0387 .58202 L
.03916 .58175 L
.03963 .58148 L
.04009 .5812 L
.04056 .58094 L
.04102 .58067 L
.04149 .58039 L
.04195 .58012 L
.04242 .57985 L
.04289 .57958 L
.04335 .57931 L
.04382 .57904 L
.04428 .57877 L
.04475 .5785 L
.04521 .57823 L
.04568 .57796 L
.04614 .57769 L
.04661 .57742 L
Mistroke
.04707 .57715 L
.04754 .57687 L
.048 .5766 L
.04847 .57633 L
.04893 .57606 L
.0494 .57579 L
.04986 .57552 L
.05033 .57525 L
.05079 .57498 L
.05126 .57471 L
.05172 .57444 L
.05219 .57417 L
.05266 .57389 L
.05312 .57362 L
.05359 .57335 L
.05405 .57308 L
.05452 .57281 L
.05498 .57254 L
.05545 .57227 L
.05591 .572 L
.05638 .57173 L
.05684 .57145 L
.05731 .57118 L
.05777 .57091 L
.05824 .57064 L
.0587 .57037 L
.05917 .5701 L
.05963 .56983 L
.0601 .56956 L
.06056 .56928 L
.06103 .56901 L
.0615 .56874 L
.06196 .56847 L
.06243 .5682 L
.06289 .56793 L
.06336 .56766 L
.06382 .56738 L
.06429 .56711 L
.06475 .56684 L
.06522 .56657 L
.06568 .5663 L
.06615 .56603 L
.06661 .56576 L
.06708 .56549 L
.06754 .56521 L
.06801 .56494 L
.06847 .56467 L
.06894 .5644 L
.0694 .56413 L
.06987 .56385 L
Mistroke
.07034 .56358 L
.0708 .56331 L
.07127 .56304 L
.07173 .56277 L
.0722 .5625 L
.07266 .56223 L
.07313 .56195 L
.07359 .56168 L
.07406 .56141 L
.07452 .56114 L
.07499 .56087 L
.07545 .56059 L
.07592 .56032 L
.07638 .56005 L
.07685 .55978 L
.07731 .55951 L
.07778 .55924 L
.07824 .55896 L
.07871 .55869 L
.07918 .55842 L
.07964 .55815 L
.08011 .55788 L
.08057 .5576 L
.08104 .55733 L
.0815 .55706 L
.08197 .55679 L
.08243 .55652 L
.0829 .55624 L
.08336 .55597 L
.08383 .5557 L
.08429 .55543 L
.08476 .55516 L
.08522 .55488 L
.08569 .55461 L
.08615 .55434 L
.08662 .55407 L
.08708 .5538 L
.08755 .55352 L
.08801 .55325 L
.08848 .55298 L
.08895 .55271 L
.08941 .55244 L
.08988 .55216 L
.09034 .55189 L
.09081 .55162 L
.09127 .55135 L
.09174 .55107 L
.0922 .5508 L
.09267 .55053 L
.09313 .55026 L
Mistroke
.0936 .54999 L
.09406 .54971 L
.09453 .54944 L
.09499 .54917 L
.09546 .5489 L
.09592 .54862 L
.09639 .54835 L
.09685 .54808 L
.09732 .54781 L
.09779 .54753 L
.09825 .54726 L
.09872 .54699 L
.09918 .54672 L
.09965 .54644 L
.10011 .54617 L
.10058 .5459 L
.10104 .54563 L
.10151 .54535 L
.10197 .54508 L
.10244 .54481 L
.1029 .54454 L
.10337 .54426 L
.10383 .54399 L
.1043 .54372 L
.10476 .54345 L
.10523 .54317 L
.10569 .5429 L
.10616 .54263 L
.10663 .54236 L
.10709 .54208 L
.10756 .54181 L
.10802 .54154 L
.10849 .54126 L
.10895 .54099 L
.10942 .54072 L
.10988 .54045 L
.11035 .54017 L
.11081 .5399 L
.11128 .53963 L
.11174 .53936 L
.11221 .53908 L
.11267 .53881 L
.11314 .53854 L
.1136 .53826 L
.11407 .53799 L
.11453 .53772 L
.115 .53745 L
.11547 .53717 L
.11593 .5369 L
.1164 .53663 L
Mistroke
.11686 .53635 L
.11733 .53608 L
.11779 .53581 L
.11826 .53553 L
.11872 .53526 L
.11919 .53499 L
.11965 .53472 L
.12012 .53444 L
.12058 .53417 L
.12105 .5339 L
.12151 .53362 L
.12198 .53335 L
.12244 .53308 L
.12291 .5328 L
.12337 .53253 L
.12384 .53226 L
.12431 .53199 L
.12477 .53171 L
.12524 .53144 L
.1257 .53117 L
.12617 .53089 L
.12663 .53062 L
.1271 .53035 L
.12756 .53007 L
.12803 .5298 L
.12849 .52953 L
.12896 .52925 L
.12942 .52898 L
.12989 .52871 L
.13035 .52843 L
.13082 .52816 L
.13128 .52789 L
.13175 .52761 L
.13221 .52734 L
.13268 .52707 L
.13314 .52679 L
.13361 .52652 L
.13408 .52625 L
.13454 .52597 L
.13501 .5257 L
.13547 .52543 L
.13594 .52515 L
.1364 .52488 L
.13687 .52461 L
.13733 .52433 L
.1378 .52406 L
.13826 .52379 L
.13873 .52351 L
.13919 .52324 L
.13966 .52297 L
Mistroke
.14012 .52269 L
.14059 .52242 L
.14105 .52214 L
.14152 .52187 L
.14198 .5216 L
.14245 .52132 L
.14292 .52105 L
.14338 .52078 L
.14385 .5205 L
.14431 .52023 L
.14478 .51996 L
.14524 .51968 L
.14571 .51941 L
.14617 .51913 L
.14664 .51886 L
.1471 .51859 L
.14757 .51831 L
.14803 .51804 L
.1485 .51777 L
.14896 .51749 L
.14943 .51722 L
.14989 .51695 L
.15036 .51667 L
.15082 .5164 L
.15129 .51612 L
.15176 .51585 L
.15222 .51558 L
.15269 .5153 L
.15315 .51503 L
.15362 .51475 L
.15408 .51448 L
.15455 .51421 L
.15501 .51393 L
.15548 .51366 L
.15594 .51339 L
.15641 .51311 L
.15687 .51284 L
.15734 .51256 L
.1578 .51229 L
.15827 .51202 L
.15873 .51174 L
.1592 .51147 L
.15966 .51119 L
.16013 .51092 L
.1606 .51065 L
.16106 .51037 L
.16153 .5101 L
.16199 .50982 L
.16246 .50955 L
.16292 .50928 L
Mistroke
.16339 .509 L
.16385 .50873 L
.16432 .50845 L
.16478 .50818 L
.16525 .50791 L
.16571 .50763 L
.16618 .50736 L
.16664 .50708 L
.16711 .50681 L
.16757 .50654 L
.16804 .50626 L
.1685 .50599 L
.16897 .50571 L
.16943 .50544 L
.1699 .50516 L
.17037 .50489 L
.17083 .50462 L
.1713 .50434 L
.17176 .50407 L
.17223 .50379 L
.17269 .50352 L
.17316 .50325 L
.17362 .50297 L
.17409 .5027 L
.17455 .50242 L
.17502 .50215 L
.17548 .50187 L
.17595 .5016 L
.17641 .50133 L
.17688 .50105 L
.17734 .50078 L
.17781 .5005 L
.17827 .50023 L
.17874 .49995 L
.17921 .49968 L
.17967 .4994 L
.18014 .49913 L
.1806 .49886 L
.18107 .49858 L
.18153 .49831 L
.182 .49803 L
.18246 .49776 L
.18293 .49748 L
.18339 .49721 L
.18386 .49693 L
.18432 .49666 L
.18479 .49639 L
.18525 .49611 L
.18572 .49584 L
.18618 .49556 L
Mistroke
.18665 .49529 L
.18711 .49501 L
.18758 .49474 L
.18805 .49446 L
.18851 .49419 L
.18898 .49391 L
.18944 .49364 L
.18991 .49337 L
.19037 .49309 L
.19084 .49282 L
.1913 .49254 L
.19177 .49227 L
.19223 .49199 L
.1927 .49172 L
.19316 .49144 L
.19363 .49117 L
.19409 .49089 L
.19456 .49062 L
.19502 .49034 L
.19549 .49007 L
.19595 .4898 L
.19642 .48952 L
.19689 .48925 L
.19735 .48897 L
.19782 .4887 L
.19828 .48842 L
.19875 .48815 L
.19921 .48787 L
.19968 .4876 L
.20014 .48732 L
.20061 .48705 L
.20107 .48677 L
.20154 .4865 L
.202 .48622 L
.20247 .48595 L
.20293 .48567 L
.2034 .4854 L
.20386 .48512 L
.20433 .48485 L
.20479 .48457 L
.20526 .4843 L
.20572 .48402 L
.20619 .48375 L
.20666 .48348 L
.20712 .4832 L
.20759 .48293 L
.20805 .48265 L
.20852 .48238 L
.20898 .4821 L
.20945 .48183 L
Mistroke
.20991 .48155 L
.21038 .48128 L
.21084 .481 L
.21131 .48073 L
.21177 .48045 L
.21224 .48018 L
.2127 .4799 L
.21317 .47963 L
.21363 .47935 L
.2141 .47908 L
.21456 .4788 L
.21503 .47853 L
.2155 .47825 L
.21596 .47798 L
.21643 .4777 L
.21689 .47743 L
.21736 .47715 L
.21782 .47688 L
.21829 .4766 L
.21875 .47633 L
.21922 .47605 L
.21968 .47578 L
.22015 .4755 L
.22061 .47522 L
.22108 .47495 L
.22154 .47467 L
.22201 .4744 L
.22247 .47412 L
.22294 .47385 L
.2234 .47357 L
.22387 .4733 L
.22434 .47302 L
.2248 .47275 L
.22527 .47247 L
.22573 .4722 L
.2262 .47192 L
.22666 .47165 L
.22713 .47137 L
.22759 .4711 L
.22806 .47082 L
.22852 .47055 L
.22899 .47027 L
.22945 .47 L
.22992 .46972 L
.23038 .46945 L
.23085 .46917 L
.23131 .46889 L
.23178 .46862 L
.23224 .46834 L
.23271 .46807 L
Mistroke
.23318 .46779 L
.23364 .46752 L
.23411 .46724 L
.23457 .46697 L
.23504 .46669 L
.2355 .46642 L
.23597 .46614 L
.23643 .46587 L
.2369 .46559 L
.23736 .46532 L
.23783 .46504 L
.23829 .46476 L
.23876 .46449 L
.23922 .46421 L
.23969 .46394 L
.24015 .46366 L
.24062 .46339 L
.24108 .46311 L
.24155 .46284 L
.24202 .46256 L
.24248 .46229 L
.24295 .46201 L
.24341 .46173 L
.24388 .46146 L
.24434 .46118 L
.24481 .46091 L
.24527 .46063 L
.24574 .46036 L
.2462 .46008 L
.24667 .45981 L
.24713 .45953 L
.2476 .45925 L
.24806 .45898 L
.24853 .4587 L
.24899 .45843 L
.24946 .45815 L
.24992 .45788 L
.25039 .4576 L
.25085 .45733 L
.25132 .45705 L
.25179 .45677 L
.25225 .4565 L
.25272 .45622 L
.25318 .45595 L
.25365 .45567 L
.25411 .4554 L
.25458 .45512 L
.25504 .45485 L
.25551 .45457 L
.25597 .45429 L
Mistroke
.25644 .45402 L
.2569 .45374 L
.25737 .45347 L
.25783 .45319 L
.2583 .45292 L
.25876 .45264 L
.25923 .45236 L
.25969 .45209 L
.26016 .45181 L
.26063 .45154 L
.26109 .45126 L
.26156 .45098 L
.26202 .45071 L
.26249 .45043 L
.26295 .45016 L
.26342 .44988 L
.26388 .44961 L
.26435 .44933 L
.26481 .44905 L
.26528 .44878 L
.26574 .4485 L
.26621 .44823 L
.26667 .44795 L
.26714 .44768 L
.2676 .4474 L
.26807 .44712 L
.26853 .44685 L
.269 .44657 L
.26947 .4463 L
.26993 .44602 L
.2704 .44574 L
.27086 .44547 L
.27133 .44519 L
.27179 .44492 L
.27226 .44464 L
.27272 .44437 L
.27319 .44409 L
.27365 .44381 L
.27412 .44354 L
.27458 .44326 L
.27505 .44299 L
.27551 .44271 L
.27598 .44243 L
.27644 .44216 L
.27691 .44188 L
.27737 .44161 L
.27784 .44133 L
.27831 .44105 L
.27877 .44078 L
.27924 .4405 L
Mistroke
.2797 .44023 L
.28017 .43995 L
.28063 .43967 L
.2811 .4394 L
.28156 .43912 L
.28203 .43885 L
.28249 .43857 L
.28296 .43829 L
.28342 .43802 L
.28389 .43774 L
.28435 .43747 L
.28482 .43719 L
.28528 .43691 L
.28575 .43664 L
.28621 .43636 L
.28668 .43609 L
.28714 .43581 L
.28761 .43553 L
.28808 .43526 L
.28854 .43498 L
.28901 .43471 L
.28947 .43443 L
.28994 .43415 L
.2904 .43388 L
.29087 .4336 L
.29133 .43332 L
.2918 .43305 L
.29226 .43277 L
.29273 .4325 L
.29319 .43222 L
.29366 .43194 L
.29412 .43167 L
.29459 .43139 L
.29505 .43112 L
.29552 .43084 L
.29598 .43056 L
.29645 .43029 L
.29692 .43001 L
.29738 .42973 L
.29785 .42946 L
.29831 .42918 L
.29878 .42891 L
.29924 .42863 L
.29971 .42835 L
.30017 .42808 L
.30064 .4278 L
.3011 .42753 L
.30157 .42725 L
.30203 .42697 L
.3025 .4267 L
Mistroke
.30296 .42642 L
.30343 .42614 L
.30389 .42587 L
.30436 .42559 L
.30482 .42532 L
.30529 .42504 L
.30576 .42476 L
.30622 .42449 L
.30669 .42421 L
.30715 .42393 L
.30762 .42366 L
.30808 .42338 L
.30855 .4231 L
.30901 .42283 L
.30948 .42255 L
.30994 .42228 L
.31041 .422 L
.31087 .42172 L
.31134 .42145 L
.3118 .42117 L
.31227 .42089 L
.31273 .42062 L
.3132 .42034 L
.31366 .42006 L
.31413 .41979 L
.3146 .41951 L
.31506 .41924 L
.31553 .41896 L
.31599 .41868 L
.31646 .41841 L
.31692 .41813 L
.31739 .41785 L
.31785 .41758 L
.31832 .4173 L
.31878 .41702 L
.31925 .41675 L
.31971 .41647 L
.32018 .4162 L
.32064 .41592 L
.32111 .41564 L
.32157 .41537 L
.32204 .41509 L
.3225 .41481 L
.32297 .41454 L
.32343 .41426 L
.3239 .41398 L
.32437 .41371 L
.32483 .41343 L
.3253 .41315 L
.32576 .41288 L
Mistroke
.32623 .4126 L
.32669 .41232 L
.32716 .41205 L
.32762 .41177 L
.32809 .4115 L
.32855 .41122 L
.32902 .41094 L
.32948 .41067 L
.32995 .41039 L
.33041 .41011 L
.33088 .40984 L
.33134 .40956 L
.33181 .40928 L
.33227 .40901 L
.33274 .40873 L
.33321 .40845 L
.33367 .40818 L
.33414 .4079 L
.3346 .40762 L
.33507 .40735 L
.33553 .40707 L
.336 .40679 L
.33646 .40652 L
.33693 .40624 L
.33739 .40596 L
.33786 .40569 L
.33832 .40541 L
.33879 .40513 L
.33925 .40486 L
.33972 .40458 L
.34018 .4043 L
.34065 .40403 L
.34111 .40375 L
.34158 .40347 L
.34205 .4032 L
.34251 .40292 L
.34298 .40265 L
.34344 .40237 L
.34391 .40209 L
.34437 .40182 L
.34484 .40154 L
.3453 .40126 L
.34577 .40099 L
.34623 .40071 L
.3467 .40043 L
.34716 .40016 L
.34763 .39988 L
.34809 .3996 L
.34856 .39933 L
.34902 .39905 L
Mistroke
.34949 .39877 L
.34995 .3985 L
.35042 .39822 L
.35089 .39794 L
.35135 .39767 L
.35182 .39739 L
.35228 .39711 L
.35275 .39683 L
.35321 .39656 L
.35368 .39628 L
.35414 .396 L
.35461 .39573 L
.35507 .39545 L
.35554 .39517 L
.356 .3949 L
.35647 .39462 L
.35693 .39434 L
.3574 .39407 L
.35786 .39379 L
.35833 .39351 L
.35879 .39324 L
.35926 .39296 L
.35973 .39268 L
.36019 .39241 L
.36066 .39213 L
.36112 .39185 L
.36159 .39158 L
.36205 .3913 L
.36252 .39102 L
.36298 .39075 L
.36345 .39047 L
.36391 .39019 L
.36438 .38992 L
.36484 .38964 L
.36531 .38936 L
.36577 .38909 L
.36624 .38881 L
.3667 .38853 L
.36717 .38826 L
.36763 .38798 L
.3681 .3877 L
.36856 .38742 L
.36903 .38715 L
.3695 .38687 L
.36996 .38659 L
.37043 .38632 L
.37089 .38604 L
.37136 .38576 L
.37182 .38549 L
.37229 .38521 L
Mistroke
.37275 .38493 L
.37322 .38466 L
.37368 .38438 L
.37415 .3841 L
.37461 .38383 L
.37508 .38355 L
.37554 .38327 L
.37601 .383 L
.37647 .38272 L
.37694 .38244 L
.3774 .38216 L
.37787 .38189 L
.37834 .38161 L
.3788 .38133 L
.37927 .38106 L
.37973 .38078 L
.3802 .3805 L
.38066 .38023 L
.38113 .37995 L
.38159 .37967 L
.38206 .3794 L
.38252 .37912 L
.38299 .37884 L
.38345 .37856 L
.38392 .37829 L
.38438 .37801 L
.38485 .37773 L
.38531 .37746 L
.38578 .37718 L
.38624 .3769 L
.38671 .37663 L
.38718 .37635 L
.38764 .37607 L
.38811 .3758 L
.38857 .37552 L
.38904 .37524 L
.3895 .37496 L
.38997 .37469 L
.39043 .37441 L
.3909 .37413 L
.39136 .37386 L
.39183 .37358 L
.39229 .3733 L
.39276 .37303 L
.39322 .37275 L
.39369 .37247 L
.39415 .37219 L
.39462 .37192 L
.39508 .37164 L
.39555 .37136 L
Mistroke
.39602 .37109 L
.39648 .37081 L
.39695 .37053 L
.39741 .37026 L
.39788 .36998 L
.39834 .3697 L
.39881 .36942 L
.39927 .36915 L
.39974 .36887 L
.4002 .36859 L
.40067 .36832 L
.40113 .36804 L
.4016 .36776 L
.40206 .36749 L
.40253 .36721 L
.40299 .36693 L
.40346 .36665 L
.40392 .36638 L
.40439 .3661 L
.40485 .36582 L
.40532 .36555 L
.40579 .36527 L
.40625 .36499 L
.40672 .36471 L
.40718 .36444 L
.40765 .36416 L
.40811 .36388 L
.40858 .36361 L
.40904 .36333 L
.40951 .36305 L
.40997 .36278 L
.41044 .3625 L
.4109 .36222 L
.41137 .36194 L
.41183 .36167 L
.4123 .36139 L
.41276 .36111 L
.41323 .36084 L
.41369 .36056 L
.41416 .36028 L
.41463 .36 L
.41509 .35973 L
.41556 .35945 L
.41602 .35917 L
.41649 .3589 L
.41695 .35862 L
.41742 .35834 L
.41788 .35807 L
.41835 .35779 L
.41881 .35751 L
Mistroke
.41928 .35723 L
.41974 .35696 L
.42021 .35668 L
.42067 .3564 L
.42114 .35613 L
.4216 .35585 L
.42207 .35557 L
.42253 .35529 L
.423 .35502 L
.42347 .35474 L
.42393 .35446 L
.4244 .35419 L
.42486 .35391 L
.42533 .35363 L
.42579 .35335 L
.42626 .35308 L
.42672 .3528 L
.42719 .35252 L
.42765 .35225 L
.42812 .35197 L
.42858 .35169 L
.42905 .35141 L
.42951 .35114 L
.42998 .35086 L
.43044 .35058 L
.43091 .35031 L
.43137 .35003 L
.43184 .34975 L
.43231 .34947 L
.43277 .3492 L
.43324 .34892 L
.4337 .34864 L
.43417 .34837 L
.43463 .34809 L
.4351 .34781 L
.43556 .34753 L
.43603 .34726 L
.43649 .34698 L
.43696 .3467 L
.43742 .34643 L
.43789 .34615 L
.43835 .34587 L
.43882 .34559 L
.43928 .34532 L
.43975 .34504 L
.44021 .34476 L
.44068 .34449 L
.44114 .34421 L
.44161 .34393 L
.44208 .34365 L
Mistroke
.44254 .34338 L
.44301 .3431 L
.44347 .34282 L
.44394 .34254 L
.4444 .34227 L
.44487 .34199 L
.44533 .34171 L
.4458 .34144 L
.44626 .34116 L
.44673 .34088 L
.44719 .3406 L
.44766 .34033 L
.44812 .34005 L
.44859 .33977 L
.44905 .3395 L
.44952 .33922 L
.44998 .33894 L
.45045 .33866 L
.45092 .33839 L
.45138 .33811 L
.45185 .33783 L
.45231 .33756 L
.45278 .33728 L
.45324 .337 L
.45371 .33672 L
.45417 .33645 L
.45464 .33617 L
.4551 .33589 L
.45557 .33561 L
.45603 .33534 L
.4565 .33506 L
.45696 .33478 L
.45743 .33451 L
.45789 .33423 L
.45836 .33395 L
.45882 .33367 L
.45929 .3334 L
.45976 .33312 L
.46022 .33284 L
.46069 .33257 L
.46115 .33229 L
.46162 .33201 L
.46208 .33173 L
.46255 .33146 L
.46301 .33118 L
.46348 .3309 L
.46394 .33062 L
.46441 .33035 L
.46487 .33007 L
.46534 .32979 L
Mistroke
.4658 .32952 L
.46627 .32924 L
.46673 .32896 L
.4672 .32868 L
.46766 .32841 L
.46813 .32813 L
.4686 .32785 L
.46906 .32757 L
.46953 .3273 L
.46999 .32702 L
.47046 .32674 L
.47092 .32647 L
.47139 .32619 L
.47185 .32591 L
.47232 .32563 L
.47278 .32536 L
.47325 .32508 L
.47371 .3248 L
.47418 .32453 L
.47464 .32425 L
.47511 .32397 L
.47557 .32369 L
.47604 .32342 L
.4765 .32314 L
.47697 .32286 L
.47744 .32258 L
.4779 .32231 L
.47837 .32203 L
.47883 .32175 L
.4793 .32148 L
.47976 .3212 L
.48023 .32092 L
.48069 .32064 L
.48116 .32037 L
.48162 .32009 L
.48209 .31981 L
.48255 .31953 L
.48302 .31926 L
.48348 .31898 L
.48395 .3187 L
.48441 .31843 L
.48488 .31815 L
.48534 .31787 L
.48581 .31759 L
.48627 .31732 L
.48674 .31704 L
.48721 .31676 L
.48767 .31648 L
.48814 .31621 L
.4886 .31593 L
Mistroke
.48907 .31565 L
.48953 .31538 L
.49 .3151 L
.49046 .31482 L
.49093 .31454 L
.49139 .31427 L
.49186 .31399 L
.49232 .31371 L
.49279 .31343 L
.49325 .31316 L
.49372 .31288 L
.49418 .3126 L
.49465 .31233 L
.49511 .31205 L
.49558 .31177 L
.49605 .31149 L
.49651 .31122 L
.49698 .31094 L
.49744 .31066 L
.49791 .31038 L
.49837 .31011 L
.49884 .30983 L
.4993 .30955 L
.49977 .30928 L
.50023 .309 L
.5007 .30872 L
.50116 .30844 L
.50163 .30817 L
.50209 .30789 L
.50256 .30761 L
.50302 .30733 L
.50349 .30706 L
.50395 .30678 L
.50442 .3065 L
.50489 .30623 L
.50535 .30595 L
.50582 .30567 L
.50628 .30539 L
.50675 .30512 L
.50721 .30484 L
.50768 .30456 L
.50814 .30428 L
.50861 .30401 L
.50907 .30373 L
.50954 .30345 L
.51 .30318 L
.51047 .3029 L
.51093 .30262 L
.5114 .30234 L
.51186 .30207 L
Mistroke
.51233 .30179 L
.51279 .30151 L
.51326 .30123 L
.51373 .30096 L
.51419 .30068 L
.51466 .3004 L
.51512 .30013 L
.51559 .29985 L
.51605 .29957 L
.51652 .29929 L
.51698 .29902 L
.51745 .29874 L
.51791 .29846 L
.51838 .29818 L
.51884 .29791 L
.51931 .29763 L
.51977 .29735 L
.52024 .29708 L
.5207 .2968 L
.52117 .29652 L
.52163 .29624 L
.5221 .29597 L
.52256 .29569 L
.52303 .29541 L
.5235 .29514 L
.52396 .29486 L
.52443 .29458 L
.52489 .2943 L
.52536 .29403 L
.52582 .29375 L
.52629 .29347 L
.52675 .29319 L
.52722 .29292 L
.52768 .29264 L
.52815 .29236 L
.52861 .29209 L
.52908 .29181 L
.52954 .29153 L
.53001 .29125 L
.53047 .29098 L
.53094 .2907 L
.5314 .29042 L
.53187 .29014 L
.53234 .28987 L
.5328 .28959 L
.53327 .28931 L
.53373 .28904 L
.5342 .28876 L
.53466 .28848 L
.53513 .2882 L
Mistroke
.53559 .28793 L
.53606 .28765 L
.53652 .28737 L
.53699 .2871 L
.53745 .28682 L
.53792 .28654 L
.53838 .28626 L
.53885 .28599 L
.53931 .28571 L
.53978 .28543 L
.54024 .28515 L
.54071 .28488 L
.54118 .2846 L
.54164 .28432 L
.54211 .28405 L
.54257 .28377 L
.54304 .28349 L
.5435 .28321 L
.54397 .28294 L
.54443 .28266 L
.5449 .28238 L
.54536 .28211 L
.54583 .28183 L
.54629 .28155 L
.54676 .28127 L
.54722 .281 L
.54769 .28072 L
.54815 .28044 L
.54862 .28016 L
.54908 .27989 L
.54955 .27961 L
.55002 .27933 L
.55048 .27906 L
.55095 .27878 L
.55141 .2785 L
.55188 .27822 L
.55234 .27795 L
.55281 .27767 L
.55327 .27739 L
.55374 .27712 L
.5542 .27684 L
.55467 .27656 L
.55513 .27628 L
.5556 .27601 L
.55606 .27573 L
.55653 .27545 L
.55699 .27518 L
.55746 .2749 L
.55792 .27462 L
.55839 .27434 L
Mistroke
.55886 .27407 L
.55932 .27379 L
.55979 .27351 L
.56025 .27324 L
.56072 .27296 L
.56118 .27268 L
.56165 .2724 L
.56211 .27213 L
.56258 .27185 L
.56304 .27157 L
.56351 .27129 L
.56397 .27102 L
.56444 .27074 L
.5649 .27046 L
.56537 .27019 L
.56583 .26991 L
.5663 .26963 L
.56676 .26935 L
.56723 .26908 L
.56769 .2688 L
.56816 .26852 L
.56863 .26825 L
.56909 .26797 L
.56956 .26769 L
.57002 .26741 L
.57049 .26714 L
.57095 .26686 L
.57142 .26658 L
.57188 .26631 L
.57235 .26603 L
.57281 .26575 L
.57328 .26547 L
.57374 .2652 L
.57421 .26492 L
.57467 .26464 L
.57514 .26437 L
.5756 .26409 L
.57607 .26381 L
.57653 .26353 L
.577 .26326 L
.57747 .26298 L
.57793 .2627 L
.5784 .26243 L
.57886 .26215 L
.57933 .26187 L
.57979 .2616 L
.58026 .26132 L
.58072 .26104 L
.58119 .26076 L
.58165 .26049 L
Mistroke
.58212 .26021 L
.58258 .25993 L
.58305 .25966 L
.58351 .25938 L
.58398 .2591 L
.58444 .25882 L
.58491 .25855 L
.58537 .25827 L
.58584 .25799 L
.58631 .25772 L
.58677 .25744 L
.58724 .25716 L
.5877 .25688 L
.58817 .25661 L
.58863 .25633 L
.5891 .25605 L
.58956 .25578 L
.59003 .2555 L
.59049 .25522 L
.59096 .25495 L
.59142 .25467 L
.59189 .25439 L
.59235 .25411 L
.59282 .25384 L
.59328 .25356 L
.59375 .25328 L
.59421 .25301 L
.59468 .25273 L
.59515 .25245 L
.59561 .25218 L
.59608 .2519 L
.59654 .25162 L
.59701 .25134 L
.59747 .25107 L
.59794 .25079 L
.5984 .25051 L
.59887 .25024 L
.59933 .24996 L
.5998 .24968 L
.60026 .2494 L
.60073 .24913 L
.60119 .24885 L
.60166 .24857 L
.60212 .2483 L
.60259 .24802 L
.60305 .24774 L
.60352 .24747 L
.60398 .24719 L
.60445 .24691 L
.60492 .24664 L
Mistroke
.60538 .24636 L
.60585 .24608 L
.60631 .2458 L
.60678 .24553 L
.60724 .24525 L
.60771 .24497 L
.60817 .2447 L
.60864 .24442 L
.6091 .24414 L
.60957 .24387 L
.61003 .24359 L
.6105 .24331 L
.61096 .24303 L
.61143 .24276 L
.61189 .24248 L
.61236 .2422 L
.61282 .24193 L
.61329 .24165 L
.61376 .24137 L
.61422 .2411 L
.61469 .24082 L
.61515 .24054 L
.61562 .24027 L
.61608 .23999 L
.61655 .23971 L
.61701 .23943 L
.61748 .23916 L
.61794 .23888 L
.61841 .2386 L
.61887 .23833 L
.61934 .23805 L
.6198 .23777 L
.62027 .2375 L
.62073 .23722 L
.6212 .23694 L
.62166 .23667 L
.62213 .23639 L
.6226 .23611 L
.62306 .23583 L
.62353 .23556 L
.62399 .23528 L
.62446 .235 L
.62492 .23473 L
.62539 .23445 L
.62585 .23417 L
.62632 .2339 L
.62678 .23362 L
.62725 .23334 L
.62771 .23307 L
.62818 .23279 L
Mistroke
.62864 .23251 L
.62911 .23224 L
.62957 .23196 L
.63004 .23168 L
.6305 .23141 L
.63097 .23113 L
.63144 .23085 L
.6319 .23057 L
.63237 .2303 L
.63283 .23002 L
.6333 .22974 L
.63376 .22947 L
.63423 .22919 L
.63469 .22891 L
.63516 .22864 L
.63562 .22836 L
.63609 .22808 L
.63655 .22781 L
.63702 .22753 L
.63748 .22725 L
.63795 .22698 L
.63841 .2267 L
.63888 .22642 L
.63934 .22615 L
.63981 .22587 L
.64027 .22559 L
.64074 .22532 L
.64121 .22504 L
.64167 .22476 L
.64214 .22449 L
.6426 .22421 L
.64307 .22393 L
.64353 .22366 L
.644 .22338 L
.64446 .2231 L
.64493 .22283 L
.64539 .22255 L
.64586 .22227 L
.64632 .222 L
.64679 .22172 L
.64725 .22144 L
.64772 .22117 L
.64818 .22089 L
.64865 .22061 L
.64911 .22034 L
.64958 .22006 L
.65005 .21978 L
.65051 .21951 L
.65098 .21923 L
.65144 .21895 L
Mistroke
.65191 .21868 L
.65237 .2184 L
.65284 .21812 L
.6533 .21785 L
.65377 .21757 L
.65423 .21729 L
.6547 .21702 L
.65516 .21674 L
.65563 .21646 L
.65609 .21619 L
.65656 .21591 L
.65702 .21563 L
.65749 .21536 L
.65795 .21508 L
.65842 .2148 L
.65889 .21453 L
.65935 .21425 L
.65982 .21397 L
.66028 .2137 L
.66075 .21342 L
.66121 .21314 L
.66168 .21287 L
.66214 .21259 L
.66261 .21231 L
.66307 .21204 L
.66354 .21176 L
.664 .21148 L
.66447 .21121 L
.66493 .21093 L
.6654 .21065 L
.66586 .21038 L
.66633 .2101 L
.66679 .20982 L
.66726 .20955 L
.66773 .20927 L
.66819 .209 L
.66866 .20872 L
.66912 .20844 L
.66959 .20817 L
.67005 .20789 L
.67052 .20761 L
.67098 .20734 L
.67145 .20706 L
.67191 .20678 L
.67238 .20651 L
.67284 .20623 L
.67331 .20595 L
.67377 .20568 L
.67424 .2054 L
.6747 .20512 L
Mistroke
.67517 .20485 L
.67563 .20457 L
.6761 .20429 L
.67657 .20402 L
.67703 .20374 L
.6775 .20347 L
.67796 .20319 L
.67843 .20291 L
.67889 .20264 L
.67936 .20236 L
.67982 .20208 L
.68029 .20181 L
.68075 .20153 L
.68122 .20125 L
.68168 .20098 L
.68215 .2007 L
.68261 .20043 L
.68308 .20015 L
.68354 .19987 L
.68401 .1996 L
.68447 .19932 L
.68494 .19904 L
.6854 .19877 L
.68587 .19849 L
.68634 .19821 L
.6868 .19794 L
.68727 .19766 L
.68773 .19739 L
.6882 .19711 L
.68866 .19683 L
.68913 .19656 L
.68959 .19628 L
.69006 .196 L
.69052 .19573 L
.69099 .19545 L
.69145 .19517 L
.69192 .1949 L
.69238 .19462 L
.69285 .19435 L
.69331 .19407 L
.69378 .19379 L
.69424 .19352 L
.69471 .19324 L
.69518 .19296 L
.69564 .19269 L
.69611 .19241 L
.69657 .19214 L
.69704 .19186 L
.6975 .19158 L
.69797 .19131 L
Mistroke
.69843 .19103 L
.6989 .19075 L
.69936 .19048 L
.69983 .1902 L
.70029 .18993 L
.70076 .18965 L
.70122 .18937 L
.70169 .1891 L
.70215 .18882 L
.70262 .18855 L
.70308 .18827 L
.70355 .18799 L
.70402 .18772 L
.70448 .18744 L
.70495 .18716 L
.70541 .18689 L
.70588 .18661 L
.70634 .18634 L
.70681 .18606 L
.70727 .18578 L
.70774 .18551 L
.7082 .18523 L
.70867 .18496 L
.70913 .18468 L
.7096 .1844 L
.71006 .18413 L
.71053 .18385 L
.71099 .18358 L
.71146 .1833 L
.71192 .18302 L
.71239 .18275 L
.71286 .18247 L
.71332 .1822 L
.71379 .18192 L
.71425 .18164 L
.71472 .18137 L
.71518 .18109 L
.71565 .18081 L
.71611 .18054 L
.71658 .18026 L
.71704 .17999 L
.71751 .17971 L
.71797 .17944 L
.71844 .17916 L
.7189 .17888 L
.71937 .17861 L
.71983 .17833 L
.7203 .17806 L
.72076 .17778 L
.72123 .1775 L
Mistroke
.72169 .17723 L
.72216 .17695 L
.72263 .17668 L
.72309 .1764 L
.72356 .17612 L
.72402 .17585 L
.72449 .17557 L
.72495 .1753 L
.72542 .17502 L
.72588 .17474 L
.72635 .17447 L
.72681 .17419 L
.72728 .17392 L
.72774 .17364 L
.72821 .17336 L
.72867 .17309 L
.72914 .17281 L
.7296 .17254 L
.73007 .17226 L
.73053 .17199 L
.731 .17171 L
.73147 .17143 L
.73193 .17116 L
.7324 .17088 L
.73286 .17061 L
.73333 .17033 L
.73379 .17005 L
.73426 .16978 L
.73472 .1695 L
.73519 .16923 L
.73565 .16895 L
.73612 .16868 L
.73658 .1684 L
.73705 .16812 L
.73751 .16785 L
.73798 .16757 L
.73844 .1673 L
.73891 .16702 L
.73937 .16675 L
.73984 .16647 L
.74031 .16619 L
.74077 .16592 L
.74124 .16564 L
.7417 .16537 L
.74217 .16509 L
.74263 .16482 L
.7431 .16454 L
.74356 .16426 L
.74403 .16399 L
.74449 .16371 L
Mistroke
.74496 .16344 L
.74542 .16316 L
.74589 .16289 L
.74635 .16261 L
.74682 .16234 L
.74728 .16206 L
.74775 .16178 L
.74821 .16151 L
.74868 .16123 L
.74915 .16096 L
.74961 .16068 L
.75008 .16041 L
.75054 .16013 L
.75101 .15986 L
.75147 .15958 L
.75194 .1593 L
.7524 .15903 L
.75287 .15875 L
.75333 .15848 L
.7538 .1582 L
.75426 .15793 L
.75473 .15765 L
.75519 .15738 L
.75566 .1571 L
.75612 .15682 L
.75659 .15655 L
.75705 .15627 L
.75752 .156 L
.75798 .15572 L
.75845 .15545 L
.75892 .15517 L
.75938 .1549 L
.75985 .15462 L
.76031 .15435 L
.76078 .15407 L
.76124 .1538 L
.76171 .15352 L
.76217 .15324 L
.76264 .15297 L
.7631 .15269 L
.76357 .15242 L
.76403 .15214 L
.7645 .15187 L
.76496 .15159 L
.76543 .15132 L
.76589 .15104 L
.76636 .15077 L
.76682 .15049 L
.76729 .15022 L
.76776 .14994 L
Mistroke
.76822 .14967 L
.76869 .14939 L
.76915 .14911 L
.76962 .14884 L
.77008 .14856 L
.77055 .14829 L
.77101 .14801 L
.77148 .14774 L
.77194 .14746 L
.77241 .14719 L
.77287 .14691 L
.77334 .14664 L
.7738 .14636 L
.77427 .14609 L
.77473 .14581 L
.7752 .14554 L
.77566 .14526 L
.77613 .14499 L
.7766 .14471 L
.77706 .14444 L
.77753 .14416 L
.77799 .14389 L
.77846 .14361 L
.77892 .14334 L
.77939 .14306 L
.77985 .14279 L
.78032 .14251 L
.78078 .14224 L
.78125 .14196 L
.78171 .14169 L
.78218 .14141 L
.78264 .14114 L
.78311 .14086 L
.78357 .14059 L
.78404 .14031 L
.7845 .14004 L
.78497 .13976 L
.78544 .13949 L
.7859 .13921 L
.78637 .13894 L
.78683 .13866 L
.7873 .13839 L
.78776 .13811 L
.78823 .13784 L
.78869 .13756 L
.78916 .13729 L
.78962 .13701 L
.79009 .13674 L
.79055 .13646 L
.79102 .13619 L
Mistroke
.79148 .13591 L
.79195 .13564 L
.79241 .13536 L
.79288 .13509 L
.79334 .13481 L
.79381 .13454 L
.79428 .13426 L
.79474 .13399 L
.79521 .13371 L
.79567 .13344 L
.79614 .13316 L
.7966 .13289 L
.79707 .13261 L
.79753 .13234 L
.798 .13206 L
.79846 .13179 L
.79893 .13151 L
.79939 .13124 L
.79986 .13096 L
.80032 .13069 L
.80079 .13041 L
.80125 .13014 L
.80172 .12987 L
.80218 .12959 L
.80265 .12932 L
.80311 .12904 L
.80358 .12877 L
.80405 .12849 L
.80451 .12822 L
.80498 .12794 L
.80544 .12767 L
.80591 .12739 L
.80637 .12712 L
.80684 .12684 L
.8073 .12657 L
.80777 .1263 L
.80823 .12602 L
.8087 .12575 L
.80916 .12547 L
.80963 .1252 L
.81009 .12492 L
.81056 .12465 L
.81102 .12437 L
.81149 .1241 L
.81195 .12382 L
.81242 .12355 L
.81289 .12327 L
.81335 .123 L
.81382 .12273 L
.81428 .12245 L
Mistroke
.81475 .12218 L
.81521 .1219 L
.81568 .12163 L
.81614 .12135 L
.81661 .12108 L
.81707 .12081 L
.81754 .12053 L
.818 .12026 L
.81847 .11998 L
.81893 .11971 L
.8194 .11943 L
.81986 .11916 L
.82033 .11888 L
.82079 .11861 L
.82126 .11834 L
.82173 .11806 L
.82219 .11779 L
.82266 .11751 L
.82312 .11724 L
.82359 .11696 L
.82405 .11669 L
.82452 .11642 L
.82498 .11614 L
.82545 .11587 L
.82591 .11559 L
.82638 .11532 L
.82684 .11504 L
.82731 .11477 L
.82777 .1145 L
.82824 .11422 L
.8287 .11395 L
.82917 .11367 L
.82963 .1134 L
.8301 .11313 L
.83057 .11285 L
.83103 .11258 L
.8315 .1123 L
.83196 .11203 L
.83243 .11175 L
.83289 .11148 L
.83336 .11121 L
.83382 .11093 L
.83429 .11066 L
.83475 .11038 L
.83522 .11011 L
.83568 .10984 L
.83615 .10956 L
.83661 .10929 L
.83708 .10901 L
.83754 .10874 L
Mistroke
.83801 .10847 L
.83847 .10819 L
.83894 .10792 L
.8394 .10764 L
.83987 .10737 L
.84034 .1071 L
.8408 .10682 L
.84127 .10655 L
.84173 .10627 L
.8422 .106 L
.84266 .10573 L
.84313 .10545 L
.84359 .10518 L
.84406 .1049 L
.84452 .10463 L
.84499 .10436 L
.84545 .10408 L
.84592 .10381 L
.84638 .10354 L
.84685 .10326 L
.84731 .10299 L
.84778 .10271 L
.84824 .10244 L
.84871 .10217 L
.84918 .10189 L
.84964 .10162 L
.85011 .10135 L
.85057 .10107 L
.85104 .1008 L
.8515 .10052 L
.85197 .10025 L
.85243 .09998 L
.8529 .0997 L
.85336 .09943 L
.85383 .09916 L
.85429 .09888 L
.85476 .09861 L
.85522 .09834 L
.85569 .09806 L
.85615 .09779 L
.85662 .09751 L
.85708 .09724 L
.85755 .09697 L
.85802 .09669 L
.85848 .09642 L
.85895 .09615 L
.85941 .09587 L
.85988 .0956 L
.86034 .09533 L
.86081 .09505 L
Mistroke
.86127 .09478 L
.86174 .09451 L
.8622 .09423 L
.86267 .09396 L
.86313 .09369 L
.8636 .09341 L
.86406 .09314 L
.86453 .09287 L
.86499 .09259 L
.86546 .09232 L
.86592 .09205 L
.86639 .09177 L
.86686 .0915 L
.86732 .09123 L
.86779 .09095 L
.86825 .09068 L
.86872 .09041 L
.86918 .09013 L
.86965 .08986 L
.87011 .08959 L
.87058 .08931 L
.87104 .08904 L
.87151 .08877 L
.87197 .08849 L
.87244 .08822 L
.8729 .08795 L
.87337 .08767 L
.87383 .0874 L
.8743 .08713 L
.87476 .08685 L
.87523 .08658 L
.87569 .08631 L
.87616 .08604 L
.87663 .08576 L
.87709 .08549 L
.87756 .08522 L
.87802 .08494 L
.87849 .08467 L
.87895 .0844 L
.87942 .08412 L
.87988 .08385 L
.88035 .08358 L
.88081 .0833 L
.88128 .08303 L
.88174 .08276 L
.88221 .08249 L
.88267 .08221 L
.88314 .08194 L
.8836 .08167 L
.88407 .08139 L
Mistroke
.88453 .08112 L
.885 .08085 L
.88547 .08058 L
.88593 .0803 L
.8864 .08003 L
.88686 .07976 L
.88733 .07948 L
.88779 .07921 L
.88826 .07894 L
.88872 .07867 L
.88919 .07839 L
.88965 .07812 L
.89012 .07785 L
.89058 .07757 L
.89105 .0773 L
.89151 .07703 L
.89198 .07676 L
.89244 .07648 L
.89291 .07621 L
.89337 .07594 L
.89384 .07567 L
.89431 .07539 L
.89477 .07512 L
.89524 .07485 L
.8957 .07458 L
.89617 .0743 L
.89663 .07403 L
.8971 .07376 L
.89756 .07349 L
.89803 .07321 L
.89849 .07294 L
.89896 .07267 L
.89942 .0724 L
.89989 .07212 L
.90035 .07185 L
.90082 .07158 L
.90128 .07131 L
.90175 .07103 L
.90221 .07076 L
.90268 .07049 L
.90315 .07022 L
.90361 .06994 L
.90408 .06967 L
.90454 .0694 L
.90501 .06913 L
.90547 .06885 L
.90594 .06858 L
.9064 .06831 L
.90687 .06804 L
.90733 .06777 L
Mistroke
.9078 .06749 L
.90826 .06722 L
.90873 .06695 L
.90919 .06668 L
.90966 .0664 L
.91012 .06613 L
.91059 .06586 L
.91105 .06559 L
.91152 .06532 L
.91199 .06504 L
.91245 .06477 L
.91292 .0645 L
.91338 .06423 L
.91385 .06396 L
.91431 .06368 L
.91478 .06341 L
.91524 .06314 L
.91571 .06287 L
.91617 .0626 L
.91664 .06232 L
.9171 .06205 L
.91757 .06178 L
.91803 .06151 L
.9185 .06124 L
.91896 .06096 L
.91943 .06069 L
.91989 .06042 L
.92036 .06015 L
.92082 .05988 L
.92129 .05961 L
.92176 .05933 L
.92222 .05906 L
.92269 .05879 L
.92315 .05852 L
.92362 .05825 L
.92408 .05797 L
.92455 .0577 L
.92501 .05743 L
.92548 .05716 L
.92594 .05689 L
.92641 .05662 L
.92687 .05634 L
.92734 .05607 L
.9278 .0558 L
.92827 .05553 L
.92873 .05526 L
.9292 .05499 L
.92966 .05471 L
.93013 .05444 L
.9306 .05417 L
Mistroke
.93106 .0539 L
.93153 .05363 L
.93199 .05336 L
.93246 .05309 L
.93292 .05281 L
.93339 .05254 L
.93385 .05227 L
.93432 .052 L
.93478 .05173 L
.93525 .05146 L
.93571 .05118 L
.93618 .05091 L
.93664 .05064 L
.93711 .05037 L
.93757 .0501 L
.93804 .04983 L
.9385 .04956 L
.93897 .04928 L
.93944 .04901 L
.9399 .04874 L
.94037 .04847 L
.94083 .0482 L
.9413 .04793 L
.94176 .04766 L
.94223 .04739 L
.94269 .04711 L
.94316 .04684 L
.94362 .04657 L
.94409 .0463 L
.94455 .04603 L
.94502 .04576 L
.94548 .04549 L
.94595 .04522 L
.94641 .04495 L
.94688 .04468 L
.94734 .04441 L
.94781 .04413 L
.94828 .04386 L
.94874 .04359 L
.94921 .04332 L
.94967 .04305 L
.95014 .04278 L
.9506 .04251 L
.95107 .04224 L
.95153 .04197 L
.952 .04169 L
.95246 .04142 L
.95293 .04116 L
.95339 .04088 L
.95386 .04061 L
Mistroke
.95432 .04034 L
.95479 .04007 L
.95525 .0398 L
.95572 .03953 L
.95618 .03926 L
.95665 .03899 L
.95711 .03872 L
.95758 .03845 L
.95805 .03818 L
.95851 .03791 L
.95898 .03764 L
.95944 .03736 L
.95991 .0371 L
.96037 .03683 L
.96084 .03656 L
.9613 .03629 L
.96177 .03602 L
.96223 .03575 L
.9627 .03548 L
.96316 .03521 L
.96363 .03494 L
.96409 .03468 L
.96456 .03441 L
.96502 .03414 L
.96549 .03387 L
.96595 .03361 L
.96642 .03334 L
.96689 .03308 L
.96735 .03282 L
.96782 .03256 L
.96828 .03229 L
.96875 .03203 L
.96921 .03178 L
.96968 .03153 L
.97014 .03127 L
.97061 .03101 L
.97107 .03077 L
.97154 .03053 L
.972 .03028 L
.97247 .03003 L
.97293 .02981 L
.9734 .02958 L
.97386 .02935 L
.97433 .02911 L
.97479 .02891 L
.97526 .02871 L
.97573 .02848 L
.97619 .02825 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008oooool2o`0002kooooo0ol00004ooooo`;o00001?ooool2o`0002Kooooo1Ol00003oooo
o`;o00001?ooool2o`0002Sooooo0ol00004ooooo`;o00001?ooool2o`0002Wooooo0ol00003oooo
o`;o00001?ooool2o`0001[ooooo000Rooooo`04o`000?ooooooooooo`0002kooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Kooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
02Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000:Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0Gooooo`008_ooool01?l0003oooooooooool0000^oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Wooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Zooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Tooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0001Wooooo000Rooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Sooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool09_oo
ool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Vooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Iooooo`008_ooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Uooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002[ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001Wooooo000Rooooo`04o`000?ooooooooooo`0002gooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00009Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Vooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002So
oooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006Oooool0
02?ooooo0_l0000_ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00009oooool3o`00
00Cooooo0_l00004ooooo`;o0000:?ooool3o`0000Cooooo0_l00004ooooo`;o0000:_ooool00ol0
003oooooooooo`02ooooo`;o00001?ooool2o`0001[ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo000NooooooSo00002_ooool001kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo0?Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0m?oo
ool00ol0003oooooooooo`08ooooo`005oooool2o`0000Gooooo00?o0000ooooooooool0m?ooool0
0ol0003oooooooooo`08ooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo0?Cooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000Fooooo`04o`000?oooooooooo
o`0000Cooooo0_l00009ooooo`Co00001?ooool2o`0000;ooooo00?o0000ooooool000000_l00000
0ooooooo0000ooooo`02o`000006ooooool0003o0000o`000?oooooo00000oooool3o`000003oooo
ool0003o000000?o00000oooool3o`000003ooooool0003o000000[o000000Goooooo`000?l0003o
0000ooooo`02o`000008ooooool0003oooooo`000?oooooo0000ooooool00002ooooo`04o`000?oo
ooooooooooooo`;o00002?ooool2o`0000?ooooo00Oo0000ooooool0003o0000ooooool0003ooooo
00Wo000000?oooooo`000?l000004Ol000000ooooooo0000o`000005o`000003ooooool0003ooooo
00So00001oooool7o`000005ooooool0003oooooo`000?ooool01Ol000000ooooooo0000ooooo`0d
o`0000;oo`001?ooool2o`0000[ooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01oooool6o`0000;ooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o
0000033o000000Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo0_l0
0008ooooo`;o00000_ooool2o`000006ooooool0003o0000ooooool0003oooooB_l000000ooooooo
0000ooooo`0`ooooo`;oo`001oooool00ol0003oooooooooo`08ooooo`005_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00GoooooBol000000ooooooo0000o`000003o`000003
ooooool0003ooooo00;o00001_ooool2o`000003ooooool0003ooooo05;o000000?oooooo`000?oo
ool0;_ooool3ool000Sooooo00?o0000ooooooooool02?ooool001Oooooo0_l00005ooooo`03o`00
0?oooooooooo00CoooooD?l000001?oooooo0000o`000?l00002ooooo`;o00001?ooool2o`0000;o
oooo0ol000000ooooooo0000o`00001@o`0002gooooo0ooo000:ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00CoooooAol000001ooooooo0000ooooool0003oooooo`00
0?ooool00_l000000ooooooo0000o`000004ooooo`Ko00001?ooool00ol0003oooooooooo`02o`00
00?ooooo00?o0000ooooool000000oooool01?l0003oooooo`000?l00003ooooo`Co000000?ooooo
o`000?ooool00_ooool5o`0000Kooooo1_l000000ooooooo0000o`000002o`0000Sooooo00?o0000
ooooool000005Ol0000]ooooo`;oo`003?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`04oooooc_o000000Coooooo`000?l0003o00000oooool00ol0003oooooooooo`1U
ooooo`_o0000:oooool2ool000kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool01?oooolXo`0000?ooooo0_l00024ooooo`Co0000:Oooool3ool000oooooo00?o0000oooo
ooooool02?ooool001kooooo0_l00004ooooob7o0000Toooool2o`0002Oooooo0ooo000@ooooo`;o
00002_ooool001kooooo00?o0000ooooooooool00ooooolGo`0009gooooo0_l0000Vooooo`;oo`00
4oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03oooooa7o000000?o
ooooo`000?ooool0X?ooool00ol0003oooooooooo`0Sooooo`?oo`005?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`03oooooa3o0000b?ooool3ool001Kooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool=o`000<[ooooo0_oo000Hoooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo2ol0003:ooooo`;o
o`006_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo2Ol0003:ooooo`?oo`00
6_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo1ol0003;ooooo`;oo`007Ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`Oo0000bOooool2
ool001oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool6o`00
0<Sooooo0ooo000Pooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?o
oooo1_l00036ooooo`?oo`008_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`Ko0000aOooool2ool002Cooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool00oooool4o`000<Gooooo0ooo000Uooooo`03o`000?oooooooooo00Sooooo000N
ooooo`;o00001?ooool4o`000<?ooooo0ooo000Vooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool00oooool4o`000<;ooooo0_oo000Yooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo0ol00031ooooo`;oo`00:oooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`?o0000_oooool3ool002cooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool00oooool3o`000;kooooo0_oo000^ooooo`03o`000?oo
oooooooo00Sooooo000;ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o
0000ooooooooool00oooool3o`000;cooooo0_oo000`ooooo`03o`000?oooooooooo00Sooooo000:
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`03ooooo`?o0000^_ooool3ool0037ooooo00?o0000ooooooooool02?ooool000[ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o00001?ooool3o`000;Sooooo
0ooo000booooo`;o00002_ooool000[ooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo0ol0002gooooo`;oo`00=Oooool00ol0003ooooo
ooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`03ooooo`;o0000]_ooool3ool003Kooooo00?o0000oooooooo
ool02?ooool000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool00oooool2o`000;Cooooo0ooo000hooooo`03o`000?oooooooooo
00Sooooo000;ooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool00oooool2o`000;?o
oooo0_oo000jooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo
0_l0002aooooo`?oo`00>oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`03ooooo`;o0000[oooool3ool003gooooo00?o0000ooooooooool02?ooool001kooooo0_l00004
ooooo`;o0000[_ooool2ool003kooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03oooo
o`;o0000[?ooool2ool0047ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool00oooool2o`000:[ooooo0ooo0012ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00?ooooo0_l0002Yooooo`;oo`00A?ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`;o0000Yoooool2ool004Kooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool00oooool2o`000:Gooooo0ooo0017ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0002Sooooo`?oo`00BOooool00ol0
003oooooooooo`08ooooo`007_ooool2o`0000Cooooo0_l0002Rooooo`;oo`00B_ooool2o`0000[o
oooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0002Pooooo`?oo`00C?ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09gooooo0ooo
001>ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0W?ooool2ool0053ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2Jooooo`?oo`00DOooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09Sooooo0ooo001Cooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Uoooool2ool005Gooooo00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`000?oo
oooooooo09Gooooo0ooo001Eooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2Cooooo`?oo`00F?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo09;ooooo0_oo001Jooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0T?ooool3ool005_o
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2>ooooo`?oo`00GOooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Cooooo00?o
0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2=ooooo`;oo`00Goooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool0
000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2;ooooo`?oo`00H?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool0
0007ooooo`Go00001?ooool2o`0000Cooooo00?o0000ooooooooool0ROooool3ool0067ooooo0_l0
000:ooooo`002_ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`28ooooo`;oo`00I?ooool00ol0003ooooo
ooooo`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`26ooooo`;oo`00I_ooool00ol0003ooooo
ooooo`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`;o00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo08Cooooo0ooo001Wooooo`03o`000?oooooooooo00Sooooo
000;ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0Poooool2ool006Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`21ooooo`;oo`00Joooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07oooooo0ooo001/oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`1nooooo`;o
o`00KOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
O?ooool2ool0073ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1jooooo`?oo`00LOooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Wooooo0_oo001cooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Moooool2ool0
07Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1eooooo`?oo`00M_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo07?ooooo0ooo001hooooo`03o`000?oooooooooo00Sooooo
000Nooooo`;o00001?ooool00ol0003oooooooooo`1booooo`;oo`00NOooool2o`0000[ooooo000N
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L?ooool3ool007_ooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1^oooo
o`?oo`00OOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo06gooooo0_oo001oooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Joooool3ool0083ooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Yooooo`?oo`00P_oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06Sooooo0_oo0024ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0
003oooooooooo`1Vooooo`?oo`00Q?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool3ool008Oooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`;oo`00ROooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo067ooooo0ooo
002:ooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05oooooo0ooo002<
ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_oo
ool2ool008kooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Looooo`;oo`00T?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003ooooooooo
ool00007ooooo`Co00001Oooool2o`0000Cooooo00?o0000ooooooooool0F_ooool3ool0093ooooo
0_l0000:ooooo`002_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Iooooo`;oo`00Toooool00ol0003ooooo
ooooo`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Gooooo`?oo`00U?ooool00ol0003ooooo
ooooo`08ooooo`002oooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0EOooool3ool009Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Dooooo`;oo`00V?ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05;ooooo0_oo002Joooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0D?ooool3ool009_ooooo00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`00
0?oooooooooo04oooooo0_oo002Looooo`;o00002_ooool001kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1=ooooo`;oo`00Woooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo04_ooooo0ooo002Pooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0BOooool3ool0
0:;ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`18ooooo`;oo`00Y?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04Kooooo0ooo002Uooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A?ooool3ool00:Oooooo00?o
0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo04?ooooo0_oo002X
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`11oooo
o`?oo`00Z_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03oooooo0ooo002/ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool2ool00:kooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0looooo`?oo`00[ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03[ooooo0ooo002aooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0>Oooool2ool00;?ooooo00?o0000ooooooooool02?ooool001ko
oooo0_l00004ooooo`03o`000?oooooooooo03Oooooo0ooo002cooooo`;o00002_ooool001kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0eooooo`?oo`00]_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo0_oo
002hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0<_ooool3ool00;Wooooo00?o0000ooooooooool02?ooool000_ooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0<?ooool3ool00;_ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0^ooooo`?oo`00_Oooool00ol0003oooooooooo`08ooooo`002_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02gooooo0_oo002oooooo`03o`000?oooooooooo00Sooooo000:
ooooo`04o`000?ooooooooooo`0000Sooooo0ol00005ooooo`;o00001?ooool00ol0003ooooooooo
o`0[ooooo`?oo`00_oooool2o`0000[ooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
:Oooool3ool00<;ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Xooooo`;oo`00a?ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Wooooo
0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool3ool00<Gooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Tooooo`?oo`00aoooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02?ooooo0_oo0039ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool3ool00<[ooooo00?o0000oooo
ooooool02?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo01oooooo0ooo003;ooooo`;o
00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`;oo`00
c_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01cooooo0_oo003@ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06_ooool3ool00=7ooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`;oo`00doooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oo
oooo0_oo003Eooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05Oooool3ool00=Kooooo00?o0000ooooooooool02?ooool001kooooo0_l0
0004ooooo`03o`000?oooooooooo01?ooooo0ooo003Gooooo`;o00002_ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Booooo`;oo`00f_ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo0ooo003Koooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03_ooool3ool00=gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0=ooooo`;oo`00goooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo0_oo003Qooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool3
ool00>;ooooo00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo
00Oooooo0ooo003Sooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`06ooooo`;oo`00i_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo0ooo003Wooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3ool00>Wooooo00?o
0000ooooooooool02?ooool001Kooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_oo003[ooooo`03o`000?oooooooooo00Sooooo000Gooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool01?l0003oooooool00?oo003]ooooo`03o`000?oo
oooooooo00Sooooo000Gooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`?oo`00kOooool2
o`0000[ooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m?ooool00ol0
003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Co
oooo00?o0000ooooooooool02?ooool001Kooooo0_l00006ooooo`03o`000?oooooooooo0?Cooooo
00?o0000ooooooooool02?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3dooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo0?Cooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo000NooooooSo00002_ooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool004Gooooo0_l000001Ooooooo0000
o`000?l0003ooooo00?o00000oooool4o`0000?ooooo0_l000000ooooooo0000o`000004o`0000;o
oooo1?l00003ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l0
00001oooool3o`0000;ooooo0ol00004ooooo`Co000000Goooooo`000?l0003o0000ooooo`06o`00
00;ooooo1Ol00002ooooo`?o00000_ooool3o`0000Wooooo0ol00005ooooo`;o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?ooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3
o`0000;ooooo0ol000000ooooooo0000o`00000cooooo`00AOooool01ol0003ooooooooooooooooo
0000ooooool000000oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0003Cooooo
0015ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool3
o`0000?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool3o`0000Co
oooo00Co0000oooooooooooooooo1Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
1_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo03;ooooo0015ooooo`07o`000?oooooooooooooo
ool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`06o`000?ooooooooooo`000?oooooo00001oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_l0000:ooooo`?o00000oooool01?l0
003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003ooooo
ooooool00006ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo03;ooooo0015ooooo`05o`000?oooooo0000ooooool000000_ooool3
o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02
ooooo`;o00000oooool4o`0000;ooooo0ol00004ooooo`?o00000_ooool4o`0000Sooooo00Ko0000
ooooool0003oooooo`000?ooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co0000
0oooool4o`0000;ooooo1?l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000Sooooo
00?o0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool3o`0000;o
oooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l0000eooooo`00AOooool2o`000003oooo
ool0003o000000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooool0003oooooo`00000Kooooo`03o`000?oooooooooo01Co
oooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`17ooooo`00AOooool01?l0003o
ooooooooooooool2o`0000Sooooo0_l00008ooooo`?o00002_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01?ooooo1Ol0000Looooo`;o00004oooool5o`0001Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`10ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-66.2392, -0.137062, \
1.82559, 0.00720095}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] 0.49966958432041564`\), 
        ",", \(BackFocalLength \[Rule] 93.35095557506479`\), 
        ",", \(BackFocalPoint \[Rule] {153.3509555750648`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] 1.2263648735485946`\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] 0\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {50.`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.583004929987583`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {53.41699507001242`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 1\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 1, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] False\), 
        ",", \(FindPupils \[Rule] Automatic\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 99.93396050505237`\), 
        ",", \(FrequencyCutoff \[Rule] 859.4809545650826`\), 
        ",", \(FrontFocalLength \[Rule] 99.93396050505234`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-49.93396050505234`\), 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {150.`, 0.`, 0.`}\), 
        ",", \(ImageSampleSize \[Rule] 0.0006256963640554054`\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[100, 50, 10], 50.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[Screen[50], {x, 150.`}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(IntensityTransform \[Rule] True\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.9341264481391712`, 
              6.583004929987581`}, {\(-0.010006608313591684`\), 
              0.9999999999999998`}}\), ",", 
        RowBox[{"ModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 429.7404772825413`}}, "<>"]\),
            
            False,
            Editable->False]}], ",", \(NormalizePlot \[Rule] True\), 
        ",", \(NumberOfPoints \[Rule] 2048\), 
        ",", \(NumberOfRays \[Rule] 128\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(LineOfRays[45, NumberOfRays \[Rule] 11]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 58.62342361805182`\), ",", 
        RowBox[{"OpticalLengthFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-22.681712035282395`\), 
                  22.681712035282395`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-22.681712035282395`\), 
                  22.681712035282395`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {58.62342361805182`, 
            58.65060962220028`}\), ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"ModulationTransferFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PaddingFactor \[Rule] Automatic\), 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
        RowBox[{"PerfectModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 429.7404772825413`}}, "<>"]\),
            
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPhaseTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 429.7404772825413`}}, "<>"]\),
            
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.6400873804286797`\), 
                  0.6407130767927351`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PhaseTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 429.7404772825413`}}, "<>"]\),
            
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] True\), 
        ",", \(PlotPoints \[Rule] 64\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.6400873804286797`\), 
                  0.6407130767927351`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{50.00000000000003`, 0, 
              0}, {53.41699507001243`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 3.4169950700124048`\), 
        ",", \(RayBoundary \[Rule] {\(-22.681712035282395`\), 
            22.681712035282395`}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {ModulationTransferFunction, 
            PointSpreadFunction, OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] True\), 
        ",", \(ShowPerfectCase \[Rule] True\), 
        ",", \(SignalPlotCutoff \[Rule] 0.01`\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 2190\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.012646791897776873`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{0.033531699915919685`, 
              98.25958992578354`}, {\(-0.010006608313591682`\), 
              0.49966958432041564`}}\), 
        ",", \(TransverseMagnification \[Rule] 0.033531699915919685`\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-24.045541711140054`\), 
                  23.986319069457963`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[68]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
MTF[sys, NumberOfPoints->2048, NumberOfRays->128, FindImagePoint->True]\
\>", "Input",
  CellLabel->"In[72]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0210016 -701.53 11.967 [
[.07997 -0.0125 -9 -9 ]
[.07997 -0.0125 9 0 ]
[.28998 -0.0125 -9 -9 ]
[.28998 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.71002 -0.0125 -6 -9 ]
[.71002 -0.0125 6 0 ]
[.92003 -0.0125 -6 -9 ]
[.92003 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09339 -30 -4.5 ]
[-0.0125 .09339 0 4.5 ]
[-0.0125 .21306 -30 -4.5 ]
[-0.0125 .21306 0 4.5 ]
[-0.0125 .33273 -30 -4.5 ]
[-0.0125 .33273 0 4.5 ]
[-0.0125 .4524 -30 -4.5 ]
[-0.0125 .4524 0 4.5 ]
[-0.0125 .57207 -30 -4.5 ]
[-0.0125 .57207 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07997 0 m
.07997 .00625 L
s
[(-20)] .07997 -0.0125 0 1 Mshowa
.28998 0 m
.28998 .00625 L
s
[(-10)] .28998 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.71002 0 m
.71002 .00625 L
s
[(10)] .71002 -0.0125 0 1 Mshowa
.92003 0 m
.92003 .00625 L
s
[(20)] .92003 -0.0125 0 1 Mshowa
.125 Mabswid
.12197 0 m
.12197 .00375 L
s
.16397 0 m
.16397 .00375 L
s
.20598 0 m
.20598 .00375 L
s
.24798 0 m
.24798 .00375 L
s
.33199 0 m
.33199 .00375 L
s
.37399 0 m
.37399 .00375 L
s
.41599 0 m
.41599 .00375 L
s
.458 0 m
.458 .00375 L
s
.542 0 m
.542 .00375 L
s
.58401 0 m
.58401 .00375 L
s
.62601 0 m
.62601 .00375 L
s
.66801 0 m
.66801 .00375 L
s
.75202 0 m
.75202 .00375 L
s
.79402 0 m
.79402 .00375 L
s
.83603 0 m
.83603 .00375 L
s
.87803 0 m
.87803 .00375 L
s
.03797 0 m
.03797 .00375 L
s
.96203 0 m
.96203 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09339 m
.00625 .09339 L
s
[(58.63)] -0.0125 .09339 1 0 Mshowa
0 .21306 m
.00625 .21306 L
s
[(58.64)] -0.0125 .21306 1 0 Mshowa
0 .33273 m
.00625 .33273 L
s
[(58.65)] -0.0125 .33273 1 0 Mshowa
0 .4524 m
.00625 .4524 L
s
[(58.66)] -0.0125 .4524 1 0 Mshowa
0 .57207 m
.00625 .57207 L
s
[(58.67)] -0.0125 .57207 1 0 Mshowa
.125 Mabswid
0 .11733 m
.00375 .11733 L
s
0 .14126 m
.00375 .14126 L
s
0 .16519 m
.00375 .16519 L
s
0 .18913 m
.00375 .18913 L
s
0 .237 m
.00375 .237 L
s
0 .26093 m
.00375 .26093 L
s
0 .28486 m
.00375 .28486 L
s
0 .3088 m
.00375 .3088 L
s
0 .35666 m
.00375 .35666 L
s
0 .3806 m
.00375 .3806 L
s
0 .40453 m
.00375 .40453 L
s
0 .42847 m
.00375 .42847 L
s
0 .47633 m
.00375 .47633 L
s
0 .50027 m
.00375 .50027 L
s
0 .5242 m
.00375 .5242 L
s
0 .54814 m
.00375 .54814 L
s
0 .06946 m
.00375 .06946 L
s
0 .04552 m
.00375 .04552 L
s
0 .02159 m
.00375 .02159 L
s
0 .596 m
.00375 .596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07997 .61178 m
.07997 .61803 L
s
.28998 .61178 m
.28998 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.71002 .61178 m
.71002 .61803 L
s
.92003 .61178 m
.92003 .61803 L
s
.125 Mabswid
.12197 .61428 m
.12197 .61803 L
s
.16397 .61428 m
.16397 .61803 L
s
.20598 .61428 m
.20598 .61803 L
s
.24798 .61428 m
.24798 .61803 L
s
.33199 .61428 m
.33199 .61803 L
s
.37399 .61428 m
.37399 .61803 L
s
.41599 .61428 m
.41599 .61803 L
s
.458 .61428 m
.458 .61803 L
s
.542 .61428 m
.542 .61803 L
s
.58401 .61428 m
.58401 .61803 L
s
.62601 .61428 m
.62601 .61803 L
s
.66801 .61428 m
.66801 .61803 L
s
.75202 .61428 m
.75202 .61803 L
s
.79402 .61428 m
.79402 .61803 L
s
.83603 .61428 m
.83603 .61803 L
s
.87803 .61428 m
.87803 .61803 L
s
.03797 .61428 m
.03797 .61803 L
s
.96203 .61428 m
.96203 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09339 m
1 .09339 L
s
.99375 .21306 m
1 .21306 L
s
.99375 .33273 m
1 .33273 L
s
.99375 .4524 m
1 .4524 L
s
.99375 .57207 m
1 .57207 L
s
.125 Mabswid
.99625 .11733 m
1 .11733 L
s
.99625 .14126 m
1 .14126 L
s
.99625 .16519 m
1 .16519 L
s
.99625 .18913 m
1 .18913 L
s
.99625 .237 m
1 .237 L
s
.99625 .26093 m
1 .26093 L
s
.99625 .28486 m
1 .28486 L
s
.99625 .3088 m
1 .3088 L
s
.99625 .35666 m
1 .35666 L
s
.99625 .3806 m
1 .3806 L
s
.99625 .40453 m
1 .40453 L
s
.99625 .42847 m
1 .42847 L
s
.99625 .47633 m
1 .47633 L
s
.99625 .50027 m
1 .50027 L
s
.99625 .5242 m
1 .5242 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .06946 m
1 .06946 L
s
.99625 .04552 m
1 .04552 L
s
.99625 .02159 m
1 .02159 L
s
.99625 .596 m
1 .596 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .09339 m
1 .09339 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .55624 Mdot
.03144 .56935 Mdot
.03906 .58013 Mdot
.04668 .5887 Mdot
.05429 .59519 Mdot
.06189 .59971 Mdot
.06948 .60239 Mdot
.07707 .60332 Mdot
.08465 .60262 Mdot
.09223 .60038 Mdot
.0998 .59672 Mdot
.10736 .59171 Mdot
.11492 .58547 Mdot
.12248 .57806 Mdot
.13002 .56959 Mdot
.13757 .56013 Mdot
.14511 .54977 Mdot
.15264 .53857 Mdot
.16017 .52662 Mdot
.1677 .51399 Mdot
.17522 .50075 Mdot
.18274 .48696 Mdot
.19025 .47268 Mdot
.19776 .45799 Mdot
.20527 .44294 Mdot
.21277 .42759 Mdot
.22027 .412 Mdot
.22776 .39621 Mdot
.23526 .38028 Mdot
.24275 .36426 Mdot
.25023 .34821 Mdot
.25772 .33215 Mdot
.2652 .31615 Mdot
.27268 .30024 Mdot
.28015 .28446 Mdot
.28763 .26885 Mdot
.2951 .25345 Mdot
.30257 .23829 Mdot
.31004 .22342 Mdot
.3175 .20886 Mdot
.32496 .19465 Mdot
.33243 .1808 Mdot
.33989 .16737 Mdot
.34734 .15436 Mdot
.3548 .14181 Mdot
.36225 .12973 Mdot
.36971 .11817 Mdot
.37716 .10712 Mdot
.38461 .09663 Mdot
.39206 .0867 Mdot
.39951 .07735 Mdot
.40696 .0686 Mdot
.4144 .06046 Mdot
.42185 .05295 Mdot
.4293 .04609 Mdot
.43674 .03988 Mdot
.44418 .03433 Mdot
.45163 .02945 Mdot
.45907 .02526 Mdot
.46651 .02175 Mdot
.47395 .01894 Mdot
.4814 .01683 Mdot
.48884 .01542 Mdot
.49628 .01472 Mdot
.50372 .01472 Mdot
.51116 .01542 Mdot
.5186 .01683 Mdot
.52605 .01894 Mdot
.53349 .02175 Mdot
.54093 .02526 Mdot
.54837 .02945 Mdot
.55582 .03433 Mdot
.56326 .03988 Mdot
.5707 .04609 Mdot
.57815 .05295 Mdot
.5856 .06046 Mdot
.59304 .0686 Mdot
.60049 .07735 Mdot
.60794 .0867 Mdot
.61539 .09663 Mdot
.62284 .10712 Mdot
.63029 .11817 Mdot
.63775 .12973 Mdot
.6452 .14181 Mdot
.65266 .15436 Mdot
.66011 .16737 Mdot
.66757 .1808 Mdot
.67504 .19465 Mdot
.6825 .20886 Mdot
.68996 .22342 Mdot
.69743 .23829 Mdot
.7049 .25345 Mdot
.71237 .26885 Mdot
.71985 .28446 Mdot
.72732 .30024 Mdot
.7348 .31615 Mdot
.74228 .33215 Mdot
.74977 .34821 Mdot
.75725 .36426 Mdot
.76474 .38028 Mdot
.77224 .39621 Mdot
.77973 .412 Mdot
.78723 .42759 Mdot
.79473 .44294 Mdot
.80224 .45799 Mdot
.80975 .47268 Mdot
.81726 .48696 Mdot
.82478 .50075 Mdot
.8323 .51399 Mdot
.83983 .52662 Mdot
.84736 .53857 Mdot
.85489 .54977 Mdot
.86243 .56013 Mdot
.86998 .56959 Mdot
.87752 .57806 Mdot
.88508 .58547 Mdot
.89264 .59171 Mdot
.9002 .59672 Mdot
.90777 .60038 Mdot
.91535 .60262 Mdot
.92293 .60332 Mdot
.93052 .60239 Mdot
.93811 .59971 Mdot
.94571 .59519 Mdot
.95332 .5887 Mdot
.96094 .58013 Mdot
.96856 .56935 Mdot
.97619 .55624 Mdot
.5 Mabswid
.02381 .55624 m
.03097 .56855 L
.03853 .57937 L
.04619 .58815 L
.05058 .59203 L
.05458 .59537 L
.05815 .59749 L
.06004 .59861 L
.06107 .59923 L
.06157 .59953 L
.06204 .59977 L
.06252 .59994 L
.06305 .60012 L
.06417 .60052 L
.06614 .60121 L
.06801 .60187 L
.06851 .60204 L
.06904 .60223 L
.06929 .60232 L
.06955 .60239 L
.07001 .60245 L
.07198 .60269 L
.07376 .60291 L
.07544 .60312 L
.07589 .60317 L
.07637 .60323 L
.07682 .60329 L
.07724 .6033 L
.07774 .60326 L
.07826 .60321 L
.07919 .60312 L
.08101 .60295 L
.08206 .60286 L
.08316 .60275 L
.08411 .60267 L
.08436 .60264 L
.08464 .60262 L
.08514 .60247 L
.08871 .60142 L
.09069 .60084 L
.09166 .60055 L
.09256 .60022 L
.09431 .59938 L
.0962 .59846 L
.09952 .59685 L
.10667 .59217 L
.11453 .58579 L
.1299 .56974 L
.14469 .55035 L
.16041 .52622 L
Mistroke
.17556 .50013 L
.19013 .47292 L
.20563 .44219 L
.22056 .41138 L
.23642 .3778 L
.2517 .34506 L
.26641 .31357 L
.28205 .2805 L
.29711 .24936 L
.3116 .22038 L
.32702 .19084 L
.34186 .16392 L
.35764 .13721 L
.37283 .11353 L
.38746 .09283 L
.40301 .07323 L
.41799 .05684 L
.43239 .0435 L
.44773 .03201 L
.46248 .02365 L
.47013 .02039 L
.47403 .01892 L
.47818 .01774 L
.48213 .01669 L
.48571 .01601 L
.48747 .01568 L
.48833 .01552 L
.48871 .01545 L
.48912 .01539 L
.48954 .01535 L
.48994 .01532 L
.49083 .01523 L
.49271 .01505 L
.49469 .01487 L
.49556 .01478 L
.49603 .01474 L
.49653 .01472 L
.49698 .01472 L
.4974 .01472 L
.49823 .01472 L
.50004 .01472 L
.50188 .01472 L
.50239 .01472 L
.50293 .01472 L
.50319 .01472 L
.50343 .01472 L
.5039 .01473 L
.50439 .01478 L
.50491 .01483 L
.50585 .01492 L
Mistroke
.50797 .01512 L
.50981 .01529 L
.51025 .01533 L
.51071 .01538 L
.51115 .01542 L
.51155 .0155 L
.51252 .01568 L
.51357 .01588 L
.51541 .01623 L
.52239 .0179 L
.52972 .02033 L
.53766 .02372 L
.55329 .03267 L
.56834 .04411 L
.58281 .05765 L
.59822 .07467 L
.61305 .0935 L
.62881 .11597 L
.644 .13986 L
.65861 .16473 L
.67415 .193 L
.68912 .22177 L
.70351 .25062 L
.71883 .28233 L
.73357 .31354 L
.74925 .34711 L
.76436 .37945 L
.77888 .41021 L
.79434 .44214 L
.80922 .47165 L
.82504 .5012 L
.84028 .52734 L
.85494 .54983 L
.87053 .57022 L
.88555 .58586 L
.8931 .59202 L
.89999 .59658 L
.90354 .59834 L
.90542 .59924 L
.90741 .60021 L
.90852 .6006 L
.90953 .6009 L
.91149 .60148 L
.91338 .60204 L
.91441 .60234 L
.91491 .60249 L
.91537 .60262 L
.91582 .60266 L
.91625 .6027 L
.9172 .60279 L
Mistroke
.9192 .60297 L
.92091 .60313 L
.92185 .60322 L
.9223 .60326 L
.92272 .6033 L
.92317 .60329 L
.92366 .60323 L
.9247 .6031 L
.92653 .60288 L
.92853 .60263 L
.92963 .6025 L
.92989 .60246 L
.93016 .60243 L
.93066 .60234 L
.93111 .60218 L
.9316 .602 L
.93263 .60165 L
.93441 .60102 L
.93623 .60038 L
.93702 .6001 L
.93789 .59979 L
.93841 .59953 L
.9389 .59925 L
.93986 .59868 L
.94197 .59742 L
.9438 .59633 L
.94578 .59513 L
.94945 .59201 L
.95289 .58907 L
.96074 .58036 L
.97619 .55624 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00=Oooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00005Oooool003Kooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001Cooooo000_ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Cooooo000hooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool04_ooool003Gooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Doooo
o`00=Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Dooooo`00=_ooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Eooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`009?oooooho`0000Cooooo000Tooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`02ooooo`009?oo
ool00ol0003oooooooooo`1cooooo`_o0000M_ooool00ol0003oooooooooo`02ooooo`009?ooool0
0ol0003oooooooooo`1aooooo`oo0000M?ooool00ol0003oooooooooo`02ooooo`009?ooool2o`00
073ooooo1?l00005ooooo`03o`000?oooooooooo00?ooooo1?l0001aooooo`;o00001?ooool002Co
oooo00?o0000ooooooooool0K_ooool4o`0000Kooooo00?o0000ooooooooool01Oooool4o`00073o
oooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0K?ooool4o`0000Sooooo
00?o0000ooooooooool01oooool4o`0006kooooo00?o0000ooooooooool00_ooool002Cooooo00?o
0000ooooooooool0J_ooool4o`0000[ooooo00?o0000ooooooooool02Oooool4o`0006cooooo00?o
0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0J?ooool4o`0000cooooo00?o0000
ooooooooool02oooool3o`0006_ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooo
ooooool0J?ooool2o`0000kooooo00?o0000ooooooooool03?ooool2o`0006_ooooo00?o0000oooo
ooooool00_ooool002Cooooo0_l0001Wooooo`;o00004?ooool00ol0003oooooooooo`0>ooooo`;o
0000J?ooool2o`0000Cooooo000Tooooo`03o`000?oooooooooo06Cooooo1?l0000@ooooo`03o`00
0?oooooooooo00kooooo1?l0001Wooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oo
oooooooo06Cooooo0_l0000Booooo`03o`000?oooooooooo013ooooo0_l0001Wooooo`03o`000?oo
oooooooo00;ooooo000Tooooo`03o`000?oooooooooo06?ooooo0_l0000Cooooo`03o`000?oooooo
oooo01;ooooo0_l0001Uooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo
06?ooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo0_l0001Uooooo`03o`000?oooooooooo
00;ooooo000Tooooo`03o`000?oooooooooo067ooooo0ol0000Dooooo`03o`000?oooooooooo01Co
oooo0_l0001Sooooo`03o`000?oooooooooo00;ooooo000Tooooo`;o0000H_ooool2o`0001Gooooo
00?o0000ooooooooool05?ooool2o`0006;ooooo0_l00004ooooo`009?ooool00ol0003ooooooooo
o`1Oooooo`?o00005_ooool00ol0003oooooooooo`0Fooooo`;o0000HOooool00ol0003ooooooooo
o`02ooooo`009?ooool00ol0003oooooooooo`1Oooooo`?o00005_ooool00ol0003oooooooooo`0F
ooooo`;o0000HOooool00ol0003oooooooooo`02ooooo`001?ooool3o`0000?ooooo0ol00004oooo
o`03o`000?oooooooooo00;ooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo00;ooooo0003ooooo`07o`000?ooooooooooooooool0003oooooo`000003
ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Mooooo`?o00006?ooool00ol0003ooooo
ooooo`0Gooooo`;o0000H?ooool00ol0003oooooooooo`02ooooo`001oooool00ol0003oooooo`00
0003ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0GOooool2o`0001Wooooo00?o0000ooooooooool0
5oooool2o`00063ooooo00?o0000ooooooooool00_ooool000Oooooo00?o0000ooooooooool00ol0
0008ooooo`Co00001?ooool2o`0000Gooooon?l00004ooooo`000oooool4o`0000;ooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Kooooo`?o00006_ooool00ol0003oooooooooo`0Iooooo`;o0000G_oo
ool00ol0003oooooooooo`02ooooo`000oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00;ooooo0003ooooo`Go00000_oo
ool3o`0000[ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`1Iooooo`?o00007?oo
ool00ol0003oooooooooo`0Kooooo`;o0000G?ooool00ol0003oooooooooo`02ooooo`009?ooool0
0ol0003oooooooooo`1Iooooo`;o00007Oooool00ol0003oooooooooo`0Kooooo`;o0000G?ooool0
0ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
00;ooooo000Tooooo`;o0000FOooool2o`0001kooooo00?o0000ooooooooool07Oooool2o`0005Wo
oooo0_l00004ooooo`009?ooool00ol0003oooooooooo`1Hooooo`;o00007_ooool00ol0003ooooo
ooooo`0Mooooo`;o0000F_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooooooo
o`1Fooooo`;o00008?ooool00ol0003oooooooooo`0Oooooo`;o0000F?ooool00ol0003ooooooooo
o`02ooooo`009?ooool00ol0003oooooooooo`1Fooooo`;o00008?ooool00ol0003oooooooooo`0O
ooooo`;o0000F?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo05Cooooo0_l0000Rooooo`03
o`000?oooooooooo027ooooo0_l0001Fooooo`03o`000?oooooooooo00;ooooo000Tooooo`;o0000
EOooool2o`0002;ooooo00?o0000ooooooooool08Oooool2o`0005Gooooo0_l00004ooooo`009?oo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooo
oooo05;ooooo0_l0000Tooooo`03o`000?oooooooooo02?ooooo0_l0001Dooooo`03o`000?oooooo
oooo00;ooooo000Tooooo`03o`000?oooooooooo05;ooooo0_l0000Tooooo`03o`000?oooooooooo
02?ooooo0_l0001Dooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool00_ooool002Cooooo0_l0001Booooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1@ooooo`;o00001?ooool002Cooooo00?o
0000ooooooooool0D?ooool2o`0002Kooooo00?o0000ooooooooool09?ooool2o`0005?ooooo00?o
0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0D?ooool2o`0002Kooooo00?o0000
ooooooooool09?ooool3o`0005;ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`1>ooooo`;o
0000:?ooool00ol0003oooooooooo`0Vooooo`;o0000DOooool00ol0003oooooooooo`02ooooo`00
9?ooool00ol0003oooooooooo`1>ooooo`;o0000:?ooool00ol0003oooooooooo`0Vooooo`?o0000
D?ooool00ol0003oooooooooo`02ooooo`009?ooool2o`00053ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04gooooo0_l00004ooooo`009?ooool0
0ol0003oooooooooo`1=ooooo`;o0000:Oooool00ol0003oooooooooo`0Xooooo`;o0000Coooool0
0ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`1=ooooo`;o0000:Oooool00ol0
003oooooooooo`0Xooooo`;o0000Coooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo00;ooooo0004ooooo`?o00000oooool3o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0000Cooooo0ol00004ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool00_ooool000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?o
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1;ooooo`;o0000:oooool00ol0003oooooooooo`0Zoooo
o`;o0000COooool00ol0003oooooooooo`02ooooo`001oooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo00Gooooo00Ko0000ooooooooooooooooo`000?ooool5o`0000Cooooo0_l0001<
ooooo`;o0000:oooool00ol0003oooooooooo`0Zooooo`;o0000C?ooool2o`0000Cooooo0007oooo
o`03o`000?oooooooooo00?o00002?ooool4o`0000;ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00;ooooo0003ooooo`Co00000_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00_ooool000?ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01?ooool2
o`0000Gooooo00?o0000ooooooooool0BOooool2o`0002gooooo00?o0000ooooooooool0;?ooool2
o`0004_ooooo00?o0000ooooooooool00_ooool000?ooooo1Ol00002ooooo`?o00002_ooool2o`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`19ooooo`;o0000;Oooool00ol0
003oooooooooo`0/ooooo`;o0000Boooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo00;ooooo000Tooooo`;o0000B?ooool2o`0002oooooo
00?o0000ooooooooool0;_ooool2o`0004Sooooo0_l00004ooooo`009?ooool00ol0003ooooooooo
o`17ooooo`;o0000;oooool00ol0003oooooooooo`0^ooooo`;o0000BOooool00ol0003ooooooooo
o`02ooooo`009?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00;ooooo000Toooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooooooo
ool0AOooool2o`00037ooooo00?o0000ooooooooool0;oooool2o`0004Sooooo00?o0000oooooooo
ool00_ooool002Cooooo00?o0000ooooooooool0AOooool2o`00037ooooo00?o0000ooooooooool0
;oooool2o`0004Sooooo00?o0000ooooooooool00_ooool002Cooooo0_l00016ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`14ooooo`;o00001?oo
ool002Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`02ooooo`009?ooool00ol0
003oooooooooo`13ooooo`;o0000<oooool00ol0003oooooooooo`0aooooo`;o0000A_ooool00ol0
003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`13ooooo`;o0000<oooool00ol0003o
ooooooooo`0aooooo`?o0000AOooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool00_ooool002Cooooo0_l00012ooooo`?o0000=?ooool00ol0003oooooooooo`0c
ooooo`;o0000@oooool2o`0000Cooooo000Tooooo`03o`000?oooooooooo047ooooo0_l0000eoooo
o`03o`000?oooooooooo03?ooooo0ol00013ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`10ooooo`;o0000=_oo
ool00ol0003oooooooooo`0eooooo`;o0000@_ooool00ol0003oooooooooo`02ooooo`009?ooool0
0ol0003oooooooooo`10ooooo`;o0000=_ooool00ol0003oooooooooo`0eooooo`;o0000@_ooool0
0ol0003oooooooooo`02ooooo`009?ooool2o`00047ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03oooooo0_l00004ooooo`009?ooool00ol0003o
ooooooooo`0nooooo`;o0000>?ooool00ol0003oooooooooo`0gooooo`;o0000@?ooool00ol0003o
ooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0nooooo`;o0000>?ooool00ol0003ooooo
ooooo`0gooooo`;o0000@?ooool00ol0003oooooooooo`02ooooo`001?ooool3o`0000?ooooo0ol0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`?o00001Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00;ooooo0003ooooo`07o`000?ooooooooooooooool0003ooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
00;ooooo0007ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0loooo
o`;o0000>_ooool00ol0003oooooooooo`0iooooo`;o0000?_ooool00ol0003oooooooooo`02oooo
o`001oooool00ol0003oooooooooo`03o`0000Sooooo1?l00006ooooo`03o`000?oooooooooo00;o
oooo0_l0000mooooo`;o0000>_ooool00ol0003oooooooooo`0iooooo`;o0000?Oooool2o`0000Co
oooo0003ooooo`Co00000_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00oooool4o`0000Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`02ooooo`00
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`02ooooo`000oooool5o`0000;ooooo0ol0000:ooooo`;o00000_ooool5o`0000Cooooo
00?o0000ooooooooool0>_ooool2o`0003cooooo00?o0000ooooooooool0>oooool2o`0003cooooo
00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0>_ooool2o`0003cooooo00?o
0000ooooooooool0>oooool2o`0003cooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`009?ooool2o`0003_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03Wooooo0_l00004oooo
o`009?ooool00ol0003oooooooooo`0hooooo`;o0000?_ooool00ol0003oooooooooo`0looooo`;o
0000>oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0hooooo`;o0000
?_ooool00ol0003oooooooooo`0looooo`;o0000>oooool00ol0003oooooooooo`02ooooo`009?oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0=_ooool2o`00
043ooooo00?o0000ooooooooool0?_ooool2o`0003Wooooo00?o0000ooooooooool00_ooool002Co
oooo0_l0000gooooo`;o0000@?ooool00ol0003oooooooooo`0nooooo`;o0000>?ooool2o`0000Co
oooo000Tooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool002Cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0e
ooooo`;o0000@Oooool00ol0003oooooooooo`10ooooo`;o0000=oooool00ol0003oooooooooo`02
ooooo`009?ooool00ol0003oooooooooo`0eooooo`;o0000@Oooool00ol0003oooooooooo`10oooo
o`;o0000=oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00;ooooo000Tooooo`;o0000=Oooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo000Tooooo`03o`000?oo
oooooooo03?ooooo0_l00013ooooo`03o`000?oooooooooo04;ooooo0_l0000eooooo`03o`000?oo
oooooooo00;ooooo000Tooooo`03o`000?oooooooooo03?ooooo0_l00013ooooo`03o`000?oooooo
oooo04;ooooo0_l0000eooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0aooooo`;o0000AOooool00ol0003ooooo
ooooo`14ooooo`;o0000<oooool00ol0003oooooooooo`02ooooo`009?ooool2o`0003;ooooo0_l0
0015ooooo`03o`000?oooooooooo04Cooooo0_l0000booooo`;o00001?ooool002Cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00;ooooo0004ooooo`?o00000oooool3o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo02oooooo0_l00017ooooo`03
o`000?oooooooooo04Kooooo0_l0000aooooo`03o`000?oooooooooo00;ooooo0003ooooo`07o`00
0?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0_ooooo`;o0000Aoooool00ol0003oooooooooo`16ooooo`;o0000<Oooool00ol0003ooooooooo
o`02ooooo`001oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Oo0000
ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool2o`00033ooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02kooooo
0_l00004ooooo`001oooool00ol0003oooooooooo`03o`0000Sooooo1?l00002ooooo`Co00001Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo0003ooooo`Co00000_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02gooooo0_l00019ooooo`03o`000?oooooooooo04Sooooo0_l0
000_ooooo`03o`000?oooooooooo00;ooooo0003ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0]ooooo`;o0000BOooool00ol0003oooooooooo`18ooooo`;o0000;ooo
ool00ol0003oooooooooo`02ooooo`000oooool5o`0000;ooooo0ol0000:ooooo`;o00001?ooool2
o`0000Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0
003oooooooooo`0[ooooo`?o0000B_ooool00ol0003oooooooooo`19ooooo`;o0000;_ooool00ol0
003oooooooooo`02ooooo`009?ooool2o`0002cooooo0_l0001;ooooo`03o`000?oooooooooo04Wo
oooo0_l0000]ooooo`;o00001?ooool002Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo000T
ooooo`03o`000?oooooooooo02Wooooo0_l0001=ooooo`03o`000?oooooooooo04_ooooo0_l0000/
ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo02Wooooo0_l0001=oooo
o`03o`000?oooooooooo04_ooooo0_l0000/ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool002Cooooo0_l0000Yooooo`;o0000
C_ooool00ol0003oooooooooo`1=ooooo`;o0000:Oooool2o`0000Cooooo000Tooooo`03o`000?oo
oooooooo02Sooooo0_l0001>ooooo`03o`000?oooooooooo04gooooo0_l0000Zooooo`03o`000?oo
oooooooo00;ooooo000Tooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool0
02Cooooo00?o0000ooooooooool09_ooool2o`00053ooooo00?o0000ooooooooool0Coooool2o`00
02Sooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool09_ooool2o`00053o
oooo00?o0000ooooooooool0Coooool2o`0002Sooooo00?o0000ooooooooool00_ooool002Cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`009?ooool2o`0002Oooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02Cooooo0_l0
0004ooooo`009?ooool00ol0003oooooooooo`0Tooooo`;o0000D_ooool00ol0003oooooooooo`1A
ooooo`;o00009_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Toooo
o`;o0000D_ooool00ol0003oooooooooo`1Aooooo`;o00009_ooool00ol0003oooooooooo`02oooo
o`009?ooool00ol0003oooooooooo`0Rooooo`?o0000Doooool00ol0003oooooooooo`1Cooooo`;o
00009?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Rooooo`;o0000
E?ooool00ol0003oooooooooo`1Cooooo`;o00009?ooool00ol0003oooooooooo`02ooooo`009?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00;ooooo000Tooooo`;o00008Oooool3
o`0005Gooooo00?o0000ooooooooool0E?ooool3o`00027ooooo0_l00004ooooo`009?ooool00ol0
003oooooooooo`0Pooooo`;o0000E_ooool00ol0003oooooooooo`1Eooooo`;o00008_ooool00ol0
003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`02ooooo`;o00007?ooool00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool06_ooool2o`0000Go
oooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool00_ooool2o`0001[ooooo
0_l0001Hooooo`03o`000?oooooooooo05Kooooo0_l0000Jooooo`;o00001Oooool00ol0003ooooo
ooooo`02ooooo`001?ooool3o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol0
0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Gooooo`;o0000F?ooool00ol0003oooooooooo`1Fooooo`;o00006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0003ooooo`07o`000?ooooooooooooooool0003ooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2o`0001Kooooo0_l0001Jooooo`03
o`000?oooooooooo05Sooooo0_l0000Gooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`00
1oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o00005_ooool2o`0005[o
oooo00?o0000ooooooooool0F?ooool3o`0001Kooooo0_l00005ooooo`;o00001?ooool000Oooooo
00?o0000ooooooooool00ol00008ooooo`Co00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04Oooool2o`0005cooooo00?o0000ooooooooool0
F_ooool2o`0001Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`000ooo
ool4o`0000;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`;o00004_ooool2o`0005cooooo
00?o0000ooooooooool0F_ooool3o`0001;ooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo
0003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Ko
oooo0_l0000Aooooo`;o0000GOooool00ol0003oooooooooo`1Looooo`;o00004?ooool3o`0000So
oooo00?o0000ooooooooool00_ooool000?ooooo1Ol00002ooooo`?o00002_ooool2o`0000;ooooo
1Ol00004ooooo`03o`000?oooooooooo00Sooooo0_l0000>ooooo`?o0000GOooool00ol0003ooooo
ooooo`1Looooo`?o00003_ooool2o`0000[ooooo00?o0000ooooooooool00_ooool002Cooooo00?o
0000ooooooooool02?ooool4o`0000[ooooo0ol0001Oooooo`03o`000?oooooooooo05kooooo0_l0
000;ooooo`Co00002_ooool00ol0003oooooooooo`02ooooo`009?ooool2o`0000_ooooo0_l00009
ooooo`Co0000Goooool00ol0003oooooooooo`1Nooooo`Co00002Oooool2o`0000_ooooo0_l00004
ooooo`009?ooool00ol0003oooooooooo`0<ooooo`_o0000HOooool00ol0003oooooooooo`1Poooo
o`_o00003_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0<ooooo`Wo
0000Hoooool00ol0003oooooooooo`1Rooooo`Wo00003_ooool00ol0003oooooooooo`02ooooo`00
9?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
0_ooool002Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool002Cooooon?l00004ooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00<?ooool3o`0005Sooooo0ol0000Gooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool03_ooool0037ooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool03Oooool0
02_ooooo0ol00003ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000oooool4o`00
0003ooooool0003o000000?o00001oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6o`00
00Kooooo1Ol00002ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`Co00000oooool2
o`0000;ooooo1_l00007ooooo`03o`000?oooooooooo00?ooooo1?l000000ooooooo0000o`000002
o`0000;ooooo1?l00003ooooo`?o00000_ooool5o`0000?ooooo0_l000001?oooooo0000oooooooo
ool2o`0000?ooooo0ol00009ooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000o`00
0002o`0000Cooooo0_l00003ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`000004oooo
ool0003o0000o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00cooooo000Zooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00006ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool0
00001?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00002ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooo`000003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool03?ooool002[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00Co0000oooooooooooo0000
0_ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go00001oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oooooo
oooo00?ooooo0ol00003ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5o`0000Cooooo
00?o0000ooooooooool03?ooool002[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Co
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000oooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Zooooo`06o`000?oo
ooooooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol00003ooooo`;o
00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003oooo
o`Co00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool3o`0000;ooooo1?l00003oooo
o`Wo00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol00003oooo
o`Co00000_ooool3o`0000Cooooo00Co0000oooooooooooooooo0_l000001?oooooo0000o`000?oo
ool4o`0000?ooooo0ol00009ooooo`?o00000_ooool3o`0000Cooooo1?l000000ooooooo0000o`00
0002o`0000?ooooo0_l00003ooooo`Co00000oooool3o`0000?ooooo0ol00005ooooo`03o`000?oo
oooooooo00cooooo000Zooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool002_ooooo0ol0
0009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool3o`0000Wooooo1?l0
0009ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`?o00005_ooool00ol0003ooooooooo
o`02ooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`;o00004?ooool3o`0000[ooooo00?o
0000ooooooooool04?ooool2o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00kooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-30.8197, 58.618, 0.192645, \
0.000338083}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0210016 -1.35862 0.889833 [
[.07997 -0.0125 -9 -9 ]
[.07997 -0.0125 9 0 ]
[.28998 -0.0125 -9 -9 ]
[.28998 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.71002 -0.0125 -6 -9 ]
[.71002 -0.0125 6 0 ]
[.92003 -0.0125 -6 -9 ]
[.92003 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06511 -18 -4.5 ]
[-0.0125 .06511 0 4.5 ]
[-0.0125 .1541 -18 -4.5 ]
[-0.0125 .1541 0 4.5 ]
[-0.0125 .24308 -18 -4.5 ]
[-0.0125 .24308 0 4.5 ]
[-0.0125 .33206 -18 -4.5 ]
[-0.0125 .33206 0 4.5 ]
[-0.0125 .42105 -6 -4.5 ]
[-0.0125 .42105 0 4.5 ]
[-0.0125 .51003 -18 -4.5 ]
[-0.0125 .51003 0 4.5 ]
[-0.0125 .59901 -18 -4.5 ]
[-0.0125 .59901 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07997 0 m
.07997 .00625 L
s
[(-20)] .07997 -0.0125 0 1 Mshowa
.28998 0 m
.28998 .00625 L
s
[(-10)] .28998 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.71002 0 m
.71002 .00625 L
s
[(10)] .71002 -0.0125 0 1 Mshowa
.92003 0 m
.92003 .00625 L
s
[(20)] .92003 -0.0125 0 1 Mshowa
.125 Mabswid
.12197 0 m
.12197 .00375 L
s
.16397 0 m
.16397 .00375 L
s
.20598 0 m
.20598 .00375 L
s
.24798 0 m
.24798 .00375 L
s
.33199 0 m
.33199 .00375 L
s
.37399 0 m
.37399 .00375 L
s
.41599 0 m
.41599 .00375 L
s
.458 0 m
.458 .00375 L
s
.542 0 m
.542 .00375 L
s
.58401 0 m
.58401 .00375 L
s
.62601 0 m
.62601 .00375 L
s
.66801 0 m
.66801 .00375 L
s
.75202 0 m
.75202 .00375 L
s
.79402 0 m
.79402 .00375 L
s
.83603 0 m
.83603 .00375 L
s
.87803 0 m
.87803 .00375 L
s
.03797 0 m
.03797 .00375 L
s
.96203 0 m
.96203 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06511 m
.00625 .06511 L
s
[(1.6)] -0.0125 .06511 1 0 Mshowa
0 .1541 m
.00625 .1541 L
s
[(1.7)] -0.0125 .1541 1 0 Mshowa
0 .24308 m
.00625 .24308 L
s
[(1.8)] -0.0125 .24308 1 0 Mshowa
0 .33206 m
.00625 .33206 L
s
[(1.9)] -0.0125 .33206 1 0 Mshowa
0 .42105 m
.00625 .42105 L
s
[(2)] -0.0125 .42105 1 0 Mshowa
0 .51003 m
.00625 .51003 L
s
[(2.1)] -0.0125 .51003 1 0 Mshowa
0 .59901 m
.00625 .59901 L
s
[(2.2)] -0.0125 .59901 1 0 Mshowa
.125 Mabswid
0 .08291 m
.00375 .08291 L
s
0 .10071 m
.00375 .10071 L
s
0 .1185 m
.00375 .1185 L
s
0 .1363 m
.00375 .1363 L
s
0 .17189 m
.00375 .17189 L
s
0 .18969 m
.00375 .18969 L
s
0 .20749 m
.00375 .20749 L
s
0 .22528 m
.00375 .22528 L
s
0 .26088 m
.00375 .26088 L
s
0 .27867 m
.00375 .27867 L
s
0 .29647 m
.00375 .29647 L
s
0 .31427 m
.00375 .31427 L
s
0 .34986 m
.00375 .34986 L
s
0 .36766 m
.00375 .36766 L
s
0 .38545 m
.00375 .38545 L
s
0 .40325 m
.00375 .40325 L
s
0 .43884 m
.00375 .43884 L
s
0 .45664 m
.00375 .45664 L
s
0 .47444 m
.00375 .47444 L
s
0 .49223 m
.00375 .49223 L
s
0 .52783 m
.00375 .52783 L
s
0 .54562 m
.00375 .54562 L
s
0 .56342 m
.00375 .56342 L
s
0 .58122 m
.00375 .58122 L
s
0 .04732 m
.00375 .04732 L
s
0 .02952 m
.00375 .02952 L
s
0 .01172 m
.00375 .01172 L
s
0 .61681 m
.00375 .61681 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07997 .61178 m
.07997 .61803 L
s
.28998 .61178 m
.28998 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.71002 .61178 m
.71002 .61803 L
s
.92003 .61178 m
.92003 .61803 L
s
.125 Mabswid
.12197 .61428 m
.12197 .61803 L
s
.16397 .61428 m
.16397 .61803 L
s
.20598 .61428 m
.20598 .61803 L
s
.24798 .61428 m
.24798 .61803 L
s
.33199 .61428 m
.33199 .61803 L
s
.37399 .61428 m
.37399 .61803 L
s
.41599 .61428 m
.41599 .61803 L
s
.458 .61428 m
.458 .61803 L
s
.542 .61428 m
.542 .61803 L
s
.58401 .61428 m
.58401 .61803 L
s
.62601 .61428 m
.62601 .61803 L
s
.66801 .61428 m
.66801 .61803 L
s
.75202 .61428 m
.75202 .61803 L
s
.79402 .61428 m
.79402 .61803 L
s
.83603 .61428 m
.83603 .61803 L
s
.87803 .61428 m
.87803 .61803 L
s
.03797 .61428 m
.03797 .61803 L
s
.96203 .61428 m
.96203 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06511 m
1 .06511 L
s
.99375 .1541 m
1 .1541 L
s
.99375 .24308 m
1 .24308 L
s
.99375 .33206 m
1 .33206 L
s
.99375 .42105 m
1 .42105 L
s
.99375 .51003 m
1 .51003 L
s
.99375 .59901 m
1 .59901 L
s
.125 Mabswid
.99625 .08291 m
1 .08291 L
s
.99625 .10071 m
1 .10071 L
s
.99625 .1185 m
1 .1185 L
s
.99625 .1363 m
1 .1363 L
s
.99625 .17189 m
1 .17189 L
s
.99625 .18969 m
1 .18969 L
s
.99625 .20749 m
1 .20749 L
s
.99625 .22528 m
1 .22528 L
s
.99625 .26088 m
1 .26088 L
s
.99625 .27867 m
1 .27867 L
s
.99625 .29647 m
1 .29647 L
s
.99625 .31427 m
1 .31427 L
s
.99625 .34986 m
1 .34986 L
s
.99625 .36766 m
1 .36766 L
s
.99625 .38545 m
1 .38545 L
s
.99625 .40325 m
1 .40325 L
s
.99625 .43884 m
1 .43884 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47444 m
1 .47444 L
s
.99625 .49223 m
1 .49223 L
s
.99625 .52783 m
1 .52783 L
s
.99625 .54562 m
1 .54562 L
s
.99625 .56342 m
1 .56342 L
s
.99625 .58122 m
1 .58122 L
s
.99625 .04732 m
1 .04732 L
s
.99625 .02952 m
1 .02952 L
s
.99625 .01172 m
1 .01172 L
s
.99625 .61681 m
1 .61681 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06511 m
1 .06511 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01662 m
.02558 .18234 L
.02723 .29163 L
.02816 .35327 L
.02862 .38357 L
.02904 .40331 L
.02952 .41798 L
.03005 .4339 L
.03097 .46173 L
.03181 .4871 L
.03228 .50109 L
.03272 .51089 L
.03297 .51338 L
.03324 .51609 L
.03371 .52086 L
.03464 .53019 L
.03562 .53999 L
.03587 .54258 L
.03615 .54537 L
.03641 .547 L
.03666 .54762 L
.03764 .55011 L
.03853 .55237 L
.03946 .55472 L
.03972 .5554 L
.03998 .55605 L
.04045 .55642 L
.04225 .55759 L
.0432 .55821 L
.04345 .55837 L
.04372 .55855 L
.0442 .55869 L
.04473 .55883 L
.04531 .55899 L
.04633 .55926 L
.05458 .56121 L
.07025 .56466 L
.08535 .56778 L
.09986 .57061 L
.11532 .57346 L
.13019 .57603 L
.146 .57861 L
.16123 .58093 L
.17588 .58302 L
.19147 .58512 L
.20648 .58699 L
.22092 .58867 L
.23628 .59035 L
.25107 .59184 L
.2668 .59334 L
Mistroke
.28194 .59466 L
.29651 .59581 L
.31202 .59696 L
.32694 .59796 L
.34281 .59893 L
.35809 .59975 L
.37279 .60046 L
.38843 .60111 L
.4035 .60166 L
.41798 .60213 L
.4334 .60252 L
.44052 .60268 L
.44824 .60282 L
.45635 .60294 L
.46402 .60304 L
.47157 .60312 L
.47246 .60311 L
.47291 .6031 L
.4734 .6031 L
.47366 .60311 L
.47394 .60312 L
.47443 .60314 L
.47538 .60317 L
.47596 .60319 L
.47651 .60321 L
.47701 .60323 L
.47729 .60322 L
.47755 .60322 L
.47861 .6032 L
.47958 .60318 L
.48002 .60317 L
.48049 .60316 L
.48095 .60316 L
.48136 .60318 L
.48227 .60321 L
.48328 .60324 L
.4837 .60325 L
.48414 .60327 L
.48457 .60328 L
.48496 .60327 L
.48674 .60323 L
.4872 .60322 L
.48769 .60321 L
.48815 .6032 L
.48857 .60321 L
.49057 .60327 L
.49105 .60328 L
.49157 .6033 L
.49183 .60331 L
.49213 .60331 L
Mistroke
.4924 .6033 L
.49265 .60329 L
.49366 .60327 L
.49461 .60324 L
.49508 .60323 L
.49552 .60322 L
.49577 .60322 L
.49604 .60323 L
.4965 .60324 L
.49751 .60327 L
.49857 .6033 L
.49902 .60331 L
.4995 .60332 L
.49978 .60331 L
.50003 .6033 L
.50053 .60329 L
.50146 .60327 L
.50233 .60324 L
.50276 .60323 L
.50317 .60322 L
.50359 .60323 L
.50406 .60324 L
.50505 .60327 L
.50595 .60329 L
.50637 .6033 L
.50676 .60331 L
.50716 .6033 L
.5076 .60329 L
.50939 .60324 L
.50987 .60322 L
.51014 .60322 L
.51039 .60321 L
.51083 .60321 L
.51131 .60322 L
.5124 .60324 L
.5134 .60327 L
.51385 .60328 L
.51434 .60329 L
.5148 .60327 L
.51522 .60326 L
.51623 .60323 L
.51718 .60319 L
.51761 .60318 L
.51805 .60317 L
.51854 .60318 L
.51899 .60318 L
.52062 .60322 L
.52105 .60322 L
.52152 .60323 L
.52196 .60323 L
Mistroke
.52236 .60322 L
.52327 .60319 L
.52427 .60315 L
.52472 .60314 L
.52522 .60312 L
.52568 .60311 L
.52611 .60312 L
.52704 .60314 L
.52806 .60315 L
.52851 .60316 L
.52899 .60317 L
.52944 .60317 L
.52985 .60315 L
.53156 .60309 L
.53205 .60307 L
.53258 .60305 L
.53302 .60304 L
.53352 .60304 L
.53454 .60306 L
.53563 .60307 L
.53617 .60308 L
.53643 .60308 L
.53667 .60309 L
.53713 .60307 L
.53762 .60305 L
.53859 .60302 L
.53947 .60298 L
.53992 .60296 L
.54033 .60295 L
.54076 .60294 L
.54124 .60295 L
.54223 .60296 L
.54314 .60297 L
.54355 .60298 L
.54399 .60298 L
.54442 .60298 L
.5448 .60296 L
.54658 .60288 L
.54746 .60285 L
.54795 .60283 L
.5484 .60283 L
.54943 .60284 L
.55039 .60285 L
.55087 .60285 L
.55138 .60286 L
.55168 .60286 L
.55194 .60285 L
.55246 .60282 L
.5534 .60278 L
.55443 .60274 L
Mistroke
.55489 .60272 L
.55539 .60269 L
.55586 .6027 L
.55629 .6027 L
.55723 .6027 L
.55773 .60271 L
.55825 .60271 L
.5587 .60271 L
.55919 .60271 L
.55964 .60269 L
.56006 .60267 L
.56177 .60259 L
.56227 .60257 L
.56274 .60255 L
.56323 .60254 L
.56349 .60254 L
.56377 .60254 L
.56464 .60255 L
.56559 .60255 L
.56587 .60255 L
.56617 .60255 L
.56642 .60255 L
.5667 .60255 L
.56696 .60253 L
.56724 .60252 L
.56775 .6025 L
.56868 .60245 L
.56921 .60242 L
.56971 .6024 L
.57017 .60238 L
.57044 .60237 L
.57068 .60237 L
.57171 .60237 L
.57268 .60237 L
.57357 .60237 L
.57405 .60237 L
.57431 .60236 L
.57455 .60234 L
.57562 .60229 L
.57675 .60223 L
.57724 .6022 L
.5775 .60219 L
.57778 .60218 L
.57826 .60217 L
.5787 .60217 L
.57967 .60217 L
.58022 .60217 L
.58074 .60217 L
.58121 .60217 L
.58148 .60216 L
Mistroke
.58172 .60216 L
.58221 .60213 L
.58267 .6021 L
.58353 .60206 L
.58452 .602 L
.585 .60198 L
.58545 .60196 L
.58589 .60196 L
.5863 .60196 L
.58722 .60195 L
.58815 .60195 L
.58841 .60194 L
.58868 .60194 L
.58917 .60193 L
.58963 .60191 L
.59013 .60188 L
.59104 .60183 L
.5931 .60172 L
.60014 .60148 L
.61581 .60089 L
.63091 .60023 L
.64543 .5995 L
.66088 .59866 L
.67576 .59774 L
.69157 .59668 L
.70681 .59555 L
.72146 .59435 L
.73705 .59299 L
.75207 .59156 L
.7665 .59006 L
.78187 .58837 L
.79667 .58662 L
.81239 .58464 L
.82754 .58258 L
.84212 .58046 L
.85762 .57808 L
.87255 .57562 L
.88842 .57283 L
.9037 .56997 L
.91841 .56706 L
.93405 .56379 L
.94185 .56207 L
.94912 .56036 L
.95272 .55956 L
.95612 .55848 L
.95703 .55807 L
.958 .55764 L
.9585 .55742 L
.95879 .55728 L
.95906 .55685 L
Mistroke
.96004 .55528 L
.96092 .55387 L
.96176 .55253 L
.96222 .55179 L
.96248 .55138 L
.96272 .54995 L
.96361 .5441 L
.96524 .53333 L
.96569 .53037 L
.96616 .52725 L
.96656 .51986 L
.967 .51016 L
.96855 .47634 L
.9694 .45771 L
.96982 .44855 L
.97021 .4332 L
.97098 .3919 L
.97182 .34695 L
.97252 .30956 L
.9733 .26827 L
.97402 .21765 L
.9747 .15413 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;oooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00006oooool0033ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001[ooooo000Yooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001[ooooo000booooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool06?ooool002oooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Joooo
o`00;oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Jooooo`00<?ooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Kooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`007_oooooho`0000[ooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`08ooooo`007_oo
ool2o`0007Wooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`002_ooool3o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002oooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool000_ooooo00?o0000ooooooooool01oooool4o`0000Gooooon?l0000:ooooo`002oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`002_ooool2o`0000[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Wooooo
0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo0_l0
0004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo000:ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool000_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool000[ooooo0_l00009ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oo
oooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo000:ooooo`?o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`002oooool00ol0003oooooooooo`08ooooo`?o00001Oooool2o`0000Gooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo0_l0000:oooo
o`002oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000:ooooo`;o00002Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`002oooool00ol0003oooooooooo`08ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo
0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`03ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o
00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002_ooool3o`0000Cooooo
00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`002oooool00ol0003oooooooooo`08ooooo`Co00001?ooool2o`0000Gooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo0_l0000:oooo
o`002oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000:ooooo`;o00002Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`002oooool00ol0003oooooooooo`08ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo
0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`03ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o
00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`005Oooool5o`0000Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`005_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000H
ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001Gooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
01Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool001Kooooo0ol00005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool001kooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Ko
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?o
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Kooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Kooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`Go00000oooool00ol0003o
ooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l0
000:ooooo`002Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`05o`000?oooooo
ooooooooool000002?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`002_ooool3o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001_ooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool01?ooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1`ooooo`;o
00001oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Kooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`00
00Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
00Gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oo
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool02?ooool5o`0006_ooooo00?o0000ooooooooool0K?ooool3o`0000[ooooo00?o
0000ooooooooool02?ooool001kooooo0_l0000>ooooo`Co0000Ioooool00ol0003oooooooooo`1W
ooooo`Go00003?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo017ooooo1?l0001Soooo
o`03o`000?oooooooooo06?ooooo1?l0000Booooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo01Gooooo1ol0001Looooo`03o`000?oooooooooo05cooooo1ol0000Fooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo01cooooo1?l0001Hooooo`03o`00
0?oooooooooo05Sooooo1?l0000Mooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00008Ooo
ool8o`00053ooooo00?o0000ooooooooool0D?ooool8o`00023ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`0Xooooo`Oo0000BOooool00ol0003oooooooooo`19ooooo`Oo0000:Oooool0
0ol0003oooooooooo`08ooooo`002Oooool5o`0000?ooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo02oooooo2?l00011ooooo`03o`000?oooooooooo03kooooo2ol0000`
ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0gooooo`_o0000=_ooool00ol0003ooooooooo
o`0fooooo`So0000>oooool00ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@_ooool?o`0002Oooooo00?o0000
ooooooooool09oooool?o`0004?ooooo00?o0000ooooooooool02?ooool000cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`03ooooo`;o0000D_oooolFo`00017ooooo00?o0000oooo
ooooool04OoooolFo`00057ooooo0_l0000:ooooo`002Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06Oooooo9Ol0001X
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00Sooooo000:ooooo`?o00002Oooool3o`0000Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool001kooooon?l0000:ooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00c?ooool3o`00057ooooo003=ooooo`03o`000?oooooooooo053ooooo001Qooooo`03
o`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`?o
00000oooool3o`0000Cooooo0ol00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000So
oooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000?ooooo0ol00002oooo
o`?o000000?oooooo`000?l000001?l00002ooooo`Go00000oooool2o`0000Cooooo00?o0000oooo
ooooool0Coooool0067ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04o`000?ooooooooooo`0000Gooooo
00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0Coooool0067ooooo00?o0000ooooool000000oooool3o`0000?ooooo00?o0000ooooool0
00000_ooool5o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001@ooooo`00H?oo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo0ol00003ooooo`;o00000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0
003oooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo0000053ooooo001Pooooo`05o`000?oooooo0000ooooool000000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000;ooooo1?l00002ooooo`Co00002_ooool01?l0003ooooo
ooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000?ooooo1?l000001?oooooo
0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o000004oooooo001Pooooo`05
o`000?oooooo0000ooooool000005?ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo05Kooooo001Pooooo`Ko00004_ooool5o`0001Cooooo00?o0000ooooooooool02?ooool5o`00
00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.6639, 1.47185, 0.192645, \
0.00454675}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0210016 0.0147151 0.00636643 [
[.07997 -0.0125 -9 -9 ]
[.07997 -0.0125 9 0 ]
[.28998 -0.0125 -9 -9 ]
[.28998 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.71002 -0.0125 -6 -9 ]
[.71002 -0.0125 6 0 ]
[.92003 -0.0125 -6 -9 ]
[.92003 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14204 -12 -4.5 ]
[-0.0125 .14204 0 4.5 ]
[-0.0125 .26937 -12 -4.5 ]
[-0.0125 .26937 0 4.5 ]
[-0.0125 .3967 -12 -4.5 ]
[-0.0125 .3967 0 4.5 ]
[-0.0125 .52403 -12 -4.5 ]
[-0.0125 .52403 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07997 0 m
.07997 .00625 L
s
[(-20)] .07997 -0.0125 0 1 Mshowa
.28998 0 m
.28998 .00625 L
s
[(-10)] .28998 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.71002 0 m
.71002 .00625 L
s
[(10)] .71002 -0.0125 0 1 Mshowa
.92003 0 m
.92003 .00625 L
s
[(20)] .92003 -0.0125 0 1 Mshowa
.125 Mabswid
.12197 0 m
.12197 .00375 L
s
.16397 0 m
.16397 .00375 L
s
.20598 0 m
.20598 .00375 L
s
.24798 0 m
.24798 .00375 L
s
.33199 0 m
.33199 .00375 L
s
.37399 0 m
.37399 .00375 L
s
.41599 0 m
.41599 .00375 L
s
.458 0 m
.458 .00375 L
s
.542 0 m
.542 .00375 L
s
.58401 0 m
.58401 .00375 L
s
.62601 0 m
.62601 .00375 L
s
.66801 0 m
.66801 .00375 L
s
.75202 0 m
.75202 .00375 L
s
.79402 0 m
.79402 .00375 L
s
.83603 0 m
.83603 .00375 L
s
.87803 0 m
.87803 .00375 L
s
.03797 0 m
.03797 .00375 L
s
.96203 0 m
.96203 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14204 m
.00625 .14204 L
s
[(20)] -0.0125 .14204 1 0 Mshowa
0 .26937 m
.00625 .26937 L
s
[(40)] -0.0125 .26937 1 0 Mshowa
0 .3967 m
.00625 .3967 L
s
[(60)] -0.0125 .3967 1 0 Mshowa
0 .52403 m
.00625 .52403 L
s
[(80)] -0.0125 .52403 1 0 Mshowa
.125 Mabswid
0 .04655 m
.00375 .04655 L
s
0 .07838 m
.00375 .07838 L
s
0 .11021 m
.00375 .11021 L
s
0 .17388 m
.00375 .17388 L
s
0 .20571 m
.00375 .20571 L
s
0 .23754 m
.00375 .23754 L
s
0 .3012 m
.00375 .3012 L
s
0 .33304 m
.00375 .33304 L
s
0 .36487 m
.00375 .36487 L
s
0 .42853 m
.00375 .42853 L
s
0 .46037 m
.00375 .46037 L
s
0 .4922 m
.00375 .4922 L
s
0 .55586 m
.00375 .55586 L
s
0 .58769 m
.00375 .58769 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07997 .61178 m
.07997 .61803 L
s
.28998 .61178 m
.28998 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.71002 .61178 m
.71002 .61803 L
s
.92003 .61178 m
.92003 .61803 L
s
.125 Mabswid
.12197 .61428 m
.12197 .61803 L
s
.16397 .61428 m
.16397 .61803 L
s
.20598 .61428 m
.20598 .61803 L
s
.24798 .61428 m
.24798 .61803 L
s
.33199 .61428 m
.33199 .61803 L
s
.37399 .61428 m
.37399 .61803 L
s
.41599 .61428 m
.41599 .61803 L
s
.458 .61428 m
.458 .61803 L
s
.542 .61428 m
.542 .61803 L
s
.58401 .61428 m
.58401 .61803 L
s
.62601 .61428 m
.62601 .61803 L
s
.66801 .61428 m
.66801 .61803 L
s
.75202 .61428 m
.75202 .61803 L
s
.79402 .61428 m
.79402 .61803 L
s
.83603 .61428 m
.83603 .61803 L
s
.87803 .61428 m
.87803 .61803 L
s
.03797 .61428 m
.03797 .61803 L
s
.96203 .61428 m
.96203 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14204 m
1 .14204 L
s
.99375 .26937 m
1 .26937 L
s
.99375 .3967 m
1 .3967 L
s
.99375 .52403 m
1 .52403 L
s
.125 Mabswid
.99625 .04655 m
1 .04655 L
s
.99625 .07838 m
1 .07838 L
s
.99625 .11021 m
1 .11021 L
s
.99625 .17388 m
1 .17388 L
s
.99625 .20571 m
1 .20571 L
s
.99625 .23754 m
1 .23754 L
s
.99625 .3012 m
1 .3012 L
s
.99625 .33304 m
1 .33304 L
s
.99625 .36487 m
1 .36487 L
s
.99625 .42853 m
1 .42853 L
s
.99625 .46037 m
1 .46037 L
s
.99625 .4922 m
1 .4922 L
s
.99625 .55586 m
1 .55586 L
s
.99625 .58769 m
1 .58769 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .55624 Mdot
.03144 .56935 Mdot
.03906 .58013 Mdot
.04668 .5887 Mdot
.05429 .59519 Mdot
.06189 .59971 Mdot
.06948 .60239 Mdot
.07707 .60332 Mdot
.08465 .60262 Mdot
.09223 .60038 Mdot
.0998 .59672 Mdot
.10736 .59171 Mdot
.11492 .58547 Mdot
.12248 .57806 Mdot
.13002 .56959 Mdot
.13757 .56013 Mdot
.14511 .54977 Mdot
.15264 .53857 Mdot
.16017 .52662 Mdot
.1677 .51399 Mdot
.17522 .50075 Mdot
.18274 .48696 Mdot
.19025 .47268 Mdot
.19776 .45799 Mdot
.20527 .44294 Mdot
.21277 .42759 Mdot
.22027 .412 Mdot
.22776 .39621 Mdot
.23526 .38028 Mdot
.24275 .36426 Mdot
.25023 .34821 Mdot
.25772 .33215 Mdot
.2652 .31615 Mdot
.27268 .30024 Mdot
.28015 .28446 Mdot
.28763 .26885 Mdot
.2951 .25345 Mdot
.30257 .23829 Mdot
.31004 .22342 Mdot
.3175 .20886 Mdot
.32496 .19465 Mdot
.33243 .1808 Mdot
.33989 .16737 Mdot
.34734 .15436 Mdot
.3548 .14181 Mdot
.36225 .12973 Mdot
.36971 .11817 Mdot
.37716 .10712 Mdot
.38461 .09663 Mdot
.39206 .0867 Mdot
.39951 .07735 Mdot
.40696 .0686 Mdot
.4144 .06046 Mdot
.42185 .05295 Mdot
.4293 .04609 Mdot
.43674 .03988 Mdot
.44418 .03433 Mdot
.45163 .02945 Mdot
.45907 .02526 Mdot
.46651 .02175 Mdot
.47395 .01894 Mdot
.4814 .01683 Mdot
.48884 .01542 Mdot
.49628 .01472 Mdot
.50372 .01472 Mdot
.51116 .01542 Mdot
.5186 .01683 Mdot
.52605 .01894 Mdot
.53349 .02175 Mdot
.54093 .02526 Mdot
.54837 .02945 Mdot
.55582 .03433 Mdot
.56326 .03988 Mdot
.5707 .04609 Mdot
.57815 .05295 Mdot
.5856 .06046 Mdot
.59304 .0686 Mdot
.60049 .07735 Mdot
.60794 .0867 Mdot
.61539 .09663 Mdot
.62284 .10712 Mdot
.63029 .11817 Mdot
.63775 .12973 Mdot
.6452 .14181 Mdot
.65266 .15436 Mdot
.66011 .16737 Mdot
.66757 .1808 Mdot
.67504 .19465 Mdot
.6825 .20886 Mdot
.68996 .22342 Mdot
.69743 .23829 Mdot
.7049 .25345 Mdot
.71237 .26885 Mdot
.71985 .28446 Mdot
.72732 .30024 Mdot
.7348 .31615 Mdot
.74228 .33215 Mdot
.74977 .34821 Mdot
.75725 .36426 Mdot
.76474 .38028 Mdot
.77224 .39621 Mdot
.77973 .412 Mdot
.78723 .42759 Mdot
.79473 .44294 Mdot
.80224 .45799 Mdot
.80975 .47268 Mdot
.81726 .48696 Mdot
.82478 .50075 Mdot
.8323 .51399 Mdot
.83983 .52662 Mdot
.84736 .53857 Mdot
.85489 .54977 Mdot
.86243 .56013 Mdot
.86998 .56959 Mdot
.87752 .57806 Mdot
.88508 .58547 Mdot
.89264 .59171 Mdot
.9002 .59672 Mdot
.90777 .60038 Mdot
.91535 .60262 Mdot
.92293 .60332 Mdot
.93052 .60239 Mdot
.93811 .59971 Mdot
.94571 .59519 Mdot
.95332 .5887 Mdot
.96094 .58013 Mdot
.96856 .56935 Mdot
.97619 .55624 Mdot
.5 Mabswid
.02381 .55624 m
.03097 .56855 L
.03853 .57937 L
.04619 .58815 L
.05058 .59203 L
.05458 .59537 L
.05815 .59749 L
.06004 .59861 L
.06107 .59923 L
.06157 .59953 L
.06204 .59977 L
.06252 .59994 L
.06305 .60012 L
.06417 .60052 L
.06614 .60121 L
.06801 .60187 L
.06851 .60204 L
.06904 .60223 L
.06929 .60232 L
.06955 .60239 L
.07001 .60245 L
.07198 .60269 L
.07376 .60291 L
.07544 .60312 L
.07589 .60317 L
.07637 .60323 L
.07682 .60329 L
.07724 .6033 L
.07774 .60326 L
.07826 .60321 L
.07919 .60312 L
.08101 .60295 L
.08206 .60286 L
.08316 .60275 L
.08411 .60267 L
.08436 .60264 L
.08464 .60262 L
.08514 .60247 L
.08871 .60142 L
.09069 .60084 L
.09166 .60055 L
.09256 .60022 L
.09431 .59938 L
.0962 .59846 L
.09952 .59685 L
.10667 .59217 L
.11453 .58579 L
.1299 .56974 L
.14469 .55035 L
.16041 .52622 L
Mistroke
.17556 .50013 L
.19013 .47292 L
.20563 .44219 L
.22056 .41138 L
.23642 .3778 L
.2517 .34506 L
.26641 .31357 L
.28205 .2805 L
.29711 .24936 L
.3116 .22038 L
.32702 .19084 L
.34186 .16392 L
.35764 .13721 L
.37283 .11353 L
.38746 .09283 L
.40301 .07323 L
.41799 .05684 L
.43239 .0435 L
.44773 .03201 L
.46248 .02365 L
.47013 .02039 L
.47403 .01892 L
.47818 .01774 L
.48213 .01669 L
.48571 .01601 L
.48747 .01568 L
.48833 .01552 L
.48871 .01545 L
.48912 .01539 L
.48954 .01535 L
.48994 .01532 L
.49083 .01523 L
.49271 .01505 L
.49469 .01487 L
.49556 .01478 L
.49603 .01474 L
.49653 .01472 L
.49698 .01472 L
.4974 .01472 L
.49823 .01472 L
.50004 .01472 L
.50188 .01472 L
.50239 .01472 L
.50293 .01472 L
.50319 .01472 L
.50343 .01472 L
.5039 .01473 L
.50439 .01478 L
.50491 .01483 L
.50585 .01492 L
Mistroke
.50797 .01512 L
.50981 .01529 L
.51025 .01533 L
.51071 .01538 L
.51115 .01542 L
.51155 .0155 L
.51252 .01568 L
.51357 .01588 L
.51541 .01623 L
.52239 .0179 L
.52972 .02033 L
.53766 .02372 L
.55329 .03267 L
.56834 .04411 L
.58281 .05765 L
.59822 .07467 L
.61305 .0935 L
.62881 .11597 L
.644 .13986 L
.65861 .16473 L
.67415 .193 L
.68912 .22177 L
.70351 .25062 L
.71883 .28233 L
.73357 .31354 L
.74925 .34711 L
.76436 .37945 L
.77888 .41021 L
.79434 .44214 L
.80922 .47165 L
.82504 .5012 L
.84028 .52734 L
.85494 .54983 L
.87053 .57022 L
.88555 .58586 L
.8931 .59202 L
.89999 .59658 L
.90354 .59834 L
.90542 .59924 L
.90741 .60021 L
.90852 .6006 L
.90953 .6009 L
.91149 .60148 L
.91338 .60204 L
.91441 .60234 L
.91491 .60249 L
.91537 .60262 L
.91582 .60266 L
.91625 .6027 L
.9172 .60279 L
Mistroke
.9192 .60297 L
.92091 .60313 L
.92185 .60322 L
.9223 .60326 L
.92272 .6033 L
.92317 .60329 L
.92366 .60323 L
.9247 .6031 L
.92653 .60288 L
.92853 .60263 L
.92963 .6025 L
.92989 .60246 L
.93016 .60243 L
.93066 .60234 L
.93111 .60218 L
.9316 .602 L
.93263 .60165 L
.93441 .60102 L
.93623 .60038 L
.93702 .6001 L
.93789 .59979 L
.93841 .59953 L
.9389 .59925 L
.93986 .59868 L
.94197 .59742 L
.9438 .59633 L
.94578 .59513 L
.94945 .59201 L
.95289 .58907 L
.96074 .58036 L
.97619 .55624 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;?ooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00007_ooool002gooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001gooooo000Vooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001gooooo000_ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool06oooool002cooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Moooo
o`00;?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Mooooo`00;Oooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Nooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`006ooooooho`0000gooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`00
4oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004ooooo`;o
0000M?ooool;o`0007Gooooo0_l0000=ooooo`004oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo077ooooo3ol0001dooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0Koooool4o`0000Gooooo00?o0000oooooooo
ool00oooool4o`0007;ooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`1^ooooo`Co00001_ooool00ol0003oooooooooo`05ooooo`Co
0000L?ooool00ol0003oooooooooo`0;ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0
K?ooool4o`0000Sooooo00?o0000ooooooooool01oooool4o`0006kooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool0J_ooool4o`0000[ooooo00?o0000ooooooooool02Ooo
ool4o`0006cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0J?ooool4
o`0000cooooo00?o0000ooooooooool02oooool3o`0006_ooooo00?o0000ooooooooool02oooool0
01_ooooo00?o0000ooooooooool0J?ooool2o`0000kooooo00?o0000ooooooooool03?ooool2o`00
06_ooooo00?o0000ooooooooool02oooool001_ooooo0_l0001Wooooo`;o00004?ooool00ol0003o
ooooooooo`0>ooooo`;o0000J?ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo06Cooooo
1?l0000@ooooo`03o`000?oooooooooo00kooooo1?l0001Wooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo06Cooooo0_l0000Booooo`03o`000?oooooooooo013ooooo0_l0
001Wooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo06?ooooo0_l0000C
ooooo`03o`000?oooooooooo01;ooooo0_l0001Uooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo06?ooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo0_l0001Uoooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo067ooooo0ol0000Dooooo`03
o`000?oooooooooo01Cooooo0_l0001Sooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo067ooooo0_l0000Eooooo`03o`000?oooooooooo01Cooooo0_l0001Sooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05oooooo0ol0000Fooooo`03o`000?oo
oooooooo01Kooooo0_l0001Qooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o0000H?ooool3
o`0001Kooooo00?o0000ooooooooool05_ooool2o`00063ooooo0_l0000=ooooo`006oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05go
oooo0ol0000Hooooo`03o`000?oooooooooo01Oooooo0_l0001Pooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo05gooooo0_l0000Iooooo`03o`000?oooooooooo01Oooooo
0_l0001Pooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05_ooooo0ol0
000Jooooo`03o`000?oooooooooo01Wooooo0_l0001Nooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo05_ooooo0ol0000Jooooo`03o`000?oooooooooo01Wooooo0_l0001N
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05cooooo00?o0000oooo
ooooool02oooool001_ooooo00?o0000ooooooooool0FOooool3o`0001cooooo00?o0000oooooooo
ool06oooool2o`0005cooooo00?o0000ooooooooool02oooool001_ooooo0_l0001Jooooo`;o0000
7Oooool00ol0003oooooooooo`0Kooooo`;o0000Foooool2o`0000gooooo000Kooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0F?ooool2
o`0001kooooo00?o0000ooooooooool07Oooool2o`0005[ooooo00?o0000ooooooooool02oooool0
01_ooooo00?o0000ooooooooool0F?ooool2o`0001kooooo00?o0000ooooooooool07Oooool2o`00
05[ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0E_ooool2o`00023o
oooo00?o0000ooooooooool07oooool2o`0005Sooooo00?o0000ooooooooool02oooool000cooooo
1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`1Fooooo`;o00008?ooool00ol0003ooooo
ooooo`0Oooooo`;o0000F?ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`0;ooooo`003_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0E?ooool2o`0002;ooooo00?o0000ooooooooool08Oooool2o`0005Ko
oooo00?o0000ooooooooool02oooool000oooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00;ooooo0_l0001Eooooo`;o00008_ooool00ol0003oooooooooo`0Qooooo`;o
0000EOooool2o`0000gooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02oooool000co
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0D_ooool2o`0002Cooooo00?o0000ooooooooool08oooool2o`0005Cooooo00?o0000
ooooooooool02oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`1Boooo
o`;o00009?ooool00ol0003oooooooooo`0Sooooo`;o0000E?ooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0D?oo
ool2o`0002Kooooo00?o0000ooooooooool09?ooool2o`0005?ooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0D?ooool2o`0002Kooooo00?o0000ooooooooool09?ooool3
o`0005;ooooo00?o0000ooooooooool02oooool001_ooooo0_l0001Aooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1?ooooo`;o00003Oooool001_o
oooo00?o0000ooooooooool0C_ooool2o`0002Sooooo00?o0000ooooooooool09_ooool2o`00057o
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0C_ooool2o`0002Sooooo
00?o0000ooooooooool09_ooool3o`00053ooooo00?o0000ooooooooool02oooool001_ooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1=
ooooo`;o0000:Oooool00ol0003oooooooooo`0Xooooo`;o0000Coooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`1=ooooo`;o0000:Oooool00ol0003oooooooooo`0Xoooo
o`;o0000Coooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo00_ooooo000Kooooo`;o0000C_ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0Boooool2o`0000gooooo000Kooooo`03o`000?oo
oooooooo04_ooooo0_l0000[ooooo`03o`000?oooooooooo02[ooooo0_l0001=ooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`03o`000?oooooooooo04_ooooo0_l0000[ooooo`03o`000?oooooo
oooo02[ooooo0_l0001=ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`19ooooo`;o0000;Oooool00ol0003ooooo
ooooo`0/ooooo`;o0000Boooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`19ooooo`;o0000;Oooool00ol0003oooooooooo`0/ooooo`;o0000Boooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`;o0000B?ooool2o`0002oooooo00?o0000ooooooooool0;_ooool2o`0004Sooooo0_l0000=oooo
o`006oooool00ol0003oooooooooo`17ooooo`;o0000;oooool00ol0003oooooooooo`0^ooooo`;o
0000BOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0AOooool2o`00037ooooo00?o0000ooooooooool0;oooool2
o`0004Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0AOooool2o`00
037ooooo00?o0000ooooooooool0;oooool2o`0004Sooooo00?o0000ooooooooool02oooool000ko
oooo0ol00003ooooo`;o00001Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00_o
oooo000?ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool02oooool000cooooo1Ol00002ooooo`04o`00
0?ooooooooooo`0000Cooooo0_l00014ooooo`;o0000<oooool00ol0003oooooooooo`0aooooo`;o
0000AOooool2o`0000gooooo000<ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`13ooooo`;o0000<oooool00ol0003oooooooooo`0aoooo
o`?o0000AOooool00ol0003oooooooooo`0;ooooo`003Oooool00ol0003oooooo`000003ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0;oooo
o`003_ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo00_ooooo000?ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03
o`000?oooooooooo047ooooo0ol0000dooooo`03o`000?oooooooooo03?ooooo0_l00014ooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo047ooooo0_l0000eooooo`03o`00
0?oooooooooo03?ooooo0ol00013ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0;ooooo`006oooool2o`00047ooooo0_l0000fooooo`03o`000?oooooooooo
03Gooooo0_l00011ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0@?ooool2o`0003Ko
oooo00?o0000ooooooooool0=Oooool2o`0004;ooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`0nooooo`;o0000>?ooool00ol0003oooooooooo`0gooooo`;o0000@?ooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`0nooooo`;o0000>?ooool00ol0003oooooooooo`0g
ooooo`;o0000@?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0??ooool2o`0003[ooooo00?o0000ooooooooool0
>Oooool2o`0003kooooo00?o0000ooooooooool02oooool001_ooooo0_l0000mooooo`;o0000>_oo
ool00ol0003oooooooooo`0iooooo`;o0000?Oooool2o`0000gooooo000Kooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0jooooo`;o0000??ooool00ol0003o
ooooooooo`0kooooo`;o0000??ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooo
ooooo`0jooooo`;o0000??ooool00ol0003oooooooooo`0kooooo`;o0000??ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool0>?ooool2o`0003kooooo00?o0000ooooooooool0??ooool2o`0003_ooooo00?o0000oooo
ooooool02oooool001_ooooo0_l0000iooooo`;o0000?_ooool00ol0003oooooooooo`0looooo`;o
0000>_ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`0fooooo`;o0000@?ooool00ol0003oooooooooo`0nooooo`;o0000>Oooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0fooooo`;o0000@?ooool00ol0
003oooooooooo`0nooooo`;o0000>Oooool00ol0003oooooooooo`0;ooooo`003Oooool3o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02oooool000cooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0;ooooo`003?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0eooooo`;o0000@Oooool0
0ol0003oooooooooo`10ooooo`;o0000=oooool00ol0003oooooooooo`0;ooooo`003?ooool4o`00
00?ooooo00Co0000oooooooooooo00001?ooool2o`0003Kooooo0_l00011ooooo`03o`000?oooooo
oooo043ooooo0_l0000fooooo`;o00003Oooool000cooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02oooool0
00gooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`;o00001Oooool00ol0
003oooooooooo`0cooooo`;o0000@oooool00ol0003oooooooooo`12ooooo`;o0000=Oooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0cooooo`;o0000@oooool00ol0003o
ooooooooo`12ooooo`;o0000=Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0<Oooool2o`0004Gooooo00?o0000
ooooooooool0A?ooool2o`0003?ooooo00?o0000ooooooooool02oooool001_ooooo0_l0000boooo
o`;o0000AOooool00ol0003oooooooooo`14ooooo`;o0000<_ooool2o`0000gooooo000Kooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0_ooooo`;o0000Aooo
ool00ol0003oooooooooo`16ooooo`;o0000<Oooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`0_ooooo`;o0000Aoooool00ol0003oooooooooo`16ooooo`;o0000<Oooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02oooool001_ooooo
0_l0000^ooooo`;o0000BOooool00ol0003oooooooooo`18ooooo`;o0000;_ooool2o`0000gooooo
000Kooooo`03o`000?oooooooooo02gooooo0_l00019ooooo`03o`000?oooooooooo04Sooooo0_l0
000_ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool02oooool001_ooooo00?o0000ooooooooool0:oooool3o`0004[ooooo00?o0000oooo
ooooool0BOooool2o`0002kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool0:oooool2o`0004_ooooo00?o0000ooooooooool0BOooool2o`0002kooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo02Wooooo0_l0001=ooooo`03o`000?oooooooooo04_ooooo0_l0000/ooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`;o0000:_ooool2o`0004gooooo00?o0000ooooooooool0Boooool2o`00
02_ooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo02Sooooo0_l0001>ooooo`03o`000?oooooooooo04gooooo
0_l0000Zooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo02Sooooo0_l0
001>ooooo`03o`000?oooooooooo04gooooo0_l0000Zooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool09_ooool2o`00053ooooo00?o0000ooooooooool0Coooool2o`0002Sooooo00?o0000oooo
ooooool02oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0Vooooo`;o
0000D?ooool00ol0003oooooooooo`1?ooooo`;o0000:?ooool00ol0003oooooooooo`0;ooooo`00
3?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo000<ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00004ooooo`;o00009oooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool09?ooool2o`0000gooooo000=oooo
o`?o00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Cooooo0_l0001B
ooooo`03o`000?oooooooooo057ooooo0_l0000Vooooo`03o`000?oooooooooo00_ooooo000<oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo02Cooooo0_l0001Booooo`03o`000?oooooooooo057ooooo0_l0000Vooooo`03o`000?oo
oooooooo00_ooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo02;ooooo0ol0001Cooooo`03o`000?oooooooooo05?ooooo
0_l0000Tooooo`03o`000?oooooooooo00_ooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o
0000ooooooooool08_ooool2o`0005Cooooo00?o0000ooooooooool0Doooool2o`0002Cooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`0Pooooo`?o0000EOooool00ol0003oooooooooo`1Doooo
o`?o00008_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Pooooo`;o
0000E_ooool00ol0003oooooooooo`1Eooooo`;o00008_ooool00ol0003oooooooooo`0;ooooo`00
6oooool2o`0000?ooooo0_l0000Looooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
EOooool00ol0003oooooooooo`0Jooooo`;o00001?ooool2o`0000gooooo000Kooooo`03o`000?oo
oooooooo00;ooooo0_l0000Jooooo`;o0000F?ooool00ol0003oooooooooo`1Fooooo`;o00006_oo
ool2o`0000Gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Gooooo`;o0000F?ooool00ol0003oooooooooo`1Fooooo`;o00006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
00Cooooo0_l0000Fooooo`;o0000F_ooool00ol0003oooooooooo`1Hooooo`;o00005oooool2o`00
00Kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool01?ooool2o`0001Ko
oooo0_l0001Jooooo`03o`000?oooooooooo05Sooooo0ol0000Fooooo`;o00001_ooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo
0_l0001Looooo`03o`000?oooooooooo05[ooooo0_l0000Dooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool01_ooool2o`0001;ooooo0_l0
001Looooo`03o`000?oooooooooo05[ooooo0ol0000Booooo`;o00002?ooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`06ooooo`;o00004Oooool2o`0005gooooo00?o0000
ooooooooool0G?ooool2o`00013ooooo0ol00008ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`;o00002Oooool2o`0000kooooo0ol0001Mooooo`03o`000?oooooooooo05cooooo0ol0000>oooo
o`;o00002Oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo00Sooooo1?l0000:ooooo`?o
0000Goooool00ol0003oooooooooo`1Nooooo`;o00002oooool4o`0000[ooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool02_ooool2o`0000Wooooo1?l0001Oooooo`03o`00
0?oooooooooo05kooooo1?l00009ooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`0<ooooo`_o0000HOooool00ol0003oooooooooo`1Pooooo`_o00003_oo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0<ooooo`Wo0000Hoooool0
0ol0003oooooooooo`1Rooooo`Wo00003_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02oooool001_ooooon?l0000=ooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00;Oooool3o`0008[ooooo00?o0000ooooooooool0:oooool3o`0001Go
oooo00?o0000ooooooooool07Oooool002kooooo00?o0000ooooooooool0R?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07?ooool002Sooooo0ol0
0003ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000oooool4o`000003ooooool0
003o000000?o00001oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6o`0000Kooooo1?l0
0002ooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`0000;ooooo0ol0
0002ooooo`?o00001?ooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`0000?ooooo
0ol00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool4o`0000?ooooo
00?o0000ooooooooool00_ooool3o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000004oooo
ool0003o0000ooooo`Co00000oooool2o`0000;ooooo2_l00005ooooo`03o`000?oooooooooo01_o
oooo000Wooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooool000003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;o
oooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo000Wooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooooooool5o`0000;ooooo00?o0000ooooooooool00_ooool5
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`Go00002?ooool00ol0003ooooo
ooooo`02ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000?ooooo00?o0000ooooool0
00000_ooool5o`0000?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000;o
oooo0ol00005ooooo`03o`000?oooooooooo01_ooooo000Wooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`08ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001Oooool01_l0003oooooooooool0
003oooooo`0000Sooooo00?o0000ooooooooool06oooool002Oooooo00Ko0000oooooooooooooooo
o`000?ooool4o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000?ooooo0_l00005ooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003oooo
o`?o00002Oooool01Ol0003oooooooooool0003ooooo00?o00001?ooool4o`0000;ooooo1?l00002
ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`Co00000oooool3
o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo1_l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000;ooooo1?l00003ooooo`Wo00000oooool3o`0000?ooooo1?l00004ooooo`03o`000?oooooo
oooo01_ooooo000Wooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Looooo`00:?ooool3o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0=ooooo`?o00002Oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`0000[ooooo1?l0
0004ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o0000;_ooool00ol0003ooooooooo
o`0Hooooo`?o00005_ooool00ol0003oooooooooo`02ooooo`;o00002oooool00ol0003ooooooooo
o`0Mooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.0859, -9.99476, \
0.192645, 0.635497}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 1.15867 0.0147151 0.588604 [
[.03653 .00222 -12 -9 ]
[.03653 .00222 12 0 ]
[.26827 .00222 -12 -9 ]
[.26827 .00222 12 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.73173 .00222 -9 -9 ]
[.73173 .00222 9 0 ]
[.96347 .00222 -9 -9 ]
[.96347 .00222 9 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03653 .01472 m
.03653 .02097 L
s
[(-0.4)] .03653 .00222 0 1 Mshowa
.26827 .01472 m
.26827 .02097 L
s
[(-0.2)] .26827 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0)] .5 .00222 0 1 Mshowa
.73173 .01472 m
.73173 .02097 L
s
[(0.2)] .73173 .00222 0 1 Mshowa
.96347 .01472 m
.96347 .02097 L
s
[(0.4)] .96347 .00222 0 1 Mshowa
.125 Mabswid
.09447 .01472 m
.09447 .01847 L
s
.1524 .01472 m
.1524 .01847 L
s
.21033 .01472 m
.21033 .01847 L
s
.3262 .01472 m
.3262 .01847 L
s
.38413 .01472 m
.38413 .01847 L
s
.44207 .01472 m
.44207 .01847 L
s
.55793 .01472 m
.55793 .01847 L
s
.61587 .01472 m
.61587 .01847 L
s
.6738 .01472 m
.6738 .01847 L
s
.78967 .01472 m
.78967 .01847 L
s
.8476 .01472 m
.8476 .01847 L
s
.90553 .01472 m
.90553 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .02322 m
.02453 .0179 L
.02525 .0238 L
.02596 .02491 L
.02668 .02061 L
.0274 .03298 L
.02812 .0288 L
.02884 .03344 L
.02956 .04924 L
.03027 .0388 L
.03099 .06068 L
.03171 .06711 L
.03243 .06435 L
.03315 .10364 L
.03386 .09594 L
.03458 .12069 L
.0353 .1588 L
.03602 .14246 L
.03674 .1984 L
.03746 .2066 L
.03817 .21087 L
.03889 .28411 L
.03961 .26831 L
.04033 .32709 L
.04105 .38633 L
.04177 .37044 L
.04248 .47388 L
.0432 .47368 L
.04392 .48849 L
.04464 .57635 L
.04536 .51917 L
.04607 .58156 L
.04679 .59684 L
.04751 .53339 L
.04823 .60329 L
.04895 .52257 L
.04967 .49179 L
.05038 .50581 L
.0511 .38554 L
.05182 .39279 L
.05254 .33312 L
.05326 .23803 L
.05398 .23708 L
.05469 .14061 L
.05541 .09621 L
.05613 .07329 L
.05685 .02413 L
.05757 .0183 L
.05828 .01949 L
.059 .03866 L
Mistroke
.05972 .0458 L
.06044 .11239 L
.06116 .1484 L
.06188 .17939 L
.06259 .2857 L
.06331 .27355 L
.06403 .33682 L
.06475 .38107 L
.06547 .31925 L
.06619 .3754 L
.0669 .31382 L
.06762 .25598 L
.06834 .25883 L
.06906 .15193 L
.06978 .12045 L
.07049 .08032 L
.07121 .02633 L
.07193 .0197 L
.07265 .02256 L
.07337 .042 L
.07409 .05907 L
.0748 .13861 L
.07552 .16048 L
.07624 .2139 L
.07696 .29709 L
.07768 .26437 L
.0784 .32331 L
.07911 .29814 L
.07983 .22867 L
.08055 .23319 L
.08127 .13473 L
.08199 .09057 L
.0827 .05945 L
.08342 .01744 L
.08414 .01478 L
.08486 .03764 L
.08558 .08131 L
.0863 .09881 L
.08701 .19869 L
.08773 .21299 L
.08845 .23046 L
.08917 .29904 L
.08989 .2179 L
.09061 .22882 L
.09132 .1939 L
.09204 .09719 L
.09276 .09087 L
.09348 .03459 L
.0942 .0148 L
.09491 .01927 L
Mistroke
.09563 .07474 L
.09635 .09377 L
.09707 .14781 L
.09779 .24495 L
.09851 .19941 L
.09922 .26953 L
.09994 .25115 L
.10066 .15754 L
.10138 .17359 L
.1021 .07413 L
.10282 .03414 L
.10353 .02299 L
.10425 .03478 L
.10497 .04406 L
.10569 .10105 L
.10641 .19082 L
.10712 .15394 L
.10784 .25562 L
.10856 .2362 L
.10928 .15955 L
.11 .20043 L
.11072 .08573 L
.11143 .04668 L
.11215 .0349 L
.11287 .03045 L
.11359 .03273 L
.11431 .09339 L
.11503 .1847 L
.11574 .13758 L
.11646 .25293 L
.11718 .22655 L
.1179 .14033 L
.11862 .18646 L
.11933 .06579 L
.12005 .0342 L
.12077 .02553 L
.12149 .04838 L
.12221 .04785 L
.12293 .12025 L
.12364 .22413 L
.12436 .1435 L
.12508 .25522 L
.1258 .20443 L
.12652 .09612 L
.12724 .12708 L
.12795 .03375 L
.12867 .01679 L
.12939 .02306 L
.13011 .11708 L
.13083 .10231 L
Mistroke
.13154 .17134 L
.13226 .26557 L
.13298 .1321 L
.1337 .1918 L
.13442 .126 L
.13514 .03113 L
.13585 .03986 L
.13657 .03372 L
.13729 .05266 L
.13801 .06291 L
.13873 .21127 L
.13945 .15386 L
.14016 .18275 L
.14088 .23172 L
.1416 .07428 L
.14232 .08692 L
.14304 .04485 L
.14375 .02553 L
.14447 .02049 L
.14519 .12437 L
.14591 .16687 L
.14663 .12962 L
.14735 .27264 L
.14806 .14351 L
.14878 .10007 L
.1495 .09618 L
.15022 .01801 L
.15094 .01872 L
.15166 .05822 L
.15237 .16693 L
.15309 .09868 L
.15381 .22557 L
.15453 .2045 L
.15525 .08051 L
.15596 .13038 L
.15668 .03799 L
.1574 .01889 L
.15812 .0229 L
.15884 .14263 L
.15956 .11796 L
.16027 .15583 L
.16099 .26437 L
.16171 .08969 L
.16243 .11242 L
.16315 .07157 L
.16387 .02131 L
.16458 .01544 L
.1653 .10494 L
.16602 .16783 L
.16674 .09679 L
Mistroke
.16746 .25487 L
.16817 .14057 L
.16889 .06342 L
.16961 .08679 L
.17033 .02995 L
.17105 .03205 L
.17177 .05923 L
.17248 .21981 L
.1732 .10795 L
.17392 .18622 L
.17464 .20575 L
.17536 .03281 L
.17608 .06137 L
.17679 .04061 L
.17751 .08025 L
.17823 .0404 L
.17895 .22284 L
.17967 .20729 L
.18038 .09633 L
.1811 .19851 L
.18182 .04882 L
.18254 .02238 L
.18326 .02331 L
.18398 .14255 L
.18469 .10082 L
.18541 .14305 L
.18613 .26346 L
.18685 .06587 L
.18757 .09249 L
.18829 .06102 L
.189 .04213 L
.18972 .02191 L
.19044 .1349 L
.19116 .21136 L
.19188 .08222 L
.19259 .20906 L
.19331 .10047 L
.19403 .01877 L
.19475 .02773 L
.19547 .08915 L
.19619 .10473 L
.1969 .09079 L
.19762 .26191 L
.19834 .11015 L
.19906 .07669 L
.19978 .08287 L
.2005 .0349 L
.20121 .03142 L
.20193 .08741 L
.20265 .23535 L
Mistroke
.20337 .09627 L
.20409 .16561 L
.2048 .12529 L
.20552 .01482 L
.20624 .01886 L
.20696 .07273 L
.20768 .15267 L
.2084 .07803 L
.20911 .22101 L
.20983 .13799 L
.21055 .03603 L
.21127 .05223 L
.21199 .04739 L
.21271 .07431 L
.21342 .07436 L
.21414 .2456 L
.21486 .13013 L
.21558 .08496 L
.2163 .08952 L
.21702 .0286 L
.21773 .03209 L
.21845 .0752 L
.21917 .22083 L
.21989 .10328 L
.22061 .13102 L
.22132 .11598 L
.22204 .01743 L
.22276 .01599 L
.22348 .06698 L
.2242 .17006 L
.22492 .08286 L
.22563 .17241 L
.22635 .12986 L
.22707 .01768 L
.22779 .02278 L
.22851 .06189 L
.22923 .13153 L
.22994 .07494 L
.23066 .20414 L
.23138 .13321 L
.2321 .02726 L
.23282 .03707 L
.23353 .05751 L
.23425 .10249 L
.23497 .07506 L
.23569 .22428 L
.23641 .1319 L
.23713 .04092 L
.23784 .04826 L
.23856 .04896 L
Mistroke
.23928 .08308 L
.24 .07765 L
.24072 .22762 L
.24144 .11241 L
.24215 .04994 L
.24287 .0495 L
.24359 .05146 L
.24431 .06835 L
.24503 .08812 L
.24574 .22958 L
.24646 .0949 L
.24718 .05914 L
.2479 .05198 L
.24862 .05237 L
.24934 .05704 L
.25005 .09946 L
.25077 .23246 L
.25149 .08268 L
.25221 .0651 L
.25293 .04803 L
.25365 .0615 L
.25436 .05645 L
.25508 .1176 L
.2558 .2268 L
.25652 .06524 L
.25724 .05987 L
.25795 .04305 L
.25867 .07329 L
.25939 .05188 L
.26011 .13141 L
.26083 .20735 L
.26155 .0478 L
.26226 .0566 L
.26298 .03834 L
.2637 .08636 L
.26442 .05292 L
.26514 .15442 L
.26586 .1875 L
.26657 .03299 L
.26729 .04542 L
.26801 .03967 L
.26873 .11267 L
.26945 .06081 L
.27016 .18111 L
.27088 .16513 L
.2716 .02247 L
.27232 .03214 L
.27304 .05815 L
.27376 .14434 L
.27447 .06909 L
Mistroke
.27519 .19237 L
.27591 .13084 L
.27663 .01504 L
.27735 .0189 L
.27807 .08804 L
.27878 .17337 L
.2795 .06862 L
.28022 .16792 L
.28094 .07788 L
.28166 .02172 L
.28237 .01574 L
.28309 .13657 L
.28381 .1844 L
.28453 .05825 L
.28525 .12004 L
.28597 .04891 L
.28668 .04663 L
.2874 .029 L
.28812 .17381 L
.28884 .1796 L
.28956 .04279 L
.29028 .07161 L
.29099 .04262 L
.29171 .08956 L
.29243 .05349 L
.29315 .18646 L
.29387 .15117 L
.29458 .02124 L
.2953 .02641 L
.29602 .06111 L
.29674 .14716 L
.29746 .0692 L
.29818 .14946 L
.29889 .09774 L
.29961 .01761 L
.30033 .0159 L
.30105 .09417 L
.30177 .18621 L
.30249 .06702 L
.3032 .09411 L
.30392 .05539 L
.30464 .04828 L
.30536 .04078 L
.30608 .12531 L
.30679 .19463 L
.30751 .04537 L
.30823 .03676 L
.30895 .03171 L
.30967 .12255 L
.31039 .08484 L
Mistroke
.3111 .12481 L
.31182 .14042 L
.31254 .02237 L
.31326 .01974 L
.31398 .05659 L
.3147 .20133 L
.31541 .09801 L
.31613 .07135 L
.31685 .06223 L
.31757 .05134 L
.31829 .06534 L
.319 .08977 L
.31972 .21503 L
.32044 .06552 L
.32116 .02491 L
.32188 .02216 L
.3226 .13606 L
.32331 .12343 L
.32403 .08572 L
.32475 .14384 L
.32547 .03384 L
.32619 .0385 L
.32691 .03926 L
.32762 .20737 L
.32834 .12201 L
.32906 .03158 L
.32978 .04399 L
.3305 .07712 L
.33121 .11802 L
.33193 .05989 L
.33265 .17278 L
.33337 .07779 L
.33409 .02251 L
.33481 .01709 L
.33552 .1492 L
.33624 .17909 L
.33696 .03902 L
.33768 .07211 L
.3384 .04693 L
.33912 .1055 L
.33983 .05185 L
.34055 .15765 L
.34127 .13834 L
.34199 .01687 L
.34271 .01749 L
.34342 .0764 L
.34414 .20419 L
.34486 .06705 L
.34558 .07022 L
.3463 .0486 L
Mistroke
.34702 .07908 L
.34773 .07382 L
.34845 .09715 L
.34917 .1809 L
.34989 .04151 L
.35061 .01944 L
.35133 .0293 L
.35204 .18291 L
.35276 .13954 L
.35348 .04574 L
.3542 .05456 L
.35492 .05357 L
.35563 .11509 L
.35635 .06819 L
.35707 .15755 L
.35779 .07947 L
.35851 .02312 L
.35923 .02268 L
.35994 .1216 L
.36066 .18306 L
.36138 .03973 L
.3621 .03514 L
.36282 .03396 L
.36354 .13709 L
.36425 .08377 L
.36497 .09329 L
.36569 .09601 L
.36641 .03538 L
.36713 .0486 L
.36784 .06974 L
.36856 .20319 L
.36928 .0766 L
.37 .01707 L
.37072 .01826 L
.37144 .14281 L
.37215 .15949 L
.37287 .05218 L
.37359 .08149 L
.37431 .0446 L
.37503 .10438 L
.37575 .0568 L
.37646 .1545 L
.37718 .1109 L
.3779 .02209 L
.37862 .02094 L
.37934 .09357 L
.38005 .20012 L
.38077 .04916 L
.38149 .03159 L
.38221 .03119 L
Mistroke
.38293 .13659 L
.38365 .10126 L
.38436 .06332 L
.38508 .1012 L
.3858 .04689 L
.38652 .07195 L
.38724 .04724 L
.38796 .17924 L
.38867 .10219 L
.38939 .01838 L
.39011 .0159 L
.39083 .12299 L
.39155 .20318 L
.39226 .04055 L
.39298 .03546 L
.3937 .03799 L
.39442 .16562 L
.39514 .09621 L
.39586 .07303 L
.39657 .07806 L
.39729 .05742 L
.39801 .09101 L
.39873 .06221 L
.39945 .16853 L
.40017 .06143 L
.40088 .03361 L
.4016 .02467 L
.40232 .15127 L
.40304 .17017 L
.40376 .02105 L
.40447 .02092 L
.40519 .05467 L
.40591 .19725 L
.40663 .08109 L
.40735 .05445 L
.40807 .04319 L
.40878 .097 L
.4095 .11661 L
.41022 .07125 L
.41094 .13135 L
.41166 .04322 L
.41238 .06835 L
.41309 .04793 L
.41381 .1632 L
.41453 .11873 L
.41525 .0198 L
.41597 .02142 L
.41668 .09056 L
.4174 .19031 L
.41812 .04898 L
Mistroke
.41884 .01919 L
.41956 .02586 L
.42028 .15128 L
.42099 .11829 L
.42171 .03534 L
.42243 .04224 L
.42315 .06188 L
.42387 .13212 L
.42459 .05602 L
.4253 .09064 L
.42602 .05686 L
.42674 .07209 L
.42746 .0641 L
.42818 .08988 L
.42889 .14077 L
.42961 .0396 L
.43033 .04521 L
.43105 .04415 L
.43177 .18094 L
.43249 .10877 L
.4332 .01842 L
.43392 .01742 L
.43464 .11202 L
.43536 .20104 L
.43608 .0377 L
.4368 .02209 L
.43751 .0319 L
.43823 .18862 L
.43895 .11508 L
.43967 .02853 L
.44039 .03597 L
.4411 .09224 L
.44182 .1706 L
.44254 .04514 L
.44326 .08268 L
.44398 .0465 L
.4447 .1251 L
.44541 .07902 L
.44613 .08909 L
.44685 .10972 L
.44757 .05036 L
.44829 .08642 L
.44901 .05808 L
.44972 .17033 L
.45044 .06903 L
.45116 .0476 L
.45188 .03758 L
.4526 .13645 L
.45331 .15458 L
.45403 .02535 L
Mistroke
.45475 .03026 L
.45547 .06007 L
.45619 .19357 L
.45691 .07381 L
.45762 .01786 L
.45834 .01879 L
.45906 .1405 L
.45978 .16045 L
.4605 .02258 L
.46122 .01687 L
.46193 .05445 L
.46265 .18754 L
.46337 .07826 L
.46409 .0203 L
.46481 .02116 L
.46552 .12624 L
.46624 .15396 L
.46696 .03181 L
.46768 .03789 L
.4684 .05211 L
.46912 .16882 L
.46983 .07756 L
.47055 .04919 L
.47127 .04232 L
.47199 .10482 L
.47271 .13532 L
.47343 .04567 L
.47414 .07574 L
.47486 .04707 L
.47558 .13877 L
.4763 .07008 L
.47702 .07789 L
.47773 .06362 L
.47845 .08025 L
.47917 .11279 L
.47989 .05279 L
.48061 .10128 L
.48133 .04663 L
.48204 .108 L
.48276 .06295 L
.48348 .09048 L
.4842 .08572 L
.48492 .06004 L
.48564 .09137 L
.48635 .05566 L
.48707 .12779 L
.48779 .05664 L
.48851 .08134 L
.48923 .05493 L
.48994 .102 L
Mistroke
.49066 .11313 L
.49138 .05056 L
.4921 .07826 L
.49282 .053 L
.49354 .14743 L
.49425 .0636 L
.49497 .07422 L
.49569 .04906 L
.49641 .11008 L
.49713 .11945 L
.49785 .04925 L
.49856 .07784 L
.49928 .05562 L
.5 .15011 L
.50072 .05571 L
.50144 .07785 L
.50215 .04915 L
.50287 .11944 L
.50359 .11017 L
.50431 .04907 L
.50503 .07413 L
.50575 .06359 L
.50646 .14751 L
.50718 .05302 L
.5079 .07816 L
.50862 .05054 L
.50934 .11322 L
.51006 .10202 L
.51077 .05484 L
.51149 .08131 L
.51221 .05672 L
.51293 .12781 L
.51365 .05557 L
.51436 .09133 L
.51508 .06013 L
.5158 .08574 L
.51652 .0904 L
.51724 .06291 L
.51796 .1081 L
.51867 .04666 L
.51939 .10121 L
.52011 .05275 L
.52083 .11288 L
.52155 .0803 L
.52227 .06355 L
.52298 .07786 L
.5237 .07016 L
.52442 .13883 L
.52514 .04699 L
.52586 .07571 L
Mistroke
.52657 .04574 L
.52729 .13539 L
.52801 .10474 L
.52873 .04228 L
.52945 .04924 L
.53017 .07762 L
.53088 .16873 L
.5316 .05205 L
.53232 .03792 L
.53304 .03185 L
.53376 .15388 L
.53448 .12617 L
.53519 .02119 L
.53591 .02031 L
.53663 .07821 L
.53735 .18746 L
.53807 .05448 L
.53878 .01687 L
.5395 .02257 L
.54022 .16037 L
.54094 .14054 L
.54166 .01879 L
.54238 .01788 L
.54309 .07377 L
.54381 .19361 L
.54453 .06008 L
.54525 .03029 L
.54597 .02536 L
.54669 .15461 L
.5474 .13649 L
.54812 .0376 L
.54884 .04766 L
.54956 .06903 L
.55028 .17038 L
.55099 .05809 L
.55171 .08652 L
.55243 .05033 L
.55315 .10975 L
.55387 .08909 L
.55459 .07911 L
.5553 .12506 L
.55602 .04647 L
.55674 .08267 L
.55746 .04519 L
.55818 .17055 L
.5589 .09215 L
.55961 .03597 L
.56033 .02853 L
.56105 .11505 L
.56177 .18848 L
Mistroke
.56249 .03191 L
.5632 .02207 L
.56392 .03769 L
.56464 .2009 L
.56536 .11204 L
.56608 .01742 L
.5668 .01842 L
.56751 .10868 L
.56823 .18096 L
.56895 .04419 L
.56967 .04521 L
.57039 .03957 L
.57111 .14078 L
.57182 .08995 L
.57254 .0641 L
.57326 .07213 L
.57398 .05686 L
.5747 .09071 L
.57541 .05602 L
.57613 .13218 L
.57685 .06189 L
.57757 .04228 L
.57829 .03534 L
.57901 .11835 L
.57972 .1513 L
.58044 .02585 L
.58116 .0192 L
.58188 .04901 L
.5826 .19033 L
.58332 .0905 L
.58403 .02142 L
.58475 .01981 L
.58547 .11875 L
.58619 .16312 L
.58691 .04792 L
.58762 .06837 L
.58834 .04322 L
.58906 .13129 L
.58978 .07123 L
.5905 .11664 L
.59122 .09699 L
.59193 .04315 L
.59265 .05443 L
.59337 .08112 L
.59409 .19723 L
.59481 .05466 L
.59553 .02091 L
.59624 .02106 L
.59696 .17014 L
.59768 .15126 L
Mistroke
.5984 .02468 L
.59912 .03359 L
.59983 .06142 L
.60055 .16852 L
.60127 .06223 L
.60199 .09096 L
.60271 .05741 L
.60343 .07806 L
.60414 .07305 L
.60486 .09617 L
.60558 .16561 L
.6063 .03801 L
.60702 .03547 L
.60774 .04053 L
.60845 .20317 L
.60917 .12304 L
.60989 .01589 L
.61061 .01838 L
.61133 .1022 L
.61204 .1793 L
.61276 .04723 L
.61348 .07196 L
.6142 .0469 L
.61492 .10124 L
.61564 .06331 L
.61635 .10128 L
.61707 .13661 L
.61779 .0312 L
.61851 .03159 L
.61923 .04916 L
.61995 .20015 L
.62066 .09355 L
.62138 .02094 L
.6221 .0221 L
.62282 .11092 L
.62354 .15447 L
.62425 .0568 L
.62497 .1044 L
.62569 .0446 L
.62641 .08147 L
.62713 .05217 L
.62785 .15952 L
.62856 .1428 L
.62928 .01825 L
.63 .01707 L
.63072 .07662 L
.63144 .20317 L
.63216 .06974 L
.63287 .0486 L
.63359 .03537 L
Mistroke
.63431 .096 L
.63503 .09328 L
.63575 .08377 L
.63646 .13705 L
.63718 .03396 L
.6379 .03514 L
.63862 .03973 L
.63934 .18301 L
.64006 .1216 L
.64077 .02269 L
.64149 .02312 L
.64221 .07944 L
.64293 .15755 L
.64365 .06821 L
.64437 .11508 L
.64508 .05357 L
.6458 .05456 L
.64652 .04575 L
.64724 .13953 L
.64796 .18294 L
.64867 .0293 L
.64939 .01944 L
.65011 .04151 L
.65083 .18094 L
.65155 .09715 L
.65227 .07381 L
.65298 .07908 L
.6537 .04862 L
.65442 .07022 L
.65514 .06703 L
.65586 .2042 L
.65658 .07641 L
.65729 .01749 L
.65801 .01688 L
.65873 .13834 L
.65945 .15766 L
.66017 .05184 L
.66088 .10553 L
.6616 .04693 L
.66232 .07212 L
.66304 .03901 L
.66376 .17913 L
.66448 .1492 L
.66519 .01708 L
.66591 .02251 L
.66663 .07781 L
.66735 .17278 L
.66807 .05988 L
.66879 .11803 L
.6695 .0771 L
Mistroke
.67022 .044 L
.67094 .03157 L
.67166 .12202 L
.67238 .20733 L
.67309 .03925 L
.67381 .03851 L
.67453 .03384 L
.67525 .14381 L
.67597 .08572 L
.67669 .12344 L
.6774 .13606 L
.67812 .02215 L
.67884 .02491 L
.67956 .06553 L
.68028 .21503 L
.681 .08978 L
.68171 .06534 L
.68243 .05133 L
.68315 .06223 L
.68387 .07136 L
.68459 .09802 L
.6853 .2013 L
.68602 .05659 L
.68674 .01973 L
.68746 .02237 L
.68818 .1404 L
.6889 .1248 L
.68961 .08483 L
.69033 .12254 L
.69105 .03172 L
.69177 .03676 L
.69249 .04536 L
.69321 .19462 L
.69392 .12534 L
.69464 .04079 L
.69536 .04828 L
.69608 .05539 L
.6968 .09413 L
.69751 .06703 L
.69823 .18621 L
.69895 .09418 L
.69967 .0159 L
.70039 .01761 L
.70111 .09775 L
.70182 .14947 L
.70254 .06918 L
.70326 .14715 L
.70398 .06112 L
.7047 .02641 L
.70542 .02123 L
Mistroke
.70613 .15117 L
.70685 .18647 L
.70757 .05349 L
.70829 .08958 L
.70901 .04262 L
.70972 .07162 L
.71044 .04279 L
.71116 .17963 L
.71188 .17381 L
.7126 .02899 L
.71332 .04663 L
.71403 .04892 L
.71475 .12005 L
.71547 .05825 L
.71619 .1844 L
.71691 .13656 L
.71763 .01574 L
.71834 .02172 L
.71906 .07788 L
.71978 .1679 L
.7205 .06861 L
.72122 .17339 L
.72193 .08805 L
.72265 .01889 L
.72337 .01504 L
.72409 .13085 L
.72481 .19237 L
.72553 .0691 L
.72624 .14434 L
.72696 .05814 L
.72768 .03214 L
.7284 .02248 L
.72912 .16514 L
.72984 .18108 L
.73055 .06081 L
.73127 .11266 L
.73199 .03967 L
.73271 .0454 L
.73343 .03299 L
.73414 .18748 L
.73486 .15441 L
.73558 .05294 L
.7363 .08636 L
.73702 .03833 L
.73774 .05659 L
.73845 .04781 L
.73917 .20735 L
.73989 .13141 L
.74061 .05188 L
.74133 .07327 L
Mistroke
.74205 .04305 L
.74276 .05987 L
.74348 .06524 L
.7442 .22677 L
.74492 .1176 L
.74564 .05645 L
.74635 .0615 L
.74707 .04802 L
.74779 .0651 L
.74851 .08267 L
.74923 .23245 L
.74995 .09948 L
.75066 .05704 L
.75138 .05237 L
.7521 .05198 L
.75282 .05915 L
.75354 .09491 L
.75426 .22958 L
.75497 .08812 L
.75569 .06833 L
.75641 .05146 L
.75713 .04951 L
.75785 .04994 L
.75856 .11239 L
.75928 .22762 L
.76 .07766 L
.76072 .08307 L
.76144 .04897 L
.76216 .04825 L
.76287 .04092 L
.76359 .13189 L
.76431 .22431 L
.76503 .07506 L
.76575 .10249 L
.76647 .05751 L
.76718 .03708 L
.7679 .02726 L
.76862 .13322 L
.76934 .20414 L
.77006 .07493 L
.77077 .13153 L
.77149 .0619 L
.77221 .02278 L
.77293 .01767 L
.77365 .12985 L
.77437 .17242 L
.77508 .08286 L
.7758 .17009 L
.77652 .06699 L
.77724 .01599 L
Mistroke
.77796 .01743 L
.77868 .116 L
.77939 .13103 L
.78011 .10327 L
.78083 .22084 L
.78155 .07518 L
.78227 .03209 L
.78298 .02861 L
.7837 .08952 L
.78442 .08494 L
.78514 .13012 L
.78586 .24561 L
.78658 .07436 L
.78729 .07433 L
.78801 .0474 L
.78873 .05223 L
.78945 .03603 L
.79017 .13801 L
.79089 .22102 L
.7916 .07803 L
.79232 .15268 L
.79304 .07272 L
.79376 .01886 L
.79448 .01482 L
.7952 .1253 L
.79591 .16559 L
.79663 .09626 L
.79735 .23536 L
.79807 .08742 L
.79879 .03143 L
.7995 .03491 L
.80022 .08287 L
.80094 .07669 L
.80166 .11017 L
.80238 .26193 L
.8031 .09078 L
.80381 .10473 L
.80453 .08913 L
.80525 .02773 L
.80597 .01876 L
.80669 .10047 L
.80741 .20903 L
.80812 .08221 L
.80884 .21137 L
.80956 .1349 L
.81028 .02192 L
.811 .04214 L
.81171 .06101 L
.81243 .09249 L
.81315 .06589 L
Mistroke
.81387 .26349 L
.81459 .14304 L
.81531 .10083 L
.81602 .14252 L
.81674 .02331 L
.81746 .02237 L
.81818 .04882 L
.8189 .19847 L
.81962 .09632 L
.82033 .20728 L
.82105 .22284 L
.82177 .04041 L
.82249 .08027 L
.82321 .0406 L
.82392 .06136 L
.82464 .03282 L
.82536 .20577 L
.82608 .18621 L
.8268 .10796 L
.82752 .21978 L
.82823 .05922 L
.82895 .03204 L
.82967 .02995 L
.83039 .08677 L
.83111 .06341 L
.83183 .14056 L
.83254 .25486 L
.83326 .09681 L
.83398 .16785 L
.8347 .10493 L
.83542 .01544 L
.83613 .0213 L
.83685 .07158 L
.83757 .11242 L
.83829 .08971 L
.83901 .26434 L
.83973 .1558 L
.84044 .11795 L
.84116 .14262 L
.84188 .02291 L
.8426 .01889 L
.84332 .03798 L
.84404 .13036 L
.84475 .08053 L
.84547 .20451 L
.84619 .22558 L
.84691 .09869 L
.84763 .16691 L
.84834 .0582 L
.84906 .01871 L
Mistroke
.84978 .01801 L
.8505 .09617 L
.85122 .10005 L
.85194 .14349 L
.85265 .27261 L
.85337 .12963 L
.85409 .16688 L
.85481 .12438 L
.85553 .0205 L
.85625 .02552 L
.85696 .04484 L
.85768 .08693 L
.8584 .0743 L
.85912 .23171 L
.85984 .18273 L
.86055 .15384 L
.86127 .21124 L
.86199 .06292 L
.86271 .05266 L
.86343 .03372 L
.86415 .03985 L
.86486 .03113 L
.86558 .126 L
.8663 .19182 L
.86702 .13213 L
.86774 .26557 L
.86846 .17133 L
.86917 .10229 L
.86989 .11706 L
.87061 .02306 L
.87133 .01678 L
.87205 .03375 L
.87276 .12705 L
.87348 .09612 L
.8742 .20441 L
.87492 .25524 L
.87564 .14353 L
.87636 .22414 L
.87707 .12025 L
.87779 .04785 L
.87851 .04836 L
.87923 .02554 L
.87995 .0342 L
.88067 .06578 L
.88138 .18643 L
.8821 .14033 L
.88282 .22652 L
.88354 .25294 L
.88426 .13761 L
.88497 .1847 L
Mistroke
.88569 .0934 L
.88641 .03272 L
.88713 .03044 L
.88785 .0349 L
.88857 .04669 L
.88928 .08573 L
.89 .2004 L
.89072 .15954 L
.89144 .23617 L
.89216 .25562 L
.89288 .15396 L
.89359 .19084 L
.89431 .10107 L
.89503 .04407 L
.89575 .03477 L
.89647 .02299 L
.89718 .03415 L
.8979 .07413 L
.89862 .17357 L
.89934 .15753 L
.90006 .2511 L
.90078 .26953 L
.90149 .19942 L
.90221 .24496 L
.90293 .14784 L
.90365 .09377 L
.90437 .07473 L
.90509 .01927 L
.9058 .0148 L
.90652 .03459 L
.90724 .09087 L
.90796 .09718 L
.90868 .19387 L
.90939 .22881 L
.91011 .21789 L
.91083 .29904 L
.91155 .2305 L
.91227 .213 L
.91299 .1987 L
.9137 .09881 L
.91442 .08129 L
.91514 .03763 L
.91586 .01478 L
.91658 .01744 L
.9173 .05944 L
.91801 .09057 L
.91873 .1347 L
.91945 .23319 L
.92017 .22869 L
.92089 .29814 L
Mistroke
.9216 .32334 L
.92232 .26438 L
.92304 .29707 L
.92376 .21389 L
.92448 .16046 L
.9252 .1386 L
.92591 .05908 L
.92663 .042 L
.92735 .02256 L
.92807 .0197 L
.92879 .02633 L
.92951 .08031 L
.93022 .12047 L
.93094 .15194 L
.93166 .25882 L
.93238 .25599 L
.9331 .31379 L
.93381 .37538 L
.93453 .31925 L
.93525 .38105 L
.93597 .33686 L
.93669 .27357 L
.93741 .28571 L
.93812 .1794 L
.93884 .14838 L
.93956 .11238 L
.94028 .0458 L
.941 .03865 L
.94172 .0195 L
.94243 .0183 L
.94315 .02413 L
.94387 .07329 L
.94459 .09622 L
.94531 .14061 L
.94602 .23709 L
.94674 .23804 L
.94746 .3331 L
.94818 .39279 L
.9489 .38552 L
.94962 .50578 L
.95033 .49181 L
.95105 .52256 L
.95177 .60332 L
.95249 .53341 L
.95321 .59682 L
.95393 .58158 L
.95464 .51914 L
.95536 .57633 L
.95608 .4885 L
.9568 .47365 L
Mistroke
.95752 .47391 L
.95823 .37045 L
.95895 .38632 L
.95967 .32711 L
.96039 .26829 L
.96111 .2841 L
.96183 .21087 L
.96254 .20658 L
.96326 .19841 L
.96398 .14246 L
.9647 .1588 L
.96542 .1207 L
.96614 .09593 L
.96685 .10364 L
.96757 .06435 L
.96829 .0671 L
.96901 .06069 L
.96973 .0388 L
.97044 .04924 L
.97116 .03345 L
.97188 .0288 L
.9726 .03298 L
.97332 .02061 L
.97404 .02491 L
.97475 .02381 L
.97547 .0179 L
.97619 .02323 L
Mfstroke
1 0 0 r
.02381 .01472 m
.02453 .01472 L
.02525 .01472 L
.02596 .01472 L
.02668 .01472 L
.0274 .01472 L
.02812 .01472 L
.02884 .01472 L
.02956 .01472 L
.03027 .01472 L
.03099 .01472 L
.03171 .01472 L
.03243 .01472 L
.03315 .01472 L
.03386 .01472 L
.03458 .01472 L
.0353 .01472 L
.03602 .01472 L
.03674 .01472 L
.03746 .01472 L
.03817 .01472 L
.03889 .01472 L
.03961 .01472 L
.04033 .01472 L
.04105 .01472 L
.04177 .01472 L
.04248 .01472 L
.0432 .01472 L
.04392 .01472 L
.04464 .01472 L
.04536 .01472 L
.04607 .01472 L
.04679 .01472 L
.04751 .01472 L
.04823 .01472 L
.04895 .01472 L
.04967 .01472 L
.05038 .01472 L
.0511 .01472 L
.05182 .01472 L
.05254 .01472 L
.05326 .01472 L
.05398 .01472 L
.05469 .01472 L
.05541 .01472 L
.05613 .01472 L
.05685 .01472 L
.05757 .01472 L
.05828 .01472 L
.059 .01472 L
Mistroke
.05972 .01472 L
.06044 .01472 L
.06116 .01472 L
.06188 .01472 L
.06259 .01472 L
.06331 .01472 L
.06403 .01472 L
.06475 .01472 L
.06547 .01472 L
.06619 .01472 L
.0669 .01472 L
.06762 .01472 L
.06834 .01472 L
.06906 .01472 L
.06978 .01472 L
.07049 .01472 L
.07121 .01472 L
.07193 .01472 L
.07265 .01472 L
.07337 .01472 L
.07409 .01472 L
.0748 .01472 L
.07552 .01472 L
.07624 .01472 L
.07696 .01472 L
.07768 .01472 L
.0784 .01472 L
.07911 .01472 L
.07983 .01472 L
.08055 .01472 L
.08127 .01472 L
.08199 .01472 L
.0827 .01472 L
.08342 .01472 L
.08414 .01472 L
.08486 .01472 L
.08558 .01472 L
.0863 .01472 L
.08701 .01472 L
.08773 .01472 L
.08845 .01472 L
.08917 .01472 L
.08989 .01472 L
.09061 .01472 L
.09132 .01472 L
.09204 .01472 L
.09276 .01472 L
.09348 .01472 L
.0942 .01472 L
.09491 .01472 L
Mistroke
.09563 .01472 L
.09635 .01472 L
.09707 .01472 L
.09779 .01472 L
.09851 .01472 L
.09922 .01472 L
.09994 .01472 L
.10066 .01472 L
.10138 .01472 L
.1021 .01472 L
.10282 .01472 L
.10353 .01472 L
.10425 .01472 L
.10497 .01472 L
.10569 .01472 L
.10641 .01472 L
.10712 .01472 L
.10784 .01472 L
.10856 .01472 L
.10928 .01472 L
.11 .01472 L
.11072 .01472 L
.11143 .01472 L
.11215 .01472 L
.11287 .01472 L
.11359 .01472 L
.11431 .01472 L
.11503 .01472 L
.11574 .01472 L
.11646 .01472 L
.11718 .01472 L
.1179 .01472 L
.11862 .01472 L
.11933 .01472 L
.12005 .01472 L
.12077 .01472 L
.12149 .01472 L
.12221 .01472 L
.12293 .01472 L
.12364 .01472 L
.12436 .01472 L
.12508 .01472 L
.1258 .01472 L
.12652 .01472 L
.12724 .01472 L
.12795 .01472 L
.12867 .01472 L
.12939 .01472 L
.13011 .01472 L
.13083 .01472 L
Mistroke
.13154 .01472 L
.13226 .01472 L
.13298 .01472 L
.1337 .01472 L
.13442 .01472 L
.13514 .01472 L
.13585 .01472 L
.13657 .01472 L
.13729 .01472 L
.13801 .01472 L
.13873 .01472 L
.13945 .01472 L
.14016 .01472 L
.14088 .01472 L
.1416 .01472 L
.14232 .01472 L
.14304 .01472 L
.14375 .01472 L
.14447 .01472 L
.14519 .01472 L
.14591 .01472 L
.14663 .01472 L
.14735 .01472 L
.14806 .01472 L
.14878 .01472 L
.1495 .01472 L
.15022 .01472 L
.15094 .01472 L
.15166 .01472 L
.15237 .01472 L
.15309 .01472 L
.15381 .01472 L
.15453 .01472 L
.15525 .01472 L
.15596 .01472 L
.15668 .01472 L
.1574 .01472 L
.15812 .01472 L
.15884 .01472 L
.15956 .01472 L
.16027 .01472 L
.16099 .01472 L
.16171 .01472 L
.16243 .01472 L
.16315 .01472 L
.16387 .01472 L
.16458 .01472 L
.1653 .01472 L
.16602 .01472 L
.16674 .01472 L
Mistroke
.16746 .01472 L
.16817 .01472 L
.16889 .01472 L
.16961 .01472 L
.17033 .01472 L
.17105 .01472 L
.17177 .01472 L
.17248 .01472 L
.1732 .01472 L
.17392 .01472 L
.17464 .01472 L
.17536 .01472 L
.17608 .01472 L
.17679 .01472 L
.17751 .01472 L
.17823 .01472 L
.17895 .01472 L
.17967 .01472 L
.18038 .01472 L
.1811 .01472 L
.18182 .01472 L
.18254 .01472 L
.18326 .01472 L
.18398 .01472 L
.18469 .01472 L
.18541 .01472 L
.18613 .01472 L
.18685 .01472 L
.18757 .01472 L
.18829 .01472 L
.189 .01472 L
.18972 .01472 L
.19044 .01472 L
.19116 .01472 L
.19188 .01472 L
.19259 .01472 L
.19331 .01472 L
.19403 .01472 L
.19475 .01472 L
.19547 .01472 L
.19619 .01472 L
.1969 .01472 L
.19762 .01472 L
.19834 .01472 L
.19906 .01472 L
.19978 .01472 L
.2005 .01472 L
.20121 .01472 L
.20193 .01472 L
.20265 .01472 L
Mistroke
.20337 .01472 L
.20409 .01472 L
.2048 .01472 L
.20552 .01472 L
.20624 .01472 L
.20696 .01472 L
.20768 .01472 L
.2084 .01472 L
.20911 .01472 L
.20983 .01472 L
.21055 .01472 L
.21127 .01472 L
.21199 .01472 L
.21271 .01472 L
.21342 .01472 L
.21414 .01472 L
.21486 .01472 L
.21558 .01472 L
.2163 .01472 L
.21702 .01472 L
.21773 .01472 L
.21845 .01472 L
.21917 .01472 L
.21989 .01472 L
.22061 .01472 L
.22132 .01472 L
.22204 .01472 L
.22276 .01472 L
.22348 .01472 L
.2242 .01472 L
.22492 .01472 L
.22563 .01472 L
.22635 .01472 L
.22707 .01472 L
.22779 .01472 L
.22851 .01472 L
.22923 .01472 L
.22994 .01472 L
.23066 .01472 L
.23138 .01472 L
.2321 .01472 L
.23282 .01472 L
.23353 .01472 L
.23425 .01472 L
.23497 .01472 L
.23569 .01472 L
.23641 .01472 L
.23713 .01472 L
.23784 .01472 L
.23856 .01472 L
Mistroke
.23928 .01472 L
.24 .01472 L
.24072 .01472 L
.24144 .01472 L
.24215 .01472 L
.24287 .01472 L
.24359 .01472 L
.24431 .01472 L
.24503 .01472 L
.24574 .01472 L
.24646 .01472 L
.24718 .01472 L
.2479 .01472 L
.24862 .01472 L
.24934 .01472 L
.25005 .01472 L
.25077 .01472 L
.25149 .01472 L
.25221 .01472 L
.25293 .01472 L
.25365 .01472 L
.25436 .01472 L
.25508 .01472 L
.2558 .01472 L
.25652 .01472 L
.25724 .01472 L
.25795 .01472 L
.25867 .01472 L
.25939 .01472 L
.26011 .01472 L
.26083 .01472 L
.26155 .01472 L
.26226 .01472 L
.26298 .01472 L
.2637 .01472 L
.26442 .01472 L
.26514 .01472 L
.26586 .01472 L
.26657 .01472 L
.26729 .01472 L
.26801 .01472 L
.26873 .01472 L
.26945 .01472 L
.27016 .01472 L
.27088 .01472 L
.2716 .01472 L
.27232 .01472 L
.27304 .01472 L
.27376 .01472 L
.27447 .01472 L
Mistroke
.27519 .01472 L
.27591 .01472 L
.27663 .01472 L
.27735 .01472 L
.27807 .01472 L
.27878 .01472 L
.2795 .01472 L
.28022 .01472 L
.28094 .01472 L
.28166 .01472 L
.28237 .01472 L
.28309 .01472 L
.28381 .01472 L
.28453 .01472 L
.28525 .01472 L
.28597 .01472 L
.28668 .01472 L
.2874 .01472 L
.28812 .01472 L
.28884 .01472 L
.28956 .01472 L
.29028 .01472 L
.29099 .01472 L
.29171 .01472 L
.29243 .01472 L
.29315 .01472 L
.29387 .01472 L
.29458 .01472 L
.2953 .01472 L
.29602 .01472 L
.29674 .01472 L
.29746 .01472 L
.29818 .01472 L
.29889 .01472 L
.29961 .01472 L
.30033 .01472 L
.30105 .01472 L
.30177 .01472 L
.30249 .01472 L
.3032 .01472 L
.30392 .01472 L
.30464 .01472 L
.30536 .01472 L
.30608 .01472 L
.30679 .01472 L
.30751 .01472 L
.30823 .01472 L
.30895 .01472 L
.30967 .01472 L
.31039 .01472 L
Mistroke
.3111 .01472 L
.31182 .01472 L
.31254 .01472 L
.31326 .01472 L
.31398 .01472 L
.3147 .01472 L
.31541 .01472 L
.31613 .01472 L
.31685 .01472 L
.31757 .01472 L
.31829 .01472 L
.319 .01472 L
.31972 .01472 L
.32044 .01472 L
.32116 .01472 L
.32188 .01472 L
.3226 .01472 L
.32331 .01472 L
.32403 .01472 L
.32475 .01472 L
.32547 .01472 L
.32619 .01472 L
.32691 .01472 L
.32762 .01472 L
.32834 .01472 L
.32906 .01472 L
.32978 .01472 L
.3305 .01472 L
.33121 .01472 L
.33193 .01472 L
.33265 .01472 L
.33337 .01472 L
.33409 .01472 L
.33481 .01472 L
.33552 .01472 L
.33624 .01472 L
.33696 .01472 L
.33768 .01472 L
.3384 .01472 L
.33912 .01472 L
.33983 .01472 L
.34055 .01472 L
.34127 .01472 L
.34199 .01472 L
.34271 .01472 L
.34342 .01472 L
.34414 .01472 L
.34486 .01472 L
.34558 .01472 L
.3463 .01472 L
Mistroke
.34702 .01472 L
.34773 .01472 L
.34845 .01472 L
.34917 .01472 L
.34989 .01472 L
.35061 .01472 L
.35133 .01472 L
.35204 .01472 L
.35276 .01472 L
.35348 .01472 L
.3542 .01472 L
.35492 .01472 L
.35563 .01472 L
.35635 .01472 L
.35707 .01472 L
.35779 .01472 L
.35851 .01472 L
.35923 .01472 L
.35994 .01472 L
.36066 .01472 L
.36138 .01472 L
.3621 .01472 L
.36282 .01472 L
.36354 .01472 L
.36425 .01472 L
.36497 .01472 L
.36569 .01472 L
.36641 .01472 L
.36713 .01472 L
.36784 .01472 L
.36856 .01472 L
.36928 .01472 L
.37 .01472 L
.37072 .01472 L
.37144 .01472 L
.37215 .01472 L
.37287 .01472 L
.37359 .01472 L
.37431 .01472 L
.37503 .01472 L
.37575 .01472 L
.37646 .01472 L
.37718 .01472 L
.3779 .01472 L
.37862 .01472 L
.37934 .01472 L
.38005 .01472 L
.38077 .01472 L
.38149 .01472 L
.38221 .01472 L
Mistroke
.38293 .01472 L
.38365 .01472 L
.38436 .01472 L
.38508 .01472 L
.3858 .01472 L
.38652 .01472 L
.38724 .01472 L
.38796 .01472 L
.38867 .01472 L
.38939 .01472 L
.39011 .01472 L
.39083 .01472 L
.39155 .01472 L
.39226 .01472 L
.39298 .01472 L
.3937 .01472 L
.39442 .01472 L
.39514 .01472 L
.39586 .01472 L
.39657 .01472 L
.39729 .01472 L
.39801 .01472 L
.39873 .01472 L
.39945 .01472 L
.40017 .01472 L
.40088 .01472 L
.4016 .01472 L
.40232 .01472 L
.40304 .01472 L
.40376 .01472 L
.40447 .01473 L
.40519 .01472 L
.40591 .01473 L
.40663 .01472 L
.40735 .01473 L
.40807 .01472 L
.40878 .01473 L
.4095 .01472 L
.41022 .01473 L
.41094 .01472 L
.41166 .01473 L
.41238 .01472 L
.41309 .01473 L
.41381 .01472 L
.41453 .01473 L
.41525 .01472 L
.41597 .01473 L
.41668 .01472 L
.4174 .01473 L
.41812 .01472 L
Mistroke
.41884 .01473 L
.41956 .01472 L
.42028 .01473 L
.42099 .01472 L
.42171 .01473 L
.42243 .01472 L
.42315 .01473 L
.42387 .01472 L
.42459 .01473 L
.4253 .01472 L
.42602 .01473 L
.42674 .01472 L
.42746 .01473 L
.42818 .01472 L
.42889 .01473 L
.42961 .01472 L
.43033 .01473 L
.43105 .01472 L
.43177 .01474 L
.43249 .01472 L
.4332 .01474 L
.43392 .01472 L
.43464 .01474 L
.43536 .01472 L
.43608 .01474 L
.4368 .01472 L
.43751 .01474 L
.43823 .01472 L
.43895 .01474 L
.43967 .01472 L
.44039 .01474 L
.4411 .01472 L
.44182 .01474 L
.44254 .01472 L
.44326 .01475 L
.44398 .01472 L
.4447 .01475 L
.44541 .01472 L
.44613 .01475 L
.44685 .01472 L
.44757 .01475 L
.44829 .01472 L
.44901 .01475 L
.44972 .01472 L
.45044 .01476 L
.45116 .01472 L
.45188 .01476 L
.4526 .01472 L
.45331 .01476 L
.45403 .01472 L
Mistroke
.45475 .01477 L
.45547 .01472 L
.45619 .01477 L
.45691 .01472 L
.45762 .01477 L
.45834 .01472 L
.45906 .01478 L
.45978 .01472 L
.4605 .01478 L
.46122 .01472 L
.46193 .01479 L
.46265 .01472 L
.46337 .0148 L
.46409 .01472 L
.46481 .0148 L
.46552 .01472 L
.46624 .01481 L
.46696 .01472 L
.46768 .01482 L
.4684 .01472 L
.46912 .01483 L
.46983 .01472 L
.47055 .01485 L
.47127 .01472 L
.47199 .01486 L
.47271 .01472 L
.47343 .01488 L
.47414 .01472 L
.47486 .0149 L
.47558 .01472 L
.4763 .01492 L
.47702 .01472 L
.47773 .01495 L
.47845 .01472 L
.47917 .01498 L
.47989 .01472 L
.48061 .01503 L
.48133 .01472 L
.48204 .01508 L
.48276 .01472 L
.48348 .01515 L
.4842 .01472 L
.48492 .01524 L
.48564 .01472 L
.48635 .01536 L
.48707 .01472 L
.48779 .01552 L
.48851 .01472 L
.48923 .01575 L
.48994 .01472 L
Mistroke
.49066 .0161 L
.49138 .01472 L
.4921 .01665 L
.49282 .01472 L
.49354 .01761 L
.49425 .01472 L
.49497 .0195 L
.49569 .01472 L
.49641 .02412 L
.49713 .01472 L
.49785 .04093 L
.49856 .01472 L
.49928 .25473 L
.5 .60332 L
.50072 .25473 L
.50144 .01472 L
.50215 .04093 L
.50287 .01472 L
.50359 .02412 L
.50431 .01472 L
.50503 .0195 L
.50575 .01472 L
.50646 .01761 L
.50718 .01472 L
.5079 .01665 L
.50862 .01472 L
.50934 .0161 L
.51006 .01472 L
.51077 .01575 L
.51149 .01472 L
.51221 .01552 L
.51293 .01472 L
.51365 .01536 L
.51436 .01472 L
.51508 .01524 L
.5158 .01472 L
.51652 .01515 L
.51724 .01472 L
.51796 .01508 L
.51867 .01472 L
.51939 .01503 L
.52011 .01472 L
.52083 .01498 L
.52155 .01472 L
.52227 .01495 L
.52298 .01472 L
.5237 .01492 L
.52442 .01472 L
.52514 .0149 L
.52586 .01472 L
Mistroke
.52657 .01488 L
.52729 .01472 L
.52801 .01486 L
.52873 .01472 L
.52945 .01485 L
.53017 .01472 L
.53088 .01483 L
.5316 .01472 L
.53232 .01482 L
.53304 .01472 L
.53376 .01481 L
.53448 .01472 L
.53519 .0148 L
.53591 .01472 L
.53663 .0148 L
.53735 .01472 L
.53807 .01479 L
.53878 .01472 L
.5395 .01478 L
.54022 .01472 L
.54094 .01478 L
.54166 .01472 L
.54238 .01477 L
.54309 .01472 L
.54381 .01477 L
.54453 .01472 L
.54525 .01477 L
.54597 .01472 L
.54669 .01476 L
.5474 .01472 L
.54812 .01476 L
.54884 .01472 L
.54956 .01476 L
.55028 .01472 L
.55099 .01475 L
.55171 .01472 L
.55243 .01475 L
.55315 .01472 L
.55387 .01475 L
.55459 .01472 L
.5553 .01475 L
.55602 .01472 L
.55674 .01475 L
.55746 .01472 L
.55818 .01474 L
.5589 .01472 L
.55961 .01474 L
.56033 .01472 L
.56105 .01474 L
.56177 .01472 L
Mistroke
.56249 .01474 L
.5632 .01472 L
.56392 .01474 L
.56464 .01472 L
.56536 .01474 L
.56608 .01472 L
.5668 .01474 L
.56751 .01472 L
.56823 .01474 L
.56895 .01472 L
.56967 .01473 L
.57039 .01472 L
.57111 .01473 L
.57182 .01472 L
.57254 .01473 L
.57326 .01472 L
.57398 .01473 L
.5747 .01472 L
.57541 .01473 L
.57613 .01472 L
.57685 .01473 L
.57757 .01472 L
.57829 .01473 L
.57901 .01472 L
.57972 .01473 L
.58044 .01472 L
.58116 .01473 L
.58188 .01472 L
.5826 .01473 L
.58332 .01472 L
.58403 .01473 L
.58475 .01472 L
.58547 .01473 L
.58619 .01472 L
.58691 .01473 L
.58762 .01472 L
.58834 .01473 L
.58906 .01472 L
.58978 .01473 L
.5905 .01472 L
.59122 .01473 L
.59193 .01472 L
.59265 .01473 L
.59337 .01472 L
.59409 .01473 L
.59481 .01472 L
.59553 .01473 L
.59624 .01472 L
.59696 .01472 L
.59768 .01472 L
Mistroke
.5984 .01472 L
.59912 .01472 L
.59983 .01472 L
.60055 .01472 L
.60127 .01472 L
.60199 .01472 L
.60271 .01472 L
.60343 .01472 L
.60414 .01472 L
.60486 .01472 L
.60558 .01472 L
.6063 .01472 L
.60702 .01472 L
.60774 .01472 L
.60845 .01472 L
.60917 .01472 L
.60989 .01472 L
.61061 .01472 L
.61133 .01472 L
.61204 .01472 L
.61276 .01472 L
.61348 .01472 L
.6142 .01472 L
.61492 .01472 L
.61564 .01472 L
.61635 .01472 L
.61707 .01472 L
.61779 .01472 L
.61851 .01472 L
.61923 .01472 L
.61995 .01472 L
.62066 .01472 L
.62138 .01472 L
.6221 .01472 L
.62282 .01472 L
.62354 .01472 L
.62425 .01472 L
.62497 .01472 L
.62569 .01472 L
.62641 .01472 L
.62713 .01472 L
.62785 .01472 L
.62856 .01472 L
.62928 .01472 L
.63 .01472 L
.63072 .01472 L
.63144 .01472 L
.63216 .01472 L
.63287 .01472 L
.63359 .01472 L
Mistroke
.63431 .01472 L
.63503 .01472 L
.63575 .01472 L
.63646 .01472 L
.63718 .01472 L
.6379 .01472 L
.63862 .01472 L
.63934 .01472 L
.64006 .01472 L
.64077 .01472 L
.64149 .01472 L
.64221 .01472 L
.64293 .01472 L
.64365 .01472 L
.64437 .01472 L
.64508 .01472 L
.6458 .01472 L
.64652 .01472 L
.64724 .01472 L
.64796 .01472 L
.64867 .01472 L
.64939 .01472 L
.65011 .01472 L
.65083 .01472 L
.65155 .01472 L
.65227 .01472 L
.65298 .01472 L
.6537 .01472 L
.65442 .01472 L
.65514 .01472 L
.65586 .01472 L
.65658 .01472 L
.65729 .01472 L
.65801 .01472 L
.65873 .01472 L
.65945 .01472 L
.66017 .01472 L
.66088 .01472 L
.6616 .01472 L
.66232 .01472 L
.66304 .01472 L
.66376 .01472 L
.66448 .01472 L
.66519 .01472 L
.66591 .01472 L
.66663 .01472 L
.66735 .01472 L
.66807 .01472 L
.66879 .01472 L
.6695 .01472 L
Mistroke
.67022 .01472 L
.67094 .01472 L
.67166 .01472 L
.67238 .01472 L
.67309 .01472 L
.67381 .01472 L
.67453 .01472 L
.67525 .01472 L
.67597 .01472 L
.67669 .01472 L
.6774 .01472 L
.67812 .01472 L
.67884 .01472 L
.67956 .01472 L
.68028 .01472 L
.681 .01472 L
.68171 .01472 L
.68243 .01472 L
.68315 .01472 L
.68387 .01472 L
.68459 .01472 L
.6853 .01472 L
.68602 .01472 L
.68674 .01472 L
.68746 .01472 L
.68818 .01472 L
.6889 .01472 L
.68961 .01472 L
.69033 .01472 L
.69105 .01472 L
.69177 .01472 L
.69249 .01472 L
.69321 .01472 L
.69392 .01472 L
.69464 .01472 L
.69536 .01472 L
.69608 .01472 L
.6968 .01472 L
.69751 .01472 L
.69823 .01472 L
.69895 .01472 L
.69967 .01472 L
.70039 .01472 L
.70111 .01472 L
.70182 .01472 L
.70254 .01472 L
.70326 .01472 L
.70398 .01472 L
.7047 .01472 L
.70542 .01472 L
Mistroke
.70613 .01472 L
.70685 .01472 L
.70757 .01472 L
.70829 .01472 L
.70901 .01472 L
.70972 .01472 L
.71044 .01472 L
.71116 .01472 L
.71188 .01472 L
.7126 .01472 L
.71332 .01472 L
.71403 .01472 L
.71475 .01472 L
.71547 .01472 L
.71619 .01472 L
.71691 .01472 L
.71763 .01472 L
.71834 .01472 L
.71906 .01472 L
.71978 .01472 L
.7205 .01472 L
.72122 .01472 L
.72193 .01472 L
.72265 .01472 L
.72337 .01472 L
.72409 .01472 L
.72481 .01472 L
.72553 .01472 L
.72624 .01472 L
.72696 .01472 L
.72768 .01472 L
.7284 .01472 L
.72912 .01472 L
.72984 .01472 L
.73055 .01472 L
.73127 .01472 L
.73199 .01472 L
.73271 .01472 L
.73343 .01472 L
.73414 .01472 L
.73486 .01472 L
.73558 .01472 L
.7363 .01472 L
.73702 .01472 L
.73774 .01472 L
.73845 .01472 L
.73917 .01472 L
.73989 .01472 L
.74061 .01472 L
.74133 .01472 L
Mistroke
.74205 .01472 L
.74276 .01472 L
.74348 .01472 L
.7442 .01472 L
.74492 .01472 L
.74564 .01472 L
.74635 .01472 L
.74707 .01472 L
.74779 .01472 L
.74851 .01472 L
.74923 .01472 L
.74995 .01472 L
.75066 .01472 L
.75138 .01472 L
.7521 .01472 L
.75282 .01472 L
.75354 .01472 L
.75426 .01472 L
.75497 .01472 L
.75569 .01472 L
.75641 .01472 L
.75713 .01472 L
.75785 .01472 L
.75856 .01472 L
.75928 .01472 L
.76 .01472 L
.76072 .01472 L
.76144 .01472 L
.76216 .01472 L
.76287 .01472 L
.76359 .01472 L
.76431 .01472 L
.76503 .01472 L
.76575 .01472 L
.76647 .01472 L
.76718 .01472 L
.7679 .01472 L
.76862 .01472 L
.76934 .01472 L
.77006 .01472 L
.77077 .01472 L
.77149 .01472 L
.77221 .01472 L
.77293 .01472 L
.77365 .01472 L
.77437 .01472 L
.77508 .01472 L
.7758 .01472 L
.77652 .01472 L
.77724 .01472 L
Mistroke
.77796 .01472 L
.77868 .01472 L
.77939 .01472 L
.78011 .01472 L
.78083 .01472 L
.78155 .01472 L
.78227 .01472 L
.78298 .01472 L
.7837 .01472 L
.78442 .01472 L
.78514 .01472 L
.78586 .01472 L
.78658 .01472 L
.78729 .01472 L
.78801 .01472 L
.78873 .01472 L
.78945 .01472 L
.79017 .01472 L
.79089 .01472 L
.7916 .01472 L
.79232 .01472 L
.79304 .01472 L
.79376 .01472 L
.79448 .01472 L
.7952 .01472 L
.79591 .01472 L
.79663 .01472 L
.79735 .01472 L
.79807 .01472 L
.79879 .01472 L
.7995 .01472 L
.80022 .01472 L
.80094 .01472 L
.80166 .01472 L
.80238 .01472 L
.8031 .01472 L
.80381 .01472 L
.80453 .01472 L
.80525 .01472 L
.80597 .01472 L
.80669 .01472 L
.80741 .01472 L
.80812 .01472 L
.80884 .01472 L
.80956 .01472 L
.81028 .01472 L
.811 .01472 L
.81171 .01472 L
.81243 .01472 L
.81315 .01472 L
Mistroke
.81387 .01472 L
.81459 .01472 L
.81531 .01472 L
.81602 .01472 L
.81674 .01472 L
.81746 .01472 L
.81818 .01472 L
.8189 .01472 L
.81962 .01472 L
.82033 .01472 L
.82105 .01472 L
.82177 .01472 L
.82249 .01472 L
.82321 .01472 L
.82392 .01472 L
.82464 .01472 L
.82536 .01472 L
.82608 .01472 L
.8268 .01472 L
.82752 .01472 L
.82823 .01472 L
.82895 .01472 L
.82967 .01472 L
.83039 .01472 L
.83111 .01472 L
.83183 .01472 L
.83254 .01472 L
.83326 .01472 L
.83398 .01472 L
.8347 .01472 L
.83542 .01472 L
.83613 .01472 L
.83685 .01472 L
.83757 .01472 L
.83829 .01472 L
.83901 .01472 L
.83973 .01472 L
.84044 .01472 L
.84116 .01472 L
.84188 .01472 L
.8426 .01472 L
.84332 .01472 L
.84404 .01472 L
.84475 .01472 L
.84547 .01472 L
.84619 .01472 L
.84691 .01472 L
.84763 .01472 L
.84834 .01472 L
.84906 .01472 L
Mistroke
.84978 .01472 L
.8505 .01472 L
.85122 .01472 L
.85194 .01472 L
.85265 .01472 L
.85337 .01472 L
.85409 .01472 L
.85481 .01472 L
.85553 .01472 L
.85625 .01472 L
.85696 .01472 L
.85768 .01472 L
.8584 .01472 L
.85912 .01472 L
.85984 .01472 L
.86055 .01472 L
.86127 .01472 L
.86199 .01472 L
.86271 .01472 L
.86343 .01472 L
.86415 .01472 L
.86486 .01472 L
.86558 .01472 L
.8663 .01472 L
.86702 .01472 L
.86774 .01472 L
.86846 .01472 L
.86917 .01472 L
.86989 .01472 L
.87061 .01472 L
.87133 .01472 L
.87205 .01472 L
.87276 .01472 L
.87348 .01472 L
.8742 .01472 L
.87492 .01472 L
.87564 .01472 L
.87636 .01472 L
.87707 .01472 L
.87779 .01472 L
.87851 .01472 L
.87923 .01472 L
.87995 .01472 L
.88067 .01472 L
.88138 .01472 L
.8821 .01472 L
.88282 .01472 L
.88354 .01472 L
.88426 .01472 L
.88497 .01472 L
Mistroke
.88569 .01472 L
.88641 .01472 L
.88713 .01472 L
.88785 .01472 L
.88857 .01472 L
.88928 .01472 L
.89 .01472 L
.89072 .01472 L
.89144 .01472 L
.89216 .01472 L
.89288 .01472 L
.89359 .01472 L
.89431 .01472 L
.89503 .01472 L
.89575 .01472 L
.89647 .01472 L
.89718 .01472 L
.8979 .01472 L
.89862 .01472 L
.89934 .01472 L
.90006 .01472 L
.90078 .01472 L
.90149 .01472 L
.90221 .01472 L
.90293 .01472 L
.90365 .01472 L
.90437 .01472 L
.90509 .01472 L
.9058 .01472 L
.90652 .01472 L
.90724 .01472 L
.90796 .01472 L
.90868 .01472 L
.90939 .01472 L
.91011 .01472 L
.91083 .01472 L
.91155 .01472 L
.91227 .01472 L
.91299 .01472 L
.9137 .01472 L
.91442 .01472 L
.91514 .01472 L
.91586 .01472 L
.91658 .01472 L
.9173 .01472 L
.91801 .01472 L
.91873 .01472 L
.91945 .01472 L
.92017 .01472 L
.92089 .01472 L
Mistroke
.9216 .01472 L
.92232 .01472 L
.92304 .01472 L
.92376 .01472 L
.92448 .01472 L
.9252 .01472 L
.92591 .01472 L
.92663 .01472 L
.92735 .01472 L
.92807 .01472 L
.92879 .01472 L
.92951 .01472 L
.93022 .01472 L
.93094 .01472 L
.93166 .01472 L
.93238 .01472 L
.9331 .01472 L
.93381 .01472 L
.93453 .01472 L
.93525 .01472 L
.93597 .01472 L
.93669 .01472 L
.93741 .01472 L
.93812 .01472 L
.93884 .01472 L
.93956 .01472 L
.94028 .01472 L
.941 .01472 L
.94172 .01472 L
.94243 .01472 L
.94315 .01472 L
.94387 .01472 L
.94459 .01472 L
.94531 .01472 L
.94602 .01472 L
.94674 .01472 L
.94746 .01472 L
.94818 .01472 L
.9489 .01472 L
.94962 .01472 L
.95033 .01472 L
.95105 .01472 L
.95177 .01472 L
.95249 .01472 L
.95321 .01472 L
.95393 .01472 L
.95464 .01472 L
.95536 .01472 L
.95608 .01472 L
.9568 .01472 L
Mistroke
.95752 .01472 L
.95823 .01472 L
.95895 .01472 L
.95967 .01472 L
.96039 .01472 L
.96111 .01472 L
.96183 .01472 L
.96254 .01472 L
.96326 .01472 L
.96398 .01472 L
.9647 .01472 L
.96542 .01472 L
.96614 .01472 L
.96685 .01472 L
.96757 .01472 L
.96829 .01472 L
.96901 .01472 L
.96973 .01472 L
.97044 .01472 L
.97116 .01472 L
.97188 .01472 L
.9726 .01472 L
.97332 .01472 L
.97404 .01472 L
.97475 .01472 L
.97547 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`007Oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002cooooo0_l00004oooo
o`04o`000?ooooooooooooooo`Go0000;oooool2o`0003;ooooo0_l00004ooooo`04o`000?oooooo
ooooooooo`Go0000;?ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000cooooo000L
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0:_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0002kooooo00Co0000oooooooooooo0000<?ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0002_ooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`0;ooooo`005Oooool5o`0000;ooooo00Co0000oooooooooooo0000
1oooool5o`0002Cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool0;_ooool01?l0003oooooooooool0000`ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool0:oooool01?l0003oooooooooool00007ooooo`Go00003?ooool001cooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool0000/ooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool0;Oooool01?l0003oooooooooool0000`ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0000gooooo000Looooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
;?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000;_ooool01?l0
003oooooooooool0000`ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00000[ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000003Oooool001cooooo
00Co0000oooooooooooo00002Oooool2o`0002cooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000002kooooo00Co0000oooooooooooo0000<?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool00000:oooool01?l0003oooooooooool00009oooo
o`;o00003Oooool001gooooo0_l0000;ooooo`03o`000?oooooooooo02_ooooo0_l00009ooooo`?o
0000<?ooool2o`0003;ooooo0_l00009ooooo`?o0000;Oooool2o`0000_ooooo00?o0000oooooooo
ool02oooool001kooooo00?o0000ooooooooool0ooooool001kooooo00?o0000ooooooooool0oooo
ool001kooooo00?o0000ooooooooool0ooooool001kooooo00?o0000ooooooooool0ooooool001So
oooo1_l0003bool000Ko00002_ooool001kooooo0_l000000ooooooo0000ooooo`04ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooooooool4
o`000003ooooool0003ooooo00Gooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooo
000000Wooooo00?o0000ooooool000000_l00002ooooo`;o00000_ooool02ol0003ooooooooooooo
oooo0000ooooool0003oooooo`000?oooooo000000Cooooo00Ko0000ooooool0003o0000ooooool0
0002ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooo`000003ooooo`?o00001_oo
ool4ool000Kooooo0ol00003ooooo`03o`000?oooooo000000?ooooo0_l00002ooooo`03o`000?oo
oooooooo00Co000000?oooooo`000?ooool00oooool00ol0003oooooo`000002o`0000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?ooool0
2Oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo1Ol000000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00005ooooo`04o`000?oooooo0000o`00013ooooo000Nooooo`;o00001_ooool2o`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`03o`000?oooooo
000000;ooooo0ol000001?oooooo0000ooooool00003ooooo`04o`000?oooooo0000o`0000;ooooo
00Oo0000ooooooooooooooooo`000?oooooo000000[ooooo1?l00002ooooo`;o00000_ooool01?l0
003oooooo`000?l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`03o`00
0?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo0_l00003ooooo`Co
00001oooool2ool000Oooooo1?l00004ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0
003oooooooooo`02o`000004ooooool0003oooooo`0000;ooooo00Co0000ooooool0003ooooo1?l0
0002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool3o`0000[ooooo0ol0
0003ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00_ooool3o`000004ooooool0
003oooooo`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooo000000;ooooo
00Co0000oooooooooooo00000_ooool2o`0000Kooooo0_l0000@ooooo`007_ooool2o`0000Kooooo
0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001?ooool3o`0000;o
oooo0ol000001?oooooo0000ooooool00003ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000
ooooooooool00_l000000ooooooo0000o`000009ooooo`Go000000?oooooo`000?l000000_ooool0
1?l0003oooooo`000?l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`03
o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo0_l00003oooo
o`Co00001oooool2ool000Oooooo1?l00003ooooo`;o00000oooool2o`0000;ooooo00?o0000oooo
ooooool00_l000001?oooooo0000ooooool00002ooooo`04o`000?oooooo0000ooooo`Co00000_oo
ool00ol0003oooooo`000002ooooo`Co000000Coooooo`000?l0003o00002Oooool5o`0000;ooooo
00?o0000ooooooooool00_l000000ooooooo0000ooooo`02ooooo`?o000000Coooooo`000?oooooo
00000_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooool000000_ooool01?l0003o
ooooooooool00002ooooo`;o00001_ooool00ol0003oooooooooo`0?ooooo`007_ooool2o`0000Ko
oooo0_l00002ooooo`03o`000?oooooooooo00;o000000Coooooo`000?oooooo00000_ooool6o`00
0007ooooool0003o0000o`000?oooooo0000ooooo`03o`000003ooooool0003ooooo00;o000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003o000000Sooooo1_l000001?oooooo0000o`00
0?ooool2o`00000<ooooool0003o0000o`000?oooooo0000ooooool0003oooooo`000?oooooo0000
0_ooool01ol0003oooooo`000?l0003oooooo`000?ooool00_l00002ooooo`;o00000oooool2o`00
00?ooooo1?l00007ooooo`;oo`001oooool4o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o000000Soooooo`000?ooooooooooo`000?oooooo0000ooooo`Go0000
00?oooooo`000?ooool00_l000000ooooooo0000o`000002o`000006ooooool0003o0000o`000?oo
oooo00001oooool5o`0000;ooooo0_l000001_oooooo0000o`000?oooooo0000ooooo`Go000000Go
ooooo`000?oooooo0000ooooo`03o`000003ooooool0003o000000;ooooo00?o0000ooooool00000
0_ooool01?l0003oooooooooool00002ooooo`;o00001_ooool00ol0003oooooooooo`0?ooooo`00
7_ooool2o`0000Kooooo0_l00002ooooo`;o000000Soooooo`000?l0003oooooo`000?oooooo0000
ooooo`_o000000?oooooo`000?ooool00ol000000ooooooo0000ooooo`02o`000005ooooool0003o
0000o`000?ooool00_l000000ooooooo0000o`000008ooooo`Ko000000Coooooo`000?l0003ooooo
0_l000002ooooooo0000o`000?l0003oooooo`000?oooooo0000ooooool0003ooooo00Co000000Ko
ooooo`000?l0003oooooo`000?ooool2o`0000;ooooo0ol00002ooooo`;o00000oooool4o`0000Oo
oooo0_oo0007ooooo`Co00000oooool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000002o`000003ooooool0003o000000Oo000000Coooooo`000?l0
003ooooo1?l000001_oooooo0000o`000?l0003oooooo`0000Oooooo1Ol000001Ooooooo0000o`00
0?l0003ooooo00;o000000?oooooo`000?ooool01Ol000001Ooooooo0000ooooool0003ooooo00?o
000000Soooooo`000?l0003o0000ooooool0003oooooo`0000;ooooo00Co0000ooooool0003o0000
0_ooool2o`0000Kooooo00?o0000ooooooooool03oooool001kooooo0ol00005ooooo`;o00000_oo
ool2o`000008ooooool0003o0000ooooool0003oooooo`000?ooool;o`000003ooooool0003ooooo
00Go000000Coooooo`000?l0003ooooo0ol000001?oooooo0000o`000?ooool3o`0000Kooooo1ol0
00000ooooooo0000o`000009o`000005ooooool0003oooooo`000?ooool01?l000001?oooooo0000
o`000?ooool5o`000005ooooool0003o0000o`000?ooool00ol00002ooooo`Go00001oooool2ool0
00Oooooo1Ol00002ooooo`?o000000Coooooo`000?l0003o00000_ooool7o`000003ooooool0003o
000000;o000000?oooooo`000?l000001ol000000ooooooo0000o`00000<o`0000Gooooo1_l00000
1Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000001Ol000001Ooooooo0000oooo
ool0003ooooo00Oo000000Coooooo`000?oooooo00000_ooool01?l0003oooooo`000?l00002oooo
o`;o00001Oooool2o`00017ooooo000Nooooo`?o00001Oooool2o`0000;ooooo0_l000001_oooooo
0000o`000?oooooo0000ooooo`go000000?oooooo`000?ooool01Ol000001?oooooo0000o`000?oo
ool3o`000003ooooool0003o000000Co00001?ooool00ol0003oooooo`00000Bo`000005ooooool0
003oooooo`000?ooool01ol000000ooooooo0000o`000007o`000003ooooool0003o000000;o0000
00?oooooo`000?l000001?l00006ooooo`;oo`001_ooool6o`000003ooooool0003o000000;o0000
00?oooooo`000?l000003ol000000ooooooo0000o`000007o`000003ooooool0003o000000go0000
1?ooool6o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000005o`000005
ooooool0003oooooo`000?ooool02Ol000001_oooooo0000oooooooooooo0000ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000Aooooo`007_ooool00ol0003oooooo`000005ooooo`;o00000_ooool2
o`000006ooooool0003o0000ooooool0003ooooo3Ol000000ooooooo0000o`000005o`000004oooo
ool0003o0000ooooo`[o00000oooool/o`000003ooooool0003o000000;o000000?oooooo`000?l0
00001Ol000001Ooooooo0000oooooooooooo000000;oo`0000Go0000oooooooooooo0000ooooo`07
o`000003ooooool0003o000000;o000000?oooooo`000?l000003ol000000ooooooo0000o`000007
o`000003ooooool0003o000000ko00000oooool:o`000004ooooool0003o0000ooooo`Oo000000?o
ooooo`000?ooool02ol000001_oooooo0000oooooooooooo0000ooooo`;o00000_ooool2o`0000Go
oooo0_l0000Aooooo`007_ooool00ol0003oooooo`000005ooooo`;o00000_ooool2o`000006oooo
ool0003o0000ooooool0003ooooo3Ol000000ooooooo0000o`000005o`000004ooooool0003o0000
ooooocWo000000?oooooo`000?l000003?l000000ooooooo0000o`000002ool000;o000000?ooooo
o`000?l000003?l000000ooooooo0000o`00000?o`000003ooooool0003o000002Go000000Cooooo
o`000?l0003ooooo1ol000000ooooooo0000ooooo`0;o`000006ooooool0003oooooooooool0003o
oooo0_l00002ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`007_ooool00ol0003ooooo
o`000005ooooo`;o00000_ooool2o`000006ooooool0003o0000ooooool0003ooooo3Ol000000ooo
oooo0000o`000005o`000004ooooool0003o0000oooood_o00000_oo001;o`000004ooooool0003o
0000ooooo`Oo000000?oooooo`000?ooool02ol000001_oooooo0000oooooooooooo0000ooooo`;o
00000_ooool2o`0000Gooooo00?o0000ooooooooool04?ooool001kooooo00?o0000ooooool00000
1Oooool2o`0000;ooooo0_l000001_oooooo0000o`000?oooooo0000ooooo`go000000?oooooo`00
0?l000001Ol000001?oooooo0000o`000?oooom;o`0000;oo`00Bol000001?oooooo0000o`000?oo
ool7o`000003ooooool0003ooooo00_o000000Koooooo`000?ooooooooooo`000?ooool2o`0000;o
oooo0_l00005ooooo`03o`000?oooooooooo013ooooo000Nooooo`03o`000?oooooo000000Gooooo
0_l00002ooooo`;o000000Koooooo`000?l0003oooooo`000?ooool=o`000003ooooool0003o0000
00Go000000?oooooo`000?l00000C?l00002ool004ko000000?oooooo`000?l000001Ol000000ooo
oooo0000ooooo`0;o`000003ooooool0003ooooo00;o000000?oooooo`000?l000000_ooool2o`00
00Gooooo00?o0000ooooooooool04?ooool001kooooo00?o0000ooooool000001Oooool2o`0000;o
oooo0_l000001_oooooo0000o`000?oooooo0000ooooo`go000000?oooooo`000?l00000E?l00002
ool005Ko000000?oooooo`000?ooool02ol000000ooooooo0000o`000002o`000003ooooool0003o
000000;ooooo0_l00005ooooo`03o`000?oooooooooo013ooooo000Nooooo`03o`000?oooooo0000
00Gooooo0_l00002ooooo`;o000000Koooooo`000?l0003oooooo`000?ooool=o`000003ooooool0
003o000005Co00000_oo001Fo`000003ooooool0003ooooo00_o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000002ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`007_ooool3
o`0000Gooooo0_l00002ooooo`;o000000Koooooo`000?l0003oooooo`000?ooool=o`000003oooo
ool0003o000005Co00000_oo001Fo`000003ooooool0003o000000_o000000?oooooo`000?l00000
0_l000000ooooooo0000o`000002ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`007_oo
ool00ol0003oooooo`000005ooooo`;o00000_ooool2o`000006ooooool0003o0000ooooool0003o
ooooI?l00002ool006Co000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o
00001Oooool00ol0003oooooooooo`0@ooooo`007_ooool00ol0003oooooo`000005ooooo`;o0000
0_ooool2o`000006ooooool0003o0000ooooool0003oooooI?l00002ool006Co000000?oooooo`00
0?l000000_l000000ooooooo0000o`000002ooooo`;o00001Oooool00ol0003oooooooooo`0@oooo
o`007_ooool00ol0003oooooo`000005ooooo`;o00000_ooool2o`000006ooooool0003o0000oooo
ool0003oooooI?l00002ool006Co000000?oooooo`000?l000000_l000000ooooooo0000o`000002
ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`007_ooool00ol0003oooooo`000005oooo
o`;o00000_ooool2o`000006ooooool0003o0000ooooool0003oooooI?l00002ool006Co000000?o
ooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00001Oooool00ol0003ooooooooo
o`0@ooooo`007_ooool01?l0003oooooo`000?l00004ooooo`;o00000_ooool2o`000006ooooool0
003o0000ooooool0003oooooI?l00002ool006Co000000?oooooo`000?l000000_l000000ooooooo
0000o`000002ooooo`;o00001?ooool2o`0001;ooooo000Nooooo`04o`000?oooooo0000o`0000Co
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00001Ro`0000;o
o`00I?l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o
00004_ooool001kooooo1?l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l00000H_l00002ool006Co000000?oooooo`000?l000000_l000000ooooooo0000
o`000002ooooo`;o00001?ooool2o`0001;ooooo000Nooooo`04o`000?ooooooooooo`0000Cooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00001Ro`0000;oo`00
I?l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l00004ooooo`03o`00
0?oooooooooo017ooooo000Nooooo`04o`000?ooooooooooo`0000Cooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`00001No`000004ooooool0003o0000o`0000;o
o`000ol000000ooooooo0000o`00001No`000003ooooool0003o000000;o000000?oooooo`000?l0
00000_ooool2o`0000Cooooo00?o0000ooooooooool04Oooool001kooooo00Co0000oooooooooooo
00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000005ko
000000Coooooo`000?l0003o00000_oo0003o`000003ooooool0003o000000Ko000000?oooooo`00
0?l00000EOl000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l00004oooo
o`03o`000?oooooooooo017ooooo000Nooooo`04o`000?ooooooooooo`0000Cooooo0_l00002oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00001@o`000003ooooool0003o0000
00[o00000_ooool00ol0003oooooo`000002ool00003o`000?oooooo000000;ooooo1ol000000ooo
oooo0000o`00001Eo`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`00
00Cooooo00?o0000ooooooooool04Oooool000_ooooo0_l00004ooooo`04o`000?oooooooooooooo
o`Go00001?ooool01?l0003oooooooooool00004ooooo`;o00000_ooool2o`000005ooooool0003o
0000o`000?ooool0Dol000000ooooooo0000o`00000:o`0000;ooooo00?o0000ooooool000000_oo
00000ol0003oooooo`000002ooooo`Oo000000?oooooo`000?l00000E_l000001Ooooooo0000o`00
0?l0003ooooo00;o00000_ooool2o`0000Cooooo00?o0000ooooooooool04Oooool000[ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`00
00Cooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`1Co`000003ooooool0003o
000000[o00000_ooool00ol0003oooooo`000002ool00003o`000?oooooo000000;ooooo1ol00000
0ooooooo0000o`00001Fo`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00001?oo
ool00ol0003oooooooooo`0Aooooo`002_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo0_l000001Ooooooo0000
o`000?l0003ooooo03Co000000?oooooo`000?l000007?l000000ooooooo0000o`000002o`000003
ooooool0003o000000Go00001?ooool01?l0003oo`00ool00?l00004ooooo`Oo000000?oooooo`00
0?l00000E_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Cooooo00?o0000
ooooooooool04Oooool000[ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03
ooooo`Co00001?ooool01?l0003oooooo`000?ooool2o`000005ooooool0003o0000o`000?ooool0
=?l000000ooooooo0000o`00000Ho`000005ooooool0003o0000o`000?ooool01?l000000ooooooo
0000o`000005o`0000Cooooo00Co0000ool00?oo003o00001?ooool7o`000003ooooool0003o0000
00?o000000Coooooo`000?l0003oooooCol000001Ooooooo0000o`000?l0003ooooo00;o00000_oo
ool2o`0000Cooooo00?o0000ooooooooool04Oooool000[ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001?ooool01?l0003o
ooooo`000?ooool2o`000005ooooool0003o0000o`000?ooool0=?l000000ooooooo0000o`00000H
o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000o`000005o`0000Cooooo00Co0000
ool00?oo003o00001?ooool7o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo
Col000002Ooooooo0000o`000?l0003oooooo`000?oooooo0000ooooo`02o`0000Cooooo00?o0000
ooooooooool04Oooool000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Co0000oooooooooooo00001?ooool01?l0003oooooo`000?ooool2o`000005
ooooool0003o0000o`000?ooool0=?l000000ooooooo0000o`00000<o`000003ooooool0003o0000
00;o000000?oooooo`000?l000001?l000000ooooooo0000o`000002ooooo`Co000000?oooooo`00
0?l000001?l00005ooooo`04o`000?oo003oo`00o`0000Gooooo1_l000000ooooooo0000o`000003
o`000004ooooool0003o0000ooooo`Ko000000?oooooo`000?l000000_l000000ooooooo0000o`00
000^o`000003ooooool0003o0000013o000000Woooooo`000?l0003o0000ooooool0003oooooo`00
0?ooool00_l00004ooooo`03o`000?oooooooooo017ooooo000;ooooo`;o00002Oooool3o`0000Go
oooo00Co0000oooooooooooo00001?ooool01?l0003oooooo`000?ooool2o`000005ooooool0003o
0000o`000?ooool03ol000000ooooooo0000o`00000Ro`000003ooooool0003ooooo00;o000000?o
ooooo`000?l000001ol000000ooooooo0000o`000002o`000003ooooool0003o000000Co000000?o
ooooo`000?l000000_ooool4o`000003ooooool0003o000000Co00001Oooool01?l0003oo`00ool0
0?l00005ooooo`Ko000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l00000
1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Oo000000Coooooo`000?l0003o
oooo8ol000000ooooooo0000o`00000@o`000009ooooool0003o0000o`000?oooooo0000ooooool0
003ooooo00;o00001?ooool00ol0003oooooooooo`0Aooooo`007_ooool01?l0003oooooooooool0
0004ooooo`04o`000?oooooo0000ooooo`;o000000Goooooo`000?l0003o0000ooooo`0?o`000003
ooooool0003o000000co000000?oooooo`000?l000004Ol000001Ooooooo0000ooooool0003ooooo
00;o000000?oooooo`000?l000001ol000000ooooooo0000o`000002o`000003ooooool0003o0000
00Co000000?oooooo`000?l000000_ooool4o`000003ooooool0003o000000Co00001_ooool2ool0
00Kooooo1_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000004o`00
0003ooooool0003o000000;o000000?oooooo`000?l000001ol000001?oooooo0000o`000?ooool9
o`000003ooooool0003o000001Oo000000?oooooo`000?l000004?l000002Ooooooo0000o`000?l0
003oooooo`000?oooooo0000ooooo`02o`0000Cooooo00?o0000ooooooooool04Oooool001kooooo
00Co0000oooooooooooo00001?ooool01?l0003oooooo`000?ooool2o`000005ooooool0003o0000
o`000?ooool03ol000000ooooooo0000o`00000<o`000003ooooool0003o0000017o000000Gooooo
o`000?oooooo0000ooooo`02o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_l0
00000ooooooo0000o`000004o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000o`00
0004o`0000Kooooo0_oo0006ooooo`Ko000000?oooooo`000?l000000_l00002ooooo`;o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000002o`000003ooooool0003o000000Oo000000Co
ooooo`000?l0003ooooo0ol000000ooooooo0000o`000003o`000003ooooool0003o000000Oo0000
00?oooooo`000?l000003Ol000000ooooooo0000o`00000@o`000009ooooool0003o0000o`000?oo
oooo0000ooooool0003ooooo00;o00001?ooool00ol0003oooooooooo`0Aooooo`007_ooool01?l0
003oooooooooool00004ooooo`04o`000?oooooo0000ooooo`;o000000Goooooo`000?l0003o0000
ooooo`0?o`000003ooooool0003o000000co000000?oooooo`000?l000004Ol000001Ooooooo0000
ooooool0003ooooo00;o000000?oooooo`000?l000001ol000001_oooooo0000o`000?oooooo0000
ooooo`Ko000000?oooooo`000?l000000_ooool4o`000003ooooool0003o000000;o000000?ooooo
o`000?ooool01Oooool2ool000Kooooo00?o0000ooooool000000ol000000ooooooo0000o`000002
o`0000;ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003ooooo00;o000000?ooooo
o`000?l000001ol000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000?o000000?o
ooooo`000?l000001ol000000ooooooo0000o`00000=o`000003ooooool0003o0000013o000000Wo
ooooo`000?l0003o0000ooooool0003oooooo`000?ooool00_l00004ooooo`03o`000?oooooooooo
017ooooo000Nooooo`;o000000?oooooo`000?ooool00oooool01?l0003oooooo`000?ooool2o`00
0005ooooool0003o0000o`000?ooool03ol000000ooooooo0000o`00000<o`000003ooooool0003o
0000017o000000Goooooo`000?oooooo0000ooooo`02o`000005ooooool0003o0000o`000?ooool0
0ol000001?oooooo0000ooooool00002ooooo`03o`000?oooooo000000Go000000?oooooo`000?l0
00000_ooool4o`000003ooooool0003o000000;o000000?oooooo`000?ooool01Oooool2ool000Ko
oooo00?o0000ooooool000000ol000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo
0000o`000004o`000008ooooool0003oooooooooool0003oooooo`000?ooool3o`000005ooooool0
003o0000o`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00Go000000?oooooo`000?l0
00001ol000000ooooooo0000o`00000=o`000003ooooool0003o0000013o000000Woooooo`000?l0
003o0000ooooool0003oooooo`000?ooool00_l00004ooooo`03o`000?oooooooooo017ooooo000N
ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000ooooool0003ooooo0_l000001Ooooooo0000
o`000?l0003ooooo00oo000000?oooooo`000?l000003?l000000ooooooo0000o`00000Ao`000005
ooooool0003oooooo`000?ooool00_l000001Ooooooo0000o`000?l0003ooooo00?o000000Cooooo
o`000?oooooo00000_ooool00ol0003oooooo`000005o`0000;ooooo00?o0000ooooooooool01?l0
00001ooooooo0000o`000?oooooo0000ooooool000001_ooool2ool000Kooooo00Co0000ooooool0
003ooooo0_l000000ooooooo0000o`000002o`0000;ooooo00?o0000ooooooooool01_l000002?oo
oooo0000oooooooooooo0000ooooool0003ooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o
000000Goooooo`000?oooooo0000ooooo`05o`000003ooooool0003o000000Oo000000Coooooo`00
0?l0003ooooo3?l000000ooooooo0000o`00000@o`000007ooooool0003o0000o`000?oooooo0000
ooooo`02o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool04Oooool001kooooo00Co
0000oooooooooooo00001?ooool01?l0003oooooo`000?ooool2o`000005ooooool0003o0000o`00
0?ooool03ol000000ooooooo0000o`000009o`000004ooooool0003o0000ooooo`Oo000000?ooooo
o`000?l000002Ol000001Ooooooo0000ooooool0003ooooo00;o000000Goooooo`000?l0003o0000
ooooo`03o`000004ooooool0003oooooo`0000;ooooo00Go0000ooooool0003o0000ooooo`03o`00
00;ooooo00?o0000ooooooooool01?l000001ooooooo0000o`000?oooooo0000ooooool000001_oo
ool2ool000Kooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000o`000002o`0000;ooooo
00?o0000ooooooooool00ol000001Ooooooo0000o`000?oooooo000000;ooooo00Co0000ooooool0
003ooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o000000Goooooo`000?oooooo0000oooo
o`03o`000003ooooool0003ooooo00Wo000000Coooooo`000?l0003ooooo0ol000000ooooooo0000
o`000006o`000003ooooool0003o000000;o000000?oooooo`000?l000002ol000001ooooooo0000
o`000?l0003oooooo`000?ooool00_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo
017ooooo000Nooooo`04o`000?ooooooooooo`0000Cooooo00Co0000ooooool0003ooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00oo000000?oooooo`000?l000002Ol000001?oooooo0000o`00
0?ooool3o`000005ooooool0003o0000o`000?ooool02ol000001Ooooooo0000ooooool0003ooooo
00;o000000Goooooo`000?l0003o0000ooooo`03o`000004ooooool0003oooooo`0000;ooooo00Co
0000ooooool0003o00000oooool01?l0003oooooooooool00002ooooo`?o00000oooool00ol0003o
ooooo`000008ooooo`;oo`002?ooool00ol0003oooooo`000003ooooo`?o00000_ooool01?l0003o
ooooooooool00003ooooo`;o000000Soooooo`000?ooooooooooo`000?oooooo0000ooooo`?o0000
00Goooooo`000?l0003o0000ooooo`02o`000005ooooool0003oooooo`000?ooool00ol000000ooo
oooo0000ooooo`04o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0ol00000
0ooooooo0000o`000006o`000003ooooool0003o000000;o000000?oooooo`000?l000002ol00000
1ooooooo0000o`000?l0003oooooo`000?ooool00_l000000ooooooo0000ooooo`03ooooo`03o`00
0?oooooooooo017ooooo000Nooooo`04o`000?ooooooooooo`0000Cooooo00Co0000ooooool0003o
oooo0_l000001Ooooooo0000o`000?l0003ooooo00oo000000?oooooo`000?l000002Ol000002?oo
oooo0000o`000?oooooo0000ooooool0003ooooo0ol000000ooooooo0000o`000003o`000003oooo
ool0003ooooo00?o000000Goooooo`000?oooooo0000ooooo`02o`000005ooooool0003oooooo`00
0?ooool00ol000001?oooooo0000ooooool00002ooooo`04o`000?oooooo0000o`0000?ooooo00Co
0000oooooooooooo00000_ooool3o`0000?ooooo00?o0000ooooool000002?ooool2ool000Sooooo
00?o0000ooooool000000oooool3o`0000;ooooo00Co0000oooooooooooo00000oooool2o`000008
ooooool0003oooooooooool0003oooooo`000?ooool3o`000005ooooool0003oooooo`000?ooool0
0_l000001Ooooooo0000ooooool0003ooooo00?o000000?oooooo`000?ooool01?l000000ooooooo
0000o`000002o`000004ooooool0003oooooooooo`?o000000?oooooo`000?l000001_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000Wo000000?oooooo`000?ooool00ol000000ooo
oooo0000ooooo`02o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool04Oooool001ko
oooo00Co0000oooooooooooo00001?ooool01?l0003oooooo`000?ooool2o`000005ooooool0003o
0000o`000?ooool03ol000000ooooooo0000o`000009o`000008ooooool0003o0000ooooool0003o
ooooo`000?ooool3o`000003ooooool0003o000000?o000000_oooooo`000?oooooo0000ooooool0
003oooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo0ol000001?oooooo
0000ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_oo
ool3o`0000?ooooo00?o0000ooooool000002?ooool2ool000Sooooo00?o0000ooooool000000ooo
ool3o`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04
o`000?oooooo0000ooooo`?o00000oooool03ol0003oooooo`000?l0003oooooo`000?oooooo0000
ooooool0003oooooo`000?oooooo0000ooooo`04o`000003ooooool0003o000000;o000000Cooooo
o`000?oooooooooo0ol000000ooooooo0000o`000006o`000003ooooool0003o000000;o000000?o
ooooo`000?l000002Ol000000ooooooo0000ooooo`03o`000003ooooool0003ooooo00;o000000?o
ooooo`000?ooool00oooool00ol0003oooooooooo`0Aooooo`007_ooool01?l0003oooooooooool0
0004ooooo`04o`000?oooooo0000ooooo`?o000000Coooooo`000?l0003ooooo3ol000000ooooooo
0000o`000009o`000008ooooool0003o0000ooooool0003oooooo`000?ooool3o`000003ooooool0
003o000000;o00000_ooool02_l0003oooooo`000?oooooo0000ooooool0003oooooo`000?ooool2
o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooooooool2o`0000?o
oooo00?o0000ooooool000002?ooool2ool000Sooooo00?o0000ooooool000000oooool2o`0000?o
oooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`00000:ooooool0003oooooo`000?oo
oooo0000ooooool0003oooooo`0000;ooooo0ol000000ooooooo0000o`000002o`000004ooooool0
003oooooooooo`?o000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000Wo000000?oooooo`000?ooool00_l000001?oooooo0000o`000?ooool2o`000003
ooooool0003ooooo00?ooooo00?o0000ooooooooool04Oooool001kooooo0_l000000ooooooo0000
ooooo`03ooooo`04o`000?oooooo0000ooooo`?o000000Coooooo`000?l0003ooooo3ol000000ooo
oooo0000o`000009o`000008ooooool0003o0000ooooool0003oooooo`000?ooool3o`000004oooo
ool0003o0000o`0000?ooooo00?o0000ooooooooool01Oooool01_l0003oooooo`000?l0003ooooo
o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000oooooooo
ool02?ooool2ool000[ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`06o`000?oo
ooooooooooooool0003ooooo0_l000000ooooooo0000ooooo`06ooooo`04o`000?oooooooooooooo
o`;o000000?oooooo`000?l000000_l000001?oooooo0000ooooooooool3o`000003ooooool0003o
000000Ko000000?oooooo`000?l000000_l000000ooooooo0000o`000009o`000003ooooool0003o
oooo00;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oo
oooooooo017ooooo000Nooooo`04o`000?ooooooooooo`0000Cooooo00Co0000ooooool0003ooooo
0ol000001?oooooo0000o`000?ooool?o`000003ooooool0003o000000Wo000000Soooooo`000?l0
003oooooo`000?oooooo0000ooooo`?o000000Coooooo`000?l0003o00000oooool00ol0003ooooo
ooooo`05ooooo`06o`000?oooooo0000o`000?oooooo00000oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02?ooool2ool000[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00005ooooo`06o`000?ooooooooooooooool0003ooooo0_l000000ooooooo0000ooooo`06
ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000oooo
ooooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l000000ooooooo0000
o`000009o`000003ooooool0003ooooo00;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000ooooo`03ooooo`03o`000?oooooooooo017ooooo000Nooooo`04o`000?ooooooooooo`0000Co
oooo00Co0000ooooool0003ooooo0ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o
000000So000000?oooooo`000?l000002Ol000002?oooooo0000o`000?oooooo0000ooooool0003o
oooo0ol000001?oooooo0000o`000?l0000=ooooo`;o000000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00gooooo0_oo000?ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00Ko0000oooooooo
ooooooooo`000?ooool2o`0000gooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o
ooooooooo`?o000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`000003ooooool0
003o000000Wo000000?oooooo`000?ooool00_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003ooooo00?ooooo00?o0000ooooooooool04Oooool001kooooo00Co0000oooooooooooo0000
1?ooool01?l0003oooooo`000?ooool3o`000004ooooool0003o0000ooooo`Co000000?oooooo`00
0?l000002?l000001?oooooo0000o`000?ooool8o`000008ooooool0003o0000ooooool0003ooooo
o`000?ooool3o`000004ooooool0003o0000o`0000gooooo0_l000000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00gooooo0_oo000?ooooo`03o`000?oooooooooo00Sooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooooooool0003o
oooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000ooooooooool3o`00
0003ooooool0003o000000?o000000Coooooo`000?l0003ooooo1?l000001Ooooooo0000o`000?l0
003ooooo00Oo000000?oooooo`000?ooool00_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003ooooo00?ooooo00?o0000ooooooooool04Oooool001kooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?oooooo0000o`000?ooool00_l000001?oooooo0000o`000?ooool4o`00
0003ooooool0003o000000So000000Coooooo`000?l0003ooooo2?l000002?oooooo0000o`000?oo
oooo0000ooooool0003ooooo0ol000001?oooooo0000o`000?l0000>ooooo`03o`000?oooooo0000
00?ooooo00?o0000ooooooooool09?ooool2ool002Kooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000kooooo0_l000000ooooooo0000o`000002o`000004ooooool0003oooooooooo`?o0000
00?oooooo`000?l000000ol000001?oooooo0000o`000?ooool4o`000005ooooool0003o0000o`00
0?ooool01Ol000001Ooooooo0000ooooool0003ooooo00;o000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo017ooooo000Nooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003oooooo`000?l0003ooooo00;o000000Koooooo`000?l0003o
ooooo`000?ooool2o`000003ooooool0003o000000Ko000000?oooooo`000?ooool00_l000000ooo
oooo0000o`000006o`000005ooooool0003o0000ooooool000000oooool3o`000003ooooool0003o
000000oooooo00?o0000ooooooooool0:_ooool2ool002cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooo`000003o`0000Cooooo0ol000000ooooooo0000o`000003o`000004ooooool0003o
0000ooooo`Co000000Goooooo`000?l0003o0000ooooo`05o`000005ooooool0003oooooo`000?oo
ool00_l000001?oooooo0000o`000?ooool2o`000003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool04_ooool001kooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo0000
o`000?ooool00_l000001_oooooo0000o`000?oooooo0000ooooo`;o000000?oooooo`000?l00000
0ol000001_oooooo0000o`000?oooooo0000ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`;o000000Goooooo`000?l0003oooooo`000003ooooo`?o000000?oooooo`000?l000003oooool0
0ol0003oooooooooo`0Zooooo`;oo`00;?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
000000?o00001?ooool3o`000003ooooool0003o000000;ooooo00Go0000ooooool0003o0000oooo
o`02o`000003ooooool0003ooooo00;o00000_ooool5o`000005ooooool0003oooooo`000?ooool0
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool04_ooool001kooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo0000o`00
0?ooool00_l000001_oooooo0000o`000?oooooo0000ooooo`;o000000?oooooo`000?l000000ol0
00001_oooooo0000o`000?oooooo0000ooooo`;o000000Goooooo`000?l0003oooooo`000002oooo
o`;o000000Goooooo`000?l0003oooooo`000003ooooo`?o000000?oooooo`000?l00000??ooool2
ool003cooooo00?o0000ooooool000000ol00004ooooo`?o000000?oooooo`000?l000000_ooool0
1Ol0003oooooo`000?l0003ooooo00;o000000?oooooo`000?ooool00_l00002ooooo`Go000000Go
ooooo`000?oooooo0000ooooo`02o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`0Booooo`007_ooool2o`0000;ooooo00Ko0000oooooooooooo
ooooo`000?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?ooool00_l00000
1ooooooo0000o`000?l0003oooooo`000?ooool00_l000000ooooooo0000ooooo`02o`000005oooo
ool0003o0000ooooool000000_ooool2o`000005ooooool0003o0000ooooool000000oooool3o`00
0003ooooool0003o000003cooooo0_oo000looooo`03o`000?oooooo000000?o00001?ooool3o`00
0003ooooool0003o000000;ooooo00Go0000ooooool0003o0000ooooo`02o`000003ooooool0003o
oooo00;o00000_ooool5o`000005ooooool0003oooooo`000?ooool00_l000001?oooooo0000o`00
0?ooool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool04_ooool001kooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?oooooo0000o`000?ooool00_l000001_oooooo
0000o`000?oooooo0000ooooo`;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o0000
00?oooooo`000?ooool00_l00004ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003ooooo
ooooo`03ooooo`?o000000?oooooo`000?l00000??ooool2ool003cooooo00?o0000ooooool00000
0ol00005ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`02ooooo`;o0000
00?oooooo`000?ooool00_l00002ooooo`Go000000Goooooo`000?oooooo0000ooooo`02o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0Boooo
o`007_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooool0003o0000ooooo`02
o`000006ooooool0003o0000ooooool0003ooooo0_l000001ooooooo0000ooooool0003oooooo`00
0?ooool00_l00003ooooo`;o00001?ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000oooo
ooooool01?ooool2o`000003ooooool0003ooooo03cooooo0_oo000nooooo`?o00001_ooool00ol0
003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo0_l00002oooo
o`;o000000Soooooo`000?l0003oooooo`000?oooooo0000ooooo`;o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo01;ooooo000Nooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003oooooo`000?l0003ooooo00;o000000Koooooo`00
0?l0003oooooo`000?ooool2o`000007ooooool0003oooooo`000?oooooo0000ooooo`02o`0000?o
oooo0_l00004ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03_ooooo0_oo000nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_l00002ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`;o00000_ooool2o`000008
ooooool0003o0000ooooool0003oooooo`000?ooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0Booooo`007_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooool0003o0000ooooo`02o`000006ooooool0003o0000oooo
ool0003ooooo0_l000001_oooooo0000ooooool0003oooooo`0000;ooooo00Co0000oooooooooooo
oooo0_l00004ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`15ooooo`;o
o`00Aoooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo00?o0000oooooooo
ool04_ooool000_ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003oooooo`000?l0003ooooo00;o000000Koooooo`00
0?l0003oooooo`000?ooool2o`000006ooooool0003oooooo`000?oooooo00000_ooool01?l0003o
ooooooooooooool2o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`15
ooooo`;oo`00Aoooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_oo
ool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`06o`000?oooooo0000ooooool0
003ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00Co0000oooooooooooo00005?oo
ool000[ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003oooooo`000?l0003ooooo00;o000000Koooooo`000?l0
003oooooo`000?ooool2o`000006ooooool0003oooooo`000?oooooo00000_ooool01?l0003ooooo
ooooooooool2o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`15oooo
o`;oo`00Aoooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`06o`000?oooooo0000ooooool0003o
oooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00Co0000oooooooooooo00005?ooool0
00[ooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo0ol000000ooooooo0000ooooo`02
ooooo`05o`000?oooooo0000o`000?ooool00_l000001ooooooo0000o`000?oooooo0000ooooool0
00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooooooo0_l00004
ooooo`04o`000?ooooooooooo`0004_ooooo0_oo001;ooooo`04o`000?ooooooooooo`0000Cooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool01_l0003oooooo`000?oooooo0000
ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`04o`000?ooooooooooo`0001Cooooo
000:ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001Oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooool0003o0000ooooo`02o`000007ooooool0003o
0000ooooool0003oooooo`000002ooooo`05o`000?oooooo0000ooooool000000_ooool01?l0003o
ooooooooooooool2o`0000Cooooo00Co0000oooooooooooo0000Boooool2ool004_ooooo00Co0000
oooooooooooo00001?ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`06o`00
0?oooooo0000ooooool0003ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00Co0000
oooooooooooo00005?ooool000[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
0005ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooo`000?l00002ooooo`08
o`000?oooooo0000o`000?oooooo0000ooooool00004ooooo`03o`000?oooooo000000;ooooo00Go
0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0004_ooooo0_oo001;ooooo`04
o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`;o00001?ooool0
1?l0003oooooo`000?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool01?l0003ooooo
ooooool0000Dooooo`002_ooool01?l0003oooooooooool00009ooooo`;o00001Oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000ooooool0003o00000_ooool01_l0003oooooo`000?l0
003oooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0004_ooooo0_oo001;ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooool0003o0000
ooooo`02o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo00005?ooool000_ooooo
0_l0000;ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?oooooo0000o`0000;ooooo00Ko0000ooooool0003o0000ooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`;oo`00
C_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`05ooooo`05o`000?oooooo0000o`000?ooool00_l000000ooooooo0000o`000002oooo
o`04o`000?ooooooooooo`0001Cooooo000Nooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooo`000?l00002ooooo`06o`000?ooooooooooo`000?oooooo00002oooool00ol0003o
ooooooooo`1Fooooo`;oo`00F?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000;o
oooo0_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`0001Cooooo000Nooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooo`000?l00002ooooo`04o`000?oooooo
ooooo`0000gooooo00?o0000ooooooooool0E_ooool2ool005Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo0000
5?ooool001kooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo0000o`0000;o
oooo00Co0000oooooooooooo0000I_ooool2ool006Kooooo00?o0000ooooooooool00_l000000ooo
oooo0000o`000002ooooo`04o`000?ooooooooooo`0001Cooooo000Nooooo`;o00000_ooool01_l0
003ooooooooooooooooo0000ooooo`;o00000_ooool01?l0003oooooooooool0001Vooooo`;oo`00
I_ooool00ol0003oooooooooo`02o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo
00005?ooool001kooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo0000o`00
00;ooooo00Co0000oooooooooooo0000I_ooool2ool006Kooooo00?o0000ooooooooool00_l00000
0ooooooo0000o`000002ooooo`04o`000?ooooooooooo`0001Cooooo000Nooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooo0000
I_ooool2ool006Kooooo00?o0000ooooooooool00_l000000ooooooo0000o`000002ooooo`04o`00
0?ooooooooooo`0001Cooooo000Nooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`02o`0000;ooooo00Co0000oooooooooooo0000I_ooool2ool006Kooooo00?o0000oooo
ooooool00_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`0001Cooooo000Noooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000
oooooooooooo0000I_ooool2ool006Kooooo00?o0000ooooooooool00_l000000ooooooo0000o`00
0002ooooo`04o`000?ooooooooooo`0001Cooooo000Nooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooo0000I_ooool2ool006Ko
oooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo00Co0000oooooooooooo00005?ooool0
01kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool0
0ol0003oooooooooo`1Wooooo`;oo`00JOooool00ol0003oooooooooo`02o`0000;ooooo00Co0000
oooooooooooo00005?ooool001kooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l0
0002ooooo`03o`000?oooooooooo06Oooooo0_oo001Yooooo`03o`000?oooooooooo00;o00000_oo
ool01?l0003oooooooooool0000Dooooo`007_ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo06Oooooo0_oo001Yooooo`03o`00
0?oooooooooo00;o00000_ooool01?l0003oooooooooool0000Dooooo`007_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo06Oo
oooo0_oo001Yooooo`03o`000?oooooooooo00;o00000_ooool01?l0003oooooooooool0000Doooo
o`007_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_l00002oooo
o`03o`000?oooooooooo06Oooooo0_oo001Yooooo`03o`000?oooooooooo00;o00000_ooool01?l0
003oooooooooool0000Dooooo`007_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_l00002ooooo`03o`000?oooooooooo06Oooooo0_oo001Yooooo`03o`000?oooooo
oooo00;o00000_ooool01?l0003oooooooooool0000Dooooo`007_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_l0001/ooooo`;oo`00K?ooool2o`0000;ooooo00Co
0000oooooooooooo00005?ooool001kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00;o0000K?ooool2ool006cooooo0_l00002ooooo`04o`000?ooooooooooo`0001Co
oooo000Nooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0006co
oooo0_oo001/ooooo`;o00000_ooool01?l0003oooooooooool0000Dooooo`007_ooool2o`0000;o
oooo00Co0000oooooooooooo00000_ooool2o`0006cooooo0_oo001/ooooo`;o00000_ooool01?l0
003oooooooooool0000Dooooo`007_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_l0001/ooooo`;oo`00K?ooool2o`0000;ooooo00Co0000oooooooooooo00005?oo
ool001kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o0000K?oo
ool2ool006cooooo0_l00002ooooo`04o`000?ooooooooooo`0001Cooooo000Nooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`02o`0006cooooo0_oo001/ooooo`;o0000
0_ooool01?l0003oooooooooool0000Dooooo`007_ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00_l0001/ooooo`;oo`00K?ooool2o`0000;ooooo00Co0000oooooooo
oooo00005?ooool000_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0006cooooo0_oo001/oooo
o`;o00000_ooool01?l0003oooooooooool0000Dooooo`002_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool00_l0001/ooooo`;oo`00K?ooool2o`0000;ooooo00Co0000oooooooooooo
00005?ooool000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Cooooo0ol000001Ooooooo0000oooooooooooo000000;ooooo0_l0001/ooooo`;oo`00K?ooool2
o`0000;ooooo00Co0000oooooooooooo00005?ooool000[ooooo00Co0000oooooooooooo00001ooo
ool4o`0000Gooooo00Co0000oooooooooooooooo0_l000001?oooooo0000ooooooooool2o`0006co
oooo0_oo001/ooooo`;o00000_ooool01?l0003oooooo`000?l0000Dooooo`002_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo0_l00000
1?oooooo0000ooooooooool2o`0006cooooo0_oo001/ooooo`;o00000_ooool01?l0003oooooo`00
0?l0000Dooooo`002_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooooooo0_l000001Ooooooo0000oooooooooooo000006gooooo0_oo001]oooo
o`05o`000?ooooooooooo`000?ooool00_l0000Dooooo`002oooool2o`0000[ooooo0_l00005oooo
o`04o`000?ooooooooooooooo`;o000000?oooooo`000?ooool0Koooool2ool0073ooooo00Co0000
ooooool0003o00005?ooool001kooooo00Co0000oooooooooooooooo0_l000000ooooooo0000oooo
o`1_ooooo`;oo`00L?ooool01?l0003oooooo`000?l0000Dooooo`007_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo0000073ooooo0_oo001`ooooo`03o`000?oooooo000001Gooooo000N
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000L?ooool2ool0073ooooo00?o0000
ooooool000005Oooool001kooooo0_l00003ooooo`03o`000?oooooo0000073ooooo0_oo001`oooo
o`03o`000?oooooo000001Gooooo000Nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
0000L?ooool2ool0073ooooo00?o0000ooooool000005Oooool001kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`00001`ooooo`;oo`00L?ooool00ol0003oooooo`00000Eooooo`007_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000073ooooo0_oo001`ooooo`03o`000?oo
oooo000001Gooooo000Nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000L?ooool2
ool0073ooooo00?o0000ooooool000005Oooool001kooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`00001`ooooo`;oo`00L?ooool00ol0003oooooo`00000Eooooo`007_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooo0000073ooooo0_oo001`ooooo`03o`000?oooooo000001Go
oooo000Nooooo`;o00000oooool00ol0003oooooo`00001`ooooo`;oo`00L?ooool00ol0003ooooo
o`00000Eooooo`007_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000077ooooo00?o
o`00ooooooooool0K_ooool00ol0003oooooo`00000Eooooo`007_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo0000077ooooo00?oo`00ooooooooool0K_ooool00ol0003oooooo`00000E
ooooo`007_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000077ooooo00?oo`00oooo
ooooool0K_ooool00ol0003oooooo`00000Eooooo`007_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo0000077ooooo00?oo`00ooooooooool0K_ooool00ol0003oooooo`00000Eooooo`00
7_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000077ooooo00?oo`00ooooooooool0
K_ooool00ol0003oooooo`00000Eooooo`007_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo0000077ooooo00?oo`00ooooooooool0K_ooool00ol0003oooooo`00000Eooooo`007_ooool2
o`0000?ooooo00?o0000ooooool00000LOooool00ooo003oooooooooo`1^ooooo`03o`000?oooooo
000001Gooooo000Nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000LOooool00ooo
003oooooooooo`1^ooooo`03o`000?oooooo000001Gooooo000Nooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool00000LOooool00ooo003oooooooooo`1^ooooo`03o`000?oooooo000001Go
oooo000Nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000LOooool00ooo003ooooo
ooooo`1^ooooo`03o`000?oooooo000001Gooooo000Nooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool00000LOooool00ooo003oooooooooo`1^ooooo`03o`000?oooooo000001Gooooo000;
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo0000077ooooo00?oo`00ooooooooool0K_ooool00ol0003oooooo`00000E
ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000077ooooo00?oo`00ooooooooool0K_oo
ool00ol0003oooooo`00000Eooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000077ooooo
00?oo`00ooooooooool0K_ooool00ol0003oooooo`00000Eooooo`002_ooool01?l0003ooooooooo
ool00008ooooo`?o00001Oooool3o`0000;ooooo00?o0000ooooool00000LOooool00ooo003ooooo
ooooo`1^ooooo`03o`000?oooooo000001Gooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
0000LOooool00ooo003oooooooooo`1^ooooo`03o`000?oooooo000001Gooooo000:ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool00000LOooool00ooo003oooooooooo`1^ooooo`03o`000?oooooo0000
01Gooooo000;ooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`00001aooooo`03ool00?oooooooooo06kooooo00?o0000ooooool000005Oooool001kooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`00001aooooo`03ool00?oooooooooo06kooooo
00?o0000ooooool000005Oooool001kooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
001aooooo`03ool00?oooooooooo06kooooo00?o0000ooooool000005Oooool001kooooo00?o0000
ooooooooool00_ooool2o`0007;ooooo00?oo`00ooooooooool0Koooool2o`0001Gooooo000Noooo
o`;o00000oooool2o`0007;ooooo00?oo`00ooooooooool0Koooool2o`0001Gooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l0001booooo`03ool00?oooooooooo06oooooo0_l0000Eooooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o0000L_ooool00ooo003oooooooooo`1_ooooo`;o0000
5Oooool001kooooo00?o0000ooooooooool00_ooool2o`0007;ooooo00?oo`00ooooooooool0Kooo
ool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0001booooo`03ool00?oooooo
oooo06oooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000L_ooool00ooo
003oooooooooo`1_ooooo`;o00005Oooool001kooooo00?o0000ooooooooool00_ooool2o`0007;o
oooo00?oo`00ooooooooool0Koooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00;ooooo
0_l0001booooo`03ool00?oooooooooo06oooooo0_l0000Eooooo`007_ooool2o`0000?ooooo0_l0
001booooo`03ool00?oooooooooo06oooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`02
ooooo`;o0000L_ooool00ooo003oooooooooo`1_ooooo`;o00005Oooool001kooooo00?o0000oooo
ooooool00_ooool2o`0007;ooooo00?oo`00ooooooooool0Koooool2o`0001Gooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l0001booooo`03ool00?oooooooooo06oooooo0_l0000Eooooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o0000L_ooool00ooo003oooooooooo`1_ooooo`;o0000
5Oooool001kooooo00?o0000ooooooooool00_ooool2o`0007;ooooo00?oo`00ooooooooool0Kooo
ool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0001booooo`03ool00?oooooo
oooo06oooooo0_l0000Eooooo`007_ooool2o`0000?ooooo0_l0001booooo`03ool00?oooooooooo
06oooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000L_ooool00ooo003o
ooooooooo`1_ooooo`;o00005Oooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1`ooooo`03ool00?oooooooooo06oooooo00?o0000ooooooooool05?ooool001kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1`ooooo`03ool00?oooooooooo06oooooo00?o
0000ooooooooool05?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1`
ooooo`03ool00?oooooooooo06oooooo00?o0000ooooooooool05?ooool001Kooooo0ol00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L?ooool00ooo003oooooooooo`1_oooo
o`03o`000?oooooooooo01Cooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1`ooooo`03ool00?oooooooooo06oooooo00?o0000oooooooo
ool05?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo073ooooo00?oo`00ooooooooool0Koooool00ol0003oooooooooo`0Dooooo`005ooo
ool00ol0003oooooooooo`04ooooo`?o00000oooool00ol0003oooooooooo`1`ooooo`03ool00?oo
oooooooo06oooooo00?o0000ooooooooool05?ooool001Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooo`005_ooool2o`0000Kooooo00?o0000ooooooooool0ooooool001Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00I?ooool3o`00057ooooo0ol0001Uooooo`00IOooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo06Cooooo000jooooo`?o00001?ooool3o`0000;ooooo
1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o
00000_ooool3o`0000Cooooo0ol00003ooooo`Co00000_ooool4o`0000Oooooo1Ol000001Ooooooo
0000o`000?l0003ooooo00;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`00
0?l000001?l00002ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool01oooool3o`00
00Gooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o00001?ooool2
o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o000002cooooo000koooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooo
ooooool0003oooooo`0000Kooooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002gooooo000kooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool5o`0000;ooooo0ol00002ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000009
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooooooo
ool0003oooooo`0000Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0[ooooo`00>oooool3o`00
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0:ooooo`;o00000oooool01?l0003ooooooooo
ool00002ooooo`;o00000oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000002Oooool3o`0000?ooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo
00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0[ooooo`00>oooool01?l0003oooooooooool00002ooooo`?o00000_ooool3
o`0000?ooooo1?l00002ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`Co00000_ooool2
o`000003ooooool0003o000000;ooooo0ol00003ooooo`;o00001?ooool3o`0000[ooooo00Co0000
oooooooooooooooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Co
ooooo`000?l0003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`03o`00
0?oooooooooo00;ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co
00000_ooool3o`0000Cooooo0ol00002ooooo`Co0000;_ooool003_ooooo00Co0000oooooooooooo
00005?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0001cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool03oooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo043ooooo000joooo
o`Co00002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0ol0000Koooo
o`;o00002?ooool5o`0000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00kooooo1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0>Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.515429, -0.0816802, \
0.00341187, 0.00671628}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00219232 0.0280925 0.561849 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.24304 -0.0125 -9 -9 ]
[.24304 -0.0125 9 0 ]
[.46227 -0.0125 -9 -9 ]
[.46227 -0.0125 9 0 ]
[.68151 -0.0125 -9 -9 ]
[.68151 -0.0125 9 0 ]
[.90074 -0.0125 -9 -9 ]
[.90074 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .14046 -18 -4.5 ]
[-0.0125 .14046 0 4.5 ]
[-0.0125 .25283 -18 -4.5 ]
[-0.0125 .25283 0 4.5 ]
[-0.0125 .3652 -18 -4.5 ]
[-0.0125 .3652 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -84 0 ]
[.5 .63053 84 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.24304 0 m
.24304 .00625 L
s
[(100)] .24304 -0.0125 0 1 Mshowa
.46227 0 m
.46227 .00625 L
s
[(200)] .46227 -0.0125 0 1 Mshowa
.68151 0 m
.68151 .00625 L
s
[(300)] .68151 -0.0125 0 1 Mshowa
.90074 0 m
.90074 .00625 L
s
[(400)] .90074 -0.0125 0 1 Mshowa
.125 Mabswid
.06766 0 m
.06766 .00375 L
s
.1115 0 m
.1115 .00375 L
s
.15535 0 m
.15535 .00375 L
s
.1992 0 m
.1992 .00375 L
s
.28689 0 m
.28689 .00375 L
s
.33073 0 m
.33073 .00375 L
s
.37458 0 m
.37458 .00375 L
s
.41843 0 m
.41843 .00375 L
s
.50612 0 m
.50612 .00375 L
s
.54997 0 m
.54997 .00375 L
s
.59381 0 m
.59381 .00375 L
s
.63766 0 m
.63766 .00375 L
s
.72535 0 m
.72535 .00375 L
s
.7692 0 m
.7692 .00375 L
s
.81305 0 m
.81305 .00375 L
s
.85689 0 m
.85689 .00375 L
s
.94459 0 m
.94459 .00375 L
s
.98843 0 m
.98843 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .14046 m
.00625 .14046 L
s
[(0.2)] -0.0125 .14046 1 0 Mshowa
0 .25283 m
.00625 .25283 L
s
[(0.4)] -0.0125 .25283 1 0 Mshowa
0 .3652 m
.00625 .3652 L
s
[(0.6)] -0.0125 .3652 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(0.8)] -0.0125 .47757 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(1)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.24304 .61178 m
.24304 .61803 L
s
.46227 .61178 m
.46227 .61803 L
s
.68151 .61178 m
.68151 .61803 L
s
.90074 .61178 m
.90074 .61803 L
s
.125 Mabswid
.06766 .61428 m
.06766 .61803 L
s
.1115 .61428 m
.1115 .61803 L
s
.15535 .61428 m
.15535 .61803 L
s
.1992 .61428 m
.1992 .61803 L
s
.28689 .61428 m
.28689 .61803 L
s
.33073 .61428 m
.33073 .61803 L
s
.37458 .61428 m
.37458 .61803 L
s
.41843 .61428 m
.41843 .61803 L
s
.50612 .61428 m
.50612 .61803 L
s
.54997 .61428 m
.54997 .61803 L
s
.59381 .61428 m
.59381 .61803 L
s
.63766 .61428 m
.63766 .61803 L
s
.72535 .61428 m
.72535 .61803 L
s
.7692 .61428 m
.7692 .61803 L
s
.81305 .61428 m
.81305 .61803 L
s
.85689 .61428 m
.85689 .61803 L
s
.94459 .61428 m
.94459 .61803 L
s
.98843 .61428 m
.98843 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .14046 m
1 .14046 L
s
.99375 .25283 m
1 .25283 L
s
.99375 .3652 m
1 .3652 L
s
.99375 .47757 m
1 .47757 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(Modulation Transfer Function)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .58994 m
.02427 .46612 L
.02474 .17721 L
.02521 .14671 L
.02567 .23954 L
.02614 .14148 L
.0266 .08553 L
.02707 .17982 L
.02753 .13287 L
.028 .05317 L
.02846 .14685 L
.02893 .12868 L
.02939 .03135 L
.02986 .12413 L
.03032 .12632 L
.03079 .04218 L
.03125 .10585 L
.03172 .12477 L
.03218 .05783 L
.03265 .08875 L
.03311 .12271 L
.03358 .0729 L
.03405 .07029 L
.03451 .11751 L
.03498 .08557 L
.03544 .05085 L
.03591 .10796 L
.03637 .09349 L
.03684 .03306 L
.0373 .09571 L
.03777 .09639 L
.03823 .03713 L
.0387 .08377 L
.03916 .09667 L
.03963 .04802 L
.04009 .07346 L
.04056 .09701 L
.04102 .05874 L
.04149 .06261 L
.04195 .09674 L
.04242 .07035 L
.04289 .04858 L
.04335 .09224 L
.04382 .07937 L
.04428 .03336 L
.04475 .08296 L
.04521 .08248 L
.04568 .03391 L
.04614 .07471 L
.04661 .0844 L
Mistroke
.04707 .04337 L
.04754 .06777 L
.048 .08842 L
.04847 .05765 L
.04893 .05233 L
.0494 .08121 L
.04986 .0603 L
.05033 .047 L
.05079 .08236 L
.05126 .0706 L
.05172 .03381 L
.05219 .07583 L
.05266 .07498 L
.05312 .03268 L
.05359 .06959 L
.05405 .0791 L
.05452 .04441 L
.05498 .05951 L
.05545 .07832 L
.05591 .05235 L
.05638 .05079 L
.05684 .07685 L
.05731 .05903 L
.05777 .04305 L
.05824 .07678 L
.0587 .06924 L
.05917 .02843 L
.05963 .0671 L
.0601 .06933 L
.06056 .03398 L
.06103 .06334 L
.0615 .07387 L
.06196 .04474 L
.06243 .05436 L
.06289 .07333 L
.06336 .05187 L
.06382 .04719 L
.06429 .07396 L
.06475 .06143 L
.06522 .03543 L
.06568 .0689 L
.06615 .06665 L
.06661 .03161 L
.06708 .06111 L
.06754 .06715 L
.06801 .03784 L
.06847 .0569 L
.06894 .07083 L
.0694 .04815 L
.06987 .04721 L
Mistroke
.07034 .06856 L
.0708 .05356 L
.07127 .04068 L
.07173 .06847 L
.0722 .06172 L
.07266 .02994 L
.07313 .06351 L
.07359 .06631 L
.07406 .03618 L
.07452 .05695 L
.07499 .06903 L
.07545 .04628 L
.07592 .04743 L
.07638 .06733 L
.07685 .05277 L
.07731 .03949 L
.07778 .06586 L
.07824 .0601 L
.07871 .02852 L
.07918 .05942 L
.07964 .06237 L
.08011 .03538 L
.08057 .05392 L
.08104 .0644 L
.0815 .0433 L
.08197 .04716 L
.08243 .06501 L
.0829 .05115 L
.08336 .0386 L
.08383 .06306 L
.08429 .05769 L
.08476 .02874 L
.08522 .05768 L
.08569 .06048 L
.08615 .03486 L
.08662 .0533 L
.08708 .06428 L
.08755 .04492 L
.08801 .04436 L
.08848 .06303 L
.08895 .05148 L
.08941 .03648 L
.08988 .06141 L
.09034 .05834 L
.09081 .02992 L
.09127 .05605 L
.09174 .06233 L
.0922 .04031 L
.09267 .047 L
.09313 .06048 L
Mistroke
.0936 .0447 L
.09406 .04326 L
.09453 .06421 L
.09499 .05653 L
.09546 .02978 L
.09592 .05752 L
.09639 .06019 L
.09685 .03616 L
.09732 .05025 L
.09779 .06137 L
.09825 .04438 L
.09872 .04233 L
.09918 .06074 L
.09965 .05184 L
.10011 .03267 L
.10058 .05633 L
.10104 .05531 L
.10151 .03042 L
.10197 .05365 L
.10244 .06107 L
.1029 .04154 L
.10337 .04527 L
.10383 .06194 L
.1043 .05118 L
.10476 .03412 L
.10523 .05751 L
.10569 .05603 L
.10616 .03112 L
.10663 .05273 L
.10709 .06038 L
.10756 .04177 L
.10802 .044 L
.10849 .06045 L
.10895 .05061 L
.10942 .03334 L
.10988 .05619 L
.11035 .05562 L
.11081 .03243 L
.11128 .05031 L
.11174 .05847 L
.11221 .04167 L
.11267 .04245 L
.11314 .05878 L
.1136 .05038 L
.11407 .0319 L
.11453 .05445 L
.115 .05532 L
.11547 .03411 L
.11593 .04791 L
.1164 .0574 L
Mistroke
.11686 .04301 L
.11733 .03962 L
.11779 .05666 L
.11826 .05058 L
.11872 .0298 L
.11919 .05259 L
.11965 .05574 L
.12012 .03684 L
.12058 .04507 L
.12105 .0571 L
.12151 .04599 L
.12198 .03542 L
.12244 .05462 L
.12291 .05266 L
.12337 .03129 L
.12384 .04861 L
.12431 .05593 L
.12477 .04127 L
.12524 .03977 L
.1257 .05514 L
.12617 .04903 L
.12663 .02973 L
.1271 .05088 L
.12756 .05403 L
.12803 .03683 L
.12849 .0433 L
.12896 .05525 L
.12942 .04595 L
.12989 .03346 L
.13035 .0525 L
.13082 .05263 L
.13128 .03385 L
.13175 .04543 L
.13221 .05501 L
.13268 .04382 L
.13314 .03559 L
.13361 .05294 L
.13408 .05114 L
.13454 .0317 L
.13501 .04656 L
.13547 .05437 L
.13594 .04203 L
.1364 .03712 L
.13687 .0531 L
.13733 .04989 L
.1378 .02996 L
.13826 .04767 L
.13873 .05428 L
.13919 .041 L
.13966 .03829 L
Mistroke
.14012 .05372 L
.14059 .04978 L
.14105 .02942 L
.14152 .04817 L
.14198 .0545 L
.14245 .04098 L
.14292 .03838 L
.14338 .05377 L
.14385 .04982 L
.14431 .02956 L
.14478 .04794 L
.14524 .05428 L
.14571 .04093 L
.14617 .03821 L
.14664 .05353 L
.1471 .04972 L
.14757 .02971 L
.14803 .04765 L
.1485 .05409 L
.14896 .04101 L
.14943 .03797 L
.14989 .05344 L
.15036 .05006 L
.15082 .03035 L
.15129 .04723 L
.15176 .05448 L
.15222 .04229 L
.15269 .03647 L
.15315 .05282 L
.15362 .05103 L
.15408 .03255 L
.15455 .0452 L
.15501 .05419 L
.15548 .04427 L
.15594 .03335 L
.15641 .05072 L
.15687 .05165 L
.15734 .03576 L
.1578 .04152 L
.15827 .05274 L
.15873 .04633 L
.1592 .02898 L
.15966 .04709 L
.16013 .05143 L
.1606 .03922 L
.16106 .03688 L
.16153 .05039 L
.16199 .04814 L
.16246 .03184 L
.16292 .04326 L
Mistroke
.16339 .0517 L
.16385 .04398 L
.16432 .0306 L
.16478 .04694 L
.16525 .05006 L
.16571 .03796 L
.16618 .03708 L
.16664 .04967 L
.16711 .04732 L
.16757 .03164 L
.16804 .04278 L
.1685 .05099 L
.16897 .04347 L
.16943 .03088 L
.1699 .04723 L
.17037 .05047 L
.17083 .03822 L
.1713 .0374 L
.17176 .05071 L
.17223 .04868 L
.17269 .03259 L
.17316 .04281 L
.17362 .05196 L
.17409 .04476 L
.17455 .03012 L
.17502 .04753 L
.17548 .05178 L
.17595 .04 L
.17641 .03594 L
.17688 .05022 L
.17734 .04939 L
.17781 .03411 L
.17827 .04139 L
.17874 .05173 L
.17921 .04628 L
.17967 .02883 L
.18014 .04507 L
.1806 .05137 L
.18107 .04227 L
.18153 .03221 L
.182 .04763 L
.18246 .05024 L
.18293 .03859 L
.18339 .03576 L
.18386 .04871 L
.18432 .04832 L
.18479 .03508 L
.18525 .03856 L
.18572 .04915 L
.18618 .04632 L
Mistroke
.18665 .03206 L
.18711 .04075 L
.18758 .04928 L
.18805 .04445 L
.18851 .02936 L
.18898 .04268 L
.18944 .04937 L
.18991 .0427 L
.19037 .02939 L
.19084 .04464 L
.1913 .04968 L
.19177 .04131 L
.19223 .03154 L
.1927 .04617 L
.19316 .04965 L
.19363 .03974 L
.19409 .03365 L
.19456 .04753 L
.19502 .04949 L
.19549 .03832 L
.19595 .03527 L
.19642 .04821 L
.19689 .04878 L
.19735 .03668 L
.19782 .03679 L
.19828 .0487 L
.19875 .04804 L
.19921 .03528 L
.19968 .03796 L
.20014 .04898 L
.20061 .04737 L
.20107 .03418 L
.20154 .03881 L
.202 .04917 L
.20247 .04694 L
.20293 .03348 L
.2034 .03939 L
.20386 .04944 L
.20433 .04694 L
.20479 .03338 L
.20526 .03945 L
.20572 .0494 L
.20619 .04687 L
.20666 .03339 L
.20712 .03932 L
.20759 .04925 L
.20805 .04688 L
.20852 .03368 L
.20898 .03878 L
.20945 .04875 L
Mistroke
.20991 .04679 L
.21038 .0342 L
.21084 .03786 L
.21131 .04799 L
.21177 .04677 L
.21224 .03509 L
.2127 .03654 L
.21317 .04711 L
.21363 .04709 L
.2141 .03666 L
.21456 .03452 L
.21503 .04587 L
.2155 .04748 L
.21596 .03857 L
.21643 .03218 L
.21689 .04454 L
.21736 .04803 L
.21782 .04076 L
.21829 .0296 L
.21875 .04307 L
.21922 .04855 L
.21968 .04296 L
.22015 .02924 L
.22061 .04144 L
.22108 .04882 L
.22154 .04501 L
.22201 .03198 L
.22247 .03942 L
.22294 .04863 L
.2234 .04688 L
.22387 .03512 L
.22434 .03651 L
.2248 .04744 L
.22527 .04816 L
.22573 .03841 L
.2262 .03278 L
.22666 .04521 L
.22713 .0487 L
.22759 .04161 L
.22806 .02848 L
.22852 .04204 L
.22899 .04835 L
.22945 .04429 L
.22992 .032 L
.23038 .03837 L
.23085 .04724 L
.23131 .0463 L
.23178 .03611 L
.23224 .03429 L
.23271 .04531 L
Mistroke
.23318 .04762 L
.23364 .04017 L
.23411 .02939 L
.23457 .042 L
.23504 .0477 L
.2355 .04386 L
.23597 .03254 L
.23643 .03695 L
.2369 .04595 L
.23736 .04658 L
.23783 .03868 L
.23829 .03022 L
.23876 .04191 L
.23922 .04724 L
.23969 .04373 L
.24015 .03293 L
.24062 .03642 L
.24108 .04578 L
.24155 .04685 L
.24202 .03896 L
.24248 .03043 L
.24295 .04263 L
.24341 .04793 L
.24388 .04373 L
.24434 .03205 L
.24481 .03767 L
.24527 .04662 L
.24574 .04684 L
.2462 .03837 L
.24667 .03091 L
.24713 .04261 L
.2476 .04774 L
.24806 .04414 L
.24853 .03351 L
.24899 .03564 L
.24946 .04531 L
.24992 .04752 L
.25039 .04128 L
.25085 .02925 L
.25132 .03953 L
.25179 .04714 L
.25225 .04638 L
.25272 .03759 L
.25318 .0315 L
.25365 .04278 L
.25411 .04751 L
.25458 .04381 L
.25504 .03349 L
.25551 .03502 L
.25597 .04414 L
Mistroke
.25644 .04641 L
.2569 .04116 L
.25737 .03069 L
.25783 .03689 L
.2583 .04471 L
.25876 .04585 L
.25923 .03985 L
.25969 .02901 L
.26016 .03852 L
.26063 .04573 L
.26109 .04579 L
.26156 .03855 L
.26202 .02921 L
.26249 .04034 L
.26295 .04645 L
.26342 .04513 L
.26388 .03707 L
.26435 .03056 L
.26481 .04085 L
.26528 .04608 L
.26574 .04439 L
.26621 .03654 L
.26667 .03073 L
.26714 .04096 L
.2676 .04651 L
.26807 .04519 L
.26853 .03728 L
.269 .03059 L
.26947 .0416 L
.26993 .04762 L
.2704 .04618 L
.27086 .03778 L
.27133 .03044 L
.27179 .0414 L
.27226 .04712 L
.27272 .04561 L
.27319 .03773 L
.27365 .02957 L
.27412 .03979 L
.27458 .04558 L
.27505 .04508 L
.27551 .03863 L
.27598 .02856 L
.27644 .03779 L
.27691 .04451 L
.27737 .04538 L
.27784 .04007 L
.27831 .03044 L
.27877 .03623 L
.27924 .04381 L
Mistroke
.2797 .04584 L
.28017 .04174 L
.28063 .0331 L
.2811 .03323 L
.28156 .04154 L
.28203 .04546 L
.28249 .0439 L
.28296 .03741 L
.28342 .02821 L
.28389 .03778 L
.28435 .04453 L
.28482 .0462 L
.28528 .04205 L
.28575 .03323 L
.28621 .03363 L
.28668 .04255 L
.28714 .04665 L
.28761 .04453 L
.28808 .03701 L
.28854 .02948 L
.28901 .03912 L
.28947 .04506 L
.28994 .0456 L
.2904 .04078 L
.29087 .03223 L
.29133 .03367 L
.2918 .04168 L
.29226 .04565 L
.29273 .04436 L
.29319 .03811 L
.29366 .02873 L
.29412 .03712 L
.29459 .04408 L
.29505 .04619 L
.29552 .04286 L
.29598 .03521 L
.29645 .03057 L
.29692 .03928 L
.29738 .04466 L
.29785 .04534 L
.29831 .04122 L
.29878 .03348 L
.29924 .03198 L
.29971 .04025 L
.30017 .0452 L
.30064 .04538 L
.3011 .04067 L
.30157 .0324 L
.30203 .0332 L
.3025 .04105 L
Mistroke
.30296 .04522 L
.30343 .04474 L
.30389 .04001 L
.30436 .03248 L
.30482 .03207 L
.30529 .03931 L
.30576 .04381 L
.30622 .04461 L
.30669 .04146 L
.30715 .03499 L
.30762 .0295 L
.30808 .03758 L
.30855 .04328 L
.30901 .04503 L
.30948 .04232 L
.30994 .03592 L
.31041 .02863 L
.31087 .03679 L
.31134 .04275 L
.3118 .04514 L
.31227 .04345 L
.31273 .03807 L
.3132 .03018 L
.31366 .0346 L
.31413 .04186 L
.3146 .04592 L
.31506 .04566 L
.31553 .04107 L
.31599 .0333 L
.31646 .03184 L
.31692 .03973 L
.31739 .04473 L
.31785 .04586 L
.31832 .04314 L
.31878 .03739 L
.31925 .02996 L
.31971 .03383 L
.32018 .04015 L
.32064 .044 L
.32111 .04464 L
.32157 .04189 L
.32204 .03625 L
.3225 .02885 L
.32297 .03492 L
.32343 .04105 L
.3239 .04438 L
.32437 .04424 L
.32483 .04074 L
.3253 .03472 L
.32576 .02872 L
Mistroke
.32623 .03573 L
.32669 .0412 L
.32716 .04414 L
.32762 .04408 L
.32809 .04104 L
.32855 .03556 L
.32902 .02865 L
.32948 .03458 L
.32995 .04038 L
.33041 .04376 L
.33088 .0441 L
.33134 .04141 L
.33181 .03632 L
.33227 .02989 L
.33274 .03292 L
.33321 .03867 L
.33367 .0427 L
.33414 .04442 L
.3346 .04348 L
.33507 .03985 L
.33553 .03395 L
.336 .02953 L
.33646 .03689 L
.33693 .04286 L
.33739 .0462 L
.33786 .04626 L
.33832 .04311 L
.33879 .03753 L
.33925 .03063 L
.33972 .03253 L
.34018 .03855 L
.34065 .0428 L
.34111 .04475 L
.34158 .04418 L
.34205 .04119 L
.34251 .03621 L
.34298 .03002 L
.34344 .03259 L
.34391 .03819 L
.34437 .04209 L
.34484 .04374 L
.3453 .043 L
.34577 .04012 L
.34623 .03565 L
.3467 .03029 L
.34716 .0314 L
.34763 .03641 L
.34809 .04036 L
.34856 .04282 L
.34902 .0435 L
Mistroke
.34949 .04223 L
.34995 .03903 L
.35042 .03418 L
.35089 .02826 L
.35135 .03404 L
.35182 .03938 L
.35228 .0431 L
.35275 .04465 L
.35321 .04397 L
.35368 .04134 L
.35414 .0373 L
.35461 .03242 L
.35507 .02898 L
.35554 .03409 L
.356 .03865 L
.35647 .04218 L
.35693 .04422 L
.3574 .04439 L
.35786 .04259 L
.35833 .03899 L
.35879 .03406 L
.35926 .02846 L
.35973 .03331 L
.36019 .03825 L
.36066 .04204 L
.36112 .04433 L
.36159 .04493 L
.36205 .0438 L
.36252 .04108 L
.36298 .03702 L
.36345 .03204 L
.36391 .02955 L
.36438 .03478 L
.36484 .03925 L
.36531 .04242 L
.36577 .04392 L
.36624 .0436 L
.3667 .04162 L
.36717 .03837 L
.36763 .03435 L
.3681 .03005 L
.36856 .03035 L
.36903 .03427 L
.3695 .03774 L
.36996 .0406 L
.37043 .04264 L
.37089 .04361 L
.37136 .04334 L
.37182 .04175 L
.37229 .03895 L
Mistroke
.37275 .0352 L
.37322 .03085 L
.37368 .02985 L
.37415 .03415 L
.37461 .03787 L
.37508 .04077 L
.37554 .0427 L
.37601 .0436 L
.37647 .04345 L
.37694 .0423 L
.3774 .0402 L
.37787 .03724 L
.37834 .0336 L
.3788 .02949 L
.37927 .03097 L
.37973 .03508 L
.3802 .03871 L
.38066 .04158 L
.38113 .04347 L
.38159 .04428 L
.38206 .04401 L
.38252 .04275 L
.38299 .04067 L
.38345 .03794 L
.38392 .03473 L
.38438 .03119 L
.38485 .02872 L
.38531 .03246 L
.38578 .03601 L
.38624 .03914 L
.38671 .04161 L
.38718 .04325 L
.38764 .04395 L
.38811 .04367 L
.38857 .04245 L
.38904 .04037 L
.3895 .03762 L
.38997 .0344 L
.39043 .03098 L
.3909 .02858 L
.39136 .03171 L
.39183 .03452 L
.39229 .03698 L
.39276 .03912 L
.39322 .04092 L
.39369 .04234 L
.39415 .04328 L
.39462 .04363 L
.39508 .04334 L
.39555 .04239 L
Mistroke
.39602 .04085 L
.39648 .03881 L
.39695 .0364 L
.39741 .03374 L
.39788 .03097 L
.39834 .02821 L
.39881 .03063 L
.39927 .03313 L
.39974 .03545 L
.4002 .03758 L
.40067 .0395 L
.40113 .04116 L
.4016 .04247 L
.40206 .04332 L
.40253 .04363 L
.40299 .04336 L
.40346 .04253 L
.40392 .04124 L
.40439 .03958 L
.40485 .03766 L
.40532 .0356 L
.40579 .03344 L
.40625 .03124 L
.40672 .02898 L
.40718 .02951 L
.40765 .03185 L
.40811 .03419 L
.40858 .03644 L
.40904 .0385 L
.40951 .04029 L
.40997 .04174 L
.41044 .04282 L
.4109 .04352 L
.41137 .04382 L
.41183 .04372 L
.4123 .04323 L
.41276 .04242 L
.41323 .04136 L
.41369 .04015 L
.41416 .03887 L
.41463 .03755 L
.41509 .03619 L
.41556 .03478 L
.41602 .03333 L
.41649 .03185 L
.41695 .03034 L
.41742 .02882 L
.41788 .02893 L
.41835 .03054 L
.41881 .03219 L
Mistroke
.41928 .03383 L
.41974 .0354 L
.42021 .0368 L
.42067 .038 L
.42114 .03897 L
.4216 .03973 L
.42207 .04031 L
.42253 .04075 L
.423 .04108 L
.42347 .04135 L
.42393 .04157 L
.4244 .04179 L
.42486 .04202 L
.42533 .04224 L
.42579 .04241 L
.42626 .04249 L
.42672 .04245 L
.42719 .04227 L
.42765 .04193 L
.42812 .04145 L
.42858 .04084 L
.42905 .04013 L
.42951 .03934 L
.42998 .03851 L
.43044 .03766 L
.43091 .03682 L
.43137 .03599 L
.43184 .03515 L
.43231 .03429 L
.43277 .03341 L
.43324 .03252 L
.4337 .03166 L
.43417 .03084 L
.43463 .03007 L
.4351 .02932 L
.43556 .02858 L
.43603 .02833 L
.43649 .02903 L
.43696 .02966 L
.43742 .03021 L
.43789 .03066 L
.43835 .03101 L
.43882 .03128 L
.43928 .03148 L
.43975 .03163 L
.44021 .03175 L
.44068 .03185 L
.44114 .03196 L
.44161 .0321 L
.44208 .03227 L
Mistroke
.44254 .03247 L
.44301 .03269 L
.44347 .03292 L
.44394 .03316 L
.4444 .0334 L
.44487 .03364 L
.44533 .03386 L
.4458 .03401 L
.44626 .03408 L
.44673 .03404 L
.44719 .03388 L
.44766 .03365 L
.44812 .03334 L
.44859 .03299 L
.44905 .0326 L
.44952 .03215 L
.44998 .03167 L
.45045 .03118 L
.45092 .03072 L
.45138 .03034 L
.45185 .03005 L
.45231 .02982 L
.45278 .02962 L
.45324 .02943 L
.45371 .02923 L
.45417 .02904 L
.45464 .02886 L
.4551 .02869 L
.45557 .0285 L
.45603 .02825 L
.4565 .02827 L
.45696 .02872 L
.45743 .02929 L
.45789 .02997 L
.45836 .03074 L
.45882 .0316 L
.45929 .03251 L
.45976 .03343 L
.46022 .03434 L
.46069 .0352 L
.46115 .03602 L
.46162 .03683 L
.46208 .03764 L
.46255 .03846 L
.46301 .03929 L
.46348 .04008 L
.46394 .0408 L
.46441 .04143 L
.46487 .04193 L
.46534 .04233 L
Mistroke
.4658 .04264 L
.46627 .04285 L
.46673 .04299 L
.4672 .04302 L
.46766 .04294 L
.46813 .0427 L
.4686 .04229 L
.46906 .04169 L
.46953 .0409 L
.46999 .03997 L
.47046 .03895 L
.47092 .03785 L
.47139 .03671 L
.47185 .03553 L
.47232 .03431 L
.47278 .03304 L
.47325 .03174 L
.47371 .03041 L
.47418 .02904 L
.47464 .02855 L
.47511 .03 L
.47557 .03146 L
.47604 .03292 L
.4765 .03433 L
.47697 .0357 L
.47744 .037 L
.4779 .03824 L
.47837 .03938 L
.47883 .04036 L
.4793 .04111 L
.47976 .0416 L
.48023 .04178 L
.48069 .04169 L
.48116 .04135 L
.48162 .04077 L
.48209 .03997 L
.48255 .03892 L
.48302 .0376 L
.48348 .03602 L
.48395 .03416 L
.48441 .03207 L
.48488 .02979 L
.48534 .02879 L
.48581 .03124 L
.48627 .03366 L
.48674 .03597 L
.48721 .03811 L
.48767 .04 L
.48814 .04157 L
.4886 .04278 L
Mistroke
.48907 .04354 L
.48953 .04381 L
.49 .04356 L
.49046 .04281 L
.49093 .04158 L
.49139 .03992 L
.49186 .03789 L
.49232 .03556 L
.49279 .03301 L
.49325 .0303 L
.49372 .02864 L
.49418 .03134 L
.49465 .03388 L
.49511 .03615 L
.49558 .03809 L
.49605 .03964 L
.49651 .04076 L
.49698 .04138 L
.49744 .04146 L
.49791 .04095 L
.49837 .03983 L
.49884 .03815 L
.4993 .03597 L
.49977 .03341 L
.50023 .03061 L
.5007 .02846 L
.50116 .03128 L
.50163 .0339 L
.50209 .0362 L
.50256 .0381 L
.50302 .03952 L
.50349 .04041 L
.50395 .0407 L
.50442 .04034 L
.50489 .03931 L
.50535 .03761 L
.50582 .03528 L
.50628 .03241 L
.50675 .02912 L
.50721 .0306 L
.50768 .03413 L
.50814 .0374 L
.50861 .04012 L
.50907 .04201 L
.50954 .04288 L
.51 .04264 L
.51047 .0413 L
.51093 .039 L
.5114 .03592 L
.51186 .0323 L
Mistroke
.51233 .02837 L
.51279 .03179 L
.51326 .03557 L
.51373 .03887 L
.51419 .04145 L
.51466 .04308 L
.51512 .04361 L
.51559 .043 L
.51605 .04125 L
.51652 .03847 L
.51698 .03487 L
.51745 .03071 L
.51791 .02987 L
.51838 .03412 L
.51884 .03784 L
.51931 .04063 L
.51977 .0422 L
.52024 .0424 L
.5207 .04123 L
.52117 .03886 L
.52163 .03556 L
.5221 .03167 L
.52256 .02861 L
.52303 .03251 L
.5235 .03588 L
.52396 .0384 L
.52443 .03985 L
.52489 .0401 L
.52536 .0391 L
.52582 .03696 L
.52629 .03387 L
.52675 .03009 L
.52722 .0302 L
.52768 .0342 L
.52815 .03766 L
.52861 .04016 L
.52908 .04139 L
.52954 .04115 L
.53001 .03945 L
.53047 .03644 L
.53094 .03243 L
.5314 .02831 L
.53187 .03288 L
.53234 .0369 L
.5328 .03985 L
.53327 .04132 L
.53373 .04111 L
.5342 .03923 L
.53466 .03592 L
.53513 .03157 L
Mistroke
.53559 .02949 L
.53606 .03426 L
.53652 .0383 L
.53699 .04101 L
.53745 .04193 L
.53792 .04084 L
.53838 .03783 L
.53885 .03329 L
.53931 .0283 L
.53978 .03372 L
.54024 .03832 L
.54071 .04138 L
.54118 .04242 L
.54164 .04123 L
.54211 .038 L
.54257 .03322 L
.54304 .02855 L
.5435 .03408 L
.54397 .03871 L
.54443 .0417 L
.5449 .04259 L
.54536 .04117 L
.54583 .03762 L
.54629 .03244 L
.54676 .02977 L
.54722 .03565 L
.54769 .04038 L
.54815 .04311 L
.54862 .04334 L
.54908 .04098 L
.54955 .03643 L
.55002 .0305 L
.55048 .03194 L
.55095 .03737 L
.55141 .04103 L
.55188 .04231 L
.55234 .04107 L
.55281 .03765 L
.55327 .03275 L
.55374 .02891 L
.5542 .03402 L
.55467 .03792 L
.55513 .04 L
.5556 .03989 L
.55606 .03757 L
.55653 .0334 L
.55699 .02812 L
.55746 .03345 L
.55792 .03781 L
.55839 .04016 L
Mistroke
.55886 .03992 L
.55932 .03708 L
.55979 .03226 L
.56025 .02966 L
.56072 .03501 L
.56118 .03876 L
.56165 .04007 L
.56211 .03866 L
.56258 .03484 L
.56304 .02947 L
.56351 .03246 L
.56397 .03726 L
.56444 .03999 L
.5649 .03993 L
.56537 .03698 L
.56583 .03173 L
.5663 .03083 L
.56676 .03682 L
.56723 .04093 L
.56769 .04203 L
.56816 .03971 L
.56863 .03443 L
.56909 .02877 L
.56956 .03581 L
.57002 .04106 L
.57049 .04315 L
.57095 .04151 L
.57142 .03648 L
.57188 .02932 L
.57235 .03438 L
.57281 .04033 L
.57328 .04317 L
.57374 .04215 L
.57421 .03747 L
.57467 .0303 L
.57514 .03371 L
.5756 .04013 L
.57607 .04341 L
.57653 .04261 L
.577 .03788 L
.57747 .03048 L
.57793 .03376 L
.5784 .0402 L
.57886 .04321 L
.57933 .04195 L
.57979 .03686 L
.58026 .02946 L
.58072 .0343 L
.58119 .03987 L
.58165 .04194 L
Mistroke
.58212 .04003 L
.58258 .03483 L
.58305 .02826 L
.58351 .03486 L
.58398 .03928 L
.58444 .04031 L
.58491 .03768 L
.58537 .0322 L
.58584 .0307 L
.58631 .03661 L
.58677 .03988 L
.58724 .03947 L
.5877 .03546 L
.58817 .02912 L
.58863 .03371 L
.5891 .0385 L
.58956 .03987 L
.59003 .03736 L
.59049 .03181 L
.59096 .03111 L
.59142 .03679 L
.59189 .03948 L
.59235 .03827 L
.59282 .03353 L
.59328 .02934 L
.59375 .03567 L
.59421 .03937 L
.59468 .03902 L
.59515 .03464 L
.59561 .02847 L
.59608 .03544 L
.59654 .03987 L
.59701 .04004 L
.59747 .0358 L
.59794 .02863 L
.5984 .03504 L
.59887 .04004 L
.59933 .04066 L
.5998 .03659 L
.60026 .02928 L
.60073 .0348 L
.60119 .04029 L
.60166 .04123 L
.60212 .03712 L
.60259 .0294 L
.60305 .03519 L
.60352 .04097 L
.60398 .04174 L
.60445 .03704 L
.60492 .02863 L
Mistroke
.60538 .03639 L
.60585 .04209 L
.60631 .04229 L
.60678 .03681 L
.60724 .02842 L
.60771 .03742 L
.60817 .04275 L
.60864 .04221 L
.6091 .03594 L
.60957 .02976 L
.61003 .03866 L
.6105 .04326 L
.61096 .04159 L
.61143 .03426 L
.61189 .03187 L
.61236 .04023 L
.61282 .04341 L
.61329 .03999 L
.61376 .03141 L
.61422 .03481 L
.61469 .04195 L
.61515 .04309 L
.61562 .03777 L
.61608 .02835 L
.61655 .03726 L
.61701 .04262 L
.61748 .04168 L
.61794 .0349 L
.61841 .03091 L
.61887 .03919 L
.61934 .04254 L
.6198 .03954 L
.62027 .03155 L
.62073 .03405 L
.6212 .04071 L
.62166 .04163 L
.62213 .03638 L
.6226 .02885 L
.62306 .03757 L
.62353 .04194 L
.62399 .03992 L
.62446 .03238 L
.62492 .0334 L
.62539 .04058 L
.62585 .04191 L
.62632 .03672 L
.62678 .02877 L
.62725 .03775 L
.62771 .04207 L
.62818 .03962 L
Mistroke
.62864 .03159 L
.62911 .03427 L
.62957 .04084 L
.63004 .04104 L
.6305 .03479 L
.63097 .03095 L
.63144 .03897 L
.6319 .04142 L
.63237 .03704 L
.63283 .02811 L
.6333 .0371 L
.63376 .04147 L
.63423 .03895 L
.63469 .03082 L
.63516 .03489 L
.63562 .04084 L
.63609 .0401 L
.63655 .03307 L
.63702 .03272 L
.63748 .03977 L
.63795 .04051 L
.63841 .03459 L
.63888 .03093 L
.63934 .03857 L
.63981 .04037 L
.64027 .03539 L
.64074 .02976 L
.64121 .03772 L
.64167 .04026 L
.64214 .03598 L
.6426 .02887 L
.64307 .03706 L
.64353 .04015 L
.644 .03643 L
.64446 .02814 L
.64493 .0364 L
.64539 .03982 L
.64586 .03646 L
.64632 .02835 L
.64679 .03597 L
.64725 .0394 L
.64772 .03619 L
.64818 .02834 L
.64865 .03566 L
.64911 .03881 L
.64958 .03549 L
.65005 .0284 L
.65051 .03581 L
.65098 .03848 L
.65144 .03484 L
Mistroke
.65191 .02902 L
.65237 .03603 L
.65284 .03811 L
.6533 .03406 L
.65377 .02972 L
.65423 .03615 L
.6547 .03748 L
.65516 .03302 L
.65563 .03052 L
.65609 .03614 L
.65656 .0366 L
.65702 .03178 L
.65749 .03135 L
.65795 .036 L
.65842 .03548 L
.65889 .03027 L
.65935 .03239 L
.65982 .03598 L
.66028 .03446 L
.66075 .02891 L
.66121 .03321 L
.66168 .03574 L
.66214 .03335 L
.66261 .02849 L
.66307 .0337 L
.66354 .03516 L
.664 .03207 L
.66447 .02962 L
.66493 .03395 L
.6654 .03434 L
.66586 .03067 L
.66633 .03073 L
.66679 .03405 L
.66726 .03333 L
.66773 .02912 L
.66819 .03193 L
.66866 .03419 L
.66912 .03238 L
.66959 .02847 L
.67005 .03285 L
.67052 .03401 L
.67098 .03121 L
.67145 .02983 L
.67191 .03345 L
.67238 .03341 L
.67284 .02977 L
.67331 .03114 L
.67377 .03369 L
.67424 .03232 L
.6747 .02819 L
Mistroke
.67517 .0324 L
.67563 .03351 L
.6761 .03072 L
.67657 .03019 L
.67703 .03345 L
.6775 .03288 L
.67796 .02885 L
.67843 .03193 L
.67889 .03379 L
.67936 .03155 L
.67982 .02936 L
.68029 .03314 L
.68075 .03324 L
.68122 .0296 L
.68168 .03127 L
.68215 .03356 L
.68261 .03177 L
.68308 .02893 L
.68354 .03276 L
.68401 .03302 L
.68447 .02953 L
.68494 .03125 L
.6854 .03345 L
.68587 .03158 L
.68634 .02913 L
.6868 .03285 L
.68727 .03296 L
.68773 .02939 L
.6882 .03133 L
.68866 .03336 L
.68913 .03136 L
.68959 .0293 L
.69006 .0328 L
.69052 .03263 L
.69099 .02895 L
.69145 .03153 L
.69192 .03309 L
.69238 .0307 L
.69285 .02993 L
.69331 .03292 L
.69378 .03212 L
.69424 .02815 L
.69471 .03203 L
.69518 .03293 L
.69564 .03003 L
.69611 .03054 L
.69657 .03297 L
.69704 .03153 L
.6975 .02879 L
.69797 .03232 L
Mistroke
.69843 .03243 L
.6989 .02908 L
.69936 .0312 L
.69983 .03272 L
.70029 .03046 L
.70076 .0299 L
.70122 .0326 L
.70169 .03161 L
.70215 .02842 L
.70262 .032 L
.70308 .03239 L
.70355 .02928 L
.70402 .03097 L
.70448 .03267 L
.70495 .03062 L
.70541 .02967 L
.70588 .03244 L
.70634 .0316 L
.70681 .02831 L
.70727 .03181 L
.70774 .03217 L
.7082 .0291 L
.70867 .03099 L
.70913 .03246 L
.7096 .03026 L
.71006 .02994 L
.71053 .0324 L
.71099 .03124 L
.71146 .02875 L
.71192 .032 L
.71239 .03195 L
.71286 .02865 L
.71332 .03128 L
.71379 .03231 L
.71425 .02976 L
.71472 .03036 L
.71518 .03231 L
.71565 .03062 L
.71611 .02942 L
.71658 .03213 L
.71704 .03136 L
.71751 .02839 L
.71797 .0317 L
.71844 .03189 L
.7189 .02882 L
.71937 .03107 L
.71983 .03219 L
.7203 .02977 L
.72076 .03028 L
.72123 .03224 L
Mistroke
.72169 .03061 L
.72216 .02937 L
.72263 .03201 L
.72309 .0312 L
.72356 .02851 L
.72402 .03166 L
.72449 .03167 L
.72495 .02855 L
.72542 .03116 L
.72588 .032 L
.72635 .02941 L
.72681 .03051 L
.72728 .0321 L
.72774 .03016 L
.72821 .0298 L
.72867 .03207 L
.72914 .03084 L
.7296 .02899 L
.73007 .03183 L
.73053 .03136 L
.731 .02818 L
.73147 .03144 L
.73193 .03171 L
.7324 .02875 L
.73286 .03099 L
.73333 .03199 L
.73379 .02954 L
.73426 .03038 L
.73472 .03209 L
.73519 .03025 L
.73565 .02968 L
.73612 .032 L
.73658 .03083 L
.73705 .02899 L
.73751 .03187 L
.73798 .03142 L
.73844 .02813 L
.73891 .03143 L
.73937 .03174 L
.73984 .02881 L
.74031 .03092 L
.74077 .03193 L
.74124 .0295 L
.7417 .03038 L
.74217 .03207 L
.74263 .03025 L
.7431 .0296 L
.74356 .03185 L
.74403 .03068 L
.74449 .02901 L
Mistroke
.74496 .03169 L
.74542 .03113 L
.74589 .02835 L
.74635 .03142 L
.74682 .03151 L
.74728 .02856 L
.74775 .03096 L
.74821 .03169 L
.74868 .02917 L
.74915 .0305 L
.74961 .03178 L
.75008 .02967 L
.75054 .03014 L
.75101 .03199 L
.75147 .03035 L
.75194 .02959 L
.7524 .03214 L
.75287 .03122 L
.75333 .02857 L
.7538 .03169 L
.75426 .03159 L
.75473 .02839 L
.75519 .03122 L
.75566 .03181 L
.75612 .02906 L
.75659 .03074 L
.75705 .03196 L
.75752 .02966 L
.75798 .03031 L
.75845 .03219 L
.75892 .03042 L
.75938 .02967 L
.75985 .03228 L
.76031 .03128 L
.76078 .02869 L
.76124 .03194 L
.76171 .03181 L
.76217 .0284 L
.76264 .0315 L
.7631 .03225 L
.76357 .02937 L
.76403 .03078 L
.7645 .03234 L
.76496 .03009 L
.76543 .03019 L
.76589 .03255 L
.76636 .03108 L
.76682 .02917 L
.76729 .03233 L
.76776 .03186 L
Mistroke
.76822 .02813 L
.76869 .03184 L
.76915 .03243 L
.76962 .02934 L
.77008 .03094 L
.77055 .03252 L
.77101 .03025 L
.77148 .03005 L
.77194 .03244 L
.77241 .03105 L
.77287 .0291 L
.77334 .03222 L
.7738 .03183 L
.77427 .02827 L
.77473 .03159 L
.7752 .03228 L
.77566 .02942 L
.77613 .03072 L
.7766 .03241 L
.77706 .03045 L
.77753 .02959 L
.77799 .03202 L
.77846 .03096 L
.77892 .02882 L
.77939 .03182 L
.77985 .03162 L
.78032 .02839 L
.78078 .03131 L
.78125 .03209 L
.78171 .02944 L
.78218 .03062 L
.78264 .03249 L
.78311 .03079 L
.78357 .02926 L
.78404 .03206 L
.7845 .03147 L
.78497 .02819 L
.78544 .03163 L
.7859 .03215 L
.78637 .02929 L
.78683 .03079 L
.7873 .03252 L
.78776 .03067 L
.78823 .02944 L
.78869 .03228 L
.78916 .03182 L
.78962 .0285 L
.79009 .03113 L
.79055 .03196 L
.79102 .02965 L
Mistroke
.79148 .02995 L
.79195 .03159 L
.79241 .0301 L
.79288 .02941 L
.79334 .03175 L
.79381 .03111 L
.79428 .02822 L
.79474 .03131 L
.79521 .03177 L
.79567 .02916 L
.79614 .03067 L
.7966 .03247 L
.79707 .031 L
.79753 .02877 L
.798 .03162 L
.79846 .0315 L
.79893 .02857 L
.79939 .03092 L
.79986 .03184 L
.80032 .02951 L
.80079 .03048 L
.80125 .03274 L
.80172 .03154 L
.80218 .02852 L
.80265 .03214 L
.80311 .03272 L
.80358 .02974 L
.80405 .03073 L
.80451 .033 L
.80498 .03138 L
.80544 .02925 L
.80591 .03321 L
.80637 .03358 L
.80684 .02984 L
.8073 .03164 L
.80777 .03466 L
.80823 .0331 L
.8087 .02823 L
.80916 .03334 L
.80963 .0347 L
.81009 .03124 L
.81056 .03086 L
.81102 .03503 L
.81149 .03439 L
.81195 .02918 L
.81242 .03332 L
.81289 .03641 L
.81335 .03405 L
.81382 .02847 L
.81428 .03457 L
Mistroke
.81475 .03634 L
.81521 .03259 L
.81568 .03033 L
.81614 .03548 L
.81661 .03554 L
.81707 .03046 L
.81754 .03258 L
.818 .03666 L
.81847 .03526 L
.81893 .0293 L
.8194 .03351 L
.81986 .0365 L
.82033 .03396 L
.82079 .02853 L
.82126 .03436 L
.82173 .03577 L
.82219 .03174 L
.82266 .03134 L
.82312 .03656 L
.82359 .03658 L
.82405 .03116 L
.82452 .03259 L
.82498 .03754 L
.82545 .03662 L
.82591 .03017 L
.82638 .03418 L
.82684 .03904 L
.82731 .03738 L
.82777 .0298 L
.82824 .0357 L
.8287 .04142 L
.82917 .04011 L
.82963 .03233 L
.8301 .03384 L
.83057 .04044 L
.83103 .03996 L
.8315 .03261 L
.83196 .03372 L
.83243 .04105 L
.83289 .04154 L
.83336 .03494 L
.83382 .0313 L
.83429 .03919 L
.83475 .04044 L
.83522 .03411 L
.83568 .03282 L
.83615 .0424 L
.83661 .04567 L
.83708 .04068 L
.83754 .02966 L
Mistroke
.83801 .03823 L
.83847 .04492 L
.83894 .04327 L
.8394 .03404 L
.83987 .03452 L
.84034 .0441 L
.8408 .04626 L
.84127 .03983 L
.84173 .02849 L
.8422 .04081 L
.84266 .04767 L
.84313 .04592 L
.84359 .03627 L
.84406 .0333 L
.84452 .04466 L
.84499 .04915 L
.84545 .04489 L
.84592 .03363 L
.84638 .03622 L
.84685 .04682 L
.84731 .05017 L
.84778 .04502 L
.84824 .0334 L
.84871 .03643 L
.84918 .04702 L
.84964 .05077 L
.85011 .04654 L
.85057 .03604 L
.85104 .03316 L
.8515 .04434 L
.85197 .05017 L
.85243 .04909 L
.8529 .04174 L
.85336 .03058 L
.85383 .0372 L
.85429 .04603 L
.85476 .04985 L
.85522 .048 L
.85569 .04134 L
.85615 .03184 L
.85662 .03429 L
.85708 .04258 L
.85755 .04773 L
.85802 .04906 L
.85848 .04658 L
.85895 .04089 L
.85941 .03299 L
.85988 .03207 L
.86034 .04059 L
.86081 .04751 L
Mistroke
.86127 .05183 L
.86174 .05293 L
.8622 .05067 L
.86267 .04531 L
.86313 .03749 L
.8636 .02818 L
.86406 .03767 L
.86453 .04652 L
.86499 .05358 L
.86546 .05828 L
.86592 .06051 L
.86639 .06061 L
.86686 .05913 L
.86732 .05673 L
.86779 .05392 L
.86825 .05108 L
.86872 .04838 L
.86918 .04588 L
.86965 .04357 L
.87011 .04137 L
.87058 .03917 L
.87104 .03687 L
.87151 .03446 L
.87197 .03211 L
.87244 .0301 L
.8729 .02868 L
.87337 .02818 L
.87383 .02818 L
.8743 .02846 L
.87476 .02907 L
.87523 .02956 L
.87569 .02977 L
.87616 .02968 L
.87663 .02937 L
.87709 .02889 L
.87756 .02828 L
.87802 .02861 L
.87849 .02931 L
.87895 .02984 L
.87942 .03 L
.87988 .02967 L
.88035 .02889 L
.88081 .02833 L
.88128 .02934 L
.88174 .03001 L
.88221 .0302 L
.88267 .02989 L
.88314 .02925 L
.8836 .02853 L
.88407 .02828 L
Mistroke
.88453 .02874 L
.885 .02909 L
.88547 .02942 L
.88593 .02978 L
.8864 .03009 L
.88686 .03022 L
.88733 .03002 L
.88779 .0294 L
.88826 .02842 L
.88872 .02892 L
.88919 .02998 L
.88965 .03067 L
.89012 .03085 L
.89058 .03052 L
.89105 .02985 L
.89151 .02909 L
.89198 .02846 L
.89244 .02811 L
.89291 .02811 L
.89337 .0284 L
.89384 .02889 L
.89431 .02942 L
.89477 .02985 L
.89524 .03011 L
.8957 .0302 L
.89617 .03017 L
.89663 .03009 L
.8971 .02999 L
.89756 .02986 L
.89803 .0297 L
.89849 .0295 L
.89896 .02925 L
.89942 .02898 L
.89989 .02873 L
.90035 .02849 L
.90082 .02826 L
.90128 .02814 L
.90175 .02832 L
.90221 .02845 L
.90268 .02854 L
.90315 .02863 L
.90361 .02872 L
.90408 .02882 L
.90454 .02888 L
.90501 .02889 L
.90547 .02882 L
.90594 .02869 L
.9064 .02852 L
.90687 .02837 L
.90733 .02824 L
Mistroke
.9078 .02813 L
.90826 .02819 L
.90873 .02832 L
.90919 .02845 L
.90966 .02853 L
.91012 .02857 L
.91059 .02859 L
.91105 .02863 L
.91152 .02871 L
.91199 .02881 L
.91245 .02891 L
.91292 .02896 L
.91338 .02893 L
.91385 .02884 L
.91431 .02872 L
.91478 .02865 L
.91524 .02865 L
.91571 .02871 L
.91617 .02876 L
.91664 .02876 L
.9171 .02868 L
.91757 .02857 L
.91803 .02848 L
.9185 .02848 L
.91896 .02858 L
.91943 .02878 L
.91989 .02899 L
.92036 .02914 L
.92082 .02916 L
.92129 .02904 L
.92176 .02882 L
.92222 .02856 L
.92269 .02833 L
.92315 .02817 L
.92362 .02811 L
.92408 .02812 L
.92455 .02819 L
.92501 .02828 L
.92548 .02835 L
.92594 .02838 L
.92641 .02839 L
.92687 .0284 L
.92734 .02842 L
.9278 .02846 L
.92827 .0285 L
.92873 .02854 L
.9292 .02855 L
.92966 .02854 L
.93013 .02854 L
.9306 .02854 L
Mistroke
.93106 .02855 L
.93153 .02855 L
.93199 .02854 L
.93246 .02853 L
.93292 .02853 L
.93339 .02853 L
.93385 .0285 L
.93432 .02845 L
.93478 .02837 L
.93525 .02828 L
.93571 .0282 L
.93618 .02814 L
.93664 .02809 L
.93711 .02814 L
.93757 .02822 L
.93804 .02831 L
.9385 .02841 L
.93897 .02848 L
.93944 .02851 L
.9399 .02851 L
.94037 .02851 L
.94083 .02851 L
.9413 .02849 L
.94176 .02842 L
.94223 .0283 L
.94269 .02812 L
.94316 .02829 L
.94362 .0285 L
.94409 .02866 L
.94455 .02871 L
.94502 .02868 L
.94548 .02856 L
.94595 .02842 L
.94641 .02826 L
.94688 .02811 L
.94734 .0282 L
.94781 .02829 L
.94828 .02835 L
.94874 .0284 L
.94921 .02843 L
.94967 .02842 L
.95014 .02837 L
.9506 .02825 L
.95107 .0281 L
.95153 .02825 L
.952 .02838 L
.95246 .02847 L
.95293 .02849 L
.95339 .02845 L
.95386 .02833 L
Mistroke
.95432 .02816 L
.95479 .02822 L
.95525 .02838 L
.95572 .02846 L
.95618 .02844 L
.95665 .02832 L
.95711 .02816 L
.95758 .0282 L
.95805 .02835 L
.95851 .02843 L
.95898 .02843 L
.95944 .02835 L
.95991 .02821 L
.96037 .02815 L
.96084 .02833 L
.9613 .02845 L
.96177 .02843 L
.96223 .02828 L
.9627 .02814 L
.96316 .02836 L
.96363 .02846 L
.96409 .02841 L
.96456 .02823 L
.96502 .0282 L
.96549 .02839 L
.96595 .02845 L
.96642 .02837 L
.96689 .02817 L
.96735 .02824 L
.96782 .02841 L
.96828 .02844 L
.96875 .02832 L
.96921 .02811 L
.96968 .02829 L
.97014 .0284 L
.97061 .02833 L
.97107 .0281 L
.97154 .02831 L
.972 .02839 L
.97247 .0283 L
.97293 .0281 L
.9734 .02828 L
.97386 .02839 L
.97433 .02832 L
.97479 .02809 L
.97526 .02831 L
.97573 .02836 L
.97619 .02824 L
Mfstroke
1 0 0 r
.02381 .58994 m
.02427 .58984 L
.02474 .58961 L
.02521 .58938 L
.02567 .58918 L
.02614 .58897 L
.0266 .58874 L
.02707 .5885 L
.02753 .58827 L
.028 .58804 L
.02846 .58779 L
.02893 .58754 L
.02939 .5873 L
.02986 .58705 L
.03032 .58679 L
.03079 .58653 L
.03125 .58628 L
.03172 .58602 L
.03218 .58576 L
.03265 .58549 L
.03311 .58523 L
.03358 .58497 L
.03405 .5847 L
.03451 .58443 L
.03498 .58416 L
.03544 .5839 L
.03591 .58363 L
.03637 .58336 L
.03684 .58309 L
.0373 .58282 L
.03777 .58255 L
.03823 .58228 L
.0387 .58201 L
.03916 .58174 L
.03963 .58147 L
.04009 .5812 L
.04056 .58093 L
.04102 .58066 L
.04149 .58039 L
.04195 .58012 L
.04242 .57985 L
.04289 .57958 L
.04335 .5793 L
.04382 .57903 L
.04428 .57876 L
.04475 .57849 L
.04521 .57822 L
.04568 .57795 L
.04614 .57768 L
.04661 .57741 L
Mistroke
.04707 .57714 L
.04754 .57686 L
.048 .57659 L
.04847 .57632 L
.04893 .57605 L
.0494 .57578 L
.04986 .57551 L
.05033 .57524 L
.05079 .57497 L
.05126 .5747 L
.05172 .57443 L
.05219 .57416 L
.05266 .57388 L
.05312 .57361 L
.05359 .57334 L
.05405 .57307 L
.05452 .5728 L
.05498 .57253 L
.05545 .57226 L
.05591 .57199 L
.05638 .57171 L
.05684 .57144 L
.05731 .57117 L
.05777 .5709 L
.05824 .57063 L
.0587 .57036 L
.05917 .57009 L
.05963 .56981 L
.0601 .56954 L
.06056 .56927 L
.06103 .569 L
.0615 .56873 L
.06196 .56846 L
.06243 .56818 L
.06289 .56791 L
.06336 .56764 L
.06382 .56737 L
.06429 .5671 L
.06475 .56683 L
.06522 .56656 L
.06568 .56628 L
.06615 .56601 L
.06661 .56574 L
.06708 .56547 L
.06754 .5652 L
.06801 .56493 L
.06847 .56465 L
.06894 .56438 L
.0694 .56411 L
.06987 .56384 L
Mistroke
.07034 .56357 L
.0708 .5633 L
.07127 .56302 L
.07173 .56275 L
.0722 .56248 L
.07266 .56221 L
.07313 .56194 L
.07359 .56166 L
.07406 .56139 L
.07452 .56112 L
.07499 .56085 L
.07545 .56058 L
.07592 .56031 L
.07638 .56003 L
.07685 .55976 L
.07731 .55949 L
.07778 .55922 L
.07824 .55895 L
.07871 .55867 L
.07918 .5584 L
.07964 .55813 L
.08011 .55786 L
.08057 .55759 L
.08104 .55731 L
.0815 .55704 L
.08197 .55677 L
.08243 .5565 L
.0829 .55622 L
.08336 .55595 L
.08383 .55568 L
.08429 .55541 L
.08476 .55514 L
.08522 .55486 L
.08569 .55459 L
.08615 .55432 L
.08662 .55405 L
.08708 .55378 L
.08755 .5535 L
.08801 .55323 L
.08848 .55296 L
.08895 .55269 L
.08941 .55241 L
.08988 .55214 L
.09034 .55187 L
.09081 .5516 L
.09127 .55133 L
.09174 .55105 L
.0922 .55078 L
.09267 .55051 L
.09313 .55024 L
Mistroke
.0936 .54996 L
.09406 .54969 L
.09453 .54942 L
.09499 .54915 L
.09546 .54887 L
.09592 .5486 L
.09639 .54833 L
.09685 .54806 L
.09732 .54778 L
.09779 .54751 L
.09825 .54724 L
.09872 .54697 L
.09918 .54669 L
.09965 .54642 L
.10011 .54615 L
.10058 .54588 L
.10104 .5456 L
.10151 .54533 L
.10197 .54506 L
.10244 .54478 L
.1029 .54451 L
.10337 .54424 L
.10383 .54397 L
.1043 .54369 L
.10476 .54342 L
.10523 .54315 L
.10569 .54288 L
.10616 .5426 L
.10663 .54233 L
.10709 .54206 L
.10756 .54178 L
.10802 .54151 L
.10849 .54124 L
.10895 .54097 L
.10942 .54069 L
.10988 .54042 L
.11035 .54015 L
.11081 .53987 L
.11128 .5396 L
.11174 .53933 L
.11221 .53906 L
.11267 .53878 L
.11314 .53851 L
.1136 .53824 L
.11407 .53796 L
.11453 .53769 L
.115 .53742 L
.11547 .53715 L
.11593 .53687 L
.1164 .5366 L
Mistroke
.11686 .53633 L
.11733 .53605 L
.11779 .53578 L
.11826 .53551 L
.11872 .53523 L
.11919 .53496 L
.11965 .53469 L
.12012 .53441 L
.12058 .53414 L
.12105 .53387 L
.12151 .5336 L
.12198 .53332 L
.12244 .53305 L
.12291 .53278 L
.12337 .5325 L
.12384 .53223 L
.12431 .53196 L
.12477 .53168 L
.12524 .53141 L
.1257 .53114 L
.12617 .53086 L
.12663 .53059 L
.1271 .53032 L
.12756 .53004 L
.12803 .52977 L
.12849 .5295 L
.12896 .52922 L
.12942 .52895 L
.12989 .52868 L
.13035 .5284 L
.13082 .52813 L
.13128 .52786 L
.13175 .52758 L
.13221 .52731 L
.13268 .52704 L
.13314 .52676 L
.13361 .52649 L
.13408 .52622 L
.13454 .52594 L
.13501 .52567 L
.13547 .5254 L
.13594 .52512 L
.1364 .52485 L
.13687 .52457 L
.13733 .5243 L
.1378 .52403 L
.13826 .52375 L
.13873 .52348 L
.13919 .52321 L
.13966 .52293 L
Mistroke
.14012 .52266 L
.14059 .52239 L
.14105 .52211 L
.14152 .52184 L
.14198 .52157 L
.14245 .52129 L
.14292 .52102 L
.14338 .52075 L
.14385 .52047 L
.14431 .5202 L
.14478 .51992 L
.14524 .51965 L
.14571 .51938 L
.14617 .5191 L
.14664 .51883 L
.1471 .51856 L
.14757 .51828 L
.14803 .51801 L
.1485 .51773 L
.14896 .51746 L
.14943 .51719 L
.14989 .51691 L
.15036 .51664 L
.15082 .51637 L
.15129 .51609 L
.15176 .51582 L
.15222 .51554 L
.15269 .51527 L
.15315 .515 L
.15362 .51472 L
.15408 .51445 L
.15455 .51417 L
.15501 .5139 L
.15548 .51363 L
.15594 .51335 L
.15641 .51308 L
.15687 .5128 L
.15734 .51253 L
.1578 .51226 L
.15827 .51198 L
.15873 .51171 L
.1592 .51143 L
.15966 .51116 L
.16013 .51089 L
.1606 .51061 L
.16106 .51034 L
.16153 .51006 L
.16199 .50979 L
.16246 .50952 L
.16292 .50924 L
Mistroke
.16339 .50897 L
.16385 .50869 L
.16432 .50842 L
.16478 .50815 L
.16525 .50787 L
.16571 .5076 L
.16618 .50732 L
.16664 .50705 L
.16711 .50677 L
.16757 .5065 L
.16804 .50623 L
.1685 .50595 L
.16897 .50568 L
.16943 .5054 L
.1699 .50513 L
.17037 .50486 L
.17083 .50458 L
.1713 .50431 L
.17176 .50403 L
.17223 .50376 L
.17269 .50348 L
.17316 .50321 L
.17362 .50294 L
.17409 .50266 L
.17455 .50239 L
.17502 .50211 L
.17548 .50184 L
.17595 .50156 L
.17641 .50129 L
.17688 .50102 L
.17734 .50074 L
.17781 .50047 L
.17827 .50019 L
.17874 .49992 L
.17921 .49964 L
.17967 .49937 L
.18014 .49909 L
.1806 .49882 L
.18107 .49855 L
.18153 .49827 L
.182 .498 L
.18246 .49772 L
.18293 .49745 L
.18339 .49717 L
.18386 .4969 L
.18432 .49662 L
.18479 .49635 L
.18525 .49608 L
.18572 .4958 L
.18618 .49553 L
Mistroke
.18665 .49525 L
.18711 .49498 L
.18758 .4947 L
.18805 .49443 L
.18851 .49415 L
.18898 .49388 L
.18944 .4936 L
.18991 .49333 L
.19037 .49306 L
.19084 .49278 L
.1913 .49251 L
.19177 .49223 L
.19223 .49196 L
.1927 .49168 L
.19316 .49141 L
.19363 .49113 L
.19409 .49086 L
.19456 .49058 L
.19502 .49031 L
.19549 .49003 L
.19595 .48976 L
.19642 .48948 L
.19689 .48921 L
.19735 .48894 L
.19782 .48866 L
.19828 .48839 L
.19875 .48811 L
.19921 .48784 L
.19968 .48756 L
.20014 .48729 L
.20061 .48701 L
.20107 .48674 L
.20154 .48646 L
.202 .48619 L
.20247 .48591 L
.20293 .48564 L
.2034 .48536 L
.20386 .48509 L
.20433 .48481 L
.20479 .48454 L
.20526 .48426 L
.20572 .48399 L
.20619 .48371 L
.20666 .48344 L
.20712 .48316 L
.20759 .48289 L
.20805 .48261 L
.20852 .48234 L
.20898 .48206 L
.20945 .48179 L
Mistroke
.20991 .48151 L
.21038 .48124 L
.21084 .48096 L
.21131 .48069 L
.21177 .48041 L
.21224 .48014 L
.2127 .47986 L
.21317 .47959 L
.21363 .47931 L
.2141 .47904 L
.21456 .47876 L
.21503 .47849 L
.2155 .47821 L
.21596 .47794 L
.21643 .47766 L
.21689 .47739 L
.21736 .47711 L
.21782 .47684 L
.21829 .47656 L
.21875 .47629 L
.21922 .47601 L
.21968 .47574 L
.22015 .47546 L
.22061 .47519 L
.22108 .47491 L
.22154 .47464 L
.22201 .47436 L
.22247 .47409 L
.22294 .47381 L
.2234 .47354 L
.22387 .47326 L
.22434 .47299 L
.2248 .47271 L
.22527 .47244 L
.22573 .47216 L
.2262 .47189 L
.22666 .47161 L
.22713 .47134 L
.22759 .47106 L
.22806 .47078 L
.22852 .47051 L
.22899 .47023 L
.22945 .46996 L
.22992 .46968 L
.23038 .46941 L
.23085 .46913 L
.23131 .46886 L
.23178 .46858 L
.23224 .46831 L
.23271 .46803 L
Mistroke
.23318 .46776 L
.23364 .46748 L
.23411 .46721 L
.23457 .46693 L
.23504 .46666 L
.2355 .46638 L
.23597 .4661 L
.23643 .46583 L
.2369 .46555 L
.23736 .46528 L
.23783 .465 L
.23829 .46473 L
.23876 .46445 L
.23922 .46418 L
.23969 .4639 L
.24015 .46363 L
.24062 .46335 L
.24108 .46308 L
.24155 .4628 L
.24202 .46252 L
.24248 .46225 L
.24295 .46197 L
.24341 .4617 L
.24388 .46142 L
.24434 .46115 L
.24481 .46087 L
.24527 .4606 L
.24574 .46032 L
.2462 .46004 L
.24667 .45977 L
.24713 .45949 L
.2476 .45922 L
.24806 .45894 L
.24853 .45867 L
.24899 .45839 L
.24946 .45812 L
.24992 .45784 L
.25039 .45756 L
.25085 .45729 L
.25132 .45701 L
.25179 .45674 L
.25225 .45646 L
.25272 .45619 L
.25318 .45591 L
.25365 .45564 L
.25411 .45536 L
.25458 .45508 L
.25504 .45481 L
.25551 .45453 L
.25597 .45426 L
Mistroke
.25644 .45398 L
.2569 .45371 L
.25737 .45343 L
.25783 .45315 L
.2583 .45288 L
.25876 .4526 L
.25923 .45233 L
.25969 .45205 L
.26016 .45178 L
.26063 .4515 L
.26109 .45123 L
.26156 .45095 L
.26202 .45067 L
.26249 .4504 L
.26295 .45012 L
.26342 .44985 L
.26388 .44957 L
.26435 .4493 L
.26481 .44902 L
.26528 .44874 L
.26574 .44847 L
.26621 .44819 L
.26667 .44792 L
.26714 .44764 L
.2676 .44736 L
.26807 .44709 L
.26853 .44681 L
.269 .44654 L
.26947 .44626 L
.26993 .44599 L
.2704 .44571 L
.27086 .44543 L
.27133 .44516 L
.27179 .44488 L
.27226 .44461 L
.27272 .44433 L
.27319 .44405 L
.27365 .44378 L
.27412 .4435 L
.27458 .44323 L
.27505 .44295 L
.27551 .44268 L
.27598 .4424 L
.27644 .44212 L
.27691 .44185 L
.27737 .44157 L
.27784 .4413 L
.27831 .44102 L
.27877 .44074 L
.27924 .44047 L
Mistroke
.2797 .44019 L
.28017 .43992 L
.28063 .43964 L
.2811 .43936 L
.28156 .43909 L
.28203 .43881 L
.28249 .43854 L
.28296 .43826 L
.28342 .43798 L
.28389 .43771 L
.28435 .43743 L
.28482 .43716 L
.28528 .43688 L
.28575 .4366 L
.28621 .43633 L
.28668 .43605 L
.28714 .43578 L
.28761 .4355 L
.28808 .43522 L
.28854 .43495 L
.28901 .43467 L
.28947 .4344 L
.28994 .43412 L
.2904 .43384 L
.29087 .43357 L
.29133 .43329 L
.2918 .43302 L
.29226 .43274 L
.29273 .43246 L
.29319 .43219 L
.29366 .43191 L
.29412 .43163 L
.29459 .43136 L
.29505 .43108 L
.29552 .43081 L
.29598 .43053 L
.29645 .43025 L
.29692 .42998 L
.29738 .4297 L
.29785 .42943 L
.29831 .42915 L
.29878 .42887 L
.29924 .4286 L
.29971 .42832 L
.30017 .42804 L
.30064 .42777 L
.3011 .42749 L
.30157 .42722 L
.30203 .42694 L
.3025 .42666 L
Mistroke
.30296 .42639 L
.30343 .42611 L
.30389 .42584 L
.30436 .42556 L
.30482 .42528 L
.30529 .42501 L
.30576 .42473 L
.30622 .42445 L
.30669 .42418 L
.30715 .4239 L
.30762 .42363 L
.30808 .42335 L
.30855 .42307 L
.30901 .4228 L
.30948 .42252 L
.30994 .42224 L
.31041 .42197 L
.31087 .42169 L
.31134 .42142 L
.3118 .42114 L
.31227 .42086 L
.31273 .42059 L
.3132 .42031 L
.31366 .42003 L
.31413 .41976 L
.3146 .41948 L
.31506 .4192 L
.31553 .41893 L
.31599 .41865 L
.31646 .41838 L
.31692 .4181 L
.31739 .41782 L
.31785 .41755 L
.31832 .41727 L
.31878 .41699 L
.31925 .41672 L
.31971 .41644 L
.32018 .41617 L
.32064 .41589 L
.32111 .41561 L
.32157 .41534 L
.32204 .41506 L
.3225 .41478 L
.32297 .41451 L
.32343 .41423 L
.3239 .41395 L
.32437 .41368 L
.32483 .4134 L
.3253 .41312 L
.32576 .41285 L
Mistroke
.32623 .41257 L
.32669 .4123 L
.32716 .41202 L
.32762 .41174 L
.32809 .41147 L
.32855 .41119 L
.32902 .41091 L
.32948 .41064 L
.32995 .41036 L
.33041 .41008 L
.33088 .40981 L
.33134 .40953 L
.33181 .40925 L
.33227 .40898 L
.33274 .4087 L
.33321 .40843 L
.33367 .40815 L
.33414 .40787 L
.3346 .4076 L
.33507 .40732 L
.33553 .40704 L
.336 .40677 L
.33646 .40649 L
.33693 .40621 L
.33739 .40594 L
.33786 .40566 L
.33832 .40538 L
.33879 .40511 L
.33925 .40483 L
.33972 .40455 L
.34018 .40428 L
.34065 .404 L
.34111 .40372 L
.34158 .40345 L
.34205 .40317 L
.34251 .40289 L
.34298 .40262 L
.34344 .40234 L
.34391 .40206 L
.34437 .40179 L
.34484 .40151 L
.3453 .40123 L
.34577 .40096 L
.34623 .40068 L
.3467 .40041 L
.34716 .40013 L
.34763 .39985 L
.34809 .39958 L
.34856 .3993 L
.34902 .39902 L
Mistroke
.34949 .39875 L
.34995 .39847 L
.35042 .39819 L
.35089 .39792 L
.35135 .39764 L
.35182 .39736 L
.35228 .39709 L
.35275 .39681 L
.35321 .39653 L
.35368 .39626 L
.35414 .39598 L
.35461 .3957 L
.35507 .39543 L
.35554 .39515 L
.356 .39487 L
.35647 .3946 L
.35693 .39432 L
.3574 .39404 L
.35786 .39377 L
.35833 .39349 L
.35879 .39321 L
.35926 .39294 L
.35973 .39266 L
.36019 .39238 L
.36066 .39211 L
.36112 .39183 L
.36159 .39155 L
.36205 .39128 L
.36252 .391 L
.36298 .39072 L
.36345 .39045 L
.36391 .39017 L
.36438 .38989 L
.36484 .38962 L
.36531 .38934 L
.36577 .38906 L
.36624 .38878 L
.3667 .38851 L
.36717 .38823 L
.36763 .38795 L
.3681 .38768 L
.36856 .3874 L
.36903 .38712 L
.3695 .38685 L
.36996 .38657 L
.37043 .38629 L
.37089 .38602 L
.37136 .38574 L
.37182 .38546 L
.37229 .38519 L
Mistroke
.37275 .38491 L
.37322 .38463 L
.37368 .38436 L
.37415 .38408 L
.37461 .3838 L
.37508 .38353 L
.37554 .38325 L
.37601 .38297 L
.37647 .3827 L
.37694 .38242 L
.3774 .38214 L
.37787 .38187 L
.37834 .38159 L
.3788 .38131 L
.37927 .38103 L
.37973 .38076 L
.3802 .38048 L
.38066 .3802 L
.38113 .37993 L
.38159 .37965 L
.38206 .37937 L
.38252 .3791 L
.38299 .37882 L
.38345 .37854 L
.38392 .37827 L
.38438 .37799 L
.38485 .37771 L
.38531 .37744 L
.38578 .37716 L
.38624 .37688 L
.38671 .37661 L
.38718 .37633 L
.38764 .37605 L
.38811 .37577 L
.38857 .3755 L
.38904 .37522 L
.3895 .37494 L
.38997 .37467 L
.39043 .37439 L
.3909 .37411 L
.39136 .37384 L
.39183 .37356 L
.39229 .37328 L
.39276 .37301 L
.39322 .37273 L
.39369 .37245 L
.39415 .37218 L
.39462 .3719 L
.39508 .37162 L
.39555 .37134 L
Mistroke
.39602 .37107 L
.39648 .37079 L
.39695 .37051 L
.39741 .37024 L
.39788 .36996 L
.39834 .36968 L
.39881 .36941 L
.39927 .36913 L
.39974 .36885 L
.4002 .36858 L
.40067 .3683 L
.40113 .36802 L
.4016 .36774 L
.40206 .36747 L
.40253 .36719 L
.40299 .36691 L
.40346 .36664 L
.40392 .36636 L
.40439 .36608 L
.40485 .36581 L
.40532 .36553 L
.40579 .36525 L
.40625 .36497 L
.40672 .3647 L
.40718 .36442 L
.40765 .36414 L
.40811 .36387 L
.40858 .36359 L
.40904 .36331 L
.40951 .36304 L
.40997 .36276 L
.41044 .36248 L
.4109 .36221 L
.41137 .36193 L
.41183 .36165 L
.4123 .36137 L
.41276 .3611 L
.41323 .36082 L
.41369 .36054 L
.41416 .36027 L
.41463 .35999 L
.41509 .35971 L
.41556 .35944 L
.41602 .35916 L
.41649 .35888 L
.41695 .3586 L
.41742 .35833 L
.41788 .35805 L
.41835 .35777 L
.41881 .3575 L
Mistroke
.41928 .35722 L
.41974 .35694 L
.42021 .35666 L
.42067 .35639 L
.42114 .35611 L
.4216 .35583 L
.42207 .35556 L
.42253 .35528 L
.423 .355 L
.42347 .35473 L
.42393 .35445 L
.4244 .35417 L
.42486 .35389 L
.42533 .35362 L
.42579 .35334 L
.42626 .35306 L
.42672 .35279 L
.42719 .35251 L
.42765 .35223 L
.42812 .35196 L
.42858 .35168 L
.42905 .3514 L
.42951 .35112 L
.42998 .35085 L
.43044 .35057 L
.43091 .35029 L
.43137 .35002 L
.43184 .34974 L
.43231 .34946 L
.43277 .34918 L
.43324 .34891 L
.4337 .34863 L
.43417 .34835 L
.43463 .34808 L
.4351 .3478 L
.43556 .34752 L
.43603 .34725 L
.43649 .34697 L
.43696 .34669 L
.43742 .34641 L
.43789 .34614 L
.43835 .34586 L
.43882 .34558 L
.43928 .34531 L
.43975 .34503 L
.44021 .34475 L
.44068 .34447 L
.44114 .3442 L
.44161 .34392 L
.44208 .34364 L
Mistroke
.44254 .34337 L
.44301 .34309 L
.44347 .34281 L
.44394 .34253 L
.4444 .34226 L
.44487 .34198 L
.44533 .3417 L
.4458 .34143 L
.44626 .34115 L
.44673 .34087 L
.44719 .34059 L
.44766 .34032 L
.44812 .34004 L
.44859 .33976 L
.44905 .33949 L
.44952 .33921 L
.44998 .33893 L
.45045 .33866 L
.45092 .33838 L
.45138 .3381 L
.45185 .33782 L
.45231 .33755 L
.45278 .33727 L
.45324 .33699 L
.45371 .33672 L
.45417 .33644 L
.45464 .33616 L
.4551 .33588 L
.45557 .33561 L
.45603 .33533 L
.4565 .33505 L
.45696 .33478 L
.45743 .3345 L
.45789 .33422 L
.45836 .33394 L
.45882 .33367 L
.45929 .33339 L
.45976 .33311 L
.46022 .33284 L
.46069 .33256 L
.46115 .33228 L
.46162 .332 L
.46208 .33173 L
.46255 .33145 L
.46301 .33117 L
.46348 .3309 L
.46394 .33062 L
.46441 .33034 L
.46487 .33006 L
.46534 .32979 L
Mistroke
.4658 .32951 L
.46627 .32923 L
.46673 .32896 L
.4672 .32868 L
.46766 .3284 L
.46813 .32812 L
.4686 .32785 L
.46906 .32757 L
.46953 .32729 L
.46999 .32702 L
.47046 .32674 L
.47092 .32646 L
.47139 .32618 L
.47185 .32591 L
.47232 .32563 L
.47278 .32535 L
.47325 .32508 L
.47371 .3248 L
.47418 .32452 L
.47464 .32424 L
.47511 .32397 L
.47557 .32369 L
.47604 .32341 L
.4765 .32314 L
.47697 .32286 L
.47744 .32258 L
.4779 .3223 L
.47837 .32203 L
.47883 .32175 L
.4793 .32147 L
.47976 .32119 L
.48023 .32092 L
.48069 .32064 L
.48116 .32036 L
.48162 .32009 L
.48209 .31981 L
.48255 .31953 L
.48302 .31925 L
.48348 .31898 L
.48395 .3187 L
.48441 .31842 L
.48488 .31815 L
.48534 .31787 L
.48581 .31759 L
.48627 .31731 L
.48674 .31704 L
.48721 .31676 L
.48767 .31648 L
.48814 .31621 L
.4886 .31593 L
Mistroke
.48907 .31565 L
.48953 .31537 L
.49 .3151 L
.49046 .31482 L
.49093 .31454 L
.49139 .31427 L
.49186 .31399 L
.49232 .31371 L
.49279 .31343 L
.49325 .31316 L
.49372 .31288 L
.49418 .3126 L
.49465 .31233 L
.49511 .31205 L
.49558 .31177 L
.49605 .31149 L
.49651 .31122 L
.49698 .31094 L
.49744 .31066 L
.49791 .31039 L
.49837 .31011 L
.49884 .30983 L
.4993 .30955 L
.49977 .30928 L
.50023 .309 L
.5007 .30872 L
.50116 .30844 L
.50163 .30817 L
.50209 .30789 L
.50256 .30761 L
.50302 .30734 L
.50349 .30706 L
.50395 .30678 L
.50442 .3065 L
.50489 .30623 L
.50535 .30595 L
.50582 .30567 L
.50628 .3054 L
.50675 .30512 L
.50721 .30484 L
.50768 .30456 L
.50814 .30429 L
.50861 .30401 L
.50907 .30373 L
.50954 .30346 L
.51 .30318 L
.51047 .3029 L
.51093 .30262 L
.5114 .30235 L
.51186 .30207 L
Mistroke
.51233 .30179 L
.51279 .30152 L
.51326 .30124 L
.51373 .30096 L
.51419 .30068 L
.51466 .30041 L
.51512 .30013 L
.51559 .29985 L
.51605 .29958 L
.51652 .2993 L
.51698 .29902 L
.51745 .29874 L
.51791 .29847 L
.51838 .29819 L
.51884 .29791 L
.51931 .29764 L
.51977 .29736 L
.52024 .29708 L
.5207 .2968 L
.52117 .29653 L
.52163 .29625 L
.5221 .29597 L
.52256 .2957 L
.52303 .29542 L
.5235 .29514 L
.52396 .29486 L
.52443 .29459 L
.52489 .29431 L
.52536 .29403 L
.52582 .29375 L
.52629 .29348 L
.52675 .2932 L
.52722 .29292 L
.52768 .29265 L
.52815 .29237 L
.52861 .29209 L
.52908 .29181 L
.52954 .29154 L
.53001 .29126 L
.53047 .29098 L
.53094 .29071 L
.5314 .29043 L
.53187 .29015 L
.53234 .28987 L
.5328 .2896 L
.53327 .28932 L
.53373 .28904 L
.5342 .28877 L
.53466 .28849 L
.53513 .28821 L
Mistroke
.53559 .28793 L
.53606 .28766 L
.53652 .28738 L
.53699 .2871 L
.53745 .28683 L
.53792 .28655 L
.53838 .28627 L
.53885 .28599 L
.53931 .28572 L
.53978 .28544 L
.54024 .28516 L
.54071 .28489 L
.54118 .28461 L
.54164 .28433 L
.54211 .28405 L
.54257 .28378 L
.54304 .2835 L
.5435 .28322 L
.54397 .28295 L
.54443 .28267 L
.5449 .28239 L
.54536 .28212 L
.54583 .28184 L
.54629 .28156 L
.54676 .28128 L
.54722 .28101 L
.54769 .28073 L
.54815 .28045 L
.54862 .28018 L
.54908 .2799 L
.54955 .27962 L
.55002 .27934 L
.55048 .27907 L
.55095 .27879 L
.55141 .27851 L
.55188 .27824 L
.55234 .27796 L
.55281 .27768 L
.55327 .2774 L
.55374 .27713 L
.5542 .27685 L
.55467 .27657 L
.55513 .2763 L
.5556 .27602 L
.55606 .27574 L
.55653 .27546 L
.55699 .27519 L
.55746 .27491 L
.55792 .27463 L
.55839 .27436 L
Mistroke
.55886 .27408 L
.55932 .2738 L
.55979 .27352 L
.56025 .27325 L
.56072 .27297 L
.56118 .27269 L
.56165 .27242 L
.56211 .27214 L
.56258 .27186 L
.56304 .27159 L
.56351 .27131 L
.56397 .27103 L
.56444 .27075 L
.5649 .27048 L
.56537 .2702 L
.56583 .26992 L
.5663 .26965 L
.56676 .26937 L
.56723 .26909 L
.56769 .26881 L
.56816 .26854 L
.56863 .26826 L
.56909 .26798 L
.56956 .26771 L
.57002 .26743 L
.57049 .26715 L
.57095 .26688 L
.57142 .2666 L
.57188 .26632 L
.57235 .26604 L
.57281 .26577 L
.57328 .26549 L
.57374 .26521 L
.57421 .26494 L
.57467 .26466 L
.57514 .26438 L
.5756 .2641 L
.57607 .26383 L
.57653 .26355 L
.577 .26327 L
.57747 .263 L
.57793 .26272 L
.5784 .26244 L
.57886 .26217 L
.57933 .26189 L
.57979 .26161 L
.58026 .26133 L
.58072 .26106 L
.58119 .26078 L
.58165 .2605 L
Mistroke
.58212 .26023 L
.58258 .25995 L
.58305 .25967 L
.58351 .2594 L
.58398 .25912 L
.58444 .25884 L
.58491 .25856 L
.58537 .25829 L
.58584 .25801 L
.58631 .25773 L
.58677 .25746 L
.58724 .25718 L
.5877 .2569 L
.58817 .25663 L
.58863 .25635 L
.5891 .25607 L
.58956 .25579 L
.59003 .25552 L
.59049 .25524 L
.59096 .25496 L
.59142 .25469 L
.59189 .25441 L
.59235 .25413 L
.59282 .25386 L
.59328 .25358 L
.59375 .2533 L
.59421 .25303 L
.59468 .25275 L
.59515 .25247 L
.59561 .25219 L
.59608 .25192 L
.59654 .25164 L
.59701 .25136 L
.59747 .25109 L
.59794 .25081 L
.5984 .25053 L
.59887 .25026 L
.59933 .24998 L
.5998 .2497 L
.60026 .24942 L
.60073 .24915 L
.60119 .24887 L
.60166 .24859 L
.60212 .24832 L
.60259 .24804 L
.60305 .24776 L
.60352 .24749 L
.60398 .24721 L
.60445 .24693 L
.60492 .24666 L
Mistroke
.60538 .24638 L
.60585 .2461 L
.60631 .24583 L
.60678 .24555 L
.60724 .24527 L
.60771 .24499 L
.60817 .24472 L
.60864 .24444 L
.6091 .24416 L
.60957 .24389 L
.61003 .24361 L
.6105 .24333 L
.61096 .24306 L
.61143 .24278 L
.61189 .2425 L
.61236 .24223 L
.61282 .24195 L
.61329 .24167 L
.61376 .2414 L
.61422 .24112 L
.61469 .24084 L
.61515 .24056 L
.61562 .24029 L
.61608 .24001 L
.61655 .23973 L
.61701 .23946 L
.61748 .23918 L
.61794 .2389 L
.61841 .23863 L
.61887 .23835 L
.61934 .23807 L
.6198 .2378 L
.62027 .23752 L
.62073 .23724 L
.6212 .23697 L
.62166 .23669 L
.62213 .23641 L
.6226 .23614 L
.62306 .23586 L
.62353 .23558 L
.62399 .23531 L
.62446 .23503 L
.62492 .23475 L
.62539 .23448 L
.62585 .2342 L
.62632 .23392 L
.62678 .23364 L
.62725 .23337 L
.62771 .23309 L
.62818 .23281 L
Mistroke
.62864 .23254 L
.62911 .23226 L
.62957 .23198 L
.63004 .23171 L
.6305 .23143 L
.63097 .23115 L
.63144 .23088 L
.6319 .2306 L
.63237 .23032 L
.63283 .23005 L
.6333 .22977 L
.63376 .22949 L
.63423 .22922 L
.63469 .22894 L
.63516 .22866 L
.63562 .22839 L
.63609 .22811 L
.63655 .22783 L
.63702 .22756 L
.63748 .22728 L
.63795 .227 L
.63841 .22673 L
.63888 .22645 L
.63934 .22617 L
.63981 .2259 L
.64027 .22562 L
.64074 .22534 L
.64121 .22507 L
.64167 .22479 L
.64214 .22451 L
.6426 .22424 L
.64307 .22396 L
.64353 .22368 L
.644 .22341 L
.64446 .22313 L
.64493 .22285 L
.64539 .22258 L
.64586 .2223 L
.64632 .22202 L
.64679 .22175 L
.64725 .22147 L
.64772 .22119 L
.64818 .22092 L
.64865 .22064 L
.64911 .22036 L
.64958 .22009 L
.65005 .21981 L
.65051 .21953 L
.65098 .21926 L
.65144 .21898 L
Mistroke
.65191 .2187 L
.65237 .21843 L
.65284 .21815 L
.6533 .21787 L
.65377 .2176 L
.65423 .21732 L
.6547 .21704 L
.65516 .21677 L
.65563 .21649 L
.65609 .21621 L
.65656 .21594 L
.65702 .21566 L
.65749 .21539 L
.65795 .21511 L
.65842 .21483 L
.65889 .21456 L
.65935 .21428 L
.65982 .214 L
.66028 .21373 L
.66075 .21345 L
.66121 .21317 L
.66168 .2129 L
.66214 .21262 L
.66261 .21234 L
.66307 .21207 L
.66354 .21179 L
.664 .21151 L
.66447 .21124 L
.66493 .21096 L
.6654 .21068 L
.66586 .21041 L
.66633 .21013 L
.66679 .20985 L
.66726 .20958 L
.66773 .2093 L
.66819 .20903 L
.66866 .20875 L
.66912 .20847 L
.66959 .2082 L
.67005 .20792 L
.67052 .20764 L
.67098 .20737 L
.67145 .20709 L
.67191 .20681 L
.67238 .20654 L
.67284 .20626 L
.67331 .20598 L
.67377 .20571 L
.67424 .20543 L
.6747 .20516 L
Mistroke
.67517 .20488 L
.67563 .2046 L
.6761 .20433 L
.67657 .20405 L
.67703 .20377 L
.6775 .2035 L
.67796 .20322 L
.67843 .20294 L
.67889 .20267 L
.67936 .20239 L
.67982 .20212 L
.68029 .20184 L
.68075 .20156 L
.68122 .20129 L
.68168 .20101 L
.68215 .20073 L
.68261 .20046 L
.68308 .20018 L
.68354 .1999 L
.68401 .19963 L
.68447 .19935 L
.68494 .19908 L
.6854 .1988 L
.68587 .19852 L
.68634 .19825 L
.6868 .19797 L
.68727 .19769 L
.68773 .19742 L
.6882 .19714 L
.68866 .19687 L
.68913 .19659 L
.68959 .19631 L
.69006 .19604 L
.69052 .19576 L
.69099 .19548 L
.69145 .19521 L
.69192 .19493 L
.69238 .19466 L
.69285 .19438 L
.69331 .1941 L
.69378 .19383 L
.69424 .19355 L
.69471 .19327 L
.69518 .193 L
.69564 .19272 L
.69611 .19245 L
.69657 .19217 L
.69704 .19189 L
.6975 .19162 L
.69797 .19134 L
Mistroke
.69843 .19107 L
.6989 .19079 L
.69936 .19051 L
.69983 .19024 L
.70029 .18996 L
.70076 .18968 L
.70122 .18941 L
.70169 .18913 L
.70215 .18886 L
.70262 .18858 L
.70308 .1883 L
.70355 .18803 L
.70402 .18775 L
.70448 .18748 L
.70495 .1872 L
.70541 .18692 L
.70588 .18665 L
.70634 .18637 L
.70681 .18609 L
.70727 .18582 L
.70774 .18554 L
.7082 .18527 L
.70867 .18499 L
.70913 .18471 L
.7096 .18444 L
.71006 .18416 L
.71053 .18389 L
.71099 .18361 L
.71146 .18333 L
.71192 .18306 L
.71239 .18278 L
.71286 .18251 L
.71332 .18223 L
.71379 .18195 L
.71425 .18168 L
.71472 .1814 L
.71518 .18113 L
.71565 .18085 L
.71611 .18057 L
.71658 .1803 L
.71704 .18002 L
.71751 .17975 L
.71797 .17947 L
.71844 .17919 L
.7189 .17892 L
.71937 .17864 L
.71983 .17837 L
.7203 .17809 L
.72076 .17782 L
.72123 .17754 L
Mistroke
.72169 .17726 L
.72216 .17699 L
.72263 .17671 L
.72309 .17644 L
.72356 .17616 L
.72402 .17588 L
.72449 .17561 L
.72495 .17533 L
.72542 .17506 L
.72588 .17478 L
.72635 .1745 L
.72681 .17423 L
.72728 .17395 L
.72774 .17368 L
.72821 .1734 L
.72867 .17313 L
.72914 .17285 L
.7296 .17257 L
.73007 .1723 L
.73053 .17202 L
.731 .17175 L
.73147 .17147 L
.73193 .17119 L
.7324 .17092 L
.73286 .17064 L
.73333 .17037 L
.73379 .17009 L
.73426 .16982 L
.73472 .16954 L
.73519 .16926 L
.73565 .16899 L
.73612 .16871 L
.73658 .16844 L
.73705 .16816 L
.73751 .16789 L
.73798 .16761 L
.73844 .16733 L
.73891 .16706 L
.73937 .16678 L
.73984 .16651 L
.74031 .16623 L
.74077 .16596 L
.74124 .16568 L
.7417 .1654 L
.74217 .16513 L
.74263 .16485 L
.7431 .16458 L
.74356 .1643 L
.74403 .16403 L
.74449 .16375 L
Mistroke
.74496 .16348 L
.74542 .1632 L
.74589 .16292 L
.74635 .16265 L
.74682 .16237 L
.74728 .1621 L
.74775 .16182 L
.74821 .16155 L
.74868 .16127 L
.74915 .161 L
.74961 .16072 L
.75008 .16044 L
.75054 .16017 L
.75101 .15989 L
.75147 .15962 L
.75194 .15934 L
.7524 .15907 L
.75287 .15879 L
.75333 .15852 L
.7538 .15824 L
.75426 .15796 L
.75473 .15769 L
.75519 .15741 L
.75566 .15714 L
.75612 .15686 L
.75659 .15659 L
.75705 .15631 L
.75752 .15604 L
.75798 .15576 L
.75845 .15549 L
.75892 .15521 L
.75938 .15493 L
.75985 .15466 L
.76031 .15438 L
.76078 .15411 L
.76124 .15383 L
.76171 .15356 L
.76217 .15328 L
.76264 .15301 L
.7631 .15273 L
.76357 .15246 L
.76403 .15218 L
.7645 .15191 L
.76496 .15163 L
.76543 .15135 L
.76589 .15108 L
.76636 .1508 L
.76682 .15053 L
.76729 .15025 L
.76776 .14998 L
Mistroke
.76822 .1497 L
.76869 .14943 L
.76915 .14915 L
.76962 .14888 L
.77008 .1486 L
.77055 .14833 L
.77101 .14805 L
.77148 .14778 L
.77194 .1475 L
.77241 .14723 L
.77287 .14695 L
.77334 .14668 L
.7738 .1464 L
.77427 .14613 L
.77473 .14585 L
.7752 .14557 L
.77566 .1453 L
.77613 .14502 L
.7766 .14475 L
.77706 .14447 L
.77753 .1442 L
.77799 .14392 L
.77846 .14365 L
.77892 .14337 L
.77939 .1431 L
.77985 .14282 L
.78032 .14255 L
.78078 .14227 L
.78125 .142 L
.78171 .14172 L
.78218 .14145 L
.78264 .14117 L
.78311 .1409 L
.78357 .14062 L
.78404 .14035 L
.7845 .14007 L
.78497 .1398 L
.78544 .13952 L
.7859 .13925 L
.78637 .13897 L
.78683 .1387 L
.7873 .13842 L
.78776 .13815 L
.78823 .13787 L
.78869 .1376 L
.78916 .13732 L
.78962 .13705 L
.79009 .13677 L
.79055 .1365 L
.79102 .13622 L
Mistroke
.79148 .13595 L
.79195 .13567 L
.79241 .1354 L
.79288 .13512 L
.79334 .13485 L
.79381 .13457 L
.79428 .1343 L
.79474 .13402 L
.79521 .13375 L
.79567 .13347 L
.79614 .1332 L
.7966 .13293 L
.79707 .13265 L
.79753 .13238 L
.798 .1321 L
.79846 .13183 L
.79893 .13155 L
.79939 .13128 L
.79986 .131 L
.80032 .13073 L
.80079 .13045 L
.80125 .13018 L
.80172 .1299 L
.80218 .12963 L
.80265 .12935 L
.80311 .12908 L
.80358 .1288 L
.80405 .12853 L
.80451 .12825 L
.80498 .12798 L
.80544 .12771 L
.80591 .12743 L
.80637 .12716 L
.80684 .12688 L
.8073 .12661 L
.80777 .12633 L
.80823 .12606 L
.8087 .12578 L
.80916 .12551 L
.80963 .12523 L
.81009 .12496 L
.81056 .12468 L
.81102 .12441 L
.81149 .12414 L
.81195 .12386 L
.81242 .12359 L
.81289 .12331 L
.81335 .12304 L
.81382 .12276 L
.81428 .12249 L
Mistroke
.81475 .12221 L
.81521 .12194 L
.81568 .12166 L
.81614 .12139 L
.81661 .12112 L
.81707 .12084 L
.81754 .12057 L
.818 .12029 L
.81847 .12002 L
.81893 .11974 L
.8194 .11947 L
.81986 .11919 L
.82033 .11892 L
.82079 .11865 L
.82126 .11837 L
.82173 .1181 L
.82219 .11782 L
.82266 .11755 L
.82312 .11727 L
.82359 .117 L
.82405 .11673 L
.82452 .11645 L
.82498 .11618 L
.82545 .1159 L
.82591 .11563 L
.82638 .11535 L
.82684 .11508 L
.82731 .11481 L
.82777 .11453 L
.82824 .11426 L
.8287 .11398 L
.82917 .11371 L
.82963 .11343 L
.8301 .11316 L
.83057 .11289 L
.83103 .11261 L
.8315 .11234 L
.83196 .11206 L
.83243 .11179 L
.83289 .11152 L
.83336 .11124 L
.83382 .11097 L
.83429 .11069 L
.83475 .11042 L
.83522 .11015 L
.83568 .10987 L
.83615 .1096 L
.83661 .10932 L
.83708 .10905 L
.83754 .10878 L
Mistroke
.83801 .1085 L
.83847 .10823 L
.83894 .10795 L
.8394 .10768 L
.83987 .1074 L
.84034 .10713 L
.8408 .10686 L
.84127 .10658 L
.84173 .10631 L
.8422 .10603 L
.84266 .10576 L
.84313 .10549 L
.84359 .10521 L
.84406 .10494 L
.84452 .10467 L
.84499 .10439 L
.84545 .10412 L
.84592 .10384 L
.84638 .10357 L
.84685 .1033 L
.84731 .10302 L
.84778 .10275 L
.84824 .10247 L
.84871 .1022 L
.84918 .10193 L
.84964 .10165 L
.85011 .10138 L
.85057 .10111 L
.85104 .10083 L
.8515 .10056 L
.85197 .10028 L
.85243 .10001 L
.8529 .09974 L
.85336 .09946 L
.85383 .09919 L
.85429 .09892 L
.85476 .09864 L
.85522 .09837 L
.85569 .09809 L
.85615 .09782 L
.85662 .09755 L
.85708 .09727 L
.85755 .097 L
.85802 .09673 L
.85848 .09645 L
.85895 .09618 L
.85941 .09591 L
.85988 .09563 L
.86034 .09536 L
.86081 .09509 L
Mistroke
.86127 .09481 L
.86174 .09454 L
.8622 .09426 L
.86267 .09399 L
.86313 .09372 L
.8636 .09344 L
.86406 .09317 L
.86453 .0929 L
.86499 .09262 L
.86546 .09235 L
.86592 .09208 L
.86639 .0918 L
.86686 .09153 L
.86732 .09126 L
.86779 .09098 L
.86825 .09071 L
.86872 .09044 L
.86918 .09016 L
.86965 .08989 L
.87011 .08962 L
.87058 .08934 L
.87104 .08907 L
.87151 .0888 L
.87197 .08852 L
.87244 .08825 L
.8729 .08798 L
.87337 .0877 L
.87383 .08743 L
.8743 .08716 L
.87476 .08688 L
.87523 .08661 L
.87569 .08634 L
.87616 .08606 L
.87663 .08579 L
.87709 .08552 L
.87756 .08525 L
.87802 .08497 L
.87849 .0847 L
.87895 .08443 L
.87942 .08415 L
.87988 .08388 L
.88035 .08361 L
.88081 .08333 L
.88128 .08306 L
.88174 .08279 L
.88221 .08251 L
.88267 .08224 L
.88314 .08197 L
.8836 .0817 L
.88407 .08142 L
Mistroke
.88453 .08115 L
.885 .08088 L
.88547 .0806 L
.88593 .08033 L
.8864 .08006 L
.88686 .07978 L
.88733 .07951 L
.88779 .07924 L
.88826 .07897 L
.88872 .07869 L
.88919 .07842 L
.88965 .07815 L
.89012 .07787 L
.89058 .0776 L
.89105 .07733 L
.89151 .07706 L
.89198 .07678 L
.89244 .07651 L
.89291 .07624 L
.89337 .07597 L
.89384 .07569 L
.89431 .07542 L
.89477 .07515 L
.89524 .07488 L
.8957 .0746 L
.89617 .07433 L
.89663 .07406 L
.8971 .07378 L
.89756 .07351 L
.89803 .07324 L
.89849 .07297 L
.89896 .07269 L
.89942 .07242 L
.89989 .07215 L
.90035 .07188 L
.90082 .0716 L
.90128 .07133 L
.90175 .07106 L
.90221 .07079 L
.90268 .07051 L
.90315 .07024 L
.90361 .06997 L
.90408 .0697 L
.90454 .06942 L
.90501 .06915 L
.90547 .06888 L
.90594 .06861 L
.9064 .06833 L
.90687 .06806 L
.90733 .06779 L
Mistroke
.9078 .06752 L
.90826 .06724 L
.90873 .06697 L
.90919 .0667 L
.90966 .06643 L
.91012 .06616 L
.91059 .06588 L
.91105 .06561 L
.91152 .06534 L
.91199 .06507 L
.91245 .06479 L
.91292 .06452 L
.91338 .06425 L
.91385 .06398 L
.91431 .06371 L
.91478 .06343 L
.91524 .06316 L
.91571 .06289 L
.91617 .06262 L
.91664 .06234 L
.9171 .06207 L
.91757 .0618 L
.91803 .06153 L
.9185 .06126 L
.91896 .06098 L
.91943 .06071 L
.91989 .06044 L
.92036 .06017 L
.92082 .0599 L
.92129 .05962 L
.92176 .05935 L
.92222 .05908 L
.92269 .05881 L
.92315 .05854 L
.92362 .05826 L
.92408 .05799 L
.92455 .05772 L
.92501 .05745 L
.92548 .05718 L
.92594 .0569 L
.92641 .05663 L
.92687 .05636 L
.92734 .05609 L
.9278 .05582 L
.92827 .05555 L
.92873 .05527 L
.9292 .055 L
.92966 .05473 L
.93013 .05446 L
.9306 .05419 L
Mistroke
.93106 .05392 L
.93153 .05364 L
.93199 .05337 L
.93246 .0531 L
.93292 .05283 L
.93339 .05256 L
.93385 .05229 L
.93432 .05202 L
.93478 .05174 L
.93525 .05147 L
.93571 .0512 L
.93618 .05093 L
.93664 .05066 L
.93711 .05038 L
.93757 .05011 L
.93804 .04984 L
.9385 .04957 L
.93897 .0493 L
.93944 .04903 L
.9399 .04876 L
.94037 .04849 L
.94083 .04821 L
.9413 .04794 L
.94176 .04767 L
.94223 .0474 L
.94269 .04713 L
.94316 .04686 L
.94362 .04659 L
.94409 .04631 L
.94455 .04604 L
.94502 .04577 L
.94548 .0455 L
.94595 .04523 L
.94641 .04496 L
.94688 .04469 L
.94734 .04442 L
.94781 .04414 L
.94828 .04387 L
.94874 .0436 L
.94921 .04333 L
.94967 .04306 L
.95014 .04279 L
.9506 .04252 L
.95107 .04225 L
.95153 .04198 L
.952 .0417 L
.95246 .04143 L
.95293 .04116 L
.95339 .04089 L
.95386 .04062 L
Mistroke
.95432 .04035 L
.95479 .04008 L
.95525 .03981 L
.95572 .03954 L
.95618 .03927 L
.95665 .039 L
.95711 .03873 L
.95758 .03845 L
.95805 .03818 L
.95851 .03792 L
.95898 .03764 L
.95944 .03737 L
.95991 .0371 L
.96037 .03683 L
.96084 .03656 L
.9613 .03629 L
.96177 .03602 L
.96223 .03576 L
.9627 .03548 L
.96316 .03521 L
.96363 .03495 L
.96409 .03468 L
.96456 .03441 L
.96502 .03414 L
.96549 .03388 L
.96595 .03361 L
.96642 .03335 L
.96689 .03308 L
.96735 .03282 L
.96782 .03256 L
.96828 .0323 L
.96875 .03203 L
.96921 .03178 L
.96968 .03153 L
.97014 .03127 L
.97061 .03102 L
.97107 .03077 L
.97154 .03053 L
.972 .03028 L
.97247 .03004 L
.97293 .02981 L
.9734 .02958 L
.97386 .02935 L
.97433 .02911 L
.97479 .02891 L
.97526 .02871 L
.97573 .02848 L
.97619 .02825 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008oooool2o`0002gooooo0ol00004ooooo`;o00001?ooool2o`0002Kooooo1Ol00003oooo
o`;o00001?ooool2o`0002Oooooo0ol00004ooooo`;o00001?ooool2o`0002Wooooo0ol00003oooo
o`;o00001?ooool2o`0001cooooo000Rooooo`04o`000?ooooooooooo`0002gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Kooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
02Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000:Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0Iooooo`008_ooool01?l0003oooooooooool0000]oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Wooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Yooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Tooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0001_ooooo000Rooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Sooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool09Ooo
ool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Vooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Kooooo`008_ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Uooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Wooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001_ooooo000Rooooo`04o`000?ooooooooooo`0002cooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00009Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Uooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002So
oooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006oooool0
02?ooooo0_l0000^ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00009oooool3o`00
00Cooooo0_l00004ooooo`;o00009oooool3o`0000Cooooo0_l00004ooooo`;o0000:_ooool00ol0
003oooooooooo`02ooooo`;o00001?ooool2o`0001cooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo000NooooooSo00002_ooool001kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000[ooooo000Nooooo`03
o`000?oooooooooo0?Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
m?ooool00ol0003oooooooooo`08ooooo`005oooool2o`0000Gooooo00?o0000ooooooooool0m?oo
ool00ol0003oooooooooo`08ooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo0?Cooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000Fooooo`04o`000?oooooo
ooooo`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo0_l000001?oooooo0000o`00
0?ooool3o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000003o`000003oooo
ool0003ooooo00Co000000?oooooo`000?l000001_ooool01?l0003oooooo`000?ooool5o`000003
ooooool0003o000000So00000_ooool2o`000003ooooool0003o000000co000000?oooooo`000?l0
00000ol000001Ooooooo0000o`000?oooooo000000?ooooo0ol000001?oooooo0000o`000?l00003
ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`02o`000003ooooool0003o000004co0000
00Coooooo`000?l0003o00000_ooool00ol0003oooooo`000002oooooaSo00000_oo0004ooooo`;o
00002_ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`08
o`000?oooooo0000ooooool0003oooooo`000?ooool2o`000003ooooool0003o000000Co000000?o
ooooo`000?l00000Bol000000ooooooo0000o`000002ooooo`03o`000?oooooo000000;o000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003ooooo05co000000?oooooo`000?ooool05Ooo
ool2ool000Oooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`04ooooo`08o`000?oooooo0000ooooool0003oooooo`000?oooomHo`00
0003ooooool0003ooooo00;o00001_ooool01?l0003oooooo`000?ooool^o`0002Gooooo3Ol00000
0ooooooo0000ooooo`0Cooooo`?oo`002?ooool00ol0003oooooooooo`08ooooo`005oooool2o`00
00Gooooo00?o0000ooooooooool01?ooool3o`000003ooooool0003o000005[o000000Coooooo`00
0?l0003o00001oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000008ol0000]
ooooo`Wo000000?oooooo`000?ooool04Oooool3ool000[ooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01?ooool3o`000003ooooool0003o000004So00000_ooool4o`00
00?ooooo00?o0000ooooool00000K_ooool9o`00017ooooo0_oo000<ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo;_l000001?oooooo0000o`000?l0002Hoooo
o`Oo00003oooool3ool000gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool01?oooolQo`000:gooooo0_l0000>ooooo`?oo`003oooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0000Gooooo6?l0002gooooo`03o`000?oooooooooo00[ooooo0ooo000@ooooo`;o0000
2_ooool001kooooo00?o0000ooooooooool01?oooolEo`000;[ooooo00?o0000ooooooooool02Ooo
ool2ool001?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool?
o`000003ooooool0003ooooo0<Oooooo0ooo000Dooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Cooooo3?l0003;ooooo`?oo`005_ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`04ooooo`[o0000c?ooool2ool001Sooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool01?ooool8o`000<cooooo0_oo000Jooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`;o00001Oooool6o`000<cooooo0ooo000Jooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool00oooool7o`000<_ooooo0_oo000Mooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo1ol00039ooooo`;oo`007oooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`Go0000bOooool3ool0023o
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool5o`000<Oooooo
0ooo000Rooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo1?l0
0037ooooo`;oo`009?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03
ooooo`Co0000aOooool3ool002Gooooo00?o0000ooooooooool02?ooool001kooooo0_l00004oooo
o`?o0000a?ooool3ool002Kooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`?o
0000`oooool2ool002Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
0oooool3o`000<7ooooo0ooo000Zooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00?ooooo0ol0002oooooo`?oo`00;?ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o0000_oooool2ool002kooooo00?o0000ooooooooool02?ooool0
00_ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`03
ooooo`;o0000_Oooool2ool0033ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo0_l0
002kooooo`?oo`00<Oooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o0000^Oooool3ool003;ooooo0_l0
000:ooooo`002_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool2o`000;Sooooo0_oo000eooooo`03o`000?oooooooooo00Sooooo000:
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00?ooooo0_l0002fooooo`?oo`00=_ooool00ol0003oooooooooo`08ooooo`002_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`03ooooo`;o0000]?ooool3ool003Sooooo00?o0000ooooooooool02?ooool000_ooooo
0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`;o0000/oooool2ool003[ooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool2o`000;7ooooo0ooo
000kooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0002_
ooooo`?oo`00?Oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo0_l0002^oooo
o`;oo`00?_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0002/ooooo`;o
o`00@Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000
Z_ooool3ool004;ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00ooo
ool2o`000:Wooooo0_oo0014ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Y_ooool2ool004Kooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Tooooo`?oo`00Aoooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:;o
oooo0ooo0019ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003ooooo
ooooo`2Qooooo`;oo`00B_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0Woooool3ool004cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`2Mooooo`?oo`00C_ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09cooooo0_oo001@oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0V_ooool3ool0057ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2Hooooo`?oo`00Doooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09Oooooo0_oo001Eooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`2Eooooo`?oo`00EOooool2
o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Toooool3ool0
05Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2Booooo`;oo`00F_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo093ooooo0ooo001Kooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0S_ooool3ool005gooooo00?o
0000ooooooooool02?ooool000_ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0SOooool2ool005oooooo00?o0000
ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Roooool3ool0063ooooo00?o0000
ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo0_l00004
ooooo`03o`000?oooooooooo08Wooooo0ooo001Qooooo`;o00002_ooool000[ooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0R?ooool2ool006Cooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0Q_ooool2ool006Kooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000
oooooooooooo00002Oooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`24ooooo`?oo`00Ioooool00ol0003oooooooooo`08ooooo`002oooool2o`0000_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08?ooooo0_oo001Y
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0POooool3ool006[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1oooooo`?oo`00K?ooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0000Cooooo00?o0000ooooooooool0O_ooool2ool006gooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07cooooo0_oo001`ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0N_ooool3
ool0077ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1iooooo`;oo`00Loooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo07Oooooo0_oo001eooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0MOooool3ool007Kooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1cooooo`?oo`00N?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000
ooooooooool0L_ooool2ool007Wooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo073ooooo0ooo001kooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0K_ooool3ool007gooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1]ooooo`;oo`00
Ooooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo06_ooooo0ooo0020ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0JOooool3ool008;ooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Xooooo`;oo`00Q?ooool00ol0
003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0I_ooool3ool008Co
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo
0ooo0027ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0Hoooool2ool008Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Qooooo`?oo`00R_ooool00ol0003oooooooooo`08
ooooo`002oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Oooooo`?oo`00S?ooool00ol0003oooooooooo`08oooo
o`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo0_oo002>ooooo`03o`000?oooooo
oooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G?ooool2ool0093ooooo00?o
0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo0_l0
0004ooooo`03o`000?oooooooooo05[ooooo0ooo002@ooooo`;o00002_ooool000[ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0FOooool2ool009?ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0Eoooool3ool009Cooooo00?o0000ooooooooool02?ooool000_ooooo0_l0000:
ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Gooooo0ooo002F
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0E?ooool2ool009Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Booooo`;oo`00V_ooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo053ooooo0ooo002Kooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`;oo`00W?oo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool2
ool009oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1;ooooo`?oo`00X?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04Wooooo0ooo002Rooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B?ooool2ool00:Cooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`16ooooo`?oo`00YOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04Cooooo0ooo002Wooooo`03o`000?oooooooooo00Sooooo000Noooo
o`;o00001?ooool00ol0003oooooooooo`13ooooo`;oo`00Z?ooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0@Oooool3ool00:[ooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0oooooo`?oo`00
[?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03kooooo0_oo002^ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0??ooool3ool00:oooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0jooooo`?oo`00/Oooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Wo
oooo0_oo002cooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003ooooo
ooooo`0gooooo`;oo`00]?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0=Oooool3ool00;Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0dooooo`;oo`00^?ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo0_oo002joooo
o`03o`000?oooooooooo00Sooooo000;ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo0ooo002kooooo`03
o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool3ool0
0;gooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]
ooooo`;oo`00_oooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00008
ooooo`?o00001Oooool2o`0000Cooooo00?o0000ooooooooool0:oooool3ool00;oooooo0_l0000:
ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Wooooo0ooo0032ooooo`03o`000?oo
oooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool2ool00<Cooooo
00?o0000ooooooooool02?ooool000_ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Kooooo0ooo0035ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool3ool00<Oooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Soooo
o`;oo`00bOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo027ooooo0ooo003:ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000
1?ooool00ol0003oooooooooo`0Oooooo`?oo`00boooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool07_ooool2ool00<kooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`;oo`00d?ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01[ooooo0ooo003Aooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool06Oooool2ool00=?ooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`;oo`00eOooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo0ooo
003Fooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`0C
ooooo`?oo`00eoooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04_ooool2ool00=[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0@ooooo`;oo`00g?ooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo0ooo003Mooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Ooo
ool2ool00=oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0;ooooo`;oo`00hOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0ooo003Rooooo`03o`000?oooooooooo
00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`?oo`00hoooool2o`0000[o
oooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool2ool00>Kooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`?oo`00ioooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo0ooo003Yooooo`03o`000?oooooooooo00Sooooo000Foooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;oo`00joooool0
0ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooo003oo`00kOooool00ol0003oooooooooo`08ooooo`005oooool00ol0
003oooooooooo`04ooooo`;o00001?ooool3ool00>gooooo0_l0000:ooooo`005oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool02?ooool001Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Sooooo
000Fooooo`;o00001_ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000G
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000:oooo
o`007_oooooho`0000[ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo0015ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`0000?o
oooo1?l00003ooooo`;o000000?oooooo`000?l000001?l00002ooooo`Co00000oooool2o`0000;o
oooo1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o000000Oooooo0ol00002ooooo`?o
00001?ooool4o`000005ooooool0003o0000o`000?ooool01_l00002ooooo`Go00000_ooool3o`00
00;ooooo0ol00009ooooo`?o00001Oooool2o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?ooooo
o`000?l00000<oooool004Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000dooooo`00AOooool01ol0003ooooooooo
oooooooo0000ooooool000000oooool00ol0003oooooo`000002ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol00003ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`04o`000?oooooooooooooo
o`Go00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0booooo`00AOooool01ol0003ooooooooooooooooo0000ooooool000000oooool0
0ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00Co0000oooooooooooo00000ooo
ool01_l0003oooooooooool0003oooooo`0000Oooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00;o00002_ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0b
ooooo`00AOooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`?o00000_ooool2
o`000003ooooool0003o000000?ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo1?l00002
ooooo`?o00001?ooool3o`0000;ooooo1?l00008ooooo`06o`000?oooooo0000ooooool0003ooooo
0_l000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000?ooooo1?l00002ooooo`Co0000
0_ooool3o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oooooooooo00;ooooo
0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co00000_ooool3o`0000Co
oooo0ol00002ooooo`Co0000=Oooool004Gooooo0_l000000ooooooo0000o`00000:ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`05o`00
0?oooooo0000ooooool000006oooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`00
01Cooooo00?o0000ooooooooool0Aoooool004Gooooo00Co0000oooooooooooooooo0_l00008oooo
o`;o00002?ooool3o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Coooo
o`Go00007?ooool2o`0001?ooooo1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0@?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-66.9601, -0.137062, \
1.84546, 0.00720095}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] 0.49966958432041564`\), 
        ",", \(BackFocalLength \[Rule] 93.35095557506479`\), 
        ",", \(BackFocalPoint \[Rule] {153.3509555750648`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] 0.8219598943548624`\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] 0\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {50.`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.583004929987583`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {53.41699507001242`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 1\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 1, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FindPupils \[Rule] Automatic\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 99.93396050505237`\), 
        ",", \(FrequencyCutoff \[Rule] 868.8319726425336`\), 
        ",", \(FrontFocalLength \[Rule] 99.93396050505234`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-49.93396050505234`\), 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {148.87046813964844`, 0, 0}\), 
        ",", \(ImageSampleSize \[Rule] 0.0006198792566778751`\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[100, 50, 10], 50.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[Screen[50], {x, 150.`}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(IntensityTransform \[Rule] True\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.9341264481391712`, 
              6.583004929987581`}, {\(-0.010006608313591684`\), 
              0.9999999999999998`}}\), ",", 
        RowBox[{"ModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 434.4159863212668`}}, "<>"]\),
            
            False,
            Editable->False]}], ",", \(NormalizePlot \[Rule] True\), 
        ",", \(NumberOfPoints \[Rule] 2048\), 
        ",", \(NumberOfRays \[Rule] 128\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(LineOfRays[45, NumberOfRays \[Rule] 11]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 58.623425541371006`\), ",", 
        
        RowBox[{"OpticalLengthFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-22.67402161424078`\), 
                  22.67402161424078`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-22.67402161424078`\), 
                  22.67402161424078`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {58.623425541371006`, 
            58.67261123306858`}\), ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"ModulationTransferFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PaddingFactor \[Rule] Automatic\), 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
        RowBox[{"PerfectModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 434.4159863212668`}}, "<>"]\),
            
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPhaseTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 434.4159863212668`}}, "<>"]\),
            
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.6341364795814662`\), 
                  0.6347563588381441`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PhaseTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 434.4159863212668`}}, "<>"]\),
            
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] True\), 
        ",", \(PlotPoints \[Rule] 64\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.6341364795814662`\), 
                  0.6347563588381441`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{50.00000000000003`, 0, 
              0}, {53.41699507001243`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 3.4169950700124048`\), 
        ",", \(RayBoundary \[Rule] {\(-22.67402161424078`\), 
            22.67402161424078`}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {ModulationTransferFunction, 
            PointSpreadFunction, OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] True\), 
        ",", \(ShowPerfectCase \[Rule] True\), 
        ",", \(SignalPlotCutoff \[Rule] 0.01`\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 2190\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.009322615022828462`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{0.033531699915919685`, 
              98.25958992578354`}, {\(-0.010006608313591682`\), 
              0.49966958432041564`}}\), 
        ",", \(TransverseMagnification \[Rule] 0.033531699915919685`\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-24.03642036129138`\), 
                  23.979154821806738`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[72]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
OpticalTransferFunction[sys, NumberOfPoints->1024, NumberOfRays->2048, \
FindImagePoint->True, IntensityTransform->False]\
\>", "Input",
  CellLabel->"In[75]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0210016 -701.422 11.9651 [
[.07997 -0.0125 -9 -9 ]
[.07997 -0.0125 9 0 ]
[.28998 -0.0125 -9 -9 ]
[.28998 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.71002 -0.0125 -6 -9 ]
[.71002 -0.0125 6 0 ]
[.92003 -0.0125 -6 -9 ]
[.92003 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09347 -30 -4.5 ]
[-0.0125 .09347 0 4.5 ]
[-0.0125 .21312 -30 -4.5 ]
[-0.0125 .21312 0 4.5 ]
[-0.0125 .33277 -30 -4.5 ]
[-0.0125 .33277 0 4.5 ]
[-0.0125 .45242 -30 -4.5 ]
[-0.0125 .45242 0 4.5 ]
[-0.0125 .57207 -30 -4.5 ]
[-0.0125 .57207 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07997 0 m
.07997 .00625 L
s
[(-20)] .07997 -0.0125 0 1 Mshowa
.28998 0 m
.28998 .00625 L
s
[(-10)] .28998 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.71002 0 m
.71002 .00625 L
s
[(10)] .71002 -0.0125 0 1 Mshowa
.92003 0 m
.92003 .00625 L
s
[(20)] .92003 -0.0125 0 1 Mshowa
.125 Mabswid
.12197 0 m
.12197 .00375 L
s
.16397 0 m
.16397 .00375 L
s
.20598 0 m
.20598 .00375 L
s
.24798 0 m
.24798 .00375 L
s
.33199 0 m
.33199 .00375 L
s
.37399 0 m
.37399 .00375 L
s
.41599 0 m
.41599 .00375 L
s
.458 0 m
.458 .00375 L
s
.542 0 m
.542 .00375 L
s
.58401 0 m
.58401 .00375 L
s
.62601 0 m
.62601 .00375 L
s
.66801 0 m
.66801 .00375 L
s
.75202 0 m
.75202 .00375 L
s
.79402 0 m
.79402 .00375 L
s
.83603 0 m
.83603 .00375 L
s
.87803 0 m
.87803 .00375 L
s
.03797 0 m
.03797 .00375 L
s
.96203 0 m
.96203 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09347 m
.00625 .09347 L
s
[(58.63)] -0.0125 .09347 1 0 Mshowa
0 .21312 m
.00625 .21312 L
s
[(58.64)] -0.0125 .21312 1 0 Mshowa
0 .33277 m
.00625 .33277 L
s
[(58.65)] -0.0125 .33277 1 0 Mshowa
0 .45242 m
.00625 .45242 L
s
[(58.66)] -0.0125 .45242 1 0 Mshowa
0 .57207 m
.00625 .57207 L
s
[(58.67)] -0.0125 .57207 1 0 Mshowa
.125 Mabswid
0 .1174 m
.00375 .1174 L
s
0 .14133 m
.00375 .14133 L
s
0 .16526 m
.00375 .16526 L
s
0 .18919 m
.00375 .18919 L
s
0 .23705 m
.00375 .23705 L
s
0 .26098 m
.00375 .26098 L
s
0 .28491 m
.00375 .28491 L
s
0 .30884 m
.00375 .30884 L
s
0 .3567 m
.00375 .3567 L
s
0 .38063 m
.00375 .38063 L
s
0 .40456 m
.00375 .40456 L
s
0 .42849 m
.00375 .42849 L
s
0 .47635 m
.00375 .47635 L
s
0 .50028 m
.00375 .50028 L
s
0 .52421 m
.00375 .52421 L
s
0 .54814 m
.00375 .54814 L
s
0 .06954 m
.00375 .06954 L
s
0 .04561 m
.00375 .04561 L
s
0 .02168 m
.00375 .02168 L
s
0 .596 m
.00375 .596 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07997 .61178 m
.07997 .61803 L
s
.28998 .61178 m
.28998 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.71002 .61178 m
.71002 .61803 L
s
.92003 .61178 m
.92003 .61803 L
s
.125 Mabswid
.12197 .61428 m
.12197 .61803 L
s
.16397 .61428 m
.16397 .61803 L
s
.20598 .61428 m
.20598 .61803 L
s
.24798 .61428 m
.24798 .61803 L
s
.33199 .61428 m
.33199 .61803 L
s
.37399 .61428 m
.37399 .61803 L
s
.41599 .61428 m
.41599 .61803 L
s
.458 .61428 m
.458 .61803 L
s
.542 .61428 m
.542 .61803 L
s
.58401 .61428 m
.58401 .61803 L
s
.62601 .61428 m
.62601 .61803 L
s
.66801 .61428 m
.66801 .61803 L
s
.75202 .61428 m
.75202 .61803 L
s
.79402 .61428 m
.79402 .61803 L
s
.83603 .61428 m
.83603 .61803 L
s
.87803 .61428 m
.87803 .61803 L
s
.03797 .61428 m
.03797 .61803 L
s
.96203 .61428 m
.96203 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09347 m
1 .09347 L
s
.99375 .21312 m
1 .21312 L
s
.99375 .33277 m
1 .33277 L
s
.99375 .45242 m
1 .45242 L
s
.99375 .57207 m
1 .57207 L
s
.125 Mabswid
.99625 .1174 m
1 .1174 L
s
.99625 .14133 m
1 .14133 L
s
.99625 .16526 m
1 .16526 L
s
.99625 .18919 m
1 .18919 L
s
.99625 .23705 m
1 .23705 L
s
.99625 .26098 m
1 .26098 L
s
.99625 .28491 m
1 .28491 L
s
.99625 .30884 m
1 .30884 L
s
.99625 .3567 m
1 .3567 L
s
.99625 .38063 m
1 .38063 L
s
.99625 .40456 m
1 .40456 L
s
.99625 .42849 m
1 .42849 L
s
.99625 .47635 m
1 .47635 L
s
.99625 .50028 m
1 .50028 L
s
.99625 .52421 m
1 .52421 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .06954 m
1 .06954 L
s
.99625 .04561 m
1 .04561 L
s
.99625 .02168 m
1 .02168 L
s
.99625 .596 m
1 .596 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .09347 m
1 .09347 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .55624 Mdot
.02428 .55712 Mdot
.02476 .558 Mdot
.02523 .55886 Mdot
.0257 .55972 Mdot
.02618 .56057 Mdot
.02665 .5614 Mdot
.02712 .56223 Mdot
.0276 .56305 Mdot
.02807 .56386 Mdot
.02854 .56466 Mdot
.02902 .56545 Mdot
.02949 .56623 Mdot
.02996 .567 Mdot
.03044 .56776 Mdot
.03091 .56852 Mdot
.03138 .56926 Mdot
.03186 .57 Mdot
.03233 .57073 Mdot
.0328 .57145 Mdot
.03328 .57216 Mdot
.03375 .57286 Mdot
.03422 .57355 Mdot
.03469 .57423 Mdot
.03517 .57491 Mdot
.03564 .57557 Mdot
.03611 .57623 Mdot
.03659 .57688 Mdot
.03706 .57752 Mdot
.03753 .57815 Mdot
.038 .57877 Mdot
.03848 .57938 Mdot
.03895 .57999 Mdot
.03942 .58058 Mdot
.0399 .58117 Mdot
.04037 .58175 Mdot
.04084 .58232 Mdot
.04131 .58289 Mdot
.04179 .58344 Mdot
.04226 .58399 Mdot
.04273 .58453 Mdot
.0432 .58506 Mdot
.04368 .58558 Mdot
.04415 .58609 Mdot
.04462 .5866 Mdot
.04509 .58709 Mdot
.04557 .58758 Mdot
.04604 .58806 Mdot
.04651 .58854 Mdot
.04698 .589 Mdot
.04745 .58946 Mdot
.04793 .58991 Mdot
.0484 .59035 Mdot
.04887 .59078 Mdot
.04934 .5912 Mdot
.04982 .59162 Mdot
.05029 .59203 Mdot
.05076 .59243 Mdot
.05123 .59283 Mdot
.0517 .59321 Mdot
.05218 .59359 Mdot
.05265 .59396 Mdot
.05312 .59432 Mdot
.05359 .59468 Mdot
.05406 .59503 Mdot
.05453 .59537 Mdot
.05501 .5957 Mdot
.05548 .59602 Mdot
.05595 .59634 Mdot
.05642 .59665 Mdot
.05689 .59696 Mdot
.05736 .59725 Mdot
.05784 .59754 Mdot
.05831 .59782 Mdot
.05878 .59809 Mdot
.05925 .59836 Mdot
.05972 .59862 Mdot
.06019 .59887 Mdot
.06067 .59911 Mdot
.06114 .59935 Mdot
.06161 .59958 Mdot
.06208 .5998 Mdot
.06255 .60002 Mdot
.06302 .60023 Mdot
.06349 .60043 Mdot
.06397 .60062 Mdot
.06444 .60081 Mdot
.06491 .60099 Mdot
.06538 .60116 Mdot
.06585 .60133 Mdot
.06632 .60149 Mdot
.06679 .60164 Mdot
.06726 .60179 Mdot
.06773 .60193 Mdot
.06821 .60206 Mdot
.06868 .60219 Mdot
.06915 .6023 Mdot
.06962 .60242 Mdot
.07009 .60252 Mdot
.07056 .60262 Mdot
.07103 .60271 Mdot
.0715 .6028 Mdot
.07197 .60288 Mdot
.07244 .60295 Mdot
.07291 .60301 Mdot
.07339 .60307 Mdot
.07386 .60313 Mdot
.07433 .60317 Mdot
.0748 .60321 Mdot
.07527 .60325 Mdot
.07574 .60327 Mdot
.07621 .60329 Mdot
.07668 .60331 Mdot
.07715 .60332 Mdot
.07762 .60332 Mdot
.07809 .60331 Mdot
.07856 .6033 Mdot
.07903 .60329 Mdot
.0795 .60326 Mdot
.07997 .60323 Mdot
.08044 .6032 Mdot
.08092 .60316 Mdot
.08139 .60311 Mdot
.08186 .60306 Mdot
.08233 .603 Mdot
.0828 .60293 Mdot
.08327 .60286 Mdot
.08374 .60278 Mdot
.08421 .6027 Mdot
.08468 .60261 Mdot
.08515 .60251 Mdot
.08562 .60241 Mdot
.08609 .60231 Mdot
.08656 .60219 Mdot
.08703 .60207 Mdot
.0875 .60195 Mdot
.08797 .60182 Mdot
.08844 .60168 Mdot
.08891 .60154 Mdot
.08938 .60139 Mdot
.08985 .60124 Mdot
.09032 .60108 Mdot
.09079 .60092 Mdot
.09126 .60075 Mdot
.09173 .60057 Mdot
.0922 .60039 Mdot
.09267 .60021 Mdot
.09314 .60001 Mdot
.09361 .59982 Mdot
.09408 .59961 Mdot
.09455 .59941 Mdot
.09502 .59919 Mdot
.09549 .59897 Mdot
.09596 .59875 Mdot
.09643 .59852 Mdot
.0969 .59828 Mdot
.09737 .59804 Mdot
.09784 .5978 Mdot
.0983 .59755 Mdot
.09877 .59729 Mdot
.09924 .59703 Mdot
.09971 .59676 Mdot
.10018 .59649 Mdot
.10065 .59622 Mdot
.10112 .59593 Mdot
.10159 .59565 Mdot
.10206 .59536 Mdot
.10253 .59506 Mdot
.103 .59476 Mdot
.10347 .59445 Mdot
.10394 .59414 Mdot
.10441 .59382 Mdot
.10488 .5935 Mdot
.10535 .59317 Mdot
.10582 .59284 Mdot
.10628 .59251 Mdot
.10675 .59216 Mdot
.10722 .59182 Mdot
.10769 .59147 Mdot
.10816 .59111 Mdot
.10863 .59075 Mdot
.1091 .59039 Mdot
.10957 .59002 Mdot
.11004 .58964 Mdot
.11051 .58926 Mdot
.11098 .58888 Mdot
.11144 .58849 Mdot
.11191 .5881 Mdot
.11238 .5877 Mdot
.11285 .5873 Mdot
.11332 .58689 Mdot
.11379 .58648 Mdot
.11426 .58606 Mdot
.11473 .58564 Mdot
.1152 .58522 Mdot
.11566 .58479 Mdot
.11613 .58436 Mdot
.1166 .58392 Mdot
.11707 .58348 Mdot
.11754 .58303 Mdot
.11801 .58258 Mdot
.11848 .58212 Mdot
.11895 .58166 Mdot
.11941 .5812 Mdot
.11988 .58073 Mdot
.12035 .58026 Mdot
.12082 .57978 Mdot
.12129 .5793 Mdot
.12176 .57882 Mdot
.12223 .57833 Mdot
.12269 .57784 Mdot
.12316 .57734 Mdot
.12363 .57684 Mdot
.1241 .57633 Mdot
.12457 .57582 Mdot
.12504 .57531 Mdot
.1255 .57479 Mdot
.12597 .57427 Mdot
.12644 .57374 Mdot
.12691 .57322 Mdot
.12738 .57268 Mdot
.12785 .57215 Mdot
.12831 .5716 Mdot
.12878 .57106 Mdot
.12925 .57051 Mdot
.12972 .56996 Mdot
.13019 .5694 Mdot
.13066 .56884 Mdot
.13112 .56828 Mdot
.13159 .56771 Mdot
.13206 .56714 Mdot
.13253 .56656 Mdot
.133 .56598 Mdot
.13346 .5654 Mdot
.13393 .56482 Mdot
.1344 .56423 Mdot
.13487 .56363 Mdot
.13534 .56303 Mdot
.1358 .56243 Mdot
.13627 .56183 Mdot
.13674 .56122 Mdot
.13721 .56061 Mdot
.13768 .56 Mdot
.13814 .55938 Mdot
.13861 .55876 Mdot
.13908 .55813 Mdot
.13955 .5575 Mdot
.14001 .55687 Mdot
.14048 .55624 Mdot
.14095 .5556 Mdot
.14142 .55495 Mdot
.14189 .55431 Mdot
.14235 .55366 Mdot
.14282 .55301 Mdot
.14329 .55235 Mdot
.14376 .55169 Mdot
.14422 .55103 Mdot
.14469 .55037 Mdot
.14516 .5497 Mdot
.14563 .54903 Mdot
.14609 .54835 Mdot
.14656 .54768 Mdot
.14703 .54699 Mdot
.1475 .54631 Mdot
.14796 .54562 Mdot
.14843 .54493 Mdot
.1489 .54424 Mdot
.14937 .54354 Mdot
.14983 .54284 Mdot
.1503 .54214 Mdot
.15077 .54144 Mdot
.15124 .54073 Mdot
.1517 .54002 Mdot
.15217 .5393 Mdot
.15264 .53859 Mdot
.15311 .53787 Mdot
.15357 .53714 Mdot
.15404 .53642 Mdot
.15451 .53569 Mdot
.15498 .53496 Mdot
.15544 .53422 Mdot
.15591 .53349 Mdot
.15638 .53275 Mdot
.15684 .532 Mdot
.15731 .53126 Mdot
.15778 .53051 Mdot
.15825 .52976 Mdot
.15871 .52901 Mdot
.15918 .52825 Mdot
.15965 .52749 Mdot
.16011 .52673 Mdot
.16058 .52597 Mdot
.16105 .5252 Mdot
.16151 .52443 Mdot
.16198 .52366 Mdot
.16245 .52288 Mdot
.16292 .52211 Mdot
.16338 .52133 Mdot
.16385 .52054 Mdot
.16432 .51976 Mdot
.16478 .51897 Mdot
.16525 .51818 Mdot
.16572 .51739 Mdot
.16618 .5166 Mdot
.16665 .5158 Mdot
.16712 .515 Mdot
.16758 .5142 Mdot
.16805 .5134 Mdot
.16852 .51259 Mdot
.16898 .51178 Mdot
.16945 .51097 Mdot
.16992 .51016 Mdot
.17038 .50934 Mdot
.17085 .50852 Mdot
.17132 .5077 Mdot
.17178 .50688 Mdot
.17225 .50606 Mdot
.17272 .50523 Mdot
.17318 .5044 Mdot
.17365 .50357 Mdot
.17412 .50274 Mdot
.17458 .5019 Mdot
.17505 .50106 Mdot
.17552 .50023 Mdot
.17598 .49938 Mdot
.17645 .49854 Mdot
.17692 .49769 Mdot
.17738 .49685 Mdot
.17785 .496 Mdot
.17832 .49514 Mdot
.17878 .49429 Mdot
.17925 .49344 Mdot
.17972 .49258 Mdot
.18018 .49172 Mdot
.18065 .49086 Mdot
.18111 .48999 Mdot
.18158 .48913 Mdot
.18205 .48826 Mdot
.18251 .48739 Mdot
.18298 .48652 Mdot
.18345 .48565 Mdot
.18391 .48477 Mdot
.18438 .4839 Mdot
.18484 .48302 Mdot
.18531 .48214 Mdot
.18578 .48125 Mdot
.18624 .48037 Mdot
.18671 .47949 Mdot
.18718 .4786 Mdot
.18764 .47771 Mdot
.18811 .47682 Mdot
.18857 .47593 Mdot
.18904 .47503 Mdot
.18951 .47414 Mdot
.18997 .47324 Mdot
.19044 .47234 Mdot
.1909 .47144 Mdot
.19137 .47054 Mdot
.19184 .46964 Mdot
.1923 .46873 Mdot
.19277 .46782 Mdot
.19323 .46692 Mdot
.1937 .46601 Mdot
.19417 .46509 Mdot
.19463 .46418 Mdot
.1951 .46327 Mdot
.19556 .46235 Mdot
.19603 .46143 Mdot
.1965 .46052 Mdot
.19696 .4596 Mdot
.19743 .45867 Mdot
.19789 .45775 Mdot
.19836 .45683 Mdot
.19882 .4559 Mdot
.19929 .45498 Mdot
.19976 .45405 Mdot
.20022 .45312 Mdot
.20069 .45219 Mdot
.20115 .45125 Mdot
.20162 .45032 Mdot
.20208 .44939 Mdot
.20255 .44845 Mdot
.20302 .44751 Mdot
.20348 .44657 Mdot
.20395 .44564 Mdot
.20441 .44469 Mdot
.20488 .44375 Mdot
.20534 .44281 Mdot
.20581 .44187 Mdot
.20627 .44092 Mdot
.20674 .43997 Mdot
.20721 .43903 Mdot
.20767 .43808 Mdot
.20814 .43713 Mdot
.2086 .43618 Mdot
.20907 .43522 Mdot
.20953 .43427 Mdot
.21 .43332 Mdot
.21046 .43236 Mdot
.21093 .43141 Mdot
.2114 .43045 Mdot
.21186 .42949 Mdot
.21233 .42853 Mdot
.21279 .42757 Mdot
.21326 .42661 Mdot
.21372 .42565 Mdot
.21419 .42469 Mdot
.21465 .42372 Mdot
.21512 .42276 Mdot
.21558 .42179 Mdot
.21605 .42083 Mdot
.21651 .41986 Mdot
.21698 .41889 Mdot
.21744 .41792 Mdot
.21791 .41695 Mdot
.21837 .41598 Mdot
.21884 .41501 Mdot
.21931 .41404 Mdot
.21977 .41307 Mdot
.22024 .41209 Mdot
.2207 .41112 Mdot
.22117 .41014 Mdot
.22163 .40917 Mdot
.2221 .40819 Mdot
.22256 .40721 Mdot
.22303 .40624 Mdot
.22349 .40526 Mdot
.22396 .40428 Mdot
.22442 .4033 Mdot
.22489 .40232 Mdot
.22535 .40134 Mdot
.22582 .40036 Mdot
.22628 .39937 Mdot
.22675 .39839 Mdot
.22721 .39741 Mdot
.22768 .39642 Mdot
.22814 .39544 Mdot
.22861 .39445 Mdot
.22907 .39347 Mdot
.22954 .39248 Mdot
.23 .3915 Mdot
.23047 .39051 Mdot
.23093 .38952 Mdot
.2314 .38853 Mdot
.23186 .38755 Mdot
.23233 .38656 Mdot
.23279 .38557 Mdot
.23326 .38458 Mdot
.23372 .38359 Mdot
.23418 .3826 Mdot
.23465 .38161 Mdot
.23511 .38062 Mdot
.23558 .37963 Mdot
.23604 .37863 Mdot
.23651 .37764 Mdot
.23697 .37665 Mdot
.23744 .37566 Mdot
.2379 .37466 Mdot
.23837 .37367 Mdot
.23883 .37268 Mdot
.2393 .37168 Mdot
.23976 .37069 Mdot
.24023 .3697 Mdot
.24069 .3687 Mdot
.24116 .36771 Mdot
.24162 .36671 Mdot
.24208 .36572 Mdot
.24255 .36472 Mdot
.24301 .36373 Mdot
.24348 .36273 Mdot
.24394 .36174 Mdot
.24441 .36074 Mdot
.24487 .35974 Mdot
.24534 .35875 Mdot
.2458 .35775 Mdot
.24627 .35676 Mdot
.24673 .35576 Mdot
.24719 .35476 Mdot
.24766 .35377 Mdot
.24812 .35277 Mdot
.24859 .35177 Mdot
.24905 .35078 Mdot
.24952 .34978 Mdot
.24998 .34878 Mdot
.25045 .34779 Mdot
.25091 .34679 Mdot
.25137 .3458 Mdot
.25184 .3448 Mdot
.2523 .3438 Mdot
.25277 .34281 Mdot
.25323 .34181 Mdot
.2537 .34081 Mdot
.25416 .33982 Mdot
.25463 .33882 Mdot
.25509 .33783 Mdot
.25555 .33683 Mdot
.25602 .33584 Mdot
.25648 .33484 Mdot
.25695 .33385 Mdot
.25741 .33285 Mdot
.25787 .33186 Mdot
.25834 .33086 Mdot
.2588 .32987 Mdot
.25927 .32887 Mdot
.25973 .32788 Mdot
.2602 .32688 Mdot
.26066 .32589 Mdot
.26112 .3249 Mdot
.26159 .3239 Mdot
.26205 .32291 Mdot
.26252 .32192 Mdot
.26298 .32093 Mdot
.26344 .31994 Mdot
.26391 .31894 Mdot
.26437 .31795 Mdot
.26484 .31696 Mdot
.2653 .31597 Mdot
.26577 .31498 Mdot
.26623 .31399 Mdot
.26669 .313 Mdot
.26716 .31201 Mdot
.26762 .31102 Mdot
.26809 .31004 Mdot
.26855 .30905 Mdot
.26901 .30806 Mdot
.26948 .30707 Mdot
.26994 .30609 Mdot
.27041 .3051 Mdot
.27087 .30412 Mdot
.27133 .30313 Mdot
.2718 .30215 Mdot
.27226 .30116 Mdot
.27273 .30018 Mdot
.27319 .2992 Mdot
.27365 .29821 Mdot
.27412 .29723 Mdot
.27458 .29625 Mdot
.27504 .29527 Mdot
.27551 .29429 Mdot
.27597 .29331 Mdot
.27644 .29233 Mdot
.2769 .29135 Mdot
.27736 .29037 Mdot
.27783 .28939 Mdot
.27829 .28842 Mdot
.27876 .28744 Mdot
.27922 .28647 Mdot
.27968 .28549 Mdot
.28015 .28452 Mdot
.28061 .28354 Mdot
.28107 .28257 Mdot
.28154 .2816 Mdot
.282 .28063 Mdot
.28247 .27966 Mdot
.28293 .27869 Mdot
.28339 .27772 Mdot
.28386 .27675 Mdot
.28432 .27578 Mdot
.28478 .27481 Mdot
.28525 .27385 Mdot
.28571 .27288 Mdot
.28617 .27191 Mdot
.28664 .27095 Mdot
.2871 .26999 Mdot
.28757 .26902 Mdot
.28803 .26806 Mdot
.28849 .2671 Mdot
.28896 .26614 Mdot
.28942 .26518 Mdot
.28988 .26422 Mdot
.29035 .26327 Mdot
.29081 .26231 Mdot
.29127 .26135 Mdot
.29174 .2604 Mdot
.2922 .25944 Mdot
.29266 .25849 Mdot
.29313 .25754 Mdot
.29359 .25659 Mdot
.29406 .25564 Mdot
.29452 .25469 Mdot
.29498 .25374 Mdot
.29545 .25279 Mdot
.29591 .25184 Mdot
.29637 .2509 Mdot
.29684 .24995 Mdot
.2973 .24901 Mdot
.29776 .24807 Mdot
.29823 .24712 Mdot
.29869 .24618 Mdot
.29915 .24524 Mdot
.29962 .2443 Mdot
.30008 .24337 Mdot
.30054 .24243 Mdot
.30101 .24149 Mdot
.30147 .24056 Mdot
.30193 .23963 Mdot
.3024 .23869 Mdot
.30286 .23776 Mdot
.30332 .23683 Mdot
.30379 .2359 Mdot
.30425 .23497 Mdot
.30471 .23405 Mdot
.30518 .23312 Mdot
.30564 .2322 Mdot
.3061 .23127 Mdot
.30657 .23035 Mdot
.30703 .22943 Mdot
.30749 .22851 Mdot
.30796 .22759 Mdot
.30842 .22667 Mdot
.30888 .22575 Mdot
.30935 .22484 Mdot
.30981 .22392 Mdot
.31027 .22301 Mdot
.31074 .2221 Mdot
.3112 .22119 Mdot
.31166 .22028 Mdot
.31213 .21937 Mdot
.31259 .21846 Mdot
.31305 .21756 Mdot
.31352 .21665 Mdot
.31398 .21575 Mdot
.31444 .21485 Mdot
.3149 .21395 Mdot
.31537 .21305 Mdot
.31583 .21215 Mdot
.31629 .21125 Mdot
.31676 .21035 Mdot
.31722 .20946 Mdot
.31768 .20857 Mdot
.31815 .20768 Mdot
.31861 .20679 Mdot
.31907 .2059 Mdot
.31954 .20501 Mdot
.32 .20412 Mdot
.32046 .20324 Mdot
.32092 .20235 Mdot
.32139 .20147 Mdot
.32185 .20059 Mdot
.32231 .19971 Mdot
.32278 .19883 Mdot
.32324 .19796 Mdot
.3237 .19708 Mdot
.32417 .19621 Mdot
.32463 .19534 Mdot
.32509 .19447 Mdot
.32555 .1936 Mdot
.32602 .19273 Mdot
.32648 .19186 Mdot
.32694 .191 Mdot
.32741 .19013 Mdot
.32787 .18927 Mdot
.32833 .18841 Mdot
.3288 .18755 Mdot
.32926 .18669 Mdot
.32972 .18584 Mdot
.33018 .18498 Mdot
.33065 .18413 Mdot
.33111 .18328 Mdot
.33157 .18243 Mdot
.33204 .18158 Mdot
.3325 .18073 Mdot
.33296 .17989 Mdot
.33342 .17904 Mdot
.33389 .1782 Mdot
.33435 .17736 Mdot
.33481 .17652 Mdot
.33528 .17568 Mdot
.33574 .17485 Mdot
.3362 .17401 Mdot
.33666 .17318 Mdot
.33713 .17235 Mdot
.33759 .17152 Mdot
.33805 .17069 Mdot
.33852 .16987 Mdot
.33898 .16904 Mdot
.33944 .16822 Mdot
.3399 .1674 Mdot
.34037 .16658 Mdot
.34083 .16576 Mdot
.34129 .16494 Mdot
.34175 .16413 Mdot
.34222 .16332 Mdot
.34268 .16251 Mdot
.34314 .1617 Mdot
.34361 .16089 Mdot
.34407 .16008 Mdot
.34453 .15928 Mdot
.34499 .15847 Mdot
.34546 .15767 Mdot
.34592 .15687 Mdot
.34638 .15608 Mdot
.34684 .15528 Mdot
.34731 .15449 Mdot
.34777 .15369 Mdot
.34823 .1529 Mdot
.34869 .15212 Mdot
.34916 .15133 Mdot
.34962 .15054 Mdot
.35008 .14976 Mdot
.35055 .14898 Mdot
.35101 .1482 Mdot
.35147 .14742 Mdot
.35193 .14664 Mdot
.3524 .14587 Mdot
.35286 .1451 Mdot
.35332 .14433 Mdot
.35378 .14356 Mdot
.35425 .14279 Mdot
.35471 .14202 Mdot
.35517 .14126 Mdot
.35563 .1405 Mdot
.3561 .13974 Mdot
.35656 .13898 Mdot
.35702 .13823 Mdot
.35748 .13747 Mdot
.35795 .13672 Mdot
.35841 .13597 Mdot
.35887 .13522 Mdot
.35933 .13448 Mdot
.3598 .13373 Mdot
.36026 .13299 Mdot
.36072 .13225 Mdot
.36118 .13151 Mdot
.36165 .13077 Mdot
.36211 .13004 Mdot
.36257 .1293 Mdot
.36303 .12857 Mdot
.3635 .12784 Mdot
.36396 .12712 Mdot
.36442 .12639 Mdot
.36488 .12567 Mdot
.36535 .12495 Mdot
.36581 .12423 Mdot
.36627 .12351 Mdot
.36673 .12279 Mdot
.3672 .12208 Mdot
.36766 .12137 Mdot
.36812 .12066 Mdot
.36858 .11995 Mdot
.36905 .11925 Mdot
.36951 .11854 Mdot
.36997 .11784 Mdot
.37043 .11714 Mdot
.37089 .11644 Mdot
.37136 .11575 Mdot
.37182 .11506 Mdot
.37228 .11437 Mdot
.37274 .11368 Mdot
.37321 .11299 Mdot
.37367 .1123 Mdot
.37413 .11162 Mdot
.37459 .11094 Mdot
.37506 .11026 Mdot
.37552 .10958 Mdot
.37598 .10891 Mdot
.37644 .10824 Mdot
.37691 .10757 Mdot
.37737 .1069 Mdot
.37783 .10623 Mdot
.37829 .10557 Mdot
.37875 .10491 Mdot
.37922 .10425 Mdot
.37968 .10359 Mdot
.38014 .10293 Mdot
.3806 .10228 Mdot
.38107 .10163 Mdot
.38153 .10098 Mdot
.38199 .10033 Mdot
.38245 .09969 Mdot
.38292 .09904 Mdot
.38338 .0984 Mdot
.38384 .09776 Mdot
.3843 .09713 Mdot
.38476 .09649 Mdot
.38523 .09586 Mdot
.38569 .09523 Mdot
.38615 .0946 Mdot
.38661 .09398 Mdot
.38708 .09335 Mdot
.38754 .09273 Mdot
.388 .09211 Mdot
.38846 .0915 Mdot
.38892 .09088 Mdot
.38939 .09027 Mdot
.38985 .08966 Mdot
.39031 .08905 Mdot
.39077 .08845 Mdot
.39123 .08784 Mdot
.3917 .08724 Mdot
.39216 .08664 Mdot
.39262 .08605 Mdot
.39308 .08545 Mdot
.39355 .08486 Mdot
.39401 .08427 Mdot
.39447 .08368 Mdot
.39493 .0831 Mdot
.39539 .08252 Mdot
.39586 .08193 Mdot
.39632 .08136 Mdot
.39678 .08078 Mdot
.39724 .08021 Mdot
.3977 .07963 Mdot
.39817 .07907 Mdot
.39863 .0785 Mdot
.39909 .07793 Mdot
.39955 .07737 Mdot
.40002 .07681 Mdot
.40048 .07625 Mdot
.40094 .0757 Mdot
.4014 .07514 Mdot
.40186 .07459 Mdot
.40233 .07404 Mdot
.40279 .0735 Mdot
.40325 .07295 Mdot
.40371 .07241 Mdot
.40417 .07187 Mdot
.40464 .07134 Mdot
.4051 .0708 Mdot
.40556 .07027 Mdot
.40602 .06974 Mdot
.40648 .06921 Mdot
.40695 .06869 Mdot
.40741 .06816 Mdot
.40787 .06764 Mdot
.40833 .06713 Mdot
.40879 .06661 Mdot
.40926 .0661 Mdot
.40972 .06559 Mdot
.41018 .06508 Mdot
.41064 .06457 Mdot
.4111 .06407 Mdot
.41157 .06357 Mdot
.41203 .06307 Mdot
.41249 .06257 Mdot
.41295 .06208 Mdot
.41341 .06159 Mdot
.41388 .0611 Mdot
.41434 .06061 Mdot
.4148 .06012 Mdot
.41526 .05964 Mdot
.41572 .05916 Mdot
.41619 .05869 Mdot
.41665 .05821 Mdot
.41711 .05774 Mdot
.41757 .05727 Mdot
.41803 .0568 Mdot
.4185 .05634 Mdot
.41896 .05587 Mdot
.41942 .05541 Mdot
.41988 .05496 Mdot
.42034 .0545 Mdot
.42081 .05405 Mdot
.42127 .0536 Mdot
.42173 .05315 Mdot
.42219 .05271 Mdot
.42265 .05226 Mdot
.42312 .05182 Mdot
.42358 .05138 Mdot
.42404 .05095 Mdot
.4245 .05052 Mdot
.42496 .05009 Mdot
.42543 .04966 Mdot
.42589 .04923 Mdot
.42635 .04881 Mdot
.42681 .04839 Mdot
.42727 .04797 Mdot
.42774 .04756 Mdot
.4282 .04714 Mdot
.42866 .04673 Mdot
.42912 .04632 Mdot
.42958 .04592 Mdot
.43004 .04552 Mdot
.43051 .04512 Mdot
.43097 .04472 Mdot
.43143 .04432 Mdot
.43189 .04393 Mdot
.43235 .04354 Mdot
.43282 .04315 Mdot
.43328 .04277 Mdot
.43374 .04238 Mdot
.4342 .042 Mdot
.43466 .04163 Mdot
.43513 .04125 Mdot
.43559 .04088 Mdot
.43605 .04051 Mdot
.43651 .04014 Mdot
.43697 .03978 Mdot
.43743 .03941 Mdot
.4379 .03905 Mdot
.43836 .0387 Mdot
.43882 .03834 Mdot
.43928 .03799 Mdot
.43974 .03764 Mdot
.44021 .03729 Mdot
.44067 .03695 Mdot
.44113 .03661 Mdot
.44159 .03627 Mdot
.44205 .03593 Mdot
.44251 .0356 Mdot
.44298 .03527 Mdot
.44344 .03494 Mdot
.4439 .03461 Mdot
.44436 .03429 Mdot
.44482 .03397 Mdot
.44529 .03365 Mdot
.44575 .03333 Mdot
.44621 .03302 Mdot
.44667 .03271 Mdot
.44713 .0324 Mdot
.44759 .0321 Mdot
.44806 .03179 Mdot
.44852 .03149 Mdot
.44898 .03119 Mdot
.44944 .0309 Mdot
.4499 .03061 Mdot
.45037 .03032 Mdot
.45083 .03003 Mdot
.45129 .02975 Mdot
.45175 .02946 Mdot
.45221 .02918 Mdot
.45267 .02891 Mdot
.45314 .02863 Mdot
.4536 .02836 Mdot
.45406 .02809 Mdot
.45452 .02783 Mdot
.45498 .02756 Mdot
.45544 .0273 Mdot
.45591 .02704 Mdot
.45637 .02679 Mdot
.45683 .02654 Mdot
.45729 .02628 Mdot
.45775 .02604 Mdot
.45822 .02579 Mdot
.45868 .02555 Mdot
.45914 .02531 Mdot
.4596 .02507 Mdot
.46006 .02484 Mdot
.46052 .02461 Mdot
.46099 .02438 Mdot
.46145 .02415 Mdot
.46191 .02393 Mdot
.46237 .02371 Mdot
.46283 .02349 Mdot
.46329 .02327 Mdot
.46376 .02306 Mdot
.46422 .02285 Mdot
.46468 .02264 Mdot
.46514 .02243 Mdot
.4656 .02223 Mdot
.46606 .02203 Mdot
.46653 .02183 Mdot
.46699 .02164 Mdot
.46745 .02145 Mdot
.46791 .02126 Mdot
.46837 .02107 Mdot
.46884 .02089 Mdot
.4693 .02071 Mdot
.46976 .02053 Mdot
.47022 .02035 Mdot
.47068 .02018 Mdot
.47114 .02001 Mdot
.47161 .01984 Mdot
.47207 .01968 Mdot
.47253 .01951 Mdot
.47299 .01936 Mdot
.47345 .0192 Mdot
.47391 .01904 Mdot
.47438 .01889 Mdot
.47484 .01874 Mdot
.4753 .0186 Mdot
.47576 .01845 Mdot
.47622 .01831 Mdot
.47668 .01817 Mdot
.47715 .01804 Mdot
.47761 .01791 Mdot
.47807 .01778 Mdot
.47853 .01765 Mdot
.47899 .01752 Mdot
.47945 .0174 Mdot
.47992 .01728 Mdot
.48038 .01717 Mdot
.48084 .01705 Mdot
.4813 .01694 Mdot
.48176 .01683 Mdot
.48222 .01673 Mdot
.48269 .01662 Mdot
.48315 .01652 Mdot
.48361 .01643 Mdot
.48407 .01633 Mdot
.48453 .01624 Mdot
.485 .01615 Mdot
.48546 .01606 Mdot
.48592 .01598 Mdot
.48638 .0159 Mdot
.48684 .01582 Mdot
.4873 .01574 Mdot
.48777 .01567 Mdot
.48823 .0156 Mdot
.48869 .01553 Mdot
.48915 .01546 Mdot
.48961 .0154 Mdot
.49007 .01534 Mdot
.49054 .01529 Mdot
.491 .01523 Mdot
.49146 .01518 Mdot
.49192 .01513 Mdot
.49238 .01508 Mdot
.49284 .01504 Mdot
.49331 .015 Mdot
.49377 .01496 Mdot
.49423 .01493 Mdot
.49469 .01489 Mdot
.49515 .01486 Mdot
.49561 .01484 Mdot
.49608 .01481 Mdot
.49654 .01479 Mdot
.497 .01477 Mdot
.49746 .01476 Mdot
.49792 .01474 Mdot
.49838 .01473 Mdot
.49885 .01472 Mdot
.49931 .01472 Mdot
.49977 .01472 Mdot
.50023 .01472 Mdot
.50069 .01472 Mdot
.50115 .01472 Mdot
.50162 .01473 Mdot
.50208 .01474 Mdot
.50254 .01476 Mdot
.503 .01477 Mdot
.50346 .01479 Mdot
.50392 .01481 Mdot
.50439 .01484 Mdot
.50485 .01486 Mdot
.50531 .01489 Mdot
.50577 .01493 Mdot
.50623 .01496 Mdot
.50669 .015 Mdot
.50716 .01504 Mdot
.50762 .01508 Mdot
.50808 .01513 Mdot
.50854 .01518 Mdot
.509 .01523 Mdot
.50946 .01529 Mdot
.50993 .01534 Mdot
.51039 .0154 Mdot
.51085 .01546 Mdot
.51131 .01553 Mdot
.51177 .0156 Mdot
.51223 .01567 Mdot
.5127 .01574 Mdot
.51316 .01582 Mdot
.51362 .0159 Mdot
.51408 .01598 Mdot
.51454 .01606 Mdot
.515 .01615 Mdot
.51547 .01624 Mdot
.51593 .01633 Mdot
.51639 .01643 Mdot
.51685 .01652 Mdot
.51731 .01662 Mdot
.51778 .01673 Mdot
.51824 .01683 Mdot
.5187 .01694 Mdot
.51916 .01705 Mdot
.51962 .01717 Mdot
.52008 .01728 Mdot
.52055 .0174 Mdot
.52101 .01752 Mdot
.52147 .01765 Mdot
.52193 .01778 Mdot
.52239 .01791 Mdot
.52285 .01804 Mdot
.52332 .01817 Mdot
.52378 .01831 Mdot
.52424 .01845 Mdot
.5247 .0186 Mdot
.52516 .01874 Mdot
.52562 .01889 Mdot
.52609 .01904 Mdot
.52655 .0192 Mdot
.52701 .01936 Mdot
.52747 .01951 Mdot
.52793 .01968 Mdot
.52839 .01984 Mdot
.52886 .02001 Mdot
.52932 .02018 Mdot
.52978 .02035 Mdot
.53024 .02053 Mdot
.5307 .02071 Mdot
.53116 .02089 Mdot
.53163 .02107 Mdot
.53209 .02126 Mdot
.53255 .02145 Mdot
.53301 .02164 Mdot
.53347 .02183 Mdot
.53394 .02203 Mdot
.5344 .02223 Mdot
.53486 .02243 Mdot
.53532 .02264 Mdot
.53578 .02285 Mdot
.53624 .02306 Mdot
.53671 .02327 Mdot
.53717 .02349 Mdot
.53763 .02371 Mdot
.53809 .02393 Mdot
.53855 .02415 Mdot
.53901 .02438 Mdot
.53948 .02461 Mdot
.53994 .02484 Mdot
.5404 .02507 Mdot
.54086 .02531 Mdot
.54132 .02555 Mdot
.54178 .02579 Mdot
.54225 .02604 Mdot
.54271 .02628 Mdot
.54317 .02654 Mdot
.54363 .02679 Mdot
.54409 .02704 Mdot
.54456 .0273 Mdot
.54502 .02756 Mdot
.54548 .02783 Mdot
.54594 .02809 Mdot
.5464 .02836 Mdot
.54686 .02863 Mdot
.54733 .02891 Mdot
.54779 .02918 Mdot
.54825 .02946 Mdot
.54871 .02975 Mdot
.54917 .03003 Mdot
.54963 .03032 Mdot
.5501 .03061 Mdot
.55056 .0309 Mdot
.55102 .03119 Mdot
.55148 .03149 Mdot
.55194 .03179 Mdot
.55241 .0321 Mdot
.55287 .0324 Mdot
.55333 .03271 Mdot
.55379 .03302 Mdot
.55425 .03333 Mdot
.55471 .03365 Mdot
.55518 .03397 Mdot
.55564 .03429 Mdot
.5561 .03461 Mdot
.55656 .03494 Mdot
.55702 .03527 Mdot
.55749 .0356 Mdot
.55795 .03593 Mdot
.55841 .03627 Mdot
.55887 .03661 Mdot
.55933 .03695 Mdot
.55979 .03729 Mdot
.56026 .03764 Mdot
.56072 .03799 Mdot
.56118 .03834 Mdot
.56164 .0387 Mdot
.5621 .03905 Mdot
.56257 .03941 Mdot
.56303 .03978 Mdot
.56349 .04014 Mdot
.56395 .04051 Mdot
.56441 .04088 Mdot
.56487 .04125 Mdot
.56534 .04163 Mdot
.5658 .042 Mdot
.56626 .04238 Mdot
.56672 .04277 Mdot
.56718 .04315 Mdot
.56765 .04354 Mdot
.56811 .04393 Mdot
.56857 .04432 Mdot
.56903 .04472 Mdot
.56949 .04512 Mdot
.56996 .04552 Mdot
.57042 .04592 Mdot
.57088 .04632 Mdot
.57134 .04673 Mdot
.5718 .04714 Mdot
.57226 .04756 Mdot
.57273 .04797 Mdot
.57319 .04839 Mdot
.57365 .04881 Mdot
.57411 .04923 Mdot
.57457 .04966 Mdot
.57504 .05009 Mdot
.5755 .05052 Mdot
.57596 .05095 Mdot
.57642 .05138 Mdot
.57688 .05182 Mdot
.57735 .05226 Mdot
.57781 .05271 Mdot
.57827 .05315 Mdot
.57873 .0536 Mdot
.57919 .05405 Mdot
.57966 .0545 Mdot
.58012 .05496 Mdot
.58058 .05541 Mdot
.58104 .05587 Mdot
.5815 .05634 Mdot
.58197 .0568 Mdot
.58243 .05727 Mdot
.58289 .05774 Mdot
.58335 .05821 Mdot
.58381 .05869 Mdot
.58428 .05916 Mdot
.58474 .05964 Mdot
.5852 .06012 Mdot
.58566 .06061 Mdot
.58612 .0611 Mdot
.58659 .06159 Mdot
.58705 .06208 Mdot
.58751 .06257 Mdot
.58797 .06307 Mdot
.58843 .06357 Mdot
.5889 .06407 Mdot
.58936 .06457 Mdot
.58982 .06508 Mdot
.59028 .06559 Mdot
.59074 .0661 Mdot
.59121 .06661 Mdot
.59167 .06713 Mdot
.59213 .06764 Mdot
.59259 .06816 Mdot
.59305 .06869 Mdot
.59352 .06921 Mdot
.59398 .06974 Mdot
.59444 .07027 Mdot
.5949 .0708 Mdot
.59536 .07134 Mdot
.59583 .07187 Mdot
.59629 .07241 Mdot
.59675 .07295 Mdot
.59721 .0735 Mdot
.59767 .07404 Mdot
.59814 .07459 Mdot
.5986 .07514 Mdot
.59906 .0757 Mdot
.59952 .07625 Mdot
.59998 .07681 Mdot
.60045 .07737 Mdot
.60091 .07793 Mdot
.60137 .0785 Mdot
.60183 .07907 Mdot
.6023 .07963 Mdot
.60276 .08021 Mdot
.60322 .08078 Mdot
.60368 .08136 Mdot
.60414 .08193 Mdot
.60461 .08252 Mdot
.60507 .0831 Mdot
.60553 .08368 Mdot
.60599 .08427 Mdot
.60645 .08486 Mdot
.60692 .08545 Mdot
.60738 .08605 Mdot
.60784 .08664 Mdot
.6083 .08724 Mdot
.60877 .08784 Mdot
.60923 .08845 Mdot
.60969 .08905 Mdot
.61015 .08966 Mdot
.61061 .09027 Mdot
.61108 .09088 Mdot
.61154 .0915 Mdot
.612 .09211 Mdot
.61246 .09273 Mdot
.61292 .09335 Mdot
.61339 .09398 Mdot
.61385 .0946 Mdot
.61431 .09523 Mdot
.61477 .09586 Mdot
.61524 .09649 Mdot
.6157 .09713 Mdot
.61616 .09776 Mdot
.61662 .0984 Mdot
.61708 .09904 Mdot
.61755 .09969 Mdot
.61801 .10033 Mdot
.61847 .10098 Mdot
.61893 .10163 Mdot
.6194 .10228 Mdot
.61986 .10293 Mdot
.62032 .10359 Mdot
.62078 .10425 Mdot
.62125 .10491 Mdot
.62171 .10557 Mdot
.62217 .10623 Mdot
.62263 .1069 Mdot
.62309 .10757 Mdot
.62356 .10824 Mdot
.62402 .10891 Mdot
.62448 .10958 Mdot
.62494 .11026 Mdot
.62541 .11094 Mdot
.62587 .11162 Mdot
.62633 .1123 Mdot
.62679 .11299 Mdot
.62726 .11368 Mdot
.62772 .11437 Mdot
.62818 .11506 Mdot
.62864 .11575 Mdot
.62911 .11644 Mdot
.62957 .11714 Mdot
.63003 .11784 Mdot
.63049 .11854 Mdot
.63095 .11925 Mdot
.63142 .11995 Mdot
.63188 .12066 Mdot
.63234 .12137 Mdot
.6328 .12208 Mdot
.63327 .12279 Mdot
.63373 .12351 Mdot
.63419 .12423 Mdot
.63465 .12495 Mdot
.63512 .12567 Mdot
.63558 .12639 Mdot
.63604 .12712 Mdot
.6365 .12784 Mdot
.63697 .12857 Mdot
.63743 .1293 Mdot
.63789 .13004 Mdot
.63835 .13077 Mdot
.63882 .13151 Mdot
.63928 .13225 Mdot
.63974 .13299 Mdot
.6402 .13373 Mdot
.64067 .13448 Mdot
.64113 .13522 Mdot
.64159 .13597 Mdot
.64205 .13672 Mdot
.64252 .13747 Mdot
.64298 .13823 Mdot
.64344 .13898 Mdot
.6439 .13974 Mdot
.64437 .1405 Mdot
.64483 .14126 Mdot
.64529 .14202 Mdot
.64575 .14279 Mdot
.64622 .14356 Mdot
.64668 .14433 Mdot
.64714 .1451 Mdot
.6476 .14587 Mdot
.64807 .14664 Mdot
.64853 .14742 Mdot
.64899 .1482 Mdot
.64945 .14898 Mdot
.64992 .14976 Mdot
.65038 .15054 Mdot
.65084 .15133 Mdot
.65131 .15212 Mdot
.65177 .1529 Mdot
.65223 .15369 Mdot
.65269 .15449 Mdot
.65316 .15528 Mdot
.65362 .15608 Mdot
.65408 .15687 Mdot
.65454 .15767 Mdot
.65501 .15847 Mdot
.65547 .15928 Mdot
.65593 .16008 Mdot
.65639 .16089 Mdot
.65686 .1617 Mdot
.65732 .16251 Mdot
.65778 .16332 Mdot
.65825 .16413 Mdot
.65871 .16494 Mdot
.65917 .16576 Mdot
.65963 .16658 Mdot
.6601 .1674 Mdot
.66056 .16822 Mdot
.66102 .16904 Mdot
.66148 .16987 Mdot
.66195 .17069 Mdot
.66241 .17152 Mdot
.66287 .17235 Mdot
.66334 .17318 Mdot
.6638 .17401 Mdot
.66426 .17485 Mdot
.66472 .17568 Mdot
.66519 .17652 Mdot
.66565 .17736 Mdot
.66611 .1782 Mdot
.66658 .17904 Mdot
.66704 .17989 Mdot
.6675 .18073 Mdot
.66796 .18158 Mdot
.66843 .18243 Mdot
.66889 .18328 Mdot
.66935 .18413 Mdot
.66982 .18498 Mdot
.67028 .18584 Mdot
.67074 .18669 Mdot
.6712 .18755 Mdot
.67167 .18841 Mdot
.67213 .18927 Mdot
.67259 .19013 Mdot
.67306 .191 Mdot
.67352 .19186 Mdot
.67398 .19273 Mdot
.67445 .1936 Mdot
.67491 .19447 Mdot
.67537 .19534 Mdot
.67583 .19621 Mdot
.6763 .19708 Mdot
.67676 .19796 Mdot
.67722 .19883 Mdot
.67769 .19971 Mdot
.67815 .20059 Mdot
.67861 .20147 Mdot
.67908 .20235 Mdot
.67954 .20324 Mdot
.68 .20412 Mdot
.68046 .20501 Mdot
.68093 .2059 Mdot
.68139 .20679 Mdot
.68185 .20768 Mdot
.68232 .20857 Mdot
.68278 .20946 Mdot
.68324 .21035 Mdot
.68371 .21125 Mdot
.68417 .21215 Mdot
.68463 .21305 Mdot
.6851 .21395 Mdot
.68556 .21485 Mdot
.68602 .21575 Mdot
.68648 .21665 Mdot
.68695 .21756 Mdot
.68741 .21846 Mdot
.68787 .21937 Mdot
.68834 .22028 Mdot
.6888 .22119 Mdot
.68926 .2221 Mdot
.68973 .22301 Mdot
.69019 .22392 Mdot
.69065 .22484 Mdot
.69112 .22575 Mdot
.69158 .22667 Mdot
.69204 .22759 Mdot
.69251 .22851 Mdot
.69297 .22943 Mdot
.69343 .23035 Mdot
.6939 .23127 Mdot
.69436 .2322 Mdot
.69482 .23312 Mdot
.69529 .23405 Mdot
.69575 .23497 Mdot
.69621 .2359 Mdot
.69668 .23683 Mdot
.69714 .23776 Mdot
.6976 .23869 Mdot
.69807 .23963 Mdot
.69853 .24056 Mdot
.69899 .24149 Mdot
.69946 .24243 Mdot
.69992 .24337 Mdot
.70038 .2443 Mdot
.70085 .24524 Mdot
.70131 .24618 Mdot
.70177 .24712 Mdot
.70224 .24807 Mdot
.7027 .24901 Mdot
.70316 .24995 Mdot
.70363 .2509 Mdot
.70409 .25184 Mdot
.70455 .25279 Mdot
.70502 .25374 Mdot
.70548 .25469 Mdot
.70594 .25564 Mdot
.70641 .25659 Mdot
.70687 .25754 Mdot
.70734 .25849 Mdot
.7078 .25944 Mdot
.70826 .2604 Mdot
.70873 .26135 Mdot
.70919 .26231 Mdot
.70965 .26327 Mdot
.71012 .26422 Mdot
.71058 .26518 Mdot
.71104 .26614 Mdot
.71151 .2671 Mdot
.71197 .26806 Mdot
.71243 .26902 Mdot
.7129 .26999 Mdot
.71336 .27095 Mdot
.71383 .27191 Mdot
.71429 .27288 Mdot
.71475 .27385 Mdot
.71522 .27481 Mdot
.71568 .27578 Mdot
.71614 .27675 Mdot
.71661 .27772 Mdot
.71707 .27869 Mdot
.71753 .27966 Mdot
.718 .28063 Mdot
.71846 .2816 Mdot
.71893 .28257 Mdot
.71939 .28354 Mdot
.71985 .28452 Mdot
.72032 .28549 Mdot
.72078 .28647 Mdot
.72124 .28744 Mdot
.72171 .28842 Mdot
.72217 .28939 Mdot
.72264 .29037 Mdot
.7231 .29135 Mdot
.72356 .29233 Mdot
.72403 .29331 Mdot
.72449 .29429 Mdot
.72496 .29527 Mdot
.72542 .29625 Mdot
.72588 .29723 Mdot
.72635 .29821 Mdot
.72681 .2992 Mdot
.72727 .30018 Mdot
.72774 .30116 Mdot
.7282 .30215 Mdot
.72867 .30313 Mdot
.72913 .30412 Mdot
.72959 .3051 Mdot
.73006 .30609 Mdot
.73052 .30707 Mdot
.73099 .30806 Mdot
.73145 .30905 Mdot
.73191 .31004 Mdot
.73238 .31102 Mdot
.73284 .31201 Mdot
.73331 .313 Mdot
.73377 .31399 Mdot
.73423 .31498 Mdot
.7347 .31597 Mdot
.73516 .31696 Mdot
.73563 .31795 Mdot
.73609 .31894 Mdot
.73656 .31994 Mdot
.73702 .32093 Mdot
.73748 .32192 Mdot
.73795 .32291 Mdot
.73841 .3239 Mdot
.73888 .3249 Mdot
.73934 .32589 Mdot
.7398 .32688 Mdot
.74027 .32788 Mdot
.74073 .32887 Mdot
.7412 .32987 Mdot
.74166 .33086 Mdot
.74213 .33186 Mdot
.74259 .33285 Mdot
.74305 .33385 Mdot
.74352 .33484 Mdot
.74398 .33584 Mdot
.74445 .33683 Mdot
.74491 .33783 Mdot
.74537 .33882 Mdot
.74584 .33982 Mdot
.7463 .34081 Mdot
.74677 .34181 Mdot
.74723 .34281 Mdot
.7477 .3438 Mdot
.74816 .3448 Mdot
.74863 .3458 Mdot
.74909 .34679 Mdot
.74955 .34779 Mdot
.75002 .34878 Mdot
.75048 .34978 Mdot
.75095 .35078 Mdot
.75141 .35177 Mdot
.75188 .35277 Mdot
.75234 .35377 Mdot
.75281 .35476 Mdot
.75327 .35576 Mdot
.75373 .35676 Mdot
.7542 .35775 Mdot
.75466 .35875 Mdot
.75513 .35974 Mdot
.75559 .36074 Mdot
.75606 .36174 Mdot
.75652 .36273 Mdot
.75699 .36373 Mdot
.75745 .36472 Mdot
.75792 .36572 Mdot
.75838 .36671 Mdot
.75884 .36771 Mdot
.75931 .3687 Mdot
.75977 .3697 Mdot
.76024 .37069 Mdot
.7607 .37168 Mdot
.76117 .37268 Mdot
.76163 .37367 Mdot
.7621 .37466 Mdot
.76256 .37566 Mdot
.76303 .37665 Mdot
.76349 .37764 Mdot
.76396 .37863 Mdot
.76442 .37963 Mdot
.76489 .38062 Mdot
.76535 .38161 Mdot
.76582 .3826 Mdot
.76628 .38359 Mdot
.76674 .38458 Mdot
.76721 .38557 Mdot
.76767 .38656 Mdot
.76814 .38755 Mdot
.7686 .38853 Mdot
.76907 .38952 Mdot
.76953 .39051 Mdot
.77 .3915 Mdot
.77046 .39248 Mdot
.77093 .39347 Mdot
.77139 .39445 Mdot
.77186 .39544 Mdot
.77232 .39642 Mdot
.77279 .39741 Mdot
.77325 .39839 Mdot
.77372 .39937 Mdot
.77418 .40036 Mdot
.77465 .40134 Mdot
.77511 .40232 Mdot
.77558 .4033 Mdot
.77604 .40428 Mdot
.77651 .40526 Mdot
.77697 .40624 Mdot
.77744 .40721 Mdot
.7779 .40819 Mdot
.77837 .40917 Mdot
.77883 .41014 Mdot
.7793 .41112 Mdot
.77976 .41209 Mdot
.78023 .41307 Mdot
.78069 .41404 Mdot
.78116 .41501 Mdot
.78163 .41598 Mdot
.78209 .41695 Mdot
.78256 .41792 Mdot
.78302 .41889 Mdot
.78349 .41986 Mdot
.78395 .42083 Mdot
.78442 .42179 Mdot
.78488 .42276 Mdot
.78535 .42372 Mdot
.78581 .42469 Mdot
.78628 .42565 Mdot
.78674 .42661 Mdot
.78721 .42757 Mdot
.78767 .42853 Mdot
.78814 .42949 Mdot
.7886 .43045 Mdot
.78907 .43141 Mdot
.78954 .43236 Mdot
.79 .43332 Mdot
.79047 .43427 Mdot
.79093 .43522 Mdot
.7914 .43618 Mdot
.79186 .43713 Mdot
.79233 .43808 Mdot
.79279 .43903 Mdot
.79326 .43997 Mdot
.79373 .44092 Mdot
.79419 .44187 Mdot
.79466 .44281 Mdot
.79512 .44375 Mdot
.79559 .44469 Mdot
.79605 .44564 Mdot
.79652 .44657 Mdot
.79698 .44751 Mdot
.79745 .44845 Mdot
.79792 .44939 Mdot
.79838 .45032 Mdot
.79885 .45125 Mdot
.79931 .45219 Mdot
.79978 .45312 Mdot
.80024 .45405 Mdot
.80071 .45498 Mdot
.80118 .4559 Mdot
.80164 .45683 Mdot
.80211 .45775 Mdot
.80257 .45867 Mdot
.80304 .4596 Mdot
.8035 .46052 Mdot
.80397 .46143 Mdot
.80444 .46235 Mdot
.8049 .46327 Mdot
.80537 .46418 Mdot
.80583 .46509 Mdot
.8063 .46601 Mdot
.80677 .46692 Mdot
.80723 .46782 Mdot
.8077 .46873 Mdot
.80816 .46964 Mdot
.80863 .47054 Mdot
.8091 .47144 Mdot
.80956 .47234 Mdot
.81003 .47324 Mdot
.81049 .47414 Mdot
.81096 .47503 Mdot
.81143 .47593 Mdot
.81189 .47682 Mdot
.81236 .47771 Mdot
.81282 .4786 Mdot
.81329 .47949 Mdot
.81376 .48037 Mdot
.81422 .48125 Mdot
.81469 .48214 Mdot
.81516 .48302 Mdot
.81562 .4839 Mdot
.81609 .48477 Mdot
.81655 .48565 Mdot
.81702 .48652 Mdot
.81749 .48739 Mdot
.81795 .48826 Mdot
.81842 .48913 Mdot
.81889 .48999 Mdot
.81935 .49086 Mdot
.81982 .49172 Mdot
.82028 .49258 Mdot
.82075 .49344 Mdot
.82122 .49429 Mdot
.82168 .49514 Mdot
.82215 .496 Mdot
.82262 .49685 Mdot
.82308 .49769 Mdot
.82355 .49854 Mdot
.82402 .49938 Mdot
.82448 .50023 Mdot
.82495 .50106 Mdot
.82542 .5019 Mdot
.82588 .50274 Mdot
.82635 .50357 Mdot
.82682 .5044 Mdot
.82728 .50523 Mdot
.82775 .50606 Mdot
.82822 .50688 Mdot
.82868 .5077 Mdot
.82915 .50852 Mdot
.82962 .50934 Mdot
.83008 .51016 Mdot
.83055 .51097 Mdot
.83102 .51178 Mdot
.83148 .51259 Mdot
.83195 .5134 Mdot
.83242 .5142 Mdot
.83288 .515 Mdot
.83335 .5158 Mdot
.83382 .5166 Mdot
.83428 .51739 Mdot
.83475 .51818 Mdot
.83522 .51897 Mdot
.83568 .51976 Mdot
.83615 .52054 Mdot
.83662 .52133 Mdot
.83708 .52211 Mdot
.83755 .52288 Mdot
.83802 .52366 Mdot
.83849 .52443 Mdot
.83895 .5252 Mdot
.83942 .52597 Mdot
.83989 .52673 Mdot
.84035 .52749 Mdot
.84082 .52825 Mdot
.84129 .52901 Mdot
.84175 .52976 Mdot
.84222 .53051 Mdot
.84269 .53126 Mdot
.84316 .532 Mdot
.84362 .53275 Mdot
.84409 .53349 Mdot
.84456 .53422 Mdot
.84502 .53496 Mdot
.84549 .53569 Mdot
.84596 .53642 Mdot
.84643 .53714 Mdot
.84689 .53787 Mdot
.84736 .53859 Mdot
.84783 .5393 Mdot
.8483 .54002 Mdot
.84876 .54073 Mdot
.84923 .54144 Mdot
.8497 .54214 Mdot
.85017 .54284 Mdot
.85063 .54354 Mdot
.8511 .54424 Mdot
.85157 .54493 Mdot
.85204 .54562 Mdot
.8525 .54631 Mdot
.85297 .54699 Mdot
.85344 .54768 Mdot
.85391 .54835 Mdot
.85437 .54903 Mdot
.85484 .5497 Mdot
.85531 .55037 Mdot
.85578 .55103 Mdot
.85624 .55169 Mdot
.85671 .55235 Mdot
.85718 .55301 Mdot
.85765 .55366 Mdot
.85811 .55431 Mdot
.85858 .55495 Mdot
.85905 .5556 Mdot
.85952 .55624 Mdot
.85999 .55687 Mdot
.86045 .5575 Mdot
.86092 .55813 Mdot
.86139 .55876 Mdot
.86186 .55938 Mdot
.86232 .56 Mdot
.86279 .56061 Mdot
.86326 .56122 Mdot
.86373 .56183 Mdot
.8642 .56243 Mdot
.86466 .56303 Mdot
.86513 .56363 Mdot
.8656 .56423 Mdot
.86607 .56482 Mdot
.86654 .5654 Mdot
.867 .56598 Mdot
.86747 .56656 Mdot
.86794 .56714 Mdot
.86841 .56771 Mdot
.86888 .56828 Mdot
.86934 .56884 Mdot
.86981 .5694 Mdot
.87028 .56996 Mdot
.87075 .57051 Mdot
.87122 .57106 Mdot
.87169 .5716 Mdot
.87215 .57215 Mdot
.87262 .57268 Mdot
.87309 .57322 Mdot
.87356 .57374 Mdot
.87403 .57427 Mdot
.8745 .57479 Mdot
.87496 .57531 Mdot
.87543 .57582 Mdot
.8759 .57633 Mdot
.87637 .57684 Mdot
.87684 .57734 Mdot
.87731 .57784 Mdot
.87777 .57833 Mdot
.87824 .57882 Mdot
.87871 .5793 Mdot
.87918 .57978 Mdot
.87965 .58026 Mdot
.88012 .58073 Mdot
.88059 .5812 Mdot
.88105 .58166 Mdot
.88152 .58212 Mdot
.88199 .58258 Mdot
.88246 .58303 Mdot
.88293 .58348 Mdot
.8834 .58392 Mdot
.88387 .58436 Mdot
.88434 .58479 Mdot
.8848 .58522 Mdot
.88527 .58564 Mdot
.88574 .58606 Mdot
.88621 .58648 Mdot
.88668 .58689 Mdot
.88715 .5873 Mdot
.88762 .5877 Mdot
.88809 .5881 Mdot
.88856 .58849 Mdot
.88902 .58888 Mdot
.88949 .58926 Mdot
.88996 .58964 Mdot
.89043 .59002 Mdot
.8909 .59039 Mdot
.89137 .59075 Mdot
.89184 .59111 Mdot
.89231 .59147 Mdot
.89278 .59182 Mdot
.89325 .59216 Mdot
.89372 .59251 Mdot
.89418 .59284 Mdot
.89465 .59317 Mdot
.89512 .5935 Mdot
.89559 .59382 Mdot
.89606 .59414 Mdot
.89653 .59445 Mdot
.897 .59476 Mdot
.89747 .59506 Mdot
.89794 .59536 Mdot
.89841 .59565 Mdot
.89888 .59593 Mdot
.89935 .59622 Mdot
.89982 .59649 Mdot
.90029 .59676 Mdot
.90076 .59703 Mdot
.90123 .59729 Mdot
.9017 .59755 Mdot
.90216 .5978 Mdot
.90263 .59804 Mdot
.9031 .59828 Mdot
.90357 .59852 Mdot
.90404 .59875 Mdot
.90451 .59897 Mdot
.90498 .59919 Mdot
.90545 .59941 Mdot
.90592 .59961 Mdot
.90639 .59982 Mdot
.90686 .60001 Mdot
.90733 .60021 Mdot
.9078 .60039 Mdot
.90827 .60057 Mdot
.90874 .60075 Mdot
.90921 .60092 Mdot
.90968 .60108 Mdot
.91015 .60124 Mdot
.91062 .60139 Mdot
.91109 .60154 Mdot
.91156 .60168 Mdot
.91203 .60182 Mdot
.9125 .60195 Mdot
.91297 .60207 Mdot
.91344 .60219 Mdot
.91391 .60231 Mdot
.91438 .60241 Mdot
.91485 .60251 Mdot
.91532 .60261 Mdot
.91579 .6027 Mdot
.91626 .60278 Mdot
.91673 .60286 Mdot
.9172 .60293 Mdot
.91767 .603 Mdot
.91814 .60306 Mdot
.91861 .60311 Mdot
.91908 .60316 Mdot
.91956 .6032 Mdot
.92003 .60323 Mdot
.9205 .60326 Mdot
.92097 .60329 Mdot
.92144 .6033 Mdot
.92191 .60331 Mdot
.92238 .60332 Mdot
.92285 .60332 Mdot
.92332 .60331 Mdot
.92379 .60329 Mdot
.92426 .60327 Mdot
.92473 .60325 Mdot
.9252 .60321 Mdot
.92567 .60317 Mdot
.92614 .60313 Mdot
.92661 .60307 Mdot
.92709 .60301 Mdot
.92756 .60295 Mdot
.92803 .60288 Mdot
.9285 .6028 Mdot
.92897 .60271 Mdot
.92944 .60262 Mdot
.92991 .60252 Mdot
.93038 .60242 Mdot
.93085 .6023 Mdot
.93132 .60219 Mdot
.93179 .60206 Mdot
.93227 .60193 Mdot
.93274 .60179 Mdot
.93321 .60164 Mdot
.93368 .60149 Mdot
.93415 .60133 Mdot
.93462 .60116 Mdot
.93509 .60099 Mdot
.93556 .60081 Mdot
.93603 .60062 Mdot
.93651 .60043 Mdot
.93698 .60023 Mdot
.93745 .60002 Mdot
.93792 .5998 Mdot
.93839 .59958 Mdot
.93886 .59935 Mdot
.93933 .59911 Mdot
.93981 .59887 Mdot
.94028 .59862 Mdot
.94075 .59836 Mdot
.94122 .59809 Mdot
.94169 .59782 Mdot
.94216 .59754 Mdot
.94264 .59725 Mdot
.94311 .59696 Mdot
.94358 .59665 Mdot
.94405 .59634 Mdot
.94452 .59602 Mdot
.94499 .5957 Mdot
.94547 .59537 Mdot
.94594 .59503 Mdot
.94641 .59468 Mdot
.94688 .59432 Mdot
.94735 .59396 Mdot
.94782 .59359 Mdot
.9483 .59321 Mdot
.94877 .59283 Mdot
.94924 .59243 Mdot
.94971 .59203 Mdot
.95018 .59162 Mdot
.95066 .5912 Mdot
.95113 .59078 Mdot
.9516 .59035 Mdot
.95207 .58991 Mdot
.95255 .58946 Mdot
.95302 .589 Mdot
.95349 .58854 Mdot
.95396 .58806 Mdot
.95443 .58758 Mdot
.95491 .58709 Mdot
.95538 .5866 Mdot
.95585 .58609 Mdot
.95632 .58558 Mdot
.9568 .58506 Mdot
.95727 .58453 Mdot
.95774 .58399 Mdot
.95821 .58344 Mdot
.95869 .58289 Mdot
.95916 .58232 Mdot
.95963 .58175 Mdot
.9601 .58117 Mdot
.96058 .58058 Mdot
.96105 .57999 Mdot
.96152 .57938 Mdot
.962 .57877 Mdot
.96247 .57815 Mdot
.96294 .57752 Mdot
.96341 .57688 Mdot
.96389 .57623 Mdot
.96436 .57557 Mdot
.96483 .57491 Mdot
.96531 .57423 Mdot
.96578 .57355 Mdot
.96625 .57286 Mdot
.96672 .57216 Mdot
.9672 .57145 Mdot
.96767 .57073 Mdot
.96814 .57 Mdot
.96862 .56926 Mdot
.96909 .56852 Mdot
.96956 .56776 Mdot
.97004 .567 Mdot
.97051 .56623 Mdot
.97098 .56545 Mdot
.97146 .56466 Mdot
.97193 .56386 Mdot
.9724 .56305 Mdot
.97288 .56223 Mdot
.97335 .5614 Mdot
.97382 .56057 Mdot
.9743 .55972 Mdot
.97477 .55886 Mdot
.97524 .558 Mdot
.97572 .55712 Mdot
.97619 .55624 Mdot
.5 Mabswid
.02381 .55624 m
.03097 .56862 L
.03853 .57945 L
.04619 .58821 L
.05058 .59228 L
.05458 .5954 L
.05815 .59773 L
.06204 .59978 L
.06417 .6007 L
.06614 .60143 L
.068 .602 L
.07001 .6025 L
.07193 .60287 L
.07369 .60311 L
.07454 .60319 L
.07499 .60323 L
.07546 .60326 L
.07592 .60328 L
.07634 .6033 L
.07675 .60331 L
.07714 .60332 L
.0776 .60332 L
.0781 .60331 L
.07835 .60331 L
.07862 .6033 L
.07911 .60328 L
.0796 .60326 L
.08006 .60323 L
.08092 .60316 L
.08193 .60305 L
.08287 .60292 L
.085 .60254 L
.08677 .60214 L
.08867 .60161 L
.09211 .60043 L
.09996 .59662 L
.10759 .59154 L
.11563 .58482 L
.13015 .56945 L
.1456 .54906 L
.16048 .52614 L
.17629 .49884 L
.19152 .47025 L
.20617 .44113 L
.22176 .4089 L
.23677 .37709 L
.2512 .34617 L
.26657 .31327 L
.28136 .28197 L
.29708 .24945 L
Mistroke
.31223 .21916 L
.3268 .19126 L
.3423 .16316 L
.35723 .13788 L
.37309 .11316 L
.38838 .09161 L
.40308 .07315 L
.41872 .05611 L
.43378 .04235 L
.44827 .03165 L
.45634 .0268 L
.46369 .02309 L
.4714 .01992 L
.47853 .01765 L
.482 .01678 L
.48582 .016 L
.48966 .0154 L
.49176 .01515 L
.49373 .01497 L
.49552 .01484 L
.49654 .01479 L
.49749 .01476 L
.498 .01474 L
.49849 .01473 L
.49892 .01472 L
.4994 .01472 L
.49964 .01472 L
.49991 .01472 L
.50019 .01472 L
.50046 .01472 L
.50093 .01472 L
.50119 .01472 L
.50143 .01473 L
.50187 .01474 L
.50233 .01475 L
.50317 .01478 L
.50406 .01482 L
.50505 .01488 L
.50682 .01501 L
.50849 .01517 L
.51223 .01567 L
.51617 .01638 L
.52321 .01814 L
.53073 .02072 L
.53772 .02375 L
.55258 .03221 L
.56838 .04416 L
.5836 .05846 L
.59824 .07471 L
.61381 .09456 L
Mistroke
.62881 .116 L
.64323 .13864 L
.65859 .16473 L
.67337 .19158 L
.68908 .22173 L
.70421 .25209 L
.71877 .28224 L
.73426 .31504 L
.74918 .34698 L
.76502 .38091 L
.7803 .4132 L
.79499 .44348 L
.81062 .47437 L
.82567 .50235 L
.84014 .52714 L
.85555 .55071 L
.87038 .57007 L
.87793 .57849 L
.88614 .58642 L
.89336 .59225 L
.90133 .59735 L
.90496 .59918 L
.90887 .60079 L
.91102 .60152 L
.913 .60208 L
.91487 .60252 L
.91687 .60288 L
.91788 .60302 L
.91883 .60313 L
.91969 .60321 L
.92013 .60324 L
.92061 .60327 L
.92106 .60329 L
.92149 .6033 L
.92194 .60331 L
.92242 .60332 L
.92287 .60332 L
.92329 .60331 L
.92367 .6033 L
.92409 .60328 L
.92462 .60325 L
.92513 .60322 L
.92607 .60313 L
.92709 .60301 L
.92818 .60285 L
.93016 .60247 L
.93197 .60201 L
.9357 .60076 L
.93917 .5992 L
.94322 .59689 L
Mistroke
.94705 .5942 L
.95482 .58718 L
.96189 .5789 L
.97619 .55624 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[75]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00=Oooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00005Oooool003Kooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001Cooooo000_ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Cooooo000hooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool04_ooool003Gooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Doooo
o`00=Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Dooooo`00=_ooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Eooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`009?oooooho`0000Cooooo000Tooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`02ooooo`009?oo
ool00ol0003oooooooooo`1cooooo`_o0000M_ooool00ol0003oooooooooo`02ooooo`009?ooool0
0ol0003oooooooooo`1`oooooa7o0000Loooool00ol0003oooooooooo`02ooooo`009?ooool2o`00
06oooooo1ol00003ooooo`04o`000?ooooooooooooooo`So0000Koooool2o`0000Cooooo000Toooo
o`03o`000?oooooooooo06cooooo1_l00006ooooo`03o`000?oooooooooo00Cooooo1_l0001_oooo
o`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo06_ooooo1Ol00008ooooo`03
o`000?oooooooooo00Oooooo1Ol0001]ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`00
0?oooooooooo06Wooooo1Ol0000:ooooo`03o`000?oooooooooo00Wooooo1?l0001/ooooo`03o`00
0?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo06Sooooo1?l0000<ooooo`03o`000?oo
oooooooo00[ooooo1Ol0001Zooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooo
oooo06Oooooo1?l0000=ooooo`03o`000?oooooooooo00cooooo1?l0001Yooooo`03o`000?oooooo
oooo00;ooooo000Tooooo`;o0000Ioooool4o`0000kooooo00?o0000ooooooooool03Oooool4o`00
06Oooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`1Tooooo`Go00003oooool00ol0003o
ooooooooo`0>ooooo`Co0000Ioooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooo
ooooo`1Sooooo`Co00004Oooool00ol0003oooooooooo`0?ooooo`Co0000I_ooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`1Sooooo`?o00004_ooool00ol0003ooooooooo
o`0@ooooo`Co0000IOooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`1R
ooooo`?o00004oooool00ol0003oooooooooo`0Aooooo`Co0000I?ooool00ol0003oooooooooo`02
ooooo`009?ooool00ol0003oooooooooo`1Qooooo`?o00005?ooool00ol0003oooooooooo`0Boooo
o`Co0000Hoooool00ol0003oooooooooo`02ooooo`009?ooool2o`00067ooooo0ol0000Eooooo`03
o`000?oooooooooo01?ooooo1?l0001Qooooo`;o00001?ooool002Cooooo00?o0000ooooooooool0
Goooool4o`0001Gooooo00?o0000ooooooooool05?ooool4o`00067ooooo00?o0000ooooooooool0
0_ooool002Cooooo00?o0000ooooooooool0G_ooool4o`0001Kooooo00?o0000ooooooooool05Ooo
ool3o`00067ooooo00?o0000ooooooooool00_ooool000Cooooo0ol00003ooooo`?o00001?ooool0
0ol0003oooooooooo`02ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool0GOooool4
o`0001Oooooo00?o0000ooooooooool05_ooool3o`00063ooooo00?o0000ooooooooool00_ooool0
00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool01Ooo
ool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05gooooo0ol0000Hooooo`03o`000?oooooooooo01Oooooo0ol0001Oooooo`03
o`000?oooooooooo00;ooooo0007ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Looooo`?o00006Oooool00ol0003oooooooooo`0Gooooo`Co0000G_ooool00ol0003o
ooooooooo`02ooooo`001oooool00ol0003oooooooooo`03o`0000Sooooo1?l00004ooooo`;o0000
1Ooooooho`0000Cooooo0003ooooo`Co00000_ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05[ooooo
1?l0000Jooooo`03o`000?oooooooooo01Wooooo0ol0001Mooooo`03o`000?oooooooooo00;ooooo
0003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05[o
oooo0ol0000Kooooo`03o`000?oooooooooo01[ooooo0ol0001Looooo`03o`000?oooooooooo00;o
oooo0003ooooo`Go00000_ooool3o`0000[ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooo
ooooo`1Iooooo`?o00007?ooool00ol0003oooooooooo`0Jooooo`Co0000Foooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`1Hooooo`Co00007?ooool00ol0003ooooooooo
o`0Kooooo`?o0000Foooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`1H
ooooo`?o00007Oooool00ol0003oooooooooo`0Looooo`?o0000F_ooool00ol0003oooooooooo`02
ooooo`009?ooool2o`0005Sooooo0ol0000Nooooo`03o`000?oooooooooo01cooooo1?l0001Hoooo
o`;o00001?ooool002Cooooo00?o0000ooooooooool0E_ooool4o`0001kooooo00?o0000oooooooo
ool07Oooool3o`0005Wooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0
E_ooool3o`0001oooooo00?o0000ooooooooool07_ooool3o`0005Sooooo00?o0000ooooooooool0
0_ooool002Cooooo00?o0000ooooooooool0EOooool3o`00023ooooo00?o0000ooooooooool07_oo
ool3o`0005Sooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0EOooool3
o`00023ooooo00?o0000ooooooooool07oooool3o`0005Oooooo00?o0000ooooooooool00_ooool0
02Cooooo00?o0000ooooooooool0E?ooool3o`00027ooooo00?o0000ooooooooool08?ooool3o`00
05Kooooo00?o0000ooooooooool00_ooool002Cooooo0_l0001Dooooo`?o00008_ooool00ol0003o
ooooooooo`0Pooooo`?o0000EOooool2o`0000Cooooo000Tooooo`03o`000?oooooooooo05?ooooo
0ol0000Rooooo`03o`000?oooooooooo027ooooo0ol0001Eooooo`03o`000?oooooooooo00;ooooo
000Tooooo`03o`000?oooooooooo05;ooooo0ol0000Sooooo`03o`000?oooooooooo027ooooo0ol0
001Eooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo05;ooooo0ol0000S
ooooo`03o`000?oooooooooo02;ooooo0ol0001Dooooo`03o`000?oooooooooo00;ooooo000Toooo
o`03o`000?oooooooooo057ooooo0ol0000Tooooo`03o`000?oooooooooo02?ooooo0ol0001Coooo
o`03o`000?oooooooooo00;ooooo000Tooooo`;o0000DOooool3o`0002Gooooo00?o0000oooooooo
ool08oooool3o`0005;ooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`1@ooooo`?o0000
9Oooool00ol0003oooooooooo`0Tooooo`?o0000D_ooool00ol0003oooooooooo`02ooooo`009?oo
ool00ol0003oooooooooo`1?ooooo`?o00009_ooool00ol0003oooooooooo`0Tooooo`?o0000D_oo
ool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`1?ooooo`?o00009_ooool0
0ol0003oooooooooo`0Uooooo`?o0000DOooool00ol0003oooooooooo`02ooooo`009?ooool00ol0
003oooooooooo`1>ooooo`?o00009oooool00ol0003oooooooooo`0Uooooo`?o0000DOooool00ol0
003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`1>ooooo`?o00009oooool00ol0003o
ooooooooo`0Vooooo`?o0000D?ooool00ol0003oooooooooo`02ooooo`009?ooool2o`0004kooooo
0ol0000Xooooo`03o`000?oooooooooo02Oooooo0_l0001?ooooo`;o00001?ooool002Cooooo00?o
0000ooooooooool0COooool2o`0002Wooooo00?o0000ooooooooool09oooool3o`0004oooooo00?o
0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0C?ooool3o`0002Wooooo00?o0000
ooooooooool0:?ooool3o`0004kooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooo
ooooool0C?ooool2o`0002[ooooo00?o0000ooooooooool0:?ooool3o`0004kooooo00?o0000oooo
ooooool00_ooool000Cooooo0ol00003ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001?ooool3o`0000Cooooo00?o0000ooooooooool0Boooool3o`0002[ooooo00?o0000oooooooo
ool0:Oooool3o`0004gooooo00?o0000ooooooooool00_ooool000?ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`;o0000:oooool0
0ol0003oooooooooo`0Yooooo`?o0000COooool00ol0003oooooooooo`02ooooo`001oooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Ko0000ooooooooooooooooo`000?oo
ool5o`0000Cooooo0_l0001;ooooo`?o0000:oooool00ol0003oooooooooo`0Zooooo`?o0000Booo
ool2o`0000Cooooo0007ooooo`03o`000?oooooooooo00?o00002?ooool4o`0000;ooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`19ooooo`?o0000;?ooool00ol0003ooooooooo
o`0Zooooo`?o0000C?ooool00ol0003oooooooooo`02ooooo`000oooool4o`0000;ooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001Ooo
ool00ol0003oooooooooo`19ooooo`?o0000;?ooool00ol0003oooooooooo`0[ooooo`?o0000Booo
ool00ol0003oooooooooo`02ooooo`000oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003ooooooooo
o`18ooooo`?o0000;Oooool00ol0003oooooooooo`0[ooooo`?o0000Boooool00ol0003ooooooooo
o`02ooooo`000oooool5o`0000;ooooo0ol0000:ooooo`;o00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04Sooooo0ol0000]ooooo`03o`000?oooooooooo02cooooo0ol0001:
ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo04Oooooo0ol0000^oooo
o`03o`000?oooooooooo02cooooo0ol0001:ooooo`03o`000?oooooooooo00;ooooo000Tooooo`;o
0000B?ooool3o`0002kooooo00?o0000ooooooooool0;Oooool3o`0004Sooooo0_l00004ooooo`00
9?ooool00ol0003oooooooooo`16ooooo`?o0000;oooool00ol0003oooooooooo`0]ooooo`?o0000
BOooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`16ooooo`?o0000;ooo
ool00ol0003oooooooooo`0^ooooo`?o0000B?ooool00ol0003oooooooooo`02ooooo`009?ooool0
0ol0003oooooooooo`15ooooo`?o0000<?ooool00ol0003oooooooooo`0^ooooo`?o0000B?ooool0
0ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`15ooooo`?o0000<?ooool00ol0
003oooooooooo`0_ooooo`?o0000Aoooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003o
ooooooooo`14ooooo`?o0000<Oooool00ol0003oooooooooo`0_ooooo`?o0000Aoooool00ol0003o
ooooooooo`02ooooo`009?ooool2o`0004Gooooo0ol0000aooooo`03o`000?oooooooooo033ooooo
0ol00015ooooo`;o00001?ooool002Cooooo00?o0000ooooooooool0A?ooool2o`0003;ooooo00?o
0000ooooooooool0<?ooool3o`0004Kooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000
ooooooooool0@oooool3o`0003;ooooo00?o0000ooooooooool0<Oooool3o`0004Gooooo00?o0000
ooooooooool00_ooool002Cooooo00?o0000ooooooooool0@oooool2o`0003?ooooo00?o0000oooo
ooooool0<Oooool3o`0004Gooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooooooo
ool0@_ooool3o`0003?ooooo00?o0000ooooooooool0<_ooool3o`0004Cooooo00?o0000oooooooo
ool00_ooool002Cooooo00?o0000ooooooooool0@_ooool2o`0003Cooooo00?o0000ooooooooool0
<_ooool3o`0004Cooooo00?o0000ooooooooool00_ooool002Cooooo0_l00012ooooo`?o0000=?oo
ool00ol0003oooooooooo`0cooooo`;o0000@oooool2o`0000Cooooo000Tooooo`03o`000?oooooo
oooo047ooooo0_l0000eooooo`03o`000?oooooooooo03?ooooo0ol00013ooooo`03o`000?oooooo
oooo00;ooooo000Tooooo`03o`000?oooooooooo043ooooo0ol0000eooooo`03o`000?oooooooooo
03Cooooo0_l00013ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo043o
oooo0ol0000eooooo`03o`000?oooooooooo03Cooooo0ol00012ooooo`03o`000?oooooooooo00;o
oooo000Tooooo`03o`000?oooooooooo03oooooo0ol0000fooooo`03o`000?oooooooooo03Gooooo
0_l00012ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo03oooooo0ol0
000fooooo`03o`000?oooooooooo03Gooooo0ol00011ooooo`03o`000?oooooooooo00;ooooo000T
ooooo`;o0000?oooool3o`0003Oooooo00?o0000ooooooooool0=Oooool3o`00043ooooo0_l00004
ooooo`009?ooool00ol0003oooooooooo`0nooooo`?o0000=oooool00ol0003oooooooooo`0foooo
o`?o0000@?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0mooooo`?o
0000>?ooool00ol0003oooooooooo`0fooooo`?o0000@?ooool00ol0003oooooooooo`02ooooo`00
1?ooool3o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`?o0000
1Oooool00ol0003oooooooooo`0mooooo`?o0000>?ooool00ol0003oooooooooo`0gooooo`?o0000
?oooool00ol0003oooooooooo`02ooooo`000oooool01ol0003ooooooooooooooooo0000ooooool0
00000oooool00ol0003oooooooooo`05ooooo`07o`000?ooooooooooooooool0003oooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0??ooool3o`0003Wooooo00?o0000
ooooooooool0=oooool3o`0003oooooo00?o0000ooooooooool00_ooool000Oooooo00?o0000oooo
ool000000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo0ol0000iooooo`03o`000?oooooo
oooo03Sooooo0ol0000nooooo`03o`000?oooooooooo00;ooooo0007ooooo`03o`000?oooooooooo
00?o00002?ooool4o`0000Kooooo00?o0000ooooooooool00_ooool2o`0003cooooo0ol0000joooo
o`03o`000?oooooooooo03Sooooo0ol0000mooooo`;o00001?ooool000?ooooo1?l00002ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`Co00001Oooool00ol0
003oooooooooo`0kooooo`?o0000>_ooool00ol0003oooooooooo`0iooooo`?o0000?Oooool00ol0
003oooooooooo`02ooooo`000oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0>oooool2o`0003_ooooo00?o0000ooooooooool0>Oooool3o`0003gooooo00?o0000oooo
ooooool00_ooool000?ooooo1Ol00002ooooo`?o00002_ooool2o`0000;ooooo1Ol00004ooooo`03
o`000?oooooooooo03[ooooo0ol0000kooooo`03o`000?oooooooooo03[ooooo0_l0000mooooo`03
o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo03[ooooo0_l0000looooo`03o`00
0?oooooooooo03[ooooo0ol0000looooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oo
oooooooo03Wooooo0ol0000looooo`03o`000?oooooooooo03_ooooo0_l0000looooo`03o`000?oo
oooooooo00;ooooo000Tooooo`;o0000>_ooool3o`0003cooooo00?o0000ooooooooool0>oooool3
o`0003[ooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`0hooooo`?o0000?Oooool00ol0
003oooooooooo`0looooo`;o0000>oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003o
ooooooooo`0hooooo`?o0000?Oooool00ol0003oooooooooo`0looooo`?o0000>_ooool00ol0003o
ooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0gooooo`?o0000?_ooool00ol0003ooooo
ooooo`0mooooo`;o0000>_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooooooo
o`0gooooo`?o0000?_ooool00ol0003oooooooooo`0mooooo`?o0000>Oooool00ol0003ooooooooo
o`02ooooo`009?ooool00ol0003oooooooooo`0fooooo`?o0000?oooool00ol0003oooooooooo`0m
ooooo`?o0000>Oooool00ol0003oooooooooo`02ooooo`009?ooool2o`0003Oooooo0ol0000ooooo
o`03o`000?oooooooooo03kooooo0ol0000gooooo`;o00001?ooool002Cooooo00?o0000oooooooo
ool0=Oooool3o`00043ooooo00?o0000ooooooooool0?_ooool3o`0003Sooooo00?o0000oooooooo
ool00_ooool002Cooooo00?o0000ooooooooool0=Oooool3o`00043ooooo00?o0000ooooooooool0
?oooool3o`0003Oooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0=?oo
ool3o`00047ooooo00?o0000ooooooooool0?oooool3o`0003Oooooo00?o0000ooooooooool00_oo
ool002Cooooo00?o0000ooooooooool0=?ooool3o`00047ooooo00?o0000ooooooooool0@?ooool3
o`0003Kooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0=?ooool2o`00
04;ooooo00?o0000ooooooooool0@?ooool3o`0003Kooooo00?o0000ooooooooool00_ooool002Co
oooo0_l0000dooooo`?o0000@_ooool00ol0003oooooooooo`11ooooo`?o0000=?ooool2o`0000Co
oooo000Tooooo`03o`000?oooooooooo03?ooooo0_l00013ooooo`03o`000?oooooooooo047ooooo
0ol0000eooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo03;ooooo0ol0
0013ooooo`03o`000?oooooooooo04;ooooo0ol0000dooooo`03o`000?oooooooooo00;ooooo000T
ooooo`03o`000?oooooooooo03;ooooo0_l00014ooooo`03o`000?oooooooooo04;ooooo0ol0000d
ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo037ooooo0ol00014oooo
o`03o`000?oooooooooo04?ooooo0_l0000dooooo`03o`000?oooooooooo00;ooooo000Tooooo`03
o`000?oooooooooo037ooooo0_l00015ooooo`03o`000?oooooooooo04?ooooo0ol0000cooooo`03
o`000?oooooooooo00;ooooo000Tooooo`;o0000<Oooool3o`0004Gooooo00?o0000ooooooooool0
A?ooool2o`0003;ooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`0`ooooo`;o0000A_oo
ool00ol0003oooooooooo`14ooooo`?o0000<_ooool00ol0003oooooooooo`02ooooo`009?ooool0
0ol0003oooooooooo`0_ooooo`?o0000A_ooool00ol0003oooooooooo`15ooooo`;o0000<_ooool0
0ol0003oooooooooo`02ooooo`001?ooool3o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo
00;ooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`0_ooooo`?o0000A_ooool00ol0
003oooooooooo`15ooooo`?o0000<Oooool00ol0003oooooooooo`02ooooo`000oooool01ol0003o
oooooooooooooooo0000ooooool000000oooool00ol0003oooooooooo`05ooooo`07o`000?oooooo
ooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
;_ooool3o`0004Oooooo00?o0000ooooooooool0A_ooool2o`00037ooooo00?o0000ooooooooool0
0_ooool000Oooooo00?o0000ooooool000000oooool00ol0003oooooooooo`05ooooo`07o`000?oo
ooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo0_l0000_ooooo`?o
0000Aoooool00ol0003oooooooooo`16ooooo`?o0000;oooool2o`0000Cooooo0007ooooo`03o`00
0?oooooooooo00?o00002?ooool4o`0000;ooooo1?l00005ooooo`03o`000?oooooooooo02gooooo
0ol00018ooooo`03o`000?oooooooooo04Oooooo0_l0000`ooooo`03o`000?oooooooooo00;ooooo
0003ooooo`Co00000_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo0ol00018ooooo`03o`00
0?oooooooooo04Oooooo0ol0000_ooooo`03o`000?oooooooooo00;ooooo0003ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`?o0000BOooool00ol0003ooooo
ooooo`18ooooo`;o0000;oooool00ol0003oooooooooo`02ooooo`000oooool5o`0000;ooooo0ol0
000:ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0;?ooool3o`0004Wooooo00?o
0000ooooooooool0B?ooool3o`0002kooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000
ooooooooool0:oooool3o`0004[ooooo00?o0000ooooooooool0BOooool2o`0002kooooo00?o0000
ooooooooool00_ooool002Cooooo0_l0000/ooooo`?o0000B_ooool00ol0003oooooooooo`19oooo
o`?o0000;?ooool2o`0000Cooooo000Tooooo`03o`000?oooooooooo02[ooooo0ol0001;ooooo`03
o`000?oooooooooo04[ooooo0_l0000]ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`00
0?oooooooooo02[ooooo0_l0001<ooooo`03o`000?oooooooooo04[ooooo0ol0000/ooooo`03o`00
0?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo02Wooooo0ol0001<ooooo`03o`000?oo
oooooooo04_ooooo0ol0000[ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooo
oooo02Wooooo0_l0001=ooooo`03o`000?oooooooooo04_ooooo0ol0000[ooooo`03o`000?oooooo
oooo00;ooooo000Tooooo`03o`000?oooooooooo02Sooooo0ol0001=ooooo`03o`000?oooooooooo
04cooooo0ol0000Zooooo`03o`000?oooooooooo00;ooooo000Tooooo`;o0000:?ooool3o`0004ko
oooo00?o0000ooooooooool0C?ooool3o`0002Wooooo0_l00004ooooo`009?ooool00ol0003ooooo
ooooo`0Wooooo`?o0000C_ooool00ol0003oooooooooo`1=ooooo`?o0000:Oooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`0Vooooo`?o0000Coooool00ol0003ooooooooo
o`1=ooooo`?o0000:Oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0V
ooooo`?o0000Coooool00ol0003oooooooooo`1>ooooo`?o0000:?ooool00ol0003oooooooooo`02
ooooo`009?ooool00ol0003oooooooooo`0Uooooo`?o0000D?ooool00ol0003oooooooooo`1>oooo
o`Co00009oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Tooooo`Co
0000D?ooool00ol0003oooooooooo`1?ooooo`?o00009oooool00ol0003oooooooooo`02ooooo`00
9?ooool2o`0002Gooooo0ol0001Aooooo`03o`000?oooooooooo053ooooo0ol0000Uooooo`;o0000
1?ooool002Cooooo00?o0000ooooooooool08oooool3o`0005;ooooo00?o0000ooooooooool0D?oo
ool3o`0002Kooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool08oooool3
o`0005;ooooo00?o0000ooooooooool0DOooool3o`0002Gooooo00?o0000ooooooooool00_ooool0
02Cooooo00?o0000ooooooooool08_ooool3o`0005?ooooo00?o0000ooooooooool0DOooool4o`00
02Cooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool08Oooool4o`0005?o
oooo00?o0000ooooooooool0D_ooool3o`0002Cooooo00?o0000ooooooooool00_ooool002Cooooo
00?o0000ooooooooool08Oooool3o`0005Cooooo00?o0000ooooooooool0Doooool3o`0002?ooooo
00?o0000ooooooooool00_ooool002Cooooo0_l0000Qooooo`?o0000EOooool00ol0003ooooooooo
o`1Cooooo`Co00008Oooool2o`0000Cooooo000Tooooo`03o`000?oooooooooo01oooooo1?l0001E
ooooo`03o`000?oooooooooo05Cooooo0ol0000Rooooo`03o`000?oooooooooo00;ooooo000Toooo
o`03o`000?oooooooooo00;ooooo0_l0000Jooooo`Co0000E_ooool00ol0003oooooooooo`1Eoooo
o`?o00006_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooooooo
ool00_ooool3o`0001Wooooo0ol0001Gooooo`03o`000?oooooooooo05Gooooo1?l0000Iooooo`;o
00001Oooool00ol0003oooooooooo`02ooooo`001?ooool3o`0000?ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool3o`0001Oooooo0ol0001Hooooo`03o`000?oooooooooo05Kooooo1?l0000Gooooo`?o0000
1Oooool00ol0003oooooooooo`02ooooo`000oooool01ol0003ooooooooooooooooo0000ooooool0
00000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0ol0000Fooooo`Co0000F?ooool00ol0
003oooooooooo`1Gooooo`Co00005Oooool4o`0000Gooooo00?o0000ooooooooool00_ooool000Oo
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool3o`0001Cooooo1?l0001Ioooo
o`03o`000?oooooooooo05Sooooo0ol0000Eooooo`?o00001Oooool2o`0000Cooooo0007ooooo`03
o`000?oooooooooo00?o00002?ooool4o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`Co00004_ooool4o`0005[ooooo00?o0000ooooooooool0FOooool3o`0001?o
oooo0ol00007ooooo`03o`000?oooooooooo00;ooooo0003ooooo`Co00000_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo0ol0000Aooooo`Co0000Foooool00ol0003oooooooooo`1Iooooo`Co
00004Oooool4o`0000Oooooo00?o0000ooooooooool00_ooool000?ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool01_ooool3o`0000oooooo1?l0001Loooo
o`03o`000?oooooooooo05[ooooo1?l0000?ooooo`Co00002?ooool00ol0003oooooooooo`02oooo
o`000oooool5o`0000;ooooo0ol0000:ooooo`;o00000_ooool5o`0000Cooooo00?o0000oooooooo
ool01oooool3o`0000gooooo1?l0001Mooooo`03o`000?oooooooooo05_ooooo1Ol0000<ooooo`Co
00002Oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`07ooooo`Go0000
2Oooool5o`0005kooooo00?o0000ooooooooool0GOooool4o`0000[ooooo1?l0000:ooooo`03o`00
0?oooooooooo00;ooooo000Tooooo`;o00002_ooool4o`0000Oooooo1Ol0001Oooooo`03o`000?oo
oooooooo05kooooo1Ol00006ooooo`Go00002_ooool2o`0000Cooooo000Tooooo`03o`000?oooooo
oooo00[ooooo3Ol0001Qooooo`03o`000?oooooooooo05oooooo3_l0000<ooooo`03o`000?oooooo
oooo00;ooooo000Tooooo`03o`000?oooooooooo00_ooooo2_l0001Sooooo`03o`000?oooooooooo
067ooooo2_l0000>ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo07So
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`009?oooooho`0000Cooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo000`ooooo`?o0000F?ooool3o`0001Oooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`0>ooooo`00<Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`0=ooooo`00:oooool3o`0000?ooooo0ol00004
ooooo`;o00000_ooool5o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000ol00007
ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001_ooool5o`0000;ooooo0ol00002
ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_ooool6o`0000Oooooo00?o
0000ooooooooool00oooool4o`000003ooooool0003o000000;o00000_ooool4o`0000?ooooo0ol0
0002ooooo`Go00000oooool2o`000004ooooool0003oooooooooo`;o00000oooool3o`0000Wooooo
1?l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00001?ooool2o`0000?ooooo
1?l000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0003o00000oooool3o`00
00Gooooo00?o0000ooooooooool03?ooool002[ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0
003oooooo`0000Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00005ooooo`03
o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool0000;ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo0000
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooool000002?ooool00ol0003oooooooooo`0<ooooo`00:_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001_ooool3o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`03ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`?o00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;ooooo1Ol00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000?ooooo00?o0000ooooooooool00oooool3o`0000?ooooo00Ko
0000oooooooooooo0000ooooool00005ooooo`Go00001?ooool00ol0003oooooooooo`0<ooooo`00
:_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool3o`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooo
oooo0000ooooool00005ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03?ooool002[ooooo00Ko0000ooooooooooooooooo`000?ooool4o`00
00;ooooo1?l00002ooooo`?o00001?ooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002Oooool0
0ol0003oooooooooo`03ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o00002Oooool0
0ol0003oooooooooo`03ooooo`;o00001?ooool3o`0000?ooooo1?l00002ooooo`?o00001?ooool0
1?l0003oooooooooooooool2o`000004ooooool0003o0000ooooo`Co00000oooool3o`0000Wooooo
0ol00002ooooo`?o00001?ooool4o`000003ooooool0003o000000;o00000oooool2o`0000?ooooo
1?l00003ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool03?ooool002[ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0=ooooo`00:oooool3o`0000Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0=ooooo`?o00002Oooool4o`0000Wooooo00?o0000ooooooooool0
0_ooool2o`0000[ooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`03o`00
0?oooooooooo00Kooooo0_l0000@ooooo`?o00002_ooool00ol0003oooooooooo`0@ooooo`;o0000
1?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
3_ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-30.8197, 58.6182, 0.192645, \
0.000338137}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0210016 -1.35426 0.881347 [
[.07997 -0.0125 -9 -9 ]
[.07997 -0.0125 9 0 ]
[.28998 -0.0125 -9 -9 ]
[.28998 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.71002 -0.0125 -6 -9 ]
[.71002 -0.0125 6 0 ]
[.92003 -0.0125 -6 -9 ]
[.92003 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0559 -18 -4.5 ]
[-0.0125 .0559 0 4.5 ]
[-0.0125 .14403 -18 -4.5 ]
[-0.0125 .14403 0 4.5 ]
[-0.0125 .23217 -18 -4.5 ]
[-0.0125 .23217 0 4.5 ]
[-0.0125 .3203 -18 -4.5 ]
[-0.0125 .3203 0 4.5 ]
[-0.0125 .40844 -6 -4.5 ]
[-0.0125 .40844 0 4.5 ]
[-0.0125 .49657 -18 -4.5 ]
[-0.0125 .49657 0 4.5 ]
[-0.0125 .58471 -18 -4.5 ]
[-0.0125 .58471 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07997 0 m
.07997 .00625 L
s
[(-20)] .07997 -0.0125 0 1 Mshowa
.28998 0 m
.28998 .00625 L
s
[(-10)] .28998 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.71002 0 m
.71002 .00625 L
s
[(10)] .71002 -0.0125 0 1 Mshowa
.92003 0 m
.92003 .00625 L
s
[(20)] .92003 -0.0125 0 1 Mshowa
.125 Mabswid
.12197 0 m
.12197 .00375 L
s
.16397 0 m
.16397 .00375 L
s
.20598 0 m
.20598 .00375 L
s
.24798 0 m
.24798 .00375 L
s
.33199 0 m
.33199 .00375 L
s
.37399 0 m
.37399 .00375 L
s
.41599 0 m
.41599 .00375 L
s
.458 0 m
.458 .00375 L
s
.542 0 m
.542 .00375 L
s
.58401 0 m
.58401 .00375 L
s
.62601 0 m
.62601 .00375 L
s
.66801 0 m
.66801 .00375 L
s
.75202 0 m
.75202 .00375 L
s
.79402 0 m
.79402 .00375 L
s
.83603 0 m
.83603 .00375 L
s
.87803 0 m
.87803 .00375 L
s
.03797 0 m
.03797 .00375 L
s
.96203 0 m
.96203 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0559 m
.00625 .0559 L
s
[(1.6)] -0.0125 .0559 1 0 Mshowa
0 .14403 m
.00625 .14403 L
s
[(1.7)] -0.0125 .14403 1 0 Mshowa
0 .23217 m
.00625 .23217 L
s
[(1.8)] -0.0125 .23217 1 0 Mshowa
0 .3203 m
.00625 .3203 L
s
[(1.9)] -0.0125 .3203 1 0 Mshowa
0 .40844 m
.00625 .40844 L
s
[(2)] -0.0125 .40844 1 0 Mshowa
0 .49657 m
.00625 .49657 L
s
[(2.1)] -0.0125 .49657 1 0 Mshowa
0 .58471 m
.00625 .58471 L
s
[(2.2)] -0.0125 .58471 1 0 Mshowa
.125 Mabswid
0 .07352 m
.00375 .07352 L
s
0 .09115 m
.00375 .09115 L
s
0 .10878 m
.00375 .10878 L
s
0 .12641 m
.00375 .12641 L
s
0 .16166 m
.00375 .16166 L
s
0 .17929 m
.00375 .17929 L
s
0 .19691 m
.00375 .19691 L
s
0 .21454 m
.00375 .21454 L
s
0 .24979 m
.00375 .24979 L
s
0 .26742 m
.00375 .26742 L
s
0 .28505 m
.00375 .28505 L
s
0 .30268 m
.00375 .30268 L
s
0 .33793 m
.00375 .33793 L
s
0 .35556 m
.00375 .35556 L
s
0 .37318 m
.00375 .37318 L
s
0 .39081 m
.00375 .39081 L
s
0 .42606 m
.00375 .42606 L
s
0 .44369 m
.00375 .44369 L
s
0 .46132 m
.00375 .46132 L
s
0 .47894 m
.00375 .47894 L
s
0 .5142 m
.00375 .5142 L
s
0 .53183 m
.00375 .53183 L
s
0 .54945 m
.00375 .54945 L
s
0 .56708 m
.00375 .56708 L
s
0 .03827 m
.00375 .03827 L
s
0 .02064 m
.00375 .02064 L
s
0 .00302 m
.00375 .00302 L
s
0 .60233 m
.00375 .60233 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07997 .61178 m
.07997 .61803 L
s
.28998 .61178 m
.28998 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.71002 .61178 m
.71002 .61803 L
s
.92003 .61178 m
.92003 .61803 L
s
.125 Mabswid
.12197 .61428 m
.12197 .61803 L
s
.16397 .61428 m
.16397 .61803 L
s
.20598 .61428 m
.20598 .61803 L
s
.24798 .61428 m
.24798 .61803 L
s
.33199 .61428 m
.33199 .61803 L
s
.37399 .61428 m
.37399 .61803 L
s
.41599 .61428 m
.41599 .61803 L
s
.458 .61428 m
.458 .61803 L
s
.542 .61428 m
.542 .61803 L
s
.58401 .61428 m
.58401 .61803 L
s
.62601 .61428 m
.62601 .61803 L
s
.66801 .61428 m
.66801 .61803 L
s
.75202 .61428 m
.75202 .61803 L
s
.79402 .61428 m
.79402 .61803 L
s
.83603 .61428 m
.83603 .61803 L
s
.87803 .61428 m
.87803 .61803 L
s
.03797 .61428 m
.03797 .61803 L
s
.96203 .61428 m
.96203 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0559 m
1 .0559 L
s
.99375 .14403 m
1 .14403 L
s
.99375 .23217 m
1 .23217 L
s
.99375 .3203 m
1 .3203 L
s
.99375 .40844 m
1 .40844 L
s
.99375 .49657 m
1 .49657 L
s
.99375 .58471 m
1 .58471 L
s
.125 Mabswid
.99625 .07352 m
1 .07352 L
s
.99625 .09115 m
1 .09115 L
s
.99625 .10878 m
1 .10878 L
s
.99625 .12641 m
1 .12641 L
s
.99625 .16166 m
1 .16166 L
s
.99625 .17929 m
1 .17929 L
s
.99625 .19691 m
1 .19691 L
s
.99625 .21454 m
1 .21454 L
s
.99625 .24979 m
1 .24979 L
s
.99625 .26742 m
1 .26742 L
s
.99625 .28505 m
1 .28505 L
s
.99625 .30268 m
1 .30268 L
s
.99625 .33793 m
1 .33793 L
s
.99625 .35556 m
1 .35556 L
s
.99625 .37318 m
1 .37318 L
s
.99625 .39081 m
1 .39081 L
s
.99625 .42606 m
1 .42606 L
s
.99625 .44369 m
1 .44369 L
s
.99625 .46132 m
1 .46132 L
s
.99625 .47894 m
1 .47894 L
s
.99625 .5142 m
1 .5142 L
s
.99625 .53183 m
1 .53183 L
s
.99625 .54945 m
1 .54945 L
s
.99625 .56708 m
1 .56708 L
s
.99625 .03827 m
1 .03827 L
s
.99625 .02064 m
1 .02064 L
s
.99625 .00302 m
1 .00302 L
s
.99625 .60233 m
1 .60233 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .0164 m
.02426 .46153 L
.02466 .54704 L
.02514 .5542 L
.02558 .55444 L
.02599 .55456 L
.02637 .55463 L
.02723 .55483 L
.03097 .55577 L
.03853 .55757 L
.05458 .56131 L
.06957 .56463 L
.08398 .56763 L
.09933 .57062 L
.1141 .57338 L
.12981 .57606 L
.14493 .57855 L
.15948 .58078 L
.17497 .58296 L
.18987 .58495 L
.20571 .58692 L
.22098 .58873 L
.23566 .59033 L
.25128 .59189 L
.26633 .59331 L
.28079 .59458 L
.29619 .59584 L
.31101 .59693 L
.32677 .59796 L
.34195 .59886 L
.35655 .59969 L
.37209 .60044 L
.38705 .60109 L
.40143 .60156 L
.41674 .60203 L
.43148 .60245 L
.43544 .60255 L
.43912 .60265 L
.43957 .60267 L
.44007 .60266 L
.44054 .60267 L
.44097 .60269 L
.44121 .60267 L
.44148 .60269 L
.44175 .60271 L
.44201 .60267 L
.44247 .60268 L
.44295 .60268 L
.44323 .60276 L
.44349 .6027 L
Mistroke
.44378 .60274 L
.44408 .60276 L
.44437 .6027 L
.44464 .60279 L
.44488 .60272 L
.44515 .60278 L
.44539 .60275 L
.44566 .60277 L
.44593 .60279 L
.44619 .60275 L
.44666 .60276 L
.44715 .60275 L
.44762 .60276 L
.44788 .60285 L
.44813 .60277 L
.44863 .60279 L
.44892 .60282 L
.44917 .60283 L
.44961 .60283 L
.45008 .60284 L
.45104 .60286 L
.45128 .60291 L
.45154 .60292 L
.45183 .60291 L
.45209 .60293 L
.45256 .60293 L
.45308 .60294 L
.45422 .60296 L
.45526 .60297 L
.45924 .60303 L
.46293 .60308 L
.46491 .60309 L
.46595 .60305 L
.4662 .60311 L
.46648 .60303 L
.46678 .60311 L
.46706 .60309 L
.46731 .60308 L
.46758 .60312 L
.46786 .60305 L
.46812 .60315 L
.46859 .60315 L
.46909 .60314 L
.46934 .60309 L
.4696 .60313 L
.47008 .60313 L
.47054 .60313 L
.47098 .60315 L
.4714 .60317 L
.47185 .60318 L
Mistroke
.47228 .60319 L
.47267 .60316 L
.47313 .60317 L
.47363 .60318 L
.4741 .60319 L
.47454 .60318 L
.47503 .6032 L
.4755 .6032 L
.47592 .60319 L
.47637 .60318 L
.47686 .6032 L
.47711 .60317 L
.47738 .60323 L
.47787 .60324 L
.47832 .60324 L
.4788 .60324 L
.47924 .60324 L
.47972 .60325 L
.47997 .60315 L
.48024 .60324 L
.48069 .60325 L
.48118 .60324 L
.48164 .60325 L
.48206 .60327 L
.48247 .60324 L
.48285 .60327 L
.48327 .60327 L
.48372 .60327 L
.48419 .60327 L
.48463 .60327 L
.48503 .60328 L
.48547 .60328 L
.48594 .60328 L
.48639 .60329 L
.48688 .60329 L
.4874 .60329 L
.48791 .60329 L
.48846 .6033 L
.48897 .6033 L
.48945 .6033 L
.48993 .6033 L
.49038 .6033 L
.49063 .60331 L
.4909 .6033 L
.49137 .6033 L
.49182 .6033 L
.49229 .6033 L
.49269 .60331 L
.49313 .60331 L
.49363 .60331 L
Mistroke
.49409 .60331 L
.49433 .60332 L
.4946 .60331 L
.49487 .60331 L
.49513 .60323 L
.49561 .60324 L
.49605 .60322 L
.49655 .60325 L
.49703 .60325 L
.49745 .60324 L
.49791 .60323 L
.49834 .60322 L
.49873 .60326 L
.49918 .60326 L
.49968 .60325 L
.50015 .60325 L
.50058 .60327 L
.50104 .60327 L
.50154 .60326 L
.502 .60326 L
.50243 .60327 L
.50293 .60326 L
.50321 .60332 L
.50347 .60324 L
.50395 .60324 L
.50419 .60331 L
.50446 .60326 L
.50472 .60328 L
.50499 .60328 L
.50547 .60329 L
.50574 .60324 L
.506 .60331 L
.50627 .60324 L
.50657 .60328 L
.50683 .60327 L
.5071 .60325 L
.50737 .6033 L
.50761 .60323 L
.50807 .60323 L
.50855 .60322 L
.50901 .60322 L
.50952 .60321 L
.50996 .60321 L
.51043 .6032 L
.5109 .6032 L
.51132 .60322 L
.51172 .60324 L
.51215 .60326 L
.51264 .60324 L
.5131 .60324 L
Mistroke
.5136 .60322 L
.51387 .60327 L
.51414 .60328 L
.51461 .60328 L
.51504 .60328 L
.51554 .60327 L
.51601 .60327 L
.51932 .60325 L
.52298 .60323 L
.5239 .60322 L
.52438 .60322 L
.52462 .60321 L
.52488 .60322 L
.52537 .60321 L
.52582 .60319 L
.52623 .6032 L
.52667 .60318 L
.52691 .6031 L
.52717 .6032 L
.52746 .60311 L
.52772 .60316 L
.5282 .60315 L
.52847 .60314 L
.52872 .60312 L
.52919 .60311 L
.52962 .60313 L
.53011 .60311 L
.53058 .6031 L
.5376 .60301 L
.54093 .60295 L
.54184 .60292 L
.5423 .60291 L
.54281 .60292 L
.54324 .6029 L
.5437 .60289 L
.54413 .60289 L
.54453 .60291 L
.54477 .60294 L
.54503 .60288 L
.5455 .60296 L
.546 .60295 L
.54629 .60295 L
.54656 .60294 L
.54704 .60294 L
.54748 .60293 L
.54847 .60291 L
.55218 .60285 L
.55403 .60281 L
.555 .60279 L
.55604 .60277 L
Mistroke
.55655 .60276 L
.55704 .60275 L
.55747 .60274 L
.55794 .60266 L
.55839 .60264 L
.55886 .60264 L
.55926 .60261 L
.5597 .60262 L
.55996 .6027 L
.56024 .60261 L
.56051 .60266 L
.56075 .60262 L
.56121 .60261 L
.5617 .60261 L
.56195 .60261 L
.56223 .60263 L
.56272 .60263 L
.563 .60254 L
.5633 .6026 L
.56356 .60257 L
.56384 .60256 L
.56481 .60252 L
.56509 .60259 L
.56535 .6025 L
.56584 .6025 L
.56631 .60249 L
.56674 .60247 L
.56721 .60246 L
.5677 .60246 L
.56816 .60245 L
.56867 .60245 L
.56914 .60245 L
.56958 .60242 L
.57001 .6024 L
.57041 .60238 L
.57088 .60237 L
.5713 .60238 L
.57177 .60236 L
.57227 .60234 L
.57269 .60234 L
.57316 .60233 L
.57516 .60227 L
.57559 .60224 L
.57606 .60223 L
.57647 .6022 L
.57691 .60221 L
.57715 .60228 L
.57741 .60217 L
.57788 .60226 L
.57834 .60225 L
Mistroke
.57877 .60224 L
.58214 .60215 L
.5969 .60167 L
.6126 .60102 L
.62771 .60038 L
.64225 .59974 L
.65773 .59892 L
.67263 .59796 L
.68846 .59692 L
.70371 .59574 L
.71839 .59468 L
.734 .5933 L
.74903 .59184 L
.76349 .59038 L
.77888 .58873 L
.79369 .58698 L
.80944 .58504 L
.82461 .58304 L
.8392 .58097 L
.85473 .57858 L
.86968 .57613 L
.88405 .57366 L
.89935 .57085 L
.91408 .56802 L
.92975 .56481 L
.94483 .56151 L
.95934 .55813 L
.96743 .55619 L
.97121 .55524 L
.97292 .5548 L
.97389 .55456 L
.97431 .55437 L
.97478 .5543 L
.97514 .55287 L
.97547 .53541 L
.97582 .43651 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[75]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;oooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00006oooool0033ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001[ooooo000Yooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001[ooooo000booooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool06?ooool002oooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Joooo
o`00;oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Jooooo`00<?ooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Kooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`007_oooooho`0000[ooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool000[ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool0
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`002oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0
00001?ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00;ooooo0_l0000:ooooo`002oooool00ol0003oooooooooo`07ooooo`Co0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo000:ooooo`;o00002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000ooooooooool02Oooool2o`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Co
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;o
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool000[ooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo00;ooooo0_l0000:ooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`002_ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1coooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000oooooooo
ool01oooool5o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Co
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;o
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool000[ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo
0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000_ooooo00?o
0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`07ooooo`05o`000?oo
ooooooooooooool000001?ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`002oooool00ol0003ooooooooo
o`08ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool000[ooooo0_l00009ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;
ooooo`03o`000?oooooooooo00Sooooo0ol00005ooooo`;o00001?ooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1coooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo0_l0
0004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o0000
2_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002_ooool3
o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`002oooool00ol0003oooooooooo`08ooooo`Co00001?ooool2o`0000Cooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo
0_l0000:ooooo`002oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000:ooooo`;o00002Ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`002oooool00ol0003oooooooooo`08ooooo`?o00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1coooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo0_l0
0004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o0000
2_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`005Oooool5
o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`005_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo000Hooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool001Gooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool001Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool001Kooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool001kooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`02ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`Go00000ooo
ool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`003?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`002Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`05
o`000?ooooooooooooooool000002?ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`002_ooool3o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool6o`0006oooooo
00?o0000ooooooooool0L?ooool4o`0000Gooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool02Oooool4o`0006_ooooo00?o0000ooooooooool0J_ooool6o`0000Wooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool03Oooool4o`0006Oooooo00?o0000
ooooooooool0I_ooool4o`0000oooooo00?o0000ooooooooool02?ooool001kooooo0_l0000Boooo
o`Co0000Hoooool00ol0003oooooooooo`1Rooooo`Co00004_ooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo01Gooooo1ol0001Looooo`03o`000?oooooooooo05_ooooo1ol0000Gooooo`03
o`000?oooooooooo00Sooooo0009ooooo`Go00000oooool01?l0003oooooooooooooool5o`0000Co
oooo00?o0000ooooooooool07?ooool4o`0005Sooooo00?o0000ooooooooool0Eoooool4o`0001ko
oooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo023ooooo1ol0001Aooooo`03o`000?oooooooooo
053ooooo1ol0000Rooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool2o`0002Sooooo2?l00019ooooo`03o`000?oooooooooo04So
oooo2?l0000Xooooo`;o00002_ooool000cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02oooooo2?l00011ooooo`03o`000?oooooooooo047ooooo
1ol0000aooooo`03o`000?oooooooooo00Sooooo0009ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0=oooool;o`0003Ko
oooo00?o0000ooooooooool0=Oooool<o`0003Sooooo00?o0000ooooooooool02?ooool000Wooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`12ooooo`oo00009oooool00ol0003oooooooooo`0Vooooo`oo0000A?ooool00ol0
003oooooooooo`08ooooo`002_ooool3o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo057o
oooo5_l0000Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_l0001Cooooo`03
o`000?oooooooooo00Sooooo000Nooooo`;o0000J?oooolVo`0006Kooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool001kooooon?l0000:ooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00c?ooool3o`00057ooooo003=ooooo`03o`000?oooooooooo
053ooooo001Qooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooooooo00;o
oooo0ol00002ooooo`?o00000oooool3o`0000Cooooo0ol00002ooooo`?o000000?oooooo`000?l0
00000_ooool2o`0000Sooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`00
00?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l00002ooooo`Go00000oooool2o`00
00Cooooo00?o0000ooooooooool0Coooool0067ooooo00?o0000ooooool000000_ooool01?l0003o
ooooooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04o`000?oo
ooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0Coooool0067ooooo00?o0000ooooool000000oooool3o`0000?o
oooo00?o0000ooooool000000_ooool5o`0000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo
0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`00001@ooooo`00H?ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003o
oooooooooooooooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo0ol0
0003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oooooooooool0003oooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo0000053ooooo001Pooooo`05o`000?oooooo0000ooooool00000
0_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00000oooool00ol0003ooooo
ooooo`02ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l00002ooooo`Co0000
2_ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000?o
oooo1?l000001?oooooo0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o0000
04oooooo001Pooooo`05o`000?oooooo0000ooooool000005?ooool01?l0003oooooooooool0000D
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo05Kooooo001Pooooo`Ko00004_ooool5o`0001Cooooo00?o0000oooo
ooooool02?ooool5o`0000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.6639, 1.48108, 0.192645, \
0.00459052}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0210016 0.0147151 0.00636545 [
[.07997 -0.0125 -9 -9 ]
[.07997 -0.0125 9 0 ]
[.28998 -0.0125 -9 -9 ]
[.28998 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.71002 -0.0125 -6 -9 ]
[.71002 -0.0125 6 0 ]
[.92003 -0.0125 -6 -9 ]
[.92003 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14202 -12 -4.5 ]
[-0.0125 .14202 0 4.5 ]
[-0.0125 .26933 -12 -4.5 ]
[-0.0125 .26933 0 4.5 ]
[-0.0125 .39664 -12 -4.5 ]
[-0.0125 .39664 0 4.5 ]
[-0.0125 .52395 -12 -4.5 ]
[-0.0125 .52395 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07997 0 m
.07997 .00625 L
s
[(-20)] .07997 -0.0125 0 1 Mshowa
.28998 0 m
.28998 .00625 L
s
[(-10)] .28998 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.71002 0 m
.71002 .00625 L
s
[(10)] .71002 -0.0125 0 1 Mshowa
.92003 0 m
.92003 .00625 L
s
[(20)] .92003 -0.0125 0 1 Mshowa
.125 Mabswid
.12197 0 m
.12197 .00375 L
s
.16397 0 m
.16397 .00375 L
s
.20598 0 m
.20598 .00375 L
s
.24798 0 m
.24798 .00375 L
s
.33199 0 m
.33199 .00375 L
s
.37399 0 m
.37399 .00375 L
s
.41599 0 m
.41599 .00375 L
s
.458 0 m
.458 .00375 L
s
.542 0 m
.542 .00375 L
s
.58401 0 m
.58401 .00375 L
s
.62601 0 m
.62601 .00375 L
s
.66801 0 m
.66801 .00375 L
s
.75202 0 m
.75202 .00375 L
s
.79402 0 m
.79402 .00375 L
s
.83603 0 m
.83603 .00375 L
s
.87803 0 m
.87803 .00375 L
s
.03797 0 m
.03797 .00375 L
s
.96203 0 m
.96203 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14202 m
.00625 .14202 L
s
[(20)] -0.0125 .14202 1 0 Mshowa
0 .26933 m
.00625 .26933 L
s
[(40)] -0.0125 .26933 1 0 Mshowa
0 .39664 m
.00625 .39664 L
s
[(60)] -0.0125 .39664 1 0 Mshowa
0 .52395 m
.00625 .52395 L
s
[(80)] -0.0125 .52395 1 0 Mshowa
.125 Mabswid
0 .04654 m
.00375 .04654 L
s
0 .07837 m
.00375 .07837 L
s
0 .1102 m
.00375 .1102 L
s
0 .17385 m
.00375 .17385 L
s
0 .20568 m
.00375 .20568 L
s
0 .23751 m
.00375 .23751 L
s
0 .30116 m
.00375 .30116 L
s
0 .33299 m
.00375 .33299 L
s
0 .36481 m
.00375 .36481 L
s
0 .42847 m
.00375 .42847 L
s
0 .4603 m
.00375 .4603 L
s
0 .49212 m
.00375 .49212 L
s
0 .55578 m
.00375 .55578 L
s
0 .58761 m
.00375 .58761 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07997 .61178 m
.07997 .61803 L
s
.28998 .61178 m
.28998 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.71002 .61178 m
.71002 .61803 L
s
.92003 .61178 m
.92003 .61803 L
s
.125 Mabswid
.12197 .61428 m
.12197 .61803 L
s
.16397 .61428 m
.16397 .61803 L
s
.20598 .61428 m
.20598 .61803 L
s
.24798 .61428 m
.24798 .61803 L
s
.33199 .61428 m
.33199 .61803 L
s
.37399 .61428 m
.37399 .61803 L
s
.41599 .61428 m
.41599 .61803 L
s
.458 .61428 m
.458 .61803 L
s
.542 .61428 m
.542 .61803 L
s
.58401 .61428 m
.58401 .61803 L
s
.62601 .61428 m
.62601 .61803 L
s
.66801 .61428 m
.66801 .61803 L
s
.75202 .61428 m
.75202 .61803 L
s
.79402 .61428 m
.79402 .61803 L
s
.83603 .61428 m
.83603 .61803 L
s
.87803 .61428 m
.87803 .61803 L
s
.03797 .61428 m
.03797 .61803 L
s
.96203 .61428 m
.96203 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14202 m
1 .14202 L
s
.99375 .26933 m
1 .26933 L
s
.99375 .39664 m
1 .39664 L
s
.99375 .52395 m
1 .52395 L
s
.125 Mabswid
.99625 .04654 m
1 .04654 L
s
.99625 .07837 m
1 .07837 L
s
.99625 .1102 m
1 .1102 L
s
.99625 .17385 m
1 .17385 L
s
.99625 .20568 m
1 .20568 L
s
.99625 .23751 m
1 .23751 L
s
.99625 .30116 m
1 .30116 L
s
.99625 .33299 m
1 .33299 L
s
.99625 .36481 m
1 .36481 L
s
.99625 .42847 m
1 .42847 L
s
.99625 .4603 m
1 .4603 L
s
.99625 .49212 m
1 .49212 L
s
.99625 .55578 m
1 .55578 L
s
.99625 .58761 m
1 .58761 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .55624 Mdot
.02428 .55712 Mdot
.02476 .558 Mdot
.02523 .55886 Mdot
.0257 .55972 Mdot
.02618 .56057 Mdot
.02665 .5614 Mdot
.02712 .56223 Mdot
.0276 .56305 Mdot
.02807 .56386 Mdot
.02854 .56466 Mdot
.02902 .56545 Mdot
.02949 .56623 Mdot
.02996 .567 Mdot
.03044 .56776 Mdot
.03091 .56852 Mdot
.03138 .56926 Mdot
.03186 .57 Mdot
.03233 .57073 Mdot
.0328 .57145 Mdot
.03328 .57216 Mdot
.03375 .57286 Mdot
.03422 .57355 Mdot
.03469 .57423 Mdot
.03517 .57491 Mdot
.03564 .57557 Mdot
.03611 .57623 Mdot
.03659 .57688 Mdot
.03706 .57752 Mdot
.03753 .57815 Mdot
.038 .57877 Mdot
.03848 .57938 Mdot
.03895 .57999 Mdot
.03942 .58058 Mdot
.0399 .58117 Mdot
.04037 .58175 Mdot
.04084 .58232 Mdot
.04131 .58289 Mdot
.04179 .58344 Mdot
.04226 .58399 Mdot
.04273 .58453 Mdot
.0432 .58506 Mdot
.04368 .58558 Mdot
.04415 .58609 Mdot
.04462 .5866 Mdot
.04509 .58709 Mdot
.04557 .58758 Mdot
.04604 .58806 Mdot
.04651 .58854 Mdot
.04698 .589 Mdot
.04745 .58946 Mdot
.04793 .58991 Mdot
.0484 .59035 Mdot
.04887 .59078 Mdot
.04934 .5912 Mdot
.04982 .59162 Mdot
.05029 .59203 Mdot
.05076 .59243 Mdot
.05123 .59283 Mdot
.0517 .59321 Mdot
.05218 .59359 Mdot
.05265 .59396 Mdot
.05312 .59432 Mdot
.05359 .59468 Mdot
.05406 .59503 Mdot
.05453 .59537 Mdot
.05501 .5957 Mdot
.05548 .59602 Mdot
.05595 .59634 Mdot
.05642 .59665 Mdot
.05689 .59696 Mdot
.05736 .59725 Mdot
.05784 .59754 Mdot
.05831 .59782 Mdot
.05878 .59809 Mdot
.05925 .59836 Mdot
.05972 .59862 Mdot
.06019 .59887 Mdot
.06067 .59911 Mdot
.06114 .59935 Mdot
.06161 .59958 Mdot
.06208 .5998 Mdot
.06255 .60002 Mdot
.06302 .60023 Mdot
.06349 .60043 Mdot
.06397 .60062 Mdot
.06444 .60081 Mdot
.06491 .60099 Mdot
.06538 .60116 Mdot
.06585 .60133 Mdot
.06632 .60149 Mdot
.06679 .60164 Mdot
.06726 .60179 Mdot
.06773 .60193 Mdot
.06821 .60206 Mdot
.06868 .60219 Mdot
.06915 .6023 Mdot
.06962 .60242 Mdot
.07009 .60252 Mdot
.07056 .60262 Mdot
.07103 .60271 Mdot
.0715 .6028 Mdot
.07197 .60288 Mdot
.07244 .60295 Mdot
.07291 .60301 Mdot
.07339 .60307 Mdot
.07386 .60313 Mdot
.07433 .60317 Mdot
.0748 .60321 Mdot
.07527 .60325 Mdot
.07574 .60327 Mdot
.07621 .60329 Mdot
.07668 .60331 Mdot
.07715 .60332 Mdot
.07762 .60332 Mdot
.07809 .60331 Mdot
.07856 .6033 Mdot
.07903 .60329 Mdot
.0795 .60326 Mdot
.07997 .60323 Mdot
.08044 .6032 Mdot
.08092 .60316 Mdot
.08139 .60311 Mdot
.08186 .60306 Mdot
.08233 .603 Mdot
.0828 .60293 Mdot
.08327 .60286 Mdot
.08374 .60278 Mdot
.08421 .6027 Mdot
.08468 .60261 Mdot
.08515 .60251 Mdot
.08562 .60241 Mdot
.08609 .60231 Mdot
.08656 .60219 Mdot
.08703 .60207 Mdot
.0875 .60195 Mdot
.08797 .60182 Mdot
.08844 .60168 Mdot
.08891 .60154 Mdot
.08938 .60139 Mdot
.08985 .60124 Mdot
.09032 .60108 Mdot
.09079 .60092 Mdot
.09126 .60075 Mdot
.09173 .60057 Mdot
.0922 .60039 Mdot
.09267 .60021 Mdot
.09314 .60001 Mdot
.09361 .59982 Mdot
.09408 .59961 Mdot
.09455 .59941 Mdot
.09502 .59919 Mdot
.09549 .59897 Mdot
.09596 .59875 Mdot
.09643 .59852 Mdot
.0969 .59828 Mdot
.09737 .59804 Mdot
.09784 .5978 Mdot
.0983 .59755 Mdot
.09877 .59729 Mdot
.09924 .59703 Mdot
.09971 .59676 Mdot
.10018 .59649 Mdot
.10065 .59622 Mdot
.10112 .59593 Mdot
.10159 .59565 Mdot
.10206 .59536 Mdot
.10253 .59506 Mdot
.103 .59476 Mdot
.10347 .59445 Mdot
.10394 .59414 Mdot
.10441 .59382 Mdot
.10488 .5935 Mdot
.10535 .59317 Mdot
.10582 .59284 Mdot
.10628 .59251 Mdot
.10675 .59216 Mdot
.10722 .59182 Mdot
.10769 .59147 Mdot
.10816 .59111 Mdot
.10863 .59075 Mdot
.1091 .59039 Mdot
.10957 .59002 Mdot
.11004 .58964 Mdot
.11051 .58926 Mdot
.11098 .58888 Mdot
.11144 .58849 Mdot
.11191 .5881 Mdot
.11238 .5877 Mdot
.11285 .5873 Mdot
.11332 .58689 Mdot
.11379 .58648 Mdot
.11426 .58606 Mdot
.11473 .58564 Mdot
.1152 .58522 Mdot
.11566 .58479 Mdot
.11613 .58436 Mdot
.1166 .58392 Mdot
.11707 .58348 Mdot
.11754 .58303 Mdot
.11801 .58258 Mdot
.11848 .58212 Mdot
.11895 .58166 Mdot
.11941 .5812 Mdot
.11988 .58073 Mdot
.12035 .58026 Mdot
.12082 .57978 Mdot
.12129 .5793 Mdot
.12176 .57882 Mdot
.12223 .57833 Mdot
.12269 .57784 Mdot
.12316 .57734 Mdot
.12363 .57684 Mdot
.1241 .57633 Mdot
.12457 .57582 Mdot
.12504 .57531 Mdot
.1255 .57479 Mdot
.12597 .57427 Mdot
.12644 .57374 Mdot
.12691 .57322 Mdot
.12738 .57268 Mdot
.12785 .57215 Mdot
.12831 .5716 Mdot
.12878 .57106 Mdot
.12925 .57051 Mdot
.12972 .56996 Mdot
.13019 .5694 Mdot
.13066 .56884 Mdot
.13112 .56828 Mdot
.13159 .56771 Mdot
.13206 .56714 Mdot
.13253 .56656 Mdot
.133 .56598 Mdot
.13346 .5654 Mdot
.13393 .56482 Mdot
.1344 .56423 Mdot
.13487 .56363 Mdot
.13534 .56303 Mdot
.1358 .56243 Mdot
.13627 .56183 Mdot
.13674 .56122 Mdot
.13721 .56061 Mdot
.13768 .56 Mdot
.13814 .55938 Mdot
.13861 .55876 Mdot
.13908 .55813 Mdot
.13955 .5575 Mdot
.14001 .55687 Mdot
.14048 .55624 Mdot
.14095 .5556 Mdot
.14142 .55495 Mdot
.14189 .55431 Mdot
.14235 .55366 Mdot
.14282 .55301 Mdot
.14329 .55235 Mdot
.14376 .55169 Mdot
.14422 .55103 Mdot
.14469 .55037 Mdot
.14516 .5497 Mdot
.14563 .54903 Mdot
.14609 .54835 Mdot
.14656 .54768 Mdot
.14703 .54699 Mdot
.1475 .54631 Mdot
.14796 .54562 Mdot
.14843 .54493 Mdot
.1489 .54424 Mdot
.14937 .54354 Mdot
.14983 .54284 Mdot
.1503 .54214 Mdot
.15077 .54144 Mdot
.15124 .54073 Mdot
.1517 .54002 Mdot
.15217 .5393 Mdot
.15264 .53859 Mdot
.15311 .53787 Mdot
.15357 .53714 Mdot
.15404 .53642 Mdot
.15451 .53569 Mdot
.15498 .53496 Mdot
.15544 .53422 Mdot
.15591 .53349 Mdot
.15638 .53275 Mdot
.15684 .532 Mdot
.15731 .53126 Mdot
.15778 .53051 Mdot
.15825 .52976 Mdot
.15871 .52901 Mdot
.15918 .52825 Mdot
.15965 .52749 Mdot
.16011 .52673 Mdot
.16058 .52597 Mdot
.16105 .5252 Mdot
.16151 .52443 Mdot
.16198 .52366 Mdot
.16245 .52288 Mdot
.16292 .52211 Mdot
.16338 .52133 Mdot
.16385 .52054 Mdot
.16432 .51976 Mdot
.16478 .51897 Mdot
.16525 .51818 Mdot
.16572 .51739 Mdot
.16618 .5166 Mdot
.16665 .5158 Mdot
.16712 .515 Mdot
.16758 .5142 Mdot
.16805 .5134 Mdot
.16852 .51259 Mdot
.16898 .51178 Mdot
.16945 .51097 Mdot
.16992 .51016 Mdot
.17038 .50934 Mdot
.17085 .50852 Mdot
.17132 .5077 Mdot
.17178 .50688 Mdot
.17225 .50606 Mdot
.17272 .50523 Mdot
.17318 .5044 Mdot
.17365 .50357 Mdot
.17412 .50274 Mdot
.17458 .5019 Mdot
.17505 .50106 Mdot
.17552 .50023 Mdot
.17598 .49938 Mdot
.17645 .49854 Mdot
.17692 .49769 Mdot
.17738 .49685 Mdot
.17785 .496 Mdot
.17832 .49514 Mdot
.17878 .49429 Mdot
.17925 .49344 Mdot
.17972 .49258 Mdot
.18018 .49172 Mdot
.18065 .49086 Mdot
.18111 .48999 Mdot
.18158 .48913 Mdot
.18205 .48826 Mdot
.18251 .48739 Mdot
.18298 .48652 Mdot
.18345 .48565 Mdot
.18391 .48477 Mdot
.18438 .4839 Mdot
.18484 .48302 Mdot
.18531 .48214 Mdot
.18578 .48125 Mdot
.18624 .48037 Mdot
.18671 .47949 Mdot
.18718 .4786 Mdot
.18764 .47771 Mdot
.18811 .47682 Mdot
.18857 .47593 Mdot
.18904 .47503 Mdot
.18951 .47414 Mdot
.18997 .47324 Mdot
.19044 .47234 Mdot
.1909 .47144 Mdot
.19137 .47054 Mdot
.19184 .46964 Mdot
.1923 .46873 Mdot
.19277 .46782 Mdot
.19323 .46692 Mdot
.1937 .46601 Mdot
.19417 .46509 Mdot
.19463 .46418 Mdot
.1951 .46327 Mdot
.19556 .46235 Mdot
.19603 .46143 Mdot
.1965 .46052 Mdot
.19696 .4596 Mdot
.19743 .45867 Mdot
.19789 .45775 Mdot
.19836 .45683 Mdot
.19882 .4559 Mdot
.19929 .45498 Mdot
.19976 .45405 Mdot
.20022 .45312 Mdot
.20069 .45219 Mdot
.20115 .45125 Mdot
.20162 .45032 Mdot
.20208 .44939 Mdot
.20255 .44845 Mdot
.20302 .44751 Mdot
.20348 .44657 Mdot
.20395 .44564 Mdot
.20441 .44469 Mdot
.20488 .44375 Mdot
.20534 .44281 Mdot
.20581 .44187 Mdot
.20627 .44092 Mdot
.20674 .43997 Mdot
.20721 .43903 Mdot
.20767 .43808 Mdot
.20814 .43713 Mdot
.2086 .43618 Mdot
.20907 .43522 Mdot
.20953 .43427 Mdot
.21 .43332 Mdot
.21046 .43236 Mdot
.21093 .43141 Mdot
.2114 .43045 Mdot
.21186 .42949 Mdot
.21233 .42853 Mdot
.21279 .42757 Mdot
.21326 .42661 Mdot
.21372 .42565 Mdot
.21419 .42469 Mdot
.21465 .42372 Mdot
.21512 .42276 Mdot
.21558 .42179 Mdot
.21605 .42083 Mdot
.21651 .41986 Mdot
.21698 .41889 Mdot
.21744 .41792 Mdot
.21791 .41695 Mdot
.21837 .41598 Mdot
.21884 .41501 Mdot
.21931 .41404 Mdot
.21977 .41307 Mdot
.22024 .41209 Mdot
.2207 .41112 Mdot
.22117 .41014 Mdot
.22163 .40917 Mdot
.2221 .40819 Mdot
.22256 .40721 Mdot
.22303 .40624 Mdot
.22349 .40526 Mdot
.22396 .40428 Mdot
.22442 .4033 Mdot
.22489 .40232 Mdot
.22535 .40134 Mdot
.22582 .40036 Mdot
.22628 .39937 Mdot
.22675 .39839 Mdot
.22721 .39741 Mdot
.22768 .39642 Mdot
.22814 .39544 Mdot
.22861 .39445 Mdot
.22907 .39347 Mdot
.22954 .39248 Mdot
.23 .3915 Mdot
.23047 .39051 Mdot
.23093 .38952 Mdot
.2314 .38853 Mdot
.23186 .38755 Mdot
.23233 .38656 Mdot
.23279 .38557 Mdot
.23326 .38458 Mdot
.23372 .38359 Mdot
.23418 .3826 Mdot
.23465 .38161 Mdot
.23511 .38062 Mdot
.23558 .37963 Mdot
.23604 .37863 Mdot
.23651 .37764 Mdot
.23697 .37665 Mdot
.23744 .37566 Mdot
.2379 .37466 Mdot
.23837 .37367 Mdot
.23883 .37268 Mdot
.2393 .37168 Mdot
.23976 .37069 Mdot
.24023 .3697 Mdot
.24069 .3687 Mdot
.24116 .36771 Mdot
.24162 .36671 Mdot
.24208 .36572 Mdot
.24255 .36472 Mdot
.24301 .36373 Mdot
.24348 .36273 Mdot
.24394 .36174 Mdot
.24441 .36074 Mdot
.24487 .35974 Mdot
.24534 .35875 Mdot
.2458 .35775 Mdot
.24627 .35676 Mdot
.24673 .35576 Mdot
.24719 .35476 Mdot
.24766 .35377 Mdot
.24812 .35277 Mdot
.24859 .35177 Mdot
.24905 .35078 Mdot
.24952 .34978 Mdot
.24998 .34878 Mdot
.25045 .34779 Mdot
.25091 .34679 Mdot
.25137 .3458 Mdot
.25184 .3448 Mdot
.2523 .3438 Mdot
.25277 .34281 Mdot
.25323 .34181 Mdot
.2537 .34081 Mdot
.25416 .33982 Mdot
.25463 .33882 Mdot
.25509 .33783 Mdot
.25555 .33683 Mdot
.25602 .33584 Mdot
.25648 .33484 Mdot
.25695 .33385 Mdot
.25741 .33285 Mdot
.25787 .33186 Mdot
.25834 .33086 Mdot
.2588 .32987 Mdot
.25927 .32887 Mdot
.25973 .32788 Mdot
.2602 .32688 Mdot
.26066 .32589 Mdot
.26112 .3249 Mdot
.26159 .3239 Mdot
.26205 .32291 Mdot
.26252 .32192 Mdot
.26298 .32093 Mdot
.26344 .31994 Mdot
.26391 .31894 Mdot
.26437 .31795 Mdot
.26484 .31696 Mdot
.2653 .31597 Mdot
.26577 .31498 Mdot
.26623 .31399 Mdot
.26669 .313 Mdot
.26716 .31201 Mdot
.26762 .31102 Mdot
.26809 .31004 Mdot
.26855 .30905 Mdot
.26901 .30806 Mdot
.26948 .30707 Mdot
.26994 .30609 Mdot
.27041 .3051 Mdot
.27087 .30412 Mdot
.27133 .30313 Mdot
.2718 .30215 Mdot
.27226 .30116 Mdot
.27273 .30018 Mdot
.27319 .2992 Mdot
.27365 .29821 Mdot
.27412 .29723 Mdot
.27458 .29625 Mdot
.27504 .29527 Mdot
.27551 .29429 Mdot
.27597 .29331 Mdot
.27644 .29233 Mdot
.2769 .29135 Mdot
.27736 .29037 Mdot
.27783 .28939 Mdot
.27829 .28842 Mdot
.27876 .28744 Mdot
.27922 .28647 Mdot
.27968 .28549 Mdot
.28015 .28452 Mdot
.28061 .28354 Mdot
.28107 .28257 Mdot
.28154 .2816 Mdot
.282 .28063 Mdot
.28247 .27966 Mdot
.28293 .27869 Mdot
.28339 .27772 Mdot
.28386 .27675 Mdot
.28432 .27578 Mdot
.28478 .27481 Mdot
.28525 .27385 Mdot
.28571 .27288 Mdot
.28617 .27191 Mdot
.28664 .27095 Mdot
.2871 .26999 Mdot
.28757 .26902 Mdot
.28803 .26806 Mdot
.28849 .2671 Mdot
.28896 .26614 Mdot
.28942 .26518 Mdot
.28988 .26422 Mdot
.29035 .26327 Mdot
.29081 .26231 Mdot
.29127 .26135 Mdot
.29174 .2604 Mdot
.2922 .25944 Mdot
.29266 .25849 Mdot
.29313 .25754 Mdot
.29359 .25659 Mdot
.29406 .25564 Mdot
.29452 .25469 Mdot
.29498 .25374 Mdot
.29545 .25279 Mdot
.29591 .25184 Mdot
.29637 .2509 Mdot
.29684 .24995 Mdot
.2973 .24901 Mdot
.29776 .24807 Mdot
.29823 .24712 Mdot
.29869 .24618 Mdot
.29915 .24524 Mdot
.29962 .2443 Mdot
.30008 .24337 Mdot
.30054 .24243 Mdot
.30101 .24149 Mdot
.30147 .24056 Mdot
.30193 .23963 Mdot
.3024 .23869 Mdot
.30286 .23776 Mdot
.30332 .23683 Mdot
.30379 .2359 Mdot
.30425 .23497 Mdot
.30471 .23405 Mdot
.30518 .23312 Mdot
.30564 .2322 Mdot
.3061 .23127 Mdot
.30657 .23035 Mdot
.30703 .22943 Mdot
.30749 .22851 Mdot
.30796 .22759 Mdot
.30842 .22667 Mdot
.30888 .22575 Mdot
.30935 .22484 Mdot
.30981 .22392 Mdot
.31027 .22301 Mdot
.31074 .2221 Mdot
.3112 .22119 Mdot
.31166 .22028 Mdot
.31213 .21937 Mdot
.31259 .21846 Mdot
.31305 .21756 Mdot
.31352 .21665 Mdot
.31398 .21575 Mdot
.31444 .21485 Mdot
.3149 .21395 Mdot
.31537 .21305 Mdot
.31583 .21215 Mdot
.31629 .21125 Mdot
.31676 .21035 Mdot
.31722 .20946 Mdot
.31768 .20857 Mdot
.31815 .20768 Mdot
.31861 .20679 Mdot
.31907 .2059 Mdot
.31954 .20501 Mdot
.32 .20412 Mdot
.32046 .20324 Mdot
.32092 .20235 Mdot
.32139 .20147 Mdot
.32185 .20059 Mdot
.32231 .19971 Mdot
.32278 .19883 Mdot
.32324 .19796 Mdot
.3237 .19708 Mdot
.32417 .19621 Mdot
.32463 .19534 Mdot
.32509 .19447 Mdot
.32555 .1936 Mdot
.32602 .19273 Mdot
.32648 .19186 Mdot
.32694 .191 Mdot
.32741 .19013 Mdot
.32787 .18927 Mdot
.32833 .18841 Mdot
.3288 .18755 Mdot
.32926 .18669 Mdot
.32972 .18584 Mdot
.33018 .18498 Mdot
.33065 .18413 Mdot
.33111 .18328 Mdot
.33157 .18243 Mdot
.33204 .18158 Mdot
.3325 .18073 Mdot
.33296 .17989 Mdot
.33342 .17904 Mdot
.33389 .1782 Mdot
.33435 .17736 Mdot
.33481 .17652 Mdot
.33528 .17568 Mdot
.33574 .17485 Mdot
.3362 .17401 Mdot
.33666 .17318 Mdot
.33713 .17235 Mdot
.33759 .17152 Mdot
.33805 .17069 Mdot
.33852 .16987 Mdot
.33898 .16904 Mdot
.33944 .16822 Mdot
.3399 .1674 Mdot
.34037 .16658 Mdot
.34083 .16576 Mdot
.34129 .16494 Mdot
.34175 .16413 Mdot
.34222 .16332 Mdot
.34268 .16251 Mdot
.34314 .1617 Mdot
.34361 .16089 Mdot
.34407 .16008 Mdot
.34453 .15928 Mdot
.34499 .15847 Mdot
.34546 .15767 Mdot
.34592 .15687 Mdot
.34638 .15608 Mdot
.34684 .15528 Mdot
.34731 .15449 Mdot
.34777 .15369 Mdot
.34823 .1529 Mdot
.34869 .15212 Mdot
.34916 .15133 Mdot
.34962 .15054 Mdot
.35008 .14976 Mdot
.35055 .14898 Mdot
.35101 .1482 Mdot
.35147 .14742 Mdot
.35193 .14664 Mdot
.3524 .14587 Mdot
.35286 .1451 Mdot
.35332 .14433 Mdot
.35378 .14356 Mdot
.35425 .14279 Mdot
.35471 .14202 Mdot
.35517 .14126 Mdot
.35563 .1405 Mdot
.3561 .13974 Mdot
.35656 .13898 Mdot
.35702 .13823 Mdot
.35748 .13747 Mdot
.35795 .13672 Mdot
.35841 .13597 Mdot
.35887 .13522 Mdot
.35933 .13448 Mdot
.3598 .13373 Mdot
.36026 .13299 Mdot
.36072 .13225 Mdot
.36118 .13151 Mdot
.36165 .13077 Mdot
.36211 .13004 Mdot
.36257 .1293 Mdot
.36303 .12857 Mdot
.3635 .12784 Mdot
.36396 .12712 Mdot
.36442 .12639 Mdot
.36488 .12567 Mdot
.36535 .12495 Mdot
.36581 .12423 Mdot
.36627 .12351 Mdot
.36673 .12279 Mdot
.3672 .12208 Mdot
.36766 .12137 Mdot
.36812 .12066 Mdot
.36858 .11995 Mdot
.36905 .11925 Mdot
.36951 .11854 Mdot
.36997 .11784 Mdot
.37043 .11714 Mdot
.37089 .11644 Mdot
.37136 .11575 Mdot
.37182 .11506 Mdot
.37228 .11437 Mdot
.37274 .11368 Mdot
.37321 .11299 Mdot
.37367 .1123 Mdot
.37413 .11162 Mdot
.37459 .11094 Mdot
.37506 .11026 Mdot
.37552 .10958 Mdot
.37598 .10891 Mdot
.37644 .10824 Mdot
.37691 .10757 Mdot
.37737 .1069 Mdot
.37783 .10623 Mdot
.37829 .10557 Mdot
.37875 .10491 Mdot
.37922 .10425 Mdot
.37968 .10359 Mdot
.38014 .10293 Mdot
.3806 .10228 Mdot
.38107 .10163 Mdot
.38153 .10098 Mdot
.38199 .10033 Mdot
.38245 .09969 Mdot
.38292 .09904 Mdot
.38338 .0984 Mdot
.38384 .09776 Mdot
.3843 .09713 Mdot
.38476 .09649 Mdot
.38523 .09586 Mdot
.38569 .09523 Mdot
.38615 .0946 Mdot
.38661 .09398 Mdot
.38708 .09335 Mdot
.38754 .09273 Mdot
.388 .09211 Mdot
.38846 .0915 Mdot
.38892 .09088 Mdot
.38939 .09027 Mdot
.38985 .08966 Mdot
.39031 .08905 Mdot
.39077 .08845 Mdot
.39123 .08784 Mdot
.3917 .08724 Mdot
.39216 .08664 Mdot
.39262 .08605 Mdot
.39308 .08545 Mdot
.39355 .08486 Mdot
.39401 .08427 Mdot
.39447 .08368 Mdot
.39493 .0831 Mdot
.39539 .08252 Mdot
.39586 .08193 Mdot
.39632 .08136 Mdot
.39678 .08078 Mdot
.39724 .08021 Mdot
.3977 .07963 Mdot
.39817 .07907 Mdot
.39863 .0785 Mdot
.39909 .07793 Mdot
.39955 .07737 Mdot
.40002 .07681 Mdot
.40048 .07625 Mdot
.40094 .0757 Mdot
.4014 .07514 Mdot
.40186 .07459 Mdot
.40233 .07404 Mdot
.40279 .0735 Mdot
.40325 .07295 Mdot
.40371 .07241 Mdot
.40417 .07187 Mdot
.40464 .07134 Mdot
.4051 .0708 Mdot
.40556 .07027 Mdot
.40602 .06974 Mdot
.40648 .06921 Mdot
.40695 .06869 Mdot
.40741 .06816 Mdot
.40787 .06764 Mdot
.40833 .06713 Mdot
.40879 .06661 Mdot
.40926 .0661 Mdot
.40972 .06559 Mdot
.41018 .06508 Mdot
.41064 .06457 Mdot
.4111 .06407 Mdot
.41157 .06357 Mdot
.41203 .06307 Mdot
.41249 .06257 Mdot
.41295 .06208 Mdot
.41341 .06159 Mdot
.41388 .0611 Mdot
.41434 .06061 Mdot
.4148 .06012 Mdot
.41526 .05964 Mdot
.41572 .05916 Mdot
.41619 .05869 Mdot
.41665 .05821 Mdot
.41711 .05774 Mdot
.41757 .05727 Mdot
.41803 .0568 Mdot
.4185 .05634 Mdot
.41896 .05587 Mdot
.41942 .05541 Mdot
.41988 .05496 Mdot
.42034 .0545 Mdot
.42081 .05405 Mdot
.42127 .0536 Mdot
.42173 .05315 Mdot
.42219 .05271 Mdot
.42265 .05226 Mdot
.42312 .05182 Mdot
.42358 .05138 Mdot
.42404 .05095 Mdot
.4245 .05052 Mdot
.42496 .05009 Mdot
.42543 .04966 Mdot
.42589 .04923 Mdot
.42635 .04881 Mdot
.42681 .04839 Mdot
.42727 .04797 Mdot
.42774 .04756 Mdot
.4282 .04714 Mdot
.42866 .04673 Mdot
.42912 .04632 Mdot
.42958 .04592 Mdot
.43004 .04552 Mdot
.43051 .04512 Mdot
.43097 .04472 Mdot
.43143 .04432 Mdot
.43189 .04393 Mdot
.43235 .04354 Mdot
.43282 .04315 Mdot
.43328 .04277 Mdot
.43374 .04238 Mdot
.4342 .042 Mdot
.43466 .04163 Mdot
.43513 .04125 Mdot
.43559 .04088 Mdot
.43605 .04051 Mdot
.43651 .04014 Mdot
.43697 .03978 Mdot
.43743 .03941 Mdot
.4379 .03905 Mdot
.43836 .0387 Mdot
.43882 .03834 Mdot
.43928 .03799 Mdot
.43974 .03764 Mdot
.44021 .03729 Mdot
.44067 .03695 Mdot
.44113 .03661 Mdot
.44159 .03627 Mdot
.44205 .03593 Mdot
.44251 .0356 Mdot
.44298 .03527 Mdot
.44344 .03494 Mdot
.4439 .03461 Mdot
.44436 .03429 Mdot
.44482 .03397 Mdot
.44529 .03365 Mdot
.44575 .03333 Mdot
.44621 .03302 Mdot
.44667 .03271 Mdot
.44713 .0324 Mdot
.44759 .0321 Mdot
.44806 .03179 Mdot
.44852 .03149 Mdot
.44898 .03119 Mdot
.44944 .0309 Mdot
.4499 .03061 Mdot
.45037 .03032 Mdot
.45083 .03003 Mdot
.45129 .02975 Mdot
.45175 .02946 Mdot
.45221 .02918 Mdot
.45267 .02891 Mdot
.45314 .02863 Mdot
.4536 .02836 Mdot
.45406 .02809 Mdot
.45452 .02783 Mdot
.45498 .02756 Mdot
.45544 .0273 Mdot
.45591 .02704 Mdot
.45637 .02679 Mdot
.45683 .02654 Mdot
.45729 .02628 Mdot
.45775 .02604 Mdot
.45822 .02579 Mdot
.45868 .02555 Mdot
.45914 .02531 Mdot
.4596 .02507 Mdot
.46006 .02484 Mdot
.46052 .02461 Mdot
.46099 .02438 Mdot
.46145 .02415 Mdot
.46191 .02393 Mdot
.46237 .02371 Mdot
.46283 .02349 Mdot
.46329 .02327 Mdot
.46376 .02306 Mdot
.46422 .02285 Mdot
.46468 .02264 Mdot
.46514 .02243 Mdot
.4656 .02223 Mdot
.46606 .02203 Mdot
.46653 .02183 Mdot
.46699 .02164 Mdot
.46745 .02145 Mdot
.46791 .02126 Mdot
.46837 .02107 Mdot
.46884 .02089 Mdot
.4693 .02071 Mdot
.46976 .02053 Mdot
.47022 .02035 Mdot
.47068 .02018 Mdot
.47114 .02001 Mdot
.47161 .01984 Mdot
.47207 .01968 Mdot
.47253 .01951 Mdot
.47299 .01936 Mdot
.47345 .0192 Mdot
.47391 .01904 Mdot
.47438 .01889 Mdot
.47484 .01874 Mdot
.4753 .0186 Mdot
.47576 .01845 Mdot
.47622 .01831 Mdot
.47668 .01817 Mdot
.47715 .01804 Mdot
.47761 .01791 Mdot
.47807 .01778 Mdot
.47853 .01765 Mdot
.47899 .01752 Mdot
.47945 .0174 Mdot
.47992 .01728 Mdot
.48038 .01717 Mdot
.48084 .01705 Mdot
.4813 .01694 Mdot
.48176 .01683 Mdot
.48222 .01673 Mdot
.48269 .01662 Mdot
.48315 .01652 Mdot
.48361 .01643 Mdot
.48407 .01633 Mdot
.48453 .01624 Mdot
.485 .01615 Mdot
.48546 .01606 Mdot
.48592 .01598 Mdot
.48638 .0159 Mdot
.48684 .01582 Mdot
.4873 .01574 Mdot
.48777 .01567 Mdot
.48823 .0156 Mdot
.48869 .01553 Mdot
.48915 .01546 Mdot
.48961 .0154 Mdot
.49007 .01534 Mdot
.49054 .01529 Mdot
.491 .01523 Mdot
.49146 .01518 Mdot
.49192 .01513 Mdot
.49238 .01508 Mdot
.49284 .01504 Mdot
.49331 .015 Mdot
.49377 .01496 Mdot
.49423 .01493 Mdot
.49469 .01489 Mdot
.49515 .01486 Mdot
.49561 .01484 Mdot
.49608 .01481 Mdot
.49654 .01479 Mdot
.497 .01477 Mdot
.49746 .01476 Mdot
.49792 .01474 Mdot
.49838 .01473 Mdot
.49885 .01472 Mdot
.49931 .01472 Mdot
.49977 .01472 Mdot
.50023 .01472 Mdot
.50069 .01472 Mdot
.50115 .01472 Mdot
.50162 .01473 Mdot
.50208 .01474 Mdot
.50254 .01476 Mdot
.503 .01477 Mdot
.50346 .01479 Mdot
.50392 .01481 Mdot
.50439 .01484 Mdot
.50485 .01486 Mdot
.50531 .01489 Mdot
.50577 .01493 Mdot
.50623 .01496 Mdot
.50669 .015 Mdot
.50716 .01504 Mdot
.50762 .01508 Mdot
.50808 .01513 Mdot
.50854 .01518 Mdot
.509 .01523 Mdot
.50946 .01529 Mdot
.50993 .01534 Mdot
.51039 .0154 Mdot
.51085 .01546 Mdot
.51131 .01553 Mdot
.51177 .0156 Mdot
.51223 .01567 Mdot
.5127 .01574 Mdot
.51316 .01582 Mdot
.51362 .0159 Mdot
.51408 .01598 Mdot
.51454 .01606 Mdot
.515 .01615 Mdot
.51547 .01624 Mdot
.51593 .01633 Mdot
.51639 .01643 Mdot
.51685 .01652 Mdot
.51731 .01662 Mdot
.51778 .01673 Mdot
.51824 .01683 Mdot
.5187 .01694 Mdot
.51916 .01705 Mdot
.51962 .01717 Mdot
.52008 .01728 Mdot
.52055 .0174 Mdot
.52101 .01752 Mdot
.52147 .01765 Mdot
.52193 .01778 Mdot
.52239 .01791 Mdot
.52285 .01804 Mdot
.52332 .01817 Mdot
.52378 .01831 Mdot
.52424 .01845 Mdot
.5247 .0186 Mdot
.52516 .01874 Mdot
.52562 .01889 Mdot
.52609 .01904 Mdot
.52655 .0192 Mdot
.52701 .01936 Mdot
.52747 .01951 Mdot
.52793 .01968 Mdot
.52839 .01984 Mdot
.52886 .02001 Mdot
.52932 .02018 Mdot
.52978 .02035 Mdot
.53024 .02053 Mdot
.5307 .02071 Mdot
.53116 .02089 Mdot
.53163 .02107 Mdot
.53209 .02126 Mdot
.53255 .02145 Mdot
.53301 .02164 Mdot
.53347 .02183 Mdot
.53394 .02203 Mdot
.5344 .02223 Mdot
.53486 .02243 Mdot
.53532 .02264 Mdot
.53578 .02285 Mdot
.53624 .02306 Mdot
.53671 .02327 Mdot
.53717 .02349 Mdot
.53763 .02371 Mdot
.53809 .02393 Mdot
.53855 .02415 Mdot
.53901 .02438 Mdot
.53948 .02461 Mdot
.53994 .02484 Mdot
.5404 .02507 Mdot
.54086 .02531 Mdot
.54132 .02555 Mdot
.54178 .02579 Mdot
.54225 .02604 Mdot
.54271 .02628 Mdot
.54317 .02654 Mdot
.54363 .02679 Mdot
.54409 .02704 Mdot
.54456 .0273 Mdot
.54502 .02756 Mdot
.54548 .02783 Mdot
.54594 .02809 Mdot
.5464 .02836 Mdot
.54686 .02863 Mdot
.54733 .02891 Mdot
.54779 .02918 Mdot
.54825 .02946 Mdot
.54871 .02975 Mdot
.54917 .03003 Mdot
.54963 .03032 Mdot
.5501 .03061 Mdot
.55056 .0309 Mdot
.55102 .03119 Mdot
.55148 .03149 Mdot
.55194 .03179 Mdot
.55241 .0321 Mdot
.55287 .0324 Mdot
.55333 .03271 Mdot
.55379 .03302 Mdot
.55425 .03333 Mdot
.55471 .03365 Mdot
.55518 .03397 Mdot
.55564 .03429 Mdot
.5561 .03461 Mdot
.55656 .03494 Mdot
.55702 .03527 Mdot
.55749 .0356 Mdot
.55795 .03593 Mdot
.55841 .03627 Mdot
.55887 .03661 Mdot
.55933 .03695 Mdot
.55979 .03729 Mdot
.56026 .03764 Mdot
.56072 .03799 Mdot
.56118 .03834 Mdot
.56164 .0387 Mdot
.5621 .03905 Mdot
.56257 .03941 Mdot
.56303 .03978 Mdot
.56349 .04014 Mdot
.56395 .04051 Mdot
.56441 .04088 Mdot
.56487 .04125 Mdot
.56534 .04163 Mdot
.5658 .042 Mdot
.56626 .04238 Mdot
.56672 .04277 Mdot
.56718 .04315 Mdot
.56765 .04354 Mdot
.56811 .04393 Mdot
.56857 .04432 Mdot
.56903 .04472 Mdot
.56949 .04512 Mdot
.56996 .04552 Mdot
.57042 .04592 Mdot
.57088 .04632 Mdot
.57134 .04673 Mdot
.5718 .04714 Mdot
.57226 .04756 Mdot
.57273 .04797 Mdot
.57319 .04839 Mdot
.57365 .04881 Mdot
.57411 .04923 Mdot
.57457 .04966 Mdot
.57504 .05009 Mdot
.5755 .05052 Mdot
.57596 .05095 Mdot
.57642 .05138 Mdot
.57688 .05182 Mdot
.57735 .05226 Mdot
.57781 .05271 Mdot
.57827 .05315 Mdot
.57873 .0536 Mdot
.57919 .05405 Mdot
.57966 .0545 Mdot
.58012 .05496 Mdot
.58058 .05541 Mdot
.58104 .05587 Mdot
.5815 .05634 Mdot
.58197 .0568 Mdot
.58243 .05727 Mdot
.58289 .05774 Mdot
.58335 .05821 Mdot
.58381 .05869 Mdot
.58428 .05916 Mdot
.58474 .05964 Mdot
.5852 .06012 Mdot
.58566 .06061 Mdot
.58612 .0611 Mdot
.58659 .06159 Mdot
.58705 .06208 Mdot
.58751 .06257 Mdot
.58797 .06307 Mdot
.58843 .06357 Mdot
.5889 .06407 Mdot
.58936 .06457 Mdot
.58982 .06508 Mdot
.59028 .06559 Mdot
.59074 .0661 Mdot
.59121 .06661 Mdot
.59167 .06713 Mdot
.59213 .06764 Mdot
.59259 .06816 Mdot
.59305 .06869 Mdot
.59352 .06921 Mdot
.59398 .06974 Mdot
.59444 .07027 Mdot
.5949 .0708 Mdot
.59536 .07134 Mdot
.59583 .07187 Mdot
.59629 .07241 Mdot
.59675 .07295 Mdot
.59721 .0735 Mdot
.59767 .07404 Mdot
.59814 .07459 Mdot
.5986 .07514 Mdot
.59906 .0757 Mdot
.59952 .07625 Mdot
.59998 .07681 Mdot
.60045 .07737 Mdot
.60091 .07793 Mdot
.60137 .0785 Mdot
.60183 .07907 Mdot
.6023 .07963 Mdot
.60276 .08021 Mdot
.60322 .08078 Mdot
.60368 .08136 Mdot
.60414 .08193 Mdot
.60461 .08252 Mdot
.60507 .0831 Mdot
.60553 .08368 Mdot
.60599 .08427 Mdot
.60645 .08486 Mdot
.60692 .08545 Mdot
.60738 .08605 Mdot
.60784 .08664 Mdot
.6083 .08724 Mdot
.60877 .08784 Mdot
.60923 .08845 Mdot
.60969 .08905 Mdot
.61015 .08966 Mdot
.61061 .09027 Mdot
.61108 .09088 Mdot
.61154 .0915 Mdot
.612 .09211 Mdot
.61246 .09273 Mdot
.61292 .09335 Mdot
.61339 .09398 Mdot
.61385 .0946 Mdot
.61431 .09523 Mdot
.61477 .09586 Mdot
.61524 .09649 Mdot
.6157 .09713 Mdot
.61616 .09776 Mdot
.61662 .0984 Mdot
.61708 .09904 Mdot
.61755 .09969 Mdot
.61801 .10033 Mdot
.61847 .10098 Mdot
.61893 .10163 Mdot
.6194 .10228 Mdot
.61986 .10293 Mdot
.62032 .10359 Mdot
.62078 .10425 Mdot
.62125 .10491 Mdot
.62171 .10557 Mdot
.62217 .10623 Mdot
.62263 .1069 Mdot
.62309 .10757 Mdot
.62356 .10824 Mdot
.62402 .10891 Mdot
.62448 .10958 Mdot
.62494 .11026 Mdot
.62541 .11094 Mdot
.62587 .11162 Mdot
.62633 .1123 Mdot
.62679 .11299 Mdot
.62726 .11368 Mdot
.62772 .11437 Mdot
.62818 .11506 Mdot
.62864 .11575 Mdot
.62911 .11644 Mdot
.62957 .11714 Mdot
.63003 .11784 Mdot
.63049 .11854 Mdot
.63095 .11925 Mdot
.63142 .11995 Mdot
.63188 .12066 Mdot
.63234 .12137 Mdot
.6328 .12208 Mdot
.63327 .12279 Mdot
.63373 .12351 Mdot
.63419 .12423 Mdot
.63465 .12495 Mdot
.63512 .12567 Mdot
.63558 .12639 Mdot
.63604 .12712 Mdot
.6365 .12784 Mdot
.63697 .12857 Mdot
.63743 .1293 Mdot
.63789 .13004 Mdot
.63835 .13077 Mdot
.63882 .13151 Mdot
.63928 .13225 Mdot
.63974 .13299 Mdot
.6402 .13373 Mdot
.64067 .13448 Mdot
.64113 .13522 Mdot
.64159 .13597 Mdot
.64205 .13672 Mdot
.64252 .13747 Mdot
.64298 .13823 Mdot
.64344 .13898 Mdot
.6439 .13974 Mdot
.64437 .1405 Mdot
.64483 .14126 Mdot
.64529 .14202 Mdot
.64575 .14279 Mdot
.64622 .14356 Mdot
.64668 .14433 Mdot
.64714 .1451 Mdot
.6476 .14587 Mdot
.64807 .14664 Mdot
.64853 .14742 Mdot
.64899 .1482 Mdot
.64945 .14898 Mdot
.64992 .14976 Mdot
.65038 .15054 Mdot
.65084 .15133 Mdot
.65131 .15212 Mdot
.65177 .1529 Mdot
.65223 .15369 Mdot
.65269 .15449 Mdot
.65316 .15528 Mdot
.65362 .15608 Mdot
.65408 .15687 Mdot
.65454 .15767 Mdot
.65501 .15847 Mdot
.65547 .15928 Mdot
.65593 .16008 Mdot
.65639 .16089 Mdot
.65686 .1617 Mdot
.65732 .16251 Mdot
.65778 .16332 Mdot
.65825 .16413 Mdot
.65871 .16494 Mdot
.65917 .16576 Mdot
.65963 .16658 Mdot
.6601 .1674 Mdot
.66056 .16822 Mdot
.66102 .16904 Mdot
.66148 .16987 Mdot
.66195 .17069 Mdot
.66241 .17152 Mdot
.66287 .17235 Mdot
.66334 .17318 Mdot
.6638 .17401 Mdot
.66426 .17485 Mdot
.66472 .17568 Mdot
.66519 .17652 Mdot
.66565 .17736 Mdot
.66611 .1782 Mdot
.66658 .17904 Mdot
.66704 .17989 Mdot
.6675 .18073 Mdot
.66796 .18158 Mdot
.66843 .18243 Mdot
.66889 .18328 Mdot
.66935 .18413 Mdot
.66982 .18498 Mdot
.67028 .18584 Mdot
.67074 .18669 Mdot
.6712 .18755 Mdot
.67167 .18841 Mdot
.67213 .18927 Mdot
.67259 .19013 Mdot
.67306 .191 Mdot
.67352 .19186 Mdot
.67398 .19273 Mdot
.67445 .1936 Mdot
.67491 .19447 Mdot
.67537 .19534 Mdot
.67583 .19621 Mdot
.6763 .19708 Mdot
.67676 .19796 Mdot
.67722 .19883 Mdot
.67769 .19971 Mdot
.67815 .20059 Mdot
.67861 .20147 Mdot
.67908 .20235 Mdot
.67954 .20324 Mdot
.68 .20412 Mdot
.68046 .20501 Mdot
.68093 .2059 Mdot
.68139 .20679 Mdot
.68185 .20768 Mdot
.68232 .20857 Mdot
.68278 .20946 Mdot
.68324 .21035 Mdot
.68371 .21125 Mdot
.68417 .21215 Mdot
.68463 .21305 Mdot
.6851 .21395 Mdot
.68556 .21485 Mdot
.68602 .21575 Mdot
.68648 .21665 Mdot
.68695 .21756 Mdot
.68741 .21846 Mdot
.68787 .21937 Mdot
.68834 .22028 Mdot
.6888 .22119 Mdot
.68926 .2221 Mdot
.68973 .22301 Mdot
.69019 .22392 Mdot
.69065 .22484 Mdot
.69112 .22575 Mdot
.69158 .22667 Mdot
.69204 .22759 Mdot
.69251 .22851 Mdot
.69297 .22943 Mdot
.69343 .23035 Mdot
.6939 .23127 Mdot
.69436 .2322 Mdot
.69482 .23312 Mdot
.69529 .23405 Mdot
.69575 .23497 Mdot
.69621 .2359 Mdot
.69668 .23683 Mdot
.69714 .23776 Mdot
.6976 .23869 Mdot
.69807 .23963 Mdot
.69853 .24056 Mdot
.69899 .24149 Mdot
.69946 .24243 Mdot
.69992 .24337 Mdot
.70038 .2443 Mdot
.70085 .24524 Mdot
.70131 .24618 Mdot
.70177 .24712 Mdot
.70224 .24807 Mdot
.7027 .24901 Mdot
.70316 .24995 Mdot
.70363 .2509 Mdot
.70409 .25184 Mdot
.70455 .25279 Mdot
.70502 .25374 Mdot
.70548 .25469 Mdot
.70594 .25564 Mdot
.70641 .25659 Mdot
.70687 .25754 Mdot
.70734 .25849 Mdot
.7078 .25944 Mdot
.70826 .2604 Mdot
.70873 .26135 Mdot
.70919 .26231 Mdot
.70965 .26327 Mdot
.71012 .26422 Mdot
.71058 .26518 Mdot
.71104 .26614 Mdot
.71151 .2671 Mdot
.71197 .26806 Mdot
.71243 .26902 Mdot
.7129 .26999 Mdot
.71336 .27095 Mdot
.71383 .27191 Mdot
.71429 .27288 Mdot
.71475 .27385 Mdot
.71522 .27481 Mdot
.71568 .27578 Mdot
.71614 .27675 Mdot
.71661 .27772 Mdot
.71707 .27869 Mdot
.71753 .27966 Mdot
.718 .28063 Mdot
.71846 .2816 Mdot
.71893 .28257 Mdot
.71939 .28354 Mdot
.71985 .28452 Mdot
.72032 .28549 Mdot
.72078 .28647 Mdot
.72124 .28744 Mdot
.72171 .28842 Mdot
.72217 .28939 Mdot
.72264 .29037 Mdot
.7231 .29135 Mdot
.72356 .29233 Mdot
.72403 .29331 Mdot
.72449 .29429 Mdot
.72496 .29527 Mdot
.72542 .29625 Mdot
.72588 .29723 Mdot
.72635 .29821 Mdot
.72681 .2992 Mdot
.72727 .30018 Mdot
.72774 .30116 Mdot
.7282 .30215 Mdot
.72867 .30313 Mdot
.72913 .30412 Mdot
.72959 .3051 Mdot
.73006 .30609 Mdot
.73052 .30707 Mdot
.73099 .30806 Mdot
.73145 .30905 Mdot
.73191 .31004 Mdot
.73238 .31102 Mdot
.73284 .31201 Mdot
.73331 .313 Mdot
.73377 .31399 Mdot
.73423 .31498 Mdot
.7347 .31597 Mdot
.73516 .31696 Mdot
.73563 .31795 Mdot
.73609 .31894 Mdot
.73656 .31994 Mdot
.73702 .32093 Mdot
.73748 .32192 Mdot
.73795 .32291 Mdot
.73841 .3239 Mdot
.73888 .3249 Mdot
.73934 .32589 Mdot
.7398 .32688 Mdot
.74027 .32788 Mdot
.74073 .32887 Mdot
.7412 .32987 Mdot
.74166 .33086 Mdot
.74213 .33186 Mdot
.74259 .33285 Mdot
.74305 .33385 Mdot
.74352 .33484 Mdot
.74398 .33584 Mdot
.74445 .33683 Mdot
.74491 .33783 Mdot
.74537 .33882 Mdot
.74584 .33982 Mdot
.7463 .34081 Mdot
.74677 .34181 Mdot
.74723 .34281 Mdot
.7477 .3438 Mdot
.74816 .3448 Mdot
.74863 .3458 Mdot
.74909 .34679 Mdot
.74955 .34779 Mdot
.75002 .34878 Mdot
.75048 .34978 Mdot
.75095 .35078 Mdot
.75141 .35177 Mdot
.75188 .35277 Mdot
.75234 .35377 Mdot
.75281 .35476 Mdot
.75327 .35576 Mdot
.75373 .35676 Mdot
.7542 .35775 Mdot
.75466 .35875 Mdot
.75513 .35974 Mdot
.75559 .36074 Mdot
.75606 .36174 Mdot
.75652 .36273 Mdot
.75699 .36373 Mdot
.75745 .36472 Mdot
.75792 .36572 Mdot
.75838 .36671 Mdot
.75884 .36771 Mdot
.75931 .3687 Mdot
.75977 .3697 Mdot
.76024 .37069 Mdot
.7607 .37168 Mdot
.76117 .37268 Mdot
.76163 .37367 Mdot
.7621 .37466 Mdot
.76256 .37566 Mdot
.76303 .37665 Mdot
.76349 .37764 Mdot
.76396 .37863 Mdot
.76442 .37963 Mdot
.76489 .38062 Mdot
.76535 .38161 Mdot
.76582 .3826 Mdot
.76628 .38359 Mdot
.76674 .38458 Mdot
.76721 .38557 Mdot
.76767 .38656 Mdot
.76814 .38755 Mdot
.7686 .38853 Mdot
.76907 .38952 Mdot
.76953 .39051 Mdot
.77 .3915 Mdot
.77046 .39248 Mdot
.77093 .39347 Mdot
.77139 .39445 Mdot
.77186 .39544 Mdot
.77232 .39642 Mdot
.77279 .39741 Mdot
.77325 .39839 Mdot
.77372 .39937 Mdot
.77418 .40036 Mdot
.77465 .40134 Mdot
.77511 .40232 Mdot
.77558 .4033 Mdot
.77604 .40428 Mdot
.77651 .40526 Mdot
.77697 .40624 Mdot
.77744 .40721 Mdot
.7779 .40819 Mdot
.77837 .40917 Mdot
.77883 .41014 Mdot
.7793 .41112 Mdot
.77976 .41209 Mdot
.78023 .41307 Mdot
.78069 .41404 Mdot
.78116 .41501 Mdot
.78163 .41598 Mdot
.78209 .41695 Mdot
.78256 .41792 Mdot
.78302 .41889 Mdot
.78349 .41986 Mdot
.78395 .42083 Mdot
.78442 .42179 Mdot
.78488 .42276 Mdot
.78535 .42372 Mdot
.78581 .42469 Mdot
.78628 .42565 Mdot
.78674 .42661 Mdot
.78721 .42757 Mdot
.78767 .42853 Mdot
.78814 .42949 Mdot
.7886 .43045 Mdot
.78907 .43141 Mdot
.78954 .43236 Mdot
.79 .43332 Mdot
.79047 .43427 Mdot
.79093 .43522 Mdot
.7914 .43618 Mdot
.79186 .43713 Mdot
.79233 .43808 Mdot
.79279 .43903 Mdot
.79326 .43997 Mdot
.79373 .44092 Mdot
.79419 .44187 Mdot
.79466 .44281 Mdot
.79512 .44375 Mdot
.79559 .44469 Mdot
.79605 .44564 Mdot
.79652 .44657 Mdot
.79698 .44751 Mdot
.79745 .44845 Mdot
.79792 .44939 Mdot
.79838 .45032 Mdot
.79885 .45125 Mdot
.79931 .45219 Mdot
.79978 .45312 Mdot
.80024 .45405 Mdot
.80071 .45498 Mdot
.80118 .4559 Mdot
.80164 .45683 Mdot
.80211 .45775 Mdot
.80257 .45867 Mdot
.80304 .4596 Mdot
.8035 .46052 Mdot
.80397 .46143 Mdot
.80444 .46235 Mdot
.8049 .46327 Mdot
.80537 .46418 Mdot
.80583 .46509 Mdot
.8063 .46601 Mdot
.80677 .46692 Mdot
.80723 .46782 Mdot
.8077 .46873 Mdot
.80816 .46964 Mdot
.80863 .47054 Mdot
.8091 .47144 Mdot
.80956 .47234 Mdot
.81003 .47324 Mdot
.81049 .47414 Mdot
.81096 .47503 Mdot
.81143 .47593 Mdot
.81189 .47682 Mdot
.81236 .47771 Mdot
.81282 .4786 Mdot
.81329 .47949 Mdot
.81376 .48037 Mdot
.81422 .48125 Mdot
.81469 .48214 Mdot
.81516 .48302 Mdot
.81562 .4839 Mdot
.81609 .48477 Mdot
.81655 .48565 Mdot
.81702 .48652 Mdot
.81749 .48739 Mdot
.81795 .48826 Mdot
.81842 .48913 Mdot
.81889 .48999 Mdot
.81935 .49086 Mdot
.81982 .49172 Mdot
.82028 .49258 Mdot
.82075 .49344 Mdot
.82122 .49429 Mdot
.82168 .49514 Mdot
.82215 .496 Mdot
.82262 .49685 Mdot
.82308 .49769 Mdot
.82355 .49854 Mdot
.82402 .49938 Mdot
.82448 .50023 Mdot
.82495 .50106 Mdot
.82542 .5019 Mdot
.82588 .50274 Mdot
.82635 .50357 Mdot
.82682 .5044 Mdot
.82728 .50523 Mdot
.82775 .50606 Mdot
.82822 .50688 Mdot
.82868 .5077 Mdot
.82915 .50852 Mdot
.82962 .50934 Mdot
.83008 .51016 Mdot
.83055 .51097 Mdot
.83102 .51178 Mdot
.83148 .51259 Mdot
.83195 .5134 Mdot
.83242 .5142 Mdot
.83288 .515 Mdot
.83335 .5158 Mdot
.83382 .5166 Mdot
.83428 .51739 Mdot
.83475 .51818 Mdot
.83522 .51897 Mdot
.83568 .51976 Mdot
.83615 .52054 Mdot
.83662 .52133 Mdot
.83708 .52211 Mdot
.83755 .52288 Mdot
.83802 .52366 Mdot
.83849 .52443 Mdot
.83895 .5252 Mdot
.83942 .52597 Mdot
.83989 .52673 Mdot
.84035 .52749 Mdot
.84082 .52825 Mdot
.84129 .52901 Mdot
.84175 .52976 Mdot
.84222 .53051 Mdot
.84269 .53126 Mdot
.84316 .532 Mdot
.84362 .53275 Mdot
.84409 .53349 Mdot
.84456 .53422 Mdot
.84502 .53496 Mdot
.84549 .53569 Mdot
.84596 .53642 Mdot
.84643 .53714 Mdot
.84689 .53787 Mdot
.84736 .53859 Mdot
.84783 .5393 Mdot
.8483 .54002 Mdot
.84876 .54073 Mdot
.84923 .54144 Mdot
.8497 .54214 Mdot
.85017 .54284 Mdot
.85063 .54354 Mdot
.8511 .54424 Mdot
.85157 .54493 Mdot
.85204 .54562 Mdot
.8525 .54631 Mdot
.85297 .54699 Mdot
.85344 .54768 Mdot
.85391 .54835 Mdot
.85437 .54903 Mdot
.85484 .5497 Mdot
.85531 .55037 Mdot
.85578 .55103 Mdot
.85624 .55169 Mdot
.85671 .55235 Mdot
.85718 .55301 Mdot
.85765 .55366 Mdot
.85811 .55431 Mdot
.85858 .55495 Mdot
.85905 .5556 Mdot
.85952 .55624 Mdot
.85999 .55687 Mdot
.86045 .5575 Mdot
.86092 .55813 Mdot
.86139 .55876 Mdot
.86186 .55938 Mdot
.86232 .56 Mdot
.86279 .56061 Mdot
.86326 .56122 Mdot
.86373 .56183 Mdot
.8642 .56243 Mdot
.86466 .56303 Mdot
.86513 .56363 Mdot
.8656 .56423 Mdot
.86607 .56482 Mdot
.86654 .5654 Mdot
.867 .56598 Mdot
.86747 .56656 Mdot
.86794 .56714 Mdot
.86841 .56771 Mdot
.86888 .56828 Mdot
.86934 .56884 Mdot
.86981 .5694 Mdot
.87028 .56996 Mdot
.87075 .57051 Mdot
.87122 .57106 Mdot
.87169 .5716 Mdot
.87215 .57215 Mdot
.87262 .57268 Mdot
.87309 .57322 Mdot
.87356 .57374 Mdot
.87403 .57427 Mdot
.8745 .57479 Mdot
.87496 .57531 Mdot
.87543 .57582 Mdot
.8759 .57633 Mdot
.87637 .57684 Mdot
.87684 .57734 Mdot
.87731 .57784 Mdot
.87777 .57833 Mdot
.87824 .57882 Mdot
.87871 .5793 Mdot
.87918 .57978 Mdot
.87965 .58026 Mdot
.88012 .58073 Mdot
.88059 .5812 Mdot
.88105 .58166 Mdot
.88152 .58212 Mdot
.88199 .58258 Mdot
.88246 .58303 Mdot
.88293 .58348 Mdot
.8834 .58392 Mdot
.88387 .58436 Mdot
.88434 .58479 Mdot
.8848 .58522 Mdot
.88527 .58564 Mdot
.88574 .58606 Mdot
.88621 .58648 Mdot
.88668 .58689 Mdot
.88715 .5873 Mdot
.88762 .5877 Mdot
.88809 .5881 Mdot
.88856 .58849 Mdot
.88902 .58888 Mdot
.88949 .58926 Mdot
.88996 .58964 Mdot
.89043 .59002 Mdot
.8909 .59039 Mdot
.89137 .59075 Mdot
.89184 .59111 Mdot
.89231 .59147 Mdot
.89278 .59182 Mdot
.89325 .59216 Mdot
.89372 .59251 Mdot
.89418 .59284 Mdot
.89465 .59317 Mdot
.89512 .5935 Mdot
.89559 .59382 Mdot
.89606 .59414 Mdot
.89653 .59445 Mdot
.897 .59476 Mdot
.89747 .59506 Mdot
.89794 .59536 Mdot
.89841 .59565 Mdot
.89888 .59593 Mdot
.89935 .59622 Mdot
.89982 .59649 Mdot
.90029 .59676 Mdot
.90076 .59703 Mdot
.90123 .59729 Mdot
.9017 .59755 Mdot
.90216 .5978 Mdot
.90263 .59804 Mdot
.9031 .59828 Mdot
.90357 .59852 Mdot
.90404 .59875 Mdot
.90451 .59897 Mdot
.90498 .59919 Mdot
.90545 .59941 Mdot
.90592 .59961 Mdot
.90639 .59982 Mdot
.90686 .60001 Mdot
.90733 .60021 Mdot
.9078 .60039 Mdot
.90827 .60057 Mdot
.90874 .60075 Mdot
.90921 .60092 Mdot
.90968 .60108 Mdot
.91015 .60124 Mdot
.91062 .60139 Mdot
.91109 .60154 Mdot
.91156 .60168 Mdot
.91203 .60182 Mdot
.9125 .60195 Mdot
.91297 .60207 Mdot
.91344 .60219 Mdot
.91391 .60231 Mdot
.91438 .60241 Mdot
.91485 .60251 Mdot
.91532 .60261 Mdot
.91579 .6027 Mdot
.91626 .60278 Mdot
.91673 .60286 Mdot
.9172 .60293 Mdot
.91767 .603 Mdot
.91814 .60306 Mdot
.91861 .60311 Mdot
.91908 .60316 Mdot
.91956 .6032 Mdot
.92003 .60323 Mdot
.9205 .60326 Mdot
.92097 .60329 Mdot
.92144 .6033 Mdot
.92191 .60331 Mdot
.92238 .60332 Mdot
.92285 .60332 Mdot
.92332 .60331 Mdot
.92379 .60329 Mdot
.92426 .60327 Mdot
.92473 .60325 Mdot
.9252 .60321 Mdot
.92567 .60317 Mdot
.92614 .60313 Mdot
.92661 .60307 Mdot
.92709 .60301 Mdot
.92756 .60295 Mdot
.92803 .60288 Mdot
.9285 .6028 Mdot
.92897 .60271 Mdot
.92944 .60262 Mdot
.92991 .60252 Mdot
.93038 .60242 Mdot
.93085 .6023 Mdot
.93132 .60219 Mdot
.93179 .60206 Mdot
.93227 .60193 Mdot
.93274 .60179 Mdot
.93321 .60164 Mdot
.93368 .60149 Mdot
.93415 .60133 Mdot
.93462 .60116 Mdot
.93509 .60099 Mdot
.93556 .60081 Mdot
.93603 .60062 Mdot
.93651 .60043 Mdot
.93698 .60023 Mdot
.93745 .60002 Mdot
.93792 .5998 Mdot
.93839 .59958 Mdot
.93886 .59935 Mdot
.93933 .59911 Mdot
.93981 .59887 Mdot
.94028 .59862 Mdot
.94075 .59836 Mdot
.94122 .59809 Mdot
.94169 .59782 Mdot
.94216 .59754 Mdot
.94264 .59725 Mdot
.94311 .59696 Mdot
.94358 .59665 Mdot
.94405 .59634 Mdot
.94452 .59602 Mdot
.94499 .5957 Mdot
.94547 .59537 Mdot
.94594 .59503 Mdot
.94641 .59468 Mdot
.94688 .59432 Mdot
.94735 .59396 Mdot
.94782 .59359 Mdot
.9483 .59321 Mdot
.94877 .59283 Mdot
.94924 .59243 Mdot
.94971 .59203 Mdot
.95018 .59162 Mdot
.95066 .5912 Mdot
.95113 .59078 Mdot
.9516 .59035 Mdot
.95207 .58991 Mdot
.95255 .58946 Mdot
.95302 .589 Mdot
.95349 .58854 Mdot
.95396 .58806 Mdot
.95443 .58758 Mdot
.95491 .58709 Mdot
.95538 .5866 Mdot
.95585 .58609 Mdot
.95632 .58558 Mdot
.9568 .58506 Mdot
.95727 .58453 Mdot
.95774 .58399 Mdot
.95821 .58344 Mdot
.95869 .58289 Mdot
.95916 .58232 Mdot
.95963 .58175 Mdot
.9601 .58117 Mdot
.96058 .58058 Mdot
.96105 .57999 Mdot
.96152 .57938 Mdot
.962 .57877 Mdot
.96247 .57815 Mdot
.96294 .57752 Mdot
.96341 .57688 Mdot
.96389 .57623 Mdot
.96436 .57557 Mdot
.96483 .57491 Mdot
.96531 .57423 Mdot
.96578 .57355 Mdot
.96625 .57286 Mdot
.96672 .57216 Mdot
.9672 .57145 Mdot
.96767 .57073 Mdot
.96814 .57 Mdot
.96862 .56926 Mdot
.96909 .56852 Mdot
.96956 .56776 Mdot
.97004 .567 Mdot
.97051 .56623 Mdot
.97098 .56545 Mdot
.97146 .56466 Mdot
.97193 .56386 Mdot
.9724 .56305 Mdot
.97288 .56223 Mdot
.97335 .5614 Mdot
.97382 .56057 Mdot
.9743 .55972 Mdot
.97477 .55886 Mdot
.97524 .558 Mdot
.97572 .55712 Mdot
.97619 .55624 Mdot
.5 Mabswid
.02381 .55624 m
.03097 .56862 L
.03853 .57945 L
.04619 .58821 L
.05058 .59228 L
.05458 .5954 L
.05815 .59773 L
.06204 .59978 L
.06417 .6007 L
.06614 .60143 L
.068 .602 L
.07001 .6025 L
.07193 .60287 L
.07369 .60311 L
.07454 .60319 L
.07499 .60323 L
.07546 .60326 L
.07592 .60328 L
.07634 .6033 L
.07675 .60331 L
.07714 .60332 L
.0776 .60332 L
.0781 .60331 L
.07835 .60331 L
.07862 .6033 L
.07911 .60328 L
.0796 .60326 L
.08006 .60323 L
.08092 .60316 L
.08193 .60305 L
.08287 .60292 L
.085 .60254 L
.08677 .60214 L
.08867 .60161 L
.09211 .60043 L
.09996 .59662 L
.10759 .59154 L
.11563 .58482 L
.13015 .56945 L
.1456 .54906 L
.16048 .52614 L
.17629 .49884 L
.19152 .47025 L
.20617 .44113 L
.22176 .4089 L
.23677 .37709 L
.2512 .34617 L
.26657 .31327 L
.28136 .28197 L
.29708 .24945 L
Mistroke
.31223 .21916 L
.3268 .19126 L
.3423 .16316 L
.35723 .13788 L
.37309 .11316 L
.38838 .09161 L
.40308 .07315 L
.41872 .05611 L
.43378 .04235 L
.44827 .03165 L
.45634 .0268 L
.46369 .02309 L
.4714 .01992 L
.47853 .01765 L
.482 .01678 L
.48582 .016 L
.48966 .0154 L
.49176 .01515 L
.49373 .01497 L
.49552 .01484 L
.49654 .01479 L
.49749 .01476 L
.498 .01474 L
.49849 .01473 L
.49892 .01472 L
.4994 .01472 L
.49964 .01472 L
.49991 .01472 L
.50019 .01472 L
.50046 .01472 L
.50093 .01472 L
.50119 .01472 L
.50143 .01473 L
.50187 .01474 L
.50233 .01475 L
.50317 .01478 L
.50406 .01482 L
.50505 .01488 L
.50682 .01501 L
.50849 .01517 L
.51223 .01567 L
.51617 .01638 L
.52321 .01814 L
.53073 .02072 L
.53772 .02375 L
.55258 .03221 L
.56838 .04416 L
.5836 .05846 L
.59824 .07471 L
.61381 .09456 L
Mistroke
.62881 .116 L
.64323 .13864 L
.65859 .16473 L
.67337 .19158 L
.68908 .22173 L
.70421 .25209 L
.71877 .28224 L
.73426 .31504 L
.74918 .34698 L
.76502 .38091 L
.7803 .4132 L
.79499 .44348 L
.81062 .47437 L
.82567 .50235 L
.84014 .52714 L
.85555 .55071 L
.87038 .57007 L
.87793 .57849 L
.88614 .58642 L
.89336 .59225 L
.90133 .59735 L
.90496 .59918 L
.90887 .60079 L
.91102 .60152 L
.913 .60208 L
.91487 .60252 L
.91687 .60288 L
.91788 .60302 L
.91883 .60313 L
.91969 .60321 L
.92013 .60324 L
.92061 .60327 L
.92106 .60329 L
.92149 .6033 L
.92194 .60331 L
.92242 .60332 L
.92287 .60332 L
.92329 .60331 L
.92367 .6033 L
.92409 .60328 L
.92462 .60325 L
.92513 .60322 L
.92607 .60313 L
.92709 .60301 L
.92818 .60285 L
.93016 .60247 L
.93197 .60201 L
.9357 .60076 L
.93917 .5992 L
.94322 .59689 L
Mistroke
.94705 .5942 L
.95482 .58718 L
.96189 .5789 L
.97619 .55624 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[75]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;?ooool5o`0000?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0_l0000^oooo
o`?o00001?ooool2o`0002[ooooo1Ol00003ooooo`;o00007_ooool002gooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001gooooo000Vooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001gooooo000_ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000^ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool06oooool002cooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Y
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Moooo
o`00;?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000:_ooool2
o`0000Cooooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool0000]ooooo`;o0000
1?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Mooooo`00;Oooool3o`0000Cooooo0_l0000/ooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000;oooool00ol0003oooooooooo`03ooooo`;o0000:oooool3o`00
00Cooooo0_l0000Nooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`006ooooooho`0000gooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`00
4oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004ooooo`;o
0000M?ooool;o`0007Gooooo0_l0000=ooooo`004oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo073ooooo4Ol0001cooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0K_ooool7o`0000?ooooo00Co0000oooooooo
oooooooo2?l0001`ooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0K?ooool6o`0000Kooooo00?o0000ooooooooool01?ooool6o`00
06oooooo00?o0000ooooooooool02oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo06_o
oooo1Ol00008ooooo`03o`000?oooooooooo00Oooooo1Ol0001]ooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo06Wooooo1Ol0000:ooooo`03o`000?oooooooooo00Wooooo
1?l0001/ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo06Sooooo1?l0
000<ooooo`03o`000?oooooooooo00[ooooo1Ol0001Zooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo06Oooooo1?l0000=ooooo`03o`000?oooooooooo00cooooo1?l0001Y
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o0000Ioooool4o`0000kooooo00?o0000oooo
ooooool03Oooool4o`0006Oooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1Tooooo`Go
00003oooool00ol0003oooooooooo`0>ooooo`Co0000Ioooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`1Sooooo`Co00004Oooool00ol0003oooooooooo`0?ooooo`Co0000
I_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Sooooo`?o00004_oo
ool00ol0003oooooooooo`0@ooooo`Co0000IOooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`1Rooooo`?o00004oooool00ol0003oooooooooo`0Aooooo`Co0000I?ooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Qooooo`?o00005?ooool00ol0
003oooooooooo`0Booooo`Co0000Hoooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003o
ooooooooo`1Pooooo`?o00005Oooool00ol0003oooooooooo`0Cooooo`Co0000H_ooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Oooooo`Co00005Oooool00ol0003ooooo
ooooo`0Dooooo`Co0000HOooool00ol0003oooooooooo`0;ooooo`006oooool2o`0005oooooo1?l0
000Fooooo`03o`000?oooooooooo01Gooooo0ol0001Pooooo`;o00003Oooool001_ooooo00?o0000
ooooooooool0GOooool4o`0001Oooooo00?o0000ooooooooool05_ooool3o`00063ooooo00?o0000
ooooooooool02oooool001_ooooo00?o0000ooooooooool0GOooool3o`0001Sooooo00?o0000oooo
ooooool05oooool3o`0005oooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool0G?ooool3o`0001Wooooo00?o0000ooooooooool05oooool4o`0005kooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0Foooool3o`0001[ooooo00?o0000ooooooooool0
6?ooool3o`0005kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0F_oo
ool4o`0001[ooooo00?o0000ooooooooool06Oooool3o`0005gooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0F_ooool3o`0001_ooooo00?o0000ooooooooool06_ooool3
o`0005cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0FOooool3o`00
01cooooo00?o0000ooooooooool06_ooool4o`0005_ooooo00?o0000ooooooooool02oooool001_o
oooo0_l0001Iooooo`Co00007?ooool00ol0003oooooooooo`0Kooooo`?o0000F_ooool2o`0000go
oooo000Kooooo`03o`000?oooooooooo05Sooooo0ol0000Mooooo`03o`000?oooooooooo01cooooo
0ol0001Jooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05Oooooo0ol0
000Nooooo`03o`000?oooooooooo01cooooo1?l0001Iooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo05Kooooo1?l0000Nooooo`03o`000?oooooooooo01gooooo0ol0001I
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05Kooooo0ol0000Ooooo
o`03o`000?oooooooooo01kooooo0ol0001Hooooo`03o`000?oooooooooo00_ooooo000<ooooo`Go
00000oooool2o`0000Gooooo00?o0000ooooooooool0EOooool3o`00023ooooo00?o0000oooooooo
ool07_ooool3o`0005Sooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05Gooooo0ol0000Poooo
o`03o`000?oooooooooo01oooooo0ol0001Gooooo`03o`000?oooooooooo00_ooooo000>ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Doooo
o`?o00008Oooool00ol0003oooooooooo`0Pooooo`?o0000E_ooool00ol0003oooooooooo`0;oooo
o`003oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool2o`00
05Cooooo0ol0000Rooooo`03o`000?oooooooooo023ooooo0ol0001Eooooo`;o00003Oooool000co
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0Doooool3o`0002;ooooo00?o0000ooooooooool08Oooool3o`0005Gooooo00?o0000
ooooooooool02oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0D_ooool3o`0002?ooooo00?o0000ooooooooool08Ooo
ool3o`0005Gooooo00?o0000ooooooooool02oooool000gooooo0ol00004ooooo`;o00001Oooool0
0ol0003oooooooooo`1Booooo`?o00008oooool00ol0003oooooooooo`0Rooooo`?o0000E?ooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Aooooo`?o00009?ooool00ol0
003oooooooooo`0Sooooo`?o0000Doooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003o
ooooooooo`1@ooooo`?o00009Oooool00ol0003oooooooooo`0Sooooo`?o0000Doooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1@ooooo`?o00009Oooool00ol0003ooooo
ooooo`0Tooooo`?o0000D_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`1?ooooo`?o00009_ooool00ol0003oooooooooo`0Tooooo`?o0000D_ooool00ol0003ooooooooo
o`0;ooooo`006oooool2o`00053ooooo0ol0000Vooooo`03o`000?oooooooooo02Gooooo0ol0001@
ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0C_ooool3o`0002Oooooo00?o0000oooo
ooooool09Oooool3o`00057ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool0C_ooool3o`0002Oooooo00?o0000ooooooooool09_ooool3o`00053ooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0COooool3o`0002Sooooo00?o0000ooooooooool0
9oooool2o`00053ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0COoo
ool2o`0002Wooooo00?o0000ooooooooool09oooool3o`0004oooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0C?ooool3o`0002Wooooo00?o0000ooooooooool0:?ooool3
o`0004kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0C?ooool2o`00
02[ooooo00?o0000ooooooooool0:?ooool3o`0004kooooo00?o0000ooooooooool02oooool001_o
oooo0_l0001<ooooo`?o0000:_ooool00ol0003oooooooooo`0Yooooo`?o0000C?ooool2o`0000go
oooo000Kooooo`03o`000?oooooooooo04_ooooo0_l0000[ooooo`03o`000?oooooooooo02Wooooo
0ol0001=ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo04[ooooo0ol0
000[ooooo`03o`000?oooooooooo02[ooooo0ol0001<ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo04Wooooo0ol0000/ooooo`03o`000?oooooooooo02[ooooo0ol0001<
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo04Wooooo0ol0000/oooo
o`03o`000?oooooooooo02_ooooo0ol0001;ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03
o`000?oooooooooo04Sooooo0ol0000]ooooo`03o`000?oooooooooo02_ooooo0ol0001;ooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo04Sooooo0ol0000]ooooo`03o`00
0?oooooooooo02cooooo0ol0001:ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo04Oooooo0ol0000^ooooo`03o`000?oooooooooo02cooooo0ol0001:ooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`;o0000B?ooool3o`0002kooooo00?o0000ooooooooool0;Oooool3
o`0004Sooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`16ooooo`?o0000;oooool00ol0
003oooooooooo`0]ooooo`?o0000BOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003o
ooooooooo`16ooooo`?o0000;oooool00ol0003oooooooooo`0^ooooo`?o0000B?ooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`15ooooo`?o0000<?ooool00ol0003ooooo
ooooo`0^ooooo`?o0000B?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`15ooooo`?o0000<?ooool00ol0003oooooooooo`0_ooooo`?o0000Aoooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`14ooooo`?o0000<Oooool00ol0003oooooooooo`0_
ooooo`?o0000Aoooool00ol0003oooooooooo`0;ooooo`003_ooool3o`0000?ooooo0_l00005oooo
o`03o`000?oooooooooo04Cooooo0ol0000aooooo`03o`000?oooooooooo033ooooo0ol00016oooo
o`03o`000?oooooooooo00_ooooo000?ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo04Cooooo0_l0000booooo`03o`000?oooooooooo
033ooooo0ol00016ooooo`03o`000?oooooooooo00_ooooo000<ooooo`Go00000_ooool01?l0003o
ooooooooool00004ooooo`;o0000A?ooool3o`0003;ooooo00?o0000ooooooooool0<Oooool3o`00
04Cooooo0_l0000=ooooo`003?ooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0@oooool2o`0003?ooooo00?o0000ooooooooool0<Oooool3
o`0004Gooooo00?o0000ooooooooool02oooool000gooooo00?o0000ooooool000000oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo04;ooooo0ol0000cooooo`03o`000?oooooo
oooo03;ooooo0ol00014ooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00000oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo04;ooooo0_l0000dooooo`03o`000?oooooo
oooo03;ooooo0ol00014ooooo`03o`000?oooooooooo00_ooooo000?ooooo`03o`000?oooooooooo
00;ooooo0_l00005ooooo`03o`000?oooooooooo047ooooo0ol0000dooooo`03o`000?oooooooooo
03?ooooo0_l00014ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo047o
oooo0_l0000eooooo`03o`000?oooooooooo03?ooooo0ol00013ooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo043ooooo0ol0000eooooo`03o`000?oooooooooo03Cooooo
0_l00013ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo043ooooo0ol0
000eooooo`03o`000?oooooooooo03Cooooo0ol00012ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`;o0000@?ooool3o`0003Kooooo00?o0000ooooooooool0=Oooool2o`00047ooooo0_l0000=
ooooo`006oooool00ol0003oooooooooo`0oooooo`?o0000=_ooool00ol0003oooooooooo`0eoooo
o`?o0000@Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0nooooo`?o
0000=oooool00ol0003oooooooooo`0eooooo`?o0000@Oooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`0nooooo`?o0000=oooool00ol0003oooooooooo`0fooooo`?o0000
@?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0mooooo`?o0000>?oo
ool00ol0003oooooooooo`0fooooo`?o0000@?ooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`0mooooo`?o0000>?ooool00ol0003oooooooooo`0gooooo`?o0000?oooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0looooo`?o0000>Oooool00ol0
003oooooooooo`0gooooo`?o0000?oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003o
ooooooooo`0looooo`?o0000>Oooool00ol0003oooooooooo`0hooooo`?o0000?_ooool00ol0003o
ooooooooo`0;ooooo`006oooool2o`0003cooooo0ol0000jooooo`03o`000?oooooooooo03Sooooo
0ol0000mooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0>oooool3o`0003[ooooo00?o
0000ooooooooool0>Oooool3o`0003gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000
ooooooooool0>oooool2o`0003_ooooo00?o0000ooooooooool0>Oooool3o`0003gooooo00?o0000
ooooooooool02oooool001_ooooo00?o0000ooooooooool0>_ooool3o`0003_ooooo00?o0000oooo
ooooool0>_ooool2o`0003gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool0>_ooool2o`0003cooooo00?o0000ooooooooool0>_ooool3o`0003cooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0>Oooool3o`0003cooooo00?o0000ooooooooool0
>oooool2o`0003cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0>Ooo
ool3o`0003cooooo00?o0000ooooooooool0>oooool3o`0003_ooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0>?ooool3o`0003gooooo00?o0000ooooooooool0??ooool2
o`0003_ooooo00?o0000ooooooooool02oooool001_ooooo0_l0000iooooo`?o0000?Oooool00ol0
003oooooooooo`0looooo`?o0000>Oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo03Oo
oooo0ol0000nooooo`03o`000?oooooooooo03gooooo0_l0000jooooo`03o`000?oooooooooo00_o
oooo000Kooooo`03o`000?oooooooooo03Oooooo0ol0000nooooo`03o`000?oooooooooo03gooooo
0ol0000iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03Kooooo0ol0
000oooooo`03o`000?oooooooooo03gooooo0ol0000iooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo03Kooooo0ol0000oooooo`03o`000?oooooooooo03kooooo0ol0000h
ooooo`03o`000?oooooooooo00_ooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000oooo
ooooool0=Oooool3o`00043ooooo00?o0000ooooooooool0?_ooool3o`0003Sooooo00?o0000oooo
ooooool02oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0=Oooool3o`00043ooooo00?o0000ooooooooool0?oooool3
o`0003Oooooo00?o0000ooooooooool02oooool000cooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool3o`00047ooooo00?o
0000ooooooooool0?oooool3o`0003Oooooo00?o0000ooooooooool02oooool000cooooo1?l00003
ooooo`04o`000?ooooooooooo`0000Cooooo0_l0000eooooo`?o0000@Oooool00ol0003ooooooooo
o`10ooooo`?o0000=Oooool2o`0000gooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0dooooo`;o0000@_ooool00ol0003ooooooooo
o`10ooooo`?o0000=_ooool00ol0003oooooooooo`0;ooooo`003Oooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<oooool3o`0004;ooooo00?o
0000ooooooooool0@Oooool3o`0003Gooooo00?o0000ooooooooool02oooool000kooooo0_l00004
ooooo`;o00001Oooool00ol0003oooooooooo`0cooooo`;o0000@oooool00ol0003oooooooooo`11
ooooo`?o0000=Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0boooo
o`?o0000@oooool00ol0003oooooooooo`12ooooo`?o0000=?ooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`0booooo`;o0000A?ooool00ol0003oooooooooo`12ooooo`?o
0000=?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0aooooo`?o0000
A?ooool00ol0003oooooooooo`13ooooo`;o0000=?ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`0aooooo`;o0000AOooool00ol0003oooooooooo`13ooooo`?o0000<ooo
ool00ol0003oooooooooo`0;ooooo`006oooool2o`00037ooooo0ol00015ooooo`03o`000?oooooo
oooo04Cooooo0_l0000booooo`;o00003Oooool001_ooooo00?o0000ooooooooool0<?ooool2o`00
04Kooooo00?o0000ooooooooool0A?ooool3o`0003;ooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool0;oooool3o`0004Kooooo00?o0000ooooooooool0AOooool2o`0003;o
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0;oooool3o`0004Kooooo
00?o0000ooooooooool0AOooool3o`00037ooooo00?o0000ooooooooool02oooool001_ooooo00?o
0000ooooooooool0;_ooool3o`0004Oooooo00?o0000ooooooooool0A_ooool2o`00037ooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0;_ooool3o`0004Oooooo00?o0000
ooooooooool0A_ooool3o`00033ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool0;Oooool3o`0004Sooooo00?o0000ooooooooool0Aoooool2o`00033ooooo00?o0000oooo
ooooool02oooool001_ooooo0_l0000^ooooo`?o0000B?ooool00ol0003oooooooooo`17ooooo`?o
0000;_ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo02cooooo0ol00019ooooo`03o`00
0?oooooooooo04Sooooo0_l0000_ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo02cooooo0ol00019ooooo`03o`000?oooooooooo04Sooooo0ol0000^ooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`03o`000?oooooooooo02_ooooo0ol0001:ooooo`03o`000?oooooo
oooo04Wooooo0_l0000^ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
02_ooooo0ol0001:ooooo`03o`000?oooooooooo04Wooooo0ol0000]ooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo02[ooooo0ol0001;ooooo`03o`000?oooooooooo04[o
oooo0_l0000]ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo02[ooooo
0_l0001<ooooo`03o`000?oooooooooo04[ooooo0ol0000/ooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo02Wooooo0ol0001<ooooo`03o`000?oooooooooo04_ooooo0ol0
000[ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o0000:_ooool2o`0004gooooo00?o0000
ooooooooool0Boooool3o`0002[ooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`0Xoooo
o`?o0000COooool00ol0003oooooooooo`1<ooooo`?o0000:_ooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`0Wooooo`?o0000C_ooool00ol0003oooooooooo`1<ooooo`?o
0000:_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Wooooo`?o0000
C_ooool00ol0003oooooooooo`1=ooooo`?o0000:Oooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`0Vooooo`?o0000Coooool00ol0003oooooooooo`1=ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Vooooo`?o0000Coooool0
0ol0003oooooooooo`1>ooooo`?o0000:?ooool00ol0003oooooooooo`0;ooooo`003Oooool3o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo02Gooooo0ol0001@ooooo`03o`000?oooooooooo
04kooooo1?l0000Wooooo`03o`000?oooooooooo00_ooooo000<ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Cooooo1?l0001@
ooooo`03o`000?oooooooooo04oooooo0ol0000Wooooo`03o`000?oooooooooo00_ooooo000<oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`;o00009Ooo
ool3o`00057ooooo00?o0000ooooooooool0D?ooool3o`0002Gooooo0_l0000=ooooo`003Oooool3
o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Sooooo`?o0000D_oo
ool00ol0003oooooooooo`1@ooooo`?o00009_ooool00ol0003oooooooooo`0;ooooo`003?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0Sooooo`?o0000D_ooool00ol0003oooooooooo`1Aooooo`?o00009Oooool00ol0003ooooo
ooooo`0;ooooo`003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0Rooooo`?o0000Doooool00ol0003oooooooooo`1Aooooo`Co
00009?ooool00ol0003oooooooooo`0;ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo027ooooo1?l0001Cooooo`03o`000?oooooooooo05;ooooo0ol0000Tooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo027ooooo0ol0001Dooooo`03o`000?oo
oooooooo05?ooooo0ol0000Sooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo023ooooo0ol0001Eooooo`03o`000?oooooooooo05?ooooo1?l0000Rooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo01oooooo1?l0001Eooooo`03o`000?oooooooooo
05Cooooo0ol0000Rooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00000oooool2o`0001[o
oooo1?l0001Fooooo`03o`000?oooooooooo05Gooooo0ol0000Jooooo`;o00001?ooool2o`0000go
oooo000Kooooo`03o`000?oooooooooo00;ooooo0ol0000Iooooo`?o0000Eoooool00ol0003ooooo
ooooo`1Eooooo`Co00006Oooool2o`0000Gooooo00?o0000ooooooooool02oooool001_ooooo00?o
0000ooooooooool00oooool3o`0001Oooooo0ol0001Hooooo`03o`000?oooooooooo05Kooooo1?l0
000Gooooo`?o00001Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`03
ooooo`?o00005_ooool4o`0005Sooooo00?o0000ooooooooool0Eoooool4o`0001Gooooo1?l00005
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Cooooo0ol0000Doooo
o`Co0000FOooool00ol0003oooooooooo`1Hooooo`?o00005Oooool3o`0000Kooooo00?o0000oooo
ooooool02oooool001_ooooo00?o0000ooooooooool01?ooool4o`0001;ooooo1?l0001Jooooo`03
o`000?oooooooooo05Wooooo0ol0000Cooooo`?o00001oooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`05ooooo`?o00004Oooool4o`0005_ooooo00?o0000ooooooooool0
FOooool4o`00017ooooo1?l00007ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo00Kooooo0ol0000?ooooo`Co0000G?ooool00ol0003oooooooooo`1Jooooo`Co00003ooo
ool4o`0000Sooooo00?o0000ooooooooool02oooool001_ooooo0_l00008ooooo`?o00003Oooool4
o`0005gooooo00?o0000ooooooooool0Foooool5o`0000cooooo1?l00008ooooo`;o00003Oooool0
01_ooooo00?o0000ooooooooool01oooool5o`0000Wooooo1Ol0001Nooooo`03o`000?oooooooooo
05gooooo1?l0000:ooooo`Co00002_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003o
ooooooooo`09ooooo`Co00001oooool5o`0005oooooo00?o0000ooooooooool0G_ooool5o`0000Ko
oooo1Ol0000;ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00[ooooo
3Ol0001Qooooo`03o`000?oooooooooo05oooooo3_l0000<ooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo00_ooooo2_l0001Sooooo`03o`000?oooooooooo067ooooo2_l0
000>ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`006ooooooho`0000gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000]oooo
o`?o0000R_ooool00ol0003oooooooooo`0[ooooo`?o00005Oooool00ol0003oooooooooo`0Moooo
o`00;_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Looooo`00:?ooool3o`0000?ooooo0ol00004ooooo`;o0000
0_ooool5o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000ol00007ooooo`?o0000
1?ooool4o`0000?ooooo0_l00002ooooo`Ko00001_ooool4o`0000;ooooo1Ol000000ooooooo0000
o`000003o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo0ol00004ooooo`?o0000
0_ooool3o`000004ooooool0003o0000ooooo`?o00000oooool3o`0000Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o
00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003oooo
o`;o00000_ooool:o`0000Gooooo00?o0000ooooooooool06oooool002Oooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00000<oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06oooool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool3o`0000?o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01_l0003ooooooooo
ool0003oooooo`0000Gooooo1Ol00008ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0
003oooooo`000002ooooo`?o00000oooool00ol0003oooooo`000002ooooo`Go00000oooool01?l0
003oooooooooooooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00000_ooool3o`0000Gooooo00?o0000oooo
ooooool06oooool002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0ol0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooo
oooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool0
1?l0003oooooooooool00005ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003o
ooooooooo`0Kooooo`009oooool01_l0003ooooooooooooooooo0000ooooo`Co00000_ooool4o`00
00;ooooo0ol00004ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool02?ooool01?l0
003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00009ooooo`05o`000?oooooo
ooooo`000?ooool00ol00004ooooo`Co00000_ooool4o`0000;ooooo0ol00002ooooo`;o000000?o
ooooo`000?l000000_ooool3o`0000;ooooo1?l00003ooooo`?o00000oooool3o`0000Wooooo00?o
0000ooooooooool00_ooool6o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00
0002ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool4o`0000?ooooo2Ol0
0003ooooo`?o00000oooool4o`0000Cooooo00?o0000ooooooooool06oooool002Oooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo000Xooooo`?o0000
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0ol00009ooooo`Co0000
2Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool4o`0000Cooooo00?o0000ooooooooool0
1?ooool2o`0000Cooooo0_l0000^ooooo`03o`000?oooooooooo01Sooooo0ol0000Fooooo`03o`00
0?oooooooooo00;ooooo0_l0000;ooooo`03o`000?oooooooooo01gooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-29.0859, -9.99629, \
0.192645, 0.635594}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 1.05007 0.0146546 0.588664 [
[.07997 .00215 -12 -9 ]
[.07997 .00215 12 0 ]
[.28999 .00215 -12 -9 ]
[.28999 .00215 12 0 ]
[.5 .00215 -3 -9 ]
[.5 .00215 3 0 ]
[.71001 .00215 -9 -9 ]
[.71001 .00215 9 0 ]
[.92003 .00215 -9 -9 ]
[.92003 .00215 9 0 ]
[.01131 .13239 -18 -4.5 ]
[.01131 .13239 0 4.5 ]
[.01131 .25012 -18 -4.5 ]
[.01131 .25012 0 4.5 ]
[.01131 .36785 -18 -4.5 ]
[.01131 .36785 0 4.5 ]
[.01131 .48559 -18 -4.5 ]
[.01131 .48559 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07997 .01465 m
.07997 .0209 L
s
[(-0.4)] .07997 .00215 0 1 Mshowa
.28999 .01465 m
.28999 .0209 L
s
[(-0.2)] .28999 .00215 0 1 Mshowa
.5 .01465 m
.5 .0209 L
s
[(0)] .5 .00215 0 1 Mshowa
.71001 .01465 m
.71001 .0209 L
s
[(0.2)] .71001 .00215 0 1 Mshowa
.92003 .01465 m
.92003 .0209 L
s
[(0.4)] .92003 .00215 0 1 Mshowa
.125 Mabswid
.13247 .01465 m
.13247 .0184 L
s
.18498 .01465 m
.18498 .0184 L
s
.23748 .01465 m
.23748 .0184 L
s
.34249 .01465 m
.34249 .0184 L
s
.39499 .01465 m
.39499 .0184 L
s
.4475 .01465 m
.4475 .0184 L
s
.5525 .01465 m
.5525 .0184 L
s
.60501 .01465 m
.60501 .0184 L
s
.65751 .01465 m
.65751 .0184 L
s
.76252 .01465 m
.76252 .0184 L
s
.81502 .01465 m
.81502 .0184 L
s
.86753 .01465 m
.86753 .0184 L
s
.02747 .01465 m
.02747 .0184 L
s
.97253 .01465 m
.97253 .0184 L
s
.25 Mabswid
0 .01465 m
1 .01465 L
s
.02381 .13239 m
.03006 .13239 L
s
[(0.2)] .01131 .13239 1 0 Mshowa
.02381 .25012 m
.03006 .25012 L
s
[(0.4)] .01131 .25012 1 0 Mshowa
.02381 .36785 m
.03006 .36785 L
s
[(0.6)] .01131 .36785 1 0 Mshowa
.02381 .48559 m
.03006 .48559 L
s
[(0.8)] .01131 .48559 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04409 m
.02756 .04409 L
s
.02381 .07352 m
.02756 .07352 L
s
.02381 .10295 m
.02756 .10295 L
s
.02381 .16182 m
.02756 .16182 L
s
.02381 .19125 m
.02756 .19125 L
s
.02381 .22069 m
.02756 .22069 L
s
.02381 .27955 m
.02756 .27955 L
s
.02381 .30899 m
.02756 .30899 L
s
.02381 .33842 m
.02756 .33842 L
s
.02381 .39729 m
.02756 .39729 L
s
.02381 .42672 m
.02756 .42672 L
s
.02381 .45615 m
.02756 .45615 L
s
.02381 .51502 m
.02756 .51502 L
s
.02381 .54445 m
.02756 .54445 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Amplitude Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .02058 m
.02502 .02066 L
.02623 .02074 L
.02744 .02083 L
.02864 .02092 L
.02985 .02101 L
.03106 .02109 L
.03227 .02119 L
.03348 .02128 L
.03469 .02137 L
.0359 .02147 L
.0371 .02156 L
.03831 .02166 L
.03952 .02176 L
.04073 .02186 L
.04194 .02196 L
.04315 .02207 L
.04436 .02218 L
.04556 .02228 L
.04677 .02239 L
.04798 .02251 L
.04919 .02262 L
.0504 .02274 L
.05161 .02285 L
.05282 .02297 L
.05402 .02309 L
.05523 .02322 L
.05644 .02334 L
.05765 .02347 L
.05886 .0236 L
.06007 .02374 L
.06128 .02387 L
.06248 .02401 L
.06369 .02415 L
.0649 .02429 L
.06611 .02444 L
.06732 .02459 L
.06853 .02474 L
.06974 .02489 L
.07095 .02506 L
.07215 .02523 L
.07336 .02536 L
.07457 .0255 L
.07578 .02574 L
.07699 .026 L
.0782 .02604 L
.07941 .026 L
.08061 .02644 L
.08182 .02716 L
.08303 .02697 L
Mistroke
.08424 .02594 L
.08545 .02678 L
.08666 .02949 L
.08787 .0294 L
.08907 .02449 L
.09028 .02545 L
.09149 .03519 L
.0927 .03807 L
.09391 .02741 L
.09512 .02636 L
.09633 .05115 L
.09753 .06387 L
.09874 .0576 L
.09995 .05958 L
.10116 .09534 L
.10237 .12595 L
.10358 .13372 L
.10479 .14559 L
.10599 .19442 L
.1072 .2484 L
.10841 .27646 L
.10962 .30047 L
.11083 .35985 L
.11204 .43083 L
.11325 .47013 L
.11445 .49007 L
.11566 .53506 L
.11687 .59036 L
.11808 .60332 L
.11929 .57523 L
.1205 .55565 L
.12171 .543 L
.12292 .48141 L
.12412 .36503 L
.12533 .25258 L
.12654 .16325 L
.12775 .03931 L
.12896 .1524 L
.13017 .28878 L
.13138 .36085 L
.13258 .41117 L
.13379 .47178 L
.135 .4796 L
.13621 .39354 L
.13742 .2687 L
.13863 .17027 L
.13984 .05001 L
.14104 .16149 L
.14225 .32334 L
.14346 .39376 L
Mistroke
.14467 .39619 L
.14588 .3991 L
.14709 .35775 L
.1483 .21017 L
.1495 .02457 L
.15071 .17256 L
.15192 .25968 L
.15313 .36276 L
.15434 .43343 L
.15555 .37213 L
.15676 .2062 L
.15796 .08249 L
.15917 .10409 L
.16038 .24805 L
.16159 .39772 L
.1628 .41106 L
.16401 .28588 L
.16522 .16033 L
.16642 .07377 L
.16763 .16417 L
.16884 .35563 L
.17005 .41033 L
.17126 .30206 L
.17247 .17722 L
.17368 .09263 L
.17489 .1409 L
.17609 .34704 L
.1773 .4077 L
.17851 .28342 L
.17972 .14152 L
.18093 .08549 L
.18214 .17405 L
.18335 .36904 L
.18455 .39802 L
.18576 .22461 L
.18697 .07655 L
.18818 .1328 L
.18939 .24013 L
.1906 .38864 L
.19181 .34591 L
.19301 .1038 L
.19422 .16238 L
.19543 .23616 L
.19664 .28747 L
.19785 .34822 L
.19906 .20791 L
.20027 .13023 L
.20147 .32246 L
.20268 .29673 L
.20389 .23856 L
Mistroke
.2051 .20021 L
.20631 .05611 L
.20752 .33117 L
.20873 .39552 L
.20993 .20295 L
.21114 .10277 L
.21235 .13075 L
.21356 .25413 L
.21477 .38992 L
.21598 .25254 L
.21719 .1128 L
.21839 .2974 L
.2196 .25284 L
.22081 .24618 L
.22202 .19019 L
.22323 .12581 L
.22444 .38412 L
.22565 .34884 L
.22686 .08093 L
.22806 .16148 L
.22927 .17016 L
.23048 .31705 L
.23169 .31739 L
.2329 .08136 L
.23411 .31714 L
.23532 .32808 L
.23652 .15473 L
.23773 .15215 L
.23894 .09557 L
.24015 .34687 L
.24136 .35422 L
.24257 .07814 L
.24378 .27069 L
.24498 .27047 L
.24619 .20067 L
.2474 .17714 L
.24861 .11358 L
.24982 .37707 L
.25103 .31956 L
.25224 .04749 L
.25344 .25424 L
.25465 .22356 L
.25586 .24075 L
.25707 .13353 L
.25828 .21298 L
.25949 .39071 L
.2607 .21205 L
.2619 .13246 L
.26311 .24083 L
.26432 .22657 L
Mistroke
.26553 .22781 L
.26674 .04314 L
.26795 .33362 L
.26916 .3252 L
.27036 .03128 L
.27157 .22138 L
.27278 .22549 L
.27399 .23943 L
.2752 .08785 L
.27641 .25341 L
.27762 .36016 L
.27883 .12077 L
.28003 .1948 L
.28124 .24014 L
.28245 .22079 L
.28366 .12663 L
.28487 .20058 L
.28608 .36563 L
.28729 .16303 L
.28849 .19595 L
.2897 .26838 L
.29091 .18249 L
.29212 .12948 L
.29333 .17686 L
.29454 .35765 L
.29575 .16855 L
.29695 .23181 L
.29816 .31054 L
.29937 .12214 L
.30058 .13905 L
.30179 .17685 L
.303 .32052 L
.30421 .12731 L
.30541 .28546 L
.30662 .33848 L
.30783 .03974 L
.30904 .21276 L
.31025 .19093 L
.31146 .23688 L
.31267 .0285 L
.31387 .32578 L
.31508 .30275 L
.31629 .10587 L
.3175 .30898 L
.31871 .17098 L
.31992 .14108 L
.32113 .1323 L
.32234 .3111 L
.32354 .16691 L
.32475 .24549 L
Mistroke
.32596 .3356 L
.32717 .05168 L
.32838 .2108 L
.32959 .20201 L
.3308 .20393 L
.332 .06924 L
.33321 .33626 L
.33442 .21447 L
.33563 .1927 L
.33684 .29668 L
.33805 .11136 L
.33926 .13922 L
.34046 .21505 L
.34167 .26268 L
.34288 .08187 L
.34409 .35706 L
.3453 .18912 L
.34651 .19853 L
.34772 .24147 L
.34892 .15365 L
.35013 .09846 L
.35134 .2624 L
.35255 .26567 L
.35376 .15627 L
.35497 .36341 L
.35618 .10166 L
.35738 .2304 L
.35859 .1897 L
.3598 .17902 L
.36101 .07824 L
.36222 .32056 L
.36343 .1707 L
.36464 .26747 L
.36584 .30141 L
.36705 .06696 L
.36826 .23073 L
.36947 .18307 L
.37068 .12751 L
.37189 .21804 L
.3731 .30024 L
.37431 .0924 L
.37551 .33827 L
.37672 .12261 L
.37793 .19499 L
.37914 .18875 L
.38035 .18838 L
.38156 .10275 L
.38277 .33363 L
.38397 .10667 L
.38518 .31477 L
Mistroke
.38639 .22792 L
.3876 .15563 L
.38881 .20631 L
.39002 .18484 L
.39123 .06815 L
.39243 .29988 L
.39364 .19515 L
.39485 .26395 L
.39606 .30133 L
.39727 .10651 L
.39848 .25454 L
.39969 .14218 L
.40089 .11457 L
.4021 .24958 L
.40331 .20578 L
.40452 .22572 L
.40573 .31297 L
.40694 .09195 L
.40815 .27725 L
.40935 .1179 L
.41056 .13585 L
.41177 .2344 L
.41298 .17625 L
.41419 .24354 L
.4154 .3005 L
.41661 .1449 L
.41781 .3022 L
.41902 .068 L
.42023 .18472 L
.42144 .20286 L
.42265 .12649 L
.42386 .26773 L
.42507 .25338 L
.42628 .22324 L
.42748 .3058 L
.42869 .10044 L
.4299 .23994 L
.43111 .14783 L
.43232 .10249 L
.43353 .27323 L
.43474 .12213 L
.43594 .30516 L
.43715 .21389 L
.43836 .22825 L
.43957 .22124 L
.44078 .13456 L
.44199 .15777 L
.4432 .23351 L
.4444 .08186 L
.44561 .34088 L
Mistroke
.44682 .06718 L
.44803 .34537 L
.44924 .08725 L
.45045 .24775 L
.45166 .14151 L
.45286 .14733 L
.45407 .21025 L
.45528 .21458 L
.45649 .23416 L
.4577 .28772 L
.45891 .1819 L
.46012 .27185 L
.46132 .1082 L
.46253 .18109 L
.46374 .20231 L
.46495 .07854 L
.46616 .31735 L
.46737 .05938 L
.46858 .34933 L
.46978 .05112 L
.47099 .28217 L
.4722 .10274 L
.47341 .1598 L
.47462 .2173 L
.47583 .12107 L
.47704 .30083 L
.47825 .18056 L
.47945 .30474 L
.48066 .1875 L
.48187 .22832 L
.48308 .16224 L
.48429 .15016 L
.4855 .19459 L
.48671 .19512 L
.48791 .24809 L
.48912 .24838 L
.49033 .24466 L
.49154 .22823 L
.49275 .18478 L
.49396 .16522 L
.49517 .17152 L
.49637 .17033 L
.49758 .24474 L
.49879 .22309 L
.5 .28386 L
.50121 .22309 L
.50242 .24474 L
.50363 .17033 L
.50483 .17152 L
.50604 .16522 L
Mistroke
.50725 .18478 L
.50846 .22823 L
.50967 .24466 L
.51088 .24838 L
.51209 .24809 L
.51329 .19512 L
.5145 .19459 L
.51571 .15016 L
.51692 .16224 L
.51813 .22832 L
.51934 .1875 L
.52055 .30475 L
.52175 .18055 L
.52296 .30083 L
.52417 .12106 L
.52538 .2173 L
.52659 .1598 L
.5278 .10274 L
.52901 .28217 L
.53022 .05112 L
.53142 .34932 L
.53263 .05939 L
.53384 .31735 L
.53505 .07854 L
.53626 .2023 L
.53747 .18109 L
.53868 .1082 L
.53988 .27185 L
.54109 .1819 L
.5423 .28772 L
.54351 .23415 L
.54472 .21458 L
.54593 .21024 L
.54714 .14733 L
.54834 .14151 L
.54955 .24775 L
.55076 .08725 L
.55197 .34537 L
.55318 .06718 L
.55439 .34089 L
.5556 .08186 L
.5568 .23351 L
.55801 .15777 L
.55922 .13456 L
.56043 .22123 L
.56164 .22825 L
.56285 .21389 L
.56406 .30516 L
.56526 .12213 L
.56647 .27323 L
Mistroke
.56768 .10249 L
.56889 .14783 L
.5701 .23994 L
.57131 .10044 L
.57252 .3058 L
.57372 .22324 L
.57493 .25338 L
.57614 .26773 L
.57735 .12649 L
.57856 .20286 L
.57977 .18472 L
.58098 .068 L
.58219 .3022 L
.58339 .1449 L
.5846 .3005 L
.58581 .24354 L
.58702 .17625 L
.58823 .2344 L
.58944 .13585 L
.59065 .1179 L
.59185 .27725 L
.59306 .09195 L
.59427 .31297 L
.59548 .22571 L
.59669 .20578 L
.5979 .24958 L
.59911 .11458 L
.60031 .14218 L
.60152 .25455 L
.60273 .10651 L
.60394 .30134 L
.60515 .26395 L
.60636 .19515 L
.60757 .29988 L
.60877 .06815 L
.60998 .18485 L
.61119 .20631 L
.6124 .15563 L
.61361 .22792 L
.61482 .31477 L
.61603 .10667 L
.61723 .33363 L
.61844 .10275 L
.61965 .18838 L
.62086 .18875 L
.62207 .19499 L
.62328 .12261 L
.62449 .33827 L
.62569 .09239 L
.6269 .30024 L
Mistroke
.62811 .21803 L
.62932 .12752 L
.63053 .18307 L
.63174 .23074 L
.63295 .06696 L
.63416 .30142 L
.63536 .26748 L
.63657 .17071 L
.63778 .32056 L
.63899 .07824 L
.6402 .17903 L
.64141 .1897 L
.64262 .2304 L
.64382 .10166 L
.64503 .36341 L
.64624 .15627 L
.64745 .26568 L
.64866 .2624 L
.64987 .09845 L
.65108 .15366 L
.65228 .24147 L
.65349 .19853 L
.6547 .18912 L
.65591 .35706 L
.65712 .08187 L
.65833 .26268 L
.65954 .21505 L
.66074 .13922 L
.66195 .11136 L
.66316 .29668 L
.66437 .1927 L
.66558 .21447 L
.66679 .33626 L
.668 .06924 L
.6692 .20392 L
.67041 .20202 L
.67162 .2108 L
.67283 .05168 L
.67404 .3356 L
.67525 .24548 L
.67646 .16691 L
.67766 .3111 L
.67887 .1323 L
.68008 .14108 L
.68129 .17098 L
.6825 .30899 L
.68371 .10587 L
.68492 .30275 L
.68613 .32578 L
.68733 .02851 L
Mistroke
.68854 .23688 L
.68975 .19093 L
.69096 .21276 L
.69217 .03974 L
.69338 .33848 L
.69459 .28547 L
.69579 .12732 L
.697 .32053 L
.69821 .17685 L
.69942 .13905 L
.70063 .12214 L
.70184 .31054 L
.70305 .23181 L
.70425 .16855 L
.70546 .35765 L
.70667 .17686 L
.70788 .12948 L
.70909 .18249 L
.7103 .26838 L
.71151 .19594 L
.71271 .16303 L
.71392 .36562 L
.71513 .20058 L
.71634 .12662 L
.71755 .22079 L
.71876 .24014 L
.71997 .19479 L
.72117 .12078 L
.72238 .36015 L
.72359 .2534 L
.7248 .08785 L
.72601 .23943 L
.72722 .2255 L
.72843 .22138 L
.72964 .03128 L
.73084 .32521 L
.73205 .33361 L
.73326 .04313 L
.73447 .22781 L
.73568 .22656 L
.73689 .24084 L
.7381 .13246 L
.7393 .21205 L
.74051 .39072 L
.74172 .21298 L
.74293 .13354 L
.74414 .24075 L
.74535 .22356 L
.74656 .25424 L
.74776 .0475 L
Mistroke
.74897 .31957 L
.75018 .37707 L
.75139 .11358 L
.7526 .17714 L
.75381 .20067 L
.75502 .27047 L
.75622 .2707 L
.75743 .07814 L
.75864 .35422 L
.75985 .34687 L
.76106 .09556 L
.76227 .15215 L
.76348 .15472 L
.76468 .32808 L
.76589 .31715 L
.7671 .08136 L
.76831 .31739 L
.76952 .31705 L
.77073 .17016 L
.77194 .16149 L
.77314 .08093 L
.77435 .34884 L
.77556 .38413 L
.77677 .12582 L
.77798 .1902 L
.77919 .24619 L
.7804 .25284 L
.78161 .2974 L
.78281 .11281 L
.78402 .25254 L
.78523 .38992 L
.78644 .25414 L
.78765 .13074 L
.78886 .10278 L
.79007 .20295 L
.79127 .39551 L
.79248 .33117 L
.79369 .05612 L
.7949 .20021 L
.79611 .23857 L
.79732 .29673 L
.79853 .32246 L
.79973 .13023 L
.80094 .2079 L
.80215 .34823 L
.80336 .28748 L
.80457 .23616 L
.80578 .16238 L
.80699 .10379 L
.80819 .34591 L
Mistroke
.8094 .38864 L
.81061 .24013 L
.81182 .1328 L
.81303 .07655 L
.81424 .22461 L
.81545 .39801 L
.81665 .36904 L
.81786 .17405 L
.81907 .08549 L
.82028 .14153 L
.82149 .28342 L
.8227 .4077 L
.82391 .34703 L
.82511 .1409 L
.82632 .09263 L
.82753 .17723 L
.82874 .30206 L
.82995 .41032 L
.83116 .35562 L
.83237 .16417 L
.83358 .07377 L
.83478 .16033 L
.83599 .28588 L
.8372 .41105 L
.83841 .39772 L
.83962 .24805 L
.84083 .10409 L
.84204 .08248 L
.84324 .20621 L
.84445 .37213 L
.84566 .43343 L
.84687 .36276 L
.84808 .25968 L
.84929 .17255 L
.8505 .02457 L
.8517 .21017 L
.85291 .35775 L
.85412 .3991 L
.85533 .3962 L
.85654 .39376 L
.85775 .32334 L
.85896 .16149 L
.86016 .05 L
.86137 .17026 L
.86258 .26871 L
.86379 .39354 L
.865 .4796 L
.86621 .47178 L
.86742 .41117 L
.86862 .36085 L
Mistroke
.86983 .28878 L
.87104 .1524 L
.87225 .03931 L
.87346 .16325 L
.87467 .25258 L
.87588 .36503 L
.87708 .4814 L
.87829 .54299 L
.8795 .55565 L
.88071 .57524 L
.88192 .60332 L
.88313 .59036 L
.88434 .53506 L
.88555 .49008 L
.88675 .47013 L
.88796 .43083 L
.88917 .35985 L
.89038 .30047 L
.89159 .27646 L
.8928 .2484 L
.89401 .19441 L
.89521 .1456 L
.89642 .13373 L
.89763 .12595 L
.89884 .09533 L
.90005 .05959 L
.90126 .05761 L
.90247 .06387 L
.90367 .05114 L
.90488 .02636 L
.90609 .02742 L
.9073 .03807 L
.90851 .03518 L
.90972 .02544 L
.91093 .02449 L
.91213 .0294 L
.91334 .02949 L
.91455 .02678 L
.91576 .02594 L
.91697 .02697 L
.91818 .02715 L
.91939 .02644 L
.92059 .026 L
.9218 .02604 L
.92301 .026 L
.92422 .02574 L
.92543 .0255 L
.92664 .02536 L
.92785 .02523 L
.92905 .02506 L
Mistroke
.93026 .02489 L
.93147 .02473 L
.93268 .02459 L
.93389 .02444 L
.9351 .02429 L
.93631 .02415 L
.93752 .02401 L
.93872 .02387 L
.93993 .02373 L
.94114 .0236 L
.94235 .02347 L
.94356 .02334 L
.94477 .02321 L
.94598 .02309 L
.94718 .02297 L
.94839 .02285 L
.9496 .02273 L
.95081 .02262 L
.95202 .0225 L
.95323 .02239 L
.95444 .02228 L
.95564 .02217 L
.95685 .02207 L
.95806 .02196 L
.95927 .02186 L
.96048 .02176 L
.96169 .02166 L
.9629 .02156 L
.9641 .02146 L
.96531 .02137 L
.96652 .02127 L
.96773 .02118 L
.96894 .02109 L
.97015 .021 L
.97136 .02091 L
.97256 .02083 L
.97377 .02074 L
.97498 .02066 L
.97619 .02057 L
Mfstroke
1 0 0 r
.02381 .01472 m
.02502 .01472 L
.02623 .01472 L
.02744 .01472 L
.02864 .01472 L
.02985 .01472 L
.03106 .01472 L
.03227 .01472 L
.03348 .01472 L
.03469 .01472 L
.0359 .01472 L
.0371 .01472 L
.03831 .01472 L
.03952 .01472 L
.04073 .01472 L
.04194 .01472 L
.04315 .01472 L
.04436 .01472 L
.04556 .01472 L
.04677 .01472 L
.04798 .01472 L
.04919 .01473 L
.0504 .01473 L
.05161 .01473 L
.05282 .01473 L
.05402 .01473 L
.05523 .01473 L
.05644 .01473 L
.05765 .01473 L
.05886 .01473 L
.06007 .01473 L
.06128 .01473 L
.06248 .01473 L
.06369 .01473 L
.0649 .01473 L
.06611 .01473 L
.06732 .01473 L
.06853 .01473 L
.06974 .01473 L
.07095 .01473 L
.07215 .01473 L
.07336 .01473 L
.07457 .01474 L
.07578 .01474 L
.07699 .01474 L
.0782 .01474 L
.07941 .01474 L
.08061 .01474 L
.08182 .01474 L
.08303 .01474 L
Mistroke
.08424 .01474 L
.08545 .01474 L
.08666 .01474 L
.08787 .01474 L
.08907 .01474 L
.09028 .01474 L
.09149 .01474 L
.0927 .01474 L
.09391 .01474 L
.09512 .01474 L
.09633 .01474 L
.09753 .01474 L
.09874 .01474 L
.09995 .01475 L
.10116 .01475 L
.10237 .01475 L
.10358 .01475 L
.10479 .01475 L
.10599 .01475 L
.1072 .01475 L
.10841 .01475 L
.10962 .01475 L
.11083 .01475 L
.11204 .01475 L
.11325 .01475 L
.11445 .01475 L
.11566 .01475 L
.11687 .01475 L
.11808 .01475 L
.11929 .01475 L
.1205 .01475 L
.12171 .01475 L
.12292 .01475 L
.12412 .01475 L
.12533 .01475 L
.12654 .01475 L
.12775 .01476 L
.12896 .01476 L
.13017 .01476 L
.13138 .01476 L
.13258 .01476 L
.13379 .01476 L
.135 .01476 L
.13621 .01476 L
.13742 .01476 L
.13863 .01476 L
.13984 .01476 L
.14104 .01476 L
.14225 .01476 L
.14346 .01476 L
Mistroke
.14467 .01476 L
.14588 .01476 L
.14709 .01476 L
.1483 .01476 L
.1495 .01476 L
.15071 .01476 L
.15192 .01476 L
.15313 .01476 L
.15434 .01476 L
.15555 .01477 L
.15676 .01477 L
.15796 .01477 L
.15917 .01477 L
.16038 .01477 L
.16159 .01477 L
.1628 .01477 L
.16401 .01477 L
.16522 .01477 L
.16642 .01477 L
.16763 .01477 L
.16884 .01477 L
.17005 .01477 L
.17126 .01477 L
.17247 .01477 L
.17368 .01477 L
.17489 .01477 L
.17609 .01477 L
.1773 .01477 L
.17851 .01477 L
.17972 .01477 L
.18093 .01477 L
.18214 .01477 L
.18335 .01477 L
.18455 .01477 L
.18576 .01478 L
.18697 .01478 L
.18818 .01478 L
.18939 .01478 L
.1906 .01478 L
.19181 .01478 L
.19301 .01478 L
.19422 .01478 L
.19543 .01478 L
.19664 .01478 L
.19785 .01478 L
.19906 .01478 L
.20027 .01478 L
.20147 .01478 L
.20268 .01478 L
.20389 .01478 L
Mistroke
.2051 .01478 L
.20631 .01478 L
.20752 .01478 L
.20873 .01478 L
.20993 .01478 L
.21114 .01478 L
.21235 .01478 L
.21356 .01478 L
.21477 .01478 L
.21598 .01478 L
.21719 .01478 L
.21839 .01479 L
.2196 .01479 L
.22081 .01479 L
.22202 .01479 L
.22323 .01479 L
.22444 .01479 L
.22565 .01479 L
.22686 .01479 L
.22806 .01479 L
.22927 .01479 L
.23048 .01479 L
.23169 .01479 L
.2329 .01479 L
.23411 .01479 L
.23532 .01479 L
.23652 .01479 L
.23773 .01479 L
.23894 .01479 L
.24015 .01479 L
.24136 .01479 L
.24257 .01479 L
.24378 .01479 L
.24498 .01479 L
.24619 .01479 L
.2474 .01479 L
.24861 .01479 L
.24982 .01479 L
.25103 .01479 L
.25224 .01479 L
.25344 .0148 L
.25465 .0148 L
.25586 .0148 L
.25707 .0148 L
.25828 .0148 L
.25949 .0148 L
.2607 .0148 L
.2619 .0148 L
.26311 .0148 L
.26432 .0148 L
Mistroke
.26553 .0148 L
.26674 .0148 L
.26795 .0148 L
.26916 .0148 L
.27036 .0148 L
.27157 .0148 L
.27278 .0148 L
.27399 .0148 L
.2752 .0148 L
.27641 .0148 L
.27762 .0148 L
.27883 .0148 L
.28003 .0148 L
.28124 .0148 L
.28245 .0148 L
.28366 .0148 L
.28487 .0148 L
.28608 .0148 L
.28729 .0148 L
.28849 .0148 L
.2897 .0148 L
.29091 .0148 L
.29212 .01481 L
.29333 .01481 L
.29454 .01481 L
.29575 .01481 L
.29695 .01481 L
.29816 .01481 L
.29937 .01481 L
.30058 .01481 L
.30179 .01481 L
.303 .01481 L
.30421 .01481 L
.30541 .01481 L
.30662 .01481 L
.30783 .01481 L
.30904 .01481 L
.31025 .01481 L
.31146 .01481 L
.31267 .01481 L
.31387 .01481 L
.31508 .01481 L
.31629 .01481 L
.3175 .01481 L
.31871 .01481 L
.31992 .01481 L
.32113 .01481 L
.32234 .01481 L
.32354 .01481 L
.32475 .01481 L
Mistroke
.32596 .01481 L
.32717 .01481 L
.32838 .01481 L
.32959 .01481 L
.3308 .01481 L
.332 .01481 L
.33321 .01481 L
.33442 .01481 L
.33563 .01481 L
.33684 .01481 L
.33805 .01481 L
.33926 .01481 L
.34046 .01482 L
.34167 .01482 L
.34288 .01482 L
.34409 .01482 L
.3453 .01482 L
.34651 .01482 L
.34772 .01482 L
.34892 .01482 L
.35013 .01482 L
.35134 .01482 L
.35255 .01482 L
.35376 .01482 L
.35497 .01482 L
.35618 .01482 L
.35738 .01482 L
.35859 .01482 L
.3598 .01482 L
.36101 .01482 L
.36222 .01482 L
.36343 .01482 L
.36464 .01482 L
.36584 .01482 L
.36705 .01482 L
.36826 .01482 L
.36947 .01482 L
.37068 .01482 L
.37189 .01482 L
.3731 .01482 L
.37431 .01482 L
.37551 .01482 L
.37672 .01482 L
.37793 .01482 L
.37914 .01482 L
.38035 .01482 L
.38156 .01482 L
.38277 .01482 L
.38397 .01482 L
.38518 .01482 L
Mistroke
.38639 .01482 L
.3876 .01482 L
.38881 .01482 L
.39002 .01482 L
.39123 .01482 L
.39243 .01482 L
.39364 .01482 L
.39485 .01482 L
.39606 .01482 L
.39727 .01482 L
.39848 .01482 L
.39969 .01482 L
.40089 .01482 L
.4021 .01482 L
.40331 .01482 L
.40452 .01482 L
.40573 .01483 L
.40694 .01483 L
.40815 .01483 L
.40935 .01483 L
.41056 .01483 L
.41177 .01483 L
.41298 .01483 L
.41419 .01483 L
.4154 .01483 L
.41661 .01483 L
.41781 .01483 L
.41902 .01483 L
.42023 .01483 L
.42144 .01483 L
.42265 .01483 L
.42386 .01483 L
.42507 .01483 L
.42628 .01483 L
.42748 .01483 L
.42869 .01483 L
.4299 .01483 L
.43111 .01483 L
.43232 .01483 L
.43353 .01483 L
.43474 .01483 L
.43594 .01483 L
.43715 .01483 L
.43836 .01483 L
.43957 .01483 L
.44078 .01483 L
.44199 .01483 L
.4432 .01483 L
.4444 .01483 L
.44561 .01483 L
Mistroke
.44682 .01483 L
.44803 .01483 L
.44924 .01483 L
.45045 .01483 L
.45166 .01483 L
.45286 .01483 L
.45407 .01483 L
.45528 .01483 L
.45649 .01483 L
.4577 .01483 L
.45891 .01483 L
.46012 .01483 L
.46132 .01483 L
.46253 .01483 L
.46374 .01483 L
.46495 .01483 L
.46616 .01483 L
.46737 .01483 L
.46858 .01483 L
.46978 .01483 L
.47099 .01483 L
.4722 .01483 L
.47341 .01483 L
.47462 .01483 L
.47583 .01483 L
.47704 .01484 L
.47825 .01483 L
.47945 .01484 L
.48066 .01484 L
.48187 .01484 L
.48308 .01484 L
.48429 .01484 L
.4855 .01484 L
.48671 .01485 L
.48791 .01485 L
.48912 .01485 L
.49033 .01486 L
.49154 .01487 L
.49275 .01488 L
.49396 .01491 L
.49517 .01495 L
.49637 .01503 L
.49758 .01527 L
.49879 .01628 L
.5 .60332 L
.50121 .01628 L
.50242 .01527 L
.50363 .01503 L
.50483 .01495 L
.50604 .01491 L
Mistroke
.50725 .01488 L
.50846 .01487 L
.50967 .01486 L
.51088 .01485 L
.51209 .01485 L
.51329 .01485 L
.5145 .01484 L
.51571 .01484 L
.51692 .01484 L
.51813 .01484 L
.51934 .01484 L
.52055 .01484 L
.52175 .01483 L
.52296 .01484 L
.52417 .01483 L
.52538 .01483 L
.52659 .01483 L
.5278 .01483 L
.52901 .01483 L
.53022 .01483 L
.53142 .01483 L
.53263 .01483 L
.53384 .01483 L
.53505 .01483 L
.53626 .01483 L
.53747 .01483 L
.53868 .01483 L
.53988 .01483 L
.54109 .01483 L
.5423 .01483 L
.54351 .01483 L
.54472 .01483 L
.54593 .01483 L
.54714 .01483 L
.54834 .01483 L
.54955 .01483 L
.55076 .01483 L
.55197 .01483 L
.55318 .01483 L
.55439 .01483 L
.5556 .01483 L
.5568 .01483 L
.55801 .01483 L
.55922 .01483 L
.56043 .01483 L
.56164 .01483 L
.56285 .01483 L
.56406 .01483 L
.56526 .01483 L
.56647 .01483 L
Mistroke
.56768 .01483 L
.56889 .01483 L
.5701 .01483 L
.57131 .01483 L
.57252 .01483 L
.57372 .01483 L
.57493 .01483 L
.57614 .01483 L
.57735 .01483 L
.57856 .01483 L
.57977 .01483 L
.58098 .01483 L
.58219 .01483 L
.58339 .01483 L
.5846 .01483 L
.58581 .01483 L
.58702 .01483 L
.58823 .01483 L
.58944 .01483 L
.59065 .01483 L
.59185 .01483 L
.59306 .01483 L
.59427 .01483 L
.59548 .01482 L
.59669 .01482 L
.5979 .01482 L
.59911 .01482 L
.60031 .01482 L
.60152 .01482 L
.60273 .01482 L
.60394 .01482 L
.60515 .01482 L
.60636 .01482 L
.60757 .01482 L
.60877 .01482 L
.60998 .01482 L
.61119 .01482 L
.6124 .01482 L
.61361 .01482 L
.61482 .01482 L
.61603 .01482 L
.61723 .01482 L
.61844 .01482 L
.61965 .01482 L
.62086 .01482 L
.62207 .01482 L
.62328 .01482 L
.62449 .01482 L
.62569 .01482 L
.6269 .01482 L
Mistroke
.62811 .01482 L
.62932 .01482 L
.63053 .01482 L
.63174 .01482 L
.63295 .01482 L
.63416 .01482 L
.63536 .01482 L
.63657 .01482 L
.63778 .01482 L
.63899 .01482 L
.6402 .01482 L
.64141 .01482 L
.64262 .01482 L
.64382 .01482 L
.64503 .01482 L
.64624 .01482 L
.64745 .01482 L
.64866 .01482 L
.64987 .01482 L
.65108 .01482 L
.65228 .01482 L
.65349 .01482 L
.6547 .01482 L
.65591 .01482 L
.65712 .01482 L
.65833 .01482 L
.65954 .01482 L
.66074 .01481 L
.66195 .01481 L
.66316 .01481 L
.66437 .01481 L
.66558 .01481 L
.66679 .01481 L
.668 .01481 L
.6692 .01481 L
.67041 .01481 L
.67162 .01481 L
.67283 .01481 L
.67404 .01481 L
.67525 .01481 L
.67646 .01481 L
.67766 .01481 L
.67887 .01481 L
.68008 .01481 L
.68129 .01481 L
.6825 .01481 L
.68371 .01481 L
.68492 .01481 L
.68613 .01481 L
.68733 .01481 L
Mistroke
.68854 .01481 L
.68975 .01481 L
.69096 .01481 L
.69217 .01481 L
.69338 .01481 L
.69459 .01481 L
.69579 .01481 L
.697 .01481 L
.69821 .01481 L
.69942 .01481 L
.70063 .01481 L
.70184 .01481 L
.70305 .01481 L
.70425 .01481 L
.70546 .01481 L
.70667 .01481 L
.70788 .01481 L
.70909 .0148 L
.7103 .0148 L
.71151 .0148 L
.71271 .0148 L
.71392 .0148 L
.71513 .0148 L
.71634 .0148 L
.71755 .0148 L
.71876 .0148 L
.71997 .0148 L
.72117 .0148 L
.72238 .0148 L
.72359 .0148 L
.7248 .0148 L
.72601 .0148 L
.72722 .0148 L
.72843 .0148 L
.72964 .0148 L
.73084 .0148 L
.73205 .0148 L
.73326 .0148 L
.73447 .0148 L
.73568 .0148 L
.73689 .0148 L
.7381 .0148 L
.7393 .0148 L
.74051 .0148 L
.74172 .0148 L
.74293 .0148 L
.74414 .0148 L
.74535 .0148 L
.74656 .0148 L
.74776 .01479 L
Mistroke
.74897 .01479 L
.75018 .01479 L
.75139 .01479 L
.7526 .01479 L
.75381 .01479 L
.75502 .01479 L
.75622 .01479 L
.75743 .01479 L
.75864 .01479 L
.75985 .01479 L
.76106 .01479 L
.76227 .01479 L
.76348 .01479 L
.76468 .01479 L
.76589 .01479 L
.7671 .01479 L
.76831 .01479 L
.76952 .01479 L
.77073 .01479 L
.77194 .01479 L
.77314 .01479 L
.77435 .01479 L
.77556 .01479 L
.77677 .01479 L
.77798 .01479 L
.77919 .01479 L
.7804 .01479 L
.78161 .01479 L
.78281 .01478 L
.78402 .01478 L
.78523 .01478 L
.78644 .01478 L
.78765 .01478 L
.78886 .01478 L
.79007 .01478 L
.79127 .01478 L
.79248 .01478 L
.79369 .01478 L
.7949 .01478 L
.79611 .01478 L
.79732 .01478 L
.79853 .01478 L
.79973 .01478 L
.80094 .01478 L
.80215 .01478 L
.80336 .01478 L
.80457 .01478 L
.80578 .01478 L
.80699 .01478 L
.80819 .01478 L
Mistroke
.8094 .01478 L
.81061 .01478 L
.81182 .01478 L
.81303 .01478 L
.81424 .01478 L
.81545 .01477 L
.81665 .01477 L
.81786 .01477 L
.81907 .01477 L
.82028 .01477 L
.82149 .01477 L
.8227 .01477 L
.82391 .01477 L
.82511 .01477 L
.82632 .01477 L
.82753 .01477 L
.82874 .01477 L
.82995 .01477 L
.83116 .01477 L
.83237 .01477 L
.83358 .01477 L
.83478 .01477 L
.83599 .01477 L
.8372 .01477 L
.83841 .01477 L
.83962 .01477 L
.84083 .01477 L
.84204 .01477 L
.84324 .01477 L
.84445 .01477 L
.84566 .01476 L
.84687 .01476 L
.84808 .01476 L
.84929 .01476 L
.8505 .01476 L
.8517 .01476 L
.85291 .01476 L
.85412 .01476 L
.85533 .01476 L
.85654 .01476 L
.85775 .01476 L
.85896 .01476 L
.86016 .01476 L
.86137 .01476 L
.86258 .01476 L
.86379 .01476 L
.865 .01476 L
.86621 .01476 L
.86742 .01476 L
.86862 .01476 L
Mistroke
.86983 .01476 L
.87104 .01476 L
.87225 .01476 L
.87346 .01475 L
.87467 .01475 L
.87588 .01475 L
.87708 .01475 L
.87829 .01475 L
.8795 .01475 L
.88071 .01475 L
.88192 .01475 L
.88313 .01475 L
.88434 .01475 L
.88555 .01475 L
.88675 .01475 L
.88796 .01475 L
.88917 .01475 L
.89038 .01475 L
.89159 .01475 L
.8928 .01475 L
.89401 .01475 L
.89521 .01475 L
.89642 .01475 L
.89763 .01475 L
.89884 .01475 L
.90005 .01475 L
.90126 .01474 L
.90247 .01474 L
.90367 .01474 L
.90488 .01474 L
.90609 .01474 L
.9073 .01474 L
.90851 .01474 L
.90972 .01474 L
.91093 .01474 L
.91213 .01474 L
.91334 .01474 L
.91455 .01474 L
.91576 .01474 L
.91697 .01474 L
.91818 .01474 L
.91939 .01474 L
.92059 .01474 L
.9218 .01474 L
.92301 .01474 L
.92422 .01474 L
.92543 .01474 L
.92664 .01473 L
.92785 .01473 L
.92905 .01473 L
Mistroke
.93026 .01473 L
.93147 .01473 L
.93268 .01473 L
.93389 .01473 L
.9351 .01473 L
.93631 .01473 L
.93752 .01473 L
.93872 .01473 L
.93993 .01473 L
.94114 .01473 L
.94235 .01473 L
.94356 .01473 L
.94477 .01473 L
.94598 .01473 L
.94718 .01473 L
.94839 .01473 L
.9496 .01473 L
.95081 .01473 L
.95202 .01472 L
.95323 .01472 L
.95444 .01472 L
.95564 .01472 L
.95685 .01472 L
.95806 .01472 L
.95927 .01472 L
.96048 .01472 L
.96169 .01472 L
.9629 .01472 L
.9641 .01472 L
.96531 .01472 L
.96652 .01472 L
.96773 .01472 L
.96894 .01472 L
.97015 .01472 L
.97136 .01472 L
.97256 .01472 L
.97377 .01472 L
.97498 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[75]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:?ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002Kooooo0_l00004oooo
o`04o`000?ooooooooooooooo`Go0000:_ooool2o`0002gooooo0_l00004ooooo`04o`000?oooooo
ooooooooo`Go00009_ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0001Oooooo000W
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool09?ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0002Wooooo00Co0000oooooooooooo0000:oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0002Gooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`0Fooooo`008?ooool5o`0000;ooooo00Co0000oooooooooooo0000
1oooool5o`0001kooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool0:Oooool01?l0003oooooooooool0000[ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool09Oooool01?l0003oooooooooool00007ooooo`Go00005oooool002Oooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool0000Vooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool0000[ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool09?ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0001Sooooo000Wooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
9_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000:Oooool01?l0
003oooooooooool0000[ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00000Uooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000006?ooool002Oooooo
00Co0000oooooooooooo00002Oooool2o`0002Kooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000002Wooooo00Co0000oooooooooooo0000:oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000009Oooool01?l0003oooooooooool00009oooo
o`;o00006?ooool002Sooooo0_l0000;ooooo`03o`000?oooooooooo02Gooooo0_l00009ooooo`?o
0000:oooool2o`0002gooooo0_l00009ooooo`?o00009oooool2o`0000_ooooo00?o0000oooooooo
ool05_ooool001kooooo00?o0000ooooooooool0ooooool001kooooo00?o0000ooooooooool0oooo
ool001kooooo00?o0000ooooooooool0ooooool001kooooo00?o0000ooooooooool0ooooool001So
oooo1_l0003bool000Ko00002_ooool001kooooo1Ol00009ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool2ool000cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`07ooooo`Go00004?ooool001kooooo00Co0000oooooooooooooooo2_l00003ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0EOooool2ool005Oooooo00?o0000ooooooooool0
3?ooool2o`0000;ooooo2_l0000Dooooo`007_ooool00ol0003oooooooooo`0:ooooo`Ko00003Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02cooooo0_oo000^ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool02oooool6o`0001gooooo000Nooooo`03o`000?oooooo
oooo00kooooo0_l0000=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0/ooooo`;oo`00;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool02oooool2o`00027ooooo000Nooooo`03o`000?oooooooooo
00kooooo0_l0000=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0/ooooo`;oo`00;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool02oooool2o`00027ooooo000Nooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool01oooool2o`0002kooooo0_oo000^ooooo`;o00002Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool2o`00027o
oooo000Nooooo`;o00004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`;o0000;_ooool2ool002kooooo
0_l00009ooooo`;o00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool08?ooool001kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool01Ol0003ooooooooo
oooooooo000000Wooooo0_l0000^ooooo`;oo`00;_ooool2o`0000Wooooo0_l00002ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Oooooo00Go0000oooooooooooo
ooooo`000009ooooo`;o00000oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Co
oooo0_oo0006ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooooooo0_l00009oooo
o`;o00000_ooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000009ooooo`;o00000ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo0_oo0006ooooo`03o`000?oo
oooooooo027ooooo00Co0000oooooooooooooooo0_l00009ooooo`;o00000_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Wooooo0_l00003oooo
o`03o`000?oooooooooo023ooooo0_l00006ooooo`;oo`001_ooool2o`0002;ooooo00Co0000oooo
oooooooooooo0_l00009ooooo`;o00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo027ooooo000Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Wooooo0_l00003ooooo`03o`000?oooooooooo023ooooo
0_l00006ooooo`;oo`001_ooool2o`0002;ooooo00Co0000oooooooooooooooo0_l00009ooooo`;o
00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo000Nooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000Wooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2
o`0000Kooooo0_oo0006ooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`04o`000?oooooo
ooooooooo`;o00002Oooool2o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0;ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Qooooo`007_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo
00Go0000ooooooooooooooooo`000009ooooo`;o00000oooool2o`0000Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool2o`0000Kooooo0_oo0006ooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`;o
00000oooool2o`0000Wooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool08Oooool001kooooo0_l0000Aooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000002Oooool2o`0000?ooooo0_l0
0008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`;oo`001_ooool2o`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool2o`0000?ooooo0_l00009ooooo`;o00000_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Qooooo`00
7_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000Wooooo0_l00003ooooo`;o00001_ooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o00001_oo
ool2ool000Kooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Kooooo0_l00003ooooo`;o00002Ooo
ool2o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Rooooo`007_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01Ol0
003oooooo`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`05o`000?oooooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000Wooooo
0_l00003ooooo`;o00000_ooool01ol0003ooooooooooooooooo0000ooooool000001Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`00
00Kooooo0_oo0006ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_l00003oooo
o`;o00002Oooool2o`0000;ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo0000ooooool0
00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo02;ooooo000Nooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002oooo
o`05o`000?oooooo0000ooooool000000oooool2o`0000Cooooo00?o0000ooooooooool00_ooool0
1Ol0003oooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oo
oooo0_l00003ooooo`;o00000_ooool01ol0003ooooooooooooooooo0000ooooool000001Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`;o00001_ooool2
ool000Kooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo0_l00007
ooooo`04o`000?oooooo0000o`0000;ooooo00So0000oooooooooooo0000ooooool0003oooooo`00
00Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00Go0000ooooool0003oooooo`000002
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool08_ooool001kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00So
0000ooooool0003oooooo`000?oooooo0000ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`05o`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool00000
1oooool2o`0000?ooooo0_l00002ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo0_l0
0003ooooo`;o00001_ooool2ool000Kooooo0_l00003ooooo`?o00001Oooool01?l0003ooooooooo
ool00003ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000?ooooo00?o0000
ooooooooool00_l00003ooooo`;o00001oooool01?l0003oooooo`000?l00002ooooo`08o`000?oo
ooooooooo`000?oooooo0000ooooool00004ooooo`03o`000?oooooooooo00;ooooo0_l000002?oo
oooo0000ooooool0003oooooo`000?oooooo00000_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00002ooooo`08o`000?oooooo0000ooooool0003oooooo`000?oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;ooooo
00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo0_l00003ooooo`;o00000_ooool02Ol0
003ooooooooooooooooo0000ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0000Kooooo0_oo0006ooooo`;o
00000oooool3o`0000Gooooo00Co0000oooooooooooo00000oooool02Ol0003ooooooooooooooooo
0000ooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool2o`0000Oooooo
00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`03o`000003ooooool0003ooooo00?o
oooo00?o0000ooooooooool00_ooool2o`000008ooooool0003oooooo`000?oooooo0000ooooool0
0002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool08_ooool001kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`;o000000coooooo`000?oooooooooo
o`000?oooooo0000ooooool0003oooooo`000?ooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool01Ol0003oooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00Oooooo0_l00003ooooo`;o00000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003ooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`;o00000oooool2o`0000Kooooo0_oo0006ooooo`;o00000oooool3o`0000?ooooo00?o0000oooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Wo0000ooooool0003oooooo`00
0?oooooo0000ooooool000000_ooool2o`0000?ooooo0_l00007ooooo`04o`000?oooooo0000o`00
00;ooooo00?o0000ooooooooool00ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo
00;ooooo0_l000002?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool01?l0003ooooo
o`000?l00005ooooo`03o`000?oooooooooo02;ooooo000Nooooo`;o00004_ooool00ol0003ooooo
ooooo`03ooooo`;o000000coooooo`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`00
0?ooool2o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`05o`000?oooooo0000
ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000001oooool2o`0000?ooooo
0_l00002ooooo`03o`000?oooooo000000;o000000Soooooo`000?oooooo0000ooooool0003ooooo
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooooooool2o`0000?ooooo
0ol00005ooooo`;oo`001_ooool2o`0000?ooooo0ol00002ooooo`;o000000Goooooo`000?oooooo
ooooo`000003ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00ol000001?oooooo
0000ooooooooool2o`0000?ooooo0_l00007ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000
ooooooooool00ol000000ooooooo0000ooooo`02ooooo`;o00000_ooool03?l0003oooooo`000?l0
003oooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00Co0000ooooool0003o00001Ooo
ool00ol0003oooooooooo`0Rooooo`007_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00?ooooo0_l000003?oooooo0000oooooooooooo0000ooooool0003oooooo`000?oooooo0000
ooooo`Co00000_ooool00ol0003oooooo`000002ooooo`05o`000?oooooo0000ooooool000000_oo
ool01ol0003ooooooooooooooooo0000ooooool000001oooool3o`0000;ooooo0_l00002ooooo`03
o`000?oooooo000000;o000000coooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo0_l00002ooooo`Co00001Oooool2ool0
00Kooooo0ol00002ooooo`?o00000_ooool2o`000005ooooool0003oooooooooool000000_ooool2
o`000007ooooool0003o0000o`000?oooooo0000ooooo`03o`000004ooooool0003oooooooooo`;o
00000_ooool3o`0000Oooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`03o`00
0003ooooool0003ooooo00;ooooo0_l00002ooooo`Co000000Soooooo`000?oooooo0000ooooool0
003oooooo`0000;ooooo00Co0000ooooool0003o00001Oooool00ol0003oooooooooo`0Rooooo`00
7_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo0_l000003?oooooo0000
o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooo`Co00000_ooool00ol0003ooooo
o`000002ooooo`05o`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000
ooooool000001oooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`00000<ooooool0
003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool01?l0003ooooooooo
ool00003ooooo`;o00000_ooool4o`0000Gooooo0_oo0006ooooo`?o00000_ooool3o`0000;ooooo
0_l000001Ooooooo0000oooooooooooo000000;ooooo0_l000001ooooooo0000o`000?l0003ooooo
o`000?ooool00ol000000ooooooo0000ooooo`03o`0000;ooooo0ol00007ooooo`04o`000?oooooo
0000o`0000;ooooo00?o0000ooooooooool00ol000000ooooooo0000ooooo`02ooooo`;o00000_oo
ool4o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o000000?oooooo`00
0?l000001Oooool00ol0003oooooooooo`0Rooooo`007_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00?ooooo0_l000003?oooooo0000o`000?oooooo0000ooooool0003oooooo`00
0?oooooo0000ooooo`Co00000_ooool02ol0003oooooo`000?l0003oooooo`000?oooooo0000oooo
ool0003ooooo00;o00000oooool00ol0003oooooo`000007ooooo`?o00000_ooool2o`000004oooo
ool0003o0000ooooo`?o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00ol0
0002ooooo`04o`000?ooooooooooo`0000?ooooo0_l00002ooooo`Co00001Oooool2ool000Kooooo
0ol00002ooooo`?o00000_ooool2o`000006ooooool0003oooooooooool0003ooooo0ol000001ooo
oooo0000o`000?l0003oooooo`000?ooool00ol000000ooooooo0000ooooo`03o`0000;ooooo0ol0
0007ooooo`04o`000?oooooo0000o`0000;ooooo0_l000002Ooooooo0000o`000?l0003oooooo`00
0?oooooo0000ooooo`02o`0000;ooooo1?l000002Ooooooo0000ooooool0003oooooo`000?oooooo
0000ooooo`02o`000003ooooool0003o000000Gooooo00?o0000ooooooooool08_ooool001kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`;o000000coooooo`000?l0003o
ooooo`000?oooooo0000ooooool0003oooooo`000?ooool4o`0000;ooooo00_o0000ooooool0003o
0000ooooool0003oooooo`000?oooooo0000ooooo`02o`0000?ooooo00?o0000ooooool000001ooo
ool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`000009ooooool0003oooooo`000?oo
oooo0000ooooool0003ooooo00Co000000Goooooo`000?ooooooooooo`000003ooooo`;o00000_oo
ool4o`0000Gooooo0_oo0006ooooo`?o00000_ooool3o`0000;ooooo0_l000000ooooooo0000oooo
o`02o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000ooooo`03o`000003oooo
ool0003ooooo00?o00000_ooool3o`0000Oooooo00Co0000ooooool0003o00000_ooool2o`000007
ooooool0003o0000o`000?oooooo0000ooooo`04o`0000;ooooo1_l000001Ooooooo0000ooooool0
003ooooo00Co000000?oooooo`000?l000001Oooool00ol0003oooooooooo`0Rooooo`002oooool2
o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool00oooool2o`000008ooooool0003o0000ooooool0003oooooo`000?ooool3o`00
0003ooooool0003o000000;o00000_ooool01Ol0003oooooo`000?l0003ooooo00?o000000?ooooo
o`000?ooool00_l00003ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooool000000_l0
0002ooooo`;o000000Coooooo`000?l0003ooooo0ol000002Ooooooo0000ooooool0003oooooo`00
0?oooooo0000ooooo`04o`000004ooooool0003oooooooooo`;o00000_ooool2o`0000;ooooo1?l0
0005ooooo`;oo`001Oooool4o`0000;ooooo0ol000001ooooooo0000o`000?l0003oooooo`000?oo
ool00_l000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?ooool00ol000000ooo
oooo0000ooooo`03o`0000;ooooo0ol000000ooooooo0000ooooo`04ooooo`04o`000?oooooo0000
o`0000;ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00000_ooool6
o`000005ooooool0003oooooo`000?ooool01?l000000ooooooo0000o`000005ooooo`03o`000?oo
oooooooo02;ooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo0_l000002?oooooo0000
o`000?oooooo0000ooooool0003ooooo0ol000000ooooooo0000o`000002o`0000;ooooo00Go0000
ooooool0003o0000ooooo`05o`000003ooooool0003o000000?ooooo00?o0000ooooool000000_l0
0003ooooo`Go00000_ooool2o`000004ooooool0003o0000ooooo`?o000000Woooooo`000?l0003o
0000ooooool0003oooooo`000?ooool01?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0
0002ooooo`Co00001Oooool2ool000Gooooo1?l00002ooooo`?o000000?oooooo`000?l000000ol0
00001?oooooo0000o`000?ooool3o`000003ooooool0003o000000?o000000Goooooo`000?l0003o
0000ooooo`05o`0000;ooooo1Ol00003ooooo`04o`000?oooooo0000ooooo`;o00000_ooool2o`00
0003ooooool0003o000000So00000_ooool6o`000005ooooool0003oooooo`000?ooool01?l00000
0ooooooo0000o`000005ooooo`03o`000?oooooooooo02;ooooo000:ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00?ooooo0_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo0ol000000ooooooo
0000o`000002o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000ol000000ooo
oooo0000o`000003ooooo`Go000000?oooooo`000?ooool01_l000001?oooooo0000o`000?ooool6
o`000009ooooool0003o0000o`000?oooooo0000ooooool0003ooooo00Co000000Coooooo`000?l0
003ooooo0_l00002ooooo`;o00000_ooool4o`0000Gooooo0_oo0005ooooo`Co00000_ooool3o`00
0003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000003
o`000003ooooool0003o000000Oo000000?oooooo`000?l000001?l000001Ooooooo0000ooooool0
003ooooo00Co00000_ooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000001?l0
00001Ooooooo0000ooooool0003ooooo00Co000000?oooooo`000?l000001Oooool00ol0003ooooo
ooooo`0Rooooo`002_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo
0ol0000Aooooo`03o`000?oooooooooo00?ooooo0_l000002?oooooo0000o`000?oooooo0000oooo
ool0003ooooo0ol000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000002o`000003ooooool0003o000000?o000000?o
ooooo`000?ooool01_l000001?oooooo0000o`000?ooool6o`000009ooooool0003o0000o`000?oo
oooo0000ooooool0003ooooo00Co000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`00
0?l00002ooooo`Co00001Oooool2ool000Gooooo1?l00002ooooo`Wo000000Coooooo`000?l0003o
oooo0ol000000ooooooo0000o`000003o`000003ooooool0003o000000Oo000000?oooooo`000?l0
00001?l000001Ooooooo0000ooooool0003ooooo00So000000?oooooo`000?l000002Ol000000ooo
oooo0000o`000004o`000005ooooool0003oooooo`000?ooool01?l000000ooooooo0000o`000005
ooooo`03o`000?oooooooooo02;ooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00ooo
ool2o`000008ooooool0003o0000ooooool0003oooooo`000?ooool3o`000003ooooool0003o0000
00;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o
000000So000000?oooooo`000?ooool01_l000001?oooooo0000o`000?ooool6o`000009ooooool0
003o0000o`000?oooooo0000ooooool0003ooooo00Co000000Coooooo`000?l0003ooooo0_l00000
1?oooooo0000o`000?l00002ooooo`Co00001Oooool2ool000Gooooo1?l00002ooooo`Wo000000Co
ooooo`000?l0003ooooo0ol000000ooooooo0000o`000003o`000003ooooool0003o000000Oo0000
00?oooooo`000?l000001?l000001Ooooooo0000ooooool0003ooooo00So000000?oooooo`000?l0
00002Ol000000ooooooo0000o`000004o`000005ooooool0003oooooo`000?ooool01?l000000ooo
oooo0000o`000005ooooo`03o`000?oooooooooo02;ooooo000:ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00_ooool2o`000008ooooool0003o0000ooooool0003oooooo`000?ooool3o`000003
ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003o`00
0003ooooool0003o000000So000000?oooooo`000?ooool01_l000001?oooooo0000o`000?ooool6
o`000009ooooool0003o0000o`000?oooooo0000ooooool0003ooooo00Co000000Coooooo`000?l0
003ooooo0_l000001?oooooo0000o`000?l00002ooooo`Co00001Oooool2ool000Gooooo1?l00002
ooooo`Wo000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000003o`000003ooooool0
003o000000Oo000000?oooooo`000?l000001?l000001Ooooooo0000ooooool0003ooooo00So0000
00?oooooo`000?l000002Ol000000ooooooo0000o`000004o`000005ooooool0003oooooo`000?oo
ool01?l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo02;ooooo000;ooooo`;o0000
2Oooool3o`0000Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`;o0000
00Soooooo`000?l0003oooooo`000?oooooo0000ooooo`?o000000?oooooo`000?l000000_l00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000002?l0
00000ooooooo0000ooooo`06o`000004ooooool0003o0000ooooo`Ko000000Woooooo`000?l0003o
0000ooooool0003oooooo`000?ooool01ol000001?oooooo0000o`000?ooool4o`000003ooooool0
003o000000;o00001Oooool2ool000Gooooo1?l000000ooooooo0000o`00000;o`000005ooooool0
003o0000o`000?ooool01Ol000000ooooooo0000o`000007o`000003ooooool0003o000000Co0000
00Goooooo`000?oooooo0000ooooo`08o`000003ooooool0003o000000Wo000000?oooooo`000?l0
00001?l000001Ooooooo0000ooooool0003ooooo00Co000000?oooooo`000?l000001Oooool00ol0
003oooooooooo`0Rooooo`007_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;o
oooo0_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo0ol000000ooooooo0000o`00
0002o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000
o`000008o`000003ooooool0003ooooo00Ko000000Coooooo`000?l0003ooooo1_l000000ooooooo
0000o`000003o`000003ooooool0003ooooo00Oo000000Coooooo`000?l0003ooooo1?l000000ooo
oooo0000o`000002o`0000;ooooo00?o0000ooooooooool00_oo0003ooooo`03o`000?oooooo0000
00?o000000?oooooo`000?l000002ol000001Ooooooo0000o`000?l0003ooooo00Go000000?ooooo
o`000?l000001ol000000ooooooo0000o`000004o`000005ooooool0003oooooo`000?ooool02?l0
00000ooooooo0000o`000009o`000003ooooool0003o000000Co000000Goooooo`000?oooooo0000
ooooo`04o`000003ooooool0003o000000Gooooo00?o0000ooooooooool08_ooool001kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`;o000000Soooooo`000?l0003ooooo
o`000?oooooo0000ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`00
0003ooooool0003o000000?o000000?oooooo`000?l000002?l000000ooooooo0000ooooo`06o`00
0004ooooool0003o0000ooooo`Ko000000?oooooo`000?l000001Ol000000ooooooo0000o`000005
o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_l00002ooooo`03o`000?oo
oooooooo00;oo`000oooool00ol0003oooooo`000003o`000003ooooool0003o000000_o000000?o
ooooo`000?l000001ol000000ooooooo0000o`000007o`000003ooooool0003o000000Co000000Go
ooooo`000?oooooo0000ooooo`08o`000003ooooool0003o000000Wo000000?oooooo`000?l00000
1?l000001Ooooooo0000ooooool0003ooooo00Co000000?oooooo`000?l000001Oooool00ol0003o
ooooooooo`0Rooooo`007_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo
0_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo0ol000000ooooooo0000o`000002
o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol000000ooooooo0000o`000008
o`000003ooooool0003ooooo00Ko000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00
0005o`000003ooooool0003o000000Go000000Coooooo`000?l0003ooooo1?l000000ooooooo0000
o`000002o`000003ooooool0003o000000;ooooo0_oo0003ooooo`03o`000?oooooo000000?o0000
00?oooooo`000?l000002ol000000ooooooo0000o`000007o`000003ooooool0003o000000Oo0000
00?oooooo`000?l000001?l000001Ooooooo0000ooooool0003ooooo00So000000?oooooo`000?l0
00002Ol000000ooooooo0000o`000004o`000005ooooool0003oooooo`000?ooool01?l000000ooo
oooo0000o`000005ooooo`03o`000?oooooooooo02;ooooo000Nooooo`;o00004oooool00ol0003o
ooooooooo`02ooooo`;o000000Soooooo`000?l0003oooooo`000?oooooo0000ooooo`?o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000009o`000003ooooool0003o000000[o000000?o
ooooo`000?l000001?l000001?oooooo0000o`000?ooool6o`000003ooooool0003o000000Go0000
00?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000;o
000000?oooooo`000?l000000_ooool2ool000?ooooo00?o0000ooooool000000ol000000ooooooo
0000o`00000;o`000003ooooool0003o000000Oo000000?oooooo`000?l000001ol000000ooooooo
0000o`000004o`000003ooooool0003o000000[o000000?oooooo`000?l000002Ol000000ooooooo
0000o`000004o`000005ooooool0003oooooo`000?ooool01?l000000ooooooo0000o`000005oooo
o`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00_ooool2o`000008ooooool0003o0000ooooool0003oooooo`000?ooool3o`000003ooooool0
003o000000;o000000?oooooo`000?l000002Ol000000ooooooo0000o`00000:o`000003ooooool0
003o000000Oo000000?oooooo`000?l000001?l000000ooooooo0000o`000005o`000003ooooool0
003o000000Go000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002o`000005oooo
ool0003o0000ooooool000000_oo00001Ol0003oooooooooool0003ooooo00Co000000?oooooo`00
0?l000002ol000000ooooooo0000o`000007o`000003ooooool0003o000000ko000000?oooooo`00
0?l000002_l000000ooooooo0000o`000009o`000003ooooool0003o000000Co000000Goooooo`00
0?oooooo0000ooooo`04o`000003ooooool0003o000000Gooooo00?o0000ooooooooool08_ooool0
01kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`;o000000Soooooo`00
0?l0003oooooo`000?oooooo0000ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000
o`000009o`000003ooooool0003o000001Co000000?oooooo`000?l000003?l000000ooooooo0000
o`000005o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_l000001Ooooooo
0000o`000?oooooo000000;oo`0000Go0000oooooooooooo0000ooooo`04o`000003ooooool0003o
000000_o000000?oooooo`000?l000009Ol000000ooooooo0000o`000009o`000003ooooool0003o
000000Co000000Goooooo`000?oooooo0000ooooo`04o`000003ooooool0003o000000Gooooo00?o
0000ooooooooool08_ooool001kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02
ooooo`;o000000Soooooo`000?l0003oooooo`000?oooooo0000ooooo`?o000000?oooooo`000?l0
00003_l000000ooooooo0000o`00000Do`000003ooooool0003o000000co000000?oooooo`000?l0
00001Ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000;o000000Goooooo`00
0?l0003oooooo`000002ool00005o`000?oooooo0000o`000?ooool01?l000000ooooooo0000o`00
000;o`000003ooooool0003o000002Go000000?oooooo`000?l000004?l000001Ooooooo0000oooo
ool0003ooooo00Co000000?oooooo`000?l000001?ooool00ol0003oooooooooo`0Sooooo`007_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo0_l000001_oooooo0000o`00
0?oooooo0000ooooo`Go000000?oooooo`000?l000009Ol000000ooooooo0000o`00000<o`000003
ooooool0003o000000Go000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002o`00
0005ooooool0003o0000ooooool000000_oo00001Ol0003oooooo`000?l0003ooooo00Co000000?o
ooooo`000?l000002ol000000ooooooo0000o`00000ho`000005ooooool0003o0000o`000?ooool0
1?l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo02?ooooo000Nooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool00_ooool2o`000006ooooool0003o0000ooooool0003o
oooo1Ol000000ooooooo0000o`00000Uo`000003ooooool0003o000000co000000?oooooo`000?l0
00001Ol000000ooooooo0000o`00000=o`000006ooooool0003oo`00ool00?l0003ooooo5Ol00000
0ooooooo0000o`00000ho`000005ooooool0003o0000o`000?ooool01?l000000ooooooo0000o`00
0004ooooo`03o`000?oooooooooo02?ooooo000Nooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00_ooool2o`000006ooooool0003o0000ooooool0003ooooo1Ol000000ooooooo0000
o`00000Uo`000003ooooool0003o000000co000000?oooooo`000?l000001Ol000000ooooooo0000
o`00000=o`000006ooooool0003oo`00ool00?l0003oooooD?l000001Ooooooo0000o`000?l0003o
oooo00Co000000?oooooo`000?l000001?ooool00ol0003oooooooooo`0Sooooo`007_ooool2o`00
01?ooooo00?o0000ooooooooool00_ooool2o`000006ooooool0003o0000ooooool0003ooooo1Ol0
00000ooooooo0000o`00000Uo`000003ooooool0003o000000co000000?oooooo`000?l000001Ol0
00000ooooooo0000o`00000=o`000006ooooool0003oo`00ool00?l0003oooooD?l000001Ooooooo
0000o`000?l0003ooooo00Co000000?oooooo`000?l000001?ooool00ol0003oooooooooo`0Soooo
o`007_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo0_l000001_oooooo
0000o`000?oooooo0000ooooo`Go000000?oooooo`000?l00000??l000000ooooooo0000o`00000=
o`000006ooooool0003oo`00ool00?l0003oooooD?l000001Ooooooo0000o`000?l0003ooooo00Co
000000?oooooo`000?l000001?ooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00;ooooo0_l000001_oooooo0000o`000?oooooo0000oooo
o`Go000000?oooooo`000?l00000<?l000000ooooooo0000o`000009o`000003ooooool0003o0000
00go000000Koooooo`000?oo003oo`00o`000?oooom@o`000005ooooool0003o0000o`000?ooool0
1?l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo02?ooooo000Nooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool00_ooool2o`000006ooooool0003o0000ooooool0003o
oooo1Ol000000ooooooo0000o`00000`o`000003ooooool0003o000000Wo000000?oooooo`000?l0
00003Ol000001_oooooo0000ool00?oo003o0000oooooe3o000000Goooooo`000?l0003o0000oooo
o`04o`000003ooooool0003o000000Cooooo00?o0000ooooooooool08oooool001kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`02ooooo`;o000000Koooooo`000?l0003oooooo`00
0?ooool5o`000003ooooool0003o0000033o000000?oooooo`000?l000004_l000000ooooooo0000
o`000004o`000006ooooool0003oo`00ool00?l0003ooooo1_l000000ooooooo0000o`000017o`00
0005ooooool0003o0000o`000?ooool01?l000000ooooooo0000o`000004ooooo`03o`000?oooooo
oooo02?ooooo000Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool2o`00
0006ooooool0003o0000ooooool0003ooooo1Ol000000ooooooo0000o`00000`o`000003ooooool0
003o000001;o000000?oooooo`000?l000001Ol000001?ooooooo`00ool00?ooool7o`000003oooo
ool0003o000004Oo000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000000Co
oooo00?o0000ooooooooool08oooool001kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`02ooooo`;o000000Koooooo`000?l0003oooooo`000?ooool5o`000003ooooool0003o0000
02_o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Bo`000003ooooool0003o0000
00Go000000Coooooool00?oo003ooooo1ol000000ooooooo0000o`00000Go`000003ooooool0003o
000000Go000000?oooooo`000?l000009Ol000001Ooooooo0000o`000?l0003ooooo00Co000000?o
ooooo`000?l000001?ooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00;ooooo0_l000001_oooooo0000o`000?oooooo0000oooooc?o0000
00?oooooo`000?l000000_l000000ooooooo0000o`00000Bo`000003ooooool0003o000000Go0000
00Coooooool00?oo003ooooo1ol000000ooooooo0000o`00000Go`000003ooooool0003o000000Go
000000?oooooo`000?l000009Ol000001Ooooooo0000o`000?l0003ooooo00Co000000?oooooo`00
0?l000001?ooool00ol0003oooooooooo`0Sooooo`007_ooool2o`0001?ooooo00?o0000oooooooo
ool00_ooool2o`000004ooooool0003o0000ooooocGo000000?oooooo`000?l000000_l000000ooo
oooo0000o`00000Bo`000004ooooool0003o0000ooooo`Co000000Coooooool00?oo003ooooo1?l0
00001?oooooo0000o`000?oooolDo`000003ooooool0003o000000;o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`00000Uo`000005ooooool0003o0000o`000?ooool01?l000000ooooooo
0000o`000004ooooo`03o`000?oooooooooo02?ooooo000Nooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooocGo000000?oooooo`000?l0
00000_l000000ooooooo0000o`00000@o`000003ooooool0003ooooo00;o000000Koooooo`000?l0
003oooooo`000?ooool2ool00003ooooool0003o000000;o000000Coooooo`000?l0003ooooo5?l0
00000ooooooo0000o`000002o`000003ooooool0003o000000Go000000?oooooo`000?l000009Ol0
00001Ooooooo0000o`000?l0003ooooo00Co000000?oooooo`000?l000001?ooool00ol0003ooooo
ooooo`0Sooooo`007_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo0_l0
00001?oooooo0000o`000?ooooleo`000003ooooool0003o000000;o000000?oooooo`000?l00000
4?l000000ooooooo0000ooooo`02o`000006ooooool0003o0000ooooool0003ooooo0_oo00000ooo
oooo0000o`000002o`000004ooooool0003o0000oooooaCo000000?oooooo`000?l000000_l00000
0ooooooo0000o`000005o`000003ooooool0003o000002Go000000Goooooo`000?l0003o0000oooo
o`04o`000003ooooool0003o000000Cooooo00?o0000ooooooooool08oooool001kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?l0003ooooo=Ol0
00000ooooooo0000o`000002o`000003ooooool0003o0000013o000000?oooooo`000?ooool00_l0
00001_oooooo0000o`000?oooooo0000ooooo`;oo`0000?oooooo`000?l000000_l000001?oooooo
0000o`000?oooolDo`000006ooooool0003o0000ooooool0003ooooo1ol000000ooooooo0000o`00
000Uo`000005ooooool0003o0000o`000?ooool01?l000000ooooooo0000o`000004ooooo`03o`00
0?oooooooooo02?ooooo000Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_oo
ool2o`000004ooooool0003o0000ooooocGo000000?oooooo`000?l000000_l000000ooooooo0000
o`000005o`000003ooooool0003o000000Go000000Koooooo`000?l0003oooooo`000?ooool2o`00
0006ooooool0003o0000ooooool0003ooooo0_oo00000ooooooo0000o`000002o`000004ooooool0
003o0000ooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000o`000005o`000006oooo
ool0003o0000ooooool0003ooooo1ol000000ooooooo0000o`00000Uo`000005ooooool0003o0000
o`000?ooool01?l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo02?ooooo000;oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000o`000?ooool[o`000003ooooool0003o
000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000003ooooool0003o
000000Go000000?oooooo`000?l000001Ol000001_oooooo0000o`000?oooooo0000ooooo`;o0000
00Koooooo`000?l0003oooooo`000?ooool2ool00003ooooool0003o000000;o000000Coooooo`00
0?l0003ooooo1?l000000ooooooo0000o`000005o`000003ooooool0003o000000Go000000Kooooo
o`000?l0003oooooo`000?ooool7o`000003ooooool0003o000002Wo000000?oooooo`000?l00000
0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo02?ooooo000:ooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00;ooooo0_l000001?oooooo0000o`000?oooolMo`000005ooooool0003oooooo`00
0?ooool02Ol000000ooooooo0000o`000002o`000003ooooool0003ooooo00;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000005o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000ooooo`02o`000006ooooool0003o0000ooooool0003ooooo
0_oo00000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Co000000Coooooo`000?l0
003ooooo1?l000000ooooooo0000o`000005o`000006ooooool0003o0000ooooool0003ooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000Wo000000Goooooo`000?oooooo0000
ooooo`06o`000003ooooool0003o000001;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000004ooooo`03o`000?oooooooooo02?ooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo
1Ol00004ooooo`?o00004_ooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?l0003o
oooo1_l000000ooooooo0000o`00000Do`000005ooooool0003oooooo`000?ooool02Ol000000ooo
oooo0000o`000002o`000003ooooool0003ooooo00;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000005o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000ooooo`02o`000006ooooool0003oooooooooool0003ooooo0_oo00001_oooooo0000
o`000?oooooo0000ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool4
o`000003ooooool0003o000000Go000000Koooooo`000?l0003oooooo`000?ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000002Ol000001Ooooooo0000ooooool0003ooooo00Ko
000000?oooooo`000?l000003Ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o
000000?oooooo`000?l000001?ooool00ol0003oooooooooo`0Sooooo`002_ooool01?l0003ooooo
ooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`02ooooo`;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000D
o`000005ooooool0003oooooo`000?ooool02Ol000000ooooooo0000o`000002o`000003ooooool0
003ooooo00;o000000?oooooo`000?l000000_l000000ooooooo0000o`000005o`000003ooooool0
003o000000;o000000Goooooo`000?l0003oooooo`000002ooooo`06o`000?oooooo0000o`000?oo
oooo00001?ooool2ool000Cooooo00Go0000ooooool0003o0000ooooo`02o`000003ooooool0003o
oooo00;o000000?oooooo`000?l000000_l000000ooooooo0000o`000005o`000006ooooool0003o
0000ooooool0003ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Co0000
00?oooooo`000?l000000_l000001Ooooooo0000ooooool0003ooooo00Ko000000?oooooo`000?l0
00003Ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o000000?oooooo`000?l0
00001?ooool00ol0003oooooooooo`0Sooooo`002_ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`;o
000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000Do`000005ooooool0003ooooo
o`000?ooool02Ol000000ooooooo0000o`000002o`000003ooooool0003ooooo00;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Co000000Go
ooooo`000?l0003oooooo`000002ooooo`06o`000?oooooo0000o`000?oooooo00001?ooool2ool0
00Cooooo00Go0000ooooool0003o0000ooooo`02o`000003ooooool0003ooooo00;o000000?ooooo
o`000?l000000_l000001?oooooo0000o`000?ooool4o`000006ooooool0003o0000ooooool0003o
oooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Co000000?oooooo`000?l0
00000_l000001Ooooooo0000ooooool0003ooooo00;o000000Goooooo`000?l0003o0000ooooo`0?
o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004
ooooo`03o`000?oooooooooo02?ooooo000:ooooo`04o`000?ooooooooooo`0000Wooooo0_l00005
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003o
0000ooooo`Ko000000?oooooo`000?l000005?l000001Ooooooo0000ooooool0003ooooo00Wo0000
00?oooooo`000?l000000_l000000ooooooo0000ooooo`02o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000_l000001?oooooo0000o`000?ooool4o`000005ooooool0003ooooooooo
ool000000_ooool01_l0003oooooo`000?l0003oooooo`0000Cooooo0_oo0004ooooo`05o`000?oo
oooo0000o`000?ooool00_l000001_oooooo0000oooooooooooo0000ooooo`Co000000Coooooo`00
0?l0003ooooo1?l000001_oooooo0000o`000?oooooo0000ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`000004o`000003ooooool0003o000000;o000000Goooooo`000?oooooo
0000ooooo`02o`000005ooooool0003o0000o`000?ooool03ol000000ooooooo0000o`000002o`00
0003ooooool0003o000000;o000000?oooooo`000?l000001?ooool00ol0003oooooooooo`0Soooo
o`002oooool2o`0000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`04
o`000?ooooooooooooooo`;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000D
o`000005ooooool0003oooooo`000?ooool02Ol000000ooooooo0000o`000002o`000003ooooool0
003ooooo00;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000004ooooool0
003o0000ooooo`Co000000Goooooo`000?ooooooooooo`000002ooooo`06o`000?oooooo0000o`00
0?oooooo00001?ooool2ool000Cooooo00Ko0000ooooool0003o0000ooooool00002ooooo`05o`00
0?ooooooooooo`000?ooool01?l000001?oooooo0000o`000?ooool4o`000006ooooool0003o0000
ooooool0003ooooo0_l000000ooooooo0000ooooo`02o`000003ooooool0003o000000Co000000?o
ooooo`000?l000000_l000001Ooooooo0000ooooool0003ooooo00;o000000Goooooo`000?l0003o
0000ooooo`0:o`000003ooooool0003o000000;o000000?oooooo`000?ooool00_l000000ooooooo
0000o`000002o`000003ooooool0003o000000Cooooo00?o0000ooooooooool08oooool001kooooo
00?o0000ooooooooool04oooool01?l0003oooooooooooooool2o`000004ooooool0003o0000oooo
o`Ko000000?oooooo`000?l000001Ol000000ooooooo0000o`00000<o`000005ooooool0003ooooo
o`000?ooool00_l000000ooooooo0000o`000004o`000003ooooool0003o000000;o000000Kooooo
o`000?ooooooooooo`000?ooool4o`000003ooooool0003o000000;o000000Coooooo`000?l0003o
oooo1?l000001Ooooooo0000oooooooooooo000000;ooooo00Ko0000ooooool0003o0000ooooool0
0004ooooo`;oo`001?ooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00Go0000oooooooo
oooo0000ooooo`04o`000004ooooool0003o0000ooooo`Co000000Ooooooo`000?l0003oooooo`00
0?oooooo000000;ooooo00Go0000ooooool0003o0000ooooo`06o`000003ooooool0003o000000;o
000000Goooooo`000?oooooo0000ooooo`02o`000005ooooool0003o0000o`000?ooool02_l00000
0ooooooo0000o`000002o`000003ooooool0003ooooo00;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000004ooooo`03o`000?oooooooooo02?ooooo000Nooooo`03o`000?oooooooooo
01?ooooo00Co0000oooooooooooooooo0_l000001?oooooo0000o`000?ooool6o`000003ooooool0
003o000000Go000000?oooooo`000?l000001ol000000ooooooo0000o`000002o`000006ooooool0
003oooooo`000?oooooo00000_ooool6o`000003ooooool0003o000000;o000000Koooooo`000?oo
ooooooooo`000?ooool4o`000003ooooool0003o000000;o00000_ooool02?l0003oooooo`000?l0
003oooooo`000?oooooo00000_ooool01Ol0003oooooooooool0003ooooo00;o000000?oooooo`00
0?ooool00oooool2ool000Cooooo00Ko0000ooooool0003o0000ooooool00002ooooo`07o`000?oo
ooooooooo`000?oooooo0000ooooo`02o`000004ooooool0003oooooooooo`Co000000Ooooooo`00
0?l0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003o0000ooooo`06o`00000:oooo
ool0003o0000ooooool0003oooooo`000?oooooo0000ooooo`;o000000Goooooo`000?oooooo0000
ooooo`0:o`000003ooooool0003o000000;o000000?oooooo`000?ooool00_l000000ooooooo0000
o`000002o`000003ooooool0003o000000Cooooo00?o0000ooooooooool08oooool001kooooo00?o
0000ooooooooool04oooool01?l0003oooooooooooooool2o`000004ooooool0003o0000ooooo`Ko
000000?oooooo`000?l000001Ol000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`00
0?l000000_l000001_oooooo0000ooooool0003oooooo`0000;ooooo1_l000000ooooooo0000o`00
0002o`000006ooooool0003oooooooooool0003ooooo1?l000000ooooooo0000o`000002o`0000;o
oooo00So0000ooooool0003o0000ooooool0003oooooo`0000;ooooo00Go0000oooooooooooo0000
ooooo`02o`000003ooooool0003ooooo00?ooooo0_oo0004ooooo`06o`000?oooooo0000o`000?oo
oooo00000_ooool01ol0003oooooooooool0003oooooo`000?ooool00_l000001?oooooo0000oooo
ooooool2o`000003ooooool0003ooooo00;o000000Coooooo`000?oooooo00000_ooool01Ol0003o
ooooo`000?l0003ooooo00Ko000000[oooooo`000?l0003oooooo`000?oooooo0000ooooool0003o
oooo0_l000001Ooooooo0000ooooool0003ooooo00?o000000?oooooo`000?l000001?l000000ooo
oooo0000o`000002o`000003ooooool0003ooooo00;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000004ooooo`03o`000?oooooooooo02?ooooo000Nooooo`;o00005?ooool01?l0003o
ooooooooooooool2o`000004ooooool0003o0000ooooo`Ko000000?oooooo`000?l000001Ol00000
1Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`000?l000000_l000001_oooooo0000oooo
ool0003oooooo`0000;ooooo1_l000000ooooooo0000o`000002o`000006ooooool0003ooooooooo
ool0003ooooo1?l000000ooooooo0000o`000002o`0000;ooooo00So0000ooooool0003o0000oooo
ool0003oooooo`0000;ooooo00Go0000oooooooooooo0000ooooo`02o`000003ooooool0003ooooo
00?ooooo0_oo0004ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool01ol0003ooooooooo
ool0003oooooo`000?ooool00_l000001?oooooo0000ooooooooool2o`000003ooooool0003ooooo
00;o000000Coooooo`000?oooooo00000_ooool01Ol0003oooooo`000?l0003ooooo00Ko000000[o
ooooo`000?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l000001Ooooooo0000ooooool0
003ooooo00?o000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`000003ooooool0
003ooooo00;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`03o`000?oo
oooooooo02?ooooo000Nooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooooooo0_l0
00001?oooooo0000o`000?ooool6o`000003ooooool0003o000000Go000000Goooooo`000?l0003o
0000ooooo`05o`000003ooooool0003o000000;o000000Koooooo`000?oooooo0000ooooool00002
ooooo`Ko000000?oooooo`000?l000000_l000001_oooooo0000oooooooooooo0000ooooo`Co0000
00?oooooo`000?l000000_l00002ooooo`08o`000?oooooo0000o`000?oooooo0000ooooool00002
ooooo`05o`000?ooooooooooo`000?ooool00_l000000ooooooo0000ooooo`03ooooo`;oo`001?oo
ool01_l0003oooooooooool0003oooooo`0000;ooooo00Oo0000oooooooooooo0000ooooool0003o
oooo00;o000000Coooooo`000?oooooooooo0_l000000ooooooo0000ooooo`02o`000004ooooool0
003oooooo`0000;ooooo00Go0000ooooool0003o0000ooooo`06o`00000:ooooool0003o0000oooo
ool0003oooooo`000?oooooo0000ooooo`;o000000Goooooo`000?oooooo0000ooooo`03o`000003
ooooool0003o000000Co000000?oooooo`000?l000000_l000000ooooooo0000ooooo`02o`000003
ooooool0003o000000;o000000?oooooo`000?l000001?ooool00ol0003oooooooooo`0Sooooo`00
7_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooooooo`;o000000Goooooo`000?l0
003o0000ooooo`05o`000003ooooool0003o000000Go000000Goooooo`000?l0003o0000ooooo`05
o`000003ooooool0003o000000;o000000Koooooo`000?oooooo0000ooooool00002ooooo`Ko0000
00?oooooo`000?l000000_l000001_oooooo0000oooooooooooo0000ooooo`Co000000?oooooo`00
0?l000000_l00002ooooo`08o`000?oooooo0000o`000?oooooo0000ooooool00002ooooo`05o`00
0?ooooooooooo`000?ooool00_l000000ooooooo0000ooooo`03ooooo`;oo`001?ooool01_l0003o
ooooooooool0003oooooo`0000;ooooo00Oo0000oooooooooooo0000ooooool0003ooooo00;o0000
00Coooooo`000?oooooooooo0_l000000ooooooo0000ooooo`02o`000004ooooool0003oooooo`00
00;ooooo00Go0000ooooool0003o0000ooooo`06o`00000:ooooool0003o0000ooooool0003ooooo
o`000?oooooo0000ooooo`;o000000Goooooo`000?oooooo0000ooooo`03o`000003ooooool0003o
000000Co000000?oooooo`000?l000000_l000000ooooooo0000ooooo`02o`000003ooooool0003o
000000;o000000?oooooo`000?l000001?ooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0
003oooooooooo`0Cooooo`04o`000?ooooooooooooooo`;o000000Ooooooo`000?l0003o0000oooo
ool0003ooooo00?o000000?oooooo`000?l000001Ol000001Ooooooo0000o`000?l0003ooooo00Go
000000?oooooo`000?l000000_l000001_oooooo0000ooooool0003oooooo`0000;ooooo1_l00000
0ooooooo0000o`000002o`000006ooooool0003oooooooooool0003ooooo1?l000000ooooooo0000
o`000002o`0000;ooooo00So0000ooooool0003o0000ooooool0003oooooo`0000;ooooo00?o0000
ooooooooool00_ooool2o`000003ooooool0003ooooo00?ooooo0_oo0004ooooo`04o`000?oooooo
ooooo`0000Cooooo00Oo0000oooooooooooo0000ooooool0003ooooo00;o000000Coooooo`000?oo
oooooooo0_l000000ooooooo0000ooooo`02o`000004ooooool0003oooooo`0000;ooooo00Go0000
ooooool0003o0000ooooo`06o`00000:ooooool0003o0000ooooool0003oooooo`000?oooooo0000
ooooo`;o000000Goooooo`000?oooooo0000ooooo`03o`000003ooooool0003o000000Co000000?o
ooooo`000?l000000_l000001Ooooooo0000ooooool0003ooooo00Go000000?oooooo`000?l00000
0oooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`0Cooooo`04o`000?oo
ooooooooooooo`;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00?o000000?oooooo`00
0?l000001Ol000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`000?l000000_l00000
1_oooooo0000ooooool0003oooooo`0000;ooooo1_l000000ooooooo0000o`000002o`000006oooo
ool0003oooooooooool0003ooooo1?l000000ooooooo0000o`000002o`0000;ooooo00So0000oooo
ool0003o0000ooooool0003oooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`000003oooo
ool0003ooooo00?ooooo0_oo0004ooooo`04o`000?ooooooooooo`0000Cooooo00Oo0000oooooooo
oooo0000ooooool0003ooooo00;o000000Coooooo`000?oooooooooo0_l000000ooooooo0000oooo
o`02o`000004ooooool0003oooooo`0000;ooooo00Go0000ooooool0003o0000ooooo`06o`00000:
ooooool0003o0000ooooool0003oooooo`000?oooooo0000ooooo`;o000000Goooooo`000?oooooo
0000ooooo`03o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l000001Ooooooo
0000ooooool0003ooooo00Go000000?oooooo`000?l000000oooool00ol0003oooooooooo`0Toooo
o`007_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooooooo`;o000000Ooooooo`00
0?l0003o0000ooooool0003ooooo00?o000000?oooooo`000?l000001Ol000001Ooooooo0000o`00
0?l0003ooooo00Go000000?oooooo`000?l000000_l000001_oooooo0000ooooool0003oooooo`00
00;ooooo1_l000001?oooooo0000o`000?l00002ooooo`05o`000?ooooooooooo`000?ooool01?l0
00000ooooooo0000o`000002o`0000;ooooo00So0000ooooool0003o0000ooooool0003oooooo`00
00;ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003ooooo00?ooooo0_oo0004oooo
o`04o`000?ooooooooooo`0000Cooooo00Oo0000oooooooooooo0000ooooool0003ooooo00;o0000
00Coooooo`000?oooooooooo0_l000000ooooooo0000ooooo`02o`000004ooooool0003oooooo`00
00;ooooo00Go0000oooooooooooo0000ooooo`06o`00000:ooooool0003o0000ooooool0003ooooo
o`000?oooooo0000ooooo`;o000000Goooooo`000?oooooo0000ooooo`03o`000003ooooool0003o
000000Co000000?oooooo`000?l000000_l000001Ooooooo0000ooooool0003ooooo00Go000000?o
ooooo`000?l000000oooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`0C
ooooo`04o`000?ooooooooooooooo`;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00?o
000000?oooooo`000?l000001Ol000001Ooooooo0000o`000?l0003ooooo00Go000000_oooooo`00
0?l0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`Ko000000Coooooo`000?l0
003o00000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000ooooool0003o0000
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
0_ooool2o`000003ooooool0003ooooo00?ooooo0_oo0004ooooo`04o`000?ooooooooooo`0000Co
oooo00Ko0000oooooooooooo0000ooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000000_ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooo`000?ooool01_l0
00002ooooooo0000o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000
ooooool0003ooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o000000;o000000Go
ooooo`000?oooooo0000ooooo`05o`000003ooooool0003o000000?ooooo00?o0000ooooooooool0
9?ooool001kooooo0_l0000Dooooo`04o`000?ooooooooooooooo`;o000000Ooooooo`000?l0003o
0000ooooool0003ooooo00?o000000?oooooo`000?l000001Ol000001Ooooooo0000o`000?l0003o
oooo00Go000000_oooooo`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`000002oooo
o`Ko000000Coooooo`000?l0003o00000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo
00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo0_l00006ooooo`;oo`001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;o
oooo00Go0000oooooooooooo0000ooooo`06o`00000;ooooool0003o0000ooooool0003oooooo`00
0?oooooo0000ooooool000000_ooool01?l0003oooooo`000?ooool3o`000003ooooool0003o0000
00Co000000?oooooo`000?l000000_l000001Ooooooo0000ooooool0003ooooo00Go000000?ooooo
o`000?l000000oooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`0Coooo
o`04o`000?ooooooooooooooo`;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00?o0000
00?oooooo`000?l000001Ol000001Ooooooo0000o`000?l0003ooooo00Go000000_oooooo`000?l0
003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`Ko000000Coooooo`000?l0003o
00000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000ooooool0003o00001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`03ool00?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`05o`000?oo
ooooooooo`000?ooool01_l000002ooooooo0000o`000?oooooo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00Co0000ooooool0003ooooo0ol000000ooooooo0000o`000004o`000003oooo
ool0003o000000;o000000Goooooo`000?oooooo0000ooooo`05o`000004ooooool0003oooooo`00
00;ooooo00?o0000ooooooooool09?ooool001kooooo00?o0000ooooooooool04oooool01?l0003o
ooooooooooooool2o`000007ooooool0003o0000o`000?oooooo0000ooooo`03o`000003ooooool0
003o000000Go000000Goooooo`000?l0003o0000ooooo`05o`00000;ooooool0003o0000ooooool0
003oooooo`000?oooooo0000ooooool000000_ooool00ol0003oooooo`000002o`0000?ooooo0_l0
0002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooo`000?l0000>oooo
o`03o`000?oooooooooo00;ooooo0_l00007ooooo`03ool00?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ool000000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo0ol00002ooooo`09o`000?oo
oooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003ooooo0ol00000
0ooooooo0000o`000004o`000003ooooool0003o000000;o000000Ooooooo`000?oooooo0000oooo
ool0003ooooo00?o000000Coooooo`000?oooooo00000_ooool00ol0003oooooooooo`0Tooooo`00
7_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooooooo`;o000000Ooooooo`000?l0
003o0000ooooool0003ooooo00?o000000?oooooo`000?l000001Ol000001ooooooo0000o`000?l0
003oooooo`000?ooool00ol000002ooooooo0000o`000?oooooo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00?o0000ooooool000000_l00003ooooo`;o00000_ooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo00?o0000ooooool000003oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`06
o`000?ooooooooooo`000?oooooo00000_ooool3o`0000;ooooo00Wo0000ooooool0003oooooo`00
0?oooooo0000ooooool000000_ooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo1_l0
00000ooooooo0000o`000002o`000007ooooool0003oooooo`000?oooooo0000ooooo`03o`000004
ooooool0003oooooo`0000;ooooo00?o0000ooooooooool09?ooool001kooooo00?o0000oooooooo
ool04oooool01?l0003oooooooooooooool2o`000007ooooool0003o0000o`000?oooooo0000oooo
o`03o`000003ooooool0003o000000Go000000?oooooo`000?l000000_ooool00ol0003ooooooooo
o`02o`00000;ooooool0003o0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool0
0ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooool000003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
o`00ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooool000001?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo
0_l00003ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo1Ol000000ooooooo0000o`000002o`000007oooo
ool0003oooooo`000?oooooo0000ooooo`03o`000004ooooool0003oooooo`0000;ooooo00?o0000
ooooooooool09?ooool001kooooo00?o0000ooooooooool04oooool01?l0003oooooooooooooool2
o`000007ooooool0003o0000o`000?oooooo0000ooooo`03o`000003ooooool0003o000000Co0000
0_ooool2o`0000;ooooo00?o0000ooooooooool00_l000002ooooooo0000o`000?oooooo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000000oooool03Ol0003ooooooooooooooooo0000ooooool0003ooooo
o`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_oo
ool3o`000003ooooool0003ooooo00Co000000Ooooooo`000?oooooo0000ooooool0003ooooo00?o
000000Coooooo`000?oooooo00000_ooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooooooo`;o000000Ooooooo`000?l0003o0000ooooool0
003ooooo00?o000000?oooooo`000?l000001?l00002ooooo`;o00000_ooool01_l0003ooooooooo
oooooooo0000ooooo`;o000000Soooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool2o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooo`00000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool03Ol0
003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo00?o000000?oooooo`000?ooool01?l000001ooo
oooo0000ooooool0003oooooo`000?ooool00ol000001?oooooo0000ooooool00002ooooo`03o`00
0?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooooooo
0_l000001ooooooo0000o`000?l0003oooooo`000?ooool00ol000000ooooooo0000o`000004o`00
00;ooooo0_l00002ooooo`06o`000?ooooooooooooooool0003ooooo0_l000000ooooooo0000oooo
o`02ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000000oooool02Ol0003ooooooooooooooooo0000ooooool0003ooooo
o`000003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`03o`00
0003ooooool0003ooooo00Co000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000Go
ooooo`000?l0003oooooo`000002ooooo`03o`000?oooooooooo02Cooooo000Nooooo`;o00005?oo
ool01?l0003oooooooooooooool2o`000007ooooool0003o0000o`000?oooooo0000ooooo`03o`00
0003ooooool0003o000000Co00000_ooool2o`0000;ooooo00Ko0000ooooooooooooooooo`000?oo
ool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooool000000_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00008ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000?ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00?o000000?oooooo`00
0?ooool01?l000001ooooooo0000ooooool0003oooooo`000?ooool00_l000001Ooooooo0000o`00
0?oooooo000000;ooooo00?o0000ooooooooool09?ooool001kooooo00?o0000ooooooooool04ooo
ool01?l0003oooooooooooooool2o`000007ooooool0003o0000o`000?oooooo0000ooooo`03o`00
0003ooooool0003o000000Co00000_ooool2o`0000;ooooo00Ko0000ooooooooooooooooo`000?oo
ool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`09ooooo`04o`000?ooooooooooo`0001Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Dooooo`04o`000?ooooooooooo`0000cooooo00Go0000ooooool0003oooooo`000003oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`03o`000003ooooool0
003ooooo00Co000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000Goooooo`000?l0
003oooooo`000002ooooo`03o`000?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo01?o
oooo00Co0000oooooooooooooooo0_l000001ooooooo0000o`000?l0003oooooo`000?ooool00ol0
00000ooooooo0000o`000004o`0000;ooooo0_l00002ooooo`06o`000?ooooooooooooooool0003o
oooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool02Oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00Gooooo00?oo`00oooo
ooooool01Oooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0000cooooo00Go0000
ooooool0003oooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooooooo`03o`000003ooooool0003ooooo00Co000000Ooooooo`000?oooooo0000ooooool0003o
oooo00;o000000Goooooo`000?l0003oooooo`000002ooooo`03o`000?oooooooooo02Cooooo000N
ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooooooo0_l000002ooooooo0000o`00
0?l0003oooooo`000?oooooo0000ooooool0003ooooo00Go00000oooool2o`0000;ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000Tooooo`03ool00?oooooo
oooo027ooooo00Co0000oooooooooooo00003?ooool01Ol0003oooooo`000?oooooo000000?ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00?o00000oooool4o`00
0007ooooool0003oooooo`000?oooooo0000ooooo`02o`000005ooooool0003o0000ooooool00000
0_ooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`0Cooooo`04o`000?oo
ooooooooooooo`;o000000_oooooo`000?l0003o0000ooooool0003oooooo`000?oooooo0000oooo
o`05o`0000?ooooo0_l00002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`07
o`000?ooooooooooooooool0003oooooo`000002ooooo`03o`000?oooooooooo00Wooooo00Co0000
oooooooooooo00009?ooool00ooo003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000cooooo
00Go0000ooooool0003oooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`03o`0000?ooooo1?l000001ooooooo0000ooooool0003oooooo`000?ooool0
0_l000001Ooooooo0000o`000?oooooo000000;ooooo00?o0000ooooooooool09?ooool000_ooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo
00Co0000oooooooooooooooo0_l000002ooooooo0000o`000?l0003oooooo`000?oooooo0000oooo
ool0003ooooo00Go00000oooool2o`0000;ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool08_ooool00ooo003o
ooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooool000000oooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo00?o00000oooool4o`000007ooooool0003ooooo
o`000?oooooo0000ooooo`02o`000005ooooool0003o0000ooooool000000_ooool00ol0003ooooo
ooooo`0Tooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooooooo`;o000000_oooooo`00
0?l0003o0000ooooool0003oooooo`000?oooooo0000ooooo`05o`0000?ooooo0_l00002ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool08Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03
o`0000?ooooo1?l000001ooooooo0000ooooool0003oooooo`000?ooool00_l000001Ooooooo0000
o`000?oooooo000000;ooooo00?o0000ooooooooool09?ooool000[ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Cooooo0ol0000Cooooo`04o`000?oooooooooo
ooooo`;o000000_oooooo`000?l0003o0000ooooool0003oooooo`000?oooooo0000ooooo`05o`00
00?ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000??ooool0
0ooo003oooooooooo`0iooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_l0
0004ooooo`Co000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000Goooooo`000?l0
003oooooo`000002ooooo`03o`000?oooooooooo02Cooooo000:ooooo`04o`000?ooooooooooo`00
00Oooooo1?l00005ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooooooo0_l00000
2ooooooo0000o`000?l0003oooooo`000?oooooo0000ooooool0003ooooo00Co00001?ooool2o`00
00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000looooo`03ool00?oooooo
oooo03Wooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02o`0000Cooooo1?l0
00001ooooooo0000ooooool0003oooooo`000?ooool00_l000001Ooooooo0000o`000?oooooo0000
00;ooooo00?o0000ooooooooool09?ooool000[ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooooooo0_l00000
2ooooooo0000o`000?l0003oooooo`000?oooooo0000ooooool0003ooooo00Co00001?ooool2o`00
00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000looooo`03ool00?oooooo
oooo03Wooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02o`0000Cooooo1?l0
00001ooooooo0000ooooool0003oooooo`000?ooool00_l000001Ooooooo0000o`000?oooooo0000
00;ooooo00?o0000ooooooooool09?ooool000[ooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooooooo0_l00000
2ooooooo0000o`000?l0003oooooo`000?oooooo0000ooooool0003ooooo00Co00001?ooool2o`00
00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo
03Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02o`0000Cooooo1?l000001ooo
oooo0000ooooool0003oooooo`000?ooool00_l000001Ooooooo0000o`000?oooooo000000;ooooo
00?o0000ooooooooool09?ooool000_ooooo0_l0000:ooooo`;o00001Oooool00ol0003ooooooooo
o`0Cooooo`04o`000?ooooooooooooooo`;o000000_oooooo`000?l0003o0000ooooool0003ooooo
o`000?oooooo0000ooooo`04o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0>_ooool00ooo003oooooooooo`0iooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_l00004ooooo`Co000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o
000000Goooooo`000?l0003oooooo`000002ooooo`03o`000?oooooooooo02Cooooo000Nooooo`03
o`000?oooooooooo01?ooooo00Ko0000ooooooooooooooooo`000?ooool4o`000009ooooool0003o
ooooo`000?oooooo0000ooooool0003ooooo00;o00001?ooool2o`0000_ooooo00?o0000oooooooo
ool0>_ooool00ooo003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo0_l00004ooooo`;o
000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l000001Ooooooo0000o`00
0?oooooo000000;ooooo00?o0000ooooooooool09?ooool001kooooo00?o0000ooooooooool04ooo
ool01_l0003ooooooooooooooooo0000ooooo`Co000000[oooooo`000?oooooo0000ooooool0003o
ooooo`000?oooooo00001Oooool2o`0000_ooooo00?o0000ooooooooool0>_ooool00ooo003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Wooooo0_l00005ooooo`0:o`000?oooooo0000ooooool0
003oooooo`000?oooooo0000ooooo`;o000000Goooooo`000?l0003oooooo`000002ooooo`03o`00
0?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo01?ooooo00Ko0000oooooooooooooooo
o`000?ooool4o`00000:ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`0000Gooooo
00?o0000ooooooooool0Aoooool00ooo003oooooooooo`16ooooo`03o`000?oooooooooo00?ooooo
00[o0000ooooool0003oooooo`000?oooooo0000ooooool0003ooooo0_l000001Ooooooo0000o`00
0?oooooo000000;ooooo00?o0000ooooooooool09?ooool001kooooo0_l0000Dooooo`06o`000?oo
ooooooooooooool0003ooooo0_l000003?oooooo0000ooooool0003oooooo`000?oooooo0000oooo
ool0003oooooo`0004oooooo00?oo`00ooooooooool0C?ooool02ol0003oooooo`000?oooooo0000
ooooool0003oooooo`000?oooooo000000;ooooo0_l000001Ooooooo0000oooooooooooo000002Ko
oooo000Nooooo`03o`000?oooooooooo01?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
00?ooooo00Oo0000ooooool0003oooooo`000?oooooo0000057ooooo00?oo`00ooooooooool0C_oo
ool01ol0003oooooo`000?oooooo0000ooooool000001?ooool2o`000005ooooool0003ooooooooo
ool000009_ooool001kooooo00?o0000ooooooooool04oooool01_l0003ooooooooooooooooo0000
ooooo`;o00000oooool01ol0003oooooo`000?oooooo0000ooooool00000DOooool00ooo003ooooo
ooooo`1>ooooo`07o`000?oooooo0000ooooool0003oooooo`000004ooooo`;o000000Goooooo`00
0?ooooooooooo`00000Vooooo`007_ooool00ol0003oooooooooo`0Cooooo`06o`000?oooooooooo
ooooool0003ooooo0_l00003ooooo`05o`000?oooooo0000ooooool00000Doooool00ooo003ooooo
ooooo`1@ooooo`05o`000?oooooo0000ooooool000001?ooool2o`000005ooooool0003ooooooooo
ool000009_ooool001kooooo00?o0000ooooooooool04oooool01_l0003ooooooooooooooooo0000
ooooo`;o00000oooool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo05Cooooo00?o0000
ooooooooool00_ooool2o`000005ooooool0003oooooooooool000009_ooool001kooooo00?o0000
ooooooooool04oooool01_l0003ooooooooooooooooo0000ooooo`;o00000oooool00ol0003ooooo
ooooo`1Eooooo`03ool00?oooooooooo05Cooooo00?o0000ooooooooool00_ooool2o`000005oooo
ool0003oooooooooool000009_ooool001kooooo00?o0000ooooooooool04oooool01_l0003ooooo
oooooooooooo0000ooooo`;o00000oooool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo
05Cooooo00?o0000ooooooooool00_ooool2o`000005ooooool0003oooooooooool000009_ooool0
01kooooo0_l0000Dooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`03o`000?oooooo
oooo05Gooooo00?oo`00ooooooooool0E?ooool00ol0003oooooooooo`02ooooo`;o000000Gooooo
o`000?ooooooooooo`00000Vooooo`007_ooool00ol0003oooooooooo`0Cooooo`04o`000?oooooo
ooooo`0000;ooooo0_l00003ooooo`03o`000?oooooooooo05Gooooo00?oo`00ooooooooool0E?oo
ool00ol0003oooooooooo`02ooooo`;o000000Goooooo`000?ooooooooooo`00000Vooooo`007_oo
ool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`03o`00
0?oooooooooo05Gooooo00?oo`00ooooooooool0E?ooool00ol0003oooooooooo`02ooooo`;o0000
00Goooooo`000?ooooooooooo`00000Vooooo`007_ooool00ol0003oooooooooo`0Cooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`1Iooooo`;o
000000Goooooo`000?ooooooooooo`00000Vooooo`007_ooool00ol0003oooooooooo`0Cooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`1Ioooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool09?ooool001kooooo00?o0000oooo
ooooool04oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo05[ooooo00?oo`00
ooooooooool0FOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02Cooooo000N
ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`1Jooooo`03ool00?oooooooooo05Wooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0Tooooo`007_ooool2o`0001Gooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`1Jooooo`03ool00?oooooooooo05Wooooo00Ko0000oooooooooooo0000ooooool0000Wooooo`00
7_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
F_ooool00ooo003oooooooooo`1Iooooo`06o`000?ooooooooooo`000?oooooo00009oooool001ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo05[o
oooo00?oo`00ooooooooool0FOooool01_l0003oooooooooool0003oooooo`0002Oooooo000Noooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`1Joooo
o`03ool00?oooooooooo05Wooooo00Ko0000oooooooooooo0000ooooool0000Wooooo`007_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0F_ooool0
0ooo003oooooooooo`1Iooooo`06o`000?ooooooooooo`000?oooooo00009oooool000_ooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`1Jooooo`03ool00?oooooooooo05Wooooo00Ko
0000oooooooooooo0000ooooool0000Wooooo`002_ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`1Iooooo`06o`000?oooooooooo
o`000?oooooo00009oooool000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00001Oooooo`03ool0
0?oooooooooo05cooooo00?o0000ooooool000009oooool000[ooooo00Co0000oooooooooooo0000
2?ooool3o`0000Gooooo0ol0000Dooooo`03o`000?oooooo000005oooooo00?oo`00ooooooooool0
G?ooool00ol0003oooooo`00000Wooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo000005oo
oooo00?oo`00ooooooooool0G?ooool00ol0003oooooo`00000Wooooo`002_ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooo000005oooooo00?oo`00ooooooooool0G?ooool00ol0003oooooo`00000Woooo
o`002oooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooool0
0000Goooool00ooo003oooooooooo`1Looooo`03o`000?oooooo000002Oooooo000Nooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooool00000Goooool00ooo003oooooooooo`1Looooo`03o`00
0?oooooo000002Oooooo000Nooooo`03o`000?oooooooooo01Cooooo00?o0000ooooool00000Gooo
ool00ooo003oooooooooo`1Looooo`03o`000?oooooo000002Oooooo000Nooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooool00000Goooool00ooo003oooooooooo`1Looooo`03o`000?oooooo
000002Oooooo000Nooooo`;o00005Oooool00ol0003oooooo`00001Oooooo`03ool00?oooooooooo
05cooooo00?o0000ooooool000009oooool001kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooo`00001Oooooo`03ool00?oooooooooo05cooooo00?o0000ooooool000009oooool001kooooo
00?o0000ooooooooool05?ooool00ol0003oooooo`00001Oooooo`03ool00?oooooooooo05cooooo
00?o0000ooooool000009oooool001kooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00
001Oooooo`03ool00?oooooooooo05cooooo00?o0000ooooool000009oooool001kooooo00?o0000
ooooooooool05?ooool00ol0003oooooo`00001Oooooo`03ool00?oooooooooo05cooooo00?o0000
ooooool000009oooool001kooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00001Ooooo
o`03ool00?oooooooooo05cooooo00?o0000ooooool000009oooool001kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooo`00001Oooooo`03ool00?oooooooooo05cooooo00?o0000ooooool0
00009oooool001kooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00001Oooooo`03ool0
0?oooooooooo05cooooo00?o0000ooooool000009oooool001kooooo0_l0000Eooooo`03o`000?oo
oooo000005oooooo00?oo`00ooooooooool0G?ooool00ol0003oooooo`00000Wooooo`007_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooo000005oooooo00?oo`00ooooooooool0G?ooool0
0ol0003oooooo`00000Wooooo`007_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo0000
05oooooo00?oo`00ooooooooool0GOooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooool00000Goooool00ooo003oooooooooo`1Mooooo`;o00009oooool001kooooo
00?o0000ooooooooool05?ooool00ol0003oooooo`00001Oooooo`03ool00?oooooooooo05gooooo
0_l0000Wooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000Goooool00ooo003ooooooooo
o`1Mooooo`03o`000?oooooooooo02Kooooo000Nooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0G_ooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo02Kooooo000Noooo
o`;o00005_ooool00ol0003oooooooooo`1Nooooo`03ool00?oooooooooo05gooooo00?o0000oooo
ooooool09_ooool001kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03
ool00?oooooooooo05gooooo00?o0000ooooooooool09_ooool001kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1Nooooo`03ool00?oooooooooo05gooooo00?o0000ooooooooool0
9_ooool001kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03ool00?oo
oooooooo05gooooo00?o0000ooooooooool09_ooool001kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1Nooooo`03ool00?oooooooooo05gooooo00?o0000ooooooooool09_ooool0
01Kooooo0ol00005ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool00ooo
003oooooooooo`1Mooooo`03o`000?oooooooooo02Kooooo000Gooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`03ool00?oooooooooo05go
oooo00?o0000ooooooooool09_ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo05kooooo00?oo`00ooooooooool0GOooool00ol0003ooooo
ooooo`0Vooooo`005oooool00ol0003oooooooooo`04ooooo`?o00005Oooool00ol0003ooooooooo
o`1Nooooo`03ool00?oooooooooo05gooooo00?o0000ooooooooool09_ooool001Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooo`005_ooool2o`0000Kooooo00?o0000oooo
ooooool0ooooool001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00I?ooool3o`0002gooooo0ol00029oooo
o`00IOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo08Sooooo000jooooo`?o0000
1?ooool3o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Wo
oooo0ol00003ooooo`?o00000_ooool3o`0000Cooooo0ol00003ooooo`Co00000_ooool4o`0000Oo
oooo0_l000000ooooooo0000o`000002o`000004ooooool0003oooooo`0000;ooooo0ol00002oooo
o`Go000000?oooooo`000?l000000ol00003ooooo`;o00001?ooool2o`000003ooooool0003ooooo
00Co00000_ooool3o`0000Sooooo0ol00005ooooo`;o000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?ooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000;ooooo0ol00000
0ooooooo0000o`00000/ooooo`00>oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00002?ooool02ol0003ooooooooooooooooo0000ooooool0
003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooo
ooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000]ooooo`00>oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo1Ol00002ooooo`?o00000_ooool01?l0003oooooooooool0
0008ooooo`Go000000Koooooo`000?oooooo0000ooooool00002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo00Go00002?oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo
0000ooooool00006ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0:oooool003_ooooo0ol00002
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool02_ooool2o`0000?ooooo00Co0000oooooooooooo
00000_ooool2o`0000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000;ooooo00Go
0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Ko0000oooooooo
oooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01_oo
ool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0[ooooo`00>oooool01?l0003ooooooooo
ool00002ooooo`?o00000_ooool3o`0000?ooooo1?l00002ooooo`Co00002Oooool00ol0003ooooo
ooooo`02ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo0ol00003ooooo`;o0000
1?ooool3o`0000Wooooo00?o0000ooooool000000_ooool2o`000004ooooool0003oooooooooo`Co
00001?ooool01?l0003oooooooooooooool3o`0000?ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000000_ooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo0_l000001?oo
oooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co00000_ooool3o`0000Cooooo0ol00002
ooooo`Co0000;_ooool003_ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`09
ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0=ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0@?ooool003[ooooo1?l0
000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool3o`0001_ooooo0_l0
0009ooooo`;o00003oooool3o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0:ooooo`;o00003_ooool5o`0001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0iooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.5688, -0.0816948, \
0.00376515, 0.00671634}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 1.05007 0.309076 0.0937521 [
[.07997 .29658 -12 -9 ]
[.07997 .29658 12 0 ]
[.28999 .29658 -12 -9 ]
[.28999 .29658 12 0 ]
[.5 .29658 -3 -9 ]
[.5 .29658 3 0 ]
[.71001 .29658 -9 -9 ]
[.71001 .29658 9 0 ]
[.92003 .29658 -9 -9 ]
[.92003 .29658 9 0 ]
[.01131 .02782 -12 -4.5 ]
[.01131 .02782 0 4.5 ]
[.01131 .12157 -12 -4.5 ]
[.01131 .12157 0 4.5 ]
[.01131 .21532 -12 -4.5 ]
[.01131 .21532 0 4.5 ]
[.01131 .40283 -6 -4.5 ]
[.01131 .40283 0 4.5 ]
[.01131 .49658 -6 -4.5 ]
[.01131 .49658 0 4.5 ]
[.01131 .59033 -6 -4.5 ]
[.01131 .59033 0 4.5 ]
[.5 .63053 -81 0 ]
[.5 .63053 81 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07997 .30908 m
.07997 .31533 L
s
[(-0.4)] .07997 .29658 0 1 Mshowa
.28999 .30908 m
.28999 .31533 L
s
[(-0.2)] .28999 .29658 0 1 Mshowa
.5 .30908 m
.5 .31533 L
s
[(0)] .5 .29658 0 1 Mshowa
.71001 .30908 m
.71001 .31533 L
s
[(0.2)] .71001 .29658 0 1 Mshowa
.92003 .30908 m
.92003 .31533 L
s
[(0.4)] .92003 .29658 0 1 Mshowa
.125 Mabswid
.13247 .30908 m
.13247 .31283 L
s
.18498 .30908 m
.18498 .31283 L
s
.23748 .30908 m
.23748 .31283 L
s
.34249 .30908 m
.34249 .31283 L
s
.39499 .30908 m
.39499 .31283 L
s
.4475 .30908 m
.4475 .31283 L
s
.5525 .30908 m
.5525 .31283 L
s
.60501 .30908 m
.60501 .31283 L
s
.65751 .30908 m
.65751 .31283 L
s
.76252 .30908 m
.76252 .31283 L
s
.81502 .30908 m
.81502 .31283 L
s
.86753 .30908 m
.86753 .31283 L
s
.02747 .30908 m
.02747 .31283 L
s
.97253 .30908 m
.97253 .31283 L
s
.25 Mabswid
0 .30908 m
1 .30908 L
s
.02381 .02782 m
.03006 .02782 L
s
[(-3)] .01131 .02782 1 0 Mshowa
.02381 .12157 m
.03006 .12157 L
s
[(-2)] .01131 .12157 1 0 Mshowa
.02381 .21532 m
.03006 .21532 L
s
[(-1)] .01131 .21532 1 0 Mshowa
.02381 .40283 m
.03006 .40283 L
s
[(1)] .01131 .40283 1 0 Mshowa
.02381 .49658 m
.03006 .49658 L
s
[(2)] .01131 .49658 1 0 Mshowa
.02381 .59033 m
.03006 .59033 L
s
[(3)] .01131 .59033 1 0 Mshowa
.125 Mabswid
.02381 .04657 m
.02756 .04657 L
s
.02381 .06532 m
.02756 .06532 L
s
.02381 .08407 m
.02756 .08407 L
s
.02381 .10282 m
.02756 .10282 L
s
.02381 .14032 m
.02756 .14032 L
s
.02381 .15907 m
.02756 .15907 L
s
.02381 .17782 m
.02756 .17782 L
s
.02381 .19657 m
.02756 .19657 L
s
.02381 .23407 m
.02756 .23407 L
s
.02381 .25283 m
.02756 .25283 L
s
.02381 .27158 m
.02756 .27158 L
s
.02381 .29033 m
.02756 .29033 L
s
.02381 .32783 m
.02756 .32783 L
s
.02381 .34658 m
.02756 .34658 L
s
.02381 .36533 m
.02756 .36533 L
s
.02381 .38408 m
.02756 .38408 L
s
.02381 .42158 m
.02756 .42158 L
s
.02381 .44033 m
.02756 .44033 L
s
.02381 .45908 m
.02756 .45908 L
s
.02381 .47783 m
.02756 .47783 L
s
.02381 .51533 m
.02756 .51533 L
s
.02381 .53408 m
.02756 .53408 L
s
.02381 .55283 m
.02756 .55283 L
s
.02381 .57158 m
.02756 .57158 L
s
.02381 .00907 m
.02756 .00907 L
s
.02381 .60908 m
.02756 .60908 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Phase Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .37841 m
.02502 .37853 L
.02623 .37866 L
.02744 .37878 L
.02864 .37889 L
.02985 .37901 L
.03106 .37913 L
.03227 .37922 L
.03348 .37933 L
.03469 .37942 L
.0359 .37953 L
.0371 .37962 L
.03831 .3797 L
.03952 .37979 L
.04073 .37987 L
.04194 .37994 L
.04315 .38001 L
.04436 .38009 L
.04556 .38016 L
.04677 .38021 L
.04798 .38026 L
.04919 .38033 L
.0504 .38036 L
.05161 .3804 L
.05282 .38044 L
.05402 .38047 L
.05523 .3805 L
.05644 .3805 L
.05765 .38051 L
.05886 .38052 L
.06007 .38052 L
.06128 .3805 L
.06248 .38051 L
.06369 .38049 L
.0649 .38043 L
.06611 .3804 L
.06732 .38041 L
.06853 .38036 L
.06974 .38021 L
.07095 .3801 L
.07215 .38024 L
.07336 .38032 L
.07457 .37977 L
.07578 .37925 L
.07699 .38001 L
.0782 .38104 L
.07941 .37936 L
.08061 .37647 L
.08182 .37892 L
.08303 .38493 L
Mistroke
.08424 .3813 L
.08545 .3672 L
.08666 .37282 L
.08787 .39603 L
.08907 .40142 L
.09028 .33507 L
.09149 .35183 L
.0927 .40894 L
.09391 .48994 L
.09512 .20959 L
.09633 .31151 L
.09753 .40607 L
.09874 .52709 L
.09995 .11883 L
.10116 .26731 L
.10237 .38768 L
.10358 .51734 L
.10479 .08155 L
.10599 .23053 L
.1072 .36312 L
.10841 .49677 L
.10962 .05302 L
.11083 .19983 L
.11204 .33753 L
.11325 .4734 L
.11445 .02695 L
.11566 .17275 L
.11687 .31284 L
.11808 .44973 L
.11929 .59126 L
.1205 .14854 L
.12171 .29054 L
.12292 .42699 L
.12412 .56738 L
.12533 .13157 L
.12654 .286 L
.12775 .43321 L
.12896 .25461 L
.13017 .38479 L
.13138 .52453 L
.13258 .08637 L
.13379 .23335 L
.135 .37054 L
.13621 .5081 L
.13742 .0709 L
.13863 .23536 L
.13984 .4109 L
.14104 .20311 L
.14225 .33569 L
.14346 .47162 L
Mistroke
.14467 .0323 L
.14588 .18572 L
.14709 .32568 L
.1483 .45625 L
.1495 .20463 L
.15071 .42156 L
.15192 .5834 L
.15313 .15517 L
.15434 .29612 L
.15555 .42934 L
.15676 .57651 L
.15796 .21691 L
.15917 .5196 L
.16038 .12917 L
.16159 .27105 L
.1628 .40327 L
.16401 .54803 L
.16522 .14182 L
.16642 .36267 L
.16763 .10652 L
.16884 .24961 L
.17005 .37995 L
.17126 .52305 L
.17247 .11609 L
.17368 .31826 L
.17489 .086 L
.17609 .23119 L
.1773 .3599 L
.17851 .5009 L
.17972 .10769 L
.18093 .35245 L
.18214 .06752 L
.18335 .21535 L
.18455 .34292 L
.18576 .48009 L
.18697 .16811 L
.18818 .42367 L
.18939 .05292 L
.1906 .20277 L
.19181 .32818 L
.19301 .4468 L
.19422 .2877 L
.19543 .44284 L
.19664 .04376 L
.19785 .19613 L
.19906 .31258 L
.20027 .19821 L
.20147 .298 L
.20268 .44249 L
.20389 .04636 L
Mistroke
.2051 .20962 L
.20631 .07886 L
.20752 .17458 L
.20873 .29419 L
.20993 .43383 L
.21114 .15269 L
.21235 .37838 L
.21356 .02921 L
.21477 .1697 L
.21598 .2822 L
.21719 .17368 L
.21839 .26652 L
.2196 .42526 L
.22081 .04222 L
.22202 .18748 L
.22323 .05174 L
.22444 .15399 L
.22565 .27226 L
.22686 .43612 L
.22806 .20358 L
.22927 .41697 L
.23048 .02924 L
.23169 .15627 L
.2329 .15589 L
.23411 .13937 L
.23532 .26271 L
.23652 .45904 L
.23773 .10772 L
.23894 .43564 L
.24015 .02443 L
.24136 .14275 L
.24257 .1823 L
.24378 .12201 L
.24498 .26227 L
.24619 .48065 L
.2474 .06768 L
.24861 .48339 L
.24982 .01883 L
.25103 .13482 L
.25224 .06231 L
.25344 .11117 L
.25465 .28551 L
.25586 .49701 L
.25707 .05123 L
.25828 .48468 L
.25949 .60284 L
.2607 .13279 L
.2619 .56558 L
.26311 .12341 L
.26432 .33225 L
Mistroke
.26553 .50775 L
.26674 .38116 L
.26795 .47974 L
.26916 .60226 L
.27036 .13647 L
.27157 .57501 L
.27278 .17079 L
.27399 .37163 L
.2752 .52122 L
.27641 .35551 L
.27762 .48071 L
.27883 .01489 L
.28003 .45091 L
.28124 .02579 L
.28245 .23756 L
.28366 .41054 L
.28487 .23105 L
.28608 .36127 L
.28729 .47782 L
.28849 .33959 L
.2897 .48264 L
.29091 .1085 L
.29212 .3208 L
.29333 .10448 L
.29454 .24753 L
.29575 .35544 L
.29695 .23652 L
.29816 .36157 L
.29937 .56901 L
.30058 .27076 L
.30179 .5606 L
.303 .14136 L
.30421 .24146 L
.30541 .13235 L
.30662 .24978 L
.30783 .41986 L
.30904 .2172 L
.31025 .4296 L
.31146 .04851 L
.31267 .16989 L
.31387 .02529 L
.31508 .14354 L
.31629 .03755 L
.3175 .13364 L
.31871 .31027 L
.31992 .59987 L
.32113 .3142 L
.32234 .51017 L
.32354 .04052 L
.32475 .50557 L
Mistroke
.32596 .03652 L
.32717 .20435 L
.32838 .599 L
.32959 .21923 L
.3308 .42756 L
.332 .23655 L
.33321 .39856 L
.33442 .51963 L
.33563 .39012 L
.33684 .51981 L
.33805 .15336 L
.33926 .46136 L
.34046 .14454 L
.34167 .30868 L
.34288 .19816 L
.34409 .29316 L
.3453 .41323 L
.34651 .27154 L
.34772 .42322 L
.34892 .09334 L
.35013 .34377 L
.35134 .06957 L
.35255 .20433 L
.35376 .09067 L
.35497 .19378 L
.35618 .31447 L
.35738 .16967 L
.35859 .35658 L
.3598 .02414 L
.36101 .36192 L
.36222 .57276 L
.36343 .09887 L
.36464 .56918 L
.36584 .10263 L
.36705 .51279 L
.36826 .09377 L
.36947 .33077 L
.37068 .54816 L
.37189 .3399 L
.3731 .48107 L
.37431 .38177 L
.37551 .47238 L
.37672 .03092 L
.37793 .44179 L
.37914 .06465 L
.38035 .29695 L
.38156 .09947 L
.38277 .26474 L
.38397 .35702 L
.38518 .2586 L
Mistroke
.38639 .38736 L
.3876 .22036 L
.38881 .39782 L
.39002 .07536 L
.39123 .3315 L
.39243 .05622 L
.39364 .17808 L
.39485 .05793 L
.39606 .17738 L
.39727 .03446 L
.39848 .17645 L
.39969 .43481 L
.40089 .11441 L
.4021 .43066 L
.40331 .57469 L
.40452 .44076 L
.40573 .56378 L
.40694 .43541 L
.40815 .56153 L
.40935 .21709 L
.41056 .5212 L
.41177 .22115 L
.41298 .37822 L
.41419 .23487 L
.4154 .35916 L
.41661 .24017 L
.41781 .35817 L
.41902 .06702 L
.42023 .34152 L
.42144 .02867 L
.42265 .21355 L
.42386 .03801 L
.42507 .16453 L
.42628 .04533 L
.42748 .16413 L
.42869 .60031 L
.4299 .16738 L
.43111 .44391 L
.43232 .13937 L
.43353 .43209 L
.43474 .56523 L
.43594 .43415 L
.43715 .55801 L
.43836 .4251 L
.43957 .57663 L
.44078 .34542 L
.44199 .02234 L
.4432 .25869 L
.4444 .10056 L
.44561 .24515 L
Mistroke
.44682 .25223 L
.44803 .24194 L
.44924 .37257 L
.45045 .22862 L
.45166 .46062 L
.45286 .15623 L
.45407 .50503 L
.45528 .0734 L
.45649 .52589 L
.4577 .0605 L
.45891 .52495 L
.46012 .0674 L
.46132 .44642 L
.46253 .08742 L
.46374 .35529 L
.46495 .14769 L
.46616 .34185 L
.46737 .30633 L
.46858 .33983 L
.46978 .4201 L
.47099 .33499 L
.4722 .58011 L
.47341 .30604 L
.47462 .02689 L
.47583 .19788 L
.47704 .03932 L
.47825 .15693 L
.47945 .04114 L
.48066 .17029 L
.48187 .026 L
.48308 .22503 L
.48429 .5484 L
.4855 .29475 L
.48671 .47057 L
.48791 .32547 L
.48912 .45293 L
.49033 .32816 L
.49154 .46297 L
.49275 .29821 L
.49396 .50941 L
.49517 .21835 L
.49637 .5917 L
.49758 .17075 L
.49879 .03894 L
.5 .16081 L
.50121 .03951 L
.50242 .1719 L
.50363 .59342 L
.50483 .22065 L
.50604 .51228 L
Mistroke
.50725 .30166 L
.50846 .46699 L
.50967 .33276 L
.51088 .4581 L
.51209 .33122 L
.51329 .4769 L
.5145 .30166 L
.51571 .55588 L
.51692 .23308 L
.51813 .03463 L
.51934 .17949 L
.52055 .05092 L
.52175 .16728 L
.52296 .05025 L
.52417 .20939 L
.52538 .03898 L
.52659 .3187 L
.5278 .59335 L
.52901 .3488 L
.53022 .43448 L
.53142 .35479 L
.53263 .32186 L
.53384 .35796 L
.53505 .16437 L
.53626 .37255 L
.53747 .10525 L
.53868 .46483 L
.53988 .08638 L
.54109 .54451 L
.5423 .08063 L
.54351 .5466 L
.54472 .09468 L
.54593 .52689 L
.54714 .17867 L
.54834 .48363 L
.54955 .2522 L
.55076 .39673 L
.55197 .26668 L
.55318 .27755 L
.55439 .27104 L
.5556 .12702 L
.5568 .28572 L
.55801 .04995 L
.55922 .37361 L
.56043 .01633 L
.56164 .45444 L
.56285 .58792 L
.56406 .46464 L
.56526 .5963 L
.56647 .46373 L
Mistroke
.56768 .17159 L
.56889 .4767 L
.5701 .20074 L
.57131 .04519 L
.57252 .19865 L
.57372 .08042 L
.57493 .20019 L
.57614 .07425 L
.57735 .25037 L
.57856 .06606 L
.57977 .37948 L
.58098 .10557 L
.58219 .39729 L
.58339 .27986 L
.5846 .39943 L
.58581 .27572 L
.58702 .41964 L
.58823 .26315 L
.58944 .56377 L
.59065 .26024 L
.59185 .01619 L
.59306 .4797 L
.59427 .01958 L
.59548 .48621 L
.59669 .03166 L
.5979 .47725 L
.59911 .16158 L
.60031 .48255 L
.60152 .22477 L
.60273 .08335 L
.60394 .22686 L
.60515 .10798 L
.60636 .2287 L
.60757 .10742 L
.60877 .38327 L
.60998 .12771 L
.61119 .45074 L
.6124 .27386 L
.61361 .44143 L
.61482 .31325 L
.61603 .41225 L
.61723 .32054 L
.61844 .15584 L
.61965 .3539 L
.62086 .12218 L
.62207 .49989 L
.62328 .0896 L
.62449 .53163 L
.62569 .44159 L
.6269 .54147 L
Mistroke
.62811 .40087 L
.62932 .02065 L
.63053 .3929 L
.63174 .15648 L
.63295 .57607 L
.63416 .16649 L
.63536 .04455 L
.63657 .16387 L
.63778 .04927 L
.63899 .42807 L
.6402 .09087 L
.64141 .42389 L
.64262 .23755 L
.64382 .38292 L
.64503 .26281 L
.64624 .16027 L
.64745 .27451 L
.64866 .14033 L
.64987 .4151 L
.65108 .16525 L
.65228 .4957 L
.65349 .3446 L
.6547 .48686 L
.65591 .36736 L
.65712 .27294 L
.65833 .38404 L
.65954 .22048 L
.66074 .53787 L
.66195 .23044 L
.66316 .59747 L
.66437 .46836 L
.66558 .59844 L
.66679 .47795 L
.668 .31651 L
.6692 .5081 L
.67041 .30034 L
.67162 .09163 L
.67283 .28661 L
.67404 .11935 L
.67525 .58898 L
.67646 .12451 L
.67766 .59473 L
.67887 .39934 L
.68008 .09652 L
.68129 .39656 L
.6825 .2205 L
.68371 .12499 L
.68492 .23155 L
.68613 .11388 L
.68733 .25902 L
Mistroke
.68854 .13825 L
.68975 .51992 L
.69096 .30809 L
.69217 .51131 L
.69338 .34182 L
.69459 .22497 L
.69579 .33465 L
.697 .23513 L
.69821 .06588 L
.69942 .36567 L
.70063 .07544 L
.70184 .45764 L
.70305 .33316 L
.70425 .45265 L
.70546 .34532 L
.70667 .20285 L
.70788 .41974 L
.70909 .20802 L
.7103 .58274 L
.71151 .44026 L
.71271 .57906 L
.71392 .46309 L
.71513 .33345 L
.71634 .51351 L
.71755 .3411 L
.71876 .12992 L
.71997 .55561 L
.72117 .12016 L
.72238 .58656 L
.72359 .46193 L
.7248 .03915 L
.72601 .4792 L
.72722 .27893 L
.72843 .09468 L
.72964 .24575 L
.73084 .12307 L
.73205 .59019 L
.73326 .49219 L
.73447 .03029 L
.73568 .44442 L
.73689 .23616 L
.7381 .08984 L
.7393 .24669 L
.74051 .12826 L
.74172 .59973 L
.74293 .16686 L
.74414 .02415 L
.74535 .40229 L
.74656 .22852 L
.74776 .18024 L
Mistroke
.74897 .25332 L
.75018 .13791 L
.75139 .60305 L
.7526 .18791 L
.75381 .60146 L
.75502 .38364 L
.75622 .24397 L
.75743 .30482 L
.75864 .26585 L
.75985 .14811 L
.76106 .5599 L
.76227 .23255 L
.76348 .58444 L
.76468 .38869 L
.76589 .26593 L
.7671 .28301 L
.76831 .28398 L
.76952 .15752 L
.77073 .54582 L
.77194 .33301 L
.77314 .56614 L
.77435 .40284 L
.77556 .28514 L
.77677 .18347 L
.77798 .31979 L
.77919 .1751 L
.7804 .55872 L
.78161 .40055 L
.78281 .30828 L
.78402 .41738 L
.78523 .30546 L
.78644 .16554 L
.78765 .51529 L
.78886 .29018 L
.79007 .57189 L
.79127 .43283 L
.79248 .31379 L
.79369 .21865 L
.7949 .34998 L
.79611 .1873 L
.79732 .584 L
.79853 .44009 L
.79973 .34087 L
.80094 .45582 L
.80215 .33994 L
.80336 .18815 L
.80457 .58781 L
.80578 .43323 L
.80699 .59292 L
.80819 .47487 L
Mistroke
.8094 .35004 L
.81061 .20076 L
.81182 .57209 L
.81303 .3171 L
.81424 .04059 L
.81545 .49307 L
.81665 .36606 L
.81786 .21881 L
.81907 .50432 L
.82028 .26014 L
.82149 .06485 L
.8227 .51349 L
.82391 .38536 L
.82511 .24074 L
.82632 .47358 L
.82753 .27198 L
.82874 .09046 L
.82995 .53699 L
.83116 .40723 L
.83237 .26472 L
.83358 .52144 L
.83478 .30116 L
.83599 .11889 L
.8372 .56376 L
.83841 .43212 L
.83962 .29081 L
.84083 .09277 L
.84204 .3797 L
.84324 .15082 L
.84445 .59328 L
.84566 .46064 L
.84687 .32027 L
.84808 .16001 L
.84929 .58781 L
.8505 .37143 L
.8517 .03459 L
.85291 .49365 L
.85412 .35427 L
.85533 .20142 L
.85654 .05226 L
.85775 .50597 L
.85896 .37396 L
.86016 .58234 L
.86137 .40736 L
.86258 .24348 L
.86379 .09219 L
.865 .54427 L
.86621 .40765 L
.86742 .26125 L
.86862 .11092 L
Mistroke
.86983 .56082 L
.87104 .43121 L
.87225 .02134 L
.87346 .46375 L
.87467 .3099 L
.87588 .15722 L
.87708 .01741 L
.87829 .4706 L
.8795 .32917 L
.88071 .18341 L
.88192 .04245 L
.88313 .49519 L
.88434 .35568 L
.88555 .21046 L
.88675 .06843 L
.88796 .52218 L
.88917 .38506 L
.89038 .23882 L
.89159 .0941 L
.8928 .55008 L
.89401 .41806 L
.89521 .26966 L
.89642 .11697 L
.89763 .57694 L
.89884 .45714 L
.90005 .30923 L
.90126 .12903 L
.90247 .59764 L
.90367 .50364 L
.90488 .40225 L
.90609 .0942 L
.9073 .60281 L
.90851 .54627 L
.90972 .5301 L
.91093 .59707 L
.91213 .59222 L
.91334 .56957 L
.91455 .56455 L
.91576 .57921 L
.91697 .58342 L
.91818 .57798 L
.91939 .57612 L
.92059 .57958 L
.9218 .58184 L
.92301 .58138 L
.92422 .58121 L
.92543 .58229 L
.92664 .58341 L
.92785 .58391 L
.92905 .58435 L
Mistroke
.93026 .58503 L
.93147 .58576 L
.93268 .58639 L
.93389 .58695 L
.9351 .58756 L
.93631 .5882 L
.93752 .58879 L
.93872 .58937 L
.93993 .58995 L
.94114 .59053 L
.94235 .59109 L
.94356 .59166 L
.94477 .59224 L
.94598 .59279 L
.94718 .59334 L
.94839 .59388 L
.9496 .59441 L
.95081 .59494 L
.95202 .59546 L
.95323 .59599 L
.95444 .5965 L
.95564 .59701 L
.95685 .59752 L
.95806 .59802 L
.95927 .59852 L
.96048 .59901 L
.96169 .59952 L
.9629 .6 L
.9641 .60048 L
.96531 .60097 L
.96652 .60144 L
.96773 .60191 L
.96894 .60238 L
.97015 .60285 L
.97136 .60331 L
.97256 .01472 L
.97377 .01517 L
.97498 .01562 L
.97619 .01608 L
Mfstroke
1 0 0 r
.02381 .48977 m
.02502 .49008 L
.02623 .49036 L
.02744 .49064 L
.02864 .49097 L
.02985 .49129 L
.03106 .49155 L
.03227 .49186 L
.03348 .49217 L
.03469 .49246 L
.0359 .49274 L
.0371 .49304 L
.03831 .49326 L
.03952 .49363 L
.04073 .49385 L
.04194 .49422 L
.04315 .49451 L
.04436 .49485 L
.04556 .49511 L
.04677 .49541 L
.04798 .49566 L
.04919 .496 L
.0504 .49623 L
.05161 .49654 L
.05282 .49688 L
.05402 .49709 L
.05523 .49743 L
.05644 .49766 L
.05765 .49801 L
.05886 .49828 L
.06007 .49861 L
.06128 .49886 L
.06248 .49918 L
.06369 .49942 L
.0649 .49974 L
.06611 .50001 L
.06732 .50035 L
.06853 .50065 L
.06974 .5009 L
.07095 .50123 L
.07215 .50146 L
.07336 .50179 L
.07457 .50203 L
.07578 .50234 L
.07699 .50266 L
.0782 .50292 L
.07941 .50321 L
.08061 .50351 L
.08182 .50383 L
.08303 .50405 L
Mistroke
.08424 .5044 L
.08545 .50467 L
.08666 .50496 L
.08787 .50523 L
.08907 .50556 L
.09028 .50584 L
.09149 .50613 L
.0927 .50643 L
.09391 .5067 L
.09512 .50702 L
.09633 .50732 L
.09753 .50758 L
.09874 .50789 L
.09995 .50818 L
.10116 .50841 L
.10237 .50874 L
.10358 .50899 L
.10479 .50931 L
.10599 .50958 L
.1072 .50985 L
.10841 .51017 L
.10962 .51042 L
.11083 .51074 L
.11204 .51105 L
.11325 .51134 L
.11445 .51169 L
.11566 .51192 L
.11687 .51223 L
.11808 .51251 L
.11929 .51277 L
.1205 .5131 L
.12171 .51338 L
.12292 .51369 L
.12412 .51399 L
.12533 .51424 L
.12654 .51452 L
.12775 .51482 L
.12896 .51514 L
.13017 .51537 L
.13138 .51569 L
.13258 .51598 L
.13379 .51622 L
.135 .51655 L
.13621 .51683 L
.13742 .51718 L
.13863 .51745 L
.13984 .51773 L
.14104 .51803 L
.14225 .51831 L
.14346 .51855 L
Mistroke
.14467 .51887 L
.14588 .51916 L
.14709 .51946 L
.1483 .51972 L
.1495 .52006 L
.15071 .52031 L
.15192 .52062 L
.15313 .52088 L
.15434 .52117 L
.15555 .52143 L
.15676 .52174 L
.15796 .52199 L
.15917 .5223 L
.16038 .52264 L
.16159 .52288 L
.1628 .52321 L
.16401 .52351 L
.16522 .5238 L
.16642 .52408 L
.16763 .52441 L
.16884 .52463 L
.17005 .52499 L
.17126 .5252 L
.17247 .52555 L
.17368 .52579 L
.17489 .52616 L
.17609 .52639 L
.1773 .52668 L
.17851 .52696 L
.17972 .5272 L
.18093 .52752 L
.18214 .52779 L
.18335 .52812 L
.18455 .52842 L
.18576 .52871 L
.18697 .52896 L
.18818 .5293 L
.18939 .52957 L
.1906 .52984 L
.19181 .53017 L
.19301 .53046 L
.19422 .5307 L
.19543 .53097 L
.19664 .53128 L
.19785 .53158 L
.19906 .53185 L
.20027 .53218 L
.20147 .53249 L
.20268 .53273 L
.20389 .53305 L
Mistroke
.2051 .53329 L
.20631 .53359 L
.20752 .53392 L
.20873 .53413 L
.20993 .53451 L
.21114 .53473 L
.21235 .53503 L
.21356 .53533 L
.21477 .5356 L
.21598 .53593 L
.21719 .53623 L
.21839 .5365 L
.2196 .5368 L
.22081 .53708 L
.22202 .53737 L
.22323 .53763 L
.22444 .53793 L
.22565 .53821 L
.22686 .53846 L
.22806 .53879 L
.22927 .53903 L
.23048 .53936 L
.23169 .53964 L
.2329 .53992 L
.23411 .54022 L
.23532 .54053 L
.23652 .54082 L
.23773 .54108 L
.23894 .54142 L
.24015 .54168 L
.24136 .54194 L
.24257 .54225 L
.24378 .54253 L
.24498 .54284 L
.24619 .54311 L
.2474 .5434 L
.24861 .54369 L
.24982 .54399 L
.25103 .54423 L
.25224 .54459 L
.25344 .5449 L
.25465 .54516 L
.25586 .54546 L
.25707 .54576 L
.25828 .54599 L
.25949 .5463 L
.2607 .54658 L
.2619 .54687 L
.26311 .54716 L
.26432 .54743 L
Mistroke
.26553 .54771 L
.26674 .54799 L
.26795 .54832 L
.26916 .54861 L
.27036 .54891 L
.27157 .54921 L
.27278 .54948 L
.27399 .54974 L
.2752 .55003 L
.27641 .5503 L
.27762 .55063 L
.27883 .55086 L
.28003 .55123 L
.28124 .55145 L
.28245 .5518 L
.28366 .55204 L
.28487 .55237 L
.28608 .55265 L
.28729 .55294 L
.28849 .5532 L
.2897 .55349 L
.29091 .55378 L
.29212 .55404 L
.29333 .55437 L
.29454 .55461 L
.29575 .55498 L
.29695 .55521 L
.29816 .55551 L
.29937 .55581 L
.30058 .55611 L
.30179 .55634 L
.303 .55668 L
.30421 .55693 L
.30541 .55727 L
.30662 .55753 L
.30783 .55783 L
.30904 .55816 L
.31025 .55836 L
.31146 .55867 L
.31267 .55893 L
.31387 .55922 L
.31508 .55952 L
.31629 .55979 L
.3175 .56011 L
.31871 .56039 L
.31992 .56066 L
.32113 .561 L
.32234 .56126 L
.32354 .5616 L
.32475 .56188 L
Mistroke
.32596 .56212 L
.32717 .56244 L
.32838 .5627 L
.32959 .563 L
.3308 .5633 L
.332 .56363 L
.33321 .56394 L
.33442 .56414 L
.33563 .56449 L
.33684 .56469 L
.33805 .56502 L
.33926 .56528 L
.34046 .56558 L
.34167 .56588 L
.34288 .56617 L
.34409 .56643 L
.3453 .56674 L
.34651 .56704 L
.34772 .56734 L
.34892 .56764 L
.35013 .56788 L
.35134 .56823 L
.35255 .56846 L
.35376 .56875 L
.35497 .56905 L
.35618 .56938 L
.35738 .56961 L
.35859 .56994 L
.3598 .57021 L
.36101 .57051 L
.36222 .5708 L
.36343 .57104 L
.36464 .5714 L
.36584 .57164 L
.36705 .57189 L
.36826 .57222 L
.36947 .57251 L
.37068 .57279 L
.37189 .57305 L
.3731 .57337 L
.37431 .57365 L
.37551 .57395 L
.37672 .57428 L
.37793 .57456 L
.37914 .57488 L
.38035 .57515 L
.38156 .57537 L
.38277 .57568 L
.38397 .57596 L
.38518 .57625 L
Mistroke
.38639 .57651 L
.3876 .57686 L
.38881 .5771 L
.39002 .57736 L
.39123 .57767 L
.39243 .57798 L
.39364 .57825 L
.39485 .57859 L
.39606 .57882 L
.39727 .57912 L
.39848 .57941 L
.39969 .57966 L
.40089 .58003 L
.4021 .5803 L
.40331 .58065 L
.40452 .58085 L
.40573 .58113 L
.40694 .58135 L
.40815 .58174 L
.40935 .58191 L
.41056 .58234 L
.41177 .58261 L
.41298 .58295 L
.41419 .58315 L
.4154 .58347 L
.41661 .5838 L
.41781 .58396 L
.41902 .58427 L
.42023 .58457 L
.42144 .58482 L
.42265 .58506 L
.42386 .58543 L
.42507 .58569 L
.42628 .58614 L
.42748 .58624 L
.42869 .58677 L
.4299 .58686 L
.43111 .58728 L
.43232 .58742 L
.43353 .58773 L
.43474 .5881 L
.43594 .58821 L
.43715 .58867 L
.43836 .58894 L
.43957 .5892 L
.44078 .58964 L
.44199 .58974 L
.4432 .59006 L
.4444 .59043 L
.44561 .59055 L
Mistroke
.44682 .59092 L
.44803 .59133 L
.44924 .59149 L
.45045 .59179 L
.45166 .5921 L
.45286 .59231 L
.45407 .59266 L
.45528 .59307 L
.45649 .59327 L
.4577 .59356 L
.45891 .59392 L
.46012 .594 L
.46132 .59437 L
.46253 .59466 L
.46374 .59531 L
.46495 .59517 L
.46616 .59582 L
.46737 .59583 L
.46858 .5961 L
.46978 .59635 L
.47099 .59655 L
.4722 .59715 L
.47341 .59734 L
.47462 .59732 L
.47583 .59786 L
.47704 .59811 L
.47825 .59825 L
.47945 .59874 L
.48066 .59923 L
.48187 .59952 L
.48308 .5994 L
.48429 .60002 L
.4855 .59988 L
.48671 .60048 L
.48791 .60066 L
.48912 .60096 L
.49033 .6015 L
.49154 .60166 L
.49275 .60176 L
.49396 .60211 L
.49517 .60249 L
.49637 .60275 L
.49758 .60302 L
.49879 .60332 L
.5 .30908 L
.50121 .01483 L
.50242 .01513 L
.50363 .0154 L
.50483 .01566 L
.50604 .01604 L
Mistroke
.50725 .01639 L
.50846 .01649 L
.50967 .01665 L
.51088 .01719 L
.51209 .01749 L
.51329 .01767 L
.5145 .01827 L
.51571 .01814 L
.51692 .01875 L
.51813 .01863 L
.51934 .01892 L
.52055 .01941 L
.52175 .0199 L
.52296 .02005 L
.52417 .02029 L
.52538 .02083 L
.52659 .02081 L
.5278 .02101 L
.52901 .0216 L
.53022 .0218 L
.53142 .02205 L
.53263 .02232 L
.53384 .02233 L
.53505 .02299 L
.53626 .02284 L
.53747 .02349 L
.53868 .02378 L
.53988 .02416 L
.54109 .02423 L
.5423 .02459 L
.54351 .02488 L
.54472 .02508 L
.54593 .02549 L
.54714 .02584 L
.54834 .02606 L
.54955 .02636 L
.55076 .02666 L
.55197 .02683 L
.55318 .02723 L
.55439 .0276 L
.5556 .02773 L
.5568 .0281 L
.55801 .02841 L
.55922 .02851 L
.56043 .02895 L
.56164 .02921 L
.56285 .02949 L
.56406 .02994 L
.56526 .03005 L
.56647 .03042 L
Mistroke
.56768 .03073 L
.56889 .03087 L
.5701 .03129 L
.57131 .03139 L
.57252 .03192 L
.57372 .03201 L
.57493 .03246 L
.57614 .03273 L
.57735 .03309 L
.57856 .03333 L
.57977 .03359 L
.58098 .03388 L
.58219 .03419 L
.58339 .03435 L
.5846 .03469 L
.58581 .03501 L
.58702 .03521 L
.58823 .03554 L
.58944 .03581 L
.59065 .03624 L
.59185 .03642 L
.59306 .0368 L
.59427 .03702 L
.59548 .0373 L
.59669 .03751 L
.5979 .03785 L
.59911 .03812 L
.60031 .03849 L
.60152 .03874 L
.60273 .03903 L
.60394 .03934 L
.60515 .03956 L
.60636 .0399 L
.60757 .04017 L
.60877 .04049 L
.60998 .04079 L
.61119 .04106 L
.6124 .04129 L
.61361 .04164 L
.61482 .0419 L
.61603 .04219 L
.61723 .04247 L
.61844 .04278 L
.61965 .043 L
.62086 .04327 L
.62207 .04359 L
.62328 .04387 L
.62449 .04421 L
.62569 .0445 L
.6269 .04478 L
Mistroke
.62811 .0451 L
.62932 .04537 L
.63053 .04565 L
.63174 .04593 L
.63295 .04626 L
.63416 .04651 L
.63536 .04676 L
.63657 .04712 L
.63778 .04736 L
.63899 .04765 L
.6402 .04795 L
.64141 .04822 L
.64262 .04855 L
.64382 .04877 L
.64503 .0491 L
.64624 .0494 L
.64745 .04969 L
.64866 .04993 L
.64987 .05027 L
.65108 .05051 L
.65228 .05082 L
.65349 .05111 L
.6547 .05141 L
.65591 .05172 L
.65712 .05198 L
.65833 .05228 L
.65954 .05257 L
.66074 .05288 L
.66195 .05314 L
.66316 .05346 L
.66437 .05367 L
.66558 .05401 L
.66679 .05422 L
.668 .05453 L
.6692 .05485 L
.67041 .05515 L
.67162 .05545 L
.67283 .05571 L
.67404 .05603 L
.67525 .05627 L
.67646 .05656 L
.67766 .05689 L
.67887 .05715 L
.68008 .05749 L
.68129 .05776 L
.6825 .05804 L
.68371 .05836 L
.68492 .05864 L
.68613 .05893 L
.68733 .05922 L
Mistroke
.68854 .05948 L
.68975 .05979 L
.69096 .05999 L
.69217 .06032 L
.69338 .06062 L
.69459 .06088 L
.69579 .06122 L
.697 .06147 L
.69821 .06182 L
.69942 .06204 L
.70063 .06234 L
.70184 .06265 L
.70305 .06294 L
.70425 .06318 L
.70546 .06354 L
.70667 .06378 L
.70788 .06412 L
.70909 .06437 L
.7103 .06467 L
.71151 .06495 L
.71271 .06521 L
.71392 .0655 L
.71513 .06578 L
.71634 .06611 L
.71755 .06635 L
.71876 .0667 L
.71997 .06693 L
.72117 .06729 L
.72238 .06752 L
.72359 .06786 L
.7248 .06812 L
.72601 .06842 L
.72722 .06867 L
.72843 .06894 L
.72964 .06924 L
.73084 .06955 L
.73205 .06983 L
.73326 .07016 L
.73447 .07044 L
.73568 .07072 L
.73689 .07099 L
.7381 .07128 L
.7393 .07157 L
.74051 .07185 L
.74172 .07217 L
.74293 .07239 L
.74414 .0727 L
.74535 .07299 L
.74656 .07325 L
.74776 .07356 L
Mistroke
.74897 .07392 L
.75018 .07417 L
.75139 .07446 L
.7526 .07476 L
.75381 .07504 L
.75502 .07531 L
.75622 .07562 L
.75743 .0759 L
.75864 .07622 L
.75985 .07647 L
.76106 .07673 L
.76227 .07707 L
.76348 .07733 L
.76468 .07762 L
.76589 .07793 L
.7671 .07824 L
.76831 .07852 L
.76952 .07879 L
.77073 .07912 L
.77194 .07936 L
.77314 .07969 L
.77435 .07994 L
.77556 .08023 L
.77677 .08053 L
.77798 .08079 L
.77919 .08107 L
.7804 .08135 L
.78161 .08166 L
.78281 .08193 L
.78402 .08223 L
.78523 .08256 L
.78644 .08282 L
.78765 .08313 L
.78886 .08343 L
.79007 .08365 L
.79127 .08402 L
.79248 .08423 L
.79369 .08456 L
.7949 .08486 L
.79611 .08511 L
.79732 .08542 L
.79853 .08567 L
.79973 .08597 L
.80094 .0863 L
.80215 .08658 L
.80336 .08688 L
.80457 .08718 L
.80578 .08745 L
.80699 .0877 L
.80819 .08799 L
Mistroke
.8094 .08831 L
.81061 .08858 L
.81182 .08885 L
.81303 .08919 L
.81424 .08945 L
.81545 .08973 L
.81665 .09004 L
.81786 .09037 L
.81907 .09063 L
.82028 .09095 L
.82149 .09119 L
.8227 .09148 L
.82391 .09177 L
.82511 .092 L
.82632 .09236 L
.82753 .0926 L
.82874 .09295 L
.82995 .09316 L
.83116 .09352 L
.83237 .09374 L
.83358 .09407 L
.83478 .09436 L
.83599 .09464 L
.8372 .09494 L
.83841 .09527 L
.83962 .09552 L
.84083 .09585 L
.84204 .09616 L
.84324 .09641 L
.84445 .09673 L
.84566 .09699 L
.84687 .09728 L
.84808 .09753 L
.84929 .09785 L
.8505 .09809 L
.8517 .09843 L
.85291 .0987 L
.85412 .099 L
.85533 .09928 L
.85654 .09961 L
.85775 .09984 L
.85896 .10012 L
.86016 .10042 L
.86137 .10071 L
.86258 .10097 L
.86379 .10133 L
.865 .1016 L
.86621 .10193 L
.86742 .10217 L
.86862 .10246 L
Mistroke
.86983 .10279 L
.87104 .10302 L
.87225 .10333 L
.87346 .10363 L
.87467 .10391 L
.87588 .10416 L
.87708 .10447 L
.87829 .10477 L
.8795 .10505 L
.88071 .10538 L
.88192 .10565 L
.88313 .10592 L
.88434 .10623 L
.88555 .10646 L
.88675 .10681 L
.88796 .1071 L
.88917 .10742 L
.89038 .10774 L
.89159 .10798 L
.8928 .1083 L
.89401 .10857 L
.89521 .10884 L
.89642 .10917 L
.89763 .10942 L
.89884 .10974 L
.90005 .10997 L
.90126 .11026 L
.90247 .11057 L
.90367 .11084 L
.90488 .11114 L
.90609 .11145 L
.9073 .11173 L
.90851 .11202 L
.90972 .11232 L
.91093 .1126 L
.91213 .11292 L
.91334 .11319 L
.91455 .11348 L
.91576 .11376 L
.91697 .1141 L
.91818 .11432 L
.91939 .11464 L
.92059 .11495 L
.9218 .11523 L
.92301 .11549 L
.92422 .11581 L
.92543 .11612 L
.92664 .11637 L
.92785 .11669 L
.92905 .11693 L
Mistroke
.93026 .11725 L
.93147 .1175 L
.93268 .11781 L
.93389 .11814 L
.9351 .11841 L
.93631 .11873 L
.93752 .11897 L
.93872 .11929 L
.93993 .11955 L
.94114 .11987 L
.94235 .12014 L
.94356 .12049 L
.94477 .12072 L
.94598 .12106 L
.94718 .12128 L
.94839 .12161 L
.9496 .12192 L
.95081 .12216 L
.95202 .12249 L
.95323 .12274 L
.95444 .12304 L
.95564 .1233 L
.95685 .12364 L
.95806 .12393 L
.95927 .12431 L
.96048 .12452 L
.96169 .12489 L
.9629 .12511 L
.9641 .12542 L
.96531 .1257 L
.96652 .12599 L
.96773 .12629 L
.96894 .1266 L
.97015 .12686 L
.97136 .12718 L
.97256 .12751 L
.97377 .12779 L
.97498 .12808 L
.97619 .12838 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[75]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o5Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo0_l0003oooooo`[ooooo000Eooooo`03o`000?oooooooooo0?Wooooo00?o0000ooooooooool0
3?ooool000cooooo0ol00006ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0>?oo
ool5ool000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo01Kooooo0_l0000=ooooo`002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo00Co
o`00oooooooooooooooo1Ooo0007ooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`03o`00
0?oooooooooo03kooooo0_l0000Hooooo`03o`000?oooooooooo00cooooo0005ooooo`Go00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0
1Oooool5ool000?ooooo00?o0000ooooooooool01Oooool2o`0000Sooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Oooooo`;o00006?ooool00ol0003oooooooooo`0<ooooo`003Ooo
ool2o`0000Kooooo0_l0000Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000Cooooo00?oo`00ooooooooool02Ooo
ool5ool000Oooooo0_l00008ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07ooo
ool2o`0001Sooooo00?o0000ooooooooool03?ooool000oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooo`000004ooooo`03ool00?oooooooooo00gooooo00?o0000ool00?oo00000_oo0003
ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`00027ooooo0_l0
000Hooooo`03o`000?oooooooooo00cooooo000;ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000Cooooo00Goo`00oooooooooooo
ooooo`00000;ooooo`03o`000?oooooooooo00;ooooo1Ooo0008ooooo`03o`000?oooooooooo01Wo
oooo00Co0000oooooooooooo00006oooool00ol0003oooooooooo`03ooooo`;o00006?ooool00ol0
003oooooooooo`0<ooooo`003?ooool3o`0000Kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool4o`0000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000?o
oooo00?o0000ool00?ooool00_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Go
oooo00?o0000ool00?oo00000ooo0004ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00oooool2o`0001Sooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo1?l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool3o`0000?ooooo00?o0000ool00?ooool00_ooool00ol0003oooooo`000009
ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`Goo`0000?o0000ooooool000005_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o00005oooool00ol0003oooooooooo`0<ooooo`005Oooool2
o`0001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`07o`000?oooooo
0000ooooool0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`Go00002?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00?o0000ooooooooool0
1_ooool3o`0000?ooooo00?o0000ool00?ooool00_ooool00ol0003oooooo`000009ooooo`03o`00
0?oooooo000000Gooooo0_l00008ooooo`Coo`005Oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`?o
00005oooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool01_l0003oooooo`000?oooooo0000oooo
o`;o000000Coooooo`000?oooooo00000_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo1Ol00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`?o00000oooool0
0ol0003oo`00ooooo`02ooooo`?o00002?ooool2o`000003ooooool0003ooooo00Cooooo0_l00008
ooooo`04o`000?oooooo0000ooooo`Goo`004?ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01oooool2o`0000Cooooo0ol0000Gooooo`03o`00
0?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo01Cooooo0_l00007ooooo`03o`000?oo
oooooooo00Wooooo00So0000ooooool0003oooooo`000?oooooo0000ooooo`;o000000Coooooo`00
0?oooooo00000_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo1Ol00008
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`?o00000oooool00ol0003oo`00ooooo`02
ooooo`?o00002?ooool2o`000003ooooool0003ooooo00Cooooo0_l00008ooooo`03o`000?oooooo
000000Gooooo1Ooo000<ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`07ooooo`;o00001?ooool3o`0001Oooooo00?o0000ooooooooool03?oo
ool001Gooooo00?o0000ooooooooool05?ooool2o`0000Oooooo00?o0000ooooooooool02Oooool0
2?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l000001?oooooo0000ooooool00002oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool5o`0000Sooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooooooool2o`0000Kooooo0_l00003ooooo`03o`000?oooooo
oooo00Kooooo0ol00003ooooo`03o`000?oo003ooooo00;ooooo0ol00008ooooo`;o000000?ooooo
o`000?ooool01?ooool2o`0000Sooooo00?o0000ooooool000002Oooool5ool000Sooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo0_l0
0004ooooo`?o00005oooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0D
ooooo`;o00001oooool00ol0003oooooooooo`09ooooo`08o`000?oooooo0000ooooool0003ooooo
o`000?ooool2o`000004ooooool0003oooooo`0000;ooooo0ol00005ooooo`03o`000?oooooooooo
00Gooooo1Ol00008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00006
ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo0ol00003ooooo`03o`000?oo
003ooooo00;ooooo0ol00008ooooo`;o000000?oooooo`000?ooool01?ooool2o`0000Sooooo00?o
0000ooooool000003Oooool5ool000Cooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`?o00005oooool00ol0003ooooo
ooooo`0<ooooo`005Oooool2o`0001Gooooo0_l00007ooooo`03o`000?oooooooooo00Wooooo00So
0000ooooool0003oooooo`000?oooooo0000ooooo`;o000000Coooooo`000?oooooo00000_ooool3
o`0000Gooooo00?o0000ooooooooool01Oooool5o`0000Sooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooooooool2o`0000Gooooo0ol00003ooooo`05o`000?ooooooooooooooool00000
1?ooool3o`0000?ooooo00?o0000ool00?ooool00_ooool3o`0000Sooooo0_l000001?oooooo0000
ooooool00003ooooo`;o00002?ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00Co
o`0000Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo0000
00Oooooo0_l00004ooooo`?o00005oooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003o
ooooooooo`0Dooooo`;o00001Oooool00ol0003oooooo`000009ooooo`0:o`000?oooooo0000oooo
ool0003oooooo`000?oooooo0000ooooo`;o000000Goooooo`000?oooooo0000ooooo`04o`0000Go
oooo00?o0000ooooooooool01Oooool5o`0000Kooooo00?o0000ooooool000001?ooool01?l0003o
ooooooooooooool2o`0000Gooooo0ol00003ooooo`04o`000?ooooooooooooooo`;o00000oooool3
o`0000?ooooo00?o0000ool00?ooool00_ooool3o`0000Sooooo0_l000001?oooooo0000ooooool0
0003ooooo`;o00002?ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00Cooooo1Ooo
00000ooooooo0000ooooo`0@ooooo`03o`000?oooooo000000Oooooo0_l00004ooooo`?o000000?o
ooooo`000?ooool05?ooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0D
ooooo`;o00001Oooool00ol0003oooooo`000009ooooo`0:o`000?oooooo0000ooooool0003ooooo
o`000?oooooo0000ooooo`;o000000Goooooo`000?oooooo0000ooooo`04o`0000Gooooo00?o0000
ooooooooool01Oooool5o`0000Kooooo00?o0000ooooool000001?ooool01?l0003ooooooooooooo
ool2o`0000Gooooo0ol00003ooooo`04o`000?ooooooooooooooo`;o00000oooool3o`0000?ooooo
00?o0000ool00?ooool00_ooool3o`0000Sooooo0_l000001?oooooo0000ooooool00003ooooo`;o
00002?ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00001Ooo000?ooooo`03o`000?oooooo000000Oooooo0_l00004ooooo`?o000000?oooooo`00
0?ooool05?ooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0Dooooo`;o
00001Oooool00ol0003oooooo`000009ooooo`0:o`000?oooooo0000ooooool0003oooooo`000?oo
oooo0000ooooo`;o000000Goooooo`000?oooooo0000ooooo`04o`0000Gooooo00?o0000oooooooo
ool01Oooool5o`0000Kooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`03o`0000Go
oooo0ol00003ooooo`04o`000?ooooooooooooooo`;o00000oooool3o`0000?ooooo00?o0000ool0
0?ooool00_ooool3o`0000Sooooo0_l000001?oooooo0000ooooool00003ooooo`;o00002?ooool0
0ol0003oooooo`00000?ooooo`;o00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
ooooo`0000Coo`002oooool00ol0003oooooo`000007ooooo`;o00001?ooool3o`000003ooooool0
003ooooo01Cooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool04_ooool0
1?l0003oooooo`000?l00005ooooo`03o`000?oooooo000000Wooooo00[o0000ooooool0003ooooo
o`000?oooooo0000ooooool0003ooooo0_l000001Ooooooo0000ooooool0003ooooo00Co00001Ooo
ool00ol0003oooooooooo`05ooooo`Go00001_ooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo00?o00001Oooool3o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`?o0000
0oooool00ol0003oo`00ooooo`02ooooo`?o00001?ooool01?l0003oooooooooooooool2o`000004
ooooool0003o0000o`0000?ooooo0_l00008ooooo`03o`000?oooooo000000oooooo0_l00005oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool5ool000Oooooo00?o0000
ooooool000001oooool2o`0000Cooooo0ol000000ooooooo0000ooooo`0Dooooo`03o`000?oooooo
oooo00cooooo000Eooooo`;o00004oooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooo
000000Oooooo00co0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?ooool2
o`000005ooooool0003oooooo`000?ooool01?l00005ooooo`03o`000?oooooooooo00Gooooo1Ol0
0006ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00ol00005ooooo`?o00000ooo
ool01?l0003oooooooooooooool2o`0000?ooooo0ol00003ooooo`03o`000?oo003ooooo00;ooooo
0ol00004ooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?l0003o00000oooool2o`00
0003ooooool0003ooooo00Gooooo00?o0000ooooool000003oooool2o`0000Gooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`07ooooo`Goo`000oooool00ol0003oooooo`000007
ooooo`;o00001?ooool3o`000003ooooool0003ooooo01Cooooo00?o0000ooooooooool03?ooool0
01Gooooo00?o0000ooooooooool04_ooool01?l0003oooooo`000?l00004ooooo`;o000000?ooooo
o`000?ooool01_ooool03?l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000
ooooo`;o000000?oooooo`000?ooool01_l00005ooooo`03o`000?oooooooooo00Gooooo1Ol00006
ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00ol00005ooooo`?o00000oooool0
1?l0003oooooooooooooool3o`0000;ooooo0ol00003ooooo`03o`000?oo003ooooo00;ooooo0ol0
0003ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000
ooooo`03ooooo`05o`000?oooooo0000ooooool000003oooool2o`0000Gooooo00?o0000oooooooo
ool00_l000000ooooooo0000ooooo`0=ooooo`Goo`0000?o0000ooooooooool01Oooool2o`0000Co
oooo0ol000000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`00
0?oooooooooo01;ooooo00Co0000ooooool0003o00001?ooool2o`000003ooooool0003ooooo00Ko
oooo00co0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?ooool2o`000003
ooooool0003ooooo00Ko00001Oooool00ol0003oooooooooo`05ooooo`Go00001Oooool4o`0000Co
oooo00?o0000ooooooooool00ol00005ooooo`?o00000oooool01?l0003oooooooooooooool3o`00
00;ooooo0ol00003ooooo`03o`000?oo003ooooo00;ooooo0ol00003ooooo`;o00000oooool2o`00
0004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000ooooo`03ooooo`04o`000?oooooo
0000ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003ooooooooo
o`02o`000003ooooool0003ooooo013ooooo00?o0000ool00?oo00000ooo00001?oooooo0000oooo
ooooool2o`000004ooooool0003oooooooooo`?o000000?oooooo`000?ooool05?ooool00ol0003o
ooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0Booooo`04o`000?oooooo0000o`0000Co
oooo0_l000000ooooooo0000ooooo`06ooooo`0<o`000?oooooo0000ooooool0003oooooo`000?oo
oooo0000ooooool0003ooooo0_l000000ooooooo0000ooooo`06o`0000Gooooo00?o0000oooooooo
ool01Oooool5o`0000Gooooo1?l000001Ooooooo0000oooooooooooo000000;ooooo0ol00005oooo
o`?o00000oooool01?l0003oooooooooooooool3o`0000;ooooo0ol00003ooooo`03o`000?oo003o
oooo00;ooooo0ol00003ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l0
00000ooooooo0000ooooo`03ooooo`04o`000?oooooo0000ooooo`;o00001oooool00ol0003ooooo
o`000004ooooo`;o00001Oooool2o`000005ooooool0003o0000ooooool000004Oooool01Ol0003o
ooooo`000?oooooo000000Goo`000_l000001?oooooo0000ooooooooool3o`000003ooooool0003o
000000?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0
003oooooooooo`0Booooo`04o`000?oooooo0000o`0000Cooooo0_l000000ooooooo0000ooooo`06
ooooo`0<o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0003ooooo0_l00000
0ooooooo0000ooooo`06o`0000Gooooo00?o0000ooooooooool01Oooool5o`0000Gooooo1_l00002
ooooo`;o000000Coooooo`000?l0003o00001Oooool3o`0000?ooooo0_l00002ooooo`?o00000_oo
ool3o`0000?ooooo00?o0000ool00?ooool00_ooool3o`0000?ooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003o00000oooool2o`000003ooooool0003ooooo00?ooooo00Co0000ooooool0003o
oooo0_l00007ooooo`03o`000?oooooo000000Cooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_l0000Aooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooool00004ool0
00;ooooo0ol000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03?ooool001Gooooo0_l0000Cooooo`04o`000?oooooo0000o`0000Cooooo0_l000000ooo
oooo0000ooooo`06ooooo`0:o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooo`Co
000000?oooooo`000?ooool01_l00005ooooo`04o`000?ooooooooooo`0000Cooooo1Ol00005oooo
o`Ko00000_ooool2o`000004ooooool0003o0000o`0000Gooooo0ol00003ooooo`;o00000_ooool3
o`0000;ooooo0ol00003ooooo`03o`000?oo003ooooo00;ooooo0ol00003ooooo`;o00000oooool2
o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000ooooo`03ooooo`04o`000?oo
oooo0000ooooo`;o00001oooool00ol0003oooooo`000004ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;o00004Oooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000oooooooo
ool00_l000000oooooooo`00ool00003ool00004o`000?oooooo0000o`0000?ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0Booooo`04
o`000?oooooo0000o`0000Cooooo0_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooo0000
00;o000000Ooooooo`000?oooooo0000ooooool0003ooooo00Co000000?oooooo`000?ooool01_l0
0005ooooo`04o`000?ooooooooooo`0000Cooooo1Ol00005ooooo`Ko00000_ooool2o`000004oooo
ool0003o0000o`0000Gooooo0ol00003ooooo`;o00000_ooool3o`0000;ooooo0ol00003ooooo`03
o`000?oo003ooooo00;ooooo0ol00002ooooo`?o00000oooool2o`000003ooooool0003o000000;o
00000_ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooool000000ol00007ooooo`03
o`000?oooooo000000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0000Aooooo`05
o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`000004ooooool0003ooooo
ooooo`;o00001?oo0003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool0
00_ooooo1Ol00005ooooo`03o`000?oooooooooo01;ooooo00Co0000ooooool0003o00001?ooool2
o`000003ooooool0003ooooo00Cooooo00?o0000ooooool000000_l000001ooooooo0000ooooool0
003oooooo`000?ooool01?l000000ooooooo0000ooooo`06o`0000Gooooo00Co0000oooooooooooo
00001?ooool5o`0000Gooooo1_l00002ooooo`;o000000Coooooo`000?l0003o00001Oooool3o`00
00?ooooo0_l00002ooooo`?o00000_ooool3o`0000?ooooo00?o0000ool00?ooool00_ooool3o`00
00;ooooo0ol00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`00
0?l000000oooool00ol0003oooooo`000003o`0000Oooooo00?o0000ooooool000001?ooool2o`00
00Gooooo0_l000000ooooooo0000o`000002o`00017ooooo00Go0000ooooool0003oooooo`000002
ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool01?l000000ooooooo0000o`000005
ool000oooooo00?o0000ooooooooool03?ooool000cooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`0Booooo`04o`000?oooooo0000o`0000Cooooo0_l000000ooooooo0000oooo
o`04ooooo`Go000000Ooooooo`000?oooooo0000ooooool0003ooooo00Co000000?oooooo`000?oo
ool01_l00005ooooo`04o`000?ooooooooooo`0000Cooooo1Ol00005ooooo`Ko00000_ooool2o`00
0003ooooool0003o000000;o00001?ooool3o`0000?ooooo0_l00002ooooo`?o00000_ooool3o`00
00?ooooo00?o0000ool00?ooool00_ooool3o`0000;ooooo0ol00003ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooo`000003o`00
00Oooooo00Go0000ooooool0003oooooo`000002ooooo`;o00001Oooool2o`000003ooooool0003o
000000;o00004Oooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_l0
00000ooooooo0000ooooo`04o`000003ooooool0003o000000?ooooo00?o0000ool00?oo00000ooo
000;ooooo`03o`000?oooooooooo00cooooo0005ooooo`Go00000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo017ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?ooooo
o`000?ooool01?ooool5o`000007ooooool0003oooooo`000?oooooo0000ooooo`04o`000003oooo
ool0003ooooo00Ko00001Oooool01?l0003oooooooooool00004ooooo`Go00001Oooool6o`0000;o
oooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol00003ooooo`;o00000_ooool3o`0000;o
oooo0ol00003ooooo`03o`000?oo003ooooo00;ooooo0ol00002ooooo`?o00000oooool2o`000003
ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooool0
00000ol00007ooooo`?o000000Coooooo`000?oooooooooo0_l00005ooooo`;o000000?oooooo`00
0?l000000_l0000Aooooo`06o`000?oooooo0000ooooool0003ooooo0_l00002ooooo`;o000000?o
ooooo`000?ooool01?l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooooooo00;ooooo
1Ooo0007ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo00Cooooo0_l0
000Booooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003ooooo00Cooooo1Ol0
00001ooooooo0000ooooool0003oooooo`000?ooool01?l000000ooooooo0000ooooo`07o`0000Co
oooo00Co0000oooooooooooo00001?ooool5o`0000Gooooo1_l00002ooooo`;o000000?oooooo`00
0?l000000_l00004ooooo`?o00000oooool2o`0000;ooooo0ol00002ooooo`?o00000oooool00ol0
003oo`00ooooo`02ooooo`?o00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`00
00;ooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooo000000?o00001oooool3o`00
0004ooooool0003oooooooooo`;o00001?ooool8o`00017ooooo00Ko0000ooooool0003oooooo`00
0?ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`04o`000004ooooool0003o0000o`0000;o
oooo00?o0000ooooooooool01_ooool5ool000?ooooo00?o0000ooooooooool03?ooool000_ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo017ooooo0_l000000ooooooo
0000o`000004ooooo`;o000000?oooooo`000?ooool01?ooool5o`000007ooooool0003oooooo`00
0?oooooo0000ooooo`04o`000003ooooool0003ooooo00Oo00001?ooool01?l0003oooooooooool0
0004ooooo`Go00001Oooool6o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol0
0003ooooo`;o00000_ooool3o`0000;ooooo0ol00003ooooo`03o`000?oo003ooooo00;ooooo0ol0
0002ooooo`?o00000_ooool3o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0
003o000000?ooooo00?o0000ooooool000000ol00007ooooo`Go00000_ooool2o`0000Cooooo2?l0
000Aooooo`06o`000?oooooo0000ooooool0003ooooo0_l00002ooooo`;o000000?oooooo`000?oo
ool01?l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooooooo00[ooooo1Ooo000>oooo
o`002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool04Oooool2o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooo0000
00Co000000Goooooo`000?oooooo0000ooooo`06o`000003ooooool0003ooooo00Oo00001?ooool0
1?l0003oooooooooool00004ooooo`Go00001Oooool6o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0ol00003ooooo`;o00000_ooool3o`0000;ooooo0ol00003ooooo`03o`000?oo
003ooooo00;ooooo0ol00002ooooo`?o00000_ooool3o`000003ooooool0003o000000;o00000_oo
ool2o`000004ooooool0003o0000o`0000;ooooo00?o0000ooooool000000ol00007ooooo`Go0000
0_ooool2o`0000Cooooo2?l0000Aooooo`06o`000?oooooo0000ooooool0003ooooo0_l00002oooo
o`;o000000?oooooo`000?ooool01?l000000ooooooo0000o`000002o`000003ooooool0003ooooo
00oooooo0_oo000=ooooo`003?ooool3o`0000Kooooo00?o0000ooooooooool04Oooool2o`000003
ooooool0003o000000;ooooo00Ko0000ooooool0003o0000ooooool00003ooooo`03o`000?oooooo
000000Co000000Goooooo`000?oooooo0000ooooo`06o`000003ooooool0003ooooo00Oo00001?oo
ool2o`000003ooooool0003ooooo00;ooooo1_l00005ooooo`Ko00000_ooool2o`000003ooooool0
003o000000;o00001?ooool3o`0000?ooooo0_l00002ooooo`?o00000_ooool3o`0000?ooooo00?o
0000ool00?ooool00_ooool3o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000000_l0
0002ooooo`;o000000Coooooo`000?l0003o00000_ooool00ol0003oooooo`000003o`0000Oooooo
1Ol00002ooooo`;o00001?ooool8o`00017ooooo00Ko0000ooooool0003oooooo`000?ooool2o`00
00;ooooo0_l000000ooooooo0000ooooo`04o`000003ooooool0003o000000;o000000?oooooo`00
0?ooool03oooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0Aooooo`;o
000000?oooooo`000?l000000_ooool01_l0003oooooo`000?l0003oooooo`0000?ooooo00?o0000
ooooool000001?l000001Ooooooo0000ooooool0003ooooo00Ko000000?oooooo`000?ooool01ol0
00001?oooooo0000ooooooooool2o`000003ooooool0003ooooo00;ooooo1_l00005ooooo`Ko0000
0_ooool2o`000003ooooool0003o000000;o00001?ooool3o`0000?ooooo0_l00002ooooo`?o0000
0_ooool3o`0000?ooooo00?o0000ool00?ooool00_ooool3o`0000;ooooo0ol00002ooooo`?o0000
00?oooooo`000?l000000_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool00ol0003o
ooooo`000003o`0000Oooooo1_l000000ooooooo0000o`000004ooooo`Wo00004?ooool01_l0003o
ooooo`000?oooooo0000ooooo`;o00000_ooool2o`000003ooooool0003ooooo00Co000000?ooooo
o`000?l000000_l000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo00cooooo000Eoooo
o`;o00004_ooool2o`000003ooooool0003o000000;ooooo00Ko0000ooooool0003o0000ooooool0
0003ooooo`Oo000000Goooooo`000?oooooo0000ooooo`06o`000003ooooool0003o000000Oo0000
00Coooooo`000?oooooooooo0_l000001?oooooo0000ooooooooool7o`0000Gooooo1_l00002oooo
o`;o000000?oooooo`000?l000000_l00004ooooo`Co00000_ooool2o`0000;ooooo0ol00002oooo
o`?o00000oooool00ol0003oo`00ooooo`02ooooo`?o00000_ooool3o`0000;ooooo0ol000000ooo
oooo0000o`000002o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooo
000000?o000000?oooooo`000?ooool01?ooool6o`000003ooooool0003o000000Cooooo2Ol0000@
ooooo`06o`000?oooooo0000ooooool0003ooooo0_l00002ooooo`;o000000?oooooo`000?ooool0
1?l000000ooooooo0000o`000002o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool0
3?ooool001Gooooo00?o0000ooooooooool04Oooool2o`000003ooooool0003o000000;ooooo00Ko
0000ooooool0003o0000ooooool00003ooooo`Oo000000Goooooo`000?oooooo0000ooooo`06o`00
0003ooooool0003o000000Oo000000Coooooo`000?oooooooooo0_l000001?oooooo0000oooooooo
ool7o`0000?ooooo00?o0000ooooool000001Ol00002ooooo`;o000000?oooooo`000?l000000_l0
0004ooooo`Co00000_ooool2o`0000;ooooo0ol00002ooooo`?o00000oooool00ol0003oo`00oooo
o`02ooooo`?o00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l0
00001?oooooo0000o`000?l00002ooooo`03o`000?oooooo000000?o000000?oooooo`000?ooool0
1?ooool6o`000003ooooool0003o000000Cooooo2Ol0000@ooooo`06o`000?oooooo0000ooooool0
003ooooo0_l00002ooooo`;o000000?oooooo`000?ooool02Ol000000ooooooo0000ooooo`0?oooo
o`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo017ooooo0_l000001ooooooo
0000o`000?l0003oooooo`000?ooool00_l000000ooooooo0000ooooo`02ooooo`Oo000000Gooooo
o`000?oooooo0000ooooo`06o`000003ooooool0003o000000Oo000000Coooooo`000?oooooooooo
0_l000001?oooooo0000ooooooooool7o`0000?ooooo00?o0000ooooool000001Ol00002ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`Co00000_ooool2o`0000;ooooo0ol00002ooooo`?o
00000oooool00ol0003oo`00ooooo`02ooooo`?o00000_ooool3o`0000;ooooo0ol000000ooooooo
0000o`000002o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooo0000
00?o000000?oooooo`000?ooool01?ooool6o`000003ooooool0003o000000Cooooo2Ol00002oooo
o`03o`000?oooooooooo00_ooooo00Ko0000ooooool0003oooooo`000?ooool2o`0000;ooooo0_l0
00000ooooooo0000ooooo`09o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool03?oo
ool001Gooooo00?o0000ooooooooool04Oooool2o`000007ooooool0003o0000o`000?oooooo0000
ooooo`02o`000003ooooool0003ooooo00;ooooo1ol000001Ooooooo0000ooooool0003ooooo00Ko
000000?oooooo`000?l000001ol000001?oooooo0000ooooooooool2o`000004ooooool0003ooooo
ooooo`Oo00000_ooool2o`000003ooooool0003o000000Co00000_ooool2o`000003ooooool0003o
000000;o00001?ooool4o`0000;ooooo0_l00002ooooo`?o00000_ooool3o`0000?ooooo00?o0000
ool00?ooool00_ooool3o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000000_l00002
ooooo`;o000000Coooooo`000?l0003o00000_ooool00ol0003oooooo`000003o`000003ooooool0
003ooooo00Cooooo1_l000000ooooooo0000o`000004ooooo`Wo00000_ooool00ol0003ooooooooo
o`0;ooooo`06o`000?oooooo0000ooooool0003ooooo0ol000001_oooooo0000o`000?oooooo0000
ooooo`Wo000000?oooooo`000?ooool03oooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0
003oooooooooo`0Aooooo`;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o000000Go
ooooo`000?oooooo0000ooooo`07o`000005ooooool0003oooooo`000?ooool01_l000000ooooooo
0000o`000007o`000004ooooool0003oooooooooo`;o000000Coooooo`000?oooooooooo1ol00002
ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o000000?oooooo`000?l000000_l00004
ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00000_ooool3o`0000?ooooo00?o0000
ool00?ooool00_ooool3o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000000_l00002
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o000000?o
ooooo`000?ooool01?ooool6o`000003ooooool0003o000000Cooooo2Ol00002ooooo`03o`000?oo
oooooooo00_ooooo00Ko0000ooooool0003oooooo`000?ooool3o`000006ooooool0003o0000oooo
ool0003ooooo2Ol000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo00cooooo000Eoooo
o`;o00004_ooool6o`000003ooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`07
o`000005ooooool0003oooooo`000?ooool01_l000000ooooooo0000o`000007o`000004ooooool0
003oooooooooo`;o000000Coooooo`000?oooooooooo1ol00002ooooo`;o000000?oooooo`000?l0
00001?l00002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co00000_ooool2o`000003
ooooool0003o000000;o00000_ooool3o`0000?ooooo00?o0000ool00?ooool00_ooool3o`0000;o
oooo0ol00002ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o000000Goooooo`000?l0
003o0000ooooo`02o`000003ooooool0003o000000Co00001Oooool6o`000003ooooool0003o0000
00Cooooo2Ol00002ooooo`03o`000?oooooo000000_ooooo00Ko0000ooooool0003oooooo`000?oo
ool6o`000003ooooool0003ooooo00Wo000000?oooooo`000?ooool03oooool00ol0003ooooooooo
o`0<ooooo`005Oooool00ol0003oooooooooo`0Aooooo`Ko000000?oooooo`000?ooool00_l00000
1Ooooooo0000ooooool0003ooooo00Oo000000Goooooo`000?oooooo0000ooooo`06o`000003oooo
ool0003o000000Oo000000Coooooo`000?oooooooooo0_l000001?oooooo0000ooooooooool7o`00
00;ooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00Cooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000oooool00ol0
003oo`00ooooo`02ooooo`?o00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000002o`00
00;ooooo1_l000001?oooooo0000o`000?ooool6o`0000Gooooo1_l000000ooooooo0000o`000004
ooooo`Wo00000_ooool00ol0003oooooo`00000;ooooo`06o`000?oooooo0000ooooool0003ooooo
1_l000000ooooooo0000ooooo`09o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool0
3?ooool001Gooooo00?o0000ooooooooool04Oooool6o`000003ooooool0003ooooo00;o000000Go
ooooo`000?oooooo0000ooooo`09o`000003ooooool0003ooooo00Ko000000?oooooo`000?l00000
1ol000001?oooooo0000ooooooooool2o`000004ooooool0003oooooooooo`Oo00000_ooool2o`00
0003ooooool0003o000000Co00000_ooool2o`000003ooooool0003o000000;o00001?ooool4o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol00003ooooo`03ool00?l0003ooooo
00;ooooo0ol00002ooooo`?o00000_ooool3o`000003ooooool0003o000000;o00000_ooool6o`00
0004ooooool0003o0000ooooo`Oo00001?ooool6o`000003ooooool0003o000000Cooooo2Ol00002
ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool01_l0003oooooo`000?oo
oooo0000ooooo`Ko000000?oooooo`000?ooool02Ol000000ooooooo0000ooooo`0?ooooo`03o`00
0?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo017ooooo1_l000000ooooooo0000oooo
o`02o`000005ooooool0003oooooo`000?ooool02Ol000000ooooooo0000ooooo`06o`000003oooo
ool0003o000000Oo000000Coooooo`000?l0003ooooo0_l000001?oooooo0000ooooooooool7o`00
00;ooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00Cooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`00
00?ooooo00?oo`00o`000?ooool00_ooool3o`0000;ooooo0ol00002ooooo`?o000000?oooooo`00
0?l000000_l00002ooooo`Ko000000Coooooo`000?l0003ooooo1ol00004ooooo`Ko000000?ooooo
o`000?l000001?ooool9o`0000;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`04
ooooo`06o`000?oooooo0000ooooool0003ooooo1_l000000ooooooo0000ooooo`09o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool04Ooo
ool6o`000003ooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`09o`000003oooo
ool0003ooooo00Ko000000?oooooo`000?l000001ol000001?oooooo0000o`000?ooool2o`000004
ooooool0003oooooooooo`?o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o
000000Co00000_ooool2o`000003ooooool0003o000000;o00001?ooool4o`0000;ooooo0_l00000
0ooooooo0000o`000002o`000005ooooool0003o0000ooooool000000oooool00ooo003o0000oooo
o`02ooooo`?o00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000002o`0000;ooooo1_l0
00001?oooooo0000o`000?ooool7o`0000Cooooo1_l000000ooooooo0000o`000004ooooo`Wo0000
0_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000Kooooo00Ko0000ooooool0003o
ooooo`000?ooool6o`000003ooooool0003ooooo00Wo000000?oooooo`000?ooool03oooool00ol0
003oooooooooo`0<ooooo`005Oooool2o`0001;ooooo1_l000000ooooooo0000ooooo`02o`000005
ooooool0003oooooo`000?ooool02Ol000000ooooooo0000ooooo`06o`000003ooooool0003o0000
00Oo000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool3o`000004ooooool0
003o0000o`0000;ooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l000000ooooooo0000
o`000002o`0000Cooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l000001Ooooooo0000
o`000?oooooo000000?ooooo00?oo`00o`000?ooool00_ooool3o`0000;ooooo1?l000001Ooooooo
0000o`000?l0003ooooo00Co00000_ooool6o`000004ooooool0003o0000ooooo`Oo00001?ooool6
o`000003ooooool0003o000000Cooooo2Ol00002ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooool000001_ooool01_l0003oooooo`000?oooooo0000ooooo`Ko000000?oooooo`000?ooool0
2Ol000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oo
oooooooo017ooooo1_l000000ooooooo0000ooooo`02o`000005ooooool0003oooooo`000?ooool0
2Ol000000ooooooo0000ooooo`06o`000003ooooool0003o000000Oo000000Coooooo`000?l0003o
oooo0_l000001?oooooo0000o`000?ooool3o`000004ooooool0003o0000o`0000;ooooo0_l00000
0ooooooo0000o`000004o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo1?l00002
ooooo`;o000000?oooooo`000?l000000_l000001Ooooooo0000o`000?oooooo000000?ooooo00?o
o`00o`000?ooool00_ooool01Ol0003oooooo`000?l0003ooooo00Co000000Goooooo`000?l0003o
0000ooooo`04o`0000;ooooo1_l000001?oooooo0000o`000?ooool7o`0000Cooooo1_l000000ooo
oooo0000o`000004ooooo`Wo00000_ooool01?l0003oooooo`000?ooool2o`000003ooooool0003o
oooo00Gooooo00Ko0000ooooool0003oooooo`000?ooool6o`000003ooooool0003ooooo00Wo0000
00?oooooo`000?ooool03oooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003ooooooooo
o`0Aooooo`Ko000000?oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00Wo0000
00?oooooo`000?ooool01_l000000ooooooo0000o`000007o`000004ooooool0003o0000ooooo`;o
000000Coooooo`000?l0003ooooo0ol000001?oooooo0000o`000?l00002ooooo`;o000000?ooooo
o`000?l000001?l00002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co00000_ooool2
o`000003ooooool0003o000000;o000000Goooooo`000?l0003oooooo`000003ooooo`03ool00?l0
003ooooo00;ooooo00Go0000ooooool0003o0000ooooo`04o`000005ooooool0003o0000o`000?oo
ool01?l00002ooooo`Ko000000Coooooo`000?l0003ooooo1ol00004ooooo`Ko000000?oooooo`00
0?l000001?ooool9o`0000;ooooo00Co0000ooooool0003ooooo0_l000001?oooooo0000ooooool0
0004ooooo`06o`000?oooooo0000ooooool0003ooooo1_l000000ooooooo0000ooooo`09o`000003
ooooool0003ooooo00oooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool0
4Oooool6o`000003ooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`09o`000003
ooooool0003ooooo00Ko000000?oooooo`000?l000001ol000001?oooooo0000o`000?ooool2o`00
0004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0
003o000000Co00000_ooool2o`000003ooooool0003o000000;o00001?ooool4o`0000;ooooo0_l0
00000ooooooo0000o`000002o`000005ooooool0003o0000ooooool000000oooool00ooo003o0000
ooooo`02ooooo`05o`000?oooooo0000o`000?ooool01?l000001Ooooooo0000o`000?l0003ooooo
00Co00000_ooool6o`000004ooooool0003o0000ooooo`Oo00001?ooool6o`000003ooooool0003o
000000Cooooo2_l000001Ooooooo0000ooooool0003ooooo00;o000000Koooooo`000?oooooo0000
ooooool00002ooooo`06o`000?oooooo0000ooooool0003ooooo1_l000000ooooooo0000o`000009
o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000oooo
ooooool04Oooool6o`000003ooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`09
o`000003ooooool0003ooooo00Ko000000Goooooo`000?l0003o0000ooooo`05o`000004ooooool0
003o0000ooooo`;o000000Coooooo`000?l0003ooooo0ol000001?oooooo0000o`000?l00002oooo
o`;o000000?oooooo`000?l000001?l00002ooooo`;o000000?oooooo`000?l000000_l00004oooo
o`Co00000_ooool2o`000003ooooool0003o000000;o000000Goooooo`000?l0003oooooo`000003
ooooo`03ool00?l0003ooooo00;ooooo00Go0000ooooool0003o0000ooooo`04o`000005ooooool0
003o0000o`000?ooool01?l00002ooooo`Ko000000Coooooo`000?l0003ooooo1ol00004ooooo`Ko
000000?oooooo`000?l000001?ooool:o`000005ooooool0003oooooo`000?ooool00_l000001_oo
oooo0000ooooool0003oooooo`0000;ooooo00Ko0000ooooool0003oooooo`000?ooool6o`000003
ooooool0003o000000Wo000000?oooooo`000?ooool03oooool00ol0003oooooooooo`0<ooooo`00
5Oooool2o`0001;ooooo1_l000000ooooooo0000ooooo`02o`000005ooooool0003oooooo`000?oo
ool02Ol000000ooooooo0000o`000006o`000005ooooool0003o0000o`000?ooool01Ol000001?oo
oooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003o0000
0_ooool9o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo1?l00002ooooo`;o0000
00?oooooo`000?l000000_l000001Ooooooo0000o`000?oooooo000000?ooooo00?oo`00o`000?oo
ool00_ooool01Ol0003oooooo`000?l0003ooooo00Co000000Goooooo`000?l0003o0000ooooo`04
o`0000;ooooo1_l000001?oooooo0000o`000?ooool7o`0000Cooooo1_l000000ooooooo0000o`00
0004ooooo`[o000000Goooooo`000?oooooo0000ooooo`02o`000006ooooool0003oooooo`000?oo
oooo00000_ooool01_l0003oooooo`000?oooooo0000ooooo`Ko000000?oooooo`000?l000002Ol0
00000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooo
oooo017ooooo1_l000000ooooooo0000ooooo`02o`000005ooooool0003oooooo`000?ooool02Ol0
00000ooooooo0000o`000006o`000005ooooool0003o0000o`000?ooool01Ol000001?oooooo0000
o`000?ooool2o`000004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003o00000_ooool9
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo1?l00002ooooo`;o000000?ooooo
o`000?l000000_l000001Ooooooo0000oooooooooooo000000?ooooo00?oo`00o`000?ooool00_oo
ool01Ol0003oooooo`000?l0003ooooo00Co000000Goooooo`000?l0003o0000ooooo`04o`0000;o
oooo1_l000001?oooooo0000o`000?ooool7o`0000Cooooo1_l000000ooooooo0000o`000004oooo
o`[o000000Goooooo`000?oooooo0000ooooo`02o`000007ooooool0003oooooo`000?oooooo0000
ooooo`02o`000005ooooool0003oooooo`000?ooool01_l000000ooooooo0000o`000009o`000003
ooooool0003ooooo00oooooo00?o0000ooooooooool03?ooool000cooooo0ol00006ooooo`03o`00
0?oooooooooo017ooooo1_l000000ooooooo0000ooooo`06o`000003ooooool0003o000000Oo0000
00?oooooo`000?l000002_l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o
000000Coooooo`000?l0003ooooo0ol000001?oooooo0000o`000?l00002ooooo`Wo00000_ooool2
o`000003ooooool0003o000000;o00001?ooool4o`0000;ooooo0_l000000ooooooo0000o`000002
o`000005ooooool0003oooooooooool000000oooool00ooo003o0000ooooo`02ooooo`05o`000?oo
oooo0000o`000?ooool01?l000001ooooooo0000o`000?l0003oooooo`000?ooool00_l00002oooo
o`Ko000000Coooooo`000?l0003ooooo1ol00004ooooo`Ko000000Goooooo`000?l0003oooooo`00
0002ooooo`[o000000Goooooo`000?oooooo0000ooooo`02o`000007ooooool0003oooooo`000?oo
oooo0000ooooo`02o`000005ooooool0003oooooo`000?ooool01_l000000ooooooo0000o`000009
o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0@ooooo`Oo000000?oooooo`000?ooool01_l000000ooo
oooo0000o`000007o`000003ooooool0003o000000[o000000?oooooo`000?l000000ol000001?oo
oooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003o0000
0_ooool9o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo1?l00002ooooo`;o0000
00?oooooo`000?l000000_l000001Ooooooo0000oooooooooooo000000?ooooo00?oo`00o`000?oo
ool00_ooool01Ol0003oooooo`000?l0003ooooo00Co000000Ooooooo`000?l0003o0000ooooool0
003ooooo00;o00000_ooool6o`000004ooooool0003o0000ooooo`Oo00001?ooool6o`000005oooo
ool0003o0000ooooool000000_ooool<o`000003ooooool0003ooooo00;o000000Ooooooo`000?oo
oooo0000ooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`06o`000003ooooool0
003o000000Wo000000?oooooo`000?ooool03oooool00ol0003oooooooooo`0<ooooo`001Oooool5
o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`Oo000000?ooooo
o`000?ooool01_l000000ooooooo0000o`000007o`000003ooooool0003o000000[o000000?ooooo
o`000?l000000ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`?o0000
00Coooooo`000?l0003o00000_ooool9o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Co
oooo1?l00002ooooo`;o000000?oooooo`000?l000000_l000001Ooooooo0000oooooooooooo0000
00?ooooo00?oo`00o`000?ooool00_ooool01Ol0003oooooooooool0003ooooo00Co000000Oooooo
o`000?l0003o0000ooooool0003ooooo00;o00000_ooool6o`000004ooooool0003o0000ooooo`Oo
00001?ooool6o`000005ooooool0003o0000ooooool000000_ooool<o`000003ooooool0003ooooo
00;o000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000Goooooo`000?oooooo0000
ooooo`06o`000003ooooool0003o000000Wo000000?oooooo`000?ooool03oooool00ol0003ooooo
ooooo`0<ooooo`003Oooool00ol0003oooooooooo`05ooooo`;o00004Oooool7o`000003ooooool0
003ooooo013o000000?oooooo`000?l000002_l000000ooooooo0000o`000003o`000004ooooool0
003o0000ooooo`;o000000Coooooo`000?l0003ooooo0ol000001?oooooo0000o`000?l00002oooo
o`[o000000Coooooo`000?l0003ooooo1?l000001_oooooo0000oooooooooooo0000ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;o000000Goooooo`000?ooooooooooo`000003ooooo`03
ool00?l0003ooooo00;ooooo00Go0000oooooooooooo0000ooooo`04o`000007ooooool0003o0000
o`000?oooooo0000ooooo`02o`0000;ooooo1_l000001?oooooo0000o`000?ooool7o`0000Cooooo
1_l000001Ooooooo0000o`000?oooooo000000;ooooo3?l000000ooooooo0000ooooo`02o`000007
ooooool0003oooooo`000?oooooo0000ooooo`02o`000005ooooool0003oooooo`000?ooool01_l0
00000ooooooo0000o`000009o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool03?oo
ool000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`Oo000000?ooooo
o`000?ooool04?l000000ooooooo0000o`00000:o`000003ooooool0003o000000?o000000Cooooo
o`000?l0003ooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000;o0000
00?oooooo`000?l000002?l000001?oooooo0000o`000?ooool4o`000006ooooool0003o0000oooo
ool0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l000001Ooooooo0000oooooooo
oooo000000;ooooo00Co0000ool00?l0003o00000_ooool01Ol0003oooooooooool0003ooooo00Co
000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o00000_ooool6o`000004ooooool0003o
0000ooooo`Oo000000Coooooo`000?oooooooooo1_l000001Ooooooo0000o`000?oooooo000000;o
oooo3?l000000ooooooo0000ooooo`02o`000007ooooool0003oooooo`000?oooooo0000ooooo`04
o`000003ooooool0003ooooo00Ko000000?oooooo`000?l000002Ol000000ooooooo0000ooooo`0?
ooooo`03o`000?oooooooooo00cooooo000<ooooo`;o00001oooool00ol0003oooooooooo`0@oooo
o`Wo000000?oooooo`000?l000003_l000000ooooooo0000o`00000:o`000003ooooool0003o0000
00?o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0
003o000000;o000000?oooooo`000?l000002?l000001?oooooo0000o`000?ooool4o`000006oooo
ool0003o0000ooooool0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l000001Ooo
oooo0000oooooooooooo000000;ooooo00Co0000ool00?l0003o00000_ooool01Ol0003ooooooooo
ool0003ooooo00Co000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o00000_ooool6o`00
0004ooooool0003o0000ooooo`Oo000000Coooooo`000?oooooooooo2Ol000001?oooooo0000oooo
ooooool<o`000003ooooool0003ooooo00;o000000Ooooooo`000?oooooo0000ooooool0003ooooo
00Co000000?oooooo`000?ooool01_l000000ooooooo0000o`000009o`000003ooooool0003ooooo
00oooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0@ooooo`Wo000000?oooooo`000?l000003_l000000ooooooo0000o`000007o`000004
ooooool0003o0000ooooo`Go000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?oo
ool3o`000003ooooool0003o000000;o000000?oooooo`000?l000002?l000001?oooooo0000o`00
0?ooool4o`000006ooooool0003o0000ooooool0003ooooo0_l00002ooooo`Oo000000Goooooo`00
0?ooooooooooo`000002ooooo`04o`000?oo003o0000o`0000;ooooo00Go0000oooooooooooo0000
ooooo`04o`000007ooooool0003o0000o`000?oooooo0000ooooo`02o`0000;ooooo1_l000001?oo
oooo0000o`000?ooool7o`000004ooooool0003oooooooooo`Wo000000Coooooo`000?oooooooooo
3?l000000ooooooo0000ooooo`02o`000007ooooool0003oooooo`000?oooooo0000ooooo`04o`00
0003ooooool0003ooooo00Ko000000?oooooo`000?l000002Ol000000ooooooo0000ooooo`0?oooo
o`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo013ooooo2Ol000000ooooooo
0000o`00000>o`000003ooooool0003o000000Oo000000Coooooo`000?l0003ooooo2?l000001?oo
oooo0000o`000?ooool2o`000005ooooool0003o0000o`000?ooool01?l000000ooooooo0000o`00
0008o`000004ooooool0003o0000ooooo`Co000000Koooooo`000?l0003oooooo`000?ooool2o`00
00;ooooo1ol000001Ooooooo0000oooooooooooo000000;ooooo00Co0000ool00?l0003o00000_oo
ool01Ol0003oooooooooool0003ooooo00Co000000Ooooooo`000?l0003o0000ooooool0003ooooo
00;o00000_ooool6o`000004ooooool0003o0000ooooo`Oo000000Coooooo`000?l0003ooooo2Ol0
00001?oooooo0000ooooooooool<o`000003ooooool0003ooooo00;o000000Ooooooo`000?oooooo
0000ooooool0003ooooo00Co000000?oooooo`000?ooool01_l000000ooooooo0000o`000009o`00
0003ooooool0003ooooo00oooooo00?o0000ooooooooool03?ooool001Gooooo0_l0000Aooooo`Wo
000000?oooooo`000?l000003_l000000ooooooo0000o`000007o`000004ooooool0003o0000oooo
o`So000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co000000?o
ooooo`000?l000002?l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000_ooool7o`000005ooooool0003oooooooooool000000_ooool01?l0003o
o`00o`000?l00002ooooo`05o`000?ooooooooooo`000?ooool01?l000001ooooooo0000o`000?l0
003oooooo`000?ooool00_l00002ooooo`Ko000000Coooooo`000?l0003ooooo1ol000001?oooooo
0000o`000?ooool9o`000004ooooool0003oooooooooo`co000000?oooooo`000?ooool00_l00000
1ooooooo0000ooooool0003oooooo`000?ooool01?l000000ooooooo0000ooooo`06o`000003oooo
ool0003o000000Wo000000?oooooo`000?ooool03oooool00ol0003oooooooooo`0<ooooo`005Ooo
ool00ol0003oooooooooo`0@ooooo`Wo000000?oooooo`000?l000003_l000000ooooooo0000o`00
0007o`000004ooooool0003o0000ooooo`So000000Coooooo`000?l0003ooooo0_l000001Ooooooo
0000o`000?l0003ooooo00oo000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002
o`000003ooooool0003o000000;ooooo1ol000001Ooooooo0000oooooooooooo000000;ooooo00Co
0000ool00?l0003o00000_ooool01Ol0003oooooooooool0003ooooo00Co000000Ooooooo`000?l0
003o0000ooooool0003ooooo00;o00000_ooool6o`000004ooooool0003o0000ooooo`Oo000000Co
ooooo`000?l0003ooooo2Ol000000ooooooo0000ooooo`0=o`000003ooooool0003ooooo00Co0000
00Goooooo`000?oooooo0000ooooo`04o`000003ooooool0003ooooo00Ko000000?oooooo`000?l0
00002Ol000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`00
0?oooooooooo013ooooo2Ol000000ooooooo0000o`00000>o`000003ooooool0003o000000Oo0000
00Coooooo`000?l0003ooooo2?l000001?oooooo0000o`000?ooool2o`000005ooooool0003o0000
o`000?ooool03ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000_ooool7o`000005ooooool0003oooooooooool000000_ooool01?l0003oo`00
o`000?l00002ooooo`05o`000?ooooooooooo`000?ooool01?l000001ooooooo0000o`000?l0003o
ooooo`000?ooool00_l00002ooooo`Ko000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000002o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?ooool03Ol000000ooooooo
0000ooooo`04o`000005ooooool0003oooooo`000?ooool01_l000000ooooooo0000o`000004o`00
0003ooooool0003o000000Wo000000?oooooo`000?ooool03oooool00ol0003oooooooooo`0<oooo
o`005Oooool00ol0003oooooooooo`0@ooooo`Wo000000?oooooo`000?l000004Ol000000ooooooo
0000o`000004o`000004ooooool0003o0000ooooo`So000000Coooooo`000?l0003ooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00oo000000Coooooo`000?l0003ooooo1?l000000ooooooo0000
o`000002o`000003ooooool0003o000000;ooooo1ol000001Ooooooo0000oooooooooooo000000;o
oooo00Co0000ool00?l0003o00000_ooool01Ol0003oooooooooool0003ooooo00Co000000Oooooo
o`000?l0003o0000ooooool0003ooooo00;o00000_ooool6o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool9o`000003ooooool0003ooooo
00go000000?oooooo`000?ooool01?l000001Ooooooo0000ooooool0003ooooo00Ko000000?ooooo
o`000?l000001?l000000ooooooo0000o`000009o`000003ooooool0003ooooo00oooooo00?o0000
ooooooooool03?ooool001Gooooo00?o0000ooooooooool04?ooool9o`000003ooooool0003o0000
017o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool8o`000004ooooool0003o
0000ooooo`;o000000Goooooo`000?l0003o0000ooooo`0?o`000004ooooool0003o0000ooooo`Co
000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`Oo000000Goooooo`000?oo
ooooooooo`000002ooooo`04o`000?oo003o0000o`0000;ooooo00Go0000oooooooooooo0000oooo
o`04o`000007ooooool0003o0000o`000?oooooo0000ooooo`02o`0000;ooooo1_l000001?oooooo
0000o`000?ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo2Ol00000
0ooooooo0000ooooo`0=o`000003ooooool0003ooooo00Co000000Goooooo`000?oooooo0000oooo
o`06o`000003ooooool0003o000000Co000000?oooooo`000?l000002Ol000000ooooooo0000oooo
o`0?ooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00004OoooolMo`000003ooooool0003o
000000Co000000Coooooo`000?l0003ooooo2ol000001?oooooo0000o`000?ooool3o`000003oooo
ool0003o0000013o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000;ooooo1ol000001Ooooooo0000oooooooooooo000000;ooooo00Co0000ool00?l0
003o00000_ooool01Ol0003oooooooooool0003ooooo00So000000Goooooo`000?ooooooooooo`00
0002ooooo`Ko000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`000004oooo
ool0003o0000ooooo`Wo000000?oooooo`000?ooool03Ol000000ooooooo0000ooooo`04o`000005
ooooool0003oooooo`000?ooool01_l000000ooooooo0000o`000004o`000003ooooool0003o0000
00_o00004?ooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0@oooooago
000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool;o`000004ooooool0003o0000
ooooo`?o000000?oooooo`000?l000005Ol000000ooooooo0000o`000002o`000003ooooool0003o
000000;ooooo00?o0000ooooool000001?l000001Ooooooo0000oooooooooooo000000;ooooo00Co
0000ool00?l0003o00000_ooool01Ol0003oooooooooool0003ooooo00So000000Goooooo`000?oo
ooooooooo`000002ooooo`Ko000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002
o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?ooool03Ol000000ooooooo0000oooo
o`04o`000005ooooool0003oooooo`000?ooool01_l000000ooooooo0000o`000004o`000003oooo
ool0003o000000_o00004?ooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003ooooooooo
o`0@oooooago000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool;o`000004oooo
ool0003o0000ooooo`?o000000?oooooo`000?l000005Ol000000ooooooo0000o`000002o`000003
ooooool0003o000000;ooooo00?o0000ooooool000001?l000001Ooooooo0000oooooooooooo0000
00;ooooo00Co0000ool00?l0003o00000_ooool01Ol0003oooooooooool0003ooooo00So000000Go
ooooo`000?ooooooooooo`000002ooooo`Ko000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000002o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?ooool03Ol000000ooo
oooo0000ooooo`04o`000005ooooool0003oooooo`000?ooool01_l000000ooooooo0000o`000004
o`000003ooooool0003o000000_o00004?ooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0
003oooooooooo`0@oooooago000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool;
o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000005Ol000000ooooooo0000o`00
0002o`000003ooooool0003o000000;ooooo00?o0000ooooool000001?l000001Ooooooo0000oooo
oooooooo000000;ooooo00Co0000ool00?l0003o00000_ooool01Ol0003oooooooooool0003ooooo
00So000000Koooooo`000?ooooooooooo`000?ooool7o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000000_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000;o
000000?oooooo`000?ooool03ol000000ooooooo0000o`000002o`000005ooooool0003oooooo`00
0?ooool03Ol000000ooooooo0000o`00000;o`00013ooooo00?o0000ooooooooool03?ooool001Go
oooo00?o0000ooooooooool02?ooool2o`0000Cooooo00?o0000ooooool000007?l000000ooooooo
0000o`000004o`000004ooooool0003o0000ooooo`_o000000?oooooo`000?l000007?l000000ooo
oooo0000o`000002o`000003ooooool0003o000000;ooooo00?o0000ooooool000001?l000001Ooo
oooo0000oooooooooooo000000;ooooo00Co0000ool00?l0003o00000_ooool01Ol0003ooooooooo
ool0003ooooo00So000000Koooooo`000?ooooooooooo`000?ooool7o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool;o`000003ooooool0
003o000000go000000?oooooo`000?l000001?l000000ooooooo0000ooooo`0=o`000003ooooool0
003o000000_o000000?oooooo`000?ooool01?ooool3o`0000Kooooo00?o0000ooooooooool03?oo
ool001Gooooo0_l00008ooooo`04o`000?ooooooooooo`0000Gooooo7Ol000000ooooooo0000o`00
0004o`000004ooooool0003o0000ooooo`_o000000?oooooo`000?l000001?l000000ooooooo0000
o`00000Eo`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool00ol0003ooooo
o`000004o`000006ooooool0003oooooooooool0003ooooo0_l000000ooo003o0000o`000002oooo
o`05o`000?ooooooooooo`000?ooool02?l000001_oooooo0000oooooooooooo0000ooooo`Oo0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000;o
000000?oooooo`000?l000000_l000000ooooooo0000ooooo`0?o`000003ooooool0003o000000Co
000000?oooooo`000?ooool03Ol000000ooooooo0000o`00000;o`0000Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`05o`0000;ooooo
00Co0000oooooooooooo00001OoooolMo`000003ooooool0003o000000Co000000Coooooo`000?l0
003ooooo2ol000000ooooooo0000o`000004o`000003ooooool0003o000001Go000000?oooooo`00
0?l000000_l000000ooooooo0000o`000002ooooo`03o`000?oooooo000000Co000000Koooooo`00
0?ooooooooooo`000?ooool2o`000003ool00?l0003o000000;ooooo00Go0000oooooooooooo0000
ooooo`08o`000004ooooool0003oooooooooo`Wo000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000005o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l000000ooo
oooo0000ooooo`0?o`000003ooooool0003o000000Co000000?oooooo`000?ooool03Ol000000ooo
oooo0000o`00000;o`0000Gooooo1Ol00006ooooo`03o`000?oooooooooo00cooooo000Eooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001OoooolMo`000003ooooool0003o0000
00Co000000Coooooo`000?l0003ooooo2ol000000ooooooo0000o`000004o`000003ooooool0003o
000001Go000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`03o`000?oooooo
000000Co000000Koooooo`000?ooooooooooo`000?ooool2o`000003ool00?l0003o000000;ooooo
00Go0000oooooooooooo0000ooooo`05o`000005ooooool0003o0000ooooool000000_ooool9o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000002
o`000003ooooool0003o000000Co000000?oooooo`000?l000003Ol000000ooooooo0000o`000004
o`000003ooooool0003ooooo01_o00001Oooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooooooo00cooooo000Eooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001Ooo
oolMo`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo2ol000000ooooooo0000
o`00000Lo`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool00ol0003ooooo
o`000004o`000006ooooool0003oooooooooool0003ooooo0_l000000ooo003o0000o`000002oooo
o`05o`000?ooooooooooo`000?ooool01Ol000001Ooooooo0000o`000?oooooo000000;ooooo2Ol0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l00000
0_l000000ooooooo0000o`000004o`000003ooooool0003o000000go000000?oooooo`000?l00000
1?l000000ooooooo0000ooooo`0Ko`0000Kooooo00?o0000ooooool000001oooool00ol0003ooooo
ooooo`0<ooooo`005Oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Gooooo
7Ol000000ooooooo0000o`000004o`000004ooooool0003o0000ooooo`_o000000?oooooo`000?l0
00007?l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo00?o0000ooooool0
00001?l000001_oooooo0000oooooooooooo0000ooooo`;o000000?oo`00o`000?l000000_ooool0
1Ol0003oooooooooool0003ooooo00Go000000Goooooo`000?l0003oooooo`000002ooooo`Wo0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000;o
000000?oooooo`000?l000001?l000000ooooooo0000o`00000=o`000003ooooool0003o000000Co
000000?oooooo`000?ooool06ol00007ooooo`;o00001oooool00ol0003oooooooooo`0<ooooo`00
5Oooool2o`0000Wooooo0_l00006oooooago000000?oooooo`000?l000001?l000001?oooooo0000
o`000?ooool;o`000003ooooool0003o000000Co000000?oooooo`000?l000005Ol000000ooooooo
0000o`000002o`000007ooooool0003o0000o`000?oooooo0000ooooo`05o`000005ooooool0003o
ooooooooool000000_ooool01?l0003oo`00o`000?l00002ooooo`05o`000?ooooooooooo`000?oo
ool01Ol000001Ooooooo0000o`000?oooooo000000;ooooo2Ol000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000Go000000?oooooo`000?l000002Ol000000ooooooo0000o`00000=
o`000003ooooool0003o000000Co000000?oooooo`000?ooool06ol00008ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool04?oooolMo`00
0003ooooool0003o000000Co000000Coooooo`000?l0003ooooo2ol000000ooooooo0000o`000004
o`000003ooooool0003o000001Go000000?oooooo`000?l000000_l000001ooooooo0000o`000?l0
003oooooo`000?ooool01Ol000001?oooooo0000ooooooooool2o`000003ooooool0003oo`0000;o
00000_ooool01Ol0003oooooooooool0003ooooo00Go000000Goooooo`000?l0003oooooo`000002
ooooo`Wo000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005o`000003ooooool0
003o000000;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000=o`000003ooooool0
003o000000Co000000?oooooo`000?ooool06ol0000@ooooo`03o`000?oooooooooo00cooooo000E
ooooo`03o`000?oooooooooo013ooooo7Ol000000ooooooo0000o`000004o`000004ooooool0003o
0000oooooa;o000000?oooooo`000?l000005Ol000000ooooooo0000o`000002o`000007ooooool0
003o0000o`000?oooooo0000ooooo`05o`000004ooooool0003oooooooooo`;o000000?oooooo`00
0?oo00000_l00002ooooo`05o`000?ooooooooooo`000?ooool01Ol000001Ooooooo0000o`000?oo
oooo000000;ooooo2Ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Go0000
00?oooooo`000?l000000_l000000ooooooo0000o`000004o`000003ooooool0003o000000go0000
00?oooooo`000?l000001?l000000ooooooo0000ooooo`0Ko`00013ooooo00?o0000ooooooooool0
3?ooool001Gooooo00?o0000ooooooooool04?oooolMo`000003ooooool0003o000000Co000000Co
ooooo`000?l0003ooooo4_l000000ooooooo0000o`00000Eo`000003ooooool0003o000000;o0000
00Ooooooo`000?l0003o0000ooooool0003ooooo00Go000000Coooooo`000?oooooooooo0_l00000
0ooooooo0000ool00002o`000003ooooool0003o000000;ooooo00?o0000ooooool000001?l00000
1Ooooooo0000o`000?oooooo000000;ooooo2Ol000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000000Go000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`000003oooo
ool0003o000000go000000?oooooo`000?l000001?l000000ooooooo0000ooooo`0Ko`00013ooooo
00?o0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool04?oooolMo`000003ooooool0
003o000000Co000000Coooooo`000?l0003ooooo4_l000000ooooooo0000o`00000Eo`000003oooo
ool0003o000000;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00Oo00000_ooool2o`00
0003ooooool0003oo`0000;o000000?oooooo`000?l000000_ooool00ol0003oooooo`000004o`00
0005ooooool0003o0000ooooool000000_ooool9o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000001Ol000000ooooooo0000o`000002o`000003ooooool0003o000000Co000000?o
ooooo`000?l000003Ol000000ooooooo0000o`000004o`000003ooooool0003ooooo01_o00004?oo
ool00ol0003oooooooooo`0<ooooo`003_oooon5o`000003ool00?l0003o000008Co00001_ooool0
01Gooooo0_l0000=ooooo`04o`000?oooooooooooooooago000000?oooooo`000?l000001?l00000
1?oooooo0000o`000?oooolBo`000003ooooool0003o000000oo000000?oooooo`000?l000000ol0
00000ooooooo0000o`000002o`000007ooooool0003o0000o`000?oooooo0000ooooo`07o`0000;o
oooo0_l000000ooooooo0000ool00002o`000003ooooool0003o000000;ooooo00?o0000ooooool0
00001?l000001Ooooooo0000o`000?oooooo000000;ooooo3ol000000ooooooo0000o`000005o`00
0003ooooool0003o000000;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000=o`00
0003ooooool0003o000000Co000000?oooooo`000?ooool06ol00002ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool03?ooool01?l0003o
oooooooooooooolKo`000003ooooool0003ooooo00Ko000000Coooooo`000?l0003ooooo4_l00000
0ooooooo0000o`000008o`000003ooooool0003o000000Co000000Ooooooo`000?l0003o0000oooo
ool0003ooooo00Co000000Ooooooo`000?l0003o0000ooooool0003ooooo00Oo00000_ooool2o`00
0003ooooool0003oo`0000;o000000?oooooo`000?l000000_ooool00ol0003oooooo`000004o`00
0005ooooool0003o0000ooooool000000_ooool?o`000003ooooool0003o000000[o000000?ooooo
o`000?l000001?l000000ooooooo0000o`000009o`000005ooooool0003o0000o`000?ooool01_l0
00000ooooooo0000ooooo`0Ko`0000;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`005Oooool00ol0003oooooooooo`0@oooooaGo000000?oooooo`000?l000000ol00000
0ooooooo0000ooooo`06o`000004ooooool0003o0000oooooa;o000000?oooooo`000?l000002?l0
00000ooooooo0000o`000004o`000007ooooool0003o0000o`000?oooooo0000ooooo`04o`000007
ooooool0003o0000o`000?oooooo0000ooooo`07o`0000;ooooo0_l000000ooooooo0000ool00002
o`000003ooooool0003o000000;ooooo1ol000000ooooooo0000o`000002o`0000;ooooo3ol00000
0ooooooo0000o`00000:o`000003ooooool0003o000000Co000000?oooooo`000?l000002Ol00000
1Ooooooo0000o`000?l0003ooooo00Ko000000?oooooo`000?ooool06ol0000@ooooo`03o`000?oo
oooooooo00cooooo000Eooooo`03o`000?oooooooooo013ooooo5Ol000000ooooooo0000o`000003
o`000003ooooool0003ooooo00Ko000000Coooooo`000?l0003ooooo3?l000000ooooooo0000o`00
0003o`000003ooooool0003o000000So000000?oooooo`000?l000001?l000001ooooooo0000o`00
0?l0003oooooo`000?ooool01?l000001ooooooo0000o`000?l0003oooooo`000?ooool01ol00002
ooooo`;o000000?oooooo`000?oo00000_l000000ooooooo0000o`000002ooooo`Oo000000?ooooo
o`000?l000000_l00002ooooo`oo000000?oooooo`000?l000002_l000000ooooooo0000o`000004
o`000003ooooool0003o000000Wo000000Goooooo`000?l0003o0000ooooo`06o`000003ooooool0
003ooooo01_o00004?ooool00ol0003oooooooooo`0<ooooo`005Oooool2o`00017ooooo5Ol00000
0ooooooo0000o`000003o`000003ooooool0003ooooo00Ko000000Coooooo`000?l0003ooooo3?l0
00000ooooooo0000o`000003o`000003ooooool0003o000000So000000?oooooo`000?l000001?l0
00001ooooooo0000o`000?l0003oooooo`000?ooool01?l000001ooooooo0000o`000?l0003ooooo
o`000?ooool01ol00002ooooo`Co000000Coo`00o`000?l0003ooooo0_l00002ooooo`Oo000000?o
ooooo`000?l000000_l00002ooooo`oo000000?oooooo`000?l000002_l000000ooooooo0000o`00
0004o`000003ooooool0003o000000Wo000000Goooooo`000?l0003o0000ooooo`06o`000003oooo
ool0003ooooo01_o00004?ooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003ooooooooo
o`0@oooooaGo000000?oooooo`000?l000000ol000000ooooooo0000ooooo`06o`000004ooooool0
003o0000ooooo`co000000?oooooo`000?l000000ol000000ooooooo0000o`000008o`000003oooo
ool0003o000000Co000000Ooooooo`000?l0003o0000ooooool0003ooooo00Co000000Ooooooo`00
0?l0003o0000ooooool0003ooooo00Oo00000_ooool4o`000003ool00?l0003o000000?o00000_oo
ool7o`000003ooooool0003o000000;o00000_ooool?o`000003ooooool0003o000000[o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000009o`000003ooooool0003o000000So000000?o
ooooo`000?ooool06ol0000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooool000005?l000000ooooooo0000o`000003o`000003ooooool0003o
oooo00Ko000000Coooooo`000?l0003ooooo3?l000000ooooooo0000o`000003o`000003ooooool0
003o000000So000000?oooooo`000?l000001?l000000ooooooo0000o`000002ooooo`03o`000?oo
oooo000000?o000000Ooooooo`000?l0003o0000ooooool0003ooooo00Oo00000_ooool4o`000003
ool00?l0003o000000?o00000_ooool7o`000003ooooool0003o000000;o00000_ooool?o`000003
ooooool0003o000000[o000000?oooooo`000?l000001?l000000ooooooo0000o`000009o`000003
ooooool0003o000000So000000?oooooo`000?ooool06ol0000@ooooo`03o`000?oooooooooo00co
oooo000Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooool000005?l000000ooooooo0000
o`000003o`000003ooooool0003ooooo00Ko000000Coooooo`000?l0003ooooo3?l000000ooooooo
0000o`000003o`000003ooooool0003o000000So000000?oooooo`000?l000001?l000000ooooooo
0000o`000002ooooo`03o`000?oooooo000000?o000000Ooooooo`000?l0003o0000ooooool0003o
oooo00Oo00000_ooool4o`000003ool00?l0003o000000?o00000_ooool7o`000003ooooool0003o
000000;o00000_ooool?o`000003ooooool0003o000000[o000000Coooooo`000?l0003ooooo0ol0
00000ooooooo0000o`000009o`000003ooooool0003o000000[o000000?oooooo`000?l000006Ol0
000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo00kooooo00?o0000
ooooool000005?l000000ooooooo0000o`000003o`000003ooooool0003ooooo00Ko000000Cooooo
o`000?l0003ooooo3?l000000ooooooo0000o`000003o`000003ooooool0003o000000So000000?o
ooooo`000?l000001?l000000ooooooo0000o`000002ooooo`03o`000?oooooo000000?o000000Oo
ooooo`000?l0003o0000ooooool0003ooooo00Oo00000_ooool4o`000003ool00?l0003o000000?o
00000_ooool7o`000003ooooool0003o000000;o00000_ooool?o`000003ooooool0003o000000[o
000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o0000
00;o000000?oooooo`000?l000002_l000000ooooooo0000o`00000Io`00013ooooo00?o0000oooo
ooooool03?ooool001Gooooo0_l0000?oooooaOo000000?oooooo`000?l000000ol000000ooooooo
0000ooooo`06o`000004ooooool0003o0000ooooo`co000000?oooooo`000?l000000ol000000ooo
oooo0000o`000007o`0000;ooooo1_l000000ooooooo0000o`000002ooooo`03o`000?oooooo0000
00?o000000Ooooooo`000?l0003o0000ooooool0003ooooo00Oo00000_ooool4o`000003ool00?l0
003o000000?o00000_ooool7o`000003ooooool0003o000000;o00000_ooool?o`000003ooooool0
003o000000[o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000004o`000003oooo
ool0003o000000;o000000?oooooo`000?l000002_l000000ooooooo0000o`00000Io`00013ooooo
00?o0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool03_oooolGo`000003ooooool0
003o000000?o000000?oooooo`000?ooool00_l000001Ooooooo0000o`000?l0003ooooo00;o0000
00?oooooo`000?l000002_l000000ooooooo0000o`000003o`000003ooooool0003o000000Oo0000
0_ooool6o`000003ooooool0003o000000;ooooo00?o0000ooooool000000ol000001ooooooo0000
o`000?l0003oooooo`000?ooool01ol00002ooooo`Co000000?oo`00o`000?l000000ol00002oooo
o`Oo000000?oooooo`000?l000000_l00002ooooo`oo000000?oooooo`000?l000002_l000001?oo
oooo0000o`000?ooool3o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l00000
0ooooooo0000o`00000:o`000003ooooool0003o000001Wo00004?ooool00ol0003oooooooooo`0<
ooooo`005Oooool00ol0003oooooooooo`0>oooooaOo000000?oooooo`000?l000000ol000000ooo
oooo0000ooooo`02o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000:
o`000003ooooool0003o000000?o000000?oooooo`000?l000001ol00002ooooo`Ko000000?ooooo
o`000?l000000_ooool00ol0003oooooo`000003o`000007ooooool0003o0000o`000?oooooo0000
ooooo`07o`0000;ooooo1?l000000ooo003o0000o`000003o`0000;ooooo1ol000000ooooooo0000
o`000002o`0000;ooooo1_l000000ooooooo0000o`000006o`000003ooooool0003o000000[o0000
00Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o000000;o
000000Coooooo`000?l0003ooooo2Ol000000ooooooo0000o`00000Io`00013ooooo00?o0000oooo
ooooool03?ooool001Gooooo00?o0000ooooooooool03_oooolGo`000003ooooool0003o000000?o
000000?oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00;o000000?oooooo`00
0?l000002_l00002ooooo`Co000000?oooooo`000?l000001ol00002ooooo`Ko000000?oooooo`00
0?l000000_ooool00ol0003oooooo`000003o`000007ooooool0003o0000o`000?oooooo0000oooo
o`04o`000003ooooool0003o000000;ooooo1?l000000ooo003o0000o`000003o`0000;ooooo1ol0
00000ooooooo0000o`000002o`0000;ooooo1_l000000ooooooo0000o`000006o`000003ooooool0
003o000000[o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000004o`000003oooo
ool0003o000000;o000000Coooooo`000?l0003ooooo2Ol000000ooooooo0000o`00000Io`00013o
oooo00?o0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool03_oooolGo`000003oooo
ool0003o000000?o000000?oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00;o
000000?oooooo`000?l000002_l00002ooooo`Co000000?oooooo`000?l000001ol00002ooooo`Ko
000000?oooooo`000?l000000_ooool01?l0003oooooo`000?l00003ooooo`?o000000?oooooo`00
0?ooool01?l000000ooooooo0000o`000002ooooo`Co000000?oo`00o`000?l000000ol00002oooo
o`Oo000000?oooooo`000?l000000_l00002ooooo`Ko000000?oooooo`000?l000001_l000000ooo
oooo0000o`00000:o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001?l00000
0ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?l000006Ol0
000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00003_oooolFo`000003ooooool0003o
oooo00Go000000?oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00;o000000?o
ooooo`000?l000002_l00002ooooo`Co000000?oooooo`000?l000001ol00002ooooo`Ko000000?o
ooooo`000?l000000_ooool01?l0003oooooo`000?l00003ooooo`?o000000?oooooo`000?ooool0
1?l000000ooooooo0000o`000002ooooo`Co000000?oo`00o`000?l000000ol00002ooooo`Oo0000
00?oooooo`000?l000000_l00002ooooo`Ko000000?oooooo`000?l000001_l000000ooooooo0000
o`00000:o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001?l000000ooooooo
0000o`000002o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?l000006Ol0000@oooo
o`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo00gooooo5_l000000ooooooo
0000ooooo`05o`000003ooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`02o`00
0003ooooool0003o000000[o00000_ooool4o`000003ooooool0003o000000Oo00000_ooool6o`00
0003ooooool0003o000000;ooooo00Co0000ooooool0003o00000oooool3o`000003ooooool0003o
oooo00Co000000?oooooo`000?l000000_ooool4o`000003ool00?l0003o000000?o00000_ooool7
o`000003ooooool0003o000000;o00000_ooool6o`000005ooooool0003o0000o`000?ooool01?l0
00000ooooooo0000o`00000:o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l00000
1?l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?l0
00006Ol0000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo00gooooo
5_l000000ooooooo0000ooooo`05o`000003ooooool0003ooooo00;o000000Goooooo`000?oooooo
0000ooooo`02o`000003ooooool0003o000000[o00000_ooool4o`000003ooooool0003o000000Oo
00000_ooool6o`000003ooooool0003o000000;ooooo00Co0000ooooool0003o00000oooool3o`00
0003ooooool0003ooooo00Co000000?oooooo`000?l000000_ooool4o`000003ool00?l0003o0000
00?o00000_ooool7o`000003ooooool0003o000000;o00000_ooool6o`000005ooooool0003o0000
o`000?ooool01?l000000ooooooo0000o`00000:o`000004ooooool0003o0000ooooo`?o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Wo0000
00?oooooo`000?l000006Ol0000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00003Ooo
oolGo`000003ooooool0003ooooo00Go000000?oooooo`000?ooool00_l000001Ooooooo0000oooo
ool0003ooooo00;o000000?oooooo`000?l000002_l00002ooooo`Co000000?oooooo`000?l00000
1ol00002ooooo`Ko000000?oooooo`000?l000000_ooool01?l0003oooooo`000?l00003ooooo`?o
000000Coooooo`000?oooooooooo0ol000000ooooooo0000o`000002ooooo`Co000000?oo`00o`00
0?l000000ol00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000_ooool6o`00
0005ooooool0003o0000o`000?ooool01?l000000ooooooo0000o`00000:o`000004ooooool0003o
0000ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`000004ooooool0
003o0000ooooo`Wo000000?oooooo`000?l000006Ol0000@ooooo`03o`000?oooooooooo00cooooo
000EooooobKo000000?oooooo`000?ooool01Ol000001?oooooo0000ooooool00002ooooo`04o`00
0?oooooo0000ooooo`;o000000?oooooo`000?l000002_l00002ooooo`Co000000?oooooo`000?l0
00001ol00002ooooo`Ko000000?oooooo`000?l000000_ooool01?l0003oooooo`000?l00003oooo
o`?o000000Coooooo`000?oooooooooo0ol000000ooooooo0000o`000002ooooo`Co000000?oo`00
o`000?l000000ol00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000_ooool6
o`000005ooooool0003o0000o`000?ooool01?l000000ooooooo0000o`00000:o`000004ooooool0
003o0000ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`000004oooo
ool0003o0000ooooo`Wo000000?oooooo`000?l000006Ol0000@ooooo`03o`000?oooooooooo00co
oooo000Eooooo`;o00003Oooool9o`000003ooooool0003o000000_o000000?oooooo`000?ooool0
1Ol000001?oooooo0000ooooool00002ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`00
0?l000002_l00002ooooo`Co000000?oooooo`000?l000001ol00002ooooo`Ko000000?oooooo`00
0?l000000_ooool01?l0003oooooo`000?l00004ooooo`;o000000Coooooo`000?oooooooooo0ol0
00000ooooooo0000o`000002ooooo`Co000000?oo`00o`000?l000000ol00002ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`?o00000_ooool6o`000005ooooool0003o0000o`000?ooool0
1?l000000ooooooo0000o`00000:o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l0
00001?l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Wo000000?oooooo`00
0?l000006Ol0000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo00ko
oooo1ol000000ooooooo0000o`00000;o`000003ooooool0003ooooo00Go000000Coooooo`000?oo
oooo00000_ooool01?l0003oooooo`000?ooool2o`000003ooooool0003o000000[o00000_ooool4
o`000003ooooool0003o000000Oo00000_ooool6o`000003ooooool0003o000000;ooooo00Co0000
ooooool0003o00001?ooool2o`000004ooooool0003oooooooooo`?o000000?oooooo`000?l00000
0_ooool4o`000003ool00?l0003o000000?o00000_ooool2o`000003ooooool0003o000000;o0000
0_ooool3o`0000;ooooo1_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
ooooo`0:o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001?l000000ooooooo
0000o`000002o`000004ooooool0003o0000ooooo`Ko000000Coooooo`000?l0003ooooo6ol0000@
ooooo`03o`000?oooooooooo00cooooo000<ooooo`?o00001_ooool00ol0003oooooooooo`0>oooo
o`Oo000000?oooooo`000?l000002ol000000ooooooo0000ooooo`03o`000006ooooool0003ooooo
o`000?oooooo00000_ooool01?l0003oooooo`000?ooool2o`000003ooooool0003o000000[o0000
0_ooool4o`000003ooooool0003o000000Oo00000_ooool6o`0000;ooooo00Go0000oooooooooooo
0000ooooo`02o`0000Cooooo0_l000001?oooooo0000ooooooooool3o`000003ooooool0003o0000
00;ooooo1?l000000ooo003o0000o`000003o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00;ooooo0ol00002ooooo`Ko00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`00
0?ooool02_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000Co000000?ooooo
o`000?l000000_l000001?oooooo0000o`000?ooool6o`000003ooooool0003o000001co00004?oo
ool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00kooooo1ol000000ooooooo0000o`00000;o`000003ooooool0003ooooo00?o000000Kooooo
o`000?oooooo0000ooooool00002ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?l0
00002_l00002ooooo`Co000000?oooooo`000?l000001ol00002ooooo`Ko00000_ooool01Ol0003o
ooooooooool0003ooooo00;o00001?ooool2o`000004ooooool0003oooooooooo`?o000000?ooooo
o`000?l000000_ooool4o`000003ool00?l0003o000000?o00000_ooool2o`000003ooooool0003o
000000;o00000_ooool3o`0000;ooooo1_l00002ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000ooooo`0:o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001?l0
00000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Ko000000?oooooo`000?l00000
7?l0000@ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03_ooool7o`000003ooooool0003o000000_o000000?oooooo`000?ooool00ol0
00001_oooooo0000ooooool0003oooooo`0000;ooooo00Co0000ooooool0003ooooo0_l000000ooo
oooo0000o`00000:o`0000;ooooo1?l000000ooooooo0000o`000007o`0000;ooooo1_l00002oooo
o`05o`000?ooooooooooo`000?ooool00_l00004ooooo`;o000000Coooooo`000?oooooooooo0ol0
00000ooooooo0000o`000002ooooo`Co000000?oo`00o`000?l000000ol00002ooooo`;o000000Co
ooooo`000?l0003o00000oooool3o`0000?ooooo1Ol00002ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000ooooo`09o`0000;ooooo0_l000000ooooooo0000o`000008o`000003oooo
ool0003o000000;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000Lo`00013o
oooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool01Oooool2o`00013ooooo
1_l000000ooooooo0000o`00000;o`000003ooooool0003ooooo00?o000000Koooooo`000?oooooo
0000ooooool00002ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?l000002_l00002
ooooo`Co000000?oooooo`000?l000001ol00002ooooo`Ko00001Oooool01?l0003oooooo`000?l0
0004ooooo`;o000000Coooooo`000?oooooooooo0ol000000ooooooo0000o`000002ooooo`Co0000
00?oo`00o`000?l000000ol00002ooooo`;o000000Coooooo`000?l0003o00000oooool3o`0000Co
oooo1?l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000ooooo`09o`0000;o
oooo0_l000000ooooooo0000o`000008o`000003ooooool0003o000000;o000000Coooooo`000?l0
003ooooo1_l000000ooooooo0000o`00000Do`000003ooooool0003o000000Go00004?ooool00ol0
003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oo
oooo1_l000000ooooooo0000o`00000;o`000003ooooool0003ooooo00?o000000Koooooo`000?oo
oooo0000ooooool00002ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?l000002_l0
0002ooooo`Co000000?oooooo`000?l000001ol00002ooooo`Ko00001Oooool01?l0003oooooo`00
0?l00004ooooo`;o000000Coooooo`000?oooooooooo0ol000000ooooooo0000o`000002ooooo`Co
000000?oo`00o`000?l000000ol00002ooooo`;o000000Coooooo`000?l0003o00000oooool3o`00
00Cooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000ooooo`09o`00
00;ooooo0_l000000ooooooo0000o`000008o`000003ooooool0003ooooo00;o000000Coooooo`00
0?l0003ooooo1_l000000ooooooo0000o`00000Do`000003ooooool0003o000000Go00004?ooool0
0ol0003oooooooooo`0<ooooo`003?ooool2o`0000Oooooo00?o0000ooooooooool03oooool6o`00
0003ooooool0003o000000_o000000?oooooo`000?ooool00ol000001_oooooo0000ooooool0003o
ooooo`0000;ooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000o`00000:o`0000;ooooo
1?l000000ooooooo0000o`000007o`0000;ooooo1_l00005ooooo`04o`000?oooooo0000o`0000Co
oooo0_l000001?oooooo0000ooooooooool3o`000003ooooool0003o000000;ooooo1?l000000ooo
003o0000o`000003o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`?o00001?ooool4
o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003ooooo00Wo00000_ooool2
o`000003ooooool0003o000000So000000?oooooo`000?ooool00_l000001?oooooo0000o`000?oo
ool6o`000003ooooool0003o000001Co000000?oooooo`000?l000001Ol0000@ooooo`03o`000?oo
oooooooo00cooooo000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool6
o`000003ooooool0003o000000Co000000?oooooo`000?l000001?l000003?oooooo0000ooooool0
003oooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00Co0000ooooool0003ooooo0_l0
00000ooooooo0000o`000008o`000004ooooool0003oooooooooo`Co000000?oooooo`000?l00000
1ol00002ooooo`Ko00001Oooool01?l0003oooooo`000?l00004ooooo`;o000000Coooooo`000?oo
oooooooo0ol000000ooooooo0000o`000002ooooo`Co000000?oo`00o`000?l000000ol00002oooo
o`;o000000Coooooo`000?l0003o00000oooool3o`0000Cooooo1?l00002ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000ooooo`09o`0000;ooooo0_l000000ooooooo0000o`000008
o`000003ooooool0003ooooo00;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00
000Do`000003ooooool0003o000000Go00004?ooool00ol0003oooooooooo`0<ooooo`005Oooool0
0ol0003oooooooooo`0?ooooo`Ko000000?oooooo`000?l000001?l000000ooooooo0000o`000004
o`00000<ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool0
1?l0003oooooo`000?ooool2o`000003ooooool0003o000000So000000Coooooo`000?oooooooooo
1?l000000ooooooo0000o`000005o`000004ooooool0003oooooooooo`Ko00001Oooool01?l0003o
ooooo`000?l00004ooooo`;o000000Coooooo`000?oooooooooo0ol000000ooooooo0000o`000002
ooooo`Co000000?oo`00o`000?l000000ol00002ooooo`;o000000Coooooo`000?l0003o00000ooo
ool3o`0000Cooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000oooo
ooooool8o`0000;ooooo0_l000000ooooooo0000o`000008o`000003ooooool0003ooooo00;o0000
00Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000Do`000003ooooool0003o000000Go
00004?ooool00ol0003oooooooooo`0<ooooo`005Oooool2o`00013ooooo1_l000000ooooooo0000
o`000004o`000003ooooool0003o000000Co000000coooooo`000?oooooo0000ooooool0003ooooo
o`000?oooooo0000ooooool00002ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?l0
00002?l000001?oooooo0000ooooooooool2o`000003ooooool0003ooooo00Oo000000Coooooo`00
0?oooooooooo1_l00005ooooo`04o`000?oooooo0000o`0000Cooooo0_l000001?oooooo0000oooo
ooooool3o`0000;ooooo00?o0000ooooooooool01?l000000ooo003o0000o`000003o`0000;ooooo
0_l000001?oooooo0000o`000?l00003ooooo`?o00001?ooool4o`0000;ooooo0_l000000ooooooo
0000o`000002o`000004ooooool0003oooooooooo`So00000_ooool2o`000004ooooool0003o0000
ooooo`Oo000000?oooooo`000?ooool00_l000001?oooooo0000o`000?ooool6o`000003ooooool0
003o000001Co000000?oooooo`000?l000001Ol0000@ooooo`03o`000?oooooooooo00cooooo000E
ooooo`03o`000?oooooooooo00oooooo1_l000000ooooooo0000o`000004o`000003ooooool0003o
000000Co000000coooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool00002
ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?l000002?l000001?oooooo0000oooo
ooooool2o`000003ooooool0003ooooo00Oo00001?ooool6o`0000Gooooo00Co0000ooooool0003o
00001?ooool4o`0000;ooooo0ol00002ooooo`03o`000?oooooooooo00Co000000?oo`00o`000?l0
00000ol00002ooooo`;o000000Coooooo`000?l0003o00000oooool3o`0000Cooooo1?l00002oooo
o`;o000000?oooooo`000?l000000_l000001?oooooo0000ooooooooool8o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool7o`000003ooooool0003ooooo00;o000000Coooooo`000?l0003ooooo
1_l000000ooooooo0000o`00000=o`000003ooooool0003o000000Co000000?oooooo`000?l00000
1Ol0000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo00oooooo1_l0
00000ooooooo0000o`000004o`000003ooooool0003o000000Co000000coooooo`000?oooooo0000
ooooool0003oooooo`000?oooooo0000ooooool00004ooooo`05o`000?oooooo0000o`000?ooool0
2_l000001?oooooo0000ooooooooool2o`000003ooooool0003ooooo00Oo00001?ooool6o`0000Go
oooo00Co0000ooooool0003o00001?ooool4o`0000;ooooo0ol00002ooooo`03o`000?oooooooooo
00Co000000?oo`00o`000?l000000ol00002ooooo`;o000000Coooooo`000?l0003o00000oooool3
o`0000Cooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000oooooooo
ool8o`0000;ooooo0_l000001?oooooo0000o`000?ooool7o`000003ooooool0003ooooo00;o0000
00Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000=o`000003ooooool0003o000000Co
000000?oooooo`000?l000001Ol0000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`00
0?oooooooooo00oooooo1_l000000ooooooo0000o`000004o`000003ooooool0003o000000Co0000
00coooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool00004ooooo`05o`00
0?oooooo0000o`000?ooool02_l000001?oooooo0000ooooooooool2o`0000?ooooo1ol00004oooo
o`Ko00001Oooool01?l0003oooooo`000?l00004ooooo`Co00000_ooool3o`0000;ooooo00?o0000
ooooooooool01?l000000ooo003o0000o`000003o`0000;ooooo0_l000001?oooooo0000o`000?l0
0003ooooo`?o00001?ooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo2?l0
0002ooooo`;o000000Coooooo`000?l0003ooooo1ol000000ooooooo0000ooooo`02o`000004oooo
ool0003o0000ooooo`Ko000000?oooooo`000?l000003Ol000000ooooooo0000o`000004o`000003
ooooool0003o000000Go00004?ooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003ooooo
ooooo`0?ooooo`Ko000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000004o`00000:
ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`0000Kooooo00Go0000ooooool0003o
0000ooooo`0:o`000004ooooool0003oooooooooo`;o00000oooool7o`0000Cooooo1_l00005oooo
o`04o`000?oooooo0000o`0000Cooooo1?l00002ooooo`?o00000_ooool00ol0003oooooooooo`04
o`000003ool00?l0003o000000?o00000_ooool00ol0003oooooooooo`03o`0000?ooooo0ol00004
ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00001?ooool8o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool7o`000003ooooool0003ooooo00;o000000Coooooo`000?l0003ooooo
1_l000000ooooooo0000o`00000=o`000003ooooool0003o000000Co000000?oooooo`000?l00000
1Ol0000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00004?ooool6o`000008ooooool0
003o0000ooooool0003oooooo`000?ooool6o`00000:ooooool0003oooooo`000?oooooo0000oooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool02_l000001?oooooo0000ooooooooool2o`00
00?ooooo1ol00004ooooo`Ko00001Oooool4o`0000Cooooo1?l00002ooooo`?o00000_ooool00ol0
003oooooooooo`04o`000003ool00?l0003o000000?o00000_ooool00ol0003oooooooooo`03o`00
00?ooooo0ol00004ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00001?ooool8o`00
00;ooooo0_l000001?oooooo0000o`000?ooool7o`000003ooooool0003ooooo00;o000000Cooooo
o`000?l0003ooooo1_l000000ooooooo0000o`00000=o`000003ooooool0003o000000Co000000?o
ooooo`000?l000001Ol0000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooo
oooo00oooooo1_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo1_l000002?oooooo
0000ooooool0003oooooo`000?oooooo00002_ooool00ol0003oooooooooo`0:o`000004ooooool0
003oooooooooo`;o00000oooool7o`0000Cooooo1Ol00006ooooo`Co00001?ooool4o`0000;ooooo
0ol00002ooooo`03o`000?oooooooooo00Co000000?oo`00o`000?l000000ol00002ooooo`03o`00
0?oooooooooo00?o00000oooool3o`0000Cooooo1?l00002ooooo`03o`000?oooooooooo00Co0000
1?ooool8o`0000;ooooo0_l000001?oooooo0000o`000?ooool7o`000003ooooool0003ooooo00;o
000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000=o`000003ooooool0003o0000
00Co000000?oooooo`000?l000001Ol0000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`03
o`000?oooooooooo00oooooo1_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo1_l0
00002?oooooo0000ooooool0003oooooo`000?oooooo00002_ooool00ol0003oooooooooo`0:o`00
0004ooooool0003oooooooooo`;o00000oooool7o`0000Cooooo1Ol00006ooooo`Co00001?ooool4
o`0000;ooooo0ol00002ooooo`03o`000?oooooooooo00Co000000?oo`00o`000?l000000ol00002
ooooo`03o`000?oooooooooo00?o00000oooool3o`0000Cooooo1?l00002ooooo`03o`000?oooooo
oooo00Co00001?ooool8o`0000;ooooo0_l000001?oooooo0000o`000?ooool7o`000003ooooool0
003ooooo00;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000=o`000003oooo
ool0003o000000Co000000?oooooo`000?l000001Ol0000@ooooo`03o`000?oooooooooo00cooooo
000Eooooo`03o`000?oooooooooo00oooooo1_l000002?oooooo0000o`000?oooooo0000ooooool0
003ooooo1_l000001_oooooo0000ooooool0003oooooo`0000cooooo00?o0000ooooooooool02_l0
00001?oooooo0000ooooooooool2o`0000?ooooo1ol00004ooooo`Go00001_ooool4o`0000Cooooo
1?l00002ooooo`?o00000_ooool00ol0003oooooooooo`04o`000003ool00?l0003o000000?o0000
0_ooool00ol0003oooooooooo`03o`0000?ooooo0ol00004ooooo`Co00000_ooool00ol0003ooooo
ooooo`04o`0000Cooooo2?l00002ooooo`;o000000Coooooo`000?l0003ooooo1ol000000ooooooo
0000ooooo`02o`000004ooooool0003o0000ooooo`Ko000000?oooooo`000?l000003Ol000000ooo
oooo0000o`000004o`000003ooooool0003o000000Go00004?ooool00ol0003oooooooooo`0<oooo
o`005Oooool00ol0003oooooooooo`0?ooooo`Ko000000Soooooo`000?l0003oooooo`000?oooooo
0000ooooo`Ko000000Koooooo`000?oooooo0000ooooool0000<ooooo`03o`000?oooooooooo00Wo
00000_ooool00ol0003oooooooooo`02o`0000Cooooo1_l00004ooooo`Go00001_ooool4o`0000Co
oooo1?l00002ooooo`?o00000_ooool00ol0003oooooooooo`04o`000003ool00?l0003o000000?o
00000_ooool00ol0003oooooooooo`03o`0000?ooooo0ol00004ooooo`Co00001Oooool4o`0000Co
oooo2?l00002ooooo`;o000000Coooooo`000?oooooooooo1ol000000ooooooo0000ooooo`02o`00
0004ooooool0003o0000ooooo`Ko000000?oooooo`000?l000003Ol000000ooooooo0000o`000004
o`000003ooooool0003o000000Go00004?ooool00ol0003oooooooooo`0<ooooo`005Oooool2o`00
013ooooo1_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo1_l000001_oooooo0000
ooooool0003oooooo`0000cooooo00?o0000ooooooooool02Ol00002ooooo`03o`000?oooooooooo
00;o00001?ooool6o`0000Cooooo1Ol00006ooooo`Co00001?ooool4o`0000;ooooo0ol00002oooo
o`03o`000?oooooooooo00Co000000?oo`00o`000?l000000ol00002ooooo`03o`000?oooooooooo
00?o00000oooool3o`0000Cooooo1?l00005ooooo`Co00001?ooool8o`0000;ooooo0_l00004oooo
o`Oo000000?oooooo`000?ooool00_l000001?oooooo0000o`000?ooool6o`000003ooooool0003o
oooo00go000000?oooooo`000?l000001?l000000ooooooo0000o`000005o`00013ooooo00?o0000
ooooooooool03?ooool001Gooooo00?o0000ooooooooool03oooool6o`000008ooooool0003o0000
ooooool0003oooooo`000?ooool6o`000006ooooool0003oooooo`000?oooooo00003oooool9o`00
00;ooooo00?o0000ooooooooool00_l00004ooooo`Go00001Oooool5o`0000Kooooo1?l00004oooo
o`?o00000oooool3o`0000;ooooo00?o0000ooooooooool01?l000000ooo003o0000o`000003o`00
00;ooooo00?o0000ooooooooool00ol00003ooooo`?o00001?ooool4o`0000Gooooo1?l00004oooo
o`So00000_ooool2o`0000Cooooo1ol000000ooooooo0000ooooo`02o`000004ooooool0003o0000
ooooo`Ko000000?oooooo`000?ooool03Ol000000ooooooo0000o`000004o`000003ooooool0003o
000000Go00004?ooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0?oooo
o`Ko000000Soooooo`000?l0003oooooo`000?oooooo0000ooooo`Ko000000Koooooo`000?oooooo
0000ooooool0000?ooooo`Wo00000_ooool00ol0003oooooooooo`02o`0000Cooooo1Ol00005oooo
o`Go00001_ooool4o`0000Cooooo0ol00003ooooo`?o00000_ooool00ol0003oooooooooo`02o`00
0003ooooool0003oo`0000Go00000_ooool00ol0003oooooooooo`03o`0000?ooooo0ol00004oooo
o`Co00001Oooool4o`0000Cooooo2?l00002ooooo`;o00001?ooool7o`000003ooooool0003ooooo
00;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000ooooo`0=o`000003ooooool0003o
000000;o000000?oooooo`000?ooool01ol0000@ooooo`03o`000?oooooooooo00cooooo000Eoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooool000000ol000002?oooooo0000o`000?oooooo
0000ooooool0003ooooo1_l000001_oooooo0000ooooool0003oooooo`0000oooooo2Ol00002oooo
o`03o`000?oooooooooo00;o00001?ooool5o`0000Kooooo1?l00006ooooo`Co00001?ooool3o`00
00?ooooo0ol00002ooooo`03o`000?oooooooooo00;o000000?oooooo`000?oo00000_l000000ooo
oooo0000o`000002ooooo`03o`000?oooooooooo00?o00000oooool3o`0000Cooooo1?l00005oooo
o`Co00001?ooool8o`0000;ooooo0_l00004ooooo`Oo000000?oooooo`000?ooool00_l000001?oo
oooo0000o`000?ooool6o`000003ooooool0003ooooo00go000000?oooooo`000?l000000_l00000
0ooooooo0000ooooo`07o`00013ooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooo`000003o`000007ooooool0003o0000ooooool0003oooooo`00
0002ooooo`Go000000Koooooo`000?oooooo0000ooooool0000?ooooo`Wo00000_ooool00ol0003o
ooooooooo`02o`0000Cooooo1Ol00006ooooo`Co00001_ooool4o`0000Cooooo0ol00003ooooo`?o
00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oo003o0000o`000?ooool00_l00002
ooooo`03o`000?oooooooooo00?o00000oooool3o`0000Cooooo1?l00005ooooo`;o000000?ooooo
o`000?ooool00oooool8o`0000;ooooo0_l00004ooooo`Oo000000?oooooo`000?ooool00_l00000
1?oooooo0000o`000?ooool6o`000003ooooool0003ooooo00go000000?oooooo`000?l000000_l0
0003ooooo`Oo00004?ooool00ol0003oooooooooo`0<ooooo`005Oooool2o`00013ooooo00?o0000
ooooool000000_l00002ooooo`;o000000Coooooo`000?oooooo00000_ooool5o`000006ooooool0
003oooooo`000?oooooo00003oooool9o`0000;ooooo00?o0000ooooooooool00_l00004ooooo`Go
00001_ooool4o`0000Kooooo1?l00004ooooo`?o00000oooool3o`0000;ooooo00Co0000oooooooo
oooo00000_ooool01Ol0003oo`00o`000?l0003ooooo00;o00000_ooool00ol0003oooooooooo`03
o`0000?ooooo0ol00004ooooo`Co00001Oooool2o`000003ooooool0003ooooo00?ooooo2?l00002
ooooo`;o00001?ooool7o`000003ooooool0003ooooo00;o000000Coooooo`000?l0003ooooo1_l0
00000ooooooo0000ooooo`05o`000003ooooool0003o000000Go000000?oooooo`000?l000000_l0
0003ooooo`Oo00004?ooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooo000000;o00000_ooool2o`000004ooooool0003oooooo`0000;ooooo1Ol0
00001?oooooo0000ooooool0000Aooooo`Wo00000_ooool00ol0003oooooooooo`02o`0000Cooooo
1Ol00006ooooo`Co00001_ooool4o`0000Cooooo0ol00003ooooo`?o00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?oo003o0000o`0000;ooooo00Co0000oooooooooooo00000_ooool3
o`0000?ooooo0_l00005ooooo`04o`000?oooooo0000o`0000Gooooo0_l000000ooooooo0000oooo
o`03ooooo`So00000_ooool2o`0000Cooooo1?l000001_oooooo0000o`000?oooooo0000ooooo`;o
000000Coooooo`000?l0003ooooo0ol000001_oooooo0000o`000?oooooo0000ooooo`Go000000?o
ooooo`000?l000001Ol000000ooooooo0000o`000002o`0000?ooooo1ol0000@ooooo`03o`000?oo
oooooooo00cooooo000;ooooo`Go00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
000000;o00000_ooool2o`000004ooooool0003oooooo`0000;ooooo1Ol000001?oooooo0000oooo
ool0000Cooooo`Oo00001Oooool2o`0000Cooooo1Ol00006ooooo`?o00001oooool4o`0000Cooooo
0ol00003ooooo`?o00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo003o0000o`00
00;ooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooo
000000Kooooo0_l000000ooooooo0000ooooo`03ooooo`So00000_ooool2o`0000Cooooo1?l00000
1_oooooo0000o`000?oooooo0000ooooo`;o000000Soooooo`000?l0003oooooo`000?oooooo0000
ooooo`;o000000?oooooo`000?ooool01Ol000000ooooooo0000o`000005o`000003ooooool0003o
000000;o00000oooool7o`00013ooooo00?o0000ooooooooool03?ooool000cooooo00Co0000oooo
oooooooo00001Oooool3ool000oooooo00?o0000ooooool000000_l00002ooooo`;o000000Cooooo
o`000?oooooo00000_ooool5o`000004ooooool0003oooooo`0001?ooooo1ol00005ooooo`;o0000
1?ooool5o`0000Kooooo0ol00007ooooo`Co00001?ooool3o`0000?ooooo0ol00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000ool00?l0003o00000_ooool01?l0003oooooooooool00002
ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003o
oooo00?ooooo00?o0000ooooool000001Ol00002ooooo`;o00001?ooool4o`000006ooooool0003o
0000ooooool0003ooooo0_l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo0_l00000
0ooooooo0000ooooo`05o`000003ooooool0003o000000Go000000?oooooo`000?l000000_l00003
ooooo`Oo00004?ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`05oooo
o`03o`000?ooooooo`0000?oo`003_ooool3o`0000;ooooo0_l000001?oooooo0000ooooool00002
ooooo`Go000000Coooooo`000?oooooo00004oooool7o`0000Gooooo0_l00004ooooo`Go00001_oo
ool3o`0000Oooooo1?l00004ooooo`?o00000oooool3o`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oo`00o`000?l00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003oooo
o`;o00001Oooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?ooool00oooool00ol0
003oooooo`000005o`0000;ooooo0_l00004ooooo`Co000000Koooooo`000?l0003oooooo`000?oo
ool2o`000008ooooool0003o0000ooooool0003oooooo`000?ooool2o`000003ooooool0003ooooo
00Go000000?oooooo`000?l000001Ol000000ooooooo0000o`000002o`0000?ooooo1ol0000@oooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`Go
o`002Oooool3o`0000;ooooo0_l000001?oooooo0000ooooool00002ooooo`Go000000Coooooo`00
0?oooooo00004oooool7o`0000Gooooo0_l00004ooooo`Go00001_ooool3o`0000Oooooo1?l00004
ooooo`?o00000oooool3o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oo`00o`00
0?l00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`;o00001Oooool00ol0003o
ooooooooo`06ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooo`000005o`0000;o
oooo0_l00004ooooo`Co000000Koooooo`000?l0003oooooo`000?ooool2o`000008ooooool0003o
0000ooooool0003oooooo`000?ooool2o`000003ooooool0003ooooo00Go000000?oooooo`000?l0
00001Ol000000ooooooo0000ooooo`02o`0000Cooooo1_l0000@ooooo`03o`000?oooooooooo00co
oooo000;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`07ooooo`Go
o`001Oooool2o`0000?ooooo0_l000001?oooooo0000ooooool00002ooooo`Go000000Coooooo`00
0?oooooo00005?ooool6o`0000Gooooo0_l00004ooooo`Go00001_ooool3o`0000Oooooo1?l00004
ooooo`?o00000oooool3o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oo`00o`00
0?l00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`;o00001Oooool00ol0003o
ooooooooo`06ooooo`;o000000?oooooo`000?ooool01Oooool6o`0000;ooooo0_l00004ooooo`Co
000000Koooooo`000?l0003oooooo`000?ooool2o`000008ooooool0003o0000ooooool0003ooooo
o`000?ooool2o`000003ooooool0003ooooo00Go000000Goooooo`000?l0003o0000ooooo`03o`00
0003ooooool0003ooooo00;o00001?ooool6o`00013ooooo00?o0000ooooooooool03?ooool000_o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00_ooooo1Ooo00000ooo
oooo0000o`000003ooooo`;o000000Coooooo`000?oooooo00000oooool4o`000003ooooool0003o
oooo01Gooooo1_l00005ooooo`;o00001?ooool5o`0000Kooooo0ol00008ooooo`?o00001?ooool3
o`0000?ooooo0ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ool00?l0003o0000
0_ooool01?l0003oooooooooool00002ooooo`?o00000oooool2o`0000Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooo`000006ooooo`Ko00000_ooool2o`0000Cooooo1?l000001_oooooo
0000o`000?oooooo0000ooooo`;o000000Soooooo`000?l0003oooooo`000?oooooo0000ooooo`;o
000000?oooooo`000?ooool01Ol000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`00
0?ooool00_l00004ooooo`Ko00004?ooool00ol0003oooooooooo`0<ooooo`003?ooool3o`0000Ko
oooo00?o0000ooooooooool03oooool5ool000;ooooo0_l000001?oooooo0000ooooool00003oooo
o`Co000000?oooooo`000?ooool05Oooool6o`0000Gooooo0_l00004ooooo`03o`000?oooooo0000
00;o00001_ooool3o`0000Sooooo0ol00004ooooo`?o00001?ooool2o`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oo`00o`000?l00002ooooo`04o`000?ooooooooooo`0000;ooooo
0ol00003ooooo`;o00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Kooooo
1_l00002ooooo`;o00001?ooool4o`000006ooooool0003o0000ooooool0003ooooo0_l000002?oo
oooo0000o`000?oooooo0000ooooool0003ooooo0_l000000ooooooo0000ooooo`03o`000003oooo
ool0003ooooo00?o000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o00001?ooool6o`00
013ooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool04Oooool2o`000003
oooooooo003oo`0000;oo`0000?oooooo`000?ooool01?ooool4o`000003ooooool0003ooooo01Go
oooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001?ooool00ol0003oooooo`000002o`00
00Kooooo0ol00008ooooo`?o00001?ooool3o`0000Cooooo0_l00002ooooo`04o`000?oooooooooo
o`0000?ooooo00?oo`00o`000?l000000_ooool01?l0003oooooooooool00002ooooo`?o00000ooo
ool2o`0000Gooooo00?o0000ooooooooool01oooool00ol0003oooooo`000006ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000Cooooo1?l000001_oooooo0000o`000?oooooo0000ooooo`;o
000000Soooooo`000?l0003oooooo`000?oooooo0000ooooo`;o000000?oooooo`000?ooool00ol0
00000ooooooo0000ooooo`03o`000007ooooool0003o0000o`000?oooooo0000ooooo`02o`0000Co
oooo1_l0000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`;o00004_ooool2o`0000?ooooo
0_l00005ool000;ooooo1?l000000ooooooo0000ooooo`0Eooooo`;o000000Coooooo`000?l0003o
00001Oooool2o`0000Cooooo00?o0000ooooool000000_l00006ooooo`03o`000?oooooo000000So
oooo0ol00004ooooo`?o00001?ooool2o`0000;ooooo00Co0000oooooooooooo00000oooool00ooo
003o0000ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`;o00001Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooo000000Kooooo0ol000000ooooooo0000o`000002
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooool0003o0000ooooo`02o`000003ooooool0
003ooooo00;o000000Soooooo`000?l0003oooooo`000?oooooo0000ooooo`;o000000?oooooo`00
0?ooool00ol00003ooooo`?o000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o00001?oo
ool6o`00013ooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oooooooooo1Ooo0002o`000003ooooool0
003ooooo01Gooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001?ooool00ol0003ooooo
o`000002o`0000Kooooo00?o0000ooooool000002?ooool3o`0000Cooooo0ol00004ooooo`;o0000
0_ooool01?l0003oooooooooool00003ooooo`03ool00?l0003ooooo00;ooooo00Co0000oooooooo
oooo00000_ooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ool000001_ooool3o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00oooool01Ol0
003oooooo`000?l0003ooooo00;o000000?oooooo`000?ooool00_l000001ooooooo0000o`000?oo
oooo0000ooooool000000_ooool01?l0003oooooo`000?ooool3o`0000?ooooo0ol000001ooooooo
0000o`000?l0003oooooo`000?ooool00_l00004ooooo`?o000000?oooooo`000?l000004?ooool0
0ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00;ooooo0_l000000ooooooo0000ooooo`04ooooo`03o`000?oo003oo`0000?oo`005_ooool2o`00
0003ooooool0003o000000Kooooo0_l00004ooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ool000002?ooool2o`0000Gooooo0ol00004ooooo`;o00000_ooool01?l0003oooooooooool00003
ooooo`03ool00?l0003ooooo00;ooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo0_l0
0005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001_ooool3o`000003ooooool0
003o000000Sooooo00Go0000ooooool0003o0000ooooo`02o`000003ooooool0003ooooo00;o0000
00Ooooooo`000?l0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003ooooo0ol00003
ooooo`04o`000?oooooo0000ooooo`?o000000?oooooo`000?ooool00_l00004ooooo`?o000000?o
ooooo`000?l000004?ooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`;o000000?oooooo`000?ooool01Ooo000B
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo00?o0000ooooool000002?ooool0
0ol0003oooooo`000008ooooo`;o00001Oooool3o`0000Cooooo00Go0000ooooooooooooooooo`00
0002ooooo`06o`000?oooooooooooooooooo003o00000oooool01?l0003oooooooooool00002oooo
o`?o00000oooool2o`0000Gooooo00?o0000ooooooooool01oooool00ol0003oooooo`000006oooo
o`?o000000?oooooo`000?l000002?ooool01Ol0003oooooo`000?l0003ooooo00;o000000?ooooo
o`000?ooool00_l000001ooooooo0000o`000?oooooo0000ooooool000000_ooool01?l0003ooooo
o`000?ooool3o`0000?ooooo00Co0000ooooool0003ooooo0ol000000ooooooo0000ooooo`02o`00
00Gooooo0_l000000ooooooo0000o`00000@ooooo`03o`000?oooooooooo00cooooo000Eooooo`03
o`000?oooooooooo01Kooooo0_l00007ooooo`;o000000?oooooo`000?ooool01?ooool5ool000ko
oooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool00ol0003oooooo`000008ooooo`03
o`000?oooooo000000Sooooo0_l00005ooooo`?o00002?ooool01?l0003oooooooooool00003oooo
o`03ool00?l0003ooooo00;ooooo00Co0000oooooooooooo00000_ooool2o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001_ooool3o`000003ooooool0003o
000000Sooooo00Go0000ooooool0003o0000ooooo`02o`000003ooooool0003ooooo00;o000000Oo
ooooo`000?l0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003ooooo0ol00003oooo
o`0:o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooo`;o00001Oooool2o`000004
ooooool0003o0000o`0000oooooo00?o0000ooooooooool03?ooool001Gooooo0_l0000Gooooo`;o
00001oooool2o`000003ooooool0003ooooo00Wooooo1?oo000:ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Cooooo00?o0000ooooool000002?ooool00ol0003oooooo`000008ooooo`;o
00001Oooool3o`0000Sooooo00Co0000oooooooooooo00000oooool00ooo003o0000ooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooo000000Kooooo0ol000000ooooooo0000o`000008ooooo`05o`000?oooooo
0000o`000?ooool00_l000000ooooooo0000ooooo`02o`000007ooooool0003o0000ooooool0003o
ooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`0:o`000?oooooo
0000ooooool0003oooooo`000?oooooo0000ooooo`;o00001Oooool2o`000004ooooool0003o0000
o`0000oooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000ooooooooool05_ooool2o`00
00Oooooo0_l000000ooooooo0000ooooo`0=ooooo`Goo`001Oooool2o`000003ooooool0003o0000
00Kooooo0_l00004ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool000002?ooool2o`00
00Gooooo0ol00008ooooo`04o`000?ooooooooooo`0000?ooooo00?oo`00o`000?ooool00_ooool0
1?l0003oooooooooool00002ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooo`000006ooooo`?o000000?oooooo`000?l000002?ooool01Ol0003oooooo`00
0?l0003ooooo00;o000000?oooooo`000?ooool00_l000001ooooooo0000o`000?oooooo0000oooo
ool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000oooool02_l0003oooooo`00
0?oooooo0000ooooool0003oooooo`000?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0
000?ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo01Kooooo0_l00007
ooooo`;o000000?oooooo`000?ooool04Oooool5ool00004ooooool0003o0000ooooo`;o00001_oo
ool2o`0000Cooooo00?o0000ooooool000002?ooool00ol0003oooooo`000008ooooo`;o00001Ooo
ool3o`0000Sooooo00Co0000oooooooooooo00000oooool00ooo003o0000ooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooo000000Oooooo0_l000000ooooooo0000o`000008ooooo`05o`000?oooooo0000o`00
0?ooool00_l000000ooooooo0000ooooo`02o`000007ooooool0003o0000ooooool0003oooooo`00
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000005ooooo`08o`000?oooooo0000oooo
ool0003oooooo`000?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000?ooooo`03o`00
0?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo01Kooooo0_l00007ooooo`;o000000?o
ooooo`000?ooool05Oooool5ool000;o00001_ooool2o`0000Cooooo00?o0000ooooool000002?oo
ool00ol0003oooooo`000008ooooo`;o00001Oooool3o`0000Sooooo00Co0000oooooooooooo0000
0oooool00ooo003o0000ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo0_l00004ooooo`;o
00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo
0000o`000008ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool01Ol0003oooooo`000?l0
003ooooo00;o000000Coooooo`000?oooooo00000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000001Oooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l00005ooooo`;o0000
00Coooooo`000?l0003o00003oooool00ol0003oooooooooo`0<ooooo`005Oooool00ol0003ooooo
ooooo`0Fooooo`;o00001oooool2o`000003ooooool0003ooooo01Oooooo0_l00005ool000Cooooo
0_l00004ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool000002?ooool2o`0000Gooooo
0ol00008ooooo`04o`000?ooooooooooo`0000?ooooo00?oo`00o`000?ooool00_ooool01?l0003o
ooooooooool00008ooooo`;o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Gooooo0_l000000ooooooo0000o`000008ooooo`06o`000?oooooo0000o`000?oooooo00000_oo
ool01Ol0003oooooo`000?l0003ooooo00;o000000Coooooo`000?oooooo00000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000001Oooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool00ol0003oooooooooo`03ooooo`;o000000Coooooo`000?l0003o00003oooool00ol0003o
ooooooooo`0<ooooo`005Oooool2o`0001Oooooo0_l00007ooooo`;o00006_ooool2o`000003oooo
ool0003o000000;ooooo1?oo0002o`0000Cooooo00?o0000ooooool000002?ooool00ol0003ooooo
ooooo`08ooooo`;o00001Oooool3o`0000Sooooo00?o0000ooooooooool01?ooool00ooo003o0000
ooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo0_l00005ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool2o`000003ooooool0003o000000Sooooo00Ko0000ooooool0
003o0000ooooool00002ooooo`05o`000?oooooo0000o`000?ooool00_l000001?oooooo0000oooo
ool00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000005ooooo`07o`000?oooooo0000
ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_l0
000?ooooo`03o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo01Kooooo0_l00007
ooooo`;o00006_ooool2o`000003ooooool0003o000000Kooooo1Ooo00001?oooooo0000ooooool0
0008ooooo`03o`000?oooooooooo00Sooooo0_l00005ooooo`?o00002?ooool00ol0003ooooooooo
o`04ooooo`03ool00?l0003ooooo00;ooooo00Co0000oooooooooooo00002?ooool2o`0000Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`000?l00000
2?ooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00Go0000ooooool0003o0000ooooo`02
o`000004ooooool0003oooooo`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000Go
oooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooo`000002o`0000oooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000oooo
ooooool05_ooool2o`0000Oooooo0_l0000Jooooo`;o000000?oooooo`000?l000001_ooool2o`00
00;ooooo1Ooo0008ooooo`03o`000?oooooooooo00Sooooo0_l00005ooooo`?o00002?ooool00ol0
003oooooooooo`04ooooo`03ool00?l0003ooooo00Gooooo00?o0000ooooooooool01_ooool2o`00
00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`00
0?l000002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000ooooool0003o0000
ooooo`02o`000003ooooool0003ooooo00?ooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00Gooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooo`000002o`0000oooooo00?o0000ooooooooool03?ooool001Gooooo00?o0000
ooooooooool05_ooool2o`0000Oooooo0_l0000Jooooo`;o000000?oooooo`000?l000001_ooool0
0ol0003oooooooooo`03ooooo`03o`000?ooooooo`0000Coo`001?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Cooooo0ol00008ooooo`03o`000?oooooooooo00Cooooo00?oo`00
o`000?ooool01Oooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000o`000008ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000Co
oooo00Oo0000ooooool0003oooooo`000?oooooo000000Gooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000Wooooo00?o0000ooooool000000ol0000>ooooo`03o`000?oooooooooo00cooooo
000Eooooo`03o`000?oooooooooo01Kooooo0_l00007ooooo`;o00006_ooool00ol0003ooooooooo
o`02o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`Goo`0000?o
0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Sooooo00?o
0000ooooooooool01?ooool00ooo003o0000ooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l0
000Aooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000o`000008ooooo`06o`000?oo
ooooooooo`000?oooooo00000_ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo
00Cooooo00Oo0000ooooool0003oooooo`000?oooooo000000Oooooo00Go0000ooooool0003ooooo
o`000009ooooo`03o`000?oooooo000000?o00003_ooool00ol0003oooooooooo`0<ooooo`005Ooo
ool2o`0001Oooooo00?o0000ooooooooool01_ooool2o`0001[ooooo00?o0000ooooooooool00_l0
000<ooooo`03o`000?oooooo000000Oooooo1Ooo0007ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`04ooooo`03ool00?l0003ooooo00Gooooo00?o
0000ooooooooool01_ooool2o`00017ooooo00?o0000ooooooooool01Oooool2o`000003ooooool0
003o000000Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?oooooo0000o`00
00;ooooo00?o0000ooooooooool01?ooool01ol0003oooooo`000?oooooo0000ooooool000001ooo
ool01Ol0003oooooo`000?oooooo000000Wooooo00?o0000ooooool000000ol0000>ooooo`03o`00
0?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_oo
ool2o`0001[ooooo00?o0000ooooooooool00_l0000<ooooo`03o`000?oooooo000000cooooo1Ooo
0002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000002?ooool00ol0003ooooooooo
o`04ooooo`03ool00?l0003ooooo00Gooooo00?o0000ooooooooool01_ooool2o`00017ooooo00?o
0000ooooooooool01Oooool2o`000003ooooool0003o000000Sooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooo`000009ooooo`05o`000?oooooo0000ooooool000002Oooool00ol0003oooooo`000004
o`0000gooooo00?o0000ooooooooool03?ooool000cooooo0ol00006ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`04o`000?oooooooooo
o`0000gooooo00?o0000ooooool000004?ooool5ool000Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`04ooooo`03ool00?l0003ooooo00Gooooo00?o0000ooooooooool01_ooool2
o`0001Wooooo0_l000000ooooooo0000o`000008ooooo`06o`000?ooooooooooo`000?oooooo0000
0_ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool0
00002Oooool01Ol0003oooooo`000?oooooo000000_ooooo1_l0000<ooooo`03o`000?oooooooooo
00cooooo000;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool0000=
ooooo`03o`000?oooooo000001Cooooo1Ooo00000ooooooo0000ooooo`0@ooooo`03ool00?l0003o
oooo00Gooooo00?o0000ooooooooool01_ooool2o`0001Wooooo0_l000000ooooooo0000o`000008
ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooo`000?l00002ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooool000002Oooool01Ol0003oooooo`000?oooooo0000
00_ooooo0ol000000ooooooo0000o`000002o`0000[ooooo00?o0000ooooooooool03?ooool000oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02;o
oooo00Co0000oooooooooooo00003Oooool00ol0003oooooo`00000Iooooo`Coo`003oooool00ooo
003o0000ooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l0000Iooooo`;o000000?oooooo`00
0?l000002oooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000o`0000gooooo00?o0000
ooooooooool01oooool00ol0003oooooo`00000=ooooo`?o00001?ooool3o`0000Sooooo00?o0000
ooooooooool03?ooool000gooooo0_l00006ooooo`;o00005oooool00ol0003oooooooooo`0Roooo
o`04o`000?ooooooooooo`0000gooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`04
ool000_ooooo00?oo`00o`000?ooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Oooooo0_l00002ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooo0000oooo
o`02o`0000gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`?o00001_oo
ool3o`0000Kooooo00?o0000ooooooooool03?ooool000oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooool000006_oo
ool00ol0003oooooooooo`04ooooo`Goo`001_ooool00ooo003o0000ooooo`05ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05oooool2o`0000;ooooo00?o0000ooooooooool03_oo
ool01?l0003oooooo`000?l0000Gooooo`03o`000?oooooooooo00gooooo0ol00009ooooo`?o0000
0oooool00ol0003oooooooooo`0<ooooo`002oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool0>oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo000001[o
oooo00?o0000ooooooooool02?ooool5ool000;ooooo00?oo`00ooooooooool0:Oooool2o`0001?o
oooo00Co0000ooooool0003o00009oooool3o`0000_ooooo0ol000000ooooooo0000ooooo`0=oooo
o`003?ooool3o`0000Kooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0000ioooo
o`Coo`00@_ooool2o`0002Sooooo00?o0000ooooooooool03?ooool3o`0000kooooo000Eooooo`03
o`000?oooooooooo0?oooooo2Oooool001Gooooo0_l0003oooooo`[ooooo000Eooooo`03o`000?oo
oooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00K?ooool3o`000;7ooooo001]ooooo`03o`000?oooooo
oooo0;3ooooo0012ooooo`?o00001?ooool3o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o00000_ooool3o`0000Cooooo0ol00003
ooooo`Co00000_ooool4o`0000Oooooo0ol00003ooooo`Ko000000?oooooo`000?l000000_l00000
0ooooooo0000o`000002o`0000?ooooo0ol00008ooooo`?o00001Oooool2o`000003ooooool0003o
000000;o000000Coooooo`000?l0003ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol0
0002ooooo`?o000000?oooooo`000?l00000??ooool004?ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
0oooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooo`00000<ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0003gooooo0013ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0<ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool5o`00
00;ooooo0ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00002ooooo`?o00000oooool3o`0000;ooooo1Ol00008ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`00
00Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0kooooo`00@oooool3o`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0:ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`;o
00000oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`06o`000?ooooooooooo`000?oooooo
00000_ooool01?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool000002?ooool3
o`0000?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0kooooo`00@oooool01?l0003oooooooooool0
0002ooooo`?o00000_ooool3o`0000?ooooo1?l00002ooooo`Co00002Oooool00ol0003ooooooooo
o`02ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo0ol00003ooooo`;o00001?oo
ool3o`0000Wooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo0_l00004ooooo`Co0000
0_ooool3o`0000Wooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Co
00000oooool3o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l0000nooooo`00
@oooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooo
oooo00007?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool06oooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo053ooooo0012
ooooo`Co00002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0ol0000K
ooooo`;o00002?ooool4o`0000;ooooo0_l0000Looooo`Go00005?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo04Wooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.529161, -3.29677, \
0.00357556, 0.0400481}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.500465 0.00109616 0.0280925 0.561849 [
[.062 -0.0125 -12 -9 ]
[.062 -0.0125 12 0 ]
[.28123 -0.0125 -12 -9 ]
[.28123 -0.0125 12 0 ]
[.50047 -0.0125 -3 -9 ]
[.50047 -0.0125 3 0 ]
[.7197 -0.0125 -9 -9 ]
[.7197 -0.0125 9 0 ]
[.93893 -0.0125 -9 -9 ]
[.93893 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .14046 -18 -4.5 ]
[-0.0125 .14046 0 4.5 ]
[-0.0125 .25283 -18 -4.5 ]
[-0.0125 .25283 0 4.5 ]
[-0.0125 .3652 -18 -4.5 ]
[-0.0125 .3652 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -84 0 ]
[.5 .63053 84 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.062 0 m
.062 .00625 L
s
[(-400)] .062 -0.0125 0 1 Mshowa
.28123 0 m
.28123 .00625 L
s
[(-200)] .28123 -0.0125 0 1 Mshowa
.50047 0 m
.50047 .00625 L
s
[(0)] .50047 -0.0125 0 1 Mshowa
.7197 0 m
.7197 .00625 L
s
[(200)] .7197 -0.0125 0 1 Mshowa
.93893 0 m
.93893 .00625 L
s
[(400)] .93893 -0.0125 0 1 Mshowa
.125 Mabswid
.11681 0 m
.11681 .00375 L
s
.17162 0 m
.17162 .00375 L
s
.22642 0 m
.22642 .00375 L
s
.33604 0 m
.33604 .00375 L
s
.39085 0 m
.39085 .00375 L
s
.44566 0 m
.44566 .00375 L
s
.55527 0 m
.55527 .00375 L
s
.61008 0 m
.61008 .00375 L
s
.66489 0 m
.66489 .00375 L
s
.77451 0 m
.77451 .00375 L
s
.82931 0 m
.82931 .00375 L
s
.88412 0 m
.88412 .00375 L
s
.00719 0 m
.00719 .00375 L
s
.99374 0 m
.99374 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .14046 m
.00625 .14046 L
s
[(0.2)] -0.0125 .14046 1 0 Mshowa
0 .25283 m
.00625 .25283 L
s
[(0.4)] -0.0125 .25283 1 0 Mshowa
0 .3652 m
.00625 .3652 L
s
[(0.6)] -0.0125 .3652 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(0.8)] -0.0125 .47757 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(1)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
0 0 m
.00375 0 L
s
0 .61803 m
.00375 .61803 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.062 .61178 m
.062 .61803 L
s
.28123 .61178 m
.28123 .61803 L
s
.50047 .61178 m
.50047 .61803 L
s
.7197 .61178 m
.7197 .61803 L
s
.93893 .61178 m
.93893 .61803 L
s
.125 Mabswid
.11681 .61428 m
.11681 .61803 L
s
.17162 .61428 m
.17162 .61803 L
s
.22642 .61428 m
.22642 .61803 L
s
.33604 .61428 m
.33604 .61803 L
s
.39085 .61428 m
.39085 .61803 L
s
.44566 .61428 m
.44566 .61803 L
s
.55527 .61428 m
.55527 .61803 L
s
.61008 .61428 m
.61008 .61803 L
s
.66489 .61428 m
.66489 .61803 L
s
.77451 .61428 m
.77451 .61803 L
s
.82931 .61428 m
.82931 .61803 L
s
.88412 .61428 m
.88412 .61803 L
s
.00719 .61428 m
.00719 .61803 L
s
.99374 .61428 m
.99374 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .14046 m
1 .14046 L
s
.99375 .25283 m
1 .25283 L
s
.99375 .3652 m
1 .3652 L
s
.99375 .47757 m
1 .47757 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.99625 0 m
1 0 L
s
.99625 .61803 m
1 .61803 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.50047 0 m
.50047 .61803 L
s
[(Modulation Transfer Function)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .49823 m
.02474 .58219 L
.02567 .58288 L
.0266 .58292 L
.02753 .58295 L
.02846 .58299 L
.0294 .58302 L
.03033 .58305 L
.03126 .58309 L
.03219 .58312 L
.03312 .58315 L
.03405 .58318 L
.03498 .58321 L
.03591 .58325 L
.03684 .58328 L
.03777 .58332 L
.03871 .58335 L
.03964 .58338 L
.04057 .58342 L
.0415 .58345 L
.04243 .58348 L
.04336 .58351 L
.04429 .58354 L
.04522 .58358 L
.04615 .58361 L
.04708 .58364 L
.04801 .58367 L
.04895 .5837 L
.04988 .58373 L
.05081 .58377 L
.05174 .58379 L
.05267 .58382 L
.0536 .58385 L
.05453 .58388 L
.05546 .58391 L
.05639 .58394 L
.05732 .58397 L
.05826 .584 L
.05919 .58403 L
.06012 .58406 L
.06105 .58409 L
.06198 .58412 L
.06291 .58415 L
.06384 .58418 L
.06477 .58421 L
.0657 .58424 L
.06663 .58426 L
.06757 .58431 L
.0685 .58433 L
.06943 .58436 L
Mistroke
.07036 .58439 L
.07129 .58442 L
.07222 .58445 L
.07315 .58448 L
.07408 .5845 L
.07501 .58453 L
.07594 .58456 L
.07687 .58459 L
.07781 .58462 L
.07874 .58464 L
.07967 .58467 L
.0806 .5847 L
.08153 .58473 L
.08246 .58475 L
.08339 .58478 L
.08432 .58481 L
.08525 .58484 L
.08618 .58486 L
.08712 .58489 L
.08805 .58492 L
.08898 .58494 L
.08991 .58496 L
.09084 .58499 L
.09177 .58501 L
.0927 .58504 L
.09363 .58507 L
.09456 .58509 L
.09549 .58512 L
.09643 .58515 L
.09736 .58517 L
.09829 .5852 L
.09922 .58522 L
.10015 .58525 L
.10108 .58527 L
.10201 .5853 L
.10294 .58532 L
.10387 .58535 L
.1048 .58537 L
.10573 .5854 L
.10667 .58542 L
.1076 .58545 L
.10853 .58547 L
.10946 .58549 L
.11039 .58552 L
.11132 .58556 L
.11225 .58558 L
.11318 .5856 L
.11411 .58563 L
.11504 .58565 L
.11598 .58568 L
Mistroke
.11691 .5857 L
.11784 .58572 L
.11877 .58575 L
.1197 .58577 L
.12063 .58579 L
.12156 .58582 L
.12249 .58584 L
.12342 .58586 L
.12435 .58589 L
.12529 .58591 L
.12622 .58593 L
.12715 .58596 L
.12808 .58598 L
.12901 .586 L
.12994 .58603 L
.13087 .58605 L
.1318 .58607 L
.13273 .58609 L
.13366 .58611 L
.13459 .58614 L
.13553 .58616 L
.13646 .58618 L
.13739 .5862 L
.13832 .58622 L
.13925 .58625 L
.14018 .58627 L
.14111 .58629 L
.14204 .58631 L
.14297 .58633 L
.1439 .58635 L
.14484 .58637 L
.14577 .5864 L
.1467 .58642 L
.14763 .58644 L
.14856 .58646 L
.14949 .58648 L
.15042 .5865 L
.15135 .58652 L
.15228 .58654 L
.15321 .58656 L
.15415 .58658 L
.15508 .58659 L
.15601 .58661 L
.15694 .58663 L
.15787 .58665 L
.1588 .58667 L
.15973 .58669 L
.16066 .58671 L
.16159 .58673 L
.16252 .58675 L
Mistroke
.16345 .58677 L
.16439 .58679 L
.16532 .58681 L
.16625 .58683 L
.16718 .58685 L
.16811 .58687 L
.16904 .58689 L
.16997 .58691 L
.1709 .58693 L
.17183 .58695 L
.17276 .58696 L
.1737 .58698 L
.17463 .587 L
.17556 .58702 L
.17649 .58704 L
.17742 .58706 L
.17835 .58708 L
.17928 .58709 L
.18021 .58711 L
.18114 .58713 L
.18207 .58715 L
.18301 .58717 L
.18394 .58718 L
.18487 .5872 L
.1858 .58722 L
.18673 .58724 L
.18766 .58726 L
.18859 .58727 L
.18952 .58729 L
.19045 .58731 L
.19138 .58733 L
.19231 .58734 L
.19325 .58736 L
.19418 .58738 L
.19511 .58739 L
.19604 .58741 L
.19697 .58743 L
.1979 .58744 L
.19883 .58746 L
.19976 .58748 L
.20069 .58749 L
.20162 .58751 L
.20256 .58753 L
.20349 .58754 L
.20442 .58756 L
.20535 .58758 L
.20628 .58759 L
.20721 .58761 L
.20814 .58763 L
.20907 .58764 L
Mistroke
.21 .58766 L
.21093 .58767 L
.21187 .58769 L
.2128 .5877 L
.21373 .58772 L
.21466 .58774 L
.21559 .58775 L
.21652 .58777 L
.21745 .58778 L
.21838 .5878 L
.21931 .58781 L
.22024 .58783 L
.22117 .58784 L
.22211 .58786 L
.22304 .58787 L
.22397 .58789 L
.2249 .5879 L
.22583 .58792 L
.22676 .58793 L
.22769 .58795 L
.22862 .58796 L
.22955 .58798 L
.23048 .58799 L
.23142 .58801 L
.23235 .58802 L
.23328 .58803 L
.23421 .58805 L
.23514 .58806 L
.23607 .58808 L
.237 .58809 L
.23793 .58811 L
.23886 .58812 L
.23979 .58813 L
.24073 .58815 L
.24166 .58816 L
.24259 .58817 L
.24352 .58819 L
.24445 .5882 L
.24538 .58822 L
.24631 .58823 L
.24724 .58824 L
.24817 .58826 L
.2491 .58827 L
.25003 .58828 L
.25097 .5883 L
.2519 .58831 L
.25283 .58832 L
.25376 .58833 L
.25469 .58835 L
.25562 .58836 L
Mistroke
.25655 .58837 L
.25748 .58839 L
.25841 .5884 L
.25934 .58841 L
.26028 .58842 L
.26121 .58844 L
.26214 .58845 L
.26307 .58846 L
.264 .58847 L
.26493 .58849 L
.26586 .5885 L
.26679 .58851 L
.26772 .58852 L
.26865 .58853 L
.26959 .58855 L
.27052 .58856 L
.27145 .58857 L
.27238 .58858 L
.27331 .58859 L
.27424 .5886 L
.27517 .58862 L
.2761 .58863 L
.27703 .58864 L
.27796 .58865 L
.27889 .58866 L
.27983 .58867 L
.28076 .58868 L
.28169 .58869 L
.28262 .58871 L
.28355 .58872 L
.28448 .58873 L
.28541 .58874 L
.28634 .58875 L
.28727 .58876 L
.2882 .58877 L
.28914 .58878 L
.29007 .58879 L
.291 .5888 L
.29193 .58882 L
.29286 .58883 L
.29379 .58884 L
.29472 .58885 L
.29565 .58886 L
.29658 .58887 L
.29751 .58888 L
.29845 .58889 L
.29938 .5889 L
.30031 .58891 L
.30124 .58892 L
.30217 .58893 L
Mistroke
.3031 .58894 L
.30403 .58895 L
.30496 .58896 L
.30589 .58897 L
.30682 .58898 L
.30775 .58899 L
.30869 .589 L
.30962 .58901 L
.31055 .58902 L
.31148 .58903 L
.31241 .58903 L
.31334 .58904 L
.31427 .58905 L
.3152 .58906 L
.31613 .58907 L
.31706 .58908 L
.318 .58909 L
.31893 .58909 L
.31986 .5891 L
.32079 .58911 L
.32172 .58912 L
.32265 .58913 L
.32358 .58914 L
.32451 .58915 L
.32544 .58916 L
.32637 .58917 L
.32731 .58917 L
.32824 .58918 L
.32917 .58919 L
.3301 .5892 L
.33103 .58921 L
.33196 .58922 L
.33289 .58922 L
.33382 .58923 L
.33475 .58924 L
.33568 .58925 L
.33661 .58925 L
.33755 .58926 L
.33848 .58927 L
.33941 .58928 L
.34034 .58929 L
.34127 .58929 L
.3422 .5893 L
.34313 .58931 L
.34406 .58932 L
.34499 .58933 L
.34592 .58934 L
.34686 .58935 L
.34779 .58935 L
.34872 .58936 L
Mistroke
.34965 .58937 L
.35058 .58938 L
.35151 .58938 L
.35244 .58939 L
.35337 .5894 L
.3543 .5894 L
.35523 .58941 L
.35617 .58942 L
.3571 .58943 L
.35803 .58943 L
.35896 .58943 L
.35989 .58944 L
.36082 .58945 L
.36175 .58946 L
.36268 .58946 L
.36361 .58947 L
.36454 .58948 L
.36548 .58948 L
.36641 .58949 L
.36734 .5895 L
.36827 .5895 L
.3692 .58951 L
.37013 .58951 L
.37106 .58952 L
.37199 .58953 L
.37292 .58953 L
.37385 .58954 L
.37478 .58955 L
.37572 .58955 L
.37665 .58956 L
.37758 .58956 L
.37851 .58957 L
.37944 .58957 L
.38037 .58958 L
.3813 .58959 L
.38223 .58959 L
.38316 .5896 L
.38409 .58961 L
.38503 .58961 L
.38596 .58962 L
.38689 .58962 L
.38782 .58963 L
.38875 .58963 L
.38968 .58964 L
.39061 .58964 L
.39154 .58965 L
.39247 .58965 L
.3934 .58966 L
.39434 .58966 L
.39527 .58967 L
Mistroke
.3962 .58967 L
.39713 .58966 L
.39806 .58967 L
.39899 .58967 L
.39992 .58968 L
.40085 .58968 L
.40178 .58969 L
.40271 .58969 L
.40364 .5897 L
.40458 .5897 L
.40551 .58971 L
.40644 .58971 L
.40737 .58972 L
.4083 .58972 L
.40923 .58973 L
.41016 .58973 L
.41109 .58973 L
.41202 .58974 L
.41295 .58974 L
.41389 .58975 L
.41482 .58975 L
.41575 .58975 L
.41668 .58976 L
.41761 .58976 L
.41854 .58976 L
.41947 .58978 L
.4204 .58978 L
.42133 .58979 L
.42226 .58979 L
.4232 .58979 L
.42413 .5898 L
.42506 .5898 L
.42599 .58981 L
.42692 .58981 L
.42785 .58981 L
.42878 .58982 L
.42971 .58982 L
.43064 .58982 L
.43157 .58982 L
.4325 .58983 L
.43344 .58983 L
.43437 .58983 L
.4353 .58984 L
.43623 .58984 L
.43716 .58984 L
.43809 .58985 L
.43902 .58985 L
.43995 .58985 L
.44088 .58986 L
.44181 .58986 L
Mistroke
.44275 .58986 L
.44368 .58986 L
.44461 .58987 L
.44554 .58987 L
.44647 .58987 L
.4474 .58987 L
.44833 .58988 L
.44926 .58988 L
.45019 .58988 L
.45112 .58988 L
.45206 .58989 L
.45299 .58989 L
.45392 .58989 L
.45485 .58989 L
.45578 .58989 L
.45671 .5899 L
.45764 .5899 L
.45857 .5899 L
.4595 .5899 L
.46043 .5899 L
.46136 .5899 L
.4623 .58991 L
.46323 .58991 L
.46416 .58989 L
.46509 .5899 L
.46602 .5899 L
.46695 .5899 L
.46788 .5899 L
.46881 .58991 L
.46974 .58991 L
.47067 .58991 L
.47161 .58991 L
.47254 .58991 L
.47347 .58991 L
.4744 .58991 L
.47533 .58992 L
.47626 .58992 L
.47719 .58992 L
.47812 .58992 L
.47905 .58992 L
.47998 .58992 L
.48092 .58992 L
.48185 .58992 L
.48278 .58993 L
.48371 .58993 L
.48464 .58994 L
.48557 .58994 L
.4865 .58994 L
.48743 .58994 L
.48836 .58994 L
Mistroke
.48929 .58994 L
.49022 .58994 L
.49116 .58994 L
.49209 .58994 L
.49302 .58994 L
.49395 .58994 L
.49488 .58994 L
.49581 .58994 L
.49674 .58994 L
.49767 .58994 L
.4986 .58994 L
.49953 .58994 L
.50047 .58994 L
.5014 .58994 L
.50233 .58994 L
.50326 .58994 L
.50419 .58994 L
.50512 .58994 L
.50605 .58994 L
.50698 .58994 L
.50791 .58994 L
.50884 .58994 L
.50978 .58994 L
.51071 .58994 L
.51164 .58994 L
.51257 .58994 L
.5135 .58994 L
.51443 .58994 L
.51536 .58994 L
.51629 .58994 L
.51722 .58993 L
.51815 .58993 L
.51908 .58993 L
.52002 .58993 L
.52095 .58993 L
.52188 .58993 L
.52281 .58993 L
.52374 .58993 L
.52467 .58993 L
.5256 .58993 L
.52653 .58991 L
.52746 .58991 L
.52839 .58991 L
.52933 .58991 L
.53026 .58991 L
.53119 .58991 L
.53212 .58991 L
.53305 .58991 L
.53398 .5899 L
.53491 .5899 L
Mistroke
.53584 .5899 L
.53677 .5899 L
.5377 .5899 L
.53864 .5899 L
.53957 .58989 L
.5405 .58989 L
.54143 .58989 L
.54236 .58989 L
.54329 .58988 L
.54422 .58988 L
.54515 .58988 L
.54608 .58989 L
.54701 .58989 L
.54794 .58988 L
.54888 .58988 L
.54981 .58988 L
.55074 .58988 L
.55167 .58988 L
.5526 .58987 L
.55353 .58987 L
.55446 .58987 L
.55539 .58987 L
.55632 .58986 L
.55725 .58986 L
.55819 .58985 L
.55912 .58985 L
.56005 .58985 L
.56098 .58985 L
.56191 .58984 L
.56284 .58984 L
.56377 .58984 L
.5647 .58983 L
.56563 .58983 L
.56656 .58983 L
.5675 .58983 L
.56843 .58982 L
.56936 .58982 L
.57029 .58982 L
.57122 .58981 L
.57215 .58981 L
.57308 .5898 L
.57401 .5898 L
.57494 .5898 L
.57587 .58979 L
.5768 .58979 L
.57774 .58979 L
.57867 .58979 L
.5796 .58978 L
.58053 .58978 L
.58146 .58978 L
Mistroke
.58239 .58977 L
.58332 .58977 L
.58425 .58977 L
.58518 .58976 L
.58611 .58976 L
.58705 .58975 L
.58798 .58975 L
.58891 .58974 L
.58984 .58974 L
.59077 .58974 L
.5917 .58972 L
.59263 .58972 L
.59356 .58972 L
.59449 .58971 L
.59542 .58971 L
.59636 .5897 L
.59729 .5897 L
.59822 .58969 L
.59915 .58969 L
.60008 .58969 L
.60101 .58968 L
.60194 .58968 L
.60287 .58967 L
.6038 .58967 L
.60473 .58966 L
.60566 .58966 L
.6066 .58965 L
.60753 .58965 L
.60846 .58964 L
.60939 .58964 L
.61032 .58963 L
.61125 .58962 L
.61218 .58962 L
.61311 .58962 L
.61404 .58962 L
.61497 .58961 L
.61591 .5896 L
.61684 .5896 L
.61777 .58959 L
.6187 .58959 L
.61963 .58958 L
.62056 .58958 L
.62149 .58957 L
.62242 .58957 L
.62335 .58956 L
.62428 .58955 L
.62522 .58955 L
.62615 .58954 L
.62708 .58953 L
.62801 .58952 L
Mistroke
.62894 .58952 L
.62987 .58951 L
.6308 .5895 L
.63173 .5895 L
.63266 .58949 L
.63359 .58949 L
.63452 .58948 L
.63546 .58947 L
.63639 .58947 L
.63732 .58946 L
.63825 .58945 L
.63918 .58945 L
.64011 .58944 L
.64104 .58943 L
.64197 .58943 L
.6429 .58942 L
.64383 .58941 L
.64477 .5894 L
.6457 .5894 L
.64663 .58939 L
.64756 .58938 L
.64849 .58938 L
.64942 .58937 L
.65035 .58936 L
.65128 .58935 L
.65221 .58934 L
.65314 .58935 L
.65408 .58934 L
.65501 .58933 L
.65594 .58932 L
.65687 .58932 L
.6578 .58931 L
.65873 .5893 L
.65966 .58929 L
.66059 .58929 L
.66152 .58928 L
.66245 .58927 L
.66339 .58926 L
.66432 .58925 L
.66525 .58925 L
.66618 .58924 L
.66711 .58923 L
.66804 .58922 L
.66897 .58921 L
.6699 .5892 L
.67083 .58919 L
.67176 .58918 L
.67269 .58918 L
.67363 .58917 L
.67456 .58916 L
Mistroke
.67549 .58915 L
.67642 .58914 L
.67735 .58913 L
.67828 .58913 L
.67921 .58912 L
.68014 .58911 L
.68107 .5891 L
.682 .58909 L
.68294 .58908 L
.68387 .58907 L
.6848 .58906 L
.68573 .58905 L
.68666 .58904 L
.68759 .58904 L
.68852 .58903 L
.68945 .58902 L
.69038 .58901 L
.69131 .589 L
.69225 .58899 L
.69318 .58898 L
.69411 .58897 L
.69504 .58896 L
.69597 .58895 L
.6969 .58894 L
.69783 .58893 L
.69876 .58892 L
.69969 .58891 L
.70062 .5889 L
.70155 .58889 L
.70249 .58888 L
.70342 .58887 L
.70435 .58886 L
.70528 .58885 L
.70621 .58884 L
.70714 .58883 L
.70807 .58882 L
.709 .58881 L
.70993 .5888 L
.71086 .58879 L
.7118 .58878 L
.71273 .58877 L
.71366 .58876 L
.71459 .58875 L
.71552 .58873 L
.71645 .58872 L
.71738 .58871 L
.71831 .5887 L
.71924 .58869 L
.72017 .58868 L
.72111 .58867 L
Mistroke
.72204 .58866 L
.72297 .58864 L
.7239 .58863 L
.72483 .58862 L
.72576 .58861 L
.72669 .5886 L
.72762 .58859 L
.72855 .58858 L
.72948 .58855 L
.73041 .58854 L
.73135 .58853 L
.73228 .58852 L
.73321 .5885 L
.73414 .58849 L
.73507 .58848 L
.736 .58847 L
.73693 .58846 L
.73786 .58844 L
.73879 .58843 L
.73972 .58842 L
.74066 .58841 L
.74159 .58839 L
.74252 .58838 L
.74345 .58837 L
.74438 .58836 L
.74531 .58834 L
.74624 .58833 L
.74717 .58832 L
.7481 .5883 L
.74903 .58829 L
.74997 .58828 L
.7509 .58827 L
.75183 .58825 L
.75276 .58824 L
.75369 .58823 L
.75462 .58821 L
.75555 .5882 L
.75648 .58819 L
.75741 .58817 L
.75834 .58816 L
.75927 .58814 L
.76021 .58813 L
.76114 .58812 L
.76207 .5881 L
.763 .58809 L
.76393 .58808 L
.76486 .58806 L
.76579 .58805 L
.76672 .58803 L
.76765 .58802 L
Mistroke
.76858 .588 L
.76952 .58799 L
.77045 .58797 L
.77138 .58796 L
.77231 .58795 L
.77324 .58793 L
.77417 .58792 L
.7751 .5879 L
.77603 .58789 L
.77696 .58787 L
.77789 .58786 L
.77883 .58784 L
.77976 .58783 L
.78069 .58781 L
.78162 .5878 L
.78255 .58778 L
.78348 .58777 L
.78441 .58775 L
.78534 .58773 L
.78627 .58772 L
.7872 .5877 L
.78813 .58769 L
.78907 .58767 L
.79 .58766 L
.79093 .58764 L
.79186 .58762 L
.79279 .58761 L
.79372 .58759 L
.79465 .58758 L
.79558 .58756 L
.79651 .58754 L
.79744 .58753 L
.79838 .58751 L
.79931 .58749 L
.80024 .58748 L
.80117 .58746 L
.8021 .58744 L
.80303 .58743 L
.80396 .58741 L
.80489 .58739 L
.80582 .58738 L
.80675 .58736 L
.80769 .58734 L
.80862 .58732 L
.80955 .58731 L
.81048 .58729 L
.81141 .58727 L
.81234 .58725 L
.81327 .58724 L
.8142 .58722 L
Mistroke
.81513 .5872 L
.81606 .58718 L
.81699 .58716 L
.81793 .58715 L
.81886 .58713 L
.81979 .58711 L
.82072 .58709 L
.82165 .58707 L
.82258 .58705 L
.82351 .58704 L
.82444 .58702 L
.82537 .587 L
.8263 .58698 L
.82724 .58696 L
.82817 .58694 L
.8291 .58694 L
.83003 .58692 L
.83096 .5869 L
.83189 .58688 L
.83282 .58686 L
.83375 .58684 L
.83468 .58682 L
.83561 .5868 L
.83655 .58678 L
.83748 .58676 L
.83841 .58674 L
.83934 .58672 L
.84027 .5867 L
.8412 .58668 L
.84213 .58666 L
.84306 .58664 L
.84399 .58662 L
.84492 .5866 L
.84585 .58658 L
.84679 .58656 L
.84772 .58654 L
.84865 .58652 L
.84958 .5865 L
.85051 .58648 L
.85144 .58646 L
.85237 .58644 L
.8533 .58641 L
.85423 .58639 L
.85516 .58637 L
.8561 .58635 L
.85703 .58633 L
.85796 .58631 L
.85889 .58629 L
.85982 .58627 L
.86075 .58624 L
Mistroke
.86168 .58622 L
.86261 .5862 L
.86354 .58618 L
.86447 .58616 L
.86541 .58613 L
.86634 .58611 L
.86727 .58609 L
.8682 .58607 L
.86913 .58604 L
.87006 .58602 L
.87099 .586 L
.87192 .58598 L
.87285 .58595 L
.87378 .58593 L
.87471 .58591 L
.87565 .58588 L
.87658 .58586 L
.87751 .58584 L
.87844 .58582 L
.87937 .58579 L
.8803 .58577 L
.88123 .58574 L
.88216 .58571 L
.88309 .58569 L
.88402 .58567 L
.88496 .58564 L
.88589 .58562 L
.88682 .5856 L
.88775 .58557 L
.88868 .58555 L
.88961 .58553 L
.89054 .5855 L
.89147 .58548 L
.8924 .58545 L
.89333 .58543 L
.89427 .5854 L
.8952 .58538 L
.89613 .58535 L
.89706 .58533 L
.89799 .5853 L
.89892 .58528 L
.89985 .58525 L
.90078 .58522 L
.90171 .5852 L
.90264 .58517 L
.90357 .58515 L
.90451 .58513 L
.90544 .5851 L
.90637 .58508 L
.9073 .58504 L
Mistroke
.90823 .58502 L
.90916 .58499 L
.91009 .58497 L
.91102 .58494 L
.91195 .58491 L
.91288 .58489 L
.91382 .58486 L
.91475 .58483 L
.91568 .58481 L
.91661 .58478 L
.91754 .58475 L
.91847 .58472 L
.9194 .5847 L
.92033 .58467 L
.92126 .58464 L
.92219 .58461 L
.92313 .58458 L
.92406 .58456 L
.92499 .58453 L
.92592 .5845 L
.92685 .58448 L
.92778 .58445 L
.92871 .58441 L
.92964 .58439 L
.93057 .58436 L
.9315 .58433 L
.93243 .5843 L
.93337 .58427 L
.9343 .58424 L
.93523 .58421 L
.93616 .58418 L
.93709 .58416 L
.93802 .58413 L
.93895 .5841 L
.93988 .58407 L
.94081 .58404 L
.94174 .58401 L
.94268 .58397 L
.94361 .58394 L
.94454 .58391 L
.94547 .58388 L
.9464 .58385 L
.94733 .58382 L
.94826 .58379 L
.94919 .58376 L
.95012 .58373 L
.95105 .5837 L
.95199 .58367 L
.95292 .58364 L
.95385 .58361 L
Mistroke
.95478 .58357 L
.95571 .58354 L
.95664 .58351 L
.95757 .58348 L
.9585 .58344 L
.95943 .58341 L
.96036 .58339 L
.96129 .58335 L
.96223 .58332 L
.96316 .58328 L
.96409 .58325 L
.96502 .58322 L
.96595 .58319 L
.96688 .58315 L
.96781 .58312 L
.96874 .58309 L
.96967 .58305 L
.9706 .58302 L
.97154 .58299 L
.97247 .58295 L
.9734 .58292 L
.97433 .58287 L
.97526 .58225 L
.97619 .49794 L
Mfstroke
1 0 0 r
.02381 .49823 m
.02474 .58219 L
.02567 .58288 L
.0266 .58292 L
.02753 .58295 L
.02846 .58299 L
.0294 .58302 L
.03033 .58305 L
.03126 .58309 L
.03219 .58312 L
.03312 .58315 L
.03405 .58318 L
.03498 .58321 L
.03591 .58325 L
.03684 .58328 L
.03777 .58332 L
.03871 .58335 L
.03964 .58338 L
.04057 .58342 L
.0415 .58345 L
.04243 .58348 L
.04336 .58351 L
.04429 .58354 L
.04522 .58358 L
.04615 .58361 L
.04708 .58364 L
.04801 .58367 L
.04895 .5837 L
.04988 .58373 L
.05081 .58377 L
.05174 .58379 L
.05267 .58382 L
.0536 .58385 L
.05453 .58388 L
.05546 .58391 L
.05639 .58394 L
.05732 .58397 L
.05826 .584 L
.05919 .58403 L
.06012 .58406 L
.06105 .58409 L
.06198 .58412 L
.06291 .58415 L
.06384 .58418 L
.06477 .58421 L
.0657 .58424 L
.06663 .58426 L
.06757 .58431 L
.0685 .58433 L
.06943 .58436 L
Mistroke
.07036 .58439 L
.07129 .58442 L
.07222 .58445 L
.07315 .58448 L
.07408 .5845 L
.07501 .58453 L
.07594 .58456 L
.07687 .58459 L
.07781 .58462 L
.07874 .58464 L
.07967 .58467 L
.0806 .5847 L
.08153 .58473 L
.08246 .58475 L
.08339 .58478 L
.08432 .58481 L
.08525 .58484 L
.08618 .58486 L
.08712 .58489 L
.08805 .58492 L
.08898 .58494 L
.08991 .58496 L
.09084 .58499 L
.09177 .58501 L
.0927 .58504 L
.09363 .58507 L
.09456 .58509 L
.09549 .58512 L
.09643 .58515 L
.09736 .58517 L
.09829 .5852 L
.09922 .58522 L
.10015 .58525 L
.10108 .58527 L
.10201 .5853 L
.10294 .58532 L
.10387 .58535 L
.1048 .58537 L
.10573 .5854 L
.10667 .58542 L
.1076 .58545 L
.10853 .58547 L
.10946 .58549 L
.11039 .58552 L
.11132 .58556 L
.11225 .58558 L
.11318 .5856 L
.11411 .58563 L
.11504 .58565 L
.11598 .58568 L
Mistroke
.11691 .5857 L
.11784 .58572 L
.11877 .58575 L
.1197 .58577 L
.12063 .58579 L
.12156 .58582 L
.12249 .58584 L
.12342 .58586 L
.12435 .58589 L
.12529 .58591 L
.12622 .58593 L
.12715 .58596 L
.12808 .58598 L
.12901 .586 L
.12994 .58603 L
.13087 .58605 L
.1318 .58607 L
.13273 .58609 L
.13366 .58611 L
.13459 .58614 L
.13553 .58616 L
.13646 .58618 L
.13739 .5862 L
.13832 .58622 L
.13925 .58625 L
.14018 .58627 L
.14111 .58629 L
.14204 .58631 L
.14297 .58633 L
.1439 .58635 L
.14484 .58637 L
.14577 .5864 L
.1467 .58642 L
.14763 .58644 L
.14856 .58646 L
.14949 .58648 L
.15042 .5865 L
.15135 .58652 L
.15228 .58654 L
.15321 .58656 L
.15415 .58658 L
.15508 .58659 L
.15601 .58661 L
.15694 .58663 L
.15787 .58665 L
.1588 .58667 L
.15973 .58669 L
.16066 .58671 L
.16159 .58673 L
.16252 .58675 L
Mistroke
.16345 .58677 L
.16439 .58679 L
.16532 .58681 L
.16625 .58683 L
.16718 .58685 L
.16811 .58687 L
.16904 .58689 L
.16997 .58691 L
.1709 .58693 L
.17183 .58695 L
.17276 .58696 L
.1737 .58698 L
.17463 .587 L
.17556 .58702 L
.17649 .58704 L
.17742 .58706 L
.17835 .58708 L
.17928 .58709 L
.18021 .58711 L
.18114 .58713 L
.18207 .58715 L
.18301 .58717 L
.18394 .58718 L
.18487 .5872 L
.1858 .58722 L
.18673 .58724 L
.18766 .58726 L
.18859 .58727 L
.18952 .58729 L
.19045 .58731 L
.19138 .58733 L
.19231 .58734 L
.19325 .58736 L
.19418 .58738 L
.19511 .58739 L
.19604 .58741 L
.19697 .58743 L
.1979 .58744 L
.19883 .58746 L
.19976 .58748 L
.20069 .58749 L
.20162 .58751 L
.20256 .58753 L
.20349 .58754 L
.20442 .58756 L
.20535 .58758 L
.20628 .58759 L
.20721 .58761 L
.20814 .58763 L
.20907 .58764 L
Mistroke
.21 .58766 L
.21093 .58767 L
.21187 .58769 L
.2128 .5877 L
.21373 .58772 L
.21466 .58774 L
.21559 .58775 L
.21652 .58777 L
.21745 .58778 L
.21838 .5878 L
.21931 .58781 L
.22024 .58783 L
.22117 .58784 L
.22211 .58786 L
.22304 .58787 L
.22397 .58789 L
.2249 .5879 L
.22583 .58792 L
.22676 .58793 L
.22769 .58795 L
.22862 .58796 L
.22955 .58798 L
.23048 .58799 L
.23142 .58801 L
.23235 .58802 L
.23328 .58803 L
.23421 .58805 L
.23514 .58806 L
.23607 .58808 L
.237 .58809 L
.23793 .58811 L
.23886 .58812 L
.23979 .58813 L
.24073 .58815 L
.24166 .58816 L
.24259 .58817 L
.24352 .58819 L
.24445 .5882 L
.24538 .58822 L
.24631 .58823 L
.24724 .58824 L
.24817 .58826 L
.2491 .58827 L
.25003 .58828 L
.25097 .5883 L
.2519 .58831 L
.25283 .58832 L
.25376 .58833 L
.25469 .58835 L
.25562 .58836 L
Mistroke
.25655 .58837 L
.25748 .58839 L
.25841 .5884 L
.25934 .58841 L
.26028 .58842 L
.26121 .58844 L
.26214 .58845 L
.26307 .58846 L
.264 .58847 L
.26493 .58849 L
.26586 .5885 L
.26679 .58851 L
.26772 .58852 L
.26865 .58853 L
.26959 .58855 L
.27052 .58856 L
.27145 .58857 L
.27238 .58858 L
.27331 .58859 L
.27424 .5886 L
.27517 .58862 L
.2761 .58863 L
.27703 .58864 L
.27796 .58865 L
.27889 .58866 L
.27983 .58867 L
.28076 .58868 L
.28169 .58869 L
.28262 .58871 L
.28355 .58872 L
.28448 .58873 L
.28541 .58874 L
.28634 .58875 L
.28727 .58876 L
.2882 .58877 L
.28914 .58878 L
.29007 .58879 L
.291 .5888 L
.29193 .58882 L
.29286 .58883 L
.29379 .58884 L
.29472 .58885 L
.29565 .58886 L
.29658 .58887 L
.29751 .58888 L
.29845 .58889 L
.29938 .5889 L
.30031 .58891 L
.30124 .58892 L
.30217 .58893 L
Mistroke
.3031 .58894 L
.30403 .58895 L
.30496 .58896 L
.30589 .58897 L
.30682 .58898 L
.30775 .58899 L
.30869 .589 L
.30962 .58901 L
.31055 .58902 L
.31148 .58903 L
.31241 .58903 L
.31334 .58904 L
.31427 .58905 L
.3152 .58906 L
.31613 .58907 L
.31706 .58908 L
.318 .58909 L
.31893 .58909 L
.31986 .5891 L
.32079 .58911 L
.32172 .58912 L
.32265 .58913 L
.32358 .58914 L
.32451 .58915 L
.32544 .58916 L
.32637 .58917 L
.32731 .58917 L
.32824 .58918 L
.32917 .58919 L
.3301 .5892 L
.33103 .58921 L
.33196 .58922 L
.33289 .58922 L
.33382 .58923 L
.33475 .58924 L
.33568 .58925 L
.33661 .58925 L
.33755 .58926 L
.33848 .58927 L
.33941 .58928 L
.34034 .58929 L
.34127 .58929 L
.3422 .5893 L
.34313 .58931 L
.34406 .58932 L
.34499 .58933 L
.34592 .58934 L
.34686 .58935 L
.34779 .58935 L
.34872 .58936 L
Mistroke
.34965 .58937 L
.35058 .58938 L
.35151 .58938 L
.35244 .58939 L
.35337 .5894 L
.3543 .5894 L
.35523 .58941 L
.35617 .58942 L
.3571 .58943 L
.35803 .58943 L
.35896 .58943 L
.35989 .58944 L
.36082 .58945 L
.36175 .58946 L
.36268 .58946 L
.36361 .58947 L
.36454 .58948 L
.36548 .58948 L
.36641 .58949 L
.36734 .5895 L
.36827 .5895 L
.3692 .58951 L
.37013 .58951 L
.37106 .58952 L
.37199 .58953 L
.37292 .58953 L
.37385 .58954 L
.37478 .58955 L
.37572 .58955 L
.37665 .58956 L
.37758 .58956 L
.37851 .58957 L
.37944 .58957 L
.38037 .58958 L
.3813 .58959 L
.38223 .58959 L
.38316 .5896 L
.38409 .58961 L
.38503 .58961 L
.38596 .58962 L
.38689 .58962 L
.38782 .58963 L
.38875 .58963 L
.38968 .58964 L
.39061 .58964 L
.39154 .58965 L
.39247 .58965 L
.3934 .58966 L
.39434 .58966 L
.39527 .58967 L
Mistroke
.3962 .58967 L
.39713 .58966 L
.39806 .58967 L
.39899 .58967 L
.39992 .58968 L
.40085 .58968 L
.40178 .58969 L
.40271 .58969 L
.40364 .5897 L
.40458 .5897 L
.40551 .58971 L
.40644 .58971 L
.40737 .58972 L
.4083 .58972 L
.40923 .58973 L
.41016 .58973 L
.41109 .58973 L
.41202 .58974 L
.41295 .58974 L
.41389 .58975 L
.41482 .58975 L
.41575 .58975 L
.41668 .58976 L
.41761 .58976 L
.41854 .58976 L
.41947 .58978 L
.4204 .58978 L
.42133 .58979 L
.42226 .58979 L
.4232 .58979 L
.42413 .5898 L
.42506 .5898 L
.42599 .58981 L
.42692 .58981 L
.42785 .58981 L
.42878 .58982 L
.42971 .58982 L
.43064 .58982 L
.43157 .58982 L
.4325 .58983 L
.43344 .58983 L
.43437 .58983 L
.4353 .58984 L
.43623 .58984 L
.43716 .58984 L
.43809 .58985 L
.43902 .58985 L
.43995 .58985 L
.44088 .58986 L
.44181 .58986 L
Mistroke
.44275 .58986 L
.44368 .58986 L
.44461 .58987 L
.44554 .58987 L
.44647 .58987 L
.4474 .58987 L
.44833 .58988 L
.44926 .58988 L
.45019 .58988 L
.45112 .58988 L
.45206 .58989 L
.45299 .58989 L
.45392 .58989 L
.45485 .58989 L
.45578 .58989 L
.45671 .5899 L
.45764 .5899 L
.45857 .5899 L
.4595 .5899 L
.46043 .5899 L
.46136 .5899 L
.4623 .58991 L
.46323 .58991 L
.46416 .58989 L
.46509 .5899 L
.46602 .5899 L
.46695 .5899 L
.46788 .5899 L
.46881 .58991 L
.46974 .58991 L
.47067 .58991 L
.47161 .58991 L
.47254 .58991 L
.47347 .58991 L
.4744 .58991 L
.47533 .58992 L
.47626 .58992 L
.47719 .58992 L
.47812 .58992 L
.47905 .58992 L
.47998 .58992 L
.48092 .58992 L
.48185 .58992 L
.48278 .58993 L
.48371 .58993 L
.48464 .58994 L
.48557 .58994 L
.4865 .58994 L
.48743 .58994 L
.48836 .58994 L
Mistroke
.48929 .58994 L
.49022 .58994 L
.49116 .58994 L
.49209 .58994 L
.49302 .58994 L
.49395 .58994 L
.49488 .58994 L
.49581 .58994 L
.49674 .58994 L
.49767 .58994 L
.4986 .58994 L
.49953 .58994 L
.50047 .58994 L
.5014 .58994 L
.50233 .58994 L
.50326 .58994 L
.50419 .58994 L
.50512 .58994 L
.50605 .58994 L
.50698 .58994 L
.50791 .58994 L
.50884 .58994 L
.50978 .58994 L
.51071 .58994 L
.51164 .58994 L
.51257 .58994 L
.5135 .58994 L
.51443 .58994 L
.51536 .58994 L
.51629 .58994 L
.51722 .58993 L
.51815 .58993 L
.51908 .58993 L
.52002 .58993 L
.52095 .58993 L
.52188 .58993 L
.52281 .58993 L
.52374 .58993 L
.52467 .58993 L
.5256 .58993 L
.52653 .58991 L
.52746 .58991 L
.52839 .58991 L
.52933 .58991 L
.53026 .58991 L
.53119 .58991 L
.53212 .58991 L
.53305 .58991 L
.53398 .5899 L
.53491 .5899 L
Mistroke
.53584 .5899 L
.53677 .5899 L
.5377 .5899 L
.53864 .5899 L
.53957 .58989 L
.5405 .58989 L
.54143 .58989 L
.54236 .58989 L
.54329 .58988 L
.54422 .58988 L
.54515 .58988 L
.54608 .58989 L
.54701 .58989 L
.54794 .58988 L
.54888 .58988 L
.54981 .58988 L
.55074 .58988 L
.55167 .58988 L
.5526 .58987 L
.55353 .58987 L
.55446 .58987 L
.55539 .58987 L
.55632 .58986 L
.55725 .58986 L
.55819 .58985 L
.55912 .58985 L
.56005 .58985 L
.56098 .58985 L
.56191 .58984 L
.56284 .58984 L
.56377 .58984 L
.5647 .58983 L
.56563 .58983 L
.56656 .58983 L
.5675 .58983 L
.56843 .58982 L
.56936 .58982 L
.57029 .58982 L
.57122 .58981 L
.57215 .58981 L
.57308 .5898 L
.57401 .5898 L
.57494 .5898 L
.57587 .58979 L
.5768 .58979 L
.57774 .58979 L
.57867 .58979 L
.5796 .58978 L
.58053 .58978 L
.58146 .58978 L
Mistroke
.58239 .58977 L
.58332 .58977 L
.58425 .58977 L
.58518 .58976 L
.58611 .58976 L
.58705 .58975 L
.58798 .58975 L
.58891 .58974 L
.58984 .58974 L
.59077 .58974 L
.5917 .58972 L
.59263 .58972 L
.59356 .58972 L
.59449 .58971 L
.59542 .58971 L
.59636 .5897 L
.59729 .5897 L
.59822 .58969 L
.59915 .58969 L
.60008 .58969 L
.60101 .58968 L
.60194 .58968 L
.60287 .58967 L
.6038 .58967 L
.60473 .58966 L
.60566 .58966 L
.6066 .58965 L
.60753 .58965 L
.60846 .58964 L
.60939 .58964 L
.61032 .58963 L
.61125 .58962 L
.61218 .58962 L
.61311 .58962 L
.61404 .58962 L
.61497 .58961 L
.61591 .5896 L
.61684 .5896 L
.61777 .58959 L
.6187 .58959 L
.61963 .58958 L
.62056 .58958 L
.62149 .58957 L
.62242 .58957 L
.62335 .58956 L
.62428 .58955 L
.62522 .58955 L
.62615 .58954 L
.62708 .58953 L
.62801 .58952 L
Mistroke
.62894 .58952 L
.62987 .58951 L
.6308 .5895 L
.63173 .5895 L
.63266 .58949 L
.63359 .58949 L
.63452 .58948 L
.63546 .58947 L
.63639 .58947 L
.63732 .58946 L
.63825 .58945 L
.63918 .58945 L
.64011 .58944 L
.64104 .58943 L
.64197 .58943 L
.6429 .58942 L
.64383 .58941 L
.64477 .5894 L
.6457 .5894 L
.64663 .58939 L
.64756 .58938 L
.64849 .58938 L
.64942 .58937 L
.65035 .58936 L
.65128 .58935 L
.65221 .58934 L
.65314 .58935 L
.65408 .58934 L
.65501 .58933 L
.65594 .58932 L
.65687 .58932 L
.6578 .58931 L
.65873 .5893 L
.65966 .58929 L
.66059 .58929 L
.66152 .58928 L
.66245 .58927 L
.66339 .58926 L
.66432 .58925 L
.66525 .58925 L
.66618 .58924 L
.66711 .58923 L
.66804 .58922 L
.66897 .58921 L
.6699 .5892 L
.67083 .58919 L
.67176 .58918 L
.67269 .58918 L
.67363 .58917 L
.67456 .58916 L
Mistroke
.67549 .58915 L
.67642 .58914 L
.67735 .58913 L
.67828 .58913 L
.67921 .58912 L
.68014 .58911 L
.68107 .5891 L
.682 .58909 L
.68294 .58908 L
.68387 .58907 L
.6848 .58906 L
.68573 .58905 L
.68666 .58904 L
.68759 .58904 L
.68852 .58903 L
.68945 .58902 L
.69038 .58901 L
.69131 .589 L
.69225 .58899 L
.69318 .58898 L
.69411 .58897 L
.69504 .58896 L
.69597 .58895 L
.6969 .58894 L
.69783 .58893 L
.69876 .58892 L
.69969 .58891 L
.70062 .5889 L
.70155 .58889 L
.70249 .58888 L
.70342 .58887 L
.70435 .58886 L
.70528 .58885 L
.70621 .58884 L
.70714 .58883 L
.70807 .58882 L
.709 .58881 L
.70993 .5888 L
.71086 .58879 L
.7118 .58878 L
.71273 .58877 L
.71366 .58876 L
.71459 .58875 L
.71552 .58873 L
.71645 .58872 L
.71738 .58871 L
.71831 .5887 L
.71924 .58869 L
.72017 .58868 L
.72111 .58867 L
Mistroke
.72204 .58866 L
.72297 .58864 L
.7239 .58863 L
.72483 .58862 L
.72576 .58861 L
.72669 .5886 L
.72762 .58859 L
.72855 .58858 L
.72948 .58855 L
.73041 .58854 L
.73135 .58853 L
.73228 .58852 L
.73321 .5885 L
.73414 .58849 L
.73507 .58848 L
.736 .58847 L
.73693 .58846 L
.73786 .58844 L
.73879 .58843 L
.73972 .58842 L
.74066 .58841 L
.74159 .58839 L
.74252 .58838 L
.74345 .58837 L
.74438 .58836 L
.74531 .58834 L
.74624 .58833 L
.74717 .58832 L
.7481 .5883 L
.74903 .58829 L
.74997 .58828 L
.7509 .58827 L
.75183 .58825 L
.75276 .58824 L
.75369 .58823 L
.75462 .58821 L
.75555 .5882 L
.75648 .58819 L
.75741 .58817 L
.75834 .58816 L
.75927 .58814 L
.76021 .58813 L
.76114 .58812 L
.76207 .5881 L
.763 .58809 L
.76393 .58808 L
.76486 .58806 L
.76579 .58805 L
.76672 .58803 L
.76765 .58802 L
Mistroke
.76858 .588 L
.76952 .58799 L
.77045 .58797 L
.77138 .58796 L
.77231 .58795 L
.77324 .58793 L
.77417 .58792 L
.7751 .5879 L
.77603 .58789 L
.77696 .58787 L
.77789 .58786 L
.77883 .58784 L
.77976 .58783 L
.78069 .58781 L
.78162 .5878 L
.78255 .58778 L
.78348 .58777 L
.78441 .58775 L
.78534 .58773 L
.78627 .58772 L
.7872 .5877 L
.78813 .58769 L
.78907 .58767 L
.79 .58766 L
.79093 .58764 L
.79186 .58762 L
.79279 .58761 L
.79372 .58759 L
.79465 .58758 L
.79558 .58756 L
.79651 .58754 L
.79744 .58753 L
.79838 .58751 L
.79931 .58749 L
.80024 .58748 L
.80117 .58746 L
.8021 .58744 L
.80303 .58743 L
.80396 .58741 L
.80489 .58739 L
.80582 .58738 L
.80675 .58736 L
.80769 .58734 L
.80862 .58732 L
.80955 .58731 L
.81048 .58729 L
.81141 .58727 L
.81234 .58725 L
.81327 .58724 L
.8142 .58722 L
Mistroke
.81513 .5872 L
.81606 .58718 L
.81699 .58716 L
.81793 .58715 L
.81886 .58713 L
.81979 .58711 L
.82072 .58709 L
.82165 .58707 L
.82258 .58705 L
.82351 .58704 L
.82444 .58702 L
.82537 .587 L
.8263 .58698 L
.82724 .58696 L
.82817 .58694 L
.8291 .58694 L
.83003 .58692 L
.83096 .5869 L
.83189 .58688 L
.83282 .58686 L
.83375 .58684 L
.83468 .58682 L
.83561 .5868 L
.83655 .58678 L
.83748 .58676 L
.83841 .58674 L
.83934 .58672 L
.84027 .5867 L
.8412 .58668 L
.84213 .58666 L
.84306 .58664 L
.84399 .58662 L
.84492 .5866 L
.84585 .58658 L
.84679 .58656 L
.84772 .58654 L
.84865 .58652 L
.84958 .5865 L
.85051 .58648 L
.85144 .58646 L
.85237 .58644 L
.8533 .58641 L
.85423 .58639 L
.85516 .58637 L
.8561 .58635 L
.85703 .58633 L
.85796 .58631 L
.85889 .58629 L
.85982 .58627 L
.86075 .58624 L
Mistroke
.86168 .58622 L
.86261 .5862 L
.86354 .58618 L
.86447 .58616 L
.86541 .58613 L
.86634 .58611 L
.86727 .58609 L
.8682 .58607 L
.86913 .58604 L
.87006 .58602 L
.87099 .586 L
.87192 .58598 L
.87285 .58595 L
.87378 .58593 L
.87471 .58591 L
.87565 .58588 L
.87658 .58586 L
.87751 .58584 L
.87844 .58582 L
.87937 .58579 L
.8803 .58577 L
.88123 .58574 L
.88216 .58571 L
.88309 .58569 L
.88402 .58567 L
.88496 .58564 L
.88589 .58562 L
.88682 .5856 L
.88775 .58557 L
.88868 .58555 L
.88961 .58553 L
.89054 .5855 L
.89147 .58548 L
.8924 .58545 L
.89333 .58543 L
.89427 .5854 L
.8952 .58538 L
.89613 .58535 L
.89706 .58533 L
.89799 .5853 L
.89892 .58528 L
.89985 .58525 L
.90078 .58522 L
.90171 .5852 L
.90264 .58517 L
.90357 .58515 L
.90451 .58513 L
.90544 .5851 L
.90637 .58508 L
.9073 .58504 L
Mistroke
.90823 .58502 L
.90916 .58499 L
.91009 .58497 L
.91102 .58494 L
.91195 .58491 L
.91288 .58489 L
.91382 .58486 L
.91475 .58483 L
.91568 .58481 L
.91661 .58478 L
.91754 .58475 L
.91847 .58472 L
.9194 .5847 L
.92033 .58467 L
.92126 .58464 L
.92219 .58461 L
.92313 .58458 L
.92406 .58456 L
.92499 .58453 L
.92592 .5845 L
.92685 .58448 L
.92778 .58445 L
.92871 .58441 L
.92964 .58439 L
.93057 .58436 L
.9315 .58433 L
.93243 .5843 L
.93337 .58427 L
.9343 .58424 L
.93523 .58421 L
.93616 .58418 L
.93709 .58416 L
.93802 .58413 L
.93895 .5841 L
.93988 .58407 L
.94081 .58404 L
.94174 .58401 L
.94268 .58397 L
.94361 .58394 L
.94454 .58391 L
.94547 .58388 L
.9464 .58385 L
.94733 .58382 L
.94826 .58379 L
.94919 .58376 L
.95012 .58373 L
.95105 .5837 L
.95199 .58367 L
.95292 .58364 L
.95385 .58361 L
Mistroke
.95478 .58357 L
.95571 .58354 L
.95664 .58351 L
.95757 .58348 L
.9585 .58344 L
.95943 .58341 L
.96036 .58339 L
.96129 .58335 L
.96223 .58332 L
.96316 .58328 L
.96409 .58325 L
.96502 .58322 L
.96595 .58319 L
.96688 .58315 L
.96781 .58312 L
.96874 .58309 L
.96967 .58305 L
.9706 .58302 L
.97154 .58299 L
.97247 .58295 L
.9734 .58292 L
.97433 .58287 L
.97526 .58225 L
.97619 .49794 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[75]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:Oooool3o`0000?ooooo0_l00004ooooo`;o00009_ooool5o`0000?ooooo0_l00004oooo
o`;o0000;?ooool2o`0002cooooo1Ol00003ooooo`;o00001?ooool2o`0002Sooooo0ol00003oooo
o`;o00001?ooool2o`0001?ooooo000Zooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002[ooooo00Co0000oooooooo
oooo0000;?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0@ooooo`008Oooool5o`000003ooooool0003o000000?o
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001oooooo1Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Zooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0002Gooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004_ooool002Oooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Sooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0:?oo
ool01?l0003oooooooooool0000^ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001;ooooo000Xooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Uooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002[ooooo00Co0000oooooooooooo0000:oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Vooooo`03o`000?oooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Booooo`00:Ooo
ool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Uooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002[ooooo00Co0000oooooooooooo0000:oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Wooooo`;o00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001;ooooo000Zooooo`03o`000?oo
oooooooo00;ooooo0_l00004ooooo`;o00009oooool3o`0000Cooooo0_l00004ooooo`;o0000;?oo
ool2o`0002gooooo0ol00004ooooo`;o00001?ooool2o`0002Wooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo0_l0000Cooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`007_oooooho`0000[ooooo000Nooooo`03o`000?oooooo000000cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`00
5oooool2o`0000Gooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo00Sooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Fooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo00Sooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo0_l0001jooooo`03o`00
0?oooooooooo07Oooooo0_l0000:ooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`005_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`08ooooo`005oooool2o`0000Gooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00So
oooo000Nooooo`;o0000N_ooool00ol0003oooooooooo`1gooooo`;o00002_ooool001kooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0007[ooooo00?o0000ooooooooool0Mooo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo07Wooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Noooo
o`;o0000N_ooool00ol0003oooooooooo`1gooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo00Sooooo000;ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000:oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000N_ooool00ol0003ooooooooo
o`1gooooo`;o00002_ooool000[ooooo00Co0000oooooooooooo00002_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0
2?ooool000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00So
oooo000;ooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool0NOooool00ol0003ooooo
ooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool001kooooo0_l0001joooo
o`03o`000?oooooooooo07Oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`1iooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`08ooooo`007_ooool2o`0007[ooooo00?o0000ooooooooool0Moooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hoooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000N_ooool0
0ol0003oooooooooo`1gooooo`;o00002_ooool001kooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000;
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007
ooooo`Go00001?ooool2o`0007[ooooo00?o0000ooooooooool0Moooool2o`0000[ooooo000:oooo
o`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool0
0009ooooo`;o00001Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool02?ooool000_ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool02?ooool001kooooo0_l0001jooooo`03o`000?oooooooooo07Oooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07So
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0NOooool00ol0003ooooo
ooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0007[ooooo00?o0000
ooooooooool0Moooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1iooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo
00Sooooo000Nooooo`;o0000N_ooool00ol0003oooooooooo`1gooooo`;o00002_ooool001kooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool02?ooool000_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005oooo
o`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08oooo
o`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool0
00[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000:
ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`;o0000N_ooool00ol0003ooooooooo
o`1gooooo`;o00002_ooool000[ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000;
ooooo`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1h
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1iooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000N_oo
ool00ol0003oooooooooo`1gooooo`;o00002_ooool001kooooo00?o0000ooooooooool0NOooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool02?ooool001kooooo0_l0001jooooo`03o`000?oooooooooo07Oooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
oooo07Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0007[ooooo
00?o0000ooooooooool0Moooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1iooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00008
ooooo`?o00001Oooool2o`0007[ooooo00?o0000ooooooooool0Moooool2o`0000[ooooo000:oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`002_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool000_ooooo0_l0
0009ooooo`?o00001Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1h
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?oo`00oooo
ooooool0Loooool00ol0003oooooooooo`1booooo`03ool00?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1cooooo`03
o`000?oooooooooo07;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0000Cooooo00?oo`00ooooooooool0Loooool00ol0003oooooooooo`1booooo`03ool0
0?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03ool00?oo
oooooooo07?ooooo00?o0000ooooooooool0L_ooool00ooo003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0Loooool0
0ol0003oooooooooo`1booooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1cooooo`03o`000?oooooooooo
07;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo07?ooooo00?o0000ooooooooool0L_ooool00ooo003o
ooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo
00?oo`00ooooooooool0Loooool00ol0003oooooooooo`1booooo`03ool00?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ooo003ooooooooo
o`1cooooo`03o`000?oooooooooo07;ooooo00?oo`00ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`007_ooool2o`0000Cooooo00?oo`00ooooooooool0Loooool00ol0003oooooooooo`1b
ooooo`03ool00?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo07?ooooo00?o0000ooooooooool0L_ooool00ooo003oooooooooo`03oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
ool0Loooool00ol0003oooooooooo`1booooo`03ool00?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1cooooo`03o`00
0?oooooooooo07;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo07?ooooo00?o0000ooooooooool0L_oo
ool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool0Loooool00ol0003oooooooooo`1booooo`03ool00?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ooo
003oooooooooo`1cooooo`03o`000?oooooooooo07;ooooo00?oo`00ooooooooool00oooool00ol0
003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?oo`00ooooooooool0Loooool00ol0003o
ooooooooo`1booooo`03ool00?oooooooooo00;ooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`03ool00?oooooooooo07?ooooo00?o0000ooooooooool0L_ooool00ooo003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o
o`00ooooooooool0Loooool00ol0003oooooooooo`1booooo`03ool00?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1c
ooooo`03o`000?oooooooooo07;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`08
ooooo`005_ooool3o`0000Gooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1coooo
o`03o`000?oooooooooo07;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`08oooo
o`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo6ooo001Kooooo`03
o`000?oooooooooo05Sooooo6ooo0005ooooo`03o`000?oooooooooo00Sooooo000Gooooo`03o`00
0?oooooooooo00Cooooo0_l0000NoooookSoo`007_ooool2o`0000[ooooo000Gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo00Sooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0NOooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo000Fooooo`;o00001_ooool00ol0
003oooooooooo`1iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02?ooool001Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07So
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0NOooool00ol0003ooooo
ooooo`1hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo000000cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`;o00002_ooool001kooooon?l0000:
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00AOooool2o`000005ooooool0003o0000o`000?ooool00ol00003ooooo`Co00000oooool2
o`000003ooooool0003o000000Co00000_ooool4o`0000?ooooo0_l00002ooooo`Go00000_ooool3
o`0000;ooooo0ol000000ooooooo0000o`000007ooooo`?o00000_ooool3o`0000Cooooo1?l00000
1Ooooooo0000o`000?l0003ooooo00Ko00000_ooool5o`0000;ooooo0ol00002ooooo`?o00002Ooo
ool3o`0000Gooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o0000
1?ooool2o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o000003?ooooo
0015ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo0000=?ooool004Gooooo00Oo0000ooooooooooooooooo`000?oooooo
000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000004ooooo`?o00000oooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`?o00000oooool01?l0
003oooooooooool00002ooooo`?o00001?ooool01?l0003oooooooooooooool5o`0000;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo
00Ko0000oooooooooooo0000ooooool00006ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0<_oo
ool004Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool00000
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooo
oooo0000ooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02o`0000[ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0<_ooool004Gooooo00Go
0000ooooool0003oooooo`000002ooooo`?o00000oooool3o`0000;ooooo0_l000000ooooooo0000
o`000003ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`Co00000_ooool3o`0000Cooooo
0ol00002ooooo`Co00002?ooool01_l0003oooooo`000?oooooo0000ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000?ooooo1?l00003ooooo`Co00000_ooool4o`0000;ooooo0ol00002oooo
o`;o000000?oooooo`000?l000002?ooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`00
0?l0003ooooo1?l00003ooooo`?o00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000_ooool4
o`0003Gooooo0015ooooo`;o000000?oooooo`000?l000002_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool01Ol0003oooooo`000?oooooo
000001_ooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0000Dooooo`03o`000?oo
oooooooo04Oooooo0015ooooo`04o`000?ooooooooooooooo`;o00002?ooool2o`0000Sooooo0ol0
000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool5o`0001cooooo0_l0
000Cooooo`Go00005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-568.761, -0.137062, \
3.69093, 0.00720095}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] 0.49966958432041564`\), 
        ",", \(BackFocalLength \[Rule] 93.35095557506479`\), 
        ",", \(BackFocalPoint \[Rule] {153.3509555750648`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] 0.9069647812376369`\), 
        ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] 0\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {50.`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.583004929987583`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {53.41699507001242`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 1\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 1, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FindPupils \[Rule] Automatic\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 99.93396050505237`\), 
        ",", \(FrequencyCutoff \[Rule] 434.4159863212668`\), 
        ",", \(FrontFocalLength \[Rule] 99.93396050505234`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-49.93396050505234`\), 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {148.87046813964844`, 0, 0}\), 
        ",", \(ImageSampleSize \[Rule] 0.001150970534565529`\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[100, 50, 10], 50.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[Screen[50], {x, 150.`}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(IntensityTransform \[Rule] False\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.9341264481391712`, 
              6.583004929987581`}, {\(-0.010006608313591684`\), 
              0.9999999999999998`}}\), ",", 
        RowBox[{"ModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-434.84063537925437`\), 
                  433.99133726327926`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(NormalizePlot \[Rule] True\), 
        ",", \(NumberOfPoints \[Rule] 1024\), 
        ",", \(NumberOfRays \[Rule] 2048\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(LineOfRays[45, NumberOfRays \[Rule] 11]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 58.62341819665073`\), ",", 
        RowBox[{"OpticalLengthFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-22.67402161424078`\), 
                  22.67402161424078`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{\(-22.67402161424078`\), 
                  22.67402161424078`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {58.62341819665073`, 
            58.6726114660934`}\), ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadPhaseFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"ModulationTransferFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PaddingFactor \[Rule] Automatic\), 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
        RowBox[{"PerfectModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-434.84063537925437`\), 
                  433.99133726327926`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPhaseTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-434.84063537925437`\), 
                  433.99133726327926`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.5881459431629854`\), 
                  0.5892969136975509`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPointSpreadPhaseFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.5881459431629854`\), 
                  0.5892969136975509`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PhaseTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-434.84063537925437`\), 
                  433.99133726327926`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] True\), 
        ",", \(PlotPoints \[Rule] 64\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.5881459431629854`\), 
                  0.5892969136975509`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PointSpreadPhaseFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.5881459431629854`\), 
                  0.5892969136975509`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{50.00000000000003`, 0, 
              0}, {53.41699507001243`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 3.4169950700124048`\), 
        ",", \(RayBoundary \[Rule] {\(-22.67402161424078`\), 
            22.67402161424078`}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {ModulationTransferFunction, 
            PointSpreadFunction, OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] True\), 
        ",", \(ShowPerfectCase \[Rule] True\), 
        ",", \(SignalPlotCutoff \[Rule] 0.01`\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 2190\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.009154107043392394`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{0.033531699915919685`, 
              98.25958992578354`}, {\(-0.010006608313591682`\), 
              0.49966958432041564`}}\), 
        ",", \(TransverseMagnification \[Rule] 0.033531699915919685`\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-22.758587422315337`\), 
                  22.755565854622198`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[75]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ModulationTransferFunction[sys3D, FindImagePoint->True, FocalFraction->0, \
NumberOfPoints->128]//Timing\
\>", "Input",
  CellLabel->"In[76]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0563124 -1.06544 5.06363 [
[.07766 -0.0125 -12 -9 ]
[.07766 -0.0125 12 0 ]
[.21844 -0.0125 -6 -9 ]
[.21844 -0.0125 6 0 ]
[.35922 -0.0125 -12 -9 ]
[.35922 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64078 -0.0125 -9 -9 ]
[.64078 -0.0125 9 0 ]
[.78156 -0.0125 -3 -9 ]
[.78156 -0.0125 3 0 ]
[.92234 -0.0125 -9 -9 ]
[.92234 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04855 -24 -4.5 ]
[-0.0125 .04855 0 4.5 ]
[-0.0125 .14983 -24 -4.5 ]
[-0.0125 .14983 0 4.5 ]
[-0.0125 .2511 -24 -4.5 ]
[-0.0125 .2511 0 4.5 ]
[-0.0125 .35237 -24 -4.5 ]
[-0.0125 .35237 0 4.5 ]
[-0.0125 .45364 -18 -4.5 ]
[-0.0125 .45364 0 4.5 ]
[-0.0125 .55492 -24 -4.5 ]
[-0.0125 .55492 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -60 0 ]
[.5 .63053 60 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07766 0 m
.07766 .00625 L
s
[(-7.5)] .07766 -0.0125 0 1 Mshowa
.21844 0 m
.21844 .00625 L
s
[(-5)] .21844 -0.0125 0 1 Mshowa
.35922 0 m
.35922 .00625 L
s
[(-2.5)] .35922 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64078 0 m
.64078 .00625 L
s
[(2.5)] .64078 -0.0125 0 1 Mshowa
.78156 0 m
.78156 .00625 L
s
[(5)] .78156 -0.0125 0 1 Mshowa
.92234 0 m
.92234 .00625 L
s
[(7.5)] .92234 -0.0125 0 1 Mshowa
.125 Mabswid
.10581 0 m
.10581 .00375 L
s
.13397 0 m
.13397 .00375 L
s
.16213 0 m
.16213 .00375 L
s
.19028 0 m
.19028 .00375 L
s
.24659 0 m
.24659 .00375 L
s
.27475 0 m
.27475 .00375 L
s
.30291 0 m
.30291 .00375 L
s
.33106 0 m
.33106 .00375 L
s
.38738 0 m
.38738 .00375 L
s
.41553 0 m
.41553 .00375 L
s
.44369 0 m
.44369 .00375 L
s
.47184 0 m
.47184 .00375 L
s
.52816 0 m
.52816 .00375 L
s
.55631 0 m
.55631 .00375 L
s
.58447 0 m
.58447 .00375 L
s
.61262 0 m
.61262 .00375 L
s
.66894 0 m
.66894 .00375 L
s
.69709 0 m
.69709 .00375 L
s
.72525 0 m
.72525 .00375 L
s
.75341 0 m
.75341 .00375 L
s
.80972 0 m
.80972 .00375 L
s
.83787 0 m
.83787 .00375 L
s
.86603 0 m
.86603 .00375 L
s
.89419 0 m
.89419 .00375 L
s
.0495 0 m
.0495 .00375 L
s
.02134 0 m
.02134 .00375 L
s
.9505 0 m
.9505 .00375 L
s
.97866 0 m
.97866 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04855 m
.00625 .04855 L
s
[(0.22)] -0.0125 .04855 1 0 Mshowa
0 .14983 m
.00625 .14983 L
s
[(0.24)] -0.0125 .14983 1 0 Mshowa
0 .2511 m
.00625 .2511 L
s
[(0.26)] -0.0125 .2511 1 0 Mshowa
0 .35237 m
.00625 .35237 L
s
[(0.28)] -0.0125 .35237 1 0 Mshowa
0 .45364 m
.00625 .45364 L
s
[(0.3)] -0.0125 .45364 1 0 Mshowa
0 .55492 m
.00625 .55492 L
s
[(0.32)] -0.0125 .55492 1 0 Mshowa
.125 Mabswid
0 .07387 m
.00375 .07387 L
s
0 .09919 m
.00375 .09919 L
s
0 .12451 m
.00375 .12451 L
s
0 .17514 m
.00375 .17514 L
s
0 .20046 m
.00375 .20046 L
s
0 .22578 m
.00375 .22578 L
s
0 .27642 m
.00375 .27642 L
s
0 .30174 m
.00375 .30174 L
s
0 .32705 m
.00375 .32705 L
s
0 .37769 m
.00375 .37769 L
s
0 .40301 m
.00375 .40301 L
s
0 .42833 m
.00375 .42833 L
s
0 .47896 m
.00375 .47896 L
s
0 .50428 m
.00375 .50428 L
s
0 .5296 m
.00375 .5296 L
s
0 .02324 m
.00375 .02324 L
s
0 .58024 m
.00375 .58024 L
s
0 .60555 m
.00375 .60555 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07766 .61178 m
.07766 .61803 L
s
.21844 .61178 m
.21844 .61803 L
s
.35922 .61178 m
.35922 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64078 .61178 m
.64078 .61803 L
s
.78156 .61178 m
.78156 .61803 L
s
.92234 .61178 m
.92234 .61803 L
s
.125 Mabswid
.10581 .61428 m
.10581 .61803 L
s
.13397 .61428 m
.13397 .61803 L
s
.16213 .61428 m
.16213 .61803 L
s
.19028 .61428 m
.19028 .61803 L
s
.24659 .61428 m
.24659 .61803 L
s
.27475 .61428 m
.27475 .61803 L
s
.30291 .61428 m
.30291 .61803 L
s
.33106 .61428 m
.33106 .61803 L
s
.38738 .61428 m
.38738 .61803 L
s
.41553 .61428 m
.41553 .61803 L
s
.44369 .61428 m
.44369 .61803 L
s
.47184 .61428 m
.47184 .61803 L
s
.52816 .61428 m
.52816 .61803 L
s
.55631 .61428 m
.55631 .61803 L
s
.58447 .61428 m
.58447 .61803 L
s
.61262 .61428 m
.61262 .61803 L
s
.66894 .61428 m
.66894 .61803 L
s
.69709 .61428 m
.69709 .61803 L
s
.72525 .61428 m
.72525 .61803 L
s
.75341 .61428 m
.75341 .61803 L
s
.80972 .61428 m
.80972 .61803 L
s
.83787 .61428 m
.83787 .61803 L
s
.86603 .61428 m
.86603 .61803 L
s
.89419 .61428 m
.89419 .61803 L
s
.0495 .61428 m
.0495 .61803 L
s
.02134 .61428 m
.02134 .61803 L
s
.9505 .61428 m
.9505 .61803 L
s
.97866 .61428 m
.97866 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04855 m
1 .04855 L
s
.99375 .14983 m
1 .14983 L
s
.99375 .2511 m
1 .2511 L
s
.99375 .35237 m
1 .35237 L
s
.99375 .45364 m
1 .45364 L
s
.99375 .55492 m
1 .55492 L
s
.125 Mabswid
.99625 .07387 m
1 .07387 L
s
.99625 .09919 m
1 .09919 L
s
.99625 .12451 m
1 .12451 L
s
.99625 .17514 m
1 .17514 L
s
.99625 .20046 m
1 .20046 L
s
.99625 .22578 m
1 .22578 L
s
.99625 .27642 m
1 .27642 L
s
.99625 .30174 m
1 .30174 L
s
.99625 .32705 m
1 .32705 L
s
.99625 .37769 m
1 .37769 L
s
.99625 .40301 m
1 .40301 L
s
.99625 .42833 m
1 .42833 L
s
.99625 .47896 m
1 .47896 L
s
.99625 .50428 m
1 .50428 L
s
.99625 .5296 m
1 .5296 L
s
.99625 .02324 m
1 .02324 L
s
.99625 .58024 m
1 .58024 L
s
.99625 .60555 m
1 .60555 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Wave Front Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.03853 .23222 L
.04619 .32714 L
.05458 .40784 L
.06247 .46923 L
.06965 .50997 L
.07139 .51981 L
.07323 .53025 L
.07369 .53287 L
.07419 .53517 L
.07447 .53598 L
.07474 .53672 L
.07525 .53817 L
.07711 .54346 L
.08121 .55509 L
.08509 .56609 L
.08689 .5712 L
.08859 .57602 L
.08904 .57731 L
.08953 .57817 L
.08978 .57847 L
.09006 .5788 L
.09054 .57938 L
.09232 .58148 L
.09641 .58633 L
.10021 .59083 L
.10204 .59299 L
.10301 .59413 L
.10353 .59476 L
.10403 .59534 L
.10446 .59583 L
.10492 .59602 L
.10591 .59641 L
.10765 .59711 L
.11181 .59879 L
.11561 .60033 L
.11738 .60104 L
.11834 .60143 L
.11926 .60179 L
.11951 .6019 L
.11978 .60196 L
.12007 .60199 L
.12034 .60201 L
.12133 .6021 L
.12325 .60227 L
.12712 .60261 L
.13129 .60297 L
.13328 .60315 L
.13376 .60319 L
.13427 .60324 L
Mistroke
.13475 .60328 L
.13518 .60328 L
.1356 .60328 L
.13606 .60328 L
.13689 .60327 L
.13874 .60325 L
.14572 .60319 L
.14747 .60317 L
.14844 .60316 L
.14935 .60315 L
.1496 .60315 L
.14987 .60315 L
.15016 .60314 L
.15043 .60313 L
.15141 .60309 L
.15333 .60302 L
.16136 .60269 L
.17576 .60211 L
.1911 .60142 L
.20585 .60084 L
.22155 .60022 L
.23666 .59969 L
.2512 .59918 L
.26667 .5987 L
.28156 .59823 L
.29739 .59781 L
.31264 .59739 L
.32732 .59706 L
.34292 .5967 L
.35796 .59643 L
.37241 .59615 L
.3878 .59592 L
.40261 .5957 L
.41835 .59553 L
.42217 .5955 L
.42309 .59549 L
.42358 .59549 L
.42385 .59549 L
.4241 .59549 L
.42437 .59548 L
.42467 .59548 L
.42519 .59547 L
.42623 .59546 L
.43352 .59536 L
.43526 .59534 L
.43714 .59531 L
.43801 .5953 L
.43848 .5953 L
.43892 .59529 L
.4393 .59529 L
Mistroke
.43971 .59529 L
.44057 .59528 L
.44452 .59527 L
.44811 .59526 L
.45196 .59524 L
.45302 .59524 L
.45359 .59524 L
.45388 .59524 L
.45414 .59524 L
.45439 .59524 L
.45465 .59523 L
.4552 .59523 L
.45616 .59522 L
.46382 .59515 L
.46743 .59511 L
.46847 .5951 L
.46899 .5951 L
.46946 .59509 L
.46989 .59509 L
.47034 .59509 L
.47131 .59509 L
.47829 .5951 L
.48186 .5951 L
.48284 .5951 L
.48387 .5951 L
.4843 .5951 L
.48475 .5951 L
.48525 .5951 L
.48571 .5951 L
.49268 .59506 L
.49659 .59504 L
.49766 .59503 L
.49879 .59502 L
.49925 .59502 L
.49976 .59502 L
.50004 .59502 L
.5003 .59502 L
.50082 .59502 L
.5085 .59506 L
.51201 .59507 L
.51294 .59508 L
.51394 .59508 L
.5144 .59508 L
.51488 .59508 L
.5153 .59509 L
.51575 .59508 L
.5179 .59508 L
.51985 .59508 L
.52365 .59507 L
.52566 .59507 L
Mistroke
.52755 .59506 L
.52926 .59506 L
.52972 .59506 L
.53022 .59506 L
.53064 .59506 L
.5311 .59506 L
.53908 .59513 L
.54287 .59516 L
.54377 .59517 L
.54473 .59518 L
.5452 .59518 L
.54564 .59519 L
.54604 .59519 L
.54647 .59519 L
.54845 .59519 L
.55062 .5952 L
.55442 .5952 L
.55804 .59521 L
.55903 .59521 L
.55958 .59521 L
.56009 .59522 L
.56058 .59522 L
.56085 .59522 L
.5611 .59522 L
.56201 .59523 L
.57004 .59533 L
.57346 .59537 L
.57525 .5954 L
.57569 .5954 L
.57616 .59541 L
.57642 .59541 L
.57667 .59541 L
.57714 .59541 L
.57925 .59542 L
.58119 .59544 L
.58499 .59546 L
.58854 .59548 L
.59033 .59549 L
.59082 .59549 L
.59109 .59549 L
.59134 .59549 L
.59184 .5955 L
.5923 .59551 L
.59642 .59558 L
.60022 .59564 L
.61478 .59582 L
.63028 .59607 L
.6452 .59635 L
.66106 .59665 L
.67634 .59698 L
Mistroke
.69104 .59732 L
.70667 .59771 L
.72173 .59812 L
.73621 .59855 L
.75163 .59903 L
.76647 .59953 L
.78224 .60009 L
.79743 .60067 L
.81205 .60125 L
.8276 .60191 L
.84257 .60254 L
.85697 .60306 L
.86057 .60318 L
.86253 .60324 L
.86348 .60327 L
.86435 .6033 L
.86485 .60331 L
.86531 .60332 L
.8658 .60331 L
.86633 .6033 L
.8685 .60325 L
.8723 .60317 L
.87622 .60308 L
.87814 .60304 L
.87897 .60302 L
.87988 .60301 L
.88038 .60299 L
.88083 .6029 L
.88173 .60273 L
.88371 .60235 L
.8879 .60153 L
.89132 .60087 L
.89311 .60052 L
.89409 .60033 L
.895 .60016 L
.89549 .60006 L
.89576 .59992 L
.89601 .59975 L
.89711 .59899 L
.89905 .59767 L
.90285 .59508 L
.90639 .59266 L
.90833 .59133 L
.90927 .59068 L
.91014 .59009 L
.91063 .58976 L
.91109 .5891 L
.9121 .58726 L
.91426 .58335 L
.91806 .57646 L
Mistroke
.92171 .56983 L
.92372 .5662 L
.9247 .56441 L
.92513 .56363 L
.92561 .56277 L
.92605 .56185 L
.92647 .56019 L
.92737 .55658 L
.92928 .54896 L
.93261 .53568 L
.94744 .45539 L
.95131 .42676 L
.95336 .41165 L
.95553 .39561 L
.95742 .37741 L
.95951 .35317 L
.9632 .31043 L
.97619 .14203 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[76]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Joooo
o`?o00006Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo0_l0000Ioooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006_ooool3o`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00005?ooool0033ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00000I
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`00
0?ooooooooooo`0001Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Sooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Cooooo`00:?ooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003oooooooooo`0@ooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo000aooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04Oooool003;ooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo1?l0000Iooooo`05o`000?ooooooooooooooool000001oooool4o`0001Kooooo
00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Ioooo
o`Co00007Oooool00ol0003oooooooooo`05ooooo`Co00005?ooool002kooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
000Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Go
oooo000^ooooo`Go00001oooool5o`0001Sooooo1Ol0000Iooooo`?o00002?ooool5o`0001Kooooo
0_l0000Jooooo`?o00002?ooool5o`0001Sooooo1Ol0000Hooooo`Go00001oooool5o`0001?ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000QooooooSo0000
1oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001?ooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo07Sooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol000000ooooooo0000o`000003o`00
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Ooo
ool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool0N?ooool2o`0000Oooooo0007ooooo`04o`000?oooooo
ooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00007ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool01Oooool000Sooooo0_l00009ooooo`?o00000oooool3o`0000Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
1Oooool0027ooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0N?oo
ool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001Oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo07Sooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool2o`00
00Gooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1hooooo`;o00001oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool01Oooool000Sooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00000ooo
ool3o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00009ooooo`04o`00
0?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo0007ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000000oooool2o`0000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool0027ooooo0_l00006ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00001oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001ooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool00ooo
ool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`008Oooool2o`0000Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`002?oo
ool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00009oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`04o`0000Gooooo0_l00007ooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`04ooooo`;o00001oooool000Oooooo00Co0000oooo
oooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Wooooo0ol00004ooooo`;o0000
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`008Oooool2o`0000Sooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`008Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo0_l00008ooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05ooooo`;o
00001oooool0027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo000Qooooo`;o00002Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool01Oooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0008ooooo`;o
00001?ooool01?l0003oooooooooooooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool0000:ooooo`04o`00
0?ooooooooooooooo`?o00001Oooool2o`0000[ooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`001oooool01?l0003ooooo
ooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`001oooool01?l0
003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`002?oo
ool2o`0000Wooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`008Oooool2o`0000[o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Ko
oooo0_l00007ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool0027ooooo0_l0000;ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`07ooooo`;o00001oooool0027ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo06_ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01Oooool0027ooooo0_l0000<ooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`08ooooo`;o00001oooool0027ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool000gooooo
00Co0000oooooooooooo00002Oooool2o`0000Gooooo0_l0000<ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`09ooooo`;o00001oooool000gooooo
00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05oooo
o`003_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0Jooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00003Oooool0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02_ooool2
o`0000Oooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05
ooooo`008Oooool2o`0000oooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo00_ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1Oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`008Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`05ooooo`008Oooool2o`00013ooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo00gooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0I_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00002oooo
o`Go00001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`001oooool0
1?l0003oooooooooool0000;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo
0_l00005ooooo`03o`000?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0>ooooo`;o00001oooool000Oooooo00Co
0000oooooooooooo00002oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003ooooooooo
ool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
06Kooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo0008ooooo`;o00002Oooool3o`0000?o
oooo0ol00005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo06Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00005?ooool2o`0006?ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`0@ooooo`;o00001oooool0027ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`1Rooooo`;o00005Oooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0Fooooo`?o0000:ooooom^o`0002Wooooo0_l0000Gooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Wooooo0ol0000;oooooago0000=?ooool0
0ol0003oooooooooo`0goooooa[o00003?ooool4o`0001Sooooo00?o0000ooooooooool01Oooool0
027ooooo0_l0000Looooo`co0000DOooool00ol0003oooooooooo`1Aooooo`co00006oooool2o`00
00Oooooo000Qooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`05ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`008Ooooooho`0000Oooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003Booooo`?o0000Boooool00=?ooooo00?o
0000ooooooooool0B_ooool0067ooooo00?o0000ooooool000000oooool4o`0000?ooooo00?o0000
ooooooooool00_ooool3o`0000Sooooo0ol00003ooooo`?o00001?ooool3o`0000;ooooo0ol00000
0ooooooo0000o`000002ooooo`;o00002?ooool5o`000005ooooool0003o0000o`000?ooool00_l0
0002ooooo`;o00000oooool3o`0000;ooooo0ol000000ooooooo0000o`000004o`0000;ooooo1Ol0
0003ooooo`;o00001?ooool00ol0003oooooooooo`19ooooo`00HOooool00ol0003oooooo`000002
ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Ko
oooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`19ooooo`00HOooool00ol0003oooooo`000003
ooooo`?o00000oooool00ol0003oooooo`000002ooooo`Go00002?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooo
oooo00000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000004[ooooo001Pooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool0
00002?ooool3o`0000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool00000B_ooool0063ooooo00Go0000ooooool0
003oooooo`000002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0ol00009oooo
o`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`00
00;ooooo1?l0000:ooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`0000?ooooo0ol00002
ooooo`Co00000oooool4o`000004ooooool0003o0000o`0000?ooooo1?l00002ooooo`;o000000?o
ooooo`000?l00000BOooool0063ooooo00Go0000ooooool0003oooooo`00000Jooooo`04o`000?oo
ooooooooo`0001Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0D?ooool0063ooooo1_l0000Hooooo`Go00005?oo
ool00ol0003oooooooooo`08ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0D?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.2786, 0.20075, \
0.0718464, 0.000799001}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0563124 0.603316 0.114984 [
[.07766 -0.0125 -12 -9 ]
[.07766 -0.0125 12 0 ]
[.21844 -0.0125 -6 -9 ]
[.21844 -0.0125 6 0 ]
[.35922 -0.0125 -12 -9 ]
[.35922 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64078 -0.0125 -9 -9 ]
[.64078 -0.0125 9 0 ]
[.78156 -0.0125 -3 -9 ]
[.78156 -0.0125 3 0 ]
[.92234 -0.0125 -9 -9 ]
[.92234 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0284 -12 -4.5 ]
[-0.0125 .0284 0 4.5 ]
[-0.0125 .14338 -12 -4.5 ]
[-0.0125 .14338 0 4.5 ]
[-0.0125 .25836 -12 -4.5 ]
[-0.0125 .25836 0 4.5 ]
[-0.0125 .37335 -12 -4.5 ]
[-0.0125 .37335 0 4.5 ]
[-0.0125 .48833 -12 -4.5 ]
[-0.0125 .48833 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07766 0 m
.07766 .00625 L
s
[(-7.5)] .07766 -0.0125 0 1 Mshowa
.21844 0 m
.21844 .00625 L
s
[(-5)] .21844 -0.0125 0 1 Mshowa
.35922 0 m
.35922 .00625 L
s
[(-2.5)] .35922 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64078 0 m
.64078 .00625 L
s
[(2.5)] .64078 -0.0125 0 1 Mshowa
.78156 0 m
.78156 .00625 L
s
[(5)] .78156 -0.0125 0 1 Mshowa
.92234 0 m
.92234 .00625 L
s
[(7.5)] .92234 -0.0125 0 1 Mshowa
.125 Mabswid
.10581 0 m
.10581 .00375 L
s
.13397 0 m
.13397 .00375 L
s
.16213 0 m
.16213 .00375 L
s
.19028 0 m
.19028 .00375 L
s
.24659 0 m
.24659 .00375 L
s
.27475 0 m
.27475 .00375 L
s
.30291 0 m
.30291 .00375 L
s
.33106 0 m
.33106 .00375 L
s
.38738 0 m
.38738 .00375 L
s
.41553 0 m
.41553 .00375 L
s
.44369 0 m
.44369 .00375 L
s
.47184 0 m
.47184 .00375 L
s
.52816 0 m
.52816 .00375 L
s
.55631 0 m
.55631 .00375 L
s
.58447 0 m
.58447 .00375 L
s
.61262 0 m
.61262 .00375 L
s
.66894 0 m
.66894 .00375 L
s
.69709 0 m
.69709 .00375 L
s
.72525 0 m
.72525 .00375 L
s
.75341 0 m
.75341 .00375 L
s
.80972 0 m
.80972 .00375 L
s
.83787 0 m
.83787 .00375 L
s
.86603 0 m
.86603 .00375 L
s
.89419 0 m
.89419 .00375 L
s
.0495 0 m
.0495 .00375 L
s
.02134 0 m
.02134 .00375 L
s
.9505 0 m
.9505 .00375 L
s
.97866 0 m
.97866 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0284 m
.00625 .0284 L
s
[(-5)] -0.0125 .0284 1 0 Mshowa
0 .14338 m
.00625 .14338 L
s
[(-4)] -0.0125 .14338 1 0 Mshowa
0 .25836 m
.00625 .25836 L
s
[(-3)] -0.0125 .25836 1 0 Mshowa
0 .37335 m
.00625 .37335 L
s
[(-2)] -0.0125 .37335 1 0 Mshowa
0 .48833 m
.00625 .48833 L
s
[(-1)] -0.0125 .48833 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .05139 m
.00375 .05139 L
s
0 .07439 m
.00375 .07439 L
s
0 .09739 m
.00375 .09739 L
s
0 .12038 m
.00375 .12038 L
s
0 .16638 m
.00375 .16638 L
s
0 .18937 m
.00375 .18937 L
s
0 .21237 m
.00375 .21237 L
s
0 .23537 m
.00375 .23537 L
s
0 .28136 m
.00375 .28136 L
s
0 .30436 m
.00375 .30436 L
s
0 .32736 m
.00375 .32736 L
s
0 .35035 m
.00375 .35035 L
s
0 .39635 m
.00375 .39635 L
s
0 .41934 m
.00375 .41934 L
s
0 .44234 m
.00375 .44234 L
s
0 .46534 m
.00375 .46534 L
s
0 .51133 m
.00375 .51133 L
s
0 .53433 m
.00375 .53433 L
s
0 .55732 m
.00375 .55732 L
s
0 .58032 m
.00375 .58032 L
s
0 .0054 m
.00375 .0054 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07766 .61178 m
.07766 .61803 L
s
.21844 .61178 m
.21844 .61803 L
s
.35922 .61178 m
.35922 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64078 .61178 m
.64078 .61803 L
s
.78156 .61178 m
.78156 .61803 L
s
.92234 .61178 m
.92234 .61803 L
s
.125 Mabswid
.10581 .61428 m
.10581 .61803 L
s
.13397 .61428 m
.13397 .61803 L
s
.16213 .61428 m
.16213 .61803 L
s
.19028 .61428 m
.19028 .61803 L
s
.24659 .61428 m
.24659 .61803 L
s
.27475 .61428 m
.27475 .61803 L
s
.30291 .61428 m
.30291 .61803 L
s
.33106 .61428 m
.33106 .61803 L
s
.38738 .61428 m
.38738 .61803 L
s
.41553 .61428 m
.41553 .61803 L
s
.44369 .61428 m
.44369 .61803 L
s
.47184 .61428 m
.47184 .61803 L
s
.52816 .61428 m
.52816 .61803 L
s
.55631 .61428 m
.55631 .61803 L
s
.58447 .61428 m
.58447 .61803 L
s
.61262 .61428 m
.61262 .61803 L
s
.66894 .61428 m
.66894 .61803 L
s
.69709 .61428 m
.69709 .61803 L
s
.72525 .61428 m
.72525 .61803 L
s
.75341 .61428 m
.75341 .61803 L
s
.80972 .61428 m
.80972 .61803 L
s
.83787 .61428 m
.83787 .61803 L
s
.86603 .61428 m
.86603 .61803 L
s
.89419 .61428 m
.89419 .61803 L
s
.0495 .61428 m
.0495 .61803 L
s
.02134 .61428 m
.02134 .61803 L
s
.9505 .61428 m
.9505 .61803 L
s
.97866 .61428 m
.97866 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0284 m
1 .0284 L
s
.99375 .14338 m
1 .14338 L
s
.99375 .25836 m
1 .25836 L
s
.99375 .37335 m
1 .37335 L
s
.99375 .48833 m
1 .48833 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .05139 m
1 .05139 L
s
.99625 .07439 m
1 .07439 L
s
.99625 .09739 m
1 .09739 L
s
.99625 .12038 m
1 .12038 L
s
.99625 .16638 m
1 .16638 L
s
.99625 .18937 m
1 .18937 L
s
.99625 .21237 m
1 .21237 L
s
.99625 .23537 m
1 .23537 L
s
.99625 .28136 m
1 .28136 L
s
.99625 .30436 m
1 .30436 L
s
.99625 .32736 m
1 .32736 L
s
.99625 .35035 m
1 .35035 L
s
.99625 .39635 m
1 .39635 L
s
.99625 .41934 m
1 .41934 L
s
.99625 .44234 m
1 .44234 L
s
.99625 .46534 m
1 .46534 L
s
.99625 .51133 m
1 .51133 L
s
.99625 .53433 m
1 .53433 L
s
.99625 .55732 m
1 .55732 L
s
.99625 .58032 m
1 .58032 L
s
.99625 .0054 m
1 .0054 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.03853 .08449 L
.05458 .15328 L
.06965 .2114 L
.08415 .26178 L
.09958 .30988 L
.11444 .35118 L
.13023 .39012 L
.14544 .42318 L
.16007 .45119 L
.17564 .47725 L
.19063 .49903 L
.20504 .51718 L
.22039 .53378 L
.23516 .54736 L
.25087 .55951 L
.26599 .56923 L
.28054 .57695 L
.29603 .58365 L
.31093 .5888 L
.32678 .59309 L
.34204 .59624 L
.35672 .59853 L
.36417 .59945 L
.37234 .6003 L
.38739 .60149 L
.39482 .60193 L
.40279 .6023 L
.41088 .6026 L
.41854 .60282 L
.42613 .60298 L
.43315 .60309 L
.44026 .60317 L
.4443 .60321 L
.4481 .60324 L
.45185 .60326 L
.45579 .60327 L
.45916 .60329 L
.46284 .6033 L
.46676 .6033 L
.47031 .60331 L
.47228 .60331 L
.47442 .60331 L
.47642 .60332 L
.47829 .60332 L
.48003 .60332 L
.4819 .60332 L
.48296 .60332 L
.48397 .60332 L
.48587 .60332 L
Mistroke
.48683 .60332 L
.48786 .60332 L
.48874 .60332 L
.4897 .60332 L
.49083 .60332 L
.4919 .60332 L
.49293 .60332 L
.49342 .60332 L
.49388 .60332 L
.49433 .60332 L
.49482 .60332 L
.49568 .60332 L
.49616 .60332 L
.49668 .60332 L
.49712 .60332 L
.4976 .60332 L
.49805 .60332 L
.49846 .60332 L
.49891 .60332 L
.49939 .60332 L
.49981 .60332 L
.50019 .60332 L
.50062 .60332 L
.50107 .60332 L
.50133 .60332 L
.5016 .60332 L
.50209 .60332 L
.50262 .60332 L
.50319 .60332 L
.50369 .60332 L
.50423 .60332 L
.5052 .60332 L
.50568 .60332 L
.5062 .60332 L
.50716 .60332 L
.50809 .60332 L
.50895 .60332 L
.50986 .60332 L
.51071 .60332 L
.51161 .60332 L
.51261 .60332 L
.51428 .60332 L
.51605 .60332 L
.51801 .60332 L
.52011 .60332 L
.52209 .60332 L
.52389 .60331 L
.52573 .60331 L
.52769 .60331 L
.53119 .60331 L
Mistroke
.53496 .6033 L
.53911 .60329 L
.54298 .60328 L
.54651 .60326 L
.55059 .60324 L
.55447 .60322 L
.56202 .60315 L
.56902 .60306 L
.57685 .60292 L
.58394 .60275 L
.59127 .60253 L
.59921 .60222 L
.60681 .60184 L
.61484 .60134 L
.62931 .60014 L
.64472 .59833 L
.65955 .59596 L
.67531 .59259 L
.6905 .58835 L
.70511 .58321 L
.72065 .57638 L
.73562 .56828 L
.75001 .5589 L
.76533 .54695 L
.78007 .53331 L
.79575 .51624 L
.81086 .49701 L
.82538 .47565 L
.84084 .44954 L
.85572 .4208 L
.87154 .38601 L
.88678 .34798 L
.90144 .30686 L
.91703 .25785 L
.93205 .20512 L
.94649 .1489 L
.96187 .08269 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[76]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Joooo
o`?o00006Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo0_l0000Ioooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006_ooool3o`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00006_ooool002[ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00000I
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`00
0?ooooooooooo`0001Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Sooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Iooooo`008_ooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003oooooooooo`0@ooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo000[ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool05oooool002cooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo1?l0000Iooooo`05o`000?ooooooooooooooool000001oooool4o`0001Kooooo
00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Ioooo
o`Co00007Oooool00ol0003oooooooooo`05ooooo`Co00006_ooool002Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
000Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01_o
oooo000Xooooo`Go00001oooool5o`0001Sooooo1Ol0000Iooooo`?o00002?ooool5o`0001Kooooo
0_l0000Jooooo`?o00002?ooool5o`0001Sooooo1Ol0000Hooooo`Go00001oooool5o`0001Wooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000KooooooSo0000
3Oooool001_ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo
0_l0000=ooooo`006oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`004oooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;oooo
o`004_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`003?ooool5o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00_ooooo000Fooooo`03o`000?oooooooooo00;ooooo
0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`03ooooo`;o00003Oooool001;ooooo1?l00005ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02oooool001;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00_ooooo000Booooo`Go00001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02oooool001_ooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`04ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00001_ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01Oooool2o`0000gooooo000K
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`006oooool2
o`0000Sooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo
oooo00Kooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00002Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01oooool2o`0000gooooo000Koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo000Dooooo`?o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00_ooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0;ooooo`003?ooool5o`000003ooooool0003o000000?o00001?ooool2o`00
00[ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
00Wooooo0_l0000=ooooo`004_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool001?ooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o00001Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o00003?ooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02_ooool2o`0000gooooo000Kooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
01_ooooo0_l0000=ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`0<ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`1Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool001_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Sooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00_ooooo000Kooooo`;o00003oooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool03Oooool2o`0000gooooo000Kooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo06Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`1Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`006oooool2o`00017ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00oooooo
0_l0000=ooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1V
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool001?ooooo0ol00005oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool001;ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool000co
oooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0;ooooo`005?ooool2o`0000Gooooo0_l0000Cooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`0@ooooo`;o00003Oooool001Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo000B
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00_ooooo000Cooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool001_o
oooo0_l0000Eooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`0Booooo`;o00003Oooool001_ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00_ooooo000Kooooo`;o00005oooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool05?ooool2o`0000gooooo000Kooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`006oooool2o`0001Sooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Kooooo0_l0
000=ooooo`006oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`;o00006_ooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool06?ooool2o`0000gooooo000Kooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0;ooooo`004_ooool5o`0000Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0;ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02oooool000cooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`005Oooool00ol0003ooooooooo
o`03ooooo`;o00007?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool06_ooool2o`0000gooooo000Booooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo000Booooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo000C
ooooo`?o00001Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0;ooooo`006oooool2o`0001oooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01gooooo0_l0000=ooooo`006ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00_o
oooo000Kooooo`;o00008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool07oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;
ooooo`006oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo000Kooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0;ooooo`006oooool2o`0002Cooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02;ooooo0_l0000=ooooo`006oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Doooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02oooool001_ooooo0_l0000W
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0U
ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo000Cooooo`?o0000
1Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo000Dooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`003?ooool5
o`0000?ooooo00?o0000ooooooooool01?ooool2o`0002[ooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Wooooo0_l0000=ooooo`005?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool001Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_o
oooo000Cooooo`;o00001_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo
000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_ooooo000Koooo
o`;o0000<?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0;Oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool02oooool001_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0;ooooo`006oooool2o`0003Cooooo0_l00013ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0<oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0;ooooo`006oooool00ol0003oooooooooo`0gooooo`;o0000?oooool00ol0003oooooooooo`0n
ooooo`;o0000>Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00_ooooo000Kooooo`;o0000>oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0>Oooool2o`0000gooooo000Kooooo`03o`00
0?oooooooooo03_ooooo0_l0000kooooo`03o`000?oooooooooo03[ooooo0_l0000mooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03gooooo0_l0000iooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;ooooo`006oooool0
0ol0003oooooooooo`0oooooo`;o0000=oooool00ol0003oooooooooo`0gooooo`;o0000@?ooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0=Oooool2o`0004;ooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool0@_ooool2o`0003Cooooo00?o0000ooooooooool0<oooool2o`0004Co
oooo00?o0000ooooooooool02oooool001_ooooo0_l00015ooooo`;o0000<_ooool00ol0003ooooo
ooooo`0aooooo`;o0000AOooool2o`0000gooooo000Kooooo`03o`000?oooooooooo04Kooooo0ol0
000_ooooo`03o`000?oooooooooo02oooooo0_l00018ooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo04Wooooo1?l0000[ooooo`03o`000?oooooooooo02_ooooo1?l0001:
ooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`1=oooo
o`Co00009oooool00ol0003oooooooooo`0Wooooo`Co0000C_ooool00ol0003oooooooooo`0;oooo
o`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo057ooooo0ol0000Toooo
o`03o`000?oooooooooo02?ooooo1?l0001Booooo`03o`000?oooooooooo00_ooooo000Cooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0E?ooool<o`0001Sooooo00?o0000oooo
ooooool05Oooool>o`0005Kooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooo
oooo00001?ooool2o`00067ooooo<?l0001Sooooo`;o00003Oooool001?ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool02oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;oooo
o`005?ooool2o`0000Gooooon?l0000=ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00;Oooool3o`0008[ooooo00?o0000ooooooooool0:oooool3o`0001Gooooo00?o0000oooo
ooooool07Oooool002kooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool07?ooool002Sooooo0ol00003ooooo`?o0000
1?ooool2o`0000;ooooo1Ol00002ooooo`?o00000oooool4o`000003ooooool0003o000000?o0000
1oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6o`0000Kooooo1?l00002ooooo`Go0000
00?oooooo`000?l000000ol000000ooooooo0000o`000003o`0000;ooooo0ol00002ooooo`?o0000
1?ooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`0000?ooooo0ol00009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool4o`0000?ooooo00?o0000oooooooo
ool00_ooool3o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000004ooooool0003o0000oooo
o`Co00000oooool2o`0000;ooooo2_l00005ooooo`03o`000?oooooooooo01_ooooo000Wooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ool000003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01_ooooo000Wooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?o
oooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooooooool5o`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Ko
0000oooooooooooo0000ooooool00005ooooo`Go00002?ooool00ol0003oooooooooo`02ooooo`05
o`000?oooooo0000ooooool000000_ooool3o`0000?ooooo00?o0000ooooool000000_ooool5o`00
00?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000;ooooo0ol00005oooo
o`03o`000?oooooooooo01_ooooo000Wooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
000000?ooooo00Co0000oooooooooooo00001Oooool01_l0003oooooooooool0003oooooo`0000So
oooo00?o0000ooooooooool06oooool002Oooooo00Ko0000ooooooooooooooooo`000?ooool4o`00
00;ooooo1?l00002ooooo`?o00001?ooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002Oooool0
1Ol0003oooooooooool0003ooooo00?o00001?ooool4o`0000;ooooo1?l00002ooooo`?o00000_oo
ool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`Co00000oooool3o`0000?ooooo0ol0
0009ooooo`03o`000?oooooooooo00;ooooo1_l000000ooooooo0000o`000003ooooo`;o000000?o
ooooo`000?l000000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1?l0
0003ooooo`Wo00000oooool3o`0000?ooooo1?l00004ooooo`03o`000?oooooooooo01_ooooo000W
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`00
:?ooool3o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`?o0000
2Oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`0000[ooooo1?l00004ooooo`03o`00
0?oooooooooo00Cooooo0_l00004ooooo`;o0000;_ooool00ol0003oooooooooo`0Hooooo`?o0000
5_ooool00ol0003oooooooooo`02ooooo`;o00002oooool00ol0003oooooooooo`0Mooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.8475, -5.67237, \
0.0718464, 0.0351862}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 7.54691 0.0147146 0.58957 [
[.04719 .00221 -15 -9 ]
[.04719 .00221 15 0 ]
[.19812 .00221 -15 -9 ]
[.19812 .00221 15 0 ]
[.34906 .00221 -15 -9 ]
[.34906 .00221 15 0 ]
[.5 .00221 -3 -9 ]
[.5 .00221 3 0 ]
[.65094 .00221 -12 -9 ]
[.65094 .00221 12 0 ]
[.80188 .00221 -12 -9 ]
[.80188 .00221 12 0 ]
[.95281 .00221 -12 -9 ]
[.95281 .00221 12 0 ]
[.01131 .13263 -18 -4.5 ]
[.01131 .13263 0 4.5 ]
[.01131 .25054 -18 -4.5 ]
[.01131 .25054 0 4.5 ]
[.01131 .36846 -18 -4.5 ]
[.01131 .36846 0 4.5 ]
[.01131 .48637 -18 -4.5 ]
[.01131 .48637 0 4.5 ]
[.01131 .60428 -6 -4.5 ]
[.01131 .60428 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04719 .01471 m
.04719 .02096 L
s
[(-0.06)] .04719 .00221 0 1 Mshowa
.19812 .01471 m
.19812 .02096 L
s
[(-0.04)] .19812 .00221 0 1 Mshowa
.34906 .01471 m
.34906 .02096 L
s
[(-0.02)] .34906 .00221 0 1 Mshowa
.5 .01471 m
.5 .02096 L
s
[(0)] .5 .00221 0 1 Mshowa
.65094 .01471 m
.65094 .02096 L
s
[(0.02)] .65094 .00221 0 1 Mshowa
.80188 .01471 m
.80188 .02096 L
s
[(0.04)] .80188 .00221 0 1 Mshowa
.95281 .01471 m
.95281 .02096 L
s
[(0.06)] .95281 .00221 0 1 Mshowa
.125 Mabswid
.08492 .01471 m
.08492 .01846 L
s
.12265 .01471 m
.12265 .01846 L
s
.16039 .01471 m
.16039 .01846 L
s
.23586 .01471 m
.23586 .01846 L
s
.27359 .01471 m
.27359 .01846 L
s
.31133 .01471 m
.31133 .01846 L
s
.3868 .01471 m
.3868 .01846 L
s
.42453 .01471 m
.42453 .01846 L
s
.46227 .01471 m
.46227 .01846 L
s
.53773 .01471 m
.53773 .01846 L
s
.57547 .01471 m
.57547 .01846 L
s
.6132 .01471 m
.6132 .01846 L
s
.68867 .01471 m
.68867 .01846 L
s
.72641 .01471 m
.72641 .01846 L
s
.76414 .01471 m
.76414 .01846 L
s
.83961 .01471 m
.83961 .01846 L
s
.87735 .01471 m
.87735 .01846 L
s
.91508 .01471 m
.91508 .01846 L
s
.00945 .01471 m
.00945 .01846 L
s
.99055 .01471 m
.99055 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
.02381 .13263 m
.03006 .13263 L
s
[(0.2)] .01131 .13263 1 0 Mshowa
.02381 .25054 m
.03006 .25054 L
s
[(0.4)] .01131 .25054 1 0 Mshowa
.02381 .36846 m
.03006 .36846 L
s
[(0.6)] .01131 .36846 1 0 Mshowa
.02381 .48637 m
.03006 .48637 L
s
[(0.8)] .01131 .48637 1 0 Mshowa
.02381 .60428 m
.03006 .60428 L
s
[(1)] .01131 .60428 1 0 Mshowa
.125 Mabswid
.02381 .04419 m
.02756 .04419 L
s
.02381 .07367 m
.02756 .07367 L
s
.02381 .10315 m
.02756 .10315 L
s
.02381 .16211 m
.02756 .16211 L
s
.02381 .19159 m
.02756 .19159 L
s
.02381 .22106 m
.02756 .22106 L
s
.02381 .28002 m
.02756 .28002 L
s
.02381 .3095 m
.02756 .3095 L
s
.02381 .33898 m
.02756 .33898 L
s
.02381 .39794 m
.02756 .39794 L
s
.02381 .42741 m
.02756 .42741 L
s
.02381 .45689 m
.02756 .45689 L
s
.02381 .51585 m
.02756 .51585 L
s
.02381 .54533 m
.02756 .54533 L
s
.02381 .57481 m
.02756 .57481 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .02 m
.02723 .02004 L
.03097 .02009 L
.03286 .02011 L
.0339 .02013 L
.03488 .02014 L
.0358 .02015 L
.03605 .02015 L
.03632 .02016 L
.03679 .0202 L
.03853 .02037 L
.04221 .02073 L
.04617 .02112 L
.04733 .02124 L
.0479 .02129 L
.04843 .02135 L
.04891 .02139 L
.04918 .02139 L
.04943 .02138 L
.05051 .02138 L
.05458 .02134 L
.05644 .02132 L
.0584 .02131 L
.06007 .02129 L
.06053 .02129 L
.06102 .02128 L
.06149 .02129 L
.06191 .02132 L
.06603 .02164 L
.06984 .02194 L
.07166 .02209 L
.07255 .02216 L
.07337 .02222 L
.07379 .02225 L
.07422 .02225 L
.07467 .02224 L
.07515 .02222 L
.07711 .02214 L
.08126 .02199 L
.08502 .02185 L
.08592 .02181 L
.08637 .0218 L
.08687 .02179 L
.08712 .02179 L
.0874 .02179 L
.08791 .0218 L
.08886 .0218 L
.09249 .0218 L
.09463 .02181 L
.09666 .02181 L
Mistroke
.09755 .02181 L
.09803 .02181 L
.09849 .02181 L
.09875 .02181 L
.09903 .02181 L
.09952 .0218 L
.10047 .02178 L
.10793 .02161 L
.10998 .02157 L
.11052 .02155 L
.1111 .02154 L
.11137 .02153 L
.11166 .02152 L
.1119 .02151 L
.11217 .0215 L
.11423 .0214 L
.11611 .02131 L
.11986 .02112 L
.12182 .02102 L
.12289 .02097 L
.12341 .02095 L
.12389 .02092 L
.12434 .02093 L
.12477 .02094 L
.12571 .02098 L
.12769 .02107 L
.13118 .02121 L
.13489 .02137 L
.13579 .02141 L
.13629 .02143 L
.13676 .02144 L
.13703 .02143 L
.13732 .02142 L
.13782 .02141 L
.13882 .02138 L
.14244 .02128 L
.14585 .02119 L
.14757 .02114 L
.14804 .02113 L
.14854 .02112 L
.14896 .0211 L
.14942 .02113 L
.14969 .02116 L
.14994 .02119 L
.15041 .02124 L
.15147 .02136 L
.15337 .02157 L
.15726 .022 L
.15938 .02224 L
.16042 .02235 L
Mistroke
.16088 .0224 L
.16137 .02246 L
.16184 .02249 L
.16227 .02251 L
.16312 .02255 L
.165 .02264 L
.16899 .02282 L
.17236 .02298 L
.17329 .02302 L
.1738 .02305 L
.17427 .02307 L
.17467 .02312 L
.1751 .02316 L
.17602 .02327 L
.18005 .02371 L
.18384 .02414 L
.19093 .02494 L
.19481 .02539 L
.19685 .02562 L
.19798 .02575 L
.19852 .02581 L
.19903 .02587 L
.19947 .0259 L
.19994 .0259 L
.20092 .02591 L
.20301 .02594 L
.20669 .02598 L
.20857 .026 L
.21033 .02602 L
.21081 .02603 L
.21131 .02603 L
.21157 .02603 L
.21186 .02605 L
.21212 .02607 L
.21237 .0261 L
.21422 .02629 L
.21757 .02664 L
.22122 .02701 L
.22222 .02712 L
.22328 .02723 L
.2238 .02728 L
.22428 .02733 L
.22472 .02731 L
.22519 .02728 L
.22895 .02703 L
.23261 .02679 L
.23439 .02667 L
.23602 .02656 L
.23645 .02653 L
.23692 .02651 L
Mistroke
.23736 .02652 L
.23777 .02654 L
.23965 .0266 L
.24363 .02672 L
.24563 .02678 L
.24778 .02685 L
.24882 .02688 L
.24907 .02689 L
.24933 .0269 L
.24981 .02691 L
.2507 .02692 L
.25166 .02693 L
.25879 .027 L
.26665 .02707 L
.27057 .02709 L
.27164 .0271 L
.27277 .0271 L
.27374 .02711 L
.27401 .02711 L
.27429 .02711 L
.27456 .02714 L
.2748 .02718 L
.28249 .02856 L
.28601 .0292 L
.28643 .02927 L
.28687 .02935 L
.28735 .0294 L
.28779 .02944 L
.2888 .02953 L
.28975 .02961 L
.29386 .02996 L
.29585 .03013 L
.29766 .03028 L
.29856 .03036 L
.29903 .0304 L
.29953 .03045 L
.29997 .03056 L
.30045 .03068 L
.30129 .0309 L
.30518 .0319 L
.31217 .03371 L
.32754 .03707 L
.34232 .03975 L
.35804 .04237 L
.36 .04251 L
.36096 .04257 L
.36138 .0426 L
.36185 .04264 L
.36234 .0427 L
.36261 .04275 L
Mistroke
.36287 .0428 L
.36397 .04303 L
.3659 .04342 L
.36971 .0442 L
.37318 .0449 L
.37402 .04507 L
.37448 .04517 L
.37492 .04529 L
.37538 .04547 L
.37589 .04566 L
.3768 .04599 L
.38022 .04726 L
.38775 .04996 L
.3948 .05153 L
.39673 .05196 L
.39779 .0522 L
.39879 .05242 L
.39925 .05252 L
.39973 .05263 L
.39998 .05275 L
.40025 .0529 L
.40074 .05316 L
.4025 .05411 L
.41015 .0582 L
.4143 .0613 L
.41819 .06504 L
.42009 .06688 L
.42216 .06888 L
.42311 .06979 L
.42412 .07076 L
.42453 .07116 L
.42498 .07183 L
.42547 .073 L
.42593 .0741 L
.433 .09099 L
.43475 .09519 L
.43572 .0975 L
.43663 .09968 L
.43688 .10028 L
.43715 .10092 L
.43744 .10195 L
.43771 .10351 L
.4387 .10917 L
.44062 .12024 L
.44449 .14254 L
.44865 .16653 L
.45254 .19763 L
.45609 .22975 L
.46307 .29391 L
.4782 .45556 L
Mistroke
.48213 .49527 L
.48583 .53267 L
.48667 .54112 L
.48707 .54524 L
.48745 .549 L
.48784 .55086 L
.48826 .55271 L
.48915 .55663 L
.49103 .56486 L
.49275 .57243 L
.49634 .58821 L
.49823 .59653 L
.49873 .59872 L
.49927 .60109 L
.49952 .60217 L
.49978 .60332 L
.50025 .60321 L
.50073 .60108 L
.50126 .59876 L
.50238 .59385 L
.50435 .5852 L
.50824 .56814 L
.51025 .5593 L
.51124 .55495 L
.51167 .55305 L
.51215 .55095 L
.51258 .54879 L
.51298 .54474 L
.51386 .53587 L
.51571 .51717 L
.52369 .43649 L
.53848 .27857 L
.54601 .2107 L
.55421 .1501 L
.55802 .12821 L
.56011 .1162 L
.56113 .11031 L
.56207 .10491 L
.56254 .10224 L
.56297 .1008 L
.56342 .09972 L
.56391 .09853 L
.5659 .09376 L
.56936 .08544 L
.57128 .08084 L
.57335 .07584 L
.57431 .07355 L
.57483 .0723 L
.57532 .07131 L
.57573 .07091 L
Mistroke
.57618 .07048 L
.57713 .06956 L
.58421 .06271 L
.59225 .05689 L
.59595 .05492 L
.59785 .05391 L
.59892 .05334 L
.5999 .05281 L
.60037 .0526 L
.60064 .05254 L
.60089 .05248 L
.60194 .05224 L
.60385 .0518 L
.60744 .05097 L
.61444 .04914 L
.62153 .04657 L
.62925 .04442 L
.63345 .04358 L
.6353 .04321 L
.63628 .04301 L
.6368 .04291 L
.63734 .0428 L
.63782 .0427 L
.63809 .04268 L
.63834 .04266 L
.63925 .04259 L
.64105 .04246 L
.645 .04217 L
.64692 .04203 L
.64793 .04196 L
.64901 .04188 L
.64946 .04185 L
.64994 .04181 L
.65022 .04179 L
.65047 .04175 L
.65097 .04162 L
.65279 .04113 L
.65987 .03922 L
.66711 .03782 L
.67125 .03726 L
.67321 .03699 L
.675 .03675 L
.67591 .03657 L
.67686 .03634 L
.67887 .03586 L
.68251 .03498 L
.6905 .033 L
.69439 .032 L
.69807 .03106 L
.69968 .03065 L
Mistroke
.70007 .03054 L
.70049 .03044 L
.70095 .03039 L
.70138 .03035 L
.70325 .03018 L
.70497 .03003 L
.7086 .0297 L
.71058 .02952 L
.71241 .02935 L
.71291 .02931 L
.71338 .02924 L
.71391 .02914 L
.7144 .02906 L
.71657 .02868 L
.72038 .02801 L
.72409 .02736 L
.72499 .0272 L
.72525 .02716 L
.7255 .02711 L
.72596 .0271 L
.72623 .0271 L
.72647 .0271 L
.72702 .02709 L
.72802 .02709 L
.73505 .02703 L
.74999 .02691 L
.75762 .02671 L
.75971 .02665 L
.76085 .02662 L
.76191 .02659 L
.76238 .02658 L
.76282 .02656 L
.76307 .02656 L
.76333 .02657 L
.7638 .0266 L
.76586 .02673 L
.76972 .02697 L
.77183 .0271 L
.77381 .02723 L
.77467 .02728 L
.7751 .02731 L
.77549 .02733 L
.77594 .02732 L
.77644 .02727 L
.7773 .02719 L
.78115 .0268 L
.78518 .0264 L
.78614 .02631 L
.78715 .02621 L
.78757 .02617 L
Mistroke
.78802 .02612 L
.78851 .0261 L
.78897 .02609 L
.79237 .02604 L
.79606 .02598 L
.79793 .02595 L
.79896 .02593 L
.79993 .02592 L
.80043 .02591 L
.80071 .02591 L
.80097 .02588 L
.80212 .02575 L
.80415 .02551 L
.81181 .02463 L
.81963 .02375 L
.82344 .02332 L
.82432 .02323 L
.82524 .02312 L
.82562 .02308 L
.82603 .02305 L
.82648 .02303 L
.8269 .02301 L
.82864 .02292 L
.83051 .02283 L
.83392 .02266 L
.83593 .02256 L
.83692 .02251 L
.8374 .02249 L
.83784 .02246 L
.83827 .02244 L
.83867 .0224 L
.83955 .02231 L
.84142 .02211 L
.84515 .0217 L
.84718 .02148 L
.84908 .02128 L
.84992 .02119 L
.85033 .02115 L
.8507 .0211 L
.85114 .02109 L
.85161 .0211 L
.85244 .02112 L
.85612 .02121 L
.85955 .02129 L
.86135 .02134 L
.86234 .02136 L
.86281 .02137 L
.86325 .02138 L
.86374 .02137 L
.864 .02136 L
Mistroke
.86426 .02135 L
.86536 .02131 L
.8673 .02124 L
.8711 .02109 L
.87302 .02101 L
.87481 .02095 L
.87528 .02093 L
.87572 .02091 L
.87596 .0209 L
.87622 .02092 L
.87668 .02094 L
.87874 .02104 L
.88577 .02138 L
.88749 .02146 L
.88796 .02148 L
.88839 .0215 L
.88885 .02152 L
.88935 .02153 L
.89041 .02155 L
.89138 .02158 L
.89329 .02162 L
.89741 .02172 L
.89943 .02177 L
.90032 .02179 L
.90079 .02181 L
.90105 .02181 L
.90129 .02181 L
.90223 .02181 L
.90311 .02181 L
.90503 .02181 L
.90908 .02182 L
.91081 .02182 L
.91173 .02182 L
.91223 .02182 L
.91271 .02182 L
.91316 .02182 L
.91364 .02182 L
.91409 .02184 L
.91449 .02185 L
.91615 .02191 L
.91962 .02204 L
.92333 .02217 L
.92442 .02221 L
.92496 .02223 L
.92546 .02225 L
.92591 .02227 L
.92639 .02225 L
.92687 .02221 L
.9274 .02217 L
.9312 .02189 L
Mistroke
.9348 .02162 L
.93676 .02147 L
.93771 .0214 L
.93813 .02137 L
.93858 .02134 L
.93907 .02134 L
.93954 .02134 L
.94056 .02135 L
.94272 .02136 L
.94652 .02138 L
.94826 .02139 L
.94922 .02139 L
.95013 .0214 L
.95065 .0214 L
.95094 .0214 L
.9512 .0214 L
.95168 .02135 L
.95218 .0213 L
.9541 .02112 L
.95796 .02075 L
.95998 .02055 L
.96212 .02035 L
.96299 .02026 L
.96347 .02022 L
.96392 .0202 L
.96418 .02019 L
.96446 .02019 L
.96494 .02018 L
.9659 .02017 L
.96937 .02011 L
.97619 .02001 L
Mfstroke
1 0 0 r
.02381 .01472 m
.02723 .01475 L
.03097 .01479 L
.03286 .0148 L
.0339 .01481 L
.03488 .01482 L
.0358 .01483 L
.03605 .01484 L
.03632 .01484 L
.03679 .01483 L
.03853 .01482 L
.04221 .01478 L
.04617 .01474 L
.04733 .01473 L
.0479 .01472 L
.04843 .01472 L
.04891 .01472 L
.04918 .01472 L
.04943 .01472 L
.05051 .01473 L
.05458 .01478 L
.05814 .01482 L
.05908 .01483 L
.06009 .01484 L
.06058 .01484 L
.06104 .01485 L
.06146 .01485 L
.06191 .01485 L
.06388 .01483 L
.06604 .0148 L
.06984 .01476 L
.07157 .01474 L
.07247 .01473 L
.07342 .01472 L
.07367 .01472 L
.07393 .01472 L
.07422 .01472 L
.07449 .01472 L
.07546 .01473 L
.07738 .01476 L
.08154 .01481 L
.08337 .01483 L
.08441 .01484 L
.08538 .01486 L
.08585 .01486 L
.08629 .01487 L
.08654 .01487 L
.08681 .01487 L
.08727 .01486 L
.08928 .01483 L
Mistroke
.09351 .01478 L
.09544 .01476 L
.0965 .01475 L
.09749 .01473 L
.09843 .01472 L
.09868 .01472 L
.09895 .01472 L
.09943 .01472 L
.10119 .01475 L
.10481 .0148 L
.1068 .01482 L
.10868 .01485 L
.11044 .01487 L
.11092 .01488 L
.11118 .01488 L
.11143 .01489 L
.11186 .01488 L
.11234 .01488 L
.11567 .01483 L
.11943 .01478 L
.12147 .01475 L
.12247 .01474 L
.12291 .01473 L
.12338 .01473 L
.12381 .01472 L
.12422 .01472 L
.1246 .01472 L
.12501 .01473 L
.12675 .01476 L
.13043 .01482 L
.13404 .01487 L
.13507 .01489 L
.13558 .0149 L
.13606 .01491 L
.13649 .01491 L
.13694 .01491 L
.1374 .0149 L
.1379 .01489 L
.14488 .01478 L
.14675 .01475 L
.14777 .01474 L
.14827 .01473 L
.14872 .01472 L
.14914 .01472 L
.14954 .01472 L
.1504 .01474 L
.15224 .01477 L
.1561 .01484 L
.15821 .01488 L
.15924 .0149 L
Mistroke
.16019 .01492 L
.16062 .01493 L
.16108 .01493 L
.16152 .01494 L
.16193 .01494 L
.16241 .01493 L
.16284 .01492 L
.16381 .01491 L
.1678 .01483 L
.17122 .01477 L
.17294 .01474 L
.17341 .01473 L
.17367 .01473 L
.17392 .01472 L
.17439 .01472 L
.17483 .01473 L
.17865 .01481 L
.18217 .01489 L
.18401 .01493 L
.18502 .01495 L
.18597 .01497 L
.18646 .01498 L
.18673 .01498 L
.18699 .01498 L
.18811 .01495 L
.1901 .01491 L
.19359 .01484 L
.19731 .01476 L
.19784 .01475 L
.19842 .01474 L
.19868 .01473 L
.19896 .01472 L
.19946 .01472 L
.19993 .01473 L
.20038 .01475 L
.2014 .01477 L
.2052 .01487 L
.2071 .01492 L
.20917 .01497 L
.21012 .01499 L
.21064 .01501 L
.21112 .01502 L
.21158 .01503 L
.21208 .01503 L
.21252 .01502 L
.21294 .01501 L
.22 .01483 L
.2218 .01478 L
.22279 .01476 L
.22327 .01474 L
Mistroke
.22372 .01473 L
.22414 .01472 L
.22459 .01473 L
.22504 .01474 L
.22554 .01476 L
.22719 .01481 L
.2313 .01493 L
.23507 .01505 L
.23595 .01508 L
.23643 .01509 L
.23688 .0151 L
.23714 .01509 L
.23742 .01509 L
.23791 .01507 L
.23886 .01504 L
.24246 .01493 L
.24625 .01482 L
.24729 .01478 L
.2484 .01475 L
.24866 .01474 L
.24894 .01473 L
.24921 .01473 L
.24945 .01472 L
.24992 .01474 L
.25041 .01476 L
.25801 .01505 L
.25984 .01512 L
.2608 .01516 L
.26133 .01518 L
.26182 .01519 L
.26208 .01519 L
.26236 .01518 L
.26295 .01516 L
.26399 .01512 L
.26603 .01504 L
.26993 .01489 L
.27198 .01482 L
.27311 .01477 L
.27365 .01475 L
.27416 .01473 L
.27463 .01473 L
.27507 .01475 L
.27606 .0148 L
.27815 .0149 L
.28183 .01508 L
.28372 .01518 L
.28549 .01526 L
.28647 .01531 L
.28674 .01532 L
.28703 .01533 L
Mistroke
.28727 .01532 L
.28754 .01531 L
.28939 .01522 L
.29299 .01504 L
.2964 .01488 L
.29826 .01479 L
.29878 .01476 L
.29906 .01475 L
.29932 .01474 L
.29978 .01474 L
.30003 .01476 L
.30029 .01478 L
.30384 .01501 L
.30765 .01525 L
.30966 .01538 L
.31077 .01545 L
.31131 .01549 L
.31181 .01552 L
.3123 .01552 L
.31254 .0155 L
.31281 .01549 L
.31389 .01542 L
.31577 .0153 L
.31946 .01506 L
.32146 .01493 L
.32257 .01486 L
.32361 .01479 L
.32409 .01476 L
.32459 .01473 L
.32485 .01476 L
.32514 .01478 L
.32565 .01483 L
.3275 .01499 L
.33108 .01531 L
.33486 .01565 L
.33581 .01574 L
.33634 .01578 L
.33683 .01583 L
.33712 .01585 L
.33742 .01582 L
.33795 .01578 L
.339 .01568 L
.3428 .01534 L
.34468 .01518 L
.3467 .015 L
.34768 .01491 L
.34861 .01483 L
.34902 .01479 L
.34945 .01475 L
.34992 .01478 L
Mistroke
.35036 .01483 L
.35417 .01533 L
.35837 .01588 L
.36028 .01613 L
.36132 .01627 L
.36158 .0163 L
.36183 .01634 L
.36229 .01636 L
.36253 .01633 L
.3628 .0163 L
.36334 .01622 L
.3645 .01607 L
.36653 .01581 L
.37018 .01533 L
.37212 .01508 L
.37314 .01495 L
.3737 .01487 L
.37421 .01481 L
.37468 .01475 L
.37518 .01485 L
.37624 .01507 L
.3781 .01545 L
.38175 .0162 L
.38391 .01665 L
.38497 .01686 L
.38594 .01707 L
.38683 .01725 L
.38728 .01732 L
.38777 .01722 L
.38975 .01681 L
.39355 .01603 L
.39716 .01529 L
.39813 .01509 L
.39915 .01488 L
.39946 .01481 L
.39974 .01476 L
.4 .01484 L
.40028 .01494 L
.40132 .01532 L
.40512 .01668 L
.40906 .0181 L
.41005 .01845 L
.41098 .01879 L
.41182 .01909 L
.4123 .01925 L
.41274 .01909 L
.41459 .01843 L
.41657 .01772 L
.42077 .01621 L
.42254 .01558 L
Mistroke
.42351 .01523 L
.424 .01506 L
.42444 .0149 L
.42486 .0148 L
.4253 .01513 L
.42624 .01582 L
.42789 .01703 L
.43198 .02005 L
.43378 .02137 L
.4348 .02212 L
.43575 .02282 L
.43666 .0235 L
.43693 .02369 L
.43718 .02388 L
.43765 .02377 L
.43815 .02341 L
.43861 .02307 L
.43966 .02229 L
.4439 .01917 L
.44762 .01643 L
.44852 .01577 L
.449 .01542 L
.4495 .01505 L
.44977 .01485 L
.45006 .01516 L
.45033 .01573 L
.45057 .01625 L
.45158 .01838 L
.45558 .02687 L
.45936 .03489 L
.46101 .03839 L
.46184 .04015 L
.46232 .04115 L
.46276 .04059 L
.46324 .03957 L
.46368 .03863 L
.46468 .03653 L
.46644 .03278 L
.46995 .02535 L
.47187 .02127 L
.47368 .01743 L
.47419 .01637 L
.47446 .01579 L
.47472 .01524 L
.47499 .01587 L
.4753 .02178 L
.47583 .03217 L
.47778 .06998 L
.48158 .14379 L
.48869 .29181 L
Mistroke
.49641 .50522 L
.49846 .56161 L
.49949 .59008 L
.49977 .59788 L
.50007 .60229 L
.50036 .59436 L
.50062 .58709 L
.50451 .47961 L
.51218 .2678 L
.5194 .12478 L
.52137 .08639 L
.52349 .0454 L
.52398 .03585 L
.52451 .0255 L
.52501 .01572 L
.52548 .01566 L
.5259 .01654 L
.52636 .01752 L
.52729 .01949 L
.53109 .02756 L
.5347 .03521 L
.53567 .03726 L
.53669 .03943 L
.537 .04008 L
.53729 .04069 L
.53754 .04123 L
.53782 .04086 L
.53809 .0403 L
.53836 .03971 L
.53886 .03865 L
.54266 .03059 L
.54629 .0229 L
.54828 .01868 L
.54926 .0166 L
.54969 .01569 L
.55017 .0148 L
.55061 .01513 L
.55102 .01543 L
.55192 .0161 L
.55383 .0175 L
.55716 .01995 L
.55905 .02134 L
.56005 .02208 L
.56111 .02286 L
.56164 .02325 L
.56214 .02362 L
.56258 .02394 L
.56306 .0237 L
.56352 .02336 L
.564 .02301 L
Mistroke
.56487 .02237 L
.57193 .01717 L
.57282 .01651 L
.57378 .0158 L
.57422 .01547 L
.57469 .01513 L
.5751 .01483 L
.57554 .01489 L
.57604 .01507 L
.57658 .01526 L
.57756 .01561 L
.57941 .01628 L
.58303 .01757 L
.58479 .0182 L
.58639 .01878 L
.58683 .01893 L
.5873 .0191 L
.58774 .01924 L
.58815 .0191 L
.59004 .01842 L
.59403 .01699 L
.59793 .01559 L
.59888 .01525 L
.5994 .01506 L
.5999 .01488 L
.60018 .01478 L
.60048 .0148 L
.60076 .01486 L
.60102 .01491 L
.60206 .01513 L
.6061 .01596 L
.60808 .01636 L
.60989 .01674 L
.61155 .01708 L
.61196 .01716 L
.61239 .01725 L
.61286 .01731 L
.6133 .01722 L
.61699 .01646 L
.62087 .01566 L
.62292 .01524 L
.62404 .01501 L
.62459 .01489 L
.62509 .01479 L
.62554 .01477 L
.62601 .01484 L
.62699 .01496 L
.62908 .01524 L
.63276 .01572 L
.63464 .01596 L
Mistroke
.63641 .01619 L
.63688 .01625 L
.63739 .01632 L
.63765 .01635 L
.63794 .01637 L
.6382 .01633 L
.63845 .0163 L
.6403 .01606 L
.64365 .01562 L
.6473 .01514 L
.6483 .01501 L
.64936 .01487 L
.6498 .01481 L
.65027 .01475 L
.65054 .01475 L
.65079 .01477 L
.65127 .01482 L
.65504 .01515 L
.65845 .01546 L
.66033 .01562 L
.66211 .01578 L
.66256 .01582 L
.66304 .01584 L
.66329 .01582 L
.66357 .01579 L
.66406 .01575 L
.66583 .01559 L
.6693 .01528 L
.67127 .0151 L
.67338 .01492 L
.6744 .01482 L
.6749 .01478 L
.67537 .01474 L
.67579 .01475 L
.67624 .01478 L
.67719 .01484 L
.68111 .01509 L
.68317 .01523 L
.68535 .01537 L
.68627 .01543 L
.68726 .01549 L
.68755 .01551 L
.68782 .01553 L
.68807 .01553 L
.68834 .01551 L
.68935 .01545 L
.69303 .01521 L
.69692 .01496 L
.69883 .01483 L
.69966 .01478 L
Mistroke
.70013 .01475 L
.70057 .01473 L
.701 .01475 L
.70146 .01477 L
.7024 .01482 L
.70438 .01491 L
.70858 .01512 L
.71047 .01521 L
.71151 .01526 L
.71248 .01531 L
.71274 .01532 L
.71299 .01533 L
.71327 .01532 L
.71353 .01531 L
.71468 .01525 L
.71671 .01515 L
.72043 .01497 L
.72233 .01488 L
.72341 .01483 L
.72439 .01478 L
.72491 .01475 L
.72539 .01473 L
.72589 .01474 L
.72615 .01475 L
.72644 .01476 L
.72836 .01483 L
.73195 .01497 L
.73372 .01503 L
.7356 .0151 L
.7372 .01516 L
.73764 .01518 L
.73811 .0152 L
.73856 .01518 L
.73897 .01516 L
.74285 .01502 L
.74708 .01486 L
.74896 .01478 L
.74947 .01476 L
.75002 .01474 L
.75029 .01473 L
.75054 .01472 L
.75101 .01473 L
.75146 .01475 L
.75194 .01476 L
.7528 .01479 L
.75475 .01485 L
.75835 .01496 L
.76034 .01502 L
.76132 .01505 L
.76222 .01508 L
Mistroke
.76266 .01509 L
.76307 .0151 L
.7635 .01509 L
.76397 .01508 L
.76588 .01502 L
.76921 .01492 L
.77295 .0148 L
.77386 .01477 L
.77483 .01475 L
.77512 .01474 L
.77539 .01473 L
.77563 .01472 L
.7759 .01472 L
.77615 .01473 L
.77641 .01474 L
.77689 .01475 L
.78394 .01493 L
.78578 .01497 L
.78669 .015 L
.78753 .01502 L
.788 .01503 L
.78849 .01503 L
.78878 .01502 L
.78905 .01501 L
.78955 .015 L
.79139 .01495 L
.79472 .01487 L
.79836 .01478 L
.7993 .01475 L
.79981 .01474 L
.80029 .01473 L
.80074 .01472 L
.80123 .01473 L
.80209 .01475 L
.80602 .01483 L
.80966 .01491 L
.81143 .01494 L
.81221 .01496 L
.81265 .01497 L
.81306 .01498 L
.81347 .01498 L
.81391 .01497 L
.81479 .01495 L
.81665 .01491 L
.82061 .01483 L
.82277 .01478 L
.82383 .01476 L
.8248 .01474 L
.82526 .01473 L
.82569 .01472 L
Mistroke
.82614 .01472 L
.82663 .01473 L
.82861 .01477 L
.83259 .01484 L
.83454 .01488 L
.83635 .01491 L
.8372 .01492 L
.83799 .01494 L
.83839 .01494 L
.83882 .01494 L
.83973 .01492 L
.84342 .01485 L
.84736 .01478 L
.84929 .01475 L
.85013 .01473 L
.8506 .01472 L
.85104 .01472 L
.8515 .01473 L
.85199 .01473 L
.85289 .01475 L
.85487 .01478 L
.85907 .01485 L
.86091 .01487 L
.86182 .01489 L
.86266 .0149 L
.86312 .01491 L
.86362 .01491 L
.8639 .01491 L
.86417 .0149 L
.86467 .01489 L
.86651 .01487 L
.86984 .01481 L
.87349 .01475 L
.87441 .01474 L
.87492 .01473 L
.87541 .01472 L
.87586 .01472 L
.87635 .01472 L
.87679 .01473 L
.87721 .01473 L
.88113 .01479 L
.88452 .01483 L
.8863 .01486 L
.88727 .01487 L
.88774 .01488 L
.88817 .01489 L
.88861 .01489 L
.88909 .01488 L
.89009 .01487 L
.89184 .01484 L
Mistroke
.89528 .01479 L
.89722 .01477 L
.89932 .01474 L
.90028 .01473 L
.90077 .01472 L
.90105 .01472 L
.9013 .01472 L
.90313 .01474 L
.9071 .01479 L
.90905 .01481 L
.91086 .01484 L
.9125 .01486 L
.91297 .01486 L
.91341 .01487 L
.91381 .01487 L
.91424 .01486 L
.91792 .01482 L
.92186 .01477 L
.92378 .01474 L
.92462 .01473 L
.92553 .01472 L
.92603 .01472 L
.92649 .01472 L
.92738 .01473 L
.92937 .01475 L
.93356 .0148 L
.93534 .01482 L
.93626 .01483 L
.93724 .01484 L
.9381 .01485 L
.93859 .01485 L
.93904 .01485 L
.94069 .01483 L
.94473 .01479 L
.94672 .01476 L
.94854 .01474 L
.94949 .01473 L
.95037 .01472 L
.95081 .01472 L
.95129 .01472 L
.95156 .01472 L
.95181 .01472 L
.95229 .01473 L
.95635 .01477 L
.95979 .0148 L
.96167 .01482 L
.96259 .01483 L
.963 .01483 L
.96344 .01484 L
.96382 .01484 L
Mistroke
.96418 .01483 L
.96495 .01483 L
.96659 .01481 L
.97006 .01478 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[76]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`007Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000Boooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool3o`00017ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00006?ooool2o`0001_ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00004Oooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0ol0000Aooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000oooool3o`0000gooooo000Looooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Oooooo00Co
0000oooooooooooo00006Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0:ooooo`005Oooool5o`00
00;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool01oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01Ol0003o
ooooooooool0003ooooo00Go00002Oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo0000
6Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool04?ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01Ol0
000@ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00[ooooo000Looooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
oooooooo0000ooooo`04o`00017ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05_ooool01?l0003oooooooooool0
000Iooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0002ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
ooooool0003ooooo00Co00003Oooool001cooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0001Cooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooo0000017ooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0
000Iooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo0000017ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`00013ooooo000Looooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000oooool2o`00017ooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0
000Iooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`;o00004Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool03Oooool001gooooo0_l0000:ooooo`;o00001?ooool2o`0001;ooooo
0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`0@ooooo`;o00002_ooool2o`0000?ooooo
0ol0000Iooooo`;o00006oooool2o`0000[ooooo0_l00003ooooo`?o00004_ooool2o`0000[ooooo
0_l00005ooooo`03o`000?oooooooooo013ooooo0_l0000:ooooo`;o00001?ooool2o`0000gooooo
000Nooooo`03o`000?oooooooooo0?oooooo000Nooooo`03o`000?oooooooooo0?oooooo000Noooo
o`03o`000?oooooooooo0?oooooo000Nooooo`03o`000?oooooooooo0?oooooo000Hooooo`Ko0000
H_oo00000ol0003oo`00ool00002ool000Co00000_oo0005o`000003ool00?l0003o000000[o0000
00?oo`00o`000?l000000ol00002ool000Co00001?oo00000ol0003oo`00ool0001Pool000Ko0000
2_ooool001[ooooo00Co0000oooooooooooooooo3?l00004ooooo`04o`000?ooooooooooooooo`ko
000000?oooooo`000?ooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool2ool00003ooooool0003ooooo00;oo`0000Coooooool00?oo
ooooo`000_ooool01?l0003oooooool00?oo0006ooooo`03o`000?oooooooooo00?ooooo00Coo`00
oooooooooooo00000_ooool00ooo003oooooool00002ooooo`04ool00?oooooo0000ooooo`;oo`00
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooo`00000=o`0000Cooooo00?o0000ooooooooool00_ooool;o`0000?ooooo
00?o0000ooooooooool02_ooool001kooooo00?o0000ooooooooool02Oooool8o`0000kooooo2ol0
000kooooo`;oo`000_ooool00ooo003oooooooooo`02ooooo`;oo`003?ooool00ooo003ooooooooo
o`02ooooo`04ool00?ooooooooooooooo`;oo`00>oooool;o`0000kooooo2Ol0000Kooooo`007_oo
ool00ol0003oooooooooo`0YoooooaSo0000:Oooool01?oo003oooooooooooooool2ool000cooooo
0_oo0003ooooo`03ool00?oooooooooo02Oooooo6?l0000looooo`007_ooool00ol0003ooooooooo
o`11ooooo`Go00009?ooool01_oo003ooooooooooooo003oooooool000cooooo0_oo0002ooooo`03
ool00?oooooooooo02;ooooo1_l0001Dooooo`007_ooool00ol0003oooooooooo`16ooooo`Oo0000
7_ooool01Ooo003oooooool00?ooooooo`0000cooooo00?oo`00oooooooo00000_oo000Pooooo`Co
0000F_ooool001kooooo00?o0000ooooooooool0COooool4o`0001_ooooo00Coo`00oooooooooooo
o`003?ooool01?oo003ooooooooooooo000Looooo`Go0000G_ooool001kooooo0_l0001Booooo`Ko
00006?ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo01Oooooo2?l0001Rooooo`00
7_ooool00ol0003oooooooooo`1Fooooo`?o00005_ooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo01Cooooo0ol0001Zooooo`007_ooool00ol0003oooooooooo`1Iooooo`Co00004_oo
ool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo017ooooo0ol0001]ooooo`007_ooool0
0ol0003oooooooooo`1Mooooo`;o00004Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooo
oooo00oooooo0_l0001`ooooo`007_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
00kooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo
073ooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0000>ooooo`03ool00?oooooooooo00So
oooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`1aooooo`007_ooool00ol0003ooooo
ooooo`1Qooooo`;o00003Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00cooooo
00?o0000ooooooooool0L_ooool001kooooo00?o0000ooooooooool0H_ooool2o`0000cooooo00?o
o`00ooooooooool02?ooool00ooo003oooooooooo`0:ooooo`;o0000MOooool001kooooo0_l0001T
ooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0:
ooooo`03o`000?oooooooooo07Cooooo000Nooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool02_ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00[ooooo00?o0000oooo
ooooool0M?ooool001kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`09ooooo`03
ool00?oooooooooo00Sooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`1dooooo`00
7_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0
2?ooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo07Gooooo000Nooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`08ooooo`03ool00?oo
oooooooo00Wooooo00?o0000ooooooooool0MOooool001kooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`08ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02?ooool0
0ol0003oooooooooo`1fooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o00002Oooool00ooo
003oooooooooo`08ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool0M_ooool001ko
oooo0_l0001Wooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool02?ooool00ooo003o
ooooooooo`07ooooo`03o`000?oooooooooo07Oooooo000Nooooo`03o`000?oooooooooo06Kooooo
00?o0000ooooooooool01oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Oooooo
00?o0000ooooooooool0Moooool001kooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`08ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool02?ooool00ol0003ooooooooo
o`1gooooo`007_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00Sooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo07Oooooo000Noooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Sooooo00?o0000ooooooooool0Moooool000_ooooo0_l00004ooooo`04
o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo
07Sooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`07ooooo`03o`000?oooooooooo07Sooooo000:ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`07ooooo`03o`000?oooooo
oooo07Sooooo000:ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool3
o`0006Oooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Oooooo00?o0000ooooooooool0N?ooool000[ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`07ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01oooool00ol0003ooooooooo
o`1hooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo000;ooooo`;o00002Ooo
ool3o`0000Gooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`07ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`1iooooo`007_ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo000Nooooo`03o`000?oooooooooo
06Sooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Kooooo00?o0000ooooooooool0NOooool001kooooo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01_ooool00ol0003o
ooooooooo`1iooooo`007_ooool2o`0006[ooooo00?o0000ooooooooool01Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool0NOooool001kooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01_ooool00ol0003oooooooooo`1iooooo`007_ooool00ol0003oooooooooo`1Y
ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05
ooooo`03o`000?oooooooooo07[ooooo000Nooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo00?o0000oooo
ooooool0N_ooool001kooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`1jooooo`00
7_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo07[ooooo000Nooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Gooooo00?o0000ooooooooool0N_ooool001kooooo0_l0001[ooooo`03o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03o`000?oooooo
oooo07[ooooo000Nooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01Oooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool0N_ooool001ko
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`1kooooo`007_ooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`05ooooo`03o`000?oooooooooo07_ooooo000Nooooo`03o`000?oooooooooo06[ooooo00?o
0000ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?o
0000ooooooooool0Noooool001kooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`05
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`1k
ooooo`007_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Gooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo07_ooooo000Nooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Gooooo00?o0000ooooooooool0Noooool001kooooo0_l0001[ooooo`03o`00
0?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03o`00
0?oooooooooo07_ooooo000Nooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01Ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool0Nooo
ool001kooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`05ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`1looooo`007_ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`03o`000?oooooooooo07cooooo000Nooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Co
oooo00?o0000ooooooooool0O?ooool000_ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0ol00004ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01Oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool0O?ooool000[ooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00?o0000ooooooooool0O?ooool000[ooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo
0ol0001[ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`04ooooo`03o`000?oooooooooo07cooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo07co
oooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`1[ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`04ooooo`03o`000?oooooooooo07cooooo000:ooooo`04o`000?ooooooooooo`0000Wo
oooo0_l00005ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool0O?ooool000_ooooo
0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`05ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ol0003ooooo
ooooo`1mooooo`007_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Gooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo07gooooo000N
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool0OOooool001kooooo00?o0000oooo
ooooool0Joooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00oooool00ol0003oooooooooo`1mooooo`007_ooool2o`0006gooooo00?o0000oooooooo
ool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?o0000oooooooo
ool0OOooool001kooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`1mooooo`007_oo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo07gooooo000Nooooo`03o`000?oooooo
oooo06cooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00?ooooo00?o0000ooooooooool0OOooool001kooooo00?o0000ooooooooool0K?ooool00ol0
003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ol0
003oooooooooo`1mooooo`007_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Co
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo07go
oooo000Nooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool0OOooool001kooooo0_l0
001]ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`02ooooo`03o`000?oooooooooo07kooooo000Nooooo`03o`000?oooooooooo06cooooo00?o0000
ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o0000
ooooooooool0O_ooool001kooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`1noooo
o`007_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo07kooooo000Nooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00?ooooo00?o0000ooooooooool0O_ooool001kooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00ooo
ool00ol0003oooooooooo`1nooooo`007_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooo
oooo07kooooo000Nooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool00oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool0O_ooool001ko
oooo0_l0001^ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`03ooooo`03o`000?oooooooooo07kooooo000Nooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo
00?o0000ooooooooool0O_ooool001kooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`04ooooo`05ool00?oooooooooooooooooo00001Oooool00ol0003oooooooooo`1nooooo`007_oo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Cooooo00Goo`00oooooooooooooooo
ool00005ooooo`03o`000?oooooooooo07kooooo000Nooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Gooooo00?o0000ooooooooool0
O_ooool000_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Cooooo
00?o0000ooooooooool0Ooooool000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`03ooooo`05
ool00?oooooooooooooooooo00001?ooool00ol0003oooooooooo`1oooooo`002_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool3o`0006kooooo00?o0000
ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Cooooo00?o0000ooooooooool0Oooo
ool000[ooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00001?ooool00ol0003ooooo
ooooo`1oooooo`002_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo
00001?ooool00ol0003oooooooooo`1oooooo`002_ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`03ooooo`05
ool00?oooooooooooooooooo00001?ooool00ol0003oooooooooo`1oooooo`002oooool2o`0000[o
oooo0_l00005ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool00oooool01Ooo003o
ooooooooooooooooo`0000Cooooo00?o0000ooooooooool0Ooooool001kooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00001?ooool00ol0
003oooooooooo`1oooooo`007_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00?o
oooo00Goo`00ooooooooooooooooool00004ooooo`03o`000?oooooooooo07oooooo000Nooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool00oooool01Ooo003oooooooooooooooooo`00
00Cooooo00?o0000ooooooooool0Ooooool001kooooo0_l0001`ooooo`03o`000?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00004ooooo`03o`000?oooooooooo07oooooo000Nooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00Cooooo00?o0000ooooooooool0Ooooool001kooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?ooool00ol0003oooooooooo`1ooooo
o`007_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03o`000?oooooooooo083ooooo000Nooooo`03o`000?oooooooooo06oo
oooo00?o0000ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o0000oooo
ooooool0P?ooool001kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool00ol0003oooooooooo`20ooooo`007_ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003oooo
o`03o`000?oooooooooo083ooooo000Nooooo`;o0000L?ooool00ol0003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool00ol0003oooooooooo`20ooooo`007_ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00;ooooo00Coo`00ooooooooooooo`001?ooool00ol0
003oooooooooo`20ooooo`007_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00;o
oooo00Coo`00ooooooooooooo`001?ooool00ol0003oooooooooo`20ooooo`007_ooool00ol0003o
ooooooooo`1`ooooo`05o`000?oooooooooooooooooo00000_ooool00ooo003oooooooooo`02oooo
o`03o`000?oooooooooo083ooooo000Nooooo`03o`000?oooooooooo073ooooo00Go0000oooooooo
ooooooooool00002ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0P?ooool001ko
oooo00?o0000ooooooooool0L?ooool01Ol0003oooooooooooooooooo`0000;ooooo00?oo`00oooo
ooooool00_ooool00ol0003oooooooooo`20ooooo`007_ooool00ol0003oooooooooo`1`ooooo`05
o`000?oooooooooooooooooo00000_ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo
083ooooo000Nooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool00_ooool00ooo003o
ooooool00004ooooo`03o`000?oooooooooo083ooooo000Nooooo`;o0000LOooool00ol0003ooooo
ooooo`02ooooo`03ool00?ooooooo`0000?ooooo00?o0000ooooooooool0POooool001kooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`02ooooo`03ool00?ooooooo`0000?ooooo00?o
0000ooooooooool0POooool001kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`02
ooooo`03ool00?ooooooo`0000?ooooo00?o0000ooooooooool0POooool001kooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`02ooooo`03ool00?ooooooo`0000?ooooo00?o0000oooo
ooooool0POooool001kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`02ooooo`03
ool00?ooooooo`0000?ooooo00?o0000ooooooooool0POooool000_ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo077ooooo00Oo0000oooooooooooo
ooooool00?ooooooo`0000?ooooo00?o0000ooooooooool0POooool000[ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0LOooool0
1ol0003oooooooooooooooooo`00oooooooo00000oooool00ol0003oooooooooo`21ooooo`002_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool3o`00077o
oooo00Oo0000ooooooooooooooooool00?ooooooo`0000?ooooo00?o0000ooooooooool0POooool0
00[ooooo00Co0000oooooooooooo00002?ooool3o`0000Gooooo00?o0000ooooooooool0LOooool0
1ol0003oooooooooooooooooo`00oooooooo00000oooool00ol0003oooooooooo`21ooooo`002_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`1aooooo`07o`000?oooooooooooooooooo003oooooool00003ooooo`03o`000?oooooo
oooo087ooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo077ooooo00Oo0000ooooooooooooooooool00?ooooooo`0000?o
oooo00?o0000ooooooooool0POooool000_ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`1aooooo`07o`000?oooooooooooooooooo003oooooool00002ooooo`03o`000?oooooooooo
08;ooooo000Nooooo`03o`000?oooooooooo077ooooo00Oo0000ooooooooooooooooool00?oooooo
o`0000;ooooo00?o0000ooooooooool0P_ooool001kooooo00?o0000ooooooooool0LOooool01ol0
003oooooooooooooooooo`00oooooooo00000_ooool00ol0003oooooooooo`22ooooo`007_ooool2
o`0007;ooooo00Oo0000ooooooooooooooooool00?ooooooo`0000;ooooo00?o0000ooooooooool0
P_ooool001kooooo00?o0000ooooooooool0L_ooool01_l0003ooooooooooooo003oooooool000;o
oooo00?o0000ooooooooool0P_ooool001kooooo00?o0000ooooooooool0L_ooool01_l0003ooooo
oooooooo003oooooool000;ooooo00?o0000ooooooooool0P_ooool001kooooo00?o0000oooooooo
ool0L_ooool01_l0003ooooooooooooo003oooooool000;ooooo00?o0000ooooooooool0P_ooool0
01kooooo00?o0000ooooooooool0L_ooool02?l0003ooooooooooooo003oooooool00?oooooo0000
QOooool001kooooo00?o0000ooooooooool0L_ooool02?l0003ooooooooooooo003oooooool00?oo
oooo0000QOooool001kooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`02ool000;o
oooo00?o0000ooooooooool0Poooool001kooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`02ool000;ooooo00?o0000ooooooooool0Poooool001kooooo0_l0001cooooo`03o`000?oo
oooooooo00;oo`000_ooool00ol0003oooooooooo`23ooooo`007_ooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo00;oo`000_ooool00ol0003oooooooooo`23ooooo`007_ooool00ol0
003oooooooooo`1cooooo`06o`000?ooooooo`00ool00?oooooo0000Q_ooool001kooooo00?o0000
ooooooooool0Loooool01_l0003oooooool00?oo003oooooo`0008Kooooo000Nooooo`03o`000?oo
oooooooo07?ooooo00Ko0000oooooooo003oo`00ooooool00026ooooo`007_ooool00ol0003ooooo
ooooo`1cooooo`06o`000?ooooooo`00ool00?oooooo0000Q_ooool001kooooo00?o0000oooooooo
ool0Loooool01_l0003oooooool00?oo003oooooo`0008Kooooo000Nooooo`;o0000MOooool01Ol0
003oo`00ool00?oooooo000008Kooooo000Nooooo`03o`000?oooooooooo07Cooooo00Go0000ool0
0?oo003oooooo`000026ooooo`007_ooool00ol0003oooooooooo`1dooooo`04o`000?oo003oo`00
o`0008Oooooo000Nooooo`03o`000?oooooooooo07Gooooo0_oo00000ol0003oooooooooo`25oooo
o`007_ooool00ol0003oooooooooo`1eooooo`;oo`0000?o0000ooooooooool0QOooool001Kooooo
0ol00005ooooo`03o`000?oooooooooo07Gooooo0_oo0028ooooo`005oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo07Gooooo0_oo0028ooooo`005oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo07Gooooo00?o0000ool00?ooool0Qoooool001Oooooo00?o0000oooo
ooooool01?ooool3o`0007Gooooo0_l00028ooooo`005oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo000Fooooo`;o00001_ooool00ol0003oooooooooo`3oooooo`005ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo001Tooooo`?o0000DOooool3o`0006Gooooo001Uooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool0I?ooool003[ooooo0ol00004ooooo`?o00000_ooool5
o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00002Oooool3o`0000?ooooo0ol0
0002ooooo`?o00001?ooool3o`0000?ooooo1?l00002ooooo`Co00001oooool5o`000005ooooool0
003o0000o`000?ooool00_l00002ooooo`;o00000oooool3o`0000;ooooo0ol000000ooooooo0000
o`000004o`0000;ooooo1Ol00003ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`?o0000
1Oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0ol00004ooooo`;o
00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l00000;?ooool003_ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
ooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooooooooooo
ool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000;Oooool003_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`Go00000_ooool3o`0000;ooooo00Co0000
oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool3o`0000Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`06o`000?oooooooooo
o`000?oooooo00001_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02_ooooo000kooooo`?o0000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`04o`000?oooooooooo
o`0000;ooooo0_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`?o00000oooool01?l0003ooooo
ooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool0
0006ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo02_ooooo000kooooo`04o`000?ooooooooooo`0000;ooooo0ol00002ooooo`?o
00000oooool4o`0000;ooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo1?l00002ooooo`;o
000000?oooooo`000?l000000_ooool3o`0000?ooooo0_l00004ooooo`?o00002_ooool01?l0003o
ooooooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000?ooooo1?l000001?oo
oooo0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000Sooooo00?o0000
ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool3o`0000;ooooo1?l0
0002ooooo`?o00001?ooool3o`0000;ooooo1?l0000^ooooo`00>oooool01?l0003oooooooooool0
000Dooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00007?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0@?ooool003[ooooo
1?l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool3o`0001_ooooo
0_l00008ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool5o`0001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0iooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0791181, -0.0815635, \
0.000523829, 0.00670538}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00626439 0.0280925 0.561849 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.1491 -0.0125 -6 -9 ]
[.1491 -0.0125 6 0 ]
[.27439 -0.0125 -6 -9 ]
[.27439 -0.0125 6 0 ]
[.39967 -0.0125 -6 -9 ]
[.39967 -0.0125 6 0 ]
[.52496 -0.0125 -6 -9 ]
[.52496 -0.0125 6 0 ]
[.65025 -0.0125 -9 -9 ]
[.65025 -0.0125 9 0 ]
[.77554 -0.0125 -9 -9 ]
[.77554 -0.0125 9 0 ]
[.90082 -0.0125 -9 -9 ]
[.90082 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .14046 -18 -4.5 ]
[-0.0125 .14046 0 4.5 ]
[-0.0125 .25283 -18 -4.5 ]
[-0.0125 .25283 0 4.5 ]
[-0.0125 .3652 -18 -4.5 ]
[-0.0125 .3652 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -84 0 ]
[.5 .63053 84 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.1491 0 m
.1491 .00625 L
s
[(20)] .1491 -0.0125 0 1 Mshowa
.27439 0 m
.27439 .00625 L
s
[(40)] .27439 -0.0125 0 1 Mshowa
.39967 0 m
.39967 .00625 L
s
[(60)] .39967 -0.0125 0 1 Mshowa
.52496 0 m
.52496 .00625 L
s
[(80)] .52496 -0.0125 0 1 Mshowa
.65025 0 m
.65025 .00625 L
s
[(100)] .65025 -0.0125 0 1 Mshowa
.77554 0 m
.77554 .00625 L
s
[(120)] .77554 -0.0125 0 1 Mshowa
.90082 0 m
.90082 .00625 L
s
[(140)] .90082 -0.0125 0 1 Mshowa
.125 Mabswid
.05513 0 m
.05513 .00375 L
s
.08645 0 m
.08645 .00375 L
s
.11778 0 m
.11778 .00375 L
s
.18042 0 m
.18042 .00375 L
s
.21174 0 m
.21174 .00375 L
s
.24306 0 m
.24306 .00375 L
s
.30571 0 m
.30571 .00375 L
s
.33703 0 m
.33703 .00375 L
s
.36835 0 m
.36835 .00375 L
s
.43099 0 m
.43099 .00375 L
s
.46232 0 m
.46232 .00375 L
s
.49364 0 m
.49364 .00375 L
s
.55628 0 m
.55628 .00375 L
s
.5876 0 m
.5876 .00375 L
s
.61893 0 m
.61893 .00375 L
s
.68157 0 m
.68157 .00375 L
s
.71289 0 m
.71289 .00375 L
s
.74421 0 m
.74421 .00375 L
s
.80686 0 m
.80686 .00375 L
s
.83818 0 m
.83818 .00375 L
s
.8695 0 m
.8695 .00375 L
s
.93215 0 m
.93215 .00375 L
s
.96347 0 m
.96347 .00375 L
s
.99479 0 m
.99479 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .14046 m
.00625 .14046 L
s
[(0.2)] -0.0125 .14046 1 0 Mshowa
0 .25283 m
.00625 .25283 L
s
[(0.4)] -0.0125 .25283 1 0 Mshowa
0 .3652 m
.00625 .3652 L
s
[(0.6)] -0.0125 .3652 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(0.8)] -0.0125 .47757 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(1)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.1491 .61178 m
.1491 .61803 L
s
.27439 .61178 m
.27439 .61803 L
s
.39967 .61178 m
.39967 .61803 L
s
.52496 .61178 m
.52496 .61803 L
s
.65025 .61178 m
.65025 .61803 L
s
.77554 .61178 m
.77554 .61803 L
s
.90082 .61178 m
.90082 .61803 L
s
.125 Mabswid
.05513 .61428 m
.05513 .61803 L
s
.08645 .61428 m
.08645 .61803 L
s
.11778 .61428 m
.11778 .61803 L
s
.18042 .61428 m
.18042 .61803 L
s
.21174 .61428 m
.21174 .61803 L
s
.24306 .61428 m
.24306 .61803 L
s
.30571 .61428 m
.30571 .61803 L
s
.33703 .61428 m
.33703 .61803 L
s
.36835 .61428 m
.36835 .61803 L
s
.43099 .61428 m
.43099 .61803 L
s
.46232 .61428 m
.46232 .61803 L
s
.49364 .61428 m
.49364 .61803 L
s
.55628 .61428 m
.55628 .61803 L
s
.5876 .61428 m
.5876 .61803 L
s
.61893 .61428 m
.61893 .61803 L
s
.68157 .61428 m
.68157 .61803 L
s
.71289 .61428 m
.71289 .61803 L
s
.74421 .61428 m
.74421 .61803 L
s
.80686 .61428 m
.80686 .61803 L
s
.83818 .61428 m
.83818 .61803 L
s
.8695 .61428 m
.8695 .61803 L
s
.93215 .61428 m
.93215 .61803 L
s
.96347 .61428 m
.96347 .61803 L
s
.99479 .61428 m
.99479 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .14046 m
1 .14046 L
s
.99375 .25283 m
1 .25283 L
s
.99375 .3652 m
1 .3652 L
s
.99375 .47757 m
1 .47757 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(Modulation Transfer Function)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .58994 m
.02723 .54365 L
.02919 .51711 L
.03005 .50552 L
.03097 .49295 L
.03122 .48963 L
.03148 .484 L
.03195 .47191 L
.03286 .44811 L
.03488 .39571 L
.03679 .34638 L
.03762 .32481 L
.03853 .30126 L
.03877 .29492 L
.03903 .29072 L
.0395 .28391 L
.04043 .27045 L
.04247 .24073 L
.04425 .21493 L
.04518 .20136 L
.04569 .19394 L
.04617 .18702 L
.04644 .18497 L
.04673 .18497 L
.04735 .18495 L
.04844 .18493 L
.05058 .18488 L
.05165 .18486 L
.05267 .18484 L
.05311 .18483 L
.05359 .18482 L
.05383 .18483 L
.0541 .18497 L
.05458 .18521 L
.05645 .18619 L
.05842 .18721 L
.06011 .18808 L
.06057 .18832 L
.06106 .18858 L
.06153 .18755 L
.06195 .18535 L
.06608 .16381 L
.06989 .14525 L
.07344 .13097 L
.07523 .12376 L
.07572 .12179 L
.076 .1207 L
.07625 .11967 L
.07675 .11994 L
.0772 .12042 L
Mistroke
.08104 .12449 L
.08513 .12843 L
.08717 .13 L
.08909 .13147 L
.08993 .13212 L
.09082 .13279 L
.09128 .13315 L
.09155 .13245 L
.09179 .13174 L
.09269 .12916 L
.0997 .10935 L
.10161 .10485 L
.10369 .09996 L
.10464 .09771 L
.10516 .09649 L
.10565 .09534 L
.10607 .09436 L
.10651 .09403 L
.10701 .09454 L
.10746 .095 L
.11454 .10217 L
.11803 .1053 L
.11904 .1062 L
.11999 .10705 L
.12084 .10782 L
.12132 .10819 L
.12176 .10734 L
.12585 .0995 L
.12965 .09222 L
.13311 .08565 L
.13402 .08392 L
.13501 .08204 L
.13546 .08117 L
.13595 .08025 L
.13636 .07962 L
.13681 .07985 L
.13894 .08091 L
.14088 .08188 L
.14468 .08392 L
.14827 .08628 L
.15007 .08747 L
.15056 .0878 L
.15084 .08798 L
.15109 .08814 L
.15159 .08791 L
.15204 .08736 L
.15619 .08228 L
.15999 .07766 L
.16368 .07327 L
.16458 .0722 L
Mistroke
.16555 .07105 L
.16583 .07071 L
.1661 .07039 L
.16634 .07019 L
.16661 .07033 L
.1676 .07084 L
.17463 .07442 L
.17665 .07533 L
.17856 .07618 L
.18028 .07695 L
.18074 .07716 L
.18124 .07738 L
.18166 .07696 L
.18213 .07641 L
.19012 .06704 L
.19195 .06495 L
.19394 .06268 L
.19485 .06164 L
.19535 .06107 L
.19582 .06053 L
.19622 .06008 L
.19665 .06011 L
.19712 .06026 L
.19756 .06041 L
.20173 .06175 L
.20553 .06303 L
.20733 .06367 L
.20926 .06434 L
.2102 .06467 L
.21066 .06484 L
.21109 .06499 L
.21147 .06488 L
.21188 .06449 L
.21274 .06367 L
.21654 .06005 L
.22063 .05625 L
.22263 .05444 L
.22453 .05273 L
.22536 .05198 L
.22581 .05157 L
.22623 .05119 L
.22648 .05121 L
.22674 .05129 L
.2272 .05145 L
.22809 .05174 L
.23507 .05411 L
.2387 .05546 L
.2397 .05582 L
.24025 .05603 L
.24077 .05622 L
Mistroke
.24125 .0564 L
.24152 .05623 L
.24177 .05604 L
.24269 .05535 L
.24683 .05221 L
.25072 .0493 L
.25415 .04674 L
.25514 .04601 L
.25563 .04565 L
.25608 .04531 L
.25649 .04522 L
.25693 .04534 L
.25785 .04559 L
.2657 .04776 L
.26761 .04833 L
.26962 .04893 L
.27067 .04924 L
.27096 .04932 L
.27127 .04942 L
.27156 .04923 L
.27183 .04905 L
.27386 .04769 L
.27785 .04501 L
.28154 .04262 L
.28336 .04147 L
.28506 .04038 L
.28548 .04011 L
.28592 .03983 L
.2864 .03964 L
.28684 .03974 L
.28881 .04021 L
.29263 .04113 L
.29671 .0422 L
.29874 .04275 L
.29973 .04302 L
.30017 .04314 L
.30065 .04327 L
.30108 .04338 L
.30149 .04331 L
.30191 .04306 L
.30237 .04279 L
.30423 .04169 L
.31123 .03766 L
.3131 .03663 L
.31508 .03554 L
.31567 .03522 L
.31596 .03506 L
.31623 .03492 L
.31673 .03498 L
.31699 .03504 L
Mistroke
.31727 .03509 L
.31929 .0355 L
.32299 .03625 L
.32695 .03723 L
.32896 .03774 L
.32995 .038 L
.33039 .03811 L
.33087 .03823 L
.3313 .03832 L
.3317 .03812 L
.33258 .03767 L
.33444 .03673 L
.34143 .03344 L
.34337 .03263 L
.34518 .03187 L
.34565 .03168 L
.34609 .03149 L
.34634 .03143 L
.3466 .03148 L
.34707 .03157 L
.34913 .03196 L
.35618 .03351 L
.35792 .034 L
.35979 .03452 L
.36034 .03467 L
.36062 .03475 L
.36087 .03482 L
.36134 .0349 L
.36158 .03479 L
.36185 .03468 L
.36376 .03386 L
.36762 .03221 L
.36979 .03146 L
.37178 .03096 L
.37365 .03049 L
.37539 .03005 L
.37584 .02994 L
.37627 .02983 L
.37676 .02988 L
.3772 .02993 L
.37919 .03013 L
.38081 .03029 L
.38253 .03047 L
.38296 .03051 L
.38342 .03056 L
.38369 .03059 L
.38393 .03064 L
.38441 .03078 L
.38615 .03128 L
.38796 .0318 L
Mistroke
.38896 .03208 L
.3899 .03235 L
.39078 .0326 L
.39127 .03274 L
.39173 .03256 L
.39338 .03194 L
.39722 .03049 L
.39816 .03013 L
.39842 .03003 L
.39868 .02994 L
.39916 .0299 L
.39943 .0299 L
.39968 .02989 L
.40025 .02989 L
.40128 .02987 L
.40304 .02985 L
.40397 .02984 L
.40495 .02983 L
.40581 .02982 L
.40629 .02981 L
.40674 .02978 L
.40839 .02965 L
.41034 .0295 L
.41219 .02936 L
.41321 .02928 L
.41348 .02926 L
.41378 .02924 L
.41403 .02932 L
.41431 .0294 L
.41624 .02998 L
.41823 .03058 L
.41921 .03087 L
.42011 .03114 L
.42054 .03127 L
.42093 .03139 L
.42139 .03144 L
.42181 .0313 L
.42365 .03068 L
.42551 .03005 L
.42748 .02939 L
.42797 .02922 L
.4285 .02904 L
.42881 .02896 L
.42909 .029 L
.42963 .02908 L
.43161 .02938 L
.43345 .02966 L
.43445 .02981 L
.4354 .02996 L
.43581 .03002 L
Mistroke
.4362 .03008 L
.43665 .03001 L
.43706 .02993 L
.4389 .02958 L
.44073 .02923 L
.44268 .02886 L
.44326 .02875 L
.44354 .02869 L
.4438 .02866 L
.44429 .02881 L
.44482 .02897 L
.44681 .02958 L
.4486 .03012 L
.44958 .03042 L
.45052 .0307 L
.45094 .03083 L
.45138 .03088 L
.45187 .03073 L
.45233 .03059 L
.45398 .03008 L
.45578 .02952 L
.45772 .02892 L
.45826 .02876 L
.45855 .02867 L
.45883 .02862 L
.45931 .02872 L
.45985 .02882 L
.46185 .02923 L
.46377 .02962 L
.46478 .02983 L
.46533 .02994 L
.46585 .03005 L
.4663 .03012 L
.46679 .03001 L
.46782 .02978 L
.46963 .02938 L
.47153 .02896 L
.47246 .02875 L
.47292 .02865 L
.47333 .02856 L
.47373 .02847 L
.47411 .02857 L
.47495 .02882 L
.47671 .02934 L
.47864 .0299 L
.48044 .03043 L
.4809 .03057 L
.48134 .03065 L
.48158 .03058 L
.48185 .0305 L
Mistroke
.48231 .03037 L
.48437 .02977 L
.48614 .02926 L
.48711 .02898 L
.48803 .02871 L
.4884 .0286 L
.4888 .02851 L
.48923 .0286 L
.48963 .02869 L
.49141 .02906 L
.49328 .02945 L
.49505 .02981 L
.49552 .02991 L
.49603 .03002 L
.49629 .03006 L
.49658 .02999 L
.49709 .02988 L
.49894 .02948 L
.50068 .0291 L
.50164 .02889 L
.50255 .02869 L
.50296 .0286 L
.5034 .0285 L
.50388 .02846 L
.50432 .02858 L
.50594 .02904 L
.50785 .02957 L
.50987 .03014 L
.51038 .03028 L
.51093 .03043 L
.51124 .03052 L
.51152 .03045 L
.51208 .03029 L
.51412 .02974 L
.51601 .02922 L
.51701 .02895 L
.51756 .0288 L
.51807 .02866 L
.51851 .02853 L
.51899 .02852 L
.51927 .02858 L
.51953 .02863 L
.52001 .02873 L
.52181 .02909 L
.52369 .02947 L
.52461 .02966 L
.52546 .02983 L
.52593 .02993 L
.52644 .02995 L
.5267 .0299 L
Mistroke
.52694 .02984 L
.5275 .02973 L
.52935 .02933 L
.53109 .02897 L
.53273 .02862 L
.53317 .02853 L
.53364 .02843 L
.53388 .02844 L
.53415 .02851 L
.53463 .02864 L
.53635 .0291 L
.53823 .02959 L
.53925 .02986 L
.5402 .03012 L
.54062 .03023 L
.54101 .03033 L
.54147 .03034 L
.54188 .03023 L
.54372 .02975 L
.54557 .02927 L
.54754 .02876 L
.54803 .02863 L
.5483 .02856 L
.54856 .02849 L
.54886 .02846 L
.54914 .02852 L
.54969 .02863 L
.55167 .02902 L
.55355 .0294 L
.55533 .02975 L
.55581 .02984 L
.55607 .0299 L
.55631 .02992 L
.55658 .02986 L
.55687 .0298 L
.55737 .0297 L
.55923 .02931 L
.56097 .02895 L
.56261 .02861 L
.56305 .02852 L
.56352 .02843 L
.56376 .02839 L
.56403 .02845 L
.56451 .02858 L
.56624 .02901 L
.56811 .02949 L
.56914 .02975 L
.57009 .02999 L
.57051 .0301 L
.57091 .0302 L
Mistroke
.57136 .03026 L
.57178 .03015 L
.57362 .0297 L
.57547 .02924 L
.57744 .02875 L
.57793 .02863 L
.57846 .0285 L
.57877 .02844 L
.57904 .02849 L
.57959 .02859 L
.58157 .02897 L
.5834 .02932 L
.5844 .02951 L
.58534 .02969 L
.58573 .02977 L
.58614 .02984 L
.58659 .0298 L
.587 .02972 L
.58883 .02936 L
.59065 .02901 L
.5926 .02864 L
.59318 .02852 L
.59346 .02847 L
.59372 .02842 L
.59421 .02853 L
.59474 .02866 L
.59673 .02915 L
.59851 .02958 L
.59949 .02982 L
.60042 .03005 L
.60084 .03015 L
.60128 .03024 L
.60177 .03012 L
.60222 .03002 L
.60387 .02964 L
.606 .02915 L
.60704 .02892 L
.60799 .0287 L
.60845 .02859 L
.60887 .02855 L
.60931 .02862 L
.60979 .0287 L
.61173 .02902 L
.61364 .02934 L
.61465 .0295 L
.6152 .0296 L
.61572 .02968 L
.61616 .02976 L
.61665 .0297 L
.61691 .02966 L
Mistroke
.61718 .02962 L
.61768 .02954 L
.61949 .02925 L
.62112 .02899 L
.62202 .02884 L
.62287 .02871 L
.62335 .02863 L
.62362 .02859 L
.62387 .0286 L
.62431 .0287 L
.62478 .0288 L
.62656 .02921 L
.62841 .02962 L
.63016 .03002 L
.63062 .03013 L
.63112 .03024 L
.63141 .03023 L
.63167 .03017 L
.63218 .03006 L
.63402 .02967 L
.63575 .0293 L
.63666 .0291 L
.63762 .0289 L
.63802 .02881 L
.63846 .02872 L
.63893 .02868 L
.63938 .02875 L
.641 .02898 L
.64289 .02925 L
.64489 .02953 L
.64539 .0296 L
.64593 .02968 L
.64624 .02972 L
.64653 .02968 L
.64708 .02959 L
.64911 .02929 L
.65099 .02901 L
.65198 .02886 L
.65253 .02878 L
.65304 .0287 L
.65353 .02863 L
.6538 .02861 L
.65406 .02867 L
.65498 .02886 L
.65678 .02924 L
.65857 .02961 L
.65955 .02982 L
.66049 .03002 L
.66091 .0301 L
.66135 .03015 L
Mistroke
.66184 .03004 L
.6623 .02995 L
.66395 .02961 L
.66575 .02924 L
.66769 .02883 L
.66823 .02872 L
.66852 .02866 L
.6688 .02863 L
.66928 .0287 L
.66982 .02878 L
.67182 .02907 L
.67374 .02934 L
.67475 .02949 L
.6753 .02957 L
.67582 .02965 L
.67627 .0297 L
.67676 .02963 L
.67779 .02949 L
.67961 .02924 L
.6815 .02897 L
.68244 .02884 L
.68289 .02878 L
.6833 .02872 L
.68371 .02867 L
.68409 .02874 L
.68492 .02891 L
.68668 .02927 L
.68861 .02966 L
.69041 .03003 L
.69088 .03013 L
.69132 .03018 L
.69156 .03014 L
.69182 .03009 L
.69229 .03 L
.69434 .02963 L
.69612 .02931 L
.69709 .02913 L
.698 .02896 L
.69838 .02889 L
.69878 .02884 L
.69921 .02889 L
.69961 .02893 L
.70138 .02914 L
.70326 .02936 L
.70503 .02957 L
.7055 .02962 L
.70601 .02968 L
.70627 .0297 L
.70656 .02966 L
.70706 .0296 L
Mistroke
.70891 .02936 L
.71066 .02914 L
.71162 .02901 L
.71253 .0289 L
.71294 .02884 L
.71338 .02879 L
.71386 .02877 L
.7143 .02885 L
.71591 .02913 L
.71948 .02976 L
.72045 .02994 L
.72094 .03002 L
.72122 .03007 L
.72148 .03002 L
.72332 .02967 L
.72668 .02901 L
.72765 .02883 L
.72812 .02874 L
.72856 .02865 L
.72896 .02865 L
.72939 .02872 L
.73028 .02885 L
.73386 .02938 L
.7349 .02953 L
.7354 .0296 L
.73588 .02967 L
.7363 .02971 L
.73676 .02962 L
.73772 .02945 L
.73949 .02912 L
.74135 .02878 L
.74294 .02849 L
.74338 .02841 L
.74385 .02837 L
.74429 .02846 L
.74469 .02854 L
.74861 .02929 L
.74965 .02949 L
.7502 .0296 L
.7505 .02966 L
.75079 .02971 L
.75103 .02976 L
.7513 .02978 L
.75159 .02971 L
.75186 .02965 L
.75285 .02943 L
.75659 .02859 L
.7575 .02839 L
.758 .02828 L
.75848 .02817 L
Mistroke
.75874 .02813 L
.75903 .02819 L
.75954 .02831 L
.76053 .02854 L
.76414 .02936 L
.76513 .02959 L
.76567 .02971 L
.76594 .02977 L
.76619 .02983 L
.76667 .02976 L
.76719 .02968 L
.76811 .02953 L
.77011 .02921 L
.77199 .02891 L
.77303 .02874 L
.77332 .02869 L
.77362 .02864 L
.77388 .02865 L
.77416 .02869 L
.77612 .02898 L
.77813 .02928 L
.77911 .02943 L
.78002 .02956 L
.78085 .02969 L
.78126 .02974 L
.78172 .02968 L
.78357 .02945 L
.78555 .02921 L
.78659 .02908 L
.78769 .02894 L
.78815 .02889 L
.78865 .02882 L
.78893 .02885 L
.78919 .02889 L
.7897 .02896 L
.79154 .02923 L
.7934 .02949 L
.79441 .02964 L
.79536 .02978 L
.79577 .02984 L
.79616 .02989 L
.79662 .02982 L
.79703 .02975 L
.79887 .02939 L
.80071 .02904 L
.80266 .02866 L
.80315 .02857 L
.80341 .02852 L
.80368 .02847 L
.80399 .02851 L
Mistroke
.80426 .02856 L
.80481 .02865 L
.8068 .02898 L
.80866 .0293 L
.80958 .02945 L
.81043 .02959 L
.8109 .02967 L
.8114 .02969 L
.81191 .0296 L
.81246 .02949 L
.81431 .02915 L
.81605 .02882 L
.81701 .02865 L
.81792 .02848 L
.81833 .0284 L
.81877 .02834 L
.81924 .02843 L
.81969 .02852 L
.8213 .02882 L
.82321 .02919 L
.82522 .02957 L
.82573 .02967 L
.82601 .02973 L
.82628 .02976 L
.82659 .02972 L
.82688 .02969 L
.82743 .02963 L
.82947 .0294 L
.83125 .0292 L
.83223 .02909 L
.83315 .02898 L
.83362 .02893 L
.83389 .02894 L
.83414 .02897 L
.83523 .0291 L
.83715 .02933 L
.83896 .02954 L
.83995 .02966 L
.84044 .02972 L
.84089 .02977 L
.84132 .02979 L
.84177 .02969 L
.84271 .02947 L
.84437 .02911 L
.84618 .0287 L
.84718 .02848 L
.84812 .02827 L
.84838 .02821 L
.84866 .02815 L
.84896 .0282 L
Mistroke
.84924 .02826 L
.85026 .02849 L
.85226 .02894 L
.85417 .02937 L
.85521 .02961 L
.85572 .02972 L
.85619 .02983 L
.85645 .0298 L
.8567 .02977 L
.85724 .0297 L
.8584 .02955 L
.86043 .02929 L
.86222 .02907 L
.86313 .02895 L
.86337 .02892 L
.86364 .02888 L
.86412 .02893 L
.8662 .02918 L
.86812 .02942 L
.86909 .02954 L
.87012 .02967 L
.87062 .02973 L
.87109 .02979 L
.87151 .02974 L
.87197 .02965 L
.87401 .02926 L
.87617 .02885 L
.87709 .02868 L
.87807 .02849 L
.87836 .02844 L
.87864 .02838 L
.87888 .02841 L
.87915 .02847 L
.88016 .02868 L
.88205 .02909 L
.88383 .02947 L
.88466 .02965 L
.88555 .02984 L
.88601 .02994 L
.88627 .02997 L
.88652 .02992 L
.8874 .02977 L
.88947 .02941 L
.89136 .02908 L
.89231 .02892 L
.89281 .02883 L
.89309 .02878 L
.89335 .02873 L
.89381 .02869 L
.89406 .02873 L
Mistroke
.89432 .02877 L
.89522 .0289 L
.89737 .02923 L
.89936 .02953 L
.90032 .02967 L
.90079 .02974 L
.90123 .0298 L
.90173 .02975 L
.90227 .02969 L
.90322 .02959 L
.90522 .02938 L
.90628 .02927 L
.90742 .02915 L
.90794 .0291 L
.90843 .02905 L
.90887 .02904 L
.90935 .02908 L
.91115 .02924 L
.91318 .02942 L
.91417 .02951 L
.91508 .02959 L
.91552 .02962 L
.91592 .02966 L
.91634 .02967 L
.91681 .02962 L
.91867 .02943 L
.92074 .02922 L
.92262 .02903 L
.92309 .02899 L
.92358 .02894 L
.92384 .02894 L
.92412 .02897 L
.92462 .02902 L
.9265 .02921 L
.92862 .02942 L
.92966 .02953 L
.93012 .02958 L
.93063 .02963 L
.9311 .02967 L
.93153 .02964 L
.93199 .02958 L
.93249 .02952 L
.93451 .02925 L
.9362 .02903 L
.9371 .02892 L
.93805 .02879 L
.93833 .02875 L
.9386 .02872 L
.9391 .02876 L
.93957 .02882 L
Mistroke
.94007 .02889 L
.9422 .02917 L
.94417 .02943 L
.94513 .02955 L
.94559 .02961 L
.94602 .02967 L
.94644 .02965 L
.9469 .02958 L
.94775 .02946 L
.94961 .02917 L
.95169 .02886 L
.95267 .02871 L
.9531 .02864 L
.95358 .02857 L
.95404 .02861 L
.95453 .02868 L
.95557 .02884 L
.95745 .02913 L
.95847 .02928 L
.95958 .02945 L
.96008 .02953 L
.96062 .02961 L
.96108 .02968 L
.96134 .02968 L
.96159 .02964 L
.96527 .02907 L
.96691 .02882 L
.96781 .02869 L
.96824 .02862 L
.96864 .02856 L
.96907 .02861 L
.96954 .02869 L
.97053 .02885 L
.97227 .02913 L
.97619 .02976 L
Mfstroke
1 0 0 r
.02381 .58994 m
.02723 .5892 L
.02919 .58877 L
.03005 .58858 L
.0305 .58848 L
.03097 .58838 L
.03121 .58833 L
.03148 .58822 L
.03195 .58798 L
.03286 .58752 L
.03488 .58649 L
.03853 .58463 L
.05458 .57632 L
.06993 .56785 L
.0847 .5593 L
.1004 .55 L
.11553 .541 L
.13008 .53229 L
.14556 .52304 L
.16047 .5141 L
.17631 .50465 L
.19157 .49549 L
.20626 .48673 L
.22188 .47737 L
.23692 .46841 L
.25139 .45974 L
.26679 .45057 L
.28161 .44169 L
.29737 .43231 L
.31255 .42322 L
.32715 .41453 L
.34268 .40523 L
.35764 .39633 L
.37202 .38773 L
.38734 .37862 L
.40208 .3698 L
.41775 .36048 L
.43284 .35145 L
.44736 .34282 L
.46281 .33358 L
.47769 .32473 L
.4935 .31528 L
.50873 .30623 L
.52338 .29746 L
.53897 .28819 L
.55398 .27921 L
.56841 .27063 L
.58378 .26144 L
.59857 .25265 L
.6143 .24323 L
Mistroke
.62944 .23423 L
.64401 .22551 L
.65952 .21629 L
.67444 .20734 L
.6903 .19792 L
.70559 .18875 L
.72029 .18002 L
.73593 .17062 L
.75099 .16169 L
.76548 .15297 L
.7809 .14382 L
.79574 .13487 L
.81152 .12552 L
.82672 .11635 L
.84134 .10769 L
.8569 .09829 L
.87187 .08943 L
.88627 .0807 L
.90161 .07173 L
.91637 .06284 L
.93206 .05397 L
.94718 .0453 L
.96171 .03813 L
.97619 .03063 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[76]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008oooool2o`0001Sooooo1Ol00003ooooo`;o00005oooool3o`0000?ooooo0_l0000Foooo
o`?o00001?ooool2o`0001Kooooo0ol00004ooooo`;o00004oooool3o`0000Cooooo0_l00004oooo
o`;o00004?ooool3o`0000;ooooo1Ol00003ooooo`;o00004?ooool3o`0000Cooooo0ol00003oooo
o`;o00007?ooool002;ooooo00Co0000oooooooooooo00006?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0001Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
01Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00013o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`00013ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool06Oooool002;ooooo00Co0000oooooooooooo00006Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0001Cooooo1Ol00002ooooo`04o`000?ooooooooooo`0001Co
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Cooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00013ooooo00Co0000
oooooooooooooooo1Ol00002ooooo`04o`000?ooooooooooo`0001_ooooo000Rooooo`04o`000?oo
ooooooooo`0001[ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01;o
oooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0000Dooooo`Co00000oooool0
1?l0003oooooooooool0000Eooooo`?o00000oooool01?l0003oooooooooool0000Cooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000@oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo00kooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`0Iooooo`008_ooool01?l0003oooooooooool0000Gooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Eooooo`03o`000?oooooo0000
00?ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`0001Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001?o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`00013ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo
00Co0000oooooooooooo00006oooool002;ooooo00Co0000oooooooooooo00005oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00005_ooool2o`0000?ooooo00Co0000
oooooooooooo00005Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0001Cooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000oooooo0_l00005ooooo`;o
00000oooool01?l0003oooooooooool0000Kooooo`008oooool2o`0001Wooooo0ol00004ooooo`;o
00006?ooool00ol0003oooooooooo`02ooooo`;o00005oooool2o`0000Cooooo0_l0000Fooooo`?o
00001?ooool2o`0001Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0000Aooooo`03
o`000?oooooooooo00;ooooo0ol00004ooooo`;o00004Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo0_l0000Looooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`007_oooooho`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo0?Cooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`08
ooooo`005oooool2o`0000Gooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`08oooo
o`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?Cooooo00?o0000oooo
ooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3doooo
o`03o`000?oooooooooo00Sooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo0_l0001Coooo
o`;o00001?ooool5o`0000;oooooS_l00002ool000Cooooo0_l0000:ooooo`005_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo04_ooooo0_l00004ooooo`So00001?ooool2o`00
08gooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`08ooooo`005_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool00_ooool2o`00
00;ooooo1?l0002Iooooo`;oo`002?ooool00ol0003oooooooooo`08ooooo`005oooool2o`0000Go
oooo00?o0000ooooooooool0@_ooool7o`0009oooooo0_oo000:ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo03cooooo1?l000000ooooooo0000o`00002Sooooo`;oo`00
3?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0eooooo`;o00001?oo
ool01?l0003oooooooooooooool2o`000:?ooooo0_oo000>ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?l0002Wooooo`;oo`004?oo
ool00ol0003oooooooooo`08ooooo`007_ooool2o`0003?ooooo0_l00004ooooo`;o0000Y_ooool2
ool0017ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0]ooooo`Go0000[?ooool2ool0
01Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0:Wooooo00?oo`00ooooooooool05?ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00001?ooool00ol0003ooooo
ooooo`2/ooooo`;oo`005oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool0[Oooool00ooo003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o0000[_ooool00ooo003oooooooooo`0H
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00007oooool4o`000003ooooool0003o0000
0;;ooooo0_oo000Jooooo`;o00002_ooool001kooooo00?o0000ooooooooool07_ooool01Ol0003o
oooooooooooooooo00000;;ooooo0_oo000Mooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0/oooool2ool001oooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0;;ooooo00?oo`00ooooooooool07oooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`0Gooooo`;o00000oooool00ol0003oooooooooo`2aooooo`;oo`008_oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool0[oooool2ool002Cooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool05_ooool01?l0003oooooooooooooool2o`000;3ooooo0_oo000V
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00005oooool00ol0003oooooooooo`2aoooo
o`;oo`009oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0[oooool2ool002[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:oooooo00?oo`00ooooooooool0
:_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0?ooooo`?o00000ooo
ool00ol0003oooooooooo`2^ooooo`03ool00?oooooooooo02_ooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo0:cooooo0_oo000^ooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00001?ooool0
1?l0003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`03o`000:kooooo00?oo`00ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`002_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
3oooool01Ol0003ooooooooooooooooo00000:gooooo0_oo000aooooo`03o`000?oooooooooo00So
oooo000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`00013o
oooo00?o0000ooooooooool0[Oooool2ool003;ooooo0_l0000:ooooo`002_ooool01?l0003ooooo
ooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`2/ooooo`;oo`00=Oooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0:[ooooo0_oo000gooooo`03o`000?oooooooooo00Sooooo000:ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0ZOooool00ooo003oooooooooo`0gooooo`03o`000?oooooo
oooo00Sooooo000;ooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`2Xooooo`03ool00?oooooooooo03Sooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Xooooo`03ool00?oooooooooo03Wo
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2Vooooo`;oo`00??ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000kooooo00?o
0000ooooooooool0Y?ooool2ool003gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo0:;ooooo0_oo0010ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0XOooool2ool004;ooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Oooooo`;o
o`00A?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`08ooooo`?o0000
00?oooooo`000?ooool0W_ooool2ool004Kooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`02o`0009kooooo00?oo`00ooooooooool0A_oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo09oooooo00?oo`00ooooooooool0Aoooool00ol0003oooooooooo`08ooooo`007_ooool2o`00
00Wooooo00?o0000ooooooooool0W_ooool00ooo003oooooooooo`17ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Looooo`;oo`00Boooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo09[ooooo
0_oo001=ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0V?ooool2ool004oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2Fooooo`;oo`00DOooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo09Cooooo0_oo001Coooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0T_ooool2ool005Gooooo00?o0000ooooooooool02?ooool001kooooo0_l00009ooooo`03o`00
0?oooooooooo093ooooo0_oo001Fooooo`;o00002_ooool001kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`2?ooooo`03ool00?oooooooooo05Oooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2?ooooo`03ool00?oooooo
oooo05Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2=ooooo`;oo`00Foooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo08cooooo00?oo`00ooooooooool0Foooool00ol0003o
ooooooooo`08ooooo`002oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2:ooooo`;oo`00G_ooool00ol0003ooooo
ooooo`08ooooo`002_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`28ooooo`;oo`00H?ooool00ol0003ooooo
ooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`Go00001?ooool2o`0000Sooooo
00?o0000ooooooooool0Q_ooool2ool0067ooooo0_l0000:ooooo`002_ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`24ooooo`;oo`00I?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`22ooooo`;oo`00I_ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003ooooo
ooooool00009ooooo`;o00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo087o
oooo00?oo`00ooooooooool0I_ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo083ooooo
00?oo`00ooooooooool0Ioooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo07kooooo0_oo001Zooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0OOooool00ooo003oooooooooo`1Z
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00002?ooool00ol0003oooooooooo`1koooo
o`;oo`00K?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0NOooool2ool006oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1gooooo`;oo`00LOooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Gooooo0_oo001cooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0M?ooool2
ool007Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1cooooo`03ool00?oooooooooo07Gooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1aooooo`;oo`00N?ooool00ol0003o
ooooooooo`08ooooo`007_ooool2o`0000Oooooo00?o0000ooooooooool0L?ooool00ooo003ooooo
ooooo`1gooooo`;o00002_ooool001kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1_ooooo`03ool00?oooooooooo07Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1]ooooo`;oo`00O?ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06_ooooo0_oo001noooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0JOooool2ool0083ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Wooooo`;oo`00P_ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Gooooo0_oo0024ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`;o00001oooool00ol0003oooooooooo`1Sooooo`;oo`00QOooool2
o`0000[ooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H_ooool00ooo
003oooooooooo`26ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0HOooool00ooo003oooooooooo`27ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H?ooool00ooo003ooooo
ooooo`28ooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05kooooo0_oo
002;ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
G?ooool2ool008gooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Jooooo`;oo`00Soooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003ooooo
ooooool00007ooooo`Co00001Oooool2o`0000Oooooo00?o0000ooooooooool0F?ooool2ool0093o
oooo0_l0000:ooooo`002_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Fooooo`;oo`00Toooool00ol0003o
ooooooooo`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo09?o
oooo00?o0000ooooooooool02?ooool000_ooooo0_l0000:ooooo`;o00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo05?ooooo0_oo002Fooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0DOooool2ool009Sooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1?
ooooo`;oo`00V_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo04kooooo00?oo`00ooooooooool0V_ooool00ol0003oooooooooo`08oooo
o`007_ooool2o`0000Oooooo00?o0000ooooooooool0COooool00ooo003oooooooooo`2Jooooo`;o
00002_ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1;ooooo`;oo`00
W_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04[ooooo00?oo`00ooooooooool0W_ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo0_oo002Qooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A_ooool2ool0
0:?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`14ooooo`;oo`00YOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo04;ooooo0_oo002Wooooo`03o`000?oooooooooo00Sooooo
000Nooooo`;o00001_ooool00ol0003oooooooooo`11ooooo`;oo`00Z?ooool2o`0000[ooooo000N
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@?ooool00ooo003oooooooooo`2Y
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0?oooool00ooo003oooooooooo`2Zooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool2ool00:gooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0looooo`03ool0
0?oooooooooo0:gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0jooooo`;oo`00/?ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo0_oo002booooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o00001_ooool00ol0003oooooooooo`0fooooo`;oo`00/oooool2o`00
00[ooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool2ool00;Ko
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0booooo`;oo`00^?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo033ooooo0_oo002jooooo`03o`000?oooooooooo00Sooooo000;
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02oooooo00?oo`00ooooooooool0^_ooool00ol0003oooooooooo`08
ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02kooooo00?oo`00ooooooooool0^ooo
ool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02gooooo
00?oo`00ooooooooool0_?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003ooooooooo
ool00008ooooo`?o00001Oooool2o`0000Kooooo00?o0000ooooooooool0:oooool2ool00;kooooo
0_l0000:ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo0_oo0031ooooo`03
o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool2ool0
0<?ooooo00?o0000ooooooooool02?ooool000_ooooo0_l00009ooooo`?o00001Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Gooooo0_oo0035ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08oooool2ool00<Oooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Qooooo`;oo`00bOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool0bOooool00ol0003oooooooooo`08
ooooo`007_ooool2o`0000Gooooo00?o0000ooooooooool08?ooool00ooo003oooooooooo`39oooo
o`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03
ool00?oooooooooo0<_ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Mooooo`;oo`00c_ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo0_oo003@ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool2
ool00=;ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Gooooo`;oo`00e?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Gooooo0_oo003Fooooo`03o`000?oooooooooo00So
oooo000Nooooo`;o00001Oooool00ol0003oooooooooo`0Cooooo`;oo`00eoooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ooo003ooooooooo
o`3Hooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04Oooool00ooo003oooooooooo`3Iooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3Joooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03_ooool2ool00=gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0<ooooo`;oo`00goooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0_oo003Qooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`;oo`00h_ooool2
o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool2ool0
0>Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`;oo`00ioooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo0_oo003Yooooo`03o`000?oooooooooo00Sooooo
000Fooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;oo`00
joooool00ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00Co0000ooooooooooooo`00kOooool00ol0003oooooooooo`08ooooo`005ooo
ool00ol0003oooooooooo`04ooooo`;o00001?ooool4ool00>cooooo0_l0000:ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool02?ooool0
01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo
00Sooooo000Fooooo`;o00001_ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00So
oooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m?ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000[ooooo000Noooo
ooSo00002_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool004Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00000oooool4o`00
00?ooooo0_l000000ooooooo0000o`000004o`0000;ooooo1?l00003ooooo`;o00000_ooool5o`00
00;ooooo0ol00002ooooo`?o000000?oooooo`000?l000001oooool3o`0000;ooooo0ol00004oooo
o`Co000000Goooooo`000?l0003o0000ooooo`06o`0000;ooooo1Ol00002ooooo`?o00000_ooool3
o`0000Wooooo0ol00005ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?oo
ool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`00
000cooooo`00AOooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003ooooo
o`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooo
oooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0003Cooooo0015ooooo`07o`000?ooooooooooooooool0
003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000001?ooool3o`0000?ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool3o`0000?o
oooo00Co0000oooooooooooo00000_ooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00002
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo03;ooooo0015ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oo
oooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`02ooooo`;o00000oooool01?l0003oooooooooool00003ooooo`06o`00
0?ooooooooooo`000?oooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_l0000:ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool01?l0003oooooooooool00006ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo03;ooooo0015
ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000?ooooo0ol00002ooooo`;o000000?o
ooooo`000?l000000oooool00ol0003oooooooooo`02ooooo`;o00000oooool4o`0000;ooooo0ol0
0004ooooo`?o00000_ooool4o`0000Sooooo00Ko0000ooooool0003oooooo`000?ooool2o`000003
ooooool0003o000000;ooooo0_l00003ooooo`Co00000oooool4o`0000;ooooo1?l00002ooooo`?o
00000_ooool2o`000003ooooool0003o000000Sooooo00?o0000ooooooooool00_ooool2o`000004
ooooool0003o0000ooooo`Co00000oooool3o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`00
00;ooooo1?l0000eooooo`00AOooool2o`000003ooooool0003o000000[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooool0
003oooooo`00000Kooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00005?ooool0
0ol0003oooooooooo`17ooooo`00AOooool01?l0003oooooooooooooool2o`0000Sooooo0_l00008
ooooo`?o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo1Ol0000L
ooooo`;o00004oooool5o`0001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`10
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-23.4337, -0.137062, \
0.645848, 0.00720095}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(40.37999999999988`\ Second\), ",", 
        RowBox[{"{", 
          
          RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
            ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
            ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
            ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                    1, #1\ 0.9` + 0.1`] &)\)\), 
            ",", \(ComponentNumber \[Rule] 5\), 
            ",", \(CosineCompensation \[Rule] True\), 
            ",", \(DiffractionSpotSize \[Rule] {0.1261948886085015`, 
                0.12624689038504655`}\), ",", \(Energy \[Rule] 100.`\), 
            ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
            ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
            ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
            ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\),
             ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
                  0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
            ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
            ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
            ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
            ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
            ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 
                  0, 1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
            ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
                SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
            ",", \(FilterTrace \[Rule] True\), 
            ",", \(FindImagePoint \[Rule] True\), 
            ",", \(FindPupils \[Rule] Automatic\), 
            ",", \(FocalFraction \[Rule] 0\), 
            ",", \(FocalLength \[Rule] 50.218237368297935`\), 
            ",", \(FrequencyCutoff \[Rule] {304.0619384331368`, 
                303.93423730280796`}\), 
            ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
            ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
            ",", \(GeometricPointSpreadFunction \[Rule] False\), 
            ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
            ",", \(ImagePoint \[Rule] {207.28232192993164`, 0, 0}\), 
            ",", \(ImageSampleSize \[Rule] {0.0016604590606381776`, 
                0.001661143294540086`}\), ",", 
            RowBox[{"ImagingOptics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      
                      TagBox[\(Move[
                          PlanoConvexLens[{f1, 100}, 50, 
                            9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                        HoldForm],
                      FontColor->RGBColor[0, 0.392187, 0]],
                    DisplayForm], ",", 
                  TagBox[
                    StyleBox[
                      TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                        HoldForm],
                      FontColor->RGBColor[0, 0.392187, 0]],
                    DisplayForm], ",", 
                  TagBox[
                    StyleBox[
                      
                      TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 
                          100.5`]\),
                        HoldForm],
                      FontColor->RGBColor[0, 0.392187, 0]],
                    DisplayForm], ",", 
                  TagBox[
                    StyleBox[
                      
                      TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                            104}, {GraphicDesign \[Rule] Off}]\),
                        HoldForm],
                      FontColor->RGBColor[0, 0.392187, 0]],
                    DisplayForm]}], "}"}]}], 
            ",", \(IntensityScale \[Rule] 1\), 
            ",", \(IntensitySetting \[Rule] Automatic\), 
            ",", \(IntensityTransform \[Rule] True\), 
            ",", \(InterceptHole \[Rule] True\), 
            ",", \(InterpolationOrder \[Rule] 1\), 
            ",", \(KernelScale \[Rule] Relative\), 
            ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
                  12.031844948762183`}, {\(-0.019913084417241732`\), 
                  0.8720142520854433`}}\), ",", 
            RowBox[{"ModulationTransferFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-153.22806346236814`\), 
                      152.0309692165684`}, {\(-153.1637101368481`\), 
                      151.96711865140398`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(NormalizePlot \[Rule] True\), 
            ",", \(NumberOfPoints \[Rule] 128\), ",", 
            RowBox[{"ObjectSource", "\[Rule]", 
              TagBox[
                StyleBox[
                  TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], ",", \(Offset \[Rule] 112.44620808978891`\), 
            ",", \(OpticalLengthFunction \[Rule] OpticalLengthFunction\), 
            ",", \(OpticalMedium \[Rule] Air\), ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(CompiledFunction[
                  If[#1 == 0 && #2 == 0, 
                    0.000022271117373179214`, \(-6.853627285348719`\) - 
                      3.532109641994116`*^-9\ Cos[
                          2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                      1.9515319104050795`*^-10\ Cos[
                          4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                      10.310895376241149`\ \((\(-1\) + 
                            0.013990424917235709`\ \((#1\^2 + #2\^2)\))\) - 
                      5.251099192578527`*^-7\ Cos[
                          2\ ArcTan[#1, #2]]\ \((\(-0.020985637375853565`\)\ \
\((#1\^2 + #2\^2)\) + 0.0001957319893648098`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                      3.4781206500308235`\ \((1 - 
                            0.04197127475170713`\ \((#1\^2 + #2\^2)\) + 
                            0.0002935979840472147`\ \((#1\^2 + #2\^2)\)\^2)\) \
+ 4.27139394586925`*^-6\ Cos[
                          4\ ArcTan[#1, #2]]\ \((\(-0.00024466498670601227`\)\
\ \((#1\^2 + #2\^2)\)\^2 + 
                            2.0537802758321623`*^-6\ \((#1\^2 + \
#2\^2)\)\^3)\) - 3.396256590938641`*^-7\ Cos[
                          2\ ArcTan[#1, #2]]\ \((0.04197127475170713`\ \
\((#1\^2 + #2\^2)\) - 0.000978659946824049`\ \((#1\^2 + #2\^2)\)\^2 + 
                            5.134450689580406`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) \
- 0.02108223618211115`\ \((\(-1\) + 
                            0.08394254950341426`\ \((#1\^2 + #2\^2)\) - 
                            0.0014679899202360734`\ \((#1\^2 + #2\^2)\)\^2 + 
                            6.845934252773875`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) \
- 7.380096153526266`*^-8\ Cos[
                          6\ ArcTan[#1, #2]]\ \((\(-2.396076988470856`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 1.9155505830353006`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                      3.180054365542885`*^-6\ Cos[
                          4\ ArcTan[#1, #2]]\ \((0.0007339949601180367`\ \
\((#1\^2 + #2\^2)\)\^2 - 0.000014376461930825136`\ \((#1\^2 + #2\^2)\)\^3 + 
                            6.704427040623552`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) \
- 1.291385970907799`*^-7\ Cos[
                          2\ ArcTan[#1, #2]]\ \((\(-0.06995212458617854`\)\ \
\((#1\^2 + #2\^2)\) + 0.0029359798404721468`\ \((#1\^2 + #2\^2)\)\^2 - 
                            0.00003594115482706284`\ \((#1\^2 + #2\^2)\)\^3 + 
                            1.3408854081247104`*^-7\ \((#1\^2 + \
#2\^2)\)\^4)\) - 0.0002074059263440704`\ \((1 - 
                            0.13990424917235708`\ \((#1\^2 + #2\^2)\) + 
                            0.00440396976070822`\ \((#1\^2 + #2\^2)\)\^2 - 
                            0.00004792153976941712`\ \((#1\^2 + #2\^2)\)\^3 + 
                            1.6761067601558881`*^-7\ \((#1\^2 + \
#2\^2)\)\^4)\)], "-CompiledCode-"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {112.43537240553266`, 
                112.44620808978891`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"PointSpreadFunction", "\[Rule]", 
                    RowBox[{"(", 
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"ModulationTransferFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(PaddingFactor \[Rule] Automatic\), 
            ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
            RowBox[{"PerfectModulationTransferFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-153.22806346236814`\), 
                      152.0309692165684`}, {\(-153.1637101368481`\), 
                      151.96711865140398`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"PerfectPhaseTransferFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-153.22806346236814`\), 
                      152.0309692165684`}, {\(-153.1637101368481`\), 
                      151.96711865140398`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-0.10460892082020519`\), 
                      0.10626937988084338`}, {\(-0.10465202755602541`\), 
                      0.1063131708505655`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"PhaseTransferFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-153.22806346236814`\), 
                      152.0309692165684`}, {\(-153.1637101368481`\), 
                      151.96711865140398`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(Plot2D \[Rule] True\), 
            ",", \(PlotPoints \[Rule] 64\), ",", 
            RowBox[{"PointSpreadFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-0.10460892082020519`\), 
                      0.10626937988084338`}, {\(-0.10465202755602541`\), 
                      0.1063131708505655`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
                  0}, {103.07278133146767`, 0, 0}}\), 
            ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
            ",", \(RayBoundary \[Rule] {{\(-8.4562214163056`\), 
                  8.4562214163056`}, {\(-8.452646568455712`\), 
                  8.452646568455712`}}\), 
            ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
            ",", \(RenderedParameters \[Rule] {ModulationTransferFunction, 
                PointSpreadFunction, OpticalPathDifference}\), 
            ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
                WaveFrontIntensity}\), 
            ",", \(ResidualFitError \[Rule] 7.313862904893167`*^-7\), 
            ",", \(SampleFactor \[Rule] 2\), 
            ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
                  82.9255011275954`, 
                Astigmatism \[Rule] 0.0000417323567305451`, 
                FieldCurvature \[Rule] \(-0.24683256227325023`\), 
                Distortion \[Rule] \(-3.777962952267033`*^-13\), 
                Coma \[Rule] 1.3460273542456333`*^-12}\), 
            ",", \(ShowPerfectCase \[Rule] True\), 
            ",", \(SignalPlotCutoff \[Rule] 0.01`\), 
            ",", \(SmoothKernelRange \[Rule] 3\), 
            ",", \(SmoothKernelSize \[Rule] 1.25`\), 
            ",", \(SourceID \[Rule] 584\), ",", \(SpatialScale \[Rule] 1\), 
            ",", \(StrehlRatio \[Rule] 0.015686737510906584`\), 
            ",", \(SurfaceNumber \[Rule] 1\), 
            ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
            ",", \(WaveFrontID \[Rule] 1\), ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.347295107870586`\), 
                      11.347295107870586`}, {\(-11.343720260020696`\), 
                      11.343720260020696`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
            ",", \(ZernikeFit \[Rule] True\), 
            ",", \(ZernikeOrder \[Rule] 8\)}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[76]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
MTF[sys3D, FindImagePoint->True, FocalFraction->0, NumberOfPoints->128, \
Plot2D->False]\
\>", "Input",
  CellLabel->"In[77]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.14862 .19854 -11.9131 -9 ]
[.14862 .19854 .08693 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.53437 .04684 -5.21687 -9 ]
[.53437 .04684 .78313 0 ]
[.76879 .09908 0 -6.15987 ]
[.76879 .09908 12 2.84013 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93374 .35168 0 -5.92116 ]
[.93374 .35168 6 3.07884 ]
[.02106 .28428 -24 -2.75851 ]
[.02106 .28428 0 6.24149 ]
[.01243 .33833 -18 -2.80426 ]
[.01243 .33833 0 6.19574 ]
[.0035 .3943 -24 -2.85182 ]
[.0035 .3943 0 6.14818 ]
[-0.00575 .4523 -18 -2.90127 ]
[-0.00575 .4523 0 6.09873 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15783 .20788 m
.16244 .21256 L
s
[(-5)] .14862 .19854 .98551 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54216 .05739 m
.54606 .06267 L
s
[(5)] .53437 .04684 .73896 1 Mshowa
.125 Mabswid
.19384 .19379 m
.19657 .19662 L
s
.23036 .17949 m
.23305 .18236 L
s
.26739 .16499 m
.27004 .1679 L
s
.30496 .15028 m
.30757 .15322 L
s
.38173 .12022 m
.38425 .12323 L
s
.42095 .10486 m
.42344 .10791 L
s
.46076 .08927 m
.4632 .09236 L
s
.50116 .07345 m
.50355 .07658 L
s
.12233 .22179 m
.12512 .22456 L
s
.08731 .2355 m
.09014 .23824 L
s
.05276 .24903 m
.05563 .25173 L
s
.58379 .0411 m
.58607 .0443 L
s
.62604 .02455 m
.62828 .02779 L
s
.66894 .00775 m
.67112 .01103 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75648 .10363 m
.75033 .1059 L
s
[(-5)] .76879 .09908 -1 .36886 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92123 .35563 m
.91497 .35761 L
s
[(5)] .93374 .35168 -1 .31581 Mshowa
.125 Mabswid
.77494 .13185 m
.77123 .1332 L
s
.7929 .15934 m
.7892 .16066 L
s
.8104 .18611 m
.80669 .18741 L
s
.82746 .21219 m
.82374 .21348 L
s
.86028 .2624 m
.85655 .26365 L
s
.87608 .28657 m
.87234 .28781 L
s
.8915 .31015 m
.88775 .31137 L
s
.90654 .33317 m
.90279 .33437 L
s
.73752 .07462 m
.73383 .076 L
s
.71803 .04481 m
.71435 .04622 L
s
.69799 .01416 m
.69432 .01559 L
s
.93557 .37757 m
.93181 .37874 L
s
.94957 .39899 m
.94581 .40015 L
s
.96326 .41992 m
.95949 .42106 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03329 .27954 m
.03941 .27717 L
s
[(0.15)] .02106 .28428 1 -0.387 Mshowa
.02471 .3337 m
.03085 .33139 L
s
[(0.2)] .01243 .33833 1 -0.37683 Mshowa
.01582 .38979 m
.02198 .38753 L
s
[(0.25)] .0035 .3943 1 -0.36626 Mshowa
.00661 .4479 m
.01279 .44571 L
s
[(0.3)] -0.00575 .4523 1 -0.35527 Mshowa
.125 Mabswid
.0316 .29022 m
.03527 .28881 L
s
.0299 .30098 m
.03357 .29957 L
s
.02818 .31181 m
.03186 .31041 L
s
.02645 .32272 m
.03013 .32132 L
s
.02296 .34476 m
.02664 .34338 L
s
.02119 .3559 m
.02488 .35452 L
s
.01941 .36712 m
.02311 .36575 L
s
.01762 .37841 m
.02132 .37705 L
s
.01401 .40125 m
.01771 .3999 L
s
.01218 .41279 m
.01588 .41145 L
s
.01034 .42441 m
.01404 .42308 L
s
.00848 .43611 m
.01219 .43479 L
s
.03497 .26893 m
.03864 .2675 L
s
.03664 .25839 m
.04031 .25696 L
s
.00473 .45978 m
.00844 .45847 L
s
.00283 .47174 m
.00655 .47044 L
s
.00092 .48379 m
.00464 .4825 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .325 .301 r
.39874 .64152 .40454 .62032 .41172 .64818 .40575 .67526 Metetra
0 .451 .171 r
.40575 .67526 .41172 .64818 .41929 .66868 .41323 .70021 Metetra
.002 .539 0 r
.41323 .70021 .41929 .66868 .42721 .68116 .42116 .71553 Metetra
.14 .593 0 r
.42116 .71553 .42721 .68116 .4354 .68714 .4294 .72302 Metetra
.224 .622 0 r
.4294 .72302 .4354 .68714 .44375 .68892 .43784 .72544 Metetra
.266 .635 0 r
.43784 .72544 .44375 .68892 .4522 .68847 .44639 .72517 Metetra
.286 .641 0 r
.44639 .72517 .4522 .68847 .46069 .68701 .45501 .72369 Metetra
.295 .644 0 r
.45501 .72369 .46069 .68701 .46923 .68517 .46366 .72176 Metetra
.301 .646 0 r
.46366 .72176 .46923 .68517 .47779 .68318 .47234 .71967 Metetra
.306 .647 0 r
.47234 .71967 .47779 .68318 .48639 .68114 .48106 .71752 Metetra
.31 .649 0 r
.48106 .71752 .48639 .68114 .49502 .67907 .4898 .71534 Metetra
.314 .65 0 r
.4898 .71534 .49502 .67907 .50367 .67697 .49858 .71314 Metetra
.317 .651 0 r
.49858 .71314 .50367 .67697 .51235 .67485 .50738 .71092 Metetra
.321 .652 0 r
.50738 .71092 .51235 .67485 .52107 .6727 .51621 .70869 Metetra
.324 .653 0 r
.51621 .70869 .52107 .6727 .52981 .67053 .52507 .70644 Metetra
.327 .654 0 r
.52507 .70644 .52981 .67053 .53858 .66833 .53396 .70416 Metetra
.33 .655 0 r
.53396 .70416 .53858 .66833 .54738 .66611 .54288 .70187 Metetra
.333 .656 0 r
.54288 .70187 .54738 .66611 .55621 .66387 .55183 .69956 Metetra
.335 .656 0 r
.55183 .69956 .55621 .66387 .56507 .6616 .56081 .69723 Metetra
.338 .657 0 r
.56081 .69723 .56507 .6616 .57396 .6593 .56982 .69489 Metetra
.34 .658 0 r
.56982 .69489 .57396 .6593 .58287 .65698 .57886 .69252 Metetra
.342 .658 0 r
.57886 .69252 .58287 .65698 .59182 .65464 .58793 .69013 Metetra
.344 .659 0 r
.58793 .69013 .59182 .65464 .6008 .65227 .59703 .68773 Metetra
.345 .659 0 r
.59703 .68773 .6008 .65227 .6098 .64988 .60616 .68531 Metetra
.347 .66 0 r
.60616 .68531 .6098 .64988 .61884 .64746 .61532 .68287 Metetra
.348 .66 0 r
.61532 .68287 .61884 .64746 .6279 .64502 .62451 .68041 Metetra
.349 .66 0 r
.62451 .68041 .6279 .64502 .637 .64256 .63373 .67793 Metetra
.35 .661 0 r
.63373 .67793 .637 .64256 .64612 .64007 .64298 .67544 Metetra
.351 .661 0 r
.64298 .67544 .64612 .64007 .65527 .63755 .65226 .67292 Metetra
.351 .661 0 r
.65226 .67292 .65527 .63755 .66445 .63501 .66157 .67039 Metetra
.352 .661 0 r
.66157 .67039 .66445 .63501 .67367 .63245 .67092 .66784 Metetra
.352 .661 0 r
.67092 .66784 .67367 .63245 .68291 .62986 .68029 .66527 Metetra
.352 .661 0 r
.68029 .66527 .68291 .62986 .69218 .62725 .68969 .66268 Metetra
.351 .661 0 r
.68969 .66268 .69218 .62725 .70148 .62461 .69913 .66007 Metetra
.351 .661 0 r
.69913 .66007 .70148 .62461 .71081 .62194 .70859 .65745 Metetra
.35 .661 0 r
.70859 .65745 .71081 .62194 .72017 .61925 .71809 .6548 Metetra
.35 .661 0 r
.71809 .6548 .72017 .61925 .72956 .61654 .72761 .65213 Metetra
.349 .66 0 r
.72761 .65213 .72956 .61654 .73897 .6138 .73717 .64945 Metetra
.348 .66 0 r
.73717 .64945 .73897 .6138 .74842 .61103 .74676 .64675 Metetra
.346 .66 0 r
.74676 .64675 .74842 .61103 .7579 .60824 .75638 .64402 Metetra
.345 .659 0 r
.75638 .64402 .7579 .60824 .76741 .60543 .76603 .64129 Metetra
.343 .659 0 r
.76603 .64129 .76741 .60543 .77694 .60259 .77572 .63852 Metetra
.341 .658 0 r
.77572 .63852 .77694 .60259 .78651 .59972 .78543 .63574 Metetra
.339 .657 0 r
.78543 .63574 .78651 .59972 .7961 .59682 .79517 .63294 Metetra
.337 .657 0 r
.79517 .63294 .7961 .59682 .80573 .5939 .80495 .63012 Metetra
.334 .656 0 r
.80495 .63012 .80573 .5939 .81539 .59095 .81476 .62727 Metetra
.332 .655 0 r
.81476 .62727 .81539 .59095 .82507 .58797 .8246 .62441 Metetra
.329 .654 0 r
.8246 .62441 .82507 .58797 .83478 .58497 .83447 .62152 Metetra
.326 .654 0 r
.83447 .62152 .83478 .58497 .84453 .58194 .84438 .61862 Metetra
.323 .653 0 r
.84438 .61862 .84453 .58194 .8543 .57888 .85431 .61569 Metetra
.319 .652 0 r
.85431 .61569 .8543 .57888 .8641 .5758 .86428 .61274 Metetra
.316 .65 0 r
.86428 .61274 .8641 .5758 .87393 .57268 .87428 .60977 Metetra
.312 .649 0 r
.87428 .60977 .87393 .57268 .88379 .56954 .88431 .60677 Metetra
.308 .648 0 r
.88431 .60677 .88379 .56954 .89368 .56637 .89437 .60376 Metetra
.304 .647 0 r
.89437 .60376 .89368 .56637 .9036 .56315 .90446 .6007 Metetra
.299 .645 0 r
.90446 .6007 .9036 .56315 .91354 .55984 .91457 .59754 Metetra
.291 .643 0 r
.91457 .59754 .91354 .55984 .92349 .5563 .92469 .59411 Metetra
.278 .639 0 r
.92469 .59411 .92349 .5563 .93338 .55212 .93475 .58992 Metetra
.251 .63 0 r
.93475 .58992 .93338 .55212 .94312 .54638 .94461 .58385 Metetra
.192 .611 0 r
.94461 .58385 .94312 .54638 .95246 .53742 .95399 .5739 Metetra
.084 .572 0 r
.95399 .5739 .95246 .53742 .96107 .52291 .96249 .55723 Metetra
0 .504 .076 r
.96249 .55723 .96107 .52291 .96861 .50061 .9697 .53116 Metetra
0 .398 .242 r
.9697 .53116 .96861 .50061 .97489 .46979 .97541 .49486 Metetra
0 .431 .201 r
.39312 .65533 .39874 .64152 .40575 .67526 .39998 .69332 Metetra
.089 .574 0 r
.39998 .69332 .40575 .67526 .41323 .70021 .40739 .72148 Metetra
.396 .674 0 r
.40739 .72148 .41323 .70021 .42116 .71553 .4153 .73884 Metetra
.622 .734 0 r
.4153 .73884 .42116 .71553 .4294 .72302 .42358 .74738 Metetra
.754 .766 0 r
.42358 .74738 .4294 .72302 .43784 .72544 .43209 .75022 Metetra
.78 .743 0 r
.43209 .75022 .43784 .72544 .44639 .72517 .44073 .75002 Metetra
.786 .728 0 r
.44073 .75002 .44639 .72517 .45501 .72369 .44943 .74847 Metetra
.789 .722 0 r
.44943 .74847 .45501 .72369 .46366 .72176 .45817 .74642 Metetra
.79 .719 0 r
.45817 .74642 .46366 .72176 .47234 .71967 .46694 .74419 Metetra
.791 .717 0 r
.46694 .74419 .47234 .71967 .48106 .71752 .47575 .74192 Metetra
.792 .715 0 r
.47575 .74192 .48106 .71752 .4898 .71534 .48458 .73961 Metetra
.792 .713 0 r
.48458 .73961 .4898 .71534 .49858 .71314 .49345 .7373 Metetra
.793 .712 0 r
.49345 .7373 .49858 .71314 .50738 .71092 .50234 .73497 Metetra
.793 .71 0 r
.50234 .73497 .50738 .71092 .51621 .70869 .51126 .73263 Metetra
.794 .709 0 r
.51126 .73263 .51621 .70869 .52507 .70644 .52021 .73028 Metetra
.794 .708 0 r
.52021 .73028 .52507 .70644 .53396 .70416 .52919 .72792 Metetra
.795 .707 0 r
.52919 .72792 .53396 .70416 .54288 .70187 .5382 .72554 Metetra
.795 .705 0 r
.5382 .72554 .54288 .70187 .55183 .69956 .54725 .72315 Metetra
.796 .704 0 r
.54725 .72315 .55183 .69956 .56081 .69723 .55632 .72075 Metetra
.796 .704 0 r
.55632 .72075 .56081 .69723 .56982 .69489 .56542 .71833 Metetra
.796 .703 0 r
.56542 .71833 .56982 .69489 .57886 .69252 .57455 .71591 Metetra
.797 .702 0 r
.57455 .71591 .57886 .69252 .58793 .69013 .58371 .71347 Metetra
.797 .701 0 r
.58371 .71347 .58793 .69013 .59703 .68773 .5929 .71102 Metetra
.797 .7 0 r
.5929 .71102 .59703 .68773 .60616 .68531 .60212 .70855 Metetra
.797 .7 0 r
.60212 .70855 .60616 .68531 .61532 .68287 .61138 .70608 Metetra
.798 .699 0 r
.61138 .70608 .61532 .68287 .62451 .68041 .62066 .70359 Metetra
.798 .699 0 r
.62066 .70359 .62451 .68041 .63373 .67793 .62997 .70109 Metetra
.798 .699 0 r
.62997 .70109 .63373 .67793 .64298 .67544 .63932 .69858 Metetra
.798 .698 0 r
.63932 .69858 .64298 .67544 .65226 .67292 .6487 .69605 Metetra
.798 .698 0 r
.6487 .69605 .65226 .67292 .66157 .67039 .6581 .69352 Metetra
.798 .698 0 r
.6581 .69352 .66157 .67039 .67092 .66784 .66754 .69097 Metetra
.798 .698 0 r
.66754 .69097 .67092 .66784 .68029 .66527 .67702 .68841 Metetra
.798 .698 0 r
.67702 .68841 .68029 .66527 .68969 .66268 .68652 .68583 Metetra
.798 .698 0 r
.68652 .68583 .68969 .66268 .69913 .66007 .69605 .68324 Metetra
.798 .698 0 r
.69605 .68324 .69913 .66007 .70859 .65745 .70562 .68065 Metetra
.798 .699 0 r
.70562 .68065 .70859 .65745 .71809 .6548 .71522 .67803 Metetra
.798 .699 0 r
.71522 .67803 .71809 .6548 .72761 .65213 .72485 .67541 Metetra
.798 .699 0 r
.72485 .67541 .72761 .65213 .73717 .64945 .73451 .67277 Metetra
.798 .7 0 r
.73451 .67277 .73717 .64945 .74676 .64675 .74421 .67012 Metetra
.797 .7 0 r
.74421 .67012 .74676 .64675 .75638 .64402 .75393 .66746 Metetra
.797 .701 0 r
.75393 .66746 .75638 .64402 .76603 .64129 .7637 .66479 Metetra
.797 .701 0 r
.7637 .66479 .76603 .64129 .77572 .63852 .77349 .6621 Metetra
.797 .702 0 r
.77349 .6621 .77572 .63852 .78543 .63574 .78332 .65939 Metetra
.796 .703 0 r
.78332 .65939 .78543 .63574 .79517 .63294 .79318 .65668 Metetra
.796 .704 0 r
.79318 .65668 .79517 .63294 .80495 .63012 .80307 .65395 Metetra
.796 .705 0 r
.80307 .65395 .80495 .63012 .81476 .62727 .81299 .6512 Metetra
.795 .706 0 r
.81299 .6512 .81476 .62727 .8246 .62441 .82295 .64844 Metetra
.795 .707 0 r
.82295 .64844 .8246 .62441 .83447 .62152 .83295 .64567 Metetra
.794 .708 0 r
.83295 .64567 .83447 .62152 .84438 .61862 .84297 .64289 Metetra
.794 .71 0 r
.84297 .64289 .84438 .61862 .85431 .61569 .85304 .64008 Metetra
.793 .711 0 r
.85304 .64008 .85431 .61569 .86428 .61274 .86313 .63727 Metetra
.793 .712 0 r
.86313 .63727 .86428 .61274 .87428 .60977 .87326 .63444 Metetra
.792 .714 0 r
.87326 .63444 .87428 .60977 .88431 .60677 .88342 .63159 Metetra
.791 .716 0 r
.88342 .63159 .88431 .60677 .89437 .60376 .89362 .62873 Metetra
.791 .717 0 r
.89362 .62873 .89437 .60376 .90446 .6007 .90385 .62583 Metetra
.79 .72 0 r
.90385 .62583 .90446 .6007 .91457 .59754 .9141 .62283 Metetra
.788 .724 0 r
.9141 .62283 .91457 .59754 .92469 .59411 .92436 .61954 Metetra
.784 .733 0 r
.92436 .61954 .92469 .59411 .93475 .58992 .93454 .61539 Metetra
.775 .755 0 r
.93454 .61539 .93475 .58992 .94461 .58385 .9445 .60913 Metetra
.704 .754 0 r
.9445 .60913 .94461 .58385 .95399 .5739 .95393 .59849 Metetra
.531 .711 0 r
.95393 .59849 .95399 .5739 .96249 .55723 .96237 .58028 Metetra
.261 .634 0 r
.96237 .58028 .96249 .55723 .9697 .53116 .96936 .55148 Metetra
0 .514 .055 r
.96936 .55148 .9697 .53116 .97541 .49486 .97467 .5112 Metetra
0 .501 .081 r
.38769 .66197 .39312 .65533 .39998 .69332 .39444 .70258 Metetra
.332 .655 0 r
.39444 .70258 .39998 .69332 .40739 .72148 .40178 .73273 Metetra
.74 .763 0 r
.40178 .73273 .40739 .72148 .4153 .73884 .40968 .75133 Metetra
.827 .62 0 r
.40968 .75133 .4153 .73884 .42358 .74738 .41798 .7605 Metetra
.86 .521 0 r
.41798 .7605 .42358 .74738 .43209 .75022 .42654 .76355 Metetra
.875 .473 0 r
.42654 .76355 .43209 .75022 .44073 .75002 .43523 .76337 Metetra
.881 .453 0 r
.43523 .76337 .44073 .75002 .44943 .74847 .44399 .76174 Metetra
.883 .446 0 r
.44399 .76174 .44943 .74847 .45817 .74642 .4528 .75958 Metetra
.884 .444 0 r
.4528 .75958 .45817 .74642 .46694 .74419 .46164 .75724 Metetra
.884 .443 0 r
.46164 .75724 .46694 .74419 .47575 .74192 .4705 .75485 Metetra
.885 .443 0 r
.4705 .75485 .47575 .74192 .48458 .73961 .4794 .75244 Metetra
.885 .442 0 r
.4794 .75244 .48458 .73961 .49345 .7373 .48832 .75002 Metetra
.885 .442 0 r
.48832 .75002 .49345 .7373 .50234 .73497 .49728 .7476 Metetra
.885 .441 0 r
.49728 .7476 .50234 .73497 .51126 .73263 .50626 .74517 Metetra
.885 .441 0 r
.50626 .74517 .51126 .73263 .52021 .73028 .51528 .74273 Metetra
.885 .441 0 r
.51528 .74273 .52021 .73028 .52919 .72792 .52432 .74028 Metetra
.885 .44 0 r
.52432 .74028 .52919 .72792 .5382 .72554 .53339 .73783 Metetra
.885 .44 0 r
.53339 .73783 .5382 .72554 .54725 .72315 .5425 .73537 Metetra
.885 .44 0 r
.5425 .73537 .54725 .72315 .55632 .72075 .55163 .7329 Metetra
.885 .439 0 r
.55163 .7329 .55632 .72075 .56542 .71833 .56079 .73043 Metetra
.886 .439 0 r
.56079 .73043 .56542 .71833 .57455 .71591 .56999 .72794 Metetra
.886 .439 0 r
.56999 .72794 .57455 .71591 .58371 .71347 .57921 .72545 Metetra
.886 .439 0 r
.57921 .72545 .58371 .71347 .5929 .71102 .58846 .72296 Metetra
.886 .439 0 r
.58846 .72296 .5929 .71102 .60212 .70855 .59775 .72045 Metetra
.886 .438 0 r
.59775 .72045 .60212 .70855 .61138 .70608 .60707 .71794 Metetra
.886 .438 0 r
.60707 .71794 .61138 .70608 .62066 .70359 .61642 .71542 Metetra
.886 .438 0 r
.61642 .71542 .62066 .70359 .62997 .70109 .62579 .7129 Metetra
.886 .438 0 r
.62579 .7129 .62997 .70109 .63932 .69858 .63521 .71036 Metetra
.886 .438 0 r
.63521 .71036 .63932 .69858 .6487 .69605 .64465 .70782 Metetra
.886 .438 0 r
.64465 .70782 .6487 .69605 .6581 .69352 .65412 .70528 Metetra
.886 .438 0 r
.65412 .70528 .6581 .69352 .66754 .69097 .66363 .70272 Metetra
.886 .438 0 r
.66363 .70272 .66754 .69097 .67702 .68841 .67317 .70016 Metetra
.886 .438 0 r
.67317 .70016 .67702 .68841 .68652 .68583 .68274 .69759 Metetra
.886 .438 0 r
.68274 .69759 .68652 .68583 .69605 .68324 .69234 .69501 Metetra
.886 .438 0 r
.69234 .69501 .69605 .68324 .70562 .68065 .70198 .69242 Metetra
.886 .438 0 r
.70198 .69242 .70562 .68065 .71522 .67803 .71165 .68983 Metetra
.886 .438 0 r
.71165 .68983 .71522 .67803 .72485 .67541 .72135 .68723 Metetra
.886 .438 0 r
.72135 .68723 .72485 .67541 .73451 .67277 .73108 .68462 Metetra
.886 .438 0 r
.73108 .68462 .73451 .67277 .74421 .67012 .74085 .682 Metetra
.886 .439 0 r
.74085 .682 .74421 .67012 .75393 .66746 .75065 .67937 Metetra
.886 .439 0 r
.75065 .67937 .75393 .66746 .7637 .66479 .76049 .67675 Metetra
.886 .439 0 r
.76049 .67675 .7637 .66479 .77349 .6621 .77036 .67411 Metetra
.886 .439 0 r
.77036 .67411 .77349 .6621 .78332 .65939 .78027 .67146 Metetra
.886 .439 0 r
.78027 .67146 .78332 .65939 .79318 .65668 .79021 .6688 Metetra
.885 .439 0 r
.79021 .6688 .79318 .65668 .80307 .65395 .80018 .66613 Metetra
.885 .44 0 r
.80018 .66613 .80307 .65395 .81299 .6512 .81019 .66346 Metetra
.885 .44 0 r
.81019 .66346 .81299 .6512 .82295 .64844 .82023 .66078 Metetra
.885 .44 0 r
.82023 .66078 .82295 .64844 .83295 .64567 .83031 .65809 Metetra
.885 .441 0 r
.83031 .65809 .83295 .64567 .84297 .64289 .84042 .65539 Metetra
.885 .441 0 r
.84042 .65539 .84297 .64289 .85304 .64008 .85057 .65268 Metetra
.885 .441 0 r
.85057 .65268 .85304 .64008 .86313 .63727 .86075 .64996 Metetra
.885 .442 0 r
.86075 .64996 .86313 .63727 .87326 .63444 .87097 .64724 Metetra
.885 .442 0 r
.87097 .64724 .87326 .63444 .88342 .63159 .88123 .6445 Metetra
.884 .443 0 r
.88123 .6445 .88342 .63159 .89362 .62873 .89152 .64176 Metetra
.884 .443 0 r
.89152 .64176 .89362 .62873 .90385 .62583 .90185 .63898 Metetra
.884 .445 0 r
.90185 .63898 .90385 .62583 .9141 .62283 .9122 .6361 Metetra
.883 .449 0 r
.9122 .6361 .9141 .62283 .92436 .61954 .92255 .63291 Metetra
.879 .46 0 r
.92255 .63291 .92436 .61954 .93454 .61539 .93284 .62881 Metetra
.87 .49 0 r
.93284 .62881 .93454 .61539 .9445 .60913 .94288 .62246 Metetra
.848 .558 0 r
.94288 .62246 .9445 .60913 .95393 .59849 .95235 .61142 Metetra
.802 .688 0 r
.95235 .61142 .95393 .59849 .96237 .58028 .96077 .59225 Metetra
.564 .719 0 r
.96077 .59225 .96237 .58028 .96936 .55148 .96764 .56176 Metetra
.133 .59 0 r
.96764 .56176 .96936 .55148 .97467 .5112 .97273 .51902 Metetra
.005 .541 0 r
.38242 .66325 .38769 .66197 .39444 .70258 .38908 .70525 Metetra
.495 .701 0 r
.38908 .70525 .39444 .70258 .40178 .73273 .39637 .73646 Metetra
.813 .659 0 r
.39637 .73646 .40178 .73273 .40968 .75133 .40425 .75571 Metetra
.88 .459 0 r
.40425 .75571 .40968 .75133 .41798 .7605 .41256 .7652 Metetra
.914 .341 0 r
.41256 .7652 .41798 .7605 .42654 .76355 .42115 .76835 Metetra
.929 .285 0 r
.42115 .76835 .42654 .76355 .43523 .76337 .42988 .76815 Metetra
.935 .264 0 r
.42988 .76815 .43523 .76337 .44399 .76174 .43868 .76646 Metetra
.937 .257 0 r
.43868 .76646 .44399 .76174 .4528 .75958 .44753 .76422 Metetra
.937 .256 0 r
.44753 .76422 .4528 .75958 .46164 .75724 .45641 .7618 Metetra
.937 .256 0 r
.45641 .7618 .46164 .75724 .4705 .75485 .46532 .75933 Metetra
.937 .257 0 r
.46532 .75933 .4705 .75485 .4794 .75244 .47425 .75684 Metetra
.936 .258 0 r
.47425 .75684 .4794 .75244 .48832 .75002 .48322 .75436 Metetra
.936 .259 0 r
.48322 .75436 .48832 .75002 .49728 .7476 .49222 .75186 Metetra
.936 .259 0 r
.49222 .75186 .49728 .7476 .50626 .74517 .50124 .74937 Metetra
.936 .26 0 r
.50124 .74937 .50626 .74517 .51528 .74273 .5103 .74686 Metetra
.936 .261 0 r
.5103 .74686 .51528 .74273 .52432 .74028 .51938 .74436 Metetra
.936 .261 0 r
.51938 .74436 .52432 .74028 .53339 .73783 .5285 .74185 Metetra
.935 .262 0 r
.5285 .74185 .53339 .73783 .5425 .73537 .53764 .73934 Metetra
.935 .262 0 r
.53764 .73934 .5425 .73537 .55163 .7329 .54682 .73682 Metetra
.935 .263 0 r
.54682 .73682 .55163 .7329 .56079 .73043 .55602 .7343 Metetra
.935 .263 0 r
.55602 .7343 .56079 .73043 .56999 .72794 .56526 .73178 Metetra
.935 .264 0 r
.56526 .73178 .56999 .72794 .57921 .72545 .57452 .72925 Metetra
.935 .264 0 r
.57452 .72925 .57921 .72545 .58846 .72296 .58382 .72671 Metetra
.935 .264 0 r
.58382 .72671 .58846 .72296 .59775 .72045 .59315 .72418 Metetra
.935 .265 0 r
.59315 .72418 .59775 .72045 .60707 .71794 .60251 .72164 Metetra
.935 .265 0 r
.60251 .72164 .60707 .71794 .61642 .71542 .6119 .71909 Metetra
.934 .265 0 r
.6119 .71909 .61642 .71542 .62579 .7129 .62132 .71654 Metetra
.934 .265 0 r
.62132 .71654 .62579 .7129 .63521 .71036 .63078 .71399 Metetra
.934 .266 0 r
.63078 .71399 .63521 .71036 .64465 .70782 .64026 .71143 Metetra
.934 .266 0 r
.64026 .71143 .64465 .70782 .65412 .70528 .64978 .70886 Metetra
.934 .266 0 r
.64978 .70886 .65412 .70528 .66363 .70272 .65933 .7063 Metetra
.934 .266 0 r
.65933 .7063 .66363 .70272 .67317 .70016 .66892 .70372 Metetra
.934 .266 0 r
.66892 .70372 .67317 .70016 .68274 .69759 .67853 .70115 Metetra
.934 .266 0 r
.67853 .70115 .68274 .69759 .69234 .69501 .68818 .69857 Metetra
.934 .266 0 r
.68818 .69857 .69234 .69501 .70198 .69242 .69786 .69598 Metetra
.934 .266 0 r
.69786 .69598 .70198 .69242 .71165 .68983 .70758 .69339 Metetra
.934 .265 0 r
.70758 .69339 .71165 .68983 .72135 .68723 .71733 .69079 Metetra
.935 .265 0 r
.71733 .69079 .72135 .68723 .73108 .68462 .72711 .68819 Metetra
.935 .265 0 r
.72711 .68819 .73108 .68462 .74085 .682 .73693 .68559 Metetra
.935 .265 0 r
.73693 .68559 .74085 .682 .75065 .67937 .74678 .68298 Metetra
.935 .264 0 r
.74678 .68298 .75065 .67937 .76049 .67675 .75667 .68037 Metetra
.935 .264 0 r
.75667 .68037 .76049 .67675 .77036 .67411 .76659 .67776 Metetra
.935 .263 0 r
.76659 .67776 .77036 .67411 .78027 .67146 .77655 .67513 Metetra
.935 .263 0 r
.77655 .67513 .78027 .67146 .79021 .6688 .78654 .6725 Metetra
.935 .263 0 r
.78654 .6725 .79021 .6688 .80018 .66613 .79657 .66987 Metetra
.935 .262 0 r
.79657 .66987 .80018 .66613 .81019 .66346 .80663 .66723 Metetra
.935 .261 0 r
.80663 .66723 .81019 .66346 .82023 .66078 .81673 .66459 Metetra
.936 .261 0 r
.81673 .66459 .82023 .66078 .83031 .65809 .82686 .66194 Metetra
.936 .26 0 r
.82686 .66194 .83031 .65809 .84042 .65539 .83703 .65929 Metetra
.936 .26 0 r
.83703 .65929 .84042 .65539 .85057 .65268 .84724 .65663 Metetra
.936 .259 0 r
.84724 .65663 .85057 .65268 .86075 .64996 .85749 .65397 Metetra
.936 .258 0 r
.85749 .65397 .86075 .64996 .87097 .64724 .86777 .6513 Metetra
.937 .257 0 r
.86777 .6513 .87097 .64724 .88123 .6445 .87809 .64863 Metetra
.937 .257 0 r
.87809 .64863 .88123 .6445 .89152 .64176 .88844 .64595 Metetra
.937 .256 0 r
.88844 .64595 .89152 .64176 .90185 .63898 .89883 .64324 Metetra
.937 .256 0 r
.89883 .64324 .90185 .63898 .9122 .6361 .90925 .64043 Metetra
.936 .259 0 r
.90925 .64043 .9122 .6361 .92255 .63291 .91967 .63731 Metetra
.933 .271 0 r
.91967 .63731 .92255 .63291 .93284 .62881 .93002 .63324 Metetra
.924 .305 0 r
.93002 .63324 .93284 .62881 .94288 .62246 .94011 .62685 Metetra
.901 .385 0 r
.94011 .62685 .94288 .62246 .95235 .61142 .94962 .61559 Metetra
.854 .541 0 r
.94962 .61559 .95235 .61142 .96077 .59225 .95806 .59592 Metetra
.764 .768 0 r
.95806 .59592 .96077 .59225 .96764 .56176 .9649 .56451 Metetra
.262 .634 0 r
.9649 .56451 .96764 .56176 .97273 .51902 .9699 .52044 Metetra
.053 .56 0 r
.37724 .66129 .38242 .66325 .38908 .70525 .38383 .70395 Metetra
.582 .724 0 r
.38383 .70395 .38908 .70525 .39637 .73646 .39107 .73565 Metetra
.837 .59 0 r
.39107 .73565 .39637 .73646 .40425 .75571 .39894 .7552 Metetra
.905 .372 0 r
.39894 .7552 .40425 .75571 .41256 .7652 .40726 .76484 Metetra
.94 .244 0 r
.40726 .76484 .41256 .7652 .42115 .76835 .41586 .76803 Metetra
.955 .185 0 r
.41586 .76803 .42115 .76835 .42988 .76815 .42461 .76781 Metetra
.961 .162 0 r
.42461 .76781 .42988 .76815 .43868 .76646 .43344 .76608 Metetra
.963 .156 0 r
.43344 .76608 .43868 .76646 .44753 .76422 .44232 .76379 Metetra
.963 .156 0 r
.44232 .76379 .44753 .76422 .45641 .7618 .45123 .76132 Metetra
.962 .157 0 r
.45123 .76132 .45641 .7618 .46532 .75933 .46016 .7588 Metetra
.962 .159 0 r
.46016 .7588 .46532 .75933 .47425 .75684 .46913 .75626 Metetra
.961 .161 0 r
.46913 .75626 .47425 .75684 .48322 .75436 .47813 .75373 Metetra
.961 .162 0 r
.47813 .75373 .48322 .75436 .49222 .75186 .48715 .75119 Metetra
.961 .164 0 r
.48715 .75119 .49222 .75186 .50124 .74937 .49621 .74865 Metetra
.96 .165 0 r
.49621 .74865 .50124 .74937 .5103 .74686 .50529 .74611 Metetra
.96 .166 0 r
.50529 .74611 .5103 .74686 .51938 .74436 .51441 .74357 Metetra
.96 .168 0 r
.51441 .74357 .51938 .74436 .5285 .74185 .52355 .74102 Metetra
.959 .169 0 r
.52355 .74102 .5285 .74185 .53764 .73934 .53272 .73848 Metetra
.959 .17 0 r
.53272 .73848 .53764 .73934 .54682 .73682 .54193 .73592 Metetra
.959 .171 0 r
.54193 .73592 .54682 .73682 .55602 .7343 .55116 .73337 Metetra
.959 .172 0 r
.55116 .73337 .55602 .7343 .56526 .73178 .56043 .73082 Metetra
.958 .173 0 r
.56043 .73082 .56526 .73178 .57452 .72925 .56972 .72826 Metetra
.958 .173 0 r
.56972 .72826 .57452 .72925 .58382 .72671 .57905 .7257 Metetra
.958 .174 0 r
.57905 .7257 .58382 .72671 .59315 .72418 .58841 .72314 Metetra
.958 .175 0 r
.58841 .72314 .59315 .72418 .60251 .72164 .5978 .72057 Metetra
.958 .175 0 r
.5978 .72057 .60251 .72164 .6119 .71909 .60722 .718 Metetra
.958 .176 0 r
.60722 .718 .6119 .71909 .62132 .71654 .61668 .71543 Metetra
.958 .176 0 r
.61668 .71543 .62132 .71654 .63078 .71399 .62616 .71286 Metetra
.958 .176 0 r
.62616 .71286 .63078 .71399 .64026 .71143 .63568 .71028 Metetra
.957 .177 0 r
.63568 .71028 .64026 .71143 .64978 .70886 .64523 .7077 Metetra
.957 .177 0 r
.64523 .7077 .64978 .70886 .65933 .7063 .65481 .70512 Metetra
.957 .177 0 r
.65481 .70512 .65933 .7063 .66892 .70372 .66443 .70254 Metetra
.957 .177 0 r
.66443 .70254 .66892 .70372 .67853 .70115 .67408 .69995 Metetra
.957 .177 0 r
.67408 .69995 .67853 .70115 .68818 .69857 .68376 .69736 Metetra
.957 .176 0 r
.68376 .69736 .68818 .69857 .69786 .69598 .69348 .69476 Metetra
.958 .176 0 r
.69348 .69476 .69786 .69598 .70758 .69339 .70323 .69216 Metetra
.958 .176 0 r
.70323 .69216 .70758 .69339 .71733 .69079 .71301 .68956 Metetra
.958 .175 0 r
.71301 .68956 .71733 .69079 .72711 .68819 .72283 .68696 Metetra
.958 .175 0 r
.72283 .68696 .72711 .68819 .73693 .68559 .73268 .68435 Metetra
.958 .174 0 r
.73268 .68435 .73693 .68559 .74678 .68298 .74257 .68174 Metetra
.958 .174 0 r
.74257 .68174 .74678 .68298 .75667 .68037 .75249 .67914 Metetra
.958 .173 0 r
.75249 .67914 .75667 .68037 .76659 .67776 .76245 .67652 Metetra
.959 .172 0 r
.76245 .67652 .76659 .67776 .77655 .67513 .77244 .6739 Metetra
.959 .171 0 r
.77244 .6739 .77655 .67513 .78654 .6725 .78247 .67128 Metetra
.959 .17 0 r
.78247 .67128 .78654 .6725 .79657 .66987 .79253 .66866 Metetra
.959 .169 0 r
.79253 .66866 .79657 .66987 .80663 .66723 .80263 .66603 Metetra
.96 .168 0 r
.80263 .66603 .80663 .66723 .81673 .66459 .81277 .6634 Metetra
.96 .167 0 r
.81277 .6634 .81673 .66459 .82686 .66194 .82295 .66076 Metetra
.96 .166 0 r
.82295 .66076 .82686 .66194 .83703 .65929 .83316 .65812 Metetra
.961 .164 0 r
.83316 .65812 .83703 .65929 .84724 .65663 .8434 .65548 Metetra
.961 .163 0 r
.8434 .65548 .84724 .65663 .85749 .65397 .85369 .65284 Metetra
.961 .161 0 r
.85369 .65284 .85749 .65397 .86777 .6513 .86401 .65019 Metetra
.962 .16 0 r
.86401 .65019 .86777 .6513 .87809 .64863 .87437 .64754 Metetra
.962 .158 0 r
.87437 .64754 .87809 .64863 .88844 .64595 .88477 .64489 Metetra
.962 .156 0 r
.88477 .64489 .88844 .64595 .89883 .64324 .89521 .6422 Metetra
.963 .156 0 r
.89521 .6422 .89883 .64324 .90925 .64043 .90567 .63943 Metetra
.962 .158 0 r
.90567 .63943 .90925 .64043 .91967 .63731 .91614 .63632 Metetra
.959 .17 0 r
.91614 .63632 .91967 .63731 .93002 .63324 .92653 .63227 Metetra
.95 .205 0 r
.92653 .63227 .93002 .63324 .94011 .62685 .93667 .62585 Metetra
.927 .292 0 r
.93667 .62585 .94011 .62685 .94962 .61559 .94622 .61448 Metetra
.879 .46 0 r
.94622 .61448 .94962 .61559 .95806 .59592 .95468 .59455 Metetra
.792 .714 0 r
.95468 .59455 .95806 .59592 .9649 .56451 .96153 .56271 Metetra
.331 .655 0 r
.96153 .56271 .9649 .56451 .9699 .52044 .96653 .51799 Metetra
.074 .568 0 r
.37209 .65771 .37724 .66129 .38383 .70395 .37862 .70066 Metetra
.619 .733 0 r
.37862 .70066 .38383 .70395 .39107 .73565 .38582 .73257 Metetra
.848 .559 0 r
.38582 .73257 .39107 .73565 .39894 .7552 .39367 .75226 Metetra
.916 .333 0 r
.39367 .75226 .39894 .7552 .40726 .76484 .40199 .76195 Metetra
.951 .202 0 r
.40199 .76195 .40726 .76484 .41586 .76803 .4106 .76516 Metetra
.966 .141 0 r
.4106 .76516 .41586 .76803 .42461 .76781 .41937 .76492 Metetra
.972 .118 0 r
.41937 .76492 .42461 .76781 .43344 .76608 .42823 .76316 Metetra
.973 .113 0 r
.42823 .76316 .43344 .76608 .44232 .76379 .43712 .76084 Metetra
.973 .113 0 r
.43712 .76084 .44232 .76379 .45123 .76132 .44606 .75834 Metetra
.973 .114 0 r
.44606 .75834 .45123 .76132 .46016 .7588 .45502 .75579 Metetra
.972 .117 0 r
.45502 .75579 .46016 .7588 .46913 .75626 .46401 .75323 Metetra
.972 .119 0 r
.46401 .75323 .46913 .75626 .47813 .75373 .47303 .75067 Metetra
.971 .121 0 r
.47303 .75067 .47813 .75373 .48715 .75119 .48208 .7481 Metetra
.971 .123 0 r
.48208 .7481 .48715 .75119 .49621 .74865 .49115 .74554 Metetra
.97 .124 0 r
.49115 .74554 .49621 .74865 .50529 .74611 .50026 .74297 Metetra
.97 .126 0 r
.50026 .74297 .50529 .74611 .51441 .74357 .5094 .7404 Metetra
.97 .128 0 r
.5094 .7404 .51441 .74357 .52355 .74102 .51857 .73783 Metetra
.969 .129 0 r
.51857 .73783 .52355 .74102 .53272 .73848 .52776 .73526 Metetra
.969 .13 0 r
.52776 .73526 .53272 .73848 .54193 .73592 .53699 .73268 Metetra
.969 .132 0 r
.53699 .73268 .54193 .73592 .55116 .73337 .54625 .73011 Metetra
.968 .133 0 r
.54625 .73011 .55116 .73337 .56043 .73082 .55554 .72753 Metetra
.968 .134 0 r
.55554 .72753 .56043 .73082 .56972 .72826 .56486 .72495 Metetra
.968 .135 0 r
.56486 .72495 .56972 .72826 .57905 .7257 .57421 .72237 Metetra
.968 .136 0 r
.57421 .72237 .57905 .7257 .58841 .72314 .58359 .71979 Metetra
.967 .136 0 r
.58359 .71979 .58841 .72314 .5978 .72057 .59301 .7172 Metetra
.967 .137 0 r
.59301 .7172 .5978 .72057 .60722 .718 .60246 .71462 Metetra
.967 .138 0 r
.60246 .71462 .60722 .718 .61668 .71543 .61193 .71203 Metetra
.967 .138 0 r
.61193 .71203 .61668 .71543 .62616 .71286 .62144 .70944 Metetra
.967 .138 0 r
.62144 .70944 .62616 .71286 .63568 .71028 .63099 .70684 Metetra
.967 .139 0 r
.63099 .70684 .63568 .71028 .64523 .7077 .64056 .70425 Metetra
.967 .139 0 r
.64056 .70425 .64523 .7077 .65481 .70512 .65017 .70165 Metetra
.967 .139 0 r
.65017 .70165 .65481 .70512 .66443 .70254 .65981 .69905 Metetra
.967 .139 0 r
.65981 .69905 .66443 .70254 .67408 .69995 .66949 .69645 Metetra
.967 .139 0 r
.66949 .69645 .67408 .69995 .68376 .69736 .6792 .69384 Metetra
.967 .139 0 r
.6792 .69384 .68376 .69736 .69348 .69476 .68894 .69123 Metetra
.967 .138 0 r
.68894 .69123 .69348 .69476 .70323 .69216 .69872 .68862 Metetra
.967 .138 0 r
.69872 .68862 .70323 .69216 .71301 .68956 .70853 .68601 Metetra
.967 .137 0 r
.70853 .68601 .71301 .68956 .72283 .68696 .71838 .68339 Metetra
.967 .137 0 r
.71838 .68339 .72283 .68696 .73268 .68435 .72826 .68078 Metetra
.968 .136 0 r
.72826 .68078 .73268 .68435 .74257 .68174 .73817 .67816 Metetra
.968 .135 0 r
.73817 .67816 .74257 .68174 .75249 .67914 .74812 .67554 Metetra
.968 .134 0 r
.74812 .67554 .75249 .67914 .76245 .67652 .75811 .67292 Metetra
.968 .133 0 r
.75811 .67292 .76245 .67652 .77244 .6739 .76813 .67029 Metetra
.969 .132 0 r
.76813 .67029 .77244 .6739 .78247 .67128 .77819 .66766 Metetra
.969 .131 0 r
.77819 .66766 .78247 .67128 .79253 .66866 .78828 .66503 Metetra
.969 .13 0 r
.78828 .66503 .79253 .66866 .80263 .66603 .79841 .66239 Metetra
.969 .128 0 r
.79841 .66239 .80263 .66603 .81277 .6634 .80858 .65976 Metetra
.97 .127 0 r
.80858 .65976 .81277 .6634 .82295 .66076 .81878 .65712 Metetra
.97 .125 0 r
.81878 .65712 .82295 .66076 .83316 .65812 .82903 .65447 Metetra
.971 .123 0 r
.82903 .65447 .83316 .65812 .8434 .65548 .83931 .65183 Metetra
.971 .122 0 r
.83931 .65183 .8434 .65548 .85369 .65284 .84962 .64919 Metetra
.972 .12 0 r
.84962 .64919 .85369 .65284 .86401 .65019 .85998 .64654 Metetra
.972 .118 0 r
.85998 .64654 .86401 .65019 .87437 .64754 .87037 .64389 Metetra
.973 .115 0 r
.87037 .64389 .87437 .64754 .88477 .64489 .8808 .64123 Metetra
.973 .113 0 r
.8808 .64123 .88477 .64489 .89521 .6422 .89127 .63855 Metetra
.973 .112 0 r
.89127 .63855 .89521 .6422 .90567 .63943 .90177 .63577 Metetra
.973 .114 0 r
.90177 .63577 .90567 .63943 .91614 .63632 .91227 .63267 Metetra
.97 .126 0 r
.91227 .63267 .91614 .63632 .92653 .63227 .9227 .62861 Metetra
.961 .162 0 r
.9227 .62861 .92653 .63227 .93667 .62585 .93287 .62216 Metetra
.938 .251 0 r
.93287 .62216 .93667 .62585 .94622 .61448 .94246 .61072 Metetra
.89 .425 0 r
.94246 .61072 .94622 .61448 .95468 .59455 .95095 .59068 Metetra
.802 .689 0 r
.95095 .59068 .95468 .59455 .96153 .56271 .95784 .55862 Metetra
.361 .664 0 r
.95784 .55862 .96153 .56271 .96653 .51799 .96288 .5136 Metetra
.081 .571 0 r
.36694 .65345 .37209 .65771 .37862 .70066 .37341 .69653 Metetra
.633 .737 0 r
.37341 .69653 .37862 .70066 .38582 .73257 .38058 .72854 Metetra
.851 .548 0 r
.38058 .72854 .38582 .73257 .39367 .75226 .3884 .74829 Metetra
.92 .319 0 r
.3884 .74829 .39367 .75226 .40199 .76195 .39672 .75801 Metetra
.955 .186 0 r
.39672 .75801 .40199 .76195 .4106 .76516 .40535 .76121 Metetra
.97 .125 0 r
.40535 .76121 .4106 .76516 .41937 .76492 .41413 .76097 Metetra
.976 .103 0 r
.41413 .76097 .41937 .76492 .42823 .76316 .42301 .75919 Metetra
.977 .097 0 r
.42301 .75919 .42823 .76316 .43712 .76084 .43192 .75685 Metetra
.977 .097 0 r
.43192 .75685 .43712 .76084 .44606 .75834 .44088 .75433 Metetra
.977 .099 0 r
.44088 .75433 .44606 .75834 .45502 .75579 .44986 .75176 Metetra
.976 .101 0 r
.44986 .75176 .45502 .75579 .46401 .75323 .45887 .74918 Metetra
.975 .104 0 r
.45887 .74918 .46401 .75323 .47303 .75067 .46791 .7466 Metetra
.975 .106 0 r
.46791 .7466 .47303 .75067 .48208 .7481 .47698 .74401 Metetra
.974 .108 0 r
.47698 .74401 .48208 .7481 .49115 .74554 .48608 .74143 Metetra
.974 .11 0 r
.48608 .74143 .49115 .74554 .50026 .74297 .4952 .73884 Metetra
.974 .112 0 r
.4952 .73884 .50026 .74297 .5094 .7404 .50436 .73625 Metetra
.973 .113 0 r
.50436 .73625 .5094 .7404 .51857 .73783 .51355 .73366 Metetra
.973 .115 0 r
.51355 .73366 .51857 .73783 .52776 .73526 .52277 .73107 Metetra
.972 .116 0 r
.52277 .73107 .52776 .73526 .53699 .73268 .53202 .72848 Metetra
.972 .118 0 r
.53202 .72848 .53699 .73268 .54625 .73011 .5413 .72589 Metetra
.972 .119 0 r
.5413 .72589 .54625 .73011 .55554 .72753 .55061 .72329 Metetra
.971 .12 0 r
.55061 .72329 .55554 .72753 .56486 .72495 .55995 .7207 Metetra
.971 .121 0 r
.55995 .7207 .56486 .72495 .57421 .72237 .56933 .7181 Metetra
.971 .122 0 r
.56933 .7181 .57421 .72237 .58359 .71979 .57873 .7155 Metetra
.971 .123 0 r
.57873 .7155 .58359 .71979 .59301 .7172 .58817 .7129 Metetra
.971 .124 0 r
.58817 .7129 .59301 .7172 .60246 .71462 .59764 .71029 Metetra
.97 .124 0 r
.59764 .71029 .60246 .71462 .61193 .71203 .60714 .70769 Metetra
.97 .125 0 r
.60714 .70769 .61193 .71203 .62144 .70944 .61667 .70508 Metetra
.97 .125 0 r
.61667 .70508 .62144 .70944 .63099 .70684 .62624 .70247 Metetra
.97 .125 0 r
.62624 .70247 .63099 .70684 .64056 .70425 .63584 .69986 Metetra
.97 .126 0 r
.63584 .69986 .64056 .70425 .65017 .70165 .64547 .69724 Metetra
.97 .126 0 r
.64547 .69724 .65017 .70165 .65981 .69905 .65514 .69463 Metetra
.97 .126 0 r
.65514 .69463 .65981 .69905 .66949 .69645 .66483 .69201 Metetra
.97 .126 0 r
.66483 .69201 .66949 .69645 .6792 .69384 .67457 .68938 Metetra
.97 .125 0 r
.67457 .68938 .6792 .69384 .68894 .69123 .68433 .68676 Metetra
.97 .125 0 r
.68433 .68676 .68894 .69123 .69872 .68862 .69414 .68413 Metetra
.97 .125 0 r
.69414 .68413 .69872 .68862 .70853 .68601 .70397 .68151 Metetra
.971 .124 0 r
.70397 .68151 .70853 .68601 .71838 .68339 .71384 .67888 Metetra
.971 .123 0 r
.71384 .67888 .71838 .68339 .72826 .68078 .72375 .67624 Metetra
.971 .123 0 r
.72375 .67624 .72826 .68078 .73817 .67816 .73369 .67361 Metetra
.971 .122 0 r
.73369 .67361 .73817 .67816 .74812 .67554 .74366 .67098 Metetra
.971 .121 0 r
.74366 .67098 .74812 .67554 .75811 .67292 .75368 .66834 Metetra
.972 .12 0 r
.75368 .66834 .75811 .67292 .76813 .67029 .76372 .6657 Metetra
.972 .118 0 r
.76372 .6657 .76813 .67029 .77819 .66766 .77381 .66305 Metetra
.972 .117 0 r
.77381 .66305 .77819 .66766 .78828 .66503 .78393 .66041 Metetra
.973 .116 0 r
.78393 .66041 .78828 .66503 .79841 .66239 .79409 .65776 Metetra
.973 .114 0 r
.79409 .65776 .79841 .66239 .80858 .65976 .80428 .65511 Metetra
.973 .112 0 r
.80428 .65511 .80858 .65976 .81878 .65712 .81451 .65245 Metetra
.974 .111 0 r
.81451 .65245 .81878 .65712 .82903 .65447 .82478 .6498 Metetra
.974 .109 0 r
.82478 .6498 .82903 .65447 .83931 .65183 .83509 .64714 Metetra
.975 .107 0 r
.83509 .64714 .83931 .65183 .84962 .64919 .84543 .64448 Metetra
.975 .105 0 r
.84543 .64448 .84962 .64919 .85998 .64654 .85582 .64182 Metetra
.976 .103 0 r
.85582 .64182 .85998 .64654 .87037 .64389 .86624 .63916 Metetra
.976 .1 0 r
.86624 .63916 .87037 .64389 .8808 .64123 .8767 .63649 Metetra
.977 .098 0 r
.8767 .63649 .8808 .64123 .89127 .63855 .8872 .6338 Metetra
.977 .097 0 r
.8872 .6338 .89127 .63855 .90177 .63577 .89772 .63101 Metetra
.977 .098 0 r
.89772 .63101 .90177 .63577 .91227 .63267 .90825 .62789 Metetra
.974 .11 0 r
.90825 .62789 .91227 .63267 .9227 .62861 .91871 .62381 Metetra
.965 .146 0 r
.91871 .62381 .9227 .62861 .93287 .62216 .92892 .61734 Metetra
.942 .236 0 r
.92892 .61734 .93287 .62216 .94246 .61072 .93854 .60586 Metetra
.894 .412 0 r
.93854 .60586 .94246 .61072 .95095 .59068 .94707 .58573 Metetra
.805 .68 0 r
.94707 .58573 .95095 .59068 .95784 .55862 .954 .55355 Metetra
.372 .667 0 r
.954 .55355 .95784 .55862 .96288 .5136 .95909 .50838 Metetra
.083 .572 0 r
.36178 .64892 .36694 .65345 .37341 .69653 .36819 .69208 Metetra
.636 .738 0 r
.36819 .69208 .37341 .69653 .38058 .72854 .37531 .72416 Metetra
.852 .545 0 r
.37531 .72416 .38058 .72854 .3884 .74829 .38312 .74395 Metetra
.921 .315 0 r
.38312 .74395 .3884 .74829 .39672 .75801 .39144 .75368 Metetra
.956 .182 0 r
.39144 .75368 .39672 .75801 .40535 .76121 .40007 .75688 Metetra
.971 .12 0 r
.40007 .75688 .40535 .76121 .41413 .76097 .40887 .75663 Metetra
.977 .098 0 r
.40887 .75663 .41413 .76097 .42301 .75919 .41776 .75484 Metetra
.978 .092 0 r
.41776 .75484 .42301 .75919 .43192 .75685 .4267 .75248 Metetra
.978 .093 0 r
.4267 .75248 .43192 .75685 .44088 .75433 .43567 .74994 Metetra
.978 .095 0 r
.43567 .74994 .44088 .75433 .44986 .75176 .44467 .74736 Metetra
.977 .097 0 r
.44467 .74736 .44986 .75176 .45887 .74918 .4537 .74476 Metetra
.977 .099 0 r
.4537 .74476 .45887 .74918 .46791 .7466 .46276 .74216 Metetra
.976 .102 0 r
.46276 .74216 .46791 .7466 .47698 .74401 .47185 .73956 Metetra
.975 .104 0 r
.47185 .73956 .47698 .74401 .48608 .74143 .48097 .73696 Metetra
.975 .106 0 r
.48097 .73696 .48608 .74143 .4952 .73884 .49012 .73435 Metetra
.975 .108 0 r
.49012 .73435 .4952 .73884 .50436 .73625 .4993 .73175 Metetra
.974 .109 0 r
.4993 .73175 .50436 .73625 .51355 .73366 .5085 .72914 Metetra
.974 .111 0 r
.5085 .72914 .51355 .73366 .52277 .73107 .51774 .72654 Metetra
.973 .112 0 r
.51774 .72654 .52277 .73107 .53202 .72848 .52701 .72393 Metetra
.973 .114 0 r
.52701 .72393 .53202 .72848 .5413 .72589 .53631 .72132 Metetra
.973 .115 0 r
.53631 .72132 .5413 .72589 .55061 .72329 .54565 .71871 Metetra
.972 .116 0 r
.54565 .71871 .55061 .72329 .55995 .7207 .55501 .7161 Metetra
.972 .117 0 r
.55501 .7161 .55995 .7207 .56933 .7181 .56441 .71348 Metetra
.972 .118 0 r
.56441 .71348 .56933 .7181 .57873 .7155 .57383 .71087 Metetra
.972 .119 0 r
.57383 .71087 .57873 .7155 .58817 .7129 .58329 .70825 Metetra
.972 .12 0 r
.58329 .70825 .58817 .7129 .59764 .71029 .59278 .70563 Metetra
.971 .12 0 r
.59278 .70563 .59764 .71029 .60714 .70769 .6023 .703 Metetra
.971 .121 0 r
.6023 .703 .60714 .70769 .61667 .70508 .61186 .70038 Metetra
.971 .121 0 r
.61186 .70038 .61667 .70508 .62624 .70247 .62145 .69775 Metetra
.971 .122 0 r
.62145 .69775 .62624 .70247 .63584 .69986 .63107 .69512 Metetra
.971 .122 0 r
.63107 .69512 .63584 .69986 .64547 .69724 .64073 .69249 Metetra
.971 .122 0 r
.64073 .69249 .64547 .69724 .65514 .69463 .65041 .68986 Metetra
.971 .122 0 r
.65041 .68986 .65514 .69463 .66483 .69201 .66014 .68722 Metetra
.971 .122 0 r
.66014 .68722 .66483 .69201 .67457 .68938 .66989 .68459 Metetra
.971 .122 0 r
.66989 .68459 .67457 .68938 .68433 .68676 .67968 .68195 Metetra
.971 .121 0 r
.67968 .68195 .68433 .68676 .69414 .68413 .68951 .6793 Metetra
.971 .121 0 r
.68951 .6793 .69414 .68413 .70397 .68151 .69937 .67666 Metetra
.971 .12 0 r
.69937 .67666 .70397 .68151 .71384 .67888 .70926 .67401 Metetra
.972 .12 0 r
.70926 .67401 .71384 .67888 .72375 .67624 .71919 .67136 Metetra
.972 .119 0 r
.71919 .67136 .72375 .67624 .73369 .67361 .72916 .66871 Metetra
.972 .118 0 r
.72916 .66871 .73369 .67361 .74366 .67098 .73916 .66606 Metetra
.972 .117 0 r
.73916 .66606 .74366 .67098 .75368 .66834 .74919 .66341 Metetra
.973 .116 0 r
.74919 .66341 .75368 .66834 .76372 .6657 .75927 .66075 Metetra
.973 .114 0 r
.75927 .66075 .76372 .6657 .77381 .66305 .76938 .65809 Metetra
.973 .113 0 r
.76938 .65809 .77381 .66305 .78393 .66041 .77952 .65542 Metetra
.974 .112 0 r
.77952 .65542 .78393 .66041 .79409 .65776 .7897 .65276 Metetra
.974 .11 0 r
.7897 .65276 .79409 .65776 .80428 .65511 .79992 .65009 Metetra
.974 .108 0 r
.79992 .65009 .80428 .65511 .81451 .65245 .81018 .64742 Metetra
.975 .107 0 r
.81018 .64742 .81451 .65245 .82478 .6498 .82048 .64475 Metetra
.975 .105 0 r
.82048 .64475 .82478 .6498 .83509 .64714 .83081 .64207 Metetra
.976 .103 0 r
.83081 .64207 .83509 .64714 .84543 .64448 .84118 .6394 Metetra
.976 .101 0 r
.84118 .6394 .84543 .64448 .85582 .64182 .85159 .63672 Metetra
.977 .098 0 r
.85159 .63672 .85582 .64182 .86624 .63916 .86204 .63404 Metetra
.977 .096 0 r
.86204 .63404 .86624 .63916 .8767 .63649 .87253 .63135 Metetra
.978 .094 0 r
.87253 .63135 .8767 .63649 .8872 .6338 .88306 .62864 Metetra
.978 .092 0 r
.88306 .62864 .8872 .6338 .89772 .63101 .89361 .62584 Metetra
.978 .094 0 r
.89361 .62584 .89772 .63101 .90825 .62789 .90417 .6227 Metetra
.975 .105 0 r
.90417 .6227 .90825 .62789 .91871 .62381 .91466 .6186 Metetra
.966 .142 0 r
.91466 .6186 .91871 .62381 .92892 .61734 .92489 .6121 Metetra
.943 .232 0 r
.92489 .6121 .92892 .61734 .93854 .60586 .93455 .60058 Metetra
.895 .409 0 r
.93455 .60058 .93854 .60586 .94707 .58573 .94312 .58039 Metetra
.806 .677 0 r
.94312 .58039 .94707 .58573 .954 .55355 .9501 .54813 Metetra
.374 .668 0 r
.9501 .54813 .954 .55355 .95909 .50838 .95524 .50284 Metetra
.083 .572 0 r
.35658 .6443 .36178 .64892 .36819 .69208 .36293 .68752 Metetra
.637 .738 0 r
.36293 .68752 .36819 .69208 .37531 .72416 .37002 .71965 Metetra
.853 .545 0 r
.37002 .71965 .37531 .72416 .38312 .74395 .3778 .73947 Metetra
.921 .315 0 r
.3778 .73947 .38312 .74395 .39144 .75368 .38612 .74922 Metetra
.956 .181 0 r
.38612 .74922 .39144 .75368 .40007 .75688 .39477 .75242 Metetra
.972 .12 0 r
.39477 .75242 .40007 .75688 .40887 .75663 .40358 .75215 Metetra
.977 .097 0 r
.40358 .75215 .40887 .75663 .41776 .75484 .41249 .75035 Metetra
.978 .092 0 r
.41249 .75035 .41776 .75484 .4267 .75248 .42144 .74798 Metetra
.978 .092 0 r
.42144 .74798 .4267 .75248 .43567 .74994 .43043 .74543 Metetra
.978 .094 0 r
.43043 .74543 .43567 .74994 .44467 .74736 .43945 .74283 Metetra
.977 .096 0 r
.43945 .74283 .44467 .74736 .4537 .74476 .4485 .74021 Metetra
.977 .099 0 r
.4485 .74021 .4537 .74476 .46276 .74216 .45758 .7376 Metetra
.976 .101 0 r
.45758 .7376 .46276 .74216 .47185 .73956 .46669 .73498 Metetra
.976 .103 0 r
.46669 .73498 .47185 .73956 .48097 .73696 .47583 .73237 Metetra
.975 .105 0 r
.47583 .73237 .48097 .73696 .49012 .73435 .485 .72975 Metetra
.975 .107 0 r
.485 .72975 .49012 .73435 .4993 .73175 .4942 .72713 Metetra
.974 .109 0 r
.4942 .72713 .4993 .73175 .5085 .72914 .50343 .72451 Metetra
.974 .11 0 r
.50343 .72451 .5085 .72914 .51774 .72654 .51269 .72189 Metetra
.974 .112 0 r
.51269 .72189 .51774 .72654 .52701 .72393 .52198 .71926 Metetra
.973 .113 0 r
.52198 .71926 .52701 .72393 .53631 .72132 .5313 .71664 Metetra
.973 .114 0 r
.5313 .71664 .53631 .72132 .54565 .71871 .54065 .71401 Metetra
.973 .116 0 r
.54065 .71401 .54565 .71871 .55501 .7161 .55004 .71138 Metetra
.972 .117 0 r
.55004 .71138 .55501 .7161 .56441 .71348 .55945 .70875 Metetra
.972 .118 0 r
.55945 .70875 .56441 .71348 .57383 .71087 .5689 .70612 Metetra
.972 .118 0 r
.5689 .70612 .57383 .71087 .58329 .70825 .57838 .70348 Metetra
.972 .119 0 r
.57838 .70348 .58329 .70825 .59278 .70563 .58789 .70085 Metetra
.972 .12 0 r
.58789 .70085 .59278 .70563 .6023 .703 .59744 .69821 Metetra
.971 .12 0 r
.59744 .69821 .6023 .703 .61186 .70038 .60702 .69557 Metetra
.971 .121 0 r
.60702 .69557 .61186 .70038 .62145 .69775 .61663 .69292 Metetra
.971 .121 0 r
.61663 .69292 .62145 .69775 .63107 .69512 .62627 .69028 Metetra
.971 .121 0 r
.62627 .69028 .63107 .69512 .64073 .69249 .63595 .68763 Metetra
.971 .121 0 r
.63595 .68763 .64073 .69249 .65041 .68986 .64566 .68498 Metetra
.971 .121 0 r
.64566 .68498 .65041 .68986 .66014 .68722 .6554 .68233 Metetra
.971 .121 0 r
.6554 .68233 .66014 .68722 .66989 .68459 .66518 .67967 Metetra
.971 .121 0 r
.66518 .67967 .66989 .68459 .67968 .68195 .675 .67701 Metetra
.971 .12 0 r
.675 .67701 .67968 .68195 .68951 .6793 .68484 .67435 Metetra
.971 .12 0 r
.68484 .67435 .68951 .6793 .69937 .67666 .69473 .67169 Metetra
.972 .119 0 r
.69473 .67169 .69937 .67666 .70926 .67401 .70465 .66903 Metetra
.972 .119 0 r
.70465 .66903 .70926 .67401 .71919 .67136 .7146 .66636 Metetra
.972 .118 0 r
.7146 .66636 .71919 .67136 .72916 .66871 .72459 .66369 Metetra
.972 .117 0 r
.72459 .66369 .72916 .66871 .73916 .66606 .73461 .66103 Metetra
.972 .116 0 r
.73461 .66103 .73916 .66606 .74919 .66341 .74467 .65835 Metetra
.973 .115 0 r
.74467 .65835 .74919 .66341 .75927 .66075 .75477 .65567 Metetra
.973 .114 0 r
.75477 .65567 .75927 .66075 .76938 .65809 .76491 .653 Metetra
.973 .112 0 r
.76491 .653 .76938 .65809 .77952 .65542 .77508 .65031 Metetra
.974 .111 0 r
.77508 .65031 .77952 .65542 .7897 .65276 .78529 .64763 Metetra
.974 .109 0 r
.78529 .64763 .7897 .65276 .79992 .65009 .79553 .64494 Metetra
.974 .108 0 r
.79553 .64494 .79992 .65009 .81018 .64742 .80581 .64226 Metetra
.975 .106 0 r
.80581 .64226 .81018 .64742 .82048 .64475 .81614 .63957 Metetra
.975 .104 0 r
.81614 .63957 .82048 .64475 .83081 .64207 .8265 .63687 Metetra
.976 .102 0 r
.8265 .63687 .83081 .64207 .84118 .6394 .83689 .63418 Metetra
.976 .1 0 r
.83689 .63418 .84118 .6394 .85159 .63672 .84733 .63148 Metetra
.977 .098 0 r
.84733 .63148 .85159 .63672 .86204 .63404 .85781 .62879 Metetra
.978 .095 0 r
.85781 .62879 .86204 .63404 .87253 .63135 .86832 .62608 Metetra
.978 .093 0 r
.86832 .62608 .87253 .63135 .88306 .62864 .87887 .62335 Metetra
.978 .091 0 r
.87887 .62335 .88306 .62864 .89361 .62584 .88946 .62052 Metetra
.978 .093 0 r
.88946 .62052 .89361 .62584 .90417 .6227 .90004 .61737 Metetra
.975 .104 0 r
.90004 .61737 .90417 .6227 .91466 .6186 .91056 .61325 Metetra
.966 .141 0 r
.91056 .61325 .91466 .6186 .92489 .6121 .92083 .60672 Metetra
.943 .231 0 r
.92083 .60672 .92489 .6121 .93455 .60058 .93052 .59516 Metetra
.895 .408 0 r
.93052 .59516 .93455 .60058 .94312 .58039 .93913 .57492 Metetra
.806 .677 0 r
.93913 .57492 .94312 .58039 .9501 .54813 .94616 .54257 Metetra
.375 .668 0 r
.94616 .54257 .9501 .54813 .95524 .50284 .95136 .49719 Metetra
.083 .572 0 r
.35135 .63963 .35658 .6443 .36293 .68752 .35765 .68292 Metetra
.636 .737 0 r
.35765 .68292 .36293 .68752 .37002 .71965 .36469 .7151 Metetra
.852 .545 0 r
.36469 .7151 .37002 .71965 .3778 .73947 .37246 .73494 Metetra
.921 .315 0 r
.37246 .73494 .3778 .73947 .38612 .74922 .38078 .7447 Metetra
.956 .182 0 r
.38078 .7447 .38612 .74922 .39477 .75242 .38943 .7479 Metetra
.971 .12 0 r
.38943 .7479 .39477 .75242 .40358 .75215 .39826 .74763 Metetra
.977 .098 0 r
.39826 .74763 .40358 .75215 .41249 .75035 .40718 .74581 Metetra
.978 .092 0 r
.40718 .74581 .41249 .75035 .42144 .74798 .41616 .74343 Metetra
.978 .092 0 r
.41616 .74343 .42144 .74798 .43043 .74543 .42517 .74086 Metetra
.978 .094 0 r
.42517 .74086 .43043 .74543 .43945 .74283 .43421 .73825 Metetra
.977 .097 0 r
.43421 .73825 .43945 .74283 .4485 .74021 .44328 .73561 Metetra
.977 .099 0 r
.44328 .73561 .4485 .74021 .45758 .7376 .45237 .73299 Metetra
.976 .101 0 r
.45237 .73299 .45758 .7376 .46669 .73498 .4615 .73035 Metetra
.976 .103 0 r
.4615 .73035 .46669 .73498 .47583 .73237 .47066 .72772 Metetra
.975 .105 0 r
.47066 .72772 .47583 .73237 .485 .72975 .47985 .72509 Metetra
.975 .107 0 r
.47985 .72509 .485 .72975 .4942 .72713 .48907 .72246 Metetra
.974 .109 0 r
.48907 .72246 .4942 .72713 .50343 .72451 .49832 .71982 Metetra
.974 .11 0 r
.49832 .71982 .50343 .72451 .51269 .72189 .5076 .71718 Metetra
.973 .112 0 r
.5076 .71718 .51269 .72189 .52198 .71926 .51691 .71454 Metetra
.973 .113 0 r
.51691 .71454 .52198 .71926 .5313 .71664 .52625 .7119 Metetra
.973 .115 0 r
.52625 .7119 .5313 .71664 .54065 .71401 .53563 .70926 Metetra
.973 .116 0 r
.53563 .70926 .54065 .71401 .55004 .71138 .54503 .70661 Metetra
.972 .117 0 r
.54503 .70661 .55004 .71138 .55945 .70875 .55447 .70396 Metetra
.972 .118 0 r
.55447 .70396 .55945 .70875 .5689 .70612 .56394 .70132 Metetra
.972 .119 0 r
.56394 .70132 .5689 .70612 .57838 .70348 .57344 .69866 Metetra
.972 .119 0 r
.57344 .69866 .57838 .70348 .58789 .70085 .58297 .69601 Metetra
.972 .12 0 r
.58297 .69601 .58789 .70085 .59744 .69821 .59254 .69336 Metetra
.971 .12 0 r
.59254 .69336 .59744 .69821 .60702 .69557 .60214 .6907 Metetra
.971 .121 0 r
.60214 .6907 .60702 .69557 .61663 .69292 .61177 .68804 Metetra
.971 .121 0 r
.61177 .68804 .61663 .69292 .62627 .69028 .62144 .68538 Metetra
.971 .121 0 r
.62144 .68538 .62627 .69028 .63595 .68763 .63114 .68271 Metetra
.971 .121 0 r
.63114 .68271 .63595 .68763 .64566 .68498 .64087 .68004 Metetra
.971 .121 0 r
.64087 .68004 .64566 .68498 .6554 .68233 .65064 .67737 Metetra
.971 .121 0 r
.65064 .67737 .6554 .68233 .66518 .67967 .66044 .6747 Metetra
.971 .121 0 r
.66044 .6747 .66518 .67967 .675 .67701 .67028 .67203 Metetra
.971 .121 0 r
.67028 .67203 .675 .67701 .68484 .67435 .68015 .66935 Metetra
.971 .12 0 r
.68015 .66935 .68484 .67435 .69473 .67169 .69006 .66667 Metetra
.972 .12 0 r
.69006 .66667 .69473 .67169 .70465 .66903 .7 .66399 Metetra
.972 .119 0 r
.7 .66399 .70465 .66903 .7146 .66636 .70998 .6613 Metetra
.972 .118 0 r
.70998 .6613 .7146 .66636 .72459 .66369 .71999 .65861 Metetra
.972 .117 0 r
.71999 .65861 .72459 .66369 .73461 .66103 .73004 .65593 Metetra
.972 .116 0 r
.73004 .65593 .73461 .66103 .74467 .65835 .74013 .65324 Metetra
.973 .115 0 r
.74013 .65324 .74467 .65835 .75477 .65567 .75025 .65055 Metetra
.973 .114 0 r
.75025 .65055 .75477 .65567 .76491 .653 .76041 .64785 Metetra
.973 .113 0 r
.76041 .64785 .76491 .653 .77508 .65031 .7706 .64515 Metetra
.974 .111 0 r
.7706 .64515 .77508 .65031 .78529 .64763 .78084 .64245 Metetra
.974 .11 0 r
.78084 .64245 .78529 .64763 .79553 .64494 .79111 .63974 Metetra
.974 .108 0 r
.79111 .63974 .79553 .64494 .80581 .64226 .80142 .63704 Metetra
.975 .106 0 r
.80142 .63704 .80581 .64226 .81614 .63957 .81176 .63433 Metetra
.975 .104 0 r
.81176 .63433 .81614 .63957 .8265 .63687 .82215 .63162 Metetra
.976 .102 0 r
.82215 .63162 .8265 .63687 .83689 .63418 .83258 .6289 Metetra
.976 .1 0 r
.83258 .6289 .83689 .63418 .84733 .63148 .84304 .62619 Metetra
.977 .098 0 r
.84304 .62619 .84733 .63148 .85781 .62879 .85354 .62347 Metetra
.977 .095 0 r
.85354 .62347 .85781 .62879 .86832 .62608 .86408 .62074 Metetra
.978 .093 0 r
.86408 .62074 .86832 .62608 .87887 .62335 .87466 .61799 Metetra
.978 .092 0 r
.87466 .61799 .87887 .62335 .88946 .62052 .88527 .61515 Metetra
.978 .093 0 r
.88527 .61515 .88946 .62052 .90004 .61737 .89589 .61197 Metetra
.975 .105 0 r
.89589 .61197 .90004 .61737 .91056 .61325 .90643 .60783 Metetra
.966 .141 0 r
.90643 .60783 .91056 .61325 .92083 .60672 .91673 .60127 Metetra
.943 .232 0 r
.91673 .60127 .92083 .60672 .93052 .59516 .92646 .58967 Metetra
.895 .408 0 r
.92646 .58967 .93052 .59516 .93913 .57492 .93511 .56937 Metetra
.806 .677 0 r
.93511 .56937 .93913 .57492 .94616 .54257 .94219 .53696 Metetra
.374 .668 0 r
.94219 .53696 .94616 .54257 .95136 .49719 .94745 .49148 Metetra
.082 .572 0 r
.3461 .63494 .35135 .63963 .35765 .68292 .35233 .67829 Metetra
.635 .737 0 r
.35233 .67829 .35765 .68292 .36469 .7151 .35934 .71051 Metetra
.852 .546 0 r
.35934 .71051 .36469 .7151 .37246 .73494 .36709 .73039 Metetra
.921 .316 0 r
.36709 .73039 .37246 .73494 .38078 .7447 .3754 .74016 Metetra
.956 .182 0 r
.3754 .74016 .38078 .7447 .38943 .7479 .38406 .74335 Metetra
.971 .121 0 r
.38406 .74335 .38943 .7479 .39826 .74763 .39291 .74307 Metetra
.977 .098 0 r
.39291 .74307 .39826 .74763 .40718 .74581 .40185 .74124 Metetra
.978 .092 0 r
.40185 .74124 .40718 .74581 .41616 .74343 .41084 .73884 Metetra
.978 .093 0 r
.41084 .73884 .41616 .74343 .42517 .74086 .41987 .73626 Metetra
.978 .095 0 r
.41987 .73626 .42517 .74086 .43421 .73825 .42893 .73363 Metetra
.977 .097 0 r
.42893 .73363 .43421 .73825 .44328 .73561 .43801 .73098 Metetra
.977 .099 0 r
.43801 .73098 .44328 .73561 .45237 .73299 .44713 .72834 Metetra
.976 .102 0 r
.44713 .72834 .45237 .73299 .4615 .73035 .45628 .72569 Metetra
.975 .104 0 r
.45628 .72569 .4615 .73035 .47066 .72772 .46546 .72305 Metetra
.975 .106 0 r
.46546 .72305 .47066 .72772 .47985 .72509 .47467 .7204 Metetra
.975 .107 0 r
.47467 .7204 .47985 .72509 .48907 .72246 .48391 .71775 Metetra
.974 .109 0 r
.48391 .71775 .48907 .72246 .49832 .71982 .49318 .71509 Metetra
.974 .111 0 r
.49318 .71509 .49832 .71982 .5076 .71718 .50248 .71244 Metetra
.973 .112 0 r
.50248 .71244 .5076 .71718 .51691 .71454 .51181 .70979 Metetra
.973 .114 0 r
.51181 .70979 .51691 .71454 .52625 .7119 .52117 .70713 Metetra
.973 .115 0 r
.52117 .70713 .52625 .7119 .53563 .70926 .53057 .70447 Metetra
.972 .116 0 r
.53057 .70447 .53563 .70926 .54503 .70661 .53999 .70181 Metetra
.972 .117 0 r
.53999 .70181 .54503 .70661 .55447 .70396 .54945 .69915 Metetra
.972 .118 0 r
.54945 .69915 .55447 .70396 .56394 .70132 .55894 .69648 Metetra
.972 .119 0 r
.55894 .69648 .56394 .70132 .57344 .69866 .56847 .69381 Metetra
.972 .12 0 r
.56847 .69381 .57344 .69866 .58297 .69601 .57802 .69114 Metetra
.971 .12 0 r
.57802 .69114 .58297 .69601 .59254 .69336 .58761 .68847 Metetra
.971 .121 0 r
.58761 .68847 .59254 .69336 .60214 .6907 .59723 .6858 Metetra
.971 .121 0 r
.59723 .6858 .60214 .6907 .61177 .68804 .60689 .68312 Metetra
.971 .121 0 r
.60689 .68312 .61177 .68804 .62144 .68538 .61658 .68044 Metetra
.971 .122 0 r
.61658 .68044 .62144 .68538 .63114 .68271 .6263 .67776 Metetra
.971 .122 0 r
.6263 .67776 .63114 .68271 .64087 .68004 .63606 .67508 Metetra
.971 .122 0 r
.63606 .67508 .64087 .68004 .65064 .67737 .64585 .67239 Metetra
.971 .122 0 r
.64585 .67239 .65064 .67737 .66044 .6747 .65567 .6697 Metetra
.971 .121 0 r
.65567 .6697 .66044 .6747 .67028 .67203 .66553 .66701 Metetra
.971 .121 0 r
.66553 .66701 .67028 .67203 .68015 .66935 .67543 .66431 Metetra
.971 .121 0 r
.67543 .66431 .68015 .66935 .69006 .66667 .68536 .66161 Metetra
.971 .12 0 r
.68536 .66161 .69006 .66667 .7 .66399 .69532 .65891 Metetra
.972 .119 0 r
.69532 .65891 .7 .66399 .70998 .6613 .70532 .65621 Metetra
.972 .119 0 r
.70532 .65621 .70998 .6613 .71999 .65861 .71536 .6535 Metetra
.972 .118 0 r
.71536 .6535 .71999 .65861 .73004 .65593 .72544 .6508 Metetra
.972 .117 0 r
.72544 .6508 .73004 .65593 .74013 .65324 .73555 .64809 Metetra
.973 .116 0 r
.73555 .64809 .74013 .65324 .75025 .65055 .74569 .64538 Metetra
.973 .114 0 r
.74569 .64538 .75025 .65055 .76041 .64785 .75588 .64267 Metetra
.973 .113 0 r
.75588 .64267 .76041 .64785 .7706 .64515 .7661 .63995 Metetra
.974 .112 0 r
.7661 .63995 .7706 .64515 .78084 .64245 .77636 .63723 Metetra
.974 .11 0 r
.77636 .63723 .78084 .64245 .79111 .63974 .78666 .6345 Metetra
.974 .108 0 r
.78666 .6345 .79111 .63974 .80142 .63704 .79699 .63178 Metetra
.975 .107 0 r
.79699 .63178 .80142 .63704 .81176 .63433 .80736 .62905 Metetra
.975 .105 0 r
.80736 .62905 .81176 .63433 .82215 .63162 .81778 .62632 Metetra
.976 .103 0 r
.81778 .62632 .82215 .63162 .83258 .6289 .82823 .62359 Metetra
.976 .1 0 r
.82823 .62359 .83258 .6289 .84304 .62619 .83872 .62085 Metetra
.977 .098 0 r
.83872 .62085 .84304 .62619 .85354 .62347 .84925 .61811 Metetra
.977 .096 0 r
.84925 .61811 .85354 .62347 .86408 .62074 .85982 .61537 Metetra
.978 .094 0 r
.85982 .61537 .86408 .62074 .87466 .61799 .87042 .6126 Metetra
.978 .092 0 r
.87042 .6126 .87466 .61799 .88527 .61515 .88106 .60973 Metetra
.978 .094 0 r
.88106 .60973 .88527 .61515 .89589 .61197 .8917 .60653 Metetra
.975 .105 0 r
.8917 .60653 .89589 .61197 .90643 .60783 .90228 .60237 Metetra
.966 .142 0 r
.90228 .60237 .90643 .60783 .91673 .60127 .91261 .59578 Metetra
.943 .232 0 r
.91261 .59578 .91673 .60127 .92646 .58967 .92237 .58414 Metetra
.895 .409 0 r
.92237 .58414 .92646 .58967 .93511 .56937 .93107 .56379 Metetra
.806 .678 0 r
.93107 .56379 .93511 .56937 .94219 .53696 .9382 .5313 Metetra
.373 .668 0 r
.9382 .5313 .94219 .53696 .94745 .49148 .94352 .48574 Metetra
.082 .571 0 r
.34081 .63022 .3461 .63494 .35233 .67829 .34698 .67363 Metetra
.634 .737 0 r
.34698 .67363 .35233 .67829 .35934 .71051 .35395 .7059 Metetra
.852 .546 0 r
.35395 .7059 .35934 .71051 .36709 .73039 .36168 .7258 Metetra
.921 .316 0 r
.36168 .7258 .36709 .73039 .3754 .74016 .36999 .73558 Metetra
.956 .183 0 r
.36999 .73558 .3754 .74016 .38406 .74335 .37866 .73878 Metetra
.971 .121 0 r
.37866 .73878 .38406 .74335 .39291 .74307 .38752 .73849 Metetra
.977 .099 0 r
.38752 .73849 .39291 .74307 .40185 .74124 .39648 .73664 Metetra
.978 .093 0 r
.39648 .73664 .40185 .74124 .41084 .73884 .40549 .73423 Metetra
.978 .093 0 r
.40549 .73423 .41084 .73884 .41987 .73626 .41454 .73163 Metetra
.978 .095 0 r
.41454 .73163 .41987 .73626 .42893 .73363 .42361 .72899 Metetra
.977 .097 0 r
.42361 .72899 .42893 .73363 .43801 .73098 .43272 .72633 Metetra
.976 .1 0 r
.43272 .72633 .43801 .73098 .44713 .72834 .44186 .72367 Metetra
.976 .102 0 r
.44186 .72367 .44713 .72834 .45628 .72569 .45103 .72101 Metetra
.975 .104 0 r
.45103 .72101 .45628 .72569 .46546 .72305 .46023 .71834 Metetra
.975 .106 0 r
.46023 .71834 .46546 .72305 .47467 .7204 .46945 .71568 Metetra
.974 .108 0 r
.46945 .71568 .47467 .7204 .48391 .71775 .47871 .71301 Metetra
.974 .11 0 r
.47871 .71301 .48391 .71775 .49318 .71509 .488 .71034 Metetra
.974 .111 0 r
.488 .71034 .49318 .71509 .50248 .71244 .49732 .70768 Metetra
.973 .113 0 r
.49732 .70768 .50248 .71244 .51181 .70979 .50668 .705 Metetra
.973 .114 0 r
.50668 .705 .51181 .70979 .52117 .70713 .51606 .70233 Metetra
.973 .115 0 r
.51606 .70233 .52117 .70713 .53057 .70447 .52548 .69965 Metetra
.972 .116 0 r
.52548 .69965 .53057 .70447 .53999 .70181 .53492 .69698 Metetra
.972 .118 0 r
.53492 .69698 .53999 .70181 .54945 .69915 .5444 .6943 Metetra
.972 .118 0 r
.5444 .6943 .54945 .69915 .55894 .69648 .55392 .69162 Metetra
.972 .119 0 r
.55392 .69162 .55894 .69648 .56847 .69381 .56346 .68893 Metetra
.971 .12 0 r
.56346 .68893 .56847 .69381 .57802 .69114 .57304 .68625 Metetra
.971 .121 0 r
.57304 .68625 .57802 .69114 .58761 .68847 .58265 .68356 Metetra
.971 .121 0 r
.58265 .68356 .58761 .68847 .59723 .6858 .59229 .68087 Metetra
.971 .122 0 r
.59229 .68087 .59723 .6858 .60689 .68312 .60197 .67817 Metetra
.971 .122 0 r
.60197 .67817 .60689 .68312 .61658 .68044 .61168 .67548 Metetra
.971 .122 0 r
.61168 .67548 .61658 .68044 .6263 .67776 .62143 .67278 Metetra
.971 .122 0 r
.62143 .67278 .6263 .67776 .63606 .67508 .63121 .67008 Metetra
.971 .122 0 r
.63121 .67008 .63606 .67508 .64585 .67239 .64102 .66737 Metetra
.971 .122 0 r
.64102 .66737 .64585 .67239 .65567 .6697 .65087 .66466 Metetra
.971 .122 0 r
.65087 .66466 .65567 .6697 .66553 .66701 .66075 .66195 Metetra
.971 .121 0 r
.66075 .66195 .66553 .66701 .67543 .66431 .67067 .65924 Metetra
.971 .121 0 r
.67067 .65924 .67543 .66431 .68536 .66161 .68063 .65653 Metetra
.971 .12 0 r
.68063 .65653 .68536 .66161 .69532 .65891 .69062 .65381 Metetra
.972 .12 0 r
.69062 .65381 .69532 .65891 .70532 .65621 .70064 .65109 Metetra
.972 .119 0 r
.70064 .65109 .70532 .65621 .71536 .6535 .7107 .64836 Metetra
.972 .118 0 r
.7107 .64836 .71536 .6535 .72544 .6508 .7208 .64564 Metetra
.972 .117 0 r
.7208 .64564 .72544 .6508 .73555 .64809 .73094 .64292 Metetra
.972 .116 0 r
.73094 .64292 .73555 .64809 .74569 .64538 .74111 .64018 Metetra
.973 .115 0 r
.74111 .64018 .74569 .64538 .75588 .64267 .75132 .63745 Metetra
.973 .113 0 r
.75132 .63745 .75588 .64267 .7661 .63995 .76157 .63471 Metetra
.973 .112 0 r
.76157 .63471 .7661 .63995 .77636 .63723 .77185 .63197 Metetra
.974 .11 0 r
.77185 .63197 .77636 .63723 .78666 .6345 .78217 .62923 Metetra
.974 .109 0 r
.78217 .62923 .78666 .6345 .79699 .63178 .79253 .62649 Metetra
.975 .107 0 r
.79253 .62649 .79699 .63178 .80736 .62905 .80293 .62374 Metetra
.975 .105 0 r
.80293 .62374 .80736 .62905 .81778 .62632 .81337 .62099 Metetra
.976 .103 0 r
.81337 .62099 .81778 .62632 .82823 .62359 .82385 .61824 Metetra
.976 .101 0 r
.82385 .61824 .82823 .62359 .83872 .62085 .83437 .61548 Metetra
.977 .099 0 r
.83437 .61548 .83872 .62085 .84925 .61811 .84492 .61272 Metetra
.977 .096 0 r
.84492 .61272 .84925 .61811 .85982 .61537 .85552 .60996 Metetra
.978 .094 0 r
.85552 .60996 .85982 .61537 .87042 .6126 .86616 .60717 Metetra
.978 .093 0 r
.86616 .60717 .87042 .6126 .88106 .60973 .87682 .60428 Metetra
.978 .094 0 r
.87682 .60428 .88106 .60973 .8917 .60653 .88749 .60106 Metetra
.975 .106 0 r
.88749 .60106 .8917 .60653 .90228 .60237 .8981 .59687 Metetra
.966 .143 0 r
.8981 .59687 .90228 .60237 .91261 .59578 .90846 .59026 Metetra
.943 .233 0 r
.90846 .59026 .91261 .59578 .92237 .58414 .91825 .57858 Metetra
.894 .409 0 r
.91825 .57858 .92237 .58414 .93107 .56379 .92699 .55818 Metetra
.806 .678 0 r
.92699 .55818 .93107 .56379 .9382 .5313 .93418 .52561 Metetra
.373 .667 0 r
.93418 .52561 .9382 .5313 .94352 .48574 .93956 .47995 Metetra
.081 .571 0 r
.33549 .62547 .34081 .63022 .34698 .67363 .3416 .66894 Metetra
.634 .737 0 r
.3416 .66894 .34698 .67363 .35395 .7059 .34852 .70126 Metetra
.852 .547 0 r
.34852 .70126 .35395 .7059 .36168 .7258 .35623 .7212 Metetra
.921 .317 0 r
.35623 .7212 .36168 .7258 .36999 .73558 .36454 .73098 Metetra
.956 .183 0 r
.36454 .73098 .36999 .73558 .37866 .73878 .37322 .73418 Metetra
.971 .122 0 r
.37322 .73418 .37866 .73878 .38752 .73849 .3821 .73388 Metetra
.977 .099 0 r
.3821 .73388 .38752 .73849 .39648 .73664 .39107 .73202 Metetra
.978 .093 0 r
.39107 .73202 .39648 .73664 .40549 .73423 .4001 .72959 Metetra
.978 .094 0 r
.4001 .72959 .40549 .73423 .41454 .73163 .40917 .72698 Metetra
.977 .096 0 r
.40917 .72698 .41454 .73163 .42361 .72899 .41827 .72432 Metetra
.977 .098 0 r
.41827 .72432 .42361 .72899 .43272 .72633 .42739 .72164 Metetra
.976 .1 0 r
.42739 .72164 .43272 .72633 .44186 .72367 .43655 .71897 Metetra
.976 .102 0 r
.43655 .71897 .44186 .72367 .45103 .72101 .44574 .71629 Metetra
.975 .104 0 r
.44574 .71629 .45103 .72101 .46023 .71834 .45496 .71361 Metetra
.975 .106 0 r
.45496 .71361 .46023 .71834 .46945 .71568 .46421 .71093 Metetra
.974 .108 0 r
.46421 .71093 .46945 .71568 .47871 .71301 .47349 .70825 Metetra
.974 .11 0 r
.47349 .70825 .47871 .71301 .488 .71034 .4828 .70557 Metetra
.974 .112 0 r
.4828 .70557 .488 .71034 .49732 .70768 .49214 .70288 Metetra
.973 .113 0 r
.49214 .70288 .49732 .70768 .50668 .705 .50151 .70019 Metetra
.973 .114 0 r
.50151 .70019 .50668 .705 .51606 .70233 .51092 .69751 Metetra
.973 .116 0 r
.51092 .69751 .51606 .70233 .52548 .69965 .52035 .69481 Metetra
.972 .117 0 r
.52035 .69481 .52548 .69965 .53492 .69698 .52982 .69212 Metetra
.972 .118 0 r
.52982 .69212 .53492 .69698 .5444 .6943 .53932 .68942 Metetra
.972 .119 0 r
.53932 .68942 .5444 .6943 .55392 .69162 .54886 .68673 Metetra
.972 .12 0 r
.54886 .68673 .55392 .69162 .56346 .68893 .55842 .68402 Metetra
.971 .12 0 r
.55842 .68402 .56346 .68893 .57304 .68625 .56802 .68132 Metetra
.971 .121 0 r
.56802 .68132 .57304 .68625 .58265 .68356 .57766 .67861 Metetra
.971 .121 0 r
.57766 .67861 .58265 .68356 .59229 .68087 .58732 .67591 Metetra
.971 .122 0 r
.58732 .67591 .59229 .68087 .60197 .67817 .59702 .67319 Metetra
.971 .122 0 r
.59702 .67319 .60197 .67817 .61168 .67548 .60676 .67048 Metetra
.971 .122 0 r
.60676 .67048 .61168 .67548 .62143 .67278 .61653 .66776 Metetra
.971 .122 0 r
.61653 .66776 .62143 .67278 .63121 .67008 .62633 .66505 Metetra
.971 .122 0 r
.62633 .66505 .63121 .67008 .64102 .66737 .63617 .66232 Metetra
.971 .122 0 r
.63617 .66232 .64102 .66737 .65087 .66466 .64604 .6596 Metetra
.971 .122 0 r
.64604 .6596 .65087 .66466 .66075 .66195 .65594 .65687 Metetra
.971 .122 0 r
.65594 .65687 .66075 .66195 .67067 .65924 .66589 .65414 Metetra
.971 .121 0 r
.66589 .65414 .67067 .65924 .68063 .65653 .67587 .65141 Metetra
.971 .121 0 r
.67587 .65141 .68063 .65653 .69062 .65381 .68588 .64867 Metetra
.971 .12 0 r
.68588 .64867 .69062 .65381 .70064 .65109 .69593 .64593 Metetra
.972 .119 0 r
.69593 .64593 .70064 .65109 .7107 .64836 .70602 .64319 Metetra
.972 .118 0 r
.70602 .64319 .7107 .64836 .7208 .64564 .71614 .64045 Metetra
.972 .117 0 r
.71614 .64045 .7208 .64564 .73094 .64292 .7263 .6377 Metetra
.972 .116 0 r
.7263 .6377 .73094 .64292 .74111 .64018 .7365 .63495 Metetra
.973 .115 0 r
.7365 .63495 .74111 .64018 .75132 .63745 .74673 .6322 Metetra
.973 .114 0 r
.74673 .6322 .75132 .63745 .76157 .63471 .757 .62944 Metetra
.973 .112 0 r
.757 .62944 .76157 .63471 .77185 .63197 .76731 .62669 Metetra
.974 .111 0 r
.76731 .62669 .77185 .63197 .78217 .62923 .77766 .62392 Metetra
.974 .109 0 r
.77766 .62392 .78217 .62923 .79253 .62649 .78805 .62116 Metetra
.975 .107 0 r
.78805 .62116 .79253 .62649 .80293 .62374 .79848 .61839 Metetra
.975 .105 0 r
.79848 .61839 .80293 .62374 .81337 .62099 .80894 .61562 Metetra
.976 .103 0 r
.80894 .61562 .81337 .62099 .82385 .61824 .81944 .61285 Metetra
.976 .101 0 r
.81944 .61285 .82385 .61824 .83437 .61548 .82999 .61008 Metetra
.977 .099 0 r
.82999 .61008 .83437 .61548 .84492 .61272 .84057 .6073 Metetra
.977 .097 0 r
.84057 .6073 .84492 .61272 .85552 .60996 .8512 .60452 Metetra
.978 .094 0 r
.8512 .60452 .85552 .60996 .86616 .60717 .86186 .60171 Metetra
.978 .093 0 r
.86186 .60171 .86616 .60717 .87682 .60428 .87255 .5988 Metetra
.978 .095 0 r
.87255 .5988 .87682 .60428 .88749 .60106 .88325 .59556 Metetra
.975 .106 0 r
.88325 .59556 .88749 .60106 .8981 .59687 .89388 .59134 Metetra
.966 .143 0 r
.89388 .59134 .8981 .59687 .90846 .59026 .90428 .5847 Metetra
.943 .233 0 r
.90428 .5847 .90846 .59026 .91825 .57858 .91411 .57298 Metetra
.894 .41 0 r
.91411 .57298 .91825 .57858 .92699 .55818 .92289 .55252 Metetra
.806 .679 0 r
.92289 .55252 .92699 .55818 .93418 .52561 .93013 .51988 Metetra
.372 .667 0 r
.93013 .51988 .93418 .52561 .93956 .47995 .93557 .47414 Metetra
.081 .571 0 r
.33014 .6207 .33549 .62547 .3416 .66894 .33619 .66423 Metetra
.633 .737 0 r
.33619 .66423 .3416 .66894 .34852 .70126 .34307 .6966 Metetra
.852 .547 0 r
.34307 .6966 .34852 .70126 .35623 .7212 .35076 .71656 Metetra
.92 .317 0 r
.35076 .71656 .35623 .7212 .36454 .73098 .35906 .72636 Metetra
.956 .184 0 r
.35906 .72636 .36454 .73098 .37322 .73418 .36775 .72955 Metetra
.971 .122 0 r
.36775 .72955 .37322 .73418 .3821 .73388 .37664 .72924 Metetra
.976 .099 0 r
.37664 .72924 .3821 .73388 .39107 .73202 .38564 .72737 Metetra
.978 .094 0 r
.38564 .72737 .39107 .73202 .4001 .72959 .39469 .72493 Metetra
.978 .094 0 r
.39469 .72493 .4001 .72959 .40917 .72698 .40377 .7223 Metetra
.977 .096 0 r
.40377 .7223 .40917 .72698 .41827 .72432 .41289 .71963 Metetra
.977 .098 0 r
.41289 .71963 .41827 .72432 .42739 .72164 .42203 .71693 Metetra
.976 .101 0 r
.42203 .71693 .42739 .72164 .43655 .71897 .43121 .71424 Metetra
.976 .103 0 r
.43121 .71424 .43655 .71897 .44574 .71629 .44042 .71155 Metetra
.975 .105 0 r
.44042 .71155 .44574 .71629 .45496 .71361 .44966 .70886 Metetra
.975 .107 0 r
.44966 .70886 .45496 .71361 .46421 .71093 .45893 .70616 Metetra
.974 .109 0 r
.45893 .70616 .46421 .71093 .47349 .70825 .46823 .70346 Metetra
.974 .11 0 r
.46823 .70346 .47349 .70825 .4828 .70557 .47756 .70076 Metetra
.973 .112 0 r
.47756 .70076 .4828 .70557 .49214 .70288 .48692 .69806 Metetra
.973 .113 0 r
.48692 .69806 .49214 .70288 .50151 .70019 .49631 .69535 Metetra
.973 .115 0 r
.49631 .69535 .50151 .70019 .51092 .69751 .50574 .69265 Metetra
.972 .116 0 r
.50574 .69265 .51092 .69751 .52035 .69481 .5152 .68994 Metetra
.972 .117 0 r
.5152 .68994 .52035 .69481 .52982 .69212 .52469 .68723 Metetra
.972 .118 0 r
.52469 .68723 .52982 .69212 .53932 .68942 .53421 .68452 Metetra
.972 .119 0 r
.53421 .68452 .53932 .68942 .54886 .68673 .54377 .6818 Metetra
.972 .12 0 r
.54377 .6818 .54886 .68673 .55842 .68402 .55336 .67908 Metetra
.971 .121 0 r
.55336 .67908 .55842 .68402 .56802 .68132 .56298 .67636 Metetra
.971 .121 0 r
.56298 .67636 .56802 .68132 .57766 .67861 .57263 .67364 Metetra
.971 .122 0 r
.57263 .67364 .57766 .67861 .58732 .67591 .58232 .67092 Metetra
.971 .122 0 r
.58232 .67092 .58732 .67591 .59702 .67319 .59204 .66819 Metetra
.971 .122 0 r
.59204 .66819 .59702 .67319 .60676 .67048 .6018 .66546 Metetra
.971 .123 0 r
.6018 .66546 .60676 .67048 .61653 .66776 .61159 .66272 Metetra
.971 .123 0 r
.61159 .66272 .61653 .66776 .62633 .66505 .62142 .65998 Metetra
.971 .123 0 r
.62142 .65998 .62633 .66505 .63617 .66232 .63128 .65724 Metetra
.971 .123 0 r
.63128 .65724 .63617 .66232 .64604 .6596 .64117 .6545 Metetra
.971 .122 0 r
.64117 .6545 .64604 .6596 .65594 .65687 .6511 .65176 Metetra
.971 .122 0 r
.6511 .65176 .65594 .65687 .66589 .65414 .66107 .64901 Metetra
.971 .122 0 r
.66107 .64901 .66589 .65414 .67587 .65141 .67107 .64626 Metetra
.971 .121 0 r
.67107 .64626 .67587 .65141 .68588 .64867 .68111 .6435 Metetra
.971 .12 0 r
.68111 .6435 .68588 .64867 .69593 .64593 .69119 .64074 Metetra
.972 .12 0 r
.69119 .64074 .69593 .64593 .70602 .64319 .7013 .63798 Metetra
.972 .119 0 r
.7013 .63798 .70602 .64319 .71614 .64045 .71144 .63523 Metetra
.972 .118 0 r
.71144 .63523 .71614 .64045 .7263 .6377 .72163 .63246 Metetra
.972 .117 0 r
.72163 .63246 .7263 .6377 .7365 .63495 .73185 .62969 Metetra
.973 .115 0 r
.73185 .62969 .7365 .63495 .74673 .6322 .74211 .62692 Metetra
.973 .114 0 r
.74211 .62692 .74673 .6322 .757 .62944 .75241 .62414 Metetra
.973 .113 0 r
.75241 .62414 .757 .62944 .76731 .62669 .76275 .62137 Metetra
.974 .111 0 r
.76275 .62137 .76731 .62669 .77766 .62392 .77312 .61859 Metetra
.974 .109 0 r
.77312 .61859 .77766 .62392 .78805 .62116 .78353 .6158 Metetra
.974 .108 0 r
.78353 .6158 .78805 .62116 .79848 .61839 .79399 .61302 Metetra
.975 .106 0 r
.79399 .61302 .79848 .61839 .80894 .61562 .80448 .61023 Metetra
.975 .104 0 r
.80448 .61023 .80894 .61562 .81944 .61285 .81501 .60743 Metetra
.976 .102 0 r
.81501 .60743 .81944 .61285 .82999 .61008 .82558 .60464 Metetra
.976 .099 0 r
.82558 .60464 .82999 .61008 .84057 .6073 .83619 .60184 Metetra
.977 .097 0 r
.83619 .60184 .84057 .6073 .8512 .60452 .84684 .59904 Metetra
.978 .095 0 r
.84684 .59904 .8512 .60452 .86186 .60171 .85753 .59621 Metetra
.978 .093 0 r
.85753 .59621 .86186 .60171 .87255 .5988 .86826 .59328 Metetra
.978 .095 0 r
.86826 .59328 .87255 .5988 .88325 .59556 .87898 .59002 Metetra
.975 .107 0 r
.87898 .59002 .88325 .59556 .89388 .59134 .88965 .58578 Metetra
.966 .143 0 r
.88965 .58578 .89388 .59134 .90428 .5847 .90007 .5791 Metetra
.943 .234 0 r
.90007 .5791 .90428 .5847 .91411 .57298 .90994 .56735 Metetra
.894 .41 0 r
.90994 .56735 .91411 .57298 .92289 .55252 .91877 .54684 Metetra
.805 .679 0 r
.91877 .54684 .92289 .55252 .93013 .51988 .92605 .51412 Metetra
.372 .667 0 r
.92605 .51412 .93013 .51988 .93557 .47414 .93156 .46828 Metetra
.08 .571 0 r
.32476 .61591 .33014 .6207 .33619 .66423 .33075 .6595 Metetra
.632 .737 0 r
.33075 .6595 .33619 .66423 .34307 .6966 .33758 .69191 Metetra
.852 .548 0 r
.33758 .69191 .34307 .6966 .35076 .71656 .34525 .7119 Metetra
.92 .318 0 r
.34525 .7119 .35076 .71656 .35906 .72636 .35355 .72171 Metetra
.956 .184 0 r
.35355 .72171 .35906 .72636 .36775 .72955 .36225 .7249 Metetra
.971 .122 0 r
.36225 .7249 .36775 .72955 .37664 .72924 .37116 .72458 Metetra
.976 .1 0 r
.37116 .72458 .37664 .72924 .38564 .72737 .38017 .72269 Metetra
.978 .094 0 r
.38017 .72269 .38564 .72737 .39469 .72493 .38923 .72024 Metetra
.978 .094 0 r
.38923 .72024 .39469 .72493 .40377 .7223 .39834 .71759 Metetra
.977 .096 0 r
.39834 .71759 .40377 .7223 .41289 .71963 .40747 .7149 Metetra
.977 .099 0 r
.40747 .7149 .41289 .71963 .42203 .71693 .41664 .71219 Metetra
.976 .101 0 r
.41664 .71219 .42203 .71693 .43121 .71424 .42584 .70949 Metetra
.976 .103 0 r
.42584 .70949 .43121 .71424 .44042 .71155 .43507 .70678 Metetra
.975 .105 0 r
.43507 .70678 .44042 .71155 .44966 .70886 .44432 .70407 Metetra
.975 .107 0 r
.44432 .70407 .44966 .70886 .45893 .70616 .45361 .70135 Metetra
.974 .109 0 r
.45361 .70135 .45893 .70616 .46823 .70346 .46293 .69864 Metetra
.974 .111 0 r
.46293 .69864 .46823 .70346 .47756 .70076 .47229 .69592 Metetra
.973 .112 0 r
.47229 .69592 .47756 .70076 .48692 .69806 .48167 .69321 Metetra
.973 .114 0 r
.48167 .69321 .48692 .69806 .49631 .69535 .49108 .69049 Metetra
.973 .115 0 r
.49108 .69049 .49631 .69535 .50574 .69265 .50053 .68776 Metetra
.972 .116 0 r
.50053 .68776 .50574 .69265 .5152 .68994 .51001 .68504 Metetra
.972 .117 0 r
.51001 .68504 .5152 .68994 .52469 .68723 .51952 .68231 Metetra
.972 .119 0 r
.51952 .68231 .52469 .68723 .53421 .68452 .52907 .67958 Metetra
.972 .119 0 r
.52907 .67958 .53421 .68452 .54377 .6818 .53864 .67685 Metetra
.971 .12 0 r
.53864 .67685 .54377 .6818 .55336 .67908 .54825 .67411 Metetra
.971 .121 0 r
.54825 .67411 .55336 .67908 .56298 .67636 .5579 .67138 Metetra
.971 .122 0 r
.5579 .67138 .56298 .67636 .57263 .67364 .56758 .66864 Metetra
.971 .122 0 r
.56758 .66864 .57263 .67364 .58232 .67092 .57729 .66589 Metetra
.971 .122 0 r
.57729 .66589 .58232 .67092 .59204 .66819 .58703 .66315 Metetra
.971 .123 0 r
.58703 .66315 .59204 .66819 .6018 .66546 .59681 .6604 Metetra
.971 .123 0 r
.59681 .6604 .6018 .66546 .61159 .66272 .60663 .65765 Metetra
.971 .123 0 r
.60663 .65765 .61159 .66272 .62142 .65998 .61647 .65489 Metetra
.971 .123 0 r
.61647 .65489 .62142 .65998 .63128 .65724 .62636 .65213 Metetra
.971 .123 0 r
.62636 .65213 .63128 .65724 .64117 .6545 .63628 .64937 Metetra
.971 .123 0 r
.63628 .64937 .64117 .6545 .6511 .65176 .64623 .64661 Metetra
.971 .122 0 r
.64623 .64661 .6511 .65176 .66107 .64901 .65622 .64384 Metetra
.971 .122 0 r
.65622 .64384 .66107 .64901 .67107 .64626 .66625 .64107 Metetra
.971 .121 0 r
.66625 .64107 .67107 .64626 .68111 .6435 .67631 .6383 Metetra
.971 .121 0 r
.67631 .6383 .68111 .6435 .69119 .64074 .68641 .63552 Metetra
.972 .12 0 r
.68641 .63552 .69119 .64074 .7013 .63798 .69655 .63274 Metetra
.972 .119 0 r
.69655 .63274 .7013 .63798 .71144 .63523 .70672 .62997 Metetra
.972 .118 0 r
.70672 .62997 .71144 .63523 .72163 .63246 .71693 .62718 Metetra
.972 .117 0 r
.71693 .62718 .72163 .63246 .73185 .62969 .72718 .6244 Metetra
.973 .116 0 r
.72718 .6244 .73185 .62969 .74211 .62692 .73746 .6216 Metetra
.973 .114 0 r
.73746 .6216 .74211 .62692 .75241 .62414 .74779 .61881 Metetra
.973 .113 0 r
.74779 .61881 .75241 .62414 .76275 .62137 .75815 .61601 Metetra
.974 .111 0 r
.75815 .61601 .76275 .62137 .77312 .61859 .76855 .61321 Metetra
.974 .11 0 r
.76855 .61321 .77312 .61859 .78353 .6158 .77899 .61041 Metetra
.974 .108 0 r
.77899 .61041 .78353 .6158 .79399 .61302 .78947 .6076 Metetra
.975 .106 0 r
.78947 .6076 .79399 .61302 .80448 .61023 .79999 .60479 Metetra
.975 .104 0 r
.79999 .60479 .80448 .61023 .81501 .60743 .81055 .60198 Metetra
.976 .102 0 r
.81055 .60198 .81501 .60743 .82558 .60464 .82114 .59917 Metetra
.976 .1 0 r
.82114 .59917 .82558 .60464 .83619 .60184 .83178 .59635 Metetra
.977 .098 0 r
.83178 .59635 .83619 .60184 .84684 .59904 .84246 .59353 Metetra
.977 .095 0 r
.84246 .59353 .84684 .59904 .85753 .59621 .85318 .59067 Metetra
.978 .094 0 r
.85318 .59067 .85753 .59621 .86826 .59328 .86393 .58773 Metetra
.977 .096 0 r
.86393 .58773 .86826 .59328 .87898 .59002 .87469 .58444 Metetra
.975 .107 0 r
.87469 .58444 .87898 .59002 .88965 .58578 .88538 .58018 Metetra
.966 .144 0 r
.88538 .58018 .88965 .58578 .90007 .5791 .89584 .57347 Metetra
.943 .234 0 r
.89584 .57347 .90007 .5791 .90994 .56735 .90574 .56168 Metetra
.894 .411 0 r
.90574 .56168 .90994 .56735 .91877 .54684 .91461 .54111 Metetra
.805 .679 0 r
.91461 .54111 .91877 .54684 .92605 .51412 .92195 .50832 Metetra
.371 .667 0 r
.92195 .50832 .92605 .51412 .93156 .46828 .92752 .46239 Metetra
.08 .571 0 r
.31934 .61108 .32476 .61591 .33075 .6595 .32527 .65473 Metetra
.632 .736 0 r
.32527 .65473 .33075 .6595 .33758 .69191 .33206 .6872 Metetra
.851 .548 0 r
.33206 .6872 .33758 .69191 .34525 .7119 .33971 .70721 Metetra
.92 .318 0 r
.33971 .70721 .34525 .7119 .35355 .72171 .34801 .71703 Metetra
.955 .185 0 r
.34801 .71703 .35355 .72171 .36225 .7249 .35671 .72022 Metetra
.971 .123 0 r
.35671 .72022 .36225 .7249 .37116 .72458 .36563 .71989 Metetra
.976 .1 0 r
.36563 .71989 .37116 .72458 .38017 .72269 .37466 .71799 Metetra
.978 .095 0 r
.37466 .71799 .38017 .72269 .38923 .72024 .38375 .71552 Metetra
.978 .095 0 r
.38375 .71552 .38923 .72024 .39834 .71759 .39287 .71286 Metetra
.977 .097 0 r
.39287 .71286 .39834 .71759 .40747 .7149 .40203 .71015 Metetra
.977 .099 0 r
.40203 .71015 .40747 .7149 .41664 .71219 .41121 .70743 Metetra
.976 .101 0 r
.41121 .70743 .41664 .71219 .42584 .70949 .42043 .70471 Metetra
.976 .103 0 r
.42043 .70471 .42584 .70949 .43507 .70678 .42968 .70198 Metetra
.975 .106 0 r
.42968 .70198 .43507 .70678 .44432 .70407 .43896 .69925 Metetra
.975 .107 0 r
.43896 .69925 .44432 .70407 .45361 .70135 .44827 .69652 Metetra
.974 .109 0 r
.44827 .69652 .45361 .70135 .46293 .69864 .45761 .69379 Metetra
.974 .111 0 r
.45761 .69379 .46293 .69864 .47229 .69592 .46698 .69106 Metetra
.973 .113 0 r
.46698 .69106 .47229 .69592 .48167 .69321 .47638 .68833 Metetra
.973 .114 0 r
.47638 .68833 .48167 .69321 .49108 .69049 .48582 .68559 Metetra
.973 .115 0 r
.48582 .68559 .49108 .69049 .50053 .68776 .49529 .68285 Metetra
.972 .117 0 r
.49529 .68285 .50053 .68776 .51001 .68504 .50479 .68011 Metetra
.972 .118 0 r
.50479 .68011 .51001 .68504 .51952 .68231 .51432 .67736 Metetra
.972 .119 0 r
.51432 .67736 .51952 .68231 .52907 .67958 .52389 .67462 Metetra
.972 .12 0 r
.52389 .67462 .52907 .67958 .53864 .67685 .53349 .67187 Metetra
.971 .121 0 r
.53349 .67187 .53864 .67685 .54825 .67411 .54312 .66911 Metetra
.971 .121 0 r
.54312 .66911 .54825 .67411 .5579 .67138 .55279 .66636 Metetra
.971 .122 0 r
.55279 .66636 .5579 .67138 .56758 .66864 .56249 .6636 Metetra
.971 .122 0 r
.56249 .6636 .56758 .66864 .57729 .66589 .57222 .66084 Metetra
.971 .123 0 r
.57222 .66084 .57729 .66589 .58703 .66315 .58199 .65808 Metetra
.971 .123 0 r
.58199 .65808 .58703 .66315 .59681 .6604 .59179 .65531 Metetra
.971 .123 0 r
.59179 .65531 .59681 .6604 .60663 .65765 .60163 .65254 Metetra
.971 .123 0 r
.60163 .65254 .60663 .65765 .61647 .65489 .6115 .64977 Metetra
.971 .123 0 r
.6115 .64977 .61647 .65489 .62636 .65213 .62141 .64699 Metetra
.971 .123 0 r
.62141 .64699 .62636 .65213 .63628 .64937 .63135 .64421 Metetra
.971 .123 0 r
.63135 .64421 .63628 .64937 .64623 .64661 .64133 .64143 Metetra
.971 .123 0 r
.64133 .64143 .64623 .64661 .65622 .64384 .65134 .63864 Metetra
.971 .122 0 r
.65134 .63864 .65622 .64384 .66625 .64107 .66139 .63586 Metetra
.971 .122 0 r
.66139 .63586 .66625 .64107 .67631 .6383 .67148 .63306 Metetra
.971 .121 0 r
.67148 .63306 .67631 .6383 .68641 .63552 .6816 .63027 Metetra
.971 .12 0 r
.6816 .63027 .68641 .63552 .69655 .63274 .69176 .62747 Metetra
.972 .119 0 r
.69176 .62747 .69655 .63274 .70672 .62997 .70196 .62468 Metetra
.972 .118 0 r
.70196 .62468 .70672 .62997 .71693 .62718 .7122 .62187 Metetra
.972 .117 0 r
.7122 .62187 .71693 .62718 .72718 .6244 .72247 .61907 Metetra
.972 .116 0 r
.72247 .61907 .72718 .6244 .73746 .6216 .73278 .61626 Metetra
.973 .115 0 r
.73278 .61626 .73746 .6216 .74779 .61881 .74313 .61344 Metetra
.973 .113 0 r
.74313 .61344 .74779 .61881 .75815 .61601 .75352 .61062 Metetra
.974 .112 0 r
.75352 .61062 .75815 .61601 .76855 .61321 .76395 .6078 Metetra
.974 .11 0 r
.76395 .6078 .76855 .61321 .77899 .61041 .77441 .60498 Metetra
.974 .108 0 r
.77441 .60498 .77899 .61041 .78947 .6076 .78492 .60216 Metetra
.975 .107 0 r
.78492 .60216 .78947 .6076 .79999 .60479 .79546 .59933 Metetra
.975 .105 0 r
.79546 .59933 .79999 .60479 .81055 .60198 .80605 .59649 Metetra
.976 .102 0 r
.80605 .59649 .81055 .60198 .82114 .59917 .81668 .59366 Metetra
.976 .1 0 r
.81668 .59366 .82114 .59917 .83178 .59635 .82734 .59082 Metetra
.977 .098 0 r
.82734 .59082 .83178 .59635 .84246 .59353 .83805 .58798 Metetra
.977 .096 0 r
.83805 .58798 .84246 .59353 .85318 .59067 .8488 .5851 Metetra
.978 .094 0 r
.8488 .5851 .85318 .59067 .86393 .58773 .85957 .58213 Metetra
.977 .096 0 r
.85957 .58213 .86393 .58773 .87469 .58444 .87036 .57883 Metetra
.975 .107 0 r
.87036 .57883 .87469 .58444 .88538 .58018 .88108 .57454 Metetra
.965 .144 0 r
.88108 .57454 .88538 .58018 .89584 .57347 .89157 .56781 Metetra
.943 .235 0 r
.89157 .56781 .89584 .57347 .90574 .56168 .90151 .55598 Metetra
.894 .411 0 r
.90151 .55598 .90574 .56168 .91461 .54111 .91043 .53535 Metetra
.805 .68 0 r
.91043 .53535 .91461 .54111 .92195 .50832 .91782 .50249 Metetra
.37 .667 0 r
.91782 .50249 .92195 .50832 .92752 .46239 .92345 .45646 Metetra
.079 .571 0 r
.3139 .60623 .31934 .61108 .32527 .65473 .31976 .64995 Metetra
.631 .736 0 r
.31976 .64995 .32527 .65473 .33206 .6872 .3265 .68246 Metetra
.851 .548 0 r
.3265 .68246 .33206 .6872 .33971 .70721 .33413 .7025 Metetra
.92 .319 0 r
.33413 .7025 .33971 .70721 .34801 .71703 .34243 .71233 Metetra
.955 .185 0 r
.34243 .71233 .34801 .71703 .35671 .72022 .35114 .71551 Metetra
.971 .123 0 r
.35114 .71551 .35671 .72022 .36563 .71989 .36007 .71517 Metetra
.976 .101 0 r
.36007 .71517 .36563 .71989 .37466 .71799 .36912 .71326 Metetra
.978 .095 0 r
.36912 .71326 .37466 .71799 .38375 .71552 .37823 .71077 Metetra
.978 .095 0 r
.37823 .71077 .38375 .71552 .39287 .71286 .38737 .7081 Metetra
.977 .097 0 r
.38737 .7081 .39287 .71286 .40203 .71015 .39655 .70537 Metetra
.977 .099 0 r
.39655 .70537 .40203 .71015 .41121 .70743 .40575 .70263 Metetra
.976 .102 0 r
.40575 .70263 .41121 .70743 .42043 .70471 .41499 .6999 Metetra
.975 .104 0 r
.41499 .6999 .42043 .70471 .42968 .70198 .42426 .69715 Metetra
.975 .106 0 r
.42426 .69715 .42968 .70198 .43896 .69925 .43356 .69441 Metetra
.974 .108 0 r
.43356 .69441 .43896 .69925 .44827 .69652 .44289 .69166 Metetra
.974 .11 0 r
.44289 .69166 .44827 .69652 .45761 .69379 .45225 .68892 Metetra
.974 .111 0 r
.45225 .68892 .45761 .69379 .46698 .69106 .46164 .68616 Metetra
.973 .113 0 r
.46164 .68616 .46698 .69106 .47638 .68833 .47107 .68342 Metetra
.973 .114 0 r
.47107 .68342 .47638 .68833 .48582 .68559 .48052 .68066 Metetra
.973 .116 0 r
.48052 .68066 .48582 .68559 .49529 .68285 .49001 .6779 Metetra
.972 .117 0 r
.49001 .6779 .49529 .68285 .50479 .68011 .49953 .67514 Metetra
.972 .118 0 r
.49953 .67514 .50479 .68011 .51432 .67736 .50909 .67238 Metetra
.972 .119 0 r
.50909 .67238 .51432 .67736 .52389 .67462 .51868 .66962 Metetra
.971 .12 0 r
.51868 .66962 .52389 .67462 .53349 .67187 .5283 .66685 Metetra
.971 .121 0 r
.5283 .66685 .53349 .67187 .54312 .66911 .53795 .66408 Metetra
.971 .122 0 r
.53795 .66408 .54312 .66911 .55279 .66636 .54764 .66131 Metetra
.971 .122 0 r
.54764 .66131 .55279 .66636 .56249 .6636 .55736 .65853 Metetra
.971 .123 0 r
.55736 .65853 .56249 .6636 .57222 .66084 .56712 .65576 Metetra
.971 .123 0 r
.56712 .65576 .57222 .66084 .58199 .65808 .57691 .65297 Metetra
.971 .123 0 r
.57691 .65297 .58199 .65808 .59179 .65531 .58674 .65019 Metetra
.971 .123 0 r
.58674 .65019 .59179 .65531 .60163 .65254 .5966 .6474 Metetra
.971 .124 0 r
.5966 .6474 .60163 .65254 .6115 .64977 .60649 .64461 Metetra
.971 .124 0 r
.60649 .64461 .6115 .64977 .62141 .64699 .61642 .64182 Metetra
.971 .123 0 r
.61642 .64182 .62141 .64699 .63135 .64421 .62639 .63902 Metetra
.971 .123 0 r
.62639 .63902 .63135 .64421 .64133 .64143 .63639 .63622 Metetra
.971 .123 0 r
.63639 .63622 .64133 .64143 .65134 .63864 .64643 .63341 Metetra
.971 .122 0 r
.64643 .63341 .65134 .63864 .66139 .63586 .65651 .63061 Metetra
.971 .122 0 r
.65651 .63061 .66139 .63586 .67148 .63306 .66662 .6278 Metetra
.971 .121 0 r
.66662 .6278 .67148 .63306 .6816 .63027 .67677 .62498 Metetra
.971 .12 0 r
.67677 .62498 .6816 .63027 .69176 .62747 .68695 .62217 Metetra
.972 .12 0 r
.68695 .62217 .69176 .62747 .70196 .62468 .69717 .61935 Metetra
.972 .119 0 r
.69717 .61935 .70196 .62468 .7122 .62187 .70744 .61653 Metetra
.972 .117 0 r
.70744 .61653 .7122 .62187 .72247 .61907 .71773 .6137 Metetra
.972 .116 0 r
.71773 .6137 .72247 .61907 .73278 .61626 .72807 .61087 Metetra
.973 .115 0 r
.72807 .61087 .73278 .61626 .74313 .61344 .73845 .60804 Metetra
.973 .114 0 r
.73845 .60804 .74313 .61344 .75352 .61062 .74886 .6052 Metetra
.973 .112 0 r
.74886 .6052 .75352 .61062 .76395 .6078 .75931 .60236 Metetra
.974 .11 0 r
.75931 .60236 .76395 .6078 .77441 .60498 .76981 .59952 Metetra
.974 .109 0 r
.76981 .59952 .77441 .60498 .78492 .60216 .78034 .59667 Metetra
.975 .107 0 r
.78034 .59667 .78492 .60216 .79546 .59933 .79091 .59382 Metetra
.975 .105 0 r
.79091 .59382 .79546 .59933 .80605 .59649 .80153 .59097 Metetra
.976 .103 0 r
.80153 .59097 .80605 .59649 .81668 .59366 .81218 .58812 Metetra
.976 .101 0 r
.81218 .58812 .81668 .59366 .82734 .59082 .82287 .58526 Metetra
.977 .098 0 r
.82287 .58526 .82734 .59082 .83805 .58798 .83361 .58239 Metetra
.977 .096 0 r
.83361 .58239 .83805 .58798 .8488 .5851 .84438 .5795 Metetra
.978 .095 0 r
.84438 .5795 .8488 .5851 .85957 .58213 .85519 .57651 Metetra
.977 .096 0 r
.85519 .57651 .85957 .58213 .87036 .57883 .866 .57318 Metetra
.974 .108 0 r
.866 .57318 .87036 .57883 .88108 .57454 .87676 .56887 Metetra
.965 .145 0 r
.87676 .56887 .88108 .57454 .89157 .56781 .88728 .56211 Metetra
.942 .235 0 r
.88728 .56211 .89157 .56781 .90151 .55598 .89726 .55024 Metetra
.894 .412 0 r
.89726 .55024 .90151 .55598 .91043 .53535 .90621 .52955 Metetra
.805 .68 0 r
.90621 .52955 .91043 .53535 .91782 .50249 .91366 .49661 Metetra
.37 .667 0 r
.91366 .49661 .91782 .50249 .92345 .45646 .91936 .4505 Metetra
.079 .57 0 r
.30842 .60136 .3139 .60623 .31976 .64995 .31421 .64513 Metetra
.631 .736 0 r
.31421 .64513 .31976 .64995 .3265 .68246 .32091 .67769 Metetra
.851 .549 0 r
.32091 .67769 .3265 .68246 .33413 .7025 .32852 .69776 Metetra
.92 .319 0 r
.32852 .69776 .33413 .7025 .34243 .71233 .33681 .7076 Metetra
.955 .185 0 r
.33681 .7076 .34243 .71233 .35114 .71551 .34553 .71078 Metetra
.971 .124 0 r
.34553 .71078 .35114 .71551 .36007 .71517 .35448 .71042 Metetra
.976 .101 0 r
.35448 .71042 .36007 .71517 .36912 .71326 .36355 .7085 Metetra
.978 .095 0 r
.36355 .7085 .36912 .71326 .37823 .71077 .37267 .706 Metetra
.977 .095 0 r
.37267 .706 .37823 .71077 .38737 .7081 .38183 .7033 Metetra
.977 .097 0 r
.38183 .7033 .38737 .7081 .39655 .70537 .39103 .70057 Metetra
.976 .1 0 r
.39103 .70057 .39655 .70537 .40575 .70263 .40026 .69781 Metetra
.976 .102 0 r
.40026 .69781 .40575 .70263 .41499 .6999 .40951 .69505 Metetra
.975 .104 0 r
.40951 .69505 .41499 .6999 .42426 .69715 .4188 .69229 Metetra
.975 .106 0 r
.4188 .69229 .42426 .69715 .43356 .69441 .42812 .68954 Metetra
.974 .108 0 r
.42812 .68954 .43356 .69441 .44289 .69166 .43747 .68677 Metetra
.974 .11 0 r
.43747 .68677 .44289 .69166 .45225 .68892 .44685 .68401 Metetra
.974 .112 0 r
.44685 .68401 .45225 .68892 .46164 .68616 .45627 .68124 Metetra
.973 .113 0 r
.45627 .68124 .46164 .68616 .47107 .68342 .46571 .67847 Metetra
.973 .115 0 r
.46571 .67847 .47107 .68342 .48052 .68066 .47519 .6757 Metetra
.972 .116 0 r
.47519 .6757 .48052 .68066 .49001 .6779 .4847 .67293 Metetra
.972 .117 0 r
.4847 .67293 .49001 .6779 .49953 .67514 .49425 .67015 Metetra
.972 .118 0 r
.49425 .67015 .49953 .67514 .50909 .67238 .50382 .66737 Metetra
.972 .119 0 r
.50382 .66737 .50909 .67238 .51868 .66962 .51343 .66459 Metetra
.971 .12 0 r
.51343 .66459 .51868 .66962 .5283 .66685 .52308 .66181 Metetra
.971 .121 0 r
.52308 .66181 .5283 .66685 .53795 .66408 .53275 .65902 Metetra
.971 .122 0 r
.53275 .65902 .53795 .66408 .54764 .66131 .54246 .65623 Metetra
.971 .122 0 r
.54246 .65623 .54764 .66131 .55736 .65853 .55221 .65344 Metetra
.971 .123 0 r
.55221 .65344 .55736 .65853 .56712 .65576 .56199 .65064 Metetra
.971 .123 0 r
.56199 .65064 .56712 .65576 .57691 .65297 .5718 .64784 Metetra
.971 .124 0 r
.5718 .64784 .57691 .65297 .58674 .65019 .58165 .64504 Metetra
.971 .124 0 r
.58165 .64504 .58674 .65019 .5966 .6474 .59153 .64223 Metetra
.971 .124 0 r
.59153 .64223 .5966 .6474 .60649 .64461 .60145 .63942 Metetra
.971 .124 0 r
.60145 .63942 .60649 .64461 .61642 .64182 .61141 .63661 Metetra
.971 .124 0 r
.61141 .63661 .61642 .64182 .62639 .63902 .6214 .63379 Metetra
.971 .123 0 r
.6214 .63379 .62639 .63902 .63639 .63622 .63142 .63097 Metetra
.971 .123 0 r
.63142 .63097 .63639 .63622 .64643 .63341 .64149 .62815 Metetra
.971 .123 0 r
.64149 .62815 .64643 .63341 .65651 .63061 .65159 .62533 Metetra
.971 .122 0 r
.65159 .62533 .65651 .63061 .66662 .6278 .66172 .62249 Metetra
.971 .121 0 r
.66172 .62249 .66662 .6278 .67677 .62498 .6719 .61966 Metetra
.971 .121 0 r
.6719 .61966 .67677 .62498 .68695 .62217 .68211 .61683 Metetra
.972 .12 0 r
.68211 .61683 .68695 .62217 .69717 .61935 .69235 .61399 Metetra
.972 .119 0 r
.69235 .61399 .69717 .61935 .70744 .61653 .70264 .61115 Metetra
.972 .118 0 r
.70264 .61115 .70744 .61653 .71773 .6137 .71297 .6083 Metetra
.972 .117 0 r
.71297 .6083 .71773 .6137 .72807 .61087 .72333 .60545 Metetra
.973 .115 0 r
.72333 .60545 .72807 .61087 .73845 .60804 .73373 .6026 Metetra
.973 .114 0 r
.73373 .6026 .73845 .60804 .74886 .6052 .74417 .59974 Metetra
.973 .112 0 r
.74417 .59974 .74886 .6052 .75931 .60236 .75465 .59688 Metetra
.974 .111 0 r
.75465 .59688 .75931 .60236 .76981 .59952 .76517 .59402 Metetra
.974 .109 0 r
.76517 .59402 .76981 .59952 .78034 .59667 .77573 .59115 Metetra
.975 .107 0 r
.77573 .59115 .78034 .59667 .79091 .59382 .78633 .58829 Metetra
.975 .105 0 r
.78633 .58829 .79091 .59382 .80153 .59097 .79697 .58541 Metetra
.976 .103 0 r
.79697 .58541 .80153 .59097 .81218 .58812 .80765 .58254 Metetra
.976 .101 0 r
.80765 .58254 .81218 .58812 .82287 .58526 .81837 .57966 Metetra
.977 .099 0 r
.81837 .57966 .82287 .58526 .83361 .58239 .82914 .57677 Metetra
.977 .096 0 r
.82914 .57677 .83361 .58239 .84438 .5795 .83994 .57386 Metetra
.978 .095 0 r
.83994 .57386 .84438 .5795 .85519 .57651 .85077 .57084 Metetra
.977 .097 0 r
.85077 .57084 .85519 .57651 .866 .57318 .86162 .56749 Metetra
.974 .108 0 r
.86162 .56749 .866 .57318 .87676 .56887 .8724 .56316 Metetra
.965 .145 0 r
.8724 .56316 .87676 .56887 .88728 .56211 .88296 .55637 Metetra
.942 .235 0 r
.88296 .55637 .88728 .56211 .89726 .55024 .89297 .54446 Metetra
.894 .412 0 r
.89297 .54446 .89726 .55024 .90621 .52955 .90197 .52372 Metetra
.805 .68 0 r
.90197 .52372 .90621 .52955 .91366 .49661 .90947 .4907 Metetra
.369 .666 0 r
.90947 .4907 .91366 .49661 .91936 .4505 .91524 .4445 Metetra
.079 .57 0 r
.30291 .59646 .30842 .60136 .31421 .64513 .30863 .64029 Metetra
.63 .736 0 r
.30863 .64029 .31421 .64513 .32091 .67769 .31529 .67289 Metetra
.851 .549 0 r
.31529 .67289 .32091 .67769 .32852 .69776 .32287 .69299 Metetra
.92 .319 0 r
.32287 .69299 .32852 .69776 .33681 .7076 .33116 .70284 Metetra
.955 .186 0 r
.33116 .70284 .33681 .7076 .34553 .71078 .33989 .70601 Metetra
.971 .124 0 r
.33989 .70601 .34553 .71078 .35448 .71042 .34885 .70565 Metetra
.976 .101 0 r
.34885 .70565 .35448 .71042 .36355 .7085 .35794 .70371 Metetra
.977 .096 0 r
.35794 .70371 .36355 .7085 .37267 .706 .36708 .70119 Metetra
.977 .096 0 r
.36708 .70119 .37267 .706 .38183 .7033 .37626 .69848 Metetra
.977 .098 0 r
.37626 .69848 .38183 .7033 .39103 .70057 .38548 .69573 Metetra
.976 .1 0 r
.38548 .69573 .39103 .70057 .40026 .69781 .39472 .69295 Metetra
.976 .102 0 r
.39472 .69295 .40026 .69781 .40951 .69505 .404 .69018 Metetra
.975 .104 0 r
.404 .69018 .40951 .69505 .4188 .69229 .41331 .68741 Metetra
.975 .106 0 r
.41331 .68741 .4188 .69229 .42812 .68954 .42265 .68463 Metetra
.974 .108 0 r
.42265 .68463 .42812 .68954 .43747 .68677 .43202 .68185 Metetra
.974 .11 0 r
.43202 .68185 .43747 .68677 .44685 .68401 .44142 .67907 Metetra
.974 .112 0 r
.44142 .67907 .44685 .68401 .45627 .68124 .45086 .67629 Metetra
.973 .113 0 r
.45086 .67629 .45627 .68124 .46571 .67847 .46033 .6735 Metetra
.973 .115 0 r
.46033 .6735 .46571 .67847 .47519 .6757 .46983 .67071 Metetra
.972 .116 0 r
.46983 .67071 .47519 .6757 .4847 .67293 .47936 .66792 Metetra
.972 .117 0 r
.47936 .66792 .4847 .67293 .49425 .67015 .48892 .66513 Metetra
.972 .119 0 r
.48892 .66513 .49425 .67015 .50382 .66737 .49852 .66233 Metetra
.972 .12 0 r
.49852 .66233 .50382 .66737 .51343 .66459 .50815 .65953 Metetra
.971 .12 0 r
.50815 .65953 .51343 .66459 .52308 .66181 .51782 .65673 Metetra
.971 .121 0 r
.51782 .65673 .52308 .66181 .53275 .65902 .52752 .65393 Metetra
.971 .122 0 r
.52752 .65393 .53275 .65902 .54246 .65623 .53725 .65112 Metetra
.971 .123 0 r
.53725 .65112 .54246 .65623 .55221 .65344 .54702 .64831 Metetra
.971 .123 0 r
.54702 .64831 .55221 .65344 .56199 .65064 .55682 .64549 Metetra
.971 .123 0 r
.55682 .64549 .56199 .65064 .5718 .64784 .56666 .64267 Metetra
.971 .124 0 r
.56666 .64267 .5718 .64784 .58165 .64504 .57653 .63985 Metetra
.971 .124 0 r
.57653 .63985 .58165 .64504 .59153 .64223 .58644 .63703 Metetra
.971 .124 0 r
.58644 .63703 .59153 .64223 .60145 .63942 .59638 .6342 Metetra
.971 .124 0 r
.59638 .6342 .60145 .63942 .61141 .63661 .60636 .63137 Metetra
.971 .124 0 r
.60636 .63137 .61141 .63661 .6214 .63379 .61637 .62853 Metetra
.971 .124 0 r
.61637 .62853 .6214 .63379 .63142 .63097 .62642 .6257 Metetra
.971 .123 0 r
.62642 .6257 .63142 .63097 .64149 .62815 .63651 .62285 Metetra
.971 .123 0 r
.63651 .62285 .64149 .62815 .65159 .62533 .64663 .62001 Metetra
.971 .122 0 r
.64663 .62001 .65159 .62533 .66172 .62249 .65679 .61716 Metetra
.971 .122 0 r
.65679 .61716 .66172 .62249 .6719 .61966 .66699 .61431 Metetra
.971 .121 0 r
.66699 .61431 .6719 .61966 .68211 .61683 .67723 .61145 Metetra
.971 .12 0 r
.67723 .61145 .68211 .61683 .69235 .61399 .6875 .6086 Metetra
.972 .119 0 r
.6875 .6086 .69235 .61399 .70264 .61115 .69781 .60574 Metetra
.972 .118 0 r
.69781 .60574 .70264 .61115 .71297 .6083 .70816 .60287 Metetra
.972 .117 0 r
.70816 .60287 .71297 .6083 .72333 .60545 .71855 .6 Metetra
.973 .115 0 r
.71855 .6 .72333 .60545 .73373 .6026 .72898 .59713 Metetra
.973 .114 0 r
.72898 .59713 .73373 .6026 .74417 .59974 .73945 .59425 Metetra
.973 .113 0 r
.73945 .59425 .74417 .59974 .75465 .59688 .74995 .59137 Metetra
.974 .111 0 r
.74995 .59137 .75465 .59688 .76517 .59402 .7605 .58849 Metetra
.974 .109 0 r
.7605 .58849 .76517 .59402 .77573 .59115 .77109 .5856 Metetra
.975 .107 0 r
.77109 .5856 .77573 .59115 .78633 .58829 .78171 .58271 Metetra
.975 .105 0 r
.78171 .58271 .78633 .58829 .79697 .58541 .79238 .57982 Metetra
.976 .103 0 r
.79238 .57982 .79697 .58541 .80765 .58254 .80309 .57692 Metetra
.976 .101 0 r
.80309 .57692 .80765 .58254 .81837 .57966 .81384 .57402 Metetra
.977 .099 0 r
.81384 .57402 .81837 .57966 .82914 .57677 .82463 .57111 Metetra
.977 .097 0 r
.82463 .57111 .82914 .57677 .83994 .57386 .83546 .56818 Metetra
.978 .095 0 r
.83546 .56818 .83994 .57386 .85077 .57084 .84633 .56514 Metetra
.977 .097 0 r
.84633 .56514 .85077 .57084 .86162 .56749 .8572 .56177 Metetra
.974 .108 0 r
.8572 .56177 .86162 .56749 .8724 .56316 .86801 .55741 Metetra
.965 .145 0 r
.86801 .55741 .8724 .56316 .88296 .55637 .8786 .55059 Metetra
.942 .236 0 r
.8786 .55059 .88296 .55637 .89297 .54446 .88866 .53864 Metetra
.893 .412 0 r
.88866 .53864 .89297 .54446 .90197 .52372 .8977 .51785 Metetra
.805 .681 0 r
.8977 .51785 .90197 .52372 .90947 .4907 .90526 .48476 Metetra
.369 .666 0 r
.90526 .48476 .90947 .4907 .91524 .4445 .91109 .43846 Metetra
.078 .57 0 r
.29736 .59153 .30291 .59646 .30863 .64029 .30302 .63542 Metetra
.63 .736 0 r
.30302 .63542 .30863 .64029 .31529 .67289 .30963 .66807 Metetra
.851 .549 0 r
.30963 .66807 .31529 .67289 .32287 .69299 .31719 .6882 Metetra
.92 .32 0 r
.31719 .6882 .32287 .69299 .33116 .70284 .32547 .69805 Metetra
.955 .186 0 r
.32547 .69805 .33116 .70284 .33989 .70601 .33421 .70122 Metetra
.97 .124 0 r
.33421 .70122 .33989 .70601 .34885 .70565 .34319 .70084 Metetra
.976 .102 0 r
.34319 .70084 .34885 .70565 .35794 .70371 .35229 .69889 Metetra
.977 .096 0 r
.35229 .69889 .35794 .70371 .36708 .70119 .36145 .69636 Metetra
.977 .096 0 r
.36145 .69636 .36708 .70119 .37626 .69848 .37066 .69363 Metetra
.977 .098 0 r
.37066 .69363 .37626 .69848 .38548 .69573 .37989 .69086 Metetra
.976 .1 0 r
.37989 .69086 .38548 .69573 .39472 .69295 .38916 .68807 Metetra
.976 .102 0 r
.38916 .68807 .39472 .69295 .404 .69018 .39845 .68529 Metetra
.975 .105 0 r
.39845 .68529 .404 .69018 .41331 .68741 .40778 .68249 Metetra
.975 .107 0 r
.40778 .68249 .41331 .68741 .42265 .68463 .41714 .6797 Metetra
.974 .109 0 r
.41714 .6797 .42265 .68463 .43202 .68185 .42654 .6769 Metetra
.974 .11 0 r
.42654 .6769 .43202 .68185 .44142 .67907 .43596 .67411 Metetra
.973 .112 0 r
.43596 .67411 .44142 .67907 .45086 .67629 .44542 .6713 Metetra
.973 .114 0 r
.44542 .6713 .45086 .67629 .46033 .6735 .4549 .6685 Metetra
.973 .115 0 r
.4549 .6685 .46033 .6735 .46983 .67071 .46442 .66569 Metetra
.972 .116 0 r
.46442 .66569 .46983 .67071 .47936 .66792 .47398 .66289 Metetra
.972 .118 0 r
.47398 .66289 .47936 .66792 .48892 .66513 .48357 .66007 Metetra
.972 .119 0 r
.48357 .66007 .48892 .66513 .49852 .66233 .49319 .65726 Metetra
.972 .12 0 r
.49319 .65726 .49852 .66233 .50815 .65953 .50284 .65444 Metetra
.971 .121 0 r
.50284 .65444 .50815 .65953 .51782 .65673 .51253 .65162 Metetra
.971 .121 0 r
.51253 .65162 .51782 .65673 .52752 .65393 .52225 .6488 Metetra
.971 .122 0 r
.52225 .6488 .52752 .65393 .53725 .65112 .532 .64597 Metetra
.971 .123 0 r
.532 .64597 .53725 .65112 .54702 .64831 .54179 .64314 Metetra
.971 .123 0 r
.54179 .64314 .54702 .64831 .55682 .64549 .55162 .64031 Metetra
.971 .124 0 r
.55162 .64031 .55682 .64549 .56666 .64267 .56148 .63747 Metetra
.971 .124 0 r
.56148 .63747 .56666 .64267 .57653 .63985 .57137 .63463 Metetra
.97 .124 0 r
.57137 .63463 .57653 .63985 .58644 .63703 .5813 .63179 Metetra
.97 .124 0 r
.5813 .63179 .58644 .63703 .59638 .6342 .59127 .62894 Metetra
.97 .124 0 r
.59127 .62894 .59638 .6342 .60636 .63137 .60127 .62609 Metetra
.971 .124 0 r
.60127 .62609 .60636 .63137 .61637 .62853 .61131 .62324 Metetra
.971 .124 0 r
.61131 .62324 .61637 .62853 .62642 .6257 .62139 .62038 Metetra
.971 .123 0 r
.62139 .62038 .62642 .6257 .63651 .62285 .6315 .61752 Metetra
.971 .123 0 r
.6315 .61752 .63651 .62285 .64663 .62001 .64165 .61466 Metetra
.971 .122 0 r
.64165 .61466 .64663 .62001 .65679 .61716 .65183 .61179 Metetra
.971 .122 0 r
.65183 .61179 .65679 .61716 .66699 .61431 .66206 .60892 Metetra
.971 .121 0 r
.66206 .60892 .66699 .61431 .67723 .61145 .67232 .60604 Metetra
.971 .12 0 r
.67232 .60604 .67723 .61145 .6875 .6086 .68262 .60317 Metetra
.972 .119 0 r
.68262 .60317 .6875 .6086 .69781 .60574 .69295 .60029 Metetra
.972 .118 0 r
.69295 .60029 .69781 .60574 .70816 .60287 .70333 .5974 Metetra
.972 .117 0 r
.70333 .5974 .70816 .60287 .71855 .6 .71375 .59451 Metetra
.973 .116 0 r
.71375 .59451 .71855 .6 .72898 .59713 .7242 .59162 Metetra
.973 .114 0 r
.7242 .59162 .72898 .59713 .73945 .59425 .73469 .58872 Metetra
.973 .113 0 r
.73469 .58872 .73945 .59425 .74995 .59137 .74523 .58582 Metetra
.974 .111 0 r
.74523 .58582 .74995 .59137 .7605 .58849 .7558 .58292 Metetra
.974 .109 0 r
.7558 .58292 .7605 .58849 .77109 .5856 .76641 .58001 Metetra
.975 .108 0 r
.76641 .58001 .77109 .5856 .78171 .58271 .77707 .5771 Metetra
.975 .106 0 r
.77707 .5771 .78171 .58271 .79238 .57982 .78776 .57418 Metetra
.976 .104 0 r
.78776 .57418 .79238 .57982 .80309 .57692 .7985 .57127 Metetra
.976 .101 0 r
.7985 .57127 .80309 .57692 .81384 .57402 .80928 .56835 Metetra
.977 .099 0 r
.80928 .56835 .81384 .57402 .82463 .57111 .8201 .56542 Metetra
.977 .097 0 r
.8201 .56542 .82463 .57111 .83546 .56818 .83096 .56246 Metetra
.977 .095 0 r
.83096 .56246 .83546 .56818 .84633 .56514 .84185 .5594 Metetra
.977 .097 0 r
.84185 .5594 .84633 .56514 .8572 .56177 .85276 .55601 Metetra
.974 .109 0 r
.85276 .55601 .8572 .56177 .86801 .55741 .8636 .55162 Metetra
.965 .146 0 r
.8636 .55162 .86801 .55741 .8786 .55059 .87422 .54477 Metetra
.942 .236 0 r
.87422 .54477 .8786 .55059 .88866 .53864 .88431 .53278 Metetra
.893 .413 0 r
.88431 .53278 .88866 .53864 .8977 .51785 .8934 .51194 Metetra
.805 .681 0 r
.8934 .51194 .8977 .51785 .90526 .48476 .90102 .47877 Metetra
.369 .666 0 r
.90102 .47877 .90526 .48476 .91109 .43846 .90691 .43238 Metetra
.078 .57 0 r
.29178 .58657 .29736 .59153 .30302 .63542 .29737 .63052 Metetra
.629 .736 0 r
.29737 .63052 .30302 .63542 .30963 .66807 .30393 .66322 Metetra
.851 .55 0 r
.30393 .66322 .30963 .66807 .31719 .6882 .31147 .68337 Metetra
.92 .32 0 r
.31147 .68337 .31719 .6882 .32547 .69805 .31975 .69324 Metetra
.955 .186 0 r
.31975 .69324 .32547 .69805 .33421 .70122 .3285 .6964 Metetra
.97 .124 0 r
.3285 .6964 .33421 .70122 .34319 .70084 .33749 .69601 Metetra
.976 .102 0 r
.33749 .69601 .34319 .70084 .35229 .69889 .34661 .69405 Metetra
.977 .096 0 r
.34661 .69405 .35229 .69889 .36145 .69636 .35579 .6915 Metetra
.977 .096 0 r
.35579 .6915 .36145 .69636 .37066 .69363 .36501 .68876 Metetra
.977 .098 0 r
.36501 .68876 .37066 .69363 .37989 .69086 .37427 .68597 Metetra
.976 .1 0 r
.37427 .68597 .37989 .69086 .38916 .68807 .38355 .68316 Metetra
.976 .103 0 r
.38355 .68316 .38916 .68807 .39845 .68529 .39287 .68036 Metetra
.975 .105 0 r
.39287 .68036 .39845 .68529 .40778 .68249 .40222 .67754 Metetra
.975 .107 0 r
.40222 .67754 .40778 .68249 .41714 .6797 .4116 .67474 Metetra
.974 .109 0 r
.4116 .67474 .41714 .6797 .42654 .6769 .42101 .67192 Metetra
.974 .111 0 r
.42101 .67192 .42654 .6769 .43596 .67411 .43046 .66911 Metetra
.973 .112 0 r
.43046 .66911 .43596 .67411 .44542 .6713 .43994 .66629 Metetra
.973 .114 0 r
.43994 .66629 .44542 .6713 .4549 .6685 .44945 .66347 Metetra
.973 .115 0 r
.44945 .66347 .4549 .6685 .46442 .66569 .45899 .66064 Metetra
.972 .117 0 r
.45899 .66064 .46442 .66569 .47398 .66289 .46856 .65782 Metetra
.972 .118 0 r
.46856 .65782 .47398 .66289 .48357 .66007 .47817 .65499 Metetra
.972 .119 0 r
.47817 .65499 .48357 .66007 .49319 .65726 .48781 .65216 Metetra
.972 .12 0 r
.48781 .65216 .49319 .65726 .50284 .65444 .49749 .64932 Metetra
.971 .121 0 r
.49749 .64932 .50284 .65444 .51253 .65162 .5072 .64648 Metetra
.971 .122 0 r
.5072 .64648 .51253 .65162 .52225 .6488 .51694 .64364 Metetra
.971 .122 0 r
.51694 .64364 .52225 .6488 .532 .64597 .52672 .6408 Metetra
.971 .123 0 r
.52672 .6408 .532 .64597 .54179 .64314 .53654 .63795 Metetra
.971 .123 0 r
.53654 .63795 .54179 .64314 .55162 .64031 .54638 .6351 Metetra
.971 .124 0 r
.54638 .6351 .55162 .64031 .56148 .63747 .55627 .63224 Metetra
.97 .124 0 r
.55627 .63224 .56148 .63747 .57137 .63463 .56619 .62938 Metetra
.97 .124 0 r
.56619 .62938 .57137 .63463 .5813 .63179 .57614 .62652 Metetra
.97 .124 0 r
.57614 .62652 .5813 .63179 .59127 .62894 .58613 .62366 Metetra
.97 .124 0 r
.58613 .62366 .59127 .62894 .60127 .62609 .59616 .62079 Metetra
.97 .124 0 r
.59616 .62079 .60127 .62609 .61131 .62324 .60622 .61791 Metetra
.971 .124 0 r
.60622 .61791 .61131 .62324 .62139 .62038 .61632 .61504 Metetra
.971 .124 0 r
.61632 .61504 .62139 .62038 .6315 .61752 .62645 .61216 Metetra
.971 .123 0 r
.62645 .61216 .6315 .61752 .64165 .61466 .63663 .60927 Metetra
.971 .123 0 r
.63663 .60927 .64165 .61466 .65183 .61179 .64684 .60638 Metetra
.971 .122 0 r
.64684 .60638 .65183 .61179 .66206 .60892 .65709 .60349 Metetra
.971 .121 0 r
.65709 .60349 .66206 .60892 .67232 .60604 .66737 .6006 Metetra
.971 .12 0 r
.66737 .6006 .67232 .60604 .68262 .60317 .6777 .59771 Metetra
.972 .119 0 r
.6777 .59771 .68262 .60317 .69295 .60029 .68806 .5948 Metetra
.972 .118 0 r
.68806 .5948 .69295 .60029 .70333 .5974 .69846 .5919 Metetra
.972 .117 0 r
.69846 .5919 .70333 .5974 .71375 .59451 .70891 .58899 Metetra
.973 .116 0 r
.70891 .58899 .71375 .59451 .7242 .59162 .71939 .58607 Metetra
.973 .114 0 r
.71939 .58607 .7242 .59162 .73469 .58872 .72991 .58316 Metetra
.973 .113 0 r
.72991 .58316 .73469 .58872 .74523 .58582 .74047 .58024 Metetra
.974 .111 0 r
.74047 .58024 .74523 .58582 .7558 .58292 .75107 .57731 Metetra
.974 .11 0 r
.75107 .57731 .7558 .58292 .76641 .58001 .76171 .57438 Metetra
.974 .108 0 r
.76171 .57438 .76641 .58001 .77707 .5771 .77239 .57145 Metetra
.975 .106 0 r
.77239 .57145 .77707 .5771 .78776 .57418 .78312 .56852 Metetra
.975 .104 0 r
.78312 .56852 .78776 .57418 .7985 .57127 .79388 .56558 Metetra
.976 .102 0 r
.79388 .56558 .7985 .57127 .80928 .56835 .80469 .56263 Metetra
.977 .099 0 r
.80469 .56263 .80928 .56835 .8201 .56542 .81554 .55968 Metetra
.977 .097 0 r
.81554 .55968 .8201 .56542 .83096 .56246 .82642 .5567 Metetra
.977 .096 0 r
.82642 .5567 .83096 .56246 .84185 .5594 .83735 .55363 Metetra
.977 .097 0 r
.83735 .55363 .84185 .5594 .85276 .55601 .84828 .55021 Metetra
.974 .109 0 r
.84828 .55021 .85276 .55601 .8636 .55162 .85915 .5458 Metetra
.965 .146 0 r
.85915 .5458 .8636 .55162 .87422 .54477 .86981 .53892 Metetra
.942 .236 0 r
.86981 .53892 .87422 .54477 .88431 .53278 .87994 .52689 Metetra
.893 .413 0 r
.87994 .52689 .88431 .53278 .8934 .51194 .88908 .50599 Metetra
.805 .681 0 r
.88908 .50599 .8934 .51194 .90102 .47877 .89675 .47274 Metetra
.368 .666 0 r
.89675 .47274 .90102 .47877 .90691 .43238 .90271 .42626 Metetra
.078 .57 0 r
.28617 .58159 .29178 .58657 .29737 .63052 .29169 .6256 Metetra
.629 .736 0 r
.29169 .6256 .29737 .63052 .30393 .66322 .2982 .65834 Metetra
.851 .55 0 r
.2982 .65834 .30393 .66322 .31147 .68337 .30571 .67852 Metetra
.92 .32 0 r
.30571 .67852 .31147 .68337 .31975 .69324 .31399 .68839 Metetra
.955 .186 0 r
.31399 .68839 .31975 .69324 .3285 .6964 .32274 .69155 Metetra
.97 .125 0 r
.32274 .69155 .3285 .6964 .33749 .69601 .33176 .69115 Metetra
.976 .102 0 r
.33176 .69115 .33749 .69601 .34661 .69405 .34089 .68917 Metetra
.977 .096 0 r
.34089 .68917 .34661 .69405 .35579 .6915 .35009 .6866 Metetra
.977 .096 0 r
.35009 .6866 .35579 .6915 .36501 .68876 .35933 .68385 Metetra
.977 .098 0 r
.35933 .68385 .36501 .68876 .37427 .68597 .36861 .68104 Metetra
.976 .101 0 r
.36861 .68104 .37427 .68597 .38355 .68316 .37792 .67822 Metetra
.976 .103 0 r
.37792 .67822 .38355 .68316 .39287 .68036 .38725 .6754 Metetra
.975 .105 0 r
.38725 .6754 .39287 .68036 .40222 .67754 .39662 .67257 Metetra
.975 .107 0 r
.39662 .67257 .40222 .67754 .4116 .67474 .40603 .66974 Metetra
.974 .109 0 r
.40603 .66974 .4116 .67474 .42101 .67192 .41546 .66691 Metetra
.974 .111 0 r
.41546 .66691 .42101 .67192 .43046 .66911 .42492 .66408 Metetra
.973 .112 0 r
.42492 .66408 .43046 .66911 .43994 .66629 .43442 .66124 Metetra
.973 .114 0 r
.43442 .66124 .43994 .66629 .44945 .66347 .44395 .6584 Metetra
.973 .115 0 r
.44395 .6584 .44945 .66347 .45899 .66064 .45352 .65556 Metetra
.972 .117 0 r
.45352 .65556 .45899 .66064 .46856 .65782 .46311 .65272 Metetra
.972 .118 0 r
.46311 .65272 .46856 .65782 .47817 .65499 .47275 .64987 Metetra
.972 .119 0 r
.47275 .64987 .47817 .65499 .48781 .65216 .48241 .64702 Metetra
.971 .12 0 r
.48241 .64702 .48781 .65216 .49749 .64932 .49211 .64417 Metetra
.971 .121 0 r
.49211 .64417 .49749 .64932 .5072 .64648 .50184 .64131 Metetra
.971 .122 0 r
.50184 .64131 .5072 .64648 .51694 .64364 .51161 .63845 Metetra
.971 .122 0 r
.51161 .63845 .51694 .64364 .52672 .6408 .52141 .63559 Metetra
.971 .123 0 r
.52141 .63559 .52672 .6408 .53654 .63795 .53124 .63272 Metetra
.971 .124 0 r
.53124 .63272 .53654 .63795 .54638 .6351 .54111 .62985 Metetra
.971 .124 0 r
.54111 .62985 .54638 .6351 .55627 .63224 .55102 .62698 Metetra
.97 .124 0 r
.55102 .62698 .55627 .63224 .56619 .62938 .56096 .6241 Metetra
.97 .124 0 r
.56096 .6241 .56619 .62938 .57614 .62652 .57094 .62122 Metetra
.97 .124 0 r
.57094 .62122 .57614 .62652 .58613 .62366 .58095 .61833 Metetra
.97 .124 0 r
.58095 .61833 .58613 .62366 .59616 .62079 .59101 .61544 Metetra
.97 .124 0 r
.59101 .61544 .59616 .62079 .60622 .61791 .60109 .61255 Metetra
.97 .124 0 r
.60109 .61255 .60622 .61791 .61632 .61504 .61122 .60966 Metetra
.971 .124 0 r
.61122 .60966 .61632 .61504 .62645 .61216 .62138 .60676 Metetra
.971 .123 0 r
.62138 .60676 .62645 .61216 .63663 .60927 .63158 .60385 Metetra
.971 .123 0 r
.63158 .60385 .63663 .60927 .64684 .60638 .64181 .60094 Metetra
.971 .122 0 r
.64181 .60094 .64684 .60638 .65709 .60349 .65209 .59803 Metetra
.971 .121 0 r
.65209 .59803 .65709 .60349 .66737 .6006 .6624 .59512 Metetra
.971 .121 0 r
.6624 .59512 .66737 .6006 .6777 .59771 .67275 .59221 Metetra
.972 .12 0 r
.67275 .59221 .6777 .59771 .68806 .5948 .68314 .58928 Metetra
.972 .118 0 r
.68314 .58928 .68806 .5948 .69846 .5919 .69357 .58636 Metetra
.972 .117 0 r
.69357 .58636 .69846 .5919 .70891 .58899 .70403 .58343 Metetra
.972 .116 0 r
.70403 .58343 .70891 .58899 .71939 .58607 .71454 .58049 Metetra
.973 .115 0 r
.71454 .58049 .71939 .58607 .72991 .58316 .72509 .57755 Metetra
.973 .113 0 r
.72509 .57755 .72991 .58316 .74047 .58024 .73568 .57461 Metetra
.974 .112 0 r
.73568 .57461 .74047 .58024 .75107 .57731 .7463 .57167 Metetra
.974 .11 0 r
.7463 .57167 .75107 .57731 .76171 .57438 .75697 .56872 Metetra
.974 .108 0 r
.75697 .56872 .76171 .57438 .77239 .57145 .76768 .56576 Metetra
.975 .106 0 r
.76768 .56576 .77239 .57145 .78312 .56852 .77843 .56281 Metetra
.975 .104 0 r
.77843 .56281 .78312 .56852 .79388 .56558 .78923 .55985 Metetra
.976 .102 0 r
.78923 .55985 .79388 .56558 .80469 .56263 .80006 .55688 Metetra
.976 .099 0 r
.80006 .55688 .80469 .56263 .81554 .55968 .81094 .55391 Metetra
.977 .097 0 r
.81094 .55391 .81554 .55968 .82642 .5567 .82186 .55091 Metetra
.977 .096 0 r
.82186 .55091 .82642 .5567 .83735 .55363 .83281 .54781 Metetra
.977 .098 0 r
.83281 .54781 .83735 .55363 .84828 .55021 .84377 .54437 Metetra
.974 .109 0 r
.84377 .54437 .84828 .55021 .85915 .5458 .85468 .53994 Metetra
.965 .146 0 r
.85468 .53994 .85915 .5458 .86981 .53892 .86537 .53302 Metetra
.942 .237 0 r
.86537 .53302 .86981 .53892 .87994 .52689 .87553 .52096 Metetra
.893 .413 0 r
.87553 .52096 .87994 .52689 .88908 .50599 .88472 .5 Metetra
.804 .682 0 r
.88472 .5 .88908 .50599 .89675 .47274 .89244 .46668 Metetra
.368 .666 0 r
.89244 .46668 .89675 .47274 .90271 .42626 .89848 .4201 Metetra
.077 .57 0 r
.28052 .57657 .28617 .58159 .29169 .6256 .28597 .62065 Metetra
.629 .736 0 r
.28597 .62065 .29169 .6256 .2982 .65834 .29244 .65343 Metetra
.851 .55 0 r
.29244 .65343 .2982 .65834 .30571 .67852 .29992 .67364 Metetra
.92 .32 0 r
.29992 .67364 .30571 .67852 .31399 .68839 .30819 .68352 Metetra
.955 .187 0 r
.30819 .68352 .31399 .68839 .32274 .69155 .31696 .68667 Metetra
.97 .125 0 r
.31696 .68667 .32274 .69155 .33176 .69115 .32598 .68626 Metetra
.976 .102 0 r
.32598 .68626 .33176 .69115 .34089 .68917 .33514 .68426 Metetra
.977 .096 0 r
.33514 .68426 .34089 .68917 .35009 .6866 .34436 .68168 Metetra
.977 .097 0 r
.34436 .68168 .35009 .6866 .35933 .68385 .35362 .67891 Metetra
.977 .098 0 r
.35362 .67891 .35933 .68385 .36861 .68104 .36291 .67609 Metetra
.976 .101 0 r
.36291 .67609 .36861 .68104 .37792 .67822 .37224 .67324 Metetra
.976 .103 0 r
.37224 .67324 .37792 .67822 .38725 .6754 .3816 .67041 Metetra
.975 .105 0 r
.3816 .67041 .38725 .6754 .39662 .67257 .39099 .66756 Metetra
.975 .107 0 r
.39099 .66756 .39662 .67257 .40603 .66974 .40041 .66472 Metetra
.974 .109 0 r
.40041 .66472 .40603 .66974 .41546 .66691 .40987 .66186 Metetra
.974 .111 0 r
.40987 .66186 .41546 .66691 .42492 .66408 .41935 .65902 Metetra
.973 .113 0 r
.41935 .65902 .42492 .66408 .43442 .66124 .42887 .65616 Metetra
.973 .114 0 r
.42887 .65616 .43442 .66124 .44395 .6584 .43843 .65331 Metetra
.973 .116 0 r
.43843 .65331 .44395 .6584 .45352 .65556 .44801 .65044 Metetra
.972 .117 0 r
.44801 .65044 .45352 .65556 .46311 .65272 .45763 .64758 Metetra
.972 .118 0 r
.45763 .64758 .46311 .65272 .47275 .64987 .46728 .64471 Metetra
.972 .119 0 r
.46728 .64471 .47275 .64987 .48241 .64702 .47697 .64185 Metetra
.971 .12 0 r
.47697 .64185 .48241 .64702 .49211 .64417 .48669 .63897 Metetra
.971 .121 0 r
.48669 .63897 .49211 .64417 .50184 .64131 .49644 .6361 Metetra
.971 .122 0 r
.49644 .6361 .50184 .64131 .51161 .63845 .50623 .63322 Metetra
.971 .123 0 r
.50623 .63322 .51161 .63845 .52141 .63559 .51606 .63034 Metetra
.971 .123 0 r
.51606 .63034 .52141 .63559 .53124 .63272 .52592 .62745 Metetra
.971 .124 0 r
.52592 .62745 .53124 .63272 .54111 .62985 .53581 .62456 Metetra
.97 .124 0 r
.53581 .62456 .54111 .62985 .55102 .62698 .54574 .62167 Metetra
.97 .124 0 r
.54574 .62167 .55102 .62698 .56096 .6241 .55571 .61877 Metetra
.97 .125 0 r
.55571 .61877 .56096 .6241 .57094 .62122 .56571 .61587 Metetra
.97 .125 0 r
.56571 .61587 .57094 .62122 .58095 .61833 .57574 .61297 Metetra
.97 .125 0 r
.57574 .61297 .58095 .61833 .59101 .61544 .58582 .61006 Metetra
.97 .125 0 r
.58582 .61006 .59101 .61544 .60109 .61255 .59593 .60715 Metetra
.97 .124 0 r
.59593 .60715 .60109 .61255 .61122 .60966 .60608 .60423 Metetra
.971 .124 0 r
.60608 .60423 .61122 .60966 .62138 .60676 .61626 .60131 Metetra
.971 .124 0 r
.61626 .60131 .62138 .60676 .63158 .60385 .62649 .59839 Metetra
.971 .123 0 r
.62649 .59839 .63158 .60385 .64181 .60094 .63675 .59546 Metetra
.971 .122 0 r
.63675 .59546 .64181 .60094 .65209 .59803 .64705 .59253 Metetra
.971 .122 0 r
.64705 .59253 .65209 .59803 .6624 .59512 .65739 .58959 Metetra
.971 .121 0 r
.65739 .58959 .6624 .59512 .67275 .59221 .66776 .58667 Metetra
.972 .12 0 r
.66776 .58667 .67275 .59221 .68314 .58928 .67818 .58372 Metetra
.972 .119 0 r
.67818 .58372 .68314 .58928 .69357 .58636 .68863 .58078 Metetra
.972 .117 0 r
.68863 .58078 .69357 .58636 .70403 .58343 .69913 .57783 Metetra
.972 .116 0 r
.69913 .57783 .70403 .58343 .71454 .58049 .70966 .57487 Metetra
.973 .115 0 r
.70966 .57487 .71454 .58049 .72509 .57755 .72024 .57191 Metetra
.973 .113 0 r
.72024 .57191 .72509 .57755 .73568 .57461 .73085 .56895 Metetra
.974 .112 0 r
.73085 .56895 .73568 .57461 .7463 .57167 .74151 .56599 Metetra
.974 .11 0 r
.74151 .56599 .7463 .57167 .75697 .56872 .7522 .56301 Metetra
.974 .108 0 r
.7522 .56301 .75697 .56872 .76768 .56576 .76294 .56004 Metetra
.975 .106 0 r
.76294 .56004 .76768 .56576 .77843 .56281 .77372 .55706 Metetra
.975 .104 0 r
.77372 .55706 .77843 .56281 .78923 .55985 .78454 .55408 Metetra
.976 .102 0 r
.78454 .55408 .78923 .55985 .80006 .55688 .7954 .5511 Metetra
.976 .1 0 r
.7954 .5511 .80006 .55688 .81094 .55391 .80631 .5481 Metetra
.977 .097 0 r
.80631 .5481 .81094 .55391 .82186 .55091 .81726 .54508 Metetra
.977 .096 0 r
.81726 .54508 .82186 .55091 .83281 .54781 .82824 .54196 Metetra
.977 .098 0 r
.82824 .54196 .83281 .54781 .84377 .54437 .83923 .53849 Metetra
.974 .109 0 r
.83923 .53849 .84377 .54437 .85468 .53994 .85017 .53403 Metetra
.965 .146 0 r
.85017 .53403 .85468 .53994 .86537 .53302 .86089 .52709 Metetra
.942 .237 0 r
.86089 .52709 .86537 .53302 .87553 .52096 .8711 .51498 Metetra
.893 .414 0 r
.8711 .51498 .87553 .52096 .88472 .5 .88033 .49397 Metetra
.804 .682 0 r
.88033 .49397 .88472 .5 .89244 .46668 .88811 .46058 Metetra
.368 .666 0 r
.88811 .46058 .89244 .46668 .89848 .4201 .89422 .41391 Metetra
.077 .57 0 r
.27484 .57153 .28052 .57657 .28597 .62065 .28022 .61567 Metetra
.628 .736 0 r
.28022 .61567 .28597 .62065 .29244 .65343 .28663 .6485 Metetra
.851 .55 0 r
.28663 .6485 .29244 .65343 .29992 .67364 .2941 .66873 Metetra
.92 .321 0 r
.2941 .66873 .29992 .67364 .30819 .68352 .30236 .67862 Metetra
.955 .187 0 r
.30236 .67862 .30819 .68352 .31696 .68667 .31113 .68177 Metetra
.97 .125 0 r
.31113 .68177 .31696 .68667 .32598 .68626 .32017 .68134 Metetra
.976 .102 0 r
.32017 .68134 .32598 .68626 .33514 .68426 .32935 .67933 Metetra
.977 .097 0 r
.32935 .67933 .33514 .68426 .34436 .68168 .33859 .67673 Metetra
.977 .097 0 r
.33859 .67673 .34436 .68168 .35362 .67891 .34787 .67394 Metetra
.977 .099 0 r
.34787 .67394 .35362 .67891 .36291 .67609 .35718 .6711 Metetra
.976 .101 0 r
.35718 .6711 .36291 .67609 .37224 .67324 .36653 .66824 Metetra
.976 .103 0 r
.36653 .66824 .37224 .67324 .3816 .67041 .37591 .66538 Metetra
.975 .105 0 r
.37591 .66538 .3816 .67041 .39099 .66756 .38532 .66252 Metetra
.975 .107 0 r
.38532 .66252 .39099 .66756 .40041 .66472 .39476 .65966 Metetra
.974 .109 0 r
.39476 .65966 .40041 .66472 .40987 .66186 .40424 .65679 Metetra
.974 .111 0 r
.40424 .65679 .40987 .66186 .41935 .65902 .41375 .65392 Metetra
.973 .113 0 r
.41375 .65392 .41935 .65902 .42887 .65616 .42329 .65105 Metetra
.973 .114 0 r
.42329 .65105 .42887 .65616 .43843 .65331 .43286 .64818 Metetra
.973 .116 0 r
.43286 .64818 .43843 .65331 .44801 .65044 .44247 .6453 Metetra
.972 .117 0 r
.44247 .6453 .44801 .65044 .45763 .64758 .45211 .64242 Metetra
.972 .118 0 r
.45211 .64242 .45763 .64758 .46728 .64471 .46178 .63953 Metetra
.972 .119 0 r
.46178 .63953 .46728 .64471 .47697 .64185 .47149 .63664 Metetra
.971 .12 0 r
.47149 .63664 .47697 .64185 .48669 .63897 .48123 .63375 Metetra
.971 .121 0 r
.48123 .63375 .48669 .63897 .49644 .6361 .49101 .63086 Metetra
.971 .122 0 r
.49101 .63086 .49644 .6361 .50623 .63322 .50082 .62796 Metetra
.971 .123 0 r
.50082 .62796 .50623 .63322 .51606 .63034 .51067 .62506 Metetra
.971 .123 0 r
.51067 .62506 .51606 .63034 .52592 .62745 .52055 .62215 Metetra
.971 .124 0 r
.52055 .62215 .52592 .62745 .53581 .62456 .53047 .61925 Metetra
.97 .124 0 r
.53047 .61925 .53581 .62456 .54574 .62167 .54042 .61633 Metetra
.97 .125 0 r
.54042 .61633 .54574 .62167 .55571 .61877 .55041 .61342 Metetra
.97 .125 0 r
.55041 .61342 .55571 .61877 .56571 .61587 .56044 .6105 Metetra
.97 .125 0 r
.56044 .6105 .56571 .61587 .57574 .61297 .5705 .60758 Metetra
.97 .125 0 r
.5705 .60758 .57574 .61297 .58582 .61006 .5806 .60465 Metetra
.97 .125 0 r
.5806 .60465 .58582 .61006 .59593 .60715 .59073 .60172 Metetra
.97 .124 0 r
.59073 .60172 .59593 .60715 .60608 .60423 .60091 .59878 Metetra
.97 .124 0 r
.60091 .59878 .60608 .60423 .61626 .60131 .61112 .59584 Metetra
.971 .124 0 r
.61112 .59584 .61626 .60131 .62649 .59839 .62137 .5929 Metetra
.971 .123 0 r
.62137 .5929 .62649 .59839 .63675 .59546 .63165 .58995 Metetra
.971 .123 0 r
.63165 .58995 .63675 .59546 .64705 .59253 .64198 .587 Metetra
.971 .122 0 r
.64198 .587 .64705 .59253 .65739 .58959 .65234 .58404 Metetra
.971 .121 0 r
.65234 .58404 .65739 .58959 .66776 .58667 .66274 .58109 Metetra
.972 .12 0 r
.66274 .58109 .66776 .58667 .67818 .58372 .67319 .57813 Metetra
.972 .119 0 r
.67319 .57813 .67818 .58372 .68863 .58078 .68367 .57516 Metetra
.972 .118 0 r
.68367 .57516 .68863 .58078 .69913 .57783 .69419 .57219 Metetra
.972 .116 0 r
.69419 .57219 .69913 .57783 .70966 .57487 .70475 .56922 Metetra
.973 .115 0 r
.70475 .56922 .70966 .57487 .72024 .57191 .71535 .56624 Metetra
.973 .113 0 r
.71535 .56624 .72024 .57191 .73085 .56895 .72599 .56325 Metetra
.973 .112 0 r
.72599 .56325 .73085 .56895 .74151 .56599 .73668 .56027 Metetra
.974 .11 0 r
.73668 .56027 .74151 .56599 .7522 .56301 .7474 .55727 Metetra
.974 .108 0 r
.7474 .55727 .7522 .56301 .76294 .56004 .75817 .55428 Metetra
.975 .106 0 r
.75817 .55428 .76294 .56004 .77372 .55706 .76897 .55128 Metetra
.975 .104 0 r
.76897 .55128 .77372 .55706 .78454 .55408 .77982 .54828 Metetra
.976 .102 0 r
.77982 .54828 .78454 .55408 .7954 .5511 .79072 .54527 Metetra
.976 .1 0 r
.79072 .54527 .7954 .5511 .80631 .5481 .80165 .54225 Metetra
.977 .098 0 r
.80165 .54225 .80631 .5481 .81726 .54508 .81263 .53921 Metetra
.977 .096 0 r
.81263 .53921 .81726 .54508 .82824 .54196 .82364 .53606 Metetra
.977 .098 0 r
.82364 .53606 .82824 .54196 .83923 .53849 .83466 .53258 Metetra
.974 .11 0 r
.83466 .53258 .83923 .53849 .85017 .53403 .84563 .52809 Metetra
.965 .147 0 r
.84563 .52809 .85017 .53403 .86089 .52709 .85639 .52112 Metetra
.942 .237 0 r
.85639 .52112 .86089 .52709 .8711 .51498 .86663 .50897 Metetra
.893 .414 0 r
.86663 .50897 .8711 .51498 .88033 .49397 .87591 .4879 Metetra
.804 .682 0 r
.87591 .4879 .88033 .49397 .88811 .46058 .88375 .45443 Metetra
.367 .666 0 r
.88375 .45443 .88811 .46058 .89422 .41391 .88993 .40767 Metetra
.077 .57 0 r
.26912 .56646 .27484 .57153 .28022 .61567 .27443 .61065 Metetra
.628 .735 0 r
.27443 .61065 .28022 .61567 .28663 .6485 .28079 .64353 Metetra
.851 .551 0 r
.28079 .64353 .28663 .6485 .2941 .66873 .28823 .66378 Metetra
.919 .321 0 r
.28823 .66378 .2941 .66873 .30236 .67862 .29649 .67368 Metetra
.955 .187 0 r
.29649 .67368 .30236 .67862 .31113 .68177 .30527 .67682 Metetra
.97 .125 0 r
.30527 .67682 .31113 .68177 .32017 .68134 .31433 .67638 Metetra
.976 .103 0 r
.31433 .67638 .32017 .68134 .32935 .67933 .32352 .67436 Metetra
.977 .097 0 r
.32352 .67436 .32935 .67933 .33859 .67673 .33278 .67174 Metetra
.977 .097 0 r
.33278 .67174 .33859 .67673 .34787 .67394 .34208 .66893 Metetra
.977 .099 0 r
.34208 .66893 .34787 .67394 .35718 .6711 .35141 .66607 Metetra
.976 .101 0 r
.35141 .66607 .35718 .6711 .36653 .66824 .36078 .6632 Metetra
.976 .103 0 r
.36078 .6632 .36653 .66824 .37591 .66538 .37018 .66032 Metetra
.975 .105 0 r
.37018 .66032 .37591 .66538 .38532 .66252 .37961 .65744 Metetra
.975 .108 0 r
.37961 .65744 .38532 .66252 .39476 .65966 .38908 .65456 Metetra
.974 .109 0 r
.38908 .65456 .39476 .65966 .40424 .65679 .39857 .65168 Metetra
.974 .111 0 r
.39857 .65168 .40424 .65679 .41375 .65392 .4081 .64879 Metetra
.973 .113 0 r
.4081 .64879 .41375 .65392 .42329 .65105 .41766 .6459 Metetra
.973 .114 0 r
.41766 .6459 .42329 .65105 .43286 .64818 .42726 .64301 Metetra
.973 .116 0 r
.42726 .64301 .43286 .64818 .44247 .6453 .43689 .64011 Metetra
.972 .117 0 r
.43689 .64011 .44247 .6453 .45211 .64242 .44655 .63721 Metetra
.972 .118 0 r
.44655 .63721 .45211 .64242 .46178 .63953 .45625 .63431 Metetra
.972 .12 0 r
.45625 .63431 .46178 .63953 .47149 .63664 .46598 .63141 Metetra
.971 .121 0 r
.46598 .63141 .47149 .63664 .48123 .63375 .47574 .62849 Metetra
.971 .121 0 r
.47574 .62849 .48123 .63375 .49101 .63086 .48554 .62558 Metetra
.971 .122 0 r
.48554 .62558 .49101 .63086 .50082 .62796 .49538 .62267 Metetra
.971 .123 0 r
.49538 .62267 .50082 .62796 .51067 .62506 .50525 .61975 Metetra
.971 .124 0 r
.50525 .61975 .51067 .62506 .52055 .62215 .51515 .61682 Metetra
.971 .124 0 r
.51515 .61682 .52055 .62215 .53047 .61925 .52509 .6139 Metetra
.97 .124 0 r
.52509 .6139 .53047 .61925 .54042 .61633 .53507 .61096 Metetra
.97 .125 0 r
.53507 .61096 .54042 .61633 .55041 .61342 .54508 .60803 Metetra
.97 .125 0 r
.54508 .60803 .55041 .61342 .56044 .6105 .55513 .60509 Metetra
.97 .125 0 r
.55513 .60509 .56044 .6105 .5705 .60758 .56522 .60215 Metetra
.97 .125 0 r
.56522 .60215 .5705 .60758 .5806 .60465 .57534 .5992 Metetra
.97 .125 0 r
.57534 .5992 .5806 .60465 .59073 .60172 .5855 .59625 Metetra
.97 .125 0 r
.5855 .59625 .59073 .60172 .60091 .59878 .5957 .59329 Metetra
.97 .124 0 r
.5957 .59329 .60091 .59878 .61112 .59584 .60594 .59033 Metetra
.971 .124 0 r
.60594 .59033 .61112 .59584 .62137 .5929 .61621 .58737 Metetra
.971 .123 0 r
.61621 .58737 .62137 .5929 .63165 .58995 .62652 .5844 Metetra
.971 .123 0 r
.62652 .5844 .63165 .58995 .64198 .587 .63687 .58143 Metetra
.971 .122 0 r
.63687 .58143 .64198 .587 .65234 .58404 .64726 .57845 Metetra
.971 .121 0 r
.64726 .57845 .65234 .58404 .66274 .58109 .65769 .57548 Metetra
.971 .12 0 r
.65769 .57548 .66274 .58109 .67319 .57813 .66816 .5725 Metetra
.972 .119 0 r
.66816 .5725 .67319 .57813 .68367 .57516 .67867 .56951 Metetra
.972 .118 0 r
.67867 .56951 .68367 .57516 .69419 .57219 .68921 .56651 Metetra
.972 .116 0 r
.68921 .56651 .69419 .57219 .70475 .56922 .6998 .56352 Metetra
.973 .115 0 r
.6998 .56352 .70475 .56922 .71535 .56624 .71043 .56052 Metetra
.973 .114 0 r
.71043 .56052 .71535 .56624 .72599 .56325 .7211 .55751 Metetra
.973 .112 0 r
.7211 .55751 .72599 .56325 .73668 .56027 .73181 .5545 Metetra
.974 .11 0 r
.73181 .5545 .73668 .56027 .7474 .55727 .74256 .55149 Metetra
.974 .108 0 r
.74256 .55149 .7474 .55727 .75817 .55428 .75336 .54847 Metetra
.975 .107 0 r
.75336 .54847 .75817 .55428 .76897 .55128 .76419 .54545 Metetra
.975 .104 0 r
.76419 .54545 .76897 .55128 .77982 .54828 .77507 .54242 Metetra
.976 .102 0 r
.77507 .54242 .77982 .54828 .79072 .54527 .78599 .53939 Metetra
.976 .1 0 r
.78599 .53939 .79072 .54527 .80165 .54225 .79696 .53635 Metetra
.977 .098 0 r
.79696 .53635 .80165 .54225 .81263 .53921 .80796 .53329 Metetra
.977 .096 0 r
.80796 .53329 .81263 .53921 .82364 .53606 .819 .53012 Metetra
.977 .098 0 r
.819 .53012 .82364 .53606 .83466 .53258 .83006 .52661 Metetra
.974 .11 0 r
.83006 .52661 .83466 .53258 .84563 .52809 .84106 .5221 Metetra
.965 .147 0 r
.84106 .5221 .84563 .52809 .85639 .52112 .85185 .5151 Metetra
.942 .237 0 r
.85185 .5151 .85639 .52112 .86663 .50897 .86213 .50291 Metetra
.893 .414 0 r
.86213 .50291 .86663 .50897 .87591 .4879 .87146 .48178 Metetra
.804 .682 0 r
.87146 .48178 .87591 .4879 .88375 .45443 .87936 .44824 Metetra
.367 .666 0 r
.87936 .44824 .88375 .45443 .88993 .40767 .88561 .40139 Metetra
.077 .57 0 r
.26337 .56137 .26912 .56646 .27443 .61065 .2686 .60562 Metetra
.628 .735 0 r
.2686 .60562 .27443 .61065 .28079 .64353 .27492 .63854 Metetra
.851 .551 0 r
.27492 .63854 .28079 .64353 .28823 .66378 .28233 .65882 Metetra
.919 .321 0 r
.28233 .65882 .28823 .66378 .29649 .67368 .29058 .66872 Metetra
.955 .187 0 r
.29058 .66872 .29649 .67368 .30527 .67682 .29937 .67185 Metetra
.97 .126 0 r
.29937 .67185 .30527 .67682 .31433 .67638 .30844 .67141 Metetra
.976 .103 0 r
.30844 .67141 .31433 .67638 .32352 .67436 .31765 .66936 Metetra
.977 .097 0 r
.31765 .66936 .32352 .67436 .33278 .67174 .32693 .66673 Metetra
.977 .097 0 r
.32693 .66673 .33278 .67174 .34208 .66893 .33625 .6639 Metetra
.977 .099 0 r
.33625 .6639 .34208 .66893 .35141 .66607 .34561 .66103 Metetra
.976 .101 0 r
.34561 .66103 .35141 .66607 .36078 .6632 .355 .65813 Metetra
.976 .104 0 r
.355 .65813 .36078 .6632 .37018 .66032 .36442 .65524 Metetra
.975 .106 0 r
.36442 .65524 .37018 .66032 .37961 .65744 .37387 .65234 Metetra
.975 .108 0 r
.37387 .65234 .37961 .65744 .38908 .65456 .38335 .64944 Metetra
.974 .11 0 r
.38335 .64944 .38908 .65456 .39857 .65168 .39287 .64654 Metetra
.974 .111 0 r
.39287 .64654 .39857 .65168 .4081 .64879 .40242 .64364 Metetra
.973 .113 0 r
.40242 .64364 .4081 .64879 .41766 .6459 .412 .64072 Metetra
.973 .115 0 r
.412 .64072 .41766 .6459 .42726 .64301 .42162 .63782 Metetra
.972 .116 0 r
.42162 .63782 .42726 .64301 .43689 .64011 .43127 .6349 Metetra
.972 .117 0 r
.43127 .6349 .43689 .64011 .44655 .63721 .44096 .63198 Metetra
.972 .119 0 r
.44096 .63198 .44655 .63721 .45625 .63431 .45068 .62906 Metetra
.972 .12 0 r
.45068 .62906 .45625 .63431 .46598 .63141 .46043 .62614 Metetra
.971 .121 0 r
.46043 .62614 .46598 .63141 .47574 .62849 .47022 .62321 Metetra
.971 .122 0 r
.47022 .62321 .47574 .62849 .48554 .62558 .48004 .62028 Metetra
.971 .122 0 r
.48004 .62028 .48554 .62558 .49538 .62267 .4899 .61734 Metetra
.971 .123 0 r
.4899 .61734 .49538 .62267 .50525 .61975 .49979 .6144 Metetra
.971 .124 0 r
.49979 .6144 .50525 .61975 .51515 .61682 .50972 .61146 Metetra
.97 .124 0 r
.50972 .61146 .51515 .61682 .52509 .6139 .51968 .60851 Metetra
.97 .124 0 r
.51968 .60851 .52509 .6139 .53507 .61096 .52968 .60556 Metetra
.97 .125 0 r
.52968 .60556 .53507 .61096 .54508 .60803 .53972 .60261 Metetra
.97 .125 0 r
.53972 .60261 .54508 .60803 .55513 .60509 .54979 .59965 Metetra
.97 .125 0 r
.54979 .59965 .55513 .60509 .56522 .60215 .5599 .59668 Metetra
.97 .125 0 r
.5599 .59668 .56522 .60215 .57534 .5992 .57005 .59372 Metetra
.97 .125 0 r
.57005 .59372 .57534 .5992 .5855 .59625 .58024 .59075 Metetra
.97 .125 0 r
.58024 .59075 .5855 .59625 .5957 .59329 .59046 .58777 Metetra
.97 .124 0 r
.59046 .58777 .5957 .59329 .60594 .59033 .60072 .58479 Metetra
.971 .124 0 r
.60072 .58479 .60594 .59033 .61621 .58737 .61102 .58181 Metetra
.971 .123 0 r
.61102 .58181 .61621 .58737 .62652 .5844 .62136 .57882 Metetra
.971 .123 0 r
.62136 .57882 .62652 .5844 .63687 .58143 .63173 .57583 Metetra
.971 .122 0 r
.63173 .57583 .63687 .58143 .64726 .57845 .64215 .57283 Metetra
.971 .121 0 r
.64215 .57283 .64726 .57845 .65769 .57548 .6526 .56983 Metetra
.971 .12 0 r
.6526 .56983 .65769 .57548 .66816 .5725 .6631 .56683 Metetra
.972 .119 0 r
.6631 .56683 .66816 .5725 .67867 .56951 .67363 .56382 Metetra
.972 .118 0 r
.67363 .56382 .67867 .56951 .68921 .56651 .68421 .5608 Metetra
.972 .117 0 r
.68421 .5608 .68921 .56651 .6998 .56352 .69482 .55779 Metetra
.973 .115 0 r
.69482 .55779 .6998 .56352 .71043 .56052 .70548 .55476 Metetra
.973 .114 0 r
.70548 .55476 .71043 .56052 .7211 .55751 .71617 .55174 Metetra
.973 .112 0 r
.71617 .55174 .7211 .55751 .73181 .5545 .72691 .5487 Metetra
.974 .11 0 r
.72691 .5487 .73181 .5545 .74256 .55149 .73769 .54567 Metetra
.974 .109 0 r
.73769 .54567 .74256 .55149 .75336 .54847 .74852 .54263 Metetra
.975 .107 0 r
.74852 .54263 .75336 .54847 .76419 .54545 .75938 .53959 Metetra
.975 .105 0 r
.75938 .53959 .76419 .54545 .77507 .54242 .77029 .53654 Metetra
.976 .102 0 r
.77029 .53654 .77507 .54242 .78599 .53939 .78124 .53349 Metetra
.976 .1 0 r
.78124 .53349 .78599 .53939 .79696 .53635 .79223 .53043 Metetra
.977 .098 0 r
.79223 .53043 .79696 .53635 .80796 .53329 .80327 .52734 Metetra
.977 .097 0 r
.80327 .52734 .80796 .53329 .819 .53012 .81434 .52415 Metetra
.977 .098 0 r
.81434 .52415 .819 .53012 .83006 .52661 .82542 .52061 Metetra
.974 .11 0 r
.82542 .52061 .83006 .52661 .84106 .5221 .83645 .51608 Metetra
.965 .147 0 r
.83645 .51608 .84106 .5221 .85185 .5151 .84728 .50904 Metetra
.942 .237 0 r
.84728 .50904 .85185 .5151 .86213 .50291 .8576 .49682 Metetra
.893 .414 0 r
.8576 .49682 .86213 .50291 .87146 .48178 .86698 .47564 Metetra
.804 .682 0 r
.86698 .47564 .87146 .48178 .87936 .44824 .87494 .44202 Metetra
.367 .666 0 r
.87494 .44202 .87936 .44824 .88561 .40139 .88126 .39507 Metetra
.077 .57 0 r
.25758 .55624 .26337 .56137 .2686 .60562 .26274 .60055 Metetra
.627 .735 0 r
.26274 .60055 .2686 .60562 .27492 .63854 .269 .63351 Metetra
.851 .551 0 r
.269 .63351 .27492 .63854 .28233 .65882 .27639 .65382 Metetra
.919 .321 0 r
.27639 .65382 .28233 .65882 .29058 .66872 .28464 .66372 Metetra
.955 .187 0 r
.28464 .66372 .29058 .66872 .29937 .67185 .29343 .66685 Metetra
.97 .126 0 r
.29343 .66685 .29937 .67185 .30844 .67141 .30252 .66639 Metetra
.976 .103 0 r
.30252 .66639 .30844 .67141 .31765 .66936 .31175 .66433 Metetra
.977 .097 0 r
.31175 .66433 .31765 .66936 .32693 .66673 .32105 .66168 Metetra
.977 .097 0 r
.32105 .66168 .32693 .66673 .33625 .6639 .33039 .65884 Metetra
.977 .099 0 r
.33039 .65884 .33625 .6639 .34561 .66103 .33976 .65595 Metetra
.976 .101 0 r
.33976 .65595 .34561 .66103 .355 .65813 .34917 .65303 Metetra
.975 .104 0 r
.34917 .65303 .355 .65813 .36442 .65524 .35861 .65012 Metetra
.975 .106 0 r
.35861 .65012 .36442 .65524 .37387 .65234 .36809 .6472 Metetra
.974 .108 0 r
.36809 .6472 .37387 .65234 .38335 .64944 .37759 .64429 Metetra
.974 .11 0 r
.37759 .64429 .38335 .64944 .39287 .64654 .38713 .64137 Metetra
.974 .111 0 r
.38713 .64137 .39287 .64654 .40242 .64364 .3967 .63844 Metetra
.973 .113 0 r
.3967 .63844 .40242 .64364 .412 .64072 .40631 .63552 Metetra
.973 .115 0 r
.40631 .63552 .412 .64072 .42162 .63782 .41595 .63259 Metetra
.972 .116 0 r
.41595 .63259 .42162 .63782 .43127 .6349 .42562 .62965 Metetra
.972 .117 0 r
.42562 .62965 .43127 .6349 .44096 .63198 .43533 .62672 Metetra
.972 .119 0 r
.43533 .62672 .44096 .63198 .45068 .62906 .44507 .62378 Metetra
.972 .12 0 r
.44507 .62378 .45068 .62906 .46043 .62614 .45484 .62083 Metetra
.971 .121 0 r
.45484 .62083 .46043 .62614 .47022 .62321 .46465 .61788 Metetra
.971 .122 0 r
.46465 .61788 .47022 .62321 .48004 .62028 .4745 .61493 Metetra
.971 .122 0 r
.4745 .61493 .48004 .62028 .4899 .61734 .48438 .61198 Metetra
.971 .123 0 r
.48438 .61198 .4899 .61734 .49979 .6144 .49429 .60902 Metetra
.971 .124 0 r
.49429 .60902 .49979 .6144 .50972 .61146 .50425 .60606 Metetra
.97 .124 0 r
.50425 .60606 .50972 .61146 .51968 .60851 .51423 .60309 Metetra
.97 .125 0 r
.51423 .60309 .51968 .60851 .52968 .60556 .52426 .60012 Metetra
.97 .125 0 r
.52426 .60012 .52968 .60556 .53972 .60261 .53432 .59715 Metetra
.97 .125 0 r
.53432 .59715 .53972 .60261 .54979 .59965 .54442 .59417 Metetra
.97 .125 0 r
.54442 .59417 .54979 .59965 .5599 .59668 .55455 .59118 Metetra
.97 .125 0 r
.55455 .59118 .5599 .59668 .57005 .59372 .56473 .5882 Metetra
.97 .125 0 r
.56473 .5882 .57005 .59372 .58024 .59075 .57494 .5852 Metetra
.97 .125 0 r
.57494 .5852 .58024 .59075 .59046 .58777 .58518 .58221 Metetra
.97 .124 0 r
.58518 .58221 .59046 .58777 .60072 .58479 .59547 .57921 Metetra
.971 .124 0 r
.59547 .57921 .60072 .58479 .61102 .58181 .60579 .5762 Metetra
.971 .123 0 r
.60579 .5762 .61102 .58181 .62136 .57882 .61616 .57319 Metetra
.971 .123 0 r
.61616 .57319 .62136 .57882 .63173 .57583 .62656 .57018 Metetra
.971 .122 0 r
.62656 .57018 .63173 .57583 .64215 .57283 .637 .56716 Metetra
.971 .121 0 r
.637 .56716 .64215 .57283 .6526 .56983 .64748 .56415 Metetra
.971 .12 0 r
.64748 .56415 .6526 .56983 .6631 .56683 .658 .56112 Metetra
.972 .119 0 r
.658 .56112 .6631 .56683 .67363 .56382 .66856 .55809 Metetra
.972 .118 0 r
.66856 .55809 .67363 .56382 .68421 .5608 .67916 .55505 Metetra
.972 .117 0 r
.67916 .55505 .68421 .5608 .69482 .55779 .68981 .55201 Metetra
.973 .115 0 r
.68981 .55201 .69482 .55779 .70548 .55476 .70049 .54897 Metetra
.973 .114 0 r
.70049 .54897 .70548 .55476 .71617 .55174 .71121 .54592 Metetra
.973 .112 0 r
.71121 .54592 .71617 .55174 .72691 .5487 .72198 .54287 Metetra
.974 .111 0 r
.72198 .54287 .72691 .5487 .73769 .54567 .73279 .53981 Metetra
.974 .109 0 r
.73279 .53981 .73769 .54567 .74852 .54263 .74364 .53675 Metetra
.975 .107 0 r
.74364 .53675 .74852 .54263 .75938 .53959 .75453 .53368 Metetra
.975 .105 0 r
.75453 .53368 .75938 .53959 .77029 .53654 .76547 .53061 Metetra
.976 .103 0 r
.76547 .53061 .77029 .53654 .78124 .53349 .77645 .52754 Metetra
.976 .1 0 r
.77645 .52754 .78124 .53349 .79223 .53043 .78747 .52446 Metetra
.977 .098 0 r
.78747 .52446 .79223 .53043 .80327 .52734 .79854 .52134 Metetra
.977 .097 0 r
.79854 .52134 .80327 .52734 .81434 .52415 .80964 .51813 Metetra
.977 .099 0 r
.80964 .51813 .81434 .52415 .82542 .52061 .82075 .51457 Metetra
.974 .11 0 r
.82075 .51457 .82542 .52061 .83645 .51608 .83182 .51001 Metetra
.965 .147 0 r
.83182 .51001 .83645 .51608 .84728 .50904 .84268 .50295 Metetra
.942 .238 0 r
.84268 .50295 .84728 .50904 .8576 .49682 .85304 .49068 Metetra
.893 .414 0 r
.85304 .49068 .8576 .49682 .86698 .47564 .86247 .46944 Metetra
.804 .682 0 r
.86247 .46944 .86698 .47564 .87494 .44202 .87049 .43575 Metetra
.367 .666 0 r
.87049 .43575 .87494 .44202 .88126 .39507 .87688 .38872 Metetra
.077 .569 0 r
.25175 .55108 .25758 .55624 .26274 .60055 .25684 .59545 Metetra
.627 .735 0 r
.25684 .59545 .26274 .60055 .269 .63351 .26305 .62846 Metetra
.85 .551 0 r
.26305 .62846 .269 .63351 .27639 .65382 .27041 .64879 Metetra
.919 .321 0 r
.27041 .64879 .27639 .65382 .28464 .66372 .27865 .6587 Metetra
.955 .188 0 r
.27865 .6587 .28464 .66372 .29343 .66685 .28746 .66183 Metetra
.97 .126 0 r
.28746 .66183 .29343 .66685 .30252 .66639 .29656 .66135 Metetra
.976 .103 0 r
.29656 .66135 .30252 .66639 .31175 .66433 .30581 .65927 Metetra
.977 .097 0 r
.30581 .65927 .31175 .66433 .32105 .66168 .31512 .65661 Metetra
.977 .097 0 r
.31512 .65661 .32105 .66168 .33039 .65884 .32448 .65374 Metetra
.977 .099 0 r
.32448 .65374 .33039 .65884 .33976 .65595 .33388 .65083 Metetra
.976 .101 0 r
.33388 .65083 .33976 .65595 .34917 .65303 .34331 .6479 Metetra
.975 .104 0 r
.34331 .6479 .34917 .65303 .35861 .65012 .35277 .64497 Metetra
.975 .106 0 r
.35277 .64497 .35861 .65012 .36809 .6472 .36227 .64204 Metetra
.974 .108 0 r
.36227 .64204 .36809 .6472 .37759 .64429 .37179 .6391 Metetra
.974 .11 0 r
.37179 .6391 .37759 .64429 .38713 .64137 .38135 .63616 Metetra
.974 .111 0 r
.38135 .63616 .38713 .64137 .3967 .63844 .39095 .63322 Metetra
.973 .113 0 r
.39095 .63322 .3967 .63844 .40631 .63552 .40057 .63027 Metetra
.973 .115 0 r
.40057 .63027 .40631 .63552 .41595 .63259 .41023 .62733 Metetra
.972 .116 0 r
.41023 .62733 .41595 .63259 .42562 .62965 .41993 .62437 Metetra
.972 .117 0 r
.41993 .62437 .42562 .62965 .43533 .62672 .42966 .62142 Metetra
.972 .119 0 r
.42966 .62142 .43533 .62672 .44507 .62378 .43942 .61846 Metetra
.972 .12 0 r
.43942 .61846 .44507 .62378 .45484 .62083 .44922 .6155 Metetra
.971 .121 0 r
.44922 .6155 .45484 .62083 .46465 .61788 .45905 .61253 Metetra
.971 .122 0 r
.45905 .61253 .46465 .61788 .4745 .61493 .46892 .60956 Metetra
.971 .122 0 r
.46892 .60956 .4745 .61493 .48438 .61198 .47882 .60658 Metetra
.971 .123 0 r
.47882 .60658 .48438 .61198 .49429 .60902 .48876 .60361 Metetra
.971 .124 0 r
.48876 .60361 .49429 .60902 .50425 .60606 .49874 .60062 Metetra
.97 .124 0 r
.49874 .60062 .50425 .60606 .51423 .60309 .50875 .59764 Metetra
.97 .125 0 r
.50875 .59764 .51423 .60309 .52426 .60012 .5188 .59465 Metetra
.97 .125 0 r
.5188 .59465 .52426 .60012 .53432 .59715 .52888 .59165 Metetra
.97 .125 0 r
.52888 .59165 .53432 .59715 .54442 .59417 .53901 .58865 Metetra
.97 .125 0 r
.53901 .58865 .54442 .59417 .55455 .59118 .54916 .58565 Metetra
.97 .125 0 r
.54916 .58565 .55455 .59118 .56473 .5882 .55936 .58264 Metetra
.97 .125 0 r
.55936 .58264 .56473 .5882 .57494 .5852 .5696 .57963 Metetra
.97 .125 0 r
.5696 .57963 .57494 .5852 .58518 .58221 .57987 .57661 Metetra
.97 .124 0 r
.57987 .57661 .58518 .58221 .59547 .57921 .59018 .57359 Metetra
.971 .124 0 r
.59018 .57359 .59547 .57921 .60579 .5762 .60053 .57057 Metetra
.971 .124 0 r
.60053 .57057 .60579 .5762 .61616 .57319 .61092 .56753 Metetra
.971 .123 0 r
.61092 .56753 .61616 .57319 .62656 .57018 .62135 .5645 Metetra
.971 .122 0 r
.62135 .5645 .62656 .57018 .637 .56716 .63182 .56146 Metetra
.971 .121 0 r
.63182 .56146 .637 .56716 .64748 .56415 .64232 .55842 Metetra
.971 .12 0 r
.64232 .55842 .64748 .56415 .658 .56112 .65287 .55538 Metetra
.972 .119 0 r
.65287 .55538 .658 .56112 .66856 .55809 .66346 .55232 Metetra
.972 .118 0 r
.66346 .55232 .66856 .55809 .67916 .55505 .67409 .54927 Metetra
.972 .117 0 r
.67409 .54927 .67916 .55505 .68981 .55201 .68476 .54621 Metetra
.973 .115 0 r
.68476 .54621 .68981 .55201 .70049 .54897 .69547 .54314 Metetra
.973 .114 0 r
.69547 .54314 .70049 .54897 .71121 .54592 .70622 .54007 Metetra
.973 .112 0 r
.70622 .54007 .71121 .54592 .72198 .54287 .71701 .53699 Metetra
.974 .111 0 r
.71701 .53699 .72198 .54287 .73279 .53981 .72785 .53391 Metetra
.974 .109 0 r
.72785 .53391 .73279 .53981 .74364 .53675 .73873 .53083 Metetra
.975 .107 0 r
.73873 .53083 .74364 .53675 .75453 .53368 .74965 .52774 Metetra
.975 .105 0 r
.74965 .52774 .75453 .53368 .76547 .53061 .76062 .52465 Metetra
.976 .103 0 r
.76062 .52465 .76547 .53061 .77645 .52754 .77163 .52155 Metetra
.976 .1 0 r
.77163 .52155 .77645 .52754 .78747 .52446 .78268 .51845 Metetra
.977 .098 0 r
.78268 .51845 .78747 .52446 .79854 .52134 .79377 .51531 Metetra
.977 .097 0 r
.79377 .51531 .79854 .52134 .80964 .51813 .8049 .51207 Metetra
.977 .099 0 r
.8049 .51207 .80964 .51813 .82075 .51457 .81605 .50849 Metetra
.974 .11 0 r
.81605 .50849 .82075 .51457 .83182 .51001 .82715 .5039 Metetra
.965 .147 0 r
.82715 .5039 .83182 .51001 .84268 .50295 .83804 .49681 Metetra
.942 .238 0 r
.83804 .49681 .84268 .50295 .85304 .49068 .84845 .4845 Metetra
.893 .414 0 r
.84845 .4845 .85304 .49068 .86247 .46944 .85792 .46321 Metetra
.804 .683 0 r
.85792 .46321 .86247 .46944 .87049 .43575 .86601 .42945 Metetra
.366 .666 0 r
.86601 .42945 .87049 .43575 .87688 .38872 .87247 .38232 Metetra
.077 .569 0 r
.24589 .5459 .25175 .55108 .25684 .59545 .2509 .59033 Metetra
.627 .735 0 r
.2509 .59033 .25684 .59545 .26305 .62846 .25706 .62338 Metetra
.85 .551 0 r
.25706 .62338 .26305 .62846 .27041 .64879 .26439 .64373 Metetra
.919 .321 0 r
.26439 .64373 .27041 .64879 .27865 .6587 .27263 .65365 Metetra
.955 .188 0 r
.27263 .65365 .27865 .6587 .28746 .66183 .28144 .65677 Metetra
.97 .126 0 r
.28144 .65677 .28746 .66183 .29656 .66135 .29056 .65628 Metetra
.976 .103 0 r
.29056 .65628 .29656 .66135 .30581 .65927 .29982 .65418 Metetra
.977 .097 0 r
.29982 .65418 .30581 .65927 .31512 .65661 .30916 .6515 Metetra
.977 .097 0 r
.30916 .6515 .31512 .65661 .32448 .65374 .31854 .64862 Metetra
.977 .099 0 r
.31854 .64862 .32448 .65374 .33388 .65083 .32796 .64569 Metetra
.976 .102 0 r
.32796 .64569 .33388 .65083 .34331 .6479 .33741 .64274 Metetra
.975 .104 0 r
.33741 .64274 .34331 .6479 .35277 .64497 .34689 .63979 Metetra
.975 .106 0 r
.34689 .63979 .35277 .64497 .36227 .64204 .35641 .63684 Metetra
.974 .108 0 r
.35641 .63684 .36227 .64204 .37179 .6391 .36595 .63388 Metetra
.974 .11 0 r
.36595 .63388 .37179 .6391 .38135 .63616 .37554 .63092 Metetra
.974 .112 0 r
.37554 .63092 .38135 .63616 .39095 .63322 .38515 .62796 Metetra
.973 .113 0 r
.38515 .62796 .39095 .63322 .40057 .63027 .3948 .625 Metetra
.973 .115 0 r
.3948 .625 .40057 .63027 .41023 .62733 .40448 .62203 Metetra
.972 .116 0 r
.40448 .62203 .41023 .62733 .41993 .62437 .4142 .61906 Metetra
.972 .117 0 r
.4142 .61906 .41993 .62437 .42966 .62142 .42395 .61608 Metetra
.972 .119 0 r
.42395 .61608 .42966 .62142 .43942 .61846 .43374 .6131 Metetra
.972 .12 0 r
.43374 .6131 .43942 .61846 .44922 .6155 .44356 .61012 Metetra
.971 .121 0 r
.44356 .61012 .44922 .6155 .45905 .61253 .45341 .60714 Metetra
.971 .122 0 r
.45341 .60714 .45905 .61253 .46892 .60956 .4633 .60415 Metetra
.971 .123 0 r
.4633 .60415 .46892 .60956 .47882 .60658 .47323 .60115 Metetra
.971 .123 0 r
.47323 .60115 .47882 .60658 .48876 .60361 .48319 .59815 Metetra
.971 .124 0 r
.48319 .59815 .48876 .60361 .49874 .60062 .49319 .59515 Metetra
.97 .124 0 r
.49319 .59515 .49874 .60062 .50875 .59764 .50323 .59215 Metetra
.97 .125 0 r
.50323 .59215 .50875 .59764 .5188 .59465 .5133 .58913 Metetra
.97 .125 0 r
.5133 .58913 .5188 .59465 .52888 .59165 .52341 .58612 Metetra
.97 .125 0 r
.52341 .58612 .52888 .59165 .53901 .58865 .53356 .5831 Metetra
.97 .125 0 r
.53356 .5831 .53901 .58865 .54916 .58565 .54374 .58008 Metetra
.97 .125 0 r
.54374 .58008 .54916 .58565 .55936 .58264 .55396 .57705 Metetra
.97 .125 0 r
.55396 .57705 .55936 .58264 .5696 .57963 .56422 .57401 Metetra
.97 .125 0 r
.56422 .57401 .5696 .57963 .57987 .57661 .57452 .57098 Metetra
.97 .125 0 r
.57452 .57098 .57987 .57661 .59018 .57359 .58486 .56793 Metetra
.97 .124 0 r
.58486 .56793 .59018 .57359 .60053 .57057 .59523 .56489 Metetra
.971 .124 0 r
.59523 .56489 .60053 .57057 .61092 .56753 .60565 .56184 Metetra
.971 .123 0 r
.60565 .56184 .61092 .56753 .62135 .5645 .6161 .55878 Metetra
.971 .122 0 r
.6161 .55878 .62135 .5645 .63182 .56146 .6266 .55572 Metetra
.971 .121 0 r
.6266 .55572 .63182 .56146 .64232 .55842 .63713 .55266 Metetra
.971 .12 0 r
.63713 .55266 .64232 .55842 .65287 .55538 .6477 .54959 Metetra
.972 .119 0 r
.6477 .54959 .65287 .55538 .66346 .55232 .65832 .54652 Metetra
.972 .118 0 r
.65832 .54652 .66346 .55232 .67409 .54927 .66897 .54344 Metetra
.972 .117 0 r
.66897 .54344 .67409 .54927 .68476 .54621 .67967 .54036 Metetra
.973 .115 0 r
.67967 .54036 .68476 .54621 .69547 .54314 .69041 .53727 Metetra
.973 .114 0 r
.69041 .53727 .69547 .54314 .70622 .54007 .70119 .53417 Metetra
.973 .112 0 r
.70119 .53417 .70622 .54007 .71701 .53699 .71201 .53108 Metetra
.974 .111 0 r
.71201 .53108 .71701 .53699 .72785 .53391 .72288 .52797 Metetra
.974 .109 0 r
.72288 .52797 .72785 .53391 .73873 .53083 .73379 .52487 Metetra
.975 .107 0 r
.73379 .52487 .73873 .53083 .74965 .52774 .74474 .52176 Metetra
.975 .105 0 r
.74474 .52176 .74965 .52774 .76062 .52465 .75573 .51864 Metetra
.976 .103 0 r
.75573 .51864 .76062 .52465 .77163 .52155 .76677 .51552 Metetra
.976 .1 0 r
.76677 .51552 .77163 .52155 .78268 .51845 .77785 .51239 Metetra
.977 .098 0 r
.77785 .51239 .78268 .51845 .79377 .51531 .78898 .50923 Metetra
.977 .097 0 r
.78898 .50923 .79377 .51531 .8049 .51207 .80014 .50597 Metetra
.977 .099 0 r
.80014 .50597 .8049 .51207 .81605 .50849 .81131 .50237 Metetra
.974 .11 0 r
.81131 .50237 .81605 .50849 .82715 .5039 .82244 .49775 Metetra
.965 .147 0 r
.82244 .49775 .82715 .5039 .83804 .49681 .83337 .49063 Metetra
.942 .238 0 r
.83337 .49063 .83804 .49681 .84845 .4845 .84382 .47828 Metetra
.893 .415 0 r
.84382 .47828 .84845 .4845 .85792 .46321 .85334 .45694 Metetra
.804 .683 0 r
.85334 .45694 .85792 .46321 .86601 .42945 .86149 .4231 Metetra
.366 .665 0 r
.86149 .4231 .86601 .42945 .87247 .38232 .86803 .37587 Metetra
.076 .569 0 r
.23999 .54069 .24589 .5459 .2509 .59033 .24492 .58517 Metetra
.627 .735 0 r
.24492 .58517 .2509 .59033 .25706 .62338 .25103 .61827 Metetra
.85 .551 0 r
.25103 .61827 .25706 .62338 .26439 .64373 .25834 .63864 Metetra
.919 .321 0 r
.25834 .63864 .26439 .64373 .27263 .65365 .26657 .64856 Metetra
.955 .188 0 r
.26657 .64856 .27263 .65365 .28144 .65677 .27539 .65167 Metetra
.97 .126 0 r
.27539 .65167 .28144 .65677 .29056 .65628 .28452 .65117 Metetra
.976 .103 0 r
.28452 .65117 .29056 .65628 .29982 .65418 .2938 .64906 Metetra
.977 .097 0 r
.2938 .64906 .29982 .65418 .30916 .6515 .30316 .64636 Metetra
.977 .097 0 r
.30316 .64636 .30916 .6515 .31854 .64862 .31256 .64346 Metetra
.977 .099 0 r
.31256 .64346 .31854 .64862 .32796 .64569 .322 .64051 Metetra
.976 .102 0 r
.322 .64051 .32796 .64569 .33741 .64274 .33147 .63754 Metetra
.975 .104 0 r
.33147 .63754 .33741 .64274 .34689 .63979 .34097 .63458 Metetra
.975 .106 0 r
.34097 .63458 .34689 .63979 .35641 .63684 .35051 .6316 Metetra
.974 .108 0 r
.35051 .6316 .35641 .63684 .36595 .63388 .36008 .62863 Metetra
.974 .11 0 r
.36008 .62863 .36595 .63388 .37554 .63092 .36968 .62565 Metetra
.974 .112 0 r
.36968 .62565 .37554 .63092 .38515 .62796 .37932 .62267 Metetra
.973 .113 0 r
.37932 .62267 .38515 .62796 .3948 .625 .38899 .61969 Metetra
.973 .115 0 r
.38899 .61969 .3948 .625 .40448 .62203 .39869 .6167 Metetra
.972 .116 0 r
.39869 .6167 .40448 .62203 .4142 .61906 .40843 .61371 Metetra
.972 .118 0 r
.40843 .61371 .4142 .61906 .42395 .61608 .4182 .61072 Metetra
.972 .119 0 r
.4182 .61072 .42395 .61608 .43374 .6131 .42801 .60772 Metetra
.972 .12 0 r
.42801 .60772 .43374 .6131 .44356 .61012 .43786 .60472 Metetra
.971 .121 0 r
.43786 .60472 .44356 .61012 .45341 .60714 .44773 .60171 Metetra
.971 .122 0 r
.44773 .60171 .45341 .60714 .4633 .60415 .45765 .5987 Metetra
.971 .123 0 r
.45765 .5987 .4633 .60415 .47323 .60115 .4676 .59568 Metetra
.971 .123 0 r
.4676 .59568 .47323 .60115 .48319 .59815 .47759 .59267 Metetra
.971 .124 0 r
.47759 .59267 .48319 .59815 .49319 .59515 .48761 .58964 Metetra
.97 .124 0 r
.48761 .58964 .49319 .59515 .50323 .59215 .49767 .58662 Metetra
.97 .125 0 r
.49767 .58662 .50323 .59215 .5133 .58913 .50776 .58359 Metetra
.97 .125 0 r
.50776 .58359 .5133 .58913 .52341 .58612 .5179 .58055 Metetra
.97 .125 0 r
.5179 .58055 .52341 .58612 .53356 .5831 .52807 .57751 Metetra
.97 .125 0 r
.52807 .57751 .53356 .5831 .54374 .58008 .53828 .57447 Metetra
.97 .125 0 r
.53828 .57447 .54374 .58008 .55396 .57705 .54852 .57142 Metetra
.97 .125 0 r
.54852 .57142 .55396 .57705 .56422 .57401 .55881 .56836 Metetra
.97 .125 0 r
.55881 .56836 .56422 .57401 .57452 .57098 .56913 .5653 Metetra
.97 .125 0 r
.56913 .5653 .57452 .57098 .58486 .56793 .5795 .56224 Metetra
.97 .124 0 r
.5795 .56224 .58486 .56793 .59523 .56489 .5899 .55917 Metetra
.971 .124 0 r
.5899 .55917 .59523 .56489 .60565 .56184 .60034 .5561 Metetra
.971 .123 0 r
.60034 .5561 .60565 .56184 .6161 .55878 .61082 .55302 Metetra
.971 .122 0 r
.61082 .55302 .6161 .55878 .6266 .55572 .62134 .54994 Metetra
.971 .121 0 r
.62134 .54994 .6266 .55572 .63713 .55266 .6319 .54686 Metetra
.971 .12 0 r
.6319 .54686 .63713 .55266 .6477 .54959 .6425 .54377 Metetra
.972 .119 0 r
.6425 .54377 .6477 .54959 .65832 .54652 .65314 .54067 Metetra
.972 .118 0 r
.65314 .54067 .65832 .54652 .66897 .54344 .66383 .53757 Metetra
.972 .117 0 r
.66383 .53757 .66897 .54344 .67967 .54036 .67455 .53447 Metetra
.973 .115 0 r
.67455 .53447 .67967 .54036 .69041 .53727 .68532 .53136 Metetra
.973 .114 0 r
.68532 .53136 .69041 .53727 .70119 .53417 .69613 .52824 Metetra
.973 .112 0 r
.69613 .52824 .70119 .53417 .71201 .53108 .70698 .52512 Metetra
.974 .111 0 r
.70698 .52512 .71201 .53108 .72288 .52797 .71787 .522 Metetra
.974 .109 0 r
.71787 .522 .72288 .52797 .73379 .52487 .72881 .51887 Metetra
.975 .107 0 r
.72881 .51887 .73379 .52487 .74474 .52176 .73979 .51573 Metetra
.975 .105 0 r
.73979 .51573 .74474 .52176 .75573 .51864 .75081 .51259 Metetra
.976 .103 0 r
.75081 .51259 .75573 .51864 .76677 .51552 .76188 .50945 Metetra
.976 .1 0 r
.76188 .50945 .76677 .51552 .77785 .51239 .77299 .5063 Metetra
.977 .098 0 r
.77299 .5063 .77785 .51239 .78898 .50923 .78415 .50312 Metetra
.977 .097 0 r
.78415 .50312 .78898 .50923 .80014 .50597 .79534 .49983 Metetra
.977 .099 0 r
.79534 .49983 .80014 .50597 .81131 .50237 .80654 .4962 Metetra
.974 .11 0 r
.80654 .4962 .81131 .50237 .82244 .49775 .81771 .49156 Metetra
.965 .147 0 r
.81771 .49156 .82244 .49775 .83337 .49063 .82867 .48441 Metetra
.942 .238 0 r
.82867 .48441 .83337 .49063 .84382 .47828 .83916 .47202 Metetra
.893 .415 0 r
.83916 .47202 .84382 .47828 .85334 .45694 .84873 .45062 Metetra
.804 .683 0 r
.84873 .45062 .85334 .45694 .86149 .4231 .85695 .4167 Metetra
.366 .665 0 r
.85695 .4167 .86149 .4231 .86803 .37587 .86356 .36939 Metetra
.076 .569 0 r
.23406 .53544 .23999 .54069 .24492 .58517 .23891 .57998 Metetra
.627 .735 0 r
.23891 .57998 .24492 .58517 .25103 .61827 .24497 .61312 Metetra
.85 .551 0 r
.24497 .61312 .25103 .61827 .25834 .63864 .25224 .63352 Metetra
.919 .322 0 r
.25224 .63352 .25834 .63864 .26657 .64856 .26047 .64345 Metetra
.955 .188 0 r
.26047 .64345 .26657 .64856 .27539 .65167 .26929 .64655 Metetra
.97 .126 0 r
.26929 .64655 .27539 .65167 .28452 .65117 .27844 .64603 Metetra
.976 .103 0 r
.27844 .64603 .28452 .65117 .2938 .64906 .28774 .64391 Metetra
.977 .097 0 r
.28774 .64391 .2938 .64906 .30316 .64636 .29712 .64119 Metetra
.977 .097 0 r
.29712 .64119 .30316 .64636 .31256 .64346 .30654 .63827 Metetra
.977 .099 0 r
.30654 .63827 .31256 .64346 .322 .64051 .316 .6353 Metetra
.976 .102 0 r
.316 .6353 .322 .64051 .33147 .63754 .32549 .63231 Metetra
.975 .104 0 r
.32549 .63231 .33147 .63754 .34097 .63458 .33501 .62933 Metetra
.975 .106 0 r
.33501 .62933 .34097 .63458 .35051 .6316 .34457 .62634 Metetra
.974 .108 0 r
.34457 .62634 .35051 .6316 .36008 .62863 .35416 .62335 Metetra
.974 .11 0 r
.35416 .62335 .36008 .62863 .36968 .62565 .36379 .62035 Metetra
.974 .112 0 r
.36379 .62035 .36968 .62565 .37932 .62267 .37344 .61735 Metetra
.973 .113 0 r
.37344 .61735 .37932 .62267 .38899 .61969 .38314 .61434 Metetra
.973 .115 0 r
.38314 .61434 .38899 .61969 .39869 .6167 .39286 .61134 Metetra
.972 .116 0 r
.39286 .61134 .39869 .6167 .40843 .61371 .40262 .60833 Metetra
.972 .118 0 r
.40262 .60833 .40843 .61371 .4182 .61072 .41242 .60531 Metetra
.972 .119 0 r
.41242 .60531 .4182 .61072 .42801 .60772 .42225 .60229 Metetra
.972 .12 0 r
.42225 .60229 .42801 .60772 .43786 .60472 .43212 .59927 Metetra
.971 .121 0 r
.43212 .59927 .43786 .60472 .44773 .60171 .44202 .59625 Metetra
.971 .122 0 r
.44202 .59625 .44773 .60171 .45765 .5987 .45196 .59322 Metetra
.971 .123 0 r
.45196 .59322 .45765 .5987 .4676 .59568 .46193 .59018 Metetra
.971 .123 0 r
.46193 .59018 .4676 .59568 .47759 .59267 .47194 .58714 Metetra
.971 .124 0 r
.47194 .58714 .47759 .59267 .48761 .58964 .48199 .5841 Metetra
.97 .124 0 r
.48199 .5841 .48761 .58964 .49767 .58662 .49207 .58105 Metetra
.97 .125 0 r
.49207 .58105 .49767 .58662 .50776 .58359 .50219 .578 Metetra
.97 .125 0 r
.50219 .578 .50776 .58359 .5179 .58055 .51235 .57494 Metetra
.97 .125 0 r
.51235 .57494 .5179 .58055 .52807 .57751 .52255 .57188 Metetra
.97 .125 0 r
.52255 .57188 .52807 .57751 .53828 .57447 .53278 .56882 Metetra
.97 .125 0 r
.53278 .56882 .53828 .57447 .54852 .57142 .54305 .56575 Metetra
.97 .125 0 r
.54305 .56575 .54852 .57142 .55881 .56836 .55336 .56267 Metetra
.97 .125 0 r
.55336 .56267 .55881 .56836 .56913 .5653 .56371 .55959 Metetra
.97 .125 0 r
.56371 .55959 .56913 .5653 .5795 .56224 .5741 .55651 Metetra
.97 .124 0 r
.5741 .55651 .5795 .56224 .5899 .55917 .58452 .55342 Metetra
.971 .124 0 r
.58452 .55342 .5899 .55917 .60034 .5561 .59499 .55032 Metetra
.971 .123 0 r
.59499 .55032 .60034 .5561 .61082 .55302 .6055 .54723 Metetra
.971 .122 0 r
.6055 .54723 .61082 .55302 .62134 .54994 .61605 .54412 Metetra
.971 .121 0 r
.61605 .54412 .62134 .54994 .6319 .54686 .62663 .54102 Metetra
.971 .12 0 r
.62663 .54102 .6319 .54686 .6425 .54377 .63726 .53791 Metetra
.972 .119 0 r
.63726 .53791 .6425 .54377 .65314 .54067 .64793 .53479 Metetra
.972 .118 0 r
.64793 .53479 .65314 .54067 .66383 .53757 .65864 .53166 Metetra
.972 .117 0 r
.65864 .53166 .66383 .53757 .67455 .53447 .66939 .52854 Metetra
.973 .115 0 r
.66939 .52854 .67455 .53447 .68532 .53136 .68019 .5254 Metetra
.973 .114 0 r
.68019 .5254 .68532 .53136 .69613 .52824 .69102 .52227 Metetra
.973 .112 0 r
.69102 .52227 .69613 .52824 .70698 .52512 .7019 .51912 Metetra
.974 .111 0 r
.7019 .51912 .70698 .52512 .71787 .522 .71283 .51598 Metetra
.974 .109 0 r
.71283 .51598 .71787 .522 .72881 .51887 .72379 .51282 Metetra
.975 .107 0 r
.72379 .51282 .72881 .51887 .73979 .51573 .7348 .50967 Metetra
.975 .105 0 r
.7348 .50967 .73979 .51573 .75081 .51259 .74586 .5065 Metetra
.976 .103 0 r
.74586 .5065 .75081 .51259 .76188 .50945 .75695 .50334 Metetra
.976 .1 0 r
.75695 .50334 .76188 .50945 .77299 .5063 .7681 .50016 Metetra
.977 .098 0 r
.7681 .50016 .77299 .5063 .78415 .50312 .77928 .49696 Metetra
.977 .097 0 r
.77928 .49696 .78415 .50312 .79534 .49983 .7905 .49365 Metetra
.977 .099 0 r
.7905 .49365 .79534 .49983 .80654 .4962 .80174 .48999 Metetra
.974 .11 0 r
.80174 .48999 .80654 .4962 .81771 .49156 .81294 .48533 Metetra
.965 .147 0 r
.81294 .48533 .81771 .49156 .82867 .48441 .82394 .47814 Metetra
.942 .238 0 r
.82394 .47814 .82867 .48441 .83916 .47202 .83446 .46571 Metetra
.893 .415 0 r
.83446 .46571 .83916 .47202 .84873 .45062 .84409 .44426 Metetra
.804 .683 0 r
.84409 .44426 .84873 .45062 .85695 .4167 .85237 .41027 Metetra
.366 .665 0 r
.85237 .41027 .85695 .4167 .86356 .36939 .85906 .36286 Metetra
.076 .569 0 r
.22809 .53017 .23406 .53544 .23891 .57998 .23286 .57477 Metetra
.627 .735 0 r
.23286 .57477 .23891 .57998 .24497 .61312 .23886 .60795 Metetra
.85 .551 0 r
.23886 .60795 .24497 .61312 .25224 .63352 .24611 .62837 Metetra
.919 .322 0 r
.24611 .62837 .25224 .63352 .26047 .64345 .25432 .6383 Metetra
.955 .188 0 r
.25432 .6383 .26047 .64345 .26929 .64655 .26316 .64139 Metetra
.97 .126 0 r
.26316 .64139 .26929 .64655 .27844 .64603 .27232 .64086 Metetra
.976 .103 0 r
.27232 .64086 .27844 .64603 .28774 .64391 .28164 .63872 Metetra
.977 .097 0 r
.28164 .63872 .28774 .64391 .29712 .64119 .29104 .63598 Metetra
.977 .097 0 r
.29104 .63598 .29712 .64119 .30654 .63827 .30048 .63304 Metetra
.977 .099 0 r
.30048 .63304 .30654 .63827 .316 .6353 .30996 .63006 Metetra
.976 .102 0 r
.30996 .63006 .316 .6353 .32549 .63231 .31947 .62705 Metetra
.975 .104 0 r
.31947 .62705 .32549 .63231 .33501 .62933 .32902 .62405 Metetra
.975 .106 0 r
.32902 .62405 .33501 .62933 .34457 .62634 .3386 .62104 Metetra
.974 .108 0 r
.3386 .62104 .34457 .62634 .35416 .62335 .34821 .61803 Metetra
.974 .11 0 r
.34821 .61803 .35416 .62335 .36379 .62035 .35785 .61501 Metetra
.974 .112 0 r
.35785 .61501 .36379 .62035 .37344 .61735 .36753 .61199 Metetra
.973 .113 0 r
.36753 .61199 .37344 .61735 .38314 .61434 .37725 .60896 Metetra
.973 .115 0 r
.37725 .60896 .38314 .61434 .39286 .61134 .387 .60594 Metetra
.972 .116 0 r
.387 .60594 .39286 .61134 .40262 .60833 .39678 .60291 Metetra
.972 .118 0 r
.39678 .60291 .40262 .60833 .41242 .60531 .4066 .59987 Metetra
.972 .119 0 r
.4066 .59987 .41242 .60531 .42225 .60229 .41645 .59683 Metetra
.972 .12 0 r
.41645 .59683 .42225 .60229 .43212 .59927 .42634 .59379 Metetra
.971 .121 0 r
.42634 .59379 .43212 .59927 .44202 .59625 .43627 .59075 Metetra
.971 .122 0 r
.43627 .59075 .44202 .59625 .45196 .59322 .44623 .5877 Metetra
.971 .123 0 r
.44623 .5877 .45196 .59322 .46193 .59018 .45622 .58464 Metetra
.971 .123 0 r
.45622 .58464 .46193 .59018 .47194 .58714 .46626 .58158 Metetra
.971 .124 0 r
.46626 .58158 .47194 .58714 .48199 .5841 .47633 .57852 Metetra
.97 .124 0 r
.47633 .57852 .48199 .5841 .49207 .58105 .48644 .57545 Metetra
.97 .125 0 r
.48644 .57545 .49207 .58105 .50219 .578 .49658 .57238 Metetra
.97 .125 0 r
.49658 .57238 .50219 .578 .51235 .57494 .50676 .5693 Metetra
.97 .125 0 r
.50676 .5693 .51235 .57494 .52255 .57188 .51698 .56622 Metetra
.97 .125 0 r
.51698 .56622 .52255 .57188 .53278 .56882 .52724 .56313 Metetra
.97 .125 0 r
.52724 .56313 .53278 .56882 .54305 .56575 .53754 .56004 Metetra
.97 .125 0 r
.53754 .56004 .54305 .56575 .55336 .56267 .54787 .55694 Metetra
.97 .125 0 r
.54787 .55694 .55336 .56267 .56371 .55959 .55825 .55384 Metetra
.97 .125 0 r
.55825 .55384 .56371 .55959 .5741 .55651 .56866 .55074 Metetra
.97 .124 0 r
.56866 .55074 .5741 .55651 .58452 .55342 .57912 .54763 Metetra
.971 .124 0 r
.57912 .54763 .58452 .55342 .59499 .55032 .58961 .54451 Metetra
.971 .123 0 r
.58961 .54451 .59499 .55032 .6055 .54723 .60014 .54139 Metetra
.971 .122 0 r
.60014 .54139 .6055 .54723 .61605 .54412 .61071 .53826 Metetra
.971 .121 0 r
.61071 .53826 .61605 .54412 .62663 .54102 .62133 .53514 Metetra
.971 .12 0 r
.62133 .53514 .62663 .54102 .63726 .53791 .63198 .532 Metetra
.972 .119 0 r
.63198 .532 .63726 .53791 .64793 .53479 .64268 .52886 Metetra
.972 .118 0 r
.64268 .52886 .64793 .53479 .65864 .53166 .65342 .52572 Metetra
.972 .117 0 r
.65342 .52572 .65864 .53166 .66939 .52854 .6642 .52257 Metetra
.973 .115 0 r
.6642 .52257 .66939 .52854 .68019 .5254 .67502 .51941 Metetra
.973 .114 0 r
.67502 .51941 .68019 .5254 .69102 .52227 .68589 .51625 Metetra
.973 .112 0 r
.68589 .51625 .69102 .52227 .7019 .51912 .6968 .51308 Metetra
.974 .111 0 r
.6968 .51308 .7019 .51912 .71283 .51598 .70775 .50991 Metetra
.974 .109 0 r
.70775 .50991 .71283 .51598 .72379 .51282 .71874 .50674 Metetra
.975 .107 0 r
.71874 .50674 .72379 .51282 .7348 .50967 .72978 .50356 Metetra
.975 .105 0 r
.72978 .50356 .7348 .50967 .74586 .5065 .74086 .50037 Metetra
.976 .103 0 r
.74086 .50037 .74586 .5065 .75695 .50334 .75199 .49718 Metetra
.976 .1 0 r
.75199 .49718 .75695 .50334 .7681 .50016 .76316 .49398 Metetra
.977 .098 0 r
.76316 .49398 .7681 .50016 .77928 .49696 .77438 .49075 Metetra
.977 .097 0 r
.77438 .49075 .77928 .49696 .7905 .49365 .78563 .48742 Metetra
.977 .099 0 r
.78563 .48742 .7905 .49365 .80174 .48999 .7969 .48374 Metetra
.974 .11 0 r
.7969 .48374 .80174 .48999 .81294 .48533 .80813 .47905 Metetra
.965 .147 0 r
.80813 .47905 .81294 .48533 .82394 .47814 .81917 .47183 Metetra
.942 .238 0 r
.81917 .47183 .82394 .47814 .83446 .46571 .82974 .45936 Metetra
.893 .415 0 r
.82974 .45936 .83446 .46571 .84409 .44426 .83942 .43785 Metetra
.804 .683 0 r
.83942 .43785 .84409 .44426 .85237 .41027 .84776 .40379 Metetra
.366 .665 0 r
.84776 .40379 .85237 .41027 .85906 .36286 .85453 .35629 Metetra
.076 .569 0 r
.22208 .52486 .22809 .53017 .23286 .57477 .22677 .56952 Metetra
.627 .735 0 r
.22677 .56952 .23286 .57477 .23886 .60795 .23271 .60274 Metetra
.85 .551 0 r
.23271 .60274 .23886 .60795 .24611 .62837 .23993 .62318 Metetra
.919 .322 0 r
.23993 .62318 .24611 .62837 .25432 .6383 .24814 .63312 Metetra
.955 .188 0 r
.24814 .63312 .25432 .6383 .26316 .64139 .25698 .63621 Metetra
.97 .126 0 r
.25698 .63621 .26316 .64139 .27232 .64086 .26616 .63566 Metetra
.976 .103 0 r
.26616 .63566 .27232 .64086 .28164 .63872 .2755 .6335 Metetra
.977 .097 0 r
.2755 .6335 .28164 .63872 .29104 .63598 .28492 .63074 Metetra
.977 .097 0 r
.28492 .63074 .29104 .63598 .30048 .63304 .29438 .62779 Metetra
.977 .099 0 r
.29438 .62779 .30048 .63304 .30996 .63006 .30388 .62478 Metetra
.976 .102 0 r
.30388 .62478 .30996 .63006 .31947 .62705 .31341 .62176 Metetra
.975 .104 0 r
.31341 .62176 .31947 .62705 .32902 .62405 .32298 .61873 Metetra
.975 .106 0 r
.32298 .61873 .32902 .62405 .3386 .62104 .33258 .6157 Metetra
.974 .108 0 r
.33258 .6157 .3386 .62104 .34821 .61803 .34221 .61267 Metetra
.974 .11 0 r
.34221 .61267 .34821 .61803 .35785 .61501 .35188 .60963 Metetra
.974 .112 0 r
.35188 .60963 .35785 .61501 .36753 .61199 .36158 .6066 Metetra
.973 .113 0 r
.36158 .6066 .36753 .61199 .37725 .60896 .37132 .60355 Metetra
.973 .115 0 r
.37132 .60355 .37725 .60896 .387 .60594 .38109 .60051 Metetra
.972 .116 0 r
.38109 .60051 .387 .60594 .39678 .60291 .39089 .59745 Metetra
.972 .118 0 r
.39089 .59745 .39678 .60291 .4066 .59987 .40074 .5944 Metetra
.972 .119 0 r
.40074 .5944 .4066 .59987 .41645 .59683 .41061 .59134 Metetra
.972 .12 0 r
.41061 .59134 .41645 .59683 .42634 .59379 .42052 .58828 Metetra
.971 .121 0 r
.42052 .58828 .42634 .59379 .43627 .59075 .43047 .58521 Metetra
.971 .122 0 r
.43047 .58521 .43627 .59075 .44623 .5877 .44046 .58214 Metetra
.971 .123 0 r
.44046 .58214 .44623 .5877 .45622 .58464 .45048 .57906 Metetra
.971 .123 0 r
.45048 .57906 .45622 .58464 .46626 .58158 .46053 .57599 Metetra
.971 .124 0 r
.46053 .57599 .46626 .58158 .47633 .57852 .47063 .5729 Metetra
.97 .124 0 r
.47063 .5729 .47633 .57852 .48644 .57545 .48076 .56981 Metetra
.97 .125 0 r
.48076 .56981 .48644 .57545 .49658 .57238 .49093 .56672 Metetra
.97 .125 0 r
.49093 .56672 .49658 .57238 .50676 .5693 .50114 .56362 Metetra
.97 .125 0 r
.50114 .56362 .50676 .5693 .51698 .56622 .51138 .56052 Metetra
.97 .125 0 r
.51138 .56052 .51698 .56622 .52724 .56313 .52167 .55741 Metetra
.97 .125 0 r
.52167 .55741 .52724 .56313 .53754 .56004 .53199 .55429 Metetra
.97 .125 0 r
.53199 .55429 .53754 .56004 .54787 .55694 .54235 .55118 Metetra
.97 .125 0 r
.54235 .55118 .54787 .55694 .55825 .55384 .55275 .54805 Metetra
.97 .125 0 r
.55275 .54805 .55825 .55384 .56866 .55074 .56319 .54493 Metetra
.97 .124 0 r
.56319 .54493 .56866 .55074 .57912 .54763 .57367 .54179 Metetra
.971 .124 0 r
.57367 .54179 .57912 .54763 .58961 .54451 .58419 .53865 Metetra
.971 .123 0 r
.58419 .53865 .58961 .54451 .60014 .54139 .59475 .53551 Metetra
.971 .122 0 r
.59475 .53551 .60014 .54139 .61071 .53826 .60535 .53236 Metetra
.971 .121 0 r
.60535 .53236 .61071 .53826 .62133 .53514 .61599 .52922 Metetra
.971 .12 0 r
.61599 .52922 .62133 .53514 .63198 .532 .62667 .52606 Metetra
.972 .119 0 r
.62667 .52606 .63198 .532 .64268 .52886 .6374 .5229 Metetra
.972 .118 0 r
.6374 .5229 .64268 .52886 .65342 .52572 .64816 .51973 Metetra
.972 .117 0 r
.64816 .51973 .65342 .52572 .6642 .52257 .65897 .51655 Metetra
.973 .115 0 r
.65897 .51655 .6642 .52257 .67502 .51941 .66982 .51337 Metetra
.973 .114 0 r
.66982 .51337 .67502 .51941 .68589 .51625 .68071 .51019 Metetra
.973 .112 0 r
.68071 .51019 .68589 .51625 .6968 .51308 .69165 .507 Metetra
.974 .111 0 r
.69165 .507 .6968 .51308 .70775 .50991 .70263 .50381 Metetra
.974 .109 0 r
.70263 .50381 .70775 .50991 .71874 .50674 .71366 .50061 Metetra
.975 .107 0 r
.71366 .50061 .71874 .50674 .72978 .50356 .72472 .49741 Metetra
.975 .105 0 r
.72472 .49741 .72978 .50356 .74086 .50037 .73584 .4942 Metetra
.976 .103 0 r
.73584 .4942 .74086 .50037 .75199 .49718 .74699 .49098 Metetra
.976 .1 0 r
.74699 .49098 .75199 .49718 .76316 .49398 .7582 .48776 Metetra
.977 .098 0 r
.7582 .48776 .76316 .49398 .77438 .49075 .76944 .48451 Metetra
.977 .097 0 r
.76944 .48451 .77438 .49075 .78563 .48742 .78073 .48115 Metetra
.977 .099 0 r
.78073 .48115 .78563 .48742 .7969 .48374 .79203 .47744 Metetra
.974 .11 0 r
.79203 .47744 .7969 .48374 .80813 .47905 .80329 .47272 Metetra
.965 .147 0 r
.80329 .47272 .80813 .47905 .81917 .47183 .81436 .46547 Metetra
.942 .238 0 r
.81436 .46547 .81917 .47183 .82974 .45936 .82498 .45297 Metetra
.893 .415 0 r
.82498 .45297 .82974 .45936 .83942 .43785 .83471 .4314 Metetra
.804 .683 0 r
.83471 .4314 .83942 .43785 .84776 .40379 .84311 .39727 Metetra
.366 .665 0 r
.84311 .39727 .84776 .40379 .85453 .35629 .84996 .34967 Metetra
.076 .569 0 r
.21603 .51953 .22208 .52486 .22677 .56952 .22064 .56424 Metetra
.627 .735 0 r
.22064 .56424 .22677 .56952 .23271 .60274 .22652 .59751 Metetra
.85 .551 0 r
.22652 .59751 .23271 .60274 .23993 .62318 .23371 .61797 Metetra
.919 .321 0 r
.23371 .61797 .23993 .62318 .24814 .63312 .24192 .6279 Metetra
.955 .188 0 r
.24192 .6279 .24814 .63312 .25698 .63621 .25077 .63099 Metetra
.97 .126 0 r
.25077 .63099 .25698 .63621 .26616 .63566 .25996 .63043 Metetra
.976 .103 0 r
.25996 .63043 .26616 .63566 .2755 .6335 .26932 .62825 Metetra
.977 .097 0 r
.26932 .62825 .2755 .6335 .28492 .63074 .27875 .62547 Metetra
.977 .097 0 r
.27875 .62547 .28492 .63074 .29438 .62779 .28824 .62249 Metetra
.977 .099 0 r
.28824 .62249 .29438 .62779 .30388 .62478 .29776 .61947 Metetra
.976 .102 0 r
.29776 .61947 .30388 .62478 .31341 .62176 .30731 .61642 Metetra
.975 .104 0 r
.30731 .61642 .31341 .62176 .32298 .61873 .3169 .61338 Metetra
.975 .106 0 r
.3169 .61338 .32298 .61873 .33258 .6157 .32652 .61033 Metetra
.974 .108 0 r
.32652 .61033 .33258 .6157 .34221 .61267 .33618 .60728 Metetra
.974 .11 0 r
.33618 .60728 .34221 .61267 .35188 .60963 .34587 .60422 Metetra
.974 .112 0 r
.34587 .60422 .35188 .60963 .36158 .6066 .35559 .60116 Metetra
.973 .113 0 r
.35559 .60116 .36158 .6066 .37132 .60355 .36535 .5981 Metetra
.973 .115 0 r
.36535 .5981 .37132 .60355 .38109 .60051 .37514 .59503 Metetra
.972 .116 0 r
.37514 .59503 .38109 .60051 .39089 .59745 .38497 .59196 Metetra
.972 .117 0 r
.38497 .59196 .39089 .59745 .40074 .5944 .39483 .58889 Metetra
.972 .119 0 r
.39483 .58889 .40074 .5944 .41061 .59134 .40473 .58581 Metetra
.972 .12 0 r
.40473 .58581 .41061 .59134 .42052 .58828 .41467 .58273 Metetra
.971 .121 0 r
.41467 .58273 .42052 .58828 .43047 .58521 .42464 .57964 Metetra
.971 .122 0 r
.42464 .57964 .43047 .58521 .44046 .58214 .43465 .57655 Metetra
.971 .123 0 r
.43465 .57655 .44046 .58214 .45048 .57906 .44469 .57345 Metetra
.971 .123 0 r
.44469 .57345 .45048 .57906 .46053 .57599 .45477 .57035 Metetra
.971 .124 0 r
.45477 .57035 .46053 .57599 .47063 .5729 .46489 .56724 Metetra
.97 .124 0 r
.46489 .56724 .47063 .5729 .48076 .56981 .47505 .56413 Metetra
.97 .125 0 r
.47505 .56413 .48076 .56981 .49093 .56672 .48524 .56102 Metetra
.97 .125 0 r
.48524 .56102 .49093 .56672 .50114 .56362 .49547 .5579 Metetra
.97 .125 0 r
.49547 .5579 .50114 .56362 .51138 .56052 .50574 .55477 Metetra
.97 .125 0 r
.50574 .55477 .51138 .56052 .52167 .55741 .51605 .55164 Metetra
.97 .125 0 r
.51605 .55164 .52167 .55741 .53199 .55429 .5264 .54851 Metetra
.97 .125 0 r
.5264 .54851 .53199 .55429 .54235 .55118 .53678 .54537 Metetra
.97 .125 0 r
.53678 .54537 .54235 .55118 .55275 .54805 .54721 .54223 Metetra
.97 .125 0 r
.54721 .54223 .55275 .54805 .56319 .54493 .55768 .53907 Metetra
.97 .124 0 r
.55768 .53907 .56319 .54493 .57367 .54179 .56818 .53592 Metetra
.971 .124 0 r
.56818 .53592 .57367 .54179 .58419 .53865 .57873 .53276 Metetra
.971 .123 0 r
.57873 .53276 .58419 .53865 .59475 .53551 .58931 .52959 Metetra
.971 .122 0 r
.58931 .52959 .59475 .53551 .60535 .53236 .59994 .52642 Metetra
.971 .121 0 r
.59994 .52642 .60535 .53236 .61599 .52922 .61061 .52325 Metetra
.971 .12 0 r
.61061 .52325 .61599 .52922 .62667 .52606 .62132 .52007 Metetra
.972 .119 0 r
.62132 .52007 .62667 .52606 .6374 .5229 .63207 .51689 Metetra
.972 .118 0 r
.63207 .51689 .6374 .5229 .64816 .51973 .64287 .5137 Metetra
.972 .117 0 r
.64287 .5137 .64816 .51973 .65897 .51655 .6537 .5105 Metetra
.973 .115 0 r
.6537 .5105 .65897 .51655 .66982 .51337 .66458 .5073 Metetra
.973 .114 0 r
.66458 .5073 .66982 .51337 .68071 .51019 .6755 .50409 Metetra
.973 .112 0 r
.6755 .50409 .68071 .51019 .69165 .507 .68647 .50088 Metetra
.974 .111 0 r
.68647 .50088 .69165 .507 .70263 .50381 .69748 .49766 Metetra
.974 .109 0 r
.69748 .49766 .70263 .50381 .71366 .50061 .70853 .49444 Metetra
.975 .107 0 r
.70853 .49444 .71366 .50061 .72472 .49741 .71963 .49121 Metetra
.975 .105 0 r
.71963 .49121 .72472 .49741 .73584 .4942 .73077 .48798 Metetra
.976 .103 0 r
.73077 .48798 .73584 .4942 .74699 .49098 .74196 .48474 Metetra
.976 .1 0 r
.74196 .48474 .74699 .49098 .7582 .48776 .75319 .48149 Metetra
.977 .098 0 r
.75319 .48149 .7582 .48776 .76944 .48451 .76447 .47821 Metetra
.977 .097 0 r
.76447 .47821 .76944 .48451 .78073 .48115 .77579 .47483 Metetra
.977 .099 0 r
.77579 .47483 .78073 .48115 .79203 .47744 .78712 .4711 Metetra
.974 .11 0 r
.78712 .4711 .79203 .47744 .80329 .47272 .79841 .46635 Metetra
.965 .147 0 r
.79841 .46635 .80329 .47272 .81436 .46547 .80953 .45907 Metetra
.942 .238 0 r
.80953 .45907 .81436 .46547 .82498 .45297 .82018 .44653 Metetra
.893 .415 0 r
.82018 .44653 .82498 .45297 .83471 .4314 .82996 .42491 Metetra
.804 .683 0 r
.82996 .42491 .83471 .4314 .84311 .39727 .83843 .3907 Metetra
.366 .665 0 r
.83843 .3907 .84311 .39727 .84996 .34967 .84536 .34301 Metetra
.077 .569 0 r
.20994 .51416 .21603 .51953 .22064 .56424 .21447 .55893 Metetra
.627 .735 0 r
.21447 .55893 .22064 .56424 .22652 .59751 .2203 .59224 Metetra
.85 .551 0 r
.2203 .59224 .22652 .59751 .23371 .61797 .22746 .61272 Metetra
.919 .321 0 r
.22746 .61272 .23371 .61797 .24192 .6279 .23565 .62266 Metetra
.955 .188 0 r
.23565 .62266 .24192 .6279 .25077 .63099 .24451 .62573 Metetra
.97 .126 0 r
.24451 .62573 .25077 .63099 .25996 .63043 .25372 .62516 Metetra
.976 .103 0 r
.25372 .62516 .25996 .63043 .26932 .62825 .26309 .62296 Metetra
.977 .097 0 r
.26309 .62296 .26932 .62825 .27875 .62547 .27255 .62016 Metetra
.977 .097 0 r
.27255 .62016 .27875 .62547 .28824 .62249 .28205 .61717 Metetra
.977 .099 0 r
.28205 .61717 .28824 .62249 .29776 .61947 .2916 .61413 Metetra
.976 .101 0 r
.2916 .61413 .29776 .61947 .30731 .61642 .30117 .61106 Metetra
.975 .104 0 r
.30117 .61106 .30731 .61642 .3169 .61338 .31078 .608 Metetra
.975 .106 0 r
.31078 .608 .3169 .61338 .32652 .61033 .32042 .60492 Metetra
.974 .108 0 r
.32042 .60492 .32652 .61033 .33618 .60728 .3301 .60186 Metetra
.974 .11 0 r
.3301 .60186 .33618 .60728 .34587 .60422 .33981 .59878 Metetra
.974 .111 0 r
.33981 .59878 .34587 .60422 .35559 .60116 .34956 .5957 Metetra
.973 .113 0 r
.34956 .5957 .35559 .60116 .36535 .5981 .35934 .59261 Metetra
.973 .115 0 r
.35934 .59261 .36535 .5981 .37514 .59503 .36915 .58953 Metetra
.972 .116 0 r
.36915 .58953 .37514 .59503 .38497 .59196 .379 .58644 Metetra
.972 .117 0 r
.379 .58644 .38497 .59196 .39483 .58889 .38889 .58334 Metetra
.972 .119 0 r
.38889 .58334 .39483 .58889 .40473 .58581 .39881 .58024 Metetra
.972 .12 0 r
.39881 .58024 .40473 .58581 .41467 .58273 .40877 .57714 Metetra
.971 .121 0 r
.40877 .57714 .41467 .58273 .42464 .57964 .41877 .57403 Metetra
.971 .122 0 r
.41877 .57403 .42464 .57964 .43465 .57655 .4288 .57092 Metetra
.971 .122 0 r
.4288 .57092 .43465 .57655 .44469 .57345 .43887 .5678 Metetra
.971 .123 0 r
.43887 .5678 .44469 .57345 .45477 .57035 .44897 .56468 Metetra
.971 .124 0 r
.44897 .56468 .45477 .57035 .46489 .56724 .45911 .56155 Metetra
.97 .124 0 r
.45911 .56155 .46489 .56724 .47505 .56413 .46929 .55842 Metetra
.97 .125 0 r
.46929 .55842 .47505 .56413 .48524 .56102 .47951 .55528 Metetra
.97 .125 0 r
.47951 .55528 .48524 .56102 .49547 .5579 .48977 .55214 Metetra
.97 .125 0 r
.48977 .55214 .49547 .5579 .50574 .55477 .50006 .54899 Metetra
.97 .125 0 r
.50006 .54899 .50574 .55477 .51605 .55164 .5104 .54584 Metetra
.97 .125 0 r
.5104 .54584 .51605 .55164 .5264 .54851 .52077 .54269 Metetra
.97 .125 0 r
.52077 .54269 .5264 .54851 .53678 .54537 .53118 .53952 Metetra
.97 .125 0 r
.53118 .53952 .53678 .54537 .54721 .54223 .54163 .53636 Metetra
.97 .124 0 r
.54163 .53636 .54721 .54223 .55768 .53907 .55213 .53318 Metetra
.971 .124 0 r
.55213 .53318 .55768 .53907 .56818 .53592 .56266 .53001 Metetra
.971 .124 0 r
.56266 .53001 .56818 .53592 .57873 .53276 .57323 .52682 Metetra
.971 .123 0 r
.57323 .52682 .57873 .53276 .58931 .52959 .58384 .52364 Metetra
.971 .122 0 r
.58384 .52364 .58931 .52959 .59994 .52642 .5945 .52044 Metetra
.971 .121 0 r
.5945 .52044 .59994 .52642 .61061 .52325 .60519 .51725 Metetra
.971 .12 0 r
.60519 .51725 .61061 .52325 .62132 .52007 .61593 .51405 Metetra
.972 .119 0 r
.61593 .51405 .62132 .52007 .63207 .51689 .62671 .51084 Metetra
.972 .118 0 r
.62671 .51084 .63207 .51689 .64287 .5137 .63753 .50762 Metetra
.972 .117 0 r
.63753 .50762 .64287 .5137 .6537 .5105 .6484 .5044 Metetra
.973 .115 0 r
.6484 .5044 .6537 .5105 .66458 .5073 .65931 .50118 Metetra
.973 .114 0 r
.65931 .50118 .66458 .5073 .6755 .50409 .67026 .49795 Metetra
.973 .112 0 r
.67026 .49795 .6755 .50409 .68647 .50088 .68125 .49471 Metetra
.974 .111 0 r
.68125 .49471 .68647 .50088 .69748 .49766 .69229 .49147 Metetra
.974 .109 0 r
.69229 .49147 .69748 .49766 .70853 .49444 .70337 .48822 Metetra
.975 .107 0 r
.70337 .48822 .70853 .49444 .71963 .49121 .7145 .48497 Metetra
.975 .105 0 r
.7145 .48497 .71963 .49121 .73077 .48798 .72567 .48172 Metetra
.976 .103 0 r
.72567 .48172 .73077 .48798 .74196 .48474 .73689 .47845 Metetra
.976 .1 0 r
.73689 .47845 .74196 .48474 .75319 .48149 .74816 .47518 Metetra
.977 .098 0 r
.74816 .47518 .75319 .48149 .76447 .47821 .75946 .47188 Metetra
.977 .097 0 r
.75946 .47188 .76447 .47821 .77579 .47483 .77081 .46847 Metetra
.977 .099 0 r
.77081 .46847 .77579 .47483 .78712 .4711 .78218 .46472 Metetra
.974 .11 0 r
.78218 .46472 .78712 .4711 .79841 .46635 .7935 .45994 Metetra
.965 .147 0 r
.7935 .45994 .79841 .46635 .80953 .45907 .80465 .45263 Metetra
.942 .238 0 r
.80465 .45263 .80953 .45907 .82018 .44653 .81535 .44004 Metetra
.893 .414 0 r
.81535 .44004 .82018 .44653 .82996 .42491 .82519 .41837 Metetra
.804 .683 0 r
.82519 .41837 .82996 .42491 .83843 .3907 .83372 .38408 Metetra
.366 .666 0 r
.83372 .38408 .83843 .3907 .84536 .34301 .84073 .33631 Metetra
.077 .57 0 r
.20382 .50876 .20994 .51416 .21447 .55893 .20826 .55359 Metetra
.627 .735 0 r
.20826 .55359 .21447 .55893 .2203 .59224 .21403 .58694 Metetra
.851 .551 0 r
.21403 .58694 .2203 .59224 .22746 .61272 .22116 .60744 Metetra
.919 .321 0 r
.22116 .60744 .22746 .61272 .23565 .62266 .22935 .61738 Metetra
.955 .187 0 r
.22935 .61738 .23565 .62266 .24451 .62573 .23821 .62044 Metetra
.97 .126 0 r
.23821 .62044 .24451 .62573 .25372 .62516 .24743 .61985 Metetra
.976 .103 0 r
.24743 .61985 .25372 .62516 .26309 .62296 .25683 .61764 Metetra
.977 .097 0 r
.25683 .61764 .26309 .62296 .27255 .62016 .26631 .61482 Metetra
.977 .097 0 r
.26631 .61482 .27255 .62016 .28205 .61717 .27583 .61181 Metetra
.977 .099 0 r
.27583 .61181 .28205 .61717 .2916 .61413 .28539 .60874 Metetra
.976 .101 0 r
.28539 .60874 .2916 .61413 .30117 .61106 .29499 .60566 Metetra
.975 .104 0 r
.29499 .60566 .30117 .61106 .31078 .608 .30462 .60258 Metetra
.975 .106 0 r
.30462 .60258 .31078 .608 .32042 .60492 .31428 .59948 Metetra
.974 .108 0 r
.31428 .59948 .32042 .60492 .3301 .60186 .32398 .59639 Metetra
.974 .11 0 r
.32398 .59639 .3301 .60186 .33981 .59878 .33372 .59329 Metetra
.974 .111 0 r
.33372 .59329 .33981 .59878 .34956 .5957 .34348 .5902 Metetra
.973 .113 0 r
.34348 .5902 .34956 .5957 .35934 .59261 .35329 .58709 Metetra
.973 .115 0 r
.35329 .58709 .35934 .59261 .36915 .58953 .36313 .58399 Metetra
.972 .116 0 r
.36313 .58399 .36915 .58953 .379 .58644 .373 .58087 Metetra
.972 .117 0 r
.373 .58087 .379 .58644 .38889 .58334 .38291 .57776 Metetra
.972 .119 0 r
.38291 .57776 .38889 .58334 .39881 .58024 .39285 .57464 Metetra
.972 .12 0 r
.39285 .57464 .39881 .58024 .40877 .57714 .40283 .57151 Metetra
.971 .121 0 r
.40283 .57151 .40877 .57714 .41877 .57403 .41285 .56838 Metetra
.971 .122 0 r
.41285 .56838 .41877 .57403 .4288 .57092 .42291 .56525 Metetra
.971 .122 0 r
.42291 .56525 .4288 .57092 .43887 .5678 .433 .56211 Metetra
.971 .123 0 r
.433 .56211 .43887 .5678 .44897 .56468 .44313 .55897 Metetra
.971 .124 0 r
.44313 .55897 .44897 .56468 .45911 .56155 .4533 .55582 Metetra
.97 .124 0 r
.4533 .55582 .45911 .56155 .46929 .55842 .4635 .55266 Metetra
.97 .125 0 r
.4635 .55266 .46929 .55842 .47951 .55528 .47374 .5495 Metetra
.97 .125 0 r
.47374 .5495 .47951 .55528 .48977 .55214 .48402 .54634 Metetra
.97 .125 0 r
.48402 .54634 .48977 .55214 .50006 .54899 .49435 .54317 Metetra
.97 .125 0 r
.49435 .54317 .50006 .54899 .5104 .54584 .5047 .54 Metetra
.97 .125 0 r
.5047 .54 .5104 .54584 .52077 .54269 .5151 .53682 Metetra
.97 .125 0 r
.5151 .53682 .52077 .54269 .53118 .53952 .52554 .53364 Metetra
.97 .125 0 r
.52554 .53364 .53118 .53952 .54163 .53636 .53602 .53045 Metetra
.97 .124 0 r
.53602 .53045 .54163 .53636 .55213 .53318 .54654 .52725 Metetra
.971 .124 0 r
.54654 .52725 .55213 .53318 .56266 .53001 .55709 .52405 Metetra
.971 .123 0 r
.55709 .52405 .56266 .53001 .57323 .52682 .56769 .52085 Metetra
.971 .123 0 r
.56769 .52085 .57323 .52682 .58384 .52364 .57833 .51764 Metetra
.971 .122 0 r
.57833 .51764 .58384 .52364 .5945 .52044 .58902 .51442 Metetra
.971 .121 0 r
.58902 .51442 .5945 .52044 .60519 .51725 .59974 .51121 Metetra
.971 .12 0 r
.59974 .51121 .60519 .51725 .61593 .51405 .6105 .50798 Metetra
.972 .119 0 r
.6105 .50798 .61593 .51405 .62671 .51084 .62131 .50475 Metetra
.972 .118 0 r
.62131 .50475 .62671 .51084 .63753 .50762 .63216 .50151 Metetra
.972 .117 0 r
.63216 .50151 .63753 .50762 .6484 .5044 .64305 .49826 Metetra
.973 .115 0 r
.64305 .49826 .6484 .5044 .65931 .50118 .65399 .49502 Metetra
.973 .114 0 r
.65399 .49502 .65931 .50118 .67026 .49795 .66497 .49176 Metetra
.973 .112 0 r
.66497 .49176 .67026 .49795 .68125 .49471 .676 .4885 Metetra
.974 .111 0 r
.676 .4885 .68125 .49471 .69229 .49147 .68706 .48524 Metetra
.974 .109 0 r
.68706 .48524 .69229 .49147 .70337 .48822 .69818 .48197 Metetra
.975 .107 0 r
.69818 .48197 .70337 .48822 .7145 .48497 .70933 .47869 Metetra
.975 .105 0 r
.70933 .47869 .7145 .48497 .72567 .48172 .72054 .47541 Metetra
.976 .103 0 r
.72054 .47541 .72567 .48172 .73689 .47845 .73179 .47212 Metetra
.976 .1 0 r
.73179 .47212 .73689 .47845 .74816 .47518 .74308 .46883 Metetra
.977 .098 0 r
.74308 .46883 .74816 .47518 .75946 .47188 .75442 .4655 Metetra
.977 .097 0 r
.75442 .4655 .75946 .47188 .77081 .46847 .7658 .46207 Metetra
.977 .099 0 r
.7658 .46207 .77081 .46847 .78218 .46472 .7772 .45828 Metetra
.974 .11 0 r
.7772 .45828 .78218 .46472 .7935 .45994 .78856 .45348 Metetra
.965 .147 0 r
.78856 .45348 .7935 .45994 .80465 .45263 .79974 .44614 Metetra
.942 .238 0 r
.79974 .44614 .80465 .45263 .81535 .44004 .81048 .43351 Metetra
.893 .414 0 r
.81048 .43351 .81535 .44004 .82519 .41837 .82037 .41178 Metetra
.804 .682 0 r
.82037 .41178 .82519 .41837 .83372 .38408 .82898 .37743 Metetra
.367 .666 0 r
.82898 .37743 .83372 .38408 .84073 .33631 .83607 .32956 Metetra
.077 .57 0 r
.19765 .50333 .20382 .50876 .20826 .55359 .20201 .54822 Metetra
.628 .735 0 r
.20201 .54822 .20826 .55359 .21403 .58694 .20772 .5816 Metetra
.851 .551 0 r
.20772 .5816 .21403 .58694 .22116 .60744 .21482 .60212 Metetra
.919 .321 0 r
.21482 .60212 .22116 .60744 .22935 .61738 .223 .61207 Metetra
.955 .187 0 r
.223 .61207 .22935 .61738 .23821 .62044 .23187 .61512 Metetra
.97 .126 0 r
.23187 .61512 .23821 .62044 .24743 .61985 .24111 .61452 Metetra
.976 .103 0 r
.24111 .61452 .24743 .61985 .25683 .61764 .25052 .61228 Metetra
.977 .097 0 r
.25052 .61228 .25683 .61764 .26631 .61482 .26002 .60945 Metetra
.977 .097 0 r
.26002 .60945 .26631 .61482 .27583 .61181 .26956 .60641 Metetra
.977 .099 0 r
.26956 .60641 .27583 .61181 .28539 .60874 .27915 .60333 Metetra
.976 .101 0 r
.27915 .60333 .28539 .60874 .29499 .60566 .28877 .60022 Metetra
.976 .104 0 r
.28877 .60022 .29499 .60566 .30462 .60258 .29842 .59712 Metetra
.975 .106 0 r
.29842 .59712 .30462 .60258 .31428 .59948 .3081 .59401 Metetra
.974 .108 0 r
.3081 .59401 .31428 .59948 .32398 .59639 .31782 .5909 Metetra
.974 .11 0 r
.31782 .5909 .32398 .59639 .33372 .59329 .32758 .58778 Metetra
.974 .111 0 r
.32758 .58778 .33372 .59329 .34348 .5902 .33737 .58466 Metetra
.973 .113 0 r
.33737 .58466 .34348 .5902 .35329 .58709 .34719 .58153 Metetra
.973 .115 0 r
.34719 .58153 .35329 .58709 .36313 .58399 .35706 .57841 Metetra
.972 .116 0 r
.35706 .57841 .36313 .58399 .373 .58087 .36695 .57527 Metetra
.972 .117 0 r
.36695 .57527 .373 .58087 .38291 .57776 .37688 .57214 Metetra
.972 .119 0 r
.37688 .57214 .38291 .57776 .39285 .57464 .38685 .56899 Metetra
.972 .12 0 r
.38685 .56899 .39285 .57464 .40283 .57151 .39686 .56585 Metetra
.971 .121 0 r
.39686 .56585 .40283 .57151 .41285 .56838 .4069 .5627 Metetra
.971 .122 0 r
.4069 .5627 .41285 .56838 .42291 .56525 .41698 .55954 Metetra
.971 .122 0 r
.41698 .55954 .42291 .56525 .433 .56211 .42709 .55638 Metetra
.971 .123 0 r
.42709 .55638 .433 .56211 .44313 .55897 .43725 .55322 Metetra
.971 .124 0 r
.43725 .55322 .44313 .55897 .4533 .55582 .44744 .55005 Metetra
.97 .124 0 r
.44744 .55005 .4533 .55582 .4635 .55266 .45767 .54687 Metetra
.97 .124 0 r
.45767 .54687 .4635 .55266 .47374 .5495 .46793 .54369 Metetra
.97 .125 0 r
.46793 .54369 .47374 .5495 .48402 .54634 .47824 .54051 Metetra
.97 .125 0 r
.47824 .54051 .48402 .54634 .49435 .54317 .48859 .53731 Metetra
.97 .125 0 r
.48859 .53731 .49435 .54317 .5047 .54 .49897 .53412 Metetra
.97 .125 0 r
.49897 .53412 .5047 .54 .5151 .53682 .50939 .53092 Metetra
.97 .125 0 r
.50939 .53092 .5151 .53682 .52554 .53364 .51986 .52771 Metetra
.97 .125 0 r
.51986 .52771 .52554 .53364 .53602 .53045 .53036 .5245 Metetra
.97 .124 0 r
.53036 .5245 .53602 .53045 .54654 .52725 .54091 .52128 Metetra
.971 .124 0 r
.54091 .52128 .54654 .52725 .55709 .52405 .55149 .51806 Metetra
.971 .123 0 r
.55149 .51806 .55709 .52405 .56769 .52085 .56212 .51483 Metetra
.971 .123 0 r
.56212 .51483 .56769 .52085 .57833 .51764 .57279 .5116 Metetra
.971 .122 0 r
.57279 .5116 .57833 .51764 .58902 .51442 .58349 .50836 Metetra
.971 .121 0 r
.58349 .50836 .58902 .51442 .59974 .51121 .59424 .50512 Metetra
.971 .12 0 r
.59424 .50512 .59974 .51121 .6105 .50798 .60504 .50187 Metetra
.972 .119 0 r
.60504 .50187 .6105 .50798 .62131 .50475 .61587 .49861 Metetra
.972 .118 0 r
.61587 .49861 .62131 .50475 .63216 .50151 .62675 .49535 Metetra
.972 .117 0 r
.62675 .49535 .63216 .50151 .64305 .49826 .63767 .49208 Metetra
.973 .115 0 r
.63767 .49208 .64305 .49826 .65399 .49502 .64864 .48881 Metetra
.973 .114 0 r
.64864 .48881 .65399 .49502 .66497 .49176 .65965 .48553 Metetra
.973 .112 0 r
.65965 .48553 .66497 .49176 .676 .4885 .6707 .48225 Metetra
.974 .11 0 r
.6707 .48225 .676 .4885 .68706 .48524 .6818 .47896 Metetra
.974 .109 0 r
.6818 .47896 .68706 .48524 .69818 .48197 .69294 .47566 Metetra
.975 .107 0 r
.69294 .47566 .69818 .48197 .70933 .47869 .70413 .47236 Metetra
.975 .105 0 r
.70413 .47236 .70933 .47869 .72054 .47541 .71536 .46906 Metetra
.976 .102 0 r
.71536 .46906 .72054 .47541 .73179 .47212 .72664 .46575 Metetra
.976 .1 0 r
.72664 .46575 .73179 .47212 .74308 .46883 .73797 .46243 Metetra
.977 .098 0 r
.73797 .46243 .74308 .46883 .75442 .4655 .74934 .45907 Metetra
.977 .097 0 r
.74934 .45907 .75442 .4655 .7658 .46207 .76075 .45562 Metetra
.977 .098 0 r
.76075 .45562 .7658 .46207 .7772 .45828 .77218 .45181 Metetra
.974 .11 0 r
.77218 .45181 .7772 .45828 .78856 .45348 .78357 .44698 Metetra
.965 .147 0 r
.78357 .44698 .78856 .45348 .79974 .44614 .7948 .4396 Metetra
.942 .237 0 r
.7948 .4396 .79974 .44614 .81048 .43351 .80558 .42693 Metetra
.893 .414 0 r
.80558 .42693 .81048 .43351 .82037 .41178 .81552 .40515 Metetra
.804 .682 0 r
.81552 .40515 .82037 .41178 .82898 .37743 .8242 .37072 Metetra
.367 .666 0 r
.8242 .37072 .82898 .37743 .83607 .32956 .83137 .32276 Metetra
.077 .57 0 r
.19145 .49786 .19765 .50333 .20201 .54822 .19572 .54281 Metetra
.628 .735 0 r
.19572 .54281 .20201 .54822 .20772 .5816 .20137 .57624 Metetra
.851 .551 0 r
.20137 .57624 .20772 .5816 .21482 .60212 .20843 .59678 Metetra
.919 .321 0 r
.20843 .59678 .21482 .60212 .223 .61207 .21661 .60672 Metetra
.955 .187 0 r
.21661 .60672 .223 .61207 .23187 .61512 .22549 .60977 Metetra
.97 .125 0 r
.22549 .60977 .23187 .61512 .24111 .61452 .23474 .60914 Metetra
.976 .103 0 r
.23474 .60914 .24111 .61452 .25052 .61228 .24417 .60689 Metetra
.977 .097 0 r
.24417 .60689 .25052 .61228 .26002 .60945 .25369 .60404 Metetra
.977 .097 0 r
.25369 .60404 .26002 .60945 .26956 .60641 .26326 .60098 Metetra
.977 .099 0 r
.26326 .60098 .26956 .60641 .27915 .60333 .27286 .59788 Metetra
.976 .101 0 r
.27286 .59788 .27915 .60333 .28877 .60022 .2825 .59475 Metetra
.976 .103 0 r
.2825 .59475 .28877 .60022 .29842 .59712 .29217 .59163 Metetra
.975 .106 0 r
.29217 .59163 .29842 .59712 .3081 .59401 .30188 .58849 Metetra
.975 .108 0 r
.30188 .58849 .3081 .59401 .31782 .5909 .31162 .58536 Metetra
.974 .109 0 r
.31162 .58536 .31782 .5909 .32758 .58778 .3214 .58222 Metetra
.974 .111 0 r
.3214 .58222 .32758 .58778 .33737 .58466 .33121 .57908 Metetra
.973 .113 0 r
.33121 .57908 .33737 .58466 .34719 .58153 .34106 .57594 Metetra
.973 .114 0 r
.34106 .57594 .34719 .58153 .35706 .57841 .35094 .57279 Metetra
.972 .116 0 r
.35094 .57279 .35706 .57841 .36695 .57527 .36086 .56963 Metetra
.972 .117 0 r
.36086 .56963 .36695 .57527 .37688 .57214 .37082 .56648 Metetra
.972 .118 0 r
.37082 .56648 .37688 .57214 .38685 .56899 .38081 .56331 Metetra
.972 .12 0 r
.38081 .56331 .38685 .56899 .39686 .56585 .39084 .56015 Metetra
.971 .121 0 r
.39084 .56015 .39686 .56585 .4069 .5627 .4009 .55697 Metetra
.971 .121 0 r
.4009 .55697 .4069 .5627 .41698 .55954 .41101 .5538 Metetra
.971 .122 0 r
.41101 .5538 .41698 .55954 .42709 .55638 .42115 .55061 Metetra
.971 .123 0 r
.42115 .55061 .42709 .55638 .43725 .55322 .43132 .54743 Metetra
.971 .124 0 r
.43132 .54743 .43725 .55322 .44744 .55005 .44154 .54423 Metetra
.971 .124 0 r
.44154 .54423 .44744 .55005 .45767 .54687 .45179 .54104 Metetra
.97 .124 0 r
.45179 .54104 .45767 .54687 .46793 .54369 .46209 .53783 Metetra
.97 .125 0 r
.46209 .53783 .46793 .54369 .47824 .54051 .47242 .53463 Metetra
.97 .125 0 r
.47242 .53463 .47824 .54051 .48859 .53731 .48279 .53141 Metetra
.97 .125 0 r
.48279 .53141 .48859 .53731 .49897 .53412 .4932 .52819 Metetra
.97 .125 0 r
.4932 .52819 .49897 .53412 .50939 .53092 .50365 .52497 Metetra
.97 .125 0 r
.50365 .52497 .50939 .53092 .51986 .52771 .51414 .52174 Metetra
.97 .125 0 r
.51414 .52174 .51986 .52771 .53036 .5245 .52467 .51851 Metetra
.97 .124 0 r
.52467 .51851 .53036 .5245 .54091 .52128 .53524 .51527 Metetra
.971 .124 0 r
.53524 .51527 .54091 .52128 .55149 .51806 .54585 .51202 Metetra
.971 .123 0 r
.54585 .51202 .55149 .51806 .56212 .51483 .5565 .50877 Metetra
.971 .123 0 r
.5565 .50877 .56212 .51483 .57279 .5116 .5672 .50551 Metetra
.971 .122 0 r
.5672 .50551 .57279 .5116 .58349 .50836 .57793 .50225 Metetra
.971 .121 0 r
.57793 .50225 .58349 .50836 .59424 .50512 .58871 .49899 Metetra
.971 .12 0 r
.58871 .49899 .59424 .50512 .60504 .50187 .59953 .49571 Metetra
.972 .119 0 r
.59953 .49571 .60504 .50187 .61587 .49861 .6104 .49243 Metetra
.972 .118 0 r
.6104 .49243 .61587 .49861 .62675 .49535 .6213 .48915 Metetra
.972 .117 0 r
.6213 .48915 .62675 .49535 .63767 .49208 .63225 .48586 Metetra
.973 .115 0 r
.63225 .48586 .63767 .49208 .64864 .48881 .64325 .48256 Metetra
.973 .114 0 r
.64325 .48256 .64864 .48881 .65965 .48553 .65429 .47926 Metetra
.973 .112 0 r
.65429 .47926 .65965 .48553 .6707 .48225 .66537 .47595 Metetra
.974 .11 0 r
.66537 .47595 .6707 .48225 .6818 .47896 .6765 .47264 Metetra
.974 .109 0 r
.6765 .47264 .6818 .47896 .69294 .47566 .68767 .46932 Metetra
.975 .107 0 r
.68767 .46932 .69294 .47566 .70413 .47236 .69889 .46599 Metetra
.975 .105 0 r
.69889 .46599 .70413 .47236 .71536 .46906 .71015 .46266 Metetra
.976 .102 0 r
.71015 .46266 .71536 .46906 .72664 .46575 .72146 .45932 Metetra
.976 .1 0 r
.72146 .45932 .72664 .46575 .73797 .46243 .73282 .45598 Metetra
.977 .098 0 r
.73282 .45598 .73797 .46243 .74934 .45907 .74422 .4526 Metetra
.977 .097 0 r
.74422 .4526 .74934 .45907 .76075 .45562 .75566 .44912 Metetra
.977 .098 0 r
.75566 .44912 .76075 .45562 .77218 .45181 .76712 .44528 Metetra
.974 .11 0 r
.76712 .44528 .77218 .45181 .78357 .44698 .77855 .44042 Metetra
.965 .147 0 r
.77855 .44042 .78357 .44698 .7948 .4396 .78981 .43302 Metetra
.942 .237 0 r
.78981 .43302 .7948 .4396 .80558 .42693 .80064 .42031 Metetra
.893 .414 0 r
.80064 .42031 .80558 .42693 .81552 .40515 .81064 .39847 Metetra
.804 .682 0 r
.81064 .39847 .81552 .40515 .8242 .37072 .81938 .36397 Metetra
.367 .666 0 r
.81938 .36397 .8242 .37072 .83137 .32276 .82664 .31592 Metetra
.077 .57 0 r
.1852 .49237 .19145 .49786 .19572 .54281 .18939 .53737 Metetra
.628 .736 0 r
.18939 .53737 .19572 .54281 .20137 .57624 .19497 .57084 Metetra
.851 .551 0 r
.19497 .57084 .20137 .57624 .20843 .59678 .20201 .5914 Metetra
.919 .321 0 r
.20201 .5914 .20843 .59678 .21661 .60672 .21017 .60135 Metetra
.955 .187 0 r
.21017 .60135 .21661 .60672 .22549 .60977 .21906 .60438 Metetra
.97 .125 0 r
.21906 .60438 .22549 .60977 .23474 .60914 .22833 .60374 Metetra
.976 .103 0 r
.22833 .60374 .23474 .60914 .24417 .60689 .23778 .60147 Metetra
.977 .097 0 r
.23778 .60147 .24417 .60689 .25369 .60404 .24732 .59859 Metetra
.977 .097 0 r
.24732 .59859 .25369 .60404 .26326 .60098 .2569 .59552 Metetra
.977 .099 0 r
.2569 .59552 .26326 .60098 .27286 .59788 .26653 .59239 Metetra
.976 .101 0 r
.26653 .59239 .27286 .59788 .2825 .59475 .27619 .58925 Metetra
.976 .103 0 r
.27619 .58925 .2825 .59475 .29217 .59163 .28589 .5861 Metetra
.975 .105 0 r
.28589 .5861 .29217 .59163 .30188 .58849 .29562 .58295 Metetra
.975 .107 0 r
.29562 .58295 .30188 .58849 .31162 .58536 .30538 .5798 Metetra
.974 .109 0 r
.30538 .5798 .31162 .58536 .3214 .58222 .31518 .57663 Metetra
.974 .111 0 r
.31518 .57663 .3214 .58222 .33121 .57908 .32501 .57347 Metetra
.973 .113 0 r
.32501 .57347 .33121 .57908 .34106 .57594 .33488 .5703 Metetra
.973 .114 0 r
.33488 .5703 .34106 .57594 .35094 .57279 .34479 .56714 Metetra
.973 .116 0 r
.34479 .56714 .35094 .57279 .36086 .56963 .35473 .56396 Metetra
.972 .117 0 r
.35473 .56396 .36086 .56963 .37082 .56648 .36471 .56078 Metetra
.972 .118 0 r
.36471 .56078 .37082 .56648 .38081 .56331 .37473 .55759 Metetra
.972 .119 0 r
.37473 .55759 .38081 .56331 .39084 .56015 .38478 .55441 Metetra
.971 .12 0 r
.38478 .55441 .39084 .56015 .4009 .55697 .39487 .55121 Metetra
.971 .121 0 r
.39487 .55121 .4009 .55697 .41101 .5538 .40499 .54801 Metetra
.971 .122 0 r
.40499 .54801 .41101 .5538 .42115 .55061 .41516 .54481 Metetra
.971 .123 0 r
.41516 .54481 .42115 .55061 .43132 .54743 .42536 .5416 Metetra
.971 .123 0 r
.42536 .5416 .43132 .54743 .44154 .54423 .4356 .53838 Metetra
.971 .124 0 r
.4356 .53838 .44154 .54423 .45179 .54104 .44588 .53517 Metetra
.97 .124 0 r
.44588 .53517 .45179 .54104 .46209 .53783 .45619 .53194 Metetra
.97 .125 0 r
.45619 .53194 .46209 .53783 .47242 .53463 .46655 .52871 Metetra
.97 .125 0 r
.46655 .52871 .47242 .53463 .48279 .53141 .47695 .52547 Metetra
.97 .125 0 r
.47695 .52547 .48279 .53141 .4932 .52819 .48738 .52223 Metetra
.97 .125 0 r
.48738 .52223 .4932 .52819 .50365 .52497 .49786 .51899 Metetra
.97 .125 0 r
.49786 .51899 .50365 .52497 .51414 .52174 .50837 .51573 Metetra
.97 .124 0 r
.50837 .51573 .51414 .52174 .52467 .51851 .51893 .51248 Metetra
.97 .124 0 r
.51893 .51248 .52467 .51851 .53524 .51527 .52953 .50921 Metetra
.971 .124 0 r
.52953 .50921 .53524 .51527 .54585 .51202 .54017 .50594 Metetra
.971 .123 0 r
.54017 .50594 .54585 .51202 .5565 .50877 .55085 .50267 Metetra
.971 .123 0 r
.55085 .50267 .5565 .50877 .5672 .50551 .56157 .49939 Metetra
.971 .122 0 r
.56157 .49939 .5672 .50551 .57793 .50225 .57233 .4961 Metetra
.971 .121 0 r
.57233 .4961 .57793 .50225 .58871 .49899 .58314 .49282 Metetra
.972 .12 0 r
.58314 .49282 .58871 .49899 .59953 .49571 .59399 .48952 Metetra
.972 .119 0 r
.59399 .48952 .59953 .49571 .6104 .49243 .60488 .48621 Metetra
.972 .118 0 r
.60488 .48621 .6104 .49243 .6213 .48915 .61581 .4829 Metetra
.972 .116 0 r
.61581 .4829 .6213 .48915 .63225 .48586 .62679 .47959 Metetra
.973 .115 0 r
.62679 .47959 .63225 .48586 .64325 .48256 .63782 .47627 Metetra
.973 .114 0 r
.63782 .47627 .64325 .48256 .65429 .47926 .64888 .47294 Metetra
.973 .112 0 r
.64888 .47294 .65429 .47926 .66537 .47595 .66 .46961 Metetra
.974 .11 0 r
.66 .46961 .66537 .47595 .6765 .47264 .67115 .46627 Metetra
.974 .108 0 r
.67115 .46627 .6765 .47264 .68767 .46932 .68236 .46292 Metetra
.975 .106 0 r
.68236 .46292 .68767 .46932 .69889 .46599 .69361 .45957 Metetra
.975 .104 0 r
.69361 .45957 .69889 .46599 .71015 .46266 .7049 .45622 Metetra
.976 .102 0 r
.7049 .45622 .71015 .46266 .72146 .45932 .71624 .45286 Metetra
.976 .1 0 r
.71624 .45286 .72146 .45932 .73282 .45598 .72763 .44949 Metetra
.977 .098 0 r
.72763 .44949 .73282 .45598 .74422 .4526 .73906 .44608 Metetra
.977 .096 0 r
.73906 .44608 .74422 .4526 .75566 .44912 .75054 .44257 Metetra
.977 .098 0 r
.75054 .44257 .75566 .44912 .76712 .44528 .76203 .43871 Metetra
.974 .11 0 r
.76203 .43871 .76712 .44528 .77855 .44042 .7735 .43383 Metetra
.965 .147 0 r
.7735 .43383 .77855 .44042 .78981 .43302 .78479 .42639 Metetra
.942 .237 0 r
.78479 .42639 .78981 .43302 .80064 .42031 .79567 .41364 Metetra
.893 .414 0 r
.79567 .41364 .80064 .42031 .81064 .39847 .80572 .39175 Metetra
.804 .682 0 r
.80572 .39175 .81064 .39847 .81938 .36397 .81453 .35717 Metetra
.367 .666 0 r
.81453 .35717 .81938 .36397 .82664 .31592 .82188 .30903 Metetra
.077 .57 0 r
.17892 .48684 .1852 .49237 .18939 .53737 .18301 .5319 Metetra
.628 .736 0 r
.18301 .5319 .18939 .53737 .19497 .57084 .18854 .5654 Metetra
.851 .55 0 r
.18854 .5654 .19497 .57084 .20201 .5914 .19554 .58598 Metetra
.92 .321 0 r
.19554 .58598 .20201 .5914 .21017 .60135 .2037 .59593 Metetra
.955 .187 0 r
.2037 .59593 .21017 .60135 .21906 .60438 .21259 .59895 Metetra
.97 .125 0 r
.21259 .59895 .21906 .60438 .22833 .60374 .22187 .5983 Metetra
.976 .102 0 r
.22187 .5983 .22833 .60374 .23778 .60147 .23134 .59601 Metetra
.977 .097 0 r
.23134 .59601 .23778 .60147 .24732 .59859 .2409 .59311 Metetra
.977 .097 0 r
.2409 .59311 .24732 .59859 .2569 .59552 .25051 .59001 Metetra
.977 .099 0 r
.25051 .59001 .2569 .59552 .26653 .59239 .26016 .58687 Metetra
.976 .101 0 r
.26016 .58687 .26653 .59239 .27619 .58925 .26984 .5837 Metetra
.976 .103 0 r
.26984 .5837 .27619 .58925 .28589 .5861 .27956 .58054 Metetra
.975 .105 0 r
.27956 .58054 .28589 .5861 .29562 .58295 .28931 .57736 Metetra
.975 .107 0 r
.28931 .57736 .29562 .58295 .30538 .5798 .29909 .57419 Metetra
.974 .109 0 r
.29909 .57419 .30538 .5798 .31518 .57663 .30892 .57101 Metetra
.974 .111 0 r
.30892 .57101 .31518 .57663 .32501 .57347 .31877 .56782 Metetra
.973 .113 0 r
.31877 .56782 .32501 .57347 .33488 .5703 .32867 .56463 Metetra
.973 .114 0 r
.32867 .56463 .33488 .5703 .34479 .56714 .33859 .56144 Metetra
.973 .116 0 r
.33859 .56144 .34479 .56714 .35473 .56396 .34856 .55824 Metetra
.972 .117 0 r
.34856 .55824 .35473 .56396 .36471 .56078 .35856 .55504 Metetra
.972 .118 0 r
.35856 .55504 .36471 .56078 .37473 .55759 .3686 .55183 Metetra
.972 .119 0 r
.3686 .55183 .37473 .55759 .38478 .55441 .37867 .54863 Metetra
.971 .12 0 r
.37867 .54863 .38478 .55441 .39487 .55121 .38879 .54541 Metetra
.971 .121 0 r
.38879 .54541 .39487 .55121 .40499 .54801 .39894 .54219 Metetra
.971 .122 0 r
.39894 .54219 .40499 .54801 .41516 .54481 .40913 .53896 Metetra
.971 .123 0 r
.40913 .53896 .41516 .54481 .42536 .5416 .41935 .53573 Metetra
.971 .123 0 r
.41935 .53573 .42536 .5416 .4356 .53838 .42962 .53249 Metetra
.971 .124 0 r
.42962 .53249 .4356 .53838 .44588 .53517 .43992 .52925 Metetra
.97 .124 0 r
.43992 .52925 .44588 .53517 .45619 .53194 .45026 .526 Metetra
.97 .124 0 r
.45026 .526 .45619 .53194 .46655 .52871 .46064 .52275 Metetra
.97 .125 0 r
.46064 .52275 .46655 .52871 .47695 .52547 .47107 .51949 Metetra
.97 .125 0 r
.47107 .51949 .47695 .52547 .48738 .52223 .48153 .51623 Metetra
.97 .125 0 r
.48153 .51623 .48738 .52223 .49786 .51899 .49203 .51296 Metetra
.97 .125 0 r
.49203 .51296 .49786 .51899 .50837 .51573 .50257 .50968 Metetra
.97 .124 0 r
.50257 .50968 .50837 .51573 .51893 .51248 .51315 .5064 Metetra
.971 .124 0 r
.51315 .5064 .51893 .51248 .52953 .50921 .52378 .50311 Metetra
.971 .124 0 r
.52378 .50311 .52953 .50921 .54017 .50594 .53444 .49982 Metetra
.971 .123 0 r
.53444 .49982 .54017 .50594 .55085 .50267 .54515 .49652 Metetra
.971 .122 0 r
.54515 .49652 .55085 .50267 .56157 .49939 .5559 .49322 Metetra
.971 .122 0 r
.5559 .49322 .56157 .49939 .57233 .4961 .56669 .48991 Metetra
.971 .121 0 r
.56669 .48991 .57233 .4961 .58314 .49282 .57752 .4866 Metetra
.972 .12 0 r
.57752 .4866 .58314 .49282 .59399 .48952 .5884 .48328 Metetra
.972 .119 0 r
.5884 .48328 .59399 .48952 .60488 .48621 .59932 .47995 Metetra
.972 .118 0 r
.59932 .47995 .60488 .48621 .61581 .4829 .61029 .47661 Metetra
.972 .116 0 r
.61029 .47661 .61581 .4829 .62679 .47959 .62129 .47327 Metetra
.973 .115 0 r
.62129 .47327 .62679 .47959 .63782 .47627 .63235 .46993 Metetra
.973 .113 0 r
.63235 .46993 .63782 .47627 .64888 .47294 .64344 .46658 Metetra
.973 .112 0 r
.64344 .46658 .64888 .47294 .66 .46961 .65459 .46322 Metetra
.974 .11 0 r
.65459 .46322 .66 .46961 .67115 .46627 .66577 .45985 Metetra
.974 .108 0 r
.66577 .45985 .67115 .46627 .68236 .46292 .67701 .45649 Metetra
.975 .106 0 r
.67701 .45649 .68236 .46292 .69361 .45957 .68829 .45311 Metetra
.975 .104 0 r
.68829 .45311 .69361 .45957 .7049 .45622 .69961 .44973 Metetra
.976 .102 0 r
.69961 .44973 .7049 .45622 .71624 .45286 .71098 .44634 Metetra
.976 .1 0 r
.71098 .44634 .71624 .45286 .72763 .44949 .7224 .44294 Metetra
.977 .098 0 r
.7224 .44294 .72763 .44949 .73906 .44608 .73387 .43951 Metetra
.977 .096 0 r
.73387 .43951 .73906 .44608 .75054 .44257 .74537 .43598 Metetra
.977 .098 0 r
.74537 .43598 .75054 .44257 .76203 .43871 .7569 .43209 Metetra
.974 .11 0 r
.7569 .43209 .76203 .43871 .7735 .43383 .7684 .42718 Metetra
.965 .147 0 r
.7684 .42718 .7735 .43383 .78479 .42639 .77974 .41971 Metetra
.942 .237 0 r
.77974 .41971 .78479 .42639 .79567 .41364 .79065 .40692 Metetra
.893 .414 0 r
.79065 .40692 .79567 .41364 .80572 .39175 .80077 .38497 Metetra
.804 .682 0 r
.80077 .38497 .80572 .39175 .81453 .35717 .80965 .35032 Metetra
.367 .666 0 r
.80965 .35032 .81453 .35717 .82188 .30903 .81708 .30209 Metetra
.078 .57 0 r
.17259 .48128 .17892 .48684 .18301 .5319 .1766 .52639 Metetra
.629 .736 0 r
.1766 .52639 .18301 .5319 .18854 .5654 .18206 .55994 Metetra
.851 .55 0 r
.18206 .55994 .18854 .5654 .19554 .58598 .18903 .58053 Metetra
.92 .32 0 r
.18903 .58053 .19554 .58598 .2037 .59593 .19718 .59048 Metetra
.955 .187 0 r
.19718 .59048 .2037 .59593 .21259 .59895 .20607 .59349 Metetra
.97 .125 0 r
.20607 .59349 .21259 .59895 .22187 .5983 .21537 .59282 Metetra
.976 .102 0 r
.21537 .59282 .22187 .5983 .23134 .59601 .22486 .59051 Metetra
.977 .096 0 r
.22486 .59051 .23134 .59601 .2409 .59311 .23444 .58759 Metetra
.977 .097 0 r
.23444 .58759 .2409 .59311 .25051 .59001 .24407 .58448 Metetra
.977 .098 0 r
.24407 .58448 .25051 .59001 .26016 .58687 .25374 .58131 Metetra
.976 .101 0 r
.25374 .58131 .26016 .58687 .26984 .5837 .26344 .57812 Metetra
.976 .103 0 r
.26344 .57812 .26984 .5837 .27956 .58054 .27318 .57494 Metetra
.975 .105 0 r
.27318 .57494 .27956 .58054 .28931 .57736 .28296 .57174 Metetra
.975 .107 0 r
.28296 .57174 .28931 .57736 .29909 .57419 .29276 .56855 Metetra
.974 .109 0 r
.29276 .56855 .29909 .57419 .30892 .57101 .30261 .56534 Metetra
.974 .111 0 r
.30261 .56534 .30892 .57101 .31877 .56782 .31249 .56214 Metetra
.973 .113 0 r
.31249 .56214 .31877 .56782 .32867 .56463 .3224 .55893 Metetra
.973 .114 0 r
.3224 .55893 .32867 .56463 .33859 .56144 .33235 .55571 Metetra
.973 .116 0 r
.33235 .55571 .33859 .56144 .34856 .55824 .34234 .55249 Metetra
.972 .117 0 r
.34234 .55249 .34856 .55824 .35856 .55504 .35237 .54927 Metetra
.972 .118 0 r
.35237 .54927 .35856 .55504 .3686 .55183 .36243 .54604 Metetra
.972 .119 0 r
.36243 .54604 .3686 .55183 .37867 .54863 .37253 .54281 Metetra
.971 .12 0 r
.37253 .54281 .37867 .54863 .38879 .54541 .38266 .53957 Metetra
.971 .121 0 r
.38266 .53957 .38879 .54541 .39894 .54219 .39284 .53633 Metetra
.971 .122 0 r
.39284 .53633 .39894 .54219 .40913 .53896 .40305 .53308 Metetra
.971 .123 0 r
.40305 .53308 .40913 .53896 .41935 .53573 .4133 .52982 Metetra
.971 .123 0 r
.4133 .52982 .41935 .53573 .42962 .53249 .42359 .52656 Metetra
.971 .124 0 r
.42359 .52656 .42962 .53249 .43992 .52925 .43392 .5233 Metetra
.97 .124 0 r
.43392 .5233 .43992 .52925 .45026 .526 .44429 .52003 Metetra
.97 .124 0 r
.44429 .52003 .45026 .526 .46064 .52275 .4547 .51675 Metetra
.97 .125 0 r
.4547 .51675 .46064 .52275 .47107 .51949 .46514 .51347 Metetra
.97 .125 0 r
.46514 .51347 .47107 .51949 .48153 .51623 .47563 .51018 Metetra
.97 .125 0 r
.47563 .51018 .48153 .51623 .49203 .51296 .48616 .50689 Metetra
.97 .124 0 r
.48616 .50689 .49203 .51296 .50257 .50968 .49673 .50359 Metetra
.97 .124 0 r
.49673 .50359 .50257 .50968 .51315 .5064 .50734 .50029 Metetra
.971 .124 0 r
.50734 .50029 .51315 .5064 .52378 .50311 .51799 .49697 Metetra
.971 .123 0 r
.51799 .49697 .52378 .50311 .53444 .49982 .52868 .49366 Metetra
.971 .123 0 r
.52868 .49366 .53444 .49982 .54515 .49652 .53941 .49033 Metetra
.971 .122 0 r
.53941 .49033 .54515 .49652 .5559 .49322 .55019 .48701 Metetra
.971 .122 0 r
.55019 .48701 .5559 .49322 .56669 .48991 .56101 .48367 Metetra
.971 .121 0 r
.56101 .48367 .56669 .48991 .57752 .4866 .57187 .48034 Metetra
.972 .12 0 r
.57187 .48034 .57752 .4866 .5884 .48328 .58278 .47699 Metetra
.972 .119 0 r
.58278 .47699 .5884 .48328 .59932 .47995 .59373 .47364 Metetra
.972 .117 0 r
.59373 .47364 .59932 .47995 .61029 .47661 .60472 .47028 Metetra
.972 .116 0 r
.60472 .47028 .61029 .47661 .62129 .47327 .61576 .46692 Metetra
.973 .115 0 r
.61576 .46692 .62129 .47327 .63235 .46993 .62684 .46355 Metetra
.973 .113 0 r
.62684 .46355 .63235 .46993 .64344 .46658 .63796 .46017 Metetra
.974 .112 0 r
.63796 .46017 .64344 .46658 .65459 .46322 .64914 .45679 Metetra
.974 .11 0 r
.64914 .45679 .65459 .46322 .66577 .45985 .66035 .4534 Metetra
.974 .108 0 r
.66035 .4534 .66577 .45985 .67701 .45649 .67162 .45 Metetra
.975 .106 0 r
.67162 .45 .67701 .45649 .68829 .45311 .68293 .4466 Metetra
.975 .104 0 r
.68293 .4466 .68829 .45311 .69961 .44973 .69428 .4432 Metetra
.976 .102 0 r
.69428 .4432 .69961 .44973 .71098 .44634 .70569 .43978 Metetra
.976 .1 0 r
.70569 .43978 .71098 .44634 .7224 .44294 .71714 .43636 Metetra
.977 .097 0 r
.71714 .43636 .7224 .44294 .73387 .43951 .72863 .4329 Metetra
.977 .096 0 r
.72863 .4329 .73387 .43951 .74537 .43598 .74017 .42934 Metetra
.977 .098 0 r
.74017 .42934 .74537 .43598 .7569 .43209 .75174 .42543 Metetra
.974 .109 0 r
.75174 .42543 .7569 .43209 .7684 .42718 .76327 .42049 Metetra
.965 .146 0 r
.76327 .42049 .7684 .42718 .77974 .41971 .77464 .41298 Metetra
.942 .237 0 r
.77464 .41298 .77974 .41971 .79065 .40692 .7856 .40015 Metetra
.893 .414 0 r
.7856 .40015 .79065 .40692 .80077 .38497 .79577 .37815 Metetra
.804 .682 0 r
.79577 .37815 .80077 .38497 .80965 .35032 .80473 .34343 Metetra
.368 .666 0 r
.80473 .34343 .80965 .35032 .81708 .30209 .81224 .29511 Metetra
.078 .57 0 r
.16622 .47568 .17259 .48128 .1766 .52639 .17014 .52085 Metetra
.629 .736 0 r
.17014 .52085 .1766 .52639 .18206 .55994 .17554 .55443 Metetra
.851 .55 0 r
.17554 .55443 .18206 .55994 .18903 .58053 .18247 .57505 Metetra
.92 .32 0 r
.18247 .57505 .18903 .58053 .19718 .59048 .19061 .585 Metetra
.955 .186 0 r
.19061 .585 .19718 .59048 .20607 .59349 .19952 .588 Metetra
.97 .125 0 r
.19952 .588 .20607 .59349 .21537 .59282 .20883 .58731 Metetra
.976 .102 0 r
.20883 .58731 .21537 .59282 .22486 .59051 .21834 .58498 Metetra
.977 .096 0 r
.21834 .58498 .22486 .59051 .23444 .58759 .22794 .58204 Metetra
.977 .096 0 r
.22794 .58204 .23444 .58759 .24407 .58448 .23759 .5789 Metetra
.977 .098 0 r
.23759 .5789 .24407 .58448 .25374 .58131 .24728 .57572 Metetra
.976 .101 0 r
.24728 .57572 .25374 .58131 .26344 .57812 .257 .5725 Metetra
.976 .103 0 r
.257 .5725 .26344 .57812 .27318 .57494 .26676 .5693 Metetra
.975 .105 0 r
.26676 .5693 .27318 .57494 .28296 .57174 .27656 .56608 Metetra
.975 .107 0 r
.27656 .56608 .28296 .57174 .29276 .56855 .28639 .56286 Metetra
.974 .109 0 r
.28639 .56286 .29276 .56855 .30261 .56534 .29626 .55964 Metetra
.974 .111 0 r
.29626 .55964 .30261 .56534 .31249 .56214 .30616 .55641 Metetra
.973 .112 0 r
.30616 .55641 .31249 .56214 .3224 .55893 .3161 .55318 Metetra
.973 .114 0 r
.3161 .55318 .3224 .55893 .33235 .55571 .32607 .54994 Metetra
.973 .115 0 r
.32607 .54994 .33235 .55571 .34234 .55249 .33608 .5467 Metetra
.972 .117 0 r
.33608 .5467 .34234 .55249 .35237 .54927 .34613 .54345 Metetra
.972 .118 0 r
.34613 .54345 .35237 .54927 .36243 .54604 .35622 .5402 Metetra
.972 .119 0 r
.35622 .5402 .36243 .54604 .37253 .54281 .36634 .53695 Metetra
.971 .12 0 r
.36634 .53695 .37253 .54281 .38266 .53957 .3765 .53369 Metetra
.971 .121 0 r
.3765 .53369 .38266 .53957 .39284 .53633 .3867 .53042 Metetra
.971 .122 0 r
.3867 .53042 .39284 .53633 .40305 .53308 .39694 .52715 Metetra
.971 .122 0 r
.39694 .52715 .40305 .53308 .4133 .52982 .40721 .52387 Metetra
.971 .123 0 r
.40721 .52387 .4133 .52982 .42359 .52656 .41753 .52059 Metetra
.971 .124 0 r
.41753 .52059 .42359 .52656 .43392 .5233 .42788 .5173 Metetra
.971 .124 0 r
.42788 .5173 .43392 .5233 .44429 .52003 .43827 .51401 Metetra
.97 .124 0 r
.43827 .51401 .44429 .52003 .4547 .51675 .4487 .51071 Metetra
.97 .124 0 r
.4487 .51071 .4547 .51675 .46514 .51347 .45918 .5074 Metetra
.97 .124 0 r
.45918 .5074 .46514 .51347 .47563 .51018 .46969 .50409 Metetra
.97 .124 0 r
.46969 .50409 .47563 .51018 .48616 .50689 .48024 .50078 Metetra
.97 .124 0 r
.48024 .50078 .48616 .50689 .49673 .50359 .49084 .49745 Metetra
.97 .124 0 r
.49084 .49745 .49673 .50359 .50734 .50029 .50148 .49412 Metetra
.971 .124 0 r
.50148 .49412 .50734 .50029 .51799 .49697 .51215 .49079 Metetra
.971 .123 0 r
.51215 .49079 .51799 .49697 .52868 .49366 .52287 .48745 Metetra
.971 .123 0 r
.52287 .48745 .52868 .49366 .53941 .49033 .53363 .4841 Metetra
.971 .122 0 r
.53363 .4841 .53941 .49033 .55019 .48701 .54444 .48075 Metetra
.971 .121 0 r
.54444 .48075 .55019 .48701 .56101 .48367 .55529 .47739 Metetra
.971 .121 0 r
.55529 .47739 .56101 .48367 .57187 .48034 .56618 .47403 Metetra
.972 .12 0 r
.56618 .47403 .57187 .48034 .58278 .47699 .57711 .47066 Metetra
.972 .118 0 r
.57711 .47066 .58278 .47699 .59373 .47364 .58809 .46728 Metetra
.972 .117 0 r
.58809 .46728 .59373 .47364 .60472 .47028 .59911 .4639 Metetra
.972 .116 0 r
.59911 .4639 .60472 .47028 .61576 .46692 .61018 .46051 Metetra
.973 .115 0 r
.61018 .46051 .61576 .46692 .62684 .46355 .62129 .45711 Metetra
.973 .113 0 r
.62129 .45711 .62684 .46355 .63796 .46017 .63244 .45371 Metetra
.974 .112 0 r
.63244 .45371 .63796 .46017 .64914 .45679 .64364 .4503 Metetra
.974 .11 0 r
.64364 .4503 .64914 .45679 .66035 .4534 .65489 .44689 Metetra
.974 .108 0 r
.65489 .44689 .66035 .4534 .67162 .45 .66619 .44347 Metetra
.975 .106 0 r
.66619 .44347 .67162 .45 .68293 .4466 .67753 .44004 Metetra
.975 .104 0 r
.67753 .44004 .68293 .4466 .69428 .4432 .68891 .43661 Metetra
.976 .102 0 r
.68891 .43661 .69428 .4432 .70569 .43978 .70035 .43317 Metetra
.976 .099 0 r
.70035 .43317 .70569 .43978 .71714 .43636 .71183 .42972 Metetra
.977 .097 0 r
.71183 .42972 .71714 .43636 .72863 .4329 .72336 .42624 Metetra
.977 .096 0 r
.72336 .42624 .72863 .4329 .74017 .42934 .73493 .42265 Metetra
.977 .098 0 r
.73493 .42265 .74017 .42934 .75174 .42543 .74653 .41871 Metetra
.974 .109 0 r
.74653 .41871 .75174 .42543 .76327 .42049 .7581 .41374 Metetra
.965 .146 0 r
.7581 .41374 .76327 .42049 .77464 .41298 .76951 .4062 Metetra
.942 .237 0 r
.76951 .4062 .77464 .41298 .7856 .40015 .78052 .39333 Metetra
.893 .413 0 r
.78052 .39333 .7856 .40015 .79577 .37815 .79074 .37128 Metetra
.805 .681 0 r
.79074 .37128 .79577 .37815 .80473 .34343 .79977 .33648 Metetra
.368 .666 0 r
.79977 .33648 .80473 .34343 .81224 .29511 .80737 .28807 Metetra
.078 .57 0 r
.15981 .47006 .16622 .47568 .17014 .52085 .16364 .51528 Metetra
.629 .736 0 r
.16364 .51528 .17014 .52085 .17554 .55443 .16897 .5489 Metetra
.851 .55 0 r
.16897 .5489 .17554 .55443 .18247 .57505 .17587 .56953 Metetra
.92 .32 0 r
.17587 .56953 .18247 .57505 .19061 .585 .184 .57948 Metetra
.955 .186 0 r
.184 .57948 .19061 .585 .19952 .588 .19291 .58247 Metetra
.97 .124 0 r
.19291 .58247 .19952 .588 .20883 .58731 .20224 .58176 Metetra
.976 .102 0 r
.20224 .58176 .20883 .58731 .21834 .58498 .21177 .57941 Metetra
.977 .096 0 r
.21177 .57941 .21834 .58498 .22794 .58204 .22139 .57645 Metetra
.977 .096 0 r
.22139 .57645 .22794 .58204 .23759 .5789 .23106 .57329 Metetra
.977 .098 0 r
.23106 .57329 .23759 .5789 .24728 .57572 .24077 .57009 Metetra
.976 .1 0 r
.24077 .57009 .24728 .57572 .257 .5725 .25052 .56685 Metetra
.976 .103 0 r
.25052 .56685 .257 .5725 .26676 .5693 .2603 .56362 Metetra
.975 .105 0 r
.2603 .56362 .26676 .5693 .27656 .56608 .27012 .56038 Metetra
.975 .107 0 r
.27012 .56038 .27656 .56608 .28639 .56286 .27997 .55714 Metetra
.974 .109 0 r
.27997 .55714 .28639 .56286 .29626 .55964 .28986 .5539 Metetra
.974 .11 0 r
.28986 .5539 .29626 .55964 .30616 .55641 .29979 .55065 Metetra
.973 .112 0 r
.29979 .55065 .30616 .55641 .3161 .55318 .30975 .54739 Metetra
.973 .114 0 r
.30975 .54739 .3161 .55318 .32607 .54994 .31974 .54414 Metetra
.973 .115 0 r
.31974 .54414 .32607 .54994 .33608 .5467 .32978 .54087 Metetra
.972 .117 0 r
.32978 .54087 .33608 .5467 .34613 .54345 .33985 .5376 Metetra
.972 .118 0 r
.33985 .5376 .34613 .54345 .35622 .5402 .34996 .53433 Metetra
.972 .119 0 r
.34996 .53433 .35622 .5402 .36634 .53695 .36011 .53105 Metetra
.972 .12 0 r
.36011 .53105 .36634 .53695 .3765 .53369 .37029 .52777 Metetra
.971 .121 0 r
.37029 .52777 .3765 .53369 .3867 .53042 .38051 .52448 Metetra
.971 .122 0 r
.38051 .52448 .3867 .53042 .39694 .52715 .39078 .52118 Metetra
.971 .122 0 r
.39078 .52118 .39694 .52715 .40721 .52387 .40108 .51788 Metetra
.971 .123 0 r
.40108 .51788 .40721 .52387 .41753 .52059 .41141 .51458 Metetra
.971 .123 0 r
.41141 .51458 .41753 .52059 .42788 .5173 .42179 .51127 Metetra
.971 .124 0 r
.42179 .51127 .42788 .5173 .43827 .51401 .43221 .50795 Metetra
.971 .124 0 r
.43221 .50795 .43827 .51401 .4487 .51071 .44267 .50463 Metetra
.97 .124 0 r
.44267 .50463 .4487 .51071 .45918 .5074 .45317 .5013 Metetra
.97 .124 0 r
.45317 .5013 .45918 .5074 .46969 .50409 .46371 .49796 Metetra
.97 .124 0 r
.46371 .49796 .46969 .50409 .48024 .50078 .47429 .49462 Metetra
.97 .124 0 r
.47429 .49462 .48024 .50078 .49084 .49745 .48491 .49128 Metetra
.971 .124 0 r
.48491 .49128 .49084 .49745 .50148 .49412 .49557 .48792 Metetra
.971 .124 0 r
.49557 .48792 .50148 .49412 .51215 .49079 .50628 .48456 Metetra
.971 .123 0 r
.50628 .48456 .51215 .49079 .52287 .48745 .51702 .4812 Metetra
.971 .123 0 r
.51702 .4812 .52287 .48745 .53363 .4841 .52781 .47783 Metetra
.971 .122 0 r
.52781 .47783 .53363 .4841 .54444 .48075 .53865 .47445 Metetra
.971 .121 0 r
.53865 .47445 .54444 .48075 .55529 .47739 .54952 .47107 Metetra
.971 .12 0 r
.54952 .47107 .55529 .47739 .56618 .47403 .56044 .46768 Metetra
.972 .119 0 r
.56044 .46768 .56618 .47403 .57711 .47066 .5714 .46429 Metetra
.972 .118 0 r
.5714 .46429 .57711 .47066 .58809 .46728 .58241 .46089 Metetra
.972 .117 0 r
.58241 .46089 .58809 .46728 .59911 .4639 .59346 .45748 Metetra
.973 .116 0 r
.59346 .45748 .59911 .4639 .61018 .46051 .60455 .45406 Metetra
.973 .114 0 r
.60455 .45406 .61018 .46051 .62129 .45711 .61569 .45064 Metetra
.973 .113 0 r
.61569 .45064 .62129 .45711 .63244 .45371 .62688 .44721 Metetra
.974 .111 0 r
.62688 .44721 .63244 .45371 .64364 .4503 .63811 .44378 Metetra
.974 .11 0 r
.63811 .44378 .64364 .4503 .65489 .44689 .64939 .44034 Metetra
.974 .108 0 r
.64939 .44034 .65489 .44689 .66619 .44347 .66072 .43689 Metetra
.975 .106 0 r
.66072 .43689 .66619 .44347 .67753 .44004 .67209 .43344 Metetra
.975 .104 0 r
.67209 .43344 .67753 .44004 .68891 .43661 .68351 .42998 Metetra
.976 .102 0 r
.68351 .42998 .68891 .43661 .70035 .43317 .69497 .42652 Metetra
.977 .099 0 r
.69497 .42652 .70035 .43317 .71183 .42972 .70649 .42304 Metetra
.977 .097 0 r
.70649 .42304 .71183 .42972 .72336 .42624 .71805 .41953 Metetra
.977 .096 0 r
.71805 .41953 .72336 .42624 .73493 .42265 .72965 .41592 Metetra
.977 .097 0 r
.72965 .41592 .73493 .42265 .74653 .41871 .74128 .41195 Metetra
.974 .109 0 r
.74128 .41195 .74653 .41871 .7581 .41374 .75289 .40695 Metetra
.965 .146 0 r
.75289 .40695 .7581 .41374 .76951 .4062 .76434 .39938 Metetra
.942 .236 0 r
.76434 .39938 .76951 .4062 .78052 .39333 .77539 .38647 Metetra
.893 .413 0 r
.77539 .38647 .78052 .39333 .79074 .37128 .78567 .36436 Metetra
.805 .681 0 r
.78567 .36436 .79074 .37128 .79977 .33648 .79477 .32949 Metetra
.368 .666 0 r
.79477 .32949 .79977 .33648 .80737 .28807 .80247 .28099 Metetra
.078 .57 0 r
.15336 .46439 .15981 .47006 .16364 .51528 .15709 .50967 Metetra
.63 .736 0 r
.15709 .50967 .16364 .51528 .16897 .5489 .16236 .54333 Metetra
.851 .549 0 r
.16236 .54333 .16897 .5489 .17587 .56953 .16922 .56397 Metetra
.92 .32 0 r
.16922 .56397 .17587 .56953 .184 .57948 .17734 .57392 Metetra
.955 .186 0 r
.17734 .57392 .184 .57948 .19291 .58247 .18626 .5769 Metetra
.97 .124 0 r
.18626 .5769 .19291 .58247 .20224 .58176 .19561 .57618 Metetra
.976 .102 0 r
.19561 .57618 .20224 .58176 .21177 .57941 .20515 .5738 Metetra
.977 .096 0 r
.20515 .5738 .21177 .57941 .22139 .57645 .21479 .57082 Metetra
.977 .096 0 r
.21479 .57082 .22139 .57645 .23106 .57329 .22449 .56764 Metetra
.977 .098 0 r
.22449 .56764 .23106 .57329 .24077 .57009 .23422 .56441 Metetra
.976 .1 0 r
.23422 .56441 .24077 .57009 .25052 .56685 .24399 .56116 Metetra
.976 .102 0 r
.24399 .56116 .25052 .56685 .2603 .56362 .25379 .55791 Metetra
.975 .105 0 r
.25379 .55791 .2603 .56362 .27012 .56038 .26363 .55464 Metetra
.975 .107 0 r
.26363 .55464 .27012 .56038 .27997 .55714 .27351 .55138 Metetra
.974 .108 0 r
.27351 .55138 .27997 .55714 .28986 .5539 .28342 .54811 Metetra
.974 .11 0 r
.28342 .54811 .28986 .5539 .29979 .55065 .29337 .54484 Metetra
.973 .112 0 r
.29337 .54484 .29979 .55065 .30975 .54739 .30335 .54157 Metetra
.973 .114 0 r
.30335 .54157 .30975 .54739 .31974 .54414 .31337 .53829 Metetra
.973 .115 0 r
.31337 .53829 .31974 .54414 .32978 .54087 .32343 .535 Metetra
.972 .116 0 r
.32343 .535 .32978 .54087 .33985 .5376 .33353 .53171 Metetra
.972 .118 0 r
.33353 .53171 .33985 .5376 .34996 .53433 .34366 .52841 Metetra
.972 .119 0 r
.34366 .52841 .34996 .53433 .36011 .53105 .35383 .52511 Metetra
.972 .12 0 r
.35383 .52511 .36011 .53105 .37029 .52777 .36404 .5218 Metetra
.971 .121 0 r
.36404 .5218 .37029 .52777 .38051 .52448 .37429 .51849 Metetra
.971 .121 0 r
.37429 .51849 .38051 .52448 .39078 .52118 .38457 .51517 Metetra
.971 .122 0 r
.38457 .51517 .39078 .52118 .40108 .51788 .3949 .51185 Metetra
.971 .123 0 r
.3949 .51185 .40108 .51788 .41141 .51458 .40526 .50852 Metetra
.971 .123 0 r
.40526 .50852 .41141 .51458 .42179 .51127 .41566 .50519 Metetra
.971 .124 0 r
.41566 .50519 .42179 .51127 .43221 .50795 .42611 .50184 Metetra
.971 .124 0 r
.42611 .50184 .43221 .50795 .44267 .50463 .43659 .4985 Metetra
.97 .124 0 r
.43659 .4985 .44267 .50463 .45317 .5013 .44712 .49515 Metetra
.97 .124 0 r
.44712 .49515 .45317 .5013 .46371 .49796 .45768 .49179 Metetra
.97 .124 0 r
.45768 .49179 .46371 .49796 .47429 .49462 .46829 .48842 Metetra
.971 .124 0 r
.46829 .48842 .47429 .49462 .48491 .49128 .47894 .48505 Metetra
.971 .124 0 r
.47894 .48505 .48491 .49128 .49557 .48792 .48963 .48167 Metetra
.971 .123 0 r
.48963 .48167 .49557 .48792 .50628 .48456 .50036 .47829 Metetra
.971 .123 0 r
.50036 .47829 .50628 .48456 .51702 .4812 .51113 .4749 Metetra
.971 .122 0 r
.51113 .4749 .51702 .4812 .52781 .47783 .52195 .4715 Metetra
.971 .122 0 r
.52195 .4715 .52781 .47783 .53865 .47445 .53281 .4681 Metetra
.971 .121 0 r
.53281 .4681 .53865 .47445 .54952 .47107 .54371 .46469 Metetra
.971 .12 0 r
.54371 .46469 .54952 .47107 .56044 .46768 .55466 .46129 Metetra
.972 .119 0 r
.55466 .46129 .56044 .46768 .5714 .46429 .56565 .45787 Metetra
.972 .118 0 r
.56565 .45787 .5714 .46429 .58241 .46089 .57669 .45444 Metetra
.972 .117 0 r
.57669 .45444 .58241 .46089 .59346 .45748 .58777 .451 Metetra
.973 .116 0 r
.58777 .451 .59346 .45748 .60455 .45406 .59889 .44756 Metetra
.973 .114 0 r
.59889 .44756 .60455 .45406 .61569 .45064 .61006 .44412 Metetra
.973 .113 0 r
.61006 .44412 .61569 .45064 .62688 .44721 .62128 .44066 Metetra
.974 .111 0 r
.62128 .44066 .62688 .44721 .63811 .44378 .63254 .4372 Metetra
.974 .109 0 r
.63254 .4372 .63811 .44378 .64939 .44034 .64385 .43374 Metetra
.975 .108 0 r
.64385 .43374 .64939 .44034 .66072 .43689 .65521 .43027 Metetra
.975 .106 0 r
.65521 .43027 .66072 .43689 .67209 .43344 .66661 .42679 Metetra
.976 .103 0 r
.66661 .42679 .67209 .43344 .68351 .42998 .67806 .4233 Metetra
.976 .101 0 r
.67806 .4233 .68351 .42998 .69497 .42652 .68956 .41981 Metetra
.977 .099 0 r
.68956 .41981 .69497 .42652 .70649 .42304 .7011 .41631 Metetra
.977 .097 0 r
.7011 .41631 .70649 .42304 .71805 .41953 .7127 .41277 Metetra
.977 .095 0 r
.7127 .41277 .71805 .41953 .72965 .41592 .72434 .40913 Metetra
.977 .097 0 r
.72434 .40913 .72965 .41592 .74128 .41195 .736 .40514 Metetra
.974 .109 0 r
.736 .40514 .74128 .41195 .75289 .40695 .74764 .4001 Metetra
.965 .146 0 r
.74764 .4001 .75289 .40695 .76434 .39938 .75913 .3925 Metetra
.942 .236 0 r
.75913 .3925 .76434 .39938 .77539 .38647 .77023 .37955 Metetra
.893 .413 0 r
.77023 .37955 .77539 .38647 .78567 .36436 .78057 .35739 Metetra
.805 .681 0 r
.78057 .35739 .78567 .36436 .79477 .32949 .78974 .32245 Metetra
.369 .666 0 r
.78974 .32245 .79477 .32949 .80247 .28099 .79753 .27385 Metetra
.079 .57 0 r
.14687 .4587 .15336 .46439 .15709 .50967 .1505 .50403 Metetra
.63 .736 0 r
.1505 .50403 .15709 .50967 .16236 .54333 .1557 .53772 Metetra
.851 .549 0 r
.1557 .53772 .16236 .54333 .16922 .56397 .16253 .55839 Metetra
.92 .319 0 r
.16253 .55839 .16922 .56397 .17734 .57392 .17064 .56833 Metetra
.955 .186 0 r
.17064 .56833 .17734 .57392 .18626 .5769 .17957 .5713 Metetra
.971 .124 0 r
.17957 .5713 .18626 .5769 .19561 .57618 .18893 .57056 Metetra
.976 .101 0 r
.18893 .57056 .19561 .57618 .20515 .5738 .19849 .56816 Metetra
.977 .095 0 r
.19849 .56816 .20515 .5738 .21479 .57082 .20815 .56516 Metetra
.977 .096 0 r
.20815 .56516 .21479 .57082 .22449 .56764 .21787 .56196 Metetra
.977 .098 0 r
.21787 .56196 .22449 .56764 .23422 .56441 .22762 .55871 Metetra
.976 .1 0 r
.22762 .55871 .23422 .56441 .24399 .56116 .23742 .55543 Metetra
.976 .102 0 r
.23742 .55543 .24399 .56116 .25379 .55791 .24724 .55216 Metetra
.975 .104 0 r
.24724 .55216 .25379 .55791 .26363 .55464 .2571 .54887 Metetra
.975 .106 0 r
.2571 .54887 .26363 .55464 .27351 .55138 .267 .54559 Metetra
.974 .108 0 r
.267 .54559 .27351 .55138 .28342 .54811 .27694 .5423 Metetra
.974 .11 0 r
.27694 .5423 .28342 .54811 .29337 .54484 .28691 .53901 Metetra
.974 .112 0 r
.28691 .53901 .29337 .54484 .30335 .54157 .29691 .5357 Metetra
.973 .113 0 r
.29691 .5357 .30335 .54157 .31337 .53829 .30696 .5324 Metetra
.973 .115 0 r
.30696 .5324 .31337 .53829 .32343 .535 .31704 .52909 Metetra
.972 .116 0 r
.31704 .52909 .32343 .535 .33353 .53171 .32716 .52578 Metetra
.972 .117 0 r
.32716 .52578 .33353 .53171 .34366 .52841 .33731 .52246 Metetra
.972 .118 0 r
.33731 .52246 .34366 .52841 .35383 .52511 .34751 .51913 Metetra
.972 .119 0 r
.34751 .51913 .35383 .52511 .36404 .5218 .35774 .5158 Metetra
.971 .12 0 r
.35774 .5158 .36404 .5218 .37429 .51849 .36801 .51247 Metetra
.971 .121 0 r
.36801 .51247 .37429 .51849 .38457 .51517 .37832 .50912 Metetra
.971 .122 0 r
.37832 .50912 .38457 .51517 .3949 .51185 .38867 .50578 Metetra
.971 .123 0 r
.38867 .50578 .3949 .51185 .40526 .50852 .39906 .50242 Metetra
.971 .123 0 r
.39906 .50242 .40526 .50852 .41566 .50519 .40949 .49907 Metetra
.971 .123 0 r
.40949 .49907 .41566 .50519 .42611 .50184 .41996 .4957 Metetra
.971 .124 0 r
.41996 .4957 .42611 .50184 .43659 .4985 .43047 .49233 Metetra
.971 .124 0 r
.43047 .49233 .43659 .4985 .44712 .49515 .44102 .48895 Metetra
.971 .124 0 r
.44102 .48895 .44712 .49515 .45768 .49179 .45161 .48557 Metetra
.971 .124 0 r
.45161 .48557 .45768 .49179 .46829 .48842 .46225 .48218 Metetra
.971 .124 0 r
.46225 .48218 .46829 .48842 .47894 .48505 .47292 .47879 Metetra
.971 .124 0 r
.47292 .47879 .47894 .48505 .48963 .48167 .48364 .47539 Metetra
.971 .123 0 r
.48364 .47539 .48963 .48167 .50036 .47829 .4944 .47198 Metetra
.971 .123 0 r
.4944 .47198 .50036 .47829 .51113 .4749 .5052 .46856 Metetra
.971 .122 0 r
.5052 .46856 .51113 .4749 .52195 .4715 .51604 .46514 Metetra
.971 .122 0 r
.51604 .46514 .52195 .4715 .53281 .4681 .52693 .46172 Metetra
.971 .121 0 r
.52693 .46172 .53281 .4681 .54371 .46469 .53786 .45828 Metetra
.972 .12 0 r
.53786 .45828 .54371 .46469 .55466 .46129 .54884 .45485 Metetra
.972 .119 0 r
.54884 .45485 .55466 .46129 .56565 .45787 .55986 .4514 Metetra
.972 .118 0 r
.55986 .4514 .56565 .45787 .57669 .45444 .57092 .44795 Metetra
.972 .117 0 r
.57092 .44795 .57669 .45444 .58777 .451 .58203 .44449 Metetra
.973 .115 0 r
.58203 .44449 .58777 .451 .59889 .44756 .59319 .44102 Metetra
.973 .114 0 r
.59319 .44102 .59889 .44756 .61006 .44412 .60439 .43755 Metetra
.973 .113 0 r
.60439 .43755 .61006 .44412 .62128 .44066 .61563 .43407 Metetra
.974 .111 0 r
.61563 .43407 .62128 .44066 .63254 .4372 .62693 .43059 Metetra
.974 .109 0 r
.62693 .43059 .63254 .4372 .64385 .43374 .63827 .42709 Metetra
.975 .107 0 r
.63827 .42709 .64385 .43374 .65521 .43027 .64965 .42359 Metetra
.975 .105 0 r
.64965 .42359 .65521 .43027 .66661 .42679 .66109 .42009 Metetra
.976 .103 0 r
.66109 .42009 .66661 .42679 .67806 .4233 .67257 .41658 Metetra
.976 .101 0 r
.67257 .41658 .67806 .4233 .68956 .41981 .6841 .41306 Metetra
.977 .099 0 r
.6841 .41306 .68956 .41981 .7011 .41631 .69568 .40953 Metetra
.977 .097 0 r
.69568 .40953 .7011 .41631 .7127 .41277 .70731 .40597 Metetra
.978 .095 0 r
.70731 .40597 .7127 .41277 .72434 .40913 .71898 .4023 Metetra
.977 .097 0 r
.71898 .4023 .72434 .40913 .736 .40514 .73067 .39827 Metetra
.974 .108 0 r
.73067 .39827 .736 .40514 .74764 .4001 .74235 .39321 Metetra
.965 .145 0 r
.74235 .39321 .74764 .4001 .75913 .3925 .75388 .38558 Metetra
.942 .236 0 r
.75388 .38558 .75913 .3925 .77023 .37955 .76502 .37259 Metetra
.893 .412 0 r
.76502 .37259 .77023 .37955 .78057 .35739 .77542 .35037 Metetra
.805 .681 0 r
.77542 .35037 .78057 .35739 .78974 .32245 .78467 .31535 Metetra
.369 .666 0 r
.78467 .31535 .78974 .32245 .79753 .27385 .79255 .26667 Metetra
.079 .57 0 r
.14033 .45296 .14687 .4587 .1505 .50403 .14387 .49835 Metetra
.631 .736 0 r
.14387 .49835 .1505 .50403 .1557 .53772 .149 .53208 Metetra
.851 .549 0 r
.149 .53208 .1557 .53772 .16253 .55839 .1558 .55276 Metetra
.92 .319 0 r
.1558 .55276 .16253 .55839 .17064 .56833 .16389 .5627 Metetra
.955 .185 0 r
.16389 .5627 .17064 .56833 .17957 .5713 .17283 .56566 Metetra
.971 .124 0 r
.17283 .56566 .17957 .5713 .18893 .57056 .1822 .5649 Metetra
.976 .101 0 r
.1822 .5649 .18893 .57056 .19849 .56816 .19179 .56248 Metetra
.978 .095 0 r
.19179 .56248 .19849 .56816 .20815 .56516 .20147 .55946 Metetra
.977 .095 0 r
.20147 .55946 .20815 .56516 .21787 .56196 .21121 .55623 Metetra
.977 .097 0 r
.21121 .55623 .21787 .56196 .22762 .55871 .22098 .55296 Metetra
.976 .1 0 r
.22098 .55296 .22762 .55871 .23742 .55543 .2308 .54966 Metetra
.976 .102 0 r
.2308 .54966 .23742 .55543 .24724 .55216 .24064 .54636 Metetra
.975 .104 0 r
.24064 .54636 .24724 .55216 .2571 .54887 .25053 .54306 Metetra
.975 .106 0 r
.25053 .54306 .2571 .54887 .267 .54559 .26045 .53975 Metetra
.974 .108 0 r
.26045 .53975 .267 .54559 .27694 .5423 .2704 .53644 Metetra
.974 .11 0 r
.2704 .53644 .27694 .5423 .28691 .53901 .2804 .53312 Metetra
.974 .111 0 r
.2804 .53312 .28691 .53901 .29691 .5357 .29043 .5298 Metetra
.973 .113 0 r
.29043 .5298 .29691 .5357 .30696 .5324 .3005 .52647 Metetra
.973 .115 0 r
.3005 .52647 .30696 .5324 .31704 .52909 .3106 .52314 Metetra
.973 .116 0 r
.3106 .52314 .31704 .52909 .32716 .52578 .32074 .5198 Metetra
.972 .117 0 r
.32074 .5198 .32716 .52578 .33731 .52246 .33092 .51646 Metetra
.972 .118 0 r
.33092 .51646 .33731 .52246 .34751 .51913 .34114 .51311 Metetra
.972 .119 0 r
.34114 .51311 .34751 .51913 .35774 .5158 .3514 .50975 Metetra
.971 .12 0 r
.3514 .50975 .35774 .5158 .36801 .51247 .3617 .5064 Metetra
.971 .121 0 r
.3617 .5064 .36801 .51247 .37832 .50912 .37203 .50303 Metetra
.971 .122 0 r
.37203 .50303 .37832 .50912 .38867 .50578 .38241 .49966 Metetra
.971 .122 0 r
.38241 .49966 .38867 .50578 .39906 .50242 .39282 .49628 Metetra
.971 .123 0 r
.39282 .49628 .39906 .50242 .40949 .49907 .40328 .4929 Metetra
.971 .123 0 r
.40328 .4929 .40949 .49907 .41996 .4957 .41377 .48951 Metetra
.971 .123 0 r
.41377 .48951 .41996 .4957 .43047 .49233 .42431 .48612 Metetra
.971 .124 0 r
.42431 .48612 .43047 .49233 .44102 .48895 .43488 .48272 Metetra
.971 .124 0 r
.43488 .48272 .44102 .48895 .45161 .48557 .4455 .47931 Metetra
.971 .124 0 r
.4455 .47931 .45161 .48557 .46225 .48218 .45616 .47589 Metetra
.971 .124 0 r
.45616 .47589 .46225 .48218 .47292 .47879 .46686 .47247 Metetra
.971 .123 0 r
.46686 .47247 .47292 .47879 .48364 .47539 .47761 .46905 Metetra
.971 .123 0 r
.47761 .46905 .48364 .47539 .4944 .47198 .48839 .46561 Metetra
.971 .123 0 r
.48839 .46561 .4944 .47198 .5052 .46856 .49922 .46218 Metetra
.971 .122 0 r
.49922 .46218 .5052 .46856 .51604 .46514 .51009 .45873 Metetra
.971 .121 0 r
.51009 .45873 .51604 .46514 .52693 .46172 .52101 .45528 Metetra
.971 .121 0 r
.52101 .45528 .52693 .46172 .53786 .45828 .53197 .45182 Metetra
.972 .12 0 r
.53197 .45182 .53786 .45828 .54884 .45485 .54297 .44836 Metetra
.972 .119 0 r
.54297 .44836 .54884 .45485 .55986 .4514 .55402 .44489 Metetra
.972 .118 0 r
.55402 .44489 .55986 .4514 .57092 .44795 .56512 .44141 Metetra
.972 .116 0 r
.56512 .44141 .57092 .44795 .58203 .44449 .57626 .43792 Metetra
.973 .115 0 r
.57626 .43792 .58203 .44449 .59319 .44102 .58744 .43443 Metetra
.973 .114 0 r
.58744 .43443 .59319 .44102 .60439 .43755 .59867 .43093 Metetra
.973 .112 0 r
.59867 .43093 .60439 .43755 .61563 .43407 .60995 .42743 Metetra
.974 .111 0 r
.60995 .42743 .61563 .43407 .62693 .43059 .62127 .42391 Metetra
.974 .109 0 r
.62127 .42391 .62693 .43059 .63827 .42709 .63264 .42039 Metetra
.975 .107 0 r
.63264 .42039 .63827 .42709 .64965 .42359 .64406 .41687 Metetra
.975 .105 0 r
.64406 .41687 .64965 .42359 .66109 .42009 .65552 .41334 Metetra
.976 .103 0 r
.65552 .41334 .66109 .42009 .67257 .41658 .66704 .4098 Metetra
.976 .101 0 r
.66704 .4098 .67257 .41658 .6841 .41306 .6786 .40625 Metetra
.977 .098 0 r
.6786 .40625 .6841 .41306 .69568 .40953 .69021 .4027 Metetra
.977 .096 0 r
.69021 .4027 .69568 .40953 .70731 .40597 .70187 .39911 Metetra
.978 .095 0 r
.70187 .39911 .70731 .40597 .71898 .4023 .71358 .39541 Metetra
.977 .097 0 r
.71358 .39541 .71898 .4023 .73067 .39827 .72531 .39136 Metetra
.974 .108 0 r
.72531 .39136 .73067 .39827 .74235 .39321 .73702 .38627 Metetra
.965 .145 0 r
.73702 .38627 .74235 .39321 .75388 .38558 .74858 .3786 Metetra
.942 .235 0 r
.74858 .3786 .75388 .38558 .76502 .37259 .75978 .36557 Metetra
.894 .412 0 r
.75978 .36557 .76502 .37259 .77542 .35037 .77024 .34329 Metetra
.805 .68 0 r
.77024 .34329 .77542 .35037 .78467 .31535 .77956 .30821 Metetra
.37 .666 0 r
.77956 .30821 .78467 .31535 .79255 .26667 .78753 .25943 Metetra
.079 .571 0 r
.13375 .4472 .14033 .45296 .14387 .49835 .13719 .49264 Metetra
.631 .736 0 r
.13719 .49264 .14387 .49835 .149 .53208 .14225 .5264 Metetra
.851 .548 0 r
.14225 .5264 .149 .53208 .1558 .55276 .14901 .5471 Metetra
.92 .319 0 r
.14901 .5471 .1558 .55276 .16389 .5627 .1571 .55704 Metetra
.955 .185 0 r
.1571 .55704 .16389 .5627 .17283 .56566 .16604 .55998 Metetra
.971 .123 0 r
.16604 .55998 .17283 .56566 .1822 .5649 .17543 .5592 Metetra
.976 .101 0 r
.17543 .5592 .1822 .5649 .19179 .56248 .18503 .55677 Metetra
.978 .095 0 r
.18503 .55677 .19179 .56248 .20147 .55946 .19474 .55372 Metetra
.978 .095 0 r
.19474 .55372 .20147 .55946 .21121 .55623 .20449 .55048 Metetra
.977 .097 0 r
.20449 .55048 .21121 .55623 .22098 .55296 .21429 .54718 Metetra
.977 .099 0 r
.21429 .54718 .22098 .55296 .2308 .54966 .22413 .54386 Metetra
.976 .102 0 r
.22413 .54386 .2308 .54966 .24064 .54636 .234 .54054 Metetra
.975 .104 0 r
.234 .54054 .24064 .54636 .25053 .54306 .24391 .53721 Metetra
.975 .106 0 r
.24391 .53721 .25053 .54306 .26045 .53975 .25385 .53388 Metetra
.974 .108 0 r
.25385 .53388 .26045 .53975 .2704 .53644 .26383 .53054 Metetra
.974 .11 0 r
.26383 .53054 .2704 .53644 .2804 .53312 .27384 .5272 Metetra
.974 .111 0 r
.27384 .5272 .2804 .53312 .29043 .5298 .2839 .52385 Metetra
.973 .113 0 r
.2839 .52385 .29043 .5298 .3005 .52647 .29399 .52051 Metetra
.973 .114 0 r
.29399 .52051 .3005 .52647 .3106 .52314 .30412 .51715 Metetra
.973 .116 0 r
.30412 .51715 .3106 .52314 .32074 .5198 .31428 .51379 Metetra
.972 .117 0 r
.31428 .51379 .32074 .5198 .33092 .51646 .32449 .51042 Metetra
.972 .118 0 r
.32449 .51042 .33092 .51646 .34114 .51311 .33473 .50705 Metetra
.972 .119 0 r
.33473 .50705 .34114 .51311 .3514 .50975 .34501 .50367 Metetra
.972 .12 0 r
.34501 .50367 .3514 .50975 .3617 .5064 .35533 .50029 Metetra
.971 .121 0 r
.35533 .50029 .3617 .5064 .37203 .50303 .36569 .4969 Metetra
.971 .121 0 r
.36569 .4969 .37203 .50303 .38241 .49966 .37609 .49351 Metetra
.971 .122 0 r
.37609 .49351 .38241 .49966 .39282 .49628 .38653 .4901 Metetra
.971 .123 0 r
.38653 .4901 .39282 .49628 .40328 .4929 .39701 .4867 Metetra
.971 .123 0 r
.39701 .4867 .40328 .4929 .41377 .48951 .40753 .48328 Metetra
.971 .123 0 r
.40753 .48328 .41377 .48951 .42431 .48612 .4181 .47986 Metetra
.971 .123 0 r
.4181 .47986 .42431 .48612 .43488 .48272 .4287 .47644 Metetra
.971 .124 0 r
.4287 .47644 .43488 .48272 .4455 .47931 .43934 .47301 Metetra
.971 .123 0 r
.43934 .47301 .4455 .47931 .45616 .47589 .45003 .46957 Metetra
.971 .123 0 r
.45003 .46957 .45616 .47589 .46686 .47247 .46076 .46612 Metetra
.971 .123 0 r
.46076 .46612 .46686 .47247 .47761 .46905 .47153 .46267 Metetra
.971 .123 0 r
.47153 .46267 .47761 .46905 .48839 .46561 .48234 .45921 Metetra
.971 .122 0 r
.48234 .45921 .48839 .46561 .49922 .46218 .4932 .45575 Metetra
.971 .122 0 r
.4932 .45575 .49922 .46218 .51009 .45873 .5041 .45228 Metetra
.971 .121 0 r
.5041 .45228 .51009 .45873 .52101 .45528 .51505 .4488 Metetra
.971 .12 0 r
.51505 .4488 .52101 .45528 .53197 .45182 .52603 .44531 Metetra
.972 .12 0 r
.52603 .44531 .53197 .45182 .54297 .44836 .53707 .44183 Metetra
.972 .118 0 r
.53707 .44183 .54297 .44836 .55402 .44489 .54814 .43833 Metetra
.972 .117 0 r
.54814 .43833 .55402 .44489 .56512 .44141 .55927 .43483 Metetra
.972 .116 0 r
.55927 .43483 .56512 .44141 .57626 .43792 .57044 .43131 Metetra
.973 .115 0 r
.57044 .43131 .57626 .43792 .58744 .43443 .58165 .4278 Metetra
.973 .114 0 r
.58165 .4278 .58744 .43443 .59867 .43093 .59291 .42427 Metetra
.973 .112 0 r
.59291 .42427 .59867 .43093 .60995 .42743 .60422 .42074 Metetra
.974 .11 0 r
.60422 .42074 .60995 .42743 .62127 .42391 .61557 .4172 Metetra
.974 .109 0 r
.61557 .4172 .62127 .42391 .63264 .42039 .62697 .41365 Metetra
.975 .107 0 r
.62697 .41365 .63264 .42039 .64406 .41687 .63842 .4101 Metetra
.975 .105 0 r
.63842 .4101 .64406 .41687 .65552 .41334 .64992 .40654 Metetra
.976 .103 0 r
.64992 .40654 .65552 .41334 .66704 .4098 .66147 .40298 Metetra
.976 .1 0 r
.66147 .40298 .66704 .4098 .6786 .40625 .67306 .3994 Metetra
.977 .098 0 r
.67306 .3994 .6786 .40625 .69021 .4027 .68471 .39582 Metetra
.977 .096 0 r
.68471 .39582 .69021 .4027 .70187 .39911 .6964 .3922 Metetra
.978 .094 0 r
.6964 .3922 .70187 .39911 .71358 .39541 .70813 .38848 Metetra
.977 .096 0 r
.70813 .38848 .71358 .39541 .72531 .39136 .7199 .3844 Metetra
.974 .108 0 r
.7199 .3844 .72531 .39136 .73702 .38627 .73164 .37928 Metetra
.965 .145 0 r
.73164 .37928 .73702 .38627 .74858 .3786 .74325 .37157 Metetra
.942 .235 0 r
.74325 .37157 .74858 .3786 .75978 .36557 .7545 .3585 Metetra
.894 .412 0 r
.7545 .3585 .75978 .36557 .77024 .34329 .76502 .33617 Metetra
.805 .68 0 r
.76502 .33617 .77024 .34329 .77956 .30821 .77442 .30101 Metetra
.37 .667 0 r
.77442 .30101 .77956 .30821 .78753 .25943 .78248 .25215 Metetra
.08 .571 0 r
.12713 .44139 .13375 .4472 .13719 .49264 .13047 .48688 Metetra
.632 .736 0 r
.13047 .48688 .13719 .49264 .14225 .5264 .13546 .52069 Metetra
.852 .548 0 r
.13546 .52069 .14225 .5264 .14901 .5471 .14218 .5414 Metetra
.92 .318 0 r
.14218 .5414 .14901 .5471 .1571 .55704 .15026 .55134 Metetra
.955 .184 0 r
.15026 .55134 .1571 .55704 .16604 .55998 .1592 .55427 Metetra
.971 .123 0 r
.1592 .55427 .16604 .55998 .17543 .5592 .16861 .55347 Metetra
.976 .1 0 r
.16861 .55347 .17543 .5592 .18503 .55677 .17823 .55101 Metetra
.978 .094 0 r
.17823 .55101 .18503 .55677 .19474 .55372 .18796 .54794 Metetra
.978 .095 0 r
.18796 .54794 .19474 .55372 .20449 .55048 .19774 .54467 Metetra
.977 .097 0 r
.19774 .54467 .20449 .55048 .21429 .54718 .20756 .54135 Metetra
.977 .099 0 r
.20756 .54135 .21429 .54718 .22413 .54386 .21741 .53801 Metetra
.976 .101 0 r
.21741 .53801 .22413 .54386 .234 .54054 .22731 .53467 Metetra
.976 .103 0 r
.22731 .53467 .234 .54054 .24391 .53721 .23724 .53131 Metetra
.975 .105 0 r
.23724 .53131 .24391 .53721 .25385 .53388 .2472 .52796 Metetra
.975 .107 0 r
.2472 .52796 .25385 .53388 .26383 .53054 .2572 .5246 Metetra
.974 .109 0 r
.2572 .5246 .26383 .53054 .27384 .5272 .26724 .52124 Metetra
.974 .111 0 r
.26724 .52124 .27384 .5272 .2839 .52385 .27732 .51787 Metetra
.973 .112 0 r
.27732 .51787 .2839 .52385 .29399 .52051 .28743 .51449 Metetra
.973 .114 0 r
.28743 .51449 .29399 .52051 .30412 .51715 .29759 .51111 Metetra
.973 .115 0 r
.29759 .51111 .30412 .51715 .31428 .51379 .30778 .50773 Metetra
.972 .117 0 r
.30778 .50773 .31428 .51379 .32449 .51042 .318 .50434 Metetra
.972 .118 0 r
.318 .50434 .32449 .51042 .33473 .50705 .32827 .50094 Metetra
.972 .119 0 r
.32827 .50094 .33473 .50705 .34501 .50367 .33858 .49754 Metetra
.972 .12 0 r
.33858 .49754 .34501 .50367 .35533 .50029 .34892 .49413 Metetra
.971 .12 0 r
.34892 .49413 .35533 .50029 .36569 .4969 .35931 .49072 Metetra
.971 .121 0 r
.35931 .49072 .36569 .4969 .37609 .49351 .36973 .4873 Metetra
.971 .122 0 r
.36973 .4873 .37609 .49351 .38653 .4901 .3802 .48387 Metetra
.971 .122 0 r
.3802 .48387 .38653 .4901 .39701 .4867 .39071 .48044 Metetra
.971 .123 0 r
.39071 .48044 .39701 .4867 .40753 .48328 .40125 .47701 Metetra
.971 .123 0 r
.40125 .47701 .40753 .48328 .4181 .47986 .41184 .47356 Metetra
.971 .123 0 r
.41184 .47356 .4181 .47986 .4287 .47644 .42247 .47011 Metetra
.971 .123 0 r
.42247 .47011 .4287 .47644 .43934 .47301 .43314 .46665 Metetra
.971 .123 0 r
.43314 .46665 .43934 .47301 .45003 .46957 .44385 .46319 Metetra
.971 .123 0 r
.44385 .46319 .45003 .46957 .46076 .46612 .45461 .45972 Metetra
.971 .123 0 r
.45461 .45972 .46076 .46612 .47153 .46267 .46541 .45624 Metetra
.971 .123 0 r
.46541 .45624 .47153 .46267 .48234 .45921 .47625 .45276 Metetra
.971 .122 0 r
.47625 .45276 .48234 .45921 .4932 .45575 .48713 .44927 Metetra
.971 .122 0 r
.48713 .44927 .4932 .45575 .5041 .45228 .49806 .44577 Metetra
.971 .121 0 r
.49806 .44577 .5041 .45228 .51505 .4488 .50904 .44227 Metetra
.971 .12 0 r
.50904 .44227 .51505 .4488 .52603 .44531 .52005 .43875 Metetra
.972 .119 0 r
.52005 .43875 .52603 .44531 .53707 .44183 .53111 .43525 Metetra
.972 .118 0 r
.53111 .43525 .53707 .44183 .54814 .43833 .54222 .43172 Metetra
.972 .117 0 r
.54222 .43172 .54814 .43833 .55927 .43483 .55337 .42819 Metetra
.972 .116 0 r
.55337 .42819 .55927 .43483 .57044 .43131 .56457 .42465 Metetra
.973 .115 0 r
.56457 .42465 .57044 .43131 .58165 .4278 .57582 .42111 Metetra
.973 .113 0 r
.57582 .42111 .58165 .4278 .59291 .42427 .58711 .41755 Metetra
.974 .112 0 r
.58711 .41755 .59291 .42427 .60422 .42074 .59845 .41399 Metetra
.974 .11 0 r
.59845 .41399 .60422 .42074 .61557 .4172 .60983 .41043 Metetra
.974 .108 0 r
.60983 .41043 .61557 .4172 .62697 .41365 .62126 .40686 Metetra
.975 .106 0 r
.62126 .40686 .62697 .41365 .63842 .4101 .63274 .40328 Metetra
.975 .104 0 r
.63274 .40328 .63842 .4101 .64992 .40654 .64427 .39969 Metetra
.976 .102 0 r
.64427 .39969 .64992 .40654 .66147 .40298 .65585 .3961 Metetra
.976 .1 0 r
.65585 .3961 .66147 .40298 .67306 .3994 .66748 .3925 Metetra
.977 .098 0 r
.66748 .3925 .67306 .3994 .68471 .39582 .67916 .38888 Metetra
.977 .096 0 r
.67916 .38888 .68471 .39582 .6964 .3922 .69088 .38524 Metetra
.978 .094 0 r
.69088 .38524 .6964 .3922 .70813 .38848 .70265 .38149 Metetra
.977 .096 0 r
.70265 .38149 .70813 .38848 .7199 .3844 .71445 .37738 Metetra
.975 .107 0 r
.71445 .37738 .7199 .3844 .73164 .37928 .72623 .37223 Metetra
.966 .144 0 r
.72623 .37223 .73164 .37928 .74325 .37157 .73788 .36449 Metetra
.943 .234 0 r
.73788 .36449 .74325 .37157 .7545 .3585 .74917 .35138 Metetra
.894 .411 0 r
.74917 .35138 .7545 .3585 .76502 .33617 .75975 .32899 Metetra
.805 .68 0 r
.75975 .32899 .76502 .33617 .77442 .30101 .76923 .29376 Metetra
.371 .667 0 r
.76923 .29376 .77442 .30101 .78248 .25215 .77739 .2448 Metetra
.08 .571 0 r
.12046 .43555 .12713 .44139 .13047 .48688 .1237 .4811 Metetra
.633 .737 0 r
.1237 .4811 .13047 .48688 .13546 .52069 .12862 .51494 Metetra
.852 .547 0 r
.12862 .51494 .13546 .52069 .14218 .5414 .1353 .53567 Metetra
.92 .318 0 r
.1353 .53567 .14218 .5414 .15026 .55134 .14337 .54561 Metetra
.956 .184 0 r
.14337 .54561 .15026 .55134 .1592 .55427 .15232 .54852 Metetra
.971 .122 0 r
.15232 .54852 .1592 .55427 .16861 .55347 .16174 .5477 Metetra
.976 .1 0 r
.16174 .5477 .16861 .55347 .17823 .55101 .17138 .54522 Metetra
.978 .094 0 r
.17138 .54522 .17823 .55101 .18796 .54794 .18113 .54213 Metetra
.978 .094 0 r
.18113 .54213 .18796 .54794 .19774 .54467 .19093 .53884 Metetra
.977 .096 0 r
.19093 .53884 .19774 .54467 .20756 .54135 .20077 .53549 Metetra
.977 .099 0 r
.20077 .53549 .20756 .54135 .21741 .53801 .21065 .53213 Metetra
.976 .101 0 r
.21065 .53213 .21741 .53801 .22731 .53467 .22057 .52876 Metetra
.976 .103 0 r
.22057 .52876 .22731 .53467 .23724 .53131 .23052 .52538 Metetra
.975 .105 0 r
.23052 .52538 .23724 .53131 .2472 .52796 .24051 .52201 Metetra
.975 .107 0 r
.24051 .52201 .2472 .52796 .2572 .5246 .25053 .51862 Metetra
.974 .109 0 r
.25053 .51862 .2572 .5246 .26724 .52124 .26059 .51524 Metetra
.974 .111 0 r
.26059 .51524 .26724 .52124 .27732 .51787 .27069 .51184 Metetra
.973 .112 0 r
.27069 .51184 .27732 .51787 .28743 .51449 .28083 .50845 Metetra
.973 .114 0 r
.28083 .50845 .28743 .51449 .29759 .51111 .29101 .50504 Metetra
.973 .115 0 r
.29101 .50504 .29759 .51111 .30778 .50773 .30122 .50163 Metetra
.972 .116 0 r
.30122 .50163 .30778 .50773 .318 .50434 .31148 .49822 Metetra
.972 .117 0 r
.31148 .49822 .318 .50434 .32827 .50094 .32177 .4948 Metetra
.972 .118 0 r
.32177 .4948 .32827 .50094 .33858 .49754 .3321 .49137 Metetra
.972 .119 0 r
.3321 .49137 .33858 .49754 .34892 .49413 .34247 .48794 Metetra
.971 .12 0 r
.34247 .48794 .34892 .49413 .35931 .49072 .35288 .4845 Metetra
.971 .121 0 r
.35288 .4845 .35931 .49072 .36973 .4873 .36333 .48106 Metetra
.971 .122 0 r
.36333 .48106 .36973 .4873 .3802 .48387 .37382 .47761 Metetra
.971 .122 0 r
.37382 .47761 .3802 .48387 .39071 .48044 .38435 .47415 Metetra
.971 .122 0 r
.38435 .47415 .39071 .48044 .40125 .47701 .39492 .47069 Metetra
.971 .123 0 r
.39492 .47069 .40125 .47701 .41184 .47356 .40554 .46722 Metetra
.971 .123 0 r
.40554 .46722 .41184 .47356 .42247 .47011 .41619 .46374 Metetra
.971 .123 0 r
.41619 .46374 .42247 .47011 .43314 .46665 .42689 .46026 Metetra
.971 .123 0 r
.42689 .46026 .43314 .46665 .44385 .46319 .43763 .45677 Metetra
.971 .123 0 r
.43763 .45677 .44385 .46319 .45461 .45972 .44842 .45328 Metetra
.971 .123 0 r
.44842 .45328 .45461 .45972 .46541 .45624 .45924 .44977 Metetra
.971 .122 0 r
.45924 .44977 .46541 .45624 .47625 .45276 .47011 .44626 Metetra
.971 .122 0 r
.47011 .44626 .47625 .45276 .48713 .44927 .48102 .44275 Metetra
.971 .121 0 r
.48102 .44275 .48713 .44927 .49806 .44577 .49198 .43922 Metetra
.971 .121 0 r
.49198 .43922 .49806 .44577 .50904 .44227 .50298 .43569 Metetra
.972 .12 0 r
.50298 .43569 .50904 .44227 .52005 .43875 .51403 .43216 Metetra
.972 .119 0 r
.51403 .43216 .52005 .43875 .53111 .43525 .52512 .42862 Metetra
.972 .118 0 r
.52512 .42862 .53111 .43525 .54222 .43172 .53625 .42507 Metetra
.972 .117 0 r
.53625 .42507 .54222 .43172 .55337 .42819 .54744 .42151 Metetra
.973 .116 0 r
.54744 .42151 .55337 .42819 .56457 .42465 .55866 .41795 Metetra
.973 .114 0 r
.55866 .41795 .56457 .42465 .57582 .42111 .56994 .41437 Metetra
.973 .113 0 r
.56994 .41437 .57582 .42111 .58711 .41755 .58126 .41079 Metetra
.974 .111 0 r
.58126 .41079 .58711 .41755 .59845 .41399 .59263 .40721 Metetra
.974 .11 0 r
.59263 .40721 .59845 .41399 .60983 .41043 .60405 .40362 Metetra
.974 .108 0 r
.60405 .40362 .60983 .41043 .62126 .40686 .61551 .40002 Metetra
.975 .106 0 r
.61551 .40002 .62126 .40686 .63274 .40328 .62702 .39641 Metetra
.975 .104 0 r
.62702 .39641 .63274 .40328 .64427 .39969 .63858 .39279 Metetra
.976 .102 0 r
.63858 .39279 .64427 .39969 .65585 .3961 .65019 .38917 Metetra
.976 .1 0 r
.65019 .38917 .65585 .3961 .66748 .3925 .66185 .38554 Metetra
.977 .097 0 r
.66185 .38554 .66748 .3925 .67916 .38888 .67356 .3819 Metetra
.978 .095 0 r
.67356 .3819 .67916 .38888 .69088 .38524 .68532 .37823 Metetra
.978 .094 0 r
.68532 .37823 .69088 .38524 .70265 .38149 .69713 .37445 Metetra
.977 .095 0 r
.69713 .37445 .70265 .38149 .71445 .37738 .70896 .37031 Metetra
.975 .107 0 r
.70896 .37031 .71445 .37738 .72623 .37223 .72078 .36513 Metetra
.966 .144 0 r
.72078 .36513 .72623 .37223 .73788 .36449 .73247 .35736 Metetra
.943 .234 0 r
.73247 .35736 .73788 .36449 .74917 .35138 .74381 .3442 Metetra
.894 .411 0 r
.74381 .3442 .74917 .35138 .75975 .32899 .75445 .32177 Metetra
.805 .679 0 r
.75445 .32177 .75975 .32899 .76923 .29376 .76401 .28646 Metetra
.371 .667 0 r
.76401 .28646 .76923 .29376 .77739 .2448 .77226 .23742 Metetra
.081 .571 0 r
.11374 .42967 .12046 .43555 .1237 .4811 .11688 .47528 Metetra
.633 .737 0 r
.11688 .47528 .1237 .4811 .12862 .51494 .12173 .50915 Metetra
.852 .547 0 r
.12173 .50915 .12862 .51494 .1353 .53567 .12838 .52989 Metetra
.92 .317 0 r
.12838 .52989 .1353 .53567 .14337 .54561 .13643 .53983 Metetra
.956 .183 0 r
.13643 .53983 .14337 .54561 .15232 .54852 .14539 .54272 Metetra
.971 .122 0 r
.14539 .54272 .15232 .54852 .16174 .5477 .15482 .54189 Metetra
.977 .099 0 r
.15482 .54189 .16174 .5477 .17138 .54522 .16449 .53939 Metetra
.978 .094 0 r
.16449 .53939 .17138 .54522 .18113 .54213 .17425 .53627 Metetra
.978 .094 0 r
.17425 .53627 .18113 .54213 .19093 .53884 .18408 .53296 Metetra
.977 .096 0 r
.18408 .53296 .19093 .53884 .20077 .53549 .19394 .52959 Metetra
.977 .098 0 r
.19394 .52959 .20077 .53549 .21065 .53213 .20384 .5262 Metetra
.976 .1 0 r
.20384 .5262 .21065 .53213 .22057 .52876 .21378 .52281 Metetra
.976 .103 0 r
.21378 .52281 .22057 .52876 .23052 .52538 .22375 .51941 Metetra
.975 .105 0 r
.22375 .51941 .23052 .52538 .24051 .52201 .23377 .51601 Metetra
.975 .107 0 r
.23377 .51601 .24051 .52201 .25053 .51862 .24381 .5126 Metetra
.974 .109 0 r
.24381 .5126 .25053 .51862 .26059 .51524 .2539 .50919 Metetra
.974 .11 0 r
.2539 .50919 .26059 .51524 .27069 .51184 .26402 .50577 Metetra
.973 .112 0 r
.26402 .50577 .27069 .51184 .28083 .50845 .27418 .50235 Metetra
.973 .113 0 r
.27418 .50235 .28083 .50845 .29101 .50504 .28438 .49892 Metetra
.973 .115 0 r
.28438 .49892 .29101 .50504 .30122 .50163 .29462 .49549 Metetra
.972 .116 0 r
.29462 .49549 .30122 .50163 .31148 .49822 .3049 .49205 Metetra
.972 .117 0 r
.3049 .49205 .31148 .49822 .32177 .4948 .31522 .48861 Metetra
.972 .118 0 r
.31522 .48861 .32177 .4948 .3321 .49137 .32557 .48516 Metetra
.972 .119 0 r
.32557 .48516 .3321 .49137 .34247 .48794 .33597 .4817 Metetra
.972 .12 0 r
.33597 .4817 .34247 .48794 .35288 .4845 .3464 .47824 Metetra
.971 .121 0 r
.3464 .47824 .35288 .4845 .36333 .48106 .35688 .47477 Metetra
.971 .121 0 r
.35688 .47477 .36333 .48106 .37382 .47761 .36739 .47129 Metetra
.971 .122 0 r
.36739 .47129 .37382 .47761 .38435 .47415 .37795 .46781 Metetra
.971 .122 0 r
.37795 .46781 .38435 .47415 .39492 .47069 .38855 .46432 Metetra
.971 .122 0 r
.38855 .46432 .39492 .47069 .40554 .46722 .39919 .46083 Metetra
.971 .123 0 r
.39919 .46083 .40554 .46722 .41619 .46374 .40987 .45733 Metetra
.971 .123 0 r
.40987 .45733 .41619 .46374 .42689 .46026 .4206 .45382 Metetra
.971 .123 0 r
.4206 .45382 .42689 .46026 .43763 .45677 .43137 .4503 Metetra
.971 .123 0 r
.43137 .4503 .43763 .45677 .44842 .45328 .44218 .44678 Metetra
.971 .122 0 r
.44218 .44678 .44842 .45328 .45924 .44977 .45303 .44325 Metetra
.971 .122 0 r
.45303 .44325 .45924 .44977 .47011 .44626 .46393 .43972 Metetra
.971 .122 0 r
.46393 .43972 .47011 .44626 .48102 .44275 .47487 .43617 Metetra
.971 .121 0 r
.47487 .43617 .48102 .44275 .49198 .43922 .48585 .43262 Metetra
.971 .12 0 r
.48585 .43262 .49198 .43922 .50298 .43569 .49688 .42907 Metetra
.972 .12 0 r
.49688 .42907 .50298 .43569 .51403 .43216 .50796 .4255 Metetra
.972 .119 0 r
.50796 .4255 .51403 .43216 .52512 .42862 .51908 .42194 Metetra
.972 .118 0 r
.51908 .42194 .52512 .42862 .53625 .42507 .53024 .41836 Metetra
.972 .116 0 r
.53024 .41836 .53625 .42507 .54744 .42151 .54145 .41478 Metetra
.973 .115 0 r
.54145 .41478 .54744 .42151 .55866 .41795 .55271 .41119 Metetra
.973 .114 0 r
.55271 .41119 .55866 .41795 .56994 .41437 .56402 .40759 Metetra
.973 .113 0 r
.56402 .40759 .56994 .41437 .58126 .41079 .57537 .40398 Metetra
.974 .111 0 r
.57537 .40398 .58126 .41079 .59263 .40721 .58677 .40037 Metetra
.974 .109 0 r
.58677 .40037 .59263 .40721 .60405 .40362 .59822 .39675 Metetra
.975 .108 0 r
.59822 .39675 .60405 .40362 .61551 .40002 .60971 .39312 Metetra
.975 .106 0 r
.60971 .39312 .61551 .40002 .62702 .39641 .62126 .38948 Metetra
.975 .104 0 r
.62126 .38948 .62702 .39641 .63858 .39279 .63285 .38584 Metetra
.976 .102 0 r
.63285 .38584 .63858 .39279 .65019 .38917 .64449 .38219 Metetra
.977 .099 0 r
.64449 .38219 .65019 .38917 .66185 .38554 .65618 .37853 Metetra
.977 .097 0 r
.65618 .37853 .66185 .38554 .67356 .3819 .66793 .37487 Metetra
.978 .095 0 r
.66793 .37487 .67356 .3819 .68532 .37823 .67972 .37116 Metetra
.978 .093 0 r
.67972 .37116 .68532 .37823 .69713 .37445 .69156 .36736 Metetra
.978 .095 0 r
.69156 .36736 .69713 .37445 .70896 .37031 .70343 .36319 Metetra
.975 .106 0 r
.70343 .36319 .70896 .37031 .72078 .36513 .71528 .35798 Metetra
.966 .143 0 r
.71528 .35798 .72078 .36513 .73247 .35736 .72701 .35017 Metetra
.943 .234 0 r
.72701 .35017 .73247 .35736 .74381 .3442 .7384 .33697 Metetra
.894 .41 0 r
.7384 .33697 .74381 .3442 .75445 .32177 .7491 .31448 Metetra
.806 .679 0 r
.7491 .31448 .75445 .32177 .76401 .28646 .75874 .27911 Metetra
.372 .667 0 r
.75874 .27911 .76401 .28646 .77226 .23742 .76709 .22997 Metetra
.081 .571 0 r
.10698 .42376 .11374 .42967 .11688 .47528 .11002 .46942 Metetra
.634 .737 0 r
.11002 .46942 .11688 .47528 .12173 .50915 .1148 .50333 Metetra
.852 .547 0 r
.1148 .50333 .12173 .50915 .12838 .52989 .1214 .52408 Metetra
.921 .317 0 r
.1214 .52408 .12838 .52989 .13643 .53983 .12944 .53402 Metetra
.956 .183 0 r
.12944 .53402 .13643 .53983 .14539 .54272 .13841 .5369 Metetra
.971 .121 0 r
.13841 .5369 .14539 .54272 .15482 .54189 .14786 .53604 Metetra
.977 .099 0 r
.14786 .53604 .15482 .54189 .16449 .53939 .15754 .53352 Metetra
.978 .093 0 r
.15754 .53352 .16449 .53939 .17425 .53627 .16733 .53038 Metetra
.978 .093 0 r
.16733 .53038 .17425 .53627 .18408 .53296 .17717 .52704 Metetra
.977 .095 0 r
.17717 .52704 .18408 .53296 .19394 .52959 .18706 .52365 Metetra
.977 .098 0 r
.18706 .52365 .19394 .52959 .20384 .5262 .19698 .52024 Metetra
.976 .1 0 r
.19698 .52024 .20384 .5262 .21378 .52281 .20694 .51682 Metetra
.976 .102 0 r
.20694 .51682 .21378 .52281 .22375 .51941 .21694 .5134 Metetra
.975 .104 0 r
.21694 .5134 .22375 .51941 .23377 .51601 .22697 .50998 Metetra
.975 .106 0 r
.22697 .50998 .23377 .51601 .24381 .5126 .23705 .50654 Metetra
.974 .108 0 r
.23705 .50654 .24381 .5126 .2539 .50919 .24716 .50311 Metetra
.974 .11 0 r
.24716 .50311 .2539 .50919 .26402 .50577 .2573 .49967 Metetra
.974 .111 0 r
.2573 .49967 .26402 .50577 .27418 .50235 .26749 .49622 Metetra
.973 .113 0 r
.26749 .49622 .27418 .50235 .28438 .49892 .27771 .49277 Metetra
.973 .114 0 r
.27771 .49277 .28438 .49892 .29462 .49549 .28797 .48931 Metetra
.973 .116 0 r
.28797 .48931 .29462 .49549 .3049 .49205 .29828 .48585 Metetra
.972 .117 0 r
.29828 .48585 .3049 .49205 .31522 .48861 .30862 .48238 Metetra
.972 .118 0 r
.30862 .48238 .31522 .48861 .32557 .48516 .319 .4789 Metetra
.972 .119 0 r
.319 .4789 .32557 .48516 .33597 .4817 .32942 .47542 Metetra
.972 .12 0 r
.32942 .47542 .33597 .4817 .3464 .47824 .33988 .47193 Metetra
.971 .12 0 r
.33988 .47193 .3464 .47824 .35688 .47477 .35038 .46844 Metetra
.971 .121 0 r
.35038 .46844 .35688 .47477 .36739 .47129 .36092 .46494 Metetra
.971 .121 0 r
.36092 .46494 .36739 .47129 .37795 .46781 .3715 .46143 Metetra
.971 .122 0 r
.3715 .46143 .37795 .46781 .38855 .46432 .38213 .45792 Metetra
.971 .122 0 r
.38213 .45792 .38855 .46432 .39919 .46083 .3928 .4544 Metetra
.971 .122 0 r
.3928 .4544 .39919 .46083 .40987 .45733 .40351 .45087 Metetra
.971 .122 0 r
.40351 .45087 .40987 .45733 .4206 .45382 .41426 .44733 Metetra
.971 .122 0 r
.41426 .44733 .4206 .45382 .43137 .4503 .42505 .44379 Metetra
.971 .122 0 r
.42505 .44379 .43137 .4503 .44218 .44678 .43589 .44025 Metetra
.971 .122 0 r
.43589 .44025 .44218 .44678 .45303 .44325 .44677 .43669 Metetra
.971 .122 0 r
.44677 .43669 .45303 .44325 .46393 .43972 .4577 .43313 Metetra
.971 .121 0 r
.4577 .43313 .46393 .43972 .47487 .43617 .46867 .42956 Metetra
.971 .121 0 r
.46867 .42956 .47487 .43617 .48585 .43262 .47968 .42598 Metetra
.972 .12 0 r
.47968 .42598 .48585 .43262 .49688 .42907 .49074 .4224 Metetra
.972 .119 0 r
.49074 .4224 .49688 .42907 .50796 .4255 .50184 .41881 Metetra
.972 .118 0 r
.50184 .41881 .50796 .4255 .51908 .42194 .51299 .41522 Metetra
.972 .117 0 r
.51299 .41522 .51908 .42194 .53024 .41836 .52419 .41162 Metetra
.972 .116 0 r
.52419 .41162 .53024 .41836 .54145 .41478 .53543 .408 Metetra
.973 .115 0 r
.53543 .408 .54145 .41478 .55271 .41119 .54672 .40438 Metetra
.973 .114 0 r
.54672 .40438 .55271 .41119 .56402 .40759 .55805 .40076 Metetra
.973 .112 0 r
.55805 .40076 .56402 .40759 .57537 .40398 .56943 .39712 Metetra
.974 .111 0 r
.56943 .39712 .57537 .40398 .58677 .40037 .58086 .39348 Metetra
.974 .109 0 r
.58086 .39348 .58677 .40037 .59822 .39675 .59234 .38983 Metetra
.975 .107 0 r
.59234 .38983 .59822 .39675 .60971 .39312 .60387 .38618 Metetra
.975 .105 0 r
.60387 .38618 .60971 .39312 .62126 .38948 .61545 .38251 Metetra
.976 .103 0 r
.61545 .38251 .62126 .38948 .63285 .38584 .62707 .37884 Metetra
.976 .101 0 r
.62707 .37884 .63285 .38584 .64449 .38219 .63875 .37517 Metetra
.977 .099 0 r
.63875 .37517 .64449 .38219 .65618 .37853 .65047 .37148 Metetra
.977 .097 0 r
.65047 .37148 .65618 .37853 .66793 .37487 .66225 .36778 Metetra
.978 .094 0 r
.66225 .36778 .66793 .37487 .67972 .37116 .67407 .36405 Metetra
.978 .093 0 r
.67407 .36405 .67972 .37116 .69156 .36736 .68595 .36021 Metetra
.978 .095 0 r
.68595 .36021 .69156 .36736 .70343 .36319 .69785 .35602 Metetra
.975 .106 0 r
.69785 .35602 .70343 .36319 .71528 .35798 .70974 .35078 Metetra
.966 .143 0 r
.70974 .35078 .71528 .35798 .72701 .35017 .72151 .34294 Metetra
.943 .233 0 r
.72151 .34294 .72701 .35017 .7384 .33697 .73295 .3297 Metetra
.894 .41 0 r
.73295 .3297 .7384 .33697 .7491 .31448 .74372 .30715 Metetra
.806 .678 0 r
.74372 .30715 .7491 .31448 .75874 .27911 .75344 .2717 Metetra
.372 .667 0 r
.75344 .2717 .75874 .27911 .76709 .22997 .76189 .22247 Metetra
.082 .572 0 r
.10018 .41781 .10698 .42376 .11002 .46942 .10311 .46352 Metetra
.635 .737 0 r
.10311 .46352 .11002 .46942 .1148 .50333 .10781 .49747 Metetra
.852 .546 0 r
.10781 .49747 .1148 .50333 .1214 .52408 .11438 .51823 Metetra
.921 .316 0 r
.11438 .51823 .1214 .52408 .12944 .53402 .12241 .52816 Metetra
.956 .182 0 r
.12241 .52816 .12944 .53402 .13841 .5369 .13138 .53103 Metetra
.971 .121 0 r
.13138 .53103 .13841 .5369 .14786 .53604 .14084 .53015 Metetra
.977 .098 0 r
.14084 .53015 .14786 .53604 .15754 .53352 .15055 .52761 Metetra
.978 .093 0 r
.15055 .52761 .15754 .53352 .16733 .53038 .16035 .52445 Metetra
.978 .093 0 r
.16035 .52445 .16733 .53038 .17717 .52704 .17022 .52108 Metetra
.978 .095 0 r
.17022 .52108 .17717 .52704 .18706 .52365 .18013 .51767 Metetra
.977 .097 0 r
.18013 .51767 .18706 .52365 .19698 .52024 .19008 .51423 Metetra
.976 .1 0 r
.19008 .51423 .19698 .52024 .20694 .51682 .20006 .51079 Metetra
.976 .102 0 r
.20006 .51079 .20694 .51682 .21694 .5134 .21008 .50734 Metetra
.975 .104 0 r
.21008 .50734 .21694 .5134 .22697 .50998 .22014 .5039 Metetra
.975 .106 0 r
.22014 .5039 .22697 .50998 .23705 .50654 .23023 .50044 Metetra
.974 .108 0 r
.23023 .50044 .23705 .50654 .24716 .50311 .24036 .49698 Metetra
.974 .109 0 r
.24036 .49698 .24716 .50311 .2573 .49967 .25053 .49351 Metetra
.974 .111 0 r
.25053 .49351 .2573 .49967 .26749 .49622 .26074 .49004 Metetra
.973 .113 0 r
.26074 .49004 .26749 .49622 .27771 .49277 .27099 .48656 Metetra
.973 .114 0 r
.27099 .48656 .27771 .49277 .28797 .48931 .28128 .48308 Metetra
.973 .115 0 r
.28128 .48308 .28797 .48931 .29828 .48585 .2916 .47959 Metetra
.972 .116 0 r
.2916 .47959 .29828 .48585 .30862 .48238 .30197 .4761 Metetra
.972 .117 0 r
.30197 .4761 .30862 .48238 .319 .4789 .31237 .4726 Metetra
.972 .118 0 r
.31237 .4726 .319 .4789 .32942 .47542 .32282 .46909 Metetra
.972 .119 0 r
.32282 .46909 .32942 .47542 .33988 .47193 .33331 .46558 Metetra
.972 .12 0 r
.33331 .46558 .33988 .47193 .35038 .46844 .34383 .46206 Metetra
.971 .121 0 r
.34383 .46206 .35038 .46844 .36092 .46494 .3544 .45853 Metetra
.971 .121 0 r
.3544 .45853 .36092 .46494 .3715 .46143 .36501 .455 Metetra
.971 .121 0 r
.36501 .455 .3715 .46143 .38213 .45792 .37566 .45146 Metetra
.971 .122 0 r
.37566 .45146 .38213 .45792 .3928 .4544 .38636 .44791 Metetra
.971 .122 0 r
.38636 .44791 .3928 .4544 .40351 .45087 .39709 .44436 Metetra
.971 .122 0 r
.39709 .44436 .40351 .45087 .41426 .44733 .40787 .4408 Metetra
.971 .122 0 r
.40787 .4408 .41426 .44733 .42505 .44379 .41869 .43723 Metetra
.971 .122 0 r
.41869 .43723 .42505 .44379 .43589 .44025 .42956 .43366 Metetra
.971 .122 0 r
.42956 .43366 .43589 .44025 .44677 .43669 .44047 .43008 Metetra
.971 .121 0 r
.44047 .43008 .44677 .43669 .4577 .43313 .45142 .42649 Metetra
.971 .121 0 r
.45142 .42649 .4577 .43313 .46867 .42956 .46242 .42289 Metetra
.971 .12 0 r
.46242 .42289 .46867 .42956 .47968 .42598 .47346 .41929 Metetra
.972 .12 0 r
.47346 .41929 .47968 .42598 .49074 .4224 .48455 .41568 Metetra
.972 .119 0 r
.48455 .41568 .49074 .4224 .50184 .41881 .49568 .41206 Metetra
.972 .118 0 r
.49568 .41206 .50184 .41881 .51299 .41522 .50686 .40844 Metetra
.972 .117 0 r
.50686 .40844 .51299 .41522 .52419 .41162 .51808 .40481 Metetra
.973 .116 0 r
.51808 .40481 .52419 .41162 .53543 .408 .52935 .40117 Metetra
.973 .115 0 r
.52935 .40117 .53543 .408 .54672 .40438 .54067 .39752 Metetra
.973 .113 0 r
.54067 .39752 .54672 .40438 .55805 .40076 .55204 .39387 Metetra
.973 .112 0 r
.55204 .39387 .55805 .40076 .56943 .39712 .56345 .39021 Metetra
.974 .11 0 r
.56345 .39021 .56943 .39712 .58086 .39348 .57491 .38654 Metetra
.974 .109 0 r
.57491 .38654 .58086 .39348 .59234 .38983 .58642 .38286 Metetra
.975 .107 0 r
.58642 .38286 .59234 .38983 .60387 .38618 .59798 .37918 Metetra
.975 .105 0 r
.59798 .37918 .60387 .38618 .61545 .38251 .60959 .37549 Metetra
.976 .103 0 r
.60959 .37549 .61545 .38251 .62707 .37884 .62125 .37179 Metetra
.976 .101 0 r
.62125 .37179 .62707 .37884 .63875 .37517 .63296 .36808 Metetra
.977 .098 0 r
.63296 .36808 .63875 .37517 .65047 .37148 .64472 .36437 Metetra
.977 .096 0 r
.64472 .36437 .65047 .37148 .66225 .36778 .65653 .36064 Metetra
.978 .094 0 r
.65653 .36064 .66225 .36778 .67407 .36405 .66839 .35688 Metetra
.978 .092 0 r
.66839 .35688 .67407 .36405 .68595 .36021 .68029 .35301 Metetra
.978 .094 0 r
.68029 .35301 .68595 .36021 .69785 .35602 .69223 .34878 Metetra
.975 .105 0 r
.69223 .34878 .69785 .35602 .70974 .35078 .70416 .34351 Metetra
.966 .142 0 r
.70416 .34351 .70974 .35078 .72151 .34294 .71597 .33564 Metetra
.943 .232 0 r
.71597 .33564 .72151 .34294 .73295 .3297 .72746 .32236 Metetra
.894 .409 0 r
.72746 .32236 .73295 .3297 .74372 .30715 .73829 .29976 Metetra
.806 .678 0 r
.73829 .29976 .74372 .30715 .75344 .2717 .74809 .26423 Metetra
.373 .667 0 r
.74809 .26423 .75344 .2717 .76189 .22247 .75664 .21491 Metetra
.082 .572 0 r
.09333 .41183 .10018 .41781 .10311 .46352 .09615 .45759 Metetra
.636 .737 0 r
.09615 .45759 .10311 .46352 .10781 .49747 .10078 .49157 Metetra
.852 .545 0 r
.10078 .49157 .10781 .49747 .11438 .51823 .1073 .51235 Metetra
.921 .316 0 r
.1073 .51235 .11438 .51823 .12241 .52816 .11532 .52227 Metetra
.956 .182 0 r
.11532 .52227 .12241 .52816 .13138 .53103 .1243 .52513 Metetra
.971 .12 0 r
.1243 .52513 .13138 .53103 .14084 .53015 .13378 .52423 Metetra
.977 .098 0 r
.13378 .52423 .14084 .53015 .15055 .52761 .1435 .52166 Metetra
.978 .092 0 r
.1435 .52166 .15055 .52761 .16035 .52445 .15333 .51848 Metetra
.978 .092 0 r
.15333 .51848 .16035 .52445 .17022 .52108 .16322 .51509 Metetra
.978 .094 0 r
.16322 .51509 .17022 .52108 .18013 .51767 .17315 .51165 Metetra
.977 .097 0 r
.17315 .51165 .18013 .51767 .19008 .51423 .18312 .50819 Metetra
.977 .099 0 r
.18312 .50819 .19008 .51423 .20006 .51079 .19312 .50472 Metetra
.976 .101 0 r
.19312 .50472 .20006 .51079 .21008 .50734 .20317 .50125 Metetra
.976 .103 0 r
.20317 .50125 .21008 .50734 .22014 .5039 .21325 .49778 Metetra
.975 .105 0 r
.21325 .49778 .22014 .5039 .23023 .50044 .22337 .4943 Metetra
.975 .107 0 r
.22337 .4943 .23023 .50044 .24036 .49698 .23352 .49081 Metetra
.974 .109 0 r
.23352 .49081 .24036 .49698 .25053 .49351 .24372 .48732 Metetra
.974 .111 0 r
.24372 .48732 .25053 .49351 .26074 .49004 .25395 .48383 Metetra
.973 .112 0 r
.25395 .48383 .26074 .49004 .27099 .48656 .26422 .48032 Metetra
.973 .114 0 r
.26422 .48032 .27099 .48656 .28128 .48308 .27453 .47682 Metetra
.973 .115 0 r
.27453 .47682 .28128 .48308 .2916 .47959 .28488 .4733 Metetra
.972 .116 0 r
.28488 .4733 .2916 .47959 .30197 .4761 .29527 .46978 Metetra
.972 .117 0 r
.29527 .46978 .30197 .4761 .31237 .4726 .3057 .46626 Metetra
.972 .118 0 r
.3057 .46626 .31237 .4726 .32282 .46909 .31617 .46272 Metetra
.972 .119 0 r
.31617 .46272 .32282 .46909 .33331 .46558 .32669 .45918 Metetra
.972 .12 0 r
.32669 .45918 .33331 .46558 .34383 .46206 .33724 .45564 Metetra
.971 .12 0 r
.33724 .45564 .34383 .46206 .3544 .45853 .34783 .45209 Metetra
.971 .121 0 r
.34783 .45209 .3544 .45853 .36501 .455 .35847 .44853 Metetra
.971 .121 0 r
.35847 .44853 .36501 .455 .37566 .45146 .36915 .44496 Metetra
.971 .121 0 r
.36915 .44496 .37566 .45146 .38636 .44791 .37987 .44139 Metetra
.971 .122 0 r
.37987 .44139 .38636 .44791 .39709 .44436 .39063 .43781 Metetra
.971 .122 0 r
.39063 .43781 .39709 .44436 .40787 .4408 .40143 .43422 Metetra
.971 .122 0 r
.40143 .43422 .40787 .4408 .41869 .43723 .41228 .43063 Metetra
.971 .121 0 r
.41228 .43063 .41869 .43723 .42956 .43366 .42318 .42703 Metetra
.971 .121 0 r
.42318 .42703 .42956 .43366 .44047 .43008 .43411 .42342 Metetra
.971 .121 0 r
.43411 .42342 .44047 .43008 .45142 .42649 .44509 .4198 Metetra
.971 .12 0 r
.44509 .4198 .45142 .42649 .46242 .42289 .45612 .41618 Metetra
.972 .12 0 r
.45612 .41618 .46242 .42289 .47346 .41929 .46719 .41255 Metetra
.972 .119 0 r
.46719 .41255 .47346 .41929 .48455 .41568 .47831 .40891 Metetra
.972 .118 0 r
.47831 .40891 .48455 .41568 .49568 .41206 .48947 .40527 Metetra
.972 .118 0 r
.48947 .40527 .49568 .41206 .50686 .40844 .50068 .40162 Metetra
.972 .116 0 r
.50068 .40162 .50686 .40844 .51808 .40481 .51193 .39796 Metetra
.973 .115 0 r
.51193 .39796 .51808 .40481 .52935 .40117 .52323 .3943 Metetra
.973 .114 0 r
.52323 .3943 .52935 .40117 .54067 .39752 .53458 .39062 Metetra
.973 .113 0 r
.53458 .39062 .54067 .39752 .55204 .39387 .54598 .38694 Metetra
.974 .111 0 r
.54598 .38694 .55204 .39387 .56345 .39021 .55742 .38325 Metetra
.974 .11 0 r
.55742 .38325 .56345 .39021 .57491 .38654 .56892 .37955 Metetra
.974 .108 0 r
.56892 .37955 .57491 .38654 .58642 .38286 .58046 .37585 Metetra
.975 .106 0 r
.58046 .37585 .58642 .38286 .59798 .37918 .59205 .37213 Metetra
.975 .104 0 r
.59205 .37213 .59798 .37918 .60959 .37549 .60369 .36841 Metetra
.976 .102 0 r
.60369 .36841 .60959 .37549 .62125 .37179 .61538 .36468 Metetra
.976 .1 0 r
.61538 .36468 .62125 .37179 .63296 .36808 .62712 .36095 Metetra
.977 .098 0 r
.62712 .36095 .63296 .36808 .64472 .36437 .63892 .35721 Metetra
.977 .096 0 r
.63892 .35721 .64472 .36437 .65653 .36064 .65076 .35345 Metetra
.978 .093 0 r
.65076 .35345 .65653 .36064 .66839 .35688 .66265 .34966 Metetra
.978 .092 0 r
.66265 .34966 .66839 .35688 .68029 .35301 .67459 .34577 Metetra
.978 .093 0 r
.67459 .34577 .68029 .35301 .69223 .34878 .68657 .34151 Metetra
.975 .105 0 r
.68657 .34151 .69223 .34878 .70416 .34351 .69853 .3362 Metetra
.966 .142 0 r
.69853 .3362 .70416 .34351 .71597 .33564 .71039 .32829 Metetra
.943 .232 0 r
.71039 .32829 .71597 .33564 .72746 .32236 .72193 .31497 Metetra
.895 .409 0 r
.72193 .31497 .72746 .32236 .73829 .29976 .73282 .29231 Metetra
.806 .677 0 r
.73282 .29231 .73829 .29976 .74809 .26423 .7427 .25672 Metetra
.374 .668 0 r
.7427 .25672 .74809 .26423 .75664 .21491 .75135 .20731 Metetra
.083 .572 0 r
.08643 .40579 .09333 .41183 .09615 .45759 .08915 .4516 Metetra
.636 .738 0 r
.08915 .4516 .09615 .45759 .10078 .49157 .0937 .48561 Metetra
.852 .545 0 r
.0937 .48561 .10078 .49157 .1073 .51235 .10018 .5064 Metetra
.921 .315 0 r
.10018 .5064 .1073 .51235 .11532 .52227 .10819 .51632 Metetra
.956 .181 0 r
.10819 .51632 .11532 .52227 .1243 .52513 .11717 .51916 Metetra
.972 .12 0 r
.11717 .51916 .1243 .52513 .13378 .52423 .12667 .51824 Metetra
.977 .097 0 r
.12667 .51824 .13378 .52423 .1435 .52166 .13641 .51565 Metetra
.978 .092 0 r
.13641 .51565 .1435 .52166 .15333 .51848 .14626 .51244 Metetra
.978 .092 0 r
.14626 .51244 .15333 .51848 .16322 .51509 .15617 .50903 Metetra
.978 .094 0 r
.15617 .50903 .16322 .51509 .17315 .51165 .16612 .50557 Metetra
.977 .096 0 r
.16612 .50557 .17315 .51165 .18312 .50819 .17611 .50208 Metetra
.977 .099 0 r
.17611 .50208 .18312 .50819 .19312 .50472 .18614 .49859 Metetra
.976 .101 0 r
.18614 .49859 .19312 .50472 .20317 .50125 .19621 .4951 Metetra
.976 .103 0 r
.19621 .4951 .20317 .50125 .21325 .49778 .20631 .4916 Metetra
.975 .105 0 r
.20631 .4916 .21325 .49778 .22337 .4943 .21645 .48809 Metetra
.975 .107 0 r
.21645 .48809 .22337 .4943 .23352 .49081 .22663 .48459 Metetra
.974 .109 0 r
.22663 .48459 .23352 .49081 .24372 .48732 .23685 .48107 Metetra
.974 .11 0 r
.23685 .48107 .24372 .48732 .25395 .48383 .24711 .47755 Metetra
.974 .112 0 r
.24711 .47755 .25395 .48383 .26422 .48032 .2574 .47402 Metetra
.973 .113 0 r
.2574 .47402 .26422 .48032 .27453 .47682 .26774 .47049 Metetra
.973 .114 0 r
.26774 .47049 .27453 .47682 .28488 .4733 .27811 .46695 Metetra
.973 .116 0 r
.27811 .46695 .28488 .4733 .29527 .46978 .28853 .4634 Metetra
.972 .117 0 r
.28853 .4634 .29527 .46978 .3057 .46626 .29898 .45985 Metetra
.972 .118 0 r
.29898 .45985 .3057 .46626 .31617 .46272 .30948 .45629 Metetra
.972 .118 0 r
.30948 .45629 .31617 .46272 .32669 .45918 .32002 .45273 Metetra
.972 .119 0 r
.32002 .45273 .32669 .45918 .33724 .45564 .3306 .44915 Metetra
.972 .12 0 r
.3306 .44915 .33724 .45564 .34783 .45209 .34122 .44558 Metetra
.971 .12 0 r
.34122 .44558 .34783 .45209 .35847 .44853 .35188 .44199 Metetra
.971 .121 0 r
.35188 .44199 .35847 .44853 .36915 .44496 .36258 .4384 Metetra
.971 .121 0 r
.36258 .4384 .36915 .44496 .37987 .44139 .37333 .4348 Metetra
.971 .121 0 r
.37333 .4348 .37987 .44139 .39063 .43781 .38412 .43119 Metetra
.971 .121 0 r
.38412 .43119 .39063 .43781 .40143 .43422 .39495 .42758 Metetra
.971 .121 0 r
.39495 .42758 .40143 .43422 .41228 .43063 .40583 .42396 Metetra
.971 .121 0 r
.40583 .42396 .41228 .43063 .42318 .42703 .41675 .42033 Metetra
.971 .121 0 r
.41675 .42033 .42318 .42703 .43411 .42342 .42771 .4167 Metetra
.971 .121 0 r
.42771 .4167 .43411 .42342 .44509 .4198 .43872 .41305 Metetra
.971 .12 0 r
.43872 .41305 .44509 .4198 .45612 .41618 .44978 .4094 Metetra
.972 .12 0 r
.44978 .4094 .45612 .41618 .46719 .41255 .46088 .40574 Metetra
.972 .119 0 r
.46088 .40574 .46719 .41255 .47831 .40891 .47202 .40208 Metetra
.972 .118 0 r
.47202 .40208 .47831 .40891 .48947 .40527 .48321 .39841 Metetra
.972 .117 0 r
.48321 .39841 .48947 .40527 .50068 .40162 .49445 .39473 Metetra
.972 .116 0 r
.49445 .39473 .50068 .40162 .51193 .39796 .50574 .39105 Metetra
.973 .115 0 r
.50574 .39105 .51193 .39796 .52323 .3943 .51707 .38735 Metetra
.973 .114 0 r
.51707 .38735 .52323 .3943 .53458 .39062 .52845 .38365 Metetra
.973 .112 0 r
.52845 .38365 .53458 .39062 .54598 .38694 .53988 .37994 Metetra
.974 .111 0 r
.53988 .37994 .54598 .38694 .55742 .38325 .55135 .37622 Metetra
.974 .109 0 r
.55135 .37622 .55742 .38325 .56892 .37955 .56288 .37249 Metetra
.974 .108 0 r
.56288 .37249 .56892 .37955 .58046 .37585 .57445 .36876 Metetra
.975 .106 0 r
.57445 .36876 .58046 .37585 .59205 .37213 .58607 .36501 Metetra
.975 .104 0 r
.58607 .36501 .59205 .37213 .60369 .36841 .59775 .36126 Metetra
.976 .102 0 r
.59775 .36126 .60369 .36841 .61538 .36468 .60947 .35751 Metetra
.976 .1 0 r
.60947 .35751 .61538 .36468 .62712 .36095 .62124 .35374 Metetra
.977 .098 0 r
.62124 .35374 .62712 .36095 .63892 .35721 .63307 .34997 Metetra
.978 .095 0 r
.63307 .34997 .63892 .35721 .65076 .35345 .64494 .34618 Metetra
.978 .093 0 r
.64494 .34618 .65076 .35345 .66265 .34966 .65687 .34236 Metetra
.978 .091 0 r
.65687 .34236 .66265 .34966 .67459 .34577 .66885 .33844 Metetra
.978 .093 0 r
.66885 .33844 .67459 .34577 .68657 .34151 .68086 .33415 Metetra
.975 .104 0 r
.68086 .33415 .68657 .34151 .69853 .3362 .69286 .32881 Metetra
.966 .141 0 r
.69286 .32881 .69853 .3362 .71039 .32829 .70476 .32087 Metetra
.943 .231 0 r
.70476 .32087 .71039 .32829 .72193 .31497 .71635 .3075 Metetra
.895 .408 0 r
.71635 .3075 .72193 .31497 .73282 .29231 .7273 .28479 Metetra
.806 .677 0 r
.7273 .28479 .73282 .29231 .7427 .25672 .73727 .24913 Metetra
.374 .668 0 r
.73727 .24913 .7427 .25672 .75135 .20731 .74602 .19963 Metetra
.083 .572 0 r
.07949 .39967 .08643 .40579 .08915 .4516 .0821 .44552 Metetra
.637 .738 0 r
.0821 .44552 .08915 .4516 .0937 .48561 .08658 .47956 Metetra
.852 .545 0 r
.08658 .47956 .0937 .48561 .10018 .5064 .09302 .50036 Metetra
.921 .315 0 r
.09302 .50036 .10018 .5064 .10819 .51632 .10101 .51027 Metetra
.956 .181 0 r
.10101 .51027 .10819 .51632 .11717 .51916 .11 .51309 Metetra
.972 .12 0 r
.11 .51309 .11717 .51916 .12667 .51824 .11951 .51215 Metetra
.977 .097 0 r
.11951 .51215 .12667 .51824 .13641 .51565 .12927 .50954 Metetra
.978 .092 0 r
.12927 .50954 .13641 .51565 .14626 .51244 .13914 .50631 Metetra
.978 .092 0 r
.13914 .50631 .14626 .51244 .15617 .50903 .14907 .50288 Metetra
.978 .094 0 r
.14907 .50288 .15617 .50903 .16612 .50557 .15905 .49939 Metetra
.977 .097 0 r
.15905 .49939 .16612 .50557 .17611 .50208 .16906 .49588 Metetra
.977 .099 0 r
.16906 .49588 .17611 .50208 .18614 .49859 .17911 .49237 Metetra
.976 .101 0 r
.17911 .49237 .18614 .49859 .19621 .4951 .1892 .48885 Metetra
.976 .103 0 r
.1892 .48885 .19621 .4951 .20631 .4916 .19933 .48532 Metetra
.975 .105 0 r
.19933 .48532 .20631 .4916 .21645 .48809 .20949 .48179 Metetra
.975 .107 0 r
.20949 .48179 .21645 .48809 .22663 .48459 .2197 .47826 Metetra
.974 .109 0 r
.2197 .47826 .22663 .48459 .23685 .48107 .22994 .47472 Metetra
.974 .11 0 r
.22994 .47472 .23685 .48107 .24711 .47755 .24022 .47117 Metetra
.973 .112 0 r
.24022 .47117 .24711 .47755 .2574 .47402 .25054 .46762 Metetra
.973 .113 0 r
.25054 .46762 .2574 .47402 .26774 .47049 .2609 .46406 Metetra
.973 .115 0 r
.2609 .46406 .26774 .47049 .27811 .46695 .2713 .4605 Metetra
.973 .116 0 r
.2713 .4605 .27811 .46695 .28853 .4634 .28174 .45693 Metetra
.972 .117 0 r
.28174 .45693 .28853 .4634 .29898 .45985 .29222 .45335 Metetra
.972 .118 0 r
.29222 .45335 .29898 .45985 .30948 .45629 .30274 .44976 Metetra
.972 .119 0 r
.30274 .44976 .30948 .45629 .32002 .45273 .3133 .44617 Metetra
.972 .119 0 r
.3133 .44617 .32002 .45273 .3306 .44915 .32391 .44258 Metetra
.972 .12 0 r
.32391 .44258 .3306 .44915 .34122 .44558 .33455 .43897 Metetra
.971 .12 0 r
.33455 .43897 .34122 .44558 .35188 .44199 .34524 .43536 Metetra
.971 .121 0 r
.34524 .43536 .35188 .44199 .36258 .4384 .35597 .43174 Metetra
.971 .121 0 r
.35597 .43174 .36258 .4384 .37333 .4348 .36674 .42811 Metetra
.971 .121 0 r
.36674 .42811 .37333 .4348 .38412 .43119 .37756 .42448 Metetra
.971 .121 0 r
.37756 .42448 .38412 .43119 .39495 .42758 .38842 .42084 Metetra
.971 .121 0 r
.38842 .42084 .39495 .42758 .40583 .42396 .39933 .41719 Metetra
.971 .121 0 r
.39933 .41719 .40583 .42396 .41675 .42033 .41027 .41354 Metetra
.971 .121 0 r
.41027 .41354 .41675 .42033 .42771 .4167 .42127 .40987 Metetra
.971 .121 0 r
.42127 .40987 .42771 .4167 .43872 .41305 .4323 .4062 Metetra
.971 .12 0 r
.4323 .4062 .43872 .41305 .44978 .4094 .44339 .40253 Metetra
.972 .12 0 r
.44339 .40253 .44978 .4094 .46088 .40574 .45452 .39884 Metetra
.972 .119 0 r
.45452 .39884 .46088 .40574 .47202 .40208 .46569 .39515 Metetra
.972 .118 0 r
.46569 .39515 .47202 .40208 .48321 .39841 .47691 .39144 Metetra
.972 .117 0 r
.47691 .39144 .48321 .39841 .49445 .39473 .48818 .38774 Metetra
.972 .116 0 r
.48818 .38774 .49445 .39473 .50574 .39105 .49949 .38403 Metetra
.973 .115 0 r
.49949 .38403 .50574 .39105 .51707 .38735 .51086 .3803 Metetra
.973 .114 0 r
.51086 .3803 .51707 .38735 .52845 .38365 .52227 .37657 Metetra
.973 .113 0 r
.52227 .37657 .52845 .38365 .53988 .37994 .53372 .37283 Metetra
.974 .111 0 r
.53372 .37283 .53988 .37994 .55135 .37622 .54523 .36908 Metetra
.974 .11 0 r
.54523 .36908 .55135 .37622 .56288 .37249 .55679 .36532 Metetra
.974 .108 0 r
.55679 .36532 .56288 .37249 .57445 .36876 .56839 .36156 Metetra
.975 .106 0 r
.56839 .36156 .57445 .36876 .58607 .36501 .58005 .35779 Metetra
.975 .104 0 r
.58005 .35779 .58607 .36501 .59775 .36126 .59175 .35401 Metetra
.976 .102 0 r
.59175 .35401 .59775 .36126 .60947 .35751 .60351 .35022 Metetra
.976 .1 0 r
.60351 .35022 .60947 .35751 .62124 .35374 .61531 .34642 Metetra
.977 .098 0 r
.61531 .34642 .62124 .35374 .63307 .34997 .62717 .34262 Metetra
.977 .095 0 r
.62717 .34262 .63307 .34997 .64494 .34618 .63908 .3388 Metetra
.978 .093 0 r
.63908 .3388 .64494 .34618 .65687 .34236 .65105 .33495 Metetra
.978 .092 0 r
.65105 .33495 .65687 .34236 .66885 .33844 .66305 .33099 Metetra
.978 .093 0 r
.66305 .33099 .66885 .33844 .68086 .33415 .6751 .32667 Metetra
.975 .105 0 r
.6751 .32667 .68086 .33415 .69286 .32881 .68714 .3213 Metetra
.966 .141 0 r
.68714 .3213 .69286 .32881 .70476 .32087 .69908 .31332 Metetra
.943 .231 0 r
.69908 .31332 .70476 .32087 .71635 .3075 .71072 .29991 Metetra
.895 .408 0 r
.71072 .29991 .71635 .3075 .7273 .28479 .72174 .27715 Metetra
.806 .677 0 r
.72174 .27715 .7273 .28479 .73727 .24913 .73179 .24142 Metetra
.375 .668 0 r
.73179 .24142 .73727 .24913 .74602 .19963 .74065 .19184 Metetra
.082 .572 0 r
.07253 .39336 .07949 .39967 .0821 .44552 .07503 .43922 Metetra
.635 .737 0 r
.07503 .43922 .0821 .44552 .08658 .47956 .07944 .47326 Metetra
.852 .546 0 r
.07944 .47326 .08658 .47956 .09302 .50036 .08583 .49404 Metetra
.921 .317 0 r
.08583 .49404 .09302 .50036 .10101 .51027 .09381 .50394 Metetra
.956 .184 0 r
.09381 .50394 .10101 .51027 .11 .51309 .1028 .50675 Metetra
.971 .122 0 r
.1028 .50675 .11 .51309 .11951 .51215 .11233 .50579 Metetra
.976 .1 0 r
.11233 .50579 .11951 .51215 .12927 .50954 .12211 .50316 Metetra
.978 .094 0 r
.12211 .50316 .12927 .50954 .13914 .50631 .132 .4999 Metetra
.978 .094 0 r
.132 .4999 .13914 .50631 .14907 .50288 .14196 .49645 Metetra
.977 .096 0 r
.14196 .49645 .14907 .50288 .15905 .49939 .15195 .49294 Metetra
.977 .099 0 r
.15195 .49294 .15905 .49939 .16906 .49588 .16199 .48941 Metetra
.976 .101 0 r
.16199 .48941 .16906 .49588 .17911 .49237 .17206 .48587 Metetra
.976 .103 0 r
.17206 .48587 .17911 .49237 .1892 .48885 .18217 .48233 Metetra
.975 .105 0 r
.18217 .48233 .1892 .48885 .19933 .48532 .19232 .47879 Metetra
.975 .107 0 r
.19232 .47879 .19933 .48532 .20949 .48179 .20251 .47523 Metetra
.974 .109 0 r
.20251 .47523 .20949 .48179 .2197 .47826 .21273 .47168 Metetra
.974 .111 0 r
.21273 .47168 .2197 .47826 .22994 .47472 .223 .46811 Metetra
.973 .112 0 r
.223 .46811 .22994 .47472 .24022 .47117 .2333 .46454 Metetra
.973 .114 0 r
.2333 .46454 .24022 .47117 .25054 .46762 .24364 .46097 Metetra
.973 .115 0 r
.24364 .46097 .25054 .46762 .2609 .46406 .25403 .45738 Metetra
.972 .117 0 r
.25403 .45738 .2609 .46406 .2713 .4605 .26445 .45379 Metetra
.972 .118 0 r
.26445 .45379 .2713 .4605 .28174 .45693 .27491 .4502 Metetra
.972 .119 0 r
.27491 .4502 .28174 .45693 .29222 .45335 .28542 .4466 Metetra
.972 .12 0 r
.28542 .4466 .29222 .45335 .30274 .44976 .29596 .44299 Metetra
.971 .121 0 r
.29596 .44299 .30274 .44976 .3133 .44617 .30655 .43937 Metetra
.971 .121 0 r
.30655 .43937 .3133 .44617 .32391 .44258 .31718 .43575 Metetra
.971 .122 0 r
.31718 .43575 .32391 .44258 .33455 .43897 .32785 .43211 Metetra
.971 .122 0 r
.32785 .43211 .33455 .43897 .34524 .43536 .33857 .42848 Metetra
.971 .123 0 r
.33857 .42848 .34524 .43536 .35597 .43174 .34932 .42483 Metetra
.971 .123 0 r
.34932 .42483 .35597 .43174 .36674 .42811 .36012 .42118 Metetra
.971 .123 0 r
.36012 .42118 .36674 .42811 .37756 .42448 .37096 .41752 Metetra
.971 .123 0 r
.37096 .41752 .37756 .42448 .38842 .42084 .38185 .41385 Metetra
.971 .123 0 r
.38185 .41385 .38842 .42084 .39933 .41719 .39278 .41017 Metetra
.971 .123 0 r
.39278 .41017 .39933 .41719 .41027 .41354 .40376 .40649 Metetra
.971 .123 0 r
.40376 .40649 .41027 .41354 .42127 .40987 .41478 .4028 Metetra
.971 .123 0 r
.41478 .4028 .42127 .40987 .4323 .4062 .42584 .3991 Metetra
.971 .122 0 r
.42584 .3991 .4323 .4062 .44339 .40253 .43695 .39539 Metetra
.971 .122 0 r
.43695 .39539 .44339 .40253 .45452 .39884 .44811 .39168 Metetra
.971 .121 0 r
.44811 .39168 .45452 .39884 .46569 .39515 .45931 .38795 Metetra
.971 .12 0 r
.45931 .38795 .46569 .39515 .47691 .39144 .47056 .38422 Metetra
.972 .119 0 r
.47056 .38422 .47691 .39144 .48818 .38774 .48186 .38049 Metetra
.972 .118 0 r
.48186 .38049 .48818 .38774 .49949 .38403 .4932 .37674 Metetra
.972 .117 0 r
.4932 .37674 .49949 .38403 .51086 .3803 .5046 .37299 Metetra
.972 .116 0 r
.5046 .37299 .51086 .3803 .52227 .37657 .51604 .36922 Metetra
.973 .115 0 r
.51604 .36922 .52227 .37657 .53372 .37283 .52752 .36545 Metetra
.973 .113 0 r
.52752 .36545 .53372 .37283 .54523 .36908 .53906 .36167 Metetra
.974 .112 0 r
.53906 .36167 .54523 .36908 .55679 .36532 .55065 .35788 Metetra
.974 .11 0 r
.55065 .35788 .55679 .36532 .56839 .36156 .56228 .35409 Metetra
.974 .108 0 r
.56228 .35409 .56839 .36156 .58005 .35779 .57397 .35028 Metetra
.975 .106 0 r
.57397 .35028 .58005 .35779 .59175 .35401 .58571 .34647 Metetra
.975 .104 0 r
.58571 .34647 .59175 .35401 .60351 .35022 .59749 .34265 Metetra
.976 .102 0 r
.59749 .34265 .60351 .35022 .61531 .34642 .60933 .33882 Metetra
.976 .1 0 r
.60933 .33882 .61531 .34642 .62717 .34262 .62123 .33498 Metetra
.977 .098 0 r
.62123 .33498 .62717 .34262 .63908 .3388 .63317 .33113 Metetra
.977 .095 0 r
.63317 .33113 .63908 .3388 .65105 .33495 .64516 .32724 Metetra
.978 .094 0 r
.64516 .32724 .65105 .33495 .66305 .33099 .65721 .32325 Metetra
.977 .095 0 r
.65721 .32325 .66305 .33099 .6751 .32667 .66929 .31889 Metetra
.975 .107 0 r
.66929 .31889 .6751 .32667 .68714 .3213 .68136 .31348 Metetra
.966 .144 0 r
.68136 .31348 .68714 .3213 .69908 .31332 .69334 .30547 Metetra
.943 .234 0 r
.69334 .30547 .69908 .31332 .71072 .29991 .70503 .29202 Metetra
.894 .41 0 r
.70503 .29202 .71072 .29991 .72174 .27715 .71612 .26922 Metetra
.806 .678 0 r
.71612 .26922 .72174 .27715 .73179 .24142 .72626 .23344 Metetra
.373 .668 0 r
.72626 .23344 .73179 .24142 .74065 .19184 .73522 .18382 Metetra
.078 .57 0 r
.06558 .38655 .07253 .39336 .07503 .43922 .06799 .43231 Metetra
.627 .735 0 r
.06799 .43231 .07503 .43922 .07944 .47326 .07233 .46626 Metetra
.85 .553 0 r
.07233 .46626 .07944 .47326 .08583 .49404 .07869 .48699 Metetra
.918 .325 0 r
.07869 .48699 .08583 .49404 .09381 .50394 .08666 .49685 Metetra
.953 .193 0 r
.08666 .49685 .09381 .50394 .1028 .50675 .09565 .49963 Metetra
.969 .132 0 r
.09565 .49963 .1028 .50675 .11233 .50579 .10519 .49866 Metetra
.974 .109 0 r
.10519 .49866 .11233 .50579 .12211 .50316 .11499 .49601 Metetra
.976 .103 0 r
.11499 .49601 .12211 .50316 .132 .4999 .1249 .49275 Metetra
.976 .104 0 r
.1249 .49275 .132 .4999 .14196 .49645 .13487 .48928 Metetra
.975 .105 0 r
.13487 .48928 .14196 .49645 .15195 .49294 .14488 .48575 Metetra
.975 .108 0 r
.14488 .48575 .15195 .49294 .16199 .48941 .15494 .48221 Metetra
.974 .11 0 r
.15494 .48221 .16199 .48941 .17206 .48587 .16503 .47866 Metetra
.973 .112 0 r
.16503 .47866 .17206 .48587 .18217 .48233 .17516 .4751 Metetra
.973 .114 0 r
.17516 .4751 .18217 .48233 .19232 .47879 .18533 .47154 Metetra
.973 .116 0 r
.18533 .47154 .19232 .47879 .20251 .47523 .19553 .46797 Metetra
.972 .118 0 r
.19553 .46797 .20251 .47523 .21273 .47168 .20578 .46439 Metetra
.972 .119 0 r
.20578 .46439 .21273 .47168 .223 .46811 .21606 .46081 Metetra
.971 .121 0 r
.21606 .46081 .223 .46811 .2333 .46454 .22639 .45722 Metetra
.971 .122 0 r
.22639 .45722 .2333 .46454 .24364 .46097 .23675 .45362 Metetra
.971 .124 0 r
.23675 .45362 .24364 .46097 .25403 .45738 .24716 .45002 Metetra
.97 .125 0 r
.24716 .45002 .25403 .45738 .26445 .45379 .2576 .44641 Metetra
.97 .126 0 r
.2576 .44641 .26445 .45379 .27491 .4502 .26809 .44279 Metetra
.97 .127 0 r
.26809 .44279 .27491 .4502 .28542 .4466 .27862 .43916 Metetra
.97 .128 0 r
.27862 .43916 .28542 .4466 .29596 .44299 .28918 .43553 Metetra
.969 .129 0 r
.28918 .43553 .29596 .44299 .30655 .43937 .29979 .43189 Metetra
.969 .129 0 r
.29979 .43189 .30655 .43937 .31718 .43575 .31045 .42824 Metetra
.969 .13 0 r
.31045 .42824 .31718 .43575 .32785 .43211 .32114 .42459 Metetra
.969 .13 0 r
.32114 .42459 .32785 .43211 .33857 .42848 .33188 .42092 Metetra
.969 .131 0 r
.33188 .42092 .33857 .42848 .34932 .42483 .34266 .41725 Metetra
.969 .131 0 r
.34266 .41725 .34932 .42483 .36012 .42118 .35348 .41357 Metetra
.969 .131 0 r
.35348 .41357 .36012 .42118 .37096 .41752 .36435 .40988 Metetra
.969 .131 0 r
.36435 .40988 .37096 .41752 .38185 .41385 .37526 .40619 Metetra
.969 .131 0 r
.37526 .40619 .38185 .41385 .39278 .41017 .38622 .40248 Metetra
.969 .131 0 r
.38622 .40248 .39278 .41017 .40376 .40649 .39722 .39877 Metetra
.969 .131 0 r
.39722 .39877 .40376 .40649 .41478 .4028 .40826 .39505 Metetra
.969 .13 0 r
.40826 .39505 .41478 .4028 .42584 .3991 .41935 .39132 Metetra
.969 .13 0 r
.41935 .39132 .42584 .3991 .43695 .39539 .43049 .38758 Metetra
.969 .13 0 r
.43049 .38758 .43695 .39539 .44811 .39168 .44167 .38383 Metetra
.969 .129 0 r
.44167 .38383 .44811 .39168 .45931 .38795 .4529 .38008 Metetra
.969 .128 0 r
.4529 .38008 .45931 .38795 .47056 .38422 .46418 .37631 Metetra
.97 .127 0 r
.46418 .37631 .47056 .38422 .48186 .38049 .4755 .37254 Metetra
.97 .126 0 r
.4755 .37254 .48186 .38049 .4932 .37674 .48688 .36876 Metetra
.97 .125 0 r
.48688 .36876 .4932 .37674 .5046 .37299 .49829 .36497 Metetra
.97 .124 0 r
.49829 .36497 .5046 .37299 .51604 .36922 .50976 .36117 Metetra
.971 .123 0 r
.50976 .36117 .51604 .36922 .52752 .36545 .52128 .35736 Metetra
.971 .121 0 r
.52128 .35736 .52752 .36545 .53906 .36167 .53284 .35354 Metetra
.971 .12 0 r
.53284 .35354 .53906 .36167 .55065 .35788 .54446 .34972 Metetra
.972 .118 0 r
.54446 .34972 .55065 .35788 .56228 .35409 .55612 .34588 Metetra
.972 .117 0 r
.55612 .34588 .56228 .35409 .57397 .35028 .56784 .34204 Metetra
.973 .115 0 r
.56784 .34204 .57397 .35028 .58571 .34647 .5796 .33818 Metetra
.973 .113 0 r
.5796 .33818 .58571 .34647 .59749 .34265 .59142 .33432 Metetra
.974 .111 0 r
.59142 .33432 .59749 .34265 .60933 .33882 .60329 .33045 Metetra
.974 .109 0 r
.60329 .33045 .60933 .33882 .62123 .33498 .61521 .32657 Metetra
.975 .107 0 r
.61521 .32657 .62123 .33498 .63317 .33113 .62718 .32267 Metetra
.975 .104 0 r
.62718 .32267 .63317 .33113 .64516 .32724 .63921 .31874 Metetra
.976 .103 0 r
.63921 .31874 .64516 .32724 .65721 .32325 .65128 .3147 Metetra
.975 .105 0 r
.65128 .3147 .65721 .32325 .66929 .31889 .66339 .3103 Metetra
.972 .116 0 r
.66339 .3103 .66929 .31889 .68136 .31348 .6755 .30485 Metetra
.963 .153 0 r
.6755 .30485 .68136 .31348 .69334 .30547 .68752 .29679 Metetra
.941 .242 0 r
.68752 .29679 .69334 .30547 .70503 .29202 .69926 .28332 Metetra
.892 .417 0 r
.69926 .28332 .70503 .29202 .71612 .26922 .71042 .26051 Metetra
.804 .683 0 r
.71042 .26051 .71612 .26922 .72626 .23344 .72064 .22476 Metetra
.367 .666 0 r
.72064 .22476 .72626 .23344 .73522 .18382 .72972 .17519 Metetra
.065 .565 0 r
.05877 .3785 .06558 .38655 .06799 .43231 .06112 .42387 Metetra
.603 .729 0 r
.06112 .42387 .06799 .43231 .07233 .46626 .06542 .45752 Metetra
.843 .573 0 r
.06542 .45752 .07233 .46626 .07869 .48699 .07176 .47806 Metetra
.911 .35 0 r
.07176 .47806 .07869 .48699 .08666 .49685 .07972 .48782 Metetra
.946 .22 0 r
.07972 .48782 .08666 .49685 .09565 .49963 .08871 .49055 Metetra
.962 .16 0 r
.08871 .49055 .09565 .49963 .10519 .49866 .09825 .48957 Metetra
.967 .138 0 r
.09825 .48957 .10519 .49866 .11499 .49601 .10806 .48692 Metetra
.969 .132 0 r
.10806 .48692 .11499 .49601 .1249 .49275 .11798 .48366 Metetra
.969 .132 0 r
.11798 .48366 .1249 .49275 .13487 .48928 .12796 .48019 Metetra
.968 .133 0 r
.12796 .48019 .13487 .48928 .14488 .48575 .13798 .47667 Metetra
.968 .135 0 r
.13798 .47667 .14488 .48575 .15494 .48221 .14805 .47312 Metetra
.967 .137 0 r
.14805 .47312 .15494 .48221 .16503 .47866 .15815 .46958 Metetra
.967 .139 0 r
.15815 .46958 .16503 .47866 .17516 .4751 .1683 .46601 Metetra
.966 .14 0 r
.1683 .46601 .17516 .4751 .18533 .47154 .17848 .46245 Metetra
.966 .142 0 r
.17848 .46245 .18533 .47154 .19553 .46797 .1887 .45887 Metetra
.966 .144 0 r
.1887 .45887 .19553 .46797 .20578 .46439 .19896 .45529 Metetra
.965 .145 0 r
.19896 .45529 .20578 .46439 .21606 .46081 .20926 .4517 Metetra
.965 .146 0 r
.20926 .4517 .21606 .46081 .22639 .45722 .21959 .4481 Metetra
.965 .148 0 r
.21959 .4481 .22639 .45722 .23675 .45362 .22997 .44449 Metetra
.964 .149 0 r
.22997 .44449 .23675 .45362 .24716 .45002 .24039 .44087 Metetra
.964 .15 0 r
.24039 .44087 .24716 .45002 .2576 .44641 .25085 .43725 Metetra
.964 .151 0 r
.25085 .43725 .2576 .44641 .26809 .44279 .26136 .43361 Metetra
.964 .152 0 r
.26136 .43361 .26809 .44279 .27862 .43916 .2719 .42997 Metetra
.964 .152 0 r
.2719 .42997 .27862 .43916 .28918 .43553 .28249 .42632 Metetra
.963 .153 0 r
.28249 .42632 .28918 .43553 .29979 .43189 .29311 .42266 Metetra
.963 .154 0 r
.29311 .42266 .29979 .43189 .31045 .42824 .30378 .41899 Metetra
.963 .154 0 r
.30378 .41899 .31045 .42824 .32114 .42459 .31449 .41531 Metetra
.963 .155 0 r
.31449 .41531 .32114 .42459 .33188 .42092 .32525 .41162 Metetra
.963 .155 0 r
.32525 .41162 .33188 .42092 .34266 .41725 .33605 .40792 Metetra
.963 .155 0 r
.33605 .40792 .34266 .41725 .35348 .41357 .34689 .40421 Metetra
.963 .155 0 r
.34689 .40421 .35348 .41357 .36435 .40988 .35778 .4005 Metetra
.963 .155 0 r
.35778 .4005 .36435 .40988 .37526 .40619 .36871 .39677 Metetra
.963 .155 0 r
.36871 .39677 .37526 .40619 .38622 .40248 .37968 .39303 Metetra
.963 .155 0 r
.37968 .39303 .38622 .40248 .39722 .39877 .3907 .38929 Metetra
.963 .155 0 r
.3907 .38929 .39722 .39877 .40826 .39505 .40177 .38553 Metetra
.963 .155 0 r
.40177 .38553 .40826 .39505 .41935 .39132 .41288 .38177 Metetra
.963 .154 0 r
.41288 .38177 .41935 .39132 .43049 .38758 .42404 .37799 Metetra
.963 .154 0 r
.42404 .37799 .43049 .38758 .44167 .38383 .43524 .37421 Metetra
.963 .153 0 r
.43524 .37421 .44167 .38383 .4529 .38008 .44649 .37041 Metetra
.963 .153 0 r
.44649 .37041 .4529 .38008 .46418 .37631 .45779 .3666 Metetra
.964 .152 0 r
.45779 .3666 .46418 .37631 .4755 .37254 .46913 .3628 Metetra
.964 .151 0 r
.46913 .3628 .4755 .37254 .48688 .36876 .48053 .35897 Metetra
.964 .15 0 r
.48053 .35897 .48688 .36876 .49829 .36497 .49197 .35513 Metetra
.964 .149 0 r
.49197 .35513 .49829 .36497 .50976 .36117 .50345 .35129 Metetra
.965 .148 0 r
.50345 .35129 .50976 .36117 .52128 .35736 .51499 .34743 Metetra
.965 .147 0 r
.51499 .34743 .52128 .35736 .53284 .35354 .52658 .34356 Metetra
.965 .146 0 r
.52658 .34356 .53284 .35354 .54446 .34972 .53822 .33968 Metetra
.966 .144 0 r
.53822 .33968 .54446 .34972 .55612 .34588 .5499 .33579 Metetra
.966 .143 0 r
.5499 .33579 .55612 .34588 .56784 .34204 .56164 .33189 Metetra
.966 .141 0 r
.56164 .33189 .56784 .34204 .5796 .33818 .57343 .32798 Metetra
.967 .14 0 r
.57343 .32798 .5796 .33818 .59142 .33432 .58527 .32406 Metetra
.967 .138 0 r
.58527 .32406 .59142 .33432 .60329 .33045 .59716 .32013 Metetra
.968 .136 0 r
.59716 .32013 .60329 .33045 .61521 .32657 .6091 .31618 Metetra
.968 .134 0 r
.6091 .31618 .61521 .32657 .62718 .32267 .6211 .31222 Metetra
.968 .132 0 r
.6211 .31222 .62718 .32267 .63921 .31874 .63314 .30822 Metetra
.969 .131 0 r
.63314 .30822 .63921 .31874 .65128 .3147 .64524 .30412 Metetra
.968 .133 0 r
.64524 .30412 .65128 .3147 .66339 .3103 .65737 .29965 Metetra
.965 .145 0 r
.65737 .29965 .66339 .3103 .6755 .30485 .66951 .29414 Metetra
.956 .181 0 r
.66951 .29414 .6755 .30485 .68752 .29679 .68156 .28605 Metetra
.934 .269 0 r
.68156 .28605 .68752 .29679 .69926 .28332 .69334 .27259 Metetra
.885 .44 0 r
.69334 .27259 .69926 .28332 .71042 .26051 .70456 .24987 Metetra
.797 .7 0 r
.70456 .24987 .71042 .26051 .72064 .22476 .71488 .21432 Metetra
.348 .66 0 r
.71488 .21432 .72064 .22476 .72972 .17519 .72408 .16507 Metetra
.031 .551 0 r
.0523 .36778 .05877 .3785 .06112 .42387 .05468 .41214 Metetra
.542 .714 0 r
.05468 .41214 .06112 .42387 .06542 .45752 .059 .44502 Metetra
.826 .622 0 r
.059 .44502 .06542 .45752 .07176 .47806 .06535 .46507 Metetra
.894 .412 0 r
.06535 .46507 .07176 .47806 .07972 .48782 .07331 .47458 Metetra
.928 .289 0 r
.07331 .47458 .07972 .48782 .08871 .49055 .08229 .47722 Metetra
.944 .231 0 r
.08229 .47722 .08871 .49055 .09825 .48957 .09183 .47622 Metetra
.949 .209 0 r
.09183 .47622 .09825 .48957 .10806 .48692 .10163 .47359 Metetra
.951 .203 0 r
.10163 .47359 .10806 .48692 .11798 .48366 .11154 .47036 Metetra
.951 .202 0 r
.11154 .47036 .11798 .48366 .12796 .48019 .12152 .46693 Metetra
.951 .203 0 r
.12152 .46693 .12796 .48019 .13798 .47667 .13154 .46344 Metetra
.95 .204 0 r
.13154 .46344 .13798 .47667 .14805 .47312 .1416 .45992 Metetra
.95 .205 0 r
.1416 .45992 .14805 .47312 .15815 .46958 .1517 .4564 Metetra
.95 .206 0 r
.1517 .4564 .15815 .46958 .1683 .46601 .16184 .45286 Metetra
.95 .208 0 r
.16184 .45286 .1683 .46601 .17848 .46245 .17202 .44931 Metetra
.949 .209 0 r
.17202 .44931 .17848 .46245 .1887 .45887 .18224 .44575 Metetra
.949 .21 0 r
.18224 .44575 .1887 .45887 .19896 .45529 .1925 .44218 Metetra
.949 .211 0 r
.1925 .44218 .19896 .45529 .20926 .4517 .2028 .43859 Metetra
.949 .211 0 r
.2028 .43859 .20926 .4517 .21959 .4481 .21314 .435 Metetra
.948 .212 0 r
.21314 .435 .21959 .4481 .22997 .44449 .22352 .43139 Metetra
.948 .213 0 r
.22352 .43139 .22997 .44449 .24039 .44087 .23394 .42778 Metetra
.948 .214 0 r
.23394 .42778 .24039 .44087 .25085 .43725 .2444 .42415 Metetra
.948 .214 0 r
.2444 .42415 .25085 .43725 .26136 .43361 .25491 .42051 Metetra
.948 .215 0 r
.25491 .42051 .26136 .43361 .2719 .42997 .26545 .41686 Metetra
.948 .215 0 r
.26545 .41686 .2719 .42997 .28249 .42632 .27604 .4132 Metetra
.947 .216 0 r
.27604 .4132 .28249 .42632 .29311 .42266 .28667 .40952 Metetra
.947 .216 0 r
.28667 .40952 .29311 .42266 .30378 .41899 .29735 .40584 Metetra
.947 .217 0 r
.29735 .40584 .30378 .41899 .31449 .41531 .30807 .40214 Metetra
.947 .217 0 r
.30807 .40214 .31449 .41531 .32525 .41162 .31883 .39843 Metetra
.947 .217 0 r
.31883 .39843 .32525 .41162 .33605 .40792 .32963 .3947 Metetra
.947 .217 0 r
.32963 .3947 .33605 .40792 .34689 .40421 .34048 .39097 Metetra
.947 .217 0 r
.34048 .39097 .34689 .40421 .35778 .4005 .35137 .38722 Metetra
.947 .217 0 r
.35137 .38722 .35778 .4005 .36871 .39677 .36231 .38346 Metetra
.947 .217 0 r
.36231 .38346 .36871 .39677 .37968 .39303 .37329 .37969 Metetra
.947 .217 0 r
.37329 .37969 .37968 .39303 .3907 .38929 .38432 .3759 Metetra
.947 .217 0 r
.38432 .3759 .3907 .38929 .40177 .38553 .39539 .37211 Metetra
.947 .217 0 r
.39539 .37211 .40177 .38553 .41288 .38177 .40651 .3683 Metetra
.947 .217 0 r
.40651 .3683 .41288 .38177 .42404 .37799 .41767 .36447 Metetra
.947 .216 0 r
.41767 .36447 .42404 .37799 .43524 .37421 .42889 .36064 Metetra
.947 .216 0 r
.42889 .36064 .43524 .37421 .44649 .37041 .44014 .35679 Metetra
.947 .216 0 r
.44014 .35679 .44649 .37041 .45779 .3666 .45145 .35293 Metetra
.948 .215 0 r
.45145 .35293 .45779 .3666 .46913 .3628 .4628 .34906 Metetra
.948 .215 0 r
.4628 .34906 .46913 .3628 .48053 .35897 .4742 .34517 Metetra
.948 .214 0 r
.4742 .34517 .48053 .35897 .49197 .35513 .48565 .34127 Metetra
.948 .213 0 r
.48565 .34127 .49197 .35513 .50345 .35129 .49714 .33736 Metetra
.948 .213 0 r
.49714 .33736 .50345 .35129 .51499 .34743 .50869 .33343 Metetra
.948 .212 0 r
.50869 .33343 .51499 .34743 .52658 .34356 .52028 .32948 Metetra
.949 .211 0 r
.52028 .32948 .52658 .34356 .53822 .33968 .53193 .32553 Metetra
.949 .21 0 r
.53193 .32553 .53822 .33968 .5499 .33579 .54362 .32156 Metetra
.949 .209 0 r
.54362 .32156 .5499 .33579 .56164 .33189 .55536 .31757 Metetra
.949 .208 0 r
.55536 .31757 .56164 .33189 .57343 .32798 .56716 .31358 Metetra
.95 .207 0 r
.56716 .31358 .57343 .32798 .58527 .32406 .579 .30956 Metetra
.95 .206 0 r
.579 .30956 .58527 .32406 .59716 .32013 .5909 .30554 Metetra
.95 .205 0 r
.5909 .30554 .59716 .32013 .6091 .31618 .60285 .30149 Metetra
.951 .203 0 r
.60285 .30149 .6091 .31618 .6211 .31222 .61485 .29743 Metetra
.951 .202 0 r
.61485 .29743 .6211 .31222 .63314 .30822 .6269 .29333 Metetra
.951 .202 0 r
.6269 .29333 .63314 .30822 .64524 .30412 .639 .28912 Metetra
.95 .204 0 r
.639 .28912 .64524 .30412 .65737 .29965 .65114 .28455 Metetra
.947 .216 0 r
.65114 .28455 .65737 .29965 .66951 .29414 .66328 .27896 Metetra
.938 .251 0 r
.66328 .27896 .66951 .29414 .68156 .28605 .67534 .27084 Metetra
.916 .335 0 r
.67534 .27084 .68156 .28605 .69334 .27259 .68715 .25748 Metetra
.868 .497 0 r
.68715 .25748 .69334 .27259 .70456 .24987 .69843 .23507 Metetra
.781 .741 0 r
.69843 .23507 .70456 .24987 .71488 .21432 .70885 .20013 Metetra
.299 .645 0 r
.70885 .20013 .71488 .21432 .72408 .16507 .7182 .15177 Metetra
0 .522 .037 r
.04653 .35223 .0523 .36778 .05468 .41214 .0491 .39445 Metetra
.415 .68 0 r
.0491 .39445 .05468 .41214 .059 .44502 .05354 .4257 Metetra
.789 .721 0 r
.05354 .4257 .059 .44502 .06535 .46507 .05996 .44471 Metetra
.855 .538 0 r
.05996 .44471 .06535 .46507 .07331 .47458 .06794 .45369 Metetra
.889 .429 0 r
.06794 .45369 .07331 .47458 .08229 .47722 .07691 .45612 Metetra
.904 .377 0 r
.07691 .45612 .08229 .47722 .09183 .47622 .08642 .45509 Metetra
.91 .356 0 r
.08642 .45509 .09183 .47622 .10163 .47359 .09619 .45251 Metetra
.912 .349 0 r
.09619 .45251 .10163 .47359 .11154 .47036 .10607 .44935 Metetra
.912 .348 0 r
.10607 .44935 .11154 .47036 .12152 .46693 .11601 .44599 Metetra
.912 .347 0 r
.11601 .44599 .12152 .46693 .13154 .46344 .126 .44257 Metetra
.912 .347 0 r
.126 .44257 .13154 .46344 .1416 .45992 .13603 .43911 Metetra
.912 .347 0 r
.13603 .43911 .1416 .45992 .1517 .4564 .1461 .43564 Metetra
.912 .348 0 r
.1461 .43564 .1517 .4564 .16184 .45286 .15621 .43216 Metetra
.912 .348 0 r
.15621 .43216 .16184 .45286 .17202 .44931 .16636 .42866 Metetra
.912 .348 0 r
.16636 .42866 .17202 .44931 .18224 .44575 .17656 .42514 Metetra
.912 .348 0 r
.17656 .42514 .18224 .44575 .1925 .44218 .18679 .42161 Metetra
.912 .348 0 r
.18679 .42161 .1925 .44218 .2028 .43859 .19706 .41805 Metetra
.912 .348 0 r
.19706 .41805 .2028 .43859 .21314 .435 .20738 .41449 Metetra
.912 .348 0 r
.20738 .41449 .21314 .435 .22352 .43139 .21774 .41091 Metetra
.912 .348 0 r
.21774 .41091 .22352 .43139 .23394 .42778 .22814 .40731 Metetra
.912 .349 0 r
.22814 .40731 .23394 .42778 .2444 .42415 .23858 .40369 Metetra
.912 .349 0 r
.23858 .40369 .2444 .42415 .25491 .42051 .24906 .40006 Metetra
.912 .349 0 r
.24906 .40006 .25491 .42051 .26545 .41686 .25959 .39641 Metetra
.912 .349 0 r
.25959 .39641 .26545 .41686 .27604 .4132 .27015 .39275 Metetra
.912 .349 0 r
.27015 .39275 .27604 .4132 .28667 .40952 .28077 .38907 Metetra
.912 .349 0 r
.28077 .38907 .28667 .40952 .29735 .40584 .29142 .38537 Metetra
.912 .349 0 r
.29142 .38537 .29735 .40584 .30807 .40214 .30212 .38165 Metetra
.912 .349 0 r
.30212 .38165 .30807 .40214 .31883 .39843 .31286 .37792 Metetra
.912 .349 0 r
.31286 .37792 .31883 .39843 .32963 .3947 .32365 .37418 Metetra
.912 .349 0 r
.32365 .37418 .32963 .3947 .34048 .39097 .33448 .37041 Metetra
.912 .349 0 r
.33448 .37041 .34048 .39097 .35137 .38722 .34535 .36663 Metetra
.912 .349 0 r
.34535 .36663 .35137 .38722 .36231 .38346 .35627 .36283 Metetra
.912 .349 0 r
.35627 .36283 .36231 .38346 .37329 .37969 .36724 .35901 Metetra
.912 .349 0 r
.36724 .35901 .37329 .37969 .38432 .3759 .37825 .35518 Metetra
.912 .349 0 r
.37825 .35518 .38432 .3759 .39539 .37211 .3893 .35133 Metetra
.912 .349 0 r
.3893 .35133 .39539 .37211 .40651 .3683 .4004 .34746 Metetra
.912 .349 0 r
.4004 .34746 .40651 .3683 .41767 .36447 .41155 .34358 Metetra
.912 .349 0 r
.41155 .34358 .41767 .36447 .42889 .36064 .42274 .33967 Metetra
.912 .349 0 r
.42274 .33967 .42889 .36064 .44014 .35679 .43398 .33575 Metetra
.912 .349 0 r
.43398 .33575 .44014 .35679 .45145 .35293 .44527 .33181 Metetra
.912 .349 0 r
.44527 .33181 .45145 .35293 .4628 .34906 .4566 .32786 Metetra
.912 .349 0 r
.4566 .32786 .4628 .34906 .4742 .34517 .46799 .32388 Metetra
.912 .349 0 r
.46799 .32388 .4742 .34517 .48565 .34127 .47942 .31989 Metetra
.912 .348 0 r
.47942 .31989 .48565 .34127 .49714 .33736 .49089 .31588 Metetra
.912 .348 0 r
.49089 .31588 .49714 .33736 .50869 .33343 .50242 .31185 Metetra
.912 .348 0 r
.50242 .31185 .50869 .33343 .52028 .32948 .51399 .30779 Metetra
.912 .348 0 r
.51399 .30779 .52028 .32948 .53193 .32553 .52561 .30372 Metetra
.912 .348 0 r
.52561 .30372 .53193 .32553 .54362 .32156 .53729 .29964 Metetra
.912 .348 0 r
.53729 .29964 .54362 .32156 .55536 .31757 .54901 .29553 Metetra
.912 .348 0 r
.54901 .29553 .55536 .31757 .56716 .31358 .56078 .2914 Metetra
.912 .348 0 r
.56078 .2914 .56716 .31358 .579 .30956 .5726 .28725 Metetra
.912 .347 0 r
.5726 .28725 .579 .30956 .5909 .30554 .58447 .28308 Metetra
.912 .347 0 r
.58447 .28308 .5909 .30554 .60285 .30149 .59639 .27889 Metetra
.912 .347 0 r
.59639 .27889 .60285 .30149 .61485 .29743 .60837 .27468 Metetra
.912 .347 0 r
.60837 .27468 .61485 .29743 .6269 .29333 .62039 .27042 Metetra
.912 .348 0 r
.62039 .27042 .6269 .29333 .639 .28912 .63246 .26605 Metetra
.911 .352 0 r
.63246 .26605 .639 .28912 .65114 .28455 .64457 .26133 Metetra
.908 .363 0 r
.64457 .26133 .65114 .28455 .66328 .27896 .65669 .25563 Metetra
.899 .395 0 r
.65669 .25563 .66328 .27896 .67534 .27084 .66873 .24754 Metetra
.876 .47 0 r
.66873 .24754 .67534 .27084 .68715 .25748 .68055 .23445 Metetra
.829 .613 0 r
.68055 .23445 .68715 .25748 .69843 .23507 .69187 .21276 Metetra
.667 .745 0 r
.69187 .21276 .69843 .23507 .70885 .20013 .7024 .17914 Metetra
.199 .613 0 r
.7024 .17914 .70885 .20013 .7182 .15177 .71193 .13275 Metetra
0 .467 .145 r
.04184 .32956 .04653 .35223 .0491 .39445 .04484 .36797 Metetra
.205 .615 0 r
.04484 .36797 .0491 .39445 .05354 .4257 .04958 .39631 Metetra
.563 .719 0 r
.04958 .39631 .05354 .4257 .05996 .44471 .05616 .41346 Metetra
.781 .74 0 r
.05616 .41346 .05996 .44471 .06794 .45369 .06419 .42147 Metetra
.814 .656 0 r
.06419 .42147 .06794 .45369 .07691 .45612 .07315 .42351 Metetra
.829 .615 0 r
.07315 .42351 .07691 .45612 .08642 .45509 .08261 .4224 Metetra
.835 .598 0 r
.08261 .4224 .08642 .45509 .09619 .45251 .0923 .41987 Metetra
.837 .591 0 r
.0923 .41987 .09619 .45251 .10607 .44935 .10211 .4168 Metetra
.838 .588 0 r
.10211 .4168 .10607 .44935 .11601 .44599 .11199 .41354 Metetra
.839 .586 0 r
.11199 .41354 .11601 .44599 .126 .44257 .1219 .41022 Metetra
.839 .585 0 r
.1219 .41022 .126 .44257 .13603 .43911 .13187 .40685 Metetra
.839 .584 0 r
.13187 .40685 .13603 .43911 .1461 .43564 .14187 .40347 Metetra
.84 .583 0 r
.14187 .40347 .1461 .43564 .15621 .43216 .15191 .40007 Metetra
.84 .582 0 r
.15191 .40007 .15621 .43216 .16636 .42866 .162 .39664 Metetra
.841 .581 0 r
.162 .39664 .16636 .42866 .17656 .42514 .17213 .39318 Metetra
.841 .58 0 r
.17213 .39318 .17656 .42514 .18679 .42161 .1823 .38971 Metetra
.841 .579 0 r
.1823 .38971 .18679 .42161 .19706 .41805 .19251 .38621 Metetra
.841 .578 0 r
.19251 .38621 .19706 .41805 .20738 .41449 .20277 .38269 Metetra
.842 .578 0 r
.20277 .38269 .20738 .41449 .21774 .41091 .21306 .37915 Metetra
.842 .577 0 r
.21306 .37915 .21774 .41091 .22814 .40731 .2234 .37558 Metetra
.842 .576 0 r
.2234 .37558 .22814 .40731 .23858 .40369 .23379 .37199 Metetra
.842 .576 0 r
.23379 .37199 .23858 .40369 .24906 .40006 .24421 .36838 Metetra
.842 .575 0 r
.24421 .36838 .24906 .40006 .25959 .39641 .25468 .36474 Metetra
.843 .575 0 r
.25468 .36474 .25959 .39641 .27015 .39275 .26519 .36108 Metetra
.843 .574 0 r
.26519 .36108 .27015 .39275 .28077 .38907 .27575 .3574 Metetra
.843 .574 0 r
.27575 .3574 .28077 .38907 .29142 .38537 .28634 .35369 Metetra
.843 .574 0 r
.28634 .35369 .29142 .38537 .30212 .38165 .29699 .34996 Metetra
.843 .573 0 r
.29699 .34996 .30212 .38165 .31286 .37792 .30767 .34621 Metetra
.843 .573 0 r
.30767 .34621 .31286 .37792 .32365 .37418 .3184 .34243 Metetra
.843 .573 0 r
.3184 .34243 .32365 .37418 .33448 .37041 .32918 .33863 Metetra
.843 .573 0 r
.32918 .33863 .33448 .37041 .34535 .36663 .34 .33481 Metetra
.843 .573 0 r
.34 .33481 .34535 .36663 .35627 .36283 .35086 .33096 Metetra
.843 .573 0 r
.35086 .33096 .35627 .36283 .36724 .35901 .36177 .32709 Metetra
.843 .573 0 r
.36177 .32709 .36724 .35901 .37825 .35518 .37273 .3232 Metetra
.843 .573 0 r
.37273 .3232 .37825 .35518 .3893 .35133 .38373 .31928 Metetra
.843 .573 0 r
.38373 .31928 .3893 .35133 .4004 .34746 .39477 .31534 Metetra
.843 .574 0 r
.39477 .31534 .4004 .34746 .41155 .34358 .40586 .31137 Metetra
.843 .574 0 r
.40586 .31137 .41155 .34358 .42274 .33967 .417 .30738 Metetra
.843 .574 0 r
.417 .30738 .42274 .33967 .43398 .33575 .42818 .30336 Metetra
.843 .575 0 r
.42818 .30336 .43398 .33575 .44527 .33181 .43941 .29932 Metetra
.843 .575 0 r
.43941 .29932 .44527 .33181 .4566 .32786 .45069 .29526 Metetra
.842 .575 0 r
.45069 .29526 .4566 .32786 .46799 .32388 .46201 .29117 Metetra
.842 .576 0 r
.46201 .29117 .46799 .32388 .47942 .31989 .47338 .28705 Metetra
.842 .577 0 r
.47338 .28705 .47942 .31989 .49089 .31588 .4848 .28291 Metetra
.842 .577 0 r
.4848 .28291 .49089 .31588 .50242 .31185 .49626 .27874 Metetra
.842 .578 0 r
.49626 .27874 .50242 .31185 .51399 .30779 .50777 .27454 Metetra
.841 .579 0 r
.50777 .27454 .51399 .30779 .52561 .30372 .51933 .27032 Metetra
.841 .579 0 r
.51933 .27032 .52561 .30372 .53729 .29964 .53094 .26608 Metetra
.841 .58 0 r
.53094 .26608 .53729 .29964 .54901 .29553 .54259 .2618 Metetra
.84 .581 0 r
.54259 .2618 .54901 .29553 .56078 .2914 .5543 .2575 Metetra
.84 .582 0 r
.5543 .2575 .56078 .2914 .5726 .28725 .56605 .25317 Metetra
.84 .583 0 r
.56605 .25317 .5726 .28725 .58447 .28308 .57785 .24881 Metetra
.839 .584 0 r
.57785 .24881 .58447 .28308 .59639 .27889 .5897 .24443 Metetra
.839 .586 0 r
.5897 .24443 .59639 .27889 .60837 .27468 .6016 .24001 Metetra
.838 .587 0 r
.6016 .24001 .60837 .27468 .62039 .27042 .61354 .23554 Metetra
.838 .589 0 r
.61354 .23554 .62039 .27042 .63246 .26605 .62554 .23096 Metetra
.836 .593 0 r
.62554 .23096 .63246 .26605 .64457 .26133 .63757 .22606 Metetra
.833 .604 0 r
.63757 .22606 .64457 .26133 .65669 .25563 .64961 .22026 Metetra
.824 .63 0 r
.64961 .22026 .65669 .25563 .66873 .24754 .66159 .21227 Metetra
.802 .688 0 r
.66159 .21227 .66873 .24754 .68055 .23445 .67338 .19974 Metetra
.718 .757 0 r
.67338 .19974 .68055 .23445 .69187 .21276 .68473 .17939 Metetra
.407 .677 0 r
.68473 .17939 .69187 .21276 .7024 .17914 .69539 .14818 Metetra
.034 .553 0 r
.69539 .14818 .7024 .17914 .71193 .13275 .70515 .10528 Metetra
0 .377 .264 r
.03849 .29852 .04184 .32956 .04484 .36797 .04219 .33121 Metetra
0 .511 .06 r
.04219 .33121 .04484 .36797 .04958 .39631 .04744 .35518 Metetra
.176 .605 0 r
.04744 .35518 .04958 .39631 .05616 .41346 .0543 .36954 Metetra
.355 .662 0 r
.0543 .36954 .05616 .41346 .06419 .42147 .06243 .37605 Metetra
.462 .692 0 r
.06243 .37605 .06419 .42147 .07315 .42351 .07137 .37746 Metetra
.514 .706 0 r
.07137 .37746 .07315 .42351 .08261 .4224 .08075 .37616 Metetra
.538 .713 0 r
.08075 .37616 .08261 .4224 .0923 .41987 .09034 .37364 Metetra
.548 .715 0 r
.09034 .37364 .0923 .41987 .10211 .4168 .10004 .37065 Metetra
.554 .717 0 r
.10004 .37065 .10211 .4168 .11199 .41354 .1098 .3675 Metetra
.559 .718 0 r
.1098 .3675 .11199 .41354 .1219 .41022 .11961 .36427 Metetra
.563 .719 0 r
.11961 .36427 .1219 .41022 .13187 .40685 .12946 .361 Metetra
.566 .72 0 r
.12946 .361 .13187 .40685 .14187 .40347 .13936 .35771 Metetra
.57 .721 0 r
.13936 .35771 .14187 .40347 .15191 .40007 .14929 .35438 Metetra
.573 .722 0 r
.14929 .35438 .15191 .40007 .162 .39664 .15927 .35102 Metetra
.576 .722 0 r
.15927 .35102 .162 .39664 .17213 .39318 .16929 .34763 Metetra
.579 .723 0 r
.16929 .34763 .17213 .39318 .1823 .38971 .17936 .34422 Metetra
.582 .724 0 r
.17936 .34422 .1823 .38971 .19251 .38621 .18947 .34077 Metetra
.584 .725 0 r
.18947 .34077 .19251 .38621 .20277 .38269 .19962 .33729 Metetra
.587 .725 0 r
.19962 .33729 .20277 .38269 .21306 .37915 .20981 .33378 Metetra
.589 .726 0 r
.20981 .33378 .21306 .37915 .2234 .37558 .22005 .33024 Metetra
.591 .726 0 r
.22005 .33024 .2234 .37558 .23379 .37199 .23033 .32667 Metetra
.593 .727 0 r
.23033 .32667 .23379 .37199 .24421 .36838 .24065 .32307 Metetra
.594 .727 0 r
.24065 .32307 .24421 .36838 .25468 .36474 .25102 .31944 Metetra
.596 .727 0 r
.25102 .31944 .25468 .36474 .26519 .36108 .26143 .31578 Metetra
.597 .728 0 r
.26143 .31578 .26519 .36108 .27575 .3574 .27188 .31209 Metetra
.598 .728 0 r
.27188 .31209 .27575 .3574 .28634 .35369 .28238 .30837 Metetra
.599 .728 0 r
.28238 .30837 .28634 .35369 .29699 .34996 .29293 .30462 Metetra
.6 .729 0 r
.29293 .30462 .29699 .34996 .30767 .34621 .30351 .30084 Metetra
.601 .729 0 r
.30351 .30084 .30767 .34621 .3184 .34243 .31414 .29703 Metetra
.601 .729 0 r
.31414 .29703 .3184 .34243 .32918 .33863 .32482 .29319 Metetra
.601 .729 0 r
.32482 .29319 .32918 .33863 .34 .33481 .33553 .28931 Metetra
.602 .729 0 r
.33553 .28931 .34 .33481 .35086 .33096 .3463 .28541 Metetra
.602 .729 0 r
.3463 .28541 .35086 .33096 .36177 .32709 .35711 .28147 Metetra
.601 .729 0 r
.35711 .28147 .36177 .32709 .37273 .3232 .36796 .27751 Metetra
.601 .729 0 r
.36796 .27751 .37273 .3232 .38373 .31928 .37886 .27351 Metetra
.6 .729 0 r
.37886 .27351 .38373 .31928 .39477 .31534 .3898 .26948 Metetra
.6 .728 0 r
.3898 .26948 .39477 .31534 .40586 .31137 .40079 .26542 Metetra
.599 .728 0 r
.40079 .26542 .40586 .31137 .417 .30738 .41182 .26132 Metetra
.598 .728 0 r
.41182 .26132 .417 .30738 .42818 .30336 .4229 .2572 Metetra
.597 .728 0 r
.4229 .2572 .42818 .30336 .43941 .29932 .43402 .25304 Metetra
.595 .727 0 r
.43402 .25304 .43941 .29932 .45069 .29526 .44519 .24886 Metetra
.594 .727 0 r
.44519 .24886 .45069 .29526 .46201 .29117 .4564 .24463 Metetra
.592 .726 0 r
.4564 .24463 .46201 .29117 .47338 .28705 .46766 .24038 Metetra
.59 .726 0 r
.46766 .24038 .47338 .28705 .4848 .28291 .47897 .23609 Metetra
.588 .725 0 r
.47897 .23609 .4848 .28291 .49626 .27874 .49032 .23177 Metetra
.586 .725 0 r
.49032 .23177 .49626 .27874 .50777 .27454 .50171 .22741 Metetra
.583 .724 0 r
.50171 .22741 .50777 .27454 .51933 .27032 .51316 .22302 Metetra
.581 .724 0 r
.51316 .22302 .51933 .27032 .53094 .26608 .52465 .2186 Metetra
.578 .723 0 r
.52465 .2186 .53094 .26608 .54259 .2618 .53618 .21414 Metetra
.575 .722 0 r
.53618 .21414 .54259 .2618 .5543 .2575 .54777 .20965 Metetra
.572 .721 0 r
.54777 .20965 .5543 .2575 .56605 .25317 .55939 .20512 Metetra
.568 .72 0 r
.55939 .20512 .56605 .25317 .57785 .24881 .57107 .20055 Metetra
.565 .72 0 r
.57107 .20055 .57785 .24881 .5897 .24443 .58279 .19595 Metetra
.561 .719 0 r
.58279 .19595 .5897 .24443 .6016 .24001 .59456 .19131 Metetra
.557 .718 0 r
.59456 .19131 .6016 .24001 .61354 .23554 .60637 .18662 Metetra
.552 .716 0 r
.60637 .18662 .61354 .23554 .62554 .23096 .61823 .18182 Metetra
.544 .714 0 r
.61823 .18182 .62554 .23096 .63757 .22606 .63013 .17673 Metetra
.529 .71 0 r
.63013 .17673 .63757 .22606 .64961 .22026 .64204 .17086 Metetra
.495 .701 0 r
.64204 .17086 .64961 .22026 .66159 .21227 .65391 .16312 Metetra
.421 .681 0 r
.65391 .16312 .66159 .21227 .67338 .19974 .66562 .15151 Metetra
.283 .64 0 r
.66562 .15151 .67338 .19974 .68473 .17939 .67698 .13322 Metetra
.071 .568 0 r
.67698 .13322 .68473 .17939 .69539 .14818 .68776 .10564 Metetra
0 .455 .165 r
.68776 .10564 .69539 .14818 .70515 .10528 .6978 .06801 Metetra
0 .19 .252 r
.03634 .26033 .03849 .29852 .04219 .33121 .041 .28577 Metetra
0 .366 .273 r
.041 .28577 .04219 .33121 .04744 .35518 .04693 .3042 Metetra
0 .446 .178 r
.04693 .3042 .04744 .35518 .0543 .36954 .05417 .31498 Metetra
0 .495 .092 r
.05417 .31498 .0543 .36954 .06243 .37605 .06244 .31954 Metetra
0 .522 .038 r
.06244 .31954 .06243 .37605 .07137 .37746 .07136 .32007 Metetra
0 .534 .009 r
.07136 .32007 .07137 .37746 .08075 .37616 .08065 .31846 Metetra
.005 .54 0 r
.08065 .31846 .08075 .37616 .09034 .37364 .09012 .31588 Metetra
.012 .544 0 r
.09012 .31588 .09034 .37364 .10004 .37065 .09969 .31291 Metetra
.017 .546 0 r
.09969 .31291 .10004 .37065 .1098 .3675 .10931 .3098 Metetra
.021 .547 0 r
.10931 .3098 .1098 .3675 .11961 .36427 .11897 .30663 Metetra
.025 .549 0 r
.11897 .30663 .11961 .36427 .12946 .361 .12869 .30341 Metetra
.028 .55 0 r
.12869 .30341 .12946 .361 .13936 .35771 .13844 .30016 Metetra
.032 .552 0 r
.13844 .30016 .13936 .35771 .14929 .35438 .14824 .29687 Metetra
.035 .553 0 r
.14824 .29687 .14929 .35438 .15927 .35102 .15808 .29355 Metetra
.038 .554 0 r
.15808 .29355 .15927 .35102 .16929 .34763 .16796 .29018 Metetra
.041 .555 0 r
.16796 .29018 .16929 .34763 .17936 .34422 .17789 .28679 Metetra
.044 .557 0 r
.17789 .28679 .17936 .34422 .18947 .34077 .18785 .28336 Metetra
.046 .558 0 r
.18785 .28336 .18947 .34077 .19962 .33729 .19787 .2799 Metetra
.049 .559 0 r
.19787 .2799 .19962 .33729 .20981 .33378 .20792 .27639 Metetra
.051 .559 0 r
.20792 .27639 .20981 .33378 .22005 .33024 .21802 .27286 Metetra
.053 .56 0 r
.21802 .27286 .22005 .33024 .23033 .32667 .22816 .26928 Metetra
.055 .561 0 r
.22816 .26928 .23033 .32667 .24065 .32307 .23835 .26568 Metetra
.056 .562 0 r
.23835 .26568 .24065 .32307 .25102 .31944 .24857 .26203 Metetra
.058 .562 0 r
.24857 .26203 .25102 .31944 .26143 .31578 .25885 .25835 Metetra
.059 .563 0 r
.25885 .25835 .26143 .31578 .27188 .31209 .26916 .25464 Metetra
.06 .563 0 r
.26916 .25464 .27188 .31209 .28238 .30837 .27952 .25089 Metetra
.061 .564 0 r
.27952 .25089 .28238 .30837 .29293 .30462 .28992 .2471 Metetra
.062 .564 0 r
.28992 .2471 .29293 .30462 .30351 .30084 .30037 .24327 Metetra
.063 .564 0 r
.30037 .24327 .30351 .30084 .31414 .29703 .31086 .23941 Metetra
.063 .564 0 r
.31086 .23941 .31414 .29703 .32482 .29319 .32139 .23552 Metetra
.064 .564 0 r
.32139 .23552 .32482 .29319 .33553 .28931 .33197 .23158 Metetra
.064 .564 0 r
.33197 .23158 .33553 .28931 .3463 .28541 .34259 .22762 Metetra
.064 .564 0 r
.34259 .22762 .3463 .28541 .35711 .28147 .35325 .22361 Metetra
.063 .564 0 r
.35325 .22361 .35711 .28147 .36796 .27751 .36396 .21957 Metetra
.063 .564 0 r
.36396 .21957 .36796 .27751 .37886 .27351 .37471 .21549 Metetra
.062 .564 0 r
.37471 .21549 .37886 .27351 .3898 .26948 .38551 .21137 Metetra
.062 .564 0 r
.38551 .21137 .3898 .26948 .40079 .26542 .39635 .20722 Metetra
.061 .563 0 r
.39635 .20722 .40079 .26542 .41182 .26132 .40723 .20302 Metetra
.06 .563 0 r
.40723 .20302 .41182 .26132 .4229 .2572 .41816 .19879 Metetra
.059 .562 0 r
.41816 .19879 .4229 .2572 .43402 .25304 .42913 .19453 Metetra
.057 .562 0 r
.42913 .19453 .43402 .25304 .44519 .24886 .44015 .19022 Metetra
.056 .561 0 r
.44015 .19022 .44519 .24886 .4564 .24463 .45121 .18588 Metetra
.054 .561 0 r
.45121 .18588 .4564 .24463 .46766 .24038 .46231 .1815 Metetra
.052 .56 0 r
.46231 .1815 .46766 .24038 .47897 .23609 .47346 .17708 Metetra
.05 .559 0 r
.47346 .17708 .47897 .23609 .49032 .23177 .48465 .17262 Metetra
.048 .558 0 r
.48465 .17262 .49032 .23177 .50171 .22741 .49589 .16812 Metetra
.045 .557 0 r
.49589 .16812 .50171 .22741 .51316 .22302 .50717 .16358 Metetra
.042 .556 0 r
.50717 .16358 .51316 .22302 .52465 .2186 .5185 .159 Metetra
.04 .555 0 r
.5185 .159 .52465 .2186 .53618 .21414 .52987 .15438 Metetra
.037 .554 0 r
.52987 .15438 .53618 .21414 .54777 .20965 .54128 .14972 Metetra
.034 .553 0 r
.54128 .14972 .54777 .20965 .55939 .20512 .55274 .14502 Metetra
.03 .551 0 r
.55274 .14502 .55939 .20512 .57107 .20055 .56424 .14028 Metetra
.027 .55 0 r
.56424 .14028 .57107 .20055 .58279 .19595 .57579 .1355 Metetra
.023 .548 0 r
.57579 .1355 .58279 .19595 .59456 .19131 .58738 .13068 Metetra
.019 .547 0 r
.58738 .13068 .59456 .19131 .60637 .18662 .59902 .1258 Metetra
.015 .545 0 r
.59902 .1258 .60637 .18662 .61823 .18182 .61069 .12082 Metetra
.009 .542 0 r
.61069 .12082 .61823 .18182 .63013 .17673 .62241 .1156 Metetra
0 .538 0 r
.62241 .1156 .63013 .17673 .64204 .17086 .63414 .10976 Metetra
0 .53 .02 r
.63414 .10976 .64204 .17086 .65391 .16312 .64586 .10244 Metetra
0 .512 .059 r
.64586 .10244 .65391 .16312 .66562 .15151 .65746 .09206 Metetra
0 .476 .128 r
.65746 .09206 .66562 .15151 .67698 .13322 .6688 .07643 Metetra
0 .414 .223 r
.6688 .07643 .67698 .13322 .68776 .10564 .67971 .05345 Metetra
0 .318 .304 r
.67971 .05345 .68776 .10564 .6978 .06801 .69004 .02248 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15783 .20788 m
.16244 .21256 L
s
[(-5)] .14862 .19854 .98551 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54216 .05739 m
.54606 .06267 L
s
[(5)] .53437 .04684 .73896 1 Mshowa
.125 Mabswid
.19384 .19379 m
.19657 .19662 L
s
.23036 .17949 m
.23305 .18236 L
s
.26739 .16499 m
.27004 .1679 L
s
.30496 .15028 m
.30757 .15322 L
s
.38173 .12022 m
.38425 .12323 L
s
.42095 .10486 m
.42344 .10791 L
s
.46076 .08927 m
.4632 .09236 L
s
.50116 .07345 m
.50355 .07658 L
s
.12233 .22179 m
.12512 .22456 L
s
.08731 .2355 m
.09014 .23824 L
s
.05276 .24903 m
.05563 .25173 L
s
.58379 .0411 m
.58607 .0443 L
s
.62604 .02455 m
.62828 .02779 L
s
.66894 .00775 m
.67112 .01103 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00boooool2o`0005?ooooo0038ooooo`?o000000?o
ooooo`000?ooool0D_ooool00<Kooooo0_l00004ooooo`;o0000D_ooool00<?ooooo0ol00002oooo
o`07o`000?ooooooooooooooool0003oooooo`00001Aooooo`00Woooool3o`0001kooooo0ol00009
ooooo`04o`000?oooooo0000o`00053ooooo002Nooooo`05o`000?ooooooooooooooool000006ooo
ool2o`0000cooooo00Co0000oooooooooooo0000D?ooool00:;ooooo00?o0000ooooooooool05_oo
ool3o`0000kooooo0_l00002ooooo`03o`000?oooooooooo04gooooo002Rooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0>ooooo`;o00000_ooool00ol0003oooooooooo`1=
ooooo`00W_ooool4o`0001Cooooo0ol0000Cooooo`;o00000oooool00ol0003oooooooooo`1<oooo
o`00W_ooool00ol0003oooooooooo`0Cooooo`;o00005_ooool2o`0000Cooooo00?o0000oooooooo
ool0Boooool009kooooo1Ol0000>ooooo`?o00006?ooool3o`0000?ooooo00?o0000ooooooooool0
Boooool00:kooooo1?l0000Iooooo`04o`000?l0DDgo0000o`0000Cooooo00?o0000ooooooooool0
B_ooool00:cooooo0_l00003ooooo`03o`000?oooooooooo01Oooooo00Co0000o`1ACOl0003o0000
1?ooool2o`0004_ooooo002Yooooo`?o00007oooool01?l0003o055=o`000?l00005ooooo`03o`00
0?oooooooooo04Wooooo002Wooooo`;o00008Oooool00ol0003o055=o`1AC@02o`0000Kooooo00?o
0000ooooooooool0B?ooool00:Cooooo0ol0000Sooooo`03o`000?l0DDgo055=00;o00001_ooool0
0ol0003oooooooooo`18ooooo`00X_ooool2o`0000;ooooo00?o0000ooooooooool08?ooool2o`00
00;o055=00?o0000o`1ACOl000001_ooool00ol0003oooooooooo`17ooooo`00Woooool3o`0000Go
oooo00?o0000ooooooooool07oooool2o`0000;o055=00?o0000o`1ACOl000001oooool00ol0003o
ooooooooo`16ooooo`00WOooool2o`0002Wooooo00So0000o`1Y>Ol0JCWo0000o`1ACOl0003o055=
o`0000Oooooo00?o0000ooooooooool0A_ooool009[ooooo0ol0000[ooooo`08o`000?l0JCWo06Ti
o`000?l0DDgo0000o`1ACOl00008ooooo`03o`000?oooooooooo04Gooooo002Gooooo`?o000000?o
ooooo`000?ooool0:_ooool02Ol0003o06Tio`1Y>Ol0JCWo0000o`1ACOl0003o055=o`000008oooo
o`;o0000A_ooool009Gooooo0_l0000`ooooo`06o`000?l0JCWo06Tio`1Y>Ol0003o055=0_l00000
0ol0M2[o0000ooooo`07ooooo`03o`000?oooooooooo04Cooooo002Booooo`?o0000<Oooool2o`00
00?o06Ti00Ko0000o`1ACOl0003o0000o`1d:_l00009ooooo`03o`000?oooooooooo00_ooooo0ol0
000eooooo`00T?ooool2o`0003?ooooo00?o0000o`1i8?l000000ol0JCT01_l0003o055=o`000?l0
003o07@Zo`0000[ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000003Co
oooo002=ooooo`Go0000<_ooool01?l0003o07TPo`1i8?l00003o`1Y>@03o`000?l0DDgo000000;o
07@Z00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`Go00001Oooool00ol0003o
ooooooooo`0booooo`00Joooool2o`0001kooooo0_l0000fooooo`;o00000ol0NB001?l0003o06Ti
o`1Y>Ol0JCT3o`000003o`1d:_l0003ooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0booooo`00J_ooool01?l0003oooooooooool0000Jooooo`?o0000=oooool00ol0003o
08<?o`000003o`1i8004o`000?l0JCWo06Tio`1Y>@?o00000_l0M2X00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Oooooo1?l0000eooooo`00J_ooool01?l0003oooooooooool0000Goooo
o`?o0000>?ooool2o`0000;o08<?00Go0000o`1i8?l0NB3o07TPo`000003o`1Y>@03o`000?l0M2[o
000000;o07@Z00?o0000ooooooooool02Oooool2o`0000Sooooo00?o0000ooooooooool0=_ooool0
06[ooooo00Co0000oooooooooooo00005Oooool2o`000003ooooool0003ooooo03Oooooo00?o0000
o`271Ol000000_l0P`l01Ol0003o07TPo`1i8?l0NB3o000000?o06Ti00?o0000o`1d:_l000000_l0
M2X00ol0003oooooooooo`09ooooo`;o00002?ooool5o`0003Cooooo001Zooooo`04o`000?oooooo
ooooo`0001;ooooo0ol00003ooooo`03o`000?oooooooooo03Cooooo0_l00002o`271@05o`000?l0
P`oo08<?o`233ol000000_l0NB001ol0003o06Tio`1Y>Ol0JCWo0000o`1d:_l000000_l0M2X00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03kooooo001Zooooo`04o`000?ooooooooooo`00
013ooooo0_l0000looooo`03o`000?l0R@3o000000;o08L500Go0000o`233ol0P`oo08<?o`000002
o`1i8003o`000?l0JCWo06Ti00;o000000Go07@Zo`000?l0M2[o07@Zo`00000=ooooo`03o`000?oo
oooooooo03kooooo001[ooooo`;o00003_ooool3o`0003cooooo0_l00002o`290004o`000?l0Q`Go
08L5o`0000?o08<?00Co0000o`1i8?l0NB3o00000_l0JCT2o`000003o`1d:_l0003o07@Z00;o0000
3_ooool00ol0003oooooooooo`0mooooo`00NOooool3o`0003_ooooo0ol000001Ol2RP3o0000o`29
0?l0R@3o000000?o08L500Co0000o`233ol0P`oo00000ol0NB02o`0000;o4Y400_l000001?l0M2[o
0000o`R=0?l0000>ooooo`03o`000?oooooooooo03cooooo001fooooo`?o00000oooool00ol0003o
ooooooooo`0eooooo`?o000000Go0h/0o`000?l2RP3o0XX0o`000002o`290005o`000?l0Q`Go08L5
o`271Ol000000_l0P`l01?l0003o07TPo`1i8?l0NB02o`0000;o4Y400_l000001?l0M2[o0000o`R=
0?l0000>ooooo`03o`000?oooooooooo03cooooo001cooooo`?o0000?Oooool00ol0003o18`0o`00
0002o`>;0004o`000?l2RP3o0XX0o`0000?o08T000Co0000o`271Ol0Q`Go00000_l0P`l01?l0003o
07TPo`1i8?l0NB02o`0000;o4Y400ol00002o`R=0003o`000?oooooooooo00gooooo00?o0000oooo
ooooool0>oooool0077ooooo0_l0000nooooo`;o00000_l4S0001?l0003o0h/0o`>;0?l00002o`::
0005o`000?l0R@3o08T0o`290?l000000_l0Q`D01?l0003o08<?o`233ol00003o`1i8004o`000?lB
T@3o4Y40oa:A00?o00000_l8S@000ol0003oooooooooo`0=ooooo`;o0000??ooool006kooooo1?l0
000kooooo`Co000000Go1H`0o`000?l4S03o18`0o`000002o`>;0005o`000?l2RP3o0XX0o`::0?l0
00000_l0R@001?l0003o08L5o`271Ol00002o`233`05o`000?l0NB3o07TPo`1i8?l000000olBT@03
o`0000;o28d000?o0000ooooooooool03_ooool00ol0003oooooooooo`0jooooo`00K?ooool2o`00
00Cooooo00?o0000ooooooooool0=Oooool3o`0000;o1X`000Co0000o`F<0?l5S03o00000_l4S000
1Ol0003o0h/0o`>;0?l3R`3o000000;o0XX000Co0000o`290?l0R@3o00000_l0Q`D01_l0003o08<?
o`233ol0P`oo0000o`1i80;o00001?lBT@02o`0000;o28d00_l0000@ooooo`03o`000?oooooooooo
03Wooooo001Yooooo`?o0000>oooool3o`000003o`N=0?l0003o1X`000;o1X`000Co0000o`F<0?l5
S03o00000ol4S0001?l0003o0h/0o`>;0?l00002o`::0004o`000?l0R@3o08T0o`0000;o08L500Co
0000o`233ol0P`oo08<?0_l000000om8X`3o0000oa:A0003oa:A0004o`000?l8S@3o28d0o`R=00;o
00004Oooool00ol0003oooooooooo`0hooooo`00Ioooool2o`0003gooooo00?o0000o`R=0?l00000
0_l7S@001Ol0003o1X`0o`J<0?l6S03o000000;o1H`000Go0000o`B<0?l4S03o18`0o`000002o`>;
0004o`000?l2RP3o0XX0o`0000;o08T000Co0000o`271Ol0Q`Go00000ol0P`l2o`0000;oB:<000Go
0000oa:A0?lBT@3o4Y40o`000002o`R=0003o`000?lbW03o0000017ooooo00?o0000ooooooooool0
>?ooool006Cooooo1Ol0000kooooo`;o00000_l8S@001?l0003o1hd0o`N=0?l00003o`J<0004o`00
0?l5S03o1H`0o`0000?o18`000Co0000o`>;0?l3R`3o00000_l2RP001?l0003o08T0o`290?l00003
o`271@04o`000?l0P`oo08<?o`0000?oB:<000Go0000oa:A0?lBT@3o4Y40o`000002o`R=0004o`00
0?lbW03o<Y`0o`00017ooooo00?o0000ooooooooool0=oooool0067ooooo0ol0000mooooo`?o0000
00Go2Hd0o`000?l8S@3o28d0o`000002o`N=0005o`000?l6S03o1X`0o`J<0?l000000_l5S0001Ol0
003o18`0o`B<0?l4S03o000000;o0h/000Co0000o`::0?l2RP3o00000_l0R@001_l0003o08L5o`27
1Ol0Q`Go0000o`233`;o00000om8X`000ol0003o4Y40oa:A0002o`0000;o28d000Co0000oc:L0?lb
W03o00004_ooool00ol0003oooooooooo`0fooooo`00Goooool2o`0003gooooo0ol000001Ol:SP3o
0000o`V=0?l9S@3o000000;o28d000Go0000o`N=0?l7S@3o1hd0o`000002o`J<0004o`000?l5S03o
1H`0o`0000?o18`000Co0000o`>;0?l3R`3o00000_l2RP001Ol0003o08T0o`290?l0R@3o000000;o
08L50_l000000om[[P3o0000odRS0002odRS0008o`000?lBT@3o4Y40o`000?mX[@3o0000o`R=0?l0
0002oc:L00;o00004Oooool2o`0003Oooooo001Looooo`?o0000??ooool3o`000005o`Z>0?l0003o
2Xh0o`Z>0?l000000_l9S@001Ol0003o28d0o`R=0?l8S@3o000000;o1hd000Co0000o`J<0?l6S03o
00000_l5S0001Ol0003o18`0o`B<0?l4S03o000000;o0h/000Co0000o`::0?l2RP3o00000ol0R@00
1?l0003o08L5o`000?l00002of^^0005o`000?m8X`3oB:<0odRS0?l000000_lBT@001Ol0003oJ:d0
o`000?l8S@3o000000;o<Y`00_l0000Booooo`03o`000?oooooooooo03Gooooo000iooooo`?o0000
7_ooool2o`000003ooooool0003o000003Wooooo0ol000001Ol;SP3o0000o`Z>0?l:SP3o000000;o
2Xh000Co0000o`V=0?l9S@3o00000ol8S@001?l0003o1hd0o`N=0?l00002o`J<0005o`000?l5S03o
1H`0o`F<0?l000000_l4S0001?l0003o0h/0o`>;0?l00003o`::0003o`000?l0R@3o08T000;o0000
00?oO[<0o`000?m[[P000_m[[P001_l0003oB:<0odRS0?l0003o4Y40o`0000;oJ:d000Go0000o`R=
0?l0003o<Y`0o`000002odbU0003o`000?oooooooooo00oooooo00?o0000ooooooooool0=Oooool0
03Sooooo00Go0000ooooooooooooooooo`00000Jooooo`?o0000?Oooool00ol0003o38h0o`000002
o`^>0004o`000?l:SP3o2Xh0o`0000;o2Xh000Go0000o`V=0?l9S@3o2Hd0o`000002o`R=0004o`00
0?l7S@3o1hd0o`0000?o1X`000Co0000o`F<0?l5S03o00000_l4S0001Ol0003o0h/0o`>;0?l3R`3o
000000;o0XX000Co0000o`290?l0003o00000_mn/`001Ol0003oJjh0of^^0?m[[P3o000000?oB:<0
0_l00002ofR]00;o00000_lbW0001?l0003oC:D0odbU0?l0000Booooo`03o`000?oooooooooo03Co
oooo000booooo`Go00001Oooool00ol0003oooooooooo`0Fooooo`;o0000?_ooool2o`0000;o38h0
00Co0000o`^>0?l;SP3o00000_l:SP001Ol0003o2Xh0o`Z>0?l:SP3o000000;o2Hd000Co0000o`R=
0?l8S@3o00000_l7S@001Ol0003o1X`0o`J<0?l6S03o000000;o1H`000Go0000o`B<0?l4S03o18`0
o`000002o`>;0003o`000?l2RP3o0XX000;o000000GoQkD0o`000?mn/`3oO[<0o`000003of^^0004
o`000?m8X`3oB:<0odRS00;o00000_mX[@02o`0000;o<Y`000?o0000odbU0?m<Y@000_l0000Boooo
o`03o`000?oooooooooo03?ooooo000looooo`03o`000?oooooooooo01?ooooo0ol0000nooooo`;o
000000Go38l0o`000?l<SP3o38h0o`000002o`^>0005o`000?l:SP3o2Xh0o`Z>0?l000000_l:SP00
1?l0003o2Hd0o`V=0?l00002o`R=0004o`000?l7S@3o1hd0o`0000?o1X`000Co0000o`F<0?l5S03o
00000ol4S0001Ol0003o0h/0o`>;0?l0003o0XX000;o00000_n7]@001Ol0003oO[<0ogjc0?mn/`3o
000000;oJjh000Go0000odRS0?m8X`3oB:<0o`000003ofR]00;o00000_lbW0001Ol0003oC:D0o`00
0?mIZ03o000001;ooooo00?o0000ooooooooool0<oooool003Sooooo1?l0000Cooooo`?o00000_oo
ool00ol0003oooooooooo`0iooooo`?o000000Co3Hl0o`000?l<S`3o00000_l<SP001Ol0003o2hh0
o`^>0?l;SP3o000000;o2Xh000Co0000o`Z>0?l:SP3o00000_l9S@001?l0003o28d0o`R=0?l00002
o`N=0005o`000?l6S03o1X`0o`J<0?l000000_l5S0001_l0003o18`0o`B<0?l4S03o0000o`>;00?o
000000GoRkH0o`000?n7]@3oQkD0o`000003ogjc0004o`000?m[[P3oJjh0o`0000?oB:<000Co0000
ofR]0?mX[@3oJ:d00_l00002oc:L0004o`000?m<Y@3o0000oeVX00;o00004_ooool00ol0003ooooo
ooooo`0booooo`00>?ooool00ol0003oooooooooo`0Booooo`;o0000?_ooool3o`000007o`f?0?l0
003o3Hl0o`f?0?l0003o38l0o`000003o`b>0004o`000?l;SP3o2hh0o`0000;o2Xh000Co0000o`Z>
0?l:SP3o00000_l9S@001?l0003o28d0o`R=0?l00002o`N=0005o`000?l6S03o1X`0o`J<0?l00000
0_l5S0000ol0003o18`0o`B<0003o`000005ohfg0?l0003oRkH0oh^f0?l000000on7]@001?l0003o
O[<0ogjc0?l00002of^^0003o`000?m8X`3oB:<000;o00000omX[@002ol0003oZ[h0o`000?lbW03o
0000odbU0?l0003oFJP0o`000?mMZP3o0000017ooooo0_l0000cooooo`00>?ooool5o`0000gooooo
0ol0000mooooo`?o000000Go3Xl0o`000?l=S`3o3Hl0o`000002o`f?0003o`000?l<S`3o000000?o
38h000Co0000o`^>0?l;SP3o00000_l:SP001?l0003o2Xh0o`Z>0?l00002o`V=0004o`000?l8S@3o
28d0o`0000?o1hd000Co0000o`J<0?l6S03o00000_l5S003o`000005ohjg0?l0003oSKL0ohfg0?l0
00000_n;]P001Ol0003oQkD0ohNe0?n7]@3o000000;oO[<000Co0000of^^0?m[[P3o00000_m8X`00
0ol0003o]l40o`000002ofR]0006o`000?nZ_P3o0000oc:L0?l0003oC:D00_l00002oefZ0003o`00
0?oooooooooo013ooooo00?o0000ooooooooool0<Oooool004Sooooo0ol0000looooo`?o000000Go
3Xl0o`000?l>S`3o3Xl0o`000002o`f?0004o`000?l=S`3o3Hl0o`0000;o38l000Co0000o`b>0?l<
SP3o00000_l;SP001?l0003o2Xh0o`Z>0?l00002o`Z>0004o`000?l9S@3o2Hd0o`0000?o28d000Co
0000o`N=0?l7S@3o00000_l6S0001?l0003o1H`0o`000?l00003ohjg0004o`000?n=]`3oSKL0o`00
00?oRkH000Co0000ohNe0?n7]@3o00000_mn/`001?l0003oJjh0of^^0?m[[P02o`0000;o]l4000Go
0000ofR]0?mX[@3o0000ojZn0002o`000004odbU0?l0003oFJP0o`0000;oGJX00_l0000Booooo`03
o`000?oooooooooo033ooooo0015ooooo`?o00000_ooool00ol0003oooooooooo`0gooooo`?o0000
00Go3hl0o`000?l>S`3o3Xl0o`000002o`j?0004o`000?l=S`3o3Hl0o`0000;o3Hl000Co0000o`b?
0?l<S`3o00000_l<SP001?l0003o2hh0o`^>0?l00002o`Z>0004o`000?l:SP3o2Xh0o`0000?o2Hd0
00Co0000o`R=0?l8S@3o00000_l7S@000ol0003o1X`0o`000002o`000003ohnh0?l0003oS[L000;o
S[L000Go0000ohfg0?n=]`3oSKL0o`000002oh^f0004o`000?n7]@3oQkD0o`0000;oO[<000Co0000
of^^0?m[[P3oJjh00_l00002okO10004o`000?mX[@3o0000o`0000;oZ[h000Wo0000odbU0?l0003o
FJP0o`000?mMZP3o0000oen[0?l000004oooool00ol0003oooooooooo`0_ooooo`00@oooool2o`00
03kooooo00?o0000o`n@0?l000000_l?S`001?l0003o3Xl0o`j?0?l00002o`j?0004o`000?l=S`3o
3Hl0o`0000;o3Hl000Co0000o`b?0?l<S`3o00000_l<SP001?l0003o2hh0o`^>0?l00002o`Z>0004
o`000?l:SP3o2Xh0o`0000?o2Hd000Go0000o`R=0?l8S@3o0000o`N=0003o`000005oi2h0?l0003o
SkP0ohnh0?l000001?n>]`001?l0003oSKL0ohfg0?l00002oh^f0004o`000?n7]@3oQkD0o`0000;o
O[<000Go0000of^^0?m[[P3oJjh0o`000003okO10004o`000?mX[@3o0000o`0000;oZ[h000So0000
odbU0?l0003oFJP0o`000?mMZP3o0000oen[00;o00004_ooool00ol0003oooooooooo`0_ooooo`00
@?ooool3o`0003kooooo0_l00002o`n@0004o`000?l?S`3o3hl0o`0000;o3Xl000Co0000o`j?0?l>
S`3o00000_l=S`001?l0003o3Hl0o`f?0?l00002o`b?0004o`000?l<SP3o38h0o`0000;o2hh000Co
0000o`Z>0?l:SP3o00000ol:SP001Ol0003o2Hd0o`V=0?l0003o28d000?o000000GoTKP0o`000?n@
^03oT;P0o`000002ohnh0003o`000?n>]`3oS[L000;oS[L000Co0000ohfg0?n=]`3o00000_n;]P00
1?l0003oQkD0ohNe0?l00003ogjc0004o`000?m[[P3o0000o`0000?o]l4000Co0000ofR]0?l0003o
00000_nZ_P002?l0003oC:D0o`000?mIZ03o0000oefZ0?l0003oGj/00ol0000Booooo`03o`000?oo
oooooooo02kooooo000nooooo`?o0000?Oooool3o`000005o`n@0?l0003o3i00o`n@0?l000000_l?
S`001?l0003o3Xl0o`j?0?l00002o`j?0004o`000?l=S`3o3Hl0o`0000?o3Hl000?o0000o`b?0?l0
00000_l<SP001?l0003o2hh0o`^>0?l00003o`Z>0005o`000?l:SP3o2Xh0o`000?l9S@000ol00000
1OnB^03o0000oi6h0?nA^03o000000;oT;P000Go0000ohnh0?n?^03oSkP0o`000003ohjg0004o`00
0?n=]`3oSKL0o`0000;oRkH000Co0000ohNe0?n7]@3o00000omn/`02o`000003olf`0?l0003o]l40
00?o]l4000Co0000ojZn0?l0003oZ[h00_l000001Om<Y@3o0000oeVX0?l0003oGJX000;o000000Co
Gj/0o`000?mOZ`3o00004_ooool00ol0003oooooooooo`0]ooooo`00>oooool3o`0000?ooooo00?o
0000ooooooooool0=oooool3o`000005o`n@0?l0003o3i00o`n@0?l000000_l?T0001?l0003o3hl0
o`n?0?l00002o`j?0004o`000?l>S`3o3Xl0o`0000?o3Hl000Ko0000o`f?0?l=S`3o0000o`b?0?l0
0002o`b>0005o`000?l;SP3o2hh0o`^>0?l000000_l:SP000ol0003o2Xh0o`Z>0002o`000005oi>h
0?l0003oT[P0oi:h0?l000000_nA^0001Ol0003oT;P0oi2h0?n@^03o000000;oSkP000Go0000ohjg
0?n>]`3oS[L0o`000002ohfg0004o`000?n;]P3oRkH0o`0000?oQkD000Co0000ogjc0?l0003o0000
0oo=/0002ol0003o]l40okO10?ng`@3o0000ojZn0?l0003oZ[h0o`000?o7_@3o000000;oFJP00_l0
00001_mOZ`3o0000oen[0?l0003oGj/0o`0001;ooooo0_l0000^ooooo`00>?ooool3o`0003gooooo
0ol000001Ol?T03o0000o`n@0?l?T03o000000;o3i0000Co0000o`n@0?l?T03o00000_l?S`001?l0
003o3Xl0o`j?0?l00002o`j?0005o`000?l=S`3o3Hl0o`f?0?l000000_l=S`000ol0003o38l0o`00
0003o`b>0004o`000?l;SP3o2hh0o`0000;o2Xh000Co0000o`Z>0?l0003o00000_nC^0001?l0003o
T[P0oi:h0?l00003oi6h0004o`000?n@^03oT;P0o`0000;oSkP000Go0000ohjg0?n>]`3oS[L0o`00
0002ohfg0004o`000?n;]P3oRkH0o`0000?oQkD00_l000000ooBX@3o0000olf`0002olf`000@o`00
0?ng`@3o]l40okO10?l0003oZ[h0o`000?nZ_P3o0000olNm0?l0003oFJP0o`000?mMZP3o0000oen[
00;o00000_mOZ`02o`0001;ooooo00?o0000ooooooooool01oooool2o`0002?ooooo000fooooo`;o
0000?_ooool2o`000005oa2@0?l0003o3i00o`n@0?l000000_l?T0001?l0003o3i00o`n@0?l00002
o`n@0004o`000?l?S`3o3hl0o`0000;o3Xl000Go0000o`j?0?l>S`3o3Xl0o`000002o`f?0004o`00
0?l=S`3o3Hl0o`0000;o38l000Co0000o`b>0?l<SP3o00000_l;SP000ol0003o2Xh0o`000002o`00
0005oi>i0?l0003oTkP0oi>h0?l000000onB^0001?l0003oTKP0oi6h0?l00002oi2h0004o`000?n?
^03oSkP0o`0000?oS[L000Co0000ohfg0?n=]`3o00000on;]P001?l0003oQkD0o`000?l00002om:Q
0005o`000?o=/03ocK00olf`0?l000000_ng`@001Ol0003oe9`0o`000?nZ_P3o000000;oakd00ol0
00000omMZP3o0000oen[0002o`0000;oGj/00ol0000Booooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00008_ooool003?ooooo0ol000000ooooooo0000o`00000jooooo`?o000000Co
4900o`000?l@T03o00000_l?T0001?l0003o3i00o`n@0?l00002o`n@0004o`000?l?T03o3i00o`00
00;o3hl000Go0000o`j?0?l>S`3o3Xl0o`000002o`j?0004o`000?l=S`3o3Hl0o`0000;o3Hl000Co
0000o`b?0?l<S`3o00000_l<SP000ol0003o2hh0o`000002o`000005oiBi0?l0003oTkT0oi>i0?l0
00000onC^0001?l0003oT[P0oi:h0?l00002oi6h0004o`000?n@^03oT;P0o`0000;oSkP000Go0000
ohjg0?n>]`3oS[L0o`000003ohfg0003o`000?n;]P3oRkH000;o000000?oeIX0o`000?oBX@000_oB
X@001?l0003ocK00olf`0?l00002okO10005o`000?oDW03o0000ojZn0?l000000_o7_@001_l0003o
c;<0o`000?mMZP3o0000oen[00;o000000KoGj/0o`000?mOZ`3o0000oenZ0?l0000Aooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo00008_ooool0037ooooo0_l0000mooooo`?o0000
00Oo4900o`000?l@T03o4900o`000?l@T03o000000;o3i0000Co0000o`n@0?l?T03o00000_l?T000
1?l0003o3i00o`n@0?l00003o`n?0004o`000?l>S`3o3Xl0o`0000;o3Xl000Co0000o`f?0?l=S`3o
00000_l=S`001Ol0003o38l0o`b?0?l0003o38h000?o000000GoUKT0o`000?nD^@3oU;T0o`000002
oi>i0005o`000?nC^03oTkP0oi>h0?l000000_nB^0001?l0003oTKP0oi6h0?l00002oi2h0004o`00
0?n?^03oSkP0o`0000CoS[L000Go0000ohfg0?n=]`3o0000oh^f0002o`0000;oeIX000Go0000om:Q
0?oBX@3odZ40o`000002olf`0003o`000?ng`@3o000000;oe9`000Go0000ojZn0?l0003oakd0o`00
0002olbc0004o`000?mMZP3o0000oen[00;o000000KoGj/0o`000?mOZ`3o0000oenZ0?l0000Boooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00008_ooool002kooooo0ol0000loooo
o`?o000000Go4900o`000?l@T03o4900o`000002oa2@0003o`000?l@T03o000000;o3i0000Co0000
o`n@0?l?T03o00000_l?T0001Ol0003o3i00o`n@0?l?T03o000000;o3hl000Co0000o`j?0?l>S`3o
00000_l>S`001?l0003o3Hl0o`f?0?l00002o`f?0003o`000?l<S`3o000000;o000000GoU[T0o`00
0?nE^@3oUKT0o`000002oiBi0005o`000?nC^@3oTkT0oi>i0?l000000_nC^0001?l0003oT[P0oi:h
0?l00002oi6h0004o`000?n@^03oT;P0o`0000?oSkP000Ko0000ohjg0?n>]`3oS[L0o`000?n=]`03
o`000003omJG0?l0003oeIX000;oeIX000Co0000om:Q0?oBX@3o00000oo=/002o`0000?oe9`00_l0
00001?o7_@3o0000olbc0?o</`02o`0000;oGj/00_l000000omOZ`3o0000o`000002oenZ00;o0000
4_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0002;ooooo000/ooooo`?o0000
>oooool3o`000005oa2@0?l0003o4900oa2@0?l000000_l@T0001?l0003o4900oa2@0?l00002oa2@
0003o`000?l?T03o000000;o3i0000Go0000o`n@0?l?T03o3i00o`000002o`n@0004o`000?l?S`3o
3hl0o`0000;o3Xl000Co0000o`j?0?l>S`3o00000_l=S`000ol0003o3Hl0o`000002o`000005oiJi
0?l0003oU[T0oiJi0?l000000_nE^@001Ol0003oU;T0oiBi0?nD^@3o000000;oTkT000Co0000oi>h
0?nC^03o00000_nB^0001?l0003oTKP0oi6h0?l00002oi2h0006o`000?n?^03oSkP0ohnh0?l0003o
S[L01?l000001OoFUP3o0000omJG0?oFU`3o000000?oeIX000Co0000om:Q0?oBX@3o00000oo=/000
0ol0003oe9`0omBL0002omBL00;o000000_oakd0o`000?o</`3o0000olf^0?l0003oGj/0o`000?mO
Z`3o0000oen[0002o`000004oenZ0?l0003oGjX0o`0001;ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool0000Rooooo`00:Oooool3o`0000;ooooo00?o0000ooooooooool0=oooool2
o`000005oa2@0?l0003o4900oa2@0?l000000_l@T0001?l0003o4900oa2@0?l00002oa2@0006o`00
0?l@T03o4900o`000?l?T03o00000ol?T0001?l0003o3i00o`n@0?l00002o`n@0004o`000?l?S`3o
3hl0o`0000;o3Xl000Go0000o`j?0?l>S`3o0000o`f?0003o`000005oiNi0?l0003oU[T0oiJi0?l0
00000_nF^@001Ol0003oUKT0oiFi0?nE^@3o000000;oU;T000Co0000oi>i0?nC^@3o00000_nC^000
1?l0003oT[P0oi:h0?l00002oi6h0006o`000?n@^03oT;P0oi2h0?l0003oSkP00ol00002omJF0004
o`000?oFUP3oeYH0o`0000?oeYL000Co0000omFJ0?oEVP3o00000_oBX@000ol0003ocK00olf`0002
o`0000Coe9`00_l000001Oo7_@3o0000olbc0?l0003ocJh000?o000000?oGj/0o`000?mOZ`000_l0
00000omOZP3o0000oenZ0002o`00017ooooo0_l00005ooooo`;o00008oooool002Kooooo0ol0000l
ooooo`?o000000Co4900o`000?l@T03o00000_l@T0001?l0003o4900oa2@0?l00002oa2@0004o`00
0?l@T03o4900o`0000;o490000Co0000o`n@0?l?T03o00000_l?T0001?l0003o3i00o`n@0?l00002
o`n@0004o`000?l?S`3o3hl0o`0000;o3Xl000?o0000o`j?0?l>S`000_l000001OnG^@3o0000oiNi
0?nG^@3o000000;oU[T000Go0000oiJi0?nF^@3oU[T0o`000002oiFi0004o`000?nD^@3oU;T0o`00
00;oTkT000Co0000oi>h0?nC^03o00000_nB^0001Ol0003oTKP0oi6h0?nA^03o000000;oT;P00_l0
00000ooFUP3o0000omJF0002omJF0004o`000?oFUP3oeYH0o`0000?oeYL000Co0000omFJ0?oEVP3o
00000ooBX@02o`0000;oh7P000go0000omBL0?oDW03o0000omio0?l0003oakd0o`000?o</`3o0000
olf^0?l0003ocZd000;o00000_mOZ`02o`000003oenZ0?l0003oGjX000?o00004_ooool00ol0003o
ooooooooo`0Wooooo`009?ooool2o`0003cooooo0ol000001ol?T03o0000oa2@0?l@T03o0000oa2@
0?l000000_l@T0001?l0003o4900oa2@0?l00002oa2@0004o`000?l@T03o4900o`0000;o490000Co
0000o`n@0?l?T03o00000_l?T0001?l0003o3i00o`n@0?l00002o`n@0004o`000?l?S`3o3hl0o`00
00;o3Xl000Co0000o`j?0?l0003o00000_nG^@001?l0003oUkT0oiNi0?l00003oiJi0004o`000?nF
^@3oU[T0o`0000;oUKT000Co0000oiBi0?nD^@3o00000_nC^@001?l0003oTkP0oi>h0?l00003oi:h
0005o`000?nA^03oTKP0o`000?n@^0000_l00002omJF0005o`000?oFUP3oeYH0omJF0?l000000_oF
UP001Ol0003oeYL0omJG0?oFU`3o000000;oeIX000?o0000om:Q0?oBX@000_l00003on1h0003o`00
0?oDW03oe9`000Co000000Coc;<0o`000?o=[P3o00000_o>[@02o`0000;oGj/00_l000001omOZP3o
0000o`000?mOZP3o0000oejZ0?l000004Oooool00ol0003oooooooooo`0Wooooo`008Oooool3o`00
0003ooooool0003ooooo03Sooooo0ol000001Ol?T03o0000o`n@0?l?T03o000000;o490000?o0000
oa2@0?l000000_l@T0001?l0003o4900oa2@0?l00002oa2@0007o`000?l@T03o4900oa2@0?l0003o
4900o`000002o`n@0004o`000?l?T03o3i00o`0000;o3i0000Co0000o`n@0?l?T03o00000_l?S`00
0ol0003o3Xl0o`000002o`000005oiRj0?l0003oUkT0oiNi0?l000000onG^@001?l0003oU[T0oiJi
0?l00002oiJi0004o`000?nE^@3oUKT0o`0000;oU;T000Co0000oi>i0?nC^@3o00000onC^0001Ol0
003oT[P0oi:h0?l0003oTKP000?o000000?oeYD0o`000?oFUP000_oFUP001?l0003oeYH0omJF0?l0
0003omJF0004o`000?oFU`3oeYL0o`0000?oeIX00_l000000ooVI@3o0000on1h0002on1h00Co0000
00kogWl0o`000?l0003oc;<0o`000?o=[P3o0000olj]0?l0003ocZd0o`000?mOZ`3o0000oen[00;o
000000KoGjX0o`000?mOZP3o0000oejZ0?l0000Booooo`03o`000?oooooooooo02Kooooo000Poooo
o`;o0000>oooool2o`000005o`n@0?l0003o3i00o`n@0?l000000_l?T0001_l0003o4900oa2@0?l0
003o4900o`0000;o490000Co0000oa2@0?l@T03o00000ol@T0001_l0003o4900oa2@0?l0003o4900
o`0000;o3i0000Co0000o`n@0?l?T03o00000_l?T0001Ol0003o3i00o`n@0?l0003o3hl000?o0000
00GoV;X0o`000?nH^P3oV;X0o`000003oiNi0004o`000?nG^@3oUkT0o`0000;oU[T000Co0000oiJi
0?nF^@3o00000_nE^@001?l0003oU;T0oiBi0?l00003oi>i0005o`000?nC^03oTkP0o`000?nB^000
0ol000001OoGU@3o0000omJE0?oFU@3o000000?oeYH000Go0000omJF0?oFUP3oeYH0o`000002omJF
0004o`000?oFU`3oeYL0o`0000;oeIX00_l00002onIU0003o`000?oPN03o000000Co00000ooNO`00
2?l0003oc;<0o`000?o=[P3o0000olj]0?l0003ocZd00ol000001?mOZ`3o0000o`000?mOZP02o`00
00;oGZX00_l0000Booooo`03o`000?oooooooooo02Gooooo000Pooooo`?o0000=oooool3o`000004
o`n@0?l0003o3i00o`0000;o3i0000Co0000o`n@0?l?T03o00000_l@T0000ol0003o4900o`000002
oa2@0005o`000?l@T03o4900oa2@0?l000000_l@T0001_l0003o4900oa2@0?l0003o4900o`0000;o
3i0000Co0000o`n@0?l?T03o00000_l?T0000ol0003o3i00o`000002o`000005oiRj0?l0003oV;X0
oiRj0?l000000_nH^P001Ol0003oUkT0oiNi0?nG^@3o000000;oUkT000Co0000oiJi0?nF^@3o0000
0_nF^@001?l0003oUKT0oiFi0?l00003oiBi0005o`000?nC^@3oTkT0o`000?nC^0000ol000001OoG
U03o0000omNE0?oGU@3o000000?oeYD000Co0000omJF0?oFUP3o00000ooFUP001?l0003oeYH0omJF
0?l00003omJG00;o000000?oj5`0o`000?oVI@000ol00003on1h0007o`000?oNO`3ogWl0omio0?l0
003ohW00o`000002olf^0006o`000?o>[@3o0000olj]0?l0003ocZd00_l000000omOZP3o0000oenZ
0002o`0000;oGZX00ol0000Aooooo`03o`000?oooooooooo02Gooooo000Pooooo`04o`000?oooooo
ooooo`0003?ooooo0ol000001ol>S`3o0000o`n@0?l?T03o0000o`n@0?l000000_l?T0001?l0003o
3i00o`n@0?l00002oa2@0003o`000?l@T03o000000?o490000Co0000oa2@0?l@T03o00000_l@T000
1?l0003o4900oa2@0?l00002oa2@0003o`000?l?T03o000000;o3i0000?o0000o`n@0?l000000_l0
00001OnI^P3o0000oiRj0?nH^P3o000000;oV;X000Go0000oiRj0?nH^P3oV;X0o`000002oiNi0004
o`000?nG^@3oUkT0o`0000;oU[T000Co0000oiJi0?nF^@3o00000onE^@001Ol0003oU;T0oiBi0?l0
003oTkT000?o000000Goei@0o`000?oGU03oei@0o`000003omNE0004o`000?oFU@3oeYD0o`0000;o
eYH000Go0000omJF0?oFUP3oeYH0o`000002omJF0003o`000?oFU`3o000000;o000000Coj5`0o`00
0?l0003o00000_oVI@001Ol0003oh7P0on1h0?oPN03o000000?ogWl000Go0000on9`0?l0003o0000
olf^0002o`000004olj]0?l0003ocZd0olj]00;o000000?oGjX0o`000?mOZP000_l000000omNZP3o
0000oejZ0003o`00017ooooo0_l0000Uooooo`008?ooool01Ol0003ooooooooooooooooo000002oo
oooo0ol000001Ol>S`3o0000o`j?0?l>S`3o000000;o3i0000?o0000o`n@0?l000000_l?T0001?l0
003o3i00o`n@0?l00002oa2@0004o`000?l@T03o4900o`0000;o490000Co0000oa2@0?l@T03o0000
0_l@T0001?l0003o4900oa2@0?l00002oa2@0004o`000?l?T03o0000o`n@00?o000000GoVKX0o`00
0?nI^P3oVKX0o`000002oiRj0005o`000?nH^P3oV;X0oiRj0?l000000_nH^P001?l0003oUkT0oiNi
0?l00002oiNi0004o`000?nF^@3oU[T0o`0000?oU[T000Go0000oiFi0?nE^@3o0000oiBi0003o`00
0005omND0?l0003oei@0omND0?l000000ooGU0001?l0003oeiD0omNE0?l00002omJE0004o`000?oF
UP3oeYH0o`0000?oeYH000?o0000omJF0?l000000_l000001?oYFP3o0000o`000?l00002onQL0004
o`000?oVI@3oiVD0o`0000;oh7P000Go0000onYE0?l0003ogWl0o`000002on9`00?o000000_ocZd0
o`000?o>[@3o0000olj]0?l0003ocZd0o`000?mOZP3o0000oenZ0002o`000003oejZ0?l0003oGZX0
00;o000000?oGZX0o`000?ooool03oooool2o`0002Gooooo000Oooooo`?o00000oooool00ol0003o
ooooooooo`0Zooooo`;o000000Go3Xl0o`000?l>S`3o3Xl0o`000002o`j?0006o`000?l?T03o3i00
o`000?l?T03o00000_l?T0001?l0003o3i00o`n@0?l00002oa2@0004o`000?l@T03o4900o`0000;o
490000Co0000oa2@0?l@T03o00000_l@T0001?l0003o4900oa2@0?l00002oa2@00Co000000GoVKX0
o`000?nI^P3oVKX0o`000002oiVj0005o`000?nH^P3oV;X0oiRj0?l000000_nH^P001?l0003oV;X0
oiRj0?l00002oiNi0004o`000?nG^@3oUkT0o`0000;oU[T000Ko0000oiJi0?nF^@3oU[T0o`000?nE
^@03o`000005omND0?l0003oei@0omND0?l000000ooGU0001?l0003oei@0omND0?l00002omNE0004
o`000?oFU@3oeYD0o`0000?oeYH000?o0000omJF0?l000000_l000001_oYF@3o0000o`000?l0003o
jEX0o`0000?oj5`000Co0000onIU0?oVI@3oiVD00_l00002onYE0005o`000?oNO`3o0000on9`0?l0
00000_oTJP002?l0003ocZd0o`000?o>[@3o0000olj]0?l0003ocZd00_l00002oenZ00;o000000Oo
GZX0o`000?l0003oGZX0o`000?mNZP3o0000017ooooo00?o0000ooooooooool08oooool001oooooo
0_l00005ooooo`03o`000?oooooooooo02Kooooo0ol000001?l=S`3o0000o`j?0?l00002o`j?0004
o`000?l>S`3o3Xl0o`0000;o3i0000?o0000o`n@0?l000000_l?T0001ol0003o3i00o`n@0?l?T03o
0000oa2@0?l000000_l@T0001?l0003o4900oa2@0?l00002oa2@0004o`000?l@T03o4900o`0000;o
490000Ko0000oa2@0?l0003o0000oiVj0?l00002oiVj0004o`000?nI^P3oVKX0o`0000?oVKX000Co
0000oiRj0?nH^P3o00000_nH^P001?l0003oV;X0oiRj0?l00002oiNi0004o`000?nG^@3oUkT0o`00
00?oU[T000?o0000oiJi0?l000000_l000001OoGU03o0000omND0?oGU03o000000;oei@000Go0000
omND0?oGU03oei@0o`000002omND0004o`000?oGU@3oeiD0o`0000;oeYD000Co0000omJF0?oFUP3o
eYH00_l000001_oYF03o0000o`000?l0003ojET0o`0000;ojEX000Go0000onQL0?oXG03oj5`0o`00
0002onIU00;o00001?oZE@001?l0003ohW00on9`0?l00002onAZ00;o00000_o>[@002ol0003ocZd0
o`000?l0003ocZd0o`000?mOZP3o0000oenZ0?l0003oGZX000?o00000_mNZP02o`00017ooooo00?o
0000ooooooooool08_ooool001oooooo0ol00005ooooo`03o`000?oooooooooo02;ooooo0ol00000
1ol=S`3o0000o`f?0?l=S`3o0000o`j?0?l000000_l>S`001?l0003o3Xl0o`j?0?l00002o`n@0003
o`000?l?T03o000000?o3i0000Ko0000o`n@0?l?T03o0000oa2@0?l00002oa2@0004o`000?l@T03o
4900o`0000;o490000Go0000oa2@0?l@T03o0000oa2@0003o`000004oiVj0?l0003oVKX0o`0000;o
VKX000Go0000oiVj0?nI^P3oVKX0o`000002oiVj0004o`000?nH^P3oV;X0o`0000;oV;X000Co0000
oiRj0?nH^P3o00000_nG^@001Ol0003oUkT0oiNi0?nG^@3o000000;oU[T00_l000001OoGT`3o0000
omND0?oGU03o000000;oei@000Co0000omND0?oGU03o00000ooGU0001?l0003oei@0omND0?l00002
omNE0006o`000?oFU@3oeYD0omJE0?l0003oeYH01?l000001OoYF03o0000onUI0?oYF@3o000000?o
jEX000Co0000onQL0?oXG03oj5`00_l000000oo`@03o0000onYE0002onYE00;o000000OohW00o`00
0?oTJP3oi6X0o`000?oTJ03o000000;ocZd00_l000000oo>[@3o0000olj]0003o`000003oenZ0?l0
003oGZX000?o00000_mNZP02o`00017ooooo00?o0000ooooooooool08_ooool001oooooo0ol00006
ooooo`03o`000?oooooooooo01oooooo0_l000001Ol<S`3o0000o`f?0?l=S`3o000000;o3Hl000?o
0000o`j?0?l000000_l>S`001?l0003o3Xl0o`j?0?l00002o`n@0004o`000?l?T03o3i00o`0000;o
3i0000Ko0000o`n@0?l?T03o0000oa2@0?l00002oa2@0004o`000?l@T03o4900o`0000;o490000?o
0000oa2@0?l000000_l000001onI^P3o0000oiVj0?nI^P3o0000oiVj0?l000000onI^P001?l0003o
VKX0oiVj0?l00002oiVj0004o`000?nH^P3oV;X0o`0000;oV;X000Co0000oiRj0?nH^P3o00000onG
^@001Ol0003oUkT0oiNi0?l0003oU[T000;o00000_oGT`001?l0003oei@0omND0?l00002omND0005
o`000?oGU03oei@0omND0?l000000_oGU0001?l0003oei@0omND0?l00003omNE0003o`000?oFU@3o
000000Co00000ooYF0001?l0003ojET0onUI0?l00003onUJ0003o`000?oXG03o000000;o00000_o`
@0001?l0003ojUD0onYE0?l00002onm400;o00000_oTJP000ol0003oi6P0o`000002o`000007olj]
0?l0003ocZd0o`000?o>[@3o0000olj]0002o`0000;oGZX00ol000000omNZP3o0000oejZ0002o`00
017ooooo00?o0000ooooooooool08Oooool000Kooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol00003ooooo`?o00001Oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo01_o
oooo0ol000001?l;SP3o0000o`b?0?l00002o`f?0006o`000?l=S`3o3Hl0o`000?l>S`3o00000_l>
S`001?l0003o3Xl0o`j?0?l00002o`n@0004o`000?l?T03o3i00o`0000;o3i0000Ko0000o`n@0?l?
T03o0000oa2@0?l00002oa2@0005o`000?l@T03o4900o`000?l@T0000ol000001OnJ^P3o0000oiVj
0?nI^P3o000000;oVKX000Co0000oiVj0?nI^P3o00000_nI^P001?l0003oVKX0oiVj0?l00002oiVj
0004o`000?nH^P3oV;X0o`0000;oV;X000Go0000oiRj0?nH^P3oV;X0o`000002oiNi0003o`000?nG
^@3o000000;o000000Goei<0o`000?oGT`3oei<0o`000002omND0005o`000?oGU03oei@0omND0?l0
00000_oGU0001?l0003oei@0omND0?l00003omND0003o`000?oGU@3o000000Co00000ooYF0001?l0
003ojEP0onUH0?l00003onUI0003o`000?oYFP3o000000;o00000_ob=`001?l0003ol400oo100?o`
@002o`0000?okd@000Ko0000onAZ0?oTJP3o0000onAX0?l00002onEX0006o`000?o>[@3o0000o`00
0?o>[@3o00000_o>[@02o`0000;oGZX00ol000000omNZP3o0000oejZ0003o`00017ooooo00?o0000
ooooooooool08?ooool000Gooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_ooool3o`0000Sooooo00?o0000ooooooooool06?oo
ool2o`000007o`^>0?l0003o2hh0o`^>0?l0003o38l0o`000002o`f?0006o`000?l=S`3o3Hl0o`00
0?l>S`3o00000_l>S`001ol0003o3Xl0o`j?0?l>S`3o0000o`n@0?l000000_l?T0001?l0003o3i00
o`n@0?l00002o`n@0003o`000?l@T03o000000;o490000?o0000oa2@0?l000000_l000001OnJ^P3o
0000oiZj0?nJ^P3o000000;oVKX000Co0000oiVj0?nI^P3o00000_nI^P001?l0003oVKX0oiVj0?l0
0002oiVj0004o`000?nI^P3oVKX0o`0000;oV;X000Go0000oiRj0?nH^P3oV;X0o`000002oiRj0003
o`000?nG^@3o000000;o000000Goei<0o`000?oGT`3oei<0o`000002omNC0005o`000?oGU03oei@0
omND0?l000000_oGU0001?l0003oei@0omND0?l00003omND0003o`000?oGU03o000000Co00000ooY
F0001?l0003ojEP0onUH0?l00003onUH0003o`000?oYF@3o000000;o000000?olc@0o`000?ob=`00
0_ob=`000ol0003ol400oo100002o`0000?okd@000Oo0000oo0m0?l0003oi6X0o`000?oTJ03o0000
00;oiFP00_l000002oo>[@3o0000olj]0?l0003ocZd0o`000?o>[@3o0000oejZ0?l0003oGZX000;o
000000OoGZX0o`000?l0003oGZX0o`000?mNZP3o0000013ooooo0_l0000Qooooo`001Oooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooo`000?l00008ooooo`03o`000?oooooooooo01Cooooo0ol000001?l:SP3o0000o`^>
0?l00002o`^>0003o`000?l<S`3o000000;o3Hl000Ko0000o`f?0?l=S`3o0000o`j?0?l00003o`j?
0006o`000?l>S`3o3Xl0o`000?l?T03o00000_l?T0001?l0003o3i00o`n@0?l00002o`n@0004o`00
0?l@T03o0000oa2@00?o000000GoVKX0o`000?nJ^P3oV[X0o`000002oiZj0004o`000?nI^P3oVKX0
o`0000;oVKX000Co0000oiVj0?nI^P3o00000_nI^P001?l0003oVKX0oiVj0?l00002oiVj0005o`00
0?nH^P3oV;X0oiRj0?l000000_nH^P000ol0003oV;X0o`000002o`000005omNC0?l0003oei<0omNC
0?l000000_oGT`001Ol0003oei<0omNC0?oGT`3o000000;oei@000Co0000omND0?oGU03o00000_oG
U0000ol0003oei@0o`000005o`0000?ojEP000Co0000onUH0?oYF03o00000_oYF0000ol0003ojEP0
onUH0003o`000003oo<c0?l0003olc@000;olc@000Co0000oo8g0?ob=`3olSL00_l00002oo@^0003
o`000?o_A03o000000?ol3d000?o0000onAX0?l000000_oUJ0002_l0003oiFP0o`000?o>[@3o0000
olj]0?l0003ocZd0o`000?o>[@04o`000003oejZ0?l0003oGZX000;o000000CoGZX0o`000?mNZP3o
00004Oooool00ol0003oooooooooo`0Oooooo`001Oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`;o00002Oooool00ol0
003oooooooooo`0>ooooo`Go000000Oo2Hd0o`000?l:SP3o2Xh0o`000?l;SP3o000000;o2hh000?o
0000o`b?0?l000000_l=S`001?l0003o3Hl0o`f?0?l00002o`j?0004o`000?l>S`3o3Xl0o`0000;o
3Xl000?o0000o`n@0?l000000_l?T0001?l0003o3i00o`n@0?l00002o`n@00Co000000GoVKX0o`00
0?nI^P3oVKX0o`000002oiZj0004o`000?nJ^P3oV[X0o`0000;oVKX000Co0000oiVj0?nI^P3o0000
0_nI^P001?l0003oVKX0oiVj0?l00002oiVj0005o`000?nI^P3oVKX0oiVj0?l000000_nH^P000ol0
003oV;X0o`000002o`000005omNC0?l0003oei<0omNC0?l000000_oGT`001?l0003oei<0omNC0?l0
0003omNC0004o`000?oGU03oei@0o`0000;oei@000?o0000omND0?l000001Ol00002onUI0005o`00
0?oYF03ojEP0onUH0?l000000_oYF0001?l0003ojEP0onUH0?oYF002o`000003oo<c0?l0003olc<0
00;olc<000Co0000oo<d0?oc=03o00000_ob=`02o`0000?om2h00_l00004oo0m0003o`000?oTJ03o
000000;oiFP000Co0000onEX0?l0003o00000_o>[@001_l0003ocZd0o`000?o>[@3o0000olj]00;o
000000?oGZX0o`000?mNZP000ol00002oejZ00;o00004Oooool00ol0003oooooooooo`0Nooooo`00
1Oooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooooooo`Co00001?ooool2o`00
0003ooooool0003o000000[ooooo00?o0000ooooooooool02_ooool3o`000004o`R=0?l0003o28d0
o`0000;o2Hd000Ko0000o`Z>0?l:SP3o0000o`^>0?l00002o`^>0003o`000?l<S`3o000000;o3Hl0
00Co0000o`f?0?l=S`3o00000_l>S`001?l0003o3Xl0o`j?0?l00002o`j?0003o`000?l?T03o0000
00;o3i0000Go0000o`n@0?l?T03o0000o`n@0002o`000005oiVj0?l0003oVKX0oiVj0?l000000_nI
^P001?l0003oV[X0oiZj0?l00002oiZj0004o`000?nI^P3oVKX0o`0000?oVKX000?o0000oiVj0?l0
00000_nI^P001Ol0003oVKX0oiVj0?nI^P3o000000;oVKX000?o0000oiRj0?l000000_l000001OoG
T`3o0000omNC0?oGT`3o000000;oei<000Co0000omNC0?oGT`3o00000ooGT`001?l0003oei<0omNC
0?l00002omND0003o`000?oGU03o000000Go00000_oYF@001?l0003ojET0onUI0?l00003onUH0006
o`000?oYF03ojEP0onUH0?l0003ojEP00_l00003oo<c0004o`000?oc<`3olc<0o`0000;olc@00ol0
0002ooLU0005o`000?od;P3o0000ooHW0?l000000oo`?@000ol0003olC/0o`000002onEX0004o`00
0?oUJ03o0000onEX00;o000000GocZd0o`000?l0003ocZd0o`000002olj]00?o00000_mNZP03o`00
00;oGZX00_l0000Aooooo`03o`000?oooooooooo01kooooo0005ooooo`04o`000?ooooooooooo`00
00Sooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo00Ko0000oooooooooooo0000o`1MAOl0
000:ooooo`;o00002?ooool2o`000007o`N<0?l0003o28d0o`R=0?l0003o28d0o`000002o`V=0006
o`000?l:SP3o2Xh0o`000?l;SP3o00000_l;SP000ol0003o38l0o`000003o`f?0003o`000?l=S`3o
000000;o3Xl000Co0000o`j?0?l>S`3o00000_l>S`000ol0003o3i00o`000002o`n@0003o`000?l?
T03o000000;o000000CoVKX0o`000?nI^P3o00000_nI^P001?l0003oVKX0oiVj0?l00002oiZj0004
o`000?nJ^P3oV[X0o`0000?oVKX000Ko0000oiVj0?nI^P3o0000oiVj0?l00003oiVj0005o`000?nI
^P3oVKX0o`000?nI^P000ol000001OoGT`3o0000omNC0?oGT`3o000000;oei<000Co0000omNC0?oG
T`3o00000ooGT`001?l0003oei<0omNC0?l00002omNC0003o`000?oGU03o000000Go00000_oYF@00
1?l0003ojET0onUI0?l00003onUI0006o`000?oYF03ojEP0onUH0?l0003ojEP00ol000000ooc<`3o
0000oo<c0002oo<c0003o`000?oc<`3olc<000?o000000?omb80o`000?og9@000_og9@02o`0000?o
mRL000?o0000oo0m0?l000000_oa>`02o`000005onEX0?l0003oiFP0o`000?oUJ0000ol000001oo>
[@3o0000olj]0?l0003ocZd0o`000?o>[P000_l00002oejZ00?o000000?oGZX0o`000?mNZP000_l0
000Aooooo`03o`000?oooooooooo01gooooo0006ooooo`;o00002_ooool01?l0003ooooooooooooo
ool5o`0000?ooooo00Ko0000oooooooooooo0000o`1MAOl0000<ooooo`03o`000?oooooooooo00;o
oooo0ol000001?l6S03o0000o`N<0?l00002o`R=0003o`000?l8S@3o000000;o2Hd000Ko0000o`Z>
0?l:SP3o0000o`^>0?l00002o`^>0004o`000?l<S`3o38l0o`0000;o3Hl000?o0000o`f?0?l00000
0_l>S`001?l0003o3Xl0o`j?0?l00002o`j?0004o`000?l?T03o0000o`n@00?o000000OoVKX0o`00
0?nI^P3oVKX0o`000?nI^P3o000000;oVKX000Co0000oiVj0?nI^P3o00000_nJ^P001Ol0003oV[X0
oiZj0?nJ^P3o000000;oVKX000Co0000oiVj0?nI^P3o00000_nI^P001Ol0003oVKX0oiVj0?l0003o
VKX000?o000000Goei80o`000?oGT`3oei<0o`000002omNC0004o`000?oGT`3oei<0o`0000?oei<0
00Co0000omNC0?oGT`3o00000_oGT`000ol0003oei<0o`000005o`0000;ojET000Co0000onUI0?oY
F@3o00000ooYF@001Ol0003ojET0onUI0?l0003ojEP000Co000000?olc@0o`000?oc<`000_oc<`00
0ol0003olc<0oo<c0003o`000003ooPQ0?l0003omb8000;omb8000Go0000ooLU0?l0003on1d0o`00
0003ooHW00;o00000_oa>`002?l0003olC/0oo4k0?l0003oiFP0o`000?oUJ03o00000_oTJ0002?l0
003ocZd0o`000?o>[@3o0000olj]0?l0003ocZh00_l000000omNZP3o0000oejZ0002o`000003oejZ
0?l0003oGZX000;o00004_ooool00ol0003oooooooooo`0Looooo`007_ooool2o`000003ooooool0
003o000000;o00003?ooool4o`000007o`F<0?l0003o1X`0o`J<0?l0003o1h`0o`000002o`R=0003
o`000?l8S@3o000000;o2Hd000Ko0000o`Z>0?l:SP3o0000o`^>0?l00002o`^>0004o`000?l<S`3o
38l0o`0000;o3Hl000?o0000o`f?0?l000000_l>S`001?l0003o3Xl0o`j?0?l00002o`j?00Co0000
00GoVKX0o`000?nI^P3oVKX0o`000002oiVj0006o`000?nI^P3oVKX0o`000?nI^P3o00000_nI^P00
1Ol0003oV[X0oiZj0?nJ^P3o000000;oV[X000Co0000oiVj0?nI^P3o00000_nI^P001Ol0003oVKX0
oiVj0?l0003oVKX000?o000000Goei80o`000?oGTP3oei80o`000002omNC0004o`000?oGT`3oei<0
o`0000?oei<000Co0000omNC0?oGT`3o00000_oGT`000ol0003oei<0o`000005o`0000;ojET000Co
0000onUI0?oYF@3o00000_oYF@001_l0003ojET0onUI0?oYF@3o0000onUI00?o00000_oc=0001_l0
003olc@0oo<d0?oc=03o0000oo<c00Co000000?omb40o`000?oh8@000_oh8@000ol0003omb80o`00
0002o`0000?on1d00ol000001?og903o0000oo4k0?l00003oo4k0005o`000?oUJ03o0000onEX0?l0
00000_oTJ002o`0000;ocZd000Go0000olj]0?l0003o0000olj^0003o`000004oejZ0?l0003o0000
oejZ00;o000000CoGZX0o`000?l0003o00004?ooool2o`0001gooooo000Nooooo`03o`000?oooooo
oooo00?o000000?o078]o`000?l000001_ooool5o`000005o`B;0?l0003o1H`0o`F<0?l000000_l6
S0000ol0003o1h`0o`000002o`R=0003o`000?l8S@3o000000;o2Hd000Co0000o`Z>0?l:SP3o0000
0_l;SP000ol0003o2hh0o`000002o`b?0006o`000?l=S`3o3Hl0o`000?l=S`3o00000_l>S`001Ol0
003o3Xl0o`j?0?l0003o3Xl000;o000000GoV;X0o`000?nI^P3oVKX0o`000002oiVj0004o`000?nI
^P3oVKX0o`0000;oVKX000?o0000oiVj0?l000000onI^P001?l0003oV[X0oiZj0?l00002oiZj0004
o`000?nI^P3oVKX0o`0000;oVKX000?o0000oiVj0?l000000_l000001OoGTP3o0000omNB0?oGTP3o
000000;oei8000Co0000omNC0?oGT`3o00000ooGT`001?l0003oei<0omNC0?l00002omNC0003o`00
0?oGT`3o000000;o000000?ojET0o`000?l000000_oYF@001?l0003ojET0onUI0?l00002onUI0006
o`000?oYF@3ojET0onUI0?l0003ojET00ol000000ooc=03o0000oo<d0002oo<d0003o`000?oc=03o
lc@000?o00000_og8P001_l0003omb40ooLQ0?og8@3o0000ooPQ00?o00000_oi6P000ol0003on1d0
ooPM0002o`0000?omb@00_l00003oo4k0003o`000?oa>`3o000000;oiFP000Co0000onAX0?l0003o
i6P00_l000002?o>[@3o0000o`000?o>[P3o0000olj^0?l0003ocZh00_l000000omNZP3o0000oejZ
0002o`000005oejZ0?l0003o0000oefZ0?l000004?ooool00ol0003oooooooooo`0Kooooo`007_oo
ool01?l0003oooooooooooooool2o`000003o`1b;Ol0003o07hG00;o00000_ooool2o`000007o`6:
0?l0003o0h/0o`>;0?l0003o18/0o`000002o`F<0006o`000?l6S03o1X`0o`000?l7S03o00000_l8
S@000ol0003o28d0o`000002o`V=0004o`000?l:SP3o2Xh0o`0000;o2hh000?o0000o`^>0?l00000
0_l<S`001_l0003o3Hl0o`f?0?l0003o3Hl0o`0000;o3Xl000?o0000o`j?0?l000000_l000001?nH
^P3o0000oiRj0?l00002oiVj0004o`000?nI^P3oVKX0o`0000;oVKX000Co0000oiVj0?nI^P3o0000
0_nI^P001?l0003oVKX0oiVj0?l00002oiZj0004o`000?nJ^P3oV[X0o`0000;oVKX000?o0000oiVj
0?l000000_l000001OoGTP3o0000omNB0?oGTP3o000000;oei8000Co0000omNB0?oGTP3o00000ooG
T`001?l0003oei<0omNC0?l00002omNC0003o`000?oGT`3o000000;o000000KojET0o`000?l0003o
0000onUI0?l00002onUI0004o`000?oYF@3ojET0o`0000?ojET000?o0000onUI0?l000000_l00000
0oob=@3o0000oo<d0002oo<d0004o`000?oc=03olc@0oo<d00;o000000?omb80o`000?og8P000oog
8P000ol0003omb40o`000002o`0000;onAX000?o0000ooTJ0?oi6P000ol00002ooTK0003o`000?og
903o000000;omb@000?o0000oo4k0?l000000_oa>`03o`0000;oi6P000?o0000onAX0?l000000_l0
00000oo>[@3o0000olj^0002o`0000;ocZh00_l000000omNZP3o0000oejZ0003o`000004oefZ0?l0
003oGJX0o`00017ooooo00?o0000ooooooooool06_ooool001gooooo0ol00002ooooo`;o000000Go
078]o`000?l0OQOo0000o`252@02o`000004o`280_l0003o0HX0o`0000;o0h/000?o0000o`B;0?l0
00000_l5S0001_l0003o1X`0o`J<0?l0003o1h`0o`0000;o28d000?o0000o`R=0?l000000_l9S@00
1?l0003o2Xh0o`Z>0?l00002o`^>0003o`000?l;SP3o000000;o38l000Oo0000o`f?0?l=S`3o0000
o`f?0?l0003o3Xl000?o000000OoV;X0o`000?nH^P3oV;X0o`000?nH^P3o000000;oVKX000Co0000
oiVj0?nI^P3o00000_nI^P001?l0003oVKX0oiVj0?l00002oiVj0004o`000?nI^P3oVKX0o`0000;o
V[X000Go0000oiZj0?nJ^P3o0000oiVj0003o`000005omNB0?l0003oei80omNB0?l000000_oGTP00
1?l0003oei80omNB0?l00003omNB0004o`000?oGT`3oei<0o`0000;oei<000?o0000omNC0?oGT`00
0_l000001_oYF@3o0000o`000?l0003ojET0o`0000;ojET000Co0000onUI0?oYF@3o00000ooYF@00
0ol0003ojET0o`000002o`000003oo8e0?l0003olSD000;olSD000Co0000oo<d0?oc=03o00000_oc
=002o`0000?omb8000?o0000ooLR0?og8P000ol00002ooTJ0003o`000?oi6P3onAX000?o00000_oj
60000ol0003onA/0ooTK0002o`0000?omb@00_l00002oo4k0008o`000?oa>`3olC/0o`000?oTJ03o
0000onAX0?l00002onAX0009o`000?o>[@3o0000o`000?o>[P3o0000olj^0?l0003ocZh000;o0000
0_mNZP03o`000003oefZ0?l0003oGJX000;o00004?ooool00ol0003oooooooooo`0Jooooo`007Ooo
ool00ol0003oooooooooo`02ooooo`;o000000Ko078]o`000?l0OQOo0000o`252Ol00002o`280P03
o`000?l1RP3o000000;o0h/000?o0000o`B;0?l000000_l5S0001_l0003o1X`0o`J<0?l0003o1h`0
o`0000;o28d000Ko0000o`R=0?l8S@3o0000o`V=0?l00002o`Z>0006o`000?l;SP3o2hh0o`000?l;
SP3o00000_l<S`000ol0003o3Hl0o`f?0004o`000005oiNj0?l0003oV;X0oiRj0?l000000_nH^P00
0ol0003oV;X0o`000002oiVj0004o`000?nI^P3oVKX0o`0000?oVKX000?o0000oiVj0?l000000_nI
^P001?l0003oVKX0oiVj0?l00002oiZj0003o`000?nJ^P3o000000;o000000Goei80o`000?oGTP3o
ei80o`000002omNB0004o`000?oGTP3oei80o`0000?oei8000Co0000omNB0?oGTP3o00000_oGT`00
1Ol0003oei<0omNC0?l0003oei<000Co000000GojET0o`000?oYF@3ojET0o`000002onUI0006o`00
0?oYF@3ojET0onUI0?l0003ojET00ol000000oob=@3o0000oo8e0002oo8e0004o`000?ob=@3olSD0
o`0000;olc@00ol00002ooLS0003o`000?og8P3omb8000?o00000_oi6`000ol0003onAX0ooTJ0003
o`0000;onQP000?o0000ooXH0?oj60000ol000000ooi6P3o0000ooLT0002o`000004ooLT0?l0003o
lC/0o`0000?olC/000Go0000onAX0?l0003oi6P0o`000002onAX00;o000000OocZh0o`000?o>[P3o
0000olj^0?l0003ocZh000;o00000_mNZP03o`000003oefZ0?l0003oGJX000;o00004Oooool00ol0
003oooooooooo`0Iooooo`007Oooool3o`0000;ooooo0_l000001_l0LRgo0000o`1n5ol0003o08D9
o`0000;o08P200?o0000o`6:0?l000000_l3R`000ol0003o18/0o`000002o`F<0006o`000?l6S03o
1X`0o`000?l7S03o00000_l8S@001_l0003o28d0o`R=0?l0003o2Hd0o`0000;o2Xh000Ko0000o`^>
0?l;SP3o0000o`^>0?l00002o`b?0006o`000?l=S`3o0000o`000?nG^@3o00000_nG^P001?l0003o
V;X0oiRj0?l00002oiRj0003o`000?nH^P3o000000;oVKX000Go0000oiVj0?nI^P3oVKX0o`000002
oiVj0003o`000?nI^P3o000000;oVKX000Go0000oiVj0?nI^P3o0000oiZj0003o`000005omNB0?l0
003oei80omNB0?l000000_oGTP001?l0003oei80omNB0?l00003omNB0004o`000?oGTP3oei80o`00
00;oei8000Go0000omNC0?oGT`3o0000omNC0005o`0000?ojET000Co0000onUI0?oYF@3o00000ooY
F@000ol0003ojET0o`000002o`000003oo8f0?l0003olSD000;olSD000Co0000oo8e0?ob=@3o0000
0_ob=@03o`0000;omb<000?o0000ooLS0?og8`000ol00002ooTK0003o`000?oi6`3onA/000?o0000
00ConQP0o`000?oj603onQP01?l000001?oj5`3o0000ooTJ0?oi6P02o`0000?omb@00_l00003oo4k
0005o`000?oa>`3o0000onAX0?l000000_oTJ0000ol0003oi6T0o`000002o`000005olj^0?l0003o
cZh0o`000?o>[P000_l000000omNZP3o0000oejZ0002o`000004oefZ0?l0003o0000oefZ00;o0000
4Oooool00ol0003oooooooooo`0Hooooo`007Oooool00ol0003oooooooooo`02ooooo`;o000000Ko
078]o`000?l0OQOo0000o`252Ol00002o`280P03o`000?l1RP3o000000;o0h/000?o0000o`B;0?l0
00000_l5S0001_l0003o1X`0o`J<0?l0003o1h`0o`0000;o28d000Ko0000o`R=0?l8S@3o0000o`V=
0?l00002o`Z>0007o`000?l;SP3o2hh0o`000?l;SP3o0000o`b?0003o`000004oiJi0?l0003oUkT0
o`0000;oUkX000Co0000oiRj0?nH^P3o00000_nH^P000ol0003oV;X0o`000003oiVj0004o`000?nI
^P3oVKX0o`0000;oVKX000Oo0000oiVj0?nI^P3o0000oiVj0?l0003oVKX000?o000000Goei80o`00
0?oGTP3oei80o`000002omNB0004o`000?oGTP3oei80o`0000?oei8000Co0000omNB0?oGTP3o0000
0_oGTP001Ol0003oei80omNB0?l0003oei<000Go00000ooYF@001?l0003ojET0onUI0?l00003onUI
0003o`000?oYF@3o000000;o000000?olSH0o`000?ob=P000_ob=P001?l0003olSD0oo8e0?l00002
oo8e00?o00000_og90000ol0003omb<0ooLS0003o`000004ooTL0?l0003onA/0ooTK00Co000000Co
nQT0o`000?oj603onQP00ol00002ooXG0003o`000?oj5`3onQL000?o00000_oi6P000ol0003omb@0
o`000002ooLT0003o`000?oa>`3o000000;olC/000?o0000onAX0?l000000_oTJ0001?l0003oi6T0
o`000?l00002olj^00;o000000?ocZh0o`000?o>[P000ol000001?mNZP3o0000o`000?mMZP02o`00
0003oefZ0?l0003o0000017ooooo0_l0000Iooooo`002_ooool2o`0000Cooooo00Co0000oooooooo
oooooooo1Ol00004ooooo`03o`000?oooooooooo00;ooooo0_l000001_l0LRgo0000o`1n5ol0003o
08D9o`0000;o08P200?o0000o`6:0?l000000_l3R`000ol0003o18/0o`000002o`F<0006o`000?l6
S03o1X`0o`000?l7S03o00000_l8S@001_l0003o28d0o`R=0?l0003o2Hd0o`0000;o2Xh000?o0000
o`^>0?l;SP001?l000001onF^@3o0000oiJi0?nF^@3o0000oiNi0?l000000_nG^P001?l0003oV;X0
oiRj0?l00002oiRj0004o`000?nH^P3oV;X0o`0000;oVKX000Co0000oiVj0?nI^P3o00000_nI^P00
0ol0003oVKX0oiVj0004o`000005omNB0?l0003oei80omNB0?l000000ooGTP000ol0003oei80o`00
0003omNB0004o`000?oGTP3oei80o`0000;oei8000Go0000omNB0?oGTP3o0000omNB0005o`0000?o
jET000Co0000onUI0?oYF@3o00000ooYF@000ol0003ojET0o`000002o`000003oo8f0?l0003olSH0
00;olSH000Co0000oo8f0?ob=P3o00000_ob=@03o`000004ooLT0?l0003omb@0ooLT00Co000000Co
nA`0o`000?oi703onA`00ol00002ooTI0003o`000?oj6@3onQT000?o00000_oj5`000ol0003onQL0
ooXG0003o`0000;onQL000?o0000ooTJ0?oi6P000_l00003ooLT00;o00000_oa>`000ol0003olC/0
o`000002onAX0004o`000?oTJ@3o0000onAY00?o000000OocZh0o`000?o>[P3o0000olj^0?l0003o
cZh000;o000000CoGZX0o`000?l0003oGJX00_l000000omMZP3o0000o`00000Aooooo`03o`000?oo
oooooooo00Gooooo0ol0000?ooooo`002Oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00_ooool2o`000006o`1b;Ol0003o07hGo`000?l0
Q@Wo00000_l0R0800ol0003o0HX0o`000002o`>;0006o`000?l4R`3o18/0o`000?l5S03o00000_l6
S0000ol0003o1h`0o`000002o`R=0006o`000?l8S@3o28d0o`000?l9S@3o00000_l:SP001_l0003o
2hh0o`000?l0003oUKT0o`0000;oU[T000Ko0000oiJi0?nF^@3o0000oiNi0?l00002oiNj0004o`00
0?nH^P3oV;X0o`0000?oV;X000?o0000oiRj0?l000000_nI^P001?l0003oVKX0oiVj0?l00002oiVj
0006o`000?nI^P3o0000o`000?oGTP3o00000_oGTP001Ol0003oei80omNB0?oGTP3o000000;oei80
00Co0000omNB0?oGTP3o00000_oGTP001?l0003oei80omNB0?l00002omNB0003o`000?oGTP3o0000
00Co00000ooYF@001?l0003ojET0onUI0?l00002onUI0003o`000?oYF@3ojET000?o000000GolSH0
o`000?ob=P3olSH0o`000003oo8f0003o`000?ob=P3olSH000?o000000Comb@0o`000?og903omb@0
0ol00002ooTM0003o`000?oi703onA`000?o00000_oi6P000ol0003onAT0ooTI0003o`0000;onQP0
00?o0000ooXG0?oj5`000ol00002ooXG0003o`000?oj5`3onQL000?o000000?onAX0o`000?og9000
0_l000003Oog903o0000oo4k0?l0003olC/0o`000?oa>`3o0000onAX0?l0003oi6T0o`000?oTJ@00
0ol000000oo>[P3o0000olj^0002o`0000;ocZh00ol000000omMZP3o0000oefZ0002o`000004oefZ
0?l0003o0000o`00017ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00kooooo0009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`00
00?ooooo0_l000001_l0LRgo0000o`1n5ol0003o08D9o`0000;o08P200?o0000o`6:0?l000000_l3
R`001_l0003o18/0o`B;0?l0003o1H`0o`0000;o1X`000?o0000o`N<0?l000000_l8S@001ol0003o
28d0o`R=0?l0003o2Hd0o`000?l:SP000ol000001?nD^@3o0000oiFi0?l00002oiJi0006o`000?nF
^@3oU[T0o`000?nG^@3o00000_nG^P001Ol0003oV;X0oiRj0?nH^P3o000000;oV;X000?o0000oiRj
0?l000000_nI^P001Ol0003oVKX0oiVj0?l0003oVKX000?o000000Coei80o`000?oGTP3o00000ooG
TP001?l0003oei80omNB0?l00002omNB0004o`000?oGTP3oei80o`0000;oei8000Go0000omNB0?oG
TP3o0000omNB0005o`0000?ojET000Co0000onUI0?oYF@3o00000_oYF@000ol0003ojET0onUI0003
o`000005oo8f0?l0003olSH0oo8f0?l000000oob=P000ol0003olSH0o`000003o`000004ooLU0?l0
003omb@0ooLT00?o00000_oh7@000ol0003onAd0ooTM0003o`0000;onAX000?o0000ooTJ0?oi6P00
0ol00002ooXI0003o`000?oj603onQP000?o000000ConQL0o`000?oj5`3onQL01?l000001?oj5`3o
0000ooTJ0?oi6P02o`0000?omb@00_l000000ooa>`3o0000oo4k0002oo4k0005o`000?oTJ@3o0000
onAY0?l000000_oTJ@02o`0000;ocZh00_l000000oo>[P3o0000olj^0002o`000003oefZ0?l0003o
GJX000?o000000CoGJX0o`000?mMZP3o00004?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00cooooo0009ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`;o000000Ko078]o`000?l0OQOo0000o`252Ol00002o`280P03
o`000?l1RP3o000000;o0h/000Ko0000o`B;0?l4R`3o0000o`F<0?l00002o`J<0003o`000?l7S03o
000000;o28d000?o0000o`R=0?l8S@001?l000001onD^@3o0000oiBi0?nD^@3o0000oiFi0?l00000
0_nF^@001_l0003oU[T0oiJi0?l0003oUkT0o`0000?oUkX000Co0000oiRj0?nH^P3o00000_nH^P00
0ol0003oV;X0o`000002oiVj0003o`000?nI^P3o000000;o000000Goei80o`000?oGTP3oei80o`00
0002omNB0004o`000?oGTP3oei80o`0000;oei8000Co0000omNB0?oGTP3o00000_oGTP001Ol0003o
ei80omNB0?l0003oei8000Go00000ooYF@001?l0003ojET0onUI0?l00002onUI0003o`000?oYF@3o
jET000?o000000GolSL0o`000?ob=P3olSH0o`000003oo8f0003o`000?ob=P3o000000;o00000_og
9@000ol0003ombD0ooLU0003o`0000;on1h000?o0000ooPM0?oh7@000ol00002ooTK0003o`000?oi
6P3onAX000?o00000_oi6@000ol0003onQT0ooXI0003o`000004ooXH0?l0003onQL0ooXG00?o0000
0_oj5`000ol0003onQL0ooXG0003o`0000;onAX000?o0000ooLT0?l000000_og90001?l0003olC/0
oo4k0?oa>`02o`000004onAY0?l0003oi6T0o`0000;oi6T00_l00002olj^00;o000000?ocZh0o`00
0?o>[P000_l000000omMZP3o0000oefZ0003o`000003oefZ0?l0003oGJX000;o00004?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo0009ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo0_l00000
1_l0LRgo0000o`1n5ol0003o08D9o`0000;o08P200?o0000o`6:0?l000000_l3R`001_l0003o18/0
o`B;0?l0003o1H`0o`0000;o1X`000?o0000o`N<0?l000000_l8S@001_l0003o28d0o`000?l0003o
TkP0o`0000;oU;T000Ko0000oiBi0?nD^@3o0000oiFi0?l00002oiJi0004o`000?nF^@3oU[T0o`00
00;oUkT000Co0000oiNj0?nG^P3o00000_nH^P001ol0003oV;X0oiRj0?l0003oV;X0o`000?nI^P00
0ol000001OoGTP3o0000omNB0?oGTP3o000000;oei8000Co0000omNB0?oGTP3o00000_oGTP001?l0
003oei80omNB0?l00002omNB0005o`000?oGTP3oei80o`000?oGTP001Ol00003onUI0004o`000?oY
F@3ojET0o`0000;ojET000?o0000onUI0?oYF@000ol000001Oob=`3o0000oo8g0?ob=`3o000000?o
lSH000?o0000oo8f0?l000000_l00002ooLU0003o`000?og9@3ombD000?o00000_oh7P000ol0003o
n1h0ooPN0003o`0000;onA/000?o0000ooTK0?oi6`000ol000001?oi6P3o0000ooTI0?oi6@04o`00
0004ooXI0?l0003onQP0ooXH00?o00000_oj5`000ol0003onQL0ooXG0003o`0000;onQP000?o0000
ooTJ0?oi6P000_l00002ooLT0005o`000?og903o0000oo4k0?l000000_oa>`001ol0003oi6T0onAY
0?l0003oi6T0o`000?oTJ@000ol000001Oo>[P3o0000olj^0?l0003ocZh000Co000000OoGJX0o`00
0?l0003o0000oefZ0?l0003oGJX000;o00004Oooool01?l0003oooooooooooooool4o`0000oooooo
0009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`;o
00001?ooool2o`000006o`1b;Ol0003o07hGo`000?l0Q@Wo00000_l0R0800ol0003o0HX0o`000002
o`>;0006o`000?l4R`3o18/0o`000?l5S03o00000_l6S007o`000004oi:h0?l0003oTkP0o`0000;o
U;T000Ko0000oiBi0?nD^@3o0000oiFi0?l00002oiJi0007o`000?nF^@3oU[T0oiJi0?l0003oUkT0
o`000002oiNj0004o`000?nH^P3oV;X0o`0000;oV;X01?l000001OoGTP3o0000omNB0?oGTP3o0000
00;oei8000Co0000omNB0?oGTP3o00000_oGTP001?l0003oei80omNB0?l00002omNB0004o`000?oG
TP3oei80omNB00Ko00000ooYF@001?l0003ojET0onUI0?l00002onUI0003o`000?oYF@3ojET000?o
000000GolSL0o`000?ob=`3olSL0o`000003oo8g0003o`000?ob=P3o000000;o00000_of9P000ol0
003ombD0ooLU0003o`0000;on1h000?o0000ooPN0?oh7P000ol00002ooTL0003o`000?oi6`3onA/0
00?o000000ConAX0o`000?oi6P3onAX00ol00002ooTI0003o`000?oj6@3onQT000?o00000_oj6000
0ol0003onQL0ooXG0003o`0000;onQL000?o0000ooXH0?oj60000ol000001?oi6`3o0000ooLT0?l0
0002ooLT00;o00000_oa>`001?l0003olC/0o`000?l00002onAY00;o00000_oTJ@002Ol0003ocZh0
o`000?l0003ocZh0o`000?o=[P3o0000olf^0002o`000006oefZ0?l0003o0000oefZ0?l0003oGJX0
0ol0000?ooooo`?o00000_ooool00ol0003oooooooooo`0@ooooo`002_ooool2o`0000Wooooo0ol0
0004ooooo`03o`000?oooooooooo00?ooooo0_l000001_l0LRgo0000o`1n5ol0003o08D9o`0000;o
08P200?o0000o`6:0?l000000_l3R`001ol0003o18/0o`B;0?l0003o1H`0o`000?l6S0000_l00000
1On@^03o0000oi6h0?nA^03o000000;oT[P000?o0000oi>h0?l000000_nD^@001_l0003oU;T0oiBi
0?l0003oUKT0o`0000?oU[T000Ko0000oiJi0?nF^@3o0000oiNi0?l00002oiNj0005o`000?nH^P3o
V;X0o`000?nH^P000_l000001OoGTP3o0000omNB0?oGTP3o000000;oei8000Co0000omNB0?oGTP3o
00000ooGTP000ol0003oei80o`000002omNB0006o`000?oGTP3oei80omNB0?l0003oei801?l00003
onUI0004o`000?oYF@3ojET0o`0000;ojET000?o0000onUI0?oYF@000ol000001Oob=`3o0000oo8g
0?ob=`3o000000?olSL000?o0000oo8g0?l000000_l00002ooHV0003o`000?of9P3omRH000?o0000
0_oh7`000ol0003on1h0ooPN0003o`0000;onA`000?o0000ooTL0?oi70000ol000001?oi6`3o0000
ooTJ0?oi6P03o`0000;onAX000?o0000ooTI0?oi6@000ol00002ooXI0003o`000?oj603onQP000?o
000000ConQP0o`000?oj5`3onQL01?l000001?oj603o0000ooTK0?oi6`03o`000006ooLT0?l0003o
mb@0o`000?oa>`3o00000ooa>`001Ol0003oi6T0o`000?oTJ@3o000000;oi6T00_l000000oo>[P3o
0000olj^0002o`0000;ocJh00_l000001?mMZP3o0000o`000?mMZP02o`000003oefZ0?l0003o0000
017ooooo00?o0000ooooooooool01Ol0000>ooooo`007?ooool00ol0003oooooooooo`03ooooo`Co
000000Co07hGo`000?l0Q@Wo00000_l0R0800ol0003o0HX0o`000002o`>;0003o`000?l4R`3o18/0
00Co000000CoT;P0o`000?n@^03o00000_nA^0001_l0003oT[P0oi:h0?l0003oTkP0o`0000;oU;T0
00Co0000oiBi0?nD^@3o00000_nE^@001?l0003oU[T0oiJi0?l00002oiJi0003o`000?nG^@3o0000
00;oUkX000?o0000oiRj0?l000000_l000001?oGT`3o0000omNB0?l00002omNB0004o`000?oGTP3o
ei80o`0000?oei8000Ko0000omNB0?oGTP3o0000omNB0?l00003omNB0003o`000?oGTP3o000000Co
00000_oYF@001?l0003ojET0onUI0?l00002onUI0003o`000?oYF@3ojET000?o000000GolSL0o`00
0?ob=`3olSL0o`000003oo8g0003o`000?ob=`3o000000;o00000_of9P000ol0003omRH0ooHV0003
o`0000;on1l000?o0000ooPO0?oh7`000ol000001?oi703o0000ooTL0?oi7004o`000004ooTK0?l0
003onA/0ooTK00?o00000_oi6P000ol0003onAX0ooTJ0003o`0000;onAT000?o0000ooXI0?oj6@00
0ol000001?oj603o0000ooXH0?oj6003o`0000;onQL000?o0000ooXH0?oj60000ol00002ooTK00;o
00000_og9002o`0000?olC/00_l000000ooTJ@3o0000o`000002onAY0006o`000?oTJ@3o0000olj^
0?l0003ocZh00_l000000oo=[P3o0000olf^0002o`000004oefZ0?l0003o0000oefZ00;o000000?o
GJX0o`000?l000004Oooool00ol0003oooooooooo`0Booooo`007?ooool2o`0000Cooooo1?l00000
1?l0OQOo0000o`252Ol00002o`280P03o`000?l1RP3o000000;o0h/000Ko0000o`B;0?l0003o0000
ohng0?l00002oi2h0003o`000?n@^03o000000;oTKP000Ko0000oi:h0?nB^03o0000oi>h0?l00002
oiBi0004o`000?nD^@3oU;T0o`0000;oUKT000Co0000oiJi0?nF^@3o00000_nF^@001?l0003oUkT0
o`000?nG^P03o`000005omNC0?l0003oei<0omNC0?l000000_oGTP000ol0003oei80o`000003omNB
0004o`000?oGTP3oei80o`0000;oei8000Go0000omNB0?oGTP3o0000omNB0005o`0000;ojET000Co
0000onUI0?oYF@3o00000_oYF@000ol0003ojET0onUI0003o`000005oo8g0?l0003olSL0oo8g0?l0
00000oob=`000ol0003olSL0o`000002o`0000;omRH000?o0000ooHV0?of9P000ol00002ooPO0003
o`000?oh7`3on1l000?o000000ConAd0o`000?oi703onA`00ol00002ooTL0003o`000?oi6`3onA/0
00?o00000_oi6`000ol0003onAX0ooTJ0003o`0000;onAX000?o0000ooTI0?oi6@000ol000001?oj
6@3o0000ooXH0?oj6003o`0000;onQP000?o0000ooXG0?oj5`000ol00002ooXH0007o`000?oi6`3o
0000ooTK0?l0003omb@0o`000002ooLT0003o`000?oa>`3o000000;olC`000?o0000onAY0?l00000
0_oTJ@001?l0003oi6T0o`000?l00002olj^00;o000000?ocJh0o`000?o=[P000_l000001?mMZP3o
0000o`000?mMZP02o`000003oefZ0?l0003o0000017ooooo00?o0000ooooooooool04_ooool001co
oooo00?o0000ooooooooool00oooool2o`000006obfJ0?l0003o0000o`000?l0Q@Wo00000_l0R080
1?l0003o0HX0o`000?l3R`03o`000004ohfg0?l0003oSkL0o`0000;oT;P000?o0000oi2h0?l00000
0_nA^0001_l0003oT[P0oi:h0?l0003oTkP0o`0000?oU;T000?o0000oiBi0?l000000_nE^@001?l0
003oU[T0oiJi0?l00002oiJi00Co000000Goei<0o`000?oGT`3oei<0o`000002omNC0004o`000?oG
TP3oei80o`0000;oei8000Co0000omNB0?oGTP3o00000_oGTP001Ol0003oei80omNB0?l0003oei80
00Go00000_oYF@001ol0003ojET0onUI0?oYF@3o0000onUI0?l000000_oYF@03o`000005oo8g0?l0
003olSL0oo8g0?l000000oob=`000ol0003olSL0o`000002o`0000;omRL000?o0000ooHV0?of9P00
0ol00002ooPP0003o`000?oh7`3on1l000?o000000Con1d0o`000?oi7@3onAd00ol00002ooTL0003
o`000?oi703onA`000?o00000_oi6`000ol0003onA/0ooTK0003o`000004ooTJ0?l0003onAX0ooTJ
00Co000000ConAT0o`000?oj6@3onQT00ol00002ooXH0003o`000?oj603onQP000?o00000_oj5`00
0ol0003onQP0ooXH0002o`0000;onA/00_l00003ooLT00;o00000_oa?0000ol0003olC`0o`000002
onAY0004o`000?oTJ@3o0000onAY00;o000000KocZh0o`000?l0003ocJh0o`000?o=[P03o`000003
oefZ0?l0003oGJX000?o000000CoGJX0o`000?l0003o00004?ooool00ol0003oooooooooo`0Aoooo
o`006oooool00ol0003oooooooooo`04ooooo`;o000000?o;IX0o`000?mJZ@000ol000000ol0R0;o
0000o`000003o`000007ohbg0?l0003oSKL0ohfg0?l0003oSkL0o`000002oi2h0003o`000?n@^03o
000000;oTKP000Co0000oi:h0?nB^03o00000_nC^0001_l0003oU;T0oiBi0?l0003oU;T0o`0000;o
UKT000Go0000oiJi0?nF^@3o0000oiJi0002o`000005omNC0?l0003oei<0omNC0?l000000_oGT`00
1?l0003oei<0omNC0?l00002omNB0004o`000?oGTP3oei80o`0000;oei8000Go0000omNB0?oGTP3o
0000omNB0005o`0000;ojET000Go0000onUI0?oYF@3ojET0o`000002onUI0003o`000?oYF@3o0000
00;o000000?olSL0o`000?ob=`000_ob=`001Ol0003olSL0oo8g0?l0003olSL000?o00000_of9`00
0ol0003omRL0ooHW0003o`0000;on20000?o0000ooPP0?oh80000ol000001?oh7@3o0000ooPM0?oh
7@03o`0000;onA`000?o0000ooTL0?oi70000ol00002ooTK0003o`000?oi6`3onA/000?o000000Co
nA/0o`000?oi6P3onAX00ol00002ooTJ0003o`000?oi6@3onAT000?o00000_oj6@000ol0003onQP0
ooXH0003o`000004ooXH0?l0003onQL0ooXG00Co000000ConQP0o`000?oi6`3o00000_oi6`001ol0
003omb@0o`000?og9@3o0000oo4l0?l000000_oa?002o`000005onAY0?l0003oi6T0o`000?oTJ@00
0ol000001_o=[P3o0000o`000?o=[P3o0000olf^00;o000000?oGJX0o`000?mMZP000ol000001OmM
ZP3o0000o`000?mMZP3o0000013ooooo00?o0000ooooooooool04?ooool001_ooooo0_l00006oooo
o`?o000000?oFZT0o`000?mf/@000_l000001?n3]03o0000ohVf0?l00002ohbg0006o`000?n=]`3o
SKL0o`000?n?]`3o00000_n@^0000ol0003oT;P0o`000002oi6h0004o`000?nB^03oT[P0o`0000;o
TkP000Ko0000oiBi0?nD^@3o0000oiBi0?l00002oiFi0003o`000?nF^@3o000000;o000000Coei<0
o`000?oGT`3o00000_oGT`001?l0003oei<0omNC0?l00003omNC0003o`000?oGTP3o000000;oei80
00Go0000omNB0?oGTP3o0000omNB0005o`0000;ojET000Go0000onUI0?oYF@3ojET0o`000002onUI
0003o`000?oYF@3o000000;o000000?olSL0o`000?ob=`000_ob=`001Ol0003olSL0oo8g0?l0003o
lSL000?o00000_of9`000ol0003omRL0ooHW0003o`0000;on20000?o0000ooPP0?oh80000ol00000
1?oh7P3o0000ooPM0?oh7@03o`0000;onAd000?o0000ooTL0?oi70000ol00002ooTL0003o`000?oi
6`3onA/000?o000000ConA/0o`000?oi6`3onA/00ol00002ooTJ0003o`000?oi6P3onAX000?o0000
0_oi6@000ol0003onQT0ooXI0003o`000004ooXH0?l0003onQP0ooXH00?o00000_oj60000ol0003o
nQP0ooXH0003o`0000;onA/00_l00002ooLU00;o00000_oa?0002?l0003olC`0oo4l0?l0003oi6T0
o`000?oTJ@3o00000_oTJ@02o`000005olf^0?l0003ocJh0o`000?o=[P001?l000001OmMZP3o0000
o`000?l0003oGJX000;o000000?oGJX0o`000?ooool03oooool00ol0003oooooooooo`0@ooooo`00
6oooool00ol0003oooooooooo`05ooooo`?o000000CoFZT0o`000?mf/@3o00000_n3]0000ol0003o
RKH0o`000002ohbg0006o`000?n=]`3oSKL0o`000?n?]`3o00000_n@^0001?l0003oT;P0oi2h0?l0
0002oi6h0003o`000?nB^03o000000;oTkP000Oo0000oiBi0?nD^@3o0000oiBi0?l0003oUKT000?o
000000Goei<0o`000?oGT`3oei<0o`000002omNC0003o`000?oGT`3o000000?oei<000Ko0000omNC
0?oGT`3o0000omNB0?l00002omNB0003o`000?oGTP3o000000Co00000ooYF@001?l0003ojET0onUI
0?l00002onUI0003o`000?oYF@3o000000;o000000?olSL0o`000?ob=`000_ob=`001?l0003olSL0
oo8g0?l00002oo8g00;o00000_of9`000ol0003omRL0ooHW0003o`0000;on24000?o0000ooPP0?oh
80000ol000001?oh7P3o0000ooPN0?oh7P03o`0000;onAd000?o0000ooTM0?oi7@000ol00002ooTL
0003o`000?oi703onA`000?o000000ConA`0o`000?oi6`3onA/00ol00002ooTK0003o`000?oi6P3o
nAX000?o00000_oi6P000ol0003onAT0ooTI0003o`000004ooXI0?l0003onQP0ooXH00?o00000_oj
60000ol0003onQP0ooXH0003o`0000;onQP00ol000001?oi6`3o0000ooLU0?l00002ooLU0003o`00
0?oa?03o000000;olC`000Go0000onAY0?l0003oi6T0o`000002onAY00;o000000?ocJh0o`000?o=
[P000_l000000oo=[P3o0000olf^0002o`000004oefZ0?l0003o0000oefZ00;o000000?oGJX0o`00
0?l000004?ooool00ol0003oooooooooo`0?ooooo`006oooool2o`0000Kooooo0ol000001?mJZ@3o
0000ogJa0?l00002oh>d0003o`000?n9]P3o000000;oS;L000Ko0000ohfg0?n=]`3o0000ohng0?l0
0002oi2h0004o`000?n@^03oT;P0o`0000;oTKP000?o0000oi:h0?l000000_nC^0000ol0003oU;T0
oiBi0004o`000005omNC0?l0003oei<0omNC0?l000000_oGT`001?l0003oei<0omNC0?l00002omNC
0004o`000?oGT`3oei<0o`0000;oei<000?o0000omNB0?oGTP001_l00003onUI0004o`000?oYF@3o
jET0o`0000;ojET000?o0000onUI0?l000000_l000000oob=`3o0000oo8g0002oo8g0004o`000?ob
=`3olSL0o`0000;olSL00ol000001?of9`3o0000ooHW0?of9`03o`0000;on24000?o0000ooPQ0?oh
8@000ol000001?oh7P3o0000ooPN0?oh7P03o`0000;on1d000?o0000ooTM0?oi7@000ol00002ooTM
0003o`000?oi703onA`000?o000000ConA`0o`000?oi703onA`00ol00002ooTK0003o`000?oi6`3o
nA/000?o00000_oi6P000ol0003onAX0ooTJ0003o`000004ooTJ0?l0003onQT0ooXI00?o00000_oj
60000ol0003onQP0ooXH0003o`000003ooXH0?l0003onQP000;o000000ConQP0o`000?oi6`3onA/0
0_l00003ooLU00;o00000_oa?0000ol0003olC`0o`000002onAY0004o`000?oTJ@3o0000onAY00;o
00000_o=[P02o`000003olf^0?l0003ocJh000;o000000CoGJX0o`000?l0003oGJX00_l000000omM
ZP3o0000o`00000@ooooo`03o`000?oooooooooo00oooooo000Kooooo`03o`000?oooooooooo00Go
oooo0ol000001?mJZ@3o0000ogJa0?l00002oh>d0003o`000?n9]P3o000000;oS;L000Co0000ohfg
0?n=]`3o00000_n?]`000ol0003oT;P0o`000002oi2h0006o`000?nA^03oTKP0o`000?nB^03o0000
0_nC^0001_l0003oU;T0o`000?l0003oei@0o`0000;oei<000Co0000omNC0?oGT`3o00000_oGT`00
1?l0003oei<0omNC0?l00002omNC0004o`000?oGT`3oei<0o`0000;oei<000?o0000omNB0?l00000
0ol00003onUI0004o`000?oYF@3ojET0o`0000;ojET000?o0000onUI0?l000000_l000000oob=`3o
0000oo8g0002oo8g0004o`000?ob=`3olSL0o`0000;olSL00ol000001?of9`3o0000ooHW0?of9`03
o`0000;on24000?o0000ooPQ0?oh8@000ol000001?oh7P3o0000ooPN0?oh7P03o`0000;on1d000?o
0000ooPM0?oh7@000ol00002ooTM0003o`000?oi7@3onAd000?o000000ConA`0o`000?oi703onA`0
0ol00002ooTL0003o`000?oi6`3onA/000?o000000ConA/0o`000?oi6P3onAX01?l000001?oi6P3o
0000ooTJ0?oi6P03o`0000;onAT000?o0000ooXH0?oj60000ol000001?oj603o0000ooXH0?oj6003
o`0000;onQP00ol00002ooTK000:o`000?og9@3o0000ooLU0?l0003olC`0o`000?oa?03o0000oo4l
00;o00000_oTJ@001?l0003oi6T0o`000?l00002olf^00?o000000?ocJh0o`000?o=[P000_l00000
1?mMZP3o0000o`000?mMZP02o`000003oefZ0?l0003o0000013ooooo00?o0000ooooooooool03_oo
ool000;ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00000_ooool3o`0000Gooooo00?o
0000ooooooooool01_ooool2o`000004oeZY0?l0003oM[40o`0000;oPk@000?o0000ohVf0?l00000
0_n<]`001?l0003oSKL0ohfg0?l00002ohng0003o`000?n@^03o000000;oT;P000Oo0000oi6h0?nA
^03o0000oi:h0?l0003oTkP000?o000000Coei@0o`000?oGU03o00000_oGT`001?l0003oei<0omNC
0?l00003omNC0003o`000?oGT`3o000000;oei<000Go0000omNC0?oGT`3o0000omNC0005o`0000;o
jET000Co0000onUI0?oYF@3o00000_oYF@000ol0003ojET0onUI0002o`000003oo8g0?l0003olSL0
00;olSL000Co0000oo8g0?ob=`3o00000_ob=`03o`000004ooHW0?l0003omRL0ooHW00?o00000_oh
8@000ol0003on240ooPQ0003o`0000;on1l000?o0000ooPN0?l000000_l00002ooPN0003o`000?oh
7@3on1d000?o00000_oh7@000ol0003onAd0ooTM0003o`000004ooTM0?l0003onA`0ooTL00?o0000
0_oi70000ol0003onA`0ooTL0003o`000004ooTK0?l0003onA/0ooTK00?o00000_oi6`000ol0003o
nAX0ooTJ0003o`0000;onAX000?o0000ooTI0?oi6@000ol000000ooj6@3o0000o`000004o`0000;o
nQP00ol000001?oj603o0000ooTK0?oi6`03o`0000;ombD00_l000000ooa?03o0000oo4l0002oo4l
0006o`000?oTJ@3o0000onAY0?l0003oi6T00ol000001_o=[P3o0000o`000?o=[P3o0000olf^00;o
000000CoGJX0o`000?l0003oGJX00_l000001?mMZP3o0000o`000?l0000@ooooo`03o`000?oooooo
oooo00gooooo00001Ooooooo0000oooooooooooo000000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2o`000004oeZY
0?l0003oM[40o`0000;oPk@000?o0000ohVf0?l000000on<]`000ol0003oSKL0o`000002ohng0003
o`000?n@^03o000000;oT;P000?o0000oi6h0?nA^0001?l000001OoGU03o0000omND0?oGU03o0000
00;oei@000?o0000omNC0?l000000ooGT`001_l0003oei<0omNC0?l0003oei<0o`0000;oei<000?o
0000omNC0?l000001?l00002onUI0004o`000?oYF@3ojET0o`0000;ojET000?o0000onUI0?oYF@00
0ol000001Oob=`3o0000oo8g0?ob=`3o000000;olSL000?o0000oo8g0?ob=`000ol00002ooHW0003
o`000?of9`3o000000;o00000_oh8@000ol0003on240ooPQ0003o`0000;on1l000?o0000ooPO0?oh
7`000_l00002ooPN0003o`000?oh7P3on1h000?o00000_oh7@000ol0003on1d0ooPM0003o`000004
ooTM0?l0003onAd0ooTM00?o00000_oi70000ol0003onA`0ooTL0003o`000004ooTL0?l0003onA/0
ooTK00?o00000_oi6`000ol0003onA/0ooTK0003o`0000;onAX000?o0000ooTJ0?oi6P000ol00000
1?oi6@3o0000o`000?l00002ooXI0003o`000?oj603onQP000?o000000ConQP0o`000?oj603onQP0
0ol00002ooTK0004o`000?og9@3o0000ooLU00;o00000ooa?002o`000005onAY0?l0003o0000onAY
0?l000000_oTJ@001ol0003ocJh0o`000?l0003ocJh0o`000?o=[P000ol000001?mMZP3o0000o`00
0?mMZP02o`000003oefZ0?l0003o0000013ooooo0_l0000>ooooo`0000Goooooo`000?oooooooooo
o`000009ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00008ooooo`;o
00000_mJZ@02o`0000;oPk@000Co0000ohVf0?n9]P3o00000_n<]`000ol0003oSKL0o`000002ohng
0003o`000?n@^03o000000;oT;P000Ko0000oi6h0?l0003o0000omND0?l00002omND0004o`000?oG
U03oei@0o`0000;oei@000Co0000omNC0?oGT`3o00000_oGT`001?l0003oei<0omNC0?l00002omNC
00Ko00000_oYF@001ol0003ojET0onUI0?oYF@3o0000onUI0?l000000_oYF@03o`000005oo8g0?l0
003olSL0oo8g0?l000000_ob=`000ol0003olSL0oo8g0003o`0000;omRL000?o0000ooHW0?of9`00
0_l00002ooPQ0003o`000?oh8@3on24000?o00000_oh7`000ol0003on1l0ooPO0003o`000004ooPN
0?l0003on1h0ooPN00?o00000_oh7P000ol0003on1d0ooPM0003o`000004ooPM0?l0003onAd0ooTM
00?o00000_oi7@000ol0003onA`0ooTL0003o`000004ooTL0?l0003onA`0ooTL00?o00000_oi6`00
0ol0003onA/0ooTK0003o`0000;onA/01_l000001?oi6P3o0000o`000?l00002ooTI0003o`000?oj
6@3onQT000?o000000ConQP0o`000?oj603onQP00ol00002ooXH0003o`000?oi6`3onA/000;o0000
00OombD0o`000?og9@3ombD0o`000?oa?03o000000;olC`000Go0000onAY0?l0003oi6T0o`000002
onAY00;o000000KocJh0o`000?l0003ocJh0o`000?o=[P02o`000004oefZ0?l0003o0000oefZ00;o
000000CoGJX0o`000?l0003o00003oooool2o`0000kooooo00001Ooooooo0000oooooooooooo0000
00[ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Wooooo0_l00002
oeZY0005o`000?mf/@3o0000oh>d0?l000000_n9]P001_l0003oS;L0ohbg0?l0003oSKL0o`0000;o
SkL01ol000001?oGU@3o0000omND0?l00002omND0004o`000?oGU03oei@0o`0000;oei@000Co0000
omNC0?oGT`3o00000_oGT`001Ol0003oei<0omNC0?l0003oei<000Co00000ooYF@001?l0003ojET0
onUI0?l00002onUI0003o`000?oYF@3o000000;o000000GolSL0o`000?ob=`3olSL0o`000003oo8g
0003o`000?ob=`3o000000;o00000_of9`000ol0003omRL0ooHW0003o`000004ooPQ0?l0003on240
ooPQ00?o00000_oh7`000ol0003on1l0ooPO0003o`000004ooPN0?l0003on1h0ooPN00?o00000_oh
7P000ol0003on1h0ooPN0003o`000004ooPN0?l0003on1d0ooPM00?o00000_oi7@000ol0003onAd0
ooTM0003o`000004ooTM0?l0003onA`0ooTL00?o00000_oi70000ol0003onA/0ooTK0003o`0000;o
nA/00ol000001?oi6`3o0000ooTJ0?oi6P03o`0000;onAX000?o0000ooTI0?oi6@000ol000001?oj
6@3o0000ooXH0?oj6003o`0000;onQP000?o0000ooXH0?oj60000ol000000ooi6`3o0000o`000003
ooLU00;o00000_oa?0000ol0003olC`0o`000002onAY0006o`000?oTJ@3o0000onAY0?l0003ocJh0
0_l000000oo=[P3o0000olf^0005o`000005oefZ0?l0003o0000o`000?mMZP000_l0000Aooooo`03
o`000?oooooooooo00_ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Ko0000oooooooo
ooooooooo`000?ooool4o`0000Cooooo00?o0000ooooooooool01oooool2o`0000;oFZT000Go0000
ogJa0?l0003oPk@0o`000002ohVf0007o`000?n<]`3oS;L0o`000?n=]`3o0000ohng0002o`000005
omJE0?l0003oeYD0omJE0?l000000_oGU@000ol0003oei@0o`000002omND0007o`000?oGU03oei@0
omND0?l0003oei@0o`000002omNC0003o`000?oGT`3o000000Go000000GojET0o`000?oYF@3ojET0
o`000002onUI0005o`000?oYF@3ojET0o`000?oYF@000ol000000oob=`3o0000oo8g0002oo8g0005
o`000?ob=`3olSL0o`000?ob=`000ol00002ooHW0003o`000?of9`3omRL000?o000000Con240o`00
0?oh8@3on2400ol00002ooPO0003o`000?oh7`3on1l000?o000000Con1h0o`000?oh7P3on1h00ol0
0002ooPN0003o`000?oh7P3on1h000?o000000Con1h0o`000?oh7P3on1h00ol00002ooPM0003o`00
0?oi7@3onAd000?o000000ConAd0o`000?oi7@3onAd00ol00002ooTL00Ko00000_oi7003o`000004
ooTK0?l0003onA/0ooTK00?o00000_oi6P000ol0003onAX0ooTJ0003o`000004ooTI0?l0003onQT0
ooXI00?o00000_oj60000ol0003onQP0ooXH0003o`000004ooXH0?l0003onA/0o`0000;onA/000Oo
0000ooLU0?l0003ombD0o`000?oa?03o000000;olC`00ol00002onAY0007o`000?oTJ@3o0000o`00
0?o=[P3o0000olf^0002o`000003olf^0?l0003ocJh000;o000000?oGJX0o`000?l000000_l00000
1?mMZP3o0000o`000?l0000?ooooo`03o`000?oooooooooo00_ooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo0_l00009ooooo`;o
000000KoFZT0o`000?mf/@3o0000oh>d0?l00002ohVf0003o`000?n<]`3oS;L000Co000000CoeYH0
o`000?oFU@3o00000_oFU@001_l0003oeiD0omNE0?l0003oei@0o`0000?oei@000Co0000omND0?oG
U03o00000_oGU007o`000005onUI0?l0003ojET0onUI0?l000000_oYF@001Ol0003ojET0onUI0?l0
003ojET000?o000000?olSL0o`000?ob=`000_ob=`001Ol0003olSL0oo8g0?l0003olSL000?o0000
0_of9`000ol0003omRL0ooHW0003o`000004ooPQ0?l0003on240ooPQ00?o00000_oh7`000ol0003o
n1l0ooPO0003o`000004ooPN0?l0003on1h0ooPN00?o00000_oh7P000ol0003on1h0ooPN0003o`00
0004ooPN0?l0003on1h0ooPN00?o00000_oh7P000ol0003on1d0ooPM0003o`000003ooPM0?l0003o
000000Co00000_oi7@03o`0000;onA`000?o0000ooTL0?oi70000ol000001?oi703o0000ooTK0?oi
6`03o`0000;onA/000?o0000ooTJ0?oi6P000ol000001?oi6P3o0000ooTI0?oi6@03o`0000;onQT0
00?o0000ooXH0?oj60000ol000001?oj603o0000ooXH0?oj6002o`0000?onA/00_l00002ooLU00;o
00000_oa?0002Ol0003olC`0oo4l0?l0003oi6T0o`000?oTJ@3o0000onAY0002o`0000;ocJh00_l0
00000oo=[P3o0000olf^0002o`000003oefZ0?l0003o000000;o000000GoGJX0o`000?l0003oGJX0
o`00000?ooooo`03o`000?oooooooooo00[ooooo0002ooooo`;o00002Oooool3o`0000;ooooo1Ol0
0003ooooo`03o`000?oooooooooo00Sooooo00So0000olNm0?l0003o0000ogJa0?l0003oPk@0o`00
00;oRKH000Ko0000ohbg0?l0003o0000omJF0?l00002omJF0003o`000?oFU@3o000000;oeYD000Co
0000omNE0?oGU@3o00000_oGU0001?l0003oei@0omND0?l00002omND0003o`000?oGU03o000000Co
00000_oYF@000ol0003ojET0o`000003onUI0003o`000?oYF@3o000000;ojET00_l000000oob=`3o
0000oo8g0002oo8g0004o`000?ob=`3olSL0o`0000;olSL00_l00002ooHW0003o`000?of9`3omRL0
00?o00000_oh8@000ol0003on240o`000002o`0000;on1l000?o0000ooPO0?oh7`000ol00002ooPN
0003o`000?oh7P3o000000;o00000_oh7P000ol0003on1h0ooPN0003o`0000;on1h000?o0000ooPN
0?l000000_l00002ooPN0003o`000?oh7P3on1h000?o00000_oh7@02o`0000;on1d000?o0000ooTM
0?oi7@000ol00002ooTM0003o`000?oi703onA`000?o000000ConA`0o`000?oi703onA`00ol00002
ooTK0003o`000?oi6`3onA/000?o000000ConAX0o`000?oi6P3onAX00ol00002ooTI0003o`000?oj
6@3onQT000?o000000ConQP0o`000?oj603onQP00ol00002ooXH000;o`000?oi6`3o0000ooTK0?l0
003ombD0o`000?og9@3o0000oo4l0?l000000ooa?0001_l0003oi6T0o`000?oTJ@3o0000onAY00?o
000000OocJh0o`000?l0003o0000olf^0?l0003ocJh000;o000000GoGJX0o`000?l0003o0000oefZ
0002o`000003oefZ0?l0003ooooo00oooooo00?o0000ooooooooool02Oooool001[ooooo00?o0000
ooooooooool02?ooool00ol0003oakd0olNm0003o`000003oh>d0?l0003oRKH000?o000000CoeYL0
o`000?oFUP3o00000_oFUP000ol0003oeYD0o`000002omJE0007o`000?oGU@3oeiD0omNE0?l0003o
ei@0o`000002omND0003o`000?oGU03o000000Co00000_oYF@001?l0003ojET0onUI0?l00002onUI
0005o`000?oYF@3ojET0o`000?oYF@000ol000001Oob=`3o0000oo8g0?ob=`3o000000;olSL000?o
0000oo8g0?ob=`000ol000001?of9`3o0000ooHW0?of9`03o`0000;on24000?o0000ooPQ0?oh8@00
0_l00002ooPO0003o`000?oh7`3on1l000?o00000_oh7P000ol0003on1h0ooPN0002o`0000;on1h0
00?o0000ooPN0?oh7P000ol00002ooPN0003o`000?oh7P3on1h000;o00000_oh7P000ol0003on1h0
ooPN0003o`0000;on1h00ol000001?oh7P3o0000ooPM0?oh7@03o`0000;onAd000?o0000ooTM0?oi
7@000ol000001?oi703o0000ooTL0?oi7003o`0000;onA`000?o0000ooTK0?oi6`000ol000001?oi
6`3o0000ooTJ0?oi6P03o`0000;onAX000?o0000ooTI0?oi6@000ol000001?oj6@3o0000ooXH0?oj
6003o`0000;onQP000?o0000ooXH0?oj60000_l00002ooTK00;o00000_og9@02o`0000?olC`000So
0000oo4l0?l0003oi6T0o`000?oTJ@3o0000onAY00?o000000KocJh0o`000?l0003ocJh0o`000?o=
[P03o`000004oefZ0?l0003o0000oefZ00;o000000?oGJX0o`000?l000003oooool2o`0000[ooooo
000Iooooo`;o00002_ooool01Ol0003oakd0olNm0?l0003od:L000Co000000OoeIT0o`000?oFU`3o
eYL0o`000?oFUP3o000000;oeYH000Co0000omJE0?oFU@3o00000_oFU@001ol0003oeiD0omNE0?l0
003oei@0o`000?oGU0001_l000001OoYF@3o0000onUI0?oYF@3o000000;ojET000Go0000onUI0?oY
F@3o0000onUI0003o`000005oo8f0?l0003olSL0oo8g0?l000000_ob=`000ol0003olSL0oo8g0003
o`0000;omRL000?o0000ooHW0?l000000_l00002ooPQ0003o`000?oh8@3on24000?o000000Con1l0
o`000?oh7`3on1l00ol00002ooPN0003o`000?oh7P3on1h000?o000000Con1h0o`000?oh7P3on1h0
0ol00002ooPN0003o`000?oh7P3on1h000?o000000?on1h0o`000?l000001?l00002ooPN00?o0000
00Con1h0o`000?oh7P3on1h00ol00002ooPM0003o`000?oi7@3onAd000?o000000ConAd0o`000?oi
703onA`00ol00002ooTL0003o`000?oi703onA`000?o000000ConA/0o`000?oi6`3onA/00ol00002
ooTJ0003o`000?oi6P3onAX000?o000000ConAT0o`000?oj6@3onQT00ol000001?oj603o0000ooXH
0?oj6004o`000008ooXI0?l0003o0000o`000?oi6`3o0000ooLU0?l00002ooLU0004o`000?oa?03o
0000oo4l00;o000000Goi6T0o`000?l0003oi6T0o`000002onAY0007o`000?o=[P3o0000o`000?o=
[P3o0000olf^0003o`000004oefZ0?l0003o0000oefZ00;o000000?oGJX0o`000?l000004?ooool0
0ol0003oooooooooo`08ooooo`006Oooool00ol0003oooooooooo`09ooooo`08o`000?o7_@3oakd0
o`000?o@Y`3o0000omBM0?l00002omFI0006o`000?oFU`3oeYL0o`000?oFUP3o00000ooFUP000ol0
003oeYD0o`000002omJE0003o`000?oGU@3oeiD000Oo000000GojET0o`000?oYF@3ojET0o`000002
onUI0004o`000?oYF@3ojET0onUI00Co000000?olSH0o`000?ob=P000_ob=P001Ol0003olSL0oo8g
0?l0003olSL000?o00000_of9`000ol0003omRL0ooHW0002o`0000;on24000?o0000ooPQ0?oh8@00
0ol00002ooPO0003o`000?oh7`3o000000;o00000_oh7P000ol0003on1h0ooPN0003o`000004ooPN
0?l0003on1h0ooPN00?o00000_oh7P000ol0003on1h0ooPN0003o`000004ooPN0?l0003o0000o`00
00;on1h000?o0000ooPN0?oh7P000ol000001?oh7P3o0000ooPN0?oh7P03o`0000;on1h000?o0000
ooPM0?oh7@000ol000001?oh7@3o0000ooTM0?oi7@03o`0000;onAd000?o0000ooTL0?oi70000ol0
00001?oi703o0000ooTK0?oi6`03o`0000;onA/000?o0000ooTJ0?oi6P000ol000001?oi6P3o0000
ooTI0?oi6@03o`000003ooXI0?l0003o000000Co00000_oj6003o`000004ooXI0?l0003onA/0ooTK
00;o00000oog9@02o`000009oo4l0?l0003olC`0oo4l0?l0003oi6T0o`000?oTJ@3o000000;oi6T0
0_l000001_o=[P3o0000o`000?o=[P3o0000olf^00?o000000CoGJX0o`000?l0003oGJX00_l00000
0omNZP3o0000o`00000>ooooo`?o00002Oooool001Wooooo00?o0000ooooooooool02Oooool2o`00
0006olNm0?l0003od:L0o`000?oDW@3o00000_oEV@001?l0003oeYL0omJG0?l00002omJF0006o`00
0?oFUP3oeYH0o`000?oFU@3o00000_oFU@000ol0003oeiD0o`000004o`0000;ojET000?o0000onUI
0?l000000ooYF@001Ol0003ojET0onUI0?l0003ojET000;o000000?olSH0o`000?ob=P000_ob=P00
0ol0003olSH0oo8f0005o`0000;omRH000?o0000ooHW0?of9`000ol000001?oh8@3o0000ooPQ0?oh
8@03o`0000;on1l000?o0000ooPO0?oh7`000_l00002ooPN0003o`000?oh7P3on1h000?o00000_oh
7P000ol0003on1h0o`000002o`0000;on1h01_l000001?oh7P3o0000o`000?l00002ooPN0003o`00
0?oh7P3on1h000?o000000Con1h0o`000?oh7P3on1h00ol00002ooPN0003o`000?oh7P3on1h000?o
000000Con1d0o`000?oh7@3on1d00ol00002ooTM0003o`000?oi7@3onAd000?o000000ConA`0o`00
0?oi703onA`00ol00002ooTK0003o`000?oi6`3onA/000?o000000?onA/0o`000?l000001?l00000
1?oi6P3o0000o`000?l00002ooTI0003o`000?oj603onQP000?o000000ConQP0o`000?oj6@3onQT0
0ol00002ooTL0004o`000?og9@3o0000ooLU00;o00000_oa?0000ol0003olC`0o`000002onAY0006
o`000?oTJ@3o0000onAZ0?l0003ocJh00_l000000oo=[P3o0000olf^0003o`000004oefZ0?l0003o
0000oefZ00;o000000CoGZX0o`000?l0003o00002_ooool3o`0000;ooooo00?o0000ooooooooool0
1oooool001Wooooo0_l0000;ooooo`07o`000?o7_@3o0000om2W0?l0003oe9d0o`000002omFI0007
o`000?oFU`3oeYL0omJG0?l0003oeYH0o`000002omJF0004o`000?oFU@3o0000omJE00Go00000_oY
F@001?l0003ojET0onUI0?l00002onUI0005o`000?oYF@3ojET0o`000?oYF@000ol000001Oob=P3o
0000oo8f0?ob=P3o000000;olSH00ol000001Oof9P3o0000ooHV0?of9P3o000000;omRH00ol00000
1?oh8@3o0000ooPQ0?oh8@03o`0000;on1l000?o0000ooPO0?oh7`000ol000001?oh7P3o0000ooPN
0?oh7P03o`0000;on1h000?o0000ooPN0?oh7P000_l00002ooPO00?o00000_oh7`000ol0003on1l0
o`000002o`0000;on1l000?o0000ooPN0?oh7P000ol000001?oh7P3o0000ooPN0?oh7P03o`0000;o
n1h000?o0000ooPN0?oh7P000ol000001?oh7P3o0000ooPM0?oh7@03o`0000;on1d000?o0000ooTM
0?oi7@000ol000001?oi7@3o0000ooTL0?oi7003o`0000;onA`01_l000001_oi6`3o0000o`000?l0
003onA/0o`0000;onAX00ol00002ooTJ0003o`000?oi6@3onAT000?o000000ConQP0o`000?oj603o
nQP00ol00002ooXI0003o`000?oi703onA`000;o000000KombD0o`000?og9@3o0000oo4l0?l00002
oo4l00?o00000_oTJ@001ol0003oi6X0o`000?l0003ocJh0o`000?o=[P000_l000001Oo=[P3o0000
o`000?l0003oGJX000;o000000CoGJX0o`000?l0003oGZX00_l00007ooooo`?o00001Oooool00ol0
003oooooooooo`07ooooo`006Oooool00ol0003oooooooooo`0:ooooo`03o`000?o7_@3oakd000;o
000000?oe9d0o`000?oEV@000_oEV@001_l0003oeYL0omJG0?l0003oeYH0o`0000;oeYH01_l00002
onUI0004o`000?oYF@3ojET0o`0000;ojET000Go0000onUI0?oYF@3o0000onUI0003o`000003oo8f
0?l0003olSH000;olSH000?o0000oo8f0?l000000_l000000oof9P3o0000ooHV0002ooHV0003o`00
0?of9P3o000000;o00000_oh80000ol0003on240o`000002o`0000;on1h000?o0000ooPO0?oh7`00
0ol000001?oh7P3o0000ooPN0?oh7P03o`0000;on1h000?o0000ooPN0?oh7P000ol000001?oh7`3o
0000o`000?l00002ooPO0003o`000?oh7`3on1l000;o00000_oh7`000ol0003on1l0ooPO0003o`00
00;on1l000?o0000ooPN0?l000000_l00002ooPN0003o`000?oh7P3on1h000?o000000Con1h0o`00
0?oh7P3on1h00ol00002ooPM0003o`000?oh7@3on1d000?o000000?onAd0o`000?l000001?l00002
ooTL00?o000000ConA`0o`000?oi6`3onA/00ol000001?oi6`3o0000ooTK0?oi6`03o`0000;onAX0
00?o0000ooTJ0?oi6P000ol000001?oi6@3o0000ooXH0?oj6003o`0000;onQP000?o0000ooXI0?oj
6@000ol000000ooi703o0000o`000002ooLU00;o00000_oa?0002Ol0003olC`0oo4l0?l0003oi6T0
o`000?oTJP3o0000onAZ0002o`0000;ocJh00ol000001?o=[P3o0000o`000?mMZP02o`000004oefZ
0?l0003o0000oejZ00?o00000_ooool4o`0000Sooooo00?o0000ooooooooool01oooool001Wooooo
00?o0000ooooooooool02_ooool02?l0003oakd0olNm0?l0003od:L0o`000?oDW@3o00000_oEV@00
1ol0003oeYL0omJG0?l0003oeYH0o`000?oFUP001?l00003onUH0003o`000?oYF@3o000000;ojET0
00Co0000onUI0?oYF@3ojET01?l000000oob=P3o0000oo8f0002oo8f0003o`000?ob=P3o000000;o
000000?omRH0o`000?of9P000_of9P000ol0003omRH0o`000002o`0000;on20000?o0000ooPP0?oh
80000_l00002ooPN0003o`000?oh7P3on1h000?o00000_oh7P000ol0003on1h0o`000002o`0000;o
n1h01_l000001?oh7`3o0000o`000?l00002ooPO0003o`000?oh7`3on1l000?o000000Con1l0o`00
0?oh7`3on1l00ol00002ooPO0003o`000?oh7`3on1l000;o00000_oh7P000ol0003on1h0ooPN0003
o`000004ooPN0?l0003on1h0ooPN00?o00000_oh7P06o`000004ooPM0?l0003o0000o`0000;onAd0
00?o0000ooTM0?oi7@000ol000001?oi703o0000ooTL0?oi7003o`000004ooTL0?l0003onA/0ooTK
00?o00000_oi6`000ol0003onAX0ooTJ0003o`000004ooTJ0?l0003onAT0ooTI00?o00000_oj6@00
0ol0003onQP0ooXH0003o`000008ooXI0?l0003onA`0o`000?oi703o0000ooLU0?l00002ooLU0004
o`000?oa?03o0000oo4l00;o000000Goi6T0o`000?oTJP3o0000onAZ0003o`000005olf^0?l0003o
0000o`000?o=[P001Ol000001OmMZP3o0000o`000?l0003oGZX000Co00003Oooool00ol0003ooooo
ooooo`06ooooo`006?ooool3o`0000_ooooo0_l000001_o7_@3o0000om2W0?l0003oe9d0o`0000;o
eIT000?o0000omJG0?oFU`001_l00002onUH0004o`000?oYF03ojEP0o`0000;ojET000Go0000onUI
0?oYF@3o0000onUI0002o`000003oo8e0?l0003olSH000;olSH000?o0000oo8f0?ob=P000_l00000
0oog9@3o0000ooHV0002ooHV0003o`000?of9P3omRH000;o00000_oh80000ol0003on200ooPP0003
o`000004ooPN0?l0003on1h0ooPN00?o00000_oh7P000ol0003on1h0ooPN0002o`0000;on1h00ol0
0002ooPN0003o`000?oh7P3on1h000;o00000_oh7`000ol0003on1l0ooPO0003o`000004ooPO0?l0
003on1l0ooPO00?o00000_oh7`000ol0003on1l0ooPO0003o`000004ooPO0?l0003on1h0ooPN00?o
00000_oh7P05o`0000;on1h00ol000001?oh7P3o0000ooPN0?oh7P03o`0000;on1d000?o0000ooTM
0?oi7@000ol000001?oi7@3o0000ooTL0?oi7003o`000004ooTL0?l0003onA`0ooTL00?o00000_oi
6`000ol0003onA/0ooTK0003o`000004ooTJ0?l0003onAX0ooTJ00?o00000_oi6@000ol0003onQT0
ooXI0003o`000004ooXH0?l0003onQT0ooXI00;o00000_oi7002o`0000?ombD00_l000002_oa?03o
0000oo4l0?oa?03o0000onAZ0?l0003oi6X0o`000?oTJP03o`000007olf^0?l0003o0000o`000?o=
[P3o0000olf^0002o`000003oefZ0?l0003o000000;o000000?oGZX0o`000?l000003_ooool00ol0
003oooooooooo`06ooooo`001Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Ko
oooo00?o0000ooooooooool02oooool3o`000005om2W0?l0003oe9d0o`000?oEV@001ol00002onUH
0004o`000?oYF03ojEP0o`0000;ojEP000Go0000onUI0?oYF@3o0000onUI0003o`000005oo8e0?l0
003olSD0oo8e0?l000000_ob=P03o`000005ooLU0?l0003ombD0ooLU0?l000000_of9P03o`000004
ooPO0?l0003on200ooPP00?o00000_oh7P000ol0003on1h0o`000002o`0000;on1h000?o0000ooPN
0?oh7P000ol000001?oh7P3o0000o`000?l00002ooPN0003o`000?oh7P3on1h000?o000000Con1l0
o`000?oh7`3on1l00ol00002ooPO0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1l0ooPO
0003o`000004ooPO0?l0003on1l0ooPO00?o00000_oh7`03o`000004ooPN0?l0003on1h0ooPN00?o
000000Con1h0o`000?oh7P3on1h00ol00002ooPN0003o`000?oh7@3on1d000?o000000ConAd0o`00
0?oi7@3onAd00ol000001?oi703o0000ooTL0?oi7003o`0000;onA`000?o0000ooTK0?oi6`000ol0
00001?oi6`3o0000ooTJ0?oi6P03o`0000;onAX000?o0000ooTI0?oi6@000ol000000ooj6@3o0000
o`000004o`000004ooXI0?l0003o0000o`0000;onA`000Co0000ooLU0?l0003ombD00_l00002oo4l
00;o000000?oi6X0o`000?oTJP000_l00002onAZ0003o`000?o=[P3o000000;o000000?ocJh0o`00
0?o=[P000_l000000omMZP3o0000o`000002o`000004oejZ0?l0003o0000o`0000gooooo00?o0000
ooooooooool01_ooool000Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool03?ooool00ol0003ofXT0o`000005o`000005onQK0?l0
003o0000onUI0?l000000_oYF@001_l0003ojEP0onUH0?l0003ojEP0o`0000;ojEP01Ol000000ooc
=@3o0000oo8e0002oo8e0003o`000?ob=@3o000000;o000000?ombD0o`000?og9@000_og9@000ol0
003ombD0o`000002o`0000;on1l000?o0000ooPO0?l000000_l00002ooPN0003o`000?oh7P3on1h0
00;o00000_oh7P06o`0000;on1h00_l00002ooPN0003o`000?oh7P3on1h000?o000000Con1h0o`00
0?oh7`3on1l00ol00002ooPO0003o`000?oh7`3on1l000;o00000_oh7`000ol0003on1l0ooPO0003
o`000003ooPO0?l0003o000000Co00000_oh7`03o`000004ooPO0?l0003on1h0ooPN00?o00000_oh
7P000ol0003on1h0o`000002o`0000;on1h000?o0000ooPN0?oh7P000ol000001?oh7@3o0000ooTM
0?oi7@03o`0000;onAd000?o0000ooTL0?l000000_l00002ooTL0003o`000?oi703onA`000?o0000
00ConA/0o`000?oi6`3onA/00ol00002ooTJ00Ko000000KonAT0o`000?l0003o0000ooXI0?l00002
ooXH00?o00000_oj6@000ol0003onA`0ooTL0002o`000006ooLU0?l0003ombD0o`000?oa?03o0000
0_oa?002o`000003onAZ0?l0003o000000;oi6X00_l000001?o=[P3o0000o`000?l00002olf^00?o
000000?oGZX0o`000?l000000_l000001?mNZP3o0000o`000?l0000<ooooo`03o`000?oooooooooo
00Kooooo0004ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2o`00
00gooooo00Ko0000omZ90?l0003ohfd0o`000?oWH004o`0000;ojET000Co0000onUI0?oYF@3o0000
0_oYF0000ol0003ojEP0o`000002o`000004oo<d0?l0003olc@0o`0000?olcD000?o0000oo8e0?l0
00000_l000000oog903o0000ooLU0002ooLU0003o`000?og9@3o000000;o00000_oh7`000ol0003o
n1l0ooPO0002o`0000;on1d000?o0000ooPN0?oh7P000ol000001?oh7@3o0000o`000?l00002ooPN
0003o`000?oh7P3on1h000?o000000Con1h0o`000?oh7P3on1h00ol00002ooPN0003o`000?oh7P3o
000000;o00000_oh7`000ol0003on1l0ooPO0003o`000004ooPO0?l0003on1l0ooPO00?o00000_oh
7`02o`0000;on1l000?o0000ooPO0?oh7`000ol000001?oh7`3o0000ooPO0?oh7`03o`0000;on1h0
00?o0000ooPN0?oh7P000_l00002ooPN0003o`000?oh7P3on1h000?o000000Con1h0o`000?oh7@3o
n1d00ol00002ooTM0003o`000?oi7@3onAd000;o00000_oi7006o`000003ooTL0?l0003o000000Co
00000_oi6`03o`000004ooTJ0?l0003onAX0ooTJ00?o000000ConAT0o`000?oj6@3onQT00ol00002
ooXH0003o`000?oj6@3onQT000?o000000?onA`0o`000?l000000_og9@02o`0000?olC`000So0000
oo4l0?l0003oi6X0o`000?oTJP3o0000onAZ00;o000000KocJh0o`000?l0003ocJh0o`000?o=[P03
o`000005oejZ0?l0003o0000o`000?mNZP000ol0000<ooooo`03o`000?oooooooooo00Kooooo0004
ooooo`04o`000?ooooooooooo`0000Wooooo0_l00005ooooo`03o`000?oooooooooo00gooooo1Ol0
00001?oWH03o0000onQK0?l00003onUI0004o`000?oYF@3o0000onUH00?o000000Golc@0o`000?oc
=03olc@0o`000002oo<d0003o`000?oc=@3olcD000;o000000?omb@0o`000?og90000_og90000ol0
003ombD0ooLU0002o`0000;on1h000?o0000ooPO0?oh7`000ol000001?oi7@3o0000ooPM0?oh7@03
o`0000;onAd00_l00002ooPM0003o`000?oh7P3on1h000?o00000_oh7P000ol0003on1h0o`000002
o`0000;on1h000?o0000ooPN0?oh7P000_l00002ooPO0003o`000?oh7`3on1l000?o000000?on1l0
o`000?l000001?l00002ooPO00?o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO
0?oh7`03o`0000;on1l000?o0000ooPN0?oh7P000ol000001?oh7P3o0000ooPN0?oh7P03o`000004
ooPN0?l0003on1h0ooPN00?o00000_oh7@06o`000006ooTM0?l0003o0000o`000?oi703o00000_oi
7003o`0000;onA`000?o0000ooTK0?oi6`000ol000001?oi6`3o0000ooTJ0?oi6P03o`000004ooTJ
0?l0003onAT0ooTI00?o00000_oj6@000ol0003onQP0ooXH0003o`000008ooXI0?l0003onA`0o`00
0?oi703o0000ooLU0?l00002ooLU0003o`000?oa?03o000000;olC`00_l00002onAZ0005o`000?oT
JP3o0000o`000?o=[P000_l000000oo=[P3o0000olf^0003o`000005oejZ0?l0003o0000o`000?mN
ZP001?l0000;ooooo`03o`000?oooooooooo00Kooooo0004ooooo`04o`000?ooooooooooo`0000_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`Go00000_oWH0001?l0003o
j5/0onQK0?l00002onUI0006o`000?oYF@3o0000o`000?oc<`3o00000ooc=0001Ol0003olc@0oo<d
0?l0003olc@000?o000000Gomb<0o`000?og903omb@0o`000002ooLT00?o000000Con1h0o`000?oh
7P3on1h00ol00002ooTM00Go00000_oi7@03o`0000;onAd000?o0000ooPM0?l000000_l00002ooPN
0003o`000?oh7P3on1h000;o00000_oh7P000ol0003on1h0ooPN0003o`000003ooPN0?l0003o0000
00Co00000_oh7`02o`0000;on1l000?o0000ooPO0?oh7`000ol000001?oh7`3o0000ooPO0?oh7`03
o`0000;on1l000?o0000ooPO0?l000000_l00002ooPO0003o`000?oh7`3on1l000?o000000Con1l0
o`000?oh7P3on1h00ol000000ooh7P3o0000o`000004o`0000;on1h00ol000001?oh7@3o0000ooPM
0?oh7@03o`000004ooTM0?l0003onA`0ooTL00?o00000_oi70000ol0003onA`0ooTL0003o`000004
ooTK0?l0003onA/0ooTK00?o000000ConAX0o`000?oi6P3onAX00ol00002ooTI0003o`000?oj6@3o
nQT000?o000000ConQP0o`000?oj6@3onQT00_l00002ooTL00;o00000oog9@02o`0000;olC`000So
0000oo4l0?l0003oi6X0o`000?oTJP3o0000onAZ00;o000000?ocJh0o`000?o=[P000_l000001Oo=
[P3o0000o`000?l0003oGZX000;o000000?oGZX0o`000?l000000_l0000;ooooo`03o`000?oooooo
oooo00Kooooo0004ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00Wooooo0ol000002?oooooo0000o`000?l0003ohfd0o`000?oW
H03o00000_oXF`000ol0003ojET0o`000002o`000005oo<c0?l0003olc<0oo<c0?l000000_oc=000
0ol0003olc@0o`000002o`0000;omb<000?o0000ooLS0?l000001Ol00002ooPN0003o`000?oh7P3o
000000;o00000_oi7003o`0000;onA`000?o0000ooTL0?l000000_l00002ooTM0003o`000?oi7@3o
nAd000;o00000_oh7@000ol0003on1h0ooPN0003o`000004ooPN0?l0003on1h0ooPN00?o00000_oh
7P02o`0000;on1l000?o0000ooPO0?oh7`000ol000001?oh7`3o0000ooPO0?oh7`03o`0000;on1l0
00?o0000ooPO0?l000000_l00002ooPO0003o`000?oh7`3on1l000;o00000_oh7`000ol0003on1l0
ooPO0003o`000003ooPO0?l0003o000000Co00000_oh7P02o`0000;on1h000?o0000ooPN0?oh7P00
0ol000001?oh7P3o0000ooPM0?oh7@03o`0000;on1d000?o0000ooTM0?l000000_l00002ooTL0003
o`000?oi703onA`000?o000000ConA`0o`000?oi6`3onA/00ol000001?oi6`3o0000ooTJ0?oi6P03
o`0000;onAX000?o0000ooTI0?oi6@000ol000001?oj6@3o0000ooXH0?oj6003o`000004ooXI0?l0
003o0000o`0000;onA`000So0000ooLU0?l0003ombD0o`000?oa?03o0000oo4l00;o000000Koi6X0
o`000?l0003oi6X0o`000?oTJ@03o`000004olf^0?l0003o0000olf^00Co000000CoGZX0o`000?l0
003oGZX01?l0000;ooooo`03o`000?oooooooooo00Gooooo0005ooooo`;o00002Oooool3o`0000Co
oooo0_l00008ooooo`?o00001Oooool4o`0000;oif001?l000001Ooc<`3o0000oo<c0?oc<`3o0000
00;olc<000?o0000oo<d0?oc=0000_l00002ooLS0003o`000?og8`3omb<000;o00000_oi7@000ol0
003onAd0ooTM0006o`000004ooTL0?l0003o0000o`0000;onA`000?o0000ooTL0?oi70000_l00002
ooTL0003o`000?oi7@3onAd000?o000000Con1d0o`000?oh7@3on1d00ol00002ooPN0003o`000?oh
7P3o000000;o00000_oh7P03o`000004ooPN0?l0003on1l0ooPO00?o000000Con1l0o`000?oh7`3o
n1l00ol00002ooPO0003o`000?oh7`3on1l000;o00000_oh7`000ol0003on1l0ooPO0003o`000003
ooPO0?l0003o000000Co000000Con1l0o`000?l0003o00000_oh7`000ol0003on1l0ooPO0003o`00
0004ooPN0?l0003on1h0ooPN00?o000000Con1h0o`000?oh7P3on1h00ol00002ooPM0003o`000?oh
7@3on1d000;o00000_oi7@000ol0003onA`0ooTL0003o`000004ooTL0?l0003onA`0ooTL00?o0000
00ConA/0o`000?oi6`3onA/00ol00002ooTJ00Ko000000?onAT0o`000?l000001?l000001?oj603o
0000o`000?l00002ooXI0003o`000?oi703onA`000;o00000_og9@02o`00000:oo4l0?l0003olC`0
oo4l0?l0003oi6X0o`000?oTJP3o0000onAY00?o000000GocJh0o`000?l0003o0000olf^0003o`00
0004oejZ0?l0003o0000oejZ00Go00002_ooool00ol0003oooooooooo`05ooooo`006?ooool00ol0
003oooooooooo`03ooooo`?o00002Oooool00ol0003okDT0o`000003o`000003oo8e0?l0003olc<0
00;olc<000Go0000oo<c0?oc<`3o0000oo<c0003o`000004ooLR0?l0003omb<0ooLS00?o00000_oi
70000ol0003onAd0o`000002o`0000;onA/000?o0000ooTK0?oi6`000_l00002ooTK0003o`000?oi
703onA`000?o000000ConA`0o`000?oi703onA`00ol00002ooTM0003o`000?oh7@3o000000;o0000
0_oh7@05o`0000;on1h00ol000001?oh7P3o0000ooPN0?oh7P03o`0000;on1l000?o0000ooPO0?l0
00000_l00002ooPO0003o`000?oh7`3on1l000?o000000Con1l0o`000?oh7`3on1l00ol000001?oh
7`3o0000o`000?l00002ooPO0003o`000?oh7`3on1l000;o00000_oh7`000ol0003on1l0ooPO0003
o`000004ooPO0?l0003on1h0ooPN00?o00000_oh7P000ol0003on1h0o`000002o`0000;on1h000?o
0000ooPM0?oh7@000ol000001?oh7@3o0000ooTM0?oi7@03o`000004ooTM0?l0003onA`0ooTL00?o
00000_oi7005o`0000;onA/00ol000001?oi6P3o0000ooTJ0?oi6P03o`000004ooTI0?l0003onQT0
ooXI00?o00000_oj60000ol0003onQT0ooXI0003o`000005ooTL0?l0003o0000o`000?og9@000_l0
0002oo4l0003o`000?oa?03o000000;oi6X00_l000001OoTJ@3o0000o`000?l0003ocJh000?o0000
00GocJh0o`000?l0003o0000oejZ0002o`000003oejZ0?l0003o000000?o00002Oooool00ol0003o
ooooooooo`05ooooo`005oooool2o`0000;ooooo0ol0000<ooooo`?o00000_oa>`001?l0003olSD0
oo8e0?l00002oo<c0003o`000?oc<`3o000000;o00000_og8P000ol0003omb80o`000002o`0000;o
nA`000?o0000ooTL0?oi70000_l00002ooTJ0003o`000?oi6`3onA/000?o000000ConA/0o`000?oi
6`3onA/00ol00002ooTL0003o`000?oi703o000000;o00000_oi7@000ol0003onAd0ooTM0002o`00
00;on1d00ol00002ooPN0003o`000?oh7P3o000000;o00000_oh7P000ol0003on1h0o`000002o`00
00;on1l000?o0000ooPO0?oh7`000_l00002ooPO0003o`000?oh7`3on1l000?o000000?on1l0o`00
0?l000001?l00002ooPO00;o00000_oh7`000ol0003on1l0ooPO0003o`000004ooPO0?l0003on1l0
ooPO00?o000000Con1l0o`000?oh7`3on1l00ol00002ooPN0003o`000?oh7P3on1h000;o00000_oh
7P000ol0003on1h0ooPN0003o`000003ooPN0?l0003o000000Co000000?onAd0o`000?l000001?l0
0002ooTL00?o000000ConA`0o`000?oi6`3onA/00ol000001?oi6`3o0000ooTJ0?oi6P03o`000004
ooTJ0?l0003onAT0ooTI00?o00000_oj6@000ol0003onQP0ooXH0003o`00000<ooXI0?l0003onA`0
o`000?oi703o0000ooLU0?l0003ombD0o`000?oa?03o00000_oa?003o`000007onAY0?l0003oi6T0
o`000?oTJ@3o0000olf^0003o`000005olf^0?l0003o0000o`000?mNZP000ol000001_mNZP3o0000
o`000?l0003oGjX0o`0000Oooooo0_l00007ooooo`005oooool4o`00013ooooo00?o0000one90?l0
00000_oa>`000ol0003olSD0o`000002oo<c00;o00000_oh8@000ol0003omb80ooLR0002o`0000;o
nA/000?o0000ooTL0?oi70000ol00002ooTJ0003o`000?oi6P3o000000;o00000_oi6P000ol0003o
nA/0o`000002o`0000;onA/000?o0000ooTL0?oi70000_l00002ooTL00Ko000000ConAd0o`000?l0
003o00000_oh7@000ol0003on1h0ooPN0002o`0000;on1h000?o0000ooPN0?oh7P000_l00002ooPN
0003o`000?oh7`3on1l000?o000000?on1l0o`000?l000001?l00002ooPO00;o00000_oh7`000ol0
003on1l0ooPO0003o`000004ooPO0?l0003on1l0ooPO00?o000000Con1l0o`000?oh7`3on1l00ol0
0002ooPO0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1h0ooPN0003o`000003ooPN0?l0
003o000000Co000000Con1h0o`000?l0003o00000_oh7P000ol0003on1d0o`000002o`0000;onAd0
00?o0000ooTM0?oi7@000ol000001?oi703o0000ooTL0?oi7003o`000004ooTK0?l0003onA/0ooTK
00?o000000ConAX0o`000?oi6P3onAX00ol00002ooTI0003o`000?oj6@3onQT000?o000000ConQP0
o`000?oj6@3onQT00_l00002ooTL00;o00000_og9@02o`0000;olC`000Go0000oo4l0?oa?03o0000
onAY0002o`0000;oi6T00_l000001Oo=[P3o0000o`000?l0003ocZh000;o000000GoGZX0o`000?l0
003o0000oejZ0003o`000003oenZ0?l0003o000000Kooooo0_l00007ooooo`005oooool2o`0001;o
oooo2_l00002ooPQ0003o`000?oh8@3o000000;o00000_oi6P000ol0003onA/0o`000002o`0000;o
nAT000?o0000ooTJ0?oi6P000_l00002ooTJ0003o`000?oi6P3onAX000?o000000ConA/0o`000?oi
6`3onA/00ol000001?oi703o0000o`000?l00002ooTL0003o`000?oi7@3onAd000;o00000_oi7@00
0ol0003on1d0ooPM0003o`000004ooPN0?l0003on1h0ooPN00?o000000Con1h0o`000?oh7P3on1h0
0ol00002ooPO00;o00000_oh7`000ol0003on1l0ooPO0003o`000004ooPO0?l0003on1l0ooPO00?o
000000Con1l0o`000?oh7`3on1l00ol00002ooPO0003o`000?oh7`3o000000;o00000_oh7`000ol0
003on1l0ooPO0002o`0000;on1l01_l000001_oh7`3o0000o`000?l0003on1h0o`0000;on1h00ol0
0002ooPN0003o`000?oh7P3on1h000;o00000_oh7@000ol0003onAd0ooTM0003o`000004ooTM0?l0
003onA`0ooTL00?o000000ConA`0o`000?oi6`3onA/00ol00002ooTK0003o`000?oi6P3o000000;o
00000_oi6P000ol0003onAT0ooTI0003o`000004ooXI0?l0003onQP0ooXH00?o000000SonQT0o`00
0?l0003o0000ooTL0?l0003ombD0o`0000;ombD000Co0000oo4l0?l0003olC`00ol000001OoTJ@3o
0000onAY0?l0003oi6T000;o000000GocJh0o`000?l0003o0000olj^0006o`000004oejZ0?l0003o
0000oenZ00;o00001_ooool2o`0000Oooooo000Iooooo`03o`000?oooooooooo013ooooo00?o0000
oo8h0?l000000_of:0001?l0003omb<0ooLS0?l00002ooPQ00;o00000_oi6P000ol0003onAX0ooTJ
0002o`0000;onQT000?o0000ooTI0?oi6@000ol000001?oi6@3o0000ooTJ0?oi6P03o`0000;onAX0
1Ol00002ooTK00;o00000_oi70000ol0003onA`0ooTL0003o`000004ooTM0?l0003onAd0ooTM00?o
00000_oh7@000ol0003on1h0o`000002o`0000;on1h01Ol00002ooPN00?o000000Con1l0o`000?oh
7`3on1l00ol000001?oh7`3o0000ooPO0?oh7`03o`0000;on1l000?o0000ooPO0?l000000_l00002
ooPO0003o`000?oh7`3on1l000;o00000_oh7`06o`000006ooPO0?l0003o0000o`000?oh7`3o0000
0_oh7`03o`0000;on1l000?o0000ooPN0?l000000_l00002ooPN0003o`000?oh7P3on1h000?o0000
00Con1h0o`000?oh7@3on1d00ol000001?oi7@3o0000ooTM0?oi7@03o`000004ooTL0?l0003onA`0
ooTL00?o00000_oi6`000ol0003onA/0ooTK0002o`0000;onAX01_l000000ooi6@3o0000o`000004
o`000006ooXH0?l0003o0000o`000?oj6@3o00000_oi7003o`0000;ombD00_l000002_oa?03o0000
oo4l0?oa?03o0000onAY0?l0003oi6T0o`000?oTJ@02o`000007olf^0?l0003o0000o`000?o>[P3o
0000olj^0004o`000004oejZ0?l0003o0000oenZ00?o00001Oooool2o`0000Oooooo000Jooooo`03
o`000?oooooooooo013ooooo0ol00002ooHX0003o`000?og8`3o000000;o000000ConAX0o`000?oi
6P3onAX00ol00002ooXH0003o`000?oj6@3o000000;o00000_oj6@000ol0003onAT0o`000002o`00
00;onAX00ol000001?oi6P3o0000ooTK0?oi6`03o`000004ooTK0?l0003onA`0ooTL00?o00000_oi
70000ol0003onAd0o`000002o`0000;on1d000?o0000ooPM0?oh7@000_l00002ooPN00?o000000Co
n1h0o`000?oh7P3on1h00ol00002ooPN0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1l0
o`000002o`0000;on1l000?o0000ooPO0?oh7`000_l00002ooPO00Ko000000Kon1l0o`000?l0003o
0000ooPO0?l00002ooPO00?o00000_oh7`000ol0003on1l0o`000002o`0000;on1l000?o0000ooPO
0?oh7`000_l00002ooPN0003o`000?oh7P3on1h000?o000000Con1h0o`000?oh7P3on1h00ol00000
1?oh7@3o0000ooTM0?oi7@03o`000003ooTM0?l0003o000000Co00000_oi7006o`000006ooTK0?l0
003o0000o`000?oi6P3o00000_oi6P03o`000004ooTI0?l0003onQT0ooXI00?o000000ConQP0o`00
0?oj6@3onQT00ol00002ooTL00?o000000?ombD0o`000?l000000_oa?0002?l0003olC`0o`000?oT
J@3o0000onAY0?l0003oi6T00_l000001_o=[P3o0000o`000?o>[P3o0000olj^00Go000000CoGjX0
o`000?l0003oGjX00ol00003ooooo`04o`000?l0ICgo0000o`0000Kooooo000Kooooo`03o`000?oo
oooooooo013ooooo00?o0000oo<a0?l000000ol00002ooTK0003o`000?oi6P3o000000;o00000_oj
60000ol0003onQP0ooXH0002o`0000;onQP000?o0000ooXI0?oj6@000ol000001?oi6@3o0000o`00
0?l00002ooTJ0003o`000?oi6P3o000000;o00000_oi6`000ol0003onA/0o`000002o`0000;onA`0
00?o0000ooTL0?oi70000_l00002ooTM00Ko000000Con1d0o`000?l0003o00000_oh7P000ol0003o
n1h0o`000002o`0000;on1h000?o0000ooPN0?oh7P000_l00002ooPO0003o`000?oh7`3on1l000;o
00000_oh7`06o`000004ooPO0?l0003o0000o`0000;on1l000?o0000ooPO0?l000000_l00002ooPO
0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1l0ooPO0002o`0000;on1l000?o0000ooPO
0?oh7`000ol000001?oh7`3o0000ooPN0?oh7P03o`000003ooPN0?l0003o000000Co000000?on1h0
o`000?l000001?l00002ooTM00;o00000_oi7@000ol0003onA`0ooTL0003o`000004ooTL0?l0003o
nA/0ooTK00?o000000ConA/0o`000?oi6P3onAX00ol000001?oi6P3o0000ooTI0?oi6@03o`0000;o
nQT000?o0000ooXH0?l000000_l00002ooXI000<o`000?oi703o0000ooTL0?l0003ombD0o`000?og
9@3o0000oo4l0?l0003olC`00_l000001_oTJ@3o0000o`000?oTJ@3o0000onAY00Co000000?ocZh0
o`000?o>[P001_l000001?mOZP3o0000o`000?mOZ`02o`0000?ooooo00Co0000o`1U?Ol0003o0000
1_ooool001cooooo0_l0000Aooooo`?o000000Con240o`000?oi6`3onA/00_l00002ooXH0003o`00
0?oj603onQP000?o000000?onQP0o`000?l000001?l00002ooXI00;o00000_oi6@000ol0003onAX0
ooTJ0002o`0000;onA/000?o0000ooTK0?oi6`000ol000001?oi703o0000ooTL0?oi7003o`000004
ooTL0?l0003o0000o`0000;onAd000?o0000ooPM0?oh7@000_l00002ooPN0003o`000?oh7P3on1h0
00;o00000_oh7P000ol0003on1h0ooPN0003o`000004ooPO0?l0003on1l0ooPO00?o000000Con1l0
o`000?l0003o00000_oh7`000ol0003on1l0o`000002o`0000;on1l000?o0000ooPO0?oh7`000_l0
0002ooPO0003o`000?oh7`3on1l000;o00000_oh7`000ol0003on1l0ooPO0003o`000004ooPO0?l0
003on1l0ooPO00?o000000?on1l0o`000?l000001?l000001?oh7P3o0000o`000?l00002ooPN0003
o`000?oh7P3on1h000;o00000_oh7P000ol0003on1d0ooPM0003o`000004ooTM0?l0003onAd0ooTM
00?o000000ConA`0o`000?oi703onA`00ol000001?oi6`3o0000ooTK0?oi6`03o`000004ooTJ0?l0
003onAX0ooTJ00?o00000_oi6@000ol0003onQT0ooXI0002o`0000;onQP000?o0000ooXI0?oj6@00
0_l00002ooTL00;o00000_og9@02o`00000:oo4l0?l0003olC`0oo4l0?l0003oi6T0o`000?oTJ@3o
0000onAY00;o000000KocZh0o`000?l0003ocZh0o`000?o>[P05o`000004oenZ0?l0003o0000oen[
00?o00000_ooool01?l0003o06Dmo`000?l00006ooooo`007_ooool00ol0003oooooooooo`0?oooo
o`03o`000?od;`3o000000?o00000_oi6@000ol0003onQP0o`000002o`0000;onQL00_l00002ooXH
0003o`000?oj603onQP000?o000000ConQT0o`000?oi6@3onAT00ol000001?oi6P3o0000ooTK0?oi
6`03o`0000;onA/01Ol00002ooTL00;o00000_oi7@000ol0003onAd0ooTM0003o`000004ooPM0?l0
003on1h0ooPN00?o000000Con1h0o`000?oh7P3on1h00ol000000ooh7P3o0000o`000004o`0000;o
n1l00_l00002ooPO0003o`000?oh7`3on1l000;o00000_oh7`000ol0003on1l0ooPO0003o`000004
ooPO0?l0003on1l0ooPO00?o000000Con1l0o`000?oh7`3on1l00ol000000ooh7`3o0000o`000004
o`000004ooPO0?l0003o0000o`0000;on1l000?o0000ooPO0?oh7`000_l00002ooPN0003o`000?oh
7P3on1h000?o000000Con1h0o`000?oh7P3on1h00ol000001?oh7@3o0000ooTM0?oi7@03o`000004
ooTM0?l0003onA`0ooTL00?o000000ConA`0o`000?oi6`3onA/00ol00002ooTK0003o`000?oi6P3o
000000;o00000_oi6P06o`000003ooXI0?l0003o000000Co000000WonQT0o`000?l0003o0000ooTL
0?l0003ombD0o`000?og9@000_l00002oo4l0008o`000?oa?03o0000onAY0?l0003oi6T0o`000?oT
J@02o`000003olj^0?l0003ocZh000;o000000?ocZh0o`000?l000000_l000001OmOZP3o0000o`00
0?l0003oGj/000Go000000?o06Dmo`000?l000001_ooool001oooooo00?o0000ooooooooool03ooo
ool:o`000004ooXG0?l0003o0000o`0000;onQL000?o0000ooXH0?l000000_l00002ooXH0003o`00
0?oj6@3o000000;o00000_oi6P000ol0003onAX0o`000002o`0000;onA/00ol000001?oi6`3o0000
ooTL0?oi7003o`000004ooTL0?l0003onAd0ooTM00?o00000_oi7@000ol0003on1d0o`000002o`00
00;on1h01Ol00002ooPN00;o00000_oh7P000ol0003on1l0ooPO0003o`000004ooPO0?l0003on1l0
ooPO00?o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO0?oh7`03o`000003ooPO
0?l0003o000000Co00000_oh7`02o`0000;on1l000?o0000ooPO0?oh7`000_l00002ooPO0003o`00
0?oh7`3on1l000?o000000Con1l0o`000?oh7P3on1h00ol000001?oh7P3o0000ooPN0?oh7P03o`00
0004ooPN0?l0003on1d0ooPM00?o000000ConAd0o`000?oi7@3onAd00ol000000ooi703o0000o`00
0004o`0000;onA/01Ol00002ooTJ00?o000000ConAX0o`000?oi6@3onAT00ol000001?oj6@3o0000
ooXH0?oj6003o`000004ooXI0?l0003onA`0ooTL00;o000000KombD0o`000?og9@3o0000oo4l0?l0
0002oo4l0006o`000?oTJ@3o0000onAY0?l0003oi6T01?l000001?o>[P3o0000o`000?o>[P04o`00
0003oenZ0?l0003o000000;o000000?oGj/0o`000?l000000_l000000ol0ICgo0000o`000006oooo
o`008?ooool00ol0003oooooooooo`0@ooooo`?o000000Con1h0o`000?oj603onQP00_l00002ooXG
0003o`000?oj5`3onQL000;o00000_oj60000ol0003onQP0ooXH0003o`000003ooTI0?l0003o0000
00Co000000ConAX0o`000?l0003o00000_oi6`000ol0003onA/0o`000002o`0000;onA`000?o0000
ooTL0?l000000_l00002ooTM0003o`000?oi7@3onAd000;o00000_oh7@03o`000004ooPN0?l0003o
n1h0ooPN00?o000000Con1h0o`000?oh7P3on1h00ol000001?oh7`3o0000ooPO0?oh7`03o`0000;o
n1l000?o0000ooPO0?l000000_l00002ooPO00Go00000_oh7`02o`0000;on1l000?o0000ooPO0?oh
7`000ol000001?oh7`3o0000ooPO0?oh7`03o`000004ooPO0?l0003on1l0ooPO00?o000000Con1l0
o`000?oh7`3on1l00ol000001?oh7P3o0000ooPN0?oh7P03o`000003ooPN0?l0003o000000Co0000
00?on1d0o`000?l000001?l00002ooTM00;o00000_oi70000ol0003onA`0ooTL0003o`000004ooTK
0?l0003onA/0ooTK00?o000000ConAX0o`000?oi6P3onAX00ol000001?oi6@3o0000ooXI0?oj6@03
o`000004ooXH0?l0003onQT0ooXI00?o000000?onA`0o`000?l000000oog9@001_l0003olC`0oo4l
0?l0003olC`0o`0000;oi6T00_l000001OoTJ@3o0000o`000?l0003ocZh000?o000000GocZh0o`00
0?l0003o0000oenZ0004o`000003oen[0?l0003o000000Go00001_ooool0027ooooo0_l0000Aoooo
o`03o`000?od;P3o000000?o000000ConQP0o`000?oj5`3onQL00ol00002ooXG0003o`000?oj603o
000000;o00000_oj6002o`0000;onAT000?o0000ooTJ0?oi6P000_l00002ooTJ0003o`000?oi6`3o
nA/000;o00000_oi6`000ol0003onA`0ooTL0003o`000003ooTL0?l0003o000000Co000000ConAd0
o`000?l0003o00000_oh7@000ol0003on1h0o`000002o`0000;on1h000?o0000ooPN0?l000000_l0
0002ooPN0003o`000?oh7`3o000000;o00000_oh7`05o`0000;on1l00ol000001?oh7`3o0000ooPO
0?oh7`03o`000004ooPO0?l0003on1l0ooPO00?o000000Con1l0o`000?oh7`3on1l00ol000001?oh
7`3o0000ooPO0?oh7`03o`000003ooPO0?l0003o000000Co000000?on1l0o`000?l000001?l00002
ooPN00;o00000_oh7P000ol0003on1h0ooPN0002o`0000;on1d000?o0000ooTM0?oi7@000ol00000
1?oi7@3o0000ooTL0?oi7003o`000004ooTL0?l0003onA/0ooTK00?o000000ConA/0o`000?oi6P3o
nAX00ol000001?oi6P3o0000ooTI0?oi6@03o`000004ooXI0?l0003onQP0ooXH00?o000000ConQT0
o`000?l0003o00000_oi70002?l0003ombD0o`000?og9@3o0000oo4l0?l0003olC`00ol000000ooT
J@3o0000o`000002onAY00;o000000GocZh0o`000?l0003o0000olj]0003o`000003oenZ0?l0003o
000000;o000000?oGj/0o`000?l000000ol000000ooooooo0000ooooo`04ooooo`008oooool00ol0
003oooooooooo`0?ooooo`;o00000_oh7P05o`0000;onQL01Ol00002ooXH00?o000000ConQT0o`00
0?oi6@3onAT00ol000001?oi6P3o0000ooTJ0?oi6P03o`000003ooTK0?l0003o000000Co00000_oi
7002o`0000;onA`000?o0000ooTM0?oi7@000_l00002ooTM0003o`000?oh7@3on1d000;o00000_oh
7P000ol0003on1h0ooPN0002o`0000;on1h01Ol00002ooPO00?o000000Con1l0o`000?oh7`3on1l0
0ol000001?oh7`3o0000ooPO0?oh7`03o`000004ooPO0?l0003on1l0ooPO00?o00000_oh7`000ol0
003on1l0o`000002o`0000;on1l01Ol00002ooPO00;o00000_oh7`000ol0003on1l0ooPO0002o`00
00;on1l000?o0000ooPN0?oh7P000ol000001?oh7P3o0000ooPN0?oh7P03o`000004ooPN0?l0003o
n1d0ooPM00?o000000ConAd0o`000?oi7@3onAd00ol000001?oi703o0000ooTL0?oi7003o`000004
ooTK0?l0003onA/0ooTK00?o000000?onAX0o`000?l000001?l000000ooi6@3o0000o`000004o`00
00;onQP00_l00002ooXI0003o`000?oi703onA`000;o00000_og9@02o`000006oo4l0?l0003olC`0
oo4l0?l0003oi6T00_l00002onAY00;o000000GocZh0o`000?l0003o0000olj]0004o`000003oen[
0?l0003o000000;o000000?oGjX0o`000?l000000_l000000ooooooo0000ooooo`04ooooo`009?oo
ool00ol0003oooooooooo`0@ooooo`;o00000_oh7P000ol0003onQT0o`000002o`0000;onQL000?o
0000ooXG0?l000000_l00002ooXH0003o`000?oj6@3o000000;o00000_oi6@000ol0003onAX0o`00
0002o`0000;onAX00_l00002ooTK0003o`000?oi6`3onA/000?o000000ConA`0o`000?oi703onA`0
0ol000001?oi7@3o0000ooTM0?oi7@03o`000003ooPM0?l0003o000000Co000000Con1h0o`000?l0
003o00000_oh7P000ol0003on1l0o`000002o`0000;on1l000?o0000ooPO0?l000000_l00002ooPO
0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1l0o`000002o`0000;on1l01Ol00002ooPO
00?o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO0?oh7`03o`000004ooPO0?l0
003on1l0ooPO00?o000000Con1h0o`000?oh7P3on1h00ol000001?oh7P3o0000ooPN0?oh7P03o`00
0004ooPM0?l0003onAd0ooTM00?o000000?onAd0o`000?l000001?l000000ooi703o0000o`000004
o`000004ooTK0?l0003o0000o`0000;onAX000?o0000ooTJ0?oi6P000_l00002ooTI0003o`000?oj
6@3onQT000?o000000ConQP0o`000?oj6@3onQT00ol000001Ooi703o0000o`000?l0003ombD000;o
00000_oa?0002?l0003olC`0o`000?oTJ@3o0000onAY0?l0003oi6T00_l000001Oo>[P3o0000o`00
0?l0003ocZd000?o000000?oGj/0o`000?l000000_l000001?mOZP3o0000o`000?l00002ooooo`03
o`000?oooooooooo00?ooooo000Uooooo`03o`000?oooooooooo013ooooo1Ol00002ooXI0003o`00
0?oj5`3onQL000;o00000_oj5`000ol0003onQP0ooXH0003o`000003ooXI0?l0003o000000Co0000
00ConAX0o`000?l0003o00000_oi6P000ol0003onA/0o`000002o`0000;onA`000?o0000ooTL0?l0
00000_l00002ooTL0003o`000?oi7@3o000000;o00000_oh7@02o`0000;on1h000?o0000ooPN0?oh
7P000_l00002ooPN0003o`000?oh7P3on1h000;o00000_oh7`000ol0003on1l0ooPO0002o`0000;o
n1l000?o0000ooPO0?oh7`000_l00002ooPO00Go00000_oh7`03o`000004ooPO0?l0003on1l0ooPO
00?o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO0?oh7`03o`000004ooPO0?l0
003on1l0ooPO00?o000000Con1l0o`000?oh7P3on1h00ol000000ooh7P3o0000o`000004o`000003
ooPN0?l0003o000000Co000000ConAd0o`000?l0003o00000_oi7@000ol0003onA`0o`000002o`00
00;onA`000?o0000ooTK0?oi6`000_l00002ooTK0003o`000?oi6P3onAX000?o000000ConAX0o`00
0?oi6@3onAT00ol000001?oj6@3o0000ooXH0?oj6003o`00000=ooXI0?l0003onA`0o`000?oi703o
0000ooLU0?l0003ombD0o`000?oa?03o0000oo4l0003o`000005onAY0?l0003oi6T0o`000?oTJ@00
0_l000001Oo>[P3o0000o`000?l0003ocZd000?o000000?oGj/0o`000?l000000_l000000omLZ@3o
0000o`000002ooooo`03o`000?oooooooooo00?ooooo000Vooooo`03o`000?oooooooooo013ooooo
0_l00002ooPN0003o`000?oj6@3o000000;o00000_oj5`000ol0003onQL0o`000002o`0000;onQP0
0_l00002ooXI0003o`000?oi6@3onAT000;o00000_oi6P000ol0003onAX0ooTJ0002o`0000;onA/0
00?o0000ooTL0?oi70000_l00002ooTL00Go00000_oi7@03o`000004ooPM0?l0003on1h0ooPN00?o
000000Con1h0o`000?oh7P3on1h00ol000001?oh7P3o0000ooPO0?oh7`03o`000003ooPO0?l0003o
000000Co000000Con1l0o`000?l0003o00000_oh7`000ol0003on1l0o`000002o`0000;on1l000?o
0000ooPO0?l000000_l00002ooPO0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1l0o`00
0002o`0000;on1l01Ol00002ooPO00Go00000_oh7P02o`0000;on1h000?o0000ooPN0?oh7P000_l0
0002ooPN0003o`000?oh7@3on1d000;o00000_oi7@000ol0003onAd0ooTM0002o`0000;onA`000?o
0000ooTL0?oi70000ol000001?oi6`3o0000ooTK0?oi6`03o`000004ooTJ0?l0003onAX0ooTJ00?o
000000ConAT0o`000?oj6@3onQT00ol000001?oj603o0000ooXI0?oj6@02o`0000;onA`00_l00002
ooLU00;o000000[olC`0o`000?oa?03olC`0o`000?oTJ@3o0000onAY0?l0003oi6T00_l000001Oo>
[P3o0000o`000?l0003ocZd000Co000000?oGj/0o`000?l000001?l00002ooooo`03o`000?oooooo
oooo00?ooooo000Wooooo`;o00004Oooool5o`0000;onQT01Ol00002ooXH00?o000000ConQP0o`00
0?oj6@3onQT00ol000001?oi6@3o0000ooTJ0?oi6P03o`000003ooTK0?l0003o000000Co000000Co
nA`0o`000?l0003o00000_oi70000ol0003onA`0o`000002o`0000;onAd000?o0000ooPM0?l00000
0_l00002ooPN0003o`000?oh7P3o000000;o00000_oh7P05o`0000;on1l00_l00002ooPO0003o`00
0?oh7`3on1l000;o00000_oh7`000ol0003on1l0ooPO0002o`0000;on1l000?o0000ooPO0?oh7`00
0_l00002ooPO0003o`000?oh7`3on1l000;o00000_oh7`05o`0000;on1l00ol000001?oh7`3o0000
ooPO0?oh7`03o`000004ooPO0?l0003on1l0ooPO00?o000000Con1h0o`000?oh7P3on1h00ol00000
1?oh7P3o0000ooPN0?oh7P03o`000004ooPM0?l0003onAd0ooTM00?o000000ConAd0o`000?oi703o
nA`00ol000000ooi703o0000o`000004o`000003ooTK0?l0003o000000Co000000?onAX0o`000?l0
00001?l000000ooj6@3o0000o`000004o`000009ooXI0?l0003o0000o`000?oi6`3o0000ooLU0?l0
003ombD000;o00000_oa?0002?l0003olC`0o`000?oTJ@3o0000onAY0?l0003oi6T00_l000001Oo>
[@3o0000o`000?l0003ocZd000?o000000?oGj/0o`000?l000001?l00002ooooo`03o`000?oooooo
oooo00?ooooo000Yooooo`03o`000?oooooooooo00oooooo1_l00002ooXI0003o`000?oj603o0000
00;o00000_oj60000ol0003onQP0o`000002o`0000;onQT000?o0000ooTI0?l000000_l00002ooTJ
00;o00000_oi6`000ol0003onA/0ooTK0002o`0000;onA`000?o0000ooTL0?oi70000_l00002ooTM
0003o`000?oi7@3onAd000;o00000_oh7@05o`0000;on1h00ol000001?oh7P3o0000ooPN0?oh7P03
o`000004ooPO0?l0003on1l0ooPO00?o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000
ooPO0?oh7`03o`000003ooPO0?l0003o000000Co000000Kon1l0o`000?l0003o0000ooPO0?l00002
ooPO00?o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO0?oh7`03o`000004ooPO
0?l0003on1h0ooPN00?o000000Con1h0o`000?oh7P3on1h00ol000000ooh7P3o0000o`000004o`00
0003ooTM0?l0003o000000Co000000KonA`0o`000?l0003o0000ooTL0?l00002ooTK00?o000000Co
nA/0o`000?oi6P3onAX00ol000001?oi6P3o0000ooTI0?oi6@03o`000004ooXI0?l0003onQP0ooXH
00?o000000ConQT0o`000?oi6`3onA/00_l000001oog9@3o0000ooLU0?l0003olC`0o`000?oa?000
0_l000001_oTJ@3o0000o`000?oTJ@3o0000onAY00;o000000GocZd0o`000?l0003o0000olj]0003
o`000003oen[0?l0003o000000?o00000_ooool00ol0003oooooooooo`03ooooo`00:_ooool00ol0
003oooooooooo`0?ooooo`?o000000Con1l0o`000?oj6@3onQT00ol000001?oj603o0000ooXH0?oj
6003o`000003ooXH0?l0003o000000?o00000_oi6P03o`000004ooTJ0?l0003onA/0ooTK00?o0000
00ConA/0o`000?oi703onA`00ol000000ooi703o0000o`000004o`000004ooTM0?l0003o0000o`00
00;on1d000?o0000ooPN0?l000000_l00002ooPN0003o`000?oh7P3o000000;o000000Con1h0o`00
0?oh7`3on1l00ol000001?oh7`3o0000ooPO0?oh7`03o`000003ooPO0?l0003o000000Co000000Co
n1l0o`000?l0003o00000_oh7`000ol0003on1l0o`000002o`0000;on1l000?o0000ooPO0?l00000
0_l000001?oh7`3o0000ooPO0?oh7`03o`000004ooPO0?l0003on1l0ooPO00?o000000?on1l0o`00
0?l000001?l000000ooh7P3o0000o`000004o`000006ooPN0?l0003o0000o`000?oh7P3o00000_oh
7@03o`000004ooTM0?l0003onAd0ooTM00?o000000ConA`0o`000?oi703onA`00ol000001?oi6`3o
0000ooTK0?oi6`03o`000004ooTJ0?l0003onAX0ooTJ00?o000000ConAT0o`000?oj6@3onQT00ol0
00001?oj603o0000ooXI0?oj6@03o`000003ooTK0?l0003o000000?ombD000?o0000oo4l0?l00000
0_oa?0001_l0003oi6T0o`000?oTJ@3o0000onAY00;o000000GocZd0o`000?l0003o0000olj]0004
o`000004oenZ0?l0003o0000o`0000Cooooo00?o0000ooooooooool00_ooool002_ooooo00?o0000
ooooooooool03oooool00ol0003om2l0o`000003o`0000;onAT01Ol00002ooXH00;o00000_oj6000
0ol0003onQT0o`000002o`0000;onAX000?o0000ooTJ0?l000000_l00002ooTK0003o`000?oi6`3o
000000;o00000_oi7002o`0000;onA`000?o0000ooTM0?oi7@000_l00002ooTM0003o`000?oh7@3o
n1d000;o00000_oh7P000ol0003on1h0ooPN0002o`0000;on1h000?o0000ooPN0?l000000_l00002
ooPO00Go00000_oh7`02o`0000;on1l000?o0000ooPO0?oh7`000_l00002ooPO0003o`000?oh7`3o
n1l000;o00000_oh7`000ol0003on1l0ooPO0002o`0000;on1l01Ol00002ooPO00Go00000_oh7`02
o`0000;on1l000?o0000ooPO0?oh7`000_l00002ooPN0003o`000?oh7P3on1h000;o00000_oh7P00
0ol0003on1h0o`000002o`0000;on1d000?o0000ooTM0?l000000_l00002ooTM0003o`000?oi703o
000000;o00000_oi70000ol0003onA/0o`000002o`0000;onA/000?o0000ooTJ0?l000000_l00002
ooTJ00Go000000?onQP0o`000?l000001?l000001?oj6@3o0000o`000?l00002ooTK0005o`000?og
9@3o0000ooLU0?l000000ooa?002o`0000;oi6T00_l000001?oTJ@3o0000o`000?o>[@03o`000003
olj]0?l0003o000000;o000000?oG:T0o`000?l000001?ooool00ol0003oooooooooo`02ooooo`00
;?ooool2o`00013ooooo1ol000001?oi6@3o0000ooXH0?oj6003o`000004ooXH0?l0003onQP0ooXH
00?o000000ConAT0o`000?oi6P3onAX00ol000000ooi6P3o0000o`000003o`0000;onA/00ol00000
1?oi703o0000ooTL0?oi7003o`000004ooTM0?l0003onAd0ooTM00?o000000Con1d0o`000?oh7P3o
n1h00ol000000ooh7P3o0000o`000003o`0000;on1h00ol000001?oh7`3o0000ooPO0?oh7`03o`00
0004ooPO0?l0003on1l0ooPO00?o000000Con1l0o`000?oh7`3on1l00ol000000ooh7`3o0000o`00
0004o`000006ooPO0?l0003o0000o`000?oh7`3o00000_oh7`03o`000004ooPO0?l0003on1l0ooPO
00?o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPN0?oh7P03o`000004ooPN0?l0
003on1h0ooPN00;o00000_oh7P000ol0003on1d0ooPM0002o`0000;onAd01Ol00002ooTL00Go0000
0_oi6`05o`0000;onAX00ol000001?oi6P3o0000ooTI0?oi6@02o`0000;onQP000?o0000ooXH0?oj
60000_l00002ooXH0003o`000?oi6`3onA/000;o000000OombD0o`000?og9@3o0000oo4l0?l0003o
lC`000?o000000Coi6T0o`000?l0003oi6P00_l000001Oo>[@3o0000o`000?l0003ocZd000?o0000
00?oG:T0o`000?l000001?ooool00ol0003oooooooooo`02ooooo`00;_ooool00ol0003ooooooooo
o`0?ooooo`;o00000_oh7`000ol0003onAT0o`000002o`0000;onQP000?o0000ooXH0?l000000_l0
0002ooXH00Go00000_oi6P02o`0000;onAX000?o0000ooTK0?l000000_l00002ooTK0003o`000?oi
703o000000;o00000_oi70000ol0003onAd0o`000002o`0000;onAd01Ol000001?oh7P3o0000o`00
0?l00002ooPN0003o`000?oh7P3o000000;o00000_oh7P000ol0003on1l0o`000002o`0000;on1l0
00?o0000ooPO0?l000000_l000000ooh7`3o0000o`000004o`000004ooPO0?l0003o0000o`0000;o
n1l000?o0000ooPO0?l000000_l000001?oh7`3o0000ooPO0?oh7`03o`000004ooPO0?l0003on1l0
ooPO00?o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO0?oh7`03o`000003ooPN
0?l0003o000000Co000000?on1h0o`000?l000001?l000001_oh7@3o0000o`000?l0003onAd0o`00
00;onAd00ol000001?oi703o0000ooTL0?oi7003o`000004ooTK0?l0003onA/0ooTK00?o000000Co
nAX0o`000?oi6P3onAX00ol000001?oi6@3o0000ooXH0?oj6003o`000004ooXH0?l0003onQP0ooXH
00?o000000?onA/0o`000?l000000_og9@02o`000006oo4l0?l0003olC`0oo4l0?l0003oi6T00_l0
00000ooTJ03o0000o`000004o`000003olj]0?l0003o000000Co00001?ooool00ol0003ooooooooo
o`02ooooo`00;oooool00ol0003oooooooooo`0?ooooo`Ko000000?onAT0o`000?l000001?l00000
1_oj603o0000o`000?l0003onQT0o`0000;onAT00ol000001?oi6P3o0000ooTJ0?oi6P03o`000004
ooTK0?l0003onA/0ooTK00;o00000_oi7005o`0000;onAd00ol000001?oi7@3o0000ooPM0?oh7@02
o`0000;on1h000?o0000ooPN0?oh7P000_l00002ooPN0003o`000?oh7P3on1h000;o00000_oh7`05
o`0000;on1l00_l00002ooPO0003o`000?oh7`3on1l000;o00000_oh7`000ol0003on1l0ooPO0002
o`0000;on1l000?o0000ooPO0?l000000_l00002ooPO0003o`000?oh7`3o000000;o00000_oh7`05
o`000003ooPO0?l0003o000000Co000000Kon1l0o`000?l0003o0000ooPN0?l00002ooPN00?o0000
00Con1h0o`000?oh7P3on1h00ol000001?oh7@3o0000ooTM0?oi7@03o`000004ooTM0?l0003onA`0
ooTL00?o000000ConA`0o`000?oi6`3onA/00ol000001?oi6`3o0000ooTJ0?oi6P03o`000004ooTJ
0?l0003onAT0ooTI00?o000000?onQP0o`000?l000001?l000002Ooj603o0000o`000?l0003onA/0
o`000?og9@3o0000ooLU0002o`0000;olC`000Co0000oo4l0?l0003oi6T00_l000001?oTJ03o0000
o`000?o>[@03o`000003olj]0?l0003o000000?o00001?ooool00ol0003oooooooooo`02ooooo`00
<?ooool00ol0003oooooooooo`0?ooooo`Ko00000_oi6@000ol0003onQP0ooXH0002o`0000;onQP0
00?o0000ooXI0?l000000_l00002ooTI0003o`000?oi6P3o000000;o00000_oi6P05o`000004ooTK
0?l0003o0000o`0000;onA`000?o0000ooTL0?l000000_l00002ooTM0003o`000?oi7@3o000000;o
000000Con1d0o`000?oh7P3on1h00ol000000ooh7P3o0000o`000004o`000006ooPO0?l0003o0000
o`000?oh7`3o00000_oh7`03o`000004ooPO0?l0003on1l0ooPO00?o000000Con1l0o`000?oh7`3o
n1l00ol000000ooh7`3o0000o`000003o`0000;on1l01Ol00002ooPO00?o000000Con1l0o`000?oh
7`3on1l00_l00002ooPO0003o`000?oh7`3on1l000;o00000_oh7`000ol0003on1h0o`000002o`00
00;on1h000?o0000ooPN0?l000000_l000001?oh7P3o0000ooPM0?oh7@03o`000003ooTM0?l0003o
000000Co000000?onA`0o`000?l000001?l000000ooi6`3o0000o`000004o`000003ooTJ0?l0003o
000000Co000000KonQT0o`000?l0003o0000ooXH0?l00002ooXH00?o000000ConQP0o`000?oi6`3o
nA/00_l000001oog9@3o0000ooLU0?l0003olC`0o`000?oa?0000ol000001?oTJ03o0000o`000?oT
J002o`000004olj]0?l0003o0000olj]00Go00001?ooool00ol0003oooooooooo`02ooooo`00<Ooo
ool2o`00017ooooo0_l000001?oh7`3o0000ooTI0?oi6@03o`000004ooXH0?l0003onQP0ooXH00?o
000000?onQT0o`000?l000000ol00002ooTJ00?o000000ConAX0o`000?oi6`3onA/00_l00002ooTK
0003o`000?oi703onA`000;o00000_oi70000ol0003onAd0ooTM0002o`0000;onAd01Ol00002ooPN
00;o00000_oh7P000ol0003on1h0ooPN0002o`0000;on1l000?o0000ooPO0?l000000_l00002ooPO
0003o`000?oh7`3o000000;o000000?on1l0o`000?l000001?l000001_oh7`3o0000o`000?l0003o
n1l0o`0000;on1l00ol000001?oh7`3o0000ooPO0?oh7`03o`000004ooPO0?l0003on1l0ooPO00?o
000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO0?oh7`02o`0000;on1h01Ol00002
ooPN00Go00000_oh7@02o`0000;onAd000?o0000ooTL0?l000000_l00002ooTL0003o`000?oi703o
000000;o000000ConA/0o`000?oi6`3onA/00ol000001?oi6P3o0000ooTJ0?oi6P03o`000004ooXI
0?l0003onQP0ooXH00?o000000ConQP0o`000?oj603onQP00ol000000ooi6`3o0000o`000002ooLU
00;o000000KolC`0o`000?oa>`3olC/0o`000?oTJ002o`000003onAX0?l0003o000000?o000000?o
cZd0o`000?l000000ol00004ooooo`03o`000?oooooooooo00;ooooo000cooooo`03o`000?oooooo
oooo00oooooo1Ol00002ooTI00Go00000_oj6002o`0000;onQT000?o0000ooTI0?l000000_l00002
ooTJ0003o`000?oi6P3o000000;o00000_oi6`000ol0003onA/0o`000002o`000003ooTL0?l0003o
000000Co000000KonAd0o`000?l0003o0000ooPM0?l00002ooPM00?o000000Con1h0o`000?oh7P3o
n1h00ol000001?oh7P3o0000ooPO0?oh7`02o`0000;on1l01Ol00002ooPO00;o00000_oh7`000ol0
003on1l0ooPO0002o`0000;on1l000?o0000ooPO0?l000000_l00002ooPO0003o`000?oh7`3o0000
00;o000000Con1l0o`000?oh7`3on1l00ol000000ooh7`3o0000o`000004o`000003ooPO0?l0003o
000000Co000000Kon1l0o`000?l0003o0000ooPN0?l00002ooPN00?o000000Con1h0o`000?oh7P3o
n1h00ol000001?oh7@3o0000ooTM0?oi7@02o`0000;onA`000?o0000ooTL0?oi70000_l00002ooTL
0003o`000?oi6`3o000000;o000000ConA/0o`000?oi6P3onAX00ol000001?oi6@3o0000ooXI0?oj
6@03o`000003ooXH0?l0003o000000Co000000WonQP0o`000?l0003o0000ooTK0?l0003ombD0o`00
0?og90000_l00002oo4k0004o`000?oa>`3o0000onAX00;o000000?oiFP0o`000?l000000ol00000
1?o>[P3o0000o`000?l00006ooooo`03o`000?oooooooooo007ooooo000dooooo`03o`000?oooooo
oooo00oooooo00?o0000oo@_0?l000000ol000001?oi6P3o0000ooXH0?oj6003o`000004ooXH0?l0
003onQT0ooXI00?o000000ConAT0o`000?oi6P3onAX00_l00002ooTJ00Go00000_oi6`02o`0000;o
nA`000?o0000ooTL0?oi70000_l00002ooTM0003o`000?oh7@3o000000;o00000_oh7@000ol0003o
n1h0o`000002o`000003ooPN0?l0003o000000Co000000Kon1l0o`000?l0003o0000ooPO0?l00002
ooPO00?o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO0?oh7`02o`0000;on1l0
1Ol00002ooPO00Go00000_oh7`02o`0000;on1l000?o0000ooPO0?l000000_l00002ooPO0003o`00
0?oh7`3o000000;o000000Con1l0o`000?oh7P3on1h00ol000001?oh7P3o0000ooPN0?oh7P03o`00
0004ooPN0?l0003on1d0ooPM00?o000000?onAd0o`000?l000001?l000000ooi703o0000o`000003
o`0000;onA/01Ol00002ooTJ00Go000000KonQT0o`000?l0003o0000ooXH0?l00002ooXH00?o0000
00ConQP0o`000?oi6`3onA/00_l000001oog903o0000ooLT0?l0003olC/0o`000?oa>`000ol00000
1?oTJ03o0000o`000?oUJ002o`000004olj]0?l0003o0000olf`00;o00001_ooool00ol0003ooooo
ooooo`01ooooo`00=Oooool00ol0003oooooooooo`0?ooooo`;o00000_oh7`000ol0003onAX0o`00
0002o`0000;onQP000?o0000ooXH0?l000000_l00002ooXI00Go000000ConAX0o`000?l0003o0000
0_oi6P000ol0003onA/0o`000002o`000004ooTK0?l0003onA`0ooTL00?o000000ConA`0o`000?oi
7@3onAd00_l00002ooPM00Go00000_oh7P02o`0000;on1h000?o0000ooPN0?oh7P000_l00002ooPO
0003o`000?oh7`3o000000;o00000_oh7`000ol0003on1l0o`000002o`000003ooPO0?l0003o0000
00Co000000Kon1l0o`000?l0003o0000ooPO0?l00002ooPO00?o000000Con1l0o`000?oh7`3on1l0
0ol000001?oh7`3o0000ooPO0?oh7`02o`0000;on1l000?o0000ooPO0?oh7`000_l00002ooPO00Go
000000?on1h0o`000?l000001?l000000ooh7P3o0000o`000004o`000006ooPM0?l0003o0000o`00
0?oi7@3o00000_oi7003o`000004ooTL0?l0003onA`0ooTL00?o000000ConA/0o`000?oi6`3onA/0
0ol000001?oi6P3o0000ooTI0?oi6@02o`0000;onQT000?o0000ooXH0?l000000_l000001?oj603o
0000ooXH0?oj6003o`000003ooTK0?l0003o000000;omb@00_l000001_oa>`3o0000oo4k0?oa>`3o
0000onAX00;o000000?oiFP0o`000?l000000ol000000oo=/03o0000o`000006ooooo`03o`000?oo
oooooooo007ooooo000fooooo`;o00004Oooool5o`000003ooTJ0?l0003o000000?o00000_oj6003
o`000004ooXI0?l0003onAT0ooTI00;o00000_oi6P000ol0003onAX0ooTJ0002o`0000;onA/000?o
0000ooTK0?l000000_l00002ooTL00Go000000ConAd0o`000?l0003o00000_oh7@000ol0003on1d0
o`000002o`000004ooPN0?l0003on1h0ooPN00?o000000?on1h0o`000?l000000ol00002ooPO00Go
00000_oh7`02o`0000;on1l000?o0000ooPO0?oh7`000_l00002ooPO0003o`000?oh7`3o000000;o
00000_oh7`000ol0003on1l0o`000002o`000003ooPO0?l0003o000000Co000000?on1l0o`000?l0
00001?l000001_oh7`3o0000o`000?l0003on1l0o`0000;on1l00_l00002ooPN0003o`000?oh7P3o
n1h000;o00000_oh7P000ol0003on1d0o`000002o`000004ooPM0?l0003onAd0ooTM00?o000000Co
nA`0o`000?oi703onA`00ol000001?oi6`3o0000ooTK0?oi6`03o`000004ooTJ0?l0003onAX0ooTJ
00?o000000?onAT0o`000?l000000ol00002ooXH00Go000000WonQP0o`000?l0003o0000ooTK0?l0
003omb@0o`000?og90000_l00002oo4k0004o`000?oa>`3o0000onEX00;o000000?oiFP0o`000?l0
00001Ol00006ooooo`03o`000?oooooooooo007ooooo000hooooo`03o`000?oooooooooo00oooooo
1Ol00002ooTJ0003o`000?oj603o000000;o00000_oj60000ol0003onQT0o`000002o`000004ooTI
0?l0003onAX0ooTJ00?o000000?onAX0o`000?l000000ol00002ooTK00?o000000ConA`0o`000?oi
703onA`00_l00002ooTM0003o`000?oh7@3on1d000;o00000_oh7@05o`0000;on1h00_l00002ooPN
0003o`000?oh7`3o000000;o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO0?oh
7`03o`000004ooPO0?l0003on1l0ooPO00;o00000_oh7`05o`0000;on1l00_l00002ooPO0003o`00
0?oh7`3o000000;o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO0?oh7`03o`00
0004ooPO0?l0003on1h0ooPN00?o000000Con1h0o`000?oh7P3on1h00_l00002ooPM00Go000000?o
nAd0o`000?l000001?l000000ooi703o0000o`000004o`000003ooTK0?l0003o000000Co000000Ko
nAX0o`000?l0003o0000ooTI0?l00002ooXI00?o000000ConQP0o`000?oj603onQP00_l00002ooXH
000;o`000?oi6`3o0000o`000?og903o0000ooLT0?l0003olC/0o`000?oa>`000ol000000ooUJ03o
0000o`000002onEX00Co00001oooool00ol0003oooooooooo`01ooooo`00>Oooool00ol0003ooooo
ooooo`0?ooooo`;o000000?on1l0o`000?l000001?l000001?oj603o0000ooXH0?oj6002o`0000;o
nQT01Ol00002ooTJ00;o00000_oi6`000ol0003onA/0o`000002o`0000;onA`000?o0000ooTL0?l0
00000_l000000ooi703o0000o`000004o`000006ooPM0?l0003o0000o`000?oh7@3o00000_oh7P03
o`000004ooPN0?l0003on1h0ooPN00;o00000_oh7`000ol0003on1l0o`000002o`0000;on1l01Ol0
00000ooh7`3o0000o`000004o`000006ooPO0?l0003o0000o`000?oh7`3o00000_oh7`03o`000004
ooPO0?l0003on1l0ooPO00;o00000_oh7`000ol0003on1l0o`000002o`0000;on1l000?o0000ooPO
0?l000000_l000000ooh7`3o0000o`000004o`000003ooPN0?l0003o000000Co000000Kon1h0o`00
0?l0003o0000ooPM0?l00002ooTM00;o00000_oi7@000ol0003onA`0ooTL0002o`0000;onA`000?o
0000ooTK0?l000000_l000001?oi6`3o0000ooTJ0?oi6P03o`000004ooTJ0?l0003onAT0ooTI00?o
000000ConQT0o`000?oj603onQP00ol000001?oj603o0000ooXH0?oj6002o`000003ooTK0?l0003o
000000?omb@000?o0000oo4k0?l000000_oa>`001?l0003oiFP0o`000?l00002onEX00Co00001ooo
ool00ol0003oooooooooo`01ooooo`00>_ooool00ol0003oooooooooo`0?ooooo`?o000000Con1l0
o`000?oi6P3onAX01Ol000001?oj603o0000o`000?l00002ooXI0003o`000?oi6@3o000000;o0000
00ConAX0o`000?oi6`3onA/00ol000000ooi6`3o0000o`000003o`0000;onA`00_l00002ooTL0003
o`000?oi7@3onAd000;o00000_oh7@000ol0003on1d0o`000002o`000004ooPN0?l0003on1h0ooPN
00?o000000?on1h0o`000?l000000ol00002ooPO00?o000000Con1l0o`000?oh7`3on1l00_l00002
ooPO0003o`000?oh7`3on1l000;o00000_oh7`000ol0003on1l0o`000002o`000004ooPO0?l0003o
n1l0ooPO00?o000000?on1l0o`000?l000000ol00002ooPO00Go00000_oh7`02o`0000;on1l000?o
0000ooPO0?l000000_l000001?oh7P3o0000ooPN0?oh7P03o`000004ooPN0?l0003on1d0ooPM00?o
000000ConAd0o`000?oi7@3onAd00ol000001?oi703o0000ooTL0?oi7002o`0000;onA/000?o0000
ooTK0?l000000_l000000ooi6P3o0000o`000004o`000003ooTI0?l0003o000000Co000000?onQP0
o`000?l000001?l000000ooj603o0000o`000002ooTK0005o`000?og903o0000ooLT0?l000000ooa
>`02o`000005onEX0?l0003oiFP0o`000?oTJ@000ol00008ooooo`7o00000Oooool1ooooo`00>ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?od;`3o000000?o000000ConAX0o`000?oj603onQP0
0ol000001?oj603o0000ooXI0?oj6@02o`0000;onAT01Ol00002ooTK00;o00000_oi6`000ol0003o
nA`0o`000002o`000004ooTL0?l0003onA`0ooTL00?o000000ConAd0o`000?oh7@3on1d00_l00002
ooPN00Go00000_oh7P02o`0000;on1h000?o0000ooPO0?l000000_l000001?oh7`3o0000ooPO0?oh
7`03o`000004ooPO0?l0003on1l0ooPO00?o000000?on1l0o`000?l000000ol00002ooPO00Go0000
00Kon1l0o`000?l0003o0000ooPO0?l00002ooPO00?o000000Con1l0o`000?oh7`3on1l00ol00000
1?oh7`3o0000ooPO0?oh7`02o`0000;on1h000?o0000ooPN0?l000000_l000000ooh7P3o0000o`00
0004o`000003ooPM0?l0003o000000Co000000?onAd0o`000?l000001?l000000ooi703o0000o`00
0003o`0000;onA/00_l00002ooTJ0003o`000?oi6P3o000000;o000000ConAT0o`000?oj6@3onQT0
0ol000001?oj603o0000ooXG0?oj5`03o`000004ooXH0?l0003onA/0ooTK00;o000000Oomb@0o`00
0?og903o0000oo4k0?l0003olC/000;o000000GoiFP0o`000?oTJ@3o0000on=/0002o`0000Sooooo
0Ol00001ooooo`7ooooo000looooo`;o00004?ooool2o`0000;on1l01Ol00002ooXH00Go000000Ko
nQT0o`000?l0003o0000ooTI0?l00002ooTJ00?o000000ConA/0o`000?oi6`3onA/00_l00002ooTL
00Go00000_oi7005o`000006ooPM0?l0003o0000o`000?oh7P3o00000_oh7P03o`000004ooPN0?l0
003on1h0ooPN00;o00000_oh7`05o`0000;on1l01Ol000001_oh7`3o0000o`000?l0003on1l0o`00
00;on1l00ol000001?oh7`3o0000ooPO0?oh7`02o`0000;on1l000?o0000ooPO0?l000000_l00002
ooPO00Go000000?on1l0o`000?l000001?l000000ooh7`3o0000o`000003o`0000;on1h00_l00002
ooPN0003o`000?oh7P3o000000;o000000Con1d0o`000?oi7@3onAd00ol000001?oi7@3o0000ooTL
0?oi7003o`000004ooTL0?l0003onA/0ooTK00?o000000ConA/0o`000?oi6P3onAX00_l000001?oi
6P3o0000ooTI0?oi6@03o`000004ooXH0?l0003onQP0ooXH00?o000000ConQL0o`000?oj603onQP0
0ol000000ooi6`3o0000o`000002ooLT00;o000000GolC/0o`000?oa>`3o0000onEX0002o`000004
on=/0?l0003o0000o`0000Sooooo0Ol00001ooooo`7ooooo000nooooo`03o`000?oooooooooo00ko
oooo0ol00002ooPO0003o`000?oi6P3o000000;o000000ConQP0o`000?oj603onQP00_l00002ooXI
0003o`000?oi6@3o000000;o00000_oi6P05o`000006ooTK0?l0003o0000o`000?oi703o00000_oi
7003o`000004ooTL0?l0003onAd0ooTM00;o00000_oh7@000ol0003on1h0o`000002o`0000;on1h0
1Ol000001_oh7P3o0000o`000?l0003on1l0o`0000;on1l00ol000001?oh7`3o0000ooPO0?oh7`02
o`0000;on1l000?o0000ooPO0?l000000_l000001?oh7`3o0000ooPO0?oh7`03o`000003ooPO0?l0
003o000000?o00000_oh7`03o`000004ooPO0?l0003on1l0ooPO00;o00000_oh7`000ol0003on1l0
o`000002o`000004ooPO0?l0003on1h0ooPN00?o000000Con1h0o`000?oh7P3on1h00_l00002ooPN
0003o`000?oh7@3o000000;o000000ConAd0o`000?oi7@3onAd00ol000000ooi703o0000o`000004
o`000003ooTK0?l0003o000000Co000000?onAX0o`000?l000000ol000000ooi6@3o0000o`000004
o`000003ooXH0?l0003o000000Co000000GonQP0o`000?l0003o0000ooTJ0003o`000003ooLT0?l0
003o000000;olC/00_l000000ooTJ@3o0000o`000002o`000003ooooool0003ooooo00Kooooo0Ol0
0001ooooo`7ooooo000oooooo`03o`000?oooooooooo00kooooo00?o0000oo@_0?l000000ol00002
ooTJ0003o`000?oj603o000000;o000000?onQP0o`000?l000001?l000001_oi6@3o0000o`000?l0
003onAX0o`0000;onA/00_l00002ooTK0003o`000?oi703o000000;o00000_oi70000ol0003onA`0
o`000002o`000003ooTM0?l0003o000000?o00000_oh7P03o`000004ooPN0?l0003on1h0ooPN00;o
00000_oh7P000ol0003on1l0o`000002o`000004ooPO0?l0003on1l0ooPO00?o000000?on1l0o`00
0?l000000ol00002ooPO00Go000000Con1l0o`000?l0003o00000_oh7`000ol0003on1l0o`000002
o`000004ooPO0?l0003on1l0ooPO00?o000000Con1l0o`000?oh7`3on1l00_l00002ooPO00Go0000
00?on1h0o`000?l000001?l000000ooh7P3o0000o`000003o`0000;on1d01Ol000001_oi7@3o0000
o`000?l0003onA`0o`0000;onA`00ol000001?oi6`3o0000ooTK0?oi6`03o`000004ooTJ0?l0003o
nAX0ooTJ00;o00000_oj6@000ol0003onQP0o`000002o`000004ooXH0?l0003onQL0ooXG00?o0000
00gonQP0o`000?oi6P3o0000ooTJ0?l0003omb@0o`000?og903o0000oo4k0?l0003olC/000;o0000
00?ohf`0o`000?l000000oooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00@?oo
ool00ol0003oooooooooo`0>ooooo`Wo00000_oj6002o`0000;onQP000?o0000ooXI0?oj6@000_l0
0002ooTI0003o`000?oi6P3o000000;o000000ConA/0o`000?oi6`3onA/00_l00002ooTL00Go0000
0_oi7002o`0000;onAd000?o0000ooPM0?l000000_l000001?oh7P3o0000ooPN0?oh7P03o`000003
ooPN0?l0003o000000?o00000_oh7`05o`000004ooPO0?l0003o0000o`0000;on1l000?o0000ooPO
0?l000000_l000001?oh7`3o0000ooPO0?oh7`02o`0000;on1l000?o0000ooPO0?oh7`000_l00002
ooPO00Go000000?on1l0o`000?l000001?l000001_oh7`3o0000o`000?l0003on1l0o`0000;on1l0
0_l00002ooPN0003o`000?oh7P3o000000;o000000Con1h0o`000?oh7P3on1h00ol000001?oh7@3o
0000ooTM0?oi7@02o`0000;onA`000?o0000ooTL0?l000000_l000001?oi703o0000ooTK0?oi6`03
o`000004ooTK0?l0003onAX0ooTJ00?o000000?onAT0o`000?l000000ol00002ooXH00Go000000?o
nQL0o`000?l000000ol00002ooTJ00;o00000_og9002o`000003oo4k0?l0003olC`000?o00001Ooo
ool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00@Oooool2o`00013ooooo0_l00002
ooPP0003o`000?oi6P3o000000;o00000_oj60000ol0003onQP0o`000002o`000004ooXI0?l0003o
nAT0ooTI00;o00000_oi6P05o`000004ooTK0?l0003o0000o`0000;onA`000?o0000ooTL0?l00000
0_l000001?oi703o0000ooTM0?oi7@02o`0000;on1d01Ol00002ooPN00;o00000_oh7P000ol0003o
n1h0o`000002o`000004ooPO0?l0003on1l0ooPO00;o00000_oh7`000ol0003on1l0ooPO0002o`00
00;on1l01Ol000000ooh7`3o0000o`000004o`000006ooPO0?l0003o0000o`000?oh7`3o00000_oh
7`02o`0000;on1l000?o0000ooPO0?l000000_l000001?oh7`3o0000ooPO0?oh7`03o`000004ooPO
0?l0003on1h0ooPN00;o00000_oh7P05o`000003ooPM0?l0003o000000Co000000?onAd0o`000?l0
00000ol00002ooTL00Go000000?onA/0o`000?l000001?l000001_oi6P3o0000o`000?l0003onAT0
o`0000;onQT00ol000000ooj603o0000ooXH0003o`000004ooXG0?l0003onQL0ooXG00?o000000Go
nAX0o`000?l0003o0000ooLT0002o`000003oo4l0?l0003ol40000;o00001Oooool00ol0003ooooo
ooooo`03ooooo`7o00000Oooool1ooooo`00@oooool00ol0003oooooooooo`0>ooooo`Ko000000?o
nAX0o`000?l000000ol00002ooXH00Go000000KonAX0o`000?l0003o0000ooTJ0?l00002ooTK00?o
000000ConA/0o`000?oi703onA`00_l00002ooTL00Go000000KonAd0o`000?l0003o0000ooPM0?l0
0002ooPM00?o000000Con1h0o`000?oh7P3on1h00_l00002ooPN0003o`000?oh7`3o000000;o0000
00?on1l0o`000?l000001?l000001_oh7`3o0000o`000?l0003on1l0o`0000;on1l00_l00002ooPO
0003o`000?oh7`3o000000;o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO0?oh
7`02o`0000;on1l01Ol000000ooh7`3o0000o`000004o`000006ooPN0?l0003o0000o`000?oh7P3o
00000_oh7P02o`000004ooPM0?l0003on1d0ooPM00?o000000ConAd0o`000?oi703onA`00ol00000
1?oi703o0000ooTK0?oi6`02o`000004ooTK0?l0003onAX0ooTJ00?o000000ConAX0o`000?oi6@3o
nAT00ol000001?oj6@3o0000ooXH0?oj6002o`0000;onQL000?o0000ooXG0?l000000_l000002Ooj
5`3o0000o`000?l0003onAX0o`000?og903o0000ooLU0002o`000003oo100?l0003o000000Oooooo
00?o0000ooooooooool00oooool1o`00007ooooo0014ooooo`03o`000?oooooooooo00kooooo00?o
0000oo@`0?l000000ol00002ooTJ0003o`000?oj603o000000;o000000ConQP0o`000?oj6@3onQT0
0_l00002ooTJ0003o`000?oi6P3o000000;o00000_oi6`05o`000006ooTL0?l0003o0000o`000?oi
703o00000_oi7002o`0000;onAd000?o0000ooPM0?l000000_l000000ooh7@3o0000o`000004o`00
0003ooPN0?l0003o000000?o00000_oh7`02o`0000;on1l000?o0000ooPO0?l000000_l000001?oh
7`3o0000ooPO0?oh7`03o`000004ooPO0?l0003on1l0ooPO00;o00000_oh7`05o`000003ooPO0?l0
003o000000Co000000Kon1l0o`000?l0003o0000ooPO0?l00002ooPO00;o00000_oh7`000ol0003o
n1h0o`000002o`000004ooPN0?l0003on1h0ooPN00?o000000?on1h0o`000?oh7@000ol000000ooi
7@3o0000o`000004o`000003ooTL0?l0003o000000Co000000?onA/0o`000?l000000ol000000ooi
6P3o0000o`000004o`000003ooTI0?l0003o000000Co000000?onQP0o`000?l000000ol000001_oj
5`3o0000o`000?l0003onQP0o`0000;onAX00_l000000oog9@3o0000ooHY0003o`0000Wooooo00?o
0000ooooooooool00_ooool1o`00007ooooo0015ooooo`03o`000?oooooooooo00kooooo0ol00000
0ooh803o0000o`000003o`0000;onQP01Ol000000ooj6@3o0000o`000003o`0000;onAX00ol00000
1?oi6`3o0000ooTK0?oi6`02o`0000;onA`000?o0000ooTL0?l000000_l000000ooi703o0000o`00
0003o`0000;on1d00_l00002ooPM0003o`000?oh7P3on1h000;o00000_oh7P000ol0003on1h0o`00
0002o`000004ooPN0?l0003on1l0ooPO00;o00000_oh7`05o`000003ooPO0?l0003o000000Co0000
00Kon1l0o`000?l0003o0000ooPO0?l00002ooPO00;o00000_oh7`000ol0003on1l0o`000002o`00
0004ooPO0?l0003on1l0ooPO00?o000000?on1l0o`000?l000000ol000000ooh7P3o0000o`000004
o`000003ooPN0?l0003o000000?o00000_oh7@02o`0000;onAd000?o0000ooTM0?l000000_l00000
1?oi703o0000ooTL0?oi7003o`000004ooTK0?l0003onA/0ooTK00;o00000_oi6P000ol0003onAX0
o`000002o`000004ooTI0?l0003onQT0ooXI00?o000000ConQP0o`000?oj5`3onQL00_l00002ooXG
0003o`000?oj603o000000;o000000ConA`0o`000?l0003omRT00_l0000<ooooo`05o`000?oooooo
ooooooooool000000Oooool004Kooooo0_l0000@ooooo`;o00000_oh80000ol0003onAX0o`000002
o`000004ooXH0?l0003onQP0ooXH00;o00000_oj6@000ol0003onAX0o`000002o`0000;onAX000?o
0000ooTK0?l000000_l000000ooi6`3o0000o`000003o`0000;onA`00_l00002ooTL0003o`000?oi
7@3o000000;o000000Con1d0o`000?oh7@3on1d00ol000000ooh7P3o0000o`000003o`0000;on1h0
1Ol000001_oh7`3o0000o`000?l0003on1l0o`0000;on1l00_l00002ooPO0003o`000?oh7`3o0000
00;o000000Con1l0o`000?oh7`3on1l00ol000000ooh7`3o0000o`000003o`0000;on1l01Ol00000
1_oh7`3o0000o`000?l0003on1l0o`0000;on1l00_l00002ooPN0003o`000?oh7P3o000000;o0000
00Con1h0o`000?oh7P3on1h00ol000001?oh7@3o0000ooTM0?oi7@02o`0000;onAd000?o0000ooTL
0?l000000_l000000ooi703o0000o`000004o`000003ooTK0?l0003o000000?o000000?onAX0o`00
0?l000001?l000000ooj6@3o0000o`000004o`000003ooXH0?l0003o000000?o000000GonQT0o`00
0?l0003o0000ooPP0003o`0000gooooo00Go0000ooooooooooooooooo`000001ooooo`00B?ooool0
0ol0003oooooooooo`0>ooooo`Go00000_oi6P000ol0003onQP0o`000002o`000003ooXH0?l0003o
000000Co000000?onAX0o`000?l000000ol00002ooTK00;o00000_oi6`000ol0003onA`0o`000002
o`000004ooTL0?l0003onA`0ooTL00;o00000_oi7@05o`000006ooPM0?l0003o0000o`000?oh7P3o
00000_oh7P03o`000004ooPN0?l0003on1h0ooPN00;o00000_oh7`000ol0003on1l0o`000002o`00
0003ooPO0?l0003o000000?o00000_oh7`05o`000006ooPO0?l0003o0000o`000?oh7`3o00000_oh
7`03o`000004ooPO0?l0003on1l0ooPO00;o000000Con1l0o`000?oh7`3on1l00ol000000ooh7`3o
0000o`000003o`0000;on1h01Ol000000ooh7P3o0000o`000004o`000003ooTM0?l0003o000000?o
000000KonA`0o`000?l0003o0000ooTL0?l00002ooTK00?o000000ConA/0o`000?oi6P3onAX00_l0
0002ooTJ0003o`000?oi6@3o000000;o000000ConQT0o`000?oj603onQP00ol000001?oj6@3o0000
ooXH0?oj6002o`000003ooTM0?l0003o000000;o00004?ooool01?l0003oooooooooool00001oooo
o`00BOooool00ol0003oooooooooo`0>ooooo`03o`000?od<03o000000Ko000000?onQP0o`000?l0
00000_oj60000ol0003onQT0ooXI0002o`0000;onAX000?o0000ooTJ0?l000000_l000000ooi6`3o
0000o`000003o`0000;onA`01Ol000001_oi703o0000o`000?l0003onAd0o`0000;on1d00_l00002
ooPM0003o`000?oh7P3o000000;o000000?on1h0o`000?l000001?l000000ooh7P3o0000o`000003
o`0000;on1l00_l00002ooPO0003o`000?oh7`3o000000;o000000Con1l0o`000?oh7`3on1l00_l0
0002ooPO0003o`000?oh7`3o000000;o000000?on1l0o`000?l000001?l000000ooh7`3o0000o`00
0003o`000006ooPO0?l0003o0000o`000?oh7P3o00000_oh7P03o`000004ooPN0?l0003on1h0ooPN
00;o000000Con1d0o`000?oh7@3on1d00ol000001?oi7@3o0000ooTL0?oi7002o`0000;onA`000?o
0000ooTL0?l000000_l000001?oi6`3o0000ooTK0?oi6`03o`000003ooTJ0?l0003o000000?o0000
00?onAT0o`000?l000001?l000000ooi6@3o0000o`000004o`000004ooTL0?l0003o0000o`0001Co
oooo00?o0000ooooool000000Oooool004[ooooo00?o0000ooooooooool03_ooool3o`000004ooPP
0?l0003onAX0ooTJ00;o00000_oj60000ol0003onQP0o`000002o`000003ooXI0?l0003o000000?o
00000_oi6P02o`0000;onA/000?o0000ooTK0?l000000_l000001?oi703o0000ooTL0?oi7002o`00
00;onA`01Ol000000ooi7@3o0000o`000003o`0000;on1h00_l00002ooPN0003o`000?oh7P3o0000
00;o000000Con1h0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO0?oh7`02o`0000;on1l01Ol0
00000ooh7`3o0000o`000003o`0000;on1l00_l00002ooPO0003o`000?oh7`3o000000;o000000Co
n1l0o`000?oh7`3on1l00_l00002ooPO0003o`000?oh7P3o000000;o000000Con1h0o`000?oh7P3o
n1h00ol000000ooh7P3o0000o`000003o`000003ooPM0?l0003o000000Co000000?onA`0o`000?l0
00000ol00002ooTL00Go000000KonA/0o`000?l0003o0000ooTJ0?l00002ooTJ00;o00000_oi6P00
0ol0003onAX0o`000002o`000003ooTM0?l0003o000000Go00005_ooool00ol0003oooooo`000001
ooooo`00Boooool2o`00013ooooo1Ol000000ooi6P3o0000o`000003o`0000;onQP00_l00002ooXI
0003o`000?oi6P3o000000;o000000ConAX0o`000?oi6`3onA/00_l00002ooTK00Go000000KonA`0
o`000?l0003o0000ooTL0?l00002ooTM00;o00000_oi7@000ol0003on1d0o`000002o`000004ooPN
0?l0003on1h0ooPN00;o00000_oh7P05o`000003ooPO0?l0003o000000Co000000Oon1l0o`000?l0
003o0000ooPO0?l0003on1l000?o000000Con1l0o`000?oh7`3on1l00ol000001?oh7`3o0000ooPO
0?oh7`02o`0000;on1l01Ol000000ooh7`3o0000o`000003o`0000;on1h01Ol000001_oh7P3o0000
o`000?l0003on1h0o`0000;on1d00_l00002ooTM0003o`000?oi7@3o000000;o000000ConA`0o`00
0?oi703onA`00ol000000ooi6`3o0000ooTK0003o`000004ooTK0?l0003onAX0ooTJ00?o000000?o
nA/0o`000?l000000ol000000ooh7P3o0000o`000005o`0001[ooooo0Ol00001ooooo`7o0000001=
ooooo`03o`000?oooooooooo00kooooo1Ol00002ooTJ0003o`000?oj603o000000;o000000ConQP0
o`000?oj6@3onQT00_l00002ooTI00Go000000KonA/0o`000?l0003o0000ooTK0?l00002ooTL00;o
00000_oi70000ol0003onA`0o`000002o`000003ooTM0?l0003o000000?o00000_oh7@05o`000006
ooPN0?l0003o0000o`000?oh7P3o00000_oh7P02o`0000;on1h000?o0000ooPO0?l000000_l00000
0ooh7`3o0000o`000003o`0000;on1l01Ol000000ooh7`3o0000o`000004o`000007ooPO0?l0003o
0000o`000?oh7`3o0000ooPO0003o`000004ooPO0?l0003on1l0ooPO00?o000000?on1h0o`000?oh
7P000ol000001?oh7P3o0000ooPN0?oh7P03o`000003ooPM0?l0003o000000?o000000?onAd0o`00
0?l000001?l000000ooi703o0000o`000003o`0000;onA/01Ol000001Ooi6`3o0000o`000?l0003o
n1l000Ko00008Oooool2o`000000C_ooool00ol0003oooooooooo`0>ooooo`So00000_oj6005o`00
0006ooXI0?l0003o0000o`000?oi6@3o00000_oi6P02o`0000;onA/000?o0000ooTK0?l000000_l0
00000ooi6`3o0000o`000003o`0000;onA`00_l00002ooTM0003o`000?oi7@3o000000;o000000Co
n1d0o`000?oh7P3on1h00_l00002ooPN00Go000000?on1h0o`000?l000000ol00002ooPO00;o0000
0_oh7`000ol0003on1l0o`000002o`000004ooPO0?l0003on1l0ooPO00;o00000_oh7`000ol0003o
n1l0o`000002o`000003ooPO0?l0003o000000?o00000_oh7`05o`000003ooPN0?l0003o000000?o
00000_oh7P05o`000006ooPN0?l0003o0000o`000?oh7@3o00000_oi7@02o`0000;onAd000?o0000
ooTL0?l000000_l000001?oi703o0000ooTL0?oi7003o`000003ooTL0?l0003o000000?o000000?o
n1l0o`000?l000001Ol0000Rooooo`?o0000001?ooooo`03o`000?oooooooooo00kooooo0_l00002
ooPP0003o`000?oi6P3o000000;o000000ConQP0o`000?oj603onQP00_l00002ooXI00Go000000?o
nAX0o`000?l000000ol00002ooTK00;o00000_oi6`000ol0003onA`0o`000002o`000004ooTL0?l0
003onAd0ooTM00;o00000_oi7@05o`000006ooPN0?l0003o0000o`000?oh7P3o00000_oh7P02o`00
00;on1h000?o0000ooPN0?l000000_l000001?oh7`3o0000ooPO0?oh7`02o`0000;on1l01Ol00000
0ooh7`3o0000o`000003o`0000;on1l00_l000001?oh7`3o0000ooPO0?oh7`03o`000004ooPO0?l0
003on1l0ooPO00;o000000Con1h0o`000?oh7P3on1h00ol000001?oh7P3o0000ooPN0?oh7P02o`00
0003ooPM0?l0003o000000Co000000?onAd0o`000?l000000ol000000ooi703o0000o`000004o`00
0005ooTM0?l0003o0000o`000?oh80001_l0000Tooooo`Co00000oooool0053ooooo00?o0000oooo
ooooool03_ooool5o`0000;onAX01Ol000001_oj603o0000o`000?l0003onQT0o`0000;onAT00_l0
0002ooTJ0003o`000?oi6P3o000000;o000000?onA/0o`000?l000000ol00002ooTL00Go000000Ko
nAd0o`000?l0003o0000ooTM0?l00002ooPM00;o00000_oh7P000ol0003on1h0o`000002o`000003
ooPN0?l0003o000000?o00000_oh7P05o`000006ooPO0?l0003o0000o`000?oh7`3o00000_oh7`02
o`000004ooPO0?l0003on1l0ooPO00?o000000?on1l0o`000?oh7`000ol000000ooh7`3o0000o`00
0004o`000003ooPN0?l0003o000000?o000000?on1h0o`000?l000001?l000000ooh7P3o0000o`00
0002ooPM0003o`000?oh7@3o000000;o000000ConAd0o`000?oi7@3onAd00_l00002ooPM0003o`00
0?oi7@3o000000;o000000?on200o`000?l000001?l0000Sooooo`Co00001oooool0057ooooo0_l0
000?ooooo`03o`000?od;`3o000000?o000000ConAX0o`000?oj603onQP00_l00002ooXH0003o`00
0?oj6@3o000000;o000000?onAT0o`000?l000000ol00002ooTJ00;o00000_oi6`000ol0003onA/0
o`000002o`000004ooTL0?l0003onA`0ooTL00;o00000_oi7@05o`000003ooPM0?l0003o000000?o
00000_oh7P02o`000004ooPN0?l0003on1h0ooPN00?o000000?on1h0o`000?oh7`000ol000000ooh
7`3o0000o`000004o`000003ooPO0?l0003o000000?o000000?on1l0o`000?l000000ol00002ooPO
00;o00000_oh7`000ol0003on1l0o`000002o`000004ooPN0?l0003on1h0ooPN00;o00000_oh7P00
0ol0003on1h0o`000002o`000004ooPN0?l0003on1d0ooPM00;o000000?on1d0o`000?l000001?l0
00000ooh7P3o0000o`000003o`000003ooPQ0?l0003o000000;o00009?ooool4o`0000_ooooo001C
ooooo`03o`000?oooooooooo00gooooo2Ol000000ooj603o0000o`000003o`0000;onQT00_l00002
ooTI0003o`000?oi6P3o000000;o000000ConAX0o`000?oi6`3onA/00_l00002ooTK00Go000000Ko
nA`0o`000?l0003o0000ooTM0?l00002ooTM00;o00000_oh7@000ol0003on1d0o`000002o`000003
ooPN0?l0003o000000?o000000?on1h0o`000?l000000ol00002ooPN00;o00000_oh7`000ol0003o
n1l0o`000002o`000004ooPO0?l0003on1l0ooPO00;o00000_oh7`000ol0003on1l0o`000002o`00
0003ooPO0?l0003o000000?o000000?on1h0o`000?l000001?l000000ooh7P3o0000o`000003o`00
0003ooPN0?l0003o000000Co000000?on1h0o`000?l000000_oh7P000ol0003on1h0o`000002o`00
0003ooPQ0?l0003o000000Co00009?ooool3o`0000oooooo001Dooooo`03o`000?oooooooooo00ko
oooo0_l00002ooPP0003o`000?oi6P3o000000;o000000?onQP0o`000?oj60000ol000000ooj6@3o
0000o`000003o`0000;onAX01Ol000001_oi6`3o0000o`000?l0003onA/0o`0000;onA`00_l00002
ooTL0003o`000?oi7@3o000000;o000000?onAd0o`000?l000000ol000001_oh7@3o0000o`000?l0
003on1h0o`0000;on1h00_l00002ooPN0003o`000?oh7P3o000000;o000000Con1h0o`000?oh7`3o
n1l00_l00002ooPO00Go000000?on1l0o`000?l000000ol000001_oh7`3o0000o`000?l0003on1l0
o`0000;on1l00_l00002ooPN0003o`000?oh7P3o000000;o000000Con1h0o`000?oh7P3on1h00_l0
0002ooPN0003o`000?oh7P3o000000;o000000?on1l0o`000?l000000ol000000oog8P3o0000o`00
0005o`0002;ooooo1?l0000Booooo`00EOooool00ol0003oooooooooo`0>ooooo`Go00000_oi6P04
o`0000;onQP00_l00002ooXI0003o`000?oi6@3o000000;o000000ConAX0o`000?oi6P3onAX00_l0
0002ooTK00Go000000?onA`0o`000?l000000ol000001_oi703o0000o`000?l0003onAd0o`0000;o
n1d00_l00002ooPM0003o`000?oh7P3o000000;o000000?on1h0o`000?l000000ol00002ooPN00Go
000000Oon1h0o`000?l0003o0000ooPN0?l0003on1l000?o000000Con1l0o`000?oh7`3on1l00_l0
0002ooPO0003o`000?oh7`3o000000;o000000?on1h0o`000?l000000ol00002ooPN00Go000000?o
n1h0o`000?l000000ol000001Ooh7`3o0000o`000?l0003omb8000Oo00008oooool4o`0001Kooooo
001Fooooo`;o00003oooool6o`000003ooTJ0?l0003onQP000?o000000ConQP0o`000?oj6@3onQT0
0_l00002ooTI00Go000000KonAX0o`000?l0003o0000ooTK0?l00002ooTK00;o00000_oi70001?l0
003onA`0o`000?l00002ooTL00Go000000?onAd0o`000?l000000ol00002ooPN00;o00000_oh7P00
0ol0003on1h0o`000002o`000003ooPN0?l0003on1h000?o000000?on1h0o`000?l000000ol00002
ooPO00Go000000?on1l0o`000?l000000ol00002ooPN00;o000000Con1h0o`000?oh7P3on1h00ol0
00000ooh7P3o0000ooPN0003o`000003ooPO0?l0003o000000?o00000_og8P06o`0002;ooooo1?l0
000Jooooo`00F?ooool00ol0003oooooooooo`0=ooooo`03o`000?od;`3o000000Ko000000?onQP0
o`000?l000000ol000001_oj6@3o0000o`000?l0003onAT0o`0000;onAX00_l00002ooTJ00Go0000
00?onA/0o`000?l000000ol000001_oi703o0000o`000?l0003onA`0o`0000;onAd00_l00002ooTM
0003o`000?oh7@3o000000;o000000?on1d0o`000?l000000ol000000ooh7P3o0000o`000003o`00
00;on1h00_l00002ooPN0003o`000?oh7P3o000000;o000000Con1h0o`000?oh7P3on1h00_l00000
1?oh7P3o0000ooPN0?oh7P03o`000003ooPN0?l0003o000000?o000000?on1l0o`000?l000000ol0
0002ooPO00;o000000?omb<0o`000?l000001Ol0000Sooooo`Co00007_ooool005Wooooo00?o0000
ooooooooool03Oooool3o`000003ooPO0?l0003o000000?o000000ConQP0o`000?oj603onQP00_l0
0002ooXI00Go000000KonAX0o`000?l0003o0000ooTJ0?l00002ooTK00;o000000ConA/0o`000?oi
703onA`00_l00002ooTL00Go000000?onAd0o`000?l000000ol00002ooPM00;o000000Con1d0o`00
0?oh7P3on1h00_l00002ooPN0003o`000?oh7P3o000000;o000000?on1h0o`000?l000000ol00000
0ooh7P3o0000o`000004o`000003ooPN0?l0003o000000?o000000Kon1h0o`000?l0003o0000ooPO
0?l00002ooPO00;o000000?on1l0o`000?l000001?l000000oog8`3o0000o`000004o`0002;ooooo
1?l0000Rooooo`00F_ooool00ol0003oooooooooo`0>ooooo`;o00000_oh7`000ol0003onAX0o`00
0004o`000006ooXH0?l0003o0000o`000?oj6@3o00000_oi6@02o`0000;onAX01Ol000000ooi6`3o
0000o`000003o`000006ooTL0?l0003o0000o`000?oi703o00000_oi7002o`0000;onAd000?o0000
ooTM0?l000000_l000000ooh7@3o0000o`000003o`000003ooPN0?l0003o000000?o00000_oh7P02
o`000004ooPN0?l0003on1h0ooPN00;o00000_oh7P000ol0003on1h0o`000002o`000003ooPN0?l0
003o000000?o000000?on1l0o`000?l000001?l000000ooh803o0000o`000002ooLS00Ko00008ooo
ool4o`0002Kooooo001Kooooo`;o00003oooool5o`0000;onAX01?l00002ooXH00Go000000KonAT0
o`000?l0003o0000ooTJ0?l00002ooTJ00;o000000ConA/0o`000?oi6`3onA/00_l00002ooTK00Go
000000?onA`0o`000?l000000ol000001_oi7@3o0000o`000?l0003onAd0o`0000;on1d00_l00002
ooPN0003o`000?oh7P3o000000;o000000?on1h0o`000?l000000ol000000ooh7P3o0000o`000003
o`0000;on1h00_l000001?oh7`3o0000ooPO0?oh7`02o`0000;on20000?o0000ooPP0?l000000_l0
00000oog8`3o0000o`000004o`0002;ooooo1?l0000Zooooo`00GOooool00ol0003oooooooooo`0=
ooooo`03o`000?od;`3o000000?o000000?onAX0o`000?oj60000ol000001?oj603o0000ooXI0?oj
6@02o`0000;onAT01Ol000000ooi6P3o0000o`000003o`000006ooTK0?l0003o0000o`000?oi6`3o
00000_oi7002o`000004ooTL0?l0003onA`0ooTL00;o00000_oi7@05o`000003ooPM0?l0003o0000
00?o000000Kon1h0o`000?l0003o0000ooPN0?l00002ooPN00;o00000_oh7P000ol0003on1h0o`00
0002o`000003ooPN0?l0003o000000?o000000?on200o`000?l000002?l0000Tooooo`?o0000;_oo
ool005kooooo00?o0000ooooooooool03Oooool9o`000003ooXH0?l0003o000000?o000000KonQP0
o`000?l0003o0000ooXI0?l00002ooTJ00;o000000ConAX0o`000?oi6`3onA/00_l00002ooTK00Go
000000?onA`0o`000?l000000ol000001_oi703o0000o`000?l0003onAd0o`0000;onAd00_l00000
1?oh7@3o0000ooPM0?oh7@02o`0000;on1h01Ol000000ooh7P3o0000o`000003o`000006ooPN0?l0
003o0000o`000?oh7`3o00000_oh7`02o`000003ooLS0?l0003o000000Go00008_ooool4o`00037o
oooo001Oooooo`03o`000?oooooooooo00gooooo0ol000001?oh7`3o0000ooTI0?oi6@02o`000004
ooXH0?l0003onQP0ooXH00;o00000_oj6005o`000003ooTI0?l0003o000000?o000000KonAX0o`00
0?l0003o0000ooTK0?l00002ooTK00;o000000ConA`0o`000?oi703onA`00_l00002ooTL00Go0000
00?onAd0o`000?l000000ol000001_oh7@3o0000o`000?l0003on1h0o`0000;on1h00_l000000ooh
7P3o0000o`000003o`0000;on1l02_l0000Sooooo`Co0000=Oooool0063ooooo0_l0000?ooooo`Go
000000?onAT0o`000?l000000ol000001_oj603o0000o`000?l0003onQP0o`0000;onQT00_l00000
1?oi6@3o0000ooTJ0?oi6P02o`0000;onAX01Ol000000ooi6`3o0000o`000003o`000007ooTL0?l0
003o0000o`000?oi703o0000ooTM0003o`000003ooTM0?l0003o000000?o00000_oh7@05o`000003
ooPN0?l0003o000000;on1l000?o0000ooPO0?l000000_l000000oog8`3o0000o`000004o`0002;o
oooo1?l0000iooooo`00H_ooool00ol0003oooooooooo`0=ooooo`Go000000ConAT0o`000?oj603o
nQP00_l00002ooXH00Go000000?onQT0o`000?l000000ol000001ooi6P3o0000o`000?l0003onAX0
o`000?oi6`000ol000000ooi6`3o0000o`000003o`0000;onA`01?l00002ooTL00;o00000_oi7@00
0ol0003onAd0o`000002o`000003ooPM0?l0003on1h000?o000000?on1l0o`000?l000000ol00000
0oog8`3o0000o`000002o`0002?ooooo1?l0000mooooo`00Hoooool00ol0003oooooooooo`0=oooo
o`03o`000?od;`3o000000Go000000KonQP0o`000?l0003o0000ooXH0?l00002ooXH00;o000000?o
nQT0o`000?l000000ol00002ooTJ00Co00000_oi6`02o`0000;onA/000?o0000ooTK0?l000000_l0
00000ooi703o0000ooTL0003o`000003ooTL0?l0003o000000?o000000?on1d0o`000?l000000ol0
0002ooPO00;o000000?omb80o`000?l000001Ol0000Qooooo`Co0000@Oooool006Cooooo00?o0000
ooooooooool03Oooool8o`0000;onQP01Ol000000ooj603o0000o`000002ooXI0003o`000?oi6@3o
000000;o000000?onAX0o`000?oi6P000ol000000ooi6`3o0000o`000003o`000003ooTK0?l0003o
000000?o00000_oi7002o`000004ooTM0?l0003onAd0ooTM00;o00000_oh7P05o`000003ooLR0?l0
003o000000;o00008_ooool4o`0004Gooooo001Uooooo`03o`000?oooooooooo00gooooo0ol00000
0ooh7`3o0000o`000003o`000004ooXH0?l0003onQP0ooXH00;o000000?onQP0o`000?l000000ol0
0002ooTI00Co00000_oi6P02o`0000;onAX000Co0000ooTK0?l0003o00000_oi6`05o`000003ooTL
0?l0003o000000?o000000Gon1h0o`000?l0003o0000ooLR0006o`00027ooooo1?l00019ooooo`00
I_ooool2o`0000oooooo0_l000001?oh7`3o0000ooTI0?oi6@05o`000003ooXH0?l0003o000000;o
nQP000?o0000ooXH0?l000000_l000000ooj6@3o0000o`000003o`000003ooTJ0?l0003o000000?o
000000KonA/0o`000?l0003o0000ooTK0?l00002ooTL00;o000000?on1d0o`000?l000000ol00000
0oog8P3o0000o`000002o`0002;ooooo1?l0001=ooooo`00J?ooool00ol0003oooooooooo`0=oooo
o`Go000000?onQT0o`000?l000000ol000000ooj5`3o0000o`000003o`0000;onQP00_l000001?oj
6@3o0000ooTI0?oi6@02o`0000;onAX000Co0000ooTJ0?l0003o00000_oi6`05o`000003ooTM0?l0
003o000000;on2401_l0000Qooooo`?o0000DOooool006Wooooo00?o0000ooooooooool03Oooool5
o`0000;onQT000Co0000ooXG0?l0003o00000_oj5`000ol0003onQP0o`000002o`000003ooXH0?l0
003o000000?o000000?onAT0o`000?l000000ol000001Ooi6`3o0000o`000?l0003onA`000Go0000
00?on240o`000?l000000_l0000Rooooo`Co0000E?ooool006[ooooo00?o0000ooooooooool03Ooo
ool00ol0003om2h0o`000005o`000003ooXG0?l0003o000000?o00000_oj6002o`000004ooXH0?l0
003onQT0ooXI00;o000000?onAX0o`000?l000000ol00002ooTL00;o000000?on200o`000?l00000
1?l0000Qooooo`Co0000F?ooool006_ooooo0_l0000>ooooo`So00000_oj5`05o`000003ooXH0?l0
003o000000?o000000?onQT0o`000?l000000_oi6`05o`000003ooPO0?l0003o000000;o00008Ooo
ool4o`0005cooooo001]ooooo`03o`000?oooooooooo00cooooo0ol000000ooh7P3o0000ooXI0003
o`000004ooXG0?l0003onQL0ooXG00;o000000?onQP0o`000?l000000ol000001Ooi6P3o0000o`00
0?l0003on1h000Ko00008?ooool4o`00063ooooo001^ooooo`03o`000?oooooooooo00gooooo1?l0
0002ooXH00Go000000?onQL0o`000?l000000_oj6@04o`0000;on1h00ol0000Qooooo`Co0000I?oo
ool006oooooo00?o0000ooooooooool03Oooool5o`000003ooXI0?l0003o000000?o000000GonQP0
o`000?l0003o0000ooTM0006o`0001oooooo1?l0001Xooooo`00L?ooool2o`0000kooooo1Ol00002
ooTJ00Co00000_oi7003o`00023ooooo1?l0001/ooooo`00L_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooo000000Co000000?on1h0o`000?l000001?l0000Oooooo`?o0000L?ooool007?o
oooo00?o0000ooooooooool02_ooool01?l0003oooooooooooooool5o`00023ooooo1?l0001coooo
o`00M?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0001gooooo`00
MOooool2o`0000Wooooo00?o0000ooooooooool07_ooool4o`0007_ooooo001gooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool06_ooool4o`0007oooooo001hooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05_ooool4o`0008?ooooo001iooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04_ooool4o`0008Oooooo001jooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03_ooool4o`0008_ooooo001kooooo`;o00000oooool00ol0003ooooo
ooooo`0;ooooo`?o0000Soooool007gooooo00Co0000oooooooooooo00002Oooool4o`0009;ooooo
001nooooo`03o`000?oooooo000000Gooooo1?l0002Fooooo`00Ooooool2o`000003ooooool0003o
000000;o0000V_ooool0083ooooo0_l0002Nooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00dOooool3o`0004cooooo003Booooo`03o`000?oooooooooo04_ooooo001Pooooo`03
o`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`?o
00000oooool3o`0000Cooooo0ol00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000So
oooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000?ooooo0ol00002oooo
o`?o000000?oooooo`000?l000001?l00002ooooo`Go00000oooool2o`0000Cooooo00?o0000oooo
ooooool0B_ooool0063ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004oooo
o`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04o`000?ooooooooooo`0000Gooooo
00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0B_ooool0063ooooo00?o0000ooooool000000oooool3o`0000?ooooo00?o0000ooooool0
00000_ooool5o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001;ooooo`00Gooo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000Sooooo0ol00003ooooo`;o00000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0
003oooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000004_ooooo001Oooooo`05o`000?oooooo0000ooooool000000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000;ooooo1?l00002ooooo`Co00002_ooool01?l0003ooooo
ooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000?ooooo1?l000001?oooooo
0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o000004[ooooo001Oooooo`05
o`000?oooooo0000ooooool000006_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo057ooooo001Oooooo`Ko00006?ooool5o`0001Cooooo00?o0000ooooooooool02?ooool5o`00
00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
057ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0832956, 0.053572, \
0.00360937, 0.00360937}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.14862 .19854 -11.9131 -9 ]
[.14862 .19854 .08693 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.53437 .04684 -5.21687 -9 ]
[.53437 .04684 .78313 0 ]
[.76879 .09908 0 -6.15987 ]
[.76879 .09908 12 2.84013 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93374 .35168 0 -5.92116 ]
[.93374 .35168 6 3.07884 ]
[.02305 .2718 -18 -2.74797 ]
[.02305 .2718 0 6.25203 ]
[.01485 .32314 -18 -2.79139 ]
[.01485 .32314 0 6.20861 ]
[.00639 .37622 -18 -2.83643 ]
[.00639 .37622 0 6.16357 ]
[-0.00237 .43112 -12 -2.88319 ]
[-0.00237 .43112 0 6.11681 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15783 .20788 m
.16244 .21256 L
s
[(-5)] .14862 .19854 .98551 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54216 .05739 m
.54606 .06267 L
s
[(5)] .53437 .04684 .73896 1 Mshowa
.125 Mabswid
.19384 .19379 m
.19657 .19662 L
s
.23036 .17949 m
.23305 .18236 L
s
.26739 .16499 m
.27004 .1679 L
s
.30496 .15028 m
.30757 .15322 L
s
.38173 .12022 m
.38425 .12323 L
s
.42095 .10486 m
.42344 .10791 L
s
.46076 .08927 m
.4632 .09236 L
s
.50116 .07345 m
.50355 .07658 L
s
.12233 .22179 m
.12512 .22456 L
s
.08731 .2355 m
.09014 .23824 L
s
.05276 .24903 m
.05563 .25173 L
s
.58379 .0411 m
.58607 .0443 L
s
.62604 .02455 m
.62828 .02779 L
s
.66894 .00775 m
.67112 .01103 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75648 .10363 m
.75033 .1059 L
s
[(-5)] .76879 .09908 -1 .36886 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92123 .35563 m
.91497 .35761 L
s
[(5)] .93374 .35168 -1 .31581 Mshowa
.125 Mabswid
.77494 .13185 m
.77123 .1332 L
s
.7929 .15934 m
.7892 .16066 L
s
.8104 .18611 m
.80669 .18741 L
s
.82746 .21219 m
.82374 .21348 L
s
.86028 .2624 m
.85655 .26365 L
s
.87608 .28657 m
.87234 .28781 L
s
.8915 .31015 m
.88775 .31137 L
s
.90654 .33317 m
.90279 .33437 L
s
.73752 .07462 m
.73383 .076 L
s
.71803 .04481 m
.71435 .04622 L
s
.69799 .01416 m
.69432 .01559 L
s
.93557 .37757 m
.93181 .37874 L
s
.94957 .39899 m
.94581 .40015 L
s
.96326 .41992 m
.95949 .42106 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03527 .26704 m
.04139 .26466 L
s
[(-20)] .02305 .2718 1 -0.38934 Mshowa
.02712 .31848 m
.03326 .31615 L
s
[(-15)] .01485 .32314 1 -0.37969 Mshowa
.01869 .37167 m
.02485 .36939 L
s
[(-10)] .00639 .37622 1 -0.36968 Mshowa
.00997 .42668 m
.01615 .42447 L
s
[(-5)] -0.00237 .43112 1 -0.35929 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(0)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03367 .27719 m
.03734 .27577 L
s
.03205 .28741 m
.03572 .286 L
s
.03042 .2977 m
.03409 .29629 L
s
.02877 .30806 m
.03245 .30665 L
s
.02546 .32898 m
.02914 .32759 L
s
.02378 .33954 m
.02747 .33816 L
s
.0221 .35018 m
.02579 .3488 L
s
.0204 .36089 m
.02409 .35951 L
s
.01697 .38252 m
.02067 .38116 L
s
.01524 .39345 m
.01894 .3921 L
s
.0135 .40445 m
.0172 .40311 L
s
.01174 .41553 m
.01544 .41419 L
s
.00819 .43792 m
.0119 .43659 L
s
.0064 .44923 m
.01011 .44791 L
s
.0046 .46061 m
.00831 .4593 L
s
.00278 .47208 m
.0065 .47078 L
s
.03687 .25695 m
.04054 .25552 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .073 .174 r
.39985 .61111 .40512 .60371 .41286 .61318 .40762 .62028 Metetra
0 .144 .225 r
.40762 .62028 .41286 .61318 .4207 .62198 .4155 .62879 Metetra
0 .231 .272 r
.4155 .62879 .4207 .62198 .42864 .63013 .42347 .63665 Metetra
0 .317 .304 r
.42347 .63665 .42864 .63013 .43666 .63766 .43153 .6439 Metetra
0 .358 .28 r
.43153 .6439 .43666 .63766 .44478 .64459 .43968 .65054 Metetra
0 .397 .244 r
.43968 .65054 .44478 .64459 .45297 .65095 .44791 .65662 Metetra
0 .433 .198 r
.44791 .65662 .45297 .65095 .46125 .65674 .45622 .66215 Metetra
0 .466 .146 r
.45622 .66215 .46125 .65674 .4696 .66201 .4646 .66715 Metetra
0 .497 .089 r
.4646 .66715 .4696 .66201 .47801 .66676 .47306 .67164 Metetra
0 .526 .028 r
.47306 .67164 .47801 .66676 .4865 .67102 .48158 .67566 Metetra
.034 .553 0 r
.48158 .67566 .4865 .67102 .49505 .67482 .49016 .67921 Metetra
.098 .578 0 r
.49016 .67921 .49505 .67482 .50366 .67816 .49881 .68233 Metetra
.161 .6 0 r
.49881 .68233 .50366 .67816 .51233 .68108 .50751 .68502 Metetra
.223 .621 0 r
.50751 .68502 .51233 .68108 .52105 .6836 .51626 .68732 Metetra
.284 .641 0 r
.51626 .68732 .52105 .6836 .52983 .68572 .52507 .68924 Metetra
.342 .658 0 r
.52507 .68924 .52983 .68572 .53865 .68747 .53393 .6908 Metetra
.398 .675 0 r
.53393 .6908 .53865 .68747 .54753 .68887 .54283 .69201 Metetra
.451 .689 0 r
.54283 .69201 .54753 .68887 .55644 .68993 .55178 .69289 Metetra
.5 .703 0 r
.55178 .69289 .55644 .68993 .5654 .69067 .56078 .69347 Metetra
.546 .715 0 r
.56078 .69347 .5654 .69067 .5744 .69109 .56981 .69374 Metetra
.589 .726 0 r
.56981 .69374 .5744 .69109 .58344 .69123 .57888 .69374 Metetra
.628 .736 0 r
.57888 .69374 .58344 .69123 .59252 .69108 .58799 .69346 Metetra
.664 .744 0 r
.58799 .69346 .59252 .69108 .60164 .69066 .59714 .69292 Metetra
.695 .752 0 r
.59714 .69292 .60164 .69066 .61078 .68997 .60632 .69213 Metetra
.723 .758 0 r
.60632 .69213 .61078 .68997 .61996 .68904 .61553 .6911 Metetra
.747 .764 0 r
.61553 .6911 .61996 .68904 .62917 .68786 .62478 .68983 Metetra
.767 .769 0 r
.62478 .68983 .62917 .68786 .63842 .68644 .63405 .68834 Metetra
.773 .761 0 r
.63405 .68834 .63842 .68644 .64768 .68479 .64336 .68663 Metetra
.776 .754 0 r
.64336 .68663 .64768 .68479 .65698 .68291 .65269 .68471 Metetra
.778 .749 0 r
.65269 .68471 .65698 .68291 .6663 .6808 .66205 .68257 Metetra
.779 .746 0 r
.66205 .68257 .6663 .6808 .67565 .67847 .67143 .68022 Metetra
.779 .745 0 r
.67143 .68022 .67565 .67847 .68501 .67592 .68084 .67765 Metetra
.779 .746 0 r
.68084 .67765 .68501 .67592 .6944 .67315 .69027 .67488 Metetra
.778 .749 0 r
.69027 .67488 .6944 .67315 .70381 .67015 .69972 .6719 Metetra
.776 .754 0 r
.69972 .6719 .70381 .67015 .71323 .66692 .70918 .66869 Metetra
.773 .761 0 r
.70918 .66869 .71323 .66692 .72267 .66345 .71867 .66527 Metetra
.767 .769 0 r
.71867 .66527 .72267 .66345 .73213 .65975 .72817 .66162 Metetra
.747 .764 0 r
.72817 .66162 .73213 .65975 .74159 .65581 .73768 .65774 Metetra
.723 .758 0 r
.73768 .65774 .74159 .65581 .75106 .65161 .7472 .65362 Metetra
.695 .752 0 r
.7472 .65362 .75106 .65161 .76054 .64714 .75673 .64924 Metetra
.664 .744 0 r
.75673 .64924 .76054 .64714 .77002 .64241 .76626 .64461 Metetra
.628 .736 0 r
.76626 .64461 .77002 .64241 .7795 .63738 .7758 .6397 Metetra
.589 .726 0 r
.7758 .6397 .7795 .63738 .78898 .63206 .78534 .63451 Metetra
.546 .715 0 r
.78534 .63451 .78898 .63206 .79845 .62643 .79487 .62901 Metetra
.5 .703 0 r
.79487 .62901 .79845 .62643 .80791 .62047 .80439 .6232 Metetra
.451 .689 0 r
.80439 .6232 .80791 .62047 .81736 .61417 .8139 .61706 Metetra
.398 .675 0 r
.8139 .61706 .81736 .61417 .82679 .6075 .8234 .61056 Metetra
.342 .658 0 r
.8234 .61056 .82679 .6075 .83619 .60046 .83287 .6037 Metetra
.284 .641 0 r
.83287 .6037 .83619 .60046 .84557 .59301 .84232 .59645 Metetra
.223 .621 0 r
.84232 .59645 .84557 .59301 .85491 .58515 .85173 .58879 Metetra
.161 .6 0 r
.85173 .58879 .85491 .58515 .86421 .57685 .86111 .5807 Metetra
.098 .578 0 r
.86111 .5807 .86421 .57685 .87346 .56808 .87045 .57216 Metetra
.034 .553 0 r
.87045 .57216 .87346 .56808 .88266 .55883 .87973 .56314 Metetra
0 .526 .028 r
.87973 .56314 .88266 .55883 .8918 .54907 .88896 .55361 Metetra
0 .497 .089 r
.88896 .55361 .8918 .54907 .90088 .53877 .89813 .54357 Metetra
0 .466 .146 r
.89813 .54357 .90088 .53877 .90987 .52792 .90722 .53297 Metetra
0 .433 .198 r
.90722 .53297 .90987 .52792 .91879 .51649 .91623 .5218 Metetra
0 .397 .244 r
.91623 .5218 .91879 .51649 .92761 .50445 .92515 .51003 Metetra
0 .358 .28 r
.92515 .51003 .92761 .50445 .93634 .49177 .93398 .49763 Metetra
0 .317 .304 r
.93398 .49763 .93634 .49177 .94495 .47844 .9427 .48458 Metetra
0 .231 .272 r
.9427 .48458 .94495 .47844 .95344 .46442 .95131 .47085 Metetra
0 .144 .225 r
.95131 .47085 .95344 .46442 .96181 .4497 .95978 .45641 Metetra
0 .073 .174 r
.95978 .45641 .96181 .4497 .97003 .43424 .96812 .44124 Metetra
0 .144 .225 r
.39454 .61784 .39985 .61111 .40762 .62028 .40235 .62671 Metetra
0 .234 .274 r
.40235 .62671 .40762 .62028 .4155 .62879 .41026 .63493 Metetra
0 .32 .303 r
.41026 .63493 .4155 .62879 .42347 .63665 .41826 .64251 Metetra
0 .363 .276 r
.41826 .64251 .42347 .63665 .43153 .6439 .42636 .64947 Metetra
0 .402 .237 r
.42636 .64947 .43153 .6439 .43968 .65054 .43454 .65584 Metetra
0 .44 .188 r
.43454 .65584 .43968 .65054 .44791 .65662 .44281 .66164 Metetra
0 .474 .132 r
.44281 .66164 .44791 .65662 .45622 .66215 .45115 .6669 Metetra
0 .506 .071 r
.45115 .6669 .45622 .66215 .4646 .66715 .45957 .67164 Metetra
0 .536 .005 r
.45957 .67164 .4646 .66715 .47306 .67164 .46805 .67589 Metetra
.062 .564 0 r
.46805 .67589 .47306 .67164 .48158 .67566 .47661 .67966 Metetra
.13 .589 0 r
.47661 .67966 .48158 .67566 .49016 .67921 .48522 .68297 Metetra
.198 .613 0 r
.48522 .68297 .49016 .67921 .49881 .68233 .4939 .68586 Metetra
.264 .635 0 r
.4939 .68586 .49881 .68233 .50751 .68502 .50263 .68834 Metetra
.329 .655 0 r
.50263 .68834 .50751 .68502 .51626 .68732 .51142 .69042 Metetra
.392 .673 0 r
.51142 .69042 .51626 .68732 .52507 .68924 .52026 .69214 Metetra
.452 .69 0 r
.52026 .69214 .52507 .68924 .53393 .6908 .52915 .6935 Metetra
.509 .705 0 r
.52915 .6935 .53393 .6908 .54283 .69201 .53809 .69454 Metetra
.563 .719 0 r
.53809 .69454 .54283 .69201 .55178 .69289 .54707 .69525 Metetra
.613 .732 0 r
.54707 .69525 .55178 .69289 .56078 .69347 .55609 .69566 Metetra
.66 .743 0 r
.55609 .69566 .56078 .69347 .56981 .69374 .56516 .69579 Metetra
.702 .754 0 r
.56516 .69579 .56981 .69374 .57888 .69374 .57426 .69564 Metetra
.741 .763 0 r
.57426 .69564 .57888 .69374 .58799 .69346 .58341 .69523 Metetra
.771 .765 0 r
.58341 .69523 .58799 .69346 .59714 .69292 .59258 .69457 Metetra
.778 .748 0 r
.59258 .69457 .59714 .69292 .60632 .69213 .6018 .69368 Metetra
.784 .733 0 r
.6018 .69368 .60632 .69213 .61553 .6911 .61104 .69255 Metetra
.79 .72 0 r
.61104 .69255 .61553 .6911 .62478 .68983 .62032 .69121 Metetra
.794 .709 0 r
.62032 .69121 .62478 .68983 .63405 .68834 .62963 .68965 Metetra
.798 .699 0 r
.62963 .68965 .63405 .68834 .64336 .68663 .63897 .68788 Metetra
.8 .692 0 r
.63897 .68788 .64336 .68663 .65269 .68471 .64834 .68591 Metetra
.802 .687 0 r
.64834 .68591 .65269 .68471 .66205 .68257 .65773 .68373 Metetra
.804 .684 0 r
.65773 .68373 .66205 .68257 .67143 .68022 .66715 .68136 Metetra
.804 .683 0 r
.66715 .68136 .67143 .68022 .68084 .67765 .6766 .67879 Metetra
.804 .684 0 r
.6766 .67879 .68084 .67765 .69027 .67488 .68607 .67602 Metetra
.802 .687 0 r
.68607 .67602 .69027 .67488 .69972 .6719 .69555 .67304 Metetra
.8 .692 0 r
.69555 .67304 .69972 .6719 .70918 .66869 .70506 .66987 Metetra
.798 .699 0 r
.70506 .66987 .70918 .66869 .71867 .66527 .71459 .66649 Metetra
.794 .709 0 r
.71459 .66649 .71867 .66527 .72817 .66162 .72413 .66289 Metetra
.79 .72 0 r
.72413 .66289 .72817 .66162 .73768 .65774 .73369 .65907 Metetra
.784 .733 0 r
.73369 .65907 .73768 .65774 .7472 .65362 .74326 .65502 Metetra
.778 .748 0 r
.74326 .65502 .7472 .65362 .75673 .64924 .75284 .65073 Metetra
.771 .765 0 r
.75284 .65073 .75673 .64924 .76626 .64461 .76242 .6462 Metetra
.741 .763 0 r
.76242 .6462 .76626 .64461 .7758 .6397 .77201 .6414 Metetra
.702 .754 0 r
.77201 .6414 .7758 .6397 .78534 .63451 .7816 .63633 Metetra
.66 .743 0 r
.7816 .63633 .78534 .63451 .79487 .62901 .79119 .63097 Metetra
.613 .732 0 r
.79119 .63097 .79487 .62901 .80439 .6232 .80078 .6253 Metetra
.563 .719 0 r
.80078 .6253 .80439 .6232 .8139 .61706 .81035 .61931 Metetra
.509 .705 0 r
.81035 .61931 .8139 .61706 .8234 .61056 .81991 .61299 Metetra
.452 .69 0 r
.81991 .61299 .8234 .61056 .83287 .6037 .82945 .6063 Metetra
.392 .673 0 r
.82945 .6063 .83287 .6037 .84232 .59645 .83897 .59924 Metetra
.329 .655 0 r
.83897 .59924 .84232 .59645 .85173 .58879 .84846 .59178 Metetra
.264 .635 0 r
.84846 .59178 .85173 .58879 .86111 .5807 .85791 .5839 Metetra
.198 .613 0 r
.85791 .5839 .86111 .5807 .87045 .57216 .86733 .57557 Metetra
.13 .589 0 r
.86733 .57557 .87045 .57216 .87973 .56314 .87669 .56678 Metetra
.062 .564 0 r
.87669 .56678 .87973 .56314 .88896 .55361 .88601 .55749 Metetra
0 .536 .005 r
.88601 .55749 .88896 .55361 .89813 .54357 .89526 .54769 Metetra
0 .506 .071 r
.89526 .54769 .89813 .54357 .90722 .53297 .90444 .53735 Metetra
0 .474 .132 r
.90444 .53735 .90722 .53297 .91623 .5218 .91355 .52644 Metetra
0 .44 .188 r
.91355 .52644 .91623 .5218 .92515 .51003 .92257 .51493 Metetra
0 .402 .237 r
.92257 .51493 .92515 .51003 .93398 .49763 .9315 .5028 Metetra
0 .363 .276 r
.9315 .5028 .93398 .49763 .9427 .48458 .94033 .49003 Metetra
0 .32 .303 r
.94033 .49003 .9427 .48458 .95131 .47085 .94904 .47657 Metetra
0 .234 .274 r
.94904 .47657 .95131 .47085 .95978 .45641 .95763 .46242 Metetra
0 .144 .225 r
.95763 .46242 .95978 .45641 .96812 .44124 .96608 .44754 Metetra
0 .231 .272 r
.38919 .62392 .39454 .61784 .40235 .62671 .39703 .6325 Metetra
0 .32 .303 r
.39703 .6325 .40235 .62671 .41026 .63493 .40498 .64043 Metetra
0 .364 .275 r
.40498 .64043 .41026 .63493 .41826 .64251 .41302 .64773 Metetra
0 .405 .234 r
.41302 .64773 .41826 .64251 .42636 .64947 .42115 .65441 Metetra
0 .444 .182 r
.42115 .65441 .42636 .64947 .43454 .65584 .42936 .66051 Metetra
0 .479 .123 r
.42936 .66051 .43454 .65584 .44281 .66164 .43766 .66604 Metetra
0 .513 .057 r
.43766 .66604 .44281 .66164 .45115 .6669 .44604 .67104 Metetra
.012 .544 0 r
.44604 .67104 .45115 .6669 .45957 .67164 .45449 .67552 Metetra
.083 .572 0 r
.45449 .67552 .45957 .67164 .46805 .67589 .46301 .67952 Metetra
.156 .599 0 r
.46301 .67952 .46805 .67589 .47661 .67966 .47159 .68305 Metetra
.228 .623 0 r
.47159 .68305 .47661 .67966 .48522 .68297 .48024 .68613 Metetra
.299 .645 0 r
.48024 .68613 .48522 .68297 .4939 .68586 .48895 .68879 Metetra
.369 .666 0 r
.48895 .68879 .4939 .68586 .50263 .68834 .49772 .69105 Metetra
.436 .685 0 r
.49772 .69105 .50263 .68834 .51142 .69042 .50654 .69293 Metetra
.5 .703 0 r
.50654 .69293 .51142 .69042 .52026 .69214 .51541 .69445 Metetra
.561 .719 0 r
.51541 .69445 .52026 .69214 .52915 .6935 .52433 .69562 Metetra
.619 .733 0 r
.52433 .69562 .52915 .6935 .53809 .69454 .53329 .69648 Metetra
.673 .746 0 r
.53329 .69648 .53809 .69454 .54707 .69525 .54231 .69702 Metetra
.723 .758 0 r
.54231 .69702 .54707 .69525 .55609 .69566 .55136 .69728 Metetra
.769 .769 0 r
.55136 .69728 .55609 .69566 .56516 .69579 .56046 .69725 Metetra
.779 .746 0 r
.56046 .69725 .56516 .69579 .57426 .69564 .56959 .69697 Metetra
.788 .725 0 r
.56959 .69697 .57426 .69564 .58341 .69523 .57877 .69643 Metetra
.795 .706 0 r
.57877 .69643 .58341 .69523 .59258 .69457 .58798 .69566 Metetra
.802 .688 0 r
.58798 .69566 .59258 .69457 .6018 .69368 .59722 .69466 Metetra
.808 .673 0 r
.59722 .69466 .6018 .69368 .61104 .69255 .6065 .69344 Metetra
.813 .659 0 r
.6065 .69344 .61104 .69255 .62032 .69121 .61581 .69202 Metetra
.817 .648 0 r
.61581 .69202 .62032 .69121 .62963 .68965 .62515 .69039 Metetra
.82 .639 0 r
.62515 .69039 .62963 .68965 .63897 .68788 .63452 .68856 Metetra
.823 .632 0 r
.63452 .68856 .63897 .68788 .64834 .68591 .64393 .68654 Metetra
.825 .626 0 r
.64393 .68654 .64834 .68591 .65773 .68373 .65335 .68433 Metetra
.826 .623 0 r
.65335 .68433 .65773 .68373 .66715 .68136 .66281 .68194 Metetra
.826 .622 0 r
.66281 .68194 .66715 .68136 .6766 .67879 .67229 .67935 Metetra
.826 .623 0 r
.67229 .67935 .6766 .67879 .68607 .67602 .6818 .67658 Metetra
.825 .626 0 r
.6818 .67658 .68607 .67602 .69555 .67304 .69132 .67363 Metetra
.823 .632 0 r
.69132 .67363 .69555 .67304 .70506 .66987 .70087 .67047 Metetra
.82 .639 0 r
.70087 .67047 .70506 .66987 .71459 .66649 .71044 .66713 Metetra
.817 .648 0 r
.71044 .66713 .71459 .66649 .72413 .66289 .72002 .66358 Metetra
.813 .659 0 r
.72002 .66358 .72413 .66289 .73369 .65907 .72963 .65982 Metetra
.808 .673 0 r
.72963 .65982 .73369 .65907 .74326 .65502 .73924 .65584 Metetra
.802 .688 0 r
.73924 .65584 .74326 .65502 .75284 .65073 .74887 .65164 Metetra
.795 .706 0 r
.74887 .65164 .75284 .65073 .76242 .6462 .7585 .6472 Metetra
.788 .725 0 r
.7585 .6472 .76242 .6462 .77201 .6414 .76814 .64251 Metetra
.779 .746 0 r
.76814 .64251 .77201 .6414 .7816 .63633 .77779 .63756 Metetra
.769 .769 0 r
.77779 .63756 .7816 .63633 .79119 .63097 .78743 .63233 Metetra
.723 .758 0 r
.78743 .63233 .79119 .63097 .80078 .6253 .79707 .6268 Metetra
.673 .746 0 r
.79707 .6268 .80078 .6253 .81035 .61931 .80671 .62097 Metetra
.619 .733 0 r
.80671 .62097 .81035 .61931 .81991 .61299 .81633 .6148 Metetra
.561 .719 0 r
.81633 .6148 .81991 .61299 .82945 .6063 .82594 .60829 Metetra
.5 .703 0 r
.82594 .60829 .82945 .6063 .83897 .59924 .83552 .60142 Metetra
.436 .685 0 r
.83552 .60142 .83897 .59924 .84846 .59178 .84508 .59415 Metetra
.369 .666 0 r
.84508 .59415 .84846 .59178 .85791 .5839 .85461 .58647 Metetra
.299 .645 0 r
.85461 .58647 .85791 .5839 .86733 .57557 .8641 .57836 Metetra
.228 .623 0 r
.8641 .57836 .86733 .57557 .87669 .56678 .87355 .56979 Metetra
.156 .599 0 r
.87355 .56979 .87669 .56678 .88601 .55749 .88295 .56073 Metetra
.083 .572 0 r
.88295 .56073 .88601 .55749 .89526 .54769 .89229 .55117 Metetra
.012 .544 0 r
.89229 .55117 .89526 .54769 .90444 .53735 .90156 .54107 Metetra
0 .513 .057 r
.90156 .54107 .90444 .53735 .91355 .52644 .91076 .53041 Metetra
0 .479 .123 r
.91076 .53041 .91355 .52644 .92257 .51493 .91988 .51917 Metetra
0 .444 .182 r
.91988 .51917 .92257 .51493 .9315 .5028 .9289 .50731 Metetra
0 .405 .234 r
.9289 .50731 .9315 .5028 .94033 .49003 .93783 .4948 Metetra
0 .364 .275 r
.93783 .4948 .94033 .49003 .94904 .47657 .94665 .48162 Metetra
0 .32 .303 r
.94665 .48162 .94904 .47657 .95763 .46242 .95534 .46775 Metetra
0 .231 .272 r
.95534 .46775 .95763 .46242 .96608 .44754 .96391 .45315 Metetra
0 .317 .304 r
.38381 .62937 .38919 .62392 .39703 .6325 .39168 .63767 Metetra
0 .362 .276 r
.39168 .63767 .39703 .6325 .40498 .64043 .39966 .64532 Metetra
0 .405 .234 r
.39966 .64532 .40498 .64043 .41302 .64773 .40773 .65233 Metetra
0 .445 .18 r
.40773 .65233 .41302 .64773 .42115 .65441 .4159 .65874 Metetra
0 .482 .118 r
.4159 .65874 .42115 .65441 .42936 .66051 .42415 .66457 Metetra
0 .516 .049 r
.42415 .66457 .42936 .66051 .43766 .66604 .43248 .66984 Metetra
.024 .548 0 r
.43248 .66984 .43766 .66604 .44604 .67104 .44089 .67458 Metetra
.099 .578 0 r
.44089 .67458 .44604 .67104 .45449 .67552 .44937 .67881 Metetra
.176 .605 0 r
.44937 .67881 .45449 .67552 .46301 .67952 .45792 .68256 Metetra
.252 .631 0 r
.45792 .68256 .46301 .67952 .47159 .68305 .46654 .68585 Metetra
.327 .654 0 r
.46654 .68585 .47159 .68305 .48024 .68613 .47522 .68871 Metetra
.401 .675 0 r
.47522 .68871 .48024 .68613 .48895 .68879 .48396 .69115 Metetra
.472 .695 0 r
.48396 .69115 .48895 .68879 .49772 .69105 .49275 .69319 Metetra
.541 .713 0 r
.49275 .69319 .49772 .69105 .50654 .69293 .5016 .69487 Metetra
.606 .73 0 r
.5016 .69487 .50654 .69293 .51541 .69445 .51051 .69619 Metetra
.667 .745 0 r
.51051 .69619 .51541 .69445 .52433 .69562 .51946 .69719 Metetra
.725 .759 0 r
.51946 .69719 .52433 .69562 .53329 .69648 .52845 .69786 Metetra
.771 .764 0 r
.52845 .69786 .53329 .69648 .54231 .69702 .5375 .69824 Metetra
.783 .737 0 r
.5375 .69824 .54231 .69702 .55136 .69728 .54658 .69834 Metetra
.793 .712 0 r
.54658 .69834 .55136 .69728 .56046 .69725 .55571 .69817 Metetra
.802 .688 0 r
.55571 .69817 .56046 .69725 .56959 .69697 .56487 .69775 Metetra
.81 .667 0 r
.56487 .69775 .56959 .69697 .57877 .69643 .57407 .69709 Metetra
.817 .647 0 r
.57407 .69709 .57877 .69643 .58798 .69566 .58331 .69621 Metetra
.824 .63 0 r
.58331 .69621 .58798 .69566 .59722 .69466 .59259 .69511 Metetra
.829 .614 0 r
.59259 .69511 .59722 .69466 .6065 .69344 .6019 .6938 Metetra
.834 .601 0 r
.6019 .6938 .6065 .69344 .61581 .69202 .61124 .69229 Metetra
.838 .59 0 r
.61124 .69229 .61581 .69202 .62515 .69039 .62061 .69059 Metetra
.841 .58 0 r
.62061 .69059 .62515 .69039 .63452 .68856 .63002 .68871 Metetra
.843 .573 0 r
.63002 .68871 .63452 .68856 .64393 .68654 .63945 .68664 Metetra
.845 .568 0 r
.63945 .68664 .64393 .68654 .65335 .68433 .64892 .6844 Metetra
.846 .565 0 r
.64892 .6844 .65335 .68433 .66281 .68194 .65841 .68198 Metetra
.846 .564 0 r
.65841 .68198 .66281 .68194 .67229 .67935 .66792 .67939 Metetra
.846 .565 0 r
.66792 .67939 .67229 .67935 .6818 .67658 .67746 .67662 Metetra
.845 .568 0 r
.67746 .67662 .6818 .67658 .69132 .67363 .68703 .67367 Metetra
.843 .573 0 r
.68703 .67367 .69132 .67363 .70087 .67047 .69661 .67054 Metetra
.841 .58 0 r
.69661 .67054 .70087 .67047 .71044 .66713 .70622 .66723 Metetra
.838 .59 0 r
.70622 .66723 .71044 .66713 .72002 .66358 .71585 .66373 Metetra
.834 .601 0 r
.71585 .66373 .72002 .66358 .72963 .65982 .72549 .66003 Metetra
.829 .614 0 r
.72549 .66003 .72963 .65982 .73924 .65584 .73515 .65612 Metetra
.824 .63 0 r
.73515 .65612 .73924 .65584 .74887 .65164 .74482 .652 Metetra
.817 .647 0 r
.74482 .652 .74887 .65164 .7585 .6472 .75451 .64765 Metetra
.81 .667 0 r
.75451 .64765 .7585 .6472 .76814 .64251 .7642 .64306 Metetra
.802 .688 0 r
.7642 .64306 .76814 .64251 .77779 .63756 .77389 .63822 Metetra
.793 .712 0 r
.77389 .63822 .77779 .63756 .78743 .63233 .78359 .63312 Metetra
.783 .737 0 r
.78359 .63312 .78743 .63233 .79707 .6268 .79329 .62773 Metetra
.771 .764 0 r
.79329 .62773 .79707 .6268 .80671 .62097 .80298 .62205 Metetra
.725 .759 0 r
.80298 .62205 .80671 .62097 .81633 .6148 .81267 .61604 Metetra
.667 .745 0 r
.81267 .61604 .81633 .6148 .82594 .60829 .82234 .6097 Metetra
.606 .73 0 r
.82234 .6097 .82594 .60829 .83552 .60142 .83199 .603 Metetra
.541 .713 0 r
.83199 .603 .83552 .60142 .84508 .59415 .84162 .59592 Metetra
.472 .695 0 r
.84162 .59592 .84508 .59415 .85461 .58647 .85122 .58844 Metetra
.401 .675 0 r
.85122 .58844 .85461 .58647 .8641 .57836 .86078 .58054 Metetra
.327 .654 0 r
.86078 .58054 .8641 .57836 .87355 .56979 .87031 .57219 Metetra
.252 .631 0 r
.87031 .57219 .87355 .56979 .88295 .56073 .87978 .56336 Metetra
.176 .605 0 r
.87978 .56336 .88295 .56073 .89229 .55117 .88921 .55403 Metetra
.099 .578 0 r
.88921 .55403 .89229 .55117 .90156 .54107 .89857 .54417 Metetra
.024 .548 0 r
.89857 .54417 .90156 .54107 .91076 .53041 .90785 .53376 Metetra
0 .516 .049 r
.90785 .53376 .91076 .53041 .91988 .51917 .91707 .52277 Metetra
0 .482 .118 r
.91707 .52277 .91988 .51917 .9289 .50731 .92619 .51117 Metetra
0 .445 .18 r
.92619 .51117 .9289 .50731 .93783 .4948 .93521 .49893 Metetra
0 .405 .234 r
.93521 .49893 .93783 .4948 .94665 .48162 .94413 .48602 Metetra
0 .362 .276 r
.94413 .48602 .94665 .48162 .95534 .46775 .95293 .47243 Metetra
0 .317 .304 r
.95293 .47243 .95534 .46775 .96391 .45315 .96161 .45811 Metetra
0 .358 .28 r
.37839 .63421 .38381 .62937 .39168 .63767 .3863 .64223 Metetra
0 .402 .237 r
.3863 .64223 .39168 .63767 .39966 .64532 .39431 .6496 Metetra
0 .444 .182 r
.39431 .6496 .39966 .64532 .40773 .65233 .40242 .65634 Metetra
0 .482 .118 r
.40242 .65634 .40773 .65233 .4159 .65874 .41061 .66248 Metetra
0 .518 .047 r
.41061 .66248 .4159 .65874 .42415 .66457 .41889 .66805 Metetra
.03 .551 0 r
.41889 .66805 .42415 .66457 .43248 .66984 .42726 .67306 Metetra
.109 .582 0 r
.42726 .67306 .43248 .66984 .44089 .67458 .4357 .67755 Metetra
.189 .61 0 r
.4357 .67755 .44089 .67458 .44937 .67881 .44421 .68153 Metetra
.269 .636 0 r
.44421 .68153 .44937 .67881 .45792 .68256 .45279 .68504 Metetra
.349 .66 0 r
.45279 .68504 .45792 .68256 .46654 .68585 .46144 .6881 Metetra
.426 .683 0 r
.46144 .6881 .46654 .68585 .47522 .68871 .47015 .69073 Metetra
.502 .703 0 r
.47015 .69073 .47522 .68871 .48396 .69115 .47892 .69296 Metetra
.574 .722 0 r
.47892 .69296 .48396 .69115 .49275 .69319 .48775 .6948 Metetra
.643 .739 0 r
.48775 .6948 .49275 .69319 .5016 .69487 .49663 .69627 Metetra
.708 .755 0 r
.49663 .69627 .5016 .69487 .51051 .69619 .50556 .6974 Metetra
.769 .769 0 r
.50556 .6974 .51051 .69619 .51946 .69719 .51454 .69821 Metetra
.782 .738 0 r
.51454 .69821 .51946 .69719 .52845 .69786 .52357 .69872 Metetra
.794 .709 0 r
.52357 .69872 .52845 .69786 .5375 .69824 .53264 .69894 Metetra
.805 .681 0 r
.53264 .69894 .5375 .69824 .54658 .69834 .54175 .69888 Metetra
.814 .655 0 r
.54175 .69888 .54658 .69834 .55571 .69817 .55091 .69857 Metetra
.823 .632 0 r
.55091 .69857 .55571 .69817 .56487 .69775 .5601 .69802 Metetra
.83 .61 0 r
.5601 .69802 .56487 .69775 .57407 .69709 .56933 .69724 Metetra
.837 .591 0 r
.56933 .69724 .57407 .69709 .58331 .69621 .5786 .69624 Metetra
.843 .573 0 r
.5786 .69624 .58331 .69621 .59259 .69511 .58791 .69504 Metetra
.848 .558 0 r
.58791 .69504 .59259 .69511 .6019 .6938 .59725 .69364 Metetra
.853 .545 0 r
.59725 .69364 .6019 .6938 .61124 .69229 .60662 .69206 Metetra
.856 .534 0 r
.60662 .69206 .61124 .69229 .62061 .69059 .61602 .69029 Metetra
.859 .525 0 r
.61602 .69029 .62061 .69059 .63002 .68871 .62546 .68835 Metetra
.861 .518 0 r
.62546 .68835 .63002 .68871 .63945 .68664 .63492 .68624 Metetra
.863 .513 0 r
.63492 .68624 .63945 .68664 .64892 .6844 .64442 .68396 Metetra
.864 .51 0 r
.64442 .68396 .64892 .6844 .65841 .68198 .65394 .68152 Metetra
.864 .509 0 r
.65394 .68152 .65841 .68198 .66792 .67939 .66349 .67891 Metetra
.864 .51 0 r
.66349 .67891 .66792 .67939 .67746 .67662 .67307 .67614 Metetra
.863 .513 0 r
.67307 .67614 .67746 .67662 .68703 .67367 .68267 .67321 Metetra
.861 .518 0 r
.68267 .67321 .68703 .67367 .69661 .67054 .69229 .6701 Metetra
.859 .525 0 r
.69229 .6701 .69661 .67054 .70622 .66723 .70194 .66682 Metetra
.856 .534 0 r
.70194 .66682 .70622 .66723 .71585 .66373 .71161 .66336 Metetra
.853 .545 0 r
.71161 .66336 .71585 .66373 .72549 .66003 .72129 .65972 Metetra
.848 .558 0 r
.72129 .65972 .72549 .66003 .73515 .65612 .73099 .65588 Metetra
.843 .573 0 r
.73099 .65588 .73515 .65612 .74482 .652 .74071 .65183 Metetra
.837 .591 0 r
.74071 .65183 .74482 .652 .75451 .64765 .75044 .64757 Metetra
.83 .61 0 r
.75044 .64757 .75451 .64765 .7642 .64306 .76018 .64309 Metetra
.823 .632 0 r
.76018 .64309 .7642 .64306 .77389 .63822 .76992 .63836 Metetra
.814 .655 0 r
.76992 .63836 .77389 .63822 .78359 .63312 .77967 .63338 Metetra
.805 .681 0 r
.77967 .63338 .78359 .63312 .79329 .62773 .78943 .62812 Metetra
.794 .709 0 r
.78943 .62812 .79329 .62773 .80298 .62205 .79918 .62258 Metetra
.782 .738 0 r
.79918 .62258 .80298 .62205 .81267 .61604 .80892 .61673 Metetra
.769 .769 0 r
.80892 .61673 .81267 .61604 .82234 .6097 .81865 .61055 Metetra
.708 .755 0 r
.81865 .61055 .82234 .6097 .83199 .603 .82836 .60403 Metetra
.643 .739 0 r
.82836 .60403 .83199 .603 .84162 .59592 .83806 .59713 Metetra
.574 .722 0 r
.83806 .59713 .84162 .59592 .85122 .58844 .84773 .58985 Metetra
.502 .703 0 r
.84773 .58985 .85122 .58844 .86078 .58054 .85737 .58214 Metetra
.426 .683 0 r
.85737 .58214 .86078 .58054 .87031 .57219 .86697 .574 Metetra
.349 .66 0 r
.86697 .574 .87031 .57219 .87978 .56336 .87652 .56539 Metetra
.269 .636 0 r
.87652 .56539 .87978 .56336 .88921 .55403 .88602 .55629 Metetra
.189 .61 0 r
.88602 .55629 .88921 .55403 .89857 .54417 .89547 .54667 Metetra
.109 .582 0 r
.89547 .54667 .89857 .54417 .90785 .53376 .90484 .5365 Metetra
.03 .551 0 r
.90484 .5365 .90785 .53376 .91707 .52277 .91414 .52576 Metetra
0 .518 .047 r
.91414 .52576 .91707 .52277 .92619 .51117 .92336 .51441 Metetra
0 .482 .118 r
.92336 .51441 .92619 .51117 .93521 .49893 .93248 .50243 Metetra
0 .444 .182 r
.93248 .50243 .93521 .49893 .94413 .48602 .9415 .48979 Metetra
0 .402 .237 r
.9415 .48979 .94413 .48602 .95293 .47243 .9504 .47646 Metetra
0 .358 .28 r
.9504 .47646 .95293 .47243 .96161 .45811 .95918 .46241 Metetra
0 .397 .244 r
.37294 .63847 .37839 .63421 .3863 .64223 .38088 .64622 Metetra
0 .439 .189 r
.38088 .64622 .3863 .64223 .39431 .6496 .38892 .65332 Metetra
0 .479 .123 r
.38892 .65332 .39431 .6496 .40242 .65634 .39706 .65979 Metetra
0 .516 .049 r
.39706 .65979 .40242 .65634 .41061 .66248 .40529 .66566 Metetra
.029 .551 0 r
.40529 .66566 .41061 .66248 .41889 .66805 .4136 .67097 Metetra
.112 .583 0 r
.4136 .67097 .41889 .66805 .42726 .67306 .422 .67573 Metetra
.196 .612 0 r
.422 .67573 .42726 .67306 .4357 .67755 .43047 .67997 Metetra
.28 .639 0 r
.43047 .67997 .4357 .67755 .44421 .68153 .43901 .68371 Metetra
.363 .665 0 r
.43901 .68371 .44421 .68153 .45279 .68504 .44763 .68699 Metetra
.445 .688 0 r
.44763 .68699 .45279 .68504 .46144 .6881 .45631 .68982 Metetra
.524 .709 0 r
.45631 .68982 .46144 .6881 .47015 .69073 .46505 .69223 Metetra
.6 .728 0 r
.46505 .69223 .47015 .69073 .47892 .69296 .47385 .69424 Metetra
.672 .746 0 r
.47385 .69424 .47892 .69296 .48775 .6948 .4827 .69588 Metetra
.741 .763 0 r
.4827 .69588 .48775 .6948 .49663 .69627 .49161 .69716 Metetra
.778 .749 0 r
.49161 .69716 .49663 .69627 .50556 .6974 .50057 .69811 Metetra
.791 .716 0 r
.50057 .69811 .50556 .6974 .51454 .69821 .50958 .69874 Metetra
.803 .684 0 r
.50958 .69874 .51454 .69821 .52357 .69872 .51864 .69908 Metetra
.815 .654 0 r
.51864 .69908 .52357 .69872 .53264 .69894 .52774 .69914 Metetra
.825 .627 0 r
.52774 .69914 .53264 .69894 .54175 .69888 .53688 .69893 Metetra
.834 .601 0 r
.53688 .69893 .54175 .69888 .55091 .69857 .54606 .69849 Metetra
.842 .577 0 r
.54606 .69849 .55091 .69857 .5601 .69802 .55528 .6978 Metetra
.849 .556 0 r
.55528 .6978 .5601 .69802 .56933 .69724 .56454 .69691 Metetra
.855 .537 0 r
.56454 .69691 .56933 .69724 .5786 .69624 .57384 .6958 Metetra
.861 .52 0 r
.57384 .6958 .5786 .69624 .58791 .69504 .58318 .6945 Metetra
.865 .505 0 r
.58318 .6945 .58791 .69504 .59725 .69364 .59254 .69301 Metetra
.869 .492 0 r
.59254 .69301 .59725 .69364 .60662 .69206 .60195 .69135 Metetra
.873 .481 0 r
.60195 .69135 .60662 .69206 .61602 .69029 .61138 .68952 Metetra
.875 .472 0 r
.61138 .68952 .61602 .69029 .62546 .68835 .62085 .68752 Metetra
.878 .466 0 r
.62085 .68752 .62546 .68835 .63492 .68624 .63034 .68536 Metetra
.879 .461 0 r
.63034 .68536 .63492 .68624 .64442 .68396 .63987 .68305 Metetra
.88 .458 0 r
.63987 .68305 .64442 .68396 .65394 .68152 .64942 .68058 Metetra
.88 .457 0 r
.64942 .68058 .65394 .68152 .66349 .67891 .65901 .67797 Metetra
.88 .458 0 r
.65901 .67797 .66349 .67891 .67307 .67614 .66862 .67519 Metetra
.879 .461 0 r
.66862 .67519 .67307 .67614 .68267 .67321 .67825 .67227 Metetra
.878 .466 0 r
.67825 .67227 .68267 .67321 .69229 .6701 .68791 .66918 Metetra
.875 .472 0 r
.68791 .66918 .69229 .6701 .70194 .66682 .6976 .66593 Metetra
.873 .481 0 r
.6976 .66593 .70194 .66682 .71161 .66336 .7073 .66252 Metetra
.869 .492 0 r
.7073 .66252 .71161 .66336 .72129 .65972 .71702 .65892 Metetra
.865 .505 0 r
.71702 .65892 .72129 .65972 .73099 .65588 .72677 .65515 Metetra
.861 .52 0 r
.72677 .65515 .73099 .65588 .74071 .65183 .73653 .65118 Metetra
.855 .537 0 r
.73653 .65118 .74071 .65183 .75044 .64757 .7463 .64701 Metetra
.849 .556 0 r
.7463 .64701 .75044 .64757 .76018 .64309 .75609 .64262 Metetra
.842 .577 0 r
.75609 .64262 .76018 .64309 .76992 .63836 .76588 .638 Metetra
.834 .601 0 r
.76588 .638 .76992 .63836 .77967 .63338 .77568 .63313 Metetra
.825 .627 0 r
.77568 .63313 .77967 .63338 .78943 .62812 .78549 .62801 Metetra
.815 .654 0 r
.78549 .62801 .78943 .62812 .79918 .62258 .79529 .6226 Metetra
.803 .684 0 r
.79529 .6226 .79918 .62258 .80892 .61673 .80509 .6169 Metetra
.791 .716 0 r
.80509 .6169 .80892 .61673 .81865 .61055 .81488 .61088 Metetra
.778 .749 0 r
.81488 .61088 .81865 .61055 .82836 .60403 .82466 .60452 Metetra
.741 .763 0 r
.82466 .60452 .82836 .60403 .83806 .59713 .83442 .59781 Metetra
.672 .746 0 r
.83442 .59781 .83806 .59713 .84773 .58985 .84415 .59071 Metetra
.6 .728 0 r
.84415 .59071 .84773 .58985 .85737 .58214 .85386 .5832 Metetra
.524 .709 0 r
.85386 .5832 .85737 .58214 .86697 .574 .86353 .57526 Metetra
.445 .688 0 r
.86353 .57526 .86697 .574 .87652 .56539 .87316 .56687 Metetra
.363 .665 0 r
.87316 .56687 .87652 .56539 .88602 .55629 .88274 .55799 Metetra
.28 .639 0 r
.88274 .55799 .88602 .55629 .89547 .54667 .89227 .54859 Metetra
.196 .612 0 r
.89227 .54859 .89547 .54667 .90484 .5365 .90173 .53866 Metetra
.112 .583 0 r
.90173 .53866 .90484 .5365 .91414 .52576 .91112 .52816 Metetra
.029 .551 0 r
.91112 .52816 .91414 .52576 .92336 .51441 .92042 .51706 Metetra
0 .516 .049 r
.92042 .51706 .92336 .51441 .93248 .50243 .92964 .50533 Metetra
0 .479 .123 r
.92964 .50533 .93248 .50243 .9415 .48979 .93875 .49295 Metetra
0 .439 .189 r
.93875 .49295 .9415 .48979 .9504 .47646 .94776 .47989 Metetra
0 .397 .244 r
.94776 .47989 .9504 .47646 .95918 .46241 .95664 .4661 Metetra
0 .433 .199 r
.36746 .64217 .37294 .63847 .38088 .64622 .37543 .64965 Metetra
0 .474 .132 r
.37543 .64965 .38088 .64622 .38892 .65332 .3835 .65648 Metetra
0 .513 .058 r
.3835 .65648 .38892 .65332 .39706 .65979 .39167 .66269 Metetra
.023 .548 0 r
.39167 .66269 .39706 .65979 .40529 .66566 .39993 .66831 Metetra
.108 .581 0 r
.39993 .66831 .40529 .66566 .4136 .67097 .40828 .67336 Metetra
.195 .612 0 r
.40828 .67336 .4136 .67097 .422 .67573 .4167 .67787 Metetra
.283 .64 0 r
.4167 .67787 .422 .67573 .43047 .67997 .42521 .68187 Metetra
.37 .667 0 r
.42521 .68187 .43047 .67997 .43901 .68371 .43378 .68538 Metetra
.456 .691 0 r
.43378 .68538 .43901 .68371 .44763 .68699 .44242 .68843 Metetra
.538 .713 0 r
.44242 .68843 .44763 .68699 .45631 .68982 .45113 .69104 Metetra
.618 .733 0 r
.45113 .69104 .45631 .68982 .46505 .69223 .4599 .69323 Metetra
.695 .752 0 r
.4599 .69323 .46505 .69223 .47385 .69424 .46873 .69504 Metetra
.767 .769 0 r
.46873 .69504 .47385 .69424 .4827 .69588 .47762 .69648 Metetra
.784 .733 0 r
.47762 .69648 .4827 .69588 .49161 .69716 .48655 .69757 Metetra
.798 .698 0 r
.48655 .69757 .49161 .69716 .50057 .69811 .49554 .69833 Metetra
.811 .664 0 r
.49554 .69833 .50057 .69811 .50958 .69874 .50458 .69879 Metetra
.823 .632 0 r
.50458 .69879 .50958 .69874 .51864 .69908 .51366 .69897 Metetra
.833 .602 0 r
.51366 .69897 .51864 .69908 .52774 .69914 .52279 .69887 Metetra
.843 .574 0 r
.52279 .69887 .52774 .69914 .53688 .69893 .53196 .69852 Metetra
.851 .549 0 r
.53196 .69852 .53688 .69893 .54606 .69849 .54117 .69794 Metetra
.859 .526 0 r
.54117 .69794 .54606 .69849 .55528 .6978 .55042 .69713 Metetra
.865 .505 0 r
.55042 .69713 .55528 .6978 .56454 .69691 .55971 .69612 Metetra
.871 .486 0 r
.55971 .69612 .56454 .69691 .57384 .6958 .56904 .6949 Metetra
.876 .47 0 r
.56904 .6949 .57384 .6958 .58318 .6945 .5784 .69351 Metetra
.881 .455 0 r
.5784 .69351 .58318 .6945 .59254 .69301 .58779 .69194 Metetra
.885 .443 0 r
.58779 .69194 .59254 .69301 .60195 .69135 .59722 .6902 Metetra
.888 .432 0 r
.59722 .6902 .60195 .69135 .61138 .68952 .60669 .6883 Metetra
.89 .424 0 r
.60669 .6883 .61138 .68952 .62085 .68752 .61618 .68624 Metetra
.892 .417 0 r
.61618 .68624 .62085 .68752 .63034 .68536 .62571 .68404 Metetra
.893 .413 0 r
.62571 .68404 .63034 .68536 .63987 .68305 .63527 .6817 Metetra
.894 .41 0 r
.63527 .6817 .63987 .68305 .64942 .68058 .64485 .67921 Metetra
.894 .409 0 r
.64485 .67921 .64942 .68058 .65901 .67797 .65447 .67657 Metetra
.894 .41 0 r
.65447 .67657 .65901 .67797 .66862 .67519 .66411 .6738 Metetra
.893 .413 0 r
.66411 .6738 .66862 .67519 .67825 .67227 .67378 .67088 Metetra
.892 .417 0 r
.67378 .67088 .67825 .67227 .68791 .66918 .68347 .66781 Metetra
.89 .424 0 r
.68347 .66781 .68791 .66918 .6976 .66593 .69319 .66459 Metetra
.888 .432 0 r
.69319 .66459 .6976 .66593 .7073 .66252 .70293 .66122 Metetra
.885 .443 0 r
.70293 .66122 .7073 .66252 .71702 .65892 .7127 .65768 Metetra
.881 .455 0 r
.7127 .65768 .71702 .65892 .72677 .65515 .72248 .65396 Metetra
.876 .47 0 r
.72248 .65396 .72677 .65515 .73653 .65118 .73228 .65006 Metetra
.871 .486 0 r
.73228 .65006 .73653 .65118 .7463 .64701 .7421 .64597 Metetra
.865 .505 0 r
.7421 .64597 .7463 .64701 .75609 .64262 .75193 .64168 Metetra
.859 .526 0 r
.75193 .64168 .75609 .64262 .76588 .638 .76177 .63716 Metetra
.851 .549 0 r
.76177 .63716 .76588 .638 .77568 .63313 .77162 .63241 Metetra
.843 .574 0 r
.77162 .63241 .77568 .63313 .78549 .62801 .78147 .6274 Metetra
.833 .602 0 r
.78147 .6274 .78549 .62801 .79529 .6226 .79133 .62213 Metetra
.823 .632 0 r
.79133 .62213 .79529 .6226 .80509 .6169 .80118 .61657 Metetra
.811 .664 0 r
.80118 .61657 .80509 .6169 .81488 .61088 .81103 .61071 Metetra
.798 .698 0 r
.81103 .61071 .81488 .61088 .82466 .60452 .82087 .60451 Metetra
.784 .733 0 r
.82087 .60451 .82466 .60452 .83442 .59781 .83069 .59797 Metetra
.767 .769 0 r
.83069 .59797 .83442 .59781 .84415 .59071 .84049 .59105 Metetra
.695 .752 0 r
.84049 .59105 .84415 .59071 .85386 .5832 .85027 .58373 Metetra
.618 .733 0 r
.85027 .58373 .85386 .5832 .86353 .57526 .86001 .57599 Metetra
.538 .713 0 r
.86001 .57599 .86353 .57526 .87316 .56687 .86971 .56781 Metetra
.456 .691 0 r
.86971 .56781 .87316 .56687 .88274 .55799 .87937 .55914 Metetra
.37 .667 0 r
.87937 .55914 .88274 .55799 .89227 .54859 .88898 .54997 Metetra
.283 .64 0 r
.88898 .54997 .89227 .54859 .90173 .53866 .89852 .54026 Metetra
.195 .612 0 r
.89852 .54026 .90173 .53866 .91112 .52816 .90799 .53 Metetra
.108 .581 0 r
.90799 .53 .91112 .52816 .92042 .51706 .91739 .51914 Metetra
.023 .548 0 r
.91739 .51914 .92042 .51706 .92964 .50533 .92669 .50766 Metetra
0 .513 .058 r
.92669 .50766 .92964 .50533 .93875 .49295 .9359 .49553 Metetra
0 .474 .132 r
.9359 .49553 .93875 .49295 .94776 .47989 .945 .48272 Metetra
0 .433 .199 r
.945 .48272 .94776 .47989 .95664 .4661 .95398 .4692 Metetra
0 .466 .146 r
.36194 .64533 .36746 .64217 .37543 .64965 .36995 .65254 Metetra
0 .506 .071 r
.36995 .65254 .37543 .64965 .3835 .65648 .37805 .65911 Metetra
.012 .543 0 r
.37805 .65911 .3835 .65648 .39167 .66269 .38625 .66506 Metetra
.099 .578 0 r
.38625 .66506 .39167 .66269 .39993 .66831 .39454 .67043 Metetra
.189 .61 0 r
.39454 .67043 .39993 .66831 .40828 .67336 .40292 .67524 Metetra
.28 .639 0 r
.40292 .67524 .40828 .67336 .4167 .67787 .41137 .67951 Metetra
.37 .667 0 r
.41137 .67951 .4167 .67787 .42521 .68187 .4199 .68327 Metetra
.459 .692 0 r
.4199 .68327 .42521 .68187 .43378 .68538 .42851 .68655 Metetra
.546 .715 0 r
.42851 .68655 .43378 .68538 .44242 .68843 .43718 .68938 Metetra
.629 .736 0 r
.43718 .68938 .44242 .68843 .45113 .69104 .44592 .69177 Metetra
.709 .755 0 r
.44592 .69177 .45113 .69104 .4599 .69323 .45472 .69376 Metetra
.773 .761 0 r
.45472 .69376 .4599 .69323 .46873 .69504 .46358 .69537 Metetra
.789 .721 0 r
.46358 .69537 .46873 .69504 .47762 .69648 .47249 .69661 Metetra
.804 .683 0 r
.47249 .69661 .47762 .69648 .48655 .69757 .48145 .69752 Metetra
.817 .647 0 r
.48145 .69752 .48655 .69757 .49554 .69833 .49047 .69811 Metetra
.829 .613 0 r
.49047 .69811 .49554 .69833 .50458 .69879 .49954 .6984 Metetra
.84 .582 0 r
.49954 .6984 .50458 .69879 .51366 .69897 .50865 .69841 Metetra
.85 .552 0 r
.50865 .69841 .51366 .69897 .52279 .69887 .5178 .69817 Metetra
.859 .525 0 r
.5178 .69817 .52279 .69887 .53196 .69852 .527 .69768 Metetra
.867 .5 0 r
.527 .69768 .53196 .69852 .54117 .69794 .53624 .69696 Metetra
.874 .477 0 r
.53624 .69696 .54117 .69794 .55042 .69713 .54551 .69603 Metetra
.88 .457 0 r
.54551 .69603 .55042 .69713 .55971 .69612 .55483 .6949 Metetra
.886 .439 0 r
.55483 .6949 .55971 .69612 .56904 .6949 .56418 .69359 Metetra
.89 .423 0 r
.56418 .69359 .56904 .6949 .5784 .69351 .57357 .6921 Metetra
.894 .409 0 r
.57357 .6921 .5784 .69351 .58779 .69194 .583 .69044 Metetra
.898 .397 0 r
.583 .69044 .58779 .69194 .59722 .6902 .59245 .68862 Metetra
.901 .387 0 r
.59245 .68862 .59722 .6902 .60669 .6883 .60195 .68666 Metetra
.903 .379 0 r
.60195 .68666 .60669 .6883 .61618 .68624 .61147 .68455 Metetra
.905 .373 0 r
.61147 .68455 .61618 .68624 .62571 .68404 .62102 .68231 Metetra
.906 .368 0 r
.62102 .68231 .62571 .68404 .63527 .6817 .63061 .67993 Metetra
.907 .366 0 r
.63061 .67993 .63527 .6817 .64485 .67921 .64023 .67741 Metetra
.907 .365 0 r
.64023 .67741 .64485 .67921 .65447 .67657 .64987 .67477 Metetra
.907 .366 0 r
.64987 .67477 .65447 .67657 .66411 .6738 .65955 .67199 Metetra
.906 .368 0 r
.65955 .67199 .66411 .6738 .67378 .67088 .66925 .66908 Metetra
.905 .373 0 r
.66925 .66908 .67378 .67088 .68347 .66781 .67898 .66603 Metetra
.903 .379 0 r
.67898 .66603 .68347 .66781 .69319 .66459 .68873 .66284 Metetra
.901 .387 0 r
.68873 .66284 .69319 .66459 .70293 .66122 .69851 .6595 Metetra
.898 .397 0 r
.69851 .6595 .70293 .66122 .7127 .65768 .70831 .656 Metetra
.894 .409 0 r
.70831 .656 .7127 .65768 .72248 .65396 .71813 .65235 Metetra
.89 .423 0 r
.71813 .65235 .72248 .65396 .73228 .65006 .72797 .64852 Metetra
.886 .439 0 r
.72797 .64852 .73228 .65006 .7421 .64597 .73783 .6445 Metetra
.88 .457 0 r
.73783 .6445 .7421 .64597 .75193 .64168 .74771 .6403 Metetra
.874 .477 0 r
.74771 .6403 .75193 .64168 .76177 .63716 .75759 .63588 Metetra
.867 .5 0 r
.75759 .63588 .76177 .63716 .77162 .63241 .76749 .63123 Metetra
.859 .525 0 r
.76749 .63123 .77162 .63241 .78147 .6274 .77739 .62635 Metetra
.85 .552 0 r
.77739 .62635 .78147 .6274 .79133 .62213 .7873 .62121 Metetra
.84 .582 0 r
.7873 .62121 .79133 .62213 .80118 .61657 .79721 .61579 Metetra
.829 .613 0 r
.79721 .61579 .80118 .61657 .81103 .61071 .80711 .61007 Metetra
.817 .647 0 r
.80711 .61007 .81103 .61071 .82087 .60451 .81701 .60403 Metetra
.804 .683 0 r
.81701 .60403 .82087 .60451 .83069 .59797 .82689 .59765 Metetra
.789 .721 0 r
.82689 .59765 .83069 .59797 .84049 .59105 .83675 .59091 Metetra
.773 .761 0 r
.83675 .59091 .84049 .59105 .85027 .58373 .84659 .58377 Metetra
.709 .755 0 r
.84659 .58377 .85027 .58373 .86001 .57599 .8564 .57622 Metetra
.629 .736 0 r
.8564 .57622 .86001 .57599 .86971 .56781 .86618 .56823 Metetra
.546 .715 0 r
.86618 .56823 .86971 .56781 .87937 .55914 .87591 .55977 Metetra
.459 .692 0 r
.87591 .55977 .87937 .55914 .88898 .54997 .88559 .55082 Metetra
.37 .667 0 r
.88559 .55082 .88898 .54997 .89852 .54026 .89521 .54133 Metetra
.28 .639 0 r
.89521 .54133 .89852 .54026 .90799 .53 .90477 .5313 Metetra
.189 .61 0 r
.90477 .5313 .90799 .53 .91739 .51914 .91425 .52067 Metetra
.099 .578 0 r
.91425 .52067 .91739 .51914 .92669 .50766 .92364 .50943 Metetra
.012 .543 0 r
.92364 .50943 .92669 .50766 .9359 .49553 .93294 .49754 Metetra
0 .506 .071 r
.93294 .49754 .9359 .49553 .945 .48272 .94214 .48498 Metetra
0 .466 .146 r
.94214 .48498 .945 .48272 .95398 .4692 .95122 .47171 Metetra
0 .497 .089 r
.3564 .64796 .36194 .64533 .36995 .65254 .36444 .65492 Metetra
0 .536 .006 r
.36444 .65492 .36995 .65254 .37805 .65911 .37257 .66123 Metetra
.083 .572 0 r
.37257 .66123 .37805 .65911 .38625 .66506 .3808 .66694 Metetra
.175 .605 0 r
.3808 .66694 .38625 .66506 .39454 .67043 .38912 .67206 Metetra
.269 .636 0 r
.38912 .67206 .39454 .67043 .40292 .67524 .39752 .67663 Metetra
.363 .664 0 r
.39752 .67663 .40292 .67524 .41137 .67951 .40601 .68067 Metetra
.455 .691 0 r
.40601 .68067 .41137 .67951 .4199 .68327 .41457 .6842 Metetra
.546 .715 0 r
.41457 .6842 .4199 .68327 .42851 .68655 .4232 .68726 Metetra
.633 .737 0 r
.4232 .68726 .42851 .68655 .43718 .68938 .4319 .68987 Metetra
.717 .757 0 r
.4319 .68987 .43718 .68938 .44592 .69177 .44067 .69206 Metetra
.775 .755 0 r
.44067 .69206 .44592 .69177 .45472 .69376 .4495 .69384 Metetra
.792 .713 0 r
.4495 .69384 .45472 .69376 .46358 .69537 .45838 .69525 Metetra
.808 .673 0 r
.45838 .69525 .46358 .69537 .47249 .69661 .46732 .69631 Metetra
.822 .635 0 r
.46732 .69631 .47249 .69661 .48145 .69752 .47632 .69704 Metetra
.834 .599 0 r
.47632 .69704 .48145 .69752 .49047 .69811 .48536 .69745 Metetra
.846 .565 0 r
.48536 .69745 .49047 .69811 .49954 .6984 .49445 .69758 Metetra
.856 .534 0 r
.49445 .69758 .49954 .6984 .50865 .69841 .50359 .69744 Metetra
.865 .505 0 r
.50359 .69744 .50865 .69841 .5178 .69817 .51277 .69705 Metetra
.874 .478 0 r
.51277 .69705 .5178 .69817 .527 .69768 .522 .69642 Metetra
.881 .454 0 r
.522 .69642 .527 .69768 .53624 .69696 .53126 .69558 Metetra
.888 .432 0 r
.53126 .69558 .53624 .69696 .54551 .69603 .54056 .69453 Metetra
.893 .413 0 r
.54056 .69453 .54551 .69603 .55483 .6949 .54991 .69329 Metetra
.898 .395 0 r
.54991 .69329 .55483 .6949 .56418 .69359 .55929 .69187 Metetra
.903 .38 0 r
.55929 .69187 .56418 .69359 .57357 .6921 .5687 .69029 Metetra
.907 .367 0 r
.5687 .69029 .57357 .6921 .583 .69044 .57815 .68855 Metetra
.91 .355 0 r
.57815 .68855 .583 .69044 .59245 .68862 .58764 .68666 Metetra
.913 .346 0 r
.58764 .68666 .59245 .68862 .60195 .68666 .59716 .68464 Metetra
.915 .338 0 r
.59716 .68464 .60195 .68666 .61147 .68455 .60671 .68248 Metetra
.916 .332 0 r
.60671 .68248 .61147 .68455 .62102 .68231 .61629 .68019 Metetra
.917 .328 0 r
.61629 .68019 .62102 .68231 .63061 .67993 .62591 .67777 Metetra
.918 .326 0 r
.62591 .67777 .63061 .67993 .64023 .67741 .63556 .67524 Metetra
.918 .325 0 r
.63556 .67524 .64023 .67741 .64987 .67477 .64523 .67258 Metetra
.918 .326 0 r
.64523 .67258 .64987 .67477 .65955 .67199 .65494 .66979 Metetra
.917 .328 0 r
.65494 .66979 .65955 .67199 .66925 .66908 .66467 .66688 Metetra
.916 .332 0 r
.66467 .66688 .66925 .66908 .67898 .66603 .67443 .66385 Metetra
.915 .338 0 r
.67443 .66385 .67898 .66603 .68873 .66284 .68422 .66068 Metetra
.913 .346 0 r
.68422 .66068 .68873 .66284 .69851 .6595 .69403 .65738 Metetra
.91 .355 0 r
.69403 .65738 .69851 .6595 .70831 .656 .70387 .65393 Metetra
.907 .367 0 r
.70387 .65393 .70831 .656 .71813 .65235 .71373 .65033 Metetra
.903 .38 0 r
.71373 .65033 .71813 .65235 .72797 .64852 .72361 .64657 Metetra
.898 .395 0 r
.72361 .64657 .72797 .64852 .73783 .6445 .73351 .64263 Metetra
.893 .413 0 r
.73351 .64263 .73783 .6445 .74771 .6403 .74342 .6385 Metetra
.888 .432 0 r
.74342 .6385 .74771 .6403 .75759 .63588 .75335 .63418 Metetra
.881 .454 0 r
.75335 .63418 .75759 .63588 .76749 .63123 .76329 .62964 Metetra
.874 .478 0 r
.76329 .62964 .76749 .63123 .77739 .62635 .77324 .62487 Metetra
.865 .505 0 r
.77324 .62487 .77739 .62635 .7873 .62121 .7832 .61985 Metetra
.856 .534 0 r
.7832 .61985 .7873 .62121 .79721 .61579 .79316 .61456 Metetra
.846 .565 0 r
.79316 .61456 .79721 .61579 .80711 .61007 .80312 .60898 Metetra
.834 .599 0 r
.80312 .60898 .80711 .61007 .81701 .60403 .81307 .60309 Metetra
.822 .635 0 r
.81307 .60309 .81701 .60403 .82689 .59765 .82301 .59687 Metetra
.808 .673 0 r
.82301 .59687 .82689 .59765 .83675 .59091 .83293 .5903 Metetra
.792 .713 0 r
.83293 .5903 .83675 .59091 .84659 .58377 .84284 .58334 Metetra
.775 .755 0 r
.84284 .58334 .84659 .58377 .8564 .57622 .85271 .57598 Metetra
.717 .757 0 r
.85271 .57598 .8564 .57622 .86618 .56823 .86256 .56818 Metetra
.633 .737 0 r
.86256 .56818 .86618 .56823 .87591 .55977 .87236 .55992 Metetra
.546 .715 0 r
.87236 .55992 .87591 .55977 .88559 .55082 .88211 .55117 Metetra
.455 .691 0 r
.88211 .55117 .88559 .55082 .89521 .54133 .89181 .5419 Metetra
.363 .664 0 r
.89181 .5419 .89521 .54133 .90477 .5313 .90145 .53208 Metetra
.269 .636 0 r
.90145 .53208 .90477 .5313 .91425 .52067 .91101 .52168 Metetra
.175 .605 0 r
.91101 .52168 .91425 .52067 .92364 .50943 .92049 .51067 Metetra
.083 .572 0 r
.92049 .51067 .92364 .50943 .93294 .49754 .92988 .49902 Metetra
0 .536 .006 r
.92988 .49902 .93294 .49754 .94214 .48498 .93917 .4867 Metetra
0 .497 .089 r
.93917 .4867 .94214 .48498 .95122 .47171 .94834 .47367 Metetra
0 .526 .029 r
.35083 .65009 .3564 .64796 .36444 .65492 .35889 .6568 Metetra
.061 .563 0 r
.35889 .6568 .36444 .65492 .37257 .66123 .36706 .66287 Metetra
.155 .598 0 r
.36706 .66287 .37257 .66123 .3808 .66694 .37532 .66834 Metetra
.252 .631 0 r
.37532 .66834 .3808 .66694 .38912 .67206 .38366 .67322 Metetra
.348 .66 0 r
.38366 .67322 .38912 .67206 .39752 .67663 .3921 .67756 Metetra
.444 .688 0 r
.3921 .67756 .39752 .67663 .40601 .68067 .40061 .68137 Metetra
.538 .713 0 r
.40061 .68137 .40601 .68067 .41457 .6842 .4092 .68468 Metetra
.629 .736 0 r
.4092 .68468 .41457 .6842 .4232 .68726 .41786 .68753 Metetra
.717 .757 0 r
.41786 .68753 .4232 .68726 .4319 .68987 .42659 .68993 Metetra
.776 .753 0 r
.42659 .68993 .4319 .68987 .44067 .69206 .43539 .69191 Metetra
.794 .709 0 r
.43539 .69191 .44067 .69206 .4495 .69384 .44424 .6935 Metetra
.81 .667 0 r
.44424 .6935 .4495 .69384 .45838 .69525 .45315 .69472 Metetra
.825 .627 0 r
.45315 .69472 .45838 .69525 .46732 .69631 .46212 .69559 Metetra
.838 .589 0 r
.46212 .69559 .46732 .69631 .47632 .69704 .47114 .69615 Metetra
.85 .553 0 r
.47114 .69615 .47632 .69704 .48536 .69745 .48021 .6964 Metetra
.861 .52 0 r
.48021 .6964 .48536 .69745 .49445 .69758 .48933 .69637 Metetra
.87 .489 0 r
.48933 .69637 .49445 .69758 .50359 .69744 .4985 .69608 Metetra
.879 .461 0 r
.4985 .69608 .50359 .69744 .51277 .69705 .5077 .69554 Metetra
.887 .435 0 r
.5077 .69554 .51277 .69705 .522 .69642 .51695 .69478 Metetra
.894 .412 0 r
.51695 .69478 .522 .69642 .53126 .69558 .52624 .69381 Metetra
.9 .391 0 r
.52624 .69381 .53126 .69558 .54056 .69453 .53557 .69265 Metetra
.905 .372 0 r
.53557 .69265 .54056 .69453 .54991 .69329 .54494 .6913 Metetra
.91 .355 0 r
.54494 .6913 .54991 .69329 .55929 .69187 .55435 .68979 Metetra
.914 .341 0 r
.55435 .68979 .55929 .69187 .5687 .69029 .56379 .68812 Metetra
.917 .328 0 r
.56379 .68812 .5687 .69029 .57815 .68855 .57327 .6863 Metetra
.92 .318 0 r
.57327 .6863 .57815 .68855 .58764 .68666 .58278 .68434 Metetra
.923 .309 0 r
.58278 .68434 .58764 .68666 .59716 .68464 .59233 .68225 Metetra
.925 .301 0 r
.59233 .68225 .59716 .68464 .60671 .68248 .6019 .68004 Metetra
.926 .296 0 r
.6019 .68004 .60671 .68248 .61629 .68019 .61152 .67771 Metetra
.927 .292 0 r
.61152 .67771 .61629 .68019 .62591 .67777 .62116 .67526 Metetra
.928 .29 0 r
.62116 .67526 .62591 .67777 .63556 .67524 .63084 .6727 Metetra
.928 .289 0 r
.63084 .6727 .63556 .67524 .64523 .67258 .64054 .67002 Metetra
.928 .29 0 r
.64054 .67002 .64523 .67258 .65494 .66979 .65028 .66723 Metetra
.927 .292 0 r
.65028 .66723 .65494 .66979 .66467 .66688 .66004 .66433 Metetra
.926 .296 0 r
.66004 .66433 .66467 .66688 .67443 .66385 .66983 .66131 Metetra
.925 .301 0 r
.66983 .66131 .67443 .66385 .68422 .66068 .67965 .65817 Metetra
.923 .309 0 r
.67965 .65817 .68422 .66068 .69403 .65738 .6895 .6549 Metetra
.92 .318 0 r
.6895 .6549 .69403 .65738 .70387 .65393 .69937 .65149 Metetra
.917 .328 0 r
.69937 .65149 .70387 .65393 .71373 .65033 .70927 .64794 Metetra
.914 .341 0 r
.70927 .64794 .71373 .65033 .72361 .64657 .71918 .64424 Metetra
.91 .355 0 r
.71918 .64424 .72361 .64657 .73351 .64263 .72912 .64037 Metetra
.905 .372 0 r
.72912 .64037 .73351 .64263 .74342 .6385 .73908 .63633 Metetra
.9 .391 0 r
.73908 .63633 .74342 .6385 .75335 .63418 .74905 .63209 Metetra
.894 .412 0 r
.74905 .63209 .75335 .63418 .76329 .62964 .75904 .62765 Metetra
.887 .435 0 r
.75904 .62765 .76329 .62964 .77324 .62487 .76903 .62299 Metetra
.879 .461 0 r
.76903 .62299 .77324 .62487 .7832 .61985 .77904 .61809 Metetra
.87 .489 0 r
.77904 .61809 .7832 .61985 .79316 .61456 .78905 .61292 Metetra
.861 .52 0 r
.78905 .61292 .79316 .61456 .80312 .60898 .79906 .60748 Metetra
.85 .553 0 r
.79906 .60748 .80312 .60898 .81307 .60309 .80906 .60174 Metetra
.838 .589 0 r
.80906 .60174 .81307 .60309 .82301 .59687 .81906 .59567 Metetra
.825 .627 0 r
.81906 .59567 .82301 .59687 .83293 .5903 .82904 .58925 Metetra
.81 .667 0 r
.82904 .58925 .83293 .5903 .84284 .58334 .83901 .58247 Metetra
.794 .709 0 r
.83901 .58247 .84284 .58334 .85271 .57598 .84895 .57528 Metetra
.776 .753 0 r
.84895 .57528 .85271 .57598 .86256 .56818 .85885 .56766 Metetra
.717 .757 0 r
.85885 .56766 .86256 .56818 .87236 .55992 .86873 .55959 Metetra
.629 .736 0 r
.86873 .55959 .87236 .55992 .88211 .55117 .87855 .55104 Metetra
.538 .713 0 r
.87855 .55104 .88211 .55117 .89181 .5419 .88833 .54198 Metetra
.444 .688 0 r
.88833 .54198 .89181 .5419 .90145 .53208 .89804 .53237 Metetra
.348 .66 0 r
.89804 .53237 .90145 .53208 .91101 .52168 .90768 .52219 Metetra
.252 .631 0 r
.90768 .52219 .91101 .52168 .92049 .51067 .91725 .5114 Metetra
.155 .598 0 r
.91725 .5114 .92049 .51067 .92988 .49902 .92672 .49998 Metetra
.061 .563 0 r
.92672 .49998 .92988 .49902 .93917 .4867 .9361 .48789 Metetra
0 .526 .029 r
.9361 .48789 .93917 .4867 .94834 .47367 .94536 .47509 Metetra
.034 .553 0 r
.34523 .65174 .35083 .65009 .35889 .6568 .35332 .65821 Metetra
.129 .589 0 r
.35332 .65821 .35889 .6568 .36706 .66287 .36151 .66405 Metetra
.227 .623 0 r
.36151 .66405 .36706 .66287 .37532 .66834 .3698 .66928 Metetra
.327 .654 0 r
.3698 .66928 .37532 .66834 .38366 .67322 .37818 .67394 Metetra
.426 .683 0 r
.37818 .67394 .38366 .67322 .3921 .67756 .38664 .67805 Metetra
.523 .709 0 r
.38664 .67805 .3921 .67756 .40061 .68137 .39518 .68164 Metetra
.618 .733 0 r
.39518 .68164 .40061 .68137 .4092 .68468 .4038 .68474 Metetra
.709 .755 0 r
.4038 .68474 .4092 .68468 .41786 .68753 .41249 .68737 Metetra
.775 .755 0 r
.41249 .68737 .41786 .68753 .42659 .68993 .42125 .68957 Metetra
.794 .709 0 r
.42125 .68957 .42659 .68993 .43539 .69191 .43007 .69136 Metetra
.811 .665 0 r
.43007 .69136 .43539 .69191 .44424 .6935 .43895 .69276 Metetra
.826 .623 0 r
.43895 .69276 .44424 .6935 .45315 .69472 .44789 .69379 Metetra
.84 .583 0 r
.44789 .69379 .45315 .69472 .46212 .69559 .45688 .69449 Metetra
.852 .545 0 r
.45688 .69449 .46212 .69559 .47114 .69615 .46593 .69488 Metetra
.864 .51 0 r
.46593 .69488 .47114 .69615 .48021 .6964 .47503 .69497 Metetra
.874 .477 0 r
.47503 .69497 .48021 .6964 .48933 .69637 .48417 .69479 Metetra
.883 .448 0 r
.48417 .69479 .48933 .69637 .4985 .69608 .49336 .69435 Metetra
.891 .42 0 r
.49336 .69435 .4985 .69608 .5077 .69554 .5026 .69368 Metetra
.898 .395 0 r
.5026 .69368 .5077 .69554 .51695 .69478 .51187 .69279 Metetra
.905 .373 0 r
.51187 .69279 .51695 .69478 .52624 .69381 .52119 .6917 Metetra
.911 .353 0 r
.52119 .6917 .52624 .69381 .53557 .69265 .53054 .69042 Metetra
.916 .335 0 r
.53054 .69042 .53557 .69265 .54494 .6913 .53994 .68897 Metetra
.92 .319 0 r
.53994 .68897 .54494 .6913 .55435 .68979 .54937 .68736 Metetra
.924 .305 0 r
.54937 .68736 .55435 .68979 .56379 .68812 .55884 .68561 Metetra
.927 .294 0 r
.55884 .68561 .56379 .68812 .57327 .6863 .56834 .68371 Metetra
.93 .284 0 r
.56834 .68371 .57327 .6863 .58278 .68434 .57788 .68168 Metetra
.932 .275 0 r
.57788 .68168 .58278 .68434 .59233 .68225 .58745 .67953 Metetra
.934 .268 0 r
.58745 .67953 .59233 .68225 .6019 .68004 .59706 .67727 Metetra
.935 .263 0 r
.59706 .67727 .6019 .68004 .61152 .67771 .60669 .6749 Metetra
.936 .26 0 r
.60669 .6749 .61152 .67771 .62116 .67526 .61637 .67241 Metetra
.937 .258 0 r
.61637 .67241 .62116 .67526 .63084 .6727 .62607 .66983 Metetra
.937 .257 0 r
.62607 .66983 .63084 .6727 .64054 .67002 .6358 .66714 Metetra
.937 .258 0 r
.6358 .66714 .64054 .67002 .65028 .66723 .64557 .66434 Metetra
.936 .26 0 r
.64557 .66434 .65028 .66723 .66004 .66433 .65536 .66144 Metetra
.935 .263 0 r
.65536 .66144 .66004 .66433 .66983 .66131 .66519 .65844 Metetra
.934 .268 0 r
.66519 .65844 .66983 .66131 .67965 .65817 .67504 .65531 Metetra
.932 .275 0 r
.67504 .65531 .67965 .65817 .6895 .6549 .68492 .65207 Metetra
.93 .284 0 r
.68492 .65207 .6895 .6549 .69937 .65149 .69482 .64871 Metetra
.927 .294 0 r
.69482 .64871 .69937 .65149 .70927 .64794 .70475 .64521 Metetra
.924 .305 0 r
.70475 .64521 .70927 .64794 .71918 .64424 .71471 .64156 Metetra
.92 .319 0 r
.71471 .64156 .71918 .64424 .72912 .64037 .72468 .63776 Metetra
.916 .335 0 r
.72468 .63776 .72912 .64037 .73908 .63633 .73468 .63379 Metetra
.911 .353 0 r
.73468 .63379 .73908 .63633 .74905 .63209 .74469 .62964 Metetra
.905 .373 0 r
.74469 .62964 .74905 .63209 .75904 .62765 .75472 .6253 Metetra
.898 .395 0 r
.75472 .6253 .75904 .62765 .76903 .62299 .76476 .62074 Metetra
.891 .42 0 r
.76476 .62074 .76903 .62299 .77904 .61809 .77481 .61594 Metetra
.883 .448 0 r
.77481 .61594 .77904 .61809 .78905 .61292 .78487 .6109 Metetra
.874 .477 0 r
.78487 .6109 .78905 .61292 .79906 .60748 .79493 .60559 Metetra
.864 .51 0 r
.79493 .60559 .79906 .60748 .80906 .60174 .80499 .59998 Metetra
.852 .545 0 r
.80499 .59998 .80906 .60174 .81906 .59567 .81504 .59406 Metetra
.84 .583 0 r
.81504 .59406 .81906 .59567 .82904 .58925 .82508 .5878 Metetra
.826 .623 0 r
.82508 .5878 .82904 .58925 .83901 .58247 .8351 .58117 Metetra
.811 .665 0 r
.8351 .58117 .83901 .58247 .84895 .57528 .8451 .57415 Metetra
.794 .709 0 r
.8451 .57415 .84895 .57528 .85885 .56766 .85508 .56671 Metetra
.775 .755 0 r
.85508 .56671 .85885 .56766 .86873 .55959 .86502 .55883 Metetra
.709 .755 0 r
.86502 .55883 .86873 .55959 .87855 .55104 .87491 .55047 Metetra
.618 .733 0 r
.87491 .55047 .87855 .55104 .88833 .54198 .88476 .5416 Metetra
.523 .709 0 r
.88476 .5416 .88833 .54198 .89804 .53237 .89455 .53219 Metetra
.426 .683 0 r
.89455 .53219 .89804 .53237 .90768 .52219 .90427 .52222 Metetra
.327 .654 0 r
.90427 .52222 .90768 .52219 .91725 .5114 .91391 .51164 Metetra
.227 .623 0 r
.91391 .51164 .91725 .5114 .92672 .49998 .92347 .50044 Metetra
.129 .589 0 r
.92347 .50044 .92672 .49998 .9361 .48789 .93293 .48857 Metetra
.034 .553 0 r
.93293 .48857 .9361 .48789 .94536 .47509 .94229 .476 Metetra
.097 .577 0 r
.3396 .65294 .34523 .65174 .35332 .65821 .34772 .65917 Metetra
.197 .613 0 r
.34772 .65917 .35332 .65821 .36151 .66405 .35594 .66478 Metetra
.299 .645 0 r
.35594 .66478 .36151 .66405 .3698 .66928 .36425 .66979 Metetra
.4 .675 0 r
.36425 .66979 .3698 .66928 .37818 .67394 .37266 .67422 Metetra
.501 .703 0 r
.37266 .67422 .37818 .67394 .38664 .67805 .38115 .67811 Metetra
.599 .728 0 r
.38115 .67811 .38664 .67805 .39518 .68164 .38972 .68149 Metetra
.694 .752 0 r
.38972 .68149 .39518 .68164 .4038 .68474 .39836 .68439 Metetra
.773 .761 0 r
.39836 .68439 .4038 .68474 .41249 .68737 .40708 .68682 Metetra
.792 .713 0 r
.40708 .68682 .41249 .68737 .42125 .68957 .41586 .68882 Metetra
.81 .667 0 r
.41586 .68882 .42125 .68957 .43007 .69136 .42471 .69042 Metetra
.826 .623 0 r
.42471 .69042 .43007 .69136 .43895 .69276 .43362 .69164 Metetra
.841 .581 0 r
.43362 .69164 .43895 .69276 .44789 .69379 .44259 .6925 Metetra
.854 .541 0 r
.44259 .6925 .44789 .69379 .45688 .69449 .45161 .69303 Metetra
.866 .504 0 r
.45161 .69303 .45688 .69449 .46593 .69488 .46068 .69325 Metetra
.876 .47 0 r
.46068 .69325 .46593 .69488 .47503 .69497 .46981 .69319 Metetra
.886 .438 0 r
.46981 .69319 .47503 .69497 .48417 .69479 .47898 .69286 Metetra
.894 .409 0 r
.47898 .69286 .48417 .69479 .49336 .69435 .48819 .69228 Metetra
.902 .383 0 r
.48819 .69228 .49336 .69435 .5026 .69368 .49745 .69148 Metetra
.909 .359 0 r
.49745 .69148 .5026 .69368 .51187 .69279 .50675 .69047 Metetra
.915 .338 0 r
.50675 .69047 .51187 .69279 .52119 .6917 .51609 .68926 Metetra
.92 .318 0 r
.51609 .68926 .52119 .6917 .53054 .69042 .52547 .68787 Metetra
.925 .301 0 r
.52547 .68787 .53054 .69042 .53994 .68897 .53489 .68632 Metetra
.929 .287 0 r
.53489 .68632 .53994 .68897 .54937 .68736 .54435 .68462 Metetra
.932 .274 0 r
.54435 .68462 .54937 .68736 .55884 .68561 .55384 .68278 Metetra
.935 .263 0 r
.55384 .68278 .55884 .68561 .56834 .68371 .56337 .68081 Metetra
.938 .253 0 r
.56337 .68081 .56834 .68371 .57788 .68168 .57294 .67871 Metetra
.94 .246 0 r
.57294 .67871 .57788 .68168 .58745 .67953 .58253 .67651 Metetra
.941 .239 0 r
.58253 .67651 .58745 .67953 .59706 .67727 .59217 .67419 Metetra
.943 .235 0 r
.59217 .67419 .59706 .67727 .60669 .6749 .60183 .67178 Metetra
.943 .231 0 r
.60183 .67178 .60669 .6749 .61637 .67241 .61153 .66926 Metetra
.944 .229 0 r
.61153 .66926 .61637 .67241 .62607 .66983 .62126 .66665 Metetra
.944 .229 0 r
.62126 .66665 .62607 .66983 .6358 .66714 .63102 .66395 Metetra
.944 .229 0 r
.63102 .66395 .6358 .66714 .64557 .66434 .64081 .66115 Metetra
.943 .231 0 r
.64081 .66115 .64557 .66434 .65536 .66144 .65064 .65825 Metetra
.943 .235 0 r
.65064 .65825 .65536 .66144 .66519 .65844 .66049 .65525 Metetra
.941 .239 0 r
.66049 .65525 .66519 .65844 .67504 .65531 .67038 .65215 Metetra
.94 .246 0 r
.67038 .65215 .67504 .65531 .68492 .65207 .68029 .64893 Metetra
.938 .253 0 r
.68029 .64893 .68492 .65207 .69482 .64871 .69023 .6456 Metetra
.935 .263 0 r
.69023 .6456 .69482 .64871 .70475 .64521 .70019 .64215 Metetra
.932 .274 0 r
.70019 .64215 .70475 .64521 .71471 .64156 .71018 .63856 Metetra
.929 .287 0 r
.71018 .63856 .71471 .64156 .72468 .63776 .72019 .63482 Metetra
.925 .301 0 r
.72019 .63482 .72468 .63776 .73468 .63379 .73023 .63093 Metetra
.92 .318 0 r
.73023 .63093 .73468 .63379 .74469 .62964 .74028 .62686 Metetra
.915 .338 0 r
.74028 .62686 .74469 .62964 .75472 .6253 .75035 .6226 Metetra
.909 .359 0 r
.75035 .6226 .75472 .6253 .76476 .62074 .76043 .61813 Metetra
.902 .383 0 r
.76043 .61813 .76476 .62074 .77481 .61594 .77053 .61345 Metetra
.894 .409 0 r
.77053 .61345 .77481 .61594 .78487 .6109 .78063 .60852 Metetra
.886 .438 0 r
.78063 .60852 .78487 .6109 .79493 .60559 .79074 .60333 Metetra
.876 .47 0 r
.79074 .60333 .79493 .60559 .80499 .59998 .80085 .59785 Metetra
.866 .504 0 r
.80085 .59785 .80499 .59998 .81504 .59406 .81095 .59207 Metetra
.854 .541 0 r
.81095 .59207 .81504 .59406 .82508 .5878 .82105 .58595 Metetra
.841 .581 0 r
.82105 .58595 .82508 .5878 .8351 .58117 .83113 .57948 Metetra
.826 .623 0 r
.83113 .57948 .8351 .58117 .8451 .57415 .84119 .57262 Metetra
.81 .667 0 r
.84119 .57262 .8451 .57415 .85508 .56671 .85122 .56535 Metetra
.792 .713 0 r
.85122 .56535 .85508 .56671 .86502 .55883 .86123 .55764 Metetra
.773 .761 0 r
.86123 .55764 .86502 .55883 .87491 .55047 .87119 .54946 Metetra
.694 .752 0 r
.87119 .54946 .87491 .55047 .88476 .5416 .88111 .54078 Metetra
.599 .728 0 r
.88111 .54078 .88476 .5416 .89455 .53219 .89097 .53157 Metetra
.501 .703 0 r
.89097 .53157 .89455 .53219 .90427 .52222 .90076 .52179 Metetra
.4 .675 0 r
.90076 .52179 .90427 .52222 .91391 .51164 .91049 .51142 Metetra
.299 .645 0 r
.91049 .51142 .91391 .51164 .92347 .50044 .92013 .50043 Metetra
.197 .613 0 r
.92013 .50043 .92347 .50044 .93293 .48857 .92967 .48877 Metetra
.097 .577 0 r
.92967 .48877 .93293 .48857 .94229 .476 .93911 .47642 Metetra
.16 .6 0 r
.33394 .65369 .3396 .65294 .34772 .65917 .34209 .6597 Metetra
.264 .634 0 r
.34209 .6597 .34772 .65917 .35594 .66478 .35034 .66509 Metetra
.368 .666 0 r
.35034 .66509 .35594 .66478 .36425 .66979 .35868 .66988 Metetra
.472 .695 0 r
.35868 .66988 .36425 .66979 .37266 .67422 .36711 .6741 Metetra
.573 .722 0 r
.36711 .6741 .37266 .67422 .38115 .67811 .37563 .67778 Metetra
.672 .746 0 r
.37563 .67778 .38115 .67811 .38972 .68149 .38422 .68096 Metetra
.767 .769 0 r
.38422 .68096 .38972 .68149 .39836 .68439 .3929 .68365 Metetra
.789 .721 0 r
.3929 .68365 .39836 .68439 .40708 .68682 .40164 .68589 Metetra
.808 .673 0 r
.40164 .68589 .40708 .68682 .41586 .68882 .41045 .68771 Metetra
.825 .627 0 r
.41045 .68771 .41586 .68882 .42471 .69042 .41933 .68913 Metetra
.84 .583 0 r
.41933 .68913 .42471 .69042 .43362 .69164 .42826 .69017 Metetra
.854 .541 0 r
.42826 .69017 .43362 .69164 .44259 .6925 .43725 .69086 Metetra
.866 .502 0 r
.43725 .69086 .44259 .6925 .45161 .69303 .4463 .69123 Metetra
.877 .466 0 r
.4463 .69123 .45161 .69303 .46068 .69325 .4554 .6913 Metetra
.888 .432 0 r
.4554 .6913 .46068 .69325 .46981 .69319 .46455 .69108 Metetra
.897 .402 0 r
.46455 .69108 .46981 .69319 .47898 .69286 .47374 .69061 Metetra
.905 .374 0 r
.47374 .69061 .47898 .69286 .48819 .69228 .48298 .6899 Metetra
.912 .349 0 r
.48298 .6899 .48819 .69228 .49745 .69148 .49227 .68897 Metetra
.918 .326 0 r
.49227 .68897 .49745 .69148 .50675 .69047 .50159 .68783 Metetra
.924 .305 0 r
.50159 .68783 .50675 .69047 .51609 .68926 .51096 .68651 Metetra
.929 .287 0 r
.51096 .68651 .51609 .68926 .52547 .68787 .52037 .68502 Metetra
.933 .272 0 r
.52037 .68502 .52547 .68787 .53489 .68632 .52981 .68338 Metetra
.937 .258 0 r
.52981 .68338 .53489 .68632 .54435 .68462 .53929 .68159 Metetra
.94 .246 0 r
.53929 .68159 .54435 .68462 .55384 .68278 .54881 .67966 Metetra
.942 .235 0 r
.54881 .67966 .55384 .68278 .56337 .68081 .55836 .67762 Metetra
.945 .227 0 r
.55836 .67762 .56337 .68081 .57294 .67871 .56795 .67546 Metetra
.947 .219 0 r
.56795 .67546 .57294 .67871 .58253 .67651 .57758 .6732 Metetra
.948 .214 0 r
.57758 .6732 .58253 .67651 .59217 .67419 .58723 .67083 Metetra
.949 .209 0 r
.58723 .67083 .59217 .67419 .60183 .67178 .59692 .66838 Metetra
.95 .206 0 r
.59692 .66838 .60183 .67178 .61153 .66926 .60665 .66583 Metetra
.95 .204 0 r
.60665 .66583 .61153 .66926 .62126 .66665 .61641 .66319 Metetra
.951 .204 0 r
.61641 .66319 .62126 .66665 .63102 .66395 .6262 .66047 Metetra
.95 .204 0 r
.6262 .66047 .63102 .66395 .64081 .66115 .63602 .65766 Metetra
.95 .206 0 r
.63602 .65766 .64081 .66115 .65064 .65825 .64587 .65477 Metetra
.949 .209 0 r
.64587 .65477 .65064 .65825 .66049 .65525 .65575 .65178 Metetra
.948 .214 0 r
.65575 .65178 .66049 .65525 .67038 .65215 .66567 .64869 Metetra
.947 .219 0 r
.66567 .64869 .67038 .65215 .68029 .64893 .67561 .64551 Metetra
.945 .227 0 r
.67561 .64551 .68029 .64893 .69023 .6456 .68558 .64221 Metetra
.942 .235 0 r
.68558 .64221 .69023 .6456 .70019 .64215 .69558 .6388 Metetra
.94 .246 0 r
.69558 .6388 .70019 .64215 .71018 .63856 .7056 .63526 Metetra
.937 .258 0 r
.7056 .63526 .71018 .63856 .72019 .63482 .71565 .63158 Metetra
.933 .272 0 r
.71565 .63158 .72019 .63482 .73023 .63093 .72572 .62775 Metetra
.929 .287 0 r
.72572 .62775 .73023 .63093 .74028 .62686 .73581 .62376 Metetra
.924 .305 0 r
.73581 .62376 .74028 .62686 .75035 .6226 .74592 .61958 Metetra
.918 .326 0 r
.74592 .61958 .75035 .6226 .76043 .61813 .75605 .61521 Metetra
.912 .349 0 r
.75605 .61521 .76043 .61813 .77053 .61345 .76618 .61062 Metetra
.905 .374 0 r
.76618 .61062 .77053 .61345 .78063 .60852 .77633 .6058 Metetra
.897 .402 0 r
.77633 .6058 .78063 .60852 .79074 .60333 .78649 .60073 Metetra
.888 .432 0 r
.78649 .60073 .79074 .60333 .80085 .59785 .79665 .59537 Metetra
.877 .466 0 r
.79665 .59537 .80085 .59785 .81095 .59207 .8068 .58972 Metetra
.866 .502 0 r
.8068 .58972 .81095 .59207 .82105 .58595 .81695 .58374 Metetra
.854 .541 0 r
.81695 .58374 .82105 .58595 .83113 .57948 .82709 .57741 Metetra
.84 .583 0 r
.82709 .57741 .83113 .57948 .84119 .57262 .83721 .57071 Metetra
.825 .627 0 r
.83721 .57071 .84119 .57262 .85122 .56535 .8473 .5636 Metetra
.808 .673 0 r
.8473 .5636 .85122 .56535 .86123 .55764 .85737 .55605 Metetra
.789 .721 0 r
.85737 .55605 .86123 .55764 .87119 .54946 .8674 .54805 Metetra
.767 .769 0 r
.8674 .54805 .87119 .54946 .88111 .54078 .87738 .53954 Metetra
.672 .746 0 r
.87738 .53954 .88111 .54078 .89097 .53157 .88731 .53052 Metetra
.573 .722 0 r
.88731 .53052 .89097 .53157 .90076 .52179 .89718 .52093 Metetra
.472 .695 0 r
.89718 .52093 .90076 .52179 .91049 .51142 .90698 .51076 Metetra
.368 .666 0 r
.90698 .51076 .91049 .51142 .92013 .50043 .91669 .49996 Metetra
.264 .634 0 r
.91669 .49996 .92013 .50043 .92967 .48877 .92632 .4885 Metetra
.16 .6 0 r
.92632 .4885 .92967 .48877 .93911 .47642 .93585 .47636 Metetra
.222 .621 0 r
.32826 .65401 .33394 .65369 .34209 .6597 .33643 .65981 Metetra
.329 .654 0 r
.33643 .65981 .34209 .6597 .35034 .66509 .3447 .66499 Metetra
.435 .685 0 r
.3447 .66499 .35034 .66509 .35868 .66988 .35307 .66957 Metetra
.54 .713 0 r
.35307 .66957 .35868 .66988 .36711 .6741 .36153 .67359 Metetra
.642 .739 0 r
.36153 .67359 .36711 .6741 .37563 .67778 .37007 .67707 Metetra
.741 .763 0 r
.37007 .67707 .37563 .67778 .38422 .68096 .3787 .68005 Metetra
.784 .734 0 r
.3787 .68005 .38422 .68096 .3929 .68365 .3874 .68256 Metetra
.804 .684 0 r
.3874 .68256 .3929 .68365 .40164 .68589 .39617 .68461 Metetra
.822 .635 0 r
.39617 .68461 .40164 .68589 .41045 .68771 .405 .68625 Metetra
.838 .589 0 r
.405 .68625 .41045 .68771 .41933 .68913 .4139 .68749 Metetra
.852 .545 0 r
.4139 .68749 .41933 .68913 .42826 .69017 .42287 .68836 Metetra
.866 .504 0 r
.42287 .68836 .42826 .69017 .43725 .69086 .43188 .6889 Metetra
.877 .466 0 r
.43188 .6889 .43725 .69086 .4463 .69123 .44096 .68911 Metetra
.888 .431 0 r
.44096 .68911 .4463 .69123 .4554 .6913 .45008 .68902 Metetra
.898 .398 0 r
.45008 .68902 .4554 .6913 .46455 .69108 .45925 .68867 Metetra
.906 .369 0 r
.45925 .68867 .46455 .69108 .47374 .69061 .46847 .68806 Metetra
.914 .342 0 r
.46847 .68806 .47374 .69061 .48298 .6899 .47774 .68722 Metetra
.92 .318 0 r
.47774 .68722 .48298 .6899 .49227 .68897 .48705 .68617 Metetra
.926 .296 0 r
.48705 .68617 .49227 .68897 .50159 .68783 .4964 .68492 Metetra
.931 .277 0 r
.4964 .68492 .50159 .68783 .51096 .68651 .50579 .68349 Metetra
.936 .26 0 r
.50579 .68349 .51096 .68651 .52037 .68502 .51522 .6819 Metetra
.94 .245 0 r
.51522 .6819 .52037 .68502 .52981 .68338 .52469 .68016 Metetra
.943 .232 0 r
.52469 .68016 .52981 .68338 .53929 .68159 .5342 .67828 Metetra
.946 .221 0 r
.5342 .67828 .53929 .68159 .54881 .67966 .54374 .67628 Metetra
.949 .211 0 r
.54374 .67628 .54881 .67966 .55836 .67762 .55332 .67417 Metetra
.951 .203 0 r
.55332 .67417 .55836 .67762 .56795 .67546 .56293 .67194 Metetra
.952 .197 0 r
.56293 .67194 .56795 .67546 .57758 .6732 .57258 .66962 Metetra
.954 .191 0 r
.57258 .66962 .57758 .6732 .58723 .67083 .58226 .66721 Metetra
.955 .187 0 r
.58226 .66721 .58723 .67083 .59692 .66838 .59198 .66472 Metetra
.955 .185 0 r
.59198 .66472 .59692 .66838 .60665 .66583 .60173 .66214 Metetra
.956 .183 0 r
.60173 .66214 .60665 .66583 .61641 .66319 .61151 .65948 Metetra
.956 .182 0 r
.61151 .65948 .61641 .66319 .6262 .66047 .62133 .65674 Metetra
.956 .183 0 r
.62133 .65674 .6262 .66047 .63602 .65766 .63118 .65392 Metetra
.955 .185 0 r
.63118 .65392 .63602 .65766 .64587 .65477 .64106 .65103 Metetra
.955 .187 0 r
.64106 .65103 .64587 .65477 .65575 .65178 .65097 .64804 Metetra
.954 .191 0 r
.65097 .64804 .65575 .65178 .66567 .64869 .66091 .64497 Metetra
.952 .197 0 r
.66091 .64497 .66567 .64869 .67561 .64551 .67089 .64181 Metetra
.951 .203 0 r
.67089 .64181 .67561 .64551 .68558 .64221 .68089 .63855 Metetra
.949 .211 0 r
.68089 .63855 .68558 .64221 .69558 .6388 .69092 .63517 Metetra
.946 .221 0 r
.69092 .63517 .69558 .6388 .7056 .63526 .70098 .63168 Metetra
.943 .232 0 r
.70098 .63168 .7056 .63526 .71565 .63158 .71106 .62806 Metetra
.94 .245 0 r
.71106 .62806 .71565 .63158 .72572 .62775 .72116 .62429 Metetra
.936 .26 0 r
.72116 .62429 .72572 .62775 .73581 .62376 .73129 .62037 Metetra
.931 .277 0 r
.73129 .62037 .73581 .62376 .74592 .61958 .74144 .61627 Metetra
.926 .296 0 r
.74144 .61627 .74592 .61958 .75605 .61521 .75161 .61198 Metetra
.92 .318 0 r
.75161 .61198 .75605 .61521 .76618 .61062 .76179 .60749 Metetra
.914 .342 0 r
.76179 .60749 .76618 .61062 .77633 .6058 .77198 .60277 Metetra
.906 .369 0 r
.77198 .60277 .77633 .6058 .78649 .60073 .78218 .5978 Metetra
.898 .398 0 r
.78218 .5978 .78649 .60073 .79665 .59537 .79239 .59257 Metetra
.888 .431 0 r
.79239 .59257 .79665 .59537 .8068 .58972 .80259 .58704 Metetra
.877 .466 0 r
.80259 .58704 .8068 .58972 .81695 .58374 .81279 .58119 Metetra
.866 .504 0 r
.81279 .58119 .81695 .58374 .82709 .57741 .82298 .575 Metetra
.852 .545 0 r
.82298 .575 .82709 .57741 .83721 .57071 .83316 .56844 Metetra
.838 .589 0 r
.83316 .56844 .83721 .57071 .8473 .5636 .84331 .56148 Metetra
.822 .635 0 r
.84331 .56148 .8473 .5636 .85737 .55605 .85344 .55409 Metetra
.804 .684 0 r
.85344 .55409 .85737 .55605 .8674 .54805 .86353 .54625 Metetra
.784 .734 0 r
.86353 .54625 .8674 .54805 .87738 .53954 .87358 .53791 Metetra
.741 .763 0 r
.87358 .53791 .87738 .53954 .88731 .53052 .88358 .52906 Metetra
.642 .739 0 r
.88358 .52906 .88731 .53052 .89718 .52093 .89352 .51966 Metetra
.54 .713 0 r
.89352 .51966 .89718 .52093 .90698 .51076 .90339 .50966 Metetra
.435 .685 0 r
.90339 .50966 .90698 .51076 .91669 .49996 .91318 .49905 Metetra
.329 .654 0 r
.91318 .49905 .91669 .49996 .92632 .4885 .92289 .48779 Metetra
.222 .621 0 r
.92289 .48779 .92632 .4885 .93585 .47636 .93249 .47584 Metetra
.283 .64 0 r
.32255 .65393 .32826 .65401 .33643 .65981 .33074 .65953 Metetra
.391 .673 0 r
.33074 .65953 .33643 .65981 .3447 .66499 .33904 .6645 Metetra
.499 .702 0 r
.33904 .6645 .3447 .66499 .35307 .66957 .34744 .66888 Metetra
.605 .73 0 r
.34744 .66888 .35307 .66957 .36153 .67359 .35592 .67271 Metetra
.707 .755 0 r
.35592 .67271 .36153 .67359 .37007 .67707 .36449 .676 Metetra
.777 .75 0 r
.36449 .676 .37007 .67707 .3787 .68005 .37314 .6788 Metetra
.798 .698 0 r
.37314 .6788 .3787 .68005 .3874 .68256 .38186 .68112 Metetra
.817 .648 0 r
.38186 .68112 .3874 .68256 .39617 .68461 .39066 .683 Metetra
.834 .599 0 r
.39066 .683 .39617 .68461 .405 .68625 .39952 .68446 Metetra
.85 .553 0 r
.39952 .68446 .405 .68625 .4139 .68749 .40845 .68554 Metetra
.864 .51 0 r
.40845 .68554 .4139 .68749 .42287 .68836 .41744 .68625 Metetra
.876 .47 0 r
.41744 .68625 .42287 .68836 .43188 .6889 .42648 .68663 Metetra
.888 .433 0 r
.42648 .68663 .43188 .6889 .44096 .68911 .43558 .68669 Metetra
.898 .398 0 r
.43558 .68669 .44096 .68911 .45008 .68902 .44473 .68646 Metetra
.907 .367 0 r
.44473 .68646 .45008 .68902 .45925 .68867 .45392 .68597 Metetra
.915 .338 0 r
.45392 .68597 .45925 .68867 .46847 .68806 .46317 .68523 Metetra
.922 .313 0 r
.46317 .68523 .46847 .68806 .47774 .68722 .47246 .68427 Metetra
.928 .29 0 r
.47246 .68427 .47774 .68722 .48705 .68617 .48179 .6831 Metetra
.933 .269 0 r
.48179 .6831 .48705 .68617 .4964 .68492 .49117 .68174 Metetra
.938 .251 0 r
.49117 .68174 .4964 .68492 .50579 .68349 .50058 .68021 Metetra
.942 .235 0 r
.50058 .68021 .50579 .68349 .51522 .6819 .51004 .67852 Metetra
.946 .221 0 r
.51004 .67852 .51522 .6819 .52469 .68016 .51953 .67669 Metetra
.949 .209 0 r
.51953 .67669 .52469 .68016 .5342 .67828 .52906 .67473 Metetra
.952 .199 0 r
.52906 .67473 .5342 .67828 .54374 .67628 .53863 .67265 Metetra
.954 .19 0 r
.53863 .67265 .54374 .67628 .55332 .67417 .54823 .67047 Metetra
.956 .183 0 r
.54823 .67047 .55332 .67417 .56293 .67194 .55787 .66819 Metetra
.957 .177 0 r
.55787 .66819 .56293 .67194 .57258 .66962 .56754 .66581 Metetra
.959 .172 0 r
.56754 .66581 .57258 .66962 .58226 .66721 .57725 .66336 Metetra
.959 .169 0 r
.57725 .66336 .58226 .66721 .59198 .66472 .58699 .66082 Metetra
.96 .166 0 r
.58699 .66082 .59198 .66472 .60173 .66214 .59677 .65821 Metetra
.96 .165 0 r
.59677 .65821 .60173 .66214 .61151 .65948 .60658 .65553 Metetra
.961 .164 0 r
.60658 .65553 .61151 .65948 .62133 .65674 .61642 .65277 Metetra
.96 .165 0 r
.61642 .65277 .62133 .65674 .63118 .65392 .62629 .64995 Metetra
.96 .166 0 r
.62629 .64995 .63118 .65392 .64106 .65103 .6362 .64705 Metetra
.959 .169 0 r
.6362 .64705 .64106 .65103 .65097 .64804 .64614 .64407 Metetra
.959 .172 0 r
.64614 .64407 .65097 .64804 .66091 .64497 .65612 .64101 Metetra
.957 .177 0 r
.65612 .64101 .66091 .64497 .67089 .64181 .66612 .63787 Metetra
.956 .183 0 r
.66612 .63787 .67089 .64181 .68089 .63855 .67615 .63463 Metetra
.954 .19 0 r
.67615 .63463 .68089 .63855 .69092 .63517 .68621 .6313 Metetra
.952 .199 0 r
.68621 .6313 .69092 .63517 .70098 .63168 .6963 .62785 Metetra
.949 .209 0 r
.6963 .62785 .70098 .63168 .71106 .62806 .70642 .62427 Metetra
.946 .221 0 r
.70642 .62427 .71106 .62806 .72116 .62429 .71656 .62057 Metetra
.942 .235 0 r
.71656 .62057 .72116 .62429 .73129 .62037 .72673 .61671 Metetra
.938 .251 0 r
.72673 .61671 .73129 .62037 .74144 .61627 .73691 .61268 Metetra
.933 .269 0 r
.73691 .61268 .74144 .61627 .75161 .61198 .74712 .60848 Metetra
.928 .29 0 r
.74712 .60848 .75161 .61198 .76179 .60749 .75734 .60407 Metetra
.922 .313 0 r
.75734 .60407 .76179 .60749 .77198 .60277 .76757 .59945 Metetra
.915 .338 0 r
.76757 .59945 .77198 .60277 .78218 .5978 .77782 .59459 Metetra
.907 .367 0 r
.77782 .59459 .78218 .5978 .79239 .59257 .78807 .58946 Metetra
.898 .398 0 r
.78807 .58946 .79239 .59257 .80259 .58704 .79832 .58404 Metetra
.888 .433 0 r
.79832 .58404 .80259 .58704 .81279 .58119 .80857 .57832 Metetra
.876 .47 0 r
.80857 .57832 .81279 .58119 .82298 .575 .81881 .57226 Metetra
.864 .51 0 r
.81881 .57226 .82298 .575 .83316 .56844 .82904 .56583 Metetra
.85 .553 0 r
.82904 .56583 .83316 .56844 .84331 .56148 .83925 .55901 Metetra
.834 .599 0 r
.83925 .55901 .84331 .56148 .85344 .55409 .84944 .55178 Metetra
.817 .648 0 r
.84944 .55178 .85344 .55409 .86353 .54625 .85959 .54408 Metetra
.798 .698 0 r
.85959 .54408 .86353 .54625 .87358 .53791 .8697 .53591 Metetra
.777 .75 0 r
.8697 .53591 .87358 .53791 .88358 .52906 .87977 .52722 Metetra
.707 .755 0 r
.87977 .52722 .88358 .52906 .89352 .51966 .88978 .51799 Metetra
.605 .73 0 r
.88978 .51799 .89352 .51966 .90339 .50966 .89972 .50817 Metetra
.499 .702 0 r
.89972 .50817 .90339 .50966 .91318 .49905 .90958 .49774 Metetra
.391 .673 0 r
.90958 .49774 .91318 .49905 .92289 .48779 .91937 .48666 Metetra
.283 .64 0 r
.91937 .48666 .92289 .48779 .93249 .47584 .92905 .47489 Metetra
.341 .658 0 r
.31681 .65346 .32255 .65393 .33074 .65953 .32503 .65886 Metetra
.451 .69 0 r
.32503 .65886 .33074 .65953 .33904 .6645 .33335 .66365 Metetra
.56 .718 0 r
.33335 .66365 .33904 .6645 .34744 .66888 .34177 .66784 Metetra
.666 .745 0 r
.34177 .66784 .34744 .66888 .35592 .67271 .35028 .67148 Metetra
.768 .769 0 r
.35028 .67148 .35592 .67271 .36449 .676 .35888 .67459 Metetra
.791 .716 0 r
.35888 .67459 .36449 .676 .37314 .6788 .36755 .67721 Metetra
.811 .664 0 r
.36755 .67721 .37314 .6788 .38186 .68112 .3763 .67936 Metetra
.829 .614 0 r
.3763 .67936 .38186 .68112 .39066 .683 .38512 .68107 Metetra
.846 .566 0 r
.38512 .68107 .39066 .683 .39952 .68446 .39401 .68237 Metetra
.861 .52 0 r
.39401 .68237 .39952 .68446 .40845 .68554 .40296 .68329 Metetra
.874 .478 0 r
.40296 .68329 .40845 .68554 .41744 .68625 .41197 .68385 Metetra
.886 .438 0 r
.41197 .68385 .41744 .68625 .42648 .68663 .42104 .68408 Metetra
.897 .402 0 r
.42104 .68408 .42648 .68663 .43558 .68669 .43016 .684 Metetra
.906 .369 0 r
.43016 .684 .43558 .68669 .44473 .68646 .43934 .68363 Metetra
.915 .338 0 r
.43934 .68363 .44473 .68646 .45392 .68597 .44856 .68301 Metetra
.922 .311 0 r
.44856 .68301 .45392 .68597 .46317 .68523 .45783 .68215 Metetra
.929 .287 0 r
.45783 .68215 .46317 .68523 .47246 .68427 .46714 .68107 Metetra
.935 .265 0 r
.46714 .68107 .47246 .68427 .48179 .6831 .4765 .67978 Metetra
.94 .246 0 r
.4765 .67978 .48179 .6831 .49117 .68174 .4859 .67832 Metetra
.944 .229 0 r
.4859 .67832 .49117 .68174 .50058 .68021 .49534 .67669 Metetra
.948 .214 0 r
.49534 .67669 .50058 .68021 .51004 .67852 .50482 .67491 Metetra
.951 .201 0 r
.50482 .67491 .51004 .67852 .51953 .67669 .51434 .67299 Metetra
.954 .19 0 r
.51434 .67299 .51953 .67669 .52906 .67473 .52389 .67095 Metetra
.957 .18 0 r
.52389 .67095 .52906 .67473 .53863 .67265 .53348 .6688 Metetra
.959 .172 0 r
.53348 .6688 .53863 .67265 .54823 .67047 .54311 .66655 Metetra
.96 .166 0 r
.54311 .66655 .54823 .67047 .55787 .66819 .55277 .66421 Metetra
.962 .16 0 r
.55277 .66421 .55787 .66819 .56754 .66581 .56247 .66179 Metetra
.963 .156 0 r
.56247 .66179 .56754 .66581 .57725 .66336 .5722 .65929 Metetra
.963 .153 0 r
.5722 .65929 .57725 .66336 .58699 .66082 .58197 .65671 Metetra
.964 .15 0 r
.58197 .65671 .58699 .66082 .59677 .65821 .59177 .65407 Metetra
.964 .149 0 r
.59177 .65407 .59677 .65821 .60658 .65553 .6016 .65136 Metetra
.964 .149 0 r
.6016 .65136 .60658 .65553 .61642 .65277 .61147 .64859 Metetra
.964 .149 0 r
.61147 .64859 .61642 .65277 .62629 .64995 .62137 .64575 Metetra
.964 .15 0 r
.62137 .64575 .62629 .64995 .6362 .64705 .63131 .64285 Metetra
.963 .153 0 r
.63131 .64285 .6362 .64705 .64614 .64407 .64128 .63988 Metetra
.963 .156 0 r
.64128 .63988 .64614 .64407 .65612 .64101 .65128 .63683 Metetra
.962 .16 0 r
.65128 .63683 .65612 .64101 .66612 .63787 .66131 .63371 Metetra
.96 .166 0 r
.66131 .63371 .66612 .63787 .67615 .63463 .67137 .6305 Metetra
.959 .172 0 r
.67137 .6305 .67615 .63463 .68621 .6313 .68146 .62719 Metetra
.957 .18 0 r
.68146 .62719 .68621 .6313 .6963 .62785 .69159 .62378 Metetra
.954 .19 0 r
.69159 .62378 .6963 .62785 .70642 .62427 .70174 .62026 Metetra
.951 .201 0 r
.70174 .62026 .70642 .62427 .71656 .62057 .71191 .6166 Metetra
.948 .214 0 r
.71191 .6166 .71656 .62057 .72673 .61671 .72211 .6128 Metetra
.944 .229 0 r
.72211 .6128 .72673 .61671 .73691 .61268 .73233 .60885 Metetra
.94 .246 0 r
.73233 .60885 .73691 .61268 .74712 .60848 .74258 .60472 Metetra
.935 .265 0 r
.74258 .60472 .74712 .60848 .75734 .60407 .75284 .6004 Metetra
.929 .287 0 r
.75284 .6004 .75734 .60407 .76757 .59945 .76312 .59586 Metetra
.922 .311 0 r
.76312 .59586 .76757 .59945 .77782 .59459 .7734 .59109 Metetra
.915 .338 0 r
.7734 .59109 .77782 .59459 .78807 .58946 .7837 .58606 Metetra
.906 .369 0 r
.7837 .58606 .78807 .58946 .79832 .58404 .794 .58076 Metetra
.897 .402 0 r
.794 .58076 .79832 .58404 .80857 .57832 .80429 .57515 Metetra
.886 .438 0 r
.80429 .57515 .80857 .57832 .81881 .57226 .81459 .56921 Metetra
.874 .478 0 r
.81459 .56921 .81881 .57226 .82904 .56583 .82487 .56291 Metetra
.861 .52 0 r
.82487 .56291 .82904 .56583 .83925 .55901 .83513 .55622 Metetra
.846 .566 0 r
.83513 .55622 .83925 .55901 .84944 .55178 .84538 .54912 Metetra
.829 .614 0 r
.84538 .54912 .84944 .55178 .85959 .54408 .85559 .54158 Metetra
.811 .664 0 r
.85559 .54158 .85959 .54408 .8697 .53591 .86576 .53355 Metetra
.791 .716 0 r
.86576 .53355 .8697 .53591 .87977 .52722 .87589 .52502 Metetra
.768 .769 0 r
.87589 .52502 .87977 .52722 .88978 .51799 .88596 .51594 Metetra
.666 .745 0 r
.88596 .51594 .88978 .51799 .89972 .50817 .89597 .50629 Metetra
.56 .718 0 r
.89597 .50629 .89972 .50817 .90958 .49774 .90591 .49602 Metetra
.451 .69 0 r
.90591 .49602 .90958 .49774 .91937 .48666 .91576 .48511 Metetra
.341 .658 0 r
.91576 .48511 .91937 .48666 .92905 .47489 .92552 .47352 Metetra
.397 .674 0 r
.31104 .65262 .31681 .65346 .32503 .65886 .31929 .65784 Metetra
.508 .705 0 r
.31929 .65784 .32503 .65886 .33335 .66365 .32764 .66244 Metetra
.618 .733 0 r
.32764 .66244 .33335 .66365 .34177 .66784 .33608 .66646 Metetra
.724 .759 0 r
.33608 .66646 .34177 .66784 .35028 .67148 .34461 .66992 Metetra
.782 .739 0 r
.34461 .66992 .35028 .67148 .35888 .67459 .35323 .67286 Metetra
.803 .685 0 r
.35323 .67286 .35888 .67459 .36755 .67721 .36193 .67531 Metetra
.823 .632 0 r
.36193 .67531 .36755 .67721 .3763 .67936 .37071 .67729 Metetra
.84 .582 0 r
.37071 .67729 .3763 .67936 .38512 .68107 .37955 .67885 Metetra
.856 .534 0 r
.37955 .67885 .38512 .68107 .39401 .68237 .38846 .67999 Metetra
.87 .489 0 r
.38846 .67999 .39401 .68237 .40296 .68329 .39744 .68076 Metetra
.883 .448 0 r
.39744 .68076 .40296 .68329 .41197 .68385 .40648 .68117 Metetra
.894 .409 0 r
.40648 .68117 .41197 .68385 .42104 .68408 .41557 .68126 Metetra
.905 .374 0 r
.41557 .68126 .42104 .68408 .43016 .684 .42472 .68105 Metetra
.914 .342 0 r
.42472 .68105 .43016 .684 .43934 .68363 .43392 .68055 Metetra
.922 .313 0 r
.43392 .68055 .43934 .68363 .44856 .68301 .44316 .67981 Metetra
.929 .287 0 r
.44316 .67981 .44856 .68301 .45783 .68215 .45246 .67882 Metetra
.935 .263 0 r
.45246 .67882 .45783 .68215 .46714 .68107 .46179 .67763 Metetra
.94 .243 0 r
.46179 .67763 .46714 .68107 .4765 .67978 .47118 .67624 Metetra
.945 .225 0 r
.47118 .67624 .4765 .67978 .4859 .67832 .4806 .67468 Metetra
.949 .209 0 r
.4806 .67468 .4859 .67832 .49534 .67669 .49006 .67295 Metetra
.953 .195 0 r
.49006 .67295 .49534 .67669 .50482 .67491 .49956 .67108 Metetra
.956 .183 0 r
.49956 .67108 .50482 .67491 .51434 .67299 .5091 .66908 Metetra
.958 .173 0 r
.5091 .66908 .51434 .67299 .52389 .67095 .51868 .66697 Metetra
.961 .164 0 r
.51868 .66697 .52389 .67095 .53348 .6688 .5283 .66475 Metetra
.962 .157 0 r
.5283 .66475 .53348 .6688 .54311 .66655 .53795 .66244 Metetra
.964 .151 0 r
.53795 .66244 .54311 .66655 .55277 .66421 .54763 .66004 Metetra
.965 .146 0 r
.54763 .66004 .55277 .66421 .56247 .66179 .55735 .65757 Metetra
.966 .142 0 r
.55735 .65757 .56247 .66179 .5722 .65929 .56711 .65502 Metetra
.967 .139 0 r
.56711 .65502 .5722 .65929 .58197 .65671 .5769 .65241 Metetra
.967 .137 0 r
.5769 .65241 .58197 .65671 .59177 .65407 .58673 .64974 Metetra
.968 .136 0 r
.58673 .64974 .59177 .65407 .6016 .65136 .59659 .647 Metetra
.968 .136 0 r
.59659 .647 .6016 .65136 .61147 .64859 .60648 .64421 Metetra
.968 .136 0 r
.60648 .64421 .61147 .64859 .62137 .64575 .61641 .64137 Metetra
.967 .137 0 r
.61641 .64137 .62137 .64575 .63131 .64285 .62637 .63846 Metetra
.967 .139 0 r
.62637 .63846 .63131 .64285 .64128 .63988 .63637 .63549 Metetra
.966 .142 0 r
.63637 .63549 .64128 .63988 .65128 .63683 .6464 .63245 Metetra
.965 .146 0 r
.6464 .63245 .65128 .63683 .66131 .63371 .65646 .62935 Metetra
.964 .151 0 r
.65646 .62935 .66131 .63371 .67137 .6305 .66655 .62616 Metetra
.962 .157 0 r
.66655 .62616 .67137 .6305 .68146 .62719 .67667 .62288 Metetra
.961 .164 0 r
.67667 .62288 .68146 .62719 .69159 .62378 .68683 .61951 Metetra
.958 .173 0 r
.68683 .61951 .69159 .62378 .70174 .62026 .69701 .61602 Metetra
.956 .183 0 r
.69701 .61602 .70174 .62026 .71191 .6166 .70722 .61242 Metetra
.953 .195 0 r
.70722 .61242 .71191 .6166 .72211 .6128 .71745 .60868 Metetra
.949 .209 0 r
.71745 .60868 .72211 .6128 .73233 .60885 .72771 .60478 Metetra
.945 .225 0 r
.72771 .60478 .73233 .60885 .74258 .60472 .73799 .60072 Metetra
.94 .243 0 r
.73799 .60072 .74258 .60472 .75284 .6004 .74829 .59647 Metetra
.935 .263 0 r
.74829 .59647 .75284 .6004 .76312 .59586 .75861 .59202 Metetra
.929 .287 0 r
.75861 .59202 .76312 .59586 .7734 .59109 .76894 .58734 Metetra
.922 .313 0 r
.76894 .58734 .7734 .59109 .7837 .58606 .77927 .5824 Metetra
.914 .342 0 r
.77927 .5824 .7837 .58606 .794 .58076 .78962 .5772 Metetra
.905 .374 0 r
.78962 .5772 .794 .58076 .80429 .57515 .79996 .5717 Metetra
.894 .409 0 r
.79996 .5717 .80429 .57515 .81459 .56921 .8103 .56587 Metetra
.883 .448 0 r
.8103 .56587 .81459 .56921 .82487 .56291 .82064 .55969 Metetra
.87 .489 0 r
.82064 .55969 .82487 .56291 .83513 .55622 .83095 .55313 Metetra
.856 .534 0 r
.83095 .55313 .83513 .55622 .84538 .54912 .84125 .54615 Metetra
.84 .582 0 r
.84125 .54615 .84538 .54912 .85559 .54158 .85152 .53874 Metetra
.823 .632 0 r
.85152 .53874 .85559 .54158 .86576 .53355 .86175 .53086 Metetra
.803 .685 0 r
.86175 .53086 .86576 .53355 .87589 .52502 .87194 .52246 Metetra
.782 .739 0 r
.87194 .52246 .87589 .52502 .88596 .51594 .88208 .51354 Metetra
.724 .759 0 r
.88208 .51354 .88596 .51594 .89597 .50629 .89216 .50403 Metetra
.618 .733 0 r
.89216 .50403 .89597 .50629 .90591 .49602 .90216 .49393 Metetra
.508 .705 0 r
.90216 .49393 .90591 .49602 .91576 .48511 .91209 .48318 Metetra
.397 .674 0 r
.91209 .48318 .91576 .48511 .92552 .47352 .92192 .47175 Metetra
.449 .689 0 r
.30525 .65142 .31104 .65262 .31929 .65784 .31352 .65646 Metetra
.562 .719 0 r
.31352 .65646 .31929 .65784 .32764 .66244 .32189 .66089 Metetra
.672 .746 0 r
.32189 .66089 .32764 .66244 .33608 .66646 .33036 .66474 Metetra
.771 .765 0 r
.33036 .66474 .33608 .66646 .34461 .66992 .33892 .66804 Metetra
.794 .709 0 r
.33892 .66804 .34461 .66992 .35323 .67286 .34756 .67082 Metetra
.814 .655 0 r
.34756 .67082 .35323 .67286 .36193 .67531 .35628 .67311 Metetra
.833 .602 0 r
.35628 .67311 .36193 .67531 .37071 .67729 .36508 .67494 Metetra
.85 .552 0 r
.36508 .67494 .37071 .67729 .37955 .67885 .37395 .67634 Metetra
.865 .505 0 r
.37395 .67634 .37955 .67885 .38846 .67999 .38289 .67734 Metetra
.879 .461 0 r
.38289 .67734 .38846 .67999 .39744 .68076 .39189 .67796 Metetra
.891 .42 0 r
.39189 .67796 .39744 .68076 .40648 .68117 .40095 .67824 Metetra
.902 .383 0 r
.40095 .67824 .40648 .68117 .41557 .68126 .41007 .6782 Metetra
.912 .349 0 r
.41007 .6782 .41557 .68126 .42472 .68105 .41924 .67785 Metetra
.92 .318 0 r
.41924 .67785 .42472 .68105 .43392 .68055 .42846 .67724 Metetra
.928 .29 0 r
.42846 .67724 .43392 .68055 .44316 .67981 .43773 .67637 Metetra
.935 .265 0 r
.43773 .67637 .44316 .67981 .45246 .67882 .44705 .67528 Metetra
.94 .243 0 r
.44705 .67528 .45246 .67882 .46179 .67763 .45641 .67398 Metetra
.945 .223 0 r
.45641 .67398 .46179 .67763 .47118 .67624 .46581 .67249 Metetra
.95 .206 0 r
.46581 .67249 .47118 .67624 .4806 .67468 .47526 .67083 Metetra
.954 .191 0 r
.47526 .67083 .4806 .67468 .49006 .67295 .48475 .66902 Metetra
.957 .179 0 r
.48475 .66902 .49006 .67295 .49956 .67108 .49427 .66706 Metetra
.96 .168 0 r
.49427 .66706 .49956 .67108 .5091 .66908 .50384 .66499 Metetra
.962 .158 0 r
.50384 .66499 .5091 .66908 .51868 .66697 .51344 .6628 Metetra
.964 .15 0 r
.51344 .6628 .51868 .66697 .5283 .66475 .52308 .66051 Metetra
.966 .144 0 r
.52308 .66051 .5283 .66475 .53795 .66244 .53275 .65814 Metetra
.967 .138 0 r
.53275 .65814 .53795 .66244 .54763 .66004 .54246 .65569 Metetra
.968 .134 0 r
.54246 .65569 .54763 .66004 .55735 .65757 .55221 .65317 Metetra
.969 .131 0 r
.55221 .65317 .55735 .65757 .56711 .65502 .56199 .65058 Metetra
.969 .128 0 r
.56199 .65058 .56711 .65502 .5769 .65241 .5718 .64793 Metetra
.97 .126 0 r
.5718 .64793 .5769 .65241 .58673 .64974 .58165 .64523 Metetra
.97 .125 0 r
.58165 .64523 .58673 .64974 .59659 .647 .59154 .64247 Metetra
.97 .125 0 r
.59154 .64247 .59659 .647 .60648 .64421 .60146 .63966 Metetra
.97 .125 0 r
.60146 .63966 .60648 .64421 .61641 .64137 .61141 .63681 Metetra
.97 .126 0 r
.61141 .63681 .61641 .64137 .62637 .63846 .6214 .63389 Metetra
.969 .128 0 r
.6214 .63389 .62637 .63846 .63637 .63549 .63142 .63092 Metetra
.969 .131 0 r
.63142 .63092 .63637 .63549 .6464 .63245 .64148 .6279 Metetra
.968 .134 0 r
.64148 .6279 .6464 .63245 .65646 .62935 .65157 .6248 Metetra
.967 .138 0 r
.65157 .6248 .65646 .62935 .66655 .62616 .66169 .62163 Metetra
.966 .144 0 r
.66169 .62163 .66655 .62616 .67667 .62288 .67184 .61838 Metetra
.964 .15 0 r
.67184 .61838 .67667 .62288 .68683 .61951 .68202 .61504 Metetra
.962 .158 0 r
.68202 .61504 .68683 .61951 .69701 .61602 .69224 .61159 Metetra
.96 .168 0 r
.69224 .61159 .69701 .61602 .70722 .61242 .70248 .60803 Metetra
.957 .179 0 r
.70248 .60803 .70722 .61242 .71745 .60868 .71275 .60434 Metetra
.954 .191 0 r
.71275 .60434 .71745 .60868 .72771 .60478 .72304 .6005 Metetra
.95 .206 0 r
.72304 .6005 .72771 .60478 .73799 .60072 .73336 .5965 Metetra
.945 .223 0 r
.73336 .5965 .73799 .60072 .74829 .59647 .7437 .59233 Metetra
.94 .243 0 r
.7437 .59233 .74829 .59647 .75861 .59202 .75405 .58795 Metetra
.935 .265 0 r
.75405 .58795 .75861 .59202 .76894 .58734 .76442 .58334 Metetra
.928 .29 0 r
.76442 .58334 .76894 .58734 .77927 .5824 .7748 .5785 Metetra
.92 .318 0 r
.7748 .5785 .77927 .5824 .78962 .5772 .78519 .57339 Metetra
.912 .349 0 r
.78519 .57339 .78962 .5772 .79996 .5717 .79558 .56798 Metetra
.902 .383 0 r
.79558 .56798 .79996 .5717 .8103 .56587 .80597 .56226 Metetra
.891 .42 0 r
.80597 .56226 .8103 .56587 .82064 .55969 .81635 .55618 Metetra
.879 .461 0 r
.81635 .55618 .82064 .55969 .83095 .55313 .82672 .54974 Metetra
.865 .505 0 r
.82672 .54974 .83095 .55313 .84125 .54615 .83707 .54289 Metetra
.85 .552 0 r
.83707 .54289 .84125 .54615 .85152 .53874 .84739 .5356 Metetra
.833 .602 0 r
.84739 .5356 .85152 .53874 .86175 .53086 .85768 .52784 Metetra
.814 .655 0 r
.85768 .52784 .86175 .53086 .87194 .52246 .86793 .51958 Metetra
.794 .709 0 r
.86793 .51958 .87194 .52246 .88208 .51354 .87813 .51079 Metetra
.771 .765 0 r
.87813 .51079 .88208 .51354 .89216 .50403 .88827 .50143 Metetra
.672 .746 0 r
.88827 .50143 .89216 .50403 .90216 .49393 .89834 .49147 Metetra
.562 .719 0 r
.89834 .49147 .90216 .49393 .91209 .48318 .90833 .48086 Metetra
.449 .689 0 r
.90833 .48086 .91209 .48318 .92192 .47175 .91824 .46959 Metetra
.499 .702 0 r
.29944 .64988 .30525 .65142 .31352 .65646 .30773 .65476 Metetra
.612 .732 0 r
.30773 .65476 .31352 .65646 .32189 .66089 .31612 .65903 Metetra
.722 .758 0 r
.31612 .65903 .32189 .66089 .33036 .66474 .32461 .66272 Metetra
.782 .738 0 r
.32461 .66272 .33036 .66474 .33892 .66804 .33319 .66586 Metetra
.804 .682 0 r
.33319 .66586 .33892 .66804 .34756 .67082 .34186 .66849 Metetra
.824 .627 0 r
.34186 .66849 .34756 .67082 .35628 .67311 .3506 .67063 Metetra
.843 .575 0 r
.3506 .67063 .35628 .67311 .36508 .67494 .35942 .67231 Metetra
.859 .525 0 r
.35942 .67231 .36508 .67494 .37395 .67634 .36832 .67357 Metetra
.874 .479 0 r
.36832 .67357 .37395 .67634 .38289 .67734 .37728 .67443 Metetra
.887 .435 0 r
.37728 .67443 .38289 .67734 .39189 .67796 .3863 .67492 Metetra
.898 .396 0 r
.3863 .67492 .39189 .67796 .40095 .67824 .39539 .67507 Metetra
.909 .359 0 r
.39539 .67507 .40095 .67824 .41007 .6782 .40453 .6749 Metetra
.918 .326 0 r
.40453 .6749 .41007 .6782 .41924 .67785 .41372 .67444 Metetra
.926 .296 0 r
.41372 .67444 .41924 .67785 .42846 .67724 .42297 .67371 Metetra
.933 .269 0 r
.42297 .67371 .42846 .67724 .43773 .67637 .43226 .67274 Metetra
.94 .246 0 r
.43226 .67274 .43773 .67637 .44705 .67528 .4416 .67154 Metetra
.945 .225 0 r
.4416 .67154 .44705 .67528 .45641 .67398 .45099 .67013 Metetra
.95 .206 0 r
.45099 .67013 .45641 .67398 .46581 .67249 .46042 .66855 Metetra
.954 .19 0 r
.46042 .66855 .46581 .67249 .47526 .67083 .46989 .6668 Metetra
.957 .176 0 r
.46989 .6668 .47526 .67083 .48475 .66902 .4794 .6649 Metetra
.96 .165 0 r
.4794 .6649 .48475 .66902 .49427 .66706 .48895 .66287 Metetra
.963 .155 0 r
.48895 .66287 .49427 .66706 .50384 .66499 .49853 .66072 Metetra
.965 .146 0 r
.49853 .66072 .50384 .66499 .51344 .6628 .50816 .65846 Metetra
.967 .139 0 r
.50816 .65846 .51344 .6628 .52308 .66051 .51782 .65611 Metetra
.968 .133 0 r
.51782 .65611 .52308 .66051 .53275 .65814 .52752 .65368 Metetra
.969 .128 0 r
.52752 .65368 .53275 .65814 .54246 .65569 .53725 .65118 Metetra
.97 .124 0 r
.53725 .65118 .54246 .65569 .55221 .65317 .54702 .64861 Metetra
.971 .121 0 r
.54702 .64861 .55221 .65317 .56199 .65058 .55682 .64598 Metetra
.972 .119 0 r
.55682 .64598 .56199 .65058 .5718 .64793 .56666 .64329 Metetra
.972 .118 0 r
.56666 .64329 .5718 .64793 .58165 .64523 .57654 .64056 Metetra
.972 .117 0 r
.57654 .64056 .58165 .64523 .59154 .64247 .58645 .63778 Metetra
.972 .116 0 r
.58645 .63778 .59154 .64247 .60146 .63966 .59639 .63496 Metetra
.972 .117 0 r
.59639 .63496 .60146 .63966 .61141 .63681 .60637 .63209 Metetra
.972 .118 0 r
.60637 .63209 .61141 .63681 .6214 .63389 .61639 .62917 Metetra
.972 .119 0 r
.61639 .62917 .6214 .63389 .63142 .63092 .62644 .6262 Metetra
.971 .121 0 r
.62644 .6262 .63142 .63092 .64148 .6279 .63652 .62317 Metetra
.97 .124 0 r
.63652 .62317 .64148 .6279 .65157 .6248 .64664 .62009 Metetra
.969 .128 0 r
.64664 .62009 .65157 .6248 .66169 .62163 .65679 .61694 Metetra
.968 .133 0 r
.65679 .61694 .66169 .62163 .67184 .61838 .66697 .61371 Metetra
.967 .139 0 r
.66697 .61371 .67184 .61838 .68202 .61504 .67718 .61039 Metetra
.965 .146 0 r
.67718 .61039 .68202 .61504 .69224 .61159 .68743 .60698 Metetra
.963 .155 0 r
.68743 .60698 .69224 .61159 .70248 .60803 .6977 .60346 Metetra
.96 .165 0 r
.6977 .60346 .70248 .60803 .71275 .60434 .708 .59982 Metetra
.957 .176 0 r
.708 .59982 .71275 .60434 .72304 .6005 .71833 .59603 Metetra
.954 .19 0 r
.71833 .59603 .72304 .6005 .73336 .5965 .72868 .59209 Metetra
.95 .206 0 r
.72868 .59209 .73336 .5965 .7437 .59233 .73905 .58797 Metetra
.945 .225 0 r
.73905 .58797 .7437 .59233 .75405 .58795 .74945 .58366 Metetra
.94 .246 0 r
.74945 .58366 .75405 .58795 .76442 .58334 .75986 .57913 Metetra
.933 .269 0 r
.75986 .57913 .76442 .58334 .7748 .5785 .77028 .57437 Metetra
.926 .296 0 r
.77028 .57437 .7748 .5785 .78519 .57339 .78071 .56934 Metetra
.918 .326 0 r
.78071 .56934 .78519 .57339 .79558 .56798 .79114 .56402 Metetra
.909 .359 0 r
.79114 .56402 .79558 .56798 .80597 .56226 .80158 .55839 Metetra
.898 .396 0 r
.80158 .55839 .80597 .56226 .81635 .55618 .812 .55242 Metetra
.887 .435 0 r
.812 .55242 .81635 .55618 .82672 .54974 .82242 .54608 Metetra
.874 .479 0 r
.82242 .54608 .82672 .54974 .83707 .54289 .83282 .53934 Metetra
.859 .525 0 r
.83282 .53934 .83707 .54289 .84739 .5356 .8432 .53216 Metetra
.843 .575 0 r
.8432 .53216 .84739 .5356 .85768 .52784 .85354 .52452 Metetra
.824 .627 0 r
.85354 .52452 .85768 .52784 .86793 .51958 .86385 .51639 Metetra
.804 .682 0 r
.86385 .51639 .86793 .51958 .87813 .51079 .87411 .50772 Metetra
.782 .738 0 r
.87411 .50772 .87813 .51079 .88827 .50143 .88431 .49849 Metetra
.722 .758 0 r
.88431 .49849 .88827 .50143 .89834 .49147 .89445 .48866 Metetra
.612 .732 0 r
.89445 .48866 .89834 .49147 .90833 .48086 .90451 .47819 Metetra
.499 .702 0 r
.90451 .47819 .90833 .48086 .91824 .46959 .91448 .46706 Metetra
.545 .715 0 r
.2936 .64801 .29944 .64988 .30773 .65476 .30191 .65274 Metetra
.658 .743 0 r
.30191 .65274 .30773 .65476 .31612 .65903 .31032 .65686 Metetra
.768 .769 0 r
.31032 .65686 .31612 .65903 .32461 .66272 .31883 .6604 Metetra
.793 .712 0 r
.31883 .6604 .32461 .66272 .33319 .66586 .32743 .6634 Metetra
.814 .656 0 r
.32743 .6634 .33319 .66586 .34186 .66849 .33612 .66588 Metetra
.833 .601 0 r
.33612 .66588 .34186 .66849 .3506 .67063 .34489 .66788 Metetra
.851 .549 0 r
.34489 .66788 .3506 .67063 .35942 .67231 .35374 .66943 Metetra
.867 .5 0 r
.35374 .66943 .35942 .67231 .36832 .67357 .36265 .67056 Metetra
.881 .455 0 r
.36265 .67056 .36832 .67357 .37728 .67443 .37164 .67129 Metetra
.894 .412 0 r
.37164 .67129 .37728 .67443 .3863 .67492 .38068 .67166 Metetra
.905 .373 0 r
.38068 .67166 .3863 .67492 .39539 .67507 .38979 .67168 Metetra
.915 .338 0 r
.38979 .67168 .39539 .67507 .40453 .6749 .39896 .6714 Metetra
.924 .306 0 r
.39896 .6714 .40453 .6749 .41372 .67444 .40817 .67082 Metetra
.931 .277 0 r
.40817 .67082 .41372 .67444 .42297 .67371 .41744 .66998 Metetra
.938 .251 0 r
.41744 .66998 .42297 .67371 .43226 .67274 .42676 .6689 Metetra
.944 .229 0 r
.42676 .6689 .43226 .67274 .4416 .67154 .43612 .6676 Metetra
.949 .209 0 r
.43612 .6676 .4416 .67154 .45099 .67013 .44553 .66611 Metetra
.954 .191 0 r
.44553 .66611 .45099 .67013 .46042 .66855 .45498 .66443 Metetra
.957 .177 0 r
.45498 .66443 .46042 .66855 .46989 .6668 .46448 .6626 Metetra
.961 .164 0 r
.46448 .6626 .46989 .6668 .4794 .6649 .47401 .66062 Metetra
.963 .153 0 r
.47401 .66062 .4794 .6649 .48895 .66287 .48358 .65851 Metetra
.966 .143 0 r
.48358 .65851 .48895 .66287 .49853 .66072 .49319 .65629 Metetra
.968 .136 0 r
.49319 .65629 .49853 .66072 .50816 .65846 .50284 .65397 Metetra
.969 .129 0 r
.50284 .65397 .50816 .65846 .51782 .65611 .51253 .65156 Metetra
.971 .124 0 r
.51253 .65156 .51782 .65611 .52752 .65368 .52225 .64907 Metetra
.972 .12 0 r
.52225 .64907 .52752 .65368 .53725 .65118 .532 .64652 Metetra
.972 .116 0 r
.532 .64652 .53725 .65118 .54702 .64861 .5418 .6439 Metetra
.973 .114 0 r
.5418 .6439 .54702 .64861 .55682 .64598 .55163 .64124 Metetra
.974 .112 0 r
.55163 .64124 .55682 .64598 .56666 .64329 .56149 .63852 Metetra
.974 .11 0 r
.56149 .63852 .56666 .64329 .57654 .64056 .57139 .63576 Metetra
.974 .11 0 r
.57139 .63576 .57654 .64056 .58645 .63778 .58132 .63295 Metetra
.974 .109 0 r
.58132 .63295 .58645 .63778 .59639 .63496 .59129 .63011 Metetra
.974 .11 0 r
.59129 .63011 .59639 .63496 .60637 .63209 .6013 .62723 Metetra
.974 .11 0 r
.6013 .62723 .60637 .63209 .61639 .62917 .61134 .6243 Metetra
.974 .112 0 r
.61134 .6243 .61639 .62917 .62644 .6262 .62141 .62133 Metetra
.973 .114 0 r
.62141 .62133 .62644 .6262 .63652 .62317 .63152 .61831 Metetra
.972 .116 0 r
.63152 .61831 .63652 .62317 .64664 .62009 .64167 .61523 Metetra
.972 .12 0 r
.64167 .61523 .64664 .62009 .65679 .61694 .65184 .61209 Metetra
.971 .124 0 r
.65184 .61209 .65679 .61694 .66697 .61371 .66205 .60888 Metetra
.969 .129 0 r
.66205 .60888 .66697 .61371 .67718 .61039 .6723 .60559 Metetra
.968 .136 0 r
.6723 .60559 .67718 .61039 .68743 .60698 .68257 .60221 Metetra
.966 .143 0 r
.68257 .60221 .68743 .60698 .6977 .60346 .69288 .59872 Metetra
.963 .153 0 r
.69288 .59872 .6977 .60346 .708 .59982 .70321 .59512 Metetra
.961 .164 0 r
.70321 .59512 .708 .59982 .71833 .59603 .71357 .59138 Metetra
.957 .177 0 r
.71357 .59138 .71833 .59603 .72868 .59209 .72396 .58749 Metetra
.954 .191 0 r
.72396 .58749 .72868 .59209 .73905 .58797 .73437 .58343 Metetra
.949 .209 0 r
.73437 .58343 .73905 .58797 .74945 .58366 .7448 .57918 Metetra
.944 .229 0 r
.7448 .57918 .74945 .58366 .75986 .57913 .75524 .57472 Metetra
.938 .251 0 r
.75524 .57472 .75986 .57913 .77028 .57437 .76571 .57002 Metetra
.931 .277 0 r
.76571 .57002 .77028 .57437 .78071 .56934 .77618 .56507 Metetra
.924 .306 0 r
.77618 .56507 .78071 .56934 .79114 .56402 .78665 .55984 Metetra
.915 .338 0 r
.78665 .55984 .79114 .56402 .80158 .55839 .79713 .55429 Metetra
.905 .373 0 r
.79713 .55429 .80158 .55839 .812 .55242 .80761 .54841 Metetra
.894 .412 0 r
.80761 .54841 .812 .55242 .82242 .54608 .81807 .54216 Metetra
.881 .455 0 r
.81807 .54216 .82242 .54608 .83282 .53934 .82852 .53552 Metetra
.867 .5 0 r
.82852 .53552 .83282 .53934 .8432 .53216 .83895 .52845 Metetra
.851 .549 0 r
.83895 .52845 .8432 .53216 .85354 .52452 .84935 .52092 Metetra
.833 .601 0 r
.84935 .52092 .85354 .52452 .86385 .51639 .85971 .51289 Metetra
.814 .656 0 r
.85971 .51289 .86385 .51639 .87411 .50772 .87003 .50434 Metetra
.793 .712 0 r
.87003 .50434 .87411 .50772 .88431 .49849 .88029 .49523 Metetra
.768 .769 0 r
.88029 .49523 .88431 .49849 .89445 .48866 .89049 .48552 Metetra
.658 .743 0 r
.89049 .48552 .89445 .48866 .90451 .47819 .90061 .47518 Metetra
.545 .715 0 r
.90061 .47518 .90451 .47819 .91448 .46706 .91065 .46417 Metetra
.588 .725 0 r
.28773 .64582 .2936 .64801 .30191 .65274 .29606 .65041 Metetra
.701 .753 0 r
.29606 .65041 .30191 .65274 .31032 .65686 .30449 .65439 Metetra
.779 .747 0 r
.30449 .65439 .31032 .65686 .31883 .6604 .31303 .6578 Metetra
.802 .689 0 r
.31303 .6578 .31883 .6604 .32743 .6634 .32165 .66066 Metetra
.823 .632 0 r
.32165 .66066 .32743 .6634 .33612 .66588 .33036 .66301 Metetra
.842 .578 0 r
.33036 .66301 .33612 .66588 .34489 .66788 .33915 .66488 Metetra
.859 .526 0 r
.33915 .66488 .34489 .66788 .35374 .66943 .34802 .66631 Metetra
.874 .478 0 r
.34802 .66631 .35374 .66943 .36265 .67056 .35696 .66731 Metetra
.888 .433 0 r
.35696 .66731 .36265 .67056 .37164 .67129 .36596 .66792 Metetra
.9 .391 0 r
.36596 .66792 .37164 .67129 .38068 .67166 .37503 .66817 Metetra
.911 .353 0 r
.37503 .66817 .38068 .67166 .38979 .67168 .38416 .66808 Metetra
.92 .319 0 r
.38416 .66808 .38979 .67168 .39896 .6714 .39335 .66769 Metetra
.929 .288 0 r
.39335 .66769 .39896 .6714 .40817 .67082 .40259 .66701 Metetra
.936 .26 0 r
.40259 .66701 .40817 .67082 .41744 .66998 .41188 .66607 Metetra
.942 .235 0 r
.41188 .66607 .41744 .66998 .42676 .6689 .42122 .66489 Metetra
.948 .214 0 r
.42122 .66489 .42676 .6689 .43612 .6676 .43061 .6635 Metetra
.953 .195 0 r
.43061 .6635 .43612 .6676 .44553 .66611 .44004 .66192 Metetra
.957 .179 0 r
.44004 .66192 .44553 .66611 .45498 .66443 .44952 .66016 Metetra
.96 .165 0 r
.44952 .66016 .45498 .66443 .46448 .6626 .45903 .65824 Metetra
.963 .153 0 r
.45903 .65824 .46448 .6626 .47401 .66062 .46859 .65619 Metetra
.966 .143 0 r
.46859 .65619 .47401 .66062 .48358 .65851 .47819 .65401 Metetra
.968 .134 0 r
.47819 .65401 .48358 .65851 .49319 .65629 .48782 .65172 Metetra
.97 .127 0 r
.48782 .65172 .49319 .65629 .50284 .65397 .49749 .64934 Metetra
.971 .121 0 r
.49749 .64934 .50284 .65397 .51253 .65156 .5072 .64687 Metetra
.972 .117 0 r
.5072 .64687 .51253 .65156 .52225 .64907 .51694 .64433 Metetra
.973 .113 0 r
.51694 .64433 .52225 .64907 .532 .64652 .52672 .64173 Metetra
.974 .11 0 r
.52672 .64173 .532 .64652 .5418 .6439 .53654 .63907 Metetra
.975 .108 0 r
.53654 .63907 .5418 .6439 .55163 .64124 .54639 .63637 Metetra
.975 .106 0 r
.54639 .63637 .55163 .64124 .56149 .63852 .55628 .63362 Metetra
.975 .105 0 r
.55628 .63362 .56149 .63852 .57139 .63576 .5662 .63083 Metetra
.975 .104 0 r
.5662 .63083 .57139 .63576 .58132 .63295 .57616 .628 Metetra
.975 .104 0 r
.57616 .628 .58132 .63295 .59129 .63011 .58616 .62514 Metetra
.975 .104 0 r
.58616 .62514 .59129 .63011 .6013 .62723 .59619 .62224 Metetra
.975 .105 0 r
.59619 .62224 .6013 .62723 .61134 .6243 .60625 .61931 Metetra
.975 .106 0 r
.60625 .61931 .61134 .6243 .62141 .62133 .61635 .61633 Metetra
.975 .108 0 r
.61635 .61633 .62141 .62133 .63152 .61831 .62649 .61331 Metetra
.974 .11 0 r
.62649 .61331 .63152 .61831 .64167 .61523 .63666 .61024 Metetra
.973 .113 0 r
.63666 .61024 .64167 .61523 .65184 .61209 .64686 .60711 Metetra
.972 .117 0 r
.64686 .60711 .65184 .61209 .66205 .60888 .6571 .60392 Metetra
.971 .121 0 r
.6571 .60392 .66205 .60888 .6723 .60559 .66738 .60065 Metetra
.97 .127 0 r
.66738 .60065 .6723 .60559 .68257 .60221 .67768 .59729 Metetra
.968 .134 0 r
.67768 .59729 .68257 .60221 .69288 .59872 .68802 .59384 Metetra
.966 .143 0 r
.68802 .59384 .69288 .59872 .70321 .59512 .69838 .59027 Metetra
.963 .153 0 r
.69838 .59027 .70321 .59512 .71357 .59138 .70878 .58657 Metetra
.96 .165 0 r
.70878 .58657 .71357 .59138 .72396 .58749 .7192 .58272 Metetra
.957 .179 0 r
.7192 .58272 .72396 .58749 .73437 .58343 .72964 .57871 Metetra
.953 .195 0 r
.72964 .57871 .73437 .58343 .7448 .57918 .74011 .57451 Metetra
.948 .214 0 r
.74011 .57451 .7448 .57918 .75524 .57472 .75059 .57011 Metetra
.942 .235 0 r
.75059 .57011 .75524 .57472 .76571 .57002 .76109 .56548 Metetra
.936 .26 0 r
.76109 .56548 .76571 .57002 .77618 .56507 .7716 .5606 Metetra
.929 .288 0 r
.7716 .5606 .77618 .56507 .78665 .55984 .78212 .55544 Metetra
.92 .319 0 r
.78212 .55544 .78665 .55984 .79713 .55429 .79264 .54997 Metetra
.911 .353 0 r
.79264 .54997 .79713 .55429 .80761 .54841 .80316 .54417 Metetra
.9 .391 0 r
.80316 .54417 .80761 .54841 .81807 .54216 .81367 .53801 Metetra
.888 .433 0 r
.81367 .53801 .81807 .54216 .82852 .53552 .82417 .53145 Metetra
.874 .478 0 r
.82417 .53145 .82852 .53552 .83895 .52845 .83465 .52447 Metetra
.859 .526 0 r
.83465 .52447 .83895 .52845 .84935 .52092 .8451 .51704 Metetra
.842 .578 0 r
.8451 .51704 .84935 .52092 .85971 .51289 .85551 .50912 Metetra
.823 .632 0 r
.85551 .50912 .85971 .51289 .87003 .50434 .86588 .50067 Metetra
.802 .689 0 r
.86588 .50067 .87003 .50434 .88029 .49523 .8762 .49166 Metetra
.779 .747 0 r
.8762 .49166 .88029 .49523 .89049 .48552 .88646 .48206 Metetra
.701 .753 0 r
.88646 .48206 .89049 .48552 .90061 .47518 .89664 .47183 Metetra
.588 .725 0 r
.89664 .47183 .90061 .47518 .91065 .46417 .90674 .46093 Metetra
.627 .735 0 r
.28184 .64333 .28773 .64582 .29606 .65041 .29019 .64779 Metetra
.74 .762 0 r
.29019 .64779 .29606 .65041 .30449 .65439 .29864 .65164 Metetra
.787 .726 0 r
.29864 .65164 .30449 .65439 .31303 .6578 .30719 .65492 Metetra
.81 .667 0 r
.30719 .65492 .31303 .6578 .32165 .66066 .31584 .65766 Metetra
.83 .611 0 r
.31584 .65766 .32165 .66066 .33036 .66301 .32457 .65989 Metetra
.849 .557 0 r
.32457 .65989 .33036 .66301 .33915 .66488 .33338 .66164 Metetra
.865 .505 0 r
.33338 .66164 .33915 .66488 .34802 .66631 .34227 .66295 Metetra
.88 .457 0 r
.34227 .66295 .34802 .66631 .35696 .66731 .35123 .66384 Metetra
.893 .413 0 r
.35123 .66384 .35696 .66731 .36596 .66792 .36026 .66434 Metetra
.905 .372 0 r
.36026 .66434 .36596 .66792 .37503 .66817 .36935 .66448 Metetra
.916 .335 0 r
.36935 .66448 .37503 .66817 .38416 .66808 .3785 .66429 Metetra
.925 .302 0 r
.3785 .66429 .38416 .66808 .39335 .66769 .38771 .66379 Metetra
.933 .272 0 r
.38771 .66379 .39335 .66769 .40259 .66701 .39697 .66302 Metetra
.94 .245 0 r
.39697 .66302 .40259 .66701 .41188 .66607 .40629 .66198 Metetra
.946 .221 0 r
.40629 .66198 .41188 .66607 .42122 .66489 .41565 .66072 Metetra
.951 .201 0 r
.41565 .66072 .42122 .66489 .43061 .6635 .42506 .65924 Metetra
.956 .183 0 r
.42506 .65924 .43061 .6635 .44004 .66192 .43452 .65757 Metetra
.96 .168 0 r
.43452 .65757 .44004 .66192 .44952 .66016 .44402 .65573 Metetra
.963 .155 0 r
.44402 .65573 .44952 .66016 .45903 .65824 .45355 .65374 Metetra
.966 .143 0 r
.45355 .65374 .45903 .65824 .46859 .65619 .46313 .65162 Metetra
.968 .134 0 r
.46313 .65162 .46859 .65619 .47819 .65401 .47275 .64937 Metetra
.97 .126 0 r
.47275 .64937 .47819 .65401 .48782 .65172 .48241 .64702 Metetra
.971 .12 0 r
.48241 .64702 .48782 .65172 .49749 .64934 .4921 .64458 Metetra
.973 .115 0 r
.4921 .64458 .49749 .64934 .5072 .64687 .50183 .64206 Metetra
.974 .111 0 r
.50183 .64206 .5072 .64687 .51694 .64433 .5116 .63948 Metetra
.975 .107 0 r
.5116 .63948 .51694 .64433 .52672 .64173 .52141 .63683 Metetra
.975 .105 0 r
.52141 .63683 .52672 .64173 .53654 .63907 .53125 .63413 Metetra
.976 .103 0 r
.53125 .63413 .53654 .63907 .54639 .63637 .54112 .63139 Metetra
.976 .102 0 r
.54112 .63139 .54639 .63637 .55628 .63362 .55103 .62861 Metetra
.976 .101 0 r
.55103 .62861 .55628 .63362 .5662 .63083 .56098 .62579 Metetra
.976 .1 0 r
.56098 .62579 .5662 .63083 .57616 .628 .57096 .62294 Metetra
.976 .1 0 r
.57096 .62294 .57616 .628 .58616 .62514 .58098 .62006 Metetra
.976 .1 0 r
.58098 .62006 .58616 .62514 .59619 .62224 .59104 .61715 Metetra
.976 .101 0 r
.59104 .61715 .59619 .62224 .60625 .61931 .60113 .6142 Metetra
.976 .102 0 r
.60113 .6142 .60625 .61931 .61635 .61633 .61126 .61122 Metetra
.976 .103 0 r
.61126 .61122 .61635 .61633 .62649 .61331 .62142 .6082 Metetra
.975 .105 0 r
.62142 .6082 .62649 .61331 .63666 .61024 .63161 .60513 Metetra
.975 .107 0 r
.63161 .60513 .63666 .61024 .64686 .60711 .64185 .60201 Metetra
.974 .111 0 r
.64185 .60201 .64686 .60711 .6571 .60392 .65211 .59883 Metetra
.973 .115 0 r
.65211 .59883 .6571 .60392 .66738 .60065 .66242 .59558 Metetra
.971 .12 0 r
.66242 .59558 .66738 .60065 .67768 .59729 .67275 .59224 Metetra
.97 .126 0 r
.67275 .59224 .67768 .59729 .68802 .59384 .68312 .58881 Metetra
.968 .134 0 r
.68312 .58881 .68802 .59384 .69838 .59027 .69351 .58527 Metetra
.966 .143 0 r
.69351 .58527 .69838 .59027 .70878 .58657 .70394 .58161 Metetra
.963 .155 0 r
.70394 .58161 .70878 .58657 .7192 .58272 .71439 .5778 Metetra
.96 .168 0 r
.71439 .5778 .7192 .58272 .72964 .57871 .72487 .57383 Metetra
.956 .183 0 r
.72487 .57383 .72964 .57871 .74011 .57451 .73537 .56968 Metetra
.951 .201 0 r
.73537 .56968 .74011 .57451 .75059 .57011 .74589 .56533 Metetra
.946 .221 0 r
.74589 .56533 .75059 .57011 .76109 .56548 .75643 .56076 Metetra
.94 .245 0 r
.75643 .56076 .76109 .56548 .7716 .5606 .76698 .55593 Metetra
.933 .272 0 r
.76698 .55593 .7716 .5606 .78212 .55544 .77754 .55084 Metetra
.925 .302 0 r
.77754 .55084 .78212 .55544 .79264 .54997 .7881 .54544 Metetra
.916 .335 0 r
.7881 .54544 .79264 .54997 .80316 .54417 .79866 .53971 Metetra
.905 .372 0 r
.79866 .53971 .80316 .54417 .81367 .53801 .80922 .53362 Metetra
.893 .413 0 r
.80922 .53362 .81367 .53801 .82417 .53145 .81976 .52715 Metetra
.88 .457 0 r
.81976 .52715 .82417 .53145 .83465 .52447 .83029 .52025 Metetra
.865 .505 0 r
.83029 .52025 .83465 .52447 .8451 .51704 .84079 .5129 Metetra
.849 .557 0 r
.84079 .5129 .8451 .51704 .85551 .50912 .85126 .50507 Metetra
.83 .611 0 r
.85126 .50507 .85551 .50912 .86588 .50067 .86168 .49671 Metetra
.81 .667 0 r
.86168 .49671 .86588 .50067 .8762 .49166 .87205 .4878 Metetra
.787 .726 0 r
.87205 .4878 .8762 .49166 .88646 .48206 .88237 .47829 Metetra
.74 .762 0 r
.88237 .47829 .88646 .48206 .89664 .47183 .89261 .46816 Metetra
.627 .735 0 r
.89261 .46816 .89664 .47183 .90674 .46093 .90277 .45736 Metetra
.662 .744 0 r
.27592 .64054 .28184 .64333 .29019 .64779 .28429 .64488 Metetra
.771 .766 0 r
.28429 .64488 .29019 .64779 .29864 .65164 .29276 .64862 Metetra
.795 .706 0 r
.29276 .64862 .29864 .65164 .30719 .65492 .30133 .65178 Metetra
.817 .648 0 r
.30133 .65178 .30719 .65492 .31584 .65766 .30999 .65441 Metetra
.837 .591 0 r
.30999 .65441 .31584 .65766 .32457 .65989 .31874 .65653 Metetra
.855 .537 0 r
.31874 .65653 .32457 .65989 .33338 .66164 .32758 .65817 Metetra
.871 .487 0 r
.32758 .65817 .33338 .66164 .34227 .66295 .33649 .65937 Metetra
.886 .439 0 r
.33649 .65937 .34227 .66295 .35123 .66384 .34547 .66016 Metetra
.898 .396 0 r
.34547 .66016 .35123 .66384 .36026 .66434 .35452 .66056 Metetra
.91 .356 0 r
.35452 .66056 .36026 .66434 .36935 .66448 .36363 .6606 Metetra
.92 .319 0 r
.36363 .6606 .36935 .66448 .3785 .66429 .37281 .66032 Metetra
.929 .287 0 r
.37281 .66032 .3785 .66429 .38771 .66379 .38204 .65973 Metetra
.936 .258 0 r
.38204 .65973 .38771 .66379 .39697 .66302 .39132 .65886 Metetra
.943 .232 0 r
.39132 .65886 .39697 .66302 .40629 .66198 .40066 .65774 Metetra
.949 .209 0 r
.40066 .65774 .40629 .66198 .41565 .66072 .41005 .65639 Metetra
.954 .19 0 r
.41005 .65639 .41565 .66072 .42506 .65924 .41948 .65483 Metetra
.958 .173 0 r
.41948 .65483 .42506 .65924 .43452 .65757 .42896 .65309 Metetra
.962 .158 0 r
.42896 .65309 .43452 .65757 .44402 .65573 .43848 .65118 Metetra
.965 .146 0 r
.43848 .65118 .44402 .65573 .45355 .65374 .44804 .64912 Metetra
.968 .136 0 r
.44804 .64912 .45355 .65374 .46313 .65162 .45764 .64693 Metetra
.97 .127 0 r
.45764 .64693 .46313 .65162 .47275 .64937 .46728 .64462 Metetra
.971 .12 0 r
.46728 .64462 .47275 .64937 .48241 .64702 .47696 .64222 Metetra
.973 .114 0 r
.47696 .64222 .48241 .64702 .4921 .64458 .48668 .63972 Metetra
.974 .11 0 r
.48668 .63972 .4921 .64458 .50183 .64206 .49643 .63715 Metetra
.975 .106 0 r
.49643 .63715 .50183 .64206 .5116 .63948 .50623 .63452 Metetra
.976 .103 0 r
.50623 .63452 .5116 .63948 .52141 .63683 .51605 .63183 Metetra
.976 .101 0 r
.51605 .63183 .52141 .63683 .53125 .63413 .52592 .62909 Metetra
.977 .099 0 r
.52592 .62909 .53125 .63413 .54112 .63139 .53582 .62631 Metetra
.977 .098 0 r
.53582 .62631 .54112 .63139 .55103 .62861 .54575 .6235 Metetra
.977 .097 0 r
.54575 .6235 .55103 .62861 .56098 .62579 .55572 .62065 Metetra
.977 .097 0 r
.55572 .62065 .56098 .62579 .57096 .62294 .56573 .61778 Metetra
.977 .097 0 r
.56573 .61778 .57096 .62294 .58098 .62006 .57577 .61488 Metetra
.977 .097 0 r
.57577 .61488 .58098 .62006 .59104 .61715 .58585 .61195 Metetra
.977 .097 0 r
.58585 .61195 .59104 .61715 .60113 .6142 .59597 .609 Metetra
.977 .098 0 r
.59597 .609 .60113 .6142 .61126 .61122 .60612 .60601 Metetra
.977 .099 0 r
.60612 .60601 .61126 .61122 .62142 .6082 .61631 .60298 Metetra
.976 .101 0 r
.61631 .60298 .62142 .6082 .63161 .60513 .62653 .59992 Metetra
.976 .103 0 r
.62653 .59992 .63161 .60513 .64185 .60201 .63679 .5968 Metetra
.975 .106 0 r
.63679 .5968 .64185 .60201 .65211 .59883 .64709 .59363 Metetra
.974 .11 0 r
.64709 .59363 .65211 .59883 .66242 .59558 .65742 .59039 Metetra
.973 .114 0 r
.65742 .59039 .66242 .59558 .67275 .59224 .66778 .58707 Metetra
.971 .12 0 r
.66778 .58707 .67275 .59224 .68312 .58881 .67818 .58366 Metetra
.97 .127 0 r
.67818 .58366 .68312 .58881 .69351 .58527 .6886 .58015 Metetra
.968 .136 0 r
.6886 .58015 .69351 .58527 .70394 .58161 .69906 .57651 Metetra
.965 .146 0 r
.69906 .57651 .70394 .58161 .71439 .5778 .70955 .57274 Metetra
.962 .158 0 r
.70955 .57274 .71439 .5778 .72487 .57383 .72006 .56881 Metetra
.958 .173 0 r
.72006 .56881 .72487 .57383 .73537 .56968 .73059 .5647 Metetra
.954 .19 0 r
.73059 .5647 .73537 .56968 .74589 .56533 .74115 .56039 Metetra
.949 .209 0 r
.74115 .56039 .74589 .56533 .75643 .56076 .75172 .55586 Metetra
.943 .232 0 r
.75172 .55586 .75643 .56076 .76698 .55593 .76231 .55109 Metetra
.936 .258 0 r
.76231 .55109 .76698 .55593 .77754 .55084 .77291 .54605 Metetra
.929 .287 0 r
.77291 .54605 .77754 .55084 .7881 .54544 .78351 .54071 Metetra
.92 .319 0 r
.78351 .54071 .7881 .54544 .79866 .53971 .79412 .53504 Metetra
.91 .356 0 r
.79412 .53504 .79866 .53971 .80922 .53362 .80472 .52902 Metetra
.898 .396 0 r
.80472 .52902 .80922 .53362 .81976 .52715 .81531 .52261 Metetra
.886 .439 0 r
.81531 .52261 .81976 .52715 .83029 .52025 .82588 .51579 Metetra
.871 .487 0 r
.82588 .51579 .83029 .52025 .84079 .5129 .83643 .50851 Metetra
.855 .537 0 r
.83643 .50851 .84079 .5129 .85126 .50507 .84694 .50076 Metetra
.837 .591 0 r
.84694 .50076 .85126 .50507 .86168 .49671 .85742 .49248 Metetra
.817 .648 0 r
.85742 .49248 .86168 .49671 .87205 .4878 .86785 .48365 Metetra
.795 .706 0 r
.86785 .48365 .87205 .4878 .88237 .47829 .87821 .47423 Metetra
.771 .766 0 r
.87821 .47423 .88237 .47829 .89261 .46816 .88851 .46418 Metetra
.662 .744 0 r
.88851 .46418 .89261 .46816 .90277 .45736 .89873 .45347 Metetra
.694 .751 0 r
.26998 .63747 .27592 .64054 .28429 .64488 .27836 .64171 Metetra
.778 .749 0 r
.27836 .64171 .28429 .64488 .29276 .64862 .28685 .64534 Metetra
.802 .689 0 r
.28685 .64534 .29276 .64862 .30133 .65178 .29544 .6484 Metetra
.823 .63 0 r
.29544 .6484 .30133 .65178 .30999 .65441 .30412 .65092 Metetra
.843 .574 0 r
.30412 .65092 .30999 .65441 .31874 .65653 .31289 .65294 Metetra
.86 .52 0 r
.31289 .65294 .31874 .65653 .32758 .65817 .32174 .65449 Metetra
.876 .47 0 r
.32174 .65449 .32758 .65817 .33649 .65937 .33067 .65559 Metetra
.89 .423 0 r
.33067 .65559 .33649 .65937 .34547 .66016 .33968 .65628 Metetra
.903 .38 0 r
.33968 .65628 .34547 .66016 .35452 .66056 .34875 .65659 Metetra
.914 .341 0 r
.34875 .65659 .35452 .66056 .36363 .6606 .35788 .65654 Metetra
.924 .306 0 r
.35788 .65654 .36363 .6606 .37281 .66032 .36708 .65617 Metetra
.932 .274 0 r
.36708 .65617 .37281 .66032 .38204 .65973 .37633 .6555 Metetra
.94 .246 0 r
.37633 .6555 .38204 .65973 .39132 .65886 .38564 .65455 Metetra
.946 .221 0 r
.38564 .65455 .39132 .65886 .40066 .65774 .395 .65335 Metetra
.952 .199 0 r
.395 .65335 .40066 .65774 .41005 .65639 .40441 .65192 Metetra
.956 .18 0 r
.40441 .65192 .41005 .65639 .41948 .65483 .41386 .65029 Metetra
.961 .164 0 r
.41386 .65029 .41948 .65483 .42896 .65309 .42336 .64848 Metetra
.964 .15 0 r
.42336 .64848 .42896 .65309 .43848 .65118 .4329 .6465 Metetra
.967 .139 0 r
.4329 .6465 .43848 .65118 .44804 .64912 .44249 .64438 Metetra
.969 .129 0 r
.44249 .64438 .44804 .64912 .45764 .64693 .45211 .64213 Metetra
.971 .121 0 r
.45211 .64213 .45764 .64693 .46728 .64462 .46178 .63976 Metetra
.973 .115 0 r
.46178 .63976 .46728 .64462 .47696 .64222 .47148 .6373 Metetra
.974 .11 0 r
.47148 .6373 .47696 .64222 .48668 .63972 .48122 .63476 Metetra
.975 .106 0 r
.48122 .63476 .48668 .63972 .49643 .63715 .491 .63214 Metetra
.976 .102 0 r
.491 .63214 .49643 .63715 .50623 .63452 .50081 .62946 Metetra
.976 .1 0 r
.50081 .62946 .50623 .63452 .51605 .63183 .51066 .62673 Metetra
.977 .098 0 r
.51066 .62673 .51605 .63183 .52592 .62909 .52055 .62396 Metetra
.977 .097 0 r
.52055 .62396 .52592 .62909 .53582 .62631 .53047 .62115 Metetra
.977 .096 0 r
.53047 .62115 .53582 .62631 .54575 .6235 .54043 .6183 Metetra
.978 .095 0 r
.54043 .6183 .54575 .6235 .55572 .62065 .55043 .61543 Metetra
.978 .095 0 r
.55043 .61543 .55572 .62065 .56573 .61778 .56046 .61254 Metetra
.978 .095 0 r
.56046 .61254 .56573 .61778 .57577 .61488 .57053 .60962 Metetra
.978 .095 0 r
.57053 .60962 .57577 .61488 .58585 .61195 .58063 .60667 Metetra
.978 .095 0 r
.58063 .60667 .58585 .61195 .59597 .609 .59077 .6037 Metetra
.977 .096 0 r
.59077 .6037 .59597 .609 .60612 .60601 .60095 .60071 Metetra
.977 .097 0 r
.60095 .60071 .60612 .60601 .61631 .60298 .61116 .59768 Metetra
.977 .098 0 r
.61116 .59768 .61631 .60298 .62653 .59992 .62142 .59461 Metetra
.976 .1 0 r
.62142 .59461 .62653 .59992 .63679 .5968 .6317 .5915 Metetra
.976 .102 0 r
.6317 .5915 .63679 .5968 .64709 .59363 .64202 .58833 Metetra
.975 .106 0 r
.64202 .58833 .64709 .59363 .65742 .59039 .65238 .5851 Metetra
.974 .11 0 r
.65238 .5851 .65742 .59039 .66778 .58707 .66277 .58179 Metetra
.973 .115 0 r
.66277 .58179 .66778 .58707 .67818 .58366 .6732 .5784 Metetra
.971 .121 0 r
.6732 .5784 .67818 .58366 .6886 .58015 .68366 .57491 Metetra
.969 .129 0 r
.68366 .57491 .6886 .58015 .69906 .57651 .69414 .57129 Metetra
.967 .139 0 r
.69414 .57129 .69906 .57651 .70955 .57274 .70466 .56754 Metetra
.964 .15 0 r
.70466 .56754 .70955 .57274 .72006 .56881 .7152 .56364 Metetra
.961 .164 0 r
.7152 .56364 .72006 .56881 .73059 .5647 .72577 .55957 Metetra
.956 .18 0 r
.72577 .55957 .73059 .5647 .74115 .56039 .73636 .5553 Metetra
.952 .199 0 r
.73636 .5553 .74115 .56039 .75172 .55586 .74697 .55081 Metetra
.946 .221 0 r
.74697 .55081 .75172 .55586 .76231 .55109 .7576 .54608 Metetra
.94 .246 0 r
.7576 .54608 .76231 .55109 .77291 .54605 .76824 .54109 Metetra
.932 .274 0 r
.76824 .54109 .77291 .54605 .78351 .54071 .77888 .53579 Metetra
.924 .306 0 r
.77888 .53579 .78351 .54071 .79412 .53504 .78952 .53018 Metetra
.914 .341 0 r
.78952 .53018 .79412 .53504 .80472 .52902 .80017 .52421 Metetra
.903 .38 0 r
.80017 .52421 .80472 .52902 .81531 .52261 .8108 .51786 Metetra
.89 .423 0 r
.8108 .51786 .81531 .52261 .82588 .51579 .82142 .5111 Metetra
.876 .47 0 r
.82142 .5111 .82588 .51579 .83643 .50851 .83201 .50389 Metetra
.86 .52 0 r
.83201 .50389 .83643 .50851 .84694 .50076 .84258 .4962 Metetra
.843 .574 0 r
.84258 .4962 .84694 .50076 .85742 .49248 .8531 .48799 Metetra
.823 .63 0 r
.8531 .48799 .85742 .49248 .86785 .48365 .86358 .47923 Metetra
.802 .689 0 r
.86358 .47923 .86785 .48365 .87821 .47423 .874 .46988 Metetra
.778 .749 0 r
.874 .46988 .87821 .47423 .88851 .46418 .88435 .45991 Metetra
.694 .751 0 r
.88435 .45991 .88851 .46418 .89873 .45347 .89463 .44927 Metetra
.722 .758 0 r
.26401 .63412 .26998 .63747 .27836 .64171 .27241 .63826 Metetra
.784 .734 0 r
.27241 .63826 .27836 .64171 .28685 .64534 .28092 .6418 Metetra
.808 .673 0 r
.28092 .6418 .28685 .64534 .29544 .6484 .28952 .64477 Metetra
.829 .615 0 r
.28952 .64477 .29544 .6484 .30412 .65092 .29822 .6472 Metetra
.848 .559 0 r
.29822 .6472 .30412 .65092 .31289 .65294 .30701 .64913 Metetra
.865 .505 0 r
.30701 .64913 .31289 .65294 .32174 .65449 .31588 .65059 Metetra
.881 .456 0 r
.31588 .65059 .32174 .65449 .33067 .65559 .32483 .65161 Metetra
.894 .409 0 r
.32483 .65161 .33067 .65559 .33968 .65628 .33385 .65221 Metetra
.907 .367 0 r
.33385 .65221 .33968 .65628 .34875 .65659 .34294 .65244 Metetra
.917 .329 0 r
.34294 .65244 .34875 .65659 .35788 .65654 .3521 .65231 Metetra
.927 .294 0 r
.3521 .65231 .35788 .65654 .36708 .65617 .36132 .65186 Metetra
.935 .263 0 r
.36132 .65186 .36708 .65617 .37633 .6555 .37059 .65111 Metetra
.942 .235 0 r
.37059 .65111 .37633 .6555 .38564 .65455 .37992 .65009 Metetra
.949 .211 0 r
.37992 .65009 .38564 .65455 .395 .65335 .3893 .64882 Metetra
.954 .19 0 r
.3893 .64882 .395 .65335 .40441 .65192 .39873 .64733 Metetra
.959 .172 0 r
.39873 .64733 .40441 .65192 .41386 .65029 .40821 .64563 Metetra
.962 .157 0 r
.40821 .64563 .41386 .65029 .42336 .64848 .41773 .64375 Metetra
.966 .144 0 r
.41773 .64375 .42336 .64848 .4329 .6465 .4273 .64171 Metetra
.968 .133 0 r
.4273 .64171 .4329 .6465 .44249 .64438 .4369 .63953 Metetra
.971 .124 0 r
.4369 .63953 .44249 .64438 .45211 .64213 .44655 .63722 Metetra
.972 .117 0 r
.44655 .63722 .45211 .64213 .46178 .63976 .45624 .63481 Metetra
.974 .111 0 r
.45624 .63481 .46178 .63976 .47148 .6373 .46596 .6323 Metetra
.975 .106 0 r
.46596 .6323 .47148 .6373 .48122 .63476 .47573 .62971 Metetra
.976 .102 0 r
.47573 .62971 .48122 .63476 .491 .63214 .48553 .62704 Metetra
.976 .1 0 r
.48553 .62704 .491 .63214 .50081 .62946 .49536 .62433 Metetra
.977 .097 0 r
.49536 .62433 .50081 .62946 .51066 .62673 .50524 .62156 Metetra
.977 .096 0 r
.50524 .62156 .51066 .62673 .52055 .62396 .51515 .61875 Metetra
.978 .095 0 r
.51515 .61875 .52055 .62396 .53047 .62115 .52509 .6159 Metetra
.978 .094 0 r
.52509 .6159 .53047 .62115 .54043 .6183 .53508 .61303 Metetra
.978 .093 0 r
.53508 .61303 .54043 .6183 .55043 .61543 .5451 .61014 Metetra
.978 .093 0 r
.5451 .61014 .55043 .61543 .56046 .61254 .55515 .60722 Metetra
.978 .093 0 r
.55515 .60722 .56046 .61254 .57053 .60962 .56525 .60428 Metetra
.978 .093 0 r
.56525 .60428 .57053 .60962 .58063 .60667 .57537 .60132 Metetra
.978 .093 0 r
.57537 .60132 .58063 .60667 .59077 .6037 .58554 .59834 Metetra
.978 .094 0 r
.58554 .59834 .59077 .6037 .60095 .60071 .59574 .59533 Metetra
.978 .095 0 r
.59574 .59533 .60095 .60071 .61116 .59768 .60598 .59229 Metetra
.977 .096 0 r
.60598 .59229 .61116 .59768 .62142 .59461 .61626 .58922 Metetra
.977 .097 0 r
.61626 .58922 .62142 .59461 .6317 .5915 .62657 .58611 Metetra
.976 .1 0 r
.62657 .58611 .6317 .5915 .64202 .58833 .63692 .58294 Metetra
.976 .102 0 r
.63692 .58294 .64202 .58833 .65238 .5851 .64731 .57972 Metetra
.975 .106 0 r
.64731 .57972 .65238 .5851 .66277 .58179 .65773 .57642 Metetra
.974 .111 0 r
.65773 .57642 .66277 .58179 .6732 .5784 .66818 .57304 Metetra
.972 .117 0 r
.66818 .57304 .6732 .5784 .68366 .57491 .67867 .56956 Metetra
.971 .124 0 r
.67867 .56956 .68366 .57491 .69414 .57129 .68919 .56596 Metetra
.968 .133 0 r
.68919 .56596 .69414 .57129 .70466 .56754 .69974 .56223 Metetra
.966 .144 0 r
.69974 .56223 .70466 .56754 .7152 .56364 .71031 .55835 Metetra
.962 .157 0 r
.71031 .55835 .7152 .56364 .72577 .55957 .72091 .55431 Metetra
.959 .172 0 r
.72091 .55431 .72577 .55957 .73636 .5553 .73154 .55007 Metetra
.954 .19 0 r
.73154 .55007 .73636 .5553 .74697 .55081 .74218 .54561 Metetra
.949 .211 0 r
.74218 .54561 .74697 .55081 .7576 .54608 .75284 .54092 Metetra
.942 .235 0 r
.75284 .54092 .7576 .54608 .76824 .54109 .76352 .53596 Metetra
.935 .263 0 r
.76352 .53596 .76824 .54109 .77888 .53579 .7742 .53071 Metetra
.927 .294 0 r
.7742 .53071 .77888 .53579 .78952 .53018 .78489 .52513 Metetra
.917 .329 0 r
.78489 .52513 .78952 .53018 .80017 .52421 .79557 .51921 Metetra
.907 .367 0 r
.79557 .51921 .80017 .52421 .8108 .51786 .80624 .51291 Metetra
.894 .409 0 r
.80624 .51291 .8108 .51786 .82142 .5111 .8169 .5062 Metetra
.881 .456 0 r
.8169 .5062 .82142 .5111 .83201 .50389 .82754 .49904 Metetra
.865 .505 0 r
.82754 .49904 .83201 .50389 .84258 .4962 .83815 .4914 Metetra
.848 .559 0 r
.83815 .4914 .84258 .4962 .8531 .48799 .84873 .48324 Metetra
.829 .615 0 r
.84873 .48324 .8531 .48799 .86358 .47923 .85925 .47454 Metetra
.808 .673 0 r
.85925 .47454 .86358 .47923 .874 .46988 .86973 .46525 Metetra
.784 .734 0 r
.86973 .46525 .874 .46988 .88435 .45991 .88013 .45534 Metetra
.722 .758 0 r
.88013 .45534 .88435 .45991 .89463 .44927 .89046 .44477 Metetra
.746 .764 0 r
.25802 .6305 .26401 .63412 .27241 .63826 .26644 .63456 Metetra
.789 .721 0 r
.26644 .63456 .27241 .63826 .28092 .6418 .27496 .63802 Metetra
.813 .66 0 r
.27496 .63802 .28092 .6418 .28952 .64477 .28358 .64091 Metetra
.833 .601 0 r
.28358 .64091 .28952 .64477 .29822 .6472 .29229 .64326 Metetra
.852 .545 0 r
.29229 .64326 .29822 .6472 .30701 .64913 .3011 .64511 Metetra
.869 .493 0 r
.3011 .64511 .30701 .64913 .31588 .65059 .30999 .64649 Metetra
.884 .443 0 r
.30999 .64649 .31588 .65059 .32483 .65161 .31895 .64743 Metetra
.898 .397 0 r
.31895 .64743 .32483 .65161 .33385 .65221 .328 .64797 Metetra
.91 .356 0 r
.328 .64797 .33385 .65221 .34294 .65244 .33711 .64812 Metetra
.92 .318 0 r
.33711 .64812 .34294 .65244 .3521 .65231 .34628 .64792 Metetra
.93 .284 0 r
.34628 .64792 .3521 .65231 .36132 .65186 .35552 .6474 Metetra
.938 .253 0 r
.35552 .6474 .36132 .65186 .37059 .65111 .36482 .64658 Metetra
.945 .227 0 r
.36482 .64658 .37059 .65111 .37992 .65009 .37417 .64549 Metetra
.951 .203 0 r
.37417 .64549 .37992 .65009 .3893 .64882 .38357 .64416 Metetra
.956 .183 0 r
.38357 .64416 .3893 .64882 .39873 .64733 .39302 .6426 Metetra
.96 .166 0 r
.39302 .6426 .39873 .64733 .40821 .64563 .40252 .64085 Metetra
.964 .151 0 r
.40252 .64085 .40821 .64563 .41773 .64375 .41206 .63891 Metetra
.967 .138 0 r
.41206 .63891 .41773 .64375 .4273 .64171 .42165 .63682 Metetra
.969 .128 0 r
.42165 .63682 .4273 .64171 .4369 .63953 .43128 .63459 Metetra
.972 .12 0 r
.43128 .63459 .4369 .63953 .44655 .63722 .44095 .63223 Metetra
.973 .113 0 r
.44095 .63223 .44655 .63722 .45624 .63481 .45066 .62977 Metetra
.975 .107 0 r
.45066 .62977 .45624 .63481 .46596 .6323 .46041 .62721 Metetra
.976 .103 0 r
.46041 .62721 .46596 .6323 .47573 .62971 .47019 .62457 Metetra
.976 .1 0 r
.47019 .62457 .47573 .62971 .48553 .62704 .48002 .62187 Metetra
.977 .097 0 r
.48002 .62187 .48553 .62704 .49536 .62433 .48988 .61912 Metetra
.977 .096 0 r
.48988 .61912 .49536 .62433 .50524 .62156 .49978 .61631 Metetra
.978 .094 0 r
.49978 .61631 .50524 .62156 .51515 .61875 .50971 .61347 Metetra
.978 .093 0 r
.50971 .61347 .51515 .61875 .52509 .6159 .51968 .6106 Metetra
.978 .093 0 r
.51968 .6106 .52509 .6159 .53508 .61303 .52969 .6077 Metetra
.978 .092 0 r
.52969 .6077 .53508 .61303 .5451 .61014 .53973 .60477 Metetra
.978 .092 0 r
.53973 .60477 .5451 .61014 .55515 .60722 .54981 .60183 Metetra
.978 .092 0 r
.54981 .60183 .55515 .60722 .56525 .60428 .55993 .59887 Metetra
.978 .092 0 r
.55993 .59887 .56525 .60428 .57537 .60132 .57008 .5959 Metetra
.978 .092 0 r
.57008 .5959 .57537 .60132 .58554 .59834 .58027 .5929 Metetra
.978 .093 0 r
.58027 .5929 .58554 .59834 .59574 .59533 .5905 .58988 Metetra
.978 .093 0 r
.5905 .58988 .59574 .59533 .60598 .59229 .60077 .58684 Metetra
.978 .094 0 r
.60077 .58684 .60598 .59229 .61626 .58922 .61107 .58376 Metetra
.977 .096 0 r
.61107 .58376 .61626 .58922 .62657 .58611 .62141 .58064 Metetra
.977 .097 0 r
.62141 .58064 .62657 .58611 .63692 .58294 .63179 .57747 Metetra
.976 .1 0 r
.63179 .57747 .63692 .58294 .64731 .57972 .6422 .57425 Metetra
.976 .103 0 r
.6422 .57425 .64731 .57972 .65773 .57642 .65265 .57096 Metetra
.975 .107 0 r
.65265 .57096 .65773 .57642 .66818 .57304 .66313 .56758 Metetra
.973 .113 0 r
.66313 .56758 .66818 .57304 .67867 .56956 .67365 .56411 Metetra
.972 .12 0 r
.67365 .56411 .67867 .56956 .68919 .56596 .68419 .56052 Metetra
.969 .128 0 r
.68419 .56052 .68919 .56596 .69974 .56223 .69477 .55681 Metetra
.967 .138 0 r
.69477 .55681 .69974 .56223 .71031 .55835 .70538 .55295 Metetra
.964 .151 0 r
.70538 .55295 .71031 .55835 .72091 .55431 .71601 .54892 Metetra
.96 .166 0 r
.71601 .54892 .72091 .55431 .73154 .55007 .72667 .5447 Metetra
.956 .183 0 r
.72667 .5447 .73154 .55007 .74218 .54561 .73735 .54027 Metetra
.951 .203 0 r
.73735 .54027 .74218 .54561 .75284 .54092 .74805 .5356 Metetra
.945 .227 0 r
.74805 .5356 .75284 .54092 .76352 .53596 .75876 .53067 Metetra
.938 .253 0 r
.75876 .53067 .76352 .53596 .7742 .53071 .76948 .52545 Metetra
.93 .284 0 r
.76948 .52545 .7742 .53071 .78489 .52513 .7802 .51991 Metetra
.92 .318 0 r
.7802 .51991 .78489 .52513 .79557 .51921 .79092 .51402 Metetra
.91 .356 0 r
.79092 .51402 .79557 .51921 .80624 .51291 .80164 .50776 Metetra
.898 .397 0 r
.80164 .50776 .80624 .51291 .8169 .5062 .81234 .50108 Metetra
.884 .443 0 r
.81234 .50108 .8169 .5062 .82754 .49904 .82302 .49396 Metetra
.869 .493 0 r
.82302 .49396 .82754 .49904 .83815 .4914 .83368 .48637 Metetra
.852 .545 0 r
.83368 .48637 .83815 .4914 .84873 .48324 .8443 .47826 Metetra
.833 .601 0 r
.8443 .47826 .84873 .48324 .85925 .47454 .85487 .4696 Metetra
.813 .66 0 r
.85487 .4696 .85925 .47454 .86973 .46525 .86539 .46035 Metetra
.789 .721 0 r
.86539 .46035 .86973 .46525 .88013 .45534 .87585 .45049 Metetra
.746 .764 0 r
.87585 .45049 .88013 .45534 .89046 .44477 .88623 .43996 Metetra
.766 .768 0 r
.25201 .62662 .25802 .6305 .26644 .63456 .26043 .63061 Metetra
.794 .709 0 r
.26043 .63061 .26644 .63456 .27496 .63802 .26897 .634 Metetra
.817 .649 0 r
.26897 .634 .27496 .63802 .28358 .64091 .2776 .63682 Metetra
.837 .59 0 r
.2776 .63682 .28358 .64091 .29229 .64326 .28634 .6391 Metetra
.856 .534 0 r
.28634 .6391 .29229 .64326 .3011 .64511 .29516 .64089 Metetra
.873 .482 0 r
.29516 .64089 .3011 .64511 .30999 .64649 .30406 .6422 Metetra
.887 .433 0 r
.30406 .6422 .30999 .64649 .31895 .64743 .31305 .64308 Metetra
.901 .388 0 r
.31305 .64308 .31895 .64743 .328 .64797 .32211 .64354 Metetra
.912 .346 0 r
.32211 .64354 .328 .64797 .33711 .64812 .33124 .64363 Metetra
.923 .309 0 r
.33124 .64363 .33711 .64812 .34628 .64792 .34043 .64337 Metetra
.932 .275 0 r
.34043 .64337 .34628 .64792 .35552 .6474 .34969 .64279 Metetra
.94 .246 0 r
.34969 .64279 .35552 .6474 .36482 .64658 .35901 .64191 Metetra
.946 .22 0 r
.35901 .64191 .36482 .64658 .37417 .64549 .36838 .64077 Metetra
.952 .197 0 r
.36838 .64077 .37417 .64549 .38357 .64416 .3778 .63938 Metetra
.957 .177 0 r
.3778 .63938 .38357 .64416 .39302 .6426 .38727 .63777 Metetra
.962 .16 0 r
.38727 .63777 .39302 .6426 .40252 .64085 .39679 .63596 Metetra
.965 .146 0 r
.39679 .63596 .40252 .64085 .41206 .63891 .40636 .63398 Metetra
.968 .134 0 r
.40636 .63398 .41206 .63891 .42165 .63682 .41597 .63183 Metetra
.97 .124 0 r
.41597 .63183 .42165 .63682 .43128 .63459 .42562 .62955 Metetra
.972 .116 0 r
.42562 .62955 .43128 .63459 .44095 .63223 .43531 .62715 Metetra
.974 .11 0 r
.43531 .62715 .44095 .63223 .45066 .62977 .44505 .62464 Metetra
.975 .105 0 r
.44505 .62464 .45066 .62977 .46041 .62721 .45482 .62204 Metetra
.976 .101 0 r
.45482 .62204 .46041 .62721 .47019 .62457 .46463 .61937 Metetra
.977 .098 0 r
.46463 .61937 .47019 .62457 .48002 .62187 .47447 .61663 Metetra
.977 .096 0 r
.47447 .61663 .48002 .62187 .48988 .61912 .48436 .61384 Metetra
.978 .094 0 r
.48436 .61384 .48988 .61912 .49978 .61631 .49428 .611 Metetra
.978 .093 0 r
.49428 .611 .49978 .61631 .50971 .61347 .50423 .60813 Metetra
.978 .092 0 r
.50423 .60813 .50971 .61347 .51968 .6106 .51423 .60523 Metetra
.978 .092 0 r
.51423 .60523 .51968 .6106 .52969 .6077 .52426 .6023 Metetra
.978 .092 0 r
.52426 .6023 .52969 .6077 .53973 .60477 .53433 .59935 Metetra
.978 .092 0 r
.53433 .59935 .53973 .60477 .54981 .60183 .54443 .59639 Metetra
.978 .091 0 r
.54443 .59639 .54981 .60183 .55993 .59887 .55457 .59341 Metetra
.978 .092 0 r
.55457 .59341 .55993 .59887 .57008 .5959 .56475 .59042 Metetra
.978 .092 0 r
.56475 .59042 .57008 .5959 .58027 .5929 .57497 .5874 Metetra
.978 .092 0 r
.57497 .5874 .58027 .5929 .5905 .58988 .58522 .58437 Metetra
.978 .092 0 r
.58522 .58437 .5905 .58988 .60077 .58684 .59551 .58131 Metetra
.978 .093 0 r
.59551 .58131 .60077 .58684 .61107 .58376 .60584 .57823 Metetra
.978 .094 0 r
.60584 .57823 .61107 .58376 .62141 .58064 .61621 .5751 Metetra
.977 .096 0 r
.61621 .5751 .62141 .58064 .63179 .57747 .62661 .57193 Metetra
.977 .098 0 r
.62661 .57193 .63179 .57747 .6422 .57425 .63705 .56871 Metetra
.976 .101 0 r
.63705 .56871 .6422 .57425 .65265 .57096 .64753 .56541 Metetra
.975 .105 0 r
.64753 .56541 .65265 .57096 .66313 .56758 .65804 .56204 Metetra
.974 .11 0 r
.65804 .56204 .66313 .56758 .67365 .56411 .66858 .55857 Metetra
.972 .116 0 r
.66858 .55857 .67365 .56411 .68419 .56052 .67916 .55499 Metetra
.97 .124 0 r
.67916 .55499 .68419 .56052 .69477 .55681 .68977 .55129 Metetra
.968 .134 0 r
.68977 .55129 .69477 .55681 .70538 .55295 .70041 .54743 Metetra
.965 .146 0 r
.70041 .54743 .70538 .55295 .71601 .54892 .71108 .54342 Metetra
.962 .16 0 r
.71108 .54342 .71601 .54892 .72667 .5447 .72177 .53921 Metetra
.957 .177 0 r
.72177 .53921 .72667 .5447 .73735 .54027 .73248 .5348 Metetra
.952 .197 0 r
.73248 .5348 .73735 .54027 .74805 .5356 .74321 .53015 Metetra
.946 .22 0 r
.74321 .53015 .74805 .5356 .75876 .53067 .75396 .52523 Metetra
.94 .246 0 r
.75396 .52523 .75876 .53067 .76948 .52545 .76471 .52004 Metetra
.932 .275 0 r
.76471 .52004 .76948 .52545 .7802 .51991 .77547 .51452 Metetra
.923 .309 0 r
.77547 .51452 .7802 .51991 .79092 .51402 .78623 .50866 Metetra
.912 .346 0 r
.78623 .50866 .79092 .51402 .80164 .50776 .79699 .50242 Metetra
.901 .388 0 r
.79699 .50242 .80164 .50776 .81234 .50108 .80773 .49577 Metetra
.887 .433 0 r
.80773 .49577 .81234 .50108 .82302 .49396 .81846 .48868 Metetra
.873 .482 0 r
.81846 .48868 .82302 .49396 .83368 .48637 .82915 .48111 Metetra
.856 .534 0 r
.82915 .48111 .83368 .48637 .8443 .47826 .83982 .47303 Metetra
.837 .59 0 r
.83982 .47303 .8443 .47826 .85487 .4696 .85044 .46441 Metetra
.817 .649 0 r
.85044 .46441 .85487 .4696 .86539 .46035 .861 .45519 Metetra
.794 .709 0 r
.861 .45519 .86539 .46035 .87585 .45049 .87151 .44536 Metetra
.766 .768 0 r
.87151 .44536 .87585 .45049 .88623 .43996 .88194 .43487 Metetra
.772 .762 0 r
.24597 .62248 .25201 .62662 .26043 .63061 .25441 .62641 Metetra
.797 .7 0 r
.25441 .62641 .26043 .63061 .26897 .634 .26295 .62974 Metetra
.82 .64 0 r
.26295 .62974 .26897 .634 .2776 .63682 .2716 .6325 Metetra
.84 .581 0 r
.2716 .6325 .2776 .63682 .28634 .6391 .28035 .63473 Metetra
.859 .525 0 r
.28035 .63473 .28634 .6391 .29516 .64089 .28919 .63646 Metetra
.875 .473 0 r
.28919 .63646 .29516 .64089 .30406 .6422 .29811 .63772 Metetra
.89 .424 0 r
.29811 .63772 .30406 .6422 .31305 .64308 .30711 .63854 Metetra
.903 .379 0 r
.30711 .63854 .31305 .64308 .32211 .64354 .31619 .63895 Metetra
.915 .339 0 r
.31619 .63895 .32211 .64354 .33124 .64363 .32533 .63899 Metetra
.925 .302 0 r
.32533 .63899 .33124 .64363 .34043 .64337 .33455 .63868 Metetra
.934 .269 0 r
.33455 .63868 .34043 .64337 .34969 .64279 .34383 .63804 Metetra
.941 .24 0 r
.34383 .63804 .34969 .64279 .35901 .64191 .35316 .63712 Metetra
.948 .214 0 r
.35316 .63712 .35901 .64191 .36838 .64077 .36255 .63592 Metetra
.954 .192 0 r
.36255 .63592 .36838 .64077 .3778 .63938 .372 .63448 Metetra
.959 .172 0 r
.372 .63448 .3778 .63938 .38727 .63777 .38149 .63283 Metetra
.963 .156 0 r
.38149 .63283 .38727 .63777 .39679 .63596 .39103 .63097 Metetra
.966 .142 0 r
.39103 .63097 .39679 .63596 .40636 .63398 .40062 .62894 Metetra
.969 .131 0 r
.40062 .62894 .40636 .63398 .41597 .63183 .41025 .62676 Metetra
.971 .121 0 r
.41025 .62676 .41597 .63183 .42562 .62955 .41993 .62443 Metetra
.973 .114 0 r
.41993 .62443 .42562 .62955 .43531 .62715 .42964 .62199 Metetra
.974 .108 0 r
.42964 .62199 .43531 .62715 .44505 .62464 .4394 .61944 Metetra
.976 .103 0 r
.4394 .61944 .44505 .62464 .45482 .62204 .44919 .61681 Metetra
.977 .099 0 r
.44919 .61681 .45482 .62204 .46463 .61937 .45902 .6141 Metetra
.977 .097 0 r
.45902 .6141 .46463 .61937 .47447 .61663 .46889 .61133 Metetra
.978 .095 0 r
.46889 .61133 .47447 .61663 .48436 .61384 .4788 .6085 Metetra
.978 .093 0 r
.4788 .6085 .48436 .61384 .49428 .611 .48874 .60564 Metetra
.978 .092 0 r
.48874 .60564 .49428 .611 .50423 .60813 .49872 .60273 Metetra
.978 .092 0 r
.49872 .60273 .50423 .60813 .51423 .60523 .50874 .59981 Metetra
.978 .091 0 r
.50874 .59981 .51423 .60523 .52426 .6023 .51879 .59685 Metetra
.978 .091 0 r
.51879 .59685 .52426 .6023 .53433 .59935 .52889 .59388 Metetra
.979 .091 0 r
.52889 .59388 .53433 .59935 .54443 .59639 .53901 .5909 Metetra
.979 .091 0 r
.53901 .5909 .54443 .59639 .55457 .59341 .54918 .5879 Metetra
.979 .091 0 r
.54918 .5879 .55457 .59341 .56475 .59042 .55938 .58489 Metetra
.978 .091 0 r
.55938 .58489 .56475 .59042 .57497 .5874 .56963 .58186 Metetra
.978 .091 0 r
.56963 .58186 .57497 .5874 .58522 .58437 .57991 .57881 Metetra
.978 .092 0 r
.57991 .57881 .58522 .58437 .59551 .58131 .59022 .57574 Metetra
.978 .092 0 r
.59022 .57574 .59551 .58131 .60584 .57823 .60058 .57264 Metetra
.978 .093 0 r
.60058 .57264 .60584 .57823 .61621 .5751 .61097 .5695 Metetra
.978 .095 0 r
.61097 .5695 .61621 .5751 .62661 .57193 .6214 .56632 Metetra
.977 .097 0 r
.6214 .56632 .62661 .57193 .63705 .56871 .63187 .56309 Metetra
.977 .099 0 r
.63187 .56309 .63705 .56871 .64753 .56541 .64237 .55979 Metetra
.976 .103 0 r
.64237 .55979 .64753 .56541 .65804 .56204 .65291 .55642 Metetra
.974 .108 0 r
.65291 .55642 .65804 .56204 .66858 .55857 .66348 .55295 Metetra
.973 .114 0 r
.66348 .55295 .66858 .55857 .67916 .55499 .67409 .54937 Metetra
.971 .121 0 r
.67409 .54937 .67916 .55499 .68977 .55129 .68473 .54567 Metetra
.969 .131 0 r
.68473 .54567 .68977 .55129 .70041 .54743 .6954 .54182 Metetra
.966 .142 0 r
.6954 .54182 .70041 .54743 .71108 .54342 .7061 .5378 Metetra
.963 .156 0 r
.7061 .5378 .71108 .54342 .72177 .53921 .71682 .53361 Metetra
.959 .172 0 r
.71682 .53361 .72177 .53921 .73248 .5348 .72757 .5292 Metetra
.954 .192 0 r
.72757 .5292 .73248 .5348 .74321 .53015 .73833 .52456 Metetra
.948 .214 0 r
.73833 .52456 .74321 .53015 .75396 .52523 .74911 .51965 Metetra
.941 .24 0 r
.74911 .51965 .75396 .52523 .76471 .52004 .7599 .51447 Metetra
.934 .269 0 r
.7599 .51447 .76471 .52004 .77547 .51452 .7707 .50896 Metetra
.925 .302 0 r
.7707 .50896 .77547 .51452 .78623 .50866 .7815 .50312 Metetra
.915 .339 0 r
.7815 .50312 .78623 .50866 .79699 .50242 .79229 .49689 Metetra
.903 .379 0 r
.79229 .49689 .79699 .50242 .80773 .49577 .80307 .49026 Metetra
.89 .424 0 r
.80307 .49026 .80773 .49577 .81846 .48868 .81384 .48319 Metetra
.875 .473 0 r
.81384 .48319 .81846 .48868 .82915 .48111 .82458 .47564 Metetra
.859 .525 0 r
.82458 .47564 .82915 .48111 .83982 .47303 .83528 .46758 Metetra
.84 .581 0 r
.83528 .46758 .83982 .47303 .85044 .46441 .84595 .45897 Metetra
.82 .64 0 r
.84595 .45897 .85044 .46441 .861 .45519 .85656 .44978 Metetra
.797 .7 0 r
.85656 .44978 .861 .45519 .87151 .44536 .86711 .43996 Metetra
.772 .762 0 r
.86711 .43996 .87151 .44536 .88194 .43487 .87759 .42949 Metetra
.775 .755 0 r
.23991 .61808 .24597 .62248 .25441 .62641 .24836 .62197 Metetra
.8 .693 0 r
.24836 .62197 .25441 .62641 .26295 .62974 .25692 .62525 Metetra
.823 .632 0 r
.25692 .62525 .26295 .62974 .2716 .6325 .26558 .62797 Metetra
.843 .574 0 r
.26558 .62797 .2716 .6325 .28035 .63473 .27434 .63015 Metetra
.861 .518 0 r
.27434 .63015 .28035 .63473 .28919 .63646 .28319 .63184 Metetra
.877 .466 0 r
.28319 .63184 .28919 .63646 .29811 .63772 .29212 .63305 Metetra
.892 .418 0 r
.29212 .63305 .29811 .63772 .30711 .63854 .30114 .63383 Metetra
.905 .373 0 r
.30114 .63383 .30711 .63854 .31619 .63895 .31023 .6342 Metetra
.916 .333 0 r
.31023 .6342 .31619 .63895 .32533 .63899 .3194 .63419 Metetra
.926 .296 0 r
.3194 .63419 .32533 .63899 .33455 .63868 .32863 .63383 Metetra
.935 .264 0 r
.32863 .63383 .33455 .63868 .34383 .63804 .33793 .63316 Metetra
.943 .235 0 r
.33793 .63316 .34383 .63804 .35316 .63712 .34728 .63219 Metetra
.949 .209 0 r
.34728 .63219 .35316 .63712 .36255 .63592 .35669 .63095 Metetra
.955 .188 0 r
.35669 .63095 .36255 .63592 .372 .63448 .36616 .62947 Metetra
.959 .169 0 r
.36616 .62947 .372 .63448 .38149 .63283 .37567 .62778 Metetra
.963 .153 0 r
.37567 .62778 .38149 .63283 .39103 .63097 .38523 .62588 Metetra
.967 .139 0 r
.38523 .62588 .39103 .63097 .40062 .62894 .39484 .62382 Metetra
.969 .128 0 r
.39484 .62382 .40062 .62894 .41025 .62676 .4045 .62159 Metetra
.972 .119 0 r
.4045 .62159 .41025 .62676 .41993 .62443 .41419 .61924 Metetra
.973 .112 0 r
.41419 .61924 .41993 .62443 .42964 .62199 .42393 .61676 Metetra
.975 .106 0 r
.42393 .61676 .42964 .62199 .4394 .61944 .43371 .61418 Metetra
.976 .102 0 r
.43371 .61418 .4394 .61944 .44919 .61681 .44352 .61151 Metetra
.977 .098 0 r
.44352 .61151 .44919 .61681 .45902 .6141 .45338 .60877 Metetra
.977 .096 0 r
.45338 .60877 .45902 .6141 .46889 .61133 .46327 .60597 Metetra
.978 .094 0 r
.46327 .60597 .46889 .61133 .4788 .6085 .4732 .60311 Metetra
.978 .093 0 r
.4732 .60311 .4788 .6085 .48874 .60564 .48317 .60022 Metetra
.978 .092 0 r
.48317 .60022 .48874 .60564 .49872 .60273 .49317 .59729 Metetra
.978 .091 0 r
.49317 .59729 .49872 .60273 .50874 .59981 .50321 .59433 Metetra
.978 .091 0 r
.50321 .59433 .50874 .59981 .51879 .59685 .51329 .59136 Metetra
.979 .091 0 r
.51329 .59136 .51879 .59685 .52889 .59388 .52341 .58837 Metetra
.979 .091 0 r
.52341 .58837 .52889 .59388 .53901 .5909 .53356 .58536 Metetra
.979 .091 0 r
.53356 .58536 .53901 .5909 .54918 .5879 .54375 .58234 Metetra
.979 .091 0 r
.54375 .58234 .54918 .5879 .55938 .58489 .55398 .57931 Metetra
.979 .091 0 r
.55398 .57931 .55938 .58489 .56963 .58186 .56425 .57626 Metetra
.978 .091 0 r
.56425 .57626 .56963 .58186 .57991 .57881 .57455 .57319 Metetra
.978 .091 0 r
.57455 .57319 .57991 .57881 .59022 .57574 .5849 .57011 Metetra
.978 .092 0 r
.5849 .57011 .59022 .57574 .60058 .57264 .59528 .567 Metetra
.978 .093 0 r
.59528 .567 .60058 .57264 .61097 .5695 .60569 .56385 Metetra
.978 .094 0 r
.60569 .56385 .61097 .5695 .6214 .56632 .61615 .56066 Metetra
.977 .096 0 r
.61615 .56066 .6214 .56632 .63187 .56309 .62665 .55741 Metetra
.977 .098 0 r
.62665 .55741 .63187 .56309 .64237 .55979 .63718 .55411 Metetra
.976 .102 0 r
.63718 .55411 .64237 .55979 .65291 .55642 .64774 .55072 Metetra
.975 .106 0 r
.64774 .55072 .65291 .55642 .66348 .55295 .65835 .54724 Metetra
.973 .112 0 r
.65835 .54724 .66348 .55295 .67409 .54937 .66898 .54366 Metetra
.972 .119 0 r
.66898 .54366 .67409 .54937 .68473 .54567 .67965 .53995 Metetra
.969 .128 0 r
.67965 .53995 .68473 .54567 .6954 .54182 .69035 .5361 Metetra
.967 .139 0 r
.69035 .5361 .6954 .54182 .7061 .5378 .70108 .53209 Metetra
.963 .153 0 r
.70108 .53209 .7061 .5378 .71682 .53361 .71184 .52789 Metetra
.959 .169 0 r
.71184 .52789 .71682 .53361 .72757 .5292 .72261 .52348 Metetra
.955 .188 0 r
.72261 .52348 .72757 .5292 .73833 .52456 .73341 .51884 Metetra
.949 .209 0 r
.73341 .51884 .73833 .52456 .74911 .51965 .74422 .51394 Metetra
.943 .235 0 r
.74422 .51394 .74911 .51965 .7599 .51447 .75505 .50875 Metetra
.935 .264 0 r
.75505 .50875 .7599 .51447 .7707 .50896 .76588 .50325 Metetra
.926 .296 0 r
.76588 .50325 .7707 .50896 .7815 .50312 .77672 .49741 Metetra
.916 .333 0 r
.77672 .49741 .7815 .50312 .79229 .49689 .78755 .49119 Metetra
.905 .373 0 r
.78755 .49119 .79229 .49689 .80307 .49026 .79837 .48456 Metetra
.892 .418 0 r
.79837 .48456 .80307 .49026 .81384 .48319 .80917 .47749 Metetra
.877 .466 0 r
.80917 .47749 .81384 .48319 .82458 .47564 .81995 .46995 Metetra
.861 .518 0 r
.81995 .46995 .82458 .47564 .83528 .46758 .8307 .46189 Metetra
.843 .574 0 r
.8307 .46189 .83528 .46758 .84595 .45897 .8414 .45329 Metetra
.823 .632 0 r
.8414 .45329 .84595 .45897 .85656 .44978 .85206 .4441 Metetra
.8 .693 0 r
.85206 .4441 .85656 .44978 .86711 .43996 .86265 .4343 Metetra
.775 .755 0 r
.86265 .4343 .86711 .43996 .87759 .42949 .87318 .42383 Metetra
.777 .75 0 r
.23383 .61343 .23991 .61808 .24836 .62197 .24229 .61728 Metetra
.802 .688 0 r
.24229 .61728 .24836 .62197 .25692 .62525 .25085 .62054 Metetra
.824 .627 0 r
.25085 .62054 .25692 .62525 .26558 .62797 .25952 .62322 Metetra
.845 .569 0 r
.25952 .62322 .26558 .62797 .27434 .63015 .26829 .62537 Metetra
.863 .513 0 r
.26829 .62537 .27434 .63015 .28319 .63184 .27716 .62702 Metetra
.879 .461 0 r
.27716 .62702 .28319 .63184 .29212 .63305 .28611 .6282 Metetra
.893 .413 0 r
.28611 .6282 .29212 .63305 .30114 .63383 .29514 .62894 Metetra
.906 .369 0 r
.29514 .62894 .30114 .63383 .31023 .6342 .30425 .62928 Metetra
.917 .329 0 r
.30425 .62928 .31023 .6342 .3194 .63419 .31343 .62924 Metetra
.927 .292 0 r
.31343 .62924 .3194 .63419 .32863 .63383 .32268 .62885 Metetra
.936 .26 0 r
.32268 .62885 .32863 .63383 .33793 .63316 .33199 .62814 Metetra
.943 .231 0 r
.33199 .62814 .33793 .63316 .34728 .63219 .34137 .62714 Metetra
.95 .206 0 r
.34137 .62714 .34728 .63219 .35669 .63095 .3508 .62587 Metetra
.955 .185 0 r
.3508 .62587 .35669 .63095 .36616 .62947 .36028 .62436 Metetra
.96 .166 0 r
.36028 .62436 .36616 .62947 .37567 .62778 .36982 .62263 Metetra
.964 .15 0 r
.36982 .62263 .37567 .62778 .38523 .62588 .3794 .6207 Metetra
.967 .137 0 r
.3794 .6207 .38523 .62588 .39484 .62382 .38903 .6186 Metetra
.97 .126 0 r
.38903 .6186 .39484 .62382 .4045 .62159 .3987 .61635 Metetra
.972 .118 0 r
.3987 .61635 .4045 .62159 .41419 .61924 .40842 .61396 Metetra
.974 .11 0 r
.40842 .61396 .41419 .61924 .42393 .61676 .41818 .61146 Metetra
.975 .105 0 r
.41818 .61146 .42393 .61676 .43371 .61418 .42798 .60885 Metetra
.976 .101 0 r
.42798 .60885 .43371 .61418 .44352 .61151 .43782 .60615 Metetra
.977 .097 0 r
.43782 .60615 .44352 .61151 .45338 .60877 .4477 .60338 Metetra
.978 .095 0 r
.4477 .60338 .45338 .60877 .46327 .60597 .45761 .60055 Metetra
.978 .093 0 r
.45761 .60055 .46327 .60597 .4732 .60311 .46757 .59767 Metetra
.978 .092 0 r
.46757 .59767 .4732 .60311 .48317 .60022 .47756 .59475 Metetra
.978 .092 0 r
.47756 .59475 .48317 .60022 .49317 .59729 .48759 .5918 Metetra
.978 .091 0 r
.48759 .5918 .49317 .59729 .50321 .59433 .49765 .58882 Metetra
.979 .091 0 r
.49765 .58882 .50321 .59433 .51329 .59136 .50775 .58582 Metetra
.979 .091 0 r
.50775 .58582 .51329 .59136 .52341 .58837 .51789 .58281 Metetra
.979 .091 0 r
.51789 .58281 .52341 .58837 .53356 .58536 .52807 .57978 Metetra
.979 .091 0 r
.52807 .57978 .53356 .58536 .54375 .58234 .53829 .57674 Metetra
.979 .091 0 r
.53829 .57674 .54375 .58234 .55398 .57931 .54854 .57368 Metetra
.979 .091 0 r
.54854 .57368 .55398 .57931 .56425 .57626 .55883 .57062 Metetra
.979 .091 0 r
.55883 .57062 .56425 .57626 .57455 .57319 .56916 .56753 Metetra
.978 .091 0 r
.56916 .56753 .57455 .57319 .5849 .57011 .57953 .56443 Metetra
.978 .092 0 r
.57953 .56443 .5849 .57011 .59528 .567 .58994 .5613 Metetra
.978 .092 0 r
.58994 .5613 .59528 .567 .60569 .56385 .60038 .55814 Metetra
.978 .093 0 r
.60038 .55814 .60569 .56385 .61615 .56066 .61087 .55493 Metetra
.978 .095 0 r
.61087 .55493 .61615 .56066 .62665 .55741 .62139 .55167 Metetra
.977 .097 0 r
.62139 .55167 .62665 .55741 .63718 .55411 .63195 .54835 Metetra
.976 .101 0 r
.63195 .54835 .63718 .55411 .64774 .55072 .64254 .54495 Metetra
.975 .105 0 r
.64254 .54495 .64774 .55072 .65835 .54724 .65317 .54147 Metetra
.974 .11 0 r
.65317 .54147 .65835 .54724 .66898 .54366 .66384 .53787 Metetra
.972 .118 0 r
.66384 .53787 .66898 .54366 .67965 .53995 .67454 .53415 Metetra
.97 .126 0 r
.67454 .53415 .67965 .53995 .69035 .5361 .68527 .53029 Metetra
.967 .137 0 r
.68527 .53029 .69035 .5361 .70108 .53209 .69602 .52626 Metetra
.964 .15 0 r
.69602 .52626 .70108 .53209 .71184 .52789 .70681 .52206 Metetra
.96 .166 0 r
.70681 .52206 .71184 .52789 .72261 .52348 .71762 .51764 Metetra
.955 .185 0 r
.71762 .51764 .72261 .52348 .73341 .51884 .72845 .51299 Metetra
.95 .206 0 r
.72845 .51299 .73341 .51884 .74422 .51394 .73929 .50808 Metetra
.943 .231 0 r
.73929 .50808 .74422 .51394 .75505 .50875 .75015 .50289 Metetra
.936 .26 0 r
.75015 .50289 .75505 .50875 .76588 .50325 .76102 .49738 Metetra
.927 .292 0 r
.76102 .49738 .76588 .50325 .77672 .49741 .77189 .49153 Metetra
.917 .329 0 r
.77189 .49153 .77672 .49741 .78755 .49119 .78276 .4853 Metetra
.906 .369 0 r
.78276 .4853 .78755 .49119 .79837 .48456 .79361 .47867 Metetra
.893 .413 0 r
.79361 .47867 .79837 .48456 .80917 .47749 .80446 .47159 Metetra
.879 .461 0 r
.80446 .47159 .80917 .47749 .81995 .46995 .81527 .46404 Metetra
.863 .513 0 r
.81527 .46404 .81995 .46995 .8307 .46189 .82606 .45598 Metetra
.845 .569 0 r
.82606 .45598 .8307 .46189 .8414 .45329 .83681 .44737 Metetra
.824 .627 0 r
.83681 .44737 .8414 .45329 .85206 .4441 .8475 .43818 Metetra
.802 .688 0 r
.8475 .43818 .85206 .4441 .86265 .4343 .85814 .42836 Metetra
.777 .75 0 r
.85814 .42836 .86265 .4343 .87318 .42383 .86871 .41789 Metetra
.779 .747 0 r
.22773 .60853 .23383 .61343 .24229 .61728 .23619 .61236 Metetra
.803 .685 0 r
.23619 .61236 .24229 .61728 .25085 .62054 .24476 .61559 Metetra
.826 .624 0 r
.24476 .61559 .25085 .62054 .25952 .62322 .25344 .61826 Metetra
.846 .566 0 r
.25344 .61826 .25952 .62322 .26829 .62537 .26223 .62039 Metetra
.864 .51 0 r
.26223 .62039 .26829 .62537 .27716 .62702 .2711 .62201 Metetra
.88 .458 0 r
.2711 .62201 .27716 .62702 .28611 .6282 .28006 .62317 Metetra
.894 .41 0 r
.28006 .62317 .28611 .6282 .29514 .62894 .28911 .62389 Metetra
.907 .366 0 r
.28911 .62389 .29514 .62894 .30425 .62928 .29823 .6242 Metetra
.918 .326 0 r
.29823 .6242 .30425 .62928 .31343 .62924 .30743 .62414 Metetra
.928 .29 0 r
.30743 .62414 .31343 .62924 .32268 .62885 .3167 .62372 Metetra
.936 .258 0 r
.3167 .62372 .32268 .62885 .33199 .62814 .32603 .62299 Metetra
.944 .229 0 r
.32603 .62299 .33199 .62814 .34137 .62714 .33542 .62196 Metetra
.95 .205 0 r
.33542 .62196 .34137 .62714 .3508 .62587 .34487 .62067 Metetra
.956 .183 0 r
.34487 .62067 .3508 .62587 .36028 .62436 .35437 .61913 Metetra
.96 .165 0 r
.35437 .61913 .36028 .62436 .36982 .62263 .36393 .61738 Metetra
.964 .149 0 r
.36393 .61738 .36982 .62263 .3794 .6207 .37353 .61543 Metetra
.968 .136 0 r
.37353 .61543 .3794 .6207 .38903 .6186 .38318 .61331 Metetra
.97 .125 0 r
.38318 .61331 .38903 .6186 .3987 .61635 .39288 .61103 Metetra
.972 .117 0 r
.39288 .61103 .3987 .61635 .40842 .61396 .40261 .60862 Metetra
.974 .11 0 r
.40261 .60862 .40842 .61396 .41818 .61146 .4124 .60608 Metetra
.975 .104 0 r
.4124 .60608 .41818 .61146 .42798 .60885 .42222 .60345 Metetra
.976 .1 0 r
.42222 .60345 .42798 .60885 .43782 .60615 .43208 .60073 Metetra
.977 .097 0 r
.43208 .60073 .43782 .60615 .4477 .60338 .44198 .59794 Metetra
.978 .095 0 r
.44198 .59794 .4477 .60338 .45761 .60055 .45192 .59509 Metetra
.978 .093 0 r
.45192 .59509 .45761 .60055 .46757 .59767 .46189 .59218 Metetra
.978 .092 0 r
.46189 .59218 .46757 .59767 .47756 .59475 .47191 .58924 Metetra
.978 .092 0 r
.47191 .58924 .47756 .59475 .48759 .5918 .48196 .58626 Metetra
.979 .091 0 r
.48196 .58626 .48759 .5918 .49765 .58882 .49205 .58326 Metetra
.979 .091 0 r
.49205 .58326 .49765 .58882 .50775 .58582 .50218 .58024 Metetra
.979 .091 0 r
.50218 .58024 .50775 .58582 .51789 .58281 .51234 .57721 Metetra
.979 .091 0 r
.51234 .57721 .51789 .58281 .52807 .57978 .52254 .57416 Metetra
.979 .091 0 r
.52254 .57416 .52807 .57978 .53829 .57674 .53278 .57109 Metetra
.979 .091 0 r
.53278 .57109 .53829 .57674 .54854 .57368 .54306 .56802 Metetra
.979 .091 0 r
.54306 .56802 .54854 .57368 .55883 .57062 .55338 .56493 Metetra
.979 .091 0 r
.55338 .56493 .55883 .57062 .56916 .56753 .56374 .56183 Metetra
.979 .091 0 r
.56374 .56183 .56916 .56753 .57953 .56443 .57413 .55871 Metetra
.978 .092 0 r
.57413 .55871 .57953 .56443 .58994 .5613 .58456 .55556 Metetra
.978 .092 0 r
.58456 .55556 .58994 .5613 .60038 .55814 .59503 .55238 Metetra
.978 .093 0 r
.59503 .55238 .60038 .55814 .61087 .55493 .60554 .54915 Metetra
.978 .095 0 r
.60554 .54915 .61087 .55493 .62139 .55167 .61609 .54588 Metetra
.977 .097 0 r
.61609 .54588 .62139 .55167 .63195 .54835 .62668 .54254 Metetra
.976 .1 0 r
.62668 .54254 .63195 .54835 .64254 .54495 .6373 .53912 Metetra
.975 .104 0 r
.6373 .53912 .64254 .54495 .65317 .54147 .64796 .53561 Metetra
.974 .11 0 r
.64796 .53561 .65317 .54147 .66384 .53787 .65865 .532 Metetra
.972 .117 0 r
.65865 .532 .66384 .53787 .67454 .53415 .66938 .52827 Metetra
.97 .125 0 r
.66938 .52827 .67454 .53415 .68527 .53029 .68014 .52439 Metetra
.968 .136 0 r
.68014 .52439 .68527 .53029 .69602 .52626 .69093 .52034 Metetra
.964 .149 0 r
.69093 .52034 .69602 .52626 .70681 .52206 .70175 .51612 Metetra
.96 .165 0 r
.70175 .51612 .70681 .52206 .71762 .51764 .71259 .51168 Metetra
.956 .183 0 r
.71259 .51168 .71762 .51764 .72845 .51299 .72345 .50702 Metetra
.95 .205 0 r
.72345 .50702 .72845 .51299 .73929 .50808 .73432 .50209 Metetra
.944 .229 0 r
.73432 .50209 .73929 .50808 .75015 .50289 .74522 .49688 Metetra
.936 .258 0 r
.74522 .49688 .75015 .50289 .76102 .49738 .75612 .49136 Metetra
.928 .29 0 r
.75612 .49136 .76102 .49738 .77189 .49153 .76702 .48549 Metetra
.918 .326 0 r
.76702 .48549 .77189 .49153 .78276 .4853 .77792 .47924 Metetra
.907 .366 0 r
.77792 .47924 .78276 .4853 .79361 .47867 .78882 .47259 Metetra
.894 .41 0 r
.78882 .47259 .79361 .47867 .80446 .47159 .79969 .4655 Metetra
.88 .458 0 r
.79969 .4655 .80446 .47159 .81527 .46404 .81055 .45793 Metetra
.864 .51 0 r
.81055 .45793 .81527 .46404 .82606 .45598 .82137 .44985 Metetra
.846 .566 0 r
.82137 .44985 .82606 .45598 .83681 .44737 .83216 .44122 Metetra
.826 .624 0 r
.83216 .44122 .83681 .44737 .8475 .43818 .84289 .432 Metetra
.803 .685 0 r
.84289 .432 .8475 .43818 .85814 .42836 .85357 .42217 Metetra
.779 .747 0 r
.85357 .42217 .85814 .42836 .86871 .41789 .86418 .41167 Metetra
.779 .746 0 r
.22161 .60337 .22773 .60853 .23619 .61236 .23007 .6072 Metetra
.804 .684 0 r
.23007 .6072 .23619 .61236 .24476 .61559 .23865 .61042 Metetra
.826 .623 0 r
.23865 .61042 .24476 .61559 .25344 .61826 .24734 .61308 Metetra
.846 .565 0 r
.24734 .61308 .25344 .61826 .26223 .62039 .25613 .6152 Metetra
.864 .509 0 r
.25613 .6152 .26223 .62039 .2711 .62201 .26502 .61681 Metetra
.88 .458 0 r
.26502 .61681 .2711 .62201 .28006 .62317 .27399 .61796 Metetra
.894 .409 0 r
.27399 .61796 .28006 .62317 .28911 .62389 .28305 .61867 Metetra
.907 .365 0 r
.28305 .61867 .28911 .62389 .29823 .6242 .29219 .61897 Metetra
.918 .325 0 r
.29219 .61897 .29823 .6242 .30743 .62414 .3014 .61889 Metetra
.928 .289 0 r
.3014 .61889 .30743 .62414 .3167 .62372 .31068 .61846 Metetra
.937 .257 0 r
.31068 .61846 .3167 .62372 .32603 .62299 .32003 .61771 Metetra
.944 .229 0 r
.32003 .61771 .32603 .62299 .33542 .62196 .32944 .61667 Metetra
.95 .204 0 r
.32944 .61667 .33542 .62196 .34487 .62067 .3389 .61536 Metetra
.956 .183 0 r
.3389 .61536 .34487 .62067 .35437 .61913 .34842 .61381 Metetra
.961 .164 0 r
.34842 .61381 .35437 .61913 .36393 .61738 .358 .61203 Metetra
.964 .149 0 r
.358 .61203 .36393 .61738 .37353 .61543 .36762 .61007 Metetra
.968 .136 0 r
.36762 .61007 .37353 .61543 .38318 .61331 .37729 .60793 Metetra
.97 .125 0 r
.37729 .60793 .38318 .61331 .39288 .61103 .38701 .60563 Metetra
.972 .116 0 r
.38701 .60563 .39288 .61103 .40261 .60862 .39677 .6032 Metetra
.974 .109 0 r
.39677 .6032 .40261 .60862 .4124 .60608 .40657 .60065 Metetra
.975 .104 0 r
.40657 .60065 .4124 .60608 .42222 .60345 .41641 .59799 Metetra
.976 .1 0 r
.41641 .59799 .42222 .60345 .43208 .60073 .4263 .59526 Metetra
.977 .097 0 r
.4263 .59526 .43208 .60073 .44198 .59794 .43622 .59244 Metetra
.978 .095 0 r
.43622 .59244 .44198 .59794 .45192 .59509 .44618 .58957 Metetra
.978 .093 0 r
.44618 .58957 .45192 .59509 .46189 .59218 .45618 .58665 Metetra
.978 .092 0 r
.45618 .58665 .46189 .59218 .47191 .58924 .46622 .58368 Metetra
.978 .091 0 r
.46622 .58368 .47191 .58924 .48196 .58626 .4763 .58069 Metetra
.979 .091 0 r
.4763 .58069 .48196 .58626 .49205 .58326 .48641 .57766 Metetra
.979 .091 0 r
.48641 .57766 .49205 .58326 .50218 .58024 .49656 .57462 Metetra
.979 .091 0 r
.49656 .57462 .50218 .58024 .51234 .57721 .50675 .57157 Metetra
.979 .091 0 r
.50675 .57157 .51234 .57721 .52254 .57416 .51698 .56849 Metetra
.979 .091 0 r
.51698 .56849 .52254 .57416 .53278 .57109 .52724 .56541 Metetra
.979 .091 0 r
.52724 .56541 .53278 .57109 .54306 .56802 .53755 .56232 Metetra
.979 .091 0 r
.53755 .56232 .54306 .56802 .55338 .56493 .54789 .55921 Metetra
.979 .091 0 r
.54789 .55921 .55338 .56493 .56374 .56183 .55827 .55608 Metetra
.979 .091 0 r
.55827 .55608 .56374 .56183 .57413 .55871 .56869 .55294 Metetra
.978 .091 0 r
.56869 .55294 .57413 .55871 .58456 .55556 .57915 .54977 Metetra
.978 .092 0 r
.57915 .54977 .58456 .55556 .59503 .55238 .58965 .54656 Metetra
.978 .093 0 r
.58965 .54656 .59503 .55238 .60554 .54915 .60018 .54332 Metetra
.978 .095 0 r
.60018 .54332 .60554 .54915 .61609 .54588 .61076 .54002 Metetra
.977 .097 0 r
.61076 .54002 .61609 .54588 .62668 .54254 .62137 .53666 Metetra
.976 .1 0 r
.62137 .53666 .62668 .54254 .6373 .53912 .63202 .53322 Metetra
.975 .104 0 r
.63202 .53322 .6373 .53912 .64796 .53561 .64271 .52969 Metetra
.974 .109 0 r
.64271 .52969 .64796 .53561 .65865 .532 .65343 .52605 Metetra
.972 .116 0 r
.65343 .52605 .65865 .532 .66938 .52827 .66419 .52229 Metetra
.97 .125 0 r
.66419 .52229 .66938 .52827 .68014 .52439 .67498 .51839 Metetra
.968 .136 0 r
.67498 .51839 .68014 .52439 .69093 .52034 .6858 .51432 Metetra
.964 .149 0 r
.6858 .51432 .69093 .52034 .70175 .51612 .69664 .51007 Metetra
.961 .164 0 r
.69664 .51007 .70175 .51612 .71259 .51168 .70751 .50561 Metetra
.956 .183 0 r
.70751 .50561 .71259 .51168 .72345 .50702 .7184 .50092 Metetra
.95 .204 0 r
.7184 .50092 .72345 .50702 .73432 .50209 .72931 .49597 Metetra
.944 .229 0 r
.72931 .49597 .73432 .50209 .74522 .49688 .74024 .49073 Metetra
.937 .257 0 r
.74024 .49073 .74522 .49688 .75612 .49136 .75117 .48518 Metetra
.928 .289 0 r
.75117 .48518 .75612 .49136 .76702 .48549 .76211 .47928 Metetra
.918 .325 0 r
.76211 .47928 .76702 .48549 .77792 .47924 .77304 .47301 Metetra
.907 .365 0 r
.77304 .47301 .77792 .47924 .78882 .47259 .78397 .46633 Metetra
.894 .409 0 r
.78397 .46633 .78882 .47259 .79969 .4655 .79488 .4592 Metetra
.88 .458 0 r
.79488 .4592 .79969 .4655 .81055 .45793 .80578 .4516 Metetra
.864 .509 0 r
.80578 .4516 .81055 .45793 .82137 .44985 .81664 .44349 Metetra
.846 .565 0 r
.81664 .44349 .82137 .44985 .83216 .44122 .82746 .43483 Metetra
.826 .623 0 r
.82746 .43483 .83216 .44122 .84289 .432 .83823 .42558 Metetra
.804 .684 0 r
.83823 .42558 .84289 .432 .85357 .42217 .84895 .41571 Metetra
.779 .746 0 r
.84895 .41571 .85357 .42217 .86418 .41167 .85959 .40517 Metetra
.779 .747 0 r
.21547 .59796 .22161 .60337 .23007 .6072 .22393 .60179 Metetra
.803 .685 0 r
.22393 .60179 .23007 .6072 .23865 .61042 .23252 .60502 Metetra
.826 .624 0 r
.23252 .60502 .23865 .61042 .24734 .61308 .24121 .60768 Metetra
.846 .566 0 r
.24121 .60768 .24734 .61308 .25613 .6152 .25001 .6098 Metetra
.864 .51 0 r
.25001 .6098 .25613 .6152 .26502 .61681 .2589 .61142 Metetra
.88 .458 0 r
.2589 .61142 .26502 .61681 .27399 .61796 .26789 .61257 Metetra
.894 .41 0 r
.26789 .61257 .27399 .61796 .28305 .61867 .27696 .61327 Metetra
.907 .366 0 r
.27696 .61327 .28305 .61867 .29219 .61897 .28611 .61357 Metetra
.918 .326 0 r
.28611 .61357 .29219 .61897 .3014 .61889 .29533 .61349 Metetra
.928 .29 0 r
.29533 .61349 .3014 .61889 .31068 .61846 .30463 .61305 Metetra
.936 .258 0 r
.30463 .61305 .31068 .61846 .32003 .61771 .31399 .6123 Metetra
.944 .229 0 r
.31399 .6123 .32003 .61771 .32944 .61667 .32342 .61125 Metetra
.95 .205 0 r
.32342 .61125 .32944 .61667 .3389 .61536 .3329 .60993 Metetra
.956 .183 0 r
.3329 .60993 .3389 .61536 .34842 .61381 .34244 .60837 Metetra
.96 .165 0 r
.34244 .60837 .34842 .61381 .358 .61203 .35203 .60659 Metetra
.964 .149 0 r
.35203 .60659 .358 .61203 .36762 .61007 .36168 .60461 Metetra
.968 .136 0 r
.36168 .60461 .36762 .61007 .37729 .60793 .37137 .60246 Metetra
.97 .125 0 r
.37137 .60246 .37729 .60793 .38701 .60563 .3811 .60015 Metetra
.972 .117 0 r
.3811 .60015 .38701 .60563 .39677 .6032 .39088 .59771 Metetra
.974 .11 0 r
.39088 .59771 .39677 .6032 .40657 .60065 .40071 .59514 Metetra
.975 .104 0 r
.40071 .59514 .40657 .60065 .41641 .59799 .41057 .59247 Metetra
.976 .1 0 r
.41057 .59247 .41641 .59799 .4263 .59526 .42048 .58972 Metetra
.977 .097 0 r
.42048 .58972 .4263 .59526 .43622 .59244 .43043 .58689 Metetra
.978 .095 0 r
.43043 .58689 .43622 .59244 .44618 .58957 .44041 .584 Metetra
.978 .093 0 r
.44041 .584 .44618 .58957 .45618 .58665 .45043 .58106 Metetra
.978 .092 0 r
.45043 .58106 .45618 .58665 .46622 .58368 .46049 .57808 Metetra
.978 .092 0 r
.46049 .57808 .46622 .58368 .4763 .58069 .47059 .57507 Metetra
.979 .091 0 r
.47059 .57507 .4763 .58069 .48641 .57766 .48073 .57202 Metetra
.979 .091 0 r
.48073 .57202 .48641 .57766 .49656 .57462 .49091 .56896 Metetra
.979 .091 0 r
.49091 .56896 .49656 .57462 .50675 .57157 .50112 .56589 Metetra
.979 .091 0 r
.50112 .56589 .50675 .57157 .51698 .56849 .51137 .56279 Metetra
.979 .091 0 r
.51137 .56279 .51698 .56849 .52724 .56541 .52166 .55969 Metetra
.979 .091 0 r
.52166 .55969 .52724 .56541 .53755 .56232 .53199 .55657 Metetra
.979 .091 0 r
.53199 .55657 .53755 .56232 .54789 .55921 .54236 .55344 Metetra
.979 .091 0 r
.54236 .55344 .54789 .55921 .55827 .55608 .55277 .5503 Metetra
.979 .091 0 r
.55277 .5503 .55827 .55608 .56869 .55294 .56321 .54713 Metetra
.978 .092 0 r
.56321 .54713 .56869 .55294 .57915 .54977 .5737 .54393 Metetra
.978 .092 0 r
.5737 .54393 .57915 .54977 .58965 .54656 .58422 .5407 Metetra
.978 .093 0 r
.58422 .5407 .58965 .54656 .60018 .54332 .59479 .53743 Metetra
.978 .095 0 r
.59479 .53743 .60018 .54332 .61076 .54002 .60539 .5341 Metetra
.977 .097 0 r
.60539 .5341 .61076 .54002 .62137 .53666 .61603 .53072 Metetra
.976 .1 0 r
.61603 .53072 .62137 .53666 .63202 .53322 .62671 .52725 Metetra
.975 .104 0 r
.62671 .52725 .63202 .53322 .64271 .52969 .63742 .52369 Metetra
.974 .11 0 r
.63742 .52369 .64271 .52969 .65343 .52605 .64817 .52003 Metetra
.972 .117 0 r
.64817 .52003 .65343 .52605 .66419 .52229 .65896 .51624 Metetra
.97 .125 0 r
.65896 .51624 .66419 .52229 .67498 .51839 .66977 .5123 Metetra
.968 .136 0 r
.66977 .5123 .67498 .51839 .6858 .51432 .68062 .5082 Metetra
.964 .149 0 r
.68062 .5082 .6858 .51432 .69664 .51007 .6915 .50392 Metetra
.96 .165 0 r
.6915 .50392 .69664 .51007 .70751 .50561 .7024 .49943 Metetra
.956 .183 0 r
.7024 .49943 .70751 .50561 .7184 .50092 .71332 .4947 Metetra
.95 .205 0 r
.71332 .4947 .7184 .50092 .72931 .49597 .72426 .48971 Metetra
.944 .229 0 r
.72426 .48971 .72931 .49597 .74024 .49073 .73522 .48444 Metetra
.936 .258 0 r
.73522 .48444 .74024 .49073 .75117 .48518 .74618 .47885 Metetra
.928 .29 0 r
.74618 .47885 .75117 .48518 .76211 .47928 .75715 .47291 Metetra
.918 .326 0 r
.75715 .47291 .76211 .47928 .77304 .47301 .76812 .4666 Metetra
.907 .366 0 r
.76812 .4666 .77304 .47301 .78397 .46633 .77908 .45988 Metetra
.894 .41 0 r
.77908 .45988 .78397 .46633 .79488 .4592 .79003 .45271 Metetra
.88 .458 0 r
.79003 .45271 .79488 .4592 .80578 .4516 .80095 .44506 Metetra
.864 .51 0 r
.80095 .44506 .80578 .4516 .81664 .44349 .81185 .4369 Metetra
.846 .566 0 r
.81185 .4369 .81664 .44349 .82746 .43483 .82271 .42819 Metetra
.826 .624 0 r
.82271 .42819 .82746 .43483 .83823 .42558 .83352 .4189 Metetra
.803 .685 0 r
.83352 .4189 .83823 .42558 .84895 .41571 .84427 .40898 Metetra
.779 .747 0 r
.84427 .40898 .84895 .41571 .85959 .40517 .85495 .39839 Metetra
.777 .75 0 r
.2093 .59229 .21547 .59796 .22393 .60179 .21777 .59614 Metetra
.802 .688 0 r
.21777 .59614 .22393 .60179 .23252 .60502 .22636 .59939 Metetra
.824 .627 0 r
.22636 .59939 .23252 .60502 .24121 .60768 .23506 .60207 Metetra
.845 .569 0 r
.23506 .60207 .24121 .60768 .25001 .6098 .24386 .6042 Metetra
.863 .513 0 r
.24386 .6042 .25001 .6098 .2589 .61142 .25276 .60583 Metetra
.879 .461 0 r
.25276 .60583 .2589 .61142 .26789 .61257 .26176 .60699 Metetra
.893 .413 0 r
.26176 .60699 .26789 .61257 .27696 .61327 .27084 .60771 Metetra
.906 .369 0 r
.27084 .60771 .27696 .61327 .28611 .61357 .28 .60801 Metetra
.917 .329 0 r
.28 .60801 .28611 .61357 .29533 .61349 .28924 .60793 Metetra
.927 .292 0 r
.28924 .60793 .29533 .61349 .30463 .61305 .29855 .60751 Metetra
.936 .26 0 r
.29855 .60751 .30463 .61305 .31399 .6123 .30792 .60675 Metetra
.943 .231 0 r
.30792 .60675 .31399 .6123 .32342 .61125 .31736 .60571 Metetra
.95 .206 0 r
.31736 .60571 .32342 .61125 .3329 .60993 .32687 .60439 Metetra
.955 .185 0 r
.32687 .60439 .3329 .60993 .34244 .60837 .33642 .60283 Metetra
.96 .166 0 r
.33642 .60283 .34244 .60837 .35203 .60659 .34603 .60104 Metetra
.964 .15 0 r
.34603 .60104 .35203 .60659 .36168 .60461 .35569 .59906 Metetra
.967 .137 0 r
.35569 .59906 .36168 .60461 .37137 .60246 .3654 .59691 Metetra
.97 .126 0 r
.3654 .59691 .37137 .60246 .3811 .60015 .37516 .59459 Metetra
.972 .118 0 r
.37516 .59459 .3811 .60015 .39088 .59771 .38496 .59214 Metetra
.974 .11 0 r
.38496 .59214 .39088 .59771 .40071 .59514 .39481 .58957 Metetra
.975 .105 0 r
.39481 .58957 .40071 .59514 .41057 .59247 .40469 .58689 Metetra
.976 .101 0 r
.40469 .58689 .41057 .59247 .42048 .58972 .41462 .58413 Metetra
.977 .097 0 r
.41462 .58413 .42048 .58972 .43043 .58689 .42459 .58129 Metetra
.978 .095 0 r
.42459 .58129 .43043 .58689 .44041 .584 .4346 .57838 Metetra
.978 .093 0 r
.4346 .57838 .44041 .584 .45043 .58106 .44464 .57543 Metetra
.978 .092 0 r
.44464 .57543 .45043 .58106 .46049 .57808 .45473 .57243 Metetra
.978 .092 0 r
.45473 .57243 .46049 .57808 .47059 .57507 .46485 .5694 Metetra
.978 .091 0 r
.46485 .5694 .47059 .57507 .48073 .57202 .47501 .56634 Metetra
.979 .091 0 r
.47501 .56634 .48073 .57202 .49091 .56896 .48521 .56326 Metetra
.979 .091 0 r
.48521 .56326 .49091 .56896 .50112 .56589 .49545 .56016 Metetra
.979 .091 0 r
.49545 .56016 .50112 .56589 .51137 .56279 .50573 .55705 Metetra
.979 .091 0 r
.50573 .55705 .51137 .56279 .52166 .55969 .51604 .55393 Metetra
.979 .091 0 r
.51604 .55393 .52166 .55969 .53199 .55657 .5264 .55079 Metetra
.979 .091 0 r
.5264 .55079 .53199 .55657 .54236 .55344 .53679 .54763 Metetra
.979 .091 0 r
.53679 .54763 .54236 .55344 .55277 .5503 .54723 .54446 Metetra
.978 .091 0 r
.54723 .54446 .55277 .5503 .56321 .54713 .5577 .54127 Metetra
.978 .092 0 r
.5577 .54127 .56321 .54713 .5737 .54393 .56821 .53804 Metetra
.978 .092 0 r
.56821 .53804 .5737 .54393 .58422 .5407 .57876 .53479 Metetra
.978 .093 0 r
.57876 .53479 .58422 .5407 .59479 .53743 .58935 .53149 Metetra
.978 .095 0 r
.58935 .53149 .59479 .53743 .60539 .5341 .59998 .52813 Metetra
.977 .097 0 r
.59998 .52813 .60539 .5341 .61603 .53072 .61065 .52471 Metetra
.976 .101 0 r
.61065 .52471 .61603 .53072 .62671 .52725 .62135 .52121 Metetra
.975 .105 0 r
.62135 .52121 .62671 .52725 .63742 .52369 .6321 .51762 Metetra
.974 .11 0 r
.6321 .51762 .63742 .52369 .64817 .52003 .64287 .51392 Metetra
.972 .118 0 r
.64287 .51392 .64817 .52003 .65896 .51624 .65369 .51009 Metetra
.97 .126 0 r
.65369 .51009 .65896 .51624 .66977 .5123 .66453 .50612 Metetra
.967 .137 0 r
.66453 .50612 .66977 .5123 .68062 .5082 .67541 .50198 Metetra
.964 .15 0 r
.67541 .50198 .68062 .5082 .6915 .50392 .68631 .49766 Metetra
.96 .166 0 r
.68631 .49766 .6915 .50392 .7024 .49943 .69724 .49312 Metetra
.955 .185 0 r
.69724 .49312 .7024 .49943 .71332 .4947 .7082 .48835 Metetra
.95 .206 0 r
.7082 .48835 .71332 .4947 .72426 .48971 .71917 .48332 Metetra
.943 .231 0 r
.71917 .48332 .72426 .48971 .73522 .48444 .73015 .478 Metetra
.936 .26 0 r
.73015 .478 .73522 .48444 .74618 .47885 .74115 .47236 Metetra
.927 .292 0 r
.74115 .47236 .74618 .47885 .75715 .47291 .75215 .46637 Metetra
.917 .329 0 r
.75215 .46637 .75715 .47291 .76812 .4666 .76315 .46001 Metetra
.906 .369 0 r
.76315 .46001 .76812 .4666 .77908 .45988 .77414 .45323 Metetra
.893 .413 0 r
.77414 .45323 .77908 .45988 .79003 .45271 .78512 .44601 Metetra
.879 .461 0 r
.78512 .44601 .79003 .45271 .80095 .44506 .79608 .43831 Metetra
.863 .513 0 r
.79608 .43831 .80095 .44506 .81185 .4369 .80701 .43009 Metetra
.845 .569 0 r
.80701 .43009 .81185 .4369 .82271 .42819 .8179 .42132 Metetra
.824 .627 0 r
.8179 .42132 .82271 .42819 .83352 .4189 .82875 .41197 Metetra
.802 .688 0 r
.82875 .41197 .83352 .4189 .84427 .40898 .83954 .40198 Metetra
.777 .75 0 r
.83954 .40198 .84427 .40898 .85495 .39839 .85025 .39133 Metetra
.775 .755 0 r
.20313 .58636 .2093 .59229 .21777 .59614 .21159 .59025 Metetra
.8 .693 0 r
.21159 .59025 .21777 .59614 .22636 .59939 .22018 .59353 Metetra
.823 .632 0 r
.22018 .59353 .22636 .59939 .23506 .60207 .22888 .59623 Metetra
.843 .574 0 r
.22888 .59623 .23506 .60207 .24386 .6042 .23769 .59839 Metetra
.861 .518 0 r
.23769 .59839 .24386 .6042 .25276 .60583 .2466 .60005 Metetra
.877 .466 0 r
.2466 .60005 .25276 .60583 .26176 .60699 .2556 .60123 Metetra
.892 .418 0 r
.2556 .60123 .26176 .60699 .27084 .60771 .26469 .60196 Metetra
.905 .373 0 r
.26469 .60196 .27084 .60771 .28 .60801 .27386 .60228 Metetra
.916 .333 0 r
.27386 .60228 .28 .60801 .28924 .60793 .28311 .60222 Metetra
.926 .296 0 r
.28311 .60222 .28924 .60793 .29855 .60751 .29243 .60181 Metetra
.935 .264 0 r
.29243 .60181 .29855 .60751 .30792 .60675 .30182 .60107 Metetra
.943 .235 0 r
.30182 .60107 .30792 .60675 .31736 .60571 .31128 .60004 Metetra
.949 .209 0 r
.31128 .60004 .31736 .60571 .32687 .60439 .32079 .59873 Metetra
.955 .188 0 r
.32079 .59873 .32687 .60439 .33642 .60283 .33037 .59717 Metetra
.959 .169 0 r
.33037 .59717 .33642 .60283 .34603 .60104 .34 .5954 Metetra
.963 .153 0 r
.34 .5954 .34603 .60104 .35569 .59906 .34967 .59342 Metetra
.967 .139 0 r
.34967 .59342 .35569 .59906 .3654 .59691 .3594 .59126 Metetra
.969 .128 0 r
.3594 .59126 .3654 .59691 .37516 .59459 .36918 .58895 Metetra
.972 .119 0 r
.36918 .58895 .37516 .59459 .38496 .59214 .379 .58649 Metetra
.973 .112 0 r
.379 .58649 .38496 .59214 .39481 .58957 .38887 .58392 Metetra
.975 .106 0 r
.38887 .58392 .39481 .58957 .40469 .58689 .39878 .58124 Metetra
.976 .102 0 r
.39878 .58124 .40469 .58689 .41462 .58413 .40873 .57847 Metetra
.977 .098 0 r
.40873 .57847 .41462 .58413 .42459 .58129 .41872 .57562 Metetra
.977 .096 0 r
.41872 .57562 .42459 .58129 .4346 .57838 .42875 .57271 Metetra
.978 .094 0 r
.42875 .57271 .4346 .57838 .44464 .57543 .43882 .56974 Metetra
.978 .093 0 r
.43882 .56974 .44464 .57543 .45473 .57243 .44892 .56673 Metetra
.978 .092 0 r
.44892 .56673 .45473 .57243 .46485 .5694 .45907 .56369 Metetra
.978 .091 0 r
.45907 .56369 .46485 .5694 .47501 .56634 .46926 .56061 Metetra
.978 .091 0 r
.46926 .56061 .47501 .56634 .48521 .56326 .47948 .55751 Metetra
.979 .091 0 r
.47948 .55751 .48521 .56326 .49545 .56016 .48975 .5544 Metetra
.979 .091 0 r
.48975 .5544 .49545 .56016 .50573 .55705 .50005 .55127 Metetra
.979 .091 0 r
.50005 .55127 .50573 .55705 .51604 .55393 .51039 .54812 Metetra
.979 .091 0 r
.51039 .54812 .51604 .55393 .5264 .55079 .52077 .54496 Metetra
.979 .091 0 r
.52077 .54496 .5264 .55079 .53679 .54763 .53119 .54178 Metetra
.978 .091 0 r
.53119 .54178 .53679 .54763 .54723 .54446 .54165 .53858 Metetra
.978 .091 0 r
.54165 .53858 .54723 .54446 .5577 .54127 .55214 .53536 Metetra
.978 .092 0 r
.55214 .53536 .5577 .54127 .56821 .53804 .56268 .5321 Metetra
.978 .093 0 r
.56268 .5321 .56821 .53804 .57876 .53479 .57326 .52881 Metetra
.978 .094 0 r
.57326 .52881 .57876 .53479 .58935 .53149 .58388 .52548 Metetra
.977 .096 0 r
.58388 .52548 .58935 .53149 .59998 .52813 .59453 .52209 Metetra
.977 .098 0 r
.59453 .52209 .59998 .52813 .61065 .52471 .60523 .51863 Metetra
.976 .102 0 r
.60523 .51863 .61065 .52471 .62135 .52121 .61596 .5151 Metetra
.975 .106 0 r
.61596 .5151 .62135 .52121 .6321 .51762 .62673 .51147 Metetra
.973 .112 0 r
.62673 .51147 .6321 .51762 .64287 .51392 .63754 .50772 Metetra
.972 .119 0 r
.63754 .50772 .64287 .51392 .65369 .51009 .64838 .50385 Metetra
.969 .128 0 r
.64838 .50385 .65369 .51009 .66453 .50612 .65925 .49984 Metetra
.967 .139 0 r
.65925 .49984 .66453 .50612 .67541 .50198 .67016 .49565 Metetra
.963 .153 0 r
.67016 .49565 .67541 .50198 .68631 .49766 .68109 .49128 Metetra
.959 .169 0 r
.68109 .49128 .68631 .49766 .69724 .49312 .69205 .48669 Metetra
.955 .188 0 r
.69205 .48669 .69724 .49312 .7082 .48835 .70303 .48187 Metetra
.949 .209 0 r
.70303 .48187 .7082 .48835 .71917 .48332 .71403 .47679 Metetra
.943 .235 0 r
.71403 .47679 .71917 .48332 .73015 .478 .72505 .47141 Metetra
.935 .264 0 r
.72505 .47141 .73015 .478 .74115 .47236 .73607 .46571 Metetra
.926 .296 0 r
.73607 .46571 .74115 .47236 .75215 .46637 .74711 .45966 Metetra
.916 .333 0 r
.74711 .45966 .75215 .46637 .76315 .46001 .75814 .45324 Metetra
.905 .373 0 r
.75814 .45324 .76315 .46001 .77414 .45323 .76916 .4464 Metetra
.892 .418 0 r
.76916 .4464 .77414 .45323 .78512 .44601 .78017 .43911 Metetra
.877 .466 0 r
.78017 .43911 .78512 .44601 .79608 .43831 .79116 .43134 Metetra
.861 .518 0 r
.79116 .43134 .79608 .43831 .80701 .43009 .80212 .42305 Metetra
.843 .574 0 r
.80212 .42305 .80701 .43009 .8179 .42132 .81305 .41421 Metetra
.823 .632 0 r
.81305 .41421 .8179 .42132 .82875 .41197 .82393 .40477 Metetra
.8 .693 0 r
.82393 .40477 .82875 .41197 .83954 .40198 .83475 .39471 Metetra
.775 .755 0 r
.83475 .39471 .83954 .40198 .85025 .39133 .8455 .38398 Metetra
.772 .762 0 r
.19693 .58017 .20313 .58636 .21159 .59025 .2054 .5841 Metetra
.797 .7 0 r
.2054 .5841 .21159 .59025 .22018 .59353 .21399 .58742 Metetra
.82 .64 0 r
.21399 .58742 .22018 .59353 .22888 .59623 .22269 .59016 Metetra
.84 .581 0 r
.22269 .59016 .22888 .59623 .23769 .59839 .2315 .59236 Metetra
.859 .525 0 r
.2315 .59236 .23769 .59839 .2466 .60005 .24041 .59405 Metetra
.875 .473 0 r
.24041 .59405 .2466 .60005 .2556 .60123 .24942 .59527 Metetra
.89 .424 0 r
.24942 .59527 .2556 .60123 .26469 .60196 .25851 .59603 Metetra
.903 .379 0 r
.25851 .59603 .26469 .60196 .27386 .60228 .26769 .59639 Metetra
.915 .339 0 r
.26769 .59639 .27386 .60228 .28311 .60222 .27695 .59635 Metetra
.925 .302 0 r
.27695 .59635 .28311 .60222 .29243 .60181 .28629 .59596 Metetra
.934 .269 0 r
.28629 .59596 .29243 .60181 .30182 .60107 .29569 .59525 Metetra
.941 .24 0 r
.29569 .59525 .30182 .60107 .31128 .60004 .30516 .59423 Metetra
.948 .214 0 r
.30516 .59423 .31128 .60004 .32079 .59873 .31469 .59294 Metetra
.954 .192 0 r
.31469 .59294 .32079 .59873 .33037 .59717 .32428 .5914 Metetra
.959 .172 0 r
.32428 .5914 .33037 .59717 .34 .5954 .33392 .58964 Metetra
.963 .156 0 r
.33392 .58964 .34 .5954 .34967 .59342 .34362 .58767 Metetra
.966 .142 0 r
.34362 .58767 .34967 .59342 .3594 .59126 .35337 .58552 Metetra
.969 .131 0 r
.35337 .58552 .3594 .59126 .36918 .58895 .36316 .58322 Metetra
.971 .121 0 r
.36316 .58322 .36918 .58895 .379 .58649 .373 .58077 Metetra
.973 .114 0 r
.373 .58077 .379 .58649 .38887 .58392 .38289 .57819 Metetra
.974 .108 0 r
.38289 .57819 .38887 .58392 .39878 .58124 .39282 .57551 Metetra
.976 .103 0 r
.39282 .57551 .39878 .58124 .40873 .57847 .40279 .57274 Metetra
.977 .099 0 r
.40279 .57274 .40873 .57847 .41872 .57562 .4128 .56989 Metetra
.977 .097 0 r
.4128 .56989 .41872 .57562 .42875 .57271 .42286 .56697 Metetra
.978 .095 0 r
.42286 .56697 .42875 .57271 .43882 .56974 .43295 .56399 Metetra
.978 .093 0 r
.43295 .56399 .43882 .56974 .44892 .56673 .44308 .56098 Metetra
.978 .092 0 r
.44308 .56098 .44892 .56673 .45907 .56369 .45325 .55792 Metetra
.978 .092 0 r
.45325 .55792 .45907 .56369 .46926 .56061 .46346 .55483 Metetra
.978 .091 0 r
.46346 .55483 .46926 .56061 .47948 .55751 .47371 .55172 Metetra
.978 .091 0 r
.47371 .55172 .47948 .55751 .48975 .5544 .484 .54858 Metetra
.979 .091 0 r
.484 .54858 .48975 .5544 .50005 .55127 .49432 .54543 Metetra
.979 .091 0 r
.49432 .54543 .50005 .55127 .51039 .54812 .50469 .54226 Metetra
.979 .091 0 r
.50469 .54226 .51039 .54812 .52077 .54496 .5151 .53907 Metetra
.978 .091 0 r
.5151 .53907 .52077 .54496 .53119 .54178 .52554 .53587 Metetra
.978 .091 0 r
.52554 .53587 .53119 .54178 .54165 .53858 .53603 .53264 Metetra
.978 .092 0 r
.53603 .53264 .54165 .53858 .55214 .53536 .54655 .52939 Metetra
.978 .092 0 r
.54655 .52939 .55214 .53536 .56268 .5321 .55711 .52611 Metetra
.978 .093 0 r
.55711 .52611 .56268 .5321 .57326 .52881 .56772 .52278 Metetra
.978 .095 0 r
.56772 .52278 .57326 .52881 .58388 .52548 .57836 .51941 Metetra
.977 .097 0 r
.57836 .51941 .58388 .52548 .59453 .52209 .58905 .51598 Metetra
.977 .099 0 r
.58905 .51598 .59453 .52209 .60523 .51863 .59977 .51249 Metetra
.976 .103 0 r
.59977 .51249 .60523 .51863 .61596 .5151 .61053 .50891 Metetra
.974 .108 0 r
.61053 .50891 .61596 .5151 .62673 .51147 .62133 .50523 Metetra
.973 .114 0 r
.62133 .50523 .62673 .51147 .63754 .50772 .63216 .50144 Metetra
.971 .121 0 r
.63216 .50144 .63754 .50772 .64838 .50385 .64303 .49752 Metetra
.969 .131 0 r
.64303 .49752 .64838 .50385 .65925 .49984 .65393 .49345 Metetra
.966 .142 0 r
.65393 .49345 .65925 .49984 .67016 .49565 .66486 .48921 Metetra
.963 .156 0 r
.66486 .48921 .67016 .49565 .68109 .49128 .67583 .48478 Metetra
.959 .172 0 r
.67583 .48478 .68109 .49128 .69205 .48669 .68681 .48014 Metetra
.954 .192 0 r
.68681 .48014 .69205 .48669 .70303 .48187 .69782 .47526 Metetra
.948 .214 0 r
.69782 .47526 .70303 .48187 .71403 .47679 .70885 .4701 Metetra
.941 .24 0 r
.70885 .4701 .71403 .47679 .72505 .47141 .7199 .46466 Metetra
.934 .269 0 r
.7199 .46466 .72505 .47141 .73607 .46571 .73096 .4589 Metetra
.925 .302 0 r
.73096 .4589 .73607 .46571 .74711 .45966 .74202 .45278 Metetra
.915 .339 0 r
.74202 .45278 .74711 .45966 .75814 .45324 .75308 .44628 Metetra
.903 .379 0 r
.75308 .44628 .75814 .45324 .76916 .4464 .76413 .43936 Metetra
.89 .424 0 r
.76413 .43936 .76916 .4464 .78017 .43911 .77517 .43199 Metetra
.875 .473 0 r
.77517 .43199 .78017 .43911 .79116 .43134 .7862 .42414 Metetra
.859 .525 0 r
.7862 .42414 .79116 .43134 .80212 .42305 .79719 .41577 Metetra
.84 .581 0 r
.79719 .41577 .80212 .42305 .81305 .41421 .80814 .40684 Metetra
.82 .64 0 r
.80814 .40684 .81305 .41421 .82393 .40477 .81905 .39732 Metetra
.797 .7 0 r
.81905 .39732 .82393 .40477 .83475 .39471 .8299 .38716 Metetra
.772 .762 0 r
.8299 .38716 .83475 .39471 .8455 .38398 .84069 .37634 Metetra
.766 .768 0 r
.19073 .57371 .19693 .58017 .2054 .5841 .19919 .57769 Metetra
.794 .709 0 r
.19919 .57769 .2054 .5841 .21399 .58742 .20777 .58107 Metetra
.817 .649 0 r
.20777 .58107 .21399 .58742 .22269 .59016 .21647 .58386 Metetra
.837 .59 0 r
.21647 .58386 .22269 .59016 .2315 .59236 .22528 .58611 Metetra
.856 .534 0 r
.22528 .58611 .2315 .59236 .24041 .59405 .23419 .58785 Metetra
.873 .482 0 r
.23419 .58785 .24041 .59405 .24942 .59527 .24321 .58911 Metetra
.887 .433 0 r
.24321 .58911 .24942 .59527 .25851 .59603 .25231 .58992 Metetra
.901 .388 0 r
.25231 .58992 .25851 .59603 .26769 .59639 .2615 .59031 Metetra
.912 .346 0 r
.2615 .59031 .26769 .59639 .27695 .59635 .27076 .59031 Metetra
.923 .309 0 r
.27076 .59031 .27695 .59635 .28629 .59596 .28011 .58996 Metetra
.932 .275 0 r
.28011 .58996 .28629 .59596 .29569 .59525 .28952 .58927 Metetra
.94 .246 0 r
.28952 .58927 .29569 .59525 .30516 .59423 .299 .58829 Metetra
.946 .22 0 r
.299 .58829 .30516 .59423 .31469 .59294 .30855 .58702 Metetra
.952 .197 0 r
.30855 .58702 .31469 .59294 .32428 .5914 .31815 .58551 Metetra
.957 .177 0 r
.31815 .58551 .32428 .5914 .33392 .58964 .32781 .58376 Metetra
.962 .16 0 r
.32781 .58376 .33392 .58964 .34362 .58767 .33753 .58181 Metetra
.965 .146 0 r
.33753 .58181 .34362 .58767 .35337 .58552 .34729 .57968 Metetra
.968 .134 0 r
.34729 .57968 .35337 .58552 .36316 .58322 .35711 .57739 Metetra
.97 .124 0 r
.35711 .57739 .36316 .58322 .373 .58077 .36697 .57495 Metetra
.972 .116 0 r
.36697 .57495 .373 .58077 .38289 .57819 .37687 .57238 Metetra
.974 .11 0 r
.37687 .57238 .38289 .57819 .39282 .57551 .38682 .56971 Metetra
.975 .105 0 r
.38682 .56971 .39282 .57551 .40279 .57274 .39682 .56694 Metetra
.976 .101 0 r
.39682 .56694 .40279 .57274 .4128 .56989 .40685 .56409 Metetra
.977 .098 0 r
.40685 .56409 .4128 .56989 .42286 .56697 .41693 .56116 Metetra
.977 .096 0 r
.41693 .56116 .42286 .56697 .43295 .56399 .42704 .55819 Metetra
.978 .094 0 r
.42704 .55819 .43295 .56399 .44308 .56098 .4372 .55516 Metetra
.978 .093 0 r
.4372 .55516 .44308 .56098 .45325 .55792 .44739 .55209 Metetra
.978 .092 0 r
.44739 .55209 .45325 .55792 .46346 .55483 .45762 .54899 Metetra
.978 .092 0 r
.45762 .54899 .46346 .55483 .47371 .55172 .4679 .54586 Metetra
.978 .092 0 r
.4679 .54586 .47371 .55172 .484 .54858 .47821 .54271 Metetra
.978 .092 0 r
.47821 .54271 .484 .54858 .49432 .54543 .48856 .53954 Metetra
.978 .091 0 r
.48856 .53954 .49432 .54543 .50469 .54226 .49895 .53635 Metetra
.978 .092 0 r
.49895 .53635 .50469 .54226 .5151 .53907 .50938 .53314 Metetra
.978 .092 0 r
.50938 .53314 .5151 .53907 .52554 .53587 .51986 .5299 Metetra
.978 .092 0 r
.51986 .5299 .52554 .53587 .53603 .53264 .53037 .52665 Metetra
.978 .092 0 r
.53037 .52665 .53603 .53264 .54655 .52939 .54092 .52336 Metetra
.978 .093 0 r
.54092 .52336 .54655 .52939 .55711 .52611 .55151 .52004 Metetra
.978 .094 0 r
.55151 .52004 .55711 .52611 .56772 .52278 .56214 .51668 Metetra
.977 .096 0 r
.56214 .51668 .56772 .52278 .57836 .51941 .57281 .51327 Metetra
.977 .098 0 r
.57281 .51327 .57836 .51941 .58905 .51598 .58352 .5098 Metetra
.976 .101 0 r
.58352 .5098 .58905 .51598 .59977 .51249 .59427 .50626 Metetra
.975 .105 0 r
.59427 .50626 .59977 .51249 .61053 .50891 .60506 .50263 Metetra
.974 .11 0 r
.60506 .50263 .61053 .50891 .62133 .50523 .61588 .4989 Metetra
.972 .116 0 r
.61588 .4989 .62133 .50523 .63216 .50144 .62674 .49506 Metetra
.97 .124 0 r
.62674 .49506 .63216 .50144 .64303 .49752 .63764 .49109 Metetra
.968 .134 0 r
.63764 .49109 .64303 .49752 .65393 .49345 .64857 .48696 Metetra
.965 .146 0 r
.64857 .48696 .65393 .49345 .66486 .48921 .65953 .48266 Metetra
.962 .16 0 r
.65953 .48266 .66486 .48921 .67583 .48478 .67052 .47816 Metetra
.957 .177 0 r
.67052 .47816 .67583 .48478 .68681 .48014 .68154 .47345 Metetra
.952 .197 0 r
.68154 .47345 .68681 .48014 .69782 .47526 .69258 .4685 Metetra
.946 .22 0 r
.69258 .4685 .69782 .47526 .70885 .4701 .70363 .46327 Metetra
.94 .246 0 r
.70363 .46327 .70885 .4701 .7199 .46466 .71471 .45775 Metetra
.932 .275 0 r
.71471 .45775 .7199 .46466 .73096 .4589 .72579 .45191 Metetra
.923 .309 0 r
.72579 .45191 .73096 .4589 .74202 .45278 .73688 .44571 Metetra
.912 .346 0 r
.73688 .44571 .74202 .45278 .75308 .44628 .74797 .43912 Metetra
.901 .388 0 r
.74797 .43912 .75308 .44628 .76413 .43936 .75906 .43211 Metetra
.887 .433 0 r
.75906 .43211 .76413 .43936 .77517 .43199 .77013 .42465 Metetra
.873 .482 0 r
.77013 .42465 .77517 .43199 .7862 .42414 .78118 .41671 Metetra
.856 .534 0 r
.78118 .41671 .7862 .42414 .79719 .41577 .7922 .40824 Metetra
.837 .59 0 r
.7922 .40824 .79719 .41577 .80814 .40684 .80319 .39921 Metetra
.817 .649 0 r
.80319 .39921 .80814 .40684 .81905 .39732 .81412 .38959 Metetra
.794 .709 0 r
.81412 .38959 .81905 .39732 .8299 .38716 .825 .37933 Metetra
.766 .768 0 r
.825 .37933 .8299 .38716 .84069 .37634 .83582 .3684 Metetra
.746 .764 0 r
.18451 .56696 .19073 .57371 .19919 .57769 .19296 .57102 Metetra
.789 .721 0 r
.19296 .57102 .19919 .57769 .20777 .58107 .20154 .57446 Metetra
.813 .66 0 r
.20154 .57446 .20777 .58107 .21647 .58386 .21023 .57732 Metetra
.833 .601 0 r
.21023 .57732 .21647 .58386 .22528 .58611 .21904 .57963 Metetra
.852 .545 0 r
.21904 .57963 .22528 .58611 .23419 .58785 .22796 .58143 Metetra
.869 .493 0 r
.22796 .58143 .23419 .58785 .24321 .58911 .23697 .58275 Metetra
.884 .443 0 r
.23697 .58275 .24321 .58911 .25231 .58992 .24608 .58361 Metetra
.898 .397 0 r
.24608 .58361 .25231 .58992 .2615 .59031 .25527 .58405 Metetra
.91 .356 0 r
.25527 .58405 .2615 .59031 .27076 .59031 .26455 .5841 Metetra
.92 .318 0 r
.26455 .5841 .27076 .59031 .28011 .58996 .2739 .58379 Metetra
.93 .284 0 r
.2739 .58379 .28011 .58996 .28952 .58927 .28332 .58315 Metetra
.938 .253 0 r
.28332 .58315 .28952 .58927 .299 .58829 .29282 .5822 Metetra
.945 .227 0 r
.29282 .5822 .299 .58829 .30855 .58702 .30237 .58097 Metetra
.951 .203 0 r
.30237 .58097 .30855 .58702 .31815 .58551 .31199 .57948 Metetra
.956 .183 0 r
.31199 .57948 .31815 .58551 .32781 .58376 .32167 .57777 Metetra
.96 .166 0 r
.32167 .57777 .32781 .58376 .33753 .58181 .3314 .57584 Metetra
.964 .151 0 r
.3314 .57584 .33753 .58181 .34729 .57968 .34118 .57373 Metetra
.967 .138 0 r
.34118 .57373 .34729 .57968 .35711 .57739 .35101 .57146 Metetra
.969 .128 0 r
.35101 .57146 .35711 .57739 .36697 .57495 .36089 .56903 Metetra
.972 .12 0 r
.36089 .56903 .36697 .57495 .37687 .57238 .37082 .56648 Metetra
.973 .113 0 r
.37082 .56648 .37687 .57238 .38682 .56971 .38079 .56382 Metetra
.975 .107 0 r
.38079 .56382 .38682 .56971 .39682 .56694 .3908 .56105 Metetra
.976 .103 0 r
.3908 .56105 .39682 .56694 .40685 .56409 .40086 .55821 Metetra
.976 .1 0 r
.40086 .55821 .40685 .56409 .41693 .56116 .41096 .55529 Metetra
.977 .097 0 r
.41096 .55529 .41693 .56116 .42704 .55819 .42109 .55231 Metetra
.977 .096 0 r
.42109 .55231 .42704 .55819 .4372 .55516 .43127 .54927 Metetra
.978 .094 0 r
.43127 .54927 .4372 .55516 .44739 .55209 .44149 .5462 Metetra
.978 .093 0 r
.44149 .5462 .44739 .55209 .45762 .54899 .45175 .54309 Metetra
.978 .093 0 r
.45175 .54309 .45762 .54899 .4679 .54586 .46205 .53995 Metetra
.978 .092 0 r
.46205 .53995 .4679 .54586 .47821 .54271 .47238 .53678 Metetra
.978 .092 0 r
.47238 .53678 .47821 .54271 .48856 .53954 .48276 .53359 Metetra
.978 .092 0 r
.48276 .53359 .48856 .53954 .49895 .53635 .49318 .53037 Metetra
.978 .092 0 r
.49318 .53037 .49895 .53635 .50938 .53314 .50363 .52713 Metetra
.978 .092 0 r
.50363 .52713 .50938 .53314 .51986 .5299 .51413 .52387 Metetra
.978 .093 0 r
.51413 .52387 .51986 .5299 .53037 .52665 .52467 .52059 Metetra
.978 .093 0 r
.52467 .52059 .53037 .52665 .54092 .52336 .53524 .51727 Metetra
.978 .094 0 r
.53524 .51727 .54092 .52336 .55151 .52004 .54586 .51391 Metetra
.977 .096 0 r
.54586 .51391 .55151 .52004 .56214 .51668 .55652 .51051 Metetra
.977 .097 0 r
.55652 .51051 .56214 .51668 .57281 .51327 .56722 .50705 Metetra
.976 .1 0 r
.56722 .50705 .57281 .51327 .58352 .5098 .57795 .50354 Metetra
.976 .103 0 r
.57795 .50354 .58352 .5098 .59427 .50626 .58873 .49994 Metetra
.975 .107 0 r
.58873 .49994 .59427 .50626 .60506 .50263 .59954 .49626 Metetra
.973 .113 0 r
.59954 .49626 .60506 .50263 .61588 .4989 .6104 .49248 Metetra
.972 .12 0 r
.6104 .49248 .61588 .4989 .62674 .49506 .62129 .48858 Metetra
.969 .128 0 r
.62129 .48858 .62674 .49506 .63764 .49109 .63221 .48454 Metetra
.967 .138 0 r
.63221 .48454 .63764 .49109 .64857 .48696 .64317 .48034 Metetra
.964 .151 0 r
.64317 .48034 .64857 .48696 .65953 .48266 .65416 .47598 Metetra
.96 .166 0 r
.65416 .47598 .65953 .48266 .67052 .47816 .66517 .47141 Metetra
.956 .183 0 r
.66517 .47141 .67052 .47816 .68154 .47345 .67622 .46662 Metetra
.951 .203 0 r
.67622 .46662 .68154 .47345 .69258 .4685 .68729 .46159 Metetra
.945 .227 0 r
.68729 .46159 .69258 .4685 .70363 .46327 .69837 .45628 Metetra
.938 .253 0 r
.69837 .45628 .70363 .46327 .71471 .45775 .70947 .45067 Metetra
.93 .284 0 r
.70947 .45067 .71471 .45775 .72579 .45191 .72059 .44474 Metetra
.92 .318 0 r
.72059 .44474 .72579 .45191 .73688 .44571 .73171 .43844 Metetra
.91 .356 0 r
.73171 .43844 .73688 .44571 .74797 .43912 .74282 .43176 Metetra
.898 .397 0 r
.74282 .43176 .74797 .43912 .75906 .43211 .75394 .42465 Metetra
.884 .443 0 r
.75394 .42465 .75906 .43211 .77013 .42465 .76504 .41709 Metetra
.869 .493 0 r
.76504 .41709 .77013 .42465 .78118 .41671 .77611 .40904 Metetra
.852 .545 0 r
.77611 .40904 .78118 .41671 .7922 .40824 .78716 .40046 Metetra
.833 .601 0 r
.78716 .40046 .7922 .40824 .80319 .39921 .79818 .39132 Metetra
.813 .66 0 r
.79818 .39132 .80319 .39921 .81412 .38959 .80914 .38158 Metetra
.789 .721 0 r
.80914 .38158 .81412 .38959 .825 .37933 .82005 .3712 Metetra
.746 .764 0 r
.82005 .3712 .825 .37933 .83582 .3684 .83089 .36015 Metetra
.722 .758 0 r
.17828 .55992 .18451 .56696 .19296 .57102 .18672 .56406 Metetra
.784 .734 0 r
.18672 .56406 .19296 .57102 .20154 .57446 .19529 .56759 Metetra
.808 .673 0 r
.19529 .56759 .20154 .57446 .21023 .57732 .20398 .57053 Metetra
.829 .615 0 r
.20398 .57053 .21023 .57732 .21904 .57963 .21279 .57291 Metetra
.848 .559 0 r
.21279 .57291 .21904 .57963 .22796 .58143 .2217 .57478 Metetra
.865 .505 0 r
.2217 .57478 .22796 .58143 .23697 .58275 .23071 .57616 Metetra
.881 .456 0 r
.23071 .57616 .23697 .58275 .24608 .58361 .23982 .57709 Metetra
.894 .409 0 r
.23982 .57709 .24608 .58361 .25527 .58405 .24902 .57759 Metetra
.907 .367 0 r
.24902 .57759 .25527 .58405 .26455 .5841 .2583 .5777 Metetra
.917 .329 0 r
.2583 .5777 .26455 .5841 .2739 .58379 .26766 .57744 Metetra
.927 .294 0 r
.26766 .57744 .2739 .58379 .28332 .58315 .27709 .57685 Metetra
.935 .263 0 r
.27709 .57685 .28332 .58315 .29282 .5822 .2866 .57595 Metetra
.942 .235 0 r
.2866 .57595 .29282 .5822 .30237 .58097 .29617 .57476 Metetra
.949 .211 0 r
.29617 .57476 .30237 .58097 .31199 .57948 .3058 .57332 Metetra
.954 .19 0 r
.3058 .57332 .31199 .57948 .32167 .57777 .31549 .57164 Metetra
.959 .172 0 r
.31549 .57164 .32167 .57777 .3314 .57584 .32523 .56975 Metetra
.962 .157 0 r
.32523 .56975 .3314 .57584 .34118 .57373 .33503 .56767 Metetra
.966 .144 0 r
.33503 .56767 .34118 .57373 .35101 .57146 .34488 .56542 Metetra
.968 .133 0 r
.34488 .56542 .35101 .57146 .36089 .56903 .35478 .56301 Metetra
.971 .124 0 r
.35478 .56301 .36089 .56903 .37082 .56648 .36472 .56048 Metetra
.972 .117 0 r
.36472 .56048 .37082 .56648 .38079 .56382 .37471 .55783 Metetra
.974 .111 0 r
.37471 .55783 .38079 .56382 .3908 .56105 .38475 .55508 Metetra
.975 .106 0 r
.38475 .55508 .3908 .56105 .40086 .55821 .39483 .55224 Metetra
.976 .102 0 r
.39483 .55224 .40086 .55821 .41096 .55529 .40495 .54932 Metetra
.976 .1 0 r
.40495 .54932 .41096 .55529 .42109 .55231 .41511 .54634 Metetra
.977 .097 0 r
.41511 .54634 .42109 .55231 .43127 .54927 .42531 .54331 Metetra
.977 .096 0 r
.42531 .54331 .43127 .54927 .44149 .5462 .43555 .54023 Metetra
.978 .095 0 r
.43555 .54023 .44149 .5462 .45175 .54309 .44583 .53711 Metetra
.978 .094 0 r
.44583 .53711 .45175 .54309 .46205 .53995 .45615 .53396 Metetra
.978 .093 0 r
.45615 .53396 .46205 .53995 .47238 .53678 .46652 .53077 Metetra
.978 .093 0 r
.46652 .53077 .47238 .53678 .48276 .53359 .47692 .52756 Metetra
.978 .093 0 r
.47692 .52756 .48276 .53359 .49318 .53037 .48736 .52432 Metetra
.978 .093 0 r
.48736 .52432 .49318 .53037 .50363 .52713 .49784 .52106 Metetra
.978 .093 0 r
.49784 .52106 .50363 .52713 .51413 .52387 .50836 .51777 Metetra
.978 .094 0 r
.50836 .51777 .51413 .52387 .52467 .52059 .51893 .51445 Metetra
.978 .095 0 r
.51893 .51445 .52467 .52059 .53524 .51727 .52953 .51109 Metetra
.977 .096 0 r
.52953 .51109 .53524 .51727 .54586 .51391 .54017 .50769 Metetra
.977 .097 0 r
.54017 .50769 .54586 .51391 .55652 .51051 .55086 .50425 Metetra
.976 .1 0 r
.55086 .50425 .55652 .51051 .56722 .50705 .56158 .50075 Metetra
.976 .102 0 r
.56158 .50075 .56722 .50705 .57795 .50354 .57235 .49718 Metetra
.975 .106 0 r
.57235 .49718 .57795 .50354 .58873 .49994 .58315 .49353 Metetra
.974 .111 0 r
.58315 .49353 .58873 .49994 .59954 .49626 .59399 .48979 Metetra
.972 .117 0 r
.59399 .48979 .59954 .49626 .6104 .49248 .60487 .48595 Metetra
.971 .124 0 r
.60487 .48595 .6104 .49248 .62129 .48858 .61579 .48198 Metetra
.968 .133 0 r
.61579 .48198 .62129 .48858 .63221 .48454 .62674 .47787 Metetra
.966 .144 0 r
.62674 .47787 .63221 .48454 .64317 .48034 .63773 .4736 Metetra
.962 .157 0 r
.63773 .4736 .64317 .48034 .65416 .47598 .64874 .46916 Metetra
.959 .172 0 r
.64874 .46916 .65416 .47598 .66517 .47141 .65979 .46451 Metetra
.954 .19 0 r
.65979 .46451 .66517 .47141 .67622 .46662 .67086 .45964 Metetra
.949 .211 0 r
.67086 .45964 .67622 .46662 .68729 .46159 .68195 .45451 Metetra
.942 .235 0 r
.68195 .45451 .68729 .46159 .69837 .45628 .69307 .44911 Metetra
.935 .263 0 r
.69307 .44911 .69837 .45628 .70947 .45067 .7042 .44341 Metetra
.927 .294 0 r
.7042 .44341 .70947 .45067 .72059 .44474 .71534 .43738 Metetra
.917 .329 0 r
.71534 .43738 .72059 .44474 .73171 .43844 .72648 .43098 Metetra
.907 .367 0 r
.72648 .43098 .73171 .43844 .74282 .43176 .73763 .42419 Metetra
.894 .409 0 r
.73763 .42419 .74282 .43176 .75394 .42465 .74877 .41697 Metetra
.881 .456 0 r
.74877 .41697 .75394 .42465 .76504 .41709 .75989 .40929 Metetra
.865 .505 0 r
.75989 .40929 .76504 .41709 .77611 .40904 .771 .40112 Metetra
.848 .559 0 r
.771 .40112 .77611 .40904 .78716 .40046 .78208 .39242 Metetra
.829 .615 0 r
.78208 .39242 .78716 .40046 .79818 .39132 .79312 .38315 Metetra
.808 .673 0 r
.79312 .38315 .79818 .39132 .80914 .38158 .80411 .37328 Metetra
.784 .734 0 r
.80411 .37328 .80914 .38158 .82005 .3712 .81504 .36277 Metetra
.722 .758 0 r
.81504 .36277 .82005 .3712 .83089 .36015 .82591 .35158 Metetra
.694 .751 0 r
.17204 .55259 .17828 .55992 .18672 .56406 .18047 .55682 Metetra
.778 .749 0 r
.18047 .55682 .18672 .56406 .19529 .56759 .18903 .56044 Metetra
.802 .689 0 r
.18903 .56044 .19529 .56759 .20398 .57053 .19771 .56347 Metetra
.823 .63 0 r
.19771 .56347 .20398 .57053 .21279 .57291 .20651 .56594 Metetra
.843 .574 0 r
.20651 .56594 .21279 .57291 .2217 .57478 .21542 .56789 Metetra
.86 .52 0 r
.21542 .56789 .2217 .57478 .23071 .57616 .22444 .56935 Metetra
.876 .47 0 r
.22444 .56935 .23071 .57616 .23982 .57709 .23354 .57036 Metetra
.89 .423 0 r
.23354 .57036 .23982 .57709 .24902 .57759 .24274 .57093 Metetra
.903 .38 0 r
.24274 .57093 .24902 .57759 .2583 .5777 .25203 .57111 Metetra
.914 .341 0 r
.25203 .57111 .2583 .5777 .26766 .57744 .2614 .57091 Metetra
.924 .306 0 r
.2614 .57091 .26766 .57744 .27709 .57685 .27084 .57038 Metetra
.932 .274 0 r
.27084 .57038 .27709 .57685 .2866 .57595 .28035 .56953 Metetra
.94 .246 0 r
.28035 .56953 .2866 .57595 .29617 .57476 .28993 .5684 Metetra
.946 .221 0 r
.28993 .5684 .29617 .57476 .3058 .57332 .29957 .567 Metetra
.952 .199 0 r
.29957 .567 .3058 .57332 .31549 .57164 .30927 .56536 Metetra
.956 .18 0 r
.30927 .56536 .31549 .57164 .32523 .56975 .31903 .56351 Metetra
.961 .164 0 r
.31903 .56351 .32523 .56975 .33503 .56767 .32885 .56147 Metetra
.964 .15 0 r
.32885 .56147 .33503 .56767 .34488 .56542 .33871 .55925 Metetra
.967 .139 0 r
.33871 .55925 .34488 .56542 .35478 .56301 .34863 .55688 Metetra
.969 .129 0 r
.34863 .55688 .35478 .56301 .36472 .56048 .35859 .55437 Metetra
.971 .121 0 r
.35859 .55437 .36472 .56048 .37471 .55783 .3686 .55174 Metetra
.973 .115 0 r
.3686 .55174 .37471 .55783 .38475 .55508 .37866 .549 Metetra
.974 .11 0 r
.37866 .549 .38475 .55508 .39483 .55224 .38876 .54617 Metetra
.975 .106 0 r
.38876 .54617 .39483 .55224 .40495 .54932 .3989 .54327 Metetra
.976 .102 0 r
.3989 .54327 .40495 .54932 .41511 .54634 .40908 .54029 Metetra
.976 .1 0 r
.40908 .54029 .41511 .54634 .42531 .54331 .4193 .53726 Metetra
.977 .098 0 r
.4193 .53726 .42531 .54331 .43555 .54023 .42957 .53418 Metetra
.977 .097 0 r
.42957 .53418 .43555 .54023 .44583 .53711 .43987 .53105 Metetra
.977 .096 0 r
.43987 .53105 .44583 .53711 .45615 .53396 .45022 .52788 Metetra
.978 .095 0 r
.45022 .52788 .45615 .53396 .46652 .53077 .46061 .52468 Metetra
.978 .095 0 r
.46061 .52468 .46652 .53077 .47692 .52756 .47103 .52145 Metetra
.978 .095 0 r
.47103 .52145 .47692 .52756 .48736 .52432 .4815 .51819 Metetra
.978 .095 0 r
.4815 .51819 .48736 .52432 .49784 .52106 .49201 .5149 Metetra
.978 .095 0 r
.49201 .5149 .49784 .52106 .50836 .51777 .50256 .51158 Metetra
.977 .096 0 r
.50256 .51158 .50836 .51777 .51893 .51445 .51315 .50822 Metetra
.977 .097 0 r
.51315 .50822 .51893 .51445 .52953 .51109 .52378 .50483 Metetra
.977 .098 0 r
.52378 .50483 .52953 .51109 .54017 .50769 .53445 .50139 Metetra
.976 .1 0 r
.53445 .50139 .54017 .50769 .55086 .50425 .54516 .4979 Metetra
.976 .102 0 r
.54516 .4979 .55086 .50425 .56158 .50075 .55591 .49434 Metetra
.975 .106 0 r
.55591 .49434 .56158 .50075 .57235 .49718 .5667 .49072 Metetra
.974 .11 0 r
.5667 .49072 .57235 .49718 .58315 .49353 .57753 .48701 Metetra
.973 .115 0 r
.57753 .48701 .58315 .49353 .59399 .48979 .5884 .48321 Metetra
.971 .121 0 r
.5884 .48321 .59399 .48979 .60487 .48595 .59931 .4793 Metetra
.969 .129 0 r
.59931 .4793 .60487 .48595 .61579 .48198 .61025 .47526 Metetra
.967 .139 0 r
.61025 .47526 .61579 .48198 .62674 .47787 .62123 .47107 Metetra
.964 .15 0 r
.62123 .47107 .62674 .47787 .63773 .4736 .63224 .46673 Metetra
.961 .164 0 r
.63224 .46673 .63773 .4736 .64874 .46916 .64329 .46219 Metetra
.956 .18 0 r
.64329 .46219 .64874 .46916 .65979 .46451 .65436 .45746 Metetra
.952 .199 0 r
.65436 .45746 .65979 .46451 .67086 .45964 .66546 .45249 Metetra
.946 .221 0 r
.66546 .45249 .67086 .45964 .68195 .45451 .67658 .44727 Metetra
.94 .246 0 r
.67658 .44727 .68195 .45451 .69307 .44911 .68772 .44177 Metetra
.932 .274 0 r
.68772 .44177 .69307 .44911 .7042 .44341 .69888 .43596 Metetra
.924 .306 0 r
.69888 .43596 .7042 .44341 .71534 .43738 .71004 .42981 Metetra
.914 .341 0 r
.71004 .42981 .71534 .43738 .72648 .43098 .72121 .4233 Metetra
.903 .38 0 r
.72121 .4233 .72648 .43098 .73763 .42419 .73239 .41639 Metetra
.89 .423 0 r
.73239 .41639 .73763 .42419 .74877 .41697 .74355 .40905 Metetra
.876 .47 0 r
.74355 .40905 .74877 .41697 .75989 .40929 .7547 .40124 Metetra
.86 .52 0 r
.7547 .40124 .75989 .40929 .771 .40112 .76584 .39294 Metetra
.843 .574 0 r
.76584 .39294 .771 .40112 .78208 .39242 .77694 .3841 Metetra
.823 .63 0 r
.77694 .3841 .78208 .39242 .79312 .38315 .788 .37469 Metetra
.802 .689 0 r
.788 .37469 .79312 .38315 .80411 .37328 .79902 .36468 Metetra
.778 .749 0 r
.79902 .36468 .80411 .37328 .81504 .36277 .80998 .35402 Metetra
.694 .751 0 r
.80998 .35402 .81504 .36277 .82591 .35158 .82087 .34268 Metetra
.662 .744 0 r
.1658 .54494 .17204 .55259 .18047 .55682 .17422 .54929 Metetra
.771 .766 0 r
.17422 .54929 .18047 .55682 .18903 .56044 .18276 .55301 Metetra
.795 .706 0 r
.18276 .55301 .18903 .56044 .19771 .56347 .19143 .55614 Metetra
.817 .648 0 r
.19143 .55614 .19771 .56347 .20651 .56594 .20023 .55871 Metetra
.837 .591 0 r
.20023 .55871 .20651 .56594 .21542 .56789 .20913 .56075 Metetra
.855 .537 0 r
.20913 .56075 .21542 .56789 .22444 .56935 .21814 .56231 Metetra
.871 .487 0 r
.21814 .56231 .22444 .56935 .23354 .57036 .22725 .56339 Metetra
.886 .439 0 r
.22725 .56339 .23354 .57036 .24274 .57093 .23645 .56405 Metetra
.898 .396 0 r
.23645 .56405 .24274 .57093 .25203 .57111 .24573 .5643 Metetra
.91 .356 0 r
.24573 .5643 .25203 .57111 .2614 .57091 .2551 .56418 Metetra
.92 .319 0 r
.2551 .56418 .2614 .57091 .27084 .57038 .26455 .56372 Metetra
.929 .287 0 r
.26455 .56372 .27084 .57038 .28035 .56953 .27407 .56294 Metetra
.936 .258 0 r
.27407 .56294 .28035 .56953 .28993 .5684 .28366 .56186 Metetra
.943 .232 0 r
.28366 .56186 .28993 .5684 .29957 .567 .29331 .56052 Metetra
.949 .209 0 r
.29331 .56052 .29957 .567 .30927 .56536 .30303 .55894 Metetra
.954 .19 0 r
.30303 .55894 .30927 .56536 .31903 .56351 .3128 .55713 Metetra
.958 .173 0 r
.3128 .55713 .31903 .56351 .32885 .56147 .32263 .55513 Metetra
.962 .158 0 r
.32263 .55513 .32885 .56147 .33871 .55925 .33251 .55295 Metetra
.965 .146 0 r
.33251 .55295 .33871 .55925 .34863 .55688 .34244 .55061 Metetra
.968 .136 0 r
.34244 .55061 .34863 .55688 .35859 .55437 .35243 .54813 Metetra
.97 .127 0 r
.35243 .54813 .35859 .55437 .3686 .55174 .36245 .54553 Metetra
.971 .12 0 r
.36245 .54553 .3686 .55174 .37866 .549 .37253 .54281 Metetra
.973 .114 0 r
.37253 .54281 .37866 .549 .38876 .54617 .38265 .54 Metetra
.974 .11 0 r
.38265 .54 .38876 .54617 .3989 .54327 .39281 .53711 Metetra
.975 .106 0 r
.39281 .53711 .3989 .54327 .40908 .54029 .40301 .53414 Metetra
.976 .103 0 r
.40301 .53414 .40908 .54029 .4193 .53726 .41326 .53111 Metetra
.976 .101 0 r
.41326 .53111 .4193 .53726 .42957 .53418 .42355 .52802 Metetra
.977 .099 0 r
.42355 .52802 .42957 .53418 .43987 .53105 .43388 .52489 Metetra
.977 .098 0 r
.43388 .52489 .43987 .53105 .45022 .52788 .44425 .52171 Metetra
.977 .097 0 r
.44425 .52171 .45022 .52788 .46061 .52468 .45466 .5185 Metetra
.977 .097 0 r
.45466 .5185 .46061 .52468 .47103 .52145 .46511 .51525 Metetra
.977 .097 0 r
.46511 .51525 .47103 .52145 .4815 .51819 .4756 .51197 Metetra
.977 .097 0 r
.4756 .51197 .4815 .51819 .49201 .5149 .48614 .50865 Metetra
.977 .097 0 r
.48614 .50865 .49201 .5149 .50256 .51158 .49671 .50529 Metetra
.977 .098 0 r
.49671 .50529 .50256 .51158 .51315 .50822 .50733 .5019 Metetra
.977 .099 0 r
.50733 .5019 .51315 .50822 .52378 .50483 .51798 .49846 Metetra
.976 .101 0 r
.51798 .49846 .52378 .50483 .53445 .50139 .52868 .49498 Metetra
.976 .103 0 r
.52868 .49498 .53445 .50139 .54516 .4979 .53942 .49144 Metetra
.975 .106 0 r
.53942 .49144 .54516 .4979 .55591 .49434 .5502 .48783 Metetra
.974 .11 0 r
.5502 .48783 .55591 .49434 .5667 .49072 .56101 .48415 Metetra
.973 .114 0 r
.56101 .48415 .5667 .49072 .57753 .48701 .57187 .48037 Metetra
.971 .12 0 r
.57187 .48037 .57753 .48701 .5884 .48321 .58277 .4765 Metetra
.97 .127 0 r
.58277 .4765 .5884 .48321 .59931 .4793 .5937 .47252 Metetra
.968 .136 0 r
.5937 .47252 .59931 .4793 .61025 .47526 .60467 .4684 Metetra
.965 .146 0 r
.60467 .4684 .61025 .47526 .62123 .47107 .61568 .46413 Metetra
.962 .158 0 r
.61568 .46413 .62123 .47107 .63224 .46673 .62672 .4597 Metetra
.958 .173 0 r
.62672 .4597 .63224 .46673 .64329 .46219 .63779 .45507 Metetra
.954 .19 0 r
.63779 .45507 .64329 .46219 .65436 .45746 .64889 .45024 Metetra
.949 .209 0 r
.64889 .45024 .65436 .45746 .66546 .45249 .66001 .44517 Metetra
.943 .232 0 r
.66001 .44517 .66546 .45249 .67658 .44727 .67116 .43984 Metetra
.936 .258 0 r
.67116 .43984 .67658 .44727 .68772 .44177 .68233 .43423 Metetra
.929 .287 0 r
.68233 .43423 .68772 .44177 .69888 .43596 .69351 .4283 Metetra
.92 .319 0 r
.69351 .4283 .69888 .43596 .71004 .42981 .7047 .42204 Metetra
.91 .356 0 r
.7047 .42204 .71004 .42981 .72121 .4233 .7159 .4154 Metetra
.898 .396 0 r
.7159 .4154 .72121 .4233 .73239 .41639 .7271 .40836 Metetra
.886 .439 0 r
.7271 .40836 .73239 .41639 .74355 .40905 .73829 .40088 Metetra
.871 .487 0 r
.73829 .40088 .74355 .40905 .7547 .40124 .74947 .39293 Metetra
.855 .537 0 r
.74947 .39293 .7547 .40124 .76584 .39294 .76062 .38448 Metetra
.837 .591 0 r
.76062 .38448 .76584 .39294 .77694 .3841 .77175 .3755 Metetra
.817 .648 0 r
.77175 .3755 .77694 .3841 .788 .37469 .78284 .36593 Metetra
.795 .706 0 r
.78284 .36593 .788 .37469 .79902 .36468 .79388 .35576 Metetra
.771 .766 0 r
.79388 .35576 .79902 .36468 .80998 .35402 .80486 .34494 Metetra
.662 .744 0 r
.80486 .34494 .80998 .35402 .82087 .34268 .81578 .33344 Metetra
.627 .735 0 r
.15956 .53697 .1658 .54494 .17422 .54929 .16795 .54144 Metetra
.74 .762 0 r
.16795 .54144 .17422 .54929 .18276 .55301 .17648 .54528 Metetra
.787 .726 0 r
.17648 .54528 .18276 .55301 .19143 .55614 .18514 .54852 Metetra
.81 .667 0 r
.18514 .54852 .19143 .55614 .20023 .55871 .19393 .5512 Metetra
.83 .611 0 r
.19393 .5512 .20023 .55871 .20913 .56075 .20282 .55335 Metetra
.849 .557 0 r
.20282 .55335 .20913 .56075 .21814 .56231 .21182 .555 Metetra
.865 .505 0 r
.21182 .555 .21814 .56231 .22725 .56339 .22093 .55619 Metetra
.88 .457 0 r
.22093 .55619 .22725 .56339 .23645 .56405 .23013 .55694 Metetra
.893 .413 0 r
.23013 .55694 .23645 .56405 .24573 .5643 .23941 .55728 Metetra
.905 .372 0 r
.23941 .55728 .24573 .5643 .2551 .56418 .24879 .55724 Metetra
.916 .335 0 r
.24879 .55724 .2551 .56418 .26455 .56372 .25824 .55686 Metetra
.925 .302 0 r
.25824 .55686 .26455 .56372 .27407 .56294 .26776 .55615 Metetra
.933 .272 0 r
.26776 .55615 .27407 .56294 .28366 .56186 .27736 .55514 Metetra
.94 .245 0 r
.27736 .55514 .28366 .56186 .29331 .56052 .28702 .55387 Metetra
.946 .221 0 r
.28702 .55387 .29331 .56052 .30303 .55894 .29675 .55234 Metetra
.951 .201 0 r
.29675 .55234 .30303 .55894 .3128 .55713 .30654 .55059 Metetra
.956 .183 0 r
.30654 .55059 .3128 .55713 .32263 .55513 .31638 .54864 Metetra
.96 .168 0 r
.31638 .54864 .32263 .55513 .33251 .55295 .32627 .54651 Metetra
.963 .155 0 r
.32627 .54651 .33251 .55295 .34244 .55061 .33622 .54421 Metetra
.966 .143 0 r
.33622 .54421 .34244 .55061 .35243 .54813 .34622 .54176 Metetra
.968 .134 0 r
.34622 .54176 .35243 .54813 .36245 .54553 .35627 .53919 Metetra
.97 .126 0 r
.35627 .53919 .36245 .54553 .37253 .54281 .36636 .5365 Metetra
.971 .12 0 r
.36636 .5365 .37253 .54281 .38265 .54 .3765 .5337 Metetra
.973 .115 0 r
.3765 .5337 .38265 .54 .39281 .53711 .38668 .53082 Metetra
.974 .111 0 r
.38668 .53082 .39281 .53711 .40301 .53414 .39691 .52787 Metetra
.975 .107 0 r
.39691 .52787 .40301 .53414 .41326 .53111 .40718 .52484 Metetra
.975 .105 0 r
.40718 .52484 .41326 .53111 .42355 .52802 .41749 .52176 Metetra
.976 .103 0 r
.41749 .52176 .42355 .52802 .43388 .52489 .42784 .51862 Metetra
.976 .102 0 r
.42784 .51862 .43388 .52489 .44425 .52171 .43823 .51544 Metetra
.976 .101 0 r
.43823 .51544 .44425 .52171 .45466 .5185 .44867 .51221 Metetra
.976 .1 0 r
.44867 .51221 .45466 .5185 .46511 .51525 .45915 .50894 Metetra
.976 .1 0 r
.45915 .50894 .46511 .51525 .4756 .51197 .46966 .50563 Metetra
.976 .1 0 r
.46966 .50563 .4756 .51197 .48614 .50865 .48022 .50229 Metetra
.976 .101 0 r
.48022 .50229 .48614 .50865 .49671 .50529 .49082 .4989 Metetra
.976 .102 0 r
.49082 .4989 .49671 .50529 .50733 .5019 .50147 .49547 Metetra
.976 .103 0 r
.50147 .49547 .50733 .5019 .51798 .49846 .51215 .49199 Metetra
.975 .105 0 r
.51215 .49199 .51798 .49846 .52868 .49498 .52287 .48845 Metetra
.975 .107 0 r
.52287 .48845 .52868 .49498 .53942 .49144 .53364 .48486 Metetra
.974 .111 0 r
.53364 .48486 .53942 .49144 .5502 .48783 .54444 .48119 Metetra
.973 .115 0 r
.54444 .48119 .5502 .48783 .56101 .48415 .55529 .47744 Metetra
.971 .12 0 r
.55529 .47744 .56101 .48415 .57187 .48037 .56617 .4736 Metetra
.97 .126 0 r
.56617 .4736 .57187 .48037 .58277 .4765 .57709 .46966 Metetra
.968 .134 0 r
.57709 .46966 .58277 .4765 .5937 .47252 .58805 .46559 Metetra
.966 .143 0 r
.58805 .46559 .5937 .47252 .60467 .4684 .59905 .46139 Metetra
.963 .155 0 r
.59905 .46139 .60467 .4684 .61568 .46413 .61008 .45703 Metetra
.96 .168 0 r
.61008 .45703 .61568 .46413 .62672 .4597 .62115 .4525 Metetra
.956 .183 0 r
.62115 .4525 .62672 .4597 .63779 .45507 .63225 .44778 Metetra
.951 .201 0 r
.63225 .44778 .63779 .45507 .64889 .45024 .64337 .44284 Metetra
.946 .221 0 r
.64337 .44284 .64889 .45024 .66001 .44517 .65453 .43766 Metetra
.94 .245 0 r
.65453 .43766 .66001 .44517 .67116 .43984 .6657 .43222 Metetra
.933 .272 0 r
.6657 .43222 .67116 .43984 .68233 .43423 .67689 .42648 Metetra
.925 .302 0 r
.67689 .42648 .68233 .43423 .69351 .4283 .6881 .42043 Metetra
.916 .335 0 r
.6881 .42043 .69351 .4283 .7047 .42204 .69932 .41403 Metetra
.905 .372 0 r
.69932 .41403 .7047 .42204 .7159 .4154 .71054 .40725 Metetra
.893 .413 0 r
.71054 .40725 .7159 .4154 .7271 .40836 .72176 .40007 Metetra
.88 .457 0 r
.72176 .40007 .7271 .40836 .73829 .40088 .73298 .39245 Metetra
.865 .505 0 r
.73298 .39245 .73829 .40088 .74947 .39293 .74418 .38435 Metetra
.849 .557 0 r
.74418 .38435 .74947 .39293 .76062 .38448 .75536 .37574 Metetra
.83 .611 0 r
.75536 .37574 .76062 .38448 .77175 .3755 .76651 .36659 Metetra
.81 .667 0 r
.76651 .36659 .77175 .3755 .78284 .36593 .77762 .35686 Metetra
.787 .726 0 r
.77762 .35686 .78284 .36593 .79388 .35576 .78868 .34652 Metetra
.74 .762 0 r
.78868 .34652 .79388 .35576 .80486 .34494 .79969 .33553 Metetra
.627 .735 0 r
.79969 .33553 .80486 .34494 .81578 .33344 .81062 .32385 Metetra
.588 .725 0 r
.15332 .52866 .15956 .53697 .16795 .54144 .16169 .53326 Metetra
.701 .753 0 r
.16169 .53326 .16795 .54144 .17648 .54528 .1702 .53723 Metetra
.779 .747 0 r
.1702 .53723 .17648 .54528 .18514 .54852 .17885 .5406 Metetra
.802 .689 0 r
.17885 .5406 .18514 .54852 .19393 .5512 .18761 .5434 Metetra
.823 .632 0 r
.18761 .5434 .19393 .5512 .20282 .55335 .1965 .54567 Metetra
.842 .578 0 r
.1965 .54567 .20282 .55335 .21182 .555 .20549 .54743 Metetra
.859 .526 0 r
.20549 .54743 .21182 .555 .22093 .55619 .21459 .54873 Metetra
.874 .478 0 r
.21459 .54873 .22093 .55619 .23013 .55694 .22379 .54958 Metetra
.888 .433 0 r
.22379 .54958 .23013 .55694 .23941 .55728 .23307 .55002 Metetra
.9 .391 0 r
.23307 .55002 .23941 .55728 .24879 .55724 .24245 .55008 Metetra
.911 .353 0 r
.24245 .55008 .24879 .55724 .25824 .55686 .2519 .54978 Metetra
.92 .319 0 r
.2519 .54978 .25824 .55686 .26776 .55615 .26143 .54915 Metetra
.929 .288 0 r
.26143 .54915 .26776 .55615 .27736 .55514 .27104 .54822 Metetra
.936 .26 0 r
.27104 .54822 .27736 .55514 .28702 .55387 .28071 .54702 Metetra
.942 .235 0 r
.28071 .54702 .28702 .55387 .29675 .55234 .29044 .54556 Metetra
.948 .214 0 r
.29044 .54556 .29675 .55234 .30654 .55059 .30024 .54388 Metetra
.953 .195 0 r
.30024 .54388 .30654 .55059 .31638 .54864 .31009 .54198 Metetra
.957 .179 0 r
.31009 .54198 .31638 .54864 .32627 .54651 .32 .5399 Metetra
.96 .165 0 r
.32 .5399 .32627 .54651 .33622 .54421 .32997 .53764 Metetra
.963 .153 0 r
.32997 .53764 .33622 .54421 .34622 .54176 .33998 .53524 Metetra
.966 .143 0 r
.33998 .53524 .34622 .54176 .35627 .53919 .35004 .5327 Metetra
.968 .134 0 r
.35004 .5327 .35627 .53919 .36636 .5365 .36016 .53004 Metetra
.97 .127 0 r
.36016 .53004 .36636 .5365 .3765 .5337 .37031 .52727 Metetra
.971 .121 0 r
.37031 .52727 .3765 .5337 .38668 .53082 .38052 .52441 Metetra
.972 .117 0 r
.38052 .52441 .38668 .53082 .39691 .52787 .39076 .52147 Metetra
.973 .113 0 r
.39076 .52147 .39691 .52787 .40718 .52484 .40105 .51845 Metetra
.974 .11 0 r
.40105 .51845 .40718 .52484 .41749 .52176 .41139 .51537 Metetra
.975 .108 0 r
.41139 .51537 .41749 .52176 .42784 .51862 .42176 .51223 Metetra
.975 .106 0 r
.42176 .51223 .42784 .51862 .43823 .51544 .43218 .50903 Metetra
.975 .105 0 r
.43218 .50903 .43823 .51544 .44867 .51221 .44264 .50579 Metetra
.975 .104 0 r
.44264 .50579 .44867 .51221 .45915 .50894 .45314 .50251 Metetra
.975 .104 0 r
.45314 .50251 .45915 .50894 .46966 .50563 .46369 .49917 Metetra
.975 .104 0 r
.46369 .49917 .46966 .50563 .48022 .50229 .47427 .4958 Metetra
.975 .105 0 r
.47427 .4958 .48022 .50229 .49082 .4989 .4849 .49238 Metetra
.975 .106 0 r
.4849 .49238 .49082 .4989 .50147 .49547 .49556 .4889 Metetra
.975 .108 0 r
.49556 .4889 .50147 .49547 .51215 .49199 .50627 .48538 Metetra
.974 .11 0 r
.50627 .48538 .51215 .49199 .52287 .48845 .51702 .48179 Metetra
.973 .113 0 r
.51702 .48179 .52287 .48845 .53364 .48486 .52781 .47814 Metetra
.972 .117 0 r
.52781 .47814 .53364 .48486 .54444 .48119 .53865 .47441 Metetra
.971 .121 0 r
.53865 .47441 .54444 .48119 .55529 .47744 .54952 .4706 Metetra
.97 .127 0 r
.54952 .4706 .55529 .47744 .56617 .4736 .56043 .46668 Metetra
.968 .134 0 r
.56043 .46668 .56617 .4736 .57709 .46966 .57138 .46266 Metetra
.966 .143 0 r
.57138 .46266 .57709 .46966 .58805 .46559 .58237 .45851 Metetra
.963 .153 0 r
.58237 .45851 .58805 .46559 .59905 .46139 .59339 .45421 Metetra
.96 .165 0 r
.59339 .45421 .59905 .46139 .61008 .45703 .60445 .44976 Metetra
.957 .179 0 r
.60445 .44976 .61008 .45703 .62115 .4525 .61554 .44513 Metetra
.953 .195 0 r
.61554 .44513 .62115 .4525 .63225 .44778 .62667 .4403 Metetra
.948 .214 0 r
.62667 .4403 .63225 .44778 .64337 .44284 .63782 .43524 Metetra
.942 .235 0 r
.63782 .43524 .64337 .44284 .65453 .43766 .64899 .42994 Metetra
.936 .26 0 r
.64899 .42994 .65453 .43766 .6657 .43222 .66019 .42438 Metetra
.929 .288 0 r
.66019 .42438 .6657 .43222 .67689 .42648 .67141 .41851 Metetra
.92 .319 0 r
.67141 .41851 .67689 .42648 .6881 .42043 .68265 .41232 Metetra
.911 .353 0 r
.68265 .41232 .6881 .42043 .69932 .41403 .69389 .40578 Metetra
.9 .391 0 r
.69389 .40578 .69932 .41403 .71054 .40725 .70514 .39886 Metetra
.888 .433 0 r
.70514 .39886 .71054 .40725 .72176 .40007 .71638 .39152 Metetra
.874 .478 0 r
.71638 .39152 .72176 .40007 .73298 .39245 .72762 .38373 Metetra
.859 .526 0 r
.72762 .38373 .73298 .39245 .74418 .38435 .73884 .37547 Metetra
.842 .578 0 r
.73884 .37547 .74418 .38435 .75536 .37574 .75004 .3667 Metetra
.823 .632 0 r
.75004 .3667 .75536 .37574 .76651 .36659 .76122 .35737 Metetra
.802 .689 0 r
.76122 .35737 .76651 .36659 .77762 .35686 .77235 .34746 Metetra
.779 .747 0 r
.77235 .34746 .77762 .35686 .78868 .34652 .78343 .33694 Metetra
.701 .753 0 r
.78343 .33694 .78868 .34652 .79969 .33553 .79445 .32576 Metetra
.588 .725 0 r
.79445 .32576 .79969 .33553 .81062 .32385 .80541 .31388 Metetra
.545 .715 0 r
.14708 .51999 .15332 .52866 .16169 .53326 .15543 .52474 Metetra
.658 .743 0 r
.15543 .52474 .16169 .53326 .1702 .53723 .16392 .52885 Metetra
.768 .769 0 r
.16392 .52885 .1702 .53723 .17885 .5406 .17254 .53236 Metetra
.793 .712 0 r
.17254 .53236 .17885 .5406 .18761 .5434 .1813 .5353 Metetra
.814 .656 0 r
.1813 .5353 .18761 .5434 .1965 .54567 .19017 .53769 Metetra
.833 .601 0 r
.19017 .53769 .1965 .54567 .20549 .54743 .19915 .53958 Metetra
.851 .549 0 r
.19915 .53958 .20549 .54743 .21459 .54873 .20824 .54099 Metetra
.867 .5 0 r
.20824 .54099 .21459 .54873 .22379 .54958 .21743 .54196 Metetra
.881 .455 0 r
.21743 .54196 .22379 .54958 .23307 .55002 .22672 .54251 Metetra
.894 .412 0 r
.22672 .54251 .23307 .55002 .24245 .55008 .23609 .54267 Metetra
.905 .373 0 r
.23609 .54267 .24245 .55008 .2519 .54978 .24554 .54246 Metetra
.915 .338 0 r
.24554 .54246 .2519 .54978 .26143 .54915 .25508 .54193 Metetra
.924 .306 0 r
.25508 .54193 .26143 .54915 .27104 .54822 .26468 .54109 Metetra
.931 .277 0 r
.26468 .54109 .27104 .54822 .28071 .54702 .27436 .53997 Metetra
.938 .251 0 r
.27436 .53997 .28071 .54702 .29044 .54556 .2841 .53858 Metetra
.944 .229 0 r
.2841 .53858 .29044 .54556 .30024 .54388 .29391 .53697 Metetra
.949 .209 0 r
.29391 .53697 .30024 .54388 .31009 .54198 .30378 .53513 Metetra
.954 .191 0 r
.30378 .53513 .31009 .54198 .32 .5399 .3137 .53311 Metetra
.957 .177 0 r
.3137 .53311 .32 .5399 .32997 .53764 .32368 .5309 Metetra
.961 .164 0 r
.32368 .5309 .32997 .53764 .33998 .53524 .33371 .52855 Metetra
.963 .153 0 r
.33371 .52855 .33998 .53524 .35004 .5327 .34379 .52604 Metetra
.966 .143 0 r
.34379 .52604 .35004 .5327 .36016 .53004 .35392 .52342 Metetra
.968 .136 0 r
.35392 .52342 .36016 .53004 .37031 .52727 .36409 .52068 Metetra
.969 .129 0 r
.36409 .52068 .37031 .52727 .38052 .52441 .37431 .51784 Metetra
.971 .124 0 r
.37431 .51784 .38052 .52441 .39076 .52147 .38458 .51492 Metetra
.972 .12 0 r
.38458 .51492 .39076 .52147 .40105 .51845 .39489 .51191 Metetra
.972 .116 0 r
.39489 .51191 .40105 .51845 .41139 .51537 .40525 .50883 Metetra
.973 .114 0 r
.40525 .50883 .41139 .51537 .42176 .51223 .41565 .50569 Metetra
.974 .112 0 r
.41565 .50569 .42176 .51223 .43218 .50903 .42609 .50249 Metetra
.974 .11 0 r
.42609 .50249 .43218 .50903 .44264 .50579 .43657 .49924 Metetra
.974 .11 0 r
.43657 .49924 .44264 .50579 .45314 .50251 .4471 .49593 Metetra
.974 .109 0 r
.4471 .49593 .45314 .50251 .46369 .49917 .45767 .49258 Metetra
.974 .11 0 r
.45767 .49258 .46369 .49917 .47427 .4958 .46828 .48917 Metetra
.974 .11 0 r
.46828 .48917 .47427 .4958 .4849 .49238 .47893 .48571 Metetra
.974 .112 0 r
.47893 .48571 .4849 .49238 .49556 .4889 .48962 .4822 Metetra
.973 .114 0 r
.48962 .4822 .49556 .4889 .50627 .48538 .50036 .47862 Metetra
.972 .116 0 r
.50036 .47862 .50627 .48538 .51702 .48179 .51113 .47498 Metetra
.972 .12 0 r
.51113 .47498 .51702 .48179 .52781 .47814 .52195 .47127 Metetra
.971 .124 0 r
.52195 .47127 .52781 .47814 .53865 .47441 .53281 .46748 Metetra
.969 .129 0 r
.53281 .46748 .53865 .47441 .54952 .4706 .54371 .46359 Metetra
.968 .136 0 r
.54371 .46359 .54952 .4706 .56043 .46668 .55464 .4596 Metetra
.966 .143 0 r
.55464 .4596 .56043 .46668 .57138 .46266 .56562 .45549 Metetra
.963 .153 0 r
.56562 .45549 .57138 .46266 .58237 .45851 .57664 .45125 Metetra
.961 .164 0 r
.57664 .45125 .58237 .45851 .59339 .45421 .58769 .44686 Metetra
.957 .177 0 r
.58769 .44686 .59339 .45421 .60445 .44976 .59877 .4423 Metetra
.954 .191 0 r
.59877 .4423 .60445 .44976 .61554 .44513 .60989 .43756 Metetra
.949 .209 0 r
.60989 .43756 .61554 .44513 .62667 .4403 .62104 .43261 Metetra
.944 .229 0 r
.62104 .43261 .62667 .4403 .63782 .43524 .63222 .42744 Metetra
.938 .251 0 r
.63222 .42744 .63782 .43524 .64899 .42994 .64342 .42201 Metetra
.931 .277 0 r
.64342 .42201 .64899 .42994 .66019 .42438 .65465 .4163 Metetra
.924 .306 0 r
.65465 .4163 .66019 .42438 .67141 .41851 .66589 .4103 Metetra
.915 .338 0 r
.66589 .4103 .67141 .41851 .68265 .41232 .67715 .40396 Metetra
.905 .373 0 r
.67715 .40396 .68265 .41232 .69389 .40578 .68841 .39727 Metetra
.894 .412 0 r
.68841 .39727 .69389 .40578 .70514 .39886 .69968 .39019 Metetra
.881 .455 0 r
.69968 .39019 .70514 .39886 .71638 .39152 .71095 .38268 Metetra
.867 .5 0 r
.71095 .38268 .71638 .39152 .72762 .38373 .72221 .37473 Metetra
.851 .549 0 r
.72221 .37473 .72762 .38373 .73884 .37547 .73346 .36629 Metetra
.833 .601 0 r
.73346 .36629 .73884 .37547 .75004 .3667 .74468 .35733 Metetra
.814 .656 0 r
.74468 .35733 .75004 .3667 .76122 .35737 .75587 .34782 Metetra
.793 .712 0 r
.75587 .34782 .76122 .35737 .77235 .34746 .76702 .33772 Metetra
.768 .769 0 r
.76702 .33772 .77235 .34746 .78343 .33694 .77812 .327 Metetra
.658 .743 0 r
.77812 .327 .78343 .33694 .79445 .32576 .78917 .31561 Metetra
.545 .715 0 r
.78917 .31561 .79445 .32576 .80541 .31388 .80014 .30353 Metetra
.499 .702 0 r
.14085 .51096 .14708 .51999 .15543 .52474 .14917 .51586 Metetra
.612 .732 0 r
.14917 .51586 .15543 .52474 .16392 .52885 .15764 .52013 Metetra
.722 .758 0 r
.15764 .52013 .16392 .52885 .17254 .53236 .16624 .52379 Metetra
.782 .738 0 r
.16624 .52379 .17254 .53236 .1813 .5353 .17497 .52687 Metetra
.804 .682 0 r
.17497 .52687 .1813 .5353 .19017 .53769 .18383 .52941 Metetra
.824 .627 0 r
.18383 .52941 .19017 .53769 .19915 .53958 .1928 .53143 Metetra
.843 .575 0 r
.1928 .53143 .19915 .53958 .20824 .54099 .20188 .53297 Metetra
.859 .525 0 r
.20188 .53297 .20824 .54099 .21743 .54196 .21106 .53406 Metetra
.874 .479 0 r
.21106 .53406 .21743 .54196 .22672 .54251 .22034 .53472 Metetra
.887 .435 0 r
.22034 .53472 .22672 .54251 .23609 .54267 .22971 .535 Metetra
.898 .396 0 r
.22971 .535 .23609 .54267 .24554 .54246 .23916 .5349 Metetra
.909 .359 0 r
.23916 .5349 .24554 .54246 .25508 .54193 .2487 .53447 Metetra
.918 .326 0 r
.2487 .53447 .25508 .54193 .26468 .54109 .25831 .53372 Metetra
.926 .296 0 r
.25831 .53372 .26468 .54109 .27436 .53997 .26799 .53269 Metetra
.933 .269 0 r
.26799 .53269 .27436 .53997 .2841 .53858 .27774 .53139 Metetra
.94 .246 0 r
.27774 .53139 .2841 .53858 .29391 .53697 .28755 .52984 Metetra
.945 .225 0 r
.28755 .52984 .29391 .53697 .30378 .53513 .29743 .52808 Metetra
.95 .206 0 r
.29743 .52808 .30378 .53513 .3137 .53311 .30736 .52612 Metetra
.954 .19 0 r
.30736 .52612 .3137 .53311 .32368 .5309 .31736 .52398 Metetra
.957 .176 0 r
.31736 .52398 .32368 .5309 .33371 .52855 .3274 .52167 Metetra
.96 .165 0 r
.3274 .52167 .33371 .52855 .34379 .52604 .3375 .51921 Metetra
.963 .155 0 r
.3375 .51921 .34379 .52604 .35392 .52342 .34764 .51662 Metetra
.965 .146 0 r
.34764 .51662 .35392 .52342 .36409 .52068 .35784 .51392 Metetra
.967 .139 0 r
.35784 .51392 .36409 .52068 .37431 .51784 .36808 .51111 Metetra
.968 .133 0 r
.36808 .51111 .37431 .51784 .38458 .51492 .37836 .5082 Metetra
.969 .128 0 r
.37836 .5082 .38458 .51492 .39489 .51191 .3887 .50521 Metetra
.97 .124 0 r
.3887 .50521 .39489 .51191 .40525 .50883 .39907 .50214 Metetra
.971 .121 0 r
.39907 .50214 .40525 .50883 .41565 .50569 .40949 .499 Metetra
.972 .119 0 r
.40949 .499 .41565 .50569 .42609 .50249 .41996 .49579 Metetra
.972 .118 0 r
.41996 .49579 .42609 .50249 .43657 .49924 .43047 .49253 Metetra
.972 .117 0 r
.43047 .49253 .43657 .49924 .4471 .49593 .44102 .4892 Metetra
.972 .116 0 r
.44102 .4892 .4471 .49593 .45767 .49258 .45161 .48582 Metetra
.972 .117 0 r
.45161 .48582 .45767 .49258 .46828 .48917 .46224 .48238 Metetra
.972 .118 0 r
.46224 .48238 .46828 .48917 .47893 .48571 .47292 .47889 Metetra
.972 .119 0 r
.47292 .47889 .47893 .48571 .48962 .4822 .48364 .47533 Metetra
.971 .121 0 r
.48364 .47533 .48962 .4822 .50036 .47862 .4944 .47171 Metetra
.97 .124 0 r
.4944 .47171 .50036 .47862 .51113 .47498 .5052 .46801 Metetra
.969 .128 0 r
.5052 .46801 .51113 .47498 .52195 .47127 .51605 .46423 Metetra
.968 .133 0 r
.51605 .46423 .52195 .47127 .53281 .46748 .52693 .46037 Metetra
.967 .139 0 r
.52693 .46037 .53281 .46748 .54371 .46359 .53786 .4564 Metetra
.965 .146 0 r
.53786 .4564 .54371 .46359 .55464 .4596 .54882 .45233 Metetra
.963 .155 0 r
.54882 .45233 .55464 .4596 .56562 .45549 .55982 .44813 Metetra
.96 .165 0 r
.55982 .44813 .56562 .45549 .57664 .45125 .57086 .44379 Metetra
.957 .176 0 r
.57086 .44379 .57664 .45125 .58769 .44686 .58194 .4393 Metetra
.954 .19 0 r
.58194 .4393 .58769 .44686 .59877 .4423 .59305 .43463 Metetra
.95 .206 0 r
.59305 .43463 .59877 .4423 .60989 .43756 .6042 .42977 Metetra
.945 .225 0 r
.6042 .42977 .60989 .43756 .62104 .43261 .61537 .4247 Metetra
.94 .246 0 r
.61537 .4247 .62104 .43261 .63222 .42744 .62658 .4194 Metetra
.933 .269 0 r
.62658 .4194 .63222 .42744 .64342 .42201 .6378 .41383 Metetra
.926 .296 0 r
.6378 .41383 .64342 .42201 .65465 .4163 .64905 .40798 Metetra
.918 .326 0 r
.64905 .40798 .65465 .4163 .66589 .4103 .66032 .40183 Metetra
.909 .359 0 r
.66032 .40183 .66589 .4103 .67715 .40396 .6716 .39533 Metetra
.898 .396 0 r
.6716 .39533 .67715 .40396 .68841 .39727 .68289 .38848 Metetra
.887 .435 0 r
.68289 .38848 .68841 .39727 .69968 .39019 .69418 .38122 Metetra
.874 .479 0 r
.69418 .38122 .69968 .39019 .71095 .38268 .70547 .37354 Metetra
.859 .525 0 r
.70547 .37354 .71095 .38268 .72221 .37473 .71676 .36541 Metetra
.843 .575 0 r
.71676 .36541 .72221 .37473 .73346 .36629 .72802 .35678 Metetra
.824 .627 0 r
.72802 .35678 .73346 .36629 .74468 .35733 .73926 .34763 Metetra
.804 .682 0 r
.73926 .34763 .74468 .35733 .75587 .34782 .75047 .33792 Metetra
.782 .738 0 r
.75047 .33792 .75587 .34782 .76702 .33772 .76164 .32761 Metetra
.722 .758 0 r
.76164 .32761 .76702 .33772 .77812 .327 .77276 .31668 Metetra
.612 .732 0 r
.77276 .31668 .77812 .327 .78917 .31561 .78382 .30508 Metetra
.499 .702 0 r
.78382 .30508 .78917 .31561 .80014 .30353 .79481 .29278 Metetra
.449 .689 0 r
.13463 .50154 .14085 .51096 .14917 .51586 .14292 .50661 Metetra
.562 .719 0 r
.14292 .50661 .14917 .51586 .15764 .52013 .15136 .51104 Metetra
.672 .746 0 r
.15136 .51104 .15764 .52013 .16624 .52379 .15994 .51486 Metetra
.771 .765 0 r
.15994 .51486 .16624 .52379 .17497 .52687 .16865 .5181 Metetra
.794 .709 0 r
.16865 .5181 .17497 .52687 .18383 .52941 .17749 .52079 Metetra
.814 .655 0 r
.17749 .52079 .18383 .52941 .1928 .53143 .18644 .52296 Metetra
.833 .602 0 r
.18644 .52296 .1928 .53143 .20188 .53297 .19551 .52464 Metetra
.85 .552 0 r
.19551 .52464 .20188 .53297 .21106 .53406 .20468 .52586 Metetra
.865 .505 0 r
.20468 .52586 .21106 .53406 .22034 .53472 .21395 .52665 Metetra
.879 .461 0 r
.21395 .52665 .22034 .53472 .22971 .535 .22331 .52705 Metetra
.891 .42 0 r
.22331 .52705 .22971 .535 .23916 .5349 .23277 .52707 Metetra
.902 .383 0 r
.23277 .52707 .23916 .5349 .2487 .53447 .2423 .52674 Metetra
.912 .349 0 r
.2423 .52674 .2487 .53447 .25831 .53372 .25191 .5261 Metetra
.92 .318 0 r
.25191 .5261 .25831 .53372 .26799 .53269 .2616 .52516 Metetra
.928 .29 0 r
.2616 .52516 .26799 .53269 .27774 .53139 .27135 .52395 Metetra
.935 .265 0 r
.27135 .52395 .27774 .53139 .28755 .52984 .28117 .52249 Metetra
.94 .243 0 r
.28117 .52249 .28755 .52984 .29743 .52808 .29106 .52081 Metetra
.945 .223 0 r
.29106 .52081 .29743 .52808 .30736 .52612 .301 .51892 Metetra
.95 .206 0 r
.301 .51892 .30736 .52612 .31736 .52398 .311 .51683 Metetra
.954 .191 0 r
.311 .51683 .31736 .52398 .3274 .52167 .32106 .51458 Metetra
.957 .179 0 r
.32106 .51458 .3274 .52167 .3375 .51921 .33117 .51218 Metetra
.96 .168 0 r
.33117 .51218 .3375 .51921 .34764 .51662 .34133 .50963 Metetra
.962 .158 0 r
.34133 .50963 .34764 .51662 .35784 .51392 .35154 .50696 Metetra
.964 .15 0 r
.35154 .50696 .35784 .51392 .36808 .51111 .3618 .50418 Metetra
.966 .144 0 r
.3618 .50418 .36808 .51111 .37836 .5082 .37211 .5013 Metetra
.967 .138 0 r
.37211 .5013 .37836 .5082 .3887 .50521 .38246 .49832 Metetra
.968 .134 0 r
.38246 .49832 .3887 .50521 .39907 .50214 .39286 .49526 Metetra
.969 .131 0 r
.39286 .49526 .39907 .50214 .40949 .499 .4033 .49212 Metetra
.969 .128 0 r
.4033 .49212 .40949 .499 .41996 .49579 .41379 .48891 Metetra
.97 .126 0 r
.41379 .48891 .41996 .49579 .43047 .49253 .42432 .48564 Metetra
.97 .125 0 r
.42432 .48564 .43047 .49253 .44102 .4892 .43489 .48229 Metetra
.97 .125 0 r
.43489 .48229 .44102 .4892 .45161 .48582 .44551 .47889 Metetra
.97 .125 0 r
.44551 .47889 .45161 .48582 .46224 .48238 .45617 .47542 Metetra
.97 .126 0 r
.45617 .47542 .46224 .48238 .47292 .47889 .46687 .47188 Metetra
.969 .128 0 r
.46687 .47188 .47292 .47889 .48364 .47533 .47762 .46828 Metetra
.969 .131 0 r
.47762 .46828 .48364 .47533 .4944 .47171 .4884 .4646 Metetra
.968 .134 0 r
.4884 .4646 .4944 .47171 .5052 .46801 .49923 .46085 Metetra
.967 .138 0 r
.49923 .46085 .5052 .46801 .51605 .46423 .5101 .457 Metetra
.966 .144 0 r
.5101 .457 .51605 .46423 .52693 .46037 .52101 .45306 Metetra
.964 .15 0 r
.52101 .45306 .52693 .46037 .53786 .4564 .53196 .44902 Metetra
.962 .158 0 r
.53196 .44902 .53786 .4564 .54882 .45233 .54295 .44485 Metetra
.96 .168 0 r
.54295 .44485 .54882 .45233 .55982 .44813 .55398 .44056 Metetra
.957 .179 0 r
.55398 .44056 .55982 .44813 .57086 .44379 .56505 .43612 Metetra
.954 .191 0 r
.56505 .43612 .57086 .44379 .58194 .4393 .57615 .43152 Metetra
.95 .206 0 r
.57615 .43152 .58194 .4393 .59305 .43463 .58729 .42673 Metetra
.945 .223 0 r
.58729 .42673 .59305 .43463 .6042 .42977 .59846 .42175 Metetra
.94 .243 0 r
.59846 .42175 .6042 .42977 .61537 .4247 .60966 .41655 Metetra
.935 .265 0 r
.60966 .41655 .61537 .4247 .62658 .4194 .62089 .4111 Metetra
.928 .29 0 r
.62089 .4111 .62658 .4194 .6378 .41383 .63214 .40539 Metetra
.92 .318 0 r
.63214 .40539 .6378 .41383 .64905 .40798 .64342 .39939 Metetra
.912 .349 0 r
.64342 .39939 .64905 .40798 .66032 .40183 .65471 .39308 Metetra
.902 .383 0 r
.65471 .39308 .66032 .40183 .6716 .39533 .66601 .38642 Metetra
.891 .42 0 r
.66601 .38642 .6716 .39533 .68289 .38848 .67732 .37939 Metetra
.879 .461 0 r
.67732 .37939 .68289 .38848 .69418 .38122 .68864 .37195 Metetra
.865 .505 0 r
.68864 .37195 .69418 .38122 .70547 .37354 .69995 .36409 Metetra
.85 .552 0 r
.69995 .36409 .70547 .37354 .71676 .36541 .71125 .35576 Metetra
.833 .602 0 r
.71125 .35576 .71676 .36541 .72802 .35678 .72254 .34693 Metetra
.814 .655 0 r
.72254 .34693 .72802 .35678 .73926 .34763 .7338 .33757 Metetra
.794 .709 0 r
.7338 .33757 .73926 .34763 .75047 .33792 .74502 .32765 Metetra
.771 .765 0 r
.74502 .32765 .75047 .33792 .76164 .32761 .75621 .31712 Metetra
.672 .746 0 r
.75621 .31712 .76164 .32761 .77276 .31668 .76735 .30597 Metetra
.562 .719 0 r
.76735 .30597 .77276 .31668 .78382 .30508 .77842 .29414 Metetra
.449 .689 0 r
.77842 .29414 .78382 .30508 .79481 .29278 .78942 .28161 Metetra
.397 .674 0 r
.12843 .4917 .13463 .50154 .14292 .50661 .13668 .49696 Metetra
.508 .705 0 r
.13668 .49696 .14292 .50661 .15136 .51104 .14509 .50157 Metetra
.618 .733 0 r
.14509 .50157 .15136 .51104 .15994 .51486 .15364 .50556 Metetra
.724 .759 0 r
.15364 .50556 .15994 .51486 .16865 .5181 .16233 .50897 Metetra
.782 .739 0 r
.16233 .50897 .16865 .5181 .17749 .52079 .17115 .51182 Metetra
.803 .685 0 r
.17115 .51182 .17749 .52079 .18644 .52296 .18008 .51414 Metetra
.823 .632 0 r
.18008 .51414 .18644 .52296 .19551 .52464 .18914 .51597 Metetra
.84 .582 0 r
.18914 .51597 .19551 .52464 .20468 .52586 .19829 .51734 Metetra
.856 .534 0 r
.19829 .51734 .20468 .52586 .21395 .52665 .20755 .51827 Metetra
.87 .489 0 r
.20755 .51827 .21395 .52665 .22331 .52705 .21691 .5188 Metetra
.883 .448 0 r
.21691 .5188 .22331 .52705 .23277 .52707 .22635 .51894 Metetra
.894 .409 0 r
.22635 .51894 .23277 .52707 .2423 .52674 .23588 .51874 Metetra
.905 .374 0 r
.23588 .51874 .2423 .52674 .25191 .5261 .24549 .51821 Metetra
.914 .342 0 r
.24549 .51821 .25191 .5261 .2616 .52516 .25518 .51737 Metetra
.922 .313 0 r
.25518 .51737 .2616 .52516 .27135 .52395 .26494 .51626 Metetra
.929 .287 0 r
.26494 .51626 .27135 .52395 .28117 .52249 .27477 .51489 Metetra
.935 .263 0 r
.27477 .51489 .28117 .52249 .29106 .52081 .28466 .51329 Metetra
.94 .243 0 r
.28466 .51329 .29106 .52081 .301 .51892 .29461 .51147 Metetra
.945 .225 0 r
.29461 .51147 .301 .51892 .311 .51683 .30462 .50946 Metetra
.949 .209 0 r
.30462 .50946 .311 .51683 .32106 .51458 .31469 .50727 Metetra
.953 .195 0 r
.31469 .50727 .32106 .51458 .33117 .51218 .32482 .50492 Metetra
.956 .183 0 r
.32482 .50492 .33117 .51218 .34133 .50963 .33499 .50243 Metetra
.958 .173 0 r
.33499 .50243 .34133 .50963 .35154 .50696 .34522 .4998 Metetra
.961 .164 0 r
.34522 .4998 .35154 .50696 .3618 .50418 .3555 .49705 Metetra
.962 .157 0 r
.3555 .49705 .3618 .50418 .37211 .5013 .36582 .49419 Metetra
.964 .151 0 r
.36582 .49419 .37211 .5013 .38246 .49832 .37619 .49123 Metetra
.965 .146 0 r
.37619 .49123 .38246 .49832 .39286 .49526 .38661 .48818 Metetra
.966 .142 0 r
.38661 .48818 .39286 .49526 .4033 .49212 .39708 .48505 Metetra
.967 .139 0 r
.39708 .48505 .4033 .49212 .41379 .48891 .40759 .48184 Metetra
.967 .137 0 r
.40759 .48184 .41379 .48891 .42432 .48564 .41814 .47855 Metetra
.968 .136 0 r
.41814 .47855 .42432 .48564 .43489 .48229 .42874 .47519 Metetra
.968 .136 0 r
.42874 .47519 .43489 .48229 .44551 .47889 .43938 .47176 Metetra
.968 .136 0 r
.43938 .47176 .44551 .47889 .45617 .47542 .45006 .46825 Metetra
.967 .137 0 r
.45006 .46825 .45617 .47542 .46687 .47188 .46079 .46468 Metetra
.967 .139 0 r
.46079 .46468 .46687 .47188 .47762 .46828 .47156 .46103 Metetra
.966 .142 0 r
.47156 .46103 .47762 .46828 .4884 .4646 .48237 .45729 Metetra
.965 .146 0 r
.48237 .45729 .4884 .4646 .49923 .46085 .49322 .45347 Metetra
.964 .151 0 r
.49322 .45347 .49923 .46085 .5101 .457 .50412 .44956 Metetra
.962 .157 0 r
.50412 .44956 .5101 .457 .52101 .45306 .51505 .44554 Metetra
.961 .164 0 r
.51505 .44554 .52101 .45306 .53196 .44902 .52603 .44141 Metetra
.958 .173 0 r
.52603 .44141 .53196 .44902 .54295 .44485 .53705 .43716 Metetra
.956 .183 0 r
.53705 .43716 .54295 .44485 .55398 .44056 .5481 .43276 Metetra
.953 .195 0 r
.5481 .43276 .55398 .44056 .56505 .43612 .5592 .42821 Metetra
.949 .209 0 r
.5592 .42821 .56505 .43612 .57615 .43152 .57033 .42349 Metetra
.945 .225 0 r
.57033 .42349 .57615 .43152 .58729 .42673 .58149 .41859 Metetra
.94 .243 0 r
.58149 .41859 .58729 .42673 .59846 .42175 .59268 .41347 Metetra
.935 .263 0 r
.59268 .41347 .59846 .42175 .60966 .41655 .60391 .40813 Metetra
.929 .287 0 r
.60391 .40813 .60966 .41655 .62089 .4111 .61516 .40254 Metetra
.922 .313 0 r
.61516 .40254 .62089 .4111 .63214 .40539 .62644 .39667 Metetra
.914 .342 0 r
.62644 .39667 .63214 .40539 .64342 .39939 .63773 .39051 Metetra
.905 .374 0 r
.63773 .39051 .64342 .39939 .65471 .39308 .64905 .38403 Metetra
.894 .409 0 r
.64905 .38403 .65471 .39308 .66601 .38642 .66037 .37719 Metetra
.883 .448 0 r
.66037 .37719 .66601 .38642 .67732 .37939 .67171 .36997 Metetra
.87 .489 0 r
.67171 .36997 .67732 .37939 .68864 .37195 .68304 .36235 Metetra
.856 .534 0 r
.68304 .36235 .68864 .37195 .69995 .36409 .69437 .35428 Metetra
.84 .582 0 r
.69437 .35428 .69995 .36409 .71125 .35576 .7057 .34575 Metetra
.823 .632 0 r
.7057 .34575 .71125 .35576 .72254 .34693 .717 .33671 Metetra
.803 .685 0 r
.717 .33671 .72254 .34693 .7338 .33757 .72828 .32713 Metetra
.782 .739 0 r
.72828 .32713 .7338 .33757 .74502 .32765 .73952 .31698 Metetra
.724 .759 0 r
.73952 .31698 .74502 .32765 .75621 .31712 .75072 .30623 Metetra
.618 .733 0 r
.75072 .30623 .75621 .31712 .76735 .30597 .76187 .29484 Metetra
.508 .705 0 r
.76187 .29484 .76735 .30597 .77842 .29414 .77296 .28277 Metetra
.397 .674 0 r
.77296 .28277 .77842 .29414 .78942 .28161 .78398 .26999 Metetra
.341 .658 0 r
.12224 .48145 .12843 .4917 .13668 .49696 .13046 .4869 Metetra
.451 .69 0 r
.13046 .4869 .13668 .49696 .14509 .50157 .13884 .4917 Metetra
.56 .718 0 r
.13884 .4917 .14509 .50157 .15364 .50556 .14736 .49587 Metetra
.666 .745 0 r
.14736 .49587 .15364 .50556 .16233 .50897 .15602 .49945 Metetra
.768 .769 0 r
.15602 .49945 .16233 .50897 .17115 .51182 .16481 .50248 Metetra
.791 .716 0 r
.16481 .50248 .17115 .51182 .18008 .51414 .17373 .50497 Metetra
.811 .664 0 r
.17373 .50497 .18008 .51414 .18914 .51597 .18276 .50696 Metetra
.829 .614 0 r
.18276 .50696 .18914 .51597 .19829 .51734 .1919 .50848 Metetra
.846 .566 0 r
.1919 .50848 .19829 .51734 .20755 .51827 .20115 .50956 Metetra
.861 .52 0 r
.20115 .50956 .20755 .51827 .21691 .5188 .21049 .51023 Metetra
.874 .478 0 r
.21049 .51023 .21691 .5188 .22635 .51894 .21993 .51051 Metetra
.886 .438 0 r
.21993 .51051 .22635 .51894 .23588 .51874 .22945 .51043 Metetra
.897 .402 0 r
.22945 .51043 .23588 .51874 .24549 .51821 .23906 .51002 Metetra
.906 .369 0 r
.23906 .51002 .24549 .51821 .25518 .51737 .24875 .5093 Metetra
.915 .338 0 r
.24875 .5093 .25518 .51737 .26494 .51626 .25851 .50829 Metetra
.922 .311 0 r
.25851 .50829 .26494 .51626 .27477 .51489 .26834 .50702 Metetra
.929 .287 0 r
.26834 .50702 .27477 .51489 .28466 .51329 .27824 .50551 Metetra
.935 .265 0 r
.27824 .50551 .28466 .51329 .29461 .51147 .2882 .50377 Metetra
.94 .246 0 r
.2882 .50377 .29461 .51147 .30462 .50946 .29822 .50184 Metetra
.944 .229 0 r
.29822 .50184 .30462 .50946 .31469 .50727 .3083 .49972 Metetra
.948 .214 0 r
.3083 .49972 .31469 .50727 .32482 .50492 .31843 .49742 Metetra
.951 .201 0 r
.31843 .49742 .32482 .50492 .33499 .50243 .32862 .49498 Metetra
.954 .19 0 r
.32862 .49498 .33499 .50243 .34522 .4998 .33887 .4924 Metetra
.957 .18 0 r
.33887 .4924 .34522 .4998 .3555 .49705 .34916 .48968 Metetra
.959 .172 0 r
.34916 .48968 .3555 .49705 .36582 .49419 .3595 .48685 Metetra
.96 .166 0 r
.3595 .48685 .36582 .49419 .37619 .49123 .36989 .48392 Metetra
.962 .16 0 r
.36989 .48392 .37619 .49123 .38661 .48818 .38033 .48088 Metetra
.963 .156 0 r
.38033 .48088 .38661 .48818 .39708 .48505 .39082 .47775 Metetra
.963 .153 0 r
.39082 .47775 .39708 .48505 .40759 .48184 .40134 .47454 Metetra
.964 .15 0 r
.40134 .47454 .40759 .48184 .41814 .47855 .41192 .47124 Metetra
.964 .149 0 r
.41192 .47124 .41814 .47855 .42874 .47519 .42254 .46786 Metetra
.964 .149 0 r
.42254 .46786 .42874 .47519 .43938 .47176 .4332 .4644 Metetra
.964 .149 0 r
.4332 .4644 .43938 .47176 .45006 .46825 .44391 .46087 Metetra
.964 .15 0 r
.44391 .46087 .45006 .46825 .46079 .46468 .45466 .45725 Metetra
.963 .153 0 r
.45466 .45725 .46079 .46468 .47156 .46103 .46546 .45355 Metetra
.963 .156 0 r
.46546 .45355 .47156 .46103 .48237 .45729 .47629 .44976 Metetra
.962 .16 0 r
.47629 .44976 .48237 .45729 .49322 .45347 .48717 .44587 Metetra
.96 .166 0 r
.48717 .44587 .49322 .45347 .50412 .44956 .4981 .44188 Metetra
.959 .172 0 r
.4981 .44188 .50412 .44956 .51505 .44554 .50906 .43779 Metetra
.957 .18 0 r
.50906 .43779 .51505 .44554 .52603 .44141 .52006 .43356 Metetra
.954 .19 0 r
.52006 .43356 .52603 .44141 .53705 .43716 .5311 .42921 Metetra
.951 .201 0 r
.5311 .42921 .53705 .43716 .5481 .43276 .54218 .42471 Metetra
.948 .214 0 r
.54218 .42471 .5481 .43276 .5592 .42821 .5533 .42004 Metetra
.944 .229 0 r
.5533 .42004 .5592 .42821 .57033 .42349 .56446 .4152 Metetra
.94 .246 0 r
.56446 .4152 .57033 .42349 .58149 .41859 .57564 .41017 Metetra
.935 .265 0 r
.57564 .41017 .58149 .41859 .59268 .41347 .58686 .40491 Metetra
.929 .287 0 r
.58686 .40491 .59268 .41347 .60391 .40813 .59811 .39942 Metetra
.922 .311 0 r
.59811 .39942 .60391 .40813 .61516 .40254 .60939 .39368 Metetra
.915 .338 0 r
.60939 .39368 .61516 .40254 .62644 .39667 .62069 .38765 Metetra
.906 .369 0 r
.62069 .38765 .62644 .39667 .63773 .39051 .63201 .38132 Metetra
.897 .402 0 r
.63201 .38132 .63773 .39051 .64905 .38403 .64335 .37465 Metetra
.886 .438 0 r
.64335 .37465 .64905 .38403 .66037 .37719 .65469 .36763 Metetra
.874 .478 0 r
.65469 .36763 .66037 .37719 .67171 .36997 .66605 .36022 Metetra
.861 .52 0 r
.66605 .36022 .67171 .36997 .68304 .36235 .6774 .35239 Metetra
.846 .566 0 r
.6774 .35239 .68304 .36235 .69437 .35428 .68875 .34412 Metetra
.829 .614 0 r
.68875 .34412 .69437 .35428 .7057 .34575 .70009 .33537 Metetra
.811 .664 0 r
.70009 .33537 .7057 .34575 .717 .33671 .71141 .3261 Metetra
.791 .716 0 r
.71141 .3261 .717 .33671 .72828 .32713 .72271 .3163 Metetra
.768 .769 0 r
.72271 .3163 .72828 .32713 .73952 .31698 .73397 .30591 Metetra
.666 .745 0 r
.73397 .30591 .73952 .31698 .75072 .30623 .74518 .29491 Metetra
.56 .718 0 r
.74518 .29491 .75072 .30623 .76187 .29484 .75635 .28327 Metetra
.451 .69 0 r
.75635 .28327 .76187 .29484 .77296 .28277 .76744 .27095 Metetra
.341 .658 0 r
.76744 .27095 .77296 .28277 .78398 .26999 .77847 .25791 Metetra
.283 .64 0 r
.11609 .47074 .12224 .48145 .13046 .4869 .12427 .4764 Metetra
.391 .673 0 r
.12427 .4764 .13046 .4869 .13884 .4917 .1326 .48139 Metetra
.499 .702 0 r
.1326 .48139 .13884 .4917 .14736 .49587 .14109 .48576 Metetra
.605 .73 0 r
.14109 .48576 .14736 .49587 .15602 .49945 .14972 .48954 Metetra
.707 .755 0 r
.14972 .48954 .15602 .49945 .16481 .50248 .15848 .49274 Metetra
.777 .75 0 r
.15848 .49274 .16481 .50248 .17373 .50497 .16737 .49541 Metetra
.798 .698 0 r
.16737 .49541 .17373 .50497 .18276 .50696 .17638 .49757 Metetra
.817 .648 0 r
.17638 .49757 .18276 .50696 .1919 .50848 .18551 .49926 Metetra
.834 .599 0 r
.18551 .49926 .1919 .50848 .20115 .50956 .19474 .5005 Metetra
.85 .553 0 r
.19474 .5005 .20115 .50956 .21049 .51023 .20407 .50131 Metetra
.864 .51 0 r
.20407 .50131 .21049 .51023 .21993 .51051 .2135 .50174 Metetra
.876 .47 0 r
.2135 .50174 .21993 .51051 .22945 .51043 .22302 .50179 Metetra
.888 .433 0 r
.22302 .50179 .22945 .51043 .23906 .51002 .23262 .50151 Metetra
.898 .398 0 r
.23262 .50151 .23906 .51002 .24875 .5093 .2423 .50091 Metetra
.907 .367 0 r
.2423 .50091 .24875 .5093 .25851 .50829 .25206 .50001 Metetra
.915 .338 0 r
.25206 .50001 .25851 .50829 .26834 .50702 .26189 .49885 Metetra
.922 .313 0 r
.26189 .49885 .26834 .50702 .27824 .50551 .27179 .49743 Metetra
.928 .29 0 r
.27179 .49743 .27824 .50551 .2882 .50377 .28176 .49579 Metetra
.933 .269 0 r
.28176 .49579 .2882 .50377 .29822 .50184 .29179 .49393 Metetra
.938 .251 0 r
.29179 .49393 .29822 .50184 .3083 .49972 .30188 .49188 Metetra
.942 .235 0 r
.30188 .49188 .3083 .49972 .31843 .49742 .31203 .48966 Metetra
.946 .221 0 r
.31203 .48966 .31843 .49742 .32862 .49498 .32223 .48727 Metetra
.949 .209 0 r
.32223 .48727 .32862 .49498 .33887 .4924 .33248 .48473 Metetra
.952 .199 0 r
.33248 .48473 .33887 .4924 .34916 .48968 .34279 .48206 Metetra
.954 .19 0 r
.34279 .48206 .34916 .48968 .3595 .48685 .35315 .47926 Metetra
.956 .183 0 r
.35315 .47926 .3595 .48685 .36989 .48392 .36356 .47635 Metetra
.957 .177 0 r
.36356 .47635 .36989 .48392 .38033 .48088 .37402 .47333 Metetra
.959 .172 0 r
.37402 .47333 .38033 .48088 .39082 .47775 .38452 .47021 Metetra
.959 .169 0 r
.38452 .47021 .39082 .47775 .40134 .47454 .39507 .46699 Metetra
.96 .166 0 r
.39507 .46699 .40134 .47454 .41192 .47124 .40567 .46368 Metetra
.96 .165 0 r
.40567 .46368 .41192 .47124 .42254 .46786 .41631 .46029 Metetra
.961 .164 0 r
.41631 .46029 .42254 .46786 .4332 .4644 .427 .4568 Metetra
.96 .165 0 r
.427 .4568 .4332 .4644 .44391 .46087 .43773 .45323 Metetra
.96 .166 0 r
.43773 .45323 .44391 .46087 .45466 .45725 .4485 .44957 Metetra
.959 .169 0 r
.4485 .44957 .45466 .45725 .46546 .45355 .45932 .44582 Metetra
.959 .172 0 r
.45932 .44582 .46546 .45355 .47629 .44976 .47018 .44197 Metetra
.957 .177 0 r
.47018 .44197 .47629 .44976 .48717 .44587 .48109 .43801 Metetra
.956 .183 0 r
.48109 .43801 .48717 .44587 .4981 .44188 .49203 .43395 Metetra
.954 .19 0 r
.49203 .43395 .4981 .44188 .50906 .43779 .50302 .42976 Metetra
.952 .199 0 r
.50302 .42976 .50906 .43779 .52006 .43356 .51405 .42545 Metetra
.949 .209 0 r
.51405 .42545 .52006 .43356 .5311 .42921 .52512 .42099 Metetra
.946 .221 0 r
.52512 .42099 .5311 .42921 .54218 .42471 .53622 .41638 Metetra
.942 .235 0 r
.53622 .41638 .54218 .42471 .5533 .42004 .54737 .41159 Metetra
.938 .251 0 r
.54737 .41159 .5533 .42004 .56446 .4152 .55855 .40662 Metetra
.933 .269 0 r
.55855 .40662 .56446 .4152 .57564 .41017 .56976 .40145 Metetra
.928 .29 0 r
.56976 .40145 .57564 .41017 .58686 .40491 .581 .39605 Metetra
.922 .313 0 r
.581 .39605 .58686 .40491 .59811 .39942 .59228 .39041 Metetra
.915 .338 0 r
.59228 .39041 .59811 .39942 .60939 .39368 .60358 .3845 Metetra
.907 .367 0 r
.60358 .3845 .60939 .39368 .62069 .38765 .6149 .3783 Metetra
.898 .398 0 r
.6149 .3783 .62069 .38765 .63201 .38132 .62624 .37179 Metetra
.888 .433 0 r
.62624 .37179 .63201 .38132 .64335 .37465 .6376 .36493 Metetra
.876 .47 0 r
.6376 .36493 .64335 .37465 .65469 .36763 .64897 .35771 Metetra
.864 .51 0 r
.64897 .35771 .65469 .36763 .66605 .36022 .66034 .3501 Metetra
.85 .553 0 r
.66034 .3501 .66605 .36022 .6774 .35239 .67171 .34206 Metetra
.834 .599 0 r
.67171 .34206 .6774 .35239 .68875 .34412 .68308 .33356 Metetra
.817 .648 0 r
.68308 .33356 .68875 .34412 .70009 .33537 .69444 .32458 Metetra
.798 .698 0 r
.69444 .32458 .70009 .33537 .71141 .3261 .70578 .31509 Metetra
.777 .75 0 r
.70578 .31509 .71141 .3261 .72271 .3163 .71708 .30504 Metetra
.707 .755 0 r
.71708 .30504 .72271 .3163 .73397 .30591 .72836 .2944 Metetra
.605 .73 0 r
.72836 .2944 .73397 .30591 .74518 .29491 .73959 .28315 Metetra
.499 .702 0 r
.73959 .28315 .74518 .29491 .75635 .28327 .75076 .27125 Metetra
.391 .673 0 r
.75076 .27125 .75635 .28327 .76744 .27095 .76187 .25866 Metetra
.283 .64 0 r
.76187 .25866 .76744 .27095 .77847 .25791 .7729 .24536 Metetra
.222 .621 0 r
.10996 .45957 .11609 .47074 .12427 .4764 .1181 .46544 Metetra
.329 .654 0 r
.1181 .46544 .12427 .4764 .1326 .48139 .12639 .47065 Metetra
.435 .685 0 r
.12639 .47065 .1326 .48139 .14109 .48576 .13484 .47522 Metetra
.54 .713 0 r
.13484 .47522 .14109 .48576 .14972 .48954 .14344 .47919 Metetra
.642 .739 0 r
.14344 .47919 .14972 .48954 .15848 .49274 .15217 .48259 Metetra
.741 .763 0 r
.15217 .48259 .15848 .49274 .16737 .49541 .16103 .48545 Metetra
.784 .734 0 r
.16103 .48545 .16737 .49541 .17638 .49757 .17002 .48779 Metetra
.804 .684 0 r
.17002 .48779 .17638 .49757 .18551 .49926 .17912 .48965 Metetra
.822 .635 0 r
.17912 .48965 .18551 .49926 .19474 .5005 .18833 .49105 Metetra
.838 .589 0 r
.18833 .49105 .19474 .5005 .20407 .50131 .19765 .49203 Metetra
.852 .545 0 r
.19765 .49203 .20407 .50131 .2135 .50174 .20706 .4926 Metetra
.866 .504 0 r
.20706 .4926 .2135 .50174 .22302 .50179 .21657 .4928 Metetra
.877 .466 0 r
.21657 .4928 .22302 .50179 .23262 .50151 .22617 .49266 Metetra
.888 .431 0 r
.22617 .49266 .23262 .50151 .2423 .50091 .23584 .49218 Metetra
.898 .398 0 r
.23584 .49218 .2423 .50091 .25206 .50001 .2456 .49141 Metetra
.906 .369 0 r
.2456 .49141 .25206 .50001 .26189 .49885 .25543 .49035 Metetra
.914 .342 0 r
.25543 .49035 .26189 .49885 .27179 .49743 .26533 .48904 Metetra
.92 .318 0 r
.26533 .48904 .27179 .49743 .28176 .49579 .2753 .48749 Metetra
.926 .296 0 r
.2753 .48749 .28176 .49579 .29179 .49393 .28534 .48572 Metetra
.931 .277 0 r
.28534 .48572 .29179 .49393 .30188 .49188 .29544 .48375 Metetra
.936 .26 0 r
.29544 .48375 .30188 .49188 .31203 .48966 .30559 .4816 Metetra
.94 .245 0 r
.30559 .4816 .31203 .48966 .32223 .48727 .31581 .47927 Metetra
.943 .232 0 r
.31581 .47927 .32223 .48727 .33248 .48473 .32608 .47679 Metetra
.946 .221 0 r
.32608 .47679 .33248 .48473 .34279 .48206 .3364 .47416 Metetra
.949 .211 0 r
.3364 .47416 .34279 .48206 .35315 .47926 .34677 .47139 Metetra
.951 .203 0 r
.34677 .47139 .35315 .47926 .36356 .47635 .3572 .46851 Metetra
.952 .197 0 r
.3572 .46851 .36356 .47635 .37402 .47333 .36767 .4655 Metetra
.954 .191 0 r
.36767 .4655 .37402 .47333 .38452 .47021 .37819 .46239 Metetra
.955 .187 0 r
.37819 .46239 .38452 .47021 .39507 .46699 .38876 .45917 Metetra
.955 .185 0 r
.38876 .45917 .39507 .46699 .40567 .46368 .39938 .45586 Metetra
.956 .183 0 r
.39938 .45586 .40567 .46368 .41631 .46029 .41005 .45244 Metetra
.956 .182 0 r
.41005 .45244 .41631 .46029 .427 .4568 .42075 .44893 Metetra
.956 .183 0 r
.42075 .44893 .427 .4568 .43773 .45323 .43151 .44533 Metetra
.955 .185 0 r
.43151 .44533 .43773 .45323 .4485 .44957 .44231 .44162 Metetra
.955 .187 0 r
.44231 .44162 .4485 .44957 .45932 .44582 .45315 .43781 Metetra
.954 .191 0 r
.45315 .43781 .45932 .44582 .47018 .44197 .46404 .4339 Metetra
.952 .197 0 r
.46404 .4339 .47018 .44197 .48109 .43801 .47496 .42987 Metetra
.951 .203 0 r
.47496 .42987 .48109 .43801 .49203 .43395 .48594 .42573 Metetra
.949 .211 0 r
.48594 .42573 .49203 .43395 .50302 .42976 .49695 .42145 Metetra
.946 .221 0 r
.49695 .42145 .50302 .42976 .51405 .42545 .508 .41704 Metetra
.943 .232 0 r
.508 .41704 .51405 .42545 .52512 .42099 .51909 .41247 Metetra
.94 .245 0 r
.51909 .41247 .52512 .42099 .53622 .41638 .53023 .40774 Metetra
.936 .26 0 r
.53023 .40774 .53622 .41638 .54737 .41159 .54139 .40283 Metetra
.931 .277 0 r
.54139 .40283 .54737 .41159 .55855 .40662 .5526 .39773 Metetra
.926 .296 0 r
.5526 .39773 .55855 .40662 .56976 .40145 .56383 .39241 Metetra
.92 .318 0 r
.56383 .39241 .56976 .40145 .581 .39605 .5751 .38686 Metetra
.914 .342 0 r
.5751 .38686 .581 .39605 .59228 .39041 .5864 .38105 Metetra
.906 .369 0 r
.5864 .38105 .59228 .39041 .60358 .3845 .59772 .37497 Metetra
.898 .398 0 r
.59772 .37497 .60358 .3845 .6149 .3783 .60906 .36859 Metetra
.888 .431 0 r
.60906 .36859 .6149 .3783 .62624 .37179 .62043 .36189 Metetra
.877 .466 0 r
.62043 .36189 .62624 .37179 .6376 .36493 .63181 .35484 Metetra
.866 .504 0 r
.63181 .35484 .6376 .36493 .64897 .35771 .64319 .34741 Metetra
.852 .545 0 r
.64319 .34741 .64897 .35771 .66034 .3501 .65459 .33958 Metetra
.838 .589 0 r
.65459 .33958 .66034 .3501 .67171 .34206 .66598 .33132 Metetra
.822 .635 0 r
.66598 .33132 .67171 .34206 .68308 .33356 .67737 .3226 Metetra
.804 .684 0 r
.67737 .3226 .68308 .33356 .69444 .32458 .68874 .31338 Metetra
.784 .734 0 r
.68874 .31338 .69444 .32458 .70578 .31509 .70009 .30363 Metetra
.741 .763 0 r
.70009 .30363 .70578 .31509 .71708 .30504 .71141 .29333 Metetra
.642 .739 0 r
.71141 .29333 .71708 .30504 .72836 .2944 .7227 .28244 Metetra
.54 .713 0 r
.7227 .28244 .72836 .2944 .73959 .28315 .73394 .27092 Metetra
.435 .685 0 r
.73394 .27092 .73959 .28315 .75076 .27125 .74512 .25875 Metetra
.329 .654 0 r
.74512 .25875 .75076 .27125 .76187 .25866 .75624 .24588 Metetra
.222 .621 0 r
.75624 .24588 .76187 .25866 .7729 .24536 .76728 .23229 Metetra
.16 .6 0 r
.10388 .4479 .10996 .45957 .1181 .46544 .11196 .45399 Metetra
.264 .634 0 r
.11196 .45399 .1181 .46544 .12639 .47065 .12021 .45942 Metetra
.368 .666 0 r
.12021 .45942 .12639 .47065 .13484 .47522 .12862 .46421 Metetra
.472 .695 0 r
.12862 .46421 .13484 .47522 .14344 .47919 .13718 .46839 Metetra
.573 .722 0 r
.13718 .46839 .14344 .47919 .15217 .48259 .14587 .472 Metetra
.672 .746 0 r
.14587 .472 .15217 .48259 .16103 .48545 .1547 .47505 Metetra
.767 .769 0 r
.1547 .47505 .16103 .48545 .17002 .48779 .16366 .47758 Metetra
.789 .721 0 r
.16366 .47758 .17002 .48779 .17912 .48965 .17274 .47963 Metetra
.808 .673 0 r
.17274 .47963 .17912 .48965 .18833 .49105 .18193 .48121 Metetra
.825 .627 0 r
.18193 .48121 .18833 .49105 .19765 .49203 .19123 .48235 Metetra
.84 .583 0 r
.19123 .48235 .19765 .49203 .20706 .4926 .20063 .48308 Metetra
.854 .541 0 r
.20063 .48308 .20706 .4926 .21657 .4928 .21012 .48344 Metetra
.866 .502 0 r
.21012 .48344 .21657 .4928 .22617 .49266 .21971 .48343 Metetra
.877 .466 0 r
.21971 .48343 .22617 .49266 .23584 .49218 .22938 .4831 Metetra
.888 .432 0 r
.22938 .4831 .23584 .49218 .2456 .49141 .23913 .48245 Metetra
.897 .402 0 r
.23913 .48245 .2456 .49141 .25543 .49035 .24896 .48151 Metetra
.905 .374 0 r
.24896 .48151 .25543 .49035 .26533 .48904 .25886 .48031 Metetra
.912 .349 0 r
.25886 .48031 .26533 .48904 .2753 .48749 .26883 .47886 Metetra
.918 .326 0 r
.26883 .47886 .2753 .48749 .28534 .48572 .27887 .47719 Metetra
.924 .305 0 r
.27887 .47719 .28534 .48572 .29544 .48375 .28898 .4753 Metetra
.929 .287 0 r
.28898 .4753 .29544 .48375 .30559 .4816 .29914 .47322 Metetra
.933 .272 0 r
.29914 .47322 .30559 .4816 .31581 .47927 .30936 .47096 Metetra
.937 .258 0 r
.30936 .47096 .31581 .47927 .32608 .47679 .31964 .46853 Metetra
.94 .246 0 r
.31964 .46853 .32608 .47679 .3364 .47416 .32998 .46595 Metetra
.942 .235 0 r
.32998 .46595 .3364 .47416 .34677 .47139 .34037 .46322 Metetra
.945 .227 0 r
.34037 .46322 .34677 .47139 .3572 .46851 .35081 .46036 Metetra
.947 .219 0 r
.35081 .46036 .3572 .46851 .36767 .4655 .3613 .45738 Metetra
.948 .214 0 r
.3613 .45738 .36767 .4655 .37819 .46239 .37184 .45427 Metetra
.949 .209 0 r
.37184 .45427 .37819 .46239 .38876 .45917 .38243 .45106 Metetra
.95 .206 0 r
.38243 .45106 .38876 .45917 .39938 .45586 .39307 .44773 Metetra
.95 .204 0 r
.39307 .44773 .39938 .45586 .41005 .45244 .40375 .4443 Metetra
.951 .204 0 r
.40375 .4443 .41005 .45244 .42075 .44893 .41448 .44076 Metetra
.95 .204 0 r
.41448 .44076 .42075 .44893 .43151 .44533 .42526 .43712 Metetra
.95 .206 0 r
.42526 .43712 .43151 .44533 .44231 .44162 .43608 .43337 Metetra
.949 .209 0 r
.43608 .43337 .44231 .44162 .45315 .43781 .44694 .4295 Metetra
.948 .214 0 r
.44694 .4295 .45315 .43781 .46404 .4339 .45785 .42553 Metetra
.947 .219 0 r
.45785 .42553 .46404 .4339 .47496 .42987 .46881 .42142 Metetra
.945 .227 0 r
.46881 .42142 .47496 .42987 .48594 .42573 .4798 .41719 Metetra
.942 .235 0 r
.4798 .41719 .48594 .42573 .49695 .42145 .49084 .41283 Metetra
.94 .246 0 r
.49084 .41283 .49695 .42145 .508 .41704 .50192 .40831 Metetra
.937 .258 0 r
.50192 .40831 .508 .41704 .51909 .41247 .51303 .40363 Metetra
.933 .272 0 r
.51303 .40363 .51909 .41247 .53023 .40774 .52419 .39878 Metetra
.929 .287 0 r
.52419 .39878 .53023 .40774 .54139 .40283 .53538 .39374 Metetra
.924 .305 0 r
.53538 .39374 .54139 .40283 .5526 .39773 .54661 .38849 Metetra
.918 .326 0 r
.54661 .38849 .5526 .39773 .56383 .39241 .55787 .38302 Metetra
.912 .349 0 r
.55787 .38302 .56383 .39241 .5751 .38686 .56916 .37731 Metetra
.905 .374 0 r
.56916 .37731 .5751 .38686 .5864 .38105 .58048 .37133 Metetra
.897 .402 0 r
.58048 .37133 .5864 .38105 .59772 .37497 .59182 .36507 Metetra
.888 .432 0 r
.59182 .36507 .59772 .37497 .60906 .36859 .60319 .3585 Metetra
.877 .466 0 r
.60319 .3585 .60906 .36859 .62043 .36189 .61457 .3516 Metetra
.866 .502 0 r
.61457 .3516 .62043 .36189 .63181 .35484 .62597 .34435 Metetra
.854 .541 0 r
.62597 .34435 .63181 .35484 .64319 .34741 .63738 .3367 Metetra
.84 .583 0 r
.63738 .3367 .64319 .34741 .65459 .33958 .64879 .32865 Metetra
.825 .627 0 r
.64879 .32865 .65459 .33958 .66598 .33132 .6602 .32015 Metetra
.808 .673 0 r
.6602 .32015 .66598 .33132 .67737 .3226 .6716 .31119 Metetra
.789 .721 0 r
.6716 .31119 .67737 .3226 .68874 .31338 .68299 .30172 Metetra
.767 .769 0 r
.68299 .30172 .68874 .31338 .70009 .30363 .69435 .29172 Metetra
.672 .746 0 r
.69435 .29172 .70009 .30363 .71141 .29333 .70569 .28115 Metetra
.573 .722 0 r
.70569 .28115 .71141 .29333 .7227 .28244 .71698 .26999 Metetra
.472 .695 0 r
.71698 .26999 .7227 .28244 .73394 .27092 .72823 .2582 Metetra
.368 .666 0 r
.72823 .2582 .73394 .27092 .74512 .25875 .73942 .24574 Metetra
.264 .634 0 r
.73942 .24574 .74512 .25875 .75624 .24588 .75055 .23258 Metetra
.16 .6 0 r
.75055 .23258 .75624 .24588 .76728 .23229 .76159 .2187 Metetra
.097 .577 0 r
.09783 .43571 .10388 .4479 .11196 .45399 .10586 .44204 Metetra
.197 .613 0 r
.10586 .44204 .11196 .45399 .12021 .45942 .11407 .4477 Metetra
.299 .645 0 r
.11407 .4477 .12021 .45942 .12862 .46421 .12243 .45272 Metetra
.4 .675 0 r
.12243 .45272 .12862 .46421 .13718 .46839 .13094 .45712 Metetra
.501 .703 0 r
.13094 .45712 .13718 .46839 .14587 .472 .1396 .46094 Metetra
.599 .728 0 r
.1396 .46094 .14587 .472 .1547 .47505 .1484 .4642 Metetra
.694 .752 0 r
.1484 .4642 .1547 .47505 .16366 .47758 .15733 .46693 Metetra
.773 .761 0 r
.15733 .46693 .16366 .47758 .17274 .47963 .16637 .46916 Metetra
.792 .713 0 r
.16637 .46916 .17274 .47963 .18193 .48121 .17554 .47093 Metetra
.81 .667 0 r
.17554 .47093 .18193 .48121 .19123 .48235 .18482 .47225 Metetra
.826 .623 0 r
.18482 .47225 .19123 .48235 .20063 .48308 .1942 .47315 Metetra
.841 .581 0 r
.1942 .47315 .20063 .48308 .21012 .48344 .20368 .47367 Metetra
.854 .541 0 r
.20368 .47367 .21012 .48344 .21971 .48343 .21325 .47381 Metetra
.866 .504 0 r
.21325 .47381 .21971 .48343 .22938 .4831 .22291 .47362 Metetra
.876 .47 0 r
.22291 .47362 .22938 .4831 .23913 .48245 .23265 .47311 Metetra
.886 .438 0 r
.23265 .47311 .23913 .48245 .24896 .48151 .24248 .4723 Metetra
.894 .409 0 r
.24248 .4723 .24896 .48151 .25886 .48031 .25238 .47121 Metetra
.902 .383 0 r
.25238 .47121 .25886 .48031 .26883 .47886 .26235 .46987 Metetra
.909 .359 0 r
.26235 .46987 .26883 .47886 .27887 .47719 .27239 .46829 Metetra
.915 .338 0 r
.27239 .46829 .27887 .47719 .28898 .4753 .2825 .46649 Metetra
.92 .318 0 r
.2825 .46649 .28898 .4753 .29914 .47322 .29267 .46449 Metetra
.925 .301 0 r
.29267 .46449 .29914 .47322 .30936 .47096 .3029 .4623 Metetra
.929 .287 0 r
.3029 .4623 .30936 .47096 .31964 .46853 .31319 .45993 Metetra
.932 .274 0 r
.31319 .45993 .31964 .46853 .32998 .46595 .32354 .4574 Metetra
.935 .263 0 r
.32354 .4574 .32998 .46595 .34037 .46322 .33394 .45471 Metetra
.938 .253 0 r
.33394 .45471 .34037 .46322 .35081 .46036 .34439 .45188 Metetra
.94 .246 0 r
.34439 .45188 .35081 .46036 .3613 .45738 .3549 .44892 Metetra
.941 .239 0 r
.3549 .44892 .3613 .45738 .37184 .45427 .36546 .44583 Metetra
.943 .235 0 r
.36546 .44583 .37184 .45427 .38243 .45106 .37607 .44261 Metetra
.943 .231 0 r
.37607 .44261 .38243 .45106 .39307 .44773 .38672 .43928 Metetra
.944 .229 0 r
.38672 .43928 .39307 .44773 .40375 .4443 .39742 .43583 Metetra
.944 .229 0 r
.39742 .43583 .40375 .4443 .41448 .44076 .40818 .43226 Metetra
.944 .229 0 r
.40818 .43226 .41448 .44076 .42526 .43712 .41897 .42858 Metetra
.943 .231 0 r
.41897 .42858 .42526 .43712 .43608 .43337 .42982 .42478 Metetra
.943 .235 0 r
.42982 .42478 .43608 .43337 .44694 .4295 .4407 .42086 Metetra
.941 .239 0 r
.4407 .42086 .44694 .4295 .45785 .42553 .45164 .41682 Metetra
.94 .246 0 r
.45164 .41682 .45785 .42553 .46881 .42142 .46261 .41264 Metetra
.938 .253 0 r
.46261 .41264 .46881 .42142 .4798 .41719 .47363 .40832 Metetra
.935 .263 0 r
.47363 .40832 .4798 .41719 .49084 .41283 .48469 .40385 Metetra
.932 .274 0 r
.48469 .40385 .49084 .41283 .50192 .40831 .49579 .39923 Metetra
.929 .287 0 r
.49579 .39923 .50192 .40831 .51303 .40363 .50694 .39443 Metetra
.925 .301 0 r
.50694 .39443 .51303 .40363 .52419 .39878 .51811 .38945 Metetra
.92 .318 0 r
.51811 .38945 .52419 .39878 .53538 .39374 .52933 .38427 Metetra
.915 .338 0 r
.52933 .38427 .53538 .39374 .54661 .38849 .54058 .37888 Metetra
.909 .359 0 r
.54058 .37888 .54661 .38849 .55787 .38302 .55186 .37325 Metetra
.902 .383 0 r
.55186 .37325 .55787 .38302 .56916 .37731 .56318 .36737 Metetra
.894 .409 0 r
.56318 .36737 .56916 .37731 .58048 .37133 .57452 .36122 Metetra
.886 .438 0 r
.57452 .36122 .58048 .37133 .59182 .36507 .58588 .35477 Metetra
.876 .47 0 r
.58588 .35477 .59182 .36507 .60319 .3585 .59727 .34801 Metetra
.866 .504 0 r
.59727 .34801 .60319 .3585 .61457 .3516 .60868 .3409 Metetra
.854 .541 0 r
.60868 .3409 .61457 .3516 .62597 .34435 .62009 .33343 Metetra
.841 .581 0 r
.62009 .33343 .62597 .34435 .63738 .3367 .63152 .32556 Metetra
.826 .623 0 r
.63152 .32556 .63738 .3367 .64879 .32865 .64295 .31727 Metetra
.81 .667 0 r
.64295 .31727 .64879 .32865 .6602 .32015 .65437 .30853 Metetra
.792 .713 0 r
.65437 .30853 .6602 .32015 .6716 .31119 .66579 .29932 Metetra
.773 .761 0 r
.66579 .29932 .6716 .31119 .68299 .30172 .67719 .28959 Metetra
.694 .752 0 r
.67719 .28959 .68299 .30172 .69435 .29172 .68856 .27932 Metetra
.599 .728 0 r
.68856 .27932 .69435 .29172 .70569 .28115 .69991 .26848 Metetra
.501 .703 0 r
.69991 .26848 .70569 .28115 .71698 .26999 .71122 .25703 Metetra
.4 .675 0 r
.71122 .25703 .71698 .26999 .72823 .2582 .72247 .24495 Metetra
.299 .645 0 r
.72247 .24495 .72823 .2582 .73942 .24574 .73367 .2322 Metetra
.197 .613 0 r
.73367 .2322 .73942 .24574 .75055 .23258 .7448 .21874 Metetra
.097 .577 0 r
.7448 .21874 .75055 .23258 .76159 .2187 .75585 .20456 Metetra
.034 .553 0 r
.09184 .42299 .09783 .43571 .10586 .44204 .09981 .42956 Metetra
.129 .589 0 r
.09981 .42956 .10586 .44204 .11407 .4477 .10796 .43546 Metetra
.227 .623 0 r
.10796 .43546 .11407 .4477 .12243 .45272 .11627 .44072 Metetra
.327 .654 0 r
.11627 .44072 .12243 .45272 .13094 .45712 .12474 .44535 Metetra
.426 .683 0 r
.12474 .44535 .13094 .45712 .1396 .46094 .13336 .44938 Metetra
.523 .709 0 r
.13336 .44938 .1396 .46094 .1484 .4642 .14212 .45286 Metetra
.618 .733 0 r
.14212 .45286 .1484 .4642 .15733 .46693 .15101 .4558 Metetra
.709 .755 0 r
.15101 .4558 .15733 .46693 .16637 .46916 .16003 .45824 Metetra
.775 .755 0 r
.16003 .45824 .16637 .46916 .17554 .47093 .16917 .46019 Metetra
.794 .709 0 r
.16917 .46019 .17554 .47093 .18482 .47225 .17842 .4617 Metetra
.811 .665 0 r
.17842 .4617 .18482 .47225 .1942 .47315 .18778 .46278 Metetra
.826 .623 0 r
.18778 .46278 .1942 .47315 .20368 .47367 .19724 .46346 Metetra
.84 .583 0 r
.19724 .46346 .20368 .47367 .21325 .47381 .2068 .46377 Metetra
.852 .545 0 r
.2068 .46377 .21325 .47381 .22291 .47362 .21644 .46372 Metetra
.864 .51 0 r
.21644 .46372 .22291 .47362 .23265 .47311 .22618 .46335 Metetra
.874 .477 0 r
.22618 .46335 .23265 .47311 .24248 .4723 .236 .46267 Metetra
.883 .448 0 r
.236 .46267 .24248 .4723 .25238 .47121 .24589 .46171 Metetra
.891 .42 0 r
.24589 .46171 .25238 .47121 .26235 .46987 .25586 .46048 Metetra
.898 .395 0 r
.25586 .46048 .26235 .46987 .27239 .46829 .2659 .45901 Metetra
.905 .373 0 r
.2659 .45901 .27239 .46829 .2825 .46649 .27601 .4573 Metetra
.911 .353 0 r
.27601 .4573 .2825 .46649 .29267 .46449 .28619 .45538 Metetra
.916 .335 0 r
.28619 .45538 .29267 .46449 .3029 .4623 .29642 .45326 Metetra
.92 .319 0 r
.29642 .45326 .3029 .4623 .31319 .45993 .30672 .45096 Metetra
.924 .305 0 r
.30672 .45096 .31319 .45993 .32354 .4574 .31708 .44848 Metetra
.927 .294 0 r
.31708 .44848 .32354 .4574 .33394 .45471 .32749 .44584 Metetra
.93 .284 0 r
.32749 .44584 .33394 .45471 .34439 .45188 .33796 .44304 Metetra
.932 .275 0 r
.33796 .44304 .34439 .45188 .3549 .44892 .34848 .4401 Metetra
.934 .268 0 r
.34848 .4401 .3549 .44892 .36546 .44583 .35905 .43702 Metetra
.935 .263 0 r
.35905 .43702 .36546 .44583 .37607 .44261 .36968 .43381 Metetra
.936 .26 0 r
.36968 .43381 .37607 .44261 .38672 .43928 .38035 .43047 Metetra
.937 .258 0 r
.38035 .43047 .38672 .43928 .39742 .43583 .39107 .427 Metetra
.937 .257 0 r
.39107 .427 .39742 .43583 .40818 .43226 .40184 .42341 Metetra
.937 .258 0 r
.40184 .42341 .40818 .43226 .41897 .42858 .41266 .41969 Metetra
.936 .26 0 r
.41266 .41969 .41897 .42858 .42982 .42478 .42353 .41584 Metetra
.935 .263 0 r
.42353 .41584 .42982 .42478 .4407 .42086 .43444 .41186 Metetra
.934 .268 0 r
.43444 .41186 .4407 .42086 .45164 .41682 .44539 .40774 Metetra
.932 .275 0 r
.44539 .40774 .45164 .41682 .46261 .41264 .45639 .40348 Metetra
.93 .284 0 r
.45639 .40348 .46261 .41264 .47363 .40832 .46743 .39907 Metetra
.927 .294 0 r
.46743 .39907 .47363 .40832 .48469 .40385 .47852 .39451 Metetra
.924 .305 0 r
.47852 .39451 .48469 .40385 .49579 .39923 .48964 .38977 Metetra
.92 .319 0 r
.48964 .38977 .49579 .39923 .50694 .39443 .5008 .38485 Metetra
.916 .335 0 r
.5008 .38485 .50694 .39443 .51811 .38945 .51201 .37974 Metetra
.911 .353 0 r
.51201 .37974 .51811 .38945 .52933 .38427 .52324 .37441 Metetra
.905 .373 0 r
.52324 .37441 .52933 .38427 .54058 .37888 .53452 .36887 Metetra
.898 .395 0 r
.53452 .36887 .54058 .37888 .55186 .37325 .54582 .36307 Metetra
.891 .42 0 r
.54582 .36307 .55186 .37325 .56318 .36737 .55716 .35702 Metetra
.883 .448 0 r
.55716 .35702 .56318 .36737 .57452 .36122 .56852 .35068 Metetra
.874 .477 0 r
.56852 .35068 .57452 .36122 .58588 .35477 .57991 .34404 Metetra
.864 .51 0 r
.57991 .34404 .58588 .35477 .59727 .34801 .59131 .33707 Metetra
.852 .545 0 r
.59131 .33707 .59727 .34801 .60868 .3409 .60274 .32975 Metetra
.84 .583 0 r
.60274 .32975 .60868 .3409 .62009 .33343 .61417 .32205 Metetra
.826 .623 0 r
.61417 .32205 .62009 .33343 .63152 .32556 .62561 .31395 Metetra
.811 .665 0 r
.62561 .31395 .63152 .32556 .64295 .31727 .63706 .30542 Metetra
.794 .709 0 r
.63706 .30542 .64295 .31727 .65437 .30853 .6485 .29643 Metetra
.775 .755 0 r
.6485 .29643 .65437 .30853 .66579 .29932 .65993 .28695 Metetra
.709 .755 0 r
.65993 .28695 .66579 .29932 .67719 .28959 .67134 .27695 Metetra
.618 .733 0 r
.67134 .27695 .67719 .28959 .68856 .27932 .68273 .2664 Metetra
.523 .709 0 r
.68273 .2664 .68856 .27932 .69991 .26848 .69408 .25528 Metetra
.426 .683 0 r
.69408 .25528 .69991 .26848 .71122 .25703 .7054 .24354 Metetra
.327 .654 0 r
.7054 .24354 .71122 .25703 .72247 .24495 .71666 .23116 Metetra
.227 .623 0 r
.71666 .23116 .72247 .24495 .73367 .2322 .72787 .2181 Metetra
.129 .589 0 r
.72787 .2181 .73367 .2322 .7448 .21874 .739 .20434 Metetra
.034 .553 0 r
.739 .20434 .7448 .21874 .75585 .20456 .75005 .18984 Metetra
0 .526 .029 r
.0859 .40969 .09184 .42299 .09981 .42956 .09381 .41653 Metetra
.061 .563 0 r
.09381 .41653 .09981 .42956 .10796 .43546 .1019 .42268 Metetra
.155 .598 0 r
.1019 .42268 .10796 .43546 .11627 .44072 .11016 .42817 Metetra
.252 .631 0 r
.11016 .42817 .11627 .44072 .12474 .44535 .11858 .43304 Metetra
.348 .66 0 r
.11858 .43304 .12474 .44535 .13336 .44938 .12715 .43731 Metetra
.444 .688 0 r
.12715 .43731 .13336 .44938 .14212 .45286 .13587 .44101 Metetra
.538 .713 0 r
.13587 .44101 .14212 .45286 .15101 .4558 .14472 .44417 Metetra
.629 .736 0 r
.14472 .44417 .15101 .4558 .16003 .45824 .15371 .44681 Metetra
.717 .757 0 r
.15371 .44681 .16003 .45824 .16917 .46019 .16282 .44897 Metetra
.776 .753 0 r
.16282 .44897 .16917 .46019 .17842 .4617 .17204 .45067 Metetra
.794 .709 0 r
.17204 .45067 .17842 .4617 .18778 .46278 .18137 .45194 Metetra
.81 .667 0 r
.18137 .45194 .18778 .46278 .19724 .46346 .19081 .45279 Metetra
.825 .627 0 r
.19081 .45279 .19724 .46346 .2068 .46377 .20035 .45327 Metetra
.838 .589 0 r
.20035 .45327 .2068 .46377 .21644 .46372 .20998 .45338 Metetra
.85 .553 0 r
.20998 .45338 .21644 .46372 .22618 .46335 .21971 .45316 Metetra
.861 .52 0 r
.21971 .45316 .22618 .46335 .236 .46267 .22951 .45262 Metetra
.87 .489 0 r
.22951 .45262 .236 .46267 .24589 .46171 .2394 .45178 Metetra
.879 .461 0 r
.2394 .45178 .24589 .46171 .25586 .46048 .24937 .45067 Metetra
.887 .435 0 r
.24937 .45067 .25586 .46048 .2659 .45901 .25941 .44931 Metetra
.894 .412 0 r
.25941 .44931 .2659 .45901 .27601 .4573 .26952 .4477 Metetra
.9 .391 0 r
.26952 .4477 .27601 .4573 .28619 .45538 .27969 .44587 Metetra
.905 .372 0 r
.27969 .44587 .28619 .45538 .29642 .45326 .28994 .44382 Metetra
.91 .355 0 r
.28994 .44382 .29642 .45326 .30672 .45096 .30024 .44159 Metetra
.914 .341 0 r
.30024 .44159 .30672 .45096 .31708 .44848 .3106 .43916 Metetra
.917 .328 0 r
.3106 .43916 .31708 .44848 .32749 .44584 .32103 .43657 Metetra
.92 .318 0 r
.32103 .43657 .32749 .44584 .33796 .44304 .33151 .43381 Metetra
.923 .309 0 r
.33151 .43381 .33796 .44304 .34848 .4401 .34204 .4309 Metetra
.925 .301 0 r
.34204 .4309 .34848 .4401 .35905 .43702 .35263 .42783 Metetra
.926 .296 0 r
.35263 .42783 .35905 .43702 .36968 .43381 .36327 .42462 Metetra
.927 .292 0 r
.36327 .42462 .36968 .43381 .38035 .43047 .37396 .42127 Metetra
.928 .29 0 r
.37396 .42127 .38035 .43047 .39107 .427 .3847 .41779 Metetra
.928 .289 0 r
.3847 .41779 .39107 .427 .40184 .42341 .39549 .41416 Metetra
.928 .29 0 r
.39549 .41416 .40184 .42341 .41266 .41969 .40632 .4104 Metetra
.927 .292 0 r
.40632 .4104 .41266 .41969 .42353 .41584 .41721 .4065 Metetra
.926 .296 0 r
.41721 .4065 .42353 .41584 .43444 .41186 .42814 .40246 Metetra
.925 .301 0 r
.42814 .40246 .43444 .41186 .44539 .40774 .43912 .39827 Metetra
.923 .309 0 r
.43912 .39827 .44539 .40774 .45639 .40348 .45014 .39393 Metetra
.92 .318 0 r
.45014 .39393 .45639 .40348 .46743 .39907 .4612 .38943 Metetra
.917 .328 0 r
.4612 .38943 .46743 .39907 .47852 .39451 .47231 .38475 Metetra
.914 .341 0 r
.47231 .38475 .47852 .39451 .48964 .38977 .48345 .3799 Metetra
.91 .355 0 r
.48345 .3799 .48964 .38977 .5008 .38485 .49464 .37485 Metetra
.905 .372 0 r
.49464 .37485 .5008 .38485 .51201 .37974 .50586 .3696 Metetra
.9 .391 0 r
.50586 .3696 .51201 .37974 .52324 .37441 .51713 .36413 Metetra
.894 .412 0 r
.51713 .36413 .52324 .37441 .53452 .36887 .52842 .35842 Metetra
.887 .435 0 r
.52842 .35842 .53452 .36887 .54582 .36307 .53975 .35246 Metetra
.879 .461 0 r
.53975 .35246 .54582 .36307 .55716 .35702 .5511 .34622 Metetra
.87 .489 0 r
.5511 .34622 .55716 .35702 .56852 .35068 .56249 .33969 Metetra
.861 .52 0 r
.56249 .33969 .56852 .35068 .57991 .34404 .57389 .33284 Metetra
.85 .553 0 r
.57389 .33284 .57991 .34404 .59131 .33707 .58532 .32566 Metetra
.838 .589 0 r
.58532 .32566 .59131 .33707 .60274 .32975 .59676 .31812 Metetra
.825 .627 0 r
.59676 .31812 .60274 .32975 .61417 .32205 .60821 .31019 Metetra
.81 .667 0 r
.60821 .31019 .61417 .32205 .62561 .31395 .61967 .30184 Metetra
.794 .709 0 r
.61967 .30184 .62561 .31395 .63706 .30542 .63113 .29306 Metetra
.776 .753 0 r
.63113 .29306 .63706 .30542 .6485 .29643 .64258 .28381 Metetra
.717 .757 0 r
.64258 .28381 .6485 .29643 .65993 .28695 .65402 .27406 Metetra
.629 .736 0 r
.65402 .27406 .65993 .28695 .67134 .27695 .66545 .26378 Metetra
.538 .713 0 r
.66545 .26378 .67134 .27695 .68273 .2664 .67685 .25295 Metetra
.444 .688 0 r
.67685 .25295 .68273 .2664 .69408 .25528 .68821 .24153 Metetra
.348 .66 0 r
.68821 .24153 .69408 .25528 .7054 .24354 .69953 .22949 Metetra
.252 .631 0 r
.69953 .22949 .7054 .24354 .71666 .23116 .7108 .2168 Metetra
.155 .598 0 r
.7108 .2168 .71666 .23116 .72787 .2181 .722 .20343 Metetra
.061 .563 0 r
.722 .20343 .72787 .2181 .739 .20434 .73314 .18934 Metetra
0 .526 .029 r
.73314 .18934 .739 .20434 .75005 .18984 .74419 .17452 Metetra
0 .497 .089 r
.08003 .39581 .0859 .40969 .09381 .41653 .08787 .40291 Metetra
0 .536 .006 r
.08787 .40291 .09381 .41653 .1019 .42268 .0959 .40931 Metetra
.083 .572 0 r
.0959 .40931 .1019 .42268 .11016 .42817 .1041 .41506 Metetra
.175 .605 0 r
.1041 .41506 .11016 .42817 .11858 .43304 .11247 .42018 Metetra
.269 .636 0 r
.11247 .42018 .11858 .43304 .12715 .43731 .12099 .42469 Metetra
.363 .664 0 r
.12099 .42469 .12715 .43731 .13587 .44101 .12966 .42862 Metetra
.455 .691 0 r
.12966 .42862 .13587 .44101 .14472 .44417 .13847 .432 Metetra
.546 .715 0 r
.13847 .432 .14472 .44417 .15371 .44681 .14742 .43487 Metetra
.633 .737 0 r
.14742 .43487 .15371 .44681 .16282 .44897 .15649 .43723 Metetra
.717 .757 0 r
.15649 .43723 .16282 .44897 .17204 .45067 .16568 .43914 Metetra
.775 .755 0 r
.16568 .43914 .17204 .45067 .18137 .45194 .17499 .44059 Metetra
.792 .713 0 r
.17499 .44059 .18137 .45194 .19081 .45279 .18441 .44163 Metetra
.808 .673 0 r
.18441 .44163 .19081 .45279 .20035 .45327 .19392 .44228 Metetra
.822 .635 0 r
.19392 .44228 .20035 .45327 .20998 .45338 .20354 .44256 Metetra
.834 .599 0 r
.20354 .44256 .20998 .45338 .21971 .45316 .21325 .44249 Metetra
.846 .565 0 r
.21325 .44249 .21971 .45316 .22951 .45262 .22304 .44209 Metetra
.856 .534 0 r
.22304 .44209 .22951 .45262 .2394 .45178 .23292 .44139 Metetra
.865 .505 0 r
.23292 .44139 .2394 .45178 .24937 .45067 .24288 .44041 Metetra
.874 .478 0 r
.24288 .44041 .24937 .45067 .25941 .44931 .25291 .43915 Metetra
.881 .454 0 r
.25291 .43915 .25941 .44931 .26952 .4477 .26302 .43765 Metetra
.888 .432 0 r
.26302 .43765 .26952 .4477 .27969 .44587 .2732 .43591 Metetra
.893 .413 0 r
.2732 .43591 .27969 .44587 .28994 .44382 .28344 .43395 Metetra
.898 .395 0 r
.28344 .43395 .28994 .44382 .30024 .44159 .29375 .43178 Metetra
.903 .38 0 r
.29375 .43178 .30024 .44159 .3106 .43916 .30412 .42942 Metetra
.907 .367 0 r
.30412 .42942 .3106 .43916 .32103 .43657 .31455 .42687 Metetra
.91 .355 0 r
.31455 .42687 .32103 .43657 .33151 .43381 .32504 .42415 Metetra
.913 .346 0 r
.32504 .42415 .33151 .43381 .34204 .4309 .33559 .42126 Metetra
.915 .338 0 r
.33559 .42126 .34204 .4309 .35263 .42783 .34619 .41821 Metetra
.916 .332 0 r
.34619 .41821 .35263 .42783 .36327 .42462 .35684 .41501 Metetra
.917 .328 0 r
.35684 .41501 .36327 .42462 .37396 .42127 .36755 .41165 Metetra
.918 .326 0 r
.36755 .41165 .37396 .42127 .3847 .41779 .3783 .40815 Metetra
.918 .325 0 r
.3783 .40815 .3847 .41779 .39549 .41416 .38911 .4045 Metetra
.918 .326 0 r
.38911 .4045 .39549 .41416 .40632 .4104 .39996 .40069 Metetra
.917 .328 0 r
.39996 .40069 .40632 .4104 .41721 .4065 .41087 .39674 Metetra
.916 .332 0 r
.41087 .39674 .41721 .4065 .42814 .40246 .42182 .39264 Metetra
.915 .338 0 r
.42182 .39264 .42814 .40246 .43912 .39827 .43282 .38837 Metetra
.913 .346 0 r
.43282 .38837 .43912 .39827 .45014 .39393 .44386 .38394 Metetra
.91 .355 0 r
.44386 .38394 .45014 .39393 .4612 .38943 .45494 .37934 Metetra
.907 .367 0 r
.45494 .37934 .4612 .38943 .47231 .38475 .46607 .37456 Metetra
.903 .38 0 r
.46607 .37456 .47231 .38475 .48345 .3799 .47724 .36958 Metetra
.898 .395 0 r
.47724 .36958 .48345 .3799 .49464 .37485 .48845 .36441 Metetra
.893 .413 0 r
.48845 .36441 .49464 .37485 .50586 .3696 .49969 .35901 Metetra
.888 .432 0 r
.49969 .35901 .50586 .3696 .51713 .36413 .51097 .35338 Metetra
.881 .454 0 r
.51097 .35338 .51713 .36413 .52842 .35842 .52229 .34751 Metetra
.874 .478 0 r
.52229 .34751 .52842 .35842 .53975 .35246 .53364 .34137 Metetra
.865 .505 0 r
.53364 .34137 .53975 .35246 .5511 .34622 .54501 .33494 Metetra
.856 .534 0 r
.54501 .33494 .5511 .34622 .56249 .33969 .55641 .32821 Metetra
.846 .565 0 r
.55641 .32821 .56249 .33969 .57389 .33284 .56784 .32116 Metetra
.834 .599 0 r
.56784 .32116 .57389 .33284 .58532 .32566 .57928 .31375 Metetra
.822 .635 0 r
.57928 .31375 .58532 .32566 .59676 .31812 .59074 .30598 Metetra
.808 .673 0 r
.59074 .30598 .59676 .31812 .60821 .31019 .60221 .29781 Metetra
.792 .713 0 r
.60221 .29781 .60821 .31019 .61967 .30184 .61368 .28921 Metetra
.775 .755 0 r
.61368 .28921 .61967 .30184 .63113 .29306 .62515 .28016 Metetra
.717 .757 0 r
.62515 .28016 .63113 .29306 .64258 .28381 .63662 .27064 Metetra
.633 .737 0 r
.63662 .27064 .64258 .28381 .65402 .27406 .64807 .26061 Metetra
.546 .715 0 r
.64807 .26061 .65402 .27406 .66545 .26378 .65951 .25005 Metetra
.455 .691 0 r
.65951 .25005 .66545 .26378 .67685 .25295 .67091 .23892 Metetra
.363 .664 0 r
.67091 .23892 .67685 .25295 .68821 .24153 .68228 .22719 Metetra
.269 .636 0 r
.68228 .22719 .68821 .24153 .69953 .22949 .69361 .21484 Metetra
.175 .605 0 r
.69361 .21484 .69953 .22949 .7108 .2168 .70488 .20183 Metetra
.083 .572 0 r
.70488 .20183 .7108 .2168 .722 .20343 .71609 .18814 Metetra
0 .536 .006 r
.71609 .18814 .722 .20343 .73314 .18934 .72722 .17373 Metetra
0 .497 .089 r
.72722 .17373 .73314 .18934 .74419 .17452 .73827 .15857 Metetra
0 .466 .146 r
.07422 .38131 .08003 .39581 .08787 .40291 .082 .38868 Metetra
0 .506 .071 r
.082 .38868 .08787 .40291 .0959 .40931 .08996 .39535 Metetra
.012 .543 0 r
.08996 .39535 .0959 .40931 .1041 .41506 .0981 .40136 Metetra
.099 .578 0 r
.0981 .40136 .1041 .41506 .11247 .42018 .10641 .40673 Metetra
.189 .61 0 r
.10641 .40673 .11247 .42018 .12099 .42469 .11488 .41148 Metetra
.28 .639 0 r
.11488 .41148 .12099 .42469 .12966 .42862 .1235 .41566 Metetra
.37 .667 0 r
.1235 .41566 .12966 .42862 .13847 .432 .13227 .41928 Metetra
.459 .692 0 r
.13227 .41928 .13847 .432 .14742 .43487 .14117 .42237 Metetra
.546 .715 0 r
.14117 .42237 .14742 .43487 .15649 .43723 .1502 .42495 Metetra
.629 .736 0 r
.1502 .42495 .15649 .43723 .16568 .43914 .15936 .42706 Metetra
.709 .755 0 r
.15936 .42706 .16568 .43914 .17499 .44059 .16864 .42872 Metetra
.773 .761 0 r
.16864 .42872 .17499 .44059 .18441 .44163 .17802 .42995 Metetra
.789 .721 0 r
.17802 .42995 .18441 .44163 .19392 .44228 .18752 .43078 Metetra
.804 .683 0 r
.18752 .43078 .19392 .44228 .20354 .44256 .19711 .43122 Metetra
.817 .647 0 r
.19711 .43122 .20354 .44256 .21325 .44249 .2068 .43132 Metetra
.829 .613 0 r
.2068 .43132 .21325 .44249 .22304 .44209 .21658 .43107 Metetra
.84 .582 0 r
.21658 .43107 .22304 .44209 .23292 .44139 .22645 .43051 Metetra
.85 .552 0 r
.22645 .43051 .23292 .44139 .24288 .44041 .23639 .42965 Metetra
.859 .525 0 r
.23639 .42965 .24288 .44041 .25291 .43915 .24642 .42852 Metetra
.867 .5 0 r
.24642 .42852 .25291 .43915 .26302 .43765 .25652 .42712 Metetra
.874 .477 0 r
.25652 .42712 .26302 .43765 .2732 .43591 .2667 .42548 Metetra
.88 .457 0 r
.2667 .42548 .2732 .43591 .28344 .43395 .27694 .4236 Metetra
.886 .439 0 r
.27694 .4236 .28344 .43395 .29375 .43178 .28726 .42151 Metetra
.89 .423 0 r
.28726 .42151 .29375 .43178 .30412 .42942 .29763 .41921 Metetra
.894 .409 0 r
.29763 .41921 .30412 .42942 .31455 .42687 .30807 .41671 Metetra
.898 .397 0 r
.30807 .41671 .31455 .42687 .32504 .42415 .31856 .41403 Metetra
.901 .387 0 r
.31856 .41403 .32504 .42415 .33559 .42126 .32912 .41117 Metetra
.903 .379 0 r
.32912 .41117 .33559 .42126 .34619 .41821 .33973 .40814 Metetra
.905 .373 0 r
.33973 .40814 .34619 .41821 .35684 .41501 .3504 .40494 Metetra
.906 .368 0 r
.3504 .40494 .35684 .41501 .36755 .41165 .36112 .40158 Metetra
.907 .366 0 r
.36112 .40158 .36755 .41165 .3783 .40815 .37189 .39805 Metetra
.907 .365 0 r
.37189 .39805 .3783 .40815 .38911 .4045 .38271 .39437 Metetra
.907 .366 0 r
.38271 .39437 .38911 .4045 .39996 .40069 .39359 .39053 Metetra
.906 .368 0 r
.39359 .39053 .39996 .40069 .41087 .39674 .40451 .38652 Metetra
.905 .373 0 r
.40451 .38652 .41087 .39674 .42182 .39264 .41548 .38235 Metetra
.903 .379 0 r
.41548 .38235 .42182 .39264 .43282 .38837 .42649 .37801 Metetra
.901 .387 0 r
.42649 .37801 .43282 .38837 .44386 .38394 .43755 .37349 Metetra
.898 .397 0 r
.43755 .37349 .44386 .38394 .45494 .37934 .44866 .36879 Metetra
.894 .409 0 r
.44866 .36879 .45494 .37934 .46607 .37456 .45981 .36389 Metetra
.89 .423 0 r
.45981 .36389 .46607 .37456 .47724 .36958 .47099 .35879 Metetra
.886 .439 0 r
.47099 .35879 .47724 .36958 .48845 .36441 .48222 .35348 Metetra
.88 .457 0 r
.48222 .35348 .48845 .36441 .49969 .35901 .49349 .34793 Metetra
.874 .477 0 r
.49349 .34793 .49969 .35901 .51097 .35338 .50479 .34214 Metetra
.867 .5 0 r
.50479 .34214 .51097 .35338 .52229 .34751 .51613 .3361 Metetra
.859 .525 0 r
.51613 .3361 .52229 .34751 .53364 .34137 .52749 .32977 Metetra
.85 .552 0 r
.52749 .32977 .53364 .34137 .54501 .33494 .53889 .32315 Metetra
.84 .582 0 r
.53889 .32315 .54501 .33494 .55641 .32821 .55031 .31622 Metetra
.829 .613 0 r
.55031 .31622 .55641 .32821 .56784 .32116 .56175 .30895 Metetra
.817 .647 0 r
.56175 .30895 .56784 .32116 .57928 .31375 .57321 .30131 Metetra
.804 .683 0 r
.57321 .30131 .57928 .31375 .59074 .30598 .58469 .2933 Metetra
.789 .721 0 r
.58469 .2933 .59074 .30598 .60221 .29781 .59617 .28488 Metetra
.773 .761 0 r
.59617 .28488 .60221 .29781 .61368 .28921 .60766 .27602 Metetra
.709 .755 0 r
.60766 .27602 .61368 .28921 .62515 .28016 .61914 .26671 Metetra
.629 .736 0 r
.61914 .26671 .62515 .28016 .63662 .27064 .63062 .2569 Metetra
.546 .715 0 r
.63062 .2569 .63662 .27064 .64807 .26061 .64208 .24658 Metetra
.459 .692 0 r
.64208 .24658 .64807 .26061 .65951 .25005 .65352 .23572 Metetra
.37 .667 0 r
.65352 .23572 .65951 .25005 .67091 .23892 .66494 .22429 Metetra
.28 .639 0 r
.66494 .22429 .67091 .23892 .68228 .22719 .67631 .21225 Metetra
.189 .61 0 r
.67631 .21225 .68228 .22719 .69361 .21484 .68764 .19958 Metetra
.099 .578 0 r
.68764 .19958 .69361 .21484 .70488 .20183 .69891 .18624 Metetra
.012 .543 0 r
.69891 .18624 .70488 .20183 .71609 .18814 .71012 .17222 Metetra
0 .506 .071 r
.71012 .17222 .71609 .18814 .72722 .17373 .72125 .15747 Metetra
0 .466 .146 r
.72125 .15747 .72722 .17373 .73827 .15857 .7323 .14197 Metetra
0 .433 .199 r
.0685 .36617 .07422 .38131 .082 .38868 .0762 .37381 Metetra
0 .474 .132 r
.0762 .37381 .082 .38868 .08996 .39535 .0841 .38076 Metetra
0 .513 .058 r
.0841 .38076 .08996 .39535 .0981 .40136 .09217 .38703 Metetra
.023 .548 0 r
.09217 .38703 .0981 .40136 .10641 .40673 .10042 .39266 Metetra
.108 .581 0 r
.10042 .39266 .10641 .40673 .11488 .41148 .10883 .39768 Metetra
.195 .612 0 r
.10883 .39768 .11488 .41148 .1235 .41566 .11739 .4021 Metetra
.283 .64 0 r
.11739 .4021 .1235 .41566 .13227 .41928 .12611 .40596 Metetra
.37 .667 0 r
.12611 .40596 .13227 .41928 .14117 .42237 .13497 .40928 Metetra
.456 .691 0 r
.13497 .40928 .14117 .42237 .1502 .42495 .14396 .41209 Metetra
.538 .713 0 r
.14396 .41209 .1502 .42495 .15936 .42706 .15308 .41441 Metetra
.618 .733 0 r
.15308 .41441 .15936 .42706 .16864 .42872 .16232 .41628 Metetra
.695 .752 0 r
.16232 .41628 .16864 .42872 .17802 .42995 .17167 .41771 Metetra
.767 .769 0 r
.17167 .41771 .17802 .42995 .18752 .43078 .18114 .41872 Metetra
.784 .733 0 r
.18114 .41872 .18752 .43078 .19711 .43122 .19071 .41935 Metetra
.798 .698 0 r
.19071 .41935 .19711 .43122 .2068 .43132 .20037 .4196 Metetra
.811 .664 0 r
.20037 .4196 .2068 .43132 .21658 .43107 .21014 .41952 Metetra
.823 .632 0 r
.21014 .41952 .21658 .43107 .22645 .43051 .21999 .4191 Metetra
.833 .602 0 r
.21999 .4191 .22645 .43051 .23639 .42965 .22992 .41838 Metetra
.843 .574 0 r
.22992 .41838 .23639 .42965 .24642 .42852 .23994 .41737 Metetra
.851 .549 0 r
.23994 .41737 .24642 .42852 .25652 .42712 .25004 .41608 Metetra
.859 .526 0 r
.25004 .41608 .25652 .42712 .2667 .42548 .26021 .41454 Metetra
.865 .505 0 r
.26021 .41454 .2667 .42548 .27694 .4236 .27045 .41275 Metetra
.871 .486 0 r
.27045 .41275 .27694 .4236 .28726 .42151 .28076 .41074 Metetra
.876 .47 0 r
.28076 .41074 .28726 .42151 .29763 .41921 .29114 .4085 Metetra
.881 .455 0 r
.29114 .4085 .29763 .41921 .30807 .41671 .30158 .40606 Metetra
.885 .443 0 r
.30158 .40606 .30807 .41671 .31856 .41403 .31208 .40342 Metetra
.888 .432 0 r
.31208 .40342 .31856 .41403 .32912 .41117 .32265 .40059 Metetra
.89 .424 0 r
.32265 .40059 .32912 .41117 .33973 .40814 .33327 .39757 Metetra
.892 .417 0 r
.33327 .39757 .33973 .40814 .3504 .40494 .34395 .39438 Metetra
.893 .413 0 r
.34395 .39438 .3504 .40494 .36112 .40158 .35468 .39101 Metetra
.894 .41 0 r
.35468 .39101 .36112 .40158 .37189 .39805 .36546 .38747 Metetra
.894 .409 0 r
.36546 .38747 .37189 .39805 .38271 .39437 .3763 .38375 Metetra
.894 .41 0 r
.3763 .38375 .38271 .39437 .39359 .39053 .38719 .37987 Metetra
.893 .413 0 r
.38719 .37987 .39359 .39053 .40451 .38652 .39813 .37581 Metetra
.892 .417 0 r
.39813 .37581 .40451 .38652 .41548 .38235 .40911 .37157 Metetra
.89 .424 0 r
.40911 .37157 .41548 .38235 .42649 .37801 .42015 .36714 Metetra
.888 .432 0 r
.42015 .36714 .42649 .37801 .43755 .37349 .43123 .36253 Metetra
.885 .443 0 r
.43123 .36253 .43755 .37349 .44866 .36879 .44235 .35773 Metetra
.881 .455 0 r
.44235 .35773 .44866 .36879 .45981 .36389 .45352 .35271 Metetra
.876 .47 0 r
.45352 .35271 .45981 .36389 .47099 .35879 .46473 .34749 Metetra
.871 .486 0 r
.46473 .34749 .47099 .35879 .48222 .35348 .47598 .34203 Metetra
.865 .505 0 r
.47598 .34203 .48222 .35348 .49349 .34793 .48726 .33633 Metetra
.859 .526 0 r
.48726 .33633 .49349 .34793 .50479 .34214 .49858 .33038 Metetra
.851 .549 0 r
.49858 .33038 .50479 .34214 .51613 .3361 .50994 .32415 Metetra
.843 .574 0 r
.50994 .32415 .51613 .3361 .52749 .32977 .52132 .31764 Metetra
.833 .602 0 r
.52132 .31764 .52749 .32977 .53889 .32315 .53274 .31082 Metetra
.823 .632 0 r
.53274 .31082 .53889 .32315 .55031 .31622 .54417 .30367 Metetra
.811 .664 0 r
.54417 .30367 .55031 .31622 .56175 .30895 .55563 .29617 Metetra
.798 .698 0 r
.55563 .29617 .56175 .30895 .57321 .30131 .56711 .28831 Metetra
.784 .733 0 r
.56711 .28831 .57321 .30131 .58469 .2933 .5786 .28004 Metetra
.767 .769 0 r
.5786 .28004 .58469 .2933 .59617 .28488 .59009 .27136 Metetra
.695 .752 0 r
.59009 .27136 .59617 .28488 .60766 .27602 .60159 .26224 Metetra
.618 .733 0 r
.60159 .26224 .60766 .27602 .61914 .26671 .61309 .25265 Metetra
.538 .713 0 r
.61309 .25265 .61914 .26671 .63062 .2569 .62458 .24256 Metetra
.456 .691 0 r
.62458 .24256 .63062 .2569 .64208 .24658 .63605 .23194 Metetra
.37 .667 0 r
.63605 .23194 .64208 .24658 .65352 .23572 .6475 .22077 Metetra
.283 .64 0 r
.6475 .22077 .65352 .23572 .66494 .22429 .65892 .20903 Metetra
.195 .612 0 r
.65892 .20903 .66494 .22429 .67631 .21225 .67029 .19667 Metetra
.108 .581 0 r
.67029 .19667 .67631 .21225 .68764 .19958 .68163 .18367 Metetra
.023 .548 0 r
.68163 .18367 .68764 .19958 .69891 .18624 .6929 .17 Metetra
0 .513 .058 r
.6929 .17 .69891 .18624 .71012 .17222 .7041 .15563 Metetra
0 .474 .132 r
.7041 .15563 .71012 .17222 .72125 .15747 .71523 .14054 Metetra
0 .433 .199 r
.71523 .14054 .72125 .15747 .7323 .14197 .72627 .12469 Metetra
0 .397 .244 r
.06287 .35036 .0685 .36617 .0762 .37381 .07049 .35828 Metetra
0 .439 .189 r
.07049 .35828 .0762 .37381 .0841 .38076 .07831 .36551 Metetra
0 .479 .123 r
.07831 .36551 .0841 .38076 .09217 .38703 .08631 .37206 Metetra
0 .516 .049 r
.08631 .37206 .09217 .38703 .10042 .39266 .09449 .37796 Metetra
.029 .551 0 r
.09449 .37796 .10042 .39266 .10883 .39768 .10284 .38323 Metetra
.112 .583 0 r
.10284 .38323 .10883 .39768 .11739 .4021 .11135 .38791 Metetra
.196 .612 0 r
.11135 .38791 .11739 .4021 .12611 .40596 .12001 .39202 Metetra
.28 .639 0 r
.12001 .39202 .12611 .40596 .13497 .40928 .12882 .39558 Metetra
.363 .665 0 r
.12882 .39558 .13497 .40928 .14396 .41209 .13776 .39862 Metetra
.445 .688 0 r
.13776 .39862 .14396 .41209 .15308 .41441 .14684 .40117 Metetra
.524 .709 0 r
.14684 .40117 .15308 .41441 .16232 .41628 .15604 .40324 Metetra
.6 .728 0 r
.15604 .40324 .16232 .41628 .17167 .41771 .16536 .40487 Metetra
.672 .746 0 r
.16536 .40487 .17167 .41771 .18114 .41872 .17479 .40608 Metetra
.741 .763 0 r
.17479 .40608 .18114 .41872 .19071 .41935 .18433 .40689 Metetra
.778 .749 0 r
.18433 .40689 .19071 .41935 .20037 .4196 .19398 .40732 Metetra
.791 .716 0 r
.19398 .40732 .20037 .4196 .21014 .41952 .20372 .40739 Metetra
.803 .684 0 r
.20372 .40739 .21014 .41952 .21999 .4191 .21355 .40713 Metetra
.815 .654 0 r
.21355 .40713 .21999 .4191 .22992 .41838 .22347 .40655 Metetra
.825 .627 0 r
.22347 .40655 .22992 .41838 .23994 .41737 .23348 .40566 Metetra
.834 .601 0 r
.23348 .40566 .23994 .41737 .25004 .41608 .24357 .40449 Metetra
.842 .577 0 r
.24357 .40449 .25004 .41608 .26021 .41454 .25373 .40305 Metetra
.849 .556 0 r
.25373 .40305 .26021 .41454 .27045 .41275 .26397 .40136 Metetra
.855 .537 0 r
.26397 .40136 .27045 .41275 .28076 .41074 .27428 .39942 Metetra
.861 .52 0 r
.27428 .39942 .28076 .41074 .29114 .4085 .28465 .39726 Metetra
.865 .505 0 r
.28465 .39726 .29114 .4085 .30158 .40606 .2951 .39487 Metetra
.869 .492 0 r
.2951 .39487 .30158 .40606 .31208 .40342 .3056 .39228 Metetra
.873 .481 0 r
.3056 .39228 .31208 .40342 .32265 .40059 .31617 .38948 Metetra
.875 .472 0 r
.31617 .38948 .32265 .40059 .33327 .39757 .3268 .38648 Metetra
.878 .466 0 r
.3268 .38648 .33327 .39757 .34395 .39438 .33749 .38329 Metetra
.879 .461 0 r
.33749 .38329 .34395 .39438 .35468 .39101 .34823 .37992 Metetra
.88 .458 0 r
.34823 .37992 .35468 .39101 .36546 .38747 .35903 .37636 Metetra
.88 .457 0 r
.35903 .37636 .36546 .38747 .3763 .38375 .36988 .37261 Metetra
.88 .458 0 r
.36988 .37261 .3763 .38375 .38719 .37987 .38078 .36868 Metetra
.879 .461 0 r
.38078 .36868 .38719 .37987 .39813 .37581 .39174 .36456 Metetra
.878 .466 0 r
.39174 .36456 .39813 .37581 .40911 .37157 .40274 .36025 Metetra
.875 .472 0 r
.40274 .36025 .40911 .37157 .42015 .36714 .41379 .35575 Metetra
.873 .481 0 r
.41379 .35575 .42015 .36714 .43123 .36253 .42489 .35104 Metetra
.869 .492 0 r
.42489 .35104 .43123 .36253 .44235 .35773 .43603 .34613 Metetra
.865 .505 0 r
.43603 .34613 .44235 .35773 .45352 .35271 .44721 .34099 Metetra
.861 .52 0 r
.44721 .34099 .45352 .35271 .46473 .34749 .45844 .33563 Metetra
.855 .537 0 r
.45844 .33563 .46473 .34749 .47598 .34203 .46971 .33003 Metetra
.849 .556 0 r
.46971 .33003 .47598 .34203 .48726 .33633 .48101 .32417 Metetra
.842 .577 0 r
.48101 .32417 .48726 .33633 .49858 .33038 .49235 .31805 Metetra
.834 .601 0 r
.49235 .31805 .49858 .33038 .50994 .32415 .50372 .31164 Metetra
.825 .627 0 r
.50372 .31164 .50994 .32415 .52132 .31764 .51513 .30493 Metetra
.815 .654 0 r
.51513 .30493 .52132 .31764 .53274 .31082 .52656 .2979 Metetra
.803 .684 0 r
.52656 .2979 .53274 .31082 .54417 .30367 .53801 .29053 Metetra
.791 .716 0 r
.53801 .29053 .54417 .30367 .55563 .29617 .54948 .28281 Metetra
.778 .749 0 r
.54948 .28281 .55563 .29617 .56711 .28831 .56097 .2747 Metetra
.741 .763 0 r
.56097 .2747 .56711 .28831 .5786 .28004 .57248 .26618 Metetra
.672 .746 0 r
.57248 .26618 .5786 .28004 .59009 .27136 .58399 .25724 Metetra
.6 .728 0 r
.58399 .25724 .59009 .27136 .60159 .26224 .5955 .24784 Metetra
.524 .709 0 r
.5955 .24784 .60159 .26224 .61309 .25265 .607 .23796 Metetra
.445 .688 0 r
.607 .23796 .61309 .25265 .62458 .24256 .6185 .22757 Metetra
.363 .665 0 r
.6185 .22757 .62458 .24256 .63605 .23194 .62998 .21665 Metetra
.28 .639 0 r
.62998 .21665 .63605 .23194 .6475 .22077 .64143 .20517 Metetra
.196 .612 0 r
.64143 .20517 .6475 .22077 .65892 .20903 .65285 .1931 Metetra
.112 .583 0 r
.65285 .1931 .65892 .20903 .67029 .19667 .66423 .18041 Metetra
.029 .551 0 r
.66423 .18041 .67029 .19667 .68163 .18367 .67556 .16708 Metetra
0 .516 .049 r
.67556 .16708 .68163 .18367 .6929 .17 .68683 .15307 Metetra
0 .479 .123 r
.68683 .15307 .6929 .17 .7041 .15563 .69804 .13836 Metetra
0 .439 .189 r
.69804 .13836 .7041 .15563 .71523 .14054 .70916 .12291 Metetra
0 .397 .244 r
.70916 .12291 .71523 .14054 .72627 .12469 .72019 .10671 Metetra
0 .358 .28 r
.05733 .33385 .06287 .35036 .07049 .35828 .06487 .34206 Metetra
0 .402 .237 r
.06487 .34206 .07049 .35828 .07831 .36551 .07261 .34958 Metetra
0 .444 .182 r
.07261 .34958 .07831 .36551 .08631 .37206 .08054 .3564 Metetra
0 .482 .118 r
.08054 .3564 .08631 .37206 .09449 .37796 .08865 .36258 Metetra
0 .518 .047 r
.08865 .36258 .09449 .37796 .10284 .38323 .09693 .36812 Metetra
.03 .551 0 r
.09693 .36812 .10284 .38323 .11135 .38791 .10537 .37306 Metetra
.109 .582 0 r
.10537 .37306 .11135 .38791 .12001 .39202 .11398 .37742 Metetra
.189 .61 0 r
.11398 .37742 .12001 .39202 .12882 .39558 .12273 .38123 Metetra
.269 .636 0 r
.12273 .38123 .12882 .39558 .13776 .39862 .13162 .38451 Metetra
.349 .66 0 r
.13162 .38451 .13776 .39862 .14684 .40117 .14065 .38728 Metetra
.426 .683 0 r
.14065 .38728 .14684 .40117 .15604 .40324 .14981 .38958 Metetra
.502 .703 0 r
.14981 .38958 .15604 .40324 .16536 .40487 .15909 .39142 Metetra
.574 .722 0 r
.15909 .39142 .16536 .40487 .17479 .40608 .16849 .39283 Metetra
.643 .739 0 r
.16849 .39283 .17479 .40608 .18433 .40689 .178 .39382 Metetra
.708 .755 0 r
.178 .39382 .18433 .40689 .19398 .40732 .18762 .39443 Metetra
.769 .769 0 r
.18762 .39443 .19398 .40732 .20372 .40739 .19733 .39467 Metetra
.782 .738 0 r
.19733 .39467 .20372 .40739 .21355 .40713 .20715 .39456 Metetra
.794 .709 0 r
.20715 .39456 .21355 .40713 .22347 .40655 .21705 .39412 Metetra
.805 .681 0 r
.21705 .39412 .22347 .40655 .23348 .40566 .22704 .39337 Metetra
.814 .655 0 r
.22704 .39337 .23348 .40566 .24357 .40449 .23711 .39232 Metetra
.823 .632 0 r
.23711 .39232 .24357 .40449 .25373 .40305 .24727 .39099 Metetra
.83 .61 0 r
.24727 .39099 .25373 .40305 .26397 .40136 .2575 .38939 Metetra
.837 .591 0 r
.2575 .38939 .26397 .40136 .27428 .39942 .2678 .38754 Metetra
.843 .573 0 r
.2678 .38754 .27428 .39942 .28465 .39726 .27818 .38544 Metetra
.848 .558 0 r
.27818 .38544 .28465 .39726 .2951 .39487 .28862 .38312 Metetra
.853 .545 0 r
.28862 .38312 .2951 .39487 .3056 .39228 .29913 .38056 Metetra
.856 .534 0 r
.29913 .38056 .3056 .39228 .31617 .38948 .3097 .3778 Metetra
.859 .525 0 r
.3097 .3778 .31617 .38948 .3268 .38648 .32034 .37482 Metetra
.861 .518 0 r
.32034 .37482 .3268 .38648 .33749 .38329 .33103 .37164 Metetra
.863 .513 0 r
.33103 .37164 .33749 .38329 .34823 .37992 .34178 .36826 Metetra
.864 .51 0 r
.34178 .36826 .34823 .37992 .35903 .37636 .35259 .36468 Metetra
.864 .509 0 r
.35259 .36468 .35903 .37636 .36988 .37261 .36345 .3609 Metetra
.864 .51 0 r
.36345 .3609 .36988 .37261 .38078 .36868 .37437 .35692 Metetra
.863 .513 0 r
.37437 .35692 .38078 .36868 .39174 .36456 .38534 .35275 Metetra
.861 .518 0 r
.38534 .35275 .39174 .36456 .40274 .36025 .39635 .34837 Metetra
.859 .525 0 r
.39635 .34837 .40274 .36025 .41379 .35575 .40742 .34378 Metetra
.856 .534 0 r
.40742 .34378 .41379 .35575 .42489 .35104 .41853 .33897 Metetra
.853 .545 0 r
.41853 .33897 .42489 .35104 .43603 .34613 .42969 .33395 Metetra
.848 .558 0 r
.42969 .33395 .43603 .34613 .44721 .34099 .44089 .32869 Metetra
.843 .573 0 r
.44089 .32869 .44721 .34099 .45844 .33563 .45214 .32319 Metetra
.837 .591 0 r
.45214 .32319 .45844 .33563 .46971 .33003 .46342 .31744 Metetra
.83 .61 0 r
.46342 .31744 .46971 .33003 .48101 .32417 .47474 .31142 Metetra
.823 .632 0 r
.47474 .31142 .48101 .32417 .49235 .31805 .4861 .30512 Metetra
.814 .655 0 r
.4861 .30512 .49235 .31805 .50372 .31164 .49749 .29852 Metetra
.805 .681 0 r
.49749 .29852 .50372 .31164 .51513 .30493 .5089 .29161 Metetra
.794 .709 0 r
.5089 .29161 .51513 .30493 .52656 .2979 .52035 .28437 Metetra
.782 .738 0 r
.52035 .28437 .52656 .2979 .53801 .29053 .53182 .27678 Metetra
.769 .769 0 r
.53182 .27678 .53801 .29053 .54948 .28281 .54331 .26881 Metetra
.708 .755 0 r
.54331 .26881 .54948 .28281 .56097 .2747 .55481 .26045 Metetra
.643 .739 0 r
.55481 .26045 .56097 .2747 .57248 .26618 .56632 .25168 Metetra
.574 .722 0 r
.56632 .25168 .57248 .26618 .58399 .25724 .57784 .24246 Metetra
.502 .703 0 r
.57784 .24246 .58399 .25724 .5955 .24784 .58937 .23278 Metetra
.426 .683 0 r
.58937 .23278 .5955 .24784 .607 .23796 .60088 .22261 Metetra
.349 .66 0 r
.60088 .22261 .607 .23796 .6185 .22757 .61238 .21192 Metetra
.269 .636 0 r
.61238 .21192 .6185 .22757 .62998 .21665 .62387 .20069 Metetra
.189 .61 0 r
.62387 .20069 .62998 .21665 .64143 .20517 .63532 .18889 Metetra
.109 .582 0 r
.63532 .18889 .64143 .20517 .65285 .1931 .64675 .17649 Metetra
.03 .551 0 r
.64675 .17649 .65285 .1931 .66423 .18041 .65813 .16346 Metetra
0 .518 .047 r
.65813 .16346 .66423 .18041 .67556 .16708 .66946 .14979 Metetra
0 .482 .118 r
.66946 .14979 .67556 .16708 .68683 .15307 .68072 .13543 Metetra
0 .444 .182 r
.68072 .13543 .68683 .15307 .69804 .13836 .69192 .12036 Metetra
0 .402 .237 r
.69192 .12036 .69804 .13836 .70916 .12291 .70303 .10456 Metetra
0 .358 .28 r
.70303 .10456 .70916 .12291 .72019 .10671 .71405 .088 Metetra
0 .317 .304 r
.0519 .31662 .05733 .33385 .06487 .34206 .05935 .32513 Metetra
0 .362 .276 r
.05935 .32513 .06487 .34206 .07261 .34958 .067 .33293 Metetra
0 .405 .234 r
.067 .33293 .07261 .34958 .08054 .3564 .07485 .34004 Metetra
0 .445 .18 r
.07485 .34004 .08054 .3564 .08865 .36258 .08289 .3465 Metetra
0 .482 .118 r
.08289 .3465 .08865 .36258 .09693 .36812 .0911 .35231 Metetra
0 .516 .049 r
.0911 .35231 .09693 .36812 .10537 .37306 .09948 .35752 Metetra
.024 .548 0 r
.09948 .35752 .10537 .37306 .11398 .37742 .10802 .36214 Metetra
.099 .578 0 r
.10802 .36214 .11398 .37742 .12273 .38123 .11671 .3662 Metetra
.176 .605 0 r
.11671 .3662 .12273 .38123 .13162 .38451 .12555 .36972 Metetra
.252 .631 0 r
.12555 .36972 .13162 .38451 .14065 .38728 .13453 .37273 Metetra
.327 .654 0 r
.13453 .37273 .14065 .38728 .14981 .38958 .14364 .37525 Metetra
.401 .675 0 r
.14364 .37525 .14981 .38958 .15909 .39142 .15288 .37731 Metetra
.472 .695 0 r
.15288 .37731 .15909 .39142 .16849 .39283 .16224 .37892 Metetra
.541 .713 0 r
.16224 .37892 .16849 .39283 .178 .39382 .17172 .38011 Metetra
.606 .73 0 r
.17172 .38011 .178 .39382 .18762 .39443 .1813 .3809 Metetra
.667 .745 0 r
.1813 .3809 .18762 .39443 .19733 .39467 .19099 .38131 Metetra
.725 .759 0 r
.19099 .38131 .19733 .39467 .20715 .39456 .20078 .38136 Metetra
.771 .764 0 r
.20078 .38136 .20715 .39456 .21705 .39412 .21066 .38107 Metetra
.783 .737 0 r
.21066 .38107 .21705 .39412 .22704 .39337 .22063 .38045 Metetra
.793 .712 0 r
.22063 .38045 .22704 .39337 .23711 .39232 .23069 .37953 Metetra
.802 .688 0 r
.23069 .37953 .23711 .39232 .24727 .39099 .24083 .37831 Metetra
.81 .667 0 r
.24083 .37831 .24727 .39099 .2575 .38939 .25105 .37681 Metetra
.817 .647 0 r
.25105 .37681 .2575 .38939 .2678 .38754 .26135 .37504 Metetra
.824 .63 0 r
.26135 .37504 .2678 .38754 .27818 .38544 .27172 .37302 Metetra
.829 .614 0 r
.27172 .37302 .27818 .38544 .28862 .38312 .28216 .37075 Metetra
.834 .601 0 r
.28216 .37075 .28862 .38312 .29913 .38056 .29267 .36825 Metetra
.838 .59 0 r
.29267 .36825 .29913 .38056 .3097 .3778 .30324 .36551 Metetra
.841 .58 0 r
.30324 .36551 .3097 .3778 .32034 .37482 .31388 .36256 Metetra
.843 .573 0 r
.31388 .36256 .32034 .37482 .33103 .37164 .32458 .35938 Metetra
.845 .568 0 r
.32458 .35938 .33103 .37164 .34178 .36826 .33534 .356 Metetra
.846 .565 0 r
.33534 .356 .34178 .36826 .35259 .36468 .34615 .3524 Metetra
.846 .564 0 r
.34615 .3524 .35259 .36468 .36345 .3609 .35703 .34859 Metetra
.846 .565 0 r
.35703 .34859 .36345 .3609 .37437 .35692 .36795 .34456 Metetra
.845 .568 0 r
.36795 .34456 .37437 .35692 .38534 .35275 .37893 .34033 Metetra
.843 .573 0 r
.37893 .34033 .38534 .35275 .39635 .34837 .38996 .33587 Metetra
.841 .58 0 r
.38996 .33587 .39635 .34837 .40742 .34378 .40104 .33119 Metetra
.838 .59 0 r
.40104 .33119 .40742 .34378 .41853 .33897 .41217 .32629 Metetra
.834 .601 0 r
.41217 .32629 .41853 .33897 .42969 .33395 .42334 .32115 Metetra
.829 .614 0 r
.42334 .32115 .42969 .33395 .44089 .32869 .43456 .31576 Metetra
.824 .63 0 r
.43456 .31576 .44089 .32869 .45214 .32319 .44582 .31012 Metetra
.817 .647 0 r
.44582 .31012 .45214 .32319 .46342 .31744 .45712 .30422 Metetra
.81 .667 0 r
.45712 .30422 .46342 .31744 .47474 .31142 .46845 .29803 Metetra
.802 .688 0 r
.46845 .29803 .47474 .31142 .4861 .30512 .47983 .29155 Metetra
.793 .712 0 r
.47983 .29155 .4861 .30512 .49749 .29852 .49123 .28476 Metetra
.783 .737 0 r
.49123 .28476 .49749 .29852 .5089 .29161 .50266 .27764 Metetra
.771 .764 0 r
.50266 .27764 .5089 .29161 .52035 .28437 .51412 .27018 Metetra
.725 .759 0 r
.51412 .27018 .52035 .28437 .53182 .27678 .52561 .26236 Metetra
.667 .745 0 r
.52561 .26236 .53182 .27678 .54331 .26881 .53711 .25415 Metetra
.606 .73 0 r
.53711 .25415 .54331 .26881 .55481 .26045 .54862 .24553 Metetra
.541 .713 0 r
.54862 .24553 .55481 .26045 .56632 .25168 .56015 .23649 Metetra
.472 .695 0 r
.56015 .23649 .56632 .25168 .57784 .24246 .57168 .227 Metetra
.401 .675 0 r
.57168 .227 .57784 .24246 .58937 .23278 .5832 .21703 Metetra
.327 .654 0 r
.5832 .21703 .58937 .23278 .60088 .22261 .59473 .20656 Metetra
.252 .631 0 r
.59473 .20656 .60088 .22261 .61238 .21192 .60623 .19556 Metetra
.176 .605 0 r
.60623 .19556 .61238 .21192 .62387 .20069 .61772 .18401 Metetra
.099 .578 0 r
.61772 .18401 .62387 .20069 .63532 .18889 .62918 .17189 Metetra
.024 .548 0 r
.62918 .17189 .63532 .18889 .64675 .17649 .6406 .15915 Metetra
0 .516 .049 r
.6406 .15915 .64675 .17649 .65813 .16346 .65198 .14579 Metetra
0 .482 .118 r
.65198 .14579 .65813 .16346 .66946 .14979 .66331 .13176 Metetra
0 .445 .18 r
.66331 .13176 .66946 .14979 .68072 .13543 .67457 .11705 Metetra
0 .405 .234 r
.67457 .11705 .68072 .13543 .69192 .12036 .68576 .10162 Metetra
0 .362 .276 r
.68576 .10162 .69192 .12036 .70303 .10456 .69686 .08546 Metetra
0 .317 .304 r
.69686 .08546 .70303 .10456 .71405 .088 .70787 .06853 Metetra
0 .231 .272 r
.04658 .29864 .0519 .31662 .05935 .32513 .05394 .30745 Metetra
0 .32 .303 r
.05394 .30745 .05935 .32513 .067 .33293 .06151 .31554 Metetra
0 .364 .275 r
.06151 .31554 .067 .33293 .07485 .34004 .06927 .32295 Metetra
0 .405 .234 r
.06927 .32295 .07485 .34004 .08289 .3465 .07722 .32968 Metetra
0 .444 .182 r
.07722 .32968 .08289 .3465 .0911 .35231 .08536 .33578 Metetra
0 .479 .123 r
.08536 .33578 .0911 .35231 .09948 .35752 .09367 .34126 Metetra
0 .513 .057 r
.09367 .34126 .09948 .35752 .10802 .36214 .10214 .34614 Metetra
.012 .544 0 r
.10214 .34614 .10802 .36214 .11671 .3662 .11077 .35046 Metetra
.083 .572 0 r
.11077 .35046 .11671 .3662 .12555 .36972 .11955 .35423 Metetra
.156 .599 0 r
.11955 .35423 .12555 .36972 .13453 .37273 .12848 .35748 Metetra
.228 .623 0 r
.12848 .35748 .13453 .37273 .14364 .37525 .13754 .36023 Metetra
.299 .645 0 r
.13754 .36023 .14364 .37525 .15288 .37731 .14673 .3625 Metetra
.369 .666 0 r
.14673 .3625 .15288 .37731 .16224 .37892 .15605 .36432 Metetra
.436 .685 0 r
.15605 .36432 .16224 .37892 .17172 .38011 .16549 .36571 Metetra
.5 .703 0 r
.16549 .36571 .17172 .38011 .1813 .3809 .17504 .36669 Metetra
.561 .719 0 r
.17504 .36669 .1813 .3809 .19099 .38131 .18469 .36728 Metetra
.619 .733 0 r
.18469 .36728 .19099 .38131 .20078 .38136 .19445 .36749 Metetra
.673 .746 0 r
.19445 .36749 .20078 .38136 .21066 .38107 .20431 .36735 Metetra
.723 .758 0 r
.20431 .36735 .21066 .38107 .22063 .38045 .21426 .36687 Metetra
.769 .769 0 r
.21426 .36687 .22063 .38045 .23069 .37953 .2243 .36607 Metetra
.779 .746 0 r
.2243 .36607 .23069 .37953 .24083 .37831 .23442 .36497 Metetra
.788 .725 0 r
.23442 .36497 .24083 .37831 .25105 .37681 .24463 .36357 Metetra
.795 .706 0 r
.24463 .36357 .25105 .37681 .26135 .37504 .25492 .36189 Metetra
.802 .688 0 r
.25492 .36189 .26135 .37504 .27172 .37302 .26528 .35995 Metetra
.808 .673 0 r
.26528 .35995 .27172 .37302 .28216 .37075 .27572 .35774 Metetra
.813 .659 0 r
.27572 .35774 .28216 .37075 .29267 .36825 .28622 .35529 Metetra
.817 .648 0 r
.28622 .35529 .29267 .36825 .30324 .36551 .2968 .35259 Metetra
.82 .639 0 r
.2968 .35259 .30324 .36551 .31388 .36256 .30744 .34965 Metetra
.823 .632 0 r
.30744 .34965 .31388 .36256 .32458 .35938 .31814 .34649 Metetra
.825 .626 0 r
.31814 .34649 .32458 .35938 .33534 .356 .3289 .34309 Metetra
.826 .623 0 r
.3289 .34309 .33534 .356 .34615 .3524 .33973 .33947 Metetra
.826 .622 0 r
.33973 .33947 .34615 .3524 .35703 .34859 .35061 .33563 Metetra
.826 .623 0 r
.35061 .33563 .35703 .34859 .36795 .34456 .36154 .33156 Metetra
.825 .626 0 r
.36154 .33156 .36795 .34456 .37893 .34033 .37253 .32726 Metetra
.823 .632 0 r
.37253 .32726 .37893 .34033 .38996 .33587 .38357 .32273 Metetra
.82 .639 0 r
.38357 .32273 .38996 .33587 .40104 .33119 .39466 .31796 Metetra
.817 .648 0 r
.39466 .31796 .40104 .33119 .41217 .32629 .4058 .31296 Metetra
.813 .659 0 r
.4058 .31296 .41217 .32629 .42334 .32115 .41699 .3077 Metetra
.808 .673 0 r
.41699 .3077 .42334 .32115 .43456 .31576 .42822 .30218 Metetra
.802 .688 0 r
.42822 .30218 .43456 .31576 .44582 .31012 .43949 .2964 Metetra
.795 .706 0 r
.43949 .2964 .44582 .31012 .45712 .30422 .45081 .29033 Metetra
.788 .725 0 r
.45081 .29033 .45712 .30422 .46845 .29803 .46216 .28397 Metetra
.779 .746 0 r
.46216 .28397 .46845 .29803 .47983 .29155 .47354 .27731 Metetra
.769 .769 0 r
.47354 .27731 .47983 .29155 .49123 .28476 .48496 .27032 Metetra
.723 .758 0 r
.48496 .27032 .49123 .28476 .50266 .27764 .49641 .26299 Metetra
.673 .746 0 r
.49641 .26299 .50266 .27764 .51412 .27018 .50788 .25531 Metetra
.619 .733 0 r
.50788 .25531 .51412 .27018 .52561 .26236 .51937 .24725 Metetra
.561 .719 0 r
.51937 .24725 .52561 .26236 .53711 .25415 .53088 .23879 Metetra
.5 .703 0 r
.53088 .23879 .53711 .25415 .54862 .24553 .54241 .22991 Metetra
.436 .685 0 r
.54241 .22991 .54862 .24553 .56015 .23649 .55394 .2206 Metetra
.369 .666 0 r
.55394 .2206 .56015 .23649 .57168 .227 .56548 .21082 Metetra
.299 .645 0 r
.56548 .21082 .57168 .227 .5832 .21703 .57702 .20056 Metetra
.228 .623 0 r
.57702 .20056 .5832 .21703 .59473 .20656 .58854 .18978 Metetra
.156 .599 0 r
.58854 .18978 .59473 .20656 .60623 .19556 .60005 .17847 Metetra
.083 .572 0 r
.60005 .17847 .60623 .19556 .61772 .18401 .61154 .1666 Metetra
.012 .544 0 r
.61154 .1666 .61772 .18401 .62918 .17189 .623 .15414 Metetra
0 .513 .057 r
.623 .15414 .62918 .17189 .6406 .15915 .63443 .14106 Metetra
0 .479 .123 r
.63443 .14106 .6406 .15915 .65198 .14579 .6458 .12735 Metetra
0 .444 .182 r
.6458 .12735 .65198 .14579 .66331 .13176 .65712 .11297 Metetra
0 .405 .234 r
.65712 .11297 .66331 .13176 .67457 .11705 .66838 .0979 Metetra
0 .364 .275 r
.66838 .0979 .67457 .11705 .68576 .10162 .67955 .08212 Metetra
0 .32 .303 r
.67955 .08212 .68576 .10162 .69686 .08546 .69065 .06559 Metetra
0 .231 .272 r
.69065 .06559 .69686 .08546 .70787 .06853 .70164 .04829 Metetra
0 .144 .225 r
.04139 .27989 .04658 .29864 .05394 .30745 .04865 .28899 Metetra
0 .234 .274 r
.04865 .28899 .05394 .30745 .06151 .31554 .05613 .29739 Metetra
0 .32 .303 r
.05613 .29739 .06151 .31554 .06927 .32295 .0638 .30509 Metetra
0 .363 .276 r
.0638 .30509 .06927 .32295 .07722 .32968 .07167 .31211 Metetra
0 .402 .237 r
.07167 .31211 .07722 .32968 .08536 .33578 .07972 .31849 Metetra
0 .44 .188 r
.07972 .31849 .08536 .33578 .09367 .34126 .08796 .32425 Metetra
0 .474 .132 r
.08796 .32425 .09367 .34126 .10214 .34614 .09636 .3294 Metetra
0 .506 .071 r
.09636 .3294 .10214 .34614 .11077 .35046 .10492 .33398 Metetra
0 .536 .005 r
.10492 .33398 .11077 .35046 .11955 .35423 .11364 .338 Metetra
.062 .564 0 r
.11364 .338 .11955 .35423 .12848 .35748 .12251 .34149 Metetra
.13 .589 0 r
.12251 .34149 .12848 .35748 .13754 .36023 .13152 .34447 Metetra
.198 .613 0 r
.13152 .34447 .13754 .36023 .14673 .3625 .14066 .34697 Metetra
.264 .635 0 r
.14066 .34697 .14673 .3625 .15605 .36432 .14993 .34901 Metetra
.329 .655 0 r
.14993 .34901 .15605 .36432 .16549 .36571 .15932 .3506 Metetra
.392 .673 0 r
.15932 .3506 .16549 .36571 .17504 .36669 .16883 .35177 Metetra
.452 .69 0 r
.16883 .35177 .17504 .36669 .18469 .36728 .17845 .35253 Metetra
.509 .705 0 r
.17845 .35253 .18469 .36728 .19445 .36749 .18818 .35291 Metetra
.563 .719 0 r
.18818 .35291 .19445 .36749 .20431 .36735 .19801 .35293 Metetra
.613 .732 0 r
.19801 .35293 .20431 .36735 .21426 .36687 .20793 .3526 Metetra
.66 .743 0 r
.20793 .3526 .21426 .36687 .2243 .36607 .21795 .35193 Metetra
.702 .754 0 r
.21795 .35193 .2243 .36607 .23442 .36497 .22806 .35094 Metetra
.741 .763 0 r
.22806 .35094 .23442 .36497 .24463 .36357 .23825 .34965 Metetra
.771 .765 0 r
.23825 .34965 .24463 .36357 .25492 .36189 .24853 .34806 Metetra
.778 .748 0 r
.24853 .34806 .25492 .36189 .26528 .35995 .25888 .34619 Metetra
.784 .733 0 r
.25888 .34619 .26528 .35995 .27572 .35774 .26931 .34405 Metetra
.79 .72 0 r
.26931 .34405 .27572 .35774 .28622 .35529 .27981 .34164 Metetra
.794 .709 0 r
.27981 .34164 .28622 .35529 .2968 .35259 .29038 .33898 Metetra
.798 .699 0 r
.29038 .33898 .2968 .35259 .30744 .34965 .30101 .33607 Metetra
.8 .692 0 r
.30101 .33607 .30744 .34965 .31814 .34649 .31172 .33291 Metetra
.802 .687 0 r
.31172 .33291 .31814 .34649 .3289 .34309 .32248 .32951 Metetra
.804 .684 0 r
.32248 .32951 .3289 .34309 .33973 .33947 .33331 .32587 Metetra
.804 .683 0 r
.33331 .32587 .33973 .33947 .35061 .33563 .3442 .32199 Metetra
.804 .684 0 r
.3442 .32199 .35061 .33563 .36154 .33156 .35514 .31787 Metetra
.802 .687 0 r
.35514 .31787 .36154 .33156 .37253 .32726 .36614 .31351 Metetra
.8 .692 0 r
.36614 .31351 .37253 .32726 .38357 .32273 .37719 .3089 Metetra
.798 .699 0 r
.37719 .3089 .38357 .32273 .39466 .31796 .38829 .30404 Metetra
.794 .709 0 r
.38829 .30404 .39466 .31796 .4058 .31296 .39944 .29893 Metetra
.79 .72 0 r
.39944 .29893 .4058 .31296 .41699 .3077 .41064 .29355 Metetra
.784 .733 0 r
.41064 .29355 .41699 .3077 .42822 .30218 .42188 .2879 Metetra
.778 .748 0 r
.42188 .2879 .42822 .30218 .43949 .2964 .43316 .28197 Metetra
.771 .765 0 r
.43316 .28197 .43949 .2964 .45081 .29033 .44449 .27574 Metetra
.741 .763 0 r
.44449 .27574 .45081 .29033 .46216 .28397 .45585 .26921 Metetra
.702 .754 0 r
.45585 .26921 .46216 .28397 .47354 .27731 .46725 .26236 Metetra
.66 .743 0 r
.46725 .26236 .47354 .27731 .48496 .27032 .47868 .25516 Metetra
.613 .732 0 r
.47868 .25516 .48496 .27032 .49641 .26299 .49014 .24762 Metetra
.563 .719 0 r
.49014 .24762 .49641 .26299 .50788 .25531 .50162 .23971 Metetra
.509 .705 0 r
.50162 .23971 .50788 .25531 .51937 .24725 .51313 .2314 Metetra
.452 .69 0 r
.51313 .2314 .51937 .24725 .53088 .23879 .52465 .22269 Metetra
.392 .673 0 r
.52465 .22269 .53088 .23879 .54241 .22991 .53618 .21355 Metetra
.329 .655 0 r
.53618 .21355 .54241 .22991 .55394 .2206 .54772 .20396 Metetra
.264 .635 0 r
.54772 .20396 .55394 .2206 .56548 .21082 .55927 .19389 Metetra
.198 .613 0 r
.55927 .19389 .56548 .21082 .57702 .20056 .57081 .18332 Metetra
.13 .589 0 r
.57081 .18332 .57702 .20056 .58854 .18978 .58234 .17224 Metetra
.062 .564 0 r
.58234 .17224 .58854 .18978 .60005 .17847 .59385 .16061 Metetra
0 .536 .005 r
.59385 .16061 .60005 .17847 .61154 .1666 .60534 .14841 Metetra
0 .506 .071 r
.60534 .14841 .61154 .1666 .623 .15414 .6168 .13561 Metetra
0 .474 .132 r
.6168 .13561 .623 .15414 .63443 .14106 .62821 .12219 Metetra
0 .44 .188 r
.62821 .12219 .63443 .14106 .6458 .12735 .63958 .10813 Metetra
0 .402 .237 r
.63958 .10813 .6458 .12735 .65712 .11297 .6509 .0934 Metetra
0 .363 .276 r
.6509 .0934 .65712 .11297 .66838 .0979 .66214 .07796 Metetra
0 .32 .303 r
.66214 .07796 .66838 .0979 .67955 .08212 .67331 .06181 Metetra
0 .234 .274 r
.67331 .06181 .67955 .08212 .69065 .06559 .68439 .04492 Metetra
0 .144 .225 r
.68439 .04492 .69065 .06559 .70164 .04829 .69537 .02725 Metetra
0 .073 .174 r
.03634 .26033 .04139 .27989 .04865 .28899 .0435 .26975 Metetra
0 .144 .225 r
.0435 .26975 .04865 .28899 .05613 .29739 .05087 .27844 Metetra
0 .231 .272 r
.05087 .27844 .05613 .29739 .0638 .30509 .05845 .28643 Metetra
0 .317 .304 r
.05845 .28643 .0638 .30509 .07167 .31211 .06623 .29375 Metetra
0 .358 .28 r
.06623 .29375 .07167 .31211 .07972 .31849 .0742 .30042 Metetra
0 .397 .244 r
.0742 .30042 .07972 .31849 .08796 .32425 .08235 .30645 Metetra
0 .433 .198 r
.08235 .30645 .08796 .32425 .09636 .3294 .09068 .31188 Metetra
0 .466 .146 r
.09068 .31188 .09636 .3294 .10492 .33398 .09917 .31672 Metetra
0 .497 .089 r
.09917 .31672 .10492 .33398 .11364 .338 .10782 .32099 Metetra
0 .526 .028 r
.10782 .32099 .11364 .338 .12251 .34149 .11663 .32473 Metetra
.034 .553 0 r
.11663 .32473 .12251 .34149 .13152 .34447 .12557 .32796 Metetra
.098 .578 0 r
.12557 .32796 .13152 .34447 .14066 .34697 .13466 .33068 Metetra
.161 .6 0 r
.13466 .33068 .14066 .34697 .14993 .34901 .14388 .33293 Metetra
.223 .621 0 r
.14388 .33293 .14993 .34901 .15932 .3506 .15323 .33473 Metetra
.284 .641 0 r
.15323 .33473 .15932 .3506 .16883 .35177 .1627 .33609 Metetra
.342 .658 0 r
.1627 .33609 .16883 .35177 .17845 .35253 .17228 .33704 Metetra
.398 .675 0 r
.17228 .33704 .17845 .35253 .18818 .35291 .18197 .3376 Metetra
.451 .689 0 r
.18197 .3376 .18818 .35291 .19801 .35293 .19177 .33777 Metetra
.5 .703 0 r
.19177 .33777 .19801 .35293 .20793 .3526 .20166 .33758 Metetra
.546 .715 0 r
.20166 .33758 .20793 .3526 .21795 .35193 .21166 .33705 Metetra
.589 .726 0 r
.21166 .33705 .21795 .35193 .22806 .35094 .22174 .33618 Metetra
.628 .736 0 r
.22174 .33618 .22806 .35094 .23825 .34965 .23192 .33499 Metetra
.664 .744 0 r
.23192 .33499 .23825 .34965 .24853 .34806 .24217 .3335 Metetra
.695 .752 0 r
.24217 .3335 .24853 .34806 .25888 .34619 .25251 .33171 Metetra
.723 .758 0 r
.25251 .33171 .25888 .34619 .26931 .34405 .26293 .32963 Metetra
.747 .764 0 r
.26293 .32963 .26931 .34405 .27981 .34164 .27342 .32728 Metetra
.767 .769 0 r
.27342 .32728 .27981 .34164 .29038 .33898 .28399 .32465 Metetra
.773 .761 0 r
.28399 .32465 .29038 .33898 .30101 .33607 .29462 .32176 Metetra
.776 .754 0 r
.29462 .32176 .30101 .33607 .31172 .33291 .30532 .31861 Metetra
.778 .749 0 r
.30532 .31861 .31172 .33291 .32248 .32951 .31609 .3152 Metetra
.779 .746 0 r
.31609 .3152 .32248 .32951 .33331 .32587 .32692 .31154 Metetra
.779 .745 0 r
.32692 .31154 .33331 .32587 .3442 .32199 .3378 .30763 Metetra
.779 .746 0 r
.3378 .30763 .3442 .32199 .35514 .31787 .34875 .30346 Metetra
.778 .749 0 r
.34875 .30346 .35514 .31787 .36614 .31351 .35976 .29903 Metetra
.776 .754 0 r
.35976 .29903 .36614 .31351 .37719 .3089 .37081 .29435 Metetra
.773 .761 0 r
.37081 .29435 .37719 .3089 .38829 .30404 .38192 .2894 Metetra
.767 .769 0 r
.38192 .2894 .38829 .30404 .39944 .29893 .39308 .28417 Metetra
.747 .764 0 r
.39308 .28417 .39944 .29893 .41064 .29355 .40429 .27867 Metetra
.723 .758 0 r
.40429 .27867 .41064 .29355 .42188 .2879 .41554 .27289 Metetra
.695 .752 0 r
.41554 .27289 .42188 .2879 .43316 .28197 .42684 .2668 Metetra
.664 .744 0 r
.42684 .2668 .43316 .28197 .44449 .27574 .43817 .26041 Metetra
.628 .736 0 r
.43817 .26041 .44449 .27574 .45585 .26921 .44955 .2537 Metetra
.589 .726 0 r
.44955 .2537 .45585 .26921 .46725 .26236 .46095 .24665 Metetra
.546 .715 0 r
.46095 .24665 .46725 .26236 .47868 .25516 .47239 .23925 Metetra
.5 .703 0 r
.47239 .23925 .47868 .25516 .49014 .24762 .48386 .23149 Metetra
.451 .689 0 r
.48386 .23149 .49014 .24762 .50162 .23971 .49535 .22334 Metetra
.398 .675 0 r
.49535 .22334 .50162 .23971 .51313 .2314 .50687 .21479 Metetra
.342 .658 0 r
.50687 .21479 .51313 .2314 .52465 .22269 .5184 .20582 Metetra
.284 .641 0 r
.5184 .20582 .52465 .22269 .53618 .21355 .52994 .19641 Metetra
.223 .621 0 r
.52994 .19641 .53618 .21355 .54772 .20396 .54148 .18653 Metetra
.161 .6 0 r
.54148 .18653 .54772 .20396 .55927 .19389 .55303 .17617 Metetra
.098 .578 0 r
.55303 .17617 .55927 .19389 .57081 .18332 .56457 .1653 Metetra
.034 .553 0 r
.56457 .1653 .57081 .18332 .58234 .17224 .57611 .1539 Metetra
0 .526 .028 r
.57611 .1539 .58234 .17224 .59385 .16061 .58762 .14195 Metetra
0 .497 .089 r
.58762 .14195 .59385 .16061 .60534 .14841 .59911 .12942 Metetra
0 .466 .146 r
.59911 .12942 .60534 .14841 .6168 .13561 .61056 .11628 Metetra
0 .433 .198 r
.61056 .11628 .6168 .13561 .62821 .12219 .62197 .10251 Metetra
0 .397 .244 r
.62197 .10251 .62821 .12219 .63958 .10813 .63334 .0881 Metetra
0 .358 .28 r
.63334 .0881 .63958 .10813 .6509 .0934 .64464 .073 Metetra
0 .317 .304 r
.64464 .073 .6509 .0934 .66214 .07796 .65587 .05721 Metetra
0 .231 .272 r
.65587 .05721 .66214 .07796 .67331 .06181 .66703 .04069 Metetra
0 .144 .225 r
.66703 .04069 .67331 .06181 .68439 .04492 .67809 .02342 Metetra
0 .073 .174 r
.67809 .02342 .68439 .04492 .69537 .02725 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15783 .20788 m
.16244 .21256 L
s
[(-5)] .14862 .19854 .98551 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54216 .05739 m
.54606 .06267 L
s
[(5)] .53437 .04684 .73896 1 Mshowa
.125 Mabswid
.19384 .19379 m
.19657 .19662 L
s
.23036 .17949 m
.23305 .18236 L
s
.26739 .16499 m
.27004 .1679 L
s
.30496 .15028 m
.30757 .15322 L
s
.38173 .12022 m
.38425 .12323 L
s
.42095 .10486 m
.42344 .10791 L
s
.46076 .08927 m
.4632 .09236 L
s
.50116 .07345 m
.50355 .07658 L
s
.12233 .22179 m
.12512 .22456 L
s
.08731 .2355 m
.09014 .23824 L
s
.05276 .24903 m
.05563 .25173 L
s
.58379 .0411 m
.58607 .0443 L
s
.62604 .02455 m
.62828 .02779 L
s
.66894 .00775 m
.67112 .01103 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003obOooool2
o`0005Gooooo0036ooooo`?o000000?oooooo`000?ooool0E?ooool00<Cooooo0_l00004ooooo`;o
0000E?ooool00<7ooooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo000005?ooooo
002oooooo`;o00002?ooool5o`0005;ooooo002Looooo`?o00007Oooool3o`0000Wooooo00Ko0000
o`0B;?l0003o0000ooooool0001Booooo`00Voooool01Ol0003ooooooooooooooooo000001Wooooo
0ol0000<ooooo`04o`000?l04Rco0000o`0000;ooooo00?o0000ooooooooool0Coooool009oooooo
00?o0000ooooooooool05Oooool3o`0000gooooo00So0000o`0B;?l04Rco0000o`0B;?l0003ooooo
o`00057ooooo002Oooooo`03o`000?oooooooooo01;ooooo0ol00003ooooo`03o`000?oooooooooo
00[ooooo00Ko0000o`0B;?l04Rco0000o`0B;?l00002ooooo`03o`000?oooooooooo04kooooo002K
ooooo`Co00004oooool2o`0001;ooooo00?o0000o`0T>Ol000000_l04R`2o`0000?ooooo00?o0000
ooooooooool0COooool009_ooooo00?o0000ooooooooool04Oooool3o`0001?ooooo00Co0000o`0T
>Ol093Wo00000_l04R`00ol0003o02@io`000002ooooo`03o`000?oooooooooo04gooooo002Koooo
o`Go00003Oooool2o`0001Gooooo00Ko0000o`0T>Ol093Wo02@io`000?l04R`2o`000003o`0T>Ol0
003ooooo00;ooooo00?o0000ooooooooool0C?ooool00:[ooooo0ol000000ooooooo0000ooooo`0D
ooooo`03o`000?l093Wo02@i00;o02@i00Go0000o`0T>Ol0003o02@io`000004ooooo`03o`000?oo
oooooooo04_ooooo002Xooooo`;o00006Oooool00ol0003o03]5o`000003o`0T>@03o`000?l093Wo
000000;o02@i00?o0000ooooooooool00_l0001=ooooo`00YOooool3o`0001[ooooo00Co0000o`0k
AOl0>dGo00000_l093T01?l0003o03]6o`000?l00002o`0T>@03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0B_ooool00:;ooooo0ol0000Mooooo`06o`000?l0>dGo03]5o`000?l093Wo0000
0_l0>dH2o`000003o`0T>Ol0003o000000Gooooo00?o0000ooooooooool0BOooool00:3ooooo0_l0
00000ooooooo0000ooooo`0Looooo`03o`000?l0>dGo03]500;o03]50_l00002o`0kAP?o000000?o
03]5o`000?ooool01?ooool00ol0003oooooooooo`19ooooo`00WOooool3o`0000Cooooo00?o0000
ooooooooool06_ooool00ol0003o03]5o`0kA@02o`0kA@03o`000?l0>dKo03]600;o03]60_l00002
o`0kA@03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B?ooool009_ooooo0_l0000Soooo
o`03o`000?l0DDgo000000?o03]500?o0000o`0kA_l0>dH00_l0>dH01Ol0003o03]5o`0kAOl0>dGo
000000Gooooo00?o0000ooooooooool0B?ooool009Sooooo0ol0000Tooooo`04o`000?l0DDgo055=
o`0000;o03]500?o0000o`1ACOl000000ol0>dH01Ol0003o03]5o`0kAOl0>dGo000000Kooooo00?o
0000ooooooooool0Aoooool009Kooooo0_l0000Vooooo`07o`000?l0DDgo055=o`1ACOl0003o03]5
o`000002o`1AC@03o`000?l0>dKo03]600;o00000ol0>dD00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Kooooo002Cooooo`?o00000_ooool00ol0003oooooooooo`0Sooooo`03o`000?l0
DDgo055=00;o055=00So0000o`1ACOl0DDgo055=o`000?l0>dKo0000o`1AC@;o000000Co03]5o`00
0?l0DDgo00001Oooool2o`0004Sooooo002Aooooo`;o0000:_ooool00ol0003o05]7o`000003o`1A
C@03o`000?l0DDgo055=00;o055=00?o0000o`1ACOl0DDd00ol00002o`1AC@03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0AOooool008kooooo0ol0000[ooooo`04o`000?l0FdOo05]7o`00
00;o055=00?o0000o`1LA_l000000ol0DDd00ol0003o055=o`1AC@02o`0000?o055=00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0;ooooo`?o0000=_ooool008cooooo0_l0000]ooooo`07
o`000?l0FdOo05]7o`1KAol0003o055=o`000002o`1LAP03o`000?l0DDgo055=00;o00000_l0DDd2
o`0000Co055=00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`05o`000?oooooo
ooooooooool00000=Oooool008Wooooo0ol000000ooooooo0000ooooo`0/ooooo`03o`000?l0FdOo
05]700;o05]70_l00002o`1LAP05o`000?l0DDgo0000o`1MA_l000000_l0DDd00ol0003o05a6o`00
0003o`1AC@03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool5o`0000Gooooo00?o
0000ooooooooool0<oooool006Oooooo0_l0000Mooooo`?o0000<Oooool00ol0003o06Dno`000003
o`1KA`03o`000?l0G4Ko05a600;o05a60_l00002o`1MAP;o000000?o05a6o`000?l000000_l0DDd0
0ol0003o05]7o`000008ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<oooool0
06Kooooo00Co0000oooooooooooo00006_ooool2o`0003?ooooo00Co0000o`1U?_l0ICko00000_l0
FdL2o`0000Co05a600Co0000o`1MA_l0GDKo05e60_l000001Ol0G4Ko0000o`000?l0DDgo000000;o
05]700?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`Co0000=_ooool006Kooooo
00Co0000oooooooooooo00005oooool3o`0003Cooooo00Oo0000o`1U?_l0ICko06Dno`000?l0FdOo
000000;o06Hl00Go0000o`1LA_l0G4Ko05a6o`000003o`1MAP05o`000?l0G4Ko05a6o`000?l0G4H0
0_l00002o`1KA`03o`000?oooooooooo00Oooooo0_l00008ooooo`03o`000?oooooooooo03Oooooo
001Vooooo`04o`000?ooooooooooo`0001Gooooo0_l000000ooooooo0000ooooo`0dooooo`03o`00
0?l0ICko06Dn00;o06Dn00Go0000o`1V??l0ISco06Hlo`000002o`1LAP;o00000ol0GDH01_l0003o
05a6o`1LA_l0003o05a6o`0000Co05]700?o0000ooooooooool01Oooool00ol0003oooooo`000008
ooooo`Go0000=Oooool006Kooooo00Co0000oooooooooooo00004_ooool3o`0003Sooooo00?o0000
o`1^<_l000000ol0ICh01ol0003o06Hlo`1V??l0ISco0000o`1LA_l000000_l0Ic/02Ol0003o05e6
o`000?l0Ic_o0000o`1LA_l0003o05a6o`000004o`1KA`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0@?ooool006Kooooo00Co0000oooooooooooo00004?ooool2o`0003[ooooo00Co0000
o`1^<_l0KS;o00000_l0ICh00ol0003o070`o`000003o`1V?004o`000?l0Ic_o06Lko`1W>`;o0000
0_l0Ic/01_l0003o05a6o`000?l0003o06Hlo`0000;o05]70_l0000:ooooo`03o`000?oooooooooo
03oooooo001Wooooo`;o00003_ooool3o`0003_ooooo00Oo0000o`1^<_l0KS;o06hbo`000?l0ICko
000000;o070`00Go0000o`1V??l0ISco06Hlo`000003o`1W>`07o`000?l0Ic_o06Lko`1W>ol0003o
05a6o`000002o`1V?003o`000?l0FdOo000000;o06Dn00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0nooooo`00MOooool3o`0003cooooo0_l00004o`1^<P05o`000?l0L33o070`o`1`<?l0
00000_l0IS`2o`0000?o06Lk00?o0000o`1W>ol0Ic/00_l0Ic/2o`0000;o06Hl00?o0000o`1KAol0
00000_l0ICh00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo001booooo`?o0000
0oooool00ol0003oooooooooo`0hooooo`04o`000?l0MbGo07LUo`0000?o06hb00?o0000o`1`<?l0
L3000_l0L302o`0000;o074^00Go0000o`1W>ol0003o074^o`000003o`1W>`;o00000ol0IS`01Ol0
003o06Dno`1U?_l0ICko000000_ooooo00?o0000ooooooooool0?Oooool006oooooo0ol00010oooo
o`05o`000?l0MbGo07LUo`1g9Ol000000_l0KS800ol0003o07TQo`000003o`1`<004o`000?l0LBko
074^o`1a;P;o00000_l0LBh01_l0003o06Lko`1W>ol0003o074^o`0000?o06Hl00Go0000o`1U?_l0
ICko06Dno`00000<ooooo`03o`000?oooooooooo03cooooo001]ooooo`;o0000@oooool01ol0003o
07LUo`1g9Ol0MbGo0000o`1^<_l000000_l0NB400ol0003o070`o`1`<002o`0000?o074^00Oo0000
o`1a;_l0LBko074^o`000?l0Ic_o000000;o074^00?o0000o`1V??l0IS`00_l00002o`1U?P03o`00
0?l0KS;o000000_ooooo0_l0000mooooo`00J_ooool4o`0004?ooooo00?o0000o`1o5_l000000ol0
MbD02Ol0003o07TQo`1i8Ol0NB7o0000o`1`<?l0003o07XOo`000003o`1a;P03o`000?l0LBko074^
00;o074^00Oo0000o`1a;_l0LBko074^o`000?l0ISco000000;o070`0_l00002o`1^<P03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0>oooool006Sooooo0_l00004ooooo`03o`000?oooooo
oooo03oooooo00Co0000o`1o5_l0OaKo00000_l0MbD2o`0000Co07TQ00Wo0000o`1j7ol0NQoo07XO
o`000?l0LBko0000o`1k7_l000000ol0LBh01?l0003o074^o`1a;_l0LBh2o`0000?o070`00Go0000
o`1^<_l0KS;o06hbo`00000=ooooo`03o`000?oooooooooo03[ooooo001Uooooo`?o0000Aoooool0
2Ol0003o07lFo`1o5_l0OaKo0000o`1g9Ol0003o084Bo`000003o`1i8@;o00000ol0NQl2o`0000;o
07/N00Ko0000o`1a;_l0LBko0000o`1k7_l00002o`1a;P;o00000ol0L3000ol0003o06hbo`1^<P02
o`1^<P03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>_ooool006?ooooo0_l00019oooo
o`;o00001?l0OaH02Ol0003o084Bo`214_l0PA;o0000o`1i8Ol0003o08<>o`000003o`1j7`07o`00
0?l0Nako07/No`1k7_l0003o074^o`000002o`1k7P03o`000?l0LBko074^00;o00000_l0L3000ol0
003o07TQo`000003o`1^<P03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>Oooool0063o
oooo0ol0001:ooooo`04o`000?l0QPOo08H7o`0000?o07lF00Co0000o`214_l0PA;o084B0_l00003
o`233P04o`000?l0NQoo0000o`0000Co07/N00Ko0000o`1k7_l0Nako07/No`000?l0LBh2o`000003
o`1j7ol0003o000000;o07TQ00Ko0000o`1^<_l0KS;o0000o`1g9Ol0000=ooooo`03o`000?oooooo
oooo03Sooooo001Nooooo`;o00000oooool00ol0003oooooooooo`16ooooo`05o`000?l0QPOo08H7
o`261ol000000_l0OaH2o`0000?o084B00?o0000o`233_l0P`h00_l0P`h2o`0000;o08@<00?o0000
o`1k7_l0Nah00_l00004o`1k7P05o`000?l0NQoo0000o`1j7ol000000ol0NB400ol0003o06hbo`00
0002o`1g9@03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>?ooool005_ooooo0ol0001=
ooooo`;o00000ol0QPL00ol0003o07lFo`000002o`290@04o`000?l0PA;o0000o`0000Co08<>00Oo
0000o`243?l0Q0co08@<o`000?l0Nako000000;o08@<00?o0000o`1k7_l0Nah00_l00002o`1j7`;o
00001?l0NB400ol0003o07LUo`1g9@02o`1g9@03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0=oooool005Sooooo0ol0001?ooooo`03o`000?l8S@3o000000?o08H70_l00003o`290@;o0000
0_l3R`001Ol0003o08<>o`233_l0P`ko000000Co08@<00Wo0000o`243?l0Q0co08@<o`000?l0Nako
0000o`243?l000000_l0NQl00ol0003o08<>o`000003o`1i8@03o`000?l0MbGo07LU00;o07LU00?o
0000ooooooooool02_ooool00ol0003oooooo`00000hooooo`00E_ooool3o`0004oooooo0_l00003
o`R=0005o`000?l0QPOo0000o`n@0?l000000ol0R@401Ol0003o0h/0o`>;0?l3R`3o000000;o08<>
00?o0000o`J<0?l000000ol0Q0`00ol0003o08@<o`243002o`243004o`000?l0Q0co08@<o`2430?o
000000Oo08<>o`000?l0NB7o07TQo`000?l0PA;o000000;o07LU0_l0000>ooooo`03o`000?oooooo
oooo03Kooooo000cooooo`?o00007Oooool3o`0000?ooooo00?o0000ooooooooool0Boooool00ol0
003o6I<0o`000003o`R=00;o00000_l?T0001Ol0003o08T1o`290Ol0R@7o000000?o0h/000?o0000
o`233_l000000_l6S0001_l0003o08@<o`243?l0003o1hd0o`0000?o08@<00_o0000o`243?l0Q0co
08@<o`000?l0P`ko0000o`233_l0003o07TQo`000002o`214P03o`000?l0MbGo000000;o07lF00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0eooooo`00<_ooool01Ol0003ooooooooooooo
oooo000001[ooooo0_l0001Cooooo`04o`000?lIT`3o6I<0o`0000?o28d000?o0000o`n@0?l?T000
0_l?T0001Ol0003o08T1o`000?lETP3o000000?o0h/000Oo0000o`J<0?l6S03o1X`0o`000?l0Q0co
000000;o1hd000?o0000o`243?l0Q0`00_l00003o`243003o`000?l0P`ko000000;o08<>00?o0000
o`214_l0PA800_l0PA801Ol0003o07lFo`1o5_l0OaKo000000kooooo00?o0000ooooooooool0=Ooo
ool002cooooo1Ol00005ooooo`03o`000?oooooooooo01Gooooo0ol0001Dooooo`03o`000?lIT`3o
6I<000;o6I<000Co0000o`R=0?l0003o00001?l?T002o`0000;o5I8000?o0000o`>;0?l3R`000_l0
0004o`J<0007o`000?l7S@3o1hd0o`N=0?l0003o08@<o`000002o`N=0004o`000?l0Q0co0000o`F<
00;o00000_l0P`h00ol0003o084Bo`214P02o`214P05o`000?l0OaKo07lFo`1o5_l000003oooool0
0ol0003oooooooooo`0dooooo`00=_ooool00ol0003oooooooooo`0Cooooo`?o0000EOooool2o`00
00Co6I<00_l00002ob6F0005o`000?l?T03o3i00o`n@0?l000000olETP000ol0003o0h/0o`000002
oaVC0003o`000?l6S03o1X`000;o00001?l7S@001?l0003o1hd0o`N=0?l7S@02o`0000;o1H`00_l0
00001?l0P`ko0000o`>;0?l00002o`214P;o00000_l0OaH00ol0003o08H7o`00000?ooooo`03o`00
0?oooooooooo03?ooooo000booooo`Co00004oooool3o`0000?ooooo00?o0000ooooooooool0DOoo
ool01?l0003o:IT0obVI0?l00003oaVC0005o`000?lQUP3o8IH0ob6F0?l000000_l?T002o`0000Co
5I8000Oo0000oaVC0?lIT`3o6I<0o`000?l6S03o000000;o6i@000Go0000o`N=0?l7S@3o1hd0o`00
0003o`N=0004o`000?l5S03o1H`0o`F<00?o00000_l3R`000ol0003o084Bo`000002o`290@;o0000
0_l0QPL00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03?ooooo000booooo`03o`000?oo
oooooooo01;ooooo0_l0001Hooooo`;o00000olYV@000ol0003o6I<0oaVC0002o`0000?o8IH000?o
0000o`n@0?l000000_lWV@000ol0003o5I80oaFB0002o`0000Co6I<000Go0000oa^D0?lKU03o6i@0
o`000002o`N=00;o00000_l7S@02o`0000Co1H`000?o0000o`>;0?l3R`000_l3R`001Ol0003o08T1
o`290Ol0R@7o000000?o08H700?o0000ooooooooool03Oooool2o`0003Cooooo000booooo`Go0000
3Oooool3o`0005Wooooo00?o0000ocVN0?l000000olYV@000ol0003o6I<0o`000002oc:L0005o`00
0?lQUP3o8IH0ob6F0?l000000olWV@000ol0003o5I80o`000002obfJ0005o`000?lIT`3o6I<0oaVC
0?l000000olKU0000ol0003o1hd0o`000002oabE00;o00000_lKU0000ol0003o1H`0o`F<0002o`00
00Co0h/000Go0000o`290Ol0R@7o08T1o`000004o`261`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0<Oooool004;ooooo1?l0001Iooooo`05o`000?liWP3o>Ih0ocVN0?l000000_lYV@02
o`0000?o<Y`000?o0000ob6F0?lQUP000_l00004obNI0005o`000?l]VP3o;IX0obfJ0?l000000_lI
T`02o`0000?o6i@00_l00003oabE0008o`000?lKU03o6i@0oa^D0?l0003o1H`0o`000?lIT`02o`00
00;o0h/00_l00002o`290@03o`000?l?T03o000000?o08H700?o0000ooooooooool03_ooool00ol0
003oooooooooo`0aooooo`00?oooool3o`0005cooooo0_l00003ocVN0005o`000?lYV@3o0000od>R
0?l000000olbW0000ol0003o8IH0o`000002ocZO0003o`000?lWV@3o9iT000;o00000ol]VP000ol0
003o6I<0o`000002oc2L0005o`000?lKU03o0000oc:L0?l000000olLU@000ol0003o6i@0oa^D0002
oa^D0003o`000?lIT`3o6I<000;o000000Co0h/0o`000?lETP3o5I800_l00002o`n@0003o`000?l0
QPOo08H700;o00004Oooool00ol0003oooooooooo`0`ooooo`00??ooool3o`0005kooooo00Co0000
odRT0?m8Y03o00000oliWP001Ol0003o@j80od>R0?m3XP3o000000;o<Y`00_l00003ocZO0003o`00
0?lWV@3o000000;o@:4000Go0000obfJ0?l]VP3o;IX0o`000003oc2L00;o00000_lbW0001_l0003o
79D0oabE0?l0003o<I`0o`0000?o6i@000Ko0000oaVC0?lIT`3o0000oaVC0?l00003oaFB0007o`00
0?l?T03o3i00o`n@0?l0003o08H7o`000002o`R=0003o`000?oooooooooo00oooooo00?o0000oooo
ooooool0;oooool003[ooooo0_l0001Oooooo`;o00000om8Y0000ol0003o>Ih0ocVN0002o`0000?o
@j8000Go0000oc:L0?l0003oC:D0o`000004ocZO0005o`000?m0X@3o@:40od2Q0?l000000_l]VP02
o`0000?o<9`000?o0000oc:L0?lbW0000_lbW002o`0000;o<I`000Oo0000oa^D0?lKU03o0000oc2L
0?l0003o6I<000?o00000olETP000ol0003o3i00o`n@0002o`n@0005o`000?l8S@3o28d0o`R=0?l0
00004Oooool00ol0003oooooooooo`0_ooooo`00=oooool3o`000003ooooool0003ooooo05gooooo
00?o0000oeNX0?l000000om8Y0000ol0003o>Ih0o`000002oeBW0005o`000?m3XP3o@j80od>R0?l0
00000om<Y@000ol0003o>Yl0ocZO0002o`0000?o@:4000Go0000obfJ0?l0003oA:80o`000002oc2L
00;o00001?lbW0001ol0003o<I`0oc6L0?laW03o0000oa^D0?l000000_l`W0001Ol0003o6I<0o`00
0?l/VP3o000000;o5I8000?o0000obNI0?l000000_l?T002o`0000;o28d00_l0000Booooo`03o`00
0?oooooooooo02kooooo000eooooo`;o00001Oooool00ol0003oooooooooo`1Jooooo`05o`000?mG
Z03oEjP0oeNX0?l000000om8Y0001Ol0003oE:L0oeBW0?mDY`3o000000;o@j800_l00003odbU0005
o`000?ljW`3o0000oe>W0?l000000om0X@02o`0000?oA:800_l00002odNS0003o`000?lbW03o<Y`0
00;o00001?laW0000ol0003o<9`0oc2L0002oc2L00;o00000_l/VP02o`0000;o9iT000?o0000o`n@
0?l000000_lQUP02o`0000;o69<000?o0000ooooooooool03oooool2o`0002oooooo000booooo`?o
0000Hoooool2o`0000?oEjP000?o0000odRT0?m8Y0000_l00003oeBW0003o`000?m3XP3o000000;o
GZX000Go0000odbU0?m<Y@3oC:D0o`000003oe>W00?o000000?oFJP0o`000?m4XP000_m4XP001ol0
003oAj<0odNS0?m7X`3o0000oc:L0?l000000_m8X`000ol0003o<I`0oc6L0002o`0000?o<9`00ol0
0002obbJ0003o`000?lWV@3o9iT000;o9iT000Go0000ob6F0?lQUP3o8IH0o`000004oaRC0003o`00
0?oooooooooo00oooooo00?o0000ooooooooool01oooool2o`0002Cooooo000`ooooo`;o0000IOoo
ool01?l0003oIJ`0ofF/0?l00002oeNX0003o`000?m8Y03o000000;oI:`000?o0000oeBW0?mDY`00
0_l00003oejZ0003o`000?m<Y@3oC:D000;o00000omCY`001Ol0003oFJP0oeVX0?mIZ03o000000;o
A:800_l00004odNS0009o`000?m8X`3oB:<0odRS0?l0003o<I`0o`000?m7X`3o000000;o<9`000Co
0000odBR0?l0003o;9X00ol00004obNI0005o`000?lQUP3o8IH0ob6F0?l000001?lHT`000ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00008oooool002go
oooo0ol00002ooooo`03o`000?oooooooooo063ooooo0_l00003ofF/0003o`000?mGZ03oEjP000;o
00000omT[0001Ol0003oE:L0o`000?m_[`3o000000?oGZX000Go0000odbU0?l0003oIZ`0o`000002
oe>W00;o00001?mIZ002o`0000;oG:X000?o0000odNS0?m7X`000_l00004odRS0004o`000?m7X`3o
Aj<0odNS00;o00000om4XP02o`0000;o@:4000?o0000obNI0?lWV@000_l00002ob6F0003o`000?lb
W03o000000;o69<00_l0000Cooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
8oooool002_ooooo0_l0001Wooooo`03o`000?mc/03o000000?oIJ`000Go0000oeNX0?l0003oLk00
o`000003ofB/00;o00000_m_[`001?l0003oGZX0oejZ0?mNZP02o`0000?oIZ`00_l00002off^0005
o`000?mIZ03oFJP0oeVX0?l000000omLZP000ol0003oAj<0o`000002oejZ0003o`000?m8X`3oB:<0
00;o00000om7X`000ol0003oA:80odBR0002odBR00;o00000_m0X@000ol0003o9iT0o`000002ocZO
00;o00000_lbW0000ol0003o69<0o`000002obRI0003o`000?oooooooooo013ooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool0000Sooooo`00:?ooool3o`0006Oooooo0_l00003og>`
0003o`000?mU[03oIJ`000;o00000_mc/0001_l0003oI:`0ofB/0?l0003oOk<0o`0000?oKjl00ol0
00000omh/@3o0000ofJ/0002ofJ/0005o`000?m][P3oKJh0off^0?l000000_mIZ002o`0000CoG:X0
00Wo0000oejZ0?mNZP3oGZX0o`000?m8X`3o0000oejZ0?l000000_m7X`02o`0000CoA:800_l00003
od2Q0005o`000?ljW`3o>Yl0ocZO0?l000001?lbW0001Ol0003o:9T0obRI0?lXV@3o000001?ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool0000Sooooo`009Oooool3o`0006Wooooo
00?o0000ognc0?l000000omc/0001Ol0003oIJ`0o`000?n2]03o000000?oLk000_l00002ognc0005
o`000?m_[`3oKjl0ofn_0?l000000omh/@000ol0003oIZ`0ofJ/0002o`0000?oKJh000?o0000oeVX
0?l000000_ma/0000ol0003oG:X0oebZ0002o`0000CoGZX000Co0000oejZ0?mNZP3oGZX00_l00002
oebY0006o`000?m4XP3oA:80o`000?mIZ03o00000_m0X@02o`0000?o>Yl000?o0000oc:L0?lbW000
0_lbW0001Ol0003o:9T0obRI0?lXV@3o000001Cooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Sooooo`008oooool2o`0000?ooooo00?o0000ooooooooool0I?ooool2o`0000;o
Ok<000Co0000og>`0?mc/03oLk000_l00002oh:d0003o`000?mc/03oLk0000;o00001?mo/`001?l0
003oKjl0o`000?l00004ogRa00;o00000_n0/`000ol0003oKJh0off^0002o`0000?oLK0000?o0000
oebZ0?l000000_md/0000ol0003oGZX0oejZ0002o`0000?oGZX000Oo0000oebY0?mLZ@3oG:T0o`00
0?m4XP3o000000;oFJP000Go0000od2Q0?l0003oDjL0o`000002ocZO0003o`000?m<Y@3o000000;o
<Y`000Oo0000od>R0?l0003o:9T0o`000?lhWP3o000001;ooooo0_l00005ooooo`;o00009?ooool0
023ooooo0ol0001[ooooo`03o`000?n;]`3o000000?oOk<00ol000000on@^03o0000oh:d0002oh:d
00;o000000?oSkP0o`000?mo/`000omo/`02o`0000;oR[H000?o0000ogRa0?mh/@000_l00003oh2c
0005o`000?m][P3o0000ohJe0?l000001?ma/0002Ol0003oM;00ogB`0?md/03o0000oejZ0?l0003o
MK40o`000002oejZ00;o00001?mLZ@001?l0003oFJP0oeVX0?mIZ002o`0000?oDjL00_l00002odbU
0003o`000?lbW03o000000;o@j8000Go0000obRI0?l0003o>9h0o`00000Dooooo`03o`000?oooooo
oooo02Sooooo000Nooooo`;o0000K?ooool2o`0000;oRkL000?o0000ognc0?mo/`000_l00003oi2h
0003o`000?n2]03oP[@000;o00000on?^0000ol0003oOk<0ognc0002o`0000?oR[H000Go0000ogRa
0?l0003oT[P0o`000004oh2c0005o`000?n6]@3oQ[D0ohJe0?l000000_ma/002o`0000?oM;000_l0
0003ogFa00;o00000_md/0000ol0003oG:T0oebY0002o`0000;oFJP00ol00003oe>W0003o`000?m<
Y@3oC:D000;oC:D000Co0000od>R0?m3XP3o@j800_l00003ocRN0003o`000?oooooooooo01;ooooo
00?o0000ooooooooool09oooool001_ooooo1Ol0001Zooooo`;o000000?oU[T0o`000?n;]`000_n;
]`02o`000003oibk0?l0003oT;P000?oT;P00_l000000onN^`3o0000ohnh0002ohnh0005o`000?mo
/`3o0000oi^j0?l000001?n:]P001Ol0003oT[P0oi:h0?nB^03o000000;oP;<00_l00003ohJe0005
o`000?ma/03o0000ohVf0?l000000_md/0000ol0003oRkL0o`000003ogFa0008o`000?md/03oM;00
ogB`0?l0003oG:T0o`000?ma/006o`0000;oDjL00_l00003odbU00;o00000_m3XP000ol0003oE:L0
o`000002ocRN00;o00005?ooool00ol0003oooooooooo`0Wooooo`006_ooool2o`0006cooooo0_l0
0003oiJi0003o`000?n;]`3oRkL000;o00000onL^`000ol0003oT;P0oi2h0002o`0000?oW[/000?o
0000ohnh0?n?^0000_l00003oi^j0003o`000?n:]P3oR[H000;o00000onB^0000ol0003oP;<0o`00
0002oiVj0003o`000?n6]@3oQ[D000;o00000on9]P02o`0000;oRkL000?o0000ogFa0?me/@000_l0
0004ogB`00?o00000_ma/0000ol0003oKJh0off^0003o`0000;oIZ`000?o0000odbU0?l000000_mN
ZP02o`0000?oE:L00_l00002odRS0003o`000?oooooooooo01;ooooo00?o0000ooooooooool09_oo
ool001[ooooo00?o0000ooooool00000J_ooool00ol0003oX;`0o`000004oiJi00;o000000?oZ;h0
o`000?nL^`000_nL^`001Ol0003oT;P0o`000?n/_P3o000000?oW[/000Go0000ohnh0?l0003oZ[h0
o`000003oi^j0003o`000?n:]P3o000000;oY;d000?o0000oi:h0?nB^0000_l00003oiVj0005o`00
0?n6]@3o0000oijk0?l000000_n9]P02o`0000CoRkL00_l00002oh^g00Go00000oma/002o`0000?o
KJh000?o0000ofJ/0?mV[0000_mV[0001Ol0003oGZX0oejZ0?mNZP3o000000CoE:L000?o0000odRS
0?m8X`000_m8X`000ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Gooooo000Jooooo`04
o`000?ooooooooooo`0006Oooooo0_l00003oj2l0003o`000?nF^@3oU[T000;o00000onX_P000ol0
003oW;/0oibk0002o`0000?o[;h000?o0000oijk0?nN^`000_l00003ojZn0003o`000?nK^P3oVkX0
00;o00000onT_@001Ol0003oT[P0o`000?n/_P3o000000CoVKX000Co0000oijk0?nN^`3oW[/00_l0
00000onQ_03o0000oh^g0002oh^g00;o000000KoRkL0o`000?l0003o0000ogB`0?l00002ohVf0005
o`000?ma/03o0000ohFe0?l000000_m][P03o`0000;oIZ`00_l00003oejZ0003o`000?mDY`3oE:L0
00;oE:L000?o0000odRS0?m8X`000_m8X`000ol0003oooooooooo`0Booooo`;o00009_ooool001[o
oooo0_l00002ooooo`03o`000?oooooooooo067ooooo0ol000000onY_P3o0000oj2l0002oj2l0005
o`000?nF^@3o0000ok?10?l000000onX_P001Ol0003oW;/0o`000?ni`P3o000000?o[;h000Go0000
oijk0?l0003o^L80o`000003ojZn0005o`000?nK^P3o0000okG10?l000001?nT_@001Ol0003o[;h0
ojbn0?n/_P3o000000;oVKX00_l00003oijk0006o`000?nQ_03oXK`0oj6l0?l0003oRkL01?l00002
oh^g00;o00001?n9]P001?l0003oQKD0ohFe0?n5]@02o`0000;oP;<000Go0000ofJ/0?l0003oN;40
o`000002oejZ0003o`000?m_[`3o000000;oE:L000?o0000ofB/0?l000000_m8X`000ol0003oEjP0
o`00000Cooooo`;o00009_ooool000[ooooo1Ol00003ooooo`;o00001Oooool2o`000005o`0B;?l0
003oooooooooool00000HOooool00ol0003o/L00o`000003ojVn0003o`000?nP_03oX;`000;o0000
0onc`@000ol0003oZ;h0ojRn0002o`0000?o^L8000?o0000ojbn0?n/_P000_l00003okW20003o`00
0?nZ_P3oZ[h000;o00000one`@000ol0003oY;d0ojBm0002o`0000?o[;h000Go0000oiVj0?l0003o
/L00o`000002oijk00;o00000onQ_003o`0000;oX[`000Go0000oh^g0?l0003oXK`0o`000003ohVf
00;o00000on5]@000ol0003oP;<0oh2c0002oh2c0004o`000?mh/@3oN;40ogRa00;o00000_m_[`00
0ol0003oE:L0o`000002ofB/0003o`000?m8X`3o000000;oEjP000?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Sooooo`002oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00Co0000ooooool0003o00000oooool00ol0003oooooooooo`1Looooo`;o0000
0ona`0002?l0003oZKh0ojVn0?l0003oX;`0o`000?nm``3o00000onc`@001Ol0003oZ;h0o`000?o4
a03o000000?o^L8000Go0000ojbn0?l0003oaL<0o`000003okW20005o`000?nZ_P3o0000olC40?l0
00000one`@001Ol0003oY;d0o`000?nm``3o000000?o[;h00_l00003ok7000;o00000_ne`@05o`00
00CoX[`000Wo0000oj6l0?nQ_03oXK`0o`000?n9]P3o0000oijk0?l000000_n5]@02o`0000?oP;<0
0ol00002ogRa0003o`000?m_[`3oKjl000;oKjl000?o0000ofB/0?mT[0000_mT[0001Ol0003oEjP0
oeNX0?mGZ03o000001Gooooo00?o0000ooooooooool08oooool000Cooooo1Ol00003ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool5o`0000?ooooo00?o0000oooooooo
ool0F_ooool00ol0003o^L80o`000003ok700003o`000?nY_P3oZKh000;o00000onm``000ol0003o
/l40ok?10002o`0000?oa<@000?o0000okW20?ni`P000_l00003olG30003o`000?ni`P3o^L8000;o
00000oo4a0000ol0003o]L40okG10002o`0000?o_L<00ol000001?o4a03o0000ok700?na`002o`00
0006okG10?l0003o0000o`000?nQ_03o00000_ng`@000ol0003oX[`0oj:l0002o`0000?oXK`00_l0
0003oijk00;o00000_nI^P001_l0003oP;<0o`000?nB^03o0000ogRa00?o00000om_[`02o`0000?o
I:`00_l00002oeNX0003o`000?mU[03o000001Gooooo00?o0000ooooooooool08_ooool000gooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0
003o018/0_l00003ooooo`03o`000?oooooooooo05Oooooo0_l00003okW20008o`000?na`03o/L00
o`000?nY_P3o0000olG30?l00003okg30005o`000?nc`@3o0000olNn0?l000000oo4a0001Ol0003o
^L80o`000?o8_03o000000?oaL<000Go0000okW20?l0003ob;`0o`000003olC40005o`000?ne`@3o
0000olNo0?l000000_nm``02o`0000Coa<@01Ol00003okG10009o`000?ng`@3o]l40okO10?l0003o
X[`0o`000?ng`@3o000000;oXK`000?o0000okG10?l000000onN^`000ol0003oVKX0oiVj0002oiVj
0004o`000?nB^03oT[P0oi:h00;o00000_n:]P000ol0003oKjl0o`000002ognc0003o`000?mT[03o
000000;oLk000_l00002ofF/0003o`000?oooooooooo01?ooooo00?o0000ooooooooool08_ooool0
00[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooool000001?l00003ooooo`03o`000?oooooooooo05?ooooo0ol000000ono``3o0000okW2
0002okW20003o`000?na`03o/L0000;o00000oo5``000ol0003o_L<0okg30002o`0000?oakh000?o
0000olC40?o4a0000_l00003olRl0003o`000?o5``3oaL<000;o00000_o8_0001?l0003oa<@0olC4
0?o4a002o`0000?oakl00_l000000oo8^`3o0000olC40002olC400?o00000_o5`P000ol0003o]L40
okG10002o`0000Co]l4000Co0000okO10?ng`@3o]l400_l00002okG10003o`000?nN^`3oW[/000;o
00000onI^P02o`0000?oT[P000?o0000ohZf0?l000000_n:]P000ol0003oOk<0ognc0002ognc0005
o`000?mc/03oLk00og>`0?l000000omU[0000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
027ooooo000:ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003
ooooo`;o000000?oooooo`000?l093T00_l000000ol0>dGo0000ooooo`02ooooo`03o`000?oooooo
oooo057ooooo00?o0000olC40?l000000ono``000ol0003o^L80okW20003o`000003olNo0?l0003o
aL<000;oaL<000Go0000okg30?l0003obKT0o`000003olNn0005o`000?o4a03o0000ol^f0?l00000
0oo8_0001Ol0003oaL<0o`000?o;]@3o000000?ob;`00ol000001?o:]`3o0000olNo0?o7_`02o`00
00?ob;/01Ol00003olG20003o`000?ne`@3o000000;oa/4000?o0000okO10?ng`@000_l00002okO1
00;o00001?ne`@02o`0000;o/L0000Go0000oiVj0?l0003o[;h0o`000002oi:h00;o00000_n:]P03
o`0000?oOk<00_l00002og>`00;o00000_mU[0000ol0003oL[00o`00000Eooooo`;o00008_ooool0
00_ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`02o`000004o`0T>Ol0003o0000
o`0000?ooooo00?o0000ooooooooool0C_ooool2o`0000?oa<@000So0000oko30?no``3o0000okW2
0?l0003ob;/0o`0000?oakl000?o0000olG30?o5``000_l00003olVi0003o`000?o7_P3oakh000;o
00000_o;]P001?l0003ob;`0olRl0?o8_002o`0000;obkD000?o0000olRl0?o8_0000_l00004olZg
00;o000000?oc;80o`000?l000000ol000001Oo4a03o0000olVh0?o9^03o000000;oaL800_l00003
olK10003o`000?ng`@3o000000;oa/000_l000000oo6`@3o0000okG10002okG100;o00001?na`000
1?l0003o[;h0ojbn0?n/_P02o`0000;oY;d000?o0000ohZf0?l000000_nJ^P000ol0003oOk<0o`00
0002ohng00;o00000_n2]0000ol0003oIJ`0o`000002og:`0003o`000?oooooooooo01?ooooo00?o
0000ooooooooool08?ooool001Sooooo0_l00002ooooo`Go000000?o055=o`000?ooool00_ooool0
0ol0003oooooooooo`1:ooooo`?o000000?oaL80o`000?o4a0000_o4a0000ol0003o_l<0oko30002
o`0000?ob;/000?o0000olNo0?o7_`000ol000000oo;]03o0000olVi0002olVi0005o`000?o7_P3o
0000olf`0?l000000oo;]P03o`000003olj^0?l0003obkD000;obkD00_l000000oo=[`3o0000olZg
0002olZg00Ko00000_o8^`02o`0000?obKP000Go0000olG20?l0003ob[H0o`000003olK100;o0000
0oo6`0002Ol0003oa/40olK10?o6`@3o0000okG10?l0003oaL80o`000003ok7000;o00000_n/_P02
o`0000CoY;d000Co0000oiZj0?l0003oV[X00_l00003ohng0003o`000?n2]03oP[@000;oP[@000Go
0000og:`0?mb/03oL[00o`00000Fooooo`03o`000?oooooooooo01oooooo000Hooooo`06o`000?oo
ooooooooooooool0003o02@i0_l000001?l0>dGo0000o`000?l00003ooooo`03o`000?oooooooooo
04Kooooo0ol000000oo6`@3o0000olG20002olG20003o`000?o4a03oa<@000?o000000?ob[P0o`00
0?o8^`000_o8^`001Ol0003oakl0o`000?o=/03o000000?obk@000?o0000olVi0?o9^@000_l00002
olf`0003o`000?o;]P3obkH000;o00000oo>[P000ol0003obkD0ol^e0002o`0000?ocJl000?o0000
olZg0?l000000_l00003olbb0005o`000?o8^`3o0000olf^0?l000000oo9^002o`0000?ob[H000Go
0000olK10?l0003obkD0o`000002olK000;o00001?o6`@001ol0003oaL80olG20?o5`P3o0000ok70
0?l000000_o4a002o`000003okg30?l0003oY;d000;oY;d00_l00002oiZj0003o`000?nZ_P3o0000
00;oSkL00_l00003oh:d00;o00000_mb/0000ol0003oOk<0o`00000Fooooo`03o`000?oooooooooo
01kooooo000Hooooo`04o`000?ooooooooooooooo`Oo000000?o05]7o`000?l000000_ooool00ol0
003oooooooooo`12ooooo`?o000000?oakl0o`000?o6`@000_o6`@002?l0003oaL80olG20?l0003o
a<@0o`000?o;]@3o00000oo:^0000ol0003ob;/0olRk0002o`0000;ocK0000Wo0000ol^d0?o;]03o
bk@0o`000?o9^@3o0000olnZ0?l000000oo=/002o`000003om2W0?l0003ocZh000?ocZh00_l00000
1?o@Y`3o0000olf_0?o=[`03o`0000?ocjT000?o0000olbb0?o</P000_l00003olf^0005o`000?o9
^03o0000olj/0?l000000oo:]P02o`0000?obkD00_l00002ol^e0003o`000?o6`@3oa/4000;o0000
0oo5`P02o`0000?oa<@000Oo0000okg30?nm``3o_L<0o`000?nT_@3o000000;o]<400_l000000onZ
_P3o0000ojZn0002o`0000;oW[/000?o0000oh:d0?l000000_n?^002o`0000;oOk<000?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Nooooo`006?ooool2o`0000?ooooo0ol000000ol0DDgo
0000o`1AC@02o`000005o`1U?_l0003oooooooooool00000@_ooool00ol0003oakh0o`000003olNo
0004o`000?o6`@3oa/40o`0000;oaL800_l00003ol^e0008o`000?o:^03ob[P0o`000?o8^`3o0000
olj/0?l00003olf`0003o`000?o;]03o000000;o00000_o?ZP000ol0003ocK00olf`0002o`0000?o
d:L000?o0000olj^0?o>[P000_l00002om2W00Co000000?odZ40o`000?o?Z@000_o?Z@001Ol0003o
c;80o`000?oAY@3o000000?ocJh00_l00003olj/00?o000000CocjX0o`000?o;]@3obkD00_l00003
ol^e0003o`000?o6`@3o000000;ob[H000Go0000olG20?l0003obKP0o`000002olC400;o00001?nm
``001Ol0003o]<40okC10?nd`@3o000000;oZ[h000?o0000ojZn0?l000001?nN^`001Ol0003oSkP0
ohnh0?n?^03o000000?oOk<000?o0000ooooooooool05Oooool00ol0003oooooooooo`0Mooooo`00
6?ooool00ol0003oooooooooo`02ooooo`;o000000?o03]6o`000?l000000ol000000ol0ICko0000
o`000002ooooo`;o0000?_ooool2o`0000?oakh000Co0000olNo0?o7_`3o00000_o6`@03o`000003
olbb0?l0003obkD000;obkD000?o0000olZh0?o:^0000_l00002olj/0003o`000?o=/03ocK0000?o
00000_oAY@001?l0003ocjX0olnZ0?o?ZP02o`000003om:Q0?l0003od:L000;od:L000Co0000olj^
0?l0003odj000ol000000oo@Y`3o0000o`000003om:Q0003o`000?o?Z@3ocjT000;o00000ooAY@00
1Ol0003ocJh0o`000?oBXP3o000000;ocZ`00_l00004olnZ00;o000000?ocjX0o`000?o;]@000_o;
]@02o`0000Cob[H000Co0000olVh0?o9^03obKP00_l00002olRk0003o`000?nm``3o_L<000;o0000
0_nd`@02o`0000?oZ[h00_l00003oijk00;o00000_n?^002o`0000;oOk<000?o0000oh^g0?l00000
5oooool00ol0003oooooooooo`0Looooo`006?ooool00ol0003oooooooooo`02ooooo`05o`000?l0
>dGo0000o`000?l0DDd01?l000000ol0ICko0000o`000002o`000003ooooool0003ooooo03Wooooo
0ol000000oo7_P3o0000olNn0002olNn0003o`000?o7_`3oakl000?o000000?oc;40o`000?o</P00
0_o</P000ol0003obkD0ol^e0003o`000003om2X0?l0003ocZ`000;ocZ`00_l000000ooBX@3o0000
om6U0003om6U0004o`000?o?ZP3o0000o`0000?odZ4000?o0000om2W0?o@Y`001_l000001?o@Y`3o
0000omFJ0?l00003om:Q0005o`000?o?Z@3o0000omBL0?l000000ooAY@02o`0000?odZ800_l00000
0ooCX03o0000olnZ0002olnZ00;o00000oo?ZP001Ol0003obkD0o`000?o?ZP3o000000?ob[H00_l0
0003olVh0007o`000?o8^`3ob;/0olRk0?l0003o_L<0o`000002olJo00;o00000_o4a0001?l0003o
Z[h0o`000?ni`P02o`000004oijk0?l0003o[;h0ojbn00;o00000_nL^`02o`0000?oRkL000?o0000
ooooooooool04oooool2o`0001kooooo000Gooooo`?o00001?ooool6o`000003o`1V??l0003o0000
00;o00000_l0MbD3o`0003?ooooo1_l000000oo7_P3o0000olNn0002olNn0003o`000?o7_P3oakh0
00?o000000?ocJl0o`000?o</@000_o</@000ol0003oc;80olbb0003o`000003om6U0?l0003od:P0
00;od:P000Co0000olj/0?l0003o00000ooBX@000ol0003odJD0om6U0003o`000003omBL0?l0003o
dZ4000;odZ401Ol00003om>P00;o00000ooEVP000ol0003odZ40om:Q0002o`0000?oe9`000Go0000
om6U0?l0003oeIT0o`000002om:R00;o00000ooCX0001Ol0003ocjX0o`000?oCW`3o000000?ocjX0
0_l00003olnZ0005o`000?o:]P3o0000olj/0?l000000_o9^002o`0000?ob;/00_l00003olJo0003
o`000?o4a03oa<@000;oa<@000Co0000okW20?ni`P3o^L800_l00003ojbn0005o`000?nL^`3oW;/0
oibk0?l000000on;]`02o`0001Oooooo00?o0000ooooooooool06oooool000Wooooo0ol00003oooo
o`?o00001Oooool00ol0003oooooooooo`04ooooo`?o000000?o05e6o`000?l0G4H00_l000001ol0
L33o0000o`1^<_l0003o07LUo`000?l0OaH00_l0000`ooooo`;o000000Goa/40o`000?o7_`3oakl0
o`000003olNn0003o`000?o7_P3oakh000?o000000?ocJl0o`000?o=[`000_o=[`002?l0003oc;40
olba0?l0003oc;80o`000?oAX`3o00000_oAY@000ol0003od:P0om2X0003o`000003omBM0?l0003o
dZ4000;odZ4000Go0000om6U0?l0003oeYL0o`000003omBL0003o`000?oBX@3o000000;o00000ooE
V@001Ol0003odj00o`000?oGTP3o000000?oeIX000Go0000om:Q0?l0003oei@0o`000003omBL00;o
00000ooEV@02o`000003omJF0?l0003odj0000;odj000_l00003om>O0005o`000?o?ZP3o0000om>O
0?l000000oo?ZP02o`0000?ocZ`00_l00002olf_0005o`000?o8^`3o0000olbb0?l000000_o6_`02
o`0000?oa<@00_l00002okW200?o00000_n/_P02o`0000;oW;/000Go0000ojRn0?l0003oRkL0o`00
0002oiJi0003o`000?oooooooooo01Gooooo00?o0000ooooooooool06_ooool000[ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003o055=o`000?l0003o05e600;o000000?o06Hlo`000?l0L3000_l000001Ol0MbGo0000
o`1o5_l0003o08H700?o0000:_ooool3o`000005olG20?l0003oa/40olK10?l000000_o7_`000ol0
003oakh0olNn0003o`000003olf^0?l0003ocJl000;ocJl000Co0000olf_0?o=[`3o00000_o</@02
o`0000;odJ<000Co0000om6U0?oAY@3odJD00_l000000ooEV@3o0000omBM0002omBM0003o`000?oB
X@3odZ4000;o00000ooFU`000ol0003oe9`0o`000002o`0000?oei<000?o0000omFI0?oEV@000_l0
0003omNB0003o`000?oEVP3oeIX000;o00000ooGU003o`000004omR@0?l0003oeIT0omFI00;o0000
0ooFUP001Ol0003odj00o`000?oGU@3o000000?odil00_l00003om>O00?o000000Codj00o`000?o>
[03ocZ`00_l00004olf_0004o`000?o</P3oc;80olbb00;o00000_o:]`000ol0003oa<@0o`000002
olRm00;o00000_o5``03o`0000;o^<800_l00003ojRn0005o`000?nF^@3oU[T0oiJi0?l000005ooo
ool00ol0003oooooooooo`0Jooooo`000_ooool5o`0000?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`;o00001_ooool3o`000003o`1MA_l0003o06Lk00;o000000Oo070`
o`000?l0NB7o0000o`1g9Ol0003o07lF00;o00000_l8S@02o`0002;ooooo1_l000001Oo4a03o0000
olG20?o5`P3o000000;oa/4000?o0000olNo0?o7_`000ol000000oo=[`3o0000olf^0002olf^0004
o`000?o=[`3ocJl0o`0000;ocJl00ol000000ooBX@3o0000om6S0002om6S0004o`000?oAY@3o0000
o`0000?oeIT000?o0000omBM0?oDW@000ol000001?oGTP3o0000omJG0?oFU`04o`000003omV>0?l0
003oei<000;oei<000Go0000omFI0?l0003ofH`0o`000003omNB0005o`000?oEVP3o0000omV=0?l0
00000_oGU002o`0000Cof9000_l000000ooIS@3o0000omJF0002omJF00;o00000ooGU@001Ol0003o
dil0o`000?oGU03o000000;odil00_l00004om>P00;o000000?odZ80o`000?o=[`000_o=[`02o`00
00;oc;800_l00003olZg00;o00000oo8_@000ol0003oaL<0olG30002olG30005o`000?nh`P3o^<80
okS20?l000000onX_P02o`0000;oU[T000?o0000oj2l0?l000005oooool00ol0003oooooooooo`0I
ooooo`002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool2o`000004o`1LA_l0003o0000o`1W>`;o000000?o070`o`000?l0NB400ol00000
1ol0OaKo0000o`261ol0003o28d0o`000?lIT`001Ol0000Jooooo`?o000000Go^L80o`000?no``3o
_l<0o`000002olC40006o`000?o5`P3oaL80olG20?l0003oa/400ol000000oo=[`3o0000olf_0002
olf_0004o`000?o=[P3ocJh0o`0000;ocJl00ol000000ooCX03o0000om:Q0002om:Q0003o`000?oA
X`3o000000;o000000?oeYL0o`000?oEV@000_oEV@001Ol0003oe9d0o`000?oISP3o000000;oei80
0ol000000ooFU`3o0000o`000003omV>0003o`000?oGT`3oei<000;o00000ooIS0000ol0003oei80
omNB0002o`0000?ofHd00_l000000ooKR03o0000omR@0002omR@00;o00000ooIS@001Ol0003oeYH0
o`000?oJR`3o000000CoeiD000Co0000omND0?oGU03oei@00_l000000ooGU@3o0000om>P0002om>P
00;o00000ooBXP000ol0003ocJl0o`000002om6U00;o00000_o?Z@001Ol0003ob[L0o`000?o=[`3o
000000;ob;d00_l00003olG300?o000000Ko^<80o`000?o4a03o0000ojRn0?l00002ok?000;o0000
0onP_0000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Sooooo000:ooooo`04o`000?oo
ooooooooooooo`Co00001Oooool00ol0003oooooooooo`05ooooo`03o`000?l0DDgo000000Co0000
00?o074^o`000?l0L3000_l000002_l0PA;o0000o`000?l0003o08H7o`000?l8S@3o0000oaVC0?l0
0002obVI0003o`000?liWP3o000000Oo00001oooool;o`000003ok700?l0003o^L8000;o^L8000Co
0000oko30?no``3o00000_o4a0000ol0003oaL80o`000002o`000003olba0?l0003ocJl000;ocJl0
00Co0000olf_0?o=[`3o00000_o=[P03o`000003om>O0?l0003odj0000;odj0000?o0000om:Q0?l0
00000_l000000ooGU03o0000omJG0002omJG0003o`000?oEV@3oeIT000;o00000_oISP03o`000006
omNB0?l0003o0000o`000?oJR@3o00000ooISP03o`000003om^60?l0003ofH`000;ofH`00ol00000
1?oKQP3o0000omV=0?oIS@02o`0000?ofhP000Go0000omR@0?l0003og8D0o`000003omV=00;o0000
0ooJR`000ol0003oeiD0omNE0002o`0000;oei@00_l00003omNE0005o`000?oCX03o0000omJF0?l0
00000ooBXP02o`0000;odJD00_l00004olnY0004o`000?o=[`3ocJl0olf_00;o00000_o;]@000ol0
003oaL<0o`000002olRl00;o00000oo4a0001Ol0003o/l00ok?00?nc`03o000000CoX;`000?o0000
ooooooooool05?ooool2o`0000Sooooo0ol0000?ooooo`002Oooool2o`0000?ooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo1?l000000ol0Ic_o0000o`1W>`04o`000003o`1i8Ol0003o0000
00;o08T10_l00002o`R=0007o`000?lIT`3o0000obVI0?l0003o>Ih0o`000002odRT0003o`000?mG
Z03o000000;oIJ`01ol000001On;]`3o0000oiJi0?nF^@3o000000;oX;`000?o0000ojVn0?l00000
0ona`0001?l0003o^L80okW20?l00002oko30003o`000?o4a03o000000;o000000?oc;80o`000?o<
/@000_o</@001?l0003ocJl0olf_0?l00002olf_00?o000000Godil0o`000?oCW`3odil0o`000002
om>P00?o000000?oei80o`000?oGU0000_oGU0000ol0003oeYL0omJG0003o`00000:omZ;0?l0003o
0000o`000?oISP3o0000omNB0?l0003og8D0o`0000?ofXT000Go0000omV>0?l0003ogH40o`000003
om^600?o000000?ogGl0o`000?oKQP000_oKQP02o`000003omf10?l0003ofhP000;ofhP00_l00003
omb50005o`000?oIS@3o0000omf20?l000000ooJR`000ol0003oeiD0o`000002omZ:00;o000000?o
fXX0o`000?oGU@000_oGU@02o`0000?oeYH000Wo0000om:R0?l0003oeIT0o`000?oAY@3o0000omBM
0?l000000oo?Z@02o`0000;ocJl00_l00003ol^e00;o00000_o8_003o`0000;oa<@00_l00002ok?0
00;o00000onP_0000ol0003oZKh0o`00000Gooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00000>ooooo`002_ooool01?l0003oooooooooooooool5o`0000?ooooo00?o0000
ooooooooool01oooool2o`000003o`1LA_l0003o000000?o000000Wo07XOo`000?l0003o0000o`21
4_l0003o08T1o`000?l?T0001Ol00002obVI0005o`000?liWP3o0000odRT0?l000000_mGZ0000ol0
003oIJ`0o`000002og>`0003o`000?mo/`3o000000?oRkL000Ko0000oiJi0?nF^@3o0000oj2l0?l0
0002ojVn0004o`000?na`03o/L00o`0000;o^L801Ol000000oo;]@3o0000olbb0002olbb0004o`00
0?o</@3oc;40o`0000;ocJl00ol000001OoCW`3o0000om>O0?oCW`3o000000?odil00_l000000ooH
T@3o0000omNB0002omNB0003o`000?oGU03oei@000?o000000?ofhP0o`000?l000000ol00002omV>
00;o00000ooLQ@000ol0003ofXT0omZ90002o`0000?ogH4000Co0000om^60?l0003o00001?oMO`00
1?l0003ofhH0o`000?l00003omf10005o`000?oKR03o0000omim0?l000000ooLQ@02o`0000?ogH80
00?o0000omZ;0?l000000_l00002omZ:00;o00000ooJRP001Ol0003oeiD0o`000?oJR`3o000000?o
eYH00_l00003omFI0007o`000?oDW@3oe9d0omBM0?l0003ocjT0o`000002om:Q00;o00000_o@Y`00
1ol0003obkD0o`000?o=[P3o0000olRl0?l000000_o;]P03o`0000;oakl00_l00002okg30003o`00
0?nP_03o000000;oZKh000?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00cooooo000Fooooo`03o`000?oooooooooo00Oooooo1?l000001?l0Ic_o0000o`00
0?l0LBh2o`00000:o`233_l0003o0000o`000?l0R@7o0000o`n@0?l0003o8IH0o`0000;o<Y`00ol0
00001oliWP3o0000odRT0?m8Y03o0000oeNX0?l000000_mU[0000ol0003oLk00o`000002ognc0004
o`000?n;]`3oRkL0o`0000;oU[T000Go0000oj2l0?nP_03o0000ojVn0006o`000005olRk0?l0003o
b[P0olZh0?l000000_o;]@001?l0003oc;80olbb0?l00002olba00?o000000Godj00o`000?oCW`3o
dil0o`000003om>O0004o`000?oCW`3o0000o`0000?of94000Oo0000omNB0?oGTP3o0000omND0?l0
003ofhH000Go00000_oJR`03o`000003omf10?l0003og8D000;og8D00ol000001?oNO03o0000omf1
0?oMP@03o`000003ommj0?l0003ogGl000;ogGl00ol000000ooONP3o0000omf10002omf100;o0000
0ooNO@001Ol0003og8D0o`000?oONP3o000000;ogH800ol00002omf10005o`000?oJRP3o0000omf0
0?l000000ooJRP02o`0000?ofX/000Go0000omJF0?l0003ofHd0o`000002omFI00;o00000ooDW@02
o`0000?odZ4000?o0000om2W0?o@Y`000_o@Y`001Ol0003ocJh0olf^0?o=[P3o000000CobkH00_l0
0002olNo0003o`000?nm``3o_L<000;o_L<000?o0000ojVn0?nY_P000_l0000Hooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03?ooool001Kooooo0_l00009ooooo`So000000?o07XO
o`000?l000000_l3R`03o`000007o`n@0?l0003o8IH0o`000?lbW03o0000od>R0008o`0000;oIJ`0
00Ko0000og>`0?mc/03o0000ognc0?l00002oh^g0003o`000?nF^@3oU[T000Go000000GoaL<0o`00
0?o7_`3oakl0o`000002olRk0007o`000?o:^03ob[P0olZh0?l0003obkD0o`000002olbb00?o0000
00?odZ40o`000?oCX0000_oCX0001Ol0003odil0om>O0?l0003odil000?o000000?of900o`000?oH
T@000_oHT@000ol0003oei80omNB0006o`0000;ofhP00ol000000ooNO@3o0000omf10002omf10005
o`000?oLQ@3o0000on1h0?l000000ooNO002o`000003on5d0?l0003oggX000;oggX000Go0000omeo
0?l0003ohG@0o`000003ommj0005o`000?oMP@3o0000on5f0?l000000ooNO@02o`0000?oggX00_l0
00000ooPN03o0000omf10002omf100;o00000ooMP0001Ol0003ofXX0o`000?oMP@3o000000?ofX/0
0_l00003omV=00;o00000_oHT0001Ol0003oe9d0o`000?oGU03o000000;odZ400_l00003om2W00;o
00000_o=[P02o`0000?obkH00ol000000oo7_`3o0000o`000003okg300;o000000GoZKh0o`000?na
`03o/L00o`00000Hooooo`03o`000?oooooooooo00;ooooo1?l0000?ooooo`005_ooool00ol0003o
ooooooooo`08ooooo`?o000000?o074^o`000?l0LBh01?l000001Ol0P`ko0000o`>;0?l0003o5I80
00?o000000Ko8IH0o`000?lbW03o0000od>R0?l00002oeBW0003o`000?mT[03o000000;oLk003Ol0
00001?nc`@3o0000okg30?l00003olG30004o`000?o7_`3oakl0o`0000;ob;/000?o0000olZh0?l0
00001Ol000000ooAX`3o0000om:Q0002om:Q0005o`000?oCX03odj00o`000?oCW`000ol000000ooH
T03o0000omR@0002omR@0003o`000?oHT@3of94000Go00000ooKQP001Ol0003ofhP0o`000?oON`3o
000000?ogWd000?o0000omf10?oMP@000_l00003on1h0004o`000?oNO03o0000o`0000?ohG@000?o
0000ommj0?oONP000_l00003on5d0003o`000?oONP3oggX000;o00000ooQMP001Ol0003ogWd0o`00
0?oRLP3o000000;oggX00_l00003on1h0005o`000?oMP@3o0000on1g0?l000000ooMP002o`0000?o
gH400ol000001?oMPP3o0000omV=0?oIS@02o`0000?of9000_l00003omND00;o00000_oEVP000ol0
003od:L0o`000002om:P00;o00000_o@Y`000ol0003obkH0o`000002olf`00;o00000_o9^@000ol0
003o_L<0o`000002olG40003o`000?na`03o/L0000;o00006Oooool01Ol0003ooooooooooooooooo
000001;ooooo000Fooooo`03o`000?oooooooooo00Sooooo00Go0000o`1U?_l0003o0000o`1a;P03
o`0000;o08@<0_l000001?l3R`3o0000oaFB0?l00002obNI00;o00000_lbW0000ol0003o@j80o`00
0002oeBW0005o`000?mT[03o0000og>`0?l000000_n2]0000ol0003oT;P0o`000002oibk0004o`00
0?nX_P3oZ;h0o`0000;o/l4000Co0000okg30?nm``3o00000_o5``001Ol0003oakl0olNo0?l0003o
b;/000?o000000God:P0o`000?oAY@3odJD0o`000003om6S0004o`000?oBX@3odZ40o`0000;odj00
0_l000000ooHT03o0000omR@0002omR@0003o`000?oHT03of90000Go00000ooLQ0000ol0003ofhH0
om^60002o`0000?ogg/000?o0000omim0?oNO@000ol000001?oQM03o0000on1h0?oPN003o`000003
on9`0?l0003ohG@000;ohG@00ol000000ooSKP3o0000on5d0002on5d00?o000000?ohfl0o`000?oQ
MP000_oQMP02o`0000?ohW800_l000000ooRL03o0000on1h0002on1h00;o00000ooPM`001Ol0003o
gH00o`000?oPM`3o000000;ogH400_l00004omf200;o00000_oLQ@001Ol0003of900o`000?oKR03o
000000;oei@00_l00003omFJ00;o00000_oBX002o`0000Cod:L000?o0000olf`0?o=/0000_l00000
0oo9^@3o0000olVi0002o`0000;oaL@00_l000001Ona`03o0000okS20?nh`P3o000001Kooooo0ol0
0003ooooo`Go00003_ooool001Gooooo0_l0000;ooooo`?o000000?o074^o`000?l0Nah00_l00000
0ol0Q0co0000o`J<0003o`000005oaFB0?l0003o9iT0o`000?ljW`001Ol00002oeBW0003o`000?mT
[03o000000;oLk0000?o0000oh:d0?l000000_n@^0001?l0003oW;/0oibk0?l00002ojRn0006o`00
0?nc`@3o/l40o`000?nm``3o00000_o5``05o`000003olj/0?l0003od:P000;od:P000Co0000om6U
0?oAY@3o00000_oAX`06o`000005omRA0?l0003of900omR@0?l000000_oHT005o`0000?og8<000?o
0000omb40?oLQ0000ol000000ooON03o0000ommk0002ommk00?o000000?ohW40o`000?oQM0000_oQ
M002o`000003on=/0?l0003ohW0000;ohW0000Go0000on5d0?l0003oi6T0o`000003on=^0005o`00
0?oQM03o0000onAY0?l000000ooSK`001Ol0003ohGH0o`000?oTJ`3o000000;ohW800_l00003on9`
0005o`000?oPN03o0000on=^0?l000000ooPM`02o`0000?oh7L00_l000000ooPN03o0000omf20002
omf200;o00000ooLQ@02o`0000?ofhP00_l00002omV=0009o`000?oEVP3o0000omNC0?l0003odZ00
o`000?oEV@3o000000?od:L00_l000001?o=/03o0000olnZ0?o?ZP03o`000004ol^d0?l0003oaL@0
o`0000;oakl000?o0000okS20?nh`P000_nh`P000ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01?ooooo000Eooooo`03o`000?oooooooooo00[ooooo0_l000001?l0L33o0000o`000?l0Nah2
o`000005o`243?l0003o1X`0o`000?lIT`000ol000001_lWV@3o0000ocZO0?l0003oC:D0o`0000;o
GZX02?l00002oh:d0003o`000?n@^03o000000;oW;/000?o0000ojRn0?l000002?l000001Oo;]03o
0000olf`0?o=/03o000000;ocZ`000Co0000om2X0?o@Z03o00000_oAY@03o`000005omND0?l0003o
ei80omNB0?l000000ooHT@000ol0003of900o`000004o`0000?ogH8000?o0000omb30?oLP`000ol0
00000ooPM`3o0000ommh0002ommh0005o`000?oON`3o0000on=^0?l000000ooRL@001?l0003ohG@0
o`000?l00003on=/0003o`000?oRL03ohW0000;o00000ooTJ@000ol0003ohfh0on=^0002o`0000?o
i6T000?o0000on=_0?l000000_l00003onA[00;o000000?oi6P0o`000?oRL0000_oRL002o`0000?o
hfh000Go0000on1g0?l0003ohfh0o`000002on1g00;o00000ooPN0000ol0003ogH80o`000002ommj
0005o`000?oLQ@3o0000omim0?l000000_oKR002o`0000?ofHd00_l00003omNC0007o`000?oEV@3o
eIT0omFI0?l0003od:L0o`000002om:Q0003o`000?o?ZP3ocjX000;ocjX00_l00002ol^d0003o`00
0?o7_`3oakl000;o00000onh`P02o`0001Wooooo00?o0000ooooooooool04_ooool001Gooooo0ol0
000:ooooo`Oo000000Go08@<o`000?l0003o0000o`J<0002o`0000;o;IX00ol000001_ljW`3o0000
odbU0?l0003oGZX0o`0000;oKjl000?o0000ognc0?l000000_n?^009o`000005olC40?l0003oakh0
olNn0?l000000_o9^@001Ol0003obk@0ol^d0?o;]03o000000;ocK0000?o0000olj/0?l000000_o@
Z003o`000005omJG0?l0003oei@0omND0?l000000ooGTP000ol0003of940o`000004o`0000?ogH80
00?o0000omf20?oMPP000ol000000ooQMP3o0000on1g0002on1g0003o`000?oON03oggP000;o0000
0ooSKP000ol0003ohW40o`000002o`000003onAX0?l0003ohf`000;ohf`00ol000000ooUI@3o0000
onAY0002onAY00?o000000CoiV@0o`000?oTJ@3oi6T00ol00002onEU0003o`000?oTJ`3oi6/000;o
00000ooTJ0001Ol0003ohW00o`000?oUIP3o000000?ohfh00_l00003on=^00;o000000?ohfh0o`00
0?oPN0000_oPN002o`0000?oggX00_l00003omim00;o00000_oMP@001Ol0003ofHd0o`000?oKQP3o
000000;oei<00_l00003omFI00;o00000_oBX@02o`0000?ocjX00_l000001_o;]03o0000o`000?l0
003oakl0o`0000;ob;/000?o0000okS20?l000000_nn``000ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01;ooooo000Eooooo`03o`000?oooooooooo00_ooooo1Ol000001?l0Nako0000o`00
0?l7S@03o`000005oaVC0?l0003o;IX0o`000?m0X@000ol000001om<Y@3o0000oejZ0?mNZP3o0000
ofn_0?l000000_mo/`001Ol0003oSkP0o`000?nN^`3o000000;o[;h000Co0000okW20?ni`P3o0000
0_o4a0001?l0003oakh0olNn0?l00002olVi0005o`000?o;]03obk@0o`000?o=/0001_l000000ooE
V@3o0000omJG0002omJG0005o`000?oGU03oei@0o`000?oGTP001_l00002omf20003o`000?oMPP3o
gH8000?o000000?ohGD0o`000?oQMP000_oQMP000ol0003oh7L0on1g0003o`000004on=/0?l0003o
hfh0on=^00?o000000?oiFD0o`000?oTJ0000_oTJ0001Ol0003ohf`0o`000?oWH@3o000000?oiFD0
00Go0000onAY0?l0003oiel0o`000003onIT00;o000000?oiel0o`000?oUI@000_oUI@03o`0000;o
iV8000?o0000onAX0?oTJ0000_l00003onEV0005o`000?oSKP3o0000onEU0?l000000_oSKP02o`00
00?ohfh000?o0000on1h0?l000000_oRL0001Ol0003oggX0o`000?oRLP3o000000;ogWd00_l00003
omf100;o00000ooKQP02o`0000;ofH`000Oo0000omFI0?l0003oei<0o`000?oBX@3o000000;oe9`0
00?o0000olnZ0?l000000_oAY@03o`000003olf`0?l0003ob;/000?ob;/000?o0000okk30?nn``00
0_l0000Iooooo`03o`000?oooooooooo017ooooo0007ooooo`?o00001?ooool2o`0000Gooooo00?o
0000ooooooooool02oooool2o`000003o`1i8Ol0003o000000;o000000?o08@<o`000?l000000_lK
U002o`000004obfJ0?l0003o@:40o`0000;oDjL01Ol00002ofn_0003o`000?mo/`3o000000;oSkP0
00?o0000oijk0?l000000_n/_P001_l0003o^L80okW20?l0003oa<@0o`0000;oakh000?o0000olVi
0?o9^@001Ol000001OoBX@3o0000omBM0?oDW@3o000000?oeIT000Go0000omJG0?oFU`3o0000omND
0006o`0000;og8<000?o0000omf20?oMPP000ol000000ooQM03o0000on5e0002on5e0003o`000?oQ
MP3ohGH000?o000000?oi6X0o`000?oSK0000_oSK002o`000003onIS0?l0003oiFD000;oiFD000?o
0000onAX0?oTJ0000_l00003onMQ0003o`000?oUI@3oiFD000;o00000ooWG`001?l0003oiV@0o`00
0?l00003onMO0005o`000?oUI@3o0000onQK0?l000000ooVHP03o`0000;oiel000?o0000onEV0?oU
IP000_l00003onEU00;o00000_oUI@000ol0003ohfh0on=^0002o`0000?ohW000_l00003on9b00;o
00000_oQMP001Ol0003ogH40o`000?oONP3o000000;ofhH00_l00003omV<00;o00000_oGT`02o`00
00?oe9`00_l00002om6U00;o000000CocK00o`000?l0003o00000oo8^`02o`000005okk30?l0003o
a<@0olC40?l000006Oooool00ol0003oooooooooo`0@ooooo`002?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03?ooool2o`000003o`1i8Ol0
003o000000?o000000Go1hd0o`000?lKU03o0000oc2L0003o`000006od2Q0?l0003oDjL0o`000?mV
[03o00000_mh/@0Go`000005olnZ0?l0003odJD0om6U0?l000000_oBX@001?l0003oe9d0omBM0?l0
0002omFI00So00000_oLQ0000ol0003og8<0omb30003o`000003on5e0?l0003ohG@000;ohG@000?o
0000on5e0?oQM@000ol000000ooTJ@3o0000onAZ0002onAZ0004o`000?oSK03o0000o`0000?oiV<0
00?o0000onEU0?oUI@000ol00002onQM0003o`000?oWH@3oif4000?o000000Coj5X0o`000?oWG`3o
iel00ol00002onUJ0003o`000?oWG`3oiel000;o00000ooXF`001Ol0003oiV80o`000?oYF@3o0000
00?oiel00ol000001?oWGP3o0000onEU0?oUI@02o`0000?oiFD00ol000000ooUIP3o0000on9`0002
o`000004onAX0?l0003ohW80on9b00;o00000ooQMP02o`0000?oggX00_l00002omeo0007o`000?oI
S03o0000om^60?l0003oei<0o`000002omV>000:o`000?oDW03o0000omJG0?l0003odJD0o`000?oB
X@3o0000olf`00;o000000CocZ`0o`000?o8^`3o00000_o9^0001_l0003oa<@0olC40?l0003oaL<0
o`0001Oooooo0_l0000Booooo`001Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000oooool2o`0000kooooo0_l000001?l0NB7o0000o`000?l00002o`N=00;o000000Go
6i@0o`000?l`W03o0000odBR0003o`000009oe>W0?l0003oIZ`0ofJ/0?l0003oN;40o`000?n:]P3o
000000;oVkX000?o0000ojZn0?l000000_ni`P001?l0003oaL<0olG30?l00002olRl0003o`000?o;
]P3o000000;ocK0000Co0000olnZ0?o?ZP3o00000ooAY@000ol0003odZ40o`000002omBM00?o0000
00?ofX/0o`000?l000000_l00002om^60003o`000?oLQ03og8@000?o000000?ohGH0o`000?oQM@00
0_oQM@000ol0003ohG@0on5d0003o`000003onAX0?l0003oi6T000;oi6T000?o0000onAZ0?l00000
0_l00002onMQ0003o`000?oVH`3oiV<000?o000000?oj5X0o`000?oXG@000_oXG@03o`000004onUG
0?l0003oj5X0onQJ00?o000000?ojUD0o`000?oYFP000_oYFP03o`0000;ojUH000?o0000onQK0?oX
F`000_l00003onUI00?o000000CojEL0o`000?oWGP3oieh00ol00002onQM0005o`000?oUI@3o0000
onMN0?l000000_oUIP02o`0000Coi6P00_l00002onA[0005o`000?oQMP3o0000on=_0?l000000_oO
NP02o`0000?ogGl00_l00002om^600;o00001?oISP001Ol0003oeYL0omJG0?oFU`3o000000?odZ40
00?o0000olj/0?o>[0000ol00002olVh00;o000000?oa<@0o`000?o5``000_o5``000ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`0=ooooo`05o`000?l0MbGo0000o`000?l0
P`h00_l000000ol7S@3o0000oabE0003o`000003oc2L0?l0003o000000;oFJP00ol000001?mV[03o
0000ogRa0?l00002ohZf0006o`000?nK^P3oVkX0o`000?nZ_P3o00000_ni`P001_l0003oaL<0olG3
0?l0003ob;`0o`0000;obkH000Co0000olf`0?o=/03o00000_o?ZP000ol0003odJD0o`000005o`00
0003omV>0?l0003o000000?o00000_oKR0000ol0003ofhH0o`000002o`000003on1g0?l0003ohGH0
00;ohGH000?o0000on5e0?oQM@000ol000000ooTJ03o0000onAX0002onAX0003o`000?oTJ@3o0000
00;o000000?oiel0o`000?oWH@000_oWH@03o`000003onUH0?l0003oj5X000;oj5X000Go0000onQM
0?l0003ojU<0o`000003onUG00;o000000?oje40o`000?oZE@000_oZE@001Ol0003ojEX0o`000?o[
D@3o000000?ojUH00ol000001?o[D`3o0000onUI0?oYF@02o`0000CojEL00_l000000ooZEP3o0000
onQM0002onQM00;o00000ooWGP02o`000003onMO0?l0003oi6P000;oi6P00_l00003onA[00;o0000
0ooSK`02o`0000;ohG@000Wo0000omeo0?l0003oggX0o`000?oKQP3o0000omf10?l000000ooISP02
o`0000;oeYL000So0000omNB0?l0003odZ40o`000?oDW@3o0000olj/00?o000000GobKP0o`000?o;
]@3obkD0o`000003olG300;o00006?ooool00ol0003oooooooooo`0?ooooo`002?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000?ooooo`Ko000000Go1hd0o`00
0?lLU@3o0000oc:L0003o`000005odBR0?l0003oFJP0o`000?m][P001_l000001on:]P3o0000oi^j
0?nK^P3o0000ojZn0?l000000_ni`P001?l0003oaL<0olG30?l00002olRl0003o`000?o;]P3o0000
00Oo000000CoeYL0o`000?oGTP3oei801Ol00002omZ;00Go000000?oggP0o`000?oPM`000_oPM`00
0ol0003ohGH0on5f0003o`000003onAX0?l0003oi6P000;oi6P000?o0000onAX0?l000000_l00000
0ooWGP3o0000onMO0002onMO0005o`000?oWH@3o0000onYF0?l000000ooYF0000ol0003oj5X0onQJ
0002o`0000?ojU<000Co0000onUG0?l0003o00000oo[D@000ol0003ojUD0onYE0002o`0000?oje40
00Go0000onYF0?l0003ok4h0o`000002on]C00?o00000_o[D@000ol0003ojEL0onUG0002o`0000?o
jUH000Go0000onQM0?l0003ojUH0o`000002onMN00;o00000ooWG`000ol0003oi6P0o`000002onIR
0005o`000?oTJ`3o0000onEU0?l000000_oSK`02o`0000?ohG@00_l00003ommj0007o`000?oMP@3o
gH40omf10?l0003ofHh0o`000002omZ900;o00000ooGTP001_l0003oe9d0omBM0?oDW@3o0000om2X
00?o00000oo;]@02o`000005olG30?l0003oa/40olK10?l000006?ooool00ol0003oooooooooo`0>
ooooo`001oooool2o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0>
ooooo`Go000000Go1H`0o`000?l0003o0000oabE0002o`0000;oAj<00_l00002oeVX00;o00000_n0
/`000ol0003oT[P0o`00000Ao`000007om2W0?l0003odZ40om:Q0?l0003oe9`0o`000003omJG00Co
00000_oISP03o`000004omim0?l0003ogg/0o`0000?oggP000?o0000on1g0?oPM`000ol000000ooT
J@3o0000onAX0002onAX0003o`000?oTJ03o000000;o000000?oj5d0o`000?oWGP000_oWGP000ol0
003oiel0onMO0002o`0000?ojUH000?o0000onUH0?oYF0000ol000001?o[D@3o0000onYC0?oZD`03
o`0000;ok4h000?o0000on]A0?o[D@000ol00002ona=0003o`000?o[D@3oje4000;o00000oo/CP02
o`000003one;0?l0003oje4000;oje400ol00002ona@0003o`000?oZEP3ojUH000;o00000ooZEP02
o`0000;ojEL000?o0000onMO0?oWG`000_l00003onIR00;o00000ooUI@02o`0000;oi6T000Go0000
on5d0?l0003ohfh0o`000002ommj00;o00000ooMP@02o`0000;ofXT00_l00003omNB00;o00000_oD
W@02o`000007om2X0?l0003o0000om6V0?l0003obkD0o`000002olbc0003o`000?o6`@3oa/4000;o
00006Oooool00ol0003oooooooooo`0=ooooo`002?ooool00ol0003oooooooooo`03ooooo`;o0000
1?ooool00ol0003oooooooooo`0>ooooo`03o`000?l0OaKo000000Co000000Wo6i@0o`000?l0003o
0000oc:L0?l0003oAj<0o`000?mLZP000ol000001?m][P3o0000oh2c0?n0/`02o`0000;oY;d000Ko
0000okG10?ne`@3o0000olC40?l00002olRl0006o`000?o;]@3obkD0o`000?o>[P3o00000oo@Y`00
1Ol0003odZ40om:Q0?l0003oe9`000Wo000000?ogH40o`000?oNO@000_oNO@000ol0003ogg/0o`00
0002ommh00?o000000?oi6X0o`000?oTJ@000_oTJ@000ol0003oi6P0o`000002o`000003onQM0?l0
003oj5d000;oj5d000?o0000onMN0?oWGP000ol00002onYD0003o`000?oZEP3ojUH000?o000000Co
k4l0o`000?o[D@3oje400ol000000oo]B`3o0000ona>0002ona>00?o00000_o]B@000ol0003ok4d0
ona=0003o`000004one90?l0003ok4h0ona>00;o00000oo]B`001Ol0003oje40o`000?o]BP3o0000
00?ok5000ol000001?o/C`3o0000onYF0?oZEP02o`0000?ojEL00ol00002onUI0005o`000?oVHP3o
0000onQK0?l000000_oUI@02o`0000?oi6T00_l00003on=^00;o00000_oQM0001ol0003ogH40o`00
0?oNO03o0000omZ90?l000000_oLQ@000ol0003oei80o`000002omV?00;o00000_oEV@000ol0003o
dJH0om6V0003o`0000;oc;<00_l000001Oo6`@3o0000olJo0?o6_`3o000001Sooooo0_l0000>oooo
o`005?ooool00ol0003oooooooooo`0?ooooo`03o`000?l0OaKo000000Go00000_laW002o`000004
odNS0?l0003oG:X0o`0000;oLK001Ol000001OnB^03o0000ojBm0?nT_@3o000000;o]L4000?o0000
olC40?l000000_o8_0001_l0003obkD0ol^e0?l0003ocZh0o`0000;od:L000?o0000om:Q0?l00000
1Ol000001OoJR@3o0000omb50?oLQ@3o000000?ogH4000?o0000omim0?l000001Ol000000ooSK03o
0000onAZ0002onAZ0003o`000?oTJ@3oi6T000;o000000?oj5d0o`000?oXG@000_oXG@000ol0003o
j5d0onQM0003o`0000;ojU<000?o0000onYD0?oZE0000ol000001?o/C@3o0000ona?0?o/C`03o`00
0003oni80?l0003okD/000;okD/000Go0000ona>0?l0003okTH0o`000003one900?o000000CokTD0
o`000?o]B@3okDT00ol00002oni60003o`000?o]B`3okD/000;o00000oo]BP001Ol0003ok500o`00
0?o]B@3o000000;ok4l00ol00002ona@0005o`000?oYE`3o0000on]A0?l000000ooYF@02o`0000?o
j5/00_l00002onMO0005o`000?oTJ@3o0000onIT0?l000000_oSKP02o`0000?ohG@00_l00002omil
00;o00000ooLQ@02o`0000;ofHl00_l00002omFI0004o`000?oFU`3o0000om6V00?o000000Goc;<0
o`000?o</@3oc;40o`000002olJo00;o00006?ooool2o`0000kooooo000Cooooo`;o00004Oooool0
0ol0003o07lFo`000002o`0000;o6I<00_l000000olaW03o0000odRS0003o`000006oebZ0?l0003o
LK00o`000?n6]@3o00000_nI^P0:o`0000;ob;`03?l00002omV>0005o`000?oJR@3ofXT0omZ90?l0
00000_oLQ@000ol0003ogH40o`000002o`000005on9a0?l0003ohfh0on=^0?l000000ooSK0000ol0
003oi6X0onAZ0003o`000005onMN0?l0003oj5d0onQM0?l000000_oXG@03o`0000;oje<000?o0000
onYC0?oZD`000ol000000oo]B`3o0000ona=0002ona=00;o000000?okTH0o`000?o^B0000_o^B000
0ol0003okD/0one;0002o`0000?okTH000Go0000one90?l0003okd80o`000003oni500;o000000?o
kd80o`000?o^AP000_o^AP03o`0000;okT@000?o0000one:0?o]BP000_l00003one900;o000000?o
kDT0o`000?o/D0000_o/D002o`0000?oje400ol000001?o[D`3o0000onQK0?oXF`02o`0000?oiel0
0_l00002onIT00?o00000_oTJ@002_l0003ohG@0o`000?oRL03o0000omil0?l0003oh7P0o`000?oL
Q@02o`000008omf10?l0003ofHl0o`000?oJR`3o0000omFI0?l00003omJG0003o`000?oAX`3o0000
00;o00000_o</@02o`000005olJo0?l0003oakl0olNo0?l000006Oooool00ol0003oooooooooo`0;
ooooo`005?ooool00ol0003oooooooooo`0@ooooo`;o000000Co08T1o`000?l0003o6I<00_l00000
1OlaW03o0000odRS0?l0003oGZX000?o00000_ma/0001ol0003oQ[D0o`000?nI^P3o0000ojbn0?l0
00000_nm``000ol0003oakl0o`000002olZg00;o000000GocJl0o`000?o@Y`3o0000om>P0003o`00
0005omFI0?l0003oei<0omNC0?l000000_oISP000ol0003ofXT0omZ90005o`000003on5d0?l0003o
hW4000;ohW4000Co0000on=^0?oSKP3o00000_oSK003o`000003onMO0?l0003oieh000;oieh000?o
0000onQM0?l000000_l00002on]C0003o`000?o[D`3oje<000?o000000?okDX0o`000?o]B`000_o]
B`001?l0003ok4d0o`000?l00003oni60003o`000?o^B03okTP000?o00000_o_@`000ol0003okTH0
oni60002o`0000?okd8000Co0000oni50?l0003o00000oo_@P001Ol0003okTH0o`000?o`@03o0000
00?okT@00ol000001?o_@`3o0000one90?o]B@02o`0000?okDT000Go0000ona@0?l0003okDX0o`00
0002on]A00;o00000oo[D`03o`0000;ojUH000Wo0000onMO0?l0003ojEX0o`000?oVI03o0000onMO
0?l000000ooTJ@02o`0000;ohW000_l00002on1h00;o00000ooMP@02o`0000;ofX/00_l00003omJG
00;o000000KodJ<0o`000?l0003o0000olba0?l00002olf`0004o`000?o7_`3oakl0olNo00;o0000
6?ooool00ol0003oooooooooo`0;ooooo`004oooool2o`0001;ooooo1Ol000000olIT`3o0000oc2L
0003o`000003odRS0?l0003o000000;oM;001Ol00002oiVj0005o`000?n/_P3o0000okg30?l00000
0_o7_`000ol0003ob[L0o`000002olf_00Co00000_oCX0001Ol0003oeIT0omFI0?l0003oei<000Ko
000000GogW`0o`000?oPN03oh7P0o`000002on5d0003o`000?oRL@3ohW4000Ko000000?oif40o`00
0?oWG`000_oWG`000ol0003oieh0o`000002o`0000;oje<000?o0000on]C0?o[D`000ol000000oo]
BP3o0000one:0002one:0003o`000?o]B`3o000000;o00000_o_A0000ol0003okTH0oni60003o`00
00;ol40000?o0000onm30?o_@`000ol000001?o`?P3o0000onm20?o_@P03o`0000;ol3h000?o0000
onm20?o_@P000_l00003oo100005o`000?o^A03o0000oo0n0?l000000_o_@`03o`0000;okd<000?o
0000one90?o]B@000_l00002one:00?o00000_o]B`001Ol0003oje<0o`000?o/CP3o000000?ojUH0
0_l00002onUJ00;o00000ooWG`002ol0003oi6T0o`000?oUI@3o0000on9`0?l0003ohf`0o`000?oP
N03o000000;ohG@000Oo0000omf10?l0003ogWh0o`000?oJR`3o000000;ofhP000?o0000omJG0?l0
00000_oGU0000ol0003odZ40om:Q0002o`0000;ocK0000Go0000olf_0?l0003oakl0o`000002olNn
0003o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool001?ooooo00?o0000oooooooo
ool04_ooool3o`000003oaFB0?l0003o000000;o000000[oAj<0o`000?l0003o0000oejZ0?l0003o
M;00o`000?n9]P3o00000_nN^`05o`0000;o_L<000?o0000olNo0?l000000_o:]`04o`000003om2W
0?l0003o000000Ko000000GofhH0o`000?oMP@3ogH40o`000003omil0005o`000?oPN03oh7P0o`00
0?oQM0000ol000000ooUI@3o0000onIS0002onIS0003o`000?oWH@3o000000Go00000_oZD`000ol0
003oje<0on]C0003o`000003one90?l0003okDX000;okDX000?o0000one:0?l000000_l00002onm3
0003o`000?o_A03okd@000?o00000_o`?P000ol0003ol400oo100003o`000004oo4l0?l0003ol3h0
oo0n00?o00000_oa>`000ol0003ol3h0oo0n0003o`0000;olC`000?o0000oo100?o`@0000_l00003
oo0n00;o00000_o`?P000ol0003okd<0onm30003o`000004onm30?l0003okDX0o`0000;okT@000?o
0000one;0?o]B`000_l00003ona>0007o`000?oZEP3o0000on]A0?l0003ojEX0o`000002onYE0003
o`000?oWG`3oiel000;o00000_oUI@02o`0000;ohf`00_l00003on5d00;o00000_oNOP02o`0000?o
fhP00_l00002omND00;o000000KodZ40o`000?oBX03o0000olf`0?l00002olf_00;o00000_o7_P00
0ol0003oakl0o`00000Hooooo`03o`000?oooooooooo00Wooooo000Cooooo`03o`000?oooooooooo
01;ooooo1Ol000000ol/VP3o0000o`000002o`0000;oGZX00_l00002ogB`0007o`000?n9]P3o0000
oijk0?l0003o/L00o`000002olC400co000000OoeIX0o`000?oGTP3oei80o`000?oIS03o000000?o
fhH000Co0000omf10?oMP@3o00000_oNO005o`000003onAX0?l0003oiFD000;oiFD000?o0000onIS
0?oVH`000_l000000ooZEP3o0000onYD0002onYD0003o`000?oZD`3ojU<000?o000000?okDX0o`00
0?o]B@000_o]B@000ol0003okDX0o`000002o`0000;okd8000?o0000onm30?o_@`000ol00002oo0m
0003o`000?o`?P3ol3h000?o000000ColCX0o`000?oa?03olC`00ol00002oo8h0003o`000?oa>`3o
lC/000?o00000_ob>0000ol0003olC`0oo4l0003o`000004oo4j0?l0003ol3h0oo0n00;o00000oo`
?P03o`000004oo0n0?l0003okd<0onm300;o00000oo^A003o`0000;okTH000?o0000ona>0?o/CP00
0_l00002on]A00;o00000ooZE@03o`000008onQK0?l0003oiFD0o`000?oWH@3o0000on=/0?l00002
onAX0007o`000?oQM03o0000on9a0?l0003ogWh0o`000002ommk0007o`000?oKR03o0000om^60?l0
003oei@0o`000002omNB0003o`000?oBX03odZ0000?o000000OocJl0o`000?o=[`3o0000olNn0?l0
003oakl000;o00006?ooool2o`0000[ooooo000Cooooo`;o00005?ooool6o`0000;oA:800_l00000
0omNZP3o0000ogFa0005o`0000;oW[/000Co0000ok700?l0003oa<@01?l000001oo</P3o0000olnY
0?o?Z@3o0000om:Q0?l000000ooEVP001_l0003oei80omNB0?l0003ofH`0o`0000;ofhH01_l00000
1OoRL03o0000on=/0?oSK03o000000;oi6P000?o0000onEU0?oUI@000ol000001OoYF03o0000onYF
0?oZEP3o000000;ojU@00ol000000oo]BP3o0000one:0002one:0003o`000?o]B@3okDT000;o0000
0_o_@P000ol0003okd80onm20003o`000003oo4l0?l0003ol3d000;ol3d00ol000001?ob>03o0000
oo4j0?oa>P03o`000003oo8f0?l0003olSP000;olSP00ol00002oo8e0003o`000?ob>03olSP000?o
000000ColSH0o`000?oa>P3olCX00ol00002oo4i0005o`000?o`?P3o0000oo4i0?l000000_o`?P03
o`0000;ol3h000Go0000oni40?l0003ol400o`000003oni600?o000000CokDT0o`000?o[D@3o0000
0_o/C@001Ol0003ojUD0o`000?o[D@3o000000;oj5/00_l00002onMQ00;o00000ooTJ002o`0000;o
hW400_l00003ommk00;o00000_oKQP02o`0000;oei8000Co0000omRA0?l0003odZ000_l000001?oC
W`3o0000olf_0?o=[`02o`000005olNo0?l0003oa[l0olJo0?l000006?ooool00ol0003ooooooooo
o`08ooooo`002_ooool3o`0000Gooooo0_l0000Eooooo`?o00000_lWV@02o`000003odBR0?l0003o
G:T000Co000000CoRkL0o`000?nQ_03oXK`02?l000001Oo8^`3o0000olbb0?o</P3o000000;ocjT0
00?o0000om:Q0?l000000_oEVP000ol0003oei80o`000005o`000005ommj0?l0003ohG@0on5d0?l0
00000ooRL0000ol0003ohf`0o`000005o`000003onQJ0?l0003ojEP000;ojEP000?o0000onYF0?l0
00000_l000000oo]B`3o0000one:0002one:0003o`000?o]BP3okDX000?o000000Cokd40o`000?o_
@P3okd800ol000000ooa>`3o0000oo4l0002oo4l0005o`000?o`?@3o0000oo8f0?l000000oob>002
o`000003oo<c0?l0003olSH000;olSH000Go0000oo8h0?l0003olc80o`000003oo8e00?o000000Co
lc<0o`000?ob=P3olSH00ol00002oo8e0003o`000?oa>@3olCT000;o00000ooa>@02o`0000;olCT0
00?o0000oo0n0?o`?P000_l00003oo1000?o000000Cokd80o`000?o]B@3okDT00_l00003ona=00;o
00000oo[D@02o`000004onUG0?l0003oif40o`0000;oj5d000Oo0000onAX0?l0003oiFD0o`000?oR
L@3o000000;ohfh000_o0000ommk0?l0003oggT0o`000?oKQP3o0000omb40?l0003oei80o`000003
omRA0003o`000?oCW`3odil000;o000000GocJl0o`000?o=[`3ocJl0o`000002olJo00;o00005ooo
ool3o`0000Wooooo0009ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`0Dooooo`?o000000?o9iT0o`000?m0X@000_l000000omLZ@3o0000ogB`0003o`000005oh^g0?l0
003oXK`0o`000?ne`@000_l000000oo5`P3o0000o`00000?o`000005om^60?l0003ogGl0omeo0?l0
00000ooONP001Ol0003ohG@0on5d0?l0003ohW0000?o000000?oif40o`000?oXG@000_oXG@001Ol0
003oj5X0onQJ0?l0003ojEP000?o000000?ok4d0o`000?o]B`000_o]B`000ol0003okDX0one:0003
o`000004onm20?l0003okd40onm100?o000000?olCX0o`000?oa>`000_oa>`000ol0003olC`0oo4l
0002o`0000?olSH000Co0000oo8h0?l0003o00000ooc<`000ol0003olSH0oo8f0002o`0000?olc80
00Go0000oo8e0?l0003om300o`000002oo<c00?o00000_oc<@000ol0003olSD0oo8e0003o`000004
oo<d0?l0003olCT0oo4i00;o00000ooa>@03o`000004oo4j0?l0003ol400oo1000;o00000oo_@P03
o`000003oni50?l0003ok4d000;o000000CokDT0o`000?o[D@3oje400_l00002onUG00;o00000ooX
G@02o`0000;oiFD00_l00003on=^00;o00000_oON@02o`0000;og8@00_l00003omRA00;o000000Go
dil0o`000?l0003odil0o`000002olf_00;o000000Coa[l0o`000?o6`@3oa/400_l0000Booooo`?o
00000_ooool00ol0003oooooooooo`07ooooo`000oooool5o`0000Gooooo00?o0000ooooooooool0
0_ooool2o`0001Kooooo0_l000001?lQUP3o0000o`000?m0X@03o`000003oebY0?l0003o000000;o
RkL01Ol000001?ne`@3o0000olG20?l00002olVh0003o`000?o=[P3o000000;odJD000?o0000omBL
0?l000000_oGU0001ol0003ofHd0omV=0?oIS@3o0000om^60?l000000_oMO`000ol0003oggX0ommj
0005o`000003onEU0?l0003oif4000;oif4000?o0000onQM0?oXG@001Ol00002ona?0004o`000?o/
C@3ok4d0o`0000;okD/00ol000001?o_@P3o0000onm20?o_@P03o`000003oo4j0?l0003olCX000;o
lCX000?o0000oo4k0?oa>`000ol000001?ob=@3o0000oo8f0?ob=P03o`0000;olc8000?o0000oo<c
0?oc<`000ol00002oo@`0003o`000?oc<P3olc8000;o00000ood<002o`0000;om2h000?o0000oo<a
0?oc<@000ol000001?od<03o0000oo<d0?oc=003o`0000;olc@000Go0000oo4i0?l0003olSD0o`00
0002oo4j00?o00000_oa?0001Ol0003okd80o`000?o`?P3o000000;okTD00_l00003one900?o0000
00Cok4h0o`000?oYE`3o00000_oZE0001ol0003oj5d0o`000?oXF`3o0000onEU0?l000000_oVH`00
2ol0003ohfh0o`000?oSK03o0000ommi0?l0003oh7L0o`000?oLQ03o000000;og8<000Co0000omRA
0?l0003of9000_l00002om>O00;o000000?ocJl0o`000?o=/0000ol000001Oo6`@3o0000olG30?o5
``3o000000kooooo0ol00005ooooo`03o`000?oooooooooo00Oooooo000=ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05Oooool6o`000003od2Q0?l0003o000000;o000000?oM;00
o`000?l000001ol00002olG20006o`000?o9^03obKP0o`000?o=[P3o00000_oAY@000ol0003oe9`0
o`000002omND0003o`000?oIS@3ofHd000So000000Gohfh0o`000?oTJ@3oi6T0o`000002onEU0003
o`000?oWH@3oif4000?o000000GojU<0o`000?o[D@3oje40o`000002ona?00Ko00000_o_@`000ol0
003okd80o`000002o`000003oo4j0?l0003olCX000;olCX000?o0000oo4j0?oa>P000ol00002oo<d
0003o`000?ob=@3o000000;o00000_od<0000ol0003olc80oo<b0003o`0000;om2h000?o0000oo@`
0?od<0000ol000001?od;P3o0000oo@`0?od<002o`0000?om2h00ol000001?od;@3o0000oo@`0?od
<003o`0000;om30000?o0000oo<d0?oc=0000_l00002oo8e00?o00000_ob=P000ol0003olC`0oo4l
0002o`0000;ol3h00ol00002onm20005o`000?o]B@3o0000oni60?l000000_o/CP02o`0000?ojU@0
0_l00002onQK00;o00000ooVH`02o`0000;ohf`00_l00002on1g00;o00000ooLP`02o`000007omR@
0?l0003of900o`000?oCW`3o0000om>O0002o`000003olf`0?l0003oc;4000;oc;4000Ko0000olG3
0?o5``3o0000olC40?l00009ooooo`Co00002?ooool00ol0003oooooooooo`07ooooo`002Oooool4
o`0000Gooooo00?o0000ooooooooool05_ooool8o`000003og6`0?l0003o000000Go00000_ng`@00
0ol0003oa/40o`00000Ao`000004omf10?l0003oggX0o`0000?ohG@000Go0000on=^0?oSKP3o0000
onAY0006o`000003onUG0?l0003ojU<000;ojU<000?o0000on]A0?l000000_l000000oo^AP3o0000
onm40002onm40003o`000?o_@`3okd<000;o00000_oa>`001?l0003olCX0oo4j0?l00002oo4j00?o
00000_oc=0000ol0003olc@0oo<d0002o`0000;om2l000?o0000oo@`0?od<0000ol00002oo@]0003
o`000?od;P3om2h000?o000000ComB`0o`000?od;P3om2h00ol00002ooD/0005o`000?od;P3o0000
ooD[0?l000000_od;@03o`0000;om2d000?o0000oo@`0?od<0000ol000001?od<03o0000oo8e0?l0
0002oo<a0003o`000?ob=P3olSH000?o000000ColSP0o`000?o`?P3o00000_oa>`000ol0003okd80
onm20002o`0000;okTH00ol00002one;0007o`000?oZE03o0000on]A0?l0003oj5/0o`000002onUH
000;o`000?oVH`3o0000onMQ0?l0003ohf`0o`000?oTJ`3o0000on1g0?l000000_oQMP001?l0003o
g8<0o`000?oMPP02o`0000;of9000_l000000ooCW`3o0000om:P0002o`0000?oc;400_l000000oo5
``3o0000olC40002o`0000Kooooo0ol0000;ooooo`?o00002?ooool000Wooooo00?o0000oooooooo
ool01_ooool2o`0001Sooooo00Go0000oc:L0?lbW03o0000oe>W0003o`000005og6`0?l0003oRKH0
o`000?nQ_0000ol00002okO100;o00000_o:]P000ol0003ocZ`0o`000002om:R0006o`000?oEV@3o
eIT0o`000?oHT03o00000_oKR0001ol0003ogH40omf10?oMP@3o0000ommj0?l000000_oQM005o`00
0003onMO0?l0003oj5X000;oj5X000Go0000onUG0?oYE`3o0000onYC0003o`000003oni80?l0003o
kTH000;okTH000?o0000onm40?o_A0000ol000001?oa?03o0000oo4k0?oa>`06o`0000;olc@000?o
0000oo<d0?oc=0000ol000001?od;`3o0000oo@_0?od;`03o`0000;omB`000?o0000oo@]0?od;@00
0ol000001?oe:P3o0000ooD/0?oe;003o`0000;omRT000?o0000ooD/0?oe;0000_l00003ooD[00;o
00000_oe:P000ol0003om2d0oo@]0003o`000004oo@]0?l0003om300oo@`00;o00000ooc<@03o`00
0004oo<c0?l0003olSP0oo8h00;o00000ooa>`03o`000004oo0n0?l0003okTH0o`0000;okd<000?o
0000one;0?o]B`000_l00002on]A00;o00000ooYF002o`0000;oif400_l00002onA[00;o00000ooQ
MP02o`000006omf20?l0003ogH80o`000?oHT03o00000_oHT0000ol0003odZ00om:P0003o`000003
olba0?l0003oc;<000;o000000?oa<@0o`000?nn``000_l00002ooooo`?o00003_ooool3o`0000So
oooo0009ooooo`Go00001?ooool00ol0003oooooooooo`0Gooooo`Go000000?oDjL0o`000?m][P00
0ol000000on9]P3o0000o`000002okO100Go00000_o:]P000ol0003ocZ`0o`000002om:R0006o`00
0?oEV@3oeIT0o`000?oHT03o00000_oKR0000ol0003ogH40o`000005o`000004onAY0?l0003oiV@0
o`0000?oiel000?o0000onQJ0?oXFP001Ol00002one;0004o`000?o^B03okTP0o`0000;okTH00ol0
00001?o`?@3o0000oo4l0?oa?003o`000003oo<d0?l0003olc@000;olc@000?o0000oo<d0?oc=000
0ol000001?od;P3o0000oo@_0?od;`03o`0000;omB/000?o0000ooD/0?oe;0000ol000001?of:03o
0000ooDZ0?oe:P03o`0000;omRP000?o0000ooHY0?of:@000ol000001?of:03o0000ooD[0?oe:`02
o`0000?omBX00ol000001?of:@3o0000oo@]0?od;@03o`0000;om2d000Go0000oo<a0?l0003om2h0
o`000002oo<c00?o00000_ob=@001Ol0003olC/0o`000?ob>03o000000;ol3h00_l00003onm300?o
000000CokTP0o`000?o[D@3o00000_o/C`002ol0003ojEP0o`000?oZEP3o0000onMQ0?l0003oiel0
o`000?oTJ`3o000000;oi6T000?o0000on5f0?l000000_oQM@000ol0003ogH80omf20002o`0000;o
f90000Co0000omRA0?l0003odZ001?l000001oo</`3o0000ol^e0?o;]@3o0000okk30?l000000_nh
`P02o`00013ooooo0_l000000ooooooo0000ooooo`07ooooo`004_ooool00ol0003oooooooooo`0F
ooooo`Go000000?oC:D0o`000?l000000_l000002_n5]@3o0000o`000?l0003oXK`0o`000?ng`@3o
0000olK00?l00002ol^e017o000000?ohGH0o`000?oSK`000_oSK`001_l0003oi6T0onAY0?l0003o
iV@0o`0000;oiel00ol000001Oo[D@3o0000ona>0?o/CP3o000000;okD/01_l00002oo0n0003o`00
0?o`?@3o000000;o000000?olSD0o`000?oc=0000_oc=0000ol0003olc@0oo<d0003o`000004oo@^
0?l0003om2h0oo@^00?o00000_oe:P000ol0003omB/0ooD[0003o`000004ooHW0?l0003omRP0ooHX
00?o00000_of9P000ol0003omRP0ooHX0003o`000004ooHV0?l0003omRP0ooHX00?o00000_of9`00
1Ol0003omBX0o`000?of9`3o000000;omRT00ol00002ooDZ0003o`000?od;@3om2d000;o00000_od
;P03o`0000;om30000?o0000oo8e0?ob=@000_l00002oo8h00?o00000_oa?0001Ol0003okd<0o`00
0?o`@03o000000;okTP00ol00002ona?00;o00000_oZEP02o`0000;oiel00_l00003onAY00;o0000
0_oQM@02o`000006omf20?l0003ogH80o`000?oHT03o00000_oHT@02o`000005om:Q0?l0003o0000
om6S0?l000000_o;]@000ol0003obKP0o`000002okS20003o`000?na`03o0000013ooooo0_l00000
0ooooooo0000ooooo`07ooooo`004Oooool00ol0003oooooooooo`0Dooooo`?o00000_ooool5o`00
0003ofJ/0?l0003o000000;o00000_nN^`05o`000006olK00?l0003obkD0o`000?o?ZP3o00000_oC
X0001_l0003oeYH0omJF0?l0003ofHd0o`0000?og8D000?o0000omim0?l000000_oQMP000ol0003o
hfl0on=_0008o`0000;ojUD000Go0000on]A0?o[D@3o0000ona>0003o`000003onm30?l0003ol400
00;ol40000?o0000oo0n0?o`?P000_l00002oo8f0004o`000?ob=@3olSD0o`0000;olc@00ol00000
1?od;P3o0000oo@^0?od;P03o`0000;omBX000?o0000ooDZ0?oe:P000ol000001?of9`3o0000ooHW
0?of9`03o`0000;ombD000?o0000ooHV0?of9P000ol000001?og903o0000ooHV0?of9P03o`0000;o
mbD000?o0000ooHW0?of9`000_l00002ooHW00?o00000_of9`000ol0003omBX0ooDZ0003o`000004
ooD[0?l0003om2h0o`0000;omB`000?o0000oo@`0?od<0000ol000001?oc<P3o0000oo8h0?l00002
oo8f0003o`000?oa?03olC`000;o00000_o`@003o`0000;okTH00ol000002?o/C@3o0000onYF0?l0
003ojUD0o`000?oWG`3o00000_oWGP002?l0003oi6T0o`000?oTJ03o0000on5e0?l0003ohGD00_l0
0002omf200?o000000Gof940o`000?oGTP3oei80o`000002om6S00;o000000?obkD0o`000?o9^000
0_l000001_nh`P3o0000ok700?l0003oZKh0o`0000kooooo0ol000000ooooooo0000ooooo`07oooo
o`004Oooool2o`0001?ooooo0_l00006ooooo`Ko00000_n0/`02o`000004oijk0?l0003o]L40o`00
00;oa/401Ol000001Oo?ZP3o0000om>P0?oCX03o000000;oeYH000?o0000omV=0?l000000_oLQ@08
o`000004onEU0?l0003oiel0o`0000?ojEX000?o0000onYE0?oZE@001Ol00002oni60004o`000?o_
@`3okd<0o`0000;ol4000ol000001?ob>03o0000oo8f0?ob=P06o`0000;om2l000?o0000oo@^0?l0
00000_l00002ooHY0003o`000?oe:P3omBX000?o00000_of9P000ol0003omRL0o`000002o`0000;o
mb@000?o0000ooLU0?og9@000ol000001?og8`3o0000ooLT0?og9003o`0000;omb<000?o0000ooLU
0?og9@000ol000001?og903o0000o`000?l00002ooLT0003o`000?of9`3omRL000?o000000ComRL0
o`000?oe:`3omB/00_l00003ooD/00?o000000Com2h0o`000?oc<P3olc800_l00003oo8f00?o0000
00ColCX0o`000?o`@03o00000_o`?P001Ol0003okTH0o`000?o_A03o000000;ok4d00_l00002onYE
00;o00000ooWGP02o`0000;oi6P00_l000001_oQM@3o0000on5e0?l0003ogH80o`0000;og8<00_l0
0002omNB00;o000000?odJ<0o`000?l000000_l000000oo9^03o0000olRk0002o`000006ok700?l0
003oZKh0o`000?nP_03o00003Oooool2o`0000;ooooo00?o0000ooooooooool01_ooool0017ooooo
00?o0000ooooooooool03oooool3o`0000Sooooo00?o0000ocRN0?l000000_mNZP02o`000003oh2c
0?l0003oVKX000?o000000Ko]L40o`000?o6`@3o0000ol^e0?l00002olnZ00co000000CoggX0o`00
0?oRLP3o00000ooTJ`001_l0003oiFD0onEU0?l0003oiel0o`0000;ojEX00ol000001Oo/C@3o0000
one90?o]B@3o000000;okTH01_l000001?oa>P3o0000oo8h0?ob>003o`000003oo@`0?l0003om2l0
00;om2l000?o0000oo@_0?od;`000_l00002ooDZ0003o`000?of:@3omRT000?o00000_of9P000ol0
003omRH0ooHV0002o`0000;omb<000?o0000ooLT0?og90000ol00002ooLR0003o`000?og8`3o0000
00;o00000_og8P000ol0003omb<0ooLS0003o`000004ooLR0?l0003omb@0o`0000;omb8000?o0000
ooLT0?og90000ol000001?og903o0000ooHW0?of9`03o`0000;omRP000Go0000ooD/0?l0003omRT0
o`000002oo@^00?o00000_od<0001Ol0003olSH0o`000?oc<`3o000000;olCX00ol00002oo0n00;o
00000_o_A003o`000004one;0?l0003o0000o`0000;ojU@000Co0000onMN0?l0003oj5d00ol00000
0ooTJ03o0000o`000003on5e00;o000000Oog8<0o`000?oLQ03o0000omNB0?l0003oei@000;o0000
00OodJH0o`000?l0003od:P0o`000?o8^`3o000000;oakl000?o0000ojVn0?l000000_nP_002o`00
00_ooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo000Aooooo`03o`000?oooooooooo00co
oooo0ol0000<ooooo`?o000000?oGZX0o`000?mh/@001?l000000ona`03o0000o`000004o`000004
ol^e0?l0003ocjX0o`0000;odil000Ko0000omNE0?oGU@3o0000omZ;0?l00002omf20006o`000?oO
NP3oggX0o`000?oRLP3o00000_oTJ`08o`0000;oje4000Go0000ona=0?o/C@3o0000one90003o`00
0003oo0n0?l0003olC`000;olC`000?o0000oo4j0?l000000_l00002oo<b0004o`000?od<03om300
o`0000;om2l00ol000001?oe:P3o0000ooDZ0?oe:P03o`0000;omRH000?o0000ooHV0?of9P000ol0
00001?og8`3o0000ooLS0?og8`03o`0000;on24000?o0000ooLR0?og8P000_l00002ooPP0003o`00
0?og8P3omb8000?o00000_oh8@000ol0003omb80o`000002o`0000;omb800ol00002ooLR0003o`00
0?og903o000000;o00000_og9@000ol0003omRP0ooHX0002o`0000;omRT00ol00002ooD/0003o`00
0?od<03om30000;o00000_oc<`03o`0000;olSP00ol000002?o`?@3o0000onm40?l0003okd<0o`00
0?o]B`3o00000_o]BP000ol0003ojU@0onYD0002o`000006onQM0?l0003oj5d0o`000?oTJ03o0000
0_oTJ0001?l0003ohGD0o`000?oQMP02o`0000;og8@00_l000001OoGU03o0000omJG0?oFU`3o0000
00;od:P000?o0000olj/0?l000000oo7_`03o`000003oj2l0?l0003oU[T000?o00002Oooool2o`00
00Cooooo00?o0000ooooooooool01Oooool0017ooooo0_l0000:ooooo`?o00003oooool7o`000003
oi:h0?l0003o000000;o00000_o5`P000ol0003ob[H0o`00000Fo`000005onIR0?l0003oj5/0onQK
0?l000000_oZEP000ol0003oje40on]A0005o`0000;okd8000Co0000oo0n0?o`?P3o00000_oa?002
o`0000;olc<000?o0000oo<b0?oc<P001_l000001?oe:`3o0000ooDZ0?oe:P03o`0000;omRH000?o
0000ooHV0?of9P000ol000001?og8P3o0000ooLS0?og8`03o`0000;on20000?o0000ooPQ0?oh8@00
0ol000001?oh7`3o0000ooPP0?oh8003o`0000;on1l000?o0000ooPQ0?oh8@000_l00002ooPP00?o
00000_oh80000ol0003omb80ooLR0002o`0000;omb8000?o0000ooLU0?og9@000ol000001?of9P3o
0000o`000?l00002ooHX0003o`000?oe;03omB`000?o000000Com2h0o`000?l0003o00000_oc<P00
1Ol0003olSP0o`000?ob=P3o000000;ol3d00_l00002onm300;o00000oo]BP03o`000003on]C0?l0
003o000000;oj5d00_l00003onAX00;o000000OohGH0o`000?oPM`3o0000omb40?l0003ofhH000;o
00000_oFU`02o`000003om2X0?l0003ocZ`000?o000000Woakl0o`000?o5a03o0000okg30?l0003o
U[T0o`000?n;]`001?l00006ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`004Oooool0
0ol0003oooooooooo`06ooooo`?o00004_ooool01Ol0003oB:<0o`000?l0003oKjl000Co00000_n/
_P02o`0000;oaL800_l00002olnZ0003o`000?oCW`3o000000;oei@000Ko0000omZ:0?oJRP3o0000
omf10?l00002on1h0003o`000?oRL03o000000?oi6P000Go0000onIR0?oVHP3o0000onQK0006o`00
0005one90?l0003okTD0oni50?l000000_o_@P06o`000004oo8f0?l0003olc<0oo<c00?o00000_od
;@001Ol0003omB`0ooD/0?l0003omB/000?o00000_of9P000ol0003omRH0ooHV0003o`000004ooLR
0?l0003omb80ooLR00?o00000_oh80000ol0003on200ooPP0003o`000004ooPN0?l0003on1l0ooPO
00?o00000_oh7P000ol0003on1l0ooPO0003o`000004ooPN0?l0003o0000o`0000;on1h000?o0000
ooPP0?oh80000ol000001?oh803o0000ooLR0?og8P03o`000004ooLS0?l0003omRH0o`0000;omb@0
00?o0000ooHX0?of:0000ol000001?oe:P3o0000oo@^0?l00002oo@]0003o`000?oc<P3olc8000;o
00000_ob=P03o`000004oo4l0?l0003okd<0o`0000;okd8000_o0000one:0?l0003okDX0o`000?o[
D`3o0000on]C0?l0003oj5d0o`000002onQM0004o`000?oTJ03o0000onAY00;o00000_oPM`02o`00
0006om^60?l0003ofhP0o`000?oFU`3o00000_oEV@02o`000003olj/0?l0003ocK0000;o000000Oo
aL@0o`000?nm``3o0000ok?00?l0003oRkL000;o000000?oL[00o`000?l000002?l00005ooooo`03
o`000?oooooooooo00Gooooo000Aooooo`03o`000?oooooooooo00?ooooo0ol0000Fooooo`;o0000
00?oI:`0o`000?l000000_n:]P02o`000003ojbn0?l0003oa<@000Go00000_o?ZP000ol0003odil0
o`000002omND0006o`000?oJRP3ofXX0o`000?oMP@3o00000_oPN0000ol0003ohW00o`000002onAX
00Go000000?oje<0o`000?o/CP000_o/CP001Ol0003okDT0one90?l0003okTD000?o00000_oa>`00
1Ol0003olSP0oo8h0?l0003olSH000?o00000_od;P000ol0003om2d0oo@]0005o`0000;omRL000?o
0000ooHV0?of9P000ol00002ooLR0003o`000?og8P3o000000;o00000_oh7`000ol0003on200ooPP
0003o`000004ooPN0?l0003on1h0ooPN00?o00000_oh7@000ol0003on1h0ooPN0003o`000004ooPM
0?l0003o0000o`0000;onAd000?o0000ooPN0?oh7P000ol000001?oh7P3o0000ooPP0?oh8003o`00
0004ooPQ0?l0003omb<0ooLS00?o00000_og9003o`000004ooHV0?l0003omBX0ooDZ00?o00000_od
;@03o`000006oo@a0?l0003olSH0o`000?ob=@3o00000_oa?003o`0000;okd800_l00002one:00;o
00000_o[D`02o`0000?oj5d00_l000001_oTJ@3o0000onA[0?l0003oh7L0o`0000;oggT000?o0000
om^80?oKR0000ol000000ooEV@3o0000omBM0002o`000003olf`0?l0003obk@000;o000000Go_L<0
o`000?nc`03o0000ojRn0002o`000004og:`0?l0003o0000oeNX00Oo00001_ooool00ol0003ooooo
ooooo`05ooooo`004?ooool3o`000004ooooool0003o0000o`0001[ooooo0_l000001_mT[03o0000
o`000?n:]P3o0000ojBm00?o000000Goa<@0o`000?o9^03o0000olj/000Do`000005onMO0?l0003o
jET0onUI0?l000000_o[D`000ol0003ok4h0ona>0005o`0000;ol3h000?o0000oo4k0?oa>`001Ol0
0002oo@`0003o`000?od;P3om2h000?o000000GomRP0o`000?of9`3omRL0o`000002ooHW00?o0000
0_og8`000ol0003omb80ooLR0002o`0000;on1l000?o0000ooPO0?oh7`000ol000001?oh7P3o0000
ooPN0?oh7P03o`0000;onAd000?o0000ooPM0?oh7@000ol000001?oi703o0000o`000?l00002ooTL
0003o`000?oi7@3onAd000?o000000ConAd0o`000?oh7P3on1h00ol00002ooPN0003o`000?oh8@3o
000000;o00000_og8P03o`000004ooLS0?l0003omRH0ooHV00?o00000_of:003o`000004ooD/0?l0
003om340oo@a00?o000000ColSD0o`000?l0003o00000_oa>`03o`000008onm20?l0003okDX0o`00
0?o]B@3o0000on]C0?l00002on]C0004o`000?oXG@3o0000onMN00;o00000_oTJ`02o`0000;oggT0
0_l000001?oKR03o0000omZ;0?oJR`02o`000008omBM0?l0003odZ40om:Q0?l0003obk@0o`000?o9
^@02o`000003ok?00?l0003oZ;h000;o000000?oSkP0o`000?mU[0002?l00007ooooo`03o`000?oo
oooooooo00Gooooo0009ooooo`;o00001Oooool4o`0001kooooo0ol000000omo/`3o0000o`000002
o`000003okg30?l0003o000000Co000000KocZ`0o`000?oCX03o0000omNE0?l00002omZ:0003o`00
0?oMP03o000000?oh7L000?o0000on=^0?l000000_oUIP001Ol0003oiel0onMO0?l0003ojET000Ko
00000_o^AP000ol0003okd80o`000002oo0n00?o000000GolSD0o`000?oc<P3olc80o`000002oo@`
00?o00000_oe:P000ol0003omRP0o`000005o`0000;omb<000?o0000ooLS0?og8`000ol000001?oh
7`3o0000ooPO0?oh7`03o`0000;on1d000?o0000ooPN0?l000000_l00002ooTL0003o`000?oi7@3o
nAd000?o000000ConA`0o`000?l0003o00000_oi6`000ol0003onA`0ooTL0003o`000004ooTL0?l0
003onAd0ooTM00?o00000_oi7@000ol0003on1h0ooPN0002o`0000;on1l00ol000001?oh803o0000
ooLS0?og8`03o`0000;ombD000Go0000ooHX0?l0003omRL0o`000002ooD/00?o00000_od<002o`00
00;olc@000Go0000oo4k0?l0003olCX0o`000002onm200;o00000_o]B@03o`0000;oje<00_l00000
2_oWGP3o0000onMO0?l0003oi6/0o`000?oSK03o0000ommi0?l00002ommk00;o000000GofX/0o`00
0?oIS`3ofHl0o`000002om:Q0003o`000?oAY@3o000000;o000000Coakl0o`000?l0003oZ;h00_l0
00000on?^03o0000oh:d0009o`0000Oooooo00?o0000ooooooooool01Oooool000Sooooo00Co0000
oooooooooooo00001?ooool2o`00027ooooo00?o0000og>`0?l000001Ol000001Onm``3o0000olRk
0?l0003ocJl000So00000_oJRP000ol0003ogH00o`000002on1g00[o00000_o[D@001?l0003okD/0
one;0?l00002oni600Go00000_ob>0001Ol0003olSD0oo8e0?l0003olc8000?o00000_oe;0000ol0
003omBX0ooDZ0002o`0000;ombD000?o0000ooLT0?og90001_l000001?oh803o0000ooPO0?oh7`03
o`0000;on1d000?o0000ooPM0?oh7@000_l00002ooTL0003o`000?oi703onA`000?o000000ConA/0
o`000?l0003o00000_oi6P000ol0003onA/0ooTK0003o`000004ooTK0?l0003onA`0ooTL00?o0000
0_oi70000ol0003onAd0ooTM0003o`000006ooPM0?l0003on1l0o`000?oh7P3o00000_oh8003o`00
00;omb8000?o0000ooLU0?og9@000_l00002ooHW00?o00000_oe:`001Ol0003om300o`000?od;`3o
000000;olc@00_l00002oo4j00?o00000_o_@@02o`0000;okDX00ol000000ooZE03o0000o`000002
onMO00;o00000_oSK003o`000003ommk0?l0003ogWh000;o00000_oIS`02o`000005om:Q0?l0003o
dJD0o`000?o?ZP000ol000001oo4a03o0000o`000?l0003oSkP0o`000?n2]0000ol000000omDY`3o
0000o`000003o`0000Sooooo00?o0000ooooooooool01Oooool000Sooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`0Nooooo`?o00000_n?]`02o`000003okC10?l0003o000000?o
000000KocJl0o`000?oBXP3o0000omJF0?l00002omZ;00Oo000000Cohfh0o`000?oUI@3o00000ooW
GP000ol0003ojEL0o`000002on]A00Ko000000Gol400o`000?oa?03olC`0o`000002oo8h00Go0000
0_od;P000ol0003omB`0ooD/0003o`000004ooHV0?l0003ombD0ooLU00?o00000_oh8@000ol0003o
n200o`000005o`0000;on1d01_l000000ooi703o0000o`000004o`0000;onA/00_l00002ooTJ0003
o`000?oi6P3onAX000?o000000ConAX0o`000?oi6`3onA/00ol00002ooTK0003o`000?oi703onA`0
00?o000000ConA`0o`000?oh7@3on1d00ol000001?oh7P3o0000o`000?l00002ooPO0003o`000?og
8P3omb8000?o000000Comb@0o`000?l0003o00000_of9`000ol0003omB/0ooD[0002o`0000;om2l0
0ol000001?oc=03o0000o`000?l00002oo4j000?o`000?o_@@3o0000onm20?l0003okDX0o`000?o]
BP3o0000onYD0?l0003ojUD0o`000?oWG`3o000000;oif400_l00002on=^00;o000000OogWh0o`00
0?oMP@3o0000omV?0?l0003oei8000;o000000GodJD0o`000?o?ZP3o0000olf`0003o`000005okS2
0?l0003o[;h0o`000?n2]0000ol000000omDY`3o0000o`000003o`0000[ooooo00?o0000oooooooo
ool01?ooool000Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Nooooo`?o
000000?oSkL0o`000?nZ_P000_l000001?o6_`3o0000olbb0?o</P05o`000007omJF0?l0003ofX/0
omZ;0?l0003ogH40o`000002on1g0006o`000?oSKP3ohfh0o`000?oUI@3o00000_oWGP05o`000003
one:0?l0003okT@000;okT@000Go0000oo100?o`@03o0000oo4l0003o`000005oo<c0?l0003om300
oo@`0?l000000_od;P03o`0000;omRP000?o0000ooHV0?l000000_l00002ooLR0003o`000?oh8@3o
n24000;o00000_oh7P000ol0003on1h0ooPN0003o`000004ooTL0?l0003onA/0ooTK00?o00000_oi
6P000ol0003onAX0ooTJ0003o`000004ooTJ0?l0003onAX0ooTJ00?o000000ConAT0o`000?oi6P3o
nAX00ol00002ooTJ0003o`000?oi6`3onA/000?o000000ConA/0o`000?oi703onA`00ol00002ooTL
00;o00000_oh7@000ol0003on1l0ooPO0003o`000004ooPQ0?l0003omb@0o`0000;omb<000?o0000
ooHW0?of9`000ol000002?oe:P3o0000o`000?l0003om2h0o`000?oc=03o00000_oc=0000ol0003o
lCX0oo4j0002o`0000;okd800_l00002one:00;o00000_oZE@03o`000007onMQ0?l0003oiV<0o`00
0?oSKP3o0000on9a0002o`0000;ogH400_l000000ooGTP3o0000omJG0002o`000005olnZ0?l0003o
cK00o`000?o;]P000ol000000on/_P3o0000o`000003o`000003oeBW0?l0003o000000Co00002_oo
ool00ol0003oooooooooo`04ooooo`002?ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo01gooooo0_l000000on2]03o0000o`000002o`000009olC40?l0003o0000o`000?o</P3o
0000om6U0?l0003oeIT001;o000000GojUH0o`000?o/D03ok500o`000002one:0003o`000?o^A03o
kT@000Go00000_ob=P000ol0003olc<0o`000005o`0000;omRT000?o0000ooHX0?of:0000_l00002
ooLS0003o`000?og8P3omb8000?o000000Con1h0o`000?oh7P3on1h00ol00002ooTL0003o`000?oi
703o000000;o00000_oi6P000ol0003onAX0ooTJ0003o`000004ooTI0?l0003onAX0ooTJ00?o0000
0_oj6@000ol0003onAT0o`000002o`0000;onAT000?o0000ooTJ0?oi6P000ol000001?oi6P3o0000
ooTK0?oi6`03o`0000;onA/00ol000001?oi703o0000ooPM0?oh7@03o`000004ooPN0?l0003on240
ooPQ00?o00000_og8`03o`000006ooHV0?l0003omBX0o`000?oe:P3o00000_od;P03o`0000;olc@0
0ol000001Ooa>P3o0000o`000?l0003okd8000?o000000CokD/0o`000?l0003o00000_oZEP02o`00
00;oiV<00_l000001ooRL@3o0000on5d0?l0003ogH40o`000?oLQ@000_l000000ooFU`3o0000omBL
0002o`000007olf`0?l0003obkH0o`000?o8_03o0000ojbn0002o`000004ohng0?l0003o0000ofn_
00Ko00002oooool00ol0003oooooooooo`04ooooo`002?ooool01?l0003oooooooooool00009oooo
o`;o00007Oooool01Ol0003oL[00o`000?l0003oW[/000Co00000_o:]`05o`000007omFI0?l0003o
fHd0omV=0?l0003ogH80o`000002on1h0003o`000?oSKP3o000000;oiFD000Go0000onQM0?oXG@3o
0000onYF0009o`000005oo0n0?l0003olCX0oo4j0?l000000_ob=P02o`0000;om2h000?o0000ooD/
0?oe;0001_l000001?og903o0000ooLS0?og8`03o`000004ooPO0?l0003on1h0ooPN00?o00000_oi
70000ol0003onA`0ooTL0002o`0000;onAX000?o0000ooTJ0?oi6P000ol000001?oi6@3o0000ooTI
0?oi6@03o`0000;onQT000?o0000ooXI0?oj6@000_l00002ooXI0003o`000?oi6@3onAT000?o0000
00?onAT0o`000?l000001?l00002ooTJ00?o000000ConAX0o`000?oi703onA`00ol000001?oi7@3o
0000ooPN0?oh7P03o`0000;on2000ol000001?og8`3o0000ooHV0?of9P02o`0000;omBX00ol00002
oo@^00?o000000colc@0o`000?oa>P3o0000oo4k0?l0003okd80o`000?o_@`3o0000one;0?l00002
ona=0008o`000?oZEP3o0000onUH0?l0003oiV<0o`000?oUI@02o`0000;ohG@00_l000000ooLQ@3o
0000omZ90002o`000007omBL0?l0003odZ40om:Q0?l0003obkH0o`000002olRl00?o000000CoSkL0
o`000?l0003oKjl01_l0000<ooooo`03o`000?oooooooooo00Cooooo0009ooooo`;o00003?ooool0
0ol0003oooooooooo`0Kooooo`;o000000?oSkP0o`000?l000000_ni`P02o`0000;ob[L00_l00002
omBM01?o000000?ok4l0o`000?o]B@000_o]B@001Ol0003okd<0onm30?l0003ol3h000Ko000000Co
lc40o`000?od;P3om2h00ol00002ooHX0003o`000?of9P3o000000;omb@00ol00002ooPP0003o`00
0?oh7`3o000000;o00000_oi7@000ol0003onA`0ooTL0003o`000004ooTJ0?l0003onAX0ooTJ00?o
00000_oi6@000ol0003onAT0o`000002o`0000;onQP000?o0000ooXI0?oj6@000ol000001?oj603o
0000ooXI0?oj6@03o`000004ooXH0?l0003o0000o`0000;onQP000?o0000ooTI0?oi6@000ol00000
1?oi6@3o0000ooTJ0?oi6P03o`000004ooTK0?l0003onAd0ooTM00?o00000_oh7P03o`000004ooPP
0?l0003omb<0ooLS00?o000000ComRH0o`000?l0003o00000_of:@001Ol0003om2h0o`000?od;P3o
000000;olc@00_l00002oo4k00;o00000_o_@`02o`0000?ok4d00_l00002onUH00;o000000OoiFD0
o`000?oTJ03o0000on5d0?l0003oh7P000;o000000CofXT0o`000?oISP3ofHh00_l000000ooBX@3o
0000om2W0002o`000004olRl0?l0003o0000okW200?o000000?oKjl0o`000?l000001Ol0000<oooo
o`03o`000?oooooooooo00Cooooo000Hooooo`03o`000?oooooooooo01_ooooo0_l000001_n?^03o
0000o`000?ni`P3o0000olRm00Go000000Coe9d0o`000?oHT03o00000_oLQ@000ol0003oggX0o`00
0002on9`0003o`000?oUIP3o000000?oieh000?o0000onYF0?l000000_o/C`000ol0003okDT0one9
0005o`0000;olCT000Go0000oo8e0?ob=@3o0000oo<a0003o`0000;omB/000?o0000ooHX0?of:000
1Ol00002ooLR0003o`000?oh803on20000;o00000_oh7@000ol0003onAd0ooTM0003o`000004ooTK
0?l0003onAX0ooTJ00?o00000_oi6@000ol0003onAT0ooTI0002o`0000;onQP000?o0000ooXH0?oj
60000ol000001?oj603o0000ooXH0?oj6003o`0000;onQP00_l00002ooXH0003o`000?oj603onQP0
00?o000000ConQT0o`000?oi6@3onAT00ol00002ooTJ0003o`000?oi6`3o000000;o00000_oi7003
o`000004ooPN0?l0003on200ooPP00?o00000_og8P02o`0000;omRH000?o0000ooHY0?of:@000_l0
0002oo@^00?o000000Solc@0o`000?l0003o0000oo4l0?l0003okd<0o`0000;okd@000Co0000ona=
0?l0003ok4l00ol000000ooXF`3o0000o`000002onAX00;o000000Coh7P0o`000?oNO03ogW`00_l0
00000ooISP3o0000omNC0002o`000003om2W0?l0003ocJh000?o000000?o^L80o`000?l000002Ol0
000=ooooo`03o`000?oooooooooo00Cooooo000Iooooo`03o`000?oooooooooo01_ooooo0ol00000
0on/_P3o0000o`000003o`000003olf_0?l0003odZ4000Go00000_oLQ@000ol0003oggX0o`000002
on9`0003o`000?oUIP3o000000;oieh02?l00002onm30003o`000?o`?P3o000000;olCT01Ol00002
oo@]0003o`000?oe:`3omB/000?o000000CombD0o`000?og8`3omb<01_l000001?oh7P3o0000ooPM
0?oh7@03o`0000;onA/000?o0000ooTK0?l000000_l00002ooTI0003o`000?oi6@3onAT000?o0000
00ConQP0o`000?oj603onQP00ol000000ooj603o0000o`000004o`0000;onQP00ol000001?oj603o
0000ooXH0?oj6003o`000004ooXH0?l0003onQT0ooXI00?o00000_oj6@000ol0003onAX0ooTJ0002
o`0000;onA/00ol000001?oi703o0000ooPN0?oh7P03o`0000;on1l000Go0000ooLR0?l0003omb80
o`000002ooHV00?o000000SomBX0o`000?l0003o0000oo@_0?l0003olc@0o`0000;olSD000?o0000
oo4l0?l000000_l00002onm400;o000000Ook4l0o`000?o[D@3o0000onQK0?l0003oj5d000?o0000
00Oohf`0o`000?l0003o0000omil0?l0003ogH4000;o000000?oei<0o`000?oEV@000_l000000oo=
[P3o0000ol^e0004o`000005oiZj0?l0003o0000o`000?mV[0001?l0000>ooooo`03o`000?oooooo
oooo00Cooooo000Jooooo`03o`000?oooooooooo01_ooooo1_l00002ol^e00?o000000?odZ40o`00
0?l000000_oKR00<o`0000;ojEL000?o0000ona@0?l000000_o]B@000ol0003okd<0onm30005o`00
00;olc@000?o0000oo@`0?l000001Ol00002ooHW0003o`000?og9@3o000000;o00000_oh8@000ol0
003on1l0ooPO0005o`0000;onA`01Ol00002ooTJ00Ko000000?onQP0o`000?l000001?l00002ooXH
00;o00000_oj5`000ol0003onQP0ooXH0003o`000004ooXG0?l0003onQP0ooXH00?o000000ConQP0
o`000?oj603onQP00ol00002ooXH0003o`000?oj6@3onQT000?o000000KonAX0o`000?l0003o0000
ooTJ0?l00002ooTL00?o00000_oh7@000ol0003on1l0ooPO0002o`0000;omb800ol000001_of9P3o
0000ooDZ0?l0003omBX0o`0000;om2l00ol00002oo8e00;o00000_o`?@03o`000003oni60?l0003o
000000;oje400_l000001_oXG@3o0000onMQ0?l0003ohf`0o`0000;ohW000_l000000ooMP@3o0000
om^60002o`000003omFI0?l0003odZ0000;o000000CobkD0o`000?l0003oa<@01Ol000000omV[03o
0000o`000002o`00013ooooo00?o0000ooooooooool00oooool001_ooooo0_l0000Kooooo`05o`00
0?n;]`3o0000o`000?nh`P000_l000000oo;]@3o0000om2W0005o`0000;ofhP000?o0000omim0?l0
00000_oRLP000ol0003oi6P0o`000002onMO0003o`000?oYE`3ojEL000So000000Gol3h0o`000?oa
>@3olCT0o`000002oo<d00;o00000_od;@001?l0003omBX0ooDZ0?l00002ooHW00;o00000_og8P00
0ol0003on240ooPQ0003o`000004ooPM0?l0003onA`0ooTL00?o000000ConAX0o`000?oi6P3onAX0
0ol00002ooXI0003o`000?oj603o000000;o00000_oj60000ol0003onQP0ooXH0003o`000004ooXG
0?l0003onQL0ooXG00?o000000ConQL0o`000?oj5`3onQL00ol00002ooXG0003o`000?oj603o0000
00;o00000_oj6006o`000006ooXI0?l0003o0000o`000?oi6@3o00000_oi6P03o`0000;onA`000?o
0000ooPM0?oh7@000ol000001_oh7`3o0000o`000?l0003omb80o`0000;omRH00_l00002ooDZ00?o
00000_od<003o`000005oo8f0?l0003o0000o`000?o`?P000ol000001?o^B03o0000o`000?l00002
onYD00;o000000Ooif40o`000?l0003o0000on9`0?l0003ohG@000;o000000?ofhH0o`000?oIS000
0_l000000ooBX03o0000om2W0003o`000004olC40?l0003o0000ojBm00Oo00004Oooool00ol0003o
ooooooooo`03ooooo`007Oooool00ol0003oooooooooo`0Iooooo`;o000000CoZ;h0o`000?l0003o
b;`00ol000001Oo@Y`3o0000omFJ0?l0003ofHd000oo000000Goje40o`000?o]BP3okDX0o`000002
onm30003o`000?o`?P3o000000Go000000Com300o`000?od;@3om2d01_l000001?og903o0000ooLR
0?og8P03o`000004ooPN0?l0003on1d0ooPM00?o00000_oi6`000ol0003onAX0o`000002o`0000;o
nQT000?o0000ooXI0?oj6@000_l00002ooXH0003o`000?oj603onQP000?o000000ConQL0o`000?oj
5`3onQL00ol00002ooXG0003o`000?oj5`3o000000;o00000_oj5`000ol0003onQL0ooXG0002o`00
00;onQL00ol000001?oj603o0000ooXH0?oj6003o`0000;onQP000?o0000ooTI0?l000000_l00002
ooTJ0003o`000?oi703onA`000?o000000Kon1d0o`000?l0003o0000ooPO0?l00002ooLR00?o0000
00ComRH0o`000?l0003o00000_oe:`03o`00000<oo@a0?l0003olSH0o`000?ob>03o0000oo0n0?l0
003ol400o`000?o^B03o00000_o]B`001?l0003ojU@0o`000?oYE`02o`0000;oiFD00_l000000ooQ
M03o0000ommj0002o`000003omV<0?l0003oei<000;o000000?od:L0o`000?o=[`001?l000000onT
_@3o0000o`000006o`00017ooooo00?o0000ooooooooool00oooool001kooooo00?o0000oooooooo
ool06?ooool01Ol0003oU[T0o`000?l0003oa<@000?o000000?ocJh0o`000?l000000ol000001?oI
S@3o0000omf10?l00002on5f0006o`000?oTJ`3oi6/0o`000?oVHP3o00000_oYF@000ol0003oje40
o`000007o`0000;olCT000Go0000oo<d0?oc=03o0000oo@`0003o`0000;omRT000?o0000ooHW0?of
9`001Ol00002ooPP0003o`000?oh7P3o000000;o00000_oi70000ol0003onA/0ooTK0002o`0000;o
nAT000?o0000ooXI0?oj6@000ol000001?oj603o0000ooXH0?oj6003o`000004ooXG0?l0003onQL0
ooXG00?o00000_oj5`000ol0003onQL0ooXG0002o`0000;onQL01_l000001_oj5`3o0000o`000?l0
003onQL0o`0000;onQP00ol00002ooXH0003o`000?oj603onQP000;o00000_oi6@000ol0003onAX0
ooTJ0003o`000006ooTK0?l0003o0000o`000?oh7@3o00000_oh7`03o`0000;omb<00_l00002ooHW
0005o`000?oe:`3o0000ooD/0?l000000_od<@02o`0000;olSP00_l00002oo1000?o00000_o]B`02
o`000007onUG0?l0003oj5/0o`000?oUI@3o0000onAY0002o`000003ommj0?l0003ogGl000;o0000
00?oei<0o`000?oEVP000_l000001?o=[`3o0000o`000?o6_`0:o`0001;ooooo00?o0000oooooooo
ool00oooool001oooooo00?o0000ooooooooool06?ooool00ol0003oU[T0o`000002o`0000;obkH0
0_l00002om:P01;o00000_o]B`001_l0003okT@0oni40?l0003ol3h0o`0000;olCT01Ol00002oo@]
0003o`000?of:@3omRT000?o000000Comb@0o`000?og8P3omb801Ol00002ooTM0003o`000?oi703o
nA`000?o000000ConAX0o`000?oi6@3onAT00ol000001?oj603o0000ooXH0?oj6003o`0000;onQL0
00?o0000ooXG0?l000000_l00002ooXG00Ko000000KonQL0o`000?l0003o0000ooXG0?l00002ooXG
00?o00000_oj5`000ol0003onQL0o`000002o`0000;onQL000?o0000ooXH0?oj60000ol000001?oj
603o0000ooTI0?oi6@03o`000006ooTJ0?l0003o0000o`000?oi703o00000_oh7@03o`0000;on200
0ol000001?og8`3o0000ooHW0?of9`02o`0000;omB`00ol000001?oc<P3o0000o`000?l00002oo4j
00;o00000_o_@`03o`000003ona>0?l0003o000000;oj5/00_l000000ooTJ@3o0000on=^0002o`00
0003omeo0?l0003ofhH000;o000000?oeIX0o`000?oBX@000ol000001?o6_`3o0000o`000?n/_P08
o`0001;ooooo00?o0000ooooooooool00oooool0023ooooo0_l0000Iooooo`;o000000?o/l00o`00
0?l000000_o;]P06o`0000;ofhH000?o0000ommj0?l000000_oSK`000ol0003oiFD0o`000002onQK
0003o`000?o[D`3o000000;okD/02?l00002oo8e0003o`000?od<03o000000Go00000_of9`000ol0
003omb@0o`000002o`0000;on20000?o0000ooPN0?l000001Ol00002ooTK00Go00000_oj6@05o`00
00;onQP01Ol00002ooXG00?o000000ConQL0o`000?oj5`3onQL00ol00002ooXG0003o`000?oj5`3o
000000;o00000_oj5`000ol0003onQL0ooXG0002o`0000;onQL000?o0000ooXG0?oj5`000ol00000
0ooj603o0000o`000004o`000004ooTI0?l0003o0000o`0000;onAX000?o0000ooTL0?l000000_l0
0002ooPN00?o000000Con200o`000?og8`3omb<00ol000001?of9`3o0000o`000?l00002oo@]00;o
00000_oc<`003?l0003olCX0o`000?oa?03o0000onm30?l0003okTH0o`000?o/CP3o0000on]A00?o
000000Koiel0o`000?l0003ohfh0o`000?oQM002o`00000:om^60?l0003ofHd0omV=0?l0003odZ40
o`000?o?Z@3o0000olbb00;o000000?o[;h0o`000?l000001Ol00002ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool002;ooooo00?o0000ooooooooool05oooool9o`000003
omFI0?l0003ofH`0017o00000_o^AP000ol0003ol400o`000002oo4j00Go00000_od;@001?l0003o
mBX0ooDZ0?l00002ooHW00;o00000_og8P000ol0003on200ooPP0002o`0000;onAd000?o0000ooTL
0?oi70000ol000001?oi6P3o0000ooTI0?oi6@03o`000004ooXH0?l0003onQP0ooXH00?o000000Co
nQL0o`000?oj5`3onQL00ol00002ooXG0003o`000?oj5`3o000000;o00000_oj5`000ol0003onQL0
ooXG0002o`0000;onQL000?o0000ooXG0?oj5`000ol000000ooj5`3o0000o`000004o`000004ooXG
0?l0003o0000o`0000;onQP000?o0000ooXH0?l000000_l00002ooTI0003o`000?oi6P3onAX000;o
00000_oi7003o`000004ooPN0?l0003on200ooPP00?o000000Comb@0o`000?l0003o00000_of:000
1Ol0003om2d0o`000?od;P3o000000;olc<00_l00002oo4l00;o00000_o^AP02o`000007on]A0?l0
003ojUD0o`000?oWG`3o0000onIT0002o`000004on5d0?l0003oggX0ommj00;o000000WofHd0o`00
0?oGU03o0000olnY0?l0003oc;80o`000?o8^`002?l00004ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool002?ooooo00?o0000ooooooooool05oooool2o`000006okg30?l0
003o0000olf`0?l0003odZ401Ol000001ooMO`3o0000on5d0?oQM03o0000onAY0?l000000_oWG`00
1_l0003ojUH0onYF0?l0003ok4h0o`0000;okTH01Ol00002oo8f0003o`000?oc<@3o000000;om2d0
1_l000001?og903o0000ooLR0?og8P03o`000004ooPN0?l0003onAd0ooTM00?o000000ConA/0o`00
0?oi6P3onAX00ol00002ooXH0003o`000?oj603o000000;o00000_oj5`000ol0003onQL0o`000002
o`0000;onQL000?o0000ooXG0?oj5`000_l00002ooXG0003o`000?oj5`3onQL000?o000000?onQL0
o`000?l000001?l000001?oj5`3o0000o`000?l00002ooXG0003o`000?oj5`3o000000;o00000_oj
5`000ol0003onQP0ooXH0002o`0000;onQP000?o0000ooTI0?oi6@000ol000001_oi6P3o0000o`00
0?l0003onA`0o`0000;on1h00ol000001?oh8@3o0000o`000?l00002ooLU0003o`000?of:03omRP0
00;o00000_od;P03o`000005oo8f0?l0003o0000o`000?o`?P000ol000000oo]B@3o0000o`000002
onYE00;o000000CoiV@0o`000?oTJ@3oi6T00_l000000ooONP3o0000omf10002o`000003omND0?l0
003oe9d000?o000000?ob;/0o`000?l000001_l00005ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool05_ooool01Ol0003oZKh0o`000?l0
003obKT000Go000000?oei<0o`000?oKQP004Ol000001Oo_@P3o0000oo4l0?oa?03o000000;olSH0
1Ol00002ooD[0003o`000?of9`3o000000Go00000_oh80000ol0003on1h0o`000002o`0000;onA`0
00?o0000ooTK0?l000000_l00002ooTI0003o`000?oj603onQP000;o00000_oj60000ol0003onQL0
ooXG0002o`0000;onQL000?o0000ooXG0?oj5`000ol000000ooj5`3o0000o`000004o`000004ooXG
0?l0003o0000o`0000;onQL000?o0000ooXG0?l000000_l00002ooXG0003o`000?oj5`3onQL000;o
00000_oj5`000ol0003onQL0ooXG0003o`000004ooXH0?l0003onQP0ooXH00?o000000KonAT0o`00
0?l0003o0000ooTK0?l00002ooTL00?o00000_oh7P02o`0000;omb8000?o0000ooLU0?og9@000ol0
00001Ooe:P3o0000o`000?l0003om30000?o000000GolSP0o`000?l0003o0000onm20003o`0000;o
k4d00_l000001ooYFP3o0000o`000?l0003oi6T0o`000?oSK`000_l000000ooMP@3o0000om^80002
o`000004omBM0?l0003o0000olf_00Wo00001oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo000Uooooo`;o00005oooool6o`000003olnZ0?l0003oe9`000Go000000OoggX0
o`000?oSKP3ohfh0o`000?oVI03o000000;ojEX000?o0000on]A0?l000000_o]B@000ol0003okd80
o`000005o`000005oo<c0?l0003om2h0oo@^0?l000000_oe:`02o`0000;ombD000?o0000ooLR0?og
8P001Ol00002ooTM0003o`000?oi703onA`000;o00000_oi6P000ol0003onAT0ooTI0003o`000004
ooXH0?l0003onQP0ooXH00?o000000?onQL0o`000?l000001?l000001?oj5`3o0000o`000?l00002
ooXG0003o`000?oj5`3o000000;o00000_oj5`000ol0003onQL0ooXG0002o`0000;onQL000?o0000
ooXG0?oj5`000ol000001?oj5`3o0000ooXG0?oj5`03o`000003ooXG0?l0003o000000Co000000Co
nQP0o`000?l0003o00000_oi6P000ol0003onA/0o`000002o`0000;onAd00ol000001?oh7`3o0000
ooLR0?og8P03o`00000@ooHV0?l0003o0000o`000?oe;03o0000oo@`0?l0003olc80o`000?ob>03o
0000oo4k0?l0003okd80o`0000;okTD000Co0000ona=0?l0003oje400_l00002onMO00;o000000?o
hfl0o`000?oQMP000_l000000ooKR03o0000omR@0003o`000004olf_0?l0003o0000olG200Ko0000
2Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo000Wooooo`03o`000?oo
oooooooo01Gooooo00Go0000ok700?l0003o0000ol^d0004o`0000;ofHh000?o0000omf10?l00000
4?l000001_o`?P3o0000oo8h0?ob>03o0000oo<c00Ko000000ComRP0o`000?og9@3ombD00ol00002
ooPQ0003o`000?oh7P3o000000Go000000?onA/0o`000?l000001?l000000ooj603o0000o`000004
o`000004ooXG0?l0003o0000o`0000;onQL000?o0000ooXG0?oj5`000_l00002ooXG0003o`000?oj
5`3onQL000;o00000_oj5`000ol0003onQL0ooXG0003o`000004ooXG0?l0003onQL0ooXG00?o0000
00?onQL0o`000?l000001?l000001?oj5`3o0000o`000?l00002ooXG0003o`000?oj603o000000;o
00000_oj6@000ol0003onAX0ooTJ0002o`0000;onA/00ol000001?oh7@3o0000ooPO0?oh7`03o`00
0006ooLS0?l0003o0000o`000?of:03o00000_oe;002o`0000;olc800ol000001?oa>`3o0000o`00
0?l00002oni500;o000000?oje40o`000?oZEP000ol000001_oUI@3o0000o`000?oQMP3o0000omim
00;o000000Cof900o`000?l0003odZ800ol000000oo5`P3o0000o`000004o`0000[ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00:?ooool00ol0003oooooooooo`0Eoooo
o`;o000000?oakl0o`000?l000000_oAY@06o`0000;ohG@000?o0000onAY0?l000000_oWG`000ol0
003ojUD0o`000002ona=0003o`000?o^A@3okTD000So000000Com300o`000?oe;03omB`01Ol00002
ooLS0003o`000?oh8@3on24000;o00000_oh7@000ol0003onA`0ooTL0002o`0000;onAX000?o0000
ooTI0?oi6@000_l00002ooXH0003o`000?oj603onQP000;o00000_oj5`000ol0003onQL0ooXG0003
o`000004ooXG0?l0003onQL0ooXG00?o000000ConQL0o`000?oj5`3onQL00ol000000ooj5`3o0000
o`000004o`000004ooXG0?l0003o0000o`0000;onQL000?o0000ooXG0?l000000_l00002ooXG0003
o`000?oj5`3onQL000;o00000_oj60000ol0003onQT0ooXI0003o`000006ooTJ0?l0003o0000o`00
0?oi703o00000_oh7@03o`000006ooPP0?l0003o0000o`000?og903o00000_of:003o`000004oo@^
0?l0003o0000o`0000;olSD00_l00002oo0n00?o000000KokDT0o`000?l0003ojUH0o`000?oXF`03
o`000006onA[0?l0003o0000omim0?l0003og8D00ol000001?oBXP3o0000o`000?o:]P07o`0000co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00:Oooool00ol0003ooooo
ooooo`0Eooooo`Wo00000_oJR@0@o`000005onm20?l0003olC/0oo4k0?l000000_ob=@05o`000004
ooHY0?l0003omRH0ooHV00Ko000000Con1l0o`000?oh7@3on1d00ol000001?oi6`3o0000ooTJ0?oi
6P03o`000004ooXI0?l0003onQP0ooXH00?o000000ConQL0o`000?oj5`3onQL00ol000001?oj5`3o
0000ooXG0?oj5`03o`000003ooXG0?l0003o000000Co00000_oj5`02o`0000;onQL000?o0000ooXG
0?oj5`000_l00002ooXG0003o`000?oj5`3onQL000;o00000_oj5`000ol0003onQL0ooXG0003o`00
0004ooXH0?l0003onQP0ooXH00?o000000KonQT0o`000?l0003o0000ooTJ0?l00002ooTL00?o0000
00Con1h0o`000?l0003o00000_og8P000ol0003omb@0o`000002o`0000;omRT00_l00002oo@`00?o
000000GolSP0o`000?l0003o0000onm20003o`000006ona>0?l0003o0000onQK0?l0003oiV800ol0
00000ooRLP3o0000o`000003o`000005omJF0?l0003o0000o`000?o:]P001ol0000>ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00_ooool002[ooooo00?o0000ooooooooool05Ooo
ool2o`000006olRk0?l0003o0000om:Q0?l0003oei801Ol000001OoRL03o0000onEU0?oUI@3o0000
00;oj5/000?o0000on]A0?l000000_o]B@08o`000004oo<b0?l0003om2h0oo@^00Go00000_og9000
0ol0003omb80o`000005o`000003ooTL0?l0003o000000Co00000_oi6@000ol0003onQT0o`000002
o`0000;onQP01Ol00002ooXG00Go00000_oj5`02o`0000;onQL000?o0000ooXG0?oj5`000ol00000
1?oj5`3o0000ooXG0?oj5`03o`000004ooXG0?l0003onQL0ooXG00?o000000ConQL0o`000?oj5`3o
nQL00ol000000ooj5`3o0000o`000004o`000006ooXH0?l0003o0000o`000?oi6@3o00000_oi6P03
o`0000;onA`00_l00002ooPO0003o`000?og8P3omb8000;o00000_of9P03o`00000=ooD/0?l0003o
0000o`000?oc<`3o0000oo8h0?l0003olC`0o`000?o_@P3o0000oni60003o`000005on]C0?l0003o
0000onIR0?l000000_oTJ003o`0000;ogH8000Ko0000omJF0?l0003odj00o`000?o?ZP07o`00013o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00:oooool2o`0001Gooooo
00Go0000okk30?l0003o0000olj/0005o`000003omb50?l0003oh7P000co000000GokTH0o`000?o`
?P3ol3h0o`000002oo8h00Go000000GomB`0o`000?of:03omRP0o`000002ooLT00;o00000_oh8000
0ol0003on1h0ooPN0002o`0000;onA`000?o0000ooTJ0?oi6P001Ol00002ooXH00?o000000ConQP0
o`000?oj5`3onQL00ol000001?oj5`3o0000ooXG0?oj5`03o`000004ooXG0?l0003onQL0ooXG00?o
000000ConQL0o`000?oj5`3onQL00ol000001?oj5`3o0000ooXG0?oj5`03o`000003ooXG0?l0003o
000000Co000000ConQL0o`000?l0003o00000_oj5`000ol0003onQP0o`000002o`0000;onQT000?o
0000ooTI0?l000000_l00002ooTK00?o000000Con1d0o`000?oh7`3on1l00ol000002_og8`3o0000
o`000?l0003omRP0o`000?oe;03o0000oo@^0?l00002oo<c00;o00000_oa?002o`000004oni60?l0
003okD/0one;00;o000000OojET0o`000?l0003o0000onAX0?l0003ohW0000;o000000?ogH80o`00
0?oJR`000ol000000oo?ZP3o0000o`000005o`00017ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`01ooooo`00;Oooool00ol0003oooooooooo`0Cooooo`Ko000000?oe9d0o`000?oI
S`001ol00002onMQ0003o`000?oYE`3o000000;ok4h02?l000001_ob=P3o0000oo@`0?od<03o0000
ooD/00Ko000000Comb<0o`000?oh803on2000ol000001?oh7@3o0000ooTL0?oi7003o`000004ooTJ
0?l0003onQT0ooXI00?o000000ConQP0o`000?oj603onQP00ol000001?oj5`3o0000ooXG0?oj5`03
o`000004ooXG0?l0003onQL0ooXG00?o000000?onQL0o`000?l000001?l00002ooXG00Go00000_oj
5`02o`0000;onQL000?o0000ooXG0?oj5`000_l00002ooXG0003o`000?oj5`3onQL000;o00000_oj
60000ol0003onQT0ooXI0002o`0000;onAX00ol000001?oi703o0000ooPM0?oh7@03o`000006ooPQ
0?l0003o0000o`000?og9@3o00000_of:002o`0000;om2h00ol000001Oob=P3o0000o`000?l0003o
l40000?o000000?okD/0o`000?o[D@000_l00002onMO00;o000000?ohW00o`000?oPN0000_l00000
1?oJR`3o0000o`000?oCW`08o`0001?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`01ooooo`00;_ooool00ol0003oooooooooo`0Dooooo`?o000000?od:P0o`000?l000000_l00002
omf10004o`000?oQM03o0000onAX00Oo000000GokD/0o`000?o_@`3okd<0o`000002oo4l0003o`00
0?ob=P3o000000Go000000ComBX0o`000?of9P3omRH01Ol00002ooPO00Go00000_oi6`000ol0003o
nAX0o`000002o`0000;onQT000?o0000ooXH0?l000000_l00002ooXG0003o`000?oj5`3o000000;o
00000_oj5`05o`0000;onQL00_l00002ooXG0003o`000?oj5`3onQL000?o000000ConQL0o`000?oj
5`3onQL00ol000001?oj5`3o0000ooXG0?oj5`03o`000004ooXG0?l0003onQL0ooXG00?o000000?o
nQP0o`000?l000001?l000001_oi6@3o0000o`000?l0003onA/0o`0000;onA`00ol000001_oh7P3o
0000o`000?l0003omb80o`0000;ombD00ol000001Ooe:`3o0000o`000?l0003olc4000?o000000Co
lCX0o`000?l0003o00000_o^A002o`000003on]A0?l0003ojEL000?o000000KoiFH0o`000?l0003o
h7P0o`000?oMP@03o`000003om>O0?l0003o000000Ko00005Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo007ooooo000_ooooo`03o`000?oooooooooo01Cooooo7Ol00002oo<c0003
o`000?od;P3om2h000Go000000CombD0o`000?og8P3omb800ol000001?oh7P3o0000ooTM0?oi7@05
o`0000;onAX01Ol00002ooXH00Go00000_oj5`03o`000004ooXG0?l0003onQL0ooXG00?o000000Co
nQL0o`000?oj5`3onQL00ol000001?oj5`3o0000ooXG0?oj5`03o`000004ooXG0?l0003onQL0ooXG
00?o000000?onQL0o`000?l000001?l000001_oj5`3o0000o`000?l0003onQP0o`0000;onQP00ol0
00001?oi6P3o0000ooTK0?oi6`03o`000004ooTM0?l0003o0000o`0000;on20000?o0000ooLR0?l0
00000_l000001?of9`3o0000o`000?l00002oo@]00;o00000_ob=@02o`0000;ol3h00ol000001_o]
BP3o0000o`000?oYE`3o0000onMN00?o000000?ohfh0o`000?l000000ol000000ooGU03o0000o`00
0006o`0001Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00<?ooool2
o`0001Gooooo0_l000001?o</`3o0000o`000?oFU`05o`000007on9a0?l0003oiFD0onEU0?l0003o
j5/0o`000002on]A0003o`000?o^B03o000000;ol4002?l000001?od;@3o0000ooHX0?of:005o`00
00;on24000?o0000ooPN0?l000000_l00002ooTL0003o`000?oi6`3o000000;o00000_oi6@000ol0
003onQP0o`000002o`0000;onQP000?o0000ooXG0?l000000_l00002ooXG0003o`000?oj5`3o0000
00;o00000_oj5`000ol0003onQL0o`000002o`000004ooXG0?l0003onQL0ooXG00?o000000?onQL0
o`000?l000001?l000001?oj5`3o0000o`000?l00002ooXG0003o`000?oj5`3o000000;o00000_oj
60000ol0003onQP0o`000002o`0000;onAT000?o0000ooTJ0?l000000_l00002ooTL00;o00000_oh
7P000ol0003on200ooPP0002o`0000;omb@00_l00002ooDZ00?o000000Gom300o`000?l0003o0000
oo4i0003o`000005onm30?l0003o0000o`000?o/D0000_l000000ooWGP3o0000onEU0004o`000003
omf00?l0003o000000Wo00006Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007o
oooo000booooo`03o`000?oooooooooo01;ooooo00Go0000olK10?l0003o0000om6S0002o`0000;o
fhP000?o0000ommk0?l000003Ol000001Oo`?P3o0000oo8h0?ob>03o000000;olc801Ol000001?of
9`3o0000ooLT0?og9005o`0000;on1h000?o0000ooTL0?oi70000_l00002ooTJ0003o`000?oi6@3o
nAT000;o00000_oj60000ol0003onQP0ooXH0002o`0000;onQL000?o0000ooXG0?oj5`000_l00002
ooXG00Go00000_oj5`05o`0000;onQL00_l00002ooXG0003o`000?oj5`3onQL000;o00000_oj5`00
0ol0003onQL0ooXG0002o`0000;onQL000?o0000ooXH0?oj60000_l00002ooXH00Go00000_oi6`03
o`000004ooTM0?l0003on1h0ooPN00?o000000Gomb80o`000?l0003o0000ooHW0003o`00000=oo@]
0?l0003om300o`000?oc=03o0000oo4i0?l0003ol3h0o`000?o_@`3o0000one90003o`000006onYF
0?l0003o0000onEU0?l0003ohfh00_l000001?oMP03o0000o`000?oGU@08o`0001_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`01ooooo`00<oooool00ol0003oooooooooo`0Boooo
o`ko000000OoiV<0o`000?oYF03ojEP0o`000?o/C`3o000000;okTH02?l000001?od<@3o0000ooD/
0?oe;005o`0000;omb<000?o0000ooPP0?l000001Ol000000ooi703o0000o`000004o`000003ooTI
0?l0003o000000Co000000?onQP0o`000?l000001?l000001_oj5`3o0000o`000?l0003onQL0o`00
00;onQL00ol000001?oj5`3o0000ooXG0?oj5`03o`000004ooXG0?l0003onQL0ooXG00?o000000Co
nQL0o`000?oj5`3onQL00ol000000ooj5`3o0000o`000004o`000006ooXH0?l0003o0000o`000?oi
6@3o00000_oi6P03o`000003ooTL0?l0003o000000Co000000Gon200o`000?l0003o0000ooLT0003
o`000004ooHY0?l0003om2d0oo@]00;o00000_oc=002o`0000;ol3h00_l000001?o]B@3o0000ona?
0?o/C`02o`000003onQM0?l0003o000000;o000000?oh7L0o`000?l000000ol000000ooCX03o0000
o`000004o`0001gooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool003Cooooo00?o
0000ooooooooool04oooool9o`000003ommi0?l0003ohf`000Wo000000Gokd@0o`000?o`?@3ol3d0
o`000002oo8f00Go000000ComB/0o`000?of9`3omRL01Ol00002ooPP0003o`000?oh7P3on1h000;o
00000_oi70000ol0003onAX0ooTJ0002o`0000;onAT000?o0000ooXH0?l000000_l00002ooXH0003
o`000?oj5`3o000000;o00000_oj5`000ol0003onQL0o`000002o`0000;onQL000?o0000ooXG0?l0
00000_l000000ooj5`3o0000o`000004o`000003ooXG0?l0003o000000Co000000KonQL0o`000?l0
003o0000ooXH0?l00002ooXH00?o000000ConQT0o`000?oi6@3onAT00ol000001_oi6`3o0000o`00
0?l0003onAd0o`0000;on1h00ol000001_og8P3o0000o`000?l0003omRL0o`0000;omRT00ol00000
1Ood<03o0000o`000?l0003olCT000?o000000Ookd<0o`000?l0003o0000ona?0?l0003ojUH000;o
000000?oiFD0o`000?oSKP000_l000001?oMP@3o0000o`000?oFUP07o`0001oooooo00?o0000oooo
ooooool01_ooool1o`00007ooooo0Oooool003Gooooo0_l0000Dooooo`Oo000000?og8@0o`000?l0
00004Ol000001?ob=@3o0000oo@`0?od<005o`0000;omRH000?o0000ooLS0?l000001Ol000001?oh
7@3o0000ooTL0?oi7003o`000004ooTJ0?l0003onAT0ooTI00;o00000_oj60000ol0003onQP0ooXH
0002o`0000;onQL000?o0000ooXG0?oj5`000_l00002ooXG00Go00000_oj5`02o`0000;onQL000?o
0000ooXG0?oj5`000_l00002ooXG0003o`000?oj5`3onQL000;o00000_oj5`000ol0003onQP0o`00
0002o`0000;onQP01Ol00002ooTJ00;o00000_oi70000ol0003onAd0o`000002o`0000;on2000_l0
0002ooLT0003o`000?of9`3o000000;o00000_od;@02o`0000;olc@00_l00002oo0n00;o00000_o]
B@04o`000006onMN0?l0003o0000on=^0?l0003oh7P02_l0000Qooooo`03o`000?oooooooooo00Ko
oooo0Ol00001ooooo`7ooooo000gooooo`03o`000?oooooooooo01;ooooo0_l000001?o=[`3o0000
o`000?oHT@05o`000007onA[0?l0003oiel0onMO0?l0003ojUD0o`000002one;0003o`000?o_@`3o
000000Oo000000Com2l0o`000?oe:P3omBX01Ol00002ooLR0003o`000?oh7`3on1l000Go000000?o
nA/0o`000?l000001?l000000ooi6@3o0000o`000004o`000003ooXH0?l0003o000000Co000000Ko
nQL0o`000?l0003o0000ooXG0?l00002ooXG00?o000000ConQL0o`000?oj5`3onQL00ol000001?oj
5`3o0000ooXG0?oj5`03o`000003ooXG0?l0003o000000?o00000_oj6003o`000004ooXI0?l0003o
nAT0ooTI00?o000000ConA/0o`000?oi703onA`00_l00002ooPN00?o000000Comb80o`000?og903o
mb@00_l00002ooDZ00?o000000Gom300o`000?l0003o0000oo4i0003o`000003onm30?l0003o0000
00;o000000GojEL0o`000?l0003o0000onEV0006o`000003omFI0?l0003o000000Co00008oooool0
0ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00>?ooool00ol0003oooooooooo`0Boooo
o`Wo000000?ohGH0o`000?l000002Ol00002onm20003o`000?oa>`3o000000;olc@01Ol00002ooDZ
0003o`000?of9P3o000000Go000000Con1l0o`000?oh7@3on1d00_l00002ooTL0003o`000?oi6P3o
nAX000;o00000_oi6@000ol0003onQP0ooXH0002o`0000;onQP000?o0000ooXH0?l000000_l00002
ooXG0003o`000?oj5`3o000000;o000000ConQL0o`000?oj5`3onQL00ol000000ooj5`3o0000o`00
0004o`000006ooXG0?l0003o0000o`000?oj603o00000_oj6003o`000004ooXI0?l0003onQT0ooXI
00?o000000?onAX0o`000?l000001?l000001Ooh7@3o0000o`000?l0003on24000Ko000000GomRL0
o`000?l0003o0000oo@]0003o`000005oo8e0?l0003o0000o`000?o`?P000ol000001_o]BP3o0000
o`000?oYE`3o0000onMO00Co000000?oggX0o`000?l000002?l0000Uooooo`03o`000?oooooooooo
00Cooooo0Ol00001ooooo`7ooooo000iooooo`03o`000?oooooooooo01?ooooo0ol000001?oCW`3o
0000o`000?oMPP0Co`0000;olc@000?o0000oo@^0?l000001?l00002ooHV0003o`000?og8P3omb80
00Go000000?on1d0o`000?l000001?l000001?oi6P3o0000ooTI0?oi6@03o`000003ooXI0?l0003o
000000?o00000_oj6005o`0000;onQL01Ol00002ooXG00;o00000_oj5`000ol0003onQL0ooXG0002
o`0000;onQP000?o0000ooXH0?l000000_l00002ooXH0003o`000?oj6@3o000000;o000000KonAX0
o`000?l0003o0000ooTL0?l00002ooTL00?o000000Kon1l0o`000?l0003o0000ooLS0?l00002ooLU
00?o000000GomB/0o`000?l0003o0000oo<a0003o`000005oo4j0?l0003o0000o`000?o^A0000ol0
00000oo[D@3o0000o`000002o`000003onAX0?l0003o000000;o000000?og8D0o`000?l000001_l0
000Wooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000jooooo`03o`000?oooooo
oooo01?ooooo1?l000000ooHT03o0000o`000003o`000007onAX0?l0003oj5d0onQM0?l0003oje<0
o`000002one:0003o`000?o_@P3o000000Oo00000_od;P000ol0003omRT0o`000005o`000004ooLR
0?l0003on1l0ooPO00;o00000_oh7P000ol0003onA`0ooTL0005o`000004ooTJ0?l0003o0000o`00
00;onQT000?o0000ooXH0?l000000_l000001?oj603o0000ooXH0?oj6003o`000004ooXH0?l0003o
nQL0ooXG00?o000000ConQP0o`000?oj5`3onQL00ol000000ooj603o0000o`000003o`0000;onQP0
1Ol00002ooTJ00;o00000_oi6`000ol0003onA`0o`000002o`0000;on1h00_l00002ooLR0003o`00
0?og8`3o000000;o000000ComRP0o`000?l0003o00000_od;P02o`0000;olSH00_l00002oo1000;o
000000OokD/0o`000?l0003o0000onUI0?l0003oiV8000;o000000?ohW80o`000?oNO@002?l0000Y
ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000kooooo`;o00005?ooool2o`00
0003olf`0?l0003o000000?o000000?ohGD0o`000?l000002_l000001_o_@@3o0000oo4j0?oa>P3o
0000oo<d00Go00000_oe:P000ol0003omRH0o`000005o`000004ooPP0?l0003on1h0ooPN00?o0000
00ConA`0o`000?oi6`3onA/00_l00002ooTJ0003o`000?oj6@3onQT000;o00000_oj6@000ol0003o
nQP0o`000002o`0000;onQP01Ol000000ooj603o0000o`000004o`000006ooXH0?l0003o0000o`00
0?oj603o00000_oj6003o`000004ooTI0?l0003onAT0ooTI00?o000000?onA/0o`000?l000000ol0
0002ooPM00?o000000Con200o`000?og8P3omb800_l00002ooHV00;o00000_oe;003o`000005oo<c
0?l0003o0000o`000?oa?0000ol000000oo^AP3o0000o`000002on]C00Co000000?oi6/0o`000?l0
00002?l0000/ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00?Oooool00ol0003ooooo
ooooo`0Booooo`Ko000000?ogH80o`000?l000004Ol00002oo<d0003o`000?od;P3o000000Co0000
0_of9P000ol0003omb<0ooLS0005o`000003ooPN0?l0003o000000Co000000?onA/0o`000?l00000
1?l000000ooi6@3o0000o`000003o`0000;onQP00ol000001?oj603o0000ooXH0?oj6002o`0000;o
nQP000?o0000ooXH0?oj60000_l00002ooXH0003o`000?oj603o000000;o000000?onAT0o`000?l0
00001?l000001_oi6P3o0000o`000?l0003onA`0o`0000;onAd00ol000000ooh7`3o0000o`000004
o`000005ooLT0?l0003o0000o`000?of:@000ol000001Ood<03o0000o`000?l0003olSP000?o0000
00Gokd80o`000?l0003o0000ona>0004o`000003onEU0?l0003o000000?o000000?ofHd0o`000?l0
00001?l0000^ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00?_ooool00ol0003ooooo
ooooo`0Cooooo`?o000000?odZ40o`000?l000002?l00002on]C0003o`000?o]BP3o000000Wo0000
0_od;`000ol0003omBX0o`000005o`000003ooLS0?l0003o000000?o00000_oh7P000ol0003onAd0
ooTM0002o`0000;onA`000?o0000ooTJ0?l000000_l00002ooTJ0003o`000?oi6@3o000000;o0000
00ConAT0o`000?oj603onQP00ol000001?oj6@3o0000ooXH0?oj6003o`000003ooXI0?l0003o0000
00?o00000_oi6@02o`0000;onAX000?o0000ooTJ0?oi6P000_l00002ooTL0003o`000?oi703o0000
00;o000000Kon1h0o`000?l0003o0000ooLR0?l00002ooLS00?o000000GomRP0o`000?l0003o0000
oo@^0003o`000005oo8e0?l0003o0000o`000?o`?P000ol000001Oo]B@3o0000o`000?l0003ojUH0
00Go000000?oggX0o`000?l000001ol0000_ooooo`03o`000?oooooooooo00;ooooo0Ol00001oooo
o`00?oooool00ol0003oooooooooo`0Dooooo`Wo000000?oi6T0o`000?oWGP001?l00002one:0003
o`000?o_@P3o000000;olC/01ol00002ooD[0003o`000?of9`3omRL000;o00000_og90000ol0003o
n240o`000005o`000003ooPM0?l0003o000000?o00000_oi6`05o`0000;onAX01Ol000000ooi6@3o
0000o`000004o`000006ooXI0?l0003o0000o`000?oi6P3o00000_oi6@03o`000004ooTJ0?l0003o
nAX0ooTJ00?o000000?onA`0o`000?l000000ol00002ooPN00;o00000_oh8@05o`0000;omRH00_l0
0002ooD/00;o00000_oc<P02o`0000;olC/00_l000001Oo^A@3o0000o`000?l0003oje4000Co0000
00?oi6T0o`000?l000000ol000000ooGTP3o0000o`000003o`0003;ooooo00Go0000oooooooooooo
ooooo`000001ooooo`00@?ooool2o`0001Gooooo1?l000001?oGU03o0000o`000?oPM`0>o`000004
oo4l0?l0003olSD0oo8e00So000000?omRL0o`000?l000000ol00002ooLR0003o`000?oh7`3on1l0
00;o00000_oh7P000ol0003onA`0o`000002o`000004ooTL0?l0003onA/0ooTK00?o000000ConA/0
o`000?oi6P3onAX00_l00002ooTJ0003o`000?oi6@3onAT000;o00000_oi6P000ol0003onAX0o`00
0002o`000003ooTJ0?l0003o000000Co000000KonA/0o`000?l0003o0000ooPM0?l00002ooPN00?o
000000Kon200o`000?l0003o0000ooLT0?l00002ooLU00?o000000GomBX0o`000?l0003o0000oo@`
0003o`000005oo8h0?l0003o0000o`000?o_@P000_l00002ona=00Co000000?oiV@0o`000?l00000
0ol000000ooIS03o0000o`000003o`0003Gooooo00Co0000oooooooooooo00000Oooool004;ooooo
00?o0000ooooooooool05?oooolHo`0000;olSH000?o0000oo@a0?l000001?l00002ooHX0003o`00
0?og9@3o000000Go000000?on200o`000?l000000ol00002ooPM00Go00000_oi7005o`000003ooTK
0?l0003o000000Co000000?onAX0o`000?l000000ol00002ooTK00;o00000_oi70000ol0003onA`0
ooTL0002o`0000;on1d01Ol000001Ooh803o0000o`000?l0003omb<000Ko000000GomRP0o`000?l0
003o0000oo@^0003o`000005oo8f0?l0003o0000o`000?o`?P000ol000000oo]B@3o0000o`000002
o`000003onMO0?l0003o000000;o000000?oggX0o`000?l000001Ol0000hooooo`03o`000?oooooo
0000007ooooo0013ooooo`03o`000?oooooooooo01Cooooo6ol00002oo<b0003o`000?od;@3o0000
00Co00000_of9P000ol0003omb<0o`000002o`0000;omb8000?o0000ooPO0?l000000_l000001?oh
7P3o0000ooTM0?oi7@03o`000004ooTM0?l0003onA`0ooTL00;o00000_oi70000ol0003onA/0o`00
0002o`000004ooTL0?l0003onA/0ooTK00?o000000?onA`0o`000?l000001?l000001_oh7@3o0000
o`000?l0003on1l0o`0000;on1l00_l00002ooLS00;o00000_of9`000ol0003omRL0o`000002o`00
0005oo@]0?l0003o0000o`000?oc<`000ol000001Ooa?03o0000o`000?l0003okTH000?o000000?o
je40o`000?l000000_l000000ooTJ@3o0000o`000007o`0003[ooooo00?o0000ooooool000000Ooo
ool004Cooooo00?o0000ooooooooool05_ooool9o`0000;oiV<000?o0000onUH0?l000000_o/C`00
0ol0003okTH0o`000009o`0000;om2h01ol00002ooLT00Go00000_oh8@05o`000003ooPN0?l0003o
000000Co000000?onAd0o`000?l000000ol00002ooTL00Go00000_oi7@02o`0000;on1h000?o0000
ooPN0?l000000_l000000ooh7`3o0000o`000004o`000005ooLR0?l0003o0000o`000?of9P001Ol0
0002ooD/00;o00000_oc<P02o`0000;olCX00_l00002onm300;o000000?ok4h0o`000?l000000_l0
0002onEU00Co000000?ofHh0o`000?l000000_l0000mooooo`7o00000Oooool1o`000000AOooool2
o`0001Oooooo4Ol00002oni80003o`000?o`@03o000000Oo000000Com300o`000?oe;03omB`01Ol0
00001?of9P3o0000ooLS0?og8`03o`000004ooLR0?l0003on200ooPP00;o00000_oh80000ol0003o
n1h0o`000002o`0000;on1h000?o0000ooPM0?l000000_l000001?oh7P3o0000ooPM0?oh7@03o`00
0003ooPN0?l0003o000000?o00000_oh8002o`0000;omb8000?o0000ooLR0?l000000_l000001Oof
9P3o0000o`000?l0003omBX000Ko000000Gom300o`000?l0003o0000oo8h0003o`000005oo100?l0
003o0000o`000?o]B`001?l000000ooWH@3o0000o`000003o`000003omZ90?l0003o000000;o0000
@?ooool2o`000000Aoooool00ol0003oooooooooo`0Goooooa;o00000_o_@`000ol0003olC`0o`00
0007o`000004oo@^0?l0003omRT0ooHY00Go00000_og9@05o`000003ooLR0?l0003o000000?o0000
0_oh8005o`0000;on1l01Ol000001_oh7`3o0000o`000?l0003on240o`0000;on2000ol000000oog
8`3o0000o`000003o`0000;omRH00_l00002ooDZ00;o00000_od;`05o`000005oo8f0?l0003o0000
o`000?o`?P000ol000000oo^B03o0000o`000002o`000003onQM0?l0003o000000;o000000?oh7P0
o`000?l000001?l00011ooooo`?o00000018ooooo`03o`000?oooooooooo01Sooooo5?l00002oo0n
0003o`000?ob>03o000000Oo000000?omB`0o`000?l000001?l000000oof9`3o0000o`000003o`00
00;omb@000?o0000ooLR0?l000000_l000000oog8P3o0000o`000004o`000003ooLR0?l0003o0000
00?o00000_og8P05o`000005ooLS0?l0003o0000o`000?of9P001_l000001Oof:@3o0000o`000?l0
003om2h000?o000000?olc@0o`000?l000003?l00002onQJ00?o00000_oQM006o`0003oooooo1?l0
0003ooooo`00BOooool00ol0003oooooooooo`0IoooooaKo00000_oa>`07o`0000;om2h01Ol00002
ooDZ0003o`000?of9`3o000000Co00000_og9002o`0000;ombD000?o0000ooLS0?l000000_l00000
1?og903o0000ooLS0?og8`03o`000003ooLU0?l0003o000000?o00000_of9`02o`0000;omBX01Ol0
00001Ood;P3o0000o`000?l0003olc@000?o000000GolC/0o`000?l0003o0000onm30003o`000005
ona=0?l0003o0000o`000?oYF0001?l000000ooRL@3o0000o`000005o`0003gooooo1?l00007oooo
o`00B_ooool00ol0003oooooooooo`0KoooooaGo000000Col3h0o`000?ob>03olSP01Ol000001?oc
<@3o0000oo@]0?od;@05o`0000;omRT01Ol000000oof9`3o0000o`000003o`0000;omRH01Ol00000
1Oof9P3o0000o`000?l0003omRP000Ko000000GomB/0o`000?l0003o0000oo@_0005o`0000;olc@0
0_l00002oo4j00;o000000Gokd80o`000?l0003o0000one;0003o`000003onYF0?l0003o000000;o
000000?ohfh0o`000?l000001Ol0000mooooo`?o00002oooool004_ooooo0_l0000NoooooaKo0000
00?olC`0o`000?l000001_l000000ood<03o0000o`000004o`000003oo@]0?l0003o000000?o0000
0_oe:`05o`000003ooHY0?l0003o000000?o00000_oe:P02o`0000;om2d000?o0000ooD/0?l00000
0_l000001Ood;`3o0000o`000?l0003olc@000Ko000000GolCX0o`000?l0003o0000onm20002o`00
00;okDX04?l0000kooooo`Co00003_ooool004gooooo00?o0000ooooooooool07OoooolEo`0000;o
l4001ol00002oo<d00Go000000?om300o`000?l000001?l000000ood;P3o0000o`000003o`0000;o
m2h01Ol000000ood;P3o0000o`000007o`0000;olSD00_l00002oo4k00ko000000?oieh0o`000?l0
00002Ol0000jooooo`Co00004_ooool004kooooo00?o0000ooooooooool08?oooolCo`000003oni4
0?l0003o000000Ko000000?olCT0o`000?l000000ol00002oo8e00Go000000?olc<0o`000?l00000
1?l000000ooc<P3o0000o`000003o`0000;olc<00_l000000oob>03o0000o`000004o`000005oo4l
0?l0003o0000o`000?o_@P000ol000000oo]BP3o0000o`000002on]C00ko0000>Oooool4o`0001Ko
oooo001?ooooo`03o`000?oooooooooo027ooooo6ol00002oo0n00Go000000?olCX0o`000?l00000
0ol00002oo8h00Go000000?olSP0o`000?l000001?l000000ooa>P3o0000o`000002oo0n01co0000
>?ooool4o`0001[ooooo001@ooooo`;o00009OoooolOo`0000;ol4001Ol000000oo`?P3o0000o`00
0003o`0000;ol3h03Ol000001Oo/C@3o0000o`000?l0003ojU@000oo0000>Oooool3o`0001kooooo
001Booooo`03o`000?oooooooooo02Kooooo5?l000000oo/D03o0000o`00000Go`000005one;0?l0
003o0000o`000?o[D@005?l0000iooooo`Co00008Oooool005?ooooo00?o0000ooooooooool09_oo
ool01?l0003ooooooooooooooolmo`0003[ooooo1?l0000Uooooo`00E?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Oooooo<_l0000kooooo`Co0000:Oooool005Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0>ooooob?o0000?oooool4o`0002gooooo001Foooo
o`;o00009?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04[ooooo0ol0000aoooo
o`00F?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Wooooo1?l0000dooooo`00
FOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Gooooo1?l0000hooooo`00F_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo1?l0000looooo`00Foooool2
o`0001oooooo00?o0000ooooooooool0GOooool4o`00043ooooo001Mooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0FOooool4o`0004Cooooo001Nooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0E_ooool3o`0004Sooooo001Oooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0D_ooool4o`0004_ooooo001Pooooo`;o00006_ooool00ol0003ooooooooo
o`1>ooooo`Co0000Coooool006;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1:
ooooo`Co0000Doooool006?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`16oooo
o`Co0000Eoooool006Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`13ooooo`?o
0000Foooool006Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`Co0000
G_ooool006Kooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo1?l0001Rooooo`00J?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo1?l0001Vooooo`00JOooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo1?l0001Zooooo`00J_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo033ooooo1?l0001^ooooo`00Joooool2o`0000kooooo
00?o0000ooooooooool0;Oooool3o`0007;ooooo001]ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0:Oooool4o`0007Gooooo001^ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool09Oooool4o`0007Wooooo001_ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool08Oooool4o`0007gooooo001`ooooo`;o00002Oooool00ol0003oooooooooo`0Mooooo`Co
0000POooool007;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`?o0000
QOooool007?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000R?oo
ool007Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000S?ooool0
07Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000T?ooool007Ko
oooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002Dooooo`00N?ooool01?l0003ooooo
ooooool00009ooooo`?o0000V?ooool007Wooooo00?o0000ooooool000001Oooool4o`0009_ooooo
001jooooo`;o000000?oooooo`000?l000000_l0002Oooooo`00Noooool2o`000:?ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo000^ooooo`?o0000R_ooool00ol0003ooooooooo
o`0[ooooo`?o00005Oooool00ol0003oooooooooo`0Looooo`00;oooool00ol0003oooooooooo`28
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0K
ooooo`00:Oooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003oooo
o`Co000000?oooooo`000?l000000ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002oooo
o`Ko00001_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o0000
00?o00000_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3o`000004ooooool0003o0000
ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003
ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol00002
ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_ooool:o`0000Gooooo00?o
0000ooooooooool06_ooool002Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool002Sooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00000_ooool00ol0003o
ooooooooo`02ooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`0000Gooooo1Ol00008
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o00000ooo
ool00ol0003oooooo`000002ooooo`Go00000oooool01?l0003oooooooooooooool5o`0000;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00000_ooool3o`0000Gooooo00?o0000ooooooooool06_ooool002Sooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01ol0003oooooo`000?oo
oooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00005ooooo`06
o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`0Jooooo`00:?ooool01_l0
003ooooooooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000ooo
ool2o`0000Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00002ooooo`;o0000
0oooool4o`0000?ooooo0ol00009ooooo`05o`000?ooooooooooo`000?ooool00ol00004ooooo`Co
00000_ooool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;o
oooo1?l00003ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00_ooool6o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool00ol0003o
ooooooooo`02ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o00000oooool4o`0000Co
oooo00?o0000ooooooooool06_ooool002Sooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01_ooooo000Yooooo`?o00002Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00gooooo0ol00009ooooo`Co00002Oooool00ol0003oooooooooo`02oooo
o`;o00002_ooool4o`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0000^oooo
o`03o`000?oooooooooo01Sooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000;oooo
o`03o`000?oooooooooo01cooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0572531, 0.0637151, \
0.00351863, 0.00351863}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -93 0 ]
[.5 .82364 93 9 ]
[.08833 .22227 -30 -8.87978 ]
[.08833 .22227 0 .12022 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60583 .01876 -20.3642 -9 ]
[.60583 .01876 3.63577 0 ]
[.73629 .04932 0 -6.20852 ]
[.73629 .04932 30 2.79148 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95788 .38865 0 -5.88734 ]
[.95788 .38865 24 3.11266 ]
[.0243 .26392 -6 -2.74131 ]
[.0243 .26392 0 6.25869 ]
[.0167 .31155 -18 -2.78158 ]
[.0167 .31155 0 6.21842 ]
[.00886 .36068 -18 -2.82323 ]
[.00886 .36068 0 6.17677 ]
[.00077 .41138 -18 -2.86636 ]
[.00077 .41138 0 6.13364 ]
[-0.00758 .46373 -18 -2.91104 ]
[-0.00758 .46373 0 6.08896 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Point Spread Intensity Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09773 .23142 m
.10243 .236 L
s
[(-0.05)] .08833 .22227 1 .97329 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61334 .02952 m
.61709 .03491 L
s
[(0.05)] .60583 .01876 .69702 1 Mshowa
.125 Mabswid
.14497 .21292 m
.14774 .21571 L
s
.1931 .19408 m
.19582 .19692 L
s
.24214 .17487 m
.24481 .17776 L
s
.29212 .1553 m
.29474 .15824 L
s
.39501 .11502 m
.39752 .11805 L
s
.44797 .09427 m
.45043 .09735 L
s
.502 .07312 m
.50439 .07625 L
s
.55711 .05154 m
.55943 .05472 L
s
.05135 .24958 m
.05422 .25228 L
s
.67072 .00705 m
.6729 .01033 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72403 .05398 m
.71789 .05631 L
s
[(-0.05)] .73629 .04932 -1 .37967 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94534 .39252 m
.93907 .39445 L
s
[(0.05)] .95788 .38865 -1 .3083 Mshowa
.125 Mabswid
.74979 .09338 m
.74609 .09475 L
s
.77462 .13138 m
.77092 .13272 L
s
.79859 .16803 m
.79488 .16935 L
s
.82172 .20342 m
.818 .20472 L
s
.86568 .27066 m
.86195 .27191 L
s
.88658 .30263 m
.88283 .30385 L
s
.9068 .33356 m
.90305 .33476 L
s
.92638 .36351 m
.92262 .36469 L
s
.69729 .01309 m
.69363 .01452 L
s
.96372 .42063 m
.95995 .42177 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03653 .25914 m
.04264 .25675 L
s
[(0)] .0243 .26392 1 -0.39082 Mshowa
.02896 .30687 m
.03509 .30453 L
s
[(0.2)] .0167 .31155 1 -0.38187 Mshowa
.02116 .3561 m
.02731 .35381 L
s
[(0.4)] .00886 .36068 1 -0.37261 Mshowa
.01311 .40691 m
.01928 .40467 L
s
[(0.6)] .00077 .41138 1 -0.36303 Mshowa
.0048 .45936 m
.01098 .45718 L
s
[(0.8)] -0.00758 .46373 1 -0.3531 Mshowa
.125 Mabswid
.03466 .27093 m
.03833 .26951 L
s
.03277 .28282 m
.03645 .2814 L
s
.03087 .2948 m
.03455 .29339 L
s
.02703 .31903 m
.03071 .31764 L
s
.02509 .33129 m
.02877 .3299 L
s
.02313 .34365 m
.02682 .34227 L
s
.01917 .36865 m
.02286 .36728 L
s
.01717 .3813 m
.02086 .37994 L
s
.01515 .39405 m
.01884 .3927 L
s
.01106 .41986 m
.01476 .41853 L
s
.00899 .43292 m
.01269 .4316 L
s
.0069 .44609 m
.01061 .44477 L
s
.00268 .47274 m
.00639 .47144 L
s
.00054 .48623 m
.00426 .48494 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .025 .123 r
.40027 .59954 .40511 .60416 .41324 .60161 .40842 .59698 Metetra
0 .024 .123 r
.40842 .59698 .41324 .60161 .42139 .59915 .41658 .59457 Metetra
0 .024 .123 r
.41658 .59457 .42139 .59915 .42957 .59662 .42478 .59202 Metetra
0 .024 .123 r
.42478 .59202 .42957 .59662 .43777 .59422 .43299 .58964 Metetra
0 .024 .123 r
.43299 .58964 .43777 .59422 .446 .59178 .44124 .58714 Metetra
0 .024 .123 r
.44124 .58714 .446 .59178 .45425 .58929 .4495 .58479 Metetra
0 .025 .123 r
.4495 .58479 .45425 .58929 .46253 .58682 .45779 .58236 Metetra
0 .025 .123 r
.45779 .58236 .46253 .58682 .47083 .58419 .46611 .57985 Metetra
0 .024 .123 r
.46611 .57985 .47083 .58419 .47916 .58166 .47446 .57726 Metetra
0 .024 .122 r
.47446 .57726 .47916 .58166 .48751 .579 .48283 .57459 Metetra
0 .024 .122 r
.48283 .57459 .48751 .579 .49589 .57669 .49122 .57218 Metetra
0 .024 .123 r
.49122 .57218 .49589 .57669 .50429 .57426 .49964 .56966 Metetra
0 .025 .123 r
.49964 .56966 .50429 .57426 .51272 .57193 .50809 .56732 Metetra
0 .025 .124 r
.50809 .56732 .51272 .57193 .52118 .56938 .51656 .56472 Metetra
0 .025 .124 r
.51656 .56472 .52118 .56938 .52966 .5668 .52506 .56218 Metetra
0 .025 .124 r
.52506 .56218 .52966 .5668 .53817 .56443 .53359 .55962 Metetra
0 .025 .124 r
.53359 .55962 .53817 .56443 .54671 .56196 .54214 .55708 Metetra
0 .026 .125 r
.54214 .55708 .54671 .56196 .55527 .55968 .55073 .55476 Metetra
0 .026 .125 r
.55073 .55476 .55527 .55968 .56386 .55704 .55933 .55213 Metetra
0 .026 .125 r
.55933 .55213 .56386 .55704 .57248 .55435 .56797 .54955 Metetra
0 .026 .125 r
.56797 .54955 .57248 .55435 .58112 .55195 .57663 .54696 Metetra
0 .027 .126 r
.57663 .54696 .58112 .55195 .58979 .54939 .58532 .54438 Metetra
0 .027 .126 r
.58532 .54438 .58979 .54939 .59849 .54689 .59404 .542 Metetra
0 .027 .126 r
.59404 .542 .59849 .54689 .60722 .54419 .60278 .53926 Metetra
0 .027 .126 r
.60278 .53926 .60722 .54419 .61597 .54139 .61154 .53647 Metetra
0 .027 .126 r
.61154 .53647 .61597 .54139 .62475 .53902 .62035 .53405 Metetra
0 .027 .126 r
.62035 .53405 .62475 .53902 .63356 .53639 .62918 .53142 Metetra
0 .027 .126 r
.62918 .53142 .63356 .53639 .64239 .53347 .63803 .52864 Metetra
0 .027 .126 r
.63803 .52864 .64239 .53347 .65126 .53097 .64691 .52604 Metetra
0 .027 .126 r
.64691 .52604 .65126 .53097 .66015 .52848 .65582 .52341 Metetra
0 .027 .126 r
.65582 .52341 .66015 .52848 .66906 .52555 .66476 .52066 Metetra
0 .027 .126 r
.66476 .52066 .66906 .52555 .67801 .52287 .67373 .51797 Metetra
0 .027 .126 r
.67373 .51797 .67801 .52287 .687 .52043 .68272 .51531 Metetra
0 .027 .126 r
.68272 .51531 .687 .52043 .69599 .51755 .69174 .51254 Metetra
0 .027 .126 r
.69174 .51254 .69599 .51755 .70502 .51469 .70079 .50975 Metetra
0 .027 .126 r
.70079 .50975 .70502 .51469 .7141 .51225 .70988 .50714 Metetra
0 .027 .127 r
.70988 .50714 .7141 .51225 .72319 .50951 .71899 .50437 Metetra
0 .027 .126 r
.71899 .50437 .72319 .50951 .73229 .50652 .72812 .50138 Metetra
0 .027 .126 r
.72812 .50138 .73229 .50652 .74145 .50394 .7373 .49878 Metetra
0 .027 .126 r
.7373 .49878 .74145 .50394 .75063 .50129 .7465 .49613 Metetra
0 .027 .126 r
.7465 .49613 .75063 .50129 .75984 .49842 .75572 .4931 Metetra
0 .027 .126 r
.75572 .4931 .75984 .49842 .76907 .49559 .76497 .49027 Metetra
0 .026 .125 r
.76497 .49027 .76907 .49559 .77832 .49262 .77426 .48746 Metetra
0 .026 .125 r
.77426 .48746 .77832 .49262 .78763 .48996 .78358 .48465 Metetra
0 .026 .125 r
.78358 .48465 .78763 .48996 .79696 .48723 .79293 .48187 Metetra
0 .026 .125 r
.79293 .48187 .79696 .48723 .80629 .48413 .80228 .47878 Metetra
0 .025 .124 r
.80228 .47878 .80629 .48413 .81567 .48121 .81169 .4759 Metetra
0 .025 .124 r
.81169 .4759 .81567 .48121 .82507 .4782 .82113 .47306 Metetra
0 .025 .124 r
.82113 .47306 .82507 .4782 .83453 .47541 .8306 .4702 Metetra
0 .025 .124 r
.8306 .4702 .83453 .47541 .844 .47258 .8401 .46739 Metetra
0 .025 .123 r
.8401 .46739 .844 .47258 .85349 .46952 .84961 .46431 Metetra
0 .024 .123 r
.84961 .46431 .85349 .46952 .86302 .46656 .85917 .4614 Metetra
0 .024 .122 r
.85917 .4614 .86302 .46656 .87257 .46348 .86876 .4584 Metetra
0 .024 .122 r
.86876 .4584 .87257 .46348 .88219 .46076 .8784 .45566 Metetra
0 .024 .123 r
.8784 .45566 .88219 .46076 .89183 .45791 .88806 .45283 Metetra
0 .025 .123 r
.88806 .45283 .89183 .45791 .90151 .45516 .89776 .44993 Metetra
0 .025 .123 r
.89776 .44993 .90151 .45516 .91121 .45224 .90747 .44693 Metetra
0 .025 .123 r
.90747 .44693 .91121 .45224 .92094 .44933 .91721 .44385 Metetra
0 .024 .123 r
.91721 .44385 .92094 .44933 .9307 .44636 .92699 .44091 Metetra
0 .024 .123 r
.92699 .44091 .9307 .44636 .94049 .44337 .9368 .43786 Metetra
0 .024 .123 r
.9368 .43786 .94049 .44337 .95032 .44049 .94666 .43498 Metetra
0 .024 .123 r
.94666 .43498 .95032 .44049 .96019 .43756 .95654 .43197 Metetra
0 .025 .123 r
.95654 .43197 .96019 .43756 .9701 .43471 .96647 .42909 Metetra
0 .024 .123 r
.3954 .59497 .40027 .59954 .40842 .59698 .40356 .59246 Metetra
0 .024 .123 r
.40356 .59246 .40842 .59698 .41658 .59457 .41174 .59009 Metetra
0 .024 .123 r
.41174 .59009 .41658 .59457 .42478 .59202 .41995 .58755 Metetra
0 .024 .123 r
.41995 .58755 .42478 .59202 .43299 .58964 .42818 .58515 Metetra
0 .024 .123 r
.42818 .58515 .43299 .58964 .44124 .58714 .43644 .58259 Metetra
0 .025 .123 r
.43644 .58259 .44124 .58714 .4495 .58479 .44472 .58027 Metetra
0 .025 .124 r
.44472 .58027 .4495 .58479 .45779 .58236 .45303 .57781 Metetra
0 .025 .124 r
.45303 .57781 .45779 .58236 .46611 .57985 .46137 .57533 Metetra
0 .025 .124 r
.46137 .57533 .46611 .57985 .47446 .57726 .46973 .5727 Metetra
0 .025 .123 r
.46973 .5727 .47446 .57726 .48283 .57459 .47812 .57004 Metetra
0 .024 .123 r
.47812 .57004 .48283 .57459 .49122 .57218 .48653 .5675 Metetra
0 .025 .123 r
.48653 .5675 .49122 .57218 .49964 .56966 .49497 .56492 Metetra
0 .025 .123 r
.49497 .56492 .49964 .56966 .50809 .56732 .50343 .56254 Metetra
0 .025 .124 r
.50343 .56254 .50809 .56732 .51656 .56472 .51192 .55996 Metetra
0 .025 .124 r
.51192 .55996 .51656 .56472 .52506 .56218 .52044 .5575 Metetra
0 .025 .124 r
.52044 .5575 .52506 .56218 .53359 .55962 .52898 .55484 Metetra
0 .025 .124 r
.52898 .55484 .53359 .55962 .54214 .55708 .53755 .55229 Metetra
0 .026 .125 r
.53755 .55229 .54214 .55708 .55073 .55476 .54615 .54992 Metetra
0 .026 .125 r
.54615 .54992 .55073 .55476 .55933 .55213 .55478 .54736 Metetra
0 .026 .125 r
.55478 .54736 .55933 .55213 .56797 .54955 .56343 .54491 Metetra
0 .026 .125 r
.56343 .54491 .56797 .54955 .57663 .54696 .57211 .5422 Metetra
0 .026 .125 r
.57211 .5422 .57663 .54696 .58532 .54438 .58082 .53961 Metetra
0 .027 .126 r
.58082 .53961 .58532 .54438 .59404 .542 .58956 .53725 Metetra
0 .027 .126 r
.58956 .53725 .59404 .542 .60278 .53926 .59832 .53453 Metetra
0 .027 .126 r
.59832 .53453 .60278 .53926 .61154 .53647 .6071 .53182 Metetra
0 .027 .126 r
.6071 .53182 .61154 .53647 .62035 .53405 .61592 .52927 Metetra
0 .027 .127 r
.61592 .52927 .62035 .53405 .62918 .53142 .62477 .52662 Metetra
0 .027 .127 r
.62477 .52662 .62918 .53142 .63803 .52864 .63365 .524 Metetra
0 .027 .127 r
.63365 .524 .63803 .52864 .64691 .52604 .64255 .52128 Metetra
0 .027 .127 r
.64255 .52128 .64691 .52604 .65582 .52341 .65147 .51852 Metetra
0 .027 .127 r
.65147 .51852 .65582 .52341 .66476 .52066 .66044 .51593 Metetra
0 .027 .127 r
.66044 .51593 .66476 .52066 .67373 .51797 .66942 .51322 Metetra
0 .027 .127 r
.66942 .51322 .67373 .51797 .68272 .51531 .67843 .51038 Metetra
0 .027 .127 r
.67843 .51038 .68272 .51531 .69174 .51254 .68748 .5077 Metetra
0 .027 .127 r
.68748 .5077 .69174 .51254 .70079 .50975 .69656 .50501 Metetra
0 .027 .127 r
.69656 .50501 .70079 .50975 .70988 .50714 .70566 .5022 Metetra
0 .027 .127 r
.70566 .5022 .70988 .50714 .71899 .50437 .71479 .49941 Metetra
0 .027 .126 r
.71479 .49941 .71899 .50437 .72812 .50138 .72394 .49653 Metetra
0 .027 .126 r
.72394 .49653 .72812 .50138 .7373 .49878 .73314 .49382 Metetra
0 .027 .126 r
.73314 .49382 .7373 .49878 .7465 .49613 .74236 .49111 Metetra
0 .027 .126 r
.74236 .49111 .7465 .49613 .75572 .4931 .75159 .48802 Metetra
0 .026 .125 r
.75159 .48802 .75572 .4931 .76497 .49027 .76087 .48517 Metetra
0 .026 .125 r
.76087 .48517 .76497 .49027 .77426 .48746 .77018 .48246 Metetra
0 .026 .125 r
.77018 .48246 .77426 .48746 .78358 .48465 .77951 .47949 Metetra
0 .026 .125 r
.77951 .47949 .78358 .48465 .79293 .48187 .78888 .4766 Metetra
0 .026 .125 r
.78888 .4766 .79293 .48187 .80228 .47878 .79826 .47352 Metetra
0 .025 .124 r
.79826 .47352 .80228 .47878 .81169 .4759 .80768 .47063 Metetra
0 .025 .124 r
.80768 .47063 .81169 .4759 .82113 .47306 .81715 .46786 Metetra
0 .025 .124 r
.81715 .46786 .82113 .47306 .8306 .4702 .82664 .46488 Metetra
0 .025 .124 r
.82664 .46488 .8306 .4702 .8401 .46739 .83616 .46202 Metetra
0 .025 .123 r
.83616 .46202 .8401 .46739 .84961 .46431 .8457 .45894 Metetra
0 .025 .123 r
.8457 .45894 .84961 .46431 .85917 .4614 .85528 .45607 Metetra
0 .024 .123 r
.85528 .45607 .85917 .4614 .86876 .4584 .8649 .45316 Metetra
0 .025 .123 r
.8649 .45316 .86876 .4584 .8784 .45566 .87456 .45039 Metetra
0 .025 .124 r
.87456 .45039 .8784 .45566 .88806 .45283 .88426 .44758 Metetra
0 .025 .124 r
.88426 .44758 .88806 .45283 .89776 .44993 .89397 .4446 Metetra
0 .025 .124 r
.89397 .4446 .89776 .44993 .90747 .44693 .90371 .44159 Metetra
0 .025 .123 r
.90371 .44159 .90747 .44693 .91721 .44385 .91346 .43845 Metetra
0 .024 .123 r
.91346 .43845 .91721 .44385 .92699 .44091 .92328 .43554 Metetra
0 .024 .123 r
.92328 .43554 .92699 .44091 .9368 .43786 .93311 .43248 Metetra
0 .024 .123 r
.93311 .43248 .9368 .43786 .94666 .43498 .94299 .42957 Metetra
0 .024 .123 r
.94299 .42957 .94666 .43498 .95654 .43197 .95289 .42648 Metetra
0 .024 .123 r
.95289 .42648 .95654 .43197 .96647 .42909 .96284 .42352 Metetra
0 .024 .123 r
.39051 .59035 .3954 .59497 .40356 .59246 .39869 .58781 Metetra
0 .024 .123 r
.39869 .58781 .40356 .59246 .41174 .59009 .40688 .58544 Metetra
0 .024 .123 r
.40688 .58544 .41174 .59009 .41995 .58755 .41511 .5829 Metetra
0 .024 .123 r
.41511 .5829 .41995 .58755 .42818 .58515 .42335 .58049 Metetra
0 .024 .123 r
.42335 .58049 .42818 .58515 .43644 .58259 .43163 .5779 Metetra
0 .025 .123 r
.43163 .5779 .43644 .58259 .44472 .58027 .43992 .57563 Metetra
0 .025 .124 r
.43992 .57563 .44472 .58027 .45303 .57781 .44825 .57318 Metetra
0 .025 .124 r
.44825 .57318 .45303 .57781 .46137 .57533 .4566 .57084 Metetra
0 .025 .124 r
.4566 .57084 .46137 .57533 .46973 .5727 .46497 .56821 Metetra
0 .025 .124 r
.46497 .56821 .46973 .5727 .47812 .57004 .47338 .56565 Metetra
0 .025 .124 r
.47338 .56565 .47812 .57004 .48653 .5675 .48181 .56297 Metetra
0 .025 .123 r
.48181 .56297 .48653 .5675 .49497 .56492 .49027 .56033 Metetra
0 .025 .124 r
.49027 .56033 .49497 .56492 .50343 .56254 .49875 .55787 Metetra
0 .025 .124 r
.49875 .55787 .50343 .56254 .51192 .55996 .50726 .55528 Metetra
0 .025 .124 r
.50726 .55528 .51192 .55996 .52044 .5575 .51579 .55285 Metetra
0 .025 .124 r
.51579 .55285 .52044 .5575 .52898 .55484 .52435 .55007 Metetra
0 .025 .124 r
.52435 .55007 .52898 .55484 .53755 .55229 .53294 .54747 Metetra
0 .025 .124 r
.53294 .54747 .53755 .55229 .54615 .54992 .54155 .54495 Metetra
0 .026 .125 r
.54155 .54495 .54615 .54992 .55478 .54736 .5502 .54244 Metetra
0 .026 .125 r
.5502 .54244 .55478 .54736 .56343 .54491 .55887 .54006 Metetra
0 .026 .126 r
.55887 .54006 .56343 .54491 .57211 .5422 .56756 .53727 Metetra
0 .026 .125 r
.56756 .53727 .57211 .5422 .58082 .53961 .57629 .53467 Metetra
0 .027 .126 r
.57629 .53467 .58082 .53961 .58956 .53725 .58504 .53223 Metetra
0 .027 .127 r
.58504 .53223 .58956 .53725 .59832 .53453 .59383 .52959 Metetra
0 .027 .127 r
.59383 .52959 .59832 .53453 .6071 .53182 .60264 .52703 Metetra
0 .027 .127 r
.60264 .52703 .6071 .53182 .61592 .52927 .61147 .52428 Metetra
0 .027 .127 r
.61147 .52428 .61592 .52927 .62477 .52662 .62034 .52163 Metetra
0 .028 .127 r
.62034 .52163 .62477 .52662 .63365 .524 .62924 .51919 Metetra
0 .028 .127 r
.62924 .51919 .63365 .524 .64255 .52128 .63815 .51635 Metetra
0 .027 .127 r
.63815 .51635 .64255 .52128 .65147 .51852 .6471 .51348 Metetra
0 .028 .127 r
.6471 .51348 .65147 .51852 .66044 .51593 .65608 .51103 Metetra
0 .028 .128 r
.65608 .51103 .66044 .51593 .66942 .51322 .66509 .5083 Metetra
0 .028 .127 r
.66509 .5083 .66942 .51322 .67843 .51038 .67411 .50529 Metetra
0 .027 .127 r
.67411 .50529 .67843 .51038 .68748 .5077 .68319 .5027 Metetra
0 .028 .127 r
.68319 .5027 .68748 .5077 .69656 .50501 .69229 .50008 Metetra
0 .028 .127 r
.69229 .50008 .69656 .50501 .70566 .5022 .7014 .49706 Metetra
0 .027 .127 r
.7014 .49706 .70566 .5022 .71479 .49941 .71055 .49424 Metetra
0 .027 .127 r
.71055 .49424 .71479 .49941 .72394 .49653 .71973 .49153 Metetra
0 .027 .127 r
.71973 .49153 .72394 .49653 .73314 .49382 .72894 .48864 Metetra
0 .027 .127 r
.72894 .48864 .73314 .49382 .74236 .49111 .73818 .4858 Metetra
0 .027 .126 r
.73818 .4858 .74236 .49111 .75159 .48802 .74743 .48278 Metetra
0 .026 .125 r
.74743 .48278 .75159 .48802 .76087 .48517 .75673 .47991 Metetra
0 .026 .126 r
.75673 .47991 .76087 .48517 .77018 .48246 .76607 .47724 Metetra
0 .026 .125 r
.76607 .47724 .77018 .48246 .77951 .47949 .77541 .47416 Metetra
0 .026 .125 r
.77541 .47416 .77951 .47949 .78888 .4766 .78479 .47118 Metetra
0 .025 .124 r
.78479 .47118 .78888 .4766 .79826 .47352 .79421 .46823 Metetra
0 .025 .124 r
.79421 .46823 .79826 .47352 .80768 .47063 .80366 .46537 Metetra
0 .025 .124 r
.80366 .46537 .80768 .47063 .81715 .46786 .81316 .46268 Metetra
0 .025 .124 r
.81316 .46268 .81715 .46786 .82664 .46488 .82266 .45964 Metetra
0 .025 .124 r
.82266 .45964 .82664 .46488 .83616 .46202 .83221 .45675 Metetra
0 .025 .124 r
.83221 .45675 .83616 .46202 .8457 .45894 .84177 .45373 Metetra
0 .025 .123 r
.84177 .45373 .8457 .45894 .85528 .45607 .85139 .45089 Metetra
0 .025 .124 r
.85139 .45089 .85528 .45607 .8649 .45316 .86104 .44809 Metetra
0 .025 .124 r
.86104 .44809 .8649 .45316 .87456 .45039 .87072 .44519 Metetra
0 .026 .124 r
.87072 .44519 .87456 .45039 .88426 .44758 .88043 .44233 Metetra
0 .025 .124 r
.88043 .44233 .88426 .44758 .89397 .4446 .89015 .43918 Metetra
0 .025 .124 r
.89015 .43918 .89397 .4446 .90371 .44159 .89991 .43613 Metetra
0 .025 .123 r
.89991 .43613 .90371 .44159 .91346 .43845 .90968 .4329 Metetra
0 .024 .123 r
.90968 .4329 .91346 .43845 .92328 .43554 .91952 .42999 Metetra
0 .024 .123 r
.91952 .42999 .92328 .43554 .93311 .43248 .92938 .42692 Metetra
0 .024 .123 r
.92938 .42692 .93311 .43248 .94299 .42957 .93929 .42396 Metetra
0 .024 .123 r
.93929 .42396 .94299 .42957 .95289 .42648 .9492 .42084 Metetra
0 .024 .123 r
.9492 .42084 .95289 .42648 .96284 .42352 .95918 .41787 Metetra
0 .024 .122 r
.38559 .58582 .39051 .59035 .39869 .58781 .39378 .5833 Metetra
0 .024 .123 r
.39378 .5833 .39869 .58781 .40688 .58544 .40199 .58091 Metetra
0 .024 .123 r
.40199 .58091 .40688 .58544 .41511 .5829 .41023 .57835 Metetra
0 .024 .123 r
.41023 .57835 .41511 .5829 .42335 .58049 .41849 .57586 Metetra
0 .024 .123 r
.41849 .57586 .42335 .58049 .43163 .5779 .42679 .57323 Metetra
0 .025 .123 r
.42679 .57323 .43163 .5779 .43992 .57563 .4351 .5709 Metetra
0 .025 .124 r
.4351 .5709 .43992 .57563 .44825 .57318 .44344 .56841 Metetra
0 .025 .124 r
.44344 .56841 .44825 .57318 .4566 .57084 .4518 .56608 Metetra
0 .026 .125 r
.4518 .56608 .4566 .57084 .46497 .56821 .4602 .5635 Metetra
0 .026 .125 r
.4602 .5635 .46497 .56821 .47338 .56565 .46861 .56104 Metetra
0 .026 .124 r
.46861 .56104 .47338 .56565 .48181 .56297 .47706 .55831 Metetra
0 .025 .124 r
.47706 .55831 .48181 .56297 .49027 .56033 .48554 .55569 Metetra
0 .025 .124 r
.48554 .55569 .49027 .56033 .49875 .55787 .49403 .55316 Metetra
0 .025 .124 r
.49403 .55316 .49875 .55787 .50726 .55528 .50256 .55062 Metetra
0 .026 .125 r
.50256 .55062 .50726 .55528 .51579 .55285 .51111 .54823 Metetra
0 .026 .125 r
.51111 .54823 .51579 .55285 .52435 .55007 .51969 .54545 Metetra
0 .026 .124 r
.51969 .54545 .52435 .55007 .53294 .54747 .5283 .54284 Metetra
0 .026 .124 r
.5283 .54284 .53294 .54747 .54155 .54495 .53693 .54017 Metetra
0 .026 .125 r
.53693 .54017 .54155 .54495 .5502 .54244 .54559 .53768 Metetra
0 .026 .126 r
.54559 .53768 .5502 .54244 .55887 .54006 .55428 .53529 Metetra
0 .027 .126 r
.55428 .53529 .55887 .54006 .56756 .53727 .56299 .53249 Metetra
0 .026 .126 r
.56299 .53249 .56756 .53727 .57629 .53467 .57174 .52987 Metetra
0 .027 .126 r
.57174 .52987 .57629 .53467 .58504 .53223 .58051 .52725 Metetra
0 .027 .126 r
.58051 .52725 .58504 .53223 .59383 .52959 .58931 .52467 Metetra
0 .027 .127 r
.58931 .52467 .59383 .52959 .60264 .52703 .59814 .52219 Metetra
0 .027 .127 r
.59814 .52219 .60264 .52703 .61147 .52428 .60699 .5193 Metetra
0 .027 .127 r
.60699 .5193 .61147 .52428 .62034 .52163 .61587 .51662 Metetra
0 .028 .127 r
.61587 .51662 .62034 .52163 .62924 .51919 .62479 .51421 Metetra
0 .028 .128 r
.62479 .51421 .62924 .51919 .63815 .51635 .63373 .51133 Metetra
0 .028 .127 r
.63373 .51133 .63815 .51635 .6471 .51348 .64269 .50844 Metetra
0 .028 .127 r
.64269 .50844 .6471 .51348 .65608 .51103 .6517 .50597 Metetra
0 .028 .128 r
.6517 .50597 .65608 .51103 .66509 .5083 .66073 .50322 Metetra
0 .028 .127 r
.66073 .50322 .66509 .5083 .67411 .50529 .66977 .5002 Metetra
0 .028 .127 r
.66977 .5002 .67411 .50529 .68319 .5027 .67886 .49761 Metetra
0 .028 .128 r
.67886 .49761 .68319 .5027 .69229 .50008 .68798 .49499 Metetra
0 .028 .127 r
.68798 .49499 .69229 .50008 .7014 .49706 .69711 .4919 Metetra
0 .027 .127 r
.69711 .4919 .7014 .49706 .71055 .49424 .70628 .48908 Metetra
0 .027 .127 r
.70628 .48908 .71055 .49424 .71973 .49153 .7155 .48649 Metetra
0 .027 .127 r
.7155 .48649 .71973 .49153 .72894 .48864 .72472 .48348 Metetra
0 .027 .126 r
.72472 .48348 .72894 .48864 .73818 .4858 .73397 .48054 Metetra
0 .027 .126 r
.73397 .48054 .73818 .4858 .74743 .48278 .74326 .47766 Metetra
0 .026 .126 r
.74326 .47766 .74743 .48278 .75673 .47991 .75258 .4748 Metetra
0 .027 .126 r
.75258 .4748 .75673 .47991 .76607 .47724 .76194 .47211 Metetra
0 .026 .126 r
.76194 .47211 .76607 .47724 .77541 .47416 .77131 .46899 Metetra
0 .026 .125 r
.77131 .46899 .77541 .47416 .78479 .47118 .78071 .46597 Metetra
0 .026 .124 r
.78071 .46597 .78479 .47118 .79421 .46823 .79015 .46314 Metetra
0 .026 .124 r
.79015 .46314 .79421 .46823 .80366 .46537 .79963 .46026 Metetra
0 .026 .125 r
.79963 .46026 .80366 .46537 .81316 .46268 .80915 .45754 Metetra
0 .026 .125 r
.80915 .45754 .81316 .46268 .82266 .45964 .81867 .45442 Metetra
0 .025 .124 r
.81867 .45442 .82266 .45964 .83221 .45675 .82823 .45143 Metetra
0 .025 .124 r
.82823 .45143 .83221 .45675 .84177 .45373 .83782 .44846 Metetra
0 .025 .124 r
.83782 .44846 .84177 .45373 .85139 .45089 .84746 .44557 Metetra
0 .026 .124 r
.84746 .44557 .85139 .45089 .86104 .44809 .85714 .4428 Metetra
0 .026 .125 r
.85714 .4428 .86104 .44809 .87072 .44519 .86683 .43975 Metetra
0 .026 .125 r
.86683 .43975 .87072 .44519 .88043 .44233 .87656 .43681 Metetra
0 .026 .124 r
.87656 .43681 .88043 .44233 .89015 .43918 .88629 .4336 Metetra
0 .025 .124 r
.88629 .4336 .89015 .43918 .89991 .43613 .89608 .43056 Metetra
0 .025 .123 r
.89608 .43056 .89991 .43613 .90968 .4329 .90588 .42737 Metetra
0 .024 .123 r
.90588 .42737 .90968 .4329 .91952 .42999 .91575 .42448 Metetra
0 .024 .123 r
.91575 .42448 .91952 .42999 .92938 .42692 .92564 .42145 Metetra
0 .024 .123 r
.92564 .42145 .92938 .42692 .93929 .42396 .93557 .41848 Metetra
0 .024 .123 r
.93557 .41848 .93929 .42396 .9492 .42084 .94552 .41535 Metetra
0 .024 .123 r
.94552 .41535 .9492 .42084 .95918 .41787 .95551 .41232 Metetra
0 .024 .123 r
.38063 .58126 .38559 .58582 .39378 .5833 .38884 .57868 Metetra
0 .024 .123 r
.38884 .57868 .39378 .5833 .40199 .58091 .39707 .57622 Metetra
0 .024 .123 r
.39707 .57622 .40199 .58091 .41023 .57835 .40533 .57363 Metetra
0 .024 .123 r
.40533 .57363 .41023 .57835 .41849 .57586 .41361 .57109 Metetra
0 .024 .123 r
.41361 .57109 .41849 .57586 .42679 .57323 .42192 .56847 Metetra
0 .024 .123 r
.42192 .56847 .42679 .57323 .4351 .5709 .43024 .56611 Metetra
0 .025 .123 r
.43024 .56611 .4351 .5709 .44344 .56841 .4386 .56364 Metetra
0 .025 .124 r
.4386 .56364 .44344 .56841 .4518 .56608 .44698 .56139 Metetra
0 .026 .125 r
.44698 .56139 .4518 .56608 .4602 .5635 .45539 .55891 Metetra
0 .026 .125 r
.45539 .55891 .4602 .5635 .46861 .56104 .46382 .55661 Metetra
0 .026 .125 r
.46382 .55661 .46861 .56104 .47706 .55831 .47229 .55383 Metetra
0 .026 .125 r
.47229 .55383 .47706 .55831 .48554 .55569 .48078 .55121 Metetra
0 .026 .125 r
.48078 .55121 .48554 .55569 .49403 .55316 .48929 .54853 Metetra
0 .026 .125 r
.48929 .54853 .49403 .55316 .50256 .55062 .49784 .54599 Metetra
0 .026 .125 r
.49784 .54599 .50256 .55062 .51111 .54823 .50641 .54354 Metetra
0 .026 .125 r
.50641 .54354 .51111 .54823 .51969 .54545 .515 .54071 Metetra
0 .026 .125 r
.515 .54071 .51969 .54545 .5283 .54284 .52363 .53805 Metetra
0 .026 .125 r
.52363 .53805 .5283 .54284 .53693 .54017 .53228 .5352 Metetra
0 .026 .125 r
.53228 .5352 .53693 .54017 .54559 .53768 .54096 .53269 Metetra
0 .026 .125 r
.54096 .53269 .54559 .53768 .55428 .53529 .54966 .53022 Metetra
0 .027 .126 r
.54966 .53022 .55428 .53529 .56299 .53249 .5584 .52748 Metetra
0 .026 .126 r
.5584 .52748 .56299 .53249 .57174 .52987 .56716 .52487 Metetra
0 .027 .126 r
.56716 .52487 .57174 .52987 .58051 .52725 .57594 .52209 Metetra
0 .027 .126 r
.57594 .52209 .58051 .52725 .58931 .52467 .58476 .5196 Metetra
0 .027 .127 r
.58476 .5196 .58931 .52467 .59814 .52219 .59362 .51721 Metetra
0 .028 .127 r
.59362 .51721 .59814 .52219 .60699 .5193 .60248 .51427 Metetra
0 .027 .127 r
.60248 .51427 .60699 .5193 .61587 .51662 .61139 .5116 Metetra
0 .028 .127 r
.61139 .5116 .61587 .51662 .62479 .51421 .62033 .50915 Metetra
0 .028 .128 r
.62033 .50915 .62479 .51421 .63373 .51133 .62928 .50632 Metetra
0 .028 .127 r
.62928 .50632 .63373 .51133 .64269 .50844 .63827 .50351 Metetra
0 .028 .127 r
.63827 .50351 .64269 .50844 .6517 .50597 .64729 .50091 Metetra
0 .028 .128 r
.64729 .50091 .6517 .50597 .66073 .50322 .65634 .49813 Metetra
0 .028 .127 r
.65634 .49813 .66073 .50322 .66977 .5002 .66541 .49522 Metetra
0 .028 .127 r
.66541 .49522 .66977 .5002 .67886 .49761 .67451 .49252 Metetra
0 .028 .128 r
.67451 .49252 .67886 .49761 .68798 .49499 .68365 .48981 Metetra
0 .028 .127 r
.68365 .48981 .68798 .49499 .69711 .4919 .6928 .48673 Metetra
0 .027 .127 r
.6928 .48673 .69711 .4919 .70628 .48908 .70199 .48388 Metetra
0 .028 .127 r
.70199 .48388 .70628 .48908 .7155 .48649 .71123 .48129 Metetra
0 .027 .127 r
.71123 .48129 .7155 .48649 .72472 .48348 .72046 .47816 Metetra
0 .027 .126 r
.72046 .47816 .72472 .48348 .73397 .48054 .72973 .47511 Metetra
0 .027 .126 r
.72973 .47511 .73397 .48054 .74326 .47766 .73905 .47236 Metetra
0 .026 .126 r
.73905 .47236 .74326 .47766 .75258 .4748 .74839 .46946 Metetra
0 .027 .126 r
.74839 .46946 .75258 .4748 .76194 .47211 .75777 .46666 Metetra
0 .026 .125 r
.75777 .46666 .76194 .47211 .77131 .46899 .76716 .46358 Metetra
0 .026 .125 r
.76716 .46358 .77131 .46899 .78071 .46597 .77658 .46055 Metetra
0 .026 .125 r
.77658 .46055 .78071 .46597 .79015 .46314 .78606 .45787 Metetra
0 .026 .125 r
.78606 .45787 .79015 .46314 .79963 .46026 .79556 .45502 Metetra
0 .026 .125 r
.79556 .45502 .79963 .46026 .80915 .45754 .80511 .45231 Metetra
0 .026 .125 r
.80511 .45231 .80915 .45754 .81867 .45442 .81465 .44921 Metetra
0 .026 .125 r
.81465 .44921 .81867 .45442 .82823 .45143 .82424 .44621 Metetra
0 .026 .125 r
.82424 .44621 .82823 .45143 .83782 .44846 .83387 .44334 Metetra
0 .026 .125 r
.83387 .44334 .83782 .44846 .84746 .44557 .84353 .44044 Metetra
0 .026 .125 r
.84353 .44044 .84746 .44557 .85714 .4428 .85324 .43768 Metetra
0 .026 .125 r
.85324 .43768 .85714 .4428 .86683 .43975 .86293 .43443 Metetra
0 .026 .125 r
.86293 .43443 .86683 .43975 .87656 .43681 .87267 .43135 Metetra
0 .025 .124 r
.87267 .43135 .87656 .43681 .88629 .4336 .88242 .42803 Metetra
0 .025 .123 r
.88242 .42803 .88629 .4336 .89608 .43056 .89222 .42494 Metetra
0 .024 .123 r
.89222 .42494 .89608 .43056 .90588 .42737 .90205 .42174 Metetra
0 .024 .123 r
.90205 .42174 .90588 .42737 .91575 .42448 .91194 .41881 Metetra
0 .024 .123 r
.91194 .41881 .91575 .42448 .92564 .42145 .92186 .4158 Metetra
0 .024 .123 r
.92186 .4158 .92564 .42145 .93557 .41848 .93182 .41282 Metetra
0 .024 .123 r
.93182 .41282 .93557 .41848 .94552 .41535 .9418 .40972 Metetra
0 .024 .123 r
.9418 .40972 .94552 .41535 .95551 .41232 .95182 .40673 Metetra
0 .024 .123 r
.37566 .5766 .38063 .58126 .38884 .57868 .38387 .57417 Metetra
0 .025 .123 r
.38387 .57417 .38884 .57868 .39707 .57622 .39212 .57173 Metetra
0 .025 .123 r
.39212 .57173 .39707 .57622 .40533 .57363 .40039 .5692 Metetra
0 .025 .123 r
.40039 .5692 .40533 .57363 .41361 .57109 .40869 .56659 Metetra
0 .024 .123 r
.40869 .56659 .41361 .57109 .42192 .56847 .41701 .56395 Metetra
0 .024 .123 r
.41701 .56395 .42192 .56847 .43024 .56611 .42536 .56142 Metetra
0 .025 .123 r
.42536 .56142 .43024 .56611 .4386 .56364 .43373 .55885 Metetra
0 .025 .124 r
.43373 .55885 .4386 .56364 .44698 .56139 .44213 .55645 Metetra
0 .026 .125 r
.44213 .55645 .44698 .56139 .45539 .55891 .45056 .55398 Metetra
0 .026 .125 r
.45056 .55398 .45539 .55891 .46382 .55661 .459 .55167 Metetra
0 .027 .126 r
.459 .55167 .46382 .55661 .47229 .55383 .46749 .54897 Metetra
0 .026 .125 r
.46749 .54897 .47229 .55383 .48078 .55121 .47599 .54642 Metetra
0 .026 .125 r
.47599 .54642 .48078 .55121 .48929 .54853 .48453 .54369 Metetra
0 .026 .125 r
.48453 .54369 .48929 .54853 .49784 .54599 .49309 .54123 Metetra
0 .027 .126 r
.49309 .54123 .49784 .54599 .50641 .54354 .50167 .53873 Metetra
0 .027 .126 r
.50167 .53873 .50641 .54354 .515 .54071 .51029 .53611 Metetra
0 .027 .126 r
.51029 .53611 .515 .54071 .52363 .53805 .51893 .5335 Metetra
0 .026 .125 r
.51893 .5335 .52363 .53805 .53228 .5352 .5276 .53062 Metetra
0 .026 .125 r
.5276 .53062 .53228 .5352 .54096 .53269 .5363 .52807 Metetra
0 .027 .126 r
.5363 .52807 .54096 .53269 .54966 .53022 .54502 .52546 Metetra
0 .027 .126 r
.54502 .52546 .54966 .53022 .5584 .52748 .55377 .52285 Metetra
0 .027 .126 r
.55377 .52285 .5584 .52748 .56716 .52487 .56255 .52021 Metetra
0 .027 .126 r
.56255 .52021 .56716 .52487 .57594 .52209 .57136 .51729 Metetra
0 .027 .126 r
.57136 .51729 .57594 .52209 .58476 .5196 .5802 .51478 Metetra
0 .028 .127 r
.5802 .51478 .58476 .5196 .59362 .51721 .58907 .51226 Metetra
0 .028 .127 r
.58907 .51226 .59362 .51721 .60248 .51427 .59796 .5094 Metetra
0 .027 .127 r
.59796 .5094 .60248 .51427 .61139 .5116 .60688 .5067 Metetra
0 .028 .127 r
.60688 .5067 .61139 .5116 .62033 .50915 .61583 .50401 Metetra
0 .028 .128 r
.61583 .50401 .62033 .50915 .62928 .50632 .62481 .50128 Metetra
0 .028 .127 r
.62481 .50128 .62928 .50632 .63827 .50351 .63382 .4986 Metetra
0 .028 .128 r
.63382 .4986 .63827 .50351 .64729 .50091 .64285 .49575 Metetra
0 .028 .128 r
.64285 .49575 .64729 .50091 .65634 .49813 .65192 .49297 Metetra
0 .028 .128 r
.65192 .49297 .65634 .49813 .66541 .49522 .66102 .49026 Metetra
0 .028 .128 r
.66102 .49026 .66541 .49522 .67451 .49252 .67014 .4874 Metetra
0 .028 .128 r
.67014 .4874 .67451 .49252 .68365 .48981 .67929 .48455 Metetra
0 .028 .127 r
.67929 .48455 .68365 .48981 .6928 .48673 .68847 .48168 Metetra
0 .027 .127 r
.68847 .48168 .6928 .48673 .70199 .48388 .69769 .47884 Metetra
0 .028 .127 r
.69769 .47884 .70199 .48388 .71123 .48129 .70694 .47614 Metetra
0 .028 .127 r
.70694 .47614 .71123 .48129 .72046 .47816 .7162 .47308 Metetra
0 .027 .126 r
.7162 .47308 .72046 .47816 .72973 .47511 .72549 .47003 Metetra
0 .027 .126 r
.72549 .47003 .72973 .47511 .73905 .47236 .73484 .46739 Metetra
0 .027 .126 r
.73484 .46739 .73905 .47236 .74839 .46946 .7442 .46448 Metetra
0 .027 .126 r
.7442 .46448 .74839 .46946 .75777 .46666 .75359 .46152 Metetra
0 .027 .126 r
.75359 .46152 .75777 .46666 .76716 .46358 .76301 .45856 Metetra
0 .026 .125 r
.76301 .45856 .76716 .46358 .77658 .46055 .77246 .45554 Metetra
0 .026 .125 r
.77246 .45554 .77658 .46055 .78606 .45787 .78197 .45286 Metetra
0 .027 .126 r
.78197 .45286 .78606 .45787 .79556 .45502 .79149 .44991 Metetra
0 .027 .126 r
.79149 .44991 .79556 .45502 .80511 .45231 .80103 .44695 Metetra
0 .027 .126 r
.80103 .44695 .80511 .45231 .81465 .44921 .8106 .44387 Metetra
0 .026 .125 r
.8106 .44387 .81465 .44921 .82424 .44621 .8202 .44076 Metetra
0 .026 .125 r
.8202 .44076 .82424 .44621 .83387 .44334 .82986 .43791 Metetra
0 .026 .125 r
.82986 .43791 .83387 .44334 .84353 .44044 .83954 .4349 Metetra
0 .027 .126 r
.83954 .4349 .84353 .44044 .85324 .43768 .84926 .43202 Metetra
0 .026 .125 r
.84926 .43202 .85324 .43768 .86293 .43443 .85897 .42874 Metetra
0 .026 .125 r
.85897 .42874 .86293 .43443 .87267 .43135 .86873 .42562 Metetra
0 .025 .124 r
.86873 .42562 .87267 .43135 .88242 .42803 .87852 .42243 Metetra
0 .025 .123 r
.87852 .42243 .88242 .42803 .89222 .42494 .88836 .41941 Metetra
0 .024 .123 r
.88836 .41941 .89222 .42494 .90205 .42174 .89823 .41636 Metetra
0 .024 .123 r
.89823 .41636 .90205 .42174 .91194 .41881 .90815 .41341 Metetra
0 .025 .123 r
.90815 .41341 .91194 .41881 .92186 .4158 .9181 .41044 Metetra
0 .025 .123 r
.9181 .41044 .92186 .4158 .93182 .41282 .92807 .40737 Metetra
0 .025 .123 r
.92807 .40737 .93182 .41282 .9418 .40972 .93807 .40421 Metetra
0 .024 .123 r
.93807 .40421 .9418 .40972 .95182 .40673 .9481 .40102 Metetra
0 .025 .123 r
.37065 .57196 .37566 .5766 .38387 .57417 .37888 .56957 Metetra
0 .025 .124 r
.37888 .56957 .38387 .57417 .39212 .57173 .38714 .5671 Metetra
0 .025 .124 r
.38714 .5671 .39212 .57173 .40039 .5692 .39542 .56458 Metetra
0 .025 .124 r
.39542 .56458 .40039 .5692 .40869 .56659 .40374 .56193 Metetra
0 .025 .123 r
.40374 .56193 .40869 .56659 .41701 .56395 .41208 .55931 Metetra
0 .025 .123 r
.41208 .55931 .41701 .56395 .42536 .56142 .42045 .55668 Metetra
0 .025 .123 r
.42045 .55668 .42536 .56142 .43373 .55885 .42884 .55407 Metetra
0 .025 .123 r
.42884 .55407 .43373 .55885 .44213 .55645 .43725 .55159 Metetra
0 .025 .124 r
.43725 .55159 .44213 .55645 .45056 .55398 .44569 .54916 Metetra
0 .026 .125 r
.44569 .54916 .45056 .55398 .459 .55167 .45416 .54685 Metetra
0 .026 .126 r
.45416 .54685 .459 .55167 .46749 .54897 .46266 .54424 Metetra
0 .026 .126 r
.46266 .54424 .46749 .54897 .47599 .54642 .47118 .54174 Metetra
0 .026 .126 r
.47118 .54174 .47599 .54642 .48453 .54369 .47973 .53899 Metetra
0 .027 .126 r
.47973 .53899 .48453 .54369 .49309 .54123 .48831 .53651 Metetra
0 .027 .126 r
.48831 .53651 .49309 .54123 .50167 .53873 .49691 .5339 Metetra
0 .027 .127 r
.49691 .5339 .50167 .53873 .51029 .53611 .50554 .53139 Metetra
0 .027 .127 r
.50554 .53139 .51029 .53611 .51893 .5335 .5142 .52877 Metetra
0 .027 .126 r
.5142 .52877 .51893 .5335 .5276 .53062 .52289 .52591 Metetra
0 .027 .126 r
.52289 .52591 .5276 .53062 .5363 .52807 .53161 .52326 Metetra
0 .027 .126 r
.53161 .52326 .5363 .52807 .54502 .52546 .54035 .52048 Metetra
0 .027 .127 r
.54035 .52048 .54502 .52546 .55377 .52285 .54912 .51797 Metetra
0 .028 .127 r
.54912 .51797 .55377 .52285 .56255 .52021 .55792 .51531 Metetra
0 .027 .127 r
.55792 .51531 .56255 .52021 .57136 .51729 .56674 .51239 Metetra
0 .027 .127 r
.56674 .51239 .57136 .51729 .5802 .51478 .5756 .50979 Metetra
0 .028 .127 r
.5756 .50979 .5802 .51478 .58907 .51226 .58449 .50714 Metetra
0 .028 .127 r
.58449 .50714 .58907 .51226 .59796 .5094 .5934 .50444 Metetra
0 .028 .127 r
.5934 .50444 .59796 .5094 .60688 .5067 .60234 .50173 Metetra
0 .028 .127 r
.60234 .50173 .60688 .5067 .61583 .50401 .61131 .49884 Metetra
0 .028 .127 r
.61131 .49884 .61583 .50401 .62481 .50128 .62031 .49622 Metetra
0 .028 .128 r
.62031 .49622 .62481 .50128 .63382 .4986 .62934 .49363 Metetra
0 .028 .128 r
.62934 .49363 .63382 .4986 .64285 .49575 .63839 .49061 Metetra
0 .028 .128 r
.63839 .49061 .64285 .49575 .65192 .49297 .64748 .48781 Metetra
0 .028 .128 r
.64748 .48781 .65192 .49297 .66102 .49026 .6566 .48524 Metetra
0 .028 .128 r
.6566 .48524 .66102 .49026 .67014 .4874 .66574 .48225 Metetra
0 .028 .127 r
.66574 .48225 .67014 .4874 .67929 .48455 .67491 .47927 Metetra
0 .028 .127 r
.67491 .47927 .67929 .48455 .68847 .48168 .68412 .47657 Metetra
0 .028 .127 r
.68412 .47657 .68847 .48168 .69769 .47884 .69335 .4737 Metetra
0 .028 .127 r
.69335 .4737 .69769 .47884 .70694 .47614 .70261 .4708 Metetra
0 .028 .127 r
.70261 .4708 .70694 .47614 .7162 .47308 .7119 .46784 Metetra
0 .027 .126 r
.7119 .46784 .7162 .47308 .72549 .47003 .72122 .46485 Metetra
0 .027 .127 r
.72122 .46485 .72549 .47003 .73484 .46739 .73059 .46218 Metetra
0 .028 .127 r
.73059 .46218 .73484 .46739 .7442 .46448 .73997 .45925 Metetra
0 .027 .127 r
.73997 .45925 .7442 .46448 .75359 .46152 .74938 .45616 Metetra
0 .027 .126 r
.74938 .45616 .75359 .46152 .76301 .45856 .75883 .45333 Metetra
0 .027 .126 r
.75883 .45333 .76301 .45856 .77246 .45554 .76831 .45039 Metetra
0 .027 .126 r
.76831 .45039 .77246 .45554 .78197 .45286 .77784 .44766 Metetra
0 .027 .127 r
.77784 .44766 .78197 .45286 .79149 .44991 .78737 .44468 Metetra
0 .027 .127 r
.78737 .44468 .79149 .44991 .80103 .44695 .79694 .44157 Metetra
0 .027 .126 r
.79694 .44157 .80103 .44695 .8106 .44387 .80654 .43857 Metetra
0 .027 .126 r
.80654 .43857 .8106 .44387 .8202 .44076 .81616 .43545 Metetra
0 .026 .126 r
.81616 .43545 .8202 .44076 .82986 .43791 .82584 .4326 Metetra
0 .026 .126 r
.82584 .4326 .82986 .43791 .83954 .4349 .83553 .4295 Metetra
0 .026 .126 r
.83553 .4295 .83954 .4349 .84926 .43202 .84527 .42648 Metetra
0 .026 .125 r
.84527 .42648 .84926 .43202 .85897 .42874 .855 .42317 Metetra
0 .025 .124 r
.855 .42317 .85897 .42874 .86873 .42562 .86478 .41997 Metetra
0 .025 .123 r
.86478 .41997 .86873 .42562 .87852 .42243 .8746 .41683 Metetra
0 .025 .123 r
.8746 .41683 .87852 .42243 .88836 .41941 .88447 .41381 Metetra
0 .025 .123 r
.88447 .41381 .88836 .41941 .89823 .41636 .89437 .41084 Metetra
0 .025 .123 r
.89437 .41084 .89823 .41636 .90815 .41341 .90431 .40783 Metetra
0 .025 .124 r
.90431 .40783 .90815 .41341 .9181 .41044 .91429 .40487 Metetra
0 .025 .124 r
.91429 .40487 .9181 .41044 .92807 .40737 .92428 .40175 Metetra
0 .025 .124 r
.92428 .40175 .92807 .40737 .93807 .40421 .93431 .39858 Metetra
0 .025 .123 r
.93431 .39858 .93807 .40421 .9481 .40102 .94435 .39533 Metetra
0 .025 .123 r
.36562 .56712 .37065 .57196 .37888 .56957 .37386 .56485 Metetra
0 .025 .124 r
.37386 .56485 .37888 .56957 .38714 .5671 .38213 .56242 Metetra
0 .025 .124 r
.38213 .56242 .38714 .5671 .39542 .56458 .39043 .56003 Metetra
0 .025 .124 r
.39043 .56003 .39542 .56458 .40374 .56193 .39876 .5574 Metetra
0 .025 .124 r
.39876 .5574 .40374 .56193 .41208 .55931 .40711 .55487 Metetra
0 .025 .124 r
.40711 .55487 .41208 .55931 .42045 .55668 .4155 .55209 Metetra
0 .025 .123 r
.4155 .55209 .42045 .55668 .42884 .55407 .42391 .54941 Metetra
0 .025 .123 r
.42391 .54941 .42884 .55407 .43725 .55159 .43235 .54676 Metetra
0 .025 .124 r
.43235 .54676 .43725 .55159 .44569 .54916 .44081 .54426 Metetra
0 .026 .125 r
.44081 .54426 .44569 .54916 .45416 .54685 .44929 .54182 Metetra
0 .026 .125 r
.44929 .54182 .45416 .54685 .46266 .54424 .4578 .53929 Metetra
0 .027 .126 r
.4578 .53929 .46266 .54424 .47118 .54174 .46634 .53682 Metetra
0 .027 .126 r
.46634 .53682 .47118 .54174 .47973 .53899 .47491 .53413 Metetra
0 .027 .126 r
.47491 .53413 .47973 .53899 .48831 .53651 .4835 .53164 Metetra
0 .027 .126 r
.4835 .53164 .48831 .53651 .49691 .5339 .49212 .52894 Metetra
0 .027 .127 r
.49212 .52894 .49691 .5339 .50554 .53139 .50077 .52661 Metetra
0 .028 .128 r
.50077 .52661 .50554 .53139 .5142 .52877 .50945 .52405 Metetra
0 .028 .128 r
.50945 .52405 .5142 .52877 .52289 .52591 .51816 .52135 Metetra
0 .028 .127 r
.51816 .52135 .52289 .52591 .53161 .52326 .52689 .51861 Metetra
0 .028 .127 r
.52689 .51861 .53161 .52326 .54035 .52048 .53565 .5157 Metetra
0 .028 .127 r
.53565 .5157 .54035 .52048 .54912 .51797 .54444 .51326 Metetra
0 .028 .128 r
.54444 .51326 .54912 .51797 .55792 .51531 .55326 .51056 Metetra
0 .028 .128 r
.55326 .51056 .55792 .51531 .56674 .51239 .56211 .50771 Metetra
0 .028 .127 r
.56211 .50771 .56674 .51239 .5756 .50979 .57098 .50497 Metetra
0 .028 .127 r
.57098 .50497 .5756 .50979 .58449 .50714 .57988 .50211 Metetra
0 .028 .128 r
.57988 .50211 .58449 .50714 .5934 .50444 .58882 .49956 Metetra
0 .028 .128 r
.58882 .49956 .5934 .50444 .60234 .50173 .59778 .49682 Metetra
0 .028 .128 r
.59778 .49682 .60234 .50173 .61131 .49884 .60676 .49377 Metetra
0 .028 .128 r
.60676 .49377 .61131 .49884 .62031 .49622 .61578 .49118 Metetra
0 .029 .128 r
.61578 .49118 .62031 .49622 .62934 .49363 .62484 .48861 Metetra
0 .029 .128 r
.62484 .48861 .62934 .49363 .63839 .49061 .6339 .48551 Metetra
0 .028 .128 r
.6339 .48551 .63839 .49061 .64748 .48781 .64301 .4827 Metetra
0 .029 .128 r
.64301 .4827 .64748 .48781 .6566 .48524 .65216 .48018 Metetra
0 .029 .128 r
.65216 .48018 .6566 .48524 .66574 .48225 .66131 .47712 Metetra
0 .028 .128 r
.66131 .47712 .66574 .48225 .67491 .47927 .6705 .47408 Metetra
0 .028 .128 r
.6705 .47408 .67491 .47927 .68412 .47657 .67974 .47151 Metetra
0 .028 .128 r
.67974 .47151 .68412 .47657 .69335 .4737 .68899 .46864 Metetra
0 .028 .128 r
.68899 .46864 .69335 .4737 .70261 .4708 .69827 .46555 Metetra
0 .028 .127 r
.69827 .46555 .70261 .4708 .7119 .46784 .70759 .46276 Metetra
0 .028 .127 r
.70759 .46276 .7119 .46784 .72122 .46485 .71694 .4599 Metetra
0 .028 .128 r
.71694 .4599 .72122 .46485 .73059 .46218 .72632 .45712 Metetra
0 .028 .128 r
.72632 .45712 .73059 .46218 .73997 .45925 .73573 .45418 Metetra
0 .028 .127 r
.73573 .45418 .73997 .45925 .74938 .45616 .74515 .45099 Metetra
0 .028 .127 r
.74515 .45099 .74938 .45616 .75883 .45333 .75464 .44827 Metetra
0 .028 .127 r
.75464 .44827 .75883 .45333 .76831 .45039 .76414 .44539 Metetra
0 .028 .128 r
.76414 .44539 .76831 .45039 .77784 .44766 .77368 .44246 Metetra
0 .028 .128 r
.77368 .44246 .77784 .44766 .78737 .44468 .78324 .43938 Metetra
0 .027 .127 r
.78324 .43938 .78737 .44468 .79694 .44157 .7928 .43606 Metetra
0 .027 .126 r
.7928 .43606 .79694 .44157 .80654 .43857 .80243 .43311 Metetra
0 .027 .126 r
.80243 .43311 .80654 .43857 .81616 .43545 .81208 .42997 Metetra
0 .027 .126 r
.81208 .42997 .81616 .43545 .82584 .4326 .82178 .42702 Metetra
0 .027 .126 r
.82178 .42702 .82584 .4326 .83553 .4295 .83149 .42385 Metetra
0 .026 .125 r
.83149 .42385 .83553 .4295 .84527 .42648 .84124 .42073 Metetra
0 .026 .125 r
.84124 .42073 .84527 .42648 .855 .42317 .85101 .41751 Metetra
0 .025 .124 r
.85101 .41751 .855 .42317 .86478 .41997 .86082 .41434 Metetra
0 .025 .123 r
.86082 .41434 .86478 .41997 .8746 .41683 .87068 .41134 Metetra
0 .025 .123 r
.87068 .41134 .8746 .41683 .88447 .41381 .88057 .40838 Metetra
0 .025 .124 r
.88057 .40838 .88447 .41381 .89437 .41084 .89052 .40552 Metetra
0 .025 .124 r
.89052 .40552 .89437 .41084 .90431 .40783 .90047 .4024 Metetra
0 .026 .124 r
.90047 .4024 .90431 .40783 .91429 .40487 .91047 .39937 Metetra
0 .025 .124 r
.91047 .39937 .91429 .40487 .92428 .40175 .92047 .39608 Metetra
0 .025 .124 r
.92047 .39608 .92428 .40175 .93431 .39858 .93051 .39283 Metetra
0 .025 .123 r
.93051 .39283 .93431 .39858 .94435 .39533 .94057 .38942 Metetra
0 .024 .123 r
.36056 .56238 .36562 .56712 .37386 .56485 .36881 .56005 Metetra
0 .025 .124 r
.36881 .56005 .37386 .56485 .38213 .56242 .3771 .55756 Metetra
0 .025 .124 r
.3771 .55756 .38213 .56242 .39043 .56003 .38541 .55519 Metetra
0 .026 .125 r
.38541 .55519 .39043 .56003 .39876 .5574 .39376 .5526 Metetra
0 .026 .125 r
.39376 .5526 .39876 .5574 .40711 .55487 .40213 .55017 Metetra
0 .026 .125 r
.40213 .55017 .40711 .55487 .4155 .55209 .41053 .54739 Metetra
0 .025 .124 r
.41053 .54739 .4155 .55209 .42391 .54941 .41896 .54476 Metetra
0 .025 .124 r
.41896 .54476 .42391 .54941 .43235 .54676 .42741 .54205 Metetra
0 .025 .124 r
.42741 .54205 .43235 .54676 .44081 .54426 .43588 .53956 Metetra
0 .026 .125 r
.43588 .53956 .44081 .54426 .44929 .54182 .44439 .53702 Metetra
0 .026 .125 r
.44439 .53702 .44929 .54182 .4578 .53929 .45291 .53452 Metetra
0 .027 .126 r
.45291 .53452 .4578 .53929 .46634 .53682 .46147 .53201 Metetra
0 .027 .126 r
.46147 .53201 .46634 .53682 .47491 .53413 .47006 .52933 Metetra
0 .027 .126 r
.47006 .52933 .47491 .53413 .4835 .53164 .47867 .52672 Metetra
0 .027 .126 r
.47867 .52672 .4835 .53164 .49212 .52894 .48731 .52393 Metetra
0 .027 .127 r
.48731 .52393 .49212 .52894 .50077 .52661 .49597 .52158 Metetra
0 .028 .128 r
.49597 .52158 .50077 .52661 .50945 .52405 .50467 .519 Metetra
0 .029 .128 r
.50467 .519 .50945 .52405 .51816 .52135 .51339 .51647 Metetra
0 .029 .128 r
.51339 .51647 .51816 .52135 .52689 .51861 .52215 .51368 Metetra
0 .028 .128 r
.52215 .51368 .52689 .51861 .53565 .5157 .53093 .51077 Metetra
0 .028 .128 r
.53093 .51077 .53565 .5157 .54444 .51326 .53973 .50831 Metetra
0 .029 .129 r
.53973 .50831 .54444 .51326 .55326 .51056 .54857 .50563 Metetra
0 .029 .129 r
.54857 .50563 .55326 .51056 .56211 .50771 .55744 .50299 Metetra
0 .029 .129 r
.55744 .50299 .56211 .50771 .57098 .50497 .56633 .50015 Metetra
0 .028 .128 r
.56633 .50015 .57098 .50497 .57988 .50211 .57525 .49719 Metetra
0 .029 .128 r
.57525 .49719 .57988 .50211 .58882 .49956 .58421 .49475 Metetra
0 .029 .129 r
.58421 .49475 .58882 .49956 .59778 .49682 .59319 .49201 Metetra
0 .029 .129 r
.59319 .49201 .59778 .49682 .60676 .49377 .60219 .48896 Metetra
0 .029 .128 r
.60219 .48896 .60676 .49377 .61578 .49118 .61124 .48634 Metetra
0 .029 .129 r
.61124 .48634 .61578 .49118 .62484 .48861 .62031 .48369 Metetra
0 .029 .129 r
.62031 .48369 .62484 .48861 .6339 .48551 .6294 .48067 Metetra
0 .029 .129 r
.6294 .48067 .6339 .48551 .64301 .4827 .63853 .47785 Metetra
0 .029 .129 r
.63853 .47785 .64301 .4827 .65216 .48018 .64769 .4752 Metetra
0 .029 .129 r
.64769 .4752 .65216 .48018 .66131 .47712 .65687 .47218 Metetra
0 .029 .128 r
.65687 .47218 .66131 .47712 .6705 .47408 .66608 .46916 Metetra
0 .029 .129 r
.66608 .46916 .6705 .47408 .67974 .47151 .67534 .46656 Metetra
0 .029 .129 r
.67534 .46656 .67974 .47151 .68899 .46864 .68461 .46363 Metetra
0 .029 .128 r
.68461 .46363 .68899 .46864 .69827 .46555 .69391 .46041 Metetra
0 .028 .128 r
.69391 .46041 .69827 .46555 .70759 .46276 .70325 .4577 Metetra
0 .029 .129 r
.70325 .4577 .70759 .46276 .71694 .4599 .71263 .45489 Metetra
0 .029 .129 r
.71263 .45489 .71694 .4599 .72632 .45712 .72202 .45187 Metetra
0 .029 .129 r
.72202 .45187 .72632 .45712 .73573 .45418 .73145 .44888 Metetra
0 .028 .128 r
.73145 .44888 .73573 .45418 .74515 .45099 .74089 .44567 Metetra
0 .028 .128 r
.74089 .44567 .74515 .45099 .75464 .44827 .7504 .44292 Metetra
0 .029 .128 r
.7504 .44292 .75464 .44827 .76414 .44539 .75993 .44005 Metetra
0 .029 .128 r
.75993 .44005 .76414 .44539 .77368 .44246 .76947 .43692 Metetra
0 .028 .128 r
.76947 .43692 .77368 .44246 .78324 .43938 .77905 .43381 Metetra
0 .027 .127 r
.77905 .43381 .78324 .43938 .7928 .43606 .78864 .43048 Metetra
0 .027 .126 r
.78864 .43048 .7928 .43606 .80243 .43311 .7983 .4276 Metetra
0 .027 .126 r
.7983 .4276 .80243 .43311 .81208 .42997 .80798 .42455 Metetra
0 .027 .126 r
.80798 .42455 .81208 .42997 .82178 .42702 .8177 .42156 Metetra
0 .027 .126 r
.8177 .42156 .82178 .42702 .83149 .42385 .82744 .41839 Metetra
0 .026 .125 r
.82744 .41839 .83149 .42385 .84124 .42073 .8372 .41519 Metetra
0 .026 .125 r
.8372 .41519 .84124 .42073 .85101 .41751 .84701 .41204 Metetra
0 .025 .124 r
.84701 .41204 .85101 .41751 .86082 .41434 .85684 .40885 Metetra
0 .025 .124 r
.85684 .40885 .86082 .41434 .87068 .41134 .86673 .40587 Metetra
0 .025 .124 r
.86673 .40587 .87068 .41134 .88057 .40838 .87665 .40283 Metetra
0 .026 .125 r
.87665 .40283 .88057 .40838 .89052 .40552 .88661 .39992 Metetra
0 .026 .125 r
.88661 .39992 .89052 .40552 .90047 .4024 .89658 .39666 Metetra
0 .026 .125 r
.89658 .39666 .90047 .4024 .91047 .39937 .90659 .39355 Metetra
0 .025 .124 r
.90659 .39355 .91047 .39937 .92047 .39608 .91661 .39022 Metetra
0 .025 .124 r
.91661 .39022 .92047 .39608 .93051 .39283 .92668 .38699 Metetra
0 .024 .123 r
.92668 .38699 .93051 .39283 .94057 .38942 .93677 .3836 Metetra
0 .024 .122 r
.35547 .55749 .36056 .56238 .36881 .56005 .36374 .55514 Metetra
0 .025 .123 r
.36374 .55514 .36881 .56005 .3771 .55756 .37205 .55265 Metetra
0 .025 .124 r
.37205 .55265 .3771 .55756 .38541 .55519 .38037 .55036 Metetra
0 .026 .124 r
.38037 .55036 .38541 .55519 .39376 .5526 .38873 .54788 Metetra
0 .026 .125 r
.38873 .54788 .39376 .5526 .40213 .55017 .3971 .54561 Metetra
0 .026 .125 r
.3971 .54561 .40213 .55017 .41053 .54739 .40552 .54284 Metetra
0 .026 .125 r
.40552 .54284 .41053 .54739 .41896 .54476 .41397 .54022 Metetra
0 .026 .125 r
.41397 .54022 .41896 .54476 .42741 .54205 .42244 .53739 Metetra
0 .026 .125 r
.42244 .53739 .42741 .54205 .43588 .53956 .43093 .5348 Metetra
0 .026 .125 r
.43093 .5348 .43588 .53956 .44439 .53702 .43946 .53207 Metetra
0 .026 .125 r
.43946 .53207 .44439 .53702 .45291 .53452 .448 .52954 Metetra
0 .027 .126 r
.448 .52954 .45291 .53452 .46147 .53201 .45658 .52696 Metetra
0 .027 .126 r
.45658 .52696 .46147 .53201 .47006 .52933 .46518 .52433 Metetra
0 .027 .126 r
.46518 .52433 .47006 .52933 .47867 .52672 .47381 .52167 Metetra
0 .027 .126 r
.47381 .52167 .47867 .52672 .48731 .52393 .48247 .51891 Metetra
0 .027 .127 r
.48247 .51891 .48731 .52393 .49597 .52158 .49115 .51657 Metetra
0 .028 .128 r
.49115 .51657 .49597 .52158 .50467 .519 .49986 .51405 Metetra
0 .029 .129 r
.49986 .51405 .50467 .519 .51339 .51647 .5086 .51175 Metetra
0 .029 .129 r
.5086 .51175 .51339 .51647 .52215 .51368 .51737 .50898 Metetra
0 .029 .129 r
.51737 .50898 .52215 .51368 .53093 .51077 .52617 .50617 Metetra
0 .029 .129 r
.52617 .50617 .53093 .51077 .53973 .50831 .535 .5036 Metetra
0 .03 .13 r
.535 .5036 .53973 .50831 .54857 .50563 .54386 .50088 Metetra
0 .03 .13 r
.54386 .50088 .54857 .50563 .55744 .50299 .55274 .49841 Metetra
0 .03 .13 r
.55274 .49841 .55744 .50299 .56633 .50015 .56166 .49543 Metetra
0 .029 .129 r
.56166 .49543 .56633 .50015 .57525 .49719 .57059 .49238 Metetra
0 .03 .13 r
.57059 .49238 .57525 .49719 .58421 .49475 .57957 .48989 Metetra
0 .03 .13 r
.57957 .48989 .58421 .49475 .59319 .49201 .58857 .4871 Metetra
0 .03 .13 r
.58857 .4871 .59319 .49201 .60219 .48896 .5976 .48412 Metetra
0 .03 .13 r
.5976 .48412 .60219 .48896 .61124 .48634 .60666 .48137 Metetra
0 .03 .13 r
.60666 .48137 .61124 .48634 .62031 .48369 .61575 .47855 Metetra
0 .03 .13 r
.61575 .47855 .62031 .48369 .6294 .48067 .62486 .4757 Metetra
0 .03 .13 r
.62486 .4757 .6294 .48067 .63853 .47785 .63401 .47286 Metetra
0 .03 .13 r
.63401 .47286 .63853 .47785 .64769 .4752 .64319 .47002 Metetra
0 .03 .13 r
.64319 .47002 .64769 .4752 .65687 .47218 .6524 .46712 Metetra
0 .03 .13 r
.6524 .46712 .65687 .47218 .66608 .46916 .66163 .46421 Metetra
0 .03 .13 r
.66163 .46421 .66608 .46916 .67534 .46656 .67091 .4615 Metetra
0 .03 .13 r
.67091 .4615 .67534 .46656 .68461 .46363 .68021 .45858 Metetra
0 .03 .13 r
.68021 .45858 .68461 .46363 .69391 .46041 .68952 .45537 Metetra
0 .029 .129 r
.68952 .45537 .69391 .46041 .70325 .4577 .6989 .45274 Metetra
0 .03 .13 r
.6989 .45274 .70325 .4577 .71263 .45489 .7083 .45003 Metetra
0 .03 .13 r
.7083 .45003 .71263 .45489 .72202 .45187 .71771 .44681 Metetra
0 .03 .13 r
.71771 .44681 .72202 .45187 .73145 .44888 .72716 .44381 Metetra
0 .029 .129 r
.72716 .44381 .73145 .44888 .74089 .44567 .73663 .44068 Metetra
0 .029 .129 r
.73663 .44068 .74089 .44567 .7504 .44292 .74615 .43781 Metetra
0 .029 .129 r
.74615 .43781 .7504 .44292 .75993 .44005 .7557 .43488 Metetra
0 .029 .129 r
.7557 .43488 .75993 .44005 .76947 .43692 .76525 .43147 Metetra
0 .028 .128 r
.76525 .43147 .76947 .43692 .77905 .43381 .77485 .42827 Metetra
0 .027 .127 r
.77485 .42827 .77905 .43381 .78864 .43048 .78446 .4249 Metetra
0 .027 .126 r
.78446 .4249 .78864 .43048 .7983 .4276 .79414 .42196 Metetra
0 .027 .126 r
.79414 .42196 .7983 .4276 .80798 .42455 .80385 .41891 Metetra
0 .027 .126 r
.80385 .41891 .80798 .42455 .8177 .42156 .81358 .41584 Metetra
0 .027 .126 r
.81358 .41584 .8177 .42156 .82744 .41839 .82334 .4127 Metetra
0 .026 .125 r
.82334 .4127 .82744 .41839 .8372 .41519 .83314 .40951 Metetra
0 .026 .125 r
.83314 .40951 .8372 .41519 .84701 .41204 .84298 .40651 Metetra
0 .026 .125 r
.84298 .40651 .84701 .41204 .85684 .40885 .85285 .40339 Metetra
0 .026 .125 r
.85285 .40339 .85684 .40885 .86673 .40587 .86277 .40051 Metetra
0 .026 .125 r
.86277 .40051 .86673 .40587 .87665 .40283 .87271 .39742 Metetra
0 .026 .125 r
.87271 .39742 .87665 .40283 .88661 .39992 .8827 .39447 Metetra
0 .026 .125 r
.8827 .39447 .88661 .39992 .89658 .39666 .89267 .391 Metetra
0 .026 .125 r
.89267 .391 .89658 .39666 .90659 .39355 .90269 .38774 Metetra
0 .025 .124 r
.90269 .38774 .90659 .39355 .91661 .39022 .91273 .38428 Metetra
0 .025 .123 r
.91273 .38428 .91661 .39022 .92668 .38699 .92282 .38102 Metetra
0 .024 .122 r
.92282 .38102 .92668 .38699 .93677 .3836 .93294 .37762 Metetra
0 .024 .122 r
.35034 .55293 .35547 .55749 .36374 .55514 .35863 .55048 Metetra
0 .024 .123 r
.35863 .55048 .36374 .55514 .37205 .55265 .36696 .54787 Metetra
0 .025 .123 r
.36696 .54787 .37205 .55265 .38037 .55036 .3753 .54544 Metetra
0 .025 .124 r
.3753 .54544 .38037 .55036 .38873 .54788 .38367 .5429 Metetra
0 .026 .125 r
.38367 .5429 .38873 .54788 .3971 .54561 .39207 .54057 Metetra
0 .027 .126 r
.39207 .54057 .3971 .54561 .40552 .54284 .4005 .53787 Metetra
0 .026 .126 r
.4005 .53787 .40552 .54284 .41397 .54022 .40896 .53534 Metetra
0 .026 .125 r
.40896 .53534 .41397 .54022 .42244 .53739 .41744 .53259 Metetra
0 .026 .125 r
.41744 .53259 .42244 .53739 .43093 .5348 .42595 .53005 Metetra
0 .026 .125 r
.42595 .53005 .43093 .5348 .43946 .53207 .43449 .52728 Metetra
0 .026 .125 r
.43449 .52728 .43946 .53207 .448 .52954 .44305 .52486 Metetra
0 .027 .126 r
.44305 .52486 .448 .52954 .45658 .52696 .45165 .52225 Metetra
0 .027 .126 r
.45165 .52225 .45658 .52696 .46518 .52433 .46026 .51968 Metetra
0 .027 .127 r
.46026 .51968 .46518 .52433 .47381 .52167 .46891 .51689 Metetra
0 .027 .126 r
.46891 .51689 .47381 .52167 .48247 .51891 .47759 .5141 Metetra
0 .027 .127 r
.47759 .5141 .48247 .51891 .49115 .51657 .48629 .51152 Metetra
0 .028 .128 r
.48629 .51152 .49115 .51657 .49986 .51405 .49502 .50888 Metetra
0 .029 .129 r
.49502 .50888 .49986 .51405 .5086 .51175 .50378 .50653 Metetra
0 .03 .13 r
.50378 .50653 .5086 .51175 .51737 .50898 .51257 .50378 Metetra
0 .03 .13 r
.51257 .50378 .51737 .50898 .52617 .50617 .52139 .50115 Metetra
0 .03 .13 r
.52139 .50115 .52617 .50617 .535 .5036 .53023 .49839 Metetra
0 .03 .13 r
.53023 .49839 .535 .5036 .54386 .50088 .53911 .4957 Metetra
0 .031 .131 r
.53911 .4957 .54386 .50088 .55274 .49841 .54802 .49333 Metetra
0 .031 .131 r
.54802 .49333 .55274 .49841 .56166 .49543 .55695 .49043 Metetra
0 .031 .131 r
.55695 .49043 .56166 .49543 .57059 .49238 .56591 .48757 Metetra
0 .031 .131 r
.56591 .48757 .57059 .49238 .57957 .48989 .5749 .4849 Metetra
0 .031 .131 r
.5749 .4849 .57957 .48989 .58857 .4871 .58392 .48212 Metetra
0 .031 .131 r
.58392 .48212 .58857 .4871 .5976 .48412 .59298 .47946 Metetra
0 .031 .131 r
.59298 .47946 .5976 .48412 .60666 .48137 .60206 .47653 Metetra
0 .031 .131 r
.60206 .47653 .60666 .48137 .61575 .47855 .61116 .47352 Metetra
0 .031 .131 r
.61116 .47352 .61575 .47855 .62486 .4757 .62031 .47094 Metetra
0 .031 .132 r
.62031 .47094 .62486 .4757 .63401 .47286 .62948 .46808 Metetra
0 .031 .131 r
.62948 .46808 .63401 .47286 .64319 .47002 .63867 .46494 Metetra
0 .031 .131 r
.63867 .46494 .64319 .47002 .6524 .46712 .6479 .4622 Metetra
0 .031 .131 r
.6479 .4622 .6524 .46712 .66163 .46421 .65717 .45943 Metetra
0 .031 .131 r
.65717 .45943 .66163 .46421 .67091 .4615 .66645 .45637 Metetra
0 .031 .131 r
.66645 .45637 .67091 .4615 .68021 .45858 .67577 .4534 Metetra
0 .031 .131 r
.67577 .4534 .68021 .45858 .68952 .45537 .68511 .45035 Metetra
0 .031 .131 r
.68511 .45035 .68952 .45537 .6989 .45274 .6945 .4475 Metetra
0 .031 .131 r
.6945 .4475 .6989 .45274 .7083 .45003 .70392 .44466 Metetra
0 .031 .131 r
.70392 .44466 .7083 .45003 .71771 .44681 .71334 .44129 Metetra
0 .03 .13 r
.71334 .44129 .71771 .44681 .72716 .44381 .72281 .43824 Metetra
0 .03 .13 r
.72281 .43824 .72716 .44381 .73663 .44068 .73232 .43528 Metetra
0 .03 .13 r
.73232 .43528 .73663 .44068 .74615 .43781 .74185 .43219 Metetra
0 .03 .13 r
.74185 .43219 .74615 .43781 .7557 .43488 .75142 .42919 Metetra
0 .029 .129 r
.75142 .42919 .7557 .43488 .76525 .43147 .76099 .42579 Metetra
0 .028 .128 r
.76099 .42579 .76525 .43147 .77485 .42827 .77062 .42267 Metetra
0 .027 .127 r
.77062 .42267 .77485 .42827 .78446 .4249 .78027 .41952 Metetra
0 .027 .126 r
.78027 .41952 .78446 .4249 .79414 .42196 .78998 .41659 Metetra
0 .027 .127 r
.78998 .41659 .79414 .42196 .80385 .41891 .79971 .41364 Metetra
0 .027 .126 r
.79971 .41364 .80385 .41891 .81358 .41584 .80947 .41046 Metetra
0 .027 .126 r
.80947 .41046 .81358 .41584 .82334 .4127 .81926 .40731 Metetra
0 .026 .125 r
.81926 .40731 .82334 .4127 .83314 .40951 .82906 .40398 Metetra
0 .026 .125 r
.82906 .40398 .83314 .40951 .84298 .40651 .83893 .40099 Metetra
0 .026 .125 r
.83893 .40099 .84298 .40651 .85285 .40339 .84882 .39778 Metetra
0 .026 .125 r
.84882 .39778 .85285 .40339 .86277 .40051 .85876 .39479 Metetra
0 .026 .126 r
.85876 .39479 .86277 .40051 .87271 .39742 .86871 .39156 Metetra
0 .027 .126 r
.86871 .39156 .87271 .39742 .8827 .39447 .87871 .3885 Metetra
0 .026 .125 r
.87871 .3885 .8827 .39447 .89267 .391 .88871 .38506 Metetra
0 .026 .124 r
.88871 .38506 .89267 .391 .90269 .38774 .89876 .38182 Metetra
0 .025 .123 r
.89876 .38182 .90269 .38774 .91273 .38428 .90884 .37847 Metetra
0 .024 .123 r
.90884 .37847 .91273 .38428 .92282 .38102 .91897 .37531 Metetra
0 .024 .122 r
.91897 .37531 .92282 .38102 .93294 .37762 .92912 .37199 Metetra
0 .024 .123 r
.34518 .54823 .35034 .55293 .35863 .55048 .35349 .5457 Metetra
0 .025 .123 r
.35349 .5457 .35863 .55048 .36696 .54787 .36184 .54303 Metetra
0 .025 .123 r
.36184 .54303 .36696 .54787 .3753 .54544 .3702 .54053 Metetra
0 .025 .124 r
.3702 .54053 .3753 .54544 .38367 .5429 .37859 .538 Metetra
0 .026 .125 r
.37859 .538 .38367 .5429 .39207 .54057 .387 .53565 Metetra
0 .026 .125 r
.387 .53565 .39207 .54057 .4005 .53787 .39544 .53302 Metetra
0 .026 .126 r
.39544 .53302 .4005 .53787 .40896 .53534 .40391 .53054 Metetra
0 .027 .126 r
.40391 .53054 .40896 .53534 .41744 .53259 .41242 .52783 Metetra
0 .027 .126 r
.41242 .52783 .41744 .53259 .42595 .53005 .42094 .52526 Metetra
0 .027 .126 r
.42094 .52526 .42595 .53005 .43449 .52728 .4295 .52244 Metetra
0 .027 .126 r
.4295 .52244 .43449 .52728 .44305 .52486 .43808 .51999 Metetra
0 .027 .127 r
.43808 .51999 .44305 .52486 .45165 .52225 .44669 .51733 Metetra
0 .028 .127 r
.44669 .51733 .45165 .52225 .46026 .51968 .45532 .5148 Metetra
0 .028 .127 r
.45532 .5148 .46026 .51968 .46891 .51689 .46399 .51197 Metetra
0 .028 .127 r
.46399 .51197 .46891 .51689 .47759 .5141 .47269 .50924 Metetra
0 .028 .127 r
.47269 .50924 .47759 .5141 .48629 .51152 .48141 .50649 Metetra
0 .028 .127 r
.48141 .50649 .48629 .51152 .49502 .50888 .49016 .50382 Metetra
0 .029 .128 r
.49016 .50382 .49502 .50888 .50378 .50653 .49893 .50142 Metetra
0 .029 .129 r
.49893 .50142 .50378 .50653 .51257 .50378 .50774 .49877 Metetra
0 .03 .13 r
.50774 .49877 .51257 .50378 .52139 .50115 .51658 .49632 Metetra
0 .03 .13 r
.51658 .49632 .52139 .50115 .53023 .49839 .52544 .49343 Metetra
0 .03 .13 r
.52544 .49343 .53023 .49839 .53911 .4957 .53434 .49075 Metetra
0 .031 .131 r
.53434 .49075 .53911 .4957 .54802 .49333 .54326 .48832 Metetra
0 .032 .132 r
.54326 .48832 .54802 .49333 .55695 .49043 .55221 .48553 Metetra
0 .032 .132 r
.55221 .48553 .55695 .49043 .56591 .48757 .5612 .48286 Metetra
0 .032 .132 r
.5612 .48286 .56591 .48757 .5749 .4849 .57021 .47994 Metetra
0 .032 .132 r
.57021 .47994 .5749 .4849 .58392 .48212 .57925 .47715 Metetra
0 .032 .133 r
.57925 .47715 .58392 .48212 .59298 .47946 .58833 .47467 Metetra
0 .033 .133 r
.58833 .47467 .59298 .47946 .60206 .47653 .59742 .47162 Metetra
0 .032 .133 r
.59742 .47162 .60206 .47653 .61116 .47352 .60655 .46852 Metetra
0 .032 .133 r
.60655 .46852 .61116 .47352 .62031 .47094 .61572 .46603 Metetra
0 .033 .133 r
.61572 .46603 .62031 .47094 .62948 .46808 .62491 .46315 Metetra
0 .032 .133 r
.62491 .46315 .62948 .46808 .63867 .46494 .63412 .45988 Metetra
0 .032 .133 r
.63412 .45988 .63867 .46494 .6479 .4622 .64338 .45722 Metetra
0 .033 .133 r
.64338 .45722 .6479 .4622 .65717 .45943 .65267 .45452 Metetra
0 .032 .133 r
.65267 .45452 .65717 .45943 .66645 .45637 .66196 .45123 Metetra
0 .032 .132 r
.66196 .45123 .66645 .45637 .67577 .4534 .6713 .44825 Metetra
0 .032 .132 r
.6713 .44825 .67577 .4534 .68511 .45035 .68068 .44541 Metetra
0 .032 .132 r
.68068 .44541 .68511 .45035 .6945 .4475 .69008 .44234 Metetra
0 .032 .132 r
.69008 .44234 .6945 .4475 .70392 .44466 .69951 .43935 Metetra
0 .031 .131 r
.69951 .43935 .70392 .44466 .71334 .44129 .70896 .43601 Metetra
0 .03 .13 r
.70896 .43601 .71334 .44129 .72281 .43824 .71845 .43292 Metetra
0 .03 .13 r
.71845 .43292 .72281 .43824 .73232 .43528 .72799 .43005 Metetra
0 .03 .13 r
.72799 .43005 .73232 .43528 .74185 .43219 .73753 .42674 Metetra
0 .029 .129 r
.73753 .42674 .74185 .43219 .75142 .42919 .74711 .42361 Metetra
0 .029 .128 r
.74711 .42361 .75142 .42919 .76099 .42579 .75671 .42022 Metetra
0 .028 .127 r
.75671 .42022 .76099 .42579 .77062 .42267 .76636 .41712 Metetra
0 .028 .127 r
.76636 .41712 .77062 .42267 .78027 .41952 .77605 .4141 Metetra
0 .028 .127 r
.77605 .4141 .78027 .41952 .78998 .41659 .78578 .41106 Metetra
0 .028 .127 r
.78578 .41106 .78998 .41659 .79971 .41364 .79554 .40812 Metetra
0 .028 .127 r
.79554 .40812 .79971 .41364 .80947 .41046 .80531 .40486 Metetra
0 .027 .127 r
.80531 .40486 .80947 .41046 .81926 .40731 .81513 .40173 Metetra
0 .027 .126 r
.81513 .40173 .81926 .40731 .82906 .40398 .82496 .39839 Metetra
0 .027 .126 r
.82496 .39839 .82906 .40398 .83893 .40099 .83486 .39542 Metetra
0 .027 .126 r
.83486 .39542 .83893 .40099 .84882 .39778 .84477 .39222 Metetra
0 .027 .126 r
.84477 .39222 .84882 .39778 .85876 .39479 .85473 .38914 Metetra
0 .026 .126 r
.85473 .38914 .85876 .39479 .86871 .39156 .8647 .38583 Metetra
0 .026 .125 r
.8647 .38583 .86871 .39156 .87871 .3885 .87471 .38265 Metetra
0 .026 .125 r
.87471 .38265 .87871 .3885 .88871 .38506 .88474 .3792 Metetra
0 .025 .124 r
.88474 .3792 .88871 .38506 .89876 .38182 .89481 .37592 Metetra
0 .025 .123 r
.89481 .37592 .89876 .38182 .90884 .37847 .90492 .3726 Metetra
0 .025 .123 r
.90492 .3726 .90884 .37847 .91897 .37531 .91509 .36947 Metetra
0 .024 .123 r
.91509 .36947 .91897 .37531 .92912 .37199 .92527 .36619 Metetra
0 .025 .123 r
.33999 .5436 .34518 .54823 .35349 .5457 .34832 .54107 Metetra
0 .025 .123 r
.34832 .54107 .35349 .5457 .36184 .54303 .35668 .53837 Metetra
0 .025 .124 r
.35668 .53837 .36184 .54303 .3702 .54053 .36506 .53579 Metetra
0 .025 .124 r
.36506 .53579 .3702 .54053 .37859 .538 .37347 .53318 Metetra
0 .026 .125 r
.37347 .53318 .37859 .538 .387 .53565 .3819 .53069 Metetra
0 .026 .125 r
.3819 .53069 .387 .53565 .39544 .53302 .39036 .528 Metetra
0 .026 .125 r
.39036 .528 .39544 .53302 .40391 .53054 .39885 .52549 Metetra
0 .027 .126 r
.39885 .52549 .40391 .53054 .41242 .52783 .40737 .52283 Metetra
0 .027 .126 r
.40737 .52283 .41242 .52783 .42094 .52526 .41591 .52026 Metetra
0 .027 .126 r
.41591 .52026 .42094 .52526 .4295 .52244 .42448 .5175 Metetra
0 .027 .126 r
.42448 .5175 .4295 .52244 .43808 .51999 .43308 .51511 Metetra
0 .028 .127 r
.43308 .51511 .43808 .51999 .44669 .51733 .4417 .5125 Metetra
0 .028 .128 r
.4417 .5125 .44669 .51733 .45532 .5148 .45035 .51009 Metetra
0 .029 .128 r
.45035 .51009 .45532 .5148 .46399 .51197 .45904 .50726 Metetra
0 .028 .128 r
.45904 .50726 .46399 .51197 .47269 .50924 .46775 .50461 Metetra
0 .028 .128 r
.46775 .50461 .47269 .50924 .48141 .50649 .47649 .50163 Metetra
0 .028 .128 r
.47649 .50163 .48141 .50649 .49016 .50382 .48526 .49883 Metetra
0 .029 .128 r
.48526 .49883 .49016 .50382 .49893 .50142 .49406 .49622 Metetra
0 .029 .129 r
.49406 .49622 .49893 .50142 .50774 .49877 .50288 .49358 Metetra
0 .03 .13 r
.50288 .49358 .50774 .49877 .51658 .49632 .51174 .49119 Metetra
0 .03 .131 r
.51174 .49119 .51658 .49632 .52544 .49343 .52062 .48824 Metetra
0 .03 .131 r
.52062 .48824 .52544 .49343 .53434 .49075 .52953 .48558 Metetra
0 .031 .132 r
.52953 .48558 .53434 .49075 .54326 .48832 .53848 .48298 Metetra
0 .032 .132 r
.53848 .48298 .54326 .48832 .55221 .48553 .54745 .4804 Metetra
0 .033 .133 r
.54745 .4804 .55221 .48553 .5612 .48286 .55645 .47798 Metetra
0 .033 .134 r
.55645 .47798 .5612 .48286 .57021 .47994 .56548 .4749 Metetra
0 .033 .133 r
.56548 .4749 .57021 .47994 .57925 .47715 .57454 .47213 Metetra
0 .033 .134 r
.57454 .47213 .57925 .47715 .58833 .47467 .58364 .46975 Metetra
0 .034 .135 r
.58364 .46975 .58833 .47467 .59742 .47162 .59276 .4667 Metetra
0 .033 .134 r
.59276 .4667 .59742 .47162 .60655 .46852 .60191 .46367 Metetra
0 .033 .134 r
.60191 .46367 .60655 .46852 .61572 .46603 .6111 .46109 Metetra
0 .034 .135 r
.6111 .46109 .61572 .46603 .62491 .46315 .62031 .45818 Metetra
0 .033 .134 r
.62031 .45818 .62491 .46315 .63412 .45988 .62954 .45497 Metetra
0 .033 .134 r
.62954 .45497 .63412 .45988 .64338 .45722 .63882 .45223 Metetra
0 .034 .135 r
.63882 .45223 .64338 .45722 .65267 .45452 .64813 .44947 Metetra
0 .033 .134 r
.64813 .44947 .65267 .45452 .66196 .45123 .65745 .44605 Metetra
0 .033 .133 r
.65745 .44605 .66196 .45123 .6713 .44825 .66681 .44302 Metetra
0 .033 .134 r
.66681 .44302 .6713 .44825 .68068 .44541 .67622 .44031 Metetra
0 .033 .133 r
.67622 .44031 .68068 .44541 .69008 .44234 .68562 .43695 Metetra
0 .032 .133 r
.68562 .43695 .69008 .44234 .69951 .43935 .69507 .43371 Metetra
0 .031 .132 r
.69507 .43371 .69951 .43935 .70896 .43601 .70454 .4305 Metetra
0 .03 .131 r
.70454 .4305 .70896 .43601 .71845 .43292 .71406 .42736 Metetra
0 .03 .131 r
.71406 .42736 .71845 .43292 .72799 .43005 .72362 .42452 Metetra
0 .03 .13 r
.72362 .42452 .72799 .43005 .73753 .42674 .73318 .4211 Metetra
0 .029 .129 r
.73318 .4211 .73753 .42674 .74711 .42361 .74278 .41792 Metetra
0 .029 .128 r
.74278 .41792 .74711 .42361 .75671 .42022 .75242 .41472 Metetra
0 .028 .128 r
.75242 .41472 .75671 .42022 .76636 .41712 .7621 .41171 Metetra
0 .028 .128 r
.7621 .41171 .76636 .41712 .77605 .4141 .77183 .4089 Metetra
0 .028 .128 r
.77183 .4089 .77605 .4141 .78578 .41106 .78157 .40575 Metetra
0 .029 .128 r
.78157 .40575 .78578 .41106 .79554 .40812 .79135 .40276 Metetra
0 .028 .128 r
.79135 .40276 .79554 .40812 .80531 .40486 .80114 .39934 Metetra
0 .028 .127 r
.80114 .39934 .80531 .40486 .81513 .40173 .81097 .39613 Metetra
0 .027 .126 r
.81097 .39613 .81513 .40173 .82496 .39839 .82082 .39269 Metetra
0 .027 .126 r
.82082 .39269 .82496 .39839 .83486 .39542 .83074 .38963 Metetra
0 .027 .126 r
.83074 .38963 .83486 .39542 .84477 .39222 .84067 .38639 Metetra
0 .027 .126 r
.84067 .38639 .84477 .39222 .85473 .38914 .85065 .38322 Metetra
0 .026 .126 r
.85065 .38322 .85473 .38914 .8647 .38583 .86064 .37991 Metetra
0 .026 .125 r
.86064 .37991 .8647 .38583 .87471 .38265 .87069 .37676 Metetra
0 .026 .125 r
.87069 .37676 .87471 .38265 .88474 .3792 .88075 .37341 Metetra
0 .025 .124 r
.88075 .37341 .88474 .3792 .89481 .37592 .89086 .37017 Metetra
0 .025 .124 r
.89086 .37017 .89481 .37592 .90492 .3726 .901 .36691 Metetra
0 .025 .123 r
.901 .36691 .90492 .3726 .91509 .36947 .9112 .36376 Metetra
0 .025 .123 r
.9112 .36376 .91509 .36947 .92527 .36619 .92141 .36046 Metetra
0 .025 .124 r
.33478 .53874 .33999 .5436 .34832 .54107 .34312 .53615 Metetra
0 .025 .124 r
.34312 .53615 .34832 .54107 .35668 .53837 .3515 .53347 Metetra
0 .025 .124 r
.3515 .53347 .35668 .53837 .36506 .53579 .3599 .53088 Metetra
0 .025 .124 r
.3599 .53088 .36506 .53579 .37347 .53318 .36832 .52835 Metetra
0 .026 .125 r
.36832 .52835 .37347 .53318 .3819 .53069 .37676 .52583 Metetra
0 .026 .125 r
.37676 .52583 .3819 .53069 .39036 .528 .38524 .52322 Metetra
0 .026 .126 r
.38524 .52322 .39036 .528 .39885 .52549 .39375 .52068 Metetra
0 .027 .126 r
.39375 .52068 .39885 .52549 .40737 .52283 .40228 .51801 Metetra
0 .027 .126 r
.40228 .51801 .40737 .52283 .41591 .52026 .41084 .51532 Metetra
0 .027 .126 r
.41084 .51532 .41591 .52026 .42448 .5175 .41944 .51252 Metetra
0 .027 .127 r
.41944 .51252 .42448 .5175 .43308 .51511 .42805 .51001 Metetra
0 .028 .127 r
.42805 .51001 .43308 .51511 .4417 .5125 .43669 .50735 Metetra
0 .029 .128 r
.43669 .50735 .4417 .5125 .45035 .51009 .44536 .50494 Metetra
0 .029 .129 r
.44536 .50494 .45035 .51009 .45904 .50726 .45406 .50223 Metetra
0 .029 .129 r
.45406 .50223 .45904 .50726 .46775 .50461 .46278 .49976 Metetra
0 .029 .129 r
.46278 .49976 .46775 .50461 .47649 .50163 .47155 .49678 Metetra
0 .029 .129 r
.47155 .49678 .47649 .50163 .48526 .49883 .48033 .49403 Metetra
0 .029 .129 r
.48033 .49403 .48526 .49883 .49406 .49622 .48915 .49128 Metetra
0 .029 .129 r
.48915 .49128 .49406 .49622 .50288 .49358 .49799 .48872 Metetra
0 .031 .131 r
.49799 .48872 .50288 .49358 .51174 .49119 .50686 .48631 Metetra
0 .031 .131 r
.50686 .48631 .51174 .49119 .52062 .48824 .51577 .48337 Metetra
0 .031 .131 r
.51577 .48337 .52062 .48824 .52953 .48558 .5247 .48068 Metetra
0 .031 .132 r
.5247 .48068 .52953 .48558 .53848 .48298 .53366 .47781 Metetra
0 .032 .133 r
.53366 .47781 .53848 .48298 .54745 .4804 .54265 .47529 Metetra
0 .033 .134 r
.54265 .47529 .54745 .4804 .55645 .47798 .55168 .47289 Metetra
0 .034 .134 r
.55168 .47289 .55645 .47798 .56548 .4749 .56073 .46976 Metetra
0 .033 .134 r
.56073 .46976 .56548 .4749 .57454 .47213 .56981 .46698 Metetra
0 .034 .135 r
.56981 .46698 .57454 .47213 .58364 .46975 .57893 .4644 Metetra
0 .035 .136 r
.57893 .4644 .58364 .46975 .59276 .4667 .58807 .46148 Metetra
0 .034 .135 r
.58807 .46148 .59276 .4667 .60191 .46367 .59724 .45861 Metetra
0 .034 .136 r
.59724 .45861 .60191 .46367 .6111 .46109 .60644 .45575 Metetra
0 .035 .136 r
.60644 .45575 .6111 .46109 .62031 .45818 .61568 .45282 Metetra
0 .034 .136 r
.61568 .45282 .62031 .45818 .62954 .45497 .62494 .44986 Metetra
0 .034 .135 r
.62494 .44986 .62954 .45497 .63882 .45223 .63423 .44692 Metetra
0 .035 .136 r
.63423 .44692 .63882 .45223 .64813 .44947 .64356 .444 Metetra
0 .034 .135 r
.64356 .444 .64813 .44947 .65745 .44605 .6529 .44073 Metetra
0 .033 .134 r
.6529 .44073 .65745 .44605 .66681 .44302 .66228 .4377 Metetra
0 .034 .134 r
.66228 .4377 .66681 .44302 .67622 .44031 .67171 .43499 Metetra
0 .033 .134 r
.67171 .43499 .67622 .44031 .68562 .43695 .68114 .43157 Metetra
0 .032 .133 r
.68114 .43157 .68562 .43695 .69507 .43371 .6906 .42823 Metetra
0 .031 .132 r
.6906 .42823 .69507 .43371 .70454 .4305 .70012 .42526 Metetra
0 .031 .131 r
.70012 .42526 .70454 .4305 .71406 .42736 .70965 .42214 Metetra
0 .031 .131 r
.70965 .42214 .71406 .42736 .72362 .42452 .71924 .41924 Metetra
0 .031 .131 r
.71924 .41924 .72362 .42452 .73318 .4211 .72882 .4158 Metetra
0 .029 .129 r
.72882 .4158 .73318 .4211 .74278 .41792 .73844 .4125 Metetra
0 .029 .129 r
.73844 .4125 .74278 .41792 .75242 .41472 .74811 .40941 Metetra
0 .029 .129 r
.74811 .40941 .75242 .41472 .7621 .41171 .75781 .40633 Metetra
0 .029 .129 r
.75781 .40633 .7621 .41171 .77183 .4089 .76756 .40347 Metetra
0 .029 .129 r
.76756 .40347 .77183 .4089 .78157 .40575 .77731 .40011 Metetra
0 .029 .129 r
.77731 .40011 .78157 .40575 .79135 .40276 .78711 .39695 Metetra
0 .029 .128 r
.78711 .39695 .79135 .40276 .80114 .39934 .79691 .3935 Metetra
0 .028 .127 r
.79691 .3935 .80114 .39934 .81097 .39613 .80677 .39029 Metetra
0 .027 .127 r
.80677 .39029 .81097 .39613 .82082 .39269 .81666 .38695 Metetra
0 .027 .126 r
.81666 .38695 .82082 .39269 .83074 .38963 .8266 .3839 Metetra
0 .027 .126 r
.8266 .3839 .83074 .38963 .84067 .38639 .83657 .38074 Metetra
0 .027 .126 r
.83657 .38074 .84067 .38639 .85065 .38322 .84657 .37755 Metetra
0 .026 .126 r
.84657 .37755 .85065 .38322 .86064 .37991 .85659 .37422 Metetra
0 .026 .125 r
.85659 .37422 .86064 .37991 .87069 .37676 .86666 .37096 Metetra
0 .026 .125 r
.86666 .37096 .87069 .37676 .88075 .37341 .87674 .36759 Metetra
0 .025 .124 r
.87674 .36759 .88075 .37341 .89086 .37017 .88687 .36425 Metetra
0 .025 .124 r
.88687 .36425 .89086 .37017 .901 .36691 .89704 .36096 Metetra
0 .025 .124 r
.89704 .36096 .901 .36691 .9112 .36376 .90725 .35776 Metetra
0 .025 .124 r
.90725 .35776 .9112 .36376 .92141 .36046 .91749 .35448 Metetra
0 .025 .124 r
.32954 .53381 .33478 .53874 .34312 .53615 .3379 .53125 Metetra
0 .025 .124 r
.3379 .53125 .34312 .53615 .3515 .53347 .34628 .52866 Metetra
0 .025 .124 r
.34628 .52866 .3515 .53347 .3599 .53088 .35469 .5261 Metetra
0 .026 .125 r
.35469 .5261 .3599 .53088 .36832 .52835 .36313 .52362 Metetra
0 .026 .125 r
.36313 .52362 .36832 .52835 .37676 .52583 .37159 .52105 Metetra
0 .027 .126 r
.37159 .52105 .37676 .52583 .38524 .52322 .38009 .5184 Metetra
0 .027 .126 r
.38009 .5184 .38524 .52322 .39375 .52068 .38861 .51575 Metetra
0 .027 .126 r
.38861 .51575 .39375 .52068 .40228 .51801 .39717 .51299 Metetra
0 .027 .126 r
.39717 .51299 .40228 .51801 .41084 .51532 .40575 .51019 Metetra
0 .027 .126 r
.40575 .51019 .41084 .51532 .41944 .51252 .41436 .50741 Metetra
0 .027 .126 r
.41436 .50741 .41944 .51252 .42805 .51001 .42299 .50485 Metetra
0 .028 .127 r
.42299 .50485 .42805 .51001 .43669 .50735 .43165 .50226 Metetra
0 .028 .128 r
.43165 .50226 .43669 .50735 .44536 .50494 .44033 .49992 Metetra
0 .029 .129 r
.44033 .49992 .44536 .50494 .45406 .50223 .44905 .49739 Metetra
0 .03 .13 r
.44905 .49739 .45406 .50223 .46278 .49976 .45779 .49508 Metetra
0 .03 .131 r
.45779 .49508 .46278 .49976 .47155 .49678 .46657 .4921 Metetra
0 .03 .13 r
.46657 .4921 .47155 .49678 .48033 .49403 .47537 .48931 Metetra
0 .03 .13 r
.47537 .48931 .48033 .49403 .48915 .49128 .48421 .48634 Metetra
0 .03 .13 r
.48421 .48634 .48915 .49128 .49799 .48872 .49307 .4837 Metetra
0 .031 .132 r
.49307 .4837 .49799 .48872 .50686 .48631 .50196 .48112 Metetra
0 .032 .132 r
.50196 .48112 .50686 .48631 .51577 .48337 .51089 .47821 Metetra
0 .032 .132 r
.51089 .47821 .51577 .48337 .5247 .48068 .51984 .47547 Metetra
0 .032 .132 r
.51984 .47547 .5247 .48068 .53366 .47781 .52882 .47244 Metetra
0 .032 .133 r
.52882 .47244 .53366 .47781 .54265 .47529 .53783 .46998 Metetra
0 .033 .134 r
.53783 .46998 .54265 .47529 .55168 .47289 .54687 .46755 Metetra
0 .034 .135 r
.54687 .46755 .55168 .47289 .56073 .46976 .55594 .46462 Metetra
0 .034 .135 r
.55594 .46462 .56073 .46976 .56981 .46698 .56505 .46191 Metetra
0 .034 .136 r
.56505 .46191 .56981 .46698 .57893 .4644 .57418 .4591 Metetra
0 .035 .136 r
.57418 .4591 .57893 .4644 .58807 .46148 .58335 .4564 Metetra
0 .035 .137 r
.58335 .4564 .58807 .46148 .59724 .45861 .59254 .45376 Metetra
0 .035 .137 r
.59254 .45376 .59724 .45861 .60644 .45575 .60176 .4506 Metetra
0 .035 .137 r
.60176 .4506 .60644 .45575 .61568 .45282 .61102 .44766 Metetra
0 .035 .137 r
.61102 .44766 .61568 .45282 .62494 .44986 .62031 .44496 Metetra
0 .035 .137 r
.62031 .44496 .62494 .44986 .63423 .44692 .62962 .44176 Metetra
0 .035 .136 r
.62962 .44176 .63423 .44692 .64356 .444 .63896 .43857 Metetra
0 .034 .136 r
.63896 .43857 .64356 .444 .6529 .44073 .64833 .4355 Metetra
0 .034 .135 r
.64833 .4355 .6529 .44073 .66228 .4377 .65773 .43237 Metetra
0 .034 .135 r
.65773 .43237 .66228 .4377 .67171 .43499 .66717 .42942 Metetra
0 .033 .134 r
.66717 .42942 .67171 .43499 .68114 .43157 .67662 .42597 Metetra
0 .032 .133 r
.67662 .42597 .68114 .43157 .6906 .42823 .6861 .42256 Metetra
0 .032 .132 r
.6861 .42256 .6906 .42823 .70012 .42526 .69565 .41972 Metetra
0 .032 .132 r
.69565 .41972 .70012 .42526 .70965 .42214 .70521 .41661 Metetra
0 .032 .132 r
.70521 .41661 .70965 .42214 .71924 .41924 .71481 .41363 Metetra
0 .031 .132 r
.71481 .41363 .71924 .41924 .72882 .4158 .72442 .41033 Metetra
0 .03 .13 r
.72442 .41033 .72882 .4158 .73844 .4125 .73407 .40709 Metetra
0 .03 .13 r
.73407 .40709 .73844 .4125 .74811 .40941 .74378 .40419 Metetra
0 .03 .13 r
.74378 .40419 .74811 .40941 .75781 .40633 .75351 .40111 Metetra
0 .03 .131 r
.75351 .40111 .75781 .40633 .76756 .40347 .76328 .39821 Metetra
0 .03 .13 r
.76328 .39821 .76756 .40347 .77731 .40011 .77304 .39465 Metetra
0 .029 .129 r
.77304 .39465 .77731 .40011 .78711 .39695 .78285 .39127 Metetra
0 .028 .128 r
.78285 .39127 .78711 .39695 .79691 .3935 .79267 .38771 Metetra
0 .028 .127 r
.79267 .38771 .79691 .3935 .80677 .39029 .80255 .3844 Metetra
0 .027 .126 r
.80255 .3844 .80677 .39029 .81666 .38695 .81246 .38107 Metetra
0 .027 .126 r
.81246 .38107 .81666 .38695 .8266 .3839 .82242 .37796 Metetra
0 .027 .126 r
.82242 .37796 .8266 .3839 .83657 .38074 .83242 .37488 Metetra
0 .027 .126 r
.83242 .37488 .83657 .38074 .84657 .37755 .84246 .37174 Metetra
0 .027 .126 r
.84246 .37174 .84657 .37755 .85659 .37422 .85251 .36849 Metetra
0 .027 .126 r
.85251 .36849 .85659 .37422 .86666 .37096 .86261 .36523 Metetra
0 .026 .125 r
.86261 .36523 .86666 .37096 .87674 .36759 .87272 .36188 Metetra
0 .026 .125 r
.87272 .36188 .87674 .36759 .88687 .36425 .88287 .35845 Metetra
0 .025 .124 r
.88287 .35845 .88687 .36425 .89704 .36096 .89306 .35509 Metetra
0 .025 .124 r
.89306 .35509 .89704 .36096 .90725 .35776 .90329 .35176 Metetra
0 .025 .124 r
.90329 .35176 .90725 .35776 .91749 .35448 .91355 .34841 Metetra
0 .025 .124 r
.32425 .52909 .32954 .53381 .3379 .53125 .33264 .52633 Metetra
0 .025 .124 r
.33264 .52633 .3379 .53125 .34628 .52866 .34105 .52364 Metetra
0 .025 .124 r
.34105 .52364 .34628 .52866 .35469 .5261 .34948 .52097 Metetra
0 .026 .125 r
.34948 .52097 .35469 .5261 .36313 .52362 .35793 .51847 Metetra
0 .026 .125 r
.35793 .51847 .36313 .52362 .37159 .52105 .36641 .51586 Metetra
0 .027 .126 r
.36641 .51586 .37159 .52105 .38009 .5184 .37491 .51342 Metetra
0 .027 .127 r
.37491 .51342 .38009 .5184 .38861 .51575 .38345 .51087 Metetra
0 .027 .127 r
.38345 .51087 .38861 .51575 .39717 .51299 .39201 .50829 Metetra
0 .027 .127 r
.39201 .50829 .39717 .51299 .40575 .51019 .40062 .50547 Metetra
0 .027 .127 r
.40062 .50547 .40575 .51019 .41436 .50741 .40924 .50272 Metetra
0 .027 .127 r
.40924 .50272 .41436 .50741 .42299 .50485 .4179 .49991 Metetra
0 .028 .127 r
.4179 .49991 .42299 .50485 .43165 .50226 .42658 .49717 Metetra
0 .028 .128 r
.42658 .49717 .43165 .50226 .44033 .49992 .43528 .49459 Metetra
0 .029 .129 r
.43528 .49459 .44033 .49992 .44905 .49739 .44401 .49206 Metetra
0 .03 .131 r
.44401 .49206 .44905 .49739 .45779 .49508 .45277 .48972 Metetra
0 .031 .131 r
.45277 .48972 .45779 .49508 .46657 .4921 .46157 .48694 Metetra
0 .031 .131 r
.46157 .48694 .46657 .4921 .47537 .48931 .47039 .48432 Metetra
0 .031 .131 r
.47039 .48432 .47537 .48931 .48421 .48634 .47924 .48137 Metetra
0 .031 .132 r
.47924 .48137 .48421 .48634 .49307 .4837 .48812 .47886 Metetra
0 .032 .132 r
.48812 .47886 .49307 .4837 .50196 .48112 .49703 .47619 Metetra
0 .032 .133 r
.49703 .47619 .50196 .48112 .51089 .47821 .50597 .47357 Metetra
0 .033 .133 r
.50597 .47357 .51089 .47821 .51984 .47547 .51495 .47085 Metetra
0 .033 .133 r
.51495 .47085 .51984 .47547 .52882 .47244 .52395 .46773 Metetra
0 .033 .134 r
.52395 .46773 .52882 .47244 .53783 .46998 .53298 .46515 Metetra
0 .034 .135 r
.53298 .46515 .53783 .46998 .54687 .46755 .54204 .46245 Metetra
0 .035 .136 r
.54204 .46245 .54687 .46755 .55594 .46462 .55113 .45974 Metetra
0 .035 .136 r
.55113 .45974 .55594 .46462 .56505 .46191 .56026 .45697 Metetra
0 .035 .136 r
.56026 .45697 .56505 .46191 .57418 .4591 .56941 .45383 Metetra
0 .036 .137 r
.56941 .45383 .57418 .4591 .58335 .4564 .57859 .45124 Metetra
0 .037 .138 r
.57859 .45124 .58335 .4564 .59254 .45376 .58782 .44869 Metetra
0 .037 .138 r
.58782 .44869 .59254 .45376 .60176 .4506 .59705 .44533 Metetra
0 .036 .137 r
.59705 .44533 .60176 .4506 .61102 .44766 .60633 .44238 Metetra
0 .037 .138 r
.60633 .44238 .61102 .44766 .62031 .44496 .61564 .43984 Metetra
0 .037 .138 r
.61564 .43984 .62031 .44496 .62962 .44176 .62497 .4365 Metetra
0 .036 .137 r
.62497 .4365 .62962 .44176 .63896 .43857 .63433 .43317 Metetra
0 .035 .136 r
.63433 .43317 .63896 .43857 .64833 .4355 .64373 .43041 Metetra
0 .035 .136 r
.64373 .43041 .64833 .4355 .65773 .43237 .65316 .42729 Metetra
0 .035 .136 r
.65316 .42729 .65773 .43237 .66717 .42942 .66262 .42409 Metetra
0 .034 .135 r
.66262 .42409 .66717 .42942 .67662 .42597 .6721 .42087 Metetra
0 .033 .134 r
.6721 .42087 .67662 .42597 .6861 .42256 .68161 .41755 Metetra
0 .033 .133 r
.68161 .41755 .6861 .42256 .69565 .41972 .69118 .41477 Metetra
0 .033 .134 r
.69118 .41477 .69565 .41972 .70521 .41661 .70076 .41159 Metetra
0 .032 .133 r
.70076 .41159 .70521 .41661 .71481 .41363 .71037 .4083 Metetra
0 .032 .132 r
.71037 .4083 .71481 .41363 .72442 .41033 .72001 .40504 Metetra
0 .031 .131 r
.72001 .40504 .72442 .41033 .73407 .40709 .72968 .40164 Metetra
0 .031 .131 r
.72968 .40164 .73407 .40709 .74378 .40419 .73941 .39868 Metetra
0 .031 .131 r
.73941 .39868 .74378 .40419 .75351 .40111 .74915 .3954 Metetra
0 .031 .131 r
.74915 .3954 .75351 .40111 .76328 .39821 .75893 .39226 Metetra
0 .03 .131 r
.75893 .39226 .76328 .39821 .77304 .39465 .76871 .38866 Metetra
0 .029 .129 r
.76871 .38866 .77304 .39465 .78285 .39127 .77854 .38525 Metetra
0 .028 .128 r
.77854 .38525 .78285 .39127 .79267 .38771 .7884 .3819 Metetra
0 .028 .127 r
.7884 .3819 .79267 .38771 .80255 .3844 .79832 .37873 Metetra
0 .027 .127 r
.79832 .37873 .80255 .3844 .81246 .38107 .80827 .37562 Metetra
0 .027 .127 r
.80827 .37562 .81246 .38107 .82242 .37796 .81826 .37245 Metetra
0 .027 .127 r
.81826 .37245 .82242 .37796 .83242 .37488 .82829 .36935 Metetra
0 .028 .127 r
.82829 .36935 .83242 .37488 .84246 .37174 .83833 .36598 Metetra
0 .027 .127 r
.83833 .36598 .84246 .37174 .85251 .36849 .8484 .36259 Metetra
0 .027 .126 r
.8484 .36259 .85251 .36849 .86261 .36523 .85849 .35907 Metetra
0 .026 .125 r
.85849 .35907 .86261 .36523 .87272 .36188 .86864 .35573 Metetra
0 .026 .125 r
.86864 .35573 .87272 .36188 .88287 .35845 .8788 .35227 Metetra
0 .025 .124 r
.8788 .35227 .88287 .35845 .89306 .35509 .88903 .349 Metetra
0 .025 .124 r
.88903 .349 .89306 .35509 .90329 .35176 .8993 .34575 Metetra
0 .025 .124 r
.8993 .34575 .90329 .35176 .91355 .34841 .90961 .34256 Metetra
0 .025 .124 r
.31894 .52426 .32425 .52909 .33264 .52633 .32735 .52142 Metetra
0 .025 .124 r
.32735 .52142 .33264 .52633 .34105 .52364 .33577 .51871 Metetra
0 .025 .124 r
.33577 .51871 .34105 .52364 .34948 .52097 .34422 .51598 Metetra
0 .026 .124 r
.34422 .51598 .34948 .52097 .35793 .51847 .35269 .51347 Metetra
0 .026 .125 r
.35269 .51347 .35793 .51847 .36641 .51586 .36119 .5108 Metetra
0 .027 .126 r
.36119 .5108 .36641 .51586 .37491 .51342 .36971 .50842 Metetra
0 .027 .127 r
.36971 .50842 .37491 .51342 .38345 .51087 .37826 .50587 Metetra
0 .028 .128 r
.37826 .50587 .38345 .51087 .39201 .50829 .38684 .50336 Metetra
0 .028 .128 r
.38684 .50336 .39201 .50829 .40062 .50547 .39545 .50052 Metetra
0 .028 .128 r
.39545 .50052 .40062 .50547 .40924 .50272 .4041 .49783 Metetra
0 .028 .128 r
.4041 .49783 .40924 .50272 .4179 .49991 .41277 .49491 Metetra
0 .028 .127 r
.41277 .49491 .4179 .49991 .42658 .49717 .42147 .49212 Metetra
0 .028 .128 r
.42147 .49212 .42658 .49717 .43528 .49459 .4302 .4894 Metetra
0 .029 .129 r
.4302 .4894 .43528 .49459 .44401 .49206 .43894 .48692 Metetra
0 .03 .13 r
.43894 .48692 .44401 .49206 .45277 .48972 .44772 .48453 Metetra
0 .031 .131 r
.44772 .48453 .45277 .48972 .46157 .48694 .45653 .48191 Metetra
0 .032 .132 r
.45653 .48191 .46157 .48694 .47039 .48432 .46537 .47937 Metetra
0 .032 .132 r
.46537 .47937 .47039 .48432 .47924 .48137 .47424 .47645 Metetra
0 .032 .133 r
.47424 .47645 .47924 .48137 .48812 .47886 .48314 .4739 Metetra
0 .033 .134 r
.48314 .4739 .48812 .47886 .49703 .47619 .49207 .47106 Metetra
0 .034 .135 r
.49207 .47106 .49703 .47619 .50597 .47357 .50103 .46861 Metetra
0 .034 .136 r
.50103 .46861 .50597 .47357 .51495 .47085 .51002 .4659 Metetra
0 .034 .135 r
.51002 .4659 .51495 .47085 .52395 .46773 .51904 .46288 Metetra
0 .034 .136 r
.51904 .46288 .52395 .46773 .53298 .46515 .5281 .46015 Metetra
0 .035 .136 r
.5281 .46015 .53298 .46515 .54204 .46245 .53718 .45722 Metetra
0 .036 .137 r
.53718 .45722 .54204 .46245 .55113 .45974 .54629 .45476 Metetra
0 .037 .138 r
.54629 .45476 .55113 .45974 .56026 .45697 .55544 .452 Metetra
0 .036 .138 r
.55544 .452 .56026 .45697 .56941 .45383 .56461 .44875 Metetra
0 .036 .138 r
.56461 .44875 .56941 .45383 .57859 .45124 .57382 .4462 Metetra
0 .038 .139 r
.57382 .4462 .57859 .45124 .58782 .44869 .58306 .4436 Metetra
0 .038 .139 r
.58306 .4436 .58782 .44869 .59705 .44533 .59232 .4403 Metetra
0 .037 .139 r
.59232 .4403 .59705 .44533 .60633 .44238 .60161 .43734 Metetra
0 .038 .139 r
.60161 .43734 .60633 .44238 .61564 .43984 .61095 .4347 Metetra
0 .038 .139 r
.61095 .4347 .61564 .43984 .62497 .4365 .6203 .43135 Metetra
0 .036 .138 r
.6203 .43135 .62497 .4365 .63433 .43317 .62968 .42797 Metetra
0 .036 .138 r
.62968 .42797 .63433 .43317 .64373 .43041 .63911 .42529 Metetra
0 .037 .138 r
.63911 .42529 .64373 .43041 .65316 .42729 .64856 .42211 Metetra
0 .036 .137 r
.64856 .42211 .65316 .42729 .66262 .42409 .65802 .41862 Metetra
0 .035 .136 r
.65802 .41862 .66262 .42409 .6721 .42087 .66754 .4156 Metetra
0 .034 .135 r
.66754 .4156 .6721 .42087 .68161 .41755 .67708 .4124 Metetra
0 .034 .135 r
.67708 .4124 .68161 .41755 .69118 .41477 .68667 .40949 Metetra
0 .034 .136 r
.68667 .40949 .69118 .41477 .70076 .41159 .69627 .40626 Metetra
0 .034 .135 r
.69627 .40626 .70076 .41159 .71037 .4083 .7059 .40275 Metetra
0 .033 .134 r
.7059 .40275 .71037 .4083 .72001 .40504 .71557 .39962 Metetra
0 .032 .133 r
.71557 .39962 .72001 .40504 .72968 .40164 .72526 .39624 Metetra
0 .032 .132 r
.72526 .39624 .72968 .40164 .73941 .39868 .73501 .39321 Metetra
0 .032 .132 r
.73501 .39321 .73941 .39868 .74915 .3954 .74477 .38981 Metetra
0 .031 .131 r
.74477 .38981 .74915 .3954 .75893 .39226 .75456 .38646 Metetra
0 .03 .13 r
.75456 .38646 .75893 .39226 .76871 .38866 .76437 .38288 Metetra
0 .029 .129 r
.76437 .38288 .76871 .38866 .77854 .38525 .77422 .3794 Metetra
0 .028 .128 r
.77422 .3794 .77854 .38525 .7884 .3819 .78412 .37615 Metetra
0 .028 .127 r
.78412 .37615 .7884 .3819 .79832 .37873 .79406 .37298 Metetra
0 .028 .128 r
.79406 .37298 .79832 .37873 .80827 .37562 .80405 .36996 Metetra
0 .028 .128 r
.80405 .36996 .80827 .37562 .81826 .37245 .81405 .36669 Metetra
0 .028 .128 r
.81405 .36669 .81826 .37245 .82829 .36935 .8241 .36355 Metetra
0 .028 .128 r
.8241 .36355 .82829 .36935 .83833 .36598 .83416 .36009 Metetra
0 .027 .127 r
.83416 .36009 .83833 .36598 .8484 .36259 .84425 .35665 Metetra
0 .027 .126 r
.84425 .35665 .8484 .36259 .85849 .35907 .85436 .35304 Metetra
0 .026 .125 r
.85436 .35304 .85849 .35907 .86864 .35573 .86454 .34972 Metetra
0 .025 .124 r
.86454 .34972 .86864 .35573 .8788 .35227 .87474 .34625 Metetra
0 .025 .124 r
.87474 .34625 .8788 .35227 .88903 .349 .88499 .343 Metetra
0 .025 .124 r
.88499 .343 .88903 .349 .8993 .34575 .89528 .33973 Metetra
0 .025 .124 r
.89528 .33973 .8993 .34575 .90961 .34256 .90563 .33658 Metetra
0 .026 .125 r
.31359 .51957 .31894 .52426 .32735 .52142 .32201 .51671 Metetra
0 .026 .125 r
.32201 .51671 .32735 .52142 .33577 .51871 .33046 .51396 Metetra
0 .026 .124 r
.33046 .51396 .33577 .51871 .34422 .51598 .33893 .51108 Metetra
0 .026 .124 r
.33893 .51108 .34422 .51598 .35269 .51347 .34742 .50842 Metetra
0 .026 .125 r
.34742 .50842 .35269 .51347 .36119 .5108 .35595 .50556 Metetra
0 .026 .125 r
.35595 .50556 .36119 .5108 .36971 .50842 .36448 .50314 Metetra
0 .027 .126 r
.36448 .50314 .36971 .50842 .37826 .50587 .37305 .50059 Metetra
0 .028 .128 r
.37305 .50059 .37826 .50587 .38684 .50336 .38163 .49823 Metetra
0 .029 .128 r
.38163 .49823 .38684 .50336 .39545 .50052 .39026 .49556 Metetra
0 .029 .129 r
.39026 .49556 .39545 .50052 .4041 .49783 .39891 .49311 Metetra
0 .029 .129 r
.39891 .49311 .4041 .49783 .41277 .49491 .40761 .49015 Metetra
0 .029 .128 r
.40761 .49015 .41277 .49491 .42147 .49212 .41633 .48734 Metetra
0 .029 .128 r
.41633 .48734 .42147 .49212 .4302 .4894 .42508 .48441 Metetra
0 .029 .129 r
.42508 .48441 .4302 .4894 .43894 .48692 .43384 .48179 Metetra
0 .03 .13 r
.43384 .48179 .43894 .48692 .44772 .48453 .44264 .47916 Metetra
0 .031 .131 r
.44264 .47916 .44772 .48453 .45653 .48191 .45147 .47656 Metetra
0 .032 .132 r
.45147 .47656 .45653 .48191 .46537 .47937 .46032 .47403 Metetra
0 .032 .133 r
.46032 .47403 .46537 .47937 .47424 .47645 .46921 .47126 Metetra
0 .033 .134 r
.46921 .47126 .47424 .47645 .48314 .4739 .47813 .46876 Metetra
0 .033 .134 r
.47813 .46876 .48314 .4739 .49207 .47106 .48708 .46592 Metetra
0 .035 .136 r
.48708 .46592 .49207 .47106 .50103 .46861 .49606 .46374 Metetra
0 .036 .137 r
.49606 .46374 .50103 .46861 .51002 .4659 .50507 .46115 Metetra
0 .036 .138 r
.50507 .46115 .51002 .4659 .51904 .46288 .51411 .45841 Metetra
0 .037 .138 r
.51411 .45841 .51904 .46288 .5281 .46015 .52318 .45554 Metetra
0 .037 .138 r
.52318 .45554 .5281 .46015 .53718 .45722 .53229 .45239 Metetra
0 .037 .139 r
.53229 .45239 .53718 .45722 .54629 .45476 .54142 .45006 Metetra
0 .039 .14 r
.54142 .45006 .54629 .45476 .55544 .452 .55059 .44725 Metetra
0 .038 .14 r
.55059 .44725 .55544 .452 .56461 .44875 .55978 .44401 Metetra
0 .038 .14 r
.55978 .44401 .56461 .44875 .57382 .4462 .56901 .44133 Metetra
0 .039 .141 r
.56901 .44133 .57382 .4462 .58306 .4436 .57827 .43853 Metetra
0 .039 .141 r
.57827 .43853 .58306 .4436 .59232 .4403 .58755 .43543 Metetra
0 .039 .141 r
.58755 .43543 .59232 .4403 .60161 .43734 .59687 .43247 Metetra
0 .039 .141 r
.59687 .43247 .60161 .43734 .61095 .4347 .60623 .42958 Metetra
0 .039 .141 r
.60623 .42958 .61095 .4347 .6203 .43135 .61561 .42637 Metetra
0 .038 .14 r
.61561 .42637 .6203 .43135 .62968 .42797 .62501 .42311 Metetra
0 .038 .14 r
.62501 .42311 .62968 .42797 .63911 .42529 .63447 .42038 Metetra
0 .039 .14 r
.63447 .42038 .63911 .42529 .64856 .42211 .64394 .41721 Metetra
0 .037 .139 r
.64394 .41721 .64856 .42211 .65802 .41862 .65342 .41356 Metetra
0 .037 .138 r
.65342 .41356 .65802 .41862 .66754 .4156 .66297 .41072 Metetra
0 .037 .138 r
.66297 .41072 .66754 .4156 .67708 .4124 .67254 .40764 Metetra
0 .036 .138 r
.67254 .40764 .67708 .4124 .68667 .40949 .68214 .4044 Metetra
0 .036 .137 r
.68214 .4044 .68667 .40949 .69627 .40626 .69176 .401 Metetra
0 .035 .136 r
.69176 .401 .69627 .40626 .7059 .40275 .70139 .39718 Metetra
0 .033 .134 r
.70139 .39718 .7059 .40275 .71557 .39962 .71109 .39402 Metetra
0 .033 .134 r
.71109 .39402 .71557 .39962 .72526 .39624 .7208 .39056 Metetra
0 .032 .133 r
.7208 .39056 .72526 .39624 .73501 .39321 .73056 .38734 Metetra
0 .032 .132 r
.73056 .38734 .73501 .39321 .74477 .38981 .74034 .38388 Metetra
0 .031 .131 r
.74034 .38388 .74477 .38981 .75456 .38646 .75015 .38048 Metetra
0 .03 .13 r
.75015 .38048 .75456 .38646 .76437 .38288 .76 .3771 Metetra
0 .029 .129 r
.76 .3771 .76437 .38288 .77422 .3794 .76988 .37372 Metetra
0 .029 .128 r
.76988 .37372 .77422 .3794 .78412 .37615 .77982 .37066 Metetra
0 .029 .128 r
.77982 .37066 .78412 .37615 .79406 .37298 .78979 .36749 Metetra
0 .029 .129 r
.78979 .36749 .79406 .37298 .80405 .36996 .79981 .36446 Metetra
0 .029 .129 r
.79981 .36446 .80405 .36996 .81405 .36669 .80982 .36091 Metetra
0 .029 .128 r
.80982 .36091 .81405 .36669 .8241 .36355 .81987 .35756 Metetra
0 .028 .128 r
.81987 .35756 .8241 .36355 .83416 .36009 .82994 .35389 Metetra
0 .027 .126 r
.82994 .35389 .83416 .36009 .84425 .35665 .84006 .35041 Metetra
0 .026 .125 r
.84006 .35041 .84425 .35665 .85436 .35304 .85019 .34681 Metetra
0 .026 .125 r
.85019 .34681 .85436 .35304 .86454 .34972 .86041 .34365 Metetra
0 .026 .124 r
.86041 .34365 .86454 .34972 .87474 .34625 .87065 .3403 Metetra
0 .025 .124 r
.87065 .3403 .87474 .34625 .88499 .343 .88095 .33717 Metetra
0 .026 .125 r
.88095 .33717 .88499 .343 .89528 .33973 .89127 .33391 Metetra
0 .026 .125 r
.89127 .33391 .89528 .33973 .90563 .33658 .90165 .33075 Metetra
0 .026 .125 r
.30823 .51451 .31359 .51957 .32201 .51671 .31666 .51166 Metetra
0 .026 .125 r
.31666 .51166 .32201 .51671 .33046 .51396 .32512 .50898 Metetra
0 .026 .125 r
.32512 .50898 .33046 .51396 .33893 .51108 .33361 .50615 Metetra
0 .026 .125 r
.33361 .50615 .33893 .51108 .34742 .50842 .34211 .50351 Metetra
0 .026 .125 r
.34211 .50351 .34742 .50842 .35595 .50556 .35066 .50063 Metetra
0 .026 .125 r
.35066 .50063 .35595 .50556 .36448 .50314 .35921 .49817 Metetra
0 .027 .126 r
.35921 .49817 .36448 .50314 .37305 .50059 .36779 .49551 Metetra
0 .028 .127 r
.36779 .49551 .37305 .50059 .38163 .49823 .3764 .49306 Metetra
0 .029 .128 r
.3764 .49306 .38163 .49823 .39026 .49556 .38505 .49034 Metetra
0 .029 .129 r
.38505 .49034 .39026 .49556 .39891 .49311 .39371 .48791 Metetra
0 .03 .13 r
.39371 .48791 .39891 .49311 .40761 .49015 .40242 .48498 Metetra
0 .029 .129 r
.40242 .48498 .40761 .49015 .41633 .48734 .41116 .48226 Metetra
0 .029 .129 r
.41116 .48226 .41633 .48734 .42508 .48441 .41992 .47935 Metetra
0 .03 .13 r
.41992 .47935 .42508 .48441 .43384 .48179 .42871 .47681 Metetra
0 .03 .13 r
.42871 .47681 .43384 .48179 .44264 .47916 .43753 .47409 Metetra
0 .031 .131 r
.43753 .47409 .44264 .47916 .45147 .47656 .44637 .47161 Metetra
0 .032 .133 r
.44637 .47161 .45147 .47656 .46032 .47403 .45524 .46903 Metetra
0 .033 .134 r
.45524 .46903 .46032 .47403 .46921 .47126 .46415 .46631 Metetra
0 .033 .134 r
.46415 .46631 .46921 .47126 .47813 .46876 .47309 .46359 Metetra
0 .034 .135 r
.47309 .46359 .47813 .46876 .48708 .46592 .48206 .46064 Metetra
0 .035 .136 r
.48206 .46064 .48708 .46592 .49606 .46374 .49105 .45837 Metetra
0 .037 .138 r
.49105 .45837 .49606 .46374 .50507 .46115 .50008 .45578 Metetra
0 .038 .14 r
.50008 .45578 .50507 .46115 .51411 .45841 .50914 .45337 Metetra
0 .039 .141 r
.50914 .45337 .51411 .45841 .52318 .45554 .51824 .45046 Metetra
0 .038 .14 r
.51824 .45046 .52318 .45554 .53229 .45239 .52736 .4474 Metetra
0 .039 .141 r
.52736 .4474 .53229 .45239 .54142 .45006 .53652 .4451 Metetra
0 .041 .143 r
.53652 .4451 .54142 .45006 .55059 .44725 .5457 .44238 Metetra
0 .041 .143 r
.5457 .44238 .55059 .44725 .55978 .44401 .55492 .43956 Metetra
0 .041 .143 r
.55492 .43956 .55978 .44401 .56901 .44133 .56417 .43669 Metetra
0 .042 .144 r
.56417 .43669 .56901 .44133 .57827 .43853 .57345 .43363 Metetra
0 .042 .144 r
.57345 .43363 .57827 .43853 .58755 .43543 .58277 .43096 Metetra
0 .042 .144 r
.58277 .43096 .58755 .43543 .59687 .43247 .59211 .42798 Metetra
0 .042 .144 r
.59211 .42798 .59687 .43247 .60623 .42958 .60148 .42463 Metetra
0 .042 .144 r
.60148 .42463 .60623 .42958 .61561 .42637 .61089 .42164 Metetra
0 .041 .143 r
.61089 .42164 .61561 .42637 .62501 .42311 .62032 .41854 Metetra
0 .041 .143 r
.62032 .41854 .62501 .42311 .63447 .42038 .62979 .41536 Metetra
0 .041 .143 r
.62979 .41536 .63447 .42038 .64394 .41721 .63928 .41204 Metetra
0 .039 .141 r
.63928 .41204 .64394 .41721 .65342 .41356 .64879 .40833 Metetra
0 .038 .14 r
.64879 .40833 .65342 .41356 .66297 .41072 .65835 .40537 Metetra
0 .039 .141 r
.65835 .40537 .66297 .41072 .67254 .40764 .66795 .40229 Metetra
0 .038 .14 r
.66795 .40229 .67254 .40764 .68214 .4044 .67755 .39868 Metetra
0 .037 .138 r
.67755 .39868 .68214 .4044 .69176 .401 .6872 .39523 Metetra
0 .035 .136 r
.6872 .39523 .69176 .401 .70139 .39718 .69685 .39147 Metetra
0 .034 .135 r
.69685 .39147 .70139 .39718 .71109 .39402 .70658 .3884 Metetra
0 .033 .134 r
.70658 .3884 .71109 .39402 .7208 .39056 .71633 .38512 Metetra
0 .033 .134 r
.71633 .38512 .7208 .39056 .73056 .38734 .72611 .38182 Metetra
0 .032 .133 r
.72611 .38182 .73056 .38734 .74034 .38388 .73591 .37837 Metetra
0 .031 .131 r
.73591 .37837 .74034 .38388 .75015 .38048 .74574 .3748 Metetra
0 .03 .13 r
.74574 .3748 .75015 .38048 .76 .3771 .75562 .37147 Metetra
0 .03 .13 r
.75562 .37147 .76 .3771 .76988 .37372 .76552 .36799 Metetra
0 .029 .129 r
.76552 .36799 .76988 .37372 .77982 .37066 .77548 .36486 Metetra
0 .029 .129 r
.77548 .36486 .77982 .37066 .78979 .36749 .78547 .36156 Metetra
0 .03 .13 r
.78547 .36156 .78979 .36749 .79981 .36446 .7955 .35846 Metetra
0 .029 .129 r
.7955 .35846 .79981 .36446 .80982 .36091 .80553 .35484 Metetra
0 .029 .128 r
.80553 .35484 .80982 .36091 .81987 .35756 .81562 .35151 Metetra
0 .028 .127 r
.81562 .35151 .81987 .35756 .82994 .35389 .82572 .3479 Metetra
0 .027 .126 r
.82572 .3479 .82994 .35389 .84006 .35041 .83587 .3445 Metetra
0 .026 .125 r
.83587 .3445 .84006 .35041 .85019 .34681 .84604 .3409 Metetra
0 .026 .125 r
.84604 .3409 .85019 .34681 .86041 .34365 .85628 .33773 Metetra
0 .026 .125 r
.85628 .33773 .86041 .34365 .87065 .3403 .86654 .33432 Metetra
0 .026 .125 r
.86654 .33432 .87065 .3403 .88095 .33717 .87686 .33109 Metetra
0 .026 .125 r
.87686 .33109 .88095 .33717 .89127 .33391 .8872 .32772 Metetra
0 .026 .125 r
.8872 .32772 .89127 .33391 .90165 .33075 .8976 .32451 Metetra
0 .026 .125 r
.30284 .50935 .30823 .51451 .31666 .51166 .31128 .50661 Metetra
0 .026 .125 r
.31128 .50661 .31666 .51166 .32512 .50898 .31974 .50406 Metetra
0 .026 .125 r
.31974 .50406 .32512 .50898 .33361 .50615 .32824 .50132 Metetra
0 .026 .126 r
.32824 .50132 .33361 .50615 .34211 .50351 .33676 .49868 Metetra
0 .026 .126 r
.33676 .49868 .34211 .50351 .35066 .50063 .34533 .49574 Metetra
0 .027 .126 r
.34533 .49574 .35066 .50063 .35921 .49817 .3539 .49313 Metetra
0 .027 .126 r
.3539 .49313 .35921 .49817 .36779 .49551 .36252 .49031 Metetra
0 .028 .127 r
.36252 .49031 .36779 .49551 .3764 .49306 .37114 .48771 Metetra
0 .028 .128 r
.37114 .48771 .3764 .49306 .38505 .49034 .37981 .48498 Metetra
0 .029 .129 r
.37981 .48498 .38505 .49034 .39371 .48791 .38849 .48262 Metetra
0 .03 .13 r
.38849 .48262 .39371 .48791 .40242 .48498 .39721 .47986 Metetra
0 .03 .13 r
.39721 .47986 .40242 .48498 .41116 .48226 .40595 .47733 Metetra
0 .03 .13 r
.40595 .47733 .41116 .48226 .41992 .47935 .41473 .4745 Metetra
0 .031 .131 r
.41473 .4745 .41992 .47935 .42871 .47681 .42353 .47197 Metetra
0 .031 .132 r
.42353 .47197 .42871 .47681 .43753 .47409 .43238 .46908 Metetra
0 .032 .132 r
.43238 .46908 .43753 .47409 .44637 .47161 .44124 .46653 Metetra
0 .033 .134 r
.44124 .46653 .44637 .47161 .45524 .46903 .45014 .46377 Metetra
0 .033 .134 r
.45014 .46377 .45524 .46903 .46415 .46631 .45906 .46104 Metetra
0 .034 .135 r
.45906 .46104 .46415 .46631 .47309 .46359 .46802 .45818 Metetra
0 .034 .135 r
.46802 .45818 .47309 .46359 .48206 .46064 .47701 .45534 Metetra
0 .035 .136 r
.47701 .45534 .48206 .46064 .49105 .45837 .48602 .45302 Metetra
0 .037 .139 r
.48602 .45302 .49105 .45837 .50008 .45578 .49507 .45058 Metetra
0 .039 .141 r
.49507 .45058 .50008 .45578 .50914 .45337 .50414 .44855 Metetra
0 .041 .143 r
.50414 .44855 .50914 .45337 .51824 .45046 .51326 .44578 Metetra
0 .041 .143 r
.51326 .44578 .51824 .45046 .52736 .4474 .5224 .44301 Metetra
0 .042 .144 r
.5224 .44301 .52736 .4474 .53652 .4451 .53158 .44055 Metetra
0 .044 .146 r
.53158 .44055 .53652 .4451 .5457 .44238 .54079 .43787 Metetra
0 .045 .147 r
.54079 .43787 .5457 .44238 .55492 .43956 .55004 .43542 Metetra
0 .046 .148 r
.55004 .43542 .55492 .43956 .56417 .43669 .55931 .43233 Metetra
0 .045 .148 r
.55931 .43233 .56417 .43669 .57345 .43363 .56861 .42908 Metetra
0 .046 .148 r
.56861 .42908 .57345 .43363 .58277 .43096 .57795 .42665 Metetra
0 .047 .149 r
.57795 .42665 .58277 .43096 .59211 .42798 .58732 .42364 Metetra
0 .046 .148 r
.58732 .42364 .59211 .42798 .60148 .42463 .59671 .42001 Metetra
0 .045 .148 r
.59671 .42001 .60148 .42463 .61089 .42164 .60614 .41721 Metetra
0 .046 .148 r
.60614 .41721 .61089 .42164 .62032 .41854 .61561 .41427 Metetra
0 .045 .147 r
.61561 .41427 .62032 .41854 .62979 .41536 .62509 .41068 Metetra
0 .044 .146 r
.62509 .41068 .62979 .41536 .63928 .41204 .6346 .40729 Metetra
0 .042 .144 r
.6346 .40729 .63928 .41204 .64879 .40833 .64414 .40371 Metetra
0 .041 .143 r
.64414 .40371 .64879 .40833 .65835 .40537 .65372 .40045 Metetra
0 .041 .143 r
.65372 .40045 .65835 .40537 .66795 .40229 .66334 .39715 Metetra
0 .039 .141 r
.66334 .39715 .66795 .40229 .67755 .39868 .67295 .39313 Metetra
0 .037 .139 r
.67295 .39313 .67755 .39868 .6872 .39523 .6826 .38948 Metetra
0 .035 .136 r
.6826 .38948 .6872 .39523 .69685 .39147 .69229 .38574 Metetra
0 .034 .135 r
.69229 .38574 .69685 .39147 .70658 .3884 .70203 .38253 Metetra
0 .034 .135 r
.70203 .38253 .70658 .3884 .71633 .38512 .71181 .37934 Metetra
0 .033 .134 r
.71181 .37934 .71633 .38512 .72611 .38182 .72161 .37601 Metetra
0 .033 .134 r
.72161 .37601 .72611 .38182 .73591 .37837 .73145 .3727 Metetra
0 .032 .132 r
.73145 .3727 .73591 .37837 .74574 .3748 .74131 .36918 Metetra
0 .031 .132 r
.74131 .36918 .74574 .3748 .75562 .37147 .75122 .36598 Metetra
0 .031 .131 r
.75122 .36598 .75562 .37147 .76552 .36799 .76115 .36246 Metetra
0 .03 .13 r
.76115 .36246 .76552 .36799 .77548 .36486 .77113 .35921 Metetra
0 .03 .13 r
.77113 .35921 .77548 .36486 .78547 .36156 .78112 .35568 Metetra
0 .03 .13 r
.78112 .35568 .78547 .36156 .7955 .35846 .79116 .35235 Metetra
0 .029 .129 r
.79116 .35235 .7955 .35846 .80553 .35484 .80121 .34863 Metetra
0 .028 .128 r
.80121 .34863 .80553 .35484 .81562 .35151 .81132 .34527 Metetra
0 .028 .127 r
.81132 .34527 .81562 .35151 .82572 .3479 .82146 .34178 Metetra
0 .027 .126 r
.82146 .34178 .82572 .3479 .83587 .3445 .83165 .3385 Metetra
0 .027 .126 r
.83165 .3385 .83587 .3445 .84604 .3409 .84186 .33502 Metetra
0 .026 .125 r
.84186 .33502 .84604 .3409 .85628 .33773 .85214 .33188 Metetra
0 .026 .126 r
.85214 .33188 .85628 .33773 .86654 .33432 .86242 .32843 Metetra
0 .026 .125 r
.86242 .32843 .86654 .33432 .87686 .33109 .87275 .32507 Metetra
0 .026 .125 r
.87275 .32507 .87686 .33109 .8872 .32772 .8831 .32152 Metetra
0 .026 .125 r
.8831 .32152 .8872 .32772 .8976 .32451 .89351 .31816 Metetra
0 .026 .125 r
.29739 .5045 .30284 .50935 .31128 .50661 .30587 .50156 Metetra
0 .026 .125 r
.30587 .50156 .31128 .50661 .31974 .50406 .31435 .49888 Metetra
0 .026 .126 r
.31435 .49888 .31974 .50406 .32824 .50132 .32287 .49606 Metetra
0 .027 .126 r
.32287 .49606 .32824 .50132 .33676 .49868 .33141 .4934 Metetra
0 .027 .126 r
.33141 .4934 .33676 .49868 .34533 .49574 .33999 .49053 Metetra
0 .027 .126 r
.33999 .49053 .34533 .49574 .3539 .49313 .34857 .48806 Metetra
0 .027 .127 r
.34857 .48806 .3539 .49313 .36252 .49031 .35719 .48533 Metetra
0 .028 .127 r
.35719 .48533 .36252 .49031 .37114 .48771 .36583 .4828 Metetra
0 .028 .128 r
.36583 .4828 .37114 .48771 .37981 .48498 .37452 .48006 Metetra
0 .029 .129 r
.37452 .48006 .37981 .48498 .38849 .48262 .38321 .47759 Metetra
0 .03 .13 r
.38321 .47759 .38849 .48262 .39721 .47986 .39196 .47463 Metetra
0 .03 .13 r
.39196 .47463 .39721 .47986 .40595 .47733 .40073 .47196 Metetra
0 .03 .131 r
.40073 .47196 .40595 .47733 .41473 .4745 .40953 .46907 Metetra
0 .031 .131 r
.40953 .46907 .41473 .4745 .42353 .47197 .41835 .46655 Metetra
0 .032 .132 r
.41835 .46655 .42353 .47197 .43238 .46908 .4272 .4637 Metetra
0 .032 .133 r
.4272 .4637 .43238 .46908 .44124 .46653 .43608 .46143 Metetra
0 .034 .135 r
.43608 .46143 .44124 .46653 .45014 .46377 .44499 .45884 Metetra
0 .035 .136 r
.44499 .45884 .45014 .46377 .45906 .46104 .45393 .45638 Metetra
0 .035 .136 r
.45393 .45638 .45906 .46104 .46802 .45818 .46291 .45343 Metetra
0 .035 .136 r
.46291 .45343 .46802 .45818 .47701 .45534 .47192 .45056 Metetra
0 .036 .137 r
.47192 .45056 .47701 .45534 .48602 .45302 .48095 .4479 Metetra
0 .038 .139 r
.48095 .4479 .48602 .45302 .49507 .45058 .49002 .44527 Metetra
0 .04 .142 r
.49002 .44527 .49507 .45058 .50414 .44855 .49912 .44317 Metetra
0 .042 .144 r
.49912 .44317 .50414 .44855 .51326 .44578 .50825 .44041 Metetra
0 .043 .145 r
.50825 .44041 .51326 .44578 .5224 .44301 .51742 .43794 Metetra
0 .045 .147 r
.51742 .43794 .5224 .44301 .53158 .44055 .52661 .43524 Metetra
0 .046 .149 r
.52661 .43524 .53158 .44055 .54079 .43787 .53585 .43268 Metetra
0 .048 .151 r
.53585 .43268 .54079 .43787 .55004 .43542 .54511 .43066 Metetra
0 .05 .152 r
.54511 .43066 .55004 .43542 .55931 .43233 .55441 .42756 Metetra
0 .049 .152 r
.55441 .42756 .55931 .43233 .56861 .42908 .56373 .42435 Metetra
0 .05 .153 r
.56373 .42435 .56861 .42908 .57795 .42665 .5731 .42202 Metetra
0 .051 .154 r
.5731 .42202 .57795 .42665 .58732 .42364 .58249 .41898 Metetra
0 .05 .153 r
.58249 .41898 .58732 .42364 .59671 .42001 .5919 .41523 Metetra
0 .049 .152 r
.5919 .41523 .59671 .42001 .60614 .41721 .60136 .41237 Metetra
0 .05 .152 r
.60136 .41237 .60614 .41721 .61561 .41427 .61085 .40939 Metetra
0 .048 .151 r
.61085 .40939 .61561 .41427 .62509 .41068 .62034 .40531 Metetra
0 .046 .149 r
.62034 .40531 .62509 .41068 .6346 .40729 .62987 .40177 Metetra
0 .045 .147 r
.62987 .40177 .6346 .40729 .64414 .40371 .63944 .3984 Metetra
0 .043 .145 r
.63944 .3984 .64414 .40371 .65372 .40045 .64903 .3948 Metetra
0 .042 .144 r
.64903 .3948 .65372 .40045 .66334 .39715 .65867 .39145 Metetra
0 .04 .142 r
.65867 .39145 .66334 .39715 .67295 .39313 .6683 .38744 Metetra
0 .038 .139 r
.6683 .38744 .67295 .39313 .6826 .38948 .678 .38397 Metetra
0 .036 .137 r
.678 .38397 .6826 .38948 .69229 .38574 .68772 .38054 Metetra
0 .035 .136 r
.68772 .38054 .69229 .38574 .70203 .38253 .69749 .37734 Metetra
0 .035 .136 r
.69749 .37734 .70203 .38253 .71181 .37934 .7073 .37419 Metetra
0 .035 .136 r
.7073 .37419 .71181 .37934 .72161 .37601 .71711 .37054 Metetra
0 .034 .135 r
.71711 .37054 .72161 .37601 .73145 .3727 .72696 .36701 Metetra
0 .032 .133 r
.72696 .36701 .73145 .3727 .74131 .36918 .73682 .36317 Metetra
0 .032 .132 r
.73682 .36317 .74131 .36918 .75122 .36598 .74676 .35989 Metetra
0 .031 .131 r
.74676 .35989 .75122 .36598 .76115 .36246 .7567 .35632 Metetra
0 .03 .131 r
.7567 .35632 .76115 .36246 .77113 .35921 .76671 .35311 Metetra
0 .03 .13 r
.76671 .35311 .77113 .35921 .78112 .35568 .77674 .34967 Metetra
0 .03 .13 r
.77674 .34967 .78112 .35568 .79116 .35235 .78682 .34651 Metetra
0 .029 .129 r
.78682 .34651 .79116 .35235 .80121 .34863 .7969 .34287 Metetra
0 .028 .128 r
.7969 .34287 .80121 .34863 .81132 .34527 .80704 .33948 Metetra
0 .028 .127 r
.80704 .33948 .81132 .34527 .82146 .34178 .81719 .33587 Metetra
0 .027 .127 r
.81719 .33587 .82146 .34178 .83165 .3385 .8274 .33246 Metetra
0 .027 .126 r
.8274 .33246 .83165 .3385 .84186 .33502 .83762 .3288 Metetra
0 .027 .126 r
.83762 .3288 .84186 .33502 .85214 .33188 .84791 .32555 Metetra
0 .027 .126 r
.84791 .32555 .85214 .33188 .86242 .32843 .85823 .32208 Metetra
0 .026 .126 r
.85823 .32208 .86242 .32843 .87275 .32507 .86859 .31878 Metetra
0 .026 .125 r
.86859 .31878 .87275 .32507 .8831 .32152 .87898 .31532 Metetra
0 .026 .125 r
.87898 .31532 .8831 .32152 .89351 .31816 .88944 .31213 Metetra
0 .027 .126 r
.29193 .49948 .29739 .5045 .30587 .50156 .30042 .4965 Metetra
0 .026 .125 r
.30042 .4965 .30587 .50156 .31435 .49888 .30892 .49381 Metetra
0 .026 .125 r
.30892 .49381 .31435 .49888 .32287 .49606 .31746 .49097 Metetra
0 .026 .126 r
.31746 .49097 .32287 .49606 .33141 .4934 .32601 .48827 Metetra
0 .026 .126 r
.32601 .48827 .33141 .4934 .33999 .49053 .3346 .48541 Metetra
0 .027 .126 r
.3346 .48541 .33999 .49053 .34857 .48806 .3432 .48291 Metetra
0 .028 .127 r
.3432 .48291 .34857 .48806 .35719 .48533 .35184 .48018 Metetra
0 .028 .128 r
.35184 .48018 .35719 .48533 .36583 .4828 .3605 .47762 Metetra
0 .029 .129 r
.3605 .47762 .36583 .4828 .37452 .48006 .3692 .4749 Metetra
0 .03 .13 r
.3692 .4749 .37452 .48006 .38321 .47759 .37792 .47239 Metetra
0 .03 .13 r
.37792 .47239 .38321 .47759 .39196 .47463 .38668 .46945 Metetra
0 .03 .13 r
.38668 .46945 .39196 .47463 .40073 .47196 .39546 .46678 Metetra
0 .03 .131 r
.39546 .46678 .40073 .47196 .40953 .46907 .40428 .46391 Metetra
0 .031 .131 r
.40428 .46391 .40953 .46907 .41835 .46655 .41312 .46133 Metetra
0 .032 .132 r
.41312 .46133 .41835 .46655 .4272 .4637 .422 .45845 Metetra
0 .033 .133 r
.422 .45845 .4272 .4637 .43608 .46143 .43088 .4562 Metetra
0 .034 .136 r
.43088 .4562 .43608 .46143 .44499 .45884 .43981 .45362 Metetra
0 .036 .137 r
.43981 .45362 .44499 .45884 .45393 .45638 .44877 .4513 Metetra
0 .037 .138 r
.44877 .4513 .45393 .45638 .46291 .45343 .45777 .44836 Metetra
0 .037 .139 r
.45777 .44836 .46291 .45343 .47192 .45056 .4668 .44565 Metetra
0 .038 .139 r
.4668 .44565 .47192 .45056 .48095 .4479 .47585 .44279 Metetra
0 .039 .14 r
.47585 .44279 .48095 .4479 .49002 .44527 .48494 .44014 Metetra
0 .041 .143 r
.48494 .44014 .49002 .44527 .49912 .44317 .49406 .43798 Metetra
0 .043 .145 r
.49406 .43798 .49912 .44317 .50825 .44041 .50321 .43543 Metetra
0 .045 .147 r
.50321 .43543 .50825 .44041 .51742 .43794 .51239 .43331 Metetra
0 .047 .149 r
.51239 .43331 .51742 .43794 .52661 .43524 .52161 .43043 Metetra
0 .048 .151 r
.52161 .43043 .52661 .43524 .53585 .43268 .53087 .42797 Metetra
0 .051 .154 r
.53087 .42797 .53585 .43268 .54511 .43066 .54016 .42607 Metetra
0 .054 .156 r
.54016 .42607 .54511 .43066 .55441 .42756 .54948 .42314 Metetra
0 .054 .156 r
.54948 .42314 .55441 .42756 .56373 .42435 .55883 .42021 Metetra
0 .055 .157 r
.55883 .42021 .56373 .42435 .5731 .42202 .56822 .41762 Metetra
0 .056 .158 r
.56822 .41762 .5731 .42202 .58249 .41898 .57763 .41454 Metetra
0 .055 .157 r
.57763 .41454 .58249 .41898 .5919 .41523 .58707 .41103 Metetra
0 .054 .156 r
.58707 .41103 .5919 .41523 .60136 .41237 .59655 .40788 Metetra
0 .054 .156 r
.59655 .40788 .60136 .41237 .61085 .40939 .60606 .40465 Metetra
0 .051 .154 r
.60606 .40465 .61085 .40939 .62034 .40531 .61557 .40043 Metetra
0 .048 .151 r
.61557 .40043 .62034 .40531 .62987 .40177 .62513 .39676 Metetra
0 .047 .149 r
.62513 .39676 .62987 .40177 .63944 .3984 .63473 .39353 Metetra
0 .045 .147 r
.63473 .39353 .63944 .3984 .64903 .3948 .64433 .38954 Metetra
0 .043 .145 r
.64433 .38954 .64903 .3948 .65867 .39145 .65398 .38594 Metetra
0 .041 .143 r
.65398 .38594 .65867 .39145 .6683 .38744 .66364 .38195 Metetra
0 .039 .14 r
.66364 .38195 .6683 .38744 .678 .38397 .67336 .37846 Metetra
0 .038 .139 r
.67336 .37846 .678 .38397 .68772 .38054 .68312 .37521 Metetra
0 .037 .139 r
.68312 .37521 .68772 .38054 .69749 .37734 .6929 .3718 Metetra
0 .037 .138 r
.6929 .3718 .69749 .37734 .7073 .37419 .70273 .3686 Metetra
0 .036 .137 r
.70273 .3686 .7073 .37419 .71711 .37054 .71256 .36477 Metetra
0 .034 .136 r
.71256 .36477 .71711 .37054 .72696 .36701 .72243 .36119 Metetra
0 .033 .133 r
.72243 .36119 .72696 .36701 .73682 .36317 .73232 .35729 Metetra
0 .032 .132 r
.73232 .35729 .73682 .36317 .74676 .35989 .74228 .35401 Metetra
0 .031 .131 r
.74228 .35401 .74676 .35989 .7567 .35632 .75225 .35046 Metetra
0 .03 .131 r
.75225 .35046 .7567 .35632 .76671 .35311 .76228 .34719 Metetra
0 .03 .13 r
.76228 .34719 .76671 .35311 .77674 .34967 .77234 .34372 Metetra
0 .03 .13 r
.77234 .34372 .77674 .34967 .78682 .34651 .78244 .3405 Metetra
0 .03 .13 r
.78244 .3405 .78682 .34651 .7969 .34287 .79255 .33685 Metetra
0 .029 .129 r
.79255 .33685 .7969 .34287 .80704 .33948 .80271 .3334 Metetra
0 .028 .128 r
.80271 .3334 .80704 .33948 .81719 .33587 .81289 .32978 Metetra
0 .028 .127 r
.81289 .32978 .81719 .33587 .8274 .33246 .82312 .32634 Metetra
0 .027 .126 r
.82312 .32634 .8274 .33246 .83762 .3288 .83337 .32267 Metetra
0 .026 .126 r
.83337 .32267 .83762 .3288 .84791 .32555 .84369 .31937 Metetra
0 .026 .125 r
.84369 .31937 .84791 .32555 .85823 .32208 .85403 .3159 Metetra
0 .026 .125 r
.85403 .3159 .85823 .32208 .86859 .31878 .86442 .31258 Metetra
0 .026 .125 r
.86442 .31258 .86859 .31878 .87898 .31532 .87484 .3091 Metetra
0 .027 .126 r
.87484 .3091 .87898 .31532 .88944 .31213 .88532 .30589 Metetra
0 .027 .126 r
.28642 .49445 .29193 .49948 .30042 .4965 .29492 .49161 Metetra
0 .027 .126 r
.29492 .49161 .30042 .4965 .30892 .49381 .30344 .48896 Metetra
0 .027 .126 r
.30344 .48896 .30892 .49381 .31746 .49097 .312 .48603 Metetra
0 .027 .126 r
.312 .48603 .31746 .49097 .32601 .48827 .32058 .48316 Metetra
0 .027 .126 r
.32058 .48316 .32601 .48827 .3346 .48541 .3292 .48013 Metetra
0 .027 .126 r
.3292 .48013 .3346 .48541 .3432 .48291 .33782 .47748 Metetra
0 .027 .127 r
.33782 .47748 .3432 .48291 .35184 .48018 .34648 .47473 Metetra
0 .028 .127 r
.34648 .47473 .35184 .48018 .3605 .47762 .35515 .47224 Metetra
0 .029 .129 r
.35515 .47224 .3605 .47762 .3692 .4749 .36385 .46973 Metetra
0 .03 .13 r
.36385 .46973 .3692 .4749 .37792 .47239 .37258 .46738 Metetra
0 .031 .131 r
.37258 .46738 .37792 .47239 .38668 .46945 .38135 .46457 Metetra
0 .031 .131 r
.38135 .46457 .38668 .46945 .39546 .46678 .39016 .46185 Metetra
0 .031 .132 r
.39016 .46185 .39546 .46678 .40428 .46391 .399 .45881 Metetra
0 .031 .132 r
.399 .45881 .40428 .46391 .41312 .46133 .40786 .45596 Metetra
0 .032 .132 r
.40786 .45596 .41312 .46133 .422 .45845 .41676 .45292 Metetra
0 .033 .133 r
.41676 .45292 .422 .45845 .43088 .4562 .42567 .45056 Metetra
0 .034 .135 r
.42567 .45056 .43088 .4562 .43981 .45362 .43462 .44807 Metetra
0 .036 .138 r
.43462 .44807 .43981 .45362 .44877 .4513 .44358 .44601 Metetra
0 .038 .14 r
.44358 .44601 .44877 .4513 .45777 .44836 .45259 .4434 Metetra
0 .039 .141 r
.45259 .4434 .45777 .44836 .4668 .44565 .46163 .44108 Metetra
0 .04 .142 r
.46163 .44108 .4668 .44565 .47585 .44279 .47071 .43818 Metetra
0 .041 .143 r
.47071 .43818 .47585 .44279 .48494 .44014 .47982 .4355 Metetra
0 .043 .145 r
.47982 .4355 .48494 .44014 .49406 .43798 .48896 .43306 Metetra
0 .045 .147 r
.48896 .43306 .49406 .43798 .50321 .43543 .49813 .4305 Metetra
0 .048 .15 r
.49813 .4305 .50321 .43543 .51239 .43331 .50734 .4284 Metetra
0 .05 .152 r
.50734 .4284 .51239 .43331 .52161 .43043 .51658 .4254 Metetra
0 .051 .154 r
.51658 .4254 .52161 .43043 .53087 .42797 .52585 .42301 Metetra
0 .055 .157 r
.52585 .42301 .53087 .42797 .54016 .42607 .53516 .42099 Metetra
0 .058 .16 r
.53516 .42099 .54016 .42607 .54948 .42314 .54451 .41849 Metetra
0 .059 .162 r
.54451 .41849 .54948 .42314 .55883 .42021 .55389 .41605 Metetra
0 .061 .163 r
.55389 .41605 .55883 .42021 .56822 .41762 .5633 .41306 Metetra
0 .061 .163 r
.5633 .41306 .56822 .41762 .57763 .41454 .57274 .40996 Metetra
0 .061 .163 r
.57274 .40996 .57763 .41454 .58707 .41103 .58221 .40681 Metetra
0 .059 .162 r
.58221 .40681 .58707 .41103 .59655 .40788 .59171 .40315 Metetra
0 .058 .16 r
.59171 .40315 .59655 .40788 .60606 .40465 .60123 .39945 Metetra
0 .055 .157 r
.60123 .39945 .60606 .40465 .61557 .40043 .61077 .39529 Metetra
0 .051 .154 r
.61077 .39529 .61557 .40043 .62513 .39676 .62034 .39153 Metetra
0 .05 .152 r
.62034 .39153 .62513 .39676 .63473 .39353 .62997 .38838 Metetra
0 .048 .15 r
.62997 .38838 .63473 .39353 .64433 .38954 .6396 .38433 Metetra
0 .045 .147 r
.6396 .38433 .64433 .38954 .65398 .38594 .64927 .38069 Metetra
0 .043 .145 r
.64927 .38069 .65398 .38594 .66364 .38195 .65897 .37695 Metetra
0 .041 .143 r
.65897 .37695 .66364 .38195 .67336 .37846 .66872 .37346 Metetra
0 .04 .142 r
.66872 .37346 .67336 .37846 .68312 .37521 .6785 .37021 Metetra
0 .039 .141 r
.6785 .37021 .68312 .37521 .6929 .3718 .68829 .36637 Metetra
0 .038 .14 r
.68829 .36637 .6929 .3718 .70273 .3686 .69813 .36278 Metetra
0 .036 .138 r
.69813 .36278 .70273 .3686 .71256 .36477 .70796 .35865 Metetra
0 .034 .135 r
.70796 .35865 .71256 .36477 .72243 .36119 .71785 .35493 Metetra
0 .032 .133 r
.71785 .35493 .72243 .36119 .73232 .35729 .72777 .35111 Metetra
0 .032 .132 r
.72777 .35111 .73232 .35729 .74228 .35401 .73776 .34797 Metetra
0 .031 .132 r
.73776 .34797 .74228 .35401 .75225 .35046 .74778 .34466 Metetra
0 .031 .132 r
.74778 .34466 .75225 .35046 .76228 .34719 .75785 .34152 Metetra
0 .031 .131 r
.75785 .34152 .76228 .34719 .77234 .34372 .76793 .33806 Metetra
0 .031 .131 r
.76793 .33806 .77234 .34372 .78244 .3405 .77805 .33467 Metetra
0 .03 .13 r
.77805 .33467 .78244 .3405 .79255 .33685 .78817 .33081 Metetra
0 .029 .129 r
.78817 .33081 .79255 .33685 .80271 .3334 .79833 .3271 Metetra
0 .028 .127 r
.79833 .3271 .80271 .3334 .81289 .32978 .80853 .32338 Metetra
0 .027 .127 r
.80853 .32338 .81289 .32978 .82312 .32634 .81879 .31992 Metetra
0 .027 .126 r
.81879 .31992 .82312 .32634 .83337 .32267 .82907 .31637 Metetra
0 .027 .126 r
.82907 .31637 .83337 .32267 .84369 .31937 .83944 .3132 Metetra
0 .027 .126 r
.83944 .3132 .84369 .31937 .85403 .3159 .84982 .30987 Metetra
0 .027 .126 r
.84982 .30987 .85403 .3159 .86442 .31258 .86025 .3066 Metetra
0 .027 .126 r
.86025 .3066 .86442 .31258 .87484 .3091 .87068 .30304 Metetra
0 .027 .126 r
.87068 .30304 .87484 .3091 .88532 .30589 .88118 .29965 Metetra
0 .027 .126 r
.2809 .48921 .28642 .49445 .29492 .49161 .28942 .48633 Metetra
0 .027 .126 r
.28942 .48633 .29492 .49161 .30344 .48896 .29795 .4837 Metetra
0 .027 .127 r
.29795 .4837 .30344 .48896 .312 .48603 .30651 .48086 Metetra
0 .027 .126 r
.30651 .48086 .312 .48603 .32058 .48316 .31511 .47806 Metetra
0 .027 .126 r
.31511 .47806 .32058 .48316 .3292 .48013 .32374 .47512 Metetra
0 .027 .126 r
.32374 .47512 .3292 .48013 .33782 .47748 .33238 .47243 Metetra
0 .027 .127 r
.33238 .47243 .33782 .47748 .34648 .47473 .34106 .4696 Metetra
0 .028 .127 r
.34106 .4696 .34648 .47473 .35515 .47224 .34975 .46695 Metetra
0 .029 .129 r
.34975 .46695 .35515 .47224 .36385 .46973 .35848 .46435 Metetra
0 .03 .13 r
.35848 .46435 .36385 .46973 .37258 .46738 .36723 .46186 Metetra
0 .031 .131 r
.36723 .46186 .37258 .46738 .38135 .46457 .37602 .45913 Metetra
0 .032 .132 r
.37602 .45913 .38135 .46457 .39016 .46185 .38483 .45652 Metetra
0 .032 .133 r
.38483 .45652 .39016 .46185 .399 .45881 .39368 .45369 Metetra
0 .032 .133 r
.39368 .45369 .399 .45881 .40786 .45596 .40256 .4509 Metetra
0 .032 .133 r
.40256 .4509 .40786 .45596 .41676 .45292 .41148 .44791 Metetra
0 .033 .134 r
.41148 .44791 .41676 .45292 .42567 .45056 .42041 .44544 Metetra
0 .034 .135 r
.42041 .44544 .42567 .45056 .43462 .44807 .42938 .44279 Metetra
0 .036 .138 r
.42938 .44279 .43462 .44807 .44358 .44601 .43836 .44058 Metetra
0 .039 .14 r
.43836 .44058 .44358 .44601 .45259 .4434 .4474 .43793 Metetra
0 .041 .143 r
.4474 .43793 .45259 .4434 .46163 .44108 .45645 .43576 Metetra
0 .042 .144 r
.45645 .43576 .46163 .44108 .47071 .43818 .46555 .43288 Metetra
0 .043 .145 r
.46555 .43288 .47071 .43818 .47982 .4355 .47467 .43042 Metetra
0 .045 .147 r
.47467 .43042 .47982 .4355 .48896 .43306 .48383 .42797 Metetra
0 .048 .15 r
.48383 .42797 .48896 .43306 .49813 .4305 .49302 .42588 Metetra
0 .051 .154 r
.49302 .42588 .49813 .4305 .50734 .4284 .50224 .42413 Metetra
0 .054 .157 r
.50224 .42413 .50734 .4284 .51658 .4254 .51151 .42142 Metetra
0 .056 .159 r
.51151 .42142 .51658 .4254 .52585 .42301 .52081 .4193 Metetra
0 .06 .162 r
.52081 .4193 .52585 .42301 .53516 .42099 .53014 .41706 Metetra
0 .064 .166 r
.53014 .41706 .53516 .42099 .54451 .41849 .53951 .41506 Metetra
0 .068 .169 r
.53951 .41506 .54451 .41849 .55389 .41605 .54892 .41307 Metetra
0 .069 .171 r
.54892 .41307 .55389 .41605 .5633 .41306 .55836 .40959 Metetra
0 .069 .17 r
.55836 .40959 .5633 .41306 .57274 .40996 .56783 .40648 Metetra
0 .069 .171 r
.56783 .40648 .57274 .40996 .58221 .40681 .57733 .40378 Metetra
0 .068 .169 r
.57733 .40378 .58221 .40681 .59171 .40315 .58685 .39962 Metetra
0 .064 .166 r
.58685 .39962 .59171 .40315 .60123 .39945 .59639 .39539 Metetra
0 .06 .162 r
.59639 .39539 .60123 .39945 .61077 .39529 .60596 .39141 Metetra
0 .056 .159 r
.60596 .39141 .61077 .39529 .62034 .39153 .61556 .38737 Metetra
0 .054 .157 r
.61556 .38737 .62034 .39153 .62997 .38838 .62521 .38387 Metetra
0 .051 .154 r
.62521 .38387 .62997 .38838 .6396 .38433 .63485 .37942 Metetra
0 .048 .15 r
.63485 .37942 .6396 .38433 .64927 .38069 .64453 .37527 Metetra
0 .045 .147 r
.64453 .37527 .64927 .38069 .65897 .37695 .65426 .3715 Metetra
0 .043 .145 r
.65426 .3715 .65897 .37695 .66872 .37346 .66401 .36777 Metetra
0 .042 .144 r
.66401 .36777 .66872 .37346 .6785 .37021 .67382 .36445 Metetra
0 .041 .143 r
.67382 .36445 .6785 .37021 .68829 .36637 .68363 .36042 Metetra
0 .039 .14 r
.68363 .36042 .68829 .36637 .69813 .36278 .69349 .35683 Metetra
0 .036 .138 r
.69349 .35683 .69813 .36278 .70796 .35865 .70335 .35281 Metetra
0 .034 .135 r
.70335 .35281 .70796 .35865 .71785 .35493 .71328 .34921 Metetra
0 .033 .133 r
.71328 .34921 .71785 .35493 .72777 .35111 .72323 .34548 Metetra
0 .032 .133 r
.72323 .34548 .72777 .35111 .73776 .34797 .73324 .34225 Metetra
0 .032 .133 r
.73324 .34225 .73776 .34797 .74778 .34466 .74328 .33883 Metetra
0 .032 .133 r
.74328 .33883 .74778 .34466 .75785 .34152 .75336 .33543 Metetra
0 .032 .132 r
.75336 .33543 .75785 .34152 .76793 .33806 .76345 .33181 Metetra
0 .031 .131 r
.76345 .33181 .76793 .33806 .77805 .33467 .77359 .3283 Metetra
0 .03 .13 r
.77359 .3283 .77805 .33467 .78817 .33081 .78374 .32454 Metetra
0 .029 .128 r
.78374 .32454 .78817 .33081 .79833 .3271 .79394 .3209 Metetra
0 .028 .127 r
.79394 .3209 .79833 .3271 .80853 .32338 .80418 .3173 Metetra
0 .027 .126 r
.80418 .3173 .80853 .32338 .81879 .31992 .81447 .31388 Metetra
0 .027 .126 r
.81447 .31388 .81879 .31992 .82907 .31637 .82478 .31033 Metetra
0 .027 .126 r
.82478 .31033 .82907 .31637 .83944 .3132 .83516 .30703 Metetra
0 .027 .126 r
.83516 .30703 .83944 .3132 .84982 .30987 .84556 .30359 Metetra
0 .027 .127 r
.84556 .30359 .84982 .30987 .86025 .3066 .85601 .30018 Metetra
0 .027 .126 r
.85601 .30018 .86025 .3066 .87068 .30304 .86647 .29657 Metetra
0 .027 .126 r
.86647 .29657 .87068 .30304 .88118 .29965 .87699 .29318 Metetra
0 .027 .126 r
.27535 .48388 .2809 .48921 .28942 .48633 .28389 .48098 Metetra
0 .027 .126 r
.28389 .48098 .28942 .48633 .29795 .4837 .29242 .47841 Metetra
0 .027 .127 r
.29242 .47841 .29795 .4837 .30651 .48086 .301 .47571 Metetra
0 .027 .127 r
.301 .47571 .30651 .48086 .31511 .47806 .3096 .473 Metetra
0 .027 .127 r
.3096 .473 .31511 .47806 .32374 .47512 .31824 .47016 Metetra
0 .028 .127 r
.31824 .47016 .32374 .47512 .33238 .47243 .32691 .46738 Metetra
0 .028 .127 r
.32691 .46738 .33238 .47243 .34106 .4696 .33561 .46442 Metetra
0 .028 .127 r
.33561 .46442 .34106 .4696 .34975 .46695 .34433 .46157 Metetra
0 .028 .128 r
.34433 .46157 .34975 .46695 .35848 .46435 .35308 .45884 Metetra
0 .029 .129 r
.35308 .45884 .35848 .46435 .36723 .46186 .36185 .45623 Metetra
0 .03 .131 r
.36185 .45623 .36723 .46186 .37602 .45913 .37065 .45367 Metetra
0 .031 .132 r
.37065 .45367 .37602 .45913 .38483 .45652 .37947 .45124 Metetra
0 .033 .133 r
.37947 .45124 .38483 .45652 .39368 .45369 .38833 .44868 Metetra
0 .033 .134 r
.38833 .44868 .39368 .45369 .40256 .4509 .39723 .44592 Metetra
0 .033 .134 r
.39723 .44592 .40256 .4509 .41148 .44791 .40616 .44294 Metetra
0 .034 .135 r
.40616 .44294 .41148 .44791 .42041 .44544 .41512 .44021 Metetra
0 .035 .136 r
.41512 .44021 .42041 .44544 .42938 .44279 .42411 .43734 Metetra
0 .036 .138 r
.42411 .43734 .42938 .44279 .43836 .44058 .43312 .43489 Metetra
0 .038 .14 r
.43312 .43489 .43836 .44058 .4474 .43793 .44217 .4323 Metetra
0 .041 .143 r
.44217 .4323 .4474 .43793 .45645 .43576 .45123 .43038 Metetra
0 .043 .145 r
.45123 .43038 .45645 .43576 .46555 .43288 .46035 .42778 Metetra
0 .045 .147 r
.46035 .42778 .46555 .43288 .47467 .43042 .46949 .42568 Metetra
0 .048 .15 r
.46949 .42568 .47467 .43042 .48383 .42797 .47867 .42328 Metetra
0 .051 .154 r
.47867 .42328 .48383 .42797 .49302 .42588 .48787 .42158 Metetra
0 .057 .159 r
.48787 .42158 .49302 .42588 .50224 .42413 .49711 .41991 Metetra
0 .061 .163 r
.49711 .41991 .50224 .42413 .51151 .42142 .5064 .41763 Metetra
0 .064 .166 r
.5064 .41763 .51151 .42142 .52081 .4193 .51572 .41567 Metetra
0 .068 .17 r
.51572 .41567 .52081 .4193 .53014 .41706 .52508 .41302 Metetra
0 .073 .174 r
.52508 .41302 .53014 .41706 .53951 .41506 .53448 .41125 Metetra
0 .079 .178 r
.53448 .41125 .53951 .41506 .54892 .41307 .54391 .40934 Metetra
0 .08 .18 r
.54391 .40934 .54892 .41307 .55836 .40959 .55337 .40561 Metetra
0 .079 .179 r
.55337 .40561 .55836 .40959 .56783 .40648 .56287 .4025 Metetra
0 .08 .18 r
.56287 .4025 .56783 .40648 .57733 .40378 .57241 .4 Metetra
0 .079 .178 r
.57241 .4 .57733 .40378 .58685 .39962 .58195 .3957 Metetra
0 .073 .174 r
.58195 .3957 .58685 .39962 .59639 .39539 .59151 .39122 Metetra
0 .068 .17 r
.59151 .39122 .59639 .39539 .60596 .39141 .60112 .38762 Metetra
0 .064 .166 r
.60112 .38762 .60596 .39141 .61556 .38737 .61075 .38339 Metetra
0 .061 .163 r
.61075 .38339 .61556 .38737 .62521 .38387 .62041 .37941 Metetra
0 .057 .159 r
.62041 .37941 .62521 .38387 .63485 .37942 .63008 .37481 Metetra
0 .051 .154 r
.63008 .37481 .63485 .37942 .64453 .37527 .63977 .37026 Metetra
0 .048 .15 r
.63977 .37026 .64453 .37527 .65426 .3715 .64952 .36641 Metetra
0 .045 .147 r
.64952 .36641 .65426 .3715 .66401 .36777 .65929 .36227 Metetra
0 .043 .145 r
.65929 .36227 .66401 .36777 .67382 .36445 .66911 .35861 Metetra
0 .041 .143 r
.66911 .35861 .67382 .36445 .68363 .36042 .67892 .35429 Metetra
0 .038 .14 r
.67892 .35429 .68363 .36042 .69349 .35683 .6888 .3506 Metetra
0 .036 .138 r
.6888 .3506 .69349 .35683 .70335 .35281 .69871 .34678 Metetra
0 .035 .136 r
.69871 .34678 .70335 .35281 .71328 .34921 .70867 .34338 Metetra
0 .034 .135 r
.70867 .34338 .71328 .34921 .72323 .34548 .71866 .33987 Metetra
0 .033 .134 r
.71866 .33987 .72323 .34548 .73324 .34225 .7287 .33659 Metetra
0 .033 .134 r
.7287 .33659 .73324 .34225 .74328 .33883 .73876 .3331 Metetra
0 .033 .133 r
.73876 .3331 .74328 .33883 .75336 .33543 .74884 .32939 Metetra
0 .032 .132 r
.74884 .32939 .75336 .33543 .76345 .33181 .75895 .32555 Metetra
0 .03 .131 r
.75895 .32555 .76345 .33181 .77359 .3283 .76909 .32182 Metetra
0 .029 .129 r
.76909 .32182 .77359 .3283 .78374 .32454 .77928 .31814 Metetra
0 .028 .128 r
.77928 .31814 .78374 .32454 .79394 .3209 .78951 .31458 Metetra
0 .028 .127 r
.78951 .31458 .79394 .3209 .80418 .3173 .79979 .31115 Metetra
0 .028 .127 r
.79979 .31115 .80418 .3173 .81447 .31388 .81012 .30783 Metetra
0 .028 .127 r
.81012 .30783 .81447 .31388 .82478 .31033 .82047 .30434 Metetra
0 .027 .127 r
.82047 .30434 .82478 .31033 .83516 .30703 .83086 .3009 Metetra
0 .027 .127 r
.83086 .3009 .83516 .30703 .84556 .30359 .84128 .29733 Metetra
0 .027 .127 r
.84128 .29733 .84556 .30359 .85601 .30018 .85174 .29373 Metetra
0 .027 .126 r
.85174 .29373 .85601 .30018 .86647 .29657 .86221 .29001 Metetra
0 .027 .126 r
.86221 .29001 .86647 .29657 .87699 .29318 .87276 .28659 Metetra
0 .027 .126 r
.26974 .47893 .27535 .48388 .28389 .48098 .27829 .476 Metetra
0 .027 .126 r
.27829 .476 .28389 .48098 .29242 .47841 .28685 .47329 Metetra
0 .027 .127 r
.28685 .47329 .29242 .47841 .301 .47571 .29546 .4704 Metetra
0 .027 .127 r
.29546 .4704 .301 .47571 .3096 .473 .30409 .46753 Metetra
0 .027 .127 r
.30409 .46753 .3096 .473 .31824 .47016 .31274 .46464 Metetra
0 .028 .127 r
.31274 .46464 .31824 .47016 .32691 .46738 .32142 .46192 Metetra
0 .028 .127 r
.32142 .46192 .32691 .46738 .33561 .46442 .33013 .45913 Metetra
0 .028 .128 r
.33013 .45913 .33561 .46442 .34433 .46157 .33886 .45643 Metetra
0 .029 .128 r
.33886 .45643 .34433 .46157 .35308 .45884 .34762 .45383 Metetra
0 .03 .13 r
.34762 .45383 .35308 .45884 .36185 .45623 .35641 .45117 Metetra
0 .03 .131 r
.35641 .45117 .36185 .45623 .37065 .45367 .36523 .44843 Metetra
0 .032 .132 r
.36523 .44843 .37065 .45367 .37947 .45124 .37408 .44574 Metetra
0 .033 .133 r
.37408 .44574 .37947 .45124 .38833 .44868 .38297 .44301 Metetra
0 .034 .134 r
.38297 .44301 .38833 .44868 .39723 .44592 .39188 .44019 Metetra
0 .034 .135 r
.39188 .44019 .39723 .44592 .40616 .44294 .40083 .43741 Metetra
0 .035 .136 r
.40083 .43741 .40616 .44294 .41512 .44021 .4098 .43489 Metetra
0 .036 .137 r
.4098 .43489 .41512 .44021 .42411 .43734 .4188 .43228 Metetra
0 .037 .139 r
.4188 .43228 .42411 .43734 .43312 .43489 .42782 .42997 Metetra
0 .039 .141 r
.42782 .42997 .43312 .43489 .44217 .4323 .43689 .42742 Metetra
0 .042 .144 r
.43689 .42742 .44217 .4323 .45123 .43038 .44598 .42533 Metetra
0 .044 .147 r
.44598 .42533 .45123 .43038 .46035 .42778 .45512 .42249 Metetra
0 .047 .149 r
.45512 .42249 .46035 .42778 .46949 .42568 .46428 .42021 Metetra
0 .05 .152 r
.46428 .42021 .46949 .42568 .47867 .42328 .47348 .41769 Metetra
0 .054 .157 r
.47348 .41769 .47867 .42328 .48787 .42158 .4827 .41627 Metetra
0 .061 .163 r
.4827 .41627 .48787 .42158 .49711 .41991 .49195 .41501 Metetra
0 .068 .169 r
.49195 .41501 .49711 .41991 .5064 .41763 .50125 .41372 Metetra
0 .074 .175 r
.50125 .41372 .5064 .41763 .51572 .41567 .5106 .41231 Metetra
0 .079 .179 r
.5106 .41231 .51572 .41567 .52508 .41302 .51998 .40974 Metetra
0 .084 .183 r
.51998 .40974 .52508 .41302 .53448 .41125 .52941 .40834 Metetra
0 .091 .189 r
.52941 .40834 .53448 .41125 .54391 .40934 .53887 .40677 Metetra
0 .094 .191 r
.53887 .40677 .54391 .40934 .55337 .40561 .54837 .40359 Metetra
0 .093 .19 r
.54837 .40359 .55337 .40561 .56287 .4025 .5579 .40048 Metetra
0 .094 .191 r
.5579 .40048 .56287 .4025 .57241 .4 .56746 .39739 Metetra
0 .091 .189 r
.56746 .39739 .57241 .4 .58195 .3957 .57703 .39267 Metetra
0 .084 .183 r
.57703 .39267 .58195 .3957 .59151 .39122 .58662 .38781 Metetra
0 .079 .179 r
.58662 .38781 .59151 .39122 .60112 .38762 .59625 .38411 Metetra
0 .074 .175 r
.59625 .38411 .60112 .38762 .61075 .38339 .6059 .37928 Metetra
0 .068 .169 r
.6059 .37928 .61075 .38339 .62041 .37941 .61556 .37426 Metetra
0 .061 .163 r
.61556 .37426 .62041 .37941 .63008 .37481 .62524 .3692 Metetra
0 .054 .156 r
.62524 .3692 .63008 .37481 .63977 .37026 .63495 .36433 Metetra
0 .05 .152 r
.63495 .36433 .63977 .37026 .64952 .36641 .64473 .36056 Metetra
0 .047 .149 r
.64473 .36056 .64952 .36641 .65929 .36227 .65452 .35659 Metetra
0 .045 .147 r
.65452 .35659 .65929 .36227 .66911 .35861 .66438 .35313 Metetra
0 .042 .144 r
.66438 .35313 .66911 .35861 .67892 .35429 .67423 .34893 Metetra
0 .039 .141 r
.67423 .34893 .67892 .35429 .6888 .3506 .68413 .34515 Metetra
0 .037 .139 r
.68413 .34515 .6888 .3506 .69871 .34678 .69406 .34116 Metetra
0 .036 .137 r
.69406 .34116 .69871 .34678 .70867 .34338 .70403 .33745 Metetra
0 .035 .136 r
.70403 .33745 .70867 .34338 .71866 .33987 .71403 .33369 Metetra
0 .034 .135 r
.71403 .33369 .71866 .33987 .7287 .33659 .72408 .33017 Metetra
0 .034 .134 r
.72408 .33017 .7287 .33659 .73876 .3331 .73417 .32669 Metetra
0 .033 .134 r
.73417 .32669 .73876 .3331 .74884 .32939 .74428 .32312 Metetra
0 .032 .132 r
.74428 .32312 .74884 .32939 .75895 .32555 .75443 .31949 Metetra
0 .031 .131 r
.75443 .31949 .75895 .32555 .76909 .32182 .76462 .31591 Metetra
0 .03 .13 r
.76462 .31591 .76909 .32182 .77928 .31814 .77483 .31224 Metetra
0 .029 .128 r
.77483 .31224 .77928 .31814 .78951 .31458 .78508 .30852 Metetra
0 .028 .128 r
.78508 .30852 .78951 .31458 .79979 .31115 .79537 .30489 Metetra
0 .028 .127 r
.79537 .30489 .79979 .31115 .81012 .30783 .80571 .30136 Metetra
0 .028 .127 r
.80571 .30136 .81012 .30783 .82047 .30434 .81608 .29776 Metetra
0 .027 .127 r
.81608 .29776 .82047 .30434 .83086 .3009 .8265 .29433 Metetra
0 .027 .127 r
.8265 .29433 .83086 .3009 .84128 .29733 .83696 .29088 Metetra
0 .027 .127 r
.83696 .29088 .84128 .29733 .85174 .29373 .84746 .28745 Metetra
0 .027 .126 r
.84746 .28745 .85174 .29373 .86221 .29001 .85798 .28382 Metetra
0 .027 .126 r
.85798 .28382 .86221 .29001 .87276 .28659 .86856 .2804 Metetra
0 .027 .126 r
.26411 .4737 .26974 .47893 .27829 .476 .27267 .47078 Metetra
0 .027 .127 r
.27267 .47078 .27829 .476 .28685 .47329 .28125 .46806 Metetra
0 .027 .127 r
.28125 .46806 .28685 .47329 .29546 .4704 .28987 .46516 Metetra
0 .027 .127 r
.28987 .46516 .29546 .4704 .30409 .46753 .29852 .46224 Metetra
0 .027 .127 r
.29852 .46224 .30409 .46753 .31274 .46464 .3072 .45935 Metetra
0 .027 .127 r
.3072 .45935 .31274 .46464 .32142 .46192 .31589 .45659 Metetra
0 .028 .127 r
.31589 .45659 .32142 .46192 .33013 .45913 .32462 .4538 Metetra
0 .028 .128 r
.32462 .4538 .33013 .45913 .33886 .45643 .33337 .45107 Metetra
0 .029 .129 r
.33337 .45107 .33886 .45643 .34762 .45383 .34214 .44848 Metetra
0 .03 .13 r
.34214 .44848 .34762 .45383 .35641 .45117 .35095 .44578 Metetra
0 .031 .131 r
.35095 .44578 .35641 .45117 .36523 .44843 .35979 .44306 Metetra
0 .032 .132 r
.35979 .44306 .36523 .44843 .37408 .44574 .36866 .44035 Metetra
0 .033 .133 r
.36866 .44035 .37408 .44574 .38297 .44301 .37756 .43763 Metetra
0 .033 .134 r
.37756 .43763 .38297 .44301 .39188 .44019 .38649 .43477 Metetra
0 .034 .135 r
.38649 .43477 .39188 .44019 .40083 .43741 .39545 .43206 Metetra
0 .035 .136 r
.39545 .43206 .40083 .43741 .4098 .43489 .40444 .42948 Metetra
0 .037 .138 r
.40444 .42948 .4098 .43489 .4188 .43228 .41346 .4269 Metetra
0 .039 .14 r
.41346 .4269 .4188 .43228 .42782 .42997 .42251 .42455 Metetra
0 .041 .143 r
.42251 .42455 .42782 .42997 .43689 .42742 .43159 .42211 Metetra
0 .044 .146 r
.43159 .42211 .43689 .42742 .44598 .42533 .44069 .42005 Metetra
0 .046 .148 r
.44069 .42005 .44598 .42533 .45512 .42249 .44985 .41733 Metetra
0 .048 .151 r
.44985 .41733 .45512 .42249 .46428 .42021 .45903 .41513 Metetra
0 .051 .154 r
.45903 .41513 .46428 .42021 .47348 .41769 .46824 .41267 Metetra
0 .056 .159 r
.46824 .41267 .47348 .41769 .4827 .41627 .47748 .41151 Metetra
0 .064 .166 r
.47748 .41151 .4827 .41627 .49195 .41501 .48676 .41038 Metetra
0 .074 .175 r
.48676 .41038 .49195 .41501 .50125 .41372 .49607 .40965 Metetra
0 .084 .183 r
.49607 .40965 .50125 .41372 .5106 .41231 .50544 .40838 Metetra
0 .09 .188 r
.50544 .40838 .5106 .41231 .51998 .40974 .51485 .40629 Metetra
0 .099 .195 r
.51485 .40629 .51998 .40974 .52941 .40834 .52429 .40639 Metetra
0 .114 .205 r
.52429 .40639 .52941 .40834 .53887 .40677 .5338 .40716 Metetra
0 .127 .214 r
.5338 .40716 .53887 .40677 .54837 .40359 .54335 .40674 Metetra
0 .131 .217 r
.54335 .40674 .54837 .40359 .5579 .40048 .55292 .40364 Metetra
0 .127 .214 r
.55292 .40364 .5579 .40048 .56746 .39739 .5625 .39774 Metetra
0 .114 .205 r
.5625 .39774 .56746 .39739 .57703 .39267 .57208 .3906 Metetra
0 .099 .195 r
.57208 .3906 .57703 .39267 .58662 .38781 .58168 .38424 Metetra
0 .09 .188 r
.58168 .38424 .58662 .38781 .59625 .38411 .59134 .38002 Metetra
0 .084 .183 r
.59134 .38002 .59625 .38411 .6059 .37928 .601 .375 Metetra
0 .074 .175 r
.601 .375 .6059 .37928 .61556 .37426 .61068 .36938 Metetra
0 .064 .166 r
.61068 .36938 .61556 .37426 .62524 .3692 .62038 .36414 Metetra
0 .056 .158 r
.62038 .36414 .62524 .3692 .63495 .36433 .63011 .35899 Metetra
0 .051 .154 r
.63011 .35899 .63495 .36433 .64473 .36056 .63991 .35512 Metetra
0 .048 .151 r
.63991 .35512 .64473 .36056 .65452 .35659 .64974 .35101 Metetra
0 .046 .149 r
.64974 .35101 .65452 .35659 .66438 .35313 .65961 .34739 Metetra
0 .044 .146 r
.65961 .34739 .66438 .35313 .67423 .34893 .66948 .34312 Metetra
0 .041 .143 r
.66948 .34312 .67423 .34893 .68413 .34515 .67941 .33919 Metetra
0 .038 .14 r
.67941 .33919 .68413 .34515 .69406 .34116 .68936 .3352 Metetra
0 .036 .138 r
.68936 .3352 .69406 .34116 .70403 .33745 .69935 .33143 Metetra
0 .035 .136 r
.69935 .33143 .70403 .33745 .71403 .33369 .70938 .32767 Metetra
0 .034 .135 r
.70938 .32767 .71403 .33369 .72408 .33017 .71945 .32406 Metetra
0 .033 .134 r
.71945 .32406 .72408 .33017 .73417 .32669 .72956 .32057 Metetra
0 .033 .133 r
.72956 .32057 .73417 .32669 .74428 .32312 .7397 .31695 Metetra
0 .032 .132 r
.7397 .31695 .74428 .32312 .75443 .31949 .74988 .3133 Metetra
0 .031 .131 r
.74988 .3133 .75443 .31949 .76462 .31591 .76009 .30966 Metetra
0 .03 .13 r
.76009 .30966 .76462 .31591 .77483 .31224 .77033 .30599 Metetra
0 .029 .129 r
.77033 .30599 .77483 .31224 .78508 .30852 .7806 .30222 Metetra
0 .028 .128 r
.7806 .30222 .78508 .30852 .79537 .30489 .79092 .29857 Metetra
0 .028 .127 r
.79092 .29857 .79537 .30489 .80571 .30136 .80129 .29501 Metetra
0 .027 .127 r
.80129 .29501 .80571 .30136 .81608 .29776 .81168 .29141 Metetra
0 .027 .127 r
.81168 .29141 .81608 .29776 .8265 .29433 .82213 .28794 Metetra
0 .027 .127 r
.82213 .28794 .8265 .29433 .83696 .29088 .83262 .28449 Metetra
0 .027 .127 r
.83262 .28449 .83696 .29088 .84746 .28745 .84314 .28103 Metetra
0 .027 .127 r
.84314 .28103 .84746 .28745 .85798 .28382 .85369 .27738 Metetra
0 .027 .126 r
.85369 .27738 .85798 .28382 .86856 .2804 .8643 .27391 Metetra
0 .027 .126 r
.25847 .46814 .26411 .4737 .27267 .47078 .26704 .46535 Metetra
0 .027 .126 r
.26704 .46535 .27267 .47078 .28125 .46806 .27562 .46279 Metetra
0 .028 .127 r
.27562 .46279 .28125 .46806 .28987 .46516 .28424 .46008 Metetra
0 .028 .127 r
.28424 .46008 .28987 .46516 .29852 .46224 .29291 .45721 Metetra
0 .028 .127 r
.29291 .45721 .29852 .46224 .3072 .45935 .3016 .4543 Metetra
0 .028 .127 r
.3016 .4543 .3072 .45935 .31589 .45659 .31033 .4513 Metetra
0 .028 .127 r
.31033 .4513 .31589 .45659 .32462 .4538 .31908 .44829 Metetra
0 .028 .128 r
.31908 .44829 .32462 .4538 .33337 .45107 .32786 .44538 Metetra
0 .029 .129 r
.32786 .44538 .33337 .45107 .34214 .44848 .33665 .44278 Metetra
0 .03 .13 r
.33665 .44278 .34214 .44848 .35095 .44578 .34547 .44015 Metetra
0 .031 .131 r
.34547 .44015 .35095 .44578 .35979 .44306 .35431 .43774 Metetra
0 .032 .133 r
.35431 .43774 .35979 .44306 .36866 .44035 .36318 .43522 Metetra
0 .033 .134 r
.36318 .43522 .36866 .44035 .37756 .43763 .37209 .43262 Metetra
0 .034 .135 r
.37209 .43262 .37756 .43763 .38649 .43477 .38106 .42959 Metetra
0 .034 .136 r
.38106 .42959 .38649 .43477 .39545 .43206 .39005 .42665 Metetra
0 .035 .136 r
.39005 .42665 .39545 .43206 .40444 .42948 .39907 .42371 Metetra
0 .036 .138 r
.39907 .42371 .40444 .42948 .41346 .4269 .40811 .42101 Metetra
0 .038 .14 r
.40811 .42101 .41346 .4269 .42251 .42455 .41717 .41864 Metetra
0 .041 .143 r
.41717 .41864 .42251 .42455 .43159 .42211 .42625 .41662 Metetra
0 .045 .147 r
.42625 .41662 .43159 .42211 .44069 .42005 .43537 .41492 Metetra
0 .048 .151 r
.43537 .41492 .44069 .42005 .44985 .41733 .44453 .41266 Metetra
0 .051 .154 r
.44453 .41266 .44985 .41733 .45903 .41513 .45373 .4106 Metetra
0 .055 .157 r
.45373 .4106 .45903 .41513 .46824 .41267 .46297 .40806 Metetra
0 .06 .162 r
.46297 .40806 .46824 .41267 .47748 .41151 .47223 .40669 Metetra
0 .068 .17 r
.47223 .40669 .47748 .41151 .48676 .41038 .48153 .40514 Metetra
0 .078 .178 r
.48153 .40514 .48676 .41038 .49607 .40965 .49086 .40445 Metetra
0 .09 .188 r
.49086 .40445 .49607 .40965 .50544 .40838 .50024 .4036 Metetra
0 .103 .197 r
.50024 .4036 .50544 .40838 .51485 .40629 .50966 .40443 Metetra
0 .129 .215 r
.50966 .40443 .51485 .40629 .52429 .40639 .51913 .41033 Metetra
0 .177 .244 r
.51913 .41033 .52429 .40639 .5338 .40716 .52868 .41923 Metetra
0 .234 .274 r
.52868 .41923 .5338 .40716 .54335 .40674 .53833 .42626 Metetra
0 .262 .287 r
.53833 .42626 .54335 .40674 .55292 .40364 .54801 .42316 Metetra
0 .234 .274 r
.54801 .42316 .55292 .40364 .5625 .39774 .55761 .40979 Metetra
0 .177 .244 r
.55761 .40979 .5625 .39774 .57208 .3906 .56716 .39446 Metetra
0 .129 .215 r
.56716 .39446 .57208 .3906 .58168 .38424 .57673 .38227 Metetra
0 .103 .197 r
.57673 .38227 .58168 .38424 .59134 .38002 .58636 .37509 Metetra
0 .09 .188 r
.58636 .37509 .59134 .38002 .601 .375 .59605 .36956 Metetra
0 .078 .178 r
.59605 .36956 .601 .375 .61068 .36938 .60575 .36387 Metetra
0 .068 .17 r
.60575 .36387 .61068 .36938 .62038 .36414 .6155 .35902 Metetra
0 .06 .162 r
.6155 .35902 .62038 .36414 .63011 .35899 .62526 .35405 Metetra
0 .055 .157 r
.62526 .35405 .63011 .35899 .63991 .35512 .63509 .35023 Metetra
0 .051 .154 r
.63509 .35023 .63991 .35512 .64974 .35101 .64494 .34593 Metetra
0 .048 .151 r
.64494 .34593 .64974 .35101 .65961 .34739 .65481 .34181 Metetra
0 .045 .147 r
.65481 .34181 .65961 .34739 .66948 .34312 .6647 .33711 Metetra
0 .041 .143 r
.6647 .33711 .66948 .34312 .67941 .33919 .67463 .33273 Metetra
0 .038 .14 r
.67463 .33273 .67941 .33919 .68936 .3352 .6846 .32871 Metetra
0 .036 .138 r
.6846 .32871 .68936 .3352 .69935 .33143 .69462 .32503 Metetra
0 .035 .136 r
.69462 .32503 .69935 .33143 .70938 .32767 .7047 .3216 Metetra
0 .034 .136 r
.7047 .3216 .70938 .32767 .71945 .32406 .71481 .31817 Metetra
0 .034 .135 r
.71481 .31817 .71945 .32406 .72956 .32057 .72496 .31483 Metetra
0 .033 .134 r
.72496 .31483 .72956 .32057 .7397 .31695 .73511 .31104 Metetra
0 .032 .133 r
.73511 .31104 .7397 .31695 .74988 .3133 .7453 .30715 Metetra
0 .031 .131 r
.7453 .30715 .74988 .3133 .76009 .30966 .75551 .30315 Metetra
0 .03 .13 r
.75551 .30315 .76009 .30966 .77033 .30599 .76577 .29937 Metetra
0 .029 .129 r
.76577 .29937 .77033 .30599 .7806 .30222 .77607 .29557 Metetra
0 .028 .128 r
.77607 .29557 .7806 .30222 .79092 .29857 .78643 .29207 Metetra
0 .028 .127 r
.78643 .29207 .79092 .29857 .80129 .29501 .79684 .28869 Metetra
0 .028 .127 r
.79684 .28869 .80129 .29501 .81168 .29141 .80728 .28529 Metetra
0 .028 .127 r
.80728 .28529 .81168 .29141 .82213 .28794 .81776 .28181 Metetra
0 .028 .127 r
.81776 .28181 .82213 .28794 .83262 .28449 .82827 .27827 Metetra
0 .028 .127 r
.82827 .27827 .83262 .28449 .84314 .28103 .8388 .27457 Metetra
0 .027 .127 r
.8388 .27457 .84314 .28103 .85369 .27738 .84936 .2707 Metetra
0 .027 .126 r
.84936 .2707 .85369 .27738 .8643 .27391 .85997 .26706 Metetra
0 .027 .126 r
.25276 .46301 .25847 .46814 .26704 .46535 .26135 .46011 Metetra
0 .027 .126 r
.26135 .46011 .26704 .46535 .27562 .46279 .26996 .45742 Metetra
0 .028 .127 r
.26996 .45742 .27562 .46279 .28424 .46008 .27861 .45459 Metetra
0 .028 .128 r
.27861 .45459 .28424 .46008 .29291 .45721 .28729 .45168 Metetra
0 .028 .128 r
.28729 .45168 .29291 .45721 .3016 .4543 .29599 .44881 Metetra
0 .028 .128 r
.29599 .44881 .3016 .4543 .31033 .4513 .30473 .44592 Metetra
0 .028 .128 r
.30473 .44592 .31033 .4513 .31908 .44829 .31349 .44302 Metetra
0 .028 .128 r
.31349 .44302 .31908 .44829 .32786 .44538 .32228 .44015 Metetra
0 .029 .128 r
.32228 .44015 .32786 .44538 .33665 .44278 .33109 .4375 Metetra
0 .03 .13 r
.33109 .4375 .33665 .44278 .34547 .44015 .33994 .43472 Metetra
0 .031 .131 r
.33994 .43472 .34547 .44015 .35431 .43774 .3488 .43214 Metetra
0 .032 .133 r
.3488 .43214 .35431 .43774 .36318 .43522 .3577 .4295 Metetra
0 .034 .135 r
.3577 .4295 .36318 .43522 .37209 .43262 .36663 .42691 Metetra
0 .035 .136 r
.36663 .42691 .37209 .43262 .38106 .42959 .37561 .424 Metetra
0 .035 .136 r
.37561 .424 .38106 .42959 .39005 .42665 .3846 .42129 Metetra
0 .036 .137 r
.3846 .42129 .39005 .42665 .39907 .42371 .39363 .41847 Metetra
0 .036 .138 r
.39363 .41847 .39907 .42371 .40811 .42101 .40269 .4158 Metetra
0 .038 .14 r
.40269 .4158 .40811 .42101 .41717 .41864 .41178 .41328 Metetra
0 .041 .143 r
.41178 .41328 .41717 .41864 .42625 .41662 .42089 .41107 Metetra
0 .045 .148 r
.42089 .41107 .42625 .41662 .43537 .41492 .43002 .40915 Metetra
0 .05 .152 r
.43002 .40915 .43537 .41492 .44453 .41266 .43921 .40689 Metetra
0 .054 .156 r
.43921 .40689 .44453 .41266 .45373 .4106 .44842 .40501 Metetra
0 .058 .16 r
.44842 .40501 .45373 .4106 .46297 .40806 .45767 .40291 Metetra
0 .064 .166 r
.45767 .40291 .46297 .40806 .47223 .40669 .46694 .40204 Metetra
0 .073 .174 r
.46694 .40204 .47223 .40669 .48153 .40514 .47625 .40071 Metetra
0 .084 .183 r
.47625 .40071 .48153 .40514 .49086 .40445 .4856 .40037 Metetra
0 .099 .194 r
.4856 .40037 .49086 .40445 .50024 .4036 .49499 .40099 Metetra
0 .128 .215 r
.49499 .40099 .50024 .4036 .50966 .40443 .5044 .40763 Metetra
0 .206 .26 r
.5044 .40763 .50966 .40443 .51913 .41033 .51386 .42501 Metetra
0 .33 .298 r
.51386 .42501 .51913 .41033 .52868 .41923 .52347 .44948 Metetra
0 .404 .235 r
.52347 .44948 .52868 .41923 .53833 .42626 .53327 .46922 Metetra
0 .437 .192 r
.53327 .46922 .53833 .42626 .54801 .42316 .54311 .46614 Metetra
0 .404 .235 r
.54311 .46614 .54801 .42316 .55761 .40979 .55279 .44006 Metetra
0 .33 .298 r
.55279 .44006 .55761 .40979 .56716 .39446 .56231 .40911 Metetra
0 .205 .26 r
.56231 .40911 .56716 .39446 .57673 .38227 .57181 .38538 Metetra
0 .129 .215 r
.57181 .38538 .57673 .38227 .58636 .37509 .5814 .37232 Metetra
0 .099 .194 r
.5814 .37232 .58636 .37509 .59605 .36956 .59109 .36527 Metetra
0 .084 .183 r
.59109 .36527 .59605 .36956 .60575 .36387 .60081 .35919 Metetra
0 .073 .174 r
.60081 .35919 .60575 .36387 .6155 .35902 .61058 .35407 Metetra
0 .064 .166 r
.61058 .35407 .6155 .35902 .62526 .35405 .62036 .34856 Metetra
0 .058 .16 r
.62036 .34856 .62526 .35405 .63509 .35023 .6302 .34425 Metetra
0 .054 .156 r
.6302 .34425 .63509 .35023 .64494 .34593 .64006 .33973 Metetra
0 .05 .152 r
.64006 .33973 .64494 .34593 .65481 .34181 .64996 .33557 Metetra
0 .045 .148 r
.64996 .33557 .65481 .34181 .6647 .33711 .65988 .33105 Metetra
0 .041 .143 r
.65988 .33105 .6647 .33711 .67463 .33273 .66984 .32683 Metetra
0 .038 .14 r
.66984 .32683 .67463 .33273 .6846 .32871 .67985 .32291 Metetra
0 .036 .138 r
.67985 .32291 .6846 .32871 .69462 .32503 .6899 .31917 Metetra
0 .036 .137 r
.6899 .31917 .69462 .32503 .7047 .3216 .69999 .31557 Metetra
0 .035 .136 r
.69999 .31557 .7047 .3216 .71481 .31817 .71011 .31187 Metetra
0 .035 .136 r
.71011 .31187 .71481 .31817 .72496 .31483 .72027 .30836 Metetra
0 .034 .135 r
.72027 .30836 .72496 .31483 .73511 .31104 .73046 .30452 Metetra
0 .032 .133 r
.73046 .30452 .73511 .31104 .7453 .30715 .74067 .30071 Metetra
0 .031 .131 r
.74067 .30071 .7453 .30715 .75551 .30315 .75092 .29685 Metetra
0 .03 .13 r
.75092 .29685 .75551 .30315 .76577 .29937 .76122 .29317 Metetra
0 .029 .128 r
.76122 .29317 .76577 .29937 .77607 .29557 .77155 .28938 Metetra
0 .028 .128 r
.77155 .28938 .77607 .29557 .78643 .29207 .78193 .28581 Metetra
0 .028 .127 r
.78193 .28581 .78643 .29207 .79684 .28869 .79235 .28227 Metetra
0 .028 .128 r
.79235 .28227 .79684 .28869 .80728 .28529 .80281 .27872 Metetra
0 .028 .128 r
.80281 .27872 .80728 .28529 .81776 .28181 .81331 .27515 Metetra
0 .028 .128 r
.81331 .27515 .81776 .28181 .82827 .27827 .82385 .27161 Metetra
0 .028 .127 r
.82385 .27161 .82827 .27827 .8388 .27457 .83442 .26799 Metetra
0 .027 .126 r
.83442 .26799 .8388 .27457 .84936 .2707 .84501 .26421 Metetra
0 .027 .126 r
.84501 .26421 .84936 .2707 .85997 .26706 .85567 .26064 Metetra
0 .027 .126 r
.24701 .45786 .25276 .46301 .26135 .46011 .25563 .45483 Metetra
0 .027 .126 r
.25563 .45483 .26135 .46011 .26996 .45742 .26427 .45201 Metetra
0 .027 .127 r
.26427 .45201 .26996 .45742 .27861 .45459 .27294 .44905 Metetra
0 .027 .127 r
.27294 .44905 .27861 .45459 .28729 .45168 .28164 .4461 Metetra
0 .028 .127 r
.28164 .4461 .28729 .45168 .29599 .44881 .29035 .4433 Metetra
0 .028 .128 r
.29035 .4433 .29599 .44881 .30473 .44592 .29909 .44053 Metetra
0 .028 .128 r
.29909 .44053 .30473 .44592 .31349 .44302 .30787 .43774 Metetra
0 .029 .128 r
.30787 .43774 .31349 .44302 .32228 .44015 .31667 .4349 Metetra
0 .029 .129 r
.31667 .4349 .32228 .44015 .33109 .4375 .3255 .4322 Metetra
0 .03 .13 r
.3255 .4322 .33109 .4375 .33994 .43472 .33437 .42926 Metetra
0 .031 .131 r
.33437 .42926 .33994 .43472 .3488 .43214 .34327 .42648 Metetra
0 .032 .132 r
.34327 .42648 .3488 .43214 .3577 .4295 .35219 .42372 Metetra
0 .033 .134 r
.35219 .42372 .3577 .4295 .36663 .42691 .36113 .42115 Metetra
0 .034 .135 r
.36113 .42115 .36663 .42691 .37561 .424 .37012 .41839 Metetra
0 .035 .137 r
.37012 .41839 .37561 .424 .3846 .42129 .37912 .41592 Metetra
0 .037 .138 r
.37912 .41592 .3846 .42129 .39363 .41847 .38817 .41322 Metetra
0 .038 .139 r
.38817 .41322 .39363 .41847 .40269 .4158 .39725 .41053 Metetra
0 .039 .141 r
.39725 .41053 .40269 .4158 .41178 .41328 .40636 .40784 Metetra
0 .042 .144 r
.40636 .40784 .41178 .41328 .42089 .41107 .41549 .40537 Metetra
0 .045 .148 r
.41549 .40537 .42089 .41107 .43002 .40915 .42465 .40323 Metetra
0 .049 .151 r
.42465 .40323 .43002 .40915 .43921 .40689 .43385 .40096 Metetra
0 .053 .156 r
.43385 .40096 .43921 .40689 .44842 .40501 .44307 .39932 Metetra
0 .059 .161 r
.44307 .39932 .44842 .40501 .45767 .40291 .45233 .3977 Metetra
0 .068 .169 r
.45233 .3977 .45767 .40291 .46694 .40204 .46161 .3973 Metetra
0 .078 .178 r
.46161 .3973 .46694 .40204 .47625 .40071 .47094 .39609 Metetra
0 .091 .189 r
.47094 .39609 .47625 .40071 .4856 .40037 .48031 .39615 Metetra
0 .114 .205 r
.48031 .39615 .4856 .40037 .49499 .40099 .48969 .39915 Metetra
0 .177 .244 r
.48969 .39915 .49499 .40099 .5044 .40763 .49905 .41396 Metetra
0 .331 .298 r
.49905 .41396 .5044 .40763 .51386 .42501 .50845 .44694 Metetra
0 .464 .15 r
.50845 .44694 .51386 .42501 .52347 .44948 .51808 .49209 Metetra
.16 .6 0 r
.51808 .49209 .52347 .44948 .53327 .46922 .52802 .52813 Metetra
.349 .66 0 r
.52802 .52813 .53327 .46922 .54311 .46614 .53808 .52508 Metetra
.16 .6 0 r
.53808 .52508 .54311 .46614 .55279 .44006 .54791 .48273 Metetra
0 .464 .15 r
.54791 .48273 .55279 .44006 .56231 .40911 .55744 .43104 Metetra
0 .33 .298 r
.55744 .43104 .56231 .40911 .57181 .38538 .56687 .39163 Metetra
0 .177 .244 r
.56687 .39163 .57181 .38538 .5814 .37232 .5764 .37033 Metetra
0 .114 .205 r
.5764 .37033 .5814 .37232 .59109 .36527 .58608 .36083 Metetra
0 .091 .189 r
.58608 .36083 .59109 .36527 .60081 .35919 .59583 .35432 Metetra
0 .078 .178 r
.59583 .35432 .60081 .35919 .61058 .35407 .60563 .34903 Metetra
0 .068 .169 r
.60563 .34903 .61058 .35407 .62036 .34856 .61542 .34301 Metetra
0 .059 .161 r
.61542 .34301 .62036 .34856 .6302 .34425 .62527 .33818 Metetra
0 .054 .156 r
.62527 .33818 .6302 .34425 .64006 .33973 .63515 .33338 Metetra
0 .049 .152 r
.63515 .33338 .64006 .33973 .64996 .33557 .64508 .32916 Metetra
0 .045 .148 r
.64508 .32916 .64996 .33557 .65988 .33105 .65503 .32484 Metetra
0 .042 .144 r
.65503 .32484 .65988 .33105 .66984 .32683 .66503 .32084 Metetra
0 .039 .141 r
.66503 .32084 .66984 .32683 .67985 .32291 .67507 .31705 Metetra
0 .038 .139 r
.67507 .31705 .67985 .32291 .6899 .31917 .68514 .31329 Metetra
0 .037 .138 r
.68514 .31329 .6899 .31917 .69999 .31557 .69525 .30953 Metetra
0 .035 .137 r
.69525 .30953 .69999 .31557 .71011 .31187 .70538 .30555 Metetra
0 .034 .135 r
.70538 .30555 .71011 .31187 .72027 .30836 .71556 .30183 Metetra
0 .033 .134 r
.71556 .30183 .72027 .30836 .73046 .30452 .72577 .29793 Metetra
0 .032 .132 r
.72577 .29793 .73046 .30452 .74067 .30071 .73602 .2942 Metetra
0 .031 .131 r
.73602 .2942 .74067 .30071 .75092 .29685 .74631 .2905 Metetra
0 .03 .13 r
.74631 .2905 .75092 .29685 .76122 .29317 .75664 .28695 Metetra
0 .029 .129 r
.75664 .28695 .76122 .29317 .77155 .28938 .767 .28317 Metetra
0 .029 .128 r
.767 .28317 .77155 .28938 .78193 .28581 .7774 .27952 Metetra
0 .028 .128 r
.7774 .27952 .78193 .28581 .79235 .28227 .78784 .27582 Metetra
0 .028 .127 r
.78784 .27582 .79235 .28227 .80281 .27872 .79832 .27211 Metetra
0 .028 .127 r
.79832 .27211 .80281 .27872 .81331 .27515 .80883 .26843 Metetra
0 .027 .127 r
.80883 .26843 .81331 .27515 .82385 .27161 .8194 .26488 Metetra
0 .027 .127 r
.8194 .26488 .82385 .27161 .83442 .26799 .83001 .26135 Metetra
0 .027 .127 r
.83001 .26135 .83442 .26799 .84501 .26421 .84064 .25768 Metetra
0 .027 .126 r
.84064 .25768 .84501 .26421 .85567 .26064 .85134 .2542 Metetra
0 .027 .126 r
.24127 .45223 .24701 .45786 .25563 .45483 .24989 .44937 Metetra
0 .027 .127 r
.24989 .44937 .25563 .45483 .26427 .45201 .25852 .44671 Metetra
0 .028 .127 r
.25852 .44671 .26427 .45201 .27294 .44905 .2672 .4439 Metetra
0 .028 .127 r
.2672 .4439 .27294 .44905 .28164 .4461 .27592 .44094 Metetra
0 .028 .127 r
.27592 .44094 .28164 .4461 .29035 .4433 .28466 .43801 Metetra
0 .028 .128 r
.28466 .43801 .29035 .4433 .29909 .44053 .29343 .43499 Metetra
0 .028 .128 r
.29343 .43499 .29909 .44053 .30787 .43774 .30224 .43201 Metetra
0 .029 .128 r
.30224 .43201 .30787 .43774 .31667 .4349 .31107 .42908 Metetra
0 .029 .129 r
.31107 .42908 .31667 .4349 .3255 .4322 .3199 .42645 Metetra
0 .03 .13 r
.3199 .42645 .3255 .4322 .33437 .42926 .32878 .42368 Metetra
0 .031 .131 r
.32878 .42368 .33437 .42926 .34327 .42648 .33768 .42117 Metetra
0 .032 .133 r
.33768 .42117 .34327 .42648 .35219 .42372 .34661 .41852 Metetra
0 .033 .134 r
.34661 .41852 .35219 .42372 .36113 .42115 .35557 .41588 Metetra
0 .034 .135 r
.35557 .41588 .36113 .42115 .37012 .41839 .36459 .41284 Metetra
0 .035 .137 r
.36459 .41284 .37012 .41839 .37912 .41592 .37363 .41006 Metetra
0 .037 .138 r
.37363 .41006 .37912 .41592 .38817 .41322 .3827 .40714 Metetra
0 .038 .139 r
.3827 .40714 .38817 .41322 .39725 .41053 .39179 .40449 Metetra
0 .039 .141 r
.39179 .40449 .39725 .41053 .40636 .40784 .40091 .40201 Metetra
0 .042 .144 r
.40091 .40201 .40636 .40784 .41549 .40537 .41005 .39997 Metetra
0 .046 .148 r
.41005 .39997 .41549 .40537 .42465 .40323 .41922 .39808 Metetra
0 .05 .152 r
.41922 .39808 .42465 .40323 .43385 .40096 .42844 .39593 Metetra
0 .055 .157 r
.42844 .39593 .43385 .40096 .44307 .39932 .43768 .39403 Metetra
0 .06 .163 r
.43768 .39403 .44307 .39932 .45233 .3977 .44697 .39202 Metetra
0 .069 .171 r
.44697 .39202 .45233 .3977 .46161 .3973 .45627 .39111 Metetra
0 .08 .18 r
.45627 .39111 .46161 .3973 .47094 .39609 .46563 .38965 Metetra
0 .094 .191 r
.46563 .38965 .47094 .39609 .48031 .39615 .475 .39023 Metetra
0 .127 .214 r
.475 .39023 .48031 .39615 .48969 .39915 .48436 .39597 Metetra
0 .234 .274 r
.48436 .39597 .48969 .39915 .49905 .41396 .49364 .41825 Metetra
0 .404 .235 r
.49364 .41825 .49905 .41396 .50845 .44694 .50295 .46396 Metetra
.16 .6 0 r
.50295 .46396 .50845 .44694 .51808 .49209 .51253 .52546 Metetra
.796 .704 0 r
.51253 .52546 .51808 .49209 .52802 .52813 .52254 .57413 Metetra
.882 .451 0 r
.52254 .57413 .52802 .52813 .53808 .52508 .53278 .57109 Metetra
.796 .703 0 r
.53278 .57109 .53808 .52508 .54791 .48273 .54278 .51614 Metetra
.16 .6 0 r
.54278 .51614 .54791 .48273 .55744 .43104 .5524 .44806 Metetra
0 .404 .235 r
.5524 .44806 .55744 .43104 .56687 .39163 .56183 .39583 Metetra
0 .234 .274 r
.56183 .39583 .56687 .39163 .5764 .37033 .57134 .36699 Metetra
0 .127 .214 r
.57134 .36699 .5764 .37033 .58608 .36083 .58101 .35468 Metetra
0 .094 .191 r
.58101 .35468 .58608 .36083 .59583 .35432 .59078 .3476 Metetra
0 .08 .18 r
.59078 .3476 .59583 .35432 .60563 .34903 .6006 .34253 Metetra
0 .069 .171 r
.6006 .34253 .60563 .34903 .61542 .34301 .61044 .33698 Metetra
0 .06 .163 r
.61044 .33698 .61542 .34301 .62527 .33818 .62033 .3325 Metetra
0 .055 .157 r
.62033 .3325 .62527 .33818 .63515 .33338 .63024 .32791 Metetra
0 .05 .152 r
.63024 .32791 .63515 .33338 .64508 .32916 .64019 .32355 Metetra
0 .046 .148 r
.64019 .32355 .64508 .32916 .65503 .32484 .65016 .31892 Metetra
0 .042 .144 r
.65016 .31892 .65503 .32484 .66503 .32084 .66016 .31444 Metetra
0 .039 .141 r
.66016 .31444 .66503 .32084 .67507 .31705 .67022 .31041 Metetra
0 .038 .139 r
.67022 .31041 .67507 .31705 .68514 .31329 .68031 .30655 Metetra
0 .037 .138 r
.68031 .30655 .68514 .31329 .69525 .30953 .69045 .30298 Metetra
0 .035 .137 r
.69045 .30298 .69525 .30953 .70538 .30555 .70063 .29927 Metetra
0 .034 .136 r
.70063 .29927 .70538 .30555 .71556 .30183 .71085 .2958 Metetra
0 .033 .134 r
.71085 .2958 .71556 .30183 .72577 .29793 .72109 .29192 Metetra
0 .032 .133 r
.72109 .29192 .72577 .29793 .73602 .2942 .73136 .28805 Metetra
0 .031 .131 r
.73136 .28805 .73602 .2942 .74631 .2905 .74165 .28402 Metetra
0 .03 .13 r
.74165 .28402 .74631 .2905 .75664 .28695 .752 .28026 Metetra
0 .029 .129 r
.752 .28026 .75664 .28695 .767 .28317 .76237 .27636 Metetra
0 .029 .128 r
.76237 .27636 .767 .28317 .7774 .27952 .77281 .27276 Metetra
0 .028 .128 r
.77281 .27276 .7774 .27952 .78784 .27582 .78329 .26923 Metetra
0 .028 .128 r
.78329 .26923 .78784 .27582 .79832 .27211 .79381 .26572 Metetra
0 .028 .127 r
.79381 .26572 .79832 .27211 .80883 .26843 .80437 .26213 Metetra
0 .028 .127 r
.80437 .26213 .80883 .26843 .8194 .26488 .81496 .25856 Metetra
0 .028 .127 r
.81496 .25856 .8194 .26488 .83001 .26135 .82558 .25483 Metetra
0 .027 .127 r
.82558 .25483 .83001 .26135 .84064 .25768 .83623 .25094 Metetra
0 .027 .126 r
.83623 .25094 .84064 .25768 .85134 .2542 .84693 .24724 Metetra
0 .027 .126 r
.23547 .44683 .24127 .45223 .24989 .44937 .2441 .44395 Metetra
0 .027 .127 r
.2441 .44395 .24989 .44937 .25852 .44671 .25276 .44127 Metetra
0 .028 .127 r
.25276 .44127 .25852 .44671 .2672 .4439 .26145 .43844 Metetra
0 .028 .128 r
.26145 .43844 .2672 .4439 .27592 .44094 .27018 .43547 Metetra
0 .028 .128 r
.27018 .43547 .27592 .44094 .28466 .43801 .27894 .43253 Metetra
0 .028 .128 r
.27894 .43253 .28466 .43801 .29343 .43499 .28773 .4295 Metetra
0 .028 .128 r
.28773 .4295 .29343 .43499 .30224 .43201 .29656 .42649 Metetra
0 .028 .128 r
.29656 .42649 .30224 .43201 .31107 .42908 .3054 .42354 Metetra
0 .029 .129 r
.3054 .42354 .31107 .42908 .3199 .42645 .31426 .42088 Metetra
0 .03 .13 r
.31426 .42088 .3199 .42645 .32878 .42368 .32315 .41809 Metetra
0 .031 .131 r
.32315 .41809 .32878 .42368 .33768 .42117 .33206 .41557 Metetra
0 .033 .133 r
.33206 .41557 .33768 .42117 .34661 .41852 .34102 .4129 Metetra
0 .034 .135 r
.34102 .4129 .34661 .41852 .35557 .41588 .35 .41026 Metetra
0 .035 .136 r
.35 .41026 .35557 .41588 .36459 .41284 .35903 .4072 Metetra
0 .035 .136 r
.35903 .4072 .36459 .41284 .37363 .41006 .36809 .4044 Metetra
0 .036 .137 r
.36809 .4044 .37363 .41006 .3827 .40714 .37718 .40145 Metetra
0 .037 .139 r
.37718 .40145 .3827 .40714 .39179 .40449 .38629 .39877 Metetra
0 .039 .141 r
.38629 .39877 .39179 .40449 .40091 .40201 .39543 .39627 Metetra
0 .042 .144 r
.39543 .39627 .40091 .40201 .41005 .39997 .40458 .39421 Metetra
0 .047 .149 r
.40458 .39421 .41005 .39997 .41922 .39808 .41377 .39231 Metetra
0 .051 .154 r
.41377 .39231 .41922 .39808 .42844 .39593 .42301 .39015 Metetra
0 .056 .158 r
.42301 .39015 .42844 .39593 .43768 .39403 .43227 .38825 Metetra
0 .061 .163 r
.43227 .38825 .43768 .39403 .44697 .39202 .44158 .38622 Metetra
0 .069 .17 r
.44158 .38622 .44697 .39202 .45627 .39111 .4509 .38529 Metetra
0 .079 .179 r
.4509 .38529 .45627 .39111 .46563 .38965 .46027 .38379 Metetra
0 .093 .19 r
.46027 .38379 .46563 .38965 .475 .39023 .46965 .38434 Metetra
0 .131 .216 r
.46965 .38434 .475 .39023 .48436 .39597 .47902 .39005 Metetra
0 .261 .287 r
.47902 .39005 .48436 .39597 .49364 .41825 .48828 .41235 Metetra
0 .437 .192 r
.48828 .41235 .49364 .41825 .50295 .46396 .49753 .4581 Metetra
.348 .66 0 r
.49753 .4581 .50295 .46396 .51253 .52546 .50703 .51969 Metetra
.882 .452 0 r
.50703 .51969 .51253 .52546 .52254 .57413 .51698 .56845 Metetra
.978 .091 0 r
.51698 .56845 .52254 .57413 .53278 .57109 .52724 .56539 Metetra
.882 .451 0 r
.52724 .56539 .53278 .57109 .54278 .51614 .53735 .5103 Metetra
.348 .66 0 r
.53735 .5103 .54278 .51614 .5524 .44806 .54709 .4421 Metetra
0 .437 .192 r
.54709 .4421 .5524 .44806 .56183 .39583 .55663 .38978 Metetra
0 .261 .287 r
.55663 .38978 .56183 .39583 .57134 .36699 .5662 .36088 Metetra
0 .131 .216 r
.5662 .36088 .57134 .36699 .58101 .35468 .57591 .34856 Metetra
0 .093 .19 r
.57591 .34856 .58101 .35468 .59078 .3476 .58571 .34146 Metetra
0 .079 .179 r
.58571 .34146 .59078 .3476 .6006 .34253 .59556 .33639 Metetra
0 .069 .17 r
.59556 .33639 .6006 .34253 .61044 .33698 .60542 .33082 Metetra
0 .061 .163 r
.60542 .33082 .61044 .33698 .62033 .3325 .61533 .32632 Metetra
0 .056 .158 r
.61533 .32632 .62033 .3325 .63024 .32791 .62527 .3217 Metetra
0 .051 .154 r
.62527 .3217 .63024 .32791 .64019 .32355 .63525 .31729 Metetra
0 .047 .149 r
.63525 .31729 .64019 .32355 .65016 .31892 .64524 .31263 Metetra
0 .042 .144 r
.64524 .31263 .65016 .31892 .66016 .31444 .65527 .30813 Metetra
0 .039 .141 r
.65527 .30813 .66016 .31444 .67022 .31041 .66535 .30408 Metetra
0 .037 .139 r
.66535 .30408 .67022 .31041 .68031 .30655 .67547 .30021 Metetra
0 .036 .137 r
.67547 .30021 .68031 .30655 .69045 .30298 .68564 .29662 Metetra
0 .035 .137 r
.68564 .29662 .69045 .30298 .70063 .29927 .69584 .2929 Metetra
0 .035 .136 r
.69584 .2929 .70063 .29927 .71085 .2958 .70609 .2894 Metetra
0 .034 .135 r
.70609 .2894 .71085 .2958 .72109 .29192 .71635 .28549 Metetra
0 .033 .133 r
.71635 .28549 .72109 .29192 .73136 .28805 .72664 .28158 Metetra
0 .031 .131 r
.72664 .28158 .73136 .28805 .74165 .28402 .73697 .27753 Metetra
0 .03 .13 r
.73697 .27753 .74165 .28402 .752 .28026 .74734 .27374 Metetra
0 .029 .129 r
.74734 .27374 .752 .28026 .76237 .27636 .75774 .26983 Metetra
0 .028 .128 r
.75774 .26983 .76237 .27636 .77281 .27276 .76821 .26621 Metetra
0 .028 .128 r
.76821 .26621 .77281 .27276 .78329 .26923 .77871 .26265 Metetra
0 .028 .128 r
.77871 .26265 .78329 .26923 .79381 .26572 .78926 .25913 Metetra
0 .028 .128 r
.78926 .25913 .79381 .26572 .80437 .26213 .79984 .25551 Metetra
0 .028 .128 r
.79984 .25551 .80437 .26213 .81496 .25856 .81047 .2519 Metetra
0 .028 .127 r
.81047 .2519 .81496 .25856 .82558 .25483 .82112 .24815 Metetra
0 .027 .127 r
.82112 .24815 .82558 .25483 .83623 .25094 .83179 .24423 Metetra
0 .027 .126 r
.83179 .24423 .83623 .25094 .84693 .24724 .84252 .24051 Metetra
0 .027 .126 r
.2296 .44167 .23547 .44683 .2441 .44395 .23828 .43858 Metetra
0 .027 .127 r
.23828 .43858 .2441 .44395 .25276 .44127 .24696 .4357 Metetra
0 .028 .127 r
.24696 .4357 .25276 .44127 .26145 .43844 .25568 .43269 Metetra
0 .028 .127 r
.25568 .43269 .26145 .43844 .27018 .43547 .26443 .42969 Metetra
0 .028 .127 r
.26443 .42969 .27018 .43547 .27894 .43253 .2732 .42683 Metetra
0 .028 .128 r
.2732 .42683 .27894 .43253 .28773 .4295 .282 .42401 Metetra
0 .028 .128 r
.282 .42401 .28773 .4295 .29656 .42649 .29082 .42116 Metetra
0 .029 .128 r
.29082 .42116 .29656 .42649 .3054 .42354 .29968 .41827 Metetra
0 .029 .129 r
.29968 .41827 .3054 .42354 .31426 .42088 .30856 .41551 Metetra
0 .03 .13 r
.30856 .41551 .31426 .42088 .32315 .41809 .31749 .41252 Metetra
0 .031 .131 r
.31749 .41252 .32315 .41809 .33206 .41557 .32643 .40968 Metetra
0 .032 .133 r
.32643 .40968 .33206 .41557 .34102 .4129 .33541 .40687 Metetra
0 .033 .134 r
.33541 .40687 .34102 .4129 .35 .41026 .34441 .40425 Metetra
0 .034 .135 r
.34441 .40425 .35 .41026 .35903 .4072 .35345 .40143 Metetra
0 .035 .137 r
.35345 .40143 .35903 .4072 .36809 .4044 .3625 .3989 Metetra
0 .037 .138 r
.3625 .3989 .36809 .4044 .37718 .40145 .3716 .39615 Metetra
0 .038 .139 r
.3716 .39615 .37718 .40145 .38629 .39877 .38074 .39339 Metetra
0 .039 .141 r
.38074 .39339 .38629 .39877 .39543 .39627 .3899 .39065 Metetra
0 .042 .144 r
.3899 .39065 .39543 .39627 .40458 .39421 .3991 .38812 Metetra
0 .046 .148 r
.3991 .38812 .40458 .39421 .41377 .39231 .40831 .38593 Metetra
0 .05 .152 r
.40831 .38593 .41377 .39231 .42301 .39015 .41757 .38361 Metetra
0 .055 .157 r
.41757 .38361 .42301 .39015 .43227 .38825 .42684 .38192 Metetra
0 .061 .163 r
.42684 .38192 .43227 .38825 .44158 .38622 .43615 .38024 Metetra
0 .069 .171 r
.43615 .38024 .44158 .38622 .4509 .38529 .44547 .37979 Metetra
0 .08 .18 r
.44547 .37979 .4509 .38529 .46027 .38379 .45486 .37853 Metetra
0 .094 .191 r
.45486 .37853 .46027 .38379 .46965 .38434 .46427 .37853 Metetra
0 .126 .214 r
.46427 .37853 .46965 .38434 .47902 .39005 .47369 .38149 Metetra
0 .234 .274 r
.47369 .38149 .47902 .39005 .48828 .41235 .48302 .39632 Metetra
0 .404 .235 r
.48302 .39632 .48828 .41235 .49753 .4581 .49231 .42939 Metetra
.16 .6 0 r
.49231 .42939 .49753 .4581 .50703 .51969 .50176 .47471 Metetra
.796 .704 0 r
.50176 .47471 .50703 .51969 .51698 .56845 .51158 .51087 Metetra
.882 .451 0 r
.51158 .51087 .51698 .56845 .52724 .56539 .52171 .50776 Metetra
.796 .704 0 r
.52171 .50776 .52724 .56539 .53735 .5103 .5318 .46516 Metetra
.159 .6 0 r
.5318 .46516 .53735 .5103 .54709 .4421 .54163 .41318 Metetra
0 .404 .235 r
.54163 .41318 .54709 .4421 .55663 .38978 .55131 .37354 Metetra
0 .234 .274 r
.55131 .37354 .55663 .38978 .5662 .36088 .561 .35211 Metetra
0 .127 .214 r
.561 .35211 .5662 .36088 .57591 .34856 .57078 .34252 Metetra
0 .094 .191 r
.57078 .34252 .57591 .34856 .58571 .34146 .58061 .33593 Metetra
0 .08 .18 r
.58061 .33593 .58571 .34146 .59556 .33639 .59048 .33057 Metetra
0 .069 .171 r
.59048 .33057 .59556 .33639 .60542 .33082 .60036 .32448 Metetra
0 .061 .163 r
.60036 .32448 .60542 .33082 .61533 .32632 .61029 .31958 Metetra
0 .055 .157 r
.61029 .31958 .61533 .32632 .62527 .3217 .62025 .3147 Metetra
0 .05 .152 r
.62025 .3147 .62527 .3217 .63525 .31729 .63025 .31041 Metetra
0 .046 .148 r
.63025 .31041 .63525 .31729 .64524 .31263 .64028 .30601 Metetra
0 .042 .144 r
.64028 .30601 .64524 .31263 .65527 .30813 .65035 .30194 Metetra
0 .039 .141 r
.65035 .30194 .65527 .30813 .66535 .30408 .66047 .29809 Metetra
0 .038 .139 r
.66047 .29809 .66535 .30408 .67547 .30021 .67062 .29426 Metetra
0 .037 .138 r
.67062 .29426 .67547 .30021 .68564 .29662 .6808 .29043 Metetra
0 .035 .137 r
.6808 .29043 .68564 .29662 .69584 .2929 .69101 .28638 Metetra
0 .034 .136 r
.69101 .28638 .69584 .2929 .70609 .2894 .70127 .2826 Metetra
0 .033 .134 r
.70127 .2826 .70609 .2894 .71635 .28549 .71155 .27862 Metetra
0 .032 .133 r
.71155 .27862 .71635 .28549 .72664 .28158 .72188 .27482 Metetra
0 .031 .131 r
.72188 .27482 .72664 .28158 .73697 .27753 .73225 .27104 Metetra
0 .03 .13 r
.73225 .27104 .73697 .27753 .74734 .27374 .74267 .26742 Metetra
0 .029 .129 r
.74267 .26742 .74734 .27374 .75774 .26983 .75311 .26357 Metetra
0 .029 .128 r
.75311 .26357 .75774 .26983 .76821 .26621 .76359 .25985 Metetra
0 .028 .128 r
.76359 .25985 .76821 .26621 .77871 .26265 .77411 .25609 Metetra
0 .028 .128 r
.77411 .25609 .77871 .26265 .78926 .25913 .78467 .2523 Metetra
0 .028 .127 r
.78467 .2523 .78926 .25913 .79984 .25551 .79527 .24854 Metetra
0 .028 .127 r
.79527 .24854 .79984 .25551 .81047 .2519 .80592 .24492 Metetra
0 .028 .127 r
.80592 .24492 .81047 .2519 .82112 .24815 .81661 .24132 Metetra
0 .027 .127 r
.81661 .24132 .82112 .24815 .83179 .24423 .82733 .23757 Metetra
0 .027 .126 r
.82733 .23757 .83179 .24423 .84252 .24051 .83811 .23402 Metetra
0 .027 .126 r
.22375 .43602 .2296 .44167 .23828 .43858 .23243 .43303 Metetra
0 .027 .127 r
.23243 .43303 .23828 .43858 .24696 .4357 .24112 .43026 Metetra
0 .027 .127 r
.24112 .43026 .24696 .4357 .25568 .43269 .24985 .42733 Metetra
0 .027 .127 r
.24985 .42733 .25568 .43269 .26443 .42969 .25861 .42432 Metetra
0 .028 .127 r
.25861 .42432 .26443 .42969 .2732 .42683 .26741 .42136 Metetra
0 .028 .127 r
.26741 .42136 .2732 .42683 .282 .42401 .27623 .41837 Metetra
0 .028 .128 r
.27623 .41837 .282 .42401 .29082 .42116 .28508 .41538 Metetra
0 .029 .128 r
.28508 .41538 .29082 .42116 .29968 .41827 .29396 .41243 Metetra
0 .029 .129 r
.29396 .41243 .29968 .41827 .30856 .41551 .30285 .4097 Metetra
0 .03 .13 r
.30285 .4097 .30856 .41551 .31749 .41252 .31179 .40684 Metetra
0 .031 .131 r
.31179 .40684 .31749 .41252 .32643 .40968 .32074 .40416 Metetra
0 .032 .132 r
.32074 .40416 .32643 .40968 .33541 .40687 .32973 .40142 Metetra
0 .033 .134 r
.32973 .40142 .33541 .40687 .34441 .40425 .33875 .39872 Metetra
0 .034 .135 r
.33875 .39872 .34441 .40425 .35345 .40143 .34782 .3957 Metetra
0 .035 .137 r
.34782 .3957 .35345 .40143 .3625 .3989 .35691 .3929 Metetra
0 .037 .138 r
.35691 .3929 .3625 .3989 .3716 .39615 .36603 .39 Metetra
0 .038 .139 r
.36603 .39 .3716 .39615 .38074 .39339 .37518 .38725 Metetra
0 .039 .141 r
.37518 .38725 .38074 .39339 .3899 .39065 .38436 .38466 Metetra
0 .042 .144 r
.38436 .38466 .3899 .39065 .3991 .38812 .39356 .38235 Metetra
0 .045 .148 r
.39356 .38235 .3991 .38812 .40831 .38593 .40278 .38034 Metetra
0 .049 .151 r
.40278 .38034 .40831 .38593 .41757 .38361 .41206 .37796 Metetra
0 .053 .156 r
.41206 .37796 .41757 .38361 .42684 .38192 .42136 .37597 Metetra
0 .059 .161 r
.42136 .37597 .42684 .38192 .43615 .38024 .43071 .37376 Metetra
0 .068 .169 r
.43071 .37376 .43615 .38024 .44547 .37979 .44006 .37281 Metetra
0 .078 .178 r
.44006 .37281 .44547 .37979 .45486 .37853 .44946 .37141 Metetra
0 .091 .189 r
.44946 .37141 .45486 .37853 .46427 .37853 .45889 .37102 Metetra
0 .114 .205 r
.45889 .37102 .46427 .37853 .47369 .38149 .46835 .37159 Metetra
0 .177 .244 r
.46835 .37159 .47369 .38149 .48302 .39632 .47778 .37822 Metetra
0 .331 .298 r
.47778 .37822 .48302 .39632 .49231 .42939 .48718 .39565 Metetra
0 .464 .15 r
.48718 .39565 .49231 .42939 .50176 .47471 .49667 .42023 Metetra
.16 .6 0 r
.49667 .42023 .50176 .47471 .51158 .51087 .50639 .44003 Metetra
.349 .66 0 r
.50639 .44003 .51158 .51087 .52171 .50776 .51635 .43684 Metetra
.16 .6 0 r
.51635 .43684 .52171 .50776 .5318 .46516 .52634 .4105 Metetra
0 .464 .15 r
.52634 .4105 .5318 .46516 .54163 .41318 .5362 .37923 Metetra
0 .331 .298 r
.5362 .37923 .54163 .41318 .55131 .37354 .54597 .35523 Metetra
0 .177 .244 r
.54597 .35523 .55131 .37354 .561 .35211 .55575 .34198 Metetra
0 .114 .205 r
.55575 .34198 .561 .35211 .57078 .34252 .56559 .33477 Metetra
0 .091 .189 r
.56559 .33477 .57078 .34252 .58061 .33593 .57545 .32853 Metetra
0 .078 .178 r
.57545 .32853 .58061 .33593 .59048 .33057 .58535 .32326 Metetra
0 .068 .169 r
.58535 .32326 .59048 .33057 .60036 .32448 .59526 .31763 Metetra
0 .059 .161 r
.59526 .31763 .60036 .32448 .61029 .31958 .60523 .31321 Metetra
0 .054 .156 r
.60523 .31321 .61029 .31958 .62025 .3147 .61522 .3086 Metetra
0 .049 .152 r
.61522 .3086 .62025 .3147 .63025 .31041 .62525 .30434 Metetra
0 .045 .148 r
.62525 .30434 .63025 .31041 .64028 .30601 .6353 .29971 Metetra
0 .042 .144 r
.6353 .29971 .64028 .30601 .65035 .30194 .64539 .29537 Metetra
0 .039 .141 r
.64539 .29537 .65035 .30194 .66047 .29809 .65552 .29132 Metetra
0 .038 .139 r
.65552 .29132 .66047 .29809 .67062 .29426 .6657 .28744 Metetra
0 .037 .138 r
.6657 .28744 .67062 .29426 .6808 .29043 .67591 .28372 Metetra
0 .035 .137 r
.67591 .28372 .6808 .29043 .69101 .28638 .68616 .2799 Metetra
0 .034 .135 r
.68616 .2799 .69101 .28638 .70127 .2826 .69645 .27628 Metetra
0 .033 .134 r
.69645 .27628 .70127 .2826 .71155 .27862 .70677 .27234 Metetra
0 .032 .132 r
.70677 .27234 .71155 .27862 .72188 .27482 .71712 .26843 Metetra
0 .031 .131 r
.71712 .26843 .72188 .27482 .73225 .27104 .7275 .26444 Metetra
0 .03 .13 r
.7275 .26444 .73225 .27104 .74267 .26742 .73793 .26064 Metetra
0 .029 .129 r
.73793 .26064 .74267 .26742 .75311 .26357 .74839 .25671 Metetra
0 .029 .128 r
.74839 .25671 .75311 .26357 .76359 .25985 .75891 .25301 Metetra
0 .028 .128 r
.75891 .25301 .76359 .25985 .77411 .25609 .76947 .24935 Metetra
0 .028 .127 r
.76947 .24935 .77411 .25609 .78467 .2523 .78006 .24569 Metetra
0 .028 .127 r
.78006 .24569 .78467 .2523 .79527 .24854 .7907 .242 Metetra
0 .027 .127 r
.7907 .242 .79527 .24854 .80592 .24492 .80138 .23835 Metetra
0 .027 .127 r
.80138 .23835 .80592 .24492 .81661 .24132 .81209 .23461 Metetra
0 .027 .127 r
.81209 .23461 .81661 .24132 .82733 .23757 .82282 .23071 Metetra
0 .027 .126 r
.82282 .23071 .82733 .23757 .83811 .23402 .83362 .22701 Metetra
0 .027 .126 r
.21785 .43035 .22375 .43602 .23243 .43303 .22654 .42743 Metetra
0 .027 .126 r
.22654 .42743 .23243 .43303 .24112 .43026 .23524 .42474 Metetra
0 .028 .127 r
.23524 .42474 .24112 .43026 .24985 .42733 .24398 .42191 Metetra
0 .028 .128 r
.24398 .42191 .24985 .42733 .25861 .42432 .25276 .41892 Metetra
0 .028 .128 r
.25276 .41892 .25861 .42432 .26741 .42136 .26157 .41587 Metetra
0 .028 .128 r
.26157 .41587 .26741 .42136 .27623 .41837 .27042 .41275 Metetra
0 .028 .128 r
.27042 .41275 .27623 .41837 .28508 .41538 .2793 .40961 Metetra
0 .028 .128 r
.2793 .40961 .28508 .41538 .29396 .41243 .28821 .40657 Metetra
0 .029 .128 r
.28821 .40657 .29396 .41243 .30285 .4097 .29712 .40384 Metetra
0 .03 .13 r
.29712 .40384 .30285 .4097 .31179 .40684 .30606 .40108 Metetra
0 .031 .131 r
.30606 .40108 .31179 .40684 .32074 .40416 .31502 .39854 Metetra
0 .032 .133 r
.31502 .39854 .32074 .40416 .32973 .40142 .32402 .3959 Metetra
0 .034 .135 r
.32402 .3959 .32973 .40142 .33875 .39872 .33306 .39317 Metetra
0 .035 .136 r
.33306 .39317 .33875 .39872 .34782 .3957 .34215 .39 Metetra
0 .035 .136 r
.34215 .39 .34782 .3957 .35691 .3929 .35127 .38693 Metetra
0 .036 .137 r
.35127 .38693 .35691 .3929 .36603 .39 .36042 .38386 Metetra
0 .036 .138 r
.36042 .38386 .36603 .39 .37518 .38725 .36959 .38103 Metetra
0 .038 .14 r
.36959 .38103 .37518 .38725 .38436 .38466 .37878 .37852 Metetra
0 .041 .143 r
.37878 .37852 .38436 .38466 .39356 .38235 .38799 .37637 Metetra
0 .045 .148 r
.38799 .37637 .39356 .38235 .40278 .38034 .39723 .37455 Metetra
0 .05 .152 r
.39723 .37455 .40278 .38034 .41206 .37796 .40652 .37216 Metetra
0 .054 .156 r
.40652 .37216 .41206 .37796 .42136 .37597 .41585 .36997 Metetra
0 .058 .16 r
.41585 .36997 .42136 .37597 .43071 .37376 .42523 .3673 Metetra
0 .064 .166 r
.42523 .3673 .43071 .37376 .44006 .37281 .43461 .36581 Metetra
0 .073 .174 r
.43461 .36581 .44006 .37281 .44946 .37141 .44403 .36413 Metetra
0 .084 .183 r
.44403 .36413 .44946 .37141 .45889 .37102 .45348 .36332 Metetra
0 .099 .194 r
.45348 .36332 .45889 .37102 .46835 .37159 .46299 .36235 Metetra
0 .129 .215 r
.46299 .36235 .46835 .37159 .47778 .37822 .47251 .36307 Metetra
0 .206 .26 r
.47251 .36307 .47778 .37822 .48718 .39565 .48202 .3689 Metetra
0 .331 .298 r
.48202 .3689 .48718 .39565 .49667 .42023 .49158 .37777 Metetra
0 .404 .235 r
.49158 .37777 .49667 .42023 .50639 .44003 .50127 .38476 Metetra
0 .437 .192 r
.50127 .38476 .50639 .44003 .51635 .43684 .5111 .38151 Metetra
0 .404 .235 r
.5111 .38151 .51635 .43684 .52634 .4105 .52098 .36789 Metetra
0 .33 .298 r
.52098 .36789 .52634 .4105 .5362 .37923 .53083 .3523 Metetra
0 .206 .26 r
.53083 .3523 .5362 .37923 .54597 .35523 .54065 .33987 Metetra
0 .129 .215 r
.54065 .33987 .54597 .35523 .55575 .34198 .5505 .33251 Metetra
0 .099 .194 r
.5505 .33251 .55575 .34198 .56559 .33477 .56037 .32682 Metetra
0 .084 .183 r
.56037 .32682 .56559 .33477 .57545 .32853 .57026 .32096 Metetra
0 .073 .173 r
.57026 .32096 .57545 .32853 .58535 .32326 .58018 .31594 Metetra
0 .064 .166 r
.58018 .31594 .58535 .32326 .59526 .31763 .59013 .31079 Metetra
0 .058 .16 r
.59013 .31079 .59526 .31763 .60523 .31321 .60013 .30681 Metetra
0 .054 .156 r
.60013 .30681 .60523 .31321 .61522 .3086 .61015 .30235 Metetra
0 .05 .152 r
.61015 .30235 .61522 .3086 .62525 .30434 .62021 .29805 Metetra
0 .045 .148 r
.62021 .29805 .62525 .30434 .6353 .29971 .63028 .29318 Metetra
0 .041 .143 r
.63028 .29318 .6353 .29971 .64539 .29537 .64039 .28864 Metetra
0 .038 .14 r
.64039 .28864 .64539 .29537 .65552 .29132 .65054 .28446 Metetra
0 .036 .138 r
.65054 .28446 .65552 .29132 .6657 .28744 .66074 .28063 Metetra
0 .036 .137 r
.66074 .28063 .6657 .28744 .67591 .28372 .67099 .27703 Metetra
0 .035 .136 r
.67099 .27703 .67591 .28372 .68616 .2799 .68128 .27344 Metetra
0 .035 .136 r
.68128 .27344 .68616 .2799 .69645 .27628 .69161 .26993 Metetra
0 .034 .135 r
.69161 .26993 .69645 .27628 .70677 .27234 .70195 .26598 Metetra
0 .032 .133 r
.70195 .26598 .70677 .27234 .71712 .26843 .71232 .26192 Metetra
0 .031 .131 r
.71232 .26192 .71712 .26843 .7275 .26444 .72272 .25775 Metetra
0 .03 .13 r
.72272 .25775 .7275 .26444 .73793 .26064 .73317 .2538 Metetra
0 .029 .128 r
.73317 .2538 .73793 .26064 .74839 .25671 .74365 .24983 Metetra
0 .028 .128 r
.74365 .24983 .74839 .25671 .75891 .25301 .7542 .24618 Metetra
0 .028 .127 r
.7542 .24618 .75891 .25301 .76947 .24935 .76479 .24262 Metetra
0 .028 .128 r
.76479 .24262 .76947 .24935 .78006 .24569 .77543 .23906 Metetra
0 .028 .128 r
.77543 .23906 .78006 .24569 .7907 .242 .7861 .23541 Metetra
0 .028 .128 r
.7861 .23541 .7907 .242 .80138 .23835 .7968 .23169 Metetra
0 .028 .127 r
.7968 .23169 .80138 .23835 .81209 .23461 .80753 .22781 Metetra
0 .027 .126 r
.80753 .22781 .81209 .23461 .82282 .23071 .81828 .22377 Metetra
0 .027 .126 r
.81828 .22377 .82282 .23071 .83362 .22701 .8291 .21996 Metetra
0 .027 .126 r
.21188 .42511 .21785 .43035 .22654 .42743 .2206 .42202 Metetra
0 .027 .126 r
.2206 .42202 .22654 .42743 .23524 .42474 .22933 .41914 Metetra
0 .028 .127 r
.22933 .41914 .23524 .42474 .24398 .42191 .2381 .41607 Metetra
0 .028 .127 r
.2381 .41607 .24398 .42191 .25276 .41892 .24691 .413 Metetra
0 .028 .127 r
.24691 .413 .25276 .41892 .26157 .41587 .25574 .40995 Metetra
0 .028 .127 r
.25574 .40995 .26157 .41587 .27042 .41275 .26459 .40703 Metetra
0 .028 .127 r
.26459 .40703 .27042 .41275 .2793 .40961 .27347 .40407 Metetra
0 .028 .128 r
.27347 .40407 .2793 .40961 .28821 .40657 .28238 .40117 Metetra
0 .029 .129 r
.28238 .40117 .28821 .40657 .29712 .40384 .29131 .39841 Metetra
0 .03 .13 r
.29131 .39841 .29712 .40384 .30606 .40108 .30027 .39554 Metetra
0 .031 .131 r
.30027 .39554 .30606 .40108 .31502 .39854 .30927 .39265 Metetra
0 .032 .133 r
.30927 .39265 .31502 .39854 .32402 .3959 .31831 .38978 Metetra
0 .033 .134 r
.31831 .38978 .32402 .3959 .33306 .39317 .32737 .3869 Metetra
0 .034 .135 r
.32737 .3869 .33306 .39317 .34215 .39 .33647 .38388 Metetra
0 .034 .136 r
.33647 .38388 .34215 .39 .35127 .38693 .3456 .381 Metetra
0 .035 .136 r
.3456 .381 .35127 .38693 .36042 .38386 .35475 .37825 Metetra
0 .036 .138 r
.35475 .37825 .36042 .38386 .36959 .38103 .36394 .37549 Metetra
0 .038 .14 r
.36394 .37549 .36959 .38103 .37878 .37852 .37315 .37296 Metetra
0 .041 .143 r
.37315 .37296 .37878 .37852 .38799 .37637 .38239 .37035 Metetra
0 .045 .147 r
.38239 .37035 .38799 .37637 .39723 .37455 .39166 .36813 Metetra
0 .048 .151 r
.39166 .36813 .39723 .37455 .40652 .37216 .40099 .36524 Metetra
0 .051 .154 r
.40099 .36524 .40652 .37216 .41585 .36997 .41034 .36288 Metetra
0 .055 .157 r
.41034 .36288 .41585 .36997 .42523 .3673 .41973 .36026 Metetra
0 .06 .162 r
.41973 .36026 .42523 .3673 .43461 .36581 .42912 .35895 Metetra
0 .068 .17 r
.42912 .35895 .43461 .36581 .44403 .36413 .43855 .35766 Metetra
0 .078 .178 r
.43855 .35766 .44403 .36413 .45348 .36332 .44802 .35676 Metetra
0 .09 .188 r
.44802 .35676 .45348 .36332 .46299 .36235 .45754 .35532 Metetra
0 .103 .197 r
.45754 .35532 .46299 .36235 .47251 .36307 .46713 .35304 Metetra
0 .129 .215 r
.46713 .35304 .47251 .36307 .48202 .3689 .47672 .35298 Metetra
0 .177 .244 r
.47672 .35298 .48202 .3689 .49158 .37777 .48636 .35361 Metetra
0 .234 .274 r
.48636 .35361 .49158 .37777 .50127 .38476 .49607 .35303 Metetra
0 .262 .287 r
.49607 .35303 .50127 .38476 .5111 .38151 .50585 .34974 Metetra
0 .234 .274 r
.50585 .34974 .5111 .38151 .52098 .36789 .51567 .34362 Metetra
0 .177 .244 r
.51567 .34362 .52098 .36789 .53083 .3523 .5255 .33625 Metetra
0 .129 .215 r
.5255 .33625 .53083 .3523 .54065 .33987 .53535 .32967 Metetra
0 .103 .197 r
.53535 .32967 .54065 .33987 .5505 .33251 .54523 .32526 Metetra
0 .09 .188 r
.54523 .32526 .5505 .33251 .56037 .32682 .55513 .32003 Metetra
0 .079 .178 r
.55513 .32003 .56037 .32682 .57026 .32096 .56505 .3142 Metetra
0 .068 .17 r
.56505 .3142 .57026 .32096 .58018 .31594 .57499 .30874 Metetra
0 .06 .162 r
.57499 .30874 .58018 .31594 .59013 .31079 .58496 .30336 Metetra
0 .055 .157 r
.58496 .30336 .59013 .31079 .60013 .30681 .59498 .29928 Metetra
0 .051 .154 r
.59498 .29928 .60013 .30681 .61015 .30235 .60503 .29495 Metetra
0 .048 .151 r
.60503 .29495 .61015 .30235 .62021 .29805 .61512 .29112 Metetra
0 .045 .147 r
.61512 .29112 .62021 .29805 .63028 .29318 .62523 .28663 Metetra
0 .041 .143 r
.62523 .28663 .63028 .29318 .64039 .28864 .63538 .2825 Metetra
0 .038 .14 r
.63538 .2825 .64039 .28864 .65054 .28446 .64556 .2783 Metetra
0 .036 .138 r
.64556 .2783 .65054 .28446 .66074 .28063 .65578 .27433 Metetra
0 .035 .136 r
.65578 .27433 .66074 .28063 .67099 .27703 .66604 .27037 Metetra
0 .034 .136 r
.66604 .27037 .67099 .27703 .68128 .27344 .67634 .26654 Metetra
0 .034 .135 r
.67634 .26654 .68128 .27344 .69161 .26993 .68669 .26284 Metetra
0 .033 .134 r
.68669 .26284 .69161 .26993 .70195 .26598 .69706 .259 Metetra
0 .032 .133 r
.69706 .259 .70195 .26598 .71232 .26192 .70747 .25514 Metetra
0 .031 .131 r
.70747 .25514 .71232 .26192 .72272 .25775 .71792 .25128 Metetra
0 .03 .13 r
.71792 .25128 .72272 .25775 .73317 .2538 .7284 .2474 Metetra
0 .029 .129 r
.7284 .2474 .73317 .2538 .74365 .24983 .73892 .24341 Metetra
0 .028 .128 r
.73892 .24341 .74365 .24983 .7542 .24618 .74948 .23956 Metetra
0 .028 .127 r
.74948 .23956 .7542 .24618 .76479 .24262 .76008 .23578 Metetra
0 .028 .127 r
.76008 .23578 .76479 .24262 .77543 .23906 .77073 .23196 Metetra
0 .028 .127 r
.77073 .23196 .77543 .23906 .7861 .23541 .78142 .22827 Metetra
0 .028 .127 r
.78142 .22827 .7861 .23541 .7968 .23169 .79216 .22459 Metetra
0 .028 .127 r
.79216 .22459 .7968 .23169 .80753 .22781 .80294 .22091 Metetra
0 .027 .127 r
.80294 .22091 .80753 .22781 .81828 .22377 .81374 .21703 Metetra
0 .027 .126 r
.81374 .21703 .81828 .22377 .8291 .21996 .8246 .21335 Metetra
0 .027 .126 r
.2059 .41952 .21188 .42511 .2206 .42202 .21464 .41641 Metetra
0 .027 .127 r
.21464 .41641 .2206 .42202 .22933 .41914 .22338 .41351 Metetra
0 .027 .127 r
.22338 .41351 .22933 .41914 .2381 .41607 .23217 .41042 Metetra
0 .027 .127 r
.23217 .41042 .2381 .41607 .24691 .413 .24099 .40734 Metetra
0 .027 .127 r
.24099 .40734 .24691 .413 .25574 .40995 .24984 .40424 Metetra
0 .027 .127 r
.24984 .40424 .25574 .40995 .26459 .40703 .25871 .40132 Metetra
0 .028 .127 r
.25871 .40132 .26459 .40703 .27347 .40407 .26761 .39832 Metetra
0 .028 .128 r
.26761 .39832 .27347 .40407 .28238 .40117 .27654 .39543 Metetra
0 .029 .129 r
.27654 .39543 .28238 .40117 .29131 .39841 .28548 .39263 Metetra
0 .03 .13 r
.28548 .39263 .29131 .39841 .30027 .39554 .29447 .38978 Metetra
0 .031 .131 r
.29447 .38978 .30027 .39554 .30927 .39265 .30349 .38684 Metetra
0 .032 .132 r
.30349 .38684 .30927 .39265 .31831 .38978 .31254 .38395 Metetra
0 .033 .133 r
.31254 .38395 .31831 .38978 .32737 .3869 .32162 .381 Metetra
0 .033 .134 r
.32162 .381 .32737 .3869 .33647 .38388 .33074 .37797 Metetra
0 .034 .135 r
.33074 .37797 .33647 .38388 .3456 .381 .33989 .37497 Metetra
0 .035 .136 r
.33989 .37497 .3456 .381 .35475 .37825 .34906 .37224 Metetra
0 .037 .138 r
.34906 .37224 .35475 .37825 .36394 .37549 .35827 .36943 Metetra
0 .038 .14 r
.35827 .36943 .36394 .37549 .37315 .37296 .36749 .36692 Metetra
0 .041 .143 r
.36749 .36692 .37315 .37296 .38239 .37035 .37676 .36417 Metetra
0 .044 .146 r
.37676 .36417 .38239 .37035 .39166 .36813 .38605 .36189 Metetra
0 .046 .148 r
.38605 .36189 .39166 .36813 .40099 .36524 .39541 .35884 Metetra
0 .048 .151 r
.39541 .35884 .40099 .36524 .41034 .36288 .40477 .35634 Metetra
0 .051 .154 r
.40477 .35634 .41034 .36288 .41973 .36026 .41419 .35359 Metetra
0 .056 .159 r
.41419 .35359 .41973 .36026 .42912 .35895 .4236 .35197 Metetra
0 .064 .166 r
.4236 .35197 .42912 .35895 .43855 .35766 .43305 .3505 Metetra
0 .074 .174 r
.43305 .3505 .43855 .35766 .44802 .35676 .44255 .34901 Metetra
0 .083 .182 r
.44255 .34901 .44802 .35676 .45754 .35532 .45209 .34741 Metetra
0 .09 .188 r
.45209 .34741 .45754 .35532 .46713 .35304 .4617 .34462 Metetra
0 .099 .195 r
.4617 .34462 .46713 .35304 .47672 .35298 .47133 .34303 Metetra
0 .114 .205 r
.47133 .34303 .47672 .35298 .48636 .35361 .481 .34126 Metetra
0 .127 .214 r
.481 .34126 .48636 .35361 .49607 .35303 .49074 .33785 Metetra
0 .131 .217 r
.49074 .33785 .49607 .35303 .50585 .34974 .50051 .33452 Metetra
0 .127 .214 r
.50051 .33452 .50585 .34974 .51567 .34362 .51032 .33118 Metetra
0 .114 .205 r
.51032 .33118 .51567 .34362 .5255 .33625 .52016 .3262 Metetra
0 .099 .194 r
.52016 .3262 .5255 .33625 .53535 .32967 .53003 .32108 Metetra
0 .09 .188 r
.53003 .32108 .53535 .32967 .54523 .32526 .53993 .31713 Metetra
0 .084 .183 r
.53993 .31713 .54523 .32526 .55513 .32003 .54985 .31202 Metetra
0 .074 .175 r
.54985 .31202 .55513 .32003 .56505 .3142 .5598 .30674 Metetra
0 .064 .166 r
.5598 .30674 .56505 .3142 .57499 .30874 .56977 .30143 Metetra
0 .056 .158 r
.56977 .30143 .57499 .30874 .58496 .30336 .57976 .29631 Metetra
0 .051 .154 r
.57976 .29631 .58496 .30336 .59498 .29928 .58981 .2923 Metetra
0 .048 .151 r
.58981 .2923 .59498 .29928 .60503 .29495 .59988 .28808 Metetra
0 .046 .149 r
.59988 .28808 .60503 .29495 .61512 .29112 .61 .28437 Metetra
0 .044 .146 r
.61 .28437 .61512 .29112 .62523 .28663 .62014 .2799 Metetra
0 .041 .143 r
.62014 .2799 .62523 .28663 .63538 .2825 .63032 .27586 Metetra
0 .038 .14 r
.63032 .27586 .63538 .2825 .64556 .2783 .64052 .2716 Metetra
0 .036 .138 r
.64052 .2716 .64556 .2783 .65578 .27433 .65077 .26763 Metetra
0 .035 .136 r
.65077 .26763 .65578 .27433 .66604 .27037 .66105 .26361 Metetra
0 .034 .135 r
.66105 .26361 .66604 .27037 .67634 .26654 .67139 .25985 Metetra
0 .033 .134 r
.67139 .25985 .67634 .26654 .68669 .26284 .68175 .25612 Metetra
0 .033 .133 r
.68175 .25612 .68669 .26284 .69706 .259 .69216 .2523 Metetra
0 .032 .132 r
.69216 .2523 .69706 .259 .70747 .25514 .70259 .24841 Metetra
0 .031 .131 r
.70259 .24841 .70747 .25514 .71792 .25128 .71307 .24457 Metetra
0 .03 .13 r
.71307 .24457 .71792 .25128 .7284 .2474 .72358 .24062 Metetra
0 .029 .129 r
.72358 .24062 .7284 .2474 .73892 .24341 .73412 .23663 Metetra
0 .028 .128 r
.73412 .23663 .73892 .24341 .74948 .23956 .74471 .23273 Metetra
0 .028 .127 r
.74471 .23273 .74948 .23956 .76008 .23578 .75535 .22894 Metetra
0 .027 .127 r
.75535 .22894 .76008 .23578 .77073 .23196 .76602 .22508 Metetra
0 .027 .127 r
.76602 .22508 .77073 .23196 .78142 .22827 .77674 .22139 Metetra
0 .027 .127 r
.77674 .22139 .78142 .22827 .79216 .22459 .7875 .21768 Metetra
0 .027 .127 r
.7875 .21768 .79216 .22459 .80294 .22091 .79831 .21397 Metetra
0 .027 .127 r
.79831 .21397 .80294 .22091 .81374 .21703 .80914 .21007 Metetra
0 .027 .126 r
.80914 .21007 .81374 .21703 .8246 .21335 .82003 .20637 Metetra
0 .027 .126 r
.1999 .41366 .2059 .41952 .21464 .41641 .20866 .41054 Metetra
0 .027 .126 r
.20866 .41054 .21464 .41641 .22338 .41351 .21741 .40773 Metetra
0 .027 .127 r
.21741 .40773 .22338 .41351 .23217 .41042 .2262 .40481 Metetra
0 .027 .127 r
.2262 .40481 .23217 .41042 .24099 .40734 .23503 .40186 Metetra
0 .028 .127 r
.23503 .40186 .24099 .40734 .24984 .40424 .24389 .39878 Metetra
0 .028 .127 r
.24389 .39878 .24984 .40424 .25871 .40132 .25278 .39576 Metetra
0 .028 .127 r
.25278 .39576 .25871 .40132 .26761 .39832 .26172 .39256 Metetra
0 .028 .128 r
.26172 .39256 .26761 .39832 .27654 .39543 .27067 .38947 Metetra
0 .029 .128 r
.27067 .38947 .27654 .39543 .28548 .39263 .27965 .38651 Metetra
0 .03 .13 r
.27965 .38651 .28548 .39263 .29447 .38978 .28864 .38366 Metetra
0 .03 .131 r
.28864 .38366 .29447 .38978 .30349 .38684 .29767 .38086 Metetra
0 .032 .132 r
.29767 .38086 .30349 .38684 .31254 .38395 .30672 .37819 Metetra
0 .033 .134 r
.30672 .37819 .31254 .38395 .32162 .381 .31581 .37539 Metetra
0 .034 .134 r
.31581 .37539 .32162 .381 .33074 .37797 .32495 .37238 Metetra
0 .034 .135 r
.32495 .37238 .33074 .37797 .33989 .37497 .33414 .36915 Metetra
0 .035 .136 r
.33414 .36915 .33989 .37497 .34906 .37224 .34334 .36617 Metetra
0 .036 .137 r
.34334 .36617 .34906 .37224 .35827 .36943 .35258 .36305 Metetra
0 .037 .139 r
.35258 .36305 .35827 .36943 .36749 .36692 .36183 .36036 Metetra
0 .039 .141 r
.36183 .36036 .36749 .36692 .37676 .36417 .37112 .35753 Metetra
0 .042 .144 r
.37112 .35753 .37676 .36417 .38605 .36189 .38042 .35536 Metetra
0 .045 .147 r
.38042 .35536 .38605 .36189 .39541 .35884 .38978 .35252 Metetra
0 .047 .149 r
.38978 .35252 .39541 .35884 .40477 .35634 .39916 .35018 Metetra
0 .05 .152 r
.39916 .35018 .40477 .35634 .41419 .35359 .40859 .34752 Metetra
0 .054 .157 r
.40859 .34752 .41419 .35359 .4236 .35197 .41803 .34557 Metetra
0 .061 .163 r
.41803 .34557 .4236 .35197 .43305 .3505 .42751 .34367 Metetra
0 .067 .169 r
.42751 .34367 .43305 .3505 .44255 .34901 .43705 .34114 Metetra
0 .074 .175 r
.43705 .34114 .44255 .34901 .45209 .34741 .44662 .33893 Metetra
0 .079 .179 r
.44662 .33893 .45209 .34741 .4617 .34462 .45625 .33603 Metetra
0 .084 .183 r
.45625 .33603 .4617 .34462 .47133 .34303 .46589 .33401 Metetra
0 .091 .189 r
.46589 .33401 .47133 .34303 .481 .34126 .47559 .33185 Metetra
0 .094 .191 r
.47559 .33185 .481 .34126 .49074 .33785 .48534 .32784 Metetra
0 .093 .19 r
.48534 .32784 .49074 .33785 .50051 .33452 .49512 .32446 Metetra
0 .094 .191 r
.49512 .32446 .50051 .33452 .51032 .33118 .50494 .3217 Metetra
0 .091 .189 r
.50494 .3217 .51032 .33118 .52016 .3262 .51479 .31709 Metetra
0 .084 .183 r
.51479 .31709 .52016 .3262 .53003 .32108 .52468 .31231 Metetra
0 .079 .179 r
.52468 .31231 .53003 .32108 .53993 .31713 .5346 .30843 Metetra
0 .074 .175 r
.5346 .30843 .53993 .31713 .54985 .31202 .54454 .30389 Metetra
0 .068 .169 r
.54454 .30389 .54985 .31202 .5598 .30674 .55452 .29962 Metetra
0 .061 .163 r
.55452 .29962 .5598 .30674 .56977 .30143 .56452 .29471 Metetra
0 .054 .156 r
.56452 .29471 .56977 .30143 .57976 .29631 .57454 .28985 Metetra
0 .05 .152 r
.57454 .28985 .57976 .29631 .58981 .2923 .58461 .28571 Metetra
0 .047 .149 r
.58461 .28571 .58981 .2923 .59988 .28808 .59471 .28128 Metetra
0 .045 .147 r
.59471 .28128 .59988 .28808 .61 .28437 .60485 .27732 Metetra
0 .042 .144 r
.60485 .27732 .61 .28437 .62014 .2799 .615 .27269 Metetra
0 .039 .141 r
.615 .27269 .62014 .2799 .63032 .27586 .62521 .26869 Metetra
0 .037 .139 r
.62521 .26869 .63032 .27586 .64052 .2716 .63544 .26457 Metetra
0 .036 .137 r
.63544 .26457 .64052 .2716 .65077 .26763 .64573 .26087 Metetra
0 .035 .136 r
.64573 .26087 .65077 .26763 .66105 .26361 .65605 .25706 Metetra
0 .034 .135 r
.65605 .25706 .66105 .26361 .67139 .25985 .66641 .25348 Metetra
0 .034 .134 r
.66641 .25348 .67139 .25985 .68175 .25612 .67681 .24969 Metetra
0 .033 .134 r
.67681 .24969 .68175 .25612 .69216 .2523 .68723 .24567 Metetra
0 .032 .132 r
.68723 .24567 .69216 .2523 .70259 .24841 .69768 .24152 Metetra
0 .031 .131 r
.69768 .24152 .70259 .24841 .71307 .24457 .70817 .23748 Metetra
0 .03 .13 r
.70817 .23748 .71307 .24457 .72358 .24062 .71871 .23349 Metetra
0 .029 .128 r
.71871 .23349 .72358 .24062 .73412 .23663 .72929 .22961 Metetra
0 .028 .128 r
.72929 .22961 .73412 .23663 .74471 .23273 .73991 .22588 Metetra
0 .028 .127 r
.73991 .22588 .74471 .23273 .75535 .22894 .75059 .22224 Metetra
0 .028 .127 r
.75059 .22224 .75535 .22894 .76602 .22508 .7613 .21844 Metetra
0 .027 .127 r
.7613 .21844 .76602 .22508 .77674 .22139 .77205 .21468 Metetra
0 .027 .127 r
.77205 .21468 .77674 .22139 .7875 .21768 .78283 .2108 Metetra
0 .027 .127 r
.78283 .2108 .7875 .21768 .79831 .21397 .79364 .20687 Metetra
0 .027 .126 r
.79364 .20687 .79831 .21397 .80914 .21007 .80449 .20283 Metetra
0 .027 .126 r
.80449 .20283 .80914 .21007 .82003 .20637 .81541 .19909 Metetra
0 .027 .126 r
.19383 .4082 .1999 .41366 .20866 .41054 .2026 .40504 Metetra
0 .027 .126 r
.2026 .40504 .20866 .41054 .21741 .40773 .21138 .40213 Metetra
0 .027 .126 r
.21138 .40213 .21741 .40773 .2262 .40481 .2202 .39902 Metetra
0 .027 .127 r
.2202 .39902 .2262 .40481 .23503 .40186 .22905 .39594 Metetra
0 .027 .127 r
.22905 .39594 .23503 .40186 .24389 .39878 .23795 .39273 Metetra
0 .028 .127 r
.23795 .39273 .24389 .39878 .25278 .39576 .24685 .38978 Metetra
0 .028 .127 r
.24685 .38978 .25278 .39576 .26172 .39256 .25579 .38669 Metetra
0 .028 .127 r
.25579 .38669 .26172 .39256 .27067 .38947 .26475 .38377 Metetra
0 .028 .128 r
.26475 .38377 .27067 .38947 .27965 .38651 .27373 .38088 Metetra
0 .029 .129 r
.27373 .38088 .27965 .38651 .28864 .38366 .28274 .37811 Metetra
0 .03 .131 r
.28274 .37811 .28864 .38366 .29767 .38086 .2918 .37509 Metetra
0 .031 .132 r
.2918 .37509 .29767 .38086 .30672 .37819 .30088 .3722 Metetra
0 .033 .133 r
.30088 .3722 .30672 .37819 .31581 .37539 .31001 .36909 Metetra
0 .033 .134 r
.31001 .36909 .31581 .37539 .32495 .37238 .31917 .36602 Metetra
0 .033 .134 r
.31917 .36602 .32495 .37238 .33414 .36915 .32837 .36275 Metetra
0 .034 .135 r
.32837 .36275 .33414 .36915 .34334 .36617 .33758 .36001 Metetra
0 .035 .136 r
.33758 .36001 .34334 .36617 .35258 .36305 .34682 .35709 Metetra
0 .037 .138 r
.34682 .35709 .35258 .36305 .36183 .36036 .35608 .35459 Metetra
0 .038 .14 r
.35608 .35459 .36183 .36036 .37112 .35753 .3654 .35164 Metetra
0 .041 .143 r
.3654 .35164 .37112 .35753 .38042 .35536 .37473 .34918 Metetra
0 .043 .145 r
.37473 .34918 .38042 .35536 .38978 .35252 .38413 .34598 Metetra
0 .045 .147 r
.38413 .34598 .38978 .35252 .39916 .35018 .39354 .34323 Metetra
0 .048 .15 r
.39354 .34323 .39916 .35018 .40859 .34752 .40299 .3405 Metetra
0 .051 .154 r
.40299 .3405 .40859 .34752 .41803 .34557 .41246 .33814 Metetra
0 .057 .159 r
.41246 .33814 .41803 .34557 .42751 .34367 .42196 .33613 Metetra
0 .061 .163 r
.42196 .33613 .42751 .34367 .43705 .34114 .43153 .33313 Metetra
0 .065 .166 r
.43153 .33313 .43705 .34114 .44662 .33893 .44111 .33074 Metetra
0 .068 .17 r
.44111 .33074 .44662 .33893 .45625 .33603 .45075 .32822 Metetra
0 .073 .174 r
.45075 .32822 .45625 .33603 .46589 .33401 .46041 .32593 Metetra
0 .079 .179 r
.46041 .32593 .46589 .33401 .47559 .33185 .47012 .32365 Metetra
0 .08 .18 r
.47012 .32365 .47559 .33185 .48534 .32784 .47989 .31985 Metetra
0 .079 .179 r
.47989 .31985 .48534 .32784 .49512 .32446 .48969 .31642 Metetra
0 .08 .18 r
.48969 .31642 .49512 .32446 .50494 .3217 .49952 .31342 Metetra
0 .079 .179 r
.49952 .31342 .50494 .3217 .51479 .31709 .5094 .30892 Metetra
0 .073 .174 r
.5094 .30892 .51479 .31709 .52468 .31231 .5193 .30434 Metetra
0 .068 .17 r
.5193 .30434 .52468 .31231 .5346 .30843 .52924 .30002 Metetra
0 .065 .166 r
.52924 .30002 .5346 .30843 .54454 .30389 .5392 .29562 Metetra
0 .061 .163 r
.5392 .29562 .54454 .30389 .55452 .29962 .5492 .29177 Metetra
0 .057 .159 r
.5492 .29177 .55452 .29962 .56452 .29471 .55922 .28695 Metetra
0 .051 .154 r
.55922 .28695 .56452 .29471 .57454 .28985 .56928 .28244 Metetra
0 .048 .15 r
.56928 .28244 .57454 .28985 .58461 .28571 .57937 .27833 Metetra
0 .045 .147 r
.57937 .27833 .58461 .28571 .59471 .28128 .5895 .27426 Metetra
0 .043 .145 r
.5895 .27426 .59471 .28128 .60485 .27732 .59967 .27062 Metetra
0 .041 .143 r
.59967 .27062 .60485 .27732 .615 .27269 .60985 .26625 Metetra
0 .038 .14 r
.60985 .26625 .615 .27269 .62521 .26869 .62009 .26233 Metetra
0 .037 .138 r
.62009 .26233 .62521 .26869 .63544 .26457 .63034 .25796 Metetra
0 .035 .136 r
.63034 .25796 .63544 .26457 .64573 .26087 .64065 .25401 Metetra
0 .034 .135 r
.64065 .25401 .64573 .26087 .65605 .25706 .65098 .24991 Metetra
0 .033 .134 r
.65098 .24991 .65605 .25706 .66641 .25348 .66137 .24632 Metetra
0 .033 .134 r
.66137 .24632 .66641 .25348 .67681 .24969 .67179 .24255 Metetra
0 .033 .133 r
.67179 .24255 .67681 .24969 .68723 .24567 .68226 .2388 Metetra
0 .032 .132 r
.68226 .2388 .68723 .24567 .69768 .24152 .69275 .23483 Metetra
0 .03 .131 r
.69275 .23483 .69768 .24152 .70817 .23748 .70328 .23098 Metetra
0 .029 .129 r
.70328 .23098 .70817 .23748 .71871 .23349 .71384 .22686 Metetra
0 .028 .128 r
.71384 .22686 .71871 .23349 .72929 .22961 .72444 .22286 Metetra
0 .028 .127 r
.72444 .22286 .72929 .22961 .73991 .22588 .73508 .2189 Metetra
0 .028 .127 r
.73508 .2189 .73991 .22588 .75059 .22224 .74577 .21511 Metetra
0 .028 .127 r
.74577 .21511 .75059 .22224 .7613 .21844 .7565 .21119 Metetra
0 .027 .127 r
.7565 .21119 .7613 .21844 .77205 .21468 .76728 .20752 Metetra
0 .027 .127 r
.76728 .20752 .77205 .21468 .78283 .2108 .7781 .20371 Metetra
0 .027 .127 r
.7781 .20371 .78283 .2108 .79364 .20687 .78896 .19994 Metetra
0 .027 .126 r
.78896 .19994 .79364 .20687 .80449 .20283 .79985 .19596 Metetra
0 .027 .126 r
.79985 .19596 .80449 .20283 .81541 .19909 .8108 .19222 Metetra
0 .027 .126 r
.18772 .40261 .19383 .4082 .2026 .40504 .19651 .39947 Metetra
0 .027 .126 r
.19651 .39947 .2026 .40504 .21138 .40213 .20531 .39651 Metetra
0 .027 .127 r
.20531 .39651 .21138 .40213 .2202 .39902 .21416 .39328 Metetra
0 .027 .126 r
.21416 .39328 .2202 .39902 .22905 .39594 .22304 .3901 Metetra
0 .027 .126 r
.22304 .3901 .22905 .39594 .23795 .39273 .23196 .38675 Metetra
0 .027 .126 r
.23196 .38675 .23795 .39273 .24685 .38978 .24087 .38379 Metetra
0 .027 .127 r
.24087 .38379 .24685 .38978 .25579 .38669 .24983 .38073 Metetra
0 .028 .127 r
.24983 .38073 .25579 .38669 .26475 .38377 .25879 .37793 Metetra
0 .029 .129 r
.25879 .37793 .26475 .38377 .27373 .38088 .26779 .37511 Metetra
0 .03 .13 r
.26779 .37511 .27373 .38088 .28274 .37811 .27681 .37245 Metetra
0 .031 .131 r
.27681 .37245 .28274 .37811 .2918 .37509 .28589 .36932 Metetra
0 .032 .132 r
.28589 .36932 .2918 .37509 .30088 .3722 .295 .36629 Metetra
0 .032 .132 r
.295 .36629 .30088 .3722 .31001 .36909 .30417 .36293 Metetra
0 .032 .133 r
.30417 .36293 .31001 .36909 .31917 .36602 .31335 .35976 Metetra
0 .032 .133 r
.31335 .35976 .31917 .36602 .32837 .36275 .32257 .35638 Metetra
0 .033 .134 r
.32257 .35638 .32837 .36275 .33758 .36001 .33179 .3537 Metetra
0 .034 .135 r
.33179 .3537 .33758 .36001 .34682 .35709 .34105 .35089 Metetra
0 .037 .138 r
.34105 .35089 .34682 .35709 .35608 .35459 .35032 .34851 Metetra
0 .039 .14 r
.35032 .34851 .35608 .35459 .3654 .35164 .35965 .34558 Metetra
0 .041 .143 r
.35965 .34558 .3654 .35164 .37473 .34918 .36901 .34294 Metetra
0 .042 .144 r
.36901 .34294 .37473 .34918 .38413 .34598 .37842 .3397 Metetra
0 .043 .145 r
.37842 .3397 .38413 .34598 .39354 .34323 .38787 .3367 Metetra
0 .045 .147 r
.38787 .3367 .39354 .34323 .40299 .3405 .39733 .33393 Metetra
0 .048 .15 r
.39733 .33393 .40299 .3405 .41246 .33814 .40684 .33105 Metetra
0 .051 .154 r
.40684 .33105 .41246 .33814 .42196 .33613 .41637 .32862 Metetra
0 .054 .157 r
.41637 .32862 .42196 .33613 .43153 .33313 .42597 .32528 Metetra
0 .056 .159 r
.42597 .32528 .43153 .33313 .44111 .33074 .43558 .32256 Metetra
0 .06 .162 r
.43558 .32256 .44111 .33074 .45075 .32822 .44522 .32021 Metetra
0 .064 .166 r
.44522 .32021 .45075 .32822 .46041 .32593 .45491 .31737 Metetra
0 .068 .169 r
.45491 .31737 .46041 .32593 .47012 .32365 .46464 .31458 Metetra
0 .069 .171 r
.46464 .31458 .47012 .32365 .47989 .31985 .47442 .31124 Metetra
0 .069 .17 r
.47442 .31124 .47989 .31985 .48969 .31642 .48423 .30778 Metetra
0 .069 .171 r
.48423 .30778 .48969 .31642 .49952 .31342 .49408 .30427 Metetra
0 .068 .169 r
.49408 .30427 .49952 .31342 .5094 .30892 .50397 .30023 Metetra
0 .064 .166 r
.50397 .30023 .5094 .30892 .5193 .30434 .51389 .29616 Metetra
0 .06 .162 r
.51389 .29616 .5193 .30434 .52924 .30002 .52385 .29162 Metetra
0 .056 .159 r
.52385 .29162 .52924 .30002 .5392 .29562 .53383 .28748 Metetra
0 .054 .157 r
.53383 .28748 .5392 .29562 .5492 .29177 .54385 .28396 Metetra
0 .051 .154 r
.54385 .28396 .5492 .29177 .55922 .28695 .5539 .27952 Metetra
0 .048 .15 r
.5539 .27952 .55922 .28695 .56928 .28244 .56398 .27549 Metetra
0 .045 .147 r
.56398 .27549 .56928 .28244 .57937 .27833 .5741 .27136 Metetra
0 .043 .145 r
.5741 .27136 .57937 .27833 .5895 .27426 .58426 .26749 Metetra
0 .042 .144 r
.58426 .26749 .5895 .27426 .59967 .27062 .59445 .26384 Metetra
0 .041 .143 r
.59445 .26384 .59967 .27062 .60985 .26625 .60467 .25961 Metetra
0 .039 .14 r
.60467 .25961 .60985 .26625 .62009 .26233 .61493 .25563 Metetra
0 .037 .138 r
.61493 .25563 .62009 .26233 .63034 .25796 .6252 .2511 Metetra
0 .034 .135 r
.6252 .2511 .63034 .25796 .64065 .25401 .63553 .24699 Metetra
0 .033 .134 r
.63553 .24699 .64065 .25401 .65098 .24991 .64588 .24278 Metetra
0 .032 .133 r
.64588 .24278 .65098 .24991 .66137 .24632 .6563 .23925 Metetra
0 .032 .133 r
.6563 .23925 .66137 .24632 .67179 .24255 .66676 .23554 Metetra
0 .032 .133 r
.66676 .23554 .67179 .24255 .68226 .2388 .67726 .232 Metetra
0 .032 .132 r
.67726 .232 .68226 .2388 .69275 .23483 .68778 .22814 Metetra
0 .031 .131 r
.68778 .22814 .69275 .23483 .70328 .23098 .69835 .22434 Metetra
0 .03 .13 r
.69835 .22434 .70328 .23098 .71384 .22686 .70892 .22007 Metetra
0 .029 .129 r
.70892 .22007 .71384 .22686 .72444 .22286 .71955 .21595 Metetra
0 .028 .127 r
.71955 .21595 .72444 .22286 .73508 .2189 .73021 .21182 Metetra
0 .027 .126 r
.73021 .21182 .73508 .2189 .74577 .21511 .74093 .20795 Metetra
0 .027 .126 r
.74093 .20795 .74577 .21511 .7565 .21119 .75168 .20399 Metetra
0 .027 .126 r
.75168 .20399 .7565 .21119 .76728 .20752 .7625 .20042 Metetra
0 .027 .126 r
.7625 .20042 .76728 .20752 .7781 .20371 .77335 .19667 Metetra
0 .027 .127 r
.77335 .19667 .7781 .20371 .78896 .19994 .78425 .19298 Metetra
0 .027 .126 r
.78425 .19298 .78896 .19994 .79985 .19596 .79517 .189 Metetra
0 .027 .126 r
.79517 .189 .79985 .19596 .8108 .19222 .80615 .18519 Metetra
0 .027 .126 r
.1816 .39681 .18772 .40261 .19651 .39947 .19042 .39349 Metetra
0 .027 .126 r
.19042 .39349 .19651 .39947 .20531 .39651 .19924 .39047 Metetra
0 .027 .126 r
.19924 .39047 .20531 .39651 .21416 .39328 .2081 .38728 Metetra
0 .027 .126 r
.2081 .38728 .21416 .39328 .22304 .3901 .21698 .38425 Metetra
0 .027 .126 r
.21698 .38425 .22304 .3901 .23196 .38675 .2259 .38103 Metetra
0 .027 .126 r
.2259 .38103 .23196 .38675 .24087 .38379 .23482 .37819 Metetra
0 .027 .127 r
.23482 .37819 .24087 .38379 .24983 .38073 .2438 .3751 Metetra
0 .028 .127 r
.2438 .3751 .24983 .38073 .25879 .37793 .25279 .37219 Metetra
0 .029 .129 r
.25279 .37219 .25879 .37793 .26779 .37511 .26182 .36912 Metetra
0 .03 .13 r
.26182 .36912 .26779 .37511 .27681 .37245 .27087 .36627 Metetra
0 .031 .131 r
.27087 .36627 .27681 .37245 .28589 .36932 .27998 .36297 Metetra
0 .031 .131 r
.27998 .36297 .28589 .36932 .295 .36629 .28911 .35996 Metetra
0 .031 .132 r
.28911 .35996 .295 .36629 .30417 .36293 .29828 .35672 Metetra
0 .031 .132 r
.29828 .35672 .30417 .36293 .31335 .35976 .30746 .35379 Metetra
0 .032 .132 r
.30746 .35379 .31335 .35976 .32257 .35638 .3167 .35054 Metetra
0 .033 .133 r
.3167 .35054 .32257 .35638 .33179 .3537 .32593 .34794 Metetra
0 .034 .135 r
.32593 .34794 .33179 .3537 .34105 .35089 .33521 .34499 Metetra
0 .036 .138 r
.33521 .34499 .34105 .35089 .35032 .34851 .34452 .34231 Metetra
0 .038 .14 r
.34452 .34231 .35032 .34851 .35965 .34558 .35389 .33899 Metetra
0 .039 .141 r
.35389 .33899 .35965 .34558 .36901 .34294 .36328 .33592 Metetra
0 .04 .142 r
.36328 .33592 .36901 .34294 .37842 .3397 .37272 .33269 Metetra
0 .041 .143 r
.37272 .33269 .37842 .3397 .38787 .3367 .38218 .32968 Metetra
0 .043 .145 r
.38218 .32968 .38787 .3367 .39733 .33393 .39165 .32717 Metetra
0 .045 .147 r
.39165 .32717 .39733 .33393 .40684 .33105 .40118 .32425 Metetra
0 .048 .15 r
.40118 .32425 .40684 .33105 .41637 .32862 .41072 .32177 Metetra
0 .05 .152 r
.41072 .32177 .41637 .32862 .42597 .32528 .42034 .3185 Metetra
0 .051 .154 r
.42034 .3185 .42597 .32528 .43558 .32256 .42997 .31566 Metetra
0 .055 .157 r
.42997 .31566 .43558 .32256 .44522 .32021 .43963 .31339 Metetra
0 .058 .16 r
.43963 .31339 .44522 .32021 .45491 .31737 .44935 .31007 Metetra
0 .059 .162 r
.44935 .31007 .45491 .31737 .46464 .31458 .45911 .30674 Metetra
0 .061 .163 r
.45911 .30674 .46464 .31458 .47442 .31124 .4689 .30376 Metetra
0 .061 .163 r
.4689 .30376 .47442 .31124 .48423 .30778 .47873 .30028 Metetra
0 .061 .163 r
.47873 .30028 .48423 .30778 .49408 .30427 .48861 .29636 Metetra
0 .059 .162 r
.48861 .29636 .49408 .30427 .50397 .30023 .49851 .29281 Metetra
0 .058 .16 r
.49851 .29281 .50397 .30023 .51389 .29616 .50845 .28918 Metetra
0 .055 .157 r
.50845 .28918 .51389 .29616 .52385 .29162 .51843 .28452 Metetra
0 .051 .154 r
.51843 .28452 .52385 .29162 .53383 .28748 .52843 .28043 Metetra
0 .05 .152 r
.52843 .28043 .53383 .28748 .54385 .28396 .53848 .27679 Metetra
0 .048 .15 r
.53848 .27679 .54385 .28396 .5539 .27952 .54855 .27237 Metetra
0 .045 .147 r
.54855 .27237 .5539 .27952 .56398 .27549 .55866 .26833 Metetra
0 .043 .145 r
.55866 .26833 .56398 .27549 .5741 .27136 .56879 .2639 Metetra
0 .041 .143 r
.56879 .2639 .5741 .27136 .58426 .26749 .57897 .25997 Metetra
0 .04 .142 r
.57897 .25997 .58426 .26749 .59445 .26384 .58919 .25628 Metetra
0 .039 .141 r
.58919 .25628 .59445 .26384 .60467 .25961 .59944 .25244 Metetra
0 .038 .14 r
.59944 .25244 .60467 .25961 .61493 .25563 .60973 .24881 Metetra
0 .036 .138 r
.60973 .24881 .61493 .25563 .6252 .2511 .62004 .24455 Metetra
0 .034 .135 r
.62004 .24455 .6252 .2511 .63553 .24699 .6304 .24053 Metetra
0 .032 .133 r
.6304 .24053 .63553 .24699 .64588 .24278 .64078 .23619 Metetra
0 .032 .132 r
.64078 .23619 .64588 .24278 .6563 .23925 .65122 .23247 Metetra
0 .031 .132 r
.65122 .23247 .6563 .23925 .66676 .23554 .66168 .22847 Metetra
0 .031 .132 r
.66168 .22847 .66676 .23554 .67726 .232 .6722 .22476 Metetra
0 .031 .131 r
.6722 .22476 .67726 .232 .68778 .22814 .68275 .22083 Metetra
0 .031 .131 r
.68275 .22083 .68778 .22814 .69835 .22434 .69335 .21716 Metetra
0 .03 .13 r
.69335 .21716 .69835 .22434 .70892 .22007 .70396 .21305 Metetra
0 .029 .129 r
.70396 .21305 .70892 .22007 .71955 .21595 .71463 .20915 Metetra
0 .028 .127 r
.71463 .20915 .71955 .21595 .73021 .21182 .72533 .20508 Metetra
0 .027 .127 r
.72533 .20508 .73021 .21182 .74093 .20795 .73607 .20118 Metetra
0 .027 .126 r
.73607 .20118 .74093 .20795 .75168 .20399 .74684 .19706 Metetra
0 .027 .126 r
.74684 .19706 .75168 .20399 .7625 .20042 .75768 .19329 Metetra
0 .027 .126 r
.75768 .19329 .7625 .20042 .77335 .19667 .76855 .18935 Metetra
0 .027 .126 r
.76855 .18935 .77335 .19667 .78425 .19298 .77947 .18556 Metetra
0 .027 .126 r
.77947 .18556 .78425 .19298 .79517 .189 .79042 .18161 Metetra
0 .027 .126 r
.79042 .18161 .79517 .189 .80615 .18519 .80144 .17793 Metetra
0 .027 .126 r
.17543 .39103 .1816 .39681 .19042 .39349 .18427 .3877 Metetra
0 .026 .125 r
.18427 .3877 .19042 .39349 .19924 .39047 .1931 .38464 Metetra
0 .026 .125 r
.1931 .38464 .19924 .39047 .2081 .38728 .20198 .38143 Metetra
0 .026 .126 r
.20198 .38143 .2081 .38728 .21698 .38425 .21088 .37839 Metetra
0 .026 .126 r
.21088 .37839 .21698 .38425 .2259 .38103 .21982 .37512 Metetra
0 .027 .126 r
.21982 .37512 .2259 .38103 .23482 .37819 .22876 .37228 Metetra
0 .028 .127 r
.22876 .37228 .23482 .37819 .2438 .3751 .23775 .36917 Metetra
0 .028 .128 r
.23775 .36917 .2438 .3751 .25279 .37219 .24676 .36627 Metetra
0 .029 .129 r
.24676 .36627 .25279 .37219 .26182 .36912 .25581 .36314 Metetra
0 .03 .13 r
.25581 .36314 .26182 .36912 .27087 .36627 .26488 .36029 Metetra
0 .03 .13 r
.26488 .36029 .27087 .36627 .27998 .36297 .27401 .35693 Metetra
0 .03 .13 r
.27401 .35693 .27998 .36297 .28911 .35996 .28316 .35387 Metetra
0 .03 .131 r
.28316 .35387 .28911 .35996 .29828 .35672 .29235 .35057 Metetra
0 .031 .131 r
.29235 .35057 .29828 .35672 .30746 .35379 .30155 .34764 Metetra
0 .032 .132 r
.30155 .34764 .30746 .35379 .3167 .35054 .31081 .34439 Metetra
0 .033 .133 r
.31081 .34439 .3167 .35054 .32593 .34794 .32006 .34173 Metetra
0 .034 .135 r
.32006 .34173 .32593 .34794 .33521 .34499 .32936 .33874 Metetra
0 .036 .137 r
.32936 .33874 .33521 .34499 .34452 .34231 .33869 .3359 Metetra
0 .037 .138 r
.33869 .3359 .34452 .34231 .35389 .33899 .34808 .33255 Metetra
0 .037 .139 r
.34808 .33255 .35389 .33899 .36328 .33592 .35751 .32927 Metetra
0 .038 .139 r
.35751 .32927 .36328 .33592 .37272 .33269 .36695 .3262 Metetra
0 .039 .14 r
.36695 .3262 .37272 .33269 .38218 .32968 .37643 .32315 Metetra
0 .041 .143 r
.37643 .32315 .38218 .32968 .39165 .32717 .38592 .32065 Metetra
0 .043 .145 r
.38592 .32065 .39165 .32717 .40118 .32425 .39547 .31747 Metetra
0 .045 .147 r
.39547 .31747 .40118 .32425 .41072 .32177 .40505 .31458 Metetra
0 .047 .149 r
.40505 .31458 .41072 .32177 .42034 .3185 .41468 .31145 Metetra
0 .048 .151 r
.41468 .31145 .42034 .3185 .42997 .31566 .42434 .30846 Metetra
0 .051 .154 r
.42434 .30846 .42997 .31566 .43963 .31339 .43401 .30604 Metetra
0 .054 .156 r
.43401 .30604 .43963 .31339 .44935 .31007 .44376 .3025 Metetra
0 .054 .156 r
.44376 .3025 .44935 .31007 .45911 .30674 .45355 .29885 Metetra
0 .055 .157 r
.45355 .29885 .45911 .30674 .4689 .30376 .46335 .2961 Metetra
0 .056 .158 r
.46335 .2961 .4689 .30376 .47873 .30028 .4732 .29261 Metetra
0 .055 .157 r
.4732 .29261 .47873 .30028 .48861 .29636 .4831 .2884 Metetra
0 .054 .156 r
.4831 .2884 .48861 .29636 .49851 .29281 .49302 .2851 Metetra
0 .054 .156 r
.49302 .2851 .49851 .29281 .50845 .28918 .50297 .28167 Metetra
0 .051 .154 r
.50297 .28167 .50845 .28918 .51843 .28452 .51297 .27713 Metetra
0 .048 .151 r
.51297 .27713 .51843 .28452 .52843 .28043 .523 .27312 Metetra
0 .047 .149 r
.523 .27312 .52843 .28043 .53848 .27679 .53307 .26929 Metetra
0 .045 .147 r
.53307 .26929 .53848 .27679 .54855 .27237 .54316 .26523 Metetra
0 .043 .145 r
.54316 .26523 .54855 .27237 .55866 .26833 .5533 .26142 Metetra
0 .041 .143 r
.5533 .26142 .55866 .26833 .56879 .2639 .56346 .25694 Metetra
0 .039 .14 r
.56346 .25694 .56879 .2639 .57897 .25997 .57366 .25299 Metetra
0 .038 .139 r
.57366 .25299 .57897 .25997 .58919 .25628 .5839 .24909 Metetra
0 .037 .139 r
.5839 .24909 .58919 .25628 .59944 .25244 .59417 .2454 Metetra
0 .037 .138 r
.59417 .2454 .59944 .25244 .60973 .24881 .60449 .24178 Metetra
0 .036 .137 r
.60449 .24178 .60973 .24881 .62004 .24455 .61483 .23763 Metetra
0 .034 .135 r
.61483 .23763 .62004 .24455 .6304 .24053 .62522 .2336 Metetra
0 .033 .133 r
.62522 .2336 .6304 .24053 .64078 .23619 .63562 .22926 Metetra
0 .031 .132 r
.63562 .22926 .64078 .23619 .65122 .23247 .64609 .22551 Metetra
0 .031 .131 r
.64609 .22551 .65122 .23247 .66168 .22847 .65658 .22145 Metetra
0 .03 .131 r
.65658 .22145 .66168 .22847 .6722 .22476 .66713 .21776 Metetra
0 .03 .13 r
.66713 .21776 .6722 .22476 .68275 .22083 .6777 .21383 Metetra
0 .03 .13 r
.6777 .21383 .68275 .22083 .69335 .21716 .68833 .21019 Metetra
0 .03 .13 r
.68833 .21019 .69335 .21716 .70396 .21305 .69897 .20603 Metetra
0 .029 .129 r
.69897 .20603 .70396 .21305 .71463 .20915 .70967 .20213 Metetra
0 .028 .128 r
.70967 .20213 .71463 .20915 .72533 .20508 .72039 .19801 Metetra
0 .027 .127 r
.72039 .19801 .72533 .20508 .73607 .20118 .73117 .19408 Metetra
0 .027 .126 r
.73117 .19408 .73607 .20118 .74684 .19706 .74197 .18991 Metetra
0 .026 .126 r
.74197 .18991 .74684 .19706 .75768 .19329 .75284 .18615 Metetra
0 .026 .126 r
.75284 .18615 .75768 .19329 .76855 .18935 .76373 .18217 Metetra
0 .026 .125 r
.76373 .18217 .76855 .18935 .77947 .18556 .77468 .17836 Metetra
0 .026 .125 r
.77468 .17836 .77947 .18556 .79042 .18161 .78566 .17439 Metetra
0 .027 .126 r
.78566 .17439 .79042 .18161 .80144 .17793 .79671 .17068 Metetra
0 .026 .125 r
.16924 .38503 .17543 .39103 .18427 .3877 .17807 .38187 Metetra
0 .026 .125 r
.17807 .38187 .18427 .3877 .1931 .38464 .18692 .37891 Metetra
0 .026 .126 r
.18692 .37891 .1931 .38464 .20198 .38143 .19581 .37575 Metetra
0 .027 .126 r
.19581 .37575 .20198 .38143 .21088 .37839 .20472 .3727 Metetra
0 .027 .126 r
.20472 .3727 .21088 .37839 .21982 .37512 .21369 .36933 Metetra
0 .027 .126 r
.21369 .36933 .21982 .37512 .22876 .37228 .22266 .3663 Metetra
0 .027 .127 r
.22266 .3663 .22876 .37228 .23775 .36917 .23168 .36306 Metetra
0 .028 .127 r
.23168 .36306 .23775 .36917 .24676 .36627 .24071 .36004 Metetra
0 .028 .128 r
.24071 .36004 .24676 .36627 .25581 .36314 .24979 .35688 Metetra
0 .029 .129 r
.24979 .35688 .25581 .36314 .26488 .36029 .25886 .3541 Metetra
0 .03 .13 r
.25886 .3541 .26488 .36029 .27401 .35693 .268 .35091 Metetra
0 .03 .13 r
.268 .35091 .27401 .35693 .28316 .35387 .27715 .34795 Metetra
0 .03 .131 r
.27715 .34795 .28316 .35387 .29235 .35057 .28636 .34469 Metetra
0 .031 .131 r
.28636 .34469 .29235 .35057 .30155 .34764 .29558 .34172 Metetra
0 .032 .132 r
.29558 .34172 .30155 .34764 .31081 .34439 .30486 .33839 Metetra
0 .032 .133 r
.30486 .33839 .31081 .34439 .32006 .34173 .31415 .3354 Metetra
0 .034 .135 r
.31415 .3354 .32006 .34173 .32936 .33874 .32348 .3322 Metetra
0 .035 .136 r
.32348 .3322 .32936 .33874 .33869 .3359 .33285 .32903 Metetra
0 .035 .136 r
.33285 .32903 .33869 .3359 .34808 .33255 .34226 .32573 Metetra
0 .035 .136 r
.34226 .32573 .34808 .33255 .35751 .32927 .3517 .32243 Metetra
0 .036 .138 r
.3517 .32243 .35751 .32927 .36695 .3262 .36115 .31968 Metetra
0 .038 .139 r
.36115 .31968 .36695 .3262 .37643 .32315 .37063 .31679 Metetra
0 .04 .142 r
.37063 .31679 .37643 .32315 .38592 .32065 .38014 .31432 Metetra
0 .042 .144 r
.38014 .31432 .38592 .32065 .39547 .31747 .38972 .31109 Metetra
0 .043 .145 r
.38972 .31109 .39547 .31747 .40505 .31458 .39933 .30786 Metetra
0 .045 .147 r
.39933 .30786 .40505 .31458 .41468 .31145 .40897 .30495 Metetra
0 .046 .149 r
.40897 .30495 .41468 .31145 .42434 .30846 .41865 .3018 Metetra
0 .048 .151 r
.41865 .3018 .42434 .30846 .43401 .30604 .42836 .29889 Metetra
0 .05 .152 r
.42836 .29889 .43401 .30604 .44376 .3025 .43813 .29533 Metetra
0 .049 .152 r
.43813 .29533 .44376 .3025 .45355 .29885 .44793 .29158 Metetra
0 .05 .153 r
.44793 .29158 .45355 .29885 .46335 .2961 .45776 .2887 Metetra
0 .051 .154 r
.45776 .2887 .46335 .2961 .4732 .29261 .46763 .2852 Metetra
0 .05 .152 r
.46763 .2852 .4732 .29261 .4831 .2884 .47755 .28107 Metetra
0 .049 .152 r
.47755 .28107 .4831 .2884 .49302 .2851 .48749 .27778 Metetra
0 .05 .152 r
.48749 .27778 .49302 .2851 .50297 .28167 .49746 .27436 Metetra
0 .048 .151 r
.49746 .27436 .50297 .28167 .51297 .27713 .50748 .27026 Metetra
0 .046 .148 r
.50748 .27026 .51297 .27713 .523 .27312 .51754 .26636 Metetra
0 .045 .147 r
.51754 .26636 .523 .27312 .53307 .26929 .52762 .26226 Metetra
0 .043 .145 r
.52762 .26226 .53307 .26929 .54316 .26523 .53774 .2585 Metetra
0 .042 .144 r
.53774 .2585 .54316 .26523 .5533 .26142 .5479 .2547 Metetra
0 .04 .142 r
.5479 .2547 .5533 .26142 .56346 .25694 .55809 .25014 Metetra
0 .038 .139 r
.55809 .25014 .56346 .25694 .57366 .25299 .56831 .24597 Metetra
0 .036 .137 r
.56831 .24597 .57366 .25299 .5839 .24909 .57857 .2417 Metetra
0 .035 .136 r
.57857 .2417 .5839 .24909 .59417 .2454 .58887 .23797 Metetra
0 .035 .136 r
.58887 .23797 .59417 .2454 .60449 .24178 .59921 .23426 Metetra
0 .035 .136 r
.59921 .23426 .60449 .24178 .61483 .23763 .60958 .2304 Metetra
0 .034 .135 r
.60958 .2304 .61483 .23763 .62522 .2336 .62 .22656 Metetra
0 .032 .133 r
.62 .22656 .62522 .2336 .63562 .22926 .63044 .2225 Metetra
0 .032 .132 r
.63044 .2225 .63562 .22926 .64609 .22551 .64094 .21877 Metetra
0 .031 .131 r
.64094 .21877 .64609 .22551 .65658 .22145 .65146 .21471 Metetra
0 .03 .131 r
.65146 .21471 .65658 .22145 .66713 .21776 .66203 .21093 Metetra
0 .03 .13 r
.66203 .21093 .66713 .21776 .6777 .21383 .67263 .20685 Metetra
0 .03 .13 r
.67263 .20685 .6777 .21383 .68833 .21019 .68327 .20299 Metetra
0 .029 .129 r
.68327 .20299 .68833 .21019 .69897 .20603 .69394 .19871 Metetra
0 .028 .128 r
.69394 .19871 .69897 .20603 .70967 .20213 .70466 .19479 Metetra
0 .028 .127 r
.70466 .19479 .70967 .20213 .72039 .19801 .71542 .19074 Metetra
0 .027 .127 r
.71542 .19074 .72039 .19801 .73117 .19408 .72623 .18692 Metetra
0 .027 .126 r
.72623 .18692 .73117 .19408 .74197 .18991 .73707 .18287 Metetra
0 .027 .126 r
.73707 .18287 .74197 .18991 .75284 .18615 .74797 .17917 Metetra
0 .027 .126 r
.74797 .17917 .75284 .18615 .76373 .18217 .7589 .17516 Metetra
0 .026 .126 r
.7589 .17516 .76373 .18217 .77468 .17836 .76987 .17124 Metetra
0 .026 .125 r
.76987 .17124 .77468 .17836 .78566 .17439 .78087 .16712 Metetra
0 .026 .125 r
.78087 .16712 .78566 .17439 .79671 .17068 .79193 .16319 Metetra
0 .026 .125 r
.16298 .37934 .16924 .38503 .17807 .38187 .17184 .37603 Metetra
0 .026 .125 r
.17184 .37603 .17807 .38187 .18692 .37891 .18072 .3729 Metetra
0 .026 .125 r
.18072 .3729 .18692 .37891 .19581 .37575 .18964 .36962 Metetra
0 .026 .126 r
.18964 .36962 .19581 .37575 .20472 .3727 .19857 .36653 Metetra
0 .026 .126 r
.19857 .36653 .20472 .3727 .21369 .36933 .20755 .36319 Metetra
0 .027 .126 r
.20755 .36319 .21369 .36933 .22266 .3663 .21652 .36029 Metetra
0 .027 .126 r
.21652 .36029 .22266 .3663 .23168 .36306 .22555 .35718 Metetra
0 .028 .127 r
.22555 .35718 .23168 .36306 .24071 .36004 .23458 .35427 Metetra
0 .028 .128 r
.23458 .35427 .24071 .36004 .24979 .35688 .24368 .35108 Metetra
0 .029 .129 r
.24368 .35108 .24979 .35688 .25886 .3541 .25278 .34818 Metetra
0 .03 .13 r
.25278 .34818 .25886 .3541 .268 .35091 .26195 .34476 Metetra
0 .03 .13 r
.26195 .34476 .268 .35091 .27715 .34795 .27114 .34158 Metetra
0 .03 .13 r
.27114 .34158 .27715 .34795 .28636 .34469 .28038 .33819 Metetra
0 .031 .131 r
.28038 .33819 .28636 .34469 .29558 .34172 .28962 .33519 Metetra
0 .031 .132 r
.28962 .33519 .29558 .34172 .30486 .33839 .2989 .332 Metetra
0 .032 .132 r
.2989 .332 .30486 .33839 .31415 .3354 .3082 .32906 Metetra
0 .033 .134 r
.3082 .32906 .31415 .3354 .32348 .3322 .31755 .32601 Metetra
0 .033 .134 r
.31755 .32601 .32348 .3322 .33285 .32903 .32693 .32281 Metetra
0 .034 .135 r
.32693 .32281 .33285 .32903 .34226 .32573 .33636 .31959 Metetra
0 .034 .135 r
.33636 .31959 .34226 .32573 .3517 .32243 .34582 .31613 Metetra
0 .035 .136 r
.34582 .31613 .3517 .32243 .36115 .31968 .35529 .31338 Metetra
0 .037 .139 r
.35529 .31338 .36115 .31968 .37063 .31679 .36481 .31029 Metetra
0 .039 .141 r
.36481 .31029 .37063 .31679 .38014 .31432 .37435 .30739 Metetra
0 .041 .143 r
.37435 .30739 .38014 .31432 .38972 .31109 .38396 .30397 Metetra
0 .041 .143 r
.38396 .30397 .38972 .31109 .39933 .30786 .3936 .30041 Metetra
0 .042 .144 r
.3936 .30041 .39933 .30786 .40897 .30495 .40325 .29762 Metetra
0 .044 .146 r
.40325 .29762 .40897 .30495 .41865 .3018 .41295 .2944 Metetra
0 .045 .147 r
.41295 .2944 .41865 .3018 .42836 .29889 .42269 .29108 Metetra
0 .046 .148 r
.42269 .29108 .42836 .29889 .43813 .29533 .43247 .2877 Metetra
0 .045 .148 r
.43247 .2877 .43813 .29533 .44793 .29158 .44229 .28412 Metetra
0 .046 .148 r
.44229 .28412 .44793 .29158 .45776 .2887 .45214 .28094 Metetra
0 .047 .149 r
.45214 .28094 .45776 .2887 .46763 .2852 .46203 .27743 Metetra
0 .046 .148 r
.46203 .27743 .46763 .2852 .47755 .28107 .47196 .27353 Metetra
0 .045 .148 r
.47196 .27353 .47755 .28107 .48749 .27778 .48192 .27002 Metetra
0 .046 .148 r
.48192 .27002 .48749 .27778 .49746 .27436 .49192 .26637 Metetra
0 .045 .147 r
.49192 .26637 .49746 .27436 .50748 .27026 .50196 .26264 Metetra
0 .044 .146 r
.50196 .26264 .50748 .27026 .51754 .26636 .51203 .25877 Metetra
0 .042 .144 r
.51203 .25877 .51754 .26636 .52762 .26226 .52214 .2545 Metetra
0 .041 .143 r
.52214 .2545 .52762 .26226 .53774 .2585 .53229 .25099 Metetra
0 .041 .143 r
.53229 .25099 .53774 .2585 .5479 .2547 .54247 .24736 Metetra
0 .039 .141 r
.54247 .24736 .5479 .2547 .55809 .25014 .55268 .24319 Metetra
0 .037 .139 r
.55268 .24319 .55809 .25014 .56831 .24597 .56293 .23918 Metetra
0 .035 .136 r
.56293 .23918 .56831 .24597 .57857 .2417 .57322 .23486 Metetra
0 .034 .135 r
.57322 .23486 .57857 .2417 .58887 .23797 .58354 .23124 Metetra
0 .034 .135 r
.58354 .23124 .58887 .23797 .59921 .23426 .59391 .22739 Metetra
0 .034 .134 r
.59391 .22739 .59921 .23426 .60958 .2304 .60431 .22352 Metetra
0 .033 .134 r
.60431 .22352 .60958 .2304 .62 .22656 .61474 .21949 Metetra
0 .032 .132 r
.61474 .21949 .62 .22656 .63044 .2225 .62521 .21533 Metetra
0 .031 .132 r
.62521 .21533 .63044 .2225 .64094 .21877 .63573 .21141 Metetra
0 .031 .131 r
.63573 .21141 .64094 .21877 .65146 .21471 .64627 .20732 Metetra
0 .03 .13 r
.64627 .20732 .65146 .21471 .66203 .21093 .65687 .20362 Metetra
0 .03 .13 r
.65687 .20362 .66203 .21093 .67263 .20685 .66751 .19973 Metetra
0 .03 .13 r
.66751 .19973 .67263 .20685 .68327 .20299 .67819 .19605 Metetra
0 .029 .129 r
.67819 .19605 .68327 .20299 .69394 .19871 .68889 .19185 Metetra
0 .028 .128 r
.68889 .19185 .69394 .19871 .70466 .19479 .69965 .18792 Metetra
0 .028 .127 r
.69965 .18792 .70466 .19479 .71542 .19074 .71042 .18371 Metetra
0 .027 .126 r
.71042 .18371 .71542 .19074 .72623 .18692 .72125 .17969 Metetra
0 .027 .126 r
.72125 .17969 .72623 .18692 .73707 .18287 .73211 .17548 Metetra
0 .026 .125 r
.73211 .17548 .73707 .18287 .74797 .17917 .74304 .17169 Metetra
0 .026 .126 r
.74304 .17169 .74797 .17917 .7589 .17516 .75399 .16766 Metetra
0 .026 .125 r
.75399 .16766 .7589 .17516 .76987 .17124 .765 .16382 Metetra
0 .026 .125 r
.765 .16382 .76987 .17124 .78087 .16712 .77605 .15983 Metetra
0 .026 .125 r
.77605 .15983 .78087 .16712 .79193 .16319 .78715 .15601 Metetra
0 .026 .125 r
.15668 .37356 .16298 .37934 .17184 .37603 .16556 .37021 Metetra
0 .026 .125 r
.16556 .37021 .17184 .37603 .18072 .3729 .17446 .36697 Metetra
0 .026 .125 r
.17446 .36697 .18072 .3729 .18964 .36962 .18341 .36359 Metetra
0 .026 .125 r
.18341 .36359 .18964 .36962 .19857 .36653 .19236 .36044 Metetra
0 .026 .125 r
.19236 .36044 .19857 .36653 .20755 .36319 .20136 .35708 Metetra
0 .026 .125 r
.20136 .35708 .20755 .36319 .21652 .36029 .21035 .35418 Metetra
0 .027 .126 r
.21035 .35418 .21652 .36029 .22555 .35718 .21938 .35113 Metetra
0 .028 .127 r
.21938 .35113 .22555 .35718 .23458 .35427 .22843 .34829 Metetra
0 .029 .128 r
.22843 .34829 .23458 .35427 .24368 .35108 .23754 .34511 Metetra
0 .029 .129 r
.23754 .34511 .24368 .35108 .25278 .34818 .24666 .34217 Metetra
0 .03 .13 r
.24666 .34217 .25278 .34818 .26195 .34476 .25586 .3387 Metetra
0 .029 .129 r
.25586 .3387 .26195 .34476 .27114 .34158 .26508 .33537 Metetra
0 .029 .129 r
.26508 .33537 .27114 .34158 .28038 .33819 .27433 .33193 Metetra
0 .03 .13 r
.27433 .33193 .28038 .33819 .28962 .33519 .2836 .3288 Metetra
0 .03 .13 r
.2836 .3288 .28962 .33519 .2989 .332 .2929 .32566 Metetra
0 .031 .131 r
.2929 .32566 .2989 .332 .3082 .32906 .30223 .32254 Metetra
0 .032 .133 r
.30223 .32254 .3082 .32906 .31755 .32601 .31159 .31949 Metetra
0 .033 .134 r
.31159 .31949 .31755 .32601 .32693 .32281 .321 .3162 Metetra
0 .033 .134 r
.321 .3162 .32693 .32281 .33636 .31959 .33043 .31317 Metetra
0 .034 .135 r
.33043 .31317 .33636 .31959 .34582 .31613 .33991 .3098 Metetra
0 .035 .136 r
.33991 .3098 .34582 .31613 .35529 .31338 .34939 .30711 Metetra
0 .037 .138 r
.34939 .30711 .35529 .31338 .36481 .31029 .35893 .30399 Metetra
0 .038 .14 r
.35893 .30399 .36481 .31029 .37435 .30739 .36851 .30072 Metetra
0 .039 .14 r
.36851 .30072 .37435 .30739 .38396 .30397 .37813 .29731 Metetra
0 .038 .14 r
.37813 .29731 .38396 .30397 .3936 .30041 .3878 .29361 Metetra
0 .039 .141 r
.3878 .29361 .3936 .30041 .40325 .29762 .39747 .29075 Metetra
0 .041 .143 r
.39747 .29075 .40325 .29762 .41295 .2944 .4072 .28739 Metetra
0 .041 .143 r
.4072 .28739 .41295 .2944 .42269 .29108 .41698 .28359 Metetra
0 .041 .143 r
.41698 .28359 .42269 .29108 .43247 .2877 .42677 .28036 Metetra
0 .042 .144 r
.42677 .28036 .43247 .2877 .44229 .28412 .4366 .277 Metetra
0 .042 .144 r
.4366 .277 .44229 .28412 .45214 .28094 .44648 .27334 Metetra
0 .042 .144 r
.44648 .27334 .45214 .28094 .46203 .27743 .45639 .2698 Metetra
0 .042 .144 r
.45639 .2698 .46203 .27743 .47196 .27353 .46634 .26634 Metetra
0 .042 .144 r
.46634 .26634 .47196 .27353 .48192 .27002 .47633 .26256 Metetra
0 .041 .143 r
.47633 .26256 .48192 .27002 .49192 .26637 .48635 .25871 Metetra
0 .041 .143 r
.48635 .25871 .49192 .26637 .50196 .26264 .4964 .25541 Metetra
0 .041 .143 r
.4964 .25541 .50196 .26264 .51203 .25877 .5065 .25164 Metetra
0 .039 .141 r
.5065 .25164 .51203 .25877 .52214 .2545 .51663 .24739 Metetra
0 .038 .14 r
.51663 .24739 .52214 .2545 .53229 .25099 .5268 .24395 Metetra
0 .039 .14 r
.5268 .24395 .53229 .25099 .54247 .24736 .537 .24028 Metetra
0 .038 .14 r
.537 .24028 .54247 .24736 .55268 .24319 .54724 .23644 Metetra
0 .037 .138 r
.54724 .23644 .55268 .24319 .56293 .23918 .55752 .23242 Metetra
0 .035 .136 r
.55752 .23242 .56293 .23918 .57322 .23486 .56783 .22798 Metetra
0 .034 .135 r
.56783 .22798 .57322 .23486 .58354 .23124 .57818 .22421 Metetra
0 .033 .134 r
.57818 .22421 .58354 .23124 .59391 .22739 .58856 .22013 Metetra
0 .033 .134 r
.58856 .22013 .59391 .22739 .60431 .22352 .59899 .2163 Metetra
0 .032 .133 r
.59899 .2163 .60431 .22352 .61474 .21949 .60945 .21222 Metetra
0 .031 .131 r
.60945 .21222 .61474 .21949 .62521 .21533 .61995 .20819 Metetra
0 .03 .13 r
.61995 .20819 .62521 .21533 .63573 .21141 .63049 .20419 Metetra
0 .03 .129 r
.63049 .20419 .63573 .21141 .64627 .20732 .64107 .20017 Metetra
0 .029 .129 r
.64107 .20017 .64627 .20732 .65687 .20362 .6517 .19648 Metetra
0 .029 .129 r
.6517 .19648 .65687 .20362 .66751 .19973 .66236 .19268 Metetra
0 .03 .13 r
.66236 .19268 .66751 .19973 .67819 .19605 .67308 .18901 Metetra
0 .029 .129 r
.67308 .18901 .67819 .19605 .68889 .19185 .6838 .18481 Metetra
0 .029 .128 r
.6838 .18481 .68889 .19185 .69965 .18792 .69458 .18082 Metetra
0 .028 .127 r
.69458 .18082 .69965 .18792 .71042 .18371 .70539 .17649 Metetra
0 .027 .126 r
.70539 .17649 .71042 .18371 .72125 .17969 .71624 .17236 Metetra
0 .026 .125 r
.71624 .17236 .72125 .17969 .73211 .17548 .72712 .16809 Metetra
0 .026 .125 r
.72712 .16809 .73211 .17548 .74304 .17169 .73808 .16428 Metetra
0 .026 .125 r
.73808 .16428 .74304 .17169 .75399 .16766 .74907 .16027 Metetra
0 .026 .125 r
.74907 .16027 .75399 .16766 .765 .16382 .76011 .15647 Metetra
0 .026 .125 r
.76011 .15647 .765 .16382 .77605 .15983 .77119 .15255 Metetra
0 .026 .125 r
.77119 .15255 .77605 .15983 .78715 .15601 .78233 .14872 Metetra
0 .026 .125 r
.15038 .36738 .15668 .37356 .16556 .37021 .15928 .36402 Metetra
0 .026 .125 r
.15928 .36402 .16556 .37021 .17446 .36697 .1682 .36079 Metetra
0 .026 .124 r
.1682 .36079 .17446 .36697 .18341 .36359 .17714 .35753 Metetra
0 .026 .124 r
.17714 .35753 .18341 .36359 .19236 .36044 .1861 .3545 Metetra
0 .026 .125 r
.1861 .3545 .19236 .36044 .20136 .35708 .1951 .35129 Metetra
0 .026 .125 r
.1951 .35129 .20136 .35708 .21035 .35418 .2041 .34839 Metetra
0 .027 .126 r
.2041 .34839 .21035 .35418 .21938 .35113 .21316 .3453 Metetra
0 .028 .128 r
.21316 .3453 .21938 .35113 .22843 .34829 .22224 .34226 Metetra
0 .028 .128 r
.22224 .34226 .22843 .34829 .23754 .34511 .23138 .33888 Metetra
0 .029 .129 r
.23138 .33888 .23754 .34511 .24666 .34217 .24055 .33565 Metetra
0 .029 .129 r
.24055 .33565 .24666 .34217 .25586 .3387 .24976 .33217 Metetra
0 .029 .128 r
.24976 .33217 .25586 .3387 .26508 .33537 .259 .32885 Metetra
0 .029 .128 r
.259 .32885 .26508 .33537 .27433 .33193 .26826 .32558 Metetra
0 .029 .129 r
.26826 .32558 .27433 .33193 .2836 .3288 .27753 .32255 Metetra
0 .03 .13 r
.27753 .32255 .2836 .3288 .2929 .32566 .28683 .31962 Metetra
0 .031 .131 r
.28683 .31962 .2929 .32566 .30223 .32254 .29618 .31645 Metetra
0 .032 .132 r
.29618 .31645 .30223 .32254 .31159 .31949 .30557 .31334 Metetra
0 .032 .133 r
.30557 .31334 .31159 .31949 .321 .3162 .31501 .30985 Metetra
0 .033 .134 r
.31501 .30985 .321 .3162 .33043 .31317 .32446 .30674 Metetra
0 .033 .134 r
.32446 .30674 .33043 .31317 .33991 .3098 .33396 .30332 Metetra
0 .035 .136 r
.33396 .30332 .33991 .3098 .34939 .30711 .34348 .30031 Metetra
0 .036 .137 r
.34348 .30031 .34939 .30711 .35893 .30399 .35304 .29703 Metetra
0 .036 .138 r
.35304 .29703 .35893 .30399 .36851 .30072 .36266 .29343 Metetra
0 .037 .138 r
.36266 .29343 .36851 .30072 .37813 .29731 .3723 .29013 Metetra
0 .037 .138 r
.3723 .29013 .37813 .29731 .3878 .29361 .38198 .28661 Metetra
0 .037 .139 r
.38198 .28661 .3878 .29361 .39747 .29075 .39167 .28358 Metetra
0 .039 .14 r
.39167 .28358 .39747 .29075 .4072 .28739 .40142 .28023 Metetra
0 .038 .14 r
.40142 .28023 .4072 .28739 .41698 .28359 .41122 .27637 Metetra
0 .038 .14 r
.41122 .27637 .41698 .28359 .42677 .28036 .42103 .27324 Metetra
0 .039 .141 r
.42103 .27324 .42677 .28036 .4366 .277 .43087 .27005 Metetra
0 .039 .141 r
.43087 .27005 .4366 .277 .44648 .27334 .44078 .26612 Metetra
0 .039 .141 r
.44078 .26612 .44648 .27334 .45639 .2698 .45071 .26255 Metetra
0 .04 .141 r
.45071 .26255 .45639 .2698 .46634 .26634 .46067 .25931 Metetra
0 .039 .141 r
.46067 .25931 .46634 .26634 .47633 .26256 .47069 .25533 Metetra
0 .038 .14 r
.47069 .25533 .47633 .26256 .48635 .25871 .48073 .25132 Metetra
0 .038 .14 r
.48073 .25132 .48635 .25871 .4964 .25541 .49081 .24802 Metetra
0 .039 .14 r
.49081 .24802 .4964 .25541 .5065 .25164 .50092 .24421 Metetra
0 .037 .139 r
.50092 .24421 .5065 .25164 .51663 .24739 .51108 .24007 Metetra
0 .037 .138 r
.51108 .24007 .51663 .24739 .5268 .24395 .52127 .2364 Metetra
0 .037 .138 r
.52127 .2364 .5268 .24395 .537 .24028 .5315 .23256 Metetra
0 .036 .138 r
.5315 .23256 .537 .24028 .54724 .23644 .54176 .229 Metetra
0 .036 .137 r
.54176 .229 .54724 .23644 .55752 .23242 .55206 .22512 Metetra
0 .035 .136 r
.55206 .22512 .55752 .23242 .56783 .22798 .5624 .22095 Metetra
0 .033 .134 r
.5624 .22095 .56783 .22798 .57818 .22421 .57278 .21717 Metetra
0 .033 .134 r
.57278 .21717 .57818 .22421 .58856 .22013 .58319 .21313 Metetra
0 .032 .133 r
.58319 .21313 .58856 .22013 .59899 .2163 .59365 .20945 Metetra
0 .032 .132 r
.59365 .20945 .59899 .2163 .60945 .21222 .60414 .20538 Metetra
0 .031 .131 r
.60414 .20538 .60945 .21222 .61995 .20819 .61466 .20136 Metetra
0 .03 .13 r
.61466 .20136 .61995 .20819 .63049 .20419 .62522 .1971 Metetra
0 .029 .129 r
.62522 .1971 .63049 .20419 .64107 .20017 .63582 .19293 Metetra
0 .029 .128 r
.63582 .19293 .64107 .20017 .6517 .19648 .64647 .189 Metetra
0 .029 .128 r
.64647 .189 .6517 .19648 .66236 .19268 .65716 .18514 Metetra
0 .029 .129 r
.65716 .18514 .66236 .19268 .67308 .18901 .6679 .18144 Metetra
0 .029 .129 r
.6679 .18144 .67308 .18901 .6838 .18481 .67867 .17748 Metetra
0 .029 .128 r
.67867 .17748 .6838 .18481 .69458 .18082 .68949 .17366 Metetra
0 .028 .128 r
.68949 .17366 .69458 .18082 .70539 .17649 .70033 .16949 Metetra
0 .027 .126 r
.70033 .16949 .70539 .17649 .71624 .17236 .71121 .16535 Metetra
0 .026 .125 r
.71121 .16535 .71624 .17236 .72712 .16809 .72213 .16103 Metetra
0 .026 .125 r
.72213 .16103 .72712 .16809 .73808 .16428 .7331 .15701 Metetra
0 .026 .124 r
.7331 .15701 .73808 .16428 .74907 .16027 .74411 .15282 Metetra
0 .026 .124 r
.74411 .15282 .74907 .16027 .76011 .15647 .75517 .14885 Metetra
0 .026 .125 r
.75517 .14885 .76011 .15647 .77119 .15255 .76628 .14486 Metetra
0 .026 .125 r
.76628 .14486 .77119 .15255 .78233 .14872 .77744 .14099 Metetra
0 .025 .124 r
.14402 .36135 .15038 .36738 .15928 .36402 .15293 .35803 Metetra
0 .025 .124 r
.15293 .35803 .15928 .36402 .1682 .36079 .16186 .35477 Metetra
0 .025 .124 r
.16186 .35477 .1682 .36079 .17714 .35753 .17083 .35153 Metetra
0 .026 .124 r
.17083 .35153 .17714 .35753 .1861 .3545 .1798 .34848 Metetra
0 .026 .125 r
.1798 .34848 .1861 .3545 .1951 .35129 .18881 .34529 Metetra
0 .027 .126 r
.18881 .34529 .1951 .35129 .2041 .34839 .19784 .34229 Metetra
0 .027 .127 r
.19784 .34229 .2041 .34839 .21316 .3453 .20692 .33918 Metetra
0 .028 .128 r
.20692 .33918 .21316 .3453 .22224 .34226 .21602 .33604 Metetra
0 .028 .128 r
.21602 .33604 .22224 .34226 .23138 .33888 .22519 .33264 Metetra
0 .028 .128 r
.22519 .33264 .23138 .33888 .24055 .33565 .23437 .32931 Metetra
0 .028 .128 r
.23437 .32931 .24055 .33565 .24976 .33217 .2436 .32592 Metetra
0 .028 .127 r
.2436 .32592 .24976 .33217 .259 .32885 .25285 .32258 Metetra
0 .028 .128 r
.25285 .32258 .259 .32885 .26826 .32558 .26212 .31941 Metetra
0 .029 .129 r
.26212 .31941 .26826 .32558 .27753 .32255 .27142 .31629 Metetra
0 .03 .13 r
.27142 .31629 .27753 .32255 .28683 .31962 .28074 .31337 Metetra
0 .031 .131 r
.28074 .31337 .28683 .31962 .29618 .31645 .29012 .30998 Metetra
0 .032 .132 r
.29012 .30998 .29618 .31645 .30557 .31334 .29953 .30677 Metetra
0 .032 .132 r
.29953 .30677 .30557 .31334 .31501 .30985 .309 .3032 Metetra
0 .032 .133 r
.309 .3032 .31501 .30985 .32446 .30674 .31846 .30011 Metetra
0 .033 .134 r
.31846 .30011 .32446 .30674 .33396 .30332 .32798 .29683 Metetra
0 .034 .135 r
.32798 .29683 .33396 .30332 .34348 .30031 .33752 .29361 Metetra
0 .034 .136 r
.33752 .29361 .34348 .30031 .35304 .29703 .34711 .29028 Metetra
0 .034 .135 r
.34711 .29028 .35304 .29703 .36266 .29343 .35675 .28653 Metetra
0 .034 .136 r
.35675 .28653 .36266 .29343 .3723 .29013 .3664 .28335 Metetra
0 .035 .136 r
.3664 .28335 .3723 .29013 .38198 .28661 .37609 .28002 Metetra
0 .036 .137 r
.37609 .28002 .38198 .28661 .39167 .28358 .38582 .27668 Metetra
0 .037 .138 r
.38582 .27668 .39167 .28358 .40142 .28023 .39559 .27328 Metetra
0 .036 .138 r
.39559 .27328 .40142 .28023 .41122 .27637 .40541 .26949 Metetra
0 .037 .138 r
.40541 .26949 .41122 .27637 .42103 .27324 .41524 .26627 Metetra
0 .038 .14 r
.41524 .26627 .42103 .27324 .43087 .27005 .42511 .26309 Metetra
0 .038 .139 r
.42511 .26309 .43087 .27005 .44078 .26612 .43504 .25906 Metetra
0 .037 .139 r
.43504 .25906 .44078 .26612 .45071 .26255 .44499 .25546 Metetra
0 .038 .139 r
.44499 .25546 .45071 .26255 .46067 .25931 .45497 .25228 Metetra
0 .038 .14 r
.45497 .25228 .46067 .25931 .47069 .25533 .46501 .24826 Metetra
0 .036 .138 r
.46501 .24826 .47069 .25533 .48073 .25132 .47508 .24425 Metetra
0 .036 .138 r
.47508 .24425 .48073 .25132 .49081 .24802 .48517 .24084 Metetra
0 .037 .138 r
.48517 .24084 .49081 .24802 .50092 .24421 .49531 .23705 Metetra
0 .036 .137 r
.49531 .23705 .50092 .24421 .51108 .24007 .50549 .23317 Metetra
0 .035 .136 r
.50549 .23317 .51108 .24007 .52127 .2364 .51571 .22926 Metetra
0 .034 .136 r
.51571 .22926 .52127 .2364 .5315 .23256 .52596 .22524 Metetra
0 .034 .135 r
.52596 .22524 .5315 .23256 .54176 .229 .53625 .22179 Metetra
0 .034 .136 r
.53625 .22179 .54176 .229 .55206 .22512 .54657 .21791 Metetra
0 .034 .135 r
.54657 .21791 .55206 .22512 .5624 .22095 .55694 .2139 Metetra
0 .033 .134 r
.55694 .2139 .5624 .22095 .57278 .21717 .56734 .20993 Metetra
0 .032 .133 r
.56734 .20993 .57278 .21717 .58319 .21313 .57777 .20582 Metetra
0 .032 .132 r
.57777 .20582 .58319 .21313 .59365 .20945 .58826 .20216 Metetra
0 .032 .132 r
.58826 .20216 .59365 .20945 .60414 .20538 .59877 .19816 Metetra
0 .031 .131 r
.59877 .19816 .60414 .20538 .61466 .20136 .60933 .19431 Metetra
0 .03 .13 r
.60933 .19431 .61466 .20136 .62522 .1971 .61992 .18999 Metetra
0 .029 .129 r
.61992 .18999 .62522 .1971 .63582 .19293 .63055 .18586 Metetra
0 .028 .128 r
.63055 .18586 .63582 .19293 .64647 .189 .64122 .18178 Metetra
0 .028 .127 r
.64122 .18178 .64647 .189 .65716 .18514 .65194 .17788 Metetra
0 .028 .128 r
.65194 .17788 .65716 .18514 .6679 .18144 .6627 .17404 Metetra
0 .028 .128 r
.6627 .17404 .6679 .18144 .67867 .17748 .6735 .17013 Metetra
0 .028 .128 r
.6735 .17013 .67867 .17748 .68949 .17366 .68434 .16629 Metetra
0 .028 .128 r
.68434 .16629 .68949 .17366 .70033 .16949 .69522 .16217 Metetra
0 .027 .127 r
.69522 .16217 .70033 .16949 .71121 .16535 .70613 .15801 Metetra
0 .027 .126 r
.70613 .15801 .71121 .16535 .72213 .16103 .71708 .15374 Metetra
0 .026 .125 r
.71708 .15374 .72213 .16103 .7331 .15701 .72808 .14964 Metetra
0 .025 .124 r
.72808 .14964 .7331 .15701 .74411 .15282 .73912 .14542 Metetra
0 .025 .124 r
.73912 .14542 .74411 .15282 .75517 .14885 .75021 .14139 Metetra
0 .025 .124 r
.75021 .14139 .75517 .14885 .76628 .14486 .76135 .13738 Metetra
0 .025 .124 r
.76135 .13738 .76628 .14486 .77744 .14099 .77253 .13342 Metetra
0 .025 .124 r
.13763 .35517 .14402 .36135 .15293 .35803 .14654 .35202 Metetra
0 .025 .124 r
.14654 .35202 .15293 .35803 .16186 .35477 .15548 .34884 Metetra
0 .025 .124 r
.15548 .34884 .16186 .35477 .17083 .35153 .16445 .34569 Metetra
0 .026 .125 r
.16445 .34569 .17083 .35153 .1798 .34848 .17344 .34261 Metetra
0 .026 .125 r
.17344 .34261 .1798 .34848 .18881 .34529 .18247 .33944 Metetra
0 .027 .126 r
.18247 .33944 .18881 .34529 .19784 .34229 .19154 .33619 Metetra
0 .027 .127 r
.19154 .33619 .19784 .34229 .20692 .33918 .20064 .33292 Metetra
0 .027 .127 r
.20064 .33292 .20692 .33918 .21602 .33604 .20979 .32955 Metetra
0 .027 .127 r
.20979 .32955 .21602 .33604 .22519 .33264 .21897 .32613 Metetra
0 .027 .127 r
.21897 .32613 .22519 .33264 .23437 .32931 .22818 .32273 Metetra
0 .027 .127 r
.22818 .32273 .23437 .32931 .2436 .32592 .2374 .31956 Metetra
0 .028 .127 r
.2374 .31956 .2436 .32592 .25285 .32258 .24666 .31635 Metetra
0 .028 .128 r
.24666 .31635 .25285 .32258 .26212 .31941 .25593 .31339 Metetra
0 .029 .129 r
.25593 .31339 .26212 .31941 .27142 .31629 .26525 .31024 Metetra
0 .03 .131 r
.26525 .31024 .27142 .31629 .28074 .31337 .27458 .30731 Metetra
0 .031 .131 r
.27458 .30731 .28074 .31337 .29012 .30998 .28401 .30368 Metetra
0 .031 .131 r
.28401 .30368 .29012 .30998 .29953 .30677 .29345 .30025 Metetra
0 .031 .131 r
.29345 .30025 .29953 .30677 .309 .3032 .30294 .29662 Metetra
0 .031 .131 r
.30294 .29662 .309 .3032 .31846 .30011 .31243 .29334 Metetra
0 .032 .132 r
.31243 .29334 .31846 .30011 .32798 .29683 .32196 .29011 Metetra
0 .032 .133 r
.32196 .29011 .32798 .29683 .33752 .29361 .33155 .28655 Metetra
0 .033 .134 r
.33155 .28655 .33752 .29361 .34711 .29028 .34116 .28316 Metetra
0 .033 .133 r
.34116 .28316 .34711 .29028 .35675 .28653 .35082 .27946 Metetra
0 .033 .134 r
.35082 .27946 .35675 .28653 .3664 .28335 .36048 .27634 Metetra
0 .034 .135 r
.36048 .27634 .3664 .28335 .37609 .28002 .37018 .27326 Metetra
0 .035 .136 r
.37018 .27326 .37609 .28002 .38582 .27668 .37994 .26966 Metetra
0 .035 .136 r
.37994 .26966 .38582 .27668 .39559 .27328 .38972 .26627 Metetra
0 .035 .136 r
.38972 .26627 .39559 .27328 .40541 .26949 .39955 .26279 Metetra
0 .036 .137 r
.39955 .26279 .40541 .26949 .41524 .26627 .40941 .25941 Metetra
0 .037 .138 r
.40941 .25941 .41524 .26627 .42511 .26309 .4193 .25609 Metetra
0 .037 .138 r
.4193 .25609 .42511 .26309 .43504 .25906 .42925 .25223 Metetra
0 .036 .137 r
.42925 .25223 .43504 .25906 .44499 .25546 .43922 .24859 Metetra
0 .037 .138 r
.43922 .24859 .44499 .25546 .45497 .25228 .44923 .2452 Metetra
0 .037 .138 r
.44923 .2452 .45497 .25228 .46501 .24826 .45929 .24129 Metetra
0 .036 .137 r
.45929 .24129 .46501 .24826 .47508 .24425 .46938 .23738 Metetra
0 .035 .136 r
.46938 .23738 .47508 .24425 .48517 .24084 .4795 .2336 Metetra
0 .035 .136 r
.4795 .2336 .48517 .24084 .49531 .23705 .48967 .22975 Metetra
0 .035 .136 r
.48967 .22975 .49531 .23705 .50549 .23317 .49987 .22608 Metetra
0 .034 .135 r
.49987 .22608 .50549 .23317 .51571 .22926 .51011 .22189 Metetra
0 .033 .134 r
.51011 .22189 .51571 .22926 .52596 .22524 .52038 .21774 Metetra
0 .033 .133 r
.52038 .21774 .52596 .22524 .53625 .22179 .53069 .21418 Metetra
0 .033 .134 r
.53069 .21418 .53625 .22179 .54657 .21791 .54104 .21032 Metetra
0 .032 .133 r
.54104 .21032 .54657 .21791 .55694 .2139 .55143 .20661 Metetra
0 .032 .132 r
.55143 .20661 .55694 .2139 .56734 .20993 .56186 .20255 Metetra
0 .031 .131 r
.56186 .20255 .56734 .20993 .57777 .20582 .57232 .19856 Metetra
0 .031 .131 r
.57232 .19856 .57777 .20582 .58826 .20216 .58283 .19491 Metetra
0 .031 .131 r
.58283 .19491 .58826 .20216 .59877 .19816 .59338 .19109 Metetra
0 .031 .131 r
.59338 .19109 .59877 .19816 .60933 .19431 .60397 .18744 Metetra
0 .03 .131 r
.60397 .18744 .60933 .19431 .61992 .18999 .61459 .18309 Metetra
0 .029 .129 r
.61459 .18309 .61992 .18999 .63055 .18586 .62524 .17894 Metetra
0 .028 .128 r
.62524 .17894 .63055 .18586 .64122 .18178 .63593 .17459 Metetra
0 .028 .127 r
.63593 .17459 .64122 .18178 .65194 .17788 .64667 .1705 Metetra
0 .027 .127 r
.64667 .1705 .65194 .17788 .6627 .17404 .65745 .16639 Metetra
0 .027 .127 r
.65745 .16639 .6627 .17404 .6735 .17013 .66828 .1625 Metetra
0 .027 .127 r
.66828 .1625 .6735 .17013 .68434 .16629 .67915 .15863 Metetra
0 .027 .127 r
.67915 .15863 .68434 .16629 .69522 .16217 .69007 .1547 Metetra
0 .027 .127 r
.69007 .1547 .69522 .16217 .70613 .15801 .70102 .15065 Metetra
0 .027 .126 r
.70102 .15065 .70613 .15801 .71708 .15374 .71201 .14659 Metetra
0 .026 .125 r
.71201 .14659 .71708 .15374 .72808 .14964 .72304 .14243 Metetra
0 .026 .125 r
.72304 .14243 .72808 .14964 .73912 .14542 .73411 .13818 Metetra
0 .025 .124 r
.73411 .13818 .73912 .14542 .75021 .14139 .74522 .134 Metetra
0 .025 .124 r
.74522 .134 .75021 .14139 .76135 .13738 .75638 .12986 Metetra
0 .025 .124 r
.75638 .12986 .76135 .13738 .77253 .13342 .76758 .12568 Metetra
0 .025 .124 r
.13117 .34922 .13763 .35517 .14654 .35202 .1401 .346 Metetra
0 .025 .124 r
.1401 .346 .14654 .35202 .15548 .34884 .14907 .34268 Metetra
0 .025 .124 r
.14907 .34268 .15548 .34884 .16445 .34569 .15806 .33946 Metetra
0 .026 .125 r
.15806 .33946 .16445 .34569 .17344 .34261 .16708 .33629 Metetra
0 .026 .125 r
.16708 .33629 .17344 .34261 .18247 .33944 .17612 .33315 Metetra
0 .027 .126 r
.17612 .33315 .18247 .33944 .19154 .33619 .18521 .3299 Metetra
0 .027 .126 r
.18521 .3299 .19154 .33619 .20064 .33292 .19432 .32673 Metetra
0 .027 .126 r
.19432 .32673 .20064 .33292 .20979 .32955 .20347 .32341 Metetra
0 .027 .126 r
.20347 .32341 .20979 .32955 .21897 .32613 .21267 .32006 Metetra
0 .027 .126 r
.21267 .32006 .21897 .32613 .22818 .32273 .2219 .31659 Metetra
0 .027 .126 r
.2219 .31659 .22818 .32273 .2374 .31956 .23114 .31341 Metetra
0 .028 .127 r
.23114 .31341 .2374 .31956 .24666 .31635 .24042 .31009 Metetra
0 .028 .128 r
.24042 .31009 .24666 .31635 .25593 .31339 .24972 .30702 Metetra
0 .029 .129 r
.24972 .30702 .25593 .31339 .26525 .31024 .25907 .30364 Metetra
0 .03 .13 r
.25907 .30364 .26525 .31024 .27458 .30731 .26844 .30051 Metetra
0 .03 .131 r
.26844 .30051 .27458 .30731 .28401 .30368 .27789 .29684 Metetra
0 .03 .13 r
.27789 .29684 .28401 .30368 .29345 .30025 .28735 .29342 Metetra
0 .03 .13 r
.28735 .29342 .29345 .30025 .30294 .29662 .29684 .28999 Metetra
0 .03 .13 r
.29684 .28999 .30294 .29662 .31243 .29334 .30635 .28676 Metetra
0 .031 .132 r
.30635 .28676 .31243 .29334 .32196 .29011 .31589 .28369 Metetra
0 .032 .132 r
.31589 .28369 .32196 .29011 .33155 .28655 .3255 .28004 Metetra
0 .032 .132 r
.3255 .28004 .33155 .28655 .34116 .28316 .33512 .27665 Metetra
0 .032 .132 r
.33512 .27665 .34116 .28316 .35082 .27946 .3448 .27307 Metetra
0 .032 .133 r
.3448 .27307 .35082 .27946 .36048 .27634 .35449 .26986 Metetra
0 .033 .134 r
.35449 .26986 .36048 .27634 .37018 .27326 .3642 .26675 Metetra
0 .034 .135 r
.3642 .26675 .37018 .27326 .37994 .26966 .374 .2629 Metetra
0 .034 .135 r
.374 .2629 .37994 .26966 .38972 .26627 .38381 .25939 Metetra
0 .034 .136 r
.38381 .25939 .38972 .26627 .39955 .26279 .39365 .2561 Metetra
0 .035 .136 r
.39365 .2561 .39955 .26279 .40941 .25941 .40354 .25244 Metetra
0 .035 .137 r
.40354 .25244 .40941 .25941 .4193 .25609 .41346 .24884 Metetra
0 .035 .137 r
.41346 .24884 .4193 .25609 .42925 .25223 .42342 .24525 Metetra
0 .035 .136 r
.42342 .24525 .42925 .25223 .43922 .24859 .43342 .24159 Metetra
0 .035 .137 r
.43342 .24159 .43922 .24859 .44923 .2452 .44346 .23788 Metetra
0 .035 .137 r
.44346 .23788 .44923 .2452 .45929 .24129 .45353 .2342 Metetra
0 .035 .136 r
.45353 .2342 .45929 .24129 .46938 .23738 .46364 .23053 Metetra
0 .034 .136 r
.46364 .23053 .46938 .23738 .4795 .2336 .47379 .2265 Metetra
0 .034 .135 r
.47379 .2265 .4795 .2336 .48967 .22975 .48398 .22271 Metetra
0 .034 .135 r
.48398 .22271 .48967 .22975 .49987 .22608 .4942 .21925 Metetra
0 .033 .134 r
.4942 .21925 .49987 .22608 .51011 .22189 .50447 .21505 Metetra
0 .032 .133 r
.50447 .21505 .51011 .22189 .52038 .21774 .51477 .21094 Metetra
0 .032 .132 r
.51477 .21094 .52038 .21774 .53069 .21418 .5251 .20719 Metetra
0 .032 .132 r
.5251 .20719 .53069 .21418 .54104 .21032 .53548 .20329 Metetra
0 .032 .132 r
.53548 .20329 .54104 .21032 .55143 .20661 .54589 .19961 Metetra
0 .031 .132 r
.54589 .19961 .55143 .20661 .56186 .20255 .55634 .19536 Metetra
0 .03 .13 r
.55634 .19536 .56186 .20255 .57232 .19856 .56683 .19126 Metetra
0 .03 .13 r
.56683 .19126 .57232 .19856 .58283 .19491 .57736 .18736 Metetra
0 .03 .13 r
.57736 .18736 .58283 .19491 .59338 .19109 .58794 .18347 Metetra
0 .03 .131 r
.58794 .18347 .59338 .19109 .60397 .18744 .59855 .17981 Metetra
0 .03 .13 r
.59855 .17981 .60397 .18744 .61459 .18309 .6092 .17562 Metetra
0 .029 .129 r
.6092 .17562 .61459 .18309 .62524 .17894 .61989 .17165 Metetra
0 .028 .128 r
.61989 .17165 .62524 .17894 .63593 .17459 .63061 .16737 Metetra
0 .028 .127 r
.63061 .16737 .63593 .17459 .64667 .1705 .64138 .16334 Metetra
0 .027 .126 r
.64138 .16334 .64667 .1705 .65745 .16639 .65219 .15918 Metetra
0 .027 .126 r
.65219 .15918 .65745 .16639 .66828 .1625 .66305 .1553 Metetra
0 .027 .126 r
.66305 .1553 .66828 .1625 .67915 .15863 .67395 .15131 Metetra
0 .027 .126 r
.67395 .15131 .67915 .15863 .69007 .1547 .68489 .14728 Metetra
0 .027 .126 r
.68489 .14728 .69007 .1547 .70102 .15065 .69586 .14309 Metetra
0 .027 .126 r
.69586 .14309 .70102 .15065 .71201 .14659 .70688 .13896 Metetra
0 .026 .125 r
.70688 .13896 .71201 .14659 .72304 .14243 .71794 .13473 Metetra
0 .026 .125 r
.71794 .13473 .72304 .14243 .73411 .13818 .72904 .13052 Metetra
0 .025 .124 r
.72904 .13052 .73411 .13818 .74522 .134 .74018 .12636 Metetra
0 .025 .124 r
.74018 .12636 .74522 .134 .75638 .12986 .75138 .1223 Metetra
0 .025 .124 r
.75138 .1223 .75638 .12986 .76758 .12568 .76262 .11815 Metetra
0 .025 .124 r
.12468 .34319 .13117 .34922 .1401 .346 .13362 .33999 Metetra
0 .025 .124 r
.13362 .33999 .1401 .346 .14907 .34268 .14261 .33662 Metetra
0 .025 .124 r
.14261 .33662 .14907 .34268 .15806 .33946 .15162 .33337 Metetra
0 .025 .124 r
.15162 .33337 .15806 .33946 .16708 .33629 .16066 .33009 Metetra
0 .026 .125 r
.16066 .33009 .16708 .33629 .17612 .33315 .16972 .32693 Metetra
0 .026 .125 r
.16972 .32693 .17612 .33315 .18521 .3299 .17884 .32356 Metetra
0 .026 .126 r
.17884 .32356 .18521 .3299 .19432 .32673 .18797 .32036 Metetra
0 .027 .126 r
.18797 .32036 .19432 .32673 .20347 .32341 .19714 .31701 Metetra
0 .027 .126 r
.19714 .31701 .20347 .32341 .21267 .32006 .20634 .31375 Metetra
0 .027 .126 r
.20634 .31375 .21267 .32006 .2219 .31659 .21559 .31028 Metetra
0 .027 .127 r
.21559 .31028 .2219 .31659 .23114 .31341 .22484 .30722 Metetra
0 .028 .127 r
.22484 .30722 .23114 .31341 .24042 .31009 .23414 .3039 Metetra
0 .029 .128 r
.23414 .3039 .24042 .31009 .24972 .30702 .24345 .30081 Metetra
0 .029 .129 r
.24345 .30081 .24972 .30702 .25907 .30364 .25284 .29726 Metetra
0 .029 .129 r
.25284 .29726 .25907 .30364 .26844 .30051 .26224 .2939 Metetra
0 .029 .129 r
.26224 .2939 .26844 .30051 .27789 .29684 .27171 .29019 Metetra
0 .029 .129 r
.27171 .29019 .27789 .29684 .28735 .29342 .2812 .28667 Metetra
0 .029 .129 r
.2812 .28667 .28735 .29342 .29684 .28999 .2907 .28334 Metetra
0 .03 .13 r
.2907 .28334 .29684 .28999 .30635 .28676 .30024 .27998 Metetra
0 .031 .131 r
.30024 .27998 .30635 .28676 .31589 .28369 .30979 .27688 Metetra
0 .031 .131 r
.30979 .27688 .31589 .28369 .3255 .28004 .31943 .27317 Metetra
0 .031 .131 r
.31943 .27317 .3255 .28004 .33512 .27665 .32907 .26978 Metetra
0 .031 .132 r
.32907 .26978 .33512 .27665 .3448 .27307 .33875 .26644 Metetra
0 .032 .133 r
.33875 .26644 .3448 .27307 .35449 .26986 .34846 .26312 Metetra
0 .033 .134 r
.34846 .26312 .35449 .26986 .3642 .26675 .3582 .25997 Metetra
0 .034 .134 r
.3582 .25997 .3642 .26675 .374 .2629 .36802 .25611 Metetra
0 .033 .134 r
.36802 .25611 .374 .2629 .38381 .25939 .37785 .2526 Metetra
0 .034 .135 r
.37785 .2526 .38381 .25939 .39365 .2561 .3877 .24947 Metetra
0 .035 .136 r
.3877 .24947 .39365 .2561 .40354 .25244 .39762 .24564 Metetra
0 .034 .135 r
.39762 .24564 .40354 .25244 .41346 .24884 .40758 .24182 Metetra
0 .034 .136 r
.40758 .24182 .41346 .24884 .42342 .24525 .41755 .23849 Metetra
0 .035 .136 r
.41755 .23849 .42342 .24525 .43342 .24159 .42757 .2348 Metetra
0 .034 .136 r
.42757 .2348 .43342 .24159 .44346 .23788 .43764 .23078 Metetra
0 .034 .135 r
.43764 .23078 .44346 .23788 .45353 .2342 .44773 .22726 Metetra
0 .035 .136 r
.44773 .22726 .45353 .2342 .46364 .23053 .45786 .22372 Metetra
0 .034 .135 r
.45786 .22372 .46364 .23053 .47379 .2265 .46804 .21948 Metetra
0 .033 .134 r
.46804 .21948 .47379 .2265 .48398 .22271 .47825 .21564 Metetra
0 .034 .134 r
.47825 .21564 .48398 .22271 .4942 .21925 .4885 .21214 Metetra
0 .033 .134 r
.4885 .21214 .4942 .21925 .50447 .21505 .49879 .20795 Metetra
0 .032 .133 r
.49879 .20795 .50447 .21505 .51477 .21094 .50911 .20388 Metetra
0 .031 .132 r
.50911 .20388 .51477 .21094 .5251 .20719 .51947 .19984 Metetra
0 .031 .131 r
.51947 .19984 .5251 .20719 .53548 .20329 .52988 .19588 Metetra
0 .031 .131 r
.52988 .19588 .53548 .20329 .54589 .19961 .54032 .19222 Metetra
0 .031 .131 r
.54032 .19222 .54589 .19961 .55634 .19536 .55079 .18795 Metetra
0 .03 .13 r
.55079 .18795 .55634 .19536 .56683 .19126 .56131 .18393 Metetra
0 .029 .129 r
.56131 .18393 .56683 .19126 .57736 .18736 .57186 .17987 Metetra
0 .029 .129 r
.57186 .17987 .57736 .18736 .58794 .18347 .58246 .17602 Metetra
0 .029 .129 r
.58246 .17602 .58794 .18347 .59855 .17981 .59311 .17237 Metetra
0 .029 .129 r
.59311 .17237 .59855 .17981 .6092 .17562 .60378 .16836 Metetra
0 .029 .129 r
.60378 .16836 .6092 .17562 .61989 .17165 .61451 .16451 Metetra
0 .029 .128 r
.61451 .16451 .61989 .17165 .63061 .16737 .62526 .16021 Metetra
0 .028 .127 r
.62526 .16021 .63061 .16737 .64138 .16334 .63605 .15611 Metetra
0 .027 .127 r
.63605 .15611 .64138 .16334 .65219 .15918 .64688 .15179 Metetra
0 .027 .126 r
.64688 .15179 .65219 .15918 .66305 .1553 .65777 .14785 Metetra
0 .027 .126 r
.65777 .14785 .66305 .1553 .67395 .15131 .66869 .14373 Metetra
0 .027 .126 r
.66869 .14373 .67395 .15131 .68489 .14728 .67966 .13967 Metetra
0 .027 .126 r
.67966 .13967 .68489 .14728 .69586 .14309 .69066 .13546 Metetra
0 .026 .125 r
.69066 .13546 .69586 .14309 .70688 .13896 .70172 .13141 Metetra
0 .026 .125 r
.70172 .13141 .70688 .13896 .71794 .13473 .7128 .12715 Metetra
0 .025 .124 r
.7128 .12715 .71794 .13473 .72904 .13052 .72394 .123 Metetra
0 .025 .124 r
.72394 .123 .72904 .13052 .74018 .12636 .73512 .11881 Metetra
0 .025 .124 r
.73512 .11881 .74018 .12636 .75138 .1223 .74635 .11475 Metetra
0 .025 .124 r
.74635 .11475 .75138 .1223 .76262 .11815 .75762 .11052 Metetra
0 .025 .123 r
.11817 .3369 .12468 .34319 .13362 .33999 .12712 .33367 Metetra
0 .025 .123 r
.12712 .33367 .13362 .33999 .14261 .33662 .13613 .33029 Metetra
0 .025 .124 r
.13613 .33029 .14261 .33662 .15162 .33337 .14515 .32709 Metetra
0 .025 .124 r
.14515 .32709 .15162 .33337 .16066 .33009 .1542 .32385 Metetra
0 .026 .125 r
.1542 .32385 .16066 .33009 .16972 .32693 .16327 .3208 Metetra
0 .026 .125 r
.16327 .3208 .16972 .32693 .17884 .32356 .1724 .31745 Metetra
0 .026 .125 r
.1724 .31745 .17884 .32356 .18797 .32036 .18154 .31426 Metetra
0 .027 .126 r
.18154 .31426 .18797 .32036 .19714 .31701 .19074 .31081 Metetra
0 .027 .126 r
.19074 .31081 .19714 .31701 .20634 .31375 .19996 .30751 Metetra
0 .027 .126 r
.19996 .30751 .20634 .31375 .21559 .31028 .20924 .30394 Metetra
0 .027 .126 r
.20924 .30394 .21559 .31028 .22484 .30722 .21851 .30077 Metetra
0 .028 .127 r
.21851 .30077 .22484 .30722 .23414 .3039 .22784 .29737 Metetra
0 .028 .128 r
.22784 .29737 .23414 .3039 .24345 .30081 .23718 .29411 Metetra
0 .029 .128 r
.23718 .29411 .24345 .30081 .25284 .29726 .24659 .29052 Metetra
0 .028 .128 r
.24659 .29052 .25284 .29726 .26224 .2939 .25603 .28704 Metetra
0 .028 .128 r
.25603 .28704 .26224 .2939 .27171 .29019 .26549 .28354 Metetra
0 .028 .128 r
.26549 .28354 .27171 .29019 .2812 .28667 .27499 .28011 Metetra
0 .029 .128 r
.27499 .28011 .2812 .28667 .2907 .28334 .28449 .27697 Metetra
0 .029 .129 r
.28449 .27697 .2907 .28334 .30024 .27998 .29406 .27355 Metetra
0 .03 .13 r
.29406 .27355 .30024 .27998 .30979 .27688 .30364 .27033 Metetra
0 .03 .131 r
.30364 .27033 .30979 .27688 .31943 .27317 .31329 .26666 Metetra
0 .03 .131 r
.31329 .26666 .31943 .27317 .32907 .26978 .32296 .2632 Metetra
0 .031 .132 r
.32296 .2632 .32907 .26978 .33875 .26644 .33265 .26 Metetra
0 .032 .132 r
.33265 .26 .33875 .26644 .34846 .26312 .3424 .25641 Metetra
0 .033 .133 r
.3424 .25641 .34846 .26312 .3582 .25997 .35218 .25295 Metetra
0 .033 .134 r
.35218 .25295 .3582 .25997 .36802 .25611 .362 .24923 Metetra
0 .033 .133 r
.362 .24923 .36802 .25611 .37785 .2526 .37186 .24563 Metetra
0 .033 .134 r
.37186 .24563 .37785 .2526 .3877 .24947 .38174 .24237 Metetra
0 .034 .135 r
.38174 .24237 .3877 .24947 .39762 .24564 .39168 .2385 Metetra
0 .033 .134 r
.39168 .2385 .39762 .24564 .40758 .24182 .40166 .23457 Metetra
0 .033 .134 r
.40166 .23457 .40758 .24182 .41755 .23849 .41165 .23128 Metetra
0 .034 .135 r
.41165 .23128 .41755 .23849 .42757 .2348 .42169 .22757 Metetra
0 .033 .134 r
.42169 .22757 .42757 .2348 .43764 .23078 .43179 .22346 Metetra
0 .033 .134 r
.43179 .22346 .43764 .23078 .44773 .22726 .4419 .21997 Metetra
0 .034 .135 r
.4419 .21997 .44773 .22726 .45786 .22372 .45205 .21644 Metetra
0 .033 .134 r
.45205 .21644 .45786 .22372 .46804 .21948 .46225 .2123 Metetra
0 .033 .133 r
.46225 .2123 .46804 .21948 .47825 .21564 .47249 .20847 Metetra
0 .033 .134 r
.47249 .20847 .47825 .21564 .4885 .21214 .48276 .20479 Metetra
0 .033 .133 r
.48276 .20479 .4885 .21214 .49879 .20795 .49307 .20086 Metetra
0 .032 .132 r
.49307 .20086 .49879 .20795 .50911 .20388 .50342 .19701 Metetra
0 .031 .132 r
.50342 .19701 .50911 .20388 .51947 .19984 .51381 .19278 Metetra
0 .03 .131 r
.51381 .19278 .51947 .19984 .52988 .19588 .52423 .18883 Metetra
0 .03 .131 r
.52423 .18883 .52988 .19588 .54032 .19222 .5347 .18509 Metetra
0 .03 .13 r
.5347 .18509 .54032 .19222 .55079 .18795 .5452 .18089 Metetra
0 .029 .129 r
.5452 .18089 .55079 .18795 .56131 .18393 .55575 .17687 Metetra
0 .029 .128 r
.55575 .17687 .56131 .18393 .57186 .17987 .56633 .17258 Metetra
0 .028 .128 r
.56633 .17258 .57186 .17987 .58246 .17602 .57695 .16857 Metetra
0 .028 .128 r
.57695 .16857 .58246 .17602 .59311 .17237 .58761 .16465 Metetra
0 .028 .128 r
.58761 .16465 .59311 .17237 .60378 .16836 .59832 .16071 Metetra
0 .029 .128 r
.59832 .16071 .60378 .16836 .61451 .16451 .60907 .15686 Metetra
0 .028 .128 r
.60907 .15686 .61451 .16451 .62526 .16021 .61985 .15268 Metetra
0 .028 .127 r
.61985 .15268 .62526 .16021 .63605 .15611 .63068 .14862 Metetra
0 .027 .126 r
.63068 .14862 .63605 .15611 .64688 .15179 .64154 .14435 Metetra
0 .027 .126 r
.64154 .14435 .64688 .15179 .65777 .14785 .65246 .14046 Metetra
0 .027 .126 r
.65246 .14046 .65777 .14785 .66869 .14373 .66341 .13633 Metetra
0 .027 .126 r
.66341 .13633 .66869 .14373 .67966 .13967 .67441 .13232 Metetra
0 .026 .126 r
.67441 .13232 .67966 .13967 .69066 .13546 .68545 .12806 Metetra
0 .026 .125 r
.68545 .12806 .69066 .13546 .70172 .13141 .69653 .12394 Metetra
0 .026 .125 r
.69653 .12394 .70172 .13141 .7128 .12715 .70764 .11951 Metetra
0 .025 .124 r
.70764 .11951 .7128 .12715 .72394 .123 .7188 .11526 Metetra
0 .025 .124 r
.7188 .11526 .72394 .123 .73512 .11881 .73 .11098 Metetra
0 .025 .123 r
.73 .11098 .73512 .11881 .74635 .11475 .74126 .10687 Metetra
0 .025 .123 r
.74126 .10687 .74635 .11475 .75762 .11052 .75256 .10262 Metetra
0 .024 .123 r
.1116 .33068 .11817 .3369 .12712 .33367 .12057 .3275 Metetra
0 .025 .123 r
.12057 .3275 .12712 .33367 .13613 .33029 .12959 .32414 Metetra
0 .025 .123 r
.12959 .32414 .13613 .33029 .14515 .32709 .13862 .32097 Metetra
0 .025 .124 r
.13862 .32097 .14515 .32709 .1542 .32385 .14769 .31768 Metetra
0 .026 .125 r
.14769 .31768 .1542 .32385 .16327 .3208 .15677 .31461 Metetra
0 .026 .125 r
.15677 .31461 .16327 .3208 .1724 .31745 .16593 .31114 Metetra
0 .026 .126 r
.16593 .31114 .1724 .31745 .18154 .31426 .1751 .30786 Metetra
0 .027 .126 r
.1751 .30786 .18154 .31426 .19074 .31081 .18433 .30433 Metetra
0 .027 .126 r
.18433 .30433 .19074 .31081 .19996 .30751 .19356 .30103 Metetra
0 .027 .126 r
.19356 .30103 .19996 .30751 .20924 .30394 .20285 .29749 Metetra
0 .027 .126 r
.20285 .29749 .20924 .30394 .21851 .30077 .21214 .29431 Metetra
0 .027 .127 r
.21214 .29431 .21851 .30077 .22784 .29737 .22148 .29093 Metetra
0 .028 .127 r
.22148 .29093 .22784 .29737 .23718 .29411 .23085 .28759 Metetra
0 .028 .127 r
.23085 .28759 .23718 .29411 .24659 .29052 .24028 .284 Metetra
0 .028 .127 r
.24028 .284 .24659 .29052 .25603 .28704 .24974 .28041 Metetra
0 .028 .127 r
.24974 .28041 .25603 .28704 .26549 .28354 .25922 .27703 Metetra
0 .028 .127 r
.25922 .27703 .26549 .28354 .27499 .28011 .26873 .27359 Metetra
0 .029 .128 r
.26873 .27359 .27499 .28011 .28449 .27697 .27825 .27046 Metetra
0 .029 .129 r
.27825 .27046 .28449 .27697 .29406 .27355 .28785 .26689 Metetra
0 .03 .13 r
.28785 .26689 .29406 .27355 .30364 .27033 .29746 .26345 Metetra
0 .03 .13 r
.29746 .26345 .30364 .27033 .31329 .26666 .30713 .25987 Metetra
0 .03 .13 r
.30713 .25987 .31329 .26666 .32296 .2632 .31682 .25635 Metetra
0 .031 .131 r
.31682 .25635 .32296 .2632 .33265 .26 .32652 .25318 Metetra
0 .032 .132 r
.32652 .25318 .33265 .26 .3424 .25641 .3363 .24945 Metetra
0 .032 .132 r
.3363 .24945 .3424 .25641 .35218 .25295 .34611 .24575 Metetra
0 .032 .132 r
.34611 .24575 .35218 .25295 .362 .24923 .35595 .24225 Metetra
0 .032 .132 r
.35595 .24225 .362 .24923 .37186 .24563 .36583 .23863 Metetra
0 .032 .133 r
.36583 .23863 .37186 .24563 .38174 .24237 .37574 .23513 Metetra
0 .033 .133 r
.37574 .23513 .38174 .24237 .39168 .2385 .38569 .23134 Metetra
0 .032 .132 r
.38569 .23134 .39168 .2385 .40166 .23457 .39569 .22747 Metetra
0 .032 .133 r
.39569 .22747 .40166 .23457 .41165 .23128 .40571 .22403 Metetra
0 .033 .133 r
.40571 .22403 .41165 .23128 .42169 .22757 .41578 .22031 Metetra
0 .032 .133 r
.41578 .22031 .42169 .22757 .43179 .22346 .42589 .21628 Metetra
0 .032 .132 r
.42589 .21628 .43179 .22346 .4419 .21997 .43603 .21267 Metetra
0 .033 .133 r
.43603 .21267 .4419 .21997 .45205 .21644 .4462 .20902 Metetra
0 .032 .133 r
.4462 .20902 .45205 .21644 .46225 .2123 .45643 .20506 Metetra
0 .032 .132 r
.45643 .20506 .46225 .2123 .47249 .20847 .46668 .2012 Metetra
0 .032 .132 r
.46668 .2012 .47249 .20847 .48276 .20479 .47698 .19724 Metetra
0 .032 .132 r
.47698 .19724 .48276 .20479 .49307 .20086 .48731 .1935 Metetra
0 .032 .132 r
.48731 .1935 .49307 .20086 .50342 .19701 .49769 .18976 Metetra
0 .031 .131 r
.49769 .18976 .50342 .19701 .51381 .19278 .5081 .18546 Metetra
0 .03 .13 r
.5081 .18546 .51381 .19278 .52423 .18883 .51855 .18149 Metetra
0 .03 .13 r
.51855 .18149 .52423 .18883 .5347 .18509 .52904 .17761 Metetra
0 .03 .13 r
.52904 .17761 .5347 .18509 .5452 .18089 .53957 .1736 Metetra
0 .029 .129 r
.53957 .1736 .5452 .18089 .55575 .17687 .55015 .16968 Metetra
0 .029 .128 r
.55015 .16968 .55575 .17687 .56633 .17258 .56075 .16533 Metetra
0 .028 .127 r
.56075 .16533 .56633 .17258 .57695 .16857 .5714 .16127 Metetra
0 .028 .127 r
.5714 .16127 .57695 .16857 .58761 .16465 .58209 .15717 Metetra
0 .028 .127 r
.58209 .15717 .58761 .16465 .59832 .16071 .59283 .15329 Metetra
0 .028 .127 r
.59283 .15329 .59832 .16071 .60907 .15686 .6036 .14939 Metetra
0 .028 .127 r
.6036 .14939 .60907 .15686 .61985 .15268 .61442 .14524 Metetra
0 .027 .127 r
.61442 .14524 .61985 .15268 .63068 .14862 .62527 .14111 Metetra
0 .027 .126 r
.62527 .14111 .63068 .14862 .64154 .14435 .63616 .13679 Metetra
0 .027 .126 r
.63616 .13679 .64154 .14435 .65246 .14046 .6471 .13282 Metetra
0 .027 .126 r
.6471 .13282 .65246 .14046 .66341 .13633 .65808 .12863 Metetra
0 .027 .126 r
.65808 .12863 .66341 .13633 .67441 .13232 .66912 .12465 Metetra
0 .026 .126 r
.66912 .12465 .67441 .13232 .68545 .12806 .68018 .12044 Metetra
0 .026 .125 r
.68018 .12044 .68545 .12806 .69653 .12394 .6913 .11639 Metetra
0 .026 .125 r
.6913 .11639 .69653 .12394 .70764 .11951 .70244 .11193 Metetra
0 .025 .124 r
.70244 .11193 .70764 .11951 .7188 .11526 .71363 .10769 Metetra
0 .025 .123 r
.71363 .10769 .7188 .11526 .73 .11098 .72486 .10331 Metetra
0 .025 .123 r
.72486 .10331 .73 .11098 .74126 .10687 .73615 .09913 Metetra
0 .024 .123 r
.73615 .09913 .74126 .10687 .75256 .10262 .74747 .09477 Metetra
0 .024 .122 r
.10501 .32428 .1116 .33068 .12057 .3275 .11398 .32118 Metetra
0 .024 .123 r
.11398 .32118 .12057 .3275 .12959 .32414 .123 .31791 Metetra
0 .025 .124 r
.123 .31791 .12959 .32414 .13862 .32097 .13203 .31486 Metetra
0 .025 .124 r
.13203 .31486 .13862 .32097 .14769 .31768 .14112 .31159 Metetra
0 .026 .125 r
.14112 .31159 .14769 .31768 .15677 .31461 .15021 .30855 Metetra
0 .027 .126 r
.15021 .30855 .15677 .31461 .16593 .31114 .1594 .30497 Metetra
0 .026 .126 r
.1594 .30497 .16593 .31114 .1751 .30786 .1686 .30155 Metetra
0 .026 .125 r
.1686 .30155 .1751 .30786 .18433 .30433 .17786 .29791 Metetra
0 .026 .125 r
.17786 .29791 .18433 .30433 .19356 .30103 .18712 .29452 Metetra
0 .026 .125 r
.18712 .29452 .19356 .30103 .20285 .29749 .19643 .29097 Metetra
0 .026 .125 r
.19643 .29097 .20285 .29749 .21214 .29431 .20575 .28763 Metetra
0 .027 .126 r
.20575 .28763 .21214 .29431 .22148 .29093 .21511 .28424 Metetra
0 .027 .126 r
.21511 .28424 .22148 .29093 .23085 .28759 .22451 .28078 Metetra
0 .027 .127 r
.22451 .28078 .23085 .28759 .24028 .284 .23394 .2773 Metetra
0 .027 .126 r
.23394 .2773 .24028 .284 .24974 .28041 .24342 .27369 Metetra
0 .027 .127 r
.24342 .27369 .24974 .28041 .25922 .27703 .25289 .27054 Metetra
0 .028 .128 r
.25289 .27054 .25922 .27703 .26873 .27359 .26242 .26719 Metetra
0 .029 .129 r
.26242 .26719 .26873 .27359 .27825 .27046 .27196 .26407 Metetra
0 .03 .13 r
.27196 .26407 .27825 .27046 .28785 .26689 .28157 .26044 Metetra
0 .03 .13 r
.28157 .26044 .28785 .26689 .29746 .26345 .29123 .25677 Metetra
0 .03 .13 r
.29123 .25677 .29746 .26345 .30713 .25987 .3009 .25335 Metetra
0 .03 .13 r
.3009 .25335 .30713 .25987 .31682 .25635 .31062 .24977 Metetra
0 .031 .131 r
.31062 .24977 .31682 .25635 .32652 .25318 .32035 .24645 Metetra
0 .031 .131 r
.32035 .24645 .32652 .25318 .3363 .24945 .33016 .24259 Metetra
0 .03 .131 r
.33016 .24259 .3363 .24945 .34611 .24575 .34 .23864 Metetra
0 .031 .131 r
.34 .23864 .34611 .24575 .35595 .24225 .34985 .23529 Metetra
0 .031 .131 r
.34985 .23529 .35595 .24225 .36583 .23863 .35975 .23161 Metetra
0 .031 .131 r
.35975 .23161 .36583 .23863 .37574 .23513 .3697 .22774 Metetra
0 .031 .131 r
.3697 .22774 .37574 .23513 .38569 .23134 .37967 .22409 Metetra
0 .031 .131 r
.37967 .22409 .38569 .23134 .39569 .22747 .38969 .22037 Metetra
0 .031 .131 r
.38969 .22037 .39569 .22747 .40571 .22403 .39974 .21661 Metetra
0 .031 .132 r
.39974 .21661 .40571 .22403 .41578 .22031 .40982 .21287 Metetra
0 .031 .131 r
.40982 .21287 .41578 .22031 .42589 .21628 .41995 .20911 Metetra
0 .031 .131 r
.41995 .20911 .42589 .21628 .43603 .21267 .43012 .20529 Metetra
0 .031 .131 r
.43012 .20529 .43603 .21267 .4462 .20902 .44032 .20145 Metetra
0 .031 .131 r
.44032 .20145 .4462 .20902 .45643 .20506 .45056 .19782 Metetra
0 .031 .131 r
.45056 .19782 .45643 .20506 .46668 .2012 .46084 .19397 Metetra
0 .031 .131 r
.46084 .19397 .46668 .2012 .47698 .19724 .47116 .1898 Metetra
0 .03 .131 r
.47116 .1898 .47698 .19724 .48731 .1935 .48152 .18623 Metetra
0 .031 .131 r
.48152 .18623 .48731 .1935 .49769 .18976 .49191 .18258 Metetra
0 .031 .131 r
.49191 .18258 .49769 .18976 .5081 .18546 .50235 .17839 Metetra
0 .03 .13 r
.50235 .17839 .5081 .18546 .51855 .18149 .51283 .17443 Metetra
0 .03 .13 r
.51283 .17443 .51855 .18149 .52904 .17761 .52335 .17033 Metetra
0 .03 .13 r
.52335 .17033 .52904 .17761 .53957 .1736 .53391 .16649 Metetra
0 .03 .13 r
.53391 .16649 .53957 .1736 .55015 .16968 .54451 .16259 Metetra
0 .029 .129 r
.54451 .16259 .55015 .16968 .56075 .16533 .55514 .15818 Metetra
0 .028 .128 r
.55514 .15818 .56075 .16533 .5714 .16127 .56582 .15398 Metetra
0 .027 .127 r
.56582 .15398 .5714 .16127 .58209 .15717 .57653 .1496 Metetra
0 .027 .126 r
.57653 .1496 .58209 .15717 .59283 .15329 .58729 .14567 Metetra
0 .027 .127 r
.58729 .14567 .59283 .15329 .6036 .14939 .59809 .14162 Metetra
0 .027 .126 r
.59809 .14162 .6036 .14939 .61442 .14524 .60893 .13753 Metetra
0 .027 .126 r
.60893 .13753 .61442 .14524 .62527 .14111 .61981 .13337 Metetra
0 .026 .125 r
.61981 .13337 .62527 .14111 .63616 .13679 .63074 .12916 Metetra
0 .026 .125 r
.63074 .12916 .63616 .13679 .6471 .13282 .64171 .12514 Metetra
0 .026 .125 r
.64171 .12514 .6471 .13282 .65808 .12863 .65272 .12098 Metetra
0 .026 .125 r
.65272 .12098 .65808 .12863 .66912 .12465 .66379 .11707 Metetra
0 .026 .126 r
.66379 .11707 .66912 .12465 .68018 .12044 .67489 .11294 Metetra
0 .027 .126 r
.67489 .11294 .68018 .12044 .6913 .11639 .68604 .10895 Metetra
0 .026 .125 r
.68604 .10895 .6913 .11639 .70244 .11193 .69721 .10442 Metetra
0 .026 .124 r
.69721 .10442 .70244 .11193 .71363 .10769 .70843 .10009 Metetra
0 .025 .124 r
.70843 .10009 .71363 .10769 .72486 .10331 .71968 .09555 Metetra
0 .024 .123 r
.71968 .09555 .72486 .10331 .73615 .09913 .731 .09121 Metetra
0 .024 .122 r
.731 .09121 .73615 .09913 .74747 .09477 .74234 .08672 Metetra
0 .024 .122 r
.09832 .31824 .10501 .32428 .11398 .32118 .10731 .31511 Metetra
0 .025 .123 r
.10731 .31511 .11398 .32118 .123 .31791 .11635 .31181 Metetra
0 .025 .124 r
.11635 .31181 .123 .31791 .13203 .31486 .12542 .30862 Metetra
0 .026 .124 r
.12542 .30862 .13203 .31486 .14112 .31159 .13454 .3052 Metetra
0 .026 .125 r
.13454 .3052 .14112 .31159 .15021 .30855 .14367 .30195 Metetra
0 .026 .125 r
.14367 .30195 .15021 .30855 .1594 .30497 .15288 .29833 Metetra
0 .026 .125 r
.15288 .29833 .1594 .30497 .1686 .30155 .1621 .29486 Metetra
0 .026 .125 r
.1621 .29486 .1686 .30155 .17786 .29791 .17136 .29131 Metetra
0 .026 .125 r
.17136 .29131 .17786 .29791 .18712 .29452 .18063 .28799 Metetra
0 .026 .125 r
.18063 .28799 .18712 .29452 .19643 .29097 .18994 .28461 Metetra
0 .026 .125 r
.18994 .28461 .19643 .29097 .20575 .28763 .19928 .28127 Metetra
0 .027 .126 r
.19928 .28127 .20575 .28763 .21511 .28424 .20865 .27791 Metetra
0 .027 .126 r
.20865 .27791 .21511 .28424 .22451 .28078 .21808 .27435 Metetra
0 .027 .126 r
.21808 .27435 .22451 .28078 .23394 .2773 .22753 .27088 Metetra
0 .027 .126 r
.22753 .27088 .23394 .2773 .24342 .27369 .23703 .2672 Metetra
0 .027 .127 r
.23703 .2672 .24342 .27369 .25289 .27054 .24653 .26398 Metetra
0 .028 .128 r
.24653 .26398 .25289 .27054 .26242 .26719 .25608 .26053 Metetra
0 .029 .129 r
.25608 .26053 .26242 .26719 .27196 .26407 .26566 .25711 Metetra
0 .029 .129 r
.26566 .25711 .27196 .26407 .28157 .26044 .2753 .25343 Metetra
0 .029 .129 r
.2753 .25343 .28157 .26044 .29123 .25677 .28499 .24962 Metetra
0 .029 .129 r
.28499 .24962 .29123 .25677 .3009 .25335 .29467 .24628 Metetra
0 .03 .13 r
.29467 .24628 .3009 .25335 .31062 .24977 .3044 .24269 Metetra
0 .03 .13 r
.3044 .24269 .31062 .24977 .32035 .24645 .31417 .23916 Metetra
0 .03 .13 r
.31417 .23916 .32035 .24645 .33016 .24259 .32399 .2354 Metetra
0 .029 .129 r
.32399 .2354 .33016 .24259 .34 .23864 .33385 .23152 Metetra
0 .03 .13 r
.33385 .23152 .34 .23864 .34985 .23529 .34372 .22818 Metetra
0 .03 .13 r
.34372 .22818 .34985 .23529 .35975 .23161 .35364 .22452 Metetra
0 .03 .13 r
.35364 .22452 .35975 .23161 .3697 .22774 .36361 .22052 Metetra
0 .03 .13 r
.36361 .22052 .3697 .22774 .37967 .22409 .3736 .21697 Metetra
0 .03 .13 r
.3736 .21697 .37967 .22409 .38969 .22037 .38363 .21339 Metetra
0 .03 .13 r
.38363 .21339 .38969 .22037 .39974 .21661 .39371 .20941 Metetra
0 .03 .13 r
.39371 .20941 .39974 .21661 .40982 .21287 .40382 .20563 Metetra
0 .03 .13 r
.40382 .20563 .40982 .21287 .41995 .20911 .41397 .20204 Metetra
0 .03 .13 r
.41397 .20204 .41995 .20911 .43012 .20529 .42416 .19805 Metetra
0 .03 .13 r
.42416 .19805 .43012 .20529 .44032 .20145 .43439 .19404 Metetra
0 .03 .13 r
.43439 .19404 .44032 .20145 .45056 .19782 .44465 .19048 Metetra
0 .03 .13 r
.44465 .19048 .45056 .19782 .46084 .19397 .45496 .18657 Metetra
0 .03 .13 r
.45496 .18657 .46084 .19397 .47116 .1898 .46531 .18234 Metetra
0 .029 .129 r
.46531 .18234 .47116 .1898 .48152 .18623 .47569 .17864 Metetra
0 .03 .13 r
.47569 .17864 .48152 .18623 .49191 .18258 .48611 .17485 Metetra
0 .03 .13 r
.48611 .17485 .49191 .18258 .50235 .17839 .49657 .17081 Metetra
0 .03 .13 r
.49657 .17081 .50235 .17839 .51283 .17443 .50707 .1668 Metetra
0 .029 .129 r
.50707 .1668 .51283 .17443 .52335 .17033 .51762 .16257 Metetra
0 .029 .129 r
.51762 .16257 .52335 .17033 .53391 .16649 .5282 .15881 Metetra
0 .029 .129 r
.5282 .15881 .53391 .16649 .54451 .16259 .53882 .15492 Metetra
0 .029 .129 r
.53882 .15492 .54451 .16259 .55514 .15818 .54949 .15076 Metetra
0 .028 .128 r
.54949 .15076 .55514 .15818 .56582 .15398 .56019 .14661 Metetra
0 .027 .127 r
.56019 .14661 .56582 .15398 .57653 .1496 .57093 .14224 Metetra
0 .027 .126 r
.57093 .14224 .57653 .1496 .58729 .14567 .58172 .13832 Metetra
0 .027 .126 r
.58172 .13832 .58729 .14567 .59809 .14162 .59255 .13422 Metetra
0 .027 .126 r
.59255 .13422 .59809 .14162 .60893 .13753 .60342 .13018 Metetra
0 .027 .126 r
.60342 .13018 .60893 .13753 .61981 .13337 .61433 .12594 Metetra
0 .026 .125 r
.61433 .12594 .61981 .13337 .63074 .12916 .62528 .12167 Metetra
0 .026 .125 r
.62528 .12167 .63074 .12916 .64171 .12514 .63628 .11743 Metetra
0 .026 .125 r
.63628 .11743 .64171 .12514 .65272 .12098 .64731 .11315 Metetra
0 .026 .125 r
.64731 .11315 .65272 .12098 .66379 .11707 .6584 .10908 Metetra
0 .026 .125 r
.6584 .10908 .66379 .11707 .67489 .11294 .66953 .10495 Metetra
0 .026 .125 r
.66953 .10495 .67489 .11294 .68604 .10895 .68072 .10095 Metetra
0 .026 .125 r
.68072 .10095 .68604 .10895 .69721 .10442 .69192 .09658 Metetra
0 .026 .125 r
.69192 .09658 .69721 .10442 .70843 .10009 .70319 .09236 Metetra
0 .025 .124 r
.70319 .09236 .70843 .10009 .71968 .09555 .71448 .0879 Metetra
0 .025 .123 r
.71448 .0879 .71968 .09555 .731 .09121 .72582 .08355 Metetra
0 .024 .122 r
.72582 .08355 .731 .09121 .74234 .08672 .7372 .07903 Metetra
0 .024 .123 r
.09161 .31202 .09832 .31824 .10731 .31511 .10061 .30891 Metetra
0 .025 .124 r
.10061 .30891 .10731 .31511 .11635 .31181 .10967 .30563 Metetra
0 .025 .124 r
.10967 .30563 .11635 .31181 .12542 .30862 .11875 .3024 Metetra
0 .026 .125 r
.11875 .3024 .12542 .30862 .13454 .3052 .12789 .2989 Metetra
0 .026 .125 r
.12789 .2989 .13454 .3052 .14367 .30195 .13706 .29551 Metetra
0 .026 .125 r
.13706 .29551 .14367 .30195 .15288 .29833 .14629 .29185 Metetra
0 .025 .124 r
.14629 .29185 .15288 .29833 .1621 .29486 .15554 .28829 Metetra
0 .025 .124 r
.15554 .28829 .1621 .29486 .17136 .29131 .16481 .28475 Metetra
0 .025 .124 r
.16481 .28475 .17136 .29131 .18063 .28799 .17411 .28139 Metetra
0 .026 .125 r
.17411 .28139 .18063 .28799 .18994 .28461 .18342 .27807 Metetra
0 .026 .125 r
.18342 .27807 .18994 .28461 .19928 .28127 .19279 .27464 Metetra
0 .027 .126 r
.19279 .27464 .19928 .28127 .20865 .27791 .20217 .27128 Metetra
0 .027 .126 r
.20217 .27128 .20865 .27791 .21808 .27435 .21162 .26768 Metetra
0 .027 .126 r
.21162 .26768 .21808 .27435 .22753 .27088 .22108 .26429 Metetra
0 .027 .126 r
.22108 .26429 .22753 .27088 .23703 .2672 .2306 .26068 Metetra
0 .027 .127 r
.2306 .26068 .23703 .2672 .24653 .26398 .24011 .25745 Metetra
0 .028 .128 r
.24011 .25745 .24653 .26398 .25608 .26053 .24968 .25398 Metetra
0 .029 .128 r
.24968 .25398 .25608 .26053 .26566 .25711 .2593 .25036 Metetra
0 .029 .128 r
.2593 .25036 .26566 .25711 .2753 .25343 .26896 .24668 Metetra
0 .028 .128 r
.26896 .24668 .2753 .25343 .28499 .24962 .27867 .24282 Metetra
0 .028 .128 r
.27867 .24282 .28499 .24962 .29467 .24628 .28837 .23946 Metetra
0 .029 .129 r
.28837 .23946 .29467 .24628 .3044 .24269 .29813 .23582 Metetra
0 .029 .129 r
.29813 .23582 .3044 .24269 .31417 .23916 .30794 .23201 Metetra
0 .029 .129 r
.30794 .23201 .31417 .23916 .32399 .2354 .31777 .22832 Metetra
0 .029 .128 r
.31777 .22832 .32399 .2354 .33385 .23152 .32765 .2245 Metetra
0 .029 .129 r
.32765 .2245 .33385 .23152 .34372 .22818 .33754 .221 Metetra
0 .029 .129 r
.33754 .221 .34372 .22818 .35364 .22452 .34749 .21729 Metetra
0 .029 .129 r
.34749 .21729 .35364 .22452 .36361 .22052 .35749 .21324 Metetra
0 .029 .129 r
.35749 .21324 .36361 .22052 .3736 .21697 .3675 .20969 Metetra
0 .029 .129 r
.3675 .20969 .3736 .21697 .38363 .21339 .37754 .20614 Metetra
0 .029 .129 r
.37754 .20614 .38363 .21339 .39371 .20941 .38765 .20203 Metetra
0 .029 .129 r
.38765 .20203 .39371 .20941 .40382 .20563 .39779 .19822 Metetra
0 .029 .129 r
.39779 .19822 .40382 .20563 .41397 .20204 .40795 .19472 Metetra
0 .029 .129 r
.40795 .19472 .41397 .20204 .42416 .19805 .41817 .19064 Metetra
0 .029 .128 r
.41817 .19064 .42416 .19805 .43439 .19404 .42842 .18657 Metetra
0 .029 .129 r
.42842 .18657 .43439 .19404 .44465 .19048 .4387 .183 Metetra
0 .029 .129 r
.4387 .183 .44465 .19048 .45496 .18657 .44903 .1791 Metetra
0 .029 .129 r
.44903 .1791 .45496 .18657 .46531 .18234 .45941 .17497 Metetra
0 .028 .128 r
.45941 .17497 .46531 .18234 .47569 .17864 .46981 .17116 Metetra
0 .029 .129 r
.46981 .17116 .47569 .17864 .48611 .17485 .48026 .16725 Metetra
0 .029 .129 r
.48026 .16725 .48611 .17485 .49657 .17081 .49074 .16343 Metetra
0 .029 .129 r
.49074 .16343 .49657 .17081 .50707 .1668 .50127 .15944 Metetra
0 .028 .128 r
.50127 .15944 .50707 .1668 .51762 .16257 .51184 .15517 Metetra
0 .028 .128 r
.51184 .15517 .51762 .16257 .5282 .15881 .52245 .15139 Metetra
0 .029 .128 r
.52245 .15139 .5282 .15881 .53882 .15492 .5331 .14745 Metetra
0 .029 .128 r
.5331 .14745 .53882 .15492 .54949 .15076 .54379 .14344 Metetra
0 .028 .128 r
.54379 .14344 .54949 .15076 .56019 .14661 .55452 .13927 Metetra
0 .027 .127 r
.55452 .13927 .56019 .14661 .57093 .14224 .56529 .13485 Metetra
0 .027 .126 r
.56529 .13485 .57093 .14224 .58172 .13832 .57611 .13081 Metetra
0 .027 .126 r
.57611 .13081 .58172 .13832 .59255 .13422 .58696 .12656 Metetra
0 .027 .126 r
.58696 .12656 .59255 .13422 .60342 .13018 .59787 .12252 Metetra
0 .027 .126 r
.59787 .12252 .60342 .13018 .61433 .12594 .6088 .11823 Metetra
0 .026 .125 r
.6088 .11823 .61433 .12594 .62528 .12167 .61978 .11399 Metetra
0 .026 .125 r
.61978 .11399 .62528 .12167 .63628 .11743 .63081 .10964 Metetra
0 .025 .124 r
.63081 .10964 .63628 .11743 .64731 .11315 .64187 .10534 Metetra
0 .025 .124 r
.64187 .10534 .64731 .11315 .6584 .10908 .65299 .1012 Metetra
0 .025 .124 r
.65299 .1012 .6584 .10908 .66953 .10495 .66415 .0971 Metetra
0 .026 .125 r
.66415 .0971 .66953 .10495 .68072 .10095 .67536 .0931 Metetra
0 .026 .125 r
.67536 .0931 .68072 .10095 .69192 .09658 .68661 .08882 Metetra
0 .026 .125 r
.68661 .08882 .69192 .09658 .70319 .09236 .69791 .08463 Metetra
0 .025 .124 r
.69791 .08463 .70319 .09236 .71448 .0879 .70923 .08017 Metetra
0 .025 .124 r
.70923 .08017 .71448 .0879 .72582 .08355 .72061 .07574 Metetra
0 .024 .123 r
.72061 .07574 .72582 .08355 .7372 .07903 .73201 .07114 Metetra
0 .025 .123 r
.08483 .30589 .09161 .31202 .10061 .30891 .09387 .30262 Metetra
0 .025 .124 r
.09387 .30262 .10061 .30891 .10967 .30563 .10295 .29926 Metetra
0 .025 .124 r
.10295 .29926 .10967 .30563 .11875 .3024 .11207 .29585 Metetra
0 .025 .124 r
.11207 .29585 .11875 .3024 .12789 .2989 .12124 .29229 Metetra
0 .025 .124 r
.12124 .29229 .12789 .2989 .13706 .29551 .13044 .28878 Metetra
0 .025 .124 r
.13044 .28878 .13706 .29551 .14629 .29185 .13967 .28523 Metetra
0 .025 .123 r
.13967 .28523 .14629 .29185 .15554 .28829 .14893 .28171 Metetra
0 .025 .123 r
.14893 .28171 .15554 .28829 .16481 .28475 .1582 .27832 Metetra
0 .025 .124 r
.1582 .27832 .16481 .28475 .17411 .28139 .16751 .27497 Metetra
0 .026 .125 r
.16751 .27497 .17411 .28139 .18342 .27807 .17683 .27175 Metetra
0 .026 .125 r
.17683 .27175 .18342 .27807 .19279 .27464 .18622 .26821 Metetra
0 .027 .126 r
.18622 .26821 .19279 .27464 .20217 .27128 .19564 .26478 Metetra
0 .027 .126 r
.19564 .26478 .20217 .27128 .21162 .26768 .20511 .26108 Metetra
0 .027 .126 r
.20511 .26108 .21162 .26768 .22108 .26429 .21459 .25766 Metetra
0 .027 .126 r
.21459 .25766 .22108 .26429 .2306 .26068 .22412 .25409 Metetra
0 .027 .127 r
.22412 .25409 .2306 .26068 .24011 .25745 .23368 .25063 Metetra
0 .028 .128 r
.23368 .25063 .24011 .25745 .24968 .25398 .24328 .24706 Metetra
0 .028 .128 r
.24328 .24706 .24968 .25398 .2593 .25036 .25293 .24322 Metetra
0 .028 .127 r
.25293 .24322 .2593 .25036 .26896 .24668 .2626 .23961 Metetra
0 .028 .127 r
.2626 .23961 .26896 .24668 .27867 .24282 .27232 .23584 Metetra
0 .028 .127 r
.27232 .23584 .27867 .24282 .28837 .23946 .28205 .23237 Metetra
0 .028 .128 r
.28205 .23237 .28837 .23946 .29813 .23582 .29183 .22872 Metetra
0 .028 .128 r
.29183 .22872 .29813 .23582 .30794 .23201 .30166 .2248 Metetra
0 .028 .127 r
.30166 .2248 .30794 .23201 .31777 .22832 .31151 .22122 Metetra
0 .028 .127 r
.31151 .22122 .31777 .22832 .32765 .2245 .3214 .21757 Metetra
0 .028 .128 r
.3214 .21757 .32765 .2245 .33754 .221 .33132 .21387 Metetra
0 .028 .128 r
.33132 .21387 .33754 .221 .34749 .21729 .34129 .21015 Metetra
0 .028 .128 r
.34129 .21015 .34749 .21729 .35749 .21324 .3513 .20623 Metetra
0 .028 .128 r
.3513 .20623 .35749 .21324 .3675 .20969 .36134 .20259 Metetra
0 .029 .128 r
.36134 .20259 .3675 .20969 .37754 .20614 .37141 .19899 Metetra
0 .029 .128 r
.37141 .19899 .37754 .20614 .38765 .20203 .38154 .19491 Metetra
0 .028 .128 r
.38154 .19491 .38765 .20203 .39779 .19822 .3917 .19107 Metetra
0 .029 .128 r
.3917 .19107 .39779 .19822 .40795 .19472 .40188 .18748 Metetra
0 .029 .128 r
.40188 .18748 .40795 .19472 .41817 .19064 .41213 .18342 Metetra
0 .028 .128 r
.41213 .18342 .41817 .19064 .42842 .18657 .42241 .17937 Metetra
0 .028 .128 r
.42241 .17937 .42842 .18657 .4387 .183 .43271 .17562 Metetra
0 .028 .128 r
.43271 .17562 .4387 .183 .44903 .1791 .44307 .17168 Metetra
0 .028 .128 r
.44307 .17168 .44903 .1791 .45941 .17497 .45346 .1677 Metetra
0 .028 .127 r
.45346 .1677 .45941 .17497 .46981 .17116 .4639 .16366 Metetra
0 .028 .127 r
.4639 .16366 .46981 .17116 .48026 .16725 .47437 .15957 Metetra
0 .028 .128 r
.47437 .15957 .48026 .16725 .49074 .16343 .48488 .15582 Metetra
0 .028 .128 r
.48488 .15582 .49074 .16343 .50127 .15944 .49543 .15179 Metetra
0 .028 .127 r
.49543 .15179 .50127 .15944 .51184 .15517 .50603 .14757 Metetra
0 .028 .127 r
.50603 .14757 .51184 .15517 .52245 .15139 .51666 .14364 Metetra
0 .028 .127 r
.51666 .14364 .52245 .15139 .5331 .14745 .52734 .13958 Metetra
0 .028 .128 r
.52734 .13958 .5331 .14745 .54379 .14344 .53806 .13574 Metetra
0 .028 .128 r
.53806 .13574 .54379 .14344 .55452 .13927 .54882 .13163 Metetra
0 .027 .127 r
.54882 .13163 .55452 .13927 .56529 .13485 .55961 .12738 Metetra
0 .027 .126 r
.55961 .12738 .56529 .13485 .57611 .13081 .57046 .12323 Metetra
0 .027 .126 r
.57046 .12323 .57611 .13081 .58696 .12656 .58134 .11896 Metetra
0 .027 .126 r
.58134 .11896 .58696 .12656 .59787 .12252 .59227 .11497 Metetra
0 .027 .126 r
.59227 .11497 .59787 .12252 .6088 .11823 .60324 .1107 Metetra
0 .026 .125 r
.60324 .1107 .6088 .11823 .61978 .11399 .61426 .10653 Metetra
0 .026 .125 r
.61426 .10653 .61978 .11399 .63081 .10964 .6253 .10202 Metetra
0 .025 .124 r
.6253 .10202 .63081 .10964 .64187 .10534 .6364 .09764 Metetra
0 .025 .123 r
.6364 .09764 .64187 .10534 .65299 .1012 .64753 .09331 Metetra
0 .025 .123 r
.64753 .09331 .65299 .1012 .66415 .0971 .65872 .0891 Metetra
0 .025 .124 r
.65872 .0891 .66415 .0971 .67536 .0931 .66996 .08493 Metetra
0 .025 .124 r
.66996 .08493 .67536 .0931 .68661 .08882 .68124 .08072 Metetra
0 .026 .124 r
.68124 .08072 .68661 .08882 .69791 .08463 .69257 .07655 Metetra
0 .025 .124 r
.69257 .07655 .69791 .08463 .70923 .08017 .70394 .07221 Metetra
0 .025 .124 r
.70394 .07221 .70923 .08017 .72061 .07574 .71535 .06781 Metetra
0 .025 .123 r
.71535 .06781 .72061 .07574 .73201 .07114 .72679 .06332 Metetra
0 .025 .123 r
.07804 .29953 .08483 .30589 .09387 .30262 .0871 .29619 Metetra
0 .025 .124 r
.0871 .29619 .09387 .30262 .10295 .29926 .0962 .29283 Metetra
0 .025 .124 r
.0962 .29283 .10295 .29926 .11207 .29585 .10534 .28938 Metetra
0 .025 .124 r
.10534 .28938 .11207 .29585 .12124 .29229 .11452 .28582 Metetra
0 .025 .123 r
.11452 .28582 .12124 .29229 .13044 .28878 .12374 .28224 Metetra
0 .025 .123 r
.12374 .28224 .13044 .28878 .13967 .28523 .13298 .27876 Metetra
0 .025 .123 r
.13298 .27876 .13967 .28523 .14893 .28171 .14226 .27524 Metetra
0 .025 .123 r
.14226 .27524 .14893 .28171 .1582 .27832 .15154 .27189 Metetra
0 .025 .124 r
.15154 .27189 .1582 .27832 .16751 .27497 .16087 .26845 Metetra
0 .026 .125 r
.16087 .26845 .16751 .27497 .17683 .27175 .17022 .2652 Metetra
0 .026 .125 r
.17022 .2652 .17683 .27175 .18622 .26821 .17964 .26151 Metetra
0 .026 .126 r
.17964 .26151 .18622 .26821 .19564 .26478 .18908 .25798 Metetra
0 .026 .126 r
.18908 .25798 .19564 .26478 .20511 .26108 .19858 .25427 Metetra
0 .027 .126 r
.19858 .25427 .20511 .26108 .21459 .25766 .20808 .25083 Metetra
0 .027 .126 r
.20808 .25083 .21459 .25766 .22412 .25409 .21762 .24735 Metetra
0 .027 .127 r
.21762 .24735 .22412 .25409 .23368 .25063 .2272 .24374 Metetra
0 .027 .127 r
.2272 .24374 .23368 .25063 .24328 .24706 .23682 .24014 Metetra
0 .027 .126 r
.23682 .24014 .24328 .24706 .25293 .24322 .2465 .23624 Metetra
0 .027 .126 r
.2465 .23624 .25293 .24322 .2626 .23961 .25618 .2327 Metetra
0 .027 .126 r
.25618 .2327 .2626 .23961 .27232 .23584 .26591 .22907 Metetra
0 .027 .127 r
.26591 .22907 .27232 .23584 .28205 .23237 .27567 .22545 Metetra
0 .028 .127 r
.27567 .22545 .28205 .23237 .29183 .22872 .28547 .22178 Metetra
0 .027 .127 r
.28547 .22178 .29183 .22872 .30166 .2248 .29533 .21781 Metetra
0 .027 .127 r
.29533 .21781 .30166 .2248 .31151 .22122 .30519 .21427 Metetra
0 .028 .127 r
.30519 .21427 .31151 .22122 .3214 .21757 .31509 .21073 Metetra
0 .028 .127 r
.31509 .21073 .3214 .21757 .33132 .21387 .32505 .20681 Metetra
0 .028 .127 r
.32505 .20681 .33132 .21387 .34129 .21015 .33504 .20305 Metetra
0 .028 .127 r
.33504 .20305 .34129 .21015 .3513 .20623 .34507 .1993 Metetra
0 .028 .128 r
.34507 .1993 .3513 .20623 .36134 .20259 .35513 .19551 Metetra
0 .028 .128 r
.35513 .19551 .36134 .20259 .37141 .19899 .36523 .19175 Metetra
0 .028 .128 r
.36523 .19175 .37141 .19899 .38154 .19491 .37538 .18783 Metetra
0 .028 .128 r
.37538 .18783 .38154 .19491 .3917 .19107 .38556 .18396 Metetra
0 .028 .128 r
.38556 .18396 .3917 .19107 .40188 .18748 .39578 .18016 Metetra
0 .028 .128 r
.39578 .18016 .40188 .18748 .41213 .18342 .40604 .17621 Metetra
0 .028 .128 r
.40604 .17621 .41213 .18342 .42241 .17937 .41634 .17226 Metetra
0 .028 .127 r
.41634 .17226 .42241 .17937 .43271 .17562 .42668 .16827 Metetra
0 .028 .127 r
.42668 .16827 .43271 .17562 .44307 .17168 .43706 .16432 Metetra
0 .028 .127 r
.43706 .16432 .44307 .17168 .45346 .1677 .44747 .16051 Metetra
0 .028 .127 r
.44747 .16051 .45346 .1677 .4639 .16366 .45793 .15631 Metetra
0 .027 .127 r
.45793 .15631 .4639 .16366 .47437 .15957 .46843 .15212 Metetra
0 .027 .127 r
.46843 .15212 .47437 .15957 .48488 .15582 .47897 .14836 Metetra
0 .028 .127 r
.47897 .14836 .48488 .15582 .49543 .15179 .48955 .1443 Metetra
0 .027 .127 r
.48955 .1443 .49543 .15179 .50603 .14757 .50017 .14018 Metetra
0 .027 .126 r
.50017 .14018 .50603 .14757 .51666 .14364 .51083 .13605 Metetra
0 .027 .126 r
.51083 .13605 .51666 .14364 .52734 .13958 .52153 .13187 Metetra
0 .027 .126 r
.52153 .13187 .52734 .13958 .53806 .13574 .53228 .12803 Metetra
0 .027 .127 r
.53228 .12803 .53806 .13574 .54882 .13163 .54307 .1239 Metetra
0 .027 .127 r
.54307 .1239 .54882 .13163 .55961 .12738 .55389 .11975 Metetra
0 .027 .126 r
.55389 .11975 .55961 .12738 .57046 .12323 .56476 .11547 Metetra
0 .026 .126 r
.56476 .11547 .57046 .12323 .58134 .11896 .57567 .11115 Metetra
0 .026 .125 r
.57567 .11115 .58134 .11896 .59227 .11497 .58663 .10711 Metetra
0 .026 .126 r
.58663 .10711 .59227 .11497 .60324 .1107 .59763 .10289 Metetra
0 .026 .126 r
.59763 .10289 .60324 .1107 .61426 .10653 .60868 .09881 Metetra
0 .026 .125 r
.60868 .09881 .61426 .10653 .6253 .10202 .61976 .0943 Metetra
0 .025 .124 r
.61976 .0943 .6253 .10202 .6364 .09764 .63088 .08995 Metetra
0 .025 .123 r
.63088 .08995 .6364 .09764 .64753 .09331 .64205 .08551 Metetra
0 .025 .123 r
.64205 .08551 .64753 .09331 .65872 .0891 .65327 .08125 Metetra
0 .025 .123 r
.65327 .08125 .65872 .0891 .66996 .08493 .66453 .07696 Metetra
0 .025 .123 r
.66453 .07696 .66996 .08493 .68124 .08072 .67584 .07275 Metetra
0 .025 .124 r
.67584 .07275 .68124 .08072 .69257 .07655 .6872 .06852 Metetra
0 .025 .124 r
.6872 .06852 .69257 .07655 .70394 .07221 .6986 .06418 Metetra
0 .025 .124 r
.6986 .06418 .70394 .07221 .71535 .06781 .71004 .05974 Metetra
0 .025 .123 r
.71004 .05974 .71535 .06781 .72679 .06332 .72152 .05526 Metetra
0 .024 .123 r
.07119 .2932 .07804 .29953 .0871 .29619 .0803 .28965 Metetra
0 .025 .123 r
.0803 .28965 .0871 .29619 .0962 .29283 .08941 .28623 Metetra
0 .025 .123 r
.08941 .28623 .0962 .29283 .10534 .28938 .09858 .28267 Metetra
0 .025 .123 r
.09858 .28267 .10534 .28938 .11452 .28582 .10778 .27915 Metetra
0 .024 .123 r
.10778 .27915 .11452 .28582 .12374 .28224 .11702 .27554 Metetra
0 .024 .123 r
.11702 .27554 .12374 .28224 .13298 .27876 .12625 .27221 Metetra
0 .025 .123 r
.12625 .27221 .13298 .27876 .14226 .27524 .13553 .26876 Metetra
0 .025 .124 r
.13553 .26876 .14226 .27524 .15154 .27189 .14482 .26553 Metetra
0 .026 .125 r
.14482 .26553 .15154 .27189 .16087 .26845 .15417 .26205 Metetra
0 .026 .125 r
.15417 .26205 .16087 .26845 .17022 .2652 .16354 .25877 Metetra
0 .027 .126 r
.16354 .25877 .17022 .2652 .17964 .26151 .17299 .25496 Metetra
0 .026 .125 r
.17299 .25496 .17964 .26151 .18908 .25798 .18247 .25132 Metetra
0 .026 .125 r
.18247 .25132 .18908 .25798 .19858 .25427 .19198 .24762 Metetra
0 .026 .125 r
.19198 .24762 .19858 .25427 .20808 .25083 .20151 .24405 Metetra
0 .027 .126 r
.20151 .24405 .20808 .25083 .21762 .24735 .21106 .24059 Metetra
0 .027 .126 r
.21106 .24059 .21762 .24735 .2272 .24374 .22069 .23671 Metetra
0 .027 .126 r
.22069 .23671 .2272 .24374 .23682 .24014 .23034 .233 Metetra
0 .026 .125 r
.23034 .233 .23682 .24014 .2465 .23624 .24004 .22909 Metetra
0 .026 .125 r
.24004 .22909 .2465 .23624 .25618 .2327 .24974 .22554 Metetra
0 .027 .126 r
.24974 .22554 .25618 .2327 .26591 .22907 .25947 .22203 Metetra
0 .027 .126 r
.25947 .22203 .26591 .22907 .27567 .22545 .26927 .21822 Metetra
0 .027 .126 r
.26927 .21822 .27567 .22545 .28547 .22178 .27909 .21454 Metetra
0 .027 .126 r
.27909 .21454 .28547 .22178 .29533 .21781 .28896 .21067 Metetra
0 .027 .126 r
.28896 .21067 .29533 .21781 .30519 .21427 .29884 .20713 Metetra
0 .028 .127 r
.29884 .20713 .30519 .21427 .31509 .21073 .30875 .20366 Metetra
0 .028 .127 r
.30875 .20366 .31509 .21073 .32505 .20681 .31875 .19962 Metetra
0 .027 .127 r
.31875 .19962 .32505 .20681 .33504 .20305 .32875 .19585 Metetra
0 .028 .127 r
.32875 .19585 .33504 .20305 .34507 .1993 .33879 .19231 Metetra
0 .028 .128 r
.33879 .19231 .34507 .1993 .35513 .19551 .34888 .18837 Metetra
0 .028 .128 r
.34888 .18837 .35513 .19551 .36523 .19175 .35901 .18444 Metetra
0 .028 .128 r
.35901 .18444 .36523 .19175 .37538 .18783 .36917 .18072 Metetra
0 .028 .128 r
.36917 .18072 .37538 .18783 .38556 .18396 .37938 .17682 Metetra
0 .028 .128 r
.37938 .17682 .38556 .18396 .39578 .18016 .38963 .17276 Metetra
0 .028 .128 r
.38963 .17276 .39578 .18016 .40604 .17621 .39991 .16893 Metetra
0 .028 .128 r
.39991 .16893 .40604 .17621 .41634 .17226 .41023 .16508 Metetra
0 .028 .127 r
.41023 .16508 .41634 .17226 .42668 .16827 .4206 .16083 Metetra
0 .027 .127 r
.4206 .16083 .42668 .16827 .43706 .16432 .43101 .15682 Metetra
0 .028 .127 r
.43101 .15682 .43706 .16432 .44747 .16051 .44144 .15309 Metetra
0 .028 .127 r
.44144 .15309 .44747 .16051 .45793 .15631 .45193 .14876 Metetra
0 .027 .126 r
.45193 .14876 .45793 .15631 .46843 .15212 .46246 .14452 Metetra
0 .027 .126 r
.46246 .14452 .46843 .15212 .47897 .14836 .47302 .14059 Metetra
0 .027 .126 r
.47302 .14059 .47897 .14836 .48955 .1443 .48363 .1365 Metetra
0 .027 .126 r
.48363 .1365 .48955 .1443 .50017 .14018 .49427 .13251 Metetra
0 .027 .126 r
.49427 .13251 .50017 .14018 .51083 .13605 .50496 .12821 Metetra
0 .026 .125 r
.50496 .12821 .51083 .13605 .52153 .13187 .51569 .12397 Metetra
0 .026 .125 r
.51569 .12397 .52153 .13187 .53228 .12803 .52646 .12009 Metetra
0 .027 .126 r
.52646 .12009 .53228 .12803 .54307 .1239 .53727 .11601 Metetra
0 .027 .126 r
.53727 .11601 .54307 .1239 .55389 .11975 .54813 .11208 Metetra
0 .027 .126 r
.54813 .11208 .55389 .11975 .56476 .11547 .55903 .10774 Metetra
0 .026 .125 r
.55903 .10774 .56476 .11547 .57567 .11115 .56997 .10349 Metetra
0 .026 .125 r
.56997 .10349 .57567 .11115 .58663 .10711 .58096 .09937 Metetra
0 .026 .125 r
.58096 .09937 .58663 .10711 .59763 .10289 .59199 .09522 Metetra
0 .027 .126 r
.59199 .09522 .59763 .10289 .60868 .09881 .60307 .09121 Metetra
0 .026 .125 r
.60307 .09121 .60868 .09881 .61976 .0943 .61417 .08667 Metetra
0 .026 .125 r
.61417 .08667 .61976 .0943 .63088 .08995 .62533 .08231 Metetra
0 .025 .124 r
.62533 .08231 .63088 .08995 .64205 .08551 .63652 .07769 Metetra
0 .025 .123 r
.63652 .07769 .64205 .08551 .65327 .08125 .64777 .0733 Metetra
0 .024 .123 r
.64777 .0733 .65327 .08125 .66453 .07696 .65905 .0688 Metetra
0 .024 .123 r
.65905 .0688 .66453 .07696 .67584 .07275 .6704 .06456 Metetra
0 .025 .123 r
.6704 .06456 .67584 .07275 .6872 .06852 .68178 .06024 Metetra
0 .025 .123 r
.68178 .06024 .6872 .06852 .6986 .06418 .69322 .05595 Metetra
0 .025 .123 r
.69322 .05595 .6986 .06418 .71004 .05974 .70469 .05152 Metetra
0 .024 .123 r
.70469 .05152 .71004 .05974 .72152 .05526 .71622 .04719 Metetra
0 .024 .123 r
.06431 .28674 .07119 .2932 .0803 .28965 .07342 .28322 Metetra
0 .024 .123 r
.07342 .28322 .0803 .28965 .08941 .28623 .08255 .27983 Metetra
0 .024 .123 r
.08255 .27983 .08941 .28623 .09858 .28267 .09174 .27627 Metetra
0 .024 .123 r
.09174 .27627 .09858 .28267 .10778 .27915 .10095 .27276 Metetra
0 .024 .123 r
.10095 .27276 .10778 .27915 .11702 .27554 .11021 .2691 Metetra
0 .024 .123 r
.11021 .2691 .11702 .27554 .12625 .27221 .11946 .26575 Metetra
0 .025 .123 r
.11946 .26575 .12625 .27221 .13553 .26876 .12877 .26223 Metetra
0 .025 .124 r
.12877 .26223 .13553 .26876 .14482 .26553 .13809 .25888 Metetra
0 .026 .125 r
.13809 .25888 .14482 .26553 .15417 .26205 .14747 .25526 Metetra
0 .026 .125 r
.14747 .25526 .15417 .26205 .16354 .25877 .15688 .25176 Metetra
0 .026 .125 r
.15688 .25176 .16354 .25877 .17299 .25496 .16635 .24798 Metetra
0 .026 .125 r
.16635 .24798 .17299 .25496 .18247 .25132 .17584 .2443 Metetra
0 .026 .125 r
.17584 .2443 .18247 .25132 .19198 .24762 .18535 .24071 Metetra
0 .026 .125 r
.18535 .24071 .19198 .24762 .20151 .24405 .1949 .23712 Metetra
0 .026 .125 r
.1949 .23712 .20151 .24405 .21106 .24059 .20447 .23368 Metetra
0 .026 .125 r
.20447 .23368 .21106 .24059 .22069 .23671 .21412 .22981 Metetra
0 .026 .125 r
.21412 .22981 .22069 .23671 .23034 .233 .22378 .22612 Metetra
0 .026 .125 r
.22378 .22612 .23034 .233 .24004 .22909 .23349 .22236 Metetra
0 .026 .125 r
.23349 .22236 .24004 .22909 .24974 .22554 .24321 .21879 Metetra
0 .026 .126 r
.24321 .21879 .24974 .22554 .25947 .22203 .25296 .21532 Metetra
0 .027 .126 r
.25296 .21532 .25947 .22203 .26927 .21822 .26278 .21139 Metetra
0 .027 .126 r
.26278 .21139 .26927 .21822 .27909 .21454 .27263 .20766 Metetra
0 .027 .126 r
.27263 .20766 .27909 .21454 .28896 .21067 .28251 .20392 Metetra
0 .027 .126 r
.28251 .20392 .28896 .21067 .29884 .20713 .29242 .20023 Metetra
0 .027 .127 r
.29242 .20023 .29884 .20713 .30875 .20366 .30236 .19663 Metetra
0 .028 .127 r
.30236 .19663 .30875 .20366 .31875 .19962 .31238 .19259 Metetra
0 .027 .127 r
.31238 .19259 .31875 .19962 .32875 .19585 .32241 .18877 Metetra
0 .028 .127 r
.32241 .18877 .32875 .19585 .33879 .19231 .33247 .18523 Metetra
0 .028 .128 r
.33247 .18523 .33879 .19231 .34888 .18837 .34259 .18119 Metetra
0 .028 .127 r
.34259 .18119 .34888 .18837 .35901 .18444 .35275 .17713 Metetra
0 .028 .127 r
.35275 .17713 .35901 .18444 .36917 .18072 .36292 .17351 Metetra
0 .028 .128 r
.36292 .17351 .36917 .18072 .37938 .17682 .37315 .16959 Metetra
0 .028 .127 r
.37315 .16959 .37938 .17682 .38963 .17276 .38344 .16537 Metetra
0 .028 .127 r
.38344 .16537 .38963 .17276 .39991 .16893 .39374 .16161 Metetra
0 .028 .128 r
.39374 .16161 .39991 .16893 .41023 .16508 .40408 .15781 Metetra
0 .028 .127 r
.40408 .15781 .41023 .16508 .4206 .16083 .41448 .1535 Metetra
0 .027 .127 r
.41448 .1535 .4206 .16083 .43101 .15682 .42491 .14949 Metetra
0 .028 .127 r
.42491 .14949 .43101 .15682 .44144 .15309 .43537 .1457 Metetra
0 .027 .127 r
.43537 .1457 .44144 .15309 .45193 .14876 .44588 .14146 Metetra
0 .027 .126 r
.44588 .14146 .45193 .14876 .46246 .14452 .45643 .1373 Metetra
0 .027 .126 r
.45643 .1373 .46246 .14452 .47302 .14059 .46703 .13319 Metetra
0 .027 .126 r
.46703 .13319 .47302 .14059 .48363 .1365 .47766 .12909 Metetra
0 .027 .126 r
.47766 .12909 .48363 .1365 .49427 .13251 .48833 .12517 Metetra
0 .026 .126 r
.48833 .12517 .49427 .13251 .50496 .12821 .49905 .12079 Metetra
0 .026 .125 r
.49905 .12079 .50496 .12821 .51569 .12397 .5098 .11649 Metetra
0 .026 .125 r
.5098 .11649 .51569 .12397 .52646 .12009 .5206 .1124 Metetra
0 .026 .125 r
.5206 .1124 .52646 .12009 .53727 .11601 .53144 .10825 Metetra
0 .026 .125 r
.53144 .10825 .53727 .11601 .54813 .11208 .54233 .10426 Metetra
0 .026 .125 r
.54233 .10426 .54813 .11208 .55903 .10774 .55325 .09984 Metetra
0 .026 .125 r
.55325 .09984 .55903 .10774 .56997 .10349 .56422 .09555 Metetra
0 .026 .125 r
.56422 .09555 .56997 .10349 .58096 .09937 .57523 .09127 Metetra
0 .026 .125 r
.57523 .09127 .58096 .09937 .59199 .09522 .58629 .08708 Metetra
0 .026 .125 r
.58629 .08708 .59199 .09522 .60307 .09121 .5974 .083 Metetra
0 .026 .125 r
.5974 .083 .60307 .09121 .61417 .08667 .60854 .07863 Metetra
0 .026 .125 r
.60854 .07863 .61417 .08667 .62533 .08231 .61973 .07436 Metetra
0 .025 .124 r
.61973 .07436 .62533 .08231 .63652 .07769 .63096 .06981 Metetra
0 .025 .123 r
.63096 .06981 .63652 .07769 .64777 .0733 .64223 .06543 Metetra
0 .024 .123 r
.64223 .06543 .64777 .0733 .65905 .0688 .65355 .06089 Metetra
0 .024 .123 r
.65355 .06089 .65905 .0688 .6704 .06456 .66493 .05665 Metetra
0 .024 .123 r
.66493 .05665 .6704 .06456 .68178 .06024 .67634 .05226 Metetra
0 .024 .123 r
.67634 .05226 .68178 .06024 .69322 .05595 .68781 .04792 Metetra
0 .024 .123 r
.68781 .04792 .69322 .05595 .70469 .05152 .69931 .0434 Metetra
0 .024 .123 r
.69931 .0434 .70469 .05152 .71622 .04719 .71087 .03898 Metetra
0 .024 .123 r
.05738 .28022 .06431 .28674 .07342 .28322 .06652 .27664 Metetra
0 .024 .123 r
.06652 .27664 .07342 .28322 .08255 .27983 .07567 .27323 Metetra
0 .024 .123 r
.07567 .27323 .08255 .27983 .09174 .27627 .08487 .26965 Metetra
0 .024 .123 r
.08487 .26965 .09174 .27627 .10095 .27276 .09409 .26618 Metetra
0 .024 .123 r
.09409 .26618 .10095 .27276 .11021 .2691 .10336 .26253 Metetra
0 .025 .123 r
.10336 .26253 .11021 .2691 .11946 .26575 .11263 .25922 Metetra
0 .025 .124 r
.11263 .25922 .11946 .26575 .12877 .26223 .12195 .25571 Metetra
0 .025 .124 r
.12195 .25571 .12877 .26223 .13809 .25888 .13129 .25231 Metetra
0 .026 .125 r
.13129 .25231 .13809 .25888 .14747 .25526 .1407 .2486 Metetra
0 .026 .125 r
.1407 .2486 .14747 .25526 .15688 .25176 .15014 .24495 Metetra
0 .026 .124 r
.15014 .24495 .15688 .25176 .16635 .24798 .15963 .24118 Metetra
0 .025 .124 r
.15963 .24118 .16635 .24798 .17584 .2443 .16914 .23744 Metetra
0 .025 .124 r
.16914 .23744 .17584 .2443 .18535 .24071 .17867 .23389 Metetra
0 .025 .124 r
.17867 .23389 .18535 .24071 .1949 .23712 .18825 .23019 Metetra
0 .026 .125 r
.18825 .23019 .1949 .23712 .20447 .23368 .19784 .22666 Metetra
0 .026 .125 r
.19784 .22666 .20447 .23368 .21412 .22981 .20751 .22275 Metetra
0 .026 .124 r
.20751 .22275 .21412 .22981 .22378 .22612 .2172 .21903 Metetra
0 .026 .124 r
.2172 .21903 .22378 .22612 .23349 .22236 .22691 .21538 Metetra
0 .026 .125 r
.22691 .21538 .23349 .22236 .24321 .21879 .23666 .21174 Metetra
0 .026 .126 r
.23666 .21174 .24321 .21879 .25296 .21532 .24643 .20824 Metetra
0 .027 .126 r
.24643 .20824 .25296 .21532 .26278 .21139 .25627 .20429 Metetra
0 .026 .126 r
.25627 .20429 .26278 .21139 .27263 .20766 .26614 .20054 Metetra
0 .027 .126 r
.26614 .20054 .27263 .20766 .28251 .20392 .27603 .19695 Metetra
0 .027 .126 r
.27603 .19695 .28251 .20392 .29242 .20023 .28597 .19315 Metetra
0 .027 .127 r
.28597 .19315 .29242 .20023 .30236 .19663 .29594 .18942 Metetra
0 .027 .127 r
.29594 .18942 .30236 .19663 .31238 .19259 .30597 .18549 Metetra
0 .027 .127 r
.30597 .18549 .31238 .19259 .32241 .18877 .31602 .18166 Metetra
0 .028 .127 r
.31602 .18166 .32241 .18877 .33247 .18523 .3261 .17805 Metetra
0 .028 .128 r
.3261 .17805 .33247 .18523 .34259 .18119 .33625 .174 Metetra
0 .027 .127 r
.33625 .174 .34259 .18119 .35275 .17713 .34643 .16991 Metetra
0 .028 .127 r
.34643 .16991 .35275 .17713 .36292 .17351 .35663 .16627 Metetra
0 .028 .128 r
.35663 .16627 .36292 .17351 .37315 .16959 .36689 .16233 Metetra
0 .028 .127 r
.36689 .16233 .37315 .16959 .38344 .16537 .37719 .15808 Metetra
0 .027 .127 r
.37719 .15808 .38344 .16537 .39374 .16161 .38752 .15427 Metetra
0 .028 .128 r
.38752 .15427 .39374 .16161 .40408 .15781 .39788 .15043 Metetra
0 .028 .127 r
.39788 .15043 .40408 .15781 .41448 .1535 .40831 .14615 Metetra
0 .027 .127 r
.40831 .14615 .41448 .1535 .42491 .14949 .41876 .14208 Metetra
0 .027 .127 r
.41876 .14208 .42491 .14949 .43537 .1457 .42925 .13812 Metetra
0 .027 .127 r
.42925 .13812 .43537 .1457 .44588 .14146 .43979 .13396 Metetra
0 .027 .126 r
.43979 .13396 .44588 .14146 .45643 .1373 .45037 .12985 Metetra
0 .027 .126 r
.45037 .12985 .45643 .1373 .46703 .13319 .46099 .12554 Metetra
0 .026 .126 r
.46099 .12554 .46703 .13319 .47766 .12909 .47165 .12139 Metetra
0 .027 .126 r
.47165 .12139 .47766 .12909 .48833 .12517 .48234 .11745 Metetra
0 .027 .126 r
.48234 .11745 .48833 .12517 .49905 .12079 .49309 .11305 Metetra
0 .026 .125 r
.49309 .11305 .49905 .12079 .5098 .11649 .50387 .10876 Metetra
0 .026 .124 r
.50387 .10876 .5098 .11649 .5206 .1124 .5147 .1045 Metetra
0 .026 .124 r
.5147 .1045 .5206 .1124 .53144 .10825 .52557 .10031 Metetra
0 .026 .125 r
.52557 .10031 .53144 .10825 .54233 .10426 .53648 .09632 Metetra
0 .026 .125 r
.53648 .09632 .54233 .10426 .55325 .09984 .54743 .09193 Metetra
0 .025 .124 r
.54743 .09193 .55325 .09984 .56422 .09555 .55843 .0877 Metetra
0 .025 .124 r
.55843 .0877 .56422 .09555 .57523 .09127 .56947 .08333 Metetra
0 .025 .124 r
.56947 .08333 .57523 .09127 .58629 .08708 .58056 .07913 Metetra
0 .026 .124 r
.58056 .07913 .58629 .08708 .5974 .083 .59169 .07498 Metetra
0 .026 .125 r
.59169 .07498 .5974 .083 .60854 .07863 .60287 .07071 Metetra
0 .026 .125 r
.60287 .07071 .60854 .07863 .61973 .07436 .61409 .06648 Metetra
0 .025 .124 r
.61409 .06648 .61973 .07436 .63096 .06981 .62535 .06193 Metetra
0 .025 .124 r
.62535 .06193 .63096 .06981 .64223 .06543 .63666 .05748 Metetra
0 .025 .123 r
.63666 .05748 .64223 .06543 .65355 .06089 .648 .05284 Metetra
0 .024 .123 r
.648 .05284 .65355 .06089 .66493 .05665 .65941 .04853 Metetra
0 .024 .123 r
.65941 .04853 .66493 .05665 .67634 .05226 .67085 .04404 Metetra
0 .024 .123 r
.67085 .04404 .67634 .05226 .68781 .04792 .68235 .03966 Metetra
0 .024 .123 r
.68235 .03966 .68781 .04792 .69931 .0434 .69388 .03511 Metetra
0 .024 .123 r
.69388 .03511 .69931 .0434 .71087 .03898 .70548 .0307 Metetra
0 .024 .123 r
.05039 .2738 .05738 .28022 .06652 .27664 .05954 .2702 Metetra
0 .024 .123 r
.05954 .2702 .06652 .27664 .07567 .27323 .06871 .26676 Metetra
0 .024 .123 r
.06871 .26676 .07567 .27323 .08487 .26965 .07794 .26312 Metetra
0 .024 .123 r
.07794 .26312 .08487 .26965 .09409 .26618 .08717 .25964 Metetra
0 .024 .123 r
.08717 .25964 .09409 .26618 .10336 .26253 .09646 .25598 Metetra
0 .025 .123 r
.09646 .25598 .10336 .26253 .11263 .25922 .10575 .25257 Metetra
0 .025 .124 r
.10575 .25257 .11263 .25922 .12195 .25571 .1151 .24901 Metetra
0 .025 .124 r
.1151 .24901 .12195 .25571 .13129 .25231 .12448 .24543 Metetra
0 .025 .124 r
.12448 .24543 .13129 .25231 .1407 .2486 .13392 .24167 Metetra
0 .025 .124 r
.13392 .24167 .1407 .2486 .15014 .24495 .14339 .23787 Metetra
0 .025 .124 r
.14339 .23787 .15014 .24495 .15963 .24118 .15288 .23421 Metetra
0 .025 .123 r
.15288 .23421 .15963 .24118 .16914 .23744 .16241 .2305 Metetra
0 .025 .124 r
.16241 .2305 .16914 .23744 .17867 .23389 .17194 .227 Metetra
0 .025 .124 r
.17194 .227 .17867 .23389 .18825 .23019 .18154 .22327 Metetra
0 .025 .124 r
.18154 .22327 .18825 .23019 .19784 .22666 .19116 .21966 Metetra
0 .025 .124 r
.19116 .21966 .19784 .22666 .20751 .22275 .20084 .21584 Metetra
0 .025 .124 r
.20084 .21584 .20751 .22275 .2172 .21903 .21054 .21212 Metetra
0 .026 .124 r
.21054 .21212 .2172 .21903 .22691 .21538 .22026 .2086 Metetra
0 .026 .125 r
.22026 .2086 .22691 .21538 .23666 .21174 .23004 .20487 Metetra
0 .026 .125 r
.23004 .20487 .23666 .21174 .24643 .20824 .23984 .20124 Metetra
0 .026 .126 r
.23984 .20124 .24643 .20824 .25627 .20429 .2497 .19733 Metetra
0 .026 .125 r
.2497 .19733 .25627 .20429 .26614 .20054 .25959 .19355 Metetra
0 .027 .126 r
.25959 .19355 .26614 .20054 .27603 .19695 .26949 .19002 Metetra
0 .027 .127 r
.26949 .19002 .27603 .19695 .28597 .19315 .27947 .18608 Metetra
0 .027 .127 r
.27947 .18608 .28597 .19315 .29594 .18942 .28948 .18215 Metetra
0 .027 .127 r
.28948 .18215 .29594 .18942 .30597 .18549 .29951 .17839 Metetra
0 .027 .127 r
.29951 .17839 .30597 .18549 .31602 .18166 .30959 .17451 Metetra
0 .028 .127 r
.30959 .17451 .31602 .18166 .3261 .17805 .31971 .17066 Metetra
0 .028 .127 r
.31971 .17066 .3261 .17805 .33625 .174 .32987 .1667 Metetra
0 .027 .127 r
.32987 .1667 .33625 .174 .34643 .16991 .34007 .16268 Metetra
0 .028 .127 r
.34007 .16268 .34643 .16991 .35663 .16627 .3503 .15885 Metetra
0 .028 .127 r
.3503 .15885 .35663 .16627 .36689 .16233 .36058 .15488 Metetra
0 .028 .127 r
.36058 .15488 .36689 .16233 .37719 .15808 .3709 .15076 Metetra
0 .027 .127 r
.3709 .15076 .37719 .15808 .38752 .15427 .38126 .14682 Metetra
0 .028 .127 r
.38126 .14682 .38752 .15427 .39788 .15043 .39165 .14285 Metetra
0 .028 .127 r
.39165 .14285 .39788 .15043 .40831 .14615 .40209 .13876 Metetra
0 .027 .127 r
.40209 .13876 .40831 .14615 .41876 .14208 .41257 .13466 Metetra
0 .027 .127 r
.41257 .13466 .41876 .14208 .42925 .13812 .4231 .13048 Metetra
0 .027 .127 r
.4231 .13048 .42925 .13812 .43979 .13396 .43366 .12647 Metetra
0 .027 .127 r
.43366 .12647 .43979 .13396 .45037 .12985 .44425 .12245 Metetra
0 .027 .126 r
.44425 .12245 .45037 .12985 .46099 .12554 .45491 .11802 Metetra
0 .026 .125 r
.45491 .11802 .46099 .12554 .47165 .12139 .46559 .11384 Metetra
0 .026 .126 r
.46559 .11384 .47165 .12139 .48234 .11745 .47632 .1098 Metetra
0 .026 .125 r
.47632 .1098 .48234 .11745 .49309 .11305 .48709 .10547 Metetra
0 .026 .125 r
.48709 .10547 .49309 .11305 .50387 .10876 .4979 .10123 Metetra
0 .026 .124 r
.4979 .10123 .50387 .10876 .5147 .1045 .50875 .09678 Metetra
0 .025 .124 r
.50875 .09678 .5147 .1045 .52557 .10031 .51965 .09253 Metetra
0 .025 .124 r
.51965 .09253 .52557 .10031 .53648 .09632 .53059 .08839 Metetra
0 .025 .124 r
.53059 .08839 .53648 .09632 .54743 .09193 .54157 .08402 Metetra
0 .025 .124 r
.54157 .08402 .54743 .09193 .55843 .0877 .5526 .07977 Metetra
0 .025 .124 r
.5526 .07977 .55843 .0877 .56947 .08333 .56367 .07528 Metetra
0 .025 .123 r
.56367 .07528 .56947 .08333 .58056 .07913 .57478 .071 Metetra
0 .025 .124 r
.57478 .071 .58056 .07913 .59169 .07498 .58594 .06669 Metetra
0 .025 .124 r
.58594 .06669 .59169 .07498 .60287 .07071 .59715 .0625 Metetra
0 .025 .124 r
.59715 .0625 .60287 .07071 .61409 .06648 .6084 .05827 Metetra
0 .025 .124 r
.6084 .05827 .61409 .06648 .62535 .06193 .6197 .05385 Metetra
0 .025 .124 r
.6197 .05385 .62535 .06193 .63666 .05748 .63104 .0494 Metetra
0 .025 .123 r
.63104 .0494 .63666 .05748 .648 .05284 .64242 .04479 Metetra
0 .024 .123 r
.64242 .04479 .648 .05284 .65941 .04853 .65385 .04043 Metetra
0 .024 .123 r
.65385 .04043 .65941 .04853 .67085 .04404 .66533 .0359 Metetra
0 .024 .123 r
.66533 .0359 .67085 .04404 .68235 .03966 .67686 .03152 Metetra
0 .024 .123 r
.67686 .03152 .68235 .03966 .69388 .03511 .68843 .02694 Metetra
0 .024 .123 r
.68843 .02694 .69388 .03511 .70548 .0307 .70005 .0225 Metetra
0 .024 .123 r
.04336 .26728 .05039 .2738 .05954 .2702 .05254 .2636 Metetra
0 .024 .123 r
.05254 .2636 .05954 .2702 .06871 .26676 .06173 .26007 Metetra
0 .024 .123 r
.06173 .26007 .06871 .26676 .07794 .26312 .07098 .25639 Metetra
0 .024 .123 r
.07098 .25639 .07794 .26312 .08717 .25964 .08023 .25289 Metetra
0 .024 .123 r
.08023 .25289 .08717 .25964 .09646 .25598 .08954 .24926 Metetra
0 .025 .123 r
.08954 .24926 .09646 .25598 .10575 .25257 .09885 .24579 Metetra
0 .025 .124 r
.09885 .24579 .10575 .25257 .1151 .24901 .10821 .24222 Metetra
0 .025 .124 r
.10821 .24222 .1151 .24901 .12448 .24543 .11762 .23856 Metetra
0 .025 .124 r
.11762 .23856 .12448 .24543 .13392 .24167 .12707 .23482 Metetra
0 .025 .123 r
.12707 .23482 .13392 .24167 .14339 .23787 .13656 .23097 Metetra
0 .025 .123 r
.13656 .23097 .14339 .23787 .15288 .23421 .14606 .2274 Metetra
0 .025 .123 r
.14606 .2274 .15288 .23421 .16241 .2305 .1556 .22371 Metetra
0 .025 .123 r
.1556 .22371 .16241 .2305 .17194 .227 .16515 .22021 Metetra
0 .025 .124 r
.16515 .22021 .17194 .227 .18154 .22327 .17478 .21641 Metetra
0 .025 .124 r
.17478 .21641 .18154 .22327 .19116 .21966 .18443 .21268 Metetra
0 .025 .124 r
.18443 .21268 .19116 .21966 .20084 .21584 .19412 .20891 Metetra
0 .025 .124 r
.19412 .20891 .20084 .21584 .21054 .21212 .20385 .20517 Metetra
0 .026 .125 r
.20385 .20517 .21054 .21212 .22026 .2086 .21358 .20166 Metetra
0 .026 .125 r
.21358 .20166 .22026 .2086 .23004 .20487 .22339 .1978 Metetra
0 .026 .125 r
.22339 .1978 .23004 .20487 .23984 .20124 .23322 .194 Metetra
0 .026 .125 r
.23322 .194 .23984 .20124 .2497 .19733 .2431 .19017 Metetra
0 .026 .125 r
.2431 .19017 .2497 .19733 .25959 .19355 .25301 .18635 Metetra
0 .027 .126 r
.25301 .18635 .25959 .19355 .26949 .19002 .26293 .18276 Metetra
0 .027 .126 r
.26293 .18276 .26949 .19002 .27947 .18608 .27293 .17875 Metetra
0 .027 .126 r
.27293 .17875 .27947 .18608 .28948 .18215 .28297 .17469 Metetra
0 .027 .126 r
.28297 .17469 .28948 .18215 .29951 .17839 .29302 .17103 Metetra
0 .027 .127 r
.29302 .17103 .29951 .17839 .30959 .17451 .30312 .16713 Metetra
0 .027 .127 r
.30312 .16713 .30959 .17451 .31971 .17066 .31328 .16306 Metetra
0 .027 .127 r
.31328 .16306 .31971 .17066 .32987 .1667 .32345 .15919 Metetra
0 .027 .127 r
.32345 .15919 .32987 .1667 .34007 .16268 .33367 .15527 Metetra
0 .027 .127 r
.33367 .15527 .34007 .16268 .3503 .15885 .34394 .15122 Metetra
0 .027 .127 r
.34394 .15122 .3503 .15885 .36058 .15488 .35424 .14722 Metetra
0 .027 .127 r
.35424 .14722 .36058 .15488 .3709 .15076 .36458 .14326 Metetra
0 .027 .127 r
.36458 .14326 .3709 .15076 .38126 .14682 .37496 .13916 Metetra
0 .027 .126 r
.37496 .13916 .38126 .14682 .39165 .14285 .38539 .13505 Metetra
0 .027 .127 r
.38539 .13505 .39165 .14285 .40209 .13876 .39584 .13112 Metetra
0 .027 .127 r
.39584 .13112 .40209 .13876 .41257 .13466 .40635 .127 Metetra
0 .027 .126 r
.40635 .127 .41257 .13466 .4231 .13048 .4169 .12265 Metetra
0 .027 .126 r
.4169 .12265 .4231 .13048 .43366 .12647 .42748 .1187 Metetra
0 .027 .126 r
.42748 .1187 .43366 .12647 .44425 .12245 .43811 .1147 Metetra
0 .027 .126 r
.43811 .1147 .44425 .12245 .45491 .11802 .44878 .11029 Metetra
0 .026 .125 r
.44878 .11029 .45491 .11802 .46559 .11384 .45949 .10608 Metetra
0 .026 .125 r
.45949 .10608 .46559 .11384 .47632 .1098 .47025 .10189 Metetra
0 .026 .125 r
.47025 .10189 .47632 .1098 .48709 .10547 .48104 .09769 Metetra
0 .026 .125 r
.48104 .09769 .48709 .10547 .4979 .10123 .49188 .09353 Metetra
0 .026 .125 r
.49188 .09353 .4979 .10123 .50875 .09678 .50277 .089 Metetra
0 .025 .124 r
.50277 .089 .50875 .09678 .51965 .09253 .51369 .08471 Metetra
0 .025 .124 r
.51369 .08471 .51965 .09253 .53059 .08839 .52466 .08045 Metetra
0 .025 .124 r
.52466 .08045 .53059 .08839 .54157 .08402 .53567 .07617 Metetra
0 .025 .124 r
.53567 .07617 .54157 .08402 .5526 .07977 .54673 .07193 Metetra
0 .025 .123 r
.54673 .07193 .5526 .07977 .56367 .07528 .55782 .06739 Metetra
0 .025 .123 r
.55782 .06739 .56367 .07528 .57478 .071 .56897 .06303 Metetra
0 .024 .123 r
.56897 .06303 .57478 .071 .58594 .06669 .58015 .05855 Metetra
0 .025 .123 r
.58015 .05855 .58594 .06669 .59715 .0625 .59139 .05435 Metetra
0 .025 .124 r
.59139 .05435 .59715 .0625 .6084 .05827 .60268 .05005 Metetra
0 .025 .124 r
.60268 .05005 .6084 .05827 .6197 .05385 .614 .04566 Metetra
0 .025 .124 r
.614 .04566 .6197 .05385 .63104 .0494 .62537 .04116 Metetra
0 .025 .123 r
.62537 .04116 .63104 .0494 .64242 .04479 .63678 .03655 Metetra
0 .024 .123 r
.63678 .03655 .64242 .04479 .65385 .04043 .64825 .0321 Metetra
0 .024 .123 r
.64825 .0321 .65385 .04043 .66533 .0359 .65976 .02753 Metetra
0 .024 .123 r
.65976 .02753 .66533 .0359 .67686 .03152 .67132 .02313 Metetra
0 .024 .123 r
.67132 .02313 .67686 .03152 .68843 .02694 .68292 .01859 Metetra
0 .024 .123 r
.68292 .01859 .68843 .02694 .70005 .0225 .69458 .01417 Metetra
0 .024 .123 r
.03626 .26082 .04336 .26728 .05254 .2636 .04546 .25711 Metetra
0 .024 .123 r
.04546 .25711 .05254 .2636 .06173 .26007 .05468 .25349 Metetra
0 .024 .123 r
.05468 .25349 .06173 .26007 .07098 .25639 .06395 .2498 Metetra
0 .024 .123 r
.06395 .2498 .07098 .25639 .08023 .25289 .07323 .24623 Metetra
0 .024 .123 r
.07323 .24623 .08023 .25289 .08954 .24926 .08254 .24263 Metetra
0 .024 .123 r
.08254 .24263 .08954 .24926 .09885 .24579 .0919 .23896 Metetra
0 .025 .123 r
.0919 .23896 .09885 .24579 .10821 .24222 .10128 .23531 Metetra
0 .025 .123 r
.10128 .23531 .10821 .24222 .11762 .23856 .11073 .23148 Metetra
0 .024 .123 r
.11073 .23148 .11762 .23856 .12707 .23482 .12019 .22775 Metetra
0 .024 .122 r
.12019 .22775 .12707 .23482 .13656 .23097 .12971 .22387 Metetra
0 .024 .122 r
.12971 .22387 .13656 .23097 .14606 .2274 .13921 .22038 Metetra
0 .024 .123 r
.13921 .22038 .14606 .2274 .1556 .22371 .14876 .21673 Metetra
0 .025 .123 r
.14876 .21673 .1556 .22371 .16515 .22021 .15834 .2132 Metetra
0 .025 .124 r
.15834 .2132 .16515 .22021 .17478 .21641 .16798 .20943 Metetra
0 .025 .124 r
.16798 .20943 .17478 .21641 .18443 .21268 .17766 .2056 Metetra
0 .025 .124 r
.17766 .2056 .18443 .21268 .19412 .20891 .18735 .20201 Metetra
0 .025 .124 r
.18735 .20201 .19412 .20891 .20385 .20517 .19708 .1983 Metetra
0 .026 .125 r
.19708 .1983 .20385 .20517 .21358 .20166 .20684 .19479 Metetra
0 .026 .125 r
.20684 .19479 .21358 .20166 .22339 .1978 .21667 .19089 Metetra
0 .026 .125 r
.21667 .19089 .22339 .1978 .23322 .194 .22654 .18691 Metetra
0 .026 .125 r
.22654 .18691 .23322 .194 .2431 .19017 .23642 .18326 Metetra
0 .027 .126 r
.23642 .18326 .2431 .19017 .25301 .18635 .24635 .17942 Metetra
0 .027 .126 r
.24635 .17942 .25301 .18635 .26293 .18276 .25631 .17565 Metetra
0 .027 .126 r
.25631 .17565 .26293 .18276 .27293 .17875 .26633 .17165 Metetra
0 .027 .126 r
.26633 .17165 .27293 .17875 .28297 .17469 .2764 .16754 Metetra
0 .027 .126 r
.2764 .16754 .28297 .17469 .29302 .17103 .28647 .16388 Metetra
0 .027 .126 r
.28647 .16388 .29302 .17103 .30312 .16713 .29659 .15994 Metetra
0 .027 .126 r
.29659 .15994 .30312 .16713 .31328 .16306 .30678 .15567 Metetra
0 .027 .126 r
.30678 .15567 .31328 .16306 .32345 .15919 .31698 .15186 Metetra
0 .027 .126 r
.31698 .15186 .32345 .15919 .33367 .15527 .32721 .14805 Metetra
0 .027 .126 r
.32721 .14805 .33367 .15527 .34394 .15122 .33751 .14376 Metetra
0 .027 .126 r
.33751 .14376 .34394 .15122 .35424 .14722 .34784 .13973 Metetra
0 .027 .126 r
.34784 .13973 .35424 .14722 .36458 .14326 .35819 .13596 Metetra
0 .027 .126 r
.35819 .13596 .36458 .14326 .37496 .13916 .36861 .1317 Metetra
0 .027 .126 r
.36861 .1317 .37496 .13916 .38539 .13505 .37906 .12745 Metetra
0 .027 .126 r
.37906 .12745 .38539 .13505 .39584 .13112 .38954 .12366 Metetra
0 .027 .126 r
.38954 .12366 .39584 .13112 .40635 .127 .40007 .11953 Metetra
0 .027 .126 r
.40007 .11953 .40635 .127 .4169 .12265 .41065 .11512 Metetra
0 .027 .126 r
.41065 .11512 .4169 .12265 .42748 .1187 .42125 .11116 Metetra
0 .027 .126 r
.42125 .11116 .42748 .1187 .43811 .1147 .4319 .10711 Metetra
0 .027 .126 r
.4319 .10711 .43811 .1147 .44878 .11029 .4426 .10282 Metetra
0 .027 .126 r
.4426 .10282 .44878 .11029 .45949 .10608 .45334 .09857 Metetra
0 .026 .125 r
.45334 .09857 .45949 .10608 .47025 .10189 .46413 .09415 Metetra
0 .026 .125 r
.46413 .09415 .47025 .10189 .48104 .09769 .47495 .09005 Metetra
0 .026 .125 r
.47495 .09005 .48104 .09769 .49188 .09353 .48582 .08588 Metetra
0 .026 .125 r
.48582 .08588 .49188 .09353 .50277 .089 .49673 .08131 Metetra
0 .025 .124 r
.49673 .08131 .50277 .089 .51369 .08471 .50769 .07692 Metetra
0 .025 .124 r
.50769 .07692 .51369 .08471 .52466 .08045 .51868 .07243 Metetra
0 .025 .124 r
.51868 .07243 .52466 .08045 .53567 .07617 .52972 .06817 Metetra
0 .025 .124 r
.52972 .06817 .53567 .07617 .54673 .07193 .54081 .06385 Metetra
0 .025 .123 r
.54081 .06385 .54673 .07193 .55782 .06739 .55193 .05928 Metetra
0 .024 .123 r
.55193 .05928 .55782 .06739 .56897 .06303 .56311 .05482 Metetra
0 .024 .122 r
.56311 .05482 .56897 .06303 .58015 .05855 .57432 .05021 Metetra
0 .024 .122 r
.57432 .05021 .58015 .05855 .59139 .05435 .58559 .04598 Metetra
0 .024 .123 r
.58559 .04598 .59139 .05435 .60268 .05005 .5969 .04161 Metetra
0 .025 .123 r
.5969 .04161 .60268 .05005 .614 .04566 .60826 .03733 Metetra
0 .025 .123 r
.60826 .03733 .614 .04566 .62537 .04116 .61966 .03286 Metetra
0 .024 .123 r
.61966 .03286 .62537 .04116 .63678 .03655 .63111 .0284 Metetra
0 .024 .123 r
.63111 .0284 .63678 .03655 .64825 .0321 .64261 .02386 Metetra
0 .024 .123 r
.64261 .02386 .64825 .0321 .65976 .02753 .65415 .01929 Metetra
0 .024 .123 r
.65415 .01929 .65976 .02753 .67132 .02313 .66574 .01485 Metetra
0 .024 .123 r
.66574 .01485 .67132 .02313 .68292 .01859 .67738 .01033 Metetra
0 .025 .123 r
.67738 .01033 .68292 .01859 .69458 .01417 .68908 .00589 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09773 .23142 m
.10243 .236 L
s
[(-0.05)] .08833 .22227 1 .97329 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61334 .02952 m
.61709 .03491 L
s
[(0.05)] .60583 .01876 .69702 1 Mshowa
.125 Mabswid
.14497 .21292 m
.14774 .21571 L
s
.1931 .19408 m
.19582 .19692 L
s
.24214 .17487 m
.24481 .17776 L
s
.29212 .1553 m
.29474 .15824 L
s
.39501 .11502 m
.39752 .11805 L
s
.44797 .09427 m
.45043 .09735 L
s
.502 .07312 m
.50439 .07625 L
s
.55711 .05154 m
.55943 .05472 L
s
.05135 .24958 m
.05422 .25228 L
s
.67072 .00705 m
.6729 .01033 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Voooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0001aoooo
o`00V_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooooooo`1^ooooo`00V_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0K_ooool009[ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00oooooo0_l0001Mooooo`00
V_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l0000?oooo
o`?o000000?oooooo`000?ooool0G?ooool009[ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`00013ooooo0ol00002ooooo`?o0000G?ooool009_ooooo0_l0000:
ooooo`;o00000_ooool5o`0000Wooooo0ol00002ooooo`?o000000Co00HOo`000?l0003o0000Fooo
ool00;Oooooo0_l00002ooooo`?o00000_l01Ql00ol0003o00HOo`000002o`0005_ooooo002doooo
o`?o000000Coooooo`000?l0003o00000_l01Ql00ol0003o00HOo`067`03o`000003o`067ol0003o
000005[ooooo002aooooo`?o00000_ooool2o`0000;o00HO00?o0000o`067ol01Ql00ol000001?l0
1Qoo0000o`000?l01Ql3o`0005Wooooo002_ooooo`;o00001?ooool00ol0003o00HOo`000002o`06
7`?o000000Co00HOo`000?l01Qoo00HO0ol000000ol01Qoo0000o`00001Iooooo`00[?ooool4o`00
00?ooooo0_l00002o`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`000?l0
1Ql3o`0000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o0000=_oo
ool00:[ooooo0_l00004ooooo`?o000000Ko00HOo`000?l01Qoo0000o`067ol00002o`067`?o0000
0_l01Ql00ol0003o00HOo`067`02o`0000;o00HO0_l0000<ooooo`04o`000?ooooooooooo`0000So
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo03?ooooo002Woooo
o`?o00000oooool3o`000004o`067ol0003o00HOo`067`;o00000ol01Ql2o`000003o`067ol0003o
00HO00;o00HO1Ol00002o`067`;o00001Oooool5o`0000;ooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03?ooooo002Uooooo`;o00000ooo
ool3o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0_l00003o`067`06
o`000?l01Qoo0000o`067ol0003o00HO1?l000000ol01Qoo0000o`00000;ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0cooooo`00X_oo
ool3o`0000;ooooo0ol000001?l01Qoo0000o`067ol01Ql3o`0000;o00HO00?o0000o`067ol00000
0_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql3o`000004o`067ol0003o00HOo`067`;o
00002oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l0000f
ooooo`00X?ooool2o`0000;ooooo0ol000001?l01Qoo0000o`067ol01Ql3o`0000;o00HO00?o0000
o`067ol01Ql00_l00002o`067`03o`000?l01Qoo00HO00?o000000Go00HOo`000?l01Qoo0000o`06
7`02o`000004o`067ol0003o0000o`0000;o00HO00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000>Oooool009gooooo0ol000001?oo
oooo0000o`000?l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`067`03
o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0_l00003o`067`;o0000
0_l01Ql00ol0003o00HOo`067`02o`0000[ooooo0_l0000:ooooo`;o00000_ooool5o`0003Gooooo
002Kooooo`;o00000_ooool2o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l0
1Qoo00HO00?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000004
o`067ol0003o00HOo`067`;o00000ol01Ql3o`000003o`067ol0003ooooo05?ooooo002Hooooo`?o
00000oooool00ol0003o00HOo`000002o`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l0
1Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`?o00000_l01Ql00ol0003o00HOo`00
0002o`000007o`067ol0003o0000o`067ol0003o00HOo`000002o`067`;o0000Doooool009Kooooo
0_l00004ooooo`;o00000_l01Ql3o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l0
1Qoo00HO0ol00002o`067`03o`000?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`067`02o`00
00;o00HO00?o0000o`067ol000000_l00003o`067`;o000000?o00HOo`000?l00000D_ooool009?o
oooo0ol00003ooooo`?o000000Ko00HOo`000?l01Qoo0000o`067ol00002o`067`?o00000_l01Ql0
0ol0003o00HOo`000002o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Qoo
00HO00?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO
0_l0001Booooo`00T?ooool4o`0000;ooooo0ol000001?l01Qoo0000o`067ol01Ql2o`0000?o00HO
0_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00HOo`067`03o`000004o`06
7ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`000?l01Ql3
o`000004o`067ol0003o00HOo`0000;o00HO00?o0000ooooooooool0Coooool008kooooo0_l00003
ooooo`?o00000_l01Ql00ol0003o00HOo`000002o`0000;o00HO00Go0000o`067ol0003o00HOo`00
0002o`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000004
o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol0
1Ql2o`0000?o00HO0_l0001@ooooo`00Roooool3o`0000;ooooo0ol00002o`067`03o`000?l01Qoo
00HO00;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o00HO0ol000001?l01Qoo0000o`067ol0
1Ql3o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo
0000o`067ol01Ql3o`000004o`067ol0003o0000o`067`?o00000_l01Ql01Ol0003o00HOo`000?l0
1Qoo0000053ooooo0029ooooo`;o00000oooool2o`0000;o00HO00?o0000o`067ol01Ql00ol00000
1?l01Qoo0000o`067ol01Ql3o`000006o`067ol0003o00HOo`000?l01Qoo00000_l01Ql3o`000004
o`067ol0003o00HOo`067`?o00000_l01Ql00ol0003o00HOo`000002o`0000;o00HO00?o0000o`06
7ol000000_l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`067`02o`00
00;o00HO0_l0001?ooooo`00Q_ooool3o`0000;ooooo0ol000001?l01Qoo0000o`067ol01Ql3o`00
0004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0_l00003o`067`;o00000_l0
1Ql00ol0003o00HOo`000002o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l0
1Qoo00HO00;o00000_l01Ql00ol0003o00HOo`067`03o`000004o`067ol0003o00HOo`067`?o0000
00Go00HOo`000?l0003o0000o`067`02o`0004kooooo001Uooooo`;o00007Oooool2o`0000;ooooo
0ol000001?l01Qoo0000o`067ol01Ql3o`0000;o00HO00?o0000o`067ol000000_l00002o`067`03
o`000?l01Qoo000000;o00000_l01Ql01?l0003o00HOo`000?l00003o`067`;o00000_l01R000ol0
003o00HOo`067`03o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol0
00001?l01Qoo0000o`000?l01Ql3o`000006o`067ol0003o00HOo`000?l01Qoo00000_l01Ql3o`00
04gooooo001Tooooo`04o`000?ooooooooooo`0001Wooooo0ol000001?oooooo0000o`000?l00002
o`067`03o`000?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o00HO00?o0000
o`067ol01Ql00_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql01Ol0003o00HOo`000?l0
1Qoo000000;o00HP0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`?o
000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO0ol00000
0ol01Qoo0000o`00001=ooooo`00I?ooool01?l0003oooooooooool0000Gooooo`;o00000_ooool2
o`0000;o00HP00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Qoo00HO00?o000000Co00HO
o`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o
00000_l01Ql3o`000004o`068?l0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol00000
1?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o0000o`067`?o000000Co00HOo`000?l01Qoo
00000_l01Ql00ol0003o00HOo`000002o`0004cooooo001Tooooo`04o`000?ooooooooooo`0001Co
oooo0ol00003ooooo`03o`000?l01R3o000000;o00HP0ol000001?l01Qoo0000o`067ol01Ql3o`00
0004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`06
7ol01Ql3o`000004o`067ol0003o00HOo`0000;o00HP00?o0000o`068?l000000_l00002o`067`03
o`000?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`000002o`0000;o00HO00?o0000o`067ol0
00000_l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql2o`0000;o00HO00?o0000oooooooo
ool0B_ooool006Cooooo00Co0000oooooooooooo00004_ooool2o`0000Cooooo0ol000001?l01R3o
0000o`000?l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`000002o`00
00;o00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql01?l0
003o00HOo`000?l00003o`0680;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o00HO00?o0000
o`067ol01Ql00_l00002o`067`03o`000?l01Qoo00HO00;o000000?o00HOo`000?l000000_l01Ql2
o`0000;o00HO0ol000001?l01Qoo0000o`067ol01Ql2o`0004_ooooo001Tooooo`04o`000?oooooo
ooooo`0000oooooo0ol00003ooooo`?o00000_l01R02o`0000;o00HP00?o0000o`067ol01Ql00_l0
0002o`068003o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o00HO00?o
0000o`067ol01Ql00_l00002o`068003o`000?l01Qoo00HO00;o00000_l01Ql01Ol0003o00HPo`00
0?l01R3o000000;o00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`06
7`?o000000?o00HPo`000?l01Ql01?l000001_l01Qoo0000o`067ol0003o00HOo`0000;o00HO0ol0
00000ol01Qoo0000o`00001:ooooo`00IOooool2o`0000kooooo0_l000001?oooooo0000oooooooo
ool2o`0000;o00HP0ol000001?l01R3o0000o`068?l01R03o`000004o`067ol0003o00HPo`0680?o
000000Co00HPo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`068?l0003o
00HPo`0680?o000000Co00HPo`000?l01Qoo00HO0_l00002o`0680?o000000Co00HOo`000?l01Qoo
00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`068?l0003o00HPo`0680?o000000Co00HO
o`000?l01Qoo00HO0_l00002o`067`?o000000Co00HOo`000?l01Qoo00HO0_l0001:ooooo`00L_oo
ool3o`0000?ooooo0ol00002o`0680;o000000Co00HPo`000?l01R3o00HP0ol000001?l01R3o0000
o`067ol01Ql3o`000004o`068?l0003o00HPo`0680?o000000Co00HOo`000?l01Qoo00HO0ol00000
1?l01R3o0000o`068?l01R03o`000004o`068?l0003o00HPo`0680?o000000Ko00HPo`000?l0003o
0000o`068?l00002o`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`068?l0
1R03o`000004o`067ol0003o0000o`067`?o000000Ko00HOo`000?l01Qoo0000o`067ol00002o`06
7`?o000000?o00HOo`000?l00000BOooool006oooooo0ol00003ooooo`?o00000_l01R001_l0003o
00HPo`000?l01R3o0000o`0680?o00000_l01R000ol0003o00HPo`000002o`0000;o00HP00?o0000
o`068?l000000_l00002o`068003o`000?l01Qoo000000;o000000Co00HOo`000?l01R3o00HP0ol0
00001?l01R3o0000o`068?l01R03o`0000;o00HP0_l00002o`068003o`000?l01R3o000000;o0000
00Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`068?l0003o00HO
o`067`?o000000Co00HOo`000?l01Qoo00HO0_l00002o`067`?o000000Co00HOo`000?l01Qoo00HO
0ol00018ooooo`00KOooool2o`0000Cooooo0_l00002o`068003o`000?l01R3o00HP00;o00000_l0
1R02o`0000;o00HP00?o0000o`068?l01R000_l00002o`068003o`000?l01R3o00HP00;o00000_l0
1R000ol0003o00HPo`068002o`0000;o00HO00?o0000o`067ol000000_l00002o`068003o`000?l0
1R3o000000;o00000_l01R001Ol0003o00HPo`000?l01R3o000000;o00HP0_l00002o`068003o`00
0?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`000002o`0000;o00HP00?o0000o`068?l00000
0_l000001?l01Qoo0000o`067ol01Ql3o`0000;o00HO0_l00002o`067`03o`000?l01Qoo000000;o
000000?o00HOo`000?l00000B?ooool006[ooooo0ol00003ooooo`?o000000Co00HPo`000?l01R3o
00HP0ol000001_l01R3o0000o`068?l0003o00HPo`0000;o00HP0ol000001?l01R3o0000o`068?l0
1R03o`000004o`068?l0003o00HPo`0680?o000000Co00HPo`000?l01Qoo00HO0_l00002o`068003
o`000?l01R3o00HP00;o00000_l01R000ol0003o00HPo`068002o`0000;o00HP0ol000001?l01R3o
0000o`068?l01R02o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`068003o`000?l01R3o00HP
00;o00000_l01R000ol0003o00HOo`000002o`0000;o00HO00Go0000o`067ol0003o00HOo`000002
o`067`;o00000_l01Ql00ol0003o00HOo`000002o`0004Oooooo001Xooooo`Co000000Coooooo`00
0?l0003o00000_l01R000ol0003o00HPo`000002o`000004o`068?l0003o00HPo`0680?o000000Co
00HPo`000?l0003o00000_l01R000ol0003o00HPo`000002o`000004o`068?l0003o00HPo`0680?o
000000Co00HPo`000?l01R3o00HP0ol000001?l01R3o0000o`068?l01R03o`000004o`078?l0003o
00HPo`0680?o000000Ko00HPo`000?l0003o0000o`068?l00002o`0680?o000000Co00HPo`000?l0
1Qoo00HO0ol000001?l01R3o0000o`068?l01R03o`000004o`068?l0003o00HPo`0680?o000000Co
00HOo`000?l01Qoo00HO0_l00002o`067`?o000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03
o`000?oooooooooo04Gooooo001Uooooo`?o00000oooool2o`0000;o00HP00?o0000o`068?l01R00
0_l00002o`068003o`000?l01R3o000000;o00000_l01R02o`0000;o00HP00?o0000o`068?l01R00
0_l00002o`068003o`000?l01R3o000000;o00000_l01R000ol0003o00HPo`000002o`0000;o00HP
00?o0000o`068?l000000_l000001?l01b3o0000o`078?l01b03o`0000;o00HP0_l000001?l01R3o
0000o`068?l01R03o`000004o`068?l0003o00HPo`0680?o000000Co00HPo`000?l01R3o00HP0ol0
00001?l01R3o0000o`068?l01R03o`000004o`068?l0003o0000o`067`?o000000Ko00HOo`000?l0
003o0000o`067ol00002o`067`?o000000Co00HOo`000?l01Qoo00HO0_l00016ooooo`00Hoooool2
o`0000?ooooo0ol000001?l01R3o0000o`068?l01R03o`000004o`068?l0003o00HPo`0680;o0000
0_l01b03o`000004o`068?l0003o00HPo`0680?o000000Co00HPo`000?l01R3o00HP0_l00002o`06
8003o`000?l01R3o00HP00;o00000_l01R000ol0003o00HPo`068002o`0000;o00LP00?o0000o`07
8?l000000_l00002o`078006o`000?l01R3o0000o`068?l0003o00HP0ol00002o`068003o`000?l0
1R3o000000;o000000Co00HPo`000?l01R3o00HP0ol000001?l01R3o0000o`068?l01R03o`000004
o`068?l0003o00HPo`0680?o000000Ko00HPo`000?l01Qoo0000o`067ol00002o`067`?o000000Co
00HOo`000?l01Qoo00HO0ol000000ol01Qoo0000o`000015ooooo`00H?ooool3o`0000;ooooo0ol0
0002o`068003o`000?l01R3o000000;o00000_l01R000ol0003o00HPo`000002o`000004o`078?l0
003o00LPo`0000;o00LP00?o0000o`068?l000000_l000001?l01b3o0000o`068?l01R03o`000004
o`068?l0003o00HPo`0680?o000000Co00LPo`000?l01R3o00HP0ol000001?l01b3o0000o`078?l0
1b02o`0000;o00LP00?o0000o`078?l01b000_l00002o`0680;o00000_l01R000ol0003o00HPo`06
8002o`0000;o00LP00?o0000o`068?l000000_l00002o`068003o`000?l01R3o000000;o000000Co
00HPo`000?l01R3o00HP0ol000001?l01R3o0000o`068?l01R02o`0000;o00HO0ol000001?l01Qoo
0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o0000AOooool005kooooo0_l00003oooo
o`;o00000_l01R000ol0003o00HPo`068002o`0000;o00HP00?o0000o`068?l01R000_l00002o`06
80Go00000_l01b02o`0000;o00HP00?o0000o`078?l000000_l00002o`078003o`000?l01R3o0000
00;o000000Co00HPo`000?l01b3o00LP0ol000001?l01b3o0000o`078?l01b03o`000004o`078?l0
003o00LPo`0780?o000000Ko00LPo`000?l0003o0000o`068?l00002o`0680?o000000Co00LPo`00
0?l01b3o00LP0_l00002o`078003o`000?l01R3o00HP00;o00000_l01R000ol0003o00HPo`000002
o`0000;o00HP00?o0000o`068?l000000_l000001_l01R3o0000o`000?l0003o00HOo`0000;o00HO
0ol000001?l01Qoo0000o`067ol01Ql3o`000003o`067ol0003o000004Cooooo001Kooooo`Co0000
00Coooooo`000?l0003o00000_l01R000ol0003o00HPo`000002o`000004o`068?l0003o00HPo`06
80?o00000_l01b02o`000004o`068?l0003o00LPo`0780?o000000Co00LPo`000?l01R3o00HP0_l0
0002o`078003o`000?l01b3o00LP00;o00000_l01R000ol0003o00HPo`000002o`0000;o00LP00?o
0000o`078?l000000_l000001?l01b3o0000o`078?l01b03o`0000;o00LQ0_l000001?l01b3o0000
o`068?l01R03o`000004o`078?l0003o00LPo`0780?o000000Co00LPo`000?l01b3o00LP0ol00000
1?l01R3o0000o`068?l01R02o`0000;o00HP00?o0000o`068?l01R000_l000001?l01R3o0000o`00
0?l00002o`068003o`000?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`000002o`000004o`06
7ol0003o00HOo`067`?o0000@oooool005Wooooo0_l00003ooooo`;o00000_l01R000ol0003o00HP
o`068002o`0000;o00HP00?o0000o`068?l000000_l00002o`078006o`000?l01b3o0000o`078?l0
003o00HP0ol00002o`078003o`000?l01b3o000000;o000000Co00HPo`000?l01b3o00LP0ol00000
1?l01b3o0000o`068?l01R02o`0000;o00LP00?o0000o`078?l01b000_l00002o`078003o`000?l0
1b3o000000;o00000_l01b401_l0003o00LQo`000?l01b7o0000o`0780?o00000_l01b000ol0003o
00LPo`000002o`000004o`078?l0003o00LPo`0780?o000000Co00LPo`000?l01R3o00HP0ol00000
1?l01R3o0000o`068?l01R03o`000006o`068?l0003o0000o`000?l01R3o00000_l01R02o`0000;o
00HO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Qoo000000;o000000?o00HOo`000?l0
0000@oooool005Kooooo0ol00002ooooo`?o000000Co00HPo`000?l01R3o00HP0ol000001?l01R3o
0000o`068?l01R02o`0000;o00LP00?o0000o`078?l01b000_l00002o`0780;o00000_l01b000ol0
003o00LPo`078002o`0000;o00LP00?o0000o`068?l000000_l000001?l01b3o0000o`078?l01b03
o`000004o`078?l0003o00LPo`0780?o000000Co00LQo`000?l01b3o00LP0_l00002o`078@03o`00
0?l01b7o00LQ00;o00000_l01b42o`0000;o00LP00?o0000o`078?l01b000_l00002o`078003o`00
0?l01b3o000000;o000000Co00LPo`000?l01b3o00LP0ol000001?l01R3o0000o`068?l01R03o`00
0005o`068?l0003o00HPo`000?l01b000_l000001_l01R3o0000o`000?l0003o00HOo`0000;o00HO
0ol000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`067ol000000_l00012ooooo`00
E?ooool2o`0000?ooooo0_l00002o`068003o`000?l01R3o000000;o00000_l01R000ol0003o00HP
o`000002o`000003o`068?l0003o000000Co000000Ko00LPo`000?l0003o0000o`078?l00002o`07
80?o000000Co00LPo`000?l01b3o00LP0_l00002o`078003o`000?l01b3o000000;o00000_l01b00
0ol0003o00LPo`000002o`000004o`078Ol0003o00LQo`078@?o000000Co00LQo`000?l01b7o00LQ
0ol000001_l01b7o0000o`000?l0003o00LPo`0000;o00LP0ol000001?l01b3o0000o`078?l01b02
o`0000;o00LQ00?o0000o`078?l000000_l00002o`078003o`000?l01R3o000000;o000000Co00HP
o`000?l01R3o00HP0_l00002o`0780?o000000Co00HPo`000?l01Qoo00HO0ol000001?l01Qoo0000
o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o00000_l01Ql2o`00047ooooo001Aooooo`?o
00000_ooool3o`000004o`068?l0003o00HPo`0680;o00000_l01R000ol0003o00HPo`068002o`00
00;o00LP0_l00002o`068003o`000?l01b3o00LP00;o00000_l01b000ol0003o00LPo`000002o`00
0004o`078?l0003o00LPo`0780?o000000Co00LPo`000?l01b3o00LP0_l00002o`078003o`000?l0
1b3o00LP00;o00000_l01b400ol0003o00LQo`000002o`0000;o00LQ00?o0000o`078Ol000000_l0
00001_l01b7o0000o`000?l0003o00LQo`0000;o00LP0ol000001?l01b3o0000o`078?l01b03o`00
0004o`078Ol0003o00LQo`078@;o00000_l01b000ol0003o00LPo`078002o`0000;o00HP1Ol00000
1_l01b3o0000o`000?l0003o00LPo`0000;o00HP0ol000001?l01Qoo0000o`067ol01Ql3o`000004
o`068?l0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0_l00011ooooo`00C_ooool8o`00
00;o00HP00?o0000o`068?l000000_l000001?l01R3o0000o`068?l01R03o`000006o`078?l0003o
00LPo`000?l01b3o00000_l01R03o`000004o`078?l0003o00LPo`0780;o00000_l01b000ol0003o
00LPo`000002o`0000;o00LP00?o0000o`078?l000000_l000001?l01b3o0000o`078?l01b03o`00
0004o`078?l0003o00LQo`078@;o00000_l01b400ol0003o00LQo`078@02o`0000;o00LQ0_l00002
o`078@03o`000?l01b7o000000;o00000_l01b000ol0003o00LPo`000002o`000004o`078Ol0003o
00LQo`078@?o000000Co00LQo`000?l01b3o00LP0ol000001_l01b3o0000o`000?l0003o00LPo`00
00;o00LP0_l00002o`078003o`000?l01b3o000000;o000000Co00HPo`000?l01Qoo00HO0ol00000
1?l01Qoo0000o`068?l01R03o`000004o`068?l0003o00HOo`067`?o000000?o00HPo`000?l00000
@?ooool004cooooo0_l00003ooooo`;o00000_l01R000ol0003o00HPo`068002o`0000;o00HP00?o
0000o`068?l000000_l00002o`0680Go000000Co00LPo`000?l0003o00000_l01b000ol0003o00LP
o`000002o`000004o`078?l0003o00LPo`0780;o00000_l01b000ol0003o00LPo`078002o`0000;o
00LP00?o0000o`078?l000000_l00002o`078@03o`000?l01b3o000000;o000000Co00LQo`000?l0
1b7o00LQ0ol000001_l01b7o0000o`000?l0003o00LQo`0000;o00LQ0_l00002o`078@03o`000?l0
1b3o00LP00;o00000_l01b400ol0003o00LQo`000002o`000004o`078Ol0003o00LQo`078@?o0000
00Ko00LPo`000?l0003o0000o`078?l00002o`0780?o000000Co00LQo`000?l01b3o00LP0ol00000
0ol01b3o0000o`068003o`000004o`068?l0003o00HOo`067`?o000000Co00HPo`000?l01R3o00HP
0ol000001Ol01Qoo0000o`000?l0003o00HP00;o0000?oooool004Wooooo0ol00002ooooo`?o0000
0_l01R000ol0003o00HPo`000002o`000004o`068?l0003o00HPo`0680?o000000Ko00HPo`000?l0
003o0000o`068?l00002o`0780;o00000_l01b000ol0003o00LPo`078002o`0000;o00LP00?o0000
o`078?l000000_l000001?l01b3o0000o`078?l01b03o`000004o`078?l0003o00LPo`0780;o0000
0_l01b400ol0003o00LQo`078@02o`0000;o00LQ00?o0000o`078Ol000000_l000001_l01b7o0000
o`000?l0003o00LQo`0000;o00LQ0ol000001?l01b7o0000o`078Ol01b43o`000004o`078Ol0003o
00LQo`078@;o00000_l01b400ol0003o00LQo`000002o`0000;o00LQ0_l000001?l01b3o0000o`07
8?l01b03o`000004o`078Ol0003o00LQo`078@?o000000Co00LPo`000?l0003o00LP0_l00002o`06
8003o`000?l01R3o000000;o000000Co00HPo`000?l01R3o00HP0ol000001_l01Qoo0000o`000?l0
003o00HPo`0000;o00HP0_l0000oooooo`00Aoooool2o`0000?ooooo0_l00002o`067`03o`000?l0
1R3o00HP00;o00000_l01R000ol0003o00HPo`000002o`0000;o00HP0_l00002o`068003o`000?l0
1R3o000000;o000000Co00LPo`000?l01b3o00LP0ol000001?l01b3o0000o`078?l01b02o`0000;o
00LP00?o0000o`078?l000000_l00002o`078003o`000?l01b3o000000;o000000Co00LQo`000?l0
1b7o00LQ0ol000000ol01b7o0000o`000003o`0000;o00LQ0_l00002o`078@03o`000?l01b7o0000
00;o00000_l01b400ol0003o00LQo`000002o`000004o`078Ol0003o00LQo`078@?o000000Co00LQ
o`000?l01b7o00LQ0_l00002o`078@06o`000?l01b7o0000o`078Ol0003o00LP0ol00002o`078003
o`000?l01b7o000000;o000000Co00LQo`000?l01b3o00LP0ol000001?l01b3o0000o`068?l01R02
o`0000;o00HP00?o0000o`068?l000000_l000001_l01R3o0000o`000?l0003o00HPo`0000;o00HP
0ol000000ol01R3o0000o`00000nooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool2o`0000?ooooo0ol0000Looooo`?o00000_ooool3o`0000;o00HO00?o0000o`067ol000000_l0
00000ol01Qoo0000o`000003o`0000;o00HP0ol000001?l01R3o0000o`068?l01R02o`0000;o00HP
00?o0000o`078?l000000_l00002o`078003o`000?l01b3o000000;o000000Co00LPo`000?l01b3o
00LP0_l00002o`078003o`000?l01b3o00LP00;o00000_l01b000ol0003o00LQo`000002o`000006
o`078Ol0003o00LQo`000?l01b7o00000_l01b43o`000004o`088Ol0003o00LQo`078@;o00000_l0
1b400ol0003o00LQo`078@02o`0000;o00LQ00?o0000o`078Ol000000_l000001?l01b7o0000o`07
8Ol01b43o`000004o`078Ol0003o00LQo`078@;o00000_l01b42o`0000;o00LP00?o0000o`078?l0
1b000_l00002o`078@03o`000?l01b7o000000;o000000Co00LPo`000?l01b3o00LP0ol000001?l0
1R3o0000o`068?l01R02o`0000;o00HP0_l00002o`068003o`000?l01R3o000000;o000000Co00HP
o`000?l01R3o00HP0ol0000mooooo`004oooool01?l0003oooooooooool00008ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Gooooo`Co000000?oooooo`000?l0
00000_l01Ql00ol0003o00HOo`067`02o`0000;o00HO0_l00002o`067`03o`000?l01R3o000000;o
00000_l01R000ol0003o00HPo`000002o`000004o`078?l0003o00HPo`0680;o00000_l01b000ol0
003o00LPo`078002o`0000;o00LP00?o0000o`078?l000000_l000001?l01b3o0000o`078?l01b03
o`000004o`078Ol0003o00LPo`0780;o00000_l01b400ol0003o00LQo`000002o`000004o`078Ol0
003o0000o`0000;o00PQ00?o0000o`088Ol000000_l000001?l01b7o0000o`078Ol01b43o`000004
o`078Ol0003o00LQo`078@;o00000_l01b400ol0003o00LQo`000002o`000004o`078Ol0003o00LQ
o`078@?o000000Ko00LQo`000?l0003o0000o`078Ol00002o`0780?o000000Co00LQo`000?l01b7o
00LQ0_l00002o`078@03o`000?l01b3o000000;o000000Co00LPo`000?l01R3o00HP0ol000001_l0
1R3o0000o`000?l0003o00HPo`0000;o00HP0_l00002o`068003o`000?l01R3o000000;o000000?o
00HPo`000?l00000?Oooool000cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`0Dooooo`?o00000_ooool3o`0000;o00HO
00?o0000o`067ol000000_l000001_l01Qoo0000o`000?l0003o00HPo`0000;o00HO0_l00002o`06
8003o`000?l01R3o00HP00;o00000_l01R000ol0003o00LPo`000002o`000004o`068?l0003o00LP
o`0780?o000000Co00LPo`000?l01b3o00LP0_l00002o`078003o`000?l01b3o000000;o000000Co
00LQo`000?l01b7o00LQ0ol000000ol01b7o0000o`000003o`0000;o00LQ0_l00002o`088@03o`00
0?l0227o00PQ00;o00000_l022400ol0003o00LQo`000002o`000004o`078Ol0003o00LQo`078@?o
000000Co00LQo`000?l01b7o00LQ0_l00002o`078@03o`000?l01b7o000000;o000000Ko00LQo`00
0?l0003o0000o`078Ol00002o`078@?o000000Co00LQo`000?l01b7o00LQ0ol000001?l01b7o0000
o`078Ol01b43o`000003o`078?l0003o00LP00?o000000Ko00HPo`000?l0003o0000o`068?l00002
o`0680?o000000Co00HPo`000?l01R3o00HP0_l00002o`068003o`000?l01R3o000000;o0000??oo
ool001?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo01;ooooo0_l00003ooooo`?o000000?o00HOo`000?l000000ol00002o`067`;o0000
0_l01Ql00ol0003o00HPo`000002o`0000;o00HP00?o0000o`068?l000000_l000001?l01R3o0000
o`068?l01R02o`0000;o00LP00?o0000o`068?l000000_l00002o`078003o`000?l01b3o000000;o
000000Co00LPo`000?l01b3o00LP0_l00002o`078@03o`000?l01b7o000000;o00000_l01b42o`00
00;o00LQ00?o0000o`078Ol000000_l000001?l0227o0000o`088Ol02243o`000004o`088_l0003o
00PQo`088@;o00000_l01b400ol0003o00LQo`000002o`000004o`088Ol0003o00LQo`078@?o0000
00Co00LQo`000?l01b7o00LQ0_l00002o`088@;o00000_l01b400ol0003o00LQo`000002o`000004
o`078Ol0003o00LQo`078@?o000000Co00LQo`000?l01b7o00LQ0ol000001?l01b7o0000o`000?l0
1b02o`000006o`078?l0003o0000o`000?l01R3o00000_l01R03o`000004o`068?l0003o00HPo`06
80?o000000Co00HPo`000?l01R3o00HP0_l00002o`0680;o0000>oooool001?ooooo00Co0000oooo
oooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co00004_ooool8o`0000;o00HO0_l0
0002o`067`03o`000?l01Qoo000000;o000000Co00HOo`000?l01Qoo00HO0_l00002o`068003o`00
0?l01R3o00HP00;o00000_l01R000ol0003o00HPo`000002o`000004o`078?l0003o00LPo`0780;o
00000_l01b000ol0003o00LPo`078002o`0000;o00LP00?o0000o`078?l000000_l000000ol01b7o
0000o`000003o`0000;o00LQ0ol000001?l01b7o0000o`078Ol01b42o`0000;o00PR00?o0000o`08
8Ol000000_l000001?l022;o0000o`088_l02283o`000004o`088_l0003o00LQo`078@;o00000_l0
22400ol0003o00PQo`000002o`000004o`088Ol0003o00LQo`078@?o000000Ko00PQo`000?l0003o
0000o`088Ol00002o`078@;o00000_l01b400ol0003o00LQo`000002o`000004o`078Ol0003o00LQ
o`078@?o000000Co00LQo`000?l01b7o00LQ0ol000000ol01b7o0000o`000002o`078003o`000?l0
1R3o000000;o000000Co00HPo`000?l01R3o00HP0ol000001?l01R3o0000o`068?l01R03o`000004
o`068?l0003o00HPo`0680;o0000>oooool001?ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0001?ooooo0_l000000ooooooo0000o`000002o`067`03o`000?l0
1Qoo000000;o000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Qoo000000;o0000
0_l01R000ol0003o00HPo`000002o`000004o`068?l0003o00HPo`0680;o00000_l01R000ol0003o
00LPo`000002o`0000;o00LP00?o0000o`078?l000000_l000000ol01b3o0000o`000003o`0000;o
00LQ0_l00002o`078@03o`000?l01b7o000000;o00000_l01b400ol0003o00LQo`000002o`000004
o`088_l0003o00PRo`088P;o00000_l022800ol0003o00PRo`000002o`000004o`088_l0003o00PR
o`088P?o000000Co00PQo`000?l0227o00PQ0_l00002o`088P03o`000?l0227o000000;o000000Ko
00PRo`000?l0003o0000o`088_l00002o`088@?o000000Co00LQo`000?l01b7o00LQ0_l00002o`07
8@03o`000?l01b7o000000;o000000Co00LQo`000?l01b7o00LQ0ol000001_l01b7o0000o`000?l0
003o00LQo`0000;o00LP0_l00002o`068003o`000?l01R3o000000;o000000Co00HPo`000?l01R3o
00HP0ol000001?l01R3o0000o`068?l01R03o`000003o`068?l0003o000003[ooooo000Dooooo`;o
00002_ooool2o`0000;ooooo1Ol0000<ooooo`Ko000000Co00HOo`000?l01Qoo00HO0_l00002o`06
7`03o`000?l01Qoo000000;o00000_l01Ql01?l0003o00HOo`000?l00002o`067`03o`000?l01R3o
00HP00;o00000_l01R000ol0003o00HPo`000002o`000004o`068?l0003o00HPo`0680;o00000_l0
1b000ol0003o00LPo`078002o`0000;o00LP0_l00002o`078@03o`000?l01b7o000000;o000000Co
00LQo`000?l01b7o00LQ0_l00002o`078@03o`000?l01b7o00LQ00;o00000_l022400ol0003o00PR
o`000002o`000004o`088_l0003o00PRo`088P;o00000_l022800ol0003o00PRo`000002o`000004
o`088_l0003o00PQo`088@?o000000Co00PRo`000?l022;o00PR0_l00002o`088P;o00000_l02280
0ol0003o00PRo`000002o`000004o`088_l0003o00LQo`078@?o000000Co00LQo`000?l01b7o00LQ
0_l00002o`078@03o`000?l01b7o000000;o000000?o00LQo`000?l000000ol00002o`078@?o0000
00Co00LPo`000?l01R3o00HP0_l00002o`078003o`000?l01R3o000000;o000000Co00HPo`000?l0
1R3o00HP0ol000001Ol01R3o0000o`000?l0003o00HP00;o00002?ooool2o`0002oooooo000coooo
o`;o000000?oooooo`000?l000000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HO
o`067`;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o00HO00?o0000o`067ol000000_l00000
1?l01R3o0000o`068?l01R02o`0000;o00HP00?o0000o`068?l000000_l000000ol01R3o0000o`00
0004o`000006o`078?l0003o0000o`000?l01b7o00000_l01b42o`0000;o00LQ00?o0000o`078Ol0
00000_l000001?l01b7o0000o`078Ol01b43o`000004o`088_l0003o00PQo`088@;o00000_l02280
0ol0003o00PRo`000002o`000004o`088_l0003o00PRo`088P;o00000_l022800ol0003o00PRo`00
0002o`0000;o00PR00?o0000o`088_l000000_l000001_l022;o0000o`000?l0003o00PRo`0000;o
00PR0_l00002o`088P03o`000?l022;o000000;o000000Co00PQo`000?l01b7o00LQ0ol000001?l0
1b7o0000o`078Ol01b42o`0000;o00LQ0_l00002o`078@03o`000?l01b7o000000;o000000Co00LQ
o`000?l01b3o00LP0ol000001?l01b3o0000o`078?l01b02o`0000;o00HP00?o0000o`068?l00000
0_l000001_l01R3o0000o`000?l0003o00HPo`0000;o00HP0_l00007ooooo`04o`000?oooooooooo
o`0002kooooo000`ooooo`Ko000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Qoo
000000;o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HOo`067`;o00000_l0
1Ql00ol0003o00HPo`000002o`000004o`068?l0003o00HPo`0680;o00000_l01R02o`0000;o00LP
00?o0000o`078?l01b000_l00002o`078@03o`000?l01b7o000000;o000000Co00LQo`000?l01b7o
00LQ0_l00002o`078@03o`000?l01b7o000000;o000000Co00PRo`000?l022;o00PR0ol000001?l0
22;o0000o`088_l02282o`0000;o00PR00?o0000o`088_l000000_l000001?l022;o0000o`088_l0
2282o`0000;o00PR1Ol00002o`088P;o00000_l022800ol0003o00PRo`000002o`000004o`088_l0
003o00PRo`088P;o00000_l022800ol0003o00PQo`000002o`000004o`088Ol0003o00LQo`078@?o
000000Ko00LQo`000?l0003o0000o`078Ol00002o`078@?o000000?o00LQo`000?l01b400ol00000
1?l01b3o0000o`078?l01b03o`000003o`078?l0003o000000?o000000Ko00HPo`000?l0003o0000
o`078?l00002o`0680?o000000?o00HPo`000?l000001_ooool01?l0003oooooooooool0000^oooo
o`00;Oooool3o`000003ooooool0003o000000;o00HO00?o0000o`067ol000000_l00002o`067`04
o`000?l01Qoo0000o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Qoo0000
00;o000000?o00HOo`000?l000000ol00002o`0680Go000000Co00LPo`000?l0003o00000_l01b00
0ol0003o00LPo`000002o`000004o`078?l0003o00LQo`078@;o00000_l01b400ol0003o00LQo`00
0002o`000004o`078Ol0003o00LQo`078@;o00000_l022800ol0003o00PRo`000002o`000004o`08
8_l0003o00PRo`088P?o000000Co00PRo`000?l022;o00PR0_l00002o`088P03o`000?l022;o0000
00;o000000Ko00PRo`000?l022;o0000o`088_l00002o`088P?o000000Co00TSo`000?l022;o00PR
0_l00002o`088P03o`000?l022;o000000;o000000Co00PRo`000?l022;o00PR0_l00002o`088P03
o`000?l0227o000000;o000000Ko00LQo`000?l0003o0000o`078Ol00002o`078@?o000000Co00LQ
o`000?l0003o00LQ0_l000001?l01b3o0000o`078?l01b03o`000006o`078?l0003o0000o`000?l0
1R3o00000_l01R02o`0000;o00LP00?o0000o`078?l000000_l000001?l01R3o0000o`068?l01R02
o`0000Kooooo00Co0000oooooooooooo0000;_ooool002_ooooo0_l00002ooooo`;o00000_l01Ql0
1?l0003o00HOo`000?l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00HOo`00
0002o`000004o`067ol0003o00HOo`067`;o00000_l01Ql2o`0000;o00HO00?o0000o`067ol00000
0_l00002o`068004o`000?l01R3o0000o`0000;o00LP00?o0000o`078?l01b000_l00002o`078@03
o`000?l01b3o000000;o000000Co00LQo`000?l01b7o00LQ0_l00002o`078@03o`000?l01b7o0000
00;o000000Co00PQo`000?l022;o00PR0_l00002o`088P03o`000?l022;o000000;o00000_l02280
0ol0003o00PRo`000002o`000004o`088_l0003o00PRo`088P;o00000_l022800ol0003o00PRo`00
0002o`000006o`088_l0003o0000o`000?l02B?o00000_l02B<3o`000004o`088_l0003o00PRo`08
8P;o000000Co00PRo`000?l022;o00PR0ol000001?l022;o0000o`088_l02282o`0000;o00LQ0_l0
0002o`078@03o`000?l01b7o000000;o000000Co00PQo`000?l01b7o00LQ0ol000000ol01b7o0000
o`078003o`000006o`078?l0003o0000o`000?l01b3o00000_l01R03o`000004o`078?l0003o00LP
o`0780;o00000_l01b000ol0003o00HPo`000002o`000003o`068?l0003o000000Gooooo00Co0000
oooooooooooo0000;_ooool002Sooooo0ol000001_oooooo0000o`000?l0003o00HOo`0000;o00HO
0_l00002o`067`03o`000?l01Qoo000000;o000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03
o`000?l01Qoo000000;o000000Co00HOo`000?l0003o00000_l01R001?l0003o00HOo`000?l00002
o`068003o`000?l01R3o00HP00;o00000_l01b000ol0003o00LPo`000002o`000004o`078Ol0003o
00LQo`078@;o00000_l01b400ol0003o00LQo`000002o`000004o`078Ol0003o00LQo`078@;o0000
0_l022800ol0003o00PQo`000002o`000004o`088_l0003o00PRo`088P;o00000_l022800ol0003o
00PRo`088P02o`0000;o00PR00?o0000o`088_l000000_l000000ol022;o0000o`000003o`0000;o
00PR0_l00002o`098`03o`000?l02B?o000000;o000000Co00TSo`000?l022;o00PR0ol000000ol0
22;o0000o`088P03o`000004o`088_l0003o00PRo`088P?o000000Ko00PRo`000?l0003o0000o`08
8Ol00002o`078@;o00000_l022800ol0003o00PQo`000002o`000004o`078Ol0003o00LQo`078@;o
00000_l01b02o`0000;o00LP00?o0000o`078?l000000_l000001?l01b3o0000o`078?l01b03o`00
0004o`078?l0003o00LPo`0780;o000000Co00HPo`000?l01R3o00HP0ol00004ooooo`04o`000?oo
ooooooooo`0002kooooo000Vooooo`;o00000_ooool2o`0000;o00HO00?o0000o`067ol000000_l0
00001?l01Qoo0000o`067ol01Ql3o`000003o`067ol0003o00HO00?o000000?o00HOo`000?l00000
1?l000000ol01Qoo0000o`000002o`068003o`000?l01R3o00HP00;o00000_l01R000ol0003o00HP
o`000002o`000004o`078?l0003o00LPo`0780;o00000_l01b400ol0003o00LQo`000002o`000004
o`078Ol0003o00LQo`078@;o00000_l01b400ol0003o00LQo`000002o`000004o`088_l0003o00PR
o`088P;o00000_l022800ol0003o00PRo`000002o`000004o`088_l0003o00PRo`088P?o000000Co
00PSo`000?l022;o00PR0_l00002o`088P;o00000_l02B<00ol0003o00TSo`000002o`000004o`09
8ol0003o00TSo`098`;o00000_l02B<00ol0003o00TSo`000002o`000004o`088_l0003o00PRo`08
8P;o00000_l022800ol0003o00PRo`000002o`000006o`088_l0003o0000o`000?l022;o00000_l0
2243o`000004o`088_l0003o00PRo`088P;o000000Co00PQo`000?l01b7o00LQ0ol000001_l01b7o
0000o`000?l0003o00LQo`0000;o00LP0_l00002o`078003o`000?l01b3o000000;o000000Co00LP
o`000?l01b3o00LP0ol000000ol01R3o0000o`068003o`000004o`068?l0003o0000o`0000Cooooo
0_l0000_ooooo`008oooool3o`000004ooooool0003o0000o`0000;o00HO00Co0000o`067ol0003o
00000_l01Ql00ol0003o00HOo`000002o`0000;o00HO1Ol000000ol01Qoo0000o`000002o`067`03
o`000?l01Qoo00HO00;o00000_l01R000ol0003o00HPo`000002o`000004o`068?l0003o00HPo`06
80;o00000_l01b000ol0003o00LPo`000002o`000004o`078?l0003o00LQo`078@;o00000_l01b40
0ol0003o00LQo`000002o`000004o`078Ol0003o00LQo`078@;o00000_l022400ol0003o00PRo`00
0002o`000004o`088_l0003o00PRo`088P;o00000_l022800ol0003o00PRo`000002o`000004o`08
8ol0003o00PSo`088`?o000000Ko00TSo`000?l0003o0000o`098ol00002o`098`;o00000_l02B<0
0ol0003o00TSo`000002o`000004o`098ol0003o00TSo`098`;o00000_l02B<00ol0003o00PRo`00
0002o`000004o`088_l0003o00PRo`088P;o00000_l02B<2o`0000;o00PR00?o0000o`088_l00000
0_l000001?l022;o0000o`088_l02283o`000003o`088_l0003o00PQ00Oo000000Co00LQo`000?l0
1b7o00LQ0ol000001?l01b3o0000o`078?l01b02o`000004o`078?l0003o00LPo`0780?o000000?o
00HPo`000?l000000ol00002o`0680;o000000?o00HPo`000?l00000=Oooool0027ooooo0_l00002
ooooo`;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o00HO00?o0000o`067ol000000_l00000
1_l01Qoo0000o`000?l0003o00HOo`0000;o00HO0_l00002o`067`03o`000?l01Qoo000000;o0000
00Co00HOo`000?l01R3o00HP0_l00002o`068003o`000?l01R3o000000;o000000Co00LPo`000?l0
1b3o00LP0_l00002o`078003o`000?l01b3o000000;o000000Co00LQo`000?l01b7o00LQ0_l00002
o`078@03o`000?l01b7o000000;o000000Co00PQo`000?l0227o00PQ0_l00002o`088P03o`000?l0
22;o000000;o000000?o00PRo`000?l000000ol00002o`088PGo000000Ko00TSo`000?l0003o0000
o`098ol00002o`098`?o000000Co00TSo`000?l02B?o00TS0_l00002o`098`03o`000?l02B?o0000
00;o000000Co00TTo`000?l02B?o00TS0_l00002o`098`03o`000?l022;o000000;o000000Ko00TS
o`000?l0003o0000o`098ol00002o`088P;o00000_l022800ol0003o00PRo`000002o`000004o`08
8_l0003o00PRo`088P;o00000_l02242o`0000;o00LQ00?o0000o`078Ol000000_l000001?l01b7o
0000o`078?l01b03o`000003o`078?l0003o00LP00?o000000Ko00LPo`000?l0003o0000o`078?l0
0002o`0780?o000000?o00HPo`000?l01R000ol0000dooooo`007_ooool4o`000003ooooool0003o
000000;o00HO00?o0000o`067ol000000_l000000ol01Qoo0000o`000003o`0000;o00HO0_l00002
o`067`03o`000?l01Qoo000000;o000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l0
1Qoo000000;o000000Co00HPo`000?l01R3o00HP0_l00002o`078003o`000?l01b3o000000;o0000
00Co00LPo`000?l01b3o00LP0_l00002o`078@03o`000?l01b7o000000;o000000Co00LQo`000?l0
1b7o00LQ0_l00002o`088@03o`000?l0227o000000;o000000?o00PRo`000?l000000ol00002o`08
8P;o00000_l022<00ol0003o00PSo`000002o`000004o`098ol0003o00TSo`098`;o00000_l02B<0
0ol0003o00TSo`000002o`000004o`098ol0003o00TSo`098`?o000000Co00TTo`000?l02B?o00TS
0_l000001?l02RCo0000o`099?l02B@3o`000004o`098ol0003o00TSo`098`;o00000_l02B<2o`00
0004o`098ol0003o00TSo`098`?o000000Co00PRo`000?l022;o00PR0_l00002o`088P03o`000?l0
22;o000000;o000000Ko00PRo`000?l0003o0000o`088Ol00002o`078@;o000000Co00LQo`000?l0
1b7o00LQ0ol000001?l01b3o0000o`078?l01b02o`0000;o00LP0_l000001?l01b3o0000o`078?l0
1b03o`000004o`078?l0003o00HPo`0680;o000000?o00HPo`000?l00000=?ooool001gooooo0_l0
00001Ooooooo0000o`000?l0003o00HO00Ko000000?o00HOo`000?l000000_l01Ql00ol0003o00HO
o`000002o`000004o`067ol0003o00HOo`067`;o00000_l01Ql00ol0003o00HOo`000002o`000004
o`067ol0003o00HOo`067`;o00000_l01R000ol0003o00HPo`000002o`000004o`068?l0003o00LP
o`0780;o00000_l01b000ol0003o00LPo`000002o`000003o`078Ol0003o000000?o00000_l01b45
o`000003o`088Ol0003o000000?o00000_l02282o`0000;o00PR00?o0000o`088_l000000_l00000
1?l022;o0000o`088ol022<2o`0000;o00TS00?o0000o`098ol000000_l000001?l02B?o0000o`09
8ol02B<2o`0000;o00TS00?o0000o`098ol000000_l000001?l02RCo0000o`099?l02B@3o`000003
o`0:9?l0003o00XT00?o000000Co00XTo`000?l02B?o00TS0ol000001ol02B?o0000o`000?l0003o
00TTo`000?l02B<00ol000001?l02B?o0000o`088_l02283o`000004o`088_l0003o00PRo`088P;o
000000Ko00PRo`000?l0003o0000o`088_l00002o`088@?o000000?o00LQo`000?l01b400ol00000
0ol01b3o0000o`000004o`000007o`078?l0003o0000o`000?l01b3o0000o`078003o`000004o`07
8?l0003o00LPo`0780?o000000?o00HPo`000?l01R000ol0000cooooo`007Oooool4o`000003o`06
7ol0003o000000;o00HO00?o0000o`067ol01Ql00_l00002o`067`04o`000?l01Qoo0000o`0000;o
00HO00?o0000o`067ol000000_l00002o`067`04o`000?l01Qoo0000o`0000;o00HP00?o0000o`06
7ol000000_l000001?l01R3o0000o`068?l01R03o`000003o`068?l0003o000000?o000000?o00LP
o`000?l000000ol00002o`078@;o00000_l01b400ol0003o00LQo`000002o`000004o`078Ol0003o
00LQo`078@;o00000_l022400ol0003o00PRo`000002o`000004o`088_l0003o00PRo`088P;o0000
0_l022800ol0003o00PRo`000002o`000004o`098ol0003o00TSo`098`;o00000_l02B<00ol0003o
00TSo`000002o`000004o`099?l0003o00TSo`098`;o00000_l02R@00ol0003o00XTo`000002o`00
0004o`0:9?l0003o00XTo`0:90;o00000_l02R@00ol0003o00XTo`000002o`000006o`098ol0003o
0000o`000?l02RCo00000_l02B@2o`0000;o00TS00?o0000o`098ol000000_l000001?l022;o0000
o`088_l02286o`0000;o00PR00?o0000o`088_l000000_l000001?l022;o0000o`000?l01b42o`00
00;o00LQ0_l00002o`078@03o`000?l01b3o000000;o000000Co00LPo`000?l01b3o00LP0_l00002
o`078003o`000?l01b3o000000;o000000Co00LPo`000?l01R3o00HP0_l00002o`0680;o0000<_oo
ool001Kooooo0_l00005ooooo`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00HOo`000002
o`000004o`067ol0003o00HOo`067`;o00000_l01Ql01?l0003o00HOo`000?l00002o`067`03o`00
0?l01Qoo00HO00;o00000_l01Ql00ol0003o00HPo`000002o`000003o`068?l0003o00HP00?o0000
0_l01R02o`0000;o00HP00Co0000o`068?l0003o00000_l01b000ol0003o00LQo`000002o`000004
o`078Ol0003o00LQo`078@;o00000_l01b400ol0003o00LQo`000002o`000004o`078Ol0003o00PQ
o`088@;o00000_l022800ol0003o00PRo`000002o`000004o`088_l0003o00PRo`088P;o00000_l0
2B<00ol0003o00TSo`000002o`000004o`098ol0003o00TSo`098`;o00000_l02R@00ol0003o00TT
o`000002o`000004o`0:9?l0003o00XTo`0:90;o00000_l02bD00ol0003o00XTo`000002o`000004
o`0;9Ol0003o00XTo`0:90;o00000_l02R@2o`0000;o00XT00?o0000o`0:9?l000000_l000001?l0
2RCo0000o`098ol02B<2o`0000;o00TS2Ol000001?l022;o0000o`088_l02282o`0000;o00PR00?o
0000o`088_l000000_l000001_l01b7o0000o`000?l0003o00LQo`0000;o00LQ0_l000001?l01b3o
0000o`078?l01b03o`000004o`078?l0003o00LPo`0780;o000000Co00LPo`000?l01b3o00LP0ol0
00001_l01R3o0000o`000?l0003o00HPo`0003;ooooo000Eooooo`04o`000?ooooooooooo`0000Co
oooo0ol00002o`067`04o`000?l01Qoo0000o`0000;o00HO00?o0000o`067ol000000_l000001?l0
1Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`067ol000000_l000000ol01Qoo0000o`000003
o`0000;o00HO1Ol000001_l01R3o0000o`000?l0003o00HPo`0000;o00HP0_l00002o`068004o`00
0?l01b3o0000o`0000;o00LQ00?o0000o`078Ol000000_l000001?l01b7o0000o`078Ol01b42o`00
00;o00LQ00?o0000o`078Ol000000_l000001?l022;o0000o`088_l02282o`0000;o00PR00?o0000
o`088_l000000_l000001?l022;o0000o`098ol02B<2o`0000;o00TS00?o0000o`098ol000000_l0
00001?l02BCo0000o`0:9?l02R@2o`0000;o00XT00?o0000o`0:9?l000000_l000001?l02bGo0000
o`0;9Ol02bD2o`0000;o00/U00?o0000o`0;9Ol000000_l000001_l02bGo0000o`000?l0003o00/U
o`0000;o00XT0_l00002o`0:9003o`000?l02RCo000000;o000000Go00TSo`000?l02B?o0000o`09
8`05o`000004o`088_l0003o00PRo`088P?o000000Co00PRo`000?l022;o00PR0_l000001_l022;o
0000o`000?l0003o00LQo`0000;o00LQ0ol000000ol01b7o0000o`078003o`000004o`078?l0003o
00LPo`0780?o000000?o00LPo`000?l000000ol000001_l01R3o0000o`000?l0003o00HPo`0000;o
00HP0_l0000aooooo`005Oooool01?l0003oooooooooool00003ooooo`;o000000Coooooo`000?l0
1Qoo00HO0_l00002o`067`03o`000?l01Qoo000000;o000000?o00HOo`000?l01Ql00ol000000ol0
1Qoo0000o`000004o`000003o`067ol0003o000000;o00HO00?o0000o`067ol000000_l000001?l0
1Qoo0000o`068?l01R02o`0000;o00HP00?o0000o`068?l000000_l000001?l01R3o0000o`068?l0
1R02o`0000;o00LP00Co0000o`078Ol0003o00000_l01b400ol0003o00LQo`000002o`000004o`07
8Ol0003o00LQo`078@;o00000_l01b400ol0003o00PRo`000002o`000004o`088_l0003o00PRo`08
8P;o00000_l022800ol0003o00PRo`000002o`000004o`098ol0003o00TSo`098`;o00000_l02B@0
0ol0003o00TTo`000002o`000004o`0:9?l0003o00XTo`0:90;o00000_l02bD00ol0003o00/Uo`00
0002o`000004o`0;9Ol0003o00/Uo`0;9@;o00000_l02bD2o`0000;o00/U00?o0000o`0;9Ol00000
0_l000001?l02bGo0000o`0:9?l02R@2o`000004o`0:9?l0003o00TSo`098`Oo000000?o00TSo`00
0?l022800ol000001?l022;o0000o`088_l02283o`000003o`088_l0003o000000;o00PQ00?o0000
o`078Ol000000_l000001?l01b7o0000o`078Ol01b42o`0000;o00LP00?o0000o`078?l000000_l0
00001ol01b3o0000o`000?l0003o00LPo`000?l01R000ol000001?l01b3o0000o`068?l01R03o`00
0003o`068?l0003o0000033ooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooo
oooooooooooo0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO1Ol000000ol01Qoo0000o`00
0002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql01?l0003o00HOo`000?l00002o`067`03o`00
0?l01Qoo000000;o000000Co00HPo`000?l01R3o00HP0_l00002o`068003o`000?l01R3o000000;o
000000Co00HPo`000?l01b3o00LP0_l00002o`078003o`000?l01b7o000000;o000000?o00LQo`00
0?l01b400ol000001?l01b7o0000o`078Ol01b42o`0000;o00PR1Ol000001?l022;o0000o`088_l0
2282o`0000;o00TS1Ol000001?l02BCo0000o`099?l02B@2o`0000;o00XT00?o0000o`0:9?l00000
0_l000001?l02bGo0000o`0;9Ol02bD2o`0000;o00`V00?o0000o`0;9Ol000000_l000001_l032Ko
0000o`0;9Ol0003o00`Vo`0000;o00/U0_l000001?l02bGo0000o`0;9Ol02bD3o`000003o`0;9Ol0
003o00XT00Oo000000Co00TSo`000?l02B?o00TS0_l00002o`088P03o`000?l022;o000000;o0000
00Ko00PRo`000?l0003o0000o`088_l00002o`088@;o000000Co00LQo`000?l01b7o00LQ0ol00000
0ol01b7o0000o`000003o`000006o`078?l0003o0000o`000?l01b3o00000_l01b02o`0000;o00LP
00?o0000o`078?l000000_l000001?l01R3o0000o`068?l01R02o`00033ooooo000Eooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool4o`000006o`067ol0003o0000o`00
0?l01Qoo00000_l01Ql2o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol0
1Ql2o`0000;o00HO00Co0000o`067ol0003o00000_l01Ql00ol0003o00HPo`000002o`000004o`06
8?l0003o00HPo`0680;o00000_l01R05o`000003o`078?l0003o000000?o00000_l01b45o`000003
o`078Ol0003o000000?o000000Ko00PQo`000?l0003o0000o`088_l00002o`088PGo000000Ko00TS
o`000?l0003o0000o`098ol00002o`098`Go000000Co00XTo`000?l02RCo00XT0_l00002o`0;9@03
o`000?l02bGo000000;o000000Co00`Vo`000?l032Ko00`V0_l00002o`0<9PCo00000_l032H3o`00
0003o`0<9_l0003o00/U00?o000000Co00/Uo`000?l02bGo00/U1_l00002o`0:9003o`000?l02B?o
000000;o000000Co00TSo`000?l022;o00PR0_l00002o`088P;o000000Co00PRo`000?l022;o00PR
0ol000000ol022;o0000o`078@03o`000006o`078Ol0003o0000o`000?l01b7o00000_l01b02o`00
0004o`078?l0003o00LPo`0780?o000000Co00LPo`000?l01b3o00LP0_l000001?l01b3o0000o`06
8?l01R03o`000003o`068?l0003o000002oooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo
0_l00005ooooo`04o`000?l01Qoo0000o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo
0000o`067ol01Ql2o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql2
o`0000;o00HO00?o0000o`067ol000000_l000000ol01R3o0000o`000003o`000006o`068?l0003o
0000o`000?l01b3o00000_l01b02o`0000;o00LP00?o0000o`078?l000000_l000001?l01b7o0000
o`078Ol01b42o`0000;o00PQ00Co0000o`088Ol0003o00000_l022800ol0003o00PRo`000002o`00
0004o`088_l0003o00TSo`098`;o00000_l02B<00ol0003o00TSo`000002o`000004o`0:9?l0003o
00XTo`0:90Go000000Co00`Vo`000?l02bGo00/U0_l00002o`0<9P03o`000?l032Ko000000;o0000
00Oo00dWo`000?l032Ko0000o`0=9ol0003o00`V00?o000000Co00dWo`000?l032Ko00`V0_l00002
o`0<9P03o`000?l02bGo000000Ko000000Co00/Uo`000?l02RCo00XT0_l00002o`098`03o`000?l0
2B?o000000;o000000Oo00TSo`000?l0003o0000o`088ol0003o00PR00?o000000Co00PRo`000?l0
22;o00PR0_l00002o`078@;o000000Co00LQo`000?l01b7o00LQ0ol000000ol01b3o0000o`078003
o`000004o`078?l0003o00LPo`0780?o000000?o00LPo`000?l01b000ol000001Ol01R3o0000o`00
0?l0003o00HP00;o0000;_ooool001Kooooo0_l00004ooooo`03o`000?oooooooooo00Gooooo00Go
0000o`067ol01Qoo0000o`067`02o`0000;o00HO00?o0000o`067ol000000_l00002o`067`03o`00
0?l01Qoo000000;o000000?o00HOo`000?l000000ol000000ol01Qoo0000o`000003o`0000;o00HO
0_l00002o`068004o`000?l01R3o0000o`0000;o00LP00?o0000o`078?l000000_l000001?l01b3o
0000o`078?l01b02o`0000;o00LQ00?o0000o`078Ol000000_l000001?l01b7o0000o`088Ol02242
o`0000;o00PR00Co0000o`088_l0003o00000_l022800ol0003o00PRo`000002o`000004o`098ol0
003o00TSo`098`;o00000_l02R@00ol0003o00XTo`000002o`000006o`0;9Ol0003o00/Uo`0;9Ol0
003o00`V0ol000001?l032Ko0000o`0<9_l032H2o`000004o`0=9ol0003o00dWo`0=9`;o00000_l0
3BL2o`0000;o00dX00?o0000o`0=9ol000000_l000001?l03BOo0000o`0<9_l032H6o`0000;o00/V
00?o0000o`0;9Ol000000_l000001?l02RCo0000o`098ol02B<2o`000006o`098ol0003o0000o`00
0?l02B?o00000_l022<2o`0000;o00PR00?o0000o`088_l000000_l000001ol022;o0000o`000?l0
003o00LQo`000?l01b400ol000001?l01b7o0000o`078?l01b02o`0000;o00LP00?o0000o`078?l0
00000_l000000ol01b3o0000o`000003o`000006o`068?l0003o0000o`000?l01R3o00000_l01R02
o`0002kooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000o`067ol01Ql00ol000000ol0
1Qoo0000o`067`03o`000004o`067ol0003o00HOo`067`;o00000_l01Ql2o`0000;o00HO00Co0000
o`067ol0003o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HPo`0680;o0000
0_l01b001?l0003o00LPo`000?l00002o`078003o`000?l01b3o000000;o000000Co00LQo`000?l0
1b7o00LQ0_l00002o`078@03o`000?l01b7o000000;o000000Co00PRo`000?l022;o00PR0_l00000
1?l022;o0000o`088_l02282o`0000;o00TS00?o0000o`098ol000000_l000001?l02RCo0000o`0:
9?l02R@2o`0000;o00/U00?o0000o`0;9Ol000001?l00002o`0=9`03o`000?l032Ko000000;o0000
00?o00dWo`000?l03BL00ol000001_l03RSo0000o`000?l0003o00hXo`0000;o00dX0_l00002o`0>
:003o`000?l03BOo000000Co000000Co00`Vo`000?l032Ko00000_l02bH2o`000004o`0;9Ol0003o
00XTo`0:90?o000000?o00TSo`000?l000000_l02B<00ol0003o00TSo`000002o`000004o`088ol0
003o00PRo`088P;o000000Go00PRo`000?l0003o0000o`088P02o`000003o`078Ol0003o000000;o
00LQ00?o0000o`078Ol000000_l000000ol01b3o0000o`000003o`000006o`078?l0003o0000o`00
0?l01R3o00000_l01R02o`0000;o00HP00?o0000o`068?l000000_l000000ol01R3o0000o`00000]
ooooo`006oooool2o`0000Sooooo0_l00002o`067`Go000000?o00HOo`000?l000000ol000001_l0
1Qoo0000o`000?l0003o00HOo`0000;o00HO0_l00002o`067`04o`000?l01Qoo0000o`0000;o00HO
00?o0000o`067ol000000_l000001?l01R3o0000o`078?l01b02o`0000;o00LP00Co0000o`078?l0
003o00000_l01b400ol0003o00LQo`000002o`000004o`078Ol0003o00LQo`078@;o00000_l02240
0ol0003o00PRo`000002o`000003o`088_l0003o00PR00?o000000Co00TSo`000?l02B?o00TS0_l0
0002o`099003o`000?l02RCo000000;o000000Co00/Uo`000?l02bGo00/U0_l00002o`0<9P03o`00
0?l032Oo000000Co000000Co00hXo`000?l03BOo00dW0_l00002o`0>:0;o00000_l03bT00ol0003o
00hXo`000002o`000004o`0?:Ol0003o00hXo`0>:0?o000000?o00dWo`000?l032H00_l00002o`0<
9P?o000000?o00`Vo`000?l02bD00ol000001_l02RCo0000o`000?l0003o00TTo`0000;o00TS0_l0
00001?l02B?o0000o`088ol022<3o`000003o`088_l0003o000000;o00PR00?o0000o`088_l00000
0_l000001?l01b7o0000o`078Ol01b42o`000006o`078?l0003o0000o`000?l01b3o00000_l01b02
o`0000;o00HP00?o0000o`068?l000000_l000001?l01R3o0000o`068?l01R02o`000004o`068?l0
003o00HPo`0680?o0000;?ooool001_ooooo00?o0000ooooooooool02Oooool2o`000004o`067ol0
003o00HOo`067`;o00000_l01Ql01?l0003o00HOo`000?l00002o`067`03o`000?l01Qoo000000;o
000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Qoo000000;o000000?o00HPo`00
0?l01R000ol000001?l01b3o0000o`078?l01b02o`0000;o00LQ00Co0000o`078Ol0003o00000_l0
1b400ol0003o00LQo`000002o`000003o`078Ol0003o000000?o00000_l022800ol0003o00PRo`00
0002o`000003o`098ol0003o00TS00?o000000Co00TSo`000?l02BCo00TT0_l00002o`0;9@03o`00
0?l02bGo000000;o000000Co00`Vo`000?l032Ko00`V0_l000001_l03RSo0000o`0>:?l03RSo0000
o`0>:0?o000000Ko00lYo`000?l03RSo0000o`0@:_l00002o`0?:@;o00000_l042X00ol0003o00lY
o`000002o`000004o`0?:Ol0003o00dWo`0=9`;o000000Ko00dWo`000?l0003o0000o`0=9ol00002
o`0<9P;o00000_l02bD2o`000004o`0:9?l0003o00TTo`0990?o000000?o00TSo`000?l02B<00ol0
00001_l022?o0000o`000?l0003o00PRo`0000;o00PR0_l000001?l0227o0000o`000?l01b43o`00
0003o`078Ol0003o000000;o00LQ00?o0000o`078?l000000_l000001?l01b3o0000o`068?l01R02
o`000004o`068?l0003o00HPo`0680?o000000?o00HPo`000?l01R000ol000000ol01R3o0000o`00
000/ooooo`006oooool00ol0003oooooooooo`0:ooooo`03o`000?l01Qoo000000;o000000Co00HO
o`000?l01Qoo00HO0_l00002o`067`04o`000?l01Qoo0000o`0000;o00HO00?o0000o`067ol00000
0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HP1?l00002o`0780Go000000?o00LQo`000?l0
00000ol000000ol01b7o0000o`000003o`0000;o00LQ0_l00002o`088P03o`000?l022;o000000Co
00000_l02B<4o`0000;o00TS1Ol000001?l02RCo0000o`0;9Ol02bD2o`0000;o00`V00?o0000o`0<
9_l000000_l000000ol03BOo0000o`0>:005o`0000;o00lY00Co0000o`0?:Ol0003o00000ol042X2
o`000003o`0A:ol0003o010Z00?o000000Co014[o`000?l03bWo00lY0ol000000ol03RSo0000o`00
0002o`0>:003o`000?l03BOo000000;o000000Oo00`Vo`000?l02bGo0000o`0;9Ol0003o00XT00?o
00000_l02B@4o`0000;o00TS0_l000001?l022?o0000o`088_l02283o`000003o`088_l0003o00PQ
00?o000000Ko00LQo`000?l0003o0000o`078Ol00002o`078@;o000000Co00LPo`000?l01b3o00LP
0ol000000ol01b3o0000o`068003o`000003o`068?l0003o000000?o000000Go00HPo`000?l0003o
0000o`068002o`0002_ooooo000Kooooo`;o00003?ooool01Ol0003o00HOo`067ol0003o00HO00?o
000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Qoo000000;o000000?o00HPo`00
0?l000000ol000001ol01R3o0000o`000?l0003o00HPo`000?l01R000ol000001?l01b3o0000o`07
8?l01b02o`0000;o00LQ00Co0000o`078Ol0003o00000_l01b400ol0003o00LQo`000002o`000004
o`088Ol0003o00PRo`088P;o00000_l022800ol0003o00PRo`000002o`000003o`098ol0003o00TS
00?o000000Co00XTo`000?l02RCo00XT1Ol000001?l02bKo0000o`0<9_l032H2o`000004o`0=9ol0
003o00dWo`0=9`;o00000_l03bT00ol0003o00lYo`000004o`0000;o014[00Go0000o`0@:_l0003o
0000o`0A:`04o`000004o`0B;?l0003o014[o`0A:`;o000000Ko010Zo`000?l03RSo0000o`0?:Ol0
0002o`0>:0;o00000_l03BL01?l0003o00`Vo`000?l00002o`0;9@;o00000_l02R@01_l0003o00TT
o`000?l02BCo0000o`098`?o000000?o00TSo`000?l022<00ol000001?l022;o0000o`088_l02282
o`0000;o00PR0_l000001?l01b7o0000o`078Ol01b43o`000003o`078Ol0003o00LP00?o000000?o
00LPo`000?l000000ol000001_l01R3o0000o`000?l0003o00HPo`0000;o00HP0_l000001?l01R3o
0000o`068?l01R02o`0002_ooooo0008ooooo`;o00001?ooool01?l0003oooooooooooooool5o`00
00Cooooo00?o0000ooooooooool03?ooool00ol0003o00HOo`000002o`000003o`067ol0003o0000
00?o000000?o00HOo`000?l000000ol00002o`0680;o000000Co00HPo`000?l01R3o00HP0_l00002
o`068004o`000?l01R3o0000o`0000;o00HP00?o0000o`078?l000000_l000001?l01b3o0000o`07
8Ol01b42o`0000;o00LQ00Co0000o`078Ol0003o00000_l022400ol0003o00PQo`000002o`000004
o`088_l0003o00PRo`088P;o00000_l022801?l0003o00TSo`000?l00002o`099003o`000?l02RCo
000000;o000000Co00/Uo`000?l02bGo00/U1Ol000000ol03BOo0000o`0=9`03o`000004o`0?:Ol0
003o00lYo`0?:@;o000000Go014[o`000?l04B_o014[o`000002o`0A:`Go000000?o014[o`000?l0
00000ol04R`2o`000003o`0B;?l0003o010Z00;o00000ol03bT2o`000004o`0>:?l0003o00dWo`0=
9`;o000000Ko00`Vo`000?l0003o0000o`0;9Ol00002o`0:90;o00000_l02B@2o`000004o`098ol0
003o00TSo`098`;o00000_l022<5o`000007o`088_l0003o0000o`000?l022;o0000o`078@03o`00
0004o`078Ol0003o00LQo`078@;o000000Ko00LPo`000?l0003o0000o`078?l00002o`0780;o0000
00Co00HPo`000?l01R3o00HP0ol000000ol01R3o0000o`068003o`000003o`068?l0003o000002[o
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0=ooooo`03o`000?l01Qoo00HO00;o00000_l01Ql01?l0003o00HOo`000?l00002
o`067`03o`000?l01Qoo000000;o000000?o00HOo`000?l01R000ol000001?l01R3o0000o`068?l0
1R02o`0000;o00HP00?o0000o`068?l000000_l000000ol01b3o0000o`078003o`000004o`078Ol0
003o00LQo`078@;o00000_l01b401?l0003o00PQo`000?l00002o`088P03o`000?l022;o000000;o
000000Co00PRo`000?l022;o00PR0_l000001?l02B?o0000o`099?l02B@2o`0000;o00XT00?o0000
o`0;9Ol000000_l000001?l032Ko0000o`0<9_l032H4o`0000;o00hX00?o0000o`0?:Ol000000_l0
00001_l04B_o0000o`0A:ol04B_o0000o`0A:`Go00000_l04R`2o`000004o`0D;Ol0003o018/o`0B
;0;o00000_l04R`2o`0000;o014[00Co0000o`0?:Ol0003o00000_l03RP3o`000003o`0=9ol0003o
000000;o00`V00?o0000o`0;9Ol000000_l000001ol02RCo0000o`000?l0003o00TTo`000?l02B<0
0ol000001ol02B?o0000o`000?l0003o00PRo`000?l022800ol000001?l022;o0000o`088_l02282
o`000003o`078Ol0003o000000Co000000Go00LPo`000?l0003o00LPo`000002o`0780?o000000?o
00HPo`000?l01R000ol000000ol01R3o0000o`000003o`000003o`067ol0003o000000Co0000:Ooo
ool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`;o00004?oo
ool2o`000004o`067ol0003o00HOo`067`;o00000_l01Ql01?l0003o00HOo`000?l00002o`067`03
o`000?l01Qoo000000;o000000?o00HOo`000?l01R000ol000001?l01R3o0000o`068?l01R02o`00
00;o00HP1Ol000000ol01b3o0000o`000003o`000003o`078Ol0003o000000?o000000?o00PQo`00
0?l000000ol00002o`088PGo000000?o00PRo`000?l000000ol000001?l02RCo0000o`0:9?l02R@2
o`0000;o00/U00?o0000o`0<9_l000000_l000001?l03BOo0000o`0>:?l00002o`0>:0;o00000_l0
4B/00ol0003o014[o`000007o`000007o`0D;Ol0003o0000o`000?l05Bko0000o`0D;@03o`000006
o`0E;_l0003o018/o`000?l052go00000_l04B/2o`000004o`0@:_l0003o0000o`0000;o00lY0_l0
00001?l03RSo0000o`0<9_l032H2o`000006o`0<9_l0003o0000o`000?l02RCo00000_l02B@2o`00
0006o`098ol0003o0000o`000?l02B?o00000_l02282o`0000;o00PR00?o0000o`088_l000000_l0
00000ol0227o0000o`000002o`078@03o`000?l01b7o000000;o000000?o00LPo`000?l01b000ol0
00001?l01R3o0000o`068?l01R02o`0000;o00HP0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o
00HO00Co0000o`067ol0003o0000:Oooool000Oooooo00Co0000oooooooooooo00002_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000o`067ol000000_l000001?l0
1Qoo0000o`067ol01Ql2o`0000;o00HO00Co0000o`067ol0003o00000_l01Ql5o`000003o`068?l0
003o000000?o000000Ko00HPo`000?l0003o0000o`068?l00002o`0780;o00000_l01b001?l0003o
00LQo`000?l00002o`078@04o`000?l01b7o0000o`0000;o00PR00?o0000o`088_l000000_l00000
1?l022;o0000o`088_l02282o`0000;o00TS00?o0000o`098ol000001?l000001?l02bGo0000o`0;
9Ol02bD2o`0000;o00`V00?o0000o`0=9ol000001?l000001?l042[o0000o`0A:ol04B/2o`000003
o`0D;_l0003o000000;o00000_l052h2o`000004o`0G<?l0003o01D^o`0E;P;o00000_l05c000ol0
003o01D^o`000002o`000005o`0D;Ol0003o0000o`000?l04R`00_l00002o`0A:`06o`000?l03bWo
0000o`0?:Ol0003o00hX0ol000000ol03BOo0000o`000002o`0;9@03o`000?l02RCo000000;o0000
00?o00TTo`000?l000000_l02B<00ol0003o00TSo`000002o`000004o`088_l0003o00PRo`088P;o
000000Ko00PRo`000?l0003o0000o`088Ol00002o`078@;o000000Co00LQo`000?l01b3o00LP0_l0
0002o`0780Go000000Oo00HPo`000?l0003o0000o`068?l0003o00HO00?o000000Co00HPo`000?l0
1Qoo00HO0_l000000ol01Qoo0000o`00000Xooooo`001oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`;o000000?o00HO
o`000?l000000ol000000ol01Qoo0000o`000003o`000006o`067ol0003o0000o`000?l01Qoo0000
0_l01R02o`0000;o00HP00Co0000o`068?l0003o00000_l01R000ol0003o00HPo`000002o`000004
o`078?l0003o00LPo`0780;o000000Co00LQo`000?l01b7o00LQ0_l00002o`078@04o`000?l022;o
0000o`0000;o00PR00?o0000o`088_l000000_l000001?l022;o0000o`098ol02B<2o`000004o`09
8ol0003o00XTo`0:90Go000000Co00`Vo`000?l032Ko00`V0_l000001_l03RSo0000o`0?:Ol03bWo
0000o`0@:P?o000000?o01@]o`000?l000000_l000001ol052go0000o`000?l0003o01P`o`000?l0
5c000ol000001?l06C7o0000o`0G<?l05c02o`0000;o01L`0_l000001_l05Bko0000o`0B;?l0003o
01<]o`0000;o014[0_l00002o`0?:@;o000000Ko00hXo`000?l03BOo0000o`0<9_l00002o`0;9@;o
000000Ko00XTo`000?l0003o0000o`098ol00002o`098`;o000000?o00PRo`000?l000001?l00000
1Ol022;o0000o`000?l022;o000000;o00PQ0ol000000ol01b7o0000o`078@03o`000007o`078?l0
003o0000o`000?l01b3o0000o`068003o`000004o`068?l0003o00HPo`0680;o000000Co00HPo`00
0?l01R3o00HP0ol000000ol01Qoo0000o`000003o`0002Oooooo0007ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`;o00005?ooool01Ol0003o00HOo`06
7ol0003o00HO00;o00000_l01Ql01?l0003o00HOo`000?l00002o`067`03o`000?l01Qoo000000;o
000000Co00HPo`000?l01R3o00HP0_l00002o`068004o`000?l01R3o0000o`0000;o00LP00?o0000
o`078?l000000_l000000ol01b3o0000o`078@03o`000004o`078Ol0003o00LQo`078@;o00000_l0
22801?l0003o00PRo`000?l00002o`088P03o`000?l022;o000000;o000000?o00TSo`000?l02B<0
0ol000001?l02bGo0000o`0;9Ol02bD5o`000003o`0=:?l0003o00hX00Go000000Oo018/o`000?l0
003o0000o`0D;Ol0003o01@^00;o000000Co01L`o`000?l0633o01P`0_l000000ol07CCo0000o`0I
<@02o`0I<@;o000000Oo01Xbo`000?l05c3o0000o`0I<Ol0003o01D^00;o00000ol04bd2o`0000;o
014[0_l000000ol03bWo0000o`0>:003o`000005o`0<9_l0003o0000o`000?l02bD00_l00002o`0:
9003o`000?l02B?o000000;o000000?o00TSo`000?l000000_l022800ol0003o00PRo`000002o`00
0003o`088_l0003o00PR00?o000000Co00PQo`000?l0003o00LQ0_l000001_l01b7o0000o`000?l0
003o00LQo`0000;o00LP0_l000001?l01b3o0000o`068?l01R03o`000003o`068?l0003o00HP00?o
000000Oo00HOo`000?l0003o0000o`067ol0003o00HO00;o00009oooool000Sooooo0_l00009oooo
o`?o00001?ooool00ol0003oooooooooo`0Cooooo`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0
003o00HOo`000002o`000003o`067ol0003o00HO00?o000000?o00HPo`000?l01R000ol000001?l0
1R3o0000o`068?l01R02o`000004o`078?l0003o00LPo`0780;o00000_l01b05o`000003o`078Ol0
003o000000?o000000?o00PQo`000?l000000ol000001?l022;o0000o`088_l02282o`0000;o00TS
00Co0000o`098ol0003o00000_l02R@00ol0003o00/Uo`000002o`000006o`0<9_l0003o00dWo`0=
9ol0003o00dX0_l00002o`0@:PCo000000?o018/o`000?l000000ol000000ol0633o0000o`0G<003
o`000006o`0P=_l0003o01ddo`0M=?l0003o01Ta0_l00003o`0J<P03o`000?l06C7o01Ta00;o0000
0_l05c001_l0003o01<]o`000?l052ko0000o`0A:`;o00000_l03bT2o`0000;o00hX0_l00002o`0<
9P;o000000Co00/Uo`000?l02RCo00XT0_l000001_l02B?o0000o`000?l0003o00TSo`0000;o00PR
0_l000001?l022;o0000o`088_l02282o`0000;o00PR1Ol000000ol01b7o0000o`000002o`078@03
o`000?l01b7o000000;o000000?o00LPo`000?l01b000ol000000ol01R3o0000o`000003o`000006
o`068?l0003o0000o`000?l01Qoo00000_l01Ql2o`000004o`067ol0003o0000o`0002Gooooo000J
ooooo`03o`000?oooooooooo01Cooooo0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO1?l0
0002o`067`Go000000?o00HPo`000?l000000ol000000ol01b3o0000o`000003o`000006o`078Ol0
003o0000o`000?l01b7o00000_l01b42o`000004o`078Ol0003o00LQo`078@;o00000_l022800ol0
003o00PRo`000004o`000003o`098ol0003o000000?o000000Co00XTo`000?l02RCo00XT0_l00002
o`0;9@03o`000?l032Ko000000Co000000?o00lYo`000?l000001_l000001?l05Bko0000o`0G<?l0
0002o`0H<0;o000000Go024go`000?l083Ko020fo`000002o`0M=0;o00000_l08CL02?l0003o01Xb
o`000?l0003o01Tao`000?l07CCo00000_l05c02o`0000;o01@^0_l000001Ol04B_o0000o`000?l0
003o00lY00?o000000Oo00dWo`000?l032Ko0000o`0<9_l0003o00/U00?o000000?o00XTo`000?l0
00000_l02B<00ol0003o00TSo`000002o`000003o`088_l0003o00PR00?o000000Oo00PRo`000?l0
003o0000o`088_l0003o00PQ00?o000000Co00LQo`000?l01b7o00LQ0_l000000ol01b7o0000o`00
0003o`000006o`068?l0003o0000o`000?l01R3o00000_l01Ql2o`000004o`067ol0003o00HOo`06
7`?o000000?o00HOo`000?l01Ql00ol0000Uooooo`006Oooool2o`0001Sooooo1?l000001ol01Qoo
0000o`000?l0003o00HOo`000?l01Ql00ol000001?l01Qoo0000o`068?l01R02o`0000;o00HP00Co
0000o`078?l0003o00000_l01b001?l0003o00LQo`000?l00002o`078@03o`000?l01b7o000000;o
000000?o00LQo`000?l01b400ol000001?l0227o0000o`088_l02282o`000004o`088_l0003o00TS
o`098`;o00000_l02B<00ol0003o00TTo`000004o`000003o`0;9Ol0003o000000?o00000_l03BL0
0ol0003o00hXo`000004o`000006o`0B;?l0003o01@]o`0D;Ol0003o01D^1Ol000001Ol083Ko0000
o`0Q=ol08COo000000;o020f0_l000000ol0;Cko0000o`0Q=`02o`0Q=`04o`000?l08COo024go`00
00?o01dd0_l00002o`0H<0;o000000?o01@]o`000?l000000_l04B/2o`000004o`0?:Ol0003o00dW
o`0=9`;o00000_l032H2o`000006o`0;9Ol0003o0000o`000?l02RCo00000_l02B<2o`000003o`09
8ol0003o000000?o000000Ko00PRo`000?l0003o0000o`088_l00002o`088P;o000000Co00LQo`00
0?l0003o00LQ0ol000001Ol01b7o0000o`000?l01b3o000000;o00LP0_l00002o`068003o`000?l0
1R3o000000;o000000?o00HOo`000?l01Ql00ol000000ol01Qoo0000o`000003o`000003o`067ol0
003o000002Gooooo000Iooooo`03o`000?oooooooooo01Sooooo00Co0000o`067ol0003o00000_l0
1Ql01?l0003o00HOo`000?l00002o`067`03o`000?l01Qoo000000;o000000Co00HPo`000?l01R3o
00HP0_l000001?l01b3o0000o`078?l01b02o`0000;o00LQ00Co0000o`078Ol0003o00000_l01b40
0ol0003o00LQo`000002o`000003o`078Ol0003o00PQ00?o000000?o00PRo`000?l022800ol00000
1?l02B?o0000o`098ol02B<2o`0000;o00XT00Co0000o`0:9?l0003o00000_l02bD01?l0003o00`V
o`000?l03BL5o`0000;o014[00?o0000o`0B;?l000001?l000001?l06C7o0000o`0M=?l00002o`0P
=P05o`000?l08COo024go`000?l083H00_l00002o`0]?P03o`000?l08COo024g00;o00000_l08CL0
1?l0003o01ddo`0M=?l07C@2o`00000<o`0H<?l0003o0000o`0D;Ol0003o01@^o`000?l04B_o0000
o`0A:ol0003o00lY0ol000001Ol03BOo0000o`000?l0003o00`V00;o00000_l02bD00ol0003o00XT
o`000002o`000005o`098ol0003o0000o`088_l000000_l02282o`0000;o00PR00?o0000o`088_l0
00000_l000000ol01b7o0000o`000003o`000007o`078Ol0003o0000o`000?l01b7o0000o`078003
o`000004o`078?l0003o00HPo`0680;o000000?o00HOo`000?l000000ol000001_l01Qoo0000o`00
0?l0003o00HOo`0000;o00HO0_l000000ol01Qoo0000o`00000Tooooo`006Oooool00ol0003ooooo
ooooo`0Iooooo`05o`000?l01Qoo00HOo`000?l01Ql00ol000000ol01Qoo0000o`067`03o`000003
o`067ol0003o000000?o000000?o00HPo`000?l000000ol000000ol01b3o0000o`000003o`000003
o`078Ol0003o000000?o00000_l01b44o`0000;o00PQ1Ol000000ol022;o0000o`000003o`000004
o`098ol0003o00XTo`0:90;o000000Co00/Uo`000?l02bGo00/U1Ol000000ol03BSo0000o`0?:@05
o`0000;o01D^00?o0000o`0G<?l000000_l06C400ol0003o01ddo`000002o`0P=P06o`000?l08COo
0000o`000?l0>dKo00000ol0;Ch2o`0000;o03A20_l000001?l0;Cko0000o`0M=?l00002o`0P=P03
o`000?l05c3o000000;o000000?o01@^o`000?l000000_l04B/2o`0000;o00hX0_l000001_l03BOo
0000o`000?l0003o00/Vo`0000;o00/U0_l000001ol02BCo0000o`000?l0003o00TSo`000?l02280
0ol000000ol022;o0000o`000003o`000006o`078Ol0003o0000o`000?l01b7o00000_l01b42o`00
0004o`078Ol0003o00LQo`078@;o000000Co00LPo`000?l01b3o00LP0ol000001Ol01R3o0000o`00
0?l01Qoo000000;o00HO0_l000001?l01Qoo0000o`067ol01Ql3o`000003o`067ol0003o00HO00?o
00008oooool001Wooooo0_l0000Kooooo`Co00000_l01Ql4o`0000;o00HO0_l00002o`067`04o`00
0?l01Qoo0000o`0000;o00HP00Co0000o`078?l0003o00000_l01b001?l0003o00LQo`000?l00002
o`078@03o`000?l01b7o000000;o000000?o00LQo`000?l01b400ol000001?l0227o0000o`088_l0
2282o`000004o`088_l0003o00TSo`098`Go000000?o00XTo`000?l02bD01Ol00002o`0<9PCo0000
0_l042X00ol0003o018/o`000002o`0E;Pco000000Go04=9o`000?l0>dKo03]6o`000002o`0]?P05
o`000?l0=4;o03A2o`0d@_l000000ol0;Ch01_l0003o020fo`0P=_l0003o024go`0000;o01P`0_l0
00001Ol04bgo0000o`000?l0003o010Z00?o000000?o00hXo`000?l000000_l032H00ol0003o00/V
o`000002o`000005o`0:9?l0003o0000o`098ol000000_l02B<2o`0000;o00PR0_l000001?l022;o
0000o`088Ol02242o`000004o`078Ol0003o00LQo`078@?o000000?o00LQo`000?l01b400ol00000
0ol01b7o0000o`000003o`000007o`078?l0003o0000o`000?l01R3o0000o`067`03o`000003o`06
7ol0003o00HO00?o000000?o00HOo`000?l000000ol000000ol01Qoo0000o`00000Sooooo`001_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool06ooo
ool00ol0003o00HOo`000002o`000003o`067ol0003o00HO00?o000000Co00HOo`000?l01Qoo00HO
0_l000001?l01Qoo0000o`068?l01R02o`0000;o00LP00Co0000o`078?l0003o00000_l01b401?l0
003o00LQo`000?l00002o`078@03o`000?l01b7o000000;o000000?o00LQo`000?l022400ol00000
0ol022;o0000o`088P03o`000004o`098ol0003o00TSo`098`_o000000?o00dWo`000?l03RP02?l0
00001_l05c3o0000o`0J<_l0003o024go`0000;o02dn00?o0000o`0kA_l000000_l0@dT01?l0003o
03]6o`0kA_l00002o`0]?P05o`000?l0=4;o03A2o`0d@_l000000ol0;Ch01?l0003o020fo`000?l0
8CL2o`000003o`0H<?l0003o01L`00;o00000_l04R`2o`0000;o00lY0_l000001?l03BOo0000o`0<
9_l032H2o`000007o`0;9Ol0003o0000o`000?l02RCo0000o`098`03o`000007o`098ol0003o0000
o`000?l022;o0000o`088P03o`000003o`088Ol0003o00LQ00?o000000?o00LQo`000?l000000ol0
00001ol01b7o0000o`000?l0003o00LQo`000?l01b000ol000001?l01b3o0000o`068?l01R02o`00
0003o`068?l0003o000000?o000000Ko00HOo`000?l0003o0000o`067ol00002o`067`;o000000?o
00HOo`000?l000008_ooool000Gooooo00Co0000oooooooooooo00002_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01cooooo00Go0000o`067ol01Qoo0000o`067`03o`000003o`06
7ol0003o00HO00?o000000?o00HOo`000?l000000ol000000ol01R3o0000o`000003o`000003o`07
8?l0003o000000?o000000?o00LQo`000?l000000ol00002o`078@Co00000_l02285o`000003o`08
8_l0003o000000Wo000000Co00/Uo`000?l032Ko00`V1?l00002o`0?:@03o`000?l04B_o000000;o
01<]00?o0000o`0G<?l000001Ol000001?l0;Cko0000o`0kA_l00002o`13B@05o`000?l0>dKo03]6
o`000?l0;Ch00_l00002o`0d@P;o00000_l0;Ch01Ol0003o03]6o`000?l08COo000000;o020f00ko
0000o`0G<?l0003o01D^o`000?l04Rco0000o`0A:ol0003o00lYo`000?l03RSo0000o`0=9`?o0000
00Go00`Vo`000?l0003o00/Uo`000002o`0:90;o00000_l02B<2o`000004o`098ol0003o00PRo`08
8P;o000000?o00PRo`000?l000000ol00002o`078@;o000000Co00LQo`000?l01b7o00LQ0_l00000
1?l01b7o0000o`078Ol01b42o`0000;o00LP00?o0000o`078?l000000_l000001Ol01R3o0000o`00
0?l01R3o000000;o00HO0_l000001?l01Qoo0000o`067ol01Ql3o`000003o`067ol0003o00HO00?o
00008Oooool000Gooooo00Co0000oooooooooooo00001oooool5o`0000?ooooo00?o0000oooooooo
ool07_ooool01?l0003o00HOo`000?l00002o`067`Go000000?o00HOo`000?l000000_l01R001?l0
003o00HPo`000?l00002o`068004o`000?l01b3o0000o`0000;o00LQ00Co0000o`078Ol0003o0000
0_l01b400ol0003o00LQo`000002o`000003o`088Ol0003o00PR00?o000000Co00PRo`000?l022;o
00PR0_l000000ol02B?o0000o`000005o`0000;o00/U00?o0000o`0;9Ol000000_l000001?l03BOo
0000o`0>:?l00002o`0?:@Oo000000So01Tao`000?l08COo0000o`0d@_l0003o02dno`0000;o03]6
00?o0000o`13BOl000000ol0>dH3o`0000;o03A200Co0000o`1DC?l0003o00000_l0>dH3o`000003
o`0P=_l0003o01dd00;o000000?o01D^o`000?l000000_l04B/2o`0000;o00hX0_l000001ol032Ko
0000o`000?l0003o00/Uo`000?l02bD00ol000001ol02RCo0000o`000?l0003o00TSo`000?l02B<0
0ol000000ol022;o0000o`000002o`088P03o`000?l0227o000000;o000000?o00LQo`000?l01b40
0ol000000ol01b7o0000o`078@03o`000003o`078Ol0003o000000?o000000Oo00LPo`000?l0003o
0000o`068?l0003o00HP00?o000000?o00HOo`000?l01Ql00ol000000ol01Qoo0000o`000003o`00
0004o`067ol0003o0000o`00023ooooo0005ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00001?ooool2o`00023ooooo00?o0000o`067ol000000_l000001?l01Qoo0000o`06
7ol01Ql2o`000004o`068?l0003o00HPo`0680;o000000Co00HPo`000?l01R3o00HP0_l00002o`07
8004o`000?l01b7o0000o`0000;o00LQ00Co0000o`078Ol0003o00000_l022401?l0003o00PQo`00
0?l00002o`088P03o`000?l022;o000000;o000000?o00PRo`000?l000000ol000000ol02B?o0000
o`0:9005o`0000;o00`V00?o0000o`0=9ol000001?l000001?l042[o0000o`0B;?l00002o`0E;PCo
000000So024go`000?l0=4;o0000o`0]?_l0003o03]6o`0000;o04=900Co0000o`0kA_l0>dKo0000
0_l0E4`2o`0000;o05A<0_l00002o`0kAP;o000000Go03]6o`000?l07CCo0000o`0I<@02o`000005
o`0C;Ol0003o0000o`000?l042X00ol000001Ol03BOo0000o`000?l032Ko000000;o00/U0_l00002
o`0:90;o000000Co00TTo`000?l02B?o00TS0_l000001_l02B?o0000o`000?l0003o00PRo`0000;o
00PR0_l000001?l01b7o0000o`078Ol01b42o`000003o`078Ol0003o000000?o000000Ko00LQo`00
0?l0003o0000o`078?l00002o`0780;o000000Co00LPo`000?l01R3o00HP0_l000000ol01R3o0000
o`000003o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql2o`000003o`067ol0003o0000
023ooooo0005ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`0Pooooo`05o`000?l01Qoo00HOo`000?l01Ql00ol000000ol01Qoo0000o`068003
o`000003o`068?l0003o00HP00?o000000Co00LPo`000?l01b3o00LP0_l000001?l01b7o0000o`07
8Ol01b42o`000004o`078Ol0003o00PQo`088@;o00000_l022801Ol0003o00PRo`000?l0003o00PR
00Go00000_l02B<00ol0003o00TSo`000002o`000003o`0:9?l0003o00/U00Go000000Co00dWo`00
0?l03RSo00hX1ol000000ol05c3o0000o`0M=003o`000006o`0d@_l0003o0000o`000?l0>dKo0000
0_l0@dT01?l0003o03]6o`000?l00002o`1DC0;o00000_l0E4`01ol0003o03]6o`0kA_l0003o0499
o`000?l0>dH00_l000000ol06C7o0000o`0G<002o`0000;o018/0_l00002o`0?:@;o000000?o00dW
o`000?l032H00ol000001ol02bGo0000o`000?l0003o00XTo`000?l02B@00ol000000ol02B?o0000
o`000002o`088P03o`000?l022;o000000;o000000?o00PQo`000?l000000ol000001Ol01b7o0000
o`000?l01b3o000000;o00LP0_l00002o`078003o`000?l01b3o000000;o000000?o00HPo`000?l0
00000ol000001Ol01R3o0000o`000?l01Qoo000000;o00HO0_l000001?l01Qoo0000o`067ol01Ql3
o`000003o`067ol0003o00HO00?o00002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000?ooooo0ol00003ooooo`001Oooool01?l0003oooooooooool00009ooooo`;o00001?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?l01Qoo000000;o000000?o00HOo`000?l000000ol00000
0ol01R3o0000o`000003o`000003o`068?l0003o000000?o000000?o00LPo`000?l000000ol00000
0ol01b7o0000o`000003o`000003o`078Ol0003o000000Oo000000?o00PRo`000?l022801Ol00002
o`098`Co00000_l02bD00ol0003o00`Vo`000004o`000004o`0?:Ol0003o014[o`0000;o01<]1_l0
00001?l0;Cko0000o`000?l0E4`3o`0000;o04=90_l000001?l0Icco0000o`1DC?l0E4`2o`0000;o
05A<00?o0000o`0kA_l0>dH00_l000000ol0>dKo0000o`0]?P02o`00000=o`0G<?l0003o01D^o`00
0?l04Rco0000o`0A:ol0003o00lYo`000?l03RSo0000o`0=9`02o`0000;o00/U0_l000000ol02RCo
0000o`000003o`000006o`098ol0003o0000o`000?l022;o00000_l02282o`000007o`088_l0003o
0000o`000?l01b7o0000o`078@03o`000003o`078Ol0003o00LP00?o000000?o00LPo`000?l00000
0ol000001ol01R3o0000o`000?l0003o00HPo`000?l01R000ol000000ol01R3o0000o`067`03o`00
0003o`067ol0003o00HO00?o000000?o00HOo`000?l000000ol000000ol01Qoo0000o`000007oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`7o0000
0Oooool1ooooo`001_ooool2o`0000_ooooo00?o0000ooooooooool00_ooool2o`0002?ooooo00?o
0000o`067ol01Ql00_l000001?l01Qoo0000o`068?l01R02o`000004o`068?l0003o00HPo`0680;o
00000_l01R001?l0003o00HPo`000?l00002o`078004o`000?l01b7o0000o`0000;o00LQ00Co0000
o`078Ol0003o00000_l02244o`0000;o00PR00Co0000o`088_l0003o00000_l022800ol0003o00TS
o`000002o`000003o`098ol0003o00XT00Go000000Co00`Vo`000?l03BOo00dW1ol000001_l052ko
0000o`0H<?l0633o0000o`0P=P?o000000?o05A<o`000?l0Ic`01?l00002o`1W?004o`000?l0E4co
05A<o`0000?o05A<0_l000001?l0>dKo0000o`000?l0>dH2o`000005o`0J<_l0003o0000o`000?l0
5Bh00_l00002o`0A:`;o00000_l03RP2o`000005o`0<9_l0003o0000o`000?l02bD00_l000001?l0
2B?o0000o`098ol02B<2o`0000;o00PR1Ol000001Ol022;o0000o`000?l022;o000000;o00LQ0_l0
00000ol01b7o0000o`000003o`000006o`078?l0003o0000o`000?l01b3o00000_l01R02o`000004
o`068?l0003o00HPo`0680;o000000Co00HPo`000?l01R3o00HP0_l000000ol01Qoo0000o`000003
o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql2o`000003o`067ol0003o000000Kooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`7o00000Oooool1oooo
o`006?ooool00ol0003oooooooooo`0Sooooo`;o000000?o00HOo`000?l01Ql00ol000000ol01Qoo
0000o`068003o`000003o`068?l0003o000000?o000000?o00HPo`000?l000000ol000000ol01b3o
0000o`000003o`000003o`078Ol0003o000000?o00000_l022801?l0003o00PRo`000?l00002o`08
8P04o`000?l022;o0000o`0000;o00TS00Co0000o`098ol0003o00000_l02R@00ol0003o00/Uo`00
0004o`000003o`0>:?l0003o00lY00oo00000_l0Ic`00ol0003o06lao`000002o`1W?004o`000?l0
E4co05A<o`0000;o05A<00Go0000o`1W??l0003o0000o`12B@05o`0000;o01L`0_l000001Ol04Rco
0000o`000?l0003o00lY00?o000000Co00dWo`000?l0003o00/U0ol000000ol02RCo0000o`098`03
o`000007o`098ol0003o0000o`000?l022;o0000o`088P03o`000003o`088_l0003o00PR00?o0000
00Go00LQo`000?l0003o00LQo`000002o`078@;o00000_l01b000ol0003o00LPo`000002o`000003
o`068?l0003o00HP00?o000000?o00HPo`000?l000000ol000001Ol01R3o0000o`000?l01Qoo0000
00;o00HO0_l000001?l01Qoo0000o`067ol01Ql3o`000003o`067ol0003o00HO00?o00001Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo0Ol00001ooooo`7ooooo
000Gooooo`03o`000?oooooooooo02Gooooo00?o0000o`067ol000000_l000000ol01Qoo0000o`00
0003o`000003o`068?l0003o000000;o00HP00Co0000o`068?l0003o00000_l01b001?l0003o00LP
o`000?l00002o`078003o`000?l01b7o000000;o000000?o00LQo`000?l022401Ol000000ol022;o
0000o`000003o`000003o`098ol0003o000000?o000000?o00TTo`000?l000000ol000001?l02bGo
0000o`0<9_l032H4o`0000;o00lY00?o0000o`0A:ol000000_l052d8o`0000;o06Ll00?o0000o`1_
<Ol000000_l0Ic`01?l0003o05A<o`1DC?l00002o`1DC005o`000?l0Icco06Llo`000?l0@TT00ol0
00001Ol06C7o0000o`000?l0003o01@]00;o00000_l042X2o`000005o`0=:?l0003o0000o`000?l0
32H00_l00002o`0;9@04o`000?l02RCo0000o`0000;o00TS0_l000001?l022;o0000o`088_l02282
o`000003o`088_l0003o000000?o000000Oo00PQo`000?l0003o0000o`078Ol0003o00LQ00?o0000
00Co00LQo`000?l01b3o00LP0_l000000ol01b3o0000o`000003o`000007o`068?l0003o0000o`00
0?l01R3o0000o`068003o`000003o`068?l0003o00HO00?o000000?o00HOo`000?l01Ql00ol00000
0ol01Qoo0000o`000003o`000003o`067ol0003o000000Gooooo00Co0000oooooooooooo00002?oo
ool01Ol0003oooooooooool0003ooooo00Co00000oooool001Oooooo0_l0000Wooooo`;o000000?o
00HPo`000?l000000_l01R001?l0003o00HPo`000?l00002o`068004o`000?l01R3o0000o`0000;o
00LP00Co0000o`078?l0003o00000_l01b04o`0000;o00LQ00Co0000o`078Ol0003o00000_l02280
1?l0003o00PRo`000?l00002o`088P04o`000?l022;o0000o`0000;o00TS00Co0000o`098ol0003o
00000_l02B@00ol0003o00XTo`000004o`000003o`0=9ol0003o00hX00So000000?o01@^o`000?l0
63001Ol00002o`1W?003o`000?l0Kc7o000000?o06Ll0_l000001?l0MRKo0000o`1DC?l00002o`1W
?0Ko00000_l05Bh2o`000005o`0A:ol0003o0000o`000?l03RP00_l000001_l032Ko0000o`000?l0
003o00/Uo`0000;o00/U0_l000001ol02RCo0000o`000?l0003o00TSo`000?l022800ol000001Ol0
22;o0000o`000?l022;o000000;o00PR0_l00002o`088@04o`000?l01b7o0000o`0000;o00LQ1Ol0
00001?l01b3o0000o`000?l01b02o`000005o`068?l0003o0000o`068?l000000_l01R02o`000004
o`068?l0003o00HPo`0680;o000000?o00HPo`000?l000000ol000001_l01Qoo0000o`000?l0003o
00HOo`0000;o00HO0_l000000ol01Qoo0000o`000004ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00006ooooo`005oooool00ol0003oooooooooo`0Xooooo`03
o`000?l01R3o000000;o00HP0_l000001?l01R3o0000o`068?l01R02o`000004o`068?l0003o00LP
o`0780;o000000?o00LPo`000?l000000ol000000ol01b7o0000o`000003o`000003o`078Ol0003o
000000?o000000Co00PRo`000?l022;o00PR0_l000001?l022?o0000o`098ol02B<2o`000004o`09
8ol0003o00TTo`0990;o000000Co00XTo`000?l032Ko00`V1Ol000000ol03RSo0000o`0?:@0<o`00
00;o06Ll00?o0000o`1_<Ol000000ol0Ic`2o`000004o`1f9_l0003o05A<o`0000;o06Ll1?l00000
1Ol05c3o0000o`000?l0003o018/00;o000000Go00lYo`000?l0003o0000o`0=9`02o`0000;o00`V
1Ol000001Ol02RCo0000o`000?l02BCo000000;o00TS0_l000001ol022;o0000o`000?l0003o00PR
o`000?l022800ol000001?l0227o0000o`088Ol02242o`000007o`078Ol0003o0000o`000?l01b7o
0000o`078@03o`000003o`078?l0003o00LP00?o000000?o00HPo`000?l000000ol000000ol01R3o
0000o`000003o`000005o`068?l0003o0000o`067ol000000_l01Ql2o`000004o`067ol0003o00HO
o`067`?o000000?o00HOo`000?l000000_l00005ooooo`;o00002_ooool2o`0000;ooooo1Ol00002
ooooo`005oooool00ol0003oooooooooo`0Yooooo`Co000000?o00HPo`000?l000000ol000000ol0
1R3o0000o`000003o`000007o`078?l0003o0000o`000?l01b3o0000o`078002o`0000;o00LQ00Co
0000o`078Ol0003o00000_l01b400ol0003o00PRo`000004o`000003o`088_l0003o000000?o0000
00?o00TSo`000?l000000ol000000ol02BCo0000o`000003o`000004o`0;9Ol0003o00`Vo`0<9PCo
00000_l03bT00ol0003o014[o`000006o`000006o`1DC?l0003o06Llo`000?l0Kc7o00000ol0Ic`2
o`000007o`1f9_l0003o05A<o`000?l0Icco0000o`1_<@04o`000005o`0D;Ol0003o0000o`000?l0
42X00_l00002o`0>:0;o000000Oo00`Vo`000?l0003o0000o`0;9Ol0003o00/U00?o000000?o00XT
o`000?l000000ol000000ol02B?o0000o`000002o`088P04o`000?l022;o0000o`0000;o00PR1Ol0
00001Ol01b7o0000o`000?l01b7o000000;o00LQ0_l000001?l01b7o0000o`078?l01b02o`000007
o`078?l0003o0000o`000?l01R3o0000o`068003o`000003o`067ol0003o00HO00?o000000?o00HO
o`000?l01Ql00ol000000ol01Qoo0000o`000003o`000007o`067ol0003o0000o`000?l01Qoo0000
o`067`02o`0001_ooooo000Gooooo`;o0000:oooool01?l0003o00HPo`000?l00002o`068004o`00
0?l01R3o0000o`0000;o00HP1?l00002o`068004o`000?l01b3o0000o`0000;o00LP00Co0000o`07
8Ol0003o00000_l01b401?l0003o00LQo`000?l00002o`088@04o`000?l022;o0000o`0000;o00PR
00Co0000o`088ol0003o00000_l02B<01?l0003o00TSo`000?l00002o`099003o`000?l02RCo0000
00Co000000?o00`Vo`000?l03BL01Ol000001?l042[o0000o`0B;?l04R`5o`000004o`1W??l0003o
06lao`0000?o06Ll0_l000000ol0MRKo0000o`000002o`1W?003o`000?l0Kc7o000000Co00000_l0
4B/2o`000005o`0>:?l0003o0000o`000?l03BL00_l000001?l02bKo0000o`0;9Ol02bD2o`000006
o`0:9?l0003o0000o`000?l02BCo00000_l02B<2o`000003o`098ol0003o000000?o000000Oo00PR
o`000?l0003o0000o`078Ol0003o00LQ00?o000000?o00LQo`000?l000000ol000000ol01b7o0000
o`000003o`000004o`078?l0003o0000o`0680;o000000Co00HPo`000?l0003o00HO1Ol000000ol0
1Qoo0000o`000003o`000007o`067ol0003o0000o`000?l01Qoo0000o`067`03o`000003o`067ol0
003o00HO00?o000000?o00HOo`000?l000006_ooool000Cooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo02_ooooo00?o0000o`068?l000000_l01R02
o`000003o`068?l0003o000000?o000000?o00HPo`000?l000000ol000000ol01b3o0000o`000003
o`000003o`078?l0003o000000?o000000?o00LQo`000?l000000ol000000ol022;o0000o`000003
o`000003o`088_l0003o000000?o000000Co00TSo`000?l02BCo00TT0_l000001?l02RCo0000o`0;
9Ol02bD4o`0000;o00dW00?o0000o`0>:?l000001?l000000ol04B_o0000o`000002o`000004o`1W
??l0003o06lao`0000?o06Ll00Go0000o`1f9_l0MRKo07HVo`000002o`1W?004o`000?l0Kc7o0000
o`0A:`Go000000Co00lYo`000?l0003o00dW0ol000000ol032Ko0000o`0;9P03o`000003o`0:9?l0
003o000000;o00TS00?o0000o`099?l000000_l000001Ol02B?o0000o`000?l022;o000000;o00PR
0_l000000ol0227o0000o`000003o`000007o`078Ol0003o0000o`000?l01b7o0000o`078@03o`00
0003o`078?l0003o00LP00?o000000?o00LPo`000?l000000ol000001Ol01Qoo0000o`000?l01Qoo
000000;o00HO0_l000001?l01Qoo0000o`067ol01Ql2o`000004o`067ol0003o00HOo`067`;o0000
00?o00HOo`000?l000000ol000000ol01Qoo0000o`000003o`0001[ooooo0003ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02go
oooo1?l000001ol01R3o0000o`000?l0003o00HPo`000?l01R000_l00002o`078003o`000?l01b3o
000000;o000000?o00LPo`000?l01b000_l00002o`078@04o`000?l01b7o0000o`0000;o00LQ00Co
0000o`088_l0003o00000_l022801?l0003o00PRo`000?l00002o`088`03o`000?l02B?o000000Co
000000?o00TTo`000?l000000ol000000ol02bGo0000o`0<9P05o`000003o`0>:?l0003o000000?o
000000Ko010Zo`000?l0003o0000o`1W??l00002o`1_<@04o`000?l0Icco06Llo`0000?o07HV00?o
0000o`1W??l0Ic`01?l000000ol03bWo0000o`0?:@03o`000003o`0=9ol0003o000000;o00`V1?l0
0002o`0;9@;o000000?o00TTo`000?l000000ol000001ol02B?o0000o`000?l0003o00PRo`000?l0
22800ol000001Ol022;o0000o`000?l01b7o000000;o00LQ0_l000001?l01b7o0000o`078Ol01b42
o`000003o`078?l0003o000000?o000000Oo00LPo`000?l0003o0000o`068?l0003o00HP00?o0000
00?o00HOo`000?l01Ql00ol000000ol01Qoo0000o`000003o`000003o`067ol0003o000000?o0000
00Go00HOo`000?l0003o00HOo`000002o`067`;o000000Co00HOo`000?l01Qoo00HO0_l0000Ioooo
o`000oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`0^ooooo`Co00000_l01R001?l0003o00HPo`000?l00002o`078004o`000?l0
1b3o0000o`0000;o00LP1?l000000ol01b3o0000o`000003o`000003o`078Ol0003o000000?o0000
00Co00PRo`000?l022;o00PR0_l000001?l022;o0000o`088ol022<2o`000004o`098ol0003o00TS
o`098`;o000000Co00TSo`000?l02RCo00XT1?l00002o`0<9PCo00000_l03BL7o`0000;o06Ll00?o
0000o`1_<Ol000000_l0Ic`01Ol0003o07HVo`1f9_l0MRKo000000;o06Ll1ol00002o`0>:0;o0000
00Oo00`Vo`000?l0003o0000o`0;9Ol0003o00/U00?o000000Go00XTo`000?l0003o00TSo`000002
o`098`;o000000?o00PRo`000?l000000ol000001ol022;o0000o`000?l0003o00PQo`000?l01b40
0ol000000ol01b7o0000o`000003o`000005o`078?l0003o0000o`078?l000000_l01b02o`000004
o`068?l0003o00HPo`0680;o000000Co00HPo`000?l0003o00HO0_l000001ol01Qoo0000o`000?l0
003o00HOo`000?l01Ql00ol000000ol01Qoo0000o`067`03o`000003o`067ol0003o00HO00?o0000
00?o00HOo`000?l01Ql00ol000000ol01Qoo0000o`00000Hooooo`000oooool01?l0003ooooooooo
ool00007ooooo`Co00001?ooool2o`0002kooooo0ol000000ol01R3o0000o`000003o`000003o`07
8?l0003o000000?o000000Oo00LPo`000?l0003o0000o`078?l0003o00LP00;o00000_l01b001?l0
003o00LQo`000?l00002o`078@03o`000?l01b7o000000Co000000?o00PRo`000?l000000ol00000
0ol022?o0000o`000003o`000003o`098ol0003o000000?o000000?o00XTo`000?l000000ol00000
0ol02bGo0000o`0<9P03o`000003o`0<9_l0003o00dX00Co00000_l0Ic`01?l0003o06lao`000?l0
Ic`2o`0000?o07HV00Co0000o`1W??l0003o06la0_l000000ol03RSo0000o`000003o`000004o`0<
9ol0003o0000o`0;9@Go000000Go00XTo`000?l0003o0000o`098`05o`000003o`088_l0003o0000
00;o00PR00Co0000o`088_l0003o00000_l02244o`000007o`078Ol0003o0000o`000?l01b7o0000
o`078003o`000003o`078?l0003o00LP00?o000000?o00HPo`000?l000000ol000000ol01R3o0000
o`000003o`000005o`067ol0003o0000o`067ol000000_l01Ql2o`000004o`067ol0003o00HOo`06
7`;o000000?o00HOo`000?l000000ol000000ol01Qoo0000o`000003o`000005o`067ol0003o0000
o`000?l01Ql00_l0000Gooooo`000oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0:_ooool3o`0000?ooooo00Go0000o`068?l01R3o0000o`06
8002o`0000;o00LP00?o0000o`078?l000000_l000000ol01b3o0000o`078002o`0000;o00LP00Co
0000o`078?l0003o00000_l01b401?l0003o00LQo`000?l00002o`078@06o`000?l022;o0000o`00
0?l022;o00000_l02282o`000004o`088_l0003o00TSo`098`;o000000Co00TSo`000?l02B?o00TS
0_l000001?l02RCo0000o`0;9Ol02bD4o`0000;o00`V1?l00002o`0=9`;o00000_l0Ic`01?l0003o
06lao`000?l0Ic`2o`0000;o07HV0_l000000ol0Icco0000o`1_<@03o`000003o`0<9ol0003o00dW
00?o000000?o00/Uo`000?l000000_l02R@01?l0003o00XTo`000?l00002o`098`;o000000Co00TS
o`000?l02B?o00TS0_l000000ol022;o0000o`000003o`000007o`088Ol0003o0000o`000?l01b7o
0000o`078@02o`0000;o00LQ00Co0000o`078Ol0003o00000_l01b04o`000007o`068?l0003o0000
o`000?l01R3o0000o`068003o`000003o`068?l0003o00HP00?o000000?o00HOo`000?l01Ql00ol0
00000ol01Qoo0000o`000003o`000005o`067ol0003o0000o`067ol000000_l01Ql2o`000004o`06
7ol0003o00HOo`067`;o000000Co00HOo`000?l01Qoo00HO0_l0000Gooooo`000oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09oooool3o`00
00Oooooo00Co0000o`068?l0003o00000_l01R001?l0003o00LPo`000?l00002o`0680Co000000?o
00LPo`000?l000000ol000000ol01b3o0000o`000003o`000003o`078Ol0003o000000?o000000?o
00PQo`000?l000000ol000000ol022;o0000o`000003o`000003o`088_l0003o000000?o000000?o
00TSo`000?l000000ol000000ol02RCo0000o`0;9@03o`000003o`0;9Ol0003o00`V00Ko000000?o
06Llo`000?l0Kc400_l000001?lXV@3o0000o`1f9_l0MRH2o`000005o`1W??l0003o06lao`000?l0
32H01?l00002o`0<9P;o000000?o00XTo`000?l000000ol000001ol02B?o0000o`000?l0003o00TS
o`000?l02B<00ol000001Ol022;o0000o`000?l022;o000000;o00PR0_l000001?l01b7o0000o`07
8Ol01b42o`000003o`078Ol0003o000000?o000000Oo00LQo`000?l0003o0000o`078Ol0003o00LP
00;o00000_l01R001?l0003o00HPo`000?l00002o`0680Co000000?o00HPo`000?l000000ol00000
1ol01Qoo0000o`000?l0003o00HOo`000?l01Ql00ol000000ol01Qoo0000o`067`03o`000003o`06
7ol0003o000000?o000000?o00HOo`000?l000000ol000000ol01Qoo0000o`00000Fooooo`001?oo
ool2o`0000[ooooo0_l00004ooooo`;o00009Oooool3o`0000_ooooo00?o0000o`068?l000001?l0
00001ol01R3o0000o`000?l0003o00LPo`000?l01b000ol000000ol01b3o0000o`078003o`000003
o`078?l0003o00LQ00;o00000_l01b401?l0003o00LQo`000?l00002o`088P04o`000?l022;o0000
o`0000;o00PR00Ko0000o`088_l0003o0000o`088_l00002o`098`;o000000Co00TSo`000?l02BCo
00TT1?l00002o`0;9@Co00000_l02bD3o`000004obRI0?l0003o0000o`1_<@;o000000Ko:9T0o`00
0?l0MRKo07HVo`000?lXV@02o`000004o`1_<Ol0003o0000o`0;9@Go000000Go00XTo`000?l0003o
00TTo`000002o`0990;o000000?o00TSo`000?l000000ol000001ol022;o0000o`000?l0003o00PR
o`000?l022800ol000000ol022;o0000o`000003o`000005o`078Ol0003o0000o`078Ol000000_l0
1b42o`000004o`078Ol0003o00LQo`078@;o000000?o00LPo`000?l000000ol000001ol01R3o0000
o`000?l0003o00HPo`000?l01R000_l000001?l01R3o0000o`000?l01R02o`000004o`067ol0003o
00HOo`067`;o000000?o00HOo`000?l000000ol000001ol01Qoo0000o`000?l0003o00HOo`000?l0
1Ql00ol000000ol01Qoo0000o`067`03o`000003o`067ol0003ooooo01Gooooo000Eooooo`03o`00
0?oooooooooo02;ooooo0ol0000?ooooo`;o000000?o00HPo`000?l01R000ol000000ol01b3o0000
o`078002o`0000;o00LP1?l00002o`0780Co000000?o00LQo`000?l000000ol000000ol01b7o0000
o`000003o`000003o`088_l0003o000000?o000000?o00PRo`000?l000000ol000000ol02B?o0000
o`000003o`000003o`098ol0003o000000?o000000?o00XTo`000?l02bD00ol000000ol02bGo0000
o`1f9P05o`0000;o:9T000Go0000o`1f9_l0MRKo0000obRI0002o`000006o`1_<Ol0003o0000o`00
0?l02RCo00000_l02R@2o`000003o`099?l0003o000000?o000000?o00TSo`000?l000000_l02B<0
1Ol0003o00PRo`000?l0003o00PR00Go000000Oo00PRo`000?l0003o0000o`088_l0003o00LQ00?o
000000?o00LQo`000?l01b400ol000000ol01b7o0000o`000003o`000005o`078Ol0003o0000o`07
8?l000000_l01R02o`000004o`068?l0003o00HPo`0680;o000000?o00HPo`000?l000000ol00000
0ol01R3o0000o`000003o`000005o`067ol0003o0000o`067ol000000_l01Ql2o`000004o`067ol0
003o00HOo`067`;o000000?o00HOo`000?l000000ol000000ol01Qoo0000o`000003o`0001Gooooo
000Eooooo`03o`000?oooooooooo01oooooo0ol0000Dooooo`?o00000_l01R04o`000007o`078?l0
003o0000o`000?l01b3o0000o`078003o`000003o`078?l0003o00LP00?o000000?o00LPo`000?l0
1b400_l00002o`078@04o`000?l022;o0000o`0000;o00PR00Ko0000o`088_l0003o0000o`088_l0
0002o`088P;o000000Co00PRo`000?l02B?o00TS0_l000001?l02B?o0000o`0:9?l02R@4o`000005
o`0:9?l0003o0000o`000?l02R@00_l000001?lXV@3o0000oeVX0?l00003obRI00;o00000_lXV@00
1Ol0003o06lao`000?l0003o00XT00Go000000Go00TTo`000?l0003o00TSo`000002o`098`;o0000
00?o00TSo`000?l000000ol000000ol022;o0000o`000002o`088P04o`000?l022;o0000o`0000;o
00PR00Go0000o`088_l0003o0000o`078@05o`000007o`078Ol0003o0000o`000?l01b7o0000o`07
8@03o`000003o`078?l0003o00LP00?o000000?o00HPo`000?l000000ol000001_l01R3o0000o`00
0?l01Qoo0000o`067`?o000000?o00HOo`000?l01Ql00ol000000ol01Qoo0000o`067`03o`000003
o`067ol0003o000000?o000000Go00HOo`000?l0003o00HOo`000002o`067`;o00000oooool00ol0
003oooooooooo`0Dooooo`005Oooool2o`0001gooooo0ol0000Gooooo`03o`000?l01R3o000000;o
000000?o00HPo`000?l01b000ol000000ol01b3o0000o`078003o`000003o`078?l0003o000000;o
00000_l01b04o`000003o`078Ol0003o000000?o000000?o00PQo`000?l000000ol000000ol022;o
0000o`000003o`000003o`088_l0003o000000?o000000?o00TSo`000?l02B<00ol000000ol02BCo
0000o`000002o`0000;o00TS1?l000001?lXV@3o0000oeVX0?l00003obRI00;o00000_lXV@05o`00
0003o`098ol0003o00TT00?o000000?o00TSo`000?l000000ol000001Ol02B?o0000o`000?l022?o
000000;o00PR0_l000001?l022;o0000o`088_l02282o`000003o`088_l0003o000000?o000000?o
00PQo`000?l000000_l01b401Ol0003o00LQo`000?l0003o00LQ00Go000000?o00LPo`000?l00000
0ol000001ol01b3o0000o`000?l0003o00HPo`000?l01R000ol000000ol01Qoo0000o`067`02o`00
0003o`067ol0003o000000?o000000?o00HOo`000?l000000ol000001ol01Qoo0000o`000?l0003o
00HOo`000?l01Ql00ol000000ol01Qoo0000o`067`03o`0000Gooooo00?o0000ooooooooool05?oo
ool001Gooooo00?o0000ooooooooool06Oooool3o`0001_ooooo0_l000000ol01R3o0000o`000002
o`0000;o00LP1?l00002o`0780;o000000?o00LPo`000?l01b000ol000000ol01b3o0000o`078@03
o`000003o`078Ol0003o00LQ00;o00000_l022401?l0003o00PRo`000?l00002o`088P06o`000?l0
22;o0000o`000?l022;o00000_l02284o`0000;o00TS0_l000000ol02B?o0000o`098`03o`000008
o`098ol0003o0000o`000?lXV@3o0000oeVX0?l00003obRI00;o00000_lXV@001?l0003oFJP0o`00
0?l02B<4o`0000;o00TS0_l000000ol02B?o0000o`098`03o`000003o`088ol0003o000000?o0000
00?o00PRo`000?l000000ol000001Ol022;o0000o`000?l0227o000000;o00PQ0_l000001?l01b7o
0000o`078Ol01b42o`000003o`078Ol0003o000000;o00LP00Ko0000o`078?l0003o0000o`078?l0
0002o`0780;o000000Co00HPo`000?l01R3o00HP0_l000000ol01R3o0000o`000003o`000004o`06
7ol0003o0000o`067`;o000000Go00HOo`000?l0003o00HOo`000002o`067`;o000000Co00HOo`00
0?l01Qoo00HO0_l000000ol01Qoo0000o`000003o`0000Wooooo00?o0000ooooooooool04oooool0
01Gooooo00?o0000ooooooooool05_ooool3o`00023ooooo00Co0000o`068?l0003o00HP0ol00000
0ol01R3o0000o`068003o`000003o`078?l0003o00LP00?o000000?o00LPo`000?l000000_l00002
o`078@Co000000?o00LQo`000?l000000ol000000ol022;o0000o`000003o`000003o`088_l0003o
000000?o000000?o00PRo`000?l000000ol000000ol02B?o0000o`000002o`0000;o00TS1Ol00000
1?lXV@3o0000oeVX0?l00003obRI00;o00000_lXV@001Ol0003oFJP0o`000?l0003o00TS00Go0000
00?o00TSo`000?l000000_l00002o`088`;o000000Co00PRo`000?l022;o00PR0_l000000ol022;o
0000o`088P03o`000003o`088Ol0003o000000?o000000?o00LQo`000?l000000ol000001Ol01b7o
0000o`000?l01b7o000000;o00LP0_l000000ol01b3o0000o`000003o`000003o`068?l0003o0000
00?o000000Go00HPo`000?l0003o00HOo`000002o`067`;o000000?o00HOo`000?l000000ol00000
0ol01Qoo0000o`000003o`000003o`067ol0003o000000?o000000?o00HOo`000?l000003_ooool0
0ol0003oooooooooo`0Cooooo`005Oooool2o`0001Gooooo0_l0000Sooooo`03o`000?l01R3o0000
00;o000000?o00HPo`000?l000000ol000000ol01b3o0000o`000002o`0000;o00LP0_l000000ol0
1b3o0000o`078003o`000003o`078?l0003o00LQ00;o00000_l01b401?l0003o00LQo`000?l00002
o`088P04o`000?l022;o0000o`0000;o00PQ00Ko0000o`088_l0003o0000o`088_l00002o`098`;o
000000?o00PRo`000?l022800ol000000ol022;o0000o`098`02o`000005obRI0?l0003oFJP0oeVX
0?l000000_lXV@02o`0000;o:9T000?o0000oeVX0?l000000_l000000ol022;o0000o`098`03o`00
0003o`088ol0003o00PS00?o000000?o00PRo`000?l022800ol000000ol022;o0000o`000002o`00
00;o00PR0_l000000ol01b7o0000o`078@03o`000003o`078Ol0003o000000?o000000?o00LQo`00
0?l000000ol000001_l01b3o0000o`000?l01R3o0000o`0680?o000000?o00HOo`000?l01R000ol0
00000ol01Qoo0000o`000003o`000006o`067ol0003o0000o`067ol0003o00HO0ol000000ol01Qoo
0000o`067`03o`000003o`067ol0003o00HO00?o00004?ooool00ol0003oooooooooo`0Cooooo`00
5?ooool2o`0001?ooooo0ol0000Vooooo`;o000000Go00HPo`000?l0003o00HPo`000002o`0780;o
000000?o00LPo`000?l01b000ol000000ol01R3o0000o`078003o`000003o`078?l0003o000000;o
00000_l01b401_l0003o00LQo`000?l0003o00PQo`0000;o00PR0_l000000ol01b7o0000o`000003
o`000003o`088_l0003o000000?o000000?o00PRo`000?l000000_l00002o`088PCo000000Co00TS
o`000?lXV@3o00000_mIZ0001?l0003o:9T0obRI0?l00003obRI0006o`000?mIZ03o0000o`088_l0
003o00PR0_l00002o`088PCo00000_l02284o`000007o`088_l0003o0000o`000?l022;o0000o`08
8P03o`000003o`078Ol0003o000000;o00000_l01b42o`000003o`078?l0003o00LQ00?o000000?o
00LPo`000?l01b000ol000000ol01R3o0000o`000002o`000003o`067ol0003o000000?o000000Oo
00HOo`000?l0003o0000o`067ol0003o00HO00?o000000?o00HOo`000?l01Ql00_l000000ol01Qoo
0000o`000003o`000003o`067ol0003o000000?o00004oooool00ol0003oooooooooo`0Cooooo`00
0_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0
3oooool3o`0002_ooooo00?o0000o`068?l000001?l000000ol01b3o0000o`000003o`000003o`06
8?l0003o000000;o00000_l01b02o`000003o`078?l0003o00LP00Go000000?o00LQo`000?l00000
0ol000000ol01b7o0000o`000002o`078@06o`000?l0227o0000o`000?l022;o00000_l02282o`00
0003o`088_l0003o00PR00?o000000?o00PRo`000?l022801Ol00002oeVX0004o`000?lXV@3o:9T0
o`0000;o:9T000?o0000oeVX0?l000001?l000001ol022;o0000o`000?l0003o00PRo`000?l02280
0ol000000ol022;o0000o`088P02o`000003o`088_l0003o000000?o000000Oo00LQo`000?l0003o
0000o`078Ol0003o00LQ00?o000000?o00LPo`000?l000000_l000000ol01b3o0000o`000003o`00
0007o`078?l0003o0000o`000?l01R3o0000o`068002o`0000;o00HO00Go0000o`067ol0003o0000
o`067`05o`000003o`067ol0003o000000?o000000Co00HOo`000?l0003o00HO0_l000000ol01Qoo
0000o`00000Hooooo`03o`000?oooooooooo01?ooooo00001Ooooooo0000oooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00cooooo0ol0000_oooo
o`05o`000?l01R3o00HPo`000?l01R000_l000001?l01R3o0000o`068?l01R02o`000003o`068?l0
003o00LP00?o000000?o00LPo`000?l000000ol000000ol01b7o0000o`078@02o`0000;o00LQ1?l0
00000ol01b7o0000o`000003o`000003o`088Ol0003o000000?o000000?o00PRo`000?l000000_l0
0002o`088PCo00000_l02283o`0000;oFJP000Co0000obRI0?lXV@3o00000_lXV@001_l0003oFJP0
o`000?l022;o0000o`088P;o00000_l022801Ol0003o00PRo`000?l0003o00PR00Go000000?o00PR
o`000?l000000_l01b401Ol0003o00LQo`000?l0003o00LQ00Go000000Oo00LQo`000?l0003o0000
o`078?l0003o00LP00;o00000_l01R001Ol0003o00HPo`000?l0003o00HP00Go000000?o00HOo`00
0?l000000ol000001Ol01Qoo0000o`000?l01Qoo000000;o00HO0_l000001?l01Qoo0000o`067ol0
1Ql2o`000003o`067ol0003o000000?o00006_ooool00ol0003oooooooooo`0Cooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000000oooool2o`0000[ooooo
0ol0000booooo`03o`000?l01R3o00HP00;o000000?o00HPo`000?l000000ol000000ol01R3o0000
o`000003o`000005o`078?l0003o0000o`068?l000000_l01b04o`000007o`078Ol0003o0000o`00
0?l01b7o0000o`078@02o`0000;o00LQ00Ko0000o`078Ol0003o0000o`078Ol00002o`088@;o0000
00?o00PRo`000?l022800ol000000ol022;o0000o`088P06o`0000;oFJP000Co0000obRI0?lXV@3o
00000_lXV@000ol0003oFJP0o`000003o`000003o`088_l0003o000000?o000000?o00PRo`000?l0
00000_l02284o`000003o`078Ol0003o000000?o000000?o00LQo`000?l000000_l01b001_l0003o
00LQo`000?l0003o00LPo`0000;o00LP0_l000000ol01b3o0000o`000003o`000005o`068?l0003o
0000o`068?l000000_l01R02o`000004o`068?l0003o00HOo`067`;o000000?o00HOo`000?l00000
0ol000000ol01Qoo0000o`000003o`000003o`067ol0003o000000Cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Cooooo`0000Goooooo`000?ooooooooooo`000008ooooo`?o0000
1?ooool00ol0003oooooooooo`06ooooo`?o0000=_ooool2o`000003o`068?l0003o000000;o00HP
00Ko0000o`068?l0003o0000o`068?l00002o`0680;o000000?o00HPo`000?l000000ol000000ol0
1b3o0000o`078@02o`0000;o00LQ00Go0000o`078Ol0003o0000o`078@05o`000003o`078Ol0003o
000000?o000000?o00LQo`000?l000000ol000000ol022;o0000o`000002o`0000;o00PR1?l00002
oeVX0004o`000?lXV@3o:9T0o`0000;o:9T000Go0000oeVX0?l0003o0000o`088P02o`000003o`08
8_l0003o000000?o000000Oo00PRo`000?l0003o0000o`078Ol0003o00LQ00;o000000Co00LQo`00
0?l01b7o00LQ0_l000000ol01b7o0000o`000003o`000003o`078?l0003o000000?o000000Go00LP
o`000?l0003o00LPo`000002o`0680;o000000?o00HPo`000?l01R000ol000000ol01R3o0000o`00
0003o`000006o`067ol0003o0000o`067ol0003o00HO0ol000000ol01Qoo0000o`067`03o`0000Oo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Booooo`0000Goooooo`000?oooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03oooo
o`?o0000>oooool00ol0003o00HPo`000004o`000003o`068?l0003o000000?o000000?o00HPo`00
0?l000000_l01R000ol0003o00HPo`000003o`000003o`078Ol0003o000000?o000000Oo00LQo`00
0?l0003o0000o`078Ol0003o00LQ00;o00000_l01b401_l0003o00LQo`000?l0003o00LQo`0000;o
00PQ0_l000000ol0227o0000o`000003o`00000>o`088Ol0003o0000obRI0?l0003oFJP0o`000?lX
V@3o0000ol^d0?l0003o:9T0o`000?mIZ003o`000003o`088_l0003o000000;o00PQ00Go0000o`08
8_l0003o0000o`078@05o`000003o`078Ol0003o000000?o000000Go00LQo`000?l0003o00LPo`00
0002o`0780;o000000?o00LPo`000?l01b000ol000000ol01b3o0000o`000003o`000003o`068?l0
003o000000;o000000Oo00HPo`000?l0003o0000o`068?l0003o00HO00?o000000?o00HOo`000?l0
1Ql00_l000000ol01Qoo0000o`000003o`0000_ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Booooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooo`000?ooool3o`0003oooooo0_l000000ol01R3o0000o`068002
o`0000;o00HP00Ko0000o`068?l0003o0000o`068?l00002o`0680;o000000?o00LPo`000?l00000
0ol000000ol01b3o0000o`000002o`0000;o00LQ1?l000000ol01b7o0000o`000003o`000003o`07
8Ol0003o000000?o000000Go00PQo`000?l0003o00LQo`000002o`078@;o000000_o00LQo`000?lX
V@3o0000oeVX0?l0003o:9T0o`000?o;]03o0000obRI0003o`000004o`088_l0003o0000o`088@Go
000000?o00LQo`000?l000000_l01b401_l0003o00LQo`000?l0003o00LQo`0000;o00LQ0_l00000
0ol01b3o0000o`000003o`000003o`078?l0003o000000;o00000_l01R02o`000003o`078?l0003o
00HP00?o000000?o00HPo`000?l01R000_l00002o`067`Co000000?o00HOo`000?l000000ol00000
0ol01Qoo0000o`00000@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04_ooool0
00;ooooo0_l00009ooooo`?o00000oooool4o`0004Cooooo0ol000000ol01R3o0000o`000003o`00
0003o`068?l0003o000000?o000000Go00HPo`000?l0003o00HPo`000002o`0780;o000000?o00LP
o`000?l01b400ol000000ol01b7o0000o`078@02o`0000;o00LP00Ko0000o`078Ol0003o0000o`07
8Ol00002o`078@;o000000?o00LQo`000?l01b400ol000000ol01b7o0000o`000003o`000007oeVX
0?l0003o:9T0o`000?o;]03o0000obRI0004o`000005o`088Ol0003o0000o`078Ol000000_l01b42
o`000003o`078Ol0003o000000?o000000?o00LQo`000?l000000ol000001_l01b3o0000o`000?l0
1b3o0000o`0780?o000000?o00LPo`000?l01b000ol000000ol01R3o0000o`000002o`000003o`06
8?l0003o000000?o000000Oo00HPo`000?l0003o0000o`067ol0003o00HO00;o000000Co00HOo`00
0?l01Qoo00HO0_l0000Cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04_ooool0
01?ooooo0_l00016ooooo`03o`000?l01R3o000000;o000000?o00HPo`000?l01R000_l00002o`06
8005o`000?l01R3o0000o`000?l01R001Ol000000ol01b3o0000o`000002o`0000;o00LQ1?l00000
0ol01b3o0000o`000003o`000003o`078Ol0003o000000?o000000?o00LQo`000?l000000_l00002
o`078@;o000000?o00LQo`000?l000000_l00002oeVX00;o000000?obk@0o`000?lXV@000_l00000
1?l0227o0000o`000?l01b45o`000005o`078Ol0003o0000o`078Ol000000_l01b02o`000003o`07
8?l0003o00LP00?o000000?o00LPo`000?l000000_l00002o`0780Co000000Oo00LPo`000?l0003o
0000o`068?l0003o00HP00;o000000Co00HPo`000?l01R3o00HP0_l000000ol01R3o0000o`000003
o`000003o`067ol0003o000000?o00005_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01;ooooo000Eooooo`03o`000?oooooooooo04Cooooo0_l000000ol01R3o0000o`000002o`00
0003o`067ol0003o000000?o000000?o00HPo`000?l000000_l01R001ol0003o00HPo`000?l0003o
00LPo`000?l01b000ol000000ol01b7o0000o`078@02o`0000;o00LP1?l000001?l01b7o0000o`07
8Ol01b42o`000003o`078Ol0003o000000?o000000?o00LQo`000?l000001?l00002oeVX00;o0000
00?obk@0o`000?lXV@000ol000001Ol01b7o0000o`000?l01b7o000000;o00LQ0_l000000ol01b7o
0000o`000003o`000003o`078?l0003o000000;o00000_l01b02o`000003o`078?l0003o00LP00?o
000000?o00LPo`000?l01b000_l000000ol01b3o0000o`000003o`000003o`068?l0003o000000?o
000000Go00HPo`000?l0003o00HPo`000002o`0680;o00007?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01;ooooo000Fooooo`03o`000?oooooooooo04Gooooo00Co0000o`068?l0
003o00HO0ol000000ol01R3o0000o`068002o`000003o`068?l0003o000000?o000000?o00HPo`00
0?l000000ol000000ol01b3o0000o`000002o`000007o`078?l0003o0000o`000?l01b3o0000o`07
8005o`000005o`078Ol0003o0000o`078Ol000000_l01b42o`000003o`078?l0003o00LQ00?o0000
0_mIZ0000ol0003obk@0ol^d0002o`000005oeVX0?l0003o0000o`000?l01b401Ol000001Ol01b3o
0000o`000?l01b3o000000;o00LP0_l000000ol01b3o0000o`078003o`000003o`078?l0003o0000
00;o000000?o00LPo`000?l000000ol000001Ol01b3o0000o`000?l01b3o000000;o00HP0_l00000
1?l01R3o0000o`068?l01R02o`000003o`068?l0003o00HP00?o00007_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01;ooooo000Gooooo`03o`000?oooooooooo04Gooooo0ol00002
o`067`Co000000Oo00HPo`000?l0003o0000o`067ol0003o00HO00;o000000Co00HPo`000?l01b3o
00LP0_l000000ol01b3o0000o`078003o`000003o`068?l0003o000000;o000000?o00LPo`000?l0
00000ol000000ol01b7o0000o`000003o`000003o`078?l0003o000000Go00000_mIZ0002?l0003o
bk@0ol^d0?o;]03o0000oeVX0?l0003o00LQ0_l000000ol01b7o0000o`000003o`000003o`078?l0
003o000000?o000000?o00LPo`000?l000000_l000001ol01b3o0000o`000?l0003o00LPo`000?l0
1b000_l000001?l01b3o0000o`078?l01b02o`000003o`078?l0003o000000?o000000?o00HPo`00
0?l000000ol000000ol01R3o0000o`000002o`0002;ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Aooooo`006?ooool2o`0004Gooooo00?o0000o`067ol000000_l000000ol01Qoo
0000o`000002o`0000;o00HO1?l000000ol01Qoo0000o`000003o`000003o`078?l0003o000000;o
00000_l01R02o`000003o`068?l0003o00LP00?o000000?o00LPo`000?l01b400_l000001?l01b3o
0000o`078?l01b02o`000003o`078?l0003o000000Co000000?oFJP0o`000?l000000oo;]004o`00
0005o`078Ol0003o0000o`078?l000000_l01b02o`000003o`078?l0003o00LP00?o000000?o00LP
o`000?l01b000_l00002o`0780Co000000?o00LPo`000?l000000ol000001Ol01R3o0000o`000?l0
1R3o000000;o00HP0_l000000ol01R3o0000o`068003o`0002Oooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`13ooooo`;o000000Ko00HO
o`000?l0003o00HOo`000?l01Ql3o`000003o`067ol0003o00HO00;o00000_l01R001ol0003o00HP
o`000?l0003o00HPo`000?l01R000ol000000ol01R3o0000o`000002o`0000;o00LP1?l000000ol0
1b3o0000o`000003o`000006o`078?l0003o0000o`078?l0003o00LQ1?l000000ooQL`3o0000ol^d
0002ol^d00;o000000Co00LQo`000?l0003o00LP1Ol000000ol01b3o0000o`000002o`0000;o00HP
1?l000001ol01b3o0000o`000?l0003o00LPo`000?l01b000_l000001?l01b3o0000o`078?l01b02
o`000003o`068?l0003o000000?o000000?o00HPo`000?l000000_l0000Zooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04Oooool001_ooooo00?o0000ooooooooool0A?ooool00ol0
003o00HOo`000004o`000003o`067ol0003o000000;o000000?o00HOo`000?l000000ol000000ol0
1R3o0000o`000003o`000006o`068?l0003o0000o`068?l0003o00HP0ol000000ol01b3o0000o`07
8002o`000003o`078?l0003o000000?o000000?o00HPo`000?l000000_l000000ol01b7o0000o`00
0002on5c0004o`000?o;]03obk@0ol^d00?o000000Go00LPo`000?l0003o00HPo`000002o`0680;o
000000?o00LPo`000?l01b000ol000000ol01R3o0000o`000002o`000003o`078?l0003o000000?o
000000?o00LPo`000?l000000ol000001_l01R3o0000o`000?l01R3o0000o`0680?o0000;oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo
04Cooooo00?o0000o`067ol000000_l01Ql2o`000003o`067ol0003o00HO00?o000000?o00HOo`00
0?l01R000_l000000ol01R3o0000o`000003o`000003o`068?l0003o000000;o00000_l01R04o`00
0003o`078?l0003o000000;o00HP00Oo0000o`068?l0003o0000o`068?l0003o00LP00Co00000_oQ
L`001?l0003obk@0ol^d0?o;]004o`000003o`078?l0003o000000?o000000?o00HPo`000?l00000
0_l000001ol01b3o0000o`000?l0003o00HPo`000?l01b000_l000001?l01b3o0000o`068?l01R02
o`000003o`068?l0003o000000?o000000?o00HPo`000?l000000_l0000cooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool001gooooo0_l00015ooooo`Co000000?o00HOo`00
0?l000000_l00002o`067`Co000000?o00HPo`000?l000000_l01R001ol0003o00HPo`000?l0003o
00HPo`000?l01R000ol000000ol01R3o0000o`068002o`000003o`068?l0003o000000?o000000?o
00HPo`000?l000000ol000000ol01b3o0000o`000002on5c0007o`000?o;]03obk@0o`000?oQL`3o
0000o`068002o`000004o`068?l0003o00HPo`0680;o000000?o00HPo`000?l000000_l00002o`06
80Co000000?o00LPo`000?l000000ol000001_l01R3o0000o`000?l01R3o0000o`0680?o0000>?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooo
oooo04?ooooo00Go0000o`067ol0003o0000o`067`05o`000003o`067ol0003o000000;o000000?o
00HOo`000?l000000ol000000ol01R3o0000o`000003o`000003o`068?l0003o000000;o000000Oo
00HPo`000?l0003o0000o`068?l0003o00HP00;o000000Co00HPo`000?l01R3o00HP1?l00002on5c
0005o`000?o;]03obk@0o`000?oQL`000_l000000ol01R3o0000o`000003o`000006o`068?l0003o
0000o`068?l0003o00HP0ol000000ol01R3o0000o`068002o`000003o`068?l0003o000000?o0000
00?o00HPo`000?l000000_l0000kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool0023ooooo00?o0000ooooooooool0@oooool01?l0003o00HOo`000?l00002o`067`07o`00
0?l01Qoo0000o`000?l01Qoo0000o`067`03o`000003o`067ol0003o00HO00;o000000?o00HPo`00
0?l000000ol000000ol01Qoo0000o`000002o`0000;o00HP1?l000000ol01R3o0000o`000003o`00
0003o`068?l0003o000000;o000000CohG<0o`000?o;]03obk@00_l000001?l01R3o0000o`000?l0
1R05o`000003o`068?l0003o000000;o000000?o00HPo`000?l000000ol000001Ol01R3o0000o`00
0?l01R3o000000;o00HP0_l00010ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool0027ooooo00?o0000ooooooooool0@oooool00ol0003o00HOo`000004o`000003o`067ol0
003o000000;o00000_l01Ql4o`000003o`068?l0003o000000;o00HO00Oo0000o`067ol0003o0000
o`067ol0003o00HO00?o000000?o00HPo`000?l01R000_l000000ol01R3o0000o`000003o`000006
o`068?l0003o0000o`000?oQL`3o00000_o;]003o`000005o`067ol0003o0000o`068?l000000_l0
1R02o`000003o`068?l0003o00HP00;o00000_l01R04o`000003o`068?l0003o000000?o0000@ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o0000A?ooool2
o`000003o`067ol0003o00HO00;o000000?o00HOo`000?l000000ol000000ol01Qoo0000o`067`02
o`000003o`068?l0003o000000?o000000?o00HOo`000?l000000_l00002o`067`Co000000?o00HP
o`000?l000000_l01R001Ol0003o00HPo`000?l0003o00HP00;o00000_oQL`000ol0003obk@0o`00
0003o`000003o`068?l0003o000000?o000000?o00HOo`000?l000000_l000001ol01R3o0000o`00
0?l0003o00HPo`000?l01R000_l00019ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool04?ooool002Cooooo00?o0000ooooooooool0@oooool3o`000007o`067ol0003o0000o`000?l0
1Qoo0000o`067`04o`000007o`068?l0003o0000o`000?l01Qoo0000o`067`02o`000003o`067ol0
003o000000?o000000?o00HOo`000?l000000_l000000ol01R3o0000o`000003o`000003o`068?l0
003o000000;o00000_oQL`02o`000003on5c0?l0003o00HO00;o000000Co00HOo`000?l01R3o00HP
0_l000000ol01Qoo0000o`000002o`0000;o00HP1?l0001;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool04?ooool002Gooooo00?o0000ooooooooool0@oooool3o`0000;o00HO1?l0
00000ol01Qoo0000o`000002o`0000;o00HO1?l000000ol01Qoo0000o`000002o`067`07o`000?l0
1Qoo0000o`000?l01R3o0000o`068002o`0000;o00HO00Go0000o`067ol0003o0000o`067`03o`00
00;ohG<00_l000001?oQL`3o0000o`000?l01Ql5o`000006o`067ol0003o0000o`068?l0003o00HP
0ol0001@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool002Kooooo00?o
0000ooooooooool0@_ooool00ol0003o00HOo`000002o`000003o`067ol0003o00HO00;o000000?o
00HOo`000?l01Ql00ol000000ol01Qoo0000o`000002o`000003o`067ol0003o000000?o000000?o
00HOo`000?l000000_l000000ol01Qoo0000o`000003o`000004o`067ol0003o0000o`067`;o0000
0_oQL`02o`000005on5c0?l0003o0000o`000?l01Ql01Ol000000ol01Qoo0000o`000002o`0005Co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`009oooool2o`0004?ooooo
0_l000000ol01Qoo0000o`000002o`000003o`067ol0003o000000?o000000Ko00HOo`000?l0003o
00HOo`000?l01Ql2o`0000;o00HO00Oo0000o`067ol0003o0000o`067ol0003o00HP00;o00000_l0
1Ql4o`000003o`067ol0003o000000;o00000_oQL`02o`000003on5c0?l0003o00HO00;o00000_l0
1Ql01?l0003o00HOo`000?l0001Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4?ooool002Wooooo00?o0000ooooooooool0@_ooool00ol0003o00HOo`000003o`0000;o00HO1?l0
00000ol01Qoo0000o`000002o`000003o`067ol0003o000000?o000000?o00HOo`000?l000000_l0
00001ol01Qoo0000o`000?l0003o00HOo`000?l01Ql00_l000000ol01Qoo0000o`000002o`000003
on5c0?l0003o000000?o000000?o00HOo`000?l000000ol0001Kooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool002[ooooo00?o0000ooooooooool0@_ooool01?l0003o00HO
o`000?l01Ql3o`000003o`067ol0003o00HO00;o000000?o00HOo`000?l000000ol000000ol01Qoo
0000o`000002o`000003o`067ol0003o000000?o000000?o00HOo`000?l000000_l000000ol01Qoo
0000o`000002o`067`;o000000GohG<0o`000?oQL`3o0000o`067`02o`00067ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`12ooooo`Co
000000?o00HOo`000?l000000_l000001Ol01Qoo0000o`000?l01Qoo000000;o00HO0_l000000ol0
1Qoo0000o`067`02o`000004o`067ol0003o00HOo`067`;o000000?o00HOo`000?l000000_l00000
0ol01Qoo0000o`000008o`0006Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?
ooooo`00;?ooool2o`0004?ooooo1?l000000ol01Qoo0000o`000002o`000003o`067ol0003o0000
00?o000000?o00HOo`000?l000000_l000000ol01Qoo0000o`000003o`000006o`067ol0003o0000
o`067ol0003o00HO0_l00002o`067`?o00000_oj5`02o`0006Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0?ooooo`00;_ooool00ol0003oooooooooo`11ooooo`07o`000?l01Qoo
0000o`000?l01Qoo0000o`067`03o`000003o`067ol0003o000000;o000000?o00HOo`000?l00000
0_l00002o`067`Co000000?o00HOo`000?l000000_l000001?l01Qoo0000o`000?l00003ooooo`;o
0000J?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo000_ooooo`03o`00
0?oooooooooo047ooooo00?o0000o`067ol000000ol00002o`067`;o000000?o00HOo`000?l01Ql0
0_l000000ol01Qoo0000o`067`03o`000003o`067ol0003o000000;o000000?o00HOo`000?l00000
0_l0001aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool0033ooooo00?o
0000ooooooooool0@Oooool00ol0003o00HOo`000004o`000003o`067ol0003o000000;o000000?o
00HOo`000?l000000_l00002o`067`;o000000?o00HOo`000?l01Ql00_l0001fooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03oooool0037ooooo0_l00012ooooo`;o000000?o00HO
o`000?l000000_l000000ol01Qoo0000o`000002o`000003o`067ol0003o000000?o000000?o00HO
o`000?l000000_l0001hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool0
03?ooooo00?o0000ooooooooool0@Oooool01?l0003o00HOo`000?l01Ql2o`000003o`067ol0003o
00HO00?o000000?o00HOo`000?l01Ql00_l0001mooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03_ooool003Cooooo00?o0000ooooooooool0@Oooool3o`000003o`067ol0003o0000
00;o00000_l01Ql4o`00083ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>oooo
o`00=Oooool00ol0003oooooooooo`11ooooo`?o000000?o00HOo`000?l000000ol00024ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool003Kooooo0_l00011ooooo`04o`00
0?l01Qoo0000o`0008[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`00
>?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0>ooooo`00>Oooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo08cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`00>_ooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0=ooooo`00>oooool2o`0003gooooo00?o0000ooooooooool0SOooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo000mooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00go
oooo000nooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0Soooool01Ol0003ooooo
oooooooooooo000000oooooo000oooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
Soooool01Ol0003ooooooooooooooooo000000oooooo0010ooooo`;o0000>?ooool00ol0003ooooo
ooooo`2@ooooo`04o`000?ooooooooooo`0000oooooo0012ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0TOooool00ol0003oooooo`00000?ooooo`00@oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo097ooooo00Co0000oooooooooooo00003_ooool004Cooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`2Booooo`03o`000?oooooo000000kooooo0015
ooooo`;o0000<oooool00ol0003oooooooooo`2Cooooo`;o00003_ooool004Oooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`2Cooooo`?o00003_ooool004Sooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`2?ooooo`Co00004Oooool004Wooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`2;ooooo`Co00005Oooool004[ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`28ooooo`?o00006Oooool004_ooooo0_l0000/ooooo`03o`000?oooooo
oooo08Cooooo1?l0000Looooo`00COooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
083ooooo1?l0000Pooooo`00C_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07co
oooo1?l0000Tooooo`00Coooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Sooooo
1?l0000Xooooo`00D?ooool2o`0002Oooooo00?o0000ooooooooool0M?ooool4o`0002cooooo001B
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool3o`00033ooooo001Coooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0KOooool4o`0003?ooooo001Dooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0JOooool4o`0003Oooooo001Eooooo`;o0000
8_ooool00ol0003oooooooooo`1Uooooo`Co0000>oooool005Oooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1Qooooo`Co0000?oooool005Sooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1Nooooo`?o0000@oooool005Wooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`1Jooooo`Co0000A_ooool005[ooooo0_l0000Mooooo`03o`000?oooooooooo05Ko
oooo1?l0001:ooooo`00G?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo
1?l0001>ooooo`00GOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0
001Booooo`00G_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo1?l0001F
ooooo`00Goooool2o`0001Sooooo00?o0000ooooooooool0Aoooool3o`0005[ooooo001Qooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool4o`0005gooooo001Rooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4o`00067ooooo001Sooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0>oooool4o`0006Gooooo001Tooooo`;o00004oooool0
0ol0003oooooooooo`0gooooo`Co0000JOooool006Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0cooooo`Co0000KOooool006Oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0`ooooo`?o0000LOooool006Sooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0]ooooo`Co0000M?ooool006Wooooo0_l0000=ooooo`03o`000?oooooooooo02Wooooo1?l0
001hooooo`00Joooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0001l
ooooo`00K?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l00020oooo
o`00KOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo0ol00024ooooo`00
K_ooool2o`0000Sooooo00?o0000ooooooooool06_ooool4o`0008Oooooo001`ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05_ooool4o`0008_ooooo001aooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool4o`0008oooooo001booooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03_ooool4o`0009?ooooo001cooooo`;o00000oooool00ol0003o
ooooooooo`0:ooooo`Co0000Uoooool007Gooooo00Co0000oooooooooooo00002Oooool3o`0009_o
oooo001fooooo`03o`000?oooooo000000Gooooo1?l0002Nooooo`00Moooool2o`000003ooooool0
003o000000;o0000X_ooool007Sooooo0_l0002Vooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00Goooool3o`00057ooooo0ol0001Zooooo`00H?ooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo06Wooooo000eooooo`?o00001?ooool3o`0000;ooooo1Ol000001Ooo
oooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o00000_ooool3
o`0000Cooooo0ol00003ooooo`Co00000_ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l0
0002ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool01oooool3o`0000Gooooo0_l0
00000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000;ooooo
1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o0000037ooooo000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003o
ooooo`0000Kooooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Co
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0003;ooooo000fooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool5o`0000;ooooo0ol00002ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003ooooo
o`0000Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0`ooooo`00=_ooool3o`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0:ooooo`;o00000oooool01?l0003oooooooooool00002oooo
o`;o00000oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002oooo
o`06o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000002Oooool3o`0000?ooooo00Co0000oooooooooooo0000
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0`ooooo`00=_ooool01?l0003oooooooooool00002ooooo`?o00000_ooool3o`0000?ooooo
1?l00002ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`Co00000_ooool2o`000003oooo
ool0003o000000;ooooo0ol00003ooooo`;o00001?ooool3o`0000[ooooo00Co0000oooooooooooo
oooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0
003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oooooooooo
00;ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co00000_ooool3
o`0000Cooooo0ol00002ooooo`Co0000<oooool003Kooooo00Co0000oooooooooooo00005?ooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03ooo
ool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo04Gooooo000eooooo`Co00002_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0ol0000Kooooo`;o00002?oo
ool5o`0000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00kooooo1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_oo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0747948, 0.0294636, \
0.00375386, 0.00375386}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -117 0 ]
[.5 .82364 117 9 ]
[.08833 .22227 -30 -8.87978 ]
[.08833 .22227 0 .12022 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60583 .01876 -20.3642 -9 ]
[.60583 .01876 3.63577 0 ]
[.73629 .04932 0 -6.20852 ]
[.73629 .04932 30 2.79148 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95788 .38865 0 -5.88734 ]
[.95788 .38865 24 3.11266 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01603 .31578 -18 -2.78515 ]
[.01603 .31578 0 6.21485 ]
[.00767 .36814 -18 -2.82957 ]
[.00767 .36814 0 6.17043 ]
[-0.00096 .42228 -18 -2.87565 ]
[-0.00096 .42228 0 6.12435 ]
[-0.0099 .4783 -18 -2.9235 ]
[-0.0099 .4783 0 6.0765 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Perfect Point Spread Intensity Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09773 .23142 m
.10243 .236 L
s
[(-0.05)] .08833 .22227 1 .97329 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61334 .02952 m
.61709 .03491 L
s
[(0.05)] .60583 .01876 .69702 1 Mshowa
.125 Mabswid
.14497 .21292 m
.14774 .21571 L
s
.1931 .19408 m
.19582 .19692 L
s
.24214 .17487 m
.24481 .17776 L
s
.29212 .1553 m
.29474 .15824 L
s
.39501 .11502 m
.39752 .11805 L
s
.44797 .09427 m
.45043 .09735 L
s
.502 .07312 m
.50439 .07625 L
s
.55711 .05154 m
.55943 .05472 L
s
.05135 .24958 m
.05422 .25228 L
s
.67072 .00705 m
.6729 .01033 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72403 .05398 m
.71789 .05631 L
s
[(-0.05)] .73629 .04932 -1 .37967 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94534 .39252 m
.93907 .39445 L
s
[(0.05)] .95788 .38865 -1 .3083 Mshowa
.125 Mabswid
.74979 .09338 m
.74609 .09475 L
s
.77462 .13138 m
.77092 .13272 L
s
.79859 .16803 m
.79488 .16935 L
s
.82172 .20342 m
.818 .20472 L
s
.86568 .27066 m
.86195 .27191 L
s
.88658 .30263 m
.88283 .30385 L
s
.9068 .33356 m
.90305 .33476 L
s
.92638 .36351 m
.92262 .36469 L
s
.69729 .01309 m
.69363 .01452 L
s
.96372 .42063 m
.95995 .42177 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02829 .3111 m
.03442 .30877 L
s
[(0.1)] .01603 .31578 1 -0.38108 Mshowa
.01998 .36357 m
.02613 .36129 L
s
[(0.2)] .00767 .36814 1 -0.37121 Mshowa
.01138 .41783 m
.01755 .4156 L
s
[(0.3)] -0.00096 .42228 1 -0.36097 Mshowa
.00248 .47396 m
.00867 .47179 L
s
[(0.4)] -0.0099 .4783 1 -0.35033 Mshowa
.125 Mabswid
.03475 .27036 m
.03842 .26893 L
s
.03315 .28044 m
.03682 .27902 L
s
.03154 .2906 m
.03521 .28918 L
s
.02992 .30082 m
.0336 .29941 L
s
.02665 .32146 m
.03033 .32006 L
s
.025 .33188 m
.02868 .33049 L
s
.02334 .34237 m
.02702 .34099 L
s
.02166 .35294 m
.02535 .35156 L
s
.01828 .37428 m
.02197 .37291 L
s
.01657 .38505 m
.02027 .3837 L
s
.01485 .3959 m
.01855 .39455 L
s
.01312 .40683 m
.01682 .40548 L
s
.00962 .4289 m
.01333 .42757 L
s
.00786 .44005 m
.01156 .43873 L
s
.00608 .45128 m
.00979 .44996 L
s
.00429 .46258 m
.008 .46127 L
s
.00067 .48542 m
.00438 .48413 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .023 .121 r
.40028 .59921 .40512 .60371 .41325 .60127 .40842 .59675 Metetra
0 .023 .121 r
.40842 .59675 .41325 .60127 .4214 .59883 .41659 .59429 Metetra
0 .023 .121 r
.41659 .59429 .4214 .59883 .42958 .59638 .42478 .59183 Metetra
0 .023 .121 r
.42478 .59183 .42958 .59638 .43778 .59392 .433 .58935 Metetra
0 .023 .121 r
.433 .58935 .43778 .59392 .446 .59145 .44124 .58687 Metetra
0 .023 .121 r
.44124 .58687 .446 .59145 .45426 .58897 .44951 .58438 Metetra
0 .023 .121 r
.44951 .58438 .45426 .58897 .46253 .58649 .4578 .58189 Metetra
0 .023 .121 r
.4578 .58189 .46253 .58649 .47083 .584 .46612 .57938 Metetra
0 .023 .121 r
.46612 .57938 .47083 .584 .47916 .5815 .47446 .57687 Metetra
0 .023 .121 r
.47446 .57687 .47916 .5815 .48751 .579 .48283 .57435 Metetra
0 .023 .121 r
.48283 .57435 .48751 .579 .49589 .57648 .49123 .57182 Metetra
0 .023 .121 r
.49123 .57182 .49589 .57648 .50429 .57396 .49965 .56929 Metetra
0 .023 .121 r
.49965 .56929 .50429 .57396 .51272 .57143 .50809 .56674 Metetra
0 .023 .121 r
.50809 .56674 .51272 .57143 .52118 .5689 .51657 .56419 Metetra
0 .023 .121 r
.51657 .56419 .52118 .5689 .52966 .56635 .52506 .56163 Metetra
0 .023 .121 r
.52506 .56163 .52966 .56635 .53817 .5638 .53359 .55907 Metetra
0 .023 .121 r
.53359 .55907 .53817 .5638 .5467 .56124 .54214 .55649 Metetra
0 .023 .121 r
.54214 .55649 .5467 .56124 .55526 .55867 .55072 .55391 Metetra
0 .023 .121 r
.55072 .55391 .55526 .55867 .56385 .55609 .55932 .55132 Metetra
0 .023 .121 r
.55932 .55132 .56385 .55609 .57247 .55351 .56796 .54872 Metetra
0 .023 .121 r
.56796 .54872 .57247 .55351 .58111 .55092 .57661 .54611 Metetra
0 .023 .121 r
.57661 .54611 .58111 .55092 .58977 .54832 .5853 .5435 Metetra
0 .023 .121 r
.5853 .5435 .58977 .54832 .59847 .54571 .59401 .54087 Metetra
0 .023 .121 r
.59401 .54087 .59847 .54571 .60719 .54309 .60275 .53824 Metetra
0 .023 .121 r
.60275 .53824 .60719 .54309 .61594 .54047 .61152 .5356 Metetra
0 .023 .121 r
.61152 .5356 .61594 .54047 .62472 .53783 .62032 .53295 Metetra
0 .023 .121 r
.62032 .53295 .62472 .53783 .63352 .53519 .62914 .5303 Metetra
0 .023 .121 r
.62914 .5303 .63352 .53519 .64235 .53254 .63799 .52763 Metetra
0 .023 .121 r
.63799 .52763 .64235 .53254 .65121 .52989 .64687 .52496 Metetra
0 .023 .121 r
.64687 .52496 .65121 .52989 .6601 .52722 .65578 .52228 Metetra
0 .023 .121 r
.65578 .52228 .6601 .52722 .66902 .52454 .66472 .51964 Metetra
0 .024 .122 r
.66472 .51964 .66902 .52454 .67796 .52186 .67368 .51694 Metetra
0 .023 .121 r
.67368 .51694 .67796 .52186 .68694 .51917 .68267 .51418 Metetra
0 .023 .121 r
.68267 .51418 .68694 .51917 .69594 .51647 .69169 .51146 Metetra
0 .023 .121 r
.69169 .51146 .69594 .51647 .70497 .51376 .70074 .50874 Metetra
0 .023 .121 r
.70074 .50874 .70497 .51376 .71403 .51104 .70982 .506 Metetra
0 .023 .121 r
.70982 .506 .71403 .51104 .72311 .50832 .71893 .50326 Metetra
0 .023 .121 r
.71893 .50326 .72311 .50832 .73223 .50558 .72807 .50051 Metetra
0 .023 .121 r
.72807 .50051 .73223 .50558 .74138 .50284 .73723 .49775 Metetra
0 .023 .121 r
.73723 .49775 .74138 .50284 .75055 .50008 .74643 .49498 Metetra
0 .023 .121 r
.74643 .49498 .75055 .50008 .75976 .49732 .75565 .4922 Metetra
0 .023 .121 r
.75565 .4922 .75976 .49732 .76899 .49455 .76491 .48941 Metetra
0 .023 .121 r
.76491 .48941 .76899 .49455 .77826 .49177 .77419 .48662 Metetra
0 .023 .121 r
.77419 .48662 .77826 .49177 .78755 .48898 .78351 .48381 Metetra
0 .023 .121 r
.78351 .48381 .78755 .48898 .79688 .48619 .79286 .481 Metetra
0 .023 .121 r
.79286 .481 .79688 .48619 .80623 .48338 .80223 .47818 Metetra
0 .023 .121 r
.80223 .47818 .80623 .48338 .81562 .48057 .81164 .47534 Metetra
0 .023 .121 r
.81164 .47534 .81562 .48057 .82503 .47774 .82108 .4725 Metetra
0 .023 .121 r
.82108 .4725 .82503 .47774 .83448 .47491 .83054 .46965 Metetra
0 .023 .121 r
.83054 .46965 .83448 .47491 .84395 .47206 .84004 .46679 Metetra
0 .023 .121 r
.84004 .46679 .84395 .47206 .85346 .46921 .84957 .46392 Metetra
0 .023 .121 r
.84957 .46392 .85346 .46921 .863 .46635 .85914 .46104 Metetra
0 .023 .121 r
.85914 .46104 .863 .46635 .87257 .46348 .86873 .45815 Metetra
0 .023 .121 r
.86873 .45815 .87257 .46348 .88217 .4606 .87835 .45526 Metetra
0 .023 .121 r
.87835 .45526 .88217 .4606 .89181 .45771 .88801 .45235 Metetra
0 .023 .121 r
.88801 .45235 .89181 .45771 .90147 .45481 .8977 .44943 Metetra
0 .023 .121 r
.8977 .44943 .90147 .45481 .91117 .4519 .90742 .4465 Metetra
0 .023 .121 r
.90742 .4465 .91117 .4519 .9209 .44898 .91717 .44357 Metetra
0 .023 .121 r
.91717 .44357 .9209 .44898 .93066 .44605 .92696 .44062 Metetra
0 .023 .121 r
.92696 .44062 .93066 .44605 .94045 .44311 .93677 .43766 Metetra
0 .023 .121 r
.93677 .43766 .94045 .44311 .95028 .44017 .94663 .4347 Metetra
0 .023 .121 r
.94663 .4347 .95028 .44017 .96014 .43721 .95651 .43172 Metetra
0 .023 .121 r
.95651 .43172 .96014 .43721 .97003 .43424 .96642 .42874 Metetra
0 .023 .121 r
.39541 .59467 .40028 .59921 .40842 .59675 .40357 .59221 Metetra
0 .023 .121 r
.40357 .59221 .40842 .59675 .41659 .59429 .41175 .58974 Metetra
0 .023 .121 r
.41175 .58974 .41659 .59429 .42478 .59183 .41996 .58725 Metetra
0 .023 .121 r
.41996 .58725 .42478 .59183 .433 .58935 .4282 .58477 Metetra
0 .023 .121 r
.4282 .58477 .433 .58935 .44124 .58687 .43645 .58227 Metetra
0 .023 .121 r
.43645 .58227 .44124 .58687 .44951 .58438 .44474 .57977 Metetra
0 .023 .121 r
.44474 .57977 .44951 .58438 .4578 .58189 .45304 .57726 Metetra
0 .023 .121 r
.45304 .57726 .4578 .58189 .46612 .57938 .46138 .57474 Metetra
0 .023 .121 r
.46138 .57474 .46612 .57938 .47446 .57687 .46974 .57221 Metetra
0 .023 .121 r
.46974 .57221 .47446 .57687 .48283 .57435 .47812 .56968 Metetra
0 .023 .121 r
.47812 .56968 .48283 .57435 .49123 .57182 .48653 .56713 Metetra
0 .023 .121 r
.48653 .56713 .49123 .57182 .49965 .56929 .49497 .56459 Metetra
0 .023 .121 r
.49497 .56459 .49965 .56929 .50809 .56674 .50344 .56203 Metetra
0 .023 .121 r
.50344 .56203 .50809 .56674 .51657 .56419 .51193 .55946 Metetra
0 .023 .121 r
.51193 .55946 .51657 .56419 .52506 .56163 .52044 .55689 Metetra
0 .023 .121 r
.52044 .55689 .52506 .56163 .53359 .55907 .52898 .55431 Metetra
0 .023 .121 r
.52898 .55431 .53359 .55907 .54214 .55649 .53755 .55172 Metetra
0 .023 .121 r
.53755 .55172 .54214 .55649 .55072 .55391 .54615 .54912 Metetra
0 .023 .121 r
.54615 .54912 .55072 .55391 .55932 .55132 .55477 .54651 Metetra
0 .023 .121 r
.55477 .54651 .55932 .55132 .56796 .54872 .56342 .5439 Metetra
0 .023 .121 r
.56342 .5439 .56796 .54872 .57661 .54611 .5721 .54128 Metetra
0 .023 .121 r
.5721 .54128 .57661 .54611 .5853 .5435 .5808 .53865 Metetra
0 .023 .121 r
.5808 .53865 .5853 .5435 .59401 .54087 .58953 .53601 Metetra
0 .023 .121 r
.58953 .53601 .59401 .54087 .60275 .53824 .59829 .53336 Metetra
0 .023 .121 r
.59829 .53336 .60275 .53824 .61152 .5356 .60708 .5307 Metetra
0 .023 .121 r
.60708 .5307 .61152 .5356 .62032 .53295 .61589 .52804 Metetra
0 .023 .121 r
.61589 .52804 .62032 .53295 .62914 .5303 .62473 .52537 Metetra
0 .023 .121 r
.62473 .52537 .62914 .5303 .63799 .52763 .6336 .52269 Metetra
0 .023 .121 r
.6336 .52269 .63799 .52763 .64687 .52496 .6425 .52 Metetra
0 .023 .121 r
.6425 .52 .64687 .52496 .65578 .52228 .65143 .5173 Metetra
0 .023 .122 r
.65143 .5173 .65578 .52228 .66472 .51964 .66038 .51462 Metetra
0 .024 .122 r
.66038 .51462 .66472 .51964 .67368 .51694 .66937 .51191 Metetra
0 .023 .122 r
.66937 .51191 .67368 .51694 .68267 .51418 .67838 .50916 Metetra
0 .023 .121 r
.67838 .50916 .68267 .51418 .69169 .51146 .68742 .50643 Metetra
0 .023 .121 r
.68742 .50643 .69169 .51146 .70074 .50874 .69649 .50368 Metetra
0 .023 .121 r
.69649 .50368 .70074 .50874 .70982 .506 .70559 .50093 Metetra
0 .023 .121 r
.70559 .50093 .70982 .506 .71893 .50326 .71472 .49817 Metetra
0 .023 .121 r
.71472 .49817 .71893 .50326 .72807 .50051 .72387 .49541 Metetra
0 .023 .121 r
.72387 .49541 .72807 .50051 .73723 .49775 .73306 .49263 Metetra
0 .023 .121 r
.73306 .49263 .73723 .49775 .74643 .49498 .74228 .48984 Metetra
0 .023 .121 r
.74228 .48984 .74643 .49498 .75565 .4922 .75152 .48705 Metetra
0 .023 .121 r
.75152 .48705 .75565 .4922 .76491 .48941 .7608 .48425 Metetra
0 .023 .121 r
.7608 .48425 .76491 .48941 .77419 .48662 .77011 .48143 Metetra
0 .023 .121 r
.77011 .48143 .77419 .48662 .78351 .48381 .77944 .47861 Metetra
0 .023 .121 r
.77944 .47861 .78351 .48381 .79286 .481 .78881 .47578 Metetra
0 .023 .121 r
.78881 .47578 .79286 .481 .80223 .47818 .79821 .47294 Metetra
0 .023 .121 r
.79821 .47294 .80223 .47818 .81164 .47534 .80764 .47009 Metetra
0 .023 .121 r
.80764 .47009 .81164 .47534 .82108 .4725 .8171 .46723 Metetra
0 .023 .121 r
.8171 .46723 .82108 .4725 .83054 .46965 .82659 .46436 Metetra
0 .023 .121 r
.82659 .46436 .83054 .46965 .84004 .46679 .83611 .46149 Metetra
0 .023 .121 r
.83611 .46149 .84004 .46679 .84957 .46392 .84566 .4586 Metetra
0 .023 .121 r
.84566 .4586 .84957 .46392 .85914 .46104 .85525 .4557 Metetra
0 .023 .121 r
.85525 .4557 .85914 .46104 .86873 .45815 .86486 .4528 Metetra
0 .023 .121 r
.86486 .4528 .86873 .45815 .87835 .45526 .87451 .44988 Metetra
0 .023 .121 r
.87451 .44988 .87835 .45526 .88801 .45235 .88419 .44695 Metetra
0 .023 .121 r
.88419 .44695 .88801 .45235 .8977 .44943 .8939 .44402 Metetra
0 .023 .121 r
.8939 .44402 .8977 .44943 .90742 .4465 .90365 .44107 Metetra
0 .023 .121 r
.90365 .44107 .90742 .4465 .91717 .44357 .91342 .43812 Metetra
0 .023 .121 r
.91342 .43812 .91717 .44357 .92696 .44062 .92323 .43516 Metetra
0 .023 .121 r
.92323 .43516 .92696 .44062 .93677 .43766 .93307 .43218 Metetra
0 .023 .121 r
.93307 .43218 .93677 .43766 .94663 .4347 .94295 .4292 Metetra
0 .023 .121 r
.94295 .4292 .94663 .4347 .95651 .43172 .95285 .4262 Metetra
0 .023 .121 r
.95285 .4262 .95651 .43172 .96642 .42874 .9628 .4232 Metetra
0 .023 .121 r
.39052 .59012 .39541 .59467 .40357 .59221 .39869 .58764 Metetra
0 .023 .121 r
.39869 .58764 .40357 .59221 .41175 .58974 .40689 .58515 Metetra
0 .023 .121 r
.40689 .58515 .41175 .58974 .41996 .58725 .41511 .58266 Metetra
0 .023 .121 r
.41511 .58266 .41996 .58725 .4282 .58477 .42336 .58015 Metetra
0 .023 .121 r
.42336 .58015 .4282 .58477 .43645 .58227 .43164 .57764 Metetra
0 .023 .121 r
.43164 .57764 .43645 .58227 .44474 .57977 .43994 .57513 Metetra
0 .023 .121 r
.43994 .57513 .44474 .57977 .45304 .57726 .44826 .5726 Metetra
0 .023 .121 r
.44826 .5726 .45304 .57726 .46138 .57474 .45661 .57007 Metetra
0 .023 .121 r
.45661 .57007 .46138 .57474 .46974 .57221 .46499 .56753 Metetra
0 .023 .121 r
.46499 .56753 .46974 .57221 .47812 .56968 .47339 .56498 Metetra
0 .023 .121 r
.47339 .56498 .47812 .56968 .48653 .56713 .48182 .56242 Metetra
0 .023 .121 r
.48182 .56242 .48653 .56713 .49497 .56459 .49027 .55986 Metetra
0 .023 .121 r
.49027 .55986 .49497 .56459 .50344 .56203 .49875 .55728 Metetra
0 .023 .121 r
.49875 .55728 .50344 .56203 .51193 .55946 .50726 .5547 Metetra
0 .023 .121 r
.50726 .5547 .51193 .55946 .52044 .55689 .51579 .55212 Metetra
0 .023 .121 r
.51579 .55212 .52044 .55689 .52898 .55431 .52435 .54952 Metetra
0 .023 .121 r
.52435 .54952 .52898 .55431 .53755 .55172 .53294 .54691 Metetra
0 .023 .121 r
.53294 .54691 .53755 .55172 .54615 .54912 .54155 .5443 Metetra
0 .023 .121 r
.54155 .5443 .54615 .54912 .55477 .54651 .55019 .54168 Metetra
0 .023 .121 r
.55019 .54168 .55477 .54651 .56342 .5439 .55886 .53905 Metetra
0 .023 .121 r
.55886 .53905 .56342 .5439 .5721 .54128 .56755 .53641 Metetra
0 .023 .121 r
.56755 .53641 .5721 .54128 .5808 .53865 .57628 .53377 Metetra
0 .023 .121 r
.57628 .53377 .5808 .53865 .58953 .53601 .58502 .53111 Metetra
0 .023 .121 r
.58502 .53111 .58953 .53601 .59829 .53336 .5938 .52845 Metetra
0 .023 .121 r
.5938 .52845 .59829 .53336 .60708 .5307 .60261 .52578 Metetra
0 .023 .121 r
.60261 .52578 .60708 .5307 .61589 .52804 .61144 .5231 Metetra
0 .023 .121 r
.61144 .5231 .61589 .52804 .62473 .52537 .6203 .52041 Metetra
0 .023 .121 r
.6203 .52041 .62473 .52537 .6336 .52269 .62919 .51772 Metetra
0 .023 .121 r
.62919 .51772 .6336 .52269 .6425 .52 .63811 .51501 Metetra
0 .023 .121 r
.63811 .51501 .6425 .52 .65143 .5173 .64705 .5123 Metetra
0 .023 .121 r
.64705 .5123 .65143 .5173 .66038 .51462 .65603 .5096 Metetra
0 .024 .122 r
.65603 .5096 .66038 .51462 .66937 .51191 .66503 .50687 Metetra
0 .023 .121 r
.66503 .50687 .66937 .51191 .67838 .50916 .67406 .50411 Metetra
0 .023 .121 r
.67406 .50411 .67838 .50916 .68742 .50643 .68312 .50136 Metetra
0 .023 .121 r
.68312 .50136 .68742 .50643 .69649 .50368 .69221 .4986 Metetra
0 .023 .121 r
.69221 .4986 .69649 .50368 .70559 .50093 .70133 .49583 Metetra
0 .023 .121 r
.70133 .49583 .70559 .50093 .71472 .49817 .71048 .49306 Metetra
0 .023 .121 r
.71048 .49306 .71472 .49817 .72387 .49541 .71966 .49027 Metetra
0 .023 .121 r
.71966 .49027 .72387 .49541 .73306 .49263 .72887 .48748 Metetra
0 .023 .121 r
.72887 .48748 .73306 .49263 .74228 .48984 .7381 .48468 Metetra
0 .023 .121 r
.7381 .48468 .74228 .48984 .75152 .48705 .74737 .48187 Metetra
0 .023 .121 r
.74737 .48187 .75152 .48705 .7608 .48425 .75667 .47905 Metetra
0 .023 .121 r
.75667 .47905 .7608 .48425 .77011 .48143 .766 .47622 Metetra
0 .023 .121 r
.766 .47622 .77011 .48143 .77944 .47861 .77535 .47338 Metetra
0 .023 .121 r
.77535 .47338 .77944 .47861 .78881 .47578 .78474 .47053 Metetra
0 .023 .121 r
.78474 .47053 .78881 .47578 .79821 .47294 .79416 .46767 Metetra
0 .023 .121 r
.79416 .46767 .79821 .47294 .80764 .47009 .80361 .4648 Metetra
0 .023 .121 r
.80361 .4648 .80764 .47009 .8171 .46723 .81309 .46193 Metetra
0 .023 .121 r
.81309 .46193 .8171 .46723 .82659 .46436 .82261 .45904 Metetra
0 .023 .121 r
.82261 .45904 .82659 .46436 .83611 .46149 .83215 .45615 Metetra
0 .023 .121 r
.83215 .45615 .83611 .46149 .84566 .4586 .84173 .45324 Metetra
0 .023 .121 r
.84173 .45324 .84566 .4586 .85525 .4557 .85133 .45033 Metetra
0 .023 .121 r
.85133 .45033 .85525 .4557 .86486 .4528 .86097 .4474 Metetra
0 .023 .121 r
.86097 .4474 .86486 .4528 .87451 .44988 .87064 .44447 Metetra
0 .023 .121 r
.87064 .44447 .87451 .44988 .88419 .44695 .88035 .44153 Metetra
0 .023 .121 r
.88035 .44153 .88419 .44695 .8939 .44402 .89008 .43857 Metetra
0 .023 .121 r
.89008 .43857 .8939 .44402 .90365 .44107 .89985 .43561 Metetra
0 .023 .121 r
.89985 .43561 .90365 .44107 .91342 .43812 .90965 .43264 Metetra
0 .023 .121 r
.90965 .43264 .91342 .43812 .92323 .43516 .91948 .42966 Metetra
0 .023 .121 r
.91948 .42966 .92323 .43516 .93307 .43218 .92935 .42666 Metetra
0 .023 .121 r
.92935 .42666 .93307 .43218 .94295 .4292 .93925 .42366 Metetra
0 .023 .121 r
.93925 .42366 .94295 .4292 .95285 .4262 .94918 .42065 Metetra
0 .023 .121 r
.94918 .42065 .95285 .4262 .9628 .4232 .95914 .41762 Metetra
0 .023 .121 r
.3856 .58553 .39052 .59012 .39869 .58764 .39379 .58304 Metetra
0 .023 .121 r
.39379 .58304 .39869 .58764 .40689 .58515 .402 .58054 Metetra
0 .023 .121 r
.402 .58054 .40689 .58515 .41511 .58266 .41024 .57803 Metetra
0 .023 .121 r
.41024 .57803 .41511 .58266 .42336 .58015 .4185 .57551 Metetra
0 .023 .121 r
.4185 .57551 .42336 .58015 .43164 .57764 .42679 .57299 Metetra
0 .023 .121 r
.42679 .57299 .43164 .57764 .43994 .57513 .43511 .57046 Metetra
0 .023 .121 r
.43511 .57046 .43994 .57513 .44826 .5726 .44345 .56792 Metetra
0 .023 .121 r
.44345 .56792 .44826 .5726 .45661 .57007 .45182 .56537 Metetra
0 .023 .121 r
.45182 .56537 .45661 .57007 .46499 .56753 .46021 .56282 Metetra
0 .023 .121 r
.46021 .56282 .46499 .56753 .47339 .56498 .46863 .56025 Metetra
0 .023 .121 r
.46863 .56025 .47339 .56498 .48182 .56242 .47707 .55768 Metetra
0 .023 .121 r
.47707 .55768 .48182 .56242 .49027 .55986 .48554 .5551 Metetra
0 .023 .121 r
.48554 .5551 .49027 .55986 .49875 .55728 .49404 .55251 Metetra
0 .023 .121 r
.49404 .55251 .49875 .55728 .50726 .5547 .50256 .54992 Metetra
0 .023 .121 r
.50256 .54992 .50726 .5547 .51579 .55212 .51111 .54732 Metetra
0 .023 .121 r
.51111 .54732 .51579 .55212 .52435 .54952 .51969 .5447 Metetra
0 .023 .121 r
.51969 .5447 .52435 .54952 .53294 .54691 .5283 .54208 Metetra
0 .023 .121 r
.5283 .54208 .53294 .54691 .54155 .5443 .53693 .53946 Metetra
0 .023 .121 r
.53693 .53946 .54155 .5443 .55019 .54168 .54558 .53682 Metetra
0 .023 .121 r
.54558 .53682 .55019 .54168 .55886 .53905 .55427 .53418 Metetra
0 .023 .121 r
.55427 .53418 .55886 .53905 .56755 .53641 .56298 .53152 Metetra
0 .023 .121 r
.56298 .53152 .56755 .53641 .57628 .53377 .57172 .52886 Metetra
0 .023 .121 r
.57172 .52886 .57628 .53377 .58502 .53111 .58049 .52619 Metetra
0 .023 .121 r
.58049 .52619 .58502 .53111 .5938 .52845 .58929 .52351 Metetra
0 .023 .121 r
.58929 .52351 .5938 .52845 .60261 .52578 .59811 .52083 Metetra
0 .023 .121 r
.59811 .52083 .60261 .52578 .61144 .5231 .60696 .51813 Metetra
0 .023 .121 r
.60696 .51813 .61144 .5231 .6203 .52041 .61584 .51543 Metetra
0 .023 .121 r
.61584 .51543 .6203 .52041 .62919 .51772 .62475 .51272 Metetra
0 .023 .121 r
.62475 .51272 .62919 .51772 .63811 .51501 .63369 .51 Metetra
0 .023 .121 r
.63369 .51 .63811 .51501 .64705 .5123 .64265 .50727 Metetra
0 .024 .122 r
.64265 .50727 .64705 .5123 .65603 .5096 .65165 .50459 Metetra
0 .024 .122 r
.65165 .50459 .65603 .5096 .66503 .50687 .66067 .50185 Metetra
0 .024 .122 r
.66067 .50185 .66503 .50687 .67406 .50411 .66972 .49903 Metetra
0 .023 .121 r
.66972 .49903 .67406 .50411 .68312 .50136 .6788 .49626 Metetra
0 .023 .121 r
.6788 .49626 .68312 .50136 .69221 .4986 .68791 .49348 Metetra
0 .023 .121 r
.68791 .49348 .69221 .4986 .70133 .49583 .69705 .4907 Metetra
0 .023 .121 r
.69705 .4907 .70133 .49583 .71048 .49306 .70622 .48791 Metetra
0 .023 .121 r
.70622 .48791 .71048 .49306 .71966 .49027 .71542 .48511 Metetra
0 .023 .121 r
.71542 .48511 .71966 .49027 .72887 .48748 .72464 .4823 Metetra
0 .023 .121 r
.72464 .4823 .72887 .48748 .7381 .48468 .7339 .47948 Metetra
0 .023 .121 r
.7339 .47948 .7381 .48468 .74737 .48187 .74319 .47665 Metetra
0 .023 .121 r
.74319 .47665 .74737 .48187 .75667 .47905 .75251 .47381 Metetra
0 .023 .121 r
.75251 .47381 .75667 .47905 .766 .47622 .76186 .47097 Metetra
0 .023 .121 r
.76186 .47097 .766 .47622 .77535 .47338 .77124 .46811 Metetra
0 .023 .121 r
.77124 .46811 .77535 .47338 .78474 .47053 .78065 .46525 Metetra
0 .023 .121 r
.78065 .46525 .78474 .47053 .79416 .46767 .79009 .46237 Metetra
0 .023 .121 r
.79009 .46237 .79416 .46767 .80361 .4648 .79956 .45949 Metetra
0 .023 .121 r
.79956 .45949 .80361 .4648 .81309 .46193 .80907 .45659 Metetra
0 .023 .121 r
.80907 .45659 .81309 .46193 .82261 .45904 .8186 .45369 Metetra
0 .023 .121 r
.8186 .45369 .82261 .45904 .83215 .45615 .82817 .45078 Metetra
0 .023 .121 r
.82817 .45078 .83215 .45615 .84173 .45324 .83777 .44786 Metetra
0 .023 .121 r
.83777 .44786 .84173 .45324 .85133 .45033 .8474 .44492 Metetra
0 .023 .121 r
.8474 .44492 .85133 .45033 .86097 .4474 .85706 .44198 Metetra
0 .023 .121 r
.85706 .44198 .86097 .4474 .87064 .44447 .86675 .43903 Metetra
0 .023 .121 r
.86675 .43903 .87064 .44447 .88035 .44153 .87648 .43607 Metetra
0 .023 .121 r
.87648 .43607 .88035 .44153 .89008 .43857 .88624 .4331 Metetra
0 .023 .121 r
.88624 .4331 .89008 .43857 .89985 .43561 .89603 .43012 Metetra
0 .023 .121 r
.89603 .43012 .89985 .43561 .90965 .43264 .90585 .42712 Metetra
0 .023 .121 r
.90585 .42712 .90965 .43264 .91948 .42966 .91571 .42412 Metetra
0 .023 .121 r
.91571 .42412 .91948 .42966 .92935 .42666 .9256 .42111 Metetra
0 .023 .121 r
.9256 .42111 .92935 .42666 .93925 .42366 .93552 .41809 Metetra
0 .023 .121 r
.93552 .41809 .93925 .42366 .94918 .42065 .94548 .41506 Metetra
0 .023 .121 r
.94548 .41506 .94918 .42065 .95914 .41762 .95547 .41202 Metetra
0 .023 .121 r
.38065 .58092 .3856 .58553 .39379 .58304 .38885 .57842 Metetra
0 .023 .121 r
.38885 .57842 .39379 .58304 .402 .58054 .39708 .5759 Metetra
0 .023 .121 r
.39708 .5759 .402 .58054 .41024 .57803 .40534 .57338 Metetra
0 .023 .121 r
.40534 .57338 .41024 .57803 .4185 .57551 .41362 .57085 Metetra
0 .023 .121 r
.41362 .57085 .4185 .57551 .42679 .57299 .42192 .56831 Metetra
0 .023 .121 r
.42192 .56831 .42679 .57299 .43511 .57046 .43025 .56576 Metetra
0 .023 .121 r
.43025 .56576 .43511 .57046 .44345 .56792 .43861 .56321 Metetra
0 .023 .121 r
.43861 .56321 .44345 .56792 .45182 .56537 .44699 .56065 Metetra
0 .023 .121 r
.44699 .56065 .45182 .56537 .46021 .56282 .4554 .55808 Metetra
0 .023 .121 r
.4554 .55808 .46021 .56282 .46863 .56025 .46384 .5555 Metetra
0 .023 .121 r
.46384 .5555 .46863 .56025 .47707 .55768 .4723 .55291 Metetra
0 .023 .121 r
.4723 .55291 .47707 .55768 .48554 .5551 .48079 .55032 Metetra
0 .023 .121 r
.48079 .55032 .48554 .5551 .49404 .55251 .4893 .54772 Metetra
0 .023 .121 r
.4893 .54772 .49404 .55251 .50256 .54992 .49784 .54511 Metetra
0 .023 .121 r
.49784 .54511 .50256 .54992 .51111 .54732 .50641 .54249 Metetra
0 .023 .121 r
.50641 .54249 .51111 .54732 .51969 .5447 .51501 .53986 Metetra
0 .023 .121 r
.51501 .53986 .51969 .5447 .5283 .54208 .52363 .53723 Metetra
0 .023 .121 r
.52363 .53723 .5283 .54208 .53693 .53946 .53228 .53458 Metetra
0 .023 .121 r
.53228 .53458 .53693 .53946 .54558 .53682 .54095 .53193 Metetra
0 .023 .121 r
.54095 .53193 .54558 .53682 .55427 .53418 .54966 .52927 Metetra
0 .023 .121 r
.54966 .52927 .55427 .53418 .56298 .53152 .55839 .5266 Metetra
0 .023 .121 r
.55839 .5266 .56298 .53152 .57172 .52886 .56714 .52393 Metetra
0 .023 .121 r
.56714 .52393 .57172 .52886 .58049 .52619 .57593 .52124 Metetra
0 .023 .121 r
.57593 .52124 .58049 .52619 .58929 .52351 .58475 .51855 Metetra
0 .023 .121 r
.58475 .51855 .58929 .52351 .59811 .52083 .59359 .51584 Metetra
0 .023 .121 r
.59359 .51584 .59811 .52083 .60696 .51813 .60246 .51313 Metetra
0 .023 .121 r
.60246 .51313 .60696 .51813 .61584 .51543 .61136 .51041 Metetra
0 .023 .121 r
.61136 .51041 .61584 .51543 .62475 .51272 .62028 .50769 Metetra
0 .023 .121 r
.62028 .50769 .62475 .51272 .63369 .51 .62924 .50495 Metetra
0 .023 .121 r
.62924 .50495 .63369 .51 .64265 .50727 .63822 .5022 Metetra
0 .023 .122 r
.63822 .5022 .64265 .50727 .65165 .50459 .64724 .49945 Metetra
0 .024 .122 r
.64724 .49945 .65165 .50459 .66067 .50185 .65628 .49669 Metetra
0 .023 .122 r
.65628 .49669 .66067 .50185 .66972 .49903 .66535 .49391 Metetra
0 .023 .121 r
.66535 .49391 .66972 .49903 .6788 .49626 .67445 .49113 Metetra
0 .023 .121 r
.67445 .49113 .6788 .49626 .68791 .49348 .68358 .48834 Metetra
0 .023 .121 r
.68358 .48834 .68791 .49348 .69705 .4907 .69274 .48554 Metetra
0 .023 .121 r
.69274 .48554 .69705 .4907 .70622 .48791 .70193 .48273 Metetra
0 .023 .121 r
.70193 .48273 .70622 .48791 .71542 .48511 .71115 .47991 Metetra
0 .023 .121 r
.71115 .47991 .71542 .48511 .72464 .4823 .7204 .47709 Metetra
0 .023 .121 r
.7204 .47709 .72464 .4823 .7339 .47948 .72968 .47425 Metetra
0 .023 .121 r
.72968 .47425 .7339 .47948 .74319 .47665 .73899 .47141 Metetra
0 .023 .121 r
.73899 .47141 .74319 .47665 .75251 .47381 .74833 .46855 Metetra
0 .023 .121 r
.74833 .46855 .75251 .47381 .76186 .47097 .7577 .46569 Metetra
0 .023 .121 r
.7577 .46569 .76186 .47097 .77124 .46811 .7671 .46281 Metetra
0 .023 .121 r
.7671 .46281 .77124 .46811 .78065 .46525 .77653 .45993 Metetra
0 .023 .121 r
.77653 .45993 .78065 .46525 .79009 .46237 .786 .45704 Metetra
0 .023 .121 r
.786 .45704 .79009 .46237 .79956 .45949 .79549 .45414 Metetra
0 .023 .121 r
.79549 .45414 .79956 .45949 .80907 .45659 .80502 .45123 Metetra
0 .023 .121 r
.80502 .45123 .80907 .45659 .8186 .45369 .81457 .44831 Metetra
0 .023 .121 r
.81457 .44831 .8186 .45369 .82817 .45078 .82416 .44537 Metetra
0 .023 .121 r
.82416 .44537 .82817 .45078 .83777 .44786 .83378 .44243 Metetra
0 .023 .121 r
.83378 .44243 .83777 .44786 .8474 .44492 .84344 .43948 Metetra
0 .023 .121 r
.84344 .43948 .8474 .44492 .85706 .44198 .85312 .43652 Metetra
0 .023 .121 r
.85312 .43652 .85706 .44198 .86675 .43903 .86284 .43355 Metetra
0 .023 .121 r
.86284 .43355 .86675 .43903 .87648 .43607 .87259 .43057 Metetra
0 .023 .121 r
.87259 .43057 .87648 .43607 .88624 .4331 .88237 .42759 Metetra
0 .023 .121 r
.88237 .42759 .88624 .4331 .89603 .43012 .89218 .42459 Metetra
0 .023 .121 r
.89218 .42459 .89603 .43012 .90585 .42712 .90203 .42158 Metetra
0 .023 .121 r
.90203 .42158 .90585 .42712 .91571 .42412 .91191 .41856 Metetra
0 .023 .121 r
.91191 .41856 .91571 .42412 .9256 .42111 .92183 .41553 Metetra
0 .023 .121 r
.92183 .41553 .9256 .42111 .93552 .41809 .93178 .41249 Metetra
0 .023 .121 r
.93178 .41249 .93552 .41809 .94548 .41506 .94176 .40943 Metetra
0 .023 .121 r
.94176 .40943 .94548 .41506 .95547 .41202 .95177 .40637 Metetra
0 .023 .121 r
.37567 .57629 .38065 .58092 .38885 .57842 .38389 .57377 Metetra
0 .023 .121 r
.38389 .57377 .38885 .57842 .39708 .5759 .39213 .57124 Metetra
0 .023 .121 r
.39213 .57124 .39708 .5759 .40534 .57338 .40041 .5687 Metetra
0 .023 .121 r
.40041 .5687 .40534 .57338 .41362 .57085 .4087 .56616 Metetra
0 .023 .121 r
.4087 .56616 .41362 .57085 .42192 .56831 .41702 .5636 Metetra
0 .023 .121 r
.41702 .5636 .42192 .56831 .43025 .56576 .42537 .56104 Metetra
0 .023 .121 r
.42537 .56104 .43025 .56576 .43861 .56321 .43374 .55847 Metetra
0 .023 .121 r
.43374 .55847 .43861 .56321 .44699 .56065 .44214 .5559 Metetra
0 .023 .121 r
.44214 .5559 .44699 .56065 .4554 .55808 .45057 .55331 Metetra
0 .023 .121 r
.45057 .55331 .4554 .55808 .46384 .5555 .45902 .55072 Metetra
0 .023 .121 r
.45902 .55072 .46384 .5555 .4723 .55291 .4675 .54812 Metetra
0 .023 .121 r
.4675 .54812 .4723 .55291 .48079 .55032 .47601 .54551 Metetra
0 .023 .121 r
.47601 .54551 .48079 .55032 .4893 .54772 .48454 .54289 Metetra
0 .023 .121 r
.48454 .54289 .4893 .54772 .49784 .54511 .4931 .54027 Metetra
0 .023 .121 r
.4931 .54027 .49784 .54511 .50641 .54249 .50168 .53763 Metetra
0 .023 .121 r
.50168 .53763 .50641 .54249 .51501 .53986 .51029 .53499 Metetra
0 .023 .121 r
.51029 .53499 .51501 .53986 .52363 .53723 .51893 .53234 Metetra
0 .023 .121 r
.51893 .53234 .52363 .53723 .53228 .53458 .5276 .52968 Metetra
0 .023 .121 r
.5276 .52968 .53228 .53458 .54095 .53193 .53629 .52701 Metetra
0 .023 .121 r
.53629 .52701 .54095 .53193 .54966 .52927 .54501 .52434 Metetra
0 .023 .121 r
.54501 .52434 .54966 .52927 .55839 .5266 .55376 .52165 Metetra
0 .023 .121 r
.55376 .52165 .55839 .5266 .56714 .52393 .56254 .51896 Metetra
0 .023 .121 r
.56254 .51896 .56714 .52393 .57593 .52124 .57134 .51626 Metetra
0 .023 .121 r
.57134 .51626 .57593 .52124 .58475 .51855 .58018 .51355 Metetra
0 .023 .121 r
.58018 .51355 .58475 .51855 .59359 .51584 .58904 .51083 Metetra
0 .023 .121 r
.58904 .51083 .59359 .51584 .60246 .51313 .59793 .50811 Metetra
0 .023 .121 r
.59793 .50811 .60246 .51313 .61136 .51041 .60684 .50537 Metetra
0 .023 .121 r
.60684 .50537 .61136 .51041 .62028 .50769 .61579 .50263 Metetra
0 .023 .121 r
.61579 .50263 .62028 .50769 .62924 .50495 .62477 .49988 Metetra
0 .023 .121 r
.62477 .49988 .62924 .50495 .63822 .5022 .63377 .49712 Metetra
0 .023 .122 r
.63377 .49712 .63822 .5022 .64724 .49945 .64281 .49441 Metetra
0 .024 .122 r
.64281 .49441 .64724 .49945 .65628 .49669 .65187 .49163 Metetra
0 .023 .122 r
.65187 .49163 .65628 .49669 .66535 .49391 .66096 .48878 Metetra
0 .023 .121 r
.66096 .48878 .66535 .49391 .67445 .49113 .67008 .48598 Metetra
0 .023 .121 r
.67008 .48598 .67445 .49113 .68358 .48834 .67923 .48316 Metetra
0 .023 .121 r
.67923 .48316 .68358 .48834 .69274 .48554 .68841 .48035 Metetra
0 .023 .121 r
.68841 .48035 .69274 .48554 .70193 .48273 .69762 .47752 Metetra
0 .023 .121 r
.69762 .47752 .70193 .48273 .71115 .47991 .70686 .47469 Metetra
0 .023 .121 r
.70686 .47469 .71115 .47991 .7204 .47709 .71613 .47185 Metetra
0 .023 .121 r
.71613 .47185 .7204 .47709 .72968 .47425 .72543 .46899 Metetra
0 .023 .121 r
.72543 .46899 .72968 .47425 .73899 .47141 .73476 .46613 Metetra
0 .023 .121 r
.73476 .46613 .73899 .47141 .74833 .46855 .74412 .46326 Metetra
0 .023 .121 r
.74412 .46326 .74833 .46855 .7577 .46569 .75351 .46038 Metetra
0 .023 .121 r
.75351 .46038 .7577 .46569 .7671 .46281 .76293 .45749 Metetra
0 .023 .121 r
.76293 .45749 .7671 .46281 .77653 .45993 .77239 .45458 Metetra
0 .023 .121 r
.77239 .45458 .77653 .45993 .786 .45704 .78187 .45168 Metetra
0 .023 .121 r
.78187 .45168 .786 .45704 .79549 .45414 .79139 .44876 Metetra
0 .023 .121 r
.79139 .44876 .79549 .45414 .80502 .45123 .80094 .44583 Metetra
0 .023 .121 r
.80094 .44583 .80502 .45123 .81457 .44831 .81052 .44289 Metetra
0 .023 .121 r
.81052 .44289 .81457 .44831 .82416 .44537 .82013 .43994 Metetra
0 .023 .121 r
.82013 .43994 .82416 .44537 .83378 .44243 .82977 .43698 Metetra
0 .023 .121 r
.82977 .43698 .83378 .44243 .84344 .43948 .83945 .43401 Metetra
0 .023 .121 r
.83945 .43401 .84344 .43948 .85312 .43652 .84916 .43103 Metetra
0 .023 .121 r
.84916 .43103 .85312 .43652 .86284 .43355 .8589 .42805 Metetra
0 .023 .121 r
.8589 .42805 .86284 .43355 .87259 .43057 .86867 .42505 Metetra
0 .023 .121 r
.86867 .42505 .87259 .43057 .88237 .42759 .87848 .42204 Metetra
0 .023 .121 r
.87848 .42204 .88237 .42759 .89218 .42459 .88832 .41902 Metetra
0 .023 .121 r
.88832 .41902 .89218 .42459 .90203 .42158 .89819 .41599 Metetra
0 .023 .121 r
.89819 .41599 .90203 .42158 .91191 .41856 .90809 .41295 Metetra
0 .023 .121 r
.90809 .41295 .91191 .41856 .92183 .41553 .91803 .4099 Metetra
0 .023 .121 r
.91803 .4099 .92183 .41553 .93178 .41249 .92801 .40685 Metetra
0 .023 .121 r
.92801 .40685 .93178 .41249 .94176 .40943 .93801 .40378 Metetra
0 .023 .121 r
.93801 .40378 .94176 .40943 .95177 .40637 .94805 .4007 Metetra
0 .023 .121 r
.37066 .57163 .37567 .57629 .38389 .57377 .3789 .56909 Metetra
0 .023 .121 r
.3789 .56909 .38389 .57377 .39213 .57124 .38716 .56655 Metetra
0 .023 .121 r
.38716 .56655 .39213 .57124 .40041 .5687 .39545 .564 Metetra
0 .023 .121 r
.39545 .564 .40041 .5687 .4087 .56616 .40376 .56144 Metetra
0 .023 .121 r
.40376 .56144 .4087 .56616 .41702 .5636 .4121 .55887 Metetra
0 .023 .121 r
.4121 .55887 .41702 .5636 .42537 .56104 .42046 .55629 Metetra
0 .023 .121 r
.42046 .55629 .42537 .56104 .43374 .55847 .42885 .55371 Metetra
0 .023 .121 r
.42885 .55371 .43374 .55847 .44214 .5559 .43727 .55112 Metetra
0 .023 .121 r
.43727 .55112 .44214 .5559 .45057 .55331 .44571 .54852 Metetra
0 .023 .121 r
.44571 .54852 .45057 .55331 .45902 .55072 .45418 .54591 Metetra
0 .023 .121 r
.45418 .54591 .45902 .55072 .4675 .54812 .46267 .54329 Metetra
0 .023 .121 r
.46267 .54329 .4675 .54812 .47601 .54551 .4712 .54067 Metetra
0 .023 .121 r
.4712 .54067 .47601 .54551 .48454 .54289 .47974 .53804 Metetra
0 .023 .121 r
.47974 .53804 .48454 .54289 .4931 .54027 .48832 .5354 Metetra
0 .023 .121 r
.48832 .5354 .4931 .54027 .50168 .53763 .49692 .53275 Metetra
0 .023 .121 r
.49692 .53275 .50168 .53763 .51029 .53499 .50555 .53009 Metetra
0 .023 .121 r
.50555 .53009 .51029 .53499 .51893 .53234 .51421 .52742 Metetra
0 .023 .121 r
.51421 .52742 .51893 .53234 .5276 .52968 .52289 .52475 Metetra
0 .023 .121 r
.52289 .52475 .5276 .52968 .53629 .52701 .5316 .52207 Metetra
0 .023 .121 r
.5316 .52207 .53629 .52701 .54501 .52434 .54034 .51938 Metetra
0 .023 .121 r
.54034 .51938 .54501 .52434 .55376 .52165 .54911 .51668 Metetra
0 .023 .121 r
.54911 .51668 .55376 .52165 .56254 .51896 .55791 .51397 Metetra
0 .023 .121 r
.55791 .51397 .56254 .51896 .57134 .51626 .56673 .51125 Metetra
0 .023 .121 r
.56673 .51125 .57134 .51626 .58018 .51355 .57558 .50853 Metetra
0 .023 .121 r
.57558 .50853 .58018 .51355 .58904 .51083 .58446 .50579 Metetra
0 .023 .121 r
.58446 .50579 .58904 .51083 .59793 .50811 .59337 .50305 Metetra
0 .023 .121 r
.59337 .50305 .59793 .50811 .60684 .50537 .60231 .5003 Metetra
0 .023 .121 r
.60231 .5003 .60684 .50537 .61579 .50263 .61127 .49754 Metetra
0 .023 .121 r
.61127 .49754 .61579 .50263 .62477 .49988 .62027 .49477 Metetra
0 .023 .121 r
.62027 .49477 .62477 .49988 .63377 .49712 .62929 .49199 Metetra
0 .024 .122 r
.62929 .49199 .63377 .49712 .64281 .49441 .63834 .48925 Metetra
0 .024 .122 r
.63834 .48925 .64281 .49441 .65187 .49163 .64743 .48645 Metetra
0 .024 .122 r
.64743 .48645 .65187 .49163 .66096 .48878 .65654 .4836 Metetra
0 .023 .121 r
.65654 .4836 .66096 .48878 .67008 .48598 .66568 .48079 Metetra
0 .023 .121 r
.66568 .48079 .67008 .48598 .67923 .48316 .67485 .47796 Metetra
0 .023 .121 r
.67485 .47796 .67923 .48316 .68841 .48035 .68405 .47513 Metetra
0 .023 .121 r
.68405 .47513 .68841 .48035 .69762 .47752 .69328 .47228 Metetra
0 .023 .121 r
.69328 .47228 .69762 .47752 .70686 .47469 .70254 .46943 Metetra
0 .023 .121 r
.70254 .46943 .70686 .47469 .71613 .47185 .71183 .46657 Metetra
0 .023 .121 r
.71183 .46657 .71613 .47185 .72543 .46899 .72115 .4637 Metetra
0 .023 .121 r
.72115 .4637 .72543 .46899 .73476 .46613 .7305 .46082 Metetra
0 .023 .121 r
.7305 .46082 .73476 .46613 .74412 .46326 .73989 .45793 Metetra
0 .023 .121 r
.73989 .45793 .74412 .46326 .75351 .46038 .7493 .45503 Metetra
0 .023 .121 r
.7493 .45503 .75351 .46038 .76293 .45749 .75874 .45212 Metetra
0 .023 .121 r
.75874 .45212 .76293 .45749 .77239 .45458 .76822 .44921 Metetra
0 .023 .121 r
.76822 .44921 .77239 .45458 .78187 .45168 .77773 .44628 Metetra
0 .023 .121 r
.77773 .44628 .78187 .45168 .79139 .44876 .78727 .44334 Metetra
0 .023 .121 r
.78727 .44334 .79139 .44876 .80094 .44583 .79684 .44039 Metetra
0 .023 .121 r
.79684 .44039 .80094 .44583 .81052 .44289 .80644 .43744 Metetra
0 .023 .121 r
.80644 .43744 .81052 .44289 .82013 .43994 .81607 .43447 Metetra
0 .023 .121 r
.81607 .43447 .82013 .43994 .82977 .43698 .82574 .43149 Metetra
0 .023 .121 r
.82574 .43149 .82977 .43698 .83945 .43401 .83544 .42851 Metetra
0 .023 .121 r
.83544 .42851 .83945 .43401 .84916 .43103 .84517 .42551 Metetra
0 .023 .121 r
.84517 .42551 .84916 .43103 .8589 .42805 .85494 .4225 Metetra
0 .023 .121 r
.85494 .4225 .8589 .42805 .86867 .42505 .86473 .41949 Metetra
0 .023 .121 r
.86473 .41949 .86867 .42505 .87848 .42204 .87456 .41646 Metetra
0 .023 .121 r
.87456 .41646 .87848 .42204 .88832 .41902 .88443 .41342 Metetra
0 .023 .121 r
.88443 .41342 .88832 .41902 .89819 .41599 .89432 .41037 Metetra
0 .023 .121 r
.89432 .41037 .89819 .41599 .90809 .41295 .90425 .40732 Metetra
0 .023 .121 r
.90425 .40732 .90809 .41295 .91803 .4099 .91421 .40425 Metetra
0 .023 .121 r
.91421 .40425 .91803 .4099 .92801 .40685 .92421 .40117 Metetra
0 .023 .121 r
.92421 .40117 .92801 .40685 .93801 .40378 .93424 .39808 Metetra
0 .023 .121 r
.93424 .39808 .93801 .40378 .94805 .4007 .94431 .39498 Metetra
0 .023 .121 r
.36563 .56694 .37066 .57163 .3789 .56909 .37388 .56439 Metetra
0 .023 .121 r
.37388 .56439 .3789 .56909 .38716 .56655 .38216 .56183 Metetra
0 .023 .121 r
.38216 .56183 .38716 .56655 .39545 .564 .39046 .55926 Metetra
0 .023 .121 r
.39046 .55926 .39545 .564 .40376 .56144 .39879 .55669 Metetra
0 .023 .121 r
.39879 .55669 .40376 .56144 .4121 .55887 .40714 .55411 Metetra
0 .023 .121 r
.40714 .55411 .4121 .55887 .42046 .55629 .41552 .55152 Metetra
0 .023 .121 r
.41552 .55152 .42046 .55629 .42885 .55371 .42393 .54892 Metetra
0 .023 .121 r
.42393 .54892 .42885 .55371 .43727 .55112 .43236 .54631 Metetra
0 .023 .121 r
.43236 .54631 .43727 .55112 .44571 .54852 .44082 .5437 Metetra
0 .023 .121 r
.44082 .5437 .44571 .54852 .45418 .54591 .44931 .54107 Metetra
0 .023 .121 r
.44931 .54107 .45418 .54591 .46267 .54329 .45782 .53844 Metetra
0 .023 .121 r
.45782 .53844 .46267 .54329 .4712 .54067 .46636 .5358 Metetra
0 .023 .121 r
.46636 .5358 .4712 .54067 .47974 .53804 .47492 .53316 Metetra
0 .023 .121 r
.47492 .53316 .47974 .53804 .48832 .5354 .48352 .5305 Metetra
0 .023 .121 r
.48352 .5305 .48832 .5354 .49692 .53275 .49214 .52784 Metetra
0 .023 .121 r
.49214 .52784 .49692 .53275 .50555 .53009 .50078 .52516 Metetra
0 .023 .121 r
.50078 .52516 .50555 .53009 .51421 .52742 .50946 .52248 Metetra
0 .023 .121 r
.50946 .52248 .51421 .52742 .52289 .52475 .51816 .51979 Metetra
0 .023 .121 r
.51816 .51979 .52289 .52475 .5316 .52207 .52689 .51709 Metetra
0 .023 .121 r
.52689 .51709 .5316 .52207 .54034 .51938 .53565 .51439 Metetra
0 .023 .121 r
.53565 .51439 .54034 .51938 .54911 .51668 .54443 .51167 Metetra
0 .023 .121 r
.54443 .51167 .54911 .51668 .55791 .51397 .55325 .50895 Metetra
0 .023 .121 r
.55325 .50895 .55791 .51397 .56673 .51125 .56209 .50621 Metetra
0 .023 .121 r
.56209 .50621 .56673 .51125 .57558 .50853 .57096 .50347 Metetra
0 .023 .121 r
.57096 .50347 .57558 .50853 .58446 .50579 .57986 .50072 Metetra
0 .023 .121 r
.57986 .50072 .58446 .50579 .59337 .50305 .58878 .49796 Metetra
0 .023 .121 r
.58878 .49796 .59337 .50305 .60231 .5003 .59774 .49519 Metetra
0 .023 .121 r
.59774 .49519 .60231 .5003 .61127 .49754 .60673 .49242 Metetra
0 .023 .121 r
.60673 .49242 .61127 .49754 .62027 .49477 .61574 .48963 Metetra
0 .023 .121 r
.61574 .48963 .62027 .49477 .62929 .49199 .62478 .48684 Metetra
0 .023 .122 r
.62478 .48684 .62929 .49199 .63834 .48925 .63386 .48407 Metetra
0 .024 .122 r
.63386 .48407 .63834 .48925 .64743 .48645 .64296 .48125 Metetra
0 .023 .122 r
.64296 .48125 .64743 .48645 .65654 .4836 .65209 .4784 Metetra
0 .023 .121 r
.65209 .4784 .65654 .4836 .66568 .48079 .66125 .47556 Metetra
0 .023 .121 r
.66125 .47556 .66568 .48079 .67485 .47796 .67044 .47272 Metetra
0 .023 .121 r
.67044 .47272 .67485 .47796 .68405 .47513 .67966 .46987 Metetra
0 .023 .121 r
.67966 .46987 .68405 .47513 .69328 .47228 .68891 .46701 Metetra
0 .023 .121 r
.68891 .46701 .69328 .47228 .70254 .46943 .69819 .46414 Metetra
0 .023 .121 r
.69819 .46414 .70254 .46943 .71183 .46657 .70751 .46126 Metetra
0 .023 .121 r
.70751 .46126 .71183 .46657 .72115 .4637 .71685 .45838 Metetra
0 .023 .121 r
.71685 .45838 .72115 .4637 .7305 .46082 .72622 .45548 Metetra
0 .023 .121 r
.72622 .45548 .7305 .46082 .73989 .45793 .73563 .45257 Metetra
0 .023 .121 r
.73563 .45257 .73989 .45793 .7493 .45503 .74506 .44965 Metetra
0 .023 .121 r
.74506 .44965 .7493 .45503 .75874 .45212 .75453 .44673 Metetra
0 .023 .121 r
.75453 .44673 .75874 .45212 .76822 .44921 .76403 .44379 Metetra
0 .023 .121 r
.76403 .44379 .76822 .44921 .77773 .44628 .77356 .44085 Metetra
0 .023 .121 r
.77356 .44085 .77773 .44628 .78727 .44334 .78312 .43789 Metetra
0 .023 .121 r
.78312 .43789 .78727 .44334 .79684 .44039 .79271 .43493 Metetra
0 .023 .121 r
.79271 .43493 .79684 .44039 .80644 .43744 .80234 .43195 Metetra
0 .023 .121 r
.80234 .43195 .80644 .43744 .81607 .43447 .81199 .42897 Metetra
0 .023 .121 r
.81199 .42897 .81607 .43447 .82574 .43149 .82168 .42597 Metetra
0 .023 .121 r
.82168 .42597 .82574 .43149 .83544 .42851 .83141 .42297 Metetra
0 .023 .121 r
.83141 .42297 .83544 .42851 .84517 .42551 .84116 .41995 Metetra
0 .023 .121 r
.84116 .41995 .84517 .42551 .85494 .4225 .85095 .41693 Metetra
0 .023 .121 r
.85095 .41693 .85494 .4225 .86473 .41949 .86077 .41389 Metetra
0 .023 .121 r
.86077 .41389 .86473 .41949 .87456 .41646 .87062 .41084 Metetra
0 .023 .121 r
.87062 .41084 .87456 .41646 .88443 .41342 .88051 .40779 Metetra
0 .023 .121 r
.88051 .40779 .88443 .41342 .89432 .41037 .89043 .40472 Metetra
0 .023 .121 r
.89043 .40472 .89432 .41037 .90425 .40732 .90038 .40164 Metetra
0 .023 .121 r
.90038 .40164 .90425 .40732 .91421 .40425 .91037 .39856 Metetra
0 .023 .121 r
.91037 .39856 .91421 .40425 .92421 .40117 .92039 .39546 Metetra
0 .023 .121 r
.92039 .39546 .92421 .40117 .93424 .39808 .93045 .39235 Metetra
0 .023 .121 r
.93045 .39235 .93424 .39808 .94431 .39498 .94054 .38923 Metetra
0 .023 .121 r
.36056 .56222 .36563 .56694 .37388 .56439 .36883 .55966 Metetra
0 .023 .121 r
.36883 .55966 .37388 .56439 .38216 .56183 .37712 .55709 Metetra
0 .023 .121 r
.37712 .55709 .38216 .56183 .39046 .55926 .38544 .5545 Metetra
0 .023 .121 r
.38544 .5545 .39046 .55926 .39879 .55669 .39379 .55192 Metetra
0 .023 .121 r
.39379 .55192 .39879 .55669 .40714 .55411 .40216 .54932 Metetra
0 .023 .121 r
.40216 .54932 .40714 .55411 .41552 .55152 .41055 .54671 Metetra
0 .023 .121 r
.41055 .54671 .41552 .55152 .42393 .54892 .41898 .5441 Metetra
0 .023 .121 r
.41898 .5441 .42393 .54892 .43236 .54631 .42743 .54148 Metetra
0 .023 .121 r
.42743 .54148 .43236 .54631 .44082 .5437 .4359 .53885 Metetra
0 .023 .121 r
.4359 .53885 .44082 .5437 .44931 .54107 .44441 .53621 Metetra
0 .023 .121 r
.44441 .53621 .44931 .54107 .45782 .53844 .45293 .53356 Metetra
0 .023 .121 r
.45293 .53356 .45782 .53844 .46636 .5358 .46149 .53091 Metetra
0 .023 .121 r
.46149 .53091 .46636 .5358 .47492 .53316 .47007 .52825 Metetra
0 .023 .121 r
.47007 .52825 .47492 .53316 .48352 .5305 .47868 .52557 Metetra
0 .023 .121 r
.47868 .52557 .48352 .5305 .49214 .52784 .48732 .52289 Metetra
0 .023 .121 r
.48732 .52289 .49214 .52784 .50078 .52516 .49599 .52021 Metetra
0 .023 .121 r
.49599 .52021 .50078 .52516 .50946 .52248 .50468 .51751 Metetra
0 .023 .121 r
.50468 .51751 .50946 .52248 .51816 .51979 .5134 .5148 Metetra
0 .023 .121 r
.5134 .5148 .51816 .51979 .52689 .51709 .52215 .51209 Metetra
0 .023 .121 r
.52215 .51209 .52689 .51709 .53565 .51439 .53092 .50937 Metetra
0 .023 .121 r
.53092 .50937 .53565 .51439 .54443 .51167 .53973 .50663 Metetra
0 .023 .121 r
.53973 .50663 .54443 .51167 .55325 .50895 .54856 .50389 Metetra
0 .023 .121 r
.54856 .50389 .55325 .50895 .56209 .50621 .55742 .50114 Metetra
0 .023 .121 r
.55742 .50114 .56209 .50621 .57096 .50347 .56631 .49839 Metetra
0 .023 .121 r
.56631 .49839 .57096 .50347 .57986 .50072 .57523 .49562 Metetra
0 .023 .121 r
.57523 .49562 .57986 .50072 .58878 .49796 .58417 .49284 Metetra
0 .023 .121 r
.58417 .49284 .58878 .49796 .59774 .49519 .59315 .49006 Metetra
0 .023 .121 r
.59315 .49006 .59774 .49519 .60673 .49242 .60215 .48726 Metetra
0 .023 .121 r
.60215 .48726 .60673 .49242 .61574 .48963 .61119 .48447 Metetra
0 .023 .121 r
.61119 .48447 .61574 .48963 .62478 .48684 .62025 .48166 Metetra
0 .024 .122 r
.62025 .48166 .62478 .48684 .63386 .48407 .62934 .47893 Metetra
0 .024 .122 r
.62934 .47893 .63386 .48407 .64296 .48125 .63847 .4761 Metetra
0 .024 .122 r
.63847 .4761 .64296 .48125 .65209 .4784 .64762 .47317 Metetra
0 .023 .121 r
.64762 .47317 .65209 .4784 .66125 .47556 .6568 .47032 Metetra
0 .023 .121 r
.6568 .47032 .66125 .47556 .67044 .47272 .66601 .46745 Metetra
0 .023 .121 r
.66601 .46745 .67044 .47272 .67966 .46987 .67525 .46459 Metetra
0 .023 .121 r
.67525 .46459 .67966 .46987 .68891 .46701 .68452 .46171 Metetra
0 .023 .121 r
.68452 .46171 .68891 .46701 .69819 .46414 .69382 .45882 Metetra
0 .023 .121 r
.69382 .45882 .69819 .46414 .70751 .46126 .70316 .45593 Metetra
0 .023 .121 r
.70316 .45593 .70751 .46126 .71685 .45838 .71252 .45302 Metetra
0 .023 .121 r
.71252 .45302 .71685 .45838 .72622 .45548 .72192 .4501 Metetra
0 .023 .121 r
.72192 .4501 .72622 .45548 .73563 .45257 .73134 .44718 Metetra
0 .023 .121 r
.73134 .44718 .73563 .45257 .74506 .44965 .7408 .44425 Metetra
0 .023 .121 r
.7408 .44425 .74506 .44965 .75453 .44673 .75029 .4413 Metetra
0 .023 .121 r
.75029 .4413 .75453 .44673 .76403 .44379 .75981 .43835 Metetra
0 .023 .121 r
.75981 .43835 .76403 .44379 .77356 .44085 .76936 .43538 Metetra
0 .023 .121 r
.76936 .43538 .77356 .44085 .78312 .43789 .77894 .43241 Metetra
0 .023 .121 r
.77894 .43241 .78312 .43789 .79271 .43493 .78856 .42943 Metetra
0 .023 .121 r
.78856 .42943 .79271 .43493 .80234 .43195 .79821 .42643 Metetra
0 .023 .121 r
.79821 .42643 .80234 .43195 .81199 .42897 .80789 .42343 Metetra
0 .023 .121 r
.80789 .42343 .81199 .42897 .82168 .42597 .8176 .42042 Metetra
0 .023 .121 r
.8176 .42042 .82168 .42597 .83141 .42297 .82735 .41739 Metetra
0 .023 .121 r
.82735 .41739 .83141 .42297 .84116 .41995 .83712 .41436 Metetra
0 .023 .121 r
.83712 .41436 .84116 .41995 .85095 .41693 .84693 .41131 Metetra
0 .023 .121 r
.84693 .41131 .85095 .41693 .86077 .41389 .85678 .40826 Metetra
0 .023 .121 r
.85678 .40826 .86077 .41389 .87062 .41084 .86666 .40519 Metetra
0 .023 .121 r
.86666 .40519 .87062 .41084 .88051 .40779 .87657 .40212 Metetra
0 .023 .121 r
.87657 .40212 .88051 .40779 .89043 .40472 .88651 .39903 Metetra
0 .023 .121 r
.88651 .39903 .89043 .40472 .90038 .40164 .89649 .39594 Metetra
0 .023 .121 r
.89649 .39594 .90038 .40164 .91037 .39856 .90651 .39283 Metetra
0 .023 .121 r
.90651 .39283 .91037 .39856 .92039 .39546 .91655 .38971 Metetra
0 .023 .121 r
.91655 .38971 .92039 .39546 .93045 .39235 .92663 .38658 Metetra
0 .023 .121 r
.92663 .38658 .93045 .39235 .94054 .38923 .93675 .38345 Metetra
0 .023 .121 r
.35547 .55748 .36056 .56222 .36883 .55966 .36375 .5549 Metetra
0 .023 .121 r
.36375 .5549 .36883 .55966 .37712 .55709 .37206 .55231 Metetra
0 .023 .121 r
.37206 .55231 .37712 .55709 .38544 .5545 .3804 .54972 Metetra
0 .023 .121 r
.3804 .54972 .38544 .5545 .39379 .55192 .38876 .54711 Metetra
0 .023 .121 r
.38876 .54711 .39379 .55192 .40216 .54932 .39715 .5445 Metetra
0 .023 .121 r
.39715 .5445 .40216 .54932 .41055 .54671 .40556 .54188 Metetra
0 .023 .121 r
.40556 .54188 .41055 .54671 .41898 .5441 .414 .53925 Metetra
0 .023 .121 r
.414 .53925 .41898 .5441 .42743 .54148 .42246 .53662 Metetra
0 .023 .121 r
.42246 .53662 .42743 .54148 .4359 .53885 .43096 .53397 Metetra
0 .023 .121 r
.43096 .53397 .4359 .53885 .44441 .53621 .43948 .53132 Metetra
0 .023 .121 r
.43948 .53132 .44441 .53621 .45293 .53356 .44802 .52866 Metetra
0 .023 .121 r
.44802 .52866 .45293 .53356 .46149 .53091 .4566 .52599 Metetra
0 .023 .121 r
.4566 .52599 .46149 .53091 .47007 .52825 .4652 .52331 Metetra
0 .023 .121 r
.4652 .52331 .47007 .52825 .47868 .52557 .47382 .52062 Metetra
0 .023 .121 r
.47382 .52062 .47868 .52557 .48732 .52289 .48248 .51792 Metetra
0 .023 .121 r
.48248 .51792 .48732 .52289 .49599 .52021 .49116 .51522 Metetra
0 .023 .121 r
.49116 .51522 .49599 .52021 .50468 .51751 .49987 .51251 Metetra
0 .023 .121 r
.49987 .51251 .50468 .51751 .5134 .5148 .50861 .50978 Metetra
0 .023 .121 r
.50861 .50978 .5134 .5148 .52215 .51209 .51738 .50705 Metetra
0 .023 .121 r
.51738 .50705 .52215 .51209 .53092 .50937 .52617 .50432 Metetra
0 .023 .121 r
.52617 .50432 .53092 .50937 .53973 .50663 .53499 .50157 Metetra
0 .023 .121 r
.53499 .50157 .53973 .50663 .54856 .50389 .54384 .49881 Metetra
0 .023 .121 r
.54384 .49881 .54856 .50389 .55742 .50114 .55272 .49604 Metetra
0 .023 .121 r
.55272 .49604 .55742 .50114 .56631 .49839 .56163 .49327 Metetra
0 .023 .121 r
.56163 .49327 .56631 .49839 .57523 .49562 .57057 .49049 Metetra
0 .023 .121 r
.57057 .49049 .57523 .49562 .58417 .49284 .57953 .48769 Metetra
0 .023 .121 r
.57953 .48769 .58417 .49284 .59315 .49006 .58853 .48489 Metetra
0 .023 .121 r
.58853 .48489 .59315 .49006 .60215 .48726 .59755 .48208 Metetra
0 .023 .121 r
.59755 .48208 .60215 .48726 .61119 .48447 .60661 .47926 Metetra
0 .023 .121 r
.60661 .47926 .61119 .48447 .62025 .48166 .61569 .47644 Metetra
0 .024 .122 r
.61569 .47644 .62025 .48166 .62934 .47893 .6248 .47361 Metetra
0 .024 .122 r
.6248 .47361 .62934 .47893 .63847 .4761 .63394 .47076 Metetra
0 .024 .122 r
.63394 .47076 .63847 .4761 .64762 .47317 .64311 .46789 Metetra
0 .023 .121 r
.64311 .46789 .64762 .47317 .6568 .47032 .65232 .46503 Metetra
0 .023 .121 r
.65232 .46503 .6568 .47032 .66601 .46745 .66155 .46215 Metetra
0 .023 .121 r
.66155 .46215 .66601 .46745 .67525 .46459 .67081 .45927 Metetra
0 .023 .121 r
.67081 .45927 .67525 .46459 .68452 .46171 .6801 .45637 Metetra
0 .023 .121 r
.6801 .45637 .68452 .46171 .69382 .45882 .68943 .45347 Metetra
0 .023 .121 r
.68943 .45347 .69382 .45882 .70316 .45593 .69878 .45055 Metetra
0 .023 .121 r
.69878 .45055 .70316 .45593 .71252 .45302 .70817 .44763 Metetra
0 .023 .121 r
.70817 .44763 .71252 .45302 .72192 .4501 .71758 .4447 Metetra
0 .023 .121 r
.71758 .4447 .72192 .4501 .73134 .44718 .72703 .44175 Metetra
0 .023 .121 r
.72703 .44175 .73134 .44718 .7408 .44425 .73651 .4388 Metetra
0 .023 .121 r
.73651 .4388 .7408 .44425 .75029 .4413 .74602 .43584 Metetra
0 .023 .121 r
.74602 .43584 .75029 .4413 .75981 .43835 .75556 .43287 Metetra
0 .023 .121 r
.75556 .43287 .75981 .43835 .76936 .43538 .76514 .42989 Metetra
0 .023 .121 r
.76514 .42989 .76936 .43538 .77894 .43241 .77474 .42689 Metetra
0 .023 .121 r
.77474 .42689 .77894 .43241 .78856 .42943 .78438 .42389 Metetra
0 .023 .121 r
.78438 .42389 .78856 .42943 .79821 .42643 .79405 .42088 Metetra
0 .023 .121 r
.79405 .42088 .79821 .42643 .80789 .42343 .80375 .41786 Metetra
0 .023 .121 r
.80375 .41786 .80789 .42343 .8176 .42042 .81349 .41482 Metetra
0 .023 .121 r
.81349 .41482 .8176 .42042 .82735 .41739 .82326 .41178 Metetra
0 .023 .121 r
.82326 .41178 .82735 .41739 .83712 .41436 .83306 .40873 Metetra
0 .023 .121 r
.83306 .40873 .83712 .41436 .84693 .41131 .8429 .40567 Metetra
0 .023 .121 r
.8429 .40567 .84693 .41131 .85678 .40826 .85277 .40259 Metetra
0 .023 .121 r
.85277 .40259 .85678 .40826 .86666 .40519 .86267 .39951 Metetra
0 .023 .121 r
.86267 .39951 .86666 .40519 .87657 .40212 .8726 .39641 Metetra
0 .023 .121 r
.8726 .39641 .87657 .40212 .88651 .39903 .88257 .39331 Metetra
0 .023 .121 r
.88257 .39331 .88651 .39903 .89649 .39594 .89258 .39019 Metetra
0 .023 .121 r
.89258 .39019 .89649 .39594 .90651 .39283 .90261 .38707 Metetra
0 .023 .121 r
.90261 .38707 .90651 .39283 .91655 .38971 .91269 .38393 Metetra
0 .023 .121 r
.91269 .38393 .91655 .38971 .92663 .38658 .92279 .38078 Metetra
0 .023 .121 r
.92279 .38078 .92663 .38658 .93675 .38345 .93294 .37762 Metetra
0 .023 .121 r
.35035 .55271 .35547 .55748 .36375 .5549 .35865 .55012 Metetra
0 .023 .121 r
.35865 .55012 .36375 .5549 .37206 .55231 .36697 .54752 Metetra
0 .023 .121 r
.36697 .54752 .37206 .55231 .3804 .54972 .37532 .5449 Metetra
0 .023 .121 r
.37532 .5449 .3804 .54972 .38876 .54711 .3837 .54229 Metetra
0 .023 .121 r
.3837 .54229 .38876 .54711 .39715 .5445 .3921 .53966 Metetra
0 .023 .121 r
.3921 .53966 .39715 .5445 .40556 .54188 .40053 .53702 Metetra
0 .023 .121 r
.40053 .53702 .40556 .54188 .414 .53925 .40899 .53438 Metetra
0 .023 .121 r
.40899 .53438 .414 .53925 .42246 .53662 .41747 .53173 Metetra
0 .023 .121 r
.41747 .53173 .42246 .53662 .43096 .53397 .42598 .52907 Metetra
0 .023 .121 r
.42598 .52907 .43096 .53397 .43948 .53132 .43452 .5264 Metetra
0 .023 .121 r
.43452 .5264 .43948 .53132 .44802 .52866 .44308 .52372 Metetra
0 .023 .121 r
.44308 .52372 .44802 .52866 .4566 .52599 .45167 .52103 Metetra
0 .023 .121 r
.45167 .52103 .4566 .52599 .4652 .52331 .46029 .51834 Metetra
0 .023 .121 r
.46029 .51834 .4652 .52331 .47382 .52062 .46894 .51564 Metetra
0 .023 .121 r
.46894 .51564 .47382 .52062 .48248 .51792 .47761 .51292 Metetra
0 .023 .121 r
.47761 .51292 .48248 .51792 .49116 .51522 .48631 .5102 Metetra
0 .023 .121 r
.48631 .5102 .49116 .51522 .49987 .51251 .49504 .50747 Metetra
0 .023 .121 r
.49504 .50747 .49987 .51251 .50861 .50978 .50379 .50474 Metetra
0 .023 .121 r
.50379 .50474 .50861 .50978 .51738 .50705 .51258 .50199 Metetra
0 .023 .121 r
.51258 .50199 .51738 .50705 .52617 .50432 .52139 .49924 Metetra
0 .023 .121 r
.52139 .49924 .52617 .50432 .53499 .50157 .53023 .49647 Metetra
0 .023 .121 r
.53023 .49647 .53499 .50157 .54384 .49881 .5391 .4937 Metetra
0 .023 .121 r
.5391 .4937 .54384 .49881 .55272 .49604 .548 .49092 Metetra
0 .023 .121 r
.548 .49092 .55272 .49604 .56163 .49327 .55693 .48813 Metetra
0 .023 .121 r
.55693 .48813 .56163 .49327 .57057 .49049 .56588 .48532 Metetra
0 .023 .121 r
.56588 .48532 .57057 .49049 .57953 .48769 .57487 .48252 Metetra
0 .023 .121 r
.57487 .48252 .57953 .48769 .58853 .48489 .58388 .4797 Metetra
0 .023 .121 r
.58388 .4797 .58853 .48489 .59755 .48208 .59292 .47687 Metetra
0 .023 .121 r
.59292 .47687 .59755 .48208 .60661 .47926 .602 .47404 Metetra
0 .023 .121 r
.602 .47404 .60661 .47926 .61569 .47644 .6111 .4712 Metetra
0 .024 .122 r
.6111 .4712 .61569 .47644 .6248 .47361 .62023 .46844 Metetra
0 .024 .122 r
.62023 .46844 .6248 .47361 .63394 .47076 .6294 .46557 Metetra
0 .024 .122 r
.6294 .46557 .63394 .47076 .64311 .46789 .63859 .46261 Metetra
0 .023 .121 r
.63859 .46261 .64311 .46789 .65232 .46503 .64781 .45972 Metetra
0 .023 .121 r
.64781 .45972 .65232 .46503 .66155 .46215 .65706 .45682 Metetra
0 .023 .121 r
.65706 .45682 .66155 .46215 .67081 .45927 .66634 .45392 Metetra
0 .023 .121 r
.66634 .45392 .67081 .45927 .6801 .45637 .67566 .451 Metetra
0 .023 .121 r
.67566 .451 .6801 .45637 .68943 .45347 .685 .44808 Metetra
0 .023 .121 r
.685 .44808 .68943 .45347 .69878 .45055 .69438 .44515 Metetra
0 .023 .121 r
.69438 .44515 .69878 .45055 .70817 .44763 .70378 .44221 Metetra
0 .023 .121 r
.70378 .44221 .70817 .44763 .71758 .4447 .71322 .43926 Metetra
0 .023 .121 r
.71322 .43926 .71758 .4447 .72703 .44175 .72269 .4363 Metetra
0 .023 .121 r
.72269 .4363 .72703 .44175 .73651 .4388 .73219 .43333 Metetra
0 .023 .121 r
.73219 .43333 .73651 .4388 .74602 .43584 .74173 .43035 Metetra
0 .023 .121 r
.74173 .43035 .74602 .43584 .75556 .43287 .75129 .42735 Metetra
0 .023 .121 r
.75129 .42735 .75556 .43287 .76514 .42989 .76089 .42435 Metetra
0 .023 .121 r
.76089 .42435 .76514 .42989 .77474 .42689 .77052 .42134 Metetra
0 .023 .121 r
.77052 .42134 .77474 .42689 .78438 .42389 .78018 .41832 Metetra
0 .023 .121 r
.78018 .41832 .78438 .42389 .79405 .42088 .78987 .41529 Metetra
0 .023 .121 r
.78987 .41529 .79405 .42088 .80375 .41786 .7996 .41225 Metetra
0 .023 .121 r
.7996 .41225 .80375 .41786 .81349 .41482 .80936 .4092 Metetra
0 .023 .121 r
.80936 .4092 .81349 .41482 .82326 .41178 .81915 .40614 Metetra
0 .023 .121 r
.81915 .40614 .82326 .41178 .83306 .40873 .82897 .40307 Metetra
0 .023 .121 r
.82897 .40307 .83306 .40873 .8429 .40567 .83883 .39998 Metetra
0 .023 .121 r
.83883 .39998 .8429 .40567 .85277 .40259 .84873 .39689 Metetra
0 .023 .121 r
.84873 .39689 .85277 .40259 .86267 .39951 .85865 .39379 Metetra
0 .023 .121 r
.85865 .39379 .86267 .39951 .8726 .39641 .86861 .39067 Metetra
0 .023 .121 r
.86861 .39067 .8726 .39641 .88257 .39331 .87861 .38755 Metetra
0 .023 .121 r
.87861 .38755 .88257 .39331 .89258 .39019 .88864 .38441 Metetra
0 .023 .121 r
.88864 .38441 .89258 .39019 .90261 .38707 .8987 .38127 Metetra
0 .023 .121 r
.8987 .38127 .90261 .38707 .91269 .38393 .9088 .37811 Metetra
0 .023 .121 r
.9088 .37811 .91269 .38393 .92279 .38078 .91893 .37494 Metetra
0 .023 .121 r
.91893 .37494 .92279 .38078 .93294 .37762 .9291 .37176 Metetra
0 .023 .121 r
.3452 .54792 .35035 .55271 .35865 .55012 .35351 .54531 Metetra
0 .023 .121 r
.35351 .54531 .35865 .55012 .36697 .54752 .36185 .54269 Metetra
0 .023 .121 r
.36185 .54269 .36697 .54752 .37532 .5449 .37022 .54006 Metetra
0 .023 .121 r
.37022 .54006 .37532 .5449 .3837 .54229 .37861 .53743 Metetra
0 .023 .121 r
.37861 .53743 .3837 .54229 .3921 .53966 .38703 .53479 Metetra
0 .023 .121 r
.38703 .53479 .3921 .53966 .40053 .53702 .39548 .53214 Metetra
0 .023 .121 r
.39548 .53214 .40053 .53702 .40899 .53438 .40395 .52948 Metetra
0 .023 .121 r
.40395 .52948 .40899 .53438 .41747 .53173 .41245 .52681 Metetra
0 .023 .121 r
.41245 .52681 .41747 .53173 .42598 .52907 .42098 .52413 Metetra
0 .023 .121 r
.42098 .52413 .42598 .52907 .43452 .5264 .42953 .52145 Metetra
0 .023 .121 r
.42953 .52145 .43452 .5264 .44308 .52372 .43811 .51875 Metetra
0 .023 .121 r
.43811 .51875 .44308 .52372 .45167 .52103 .44672 .51605 Metetra
0 .023 .121 r
.44672 .51605 .45167 .52103 .46029 .51834 .45536 .51334 Metetra
0 .023 .121 r
.45536 .51334 .46029 .51834 .46894 .51564 .46402 .51062 Metetra
0 .023 .121 r
.46402 .51062 .46894 .51564 .47761 .51292 .47271 .5079 Metetra
0 .023 .121 r
.47271 .5079 .47761 .51292 .48631 .5102 .48143 .50516 Metetra
0 .023 .121 r
.48143 .50516 .48631 .5102 .49504 .50747 .49017 .50241 Metetra
0 .023 .121 r
.49017 .50241 .49504 .50747 .50379 .50474 .49895 .49966 Metetra
0 .023 .121 r
.49895 .49966 .50379 .50474 .51258 .50199 .50775 .4969 Metetra
0 .023 .121 r
.50775 .4969 .51258 .50199 .52139 .49924 .51658 .49413 Metetra
0 .023 .121 r
.51658 .49413 .52139 .49924 .53023 .49647 .52544 .49134 Metetra
0 .023 .121 r
.52544 .49134 .53023 .49647 .5391 .4937 .53433 .48855 Metetra
0 .023 .121 r
.53433 .48855 .5391 .4937 .548 .49092 .54325 .48576 Metetra
0 .023 .121 r
.54325 .48576 .548 .49092 .55693 .48813 .55219 .48295 Metetra
0 .023 .121 r
.55219 .48295 .55693 .48813 .56588 .48532 .56117 .48013 Metetra
0 .023 .121 r
.56117 .48013 .56588 .48532 .57487 .48252 .57017 .47731 Metetra
0 .023 .121 r
.57017 .47731 .57487 .48252 .58388 .4797 .5792 .47447 Metetra
0 .023 .121 r
.5792 .47447 .58388 .4797 .59292 .47687 .58827 .47163 Metetra
0 .023 .121 r
.58827 .47163 .59292 .47687 .602 .47404 .59736 .46878 Metetra
0 .023 .121 r
.59736 .46878 .602 .47404 .6111 .4712 .60648 .46592 Metetra
0 .024 .122 r
.60648 .46592 .6111 .4712 .62023 .46844 .61564 .46312 Metetra
0 .024 .122 r
.61564 .46312 .62023 .46844 .6294 .46557 .62482 .46024 Metetra
0 .024 .122 r
.62482 .46024 .6294 .46557 .63859 .46261 .63403 .45727 Metetra
0 .023 .121 r
.63403 .45727 .63859 .46261 .64781 .45972 .64327 .45437 Metetra
0 .023 .121 r
.64327 .45437 .64781 .45972 .65706 .45682 .65255 .45145 Metetra
0 .023 .121 r
.65255 .45145 .65706 .45682 .66634 .45392 .66185 .44853 Metetra
0 .023 .121 r
.66185 .44853 .66634 .45392 .67566 .451 .67118 .4456 Metetra
0 .023 .121 r
.67118 .4456 .67566 .451 .685 .44808 .68055 .44266 Metetra
0 .023 .121 r
.68055 .44266 .685 .44808 .69438 .44515 .68995 .43971 Metetra
0 .023 .121 r
.68995 .43971 .69438 .44515 .70378 .44221 .69938 .43675 Metetra
0 .023 .121 r
.69938 .43675 .70378 .44221 .71322 .43926 .70884 .43378 Metetra
0 .023 .121 r
.70884 .43378 .71322 .43926 .72269 .4363 .71833 .4308 Metetra
0 .023 .121 r
.71833 .4308 .72269 .4363 .73219 .43333 .72785 .42782 Metetra
0 .023 .121 r
.72785 .42782 .73219 .43333 .74173 .43035 .7374 .42482 Metetra
0 .023 .121 r
.7374 .42482 .74173 .43035 .75129 .42735 .74699 .42181 Metetra
0 .023 .121 r
.74699 .42181 .75129 .42735 .76089 .42435 .75661 .41879 Metetra
0 .023 .121 r
.75661 .41879 .76089 .42435 .77052 .42134 .76626 .41576 Metetra
0 .023 .121 r
.76626 .41576 .77052 .42134 .78018 .41832 .77595 .41272 Metetra
0 .023 .121 r
.77595 .41272 .78018 .41832 .78987 .41529 .78566 .40967 Metetra
0 .023 .121 r
.78566 .40967 .78987 .41529 .7996 .41225 .79541 .40661 Metetra
0 .023 .121 r
.79541 .40661 .7996 .41225 .80936 .4092 .8052 .40354 Metetra
0 .023 .121 r
.8052 .40354 .80936 .4092 .81915 .40614 .81501 .40046 Metetra
0 .023 .121 r
.81501 .40046 .81915 .40614 .82897 .40307 .82486 .39737 Metetra
0 .023 .121 r
.82486 .39737 .82897 .40307 .83883 .39998 .83474 .39426 Metetra
0 .023 .121 r
.83474 .39426 .83883 .39998 .84873 .39689 .84466 .39115 Metetra
0 .023 .121 r
.84466 .39115 .84873 .39689 .85865 .39379 .85461 .38803 Metetra
0 .023 .121 r
.85461 .38803 .85865 .39379 .86861 .39067 .8646 .3849 Metetra
0 .023 .121 r
.8646 .3849 .86861 .39067 .87861 .38755 .87462 .38175 Metetra
0 .023 .121 r
.87462 .38175 .87861 .38755 .88864 .38441 .88467 .3786 Metetra
0 .023 .121 r
.88467 .3786 .88864 .38441 .8987 .38127 .89476 .37543 Metetra
0 .023 .121 r
.89476 .37543 .8987 .38127 .9088 .37811 .90488 .37225 Metetra
0 .023 .121 r
.90488 .37225 .9088 .37811 .91893 .37494 .91504 .36906 Metetra
0 .023 .121 r
.91504 .36906 .91893 .37494 .9291 .37176 .92523 .36586 Metetra
0 .023 .121 r
.34002 .54309 .3452 .54792 .35351 .54531 .34835 .54047 Metetra
0 .023 .121 r
.34835 .54047 .35351 .54531 .36185 .54269 .3567 .53783 Metetra
0 .023 .121 r
.3567 .53783 .36185 .54269 .37022 .54006 .36509 .53519 Metetra
0 .023 .121 r
.36509 .53519 .37022 .54006 .37861 .53743 .3735 .53254 Metetra
0 .023 .121 r
.3735 .53254 .37861 .53743 .38703 .53479 .38193 .52989 Metetra
0 .023 .121 r
.38193 .52989 .38703 .53479 .39548 .53214 .3904 .52722 Metetra
0 .023 .121 r
.3904 .52722 .39548 .53214 .40395 .52948 .39888 .52454 Metetra
0 .023 .121 r
.39888 .52454 .40395 .52948 .41245 .52681 .4074 .52186 Metetra
0 .023 .121 r
.4074 .52186 .41245 .52681 .42098 .52413 .41594 .51917 Metetra
0 .023 .121 r
.41594 .51917 .42098 .52413 .42953 .52145 .42452 .51647 Metetra
0 .023 .121 r
.42452 .51647 .42953 .52145 .43811 .51875 .43311 .51376 Metetra
0 .023 .121 r
.43311 .51376 .43811 .51875 .44672 .51605 .44174 .51104 Metetra
0 .023 .121 r
.44174 .51104 .44672 .51605 .45536 .51334 .45039 .50832 Metetra
0 .023 .121 r
.45039 .50832 .45536 .51334 .46402 .51062 .45907 .50558 Metetra
0 .023 .121 r
.45907 .50558 .46402 .51062 .47271 .5079 .46778 .50284 Metetra
0 .023 .121 r
.46778 .50284 .47271 .5079 .48143 .50516 .47652 .50008 Metetra
0 .023 .121 r
.47652 .50008 .48143 .50516 .49017 .50241 .48528 .49732 Metetra
0 .023 .121 r
.48528 .49732 .49017 .50241 .49895 .49966 .49407 .49455 Metetra
0 .023 .121 r
.49407 .49455 .49895 .49966 .50775 .4969 .50289 .49177 Metetra
0 .023 .121 r
.50289 .49177 .50775 .4969 .51658 .49413 .51174 .48898 Metetra
0 .023 .121 r
.51174 .48898 .51658 .49413 .52544 .49134 .52062 .48619 Metetra
0 .023 .121 r
.52062 .48619 .52544 .49134 .53433 .48855 .52953 .48338 Metetra
0 .023 .121 r
.52953 .48338 .53433 .48855 .54325 .48576 .53847 .48057 Metetra
0 .023 .121 r
.53847 .48057 .54325 .48576 .55219 .48295 .54743 .47774 Metetra
0 .023 .121 r
.54743 .47774 .55219 .48295 .56117 .48013 .55642 .47491 Metetra
0 .023 .121 r
.55642 .47491 .56117 .48013 .57017 .47731 .56545 .47206 Metetra
0 .023 .121 r
.56545 .47206 .57017 .47731 .5792 .47447 .5745 .46921 Metetra
0 .023 .121 r
.5745 .46921 .5792 .47447 .58827 .47163 .58358 .46635 Metetra
0 .023 .121 r
.58358 .46635 .58827 .47163 .59736 .46878 .5927 .46348 Metetra
0 .023 .121 r
.5927 .46348 .59736 .46878 .60648 .46592 .60184 .4606 Metetra
0 .024 .122 r
.60184 .4606 .60648 .46592 .61564 .46312 .61101 .45776 Metetra
0 .024 .122 r
.61101 .45776 .61564 .46312 .62482 .46024 .62021 .45486 Metetra
0 .024 .122 r
.62021 .45486 .62482 .46024 .63403 .45727 .62945 .45191 Metetra
0 .023 .121 r
.62945 .45191 .63403 .45727 .64327 .45437 .63871 .44898 Metetra
0 .023 .121 r
.63871 .44898 .64327 .45437 .65255 .45145 .648 .44605 Metetra
0 .023 .121 r
.648 .44605 .65255 .45145 .66185 .44853 .65733 .44311 Metetra
0 .023 .121 r
.65733 .44311 .66185 .44853 .67118 .4456 .66668 .44017 Metetra
0 .023 .121 r
.66668 .44017 .67118 .4456 .68055 .44266 .67607 .43721 Metetra
0 .023 .121 r
.67607 .43721 .68055 .44266 .68995 .43971 .68549 .43424 Metetra
0 .023 .121 r
.68549 .43424 .68995 .43971 .69938 .43675 .69494 .43126 Metetra
0 .023 .121 r
.69494 .43126 .69938 .43675 .70884 .43378 .70442 .42828 Metetra
0 .023 .121 r
.70442 .42828 .70884 .43378 .71833 .4308 .71393 .42528 Metetra
0 .023 .121 r
.71393 .42528 .71833 .4308 .72785 .42782 .72348 .42227 Metetra
0 .023 .121 r
.72348 .42227 .72785 .42782 .7374 .42482 .73306 .41925 Metetra
0 .023 .121 r
.73306 .41925 .7374 .42482 .74699 .42181 .74267 .41623 Metetra
0 .023 .121 r
.74267 .41623 .74699 .42181 .75661 .41879 .75231 .41319 Metetra
0 .023 .121 r
.75231 .41319 .75661 .41879 .76626 .41576 .76198 .41014 Metetra
0 .023 .121 r
.76198 .41014 .76626 .41576 .77595 .41272 .77169 .40708 Metetra
0 .023 .121 r
.77169 .40708 .77595 .41272 .78566 .40967 .78143 .40401 Metetra
0 .023 .121 r
.78143 .40401 .78566 .40967 .79541 .40661 .7912 .40093 Metetra
0 .023 .121 r
.7912 .40093 .79541 .40661 .8052 .40354 .80101 .39784 Metetra
0 .023 .121 r
.80101 .39784 .8052 .40354 .81501 .40046 .81085 .39474 Metetra
0 .023 .121 r
.81085 .39474 .81501 .40046 .82486 .39737 .82072 .39163 Metetra
0 .023 .121 r
.82072 .39163 .82486 .39737 .83474 .39426 .83063 .38851 Metetra
0 .023 .121 r
.83063 .38851 .83474 .39426 .84466 .39115 .84057 .38538 Metetra
0 .023 .121 r
.84057 .38538 .84466 .39115 .85461 .38803 .85055 .38224 Metetra
0 .023 .121 r
.85055 .38224 .85461 .38803 .8646 .3849 .86056 .37908 Metetra
0 .023 .121 r
.86056 .37908 .8646 .3849 .87462 .38175 .8706 .37592 Metetra
0 .023 .121 r
.8706 .37592 .87462 .38175 .88467 .3786 .88068 .37274 Metetra
0 .023 .121 r
.88068 .37274 .88467 .3786 .89476 .37543 .89079 .36955 Metetra
0 .023 .121 r
.89079 .36955 .89476 .37543 .90488 .37225 .90094 .36636 Metetra
0 .023 .121 r
.90094 .36636 .90488 .37225 .91504 .36906 .91112 .36315 Metetra
0 .023 .121 r
.91112 .36315 .91504 .36906 .92523 .36586 .92134 .35993 Metetra
0 .023 .121 r
.33481 .53824 .34002 .54309 .34835 .54047 .34315 .5356 Metetra
0 .023 .121 r
.34315 .5356 .34835 .54047 .3567 .53783 .35152 .53295 Metetra
0 .023 .121 r
.35152 .53295 .3567 .53783 .36509 .53519 .35992 .53029 Metetra
0 .023 .121 r
.35992 .53029 .36509 .53519 .3735 .53254 .36835 .52763 Metetra
0 .023 .121 r
.36835 .52763 .3735 .53254 .38193 .52989 .3768 .52496 Metetra
0 .023 .121 r
.3768 .52496 .38193 .52989 .3904 .52722 .38528 .52227 Metetra
0 .023 .121 r
.38528 .52227 .3904 .52722 .39888 .52454 .39379 .51958 Metetra
0 .023 .121 r
.39379 .51958 .39888 .52454 .4074 .52186 .40232 .51688 Metetra
0 .023 .121 r
.40232 .51688 .4074 .52186 .41594 .51917 .41088 .51418 Metetra
0 .023 .121 r
.41088 .51418 .41594 .51917 .42452 .51647 .41947 .51146 Metetra
0 .023 .121 r
.41947 .51146 .42452 .51647 .43311 .51376 .42808 .50874 Metetra
0 .023 .121 r
.42808 .50874 .43311 .51376 .44174 .51104 .43673 .506 Metetra
0 .023 .121 r
.43673 .506 .44174 .51104 .45039 .50832 .4454 .50326 Metetra
0 .023 .121 r
.4454 .50326 .45039 .50832 .45907 .50558 .4541 .50051 Metetra
0 .023 .121 r
.4541 .50051 .45907 .50558 .46778 .50284 .46282 .49775 Metetra
0 .023 .121 r
.46282 .49775 .46778 .50284 .47652 .50008 .47158 .49498 Metetra
0 .023 .121 r
.47158 .49498 .47652 .50008 .48528 .49732 .48036 .4922 Metetra
0 .023 .121 r
.48036 .4922 .48528 .49732 .49407 .49455 .48917 .48941 Metetra
0 .023 .121 r
.48917 .48941 .49407 .49455 .50289 .49177 .49801 .48662 Metetra
0 .023 .121 r
.49801 .48662 .50289 .49177 .51174 .48898 .50688 .48381 Metetra
0 .023 .121 r
.50688 .48381 .51174 .48898 .52062 .48619 .51577 .481 Metetra
0 .023 .121 r
.51577 .481 .52062 .48619 .52953 .48338 .5247 .47818 Metetra
0 .023 .121 r
.5247 .47818 .52953 .48338 .53847 .48057 .53366 .47534 Metetra
0 .023 .121 r
.53366 .47534 .53847 .48057 .54743 .47774 .54264 .4725 Metetra
0 .023 .121 r
.54264 .4725 .54743 .47774 .55642 .47491 .55165 .46965 Metetra
0 .023 .121 r
.55165 .46965 .55642 .47491 .56545 .47206 .5607 .46679 Metetra
0 .023 .121 r
.5607 .46679 .56545 .47206 .5745 .46921 .56977 .46392 Metetra
0 .023 .121 r
.56977 .46392 .5745 .46921 .58358 .46635 .57887 .46104 Metetra
0 .023 .121 r
.57887 .46104 .58358 .46635 .5927 .46348 .588 .45817 Metetra
0 .023 .121 r
.588 .45817 .5927 .46348 .60184 .4606 .59717 .45528 Metetra
0 .024 .122 r
.59717 .45528 .60184 .4606 .61101 .45776 .60636 .45253 Metetra
0 .024 .122 r
.60636 .45253 .61101 .45776 .62021 .45486 .61559 .44961 Metetra
0 .024 .122 r
.61559 .44961 .62021 .45486 .62945 .45191 .62484 .44653 Metetra
0 .023 .121 r
.62484 .44653 .62945 .45191 .63871 .44898 .63412 .44358 Metetra
0 .023 .121 r
.63412 .44358 .63871 .44898 .648 .44605 .64343 .44062 Metetra
0 .023 .121 r
.64343 .44062 .648 .44605 .65733 .44311 .65278 .43767 Metetra
0 .023 .121 r
.65278 .43767 .65733 .44311 .66668 .44017 .66216 .4347 Metetra
0 .023 .121 r
.66216 .4347 .66668 .44017 .67607 .43721 .67157 .43172 Metetra
0 .023 .121 r
.67157 .43172 .67607 .43721 .68549 .43424 .68101 .42874 Metetra
0 .023 .121 r
.68101 .42874 .68549 .43424 .69494 .43126 .69048 .42574 Metetra
0 .023 .121 r
.69048 .42574 .69494 .43126 .70442 .42828 .69998 .42273 Metetra
0 .023 .121 r
.69998 .42273 .70442 .42828 .71393 .42528 .70952 .41972 Metetra
0 .023 .121 r
.70952 .41972 .71393 .42528 .72348 .42227 .71908 .41669 Metetra
0 .023 .121 r
.71908 .41669 .72348 .42227 .73306 .41925 .72868 .41366 Metetra
0 .023 .121 r
.72868 .41366 .73306 .41925 .74267 .41623 .73831 .41061 Metetra
0 .023 .121 r
.73831 .41061 .74267 .41623 .75231 .41319 .74798 .40755 Metetra
0 .023 .121 r
.74798 .40755 .75231 .41319 .76198 .41014 .75768 .40449 Metetra
0 .023 .121 r
.75768 .40449 .76198 .41014 .77169 .40708 .76741 .40141 Metetra
0 .023 .121 r
.76741 .40141 .77169 .40708 .78143 .40401 .77717 .39832 Metetra
0 .023 .121 r
.77717 .39832 .78143 .40401 .7912 .40093 .78697 .39522 Metetra
0 .023 .121 r
.78697 .39522 .7912 .40093 .80101 .39784 .7968 .39211 Metetra
0 .023 .121 r
.7968 .39211 .80101 .39784 .81085 .39474 .80666 .38899 Metetra
0 .023 .121 r
.80666 .38899 .81085 .39474 .82072 .39163 .81656 .38586 Metetra
0 .023 .121 r
.81656 .38586 .82072 .39163 .83063 .38851 .82649 .38272 Metetra
0 .023 .121 r
.82649 .38272 .83063 .38851 .84057 .38538 .83646 .37957 Metetra
0 .023 .121 r
.83646 .37957 .84057 .38538 .85055 .38224 .84645 .3764 Metetra
0 .023 .121 r
.84645 .3764 .85055 .38224 .86056 .37908 .85649 .37323 Metetra
0 .023 .121 r
.85649 .37323 .86056 .37908 .8706 .37592 .86656 .37005 Metetra
0 .023 .121 r
.86656 .37005 .8706 .37592 .88068 .37274 .87666 .36685 Metetra
0 .023 .121 r
.87666 .36685 .88068 .37274 .89079 .36955 .8868 .36364 Metetra
0 .023 .121 r
.8868 .36364 .89079 .36955 .90094 .36636 .89697 .36042 Metetra
0 .023 .121 r
.89697 .36042 .90094 .36636 .91112 .36315 .90718 .3572 Metetra
0 .023 .121 r
.90718 .3572 .91112 .36315 .92134 .35993 .91743 .35396 Metetra
0 .023 .121 r
.32956 .53336 .33481 .53824 .34315 .5356 .33793 .5307 Metetra
0 .023 .121 r
.33793 .5307 .34315 .5356 .35152 .53295 .34632 .52804 Metetra
0 .023 .121 r
.34632 .52804 .35152 .53295 .35992 .53029 .35473 .52537 Metetra
0 .023 .121 r
.35473 .52537 .35992 .53029 .36835 .52763 .36317 .52269 Metetra
0 .023 .121 r
.36317 .52269 .36835 .52763 .3768 .52496 .37164 .52 Metetra
0 .023 .121 r
.37164 .52 .3768 .52496 .38528 .52227 .38014 .5173 Metetra
0 .023 .121 r
.38014 .5173 .38528 .52227 .39379 .51958 .38866 .51459 Metetra
0 .023 .121 r
.38866 .51459 .39379 .51958 .40232 .51688 .39721 .51188 Metetra
0 .023 .121 r
.39721 .51188 .40232 .51688 .41088 .51418 .40579 .50916 Metetra
0 .023 .121 r
.40579 .50916 .41088 .51418 .41947 .51146 .41439 .50642 Metetra
0 .023 .121 r
.41439 .50642 .41947 .51146 .42808 .50874 .42303 .50368 Metetra
0 .023 .121 r
.42303 .50368 .42808 .50874 .43673 .506 .43169 .50093 Metetra
0 .023 .121 r
.43169 .50093 .43673 .506 .4454 .50326 .44038 .49817 Metetra
0 .023 .121 r
.44038 .49817 .4454 .50326 .4541 .50051 .44909 .49541 Metetra
0 .023 .121 r
.44909 .49541 .4541 .50051 .46282 .49775 .45784 .49263 Metetra
0 .023 .121 r
.45784 .49263 .46282 .49775 .47158 .49498 .46661 .48984 Metetra
0 .023 .121 r
.46661 .48984 .47158 .49498 .48036 .4922 .47541 .48705 Metetra
0 .023 .121 r
.47541 .48705 .48036 .4922 .48917 .48941 .48424 .48425 Metetra
0 .023 .121 r
.48424 .48425 .48917 .48941 .49801 .48662 .4931 .48143 Metetra
0 .023 .121 r
.4931 .48143 .49801 .48662 .50688 .48381 .50198 .47861 Metetra
0 .023 .121 r
.50198 .47861 .50688 .48381 .51577 .481 .5109 .47578 Metetra
0 .023 .121 r
.5109 .47578 .51577 .481 .5247 .47818 .51984 .47294 Metetra
0 .023 .121 r
.51984 .47294 .5247 .47818 .53366 .47534 .52882 .47009 Metetra
0 .023 .121 r
.52882 .47009 .53366 .47534 .54264 .4725 .53782 .46723 Metetra
0 .023 .121 r
.53782 .46723 .54264 .4725 .55165 .46965 .54685 .46436 Metetra
0 .023 .121 r
.54685 .46436 .55165 .46965 .5607 .46679 .55592 .46149 Metetra
0 .023 .121 r
.55592 .46149 .5607 .46679 .56977 .46392 .56501 .4586 Metetra
0 .023 .121 r
.56501 .4586 .56977 .46392 .57887 .46104 .57413 .4557 Metetra
0 .023 .121 r
.57413 .4557 .57887 .46104 .588 .45817 .58328 .4528 Metetra
0 .023 .121 r
.58328 .4528 .588 .45817 .59717 .45528 .59246 .44988 Metetra
0 .024 .122 r
.59246 .44988 .59717 .45528 .60636 .45253 .60168 .44698 Metetra
0 .024 .122 r
.60168 .44698 .60636 .45253 .61559 .44961 .61092 .44405 Metetra
0 .024 .122 r
.61092 .44405 .61559 .44961 .62484 .44653 .62019 .44108 Metetra
0 .023 .121 r
.62019 .44108 .62484 .44653 .63412 .44358 .6295 .43812 Metetra
0 .023 .121 r
.6295 .43812 .63412 .44358 .64343 .44062 .63884 .43516 Metetra
0 .023 .121 r
.63884 .43516 .64343 .44062 .65278 .43767 .6482 .43218 Metetra
0 .023 .121 r
.6482 .43218 .65278 .43767 .66216 .4347 .6576 .4292 Metetra
0 .023 .121 r
.6576 .4292 .66216 .4347 .67157 .43172 .66703 .4262 Metetra
0 .023 .121 r
.66703 .4262 .67157 .43172 .68101 .42874 .67649 .4232 Metetra
0 .023 .121 r
.67649 .4232 .68101 .42874 .69048 .42574 .68599 .42018 Metetra
0 .023 .121 r
.68599 .42018 .69048 .42574 .69998 .42273 .69551 .41716 Metetra
0 .023 .121 r
.69551 .41716 .69998 .42273 .70952 .41972 .70507 .41412 Metetra
0 .023 .121 r
.70507 .41412 .70952 .41972 .71908 .41669 .71466 .41108 Metetra
0 .023 .121 r
.71466 .41108 .71908 .41669 .72868 .41366 .72428 .40802 Metetra
0 .023 .121 r
.72428 .40802 .72868 .41366 .73831 .41061 .73394 .40496 Metetra
0 .023 .121 r
.73394 .40496 .73831 .41061 .74798 .40755 .74362 .40188 Metetra
0 .023 .121 r
.74362 .40188 .74798 .40755 .75768 .40449 .75334 .39879 Metetra
0 .023 .121 r
.75334 .39879 .75768 .40449 .76741 .40141 .7631 .3957 Metetra
0 .023 .121 r
.7631 .3957 .76741 .40141 .77717 .39832 .77288 .39259 Metetra
0 .023 .121 r
.77288 .39259 .77717 .39832 .78697 .39522 .7827 .38947 Metetra
0 .023 .121 r
.7827 .38947 .78697 .39522 .7968 .39211 .79256 .38634 Metetra
0 .023 .121 r
.79256 .38634 .7968 .39211 .80666 .38899 .80245 .3832 Metetra
0 .023 .121 r
.80245 .3832 .80666 .38899 .81656 .38586 .81237 .38005 Metetra
0 .023 .121 r
.81237 .38005 .81656 .38586 .82649 .38272 .82232 .37689 Metetra
0 .023 .121 r
.82232 .37689 .82649 .38272 .83646 .37957 .83231 .37372 Metetra
0 .023 .121 r
.83231 .37372 .83646 .37957 .84645 .3764 .84234 .37054 Metetra
0 .023 .121 r
.84234 .37054 .84645 .3764 .85649 .37323 .8524 .36734 Metetra
0 .023 .121 r
.8524 .36734 .85649 .37323 .86656 .37005 .86249 .36414 Metetra
0 .023 .121 r
.86249 .36414 .86656 .37005 .87666 .36685 .87262 .36092 Metetra
0 .023 .121 r
.87262 .36092 .87666 .36685 .8868 .36364 .88278 .35769 Metetra
0 .023 .121 r
.88278 .35769 .8868 .36364 .89697 .36042 .89298 .35445 Metetra
0 .023 .121 r
.89298 .35445 .89697 .36042 .90718 .3572 .90322 .3512 Metetra
0 .023 .121 r
.90322 .3512 .90718 .3572 .91743 .35396 .91349 .34794 Metetra
0 .023 .121 r
.32429 .52845 .32956 .53336 .33793 .5307 .33267 .52578 Metetra
0 .023 .121 r
.33267 .52578 .33793 .5307 .34632 .52804 .34108 .5231 Metetra
0 .023 .121 r
.34108 .5231 .34632 .52804 .35473 .52537 .34951 .52041 Metetra
0 .023 .121 r
.34951 .52041 .35473 .52537 .36317 .52269 .35797 .51772 Metetra
0 .023 .121 r
.35797 .51772 .36317 .52269 .37164 .52 .36645 .51501 Metetra
0 .023 .121 r
.36645 .51501 .37164 .52 .38014 .5173 .37496 .5123 Metetra
0 .023 .121 r
.37496 .5123 .38014 .5173 .38866 .51459 .3835 .50957 Metetra
0 .023 .121 r
.3835 .50957 .38866 .51459 .39721 .51188 .39207 .50684 Metetra
0 .023 .121 r
.39207 .50684 .39721 .51188 .40579 .50916 .40067 .5041 Metetra
0 .023 .121 r
.40067 .5041 .40579 .50916 .41439 .50642 .40929 .50136 Metetra
0 .023 .121 r
.40929 .50136 .41439 .50642 .42303 .50368 .41794 .4986 Metetra
0 .023 .121 r
.41794 .4986 .42303 .50368 .43169 .50093 .42662 .49583 Metetra
0 .023 .121 r
.42662 .49583 .43169 .50093 .44038 .49817 .43532 .49306 Metetra
0 .023 .121 r
.43532 .49306 .44038 .49817 .44909 .49541 .44406 .49027 Metetra
0 .023 .121 r
.44406 .49027 .44909 .49541 .45784 .49263 .45282 .48748 Metetra
0 .023 .121 r
.45282 .48748 .45784 .49263 .46661 .48984 .46161 .48468 Metetra
0 .023 .121 r
.46161 .48468 .46661 .48984 .47541 .48705 .47043 .48187 Metetra
0 .023 .121 r
.47043 .48187 .47541 .48705 .48424 .48425 .47928 .47905 Metetra
0 .023 .121 r
.47928 .47905 .48424 .48425 .4931 .48143 .48815 .47622 Metetra
0 .023 .121 r
.48815 .47622 .4931 .48143 .50198 .47861 .49706 .47338 Metetra
0 .023 .121 r
.49706 .47338 .50198 .47861 .5109 .47578 .50599 .47053 Metetra
0 .023 .121 r
.50599 .47053 .5109 .47578 .51984 .47294 .51496 .46767 Metetra
0 .023 .121 r
.51496 .46767 .51984 .47294 .52882 .47009 .52395 .4648 Metetra
0 .023 .121 r
.52395 .4648 .52882 .47009 .53782 .46723 .53297 .46193 Metetra
0 .023 .121 r
.53297 .46193 .53782 .46723 .54685 .46436 .54202 .45904 Metetra
0 .023 .121 r
.54202 .45904 .54685 .46436 .55592 .46149 .55111 .45615 Metetra
0 .023 .121 r
.55111 .45615 .55592 .46149 .56501 .4586 .56022 .45325 Metetra
0 .023 .121 r
.56022 .45325 .56501 .4586 .57413 .4557 .56936 .45033 Metetra
0 .023 .121 r
.56936 .45033 .57413 .4557 .58328 .4528 .57853 .44742 Metetra
0 .023 .121 r
.57853 .44742 .58328 .4528 .59246 .44988 .58773 .44449 Metetra
0 .024 .122 r
.58773 .44449 .59246 .44988 .60168 .44698 .59697 .44171 Metetra
0 .024 .122 r
.59697 .44171 .60168 .44698 .61092 .44405 .60624 .43876 Metetra
0 .024 .122 r
.60624 .43876 .61092 .44405 .62019 .44108 .61553 .43563 Metetra
0 .023 .121 r
.61553 .43563 .62019 .44108 .6295 .43812 .62485 .43265 Metetra
0 .023 .121 r
.62485 .43265 .6295 .43812 .63884 .43516 .63421 .42966 Metetra
0 .023 .121 r
.63421 .42966 .63884 .43516 .6482 .43218 .6436 .42667 Metetra
0 .023 .121 r
.6436 .42667 .6482 .43218 .6576 .4292 .65302 .42366 Metetra
0 .023 .121 r
.65302 .42366 .6576 .4292 .66703 .4262 .66247 .42065 Metetra
0 .023 .121 r
.66247 .42065 .66703 .4262 .67649 .4232 .67195 .41763 Metetra
0 .023 .121 r
.67195 .41763 .67649 .4232 .68599 .42018 .68147 .41459 Metetra
0 .023 .121 r
.68147 .41459 .68599 .42018 .69551 .41716 .69101 .41155 Metetra
0 .023 .121 r
.69101 .41155 .69551 .41716 .70507 .41412 .70059 .40849 Metetra
0 .023 .121 r
.70059 .40849 .70507 .41412 .71466 .41108 .71021 .40543 Metetra
0 .023 .121 r
.71021 .40543 .71466 .41108 .72428 .40802 .71985 .40236 Metetra
0 .023 .121 r
.71985 .40236 .72428 .40802 .73394 .40496 .72953 .39927 Metetra
0 .023 .121 r
.72953 .39927 .73394 .40496 .74362 .40188 .73924 .39618 Metetra
0 .023 .121 r
.73924 .39618 .74362 .40188 .75334 .39879 .74898 .39307 Metetra
0 .023 .121 r
.74898 .39307 .75334 .39879 .7631 .3957 .75876 .38995 Metetra
0 .023 .121 r
.75876 .38995 .7631 .3957 .77288 .39259 .76857 .38683 Metetra
0 .023 .121 r
.76857 .38683 .77288 .39259 .7827 .38947 .77841 .38369 Metetra
0 .023 .121 r
.77841 .38369 .7827 .38947 .79256 .38634 .78829 .38054 Metetra
0 .023 .121 r
.78829 .38054 .79256 .38634 .80245 .3832 .7982 .37738 Metetra
0 .023 .121 r
.7982 .37738 .80245 .3832 .81237 .38005 .80815 .37421 Metetra
0 .023 .121 r
.80815 .37421 .81237 .38005 .82232 .37689 .81813 .37103 Metetra
0 .023 .121 r
.81813 .37103 .82232 .37689 .83231 .37372 .82814 .36783 Metetra
0 .023 .121 r
.82814 .36783 .83231 .37372 .84234 .37054 .83819 .36463 Metetra
0 .023 .121 r
.83819 .36463 .84234 .37054 .8524 .36734 .84828 .36142 Metetra
0 .023 .121 r
.84828 .36142 .8524 .36734 .86249 .36414 .8584 .35819 Metetra
0 .023 .121 r
.8584 .35819 .86249 .36414 .87262 .36092 .86855 .35495 Metetra
0 .023 .121 r
.86855 .35495 .87262 .36092 .88278 .35769 .87874 .35171 Metetra
0 .023 .121 r
.87874 .35171 .88278 .35769 .89298 .35445 .88897 .34845 Metetra
0 .023 .121 r
.88897 .34845 .89298 .35445 .90322 .3512 .89923 .34517 Metetra
0 .023 .121 r
.89923 .34517 .90322 .3512 .91349 .34794 .90953 .34189 Metetra
0 .023 .121 r
.31899 .52351 .32429 .52845 .33267 .52578 .32738 .52083 Metetra
0 .023 .121 r
.32738 .52083 .33267 .52578 .34108 .5231 .3358 .51813 Metetra
0 .023 .121 r
.3358 .51813 .34108 .5231 .34951 .52041 .34425 .51543 Metetra
0 .023 .121 r
.34425 .51543 .34951 .52041 .35797 .51772 .35273 .51272 Metetra
0 .023 .121 r
.35273 .51272 .35797 .51772 .36645 .51501 .36123 .50999 Metetra
0 .023 .121 r
.36123 .50999 .36645 .51501 .37496 .5123 .36976 .50726 Metetra
0 .023 .121 r
.36976 .50726 .37496 .5123 .3835 .50957 .37832 .50453 Metetra
0 .023 .121 r
.37832 .50453 .3835 .50957 .39207 .50684 .3869 .50178 Metetra
0 .023 .121 r
.3869 .50178 .39207 .50684 .40067 .5041 .39551 .49902 Metetra
0 .023 .121 r
.39551 .49902 .40067 .5041 .40929 .50136 .40415 .49626 Metetra
0 .023 .121 r
.40415 .49626 .40929 .50136 .41794 .4986 .41282 .49348 Metetra
0 .023 .121 r
.41282 .49348 .41794 .4986 .42662 .49583 .42152 .4907 Metetra
0 .023 .121 r
.42152 .4907 .42662 .49583 .43532 .49306 .43024 .48791 Metetra
0 .023 .121 r
.43024 .48791 .43532 .49306 .44406 .49027 .43899 .48511 Metetra
0 .023 .121 r
.43899 .48511 .44406 .49027 .45282 .48748 .44777 .4823 Metetra
0 .023 .121 r
.44777 .4823 .45282 .48748 .46161 .48468 .45658 .47948 Metetra
0 .023 .121 r
.45658 .47948 .46161 .48468 .47043 .48187 .46542 .47665 Metetra
0 .023 .121 r
.46542 .47665 .47043 .48187 .47928 .47905 .47428 .47381 Metetra
0 .023 .121 r
.47428 .47381 .47928 .47905 .48815 .47622 .48318 .47097 Metetra
0 .023 .121 r
.48318 .47097 .48815 .47622 .49706 .47338 .4921 .46811 Metetra
0 .023 .121 r
.4921 .46811 .49706 .47338 .50599 .47053 .50106 .46525 Metetra
0 .023 .121 r
.50106 .46525 .50599 .47053 .51496 .46767 .51004 .46237 Metetra
0 .023 .121 r
.51004 .46237 .51496 .46767 .52395 .4648 .51905 .45949 Metetra
0 .023 .121 r
.51905 .45949 .52395 .4648 .53297 .46193 .52809 .45659 Metetra
0 .023 .121 r
.52809 .45659 .53297 .46193 .54202 .45904 .53716 .45369 Metetra
0 .023 .121 r
.53716 .45369 .54202 .45904 .55111 .45615 .54627 .45078 Metetra
0 .023 .121 r
.54627 .45078 .55111 .45615 .56022 .45325 .5554 .44786 Metetra
0 .023 .121 r
.5554 .44786 .56022 .45325 .56936 .45033 .56456 .44492 Metetra
0 .023 .121 r
.56456 .44492 .56936 .45033 .57853 .44742 .57375 .44199 Metetra
0 .023 .122 r
.57375 .44199 .57853 .44742 .58773 .44449 .58298 .43905 Metetra
0 .024 .122 r
.58298 .43905 .58773 .44449 .59697 .44171 .59223 .43624 Metetra
0 .024 .122 r
.59223 .43624 .59697 .44171 .60624 .43876 .60152 .43327 Metetra
0 .024 .122 r
.60152 .43327 .60624 .43876 .61553 .43563 .61083 .43014 Metetra
0 .023 .122 r
.61083 .43014 .61553 .43563 .62485 .43265 .62018 .42714 Metetra
0 .023 .121 r
.62018 .42714 .62485 .43265 .63421 .42966 .62955 .42412 Metetra
0 .023 .121 r
.62955 .42412 .63421 .42966 .6436 .42667 .63896 .42111 Metetra
0 .023 .121 r
.63896 .42111 .6436 .42667 .65302 .42366 .64841 .41809 Metetra
0 .023 .121 r
.64841 .41809 .65302 .42366 .66247 .42065 .65788 .41506 Metetra
0 .023 .121 r
.65788 .41506 .66247 .42065 .67195 .41763 .66738 .41202 Metetra
0 .023 .121 r
.66738 .41202 .67195 .41763 .68147 .41459 .67692 .40896 Metetra
0 .023 .121 r
.67692 .40896 .68147 .41459 .69101 .41155 .68649 .4059 Metetra
0 .023 .121 r
.68649 .4059 .69101 .41155 .70059 .40849 .69609 .40283 Metetra
0 .023 .121 r
.69609 .40283 .70059 .40849 .71021 .40543 .70573 .39975 Metetra
0 .023 .121 r
.70573 .39975 .71021 .40543 .71985 .40236 .71539 .39665 Metetra
0 .023 .121 r
.71539 .39665 .71985 .40236 .72953 .39927 .72509 .39355 Metetra
0 .023 .121 r
.72509 .39355 .72953 .39927 .73924 .39618 .73483 .39043 Metetra
0 .023 .121 r
.73483 .39043 .73924 .39618 .74898 .39307 .74459 .38731 Metetra
0 .023 .121 r
.74459 .38731 .74898 .39307 .75876 .38995 .75439 .38417 Metetra
0 .023 .121 r
.75439 .38417 .75876 .38995 .76857 .38683 .76423 .38102 Metetra
0 .023 .121 r
.76423 .38102 .76857 .38683 .77841 .38369 .7741 .37787 Metetra
0 .023 .121 r
.7741 .37787 .77841 .38369 .78829 .38054 .784 .3747 Metetra
0 .023 .121 r
.784 .3747 .78829 .38054 .7982 .37738 .79393 .37152 Metetra
0 .023 .121 r
.79393 .37152 .7982 .37738 .80815 .37421 .8039 .36833 Metetra
0 .023 .121 r
.8039 .36833 .80815 .37421 .81813 .37103 .81391 .36512 Metetra
0 .023 .121 r
.81391 .36512 .81813 .37103 .82814 .36783 .82395 .36191 Metetra
0 .023 .121 r
.82395 .36191 .82814 .36783 .83819 .36463 .83402 .35869 Metetra
0 .023 .121 r
.83402 .35869 .83819 .36463 .84828 .36142 .84413 .35545 Metetra
0 .023 .121 r
.84413 .35545 .84828 .36142 .8584 .35819 .85428 .35221 Metetra
0 .023 .121 r
.85428 .35221 .8584 .35819 .86855 .35495 .86446 .34895 Metetra
0 .023 .121 r
.86446 .34895 .86855 .35495 .87874 .35171 .87467 .34568 Metetra
0 .023 .121 r
.87467 .34568 .87874 .35171 .88897 .34845 .88492 .3424 Metetra
0 .023 .121 r
.88492 .3424 .88897 .34845 .89923 .34517 .89521 .33911 Metetra
0 .023 .121 r
.89521 .33911 .89923 .34517 .90953 .34189 .90553 .3358 Metetra
0 .023 .121 r
.31365 .51855 .31899 .52351 .32738 .52083 .32207 .51584 Metetra
0 .023 .121 r
.32207 .51584 .32738 .52083 .3358 .51813 .3305 .51313 Metetra
0 .023 .121 r
.3305 .51313 .3358 .51813 .34425 .51543 .33897 .51041 Metetra
0 .023 .121 r
.33897 .51041 .34425 .51543 .35273 .51272 .34746 .50769 Metetra
0 .023 .121 r
.34746 .50769 .35273 .51272 .36123 .50999 .35598 .50495 Metetra
0 .023 .121 r
.35598 .50495 .36123 .50999 .36976 .50726 .36453 .5022 Metetra
0 .023 .121 r
.36453 .5022 .36976 .50726 .37832 .50453 .3731 .49945 Metetra
0 .023 .121 r
.3731 .49945 .37832 .50453 .3869 .50178 .3817 .49668 Metetra
0 .023 .121 r
.3817 .49668 .3869 .50178 .39551 .49902 .39033 .49391 Metetra
0 .023 .121 r
.39033 .49391 .39551 .49902 .40415 .49626 .39899 .49113 Metetra
0 .023 .121 r
.39899 .49113 .40415 .49626 .41282 .49348 .40767 .48834 Metetra
0 .023 .121 r
.40767 .48834 .41282 .49348 .42152 .4907 .41638 .48554 Metetra
0 .023 .121 r
.41638 .48554 .42152 .4907 .43024 .48791 .42513 .48273 Metetra
0 .023 .121 r
.42513 .48273 .43024 .48791 .43899 .48511 .4339 .47991 Metetra
0 .023 .121 r
.4339 .47991 .43899 .48511 .44777 .4823 .44269 .47709 Metetra
0 .023 .121 r
.44269 .47709 .44777 .4823 .45658 .47948 .45152 .47425 Metetra
0 .023 .121 r
.45152 .47425 .45658 .47948 .46542 .47665 .46038 .47141 Metetra
0 .023 .121 r
.46038 .47141 .46542 .47665 .47428 .47381 .46926 .46855 Metetra
0 .023 .121 r
.46926 .46855 .47428 .47381 .48318 .47097 .47817 .46569 Metetra
0 .023 .121 r
.47817 .46569 .48318 .47097 .4921 .46811 .48712 .46281 Metetra
0 .023 .121 r
.48712 .46281 .4921 .46811 .50106 .46525 .49609 .45993 Metetra
0 .023 .121 r
.49609 .45993 .50106 .46525 .51004 .46237 .50509 .45704 Metetra
0 .023 .121 r
.50509 .45704 .51004 .46237 .51905 .45949 .51412 .45414 Metetra
0 .023 .121 r
.51412 .45414 .51905 .45949 .52809 .45659 .52318 .45123 Metetra
0 .023 .121 r
.52318 .45123 .52809 .45659 .53716 .45369 .53228 .44831 Metetra
0 .023 .121 r
.53228 .44831 .53716 .45369 .54627 .45078 .5414 .44538 Metetra
0 .023 .121 r
.5414 .44538 .54627 .45078 .5554 .44786 .55055 .44244 Metetra
0 .023 .121 r
.55055 .44244 .5554 .44786 .56456 .44492 .55973 .43948 Metetra
0 .023 .121 r
.55973 .43948 .56456 .44492 .57375 .44199 .56894 .43653 Metetra
0 .023 .121 r
.56894 .43653 .57375 .44199 .58298 .43905 .57819 .43357 Metetra
0 .024 .122 r
.57819 .43357 .58298 .43905 .59223 .43624 .58746 .43067 Metetra
0 .024 .122 r
.58746 .43067 .59223 .43624 .60152 .43327 .59677 .42768 Metetra
0 .024 .122 r
.59677 .42768 .60152 .43327 .61083 .43014 .6061 .4246 Metetra
0 .023 .121 r
.6061 .4246 .61083 .43014 .62018 .42714 .61547 .42158 Metetra
0 .023 .121 r
.61547 .42158 .62018 .42714 .62955 .42412 .62487 .41856 Metetra
0 .023 .121 r
.62487 .41856 .62955 .42412 .63896 .42111 .6343 .41553 Metetra
0 .023 .121 r
.6343 .41553 .63896 .42111 .64841 .41809 .64376 .41249 Metetra
0 .023 .121 r
.64376 .41249 .64841 .41809 .65788 .41506 .65326 .40943 Metetra
0 .023 .121 r
.65326 .40943 .65788 .41506 .66738 .41202 .66279 .40637 Metetra
0 .023 .121 r
.66279 .40637 .66738 .41202 .67692 .40896 .67235 .4033 Metetra
0 .023 .121 r
.67235 .4033 .67692 .40896 .68649 .4059 .68194 .40022 Metetra
0 .023 .121 r
.68194 .40022 .68649 .4059 .69609 .40283 .69156 .39713 Metetra
0 .023 .121 r
.69156 .39713 .69609 .40283 .70573 .39975 .70122 .39403 Metetra
0 .023 .121 r
.70122 .39403 .70573 .39975 .71539 .39665 .71091 .39091 Metetra
0 .023 .121 r
.71091 .39091 .71539 .39665 .72509 .39355 .72063 .38779 Metetra
0 .023 .121 r
.72063 .38779 .72509 .39355 .73483 .39043 .73039 .38465 Metetra
0 .023 .121 r
.73039 .38465 .73483 .39043 .74459 .38731 .74018 .38151 Metetra
0 .023 .121 r
.74018 .38151 .74459 .38731 .75439 .38417 .75 .37835 Metetra
0 .023 .121 r
.75 .37835 .75439 .38417 .76423 .38102 .75986 .37519 Metetra
0 .023 .121 r
.75986 .37519 .76423 .38102 .7741 .37787 .76975 .37201 Metetra
0 .023 .121 r
.76975 .37201 .7741 .37787 .784 .3747 .77968 .36882 Metetra
0 .023 .121 r
.77968 .36882 .784 .3747 .79393 .37152 .78964 .36562 Metetra
0 .023 .121 r
.78964 .36562 .79393 .37152 .8039 .36833 .79963 .36241 Metetra
0 .023 .121 r
.79963 .36241 .8039 .36833 .81391 .36512 .80966 .35918 Metetra
0 .023 .121 r
.80966 .35918 .81391 .36512 .82395 .36191 .81973 .35595 Metetra
0 .023 .121 r
.81973 .35595 .82395 .36191 .83402 .35869 .82983 .35271 Metetra
0 .023 .121 r
.82983 .35271 .83402 .35869 .84413 .35545 .83996 .34945 Metetra
0 .023 .121 r
.83996 .34945 .84413 .35545 .85428 .35221 .85013 .34618 Metetra
0 .023 .121 r
.85013 .34618 .85428 .35221 .86446 .34895 .86034 .3429 Metetra
0 .023 .121 r
.86034 .3429 .86446 .34895 .87467 .34568 .87058 .33961 Metetra
0 .023 .121 r
.87058 .33961 .87467 .34568 .88492 .3424 .88085 .33631 Metetra
0 .023 .121 r
.88085 .33631 .88492 .3424 .89521 .33911 .89117 .333 Metetra
0 .023 .121 r
.89117 .333 .89521 .33911 .90553 .3358 .90152 .32967 Metetra
0 .023 .121 r
.30829 .51355 .31365 .51855 .32207 .51584 .31672 .51083 Metetra
0 .023 .121 r
.31672 .51083 .32207 .51584 .3305 .51313 .32517 .50811 Metetra
0 .023 .121 r
.32517 .50811 .3305 .51313 .33897 .51041 .33365 .50537 Metetra
0 .023 .121 r
.33365 .50537 .33897 .51041 .34746 .50769 .34216 .50263 Metetra
0 .023 .121 r
.34216 .50263 .34746 .50769 .35598 .50495 .3507 .49987 Metetra
0 .023 .121 r
.3507 .49987 .35598 .50495 .36453 .5022 .35926 .49711 Metetra
0 .023 .121 r
.35926 .49711 .36453 .5022 .3731 .49945 .36785 .49434 Metetra
0 .023 .121 r
.36785 .49434 .3731 .49945 .3817 .49668 .37647 .49156 Metetra
0 .023 .121 r
.37647 .49156 .3817 .49668 .39033 .49391 .38511 .48877 Metetra
0 .023 .121 r
.38511 .48877 .39033 .49391 .39899 .49113 .39379 .48597 Metetra
0 .023 .121 r
.39379 .48597 .39899 .49113 .40767 .48834 .40249 .48316 Metetra
0 .023 .121 r
.40249 .48316 .40767 .48834 .41638 .48554 .41122 .48035 Metetra
0 .023 .121 r
.41122 .48035 .41638 .48554 .42513 .48273 .41998 .47752 Metetra
0 .023 .121 r
.41998 .47752 .42513 .48273 .4339 .47991 .42877 .47469 Metetra
0 .023 .121 r
.42877 .47469 .4339 .47991 .44269 .47709 .43759 .47184 Metetra
0 .023 .121 r
.43759 .47184 .44269 .47709 .45152 .47425 .44643 .46899 Metetra
0 .023 .121 r
.44643 .46899 .45152 .47425 .46038 .47141 .4553 .46613 Metetra
0 .023 .121 r
.4553 .46613 .46038 .47141 .46926 .46855 .46421 .46326 Metetra
0 .023 .121 r
.46421 .46326 .46926 .46855 .47817 .46569 .47314 .46038 Metetra
0 .023 .121 r
.47314 .46038 .47817 .46569 .48712 .46281 .4821 .45749 Metetra
0 .023 .121 r
.4821 .45749 .48712 .46281 .49609 .45993 .49109 .45459 Metetra
0 .023 .121 r
.49109 .45459 .49609 .45993 .50509 .45704 .50011 .45168 Metetra
0 .023 .121 r
.50011 .45168 .50509 .45704 .51412 .45414 .50917 .44876 Metetra
0 .023 .121 r
.50917 .44876 .51412 .45414 .52318 .45123 .51825 .44583 Metetra
0 .023 .121 r
.51825 .44583 .52318 .45123 .53228 .44831 .52736 .44289 Metetra
0 .023 .121 r
.52736 .44289 .53228 .44831 .5414 .44538 .5365 .43994 Metetra
0 .023 .121 r
.5365 .43994 .5414 .44538 .55055 .44244 .54567 .43699 Metetra
0 .023 .121 r
.54567 .43699 .55055 .44244 .55973 .43948 .55487 .43401 Metetra
0 .023 .121 r
.55487 .43401 .55973 .43948 .56894 .43653 .56411 .43106 Metetra
0 .023 .122 r
.56411 .43106 .56894 .43653 .57819 .43357 .57337 .4281 Metetra
0 .024 .122 r
.57337 .4281 .57819 .43357 .58746 .43067 .58267 .42545 Metetra
0 .024 .123 r
.58267 .42545 .58746 .43067 .59677 .42768 .592 .42245 Metetra
0 .024 .122 r
.592 .42245 .59677 .42768 .6061 .4246 .60135 .41907 Metetra
0 .023 .122 r
.60135 .41907 .6061 .4246 .61547 .42158 .61074 .41602 Metetra
0 .023 .121 r
.61074 .41602 .61547 .42158 .62487 .41856 .62016 .41296 Metetra
0 .023 .121 r
.62016 .41296 .62487 .41856 .6343 .41553 .62961 .40991 Metetra
0 .023 .121 r
.62961 .40991 .6343 .41553 .64376 .41249 .63909 .40685 Metetra
0 .023 .121 r
.63909 .40685 .64376 .41249 .65326 .40943 .64861 .40378 Metetra
0 .023 .121 r
.64861 .40378 .65326 .40943 .66279 .40637 .65816 .4007 Metetra
0 .023 .121 r
.65816 .4007 .66279 .40637 .67235 .4033 .66774 .39761 Metetra
0 .023 .121 r
.66774 .39761 .67235 .4033 .68194 .40022 .67736 .3945 Metetra
0 .023 .121 r
.67736 .3945 .68194 .40022 .69156 .39713 .687 .39139 Metetra
0 .023 .121 r
.687 .39139 .69156 .39713 .70122 .39403 .69668 .38827 Metetra
0 .023 .121 r
.69668 .38827 .70122 .39403 .71091 .39091 .7064 .38514 Metetra
0 .023 .121 r
.7064 .38514 .71091 .39091 .72063 .38779 .71614 .38199 Metetra
0 .023 .121 r
.71614 .38199 .72063 .38779 .73039 .38465 .72592 .37884 Metetra
0 .023 .121 r
.72592 .37884 .73039 .38465 .74018 .38151 .73573 .37567 Metetra
0 .023 .121 r
.73573 .37567 .74018 .38151 .75 .37835 .74558 .3725 Metetra
0 .023 .121 r
.74558 .3725 .75 .37835 .75986 .37519 .75546 .36931 Metetra
0 .023 .121 r
.75546 .36931 .75986 .37519 .76975 .37201 .76538 .36611 Metetra
0 .023 .121 r
.76538 .36611 .76975 .37201 .77968 .36882 .77533 .3629 Metetra
0 .023 .121 r
.77533 .3629 .77968 .36882 .78964 .36562 .78531 .35968 Metetra
0 .023 .121 r
.78531 .35968 .78964 .36562 .79963 .36241 .79533 .35645 Metetra
0 .023 .121 r
.79533 .35645 .79963 .36241 .80966 .35918 .80539 .35321 Metetra
0 .023 .121 r
.80539 .35321 .80966 .35918 .81973 .35595 .81548 .34995 Metetra
0 .023 .121 r
.81548 .34995 .81973 .35595 .82983 .35271 .8256 .34669 Metetra
0 .023 .121 r
.8256 .34669 .82983 .35271 .83996 .34945 .83576 .34341 Metetra
0 .023 .121 r
.83576 .34341 .83996 .34945 .85013 .34618 .84596 .34012 Metetra
0 .023 .121 r
.84596 .34012 .85013 .34618 .86034 .3429 .85619 .33682 Metetra
0 .023 .121 r
.85619 .33682 .86034 .3429 .87058 .33961 .86646 .33351 Metetra
0 .023 .121 r
.86646 .33351 .87058 .33961 .88085 .33631 .87676 .33018 Metetra
0 .023 .121 r
.87676 .33018 .88085 .33631 .89117 .333 .8871 .32685 Metetra
0 .023 .121 r
.8871 .32685 .89117 .333 .90152 .32967 .89748 .3235 Metetra
0 .023 .121 r
.30289 .50853 .30829 .51355 .31672 .51083 .31134 .50579 Metetra
0 .023 .121 r
.31134 .50579 .31672 .51083 .32517 .50811 .31981 .50305 Metetra
0 .023 .121 r
.31981 .50305 .32517 .50811 .33365 .50537 .3283 .5003 Metetra
0 .023 .121 r
.3283 .5003 .33365 .50537 .34216 .50263 .33683 .49754 Metetra
0 .023 .121 r
.33683 .49754 .34216 .50263 .3507 .49987 .34538 .49477 Metetra
0 .023 .121 r
.34538 .49477 .3507 .49987 .35926 .49711 .35396 .49199 Metetra
0 .023 .121 r
.35396 .49199 .35926 .49711 .36785 .49434 .36257 .4892 Metetra
0 .023 .121 r
.36257 .4892 .36785 .49434 .37647 .49156 .37121 .4864 Metetra
0 .023 .121 r
.37121 .4864 .37647 .49156 .38511 .48877 .37987 .4836 Metetra
0 .023 .121 r
.37987 .4836 .38511 .48877 .39379 .48597 .38856 .48078 Metetra
0 .023 .121 r
.38856 .48078 .39379 .48597 .40249 .48316 .39728 .47796 Metetra
0 .023 .121 r
.39728 .47796 .40249 .48316 .41122 .48035 .40603 .47513 Metetra
0 .023 .121 r
.40603 .47513 .41122 .48035 .41998 .47752 .41481 .47228 Metetra
0 .023 .121 r
.41481 .47228 .41998 .47752 .42877 .47469 .42361 .46943 Metetra
0 .023 .121 r
.42361 .46943 .42877 .47469 .43759 .47184 .43245 .46657 Metetra
0 .023 .121 r
.43245 .46657 .43759 .47184 .44643 .46899 .44131 .4637 Metetra
0 .023 .121 r
.44131 .4637 .44643 .46899 .4553 .46613 .4502 .46082 Metetra
0 .023 .121 r
.4502 .46082 .4553 .46613 .46421 .46326 .45912 .45793 Metetra
0 .023 .121 r
.45912 .45793 .46421 .46326 .47314 .46038 .46808 .45503 Metetra
0 .023 .121 r
.46808 .45503 .47314 .46038 .4821 .45749 .47706 .45212 Metetra
0 .023 .121 r
.47706 .45212 .4821 .45749 .49109 .45459 .48607 .44921 Metetra
0 .023 .121 r
.48607 .44921 .49109 .45459 .50011 .45168 .49511 .44628 Metetra
0 .023 .121 r
.49511 .44628 .50011 .45168 .50917 .44876 .50418 .44334 Metetra
0 .023 .121 r
.50418 .44334 .50917 .44876 .51825 .44583 .51328 .44039 Metetra
0 .023 .121 r
.51328 .44039 .51825 .44583 .52736 .44289 .52241 .43744 Metetra
0 .023 .121 r
.52241 .43744 .52736 .44289 .5365 .43994 .53157 .43447 Metetra
0 .023 .121 r
.53157 .43447 .5365 .43994 .54567 .43699 .54076 .43149 Metetra
0 .023 .121 r
.54076 .43149 .54567 .43699 .55487 .43401 .54998 .42851 Metetra
0 .023 .121 r
.54998 .42851 .55487 .43401 .56411 .43106 .55924 .42552 Metetra
0 .023 .122 r
.55924 .42552 .56411 .43106 .57337 .4281 .56852 .42251 Metetra
0 .024 .122 r
.56852 .42251 .57337 .4281 .58267 .42545 .57784 .41957 Metetra
0 .024 .122 r
.57784 .41957 .58267 .42545 .592 .42245 .58719 .41654 Metetra
0 .024 .122 r
.58719 .41654 .592 .42245 .60135 .41907 .59656 .41343 Metetra
0 .023 .122 r
.59656 .41343 .60135 .41907 .61074 .41602 .60597 .41038 Metetra
0 .023 .121 r
.60597 .41038 .61074 .41602 .62016 .41296 .61541 .40732 Metetra
0 .023 .121 r
.61541 .40732 .62016 .41296 .62961 .40991 .62489 .40425 Metetra
0 .023 .121 r
.62489 .40425 .62961 .40991 .63909 .40685 .6344 .40117 Metetra
0 .023 .121 r
.6344 .40117 .63909 .40685 .64861 .40378 .64393 .39808 Metetra
0 .023 .121 r
.64393 .39808 .64861 .40378 .65816 .4007 .6535 .39498 Metetra
0 .023 .121 r
.6535 .39498 .65816 .4007 .66774 .39761 .66311 .39187 Metetra
0 .023 .121 r
.66311 .39187 .66774 .39761 .67736 .3945 .67274 .38875 Metetra
0 .023 .121 r
.67274 .38875 .67736 .3945 .687 .39139 .68241 .38562 Metetra
0 .023 .121 r
.68241 .38562 .687 .39139 .69668 .38827 .69212 .38248 Metetra
0 .023 .121 r
.69212 .38248 .69668 .38827 .7064 .38514 .70185 .37932 Metetra
0 .023 .121 r
.70185 .37932 .7064 .38514 .71614 .38199 .71162 .37616 Metetra
0 .023 .121 r
.71162 .37616 .71614 .38199 .72592 .37884 .72143 .37299 Metetra
0 .023 .121 r
.72143 .37299 .72592 .37884 .73573 .37567 .73126 .3698 Metetra
0 .023 .121 r
.73126 .3698 .73573 .37567 .74558 .3725 .74113 .3666 Metetra
0 .023 .121 r
.74113 .3666 .74558 .3725 .75546 .36931 .75104 .3634 Metetra
0 .023 .121 r
.75104 .3634 .75546 .36931 .76538 .36611 .76098 .36018 Metetra
0 .023 .121 r
.76098 .36018 .76538 .36611 .77533 .3629 .77095 .35695 Metetra
0 .023 .121 r
.77095 .35695 .77533 .3629 .78531 .35968 .78096 .35371 Metetra
0 .023 .121 r
.78096 .35371 .78531 .35968 .79533 .35645 .79101 .35045 Metetra
0 .023 .121 r
.79101 .35045 .79533 .35645 .80539 .35321 .80108 .34719 Metetra
0 .023 .121 r
.80108 .34719 .80539 .35321 .81548 .34995 .8112 .34391 Metetra
0 .023 .121 r
.8112 .34391 .81548 .34995 .8256 .34669 .82135 .34063 Metetra
0 .023 .121 r
.82135 .34063 .8256 .34669 .83576 .34341 .83153 .33733 Metetra
0 .023 .121 r
.83153 .33733 .83576 .34341 .84596 .34012 .84176 .33402 Metetra
0 .023 .121 r
.84176 .33402 .84596 .34012 .85619 .33682 .85201 .3307 Metetra
0 .023 .121 r
.85201 .3307 .85619 .33682 .86646 .33351 .86231 .32736 Metetra
0 .023 .121 r
.86231 .32736 .86646 .33351 .87676 .33018 .87264 .32402 Metetra
0 .023 .121 r
.87264 .32402 .87676 .33018 .8871 .32685 .883 .32066 Metetra
0 .023 .121 r
.883 .32066 .8871 .32685 .89748 .3235 .89341 .31729 Metetra
0 .023 .121 r
.29746 .50347 .30289 .50853 .31134 .50579 .30592 .50072 Metetra
0 .023 .121 r
.30592 .50072 .31134 .50579 .31981 .50305 .31441 .49796 Metetra
0 .023 .121 r
.31441 .49796 .31981 .50305 .3283 .5003 .32292 .49519 Metetra
0 .023 .121 r
.32292 .49519 .3283 .5003 .33683 .49754 .33147 .49242 Metetra
0 .023 .121 r
.33147 .49242 .33683 .49754 .34538 .49477 .34004 .48963 Metetra
0 .023 .121 r
.34004 .48963 .34538 .49477 .35396 .49199 .34863 .48683 Metetra
0 .023 .121 r
.34863 .48683 .35396 .49199 .36257 .4892 .35726 .48403 Metetra
0 .023 .121 r
.35726 .48403 .36257 .4892 .37121 .4864 .36591 .48122 Metetra
0 .023 .121 r
.36591 .48122 .37121 .4864 .37987 .4836 .37459 .47839 Metetra
0 .023 .121 r
.37459 .47839 .37987 .4836 .38856 .48078 .3833 .47556 Metetra
0 .023 .121 r
.3833 .47556 .38856 .48078 .39728 .47796 .39204 .47272 Metetra
0 .023 .121 r
.39204 .47272 .39728 .47796 .40603 .47513 .40081 .46987 Metetra
0 .023 .121 r
.40081 .46987 .40603 .47513 .41481 .47228 .4096 .46701 Metetra
0 .023 .121 r
.4096 .46701 .41481 .47228 .42361 .46943 .41842 .46414 Metetra
0 .023 .121 r
.41842 .46414 .42361 .46943 .43245 .46657 .42728 .46126 Metetra
0 .023 .121 r
.42728 .46126 .43245 .46657 .44131 .4637 .43616 .45838 Metetra
0 .023 .121 r
.43616 .45838 .44131 .4637 .4502 .46082 .44507 .45548 Metetra
0 .023 .121 r
.44507 .45548 .4502 .46082 .45912 .45793 .45401 .45257 Metetra
0 .023 .121 r
.45401 .45257 .45912 .45793 .46808 .45503 .46298 .44966 Metetra
0 .023 .121 r
.46298 .44966 .46808 .45503 .47706 .45212 .47198 .44673 Metetra
0 .023 .121 r
.47198 .44673 .47706 .45212 .48607 .44921 .48101 .44379 Metetra
0 .023 .121 r
.48101 .44379 .48607 .44921 .49511 .44628 .49007 .44085 Metetra
0 .023 .121 r
.49007 .44085 .49511 .44628 .50418 .44334 .49916 .43789 Metetra
0 .023 .121 r
.49916 .43789 .50418 .44334 .51328 .44039 .50828 .43493 Metetra
0 .023 .121 r
.50828 .43493 .51328 .44039 .52241 .43744 .51743 .43195 Metetra
0 .023 .121 r
.51743 .43195 .52241 .43744 .53157 .43447 .52661 .42897 Metetra
0 .023 .121 r
.52661 .42897 .53157 .43447 .54076 .43149 .53582 .42598 Metetra
0 .023 .121 r
.53582 .42598 .54076 .43149 .54998 .42851 .54507 .42297 Metetra
0 .023 .121 r
.54507 .42297 .54998 .42851 .55924 .42552 .55434 .41998 Metetra
0 .023 .122 r
.55434 .41998 .55924 .42552 .56852 .42251 .56364 .41698 Metetra
0 .024 .122 r
.56364 .41698 .56852 .42251 .57784 .41957 .57299 .4143 Metetra
0 .024 .122 r
.57299 .4143 .57784 .41957 .58719 .41654 .58236 .41126 Metetra
0 .024 .122 r
.58236 .41126 .58719 .41654 .59656 .41343 .59175 .40784 Metetra
0 .023 .122 r
.59175 .40784 .59656 .41343 .60597 .41038 .60118 .40475 Metetra
0 .023 .121 r
.60118 .40475 .60597 .41038 .61541 .40732 .61064 .40165 Metetra
0 .023 .121 r
.61064 .40165 .61541 .40732 .62489 .40425 .62014 .39856 Metetra
0 .023 .121 r
.62014 .39856 .62489 .40425 .6344 .40117 .62967 .39546 Metetra
0 .023 .121 r
.62967 .39546 .6344 .40117 .64393 .39808 .63923 .39235 Metetra
0 .023 .121 r
.63923 .39235 .64393 .39808 .6535 .39498 .64882 .38923 Metetra
0 .023 .121 r
.64882 .38923 .6535 .39498 .66311 .39187 .65845 .3861 Metetra
0 .023 .121 r
.65845 .3861 .66311 .39187 .67274 .38875 .6681 .38296 Metetra
0 .023 .121 r
.6681 .38296 .67274 .38875 .68241 .38562 .6778 .37981 Metetra
0 .023 .121 r
.6778 .37981 .68241 .38562 .69212 .38248 .68752 .37665 Metetra
0 .023 .121 r
.68752 .37665 .69212 .38248 .70185 .37932 .69728 .37348 Metetra
0 .023 .121 r
.69728 .37348 .70185 .37932 .71162 .37616 .70707 .37029 Metetra
0 .023 .121 r
.70707 .37029 .71162 .37616 .72143 .37299 .7169 .3671 Metetra
0 .023 .121 r
.7169 .3671 .72143 .37299 .73126 .3698 .72676 .36389 Metetra
0 .023 .121 r
.72676 .36389 .73126 .3698 .74113 .3666 .73666 .36067 Metetra
0 .023 .121 r
.73666 .36067 .74113 .3666 .75104 .3634 .74659 .35744 Metetra
0 .023 .121 r
.74659 .35744 .75104 .3634 .76098 .36018 .75655 .3542 Metetra
0 .023 .121 r
.75655 .3542 .76098 .36018 .77095 .35695 .76655 .35095 Metetra
0 .023 .121 r
.76655 .35095 .77095 .35695 .78096 .35371 .77658 .34769 Metetra
0 .023 .121 r
.77658 .34769 .78096 .35371 .79101 .35045 .78665 .34442 Metetra
0 .023 .121 r
.78665 .34442 .79101 .35045 .80108 .34719 .79675 .34113 Metetra
0 .023 .121 r
.79675 .34113 .80108 .34719 .8112 .34391 .80689 .33784 Metetra
0 .023 .121 r
.80689 .33784 .8112 .34391 .82135 .34063 .81707 .33453 Metetra
0 .023 .121 r
.81707 .33453 .82135 .34063 .83153 .33733 .82728 .33121 Metetra
0 .023 .121 r
.82728 .33121 .83153 .33733 .84176 .33402 .83753 .32788 Metetra
0 .023 .121 r
.83753 .32788 .84176 .33402 .85201 .3307 .84781 .32453 Metetra
0 .023 .121 r
.84781 .32453 .85201 .3307 .86231 .32736 .85813 .32118 Metetra
0 .023 .121 r
.85813 .32118 .86231 .32736 .87264 .32402 .86849 .31781 Metetra
0 .023 .121 r
.86849 .31781 .87264 .32402 .883 .32066 .87888 .31443 Metetra
0 .023 .121 r
.87888 .31443 .883 .32066 .89341 .31729 .88931 .31104 Metetra
0 .023 .121 r
.292 .49839 .29746 .50347 .30592 .50072 .30048 .49562 Metetra
0 .023 .121 r
.30048 .49562 .30592 .50072 .31441 .49796 .30898 .49284 Metetra
0 .023 .121 r
.30898 .49284 .31441 .49796 .32292 .49519 .31751 .49006 Metetra
0 .023 .121 r
.31751 .49006 .32292 .49519 .33147 .49242 .32607 .48726 Metetra
0 .023 .121 r
.32607 .48726 .33147 .49242 .34004 .48963 .33466 .48446 Metetra
0 .023 .121 r
.33466 .48446 .34004 .48963 .34863 .48683 .34327 .48165 Metetra
0 .023 .121 r
.34327 .48165 .34863 .48683 .35726 .48403 .35191 .47883 Metetra
0 .023 .121 r
.35191 .47883 .35726 .48403 .36591 .48122 .36058 .476 Metetra
0 .023 .121 r
.36058 .476 .36591 .48122 .37459 .47839 .36928 .47316 Metetra
0 .023 .121 r
.36928 .47316 .37459 .47839 .3833 .47556 .37801 .47031 Metetra
0 .023 .121 r
.37801 .47031 .3833 .47556 .39204 .47272 .38676 .46745 Metetra
0 .023 .121 r
.38676 .46745 .39204 .47272 .40081 .46987 .39555 .46458 Metetra
0 .023 .121 r
.39555 .46458 .40081 .46987 .4096 .46701 .40436 .46171 Metetra
0 .023 .121 r
.40436 .46171 .4096 .46701 .41842 .46414 .4132 .45882 Metetra
0 .023 .121 r
.4132 .45882 .41842 .46414 .42728 .46126 .42208 .45592 Metetra
0 .023 .121 r
.42208 .45592 .42728 .46126 .43616 .45838 .43098 .45302 Metetra
0 .023 .121 r
.43098 .45302 .43616 .45838 .44507 .45548 .43991 .4501 Metetra
0 .023 .121 r
.43991 .4501 .44507 .45548 .45401 .45257 .44886 .44718 Metetra
0 .023 .121 r
.44886 .44718 .45401 .45257 .46298 .44966 .45785 .44425 Metetra
0 .023 .121 r
.45785 .44425 .46298 .44966 .47198 .44673 .46687 .4413 Metetra
0 .023 .121 r
.46687 .4413 .47198 .44673 .48101 .44379 .47592 .43835 Metetra
0 .023 .121 r
.47592 .43835 .48101 .44379 .49007 .44085 .485 .43538 Metetra
0 .023 .121 r
.485 .43538 .49007 .44085 .49916 .43789 .49411 .43241 Metetra
0 .023 .121 r
.49411 .43241 .49916 .43789 .50828 .43493 .50325 .42943 Metetra
0 .023 .121 r
.50325 .42943 .50828 .43493 .51743 .43195 .51242 .42643 Metetra
0 .023 .121 r
.51242 .42643 .51743 .43195 .52661 .42897 .52162 .42343 Metetra
0 .023 .121 r
.52162 .42343 .52661 .42897 .53582 .42598 .53085 .42042 Metetra
0 .023 .121 r
.53085 .42042 .53582 .42598 .54507 .42297 .54012 .41739 Metetra
0 .023 .121 r
.54012 .41739 .54507 .42297 .55434 .41998 .54941 .41439 Metetra
0 .024 .122 r
.54941 .41439 .55434 .41998 .56364 .41698 .55874 .41137 Metetra
0 .024 .122 r
.55874 .41137 .56364 .41698 .57299 .4143 .5681 .40875 Metetra
0 .025 .123 r
.5681 .40875 .57299 .4143 .58236 .41126 .57749 .40568 Metetra
0 .024 .122 r
.57749 .40568 .58236 .41126 .59175 .40784 .5869 .40218 Metetra
0 .024 .122 r
.5869 .40218 .59175 .40784 .60118 .40475 .59636 .39907 Metetra
0 .023 .121 r
.59636 .39907 .60118 .40475 .61064 .40165 .60584 .39594 Metetra
0 .023 .121 r
.60584 .39594 .61064 .40165 .62014 .39856 .61536 .39284 Metetra
0 .023 .121 r
.61536 .39284 .62014 .39856 .62967 .39546 .62491 .38972 Metetra
0 .023 .121 r
.62491 .38972 .62967 .39546 .63923 .39235 .63449 .38659 Metetra
0 .023 .121 r
.63449 .38659 .63923 .39235 .64882 .38923 .64411 .38345 Metetra
0 .023 .121 r
.64411 .38345 .64882 .38923 .65845 .3861 .65375 .3803 Metetra
0 .023 .121 r
.65375 .3803 .65845 .3861 .6681 .38296 .66344 .37714 Metetra
0 .023 .121 r
.66344 .37714 .6681 .38296 .6778 .37981 .67315 .37396 Metetra
0 .023 .121 r
.67315 .37396 .6778 .37981 .68752 .37665 .6829 .37078 Metetra
0 .023 .121 r
.6829 .37078 .68752 .37665 .69728 .37348 .69268 .36759 Metetra
0 .023 .121 r
.69268 .36759 .69728 .37348 .70707 .37029 .7025 .36438 Metetra
0 .023 .121 r
.7025 .36438 .70707 .37029 .7169 .3671 .71235 .36117 Metetra
0 .023 .121 r
.71235 .36117 .7169 .3671 .72676 .36389 .72223 .35794 Metetra
0 .023 .121 r
.72223 .35794 .72676 .36389 .73666 .36067 .73215 .3547 Metetra
0 .023 .121 r
.73215 .3547 .73666 .36067 .74659 .35744 .7421 .35146 Metetra
0 .023 .121 r
.7421 .35146 .74659 .35744 .75655 .3542 .75209 .34819 Metetra
0 .023 .121 r
.75209 .34819 .75655 .3542 .76655 .35095 .76211 .34492 Metetra
0 .023 .121 r
.76211 .34492 .76655 .35095 .77658 .34769 .77217 .34164 Metetra
0 .023 .121 r
.77217 .34164 .77658 .34769 .78665 .34442 .78227 .33834 Metetra
0 .023 .121 r
.78227 .33834 .78665 .34442 .79675 .34113 .7924 .33504 Metetra
0 .023 .121 r
.7924 .33504 .79675 .34113 .80689 .33784 .80256 .33172 Metetra
0 .023 .121 r
.80256 .33172 .80689 .33784 .81707 .33453 .81276 .32839 Metetra
0 .023 .121 r
.81276 .32839 .81707 .33453 .82728 .33121 .823 .32505 Metetra
0 .023 .121 r
.823 .32505 .82728 .33121 .83753 .32788 .83327 .32169 Metetra
0 .023 .121 r
.83327 .32169 .83753 .32788 .84781 .32453 .84358 .31833 Metetra
0 .023 .121 r
.84358 .31833 .84781 .32453 .85813 .32118 .85393 .31495 Metetra
0 .023 .121 r
.85393 .31495 .85813 .32118 .86849 .31781 .86431 .31156 Metetra
0 .023 .121 r
.86431 .31156 .86849 .31781 .87888 .31443 .87473 .30816 Metetra
0 .023 .121 r
.87473 .30816 .87888 .31443 .88931 .31104 .88519 .30475 Metetra
0 .023 .121 r
.28651 .49327 .292 .49839 .30048 .49562 .295 .49049 Metetra
0 .023 .121 r
.295 .49049 .30048 .49562 .30898 .49284 .30352 .48769 Metetra
0 .023 .121 r
.30352 .48769 .30898 .49284 .31751 .49006 .31207 .48489 Metetra
0 .023 .121 r
.31207 .48489 .31751 .49006 .32607 .48726 .32064 .48208 Metetra
0 .023 .121 r
.32064 .48208 .32607 .48726 .33466 .48446 .32925 .47926 Metetra
0 .023 .121 r
.32925 .47926 .33466 .48446 .34327 .48165 .33788 .47643 Metetra
0 .023 .121 r
.33788 .47643 .34327 .48165 .35191 .47883 .34654 .4736 Metetra
0 .023 .121 r
.34654 .4736 .35191 .47883 .36058 .476 .35523 .47075 Metetra
0 .023 .121 r
.35523 .47075 .36058 .476 .36928 .47316 .36394 .46789 Metetra
0 .023 .121 r
.36394 .46789 .36928 .47316 .37801 .47031 .37269 .46503 Metetra
0 .023 .121 r
.37269 .46503 .37801 .47031 .38676 .46745 .38146 .46215 Metetra
0 .023 .121 r
.38146 .46215 .38676 .46745 .39555 .46458 .39026 .45927 Metetra
0 .023 .121 r
.39026 .45927 .39555 .46458 .40436 .46171 .39909 .45637 Metetra
0 .023 .121 r
.39909 .45637 .40436 .46171 .4132 .45882 .40795 .45347 Metetra
0 .023 .121 r
.40795 .45347 .4132 .45882 .42208 .45592 .41684 .45055 Metetra
0 .023 .121 r
.41684 .45055 .42208 .45592 .43098 .45302 .42576 .44763 Metetra
0 .023 .121 r
.42576 .44763 .43098 .45302 .43991 .4501 .43471 .4447 Metetra
0 .023 .121 r
.43471 .4447 .43991 .4501 .44886 .44718 .44369 .44175 Metetra
0 .023 .121 r
.44369 .44175 .44886 .44718 .45785 .44425 .4527 .4388 Metetra
0 .023 .121 r
.4527 .4388 .45785 .44425 .46687 .4413 .46173 .43584 Metetra
0 .023 .121 r
.46173 .43584 .46687 .4413 .47592 .43835 .4708 .43287 Metetra
0 .023 .121 r
.4708 .43287 .47592 .43835 .485 .43538 .4799 .42989 Metetra
0 .023 .121 r
.4799 .42989 .485 .43538 .49411 .43241 .48903 .42689 Metetra
0 .023 .121 r
.48903 .42689 .49411 .43241 .50325 .42943 .49819 .42389 Metetra
0 .023 .121 r
.49819 .42389 .50325 .42943 .51242 .42643 .50738 .42088 Metetra
0 .023 .121 r
.50738 .42088 .51242 .42643 .52162 .42343 .5166 .41786 Metetra
0 .023 .121 r
.5166 .41786 .52162 .42343 .53085 .42042 .52585 .41483 Metetra
0 .023 .121 r
.52585 .41483 .53085 .42042 .54012 .41739 .53514 .41178 Metetra
0 .023 .121 r
.53514 .41178 .54012 .41739 .54941 .41439 .54445 .40875 Metetra
0 .024 .122 r
.54445 .40875 .54941 .41439 .55874 .41137 .5538 .4057 Metetra
0 .024 .122 r
.5538 .4057 .55874 .41137 .5681 .40875 .56318 .40283 Metetra
0 .025 .123 r
.56318 .40283 .5681 .40875 .57749 .40568 .57259 .39975 Metetra
0 .024 .122 r
.57259 .39975 .57749 .40568 .5869 .40218 .58203 .39644 Metetra
0 .024 .122 r
.58203 .39644 .5869 .40218 .59636 .39907 .5915 .39332 Metetra
0 .023 .121 r
.5915 .39332 .59636 .39907 .60584 .39594 .60101 .39019 Metetra
0 .023 .121 r
.60101 .39019 .60584 .39594 .61536 .39284 .61055 .38707 Metetra
0 .023 .121 r
.61055 .38707 .61536 .39284 .62491 .38972 .62012 .38393 Metetra
0 .023 .121 r
.62012 .38393 .62491 .38972 .63449 .38659 .62972 .38078 Metetra
0 .023 .121 r
.62972 .38078 .63449 .38659 .64411 .38345 .63936 .37762 Metetra
0 .023 .121 r
.63936 .37762 .64411 .38345 .65375 .3803 .64903 .37445 Metetra
0 .023 .121 r
.64903 .37445 .65375 .3803 .66344 .37714 .65874 .37127 Metetra
0 .023 .121 r
.65874 .37127 .66344 .37714 .67315 .37396 .66847 .36808 Metetra
0 .023 .121 r
.66847 .36808 .67315 .37396 .6829 .37078 .67825 .36488 Metetra
0 .023 .121 r
.67825 .36488 .6829 .37078 .69268 .36759 .68805 .36166 Metetra
0 .023 .121 r
.68805 .36166 .69268 .36759 .7025 .36438 .69789 .35844 Metetra
0 .023 .121 r
.69789 .35844 .7025 .36438 .71235 .36117 .70776 .3552 Metetra
0 .023 .121 r
.70776 .3552 .71235 .36117 .72223 .35794 .71767 .35196 Metetra
0 .023 .121 r
.71767 .35196 .72223 .35794 .73215 .3547 .72762 .3487 Metetra
0 .023 .121 r
.72762 .3487 .73215 .3547 .7421 .35146 .73759 .34543 Metetra
0 .023 .121 r
.73759 .34543 .7421 .35146 .75209 .34819 .74761 .34214 Metetra
0 .023 .121 r
.74761 .34214 .75209 .34819 .76211 .34492 .75765 .33885 Metetra
0 .023 .121 r
.75765 .33885 .76211 .34492 .77217 .34164 .76774 .33555 Metetra
0 .023 .121 r
.76774 .33555 .77217 .34164 .78227 .33834 .77785 .33223 Metetra
0 .023 .121 r
.77785 .33223 .78227 .33834 .7924 .33504 .78801 .3289 Metetra
0 .023 .121 r
.78801 .3289 .7924 .33504 .80256 .33172 .7982 .32556 Metetra
0 .023 .121 r
.7982 .32556 .80256 .33172 .81276 .32839 .80843 .32221 Metetra
0 .023 .121 r
.80843 .32221 .81276 .32839 .823 .32505 .81869 .31885 Metetra
0 .023 .121 r
.81869 .31885 .823 .32505 .83327 .32169 .82899 .31547 Metetra
0 .023 .121 r
.82899 .31547 .83327 .32169 .84358 .31833 .83932 .31208 Metetra
0 .023 .121 r
.83932 .31208 .84358 .31833 .85393 .31495 .8497 .30868 Metetra
0 .023 .121 r
.8497 .30868 .85393 .31495 .86431 .31156 .86011 .30527 Metetra
0 .023 .121 r
.86011 .30527 .86431 .31156 .87473 .30816 .87055 .30185 Metetra
0 .023 .121 r
.87055 .30185 .87473 .30816 .88519 .30475 .88104 .29841 Metetra
0 .023 .121 r
.28098 .48812 .28651 .49327 .295 .49049 .28949 .48532 Metetra
0 .023 .121 r
.28949 .48532 .295 .49049 .30352 .48769 .29803 .48252 Metetra
0 .023 .121 r
.29803 .48252 .30352 .48769 .31207 .48489 .30659 .4797 Metetra
0 .023 .121 r
.30659 .4797 .31207 .48489 .32064 .48208 .31518 .47687 Metetra
0 .023 .121 r
.31518 .47687 .32064 .48208 .32925 .47926 .3238 .47403 Metetra
0 .023 .121 r
.3238 .47403 .32925 .47926 .33788 .47643 .33245 .47119 Metetra
0 .023 .121 r
.33245 .47119 .33788 .47643 .34654 .4736 .34113 .46833 Metetra
0 .023 .121 r
.34113 .46833 .34654 .4736 .35523 .47075 .34983 .46547 Metetra
0 .023 .121 r
.34983 .46547 .35523 .47075 .36394 .46789 .35857 .46259 Metetra
0 .023 .121 r
.35857 .46259 .36394 .46789 .37269 .46503 .36733 .45971 Metetra
0 .023 .121 r
.36733 .45971 .37269 .46503 .38146 .46215 .37612 .45682 Metetra
0 .023 .121 r
.37612 .45682 .38146 .46215 .39026 .45927 .38494 .45391 Metetra
0 .023 .121 r
.38494 .45391 .39026 .45927 .39909 .45637 .39379 .451 Metetra
0 .023 .121 r
.39379 .451 .39909 .45637 .40795 .45347 .40267 .44808 Metetra
0 .023 .121 r
.40267 .44808 .40795 .45347 .41684 .45055 .41158 .44515 Metetra
0 .023 .121 r
.41158 .44515 .41684 .45055 .42576 .44763 .42051 .44221 Metetra
0 .023 .121 r
.42051 .44221 .42576 .44763 .43471 .4447 .42948 .43926 Metetra
0 .023 .121 r
.42948 .43926 .43471 .4447 .44369 .44175 .43848 .4363 Metetra
0 .023 .121 r
.43848 .4363 .44369 .44175 .4527 .4388 .44751 .43333 Metetra
0 .023 .121 r
.44751 .43333 .4527 .4388 .46173 .43584 .45656 .43035 Metetra
0 .023 .121 r
.45656 .43035 .46173 .43584 .4708 .43287 .46565 .42736 Metetra
0 .023 .121 r
.46565 .42736 .4708 .43287 .4799 .42989 .47477 .42436 Metetra
0 .023 .121 r
.47477 .42436 .4799 .42989 .48903 .42689 .48392 .42135 Metetra
0 .023 .121 r
.48392 .42135 .48903 .42689 .49819 .42389 .4931 .41833 Metetra
0 .023 .121 r
.4931 .41833 .49819 .42389 .50738 .42088 .50231 .41529 Metetra
0 .023 .121 r
.50231 .41529 .50738 .42088 .5166 .41786 .51155 .41226 Metetra
0 .023 .121 r
.51155 .41226 .5166 .41786 .52585 .41483 .52082 .40922 Metetra
0 .023 .121 r
.52082 .40922 .52585 .41483 .53514 .41178 .53012 .40615 Metetra
0 .024 .122 r
.53012 .40615 .53514 .41178 .54445 .40875 .53946 .40316 Metetra
0 .024 .122 r
.53946 .40316 .54445 .40875 .5538 .4057 .54883 .40015 Metetra
0 .025 .123 r
.54883 .40015 .5538 .4057 .56318 .40283 .55824 .39823 Metetra
0 .026 .125 r
.55824 .39823 .56318 .40283 .57259 .39975 .56768 .39512 Metetra
0 .025 .123 r
.56768 .39512 .57259 .39975 .58203 .39644 .57712 .39084 Metetra
0 .024 .122 r
.57712 .39084 .58203 .39644 .5915 .39332 .58662 .38764 Metetra
0 .024 .122 r
.58662 .38764 .5915 .39332 .60101 .39019 .59614 .38442 Metetra
0 .023 .121 r
.59614 .38442 .60101 .39019 .61055 .38707 .60571 .38128 Metetra
0 .023 .121 r
.60571 .38128 .61055 .38707 .62012 .38393 .6153 .37812 Metetra
0 .023 .121 r
.6153 .37812 .62012 .38393 .62972 .38078 .62493 .37494 Metetra
0 .023 .121 r
.62493 .37494 .62972 .38078 .63936 .37762 .63459 .37177 Metetra
0 .023 .121 r
.63459 .37177 .63936 .37762 .64903 .37445 .64428 .36857 Metetra
0 .023 .121 r
.64428 .36857 .64903 .37445 .65874 .37127 .65401 .36537 Metetra
0 .023 .121 r
.65401 .36537 .65874 .37127 .66847 .36808 .66377 .36216 Metetra
0 .023 .121 r
.66377 .36216 .66847 .36808 .67825 .36488 .67356 .35894 Metetra
0 .023 .121 r
.67356 .35894 .67825 .36488 .68805 .36166 .68339 .3557 Metetra
0 .023 .121 r
.68339 .3557 .68805 .36166 .69789 .35844 .69325 .35246 Metetra
0 .023 .121 r
.69325 .35246 .69789 .35844 .70776 .3552 .70315 .3492 Metetra
0 .023 .121 r
.70315 .3492 .70776 .3552 .71767 .35196 .71308 .34593 Metetra
0 .023 .121 r
.71308 .34593 .71767 .35196 .72762 .3487 .72305 .34265 Metetra
0 .023 .121 r
.72305 .34265 .72762 .3487 .73759 .34543 .73305 .33936 Metetra
0 .023 .121 r
.73305 .33936 .73759 .34543 .74761 .34214 .74309 .33606 Metetra
0 .023 .121 r
.74309 .33606 .74761 .34214 .75765 .33885 .75316 .33274 Metetra
0 .023 .121 r
.75316 .33274 .75765 .33885 .76774 .33555 .76327 .32942 Metetra
0 .023 .121 r
.76327 .32942 .76774 .33555 .77785 .33223 .77341 .32608 Metetra
0 .023 .121 r
.77341 .32608 .77785 .33223 .78801 .3289 .78359 .32273 Metetra
0 .023 .121 r
.78359 .32273 .78801 .3289 .7982 .32556 .79381 .31937 Metetra
0 .023 .121 r
.79381 .31937 .7982 .32556 .80843 .32221 .80406 .31599 Metetra
0 .023 .121 r
.80406 .31599 .80843 .32221 .81869 .31885 .81435 .31261 Metetra
0 .023 .121 r
.81435 .31261 .81869 .31885 .82899 .31547 .82468 .30921 Metetra
0 .023 .121 r
.82468 .30921 .82899 .31547 .83932 .31208 .83504 .3058 Metetra
0 .023 .121 r
.83504 .3058 .83932 .31208 .8497 .30868 .84544 .30238 Metetra
0 .023 .121 r
.84544 .30238 .8497 .30868 .86011 .30527 .85587 .29894 Metetra
0 .023 .121 r
.85587 .29894 .86011 .30527 .87055 .30185 .86635 .2955 Metetra
0 .023 .121 r
.86635 .2955 .87055 .30185 .88104 .29841 .87686 .29204 Metetra
0 .023 .121 r
.27542 .48295 .28098 .48812 .28949 .48532 .28395 .48013 Metetra
0 .023 .121 r
.28395 .48013 .28949 .48532 .29803 .48252 .2925 .47731 Metetra
0 .023 .121 r
.2925 .47731 .29803 .48252 .30659 .4797 .30108 .47447 Metetra
0 .023 .121 r
.30108 .47447 .30659 .4797 .31518 .47687 .30969 .47163 Metetra
0 .023 .121 r
.30969 .47163 .31518 .47687 .3238 .47403 .31833 .46877 Metetra
0 .023 .121 r
.31833 .46877 .3238 .47403 .33245 .47119 .32699 .46591 Metetra
0 .023 .121 r
.32699 .46591 .33245 .47119 .34113 .46833 .33569 .46304 Metetra
0 .023 .121 r
.33569 .46304 .34113 .46833 .34983 .46547 .34441 .46015 Metetra
0 .023 .121 r
.34441 .46015 .34983 .46547 .35857 .46259 .35316 .45726 Metetra
0 .023 .121 r
.35316 .45726 .35857 .46259 .36733 .45971 .36194 .45436 Metetra
0 .023 .121 r
.36194 .45436 .36733 .45971 .37612 .45682 .37075 .45145 Metetra
0 .023 .121 r
.37075 .45145 .37612 .45682 .38494 .45391 .37959 .44853 Metetra
0 .023 .121 r
.37959 .44853 .38494 .45391 .39379 .451 .38846 .4456 Metetra
0 .023 .121 r
.38846 .4456 .39379 .451 .40267 .44808 .39735 .44266 Metetra
0 .023 .121 r
.39735 .44266 .40267 .44808 .41158 .44515 .40628 .43971 Metetra
0 .023 .121 r
.40628 .43971 .41158 .44515 .42051 .44221 .41524 .43675 Metetra
0 .023 .121 r
.41524 .43675 .42051 .44221 .42948 .43926 .42422 .43378 Metetra
0 .023 .121 r
.42422 .43378 .42948 .43926 .43848 .4363 .43324 .4308 Metetra
0 .023 .121 r
.43324 .4308 .43848 .4363 .44751 .43333 .44228 .42782 Metetra
0 .023 .121 r
.44228 .42782 .44751 .43333 .45656 .43035 .45136 .42482 Metetra
0 .023 .121 r
.45136 .42482 .45656 .43035 .46565 .42736 .46047 .42181 Metetra
0 .023 .121 r
.46047 .42181 .46565 .42736 .47477 .42436 .4696 .41879 Metetra
0 .023 .121 r
.4696 .41879 .47477 .42436 .48392 .42135 .47877 .41576 Metetra
0 .023 .121 r
.47877 .41576 .48392 .42135 .4931 .41833 .48797 .41272 Metetra
0 .023 .121 r
.48797 .41272 .4931 .41833 .50231 .41529 .4972 .40967 Metetra
0 .023 .121 r
.4972 .40967 .50231 .41529 .51155 .41226 .50646 .40661 Metetra
0 .023 .121 r
.50646 .40661 .51155 .41226 .52082 .40922 .51576 .40354 Metetra
0 .023 .121 r
.51576 .40354 .52082 .40922 .53012 .40615 .52508 .40046 Metetra
0 .024 .122 r
.52508 .40046 .53012 .40615 .53946 .40316 .53444 .39739 Metetra
0 .024 .122 r
.53444 .39739 .53946 .40316 .54883 .40015 .54383 .39431 Metetra
0 .025 .123 r
.54383 .39431 .54883 .40015 .55824 .39823 .55325 .39156 Metetra
0 .026 .125 r
.55325 .39156 .55824 .39823 .56768 .39512 .5627 .38843 Metetra
0 .025 .123 r
.5627 .38843 .56768 .39512 .57712 .39084 .57218 .38494 Metetra
0 .024 .122 r
.57218 .38494 .57712 .39084 .58662 .38764 .5817 .38178 Metetra
0 .024 .122 r
.5817 .38178 .58662 .38764 .59614 .38442 .59125 .3786 Metetra
0 .023 .121 r
.59125 .3786 .59614 .38442 .60571 .38128 .60083 .37543 Metetra
0 .023 .121 r
.60083 .37543 .60571 .38128 .6153 .37812 .61045 .37225 Metetra
0 .023 .121 r
.61045 .37225 .6153 .37812 .62493 .37494 .6201 .36906 Metetra
0 .023 .121 r
.6201 .36906 .62493 .37494 .63459 .37177 .62978 .36587 Metetra
0 .023 .121 r
.62978 .36587 .63459 .37177 .64428 .36857 .6395 .36265 Metetra
0 .023 .121 r
.6395 .36265 .64428 .36857 .65401 .36537 .64925 .35943 Metetra
0 .023 .121 r
.64925 .35943 .65401 .36537 .66377 .36216 .65903 .3562 Metetra
0 .023 .121 r
.65903 .3562 .66377 .36216 .67356 .35894 .66885 .35296 Metetra
0 .023 .121 r
.66885 .35296 .67356 .35894 .68339 .3557 .6787 .3497 Metetra
0 .023 .121 r
.6787 .3497 .68339 .3557 .69325 .35246 .68859 .34643 Metetra
0 .023 .121 r
.68859 .34643 .69325 .35246 .70315 .3492 .69851 .34316 Metetra
0 .023 .121 r
.69851 .34316 .70315 .3492 .71308 .34593 .70847 .33987 Metetra
0 .023 .121 r
.70847 .33987 .71308 .34593 .72305 .34265 .71846 .33657 Metetra
0 .023 .121 r
.71846 .33657 .72305 .34265 .73305 .33936 .72848 .33325 Metetra
0 .023 .121 r
.72848 .33325 .73305 .33936 .74309 .33606 .73855 .32993 Metetra
0 .023 .121 r
.73855 .32993 .74309 .33606 .75316 .33274 .74864 .32659 Metetra
0 .023 .121 r
.74864 .32659 .75316 .33274 .76327 .32942 .75878 .32324 Metetra
0 .023 .121 r
.75878 .32324 .76327 .32942 .77341 .32608 .76894 .31988 Metetra
0 .023 .121 r
.76894 .31988 .77341 .32608 .78359 .32273 .77915 .31651 Metetra
0 .023 .121 r
.77915 .31651 .78359 .32273 .79381 .31937 .78939 .31313 Metetra
0 .023 .121 r
.78939 .31313 .79381 .31937 .80406 .31599 .79967 .30973 Metetra
0 .023 .121 r
.79967 .30973 .80406 .31599 .81435 .31261 .80998 .30632 Metetra
0 .023 .121 r
.80998 .30632 .81435 .31261 .82468 .30921 .82034 .3029 Metetra
0 .023 .121 r
.82034 .3029 .82468 .30921 .83504 .3058 .83072 .29947 Metetra
0 .023 .121 r
.83072 .29947 .83504 .3058 .84544 .30238 .84115 .29603 Metetra
0 .023 .121 r
.84115 .29603 .84544 .30238 .85587 .29894 .85161 .29257 Metetra
0 .023 .121 r
.85161 .29257 .85587 .29894 .86635 .2955 .86211 .2891 Metetra
0 .023 .121 r
.86211 .2891 .86635 .2955 .87686 .29204 .87265 .28562 Metetra
0 .023 .121 r
.26983 .47774 .27542 .48295 .28395 .48013 .27837 .47491 Metetra
0 .023 .121 r
.27837 .47491 .28395 .48013 .2925 .47731 .28694 .47206 Metetra
0 .023 .121 r
.28694 .47206 .2925 .47731 .30108 .47447 .29554 .46921 Metetra
0 .023 .121 r
.29554 .46921 .30108 .47447 .30969 .47163 .30417 .46635 Metetra
0 .023 .121 r
.30417 .46635 .30969 .47163 .31833 .46877 .31282 .46348 Metetra
0 .023 .121 r
.31282 .46348 .31833 .46877 .32699 .46591 .3215 .4606 Metetra
0 .023 .121 r
.3215 .4606 .32699 .46591 .33569 .46304 .33021 .45771 Metetra
0 .023 .121 r
.33021 .45771 .33569 .46304 .34441 .46015 .33895 .45481 Metetra
0 .023 .121 r
.33895 .45481 .34441 .46015 .35316 .45726 .34772 .4519 Metetra
0 .023 .121 r
.34772 .4519 .35316 .45726 .36194 .45436 .35652 .44898 Metetra
0 .023 .121 r
.35652 .44898 .36194 .45436 .37075 .45145 .36535 .44605 Metetra
0 .023 .121 r
.36535 .44605 .37075 .45145 .37959 .44853 .3742 .44311 Metetra
0 .023 .121 r
.3742 .44311 .37959 .44853 .38846 .4456 .38309 .44017 Metetra
0 .023 .121 r
.38309 .44017 .38846 .4456 .39735 .44266 .392 .43721 Metetra
0 .023 .121 r
.392 .43721 .39735 .44266 .40628 .43971 .40095 .43424 Metetra
0 .023 .121 r
.40095 .43424 .40628 .43971 .41524 .43675 .40992 .43126 Metetra
0 .023 .121 r
.40992 .43126 .41524 .43675 .42422 .43378 .41893 .42828 Metetra
0 .023 .121 r
.41893 .42828 .42422 .43378 .43324 .4308 .42796 .42528 Metetra
0 .023 .121 r
.42796 .42528 .43324 .4308 .44228 .42782 .43703 .42227 Metetra
0 .023 .121 r
.43703 .42227 .44228 .42782 .45136 .42482 .44612 .41925 Metetra
0 .023 .121 r
.44612 .41925 .45136 .42482 .46047 .42181 .45525 .41623 Metetra
0 .023 .121 r
.45525 .41623 .46047 .42181 .4696 .41879 .46441 .41319 Metetra
0 .023 .121 r
.46441 .41319 .4696 .41879 .47877 .41576 .4736 .41014 Metetra
0 .023 .121 r
.4736 .41014 .47877 .41576 .48797 .41272 .48282 .40709 Metetra
0 .023 .121 r
.48282 .40709 .48797 .41272 .4972 .40967 .49207 .40402 Metetra
0 .023 .121 r
.49207 .40402 .4972 .40967 .50646 .40661 .50135 .40094 Metetra
0 .023 .121 r
.50135 .40094 .50646 .40661 .51576 .40354 .51066 .39786 Metetra
0 .023 .121 r
.51066 .39786 .51576 .40354 .52508 .40046 .52001 .39475 Metetra
0 .024 .122 r
.52001 .39475 .52508 .40046 .53444 .39739 .52938 .39174 Metetra
0 .024 .122 r
.52938 .39174 .53444 .39739 .54383 .39431 .53879 .3887 Metetra
0 .025 .124 r
.53879 .3887 .54383 .39431 .55325 .39156 .54825 .38693 Metetra
0 .026 .126 r
.54825 .38693 .55325 .39156 .5627 .38843 .55772 .38379 Metetra
0 .025 .124 r
.55772 .38379 .5627 .38843 .57218 .38494 .56722 .37927 Metetra
0 .024 .122 r
.56722 .37927 .57218 .38494 .5817 .38178 .57676 .37602 Metetra
0 .024 .122 r
.57676 .37602 .5817 .38178 .59125 .3786 .58633 .37275 Metetra
0 .023 .121 r
.58633 .37275 .59125 .3786 .60083 .37543 .59593 .36958 Metetra
0 .023 .121 r
.59593 .36958 .60083 .37543 .61045 .37225 .60557 .36637 Metetra
0 .023 .121 r
.60557 .36637 .61045 .37225 .6201 .36906 .61524 .36315 Metetra
0 .023 .121 r
.61524 .36315 .6201 .36906 .62978 .36587 .62495 .35994 Metetra
0 .023 .121 r
.62495 .35994 .62978 .36587 .6395 .36265 .63468 .3567 Metetra
0 .023 .121 r
.63468 .3567 .6395 .36265 .64925 .35943 .64446 .35346 Metetra
0 .023 .121 r
.64446 .35346 .64925 .35943 .65903 .3562 .65426 .35021 Metetra
0 .023 .121 r
.65426 .35021 .65903 .3562 .66885 .35296 .66411 .34694 Metetra
0 .023 .121 r
.66411 .34694 .66885 .35296 .6787 .3497 .67398 .34366 Metetra
0 .023 .121 r
.67398 .34366 .6787 .3497 .68859 .34643 .68389 .34037 Metetra
0 .023 .121 r
.68389 .34037 .68859 .34643 .69851 .34316 .69384 .33707 Metetra
0 .023 .121 r
.69384 .33707 .69851 .34316 .70847 .33987 .70382 .33376 Metetra
0 .023 .121 r
.70382 .33376 .70847 .33987 .71846 .33657 .71383 .33044 Metetra
0 .023 .121 r
.71383 .33044 .71846 .33657 .72848 .33325 .72388 .32711 Metetra
0 .023 .121 r
.72388 .32711 .72848 .33325 .73855 .32993 .73397 .32376 Metetra
0 .023 .121 r
.73397 .32376 .73855 .32993 .74864 .32659 .74409 .3204 Metetra
0 .023 .121 r
.74409 .3204 .74864 .32659 .75878 .32324 .75425 .31703 Metetra
0 .023 .121 r
.75425 .31703 .75878 .32324 .76894 .31988 .76445 .31365 Metetra
0 .023 .121 r
.76445 .31365 .76894 .31988 .77915 .31651 .77468 .31026 Metetra
0 .023 .121 r
.77468 .31026 .77915 .31651 .78939 .31313 .78494 .30685 Metetra
0 .023 .121 r
.78494 .30685 .78939 .31313 .79967 .30973 .79525 .30343 Metetra
0 .023 .121 r
.79525 .30343 .79967 .30973 .80998 .30632 .80559 .3 Metetra
0 .023 .121 r
.80559 .3 .80998 .30632 .82034 .3029 .81597 .29656 Metetra
0 .023 .121 r
.81597 .29656 .82034 .3029 .83072 .29947 .82638 .2931 Metetra
0 .023 .121 r
.82638 .2931 .83072 .29947 .84115 .29603 .83683 .28963 Metetra
0 .023 .121 r
.83683 .28963 .84115 .29603 .85161 .29257 .84732 .28615 Metetra
0 .023 .121 r
.84732 .28615 .85161 .29257 .86211 .2891 .85785 .28266 Metetra
0 .023 .121 r
.85785 .28266 .86211 .2891 .87265 .28562 .86842 .27915 Metetra
0 .023 .121 r
.2642 .4725 .26983 .47774 .27837 .47491 .27276 .46965 Metetra
0 .023 .121 r
.27276 .46965 .27837 .47491 .28694 .47206 .28135 .46679 Metetra
0 .023 .121 r
.28135 .46679 .28694 .47206 .29554 .46921 .28996 .46392 Metetra
0 .023 .121 r
.28996 .46392 .29554 .46921 .30417 .46635 .29861 .46104 Metetra
0 .023 .121 r
.29861 .46104 .30417 .46635 .31282 .46348 .30728 .45815 Metetra
0 .023 .121 r
.30728 .45815 .31282 .46348 .3215 .4606 .31598 .45526 Metetra
0 .023 .121 r
.31598 .45526 .3215 .4606 .33021 .45771 .32471 .45235 Metetra
0 .023 .121 r
.32471 .45235 .33021 .45771 .33895 .45481 .33346 .44943 Metetra
0 .023 .121 r
.33346 .44943 .33895 .45481 .34772 .4519 .34225 .4465 Metetra
0 .023 .121 r
.34225 .4465 .34772 .4519 .35652 .44898 .35107 .44357 Metetra
0 .023 .121 r
.35107 .44357 .35652 .44898 .36535 .44605 .35991 .44062 Metetra
0 .023 .121 r
.35991 .44062 .36535 .44605 .3742 .44311 .36878 .43767 Metetra
0 .023 .121 r
.36878 .43767 .3742 .44311 .38309 .44017 .37769 .4347 Metetra
0 .023 .121 r
.37769 .4347 .38309 .44017 .392 .43721 .38662 .43172 Metetra
0 .023 .121 r
.38662 .43172 .392 .43721 .40095 .43424 .39559 .42874 Metetra
0 .023 .121 r
.39559 .42874 .40095 .43424 .40992 .43126 .40458 .42574 Metetra
0 .023 .121 r
.40458 .42574 .40992 .43126 .41893 .42828 .4136 .42274 Metetra
0 .023 .121 r
.4136 .42274 .41893 .42828 .42796 .42528 .42266 .41972 Metetra
0 .023 .121 r
.42266 .41972 .42796 .42528 .43703 .42227 .43174 .4167 Metetra
0 .023 .121 r
.43174 .4167 .43703 .42227 .44612 .41925 .44086 .41366 Metetra
0 .023 .121 r
.44086 .41366 .44612 .41925 .45525 .41623 .45 .41061 Metetra
0 .023 .121 r
.45 .41061 .45525 .41623 .46441 .41319 .45918 .40756 Metetra
0 .023 .121 r
.45918 .40756 .46441 .41319 .4736 .41014 .46839 .40449 Metetra
0 .023 .121 r
.46839 .40449 .4736 .41014 .48282 .40709 .47763 .40143 Metetra
0 .023 .121 r
.47763 .40143 .48282 .40709 .49207 .40402 .4869 .39832 Metetra
0 .023 .121 r
.4869 .39832 .49207 .40402 .50135 .40094 .4962 .39524 Metetra
0 .023 .122 r
.4962 .39524 .50135 .40094 .51066 .39786 .50553 .39215 Metetra
0 .023 .122 r
.50553 .39215 .51066 .39786 .52001 .39475 .5149 .38901 Metetra
0 .024 .122 r
.5149 .38901 .52001 .39475 .52938 .39174 .5243 .38606 Metetra
0 .024 .122 r
.5243 .38606 .52938 .39174 .53879 .3887 .53373 .38307 Metetra
0 .027 .127 r
.53373 .38307 .53879 .3887 .54825 .38693 .54321 .38243 Metetra
0 .03 .131 r
.54321 .38243 .54825 .38693 .55772 .38379 .55271 .37927 Metetra
0 .027 .127 r
.55271 .37927 .55772 .38379 .56722 .37927 .56222 .37358 Metetra
0 .024 .122 r
.56222 .37358 .56722 .37927 .57676 .37602 .57178 .37024 Metetra
0 .024 .122 r
.57178 .37024 .57676 .37602 .58633 .37275 .58137 .36687 Metetra
0 .023 .122 r
.58137 .36687 .58633 .37275 .59593 .36958 .591 .36368 Metetra
0 .023 .122 r
.591 .36368 .59593 .36958 .60557 .36637 .60066 .36045 Metetra
0 .023 .121 r
.60066 .36045 .60557 .36637 .61524 .36315 .61035 .3572 Metetra
0 .023 .121 r
.61035 .3572 .61524 .36315 .62495 .35994 .62008 .35397 Metetra
0 .023 .121 r
.62008 .35397 .62495 .35994 .63468 .3567 .62984 .35071 Metetra
0 .023 .121 r
.62984 .35071 .63468 .3567 .64446 .35346 .63964 .34745 Metetra
0 .023 .121 r
.63964 .34745 .64446 .35346 .65426 .35021 .64947 .34417 Metetra
0 .023 .121 r
.64947 .34417 .65426 .35021 .66411 .34694 .65933 .34088 Metetra
0 .023 .121 r
.65933 .34088 .66411 .34694 .67398 .34366 .66923 .33759 Metetra
0 .023 .121 r
.66923 .33759 .67398 .34366 .68389 .34037 .67917 .33427 Metetra
0 .023 .121 r
.67917 .33427 .68389 .34037 .69384 .33707 .68913 .33095 Metetra
0 .023 .121 r
.68913 .33095 .69384 .33707 .70382 .33376 .69914 .32762 Metetra
0 .023 .121 r
.69914 .32762 .70382 .33376 .71383 .33044 .70918 .32428 Metetra
0 .023 .121 r
.70918 .32428 .71383 .33044 .72388 .32711 .71925 .32092 Metetra
0 .023 .121 r
.71925 .32092 .72388 .32711 .73397 .32376 .72937 .31755 Metetra
0 .023 .121 r
.72937 .31755 .73397 .32376 .74409 .3204 .73951 .31417 Metetra
0 .023 .121 r
.73951 .31417 .74409 .3204 .75425 .31703 .7497 .31078 Metetra
0 .023 .121 r
.7497 .31078 .75425 .31703 .76445 .31365 .75992 .30737 Metetra
0 .023 .121 r
.75992 .30737 .76445 .31365 .77468 .31026 .77017 .30396 Metetra
0 .023 .121 r
.77017 .30396 .77468 .31026 .78494 .30685 .78047 .30053 Metetra
0 .023 .121 r
.78047 .30053 .78494 .30685 .79525 .30343 .7908 .29709 Metetra
0 .023 .121 r
.7908 .29709 .79525 .30343 .80559 .3 .80116 .29363 Metetra
0 .023 .121 r
.80116 .29363 .80559 .3 .81597 .29656 .81157 .29017 Metetra
0 .023 .121 r
.81157 .29017 .81597 .29656 .82638 .2931 .82201 .28669 Metetra
0 .023 .121 r
.82201 .28669 .82638 .2931 .83683 .28963 .83249 .2832 Metetra
0 .023 .121 r
.83249 .2832 .83683 .28963 .84732 .28615 .84301 .2797 Metetra
0 .023 .121 r
.84301 .2797 .84732 .28615 .85785 .28266 .85356 .27618 Metetra
0 .023 .121 r
.85356 .27618 .85785 .28266 .86842 .27915 .86416 .27265 Metetra
0 .023 .121 r
.25854 .46723 .2642 .4725 .27276 .46965 .26712 .46436 Metetra
0 .023 .121 r
.26712 .46436 .27276 .46965 .28135 .46679 .27572 .46149 Metetra
0 .023 .121 r
.27572 .46149 .28135 .46679 .28996 .46392 .28435 .4586 Metetra
0 .023 .121 r
.28435 .4586 .28996 .46392 .29861 .46104 .29301 .4557 Metetra
0 .023 .121 r
.29301 .4557 .29861 .46104 .30728 .45815 .3017 .4528 Metetra
0 .023 .121 r
.3017 .4528 .30728 .45815 .31598 .45526 .31042 .44988 Metetra
0 .023 .121 r
.31042 .44988 .31598 .45526 .32471 .45235 .31916 .44695 Metetra
0 .023 .121 r
.31916 .44695 .32471 .45235 .33346 .44943 .32794 .44402 Metetra
0 .023 .121 r
.32794 .44402 .33346 .44943 .34225 .4465 .33674 .44107 Metetra
0 .023 .121 r
.33674 .44107 .34225 .4465 .35107 .44357 .34558 .43812 Metetra
0 .023 .121 r
.34558 .43812 .35107 .44357 .35991 .44062 .35444 .43516 Metetra
0 .023 .121 r
.35444 .43516 .35991 .44062 .36878 .43767 .36333 .43218 Metetra
0 .023 .121 r
.36333 .43218 .36878 .43767 .37769 .4347 .37226 .4292 Metetra
0 .023 .121 r
.37226 .4292 .37769 .4347 .38662 .43172 .38121 .4262 Metetra
0 .023 .121 r
.38121 .4262 .38662 .43172 .39559 .42874 .39019 .4232 Metetra
0 .023 .121 r
.39019 .4232 .39559 .42874 .40458 .42574 .3992 .42018 Metetra
0 .023 .121 r
.3992 .42018 .40458 .42574 .4136 .42274 .40825 .41716 Metetra
0 .023 .121 r
.40825 .41716 .4136 .42274 .42266 .41972 .41732 .41412 Metetra
0 .023 .121 r
.41732 .41412 .42266 .41972 .43174 .4167 .42642 .41108 Metetra
0 .023 .121 r
.42642 .41108 .43174 .4167 .44086 .41366 .43556 .40802 Metetra
0 .023 .121 r
.43556 .40802 .44086 .41366 .45 .41061 .44472 .40496 Metetra
0 .023 .121 r
.44472 .40496 .45 .41061 .45918 .40756 .45392 .40188 Metetra
0 .023 .121 r
.45392 .40188 .45918 .40756 .46839 .40449 .46315 .3988 Metetra
0 .023 .121 r
.46315 .3988 .46839 .40449 .47763 .40143 .47241 .39571 Metetra
0 .023 .121 r
.47241 .39571 .47763 .40143 .4869 .39832 .4817 .39259 Metetra
0 .023 .121 r
.4817 .39259 .4869 .39832 .4962 .39524 .49102 .38948 Metetra
0 .023 .122 r
.49102 .38948 .4962 .39524 .50553 .39215 .50037 .38636 Metetra
0 .023 .122 r
.50037 .38636 .50553 .39215 .5149 .38901 .50976 .38321 Metetra
0 .024 .122 r
.50976 .38321 .5149 .38901 .5243 .38606 .51918 .38013 Metetra
0 .024 .122 r
.51918 .38013 .5243 .38606 .53373 .38307 .52863 .37703 Metetra
0 .027 .126 r
.52863 .37703 .53373 .38307 .54321 .38243 .53812 .37485 Metetra
0 .03 .13 r
.53812 .37485 .54321 .38243 .55271 .37927 .54764 .37167 Metetra
0 .027 .126 r
.54764 .37167 .55271 .37927 .56222 .37358 .55718 .36748 Metetra
0 .024 .122 r
.55718 .36748 .56222 .37358 .57178 .37024 .56677 .36421 Metetra
0 .024 .122 r
.56677 .36421 .57178 .37024 .58137 .36687 .57638 .36093 Metetra
0 .023 .122 r
.57638 .36093 .58137 .36687 .591 .36368 .58603 .35771 Metetra
0 .023 .122 r
.58603 .35771 .591 .36368 .60066 .36045 .59571 .35446 Metetra
0 .023 .121 r
.59571 .35446 .60066 .36045 .61035 .3572 .60543 .35121 Metetra
0 .023 .121 r
.60543 .35121 .61035 .3572 .62008 .35397 .61518 .34795 Metetra
0 .023 .121 r
.61518 .34795 .62008 .35397 .62984 .35071 .62497 .34467 Metetra
0 .023 .121 r
.62497 .34467 .62984 .35071 .63964 .34745 .63478 .34139 Metetra
0 .023 .121 r
.63478 .34139 .63964 .34745 .64947 .34417 .64464 .33809 Metetra
0 .023 .121 r
.64464 .33809 .64947 .34417 .65933 .34088 .65453 .33478 Metetra
0 .023 .121 r
.65453 .33478 .65933 .34088 .66923 .33759 .66445 .33147 Metetra
0 .023 .121 r
.66445 .33147 .66923 .33759 .67917 .33427 .67441 .32813 Metetra
0 .023 .121 r
.67441 .32813 .67917 .33427 .68913 .33095 .6844 .32479 Metetra
0 .023 .121 r
.6844 .32479 .68913 .33095 .69914 .32762 .69443 .32144 Metetra
0 .023 .121 r
.69443 .32144 .69914 .32762 .70918 .32428 .70449 .31807 Metetra
0 .023 .121 r
.70449 .31807 .70918 .32428 .71925 .32092 .71459 .31469 Metetra
0 .023 .121 r
.71459 .31469 .71925 .32092 .72937 .31755 .72473 .3113 Metetra
0 .023 .121 r
.72473 .3113 .72937 .31755 .73951 .31417 .7349 .3079 Metetra
0 .023 .121 r
.7349 .3079 .73951 .31417 .7497 .31078 .74511 .30448 Metetra
0 .023 .121 r
.74511 .30448 .7497 .31078 .75992 .30737 .75536 .30106 Metetra
0 .023 .121 r
.75536 .30106 .75992 .30737 .77017 .30396 .76564 .29762 Metetra
0 .023 .121 r
.76564 .29762 .77017 .30396 .78047 .30053 .77596 .29417 Metetra
0 .023 .121 r
.77596 .29417 .78047 .30053 .7908 .29709 .78632 .2907 Metetra
0 .023 .121 r
.78632 .2907 .7908 .29709 .80116 .29363 .79671 .28723 Metetra
0 .023 .121 r
.79671 .28723 .80116 .29363 .81157 .29017 .80714 .28374 Metetra
0 .023 .121 r
.80714 .28374 .81157 .29017 .82201 .28669 .81761 .28024 Metetra
0 .023 .121 r
.81761 .28024 .82201 .28669 .83249 .2832 .82812 .27672 Metetra
0 .023 .121 r
.82812 .27672 .83249 .2832 .84301 .2797 .83866 .27319 Metetra
0 .023 .121 r
.83866 .27319 .84301 .2797 .85356 .27618 .84924 .26965 Metetra
0 .023 .121 r
.84924 .26965 .85356 .27618 .86416 .27265 .85987 .2661 Metetra
0 .023 .121 r
.25285 .46193 .25854 .46723 .26712 .46436 .26144 .45905 Metetra
0 .023 .121 r
.26144 .45905 .26712 .46436 .27572 .46149 .27006 .45615 Metetra
0 .023 .121 r
.27006 .45615 .27572 .46149 .28435 .4586 .27871 .45324 Metetra
0 .023 .121 r
.27871 .45324 .28435 .4586 .29301 .4557 .28738 .45033 Metetra
0 .023 .121 r
.28738 .45033 .29301 .4557 .3017 .4528 .29609 .44741 Metetra
0 .023 .121 r
.29609 .44741 .3017 .4528 .31042 .44988 .30483 .44448 Metetra
0 .023 .121 r
.30483 .44448 .31042 .44988 .31916 .44695 .31359 .44153 Metetra
0 .023 .121 r
.31359 .44153 .31916 .44695 .32794 .44402 .32238 .43858 Metetra
0 .023 .121 r
.32238 .43858 .32794 .44402 .33674 .44107 .3312 .43562 Metetra
0 .023 .121 r
.3312 .43562 .33674 .44107 .34558 .43812 .34006 .43264 Metetra
0 .023 .121 r
.34006 .43264 .34558 .43812 .35444 .43516 .34894 .42966 Metetra
0 .023 .121 r
.34894 .42966 .35444 .43516 .36333 .43218 .35785 .42667 Metetra
0 .023 .121 r
.35785 .42667 .36333 .43218 .37226 .4292 .36679 .42366 Metetra
0 .023 .121 r
.36679 .42366 .37226 .4292 .38121 .4262 .37576 .42066 Metetra
0 .023 .121 r
.37576 .42066 .38121 .4262 .39019 .4232 .38476 .41763 Metetra
0 .023 .121 r
.38476 .41763 .39019 .4232 .3992 .42018 .39379 .4146 Metetra
0 .023 .121 r
.39379 .4146 .3992 .42018 .40825 .41716 .40285 .41156 Metetra
0 .023 .121 r
.40285 .41156 .40825 .41716 .41732 .41412 .41195 .4085 Metetra
0 .023 .121 r
.41195 .4085 .41732 .41412 .42642 .41108 .42107 .40546 Metetra
0 .023 .121 r
.42107 .40546 .42642 .41108 .43556 .40802 .43022 .40236 Metetra
0 .023 .121 r
.43022 .40236 .43556 .40802 .44472 .40496 .43941 .3993 Metetra
0 .023 .121 r
.43941 .3993 .44472 .40496 .45392 .40188 .44862 .39621 Metetra
0 .023 .121 r
.44862 .39621 .45392 .40188 .46315 .3988 .45787 .39309 Metetra
0 .024 .122 r
.45787 .39309 .46315 .3988 .47241 .39571 .46715 .39004 Metetra
0 .024 .122 r
.46715 .39004 .47241 .39571 .4817 .39259 .47646 .38685 Metetra
0 .024 .122 r
.47646 .38685 .4817 .39259 .49102 .38948 .48581 .38379 Metetra
0 .024 .122 r
.48581 .38379 .49102 .38948 .50037 .38636 .49518 .38073 Metetra
0 .024 .122 r
.49518 .38073 .50037 .38636 .50976 .38321 .50459 .37746 Metetra
0 .024 .123 r
.50459 .37746 .50976 .38321 .51918 .38013 .51403 .37517 Metetra
0 .026 .124 r
.51403 .37517 .51918 .38013 .52863 .37703 .5235 .37274 Metetra
0 .038 .139 r
.5235 .37274 .52863 .37703 .53812 .37485 .53304 .38196 Metetra
0 .051 .153 r
.53304 .38196 .53812 .37485 .54764 .37167 .54262 .37877 Metetra
0 .038 .139 r
.54262 .37877 .54764 .37167 .55718 .36748 .55213 .36314 Metetra
0 .026 .124 r
.55213 .36314 .55718 .36748 .56677 .36421 .56173 .35916 Metetra
0 .024 .123 r
.56173 .35916 .56677 .36421 .57638 .36093 .57136 .35503 Metetra
0 .024 .122 r
.57136 .35503 .57638 .36093 .58603 .35771 .58104 .3519 Metetra
0 .024 .122 r
.58104 .3519 .58603 .35771 .59571 .35446 .59074 .34855 Metetra
0 .024 .122 r
.59074 .34855 .59571 .35446 .60543 .35121 .60048 .3452 Metetra
0 .024 .122 r
.60048 .3452 .60543 .35121 .61518 .34795 .61025 .34198 Metetra
0 .024 .122 r
.61025 .34198 .61518 .34795 .62497 .34467 .62006 .33861 Metetra
0 .023 .121 r
.62006 .33861 .62497 .34467 .63478 .34139 .6299 .33533 Metetra
0 .023 .121 r
.6299 .33533 .63478 .34139 .64464 .33809 .63978 .332 Metetra
0 .023 .121 r
.63978 .332 .64464 .33809 .65453 .33478 .64969 .32865 Metetra
0 .023 .121 r
.64969 .32865 .65453 .33478 .66445 .33147 .65964 .32533 Metetra
0 .023 .121 r
.65964 .32533 .66445 .33147 .67441 .32813 .66962 .32196 Metetra
0 .023 .121 r
.66962 .32196 .67441 .32813 .6844 .32479 .67964 .3186 Metetra
0 .023 .121 r
.67964 .3186 .6844 .32479 .69443 .32144 .68969 .31522 Metetra
0 .023 .121 r
.68969 .31522 .69443 .32144 .70449 .31807 .69978 .31182 Metetra
0 .023 .121 r
.69978 .31182 .70449 .31807 .71459 .31469 .70991 .30843 Metetra
0 .023 .121 r
.70991 .30843 .71459 .31469 .72473 .3113 .72007 .30501 Metetra
0 .023 .121 r
.72007 .30501 .72473 .3113 .7349 .3079 .73026 .30159 Metetra
0 .023 .121 r
.73026 .30159 .7349 .3079 .74511 .30448 .7405 .29815 Metetra
0 .023 .121 r
.7405 .29815 .74511 .30448 .75536 .30106 .75077 .2947 Metetra
0 .023 .121 r
.75077 .2947 .75536 .30106 .76564 .29762 .76108 .29124 Metetra
0 .023 .121 r
.76108 .29124 .76564 .29762 .77596 .29417 .77142 .28776 Metetra
0 .023 .121 r
.77142 .28776 .77596 .29417 .78632 .2907 .7818 .28428 Metetra
0 .023 .121 r
.7818 .28428 .78632 .2907 .79671 .28723 .79223 .28078 Metetra
0 .023 .121 r
.79223 .28078 .79671 .28723 .80714 .28374 .80268 .27726 Metetra
0 .023 .121 r
.80268 .27726 .80714 .28374 .81761 .28024 .81318 .27374 Metetra
0 .023 .121 r
.81318 .27374 .81761 .28024 .82812 .27672 .82371 .2702 Metetra
0 .023 .121 r
.82371 .2702 .82812 .27672 .83866 .27319 .83429 .26665 Metetra
0 .023 .121 r
.83429 .26665 .83866 .27319 .84924 .26965 .8449 .26309 Metetra
0 .023 .121 r
.8449 .26309 .84924 .26965 .85987 .2661 .85555 .25951 Metetra
0 .023 .121 r
.24712 .45659 .25285 .46193 .26144 .45905 .25573 .4537 Metetra
0 .023 .121 r
.25573 .4537 .26144 .45905 .27006 .45615 .26436 .45078 Metetra
0 .023 .121 r
.26436 .45078 .27006 .45615 .27871 .45324 .27303 .44786 Metetra
0 .023 .121 r
.27303 .44786 .27871 .45324 .28738 .45033 .28172 .44493 Metetra
0 .023 .121 r
.28172 .44493 .28738 .45033 .29609 .44741 .29045 .44198 Metetra
0 .023 .121 r
.29045 .44198 .29609 .44741 .30483 .44448 .2992 .43904 Metetra
0 .023 .121 r
.2992 .43904 .30483 .44448 .31359 .44153 .30798 .43607 Metetra
0 .023 .121 r
.30798 .43607 .31359 .44153 .32238 .43858 .31679 .4331 Metetra
0 .023 .121 r
.31679 .4331 .32238 .43858 .3312 .43562 .32563 .43013 Metetra
0 .023 .121 r
.32563 .43013 .3312 .43562 .34006 .43264 .3345 .42713 Metetra
0 .023 .121 r
.3345 .42713 .34006 .43264 .34894 .42966 .3434 .42414 Metetra
0 .023 .121 r
.3434 .42414 .34894 .42966 .35785 .42667 .35233 .42112 Metetra
0 .023 .121 r
.35233 .42112 .35785 .42667 .36679 .42366 .36129 .4181 Metetra
0 .023 .121 r
.36129 .4181 .36679 .42366 .37576 .42066 .37028 .41508 Metetra
0 .023 .121 r
.37028 .41508 .37576 .42066 .38476 .41763 .3793 .41202 Metetra
0 .023 .121 r
.3793 .41202 .38476 .41763 .39379 .4146 .38835 .40899 Metetra
0 .023 .121 r
.38835 .40899 .39379 .4146 .40285 .41156 .39743 .40592 Metetra
0 .023 .121 r
.39743 .40592 .40285 .41156 .41195 .4085 .40654 .40284 Metetra
0 .023 .122 r
.40654 .40284 .41195 .4085 .42107 .40546 .41568 .3998 Metetra
0 .023 .122 r
.41568 .3998 .42107 .40546 .43022 .40236 .42486 .39666 Metetra
0 .023 .122 r
.42486 .39666 .43022 .40236 .43941 .3993 .43406 .3936 Metetra
0 .024 .122 r
.43406 .3936 .43941 .3993 .44862 .39621 .4433 .39049 Metetra
0 .024 .122 r
.4433 .39049 .44862 .39621 .45787 .39309 .45256 .38734 Metetra
0 .024 .122 r
.45256 .38734 .45787 .39309 .46715 .39004 .46186 .38433 Metetra
0 .024 .122 r
.46186 .38433 .46715 .39004 .47646 .38685 .4712 .38107 Metetra
0 .024 .122 r
.4712 .38107 .47646 .38685 .48581 .38379 .48056 .37805 Metetra
0 .024 .122 r
.48056 .37805 .48581 .38379 .49518 .38073 .48995 .37504 Metetra
0 .024 .122 r
.48995 .37504 .49518 .38073 .50459 .37746 .49938 .37165 Metetra
0 .026 .124 r
.49938 .37165 .50459 .37746 .51403 .37517 .50884 .37003 Metetra
0 .029 .129 r
.50884 .37003 .51403 .37517 .5235 .37274 .51833 .36815 Metetra
0 .066 .167 r
.51833 .36815 .5235 .37274 .53304 .38196 .52789 .38693 Metetra
0 .111 .203 r
.52789 .38693 .53304 .38196 .54262 .37877 .53753 .38373 Metetra
0 .066 .167 r
.53753 .38373 .54262 .37877 .55213 .36314 .54704 .35848 Metetra
0 .029 .129 r
.54704 .35848 .55213 .36314 .56173 .35916 .55666 .35392 Metetra
0 .026 .124 r
.55666 .35392 .56173 .35916 .57136 .35503 .56631 .34909 Metetra
0 .024 .122 r
.56631 .34909 .57136 .35503 .58104 .3519 .57601 .34603 Metetra
0 .024 .122 r
.57601 .34603 .58104 .3519 .59074 .34855 .58573 .34259 Metetra
0 .024 .122 r
.58573 .34259 .59074 .34855 .60048 .3452 .59549 .33915 Metetra
0 .024 .122 r
.59549 .33915 .60048 .3452 .61025 .34198 .60529 .33597 Metetra
0 .024 .122 r
.60529 .33597 .61025 .34198 .62006 .33861 .61512 .33252 Metetra
0 .024 .122 r
.61512 .33252 .62006 .33861 .6299 .33533 .62499 .32922 Metetra
0 .024 .122 r
.62499 .32922 .6299 .33533 .63978 .332 .63489 .32587 Metetra
0 .023 .122 r
.63489 .32587 .63978 .332 .64969 .32865 .64482 .32248 Metetra
0 .023 .122 r
.64482 .32248 .64969 .32865 .65964 .32533 .65479 .31916 Metetra
0 .023 .122 r
.65479 .31916 .65964 .32533 .66962 .32196 .6648 .31574 Metetra
0 .023 .121 r
.6648 .31574 .66962 .32196 .67964 .3186 .67484 .31237 Metetra
0 .023 .121 r
.67484 .31237 .67964 .3186 .68969 .31522 .68492 .30897 Metetra
0 .023 .121 r
.68492 .30897 .68969 .31522 .69978 .31182 .69503 .30554 Metetra
0 .023 .121 r
.69503 .30554 .69978 .31182 .70991 .30843 .70518 .30214 Metetra
0 .023 .121 r
.70518 .30214 .70991 .30843 .72007 .30501 .71537 .29868 Metetra
0 .023 .121 r
.71537 .29868 .72007 .30501 .73026 .30159 .72559 .29524 Metetra
0 .023 .121 r
.72559 .29524 .73026 .30159 .7405 .29815 .73585 .29178 Metetra
0 .023 .121 r
.73585 .29178 .7405 .29815 .75077 .2947 .74615 .2883 Metetra
0 .023 .121 r
.74615 .2883 .75077 .2947 .76108 .29124 .75648 .28482 Metetra
0 .023 .121 r
.75648 .28482 .76108 .29124 .77142 .28776 .76686 .28132 Metetra
0 .023 .121 r
.76686 .28132 .77142 .28776 .7818 .28428 .77726 .27781 Metetra
0 .023 .121 r
.77726 .27781 .7818 .28428 .79223 .28078 .78771 .27429 Metetra
0 .023 .121 r
.78771 .27429 .79223 .28078 .80268 .27726 .7982 .27074 Metetra
0 .023 .121 r
.7982 .27074 .80268 .27726 .81318 .27374 .80872 .2672 Metetra
0 .023 .121 r
.80872 .2672 .81318 .27374 .82371 .2702 .81928 .26364 Metetra
0 .023 .121 r
.81928 .26364 .82371 .2702 .83429 .26665 .82988 .26006 Metetra
0 .023 .121 r
.82988 .26006 .83429 .26665 .8449 .26309 .84052 .25648 Metetra
0 .023 .121 r
.84052 .25648 .8449 .26309 .85555 .25951 .8512 .25287 Metetra
0 .023 .121 r
.24135 .45123 .24712 .45659 .25573 .4537 .24997 .44836 Metetra
0 .023 .122 r
.24997 .44836 .25573 .4537 .26436 .45078 .25863 .44541 Metetra
0 .023 .121 r
.25863 .44541 .26436 .45078 .27303 .44786 .26731 .44246 Metetra
0 .024 .122 r
.26731 .44246 .27303 .44786 .28172 .44493 .27602 .43955 Metetra
0 .023 .122 r
.27602 .43955 .28172 .44493 .29045 .44198 .28477 .43653 Metetra
0 .023 .122 r
.28477 .43653 .29045 .44198 .2992 .43904 .29353 .43363 Metetra
0 .024 .122 r
.29353 .43363 .2992 .43904 .30798 .43607 .30233 .43062 Metetra
0 .023 .122 r
.30233 .43062 .30798 .43607 .31679 .4331 .31116 .42762 Metetra
0 .024 .122 r
.31116 .42762 .31679 .4331 .32563 .43013 .32002 .42469 Metetra
0 .024 .122 r
.32002 .42469 .32563 .43013 .3345 .42713 .32891 .42159 Metetra
0 .024 .122 r
.32891 .42159 .3345 .42713 .3434 .42414 .33782 .41866 Metetra
0 .024 .122 r
.33782 .41866 .3434 .42414 .35233 .42112 .34677 .41561 Metetra
0 .024 .122 r
.34677 .41561 .35233 .42112 .36129 .4181 .35575 .41254 Metetra
0 .024 .122 r
.35575 .41254 .36129 .4181 .37028 .41508 .36475 .40962 Metetra
0 .024 .122 r
.36475 .40962 .37028 .41508 .3793 .41202 .3738 .4064 Metetra
0 .024 .122 r
.3738 .4064 .3793 .41202 .38835 .40899 .38286 .40348 Metetra
0 .024 .122 r
.38286 .40348 .38835 .40899 .39743 .40592 .39196 .40039 Metetra
0 .024 .122 r
.39196 .40039 .39743 .40592 .40654 .40284 .4011 .39723 Metetra
0 .024 .122 r
.4011 .39723 .40654 .40284 .41568 .3998 .41025 .39443 Metetra
0 .024 .122 r
.41025 .39443 .41568 .3998 .42486 .39666 .41945 .391 Metetra
0 .024 .122 r
.41945 .391 .42486 .39666 .43406 .3936 .42867 .3882 Metetra
0 .024 .122 r
.42867 .3882 .43406 .3936 .4433 .39049 .43792 .38514 Metetra
0 .024 .122 r
.43792 .38514 .4433 .39049 .45256 .38734 .44722 .38175 Metetra
0 .025 .123 r
.44722 .38175 .45256 .38734 .46186 .38433 .45652 .37968 Metetra
0 .025 .123 r
.45652 .37968 .46186 .38433 .4712 .38107 .46589 .37559 Metetra
0 .025 .124 r
.46589 .37559 .4712 .38107 .48056 .37805 .47526 .37356 Metetra
0 .027 .127 r
.47526 .37356 .48056 .37805 .48995 .37504 .48466 .37167 Metetra
0 .027 .126 r
.48466 .37167 .48995 .37504 .49938 .37165 .49414 .36675 Metetra
0 .038 .139 r
.49414 .36675 .49938 .37165 .50884 .37003 .50354 .3765 Metetra
0 .065 .167 r
.50354 .3765 .50884 .37003 .51833 .36815 .51305 .38425 Metetra
0 .391 .25 r
.51305 .38425 .51833 .36815 .52789 .38693 .52254 .57416 Metetra
.166 .602 0 r
.52254 .57416 .52789 .38693 .53753 .38373 .53278 .57109 Metetra
0 .391 .25 r
.53278 .57109 .53753 .38373 .54704 .35848 .54203 .37457 Metetra
0 .065 .167 r
.54203 .37457 .54704 .35848 .55666 .35392 .55166 .36033 Metetra
0 .038 .139 r
.55166 .36033 .55666 .35392 .56631 .34909 .56124 .34404 Metetra
0 .027 .126 r
.56124 .34404 .56631 .34909 .57601 .34603 .57098 .34248 Metetra
0 .027 .127 r
.57098 .34248 .57601 .34603 .58573 .34259 .58072 .33787 Metetra
0 .025 .124 r
.58072 .33787 .58573 .34259 .59549 .33915 .59048 .3334 Metetra
0 .025 .123 r
.59048 .3334 .59549 .33915 .60529 .33597 .60033 .33102 Metetra
0 .025 .123 r
.60033 .33102 .60529 .33597 .61512 .33252 .61015 .32658 Metetra
0 .024 .122 r
.61015 .32658 .61512 .33252 .62499 .32922 .62005 .32348 Metetra
0 .024 .122 r
.62005 .32348 .62499 .32922 .63489 .32587 .62998 .32004 Metetra
0 .024 .122 r
.62998 .32004 .63489 .32587 .64482 .32248 .63992 .31634 Metetra
0 .024 .122 r
.63992 .31634 .64482 .32248 .65479 .31916 .64993 .31328 Metetra
0 .024 .122 r
.64993 .31328 .65479 .31916 .6648 .31574 .65995 .30957 Metetra
0 .024 .122 r
.65995 .30957 .6648 .31574 .67484 .31237 .67002 .30623 Metetra
0 .024 .122 r
.67002 .30623 .67484 .31237 .68492 .30897 .68013 .30282 Metetra
0 .024 .122 r
.68013 .30282 .68492 .30897 .69503 .30554 .69026 .29923 Metetra
0 .024 .122 r
.69026 .29923 .69503 .30554 .70518 .30214 .70044 .29595 Metetra
0 .024 .122 r
.70044 .29595 .70518 .30214 .71537 .29868 .71065 .29236 Metetra
0 .024 .122 r
.71065 .29236 .71537 .29868 .72559 .29524 .7209 .28892 Metetra
0 .024 .122 r
.7209 .28892 .72559 .29524 .73585 .29178 .73118 .28546 Metetra
0 .024 .122 r
.73118 .28546 .73585 .29178 .74615 .2883 .7415 .28186 Metetra
0 .024 .122 r
.7415 .28186 .74615 .2883 .75648 .28482 .75187 .27845 Metetra
0 .024 .122 r
.75187 .27845 .75648 .28482 .76686 .28132 .76226 .27486 Metetra
0 .023 .122 r
.76226 .27486 .76686 .28132 .77726 .27781 .7727 .27134 Metetra
0 .024 .122 r
.7727 .27134 .77726 .27781 .78771 .27429 .78317 .26782 Metetra
0 .023 .122 r
.78317 .26782 .78771 .27429 .7982 .27074 .79368 .26419 Metetra
0 .023 .122 r
.79368 .26419 .7982 .27074 .80872 .2672 .80424 .26068 Metetra
0 .024 .122 r
.80424 .26068 .80872 .2672 .81928 .26364 .81482 .25705 Metetra
0 .023 .121 r
.81482 .25705 .81928 .26364 .82988 .26006 .82545 .25346 Metetra
0 .023 .122 r
.82545 .25346 .82988 .26006 .84052 .25648 .83612 .24987 Metetra
0 .023 .121 r
.83612 .24987 .84052 .25648 .8512 .25287 .84682 .24619 Metetra
0 .023 .122 r
.23555 .44583 .24135 .45123 .24997 .44836 .24419 .44294 Metetra
0 .024 .122 r
.24419 .44294 .24997 .44836 .25863 .44541 .25286 .43997 Metetra
0 .024 .122 r
.25286 .43997 .25863 .44541 .26731 .44246 .26156 .43701 Metetra
0 .024 .122 r
.26156 .43701 .26731 .44246 .27602 .43955 .27029 .43408 Metetra
0 .024 .122 r
.27029 .43408 .27602 .43955 .28477 .43653 .27905 .43104 Metetra
0 .024 .122 r
.27905 .43104 .28477 .43653 .29353 .43363 .28783 .42812 Metetra
0 .024 .122 r
.28783 .42812 .29353 .43363 .30233 .43062 .29665 .42509 Metetra
0 .024 .122 r
.29665 .42509 .30233 .43062 .31116 .42762 .3055 .42208 Metetra
0 .024 .122 r
.3055 .42208 .31116 .42762 .32002 .42469 .31437 .41913 Metetra
0 .024 .122 r
.31437 .41913 .32002 .42469 .32891 .42159 .32328 .416 Metetra
0 .024 .122 r
.32328 .416 .32891 .42159 .33782 .41866 .33221 .41306 Metetra
0 .024 .122 r
.33221 .41306 .33782 .41866 .34677 .41561 .34118 .40999 Metetra
0 .024 .122 r
.34118 .40999 .34677 .41561 .35575 .41254 .35018 .4069 Metetra
0 .024 .122 r
.35018 .4069 .35575 .41254 .36475 .40962 .3592 .40396 Metetra
0 .024 .122 r
.3592 .40396 .36475 .40962 .3738 .4064 .36827 .40072 Metetra
0 .024 .122 r
.36827 .40072 .3738 .4064 .38286 .40348 .37735 .39779 Metetra
0 .024 .122 r
.37735 .39779 .38286 .40348 .39196 .40039 .38647 .39467 Metetra
0 .024 .122 r
.38647 .39467 .39196 .40039 .4011 .39723 .39562 .39149 Metetra
0 .024 .122 r
.39562 .39149 .4011 .39723 .41025 .39443 .40479 .38867 Metetra
0 .024 .122 r
.40479 .38867 .41025 .39443 .41945 .391 .41402 .38522 Metetra
0 .024 .122 r
.41402 .38522 .41945 .391 .42867 .3882 .42325 .3824 Metetra
0 .025 .123 r
.42325 .3824 .42867 .3882 .43792 .38514 .43253 .37932 Metetra
0 .025 .123 r
.43253 .37932 .43792 .38514 .44722 .38175 .44184 .37591 Metetra
0 .026 .125 r
.44184 .37591 .44722 .38175 .45652 .37968 .45116 .37383 Metetra
0 .026 .125 r
.45116 .37383 .45652 .37968 .46589 .37559 .46055 .36971 Metetra
0 .026 .126 r
.46055 .36971 .46589 .37559 .47526 .37356 .46994 .36766 Metetra
0 .03 .131 r
.46994 .36766 .47526 .37356 .48466 .37167 .47937 .36576 Metetra
0 .03 .13 r
.47937 .36576 .48466 .37167 .49414 .36675 .48886 .36081 Metetra
0 .051 .153 r
.48886 .36081 .49414 .36675 .50354 .3765 .49826 .37056 Metetra
0 .111 .203 r
.49826 .37056 .50354 .3765 .51305 .38425 .50778 .3783 Metetra
.166 .602 0 r
.50778 .3783 .51305 .38425 .52254 .57416 .51698 .56849 Metetra
.979 .091 0 r
.51698 .56849 .52254 .57416 .53278 .57109 .52724 .56541 Metetra
.166 .602 0 r
.52724 .56541 .53278 .57109 .54203 .37457 .53682 .36856 Metetra
0 .111 .203 r
.53682 .36856 .54203 .37457 .55166 .36033 .5465 .35428 Metetra
0 .051 .153 r
.5465 .35428 .55166 .36033 .56124 .34404 .55611 .33795 Metetra
0 .03 .13 r
.55611 .33795 .56124 .34404 .57098 .34248 .56588 .33638 Metetra
0 .03 .131 r
.56588 .33638 .57098 .34248 .58072 .33787 .57564 .33175 Metetra
0 .026 .126 r
.57564 .33175 .58072 .33787 .59048 .3334 .58543 .32726 Metetra
0 .026 .125 r
.58543 .32726 .59048 .3334 .60033 .33102 .5953 .32485 Metetra
0 .026 .125 r
.5953 .32485 .60033 .33102 .61015 .32658 .60515 .32038 Metetra
0 .025 .123 r
.60515 .32038 .61015 .32658 .62005 .32348 .61507 .31726 Metetra
0 .025 .123 r
.61507 .31726 .62005 .32348 .62998 .32004 .62502 .3138 Metetra
0 .024 .122 r
.62502 .3138 .62998 .32004 .63992 .31634 .63499 .31008 Metetra
0 .024 .122 r
.63499 .31008 .63992 .31634 .64993 .31328 .64502 .307 Metetra
0 .024 .122 r
.64502 .307 .64993 .31328 .65995 .30957 .65507 .30327 Metetra
0 .024 .122 r
.65507 .30327 .65995 .30957 .67002 .30623 .66516 .29991 Metetra
0 .024 .122 r
.66516 .29991 .67002 .30623 .68013 .30282 .67529 .29648 Metetra
0 .024 .122 r
.67529 .29648 .68013 .30282 .69026 .29923 .68545 .29286 Metetra
0 .024 .122 r
.68545 .29286 .69026 .29923 .70044 .29595 .69566 .28956 Metetra
0 .024 .122 r
.69566 .28956 .70044 .29595 .71065 .29236 .70589 .28594 Metetra
0 .024 .122 r
.70589 .28594 .71065 .29236 .7209 .28892 .71616 .28248 Metetra
0 .024 .122 r
.71616 .28248 .7209 .28892 .73118 .28546 .72648 .27899 Metetra
0 .024 .122 r
.72648 .27899 .73118 .28546 .7415 .28186 .73682 .27538 Metetra
0 .024 .122 r
.73682 .27538 .7415 .28186 .75187 .27845 .74721 .27194 Metetra
0 .024 .122 r
.74721 .27194 .75187 .27845 .76226 .27486 .75763 .26833 Metetra
0 .024 .122 r
.75763 .26833 .76226 .27486 .7727 .27134 .76809 .26478 Metetra
0 .024 .122 r
.76809 .26478 .7727 .27134 .78317 .26782 .7786 .26123 Metetra
0 .024 .122 r
.7786 .26123 .78317 .26782 .79368 .26419 .78913 .25758 Metetra
0 .024 .122 r
.78913 .25758 .79368 .26419 .80424 .26068 .79971 .25405 Metetra
0 .024 .122 r
.79971 .25405 .80424 .26068 .81482 .25705 .81033 .2504 Metetra
0 .024 .122 r
.81033 .2504 .81482 .25705 .82545 .25346 .82098 .24678 Metetra
0 .024 .122 r
.82098 .24678 .82545 .25346 .83612 .24987 .83168 .24316 Metetra
0 .023 .122 r
.83168 .24316 .83612 .24987 .84682 .24619 .84241 .23946 Metetra
0 .023 .121 r
.22972 .44039 .23555 .44583 .24419 .44294 .23838 .43744 Metetra
0 .023 .122 r
.23838 .43744 .24419 .44294 .25286 .43997 .24706 .43447 Metetra
0 .023 .121 r
.24706 .43447 .25286 .43997 .26156 .43701 .25578 .4315 Metetra
0 .024 .122 r
.25578 .4315 .26156 .43701 .27029 .43408 .26453 .42851 Metetra
0 .023 .122 r
.26453 .42851 .27029 .43408 .27905 .43104 .2733 .42551 Metetra
0 .023 .122 r
.2733 .42551 .27905 .43104 .28783 .42812 .28211 .42251 Metetra
0 .024 .122 r
.28211 .42251 .28783 .42812 .29665 .42509 .29094 .41949 Metetra
0 .023 .122 r
.29094 .41949 .29665 .42509 .3055 .42208 .29981 .41646 Metetra
0 .024 .122 r
.29981 .41646 .3055 .42208 .31437 .41913 .3087 .41343 Metetra
0 .024 .122 r
.3087 .41343 .31437 .41913 .32328 .416 .31762 .41038 Metetra
0 .024 .122 r
.31762 .41038 .32328 .416 .33221 .41306 .32658 .40733 Metetra
0 .024 .122 r
.32658 .40733 .33221 .41306 .34118 .40999 .33556 .40426 Metetra
0 .024 .122 r
.33556 .40426 .34118 .40999 .35018 .4069 .34458 .40118 Metetra
0 .024 .122 r
.34458 .40118 .35018 .4069 .3592 .40396 .35362 .3981 Metetra
0 .024 .122 r
.35362 .3981 .3592 .40396 .36827 .40072 .3627 .39499 Metetra
0 .024 .122 r
.3627 .39499 .36827 .40072 .37735 .39779 .37181 .39189 Metetra
0 .024 .122 r
.37181 .39189 .37735 .39779 .38647 .39467 .38095 .38877 Metetra
0 .024 .122 r
.38095 .38877 .38647 .39467 .39562 .39149 .39012 .38563 Metetra
0 .024 .122 r
.39012 .38563 .39562 .39149 .40479 .38867 .39932 .38253 Metetra
0 .024 .122 r
.39932 .38253 .40479 .38867 .41402 .38522 .40855 .37933 Metetra
0 .024 .122 r
.40855 .37933 .41402 .38522 .42325 .3824 .41781 .37621 Metetra
0 .024 .122 r
.41781 .37621 .42325 .3824 .43253 .37932 .42711 .37305 Metetra
0 .024 .122 r
.42711 .37305 .43253 .37932 .44184 .37591 .43644 .36983 Metetra
0 .025 .123 r
.43644 .36983 .44184 .37591 .45116 .37383 .4458 .36677 Metetra
0 .025 .123 r
.4458 .36677 .45116 .37383 .46055 .36971 .45519 .36344 Metetra
0 .025 .124 r
.45519 .36344 .46055 .36971 .46994 .36766 .46462 .36037 Metetra
0 .027 .127 r
.46462 .36037 .46994 .36766 .47937 .36576 .47407 .35729 Metetra
0 .027 .126 r
.47407 .35729 .47937 .36576 .48886 .36081 .48357 .35384 Metetra
0 .038 .139 r
.48357 .35384 .48886 .36081 .49826 .37056 .49308 .35217 Metetra
0 .065 .167 r
.49308 .35217 .49826 .37056 .50778 .3783 .50263 .35023 Metetra
0 .391 .25 r
.50263 .35023 .50778 .3783 .51698 .56849 .51215 .36904 Metetra
.166 .602 0 r
.51215 .36904 .51698 .56849 .52724 .56541 .52185 .36577 Metetra
0 .391 .25 r
.52185 .36577 .52724 .56541 .53682 .36856 .53154 .34037 Metetra
0 .065 .167 r
.53154 .34037 .53682 .36856 .5465 .35428 .54123 .33574 Metetra
0 .038 .139 r
.54123 .33574 .5465 .35428 .55611 .33795 .55095 .33083 Metetra
0 .027 .126 r
.55095 .33083 .55611 .33795 .56588 .33638 .56072 .32771 Metetra
0 .027 .127 r
.56072 .32771 .56588 .33638 .57564 .33175 .57051 .32421 Metetra
0 .025 .124 r
.57051 .32421 .57564 .33175 .58543 .32726 .58034 .32071 Metetra
0 .025 .123 r
.58034 .32071 .58543 .32726 .5953 .32485 .59021 .31746 Metetra
0 .025 .123 r
.59021 .31746 .5953 .32485 .60515 .32038 .60011 .31394 Metetra
0 .024 .122 r
.60011 .31394 .60515 .32038 .61507 .31726 .61005 .31058 Metetra
0 .024 .122 r
.61005 .31058 .61507 .31726 .62502 .3138 .62002 .30716 Metetra
0 .024 .122 r
.62002 .30716 .62502 .3138 .63499 .31008 .63002 .3037 Metetra
0 .024 .122 r
.63002 .3037 .63499 .31008 .64502 .307 .64007 .30031 Metetra
0 .024 .122 r
.64007 .30031 .64502 .307 .65507 .30327 .65015 .29683 Metetra
0 .024 .122 r
.65015 .29683 .65507 .30327 .66516 .29991 .66026 .29339 Metetra
0 .024 .122 r
.66026 .29339 .66516 .29991 .67529 .29648 .67042 .28992 Metetra
0 .024 .122 r
.67042 .28992 .67529 .29648 .68545 .29286 .6806 .28642 Metetra
0 .024 .122 r
.6806 .28642 .68545 .29286 .69566 .28956 .69083 .28295 Metetra
0 .024 .122 r
.69083 .28295 .69566 .28956 .70589 .28594 .70109 .27943 Metetra
0 .024 .122 r
.70109 .27943 .70589 .28594 .71616 .28248 .71139 .27592 Metetra
0 .024 .122 r
.71139 .27592 .71616 .28248 .72648 .27899 .72173 .27239 Metetra
0 .024 .122 r
.72173 .27239 .72648 .27899 .73682 .27538 .7321 .26884 Metetra
0 .024 .122 r
.7321 .26884 .73682 .27538 .74721 .27194 .74252 .26529 Metetra
0 .024 .122 r
.74252 .26529 .74721 .27194 .75763 .26833 .75297 .26171 Metetra
0 .023 .122 r
.75297 .26171 .75763 .26833 .76809 .26478 .76346 .25813 Metetra
0 .024 .122 r
.76346 .25813 .76809 .26478 .7786 .26123 .77399 .25454 Metetra
0 .023 .122 r
.77399 .25454 .7786 .26123 .78913 .25758 .78455 .25092 Metetra
0 .023 .122 r
.78455 .25092 .78913 .25758 .79971 .25405 .79516 .24731 Metetra
0 .024 .122 r
.79516 .24731 .79971 .25405 .81033 .2504 .8058 .24367 Metetra
0 .023 .121 r
.8058 .24367 .81033 .2504 .82098 .24678 .81649 .24002 Metetra
0 .023 .122 r
.81649 .24002 .82098 .24678 .83168 .24316 .82721 .23636 Metetra
0 .023 .121 r
.82721 .23636 .83168 .24316 .84241 .23946 .83797 .23268 Metetra
0 .023 .121 r
.22385 .43493 .22972 .44039 .23838 .43744 .23252 .43195 Metetra
0 .023 .121 r
.23252 .43195 .23838 .43744 .24706 .43447 .24123 .42897 Metetra
0 .023 .121 r
.24123 .42897 .24706 .43447 .25578 .4315 .24996 .42597 Metetra
0 .023 .121 r
.24996 .42597 .25578 .4315 .26453 .42851 .25872 .42297 Metetra
0 .023 .121 r
.25872 .42297 .26453 .42851 .2733 .42551 .26752 .41995 Metetra
0 .023 .121 r
.26752 .41995 .2733 .42551 .28211 .42251 .27634 .41693 Metetra
0 .023 .121 r
.27634 .41693 .28211 .42251 .29094 .41949 .28519 .41389 Metetra
0 .023 .121 r
.28519 .41389 .29094 .41949 .29981 .41646 .29407 .41085 Metetra
0 .023 .121 r
.29407 .41085 .29981 .41646 .3087 .41343 .30299 .40779 Metetra
0 .023 .121 r
.30299 .40779 .3087 .41343 .31762 .41038 .31193 .40472 Metetra
0 .023 .121 r
.31193 .40472 .31762 .41038 .32658 .40733 .3209 .40165 Metetra
0 .023 .121 r
.3209 .40165 .32658 .40733 .33556 .40426 .3299 .39856 Metetra
0 .023 .121 r
.3299 .39856 .33556 .40426 .34458 .40118 .33894 .39546 Metetra
0 .023 .121 r
.33894 .39546 .34458 .40118 .35362 .3981 .348 .39236 Metetra
0 .023 .121 r
.348 .39236 .35362 .3981 .3627 .39499 .3571 .38923 Metetra
0 .023 .121 r
.3571 .38923 .3627 .39499 .37181 .39189 .36622 .38611 Metetra
0 .023 .121 r
.36622 .38611 .37181 .39189 .38095 .38877 .37538 .38297 Metetra
0 .023 .121 r
.37538 .38297 .38095 .38877 .39012 .38563 .38457 .37982 Metetra
0 .023 .122 r
.38457 .37982 .39012 .38563 .39932 .38253 .39379 .37668 Metetra
0 .023 .122 r
.39379 .37668 .39932 .38253 .40855 .37933 .40305 .37348 Metetra
0 .023 .122 r
.40305 .37348 .40855 .37933 .41781 .37621 .41233 .37032 Metetra
0 .024 .122 r
.41233 .37032 .41781 .37621 .42711 .37305 .42165 .36713 Metetra
0 .024 .122 r
.42165 .36713 .42711 .37305 .43644 .36983 .431 .36391 Metetra
0 .024 .122 r
.431 .36391 .43644 .36983 .4458 .36677 .44038 .36076 Metetra
0 .024 .122 r
.44038 .36076 .4458 .36677 .45519 .36344 .44979 .35747 Metetra
0 .024 .122 r
.44979 .35747 .45519 .36344 .46462 .36037 .45924 .35431 Metetra
0 .024 .122 r
.45924 .35431 .46462 .36037 .47407 .35729 .46872 .35115 Metetra
0 .024 .122 r
.46872 .35115 .47407 .35729 .48357 .35384 .47823 .34777 Metetra
0 .026 .124 r
.47823 .34777 .48357 .35384 .49308 .35217 .48777 .34539 Metetra
0 .029 .129 r
.48777 .34539 .49308 .35217 .50263 .35023 .49734 .34286 Metetra
0 .066 .167 r
.49734 .34286 .50263 .35023 .51215 .36904 .50689 .35206 Metetra
0 .111 .203 r
.50689 .35206 .51215 .36904 .52185 .36577 .51658 .34876 Metetra
0 .066 .167 r
.51658 .34876 .52185 .36577 .53154 .34037 .5263 .33294 Metetra
0 .029 .129 r
.5263 .33294 .53154 .34037 .54123 .33574 .53602 .32885 Metetra
0 .026 .124 r
.53602 .32885 .54123 .33574 .55095 .33083 .54577 .32461 Metetra
0 .024 .122 r
.54577 .32461 .55095 .33083 .56072 .32771 .55555 .32138 Metetra
0 .024 .122 r
.55555 .32138 .56072 .32771 .57051 .32421 .56537 .31792 Metetra
0 .024 .122 r
.56537 .31792 .57051 .32421 .58034 .32071 .57522 .31446 Metetra
0 .024 .122 r
.57522 .31446 .58034 .32071 .59021 .31746 .58512 .31113 Metetra
0 .024 .122 r
.58512 .31113 .59021 .31746 .60011 .31394 .59504 .30765 Metetra
0 .024 .122 r
.59504 .30765 .60011 .31394 .61005 .31058 .605 .30425 Metetra
0 .024 .122 r
.605 .30425 .61005 .31058 .62002 .30716 .615 .30082 Metetra
0 .023 .122 r
.615 .30082 .62002 .30716 .63002 .3037 .62503 .29736 Metetra
0 .023 .122 r
.62503 .29736 .63002 .3037 .64007 .30031 .63509 .29393 Metetra
0 .023 .122 r
.63509 .29393 .64007 .30031 .65015 .29683 .6452 .29044 Metetra
0 .023 .121 r
.6452 .29044 .65015 .29683 .66026 .29339 .65534 .28697 Metetra
0 .023 .121 r
.65534 .28697 .66026 .29339 .67042 .28992 .66552 .28348 Metetra
0 .023 .121 r
.66552 .28348 .67042 .28992 .6806 .28642 .67573 .27997 Metetra
0 .023 .121 r
.67573 .27997 .6806 .28642 .69083 .28295 .68598 .27646 Metetra
0 .023 .121 r
.68598 .27646 .69083 .28295 .70109 .27943 .69627 .27293 Metetra
0 .023 .121 r
.69627 .27293 .70109 .27943 .71139 .27592 .70659 .26939 Metetra
0 .023 .121 r
.70659 .26939 .71139 .27592 .72173 .27239 .71696 .26583 Metetra
0 .023 .121 r
.71696 .26583 .72173 .27239 .7321 .26884 .72736 .26226 Metetra
0 .023 .121 r
.72736 .26226 .7321 .26884 .74252 .26529 .7378 .25869 Metetra
0 .023 .121 r
.7378 .25869 .74252 .26529 .75297 .26171 .74828 .25509 Metetra
0 .023 .121 r
.74828 .25509 .75297 .26171 .76346 .25813 .75879 .25148 Metetra
0 .023 .121 r
.75879 .25148 .76346 .25813 .77399 .25454 .76935 .24787 Metetra
0 .023 .121 r
.76935 .24787 .77399 .25454 .78455 .25092 .77994 .24423 Metetra
0 .023 .121 r
.77994 .24423 .78455 .25092 .79516 .24731 .79057 .24059 Metetra
0 .023 .121 r
.79057 .24059 .79516 .24731 .8058 .24367 .80125 .23692 Metetra
0 .023 .121 r
.80125 .23692 .8058 .24367 .81649 .24002 .81196 .23325 Metetra
0 .023 .121 r
.81196 .23325 .81649 .24002 .82721 .23636 .82271 .22957 Metetra
0 .023 .121 r
.82271 .22957 .82721 .23636 .83797 .23268 .8335 .22586 Metetra
0 .023 .121 r
.21794 .42943 .22385 .43493 .23252 .43195 .22663 .42643 Metetra
0 .023 .121 r
.22663 .42643 .23252 .43195 .24123 .42897 .23535 .42343 Metetra
0 .023 .121 r
.23535 .42343 .24123 .42897 .24996 .42597 .24411 .42042 Metetra
0 .023 .121 r
.24411 .42042 .24996 .42597 .25872 .42297 .25289 .41739 Metetra
0 .023 .121 r
.25289 .41739 .25872 .42297 .26752 .41995 .2617 .41436 Metetra
0 .023 .121 r
.2617 .41436 .26752 .41995 .27634 .41693 .27054 .41131 Metetra
0 .023 .121 r
.27054 .41131 .27634 .41693 .28519 .41389 .27941 .40826 Metetra
0 .023 .121 r
.27941 .40826 .28519 .41389 .29407 .41085 .28831 .40519 Metetra
0 .023 .121 r
.28831 .40519 .29407 .41085 .30299 .40779 .29724 .40212 Metetra
0 .023 .121 r
.29724 .40212 .30299 .40779 .31193 .40472 .3062 .39903 Metetra
0 .023 .121 r
.3062 .39903 .31193 .40472 .3209 .40165 .31519 .39594 Metetra
0 .023 .121 r
.31519 .39594 .3209 .40165 .3299 .39856 .32421 .39283 Metetra
0 .023 .121 r
.32421 .39283 .3299 .39856 .33894 .39546 .33326 .38971 Metetra
0 .023 .121 r
.33326 .38971 .33894 .39546 .348 .39236 .34235 .38659 Metetra
0 .023 .121 r
.34235 .38659 .348 .39236 .3571 .38923 .35146 .38345 Metetra
0 .023 .121 r
.35146 .38345 .3571 .38923 .36622 .38611 .36061 .3803 Metetra
0 .023 .121 r
.36061 .3803 .36622 .38611 .37538 .38297 .36978 .37714 Metetra
0 .023 .121 r
.36978 .37714 .37538 .38297 .38457 .37982 .37899 .37396 Metetra
0 .023 .121 r
.37899 .37396 .38457 .37982 .39379 .37668 .38823 .37078 Metetra
0 .023 .121 r
.38823 .37078 .39379 .37668 .40305 .37348 .39751 .36759 Metetra
0 .023 .121 r
.39751 .36759 .40305 .37348 .41233 .37032 .40681 .36439 Metetra
0 .023 .121 r
.40681 .36439 .41233 .37032 .42165 .36713 .41615 .36117 Metetra
0 .023 .121 r
.41615 .36117 .42165 .36713 .431 .36391 .42552 .35794 Metetra
0 .024 .122 r
.42552 .35794 .431 .36391 .44038 .36076 .43492 .35471 Metetra
0 .024 .122 r
.43492 .35471 .44038 .36076 .44979 .35747 .44435 .35146 Metetra
0 .024 .122 r
.44435 .35146 .44979 .35747 .45924 .35431 .45382 .3482 Metetra
0 .024 .122 r
.45382 .3482 .45924 .35431 .46872 .35115 .46332 .34494 Metetra
0 .024 .122 r
.46332 .34494 .46872 .35115 .47823 .34777 .47286 .34165 Metetra
0 .024 .123 r
.47286 .34165 .47823 .34777 .48777 .34539 .48243 .33842 Metetra
0 .026 .124 r
.48243 .33842 .48777 .34539 .49734 .34286 .49203 .33518 Metetra
0 .038 .139 r
.49203 .33518 .49734 .34286 .50689 .35206 .50165 .33286 Metetra
0 .051 .153 r
.50165 .33286 .50689 .35206 .51658 .34876 .51133 .32953 Metetra
0 .038 .139 r
.51133 .32953 .51658 .34876 .5263 .33294 .52104 .32519 Metetra
0 .026 .124 r
.52104 .32519 .5263 .33294 .53602 .32885 .53077 .32177 Metetra
0 .024 .123 r
.53077 .32177 .53602 .32885 .54577 .32461 .54055 .31834 Metetra
0 .024 .122 r
.54055 .31834 .54577 .32461 .55555 .32138 .55035 .31497 Metetra
0 .024 .122 r
.55035 .31497 .55555 .32138 .56537 .31792 .5602 .31157 Metetra
0 .024 .122 r
.5602 .31157 .56537 .31792 .57522 .31446 .57007 .30816 Metetra
0 .024 .122 r
.57007 .30816 .57522 .31446 .58512 .31113 .57999 .30475 Metetra
0 .024 .122 r
.57999 .30475 .58512 .31113 .59504 .30765 .58994 .30132 Metetra
0 .023 .121 r
.58994 .30132 .59504 .30765 .605 .30425 .59992 .29789 Metetra
0 .023 .121 r
.59992 .29789 .605 .30425 .615 .30082 .60994 .29443 Metetra
0 .023 .121 r
.60994 .29443 .615 .30082 .62503 .29736 .61999 .29097 Metetra
0 .023 .121 r
.61999 .29097 .62503 .29736 .63509 .29393 .63009 .2875 Metetra
0 .023 .121 r
.63009 .2875 .63509 .29393 .6452 .29044 .64022 .28401 Metetra
0 .023 .121 r
.64022 .28401 .6452 .29044 .65534 .28697 .65038 .28051 Metetra
0 .023 .121 r
.65038 .28051 .65534 .28697 .66552 .28348 .66058 .27699 Metetra
0 .023 .121 r
.66058 .27699 .66552 .28348 .67573 .27997 .67082 .27347 Metetra
0 .023 .121 r
.67082 .27347 .67573 .27997 .68598 .27646 .6811 .26993 Metetra
0 .023 .121 r
.6811 .26993 .68598 .27646 .69627 .27293 .69141 .26637 Metetra
0 .023 .121 r
.69141 .26637 .69627 .27293 .70659 .26939 .70177 .26281 Metetra
0 .023 .121 r
.70177 .26281 .70659 .26939 .71696 .26583 .71215 .25923 Metetra
0 .023 .121 r
.71215 .25923 .71696 .26583 .72736 .26226 .72258 .25564 Metetra
0 .023 .121 r
.72258 .25564 .72736 .26226 .7378 .25869 .73305 .25204 Metetra
0 .023 .121 r
.73305 .25204 .7378 .25869 .74828 .25509 .74355 .24842 Metetra
0 .023 .121 r
.74355 .24842 .74828 .25509 .75879 .25148 .7541 .24479 Metetra
0 .023 .121 r
.7541 .24479 .75879 .25148 .76935 .24787 .76468 .24114 Metetra
0 .023 .121 r
.76468 .24114 .76935 .24787 .77994 .24423 .7753 .23749 Metetra
0 .023 .121 r
.7753 .23749 .77994 .24423 .79057 .24059 .78596 .23381 Metetra
0 .023 .121 r
.78596 .23381 .79057 .24059 .80125 .23692 .79666 .23013 Metetra
0 .023 .121 r
.79666 .23013 .80125 .23692 .81196 .23325 .8074 .22643 Metetra
0 .023 .121 r
.8074 .22643 .81196 .23325 .82271 .22957 .81818 .22272 Metetra
0 .023 .121 r
.81818 .22272 .82271 .22957 .8335 .22586 .829 .21899 Metetra
0 .023 .121 r
.212 .42389 .21794 .42943 .22663 .42643 .22071 .42088 Metetra
0 .023 .121 r
.22071 .42088 .22663 .42643 .23535 .42343 .22944 .41786 Metetra
0 .023 .121 r
.22944 .41786 .23535 .42343 .24411 .42042 .23821 .41483 Metetra
0 .023 .121 r
.23821 .41483 .24411 .42042 .25289 .41739 .24701 .41178 Metetra
0 .023 .121 r
.24701 .41178 .25289 .41739 .2617 .41436 .25584 .40873 Metetra
0 .023 .121 r
.25584 .40873 .2617 .41436 .27054 .41131 .2647 .40567 Metetra
0 .023 .121 r
.2647 .40567 .27054 .41131 .27941 .40826 .27358 .40259 Metetra
0 .023 .121 r
.27358 .40259 .27941 .40826 .28831 .40519 .2825 .39951 Metetra
0 .023 .121 r
.2825 .39951 .28831 .40519 .29724 .40212 .29145 .39641 Metetra
0 .023 .121 r
.29145 .39641 .29724 .40212 .3062 .39903 .30043 .39331 Metetra
0 .023 .121 r
.30043 .39331 .3062 .39903 .31519 .39594 .30944 .39019 Metetra
0 .023 .121 r
.30944 .39019 .31519 .39594 .32421 .39283 .31848 .38707 Metetra
0 .023 .121 r
.31848 .38707 .32421 .39283 .33326 .38971 .32755 .38393 Metetra
0 .023 .121 r
.32755 .38393 .33326 .38971 .34235 .38659 .33665 .38078 Metetra
0 .023 .121 r
.33665 .38078 .34235 .38659 .35146 .38345 .34579 .37762 Metetra
0 .023 .121 r
.34579 .37762 .35146 .38345 .36061 .3803 .35495 .37445 Metetra
0 .023 .121 r
.35495 .37445 .36061 .3803 .36978 .37714 .36415 .37127 Metetra
0 .023 .121 r
.36415 .37127 .36978 .37714 .37899 .37396 .37338 .36808 Metetra
0 .023 .121 r
.37338 .36808 .37899 .37396 .38823 .37078 .38264 .36488 Metetra
0 .023 .121 r
.38264 .36488 .38823 .37078 .39751 .36759 .39193 .36167 Metetra
0 .023 .121 r
.39193 .36167 .39751 .36759 .40681 .36439 .40126 .35844 Metetra
0 .023 .121 r
.40126 .35844 .40681 .36439 .41615 .36117 .41061 .35521 Metetra
0 .023 .121 r
.41061 .35521 .41615 .36117 .42552 .35794 .42 .35196 Metetra
0 .023 .121 r
.42 .35196 .42552 .35794 .43492 .35471 .42943 .34872 Metetra
0 .023 .121 r
.42943 .34872 .43492 .35471 .44435 .35146 .43888 .34543 Metetra
0 .023 .121 r
.43888 .34543 .44435 .35146 .45382 .3482 .44837 .34217 Metetra
0 .023 .122 r
.44837 .34217 .45382 .3482 .46332 .34494 .45789 .33889 Metetra
0 .023 .122 r
.45789 .33889 .46332 .34494 .47286 .34165 .46745 .33556 Metetra
0 .024 .122 r
.46745 .33556 .47286 .34165 .48243 .33842 .47704 .33243 Metetra
0 .024 .122 r
.47704 .33243 .48243 .33842 .49203 .33518 .48666 .32925 Metetra
0 .027 .126 r
.48666 .32925 .49203 .33518 .50165 .33286 .49629 .32846 Metetra
0 .03 .13 r
.49629 .32846 .50165 .33286 .51133 .32953 .50599 .32511 Metetra
0 .027 .126 r
.50599 .32511 .51133 .32953 .52104 .32519 .51574 .3192 Metetra
0 .024 .122 r
.51574 .3192 .52104 .32519 .53077 .32177 .5255 .31567 Metetra
0 .024 .122 r
.5255 .31567 .53077 .32177 .54055 .31834 .53529 .3121 Metetra
0 .023 .122 r
.53529 .3121 .54055 .31834 .55035 .31497 .54512 .30872 Metetra
0 .023 .122 r
.54512 .30872 .55035 .31497 .5602 .31157 .55499 .30529 Metetra
0 .023 .121 r
.55499 .30529 .5602 .31157 .57007 .30816 .56489 .30185 Metetra
0 .023 .121 r
.56489 .30185 .57007 .30816 .57999 .30475 .57483 .29843 Metetra
0 .023 .121 r
.57483 .29843 .57999 .30475 .58994 .30132 .5848 .29497 Metetra
0 .023 .121 r
.5848 .29497 .58994 .30132 .59992 .29789 .59481 .29151 Metetra
0 .023 .121 r
.59481 .29151 .59992 .29789 .60994 .29443 .60485 .28803 Metetra
0 .023 .121 r
.60485 .28803 .60994 .29443 .61999 .29097 .61493 .28454 Metetra
0 .023 .121 r
.61493 .28454 .61999 .29097 .63009 .2875 .62505 .28105 Metetra
0 .023 .121 r
.62505 .28105 .63009 .2875 .64022 .28401 .6352 .27753 Metetra
0 .023 .121 r
.6352 .27753 .64022 .28401 .65038 .28051 .64539 .27401 Metetra
0 .023 .121 r
.64539 .27401 .65038 .28051 .66058 .27699 .65562 .27047 Metetra
0 .023 .121 r
.65562 .27047 .66058 .27699 .67082 .27347 .66588 .26692 Metetra
0 .023 .121 r
.66588 .26692 .67082 .27347 .6811 .26993 .67619 .26336 Metetra
0 .023 .121 r
.67619 .26336 .6811 .26993 .69141 .26637 .68652 .25978 Metetra
0 .023 .121 r
.68652 .25978 .69141 .26637 .70177 .26281 .6969 .25619 Metetra
0 .023 .121 r
.6969 .25619 .70177 .26281 .71215 .25923 .70732 .25259 Metetra
0 .023 .121 r
.70732 .25259 .71215 .25923 .72258 .25564 .71777 .24898 Metetra
0 .023 .121 r
.71777 .24898 .72258 .25564 .73305 .25204 .72827 .24535 Metetra
0 .023 .121 r
.72827 .24535 .73305 .25204 .74355 .24842 .7388 .24171 Metetra
0 .023 .121 r
.7388 .24171 .74355 .24842 .7541 .24479 .74937 .23805 Metetra
0 .023 .121 r
.74937 .23805 .7541 .24479 .76468 .24114 .75998 .23438 Metetra
0 .023 .121 r
.75998 .23438 .76468 .24114 .7753 .23749 .77063 .2307 Metetra
0 .023 .121 r
.77063 .2307 .7753 .23749 .78596 .23381 .78132 .227 Metetra
0 .023 .121 r
.78132 .227 .78596 .23381 .79666 .23013 .79204 .22329 Metetra
0 .023 .121 r
.79204 .22329 .79666 .23013 .8074 .22643 .80281 .21957 Metetra
0 .023 .121 r
.80281 .21957 .8074 .22643 .81818 .22272 .81362 .21583 Metetra
0 .023 .121 r
.81362 .21583 .81818 .22272 .829 .21899 .82447 .21208 Metetra
0 .023 .121 r
.20602 .41832 .212 .42389 .22071 .42088 .21474 .41529 Metetra
0 .023 .121 r
.21474 .41529 .22071 .42088 .22944 .41786 .2235 .41225 Metetra
0 .023 .121 r
.2235 .41225 .22944 .41786 .23821 .41483 .23228 .4092 Metetra
0 .023 .121 r
.23228 .4092 .23821 .41483 .24701 .41178 .2411 .40614 Metetra
0 .023 .121 r
.2411 .40614 .24701 .41178 .25584 .40873 .24994 .40307 Metetra
0 .023 .121 r
.24994 .40307 .25584 .40873 .2647 .40567 .25882 .39998 Metetra
0 .023 .121 r
.25882 .39998 .2647 .40567 .27358 .40259 .26773 .39689 Metetra
0 .023 .121 r
.26773 .39689 .27358 .40259 .2825 .39951 .27666 .39379 Metetra
0 .023 .121 r
.27666 .39379 .2825 .39951 .29145 .39641 .28563 .39067 Metetra
0 .023 .121 r
.28563 .39067 .29145 .39641 .30043 .39331 .29463 .38755 Metetra
0 .023 .121 r
.29463 .38755 .30043 .39331 .30944 .39019 .30365 .38441 Metetra
0 .023 .121 r
.30365 .38441 .30944 .39019 .31848 .38707 .31271 .38127 Metetra
0 .023 .121 r
.31271 .38127 .31848 .38707 .32755 .38393 .3218 .37811 Metetra
0 .023 .121 r
.3218 .37811 .32755 .38393 .33665 .38078 .33092 .37494 Metetra
0 .023 .121 r
.33092 .37494 .33665 .38078 .34579 .37762 .34008 .37176 Metetra
0 .023 .121 r
.34008 .37176 .34579 .37762 .35495 .37445 .34926 .36857 Metetra
0 .023 .121 r
.34926 .36857 .35495 .37445 .36415 .37127 .35848 .36537 Metetra
0 .023 .121 r
.35848 .36537 .36415 .37127 .37338 .36808 .36773 .36216 Metetra
0 .023 .121 r
.36773 .36216 .37338 .36808 .38264 .36488 .37701 .35894 Metetra
0 .023 .121 r
.37701 .35894 .38264 .36488 .39193 .36167 .38632 .3557 Metetra
0 .023 .121 r
.38632 .3557 .39193 .36167 .40126 .35844 .39567 .35246 Metetra
0 .023 .121 r
.39567 .35246 .40126 .35844 .41061 .35521 .40504 .3492 Metetra
0 .023 .121 r
.40504 .3492 .41061 .35521 .42 .35196 .41445 .34593 Metetra
0 .023 .121 r
.41445 .34593 .42 .35196 .42943 .34872 .4239 .34266 Metetra
0 .023 .121 r
.4239 .34266 .42943 .34872 .43888 .34543 .43337 .33936 Metetra
0 .023 .121 r
.43337 .33936 .43888 .34543 .44837 .34217 .44288 .33607 Metetra
0 .023 .122 r
.44288 .33607 .44837 .34217 .45789 .33889 .45243 .33276 Metetra
0 .023 .122 r
.45243 .33276 .45789 .33889 .46745 .33556 .46201 .32942 Metetra
0 .024 .122 r
.46201 .32942 .46745 .33556 .47704 .33243 .47161 .32619 Metetra
0 .024 .122 r
.47161 .32619 .47704 .33243 .48666 .32925 .48126 .32292 Metetra
0 .027 .127 r
.48126 .32292 .48666 .32925 .49629 .32846 .49092 .32094 Metetra
0 .03 .131 r
.49092 .32094 .49629 .32846 .50599 .32511 .50064 .31757 Metetra
0 .027 .127 r
.50064 .31757 .50599 .32511 .51574 .3192 .5104 .3128 Metetra
0 .024 .122 r
.5104 .3128 .51574 .3192 .5255 .31567 .52019 .30932 Metetra
0 .024 .122 r
.52019 .30932 .5255 .31567 .53529 .3121 .53 .30581 Metetra
0 .023 .122 r
.53 .30581 .53529 .3121 .54512 .30872 .53986 .3024 Metetra
0 .023 .122 r
.53986 .3024 .54512 .30872 .55499 .30529 .54975 .29895 Metetra
0 .023 .121 r
.54975 .29895 .55499 .30529 .56489 .30185 .55967 .2955 Metetra
0 .023 .121 r
.55967 .2955 .56489 .30185 .57483 .29843 .56963 .29205 Metetra
0 .023 .121 r
.56963 .29205 .57483 .29843 .5848 .29497 .57963 .28857 Metetra
0 .023 .121 r
.57963 .28857 .5848 .29497 .59481 .29151 .58966 .28508 Metetra
0 .023 .121 r
.58966 .28508 .59481 .29151 .60485 .28803 .59973 .28159 Metetra
0 .023 .121 r
.59973 .28159 .60485 .28803 .61493 .28454 .60983 .27807 Metetra
0 .023 .121 r
.60983 .27807 .61493 .28454 .62505 .28105 .61997 .27455 Metetra
0 .023 .121 r
.61997 .27455 .62505 .28105 .6352 .27753 .63015 .27102 Metetra
0 .023 .121 r
.63015 .27102 .6352 .27753 .64539 .27401 .64037 .26747 Metetra
0 .023 .121 r
.64037 .26747 .64539 .27401 .65562 .27047 .65062 .26391 Metetra
0 .023 .121 r
.65062 .26391 .65562 .27047 .66588 .26692 .66091 .26033 Metetra
0 .023 .121 r
.66091 .26033 .66588 .26692 .67619 .26336 .67124 .25675 Metetra
0 .023 .121 r
.67124 .25675 .67619 .26336 .68652 .25978 .6816 .25315 Metetra
0 .023 .121 r
.6816 .25315 .68652 .25978 .6969 .25619 .69201 .24953 Metetra
0 .023 .121 r
.69201 .24953 .6969 .25619 .70732 .25259 .70245 .24591 Metetra
0 .023 .121 r
.70245 .24591 .70732 .25259 .71777 .24898 .71293 .24227 Metetra
0 .023 .121 r
.71293 .24227 .71777 .24898 .72827 .24535 .72345 .23861 Metetra
0 .023 .121 r
.72345 .23861 .72827 .24535 .7388 .24171 .73401 .23495 Metetra
0 .023 .121 r
.73401 .23495 .7388 .24171 .74937 .23805 .74461 .23127 Metetra
0 .023 .121 r
.74461 .23127 .74937 .23805 .75998 .23438 .75524 .22757 Metetra
0 .023 .121 r
.75524 .22757 .75998 .23438 .77063 .2307 .76592 .22386 Metetra
0 .023 .121 r
.76592 .22386 .77063 .2307 .78132 .227 .77664 .22014 Metetra
0 .023 .121 r
.77664 .22014 .78132 .227 .79204 .22329 .78739 .2164 Metetra
0 .023 .121 r
.78739 .2164 .79204 .22329 .80281 .21957 .79819 .21265 Metetra
0 .023 .121 r
.79819 .21265 .80281 .21957 .81362 .21583 .80903 .20889 Metetra
0 .023 .121 r
.80903 .20889 .81362 .21583 .82447 .21208 .81991 .20511 Metetra
0 .023 .121 r
.2 .41272 .20602 .41832 .21474 .41529 .20874 .40967 Metetra
0 .023 .121 r
.20874 .40967 .21474 .41529 .2235 .41225 .21751 .40661 Metetra
0 .023 .121 r
.21751 .40661 .2235 .41225 .23228 .4092 .22632 .40354 Metetra
0 .023 .121 r
.22632 .40354 .23228 .4092 .2411 .40614 .23515 .40046 Metetra
0 .023 .121 r
.23515 .40046 .2411 .40614 .24994 .40307 .24401 .39737 Metetra
0 .023 .121 r
.24401 .39737 .24994 .40307 .25882 .39998 .25291 .39427 Metetra
0 .023 .121 r
.25291 .39427 .25882 .39998 .26773 .39689 .26183 .39115 Metetra
0 .023 .121 r
.26183 .39115 .26773 .39689 .27666 .39379 .27078 .38803 Metetra
0 .023 .121 r
.27078 .38803 .27666 .39379 .28563 .39067 .27977 .3849 Metetra
0 .023 .121 r
.27977 .3849 .28563 .39067 .29463 .38755 .28879 .38175 Metetra
0 .023 .121 r
.28879 .38175 .29463 .38755 .30365 .38441 .29783 .3786 Metetra
0 .023 .121 r
.29783 .3786 .30365 .38441 .31271 .38127 .30691 .37543 Metetra
0 .023 .121 r
.30691 .37543 .31271 .38127 .3218 .37811 .31602 .37225 Metetra
0 .023 .121 r
.31602 .37225 .3218 .37811 .33092 .37494 .32516 .36906 Metetra
0 .023 .121 r
.32516 .36906 .33092 .37494 .34008 .37176 .33433 .36586 Metetra
0 .023 .121 r
.33433 .36586 .34008 .37176 .34926 .36857 .34354 .36265 Metetra
0 .023 .121 r
.34354 .36265 .34926 .36857 .35848 .36537 .35277 .35943 Metetra
0 .023 .121 r
.35277 .35943 .35848 .36537 .36773 .36216 .36204 .3562 Metetra
0 .023 .121 r
.36204 .3562 .36773 .36216 .37701 .35894 .37134 .35296 Metetra
0 .023 .121 r
.37134 .35296 .37701 .35894 .38632 .3557 .38067 .3497 Metetra
0 .023 .121 r
.38067 .3497 .38632 .3557 .39567 .35246 .39004 .34643 Metetra
0 .023 .121 r
.39004 .34643 .39567 .35246 .40504 .3492 .39944 .34316 Metetra
0 .023 .121 r
.39944 .34316 .40504 .3492 .41445 .34593 .40887 .33987 Metetra
0 .023 .121 r
.40887 .33987 .41445 .34593 .4239 .34266 .41833 .33657 Metetra
0 .023 .121 r
.41833 .33657 .4239 .34266 .43337 .33936 .42783 .33325 Metetra
0 .023 .121 r
.42783 .33325 .43337 .33936 .44288 .33607 .43736 .32993 Metetra
0 .023 .121 r
.43736 .32993 .44288 .33607 .45243 .33276 .44693 .3266 Metetra
0 .023 .121 r
.44693 .3266 .45243 .33276 .46201 .32942 .45653 .32325 Metetra
0 .024 .122 r
.45653 .32325 .46201 .32942 .47161 .32619 .46616 .31991 Metetra
0 .024 .122 r
.46616 .31991 .47161 .32619 .48126 .32292 .47582 .31656 Metetra
0 .025 .124 r
.47582 .31656 .48126 .32292 .49092 .32094 .48552 .31354 Metetra
0 .026 .126 r
.48552 .31354 .49092 .32094 .50064 .31757 .49526 .31014 Metetra
0 .025 .124 r
.49526 .31014 .50064 .31757 .5104 .3128 .50503 .30637 Metetra
0 .024 .122 r
.50503 .30637 .5104 .3128 .52019 .30932 .51484 .30293 Metetra
0 .024 .122 r
.51484 .30293 .52019 .30932 .53 .30581 .52468 .29947 Metetra
0 .023 .121 r
.52468 .29947 .53 .30581 .53986 .3024 .53456 .29603 Metetra
0 .023 .121 r
.53456 .29603 .53986 .3024 .54975 .29895 .54447 .29257 Metetra
0 .023 .121 r
.54447 .29257 .54975 .29895 .55967 .2955 .55442 .2891 Metetra
0 .023 .121 r
.55442 .2891 .55967 .2955 .56963 .29205 .5644 .28562 Metetra
0 .023 .121 r
.5644 .28562 .56963 .29205 .57963 .28857 .57442 .28212 Metetra
0 .023 .121 r
.57442 .28212 .57963 .28857 .58966 .28508 .58448 .27862 Metetra
0 .023 .121 r
.58448 .27862 .58966 .28508 .59973 .28159 .59457 .27509 Metetra
0 .023 .121 r
.59457 .27509 .59973 .28159 .60983 .27807 .6047 .27156 Metetra
0 .023 .121 r
.6047 .27156 .60983 .27807 .61997 .27455 .61486 .26802 Metetra
0 .023 .121 r
.61486 .26802 .61997 .27455 .63015 .27102 .62507 .26446 Metetra
0 .023 .121 r
.62507 .26446 .63015 .27102 .64037 .26747 .63531 .26088 Metetra
0 .023 .121 r
.63531 .26088 .64037 .26747 .65062 .26391 .64559 .2573 Metetra
0 .023 .121 r
.64559 .2573 .65062 .26391 .66091 .26033 .6559 .2537 Metetra
0 .023 .121 r
.6559 .2537 .66091 .26033 .67124 .25675 .66626 .25009 Metetra
0 .023 .121 r
.66626 .25009 .67124 .25675 .6816 .25315 .67665 .24647 Metetra
0 .023 .121 r
.67665 .24647 .6816 .25315 .69201 .24953 .68708 .24283 Metetra
0 .023 .121 r
.68708 .24283 .69201 .24953 .70245 .24591 .69755 .23918 Metetra
0 .023 .121 r
.69755 .23918 .70245 .24591 .71293 .24227 .70806 .23551 Metetra
0 .023 .121 r
.70806 .23551 .71293 .24227 .72345 .23861 .7186 .23183 Metetra
0 .023 .121 r
.7186 .23183 .72345 .23861 .73401 .23495 .72919 .22814 Metetra
0 .023 .121 r
.72919 .22814 .73401 .23495 .74461 .23127 .73981 .22443 Metetra
0 .023 .121 r
.73981 .22443 .74461 .23127 .75524 .22757 .75048 .22071 Metetra
0 .023 .121 r
.75048 .22071 .75524 .22757 .76592 .22386 .76118 .21698 Metetra
0 .023 .121 r
.76118 .21698 .76592 .22386 .77664 .22014 .77193 .21323 Metetra
0 .023 .121 r
.77193 .21323 .77664 .22014 .78739 .2164 .78271 .20947 Metetra
0 .023 .121 r
.78271 .20947 .78739 .2164 .79819 .21265 .79354 .20569 Metetra
0 .023 .121 r
.79354 .20569 .79819 .21265 .80903 .20889 .80441 .2019 Metetra
0 .023 .121 r
.80441 .2019 .80903 .20889 .81991 .20511 .81531 .1981 Metetra
0 .023 .121 r
.19394 .40708 .2 .41272 .20874 .40967 .2027 .40401 Metetra
0 .023 .121 r
.2027 .40401 .20874 .40967 .21751 .40661 .21149 .40093 Metetra
0 .023 .121 r
.21149 .40093 .21751 .40661 .22632 .40354 .22031 .39784 Metetra
0 .023 .121 r
.22031 .39784 .22632 .40354 .23515 .40046 .22916 .39474 Metetra
0 .023 .121 r
.22916 .39474 .23515 .40046 .24401 .39737 .23805 .39163 Metetra
0 .023 .121 r
.23805 .39163 .24401 .39737 .25291 .39427 .24696 .38851 Metetra
0 .023 .121 r
.24696 .38851 .25291 .39427 .26183 .39115 .2559 .38538 Metetra
0 .023 .121 r
.2559 .38538 .26183 .39115 .27078 .38803 .26487 .38224 Metetra
0 .023 .121 r
.26487 .38224 .27078 .38803 .27977 .3849 .27387 .37908 Metetra
0 .023 .121 r
.27387 .37908 .27977 .3849 .28879 .38175 .28291 .37592 Metetra
0 .023 .121 r
.28291 .37592 .28879 .38175 .29783 .3786 .29197 .37274 Metetra
0 .023 .121 r
.29197 .37274 .29783 .3786 .30691 .37543 .30107 .36956 Metetra
0 .023 .121 r
.30107 .36956 .30691 .37543 .31602 .37225 .3102 .36636 Metetra
0 .023 .121 r
.3102 .36636 .31602 .37225 .32516 .36906 .31936 .36315 Metetra
0 .023 .121 r
.31936 .36315 .32516 .36906 .33433 .36586 .32855 .35993 Metetra
0 .023 .121 r
.32855 .35993 .33433 .36586 .34354 .36265 .33777 .3567 Metetra
0 .023 .121 r
.33777 .3567 .34354 .36265 .35277 .35943 .34703 .35346 Metetra
0 .023 .121 r
.34703 .35346 .35277 .35943 .36204 .3562 .35632 .3502 Metetra
0 .023 .121 r
.35632 .3502 .36204 .3562 .37134 .35296 .36564 .34694 Metetra
0 .023 .121 r
.36564 .34694 .37134 .35296 .38067 .3497 .37499 .34366 Metetra
0 .023 .121 r
.37499 .34366 .38067 .3497 .39004 .34643 .38438 .34038 Metetra
0 .023 .121 r
.38438 .34038 .39004 .34643 .39944 .34316 .39379 .33708 Metetra
0 .023 .121 r
.39379 .33708 .39944 .34316 .40887 .33987 .40325 .33376 Metetra
0 .023 .121 r
.40325 .33376 .40887 .33987 .41833 .33657 .41273 .33045 Metetra
0 .023 .121 r
.41273 .33045 .41833 .33657 .42783 .33325 .42225 .32711 Metetra
0 .023 .121 r
.42225 .32711 .42783 .33325 .43736 .32993 .4318 .32377 Metetra
0 .023 .121 r
.4318 .32377 .43736 .32993 .44693 .3266 .44139 .32042 Metetra
0 .023 .121 r
.44139 .32042 .44693 .3266 .45653 .32325 .45101 .31704 Metetra
0 .024 .122 r
.45101 .31704 .45653 .32325 .46616 .31991 .46066 .31374 Metetra
0 .024 .122 r
.46066 .31374 .46616 .31991 .47582 .31656 .47035 .31042 Metetra
0 .025 .123 r
.47035 .31042 .47582 .31656 .48552 .31354 .48006 .30821 Metetra
0 .026 .125 r
.48006 .30821 .48552 .31354 .49526 .31014 .48982 .3048 Metetra
0 .025 .123 r
.48982 .3048 .49526 .31014 .50503 .30637 .49963 .30017 Metetra
0 .024 .122 r
.49963 .30017 .50503 .30637 .51484 .30293 .50946 .29665 Metetra
0 .024 .122 r
.50946 .29665 .51484 .30293 .52468 .29947 .51932 .29311 Metetra
0 .023 .121 r
.51932 .29311 .52468 .29947 .53456 .29603 .52922 .28965 Metetra
0 .023 .121 r
.52922 .28965 .53456 .29603 .54447 .29257 .53916 .28616 Metetra
0 .023 .121 r
.53916 .28616 .54447 .29257 .55442 .2891 .54913 .28266 Metetra
0 .023 .121 r
.54913 .28266 .55442 .2891 .5644 .28562 .55914 .27916 Metetra
0 .023 .121 r
.55914 .27916 .5644 .28562 .57442 .28212 .56918 .27564 Metetra
0 .023 .121 r
.56918 .27564 .57442 .28212 .58448 .27862 .57926 .27211 Metetra
0 .023 .121 r
.57926 .27211 .58448 .27862 .59457 .27509 .58938 .26856 Metetra
0 .023 .121 r
.58938 .26856 .59457 .27509 .6047 .27156 .59953 .26501 Metetra
0 .023 .121 r
.59953 .26501 .6047 .27156 .61486 .26802 .60972 .26144 Metetra
0 .023 .121 r
.60972 .26144 .61486 .26802 .62507 .26446 .61995 .25785 Metetra
0 .023 .121 r
.61995 .25785 .62507 .26446 .63531 .26088 .63022 .25426 Metetra
0 .023 .121 r
.63022 .25426 .63531 .26088 .64559 .2573 .64052 .25065 Metetra
0 .023 .121 r
.64052 .25065 .64559 .2573 .6559 .2537 .65086 .24702 Metetra
0 .023 .121 r
.65086 .24702 .6559 .2537 .66626 .25009 .66124 .24339 Metetra
0 .023 .121 r
.66124 .24339 .66626 .25009 .67665 .24647 .67166 .23974 Metetra
0 .023 .121 r
.67166 .23974 .67665 .24647 .68708 .24283 .68212 .23608 Metetra
0 .023 .121 r
.68212 .23608 .68708 .24283 .69755 .23918 .69261 .2324 Metetra
0 .023 .121 r
.69261 .2324 .69755 .23918 .70806 .23551 .70315 .22871 Metetra
0 .023 .121 r
.70315 .22871 .70806 .23551 .7186 .23183 .71372 .22501 Metetra
0 .023 .121 r
.71372 .22501 .7186 .23183 .72919 .22814 .72433 .22129 Metetra
0 .023 .121 r
.72433 .22129 .72919 .22814 .73981 .22443 .73499 .21756 Metetra
0 .023 .121 r
.73499 .21756 .73981 .22443 .75048 .22071 .74568 .21381 Metetra
0 .023 .121 r
.74568 .21381 .75048 .22071 .76118 .21698 .75641 .21005 Metetra
0 .023 .121 r
.75641 .21005 .76118 .21698 .77193 .21323 .76719 .20628 Metetra
0 .023 .121 r
.76719 .20628 .77193 .21323 .78271 .20947 .778 .20249 Metetra
0 .023 .121 r
.778 .20249 .78271 .20947 .79354 .20569 .78885 .19869 Metetra
0 .023 .121 r
.78885 .19869 .79354 .20569 .80441 .2019 .79975 .19487 Metetra
0 .023 .121 r
.79975 .19487 .80441 .2019 .81531 .1981 .81069 .19104 Metetra
0 .023 .121 r
.18785 .40141 .19394 .40708 .2027 .40401 .19663 .39832 Metetra
0 .023 .121 r
.19663 .39832 .2027 .40401 .21149 .40093 .20543 .39522 Metetra
0 .023 .121 r
.20543 .39522 .21149 .40093 .22031 .39784 .21427 .39211 Metetra
0 .023 .121 r
.21427 .39211 .22031 .39784 .22916 .39474 .22314 .38899 Metetra
0 .023 .121 r
.22314 .38899 .22916 .39474 .23805 .39163 .23204 .38586 Metetra
0 .023 .121 r
.23204 .38586 .23805 .39163 .24696 .38851 .24097 .38272 Metetra
0 .023 .121 r
.24097 .38272 .24696 .38851 .2559 .38538 .24993 .37957 Metetra
0 .023 .121 r
.24993 .37957 .2559 .38538 .26487 .38224 .25892 .3764 Metetra
0 .023 .121 r
.25892 .3764 .26487 .38224 .27387 .37908 .26794 .37323 Metetra
0 .023 .121 r
.26794 .37323 .27387 .37908 .28291 .37592 .27699 .37005 Metetra
0 .023 .121 r
.27699 .37005 .28291 .37592 .29197 .37274 .28608 .36685 Metetra
0 .023 .121 r
.28608 .36685 .29197 .37274 .30107 .36956 .29519 .36364 Metetra
0 .023 .121 r
.29519 .36364 .30107 .36956 .3102 .36636 .30434 .36042 Metetra
0 .023 .121 r
.30434 .36042 .3102 .36636 .31936 .36315 .31352 .3572 Metetra
0 .023 .121 r
.31352 .3572 .31936 .36315 .32855 .35993 .32273 .35396 Metetra
0 .023 .121 r
.32273 .35396 .32855 .35993 .33777 .3567 .33197 .3507 Metetra
0 .023 .121 r
.33197 .3507 .33777 .3567 .34703 .35346 .34125 .34744 Metetra
0 .023 .121 r
.34125 .34744 .34703 .35346 .35632 .3502 .35056 .34417 Metetra
0 .023 .121 r
.35056 .34417 .35632 .3502 .36564 .34694 .3599 .34088 Metetra
0 .023 .121 r
.3599 .34088 .36564 .34694 .37499 .34366 .36927 .33758 Metetra
0 .023 .121 r
.36927 .33758 .37499 .34366 .38438 .34038 .37868 .33427 Metetra
0 .023 .121 r
.37868 .33427 .38438 .34038 .39379 .33708 .38811 .33095 Metetra
0 .023 .121 r
.38811 .33095 .39379 .33708 .40325 .33376 .39759 .32762 Metetra
0 .023 .121 r
.39759 .32762 .40325 .33376 .41273 .33045 .40709 .32428 Metetra
0 .023 .121 r
.40709 .32428 .41273 .33045 .42225 .32711 .41663 .32092 Metetra
0 .023 .121 r
.41663 .32092 .42225 .32711 .4318 .32377 .42621 .31755 Metetra
0 .023 .121 r
.42621 .31755 .4318 .32377 .44139 .32042 .43582 .31417 Metetra
0 .023 .121 r
.43582 .31417 .44139 .32042 .45101 .31704 .44546 .31078 Metetra
0 .024 .122 r
.44546 .31078 .45101 .31704 .46066 .31374 .45513 .30739 Metetra
0 .024 .122 r
.45513 .30739 .46066 .31374 .47035 .31042 .46485 .30399 Metetra
0 .025 .123 r
.46485 .30399 .47035 .31042 .48006 .30821 .47459 .30077 Metetra
0 .026 .125 r
.47459 .30077 .48006 .30821 .48982 .3048 .48437 .29733 Metetra
0 .025 .123 r
.48437 .29733 .48982 .3048 .49963 .30017 .49419 .29366 Metetra
0 .024 .122 r
.49419 .29366 .49963 .30017 .50946 .29665 .50404 .29018 Metetra
0 .024 .122 r
.50404 .29018 .50946 .29665 .51932 .29311 .51393 .28669 Metetra
0 .023 .121 r
.51393 .28669 .51932 .29311 .52922 .28965 .52385 .2832 Metetra
0 .023 .121 r
.52385 .2832 .52922 .28965 .53916 .28616 .53381 .2797 Metetra
0 .023 .121 r
.53381 .2797 .53916 .28616 .54913 .28266 .54381 .27618 Metetra
0 .023 .121 r
.54381 .27618 .54913 .28266 .55914 .27916 .55384 .27265 Metetra
0 .023 .121 r
.55384 .27265 .55914 .27916 .56918 .27564 .5639 .26911 Metetra
0 .023 .121 r
.5639 .26911 .56918 .27564 .57926 .27211 .57401 .26555 Metetra
0 .023 .121 r
.57401 .26555 .57926 .27211 .58938 .26856 .58415 .26199 Metetra
0 .023 .121 r
.58415 .26199 .58938 .26856 .59953 .26501 .59433 .2584 Metetra
0 .023 .121 r
.59433 .2584 .59953 .26501 .60972 .26144 .60455 .25481 Metetra
0 .023 .121 r
.60455 .25481 .60972 .26144 .61995 .25785 .6148 .2512 Metetra
0 .023 .121 r
.6148 .2512 .61995 .25785 .63022 .25426 .62509 .24758 Metetra
0 .023 .121 r
.62509 .24758 .63022 .25426 .64052 .25065 .63542 .24395 Metetra
0 .023 .121 r
.63542 .24395 .64052 .25065 .65086 .24702 .64579 .2403 Metetra
0 .023 .121 r
.64579 .2403 .65086 .24702 .66124 .24339 .65619 .23664 Metetra
0 .023 .121 r
.65619 .23664 .66124 .24339 .67166 .23974 .66664 .23297 Metetra
0 .023 .121 r
.66664 .23297 .67166 .23974 .68212 .23608 .67712 .22928 Metetra
0 .023 .121 r
.67712 .22928 .68212 .23608 .69261 .2324 .68764 .22558 Metetra
0 .023 .121 r
.68764 .22558 .69261 .2324 .70315 .22871 .6982 .22186 Metetra
0 .023 .121 r
.6982 .22186 .70315 .22871 .71372 .22501 .7088 .21813 Metetra
0 .023 .121 r
.7088 .21813 .71372 .22501 .72433 .22129 .71945 .21439 Metetra
0 .023 .121 r
.71945 .21439 .72433 .22129 .73499 .21756 .73013 .21063 Metetra
0 .023 .121 r
.73013 .21063 .73499 .21756 .74568 .21381 .74085 .20686 Metetra
0 .023 .121 r
.74085 .20686 .74568 .21381 .75641 .21005 .75161 .20307 Metetra
0 .023 .121 r
.75161 .20307 .75641 .21005 .76719 .20628 .76241 .19927 Metetra
0 .023 .121 r
.76241 .19927 .76719 .20628 .778 .20249 .77325 .19546 Metetra
0 .023 .121 r
.77325 .19546 .778 .20249 .78885 .19869 .78414 .19163 Metetra
0 .023 .121 r
.78414 .19163 .78885 .19869 .79975 .19487 .79506 .18778 Metetra
0 .023 .121 r
.79506 .18778 .79975 .19487 .81069 .19104 .80603 .18393 Metetra
0 .023 .121 r
.18172 .3957 .18785 .40141 .19663 .39832 .19051 .39259 Metetra
0 .023 .121 r
.19051 .39259 .19663 .39832 .20543 .39522 .19934 .38947 Metetra
0 .023 .121 r
.19934 .38947 .20543 .39522 .21427 .39211 .20819 .38634 Metetra
0 .023 .121 r
.20819 .38634 .21427 .39211 .22314 .38899 .21708 .3832 Metetra
0 .023 .121 r
.21708 .3832 .22314 .38899 .23204 .38586 .22599 .38005 Metetra
0 .023 .121 r
.22599 .38005 .23204 .38586 .24097 .38272 .23494 .37689 Metetra
0 .023 .121 r
.23494 .37689 .24097 .38272 .24993 .37957 .24392 .37372 Metetra
0 .023 .121 r
.24392 .37372 .24993 .37957 .25892 .3764 .25293 .37054 Metetra
0 .023 .121 r
.25293 .37054 .25892 .3764 .26794 .37323 .26197 .36734 Metetra
0 .023 .121 r
.26197 .36734 .26794 .37323 .27699 .37005 .27104 .36414 Metetra
0 .023 .121 r
.27104 .36414 .27699 .37005 .28608 .36685 .28014 .36092 Metetra
0 .023 .121 r
.28014 .36092 .28608 .36685 .29519 .36364 .28928 .35769 Metetra
0 .023 .121 r
.28928 .35769 .29519 .36364 .30434 .36042 .29844 .35445 Metetra
0 .023 .121 r
.29844 .35445 .30434 .36042 .31352 .3572 .30764 .3512 Metetra
0 .023 .121 r
.30764 .3512 .31352 .3572 .32273 .35396 .31687 .34794 Metetra
0 .023 .121 r
.31687 .34794 .32273 .35396 .33197 .3507 .32613 .34467 Metetra
0 .023 .121 r
.32613 .34467 .33197 .3507 .34125 .34744 .33543 .34139 Metetra
0 .023 .121 r
.33543 .34139 .34125 .34744 .35056 .34417 .34476 .33809 Metetra
0 .023 .121 r
.34476 .33809 .35056 .34417 .3599 .34088 .35412 .33478 Metetra
0 .023 .121 r
.35412 .33478 .3599 .34088 .36927 .33758 .36351 .33146 Metetra
0 .023 .121 r
.36351 .33146 .36927 .33758 .37868 .33427 .37294 .32813 Metetra
0 .023 .121 r
.37294 .32813 .37868 .33427 .38811 .33095 .3824 .32479 Metetra
0 .023 .121 r
.3824 .32479 .38811 .33095 .39759 .32762 .39189 .32144 Metetra
0 .023 .121 r
.39189 .32144 .39759 .32762 .40709 .32428 .40142 .31807 Metetra
0 .023 .121 r
.40142 .31807 .40709 .32428 .41663 .32092 .41098 .31469 Metetra
0 .023 .121 r
.41098 .31469 .41663 .32092 .42621 .31755 .42058 .3113 Metetra
0 .023 .121 r
.42058 .3113 .42621 .31755 .43582 .31417 .43021 .30791 Metetra
0 .023 .121 r
.43021 .30791 .43582 .31417 .44546 .31078 .43987 .30449 Metetra
0 .023 .121 r
.43987 .30449 .44546 .31078 .45513 .30739 .44957 .30109 Metetra
0 .024 .122 r
.44957 .30109 .45513 .30739 .46485 .30399 .4593 .29768 Metetra
0 .024 .122 r
.4593 .29768 .46485 .30399 .47459 .30077 .46906 .29467 Metetra
0 .025 .123 r
.46906 .29467 .47459 .30077 .48437 .29733 .47887 .2912 Metetra
0 .024 .122 r
.47887 .2912 .48437 .29733 .49419 .29366 .48871 .28729 Metetra
0 .024 .122 r
.48871 .28729 .49419 .29366 .50404 .29018 .49859 .28377 Metetra
0 .023 .121 r
.49859 .28377 .50404 .29018 .51393 .28669 .5085 .28024 Metetra
0 .023 .121 r
.5085 .28024 .51393 .28669 .52385 .2832 .51844 .27673 Metetra
0 .023 .121 r
.51844 .27673 .52385 .2832 .53381 .2797 .52843 .2732 Metetra
0 .023 .121 r
.52843 .2732 .53381 .2797 .54381 .27618 .53845 .26965 Metetra
0 .023 .121 r
.53845 .26965 .54381 .27618 .55384 .27265 .5485 .2661 Metetra
0 .023 .121 r
.5485 .2661 .55384 .27265 .5639 .26911 .55859 .26254 Metetra
0 .023 .121 r
.55859 .26254 .5639 .26911 .57401 .26555 .56872 .25896 Metetra
0 .023 .121 r
.56872 .25896 .57401 .26555 .58415 .26199 .57889 .25536 Metetra
0 .023 .121 r
.57889 .25536 .58415 .26199 .59433 .2584 .58909 .25176 Metetra
0 .023 .121 r
.58909 .25176 .59433 .2584 .60455 .25481 .59933 .24814 Metetra
0 .023 .121 r
.59933 .24814 .60455 .25481 .6148 .2512 .60961 .24451 Metetra
0 .023 .121 r
.60961 .24451 .6148 .2512 .62509 .24758 .61993 .24086 Metetra
0 .023 .121 r
.61993 .24086 .62509 .24758 .63542 .24395 .63028 .2372 Metetra
0 .023 .121 r
.63028 .2372 .63542 .24395 .64579 .2403 .64068 .23353 Metetra
0 .023 .121 r
.64068 .23353 .64579 .2403 .65619 .23664 .65111 .22985 Metetra
0 .023 .121 r
.65111 .22985 .65619 .23664 .66664 .23297 .66158 .22615 Metetra
0 .023 .121 r
.66158 .22615 .66664 .23297 .67712 .22928 .67209 .22243 Metetra
0 .023 .121 r
.67209 .22243 .67712 .22928 .68764 .22558 .68264 .21871 Metetra
0 .023 .121 r
.68264 .21871 .68764 .22558 .6982 .22186 .69323 .21496 Metetra
0 .023 .121 r
.69323 .21496 .6982 .22186 .7088 .21813 .70386 .21121 Metetra
0 .023 .121 r
.70386 .21121 .7088 .21813 .71945 .21439 .71452 .20744 Metetra
0 .023 .121 r
.71452 .20744 .71945 .21439 .73013 .21063 .72523 .20366 Metetra
0 .023 .121 r
.72523 .20366 .73013 .21063 .74085 .20686 .73598 .19986 Metetra
0 .023 .121 r
.73598 .19986 .74085 .20686 .75161 .20307 .74677 .19604 Metetra
0 .023 .121 r
.74677 .19604 .75161 .20307 .76241 .19927 .7576 .19222 Metetra
0 .023 .121 r
.7576 .19222 .76241 .19927 .77325 .19546 .76847 .18838 Metetra
0 .023 .121 r
.76847 .18838 .77325 .19546 .78414 .19163 .77939 .18452 Metetra
0 .023 .121 r
.77939 .18452 .78414 .19163 .79506 .18778 .79034 .18065 Metetra
0 .023 .121 r
.79034 .18065 .79506 .18778 .80603 .18393 .80134 .17677 Metetra
0 .023 .121 r
.17555 .38995 .18172 .3957 .19051 .39259 .18436 .38683 Metetra
0 .023 .121 r
.18436 .38683 .19051 .39259 .19934 .38947 .1932 .38369 Metetra
0 .023 .121 r
.1932 .38369 .19934 .38947 .20819 .38634 .20207 .38054 Metetra
0 .023 .121 r
.20207 .38054 .20819 .38634 .21708 .3832 .21098 .37738 Metetra
0 .023 .121 r
.21098 .37738 .21708 .3832 .22599 .38005 .21991 .37421 Metetra
0 .023 .121 r
.21991 .37421 .22599 .38005 .23494 .37689 .22888 .37103 Metetra
0 .023 .121 r
.22888 .37103 .23494 .37689 .24392 .37372 .23787 .36783 Metetra
0 .023 .121 r
.23787 .36783 .24392 .37372 .25293 .37054 .2469 .36463 Metetra
0 .023 .121 r
.2469 .36463 .25293 .37054 .26197 .36734 .25596 .36142 Metetra
0 .023 .121 r
.25596 .36142 .26197 .36734 .27104 .36414 .26505 .35819 Metetra
0 .023 .121 r
.26505 .35819 .27104 .36414 .28014 .36092 .27417 .35495 Metetra
0 .023 .121 r
.27417 .35495 .28014 .36092 .28928 .35769 .28332 .35171 Metetra
0 .023 .121 r
.28332 .35171 .28928 .35769 .29844 .35445 .29251 .34845 Metetra
0 .023 .121 r
.29251 .34845 .29844 .35445 .30764 .3512 .30173 .34517 Metetra
0 .023 .121 r
.30173 .34517 .30764 .3512 .31687 .34794 .31098 .34189 Metetra
0 .023 .121 r
.31098 .34189 .31687 .34794 .32613 .34467 .32026 .3386 Metetra
0 .023 .121 r
.32026 .3386 .32613 .34467 .33543 .34139 .32957 .33529 Metetra
0 .023 .121 r
.32957 .33529 .33543 .34139 .34476 .33809 .33892 .33198 Metetra
0 .023 .121 r
.33892 .33198 .34476 .33809 .35412 .33478 .3483 .32865 Metetra
0 .023 .121 r
.3483 .32865 .35412 .33478 .36351 .33146 .35772 .32531 Metetra
0 .023 .121 r
.35772 .32531 .36351 .33146 .37294 .32813 .36716 .32195 Metetra
0 .023 .121 r
.36716 .32195 .37294 .32813 .3824 .32479 .37664 .31859 Metetra
0 .023 .121 r
.37664 .31859 .3824 .32479 .39189 .32144 .38616 .31521 Metetra
0 .023 .121 r
.38616 .31521 .39189 .32144 .40142 .31807 .39571 .31183 Metetra
0 .023 .121 r
.39571 .31183 .40142 .31807 .41098 .31469 .40529 .30842 Metetra
0 .023 .121 r
.40529 .30842 .41098 .31469 .42058 .3113 .41491 .30501 Metetra
0 .023 .121 r
.41491 .30501 .42058 .3113 .43021 .30791 .42456 .30159 Metetra
0 .023 .121 r
.42456 .30159 .43021 .30791 .43987 .30449 .43424 .29815 Metetra
0 .023 .121 r
.43424 .29815 .43987 .30449 .44957 .30109 .44396 .29473 Metetra
0 .024 .122 r
.44396 .29473 .44957 .30109 .4593 .29768 .45372 .29129 Metetra
0 .024 .122 r
.45372 .29129 .4593 .29768 .46906 .29467 .4635 .28818 Metetra
0 .025 .123 r
.4635 .28818 .46906 .29467 .47887 .2912 .47333 .2847 Metetra
0 .024 .122 r
.47333 .2847 .47887 .2912 .48871 .28729 .4832 .28083 Metetra
0 .024 .122 r
.4832 .28083 .48871 .28729 .49859 .28377 .4931 .27729 Metetra
0 .023 .121 r
.4931 .27729 .49859 .28377 .5085 .28024 .50303 .27374 Metetra
0 .023 .121 r
.50303 .27374 .5085 .28024 .51844 .27673 .513 .2702 Metetra
0 .023 .121 r
.513 .2702 .51844 .27673 .52843 .2732 .52301 .26665 Metetra
0 .023 .121 r
.52301 .26665 .52843 .2732 .53845 .26965 .53305 .26308 Metetra
0 .023 .121 r
.53305 .26308 .53845 .26965 .5485 .2661 .54313 .25951 Metetra
0 .023 .121 r
.54313 .25951 .5485 .2661 .55859 .26254 .55325 .25592 Metetra
0 .023 .121 r
.55325 .25592 .55859 .26254 .56872 .25896 .5634 .25231 Metetra
0 .023 .121 r
.5634 .25231 .56872 .25896 .57889 .25536 .57359 .2487 Metetra
0 .023 .121 r
.57359 .2487 .57889 .25536 .58909 .25176 .58382 .24507 Metetra
0 .023 .121 r
.58382 .24507 .58909 .25176 .59933 .24814 .59408 .24143 Metetra
0 .023 .121 r
.59408 .24143 .59933 .24814 .60961 .24451 .60439 .23777 Metetra
0 .023 .121 r
.60439 .23777 .60961 .24451 .61993 .24086 .61473 .2341 Metetra
0 .023 .121 r
.61473 .2341 .61993 .24086 .63028 .2372 .62511 .23041 Metetra
0 .023 .121 r
.62511 .23041 .63028 .2372 .64068 .23353 .63553 .22672 Metetra
0 .023 .121 r
.63553 .22672 .64068 .23353 .65111 .22985 .64599 .223 Metetra
0 .023 .121 r
.64599 .223 .65111 .22985 .66158 .22615 .65649 .21928 Metetra
0 .023 .121 r
.65649 .21928 .66158 .22615 .67209 .22243 .66702 .21554 Metetra
0 .023 .121 r
.66702 .21554 .67209 .22243 .68264 .21871 .6776 .21179 Metetra
0 .023 .121 r
.6776 .21179 .68264 .21871 .69323 .21496 .68822 .20802 Metetra
0 .023 .121 r
.68822 .20802 .69323 .21496 .70386 .21121 .69887 .20424 Metetra
0 .023 .121 r
.69887 .20424 .70386 .21121 .71452 .20744 .70957 .20044 Metetra
0 .023 .121 r
.70957 .20044 .71452 .20744 .72523 .20366 .7203 .19663 Metetra
0 .023 .121 r
.7203 .19663 .72523 .20366 .73598 .19986 .73108 .19281 Metetra
0 .023 .121 r
.73108 .19281 .73598 .19986 .74677 .19604 .7419 .18897 Metetra
0 .023 .121 r
.7419 .18897 .74677 .19604 .7576 .19222 .75276 .18512 Metetra
0 .023 .121 r
.75276 .18512 .7576 .19222 .76847 .18838 .76366 .18125 Metetra
0 .023 .121 r
.76366 .18125 .76847 .18838 .77939 .18452 .7746 .17736 Metetra
0 .023 .121 r
.7746 .17736 .77939 .18452 .79034 .18065 .78558 .17347 Metetra
0 .023 .121 r
.78558 .17347 .79034 .18065 .80134 .17677 .79661 .16955 Metetra
0 .023 .121 r
.16934 .38417 .17555 .38995 .18436 .38683 .17817 .38102 Metetra
0 .023 .121 r
.17817 .38102 .18436 .38683 .1932 .38369 .18703 .37787 Metetra
0 .023 .121 r
.18703 .37787 .1932 .38369 .20207 .38054 .19592 .3747 Metetra
0 .023 .121 r
.19592 .3747 .20207 .38054 .21098 .37738 .20484 .37152 Metetra
0 .023 .121 r
.20484 .37152 .21098 .37738 .21991 .37421 .21379 .36833 Metetra
0 .023 .121 r
.21379 .36833 .21991 .37421 .22888 .37103 .22277 .36512 Metetra
0 .023 .121 r
.22277 .36512 .22888 .37103 .23787 .36783 .23179 .36191 Metetra
0 .023 .121 r
.23179 .36191 .23787 .36783 .2469 .36463 .24083 .35869 Metetra
0 .023 .121 r
.24083 .35869 .2469 .36463 .25596 .36142 .24991 .35545 Metetra
0 .023 .121 r
.24991 .35545 .25596 .36142 .26505 .35819 .25902 .35221 Metetra
0 .023 .121 r
.25902 .35221 .26505 .35819 .27417 .35495 .26816 .34895 Metetra
0 .023 .121 r
.26816 .34895 .27417 .35495 .28332 .35171 .27733 .34568 Metetra
0 .023 .121 r
.27733 .34568 .28332 .35171 .29251 .34845 .28654 .3424 Metetra
0 .023 .121 r
.28654 .3424 .29251 .34845 .30173 .34517 .29577 .33911 Metetra
0 .023 .121 r
.29577 .33911 .30173 .34517 .31098 .34189 .30504 .3358 Metetra
0 .023 .121 r
.30504 .3358 .31098 .34189 .32026 .3386 .31434 .33249 Metetra
0 .023 .121 r
.31434 .33249 .32026 .3386 .32957 .33529 .32368 .32916 Metetra
0 .023 .121 r
.32368 .32916 .32957 .33529 .33892 .33198 .33305 .32582 Metetra
0 .023 .121 r
.33305 .32582 .33892 .33198 .3483 .32865 .34245 .32247 Metetra
0 .023 .121 r
.34245 .32247 .3483 .32865 .35772 .32531 .35188 .31911 Metetra
0 .023 .121 r
.35188 .31911 .35772 .32531 .36716 .32195 .36135 .31573 Metetra
0 .023 .121 r
.36135 .31573 .36716 .32195 .37664 .31859 .37085 .31235 Metetra
0 .023 .121 r
.37085 .31235 .37664 .31859 .38616 .31521 .38039 .30895 Metetra
0 .023 .121 r
.38039 .30895 .38616 .31521 .39571 .31183 .38996 .30554 Metetra
0 .023 .121 r
.38996 .30554 .39571 .31183 .40529 .30842 .39956 .30211 Metetra
0 .023 .121 r
.39956 .30211 .40529 .30842 .41491 .30501 .4092 .29868 Metetra
0 .023 .121 r
.4092 .29868 .41491 .30501 .42456 .30159 .41887 .29523 Metetra
0 .023 .121 r
.41887 .29523 .42456 .30159 .43424 .29815 .42858 .29177 Metetra
0 .023 .121 r
.42858 .29177 .43424 .29815 .44396 .29473 .43832 .2883 Metetra
0 .023 .122 r
.43832 .2883 .44396 .29473 .45372 .29129 .4481 .28482 Metetra
0 .024 .122 r
.4481 .28482 .45372 .29129 .4635 .28818 .45791 .2814 Metetra
0 .024 .122 r
.45791 .2814 .4635 .28818 .47333 .2847 .46776 .27789 Metetra
0 .024 .122 r
.46776 .27789 .47333 .2847 .4832 .28083 .47765 .27429 Metetra
0 .023 .122 r
.47765 .27429 .4832 .28083 .4931 .27729 .48757 .27075 Metetra
0 .023 .121 r
.48757 .27075 .4931 .27729 .50303 .27374 .49753 .2672 Metetra
0 .023 .121 r
.49753 .2672 .50303 .27374 .513 .2702 .50752 .26363 Metetra
0 .023 .121 r
.50752 .26363 .513 .2702 .52301 .26665 .51755 .26006 Metetra
0 .023 .121 r
.51755 .26006 .52301 .26665 .53305 .26308 .52762 .25647 Metetra
0 .023 .121 r
.52762 .25647 .53305 .26308 .54313 .25951 .53772 .25287 Metetra
0 .023 .121 r
.53772 .25287 .54313 .25951 .55325 .25592 .54786 .24925 Metetra
0 .023 .121 r
.54786 .24925 .55325 .25592 .5634 .25231 .55804 .24563 Metetra
0 .023 .121 r
.55804 .24563 .5634 .25231 .57359 .2487 .56826 .24199 Metetra
0 .023 .121 r
.56826 .24199 .57359 .2487 .58382 .24507 .57851 .23833 Metetra
0 .023 .121 r
.57851 .23833 .58382 .24507 .59408 .24143 .5888 .23466 Metetra
0 .023 .121 r
.5888 .23466 .59408 .24143 .60439 .23777 .59913 .23098 Metetra
0 .023 .121 r
.59913 .23098 .60439 .23777 .61473 .2341 .6095 .22729 Metetra
0 .023 .121 r
.6095 .22729 .61473 .2341 .62511 .23041 .61991 .22358 Metetra
0 .023 .121 r
.61991 .22358 .62511 .23041 .63553 .22672 .63035 .21985 Metetra
0 .023 .121 r
.63035 .21985 .63553 .22672 .64599 .223 .64084 .21612 Metetra
0 .023 .121 r
.64084 .21612 .64599 .223 .65649 .21928 .65136 .21237 Metetra
0 .023 .121 r
.65136 .21237 .65649 .21928 .66702 .21554 .66192 .2086 Metetra
0 .023 .121 r
.66192 .2086 .66702 .21554 .6776 .21179 .67253 .20482 Metetra
0 .023 .121 r
.67253 .20482 .6776 .21179 .68822 .20802 .68317 .20103 Metetra
0 .023 .121 r
.68317 .20103 .68822 .20802 .69887 .20424 .69385 .19722 Metetra
0 .023 .121 r
.69385 .19722 .69887 .20424 .70957 .20044 .70458 .1934 Metetra
0 .023 .121 r
.70458 .1934 .70957 .20044 .7203 .19663 .71534 .18956 Metetra
0 .023 .121 r
.71534 .18956 .7203 .19663 .73108 .19281 .72615 .18571 Metetra
0 .023 .121 r
.72615 .18571 .73108 .19281 .7419 .18897 .73699 .18184 Metetra
0 .023 .121 r
.73699 .18184 .7419 .18897 .75276 .18512 .74788 .17796 Metetra
0 .023 .121 r
.74788 .17796 .75276 .18512 .76366 .18125 .75881 .17407 Metetra
0 .023 .121 r
.75881 .17407 .76366 .18125 .7746 .17736 .76978 .17016 Metetra
0 .023 .121 r
.76978 .17016 .7746 .17736 .78558 .17347 .7808 .16623 Metetra
0 .023 .121 r
.7808 .16623 .78558 .17347 .79661 .16955 .79185 .16229 Metetra
0 .023 .121 r
.16309 .37835 .16934 .38417 .17817 .38102 .17193 .37519 Metetra
0 .023 .121 r
.17193 .37519 .17817 .38102 .18703 .37787 .18081 .37201 Metetra
0 .023 .121 r
.18081 .37201 .18703 .37787 .19592 .3747 .18972 .36882 Metetra
0 .023 .121 r
.18972 .36882 .19592 .3747 .20484 .37152 .19866 .36562 Metetra
0 .023 .121 r
.19866 .36562 .20484 .37152 .21379 .36833 .20763 .36241 Metetra
0 .023 .121 r
.20763 .36241 .21379 .36833 .22277 .36512 .21663 .35918 Metetra
0 .023 .121 r
.21663 .35918 .22277 .36512 .23179 .36191 .22566 .35595 Metetra
0 .023 .121 r
.22566 .35595 .23179 .36191 .24083 .35869 .23473 .35271 Metetra
0 .023 .121 r
.23473 .35271 .24083 .35869 .24991 .35545 .24382 .34945 Metetra
0 .023 .121 r
.24382 .34945 .24991 .35545 .25902 .35221 .25295 .34618 Metetra
0 .023 .121 r
.25295 .34618 .25902 .35221 .26816 .34895 .26211 .3429 Metetra
0 .023 .121 r
.26211 .3429 .26816 .34895 .27733 .34568 .2713 .33961 Metetra
0 .023 .121 r
.2713 .33961 .27733 .34568 .28654 .3424 .28052 .33631 Metetra
0 .023 .121 r
.28052 .33631 .28654 .3424 .29577 .33911 .28978 .333 Metetra
0 .023 .121 r
.28978 .333 .29577 .33911 .30504 .3358 .29907 .32967 Metetra
0 .023 .121 r
.29907 .32967 .30504 .3358 .31434 .33249 .30839 .32633 Metetra
0 .023 .121 r
.30839 .32633 .31434 .33249 .32368 .32916 .31775 .32299 Metetra
0 .023 .121 r
.31775 .32299 .32368 .32916 .33305 .32582 .32713 .31962 Metetra
0 .023 .121 r
.32713 .31962 .33305 .32582 .34245 .32247 .33656 .31625 Metetra
0 .023 .121 r
.33656 .31625 .34245 .32247 .35188 .31911 .34601 .31287 Metetra
0 .023 .121 r
.34601 .31287 .35188 .31911 .36135 .31573 .3555 .30947 Metetra
0 .023 .121 r
.3555 .30947 .36135 .31573 .37085 .31235 .36502 .30606 Metetra
0 .023 .121 r
.36502 .30606 .37085 .31235 .38039 .30895 .37458 .30264 Metetra
0 .023 .121 r
.37458 .30264 .38039 .30895 .38996 .30554 .38417 .29921 Metetra
0 .023 .121 r
.38417 .29921 .38996 .30554 .39956 .30211 .3938 .29576 Metetra
0 .023 .121 r
.3938 .29576 .39956 .30211 .4092 .29868 .40346 .29231 Metetra
0 .023 .121 r
.40346 .29231 .4092 .29868 .41887 .29523 .41315 .28884 Metetra
0 .023 .121 r
.41315 .28884 .41887 .29523 .42858 .29177 .42288 .28535 Metetra
0 .023 .121 r
.42288 .28535 .42858 .29177 .43832 .2883 .43264 .28188 Metetra
0 .023 .122 r
.43264 .28188 .43832 .2883 .4481 .28482 .44244 .2784 Metetra
0 .024 .122 r
.44244 .2784 .4481 .28482 .45791 .2814 .45227 .27524 Metetra
0 .024 .122 r
.45227 .27524 .45791 .2814 .46776 .27789 .46215 .27171 Metetra
0 .024 .122 r
.46215 .27171 .46776 .27789 .47765 .27429 .47206 .26779 Metetra
0 .023 .122 r
.47206 .26779 .47765 .27429 .48757 .27075 .48201 .26421 Metetra
0 .023 .121 r
.48201 .26421 .48757 .27075 .49753 .2672 .49199 .26061 Metetra
0 .023 .121 r
.49199 .26061 .49753 .2672 .50752 .26363 .502 .25703 Metetra
0 .023 .121 r
.502 .25703 .50752 .26363 .51755 .26006 .51206 .25343 Metetra
0 .023 .121 r
.51206 .25343 .51755 .26006 .52762 .25647 .52215 .24981 Metetra
0 .023 .121 r
.52215 .24981 .52762 .25647 .53772 .25287 .53228 .24619 Metetra
0 .023 .121 r
.53228 .24619 .53772 .25287 .54786 .24925 .54244 .24255 Metetra
0 .023 .121 r
.54244 .24255 .54786 .24925 .55804 .24563 .55264 .2389 Metetra
0 .023 .121 r
.55264 .2389 .55804 .24563 .56826 .24199 .56288 .23523 Metetra
0 .023 .121 r
.56288 .23523 .56826 .24199 .57851 .23833 .57316 .23155 Metetra
0 .023 .121 r
.57316 .23155 .57851 .23833 .5888 .23466 .58348 .22786 Metetra
0 .023 .121 r
.58348 .22786 .5888 .23466 .59913 .23098 .59384 .22415 Metetra
0 .023 .121 r
.59384 .22415 .59913 .23098 .6095 .22729 .60423 .22043 Metetra
0 .023 .121 r
.60423 .22043 .6095 .22729 .61991 .22358 .61466 .21669 Metetra
0 .023 .121 r
.61466 .21669 .61991 .22358 .63035 .21985 .62513 .21294 Metetra
0 .023 .121 r
.62513 .21294 .63035 .21985 .64084 .21612 .63565 .20918 Metetra
0 .023 .121 r
.63565 .20918 .64084 .21612 .65136 .21237 .6462 .2054 Metetra
0 .023 .121 r
.6462 .2054 .65136 .21237 .66192 .2086 .65679 .20161 Metetra
0 .023 .121 r
.65679 .20161 .66192 .2086 .67253 .20482 .66742 .19781 Metetra
0 .023 .121 r
.66742 .19781 .67253 .20482 .68317 .20103 .67809 .19399 Metetra
0 .023 .121 r
.67809 .19399 .68317 .20103 .69385 .19722 .6888 .19015 Metetra
0 .023 .121 r
.6888 .19015 .69385 .19722 .70458 .1934 .69955 .1863 Metetra
0 .023 .121 r
.69955 .1863 .70458 .1934 .71534 .18956 .71034 .18244 Metetra
0 .023 .121 r
.71034 .18244 .71534 .18956 .72615 .18571 .72118 .17856 Metetra
0 .023 .121 r
.72118 .17856 .72615 .18571 .73699 .18184 .73205 .17467 Metetra
0 .023 .121 r
.73205 .17467 .73699 .18184 .74788 .17796 .74297 .17076 Metetra
0 .023 .121 r
.74297 .17076 .74788 .17796 .75881 .17407 .75393 .16684 Metetra
0 .023 .121 r
.75393 .16684 .75881 .17407 .76978 .17016 .76493 .1629 Metetra
0 .023 .121 r
.76493 .1629 .76978 .17016 .7808 .16623 .77597 .15894 Metetra
0 .023 .121 r
.77597 .15894 .7808 .16623 .79185 .16229 .78706 .15498 Metetra
0 .023 .121 r
.1568 .3725 .16309 .37835 .17193 .37519 .16566 .36931 Metetra
0 .023 .121 r
.16566 .36931 .17193 .37519 .18081 .37201 .17456 .36611 Metetra
0 .023 .121 r
.17456 .36611 .18081 .37201 .18972 .36882 .18348 .3629 Metetra
0 .023 .121 r
.18348 .3629 .18972 .36882 .19866 .36562 .19244 .35968 Metetra
0 .023 .121 r
.19244 .35968 .19866 .36562 .20763 .36241 .20143 .35645 Metetra
0 .023 .121 r
.20143 .35645 .20763 .36241 .21663 .35918 .21045 .35321 Metetra
0 .023 .121 r
.21045 .35321 .21663 .35918 .22566 .35595 .2195 .34995 Metetra
0 .023 .121 r
.2195 .34995 .22566 .35595 .23473 .35271 .22858 .34669 Metetra
0 .023 .121 r
.22858 .34669 .23473 .35271 .24382 .34945 .2377 .34341 Metetra
0 .023 .121 r
.2377 .34341 .24382 .34945 .25295 .34618 .24684 .34012 Metetra
0 .023 .121 r
.24684 .34012 .25295 .34618 .26211 .3429 .25602 .33682 Metetra
0 .023 .121 r
.25602 .33682 .26211 .3429 .2713 .33961 .26523 .33351 Metetra
0 .023 .121 r
.26523 .33351 .2713 .33961 .28052 .33631 .27447 .33018 Metetra
0 .023 .121 r
.27447 .33018 .28052 .33631 .28978 .333 .28375 .32685 Metetra
0 .023 .121 r
.28375 .32685 .28978 .333 .29907 .32967 .29306 .3235 Metetra
0 .023 .121 r
.29306 .3235 .29907 .32967 .30839 .32633 .3024 .32014 Metetra
0 .023 .121 r
.3024 .32014 .30839 .32633 .31775 .32299 .31178 .31677 Metetra
0 .023 .121 r
.31178 .31677 .31775 .32299 .32713 .31962 .32118 .31339 Metetra
0 .023 .121 r
.32118 .31339 .32713 .31962 .33656 .31625 .33063 .30999 Metetra
0 .023 .121 r
.33063 .30999 .33656 .31625 .34601 .31287 .3401 .30659 Metetra
0 .023 .121 r
.3401 .30659 .34601 .31287 .3555 .30947 .34961 .30317 Metetra
0 .023 .121 r
.34961 .30317 .3555 .30947 .36502 .30606 .35915 .29974 Metetra
0 .023 .121 r
.35915 .29974 .36502 .30606 .37458 .30264 .36873 .29629 Metetra
0 .023 .121 r
.36873 .29629 .37458 .30264 .38417 .29921 .37834 .29284 Metetra
0 .023 .121 r
.37834 .29284 .38417 .29921 .3938 .29576 .38799 .28937 Metetra
0 .023 .121 r
.38799 .28937 .3938 .29576 .40346 .29231 .39767 .28589 Metetra
0 .023 .121 r
.39767 .28589 .40346 .29231 .41315 .28884 .40739 .28239 Metetra
0 .023 .121 r
.40739 .28239 .41315 .28884 .42288 .28535 .41714 .27889 Metetra
0 .023 .121 r
.41714 .27889 .42288 .28535 .43264 .28188 .42693 .27537 Metetra
0 .023 .122 r
.42693 .27537 .43264 .28188 .44244 .2784 .43675 .27185 Metetra
0 .024 .122 r
.43675 .27185 .44244 .2784 .45227 .27524 .44661 .26839 Metetra
0 .024 .123 r
.44661 .26839 .45227 .27524 .46215 .27171 .4565 .26483 Metetra
0 .024 .122 r
.4565 .26483 .46215 .27171 .47206 .26779 .46644 .26117 Metetra
0 .023 .122 r
.46644 .26117 .47206 .26779 .48201 .26421 .4764 .25758 Metetra
0 .023 .121 r
.4764 .25758 .48201 .26421 .49199 .26061 .48641 .25398 Metetra
0 .023 .121 r
.48641 .25398 .49199 .26061 .502 .25703 .49645 .25037 Metetra
0 .023 .121 r
.49645 .25037 .502 .25703 .51206 .25343 .50653 .24675 Metetra
0 .023 .121 r
.50653 .24675 .51206 .25343 .52215 .24981 .51664 .24311 Metetra
0 .023 .121 r
.51664 .24311 .52215 .24981 .53228 .24619 .52679 .23946 Metetra
0 .023 .121 r
.52679 .23946 .53228 .24619 .54244 .24255 .53698 .23579 Metetra
0 .023 .121 r
.53698 .23579 .54244 .24255 .55264 .2389 .54721 .23212 Metetra
0 .023 .121 r
.54721 .23212 .55264 .2389 .56288 .23523 .55748 .22842 Metetra
0 .023 .121 r
.55748 .22842 .56288 .23523 .57316 .23155 .56778 .22472 Metetra
0 .023 .121 r
.56778 .22472 .57316 .23155 .58348 .22786 .57812 .221 Metetra
0 .023 .121 r
.57812 .221 .58348 .22786 .59384 .22415 .5885 .21727 Metetra
0 .023 .121 r
.5885 .21727 .59384 .22415 .60423 .22043 .59892 .21352 Metetra
0 .023 .121 r
.59892 .21352 .60423 .22043 .61466 .21669 .60938 .20976 Metetra
0 .023 .121 r
.60938 .20976 .61466 .21669 .62513 .21294 .61988 .20599 Metetra
0 .023 .121 r
.61988 .20599 .62513 .21294 .63565 .20918 .63042 .2022 Metetra
0 .023 .121 r
.63042 .2022 .63565 .20918 .6462 .2054 .641 .19839 Metetra
0 .023 .121 r
.641 .19839 .6462 .2054 .65679 .20161 .65162 .19457 Metetra
0 .023 .121 r
.65162 .19457 .65679 .20161 .66742 .19781 .66227 .19074 Metetra
0 .023 .121 r
.66227 .19074 .66742 .19781 .67809 .19399 .67297 .1869 Metetra
0 .023 .121 r
.67297 .1869 .67809 .19399 .6888 .19015 .68371 .18303 Metetra
0 .023 .121 r
.68371 .18303 .6888 .19015 .69955 .1863 .69449 .17916 Metetra
0 .023 .121 r
.69449 .17916 .69955 .1863 .71034 .18244 .70531 .17527 Metetra
0 .023 .121 r
.70531 .17527 .71034 .18244 .72118 .17856 .71617 .17136 Metetra
0 .023 .121 r
.71617 .17136 .72118 .17856 .73205 .17467 .72708 .16744 Metetra
0 .023 .121 r
.72708 .16744 .73205 .17467 .74297 .17076 .73802 .1635 Metetra
0 .023 .121 r
.73802 .1635 .74297 .17076 .75393 .16684 .74901 .15955 Metetra
0 .023 .121 r
.74901 .15955 .75393 .16684 .76493 .1629 .76004 .15559 Metetra
0 .023 .121 r
.76004 .15559 .76493 .1629 .77597 .15894 .77112 .15161 Metetra
0 .023 .121 r
.77112 .15161 .77597 .15894 .78706 .15498 .78223 .14761 Metetra
0 .023 .121 r
.15047 .3666 .1568 .3725 .16566 .36931 .15935 .3634 Metetra
0 .023 .121 r
.15935 .3634 .16566 .36931 .17456 .36611 .16826 .36018 Metetra
0 .023 .121 r
.16826 .36018 .17456 .36611 .18348 .3629 .17721 .35695 Metetra
0 .023 .121 r
.17721 .35695 .18348 .3629 .19244 .35968 .18618 .35371 Metetra
0 .023 .121 r
.18618 .35371 .19244 .35968 .20143 .35645 .19519 .35045 Metetra
0 .023 .121 r
.19519 .35045 .20143 .35645 .21045 .35321 .20423 .34719 Metetra
0 .023 .121 r
.20423 .34719 .21045 .35321 .2195 .34995 .21329 .34391 Metetra
0 .023 .121 r
.21329 .34391 .2195 .34995 .22858 .34669 .2224 .34063 Metetra
0 .023 .121 r
.2224 .34063 .22858 .34669 .2377 .34341 .23153 .33733 Metetra
0 .023 .121 r
.23153 .33733 .2377 .34341 .24684 .34012 .24069 .33402 Metetra
0 .023 .121 r
.24069 .33402 .24684 .34012 .25602 .33682 .24989 .3307 Metetra
0 .023 .121 r
.24989 .3307 .25602 .33682 .26523 .33351 .25912 .32736 Metetra
0 .023 .121 r
.25912 .32736 .26523 .33351 .27447 .33018 .26838 .32402 Metetra
0 .023 .121 r
.26838 .32402 .27447 .33018 .28375 .32685 .27768 .32066 Metetra
0 .023 .121 r
.27768 .32066 .28375 .32685 .29306 .3235 .28701 .31729 Metetra
0 .023 .121 r
.28701 .31729 .29306 .3235 .3024 .32014 .29637 .31391 Metetra
0 .023 .121 r
.29637 .31391 .3024 .32014 .31178 .31677 .30576 .31052 Metetra
0 .023 .121 r
.30576 .31052 .31178 .31677 .32118 .31339 .31519 .30711 Metetra
0 .023 .121 r
.31519 .30711 .32118 .31339 .33063 .30999 .32466 .30369 Metetra
0 .023 .121 r
.32466 .30369 .33063 .30999 .3401 .30659 .33415 .30026 Metetra
0 .023 .121 r
.33415 .30026 .3401 .30659 .34961 .30317 .34368 .29682 Metetra
0 .023 .121 r
.34368 .29682 .34961 .30317 .35915 .29974 .35325 .29337 Metetra
0 .023 .121 r
.35325 .29337 .35915 .29974 .36873 .29629 .36285 .2899 Metetra
0 .023 .121 r
.36285 .2899 .36873 .29629 .37834 .29284 .37248 .28642 Metetra
0 .023 .121 r
.37248 .28642 .37834 .29284 .38799 .28937 .38215 .28293 Metetra
0 .023 .121 r
.38215 .28293 .38799 .28937 .39767 .28589 .39185 .27943 Metetra
0 .023 .121 r
.39185 .27943 .39767 .28589 .40739 .28239 .40159 .27591 Metetra
0 .023 .121 r
.40159 .27591 .40739 .28239 .41714 .27889 .41136 .27238 Metetra
0 .023 .121 r
.41136 .27238 .41714 .27889 .42693 .27537 .42117 .26885 Metetra
0 .023 .121 r
.42117 .26885 .42693 .27537 .43675 .27185 .43102 .2653 Metetra
0 .024 .122 r
.43102 .2653 .43675 .27185 .44661 .26839 .4409 .26189 Metetra
0 .024 .122 r
.4409 .26189 .44661 .26839 .4565 .26483 .45081 .2583 Metetra
0 .024 .122 r
.45081 .2583 .4565 .26483 .46644 .26117 .46077 .25455 Metetra
0 .023 .121 r
.46077 .25455 .46644 .26117 .4764 .25758 .47076 .25094 Metetra
0 .023 .121 r
.47076 .25094 .4764 .25758 .48641 .25398 .48079 .2473 Metetra
0 .023 .121 r
.48079 .2473 .48641 .25398 .49645 .25037 .49086 .24367 Metetra
0 .023 .121 r
.49086 .24367 .49645 .25037 .50653 .24675 .50096 .24002 Metetra
0 .023 .121 r
.50096 .24002 .50653 .24675 .51664 .24311 .5111 .23636 Metetra
0 .023 .121 r
.5111 .23636 .51664 .24311 .52679 .23946 .52127 .23268 Metetra
0 .023 .121 r
.52127 .23268 .52679 .23946 .53698 .23579 .53149 .22899 Metetra
0 .023 .121 r
.53149 .22899 .53698 .23579 .54721 .23212 .54174 .22529 Metetra
0 .023 .121 r
.54174 .22529 .54721 .23212 .55748 .22842 .55203 .22157 Metetra
0 .023 .121 r
.55203 .22157 .55748 .22842 .56778 .22472 .56236 .21784 Metetra
0 .023 .121 r
.56236 .21784 .56778 .22472 .57812 .221 .57273 .2141 Metetra
0 .023 .121 r
.57273 .2141 .57812 .221 .5885 .21727 .58314 .21034 Metetra
0 .023 .121 r
.58314 .21034 .5885 .21727 .59892 .21352 .59358 .20657 Metetra
0 .023 .121 r
.59358 .20657 .59892 .21352 .60938 .20976 .60407 .20278 Metetra
0 .023 .121 r
.60407 .20278 .60938 .20976 .61988 .20599 .61459 .19898 Metetra
0 .023 .121 r
.61459 .19898 .61988 .20599 .63042 .2022 .62516 .19516 Metetra
0 .023 .121 r
.62516 .19516 .63042 .2022 .641 .19839 .63576 .19133 Metetra
0 .023 .121 r
.63576 .19133 .641 .19839 .65162 .19457 .64641 .18749 Metetra
0 .023 .121 r
.64641 .18749 .65162 .19457 .66227 .19074 .65709 .18363 Metetra
0 .023 .121 r
.65709 .18363 .66227 .19074 .67297 .1869 .66782 .17976 Metetra
0 .023 .121 r
.66782 .17976 .67297 .1869 .68371 .18303 .67859 .17587 Metetra
0 .023 .121 r
.67859 .17587 .68371 .18303 .69449 .17916 .68939 .17196 Metetra
0 .023 .121 r
.68939 .17196 .69449 .17916 .70531 .17527 .70024 .16804 Metetra
0 .023 .121 r
.70024 .16804 .70531 .17527 .71617 .17136 .71113 .16411 Metetra
0 .023 .121 r
.71113 .16411 .71617 .17136 .72708 .16744 .72207 .16016 Metetra
0 .023 .121 r
.72207 .16016 .72708 .16744 .73802 .1635 .73304 .1562 Metetra
0 .023 .121 r
.73304 .1562 .73802 .1635 .74901 .15955 .74406 .15222 Metetra
0 .023 .121 r
.74406 .15222 .74901 .15955 .76004 .15559 .75512 .14822 Metetra
0 .023 .121 r
.75512 .14822 .76004 .15559 .77112 .15161 .76622 .14421 Metetra
0 .023 .121 r
.76622 .14421 .77112 .15161 .78223 .14761 .77737 .14019 Metetra
0 .023 .121 r
.1441 .36067 .15047 .3666 .15935 .3634 .153 .35744 Metetra
0 .023 .121 r
.153 .35744 .15935 .3634 .16826 .36018 .16193 .3542 Metetra
0 .023 .121 r
.16193 .3542 .16826 .36018 .17721 .35695 .17089 .35095 Metetra
0 .023 .121 r
.17089 .35095 .17721 .35695 .18618 .35371 .17988 .34769 Metetra
0 .023 .121 r
.17988 .34769 .18618 .35371 .19519 .35045 .18891 .34442 Metetra
0 .023 .121 r
.18891 .34442 .19519 .35045 .20423 .34719 .19796 .34113 Metetra
0 .023 .121 r
.19796 .34113 .20423 .34719 .21329 .34391 .20705 .33784 Metetra
0 .023 .121 r
.20705 .33784 .21329 .34391 .2224 .34063 .21617 .33453 Metetra
0 .023 .121 r
.21617 .33453 .2224 .34063 .23153 .33733 .22532 .33121 Metetra
0 .023 .121 r
.22532 .33121 .23153 .33733 .24069 .33402 .23451 .32788 Metetra
0 .023 .121 r
.23451 .32788 .24069 .33402 .24989 .3307 .24372 .32453 Metetra
0 .023 .121 r
.24372 .32453 .24989 .3307 .25912 .32736 .25297 .32118 Metetra
0 .023 .121 r
.25297 .32118 .25912 .32736 .26838 .32402 .26225 .31781 Metetra
0 .023 .121 r
.26225 .31781 .26838 .32402 .27768 .32066 .27157 .31443 Metetra
0 .023 .121 r
.27157 .31443 .27768 .32066 .28701 .31729 .28092 .31104 Metetra
0 .023 .121 r
.28092 .31104 .28701 .31729 .29637 .31391 .2903 .30764 Metetra
0 .023 .121 r
.2903 .30764 .29637 .31391 .30576 .31052 .29971 .30422 Metetra
0 .023 .121 r
.29971 .30422 .30576 .31052 .31519 .30711 .30916 .30079 Metetra
0 .023 .121 r
.30916 .30079 .31519 .30711 .32466 .30369 .31865 .29735 Metetra
0 .023 .121 r
.31865 .29735 .32466 .30369 .33415 .30026 .32816 .2939 Metetra
0 .023 .121 r
.32816 .2939 .33415 .30026 .34368 .29682 .33771 .29044 Metetra
0 .023 .121 r
.33771 .29044 .34368 .29682 .35325 .29337 .3473 .28696 Metetra
0 .023 .121 r
.3473 .28696 .35325 .29337 .36285 .2899 .35692 .28347 Metetra
0 .023 .121 r
.35692 .28347 .36285 .2899 .37248 .28642 .36657 .27997 Metetra
0 .023 .121 r
.36657 .27997 .37248 .28642 .38215 .28293 .37627 .27645 Metetra
0 .023 .121 r
.37627 .27645 .38215 .28293 .39185 .27943 .38599 .27292 Metetra
0 .023 .121 r
.38599 .27292 .39185 .27943 .40159 .27591 .39575 .26938 Metetra
0 .023 .121 r
.39575 .26938 .40159 .27591 .41136 .27238 .40555 .26583 Metetra
0 .023 .121 r
.40555 .26583 .41136 .27238 .42117 .26885 .41538 .26227 Metetra
0 .023 .122 r
.41538 .26227 .42117 .26885 .43102 .2653 .42525 .2587 Metetra
0 .024 .122 r
.42525 .2587 .43102 .2653 .4409 .26189 .43515 .25528 Metetra
0 .024 .122 r
.43515 .25528 .4409 .26189 .45081 .2583 .44509 .25167 Metetra
0 .024 .122 r
.44509 .25167 .45081 .2583 .46077 .25455 .45507 .24788 Metetra
0 .023 .122 r
.45507 .24788 .46077 .25455 .47076 .25094 .46509 .24424 Metetra
0 .023 .121 r
.46509 .24424 .47076 .25094 .48079 .2473 .47514 .24058 Metetra
0 .023 .121 r
.47514 .24058 .48079 .2473 .49086 .24367 .48523 .23692 Metetra
0 .023 .121 r
.48523 .23692 .49086 .24367 .50096 .24002 .49535 .23325 Metetra
0 .023 .121 r
.49535 .23325 .50096 .24002 .5111 .23636 .50551 .22956 Metetra
0 .023 .121 r
.50551 .22956 .5111 .23636 .52127 .23268 .51572 .22586 Metetra
0 .023 .121 r
.51572 .22586 .52127 .23268 .53149 .22899 .52596 .22215 Metetra
0 .023 .121 r
.52596 .22215 .53149 .22899 .54174 .22529 .53623 .21842 Metetra
0 .023 .121 r
.53623 .21842 .54174 .22529 .55203 .22157 .54655 .21468 Metetra
0 .023 .121 r
.54655 .21468 .55203 .22157 .56236 .21784 .5569 .21092 Metetra
0 .023 .121 r
.5569 .21092 .56236 .21784 .57273 .2141 .5673 .20715 Metetra
0 .023 .121 r
.5673 .20715 .57273 .2141 .58314 .21034 .57773 .20336 Metetra
0 .023 .121 r
.57773 .20336 .58314 .21034 .59358 .20657 .5882 .19956 Metetra
0 .023 .121 r
.5882 .19956 .59358 .20657 .60407 .20278 .59871 .19575 Metetra
0 .023 .121 r
.59871 .19575 .60407 .20278 .61459 .19898 .60927 .19192 Metetra
0 .023 .121 r
.60927 .19192 .61459 .19898 .62516 .19516 .61986 .18808 Metetra
0 .023 .121 r
.61986 .18808 .62516 .19516 .63576 .19133 .63049 .18422 Metetra
0 .023 .121 r
.63049 .18422 .63576 .19133 .64641 .18749 .64116 .18035 Metetra
0 .023 .121 r
.64116 .18035 .64641 .18749 .65709 .18363 .65188 .17647 Metetra
0 .023 .121 r
.65188 .17647 .65709 .18363 .66782 .17976 .66263 .17256 Metetra
0 .023 .121 r
.66263 .17256 .66782 .17976 .67859 .17587 .67342 .16865 Metetra
0 .023 .121 r
.67342 .16865 .67859 .17587 .68939 .17196 .68426 .16472 Metetra
0 .023 .121 r
.68426 .16472 .68939 .17196 .70024 .16804 .69514 .16077 Metetra
0 .023 .121 r
.69514 .16077 .70024 .16804 .71113 .16411 .70606 .15681 Metetra
0 .023 .121 r
.70606 .15681 .71113 .16411 .72207 .16016 .71702 .15283 Metetra
0 .023 .121 r
.71702 .15283 .72207 .16016 .73304 .1562 .72803 .14884 Metetra
0 .023 .121 r
.72803 .14884 .73304 .1562 .74406 .15222 .73907 .14483 Metetra
0 .023 .121 r
.73907 .14483 .74406 .15222 .75512 .14822 .75016 .14081 Metetra
0 .023 .121 r
.75016 .14081 .75512 .14822 .76622 .14421 .7613 .13677 Metetra
0 .023 .121 r
.7613 .13677 .76622 .14421 .77737 .14019 .77247 .13272 Metetra
0 .023 .121 r
.13769 .3547 .1441 .36067 .153 .35744 .14661 .35145 Metetra
0 .023 .121 r
.14661 .35145 .153 .35744 .16193 .3542 .15555 .34819 Metetra
0 .023 .121 r
.15555 .34819 .16193 .3542 .17089 .35095 .16453 .34492 Metetra
0 .023 .121 r
.16453 .34492 .17089 .35095 .17988 .34769 .17354 .34164 Metetra
0 .023 .121 r
.17354 .34164 .17988 .34769 .18891 .34442 .18259 .33834 Metetra
0 .023 .121 r
.18259 .33834 .18891 .34442 .19796 .34113 .19166 .33504 Metetra
0 .023 .121 r
.19166 .33504 .19796 .34113 .20705 .33784 .20077 .33172 Metetra
0 .023 .121 r
.20077 .33172 .20705 .33784 .21617 .33453 .2099 .32839 Metetra
0 .023 .121 r
.2099 .32839 .21617 .33453 .22532 .33121 .21907 .32505 Metetra
0 .023 .121 r
.21907 .32505 .22532 .33121 .23451 .32788 .22828 .32169 Metetra
0 .023 .121 r
.22828 .32169 .23451 .32788 .24372 .32453 .23751 .31833 Metetra
0 .023 .121 r
.23751 .31833 .24372 .32453 .25297 .32118 .24678 .31495 Metetra
0 .023 .121 r
.24678 .31495 .25297 .32118 .26225 .31781 .25608 .31156 Metetra
0 .023 .121 r
.25608 .31156 .26225 .31781 .27157 .31443 .26542 .30816 Metetra
0 .023 .121 r
.26542 .30816 .27157 .31443 .28092 .31104 .27479 .30475 Metetra
0 .023 .121 r
.27479 .30475 .28092 .31104 .2903 .30764 .28419 .30132 Metetra
0 .023 .121 r
.28419 .30132 .2903 .30764 .29971 .30422 .29362 .29788 Metetra
0 .023 .121 r
.29362 .29788 .29971 .30422 .30916 .30079 .30309 .29443 Metetra
0 .023 .121 r
.30309 .29443 .30916 .30079 .31865 .29735 .3126 .29097 Metetra
0 .023 .121 r
.3126 .29097 .31865 .29735 .32816 .2939 .32213 .28749 Metetra
0 .023 .121 r
.32213 .28749 .32816 .2939 .33771 .29044 .33171 .28401 Metetra
0 .023 .121 r
.33171 .28401 .33771 .29044 .3473 .28696 .34131 .2805 Metetra
0 .023 .121 r
.34131 .2805 .3473 .28696 .35692 .28347 .35095 .27699 Metetra
0 .023 .121 r
.35095 .27699 .35692 .28347 .36657 .27997 .36063 .27347 Metetra
0 .023 .121 r
.36063 .27347 .36657 .27997 .37627 .27645 .37034 .26993 Metetra
0 .023 .121 r
.37034 .26993 .37627 .27645 .38599 .27292 .38009 .26637 Metetra
0 .023 .121 r
.38009 .26637 .38599 .27292 .39575 .26938 .38987 .26281 Metetra
0 .023 .121 r
.38987 .26281 .39575 .26938 .40555 .26583 .39969 .25923 Metetra
0 .023 .121 r
.39969 .25923 .40555 .26583 .41538 .26227 .40955 .25564 Metetra
0 .023 .121 r
.40955 .25564 .41538 .26227 .42525 .2587 .41944 .25204 Metetra
0 .024 .122 r
.41944 .25204 .42525 .2587 .43515 .25528 .42936 .24845 Metetra
0 .024 .122 r
.42936 .24845 .43515 .25528 .44509 .25167 .43933 .24482 Metetra
0 .024 .122 r
.43933 .24482 .44509 .25167 .45507 .24788 .44933 .24115 Metetra
0 .023 .121 r
.44933 .24115 .45507 .24788 .46509 .24424 .45937 .23749 Metetra
0 .023 .121 r
.45937 .23749 .46509 .24424 .47514 .24058 .46944 .23381 Metetra
0 .023 .121 r
.46944 .23381 .47514 .24058 .48523 .23692 .47956 .23013 Metetra
0 .023 .121 r
.47956 .23013 .48523 .23692 .49535 .23325 .48971 .22643 Metetra
0 .023 .121 r
.48971 .22643 .49535 .23325 .50551 .22956 .49989 .22272 Metetra
0 .023 .121 r
.49989 .22272 .50551 .22956 .51572 .22586 .51012 .21899 Metetra
0 .023 .121 r
.51012 .21899 .51572 .22586 .52596 .22215 .52038 .21525 Metetra
0 .023 .121 r
.52038 .21525 .52596 .22215 .53623 .21842 .53069 .2115 Metetra
0 .023 .121 r
.53069 .2115 .53623 .21842 .54655 .21468 .54103 .20773 Metetra
0 .023 .121 r
.54103 .20773 .54655 .21468 .5569 .21092 .55141 .20395 Metetra
0 .023 .121 r
.55141 .20395 .5569 .21092 .5673 .20715 .56183 .20015 Metetra
0 .023 .121 r
.56183 .20015 .5673 .20715 .57773 .20336 .57229 .19634 Metetra
0 .023 .121 r
.57229 .19634 .57773 .20336 .5882 .19956 .58279 .19251 Metetra
0 .023 .121 r
.58279 .19251 .5882 .19956 .59871 .19575 .59332 .18867 Metetra
0 .023 .121 r
.59332 .18867 .59871 .19575 .60927 .19192 .6039 .18482 Metetra
0 .023 .121 r
.6039 .18482 .60927 .19192 .61986 .18808 .61452 .18095 Metetra
0 .023 .121 r
.61452 .18095 .61986 .18808 .63049 .18422 .62518 .17706 Metetra
0 .023 .121 r
.62518 .17706 .63049 .18422 .64116 .18035 .63588 .17317 Metetra
0 .023 .121 r
.63588 .17317 .64116 .18035 .65188 .17647 .64662 .16925 Metetra
0 .023 .121 r
.64662 .16925 .65188 .17647 .66263 .17256 .6574 .16532 Metetra
0 .023 .121 r
.6574 .16532 .66263 .17256 .67342 .16865 .66823 .16138 Metetra
0 .023 .121 r
.66823 .16138 .67342 .16865 .68426 .16472 .67909 .15742 Metetra
0 .023 .121 r
.67909 .15742 .68426 .16472 .69514 .16077 .69 .15345 Metetra
0 .023 .121 r
.69 .15345 .69514 .16077 .70606 .15681 .70095 .14946 Metetra
0 .023 .121 r
.70095 .14946 .70606 .15681 .71702 .15283 .71194 .14545 Metetra
0 .023 .121 r
.71194 .14545 .71702 .15283 .72803 .14884 .72297 .14143 Metetra
0 .023 .121 r
.72297 .14143 .72803 .14884 .73907 .14483 .73405 .13739 Metetra
0 .023 .121 r
.73405 .13739 .73907 .14483 .75016 .14081 .74517 .13334 Metetra
0 .023 .121 r
.74517 .13334 .75016 .14081 .7613 .13677 .75634 .12927 Metetra
0 .023 .121 r
.75634 .12927 .7613 .13677 .77247 .13272 .76754 .12519 Metetra
0 .023 .121 r
.13124 .3487 .13769 .3547 .14661 .35145 .14017 .34543 Metetra
0 .023 .121 r
.14017 .34543 .14661 .35145 .15555 .34819 .14914 .34214 Metetra
0 .023 .121 r
.14914 .34214 .15555 .34819 .16453 .34492 .15813 .33885 Metetra
0 .023 .121 r
.15813 .33885 .16453 .34492 .17354 .34164 .16716 .33555 Metetra
0 .023 .121 r
.16716 .33555 .17354 .34164 .18259 .33834 .17622 .33223 Metetra
0 .023 .121 r
.17622 .33223 .18259 .33834 .19166 .33504 .18532 .3289 Metetra
0 .023 .121 r
.18532 .3289 .19166 .33504 .20077 .33172 .19444 .32556 Metetra
0 .023 .121 r
.19444 .32556 .20077 .33172 .2099 .32839 .2036 .32221 Metetra
0 .023 .121 r
.2036 .32221 .2099 .32839 .21907 .32505 .21279 .31885 Metetra
0 .023 .121 r
.21279 .31885 .21907 .32505 .22828 .32169 .22201 .31547 Metetra
0 .023 .121 r
.22201 .31547 .22828 .32169 .23751 .31833 .23126 .31208 Metetra
0 .023 .121 r
.23126 .31208 .23751 .31833 .24678 .31495 .24055 .30868 Metetra
0 .023 .121 r
.24055 .30868 .24678 .31495 .25608 .31156 .24987 .30527 Metetra
0 .023 .121 r
.24987 .30527 .25608 .31156 .26542 .30816 .25923 .30185 Metetra
0 .023 .121 r
.25923 .30185 .26542 .30816 .27479 .30475 .26861 .29841 Metetra
0 .023 .121 r
.26861 .29841 .27479 .30475 .28419 .30132 .27804 .29496 Metetra
0 .023 .121 r
.27804 .29496 .28419 .30132 .29362 .29788 .28749 .2915 Metetra
0 .023 .121 r
.28749 .2915 .29362 .29788 .30309 .29443 .29698 .28803 Metetra
0 .023 .121 r
.29698 .28803 .30309 .29443 .3126 .29097 .30651 .28454 Metetra
0 .023 .121 r
.30651 .28454 .3126 .29097 .32213 .28749 .31606 .28104 Metetra
0 .023 .121 r
.31606 .28104 .32213 .28749 .33171 .28401 .32566 .27753 Metetra
0 .023 .121 r
.32566 .27753 .33171 .28401 .34131 .2805 .33529 .27401 Metetra
0 .023 .121 r
.33529 .27401 .34131 .2805 .35095 .27699 .34495 .27047 Metetra
0 .023 .121 r
.34495 .27047 .35095 .27699 .36063 .27347 .35465 .26692 Metetra
0 .023 .121 r
.35465 .26692 .36063 .27347 .37034 .26993 .36438 .26336 Metetra
0 .023 .121 r
.36438 .26336 .37034 .26993 .38009 .26637 .37415 .25978 Metetra
0 .023 .121 r
.37415 .25978 .38009 .26637 .38987 .26281 .38396 .2562 Metetra
0 .023 .121 r
.38396 .2562 .38987 .26281 .39969 .25923 .3938 .25259 Metetra
0 .023 .121 r
.3938 .25259 .39969 .25923 .40955 .25564 .40367 .24899 Metetra
0 .023 .121 r
.40367 .24899 .40955 .25564 .41944 .25204 .41359 .24537 Metetra
0 .024 .122 r
.41359 .24537 .41944 .25204 .42936 .24845 .42353 .2419 Metetra
0 .024 .122 r
.42353 .2419 .42936 .24845 .43933 .24482 .43352 .23824 Metetra
0 .024 .122 r
.43352 .23824 .43933 .24482 .44933 .24115 .44355 .2344 Metetra
0 .023 .121 r
.44355 .2344 .44933 .24115 .45937 .23749 .45361 .23071 Metetra
0 .023 .121 r
.45361 .23071 .45937 .23749 .46944 .23381 .46371 .227 Metetra
0 .023 .121 r
.46371 .227 .46944 .23381 .47956 .23013 .47385 .22329 Metetra
0 .023 .121 r
.47385 .22329 .47956 .23013 .48971 .22643 .48402 .21957 Metetra
0 .023 .121 r
.48402 .21957 .48971 .22643 .49989 .22272 .49423 .21583 Metetra
0 .023 .121 r
.49423 .21583 .49989 .22272 .51012 .21899 .50449 .21208 Metetra
0 .023 .121 r
.50449 .21208 .51012 .21899 .52038 .21525 .51477 .20831 Metetra
0 .023 .121 r
.51477 .20831 .52038 .21525 .53069 .2115 .5251 .20453 Metetra
0 .023 .121 r
.5251 .20453 .53069 .2115 .54103 .20773 .53547 .20074 Metetra
0 .023 .121 r
.53547 .20074 .54103 .20773 .55141 .20395 .54588 .19693 Metetra
0 .023 .121 r
.54588 .19693 .55141 .20395 .56183 .20015 .55632 .1931 Metetra
0 .023 .121 r
.55632 .1931 .56183 .20015 .57229 .19634 .56681 .18926 Metetra
0 .023 .121 r
.56681 .18926 .57229 .19634 .58279 .19251 .57733 .18541 Metetra
0 .023 .121 r
.57733 .18541 .58279 .19251 .59332 .18867 .5879 .18155 Metetra
0 .023 .121 r
.5879 .18155 .59332 .18867 .6039 .18482 .5985 .17766 Metetra
0 .023 .121 r
.5985 .17766 .6039 .18482 .61452 .18095 .60915 .17377 Metetra
0 .023 .121 r
.60915 .17377 .61452 .18095 .62518 .17706 .61983 .16985 Metetra
0 .023 .121 r
.61983 .16985 .62518 .17706 .63588 .17317 .63056 .16593 Metetra
0 .023 .121 r
.63056 .16593 .63588 .17317 .64662 .16925 .64133 .16199 Metetra
0 .023 .121 r
.64133 .16199 .64662 .16925 .6574 .16532 .65214 .15803 Metetra
0 .023 .121 r
.65214 .15803 .6574 .16532 .66823 .16138 .66299 .15406 Metetra
0 .023 .121 r
.66299 .15406 .66823 .16138 .67909 .15742 .67389 .15007 Metetra
0 .023 .121 r
.67389 .15007 .67909 .15742 .69 .15345 .68482 .14607 Metetra
0 .023 .121 r
.68482 .14607 .69 .15345 .70095 .14946 .6958 .14205 Metetra
0 .023 .121 r
.6958 .14205 .70095 .14946 .71194 .14545 .70682 .13801 Metetra
0 .023 .121 r
.70682 .13801 .71194 .14545 .72297 .14143 .71788 .13397 Metetra
0 .023 .121 r
.71788 .13397 .72297 .14143 .73405 .13739 .72899 .1299 Metetra
0 .023 .121 r
.72899 .1299 .73405 .13739 .74517 .13334 .74014 .12582 Metetra
0 .023 .121 r
.74014 .12582 .74517 .13334 .75634 .12927 .75134 .12172 Metetra
0 .023 .121 r
.75134 .12172 .75634 .12927 .76754 .12519 .76258 .11761 Metetra
0 .023 .121 r
.12474 .34265 .13124 .3487 .14017 .34543 .1337 .33936 Metetra
0 .023 .121 r
.1337 .33936 .14017 .34543 .14914 .34214 .14268 .33606 Metetra
0 .023 .121 r
.14268 .33606 .14914 .34214 .15813 .33885 .15169 .33274 Metetra
0 .023 .121 r
.15169 .33274 .15813 .33885 .16716 .33555 .16074 .32942 Metetra
0 .023 .121 r
.16074 .32942 .16716 .33555 .17622 .33223 .16982 .32608 Metetra
0 .023 .121 r
.16982 .32608 .17622 .33223 .18532 .3289 .17893 .32273 Metetra
0 .023 .121 r
.17893 .32273 .18532 .3289 .19444 .32556 .18807 .31937 Metetra
0 .023 .121 r
.18807 .31937 .19444 .32556 .2036 .32221 .19725 .31599 Metetra
0 .023 .121 r
.19725 .31599 .2036 .32221 .21279 .31885 .20646 .31261 Metetra
0 .023 .121 r
.20646 .31261 .21279 .31885 .22201 .31547 .2157 .30921 Metetra
0 .023 .121 r
.2157 .30921 .22201 .31547 .23126 .31208 .22497 .3058 Metetra
0 .023 .121 r
.22497 .3058 .23126 .31208 .24055 .30868 .23428 .30238 Metetra
0 .023 .121 r
.23428 .30238 .24055 .30868 .24987 .30527 .24362 .29894 Metetra
0 .023 .121 r
.24362 .29894 .24987 .30527 .25923 .30185 .25299 .29549 Metetra
0 .023 .121 r
.25299 .29549 .25923 .30185 .26861 .29841 .2624 .29204 Metetra
0 .023 .121 r
.2624 .29204 .26861 .29841 .27804 .29496 .27184 .28856 Metetra
0 .023 .121 r
.27184 .28856 .27804 .29496 .28749 .2915 .28132 .28508 Metetra
0 .023 .121 r
.28132 .28508 .28749 .2915 .29698 .28803 .29083 .28158 Metetra
0 .023 .121 r
.29083 .28158 .29698 .28803 .30651 .28454 .30038 .27807 Metetra
0 .023 .121 r
.30038 .27807 .30651 .28454 .31606 .28104 .30995 .27455 Metetra
0 .023 .121 r
.30995 .27455 .31606 .28104 .32566 .27753 .31957 .27102 Metetra
0 .023 .121 r
.31957 .27102 .32566 .27753 .33529 .27401 .32922 .26747 Metetra
0 .023 .121 r
.32922 .26747 .33529 .27401 .34495 .27047 .3389 .26391 Metetra
0 .023 .121 r
.3389 .26391 .34495 .27047 .35465 .26692 .34862 .26033 Metetra
0 .023 .121 r
.34862 .26033 .35465 .26692 .36438 .26336 .35838 .25675 Metetra
0 .023 .121 r
.35838 .25675 .36438 .26336 .37415 .25978 .36817 .25315 Metetra
0 .023 .121 r
.36817 .25315 .37415 .25978 .38396 .2562 .378 .24953 Metetra
0 .023 .121 r
.378 .24953 .38396 .2562 .3938 .25259 .38786 .24591 Metetra
0 .023 .121 r
.38786 .24591 .3938 .25259 .40367 .24899 .39776 .24227 Metetra
0 .023 .121 r
.39776 .24227 .40367 .24899 .41359 .24537 .4077 .23862 Metetra
0 .024 .122 r
.4077 .23862 .41359 .24537 .42353 .2419 .41767 .235 Metetra
0 .024 .122 r
.41767 .235 .42353 .2419 .43352 .23824 .42768 .23132 Metetra
0 .024 .122 r
.42768 .23132 .43352 .23824 .44355 .2344 .43773 .22758 Metetra
0 .023 .121 r
.43773 .22758 .44355 .2344 .45361 .23071 .44782 .22387 Metetra
0 .023 .121 r
.44782 .22387 .45361 .23071 .46371 .227 .45794 .22014 Metetra
0 .023 .121 r
.45794 .22014 .46371 .227 .47385 .22329 .4681 .21641 Metetra
0 .023 .121 r
.4681 .21641 .47385 .22329 .48402 .21957 .4783 .21265 Metetra
0 .023 .121 r
.4783 .21265 .48402 .21957 .49423 .21583 .48854 .20889 Metetra
0 .023 .121 r
.48854 .20889 .49423 .21583 .50449 .21208 .49881 .20511 Metetra
0 .023 .121 r
.49881 .20511 .50449 .21208 .51477 .20831 .50913 .20132 Metetra
0 .023 .121 r
.50913 .20132 .51477 .20831 .5251 .20453 .51948 .19751 Metetra
0 .023 .121 r
.51948 .19751 .5251 .20453 .53547 .20074 .52987 .19369 Metetra
0 .023 .121 r
.52987 .19369 .53547 .20074 .54588 .19693 .5403 .18986 Metetra
0 .023 .121 r
.5403 .18986 .54588 .19693 .55632 .1931 .55077 .18601 Metetra
0 .023 .121 r
.55077 .18601 .55632 .1931 .56681 .18926 .56129 .18214 Metetra
0 .023 .121 r
.56129 .18214 .56681 .18926 .57733 .18541 .57184 .17826 Metetra
0 .023 .121 r
.57184 .17826 .57733 .18541 .5879 .18155 .58243 .17437 Metetra
0 .023 .121 r
.58243 .17437 .5879 .18155 .5985 .17766 .59306 .17046 Metetra
0 .023 .121 r
.59306 .17046 .5985 .17766 .60915 .17377 .60373 .16653 Metetra
0 .023 .121 r
.60373 .16653 .60915 .17377 .61983 .16985 .61445 .16259 Metetra
0 .023 .121 r
.61445 .16259 .61983 .16985 .63056 .16593 .6252 .15864 Metetra
0 .023 .121 r
.6252 .15864 .63056 .16593 .64133 .16199 .636 .15467 Metetra
0 .023 .121 r
.636 .15467 .64133 .16199 .65214 .15803 .64684 .15068 Metetra
0 .023 .121 r
.64684 .15068 .65214 .15803 .66299 .15406 .65772 .14668 Metetra
0 .023 .121 r
.65772 .14668 .66299 .15406 .67389 .15007 .66864 .14267 Metetra
0 .023 .121 r
.66864 .14267 .67389 .15007 .68482 .14607 .67961 .13864 Metetra
0 .023 .121 r
.67961 .13864 .68482 .14607 .6958 .14205 .69061 .13459 Metetra
0 .023 .121 r
.69061 .13459 .6958 .14205 .70682 .13801 .70167 .13053 Metetra
0 .023 .121 r
.70167 .13053 .70682 .13801 .71788 .13397 .71276 .12645 Metetra
0 .023 .121 r
.71276 .12645 .71788 .13397 .72899 .1299 .7239 .12235 Metetra
0 .023 .121 r
.7239 .12235 .72899 .1299 .74014 .12582 .73508 .11824 Metetra
0 .023 .121 r
.73508 .11824 .74014 .12582 .75134 .12172 .7463 .11411 Metetra
0 .023 .121 r
.7463 .11411 .75134 .12172 .76258 .11761 .75757 .10997 Metetra
0 .023 .121 r
.11821 .33656 .12474 .34265 .1337 .33936 .12718 .33325 Metetra
0 .023 .121 r
.12718 .33325 .1337 .33936 .14268 .33606 .13618 .32993 Metetra
0 .023 .121 r
.13618 .32993 .14268 .33606 .15169 .33274 .14521 .32659 Metetra
0 .023 .121 r
.14521 .32659 .15169 .33274 .16074 .32942 .15428 .32324 Metetra
0 .023 .121 r
.15428 .32324 .16074 .32942 .16982 .32608 .16337 .31988 Metetra
0 .023 .121 r
.16337 .31988 .16982 .32608 .17893 .32273 .1725 .31651 Metetra
0 .023 .121 r
.1725 .31651 .17893 .32273 .18807 .31937 .18166 .31313 Metetra
0 .023 .121 r
.18166 .31313 .18807 .31937 .19725 .31599 .19086 .30973 Metetra
0 .023 .121 r
.19086 .30973 .19725 .31599 .20646 .31261 .20009 .30632 Metetra
0 .023 .121 r
.20009 .30632 .20646 .31261 .2157 .30921 .20935 .3029 Metetra
0 .023 .121 r
.20935 .3029 .2157 .30921 .22497 .3058 .21864 .29947 Metetra
0 .023 .121 r
.21864 .29947 .22497 .3058 .23428 .30238 .22797 .29603 Metetra
0 .023 .121 r
.22797 .29603 .23428 .30238 .24362 .29894 .23733 .29257 Metetra
0 .023 .121 r
.23733 .29257 .24362 .29894 .25299 .29549 .24672 .2891 Metetra
0 .023 .121 r
.24672 .2891 .25299 .29549 .2624 .29204 .25615 .28562 Metetra
0 .023 .121 r
.25615 .28562 .2624 .29204 .27184 .28856 .26561 .28212 Metetra
0 .023 .121 r
.26561 .28212 .27184 .28856 .28132 .28508 .27511 .27861 Metetra
0 .023 .121 r
.27511 .27861 .28132 .28508 .29083 .28158 .28464 .27509 Metetra
0 .023 .121 r
.28464 .27509 .29083 .28158 .30038 .27807 .2942 .27156 Metetra
0 .023 .121 r
.2942 .27156 .30038 .27807 .30995 .27455 .3038 .26802 Metetra
0 .023 .121 r
.3038 .26802 .30995 .27455 .31957 .27102 .31344 .26446 Metetra
0 .023 .121 r
.31344 .26446 .31957 .27102 .32922 .26747 .32311 .26088 Metetra
0 .023 .121 r
.32311 .26088 .32922 .26747 .3389 .26391 .33282 .2573 Metetra
0 .023 .121 r
.33282 .2573 .3389 .26391 .34862 .26033 .34256 .2537 Metetra
0 .023 .121 r
.34256 .2537 .34862 .26033 .35838 .25675 .35234 .25009 Metetra
0 .023 .121 r
.35234 .25009 .35838 .25675 .36817 .25315 .36215 .24647 Metetra
0 .023 .121 r
.36215 .24647 .36817 .25315 .378 .24953 .372 .24283 Metetra
0 .023 .121 r
.372 .24283 .378 .24953 .38786 .24591 .38189 .23918 Metetra
0 .023 .121 r
.38189 .23918 .38786 .24591 .39776 .24227 .39181 .23552 Metetra
0 .023 .121 r
.39181 .23552 .39776 .24227 .4077 .23862 .40177 .23184 Metetra
0 .024 .122 r
.40177 .23184 .4077 .23862 .41767 .235 .41176 .22823 Metetra
0 .024 .122 r
.41176 .22823 .41767 .235 .42768 .23132 .4218 .22452 Metetra
0 .024 .122 r
.4218 .22452 .42768 .23132 .43773 .22758 .43187 .22072 Metetra
0 .023 .121 r
.43187 .22072 .43773 .22758 .44782 .22387 .44198 .21699 Metetra
0 .023 .121 r
.44198 .21699 .44782 .22387 .45794 .22014 .45213 .21323 Metetra
0 .023 .121 r
.45213 .21323 .45794 .22014 .4681 .21641 .46231 .20947 Metetra
0 .023 .121 r
.46231 .20947 .4681 .21641 .4783 .21265 .47254 .20569 Metetra
0 .023 .121 r
.47254 .20569 .4783 .21265 .48854 .20889 .4828 .2019 Metetra
0 .023 .121 r
.4828 .2019 .48854 .20889 .49881 .20511 .4931 .1981 Metetra
0 .023 .121 r
.4931 .1981 .49881 .20511 .50913 .20132 .50344 .19428 Metetra
0 .023 .121 r
.50344 .19428 .50913 .20132 .51948 .19751 .51382 .19045 Metetra
0 .023 .121 r
.51382 .19045 .51948 .19751 .52987 .19369 .52423 .1866 Metetra
0 .023 .121 r
.52423 .1866 .52987 .19369 .5403 .18986 .53469 .18274 Metetra
0 .023 .121 r
.53469 .18274 .5403 .18986 .55077 .18601 .54519 .17886 Metetra
0 .023 .121 r
.54519 .17886 .55077 .18601 .56129 .18214 .55573 .17497 Metetra
0 .023 .121 r
.55573 .17497 .56129 .18214 .57184 .17826 .56631 .17106 Metetra
0 .023 .121 r
.56631 .17106 .57184 .17826 .58243 .17437 .57692 .16714 Metetra
0 .023 .121 r
.57692 .16714 .58243 .17437 .59306 .17046 .58758 .1632 Metetra
0 .023 .121 r
.58758 .1632 .59306 .17046 .60373 .16653 .59828 .15925 Metetra
0 .023 .121 r
.59828 .15925 .60373 .16653 .61445 .16259 .60903 .15528 Metetra
0 .023 .121 r
.60903 .15528 .61445 .16259 .6252 .15864 .61981 .1513 Metetra
0 .023 .121 r
.61981 .1513 .6252 .15864 .636 .15467 .63063 .1473 Metetra
0 .023 .121 r
.63063 .1473 .636 .15467 .64684 .15068 .6415 .14329 Metetra
0 .023 .121 r
.6415 .14329 .64684 .15068 .65772 .14668 .65241 .13926 Metetra
0 .023 .121 r
.65241 .13926 .65772 .14668 .66864 .14267 .66336 .13521 Metetra
0 .023 .121 r
.66336 .13521 .66864 .14267 .67961 .13864 .67436 .13115 Metetra
0 .023 .121 r
.67436 .13115 .67961 .13864 .69061 .13459 .68539 .12708 Metetra
0 .023 .121 r
.68539 .12708 .69061 .13459 .70167 .13053 .69647 .12298 Metetra
0 .023 .121 r
.69647 .12298 .70167 .13053 .71276 .12645 .7076 .11887 Metetra
0 .023 .121 r
.7076 .11887 .71276 .12645 .7239 .12235 .71876 .11475 Metetra
0 .023 .121 r
.71876 .11475 .7239 .12235 .73508 .11824 .72998 .11061 Metetra
0 .023 .121 r
.72998 .11061 .73508 .11824 .7463 .11411 .74123 .10645 Metetra
0 .023 .121 r
.74123 .10645 .7463 .11411 .75757 .10997 .75253 .10228 Metetra
0 .023 .121 r
.11163 .33044 .11821 .33656 .12718 .33325 .12062 .32711 Metetra
0 .023 .121 r
.12062 .32711 .12718 .33325 .13618 .32993 .12964 .32376 Metetra
0 .023 .121 r
.12964 .32376 .13618 .32993 .14521 .32659 .13869 .3204 Metetra
0 .023 .121 r
.13869 .3204 .14521 .32659 .15428 .32324 .14777 .31703 Metetra
0 .023 .121 r
.14777 .31703 .15428 .32324 .16337 .31988 .15688 .31365 Metetra
0 .023 .121 r
.15688 .31365 .16337 .31988 .1725 .31651 .16603 .31026 Metetra
0 .023 .121 r
.16603 .31026 .1725 .31651 .18166 .31313 .17521 .30685 Metetra
0 .023 .121 r
.17521 .30685 .18166 .31313 .19086 .30973 .18443 .30343 Metetra
0 .023 .121 r
.18443 .30343 .19086 .30973 .20009 .30632 .19367 .3 Metetra
0 .023 .121 r
.19367 .3 .20009 .30632 .20935 .3029 .20295 .29656 Metetra
0 .023 .121 r
.20295 .29656 .20935 .3029 .21864 .29947 .21226 .2931 Metetra
0 .023 .121 r
.21226 .2931 .21864 .29947 .22797 .29603 .22161 .28963 Metetra
0 .023 .121 r
.22161 .28963 .22797 .29603 .23733 .29257 .23099 .28615 Metetra
0 .023 .121 r
.23099 .28615 .23733 .29257 .24672 .2891 .2404 .28266 Metetra
0 .023 .121 r
.2404 .28266 .24672 .2891 .25615 .28562 .24985 .27915 Metetra
0 .023 .121 r
.24985 .27915 .25615 .28562 .26561 .28212 .25934 .27564 Metetra
0 .023 .121 r
.25934 .27564 .26561 .28212 .27511 .27861 .26885 .27211 Metetra
0 .023 .121 r
.26885 .27211 .27511 .27861 .28464 .27509 .2784 .26856 Metetra
0 .023 .121 r
.2784 .26856 .28464 .27509 .2942 .27156 .28799 .265 Metetra
0 .023 .121 r
.28799 .265 .2942 .27156 .3038 .26802 .29761 .26143 Metetra
0 .023 .121 r
.29761 .26143 .3038 .26802 .31344 .26446 .30727 .25785 Metetra
0 .023 .121 r
.30727 .25785 .31344 .26446 .32311 .26088 .31696 .25426 Metetra
0 .023 .121 r
.31696 .25426 .32311 .26088 .33282 .2573 .32669 .25065 Metetra
0 .023 .121 r
.32669 .25065 .33282 .2573 .34256 .2537 .33645 .24702 Metetra
0 .023 .121 r
.33645 .24702 .34256 .2537 .35234 .25009 .34625 .24339 Metetra
0 .023 .121 r
.34625 .24339 .35234 .25009 .36215 .24647 .35609 .23974 Metetra
0 .023 .121 r
.35609 .23974 .36215 .24647 .372 .24283 .36596 .23608 Metetra
0 .023 .121 r
.36596 .23608 .372 .24283 .38189 .23918 .37587 .2324 Metetra
0 .023 .121 r
.37587 .2324 .38189 .23918 .39181 .23552 .38581 .22872 Metetra
0 .023 .121 r
.38581 .22872 .39181 .23552 .40177 .23184 .3958 .22502 Metetra
0 .024 .122 r
.3958 .22502 .40177 .23184 .41176 .22823 .40581 .2214 Metetra
0 .024 .122 r
.40581 .2214 .41176 .22823 .4218 .22452 .41587 .21767 Metetra
0 .024 .122 r
.41587 .21767 .4218 .22452 .43187 .22072 .42597 .21382 Metetra
0 .023 .121 r
.42597 .21382 .43187 .22072 .44198 .21699 .4361 .21006 Metetra
0 .023 .121 r
.4361 .21006 .44198 .21699 .45213 .21323 .44627 .20628 Metetra
0 .023 .121 r
.44627 .20628 .45213 .21323 .46231 .20947 .45648 .20249 Metetra
0 .023 .121 r
.45648 .20249 .46231 .20947 .47254 .20569 .46673 .19869 Metetra
0 .023 .121 r
.46673 .19869 .47254 .20569 .4828 .2019 .47702 .19487 Metetra
0 .023 .121 r
.47702 .19487 .4828 .2019 .4931 .1981 .48734 .19104 Metetra
0 .023 .121 r
.48734 .19104 .4931 .1981 .50344 .19428 .49771 .18719 Metetra
0 .023 .121 r
.49771 .18719 .50344 .19428 .51382 .19045 .50811 .18333 Metetra
0 .023 .121 r
.50811 .18333 .51382 .19045 .52423 .1866 .51856 .17946 Metetra
0 .023 .121 r
.51856 .17946 .52423 .1866 .53469 .18274 .52904 .17557 Metetra
0 .023 .121 r
.52904 .17557 .53469 .18274 .54519 .17886 .53957 .17166 Metetra
0 .023 .121 r
.53957 .17166 .54519 .17886 .55573 .17497 .55013 .16774 Metetra
0 .023 .121 r
.55013 .16774 .55573 .17497 .56631 .17106 .56073 .16381 Metetra
0 .023 .121 r
.56073 .16381 .56631 .17106 .57692 .16714 .57138 .15986 Metetra
0 .023 .121 r
.57138 .15986 .57692 .16714 .58758 .1632 .58207 .15589 Metetra
0 .023 .121 r
.58207 .15589 .58758 .1632 .59828 .15925 .59279 .15191 Metetra
0 .023 .121 r
.59279 .15191 .59828 .15925 .60903 .15528 .60356 .14792 Metetra
0 .023 .121 r
.60356 .14792 .60903 .15528 .61981 .1513 .61437 .14391 Metetra
0 .023 .121 r
.61437 .14391 .61981 .1513 .63063 .1473 .62523 .13988 Metetra
0 .023 .121 r
.62523 .13988 .63063 .1473 .6415 .14329 .63612 .13584 Metetra
0 .023 .121 r
.63612 .13584 .6415 .14329 .65241 .13926 .64706 .13178 Metetra
0 .023 .121 r
.64706 .13178 .65241 .13926 .66336 .13521 .65804 .1277 Metetra
0 .023 .121 r
.65804 .1277 .66336 .13521 .67436 .13115 .66907 .12361 Metetra
0 .023 .121 r
.66907 .12361 .67436 .13115 .68539 .12708 .68013 .11951 Metetra
0 .023 .121 r
.68013 .11951 .68539 .12708 .69647 .12298 .69124 .11539 Metetra
0 .023 .121 r
.69124 .11539 .69647 .12298 .7076 .11887 .7024 .11125 Metetra
0 .023 .121 r
.7024 .11125 .7076 .11887 .71876 .11475 .71359 .10709 Metetra
0 .023 .121 r
.71359 .10709 .71876 .11475 .72998 .11061 .72484 .10292 Metetra
0 .023 .121 r
.72484 .10292 .72998 .11061 .74123 .10645 .73612 .09873 Metetra
0 .023 .121 r
.73612 .09873 .74123 .10645 .75253 .10228 .74745 .09453 Metetra
0 .023 .121 r
.10501 .32427 .11163 .33044 .12062 .32711 .11401 .32092 Metetra
0 .023 .121 r
.11401 .32092 .12062 .32711 .12964 .32376 .12305 .31755 Metetra
0 .023 .121 r
.12305 .31755 .12964 .32376 .13869 .3204 .13212 .31417 Metetra
0 .023 .121 r
.13212 .31417 .13869 .3204 .14777 .31703 .14122 .31078 Metetra
0 .023 .121 r
.14122 .31078 .14777 .31703 .15688 .31365 .15035 .30737 Metetra
0 .023 .121 r
.15035 .30737 .15688 .31365 .16603 .31026 .15952 .30396 Metetra
0 .023 .121 r
.15952 .30396 .16603 .31026 .17521 .30685 .16872 .30053 Metetra
0 .023 .121 r
.16872 .30053 .17521 .30685 .18443 .30343 .17795 .29709 Metetra
0 .023 .121 r
.17795 .29709 .18443 .30343 .19367 .3 .18722 .29363 Metetra
0 .023 .121 r
.18722 .29363 .19367 .3 .20295 .29656 .19651 .29017 Metetra
0 .023 .121 r
.19651 .29017 .20295 .29656 .21226 .2931 .20585 .28669 Metetra
0 .023 .121 r
.20585 .28669 .21226 .2931 .22161 .28963 .21521 .2832 Metetra
0 .023 .121 r
.21521 .2832 .22161 .28963 .23099 .28615 .22461 .27969 Metetra
0 .023 .121 r
.22461 .27969 .23099 .28615 .2404 .28266 .23405 .27618 Metetra
0 .023 .121 r
.23405 .27618 .2404 .28266 .24985 .27915 .24351 .27265 Metetra
0 .023 .121 r
.24351 .27265 .24985 .27915 .25934 .27564 .25302 .26911 Metetra
0 .023 .121 r
.25302 .26911 .25934 .27564 .26885 .27211 .26255 .26555 Metetra
0 .023 .121 r
.26255 .26555 .26885 .27211 .2784 .26856 .27213 .26198 Metetra
0 .023 .121 r
.27213 .26198 .2784 .26856 .28799 .265 .28173 .2584 Metetra
0 .023 .121 r
.28173 .2584 .28799 .265 .29761 .26143 .29138 .25481 Metetra
0 .023 .121 r
.29138 .25481 .29761 .26143 .30727 .25785 .30106 .2512 Metetra
0 .023 .121 r
.30106 .2512 .30727 .25785 .31696 .25426 .31077 .24758 Metetra
0 .023 .121 r
.31077 .24758 .31696 .25426 .32669 .25065 .32052 .24395 Metetra
0 .023 .121 r
.32052 .24395 .32669 .25065 .33645 .24702 .3303 .2403 Metetra
0 .023 .121 r
.3303 .2403 .33645 .24702 .34625 .24339 .34013 .23664 Metetra
0 .023 .121 r
.34013 .23664 .34625 .24339 .35609 .23974 .34998 .23297 Metetra
0 .023 .121 r
.34998 .23297 .35609 .23974 .36596 .23608 .35988 .22928 Metetra
0 .023 .121 r
.35988 .22928 .36596 .23608 .37587 .2324 .36981 .22558 Metetra
0 .023 .121 r
.36981 .22558 .37587 .2324 .38581 .22872 .37978 .22186 Metetra
0 .023 .121 r
.37978 .22186 .38581 .22872 .3958 .22502 .38979 .21813 Metetra
0 .024 .122 r
.38979 .21813 .3958 .22502 .40581 .2214 .39983 .2144 Metetra
0 .024 .122 r
.39983 .2144 .40581 .2214 .41587 .21767 .40991 .21064 Metetra
0 .024 .122 r
.40991 .21064 .41587 .21767 .42597 .21382 .42003 .20686 Metetra
0 .023 .121 r
.42003 .20686 .42597 .21382 .4361 .21006 .43019 .20307 Metetra
0 .023 .121 r
.43019 .20307 .4361 .21006 .44627 .20628 .44038 .19927 Metetra
0 .023 .121 r
.44038 .19927 .44627 .20628 .45648 .20249 .45062 .19546 Metetra
0 .023 .121 r
.45062 .19546 .45648 .20249 .46673 .19869 .46089 .19163 Metetra
0 .023 .121 r
.46089 .19163 .46673 .19869 .47702 .19487 .4712 .18778 Metetra
0 .023 .121 r
.4712 .18778 .47702 .19487 .48734 .19104 .48155 .18393 Metetra
0 .023 .121 r
.48155 .18393 .48734 .19104 .49771 .18719 .49194 .18005 Metetra
0 .023 .121 r
.49194 .18005 .49771 .18719 .50811 .18333 .50237 .17617 Metetra
0 .023 .121 r
.50237 .17617 .50811 .18333 .51856 .17946 .51284 .17226 Metetra
0 .023 .121 r
.51284 .17226 .51856 .17946 .52904 .17557 .52335 .16835 Metetra
0 .023 .121 r
.52335 .16835 .52904 .17557 .53957 .17166 .5339 .16441 Metetra
0 .023 .121 r
.5339 .16441 .53957 .17166 .55013 .16774 .54449 .16047 Metetra
0 .023 .121 r
.54449 .16047 .55013 .16774 .56073 .16381 .55512 .1565 Metetra
0 .023 .121 r
.55512 .1565 .56073 .16381 .57138 .15986 .5658 .15253 Metetra
0 .023 .121 r
.5658 .15253 .57138 .15986 .58207 .15589 .57651 .14853 Metetra
0 .023 .121 r
.57651 .14853 .58207 .15589 .59279 .15191 .58727 .14452 Metetra
0 .023 .121 r
.58727 .14452 .59279 .15191 .60356 .14792 .59806 .1405 Metetra
0 .023 .121 r
.59806 .1405 .60356 .14792 .61437 .14391 .6089 .13646 Metetra
0 .023 .121 r
.6089 .13646 .61437 .14391 .62523 .13988 .61978 .1324 Metetra
0 .023 .121 r
.61978 .1324 .62523 .13988 .63612 .13584 .63071 .12833 Metetra
0 .023 .121 r
.63071 .12833 .63612 .13584 .64706 .13178 .64167 .12424 Metetra
0 .023 .121 r
.64167 .12424 .64706 .13178 .65804 .1277 .65268 .12014 Metetra
0 .023 .121 r
.65268 .12014 .65804 .1277 .66907 .12361 .66374 .11602 Metetra
0 .023 .121 r
.66374 .11602 .66907 .12361 .68013 .11951 .67483 .11188 Metetra
0 .023 .121 r
.67483 .11188 .68013 .11951 .69124 .11539 .68597 .10773 Metetra
0 .023 .121 r
.68597 .10773 .69124 .11539 .7024 .11125 .69716 .10356 Metetra
0 .023 .121 r
.69716 .10356 .7024 .11125 .71359 .10709 .70839 .09938 Metetra
0 .023 .121 r
.70839 .09938 .71359 .10709 .72484 .10292 .71966 .09518 Metetra
0 .023 .121 r
.71966 .09518 .72484 .10292 .73612 .09873 .73098 .09096 Metetra
0 .023 .121 r
.73098 .09096 .73612 .09873 .74745 .09453 .74234 .08672 Metetra
0 .023 .121 r
.09834 .31807 .10501 .32427 .11401 .32092 .10737 .31469 Metetra
0 .023 .121 r
.10737 .31469 .11401 .32092 .12305 .31755 .11642 .3113 Metetra
0 .023 .121 r
.11642 .3113 .12305 .31755 .13212 .31417 .12551 .3079 Metetra
0 .023 .121 r
.12551 .3079 .13212 .31417 .14122 .31078 .13463 .30448 Metetra
0 .023 .121 r
.13463 .30448 .14122 .31078 .15035 .30737 .14378 .30106 Metetra
0 .023 .121 r
.14378 .30106 .15035 .30737 .15952 .30396 .15296 .29762 Metetra
0 .023 .121 r
.15296 .29762 .15952 .30396 .16872 .30053 .16218 .29417 Metetra
0 .023 .121 r
.16218 .29417 .16872 .30053 .17795 .29709 .17143 .2907 Metetra
0 .023 .121 r
.17143 .2907 .17795 .29709 .18722 .29363 .18072 .28723 Metetra
0 .023 .121 r
.18072 .28723 .18722 .29363 .19651 .29017 .19003 .28374 Metetra
0 .023 .121 r
.19003 .28374 .19651 .29017 .20585 .28669 .19939 .28023 Metetra
0 .023 .121 r
.19939 .28023 .20585 .28669 .21521 .2832 .20877 .27672 Metetra
0 .023 .121 r
.20877 .27672 .21521 .2832 .22461 .27969 .21819 .27319 Metetra
0 .023 .121 r
.21819 .27319 .22461 .27969 .23405 .27618 .22765 .26965 Metetra
0 .023 .121 r
.22765 .26965 .23405 .27618 .24351 .27265 .23713 .2661 Metetra
0 .023 .121 r
.23713 .2661 .24351 .27265 .25302 .26911 .24666 .26253 Metetra
0 .023 .121 r
.24666 .26253 .25302 .26911 .26255 .26555 .25622 .25896 Metetra
0 .023 .121 r
.25622 .25896 .26255 .26555 .27213 .26198 .26581 .25536 Metetra
0 .023 .121 r
.26581 .25536 .27213 .26198 .28173 .2584 .27544 .25176 Metetra
0 .023 .121 r
.27544 .25176 .28173 .2584 .29138 .25481 .2851 .24814 Metetra
0 .023 .121 r
.2851 .24814 .29138 .25481 .30106 .2512 .2948 .24451 Metetra
0 .023 .121 r
.2948 .24451 .30106 .2512 .31077 .24758 .30454 .24086 Metetra
0 .023 .121 r
.30454 .24086 .31077 .24758 .32052 .24395 .31431 .2372 Metetra
0 .023 .121 r
.31431 .2372 .32052 .24395 .3303 .2403 .32411 .23353 Metetra
0 .023 .121 r
.32411 .23353 .3303 .2403 .34013 .23664 .33396 .22985 Metetra
0 .023 .121 r
.33396 .22985 .34013 .23664 .34998 .23297 .34384 .22615 Metetra
0 .023 .121 r
.34384 .22615 .34998 .23297 .35988 .22928 .35376 .22243 Metetra
0 .023 .121 r
.35376 .22243 .35988 .22928 .36981 .22558 .36371 .21871 Metetra
0 .023 .121 r
.36371 .21871 .36981 .22558 .37978 .22186 .3737 .21497 Metetra
0 .023 .121 r
.3737 .21497 .37978 .22186 .38979 .21813 .38373 .21122 Metetra
0 .024 .122 r
.38373 .21122 .38979 .21813 .39983 .2144 .39379 .20755 Metetra
0 .024 .122 r
.39379 .20755 .39983 .2144 .40991 .21064 .4039 .20377 Metetra
0 .024 .122 r
.4039 .20377 .40991 .21064 .42003 .20686 .41405 .19987 Metetra
0 .023 .121 r
.41405 .19987 .42003 .20686 .43019 .20307 .42423 .19605 Metetra
0 .023 .121 r
.42423 .19605 .43019 .20307 .44038 .19927 .43445 .19222 Metetra
0 .023 .121 r
.43445 .19222 .44038 .19927 .45062 .19546 .44471 .18838 Metetra
0 .023 .121 r
.44471 .18838 .45062 .19546 .46089 .19163 .455 .18452 Metetra
0 .023 .121 r
.455 .18452 .46089 .19163 .4712 .18778 .46534 .18065 Metetra
0 .023 .121 r
.46534 .18065 .4712 .18778 .48155 .18393 .47572 .17677 Metetra
0 .023 .121 r
.47572 .17677 .48155 .18393 .49194 .18005 .48613 .17287 Metetra
0 .023 .121 r
.48613 .17287 .49194 .18005 .50237 .17617 .49659 .16895 Metetra
0 .023 .121 r
.49659 .16895 .50237 .17617 .51284 .17226 .50708 .16502 Metetra
0 .023 .121 r
.50708 .16502 .51284 .17226 .52335 .16835 .51762 .16107 Metetra
0 .023 .121 r
.51762 .16107 .52335 .16835 .5339 .16441 .5282 .15711 Metetra
0 .023 .121 r
.5282 .15711 .5339 .16441 .54449 .16047 .53881 .15314 Metetra
0 .023 .121 r
.53881 .15314 .54449 .16047 .55512 .1565 .54947 .14915 Metetra
0 .023 .121 r
.54947 .14915 .55512 .1565 .5658 .15253 .56017 .14514 Metetra
0 .023 .121 r
.56017 .14514 .5658 .15253 .57651 .14853 .57091 .14112 Metetra
0 .023 .121 r
.57091 .14112 .57651 .14853 .58727 .14452 .5817 .13708 Metetra
0 .023 .121 r
.5817 .13708 .58727 .14452 .59806 .1405 .59252 .13303 Metetra
0 .023 .121 r
.59252 .13303 .59806 .1405 .6089 .13646 .60339 .12896 Metetra
0 .023 .121 r
.60339 .12896 .6089 .13646 .61978 .1324 .6143 .12487 Metetra
0 .023 .121 r
.6143 .12487 .61978 .1324 .63071 .12833 .62525 .12077 Metetra
0 .023 .121 r
.62525 .12077 .63071 .12833 .64167 .12424 .63625 .11666 Metetra
0 .023 .121 r
.63625 .11666 .64167 .12424 .65268 .12014 .64729 .11252 Metetra
0 .023 .121 r
.64729 .11252 .65268 .12014 .66374 .11602 .65837 .10837 Metetra
0 .023 .121 r
.65837 .10837 .66374 .11602 .67483 .11188 .6695 .10421 Metetra
0 .023 .121 r
.6695 .10421 .67483 .11188 .68597 .10773 .68067 .10002 Metetra
0 .023 .121 r
.68067 .10002 .68597 .10773 .69716 .10356 .69188 .09582 Metetra
0 .023 .121 r
.69188 .09582 .69716 .10356 .70839 .09938 .70314 .09161 Metetra
0 .023 .121 r
.70314 .09161 .70839 .09938 .71966 .09518 .71444 .08738 Metetra
0 .023 .121 r
.71444 .08738 .71966 .09518 .73098 .09096 .72579 .08313 Metetra
0 .023 .121 r
.72579 .08313 .73098 .09096 .74234 .08672 .73719 .07886 Metetra
0 .023 .121 r
.09164 .31182 .09834 .31807 .10737 .31469 .10068 .30842 Metetra
0 .023 .121 r
.10068 .30842 .10737 .31469 .11642 .3113 .10975 .30501 Metetra
0 .023 .121 r
.10975 .30501 .11642 .3113 .12551 .3079 .11885 .30158 Metetra
0 .023 .121 r
.11885 .30158 .12551 .3079 .13463 .30448 .12799 .29815 Metetra
0 .023 .121 r
.12799 .29815 .13463 .30448 .14378 .30106 .13716 .2947 Metetra
0 .023 .121 r
.13716 .2947 .14378 .30106 .15296 .29762 .14636 .29124 Metetra
0 .023 .121 r
.14636 .29124 .15296 .29762 .16218 .29417 .1556 .28776 Metetra
0 .023 .121 r
.1556 .28776 .16218 .29417 .17143 .2907 .16487 .28427 Metetra
0 .023 .121 r
.16487 .28427 .17143 .2907 .18072 .28723 .17417 .28077 Metetra
0 .023 .121 r
.17417 .28077 .18072 .28723 .19003 .28374 .18351 .27726 Metetra
0 .023 .121 r
.18351 .27726 .19003 .28374 .19939 .28023 .19288 .27374 Metetra
0 .023 .121 r
.19288 .27374 .19939 .28023 .20877 .27672 .20229 .2702 Metetra
0 .023 .121 r
.20229 .2702 .20877 .27672 .21819 .27319 .21173 .26665 Metetra
0 .023 .121 r
.21173 .26665 .21819 .27319 .22765 .26965 .2212 .26308 Metetra
0 .023 .121 r
.2212 .26308 .22765 .26965 .23713 .2661 .23071 .25951 Metetra
0 .023 .121 r
.23071 .25951 .23713 .2661 .24666 .26253 .24025 .25592 Metetra
0 .023 .121 r
.24025 .25592 .24666 .26253 .25622 .25896 .24983 .25231 Metetra
0 .023 .121 r
.24983 .25231 .25622 .25896 .26581 .25536 .25945 .2487 Metetra
0 .023 .121 r
.25945 .2487 .26581 .25536 .27544 .25176 .2691 .24507 Metetra
0 .023 .121 r
.2691 .24507 .27544 .25176 .2851 .24814 .27878 .24142 Metetra
0 .023 .121 r
.27878 .24142 .2851 .24814 .2948 .24451 .2885 .23777 Metetra
0 .023 .121 r
.2885 .23777 .2948 .24451 .30454 .24086 .29826 .2341 Metetra
0 .023 .121 r
.29826 .2341 .30454 .24086 .31431 .2372 .30805 .23041 Metetra
0 .023 .121 r
.30805 .23041 .31431 .2372 .32411 .23353 .31788 .22672 Metetra
0 .023 .121 r
.31788 .22672 .32411 .23353 .33396 .22985 .32775 .223 Metetra
0 .023 .121 r
.32775 .223 .33396 .22985 .34384 .22615 .33765 .21928 Metetra
0 .023 .121 r
.33765 .21928 .34384 .22615 .35376 .22243 .34759 .21554 Metetra
0 .023 .121 r
.34759 .21554 .35376 .22243 .36371 .21871 .35757 .21179 Metetra
0 .023 .121 r
.35757 .21179 .36371 .21871 .3737 .21497 .36758 .20802 Metetra
0 .023 .121 r
.36758 .20802 .3737 .21497 .38373 .21122 .37764 .20424 Metetra
0 .024 .122 r
.37764 .20424 .38373 .21122 .39379 .20755 .38772 .20048 Metetra
0 .024 .122 r
.38772 .20048 .39379 .20755 .4039 .20377 .39785 .19667 Metetra
0 .024 .122 r
.39785 .19667 .4039 .20377 .41405 .19987 .40802 .19281 Metetra
0 .023 .121 r
.40802 .19281 .41405 .19987 .42423 .19605 .41823 .18897 Metetra
0 .023 .121 r
.41823 .18897 .42423 .19605 .43445 .19222 .42847 .18512 Metetra
0 .023 .121 r
.42847 .18512 .43445 .19222 .44471 .18838 .43875 .18125 Metetra
0 .023 .121 r
.43875 .18125 .44471 .18838 .455 .18452 .44908 .17736 Metetra
0 .023 .121 r
.44908 .17736 .455 .18452 .46534 .18065 .45944 .17347 Metetra
0 .023 .121 r
.45944 .17347 .46534 .18065 .47572 .17677 .46984 .16955 Metetra
0 .023 .121 r
.46984 .16955 .47572 .17677 .48613 .17287 .48028 .16563 Metetra
0 .023 .121 r
.48028 .16563 .48613 .17287 .49659 .16895 .49076 .16168 Metetra
0 .023 .121 r
.49076 .16168 .49659 .16895 .50708 .16502 .50129 .15772 Metetra
0 .023 .121 r
.50129 .15772 .50708 .16502 .51762 .16107 .51185 .15375 Metetra
0 .023 .121 r
.51185 .15375 .51762 .16107 .5282 .15711 .52245 .14976 Metetra
0 .023 .121 r
.52245 .14976 .5282 .15711 .53881 .15314 .5331 .14576 Metetra
0 .023 .121 r
.5331 .14576 .53881 .15314 .54947 .14915 .54378 .14174 Metetra
0 .023 .121 r
.54378 .14174 .54947 .14915 .56017 .14514 .55451 .1377 Metetra
0 .023 .121 r
.55451 .1377 .56017 .14514 .57091 .14112 .56528 .13365 Metetra
0 .023 .121 r
.56528 .13365 .57091 .14112 .5817 .13708 .57609 .12959 Metetra
0 .023 .121 r
.57609 .12959 .5817 .13708 .59252 .13303 .58694 .1255 Metetra
0 .023 .121 r
.58694 .1255 .59252 .13303 .60339 .12896 .59784 .1214 Metetra
0 .023 .121 r
.59784 .1214 .60339 .12896 .6143 .12487 .60878 .11729 Metetra
0 .023 .121 r
.60878 .11729 .6143 .12487 .62525 .12077 .61976 .11316 Metetra
0 .023 .121 r
.61976 .11316 .62525 .12077 .63625 .11666 .63078 .10901 Metetra
0 .023 .121 r
.63078 .10901 .63625 .11666 .64729 .11252 .64185 .10485 Metetra
0 .023 .121 r
.64185 .10485 .64729 .11252 .65837 .10837 .65296 .10067 Metetra
0 .023 .121 r
.65296 .10067 .65837 .10837 .6695 .10421 .66412 .09647 Metetra
0 .023 .121 r
.66412 .09647 .6695 .10421 .68067 .10002 .67532 .09226 Metetra
0 .023 .121 r
.67532 .09226 .68067 .10002 .69188 .09582 .68657 .08803 Metetra
0 .023 .121 r
.68657 .08803 .69188 .09582 .70314 .09161 .69786 .08378 Metetra
0 .023 .121 r
.69786 .08378 .70314 .09161 .71444 .08738 .70919 .07952 Metetra
0 .023 .121 r
.70919 .07952 .71444 .08738 .72579 .08313 .72057 .07524 Metetra
0 .023 .121 r
.72057 .07524 .72579 .08313 .73719 .07886 .732 .07094 Metetra
0 .023 .121 r
.08488 .30554 .09164 .31182 .10068 .30842 .09394 .30211 Metetra
0 .023 .121 r
.09394 .30211 .10068 .30842 .10975 .30501 .10303 .29868 Metetra
0 .023 .121 r
.10303 .29868 .10975 .30501 .11885 .30158 .11215 .29523 Metetra
0 .023 .121 r
.11215 .29523 .11885 .30158 .12799 .29815 .12131 .29177 Metetra
0 .023 .121 r
.12131 .29177 .12799 .29815 .13716 .2947 .1305 .2883 Metetra
0 .023 .121 r
.1305 .2883 .13716 .2947 .14636 .29124 .13972 .28481 Metetra
0 .023 .121 r
.13972 .28481 .14636 .29124 .1556 .28776 .14898 .28131 Metetra
0 .023 .121 r
.14898 .28131 .1556 .28776 .16487 .28427 .15827 .2778 Metetra
0 .023 .121 r
.15827 .2778 .16487 .28427 .17417 .28077 .16759 .27428 Metetra
0 .023 .121 r
.16759 .27428 .17417 .28077 .18351 .27726 .17694 .27074 Metetra
0 .023 .121 r
.17694 .27074 .18351 .27726 .19288 .27374 .18634 .2672 Metetra
0 .023 .121 r
.18634 .2672 .19288 .27374 .20229 .2702 .19576 .26363 Metetra
0 .023 .121 r
.19576 .26363 .20229 .2702 .21173 .26665 .20522 .26006 Metetra
0 .023 .121 r
.20522 .26006 .21173 .26665 .2212 .26308 .21471 .25647 Metetra
0 .023 .121 r
.21471 .25647 .2212 .26308 .23071 .25951 .22424 .25287 Metetra
0 .023 .121 r
.22424 .25287 .23071 .25951 .24025 .25592 .23381 .24925 Metetra
0 .023 .121 r
.23381 .24925 .24025 .25592 .24983 .25231 .24341 .24563 Metetra
0 .023 .121 r
.24341 .24563 .24983 .25231 .25945 .2487 .25304 .24199 Metetra
0 .023 .121 r
.25304 .24199 .25945 .2487 .2691 .24507 .26271 .23833 Metetra
0 .023 .121 r
.26271 .23833 .2691 .24507 .27878 .24142 .27242 .23466 Metetra
0 .023 .121 r
.27242 .23466 .27878 .24142 .2885 .23777 .28216 .23098 Metetra
0 .023 .121 r
.28216 .23098 .2885 .23777 .29826 .2341 .29194 .22729 Metetra
0 .023 .121 r
.29194 .22729 .29826 .2341 .30805 .23041 .30175 .22358 Metetra
0 .023 .121 r
.30175 .22358 .30805 .23041 .31788 .22672 .31161 .21985 Metetra
0 .023 .121 r
.31161 .21985 .31788 .22672 .32775 .223 .32149 .21612 Metetra
0 .023 .121 r
.32149 .21612 .32775 .223 .33765 .21928 .33142 .21237 Metetra
0 .023 .121 r
.33142 .21237 .33765 .21928 .34759 .21554 .34138 .2086 Metetra
0 .023 .121 r
.34138 .2086 .34759 .21554 .35757 .21179 .35138 .20482 Metetra
0 .023 .121 r
.35138 .20482 .35757 .21179 .36758 .20802 .36142 .20103 Metetra
0 .023 .121 r
.36142 .20103 .36758 .20802 .37764 .20424 .3715 .19723 Metetra
0 .023 .122 r
.3715 .19723 .37764 .20424 .38772 .20048 .38161 .19345 Metetra
0 .024 .122 r
.38161 .19345 .38772 .20048 .39785 .19667 .39176 .18961 Metetra
0 .023 .122 r
.39176 .18961 .39785 .19667 .40802 .19281 .40195 .18572 Metetra
0 .023 .121 r
.40195 .18572 .40802 .19281 .41823 .18897 .41218 .18185 Metetra
0 .023 .121 r
.41218 .18185 .41823 .18897 .42847 .18512 .42245 .17796 Metetra
0 .023 .121 r
.42245 .17796 .42847 .18512 .43875 .18125 .43276 .17407 Metetra
0 .023 .121 r
.43276 .17407 .43875 .18125 .44908 .17736 .44311 .17016 Metetra
0 .023 .121 r
.44311 .17016 .44908 .17736 .45944 .17347 .4535 .16623 Metetra
0 .023 .121 r
.4535 .16623 .45944 .17347 .46984 .16955 .46392 .16229 Metetra
0 .023 .121 r
.46392 .16229 .46984 .16955 .48028 .16563 .47439 .15833 Metetra
0 .023 .121 r
.47439 .15833 .48028 .16563 .49076 .16168 .4849 .15436 Metetra
0 .023 .121 r
.4849 .15436 .49076 .16168 .50129 .15772 .49545 .15038 Metetra
0 .023 .121 r
.49545 .15038 .50129 .15772 .51185 .15375 .50603 .14638 Metetra
0 .023 .121 r
.50603 .14638 .51185 .15375 .52245 .14976 .51666 .14236 Metetra
0 .023 .121 r
.51666 .14236 .52245 .14976 .5331 .14576 .52734 .13833 Metetra
0 .023 .121 r
.52734 .13833 .5331 .14576 .54378 .14174 .53805 .13428 Metetra
0 .023 .121 r
.53805 .13428 .54378 .14174 .55451 .1377 .5488 .13021 Metetra
0 .023 .121 r
.5488 .13021 .55451 .1377 .56528 .13365 .5596 .12613 Metetra
0 .023 .121 r
.5596 .12613 .56528 .13365 .57609 .12959 .57044 .12204 Metetra
0 .023 .121 r
.57044 .12204 .57609 .12959 .58694 .1255 .58132 .11792 Metetra
0 .023 .121 r
.58132 .11792 .58694 .1255 .59784 .1214 .59225 .1138 Metetra
0 .023 .121 r
.59225 .1138 .59784 .1214 .60878 .11729 .60321 .10965 Metetra
0 .023 .121 r
.60321 .10965 .60878 .11729 .61976 .11316 .61422 .10549 Metetra
0 .023 .121 r
.61422 .10549 .61976 .11316 .63078 .10901 .62528 .10131 Metetra
0 .023 .121 r
.62528 .10131 .63078 .10901 .64185 .10485 .63638 .09712 Metetra
0 .023 .121 r
.63638 .09712 .64185 .10485 .65296 .10067 .64752 .09291 Metetra
0 .023 .121 r
.64752 .09291 .65296 .10067 .66412 .09647 .6587 .08868 Metetra
0 .023 .121 r
.6587 .08868 .66412 .09647 .67532 .09226 .66994 .08444 Metetra
0 .023 .121 r
.66994 .08444 .67532 .09226 .68657 .08803 .68121 .08017 Metetra
0 .023 .121 r
.68121 .08017 .68657 .08803 .69786 .08378 .69253 .0759 Metetra
0 .023 .121 r
.69253 .0759 .69786 .08378 .70919 .07952 .7039 .0716 Metetra
0 .023 .121 r
.7039 .0716 .70919 .07952 .72057 .07524 .71531 .06729 Metetra
0 .023 .121 r
.71531 .06729 .72057 .07524 .732 .07094 .72677 .06296 Metetra
0 .023 .121 r
.07809 .29921 .08488 .30554 .09394 .30211 .08716 .29576 Metetra
0 .023 .121 r
.08716 .29576 .09394 .30211 .10303 .29868 .09627 .2923 Metetra
0 .023 .121 r
.09627 .2923 .10303 .29868 .11215 .29523 .10541 .28883 Metetra
0 .023 .121 r
.10541 .28883 .11215 .29523 .12131 .29177 .11458 .28535 Metetra
0 .023 .121 r
.11458 .28535 .12131 .29177 .1305 .2883 .12379 .28185 Metetra
0 .023 .121 r
.12379 .28185 .1305 .2883 .13972 .28481 .13303 .27834 Metetra
0 .023 .121 r
.13303 .27834 .13972 .28481 .14898 .28131 .14231 .27482 Metetra
0 .023 .121 r
.14231 .27482 .14898 .28131 .15827 .2778 .15162 .27129 Metetra
0 .023 .121 r
.15162 .27129 .15827 .2778 .16759 .27428 .16096 .26774 Metetra
0 .023 .121 r
.16096 .26774 .16759 .27428 .17694 .27074 .17033 .26418 Metetra
0 .023 .121 r
.17033 .26418 .17694 .27074 .18634 .2672 .17974 .26061 Metetra
0 .023 .121 r
.17974 .26061 .18634 .2672 .19576 .26363 .18919 .25702 Metetra
0 .023 .121 r
.18919 .25702 .19576 .26363 .20522 .26006 .19867 .25342 Metetra
0 .023 .121 r
.19867 .25342 .20522 .26006 .21471 .25647 .20818 .24981 Metetra
0 .023 .121 r
.20818 .24981 .21471 .25647 .22424 .25287 .21773 .24619 Metetra
0 .023 .121 r
.21773 .24619 .22424 .25287 .23381 .24925 .22732 .24255 Metetra
0 .023 .121 r
.22732 .24255 .23381 .24925 .24341 .24563 .23694 .23889 Metetra
0 .023 .121 r
.23694 .23889 .24341 .24563 .25304 .24199 .24659 .23523 Metetra
0 .023 .121 r
.24659 .23523 .25304 .24199 .26271 .23833 .25628 .23155 Metetra
0 .023 .121 r
.25628 .23155 .26271 .23833 .27242 .23466 .26601 .22786 Metetra
0 .023 .121 r
.26601 .22786 .27242 .23466 .28216 .23098 .27578 .22415 Metetra
0 .023 .121 r
.27578 .22415 .28216 .23098 .29194 .22729 .28558 .22043 Metetra
0 .023 .121 r
.28558 .22043 .29194 .22729 .30175 .22358 .29541 .21669 Metetra
0 .023 .121 r
.29541 .21669 .30175 .22358 .31161 .21985 .30529 .21294 Metetra
0 .023 .121 r
.30529 .21294 .31161 .21985 .32149 .21612 .3152 .20918 Metetra
0 .023 .121 r
.3152 .20918 .32149 .21612 .33142 .21237 .32515 .2054 Metetra
0 .023 .121 r
.32515 .2054 .33142 .21237 .34138 .2086 .33513 .20161 Metetra
0 .023 .121 r
.33513 .20161 .34138 .2086 .35138 .20482 .34516 .19781 Metetra
0 .023 .121 r
.34516 .19781 .35138 .20482 .36142 .20103 .35522 .19399 Metetra
0 .023 .121 r
.35522 .19399 .36142 .20103 .3715 .19723 .36532 .19016 Metetra
0 .024 .122 r
.36532 .19016 .3715 .19723 .38161 .19345 .37545 .18638 Metetra
0 .024 .122 r
.37545 .18638 .38161 .19345 .39176 .18961 .38563 .18251 Metetra
0 .024 .122 r
.38563 .18251 .39176 .18961 .40195 .18572 .39585 .17857 Metetra
0 .023 .121 r
.39585 .17857 .40195 .18572 .41218 .18185 .4061 .17467 Metetra
0 .023 .121 r
.4061 .17467 .41218 .18185 .42245 .17796 .41639 .17076 Metetra
0 .023 .121 r
.41639 .17076 .42245 .17796 .43276 .17407 .42673 .16684 Metetra
0 .023 .121 r
.42673 .16684 .43276 .17407 .44311 .17016 .4371 .1629 Metetra
0 .023 .121 r
.4371 .1629 .44311 .17016 .4535 .16623 .44751 .15894 Metetra
0 .023 .121 r
.44751 .15894 .4535 .16623 .46392 .16229 .45796 .15498 Metetra
0 .023 .121 r
.45796 .15498 .46392 .16229 .47439 .15833 .46846 .15099 Metetra
0 .023 .121 r
.46846 .15099 .47439 .15833 .4849 .15436 .47899 .14699 Metetra
0 .023 .121 r
.47899 .14699 .4849 .15436 .49545 .15038 .48956 .14298 Metetra
0 .023 .121 r
.48956 .14298 .49545 .15038 .50603 .14638 .50018 .13895 Metetra
0 .023 .121 r
.50018 .13895 .50603 .14638 .51666 .14236 .51084 .1349 Metetra
0 .023 .121 r
.51084 .1349 .51666 .14236 .52734 .13833 .52154 .13084 Metetra
0 .023 .121 r
.52154 .13084 .52734 .13833 .53805 .13428 .53228 .12676 Metetra
0 .023 .121 r
.53228 .12676 .53805 .13428 .5488 .13021 .54306 .12267 Metetra
0 .023 .121 r
.54306 .12267 .5488 .13021 .5596 .12613 .55388 .11856 Metetra
0 .023 .121 r
.55388 .11856 .5596 .12613 .57044 .12204 .56475 .11443 Metetra
0 .023 .121 r
.56475 .11443 .57044 .12204 .58132 .11792 .57566 .11029 Metetra
0 .023 .121 r
.57566 .11029 .58132 .11792 .59225 .1138 .58661 .10613 Metetra
0 .023 .121 r
.58661 .10613 .59225 .1138 .60321 .10965 .59761 .10196 Metetra
0 .023 .121 r
.59761 .10196 .60321 .10965 .61422 .10549 .60865 .09776 Metetra
0 .023 .121 r
.60865 .09776 .61422 .10549 .62528 .10131 .61973 .09356 Metetra
0 .023 .121 r
.61973 .09356 .62528 .10131 .63638 .09712 .63086 .08933 Metetra
0 .023 .121 r
.63086 .08933 .63638 .09712 .64752 .09291 .64203 .08509 Metetra
0 .023 .121 r
.64203 .08509 .64752 .09291 .6587 .08868 .65325 .08083 Metetra
0 .023 .121 r
.65325 .08083 .6587 .08868 .66994 .08444 .66451 .07655 Metetra
0 .023 .121 r
.66451 .07655 .66994 .08444 .68121 .08017 .67582 .07226 Metetra
0 .023 .121 r
.67582 .07226 .68121 .08017 .69253 .0759 .68717 .06795 Metetra
0 .023 .121 r
.68717 .06795 .69253 .0759 .7039 .0716 .69857 .06362 Metetra
0 .023 .121 r
.69857 .06362 .7039 .0716 .71531 .06729 .71001 .05928 Metetra
0 .023 .121 r
.71001 .05928 .71531 .06729 .72677 .06296 .7215 .05492 Metetra
0 .023 .121 r
.07124 .29284 .07809 .29921 .08716 .29576 .08034 .28937 Metetra
0 .023 .121 r
.08034 .28937 .08716 .29576 .09627 .2923 .08946 .28589 Metetra
0 .023 .121 r
.08946 .28589 .09627 .2923 .10541 .28883 .09862 .28239 Metetra
0 .023 .121 r
.09862 .28239 .10541 .28883 .11458 .28535 .10781 .27888 Metetra
0 .023 .121 r
.10781 .27888 .11458 .28535 .12379 .28185 .11704 .27537 Metetra
0 .023 .121 r
.11704 .27537 .12379 .28185 .13303 .27834 .1263 .27183 Metetra
0 .023 .121 r
.1263 .27183 .13303 .27834 .14231 .27482 .13559 .26829 Metetra
0 .023 .121 r
.13559 .26829 .14231 .27482 .15162 .27129 .14492 .26473 Metetra
0 .023 .121 r
.14492 .26473 .15162 .27129 .16096 .26774 .15428 .26116 Metetra
0 .023 .121 r
.15428 .26116 .16096 .26774 .17033 .26418 .16368 .25758 Metetra
0 .023 .121 r
.16368 .25758 .17033 .26418 .17974 .26061 .17311 .25398 Metetra
0 .023 .121 r
.17311 .25398 .17974 .26061 .18919 .25702 .18257 .25037 Metetra
0 .023 .121 r
.18257 .25037 .18919 .25702 .19867 .25342 .19207 .24674 Metetra
0 .023 .121 r
.19207 .24674 .19867 .25342 .20818 .24981 .20161 .24311 Metetra
0 .023 .121 r
.20161 .24311 .20818 .24981 .21773 .24619 .21118 .23946 Metetra
0 .023 .121 r
.21118 .23946 .21773 .24619 .22732 .24255 .22078 .23579 Metetra
0 .023 .121 r
.22078 .23579 .22732 .24255 .23694 .23889 .23042 .23212 Metetra
0 .023 .121 r
.23042 .23212 .23694 .23889 .24659 .23523 .2401 .22842 Metetra
0 .023 .121 r
.2401 .22842 .24659 .23523 .25628 .23155 .24981 .22472 Metetra
0 .023 .121 r
.24981 .22472 .25628 .23155 .26601 .22786 .25956 .221 Metetra
0 .023 .121 r
.25956 .221 .26601 .22786 .27578 .22415 .26935 .21727 Metetra
0 .023 .121 r
.26935 .21727 .27578 .22415 .28558 .22043 .27917 .21352 Metetra
0 .023 .121 r
.27917 .21352 .28558 .22043 .29541 .21669 .28903 .20976 Metetra
0 .023 .121 r
.28903 .20976 .29541 .21669 .30529 .21294 .29892 .20599 Metetra
0 .023 .121 r
.29892 .20599 .30529 .21294 .3152 .20918 .30886 .2022 Metetra
0 .023 .121 r
.30886 .2022 .3152 .20918 .32515 .2054 .31883 .19839 Metetra
0 .023 .121 r
.31883 .19839 .32515 .2054 .33513 .20161 .32884 .19457 Metetra
0 .023 .121 r
.32884 .19457 .33513 .20161 .34516 .19781 .33888 .19074 Metetra
0 .023 .121 r
.33888 .19074 .34516 .19781 .35522 .19399 .34897 .1869 Metetra
0 .023 .121 r
.34897 .1869 .35522 .19399 .36532 .19016 .35909 .18303 Metetra
0 .023 .122 r
.35909 .18303 .36532 .19016 .37545 .18638 .36925 .17916 Metetra
0 .024 .122 r
.36925 .17916 .37545 .18638 .38563 .18251 .37945 .17527 Metetra
0 .023 .122 r
.37945 .17527 .38563 .18251 .39585 .17857 .38969 .17136 Metetra
0 .023 .121 r
.38969 .17136 .39585 .17857 .4061 .17467 .39997 .16744 Metetra
0 .023 .121 r
.39997 .16744 .4061 .17467 .41639 .17076 .41029 .1635 Metetra
0 .023 .121 r
.41029 .1635 .41639 .17076 .42673 .16684 .42065 .15955 Metetra
0 .023 .121 r
.42065 .15955 .42673 .16684 .4371 .1629 .43105 .15559 Metetra
0 .023 .121 r
.43105 .15559 .4371 .1629 .44751 .15894 .44148 .15161 Metetra
0 .023 .121 r
.44148 .15161 .44751 .15894 .45796 .15498 .45196 .14761 Metetra
0 .023 .121 r
.45196 .14761 .45796 .15498 .46846 .15099 .46248 .1436 Metetra
0 .023 .121 r
.46248 .1436 .46846 .15099 .47899 .14699 .47304 .13957 Metetra
0 .023 .121 r
.47304 .13957 .47899 .14699 .48956 .14298 .48364 .13552 Metetra
0 .023 .121 r
.48364 .13552 .48956 .14298 .50018 .13895 .49428 .13146 Metetra
0 .023 .121 r
.49428 .13146 .50018 .13895 .51084 .1349 .50497 .12739 Metetra
0 .023 .121 r
.50497 .12739 .51084 .1349 .52154 .13084 .51569 .1233 Metetra
0 .023 .121 r
.51569 .1233 .52154 .13084 .53228 .12676 .52646 .11919 Metetra
0 .023 .121 r
.52646 .11919 .53228 .12676 .54306 .12267 .53727 .11507 Metetra
0 .023 .121 r
.53727 .11507 .54306 .12267 .55388 .11856 .54812 .11093 Metetra
0 .023 .121 r
.54812 .11093 .55388 .11856 .56475 .11443 .55902 .10677 Metetra
0 .023 .121 r
.55902 .10677 .56475 .11443 .57566 .11029 .56996 .1026 Metetra
0 .023 .121 r
.56996 .1026 .57566 .11029 .58661 .10613 .58094 .09841 Metetra
0 .023 .121 r
.58094 .09841 .58661 .10613 .59761 .10196 .59196 .0942 Metetra
0 .023 .121 r
.59196 .0942 .59761 .10196 .60865 .09776 .60303 .08998 Metetra
0 .023 .121 r
.60303 .08998 .60865 .09776 .61973 .09356 .61415 .08574 Metetra
0 .023 .121 r
.61415 .08574 .61973 .09356 .63086 .08933 .6253 .08149 Metetra
0 .023 .121 r
.6253 .08149 .63086 .08933 .64203 .08509 .63651 .07721 Metetra
0 .023 .121 r
.63651 .07721 .64203 .08509 .65325 .08083 .64775 .07292 Metetra
0 .023 .121 r
.64775 .07292 .65325 .08083 .66451 .07655 .65904 .06862 Metetra
0 .023 .121 r
.65904 .06862 .66451 .07655 .67582 .07226 .67038 .06429 Metetra
0 .023 .121 r
.67038 .06429 .67582 .07226 .68717 .06795 .68177 .05995 Metetra
0 .023 .121 r
.68177 .05995 .68717 .06795 .69857 .06362 .6932 .05559 Metetra
0 .023 .121 r
.6932 .05559 .69857 .06362 .71001 .05928 .70467 .05121 Metetra
0 .023 .121 r
.70467 .05121 .71001 .05928 .7215 .05492 .71619 .04682 Metetra
0 .023 .121 r
.06435 .28642 .07124 .29284 .08034 .28937 .07347 .28293 Metetra
0 .023 .121 r
.07347 .28293 .08034 .28937 .08946 .28589 .08261 .27942 Metetra
0 .023 .121 r
.08261 .27942 .08946 .28589 .09862 .28239 .09179 .27591 Metetra
0 .023 .121 r
.09179 .27591 .09862 .28239 .10781 .27888 .101 .27238 Metetra
0 .023 .121 r
.101 .27238 .10781 .27888 .11704 .27537 .11024 .26883 Metetra
0 .023 .121 r
.11024 .26883 .11704 .27537 .1263 .27183 .11952 .26528 Metetra
0 .023 .121 r
.11952 .26528 .1263 .27183 .13559 .26829 .12883 .26171 Metetra
0 .023 .121 r
.12883 .26171 .13559 .26829 .14492 .26473 .13818 .25813 Metetra
0 .023 .121 r
.13818 .25813 .14492 .26473 .15428 .26116 .14756 .25453 Metetra
0 .023 .121 r
.14756 .25453 .15428 .26116 .16368 .25758 .15698 .25092 Metetra
0 .023 .121 r
.15698 .25092 .16368 .25758 .17311 .25398 .16643 .2473 Metetra
0 .023 .121 r
.16643 .2473 .17311 .25398 .18257 .25037 .17591 .24367 Metetra
0 .023 .121 r
.17591 .24367 .18257 .25037 .19207 .24674 .18543 .24002 Metetra
0 .023 .121 r
.18543 .24002 .19207 .24674 .20161 .24311 .19499 .23636 Metetra
0 .023 .121 r
.19499 .23636 .20161 .24311 .21118 .23946 .20458 .23268 Metetra
0 .023 .121 r
.20458 .23268 .21118 .23946 .22078 .23579 .2142 .22899 Metetra
0 .023 .121 r
.2142 .22899 .22078 .23579 .23042 .23212 .22386 .22529 Metetra
0 .023 .121 r
.22386 .22529 .23042 .23212 .2401 .22842 .23356 .22157 Metetra
0 .023 .121 r
.23356 .22157 .2401 .22842 .24981 .22472 .2433 .21784 Metetra
0 .023 .121 r
.2433 .21784 .24981 .22472 .25956 .221 .25307 .2141 Metetra
0 .023 .121 r
.25307 .2141 .25956 .221 .26935 .21727 .26287 .21034 Metetra
0 .023 .121 r
.26287 .21034 .26935 .21727 .27917 .21352 .27272 .20657 Metetra
0 .023 .121 r
.27272 .20657 .27917 .21352 .28903 .20976 .2826 .20278 Metetra
0 .023 .121 r
.2826 .20278 .28903 .20976 .29892 .20599 .29252 .19898 Metetra
0 .023 .121 r
.29252 .19898 .29892 .20599 .30886 .2022 .30247 .19516 Metetra
0 .023 .121 r
.30247 .19516 .30886 .2022 .31883 .19839 .31247 .19133 Metetra
0 .023 .121 r
.31247 .19133 .31883 .19839 .32884 .19457 .3225 .18749 Metetra
0 .023 .121 r
.3225 .18749 .32884 .19457 .33888 .19074 .33257 .18363 Metetra
0 .023 .121 r
.33257 .18363 .33888 .19074 .34897 .1869 .34268 .17976 Metetra
0 .023 .121 r
.34268 .17976 .34897 .1869 .35909 .18303 .35282 .17588 Metetra
0 .023 .122 r
.35282 .17588 .35909 .18303 .36925 .17916 .363 .17204 Metetra
0 .024 .122 r
.363 .17204 .36925 .17916 .37945 .17527 .37323 .16812 Metetra
0 .023 .122 r
.37323 .16812 .37945 .17527 .38969 .17136 .3835 .16412 Metetra
0 .023 .121 r
.3835 .16412 .38969 .17136 .39997 .16744 .3938 .16017 Metetra
0 .023 .121 r
.3938 .16017 .39997 .16744 .41029 .1635 .40414 .1562 Metetra
0 .023 .121 r
.40414 .1562 .41029 .1635 .42065 .15955 .41453 .15222 Metetra
0 .023 .121 r
.41453 .15222 .42065 .15955 .43105 .15559 .42495 .14823 Metetra
0 .023 .121 r
.42495 .14823 .43105 .15559 .44148 .15161 .43541 .14421 Metetra
0 .023 .121 r
.43541 .14421 .44148 .15161 .45196 .14761 .44592 .14019 Metetra
0 .023 .121 r
.44592 .14019 .45196 .14761 .46248 .1436 .45646 .13615 Metetra
0 .023 .121 r
.45646 .13615 .46248 .1436 .47304 .13957 .46705 .13209 Metetra
0 .023 .121 r
.46705 .13209 .47304 .13957 .48364 .13552 .47767 .12802 Metetra
0 .023 .121 r
.47767 .12802 .48364 .13552 .49428 .13146 .48834 .12393 Metetra
0 .023 .121 r
.48834 .12393 .49428 .13146 .50497 .12739 .49905 .11982 Metetra
0 .023 .121 r
.49905 .11982 .50497 .12739 .51569 .1233 .50981 .1157 Metetra
0 .023 .121 r
.50981 .1157 .51569 .1233 .52646 .11919 .5206 .11157 Metetra
0 .023 .121 r
.5206 .11157 .52646 .11919 .53727 .11507 .53144 .10741 Metetra
0 .023 .121 r
.53144 .10741 .53727 .11507 .54812 .11093 .54232 .10324 Metetra
0 .023 .121 r
.54232 .10324 .54812 .11093 .55902 .10677 .55324 .09906 Metetra
0 .023 .121 r
.55324 .09906 .55902 .10677 .56996 .1026 .56421 .09485 Metetra
0 .023 .121 r
.56421 .09485 .56996 .1026 .58094 .09841 .57522 .09063 Metetra
0 .023 .121 r
.57522 .09063 .58094 .09841 .59196 .0942 .58628 .0864 Metetra
0 .023 .121 r
.58628 .0864 .59196 .0942 .60303 .08998 .59737 .08214 Metetra
0 .023 .121 r
.59737 .08214 .60303 .08998 .61415 .08574 .60852 .07787 Metetra
0 .023 .121 r
.60852 .07787 .61415 .08574 .6253 .08149 .61971 .07358 Metetra
0 .023 .121 r
.61971 .07358 .6253 .08149 .63651 .07721 .63094 .06928 Metetra
0 .023 .121 r
.63094 .06928 .63651 .07721 .64775 .07292 .64222 .06496 Metetra
0 .023 .121 r
.64222 .06496 .64775 .07292 .65904 .06862 .65354 .06062 Metetra
0 .023 .121 r
.65354 .06062 .65904 .06862 .67038 .06429 .66491 .05626 Metetra
0 .023 .121 r
.66491 .05626 .67038 .06429 .68177 .05995 .67632 .05189 Metetra
0 .023 .121 r
.67632 .05189 .68177 .05995 .6932 .05559 .68778 .04749 Metetra
0 .023 .121 r
.68778 .04749 .6932 .05559 .70467 .05121 .69929 .04308 Metetra
0 .023 .121 r
.69929 .04308 .70467 .05121 .71619 .04682 .71085 .03865 Metetra
0 .023 .121 r
.05742 .27996 .06435 .28642 .07347 .28293 .06655 .27645 Metetra
0 .023 .121 r
.06655 .27645 .07347 .28293 .08261 .27942 .07571 .27292 Metetra
0 .023 .121 r
.07571 .27292 .08261 .27942 .09179 .27591 .08491 .26938 Metetra
0 .023 .121 r
.08491 .26938 .09179 .27591 .101 .27238 .09414 .26583 Metetra
0 .023 .121 r
.09414 .26583 .101 .27238 .11024 .26883 .1034 .26226 Metetra
0 .023 .121 r
.1034 .26226 .11024 .26883 .11952 .26528 .1127 .25868 Metetra
0 .023 .121 r
.1127 .25868 .11952 .26528 .12883 .26171 .12203 .25509 Metetra
0 .023 .121 r
.12203 .25509 .12883 .26171 .13818 .25813 .13139 .25148 Metetra
0 .023 .121 r
.13139 .25148 .13818 .25813 .14756 .25453 .14079 .24786 Metetra
0 .023 .121 r
.14079 .24786 .14756 .25453 .15698 .25092 .15023 .24423 Metetra
0 .023 .121 r
.15023 .24423 .15698 .25092 .16643 .2473 .1597 .24058 Metetra
0 .023 .121 r
.1597 .24058 .16643 .2473 .17591 .24367 .1692 .23692 Metetra
0 .023 .121 r
.1692 .23692 .17591 .24367 .18543 .24002 .17874 .23325 Metetra
0 .023 .121 r
.17874 .23325 .18543 .24002 .19499 .23636 .18832 .22956 Metetra
0 .023 .121 r
.18832 .22956 .19499 .23636 .20458 .23268 .19793 .22586 Metetra
0 .023 .121 r
.19793 .22586 .20458 .23268 .2142 .22899 .20758 .22215 Metetra
0 .023 .121 r
.20758 .22215 .2142 .22899 .22386 .22529 .21726 .21842 Metetra
0 .023 .121 r
.21726 .21842 .22386 .22529 .23356 .22157 .22698 .21468 Metetra
0 .023 .121 r
.22698 .21468 .23356 .22157 .2433 .21784 .23673 .21092 Metetra
0 .023 .121 r
.23673 .21092 .2433 .21784 .25307 .2141 .24653 .20715 Metetra
0 .023 .121 r
.24653 .20715 .25307 .2141 .26287 .21034 .25635 .20336 Metetra
0 .023 .121 r
.25635 .20336 .26287 .21034 .27272 .20657 .26622 .19956 Metetra
0 .023 .121 r
.26622 .19956 .27272 .20657 .2826 .20278 .27612 .19575 Metetra
0 .023 .121 r
.27612 .19575 .2826 .20278 .29252 .19898 .28607 .19192 Metetra
0 .023 .121 r
.28607 .19192 .29252 .19898 .30247 .19516 .29604 .18808 Metetra
0 .023 .121 r
.29604 .18808 .30247 .19516 .31247 .19133 .30606 .18422 Metetra
0 .023 .121 r
.30606 .18422 .31247 .19133 .3225 .18749 .31612 .18035 Metetra
0 .023 .121 r
.31612 .18035 .3225 .18749 .33257 .18363 .32621 .17647 Metetra
0 .023 .121 r
.32621 .17647 .33257 .18363 .34268 .17976 .33634 .17257 Metetra
0 .023 .121 r
.33634 .17257 .34268 .17976 .35282 .17588 .34651 .16865 Metetra
0 .024 .122 r
.34651 .16865 .35282 .17588 .363 .17204 .35672 .16475 Metetra
0 .024 .122 r
.35672 .16475 .363 .17204 .37323 .16812 .36697 .1608 Metetra
0 .024 .122 r
.36697 .1608 .37323 .16812 .3835 .16412 .37726 .15681 Metetra
0 .023 .121 r
.37726 .15681 .3835 .16412 .3938 .16017 .38758 .15283 Metetra
0 .023 .121 r
.38758 .15283 .3938 .16017 .40414 .1562 .39795 .14884 Metetra
0 .023 .121 r
.39795 .14884 .40414 .1562 .41453 .15222 .40836 .14483 Metetra
0 .023 .121 r
.40836 .14483 .41453 .15222 .42495 .14823 .41881 .14081 Metetra
0 .023 .121 r
.41881 .14081 .42495 .14823 .43541 .14421 .4293 .13677 Metetra
0 .023 .121 r
.4293 .13677 .43541 .14421 .44592 .14019 .43983 .13272 Metetra
0 .023 .121 r
.43983 .13272 .44592 .14019 .45646 .13615 .4504 .12865 Metetra
0 .023 .121 r
.4504 .12865 .45646 .13615 .46705 .13209 .46101 .12456 Metetra
0 .023 .121 r
.46101 .12456 .46705 .13209 .47767 .12802 .47166 .12046 Metetra
0 .023 .121 r
.47166 .12046 .47767 .12802 .48834 .12393 .48236 .11634 Metetra
0 .023 .121 r
.48236 .11634 .48834 .12393 .49905 .11982 .4931 .1122 Metetra
0 .023 .121 r
.4931 .1122 .49905 .11982 .50981 .1157 .50388 .10805 Metetra
0 .023 .121 r
.50388 .10805 .50981 .1157 .5206 .11157 .5147 .10388 Metetra
0 .023 .121 r
.5147 .10388 .5206 .11157 .53144 .10741 .52557 .0997 Metetra
0 .023 .121 r
.52557 .0997 .53144 .10741 .54232 .10324 .53648 .0955 Metetra
0 .023 .121 r
.53648 .0955 .54232 .10324 .55324 .09906 .54743 .09128 Metetra
0 .023 .121 r
.54743 .09128 .55324 .09906 .56421 .09485 .55842 .08705 Metetra
0 .023 .121 r
.55842 .08705 .56421 .09485 .57522 .09063 .56946 .0828 Metetra
0 .023 .121 r
.56946 .0828 .57522 .09063 .58628 .0864 .58055 .07853 Metetra
0 .023 .121 r
.58055 .07853 .58628 .0864 .59737 .08214 .59168 .07425 Metetra
0 .023 .121 r
.59168 .07425 .59737 .08214 .60852 .07787 .60285 .06994 Metetra
0 .023 .121 r
.60285 .06994 .60852 .07787 .61971 .07358 .61407 .06562 Metetra
0 .023 .121 r
.61407 .06562 .61971 .07358 .63094 .06928 .62533 .06129 Metetra
0 .023 .121 r
.62533 .06129 .63094 .06928 .64222 .06496 .63664 .05693 Metetra
0 .023 .121 r
.63664 .05693 .64222 .06496 .65354 .06062 .64799 .05256 Metetra
0 .023 .121 r
.64799 .05256 .65354 .06062 .66491 .05626 .65939 .04817 Metetra
0 .023 .121 r
.65939 .04817 .66491 .05626 .67632 .05189 .67084 .04376 Metetra
0 .023 .121 r
.67084 .04376 .67632 .05189 .68778 .04749 .68233 .03934 Metetra
0 .023 .121 r
.68233 .03934 .68778 .04749 .69929 .04308 .69387 .03489 Metetra
0 .023 .121 r
.69387 .03489 .69929 .04308 .71085 .03865 .70546 .03043 Metetra
0 .023 .121 r
.05044 .27347 .05742 .27996 .06655 .27645 .05959 .26993 Metetra
0 .023 .121 r
.05959 .26993 .06655 .27645 .07571 .27292 .06877 .26637 Metetra
0 .023 .121 r
.06877 .26637 .07571 .27292 .08491 .26938 .07798 .26281 Metetra
0 .023 .121 r
.07798 .26281 .08491 .26938 .09414 .26583 .08723 .25923 Metetra
0 .023 .121 r
.08723 .25923 .09414 .26583 .1034 .26226 .09651 .25564 Metetra
0 .023 .121 r
.09651 .25564 .1034 .26226 .1127 .25868 .10583 .25204 Metetra
0 .023 .121 r
.10583 .25204 .1127 .25868 .12203 .25509 .11518 .24842 Metetra
0 .023 .121 r
.11518 .24842 .12203 .25509 .13139 .25148 .12456 .24479 Metetra
0 .023 .121 r
.12456 .24479 .13139 .25148 .14079 .24786 .13398 .24114 Metetra
0 .023 .121 r
.13398 .24114 .14079 .24786 .15023 .24423 .14344 .23749 Metetra
0 .023 .121 r
.14344 .23749 .15023 .24423 .1597 .24058 .15293 .23381 Metetra
0 .023 .121 r
.15293 .23381 .1597 .24058 .1692 .23692 .16245 .23013 Metetra
0 .023 .121 r
.16245 .23013 .1692 .23692 .17874 .23325 .17201 .22643 Metetra
0 .023 .121 r
.17201 .22643 .17874 .23325 .18832 .22956 .18161 .22272 Metetra
0 .023 .121 r
.18161 .22272 .18832 .22956 .19793 .22586 .19124 .21899 Metetra
0 .023 .121 r
.19124 .21899 .19793 .22586 .20758 .22215 .20091 .21525 Metetra
0 .023 .121 r
.20091 .21525 .20758 .22215 .21726 .21842 .21061 .2115 Metetra
0 .023 .121 r
.21061 .2115 .21726 .21842 .22698 .21468 .22035 .20773 Metetra
0 .023 .121 r
.22035 .20773 .22698 .21468 .23673 .21092 .23013 .20395 Metetra
0 .023 .121 r
.23013 .20395 .23673 .21092 .24653 .20715 .23994 .20015 Metetra
0 .023 .121 r
.23994 .20015 .24653 .20715 .25635 .20336 .24979 .19634 Metetra
0 .023 .121 r
.24979 .19634 .25635 .20336 .26622 .19956 .25968 .19251 Metetra
0 .023 .121 r
.25968 .19251 .26622 .19956 .27612 .19575 .2696 .18867 Metetra
0 .023 .121 r
.2696 .18867 .27612 .19575 .28607 .19192 .27957 .18482 Metetra
0 .023 .121 r
.27957 .18482 .28607 .19192 .29604 .18808 .28957 .18095 Metetra
0 .023 .121 r
.28957 .18095 .29604 .18808 .30606 .18422 .29961 .17706 Metetra
0 .023 .121 r
.29961 .17706 .30606 .18422 .31612 .18035 .30969 .17317 Metetra
0 .023 .121 r
.30969 .17317 .31612 .18035 .32621 .17647 .3198 .16925 Metetra
0 .023 .121 r
.3198 .16925 .32621 .17647 .33634 .17257 .32996 .16533 Metetra
0 .023 .121 r
.32996 .16533 .33634 .17257 .34651 .16865 .34015 .16138 Metetra
0 .023 .121 r
.34015 .16138 .34651 .16865 .35672 .16475 .35038 .15745 Metetra
0 .024 .122 r
.35038 .15745 .35672 .16475 .36697 .1608 .36066 .15348 Metetra
0 .023 .121 r
.36066 .15348 .36697 .1608 .37726 .15681 .37097 .14946 Metetra
0 .023 .121 r
.37097 .14946 .37726 .15681 .38758 .15283 .38132 .14545 Metetra
0 .023 .121 r
.38132 .14545 .38758 .15283 .39795 .14884 .39172 .14143 Metetra
0 .023 .121 r
.39172 .14143 .39795 .14884 .40836 .14483 .40215 .13739 Metetra
0 .023 .121 r
.40215 .13739 .40836 .14483 .41881 .14081 .41262 .13334 Metetra
0 .023 .121 r
.41262 .13334 .41881 .14081 .4293 .13677 .42314 .12927 Metetra
0 .023 .121 r
.42314 .12927 .4293 .13677 .43983 .13272 .43369 .12519 Metetra
0 .023 .121 r
.43369 .12519 .43983 .13272 .4504 .12865 .44429 .12109 Metetra
0 .023 .121 r
.44429 .12109 .4504 .12865 .46101 .12456 .45493 .11697 Metetra
0 .023 .121 r
.45493 .11697 .46101 .12456 .47166 .12046 .46561 .11284 Metetra
0 .023 .121 r
.46561 .11284 .47166 .12046 .48236 .11634 .47633 .10869 Metetra
0 .023 .121 r
.47633 .10869 .48236 .11634 .4931 .1122 .4871 .10453 Metetra
0 .023 .121 r
.4871 .10453 .4931 .1122 .50388 .10805 .49791 .10035 Metetra
0 .023 .121 r
.49791 .10035 .50388 .10805 .5147 .10388 .50876 .09615 Metetra
0 .023 .121 r
.50876 .09615 .5147 .10388 .52557 .0997 .51965 .09193 Metetra
0 .023 .121 r
.51965 .09193 .52557 .0997 .53648 .0955 .53059 .0877 Metetra
0 .023 .121 r
.53059 .0877 .53648 .0955 .54743 .09128 .54157 .08345 Metetra
0 .023 .121 r
.54157 .08345 .54743 .09128 .55842 .08705 .55259 .07919 Metetra
0 .023 .121 r
.55259 .07919 .55842 .08705 .56946 .0828 .56366 .07491 Metetra
0 .023 .121 r
.56366 .07491 .56946 .0828 .58055 .07853 .57478 .07061 Metetra
0 .023 .121 r
.57478 .07061 .58055 .07853 .59168 .07425 .58593 .06629 Metetra
0 .023 .121 r
.58593 .06629 .59168 .07425 .60285 .06994 .59714 .06196 Metetra
0 .023 .121 r
.59714 .06196 .60285 .06994 .61407 .06562 .60838 .0576 Metetra
0 .023 .121 r
.60838 .0576 .61407 .06562 .62533 .06129 .61968 .05323 Metetra
0 .023 .121 r
.61968 .05323 .62533 .06129 .63664 .05693 .63102 .04885 Metetra
0 .023 .121 r
.63102 .04885 .63664 .05693 .64799 .05256 .6424 .04444 Metetra
0 .023 .121 r
.6424 .04444 .64799 .05256 .65939 .04817 .65383 .04002 Metetra
0 .023 .121 r
.65383 .04002 .65939 .04817 .67084 .04376 .66531 .03558 Metetra
0 .023 .121 r
.66531 .03558 .67084 .04376 .68233 .03934 .67684 .03112 Metetra
0 .023 .121 r
.67684 .03112 .68233 .03934 .69387 .03489 .68841 .02664 Metetra
0 .023 .121 r
.68841 .02664 .69387 .03489 .70546 .03043 .70003 .02215 Metetra
0 .023 .121 r
.04341 .26692 .05044 .27347 .05959 .26993 .05258 .26336 Metetra
0 .023 .121 r
.05258 .26336 .05959 .26993 .06877 .26637 .06178 .25978 Metetra
0 .023 .121 r
.06178 .25978 .06877 .26637 .07798 .26281 .07101 .25619 Metetra
0 .023 .121 r
.07101 .25619 .07798 .26281 .08723 .25923 .08028 .25259 Metetra
0 .023 .121 r
.08028 .25259 .08723 .25923 .09651 .25564 .08958 .24898 Metetra
0 .023 .121 r
.08958 .24898 .09651 .25564 .10583 .25204 .09891 .24535 Metetra
0 .023 .121 r
.09891 .24535 .10583 .25204 .11518 .24842 .10828 .24171 Metetra
0 .023 .121 r
.10828 .24171 .11518 .24842 .12456 .24479 .11768 .23805 Metetra
0 .023 .121 r
.11768 .23805 .12456 .24479 .13398 .24114 .12712 .23438 Metetra
0 .023 .121 r
.12712 .23438 .13398 .24114 .14344 .23749 .1366 .2307 Metetra
0 .023 .121 r
.1366 .2307 .14344 .23749 .15293 .23381 .14611 .227 Metetra
0 .023 .121 r
.14611 .227 .15293 .23381 .16245 .23013 .15565 .22329 Metetra
0 .023 .121 r
.15565 .22329 .16245 .23013 .17201 .22643 .16523 .21957 Metetra
0 .023 .121 r
.16523 .21957 .17201 .22643 .18161 .22272 .17485 .21583 Metetra
0 .023 .121 r
.17485 .21583 .18161 .22272 .19124 .21899 .1845 .21208 Metetra
0 .023 .121 r
.1845 .21208 .19124 .21899 .20091 .21525 .19419 .20831 Metetra
0 .023 .121 r
.19419 .20831 .20091 .21525 .21061 .2115 .20391 .20453 Metetra
0 .023 .121 r
.20391 .20453 .21061 .2115 .22035 .20773 .21367 .20073 Metetra
0 .023 .121 r
.21367 .20073 .22035 .20773 .23013 .20395 .22347 .19693 Metetra
0 .023 .121 r
.22347 .19693 .23013 .20395 .23994 .20015 .23331 .1931 Metetra
0 .023 .121 r
.23331 .1931 .23994 .20015 .24979 .19634 .24318 .18926 Metetra
0 .023 .121 r
.24318 .18926 .24979 .19634 .25968 .19251 .25309 .18541 Metetra
0 .023 .121 r
.25309 .18541 .25968 .19251 .2696 .18867 .26304 .18155 Metetra
0 .023 .121 r
.26304 .18155 .2696 .18867 .27957 .18482 .27303 .17766 Metetra
0 .023 .121 r
.27303 .17766 .27957 .18482 .28957 .18095 .28305 .17377 Metetra
0 .023 .121 r
.28305 .17377 .28957 .18095 .29961 .17706 .29311 .16986 Metetra
0 .023 .121 r
.29311 .16986 .29961 .17706 .30969 .17317 .30321 .16593 Metetra
0 .023 .121 r
.30321 .16593 .30969 .17317 .3198 .16925 .31335 .16199 Metetra
0 .023 .121 r
.31335 .16199 .3198 .16925 .32996 .16533 .32353 .15803 Metetra
0 .023 .121 r
.32353 .15803 .32996 .16533 .34015 .16138 .33375 .15406 Metetra
0 .023 .122 r
.33375 .15406 .34015 .16138 .35038 .15745 .344 .15013 Metetra
0 .024 .122 r
.344 .15013 .35038 .15745 .36066 .15348 .3543 .14612 Metetra
0 .023 .122 r
.3543 .14612 .36066 .15348 .37097 .14946 .36464 .14206 Metetra
0 .023 .121 r
.36464 .14206 .37097 .14946 .38132 .14545 .37502 .13802 Metetra
0 .023 .121 r
.37502 .13802 .38132 .14545 .39172 .14143 .38544 .13397 Metetra
0 .023 .121 r
.38544 .13397 .39172 .14143 .40215 .13739 .3959 .1299 Metetra
0 .023 .121 r
.3959 .1299 .40215 .13739 .41262 .13334 .4064 .12582 Metetra
0 .023 .121 r
.4064 .12582 .41262 .13334 .42314 .12927 .41694 .12172 Metetra
0 .023 .121 r
.41694 .12172 .42314 .12927 .43369 .12519 .42752 .11761 Metetra
0 .023 .121 r
.42752 .11761 .43369 .12519 .44429 .12109 .43814 .11348 Metetra
0 .023 .121 r
.43814 .11348 .44429 .12109 .45493 .11697 .44881 .10933 Metetra
0 .023 .121 r
.44881 .10933 .45493 .11697 .46561 .11284 .45951 .10517 Metetra
0 .023 .121 r
.45951 .10517 .46561 .11284 .47633 .10869 .47026 .10099 Metetra
0 .023 .121 r
.47026 .10099 .47633 .10869 .4871 .10453 .48106 .09679 Metetra
0 .023 .121 r
.48106 .09679 .4871 .10453 .49791 .10035 .49189 .09258 Metetra
0 .023 .121 r
.49189 .09258 .49791 .10035 .50876 .09615 .50277 .08835 Metetra
0 .023 .121 r
.50277 .08835 .50876 .09615 .51965 .09193 .51369 .08411 Metetra
0 .023 .121 r
.51369 .08411 .51965 .09193 .53059 .0877 .52466 .07985 Metetra
0 .023 .121 r
.52466 .07985 .53059 .0877 .54157 .08345 .53567 .07557 Metetra
0 .023 .121 r
.53567 .07557 .54157 .08345 .55259 .07919 .54672 .07127 Metetra
0 .023 .121 r
.54672 .07127 .55259 .07919 .56366 .07491 .55782 .06695 Metetra
0 .023 .121 r
.55782 .06695 .56366 .07491 .57478 .07061 .56896 .06262 Metetra
0 .023 .121 r
.56896 .06262 .57478 .07061 .58593 .06629 .58015 .05827 Metetra
0 .023 .121 r
.58015 .05827 .58593 .06629 .59714 .06196 .59138 .05391 Metetra
0 .023 .121 r
.59138 .05391 .59714 .06196 .60838 .0576 .60266 .04952 Metetra
0 .023 .121 r
.60266 .04952 .60838 .0576 .61968 .05323 .61399 .04512 Metetra
0 .023 .121 r
.61399 .04512 .61968 .05323 .63102 .04885 .62536 .0407 Metetra
0 .023 .121 r
.62536 .0407 .63102 .04885 .6424 .04444 .63677 .03626 Metetra
0 .023 .121 r
.63677 .03626 .6424 .04444 .65383 .04002 .64824 .03181 Metetra
0 .023 .121 r
.64824 .03181 .65383 .04002 .66531 .03558 .65975 .02733 Metetra
0 .023 .121 r
.65975 .02733 .66531 .03558 .67684 .03112 .6713 .02284 Metetra
0 .023 .121 r
.6713 .02284 .67684 .03112 .68841 .02664 .68291 .01833 Metetra
0 .023 .121 r
.68291 .01833 .68841 .02664 .70003 .02215 .69456 .0138 Metetra
0 .023 .121 r
.03634 .26033 .04341 .26692 .05258 .26336 .04552 .25675 Metetra
0 .023 .121 r
.04552 .25675 .05258 .26336 .06178 .25978 .05474 .25315 Metetra
0 .023 .121 r
.05474 .25315 .06178 .25978 .07101 .25619 .06399 .24953 Metetra
0 .023 .121 r
.06399 .24953 .07101 .25619 .08028 .25259 .07327 .24591 Metetra
0 .023 .121 r
.07327 .24591 .08028 .25259 .08958 .24898 .08259 .24227 Metetra
0 .023 .121 r
.08259 .24227 .08958 .24898 .09891 .24535 .09195 .23861 Metetra
0 .023 .121 r
.09195 .23861 .09891 .24535 .10828 .24171 .10134 .23495 Metetra
0 .023 .121 r
.10134 .23495 .10828 .24171 .11768 .23805 .11076 .23126 Metetra
0 .023 .121 r
.11076 .23126 .11768 .23805 .12712 .23438 .12022 .22757 Metetra
0 .023 .121 r
.12022 .22757 .12712 .23438 .1366 .2307 .12971 .22386 Metetra
0 .023 .121 r
.12971 .22386 .1366 .2307 .14611 .227 .13924 .22014 Metetra
0 .023 .121 r
.13924 .22014 .14611 .227 .15565 .22329 .1488 .2164 Metetra
0 .023 .121 r
.1488 .2164 .15565 .22329 .16523 .21957 .1584 .21265 Metetra
0 .023 .121 r
.1584 .21265 .16523 .21957 .17485 .21583 .16804 .20889 Metetra
0 .023 .121 r
.16804 .20889 .17485 .21583 .1845 .21208 .17771 .20511 Metetra
0 .023 .121 r
.17771 .20511 .1845 .21208 .19419 .20831 .18742 .20132 Metetra
0 .023 .121 r
.18742 .20132 .19419 .20831 .20391 .20453 .19717 .19751 Metetra
0 .023 .121 r
.19717 .19751 .20391 .20453 .21367 .20073 .20695 .19369 Metetra
0 .023 .121 r
.20695 .19369 .21367 .20073 .22347 .19693 .21677 .18986 Metetra
0 .023 .121 r
.21677 .18986 .22347 .19693 .23331 .1931 .22663 .18601 Metetra
0 .023 .121 r
.22663 .18601 .23331 .1931 .24318 .18926 .23652 .18214 Metetra
0 .023 .121 r
.23652 .18214 .24318 .18926 .25309 .18541 .24646 .17826 Metetra
0 .023 .121 r
.24646 .17826 .25309 .18541 .26304 .18155 .25643 .17437 Metetra
0 .023 .121 r
.25643 .17437 .26304 .18155 .27303 .17766 .26644 .17046 Metetra
0 .023 .121 r
.26644 .17046 .27303 .17766 .28305 .17377 .27648 .16653 Metetra
0 .023 .121 r
.27648 .16653 .28305 .17377 .29311 .16986 .28657 .16259 Metetra
0 .023 .121 r
.28657 .16259 .29311 .16986 .30321 .16593 .29669 .15864 Metetra
0 .023 .121 r
.29669 .15864 .30321 .16593 .31335 .16199 .30686 .15467 Metetra
0 .023 .121 r
.30686 .15467 .31335 .16199 .32353 .15803 .31706 .15068 Metetra
0 .023 .121 r
.31706 .15068 .32353 .15803 .33375 .15406 .3273 .14668 Metetra
0 .023 .121 r
.3273 .14668 .33375 .15406 .344 .15013 .33758 .14267 Metetra
0 .024 .122 r
.33758 .14267 .344 .15013 .3543 .14612 .3479 .13864 Metetra
0 .023 .121 r
.3479 .13864 .3543 .14612 .36464 .14206 .35827 .13459 Metetra
0 .023 .121 r
.35827 .13459 .36464 .14206 .37502 .13802 .36867 .13053 Metetra
0 .023 .121 r
.36867 .13053 .37502 .13802 .38544 .13397 .37911 .12645 Metetra
0 .023 .121 r
.37911 .12645 .38544 .13397 .3959 .1299 .3896 .12235 Metetra
0 .023 .121 r
.3896 .12235 .3959 .1299 .4064 .12582 .40012 .11824 Metetra
0 .023 .121 r
.40012 .11824 .4064 .12582 .41694 .12172 .41069 .11411 Metetra
0 .023 .121 r
.41069 .11411 .41694 .12172 .42752 .11761 .4213 .10997 Metetra
0 .023 .121 r
.4213 .10997 .42752 .11761 .43814 .11348 .43195 .10581 Metetra
0 .023 .121 r
.43195 .10581 .43814 .11348 .44881 .10933 .44264 .10163 Metetra
0 .023 .121 r
.44264 .10163 .44881 .10933 .45951 .10517 .45337 .09744 Metetra
0 .023 .121 r
.45337 .09744 .45951 .10517 .47026 .10099 .46415 .09323 Metetra
0 .023 .121 r
.46415 .09323 .47026 .10099 .48106 .09679 .47497 .08901 Metetra
0 .023 .121 r
.47497 .08901 .48106 .09679 .49189 .09258 .48583 .08476 Metetra
0 .023 .121 r
.48583 .08476 .49189 .09258 .50277 .08835 .49674 .0805 Metetra
0 .023 .121 r
.49674 .0805 .50277 .08835 .51369 .08411 .50769 .07623 Metetra
0 .023 .121 r
.50769 .07623 .51369 .08411 .52466 .07985 .51868 .07193 Metetra
0 .023 .121 r
.51868 .07193 .52466 .07985 .53567 .07557 .52972 .06762 Metetra
0 .023 .121 r
.52972 .06762 .53567 .07557 .54672 .07127 .5408 .06329 Metetra
0 .023 .121 r
.5408 .06329 .54672 .07127 .55782 .06695 .55193 .05894 Metetra
0 .023 .121 r
.55193 .05894 .55782 .06695 .56896 .06262 .5631 .05458 Metetra
0 .023 .121 r
.5631 .05458 .56896 .06262 .58015 .05827 .57432 .0502 Metetra
0 .023 .121 r
.57432 .0502 .58015 .05827 .59138 .05391 .58558 .0458 Metetra
0 .023 .121 r
.58558 .0458 .59138 .05391 .60266 .04952 .59689 .04138 Metetra
0 .023 .121 r
.59689 .04138 .60266 .04952 .61399 .04512 .60825 .03695 Metetra
0 .023 .121 r
.60825 .03695 .61399 .04512 .62536 .0407 .61965 .03249 Metetra
0 .023 .121 r
.61965 .03249 .62536 .0407 .63677 .03626 .6311 .02802 Metetra
0 .023 .121 r
.6311 .02802 .63677 .03626 .64824 .03181 .64259 .02353 Metetra
0 .023 .121 r
.64259 .02353 .64824 .03181 .65975 .02733 .65414 .01902 Metetra
0 .023 .121 r
.65414 .01902 .65975 .02733 .6713 .02284 .66573 .0145 Metetra
0 .023 .121 r
.66573 .0145 .6713 .02284 .68291 .01833 .67736 .00995 Metetra
0 .023 .121 r
.67736 .00995 .68291 .01833 .69456 .0138 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09773 .23142 m
.10243 .236 L
s
[(-0.05)] .08833 .22227 1 .97329 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61334 .02952 m
.61709 .03491 L
s
[(0.05)] .60583 .01876 .69702 1 Mshowa
.125 Mabswid
.14497 .21292 m
.14774 .21571 L
s
.1931 .19408 m
.19582 .19692 L
s
.24214 .17487 m
.24481 .17776 L
s
.29212 .1553 m
.29474 .15824 L
s
.39501 .11502 m
.39752 .11805 L
s
.44797 .09427 m
.45043 .09735 L
s
.502 .07312 m
.50439 .07625 L
s
.55711 .05154 m
.55943 .05472 L
s
.05135 .24958 m
.05422 .25228 L
s
.67072 .00705 m
.6729 .01033 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Voooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0001aoooo
o`00V_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooooooo`1^ooooo`00V_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0K_ooool009[ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo06kooooo002Jooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0001;ooooo0_l0001Moooo
o`00V_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00004_oo
ool5o`0005gooooo002Kooooo`;o00002_ooool2o`0000;ooooo1Ol0000<ooooo`Go000000?o00DN
o`000?l00000G?ooool00;Wooooo1Ol00002o`057P03o`000?l01Ako000000?o0000F_ooool00;Ko
oooo1_l000001?l01Ako0000o`057_l01Ah3o`000003o`057_l0003ooooo05[ooooo002dooooo`;o
00000_ooool00ol0003o00DNo`000002o`057P?o000000Co00DNo`000?l0003o00DN0_l0001Joooo
o`00/Oooool3o`0000;ooooo0_l00003o`057P;o000000Co00DNo`000?l01Ako00DN0ol00002o`05
7P03o`000?oooooooooo05Oooooo002_ooooo`;o00000_ooool3o`000004o`057_l0003o00DNo`05
7P;o00000_l01Ah3o`000003o`057_l0003o000000;o00DN0_l0001Hooooo`00[?ooool3o`000006
ooooool0003o0000o`000?l01Ako00000_l01Ah3o`000006o`057_l0003o00DNo`000?l01Ako0000
0_l01Ah4o`000003o`057_l0003ooooo00gooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`?o0000=_ooool00:[ooooo0_l000001_oooooo0000o`000?l0003o00DNo`0000;o
00DN0ol00002o`057P04o`000?l01Ako0000o`0000?o00DN00?o0000o`057_l000000_l00002o`05
7P;o00003?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0cooooo`00Yoooool6o`000004o`057_l0003o00DNo`057P?o0000
0_l01Ah00ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l01Ah00_l000000ol01Ako0000
o`000002o`000003o`057_l0003ooooo00Cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0cooooo`00Y?ooool6o`0000;o
00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako00DN00?o000000Co00DNo`000?l0
1Ako00DN0ol000001_l01Ako0000o`057_l0003o00DNo`0000;o00DN0_l0000;ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0cooooo`00
X_ooool5o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako00DN00?o0000
00Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`0000;o00DN0_l00002o`05
7P03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0
003ooooo00Co0000=_ooool009oooooo1Ol00002o`057P03o`000?l01Ako00DN00?o000000Co00DN
o`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o
000000Co00DNo`000?l0003o00DN0_l00003o`057P;o00002Oooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo0000>Oooool009gooooo0_l00002ooooo`03o`000?l0
1Ako000000;o00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o
000000Co00DNo`000?l01Ako00DN0ol00002o`057P03o`000?l01Ako000000;o00000_l01Ah01Ol0
003o00DNo`000?l01Ako000000[ooooo0_l0000:ooooo`;o00000_ooool5o`0003Gooooo002Joooo
o`?o00000_ooool2o`0000;o00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o
00DNo`057P?o00000_l01Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l01Ah00_l0
00000ol01Ako0000o`000002o`057P;o00000ol01Ah00ol0003oooooooooo`1Aooooo`00Uoooool3
o`0000;ooooo0ol000001?l01Ako0000o`057_l00002o`057P03o`000?l01Ako000000;o00000_l0
1Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l0
1Ako00DN00?o000000?o00DNo`000?l01Ah01?l000001?l01Ako0000o`057_l01Ah2o`0005?ooooo
002Eooooo`;o00000_ooool3o`000004o`057_l0003o00DNo`057P;o00000ol01Ah2o`0000;o00DN
00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako00DN00?o000000Co00DNo`000?l01Ako
00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000?o00DN
o`000?l00000D_ooool009;ooooo0ol000001?oooooo0000o`000?l00002o`057P03o`000?l01Ako
000000;o00000_l01Ah01Ol0003o00DNo`000?l01Ako000000;o00DN0ol000001?l01Ako0000o`05
7_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l0
1Ako0000o`000?l01Ah3o`000004o`057_l0003o00DNo`057P?o0000DOooool0093ooooo0_l00002
ooooo`;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l01Ah00_l00002
o`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`05
7_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol00002o`057P03o`000?l01Ako0000
00;o00000_l01Ah00ol0003oooooooooo`1?ooooo`00SOooool3o`000006ooooool0003o0000o`00
0?l01Ako00000_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Ko00DNo`000?l01Ako0000
o`057_l00002o`057P?o000000Co00DNo`000?l01Ako00DN0ol00002o`057P03o`000?l01Ako0000
00;o00000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o000000;o00DN0_l00002o`05
7P03o`000?l01Ako00DN00;o0000D?ooool008_ooooo0_l000001_oooooo0000o`000?l0003o00DN
o`0000;o00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P;o0000
0ol01Ah2o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako00DN00;o0000
0_l01Ah00ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l000000ol000001?l01Ako0000
o`057_l01Ah3o`000003o`057_l0003ooooo04oooooo0028ooooo`Ko00000_l01Ah00ol0003o00DN
o`000002o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako000000;o0000
0_l01Ah01Ol0003o00DNo`000?l01Ako000000;o00DN0_l00002o`057P03o`000?l01Ako00DN00?o
000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o
00DNo`057P?o000000Co00DNo`000?l01Ako00DN0_l0001?ooooo`00IOooool2o`0001kooooo0ol0
00000ooooooo0000o`000002o`057P03o`000?l01Ako00DN00;o00000_l01Ah00ol0003o00DNo`05
7P02o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako00DN00;o00000_l0
1Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako
0000o`057_l01Ah3o`000004o`057_l0003o0000o`057P?o000000Co00DNo`000?l01Ako00DN0ol0
00001?l01Ako0000o`000?l0001=ooooo`00I?ooool01?l0003oooooooooool0000Kooooo`;o0000
00Koooooo`000?l0003o0000o`057_l00002o`057P?o000000Co00DNo`000?l01Ako00DN0ol00000
1?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Ko00DNo`000?l01Ako
0000o`057_l00002o`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l0
1Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako
0000o`057_l01Ah3o`0004gooooo001Tooooo`04o`000?ooooooooooo`0001Sooooo1_l000001?l0
1Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN
0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`00
0?l0003o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P?o000000Co
00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`000?l01Ah3o`0000;o00DN00?o0000o`057_l0
00000_l00002o`057P;o0000C?ooool006Cooooo00Co0000oooooooooooo00005_ooool5o`0000;o
00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako000000;o00000_l01Ah00ol0003o
00DNo`000002o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako000000;o
00000_l01Ah2o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako000000;o
00000_l01Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03
o`000?l01Ako00DN00;o00000_l01Ah01Ol0003o00DNo`000?l01Ako000004cooooo001Tooooo`04
o`000?ooooooooooo`0001?ooooo1Ol00002o`057P03o`000?l01Ako00DN00;o00000_l01Ah00ol0
003o00DNo`057P02o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako00DN
00;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN00Go0000o`057_l0003o00DNo`000002
o`057P?o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako00DN00;o00000_l0
1Ah00ol0003o00DNo`057P02o`000003o`057_l0003o000000;o00DN0ol000001?l01Ako0000o`05
7_l01Ah2o`0000;o00DN0_l0001;ooooo`00I?ooool01?l0003oooooooooool0000Aooooo`Go0000
00Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DN
o`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`05
7_l0003o00DNo`057P;o00000_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`00
0?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000003o`057_l0003o00DN00Co000000Co
00DNo`000?l01Ako00DN0ol000001_l01Ako0000o`000?l0003o00DNo`0004_ooooo001Uooooo`;o
00003oooool5o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3o`00
0004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`05
7_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Ko00DNo`000?l0003o0000o`057_l00002
o`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`05
7_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol000001_l01Ako0000o`057_l0003o
00DNo`0000;o00DN0_l0001:ooooo`00Loooool3o`0000;ooooo0ol00002o`057P;o00000_l01Ah0
0ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako
000000;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P?o00000_l0
1Ah2o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako000000;o000000Co
00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o0000o`05
7P?o000000Co00DNo`000?l01Ako00DN0_l00002o`057P?o000000?o00DNo`000?ooool0BOooool0
077ooooo0_l00003ooooo`;o00000_l01Ah3o`000004o`057_l0003o00DNo`057P;o00000_l01Ah0
0ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako
00DN00;o00000_l01Ah00ol0003o00DNo`000002o`0000;o00DN00Go0000o`057_l0003o00DNo`00
0002o`057P;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l000000_l0
0002o`057P03o`000?l01Ako000000;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0
003o00DNo`057P?o000000Ko00DNo`000?l0003o0000o`057_l00002o`057P;o0000BOooool006ko
oooo0ol00002ooooo`?o00000_l01Ah2o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`00
0?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o0000
00Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako00DN00;o00000_l01Ah3o`000004
o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako
00DN00;o00000_l01Ah00ol0003o00DNo`057P02o`000004o`057_l0003o0000o`057P?o00000_l0
1Ah2o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?oooooooooo04Kooooo001/
ooooo`;o00000_ooool3o`0000;o00DN00Ko0000o`057_l0003o00DNo`000?l01Ah3o`0000;o00DN
00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako
00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Ko00DN
o`000?l0003o0000o`057_l00002o`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako
0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000?o00DNo`000?l01Ah00ol00002
o`057P05o`000?l01Ako0000o`057_l000000_l01Ah2o`0000;o00DN00?o0000o`057_l01Ah00_l0
0017ooooo`00JOooool3o`0000;ooooo0_l00002o`057P03o`000?l01Ako00DN00;o00000_l01Ah2
o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako00DN00;o00000_l01Ah0
0ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako
000000;o000000Co00DNo`000?l0003o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0
003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`00
0004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0_l00002o`057P?o000000Co
00DNo`000?l01Ako00DN0ol000000ol01Ako0000ooooo`16ooooo`00I_ooool3o`0000;ooooo0ol0
00001?l01Ako0000o`057_l01Ah3o`000006o`057_l0003o0000o`000?l01Ako00000_l01Ah3o`00
0004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l0
1Ako00DN00;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN0_l00002o`057P03o`000?l0
1Ako00DN00;o00000_l01Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l000000_l0
00001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l0
003o00DN0ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0ol000001?l01Ako0000o`05
7_l01Ah2o`0004Kooooo001Tooooo`;o00000_ooool3o`0000;o00HO00?o0000o`057_l000000_l0
0002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l000000_l0
00001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l0
1Ako00DN0ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0ol000001?l01Ako0000o`05
7_l01Ah2o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako000000;o0000
0_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P?o000000Ko00DNo`000?l0
003o0000o`057_l00002o`057P?o000000Co00DNo`000?l01Ako00DN0ol000000ol01Ako0000oooo
o`15ooooo`00HOooool3o`0000;ooooo0_l00002o`057P03o`000?l01Qoo00HO00;o00000_l01Al3
o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN00?o
0000o`057_l000000_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN
0ol000001_l01Ako0000o`057_l0003o00DNo`0000;o00DN0ol000001?l01Ako0000o`057_l01Ah3
o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`00
0?l01Ako00DN00;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o0000o`0000;o
00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DN
o`057P;o0000AOooool005oooooo0_l00002ooooo`?o000000Co00DNo`000?l01Ako00DN0ol00000
1?l01Qoo0000o`000?l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN
0ol000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03
o`000?l01Ako000000;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o0000o`00
00;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o
00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah2o`0000;o
00DN0ol000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l0
1Ako0000o`057_l01Ah3o`000003o`057_l0003o000004Cooooo001Looooo`?o00000_ooool2o`00
00;o00DN00?o0000o`057_l000000_l00002o`057`;o00000_l01Ql00ol0003o00DNo`057P02o`00
00;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o
00DNo`057P?o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako00DN00;o0000
0_l01Ah2o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako000000;o0000
00Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DN
o`057P?o000000Go00DNo`000?l0003o0000o`057P02o`000006o`057_l0003o0000o`000?l01Ako
00000_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`00
04Cooooo001Jooooo`;o00000_ooool3o`000004o`057_l0003o00DNo`057P?o000000Ko00DNo`00
0?l0003o0000o`057_l00002o`067`?o000000Co00HOo`000?l01Ako00DN0_l00002o`057P03o`00
0?l01Ako000000;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P?o
000000Co00DNo`000?l01Ako00DN0ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0ol0
00001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`00
0?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0ol000001_l01Ako0000o`000?l0003o00DN
o`0000;o00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P;o0000
0_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o000004?ooooo001Gooooo`?o00000_oo
ool2o`0000;o00DN00?o0000o`057_l000000_l00002o`057P;o00000_l01Ah00ol0003o00DNo`00
0002o`000004o`067ol0003o00HOo`067`?o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03
o`000?l01Ako00DN00;o00000_l01Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l0
00000_l000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0ol000001?l01Ako0000o`057_l0
1Ah3o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN
00?o0000o`057_l000000_l000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0ol000001?l0
1Ako0000o`000?l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN
0_l00002o`057P03o`000?l01Ako000000;o0000@_ooool005Cooooo0ol00002ooooo`?o000000Co
00DNo`000?l01Ako00DN0_l00002o`057P?o000000Co00DNo`000?l01Ako00DN0_l00002o`067`03
o`000?l01Qoo000000;o00000_l01Al00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`05
7P?o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako00DN00;o00000_l01Ah2
o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako000000;o000000Co00DN
o`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P;o
00000_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako000000;o
000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o
00DNo`057P;o00000_l01Ah2o`00047ooooo001Booooo`;o00000_ooool3o`0000;o00DN00?o0000
o`057_l000000_l000001?l01Ako0000o`000?l00002o`057P03o`000?l01Ako000000;o000000Co
00DNo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Aoo00DO00;o00000_l01Ah00ol0003o00DN
o`000002o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3o`000006
o`057_l0003o0000o`000?l01Ako00000_l01Ah2o`0000;o00DN00?o0000o`057_l01Ah00_l00002
o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`05
7_l01Ah3o`000006o`057_l0003o0000o`000?l01Ako00000_l01Ah2o`0000;o00DN00?o0000o`05
7_l01Ah00_l000001?l01Ako0000o`000?l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co
00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah2o`00047ooooo001?ooooo`?o0000
0_ooool2o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P;o00000_l01Ah00ol0003o00DN
o`057P02o`0000;o00DN00?o0000o`057_l000000_l000001?l01Aoo0000o`067ol01Ql3o`000004
o`057ol0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN1Ol000001?l0
1Ako0000o`000?l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0ol0
00001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`00
0?l01Ako000000;o000000Ko00DNo`000?l0003o0000o`057_l00002o`057P?o000000Co00DNo`00
0?l01Ako00DN0ol000000ol01Ako0000o`057P03o`0000;o00DN00?o0000o`057_l000000_l00000
1?l01Ako0000o`057_l01Ah3o`000003o`057_l0003o000000Co000000?o00DNo`000?l00000@?oo
ool004gooooo0_l00002ooooo`?o00000_l01Ah00ol0003o00DNo`000002o`000006o`057_l0003o
0000o`000?l01Ako00000_l01Ah3o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o
00DOo`000002o`0000;o00HO00?o0000o`057ol000000_l000001?l01Ako0000o`057_l01Ah3o`00
0006o`057_l0003o0000o`000?l01Ako00000_l01Ah2o`0000;o00DN00?o0000o`057_l01Ah00_l0
0002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000
o`057_l01Ah2o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P;o00000_l01Ah00ol0003o
00DNo`000002o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol00000
1?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001_l01Ako0000o`00
0?l0003o00DNo`0000;o00DN0ol000000ol01Ako0000ooooo`0oooooo`00B_ooool3o`0000;ooooo
0_l00002o`057P03o`000?l01Ako00DN00;o00000_l01Ah2o`0000;o00DN00?o0000o`057_l00000
0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057`03
o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00DNo`000002o`000004o`057_l0003o0000o`00
00;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o
00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P?o0000
00Co00DNo`000?l01Ako00DN0ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l00002
o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`00
0?l01Ah3o`000004o`057_l0003o00DNo`057P;o00000_l01Ah2o`0000;o00DN00?o0000o`057_l0
00000_l000001?l01Ako0000o`057_l01Ah2o`0003oooooo0018ooooo`;o00000_ooool3o`0000;o
00DN00?o0000o`057_l000000_l000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l00002
o`057P03o`000?l01Ako00DN00;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o
00DOo`057`?o000000Co00HOo`000?l01Qoo00HO0_l00002o`057P;o00000_l01Ah00ol0003o00DN
o`057P02o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3o`000004
o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DN
o`057P?o000000Ko00DNo`000?l0003o0000o`057_l00002o`057P?o000000Co00DNo`000?l01Ako
00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0ol000001?l0
1Ako0000o`057_l01Ah3o`000006o`057_l0003o0000o`000?l01Ako00000_l01Ah2o`0000;o00DN
00?o0000o`057_l000000_l000000ol01Ako0000o`00000nooooo`005?ooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000?ooooo0ol0000Mooooo`?o00000_ooool3o`000003o`057_l0
003o000000?o00000_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l0
1Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o0000
0_l01Ql00ol0003o00HOo`000002o`000006o`057ol0003o0000o`000?l01Ako00000_l01Ah3o`00
0004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o
00DNo`057P?o000000Co00DNo`000?l01Ako00DN0_l00002o`057PGo00000_l01Ah2o`0000;o00DN
00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`05
7P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P?o000000Ko00DN
o`000?l0003o0000o`057_l00002o`057P?o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako
0000o`057_l01Ah2o`0003kooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo01Oooooo2?l00002o`057P;o00000_l0
1Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DN
o`057P02o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3o`000004
o`057_l0003o00HOo`067`;o00000_l01Ql2o`0000;o00HO00?o0000o`057_l000000_l000001?l0
1Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`00
0002o`0000;o00DN00?o0000o`057_l000000_l000001_l01Ako0000o`000?l0003o00DNo`0000;o
00DN0ol000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l0
1Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`00
0002o`000006o`057_l0003o0000o`000?l01Ako00000_l01Ah3o`000004o`057_l0003o00DNo`05
7P?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`00000mooooo`003?ooool5o`0000;o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo01Gooooo0_l00003ooooo`?o000000Ko00DNo`000?l0003o0000o`057_l00002o`057P;o0000
0_l01Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000
o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l00002o`057PGo000000Ko00DOo`000?l0
003o0000o`067ol00002o`067`;o00000_l01Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000
o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l01Ah00_l0
0002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P?o0000
00Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l0
1Ako00DN0ol000000ol01Ako0000o`000004o`000003o`057_l0003o000000;o00DN00?o0000o`05
7_l000000_l000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P;o00000_l0
1Ah00ol0003o00DNo`000002o`0003cooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`0Booooo`?o00000_ooool3o`0000;o00DN
0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03
o`000?l01Ako00DN00;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`05
7P;o00000_l01Ah3o`000004o`057_l0003o00DNo`057P;o00000_l01Ql00ol0003o00HOo`000002
o`000004o`067ol0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN00?o
0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3o`000006o`057_l0003o0000o`000?l0
1Ako00000_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3
o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000006o`057_l0
003o0000o`000?l01Ako00000_l01Ah3o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0
003o00DNo`000002o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0_l0
0002o`057P;o0000>oooool001?ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
ool0003ooooo00Co00004oooool2o`000003ooooool0003o000000?o000000Ko00DNo`000?l0003o
0000o`057_l00002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`05
7_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l00000
1?l01Ako0000o`000?l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Qoo00HO
0_l00002o`067`03o`000?l01Qoo000000;o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako
0000o`057_l01Ah2o`0000;o00DN1Ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0ol0
00001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000
o`057_l01Ah3o`000004o`057_l0003o00DNo`057P;o00000_l01Ah2o`0000;o00DN00?o0000o`05
7_l000000_l000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P;o000000Co
00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000003o`057_l0003o000000?o
0000>oooool001?ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0001?ooooo1_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l0
00001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`00
0?l01Ako000000;o000000?o00DNo`000?l000000ol00002o`057P;o00000_l01Ah00ol0003o00DN
o`057P02o`0000;o00DN00?o0000o`057_l000000_l000001?l01Qoo0000o`067ol01Ql2o`0000;o
00HO00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3o`000006o`057_l0003o0000
o`000?l01Ako00000_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`05
7_l01Ah3o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000003
o`057_l0003o000000Co000000Ko00DNo`000?l0003o0000o`057_l00002o`057P;o00000_l01Ah0
0ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P?o000000?o00DNo`000?l01Ah00ol0
00001?l01Ako0000o`057_l01Ah3o`000006o`057_l0003o0000o`000?l01Ako00000_l01Ah2o`00
03[ooooo000Dooooo`;o00002_ooool2o`0000;ooooo1Ol0000<ooooo`?o000000?oooooo`000?l0
00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0
003o00DNo`000002o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2
o`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0ol0
00001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`067ol000000_l000001?l01Qoo0000
o`067ol01Ql2o`0000;o00DN00?o0000o`057_l000000_l00002o`057P;o00000_l01Ah00ol0003o
00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`00
0004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0_l00002o`057P;o00000_l0
1Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako
00DN1?l00002o`057P?o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako0000
00;o000000Ko00DNo`000?l0003o0000o`057_l00002o`057P?o000000?o00DNo`000?ooool02?oo
ool2o`0002oooooo000cooooo`;o000000Koooooo`000?l0003o0000o`057_l00002o`057P;o0000
0_l01Ah00ol0003o00DNo`000002o`0000;o00DN00Co0000o`057_l0003o00000_l01Ah00ol0003o
00DNo`057P02o`0000;o00DN00?o0000o`057_l000000_l000001_l01Ako0000o`000?l0003o00DN
o`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o00000_l01Ah00ol0003o00DNo`000002
o`000004o`057_l0003o00DNo`057P;o00000_l01Ql00ol0003o00HOo`000002o`000003o`067ol0
003o000000?o00000_l01Ah3o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DN
o`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004
o`057_l0003o00DNo`057P?o000000Ko00DNo`000?l0003o0000o`057_l00002o`057P;o00000_l0
1Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P?o000000?o00DNo`000?l01Ah0
0ol000001?l01Ako0000o`057_l01Ah3o`000003o`057_l0003o000000?o00000_l01Ah2o`0000;o
00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000Oooooo00Co0000oooo
oooooooo0000;_ooool0033ooooo0ol000000ooooooo0000o`000002o`057P03o`000?l01Ako0000
00;o00000_l01Ah01?l0003o00DNo`000?l00002o`057P03o`000?l01Ako00DN00;o00000_l01Ah0
0ol0003o00DNo`000002o`000003o`057_l0003o000000?o00000_l01Ah2o`0000;o00DN00?o0000
o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l01Ah00_l0
0002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Qoo00HO0_l00002o`067`;o0000
0_l01Ql00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l0
1Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002
o`057PGo000000Ko00DNo`000?l0003o0000o`057_l00002o`057P?o000000Co00DNo`000?l01Ako
00DN0_l000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000?o00DN
o`000?l01Ah00ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0ol000001?l01Ako0000
o`057_l01Ah2o`000004o`057_l0003o00DNo`057P?o000000?o00DNo`000?ooool01_ooool01?l0
003oooooooooool0000^ooooo`00;_ooool2o`000004ooooool0003o0000o`0000;o00DN00Co0000
o`057_l0003o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l000000_l0
00001?l01Ako0000o`057_l01Ah2o`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o0000
00Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o00000_l01Ah00ol0003o
00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah5o`000006o`067ol0003o0000
o`000?l01Qoo00000_l01Ql2o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`05
7_l01Ah3o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000006
o`057_l0003o0000o`000?l01Ako00000_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l00000
1?l01Ako0000o`057_l01Ah3o`000003o`057_l0003o00DN00?o000000Co00DNo`000?l01Ako00DN
0ol000000ol01Ako0000o`000003o`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o0000
00Co00DNo`000?l01Ako00DN0ol000000ol01Ako0000o`057P03o`000004o`057_l0003o00DNo`05
7P;o00001_ooool01?l0003oooooooooool0000^ooooo`00:oooool3o`000003ooooool0003o0000
00;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`00
0?l01Ako00DN0_l00002o`057PGo000000Ko00DNo`000?l0003o0000o`057_l00002o`057P;o0000
0_l01Ah00ol0003o00DNo`000002o`0000;o00DN00Co0000o`057_l0003o00000_l01Ah00ol0003o
00DNo`057P02o`0000;o00DN00?o0000o`057_l000000_l000001_l01Ako0000o`000?l0003o00DN
o`0000;o00DN0_l00002o`067`03o`000?l01Qoo000000;o000000Co00HOo`000?l01Ako00DN0_l0
0002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0ol000000ol01Ako0000
o`000003o`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako
00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`05
7P03o`000?l01Ako000000;o000000Ko00DNo`000?l0003o0000o`057_l00002o`057P?o000000Co
00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`05
7P;o00000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o000000Gooooo00Co0000oooo
oooooooo0000;_ooool002Wooooo0_l00002ooooo`;o00000_l01Ah00ol0003o00DNo`000002o`00
0004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000006o`057_l0003o
0000o`000?l01Ako00000_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l00002o`057P04o`00
0?l01Ako0000o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako000000;o
000000?o00DNo`000?l000000ol00002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004
o`057_l0003o00HOo`067`;o00000_l01Ql00ol0003o00HOo`000002o`000004o`057_l0003o00DN
o`057P;o00000_l01Ah00ol0003o00DNo`000002o`000006o`057_l0003o0000o`000?l01Ako0000
0_l01Ah3o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`000?l01Ako00DN0ol000001?l0
1Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`000003
o`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0ol0
00000ol01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako
00DN0_l000001_l01Ako0000o`000?l0003o00DNo`0000Gooooo00Co0000oooooooooooo0000;_oo
ool002Kooooo0ol000001_oooooo0000o`000?l0003o00DNo`0000;o00DN0_l00002o`057P03o`00
0?l01Ako000000;o000000?o00DNo`000?l000001?l000000ol01Ako0000o`000002o`057P03o`00
0?l01Ako000000;o00000_l01Ah01?l0003o00DNo`000?l00002o`057P03o`000?l01Ako00DN00;o
00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah2o`00
00;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000
o`057_l000000_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`057_l000000_l0
00000ol01Ako0000o`000003o`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co
00DNo`000?l01Ako00DN0ol000000ol01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P?o
000000Co00DNo`000?l01Ako00DN0_l000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0ol0
00001?l01Ako0000o`057_l01Ah4o`0000;o00DN0ol000001?l01Ako0000o`057_l01Ah2o`0000;o
00DN00?o0000o`057_l000000_l000000ol01Ako0000o`000004o`000003o`057_l0003o000000;o
00DO00?o0000o`057_l000000_l00004ooooo`;o0000;oooool002?ooooo0ol00002ooooo`;o0000
0_l01Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000
o`000002o`057P03o`000?l01Ako00DN00;o00000_l01Ah01?l0003o00DNo`000?l00002o`057P03
o`000?l01Ako00DN00;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`05
7P;o00000_l01Ah5o`000006o`057_l0003o0000o`000?l01Ako00000_l01Ah2o`0000;o00DN00?o
0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`067ol00000
0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o
000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`00
0?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l000001?l00000
0ol01Ako0000o`000002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0ol0
00000ol01Ako0000o`000003o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako
00DN0_l000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0ol000001?l01Ako0000o`057ol0
1Al2o`000003o`057ol0003o000003Gooooo000Qooooo`;o00000oooool2o`0000;o00DN00?o0000
o`057_l000000_l000000ol01Ako0000o`000003o`0000;o00DN0_l00002o`057P03o`000?l01Ako
000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co
00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000Ko00DNo`000?l0003o
0000o`057_l00002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DN
o`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l0
1Ql5o`000006o`067ol0003o0000o`000?l01Aoo00000_l01Ah2o`0000;o00DN00?o0000o`057_l0
00000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l0
1Ako0000o`057_l01Ah2o`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DN
o`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN
0_l00002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l000001?l000000ol01Ako0000
o`000002o`057P03o`000?l01Ako000000;o000000Co00HOo`000?l01Ako00DN0ol000000ol01Qoo
0000o`057`02o`0003Gooooo000Nooooo`So000000Co00DNo`000?l01Ako00DN0_l00002o`057P;o
00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0
003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002
o`000003o`057_l0003o000000?o00000_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l00000
1?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`05
7_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001_l01Ako0000o`000?l0003o00HOo`00
00;o00HO0_l00002o`067`03o`000?l01Aoo000000;o000000Co00DNo`000?l01Ako00DN0_l00002
o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057PGo000000Ko
00DNo`000?l0003o0000o`057_l00002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004
o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DN
o`057P;o00000_l01Ah2o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN
0_l000001?l01Aoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o000000?o00DNo`00
0?l00000=?ooool001gooooo0_l00002ooooo`?o000000?o00DNo`000?l000000ol000001?l01Ako
0000o`000?l00002o`057P04o`000?l01Ako0000o`0000;o00DN00?o0000o`057_l000000_l00000
1?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`05
7_l01Ah2o`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako
00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`05
7P03o`000?l01Ako000000;o000000?o00DNo`000?l000000ol00002o`057P;o00000_l01Ah00ol0
003o00HOo`000002o`000004o`067ol0003o00HOo`067`;o00000_l01Ah00ol0003o00DNo`000002
o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000006o`057_l0
003o0000o`000?l01Ako00000_l01Ah2o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`00
0?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah3o`000003o`057_l0003o00DN00?o000000?o
00DNo`000?l000001?l000001ol01Ako0000o`000?l0003o00DNo`000?l01Ah00ol000001?l01Ako
0000o`057_l01Ah3o`000003o`057ol0003o00DO00?o000000Co00HOo`000?l01Qoo00HO0ol00000
0ol01Aoo0000o`057P03o`0003?ooooo000Mooooo`Co00000_l01Ah2o`0000;o00DN00Co0000o`05
7_l0003o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN00Co0000o`057_l0003o00000_l0
1Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`00
0003o`000006o`057_l0003o0000o`000?l01Ako00000_l01Ah2o`0000;o00DN00?o0000o`057_l0
00000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000000ol0
1Ako0000o`000003o`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`00
0?l01Ako00DN0_l00002o`067`03o`000?l01Qoo000000;o000000Co00HOo`000?l01Ako00DN0_l0
0002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l000000ol00002o`057P;o000000Co
00DNo`000?l01Ako00DN0ol000000ol01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P?o
000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`000004o`000003o`057_l0003o000000;o
00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`05
7_l000000_l000001?l01Qoo0000o`057ol01Al2o`0000;o00HO00?o0000o`067ol000000_l00000
0ol01Ako0000o`000003o`0000;o00DN0_l0000booooo`005_ooool2o`0000Gooooo0_l000001_l0
1Ako0000o`000?l0003o00DNo`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co
00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l00000
0ol00002o`057P;o00000_l01Ah01?l0003o00DNo`000?l00002o`057P03o`000?l01Ako000000;o
000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`00
0?l01Ako00DN0_l00002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o
00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057ol0003o00HOo`067`;o0000
0_l01Ql00ol0003o00HOo`000002o`000003o`057ol0003o000000?o000000Ko00DNo`000?l0003o
0000o`057_l00002o`057P?o000000?o00DNo`000?l01Ah00ol000001?l01Ako0000o`057_l01Ah2
o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN1Ol0
00001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o
000000Co00DNo`000?l01Ako00DN0_l000001?l01Aoo0000o`067ol01Ql3o`000003o`067ol0003o
000000?o000000Ko00HOo`000?l0003o0000o`057_l00002o`057P?o000000?o00DNo`000?ooool0
<Oooool001Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`000002o`057P03o`00
0?l01Ako000000;o00000_l01Ah01?l0003o00DNo`000?l00002o`057P03o`000?l01Ako000000;o
000000Co00DNo`000?l01Ako00DN0_l00002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`00
0004o`057_l0003o00DNo`057P;o00000_l01Ah01?l0003o00DNo`000?l00002o`057P03o`000?l0
1Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057PGo000000Ko00DNo`000?l0003o
0000o`057_l00002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DN
o`057P;o00000_l01Ah00ol0003o00DOo`000002o`000004o`067ol0003o00HOo`067`;o00000_l0
1Ql2o`000004o`057ol0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`05
7_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`05
7P;o00000_l01Ah5o`000003o`057_l0003o000000?o00000_l01Ah2o`000004o`057_l0003o00DN
o`057P?o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah3o`000003o`06
7ol0003o00DO00?o000000Ko00HOo`000?l0003o0000o`057ol00002o`057`;o00000_l01Ah00ol0
003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o0000<Oooool001Gooooo00Co0000oooo
oooooooo00000oooool3o`000003ooooool0003o00DN00;o00000_l01Ah00ol0003o00DNo`057P02
o`0000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`000003o`000006o`057_l0003o
0000o`000?l01Ako00000_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000
o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`000003o`000006
o`057_l0003o0000o`000?l01Ako00000_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l00000
1?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`05
7_l01Ah2o`0000;o00DN1Ol000001ol01Qoo0000o`000?l0003o00HOo`000?l01Al00ol000001?l0
1Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l0
1Ah2o`0000;o00DN1Ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN1?l00002o`057P?o
000000?o00DNo`000?l01Ah00ol000001?l01Ako0000o`057_l01Ah3o`000003o`057_l0003o00DN
00?o000000?o00HOo`000?l000000ol00002o`067`;o000000Co00HOo`000?l01Aoo00DO0ol00000
1?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P?o000000?o00DNo`000?l00000
<?ooool001Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`;o0000
00?o00DNo`000?l01Ah00ol000000ol01Ako0000o`000003o`0000;o00DN0_l00002o`057P04o`00
0?l01Ako0000o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`00
00;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN0_l00002
o`057P04o`000?l01Ako0000o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`05
7_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o
00DN1Ol000001_l01Ako0000o`000?l0003o00DOo`0000;o00HO0_l000001?l01Qoo0000o`067ol0
1Ql2o`0000;o00DO00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN
00?o0000o`057_l000000_l000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l000001?l0
1Ako0000o`057_l01Ah3o`000003o`057_l0003o00DN00?o000000Co00DNo`000?l01Ako00DN0_l0
0002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l000000ol00002o`067`;o000000Co
00HOo`000?l01Qoo00HO0ol000000ol01Aoo0000o`067`03o`000004o`057_l0003o00DNo`057P?o
000000?o00DNo`000?l01Ah00ol000001?l01Ako0000o`057_l01Ah2o`00033ooooo000Eooooo`04
o`000?ooooooooooo`0000?ooooo0_l00005ooooo`Co000000?o00DNo`000?l000000_l01Ah00ol0
003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah01?l0003o00DNo`000?l0
0002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057PGo0000
00Ko00DNo`000?l0003o0000o`057_l00002o`057P;o00000_l01Ah01?l0003o00DNo`000?l00002
o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057PGo000000Ko
00DNo`000?l0003o0000o`057_l00002o`057P;o00000_l01Ah00ol0003o00DOo`000002o`000003
o`067ol0003o00HO00?o000000Co00HOo`000?l01Aoo00DO0_l00002o`057P03o`000?l01Ako0000
00;o000000?o00DNo`000?l000000ol00002o`057P;o000000Co00DNo`000?l01Ako00DN0ol00000
0ol01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`00
0002o`000003o`057_l0003o000000?o000000Ko00DNo`000?l0003o0000o`067ol00002o`067`?o
000000?o00HOo`000?l01Ql00ol000001?l01Qoo0000o`057ol01Al2o`0000;o00DN00?o0000o`05
7_l000000_l000001?l01Ako0000o`057_l01Ah2o`000003o`057_l0003o000000Co000000?o00DN
o`000?l00000;oooool001Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04
ooooo`03o`000?l01Ako00DN00;o00000_l01Ah01?l0003o00DNo`000?l00002o`057P03o`000?l0
1Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o0000
00?o00DNo`000?l000000ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l00002o`05
7P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako
000000;o000000?o00DNo`000?l000000ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN
0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Aoo
0000o`067ol01Ql2o`0000;o00HO00?o0000o`067ol000000_l000000ol01Qoo0000o`000003o`00
00;o00DN0_l00002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l01Ah00ol000001?l0
1Ako0000o`057_l01Ah3o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l000000ol00000
1_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l00002o`067`03o`000?l01Qoo000000;o0000
00Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Qoo000000;o000000Co00DNo`000?l0
1Ako00DN0_l000000ol01Ako0000o`000004o`000003o`057_l0003o000000;o00DN00?o0000o`05
7_l000000_l000000ol01Ako0000ooooo`0^ooooo`005_ooool2o`0000Cooooo00?o0000oooooooo
ool01Oooool2o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`00
0003o`057_l0003o00DN00?o000000?o00DNo`000?l000000ol00002o`057P;o00000_l01Ah01?l0
003o00DNo`000?l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l0
0002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057P;o0000
0_l01Ah01?l0003o00DNo`000?l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l0
1Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l01Al00ol000001?l0
1Qoo0000o`067ol01Ql2o`0000;o00HO0_l00002o`067`03o`000?l01Ako000000;o000000Co00DN
o`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l00000
0_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN0_l000001?l01Ako0000o`057_l01Ah2o`00
00;o00DN00?o0000o`057_l000000_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000
o`067ol000000_l000001?l01Qoo0000o`067ol01Ql2o`000003o`057_l0003o000000Co000000Go
00DNo`000?l0003o00DNo`000002o`057P?o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako
0000o`057_l01Ah2o`0002kooooo000Looooo`;o00001oooool00ol0003o00DNo`000002o`000004
o`057_l0003o00DNo`057P;o00000_l01Ah5o`000003o`057_l0003o000000;o00DN00?o0000o`05
7_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00Co0000o`057_l0003o00000_l0
1Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah5o`000006o`05
7_l0003o0000o`000?l01Ako00000_l01Ah2o`000004o`057_l0003o00DNo`057P;o00000_l01Ah0
0ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah4o`0000;o00DO1Ol0
00001_l01Qoo0000o`000?l0003o00HOo`0000;o00HO0_l000001?l01Qoo0000o`057_l01Ah3o`00
0003o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol00002o`057PGo000000Oo00DNo`00
0?l0003o0000o`057_l0003o00DN00?o000000Co00DNo`000?l01Ako00DN0_l00002o`067`03o`00
0?l01Qoo000000;o000000Co00HOo`000?l01Qoo00HO0_l000000ol01Qoo0000o`000004o`000005
o`057_l0003o0000o`057_l000000_l01Ah3o`000003o`057_l0003o00DN00?o000000Co00DNo`00
0?l01Ako00DN0ol000000ol01Ako0000o`057P03o`000003o`057_l0003o000002gooooo000Loooo
o`03o`000?oooooooooo00Oooooo0_l000000ol01Ako0000o`000003o`000006o`057_l0003o0000
o`000?l01Ako00000_l01Ah2o`0000;o00DN00Co0000o`057_l0003o00000_l01Ah00ol0003o00DN
o`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000003
o`057_l0003o000000?o000000Ko00DNo`000?l0003o0000o`057_l00002o`057P;o00000_l01Ah0
0ol0003o00DNo`000002o`000003o`057_l0003o00DN00?o000000Co00DNo`000?l01Ako00DN0_l0
0002o`057PGo000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00?o000000Co00HOo`000?l0
1Qoo00HO0_l00002o`067`03o`000?l01Qoo000000;o000000?o00HOo`000?l01Ql00ol000001?l0
1Ako0000o`057_l01Ah2o`0000;o00DN1Ol000001ol01Ako0000o`000?l0003o00DNo`000?l01Ah0
0ol000001?l01Ako0000o`057_l01Ah2o`0000;o00DO00?o0000o`057_l000000_l000001?l01Qoo
0000o`067ol01Ql2o`000004o`067ol0003o00HOo`067`?o000000Go00HOo`000?l0003o00DNo`00
0002o`057P?o000000?o00DNo`000?l01Ah00ol000001?l01Ako0000o`057_l01Ah2o`0000;o00DN
00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`000003o`057_l0003o000000?o
0000;Oooool001_ooooo00?o0000ooooool000002_ooool01Ol0003o00DNo`057_l0003o00DN00;o
00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0
003o00DNo`000002o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l000000ol00002o`05
7P;o00000_l01Ah01?l0003o00DNo`000?l00002o`057P03o`000?l01Ako000000;o000000Co00DN
o`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l000000ol0
00001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l000001?l01Ako0000o`057_l01Ah2o`00
00;o00DN00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql2o`000004o`067ol0003o
00HOo`067`;o00000_l01Ql5o`000003o`057_l0003o000000?o00000_l01Ah2o`000004o`057_l0
003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057ol0003o00DOo`057`;o
000000Co00HOo`000?l01Qoo00HO0ol000000ol01Qoo0000o`000003o`000007o`067ol0003o0000
o`000?l01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DN
o`000002o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l000001?l000001Ol01Ako
0000o`000?l01Ako000000;o00DN0_l0000/ooooo`006oooool2o`0000_ooooo00?o0000o`057_l0
1Ah00_l00002o`057P04o`000?l01Ako0000o`0000;o00DN00?o0000o`057_l000000_l000001?l0
1Ako0000o`057_l01Ah2o`0000;o00DN1Ol000000ol01Ako0000o`000002o`057P03o`000?l01Ako
000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000?o
00DNo`000?l01Ah00ol000000ol01Ako0000o`000003o`0000;o00DN0_l000001?l01Ako0000o`05
7_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`057P03o`000004o`05
7_l0003o00DNo`057P;o00000_l01Ql00ol0003o00HOo`000002o`000003o`067ol0003o00HO00?o
000000Ko00HOo`000?l0003o0000o`067ol00002o`057P?o000000?o00DOo`000?l01Ah00ol00000
0ol01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P;o00000_l01Al5o`000003o`067ol0
003o000000?o000000Ko00HOo`000?l0003o0000o`067ol00002o`067`;o000000Co00DNo`000?l0
1Ako00DN0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00000
0ol01Ako0000o`000004o`000005o`057_l0003o0000o`057_l000000_l01Ah3o`000003o`057_l0
003o00DN00?o000000?o00DNo`000?l00000:oooool001_ooooo00?o0000ooooooooool02oooool2
o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0
003o000000?o000000Ko00DNo`000?l0003o0000o`057_l00002o`057P;o00000_l01Ah01?l0003o
00DNo`000?l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002
o`057PCo00000_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`057P03
o`000004o`057_l0003o00DNo`057P;o00000_l01Ah01?l0003o00DNo`000?l00002o`057P03o`00
0?l01Ako000000;o000000?o00DNo`000?l000000ol00002o`067`04o`000?l01Qoo0000o`0000;o
00HO0_l00002o`067`03o`000?l01Qoo000000;o000000Co00DOo`000?l01Aoo00DO0_l000001?l0
1Ako0000o`057_l01Ah2o`0000;o00HO1Ol000001ol01Qoo0000o`000?l0003o00HOo`000?l01Ql0
0ol000001?l01Qoo0000o`067ol01Ql2o`000004o`067ol0003o00HOo`067`?o000000?o00DNo`00
0?l01Ah00ol000001?l01Ako0000o`057_l01Ah2o`000003o`057_l0003o000000Co000000Go00DN
o`000?l0003o00DNo`000002o`057P?o000000?o00DNo`000?l01Ah00ol000001?l01Ako0000o`05
7_l01Ah2o`000004o`057_l0003o00DNo`057P;o0000:oooool001_ooooo0ol0000<ooooo`03o`00
0?l01Ako000000;o000000?o00DNo`000?l000000ol00002o`057P;o00000_l01Ah01?l0003o00DN
o`000?l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`05
7P04o`000?l01Ako0000o`0000;o00DN1Ol000001ol01Ako0000o`000?l0003o00DNo`000?l01Ah0
0ol000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00Co0000o`057_l0003o00000_l01Ah00ol0
003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l000000ol00002
o`057P;o00000_l01Ql00ol0003o00HOo`000004o`000006o`067ol0003o0000o`000?l01Qoo0000
0_l01Ql2o`0000;o00HO00?o0000o`057ol000000_l000000ol01Aoo0000o`000003o`000007o`06
7ol0003o0000o`000?l01Qoo0000o`067`03o`000004o`067ol0003o00HOo`067`;o00000_l01Ql0
0ol0003o00HOo`000002o`000003o`067ol0003o00HO00?o000000Co00DNo`000?l01Ako00DN0_l0
00000ol01Ako0000o`000004o`000003o`057_l0003o000000;o00DN00?o0000o`057_l000000_l0
00000ol01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`000?l01Ako
00DN0ol000000ol01Ako0000o`000003o`000003o`057_l0003o000002[ooooo0008ooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0=ooooo`;o0000
00?o00DNo`000?l000000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o
00000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l0
00000ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l00002o`057P04o`000?l01Ako
0000o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`000004o`05
7_l0003o00DNo`057P;o00000_l01Ah5o`000003o`057_l0003o000000;o00DN00?o0000o`057_l0
00000_l000001?l01Ako0000o`067ol01Ql2o`000004o`067ol0003o00HOo`067`;o00000_l01R00
0ol0003o00HOo`000002o`000004o`067ol0003o00HOo`067`;o000000Ko00DOo`000?l0003o0000
o`067ol00002o`067`;o000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Qoo0000
00;o000000Co00HOo`000?l01Qoo00HO0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00DN1Ol0
00000ol01Ako0000o`000002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN
0_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l000000_l000000ol01Ako
0000o`000003o`000006o`057_l0003o0000o`000?l01Ako00000_l01Ah2o`000003o`057_l0003o
000002Wooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0?ooooo`05o`000?l01Ako00DNo`000?l01Ah00_l00002o`057P03o`000?l0
1Ako000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057PGo000000?o00DNo`000?l00000
0_l01Ah01?l0003o00DNo`000?l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l0
1Ako00DN0_l00002o`057P04o`000?l01Ako0000o`0000;o00DN00?o0000o`057_l000000_l00000
0ol01Ako0000o`000003o`000006o`057_l0003o0000o`000?l01Ako00000_l01Ah2o`000004o`05
7_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000003o`067ol0003o00HO00?o
000000?o00HOo`000?l01R000ol00002o`0680Go000000?o00HOo`000?l000000_l01Ql00ol0003o
00HOo`000002o`000003o`067ol0003o00HO00?o000000Co00HOo`000?l01Qoo00HO0_l000001?l0
1Qoo0000o`067ol01Ql3o`000003o`067ol0003o000000?o000000Oo00DNo`000?l0003o0000o`05
7_l0003o00DN00?o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah3o`00
0003o`057_l0003o00DN00?o000000?o00DNo`000?l000000ol000001_l01Ako0000o`000?l0003o
00DNo`0000;o00DN0_l000001?l01Ako0000o`057_l01Ah3o`000003o`057_l0003o00DN00;o0000
:Oooool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000
4Oooool00ol0003o00DNo`000002o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l00000
0ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l000001?l01Ako0000o`057_l01Ah2
o`0000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`057P03o`000003o`057_l0003o
000000?o000000?o00DNo`000?l000000ol00002o`057P;o00000_l01Ah01?l0003o00DNo`000?l0
0002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l01Ah00ol000001?l01Ako0000o`05
7_l01Ah2o`0000;o00DN1?l00002o`067`Go000000Oo00LQo`000?l01R3o0000o`068?l0003o00HO
00?o000000Co00HOo`000?l01Qoo00HO0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o
0000o`067ol000000_l000000ol01Qoo0000o`000003o`000006o`067ol0003o0000o`000?l01Aoo
00000_l01Al2o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`00
0003o`057_l0003o00DN00?o000000?o00DNo`000?l000000ol000001_l01Ako0000o`000?l0003o
00DNo`0000;o00DN0_l000001?l01Ako0000o`057_l01Ah3o`000003o`057_l0003o00DN00?o0000
00Co00DNo`000?l01Ako00DN0_l000000ol01Ako0000o`00000Xooooo`001oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003o
00DNo`057P04o`0000;o00DN0_l00002o`057P04o`000?l01Ako0000o`0000;o00DN00?o0000o`05
7_l000000_l000000ol01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P;o00000_l01Ah4
o`0000;o00DN0_l00002o`057P04o`000?l01Ako0000o`0000;o00DN00?o0000o`057_l000000_l0
00001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P;o00000_l01Ah01?l0003o
00DNo`000?l00002o`057PGo000000Oo00DNo`000?l0003o0000o`057_l0003o00HO00Go00000_l0
1R001?l0003o00LQo`000?l00002o`0680;o00000_l01Ql00ol0003o00HOo`000002o`000003o`06
7ol0003o00HO00?o00000_l01Ql4o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql2o`00
0004o`057ol0003o00DOo`057`?o000000?o00DNo`000?l01Ah00ol000001?l01Ako0000o`057_l0
1Ah2o`000003o`057_l0003o000000?o00000_l01Ah2o`000004o`057_l0003o00DNo`057P;o0000
00Co00DNo`000?l01Ako00DN0ol000000ol01Ako0000o`057P03o`000004o`057_l0003o00DNo`05
7P;o000000?o00DNo`000?l000001?l000001?l01Ako0000o`000?l01Ah2o`0002Oooooo0007oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool2o`0001Cooooo0_l00000
0ol01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`00
0002o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l000000ol000001ol01Ako0000o`00
0?l0003o00DNo`000?l01Ah00ol000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00Co0000o`05
7_l0003o00000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o000000?o000000?o00DN
o`000?l000000ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l00002o`057P03o`00
0?l01Ako000000;o000000?o00HOo`000?l01Ql01Ol000001_l01b7o0000o`000?l0003o00TSo`00
00;o00HO0_l00002o`067`Co00000_l01R001?l0003o00HOo`000?l00002o`067`;o00000_l01Ql0
0ol0003o00HOo`000002o`000003o`067ol0003o00DO00?o000000Co00DNo`000?l01Ako00DN0_l0
00000ol01Ako0000o`000004o`000005o`057_l0003o0000o`057_l000000_l01Ah3o`000003o`05
7_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000001?l01Ako0000o`057_l01Ah2o`000003
o`057_l0003o000000Co000000Go00DNo`000?l0003o00DNo`000002o`057P?o000000?o00DNo`00
0?l01Ah00_l0000Wooooo`001oooool01?l0003oooooooooool00008ooooo`;o00001Oooool00ol0
003oooooooooo`0Dooooo`03o`000?l01Ako000000;o000000?o00DNo`000?l01Ah00ol000001?l0
1Ako0000o`057_l01Ah2o`0000;o00DN1?l00002o`057P;o00000_l01Ah01?l0003o00DNo`000?l0
0002o`057P04o`000?l01Ako0000o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000
o`057_l01Ah2o`000003o`057_l0003o000000?o00000_l01Ah2o`000004o`057_l0003o00DNo`05
7P;o00000_l01Ah01?l0003o00DNo`000?l00002o`057P03o`000?l01Ako000000;o000000?o00DN
o`000?l01Ah00ol000001?l01Aoo0000o`067ol01Ql2o`0000;o00HO1?l000000ol03BOo0000o`09
8`02o`098`;o000000So00LQo`000?l01Qoo0000o`098ol0003o00HPo`0000;o00HP0_l000001_l0
1R3o0000o`000?l0003o00HOo`0000;o00HO0_l000000ol01Qoo0000o`000003o`0000;o00DN1Ol0
00000ol01Ako0000o`000002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l01Ah00ol0
00001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o0000o`057P;o00000_l01Ah5o`000003
o`057_l0003o000000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`057P03o`000004
o`057_l0003o00DNo`057P;o000000Co00DNo`000?l0003o00009Oooool000Sooooo0_l0000:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool2o`000003o`057_l0003o0000
00?o000000?o00DNo`000?l000000ol000001ol01Ako0000o`000?l0003o00DNo`000?l01Ah00ol0
00001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o
00DNo`000002o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000_l01Ah00ol0003o
00DNo`000002o`000003o`057_l0003o00DN00?o000000Co00DNo`000?l01Ako00DN0_l00002o`05
7P04o`000?l01Ako0000o`0000;o00DN1Ol000000ol01Aoo0000o`000003o`000008o`067ol0003o
0000o`000?l01Qoo0000o`098ol00002o`0=9`03o`000?l02B?o00TS00;o000000?o00LQo`000?l0
00000ol02B<4o`000003o`078Ol0003o000000;o00HO1Ol000000ol01Qoo0000o`000002o`057P03
o`000?l01Ako000000;o000000?o00DNo`000?l01Ah00ol000001?l01Ako0000o`057_l01Ah2o`00
0004o`057_l0003o00DNo`057P;o00000_l01Ah5o`000003o`057_l0003o000000?o000000Oo00DN
o`000?l0003o0000o`057_l0003o00DN00?o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako
0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P?o000000?o00DNo`000?l000000ol0000U
ooooo`006_ooool2o`0001Sooooo00?o0000o`057_l000000_l01Ah2o`0000;o00DN00Co0000o`05
7_l0003o00000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o00DN00?o000000?o00DN
o`000?l01Ah00ol000000ol01Ako0000o`000003o`0000;o00DN0_l000001?l01Ako0000o`057_l0
1Ah2o`0000;o00DN00Co0000o`057_l0003o00000_l01Ah00ol0003o00DNo`000002o`000003o`05
7_l0003o00DN00?o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000003o`0000;o00DN
0_l000001?l01Aoo0000o`057ol01Al2o`000004o`067ol0003o00HOo`067`?o00000_l03BL00ol0
003o00TSo`000002o`0@:P03o`000?l042[o000000?o00TS00?o0000o`078Ol01b400_l000001ol0
1R3o0000o`000?l0003o00HOo`000?l01Ql00ol000001?l01Qoo0000o`057_l01Ah2o`000004o`05
7_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o000000?o
000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol00000
1?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P?o000000?o00DNo`000?l01Ah0
0ol000000ol01Ako0000o`000003o`000007o`057_l0003o0000o`000?l01Ako0000o`057P02o`00
02Gooooo000Jooooo`03o`000?oooooooooo01Oooooo00?o0000o`057_l000000_l000001?l01Ako
0000o`057_l01Ah2o`0000;o00DN00Co0000o`057_l0003o00000_l01Ah5o`000003o`057_l0003o
000000?o000000?o00DNo`000?l000000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o
00DN00?o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN
1?l00002o`057P;o00000_l01Ah00ol0003o00DNo`000004o`000007o`057_l0003o0000o`000?l0
1Ako0000o`057`03o`000003o`067ol0003o00HO00?o000000So00LQo`000?l02B?o0000o`0=9ol0
003o00TSo`0000;o010Z00?o0000o`0@:_l000000_l02B<01Ol0003o00dWo`000?l0003o00HP00;o
00000_l01Ql01?l0003o00HOo`000?l00002o`067`03o`000?l01Qoo000000;o000000?o00DNo`00
0?l01Ah00ol000000ol01Ako0000o`000003o`000006o`057_l0003o0000o`000?l01Ako00000_l0
1Ah2o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03
o`000?l01Ako000000;o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000003o`000007
o`057_l0003o0000o`000?l01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P;o000000?o
00DNo`000?l000009?ooool001Wooooo00?o0000ooooooooool06Oooool2o`000003o`057_l0003o
00DN00?o000000?o00DNo`000?l000000ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN
0_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00Co0000o`057_l0003o00000_l01Ah00ol0
003o00DNo`000002o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000ol000001ol0
1Ako0000o`000?l0003o00DNo`000?l01Ah00ol000001?l01Ako0000o`057_l01Ah4o`0000;o00DN
0_l000001?l01Ako0000o`057_l01Ah2o`0000;o00HO1?l00002o`067`03o`000?l01b7o000000;o
000000?o00dWo`000?l000000_l042X2o`0000;o010Z0_l00002o`0=9`?o000000Co00HOo`000?l0
1Qoo00HO0_l000000ol01Qoo0000o`000003o`000003o`057_l0003o000000?o00000_l01Ah2o`00
0004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o
00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`000003o`000007o`057_l0003o
0000o`000?l01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`000?l0
1Ako00DN0_l000001?l01Ako0000o`057_l01Ah3o`000003o`057_l0003o000000?o00008oooool0
01Wooooo0_l0000Looooo`Co000000?o00DNo`000?l000000_l01Ah01?l0003o00DNo`000?l00002
o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l01Ah00ol000001?l01Ako0000o`057_l0
1Ah2o`000003o`057_l0003o000000?o00000_l01Ah2o`000004o`057_l0003o00DNo`057P;o0000
0_l01Ah01?l0003o00DNo`000?l00002o`057P04o`000?l01Ako0000o`0000;o00DN00?o0000o`05
7_l000000_l000000ol01Ako0000o`057P03o`000003o`057_l0003o000000?o000000Oo00HOo`00
0?l0003o0000o`067ol0003o00HO00Go000000Ko010Zo`000?l0003o0000o`0L<ol00002o`0@:P;o
00000_l042X01?l0003o00dWo`0=9ol00002o`067`Go000000?o00HOo`000?l000000_l01Ah01?l0
003o00DNo`000?l00002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l01Ah00ol00000
1?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l00000
0ol00002o`057P;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah2o`00
00;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`057P03o`000003o`057_l0003o0000
00?o000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00;o00008oooool001Wooooo00?o0000
ooooooooool06oooool00ol0003o00DNo`057P02o`0000;o00DN00Co0000o`057_l0003o00000_l0
1Ah00ol0003o00DNo`000002o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l000000ol0
00000ol01Ako0000o`000002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l01Ah00ol0
00001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l0
00000ol00002o`057PCo00000_l01Ah2o`000004o`067ol0003o00HOo`067`;o00000_l01Ql01?l0
003o00HOo`000?l00002o`068004o`000?l02B?o0000o`0@:P;o00000_l073<00ol0003o010Zo`00
0002o`1T?`0;o`000?l042[o0000o`000?l03BOo0000o`067ol0003o00HOo`000?l01Ql00ol00000
1?l01Aoo0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`000?l01Ako
00DN0_l00002o`057PGo000000?o00DNo`000?l000000ol000001Ol01Ako0000o`000?l01Ako0000
00;o00DN0ol000000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00?o000000Co00DNo`00
0?l01Ako00DN0_l000000ol01Ako0000o`000003o`000007o`057_l0003o0000o`000?l01Ako0000
o`057P03o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l000008_ooool001Wooooo
0ol0000Looooo`;o000000Co00DNo`000?l01Ako00DN0_l000000ol01Ako0000o`000003o`0000;o
00DN1?l00002o`057P;o00000_l01Ah01?l0003o00DNo`000?l00002o`057P04o`000?l01Ako0000
o`0000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`057P03o`000003o`057_l0003o
000000?o000000?o00DNo`000?l000000ol000001ol01Ako0000o`000?l0003o00DNo`000?l01Ah0
0ol000000ol01Ako0000o`067`03o`000004o`067ol0003o00HOo`067`;o000000Co00HPo`000?l0
1R3o00HP0ol00002o`0@:P;o00000_l073<2o`0000;o06@o0_l00002o`0L<`?o00000_l01Ql2o`00
00;o00DO00?o0000o`057ol000000_l000000ol01Ako0000o`057P03o`000003o`057_l0003o0000
00?o000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol0
00000ol01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l00000
0ol000000ol01Ako0000o`000004o`000005o`057_l0003o0000o`057_l000000_l01Ah2o`000004
o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o00DN
00;o00008_ooool000Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0
003oooooooooo`0Nooooo`Co000000?o00DNo`000?l000000_l01Ah00ol0003o00DNo`000002o`00
0003o`057_l0003o00DN00?o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l0
1Ah2o`000003o`057_l0003o000000?o00000_l01Ah4o`0000;o00DN0_l000001?l01Ako0000o`05
7_l01Ah3o`000003o`057_l0003o00DN00;o00000_l01Ah01?l0003o00DNo`000?l00002o`057P04
o`000?l01Ako0000o`0000;o00HO1Ol000000ol01Qoo0000o`068003o`0000;o00LQ0_l000001?l0
42[o0000o`000?l073<2o`0000?o06@o0_l000001?l073?o0000o`000?l01Ql3o`000003o`067ol0
003o000000?o000000?o00DOo`000?l000000ol000001_l01Ako0000o`000?l0003o00DNo`0000;o
00DN0_l000001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000Co00DN
o`000?l01Ako00DN0_l00002o`057PGo000000Go00DNo`000?l0003o00DNo`000002o`057P;o0000
0_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah0
0ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000?o000000Co00DNo`000?l0003o
00008?ooool000Gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo01oooooo00Co0000o`057_l0003o00000_l01Ah00ol0003o00DNo`000002
o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`000003
o`000003o`057_l0003o000000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`057P03
o`000003o`057_l0003o00DN00?o000000Co00DNo`000?l01Ako00DN0_l000000ol01Ako0000o`00
0003o`000003o`057_l0003o000000?o000000Ko00HOo`000?l0003o0000o`067ol00002o`067`Co
00000_l01b400ol0003o00LQo`000004o`000004o`1T?ol0003o:YX0o`0000?o06@o00?o0000o`0L
<ol000000ol00002o`067`;o000000Co00HOo`000?l01Aoo00DO0_l00002o`057P04o`000?l01Ako
0000o`0000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`057P03o`000003o`057_l0
003o000000?o000000?o00DNo`000?l000000ol000001ol01Ako0000o`000?l0003o00DNo`000?l0
1Ah00ol000000ol01Ako0000o`057P03o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`00
0?l01Ako00DN0_l000000ol01Ako0000o`000003o`000006o`057_l0003o0000o`000?l01Ako0000
0_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l000008?ooool000Gooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o00008Oooool01Ol0003o
00DNo`057_l0003o00DN00;o00000_l01Ah4o`0000;o00DN1?l00002o`057P;o00000_l01Ah01?l0
003o00DNo`000?l00002o`057P04o`000?l01Ako0000o`0000;o00DN00Co0000o`057_l0003o0000
0_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o000000?o000000?o00DNo`000?l00000
0_l01Ah01?l0003o00DNo`000?l00002o`057`04o`000?l01Qoo0000o`0000;o00HO00?o0000o`06
7ol000000_l000000ol01Qoo0000o`068005o`000004o`068?l0003o0000o`0L<`?o000000?o:YX0
o`000?l0I3l00_l0I3l4o`0000;o00HP0_l000000ol01Qoo0000o`067`03o`000004o`057_l0003o
00DNo`057P;o000000Co00DNo`000?l01Ako00DN0_l000000ol01Ako0000o`000003o`000006o`05
7_l0003o0000o`000?l01Ako00000_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000Co00DN
o`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah2o`000003o`057_l0003o000000Co0000
00?o00DNo`000?l000000ol000001Ol01Ako0000o`000?l01Ako000000;o00DN0_l000001?l01Ako
0000o`057_l01Ah3o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00_l00009oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000?ooooo0005ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Roooo
o`Co000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol0
00001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l0
00000ol000000ol01Ako0000o`000003o`0000;o00DN0_l000001?l01Ako0000o`057_l01Ah2o`00
0004o`057_l0003o00DNo`057P;o000000Co00DOo`000?l01Aoo00DO0_l00002o`067`04o`000?l0
1Qoo0000o`0000;o00HO00Co0000o`067ol0003o00000_l01Ql4o`0000;o00HO1?l000000olZVP3o
0000o`1T?`02o`1T?`;o000000Oo00LQo`000?l01R3o0000o`068?l0003o00HO00;o00000_l01Ql5
o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000_l01Ah01?l0003o00DNo`000?l0
0002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`00
0003o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000_l01Ah00ol0003o00DNo`00
0002o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`05
7P03o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000ol000000ol01Ako0000o`00
0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`7o00000Oooool1ooooo`001Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Sooooo`04o`000?l01Ako0000o`0000;o00DN00?o
0000o`057_l000000_l000000ol01Ako0000o`057P03o`000003o`057_l0003o000000?o000000?o
00DNo`000?l000000ol000000ol01Ako0000o`000002o`057P03o`000?l01Ako000000Co000000Oo
00DNo`000?l0003o0000o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Aoo
0000o`000003o`000003o`067ol0003o000000?o000000?o00HOo`000?l000000ol000001ol01Qoo
0000o`000?l0003o00HOo`000?l01Ql00ol000001_l01Qoo0000o`000?l0003o:YX0o`0000?o06@o
1Ol00002o`0680;o000000Oo00HOo`000?l0003o0000o`067ol0003o00DN00?o000000?o00DNo`00
0?l01Ah00ol000001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000?o
00DNo`000?l000000ol000001ol01Ako0000o`000?l0003o00DNo`000?l01Ah00ol000000ol01Ako
0000o`057P03o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`000?l01Ako00DN0_l00000
0ol01Ako0000o`000003o`000003o`057_l0003o000000?o000000Ko00DNo`000?l0003o0000o`05
7_l00002o`057P;o000000Co00DNo`000?l01Ako00DN0_l000000ol01Ako0000o`000006ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool1o`00007ooooo0Oooool0
00Gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo0_l0
000Uooooo`05o`000?l01Ako00DNo`000?l01Ah00_l00002o`057PCo00000_l01Ah2o`0000;o00DN
00Co0000o`057_l0003o00000_l01Ah01?l0003o00DNo`000?l00002o`057P03o`000?l01Ako0000
00;o000000?o00DNo`000?l01Ah00_l00002o`057PCo00000_l01Ah4o`0000;o00DN0_l000001?l0
1Qoo0000o`067ol01Ql2o`0000;o00HO00Co0000o`067ol0003o00000_l01Ql01?l0003o00HOo`00
0?l00002o`067`04o`000?l01Qoo0000o`0000;o00HO1Ol000000olZVP3o0000o`1T?`02o`1T?`?o
000000Go00LQo`000?l0003o0000o`067`02o`0000;o00HO00Co0000o`067ol0003o00000_l01Ah0
1?l0003o00DNo`000?l00002o`057PGo000000?o00DNo`000?l000000ol000001Ol01Ako0000o`00
0?l01Ako000000;o00DN0_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00Co0000o`057_l0
003o00000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o000000?o000000Go00DNo`00
0?l0003o00DNo`000002o`057P;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`05
7_l01Ah3o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l000000_l00006ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool1o`00007ooooo0Oooool000Ko
oooo0_l00009ooooo`?o00001?ooool00ol0003oooooooooo`0Uooooo`Co000000Oo00DNo`000?l0
003o0000o`057_l0003o00DN00?o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`05
7_l01Ah2o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000ol000001ol01Ako0000
o`000?l0003o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P03o`000003o`067ol0003o00HO
00?o000000Co00HOo`000?l01Qoo00HO0_l000000ol01Qoo0000o`000003o`000003o`067ol0003o
000000?o000000Oo00HOo`000?l0003o0000o`057ol0003o00DO00;o000000?o:YX0o`000?l0I3l0
0_l0I3l4o`000006o`068?l0003o0000o`000?l01Qoo00000_l01Ql2o`000003o`067ol0003o0000
00?o000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol0
00000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l000000ol0
00000ol01Ako0000o`000003o`000007o`057_l0003o0000o`000?l01Ako0000o`057P03o`000003
o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`000003o`000003
o`057_l0003o000000?o000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00;o00001Oooool0
1?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00003ooooo`006?oo
ool2o`0002Oooooo00?o0000o`057_l000000_l000000ol01Ako0000o`057P03o`000003o`057_l0
003o00DN00?o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000003o`000003o`057_l0
003o000000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`057P03o`000003o`057_l0
003o00DN00?o000000?o00HOo`000?l01Ql00ol000000ol01Qoo0000o`000003o`000003o`067ol0
003o000000;o00HO00Co0000o`067ol0003o00000_l01Ql01?l0003o00HOo`000?l00002o`057P03
o`000?l01Aoo000000?o000000?o:YX0o`000?l0I3l00_l0I3l5o`0000;o00HO00?o0000o`067ol0
00000_l000001Ol01Qoo0000o`000?l01Ako000000;o00DN0_l000001?l01Ako0000o`057_l01Ah2
o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l000000ol00002o`057PCo00000_l0
1Ah2o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako
0000o`057_l01Ah2o`000004o`057_l0003o0000o`057P;o000000?o00DNo`000?l000000ol00000
1ol01Ako0000o`000?l0003o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P03o`000004o`05
7_l0003o00DNo`057P;o000000?o00DNo`000?l000001?ooool01?l0003oooooooooool00008oooo
o`06o`000?ooooooooooo`000?oooooo00001_ooool001Sooooo00?o0000ooooooooool09oooool2
o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000002
o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l01Ah00_l00002o`057P04o`000?l01Ako
0000o`0000;o00DN1?l00002o`057PCo00000_l01Ql4o`0000;o00HO0_l000001?l01Qoo0000o`06
7ol01Ql2o`000004o`057ol0003o00HOo`067`;o000000Co00DNo`000?l01Qoo00HO0_l000000ol0
1Ako0000o`000003o`000006o`057ol0003o0000o`000?lZVP3o00000ol0I3l3o`000003o`067ol0
003o000000?o000000Oo00HOo`000?l0003o0000o`067ol0003o00DN00?o000000?o00DNo`000?l0
00000ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000;o00DN00?o0000o`057_l0
00000_l000000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l0
1Ah00ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000?o000000Go00DNo`000?l0
003o00DNo`000002o`057P;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l0
1Ah2o`000003o`057_l0003o000000Co000000?o00DNo`000?l000000_l00005ooooo`;o00002_oo
ool2o`0000;ooooo1Ol00002ooooo`006?ooool00ol0003oooooooooo`0Yooooo`03o`000?l01Ako
000000;o00DN0_l000001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P;o0000
00Co00DNo`000?l01Ako00DN0_l000000ol01Ako0000o`000003o`000007o`057_l0003o0000o`00
0?l01Ako0000o`057P03o`000003o`067ol0003o00HO00?o000000?o00HOo`000?l01Ql00ol00000
0ol01Qoo0000o`067`03o`000003o`057ol0003o000000?o000000?o00DNo`000?l000000ol00000
0ol01Ako0000o`000002o`057P05o`000?l01Ako0000o`000?l01Ah00_l000000olZVP3o0000o`1T
?`02o`1T?`Co00000_l01Ql01?l0003o00HOo`000?l00002o`067`Co00000_l01Ah2o`000004o`05
7_l0003o00DNo`057P;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah2
o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l000000ol000000ol01Ako0000o`00
0003o`000007o`057_l0003o0000o`000?l01Ako0000o`057P03o`000003o`057_l0003o00DN00?o
000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P03o`000003o`057_l0003o000000?o
000000Go00DNo`000?l0003o00DNo`000002o`057P?o000000?o00DNo`000?l01Ah00_l0000Koooo
o`005oooool2o`0002_ooooo00?o0000o`057_l000000_l000000ol01Ako0000o`057P03o`000003
o`057_l0003o000000?o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000002o`057P04
o`000?l01Ako0000o`0000;o00DN00Co0000o`057_l0003o00000_l01Ql01?l0003o00HOo`000?l0
0002o`067`Co00000_l01Ql4o`0000;o00DO0_l000001?l01Ako0000o`057_l01Ah2o`000004o`05
7_l0003o00DNo`057P;o000000Co00DNo`000?l01Ako00DN0_l000000ol01Ako0000o`057P02o`00
0008obZJ0?l0003o06@oo`1T?ol0003o:YX0o`000?l01Ql5o`000007o`067ol0003o0000o`000?l0
1Qoo0000o`067`03o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol0
1Ako0000o`000003o`000003o`057_l0003o000000?o000000Go00DNo`000?l0003o00DNo`000002
o`057P;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah2o`000004o`05
7_l0003o00DNo`057P;o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000003o`000007
o`057_l0003o0000o`000?l01Ako0000o`057P03o`000003o`057_l0003o00DN00?o000000?o00DN
o`000?l01Ah00ol000000ol01Ako0000o`00000Jooooo`005oooool00ol0003oooooooooo`0[oooo
o`;o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000003o`000005o`057_l0003o0000
o`057_l000000_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l000000ol0
00000ol01Qoo0000o`000003o`000007o`067ol0003o0000o`000?l01Qoo0000o`067`03o`000003
o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P03o`000003
o`057_l0003o000000?o000000?o00DNo`000?l000001?l000001_lZVP3o0000o`1T?ol0I3oo0000
obZJ00;o000000Co00HOo`000?l01Qoo00HO0_l000001?l01Qoo0000o`067ol01Ql2o`000003o`05
7ol0003o000000?o000000?o00DNo`000?l000000ol000001ol01Ako0000o`000?l0003o00DNo`00
0?l01Ah00ol000000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00?o000000?o00DNo`00
0?l01Ah00ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000?o000000Go00DNo`00
0?l0003o00DNo`000002o`057P;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`05
7_l01Ah2o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000ol000001_l01Ako0000
o`000?l0003o00DNo`0001[ooooo000Gooooo`03o`000?oooooooooo02gooooo00?o0000o`057_l0
00000_l01Ah4o`0000;o00DN0_l000000ol01Ako0000o`000003o`000003o`057_l0003o000000?o
000000?o00DNo`000?l000000_l01Ql01?l0003o00HOo`000?l00002o`067`04o`000?l01Qoo0000
o`0000;o00HO00Co0000o`067ol0003o00000_l01Ah01?l0003o00DNo`000?l00002o`057PCo0000
0_l01Ah4o`0000;o00DN0_l000001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`05
7P;o000000Ko:YX0o`000?l0I3oo06@oo`000?lZVP06o`000003o`067ol0003o000000?o000000?o
00HOo`000?l000000_l01Al01?l0003o00DNo`000?l00002o`057P04o`000?l01Ako0000o`0000;o
00DN00Co0000o`057_l0003o00000_l01Ah01?l0003o00DNo`000?l00002o`057PCo000000?o00DN
o`000?l000000ol000001ol01Ako0000o`000?l0003o00DNo`000?l01Ah00ol000000ol01Ako0000
o`057P03o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l000000ol000000ol01Ako0000
o`000003o`000005o`057_l0003o0000o`057_l000000_l01Ah2o`000004o`057_l0003o00DNo`05
7P;o000000Co00DNo`000?l01Ako00DN0_l0000Iooooo`005oooool2o`0002oooooo1?l000000ol0
1Ako0000o`000003o`000003o`057_l0003o000000;o00DN00Co0000o`057_l0003o00000_l01Ah0
1?l0003o00DNo`000?l00002o`067`04o`000?l01Qoo0000o`0000;o00HO00Go0000o`067ol0003o
0000o`067`05o`000003o`057_l0003o000000?o000000Oo00DNo`000?l0003o0000o`057_l0003o
00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P03o`000003o`057_l0003o
000000Go000000Wo:YX0o`000?l0I3oo06@oo`000?lZVP3o0000o`057_l000000_l01Ql2o`000004
o`067ol0003o00HOo`067`;o000000Co00HOo`000?l01Aoo00DO0_l000001?l01Ako0000o`057_l0
1Ah2o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000ol000001ol01Ako0000o`00
0?l0003o00DNo`000?l01Ah00_l00002o`057P04o`000?l01Ako0000o`0000;o00DN00Co0000o`05
7_l0003o00000_l01Ah4o`000003o`057_l0003o000000?o000000Oo00DNo`000?l0003o0000o`05
7_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P03o`000003o`05
7_l0003o00DN00?o000000?o00DNo`000?l000000ol000000ol01Ako0000o`00000Hooooo`001?oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0;?oo
ool4o`000003o`057_l0003o000000;o00DN00Co0000o`057_l0003o00000_l01Ah01_l0003o00DN
o`000?l0003o00DNo`0000;o00DN0_l000000ol01Aoo0000o`000003o`000003o`067ol0003o0000
00?o000000?o00HOo`000?l000000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o00DN
00;o00000_l01Ah01?l0003o00DNo`000?l00002o`057PCo00000_l01Ah4o`0000;o00DN0_l00000
0ol01Ako0000o`057P04o`000008obZJ0?l0003o06@oo`1T?ol0003o:YX0o`000?l01Ah3o`000003
o`057ol0003o00HO00?o000000?o00HOo`000?l01Ql00ol000000ol01Aoo0000o`000003o`000005
o`057_l0003o0000o`057_l000000_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000Co00DN
o`000?l01Ako00DN0_l000000ol01Ako0000o`000003o`000003o`057_l0003o000000?o000000Oo
00DNo`000?l0003o0000o`057_l0003o00DN00;o00000_l01Ah01Ol0003o00DNo`000?l0003o00DN
00;o000000Go00DNo`000?l0003o00DNo`000002o`057P;o000000?o00DNo`000?l000000ol00000
0ol01Ako0000o`000003o`000007o`057_l0003o0000o`000?l01Ako0000o`057P03o`000003o`05
7_l0003o000001Oooooo0003ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo02Wooooo0ol00004ooooo`03o`000?l01Ako000000;o
00DN0_l000000ol01Ako0000o`000003o`000003o`057_l0003o000000?o000000?o00HOo`000?l0
00000_l01Ql01?l0003o00HOo`000?l00002o`067`04o`000?l01Qoo0000o`0000;o00DN00Co0000
o`057_l0003o00000_l01Ah4o`000003o`057_l0003o000000?o000000Oo00DNo`000?l0003o0000
o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P02o`0000;o
00DN0_l000001?lZVP3o0000o`1T?ol0I3l4o`0000;o00DN1?l00002o`067`Co000000Oo00HOo`00
0?l0003o0000o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`00
0003o`000003o`057_l0003o000000?o000000Go00DNo`000?l0003o00DNo`000002o`057P;o0000
00Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DN
o`057P;o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000003o`000005o`057_l0003o
0000o`057_l000000_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`000?l01Ako
00DN0_l000000ol01Ako0000o`000003o`0001Oooooo0003ooooo`04o`000?ooooooooooo`0000_o
oooo00Co0000oooooooooooooooo0_l0000Xooooo`?o00002?ooool4o`000003o`057_l0003o0000
00;o00DN00Co0000o`057_l0003o00000_l01Al01?l0003o00DOo`000?l00002o`067`05o`000?l0
1Qoo0000o`000?l01Ql01Ol000000ol01Ako0000o`000003o`000007o`057_l0003o0000o`000?l0
1Ako0000o`057P02o`0000;o00DN00Co0000o`057_l0003o00000_l01Ah01?l0003o00DNo`000?l0
0002o`057P05o`000?l01Ako0000o`000?l01Ah01Ol000000ol01Ako0000o`000003o`000004obZJ
0?l0003o06@oo`1T?`;o000000Oo00DNo`000?l0003o0000o`057_l0003o00DO00?o000000?o00HO
o`000?l01Ql00_l00002o`067`Co00000_l01Ah4o`000007o`057_l0003o0000o`000?l01Ako0000
o`057P03o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000
o`057P03o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000ol000001Ol01Ako0000
o`000?l01Ako000000;o00DN0_l000000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00?o
000000?o00DNo`000?l000000ol000000ol01Ako0000o`000003o`000005o`057_l0003o0000o`05
7_l000000_l01Ah2o`0001Kooooo0003ooooo`04o`000?ooooooooooo`0000Wooooo0_l00004oooo
o`03o`000?oooooooooo02Gooooo0_l0000<ooooo`04o`000?l01Ako0000o`0000;o00DN00Go0000
o`057_l0003o0000o`067`05o`000003o`067ol0003o000000?o000000?o00DOo`000?l000000_l0
1Ah01?l0003o00DNo`000?l00002o`057P04o`000?l01Ako0000o`0000;o00DN00Co0000o`057_l0
003o00000_l01Ah01Ol0003o00DNo`000?l0003o00DN00Go000000?o00DNo`000?l000000ol00000
0ol01Ako0000o`000002o`057P04o`000?l01Ako0000o`0000;o00DN00Go0000o`057_l0003o:YX0
o`000002o`1T?`?o000000?o00DNo`000?l000000ol000000ol01Aoo0000o`000003o`000007o`06
7ol0003o0000o`000?l01Qoo0000o`057`03o`000003o`057_l0003o00DN00;o00000_l01Ah01?l0
003o00DNo`000?l00002o`057P05o`000?l01Ako0000o`000?l01Ah01Ol000000ol01Ako0000o`00
0003o`000007o`057_l0003o0000o`000?l01Ako0000o`057P03o`000003o`057_l0003o00DN00?o
000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`000002o`000003o`057_l0003o000000?o
000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol00000
0ol01Ako0000o`057P03o`000003o`057_l0003ooooo01Gooooo0003ooooo`04o`000?oooooooooo
o`0000_ooooo00Go0000ooooooooooooooooo`00000Tooooo`?o00003oooool00ol0003o00DNo`00
0004o`000003o`057_l0003o000000;o00HO00?o0000o`067ol000000_l000000ol01Aoo0000o`06
7`02o`0000;o00DN00Ko0000o`057_l0003o0000o`057_l00002o`057P;o000000?o00DNo`000?l0
00000ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000;o00DN00Co0000o`057_l0
003o00000_l01Ah01_l0003o00DNo`000?l0003o00DNo`0000;o00DN0_l000000ol01Ako0000o`00
0004o`000004obZJ0?l0003o06@oo`1T?`Co00000_l01Ah01?l0003o00DNo`000?l00002o`057P06
o`000?l01Qoo0000o`000?l01Qoo00000_l01Ql2o`000004o`057_l0003o00DNo`057P;o000000?o
00DNo`000?l000000ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000;o00DN00Ko
0000o`057_l0003o0000o`057_l00002o`057P;o000000Co00DNo`000?l01Ako00DN0_l000000ol0
1Ako0000o`000003o`000003o`057_l0003o000000?o000000Oo00DNo`000?l0003o0000o`057_l0
003o00DN00;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah2o`000004
o`057_l0003o00DNo`057P;o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000003o`00
01Gooooo0003ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003
ooooo`;o00008?ooool3o`0001?ooooo0_l000000ol01Ako0000o`057`02o`0000;o00HO00Co0000
o`067ol0003o00000_l01Al4o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000ol0
00000ol01Ako0000o`000002o`057P04o`000?l01Ako0000o`0000;o00DN00Ko0000o`057_l0003o
0000o`057_l00002o`057P;o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000003o`00
0003o`057_l0003o000000;o00DN00Ko0000o`057_l0003o0000obZJ0?l00002o`1T?`;o000000Co
00DNo`000?l01Ako00DN0_l000000ol01Ako0000o`000003o`000003o`067ol0003o000000?o0000
00?o00HOo`000?l000000ol000001Ol01Ako0000o`000?l01Ako000000;o00DN0_l000001?l01Ako
0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l000000ol00000
0ol01Ako0000o`000003o`000005o`057_l0003o0000o`057_l000000_l01Ah2o`000004o`057_l0
003o00DNo`057P;o000000Co00DNo`000?l01Ako00DN0_l000000ol01Ako0000o`000003o`000003
o`057_l0003o000000?o000000?o00DNo`000?l000000ol000001Ol01Ako0000o`000?l01Ako0000
00;o00DN0_l00003ooooo`03o`000?oooooooooo01Cooooo0004ooooo`;o00002Oooool3o`0000Co
oooo00?o0000ooooooooool07?ooool3o`0001Sooooo0ol000000ol01Qoo0000o`000003o`000007
o`067ol0003o0000o`000?l01Ako0000o`057P03o`000003o`057_l0003o00DN00;o00000_l01Ah0
1_l0003o00DNo`000?l0003o00DNo`0000;o00DN0_l000000ol01Ako0000o`000003o`000003o`05
7_l0003o000000?o000000?o00DNo`000?l000000_l01Ah01_l0003o00DNo`000?l0003o00DNo`00
00;o00DN0_l000001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o:YX0o`0000;o06@o1_l0
00001Ol01Ako0000o`000?l01Ako000000;o00DO0_l000001?l01Qoo0000o`067ol01Ql2o`000004
o`067ol0003o00DNo`057P;o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`000003o`00
0003o`057_l0003o000000?o000000Go00DNo`000?l0003o00DNo`000002o`057P;o000000?o00DN
o`000?l01Ah00ol000000ol01Ako0000o`057P03o`000003o`057_l0003o000000?o000000?o00DN
o`000?l000000ol000001_l01Ako0000o`000?l01Ako0000o`057P?o000000?o00DNo`000?l01Ah0
0ol000000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00?o00001Oooool00ol0003ooooo
ooooo`0Dooooo`005_ooool00ol0003oooooooooo`0Iooooo`?o00006oooool00ol0003o00DOo`00
0002o`000003o`057ol0003o00DN00?o000000?o00DNo`000?l01Ah00_l00002o`057PCo000000?o
00DNo`000?l000000ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000;o00DN00Co
0000o`057_l0003o00000_l01Ah01_l0003o00DNo`000?l0003o00DNo`0000;o00DN0_l000000ol0
1Ako0000o`000003o`000003o`057_l0003o000000?o000000Ko00DNo`000?l0003o0000obZJ0?l0
0002o`1T?`?o00000_l01Ah2o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l000000ol0
00000ol01Qoo0000o`000003o`000003o`057_l0003o000000;o00000_l01Ah2o`000003o`057_l0
003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P03o`000003o`057_l0
003o000000;o000000?o00DNo`000?l000000ol000001ol01Ako0000o`000?l0003o00DNo`000?l0
1Ah00ol000000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00;o000000?o00DNo`000?l0
00000ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000?o00002Oooool00ol0003o
ooooooooo`0Cooooo`005_ooool00ol0003oooooooooo`0Fooooo`?o00007oooool2o`000003o`05
7_l0003o000000;o00000_l01Ah4o`000007o`057_l0003o0000o`000?l01Ako0000o`057P03o`00
0003o`057_l0003o00DN00;o00000_l01Ah01Ol0003o00DNo`000?l0003o00DN00Go000000?o00DN
o`000?l000000ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000;o00DN00Ko0000
o`057_l0003o0000o`057_l00002o`057P;o000000Go00DNo`000?l0003o:YX0o`000002o`1T?`Go
000000?o00DNo`000?l000000_l00002o`057P;o000000Co00DNo`000?l01Qoo00HO0_l000000ol0
1Qoo0000o`067`03o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l000000_l00002o`05
7PCo000000?o00DNo`000?l000000ol000001ol01Ako0000o`000?l0003o00DNo`000?l01Ah00_l0
0002o`057P06o`000?l01Ako0000o`000?l01Ako00000_l01Ah2o`000003o`057_l0003o000000?o
000000?o00DNo`000?l000000ol000001Ol01Ako0000o`000?l01Ako000000;o00DN0_l000001?l0
1Ako0000o`057_l01Ah2o`0000kooooo00?o0000ooooooooool04oooool001Gooooo00?o0000oooo
ooooool05?ooool3o`0002Cooooo00Co0000o`057_l0003o00DN0ol000000ol01Ako0000o`057P03
o`000003o`057_l0003o00DN00;o00000_l01Ah4o`000003o`057_l0003o000000?o000000?o00DN
o`000?l000000_l01Ah01?l0003o00DNo`000?l00002o`057P06o`000?l01Ako0000o`000?l01Ako
00000_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l000000ol000000ol0
1Ako0000o`000002o`000004obZJ0?l0003o06@oo`1T?`;o00000_l01Ah2o`000003o`057_l0003o
00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Qoo0000o`000002o`0000;o00HO1?l00000
1ol01Ako0000o`000?l0003o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P02o`000004o`05
7_l0003o00DNo`057P;o000000Co00DNo`000?l01Ako00DN0_l000000ol01Ako0000o`000003o`00
0003o`057_l0003o000000?o000000Go00DNo`000?l0003o00DNo`000002o`057P;o000000Co00DN
o`000?l01Ako00DN0_l000000ol01Ako0000o`057P03o`000003o`057_l0003o000000?o00004?oo
ool00ol0003oooooooooo`0Cooooo`005Oooool2o`0001?ooooo0_l0000Wooooo`03o`000?l01Ako
000000;o000000?o00DNo`000?l000000_l00002o`057PCo000000Oo00DNo`000?l0003o0000o`05
7_l0003o00DN00?o000000?o00DNo`000?l01Ah00_l00002o`057P05o`000?l01Ako0000o`000?l0
1Ah01Ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000?o000000Go00DNo`000?l0
003o00DNo`000002o`057P;o000000Ko00DNo`000?l01Ako0000obZJ0?l00002o`1T?`Co000000?o
00DNo`000?l000000_l00002o`057PCo000000Oo00DNo`000?l0003o0000o`067ol0003o00HO00?o
000000?o00HOo`000?l01Ah00_l000001?l01Ako0000o`057_l01Ah2o`000003o`057_l0003o0000
00?o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000003o`000005o`057_l0003o0000
o`057_l000000_l01Ah2o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol00000
0ol01Ako0000o`000003o`000003o`057_l0003o000000;o000000Co00DNo`000?l0003o00005Ooo
ool00ol0003oooooooooo`0Cooooo`005Oooool00ol0003oooooooooo`0?ooooo`?o0000:_ooool0
0ol0003o00DNo`057P02o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol00000
0ol01Ako0000o`057P02o`0000;o00DN1?l000000ol01Ako0000o`000003o`000003o`057_l0003o
000000;o00DN00Ko0000o`057_l0003o0000o`057_l00002o`057P;o000000Co00DNo`000?l01Ako
00DN0_l000000ol01Ako0000o`000003o`000003o`057_l0003o000000?o000000Co:YX0o`000?l0
I3oo06@o1Ol000000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00;o00000_l01Ah01Ol0
003o00HOo`000?l0003o00HO00Go000000?o00DNo`000?l000000ol000001Ol01Ako0000o`000?l0
1Ako000000;o00DN0_l000001?l01Ako0000o`057_l01Ah2o`000003o`057_l0003o00DN00?o0000
00?o00DNo`000?l000000ol000000ol01Ako0000o`000002o`000003o`057_l0003o000000?o0000
00Oo00DNo`000?l0003o0000o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00_l0000Hoooo
o`03o`000?oooooooooo01?ooooo000Eooooo`03o`000?oooooooooo00cooooo0ol0000^ooooo`;o
000000?o00DNo`000?l000000ol000000ol01Ako0000o`000002o`0000;o00DN1?l000001ol01Ako
0000o`000?l0003o00DNo`000?l01Ah00_l00002o`057P06o`000?l01Ako0000o`000?l01Ako0000
0_l01Ah2o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000ol000001Ol01Ako0000
o`000?l01Ako000000;o00DN0_l000000ol01Ako0000o`057P02o`0000;o:YX000Co0000o`1T?ol0
003o00000_l01Ah4o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000ol000001Ol0
1Qoo0000o`000?l01Qoo000000;o00HO0_l000001?l01Ako0000o`057_l01Ah2o`000003o`057_l0
003o00DN00?o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000002o`000007o`057_l0
003o0000o`000?l01Ako0000o`057P03o`000003o`057_l0003o00DN00;o000000Co00DNo`000?l0
1Ako00DN0_l000000ol01Ako0000o`000003o`000003o`057_l0003o000000?o00006_ooool00ol0
003oooooooooo`0Cooooo`005Oooool2o`0000[ooooo0ol0000cooooo`03o`000?l01Ako000000;o
00DN0_l000000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l0
00000_l000000ol01Ako0000o`000003o`000003o`057_l0003o000000?o000000?o00DNo`000?l0
00000_l01Ah01_l0003o00DNo`000?l0003o00DNo`0000;o00DN0_l000000ol01Ako0000o`057P03
o`000003o`057_l0003o000000;o000000Co00DNo`000?l0003o:YX00_l000001olZVP3o0000o`00
0?l0003o00DNo`000?l01Ah00_l00002o`057P06o`000?l01Ako0000o`000?l01Ako00000_l01Ah2
o`000003o`067ol0003o000000?o000000?o00HOo`000?l000000ol000000ol01Ako0000o`000002
o`0000;o00DN0_l000000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00;o00000_l01Ah0
1Ol0003o00DNo`000?l0003o00DN00Go000000?o00DNo`000?l000000ol000001Ol01Ako0000o`00
0?l01Ako000000;o00DN0_l00004ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
4oooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oo
oooooooo00Kooooo0ol0000fooooo`03o`000?l01Ako000000;o000000?o00DNo`000?l000000ol0
00000ol01Ako0000o`000002o`0000;o00DN0_l000000ol01Ako0000o`057P03o`000003o`057_l0
003o00DN00;o00000_l01Ah01Ol0003o00DNo`000?l0003o00DN00Go000000?o00DNo`000?l00000
0ol000000ol01Ako0000o`000002o`0000;o00DN0_l000000ol01Ako0000o`057P04o`000008obZJ
0?l0003o0000obZJ0?l0003o00DNo`000?l01Ah2o`000003o`057_l0003o000000?o000000?o00DN
o`000?l000000ol000001Ol01Ako0000o`000?l01Qoo000000;o00HO0_l000000ol01Qoo0000o`05
7P03o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l000000_l000000ol01Ako0000o`00
0003o`000003o`057_l0003o000000?o000000Go00DNo`000?l0003o00DNo`000002o`057P;o0000
00?o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P03o`0000Oooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Booooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool3o`0003[ooooo0_l000001Ol01Ako0000
o`000?l01Ako000000;o00DN0_l000000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00;o
00000_l01Ah4o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000_l01Ah01_l0003o
00DNo`000?l0003o00DNo`0000;o00DN0_l000000ol01Ako0000o`057P03o`000003o`057_l0003o
000000;o00000_l01Ah2o`000004obZJ0?l0003o0000obZJ00Co000000?o00DNo`000?l000000_l0
1Ah01_l0003o00DNo`000?l0003o00DNo`0000;o00DN0_l000000ol01Ako0000o`067`03o`000003
o`067ol0003o000000;o00000_l01Ah4o`000007o`057_l0003o0000o`000?l01Ako0000o`057P02
o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`000?l01Ako00DN0_l000000ol01Ako0000
o`000003o`000003o`057_l0003o000000;o000000?o00DNo`000?l000000ol0000;ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool04_ooool00005ooooool0003oooooooooool00000
1oooool5o`0000?ooooo0_l00002ooooo`?o0000?oooool00ol0003o00DNo`000004o`000003o`05
7_l0003o000000?o000000?o00DNo`000?l000000_l000001ol01Ako0000o`000?l0003o00DNo`00
0?l01Ah00ol000000ol01Ako0000o`057P02o`000004o`057_l0003o00DNo`057P;o000000?o00DN
o`000?l000000ol000000ol01Ako0000o`000002o`0000;o00DN0_l000000ol01Ako0000o`057P05
o`000004obZJ0?l0003o0000obZJ00;o000000Co00DNo`000?l0003o00DN1Ol000000ol01Ako0000
o`000003o`000003o`057_l0003o000000;o000000Oo00HOo`000?l0003o0000o`067ol0003o00DO
00?o000000?o00DNo`000?l01Ah00_l000001?l01Ako0000o`057_l01Ah2o`000003o`057_l0003o
000000?o000000?o00DNo`000?l000000ol000001_l01Ako0000o`000?l01Ako0000o`057P?o0000
00?o00DNo`000?l01Ah00_l0000@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
4_ooool00005ooooool0003oooooooooool000001oooool01?l0003oooooooooool00004ooooo`Co
0000@oooool2o`000003o`057_l0003o00DN00;o000000Co00DNo`000?l01Ako00DN0_l000000ol0
1Ako0000o`057P03o`000003o`057_l0003o000000;o00000_l01Ah4o`000003o`057_l0003o0000
00?o000000Go00DNo`000?l0003o00DNo`000002o`057P;o000000?o00DNo`000?l01Ah00ol00000
0ol01Ako0000o`000002o`0000;o00DN0ol000001?lZVP3o0000o`000?lZVP03o`000005o`057_l0
003o0000o`057_l000000_l01Ah2o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah0
0_l00002o`057`Co000000?o00HOo`000?l000000ol000000ol01Ako0000o`000003o`000005o`05
7_l0003o0000o`057_l000000_l01Ah2o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l0
00000_l000000ol01Ako0000o`000003o`0001?ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Booooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`000?oooooo000000Co
oooo0_l00017ooooo`?o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000002o`0000;o
00DN0_l000000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00;o00000_l01Ah01Ol0003o
00DNo`000?l0003o00DN00Go000000?o00DNo`000?l000000_l00002o`057P;o000000?o00DNo`00
0?l01Ah00ol000001?l01Ako0000o`000?lZVP02o`000003obZJ0?l0003o00DN00;o000000?o00DN
o`000?l000000ol000000ol01Ako0000o`000002o`0000;o00DN1?l000001ol01Ako0000o`000?l0
003o00HOo`000?l01Ql00_l000001?l01Aoo0000o`057_l01Ah2o`000003o`057_l0003o00DN00?o
000000?o00DNo`000?l000000ol000000ol01Ako0000o`000002o`000007o`057_l0003o0000o`00
0?l01Ako0000o`057P02o`0001Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0B
ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`;o00001_ooool00ol0003oooooooooo`14
ooooo`04o`000?l01Ako0000o`0000;o00DN00Oo0000o`057_l0003o0000o`057_l0003o00DN00?o
000000?o00DNo`000?l000000_l00002o`057PCo000000?o00DNo`000?l000000ol000001Ol01Ako
0000o`000?l01Ako000000;o00DN0_l000000ol01Ako0000o`057P03o`000003o`057_l0003o0000
00;o00000_l01Ah4o`000004obZJ0?l0003o0000obZJ00;o000000Go00DNo`000?l0003o00DNo`00
0002o`057P;o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P02o`000003o`057_l0
003o000000?o000000?o00HOo`000?l000000ol000000ol01Ako0000o`000002o`0000;o00DN0_l0
00000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00;o000000?o00DNo`000?l000000ol0
000Looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool000;ooooo0_l0000;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?ooool00ol0003o00DNo`000004
o`000003o`057_l0003o000000?o000000Ko00DNo`000?l0003o00DNo`000?l01Ah3o`000003o`05
7_l0003o00DN00;o00000_l01Ah01Ol0003o00DNo`000?l0003o00DN00Go000000?o00DNo`000?l0
00000_l00002o`057P;o000000?o00DNo`000?l01Ah00ol000001Ol01Ako0000o`000?l0003o:YX0
00;o000000Go:YX0o`000?l0003o0000o`057P05o`000003o`057_l0003o000000;o000000?o00DN
o`000?l000000ol000000ol01Ako0000o`000002o`057P06o`000?l01Aoo0000o`000?l01Qoo0000
0_l01Al2o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l000000_l000000ol01Ako0000
o`000003o`000003o`057_l0003o0000027ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Booooo`006?ooool00ol0003oooooooooo`14ooooo`;o000000?o00DNo`000?l01Ah00_l0
00001?l01Ako0000o`057_l01Ah2o`000003o`057_l0003o000000?o000000?o00DNo`000?l00000
0_l000000ol01Ako0000o`000003o`000003o`057_l0003o000000;o00DN00Oo0000o`057_l0003o
0000o`057_l0003o00DN00?o000000?o00DNo`000?l000000_l00002o`057PGo000000Ko:YX0o`00
0?l0003o:YX0o`000?l01Ah2o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l01Ah0
0_l00002o`057P05o`000?l01Ako0000o`000?l01Ah01Ol000000ol01Aoo0000o`000003o`000003
o`067ol0003o000000;o000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00;o000000Co00DN
o`000?l01Ako00DN0_l0000Tooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04Ooo
ool001Wooooo0_l00016ooooo`?o000000?o00DNo`000?l000000ol000001Ol01Ako0000o`000?l0
1Ako000000;o00DN0_l000000ol01Ako0000o`057P03o`000003o`057_l0003o000000;o000000?o
00DNo`000?l000000ol000000ol01Ako0000o`000002o`0000;o00DN0_l000000ol01Ako0000o`05
7P03o`000003o`057_l0003o00DN00;o000000Co:YX0o`000?l0003o:YX00_l000000ol01Ako0000
o`000003o`000003o`057_l0003o000000;o000000?o00DNo`000?l000000ol000001Ol01Ako0000
o`000?l01Ako000000;o00DN0_l000000ol01Qoo0000o`067`03o`000003o`057_l0003o000000;o
000000?o00DNo`000?l000000ol000000ol01Ako0000o`000003o`0002Oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Aooooo`006oooool00ol0003oooooooooo`13ooooo`03o`00
0?l01Ako000000;o000000?o00DNo`000?l000000_l000000ol01Ako0000o`000003o`000003o`05
7_l0003o000000;o00000_l01Ah2o`000003o`057_l0003o00DN00;o00000_l01Ah01ol0003o00DN
o`000?l0003o00DNo`000?l01Ah00ol000000ol01Ako0000o`000002o`0000;o00DN1_l000001?lZ
VP3o0000o`000?lZVP03o`000003o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00_l00002
o`057PCo000000?o00DNo`000?l000000ol000000ol01Ako0000o`000002o`000007o`067ol0003o
0000o`000?l01Aoo0000o`057P02o`000004o`057_l0003o00DNo`057P;o0000;?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo04?ooooo
00?o0000o`057_l01Ah00_l000000ol01Ako0000o`057P02o`0000;o00DN00Oo0000o`057_l0003o
0000o`057_l0003o00DN00?o000000?o00DNo`000?l000000_l000000ol01Ako0000o`000003o`00
0003o`057_l0003o000000?o000000Ko00DNo`000?l0003o00DNo`000?l01Ah3o`000003o`057_l0
003o00DN00?o000000Ko:YX0o`000?l0003o:YX0o`000?l01Ah4o`0000;o00DN1?l000001ol01Ako
0000o`000?l0003o00DNo`000?l01Ah00_l000001?l01Ako0000o`057_l01Ah2o`000003o`057_l0
003o00DN00;o00000_l01Ql4o`000003o`057_l0003o000000?o0000;oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo017ooooo000Mooooo`03o`000?oooooooooo04?ooooo0_l00000
0ol01Ako0000o`000002o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000ol00000
1_l01Ako0000o`000?l01Ako0000o`057P?o000000?o00DNo`000?l01Ah00_l000000ol01Ako0000
o`000003o`000003o`057_l0003o000000;o00000_l01Ah4o`000004o`057_l0003o0000obZJ00;o
000000Ko:YX0o`000?l0003o00DNo`000?l01Ah3o`000003o`057_l0003o00DN00;o000000?o00DN
o`000?l000000ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000;o000000Oo00DO
o`000?l0003o0000o`067ol0003o00DN00;o0000=Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo000Nooooo`;o0000AOooool01?l0003o00DNo`000?l01Ah3o`000003o`05
7_l0003o00DN00;o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000002o`0000;o00DN
1?l000000ol01Ako0000o`000002o`057P07o`000?l01Ako0000o`000?l01Ako0000o`057P03o`00
0003o`057_l0003o00DN00Co000000Go:YX0o`000?l0003o0000o`057P04o`0000;o00DN1?l00000
0ol01Ako0000o`000002o`057P07o`000?l01Ako0000o`000?l01Ako0000o`057P03o`000003o`05
7_l0003o000000;o000000?o00DNo`000?l000000ol0000hooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04Oooool0023ooooo00?o0000ooooooooool0@oooool4o`000003o`057_l0
003o000000;o000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00;o000000?o00DNo`000?l0
1Ah00ol000000ol01Ako0000o`057P02o`000003o`057_l0003o000000?o000000?o00DNo`000?l0
00000_l00002o`057PCo000000Go00DNo`000?l0003o0000obZJ0004o`000003o`057_l0003o00DN
00?o000000?o00DNo`000?l000000_l000000ol01Ako0000o`000003o`000003o`057_l0003o0000
00;o00000_l01Ah2o`000003o`057_l0003o00DN00;o0000?Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo000Qooooo`03o`000?oooooooooo04;ooooo00?o0000o`057_l0
1Ah00_l000000ol01Ako0000o`057P02o`0000;o00DN1?l000000ol01Ako0000o`000003o`000003
o`057_l0003o000000;o000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00;o000000?o00DN
o`000?l01Ah00ol000000ol01Ako0000o`000002o`000004o`057_l0003o0000obZJ00Oo00000_l0
1Ah2o`000003o`057_l0003o00DN00;o000000Co00DNo`000?l01Ako00DN0_l000000ol01Ako0000
o`057P03o`000003o`057_l0003o000000;o0000@?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo04;ooooo0_l000000ol01Ako0000o`00
0002o`000007o`057_l0003o0000o`000?l01Ako0000o`057P02o`000004o`057_l0003o00DNo`05
7P;o000000?o00DNo`000?l000000_l00002o`057PCo000000?o00DNo`000?l000000_l00002o`05
7P;o000000?o00DNo`000?l01Ah00_l000000ol01Ako0000obZJ0003o`000003o`057_l0003o0000
00?o000000?o00DNo`000?l000000_l000000ol01Ako0000o`000003o`000003o`057_l0003o0000
00;o000000Co00DNo`000?l0003o0000AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo013ooooo000Sooooo`;o0000A?ooool00ol0003o00DNo`000004o`000003o`057_l0003o0000
00;o000000?o00DNo`000?l000000ol000001_l01Ako0000o`000?l01Ako0000o`057P?o000000?o
00DNo`000?l01Ah00_l000000ol01Ako0000o`000003o`000003o`057_l0003o000000;o000000Oo
00DNo`000?l0003o0000obZJ0?l0003o:YX000;o000000?o00DNo`000?l01Ah00ol000000ol01Ako
0000o`057P02o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l000000_l00019oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool002Gooooo00?o0000oooooooo
ool0@_ooool01Ol0003o00DNo`057_l0003o00DN00;o000000?o00DNo`000?l01Ah00_l00002o`05
7PCo000000?o00DNo`000?l000000_l00002o`057PCo000000?o00DNo`000?l000000_l01Ah01ol0
003o00DNo`000?l0003o00DNo`000?l01Ah00_l00002o`057P04o`000?lZVP3o0000obZJ00Go0000
0_l01Ah4o`000003o`057_l0003o000000?o000000?o00DNo`000?l00000COooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`000?oooooooooo04;ooooo1?l0
00000ol01Ako0000o`000002o`000007o`057_l0003o0000o`000?l01Ako0000o`057P02o`000003
o`057_l0003o00DN00?o000000?o00DNo`000?l000000_l000000ol01Ako0000o`000003o`000003
o`057_l0003o000000;o000000?o00DNo`000?l000000_l000001olZVP3o0000obZJ0?l0003o00DN
o`000?l01Ah00ol000000ol01Ako0000o`000002o`000003o`057_l0003o000000?o0000D?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo000Wooooo`03o`000?oooooooooo
04;ooooo00Go0000o`057_l0003o0000o`057P05o`000003o`057_l0003o000000;o000000?o00DN
o`000?l000000ol000001_l01Ako0000o`000?l01Ako0000o`057P;o00000_l01Ah01Ol0003o00DN
o`000?l0003o00DN00Co00000_l01Ah2o`000003obZJ0?l0003o:YX000Co00000_l01Ah2o`000003
o`057_l0003o00DN00;o0000E_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013o
oooo000Xooooo`;o0000@oooool01_l0003o00DNo`000?l0003o00DNo`0000;o00DN0_l000000ol0
1Ako0000o`057P02o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000_l000000ol0
1Ako0000o`000003o`000006o`057_l0003o0000o`057_l0003o00DN0ol000001Ol01Ako0000obZJ
0?l0003o:YX000Ko000000?o00DNo`000?l000000_l0001Hooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04?ooool002[ooooo00?o0000ooooooooool0@Oooool00ol0003o00DNo`00
0004o`000003o`057_l0003o000000;o000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00;o
000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`000002o`000003o`057_l0003o000000;o
00000_l01Ah3o`000006obZJ0?l0003o:YX0o`000?l01Ako00000_l01Ah2o`0005gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`11oooo
o`;o000000?o00DNo`000?l000000_l000000ol01Ako0000o`000002o`0000;o00DN1?l000000ol0
1Ako0000o`000002o`0000;o00DN0_l000000ol01Ako0000o`057P02o`000003o`057_l0003o00DN
00?o000000Ko00DNo`000?l0003o:YX0o`000?lZVP05o`00063ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0?ooooo`00;?ooool00ol0003oooooooooo`12ooooo`04o`000?l01Ako
0000o`057P;o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`000002o`000003o`057_l0
003o000000?o000000?o00DNo`000?l000000_l000000ol01Ako0000o`000002o`0000;o00DN0_l0
00000ol01Ako0000o`000003o`0006Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0?ooooo`00;Oooool2o`0004?ooooo0ol000000ol01Ako0000o`000003o`000006o`057_l0003o
0000o`057_l0003o00DN0_l000001?l01Ako0000o`057_l01Ah2o`000003o`057_l0003o000000;o
000000?o00DNo`000?l000000ol000001?l01Ako0000o`000?l00002ooXG00;o0000IOooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo000_ooooo`03o`000?oooooooooo047o
oooo0ol00002o`057PCo000000?o00DNo`000?l000000_l000000ol01Ako0000o`000003o`000006
o`057_l0003o0000o`057_l0003o00DN0_l00002o`057P04o`000?l01Ako0000o`0000?ooooo0_l0
001Xooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool0033ooooo00?o0000
ooooooooool0@?ooool00ol0003o00DNo`000002o`000003o`057_l0003o00DN00;o000000?o00DN
o`000?l000000_l00002o`057PCo000000?o00DNo`000?l000000_l000000ol01Ako0000o`000003
o`00073ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`00<Oooool00ol0
003oooooooooo`10ooooo`;o000000?o00DNo`000?l000000_l000001_l01Ako0000o`000?l01Ako
0000o`057P?o000000?o00DNo`000?l01Ah00_l000000ol01Ako0000o`000002o`0007Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`00<_ooool2o`0004;ooooo00?o0000
o`057_l000000ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000;o000000?o00DN
o`000?l00000N_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo000doooo
o`03o`000?oooooooooo043ooooo00Co0000o`057_l0003o00DN0_l00002o`057PCo000000?o00DN
o`000?l000000_l0001mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool0
03Gooooo00?o0000ooooooooool0@?ooool3o`000007o`057_l0003o0000o`000?l01Ako0000o`05
7P02o`0008;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`00=_ooool0
0ol0003oooooooooo`10ooooo`Co000000?o00DNo`000?l000000_l00024ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03_ooool003Oooooo0_l00012ooooo`?o0000ROooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo000iooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00ko
oooo000jooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Roooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00kooooo000kooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo000l
ooooo`;o0000?Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03Oooool003kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool003oooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`2>ooooo`05o`000?ooooooooooooooool000003oooool0043o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2>ooooo`05o`000?oooooooooooooo
ool000003oooool0047ooooo0_l0000hooooo`03o`000?oooooooooo08oooooo00Co0000oooooooo
oooo00003oooool004?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2@ooooo`03
o`000?oooooo000000oooooo0014ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
T?ooool01?l0003oooooooooool0000>ooooo`00AOooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooool000003_ooool004Kooooo0_l0000cooooo`03o`000?oo
oooooooo09;ooooo0_l0000>ooooo`00B?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo09;ooooo0ol0000>ooooo`00BOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
08kooooo1?l0000Aooooo`00B_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo08[o
oooo1?l0000Eooooo`00Boooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo08Oooooo
0ol0000Iooooo`00C?ooool2o`0002cooooo00?o0000ooooooooool0Poooool4o`0001cooooo001>
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Ooooool4o`00023ooooo001?oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Noooool4o`0002Cooooo001@ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0Moooool4o`0002Sooooo001Aooooo`;o0000
9oooool00ol0003oooooooooo`1dooooo`?o0000;?ooool005?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1`ooooo`Co0000;oooool005Cooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1/ooooo`Co0000<oooool005Gooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`1Xooooo`Co0000=oooool005Kooooo0_l0000Rooooo`03o`000?oooooooooo06Co
oooo1?l0000kooooo`00F?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo
0ol0000oooooo`00FOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05gooooo1?l0
0012ooooo`00F_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Wooooo1?l00016
ooooo`00Foooool2o`0001gooooo00?o0000ooooooooool0EOooool4o`0004[ooooo001Mooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool4o`0004kooooo001Nooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool3o`0005;ooooo001Oooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0B_ooool4o`0005Gooooo001Pooooo`;o00006?ooool0
0ol0003oooooooooo`16ooooo`Co0000FOooool006;ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`12ooooo`Co0000GOooool006?ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0nooooo`Co0000HOooool006Cooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0kooooo`?o0000IOooool006Gooooo0_l0000Cooooo`03o`000?oooooooooo03Oooooo1?l0
001Xooooo`00Ioooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo1?l0001/
ooooo`00J?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo1?l0001`oooo
o`00JOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo1?l0001dooooo`00
J_ooool2o`0000gooooo00?o0000ooooooooool0:Oooool3o`0007Sooooo001/ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool09Oooool4o`0007_ooooo001]ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool08Oooool4o`0007oooooo001^ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07Oooool4o`0008?ooooo001_ooooo`;o00002?ooool00ol0003o
ooooooooo`0Iooooo`Co0000Qoooool0077ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Fooooo`?o0000Roooool007;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Booooo`Co0000S_ooool007?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`Co0000T_ooool007Cooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002Foooo
o`00M_ooool01?l0003oooooooooool00008ooooo`Co0000V_ooool007Oooooo00?o0000ooooool0
00001Oooool3o`0009kooooo001hooooo`;o000000?oooooo`000?l000000_l0002Qooooo`00NOoo
ool2o`000:Gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo001hooooo`?o0000
DOooool3o`00057ooooo001iooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0D?oo
ool001kooooo0ol00004ooooo`?o00000_ooool3o`0000?ooooo1Ol00002ooooo`?o00000oooool3
o`0000Cooooo0_l00008ooooo`?o00001?ooool3o`0000;ooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o00000_ooool3o`0000Cooooo0ol0
0003ooooo`Co00000_ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o0000
0_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l00002ooooo`Go0000
0oooool2o`0000Cooooo00?o0000ooooooooool01oooool3o`0000Gooooo0_l000000ooooooo0000
o`000002o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o
00000_ooool3o`000003ooooool0003o000001Sooooo000Oooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooo
oooo0000ooooool00006ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000oooooooooooooooo
o`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Iooooo`007oooool00ol0
003oooooooooo`02ooooo`Go00000_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
ooooo`Go000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool5o`0000;ooooo0ol00002ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003ooooo
o`0000Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0Gooooo`007oooool3o`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooool000000oooool01?l0003oooooooooool0000;ooooo`?o00000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo
0_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000009ooooo`?o00000oooool01?l0003oooooooooool00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00006ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo01Oooooo000Oooooo`04o`000?ooooooooooo`0000;ooooo0ol00002ooooo`;o000000?ooooo
o`000?l000000_ooool4o`0000;ooooo0ol00003ooooo`?o00000_ooool4o`0000Wooooo00Co0000
oooooooooooo00000_ooool3o`0000;ooooo0ol00003ooooo`Co00000_ooool4o`0000Wooooo00?o
0000ooooooooool00_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000ooo
ool2o`0000Cooooo0ol0000:ooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`0000?ooooo
0ol00002ooooo`Co00000oooool4o`000004ooooool0003o0000o`0000?ooooo1?l00002ooooo`;o
000000?oooooo`000?l000002?ooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?l0
003ooooo1?l00003ooooo`?o00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000_ooool4o`00
01[ooooo000Oooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooool0000Looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000
5?ooool00ol0003oooooooooo`0/ooooo`007_ooool4o`00017ooooo0_l0000>ooooo`03o`000?oo
oooooooo00Sooooo1?l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_oo
ool3o`0001_ooooo0_l00008ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03_ooool5o`0001Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Uooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0771671, 0.0284147, \
0.00376288, 0.00376288}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -108 0 ]
[.5 .82364 108 9 ]
[.13049 .20567 -23.9762 -9 ]
[.13049 .20567 .0238 0 ]
[.33577 .12491 -5.58425 -9 ]
[.33577 .12491 .41575 0 ]
[.55826 .03745 -15.5233 -9 ]
[.55826 .03745 2.47666 0 ]
[.75923 .08444 0 -6.17413 ]
[.75923 .08444 24 2.82587 ]
[.85704 .23422 0 -6.03048 ]
[.85704 .23422 6 2.96952 ]
[.94201 .36435 0 -5.90954 ]
[.94201 .36435 18 3.09046 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01557 .31865 -24 -2.78758 ]
[.01557 .31865 0 6.21242 ]
[.00673 .37408 -18 -2.83462 ]
[.00673 .37408 0 6.16538 ]
[-0.00244 .43151 -24 -2.88352 ]
[-0.00244 .43151 0 6.11648 ]
[-0.01194 .49105 -6 -2.93442 ]
[-0.01194 .49105 0 6.06558 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Perfect Modulation Transfer Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13976 .21496 m
.1444 .2196 L
s
[(-100)] .13049 .20567 .99802 1 Mshowa
.34434 .13486 m
.34862 .13983 L
s
[(0)] .33577 .12491 .86142 1 Mshowa
.56596 .04808 m
.56981 .05339 L
s
[(100)] .55826 .03745 .72482 1 Mshowa
.125 Mabswid
.17941 .19944 m
.18215 .20226 L
s
.21968 .18367 m
.22238 .18653 L
s
.26058 .16765 m
.26323 .17056 L
s
.30212 .15139 m
.30474 .15433 L
s
.38723 .11806 m
.38975 .12108 L
s
.43082 .10099 m
.4333 .10405 L
s
.47513 .08364 m
.47755 .08675 L
s
.52017 .06601 m
.52254 .06915 L
s
.10072 .23025 m
.10354 .233 L
s
.06227 .2453 m
.06513 .24802 L
s
.61252 .02984 m
.61477 .03307 L
s
.65987 .0113 m
.66206 .01458 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74693 .08901 m
.74078 .0913 L
s
[(-100)] .75923 .08444 -1 .37203 Mshowa
.84462 .23845 m
.83841 .24056 L
s
[(0)] .85704 .23422 -1 .34011 Mshowa
.92949 .36827 m
.92323 .37023 L
s
[(100)] .94201 .36435 -1 .31323 Mshowa
.125 Mabswid
.76763 .12068 m
.76393 .12203 L
s
.78772 .15141 m
.78402 .15274 L
s
.80724 .18126 m
.80352 .18257 L
s
.82619 .21026 m
.82247 .21155 L
s
.86253 .26585 m
.8588 .2671 L
s
.87996 .2925 m
.87622 .29373 L
s
.89692 .31844 m
.89317 .31965 L
s
.91342 .34369 m
.90967 .34488 L
s
.72559 .05638 m
.72191 .05777 L
s
.70359 .02273 m
.69992 .02415 L
s
.94515 .39222 m
.94139 .39338 L
s
.9604 .41556 m
.95664 .4167 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02784 .31398 m
.03397 .31165 L
s
[(0.25)] .01557 .31865 1 -0.38054 Mshowa
.01903 .36953 m
.02519 .36725 L
s
[(0.5)] .00673 .37408 1 -0.37008 Mshowa
.00991 .42708 m
.01609 .42486 L
s
[(0.75)] -0.00244 .43151 1 -0.35922 Mshowa
.00046 .48674 m
.00665 .48459 L
s
[(1)] -0.01194 .49105 1 -0.34791 Mshowa
.125 Mabswid
.03466 .27092 m
.03833 .26949 L
s
.03297 .28157 m
.03664 .28015 L
s
.03127 .2923 m
.03495 .29089 L
s
.02956 .3031 m
.03324 .3017 L
s
.0261 .32493 m
.02978 .32354 L
s
.02435 .33597 m
.02804 .33458 L
s
.02259 .34707 m
.02628 .34569 L
s
.02082 .35826 m
.02451 .35689 L
s
.01723 .38087 m
.02093 .37951 L
s
.01542 .3923 m
.01912 .39095 L
s
.0136 .40381 m
.0173 .40247 L
s
.01176 .4154 m
.01547 .41406 L
s
.00805 .43884 m
.01176 .43751 L
s
.00617 .45068 m
.00988 .44937 L
s
.00428 .46261 m
.00799 .46131 L
s
.00238 .47463 m
.00609 .47333 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .024 .122 r
.40028 .59922 .40512 .60371 .41325 .6013 .40842 .5969 Metetra
0 .024 .122 r
.40842 .5969 .41325 .6013 .4214 .59888 .41658 .59463 Metetra
0 .024 .123 r
.41658 .59463 .4214 .59888 .42957 .59645 .42477 .59235 Metetra
0 .025 .123 r
.42477 .59235 .42957 .59645 .43778 .59402 .43298 .59007 Metetra
0 .025 .124 r
.43298 .59007 .43778 .59402 .446 .59158 .44122 .58779 Metetra
0 .025 .124 r
.44122 .58779 .446 .59158 .45425 .58913 .44948 .5855 Metetra
0 .026 .125 r
.44948 .5855 .45425 .58913 .46253 .58667 .45778 .5832 Metetra
0 .026 .125 r
.45778 .5832 .46253 .58667 .47083 .58421 .46609 .5809 Metetra
0 .026 .126 r
.46609 .5809 .47083 .58421 .47916 .58174 .47444 .57858 Metetra
0 .027 .126 r
.47444 .57858 .47916 .58174 .48751 .57926 .48281 .57627 Metetra
0 .027 .127 r
.48281 .57627 .48751 .57926 .49589 .57678 .4912 .57394 Metetra
0 .028 .127 r
.4912 .57394 .49589 .57678 .50429 .57429 .49963 .57161 Metetra
0 .028 .128 r
.49963 .57161 .50429 .57429 .51272 .57179 .50808 .56926 Metetra
0 .028 .128 r
.50808 .56926 .51272 .57179 .52118 .56928 .51656 .56692 Metetra
0 .029 .129 r
.51656 .56692 .52118 .56928 .52966 .56676 .52506 .56456 Metetra
0 .029 .129 r
.52506 .56456 .52966 .56676 .53817 .56424 .5336 .5622 Metetra
0 .03 .13 r
.5336 .5622 .53817 .56424 .54671 .56171 .54216 .55983 Metetra
0 .03 .13 r
.54216 .55983 .54671 .56171 .55527 .55917 .55075 .55745 Metetra
0 .03 .131 r
.55075 .55745 .55527 .55917 .56386 .55662 .55936 .55506 Metetra
0 .031 .131 r
.55936 .55506 .56386 .55662 .57247 .55407 .56801 .55267 Metetra
0 .031 .132 r
.56801 .55267 .57247 .55407 .58112 .5515 .57668 .55026 Metetra
0 .032 .132 r
.57668 .55026 .58112 .5515 .58979 .54893 .58538 .54785 Metetra
0 .032 .133 r
.58538 .54785 .58979 .54893 .59848 .54635 .59411 .54544 Metetra
0 .032 .133 r
.59411 .54544 .59848 .54635 .60721 .54376 .60286 .54301 Metetra
0 .033 .134 r
.60286 .54301 .60721 .54376 .61596 .54117 .61165 .54057 Metetra
0 .033 .134 r
.61165 .54057 .61596 .54117 .62474 .53856 .62046 .53813 Metetra
0 .034 .135 r
.62046 .53813 .62474 .53856 .63355 .53595 .62931 .53568 Metetra
0 .034 .135 r
.62931 .53568 .63355 .53595 .64238 .53333 .63818 .53322 Metetra
0 .035 .136 r
.63818 .53322 .64238 .53333 .65125 .5307 .64708 .53075 Metetra
0 .035 .136 r
.64708 .53075 .65125 .5307 .66014 .52806 .65601 .52827 Metetra
0 .035 .137 r
.65601 .52827 .66014 .52806 .66906 .52541 .66497 .52576 Metetra
0 .036 .137 r
.66497 .52576 .66906 .52541 .678 .52274 .67395 .52311 Metetra
0 .035 .137 r
.67395 .52311 .678 .52274 .68698 .52002 .68296 .52023 Metetra
0 .035 .136 r
.68296 .52023 .68698 .52002 .69598 .5173 .69198 .51733 Metetra
0 .035 .136 r
.69198 .51733 .69598 .5173 .70501 .51456 .70104 .51441 Metetra
0 .034 .135 r
.70104 .51441 .70501 .51456 .71407 .51181 .71012 .51148 Metetra
0 .034 .135 r
.71012 .51148 .71407 .51181 .72316 .50906 .71924 .50853 Metetra
0 .033 .134 r
.71924 .50853 .72316 .50906 .73228 .5063 .72838 .50558 Metetra
0 .033 .134 r
.72838 .50558 .73228 .5063 .74142 .50352 .73754 .50262 Metetra
0 .033 .133 r
.73754 .50262 .74142 .50352 .7506 .50074 .74674 .49965 Metetra
0 .032 .133 r
.74674 .49965 .7506 .50074 .7598 .49795 .75596 .49668 Metetra
0 .032 .132 r
.75596 .49668 .7598 .49795 .76904 .49515 .76522 .49369 Metetra
0 .031 .132 r
.76522 .49369 .76904 .49515 .7783 .49235 .7745 .49069 Metetra
0 .031 .131 r
.7745 .49069 .7783 .49235 .78759 .48953 .78381 .48768 Metetra
0 .03 .131 r
.78381 .48768 .78759 .48953 .79692 .4867 .79315 .48466 Metetra
0 .03 .13 r
.79315 .48466 .79692 .4867 .80627 .48387 .80252 .48164 Metetra
0 .03 .13 r
.80252 .48164 .80627 .48387 .81566 .48102 .81192 .4786 Metetra
0 .029 .129 r
.81192 .4786 .81566 .48102 .82507 .47817 .82135 .47556 Metetra
0 .029 .129 r
.82135 .47556 .82507 .47817 .83452 .47531 .83081 .4725 Metetra
0 .028 .128 r
.83081 .4725 .83452 .47531 .84399 .47244 .8403 .46944 Metetra
0 .028 .128 r
.8403 .46944 .84399 .47244 .8535 .46955 .84982 .46636 Metetra
0 .028 .127 r
.84982 .46636 .8535 .46955 .86303 .46666 .85936 .46328 Metetra
0 .027 .127 r
.85936 .46328 .86303 .46666 .8726 .46376 .86894 .46018 Metetra
0 .027 .126 r
.86894 .46018 .8726 .46376 .8822 .46085 .87855 .45708 Metetra
0 .027 .126 r
.87855 .45708 .8822 .46085 .89183 .45794 .88819 .45397 Metetra
0 .026 .125 r
.88819 .45397 .89183 .45794 .9015 .45501 .89786 .45085 Metetra
0 .026 .125 r
.89786 .45085 .9015 .45501 .91119 .45207 .90756 .44772 Metetra
0 .025 .124 r
.90756 .44772 .91119 .45207 .92092 .44912 .91729 .44457 Metetra
0 .025 .124 r
.91729 .44457 .92092 .44912 .93067 .44616 .92706 .44142 Metetra
0 .025 .123 r
.92706 .44142 .93067 .44616 .94046 .4432 .93685 .43826 Metetra
0 .024 .123 r
.93685 .43826 .94046 .4432 .95029 .44022 .94668 .43509 Metetra
0 .024 .122 r
.94668 .43509 .95029 .44022 .96014 .43724 .95654 .43192 Metetra
0 .024 .122 r
.95654 .43192 .96014 .43724 .97003 .43424 .96643 .42876 Metetra
0 .024 .122 r
.39541 .59469 .40028 .59922 .40842 .5969 .40356 .59251 Metetra
0 .025 .123 r
.40356 .59251 .40842 .5969 .41658 .59463 .41173 .5904 Metetra
0 .026 .124 r
.41173 .5904 .41658 .59463 .42477 .59235 .41993 .5883 Metetra
0 .026 .126 r
.41993 .5883 .42477 .59235 .43298 .59007 .42815 .5862 Metetra
0 .027 .127 r
.42815 .5862 .43298 .59007 .44122 .58779 .43641 .5841 Metetra
0 .028 .128 r
.43641 .5841 .44122 .58779 .44948 .5855 .44468 .58199 Metetra
0 .03 .13 r
.44468 .58199 .44948 .5855 .45778 .5832 .45299 .57987 Metetra
0 .031 .131 r
.45299 .57987 .45778 .5832 .46609 .5809 .46132 .57774 Metetra
0 .032 .132 r
.46132 .57774 .46609 .5809 .47444 .57858 .46968 .57561 Metetra
0 .033 .133 r
.46968 .57561 .47444 .57858 .48281 .57627 .47807 .57348 Metetra
0 .034 .135 r
.47807 .57348 .48281 .57627 .4912 .57394 .48649 .57133 Metetra
0 .035 .136 r
.48649 .57133 .4912 .57394 .49963 .57161 .49493 .56918 Metetra
0 .036 .137 r
.49493 .56918 .49963 .57161 .50808 .56926 .5034 .56702 Metetra
0 .037 .139 r
.5034 .56702 .50808 .56926 .51656 .56692 .5119 .56486 Metetra
0 .038 .14 r
.5119 .56486 .51656 .56692 .52506 .56456 .52043 .56269 Metetra
0 .039 .141 r
.52043 .56269 .52506 .56456 .5336 .5622 .52899 .56051 Metetra
0 .041 .143 r
.52899 .56051 .5336 .5622 .54216 .55983 .53758 .55832 Metetra
0 .042 .144 r
.53758 .55832 .54216 .55983 .55075 .55745 .54619 .55613 Metetra
0 .043 .145 r
.54619 .55613 .55075 .55745 .55936 .55506 .55484 .55392 Metetra
0 .044 .147 r
.55484 .55392 .55936 .55506 .56801 .55267 .56351 .55172 Metetra
0 .046 .148 r
.56351 .55172 .56801 .55267 .57668 .55026 .57221 .5495 Metetra
0 .047 .149 r
.57221 .5495 .57668 .55026 .58538 .54785 .58094 .54727 Metetra
0 .048 .151 r
.58094 .54727 .58538 .54785 .59411 .54544 .58971 .54504 Metetra
0 .049 .152 r
.58971 .54504 .59411 .54544 .60286 .54301 .5985 .5428 Metetra
0 .051 .153 r
.5985 .5428 .60286 .54301 .61165 .54057 .60732 .54055 Metetra
0 .052 .155 r
.60732 .54055 .61165 .54057 .62046 .53813 .61617 .5383 Metetra
0 .053 .156 r
.61617 .5383 .62046 .53813 .62931 .53568 .62505 .53603 Metetra
0 .055 .157 r
.62505 .53603 .62931 .53568 .63818 .53322 .63396 .53376 Metetra
0 .056 .158 r
.63396 .53376 .63818 .53322 .64708 .53075 .64291 .53148 Metetra
0 .057 .16 r
.64291 .53148 .64708 .53075 .65601 .52827 .65188 .52918 Metetra
0 .059 .161 r
.65188 .52918 .65601 .52827 .66497 .52576 .66088 .52685 Metetra
0 .059 .162 r
.66088 .52685 .66497 .52576 .67395 .52311 .6699 .52423 Metetra
0 .059 .161 r
.6699 .52423 .67395 .52311 .68296 .52023 .67893 .52116 Metetra
0 .058 .16 r
.67893 .52116 .68296 .52023 .69198 .51733 .68799 .51805 Metetra
0 .056 .159 r
.68799 .51805 .69198 .51733 .70104 .51441 .69707 .51492 Metetra
0 .055 .158 r
.69707 .51492 .70104 .51441 .71012 .51148 .70618 .51177 Metetra
0 .054 .156 r
.70618 .51177 .71012 .51148 .71924 .50853 .71531 .50862 Metetra
0 .052 .155 r
.71531 .50862 .71924 .50853 .72838 .50558 .72448 .50546 Metetra
0 .051 .154 r
.72448 .50546 .72838 .50558 .73754 .50262 .73367 .50228 Metetra
0 .05 .152 r
.73367 .50228 .73754 .50262 .74674 .49965 .74289 .4991 Metetra
0 .048 .151 r
.74289 .4991 .74674 .49965 .75596 .49668 .75213 .49591 Metetra
0 .047 .15 r
.75213 .49591 .75596 .49668 .76522 .49369 .7614 .49271 Metetra
0 .046 .148 r
.7614 .49271 .76522 .49369 .7745 .49069 .77071 .48949 Metetra
0 .045 .147 r
.77071 .48949 .7745 .49069 .78381 .48768 .78004 .48627 Metetra
0 .043 .146 r
.78004 .48627 .78381 .48768 .79315 .48466 .78939 .48304 Metetra
0 .042 .144 r
.78939 .48304 .79315 .48466 .80252 .48164 .79878 .4798 Metetra
0 .041 .143 r
.79878 .4798 .80252 .48164 .81192 .4786 .80819 .47654 Metetra
0 .04 .142 r
.80819 .47654 .81192 .4786 .82135 .47556 .81764 .47328 Metetra
0 .039 .14 r
.81764 .47328 .82135 .47556 .83081 .4725 .82711 .47001 Metetra
0 .037 .139 r
.82711 .47001 .83081 .4725 .8403 .46944 .83661 .46673 Metetra
0 .036 .138 r
.83661 .46673 .8403 .46944 .84982 .46636 .84614 .46344 Metetra
0 .035 .136 r
.84614 .46344 .84982 .46636 .85936 .46328 .85569 .46014 Metetra
0 .034 .135 r
.85569 .46014 .85936 .46328 .86894 .46018 .86528 .45683 Metetra
0 .033 .134 r
.86528 .45683 .86894 .46018 .87855 .45708 .8749 .4535 Metetra
0 .032 .132 r
.8749 .4535 .87855 .45708 .88819 .45397 .88454 .45017 Metetra
0 .031 .131 r
.88454 .45017 .88819 .45397 .89786 .45085 .89422 .44683 Metetra
0 .03 .13 r
.89422 .44683 .89786 .45085 .90756 .44772 .90393 .44348 Metetra
0 .029 .129 r
.90393 .44348 .90756 .44772 .91729 .44457 .91366 .44012 Metetra
0 .028 .127 r
.91366 .44012 .91729 .44457 .92706 .44142 .92343 .43675 Metetra
0 .027 .126 r
.92343 .43675 .92706 .44142 .93685 .43826 .93322 .43337 Metetra
0 .026 .125 r
.93322 .43337 .93685 .43826 .94668 .43509 .94305 .42998 Metetra
0 .025 .123 r
.94305 .42998 .94668 .43509 .95654 .43192 .95291 .4266 Metetra
0 .024 .122 r
.95291 .4266 .95654 .43192 .96643 .42876 .9628 .42325 Metetra
0 .024 .122 r
.39052 .59015 .39541 .59469 .40356 .59251 .39868 .58809 Metetra
0 .025 .124 r
.39868 .58809 .40356 .59251 .41173 .5904 .40686 .58615 Metetra
0 .027 .126 r
.40686 .58615 .41173 .5904 .41993 .5883 .41506 .58424 Metetra
0 .029 .128 r
.41506 .58424 .41993 .5883 .42815 .5862 .4233 .58233 Metetra
0 .03 .131 r
.4233 .58233 .42815 .5862 .43641 .5841 .43156 .58042 Metetra
0 .032 .133 r
.43156 .58042 .43641 .5841 .44468 .58199 .43985 .5785 Metetra
0 .034 .135 r
.43985 .5785 .44468 .58199 .45299 .57987 .44817 .57657 Metetra
0 .036 .137 r
.44817 .57657 .45299 .57987 .46132 .57774 .45652 .57464 Metetra
0 .038 .139 r
.45652 .57464 .46132 .57774 .46968 .57561 .4649 .5727 Metetra
0 .04 .142 r
.4649 .5727 .46968 .57561 .47807 .57348 .4733 .57075 Metetra
0 .042 .144 r
.4733 .57075 .47807 .57348 .48649 .57133 .48174 .5688 Metetra
0 .044 .146 r
.48174 .5688 .48649 .57133 .49493 .56918 .4902 .56684 Metetra
0 .046 .148 r
.4902 .56684 .49493 .56918 .5034 .56702 .49869 .56487 Metetra
0 .048 .15 r
.49869 .56487 .5034 .56702 .5119 .56486 .50722 .5629 Metetra
0 .05 .153 r
.50722 .5629 .5119 .56486 .52043 .56269 .51577 .56092 Metetra
0 .052 .155 r
.51577 .56092 .52043 .56269 .52899 .56051 .52435 .55893 Metetra
0 .054 .157 r
.52435 .55893 .52899 .56051 .53758 .55832 .53296 .55694 Metetra
0 .057 .159 r
.53296 .55694 .53758 .55832 .54619 .55613 .5416 .55494 Metetra
0 .059 .161 r
.5416 .55494 .54619 .55613 .55484 .55392 .55028 .55293 Metetra
0 .061 .164 r
.55028 .55293 .55484 .55392 .56351 .55172 .55898 .55092 Metetra
0 .064 .166 r
.55898 .55092 .56351 .55172 .57221 .5495 .56771 .54889 Metetra
0 .066 .168 r
.56771 .54889 .57221 .5495 .58094 .54727 .57648 .54687 Metetra
0 .069 .17 r
.57648 .54687 .58094 .54727 .58971 .54504 .58527 .54483 Metetra
0 .071 .172 r
.58527 .54483 .58971 .54504 .5985 .5428 .5941 .54278 Metetra
0 .074 .175 r
.5941 .54278 .5985 .5428 .60732 .54055 .60295 .54073 Metetra
0 .076 .177 r
.60295 .54073 .60732 .54055 .61617 .5383 .61184 .53867 Metetra
0 .079 .179 r
.61184 .53867 .61617 .5383 .62505 .53603 .62076 .53661 Metetra
0 .082 .181 r
.62076 .53661 .62505 .53603 .63396 .53376 .62971 .53453 Metetra
0 .084 .183 r
.62971 .53453 .63396 .53376 .64291 .53148 .6387 .53245 Metetra
0 .087 .185 r
.6387 .53245 .64291 .53148 .65188 .52918 .64771 .53035 Metetra
0 .09 .188 r
.64771 .53035 .65188 .52918 .66088 .52685 .65676 .52819 Metetra
0 .091 .189 r
.65676 .52819 .66088 .52685 .6699 .52423 .66582 .52561 Metetra
0 .091 .188 r
.66582 .52561 .6699 .52423 .67893 .52116 .67488 .52235 Metetra
0 .088 .186 r
.67488 .52235 .67893 .52116 .68799 .51805 .68396 .51902 Metetra
0 .085 .184 r
.68396 .51902 .68799 .51805 .69707 .51492 .69307 .51566 Metetra
0 .082 .182 r
.69307 .51566 .69707 .51492 .70618 .51177 .70221 .5123 Metetra
0 .08 .179 r
.70221 .5123 .70618 .51177 .71531 .50862 .71137 .50892 Metetra
0 .077 .177 r
.71137 .50892 .71531 .50862 .72448 .50546 .72055 .50553 Metetra
0 .074 .175 r
.72055 .50553 .72448 .50546 .73367 .50228 .72977 .50214 Metetra
0 .072 .173 r
.72977 .50214 .73367 .50228 .74289 .4991 .73901 .49873 Metetra
0 .069 .171 r
.73901 .49873 .74289 .4991 .75213 .49591 .74828 .49531 Metetra
0 .067 .168 r
.74828 .49531 .75213 .49591 .7614 .49271 .75757 .49189 Metetra
0 .064 .166 r
.75757 .49189 .7614 .49271 .77071 .48949 .76689 .48845 Metetra
0 .062 .164 r
.76689 .48845 .77071 .48949 .78004 .48627 .77624 .485 Metetra
0 .06 .162 r
.77624 .485 .78004 .48627 .78939 .48304 .78561 .48155 Metetra
0 .057 .16 r
.78561 .48155 .78939 .48304 .79878 .4798 .79501 .47808 Metetra
0 .055 .157 r
.79501 .47808 .79878 .4798 .80819 .47654 .80444 .4746 Metetra
0 .053 .155 r
.80444 .4746 .80819 .47654 .81764 .47328 .8139 .47112 Metetra
0 .051 .153 r
.8139 .47112 .81764 .47328 .82711 .47001 .82339 .46762 Metetra
0 .048 .151 r
.82339 .46762 .82711 .47001 .83661 .46673 .8329 .46411 Metetra
0 .046 .149 r
.8329 .46411 .83661 .46673 .84614 .46344 .84244 .46059 Metetra
0 .044 .146 r
.84244 .46059 .84614 .46344 .85569 .46014 .85201 .45707 Metetra
0 .042 .144 r
.85201 .45707 .85569 .46014 .86528 .45683 .8616 .45353 Metetra
0 .04 .142 r
.8616 .45353 .86528 .45683 .8749 .4535 .87123 .44998 Metetra
0 .038 .14 r
.87123 .44998 .8749 .4535 .88454 .45017 .88088 .44642 Metetra
0 .036 .138 r
.88088 .44642 .88454 .45017 .89422 .44683 .89056 .44285 Metetra
0 .034 .136 r
.89056 .44285 .89422 .44683 .90393 .44348 .90027 .43927 Metetra
0 .033 .133 r
.90027 .43927 .90393 .44348 .91366 .44012 .91001 .43568 Metetra
0 .031 .131 r
.91001 .43568 .91366 .44012 .92343 .43675 .91978 .43208 Metetra
0 .029 .129 r
.91978 .43208 .92343 .43675 .93322 .43337 .92957 .42847 Metetra
0 .027 .127 r
.92957 .42847 .93322 .43337 .94305 .42998 .9394 .42486 Metetra
0 .026 .125 r
.9394 .42486 .94305 .42998 .95291 .4266 .94926 .42126 Metetra
0 .024 .123 r
.94926 .42126 .95291 .4266 .9628 .42325 .95916 .41771 Metetra
0 .024 .123 r
.3856 .58557 .39052 .59015 .39868 .58809 .39376 .58366 Metetra
0 .026 .125 r
.39376 .58366 .39868 .58809 .40686 .58615 .40195 .58189 Metetra
0 .028 .128 r
.40195 .58189 .40686 .58615 .41506 .58424 .41017 .58017 Metetra
0 .031 .131 r
.41017 .58017 .41506 .58424 .4233 .58233 .41841 .57845 Metetra
0 .033 .134 r
.41841 .57845 .4233 .58233 .43156 .58042 .42669 .57673 Metetra
0 .036 .137 r
.42669 .57673 .43156 .58042 .43985 .5785 .43499 .575 Metetra
0 .039 .141 r
.43499 .575 .43985 .5785 .44817 .57657 .44332 .57326 Metetra
0 .042 .144 r
.44332 .57326 .44817 .57657 .45652 .57464 .45168 .57152 Metetra
0 .044 .147 r
.45168 .57152 .45652 .57464 .4649 .5727 .46008 .56978 Metetra
0 .047 .15 r
.46008 .56978 .4649 .5727 .4733 .57075 .4685 .56802 Metetra
0 .05 .153 r
.4685 .56802 .4733 .57075 .48174 .5688 .47695 .56626 Metetra
0 .053 .156 r
.47695 .56626 .48174 .5688 .4902 .56684 .48543 .5645 Metetra
0 .057 .159 r
.48543 .5645 .4902 .56684 .49869 .56487 .49395 .56273 Metetra
0 .06 .162 r
.49395 .56273 .49869 .56487 .50722 .5629 .50249 .56095 Metetra
0 .063 .165 r
.50249 .56095 .50722 .5629 .51577 .56092 .51107 .55916 Metetra
0 .067 .168 r
.51107 .55916 .51577 .56092 .52435 .55893 .51967 .55737 Metetra
0 .07 .172 r
.51967 .55737 .52435 .55893 .53296 .55694 .52831 .55558 Metetra
0 .074 .175 r
.52831 .55558 .53296 .55694 .5416 .55494 .53698 .55377 Metetra
0 .078 .178 r
.53698 .55377 .5416 .55494 .55028 .55293 .54568 .55196 Metetra
0 .081 .181 r
.54568 .55196 .55028 .55293 .55898 .55092 .55441 .55014 Metetra
0 .085 .184 r
.55441 .55014 .55898 .55092 .56771 .54889 .56317 .54832 Metetra
0 .089 .187 r
.56317 .54832 .56771 .54889 .57648 .54687 .57197 .54649 Metetra
0 .093 .19 r
.57197 .54649 .57648 .54687 .58527 .54483 .5808 .54465 Metetra
0 .097 .193 r
.5808 .54465 .58527 .54483 .5941 .54278 .58966 .54281 Metetra
0 .102 .196 r
.58966 .54281 .5941 .54278 .60295 .54073 .59855 .54096 Metetra
0 .106 .199 r
.59855 .54096 .60295 .54073 .61184 .53867 .60748 .5391 Metetra
0 .11 .203 r
.60748 .5391 .61184 .53867 .62076 .53661 .61644 .53723 Metetra
0 .115 .206 r
.61644 .53723 .62076 .53661 .62971 .53453 .62543 .53536 Metetra
0 .119 .209 r
.62543 .53536 .62971 .53453 .6387 .53245 .63445 .53348 Metetra
0 .124 .212 r
.63445 .53348 .6387 .53245 .64771 .53035 .64351 .53157 Metetra
0 .128 .215 r
.64351 .53157 .64771 .53035 .65676 .52819 .6526 .5296 Metetra
0 .131 .216 r
.6526 .5296 .65676 .52819 .66582 .52561 .6617 .52705 Metetra
0 .129 .215 r
.6617 .52705 .66582 .52561 .67488 .52235 .67079 .52359 Metetra
0 .125 .213 r
.67079 .52359 .67488 .52235 .68396 .51902 .6799 .52004 Metetra
0 .12 .209 r
.6799 .52004 .68396 .51902 .69307 .51566 .68904 .51646 Metetra
0 .116 .206 r
.68904 .51646 .69307 .51566 .70221 .5123 .6982 .51287 Metetra
0 .111 .203 r
.6982 .51287 .70221 .5123 .71137 .50892 .70739 .50926 Metetra
0 .107 .2 r
.70739 .50926 .71137 .50892 .72055 .50553 .7166 .50565 Metetra
0 .103 .197 r
.7166 .50565 .72055 .50553 .72977 .50214 .72584 .50203 Metetra
0 .098 .194 r
.72584 .50203 .72977 .50214 .73901 .49873 .7351 .49839 Metetra
0 .094 .191 r
.7351 .49839 .73901 .49873 .74828 .49531 .74439 .49475 Metetra
0 .09 .188 r
.74439 .49475 .74828 .49531 .75757 .49189 .7537 .4911 Metetra
0 .086 .185 r
.7537 .4911 .75757 .49189 .76689 .48845 .76304 .48743 Metetra
0 .082 .182 r
.76304 .48743 .76689 .48845 .77624 .485 .77241 .48376 Metetra
0 .079 .179 r
.77241 .48376 .77624 .485 .78561 .48155 .7818 .48007 Metetra
0 .075 .175 r
.7818 .48007 .78561 .48155 .79501 .47808 .79122 .47638 Metetra
0 .071 .172 r
.79122 .47638 .79501 .47808 .80444 .4746 .80067 .47267 Metetra
0 .068 .169 r
.80067 .47267 .80444 .4746 .8139 .47112 .81014 .46896 Metetra
0 .064 .166 r
.81014 .46896 .8139 .47112 .82339 .46762 .81964 .46523 Metetra
0 .061 .163 r
.81964 .46523 .82339 .46762 .8329 .46411 .82916 .4615 Metetra
0 .057 .16 r
.82916 .4615 .8329 .46411 .84244 .46059 .83871 .45775 Metetra
0 .054 .157 r
.83871 .45775 .84244 .46059 .85201 .45707 .84829 .45399 Metetra
0 .051 .154 r
.84829 .45399 .85201 .45707 .8616 .45353 .8579 .45022 Metetra
0 .048 .151 r
.8579 .45022 .8616 .45353 .87123 .44998 .86753 .44644 Metetra
0 .045 .148 r
.86753 .44644 .87123 .44998 .88088 .44642 .87719 .44266 Metetra
0 .042 .144 r
.87719 .44266 .88088 .44642 .89056 .44285 .88688 .43886 Metetra
0 .039 .141 r
.88688 .43886 .89056 .44285 .90027 .43927 .89659 .43505 Metetra
0 .037 .138 r
.89659 .43505 .90027 .43927 .91001 .43568 .90633 .43122 Metetra
0 .034 .135 r
.90633 .43122 .91001 .43568 .91978 .43208 .9161 .42739 Metetra
0 .032 .132 r
.9161 .42739 .91978 .43208 .92957 .42847 .9259 .42355 Metetra
0 .029 .129 r
.9259 .42355 .92957 .42847 .9394 .42486 .93573 .4197 Metetra
0 .027 .126 r
.93573 .4197 .9394 .42486 .94926 .42126 .94559 .41588 Metetra
0 .025 .123 r
.94559 .41588 .94926 .42126 .95916 .41771 .95549 .41213 Metetra
0 .025 .123 r
.38064 .58097 .3856 .58557 .39376 .58366 .38882 .57919 Metetra
0 .027 .126 r
.38882 .57919 .39376 .58366 .40195 .58189 .39702 .57761 Metetra
0 .03 .13 r
.39702 .57761 .40195 .58189 .41017 .58017 .40524 .57607 Metetra
0 .033 .134 r
.40524 .57607 .41017 .58017 .41841 .57845 .4135 .57454 Metetra
0 .037 .138 r
.4135 .57454 .41841 .57845 .42669 .57673 .42178 .57301 Metetra
0 .04 .142 r
.42178 .57301 .42669 .57673 .43499 .575 .43009 .57148 Metetra
0 .044 .146 r
.43009 .57148 .43499 .575 .44332 .57326 .43844 .56994 Metetra
0 .048 .15 r
.43844 .56994 .44332 .57326 .45168 .57152 .44682 .56839 Metetra
0 .052 .154 r
.44682 .56839 .45168 .57152 .46008 .56978 .45522 .56684 Metetra
0 .056 .158 r
.45522 .56684 .46008 .56978 .4685 .56802 .46366 .56528 Metetra
0 .06 .162 r
.46366 .56528 .4685 .56802 .47695 .56626 .47213 .56371 Metetra
0 .064 .166 r
.47213 .56371 .47695 .56626 .48543 .5645 .48063 .56214 Metetra
0 .069 .17 r
.48063 .56214 .48543 .5645 .49395 .56273 .48917 .56057 Metetra
0 .073 .174 r
.48917 .56057 .49395 .56273 .50249 .56095 .49773 .55899 Metetra
0 .078 .178 r
.49773 .55899 .50249 .56095 .51107 .55916 .50633 .5574 Metetra
0 .083 .182 r
.50633 .5574 .51107 .55916 .51967 .55737 .51496 .5558 Metetra
0 .088 .186 r
.51496 .5558 .51967 .55737 .52831 .55558 .52362 .5542 Metetra
0 .093 .19 r
.52362 .5542 .52831 .55558 .53698 .55377 .53232 .5526 Metetra
0 .099 .194 r
.53232 .5526 .53698 .55377 .54568 .55196 .54104 .55099 Metetra
0 .104 .198 r
.54104 .55099 .54568 .55196 .55441 .55014 .5498 .54937 Metetra
0 .11 .202 r
.5498 .54937 .55441 .55014 .56317 .54832 .5586 .54774 Metetra
0 .116 .206 r
.5586 .54774 .56317 .54832 .57197 .54649 .56742 .54611 Metetra
0 .121 .21 r
.56742 .54611 .57197 .54649 .5808 .54465 .57629 .54448 Metetra
0 .127 .214 r
.57629 .54448 .5808 .54465 .58966 .54281 .58518 .54283 Metetra
0 .134 .218 r
.58518 .54283 .58966 .54281 .59855 .54096 .59411 .54118 Metetra
0 .14 .222 r
.59411 .54118 .59855 .54096 .60748 .5391 .60307 .53953 Metetra
0 .146 .226 r
.60307 .53953 .60748 .5391 .61644 .53723 .61207 .53787 Metetra
0 .153 .23 r
.61207 .53787 .61644 .53723 .62543 .53536 .6211 .5362 Metetra
0 .16 .234 r
.6211 .5362 .62543 .53536 .63445 .53348 .63017 .53452 Metetra
0 .166 .238 r
.63017 .53452 .63445 .53348 .64351 .53157 .63927 .53282 Metetra
0 .173 .242 r
.63927 .53282 .64351 .53157 .6526 .5296 .6484 .53103 Metetra
0 .177 .244 r
.6484 .53103 .6526 .5296 .6617 .52705 .65754 .52852 Metetra
0 .175 .243 r
.65754 .52852 .6617 .52705 .67079 .52359 .66666 .52485 Metetra
0 .168 .239 r
.66666 .52485 .67079 .52359 .6799 .52004 .6758 .52108 Metetra
0 .161 .235 r
.6758 .52108 .6799 .52004 .68904 .51646 .68497 .51727 Metetra
0 .155 .231 r
.68497 .51727 .68904 .51646 .6982 .51287 .69416 .51345 Metetra
0 .148 .227 r
.69416 .51345 .6982 .51287 .70739 .50926 .70337 .50962 Metetra
0 .141 .223 r
.70337 .50962 .70739 .50926 .7166 .50565 .71261 .50578 Metetra
0 .135 .219 r
.71261 .50578 .7166 .50565 .72584 .50203 .72187 .50192 Metetra
0 .129 .215 r
.72187 .50192 .72584 .50203 .7351 .49839 .73116 .49806 Metetra
0 .123 .211 r
.73116 .49806 .7351 .49839 .74439 .49475 .74047 .49419 Metetra
0 .117 .207 r
.74047 .49419 .74439 .49475 .7537 .4911 .7498 .4903 Metetra
0 .111 .203 r
.7498 .4903 .7537 .4911 .76304 .48743 .75917 .48641 Metetra
0 .106 .199 r
.75917 .48641 .76304 .48743 .77241 .48376 .76855 .48251 Metetra
0 .1 .195 r
.76855 .48251 .77241 .48376 .7818 .48007 .77796 .47859 Metetra
0 .095 .191 r
.77796 .47859 .7818 .48007 .79122 .47638 .7874 .47467 Metetra
0 .089 .187 r
.7874 .47467 .79122 .47638 .80067 .47267 .79686 .47073 Metetra
0 .084 .183 r
.79686 .47073 .80067 .47267 .81014 .46896 .80635 .46679 Metetra
0 .079 .179 r
.80635 .46679 .81014 .46896 .81964 .46523 .81586 .46283 Metetra
0 .075 .175 r
.81586 .46283 .81964 .46523 .82916 .4615 .8254 .45886 Metetra
0 .07 .171 r
.8254 .45886 .82916 .4615 .83871 .45775 .83496 .45488 Metetra
0 .065 .167 r
.83496 .45488 .83871 .45775 .84829 .45399 .84455 .4509 Metetra
0 .061 .163 r
.84455 .4509 .84829 .45399 .8579 .45022 .85417 .4469 Metetra
0 .057 .159 r
.85417 .4469 .8579 .45022 .86753 .44644 .86381 .44289 Metetra
0 .053 .155 r
.86381 .44289 .86753 .44644 .87719 .44266 .87347 .43886 Metetra
0 .049 .151 r
.87347 .43886 .87719 .44266 .88688 .43886 .88317 .43483 Metetra
0 .045 .147 r
.88317 .43483 .88688 .43886 .89659 .43505 .89289 .43079 Metetra
0 .041 .143 r
.89289 .43079 .89659 .43505 .90633 .43122 .90263 .42674 Metetra
0 .038 .139 r
.90263 .42674 .90633 .43122 .9161 .42739 .91241 .42267 Metetra
0 .034 .135 r
.91241 .42267 .9161 .42739 .9259 .42355 .9222 .41859 Metetra
0 .031 .131 r
.9222 .41859 .9259 .42355 .93573 .4197 .93203 .41452 Metetra
0 .028 .127 r
.93203 .41452 .93573 .4197 .94559 .41588 .94189 .41047 Metetra
0 .025 .124 r
.94189 .41047 .94559 .41588 .95549 .41213 .95179 .40652 Metetra
0 .025 .123 r
.37567 .57635 .38064 .58097 .38882 .57919 .38385 .5747 Metetra
0 .028 .128 r
.38385 .5747 .38882 .57919 .39702 .57761 .39205 .57329 Metetra
0 .032 .132 r
.39205 .57329 .39702 .57761 .40524 .57607 .40029 .57195 Metetra
0 .036 .137 r
.40029 .57195 .40524 .57607 .4135 .57454 .40855 .57061 Metetra
0 .04 .142 r
.40855 .57061 .4135 .57454 .42178 .57301 .41684 .56928 Metetra
0 .045 .147 r
.41684 .56928 .42178 .57301 .43009 .57148 .42517 .56794 Metetra
0 .049 .152 r
.42517 .56794 .43009 .57148 .43844 .56994 .43353 .56659 Metetra
0 .054 .157 r
.43353 .56659 .43844 .56994 .44682 .56839 .44192 .56524 Metetra
0 .059 .162 r
.44192 .56524 .44682 .56839 .45522 .56684 .45034 .56388 Metetra
0 .065 .167 r
.45034 .56388 .45522 .56684 .46366 .56528 .45879 .56251 Metetra
0 .07 .171 r
.45879 .56251 .46366 .56528 .47213 .56371 .46728 .56115 Metetra
0 .076 .176 r
.46728 .56115 .47213 .56371 .48063 .56214 .4758 .55977 Metetra
0 .082 .181 r
.4758 .55977 .48063 .56214 .48917 .56057 .48435 .55839 Metetra
0 .088 .186 r
.48435 .55839 .48917 .56057 .49773 .55899 .49294 .55701 Metetra
0 .094 .191 r
.49294 .55701 .49773 .55899 .50633 .5574 .50156 .55562 Metetra
0 .101 .196 r
.50156 .55562 .50633 .5574 .51496 .5558 .51021 .55422 Metetra
0 .108 .201 r
.51021 .55422 .51496 .5558 .52362 .5542 .5189 .55282 Metetra
0 .115 .206 r
.5189 .55282 .52362 .5542 .53232 .5526 .52762 .55142 Metetra
0 .122 .211 r
.52762 .55142 .53232 .5526 .54104 .55099 .53637 .55 Metetra
0 .13 .216 r
.53637 .55 .54104 .55099 .5498 .54937 .54516 .54859 Metetra
0 .137 .22 r
.54516 .54859 .5498 .54937 .5586 .54774 .55398 .54716 Metetra
0 .145 .225 r
.55398 .54716 .5586 .54774 .56742 .54611 .56284 .54573 Metetra
0 .153 .23 r
.56284 .54573 .56742 .54611 .57629 .54448 .57173 .5443 Metetra
0 .161 .235 r
.57173 .5443 .57629 .54448 .58518 .54283 .58066 .54286 Metetra
0 .17 .24 r
.58066 .54286 .58518 .54283 .59411 .54118 .58963 .54142 Metetra
0 .178 .245 r
.58963 .54142 .59411 .54118 .60307 .53953 .59863 .53996 Metetra
0 .187 .25 r
.59863 .53996 .60307 .53953 .61207 .53787 .60766 .53851 Metetra
0 .196 .255 r
.60766 .53851 .61207 .53787 .6211 .5362 .61673 .53705 Metetra
0 .206 .26 r
.61673 .53705 .6211 .5362 .63017 .53452 .62584 .53557 Metetra
0 .215 .265 r
.62584 .53557 .63017 .53452 .63927 .53282 .63498 .53408 Metetra
0 .224 .269 r
.63498 .53408 .63927 .53282 .6484 .53103 .64416 .53247 Metetra
0 .23 .272 r
.64416 .53247 .6484 .53103 .65754 .52852 .65334 .53 Metetra
0 .227 .27 r
.65334 .53 .65754 .52852 .66666 .52485 .66249 .52613 Metetra
0 .218 .266 r
.66249 .52613 .66666 .52485 .6758 .52108 .67166 .52213 Metetra
0 .208 .261 r
.67166 .52213 .6758 .52108 .68497 .51727 .68086 .51809 Metetra
0 .199 .256 r
.68086 .51809 .68497 .51727 .69416 .51345 .69008 .51404 Metetra
0 .19 .251 r
.69008 .51404 .69416 .51345 .70337 .50962 .69932 .50998 Metetra
0 .181 .246 r
.69932 .50998 .70337 .50962 .71261 .50578 .70858 .5059 Metetra
0 .172 .241 r
.70858 .5059 .71261 .50578 .72187 .50192 .71787 .50182 Metetra
0 .163 .236 r
.71787 .50182 .72187 .50192 .73116 .49806 .72718 .49772 Metetra
0 .155 .232 r
.72718 .49772 .73116 .49806 .74047 .49419 .73651 .49362 Metetra
0 .147 .227 r
.73651 .49362 .74047 .49419 .7498 .4903 .74587 .4895 Metetra
0 .139 .222 r
.74587 .4895 .7498 .4903 .75917 .48641 .75525 .48538 Metetra
0 .131 .217 r
.75525 .48538 .75917 .48641 .76855 .48251 .76466 .48124 Metetra
0 .124 .212 r
.76466 .48124 .76855 .48251 .77796 .47859 .77409 .4771 Metetra
0 .117 .207 r
.77409 .4771 .77796 .47859 .7874 .47467 .78354 .47294 Metetra
0 .11 .202 r
.78354 .47294 .7874 .47467 .79686 .47073 .79302 .46877 Metetra
0 .103 .197 r
.79302 .46877 .79686 .47073 .80635 .46679 .80252 .4646 Metetra
0 .096 .192 r
.80252 .4646 .80635 .46679 .81586 .46283 .81205 .46041 Metetra
0 .09 .187 r
.81205 .46041 .81586 .46283 .8254 .45886 .8216 .45621 Metetra
0 .083 .182 r
.8216 .45621 .8254 .45886 .83496 .45488 .83118 .452 Metetra
0 .077 .178 r
.83118 .452 .83496 .45488 .84455 .4509 .84078 .44778 Metetra
0 .072 .173 r
.84078 .44778 .84455 .4509 .85417 .4469 .85041 .44354 Metetra
0 .066 .168 r
.85041 .44354 .85417 .4469 .86381 .44289 .86006 .4393 Metetra
0 .061 .163 r
.86006 .4393 .86381 .44289 .87347 .43886 .86973 .43505 Metetra
0 .055 .158 r
.86973 .43505 .87347 .43886 .88317 .43483 .87943 .43078 Metetra
0 .05 .153 r
.87943 .43078 .88317 .43483 .89289 .43079 .88916 .4265 Metetra
0 .046 .148 r
.88916 .4265 .89289 .43079 .90263 .42674 .89891 .42222 Metetra
0 .041 .143 r
.89891 .42222 .90263 .42674 .91241 .42267 .90868 .41792 Metetra
0 .037 .138 r
.90868 .41792 .91241 .42267 .9222 .41859 .91848 .41361 Metetra
0 .033 .133 r
.91848 .41361 .9222 .41859 .93203 .41452 .92831 .4093 Metetra
0 .029 .129 r
.92831 .4093 .93203 .41452 .94189 .41047 .93817 .40502 Metetra
0 .025 .124 r
.93817 .40502 .94189 .41047 .95179 .40652 .94808 .40087 Metetra
0 .025 .124 r
.37066 .5717 .37567 .57635 .38385 .5747 .37885 .57019 Metetra
0 .029 .129 r
.37885 .57019 .38385 .5747 .39205 .57329 .38706 .56896 Metetra
0 .033 .134 r
.38706 .56896 .39205 .57329 .40029 .57195 .3953 .5678 Metetra
0 .038 .14 r
.3953 .5678 .40029 .57195 .40855 .57061 .40357 .56666 Metetra
0 .043 .146 r
.40357 .56666 .40855 .57061 .41684 .56928 .41187 .56552 Metetra
0 .049 .152 r
.41187 .56552 .41684 .56928 .42517 .56794 .42021 .56437 Metetra
0 .055 .157 r
.42021 .56437 .42517 .56794 .43353 .56659 .42858 .56322 Metetra
0 .061 .163 r
.42858 .56322 .43353 .56659 .44192 .56524 .43698 .56206 Metetra
0 .067 .169 r
.43698 .56206 .44192 .56524 .45034 .56388 .44542 .5609 Metetra
0 .074 .175 r
.44542 .5609 .45034 .56388 .45879 .56251 .45389 .55973 Metetra
0 .081 .181 r
.45389 .55973 .45879 .56251 .46728 .56115 .46239 .55856 Metetra
0 .089 .186 r
.46239 .55856 .46728 .56115 .4758 .55977 .47093 .55738 Metetra
0 .096 .192 r
.47093 .55738 .4758 .55977 .48435 .55839 .4795 .5562 Metetra
0 .104 .198 r
.4795 .5562 .48435 .55839 .49294 .55701 .48811 .55502 Metetra
0 .112 .204 r
.48811 .55502 .49294 .55701 .50156 .55562 .49675 .55382 Metetra
0 .121 .21 r
.49675 .55382 .50156 .55562 .51021 .55422 .50542 .55263 Metetra
0 .129 .216 r
.50542 .55263 .51021 .55422 .5189 .55282 .51413 .55143 Metetra
0 .138 .221 r
.51413 .55143 .5189 .55282 .52762 .55142 .52288 .55022 Metetra
0 .148 .227 r
.52288 .55022 .52762 .55142 .53637 .55 .53166 .54901 Metetra
0 .157 .233 r
.53166 .54901 .53637 .55 .54516 .54859 .54048 .5478 Metetra
0 .167 .239 r
.54048 .5478 .54516 .54859 .55398 .54716 .54933 .54658 Metetra
0 .178 .245 r
.54933 .54658 .55398 .54716 .56284 .54573 .55822 .54535 Metetra
0 .188 .25 r
.55822 .54535 .56284 .54573 .57173 .5443 .56714 .54412 Metetra
0 .199 .256 r
.56714 .54412 .57173 .5443 .58066 .54286 .5761 .54289 Metetra
0 .21 .262 r
.5761 .54289 .58066 .54286 .58963 .54142 .5851 .54165 Metetra
0 .222 .268 r
.5851 .54165 .58963 .54142 .59863 .53996 .59414 .5404 Metetra
0 .233 .274 r
.59414 .5404 .59863 .53996 .60766 .53851 .60321 .53915 Metetra
0 .245 .279 r
.60321 .53915 .60766 .53851 .61673 .53705 .61232 .5379 Metetra
0 .258 .285 r
.61232 .5379 .61673 .53705 .62584 .53557 .62147 .53664 Metetra
0 .27 .291 r
.62147 .53664 .62584 .53557 .63498 .53408 .63066 .53534 Metetra
0 .282 .296 r
.63066 .53534 .63498 .53408 .64416 .53247 .63987 .53393 Metetra
0 .289 .3 r
.63987 .53393 .64416 .53247 .65334 .53 .64909 .53149 Metetra
0 .285 .298 r
.64909 .53149 .65334 .53 .66249 .52613 .65828 .52742 Metetra
0 .273 .292 r
.65828 .52742 .66249 .52613 .67166 .52213 .66748 .52319 Metetra
0 .261 .287 r
.66748 .52319 .67166 .52213 .68086 .51809 .67671 .51892 Metetra
0 .248 .281 r
.67671 .51892 .68086 .51809 .69008 .51404 .68595 .51463 Metetra
0 .236 .275 r
.68595 .51463 .69008 .51404 .69932 .50998 .69522 .51033 Metetra
0 .224 .269 r
.69522 .51033 .69932 .50998 .70858 .5059 .70451 .50603 Metetra
0 .213 .263 r
.70451 .50603 .70858 .5059 .71787 .50182 .71383 .50171 Metetra
0 .202 .258 r
.71383 .50171 .71787 .50182 .72718 .49772 .72316 .49738 Metetra
0 .191 .252 r
.72316 .49738 .72718 .49772 .73651 .49362 .73252 .49304 Metetra
0 .18 .246 r
.73252 .49304 .73651 .49362 .74587 .4895 .7419 .4887 Metetra
0 .17 .24 r
.7419 .4887 .74587 .4895 .75525 .48538 .75131 .48434 Metetra
0 .16 .234 r
.75131 .48434 .75525 .48538 .76466 .48124 .76073 .47997 Metetra
0 .15 .229 r
.76073 .47997 .76466 .48124 .77409 .4771 .77018 .47559 Metetra
0 .141 .223 r
.77018 .47559 .77409 .4771 .78354 .47294 .77966 .4712 Metetra
0 .132 .217 r
.77966 .4712 .78354 .47294 .79302 .46877 .78915 .4668 Metetra
0 .123 .211 r
.78915 .4668 .79302 .46877 .80252 .4646 .79867 .46239 Metetra
0 .114 .205 r
.79867 .46239 .80252 .4646 .81205 .46041 .80821 .45796 Metetra
0 .106 .2 r
.80821 .45796 .81205 .46041 .8216 .45621 .81778 .45353 Metetra
0 .098 .194 r
.81778 .45353 .8216 .45621 .83118 .452 .82737 .44909 Metetra
0 .09 .188 r
.82737 .44909 .83118 .452 .84078 .44778 .83698 .44463 Metetra
0 .083 .182 r
.83698 .44463 .84078 .44778 .85041 .44354 .84662 .44017 Metetra
0 .076 .176 r
.84662 .44017 .85041 .44354 .86006 .4393 .85628 .43569 Metetra
0 .069 .17 r
.85628 .43569 .86006 .4393 .86973 .43505 .86596 .4312 Metetra
0 .063 .165 r
.86596 .4312 .86973 .43505 .87943 .43078 .87567 .4267 Metetra
0 .056 .159 r
.87567 .4267 .87943 .43078 .88916 .4265 .8854 .42219 Metetra
0 .05 .153 r
.8854 .42219 .88916 .4265 .89891 .42222 .89515 .41767 Metetra
0 .045 .147 r
.89515 .41767 .89891 .42222 .90868 .41792 .90493 .41313 Metetra
0 .039 .141 r
.90493 .41313 .90868 .41792 .91848 .41361 .91474 .40859 Metetra
0 .034 .136 r
.91474 .40859 .91848 .41361 .92831 .4093 .92457 .40404 Metetra
0 .03 .13 r
.92457 .40404 .92831 .4093 .93817 .40502 .93443 .39954 Metetra
0 .026 .125 r
.93443 .39954 .93817 .40502 .94808 .40087 .94434 .39519 Metetra
0 .025 .124 r
.36562 .56702 .37066 .5717 .37885 .57019 .37382 .56564 Metetra
0 .03 .13 r
.37382 .56564 .37885 .57019 .38706 .56896 .38204 .56459 Metetra
0 .035 .136 r
.38204 .56459 .38706 .56896 .3953 .5678 .39029 .56363 Metetra
0 .041 .143 r
.39029 .56363 .3953 .5678 .40357 .56666 .39856 .56268 Metetra
0 .047 .15 r
.39856 .56268 .40357 .56666 .41187 .56552 .40688 .56173 Metetra
0 .054 .156 r
.40688 .56173 .41187 .56552 .42021 .56437 .41522 .56078 Metetra
0 .061 .163 r
.41522 .56078 .42021 .56437 .42858 .56322 .4236 .55982 Metetra
0 .068 .17 r
.4236 .55982 .42858 .56322 .43698 .56206 .43202 .55886 Metetra
0 .076 .176 r
.43202 .55886 .43698 .56206 .44542 .5609 .44047 .5579 Metetra
0 .084 .183 r
.44047 .5579 .44542 .5609 .45389 .55973 .44895 .55693 Metetra
0 .093 .19 r
.44895 .55693 .45389 .55973 .46239 .55856 .45747 .55595 Metetra
0 .102 .197 r
.45747 .55595 .46239 .55856 .47093 .55738 .46602 .55498 Metetra
0 .111 .203 r
.46602 .55498 .47093 .55738 .4795 .5562 .47461 .55399 Metetra
0 .121 .21 r
.47461 .55399 .4795 .5562 .48811 .55502 .48324 .55301 Metetra
0 .131 .217 r
.48324 .55301 .48811 .55502 .49675 .55382 .4919 .55202 Metetra
0 .142 .223 r
.4919 .55202 .49675 .55382 .50542 .55263 .5006 .55102 Metetra
0 .153 .23 r
.5006 .55102 .50542 .55263 .51413 .55143 .50933 .55002 Metetra
0 .164 .237 r
.50933 .55002 .51413 .55143 .52288 .55022 .5181 .54902 Metetra
0 .176 .244 r
.5181 .54902 .52288 .55022 .53166 .54901 .52691 .54801 Metetra
0 .188 .25 r
.52691 .54801 .53166 .54901 .54048 .5478 .53575 .547 Metetra
0 .201 .257 r
.53575 .547 .54048 .5478 .54933 .54658 .54463 .54598 Metetra
0 .214 .264 r
.54463 .54598 .54933 .54658 .55822 .54535 .55355 .54496 Metetra
0 .227 .27 r
.55355 .54496 .55822 .54535 .56714 .54412 .56251 .54394 Metetra
0 .241 .277 r
.56251 .54394 .56714 .54412 .5761 .54289 .57151 .54291 Metetra
0 .255 .284 r
.57151 .54291 .5761 .54289 .5851 .54165 .58054 .54188 Metetra
0 .269 .291 r
.58054 .54188 .5851 .54165 .59414 .5404 .58961 .54084 Metetra
0 .284 .297 r
.58961 .54084 .59414 .5404 .60321 .53915 .59872 .5398 Metetra
0 .299 .304 r
.59872 .5398 .60321 .53915 .61232 .5379 .60787 .53876 Metetra
0 .311 .307 r
.60787 .53876 .61232 .5379 .62147 .53664 .61706 .53771 Metetra
0 .317 .304 r
.61706 .53771 .62147 .53664 .63066 .53534 .62629 .53662 Metetra
0 .324 .301 r
.62629 .53662 .63066 .53534 .63987 .53393 .63555 .5354 Metetra
0 .328 .299 r
.63555 .5354 .63987 .53393 .64909 .53149 .64481 .533 Metetra
0 .325 .3 r
.64481 .533 .64909 .53149 .65828 .52742 .65403 .52872 Metetra
0 .319 .303 r
.65403 .52872 .65828 .52742 .66748 .52319 .66326 .52426 Metetra
0 .312 .306 r
.66326 .52426 .66748 .52319 .67671 .51892 .67252 .51975 Metetra
0 .303 .306 r
.67252 .51975 .67671 .51892 .68595 .51463 .68179 .51523 Metetra
0 .288 .299 r
.68179 .51523 .68595 .51463 .69522 .51033 .69109 .51069 Metetra
0 .273 .292 r
.69109 .51069 .69522 .51033 .70451 .50603 .70041 .50615 Metetra
0 .258 .286 r
.70041 .50615 .70451 .50603 .71383 .50171 .70975 .5016 Metetra
0 .244 .279 r
.70975 .5016 .71383 .50171 .72316 .49738 .71911 .49704 Metetra
0 .23 .272 r
.71911 .49704 .72316 .49738 .73252 .49304 .72849 .49246 Metetra
0 .217 .265 r
.72849 .49246 .73252 .49304 .7419 .4887 .7379 .48788 Metetra
0 .204 .259 r
.7379 .48788 .7419 .4887 .75131 .48434 .74733 .48329 Metetra
0 .191 .252 r
.74733 .48329 .75131 .48434 .76073 .47997 .75677 .47868 Metetra
0 .179 .245 r
.75677 .47868 .76073 .47997 .77018 .47559 .76624 .47407 Metetra
0 .167 .239 r
.76624 .47407 .77018 .47559 .77966 .4712 .77574 .46944 Metetra
0 .156 .232 r
.77574 .46944 .77966 .4712 .78915 .4668 .78525 .46481 Metetra
0 .145 .225 r
.78525 .46481 .78915 .4668 .79867 .46239 .79479 .46016 Metetra
0 .134 .218 r
.79479 .46016 .79867 .46239 .80821 .45796 .80434 .4555 Metetra
0 .124 .212 r
.80434 .4555 .80821 .45796 .81778 .45353 .81392 .45083 Metetra
0 .114 .205 r
.81392 .45083 .81778 .45353 .82737 .44909 .82353 .44615 Metetra
0 .104 .198 r
.82353 .44615 .82737 .44909 .83698 .44463 .83315 .44146 Metetra
0 .095 .192 r
.83315 .44146 .83698 .44463 .84662 .44017 .8428 .43676 Metetra
0 .086 .185 r
.8428 .43676 .84662 .44017 .85628 .43569 .85247 .43205 Metetra
0 .078 .178 r
.85247 .43205 .85628 .43569 .86596 .4312 .86216 .42733 Metetra
0 .07 .171 r
.86216 .42733 .86596 .4312 .87567 .4267 .87188 .42259 Metetra
0 .063 .165 r
.87188 .42259 .87567 .4267 .8854 .42219 .88162 .41784 Metetra
0 .055 .158 r
.88162 .41784 .8854 .42219 .89515 .41767 .89138 .41308 Metetra
0 .049 .151 r
.89138 .41308 .89515 .41767 .90493 .41313 .90116 .40831 Metetra
0 .042 .145 r
.90116 .40831 .90493 .41313 .91474 .40859 .91097 .40353 Metetra
0 .036 .138 r
.91097 .40353 .91474 .40859 .92457 .40404 .9208 .39875 Metetra
0 .031 .131 r
.9208 .39875 .92457 .40404 .93443 .39954 .93066 .39402 Metetra
0 .026 .125 r
.93066 .39402 .93443 .39954 .94434 .39519 .94057 .38947 Metetra
0 .026 .125 r
.36056 .56232 .36562 .56702 .37382 .56564 .36877 .56108 Metetra
0 .031 .131 r
.36877 .56108 .37382 .56564 .38204 .56459 .37699 .5602 Metetra
0 .037 .138 r
.37699 .5602 .38204 .56459 .39029 .56363 .38524 .55943 Metetra
0 .043 .146 r
.38524 .55943 .39029 .56363 .39856 .56268 .39352 .55868 Metetra
0 .051 .153 r
.39352 .55868 .39856 .56268 .40688 .56173 .40184 .55792 Metetra
0 .059 .161 r
.40184 .55792 .40688 .56173 .41522 .56078 .4102 .55717 Metetra
0 .067 .169 r
.4102 .55717 .41522 .56078 .4236 .55982 .41859 .55641 Metetra
0 .076 .176 r
.41859 .55641 .4236 .55982 .43202 .55886 .42702 .55564 Metetra
0 .085 .184 r
.42702 .55564 .43202 .55886 .44047 .5579 .43548 .55487 Metetra
0 .095 .192 r
.43548 .55487 .44047 .5579 .44895 .55693 .44398 .5541 Metetra
0 .105 .199 r
.44398 .5541 .44895 .55693 .45747 .55595 .45251 .55333 Metetra
0 .116 .207 r
.45251 .55333 .45747 .55595 .46602 .55498 .46108 .55255 Metetra
0 .128 .214 r
.46108 .55255 .46602 .55498 .47461 .55399 .46969 .55177 Metetra
0 .14 .222 r
.46969 .55177 .47461 .55399 .48324 .55301 .47833 .55098 Metetra
0 .152 .23 r
.47833 .55098 .48324 .55301 .4919 .55202 .48702 .55019 Metetra
0 .165 .237 r
.48702 .55019 .4919 .55202 .5006 .55102 .49573 .5494 Metetra
0 .178 .245 r
.49573 .5494 .5006 .55102 .50933 .55002 .50449 .5486 Metetra
0 .192 .252 r
.50449 .5486 .50933 .55002 .5181 .54902 .51329 .5478 Metetra
0 .206 .26 r
.51329 .5478 .5181 .54902 .52691 .54801 .52212 .547 Metetra
0 .221 .268 r
.52212 .547 .52691 .54801 .53575 .547 .53099 .54619 Metetra
0 .237 .275 r
.53099 .54619 .53575 .547 .54463 .54598 .5399 .54538 Metetra
0 .253 .283 r
.5399 .54538 .54463 .54598 .55355 .54496 .54885 .54457 Metetra
0 .269 .291 r
.54885 .54457 .55355 .54496 .56251 .54394 .55784 .54375 Metetra
0 .286 .298 r
.55784 .54375 .56251 .54394 .57151 .54291 .56686 .54294 Metetra
0 .303 .306 r
.56686 .54294 .57151 .54291 .58054 .54188 .57593 .54211 Metetra
0 .313 .306 r
.57593 .54211 .58054 .54188 .58961 .54084 .58504 .54129 Metetra
0 .321 .302 r
.58504 .54129 .58961 .54084 .59872 .5398 .59419 .54046 Metetra
0 .329 .299 r
.59419 .54046 .59872 .5398 .60787 .53876 .60338 .53963 Metetra
0 .336 .295 r
.60338 .53963 .60787 .53876 .61706 .53771 .6126 .53879 Metetra
0 .344 .29 r
.6126 .53879 .61706 .53771 .62629 .53662 .62187 .53791 Metetra
0 .351 .285 r
.62187 .53791 .62629 .53662 .63555 .5354 .63118 .53688 Metetra
0 .355 .282 r
.63118 .53688 .63555 .5354 .64481 .533 .64048 .53452 Metetra
0 .353 .284 r
.64048 .53452 .64481 .533 .65403 .52872 .64973 .53003 Metetra
0 .346 .289 r
.64973 .53003 .65403 .52872 .66326 .52426 .659 .52534 Metetra
0 .338 .293 r
.659 .52534 .66326 .52426 .67252 .51975 .66829 .52059 Metetra
0 .331 .298 r
.66829 .52059 .67252 .51975 .68179 .51523 .67759 .51583 Metetra
0 .323 .302 r
.67759 .51583 .68179 .51523 .69109 .51069 .68692 .51106 Metetra
0 .315 .305 r
.68692 .51106 .69109 .51069 .70041 .50615 .69627 .50628 Metetra
0 .308 .308 r
.69627 .50628 .70041 .50615 .70975 .5016 .70563 .50149 Metetra
0 .29 .3 r
.70563 .50149 .70975 .5016 .71911 .49704 .71502 .49669 Metetra
0 .273 .292 r
.71502 .49669 .71911 .49704 .72849 .49246 .72443 .49188 Metetra
0 .257 .285 r
.72443 .49188 .72849 .49246 .7379 .48788 .73386 .48705 Metetra
0 .241 .277 r
.73386 .48705 .7379 .48788 .74733 .48329 .74331 .48222 Metetra
0 .225 .27 r
.74331 .48222 .74733 .48329 .75677 .47868 .75278 .47738 Metetra
0 .21 .262 r
.75278 .47738 .75677 .47868 .76624 .47407 .76227 .47253 Metetra
0 .196 .254 r
.76227 .47253 .76624 .47407 .77574 .46944 .77178 .46767 Metetra
0 .182 .247 r
.77178 .46767 .77574 .46944 .78525 .46481 .78131 .4628 Metetra
0 .168 .239 r
.78131 .4628 .78525 .46481 .79479 .46016 .79087 .45791 Metetra
0 .155 .231 r
.79087 .45791 .79479 .46016 .80434 .4555 .80044 .45302 Metetra
0 .143 .224 r
.80044 .45302 .80434 .4555 .81392 .45083 .81004 .44811 Metetra
0 .131 .216 r
.81004 .44811 .81392 .45083 .82353 .44615 .81966 .4432 Metetra
0 .119 .209 r
.81966 .4432 .82353 .44615 .83315 .44146 .82929 .43827 Metetra
0 .108 .201 r
.82929 .43827 .83315 .44146 .8428 .43676 .83895 .43333 Metetra
0 .098 .193 r
.83895 .43333 .8428 .43676 .85247 .43205 .84863 .42838 Metetra
0 .088 .186 r
.84863 .42838 .85247 .43205 .86216 .42733 .85834 .42342 Metetra
0 .078 .178 r
.85834 .42342 .86216 .42733 .87188 .42259 .86806 .41845 Metetra
0 .069 .171 r
.86806 .41845 .87188 .42259 .88162 .41784 .87781 .41346 Metetra
0 .061 .163 r
.87781 .41346 .88162 .41784 .89138 .41308 .88757 .40847 Metetra
0 .053 .155 r
.88757 .40847 .89138 .41308 .90116 .40831 .89736 .40346 Metetra
0 .045 .148 r
.89736 .40346 .90116 .40831 .91097 .40353 .90717 .39844 Metetra
0 .038 .14 r
.90717 .39844 .91097 .40353 .9208 .39875 .91701 .39343 Metetra
0 .032 .133 r
.91701 .39343 .9208 .39875 .93066 .39402 .92687 .38847 Metetra
0 .027 .126 r
.92687 .38847 .93066 .39402 .94057 .38947 .93678 .38371 Metetra
0 .026 .125 r
.35547 .55759 .36056 .56232 .36877 .56108 .36368 .55648 Metetra
0 .032 .132 r
.36368 .55648 .36877 .56108 .37699 .5602 .37191 .55579 Metetra
0 .038 .14 r
.37191 .55579 .37699 .5602 .38524 .55943 .38016 .55521 Metetra
0 .046 .149 r
.38016 .55521 .38524 .55943 .39352 .55868 .38845 .55465 Metetra
0 .055 .157 r
.38845 .55465 .39352 .55868 .40184 .55792 .39678 .55409 Metetra
0 .064 .166 r
.39678 .55409 .40184 .55792 .4102 .55717 .40515 .55353 Metetra
0 .073 .174 r
.40515 .55353 .4102 .55717 .41859 .55641 .41355 .55297 Metetra
0 .084 .183 r
.41355 .55297 .41859 .55641 .42702 .55564 .42198 .5524 Metetra
0 .095 .191 r
.42198 .5524 .42702 .55564 .43548 .55487 .43046 .55183 Metetra
0 .106 .2 r
.43046 .55183 .43548 .55487 .44398 .5541 .43897 .55126 Metetra
0 .119 .208 r
.43897 .55126 .44398 .5541 .45251 .55333 .44752 .55068 Metetra
0 .132 .217 r
.44752 .55068 .45251 .55333 .46108 .55255 .4561 .55011 Metetra
0 .145 .225 r
.4561 .55011 .46108 .55255 .46969 .55177 .46473 .54952 Metetra
0 .159 .234 r
.46473 .54952 .46969 .55177 .47833 .55098 .47339 .54894 Metetra
0 .174 .242 r
.47339 .54894 .47833 .55098 .48702 .55019 .48209 .54835 Metetra
0 .189 .251 r
.48209 .54835 .48702 .55019 .49573 .5494 .49083 .54776 Metetra
0 .205 .259 r
.49083 .54776 .49573 .5494 .50449 .5486 .49961 .54717 Metetra
0 .222 .268 r
.49961 .54717 .50449 .5486 .51329 .5478 .50843 .54658 Metetra
0 .239 .277 r
.50843 .54658 .51329 .5478 .52212 .547 .51729 .54598 Metetra
0 .257 .285 r
.51729 .54598 .52212 .547 .53099 .54619 .52619 .54538 Metetra
0 .276 .294 r
.52619 .54538 .53099 .54619 .5399 .54538 .53512 .54478 Metetra
0 .295 .302 r
.53512 .54478 .5399 .54538 .54885 .54457 .5441 .54417 Metetra
0 .311 .307 r
.5441 .54417 .54885 .54457 .55784 .54375 .55312 .54357 Metetra
0 .319 .303 r
.55312 .54357 .55784 .54375 .56686 .54294 .56218 .54296 Metetra
0 .328 .299 r
.56218 .54296 .56686 .54294 .57593 .54211 .57128 .54235 Metetra
0 .336 .295 r
.57128 .54235 .57593 .54211 .58504 .54129 .58043 .54174 Metetra
0 .345 .289 r
.58043 .54174 .58504 .54129 .59419 .54046 .58961 .54112 Metetra
0 .353 .284 r
.58961 .54112 .59419 .54046 .60338 .53963 .59884 .5405 Metetra
0 .362 .277 r
.59884 .5405 .60338 .53963 .6126 .53879 .60811 .53988 Metetra
0 .37 .27 r
.60811 .53988 .6126 .53879 .62187 .53791 .61742 .53921 Metetra
0 .378 .263 r
.61742 .53921 .62187 .53791 .63118 .53688 .62676 .53838 Metetra
0 .383 .258 r
.62676 .53838 .63118 .53688 .64048 .53452 .6361 .53605 Metetra
0 .38 .261 r
.6361 .53605 .64048 .53452 .64973 .53003 .64539 .53135 Metetra
0 .372 .268 r
.64539 .53135 .64973 .53003 .659 .52534 .6547 .52643 Metetra
0 .364 .275 r
.6547 .52643 .659 .52534 .66829 .52059 .66401 .52144 Metetra
0 .355 .282 r
.66401 .52144 .66829 .52059 .67759 .51583 .67335 .51644 Metetra
0 .347 .288 r
.67335 .51644 .67759 .51583 .68692 .51106 .68271 .51142 Metetra
0 .338 .293 r
.68271 .51142 .68692 .51106 .69627 .50628 .69208 .5064 Metetra
0 .33 .298 r
.69208 .5064 .69627 .50628 .70563 .50149 .70148 .50137 Metetra
0 .321 .302 r
.70148 .50137 .70563 .50149 .71502 .49669 .7109 .49633 Metetra
0 .313 .306 r
.7109 .49633 .71502 .49669 .72443 .49188 .72033 .49128 Metetra
0 .3 .304 r
.72033 .49128 .72443 .49188 .73386 .48705 .72978 .48622 Metetra
0 .28 .296 r
.72978 .48622 .73386 .48705 .74331 .48222 .73926 .48115 Metetra
0 .262 .287 r
.73926 .48115 .74331 .48222 .75278 .47738 .74875 .47607 Metetra
0 .244 .279 r
.74875 .47607 .75278 .47738 .76227 .47253 .75826 .47098 Metetra
0 .226 .27 r
.75826 .47098 .76227 .47253 .77178 .46767 .76779 .46588 Metetra
0 .209 .262 r
.76779 .46588 .77178 .46767 .78131 .4628 .77735 .46077 Metetra
0 .193 .253 r
.77735 .46077 .78131 .4628 .79087 .45791 .78692 .45565 Metetra
0 .178 .245 r
.78692 .45565 .79087 .45791 .80044 .45302 .79651 .45052 Metetra
0 .163 .236 r
.79651 .45052 .80044 .45302 .81004 .44811 .80612 .44537 Metetra
0 .148 .228 r
.80612 .44537 .81004 .44811 .81966 .4432 .81575 .44022 Metetra
0 .135 .219 r
.81575 .44022 .81966 .4432 .82929 .43827 .82541 .43505 Metetra
0 .122 .21 r
.82541 .43505 .82929 .43827 .83895 .43333 .83508 .42988 Metetra
0 .109 .202 r
.83508 .42988 .83895 .43333 .84863 .42838 .84477 .42469 Metetra
0 .098 .193 r
.84477 .42469 .84863 .42838 .85834 .42342 .85448 .41949 Metetra
0 .087 .185 r
.85448 .41949 .85834 .42342 .86806 .41845 .86422 .41428 Metetra
0 .076 .176 r
.86422 .41428 .86806 .41845 .87781 .41346 .87397 .40905 Metetra
0 .066 .168 r
.87397 .40905 .87781 .41346 .88757 .40847 .88374 .40382 Metetra
0 .057 .159 r
.88374 .40382 .88757 .40847 .89736 .40346 .89354 .39857 Metetra
0 .048 .151 r
.89354 .39857 .89736 .40346 .90717 .39844 .90335 .39332 Metetra
0 .04 .142 r
.90335 .39332 .90717 .39844 .91701 .39343 .91319 .38807 Metetra
0 .033 .134 r
.91319 .38807 .91701 .39343 .92687 .38847 .92305 .38288 Metetra
0 .027 .126 r
.92305 .38288 .92687 .38847 .93678 .38371 .93297 .37792 Metetra
0 .026 .125 r
.35034 .55283 .35547 .55759 .36368 .55648 .35856 .55186 Metetra
0 .032 .133 r
.35856 .55186 .36368 .55648 .37191 .55579 .36679 .55135 Metetra
0 .04 .142 r
.36679 .55135 .37191 .55579 .38016 .55521 .37505 .55096 Metetra
0 .049 .152 r
.37505 .55096 .38016 .55521 .38845 .55465 .38335 .55059 Metetra
0 .059 .161 r
.38335 .55059 .38845 .55465 .39678 .55409 .39169 .55023 Metetra
0 .069 .17 r
.39169 .55023 .39678 .55409 .40515 .55353 .40006 .54987 Metetra
0 .08 .18 r
.40006 .54987 .40515 .55353 .41355 .55297 .40847 .5495 Metetra
0 .092 .189 r
.40847 .5495 .41355 .55297 .42198 .5524 .41691 .54914 Metetra
0 .105 .199 r
.41691 .54914 .42198 .5524 .43046 .55183 .4254 .54877 Metetra
0 .118 .208 r
.4254 .54877 .43046 .55183 .43897 .55126 .43392 .5484 Metetra
0 .133 .218 r
.43392 .5484 .43897 .55126 .44752 .55068 .44249 .54802 Metetra
0 .148 .227 r
.44249 .54802 .44752 .55068 .4561 .55011 .45109 .54764 Metetra
0 .163 .236 r
.45109 .54764 .4561 .55011 .46473 .54952 .45973 .54727 Metetra
0 .18 .246 r
.45973 .54727 .46473 .54952 .47339 .54894 .46841 .54688 Metetra
0 .197 .255 r
.46841 .54688 .47339 .54894 .48209 .54835 .47713 .5465 Metetra
0 .215 .265 r
.47713 .5465 .48209 .54835 .49083 .54776 .48589 .54612 Metetra
0 .234 .274 r
.48589 .54612 .49083 .54776 .49961 .54717 .49469 .54573 Metetra
0 .254 .284 r
.49469 .54573 .49961 .54717 .50843 .54658 .50354 .54534 Metetra
0 .274 .293 r
.50354 .54534 .50843 .54658 .51729 .54598 .51242 .54495 Metetra
0 .295 .302 r
.51242 .54495 .51729 .54598 .52619 .54538 .52134 .54456 Metetra
0 .312 .306 r
.52134 .54456 .52619 .54538 .53512 .54478 .53031 .54417 Metetra
0 .321 .302 r
.53031 .54417 .53512 .54478 .5441 .54417 .53932 .54377 Metetra
0 .331 .298 r
.53932 .54377 .5441 .54417 .55312 .54357 .54837 .54338 Metetra
0 .34 .292 r
.54837 .54338 .55312 .54357 .56218 .54296 .55746 .54298 Metetra
0 .35 .286 r
.55746 .54298 .56218 .54296 .57128 .54235 .56659 .54259 Metetra
0 .359 .279 r
.56659 .54259 .57128 .54235 .58043 .54174 .57577 .54219 Metetra
0 .368 .271 r
.57577 .54219 .58043 .54174 .58961 .54112 .58499 .54179 Metetra
0 .378 .263 r
.58499 .54179 .58961 .54112 .59884 .5405 .59425 .54139 Metetra
0 .387 .254 r
.59425 .54139 .59884 .5405 .60811 .53988 .60356 .54098 Metetra
0 .397 .244 r
.60356 .54098 .60811 .53988 .61742 .53921 .61291 .54053 Metetra
0 .406 .234 r
.61291 .54053 .61742 .53921 .62676 .53838 .6223 .53989 Metetra
0 .411 .227 r
.6223 .53989 .62676 .53838 .6361 .53605 .63169 .5376 Metetra
0 .408 .231 r
.63169 .5376 .6361 .53605 .64539 .53135 .64101 .53268 Metetra
0 .399 .241 r
.64101 .53268 .64539 .53135 .6547 .52643 .65035 .52752 Metetra
0 .39 .251 r
.65035 .52752 .6547 .52643 .66401 .52144 .6597 .52229 Metetra
0 .38 .261 r
.6597 .52229 .66401 .52144 .67335 .51644 .66907 .51705 Metetra
0 .371 .269 r
.66907 .51705 .67335 .51644 .68271 .51142 .67846 .51179 Metetra
0 .361 .277 r
.67846 .51179 .68271 .51142 .69208 .5064 .68786 .50653 Metetra
0 .352 .284 r
.68786 .50653 .69208 .5064 .70148 .50137 .69729 .50126 Metetra
0 .342 .291 r
.69729 .50126 .70148 .50137 .7109 .49633 .70673 .49597 Metetra
0 .333 .296 r
.70673 .49597 .7109 .49633 .72033 .49128 .71619 .49068 Metetra
0 .324 .301 r
.71619 .49068 .72033 .49128 .72978 .48622 .72567 .48538 Metetra
0 .314 .305 r
.72567 .48538 .72978 .48622 .73926 .48115 .73517 .48007 Metetra
0 .301 .305 r
.73517 .48007 .73926 .48115 .74875 .47607 .74469 .47475 Metetra
0 .279 .295 r
.74469 .47475 .74875 .47607 .75826 .47098 .75422 .46942 Metetra
0 .259 .286 r
.75422 .46942 .75826 .47098 .76779 .46588 .76377 .46408 Metetra
0 .239 .276 r
.76377 .46408 .76779 .46588 .77735 .46077 .77335 .45873 Metetra
0 .22 .267 r
.77335 .45873 .77735 .46077 .78692 .45565 .78294 .45336 Metetra
0 .202 .258 r
.78294 .45336 .78692 .45565 .79651 .45052 .79255 .44799 Metetra
0 .184 .248 r
.79255 .44799 .79651 .45052 .80612 .44537 .80218 .44261 Metetra
0 .167 .239 r
.80218 .44261 .80612 .44537 .81575 .44022 .81182 .43721 Metetra
0 .151 .229 r
.81182 .43721 .81575 .44022 .82541 .43505 .82149 .43181 Metetra
0 .136 .22 r
.82149 .43181 .82541 .43505 .83508 .42988 .83117 .42639 Metetra
0 .122 .21 r
.83117 .42639 .83508 .42988 .84477 .42469 .84088 .42097 Metetra
0 .108 .201 r
.84088 .42097 .84477 .42469 .85448 .41949 .8506 .41553 Metetra
0 .095 .192 r
.8506 .41553 .85448 .41949 .86422 .41428 .86034 .41008 Metetra
0 .083 .182 r
.86034 .41008 .86422 .41428 .87397 .40905 .8701 .40461 Metetra
0 .072 .173 r
.8701 .40461 .87397 .40905 .88374 .40382 .87988 .39914 Metetra
0 .061 .163 r
.87988 .39914 .88374 .40382 .89354 .39857 .88968 .39365 Metetra
0 .051 .154 r
.88968 .39365 .89354 .39857 .90335 .39332 .8995 .38816 Metetra
0 .042 .144 r
.8995 .38816 .90335 .39332 .91319 .38807 .90934 .38267 Metetra
0 .034 .135 r
.90934 .38267 .91319 .38807 .92305 .38288 .91921 .37726 Metetra
0 .027 .127 r
.91921 .37726 .92305 .38288 .93297 .37792 .92914 .37209 Metetra
0 .027 .126 r
.34519 .54804 .35034 .55283 .35856 .55186 .35342 .54721 Metetra
0 .033 .134 r
.35342 .54721 .35856 .55186 .36679 .55135 .36165 .54688 Metetra
0 .042 .144 r
.36165 .54688 .36679 .55135 .37505 .55096 .36992 .54668 Metetra
0 .052 .154 r
.36992 .54668 .37505 .55096 .38335 .55059 .37822 .54651 Metetra
0 .063 .165 r
.37822 .54651 .38335 .55059 .39169 .55023 .38656 .54635 Metetra
0 .075 .175 r
.38656 .54635 .39169 .55023 .40006 .54987 .39494 .54619 Metetra
0 .087 .185 r
.39494 .54619 .40006 .54987 .40847 .5495 .40335 .54602 Metetra
0 .101 .196 r
.40335 .54602 .40847 .5495 .41691 .54914 .41181 .54585 Metetra
0 .115 .206 r
.41181 .54585 .41691 .54914 .4254 .54877 .42031 .54568 Metetra
0 .131 .216 r
.42031 .54568 .4254 .54877 .43392 .5484 .42885 .54551 Metetra
0 .147 .227 r
.42885 .54551 .43392 .5484 .44249 .54802 .43742 .54534 Metetra
0 .165 .237 r
.43742 .54534 .44249 .54802 .45109 .54764 .44604 .54516 Metetra
0 .183 .247 r
.44604 .54516 .45109 .54764 .45973 .54727 .4547 .54499 Metetra
0 .202 .258 r
.4547 .54499 .45973 .54727 .46841 .54688 .46339 .54481 Metetra
0 .222 .268 r
.46339 .54481 .46841 .54688 .47713 .5465 .47213 .54463 Metetra
0 .243 .278 r
.47213 .54463 .47713 .5465 .48589 .54612 .48091 .54446 Metetra
0 .265 .289 r
.48091 .54446 .48589 .54612 .49469 .54573 .48974 .54428 Metetra
0 .288 .299 r
.48974 .54428 .49469 .54573 .50354 .54534 .4986 .5441 Metetra
0 .309 .307 r
.4986 .5441 .50354 .54534 .51242 .54495 .50751 .54392 Metetra
0 .32 .303 r
.50751 .54392 .51242 .54495 .52134 .54456 .51646 .54373 Metetra
0 .33 .298 r
.51646 .54373 .52134 .54456 .53031 .54417 .52545 .54355 Metetra
0 .34 .292 r
.52545 .54355 .53031 .54417 .53932 .54377 .53449 .54337 Metetra
0 .351 .285 r
.53449 .54337 .53932 .54377 .54837 .54338 .54357 .54319 Metetra
0 .361 .278 r
.54357 .54319 .54837 .54338 .55746 .54298 .55269 .54301 Metetra
0 .371 .269 r
.55269 .54301 .55746 .54298 .56659 .54259 .56186 .54282 Metetra
0 .382 .259 r
.56186 .54282 .56659 .54259 .57577 .54219 .57107 .54264 Metetra
0 .392 .249 r
.57107 .54264 .57577 .54219 .58499 .54179 .58032 .54246 Metetra
0 .402 .237 r
.58032 .54246 .58499 .54179 .59425 .54139 .58963 .54228 Metetra
0 .413 .225 r
.58963 .54228 .59425 .54139 .60356 .54098 .59897 .54209 Metetra
0 .423 .212 r
.59897 .54209 .60356 .54098 .61291 .54053 .60837 .54186 Metetra
0 .433 .198 r
.60837 .54186 .61291 .54053 .6223 .53989 .6178 .54141 Metetra
0 .439 .19 r
.6178 .54141 .6223 .53989 .63169 .5376 .62722 .53917 Metetra
0 .435 .195 r
.62722 .53917 .63169 .5376 .64101 .53268 .63658 .53403 Metetra
0 .426 .208 r
.63658 .53403 .64101 .53268 .65035 .52752 .64596 .52863 Metetra
0 .415 .222 r
.64596 .52863 .65035 .52752 .6597 .52229 .65534 .52316 Metetra
0 .405 .234 r
.65534 .52316 .6597 .52229 .66907 .51705 .66474 .51767 Metetra
0 .395 .246 r
.66474 .51767 .66907 .51705 .67846 .51179 .67416 .51217 Metetra
0 .384 .257 r
.67416 .51217 .67846 .51179 .68786 .50653 .6836 .50666 Metetra
0 .374 .267 r
.6836 .50666 .68786 .50653 .69729 .50126 .69306 .50114 Metetra
0 .364 .275 r
.69306 .50114 .69729 .50126 .70673 .49597 .70253 .49561 Metetra
0 .353 .283 r
.70253 .49561 .70673 .49597 .71619 .49068 .71202 .49008 Metetra
0 .343 .291 r
.71202 .49008 .71619 .49068 .72567 .48538 .72152 .48453 Metetra
0 .333 .297 r
.72152 .48453 .72567 .48538 .73517 .48007 .73104 .47898 Metetra
0 .322 .302 r
.73104 .47898 .73517 .48007 .74469 .47475 .74059 .47342 Metetra
0 .312 .306 r
.74059 .47342 .74469 .47475 .75422 .46942 .75014 .46784 Metetra
0 .294 .302 r
.75014 .46784 .75422 .46942 .76377 .46408 .75972 .46226 Metetra
0 .271 .291 r
.75972 .46226 .76377 .46408 .77335 .45873 .76931 .45666 Metetra
0 .249 .281 r
.76931 .45666 .77335 .45873 .78294 .45336 .77892 .45106 Metetra
0 .227 .271 r
.77892 .45106 .78294 .45336 .79255 .44799 .78855 .44545 Metetra
0 .207 .26 r
.78855 .44545 .79255 .44799 .80218 .44261 .7982 .43982 Metetra
0 .188 .25 r
.7982 .43982 .80218 .44261 .81182 .43721 .80786 .43419 Metetra
0 .169 .24 r
.80786 .43419 .81182 .43721 .82149 .43181 .81754 .42854 Metetra
0 .152 .229 r
.81754 .42854 .82149 .43181 .83117 .42639 .82724 .42288 Metetra
0 .135 .219 r
.82724 .42288 .83117 .42639 .84088 .42097 .83696 .41721 Metetra
0 .119 .209 r
.83696 .41721 .84088 .42097 .8506 .41553 .84669 .41154 Metetra
0 .104 .198 r
.84669 .41154 .8506 .41553 .86034 .41008 .85644 .40584 Metetra
0 .091 .188 r
.85644 .40584 .86034 .41008 .8701 .40461 .86621 .40014 Metetra
0 .078 .178 r
.86621 .40014 .8701 .40461 .87988 .39914 .876 .39443 Metetra
0 .066 .167 r
.876 .39443 .87988 .39914 .88968 .39365 .88581 .3887 Metetra
0 .054 .157 r
.88581 .3887 .88968 .39365 .8995 .38816 .89563 .38297 Metetra
0 .044 .147 r
.89563 .38297 .8995 .38816 .90934 .38267 .90547 .37724 Metetra
0 .035 .137 r
.90547 .37724 .90934 .38267 .91921 .37726 .91535 .37159 Metetra
0 .028 .127 r
.91535 .37159 .91921 .37726 .92914 .37209 .92528 .36622 Metetra
0 .027 .126 r
.34001 .54323 .34519 .54804 .35342 .54721 .34824 .54253 Metetra
0 .034 .135 r
.34824 .54253 .35342 .54721 .36165 .54688 .35648 .54238 Metetra
0 .044 .146 r
.35648 .54238 .36165 .54688 .36992 .54668 .36475 .54238 Metetra
0 .055 .157 r
.36475 .54238 .36992 .54668 .37822 .54651 .37305 .54241 Metetra
0 .067 .169 r
.37305 .54241 .37822 .54651 .38656 .54635 .3814 .54244 Metetra
0 .08 .18 r
.3814 .54244 .38656 .54635 .39494 .54619 .38978 .54248 Metetra
0 .095 .191 r
.38978 .54248 .39494 .54619 .40335 .54602 .39821 .54251 Metetra
0 .11 .202 r
.39821 .54251 .40335 .54602 .41181 .54585 .40667 .54254 Metetra
0 .126 .214 r
.40667 .54254 .41181 .54585 .42031 .54568 .41518 .54257 Metetra
0 .144 .225 r
.41518 .54257 .42031 .54568 .42885 .54551 .42373 .5426 Metetra
0 .163 .236 r
.42373 .5426 .42885 .54551 .43742 .54534 .43232 .54263 Metetra
0 .183 .247 r
.43232 .54263 .43742 .54534 .44604 .54516 .44095 .54266 Metetra
0 .203 .259 r
.44095 .54266 .44604 .54516 .4547 .54499 .44962 .54269 Metetra
0 .225 .27 r
.44962 .54269 .4547 .54499 .46339 .54481 .45834 .54272 Metetra
0 .248 .281 r
.45834 .54272 .46339 .54481 .47213 .54463 .46709 .54275 Metetra
0 .273 .292 r
.46709 .54275 .47213 .54463 .48091 .54446 .4759 .54278 Metetra
0 .298 .303 r
.4759 .54278 .48091 .54446 .48974 .54428 .48474 .54281 Metetra
0 .315 .305 r
.48474 .54281 .48974 .54428 .4986 .5441 .49363 .54284 Metetra
0 .326 .3 r
.49363 .54284 .4986 .5441 .50751 .54392 .50256 .54287 Metetra
0 .337 .294 r
.50256 .54287 .50751 .54392 .51646 .54373 .51153 .5429 Metetra
0 .348 .287 r
.51153 .5429 .51646 .54373 .52545 .54355 .52055 .54293 Metetra
0 .36 .279 r
.52055 .54293 .52545 .54355 .53449 .54337 .52961 .54296 Metetra
0 .371 .269 r
.52961 .54296 .53449 .54337 .54357 .54319 .53872 .543 Metetra
0 .382 .259 r
.53872 .543 .54357 .54319 .55269 .54301 .54788 .54303 Metetra
0 .393 .247 r
.54788 .54303 .55269 .54301 .56186 .54282 .55708 .54307 Metetra
0 .405 .235 r
.55708 .54307 .56186 .54282 .57107 .54264 .56632 .5431 Metetra
0 .416 .221 r
.56632 .5431 .57107 .54264 .58032 .54246 .57562 .54314 Metetra
0 .427 .206 r
.57562 .54314 .58032 .54246 .58963 .54228 .58495 .54318 Metetra
0 .438 .19 r
.58495 .54318 .58963 .54228 .59897 .54209 .59434 .54321 Metetra
0 .449 .173 r
.59434 .54321 .59897 .54209 .60837 .54186 .60377 .5432 Metetra
0 .46 .156 r
.60377 .5432 .60837 .54186 .6178 .54141 .61325 .54295 Metetra
0 .466 .146 r
.61325 .54295 .6178 .54141 .62722 .53917 .62271 .54075 Metetra
0 .463 .152 r
.62271 .54075 .62722 .53917 .63658 .53403 .63211 .53539 Metetra
0 .452 .169 r
.63211 .53539 .63658 .53403 .64596 .52863 .64152 .52975 Metetra
0 .441 .186 r
.64152 .52975 .64596 .52863 .65534 .52316 .65094 .52403 Metetra
0 .43 .202 r
.65094 .52403 .65534 .52316 .66474 .51767 .66038 .51829 Metetra
0 .419 .217 r
.66038 .51829 .66474 .51767 .67416 .51217 .66983 .51254 Metetra
0 .407 .231 r
.66983 .51254 .67416 .51217 .6836 .50666 .6793 .50679 Metetra
0 .396 .244 r
.6793 .50679 .6836 .50666 .69306 .50114 .68878 .50102 Metetra
0 .385 .256 r
.68878 .50102 .69306 .50114 .70253 .49561 .69828 .49525 Metetra
0 .374 .267 r
.69828 .49525 .70253 .49561 .71202 .49008 .7078 .48947 Metetra
0 .362 .277 r
.7078 .48947 .71202 .49008 .72152 .48453 .71733 .48368 Metetra
0 .351 .285 r
.71733 .48368 .72152 .48453 .73104 .47898 .72688 .47788 Metetra
0 .34 .292 r
.72688 .47788 .73104 .47898 .74059 .47342 .73645 .47207 Metetra
0 .329 .299 r
.73645 .47207 .74059 .47342 .75014 .46784 .74603 .46625 Metetra
0 .317 .304 r
.74603 .46625 .75014 .46784 .75972 .46226 .75563 .46042 Metetra
0 .304 .306 r
.75563 .46042 .75972 .46226 .76931 .45666 .76524 .45459 Metetra
0 .279 .295 r
.76524 .45459 .76931 .45666 .77892 .45106 .77487 .44874 Metetra
0 .254 .284 r
.77487 .44874 .77892 .45106 .78855 .44545 .78452 .44288 Metetra
0 .231 .273 r
.78452 .44288 .78855 .44545 .7982 .43982 .79418 .43701 Metetra
0 .209 .261 r
.79418 .43701 .7982 .43982 .80786 .43419 .80386 .43113 Metetra
0 .188 .25 r
.80386 .43113 .80786 .43419 .81754 .42854 .81356 .42525 Metetra
0 .168 .239 r
.81356 .42525 .81754 .42854 .82724 .42288 .82327 .41935 Metetra
0 .149 .228 r
.82327 .41935 .82724 .42288 .83696 .41721 .833 .41344 Metetra
0 .131 .216 r
.833 .41344 .83696 .41721 .84669 .41154 .84275 .40751 Metetra
0 .114 .205 r
.84275 .40751 .84669 .41154 .85644 .40584 .85251 .40158 Metetra
0 .098 .194 r
.85251 .40158 .85644 .40584 .86621 .40014 .86229 .39564 Metetra
0 .084 .183 r
.86229 .39564 .86621 .40014 .876 .39443 .87209 .38968 Metetra
0 .07 .171 r
.87209 .38968 .876 .39443 .88581 .3887 .8819 .38371 Metetra
0 .058 .16 r
.8819 .38371 .88581 .3887 .89563 .38297 .89173 .37774 Metetra
0 .046 .149 r
.89173 .37774 .89563 .38297 .90547 .37724 .90158 .37177 Metetra
0 .036 .138 r
.90158 .37177 .90547 .37724 .91535 .37159 .91146 .3659 Metetra
0 .028 .128 r
.91146 .3659 .91535 .37159 .92528 .36622 .92139 .36032 Metetra
0 .027 .126 r
.3348 .53839 .34001 .54323 .34824 .54253 .34303 .53783 Metetra
0 .035 .137 r
.34303 .53783 .34824 .54253 .35648 .54238 .35127 .53786 Metetra
0 .046 .148 r
.35127 .53786 .35648 .54238 .36475 .54238 .35954 .53805 Metetra
0 .058 .16 r
.35954 .53805 .36475 .54238 .37305 .54241 .36785 .53828 Metetra
0 .071 .172 r
.36785 .53828 .37305 .54241 .3814 .54244 .3762 .53851 Metetra
0 .086 .185 r
.3762 .53851 .3814 .54244 .38978 .54248 .38459 .53874 Metetra
0 .102 .197 r
.38459 .53874 .38978 .54248 .39821 .54251 .39303 .53898 Metetra
0 .119 .209 r
.39303 .53898 .39821 .54251 .40667 .54254 .4015 .53921 Metetra
0 .138 .221 r
.4015 .53921 .40667 .54254 .41518 .54257 .41002 .53944 Metetra
0 .158 .233 r
.41002 .53944 .41518 .54257 .42373 .5426 .41858 .53968 Metetra
0 .179 .245 r
.41858 .53968 .42373 .5426 .43232 .54263 .42718 .53991 Metetra
0 .201 .257 r
.42718 .53991 .43232 .54263 .44095 .54266 .43582 .54015 Metetra
0 .225 .27 r
.43582 .54015 .44095 .54266 .44962 .54269 .44451 .54038 Metetra
0 .25 .282 r
.44451 .54038 .44962 .54269 .45834 .54272 .45324 .54062 Metetra
0 .276 .294 r
.45324 .54062 .45834 .54272 .46709 .54275 .46202 .54086 Metetra
0 .304 .306 r
.46202 .54086 .46709 .54275 .4759 .54278 .47084 .54109 Metetra
0 .318 .304 r
.47084 .54109 .4759 .54278 .48474 .54281 .4797 .54133 Metetra
0 .33 .298 r
.4797 .54133 .48474 .54281 .49363 .54284 .48861 .54157 Metetra
0 .342 .291 r
.48861 .54157 .49363 .54284 .50256 .54287 .49756 .54182 Metetra
0 .354 .283 r
.49756 .54182 .50256 .54287 .51153 .5429 .50656 .54206 Metetra
0 .367 .273 r
.50656 .54206 .51153 .5429 .52055 .54293 .51561 .5423 Metetra
0 .379 .262 r
.51561 .5423 .52055 .54293 .52961 .54296 .5247 .54255 Metetra
0 .391 .25 r
.5247 .54255 .52961 .54296 .53872 .543 .53383 .5428 Metetra
0 .403 .237 r
.53383 .5428 .53872 .543 .54788 .54303 .54302 .54305 Metetra
0 .415 .222 r
.54302 .54305 .54788 .54303 .55708 .54307 .55225 .54331 Metetra
0 .427 .206 r
.55225 .54331 .55708 .54307 .56632 .5431 .56153 .54356 Metetra
0 .439 .189 r
.56153 .54356 .56632 .5431 .57562 .54314 .57086 .54382 Metetra
0 .452 .17 r
.57086 .54382 .57562 .54314 .58495 .54318 .58024 .54409 Metetra
0 .464 .15 r
.58024 .54409 .58495 .54318 .59434 .54321 .58966 .54434 Metetra
0 .476 .129 r
.58966 .54434 .59434 .54321 .60377 .5432 .59913 .54455 Metetra
0 .487 .108 r
.59913 .54455 .60377 .5432 .61325 .54295 .60865 .54451 Metetra
0 .494 .095 r
.60865 .54451 .61325 .54295 .62271 .54075 .61816 .54235 Metetra
0 .49 .103 r
.61816 .54235 .62271 .54075 .63211 .53539 .62759 .53677 Metetra
0 .479 .124 r
.62759 .53677 .63211 .53539 .64152 .52975 .63704 .53088 Metetra
0 .467 .145 r
.63704 .53088 .64152 .52975 .65094 .52403 .6465 .52491 Metetra
0 .455 .165 r
.6465 .52491 .65094 .52403 .66038 .51829 .65597 .51892 Metetra
0 .443 .184 r
.65597 .51892 .66038 .51829 .66983 .51254 .66545 .51292 Metetra
0 .43 .202 r
.66545 .51292 .66983 .51254 .6793 .50679 .67495 .50692 Metetra
0 .418 .218 r
.67495 .50692 .6793 .50679 .68878 .50102 .68447 .5009 Metetra
0 .406 .233 r
.68447 .5009 .68878 .50102 .69828 .49525 .694 .49488 Metetra
0 .394 .247 r
.694 .49488 .69828 .49525 .7078 .48947 .70355 .48885 Metetra
0 .382 .259 r
.70355 .48885 .7078 .48947 .71733 .48368 .71311 .48281 Metetra
0 .37 .27 r
.71311 .48281 .71733 .48368 .72688 .47788 .72268 .47677 Metetra
0 .357 .28 r
.72268 .47677 .72688 .47788 .73645 .47207 .73228 .47071 Metetra
0 .345 .289 r
.73228 .47071 .73645 .47207 .74603 .46625 .74188 .46465 Metetra
0 .333 .296 r
.74188 .46465 .74603 .46625 .75563 .46042 .7515 .45857 Metetra
0 .321 .302 r
.7515 .45857 .75563 .46042 .76524 .45459 .76114 .45249 Metetra
0 .309 .307 r
.76114 .45249 .76524 .45459 .77487 .44874 .77079 .4464 Metetra
0 .283 .297 r
.77079 .4464 .77487 .44874 .78452 .44288 .78046 .44029 Metetra
0 .256 .285 r
.78046 .44029 .78452 .44288 .79418 .43701 .79014 .43418 Metetra
0 .231 .273 r
.79014 .43418 .79418 .43701 .80386 .43113 .79984 .42806 Metetra
0 .207 .26 r
.79984 .42806 .80386 .43113 .81356 .42525 .80955 .42192 Metetra
0 .184 .248 r
.80955 .42192 .81356 .42525 .82327 .41935 .81928 .41578 Metetra
0 .163 .236 r
.81928 .41578 .82327 .41935 .833 .41344 .82902 .40963 Metetra
0 .143 .224 r
.82902 .40963 .833 .41344 .84275 .40751 .83878 .40346 Metetra
0 .124 .212 r
.83878 .40346 .84275 .40751 .85251 .40158 .84855 .39729 Metetra
0 .106 .2 r
.84855 .39729 .85251 .40158 .86229 .39564 .85834 .3911 Metetra
0 .09 .188 r
.85834 .3911 .86229 .39564 .87209 .38968 .86815 .3849 Metetra
0 .075 .175 r
.86815 .3849 .87209 .38968 .8819 .38371 .87797 .37869 Metetra
0 .061 .163 r
.87797 .37869 .8819 .38371 .89173 .37774 .8878 .37247 Metetra
0 .049 .151 r
.8878 .37247 .89173 .37774 .90158 .37177 .89766 .36627 Metetra
0 .038 .139 r
.89766 .36627 .90158 .37177 .91146 .3659 .90754 .36016 Metetra
0 .029 .128 r
.90754 .36016 .91146 .3659 .92139 .36032 .91748 .35438 Metetra
0 .027 .127 r
.32955 .53352 .3348 .53839 .34303 .53783 .33779 .5331 Metetra
0 .036 .138 r
.33779 .5331 .34303 .53783 .35127 .53786 .34603 .53331 Metetra
0 .048 .15 r
.34603 .53331 .35127 .53786 .35954 .53805 .35431 .53369 Metetra
0 .061 .163 r
.35431 .53369 .35954 .53805 .36785 .53828 .36262 .53412 Metetra
0 .076 .176 r
.36262 .53412 .36785 .53828 .3762 .53851 .37098 .53455 Metetra
0 .092 .189 r
.37098 .53455 .3762 .53851 .38459 .53874 .37937 .53498 Metetra
0 .11 .202 r
.37937 .53498 .38459 .53874 .39303 .53898 .38781 .53542 Metetra
0 .129 .215 r
.38781 .53542 .39303 .53898 .4015 .53921 .39629 .53586 Metetra
0 .15 .228 r
.39629 .53586 .4015 .53921 .41002 .53944 .40482 .53629 Metetra
0 .172 .241 r
.40482 .53629 .41002 .53944 .41858 .53968 .41339 .53673 Metetra
0 .196 .255 r
.41339 .53673 .41858 .53968 .42718 .53991 .422 .53717 Metetra
0 .221 .268 r
.422 .53717 .42718 .53991 .43582 .54015 .43066 .53761 Metetra
0 .248 .281 r
.43066 .53761 .43582 .54015 .44451 .54038 .43936 .53805 Metetra
0 .276 .294 r
.43936 .53805 .44451 .54038 .45324 .54062 .44811 .5385 Metetra
0 .305 .307 r
.44811 .5385 .45324 .54062 .46202 .54086 .4569 .53894 Metetra
0 .32 .303 r
.4569 .53894 .46202 .54086 .47084 .54109 .46574 .53939 Metetra
0 .333 .297 r
.46574 .53939 .47084 .54109 .4797 .54133 .47462 .53984 Metetra
0 .346 .289 r
.47462 .53984 .4797 .54133 .48861 .54157 .48355 .5403 Metetra
0 .359 .279 r
.48355 .5403 .48861 .54157 .49756 .54182 .49252 .54075 Metetra
0 .372 .268 r
.49252 .54075 .49756 .54182 .50656 .54206 .50155 .54121 Metetra
0 .385 .256 r
.50155 .54121 .50656 .54206 .51561 .5423 .51062 .54167 Metetra
0 .398 .242 r
.51062 .54167 .51561 .5423 .5247 .54255 .51974 .54214 Metetra
0 .411 .227 r
.51974 .54214 .5247 .54255 .53383 .5428 .5289 .5426 Metetra
0 .424 .21 r
.5289 .5426 .53383 .5428 .54302 .54305 .53812 .54308 Metetra
0 .437 .192 r
.53812 .54308 .54302 .54305 .55225 .54331 .54738 .54355 Metetra
0 .45 .172 r
.54738 .54355 .55225 .54331 .56153 .54356 .5567 .54403 Metetra
0 .463 .151 r
.5567 .54403 .56153 .54356 .57086 .54382 .56606 .54452 Metetra
0 .476 .128 r
.56606 .54452 .57086 .54382 .58024 .54409 .57547 .545 Metetra
0 .489 .104 r
.57547 .545 .58024 .54409 .58966 .54434 .58493 .54549 Metetra
0 .502 .079 r
.58493 .54549 .58966 .54434 .59913 .54455 .59445 .54592 Metetra
0 .515 .053 r
.59445 .54592 .59913 .54455 .60865 .54451 .60401 .54608 Metetra
0 .522 .038 r
.60401 .54608 .60865 .54451 .61816 .54235 .61355 .54396 Metetra
0 .518 .047 r
.61355 .54396 .61816 .54235 .62759 .53677 .62303 .53816 Metetra
0 .505 .072 r
.62303 .53816 .62759 .53677 .63704 .53088 .63251 .53202 Metetra
0 .493 .098 r
.63251 .53202 .63704 .53088 .6465 .52491 .64201 .5258 Metetra
0 .48 .123 r
.64201 .5258 .6465 .52491 .65597 .51892 .65151 .51955 Metetra
0 .466 .146 r
.65151 .51955 .65597 .51892 .66545 .51292 .66103 .5133 Metetra
0 .453 .167 r
.66103 .5133 .66545 .51292 .67495 .50692 .67057 .50705 Metetra
0 .44 .187 r
.67057 .50705 .67495 .50692 .68447 .5009 .68012 .50078 Metetra
0 .427 .206 r
.68012 .50078 .68447 .5009 .694 .49488 .68968 .49451 Metetra
0 .414 .223 r
.68968 .49451 .694 .49488 .70355 .48885 .69925 .48823 Metetra
0 .401 .239 r
.69925 .48823 .70355 .48885 .71311 .48281 .70884 .48194 Metetra
0 .388 .253 r
.70884 .48194 .71311 .48281 .72268 .47677 .71845 .47564 Metetra
0 .375 .266 r
.71845 .47564 .72268 .47677 .73228 .47071 .72807 .46934 Metetra
0 .362 .277 r
.72807 .46934 .73228 .47071 .74188 .46465 .7377 .46303 Metetra
0 .349 .287 r
.7377 .46303 .74188 .46465 .7515 .45857 .74734 .4567 Metetra
0 .336 .295 r
.74734 .4567 .7515 .45857 .76114 .45249 .757 .45037 Metetra
0 .323 .302 r
.757 .45037 .76114 .45249 .77079 .4464 .76667 .44403 Metetra
0 .31 .307 r
.76667 .44403 .77079 .4464 .78046 .44029 .77636 .43768 Metetra
0 .283 .297 r
.77636 .43768 .78046 .44029 .79014 .43418 .78606 .43132 Metetra
0 .254 .284 r
.78606 .43132 .79014 .43418 .79984 .42806 .79578 .42496 Metetra
0 .227 .271 r
.79578 .42496 .79984 .42806 .80955 .42192 .80551 .41858 Metetra
0 .202 .258 r
.80551 .41858 .80955 .42192 .81928 .41578 .81525 .41219 Metetra
0 .178 .245 r
.81525 .41219 .81928 .41578 .82902 .40963 .82501 .40579 Metetra
0 .155 .232 r
.82501 .40579 .82902 .40963 .83878 .40346 .83478 .39938 Metetra
0 .134 .219 r
.83478 .39938 .83878 .40346 .84855 .39729 .84457 .39296 Metetra
0 .115 .206 r
.84457 .39296 .84855 .39729 .85834 .3911 .85437 .38653 Metetra
0 .096 .192 r
.85437 .38653 .85834 .3911 .86815 .3849 .86418 .38009 Metetra
0 .08 .179 r
.86418 .38009 .86815 .3849 .87797 .37869 .87401 .37363 Metetra
0 .064 .166 r
.87401 .37363 .87797 .37869 .8878 .37247 .88385 .36717 Metetra
0 .051 .153 r
.88385 .36717 .8878 .37247 .89766 .36627 .89371 .36072 Metetra
0 .039 .141 r
.89371 .36072 .89766 .36627 .90754 .36016 .9036 .35439 Metetra
0 .029 .129 r
.9036 .35439 .90754 .36016 .91748 .35438 .91354 .34839 Metetra
0 .028 .127 r
.32428 .52862 .32955 .53352 .33779 .5331 .33252 .52834 Metetra
0 .037 .139 r
.33252 .52834 .33779 .5331 .34603 .53331 .34077 .52873 Metetra
0 .05 .152 r
.34077 .52873 .34603 .53331 .35431 .53369 .34904 .52931 Metetra
0 .064 .166 r
.34904 .52931 .35431 .53369 .36262 .53412 .35736 .52993 Metetra
0 .08 .18 r
.35736 .52993 .36262 .53412 .37098 .53455 .36571 .53057 Metetra
0 .098 .194 r
.36571 .53057 .37098 .53455 .37937 .53498 .37411 .5312 Metetra
0 .118 .208 r
.37411 .5312 .37937 .53498 .38781 .53542 .38256 .53184 Metetra
0 .139 .222 r
.38256 .53184 .38781 .53542 .39629 .53586 .39105 .53248 Metetra
0 .162 .236 r
.39105 .53248 .39629 .53586 .40482 .53629 .39958 .53312 Metetra
0 .187 .25 r
.39958 .53312 .40482 .53629 .41339 .53673 .40816 .53376 Metetra
0 .214 .264 r
.40816 .53376 .41339 .53673 .422 .53717 .41679 .53441 Metetra
0 .242 .278 r
.41679 .53441 .422 .53717 .43066 .53761 .42545 .53506 Metetra
0 .271 .292 r
.42545 .53506 .43066 .53761 .43936 .53805 .43417 .53571 Metetra
0 .303 .306 r
.43417 .53571 .43936 .53805 .44811 .5385 .44293 .53636 Metetra
0 .32 .303 r
.44293 .53636 .44811 .5385 .4569 .53894 .45174 .53702 Metetra
0 .333 .296 r
.45174 .53702 .4569 .53894 .46574 .53939 .46059 .53768 Metetra
0 .347 .288 r
.46059 .53768 .46574 .53939 .47462 .53984 .4695 .53834 Metetra
0 .361 .277 r
.4695 .53834 .47462 .53984 .48355 .5403 .47845 .53901 Metetra
0 .375 .265 r
.47845 .53901 .48355 .5403 .49252 .54075 .48745 .53968 Metetra
0 .389 .252 r
.48745 .53968 .49252 .54075 .50155 .54121 .49649 .54035 Metetra
0 .403 .236 r
.49649 .54035 .50155 .54121 .51062 .54167 .50559 .54103 Metetra
0 .417 .219 r
.50559 .54103 .51062 .54167 .51974 .54214 .51473 .54172 Metetra
0 .431 .201 r
.51473 .54172 .51974 .54214 .5289 .5426 .52393 .54241 Metetra
0 .445 .18 r
.52393 .54241 .5289 .5426 .53812 .54308 .53317 .5431 Metetra
0 .459 .158 r
.53317 .5431 .53812 .54308 .54738 .54355 .54247 .5438 Metetra
0 .473 .134 r
.54247 .5438 .54738 .54355 .5567 .54403 .55181 .5445 Metetra
0 .487 .109 r
.55181 .5445 .5567 .54403 .56606 .54452 .56121 .54521 Metetra
0 .501 .082 r
.56121 .54521 .56606 .54452 .57547 .545 .57066 .54593 Metetra
0 .515 .053 r
.57066 .54593 .57547 .545 .58493 .54549 .58016 .54664 Metetra
0 .529 .023 r
.58016 .54664 .58493 .54549 .59445 .54592 .58971 .5473 Metetra
.008 .542 0 r
.58971 .5473 .59445 .54592 .60401 .54608 .59931 .54767 Metetra
.027 .55 0 r
.59931 .54767 .60401 .54608 .61355 .54396 .6089 .54559 Metetra
.015 .545 0 r
.6089 .54559 .61355 .54396 .62303 .53816 .61842 .53956 Metetra
0 .532 .015 r
.61842 .53956 .62303 .53816 .63251 .53202 .62794 .53318 Metetra
0 .518 .045 r
.62794 .53318 .63251 .53202 .64201 .5258 .63747 .5267 Metetra
0 .504 .075 r
.63747 .5267 .64201 .5258 .65151 .51955 .64702 .5202 Metetra
0 .49 .102 r
.64702 .5202 .65151 .51955 .66103 .5133 .65657 .51369 Metetra
0 .476 .128 r
.65657 .51369 .66103 .5133 .67057 .50705 .66614 .50718 Metetra
0 .462 .152 r
.66614 .50718 .67057 .50705 .68012 .50078 .67572 .50066 Metetra
0 .448 .175 r
.67572 .50066 .68012 .50078 .68968 .49451 .68532 .49413 Metetra
0 .434 .196 r
.68532 .49413 .68968 .49451 .69925 .48823 .69492 .4876 Metetra
0 .421 .215 r
.69492 .4876 .69925 .48823 .70884 .48194 .70454 .48106 Metetra
0 .407 .232 r
.70454 .48106 .70884 .48194 .71845 .47564 .71417 .47451 Metetra
0 .393 .248 r
.71417 .47451 .71845 .47564 .72807 .46934 .72382 .46796 Metetra
0 .379 .262 r
.72382 .46796 .72807 .46934 .7377 .46303 .73347 .46139 Metetra
0 .365 .275 r
.73347 .46139 .7377 .46303 .74734 .4567 .74314 .45482 Metetra
0 .351 .285 r
.74314 .45482 .74734 .4567 .757 .45037 .75283 .44824 Metetra
0 .337 .294 r
.75283 .44824 .757 .45037 .76667 .44403 .76252 .44165 Metetra
0 .323 .302 r
.76252 .44165 .76667 .44403 .77636 .43768 .77223 .43505 Metetra
0 .309 .307 r
.77223 .43505 .77636 .43768 .78606 .43132 .78195 .42845 Metetra
0 .279 .295 r
.78195 .42845 .78606 .43132 .79578 .42496 .79169 .42183 Metetra
0 .249 .281 r
.79169 .42183 .79578 .42496 .80551 .41858 .80143 .4152 Metetra
0 .22 .267 r
.80143 .4152 .80551 .41858 .81525 .41219 .81119 .40857 Metetra
0 .194 .253 r
.81119 .40857 .81525 .41219 .82501 .40579 .82097 .40192 Metetra
0 .168 .239 r
.82097 .40192 .82501 .40579 .83478 .39938 .83075 .39527 Metetra
0 .145 .225 r
.83075 .39527 .83478 .39938 .84457 .39296 .84055 .3886 Metetra
0 .123 .211 r
.84055 .3886 .84457 .39296 .85437 .38653 .85036 .38193 Metetra
0 .103 .197 r
.85036 .38193 .85437 .38653 .86418 .38009 .86018 .37524 Metetra
0 .085 .183 r
.86018 .37524 .86418 .38009 .87401 .37363 .87002 .36854 Metetra
0 .068 .169 r
.87002 .36854 .87401 .37363 .88385 .36717 .87987 .36184 Metetra
0 .053 .156 r
.87987 .36184 .88385 .36717 .89371 .36072 .88974 .35515 Metetra
0 .04 .142 r
.88974 .35515 .89371 .36072 .9036 .35439 .89963 .34857 Metetra
0 .029 .129 r
.89963 .34857 .9036 .35439 .91354 .34839 .90958 .34237 Metetra
0 .028 .128 r
.31898 .52369 .32428 .52862 .33252 .52834 .32722 .52355 Metetra
0 .038 .14 r
.32722 .52355 .33252 .52834 .34077 .52873 .33547 .52412 Metetra
0 .052 .154 r
.33547 .52412 .34077 .52873 .34904 .52931 .34374 .5249 Metetra
0 .067 .169 r
.34374 .5249 .34904 .52931 .35736 .52993 .35206 .52572 Metetra
0 .085 .184 r
.35206 .52572 .35736 .52993 .36571 .53057 .36042 .52656 Metetra
0 .105 .199 r
.36042 .52656 .36571 .53057 .37411 .5312 .36882 .52739 Metetra
0 .126 .214 r
.36882 .52739 .37411 .5312 .38256 .53184 .37727 .52823 Metetra
0 .15 .228 r
.37727 .52823 .38256 .53184 .39105 .53248 .38577 .52908 Metetra
0 .175 .243 r
.38577 .52908 .39105 .53248 .39958 .53312 .39431 .52992 Metetra
0 .203 .258 r
.39431 .52992 .39958 .53312 .40816 .53376 .4029 .53077 Metetra
0 .232 .273 r
.4029 .53077 .40816 .53376 .41679 .53441 .41153 .53162 Metetra
0 .263 .288 r
.41153 .53162 .41679 .53441 .42545 .53506 .42021 .53248 Metetra
0 .296 .303 r
.42021 .53248 .42545 .53506 .43417 .53571 .42894 .53334 Metetra
0 .318 .304 r
.42894 .53334 .43417 .53571 .44293 .53636 .43772 .5342 Metetra
0 .332 .297 r
.43772 .5342 .44293 .53636 .45174 .53702 .44654 .53507 Metetra
0 .347 .288 r
.44654 .53507 .45174 .53702 .46059 .53768 .45541 .53595 Metetra
0 .362 .277 r
.45541 .53595 .46059 .53768 .4695 .53834 .46433 .53682 Metetra
0 .377 .264 r
.46433 .53682 .4695 .53834 .47845 .53901 .4733 .53771 Metetra
0 .392 .249 r
.4733 .53771 .47845 .53901 .48745 .53968 .48232 .5386 Metetra
0 .407 .232 r
.48232 .5386 .48745 .53968 .49649 .54035 .49139 .53949 Metetra
0 .421 .214 r
.49139 .53949 .49649 .54035 .50559 .54103 .50051 .54039 Metetra
0 .436 .193 r
.50051 .54039 .50559 .54103 .51473 .54172 .50968 .54129 Metetra
0 .451 .171 r
.50968 .54129 .51473 .54172 .52393 .54241 .5189 .54221 Metetra
0 .466 .146 r
.5189 .54221 .52393 .54241 .53317 .5431 .52818 .54312 Metetra
0 .481 .12 r
.52818 .54312 .53317 .5431 .54247 .5438 .5375 .54405 Metetra
0 .496 .092 r
.5375 .54405 .54247 .5438 .55181 .5445 .54688 .54498 Metetra
0 .511 .062 r
.54688 .54498 .55181 .5445 .56121 .54521 .55631 .54592 Metetra
0 .525 .03 r
.55631 .54592 .56121 .54521 .57066 .54593 .5658 .54687 Metetra
.004 .54 0 r
.5658 .54687 .57066 .54593 .58016 .54664 .57534 .54781 Metetra
.04 .555 0 r
.57534 .54781 .58016 .54664 .58971 .5473 .58493 .54869 Metetra
.075 .569 0 r
.58493 .54869 .58971 .5473 .59931 .54767 .59457 .54928 Metetra
.097 .577 0 r
.59457 .54928 .59931 .54767 .6089 .54559 .6042 .54724 Metetra
.084 .572 0 r
.6042 .54724 .6089 .54559 .61842 .53956 .61376 .54098 Metetra
.049 .559 0 r
.61376 .54098 .61842 .53956 .62794 .53318 .62332 .53434 Metetra
.013 .544 0 r
.62332 .53434 .62794 .53318 .63747 .5267 .63289 .5276 Metetra
0 .529 .021 r
.63289 .5276 .63747 .5267 .64702 .5202 .64247 .52084 Metetra
0 .514 .054 r
.64247 .52084 .64702 .5202 .65657 .51369 .65206 .51408 Metetra
0 .499 .085 r
.65206 .51408 .65657 .51369 .66614 .50718 .66167 .50731 Metetra
0 .484 .113 r
.66167 .50731 .66614 .50718 .67572 .50066 .67128 .50054 Metetra
0 .47 .14 r
.67128 .50054 .67572 .50066 .68532 .49413 .68091 .49375 Metetra
0 .455 .165 r
.68091 .49375 .68532 .49413 .69492 .4876 .69055 .48697 Metetra
0 .44 .188 r
.69055 .48697 .69492 .4876 .70454 .48106 .7002 .48017 Metetra
0 .425 .209 r
.7002 .48017 .70454 .48106 .71417 .47451 .70986 .47337 Metetra
0 .41 .228 r
.70986 .47337 .71417 .47451 .72382 .46796 .71953 .46656 Metetra
0 .395 .245 r
.71953 .46656 .72382 .46796 .73347 .46139 .72922 .45974 Metetra
0 .381 .26 r
.72922 .45974 .73347 .46139 .74314 .45482 .73891 .45292 Metetra
0 .366 .274 r
.73891 .45292 .74314 .45482 .75283 .44824 .74862 .44609 Metetra
0 .351 .285 r
.74862 .44609 .75283 .44824 .76252 .44165 .75834 .43925 Metetra
0 .336 .295 r
.75834 .43925 .76252 .44165 .77223 .43505 .76807 .4324 Metetra
0 .321 .302 r
.76807 .4324 .77223 .43505 .78195 .42845 .77781 .42554 Metetra
0 .305 .306 r
.77781 .42554 .78195 .42845 .79169 .42183 .78756 .41868 Metetra
0 .271 .291 r
.78756 .41868 .79169 .42183 .80143 .4152 .79733 .4118 Metetra
0 .239 .277 r
.79733 .4118 .80143 .4152 .81119 .40857 .8071 .40492 Metetra
0 .21 .262 r
.8071 .40492 .81119 .40857 .82097 .40192 .81689 .39803 Metetra
0 .182 .247 r
.81689 .39803 .82097 .40192 .83075 .39527 .82669 .39113 Metetra
0 .156 .232 r
.82669 .39113 .83075 .39527 .84055 .3886 .8365 .38421 Metetra
0 .132 .217 r
.8365 .38421 .84055 .3886 .85036 .38193 .84633 .37729 Metetra
0 .11 .202 r
.84633 .37729 .85036 .38193 .86018 .37524 .85616 .37036 Metetra
0 .09 .187 r
.85616 .37036 .86018 .37524 .87002 .36854 .86601 .36341 Metetra
0 .072 .173 r
.86601 .36341 .87002 .36854 .87987 .36184 .87586 .35646 Metetra
0 .055 .158 r
.87586 .35646 .87987 .36184 .88974 .35515 .88573 .34953 Metetra
0 .041 .143 r
.88573 .34953 .88974 .35515 .89963 .34857 .89563 .34272 Metetra
0 .03 .13 r
.89563 .34272 .89963 .34857 .90958 .34237 .9056 .33631 Metetra
0 .028 .128 r
.31364 .51874 .31898 .52369 .32722 .52355 .32189 .51873 Metetra
0 .039 .141 r
.32189 .51873 .32722 .52355 .33547 .52412 .33013 .51949 Metetra
0 .054 .156 r
.33013 .51949 .33547 .52412 .34374 .5249 .33841 .52046 Metetra
0 .071 .172 r
.33841 .52046 .34374 .5249 .35206 .52572 .34672 .52148 Metetra
0 .09 .188 r
.34672 .52148 .35206 .52572 .36042 .52656 .35509 .52252 Metetra
0 .111 .203 r
.35509 .52252 .36042 .52656 .36882 .52739 .3635 .52356 Metetra
0 .135 .219 r
.3635 .52356 .36882 .52739 .37727 .52823 .37195 .5246 Metetra
0 .161 .235 r
.37195 .5246 .37727 .52823 .38577 .52908 .38045 .52565 Metetra
0 .189 .251 r
.38045 .52565 .38577 .52908 .39431 .52992 .389 .5267 Metetra
0 .219 .266 r
.389 .5267 .39431 .52992 .4029 .53077 .39759 .52776 Metetra
0 .251 .282 r
.39759 .52776 .4029 .53077 .41153 .53162 .40624 .52882 Metetra
0 .285 .298 r
.40624 .52882 .41153 .53162 .42021 .53248 .41493 .52989 Metetra
0 .314 .306 r
.41493 .52989 .42021 .53248 .42894 .53334 .42367 .53096 Metetra
0 .329 .298 r
.42367 .53096 .42894 .53334 .43772 .5342 .43246 .53203 Metetra
0 .345 .289 r
.43246 .53203 .43772 .5342 .44654 .53507 .4413 .53312 Metetra
0 .361 .278 r
.4413 .53312 .44654 .53507 .45541 .53595 .45019 .5342 Metetra
0 .377 .264 r
.45019 .5342 .45541 .53595 .46433 .53682 .45912 .5353 Metetra
0 .392 .248 r
.45912 .5353 .46433 .53682 .4733 .53771 .46811 .5364 Metetra
0 .408 .23 r
.46811 .5364 .4733 .53771 .48232 .5386 .47715 .5375 Metetra
0 .424 .21 r
.47715 .5375 .48232 .5386 .49139 .53949 .48625 .53862 Metetra
0 .44 .188 r
.48625 .53862 .49139 .53949 .50051 .54039 .49539 .53974 Metetra
0 .455 .164 r
.49539 .53974 .50051 .54039 .50968 .54129 .50459 .54087 Metetra
0 .471 .137 r
.50459 .54087 .50968 .54129 .5189 .54221 .51383 .542 Metetra
0 .487 .109 r
.51383 .542 .5189 .54221 .52818 .54312 .52314 .54315 Metetra
0 .503 .078 r
.52314 .54315 .52818 .54312 .5375 .54405 .53249 .5443 Metetra
0 .518 .045 r
.53249 .5443 .5375 .54405 .54688 .54498 .5419 .54546 Metetra
0 .534 .01 r
.5419 .54546 .54688 .54498 .55631 .54592 .55137 .54663 Metetra
.028 .55 0 r
.55137 .54663 .55631 .54592 .5658 .54687 .56089 .54781 Metetra
.067 .566 0 r
.56089 .54781 .5658 .54687 .57534 .54781 .57046 .54899 Metetra
.108 .581 0 r
.57046 .54899 .57534 .54781 .58493 .54869 .5801 .5501 Metetra
.149 .596 0 r
.5801 .5501 .58493 .54869 .59457 .54928 .58978 .5509 Metetra
.175 .605 0 r
.58978 .5509 .59457 .54928 .6042 .54724 .59945 .5489 Metetra
.16 .6 0 r
.59945 .5489 .6042 .54724 .61376 .54098 .60905 .54241 Metetra
.119 .585 0 r
.60905 .54241 .61376 .54098 .62332 .53434 .61865 .53552 Metetra
.077 .57 0 r
.61865 .53552 .62332 .53434 .63289 .5276 .62826 .52852 Metetra
.037 .554 0 r
.62826 .52852 .63289 .5276 .64247 .52084 .63788 .5215 Metetra
0 .538 .001 r
.63788 .5215 .64247 .52084 .65206 .51408 .64751 .51447 Metetra
0 .522 .036 r
.64751 .51447 .65206 .51408 .66167 .50731 .65715 .50745 Metetra
0 .507 .07 r
.65715 .50745 .66167 .50731 .67128 .50054 .6668 .50041 Metetra
0 .491 .101 r
.6668 .50041 .67128 .50054 .68091 .49375 .67646 .49337 Metetra
0 .475 .131 r
.67646 .49337 .68091 .49375 .69055 .48697 .68613 .48633 Metetra
0 .459 .158 r
.68613 .48633 .69055 .48697 .7002 .48017 .69581 .47927 Metetra
0 .444 .182 r
.69581 .47927 .7002 .48017 .70986 .47337 .7055 .47222 Metetra
0 .428 .205 r
.7055 .47222 .70986 .47337 .71953 .46656 .71521 .46515 Metetra
0 .412 .226 r
.71521 .46515 .71953 .46656 .72922 .45974 .72492 .45808 Metetra
0 .396 .244 r
.72492 .45808 .72922 .45974 .73891 .45292 .73464 .451 Metetra
0 .381 .26 r
.73464 .451 .73891 .45292 .74862 .44609 .74437 .44392 Metetra
0 .365 .274 r
.74437 .44392 .74862 .44609 .75834 .43925 .75411 .43683 Metetra
0 .349 .286 r
.75411 .43683 .75834 .43925 .76807 .4324 .76387 .42973 Metetra
0 .333 .296 r
.76387 .42973 .76807 .4324 .77781 .42554 .77363 .42262 Metetra
0 .318 .304 r
.77363 .42262 .77781 .42554 .78756 .41868 .7834 .4155 Metetra
0 .294 .302 r
.7834 .4155 .78756 .41868 .79733 .4118 .79319 .40838 Metetra
0 .259 .286 r
.79319 .40838 .79733 .4118 .8071 .40492 .80298 .40124 Metetra
0 .227 .27 r
.80298 .40124 .8071 .40492 .81689 .39803 .81279 .3941 Metetra
0 .196 .255 r
.81279 .3941 .81689 .39803 .82669 .39113 .8226 .38695 Metetra
0 .168 .239 r
.8226 .38695 .82669 .39113 .8365 .38421 .83243 .37979 Metetra
0 .141 .223 r
.83243 .37979 .8365 .38421 .84633 .37729 .84226 .37262 Metetra
0 .117 .207 r
.84226 .37262 .84633 .37729 .85616 .37036 .85211 .36544 Metetra
0 .095 .191 r
.85211 .36544 .85616 .37036 .86601 .36341 .86196 .35825 Metetra
0 .075 .176 r
.86196 .35825 .86601 .36341 .87586 .35646 .87183 .35105 Metetra
0 .058 .16 r
.87183 .35105 .87586 .35646 .88573 .34953 .88171 .34388 Metetra
0 .042 .145 r
.88171 .34388 .88573 .34953 .89563 .34272 .89161 .33684 Metetra
0 .03 .13 r
.89161 .33684 .89563 .34272 .9056 .33631 .90158 .33022 Metetra
0 .029 .128 r
.30828 .51375 .31364 .51874 .32189 .51873 .31653 .51389 Metetra
0 .04 .142 r
.31653 .51389 .32189 .51873 .33013 .51949 .32477 .51483 Metetra
0 .056 .158 r
.32477 .51483 .33013 .51949 .33841 .52046 .33304 .516 Metetra
0 .074 .175 r
.33304 .516 .33841 .52046 .34672 .52148 .34136 .51722 Metetra
0 .095 .191 r
.34136 .51722 .34672 .52148 .35509 .52252 .34972 .51846 Metetra
0 .118 .208 r
.34972 .51846 .35509 .52252 .3635 .52356 .35813 .5197 Metetra
0 .144 .225 r
.35813 .5197 .3635 .52356 .37195 .5246 .36659 .52095 Metetra
0 .172 .241 r
.36659 .52095 .37195 .5246 .38045 .52565 .3751 .5222 Metetra
0 .203 .258 r
.3751 .5222 .38045 .52565 .389 .5267 .38365 .52346 Metetra
0 .236 .275 r
.38365 .52346 .389 .5267 .39759 .52776 .39225 .52473 Metetra
0 .271 .291 r
.39225 .52473 .39759 .52776 .40624 .52882 .40091 .526 Metetra
0 .308 .308 r
.40091 .526 .40624 .52882 .41493 .52989 .40961 .52727 Metetra
0 .325 .301 r
.40961 .52727 .41493 .52989 .42367 .53096 .41836 .52856 Metetra
0 .341 .292 r
.41836 .52856 .42367 .53096 .43246 .53203 .42716 .52984 Metetra
0 .358 .28 r
.42716 .52984 .43246 .53203 .4413 .53312 .43601 .53114 Metetra
0 .375 .266 r
.43601 .53114 .4413 .53312 .45019 .5342 .44492 .53245 Metetra
0 .391 .25 r
.44492 .53245 .45019 .5342 .45912 .5353 .45387 .53376 Metetra
0 .408 .231 r
.45387 .53376 .45912 .5353 .46811 .5364 .46288 .53508 Metetra
0 .425 .209 r
.46288 .53508 .46811 .5364 .47715 .5375 .47194 .5364 Metetra
0 .441 .186 r
.47194 .5364 .47715 .5375 .48625 .53862 .48106 .53774 Metetra
0 .458 .16 r
.48106 .53774 .48625 .53862 .49539 .53974 .49022 .53908 Metetra
0 .475 .131 r
.49022 .53908 .49539 .53974 .50459 .54087 .49944 .54044 Metetra
0 .491 .101 r
.49944 .54044 .50459 .54087 .51383 .542 .50872 .5418 Metetra
0 .508 .067 r
.50872 .5418 .51383 .542 .52314 .54315 .51805 .54317 Metetra
0 .525 .032 r
.51805 .54317 .52314 .54315 .53249 .5443 .52743 .54456 Metetra
.006 .541 0 r
.52743 .54456 .53249 .5443 .5419 .54546 .53688 .54595 Metetra
.047 .558 0 r
.53688 .54595 .5419 .54546 .55137 .54663 .54637 .54735 Metetra
.09 .575 0 r
.54637 .54735 .55137 .54663 .56089 .54781 .55593 .54877 Metetra
.135 .591 0 r
.55593 .54877 .56089 .54781 .57046 .54899 .56554 .55018 Metetra
.183 .608 0 r
.56554 .55018 .57046 .54899 .5801 .5501 .57521 .55153 Metetra
.23 .624 0 r
.57521 .55153 .5801 .5501 .58978 .5509 .58493 .55254 Metetra
.259 .633 0 r
.58493 .55254 .58978 .5509 .59945 .5489 .59465 .55059 Metetra
.242 .627 0 r
.59465 .55059 .59945 .5489 .60905 .54241 .60429 .54386 Metetra
.195 .612 0 r
.60429 .54386 .60905 .54241 .61865 .53552 .61394 .53671 Metetra
.147 .595 0 r
.61394 .53671 .61865 .53552 .62826 .52852 .62359 .52944 Metetra
.101 .579 0 r
.62359 .52944 .62826 .52852 .63788 .5215 .63325 .52216 Metetra
.058 .562 0 r
.63325 .52216 .63788 .5215 .64751 .51447 .64291 .51487 Metetra
.016 .545 0 r
.64291 .51487 .64751 .51447 .65715 .50745 .65259 .50758 Metetra
0 .529 .022 r
.65259 .50758 .65715 .50745 .6668 .50041 .66228 .50029 Metetra
0 .512 .059 r
.66228 .50029 .6668 .50041 .67646 .49337 .67197 .49299 Metetra
0 .495 .093 r
.67197 .49299 .67646 .49337 .68613 .48633 .68168 .48568 Metetra
0 .479 .124 r
.68168 .48568 .68613 .48633 .69581 .47927 .69139 .47837 Metetra
0 .462 .153 r
.69139 .47837 .69581 .47927 .7055 .47222 .70111 .47105 Metetra
0 .445 .18 r
.70111 .47105 .7055 .47222 .71521 .46515 .71084 .46373 Metetra
0 .429 .204 r
.71084 .46373 .71521 .46515 .72492 .45808 .72058 .4564 Metetra
0 .412 .226 r
.72058 .4564 .72492 .45808 .73464 .451 .73033 .44907 Metetra
0 .395 .245 r
.73033 .44907 .73464 .451 .74437 .44392 .74009 .44173 Metetra
0 .379 .262 r
.74009 .44173 .74437 .44392 .75411 .43683 .74986 .43438 Metetra
0 .362 .277 r
.74986 .43438 .75411 .43683 .76387 .42973 .75963 .42703 Metetra
0 .346 .289 r
.75963 .42703 .76387 .42973 .77363 .42262 .76942 .41967 Metetra
0 .329 .299 r
.76942 .41967 .77363 .42262 .7834 .4155 .77921 .4123 Metetra
0 .312 .306 r
.77921 .4123 .7834 .4155 .79319 .40838 .78902 .40492 Metetra
0 .28 .296 r
.78902 .40492 .79319 .40838 .80298 .40124 .79883 .39754 Metetra
0 .244 .279 r
.79883 .39754 .80298 .40124 .81279 .3941 .80865 .39014 Metetra
0 .211 .262 r
.80865 .39014 .81279 .3941 .8226 .38695 .81848 .38274 Metetra
0 .179 .246 r
.81848 .38274 .8226 .38695 .83243 .37979 .82832 .37533 Metetra
0 .151 .229 r
.82832 .37533 .83243 .37979 .84226 .37262 .83817 .36791 Metetra
0 .124 .212 r
.83817 .36791 .84226 .37262 .85211 .36544 .84802 .36049 Metetra
0 .1 .195 r
.84802 .36049 .85211 .36544 .86196 .35825 .85789 .35305 Metetra
0 .079 .179 r
.85789 .35305 .86196 .35825 .87183 .35105 .86776 .3456 Metetra
0 .06 .162 r
.86776 .3456 .87183 .35105 .88171 .34388 .87765 .33818 Metetra
0 .044 .146 r
.87765 .33818 .88171 .34388 .89161 .33684 .88757 .33091 Metetra
0 .031 .131 r
.88757 .33091 .89161 .33684 .90158 .33022 .89754 .32408 Metetra
0 .029 .129 r
.30288 .50874 .30828 .51375 .31653 .51389 .31113 .50901 Metetra
0 .041 .143 r
.31113 .50901 .31653 .51389 .32477 .51483 .31937 .51014 Metetra
0 .058 .16 r
.31937 .51014 .32477 .51483 .33304 .516 .32764 .5115 Metetra
0 .077 .178 r
.32764 .5115 .33304 .516 .34136 .51722 .33596 .51293 Metetra
0 .1 .195 r
.33596 .51293 .34136 .51722 .34972 .51846 .34432 .51437 Metetra
0 .125 .213 r
.34432 .51437 .34972 .51846 .35813 .5197 .35273 .51582 Metetra
0 .153 .23 r
.35273 .51582 .35813 .5197 .36659 .52095 .36119 .51727 Metetra
0 .184 .248 r
.36119 .51727 .36659 .52095 .3751 .5222 .3697 .51873 Metetra
0 .217 .266 r
.3697 .51873 .3751 .5222 .38365 .52346 .37826 .5202 Metetra
0 .253 .283 r
.37826 .5202 .38365 .52346 .39225 .52473 .38687 .52167 Metetra
0 .292 .301 r
.38687 .52167 .39225 .52473 .40091 .526 .39553 .52315 Metetra
0 .318 .304 r
.39553 .52315 .40091 .526 .40961 .52727 .40424 .52464 Metetra
0 .336 .295 r
.40424 .52464 .40961 .52727 .41836 .52856 .41301 .52613 Metetra
0 .353 .283 r
.41301 .52613 .41836 .52856 .42716 .52984 .42182 .52764 Metetra
0 .371 .269 r
.42182 .52764 .42716 .52984 .43601 .53114 .43069 .52915 Metetra
0 .388 .253 r
.43069 .52915 .43601 .53114 .44492 .53245 .43961 .53067 Metetra
0 .406 .233 r
.43961 .53067 .44492 .53245 .45387 .53376 .44858 .5322 Metetra
0 .424 .211 r
.44858 .5322 .45387 .53376 .46288 .53508 .4576 .53374 Metetra
0 .441 .186 r
.4576 .53374 .46288 .53508 .47194 .5364 .46668 .53529 Metetra
0 .459 .159 r
.46668 .53529 .47194 .5364 .48106 .53774 .47582 .53685 Metetra
0 .476 .129 r
.47582 .53685 .48106 .53774 .49022 .53908 .48501 .53842 Metetra
0 .494 .096 r
.48501 .53842 .49022 .53908 .49944 .54044 .49425 .54 Metetra
0 .511 .06 r
.49425 .54 .49944 .54044 .50872 .5418 .50355 .54159 Metetra
0 .529 .022 r
.50355 .54159 .50872 .5418 .51805 .54317 .51291 .5432 Metetra
.019 .546 0 r
.51291 .5432 .51805 .54317 .52743 .54456 .52233 .54481 Metetra
.062 .564 0 r
.52233 .54481 .52743 .54456 .53688 .54595 .5318 .54644 Metetra
.109 .582 0 r
.5318 .54644 .53688 .54595 .54637 .54735 .54133 .54808 Metetra
.158 .599 0 r
.54133 .54808 .54637 .54735 .55593 .54877 .55092 .54973 Metetra
.209 .617 0 r
.55092 .54973 .55593 .54877 .56554 .55018 .56057 .55138 Metetra
.263 .634 0 r
.56057 .55138 .56554 .55018 .57521 .55153 .57028 .55297 Metetra
.317 .651 0 r
.57028 .55297 .57521 .55153 .58493 .55254 .58004 .5542 Metetra
.35 .661 0 r
.58004 .5542 .58493 .55254 .59465 .55059 .5898 .55229 Metetra
.33 .655 0 r
.5898 .55229 .59465 .55059 .60429 .54386 .59948 .54532 Metetra
.277 .639 0 r
.59948 .54532 .60429 .54386 .61394 .53671 .60917 .53791 Metetra
.223 .621 0 r
.60917 .53791 .61394 .53671 .62359 .52944 .61886 .53038 Metetra
.17 .604 0 r
.61886 .53038 .62359 .52944 .63325 .52216 .62856 .52283 Metetra
.121 .586 0 r
.62856 .52283 .63325 .52216 .64291 .51487 .63827 .51528 Metetra
.074 .568 0 r
.63827 .51528 .64291 .51487 .65259 .50758 .64799 .50772 Metetra
.029 .551 0 r
.64799 .50772 .65259 .50758 .66228 .50029 .65771 .50016 Metetra
0 .533 .012 r
.65771 .50016 .66228 .50029 .67197 .49299 .66744 .4926 Metetra
0 .516 .051 r
.66744 .4926 .67197 .49299 .68168 .48568 .67718 .48503 Metetra
0 .498 .087 r
.67718 .48503 .68168 .48568 .69139 .47837 .68692 .47746 Metetra
0 .481 .121 r
.68692 .47746 .69139 .47837 .70111 .47105 .69668 .46988 Metetra
0 .463 .151 r
.69668 .46988 .70111 .47105 .71084 .46373 .70644 .4623 Metetra
0 .445 .18 r
.70644 .4623 .71084 .46373 .72058 .4564 .71621 .45471 Metetra
0 .428 .205 r
.71621 .45471 .72058 .4564 .73033 .44907 .72598 .44712 Metetra
0 .41 .228 r
.72598 .44712 .73033 .44907 .74009 .44173 .73577 .43952 Metetra
0 .393 .248 r
.73577 .43952 .74009 .44173 .74986 .43438 .74556 .43192 Metetra
0 .375 .265 r
.74556 .43192 .74986 .43438 .75963 .42703 .75536 .42431 Metetra
0 .358 .28 r
.75536 .42431 .75963 .42703 .76942 .41967 .76517 .41669 Metetra
0 .34 .292 r
.76517 .41669 .76942 .41967 .77921 .4123 .77499 .40907 Metetra
0 .323 .302 r
.77499 .40907 .77921 .4123 .78902 .40492 .78481 .40144 Metetra
0 .301 .305 r
.78481 .40144 .78902 .40492 .79883 .39754 .79464 .3938 Metetra
0 .262 .287 r
.79464 .3938 .79883 .39754 .80865 .39014 .80448 .38616 Metetra
0 .226 .27 r
.80448 .38616 .80865 .39014 .81848 .38274 .81433 .37851 Metetra
0 .192 .252 r
.81433 .37851 .81848 .38274 .82832 .37533 .82418 .37084 Metetra
0 .16 .235 r
.82418 .37084 .82832 .37533 .83817 .36791 .83404 .36317 Metetra
0 .132 .217 r
.83404 .36317 .83817 .36791 .84802 .36049 .84391 .3555 Metetra
0 .106 .2 r
.84391 .3555 .84802 .36049 .85789 .35305 .85379 .34781 Metetra
0 .083 .182 r
.85379 .34781 .85789 .35305 .86776 .3456 .86367 .34012 Metetra
0 .062 .164 r
.86367 .34012 .86776 .3456 .87765 .33818 .87357 .33245 Metetra
0 .045 .147 r
.87357 .33245 .87765 .33818 .88757 .33091 .88349 .32494 Metetra
0 .031 .131 r
.88349 .32494 .88757 .33091 .89754 .32408 .89348 .3179 Metetra
0 .029 .129 r
.29745 .50369 .30288 .50874 .31113 .50901 .3057 .50411 Metetra
0 .042 .144 r
.3057 .50411 .31113 .50901 .31937 .51014 .31394 .50542 Metetra
0 .06 .162 r
.31394 .50542 .31937 .51014 .32764 .5115 .32221 .50698 Metetra
0 .081 .181 r
.32221 .50698 .32764 .5115 .33596 .51293 .33052 .50861 Metetra
0 .105 .199 r
.33052 .50861 .33596 .51293 .34432 .51437 .33888 .51025 Metetra
0 .132 .218 r
.33888 .51025 .34432 .51437 .35273 .51582 .3473 .5119 Metetra
0 .163 .236 r
.3473 .5119 .35273 .51582 .36119 .51727 .35576 .51356 Metetra
0 .196 .254 r
.35576 .51356 .36119 .51727 .3697 .51873 .36427 .51523 Metetra
0 .232 .273 r
.36427 .51523 .3697 .51873 .37826 .5202 .37284 .51691 Metetra
0 .271 .291 r
.37284 .51691 .37826 .5202 .38687 .52167 .38145 .51859 Metetra
0 .31 .307 r
.38145 .51859 .38687 .52167 .39553 .52315 .39012 .52028 Metetra
0 .328 .299 r
.39012 .52028 .39553 .52315 .40424 .52464 .39884 .52199 Metetra
0 .347 .288 r
.39884 .52199 .40424 .52464 .41301 .52613 .40761 .5237 Metetra
0 .365 .274 r
.40761 .5237 .41301 .52613 .42182 .52764 .41644 .52542 Metetra
0 .384 .257 r
.41644 .52542 .42182 .52764 .43069 .52915 .42532 .52715 Metetra
0 .402 .238 r
.42532 .52715 .43069 .52915 .43961 .53067 .43425 .52889 Metetra
0 .421 .215 r
.43425 .52889 .43961 .53067 .44858 .5322 .44324 .53064 Metetra
0 .439 .189 r
.44324 .53064 .44858 .5322 .4576 .53374 .45228 .5324 Metetra
0 .458 .16 r
.45228 .5324 .4576 .53374 .46668 .53529 .46138 .53417 Metetra
0 .476 .129 r
.46138 .53417 .46668 .53529 .47582 .53685 .47054 .53596 Metetra
0 .494 .094 r
.47054 .53596 .47582 .53685 .48501 .53842 .47975 .53776 Metetra
0 .513 .057 r
.47975 .53776 .48501 .53842 .49425 .54 .48902 .53957 Metetra
0 .531 .016 r
.48902 .53957 .49425 .54 .50355 .54159 .49834 .54139 Metetra
.027 .55 0 r
.49834 .54139 .50355 .54159 .51291 .5432 .50773 .54322 Metetra
.073 .568 0 r
.50773 .54322 .51291 .5432 .52233 .54481 .51717 .54507 Metetra
.123 .587 0 r
.51717 .54507 .52233 .54481 .5318 .54644 .52667 .54694 Metetra
.175 .605 0 r
.52667 .54694 .5318 .54644 .54133 .54808 .53624 .54881 Metetra
.231 .624 0 r
.53624 .54881 .54133 .54808 .55092 .54973 .54586 .55071 Metetra
.289 .642 0 r
.54586 .55071 .55092 .54973 .56057 .55138 .55554 .5526 Metetra
.35 .661 0 r
.55554 .5526 .56057 .55138 .57028 .55297 .56529 .55443 Metetra
.41 .678 0 r
.56529 .55443 .57028 .55297 .58004 .5542 .57509 .55588 Metetra
.447 .688 0 r
.57509 .55588 .58004 .5542 .5898 .55229 .58489 .55401 Metetra
.425 .682 0 r
.58489 .55401 .5898 .55229 .59948 .54532 .59463 .5468 Metetra
.365 .665 0 r
.59463 .5468 .59948 .54532 .60917 .53791 .60436 .53913 Metetra
.304 .647 0 r
.60436 .53913 .60917 .53791 .61886 .53038 .61409 .53132 Metetra
.245 .628 0 r
.61409 .53132 .61886 .53038 .62856 .52283 .62383 .5235 Metetra
.189 .61 0 r
.62383 .5235 .62856 .52283 .63827 .51528 .63358 .51568 Metetra
.136 .591 0 r
.63358 .51568 .63827 .51528 .64799 .50772 .64333 .50786 Metetra
.085 .573 0 r
.64333 .50786 .64799 .50772 .65771 .50016 .6531 .50003 Metetra
.038 .554 0 r
.6531 .50003 .65771 .50016 .66744 .4926 .66286 .4922 Metetra
0 .536 .006 r
.66286 .4922 .66744 .4926 .67718 .48503 .67264 .48437 Metetra
0 .517 .047 r
.67264 .48437 .67718 .48503 .68692 .47746 .68242 .47654 Metetra
0 .499 .085 r
.68242 .47654 .68692 .47746 .69668 .46988 .6922 .4687 Metetra
0 .481 .121 r
.6922 .4687 .69668 .46988 .70644 .4623 .70199 .46085 Metetra
0 .462 .153 r
.70199 .46085 .70644 .4623 .71621 .45471 .71179 .45301 Metetra
0 .444 .182 r
.71179 .45301 .71621 .45471 .72598 .44712 .7216 .44515 Metetra
0 .425 .209 r
.7216 .44515 .72598 .44712 .73577 .43952 .73141 .4373 Metetra
0 .407 .232 r
.73141 .4373 .73577 .43952 .74556 .43192 .74123 .42943 Metetra
0 .388 .253 r
.74123 .42943 .74556 .43192 .75536 .42431 .75106 .42157 Metetra
0 .37 .27 r
.75106 .42157 .75536 .42431 .76517 .41669 .76089 .41369 Metetra
0 .351 .285 r
.76089 .41369 .76517 .41669 .77499 .40907 .77073 .40582 Metetra
0 .333 .297 r
.77073 .40582 .77499 .40907 .78481 .40144 .78057 .39793 Metetra
0 .314 .305 r
.78057 .39793 .78481 .40144 .79464 .3938 .79042 .39004 Metetra
0 .281 .296 r
.79042 .39004 .79464 .3938 .80448 .38616 .80028 .38214 Metetra
0 .241 .278 r
.80028 .38214 .80448 .38616 .81433 .37851 .81014 .37423 Metetra
0 .204 .259 r
.81014 .37423 .81433 .37851 .82418 .37084 .82001 .36632 Metetra
0 .171 .241 r
.82001 .36632 .82418 .37084 .83404 .36317 .82989 .3584 Metetra
0 .14 .222 r
.82989 .3584 .83404 .36317 .84391 .3555 .83977 .35047 Metetra
0 .112 .204 r
.83977 .35047 .84391 .3555 .85379 .34781 .84966 .34253 Metetra
0 .087 .185 r
.84966 .34253 .85379 .34781 .86367 .34012 .85955 .33459 Metetra
0 .065 .167 r
.85955 .33459 .86367 .34012 .87357 .33245 .86946 .32668 Metetra
0 .046 .149 r
.86946 .32668 .87357 .33245 .88349 .32494 .87939 .31893 Metetra
0 .031 .132 r
.87939 .31893 .88349 .32494 .89348 .3179 .88938 .31168 Metetra
0 .029 .129 r
.29199 .49862 .29745 .50369 .3057 .50411 .30024 .49917 Metetra
0 .043 .146 r
.30024 .49917 .3057 .50411 .31394 .50542 .30847 .50067 Metetra
0 .062 .164 r
.30847 .50067 .31394 .50542 .32221 .50698 .31674 .50243 Metetra
0 .085 .183 r
.31674 .50243 .32221 .50698 .33052 .50861 .32505 .50426 Metetra
0 .111 .203 r
.32505 .50426 .33052 .50861 .33888 .51025 .33341 .50611 Metetra
0 .14 .222 r
.33341 .50611 .33888 .51025 .3473 .5119 .34182 .50797 Metetra
0 .172 .242 r
.34182 .50797 .3473 .5119 .35576 .51356 .35029 .50983 Metetra
0 .208 .261 r
.35029 .50983 .35576 .51356 .36427 .51523 .35881 .51171 Metetra
0 .247 .28 r
.35881 .51171 .36427 .51523 .37284 .51691 .36737 .5136 Metetra
0 .289 .3 r
.36737 .5136 .37284 .51691 .38145 .51859 .37599 .51549 Metetra
0 .319 .303 r
.37599 .51549 .38145 .51859 .39012 .52028 .38467 .5174 Metetra
0 .339 .293 r
.38467 .5174 .39012 .52028 .39884 .52199 .3934 .51931 Metetra
0 .358 .28 r
.3934 .51931 .39884 .52199 .40761 .5237 .40218 .52124 Metetra
0 .377 .264 r
.40218 .52124 .40761 .5237 .41644 .52542 .41101 .52318 Metetra
0 .397 .244 r
.41101 .52318 .41644 .52542 .42532 .52715 .41991 .52512 Metetra
0 .416 .221 r
.41991 .52512 .42532 .52715 .43425 .52889 .42885 .52709 Metetra
0 .435 .195 r
.42885 .52709 .43425 .52889 .44324 .53064 .43786 .52906 Metetra
0 .455 .165 r
.43786 .52906 .44324 .53064 .45228 .5324 .44691 .53105 Metetra
0 .474 .132 r
.44691 .53105 .45228 .5324 .46138 .53417 .45603 .53304 Metetra
0 .493 .096 r
.45603 .53304 .46138 .53417 .47054 .53596 .46521 .53506 Metetra
0 .513 .057 r
.46521 .53506 .47054 .53596 .47975 .53776 .47444 .53708 Metetra
0 .532 .015 r
.47444 .53708 .47975 .53776 .48902 .53957 .48373 .53912 Metetra
.031 .551 0 r
.48373 .53912 .48902 .53957 .49834 .54139 .49308 .54118 Metetra
.08 .571 0 r
.49308 .54118 .49834 .54139 .50773 .54322 .50249 .54325 Metetra
.132 .59 0 r
.50249 .54325 .50773 .54322 .51717 .54507 .51196 .54534 Metetra
.188 .61 0 r
.51196 .54534 .51717 .54507 .52667 .54694 .5215 .54744 Metetra
.247 .629 0 r
.5215 .54744 .52667 .54694 .53624 .54881 .53109 .54956 Metetra
.309 .648 0 r
.53109 .54956 .53624 .54881 .54586 .55071 .54075 .55169 Metetra
.374 .668 0 r
.54075 .55169 .54586 .55071 .55554 .5526 .55047 .55383 Metetra
.442 .687 0 r
.55047 .55383 .55554 .5526 .56529 .55443 .56025 .5559 Metetra
.51 .705 0 r
.56025 .5559 .56529 .55443 .57509 .55588 .57009 .55757 Metetra
.551 .716 0 r
.57009 .55757 .57509 .55588 .58489 .55401 .57994 .55575 Metetra
.527 .71 0 r
.57994 .55575 .58489 .55401 .59463 .5468 .58971 .5483 Metetra
.46 .692 0 r
.58971 .5483 .59463 .5468 .60436 .53913 .59949 .54036 Metetra
.391 .673 0 r
.59949 .54036 .60436 .53913 .61409 .53132 .60927 .53228 Metetra
.325 .653 0 r
.60927 .53228 .61409 .53132 .62383 .5235 .61905 .52419 Metetra
.262 .634 0 r
.61905 .52419 .62383 .5235 .63358 .51568 .62884 .51609 Metetra
.202 .614 0 r
.62884 .51609 .63358 .51568 .64333 .50786 .63864 .508 Metetra
.146 .595 0 r
.63864 .508 .64333 .50786 .6531 .50003 .64844 .4999 Metetra
.093 .576 0 r
.64844 .4999 .6531 .50003 .66286 .4922 .65824 .49181 Metetra
.043 .556 0 r
.65824 .49181 .66286 .4922 .67264 .48437 .66805 .48371 Metetra
0 .537 .004 r
.66805 .48371 .67264 .48437 .68242 .47654 .67786 .47561 Metetra
0 .517 .047 r
.67786 .47561 .68242 .47654 .6922 .4687 .68768 .4675 Metetra
0 .498 .087 r
.68768 .4675 .6922 .4687 .70199 .46085 .69751 .45939 Metetra
0 .479 .124 r
.69751 .45939 .70199 .46085 .71179 .45301 .70734 .45128 Metetra
0 .459 .157 r
.70734 .45128 .71179 .45301 .7216 .44515 .71718 .44317 Metetra
0 .44 .188 r
.71718 .44317 .7216 .44515 .73141 .4373 .72702 .43505 Metetra
0 .421 .215 r
.72702 .43505 .73141 .4373 .74123 .42943 .73686 .42693 Metetra
0 .401 .238 r
.73686 .42693 .74123 .42943 .75106 .42157 .74671 .4188 Metetra
0 .382 .259 r
.74671 .4188 .75106 .42157 .76089 .41369 .75657 .41067 Metetra
0 .363 .276 r
.75657 .41067 .76089 .41369 .77073 .40582 .76643 .40253 Metetra
0 .343 .29 r
.76643 .40253 .77073 .40582 .78057 .39793 .7763 .39439 Metetra
0 .324 .301 r
.7763 .39439 .78057 .39793 .79042 .39004 .78617 .38624 Metetra
0 .3 .305 r
.78617 .38624 .79042 .39004 .80028 .38214 .79604 .37809 Metetra
0 .257 .285 r
.79604 .37809 .80028 .38214 .81014 .37423 .80592 .36993 Metetra
0 .218 .266 r
.80592 .36993 .81014 .37423 .82001 .36632 .81581 .36176 Metetra
0 .181 .246 r
.81581 .36176 .82001 .36632 .82989 .3584 .8257 .35359 Metetra
0 .148 .227 r
.8257 .35359 .82989 .3584 .83977 .35047 .8356 .34541 Metetra
0 .117 .208 r
.8356 .34541 .83977 .35047 .84966 .34253 .8455 .33722 Metetra
0 .091 .188 r
.8455 .33722 .84966 .34253 .85955 .33459 .8554 .32903 Metetra
0 .067 .169 r
.8554 .32903 .85955 .33459 .86946 .32668 .86532 .32087 Metetra
0 .047 .15 r
.86532 .32087 .86946 .32668 .87939 .31893 .87526 .31288 Metetra
0 .032 .132 r
.87526 .31288 .87939 .31893 .88938 .31168 .88526 .30542 Metetra
0 .03 .13 r
.28649 .49351 .29199 .49862 .30024 .49917 .29474 .49421 Metetra
0 .044 .147 r
.29474 .49421 .30024 .49917 .30847 .50067 .30297 .49589 Metetra
0 .064 .166 r
.30297 .49589 .30847 .50067 .31674 .50243 .31123 .49785 Metetra
0 .088 .186 r
.31123 .49785 .31674 .50243 .32505 .50426 .31954 .49988 Metetra
0 .116 .207 r
.31954 .49988 .32505 .50426 .33341 .50611 .3279 .50194 Metetra
0 .147 .227 r
.3279 .50194 .33341 .50611 .34182 .50797 .33632 .504 Metetra
0 .182 .247 r
.33632 .504 .34182 .50797 .35029 .50983 .34478 .50608 Metetra
0 .221 .268 r
.34478 .50608 .35029 .50983 .35881 .51171 .3533 .50816 Metetra
0 .263 .288 r
.3533 .50816 .35881 .51171 .36737 .5136 .36187 .51026 Metetra
0 .308 .308 r
.36187 .51026 .36737 .5136 .37599 .51549 .37049 .51237 Metetra
0 .328 .299 r
.37049 .51237 .37599 .51549 .38467 .5174 .37917 .51449 Metetra
0 .349 .287 r
.37917 .51449 .38467 .5174 .3934 .51931 .38791 .51662 Metetra
0 .369 .271 r
.38791 .51662 .3934 .51931 .40218 .52124 .3967 .51876 Metetra
0 .389 .252 r
.3967 .51876 .40218 .52124 .41101 .52318 .40554 .52092 Metetra
0 .409 .229 r
.40554 .52092 .41101 .52318 .41991 .52512 .41445 .52309 Metetra
0 .43 .203 r
.41445 .52309 .41991 .52512 .42885 .52709 .42341 .52527 Metetra
0 .45 .173 r
.42341 .52527 .42885 .52709 .43786 .52906 .43242 .52747 Metetra
0 .47 .139 r
.43242 .52747 .43786 .52906 .44691 .53105 .4415 .52968 Metetra
0 .49 .102 r
.4415 .52968 .44691 .53105 .45603 .53304 .45063 .53191 Metetra
0 .511 .061 r
.45063 .53191 .45603 .53304 .46521 .53506 .45983 .53415 Metetra
0 .531 .017 r
.45983 .53415 .46521 .53506 .47444 .53708 .46908 .5364 Metetra
.03 .551 0 r
.46908 .5364 .47444 .53708 .48373 .53912 .4784 .53868 Metetra
.082 .571 0 r
.4784 .53868 .48373 .53912 .49308 .54118 .48777 .54097 Metetra
.137 .592 0 r
.48777 .54097 .49308 .54118 .50249 .54325 .49721 .54328 Metetra
.195 .612 0 r
.49721 .54328 .50249 .54325 .51196 .54534 .50671 .5456 Metetra
.257 .632 0 r
.50671 .5456 .51196 .54534 .5215 .54744 .51627 .54795 Metetra
.323 .653 0 r
.51627 .54795 .5215 .54744 .53109 .54956 .52589 .55031 Metetra
.392 .673 0 r
.52589 .55031 .53109 .54956 .54075 .55169 .53558 .55269 Metetra
.465 .693 0 r
.53558 .55269 .54075 .55169 .55047 .55383 .54534 .55507 Metetra
.541 .713 0 r
.54534 .55507 .55047 .55383 .56025 .5559 .55516 .55739 Metetra
.616 .733 0 r
.55516 .55739 .56025 .5559 .57009 .55757 .56504 .55929 Metetra
.662 .744 0 r
.56504 .55929 .57009 .55757 .57994 .55575 .57492 .55751 Metetra
.635 .737 0 r
.57492 .55751 .57994 .55575 .58971 .5483 .58475 .54981 Metetra
.56 .718 0 r
.58475 .54981 .58971 .5483 .59949 .54036 .59457 .5416 Metetra
.484 .698 0 r
.59457 .5416 .59949 .54036 .60927 .53228 .6044 .53325 Metetra
.41 .678 0 r
.6044 .53325 .60927 .53228 .61905 .52419 .61422 .52488 Metetra
.34 .658 0 r
.61422 .52488 .61905 .52419 .62884 .51609 .62406 .51651 Metetra
.273 .637 0 r
.62406 .51651 .62884 .51609 .63864 .508 .63389 .50814 Metetra
.21 .617 0 r
.63389 .50814 .63864 .508 .64844 .4999 .64373 .49977 Metetra
.151 .597 0 r
.64373 .49977 .64844 .4999 .65824 .49181 .65357 .49141 Metetra
.095 .577 0 r
.65357 .49141 .65824 .49181 .66805 .48371 .66342 .48304 Metetra
.043 .556 0 r
.66342 .48304 .66805 .48371 .67786 .47561 .67327 .47467 Metetra
0 .536 .006 r
.67327 .47467 .67786 .47561 .68768 .4675 .68313 .4663 Metetra
0 .516 .051 r
.68313 .4663 .68768 .4675 .69751 .45939 .69298 .45792 Metetra
0 .495 .092 r
.69298 .45792 .69751 .45939 .70734 .45128 .70285 .44955 Metetra
0 .475 .13 r
.70285 .44955 .70734 .45128 .71718 .44317 .71271 .44117 Metetra
0 .455 .165 r
.71271 .44117 .71718 .44317 .72702 .43505 .72258 .43279 Metetra
0 .435 .195 r
.72258 .43279 .72702 .43505 .73686 .42693 .73245 .4244 Metetra
0 .414 .223 r
.73245 .4244 .73686 .42693 .74671 .4188 .74233 .41601 Metetra
0 .394 .246 r
.74233 .41601 .74671 .4188 .75657 .41067 .75221 .40762 Metetra
0 .374 .267 r
.75221 .40762 .75657 .41067 .76643 .40253 .7621 .39922 Metetra
0 .354 .283 r
.7621 .39922 .76643 .40253 .7763 .39439 .77199 .39082 Metetra
0 .333 .296 r
.77199 .39082 .7763 .39439 .78617 .38624 .78188 .38242 Metetra
0 .313 .306 r
.78188 .38242 .78617 .38624 .79604 .37809 .79178 .37401 Metetra
0 .274 .293 r
.79178 .37401 .79604 .37809 .80592 .36993 .80167 .36559 Metetra
0 .231 .273 r
.80167 .36559 .80592 .36993 .81581 .36176 .81158 .35717 Metetra
0 .192 .252 r
.81158 .35717 .81581 .36176 .8257 .35359 .82148 .34875 Metetra
0 .156 .232 r
.82148 .34875 .8257 .35359 .8356 .34541 .83139 .34031 Metetra
0 .123 .212 r
.83139 .34031 .8356 .34541 .8455 .33722 .84131 .33187 Metetra
0 .095 .191 r
.84131 .33187 .8455 .33722 .8554 .32903 .85123 .32343 Metetra
0 .07 .171 r
.85123 .32343 .8554 .32903 .86532 .32087 .86115 .31502 Metetra
0 .049 .151 r
.86115 .31502 .86532 .32087 .87526 .31288 .8711 .30679 Metetra
0 .032 .133 r
.8711 .30679 .87526 .31288 .88526 .30542 .88112 .29911 Metetra
0 .03 .13 r
.28096 .48838 .28649 .49351 .29474 .49421 .28921 .48921 Metetra
0 .045 .148 r
.28921 .48921 .29474 .49421 .30297 .49589 .29744 .49108 Metetra
0 .066 .168 r
.29744 .49108 .30297 .49589 .31123 .49785 .3057 .49324 Metetra
0 .092 .189 r
.3057 .49324 .31123 .49785 .31954 .49988 .314 .49548 Metetra
0 .122 .21 r
.314 .49548 .31954 .49988 .3279 .50194 .32236 .49774 Metetra
0 .155 .232 r
.32236 .49774 .3279 .50194 .33632 .504 .33077 .50001 Metetra
0 .193 .253 r
.33077 .50001 .33632 .504 .34478 .50608 .33923 .5023 Metetra
0 .234 .274 r
.33923 .5023 .34478 .50608 .3533 .50816 .34775 .50459 Metetra
0 .279 .295 r
.34775 .50459 .3533 .50816 .36187 .51026 .35632 .5069 Metetra
0 .316 .304 r
.35632 .5069 .36187 .51026 .37049 .51237 .36495 .50922 Metetra
0 .338 .294 r
.36495 .50922 .37049 .51237 .37917 .51449 .37364 .51156 Metetra
0 .359 .279 r
.37364 .51156 .37917 .51449 .38791 .51662 .38238 .5139 Metetra
0 .38 .261 r
.38238 .5139 .38791 .51662 .3967 .51876 .39118 .51627 Metetra
0 .401 .239 r
.39118 .51627 .3967 .51876 .40554 .52092 .40003 .51864 Metetra
0 .422 .213 r
.40003 .51864 .40554 .52092 .41445 .52309 .40895 .52103 Metetra
0 .443 .183 r
.40895 .52103 .41445 .52309 .42341 .52527 .41792 .52344 Metetra
0 .465 .149 r
.41792 .52344 .42341 .52527 .43242 .52747 .42695 .52586 Metetra
0 .486 .111 r
.42695 .52586 .43242 .52747 .4415 .52968 .43604 .5283 Metetra
0 .507 .069 r
.43604 .5283 .4415 .52968 .45063 .53191 .44519 .53076 Metetra
0 .528 .024 r
.44519 .53076 .45063 .53191 .45983 .53415 .4544 .53323 Metetra
.026 .549 0 r
.4544 .53323 .45983 .53415 .46908 .5364 .46367 .53572 Metetra
.079 .57 0 r
.46367 .53572 .46908 .5364 .4784 .53868 .47301 .53823 Metetra
.136 .592 0 r
.47301 .53823 .4784 .53868 .48777 .54097 .48241 .54076 Metetra
.197 .613 0 r
.48241 .54076 .48777 .54097 .49721 .54328 .49187 .54331 Metetra
.262 .634 0 r
.49187 .54331 .49721 .54328 .50671 .5456 .5014 .54587 Metetra
.331 .655 0 r
.5014 .54587 .50671 .5456 .51627 .54795 .51099 .54846 Metetra
.404 .676 0 r
.51099 .54846 .51627 .54795 .52589 .55031 .52064 .55107 Metetra
.481 .698 0 r
.52064 .55107 .52589 .55031 .53558 .55269 .53036 .55369 Metetra
.562 .719 0 r
.53036 .55369 .53558 .55269 .54534 .55507 .54015 .55633 Metetra
.645 .74 0 r
.54015 .55633 .54534 .55507 .55516 .55739 .55001 .55889 Metetra
.729 .76 0 r
.55001 .55889 .55516 .55739 .56504 .55929 .55993 .56102 Metetra
.772 .763 0 r
.55993 .56102 .56504 .55929 .57492 .55751 .56986 .55929 Metetra
.75 .765 0 r
.56986 .55929 .57492 .55751 .58475 .54981 .57973 .55134 Metetra
.667 .745 0 r
.57973 .55134 .58475 .54981 .59457 .5416 .5896 .54285 Metetra
.583 .724 0 r
.5896 .54285 .59457 .5416 .6044 .53325 .59947 .53422 Metetra
.501 .703 0 r
.59947 .53422 .6044 .53325 .61422 .52488 .60935 .52558 Metetra
.423 .682 0 r
.60935 .52558 .61422 .52488 .62406 .51651 .61922 .51693 Metetra
.349 .66 0 r
.61922 .51693 .62406 .51651 .63389 .50814 .6291 .50829 Metetra
.279 .639 0 r
.6291 .50829 .63389 .50814 .64373 .49977 .63898 .49965 Metetra
.213 .618 0 r
.63898 .49965 .64373 .49977 .65357 .49141 .64886 .491 Metetra
.151 .597 0 r
.64886 .491 .65357 .49141 .66342 .48304 .65875 .48236 Metetra
.093 .576 0 r
.65875 .48236 .66342 .48304 .67327 .47467 .66863 .47372 Metetra
.038 .554 0 r
.66863 .47372 .67327 .47467 .68313 .4663 .67852 .46508 Metetra
0 .533 .012 r
.67852 .46508 .68313 .4663 .69298 .45792 .68842 .45644 Metetra
0 .512 .058 r
.68842 .45644 .69298 .45792 .70285 .44955 .69831 .44779 Metetra
0 .491 .101 r
.69831 .44779 .70285 .44955 .71271 .44117 .70821 .43915 Metetra
0 .47 .14 r
.70821 .43915 .71271 .44117 .72258 .43279 .71811 .4305 Metetra
0 .449 .175 r
.71811 .4305 .72258 .43279 .73245 .4244 .72801 .42185 Metetra
0 .427 .206 r
.72801 .42185 .73245 .4244 .74233 .41601 .73791 .4132 Metetra
0 .406 .233 r
.73791 .4132 .74233 .41601 .75221 .40762 .74782 .40455 Metetra
0 .385 .256 r
.74782 .40455 .75221 .40762 .7621 .39922 .75773 .39589 Metetra
0 .364 .275 r
.75773 .39589 .7621 .39922 .77199 .39082 .76764 .38723 Metetra
0 .343 .291 r
.76764 .38723 .77199 .39082 .78188 .38242 .77756 .37856 Metetra
0 .322 .302 r
.77756 .37856 .78188 .38242 .79178 .37401 .78747 .3699 Metetra
0 .291 .3 r
.78747 .3699 .79178 .37401 .80167 .36559 .79739 .36122 Metetra
0 .245 .279 r
.79739 .36122 .80167 .36559 .81158 .35717 .80731 .35255 Metetra
0 .203 .258 r
.80731 .35255 .81158 .35717 .82148 .34875 .81724 .34386 Metetra
0 .164 .237 r
.81724 .34386 .82148 .34875 .83139 .34031 .82716 .33518 Metetra
0 .13 .216 r
.82716 .33518 .83139 .34031 .84131 .33187 .83709 .32648 Metetra
0 .099 .194 r
.83709 .32648 .84131 .33187 .85123 .32343 .84702 .31779 Metetra
0 .072 .173 r
.84702 .31779 .85123 .32343 .86115 .31502 .85695 .30913 Metetra
0 .05 .153 r
.85695 .30913 .86115 .31502 .8711 .30679 .86691 .30066 Metetra
0 .033 .133 r
.86691 .30066 .8711 .30679 .88112 .29911 .87694 .29277 Metetra
0 .03 .131 r
.2754 .48321 .28096 .48838 .28921 .48921 .28365 .48419 Metetra
0 .046 .149 r
.28365 .48419 .28921 .48921 .29744 .49108 .29187 .48624 Metetra
0 .069 .17 r
.29187 .48624 .29744 .49108 .3057 .49324 .30012 .4886 Metetra
0 .096 .192 r
.30012 .4886 .3057 .49324 .314 .49548 .30842 .49105 Metetra
0 .127 .214 r
.30842 .49105 .314 .49548 .32236 .49774 .31678 .49351 Metetra
0 .163 .236 r
.31678 .49351 .32236 .49774 .33077 .50001 .32518 .49599 Metetra
0 .203 .258 r
.32518 .49599 .33077 .50001 .33923 .5023 .33365 .49849 Metetra
0 .248 .281 r
.33365 .49849 .33923 .5023 .34775 .50459 .34216 .50099 Metetra
0 .296 .303 r
.34216 .50099 .34775 .50459 .35632 .5069 .35074 .50352 Metetra
0 .325 .301 r
.35074 .50352 .35632 .5069 .36495 .50922 .35937 .50605 Metetra
0 .347 .288 r
.35937 .50605 .36495 .50922 .37364 .51156 .36806 .5086 Metetra
0 .369 .271 r
.36806 .5086 .37364 .51156 .38238 .5139 .37681 .51117 Metetra
0 .391 .25 r
.37681 .51117 .38238 .5139 .39118 .51627 .38561 .51375 Metetra
0 .413 .224 r
.38561 .51375 .39118 .51627 .40003 .51864 .39447 .51635 Metetra
0 .435 .195 r
.39447 .51635 .40003 .51864 .40895 .52103 .4034 .51896 Metetra
0 .457 .161 r
.4034 .51896 .40895 .52103 .41792 .52344 .41238 .5216 Metetra
0 .479 .123 r
.41238 .5216 .41792 .52344 .42695 .52586 .42142 .52424 Metetra
0 .501 .081 r
.42142 .52424 .42695 .52586 .43604 .5283 .43053 .52691 Metetra
0 .523 .034 r
.43053 .52691 .43604 .5283 .44519 .53076 .4397 .5296 Metetra
.016 .545 0 r
.4397 .5296 .44519 .53076 .4544 .53323 .44893 .53231 Metetra
.071 .567 0 r
.44893 .53231 .4544 .53323 .46367 .53572 .45822 .53503 Metetra
.131 .59 0 r
.45822 .53503 .46367 .53572 .47301 .53823 .46758 .53778 Metetra
.194 .612 0 r
.46758 .53778 .47301 .53823 .48241 .54076 .477 .54055 Metetra
.262 .634 0 r
.477 .54055 .48241 .54076 .49187 .54331 .48648 .54333 Metetra
.334 .656 0 r
.48648 .54333 .49187 .54331 .5014 .54587 .49603 .54615 Metetra
.41 .678 0 r
.49603 .54615 .5014 .54587 .51099 .54846 .50565 .54898 Metetra
.49 .7 0 r
.50565 .54898 .51099 .54846 .52064 .55107 .51534 .55183 Metetra
.575 .722 0 r
.51534 .55183 .52064 .55107 .53036 .55369 .52509 .55471 Metetra
.664 .744 0 r
.52509 .55471 .53036 .55369 .54015 .55633 .53491 .5576 Metetra
.756 .766 0 r
.53491 .5576 .54015 .55633 .55001 .55889 .5448 .56041 Metetra
.787 .726 0 r
.5448 .56041 .55001 .55889 .55993 .56102 .55476 .56277 Metetra
.799 .695 0 r
.55476 .56277 .55993 .56102 .56986 .55929 .56474 .56109 Metetra
.792 .713 0 r
.56474 .56109 .56986 .55929 .57973 .55134 .57466 .55289 Metetra
.772 .763 0 r
.57466 .55289 .57973 .55134 .5896 .54285 .58458 .54413 Metetra
.687 .75 0 r
.58458 .54413 .5896 .54285 .59947 .53422 .5945 .53521 Metetra
.597 .728 0 r
.5945 .53521 .59947 .53422 .60935 .52558 .60442 .52629 Metetra
.511 .706 0 r
.60442 .52629 .60935 .52558 .61922 .51693 .61434 .51736 Metetra
.429 .683 0 r
.61434 .51736 .61922 .51693 .6291 .50829 .62426 .50844 Metetra
.352 .661 0 r
.62426 .50844 .6291 .50829 .63898 .49965 .63418 .49952 Metetra
.279 .639 0 r
.63418 .49952 .63898 .49965 .64886 .491 .6441 .4906 Metetra
.21 .617 0 r
.6441 .4906 .64886 .491 .65875 .48236 .65403 .48168 Metetra
.146 .595 0 r
.65403 .48168 .65875 .48236 .66863 .47372 .66395 .47277 Metetra
.086 .573 0 r
.66395 .47277 .66863 .47372 .67852 .46508 .67388 .46385 Metetra
.03 .551 0 r
.67388 .46385 .67852 .46508 .68842 .45644 .6838 .45494 Metetra
0 .529 .022 r
.6838 .45494 .68842 .45644 .69831 .44779 .69373 .44602 Metetra
0 .507 .07 r
.69373 .44602 .69831 .44779 .70821 .43915 .70366 .43711 Metetra
0 .485 .113 r
.70366 .43711 .70821 .43915 .71811 .4305 .71359 .4282 Metetra
0 .463 .152 r
.71359 .4282 .71811 .4305 .72801 .42185 .72353 .41928 Metetra
0 .441 .187 r
.72353 .41928 .72801 .42185 .73791 .4132 .73346 .41036 Metetra
0 .419 .218 r
.73346 .41036 .73791 .4132 .74782 .40455 .74339 .40145 Metetra
0 .396 .244 r
.74339 .40145 .74782 .40455 .75773 .39589 .75333 .39253 Metetra
0 .374 .266 r
.75333 .39253 .75773 .39589 .76764 .38723 .76326 .3836 Metetra
0 .352 .284 r
.76326 .3836 .76764 .38723 .77756 .37856 .7732 .37468 Metetra
0 .33 .298 r
.7732 .37468 .77756 .37856 .78747 .3699 .78314 .36575 Metetra
0 .308 .308 r
.78314 .36575 .78747 .3699 .79739 .36122 .79308 .35682 Metetra
0 .259 .286 r
.79308 .35682 .79739 .36122 .80731 .35255 .80302 .34789 Metetra
0 .214 .264 r
.80302 .34789 .80731 .35255 .81724 .34386 .81296 .33895 Metetra
0 .173 .242 r
.81296 .33895 .81724 .34386 .82716 .33518 .8229 .33 Metetra
0 .136 .22 r
.8229 .33 .82716 .33518 .83709 .32648 .83284 .32106 Metetra
0 .103 .197 r
.83284 .32106 .83709 .32648 .84702 .31779 .84278 .31211 Metetra
0 .075 .175 r
.84278 .31211 .84702 .31779 .85695 .30913 .85273 .3032 Metetra
0 .051 .154 r
.85273 .3032 .85695 .30913 .86691 .30066 .8627 .29449 Metetra
0 .033 .134 r
.8627 .29449 .86691 .30066 .87694 .29277 .87274 .28638 Metetra
0 .031 .131 r
.26981 .47802 .2754 .48321 .28365 .48419 .27806 .47913 Metetra
0 .048 .15 r
.27806 .47913 .28365 .48419 .29187 .48624 .28627 .48137 Metetra
0 .071 .172 r
.28627 .48137 .29187 .48624 .30012 .4886 .29451 .48394 Metetra
0 .1 .195 r
.29451 .48394 .30012 .4886 .30842 .49105 .30281 .48659 Metetra
0 .133 .218 r
.30281 .48659 .30842 .49105 .31678 .49351 .31116 .48926 Metetra
0 .171 .241 r
.31116 .48926 .31678 .49351 .32518 .49599 .31956 .49195 Metetra
0 .214 .264 r
.31956 .49195 .32518 .49599 .33365 .49849 .32802 .49465 Metetra
0 .261 .287 r
.32802 .49465 .33365 .49849 .34216 .50099 .33654 .49737 Metetra
0 .31 .307 r
.33654 .49737 .34216 .50099 .35074 .50352 .34511 .50011 Metetra
0 .333 .296 r
.34511 .50011 .35074 .50352 .35937 .50605 .35375 .50286 Metetra
0 .356 .281 r
.35375 .50286 .35937 .50605 .36806 .5086 .36244 .50563 Metetra
0 .379 .262 r
.36244 .50563 .36806 .5086 .37681 .51117 .37119 .50841 Metetra
0 .402 .238 r
.37119 .50841 .37681 .51117 .38561 .51375 .38 .51122 Metetra
0 .425 .209 r
.38 .51122 .38561 .51375 .39447 .51635 .38887 .51404 Metetra
0 .448 .176 r
.38887 .51404 .39447 .51635 .4034 .51896 .3978 .51688 Metetra
0 .471 .138 r
.3978 .51688 .4034 .51896 .41238 .5216 .4068 .51974 Metetra
0 .494 .095 r
.4068 .51974 .41238 .5216 .42142 .52424 .41585 .52261 Metetra
0 .517 .048 r
.41585 .52261 .42142 .52424 .43053 .52691 .42497 .52551 Metetra
.003 .54 0 r
.42497 .52551 .43053 .52691 .4397 .5296 .43415 .52843 Metetra
.059 .563 0 r
.43415 .52843 .4397 .5296 .44893 .53231 .4434 .53137 Metetra
.12 .586 0 r
.4434 .53137 .44893 .53231 .45822 .53503 .45271 .53434 Metetra
.185 .609 0 r
.45271 .53434 .45822 .53503 .46758 .53778 .46209 .53732 Metetra
.255 .632 0 r
.46209 .53732 .46758 .53778 .477 .54055 .47153 .54033 Metetra
.33 .655 0 r
.47153 .54033 .477 .54055 .48648 .54333 .48104 .54336 Metetra
.409 .678 0 r
.48104 .54336 .48648 .54333 .49603 .54615 .49062 .54642 Metetra
.493 .701 0 r
.49062 .54642 .49603 .54615 .50565 .54898 .50026 .5495 Metetra
.581 .724 0 r
.50026 .5495 .50565 .54898 .51534 .55183 .50998 .55261 Metetra
.674 .747 0 r
.50998 .55261 .51534 .55183 .52509 .55471 .51976 .55574 Metetra
.77 .768 0 r
.51976 .55574 .52509 .55471 .53491 .5576 .52962 .55889 Metetra
.793 .712 0 r
.52962 .55889 .53491 .5576 .5448 .56041 .53954 .56195 Metetra
.814 .655 0 r
.53954 .56195 .5448 .56041 .55476 .56277 .54954 .56455 Metetra
.827 .619 0 r
.54954 .56455 .55476 .56277 .56474 .56109 .55956 .56291 Metetra
.82 .641 0 r
.55956 .56291 .56474 .56109 .57466 .55289 .56953 .55446 Metetra
.798 .698 0 r
.56953 .55446 .57466 .55289 .58458 .54413 .5795 .54541 Metetra
.776 .754 0 r
.5795 .54541 .58458 .54413 .5945 .53521 .58947 .53621 Metetra
.698 .753 0 r
.58947 .53621 .5945 .53521 .60442 .52629 .59943 .527 Metetra
.604 .73 0 r
.59943 .527 .60442 .52629 .61434 .51736 .6094 .51779 Metetra
.514 .706 0 r
.6094 .51779 .61434 .51736 .62426 .50844 .61937 .50859 Metetra
.429 .683 0 r
.61937 .50859 .62426 .50844 .63418 .49952 .62933 .49939 Metetra
.349 .66 0 r
.62933 .49939 .63418 .49952 .6441 .4906 .63929 .49019 Metetra
.273 .637 0 r
.63929 .49019 .6441 .4906 .65403 .48168 .64926 .48099 Metetra
.202 .614 0 r
.64926 .48099 .65403 .48168 .66395 .47277 .65922 .4718 Metetra
.136 .591 0 r
.65922 .4718 .66395 .47277 .67388 .46385 .66919 .46261 Metetra
.074 .568 0 r
.66919 .46261 .67388 .46385 .6838 .45494 .67915 .45343 Metetra
.017 .546 0 r
.67915 .45343 .6838 .45494 .69373 .44602 .68911 .44424 Metetra
0 .523 .036 r
.68911 .44424 .69373 .44602 .70366 .43711 .69908 .43506 Metetra
0 .5 .084 r
.69908 .43506 .70366 .43711 .71359 .4282 .70904 .42587 Metetra
0 .477 .128 r
.70904 .42587 .71359 .4282 .72353 .41928 .719 .41669 Metetra
0 .454 .167 r
.719 .41669 .72353 .41928 .73346 .41036 .72896 .4075 Metetra
0 .431 .201 r
.72896 .4075 .73346 .41036 .74339 .40145 .73893 .39832 Metetra
0 .408 .231 r
.73893 .39832 .74339 .40145 .75333 .39253 .74889 .38914 Metetra
0 .385 .256 r
.74889 .38914 .75333 .39253 .76326 .3836 .75885 .37995 Metetra
0 .362 .277 r
.75885 .37995 .76326 .3836 .7732 .37468 .76881 .37076 Metetra
0 .339 .293 r
.76881 .37076 .7732 .37468 .78314 .36575 .77877 .36157 Metetra
0 .316 .305 r
.77877 .36157 .78314 .36575 .79308 .35682 .78873 .35238 Metetra
0 .274 .293 r
.78873 .35238 .79308 .35682 .80302 .34789 .79869 .34319 Metetra
0 .225 .27 r
.79869 .34319 .80302 .34789 .81296 .33895 .80864 .33399 Metetra
0 .182 .247 r
.80864 .33399 .81296 .33895 .8229 .33 .8186 .32479 Metetra
0 .142 .224 r
.8186 .32479 .8229 .33 .83284 .32106 .82856 .31559 Metetra
0 .108 .201 r
.82856 .31559 .83284 .32106 .84278 .31211 .83851 .30639 Metetra
0 .078 .178 r
.83851 .30639 .84278 .31211 .85273 .3032 .84847 .29723 Metetra
0 .053 .155 r
.84847 .29723 .85273 .3032 .8627 .29449 .85846 .28828 Metetra
0 .033 .134 r
.85846 .28828 .8627 .29449 .87274 .28638 .86851 .27995 Metetra
0 .031 .131 r
.26418 .47279 .26981 .47802 .27806 .47913 .27242 .47405 Metetra
0 .049 .151 r
.27242 .47405 .27806 .47913 .28627 .48137 .28063 .47648 Metetra
0 .073 .174 r
.28063 .47648 .28627 .48137 .29451 .48394 .28887 .47924 Metetra
0 .104 .198 r
.28887 .47924 .29451 .48394 .30281 .48659 .29715 .48209 Metetra
0 .139 .222 r
.29715 .48209 .30281 .48659 .31116 .48926 .3055 .48498 Metetra
0 .18 .246 r
.3055 .48498 .31116 .48926 .31956 .49195 .3139 .48788 Metetra
0 .225 .27 r
.3139 .48788 .31956 .49195 .32802 .49465 .32236 .49079 Metetra
0 .276 .294 r
.32236 .49079 .32802 .49465 .33654 .49737 .33087 .49372 Metetra
0 .318 .304 r
.33087 .49372 .33654 .49737 .34511 .50011 .33945 .49668 Metetra
0 .341 .292 r
.33945 .49668 .34511 .50011 .35375 .50286 .34808 .49964 Metetra
0 .365 .274 r
.34808 .49964 .35375 .50286 .36244 .50563 .35678 .50263 Metetra
0 .389 .252 r
.35678 .50263 .36244 .50563 .37119 .50841 .36553 .50564 Metetra
0 .413 .224 r
.36553 .50564 .37119 .50841 .38 .51122 .37435 .50866 Metetra
0 .437 .192 r
.37435 .50866 .38 .51122 .38887 .51404 .38322 .51171 Metetra
0 .461 .155 r
.38322 .51171 .38887 .51404 .3978 .51688 .39216 .51477 Metetra
0 .485 .113 r
.39216 .51477 .3978 .51688 .4068 .51974 .40117 .51786 Metetra
0 .509 .066 r
.40117 .51786 .4068 .51974 .41585 .52261 .41023 .52097 Metetra
0 .532 .014 r
.41023 .52097 .41585 .52261 .42497 .52551 .41937 .5241 Metetra
.043 .556 0 r
.41937 .5241 .42497 .52551 .43415 .52843 .42856 .52726 Metetra
.105 .58 0 r
.42856 .52726 .43415 .52843 .4434 .53137 .43783 .53043 Metetra
.172 .604 0 r
.43783 .53043 .4434 .53137 .45271 .53434 .44715 .53364 Metetra
.243 .628 0 r
.44715 .53364 .45271 .53434 .46209 .53732 .45655 .53686 Metetra
.32 .652 0 r
.45655 .53686 .46209 .53732 .47153 .54033 .46601 .54012 Metetra
.402 .676 0 r
.46601 .54012 .47153 .54033 .48104 .54336 .47555 .5434 Metetra
.489 .7 0 r
.47555 .5434 .48104 .54336 .49062 .54642 .48515 .5467 Metetra
.58 .724 0 r
.48515 .5467 .49062 .54642 .50026 .5495 .49482 .55004 Metetra
.677 .747 0 r
.49482 .55004 .50026 .5495 .50998 .55261 .50456 .5534 Metetra
.771 .764 0 r
.50456 .5534 .50998 .55261 .51976 .55574 .51438 .55679 Metetra
.795 .705 0 r
.51438 .55679 .51976 .55574 .52962 .55889 .52427 .56019 Metetra
.819 .642 0 r
.52427 .56019 .52962 .55889 .53954 .56195 .53423 .56351 Metetra
.842 .578 0 r
.53423 .56351 .53954 .56195 .54954 .56455 .54426 .56634 Metetra
.855 .537 0 r
.54426 .56634 .54954 .56455 .55956 .56291 .55432 .56475 Metetra
.847 .561 0 r
.55432 .56475 .55956 .56291 .56953 .55446 .56435 .55604 Metetra
.825 .626 0 r
.56435 .55604 .56953 .55446 .5795 .54541 .57437 .54671 Metetra
.801 .69 0 r
.57437 .54671 .5795 .54541 .58947 .53621 .58439 .53723 Metetra
.777 .75 0 r
.58439 .53723 .58947 .53621 .59943 .527 .5944 .52773 Metetra
.702 .753 0 r
.5944 .52773 .59943 .527 .6094 .51779 .60441 .51823 Metetra
.604 .729 0 r
.60441 .51823 .6094 .51779 .61937 .50859 .61442 .50874 Metetra
.511 .706 0 r
.61442 .50874 .61937 .50859 .62933 .49939 .62443 .49926 Metetra
.423 .682 0 r
.62443 .49926 .62933 .49939 .63929 .49019 .63444 .48978 Metetra
.34 .658 0 r
.63444 .48978 .63929 .49019 .64926 .48099 .64445 .4803 Metetra
.262 .634 0 r
.64445 .4803 .64926 .48099 .65922 .4718 .65445 .47083 Metetra
.189 .61 0 r
.65445 .47083 .65922 .4718 .66919 .46261 .66445 .46136 Metetra
.121 .586 0 r
.66445 .46136 .66919 .46261 .67915 .45343 .67445 .4519 Metetra
.058 .562 0 r
.67445 .4519 .67915 .45343 .68911 .44424 .68445 .44244 Metetra
0 .538 0 r
.68445 .44244 .68911 .44424 .69908 .43506 .69445 .43298 Metetra
0 .514 .054 r
.69445 .43298 .69908 .43506 .70904 .42587 .70444 .42353 Metetra
0 .491 .102 r
.70444 .42353 .70904 .42587 .719 .41669 .71444 .41407 Metetra
0 .467 .145 r
.71444 .41407 .719 .41669 .72896 .4075 .72443 .40462 Metetra
0 .443 .183 r
.72443 .40462 .72896 .4075 .73893 .39832 .73442 .39517 Metetra
0 .419 .217 r
.73442 .39517 .73893 .39832 .74889 .38914 .74441 .38572 Metetra
0 .395 .245 r
.74441 .38572 .74889 .38914 .75885 .37995 .7544 .37627 Metetra
0 .371 .269 r
.7544 .37627 .75885 .37995 .76881 .37076 .76438 .36682 Metetra
0 .347 .288 r
.76438 .36682 .76881 .37076 .77877 .36157 .77436 .35736 Metetra
0 .323 .301 r
.77436 .35736 .77877 .36157 .78873 .35238 .78434 .34791 Metetra
0 .289 .3 r
.78434 .34791 .78873 .35238 .79869 .34319 .79432 .33846 Metetra
0 .237 .276 r
.79432 .33846 .79869 .34319 .80864 .33399 .8043 .329 Metetra
0 .191 .252 r
.8043 .329 .80864 .33399 .8186 .32479 .81427 .31954 Metetra
0 .149 .228 r
.81427 .31954 .8186 .32479 .82856 .31559 .82425 .31008 Metetra
0 .112 .204 r
.82425 .31008 .82856 .31559 .83851 .30639 .83422 .30063 Metetra
0 .08 .18 r
.83422 .30063 .83851 .30639 .84847 .29723 .84419 .29121 Metetra
0 .054 .157 r
.84419 .29121 .84847 .29723 .85846 .28828 .85418 .28202 Metetra
0 .034 .135 r
.85418 .28202 .85846 .28828 .86851 .27995 .86425 .27348 Metetra
0 .031 .132 r
.25852 .46753 .26418 .47279 .27242 .47405 .26676 .46893 Metetra
0 .05 .152 r
.26676 .46893 .27242 .47405 .28063 .47648 .27496 .47155 Metetra
0 .076 .176 r
.27496 .47155 .28063 .47648 .28887 .47924 .28319 .47451 Metetra
0 .108 .201 r
.28319 .47451 .28887 .47924 .29715 .48209 .29147 .47757 Metetra
0 .145 .226 r
.29147 .47757 .29715 .48209 .3055 .48498 .2998 .48066 Metetra
0 .188 .25 r
.2998 .48066 .3055 .48498 .3139 .48788 .3082 .48378 Metetra
0 .237 .275 r
.3082 .48378 .3139 .48788 .32236 .49079 .31665 .4869 Metetra
0 .29 .3 r
.31665 .4869 .32236 .49079 .33087 .49372 .32516 .49005 Metetra
0 .325 .301 r
.32516 .49005 .33087 .49372 .33945 .49668 .33374 .49322 Metetra
0 .35 .286 r
.33374 .49322 .33945 .49668 .34808 .49964 .34237 .4964 Metetra
0 .375 .266 r
.34237 .4964 .34808 .49964 .35678 .50263 .35107 .49961 Metetra
0 .399 .241 r
.35107 .49961 .35678 .50263 .36553 .50564 .35983 .50284 Metetra
0 .424 .21 r
.35983 .50284 .36553 .50564 .37435 .50866 .36865 .50609 Metetra
0 .449 .174 r
.36865 .50609 .37435 .50866 .38322 .51171 .37753 .50936 Metetra
0 .474 .133 r
.37753 .50936 .38322 .51171 .39216 .51477 .38648 .51265 Metetra
0 .498 .086 r
.38648 .51265 .39216 .51477 .40117 .51786 .39549 .51597 Metetra
0 .523 .035 r
.39549 .51597 .40117 .51786 .41023 .52097 .40457 .51931 Metetra
.023 .548 0 r
.40457 .51931 .41023 .52097 .41937 .5241 .41371 .52268 Metetra
.085 .573 0 r
.41371 .52268 .41937 .5241 .42856 .52726 .42292 .52607 Metetra
.153 .598 0 r
.42292 .52607 .42856 .52726 .43783 .53043 .4322 .52949 Metetra
.226 .622 0 r
.4322 .52949 .43783 .53043 .44715 .53364 .44154 .53293 Metetra
.305 .647 0 r
.44154 .53293 .44715 .53364 .45655 .53686 .45096 .5364 Metetra
.388 .672 0 r
.45096 .5364 .45655 .53686 .46601 .54012 .46044 .5399 Metetra
.478 .697 0 r
.46044 .5399 .46601 .54012 .47555 .5434 .47 .54343 Metetra
.572 .722 0 r
.47 .54343 .47555 .5434 .48515 .5467 .47962 .54699 Metetra
.672 .746 0 r
.47962 .54699 .48515 .5467 .49482 .55004 .48932 .55058 Metetra
.771 .765 0 r
.48932 .55058 .49482 .55004 .50456 .5534 .49909 .55419 Metetra
.796 .704 0 r
.49909 .55419 .50456 .5534 .51438 .55679 .50894 .55784 Metetra
.821 .637 0 r
.50894 .55784 .51438 .55679 .52427 .56019 .51886 .56151 Metetra
.845 .566 0 r
.51886 .56151 .52427 .56019 .53423 .56351 .52885 .56509 Metetra
.869 .494 0 r
.52885 .56509 .53423 .56351 .54426 .56634 .53892 .56816 Metetra
.883 .448 0 r
.53892 .56816 .54426 .56634 .55432 .56475 .54903 .56661 Metetra
.875 .475 0 r
.54903 .56661 .55432 .56475 .56435 .55604 .55911 .55765 Metetra
.852 .548 0 r
.55911 .55765 .56435 .55604 .57437 .54671 .56918 .54803 Metetra
.827 .62 0 r
.56918 .54803 .57437 .54671 .58439 .53723 .57925 .53825 Metetra
.802 .687 0 r
.57925 .53825 .58439 .53723 .5944 .52773 .58931 .52846 Metetra
.777 .75 0 r
.58931 .52846 .5944 .52773 .60441 .51823 .59937 .51867 Metetra
.698 .753 0 r
.59937 .51867 .60441 .51823 .61442 .50874 .60943 .50889 Metetra
.597 .728 0 r
.60943 .50889 .61442 .50874 .62443 .49926 .61949 .49912 Metetra
.501 .703 0 r
.61949 .49912 .62443 .49926 .63444 .48978 .62954 .48936 Metetra
.41 .678 0 r
.62954 .48936 .63444 .48978 .64445 .4803 .63959 .4796 Metetra
.325 .653 0 r
.63959 .4796 .64445 .4803 .65445 .47083 .64963 .46985 Metetra
.245 .628 0 r
.64963 .46985 .65445 .47083 .66445 .46136 .65967 .4601 Metetra
.171 .604 0 r
.65967 .4601 .66445 .46136 .67445 .4519 .66971 .45036 Metetra
.101 .579 0 r
.66971 .45036 .67445 .4519 .68445 .44244 .67975 .44062 Metetra
.038 .554 0 r
.67975 .44062 .68445 .44244 .69445 .43298 .68978 .43089 Metetra
0 .529 .021 r
.68978 .43089 .69445 .43298 .70444 .42353 .69981 .42116 Metetra
0 .505 .074 r
.69981 .42116 .70444 .42353 .71444 .41407 .70983 .41144 Metetra
0 .48 .122 r
.70983 .41144 .71444 .41407 .72443 .40462 .71986 .40171 Metetra
0 .455 .165 r
.71986 .40171 .72443 .40462 .73442 .39517 .72988 .39199 Metetra
0 .43 .202 r
.72988 .39199 .73442 .39517 .74441 .38572 .73989 .38227 Metetra
0 .405 .234 r
.73989 .38227 .74441 .38572 .7544 .37627 .74991 .37255 Metetra
0 .381 .26 r
.74991 .37255 .7544 .37627 .76438 .36682 .75992 .36284 Metetra
0 .356 .282 r
.75992 .36284 .76438 .36682 .77436 .35736 .76992 .35312 Metetra
0 .331 .298 r
.76992 .35312 .77436 .35736 .78434 .34791 .77993 .3434 Metetra
0 .304 .306 r
.77993 .3434 .78434 .34791 .79432 .33846 .78993 .33369 Metetra
0 .249 .281 r
.78993 .33369 .79432 .33846 .8043 .329 .79992 .32397 Metetra
0 .2 .257 r
.79992 .32397 .8043 .329 .81427 .31954 .80991 .31426 Metetra
0 .155 .232 r
.80991 .31426 .81427 .31954 .82425 .31008 .8199 .30454 Metetra
0 .116 .207 r
.8199 .30454 .82425 .31008 .83422 .30063 .82989 .29482 Metetra
0 .083 .182 r
.82989 .29482 .83422 .30063 .84419 .29121 .83987 .28516 Metetra
0 .055 .158 r
.83987 .28516 .84419 .29121 .85418 .28202 .84988 .27572 Metetra
0 .034 .135 r
.84988 .27572 .85418 .28202 .86425 .27348 .85996 .26696 Metetra
0 .032 .132 r
.25282 .46224 .25852 .46753 .26676 .46893 .26106 .46378 Metetra
0 .051 .153 r
.26106 .46378 .26676 .46893 .27496 .47155 .26925 .46659 Metetra
0 .078 .178 r
.26925 .46659 .27496 .47155 .28319 .47451 .27747 .46975 Metetra
0 .112 .204 r
.27747 .46975 .28319 .47451 .29147 .47757 .28574 .47302 Metetra
0 .152 .229 r
.28574 .47302 .29147 .47757 .2998 .48066 .29407 .47632 Metetra
0 .197 .255 r
.29407 .47632 .2998 .48066 .3082 .48378 .30246 .47964 Metetra
0 .248 .281 r
.30246 .47964 .3082 .48378 .31665 .4869 .31091 .48298 Metetra
0 .305 .307 r
.31091 .48298 .31665 .4869 .32516 .49005 .31942 .48634 Metetra
0 .332 .297 r
.31942 .48634 .32516 .49005 .33374 .49322 .32799 .48973 Metetra
0 .358 .28 r
.32799 .48973 .33374 .49322 .34237 .4964 .33662 .49313 Metetra
0 .384 .257 r
.33662 .49313 .34237 .4964 .35107 .49961 .34532 .49656 Metetra
0 .409 .229 r
.34532 .49656 .35107 .49961 .35983 .50284 .35408 .50001 Metetra
0 .435 .195 r
.35408 .50001 .35983 .50284 .36865 .50609 .3629 .50348 Metetra
0 .461 .155 r
.3629 .50348 .36865 .50609 .37753 .50936 .37179 .50698 Metetra
0 .487 .11 r
.37179 .50698 .37753 .50936 .38648 .51265 .38074 .5105 Metetra
0 .512 .058 r
.38074 .5105 .38648 .51265 .39549 .51597 .38976 .51405 Metetra
0 .538 .001 r
.38976 .51405 .39549 .51597 .40457 .51931 .39885 .51763 Metetra
.061 .564 0 r
.39885 .51763 .40457 .51931 .41371 .52268 .40801 .52123 Metetra
.13 .589 0 r
.40801 .52123 .41371 .52268 .42292 .52607 .41723 .52486 Metetra
.204 .615 0 r
.41723 .52486 .42292 .52607 .4322 .52949 .42652 .52851 Metetra
.283 .641 0 r
.42652 .52851 .4322 .52949 .44154 .53293 .43588 .5322 Metetra
.369 .666 0 r
.43588 .5322 .44154 .53293 .45096 .5364 .44531 .53592 Metetra
.46 .692 0 r
.44531 .53592 .45096 .5364 .46044 .5399 .45482 .53966 Metetra
.557 .718 0 r
.45482 .53966 .46044 .5399 .47 .54343 .46439 .54344 Metetra
.66 .743 0 r
.46439 .54344 .47 .54343 .47962 .54699 .47404 .54725 Metetra
.769 .769 0 r
.47404 .54725 .47962 .54699 .48932 .55058 .48377 .5511 Metetra
.795 .707 0 r
.48377 .5511 .48932 .55058 .49909 .55419 .49356 .55498 Metetra
.821 .638 0 r
.49356 .55498 .49909 .55419 .50894 .55784 .50344 .55889 Metetra
.846 .564 0 r
.50344 .55889 .50894 .55784 .51886 .56151 .51339 .56281 Metetra
.872 .484 0 r
.51339 .56281 .51886 .56151 .52885 .56509 .52342 .56666 Metetra
.896 .403 0 r
.52342 .56666 .52885 .56509 .53892 .56816 .53352 .56997 Metetra
.911 .353 0 r
.53352 .56997 .53892 .56816 .54903 .56661 .54368 .56847 Metetra
.902 .383 0 r
.54368 .56847 .54903 .56661 .55911 .55765 .55381 .55924 Metetra
.878 .463 0 r
.55381 .55924 .55911 .55765 .56918 .54803 .56394 .54934 Metetra
.853 .544 0 r
.56394 .54934 .56918 .54803 .57925 .53825 .57406 .53926 Metetra
.827 .62 0 r
.57406 .53926 .57925 .53825 .58931 .52846 .58417 .52918 Metetra
.801 .69 0 r
.58417 .52918 .58931 .52846 .59937 .51867 .59428 .5191 Metetra
.776 .754 0 r
.59428 .5191 .59937 .51867 .60943 .50889 .60439 .50903 Metetra
.687 .75 0 r
.60439 .50903 .60943 .50889 .61949 .49912 .61449 .49897 Metetra
.582 .724 0 r
.61449 .49897 .61949 .49912 .62954 .48936 .62458 .48892 Metetra
.484 .698 0 r
.62458 .48892 .62954 .48936 .63959 .4796 .63468 .47888 Metetra
.391 .673 0 r
.63468 .47888 .63959 .4796 .64963 .46985 .64476 .46884 Metetra
.304 .647 0 r
.64476 .46884 .64963 .46985 .65967 .4601 .65485 .45881 Metetra
.223 .621 0 r
.65485 .45881 .65967 .4601 .66971 .45036 .66492 .44879 Metetra
.147 .596 0 r
.66492 .44879 .66971 .45036 .67975 .44062 .675 .43878 Metetra
.078 .57 0 r
.675 .43878 .67975 .44062 .68978 .43089 .68506 .42877 Metetra
.014 .544 0 r
.68506 .42877 .68978 .43089 .69981 .42116 .69513 .41876 Metetra
0 .519 .045 r
.69513 .41876 .69981 .42116 .70983 .41144 .70519 .40876 Metetra
0 .493 .097 r
.70519 .40876 .70983 .41144 .71986 .40171 .71524 .39877 Metetra
0 .467 .144 r
.71524 .39877 .71986 .40171 .72988 .39199 .72529 .38877 Metetra
0 .442 .185 r
.72529 .38877 .72988 .39199 .73989 .38227 .73534 .37878 Metetra
0 .416 .221 r
.73534 .37878 .73989 .38227 .74991 .37255 .74538 .3688 Metetra
0 .39 .251 r
.74538 .3688 .74991 .37255 .75992 .36284 .75541 .35882 Metetra
0 .364 .275 r
.75541 .35882 .75992 .36284 .76992 .35312 .76545 .34883 Metetra
0 .339 .293 r
.76545 .34883 .76992 .35312 .77993 .3434 .77547 .33886 Metetra
0 .313 .306 r
.77547 .33886 .77993 .3434 .78993 .33369 .78549 .32888 Metetra
0 .262 .287 r
.78549 .32888 .78993 .33369 .79992 .32397 .79551 .3189 Metetra
0 .209 .262 r
.79551 .3189 .79992 .32397 .80991 .31426 .80552 .30892 Metetra
0 .162 .236 r
.80552 .30892 .80991 .31426 .8199 .30454 .81553 .29895 Metetra
0 .121 .21 r
.81553 .29895 .8199 .30454 .82989 .29482 .82553 .28898 Metetra
0 .086 .184 r
.82553 .28898 .82989 .29482 .83987 .28516 .83553 .27906 Metetra
0 .057 .159 r
.83553 .27906 .83987 .28516 .84988 .27572 .84555 .26937 Metetra
0 .035 .136 r
.84555 .26937 .84988 .27572 .85996 .26696 .85564 .2604 Metetra
0 .032 .132 r
.24709 .45692 .25282 .46224 .26106 .46378 .25532 .4586 Metetra
0 .052 .155 r
.25532 .4586 .26106 .46378 .26925 .46659 .2635 .46158 Metetra
0 .08 .18 r
.2635 .46158 .26925 .46659 .27747 .46975 .27171 .46495 Metetra
0 .116 .207 r
.27171 .46495 .27747 .46975 .28574 .47302 .27997 .46841 Metetra
0 .158 .233 r
.27997 .46841 .28574 .47302 .29407 .47632 .2883 .47192 Metetra
0 .206 .26 r
.2883 .47192 .29407 .47632 .30246 .47964 .29668 .47544 Metetra
0 .26 .286 r
.29668 .47544 .30246 .47964 .31091 .48298 .30512 .47899 Metetra
0 .313 .306 r
.30512 .47899 .31091 .48298 .31942 .48634 .31363 .48256 Metetra
0 .34 .293 r
.31363 .48256 .31942 .48634 .32799 .48973 .3222 .48616 Metetra
0 .366 .273 r
.3222 .48616 .32799 .48973 .33662 .49313 .33083 .48978 Metetra
0 .393 .248 r
.33083 .48978 .33662 .49313 .34532 .49656 .33953 .49342 Metetra
0 .419 .216 r
.33953 .49342 .34532 .49656 .35408 .50001 .34829 .49709 Metetra
0 .446 .179 r
.34829 .49709 .35408 .50001 .3629 .50348 .35711 .50078 Metetra
0 .473 .135 r
.35711 .50078 .3629 .50348 .37179 .50698 .36601 .5045 Metetra
0 .499 .085 r
.36601 .5045 .37179 .50698 .38074 .5105 .37497 .50825 Metetra
0 .526 .029 r
.37497 .50825 .38074 .5105 .38976 .51405 .38399 .51202 Metetra
.033 .552 0 r
.38399 .51202 .38976 .51405 .39885 .51763 .39309 .51582 Metetra
.101 .579 0 r
.39309 .51582 .39885 .51763 .40801 .52123 .40225 .51966 Metetra
.176 .605 0 r
.40225 .51966 .40801 .52123 .41723 .52486 .41149 .52352 Metetra
.256 .632 0 r
.41149 .52352 .41723 .52486 .42652 .52851 .42079 .52741 Metetra
.343 .659 0 r
.42079 .52741 .42652 .52851 .43588 .5322 .43017 .53134 Metetra
.435 .685 0 r
.43017 .53134 .43588 .5322 .44531 .53592 .43962 .5353 Metetra
.534 .712 0 r
.43962 .5353 .44531 .53592 .45482 .53966 .44914 .53929 Metetra
.639 .738 0 r
.44914 .53929 .45482 .53966 .46439 .54344 .45874 .54331 Metetra
.751 .765 0 r
.45874 .54331 .46439 .54344 .47404 .54725 .46841 .54737 Metetra
.792 .715 0 r
.46841 .54737 .47404 .54725 .48377 .5511 .47816 .55147 Metetra
.818 .645 0 r
.47816 .55147 .48377 .5511 .49356 .55498 .48798 .5556 Metetra
.845 .568 0 r
.48798 .5556 .49356 .55498 .50344 .55889 .49788 .55977 Metetra
.871 .485 0 r
.49788 .55977 .50344 .55889 .51339 .56281 .50786 .56395 Metetra
.898 .397 0 r
.50786 .56395 .51339 .56281 .52342 .56666 .51792 .56805 Metetra
.923 .308 0 r
.51792 .56805 .52342 .56666 .53352 .56997 .52806 .5716 Metetra
.938 .252 0 r
.52806 .5716 .53352 .56997 .54368 .56847 .53826 .57015 Metetra
.929 .286 0 r
.53826 .57015 .54368 .56847 .55381 .55924 .54845 .56066 Metetra
.904 .375 0 r
.54845 .56066 .55381 .55924 .56394 .54934 .55863 .55047 Metetra
.878 .464 0 r
.55863 .55047 .56394 .54934 .57406 .53926 .5688 .54011 Metetra
.851 .548 0 r
.5688 .54011 .57406 .53926 .58417 .52918 .57897 .52973 Metetra
.825 .626 0 r
.57897 .52973 .58417 .52918 .59428 .5191 .58913 .51937 Metetra
.798 .698 0 r
.58913 .51937 .59428 .5191 .60439 .50903 .59929 .50901 Metetra
.772 .764 0 r
.59929 .50901 .60439 .50903 .61449 .49897 .60943 .49867 Metetra
.666 .745 0 r
.60943 .49867 .61449 .49897 .62458 .48892 .61958 .48834 Metetra
.56 .718 0 r
.61958 .48834 .62458 .48892 .63468 .47888 .62971 .47801 Metetra
.459 .692 0 r
.62971 .47801 .63468 .47888 .64476 .46884 .63984 .4677 Metetra
.365 .665 0 r
.63984 .4677 .64476 .46884 .65485 .45881 .64997 .45739 Metetra
.277 .639 0 r
.64997 .45739 .65485 .45881 .66492 .44879 .66008 .44709 Metetra
.195 .612 0 r
.66008 .44709 .66492 .44879 .675 .43878 .6702 .4368 Metetra
.119 .585 0 r
.6702 .4368 .675 .43878 .68506 .42877 .6803 .42652 Metetra
.049 .559 0 r
.6803 .42652 .68506 .42877 .69513 .41876 .6904 .41624 Metetra
0 .532 .014 r
.6904 .41624 .69513 .41876 .70519 .40876 .7005 .40597 Metetra
0 .506 .072 r
.7005 .40597 .70519 .40876 .71524 .39877 .71058 .39571 Metetra
0 .479 .123 r
.71058 .39571 .71524 .39877 .72529 .38877 .72066 .38545 Metetra
0 .453 .168 r
.72066 .38545 .72529 .38877 .73534 .37878 .73074 .37519 Metetra
0 .426 .208 r
.73074 .37519 .73534 .37878 .74538 .3688 .74081 .36495 Metetra
0 .399 .241 r
.74081 .36495 .74538 .3688 .75541 .35882 .75087 .3547 Metetra
0 .373 .268 r
.75087 .3547 .75541 .35882 .76545 .34883 .76093 .34446 Metetra
0 .346 .288 r
.76093 .34446 .76545 .34883 .77547 .33886 .77098 .33422 Metetra
0 .32 .303 r
.77098 .33422 .77547 .33886 .78549 .32888 .78102 .32398 Metetra
0 .274 .293 r
.78102 .32398 .78549 .32888 .79551 .3189 .79106 .31375 Metetra
0 .219 .266 r
.79106 .31375 .79551 .3189 .80552 .30892 .80109 .30352 Metetra
0 .169 .24 r
.80109 .30352 .80552 .30892 .81553 .29895 .81112 .29329 Metetra
0 .126 .213 r
.81112 .29329 .81553 .29895 .82553 .28898 .82113 .28307 Metetra
0 .089 .186 r
.82113 .28307 .82553 .28898 .83553 .27906 .83115 .2729 Metetra
0 .058 .16 r
.83115 .2729 .83553 .27906 .84555 .26937 .84119 .26298 Metetra
0 .035 .136 r
.84119 .26298 .84555 .26937 .85564 .2604 .8513 .25379 Metetra
0 .032 .133 r
.24132 .45156 .24709 .45692 .25532 .4586 .24955 .45336 Metetra
0 .053 .156 r
.24955 .45336 .25532 .4586 .2635 .46158 .25773 .45651 Metetra
0 .083 .182 r
.25773 .45651 .2635 .46158 .27171 .46495 .26593 .46005 Metetra
0 .12 .209 r
.26593 .46005 .27171 .46495 .27997 .46841 .27418 .46369 Metetra
0 .164 .237 r
.27418 .46369 .27997 .46841 .2883 .47192 .28249 .46738 Metetra
0 .214 .264 r
.28249 .46738 .2883 .47192 .29668 .47544 .29087 .47109 Metetra
0 .271 .292 r
.29087 .47109 .29668 .47544 .30512 .47899 .29931 .47482 Metetra
0 .319 .303 r
.29931 .47482 .30512 .47899 .31363 .48256 .30781 .47858 Metetra
0 .346 .288 r
.30781 .47858 .31363 .48256 .3222 .48616 .31638 .48237 Metetra
0 .374 .267 r
.31638 .48237 .3222 .48616 .33083 .48978 .32501 .48618 Metetra
0 .401 .238 r
.32501 .48618 .33083 .48978 .33953 .49342 .3337 .49001 Metetra
0 .429 .204 r
.3337 .49001 .33953 .49342 .34829 .49709 .34246 .49388 Metetra
0 .456 .163 r
.34246 .49388 .34829 .49709 .35711 .50078 .35129 .49777 Metetra
0 .484 .115 r
.35129 .49777 .35711 .50078 .36601 .5045 .36019 .50169 Metetra
0 .511 .061 r
.36019 .50169 .36601 .5045 .37497 .50825 .36915 .50564 Metetra
0 .538 0 r
.36915 .50564 .37497 .50825 .38399 .51202 .37819 .50962 Metetra
.067 .566 0 r
.37819 .50962 .38399 .51202 .39309 .51582 .38729 .51363 Metetra
.141 .593 0 r
.38729 .51363 .39309 .51582 .40225 .51966 .39646 .51767 Metetra
.221 .621 0 r
.39646 .51767 .40225 .51966 .41149 .52352 .40571 .52174 Metetra
.307 .648 0 r
.40571 .52174 .41149 .52352 .42079 .52741 .41503 .52585 Metetra
.401 .675 0 r
.41503 .52585 .42079 .52741 .43017 .53134 .42442 .52999 Metetra
.5 .703 0 r
.42442 .52999 .43017 .53134 .43962 .5353 .43388 .53416 Metetra
.607 .73 0 r
.43388 .53416 .43962 .5353 .44914 .53929 .44342 .53837 Metetra
.72 .758 0 r
.44342 .53837 .44914 .53929 .45874 .54331 .45304 .54262 Metetra
.785 .731 0 r
.45304 .54262 .45874 .54331 .46841 .54737 .46273 .54691 Metetra
.813 .66 0 r
.46273 .54691 .46841 .54737 .47816 .55147 .4725 .55123 Metetra
.84 .582 0 r
.4725 .55123 .47816 .55147 .48798 .5556 .48235 .55559 Metetra
.867 .498 0 r
.48235 .55559 .48798 .5556 .49788 .55977 .49227 .55999 Metetra
.895 .407 0 r
.49227 .55999 .49788 .55977 .50786 .56395 .50228 .56441 Metetra
.922 .311 0 r
.50228 .56441 .50786 .56395 .51792 .56805 .51237 .56874 Metetra
.948 .213 0 r
.51237 .56874 .51792 .56805 .52806 .5716 .52254 .5725 Metetra
.963 .153 0 r
.52254 .5725 .52806 .5716 .53826 .57015 .53278 .57109 Metetra
.954 .189 0 r
.53278 .57109 .53826 .57015 .54845 .56066 .54303 .56137 Metetra
.929 .286 0 r
.54303 .56137 .54845 .56066 .55863 .55047 .55326 .55091 Metetra
.902 .384 0 r
.55326 .55091 .55863 .55047 .5688 .54011 .56349 .54029 Metetra
.874 .476 0 r
.56349 .54029 .5688 .54011 .57897 .52973 .57371 .52964 Metetra
.847 .562 0 r
.57371 .52964 .57897 .52973 .58913 .51937 .58392 .51901 Metetra
.819 .641 0 r
.58392 .51901 .58913 .51937 .59929 .50901 .59412 .5084 Metetra
.792 .714 0 r
.59412 .5084 .59929 .50901 .60943 .49867 .60432 .49779 Metetra
.749 .764 0 r
.60432 .49779 .60943 .49867 .61958 .48834 .6145 .4872 Metetra
.634 .737 0 r
.6145 .4872 .61958 .48834 .62971 .47801 .62468 .47662 Metetra
.526 .71 0 r
.62468 .47662 .62971 .47801 .63984 .4677 .63486 .46604 Metetra
.425 .682 0 r
.63486 .46604 .63984 .4677 .64997 .45739 .64502 .45548 Metetra
.33 .655 0 r
.64502 .45548 .64997 .45739 .66008 .44709 .65518 .44493 Metetra
.242 .627 0 r
.65518 .44493 .66008 .44709 .6702 .4368 .66533 .43439 Metetra
.16 .6 0 r
.66533 .43439 .6702 .4368 .6803 .42652 .67548 .42385 Metetra
.085 .573 0 r
.67548 .42385 .6803 .42652 .6904 .41624 .68561 .41333 Metetra
.016 .545 0 r
.68561 .41333 .6904 .41624 .7005 .40597 .69574 .40281 Metetra
0 .518 .046 r
.69574 .40281 .7005 .40597 .71058 .39571 .70586 .3923 Metetra
0 .49 .102 r
.70586 .3923 .71058 .39571 .72066 .38545 .71598 .38179 Metetra
0 .463 .151 r
.71598 .38179 .72066 .38545 .73074 .37519 .72609 .3713 Metetra
0 .436 .194 r
.72609 .3713 .73074 .37519 .74081 .36495 .73618 .3608 Metetra
0 .408 .231 r
.73618 .3608 .74081 .36495 .75087 .3547 .74628 .35032 Metetra
0 .381 .26 r
.74628 .35032 .75087 .3547 .76093 .34446 .75636 .33984 Metetra
0 .353 .283 r
.75636 .33984 .76093 .34446 .77098 .33422 .76644 .32936 Metetra
0 .326 .3 r
.76644 .32936 .77098 .33422 .78102 .32398 .77651 .31889 Metetra
0 .286 .298 r
.77651 .31889 .78102 .32398 .79106 .31375 .78657 .30842 Metetra
0 .228 .271 r
.78657 .30842 .79106 .31375 .80109 .30352 .79662 .29796 Metetra
0 .176 .243 r
.79662 .29796 .80109 .30352 .81112 .29329 .80667 .2875 Metetra
0 .13 .216 r
.80667 .2875 .81112 .29329 .82113 .28307 .8167 .27705 Metetra
0 .091 .188 r
.8167 .27705 .82113 .28307 .83115 .2729 .82674 .26665 Metetra
0 .059 .162 r
.82674 .26665 .83115 .2729 .84119 .26298 .83679 .25652 Metetra
0 .036 .137 r
.83679 .25652 .84119 .26298 .8513 .25379 .84692 .24714 Metetra
0 .032 .133 r
.23552 .44616 .24132 .45156 .24955 .45336 .24376 .44791 Metetra
0 .053 .156 r
.24376 .44791 .24955 .45336 .25773 .45651 .25194 .45101 Metetra
0 .084 .183 r
.25194 .45101 .25773 .45651 .26593 .46005 .26015 .4545 Metetra
0 .121 .21 r
.26015 .4545 .26593 .46005 .27418 .46369 .26841 .45809 Metetra
0 .166 .238 r
.26841 .45809 .27418 .46369 .28249 .46738 .27673 .46172 Metetra
0 .217 .266 r
.27673 .46172 .28249 .46738 .29087 .47109 .28512 .46537 Metetra
0 .275 .293 r
.28512 .46537 .29087 .47109 .29931 .47482 .29356 .46905 Metetra
0 .321 .302 r
.29356 .46905 .29931 .47482 .30781 .47858 .30207 .47275 Metetra
0 .349 .287 r
.30207 .47275 .30781 .47858 .31638 .48237 .31065 .47647 Metetra
0 .377 .264 r
.31065 .47647 .31638 .48237 .32501 .48618 .31929 .48023 Metetra
0 .404 .235 r
.31929 .48023 .32501 .48618 .3337 .49001 .32799 .484 Metetra
0 .432 .199 r
.32799 .484 .3337 .49001 .34246 .49388 .33676 .48781 Metetra
0 .46 .157 r
.33676 .48781 .34246 .49388 .35129 .49777 .3456 .49164 Metetra
0 .487 .108 r
.3456 .49164 .35129 .49777 .36019 .50169 .3545 .4955 Metetra
0 .515 .052 r
.3545 .4955 .36019 .50169 .36915 .50564 .36347 .49939 Metetra
.01 .543 0 r
.36347 .49939 .36915 .50564 .37819 .50962 .37251 .5033 Metetra
.079 .571 0 r
.37251 .5033 .37819 .50962 .38729 .51363 .38162 .50725 Metetra
.155 .598 0 r
.38162 .50725 .38729 .51363 .39646 .51767 .39081 .51123 Metetra
.237 .626 0 r
.39081 .51123 .39646 .51767 .40571 .52174 .40006 .51524 Metetra
.326 .654 0 r
.40006 .51524 .40571 .52174 .41503 .52585 .40938 .51928 Metetra
.422 .681 0 r
.40938 .51928 .41503 .52585 .42442 .52999 .41878 .52336 Metetra
.524 .709 0 r
.41878 .52336 .42442 .52999 .43388 .53416 .42825 .52747 Metetra
.633 .737 0 r
.42825 .52747 .43388 .53416 .44342 .53837 .4378 .53162 Metetra
.749 .765 0 r
.4378 .53162 .44342 .53837 .45304 .54262 .44742 .5358 Metetra
.792 .713 0 r
.44742 .5358 .45304 .54262 .46273 .54691 .45712 .54002 Metetra
.82 .64 0 r
.45712 .54002 .46273 .54691 .4725 .55123 .4669 .54427 Metetra
.848 .559 0 r
.4669 .54427 .4725 .55123 .48235 .55559 .47676 .54857 Metetra
.876 .472 0 r
.47676 .54857 .48235 .55559 .49227 .55999 .48669 .5529 Metetra
.903 .378 0 r
.48669 .5529 .49227 .55999 .50228 .56441 .49671 .55725 Metetra
.931 .279 0 r
.49671 .55725 .50228 .56441 .51237 .56874 .5068 .56151 Metetra
.957 .178 0 r
.5068 .56151 .51237 .56874 .52254 .5725 .51699 .56521 Metetra
.973 .116 0 r
.51699 .56521 .52254 .5725 .53278 .57109 .52724 .56377 Metetra
.963 .153 0 r
.52724 .56377 .53278 .57109 .54303 .56137 .53752 .55406 Metetra
.938 .253 0 r
.53752 .55406 .54303 .56137 .55326 .55091 .54778 .54363 Metetra
.91 .354 0 r
.54778 .54363 .55326 .55091 .56349 .54029 .55804 .53303 Metetra
.883 .449 0 r
.55804 .53303 .56349 .54029 .57371 .52964 .56829 .52241 Metetra
.855 .538 0 r
.56829 .52241 .57371 .52964 .58392 .51901 .57854 .5118 Metetra
.827 .62 0 r
.57854 .5118 .58392 .51901 .59412 .5084 .58878 .50121 Metetra
.799 .696 0 r
.58878 .50121 .59412 .5084 .60432 .49779 .59901 .49062 Metetra
.771 .764 0 r
.59901 .49062 .60432 .49779 .6145 .4872 .60923 .48005 Metetra
.661 .744 0 r
.60923 .48005 .6145 .4872 .62468 .47662 .61944 .46949 Metetra
.551 .716 0 r
.61944 .46949 .62468 .47662 .63486 .46604 .62965 .45894 Metetra
.447 .688 0 r
.62965 .45894 .63486 .46604 .64502 .45548 .63985 .4484 Metetra
.349 .661 0 r
.63985 .4484 .64502 .45548 .65518 .44493 .65005 .43787 Metetra
.259 .633 0 r
.65005 .43787 .65518 .44493 .66533 .43439 .66023 .42735 Metetra
.175 .605 0 r
.66023 .42735 .66533 .43439 .67548 .42385 .67041 .41683 Metetra
.097 .577 0 r
.67041 .41683 .67548 .42385 .68561 .41333 .68059 .40633 Metetra
.027 .55 0 r
.68059 .40633 .68561 .41333 .69574 .40281 .69075 .39583 Metetra
0 .522 .037 r
.69075 .39583 .69574 .40281 .70586 .3923 .70091 .38534 Metetra
0 .494 .095 r
.70091 .38534 .70586 .3923 .71598 .38179 .71106 .37485 Metetra
0 .467 .145 r
.71106 .37485 .71598 .38179 .72609 .3713 .72121 .36437 Metetra
0 .439 .189 r
.72121 .36437 .72609 .3713 .73618 .3608 .73134 .3539 Metetra
0 .411 .227 r
.73134 .3539 .73618 .3608 .74628 .35032 .74147 .34343 Metetra
0 .383 .258 r
.74147 .34343 .74628 .35032 .75636 .33984 .7516 .33297 Metetra
0 .356 .282 r
.7516 .33297 .75636 .33984 .76644 .32936 .76171 .32251 Metetra
0 .328 .299 r
.76171 .32251 .76644 .32936 .77651 .31889 .77182 .31206 Metetra
0 .291 .3 r
.77182 .31206 .77651 .31889 .78657 .30842 .78192 .30161 Metetra
0 .231 .272 r
.78192 .30161 .78657 .30842 .79662 .29796 .79201 .29116 Metetra
0 .178 .245 r
.79201 .29116 .79662 .29796 .80667 .2875 .8021 .28071 Metetra
0 .132 .217 r
.8021 .28071 .80667 .2875 .8167 .27705 .81217 .27028 Metetra
0 .092 .189 r
.81217 .27028 .8167 .27705 .82674 .26665 .82225 .2599 Metetra
0 .06 .162 r
.82225 .2599 .82674 .26665 .83679 .25652 .83234 .24978 Metetra
0 .036 .137 r
.83234 .24978 .83679 .25652 .84692 .24714 .84251 .2404 Metetra
0 .032 .133 r
.22969 .44071 .23552 .44616 .24376 .44791 .23795 .44232 Metetra
0 .053 .155 r
.23795 .44232 .24376 .44791 .25194 .45101 .24615 .44523 Metetra
0 .082 .181 r
.24615 .44523 .25194 .45101 .26015 .4545 .25437 .44852 Metetra
0 .119 .209 r
.25437 .44852 .26015 .4545 .26841 .45809 .26265 .45191 Metetra
0 .162 .236 r
.26265 .45191 .26841 .45809 .27673 .46172 .27099 .45533 Metetra
0 .212 .263 r
.27099 .45533 .27673 .46172 .28512 .46537 .27939 .45877 Metetra
0 .268 .29 r
.27939 .45877 .28512 .46537 .29356 .46905 .28786 .46224 Metetra
0 .318 .304 r
.28786 .46224 .29356 .46905 .30207 .47275 .29638 .46573 Metetra
0 .345 .289 r
.29638 .46573 .30207 .47275 .31065 .47647 .30497 .46924 Metetra
0 .372 .268 r
.30497 .46924 .31065 .47647 .31929 .48023 .31362 .47278 Metetra
0 .399 .241 r
.31362 .47278 .31929 .48023 .32799 .484 .32234 .47634 Metetra
0 .426 .207 r
.32234 .47634 .32799 .484 .33676 .48781 .33112 .47992 Metetra
0 .454 .167 r
.33112 .47992 .33676 .48781 .3456 .49164 .33997 .48353 Metetra
0 .481 .12 r
.33997 .48353 .3456 .49164 .3545 .4955 .34889 .48717 Metetra
0 .508 .067 r
.34889 .48717 .3545 .4955 .36347 .49939 .35787 .49083 Metetra
0 .535 .008 r
.35787 .49083 .36347 .49939 .37251 .5033 .36692 .49452 Metetra
.058 .562 0 r
.36692 .49452 .37251 .5033 .38162 .50725 .37604 .49824 Metetra
.131 .59 0 r
.37604 .49824 .38162 .50725 .39081 .51123 .38523 .50198 Metetra
.209 .617 0 r
.38523 .50198 .39081 .51123 .40006 .51524 .39449 .50576 Metetra
.294 .644 0 r
.39449 .50576 .40006 .51524 .40938 .51928 .40382 .50956 Metetra
.386 .671 0 r
.40382 .50956 .40938 .51928 .41878 .52336 .41322 .5134 Metetra
.484 .698 0 r
.41322 .5134 .41878 .52336 .42825 .52747 .4227 .51727 Metetra
.588 .726 0 r
.4227 .51727 .42825 .52747 .4378 .53162 .43225 .52117 Metetra
.699 .753 0 r
.43225 .52117 .4378 .53162 .44742 .5358 .44187 .52511 Metetra
.78 .743 0 r
.44187 .52511 .44742 .5358 .45712 .54002 .45157 .52908 Metetra
.807 .674 0 r
.45157 .52908 .45712 .54002 .4669 .54427 .46135 .53308 Metetra
.835 .598 0 r
.46135 .53308 .4669 .54427 .47676 .54857 .4712 .53712 Metetra
.862 .516 0 r
.4712 .53712 .47676 .54857 .48669 .5529 .48113 .5412 Metetra
.889 .427 0 r
.48113 .5412 .48669 .5529 .49671 .55725 .49114 .54529 Metetra
.916 .333 0 r
.49114 .54529 .49671 .55725 .5068 .56151 .50124 .5493 Metetra
.942 .237 0 r
.50124 .5493 .5068 .56151 .51699 .56521 .51141 .55276 Metetra
.957 .178 0 r
.51141 .55276 .51699 .56521 .52724 .56377 .52167 .55124 Metetra
.948 .213 0 r
.52167 .55124 .52724 .56377 .53752 .55406 .53196 .54171 Metetra
.923 .309 0 r
.53196 .54171 .53752 .55406 .54778 .54363 .54225 .53148 Metetra
.896 .404 0 r
.54225 .53148 .54778 .54363 .55804 .53303 .55253 .52108 Metetra
.869 .494 0 r
.55253 .52108 .55804 .53303 .56829 .52241 .5628 .51066 Metetra
.841 .578 0 r
.5628 .51066 .56829 .52241 .57854 .5118 .57307 .50026 Metetra
.814 .656 0 r
.57307 .50026 .57854 .5118 .58878 .50121 .58333 .48987 Metetra
.787 .727 0 r
.58333 .48987 .58878 .50121 .59901 .49062 .59358 .47949 Metetra
.728 .76 0 r
.59358 .47949 .59901 .49062 .60923 .48005 .60383 .46911 Metetra
.615 .732 0 r
.60383 .46911 .60923 .48005 .61944 .46949 .61407 .45875 Metetra
.509 .705 0 r
.61407 .45875 .61944 .46949 .62965 .45894 .62431 .4484 Metetra
.41 .678 0 r
.62431 .4484 .62965 .45894 .63985 .4484 .63454 .43805 Metetra
.317 .651 0 r
.63454 .43805 .63985 .4484 .65005 .43787 .64477 .42771 Metetra
.23 .624 0 r
.64477 .42771 .65005 .43787 .66023 .42735 .65499 .41738 Metetra
.15 .596 0 r
.65499 .41738 .66023 .42735 .67041 .41683 .6652 .40706 Metetra
.076 .569 0 r
.6652 .40706 .67041 .41683 .68059 .40633 .67541 .39674 Metetra
.008 .542 0 r
.67541 .39674 .68059 .40633 .69075 .39583 .68561 .38643 Metetra
0 .515 .053 r
.68561 .38643 .69075 .39583 .70091 .38534 .69581 .37613 Metetra
0 .488 .108 r
.69581 .37613 .70091 .38534 .71106 .37485 .706 .36583 Metetra
0 .46 .156 r
.706 .36583 .71106 .37485 .72121 .36437 .71618 .35553 Metetra
0 .433 .198 r
.71618 .35553 .72121 .36437 .73134 .3539 .72636 .34524 Metetra
0 .406 .233 r
.72636 .34524 .73134 .3539 .74147 .34343 .73654 .33495 Metetra
0 .379 .262 r
.73654 .33495 .74147 .34343 .7516 .33297 .7467 .32467 Metetra
0 .352 .285 r
.7467 .32467 .7516 .33297 .76171 .32251 .75686 .31439 Metetra
0 .324 .301 r
.75686 .31439 .76171 .32251 .77182 .31206 .76702 .30411 Metetra
0 .283 .297 r
.76702 .30411 .77182 .31206 .78192 .30161 .77717 .29383 Metetra
0 .225 .27 r
.77717 .29383 .78192 .30161 .79201 .29116 .78731 .28356 Metetra
0 .174 .242 r
.78731 .28356 .79201 .29116 .8021 .28071 .79744 .27328 Metetra
0 .129 .215 r
.79744 .27328 .8021 .28071 .81217 .27028 .80757 .26302 Metetra
0 .09 .188 r
.80757 .26302 .81217 .27028 .82225 .2599 .8177 .2528 Metetra
0 .059 .161 r
.8177 .2528 .82225 .2599 .83234 .24978 .82785 .24284 Metetra
0 .035 .137 r
.82785 .24284 .83234 .24978 .84251 .2404 .83807 .2336 Metetra
0 .032 .132 r
.22382 .43524 .22969 .44071 .23795 .44232 .2321 .43668 Metetra
0 .052 .154 r
.2321 .43668 .23795 .44232 .24615 .44523 .24032 .43939 Metetra
0 .08 .18 r
.24032 .43939 .24615 .44523 .25437 .44852 .24857 .44245 Metetra
0 .115 .206 r
.24857 .44245 .25437 .44852 .26265 .45191 .25687 .44562 Metetra
0 .156 .232 r
.25687 .44562 .26265 .45191 .27099 .45533 .26523 .44882 Metetra
0 .204 .259 r
.26523 .44882 .27099 .45533 .27939 .45877 .27365 .45204 Metetra
0 .257 .285 r
.27365 .45204 .27939 .45877 .28786 .46224 .28213 .45528 Metetra
0 .311 .306 r
.28213 .45528 .28786 .46224 .29638 .46573 .29067 .45853 Metetra
0 .338 .294 r
.29067 .45853 .29638 .46573 .30497 .46924 .29928 .46181 Metetra
0 .364 .275 r
.29928 .46181 .30497 .46924 .31362 .47278 .30794 .46511 Metetra
0 .391 .25 r
.30794 .46511 .31362 .47278 .32234 .47634 .31668 .46844 Metetra
0 .417 .22 r
.31668 .46844 .32234 .47634 .33112 .47992 .32547 .47178 Metetra
0 .443 .183 r
.32547 .47178 .33112 .47992 .33997 .48353 .33433 .47515 Metetra
0 .47 .14 r
.33433 .47515 .33997 .48353 .34889 .48717 .34326 .47854 Metetra
0 .496 .091 r
.34326 .47854 .34889 .48717 .35787 .49083 .35225 .48196 Metetra
0 .522 .037 r
.35225 .48196 .35787 .49083 .36692 .49452 .36131 .4854 Metetra
.024 .549 0 r
.36131 .4854 .36692 .49452 .37604 .49824 .37044 .48887 Metetra
.091 .575 0 r
.37044 .48887 .37604 .49824 .38523 .50198 .37964 .49236 Metetra
.164 .601 0 r
.37964 .49236 .38523 .50198 .39449 .50576 .38891 .49588 Metetra
.243 .628 0 r
.38891 .49588 .39449 .50576 .40382 .50956 .39824 .49943 Metetra
.328 .654 0 r
.39824 .49943 .40382 .50956 .41322 .5134 .40765 .503 Metetra
.418 .68 0 r
.40765 .503 .41322 .5134 .4227 .51727 .41713 .50661 Metetra
.515 .707 0 r
.41713 .50661 .4227 .51727 .43225 .52117 .42668 .51025 Metetra
.618 .733 0 r
.42668 .51025 .43225 .52117 .44187 .52511 .43631 .51392 Metetra
.728 .76 0 r
.43631 .51392 .44187 .52511 .45157 .52908 .44601 .51762 Metetra
.786 .729 0 r
.44601 .51762 .45157 .52908 .46135 .53308 .45579 .52135 Metetra
.812 .661 0 r
.45579 .52135 .46135 .53308 .4712 .53712 .46564 .52511 Metetra
.839 .586 0 r
.46564 .52511 .4712 .53712 .48113 .5412 .47557 .52891 Metetra
.865 .505 0 r
.47557 .52891 .48113 .5412 .49114 .54529 .48557 .53273 Metetra
.891 .42 0 r
.48557 .53273 .49114 .54529 .50124 .5493 .49566 .53645 Metetra
.916 .333 0 r
.49566 .53645 .50124 .5493 .51141 .55276 .50583 .53965 Metetra
.931 .278 0 r
.50583 .53965 .51141 .55276 .52167 .55124 .51609 .53805 Metetra
.922 .31 0 r
.51609 .53805 .52167 .55124 .53196 .54171 .52639 .52872 Metetra
.898 .397 0 r
.52639 .52872 .53196 .54171 .54225 .53148 .53669 .51871 Metetra
.872 .484 0 r
.53669 .51871 .54225 .53148 .55253 .52108 .54699 .50853 Metetra
.845 .566 0 r
.54699 .50853 .55253 .52108 .5628 .51066 .55728 .49835 Metetra
.819 .643 0 r
.55728 .49835 .5628 .51066 .57307 .50026 .56757 .48817 Metetra
.793 .713 0 r
.56757 .48817 .57307 .50026 .58333 .48987 .57785 .478 Metetra
.756 .766 0 r
.57785 .478 .58333 .48987 .59358 .47949 .58813 .46784 Metetra
.645 .74 0 r
.58813 .46784 .59358 .47949 .60383 .46911 .5984 .45769 Metetra
.54 .713 0 r
.5984 .45769 .60383 .46911 .61407 .45875 .60867 .44754 Metetra
.442 .687 0 r
.60867 .44754 .61407 .45875 .62431 .4484 .61894 .4374 Metetra
.35 .661 0 r
.61894 .4374 .62431 .4484 .63454 .43805 .6292 .42727 Metetra
.263 .634 0 r
.6292 .42727 .63454 .43805 .64477 .42771 .63945 .41715 Metetra
.183 .608 0 r
.63945 .41715 .64477 .42771 .65499 .41738 .6497 .40703 Metetra
.109 .582 0 r
.6497 .40703 .65499 .41738 .6652 .40706 .65995 .39691 Metetra
.04 .555 0 r
.65995 .39691 .6652 .40706 .67541 .39674 .67019 .38681 Metetra
0 .529 .022 r
.67019 .38681 .67541 .39674 .68561 .38643 .68043 .3767 Metetra
0 .503 .078 r
.68043 .3767 .68561 .38643 .69581 .37613 .69067 .3666 Metetra
0 .476 .129 r
.69067 .3666 .69581 .37613 .706 .36583 .7009 .35651 Metetra
0 .45 .173 r
.7009 .35651 .706 .36583 .71618 .35553 .71112 .34641 Metetra
0 .423 .211 r
.71112 .34641 .71618 .35553 .72636 .34524 .72134 .33632 Metetra
0 .397 .243 r
.72134 .33632 .72636 .34524 .73654 .33495 .73156 .32623 Metetra
0 .371 .269 r
.73156 .32623 .73654 .33495 .7467 .32467 .74177 .31615 Metetra
0 .344 .29 r
.74177 .31615 .7467 .32467 .75686 .31439 .75198 .30606 Metetra
0 .318 .304 r
.75198 .30606 .75686 .31439 .76702 .30411 .76218 .29598 Metetra
0 .271 .292 r
.76218 .29598 .76702 .30411 .77717 .29383 .77238 .2859 Metetra
0 .216 .265 r
.77238 .2859 .77717 .29383 .78731 .28356 .78257 .27581 Metetra
0 .167 .239 r
.78257 .27581 .78731 .28356 .79744 .27328 .79276 .26573 Metetra
0 .124 .212 r
.79276 .26573 .79744 .27328 .80757 .26302 .80294 .25565 Metetra
0 .088 .186 r
.80294 .25565 .80757 .26302 .8177 .2528 .81312 .24562 Metetra
0 .058 .16 r
.81312 .24562 .8177 .2528 .82785 .24284 .82332 .23584 Metetra
0 .035 .136 r
.82332 .23584 .82785 .24284 .83807 .2336 .83359 .22675 Metetra
0 .032 .132 r
.21791 .42973 .22382 .43524 .2321 .43668 .22621 .431 Metetra
0 .051 .153 r
.22621 .431 .2321 .43668 .24032 .43939 .23446 .4335 Metetra
0 .077 .178 r
.23446 .4335 .24032 .43939 .24857 .44245 .24273 .43634 Metetra
0 .111 .203 r
.24273 .43634 .24857 .44245 .25687 .44562 .25105 .43928 Metetra
0 .15 .228 r
.25105 .43928 .25687 .44562 .26523 .44882 .25943 .44225 Metetra
0 .195 .254 r
.25943 .44225 .26523 .44882 .27365 .45204 .26787 .44524 Metetra
0 .245 .28 r
.26787 .44524 .27365 .45204 .28213 .45528 .27637 .44824 Metetra
0 .302 .305 r
.27637 .44824 .28213 .45528 .29067 .45853 .28493 .45126 Metetra
0 .331 .298 r
.28493 .45126 .29067 .45853 .29928 .46181 .29355 .45431 Metetra
0 .356 .281 r
.29355 .45431 .29928 .46181 .30794 .46511 .30224 .45737 Metetra
0 .381 .26 r
.30224 .45737 .30794 .46511 .31668 .46844 .31098 .46045 Metetra
0 .407 .232 r
.31098 .46045 .31668 .46844 .32547 .47178 .3198 .46355 Metetra
0 .432 .199 r
.3198 .46355 .32547 .47178 .33433 .47515 .32867 .46667 Metetra
0 .458 .16 r
.32867 .46667 .33433 .47515 .34326 .47854 .33761 .46982 Metetra
0 .483 .116 r
.33761 .46982 .34326 .47854 .35225 .48196 .34662 .47298 Metetra
0 .509 .066 r
.34662 .47298 .35225 .48196 .36131 .4854 .35569 .47617 Metetra
0 .534 .01 r
.35569 .47617 .36131 .4854 .37044 .48887 .36483 .47938 Metetra
.051 .56 0 r
.36483 .47938 .37044 .48887 .37964 .49236 .37403 .48262 Metetra
.118 .585 0 r
.37403 .48262 .37964 .49236 .38891 .49588 .38331 .48588 Metetra
.191 .611 0 r
.38331 .48588 .38891 .49588 .39824 .49943 .39265 .48917 Metetra
.269 .636 0 r
.39265 .48917 .39824 .49943 .40765 .503 .40206 .49248 Metetra
.352 .661 0 r
.40206 .49248 .40765 .503 .41713 .50661 .41155 .49582 Metetra
.442 .687 0 r
.41155 .49582 .41713 .50661 .42668 .51025 .4211 .49919 Metetra
.537 .712 0 r
.4211 .49919 .42668 .51025 .43631 .51392 .43073 .50259 Metetra
.638 .738 0 r
.43073 .50259 .43631 .51392 .44601 .51762 .44043 .50601 Metetra
.744 .763 0 r
.44043 .50601 .44601 .51762 .45579 .52135 .45021 .50947 Metetra
.789 .722 0 r
.45021 .50947 .45579 .52135 .46564 .52511 .46006 .51295 Metetra
.814 .655 0 r
.46006 .51295 .46564 .52511 .47557 .52891 .46998 .51646 Metetra
.84 .583 0 r
.46998 .51646 .47557 .52891 .48557 .53273 .47999 .52 Metetra
.865 .505 0 r
.47999 .52 .48557 .53273 .49566 .53645 .49007 .52344 Metetra
.889 .427 0 r
.49007 .52344 .49566 .53645 .50583 .53965 .50023 .52637 Metetra
.904 .377 0 r
.50023 .52637 .50583 .53965 .51609 .53805 .51049 .52468 Metetra
.895 .407 0 r
.51049 .52468 .51609 .53805 .52639 .52872 .5208 .51555 Metetra
.872 .485 0 r
.5208 .51555 .52639 .52872 .53669 .51871 .53112 .50577 Metetra
.846 .563 0 r
.53112 .50577 .53669 .51871 .54699 .50853 .54143 .49583 Metetra
.821 .637 0 r
.54143 .49583 .54699 .50853 .55728 .49835 .55174 .48587 Metetra
.795 .706 0 r
.55174 .48587 .55728 .49835 .56757 .48817 .56205 .47592 Metetra
.77 .768 0 r
.56205 .47592 .56757 .48817 .57785 .478 .57235 .46598 Metetra
.664 .744 0 r
.57235 .46598 .57785 .478 .58813 .46784 .58265 .45604 Metetra
.561 .719 0 r
.58265 .45604 .58813 .46784 .5984 .45769 .59295 .44611 Metetra
.465 .693 0 r
.59295 .44611 .5984 .45769 .60867 .44754 .60324 .43619 Metetra
.374 .668 0 r
.60324 .43619 .60867 .44754 .61894 .4374 .61354 .42627 Metetra
.289 .642 0 r
.61354 .42627 .61894 .4374 .6292 .42727 .62383 .41636 Metetra
.209 .617 0 r
.62383 .41636 .6292 .42727 .63945 .41715 .63411 .40645 Metetra
.136 .591 0 r
.63411 .40645 .63945 .41715 .6497 .40703 .64439 .39655 Metetra
.067 .566 0 r
.64439 .39655 .6497 .40703 .65995 .39691 .65467 .38665 Metetra
.005 .54 0 r
.65467 .38665 .65995 .39691 .67019 .38681 .66495 .37675 Metetra
0 .515 .052 r
.66495 .37675 .67019 .38681 .68043 .3767 .67522 .36686 Metetra
0 .49 .104 r
.67522 .36686 .68043 .3767 .69067 .3666 .6855 .35697 Metetra
0 .464 .149 r
.6855 .35697 .69067 .3666 .7009 .35651 .69576 .34708 Metetra
0 .439 .19 r
.69576 .34708 .7009 .35651 .71112 .34641 .70603 .33719 Metetra
0 .413 .224 r
.70603 .33719 .71112 .34641 .72134 .33632 .71629 .32731 Metetra
0 .388 .253 r
.71629 .32731 .72134 .33632 .73156 .32623 .72655 .31742 Metetra
0 .362 .277 r
.72655 .31742 .73156 .32623 .74177 .31615 .73681 .30754 Metetra
0 .337 .294 r
.73681 .30754 .74177 .31615 .75198 .30606 .74706 .29765 Metetra
0 .311 .306 r
.74706 .29765 .75198 .30606 .76218 .29598 .75731 .28777 Metetra
0 .259 .286 r
.75731 .28777 .76218 .29598 .77238 .2859 .76755 .27788 Metetra
0 .207 .26 r
.76755 .27788 .77238 .2859 .78257 .27581 .7778 .268 Metetra
0 .161 .235 r
.7778 .268 .78257 .27581 .79276 .26573 .78804 .25811 Metetra
0 .12 .209 r
.78804 .25811 .79276 .26573 .80294 .25565 .79827 .24823 Metetra
0 .085 .184 r
.79827 .24823 .80294 .25565 .81312 .24562 .80851 .23839 Metetra
0 .056 .159 r
.80851 .23839 .81312 .24562 .82332 .23584 .81877 .22878 Metetra
0 .035 .136 r
.81877 .22878 .82332 .23584 .83359 .22675 .82909 .21985 Metetra
0 .031 .132 r
.21197 .42418 .21791 .42973 .22621 .431 .22029 .42529 Metetra
0 .049 .152 r
.22029 .42529 .22621 .431 .23446 .4335 .22856 .42758 Metetra
0 .075 .176 r
.22856 .42758 .23446 .4335 .24273 .43634 .23685 .4302 Metetra
0 .107 .2 r
.23685 .4302 .24273 .43634 .25105 .43928 .2452 .4329 Metetra
0 .144 .225 r
.2452 .4329 .25105 .43928 .25943 .44225 .2536 .43564 Metetra
0 .186 .249 r
.2536 .43564 .25943 .44225 .26787 .44524 .26206 .4384 Metetra
0 .234 .274 r
.26206 .4384 .26787 .44524 .27637 .44824 .27058 .44117 Metetra
0 .287 .299 r
.27058 .44117 .27637 .44824 .28493 .45126 .27916 .44395 Metetra
0 .323 .302 r
.27916 .44395 .28493 .45126 .29355 .45431 .2878 .44676 Metetra
0 .348 .287 r
.2878 .44676 .29355 .45431 .30224 .45737 .2965 .44958 Metetra
0 .372 .268 r
.2965 .44958 .30224 .45737 .31098 .46045 .30527 .45242 Metetra
0 .397 .244 r
.30527 .45242 .31098 .46045 .3198 .46355 .31409 .45527 Metetra
0 .421 .214 r
.31409 .45527 .3198 .46355 .32867 .46667 .32298 .45815 Metetra
0 .446 .179 r
.32298 .45815 .32867 .46667 .33761 .46982 .33194 .46104 Metetra
0 .47 .139 r
.33194 .46104 .33761 .46982 .34662 .47298 .34096 .46396 Metetra
0 .495 .093 r
.34096 .46396 .34662 .47298 .35569 .47617 .35004 .4669 Metetra
0 .52 .043 r
.35004 .4669 .35569 .47617 .36483 .47938 .35919 .46985 Metetra
.013 .544 0 r
.35919 .46985 .36483 .47938 .37403 .48262 .3684 .47283 Metetra
.074 .569 0 r
.3684 .47283 .37403 .48262 .38331 .48588 .37769 .47584 Metetra
.141 .593 0 r
.37769 .47584 .38331 .48588 .39265 .48917 .38704 .47886 Metetra
.212 .618 0 r
.38704 .47886 .39265 .48917 .40206 .49248 .39646 .48191 Metetra
.289 .642 0 r
.39646 .48191 .40206 .49248 .41155 .49582 .40595 .48498 Metetra
.371 .667 0 r
.40595 .48498 .41155 .49582 .4211 .49919 .41551 .48808 Metetra
.458 .691 0 r
.41551 .48808 .4211 .49919 .43073 .50259 .42514 .4912 Metetra
.551 .716 0 r
.42514 .4912 .43073 .50259 .44043 .50601 .43484 .49436 Metetra
.649 .741 0 r
.43484 .49436 .44043 .50601 .45021 .50947 .44461 .49753 Metetra
.752 .765 0 r
.44461 .49753 .45021 .50947 .46006 .51295 .45446 .50074 Metetra
.79 .719 0 r
.45446 .50074 .46006 .51295 .46998 .51646 .46439 .50397 Metetra
.814 .655 0 r
.46439 .50397 .46998 .51646 .47999 .52 .47439 .50721 Metetra
.839 .586 0 r
.47439 .50721 .47999 .52 .49007 .52344 .48446 .51037 Metetra
.862 .515 0 r
.48446 .51037 .49007 .52344 .50023 .52637 .49462 .51304 Metetra
.876 .471 0 r
.49462 .51304 .50023 .52637 .51049 .52468 .50488 .51127 Metetra
.868 .497 0 r
.50488 .51127 .51049 .52468 .5208 .51555 .5152 .50234 Metetra
.845 .568 0 r
.5152 .50234 .5208 .51555 .53112 .50577 .52553 .49278 Metetra
.821 .638 0 r
.52553 .49278 .53112 .50577 .54143 .49583 .53586 .48307 Metetra
.796 .704 0 r
.53586 .48307 .54143 .49583 .55174 .48587 .54619 .47334 Metetra
.771 .764 0 r
.54619 .47334 .55174 .48587 .56205 .47592 .55651 .46362 Metetra
.674 .747 0 r
.55651 .46362 .56205 .47592 .57235 .46598 .56684 .45391 Metetra
.575 .722 0 r
.56684 .45391 .57235 .46598 .58265 .45604 .57716 .4442 Metetra
.481 .698 0 r
.57716 .4442 .58265 .45604 .59295 .44611 .58748 .43449 Metetra
.392 .673 0 r
.58748 .43449 .59295 .44611 .60324 .43619 .5978 .42479 Metetra
.309 .648 0 r
.5978 .42479 .60324 .43619 .61354 .42627 .60812 .41509 Metetra
.231 .624 0 r
.60812 .41509 .61354 .42627 .62383 .41636 .61843 .4054 Metetra
.158 .599 0 r
.61843 .4054 .62383 .41636 .63411 .40645 .62875 .39571 Metetra
.09 .575 0 r
.62875 .39571 .63411 .40645 .64439 .39655 .63906 .38602 Metetra
.028 .55 0 r
.63906 .38602 .64439 .39655 .65467 .38665 .64937 .37633 Metetra
0 .526 .029 r
.64937 .37633 .65467 .38665 .66495 .37675 .65968 .36665 Metetra
0 .501 .081 r
.65968 .36665 .66495 .37675 .67522 .36686 .66999 .35696 Metetra
0 .477 .128 r
.66999 .35696 .67522 .36686 .6855 .35697 .6803 .34728 Metetra
0 .452 .169 r
.6803 .34728 .6855 .35697 .69576 .34708 .69061 .3376 Metetra
0 .427 .206 r
.69061 .3376 .69576 .34708 .70603 .33719 .70091 .32792 Metetra
0 .403 .237 r
.70091 .32792 .70603 .33719 .71629 .32731 .71121 .31824 Metetra
0 .378 .263 r
.71121 .31824 .71629 .32731 .72655 .31742 .72151 .30856 Metetra
0 .354 .283 r
.72151 .30856 .72655 .31742 .73681 .30754 .73181 .29888 Metetra
0 .329 .299 r
.73181 .29888 .73681 .30754 .74706 .29765 .74211 .28919 Metetra
0 .3 .305 r
.74211 .28919 .74706 .29765 .75731 .28777 .75241 .27951 Metetra
0 .246 .28 r
.75241 .27951 .75731 .28777 .76755 .27788 .7627 .26982 Metetra
0 .197 .255 r
.7627 .26982 .76755 .27788 .7778 .268 .773 .26013 Metetra
0 .154 .231 r
.773 .26013 .7778 .268 .78804 .25811 .78329 .25044 Metetra
0 .115 .206 r
.78329 .25044 .78804 .25811 .79827 .24823 .79358 .24075 Metetra
0 .082 .182 r
.79358 .24075 .79827 .24823 .80851 .23839 .80387 .2311 Metetra
0 .055 .158 r
.80387 .2311 .80851 .23839 .81877 .22878 .81418 .22168 Metetra
0 .034 .135 r
.81418 .22168 .81877 .22878 .82909 .21985 .82455 .21291 Metetra
0 .031 .131 r
.20599 .4186 .21197 .42418 .22029 .42529 .21433 .41954 Metetra
0 .048 .151 r
.21433 .41954 .22029 .42529 .22856 .42758 .22263 .42162 Metetra
0 .073 .174 r
.22263 .42162 .22856 .42758 .23685 .4302 .23094 .42401 Metetra
0 .103 .197 r
.23094 .42401 .23685 .4302 .2452 .4329 .23931 .42649 Metetra
0 .138 .221 r
.23931 .42649 .2452 .4329 .2536 .43564 .24773 .429 Metetra
0 .178 .245 r
.24773 .429 .2536 .43564 .26206 .4384 .25622 .43152 Metetra
0 .222 .268 r
.25622 .43152 .26206 .4384 .27058 .44117 .26476 .43405 Metetra
0 .272 .292 r
.26476 .43405 .27058 .44117 .27916 .44395 .27336 .4366 Metetra
0 .316 .305 r
.27336 .4366 .27916 .44395 .2878 .44676 .28202 .43917 Metetra
0 .339 .293 r
.28202 .43917 .2878 .44676 .2965 .44958 .29074 .44175 Metetra
0 .363 .276 r
.29074 .44175 .2965 .44958 .30527 .45242 .29952 .44434 Metetra
0 .387 .254 r
.29952 .44434 .30527 .45242 .31409 .45527 .30836 .44695 Metetra
0 .41 .228 r
.30836 .44695 .31409 .45527 .32298 .45815 .31727 .44958 Metetra
0 .434 .197 r
.31727 .44958 .32298 .45815 .33194 .46104 .32624 .45223 Metetra
0 .458 .16 r
.32624 .45223 .33194 .46104 .34096 .46396 .33527 .4549 Metetra
0 .481 .119 r
.33527 .4549 .34096 .46396 .35004 .4669 .34436 .45758 Metetra
0 .505 .073 r
.34436 .45758 .35004 .4669 .35919 .46985 .35352 .46028 Metetra
0 .529 .023 r
.35352 .46028 .35919 .46985 .3684 .47283 .36275 .463 Metetra
.033 .552 0 r
.36275 .463 .3684 .47283 .37769 .47584 .37204 .46575 Metetra
.093 .576 0 r
.37204 .46575 .37769 .47584 .38704 .47886 .3814 .46851 Metetra
.158 .599 0 r
.3814 .46851 .38704 .47886 .39646 .48191 .39083 .47129 Metetra
.229 .623 0 r
.39083 .47129 .39646 .48191 .40595 .48498 .40032 .4741 Metetra
.304 .647 0 r
.40032 .4741 .40595 .48498 .41551 .48808 .40989 .47693 Metetra
.383 .67 0 r
.40989 .47693 .41551 .48808 .42514 .4912 .41952 .47978 Metetra
.468 .694 0 r
.41952 .47978 .42514 .4912 .43484 .49436 .42923 .48266 Metetra
.558 .718 0 r
.42923 .48266 .43484 .49436 .44461 .49753 .439 .48556 Metetra
.653 .742 0 r
.439 .48556 .44461 .49753 .45446 .50074 .44885 .48849 Metetra
.752 .765 0 r
.44885 .48849 .45446 .50074 .46439 .50397 .45877 .49144 Metetra
.789 .721 0 r
.45877 .49144 .46439 .50397 .47439 .50721 .46877 .4944 Metetra
.812 .66 0 r
.46877 .4944 .47439 .50721 .48446 .51037 .47884 .49728 Metetra
.835 .598 0 r
.47884 .49728 .48446 .51037 .49462 .51304 .48899 .49968 Metetra
.848 .558 0 r
.48899 .49968 .49462 .51304 .50488 .51127 .49925 .49782 Metetra
.84 .582 0 r
.49925 .49782 .50488 .51127 .5152 .50234 .50959 .48909 Metetra
.818 .644 0 r
.50959 .48909 .5152 .50234 .52553 .49278 .51993 .47976 Metetra
.795 .706 0 r
.51993 .47976 .52553 .49278 .53586 .48307 .53027 .47028 Metetra
.771 .765 0 r
.53027 .47028 .53586 .48307 .54619 .47334 .54062 .46078 Metetra
.677 .747 0 r
.54062 .46078 .54619 .47334 .55651 .46362 .55096 .45128 Metetra
.581 .724 0 r
.55096 .45128 .55651 .46362 .56684 .45391 .5613 .44179 Metetra
.49 .7 0 r
.5613 .44179 .56684 .45391 .57716 .4442 .57165 .43231 Metetra
.404 .676 0 r
.57165 .43231 .57716 .4442 .58748 .43449 .58199 .42282 Metetra
.323 .653 0 r
.58199 .42282 .58748 .43449 .5978 .42479 .59233 .41334 Metetra
.247 .629 0 r
.59233 .41334 .5978 .42479 .60812 .41509 .60267 .40386 Metetra
.175 .605 0 r
.60267 .40386 .60812 .41509 .61843 .4054 .61302 .39439 Metetra
.109 .582 0 r
.61302 .39439 .61843 .4054 .62875 .39571 .62336 .38491 Metetra
.047 .558 0 r
.62336 .38491 .62875 .39571 .63906 .38602 .6337 .37544 Metetra
0 .534 .009 r
.6337 .37544 .63906 .38602 .64937 .37633 .64405 .36596 Metetra
0 .511 .061 r
.64405 .36596 .64937 .37633 .65968 .36665 .65439 .35649 Metetra
0 .487 .108 r
.65439 .35649 .65968 .36665 .66999 .35696 .66473 .34702 Metetra
0 .463 .151 r
.66473 .34702 .66999 .35696 .6803 .34728 .67508 .33755 Metetra
0 .44 .188 r
.67508 .33755 .6803 .34728 .69061 .3376 .68542 .32807 Metetra
0 .416 .221 r
.68542 .32807 .69061 .3376 .70091 .32792 .69576 .3186 Metetra
0 .393 .248 r
.69576 .3186 .70091 .32792 .71121 .31824 .70611 .30912 Metetra
0 .369 .271 r
.70611 .30912 .71121 .31824 .72151 .30856 .71645 .29964 Metetra
0 .345 .289 r
.71645 .29964 .72151 .30856 .73181 .29888 .72679 .29016 Metetra
0 .322 .302 r
.72679 .29016 .73181 .29888 .74211 .28919 .73714 .28068 Metetra
0 .285 .298 r
.73714 .28068 .74211 .28919 .75241 .27951 .74748 .2712 Metetra
0 .234 .274 r
.74748 .2712 .75241 .27951 .7627 .26982 .75782 .26171 Metetra
0 .188 .25 r
.75782 .26171 .7627 .26982 .773 .26013 .76816 .25222 Metetra
0 .147 .227 r
.76816 .25222 .773 .26013 .78329 .25044 .77851 .24272 Metetra
0 .111 .203 r
.77851 .24272 .78329 .25044 .79358 .24075 .78885 .23322 Metetra
0 .08 .179 r
.78885 .23322 .79358 .24075 .80387 .2311 .79919 .22377 Metetra
0 .054 .156 r
.79919 .22377 .80387 .2311 .81418 .22168 .80956 .21453 Metetra
0 .034 .135 r
.80956 .21453 .81418 .22168 .82455 .21291 .81999 .20591 Metetra
0 .031 .131 r
.19997 .41299 .20599 .4186 .21433 .41954 .20834 .41376 Metetra
0 .047 .15 r
.20834 .41376 .21433 .41954 .22263 .42162 .21666 .41562 Metetra
0 .07 .172 r
.21666 .41562 .22263 .42162 .23094 .42401 .225 .41779 Metetra
0 .099 .194 r
.225 .41779 .23094 .42401 .23931 .42649 .23339 .42004 Metetra
0 .132 .217 r
.23339 .42004 .23931 .42649 .24773 .429 .24184 .42231 Metetra
0 .169 .24 r
.24184 .42231 .24773 .429 .25622 .43152 .25034 .4246 Metetra
0 .211 .263 r
.25034 .4246 .25622 .43152 .26476 .43405 .2589 .4269 Metetra
0 .258 .285 r
.2589 .4269 .26476 .43405 .27336 .4366 .26753 .42921 Metetra
0 .308 .308 r
.26753 .42921 .27336 .4366 .28202 .43917 .27621 .43154 Metetra
0 .331 .298 r
.27621 .43154 .28202 .43917 .29074 .44175 .28494 .43388 Metetra
0 .354 .283 r
.28494 .43388 .29074 .44175 .29952 .44434 .29374 .43623 Metetra
0 .377 .264 r
.29374 .43623 .29952 .44434 .30836 .44695 .3026 .4386 Metetra
0 .399 .241 r
.3026 .4386 .30836 .44695 .31727 .44958 .31153 .44098 Metetra
0 .422 .213 r
.31153 .44098 .31727 .44958 .32624 .45223 .32051 .44338 Metetra
0 .445 .181 r
.32051 .44338 .32624 .45223 .33527 .4549 .32955 .44579 Metetra
0 .467 .144 r
.32955 .44579 .33527 .4549 .34436 .45758 .33866 .44822 Metetra
0 .49 .102 r
.33866 .44822 .34436 .45758 .35352 .46028 .34784 .45067 Metetra
0 .513 .057 r
.34784 .45067 .35352 .46028 .36275 .463 .35707 .45314 Metetra
0 .536 .006 r
.35707 .45314 .36275 .463 .37204 .46575 .36638 .45562 Metetra
.048 .558 0 r
.36638 .45562 .37204 .46575 .3814 .46851 .37574 .45812 Metetra
.108 .581 0 r
.37574 .45812 .3814 .46851 .39083 .47129 .38518 .46064 Metetra
.171 .604 0 r
.38518 .46064 .39083 .47129 .40032 .4741 .39468 .46318 Metetra
.24 .627 0 r
.39468 .46318 .40032 .4741 .40989 .47693 .40425 .46574 Metetra
.312 .649 0 r
.40425 .46574 .40989 .47693 .41952 .47978 .41389 .46833 Metetra
.39 .672 0 r
.41389 .46833 .41952 .47978 .42923 .48266 .4236 .47093 Metetra
.472 .695 0 r
.4236 .47093 .42923 .48266 .439 .48556 .43337 .47355 Metetra
.558 .718 0 r
.43337 .47355 .439 .48556 .44885 .48849 .44322 .4762 Metetra
.649 .741 0 r
.44322 .4762 .44885 .48849 .45877 .49144 .45314 .47887 Metetra
.744 .763 0 r
.45314 .47887 .45877 .49144 .46877 .4944 .46314 .48155 Metetra
.786 .729 0 r
.46314 .48155 .46877 .4944 .47884 .49728 .47321 .48415 Metetra
.808 .674 0 r
.47321 .48415 .47884 .49728 .48899 .49968 .48335 .48629 Metetra
.82 .639 0 r
.48335 .48629 .48899 .49968 .49925 .49782 .49361 .48434 Metetra
.813 .659 0 r
.49361 .48434 .49925 .49782 .50959 .48909 .50396 .47581 Metetra
.792 .715 0 r
.50396 .47581 .50959 .48909 .51993 .47976 .51431 .4667 Metetra
.769 .769 0 r
.51431 .4667 .51993 .47976 .53027 .47028 .52467 .45745 Metetra
.672 .746 0 r
.52467 .45745 .53027 .47028 .54062 .46078 .53503 .44818 Metetra
.58 .724 0 r
.53503 .44818 .54062 .46078 .55096 .45128 .54539 .43891 Metetra
.493 .701 0 r
.54539 .43891 .55096 .45128 .5613 .44179 .55575 .42964 Metetra
.41 .678 0 r
.55575 .42964 .5613 .44179 .57165 .43231 .56611 .42038 Metetra
.331 .655 0 r
.56611 .42038 .57165 .43231 .58199 .42282 .57648 .41111 Metetra
.257 .632 0 r
.57648 .41111 .58199 .42282 .59233 .41334 .58684 .40185 Metetra
.188 .61 0 r
.58684 .40185 .59233 .41334 .60267 .40386 .59721 .39259 Metetra
.123 .587 0 r
.59721 .39259 .60267 .40386 .61302 .39439 .60758 .38333 Metetra
.063 .564 0 r
.60758 .38333 .61302 .39439 .62336 .38491 .61795 .37407 Metetra
.007 .541 0 r
.61795 .37407 .62336 .38491 .6337 .37544 .62833 .36481 Metetra
0 .519 .045 r
.62833 .36481 .6337 .37544 .64405 .36596 .6387 .35555 Metetra
0 .496 .092 r
.6387 .35555 .64405 .36596 .65439 .35649 .64907 .34629 Metetra
0 .473 .134 r
.64907 .34629 .65439 .35649 .66473 .34702 .65945 .33703 Metetra
0 .45 .172 r
.65945 .33703 .66473 .34702 .67508 .33755 .66983 .32776 Metetra
0 .428 .205 r
.66983 .32776 .67508 .33755 .68542 .32807 .68021 .3185 Metetra
0 .405 .234 r
.68021 .3185 .68542 .32807 .69576 .3186 .69059 .30923 Metetra
0 .382 .259 r
.69059 .30923 .69576 .3186 .70611 .30912 .70098 .29996 Metetra
0 .359 .279 r
.70098 .29996 .70611 .30912 .71645 .29964 .71136 .29068 Metetra
0 .337 .294 r
.71136 .29068 .71645 .29964 .72679 .29016 .72175 .2814 Metetra
0 .314 .305 r
.72175 .2814 .72679 .29016 .73714 .28068 .73213 .27212 Metetra
0 .27 .291 r
.73213 .27212 .73714 .28068 .74748 .2712 .74252 .26284 Metetra
0 .222 .268 r
.74252 .26284 .74748 .2712 .75782 .26171 .75291 .25355 Metetra
0 .179 .245 r
.75291 .25355 .75782 .26171 .76816 .25222 .7633 .24425 Metetra
0 .141 .223 r
.7633 .24425 .76816 .25222 .77851 .24272 .7737 .23495 Metetra
0 .106 .2 r
.7737 .23495 .77851 .24272 .78885 .23322 .78409 .22565 Metetra
0 .077 .177 r
.78409 .22565 .78885 .23322 .79919 .22377 .79449 .21639 Metetra
0 .052 .155 r
.79449 .21639 .79919 .22377 .80956 .21453 .80491 .20733 Metetra
0 .033 .134 r
.80491 .20733 .80956 .21453 .81999 .20591 .81539 .19887 Metetra
0 .03 .13 r
.19392 .40734 .19997 .41299 .20834 .41376 .20231 .40794 Metetra
0 .046 .149 r
.20231 .40794 .20834 .41376 .21666 .41562 .21065 .40959 Metetra
0 .068 .17 r
.21065 .40959 .21666 .41562 .225 .41779 .21902 .41153 Metetra
0 .095 .191 r
.21902 .41153 .225 .41779 .23339 .42004 .22744 .41355 Metetra
0 .126 .213 r
.22744 .41355 .23339 .42004 .24184 .42231 .23591 .41559 Metetra
0 .161 .235 r
.23591 .41559 .24184 .42231 .25034 .4246 .24443 .41764 Metetra
0 .201 .257 r
.24443 .41764 .25034 .4246 .2589 .4269 .25302 .41971 Metetra
0 .244 .279 r
.25302 .41971 .2589 .4269 .26753 .42921 .26166 .42178 Metetra
0 .292 .301 r
.26166 .42178 .26753 .42921 .27621 .43154 .27036 .42387 Metetra
0 .323 .302 r
.27036 .42387 .27621 .43154 .28494 .43388 .27912 .42597 Metetra
0 .345 .29 r
.27912 .42597 .28494 .43388 .29374 .43623 .28794 .42808 Metetra
0 .366 .273 r
.28794 .42808 .29374 .43623 .3026 .4386 .29682 .4302 Metetra
0 .388 .253 r
.29682 .4302 .3026 .4386 .31153 .44098 .30576 .43233 Metetra
0 .41 .228 r
.30576 .43233 .31153 .44098 .32051 .44338 .31475 .43448 Metetra
0 .432 .199 r
.31475 .43448 .32051 .44338 .32955 .44579 .32382 .43665 Metetra
0 .454 .167 r
.32382 .43665 .32955 .44579 .33866 .44822 .33294 .43883 Metetra
0 .476 .13 r
.33294 .43883 .33866 .44822 .34784 .45067 .34212 .44102 Metetra
0 .497 .088 r
.34212 .44102 .34784 .45067 .35707 .45314 .35137 .44323 Metetra
0 .519 .043 r
.35137 .44323 .35707 .45314 .36638 .45562 .36069 .44545 Metetra
.006 .541 0 r
.36069 .44545 .36638 .45562 .37574 .45812 .37006 .44769 Metetra
.06 .563 0 r
.37006 .44769 .37574 .45812 .38518 .46064 .37951 .44995 Metetra
.117 .585 0 r
.37951 .44995 .38518 .46064 .39468 .46318 .38902 .45222 Metetra
.179 .607 0 r
.38902 .45222 .39468 .46318 .40425 .46574 .39859 .45452 Metetra
.245 .628 0 r
.39859 .45452 .40425 .46574 .41389 .46833 .40824 .45683 Metetra
.315 .65 0 r
.40824 .45683 .41389 .46833 .4236 .47093 .41795 .45916 Metetra
.39 .672 0 r
.41795 .45916 .4236 .47093 .43337 .47355 .42773 .46151 Metetra
.468 .694 0 r
.42773 .46151 .43337 .47355 .44322 .4762 .43758 .46388 Metetra
.551 .716 0 r
.43758 .46388 .44322 .4762 .45314 .47887 .4475 .46627 Metetra
.638 .738 0 r
.4475 .46627 .45314 .47887 .46314 .48155 .45749 .46866 Metetra
.728 .76 0 r
.45749 .46866 .46314 .48155 .47321 .48415 .46756 .47098 Metetra
.78 .743 0 r
.46756 .47098 .47321 .48415 .48335 .48629 .4777 .47286 Metetra
.793 .712 0 r
.4777 .47286 .48335 .48629 .49361 .48434 .48796 .47082 Metetra
.785 .731 0 r
.48796 .47082 .49361 .48434 .50396 .47581 .49832 .4625 Metetra
.751 .765 0 r
.49832 .4625 .50396 .47581 .51431 .4667 .50868 .45361 Metetra
.66 .743 0 r
.50868 .45361 .51431 .4667 .52467 .45745 .51905 .44458 Metetra
.572 .722 0 r
.51905 .44458 .52467 .45745 .53503 .44818 .52943 .43554 Metetra
.489 .7 0 r
.52943 .43554 .53503 .44818 .54539 .43891 .5398 .42649 Metetra
.409 .678 0 r
.5398 .42649 .54539 .43891 .55575 .42964 .55018 .41745 Metetra
.334 .656 0 r
.55018 .41745 .55575 .42964 .56611 .42038 .56056 .40841 Metetra
.262 .634 0 r
.56056 .40841 .56611 .42038 .57648 .41111 .57095 .39936 Metetra
.195 .612 0 r
.57095 .39936 .57648 .41111 .58684 .40185 .58134 .39032 Metetra
.132 .59 0 r
.58134 .39032 .58684 .40185 .59721 .39259 .59173 .38128 Metetra
.074 .568 0 r
.59173 .38128 .59721 .39259 .60758 .38333 .60212 .37223 Metetra
.019 .547 0 r
.60212 .37223 .60758 .38333 .61795 .37407 .61252 .36319 Metetra
0 .525 .031 r
.61252 .36319 .61795 .37407 .62833 .36481 .62292 .35414 Metetra
0 .503 .078 r
.62292 .35414 .62833 .36481 .6387 .35555 .63333 .34509 Metetra
0 .481 .12 r
.63333 .34509 .6387 .35555 .64907 .34629 .64373 .33604 Metetra
0 .459 .158 r
.64373 .33604 .64907 .34629 .65945 .33703 .65414 .32699 Metetra
0 .437 .192 r
.65414 .32699 .65945 .33703 .66983 .32776 .66456 .31793 Metetra
0 .415 .221 r
.66456 .31793 .66983 .32776 .68021 .3185 .67497 .30887 Metetra
0 .394 .247 r
.67497 .30887 .68021 .3185 .69059 .30923 .68539 .29981 Metetra
0 .372 .269 r
.68539 .29981 .69059 .30923 .70098 .29996 .69582 .29074 Metetra
0 .35 .286 r
.69582 .29074 .70098 .29996 .71136 .29068 .70624 .28167 Metetra
0 .328 .299 r
.70624 .28167 .71136 .29068 .72175 .2814 .71667 .27259 Metetra
0 .304 .306 r
.71667 .27259 .72175 .2814 .73213 .27212 .7271 .26351 Metetra
0 .256 .284 r
.7271 .26351 .73213 .27212 .74252 .26284 .73753 .25443 Metetra
0 .211 .262 r
.73753 .25443 .74252 .26284 .75291 .25355 .74797 .24533 Metetra
0 .171 .241 r
.74797 .24533 .75291 .25355 .7633 .24425 .75841 .23624 Metetra
0 .134 .219 r
.75841 .23624 .7633 .24425 .7737 .23495 .76885 .22713 Metetra
0 .102 .197 r
.76885 .22713 .7737 .23495 .78409 .22565 .7793 .21803 Metetra
0 .074 .175 r
.7793 .21803 .78409 .22565 .79449 .21639 .78975 .20896 Metetra
0 .051 .154 r
.78975 .20896 .79449 .21639 .80491 .20733 .80022 .20008 Metetra
0 .033 .134 r
.80022 .20008 .80491 .20733 .81539 .19887 .81076 .19178 Metetra
0 .03 .13 r
.18782 .40165 .19392 .40734 .20231 .40794 .19624 .40209 Metetra
0 .045 .148 r
.19624 .40209 .20231 .40794 .21065 .40959 .20461 .40352 Metetra
0 .066 .168 r
.20461 .40352 .21065 .40959 .21902 .41153 .213 .40524 Metetra
0 .091 .188 r
.213 .40524 .21902 .41153 .22744 .41355 .22145 .40703 Metetra
0 .12 .209 r
.22145 .40703 .22744 .41355 .23591 .41559 .22994 .40883 Metetra
0 .153 .23 r
.22994 .40883 .23591 .41559 .24443 .41764 .23849 .41065 Metetra
0 .19 .251 r
.23849 .41065 .24443 .41764 .25302 .41971 .2471 .41248 Metetra
0 .231 .272 r
.2471 .41248 .25302 .41971 .26166 .42178 .25577 .41431 Metetra
0 .275 .293 r
.25577 .41431 .26166 .42178 .27036 .42387 .26449 .41616 Metetra
0 .314 .305 r
.26449 .41616 .27036 .42387 .27912 .42597 .27327 .41801 Metetra
0 .335 .295 r
.27327 .41801 .27912 .42597 .28794 .42808 .28211 .41988 Metetra
0 .356 .281 r
.28211 .41988 .28794 .42808 .29682 .4302 .291 .42176 Metetra
0 .377 .264 r
.291 .42176 .29682 .4302 .30576 .43233 .29996 .42365 Metetra
0 .398 .242 r
.29996 .42365 .30576 .43233 .31475 .43448 .30897 .42555 Metetra
0 .419 .217 r
.30897 .42555 .31475 .43448 .32382 .43665 .31805 .42746 Metetra
0 .44 .188 r
.31805 .42746 .32382 .43665 .33294 .43883 .32719 .42939 Metetra
0 .461 .155 r
.32719 .42939 .33294 .43883 .34212 .44102 .33639 .43132 Metetra
0 .482 .118 r
.33639 .43132 .34212 .44102 .35137 .44323 .34565 .43328 Metetra
0 .503 .078 r
.34565 .43328 .35137 .44323 .36069 .44545 .35497 .43524 Metetra
0 .524 .033 r
.35497 .43524 .36069 .44545 .37006 .44769 .36436 .43722 Metetra
.015 .545 0 r
.36436 .43722 .37006 .44769 .37951 .44995 .37381 .43922 Metetra
.067 .566 0 r
.37381 .43922 .37951 .44995 .38902 .45222 .38333 .44123 Metetra
.122 .587 0 r
.38333 .44123 .38902 .45222 .39859 .45452 .39291 .44325 Metetra
.182 .608 0 r
.39291 .44325 .39859 .45452 .40824 .45683 .40256 .44529 Metetra
.245 .628 0 r
.40256 .44529 .40824 .45683 .41795 .45916 .41228 .44735 Metetra
.312 .649 0 r
.41228 .44735 .41795 .45916 .42773 .46151 .42206 .44943 Metetra
.383 .67 0 r
.42206 .44943 .42773 .46151 .43758 .46388 .43192 .45152 Metetra
.458 .691 0 r
.43192 .45152 .43758 .46388 .4475 .46627 .44184 .45363 Metetra
.537 .712 0 r
.44184 .45363 .4475 .46627 .45749 .46866 .45183 .45575 Metetra
.619 .733 0 r
.45183 .45575 .45749 .46866 .46756 .47098 .46189 .45778 Metetra
.7 .753 0 r
.46189 .45778 .46756 .47098 .4777 .47286 .47203 .4594 Metetra
.75 .765 0 r
.47203 .4594 .4777 .47286 .48796 .47082 .48229 .45728 Metetra
.721 .758 0 r
.48229 .45728 .48796 .47082 .49832 .4625 .49266 .44915 Metetra
.64 .738 0 r
.49266 .44915 .49832 .4625 .50868 .45361 .50303 .44048 Metetra
.557 .718 0 r
.50303 .44048 .50868 .45361 .51905 .44458 .51342 .43168 Metetra
.478 .697 0 r
.51342 .43168 .51905 .44458 .52943 .43554 .5238 .42286 Metetra
.402 .676 0 r
.5238 .42286 .52943 .43554 .5398 .42649 .5342 .41404 Metetra
.33 .655 0 r
.5342 .41404 .5398 .42649 .55018 .41745 .54459 .40522 Metetra
.262 .634 0 r
.54459 .40522 .55018 .41745 .56056 .40841 .55499 .3964 Metetra
.197 .613 0 r
.55499 .3964 .56056 .40841 .57095 .39936 .5654 .38757 Metetra
.137 .592 0 r
.5654 .38757 .57095 .39936 .58134 .39032 .57581 .37875 Metetra
.08 .571 0 r
.57581 .37875 .58134 .39032 .59173 .38128 .58622 .36992 Metetra
.027 .55 0 r
.58622 .36992 .59173 .38128 .60212 .37223 .59664 .36109 Metetra
0 .529 .022 r
.59664 .36109 .60212 .37223 .61252 .36319 .60707 .35226 Metetra
0 .508 .067 r
.60707 .35226 .61252 .36319 .62292 .35414 .6175 .34343 Metetra
0 .487 .109 r
.6175 .34343 .62292 .35414 .63333 .34509 .62793 .33459 Metetra
0 .466 .146 r
.62793 .33459 .63333 .34509 .64373 .33604 .63837 .32575 Metetra
0 .445 .18 r
.63837 .32575 .64373 .33604 .65414 .32699 .64881 .3169 Metetra
0 .424 .21 r
.64881 .3169 .65414 .32699 .66456 .31793 .65926 .30805 Metetra
0 .403 .236 r
.65926 .30805 .66456 .31793 .67497 .30887 .66971 .2992 Metetra
0 .382 .259 r
.66971 .2992 .67497 .30887 .68539 .29981 .68017 .29034 Metetra
0 .361 .277 r
.68017 .29034 .68539 .29981 .69582 .29074 .69063 .28148 Metetra
0 .34 .292 r
.69063 .28148 .69582 .29074 .70624 .28167 .70109 .27261 Metetra
0 .32 .303 r
.70109 .27261 .70624 .28167 .71667 .27259 .71156 .26374 Metetra
0 .287 .299 r
.71156 .26374 .71667 .27259 .7271 .26351 .72204 .25485 Metetra
0 .241 .278 r
.72204 .25485 .7271 .26351 .73753 .25443 .73252 .24597 Metetra
0 .2 .257 r
.73252 .24597 .73753 .25443 .74797 .24533 .743 .23707 Metetra
0 .162 .236 r
.743 .23707 .74797 .24533 .75841 .23624 .75349 .22817 Metetra
0 .128 .215 r
.75349 .22817 .75841 .23624 .76885 .22713 .76398 .21926 Metetra
0 .098 .194 r
.76398 .21926 .76885 .22713 .7793 .21803 .77448 .21035 Metetra
0 .072 .173 r
.77448 .21035 .7793 .21803 .78975 .20896 .78498 .20147 Metetra
0 .05 .152 r
.78498 .20147 .78975 .20896 .80022 .20008 .79551 .19278 Metetra
0 .033 .133 r
.79551 .19278 .80022 .20008 .81076 .19178 .80609 .18463 Metetra
0 .03 .13 r
.18169 .39593 .18782 .40165 .19624 .40209 .19014 .3962 Metetra
0 .044 .146 r
.19014 .3962 .19624 .40209 .20461 .40352 .19853 .39742 Metetra
0 .064 .166 r
.19853 .39742 .20461 .40352 .213 .40524 .20695 .3989 Metetra
0 .087 .186 r
.20695 .3989 .213 .40524 .22145 .40703 .21542 .40046 Metetra
0 .115 .206 r
.21542 .40046 .22145 .40703 .22994 .40883 .22394 .40203 Metetra
0 .146 .226 r
.22394 .40203 .22994 .40883 .23849 .41065 .23252 .40362 Metetra
0 .18 .246 r
.23252 .40362 .23849 .41065 .2471 .41248 .24115 .40521 Metetra
0 .218 .266 r
.24115 .40521 .2471 .41248 .25577 .41431 .24984 .4068 Metetra
0 .259 .286 r
.24984 .4068 .25577 .41431 .26449 .41616 .25858 .40841 Metetra
0 .304 .306 r
.25858 .40841 .26449 .41616 .27327 .41801 .26738 .41002 Metetra
0 .326 .3 r
.26738 .41002 .27327 .41801 .28211 .41988 .27624 .41165 Metetra
0 .346 .288 r
.27624 .41165 .28211 .41988 .291 .42176 .28516 .41328 Metetra
0 .366 .273 r
.28516 .41328 .291 .42176 .29996 .42365 .29413 .41492 Metetra
0 .386 .255 r
.29413 .41492 .29996 .42365 .30897 .42555 .30317 .41657 Metetra
0 .406 .233 r
.30317 .41657 .30897 .42555 .31805 .42746 .31226 .41823 Metetra
0 .426 .207 r
.31226 .41823 .31805 .42746 .32719 .42939 .32141 .41991 Metetra
0 .446 .178 r
.32141 .41991 .32719 .42939 .33639 .43132 .33063 .42159 Metetra
0 .466 .146 r
.33063 .42159 .33639 .43132 .34565 .43328 .3399 .42328 Metetra
0 .486 .11 r
.3399 .42328 .34565 .43328 .35497 .43524 .34924 .42499 Metetra
0 .506 .07 r
.34924 .42499 .35497 .43524 .36436 .43722 .35864 .42671 Metetra
0 .526 .028 r
.35864 .42671 .36436 .43722 .37381 .43922 .3681 .42844 Metetra
.019 .546 0 r
.3681 .42844 .37381 .43922 .38333 .44123 .37763 .43019 Metetra
.069 .566 0 r
.37763 .43019 .38333 .44123 .39291 .44325 .38722 .43195 Metetra
.122 .587 0 r
.38722 .43195 .39291 .44325 .40256 .44529 .39687 .43372 Metetra
.179 .607 0 r
.39687 .43372 .40256 .44529 .41228 .44735 .40659 .43551 Metetra
.24 .627 0 r
.40659 .43551 .41228 .44735 .42206 .44943 .41638 .43731 Metetra
.304 .647 0 r
.41638 .43731 .42206 .44943 .43192 .45152 .42624 .43913 Metetra
.371 .667 0 r
.42624 .43913 .43192 .45152 .44184 .45363 .43616 .44096 Metetra
.442 .687 0 r
.43616 .44096 .44184 .45363 .45183 .45575 .44615 .44279 Metetra
.516 .707 0 r
.44615 .44279 .45183 .45575 .46189 .45778 .45621 .44455 Metetra
.589 .726 0 r
.45621 .44455 .46189 .45778 .47203 .4594 .46635 .44591 Metetra
.634 .737 0 r
.46635 .44591 .47203 .4594 .48229 .45728 .47661 .4437 Metetra
.607 .73 0 r
.47661 .4437 .48229 .45728 .49266 .44915 .48698 .43577 Metetra
.535 .712 0 r
.48698 .43577 .49266 .44915 .50303 .44048 .49737 .42732 Metetra
.46 .692 0 r
.49737 .42732 .50303 .44048 .51342 .43168 .50777 .41874 Metetra
.388 .672 0 r
.50777 .41874 .51342 .43168 .5238 .42286 .51817 .41015 Metetra
.32 .652 0 r
.51817 .41015 .5238 .42286 .5342 .41404 .52857 .40155 Metetra
.255 .632 0 r
.52857 .40155 .5342 .41404 .54459 .40522 .53899 .39295 Metetra
.194 .612 0 r
.53899 .39295 .54459 .40522 .55499 .3964 .5494 .38434 Metetra
.136 .592 0 r
.5494 .38434 .55499 .3964 .5654 .38757 .55983 .37574 Metetra
.082 .571 0 r
.55983 .37574 .5654 .38757 .57581 .37875 .57026 .36713 Metetra
.031 .551 0 r
.57026 .36713 .57581 .37875 .58622 .36992 .5807 .35852 Metetra
0 .531 .016 r
.5807 .35852 .58622 .36992 .59664 .36109 .59114 .34991 Metetra
0 .511 .06 r
.59114 .34991 .59664 .36109 .60707 .35226 .60159 .34129 Metetra
0 .491 .1 r
.60159 .34129 .60707 .35226 .6175 .34343 .61205 .33266 Metetra
0 .471 .137 r
.61205 .33266 .6175 .34343 .62793 .33459 .62251 .32404 Metetra
0 .451 .171 r
.62251 .32404 .62793 .33459 .63837 .32575 .63298 .31541 Metetra
0 .431 .2 r
.63298 .31541 .63837 .32575 .64881 .3169 .64345 .30677 Metetra
0 .411 .227 r
.64345 .30677 .64881 .3169 .65926 .30805 .65393 .29813 Metetra
0 .391 .25 r
.65393 .29813 .65926 .30805 .66971 .2992 .66442 .28948 Metetra
0 .371 .269 r
.66442 .28948 .66971 .2992 .68017 .29034 .67491 .28083 Metetra
0 .351 .285 r
.67491 .28083 .68017 .29034 .69063 .28148 .68541 .27217 Metetra
0 .331 .298 r
.68541 .27217 .69063 .28148 .70109 .27261 .69592 .2635 Metetra
0 .311 .307 r
.69592 .2635 .70109 .27261 .71156 .26374 .70643 .25483 Metetra
0 .27 .291 r
.70643 .25483 .71156 .26374 .72204 .25485 .71695 .24615 Metetra
0 .228 .271 r
.71695 .24615 .72204 .25485 .73252 .24597 .72747 .23746 Metetra
0 .189 .251 r
.72747 .23746 .73252 .24597 .743 .23707 .738 .22876 Metetra
0 .154 .231 r
.738 .22876 .743 .23707 .75349 .22817 .74854 .22006 Metetra
0 .122 .211 r
.74854 .22006 .75349 .22817 .76398 .21926 .75908 .21134 Metetra
0 .094 .19 r
.75908 .21134 .76398 .21926 .77448 .21035 .76963 .20263 Metetra
0 .069 .17 r
.76963 .20263 .77448 .21035 .78498 .20147 .78018 .19394 Metetra
0 .048 .151 r
.78018 .19394 .78498 .20147 .79551 .19278 .79076 .18543 Metetra
0 .032 .133 r
.79076 .18543 .79551 .19278 .80609 .18463 .8014 .17744 Metetra
0 .029 .129 r
.17552 .39018 .18169 .39593 .19014 .3962 .18399 .39027 Metetra
0 .043 .145 r
.18399 .39027 .19014 .3962 .19853 .39742 .19242 .39127 Metetra
0 .061 .164 r
.19242 .39127 .19853 .39742 .20695 .3989 .20086 .39253 Metetra
0 .084 .183 r
.20086 .39253 .20695 .3989 .21542 .40046 .20936 .39386 Metetra
0 .109 .202 r
.20936 .39386 .21542 .40046 .22394 .40203 .21791 .3952 Metetra
0 .138 .221 r
.21791 .3952 .22394 .40203 .23252 .40362 .22651 .39654 Metetra
0 .17 .24 r
.22651 .39654 .23252 .40362 .24115 .40521 .23517 .39789 Metetra
0 .205 .259 r
.23517 .39789 .24115 .40521 .24984 .4068 .24388 .39925 Metetra
0 .243 .279 r
.24388 .39925 .24984 .4068 .25858 .40841 .25265 .40062 Metetra
0 .285 .298 r
.25265 .40062 .25858 .40841 .26738 .41002 .26147 .40199 Metetra
0 .317 .304 r
.26147 .40199 .26738 .41002 .27624 .41165 .27035 .40337 Metetra
0 .336 .295 r
.27035 .40337 .27624 .41165 .28516 .41328 .27929 .40476 Metetra
0 .355 .282 r
.27929 .40476 .28516 .41328 .29413 .41492 .28828 .40615 Metetra
0 .374 .266 r
.28828 .40615 .29413 .41492 .30317 .41657 .29733 .40755 Metetra
0 .393 .247 r
.29733 .40755 .30317 .41657 .31226 .41823 .30644 .40896 Metetra
0 .412 .225 r
.30644 .40896 .31226 .41823 .32141 .41991 .31561 .41038 Metetra
0 .432 .2 r
.31561 .41038 .32141 .41991 .33063 .42159 .32484 .41181 Metetra
0 .451 .171 r
.32484 .41181 .33063 .42159 .3399 .42328 .33413 .41325 Metetra
0 .47 .14 r
.33413 .41325 .3399 .42328 .34924 .42499 .34348 .4147 Metetra
0 .489 .105 r
.34348 .4147 .34924 .42499 .35864 .42671 .35289 .41616 Metetra
0 .508 .067 r
.35289 .41616 .35864 .42671 .3681 .42844 .36236 .41763 Metetra
0 .527 .026 r
.36236 .41763 .3681 .42844 .37763 .43019 .3719 .41911 Metetra
.019 .546 0 r
.3719 .41911 .37763 .43019 .38722 .43195 .3815 .4206 Metetra
.066 .566 0 r
.3815 .4206 .38722 .43195 .39687 .43372 .39116 .42211 Metetra
.117 .585 0 r
.39116 .42211 .39687 .43372 .40659 .43551 .40089 .42362 Metetra
.171 .604 0 r
.40089 .42362 .40659 .43551 .41638 .43731 .41068 .42515 Metetra
.228 .623 0 r
.41068 .42515 .41638 .43731 .42624 .43913 .42054 .42669 Metetra
.289 .642 0 r
.42054 .42669 .42624 .43913 .43616 .44096 .43047 .42825 Metetra
.352 .661 0 r
.43047 .42825 .43616 .44096 .44615 .44279 .44046 .4298 Metetra
.419 .68 0 r
.44046 .4298 .44615 .44279 .45621 .44455 .45052 .43129 Metetra
.484 .699 0 r
.45052 .43129 .45621 .44455 .46635 .44591 .46066 .43239 Metetra
.525 .709 0 r
.46066 .43239 .46635 .44591 .47661 .4437 .47092 .43009 Metetra
.501 .703 0 r
.47092 .43009 .47661 .4437 .48698 .43577 .4813 .42235 Metetra
.436 .685 0 r
.4813 .42235 .48698 .43577 .49737 .42732 .49169 .41412 Metetra
.369 .666 0 r
.49169 .41412 .49737 .42732 .50777 .41874 .5021 .40577 Metetra
.305 .647 0 r
.5021 .40577 .50777 .41874 .51817 .41015 .51251 .39739 Metetra
.243 .628 0 r
.51251 .39739 .51817 .41015 .52857 .40155 .52293 .38901 Metetra
.185 .609 0 r
.52293 .38901 .52857 .40155 .53899 .39295 .53336 .38063 Metetra
.13 .59 0 r
.53336 .38063 .53899 .39295 .5494 .38434 .5438 .37225 Metetra
.079 .57 0 r
.5438 .37225 .5494 .38434 .55983 .37574 .55424 .36386 Metetra
.03 .551 0 r
.55424 .36386 .55983 .37574 .57026 .36713 .56469 .35547 Metetra
0 .532 .015 r
.56469 .35547 .57026 .36713 .5807 .35852 .57515 .34707 Metetra
0 .513 .057 r
.57515 .34707 .5807 .35852 .59114 .34991 .58562 .33867 Metetra
0 .494 .096 r
.58562 .33867 .59114 .34991 .60159 .34129 .59609 .33027 Metetra
0 .475 .131 r
.59609 .33027 .60159 .34129 .61205 .33266 .60657 .32186 Metetra
0 .455 .164 r
.60657 .32186 .61205 .33266 .62251 .32404 .61706 .31344 Metetra
0 .436 .193 r
.61706 .31344 .62251 .32404 .63298 .31541 .62756 .30502 Metetra
0 .417 .219 r
.62756 .30502 .63298 .31541 .64345 .30677 .63807 .29659 Metetra
0 .398 .242 r
.63807 .29659 .64345 .30677 .65393 .29813 .64858 .28815 Metetra
0 .379 .262 r
.64858 .28815 .65393 .29813 .66442 .28948 .6591 .27971 Metetra
0 .36 .279 r
.6591 .27971 .66442 .28948 .67491 .28083 .66963 .27126 Metetra
0 .341 .292 r
.66963 .27126 .67491 .28083 .68541 .27217 .68017 .2628 Metetra
0 .322 .302 r
.68017 .2628 .68541 .27217 .69592 .2635 .69071 .25434 Metetra
0 .296 .302 r
.69071 .25434 .69592 .2635 .70643 .25483 .70126 .24587 Metetra
0 .253 .283 r
.70126 .24587 .70643 .25483 .71695 .24615 .71182 .23738 Metetra
0 .214 .264 r
.71182 .23738 .71695 .24615 .72747 .23746 .72239 .2289 Metetra
0 .178 .245 r
.72239 .2289 .72747 .23746 .738 .22876 .73297 .2204 Metetra
0 .146 .226 r
.73297 .2204 .738 .22876 .74854 .22006 .74355 .21189 Metetra
0 .116 .207 r
.74355 .21189 .74854 .22006 .75908 .21134 .75414 .20337 Metetra
0 .09 .187 r
.75414 .20337 .75908 .21134 .76963 .20263 .76474 .19485 Metetra
0 .067 .168 r
.76474 .19485 .76963 .20263 .78018 .19394 .77535 .18636 Metetra
0 .047 .15 r
.77535 .18636 .78018 .19394 .79076 .18543 .78598 .17803 Metetra
0 .032 .132 r
.78598 .17803 .79076 .18543 .8014 .17744 .79667 .1702 Metetra
0 .029 .129 r
.16931 .38439 .17552 .39018 .18399 .39027 .17781 .38431 Metetra
0 .042 .144 r
.17781 .38431 .18399 .39027 .19242 .39127 .18626 .38509 Metetra
0 .059 .162 r
.18626 .38509 .19242 .39127 .20086 .39253 .19474 .38613 Metetra
0 .08 .18 r
.19474 .38613 .20086 .39253 .20936 .39386 .20326 .38722 Metetra
0 .104 .198 r
.20326 .38722 .20936 .39386 .21791 .3952 .21184 .38832 Metetra
0 .131 .216 r
.21184 .38832 .21791 .3952 .22651 .39654 .22047 .38943 Metetra
0 .16 .235 r
.22047 .38943 .22651 .39654 .23517 .39789 .22915 .39054 Metetra
0 .193 .253 r
.22915 .39054 .23517 .39789 .24388 .39925 .23789 .39166 Metetra
0 .228 .271 r
.23789 .39166 .24388 .39925 .25265 .40062 .24668 .39279 Metetra
0 .266 .289 r
.24668 .39279 .25265 .40062 .26147 .40199 .25553 .39392 Metetra
0 .308 .308 r
.25553 .39392 .26147 .40199 .27035 .40337 .26443 .39505 Metetra
0 .326 .3 r
.26443 .39505 .27035 .40337 .27929 .40476 .27338 .39619 Metetra
0 .344 .29 r
.27338 .39619 .27929 .40476 .28828 .40615 .2824 .39734 Metetra
0 .362 .277 r
.2824 .39734 .28828 .40615 .29733 .40755 .29147 .39849 Metetra
0 .381 .26 r
.29147 .39849 .29733 .40755 .30644 .40896 .3006 .39965 Metetra
0 .399 .241 r
.3006 .39965 .30644 .40896 .31561 .41038 .30978 .40082 Metetra
0 .417 .22 r
.30978 .40082 .31561 .41038 .32484 .41181 .31903 .40199 Metetra
0 .435 .195 r
.31903 .40199 .32484 .41181 .33413 .41325 .32833 .40318 Metetra
0 .453 .167 r
.32833 .40318 .33413 .41325 .34348 .4147 .3377 .40437 Metetra
0 .472 .137 r
.3377 .40437 .34348 .4147 .35289 .41616 .34712 .40557 Metetra
0 .49 .103 r
.34712 .40557 .35289 .41616 .36236 .41763 .35661 .40677 Metetra
0 .508 .067 r
.35661 .40677 .36236 .41763 .3719 .41911 .36615 .40799 Metetra
0 .526 .028 r
.36615 .40799 .3719 .41911 .3815 .4206 .37576 .40922 Metetra
.014 .545 0 r
.37576 .40922 .3815 .4206 .39116 .42211 .38543 .41045 Metetra
.06 .563 0 r
.38543 .41045 .39116 .42211 .40089 .42362 .39517 .4117 Metetra
.107 .581 0 r
.39517 .4117 .40089 .42362 .41068 .42515 .40496 .41296 Metetra
.158 .599 0 r
.40496 .41296 .41068 .42515 .42054 .42669 .41483 .41423 Metetra
.212 .618 0 r
.41483 .41423 .42054 .42669 .43047 .42825 .42475 .4155 Metetra
.269 .636 0 r
.42475 .4155 .43047 .42825 .44046 .4298 .43475 .41678 Metetra
.328 .654 0 r
.43475 .41678 .44046 .4298 .45052 .43129 .44481 .41799 Metetra
.386 .671 0 r
.44481 .41799 .45052 .43129 .46066 .43239 .45495 .41883 Metetra
.422 .681 0 r
.45495 .41883 .46066 .43239 .47092 .43009 .46521 .41645 Metetra
.401 .675 0 r
.46521 .41645 .47092 .43009 .4813 .42235 .4756 .4089 Metetra
.343 .659 0 r
.4756 .4089 .4813 .42235 .49169 .41412 .486 .40089 Metetra
.283 .641 0 r
.486 .40089 .49169 .41412 .5021 .40577 .49642 .39276 Metetra
.226 .622 0 r
.49642 .39276 .5021 .40577 .51251 .39739 .50684 .3846 Metetra
.171 .604 0 r
.50684 .3846 .51251 .39739 .52293 .38901 .51727 .37644 Metetra
.12 .586 0 r
.51727 .37644 .52293 .38901 .53336 .38063 .52772 .36828 Metetra
.071 .567 0 r
.52772 .36828 .53336 .38063 .5438 .37225 .53817 .36012 Metetra
.025 .549 0 r
.53817 .36012 .5438 .37225 .55424 .36386 .54863 .35194 Metetra
0 .531 .017 r
.54863 .35194 .55424 .36386 .56469 .35547 .5591 .34377 Metetra
0 .513 .057 r
.5591 .34377 .56469 .35547 .57515 .34707 .56958 .33558 Metetra
0 .494 .094 r
.56958 .33558 .57515 .34707 .58562 .33867 .58007 .3274 Metetra
0 .476 .129 r
.58007 .3274 .58562 .33867 .59609 .33027 .59057 .3192 Metetra
0 .458 .16 r
.59057 .3192 .59609 .33027 .60657 .32186 .60108 .311 Metetra
0 .44 .188 r
.60108 .311 .60657 .32186 .61706 .31344 .61159 .30279 Metetra
0 .421 .214 r
.61159 .30279 .61706 .31344 .62756 .30502 .62212 .29458 Metetra
0 .403 .236 r
.62212 .29458 .62756 .30502 .63807 .29659 .63266 .28636 Metetra
0 .385 .256 r
.63266 .28636 .63807 .29659 .64858 .28815 .6432 .27813 Metetra
0 .367 .273 r
.6432 .27813 .64858 .28815 .6591 .27971 .65376 .26989 Metetra
0 .349 .287 r
.65376 .26989 .6591 .27971 .66963 .27126 .66432 .26164 Metetra
0 .33 .298 r
.66432 .26164 .66963 .27126 .68017 .2628 .6749 .25339 Metetra
0 .312 .306 r
.6749 .25339 .68017 .2628 .69071 .25434 .68548 .24513 Metetra
0 .276 .294 r
.68548 .24513 .69071 .25434 .70126 .24587 .69607 .23685 Metetra
0 .237 .276 r
.69607 .23685 .70126 .24587 .71182 .23738 .70667 .22857 Metetra
0 .201 .257 r
.70667 .22857 .71182 .23738 .72239 .2289 .71728 .22028 Metetra
0 .168 .239 r
.71728 .22028 .72239 .2289 .73297 .2204 .7279 .21198 Metetra
0 .138 .221 r
.7279 .21198 .73297 .2204 .74355 .21189 .73853 .20367 Metetra
0 .11 .203 r
.73853 .20367 .74355 .21189 .75414 .20337 .74917 .19535 Metetra
0 .086 .184 r
.74917 .19535 .75414 .20337 .76474 .19485 .75982 .18703 Metetra
0 .064 .166 r
.75982 .18703 .76474 .19485 .77535 .18636 .77048 .17872 Metetra
0 .046 .148 r
.77048 .17872 .77535 .18636 .78598 .17803 .78117 .17058 Metetra
0 .031 .132 r
.78117 .17058 .78598 .17803 .79667 .1702 .79191 .16291 Metetra
0 .029 .129 r
.16306 .37856 .16931 .38439 .17781 .38431 .17159 .37831 Metetra
0 .041 .143 r
.17159 .37831 .17781 .38431 .18626 .38509 .18007 .37888 Metetra
0 .057 .16 r
.18007 .37888 .18626 .38509 .19474 .38613 .18858 .37968 Metetra
0 .077 .177 r
.18858 .37968 .19474 .38613 .20326 .38722 .19713 .38053 Metetra
0 .099 .194 r
.19713 .38053 .20326 .38722 .21184 .38832 .20574 .3814 Metetra
0 .124 .212 r
.20574 .3814 .21184 .38832 .22047 .38943 .21439 .38228 Metetra
0 .151 .229 r
.21439 .38228 .22047 .38943 .22915 .39054 .2231 .38315 Metetra
0 .181 .246 r
.2231 .38315 .22915 .39054 .23789 .39166 .23186 .38403 Metetra
0 .213 .264 r
.23186 .38403 .23789 .39166 .24668 .39279 .24068 .38491 Metetra
0 .249 .281 r
.24068 .38491 .24668 .39279 .25553 .39392 .24955 .3858 Metetra
0 .286 .298 r
.24955 .3858 .25553 .39392 .26443 .39505 .25847 .38669 Metetra
0 .316 .305 r
.25847 .38669 .26443 .39505 .27338 .39619 .26745 .38758 Metetra
0 .333 .296 r
.26745 .38758 .27338 .39619 .2824 .39734 .27649 .38848 Metetra
0 .35 .286 r
.27649 .38848 .2824 .39734 .29147 .39849 .28558 .38939 Metetra
0 .368 .272 r
.28558 .38939 .29147 .39849 .3006 .39965 .29473 .3903 Metetra
0 .385 .256 r
.29473 .3903 .3006 .39965 .30978 .40082 .30393 .39121 Metetra
0 .402 .237 r
.30393 .39121 .30978 .40082 .31903 .40199 .31319 .39213 Metetra
0 .42 .216 r
.31319 .39213 .31903 .40199 .32833 .40318 .32251 .39306 Metetra
0 .437 .192 r
.32251 .39306 .32833 .40318 .3377 .40437 .33189 .39399 Metetra
0 .454 .166 r
.33189 .39399 .3377 .40437 .34712 .40557 .34133 .39493 Metetra
0 .472 .137 r
.34133 .39493 .34712 .40557 .35661 .40677 .35083 .39588 Metetra
0 .489 .105 r
.35083 .39588 .35661 .40677 .36615 .40799 .36038 .39683 Metetra
0 .506 .071 r
.36038 .39683 .36615 .40799 .37576 .40922 .37 .39779 Metetra
0 .524 .034 r
.37 .39779 .37576 .40922 .38543 .41045 .37968 .39876 Metetra
.006 .541 0 r
.37968 .39876 .38543 .41045 .39517 .4117 .38942 .39974 Metetra
.048 .558 0 r
.38942 .39974 .39517 .4117 .40496 .41296 .39923 .40073 Metetra
.093 .576 0 r
.39923 .40073 .40496 .41296 .41483 .41423 .4091 .40172 Metetra
.14 .593 0 r
.4091 .40172 .41483 .41423 .42475 .4155 .41903 .40272 Metetra
.19 .61 0 r
.41903 .40272 .42475 .4155 .43475 .41678 .42902 .40372 Metetra
.243 .628 0 r
.42902 .40372 .43475 .41678 .44481 .41799 .43909 .40465 Metetra
.295 .644 0 r
.43909 .40465 .44481 .41799 .45495 .41883 .44922 .40524 Metetra
.327 .654 0 r
.44922 .40524 .45495 .41883 .46521 .41645 .45949 .40277 Metetra
.308 .648 0 r
.45949 .40277 .46521 .41645 .4756 .4089 .46988 .39542 Metetra
.256 .632 0 r
.46988 .39542 .4756 .4089 .486 .40089 .48029 .38762 Metetra
.203 .615 0 r
.48029 .38762 .486 .40089 .49642 .39276 .49072 .37971 Metetra
.153 .597 0 r
.49072 .37971 .49642 .39276 .50684 .3846 .50115 .37177 Metetra
.105 .58 0 r
.50115 .37177 .50684 .3846 .51727 .37644 .5116 .36383 Metetra
.059 .563 0 r
.5116 .36383 .51727 .37644 .52772 .36828 .52205 .35589 Metetra
.016 .545 0 r
.52205 .35589 .52772 .36828 .53817 .36012 .53252 .34794 Metetra
0 .528 .024 r
.53252 .34794 .53817 .36012 .54863 .35194 .543 .33998 Metetra
0 .511 .062 r
.543 .33998 .54863 .35194 .5591 .34377 .55349 .33202 Metetra
0 .493 .097 r
.55349 .33202 .5591 .34377 .56958 .33558 .56399 .32405 Metetra
0 .476 .129 r
.56399 .32405 .56958 .33558 .58007 .3274 .5745 .31607 Metetra
0 .459 .159 r
.5745 .31607 .58007 .3274 .59057 .3192 .58502 .30809 Metetra
0 .441 .186 r
.58502 .30809 .59057 .3192 .60108 .311 .59555 .3001 Metetra
0 .424 .21 r
.59555 .3001 .60108 .311 .61159 .30279 .6061 .2921 Metetra
0 .407 .232 r
.6061 .2921 .61159 .30279 .62212 .29458 .61665 .28409 Metetra
0 .389 .252 r
.61665 .28409 .62212 .29458 .63266 .28636 .62722 .27607 Metetra
0 .372 .268 r
.62722 .27607 .63266 .28636 .6432 .27813 .6378 .26805 Metetra
0 .355 .282 r
.6378 .26805 .6432 .27813 .65376 .26989 .64838 .26002 Metetra
0 .337 .294 r
.64838 .26002 .65376 .26989 .66432 .26164 .65898 .25197 Metetra
0 .32 .303 r
.65898 .25197 .66432 .26164 .6749 .25339 .66959 .24392 Metetra
0 .296 .303 r
.66959 .24392 .6749 .25339 .68548 .24513 .68022 .23586 Metetra
0 .258 .285 r
.68022 .23586 .68548 .24513 .69607 .23685 .69085 .22779 Metetra
0 .222 .268 r
.69085 .22779 .69607 .23685 .70667 .22857 .70149 .21971 Metetra
0 .189 .251 r
.70149 .21971 .70667 .22857 .71728 .22028 .71215 .21162 Metetra
0 .158 .233 r
.71215 .21162 .71728 .22028 .7279 .21198 .72281 .20352 Metetra
0 .13 .216 r
.72281 .20352 .7279 .21198 .73853 .20367 .73349 .1954 Metetra
0 .105 .199 r
.73349 .1954 .73853 .20367 .74917 .19535 .74417 .18728 Metetra
0 .082 .181 r
.74417 .18728 .74917 .19535 .75982 .18703 .75487 .17915 Metetra
0 .062 .164 r
.75487 .17915 .75982 .18703 .77048 .17872 .76558 .17104 Metetra
0 .045 .147 r
.76558 .17104 .77048 .17872 .78117 .17058 .77632 .16307 Metetra
0 .031 .131 r
.77632 .16307 .78117 .17058 .79191 .16291 .78711 .15556 Metetra
0 .029 .128 r
.15678 .37269 .16306 .37856 .17159 .37831 .16533 .37227 Metetra
0 .04 .142 r
.16533 .37227 .17159 .37831 .18007 .37888 .17384 .37262 Metetra
0 .055 .158 r
.17384 .37262 .18007 .37888 .18858 .37968 .18238 .37319 Metetra
0 .073 .174 r
.18238 .37319 .18858 .37968 .19713 .38053 .19096 .37381 Metetra
0 .094 .19 r
.19096 .37381 .19713 .38053 .20574 .3814 .1996 .37445 Metetra
0 .117 .207 r
.1996 .37445 .20574 .3814 .21439 .38228 .20828 .37508 Metetra
0 .142 .223 r
.20828 .37508 .21439 .38228 .2231 .38315 .21702 .37572 Metetra
0 .169 .24 r
.21702 .37572 .2231 .38315 .23186 .38403 .22581 .37636 Metetra
0 .199 .256 r
.22581 .37636 .23186 .38403 .24068 .38491 .23465 .377 Metetra
0 .231 .273 r
.23465 .377 .24068 .38491 .24955 .3858 .24354 .37764 Metetra
0 .266 .289 r
.24354 .37764 .24955 .3858 .25847 .38669 .25249 .37829 Metetra
0 .303 .306 r
.25249 .37829 .25847 .38669 .26745 .38758 .26149 .37894 Metetra
0 .322 .302 r
.26149 .37894 .26745 .38758 .27649 .38848 .27055 .37959 Metetra
0 .338 .293 r
.27055 .37959 .27649 .38848 .28558 .38939 .27966 .38024 Metetra
0 .355 .282 r
.27966 .38024 .28558 .38939 .29473 .3903 .28883 .3809 Metetra
0 .371 .269 r
.28883 .3809 .29473 .3903 .30393 .39121 .29805 .38156 Metetra
0 .388 .253 r
.29805 .38156 .30393 .39121 .31319 .39213 .30733 .38223 Metetra
0 .404 .235 r
.30733 .38223 .31319 .39213 .32251 .39306 .31667 .3829 Metetra
0 .421 .215 r
.31667 .3829 .32251 .39306 .33189 .39399 .32606 .38358 Metetra
0 .437 .192 r
.32606 .38358 .33189 .39399 .34133 .39493 .33551 .38426 Metetra
0 .453 .167 r
.33551 .38426 .34133 .39493 .35083 .39588 .34502 .38494 Metetra
0 .47 .14 r
.34502 .38494 .35083 .39588 .36038 .39683 .35459 .38563 Metetra
0 .486 .11 r
.35459 .38563 .36038 .39683 .37 .39779 .36422 .38633 Metetra
0 .503 .078 r
.36422 .38633 .37 .39779 .37968 .39876 .37391 .38703 Metetra
0 .519 .044 r
.37391 .38703 .37968 .39876 .38942 .39974 .38366 .38774 Metetra
0 .536 .007 r
.38366 .38774 .38942 .39974 .39923 .40073 .39347 .38846 Metetra
.032 .552 0 r
.39347 .38846 .39923 .40073 .4091 .40172 .40335 .38918 Metetra
.074 .568 0 r
.40335 .38918 .4091 .40172 .41903 .40272 .41328 .3899 Metetra
.118 .585 0 r
.41328 .3899 .41903 .40272 .42902 .40372 .42328 .39063 Metetra
.164 .601 0 r
.42328 .39063 .42902 .40372 .43909 .40465 .43335 .39129 Metetra
.209 .617 0 r
.43335 .39129 .43909 .40465 .44922 .40524 .44349 .39162 Metetra
.237 .626 0 r
.44349 .39162 .44922 .40524 .45949 .40277 .45375 .38907 Metetra
.221 .621 0 r
.45375 .38907 .45949 .40277 .46988 .39542 .46415 .3819 Metetra
.175 .605 0 r
.46415 .3819 .46988 .39542 .48029 .38762 .47457 .37432 Metetra
.129 .589 0 r
.47457 .37432 .48029 .38762 .49072 .37971 .485 .36662 Metetra
.085 .573 0 r
.485 .36662 .49072 .37971 .50115 .37177 .49544 .35891 Metetra
.043 .556 0 r
.49544 .35891 .50115 .37177 .5116 .36383 .5059 .35118 Metetra
.003 .54 0 r
.5059 .35118 .5116 .36383 .52205 .35589 .51637 .34346 Metetra
0 .523 .035 r
.51637 .34346 .52205 .35589 .53252 .34794 .52685 .33572 Metetra
0 .507 .07 r
.52685 .33572 .53252 .34794 .543 .33998 .53735 .32798 Metetra
0 .49 .102 r
.53735 .32798 .543 .33998 .55349 .33202 .54785 .32023 Metetra
0 .474 .133 r
.54785 .32023 .55349 .33202 .56399 .32405 .55837 .31247 Metetra
0 .457 .161 r
.55837 .31247 .56399 .32405 .5745 .31607 .56891 .3047 Metetra
0 .441 .186 r
.56891 .3047 .5745 .31607 .58502 .30809 .57945 .29693 Metetra
0 .425 .21 r
.57945 .29693 .58502 .30809 .59555 .3001 .59001 .28915 Metetra
0 .408 .23 r
.59001 .28915 .59555 .3001 .6061 .2921 .60058 .28135 Metetra
0 .392 .249 r
.60058 .28135 .6061 .2921 .61665 .28409 .61116 .27355 Metetra
0 .375 .265 r
.61116 .27355 .61665 .28409 .62722 .27607 .62176 .26574 Metetra
0 .359 .279 r
.62176 .26574 .62722 .27607 .6378 .26805 .63236 .25792 Metetra
0 .342 .291 r
.63236 .25792 .6378 .26805 .64838 .26002 .64298 .2501 Metetra
0 .326 .3 r
.64298 .2501 .64838 .26002 .65898 .25197 .65362 .24226 Metetra
0 .31 .307 r
.65362 .24226 .65898 .25197 .66959 .24392 .66426 .23441 Metetra
0 .275 .293 r
.66426 .23441 .66959 .24392 .68022 .23586 .67492 .22655 Metetra
0 .24 .277 r
.67492 .22655 .68022 .23586 .69085 .22779 .68559 .21868 Metetra
0 .207 .26 r
.68559 .21868 .69085 .22779 .70149 .21971 .69628 .21079 Metetra
0 .176 .244 r
.69628 .21079 .70149 .21971 .71215 .21162 .70697 .2029 Metetra
0 .148 .227 r
.70697 .2029 .71215 .21162 .72281 .20352 .71768 .195 Metetra
0 .123 .211 r
.71768 .195 .72281 .20352 .73349 .1954 .72841 .18708 Metetra
0 .099 .194 r
.72841 .18708 .73349 .1954 .74417 .18728 .73914 .17915 Metetra
0 .078 .178 r
.73914 .17915 .74417 .18728 .75487 .17915 .74989 .17122 Metetra
0 .059 .162 r
.74989 .17122 .75487 .17915 .76558 .17104 .76065 .1633 Metetra
0 .043 .146 r
.76065 .1633 .76558 .17104 .77632 .16307 .77144 .15552 Metetra
0 .03 .131 r
.77144 .15552 .77632 .16307 .78711 .15556 .78228 .14816 Metetra
0 .028 .128 r
.15045 .36679 .15678 .37269 .16533 .37227 .15903 .36619 Metetra
0 .039 .141 r
.15903 .36619 .16533 .37227 .17384 .37262 .16757 .36633 Metetra
0 .053 .156 r
.16757 .36633 .17384 .37262 .18238 .37319 .17614 .36667 Metetra
0 .07 .171 r
.17614 .36667 .18238 .37319 .19096 .37381 .18476 .36705 Metetra
0 .089 .187 r
.18476 .36705 .19096 .37381 .1996 .37445 .19342 .36745 Metetra
0 .11 .202 r
.19342 .36745 .1996 .37445 .20828 .37508 .20214 .36785 Metetra
0 .133 .218 r
.20214 .36785 .20828 .37508 .21702 .37572 .2109 .36824 Metetra
0 .158 .233 r
.2109 .36824 .21702 .37572 .22581 .37636 .21972 .36864 Metetra
0 .185 .249 r
.21972 .36864 .22581 .37636 .23465 .377 .22858 .36904 Metetra
0 .215 .264 r
.22858 .36904 .23465 .377 .24354 .37764 .2375 .36944 Metetra
0 .246 .28 r
.2375 .36944 .24354 .37764 .25249 .37829 .24648 .36984 Metetra
0 .28 .295 r
.24648 .36984 .25249 .37829 .26149 .37894 .2555 .37024 Metetra
0 .311 .307 r
.2555 .37024 .26149 .37894 .27055 .37959 .26458 .37065 Metetra
0 .326 .3 r
.26458 .37065 .27055 .37959 .27966 .38024 .27372 .37105 Metetra
0 .342 .291 r
.27372 .37105 .27966 .38024 .28883 .3809 .2829 .37146 Metetra
0 .358 .28 r
.2829 .37146 .28883 .3809 .29805 .38156 .29215 .37187 Metetra
0 .373 .267 r
.29215 .37187 .29805 .38156 .30733 .38223 .30144 .37228 Metetra
0 .389 .252 r
.30144 .37228 .30733 .38223 .31667 .3829 .3108 .3727 Metetra
0 .404 .235 r
.3108 .3727 .31667 .3829 .32606 .38358 .32021 .37312 Metetra
0 .42 .216 r
.32021 .37312 .32606 .38358 .33551 .38426 .32968 .37354 Metetra
0 .435 .195 r
.32968 .37354 .33551 .38426 .34502 .38494 .3392 .37396 Metetra
0 .451 .172 r
.3392 .37396 .34502 .38494 .35459 .38563 .34878 .37439 Metetra
0 .466 .146 r
.34878 .37439 .35459 .38563 .36422 .38633 .35842 .37482 Metetra
0 .482 .118 r
.35842 .37482 .36422 .38633 .37391 .38703 .36812 .37526 Metetra
0 .497 .089 r
.36812 .37526 .37391 .38703 .38366 .38774 .37788 .3757 Metetra
0 .513 .057 r
.37788 .3757 .38366 .38774 .39347 .38846 .3877 .37615 Metetra
0 .528 .023 r
.3877 .37615 .39347 .38846 .40335 .38918 .39758 .3766 Metetra
.013 .544 0 r
.39758 .3766 .40335 .38918 .41328 .3899 .40752 .37705 Metetra
.051 .559 0 r
.40752 .37705 .41328 .3899 .42328 .39063 .41753 .3775 Metetra
.091 .575 0 r
.41753 .3775 .42328 .39063 .43335 .39129 .4276 .37788 Metetra
.13 .59 0 r
.4276 .37788 .43335 .39129 .44349 .39162 .43774 .37796 Metetra
.155 .598 0 r
.43774 .37796 .44349 .39162 .45375 .38907 .448 .37532 Metetra
.14 .593 0 r
.448 .37532 .45375 .38907 .46415 .3819 .4584 .36835 Metetra
.101 .579 0 r
.4584 .36835 .46415 .3819 .47457 .37432 .46883 .36098 Metetra
.061 .563 0 r
.46883 .36098 .47457 .37432 .485 .36662 .47927 .3535 Metetra
.022 .548 0 r
.47927 .3535 .485 .36662 .49544 .35891 .48972 .346 Metetra
0 .532 .014 r
.48972 .346 .49544 .35891 .5059 .35118 .50019 .33849 Metetra
0 .517 .049 r
.50019 .33849 .5059 .35118 .51637 .34346 .51067 .33098 Metetra
0 .501 .081 r
.51067 .33098 .51637 .34346 .52685 .33572 .52117 .32346 Metetra
0 .486 .111 r
.52117 .32346 .52685 .33572 .53735 .32798 .53168 .31593 Metetra
0 .47 .139 r
.53168 .31593 .53735 .32798 .54785 .32023 .5422 .30839 Metetra
0 .454 .165 r
.5422 .30839 .54785 .32023 .55837 .31247 .55274 .30084 Metetra
0 .439 .189 r
.55274 .30084 .55837 .31247 .56891 .3047 .56329 .29329 Metetra
0 .423 .211 r
.56329 .29329 .56891 .3047 .57945 .29693 .57386 .28572 Metetra
0 .408 .231 r
.57386 .28572 .57945 .29693 .59001 .28915 .58444 .27815 Metetra
0 .392 .248 r
.58444 .27815 .59001 .28915 .60058 .28135 .59503 .27056 Metetra
0 .377 .264 r
.59503 .27056 .60058 .28135 .61116 .27355 .60564 .26297 Metetra
0 .361 .277 r
.60564 .26297 .61116 .27355 .62176 .26574 .61627 .25536 Metetra
0 .346 .289 r
.61627 .25536 .62176 .26574 .63236 .25792 .6269 .24775 Metetra
0 .33 .298 r
.6269 .24775 .63236 .25792 .64298 .2501 .63756 .24012 Metetra
0 .315 .305 r
.63756 .24012 .64298 .2501 .65362 .24226 .64822 .23249 Metetra
0 .288 .299 r
.64822 .23249 .65362 .24226 .66426 .23441 .6589 .22484 Metetra
0 .254 .284 r
.6589 .22484 .66426 .23441 .67492 .22655 .6696 .21718 Metetra
0 .222 .268 r
.6696 .21718 .67492 .22655 .68559 .21868 .68031 .20951 Metetra
0 .192 .253 r
.68031 .20951 .68559 .21868 .69628 .21079 .69103 .20183 Metetra
0 .165 .237 r
.69103 .20183 .69628 .21079 .70697 .2029 .70177 .19413 Metetra
0 .139 .222 r
.70177 .19413 .70697 .2029 .71768 .195 .71253 .18642 Metetra
0 .115 .206 r
.71253 .18642 .71768 .195 .72841 .18708 .72329 .1787 Metetra
0 .094 .19 r
.72329 .1787 .72841 .18708 .73914 .17915 .73408 .17097 Metetra
0 .074 .175 r
.73408 .17097 .73914 .17915 .74989 .17122 .74487 .16323 Metetra
0 .057 .159 r
.74487 .16323 .74989 .17122 .76065 .1633 .75569 .15551 Metetra
0 .042 .144 r
.75569 .15551 .76065 .1633 .77144 .15552 .76652 .14791 Metetra
0 .03 .13 r
.76652 .14791 .77144 .15552 .78228 .14816 .77742 .14071 Metetra
0 .028 .127 r
.14408 .36085 .15045 .36679 .15903 .36619 .15269 .36007 Metetra
0 .038 .14 r
.15269 .36007 .15903 .36619 .16757 .36633 .16127 .35999 Metetra
0 .051 .154 r
.16127 .35999 .16757 .36633 .17614 .36667 .16987 .3601 Metetra
0 .067 .168 r
.16987 .3601 .17614 .36667 .18476 .36705 .17852 .36025 Metetra
0 .084 .183 r
.17852 .36025 .18476 .36705 .19342 .36745 .18721 .36041 Metetra
0 .103 .198 r
.18721 .36041 .19342 .36745 .20214 .36785 .19595 .36057 Metetra
0 .124 .212 r
.19595 .36057 .20214 .36785 .2109 .36824 .20475 .36073 Metetra
0 .147 .227 r
.20475 .36073 .2109 .36824 .21972 .36864 .21359 .36088 Metetra
0 .172 .241 r
.21359 .36088 .21972 .36864 .22858 .36904 .22249 .36104 Metetra
0 .199 .256 r
.22249 .36104 .22858 .36904 .2375 .36944 .23143 .3612 Metetra
0 .227 .271 r
.23143 .3612 .2375 .36944 .24648 .36984 .24043 .36135 Metetra
0 .258 .285 r
.24043 .36135 .24648 .36984 .2555 .37024 .24948 .36151 Metetra
0 .29 .3 r
.24948 .36151 .2555 .37024 .26458 .37065 .25859 .36166 Metetra
0 .315 .305 r
.25859 .36166 .26458 .37065 .27372 .37105 .26774 .36182 Metetra
0 .329 .299 r
.26774 .36182 .27372 .37105 .2829 .37146 .27695 .36198 Metetra
0 .344 .29 r
.27695 .36198 .2829 .37146 .29215 .37187 .28621 .36214 Metetra
0 .358 .28 r
.28621 .36214 .29215 .37187 .30144 .37228 .29553 .3623 Metetra
0 .373 .267 r
.29553 .3623 .30144 .37228 .3108 .3727 .3049 .36245 Metetra
0 .388 .253 r
.3049 .36245 .3108 .3727 .32021 .37312 .31433 .36262 Metetra
0 .402 .237 r
.31433 .36262 .32021 .37312 .32968 .37354 .32381 .36278 Metetra
0 .417 .22 r
.32381 .36278 .32968 .37354 .3392 .37396 .33335 .36294 Metetra
0 .431 .2 r
.33335 .36294 .3392 .37396 .34878 .37439 .34295 .36311 Metetra
0 .446 .179 r
.34295 .36311 .34878 .37439 .35842 .37482 .3526 .36328 Metetra
0 .461 .155 r
.3526 .36328 .35842 .37482 .36812 .37526 .36231 .36345 Metetra
0 .475 .13 r
.36231 .36345 .36812 .37526 .37788 .3757 .37208 .36362 Metetra
0 .49 .103 r
.37208 .36362 .37788 .3757 .3877 .37615 .38191 .3638 Metetra
0 .505 .074 r
.38191 .3638 .3877 .37615 .39758 .3766 .3918 .36398 Metetra
0 .519 .043 r
.3918 .36398 .39758 .3766 .40752 .37705 .40175 .36416 Metetra
0 .534 .01 r
.40175 .36416 .40752 .37705 .41753 .3775 .41176 .36433 Metetra
.024 .548 0 r
.41176 .36433 .41753 .3775 .4276 .37788 .42183 .36445 Metetra
.058 .562 0 r
.42183 .36445 .4276 .37788 .43774 .37796 .43197 .36427 Metetra
.079 .57 0 r
.43197 .36427 .43774 .37796 .448 .37532 .44224 .36155 Metetra
.067 .566 0 r
.44224 .36155 .448 .37532 .4584 .36835 .45264 .35476 Metetra
.033 .552 0 r
.45264 .35476 .4584 .36835 .46883 .36098 .46307 .3476 Metetra
0 .538 .002 r
.46307 .3476 .46883 .36098 .47927 .3535 .47352 .34034 Metetra
0 .523 .035 r
.47352 .34034 .47927 .3535 .48972 .346 .48398 .33305 Metetra
0 .508 .066 r
.48398 .33305 .48972 .346 .50019 .33849 .49446 .32576 Metetra
0 .494 .096 r
.49446 .32576 .50019 .33849 .51067 .33098 .50495 .31846 Metetra
0 .479 .123 r
.50495 .31846 .51067 .33098 .52117 .32346 .51546 .31115 Metetra
0 .464 .149 r
.51546 .31115 .52117 .32346 .53168 .31593 .52598 .30384 Metetra
0 .45 .173 r
.52598 .30384 .53168 .31593 .5422 .30839 .53652 .29651 Metetra
0 .435 .195 r
.53652 .29651 .5422 .30839 .55274 .30084 .54708 .28917 Metetra
0 .42 .215 r
.54708 .28917 .55274 .30084 .56329 .29329 .55765 .28183 Metetra
0 .406 .233 r
.55765 .28183 .56329 .29329 .57386 .28572 .56824 .27447 Metetra
0 .391 .25 r
.56824 .27447 .57386 .28572 .58444 .27815 .57884 .2671 Metetra
0 .377 .264 r
.57884 .2671 .58444 .27815 .59503 .27056 .58946 .25972 Metetra
0 .362 .277 r
.58946 .25972 .59503 .27056 .60564 .26297 .6001 .25233 Metetra
0 .347 .288 r
.6001 .25233 .60564 .26297 .61627 .25536 .61075 .24493 Metetra
0 .333 .297 r
.61075 .24493 .61627 .25536 .6269 .24775 .62142 .23752 Metetra
0 .318 .304 r
.62142 .23752 .6269 .24775 .63756 .24012 .6321 .2301 Metetra
0 .298 .304 r
.6321 .2301 .63756 .24012 .64822 .23249 .6428 .22266 Metetra
0 .265 .289 r
.6428 .22266 .64822 .23249 .6589 .22484 .65352 .21522 Metetra
0 .235 .274 r
.65352 .21522 .6589 .22484 .6696 .21718 .66425 .20776 Metetra
0 .206 .26 r
.66425 .20776 .6696 .21718 .68031 .20951 .675 .20029 Metetra
0 .179 .245 r
.675 .20029 .68031 .20951 .69103 .20183 .68576 .1928 Metetra
0 .153 .23 r
.68576 .1928 .69103 .20183 .70177 .19413 .69654 .18531 Metetra
0 .13 .216 r
.69654 .18531 .70177 .19413 .71253 .18642 .70734 .1778 Metetra
0 .108 .201 r
.70734 .1778 .71253 .18642 .72329 .1787 .71815 .17028 Metetra
0 .088 .186 r
.71815 .17028 .72329 .1787 .73408 .17097 .72898 .16274 Metetra
0 .071 .172 r
.72898 .16274 .73408 .17097 .74487 .16323 .73982 .15519 Metetra
0 .055 .157 r
.73982 .15519 .74487 .16323 .75569 .15551 .75069 .14766 Metetra
0 .041 .143 r
.75069 .14766 .75569 .15551 .76652 .14791 .76158 .14025 Metetra
0 .03 .13 r
.76158 .14025 .76652 .14791 .77742 .14071 .77252 .13321 Metetra
0 .028 .127 r
.13767 .35487 .14408 .36085 .15269 .36007 .14631 .35392 Metetra
0 .037 .138 r
.14631 .35392 .15269 .36007 .16127 .35999 .15492 .35362 Metetra
0 .049 .152 r
.15492 .35362 .16127 .35999 .16987 .3601 .16356 .35349 Metetra
0 .063 .165 r
.16356 .35349 .16987 .3601 .17852 .36025 .17224 .35341 Metetra
0 .079 .179 r
.17224 .35341 .17852 .36025 .18721 .36041 .18096 .35333 Metetra
0 .097 .193 r
.18096 .35333 .18721 .36041 .19595 .36057 .18974 .35325 Metetra
0 .116 .207 r
.18974 .35325 .19595 .36057 .20475 .36073 .19856 .35317 Metetra
0 .137 .22 r
.19856 .35317 .20475 .36073 .21359 .36088 .20744 .35308 Metetra
0 .159 .234 r
.20744 .35308 .21359 .36088 .22249 .36104 .21636 .353 Metetra
0 .183 .248 r
.21636 .353 .22249 .36104 .23143 .3612 .22533 .35291 Metetra
0 .209 .261 r
.22533 .35291 .23143 .3612 .24043 .36135 .23436 .35282 Metetra
0 .236 .275 r
.23436 .35282 .24043 .36135 .24948 .36151 .24343 .35273 Metetra
0 .265 .289 r
.24343 .35273 .24948 .36151 .25859 .36166 .25256 .35264 Metetra
0 .296 .303 r
.25256 .35264 .25859 .36166 .26774 .36182 .26174 .35254 Metetra
0 .316 .304 r
.26174 .35254 .26774 .36182 .27695 .36198 .27097 .35245 Metetra
0 .33 .298 r
.27097 .35245 .27695 .36198 .28621 .36214 .28026 .35236 Metetra
0 .344 .29 r
.28026 .35236 .28621 .36214 .29553 .3623 .28959 .35226 Metetra
0 .357 .28 r
.28959 .35226 .29553 .3623 .3049 .36245 .29898 .35217 Metetra
0 .371 .269 r
.29898 .35217 .3049 .36245 .31433 .36262 .30843 .35207 Metetra
0 .385 .256 r
.30843 .35207 .31433 .36262 .32381 .36278 .31793 .35198 Metetra
0 .399 .242 r
.31793 .35198 .32381 .36278 .33335 .36294 .32749 .35188 Metetra
0 .412 .225 r
.32749 .35188 .33335 .36294 .34295 .36311 .3371 .35178 Metetra
0 .426 .208 r
.3371 .35178 .34295 .36311 .3526 .36328 .34676 .35169 Metetra
0 .44 .188 r
.34676 .35169 .3526 .36328 .36231 .36345 .35649 .3516 Metetra
0 .454 .167 r
.35649 .3516 .36231 .36345 .37208 .36362 .36627 .3515 Metetra
0 .467 .144 r
.36627 .3515 .37208 .36362 .38191 .3638 .3761 .35141 Metetra
0 .481 .12 r
.3761 .35141 .38191 .3638 .3918 .36398 .386 .35132 Metetra
0 .495 .094 r
.386 .35132 .3918 .36398 .40175 .36416 .39595 .35123 Metetra
0 .508 .066 r
.39595 .35123 .40175 .36416 .41176 .36433 .40597 .35113 Metetra
0 .522 .037 r
.40597 .35113 .41176 .36433 .42183 .36445 .41604 .35097 Metetra
0 .535 .008 r
.41604 .35097 .42183 .36445 .43197 .36427 .42619 .35054 Metetra
.01 .543 0 r
.42619 .35054 .43197 .36427 .44224 .36155 .43646 .34774 Metetra
0 .538 .001 r
.43646 .34774 .44224 .36155 .45264 .35476 .44686 .34113 Metetra
0 .525 .03 r
.44686 .34113 .45264 .35476 .46307 .3476 .4573 .33418 Metetra
0 .512 .059 r
.4573 .33418 .46307 .3476 .47352 .34034 .46775 .32714 Metetra
0 .498 .087 r
.46775 .32714 .47352 .34034 .48398 .33305 .47822 .32007 Metetra
0 .484 .113 r
.47822 .32007 .48398 .33305 .49446 .32576 .48871 .31299 Metetra
0 .471 .138 r
.48871 .31299 .49446 .32576 .50495 .31846 .49921 .3059 Metetra
0 .457 .161 r
.49921 .3059 .50495 .31846 .51546 .31115 .50973 .29881 Metetra
0 .443 .183 r
.50973 .29881 .51546 .31115 .52598 .30384 .52027 .2917 Metetra
0 .429 .203 r
.52027 .2917 .52598 .30384 .53652 .29651 .53083 .28458 Metetra
0 .416 .221 r
.53083 .28458 .53652 .29651 .54708 .28917 .5414 .27745 Metetra
0 .402 .238 r
.5414 .27745 .54708 .28917 .55765 .28183 .55199 .27032 Metetra
0 .388 .253 r
.55199 .27032 .55765 .28183 .56824 .27447 .5626 .26317 Metetra
0 .375 .266 r
.5626 .26317 .56824 .27447 .57884 .2671 .57322 .256 Metetra
0 .361 .278 r
.57322 .256 .57884 .2671 .58946 .25972 .58387 .24883 Metetra
0 .347 .288 r
.58387 .24883 .58946 .25972 .6001 .25233 .59453 .24165 Metetra
0 .333 .296 r
.59453 .24165 .6001 .25233 .61075 .24493 .60521 .23445 Metetra
0 .32 .303 r
.60521 .23445 .61075 .24493 .62142 .23752 .6159 .22724 Metetra
0 .304 .306 r
.6159 .22724 .62142 .23752 .6321 .2301 .62662 .22002 Metetra
0 .273 .292 r
.62662 .22002 .6321 .2301 .6428 .22266 .63735 .21279 Metetra
0 .243 .279 r
.63735 .21279 .6428 .22266 .65352 .21522 .6481 .20554 Metetra
0 .216 .265 r
.6481 .20554 .65352 .21522 .66425 .20776 .65887 .19828 Metetra
0 .19 .251 r
.65887 .19828 .66425 .20776 .675 .20029 .66965 .19101 Metetra
0 .165 .237 r
.66965 .19101 .675 .20029 .68576 .1928 .68045 .18373 Metetra
0 .142 .224 r
.68045 .18373 .68576 .1928 .69654 .18531 .69127 .17643 Metetra
0 .121 .21 r
.69127 .17643 .69654 .18531 .70734 .1778 .70211 .16912 Metetra
0 .101 .196 r
.70211 .16912 .70734 .1778 .71815 .17028 .71297 .16179 Metetra
0 .083 .182 r
.71297 .16179 .71815 .17028 .72898 .16274 .72384 .15445 Metetra
0 .067 .169 r
.72384 .15445 .72898 .16274 .73982 .15519 .73474 .1471 Metetra
0 .052 .155 r
.73474 .1471 .73982 .15519 .75069 .14766 .74565 .13976 Metetra
0 .04 .142 r
.74565 .13976 .75069 .14766 .76158 .14025 .75659 .13253 Metetra
0 .029 .129 r
.75659 .13253 .76158 .14025 .77252 .13321 .76758 .12565 Metetra
0 .027 .127 r
.13122 .34885 .13767 .35487 .14631 .35392 .13989 .34773 Metetra
0 .036 .137 r
.13989 .34773 .14631 .35392 .15492 .35362 .14854 .3472 Metetra
0 .047 .15 r
.14854 .3472 .15492 .35362 .16356 .35349 .15721 .34685 Metetra
0 .06 .162 r
.15721 .34685 .16356 .35349 .17224 .35341 .16592 .34653 Metetra
0 .075 .175 r
.16592 .34653 .17224 .35341 .18096 .35333 .17468 .34621 Metetra
0 .091 .188 r
.17468 .34621 .18096 .35333 .18974 .35325 .18349 .34589 Metetra
0 .108 .201 r
.18349 .34589 .18974 .35325 .19856 .35317 .19234 .34557 Metetra
0 .127 .214 r
.19234 .34557 .19856 .35317 .20744 .35308 .20124 .34524 Metetra
0 .147 .227 r
.20124 .34524 .20744 .35308 .21636 .353 .2102 .34491 Metetra
0 .169 .239 r
.2102 .34491 .21636 .353 .22533 .35291 .2192 .34458 Metetra
0 .192 .252 r
.2192 .34458 .22533 .35291 .23436 .35282 .22825 .34424 Metetra
0 .216 .265 r
.22825 .34424 .23436 .35282 .24343 .35273 .23735 .34391 Metetra
0 .242 .278 r
.23735 .34391 .24343 .35273 .25256 .35264 .24651 .34357 Metetra
0 .269 .291 r
.24651 .34357 .25256 .35264 .26174 .35254 .25571 .34322 Metetra
0 .298 .303 r
.25571 .34322 .26174 .35254 .27097 .35245 .26496 .34288 Metetra
0 .316 .305 r
.26496 .34288 .27097 .35245 .28026 .35236 .27427 .34253 Metetra
0 .329 .299 r
.27427 .34253 .28026 .35236 .28959 .35226 .28363 .34218 Metetra
0 .342 .291 r
.28363 .34218 .28959 .35226 .29898 .35217 .29304 .34183 Metetra
0 .355 .282 r
.29304 .34183 .29898 .35217 .30843 .35207 .3025 .34148 Metetra
0 .368 .272 r
.3025 .34148 .30843 .35207 .31793 .35198 .31202 .34113 Metetra
0 .38 .261 r
.31202 .34113 .31793 .35198 .32749 .35188 .32159 .34077 Metetra
0 .393 .248 r
.32159 .34077 .32749 .35188 .3371 .35178 .33122 .34042 Metetra
0 .406 .233 r
.33122 .34042 .3371 .35178 .34676 .35169 .3409 .34006 Metetra
0 .419 .217 r
.3409 .34006 .34676 .35169 .35649 .3516 .35064 .3397 Metetra
0 .432 .2 r
.35064 .3397 .35649 .3516 .36627 .3515 .36043 .33934 Metetra
0 .444 .181 r
.36043 .33934 .36627 .3515 .3761 .35141 .37028 .33898 Metetra
0 .457 .161 r
.37028 .33898 .3761 .35141 .386 .35132 .38018 .33862 Metetra
0 .47 .139 r
.38018 .33862 .386 .35132 .39595 .35123 .39014 .33826 Metetra
0 .483 .116 r
.39014 .33826 .39595 .35123 .40597 .35113 .40017 .33789 Metetra
0 .496 .092 r
.40017 .33789 .40597 .35113 .41604 .35097 .41025 .33746 Metetra
0 .508 .068 r
.41025 .33746 .41604 .35097 .42619 .35054 .42039 .33678 Metetra
0 .515 .052 r
.42039 .33678 .42619 .35054 .43646 .34774 .43066 .33389 Metetra
0 .511 .061 r
.43066 .33389 .43646 .34774 .44686 .34113 .44107 .32747 Metetra
0 .499 .086 r
.44107 .32747 .44686 .34113 .4573 .33418 .45151 .32073 Metetra
0 .486 .11 r
.45151 .32073 .4573 .33418 .46775 .32714 .46197 .3139 Metetra
0 .473 .134 r
.46197 .3139 .46775 .32714 .47822 .32007 .47244 .30704 Metetra
0 .461 .156 r
.47244 .30704 .47822 .32007 .48871 .31299 .48294 .30018 Metetra
0 .448 .176 r
.48294 .30018 .48871 .31299 .49921 .3059 .49345 .2933 Metetra
0 .435 .195 r
.49345 .2933 .49921 .3059 .50973 .29881 .50399 .28642 Metetra
0 .422 .213 r
.50399 .28642 .50973 .29881 .52027 .2917 .51454 .27952 Metetra
0 .409 .229 r
.51454 .27952 .52027 .2917 .53083 .28458 .52511 .27261 Metetra
0 .396 .244 r
.52511 .27261 .53083 .28458 .5414 .27745 .5357 .26569 Metetra
0 .384 .257 r
.5357 .26569 .5414 .27745 .55199 .27032 .54631 .25876 Metetra
0 .371 .269 r
.54631 .25876 .55199 .27032 .5626 .26317 .55693 .25181 Metetra
0 .358 .28 r
.55693 .25181 .5626 .26317 .57322 .256 .56758 .24486 Metetra
0 .345 .289 r
.56758 .24486 .57322 .256 .58387 .24883 .57825 .23789 Metetra
0 .332 .297 r
.57825 .23789 .58387 .24883 .59453 .24165 .58893 .23091 Metetra
0 .319 .303 r
.58893 .23091 .59453 .24165 .60521 .23445 .59964 .22392 Metetra
0 .305 .307 r
.59964 .22392 .60521 .23445 .6159 .22724 .61036 .21691 Metetra
0 .276 .294 r
.61036 .21691 .6159 .22724 .62662 .22002 .6211 .20989 Metetra
0 .249 .281 r
.6211 .20989 .62662 .22002 .63735 .21279 .63187 .20286 Metetra
0 .222 .268 r
.63187 .20286 .63735 .21279 .6481 .20554 .64265 .19582 Metetra
0 .198 .255 r
.64265 .19582 .6481 .20554 .65887 .19828 .65345 .18876 Metetra
0 .174 .243 r
.65345 .18876 .65887 .19828 .66965 .19101 .66427 .18168 Metetra
0 .152 .23 r
.66427 .18168 .66965 .19101 .68045 .18373 .67511 .1746 Metetra
0 .132 .217 r
.67511 .1746 .68045 .18373 .69127 .17643 .68598 .1675 Metetra
0 .112 .204 r
.68598 .1675 .69127 .17643 .70211 .16912 .69686 .16038 Metetra
0 .095 .191 r
.69686 .16038 .70211 .16912 .71297 .16179 .70776 .15325 Metetra
0 .078 .178 r
.70776 .15325 .71297 .16179 .72384 .15445 .71868 .14611 Metetra
0 .064 .166 r
.71868 .14611 .72384 .15445 .73474 .1471 .72962 .13895 Metetra
0 .05 .153 r
.72962 .13895 .73474 .1471 .74565 .13976 .74058 .1318 Metetra
0 .038 .14 r
.74058 .1318 .74565 .13976 .75659 .13253 .75157 .12476 Metetra
0 .029 .129 r
.75157 .12476 .75659 .13253 .76758 .12565 .76261 .11804 Metetra
0 .027 .126 r
.12473 .34279 .13122 .34885 .13989 .34773 .13343 .34149 Metetra
0 .035 .136 r
.13343 .34149 .13989 .34773 .14854 .3472 .14211 .34075 Metetra
0 .045 .148 r
.14211 .34075 .14854 .3472 .15721 .34685 .15082 .34016 Metetra
0 .057 .16 r
.15082 .34016 .15721 .34685 .16592 .34653 .15956 .3396 Metetra
0 .07 .171 r
.15956 .3396 .16592 .34653 .17468 .34621 .16836 .33905 Metetra
0 .085 .183 r
.16836 .33905 .17468 .34621 .18349 .34589 .1772 .33849 Metetra
0 .1 .195 r
.1772 .33849 .18349 .34589 .19234 .34557 .18608 .33792 Metetra
0 .117 .207 r
.18608 .33792 .19234 .34557 .20124 .34524 .19502 .33735 Metetra
0 .135 .219 r
.19502 .33735 .20124 .34524 .2102 .34491 .204 .33678 Metetra
0 .154 .231 r
.204 .33678 .2102 .34491 .2192 .34458 .21303 .3362 Metetra
0 .175 .243 r
.21303 .3362 .2192 .34458 .22825 .34424 .22211 .33562 Metetra
0 .197 .255 r
.22211 .33562 .22825 .34424 .23735 .34391 .23124 .33504 Metetra
0 .22 .267 r
.23124 .33504 .23735 .34391 .24651 .34357 .24042 .33445 Metetra
0 .244 .279 r
.24042 .33445 .24651 .34357 .25571 .34322 .24965 .33386 Metetra
0 .269 .291 r
.24965 .33386 .25571 .34322 .26496 .34288 .25893 .33326 Metetra
0 .296 .303 r
.25893 .33326 .26496 .34288 .27427 .34253 .26826 .33266 Metetra
0 .314 .305 r
.26826 .33266 .27427 .34253 .28363 .34218 .27764 .33206 Metetra
0 .326 .3 r
.27764 .33206 .28363 .34218 .29304 .34183 .28707 .33146 Metetra
0 .338 .293 r
.28707 .33146 .29304 .34183 .3025 .34148 .29655 .33085 Metetra
0 .35 .286 r
.29655 .33085 .3025 .34148 .31202 .34113 .30609 .33024 Metetra
0 .362 .277 r
.30609 .33024 .31202 .34113 .32159 .34077 .31568 .32963 Metetra
0 .374 .267 r
.31568 .32963 .32159 .34077 .33122 .34042 .32532 .32901 Metetra
0 .386 .255 r
.32532 .32901 .33122 .34042 .3409 .34006 .33502 .32839 Metetra
0 .398 .242 r
.33502 .32839 .3409 .34006 .35064 .3397 .34477 .32777 Metetra
0 .41 .229 r
.34477 .32777 .35064 .3397 .36043 .33934 .35457 .32714 Metetra
0 .422 .213 r
.35457 .32714 .36043 .33934 .37028 .33898 .36443 .32652 Metetra
0 .434 .197 r
.36443 .32652 .37028 .33898 .38018 .33862 .37435 .32589 Metetra
0 .446 .179 r
.37435 .32589 .38018 .33862 .39014 .33826 .38432 .32526 Metetra
0 .457 .161 r
.38432 .32526 .39014 .33826 .40017 .33789 .39435 .32462 Metetra
0 .469 .141 r
.39435 .32462 .40017 .33789 .41025 .33746 .40443 .32392 Metetra
0 .481 .121 r
.40443 .32392 .41025 .33746 .42039 .33678 .41458 .32299 Metetra
0 .487 .108 r
.41458 .32299 .42039 .33678 .43066 .33389 .42486 .32002 Metetra
0 .483 .116 r
.42486 .32002 .43066 .33389 .44107 .32747 .43527 .31378 Metetra
0 .472 .136 r
.43527 .31378 .44107 .32747 .45151 .32073 .44571 .30724 Metetra
0 .46 .156 r
.44571 .30724 .45151 .32073 .46197 .3139 .45617 .30062 Metetra
0 .449 .175 r
.45617 .30062 .46197 .3139 .47244 .30704 .46665 .29398 Metetra
0 .437 .193 r
.46665 .29398 .47244 .30704 .48294 .30018 .47715 .28732 Metetra
0 .425 .209 r
.47715 .28732 .48294 .30018 .49345 .2933 .48767 .28066 Metetra
0 .413 .225 r
.48767 .28066 .49345 .2933 .50399 .28642 .49822 .27398 Metetra
0 .401 .239 r
.49822 .27398 .50399 .28642 .51454 .27952 .50878 .26729 Metetra
0 .389 .252 r
.50878 .26729 .51454 .27952 .52511 .27261 .51937 .26059 Metetra
0 .377 .264 r
.51937 .26059 .52511 .27261 .5357 .26569 .52997 .25388 Metetra
0 .365 .274 r
.52997 .25388 .5357 .26569 .54631 .25876 .5406 .24715 Metetra
0 .353 .284 r
.5406 .24715 .54631 .25876 .55693 .25181 .55124 .24041 Metetra
0 .341 .292 r
.55124 .24041 .55693 .25181 .56758 .24486 .56191 .23366 Metetra
0 .329 .298 r
.56191 .23366 .56758 .24486 .57825 .23789 .5726 .2269 Metetra
0 .317 .304 r
.5726 .2269 .57825 .23789 .58893 .23091 .58331 .22012 Metetra
0 .303 .306 r
.58331 .22012 .58893 .23091 .59964 .22392 .59404 .21333 Metetra
0 .276 .294 r
.59404 .21333 .59964 .22392 .61036 .21691 .60479 .20653 Metetra
0 .25 .282 r
.60479 .20653 .61036 .21691 .6211 .20989 .61556 .19971 Metetra
0 .225 .27 r
.61556 .19971 .6211 .20989 .63187 .20286 .62636 .19288 Metetra
0 .202 .258 r
.62636 .19288 .63187 .20286 .64265 .19582 .63717 .18603 Metetra
0 .18 .246 r
.63717 .18603 .64265 .19582 .65345 .18876 .64801 .17918 Metetra
0 .159 .234 r
.64801 .17918 .65345 .18876 .66427 .18168 .65887 .1723 Metetra
0 .14 .222 r
.65887 .1723 .66427 .18168 .67511 .1746 .66974 .16541 Metetra
0 .121 .21 r
.66974 .16541 .67511 .1746 .68598 .1675 .68065 .15851 Metetra
0 .104 .198 r
.68065 .15851 .68598 .1675 .69686 .16038 .69157 .15159 Metetra
0 .088 .186 r
.69157 .15159 .69686 .16038 .70776 .15325 .70251 .14466 Metetra
0 .074 .174 r
.70251 .14466 .70776 .15325 .71868 .14611 .71348 .13771 Metetra
0 .06 .162 r
.71348 .13771 .71868 .14611 .72962 .13895 .72446 .13075 Metetra
0 .048 .151 r
.72446 .13075 .72962 .13895 .74058 .1318 .73547 .12379 Metetra
0 .037 .139 r
.73547 .12379 .74058 .1318 .75157 .12476 .74651 .11693 Metetra
0 .028 .128 r
.74651 .11693 .75157 .12476 .76261 .11804 .7576 .11037 Metetra
0 .027 .126 r
.11819 .33669 .12473 .34279 .13343 .34149 .12693 .33522 Metetra
0 .034 .135 r
.12693 .33522 .13343 .34149 .14211 .34075 .13564 .33426 Metetra
0 .043 .146 r
.13564 .33426 .14211 .34075 .15082 .34016 .14439 .33343 Metetra
0 .054 .157 r
.14439 .33343 .15082 .34016 .15956 .3396 .15317 .33264 Metetra
0 .066 .168 r
.15317 .33264 .15956 .3396 .16836 .33905 .162 .33184 Metetra
0 .079 .179 r
.162 .33184 .16836 .33905 .1772 .33849 .17087 .33104 Metetra
0 .093 .19 r
.17087 .33104 .1772 .33849 .18608 .33792 .17979 .33023 Metetra
0 .108 .201 r
.17979 .33023 .18608 .33792 .19502 .33735 .18876 .32942 Metetra
0 .124 .212 r
.18876 .32942 .19502 .33735 .204 .33678 .19777 .3286 Metetra
0 .141 .223 r
.19777 .3286 .204 .33678 .21303 .3362 .20683 .32778 Metetra
0 .159 .234 r
.20683 .32778 .21303 .3362 .22211 .33562 .21594 .32696 Metetra
0 .178 .245 r
.21594 .32696 .22211 .33562 .23124 .33504 .2251 .32613 Metetra
0 .198 .256 r
.2251 .32613 .23124 .33504 .24042 .33445 .23431 .32529 Metetra
0 .22 .267 r
.23431 .32529 .24042 .33445 .24965 .33386 .24356 .32445 Metetra
0 .242 .278 r
.24356 .32445 .24965 .33386 .25893 .33326 .25286 .3236 Metetra
0 .265 .289 r
.25286 .3236 .25893 .33326 .26826 .33266 .26222 .32275 Metetra
0 .29 .3 r
.26222 .32275 .26826 .33266 .27764 .33206 .27162 .3219 Metetra
0 .311 .307 r
.27162 .3219 .27764 .33206 .28707 .33146 .28107 .32104 Metetra
0 .322 .302 r
.28107 .32104 .28707 .33146 .29655 .33085 .29058 .32017 Metetra
0 .333 .297 r
.29058 .32017 .29655 .33085 .30609 .33024 .30013 .31931 Metetra
0 .344 .29 r
.30013 .31931 .30609 .33024 .31568 .32963 .30974 .31843 Metetra
0 .355 .282 r
.30974 .31843 .31568 .32963 .32532 .32901 .3194 .31756 Metetra
0 .366 .274 r
.3194 .31756 .32532 .32901 .33502 .32839 .32911 .31668 Metetra
0 .377 .264 r
.32911 .31668 .33502 .32839 .34477 .32777 .33888 .31579 Metetra
0 .388 .253 r
.33888 .31579 .34477 .32777 .35457 .32714 .3487 .3149 Metetra
0 .399 .241 r
.3487 .3149 .35457 .32714 .36443 .32652 .35857 .31401 Metetra
0 .41 .228 r
.35857 .31401 .36443 .32652 .37435 .32589 .36849 .31311 Metetra
0 .421 .214 r
.36849 .31311 .37435 .32589 .38432 .32526 .37847 .31221 Metetra
0 .432 .199 r
.37847 .31221 .38432 .32526 .39435 .32462 .38851 .3113 Metetra
0 .443 .183 r
.38851 .3113 .39435 .32462 .40443 .32392 .3986 .31034 Metetra
0 .453 .167 r
.3986 .31034 .40443 .32392 .41458 .32299 .40876 .30916 Metetra
0 .459 .157 r
.40876 .30916 .41458 .32299 .42486 .32002 .41904 .3061 Metetra
0 .456 .163 r
.41904 .3061 .42486 .32002 .43527 .31378 .42945 .30005 Metetra
0 .446 .179 r
.42945 .30005 .43527 .31378 .44571 .30724 .43989 .29372 Metetra
0 .435 .195 r
.43989 .29372 .44571 .30724 .45617 .30062 .45035 .28731 Metetra
0 .424 .211 r
.45035 .28731 .45617 .30062 .46665 .29398 .46084 .28087 Metetra
0 .413 .225 r
.46084 .28087 .46665 .29398 .47715 .28732 .47135 .27443 Metetra
0 .402 .238 r
.47135 .27443 .47715 .28732 .48767 .28066 .48188 .26797 Metetra
0 .391 .25 r
.48188 .26797 .48767 .28066 .49822 .27398 .49243 .2615 Metetra
0 .38 .261 r
.49243 .2615 .49822 .27398 .50878 .26729 .50301 .25502 Metetra
0 .369 .271 r
.50301 .25502 .50878 .26729 .51937 .26059 .5136 .24853 Metetra
0 .358 .28 r
.5136 .24853 .51937 .26059 .52997 .25388 .52422 .24202 Metetra
0 .347 .288 r
.52422 .24202 .52997 .25388 .5406 .24715 .53486 .2355 Metetra
0 .336 .295 r
.53486 .2355 .5406 .24715 .55124 .24041 .54553 .22897 Metetra
0 .325 .301 r
.54553 .22897 .55124 .24041 .56191 .23366 .55622 .22242 Metetra
0 .314 .306 r
.55622 .22242 .56191 .23366 .5726 .2269 .56693 .21586 Metetra
0 .296 .303 r
.56693 .21586 .5726 .2269 .58331 .22012 .57766 .20928 Metetra
0 .271 .292 r
.57766 .20928 .58331 .22012 .59404 .21333 .58841 .2027 Metetra
0 .248 .281 r
.58841 .2027 .59404 .21333 .60479 .20653 .59919 .19609 Metetra
0 .225 .27 r
.59919 .19609 .60479 .20653 .61556 .19971 .60999 .18948 Metetra
0 .203 .259 r
.60999 .18948 .61556 .19971 .62636 .19288 .62082 .18284 Metetra
0 .183 .248 r
.62082 .18284 .62636 .19288 .63717 .18603 .63166 .1762 Metetra
0 .164 .237 r
.63166 .1762 .63717 .18603 .64801 .17918 .64253 .16954 Metetra
0 .145 .225 r
.64253 .16954 .64801 .17918 .65887 .1723 .65343 .16286 Metetra
0 .128 .214 r
.65343 .16286 .65887 .1723 .66974 .16541 .66434 .15617 Metetra
0 .112 .203 r
.66434 .15617 .66974 .16541 .68065 .15851 .67528 .14947 Metetra
0 .096 .192 r
.67528 .14947 .68065 .15851 .69157 .15159 .68624 .14275 Metetra
0 .082 .181 r
.68624 .14275 .69157 .15159 .70251 .14466 .69723 .13601 Metetra
0 .069 .17 r
.69723 .13601 .70251 .14466 .71348 .13771 .70824 .12926 Metetra
0 .057 .159 r
.70824 .12926 .71348 .13771 .72446 .13075 .71927 .12249 Metetra
0 .046 .148 r
.71927 .12249 .72446 .13075 .73547 .12379 .73033 .11573 Metetra
0 .036 .138 r
.73033 .11573 .73547 .12379 .74651 .11693 .74142 .10905 Metetra
0 .028 .128 r
.74142 .10905 .74651 .11693 .7576 .11037 .75256 .10265 Metetra
0 .027 .126 r
.11161 .33056 .11819 .33669 .12693 .33522 .12039 .32891 Metetra
0 .033 .134 r
.12039 .32891 .12693 .33522 .13564 .33426 .12914 .32772 Metetra
0 .042 .144 r
.12914 .32772 .13564 .33426 .14439 .33343 .13792 .32666 Metetra
0 .051 .154 r
.13792 .32666 .14439 .33343 .15317 .33264 .14674 .32563 Metetra
0 .062 .164 r
.14674 .32563 .15317 .33264 .162 .33184 .1556 .32459 Metetra
0 .073 .174 r
.1556 .32459 .162 .33184 .17087 .33104 .16451 .32355 Metetra
0 .085 .184 r
.16451 .32355 .17087 .33104 .17979 .33023 .17346 .3225 Metetra
0 .099 .194 r
.17346 .3225 .17979 .33023 .18876 .32942 .18246 .32145 Metetra
0 .113 .204 r
.18246 .32145 .18876 .32942 .19777 .3286 .19151 .32039 Metetra
0 .128 .214 r
.19151 .32039 .19777 .3286 .20683 .32778 .2006 .31932 Metetra
0 .144 .225 r
.2006 .31932 .20683 .32778 .21594 .32696 .20974 .31825 Metetra
0 .16 .235 r
.20974 .31825 .21594 .32696 .2251 .32613 .21893 .31717 Metetra
0 .178 .245 r
.21893 .31717 .2251 .32613 .23431 .32529 .22816 .31608 Metetra
0 .197 .255 r
.22816 .31608 .23431 .32529 .24356 .32445 .23744 .31499 Metetra
0 .216 .265 r
.23744 .31499 .24356 .32445 .25286 .3236 .24677 .3139 Metetra
0 .236 .275 r
.24677 .3139 .25286 .3236 .26222 .32275 .25615 .31279 Metetra
0 .257 .285 r
.25615 .31279 .26222 .32275 .27162 .3219 .26558 .31169 Metetra
0 .279 .295 r
.26558 .31169 .27162 .3219 .28107 .32104 .27505 .31057 Metetra
0 .302 .305 r
.27505 .31057 .28107 .32104 .29058 .32017 .28458 .30945 Metetra
0 .315 .305 r
.28458 .30945 .29058 .32017 .30013 .31931 .29416 .30833 Metetra
0 .326 .3 r
.29416 .30833 .30013 .31931 .30974 .31843 .30378 .3072 Metetra
0 .336 .295 r
.30378 .3072 .30974 .31843 .3194 .31756 .31346 .30606 Metetra
0 .346 .289 r
.31346 .30606 .3194 .31756 .32911 .31668 .32319 .30492 Metetra
0 .356 .282 r
.32319 .30492 .32911 .31668 .33888 .31579 .33297 .30377 Metetra
0 .366 .274 r
.33297 .30377 .33888 .31579 .3487 .3149 .3428 .30262 Metetra
0 .376 .265 r
.3428 .30262 .3487 .3149 .35857 .31401 .35269 .30146 Metetra
0 .386 .255 r
.35269 .30146 .35857 .31401 .36849 .31311 .36262 .3003 Metetra
0 .396 .244 r
.36262 .3003 .36849 .31311 .37847 .31221 .37261 .29913 Metetra
0 .406 .232 r
.37261 .29913 .37847 .31221 .38851 .3113 .38266 .29795 Metetra
0 .417 .22 r
.38266 .29795 .38851 .3113 .3986 .31034 .39276 .29673 Metetra
0 .426 .208 r
.39276 .29673 .3986 .31034 .40876 .30916 .40292 .29529 Metetra
0 .432 .2 r
.40292 .29529 .40876 .30916 .41904 .3061 .4132 .29215 Metetra
0 .428 .204 r
.4132 .29215 .41904 .3061 .42945 .30005 .42361 .28628 Metetra
0 .419 .217 r
.42361 .28628 .42945 .30005 .43989 .29372 .43405 .28015 Metetra
0 .409 .229 r
.43405 .28015 .43989 .29372 .45035 .28731 .44452 .27395 Metetra
0 .399 .241 r
.44452 .27395 .45035 .28731 .46084 .28087 .45501 .26773 Metetra
0 .389 .252 r
.45501 .26773 .46084 .28087 .47135 .27443 .46552 .26149 Metetra
0 .379 .262 r
.46552 .26149 .47135 .27443 .48188 .26797 .47606 .25524 Metetra
0 .369 .271 r
.47606 .25524 .48188 .26797 .49243 .2615 .48662 .24898 Metetra
0 .358 .28 r
.48662 .24898 .49243 .2615 .50301 .25502 .49721 .2427 Metetra
0 .348 .287 r
.49721 .2427 .50301 .25502 .5136 .24853 .50782 .23642 Metetra
0 .338 .293 r
.50782 .23642 .5136 .24853 .52422 .24202 .51845 .23011 Metetra
0 .328 .299 r
.51845 .23011 .52422 .24202 .53486 .2355 .52911 .2238 Metetra
0 .318 .304 r
.52911 .2238 .53486 .2355 .54553 .22897 .53979 .21747 Metetra
0 .308 .308 r
.53979 .21747 .54553 .22897 .55622 .22242 .5505 .21112 Metetra
0 .285 .298 r
.5505 .21112 .55622 .22242 .56693 .21586 .56123 .20476 Metetra
0 .263 .288 r
.56123 .20476 .56693 .21586 .57766 .20928 .57198 .19839 Metetra
0 .241 .278 r
.57198 .19839 .57766 .20928 .58841 .2027 .58276 .19201 Metetra
0 .221 .267 r
.58276 .19201 .58841 .2027 .59919 .19609 .59356 .1856 Metetra
0 .201 .257 r
.59356 .1856 .59919 .19609 .60999 .18948 .60439 .17919 Metetra
0 .183 .247 r
.60439 .17919 .60999 .18948 .62082 .18284 .61525 .17276 Metetra
0 .165 .237 r
.61525 .17276 .62082 .18284 .63166 .1762 .62612 .16631 Metetra
0 .148 .227 r
.62612 .16631 .63166 .1762 .64253 .16954 .63703 .15985 Metetra
0 .132 .217 r
.63703 .15985 .64253 .16954 .65343 .16286 .64795 .15337 Metetra
0 .116 .207 r
.64795 .15337 .65343 .16286 .66434 .15617 .65891 .14688 Metetra
0 .102 .197 r
.65891 .14688 .66434 .15617 .67528 .14947 .66989 .14037 Metetra
0 .089 .187 r
.66989 .14037 .67528 .14947 .68624 .14275 .68089 .13384 Metetra
0 .076 .176 r
.68089 .13384 .68624 .14275 .69723 .13601 .69192 .1273 Metetra
0 .064 .166 r
.69192 .1273 .69723 .13601 .70824 .12926 .70297 .12074 Metetra
0 .054 .156 r
.70297 .12074 .70824 .12926 .71927 .12249 .71405 .11417 Metetra
0 .044 .146 r
.71405 .11417 .71927 .12249 .73033 .11573 .72516 .10761 Metetra
0 .035 .136 r
.72516 .10761 .73033 .11573 .74142 .10905 .73629 .10111 Metetra
0 .028 .127 r
.73629 .10111 .74142 .10905 .75256 .10265 .74748 .09487 Metetra
0 .026 .125 r
.10499 .32438 .11161 .33056 .12039 .32891 .1138 .32255 Metetra
0 .032 .133 r
.1138 .32255 .12039 .32891 .12914 .32772 .12259 .32115 Metetra
0 .04 .142 r
.12259 .32115 .12914 .32772 .13792 .32666 .13141 .31985 Metetra
0 .048 .151 r
.13141 .31985 .13792 .32666 .14674 .32563 .14026 .31858 Metetra
0 .058 .16 r
.14026 .31858 .14674 .32563 .1556 .32459 .14917 .3173 Metetra
0 .068 .169 r
.14917 .3173 .1556 .32459 .16451 .32355 .15811 .31601 Metetra
0 .079 .178 r
.15811 .31601 .16451 .32355 .17346 .3225 .1671 .31472 Metetra
0 .09 .188 r
.1671 .31472 .17346 .3225 .18246 .32145 .17613 .31343 Metetra
0 .102 .197 r
.17613 .31343 .18246 .32145 .19151 .32039 .18521 .31212 Metetra
0 .115 .206 r
.18521 .31212 .19151 .32039 .2006 .31932 .19434 .31081 Metetra
0 .129 .215 r
.19434 .31081 .2006 .31932 .20974 .31825 .20351 .30949 Metetra
0 .144 .225 r
.20351 .30949 .20974 .31825 .21893 .31717 .21272 .30816 Metetra
0 .159 .234 r
.21272 .30816 .21893 .31717 .22816 .31608 .22199 .30683 Metetra
0 .175 .243 r
.22199 .30683 .22816 .31608 .23744 .31499 .2313 .30549 Metetra
0 .191 .252 r
.2313 .30549 .23744 .31499 .24677 .3139 .24065 .30414 Metetra
0 .209 .261 r
.24065 .30414 .24677 .3139 .25615 .31279 .25006 .30279 Metetra
0 .227 .271 r
.25006 .30279 .25615 .31279 .26558 .31169 .25951 .30143 Metetra
0 .246 .28 r
.25951 .30143 .26558 .31169 .27505 .31057 .26901 .30006 Metetra
0 .265 .289 r
.26901 .30006 .27505 .31057 .28458 .30945 .27856 .29869 Metetra
0 .286 .298 r
.27856 .29869 .28458 .30945 .29416 .30833 .28815 .29731 Metetra
0 .307 .307 r
.28815 .29731 .29416 .30833 .30378 .3072 .2978 .29592 Metetra
0 .317 .304 r
.2978 .29592 .30378 .3072 .31346 .30606 .3075 .29452 Metetra
0 .326 .3 r
.3075 .29452 .31346 .30606 .32319 .30492 .31724 .29312 Metetra
0 .335 .295 r
.31724 .29312 .32319 .30492 .33297 .30377 .32704 .29171 Metetra
0 .344 .29 r
.32704 .29171 .33297 .30377 .3428 .30262 .33689 .2903 Metetra
0 .353 .283 r
.33689 .2903 .3428 .30262 .35269 .30146 .34678 .28888 Metetra
0 .363 .276 r
.34678 .28888 .35269 .30146 .36262 .3003 .35673 .28745 Metetra
0 .372 .269 r
.35673 .28745 .36262 .3003 .37261 .29913 .36674 .28601 Metetra
0 .381 .26 r
.36674 .28601 .37261 .29913 .38266 .29795 .37679 .28457 Metetra
0 .39 .251 r
.37679 .28457 .38266 .29795 .39276 .29673 .3869 .28307 Metetra
0 .399 .241 r
.3869 .28307 .39276 .29673 .40292 .29529 .39707 .28139 Metetra
0 .404 .235 r
.39707 .28139 .40292 .29529 .4132 .29215 .40735 .27817 Metetra
0 .401 .239 r
.40735 .27817 .4132 .29215 .42361 .28628 .41776 .27248 Metetra
0 .392 .248 r
.41776 .27248 .42361 .28628 .43405 .28015 .4282 .26655 Metetra
0 .383 .258 r
.4282 .26655 .43405 .28015 .44452 .27395 .43867 .26056 Metetra
0 .374 .266 r
.43867 .26056 .44452 .27395 .45501 .26773 .44916 .25454 Metetra
0 .365 .274 r
.44916 .25454 .45501 .26773 .46552 .26149 .45968 .24851 Metetra
0 .356 .282 r
.45968 .24851 .46552 .26149 .47606 .25524 .47022 .24247 Metetra
0 .346 .288 r
.47022 .24247 .47606 .25524 .48662 .24898 .48079 .23641 Metetra
0 .337 .294 r
.48079 .23641 .48662 .24898 .49721 .2427 .49139 .23034 Metetra
0 .328 .299 r
.49139 .23034 .49721 .2427 .50782 .23642 .50201 .22426 Metetra
0 .319 .303 r
.50201 .22426 .50782 .23642 .51845 .23011 .51266 .21816 Metetra
0 .31 .307 r
.51266 .21816 .51845 .23011 .52911 .2238 .52333 .21205 Metetra
0 .291 .3 r
.52333 .21205 .52911 .2238 .53979 .21747 .53403 .20592 Metetra
0 .27 .291 r
.53403 .20592 .53979 .21747 .5505 .21112 .54475 .19978 Metetra
0 .251 .282 r
.54475 .19978 .5505 .21112 .56123 .20476 .5555 .19362 Metetra
0 .232 .273 r
.5555 .19362 .56123 .20476 .57198 .19839 .56628 .18745 Metetra
0 .213 .264 r
.56628 .18745 .57198 .19839 .58276 .19201 .57708 .18126 Metetra
0 .196 .254 r
.57708 .18126 .58276 .19201 .59356 .1856 .58791 .17506 Metetra
0 .179 .245 r
.58791 .17506 .59356 .1856 .60439 .17919 .59876 .16884 Metetra
0 .163 .236 r
.59876 .16884 .60439 .17919 .61525 .17276 .60964 .16261 Metetra
0 .147 .227 r
.60964 .16261 .61525 .17276 .62612 .16631 .62055 .15636 Metetra
0 .133 .218 r
.62055 .15636 .62612 .16631 .63703 .15985 .63149 .1501 Metetra
0 .119 .208 r
.63149 .1501 .63703 .15985 .64795 .15337 .64245 .14382 Metetra
0 .106 .199 r
.64245 .14382 .64795 .15337 .65891 .14688 .65344 .13752 Metetra
0 .093 .19 r
.65344 .13752 .65891 .14688 .66989 .14037 .66445 .13121 Metetra
0 .081 .181 r
.66445 .13121 .66989 .14037 .68089 .13384 .6755 .12488 Metetra
0 .07 .172 r
.6755 .12488 .68089 .13384 .69192 .1273 .68657 .11854 Metetra
0 .06 .162 r
.68657 .11854 .69192 .1273 .70297 .12074 .69766 .11218 Metetra
0 .051 .153 r
.69766 .11218 .70297 .12074 .71405 .11417 .70879 .1058 Metetra
0 .042 .144 r
.70879 .1058 .71405 .11417 .72516 .10761 .71994 .09943 Metetra
0 .034 .135 r
.71994 .09943 .72516 .10761 .73629 .10111 .73113 .09311 Metetra
0 .027 .127 r
.73113 .09311 .73629 .10111 .74748 .09487 .74236 .08703 Metetra
0 .026 .125 r
.09833 .31817 .10499 .32438 .1138 .32255 .10717 .31616 Metetra
0 .031 .132 r
.10717 .31616 .1138 .32255 .12259 .32115 .116 .31453 Metetra
0 .038 .14 r
.116 .31453 .12259 .32115 .13141 .31985 .12486 .313 Metetra
0 .046 .148 r
.12486 .313 .13141 .31985 .14026 .31858 .13375 .31148 Metetra
0 .054 .156 r
.13375 .31148 .14026 .31858 .14917 .3173 .14269 .30996 Metetra
0 .062 .165 r
.14269 .30996 .14917 .3173 .15811 .31601 .15167 .30844 Metetra
0 .072 .173 r
.15167 .30844 .15811 .31601 .1671 .31472 .1607 .3069 Metetra
0 .082 .181 r
.1607 .3069 .1671 .31472 .17613 .31343 .16977 .30536 Metetra
0 .092 .189 r
.16977 .30536 .17613 .31343 .18521 .31212 .17888 .30381 Metetra
0 .104 .198 r
.17888 .30381 .18521 .31212 .19434 .31081 .18804 .30225 Metetra
0 .115 .206 r
.18804 .30225 .19434 .31081 .20351 .30949 .19724 .30069 Metetra
0 .128 .214 r
.19724 .30069 .20351 .30949 .21272 .30816 .20649 .29911 Metetra
0 .141 .223 r
.20649 .29911 .21272 .30816 .22199 .30683 .21578 .29753 Metetra
0 .154 .231 r
.21578 .29753 .22199 .30683 .2313 .30549 .22512 .29594 Metetra
0 .168 .239 r
.22512 .29594 .2313 .30549 .24065 .30414 .2345 .29435 Metetra
0 .183 .248 r
.2345 .29435 .24065 .30414 .25006 .30279 .24393 .29274 Metetra
0 .198 .256 r
.24393 .29274 .25006 .30279 .25951 .30143 .25341 .29113 Metetra
0 .214 .264 r
.25341 .29113 .25951 .30143 .26901 .30006 .26293 .28951 Metetra
0 .231 .272 r
.26293 .28951 .26901 .30006 .27856 .29869 .27251 .28788 Metetra
0 .248 .281 r
.27251 .28788 .27856 .29869 .28815 .29731 .28213 .28624 Metetra
0 .266 .289 r
.28213 .28624 .28815 .29731 .2978 .29592 .29179 .28459 Metetra
0 .284 .297 r
.29179 .28459 .2978 .29592 .3075 .29452 .30151 .28294 Metetra
0 .303 .306 r
.30151 .28294 .3075 .29452 .31724 .29312 .31127 .28128 Metetra
0 .314 .305 r
.31127 .28128 .31724 .29312 .32704 .29171 .32109 .27961 Metetra
0 .322 .302 r
.32109 .27961 .32704 .29171 .33689 .2903 .33095 .27793 Metetra
0 .331 .298 r
.33095 .27793 .33689 .2903 .34678 .28888 .34086 .27625 Metetra
0 .339 .293 r
.34086 .27625 .34678 .28888 .35673 .28745 .35083 .27456 Metetra
0 .347 .288 r
.35083 .27456 .35673 .28745 .36674 .28601 .36084 .27286 Metetra
0 .355 .282 r
.36084 .27286 .36674 .28601 .37679 .28457 .37091 .27114 Metetra
0 .364 .275 r
.37091 .27114 .37679 .28457 .3869 .28307 .38102 .26938 Metetra
0 .372 .269 r
.38102 .26938 .3869 .28307 .39707 .28139 .3912 .26746 Metetra
0 .376 .265 r
.3912 .26746 .39707 .28139 .40735 .27817 .40148 .26415 Metetra
0 .373 .267 r
.40148 .26415 .40735 .27817 .41776 .27248 .41189 .25864 Metetra
0 .366 .274 r
.41189 .25864 .41776 .27248 .4282 .26655 .42233 .25291 Metetra
0 .358 .28 r
.42233 .25291 .4282 .26655 .43867 .26056 .4328 .24712 Metetra
0 .349 .286 r
.4328 .24712 .43867 .26056 .44916 .25454 .4433 .24131 Metetra
0 .341 .292 r
.4433 .24131 .44916 .25454 .45968 .24851 .45382 .23549 Metetra
0 .333 .297 r
.45382 .23549 .45968 .24851 .47022 .24247 .46437 .22965 Metetra
0 .324 .301 r
.46437 .22965 .47022 .24247 .48079 .23641 .47495 .2238 Metetra
0 .316 .305 r
.47495 .2238 .48079 .23641 .49139 .23034 .48555 .21793 Metetra
0 .308 .308 r
.48555 .21793 .49139 .23034 .50201 .22426 .49618 .21205 Metetra
0 .289 .299 r
.49618 .21205 .50201 .22426 .51266 .21816 .50684 .20616 Metetra
0 .27 .291 r
.50684 .20616 .51266 .21816 .52333 .21205 .51752 .20025 Metetra
0 .252 .283 r
.51752 .20025 .52333 .21205 .53403 .20592 .52824 .19432 Metetra
0 .235 .275 r
.52824 .19432 .53403 .20592 .54475 .19978 .53898 .18838 Metetra
0 .218 .266 r
.53898 .18838 .54475 .19978 .5555 .19362 .54975 .18242 Metetra
0 .202 .258 r
.54975 .18242 .5555 .19362 .56628 .18745 .56054 .17645 Metetra
0 .187 .25 r
.56054 .17645 .56628 .18745 .57708 .18126 .57137 .17047 Metetra
0 .172 .241 r
.57137 .17047 .57708 .18126 .58791 .17506 .58222 .16446 Metetra
0 .158 .233 r
.58222 .16446 .58791 .17506 .59876 .16884 .5931 .15845 Metetra
0 .144 .225 r
.5931 .15845 .59876 .16884 .60964 .16261 .60401 .15241 Metetra
0 .131 .216 r
.60401 .15241 .60964 .16261 .62055 .15636 .61495 .14636 Metetra
0 .118 .208 r
.61495 .14636 .62055 .15636 .63149 .1501 .62592 .1403 Metetra
0 .106 .2 r
.62592 .1403 .63149 .1501 .64245 .14382 .63691 .13421 Metetra
0 .095 .192 r
.63691 .13421 .64245 .14382 .65344 .13752 .64794 .12811 Metetra
0 .084 .183 r
.64794 .12811 .65344 .13752 .66445 .13121 .65899 .122 Metetra
0 .074 .175 r
.65899 .122 .66445 .13121 .6755 .12488 .67007 .11587 Metetra
0 .065 .167 r
.67007 .11587 .6755 .12488 .68657 .11854 .68118 .10972 Metetra
0 .056 .158 r
.68118 .10972 .68657 .11854 .69766 .11218 .69232 .10355 Metetra
0 .047 .15 r
.69232 .10355 .69766 .11218 .70879 .1058 .70349 .09737 Metetra
0 .04 .142 r
.70349 .09737 .70879 .1058 .71994 .09943 .71469 .09119 Metetra
0 .033 .134 r
.71469 .09119 .71994 .09943 .73113 .09311 .72593 .08506 Metetra
0 .027 .126 r
.72593 .08506 .73113 .09311 .74236 .08703 .73721 .07913 Metetra
0 .026 .124 r
.09162 .31191 .09833 .31817 .10717 .31616 .1005 .30972 Metetra
0 .03 .131 r
.1005 .30972 .10717 .31616 .116 .31453 .10937 .30787 Metetra
0 .036 .138 r
.10937 .30787 .116 .31453 .12486 .313 .11827 .3061 Metetra
0 .043 .145 r
.11827 .3061 .12486 .313 .13375 .31148 .1272 .30434 Metetra
0 .05 .152 r
.1272 .30434 .13375 .31148 .14269 .30996 .13618 .30258 Metetra
0 .057 .16 r
.13618 .30258 .14269 .30996 .15167 .30844 .1452 .30081 Metetra
0 .065 .167 r
.1452 .30081 .15167 .30844 .1607 .3069 .15426 .29904 Metetra
0 .074 .175 r
.15426 .29904 .1607 .3069 .16977 .30536 .16337 .29725 Metetra
0 .083 .182 r
.16337 .29725 .16977 .30536 .17888 .30381 .17251 .29546 Metetra
0 .092 .189 r
.17251 .29546 .17888 .30381 .18804 .30225 .18171 .29365 Metetra
0 .102 .197 r
.18171 .29365 .18804 .30225 .19724 .30069 .19094 .29184 Metetra
0 .113 .204 r
.19094 .29184 .19724 .30069 .20649 .29911 .20022 .29002 Metetra
0 .124 .212 r
.20022 .29002 .20649 .29911 .21578 .29753 .20954 .28819 Metetra
0 .135 .219 r
.20954 .28819 .21578 .29753 .22512 .29594 .21891 .28635 Metetra
0 .147 .226 r
.21891 .28635 .22512 .29594 .2345 .29435 .22832 .2845 Metetra
0 .159 .234 r
.22832 .2845 .2345 .29435 .24393 .29274 .23778 .28264 Metetra
0 .172 .241 r
.23778 .28264 .24393 .29274 .25341 .29113 .24729 .28078 Metetra
0 .185 .249 r
.24729 .28078 .25341 .29113 .26293 .28951 .25684 .2789 Metetra
0 .199 .256 r
.25684 .2789 .26293 .28951 .27251 .28788 .26643 .27702 Metetra
0 .213 .263 r
.26643 .27702 .27251 .28788 .28213 .28624 .27607 .27513 Metetra
0 .227 .271 r
.27607 .27513 .28213 .28624 .29179 .28459 .28576 .27323 Metetra
0 .243 .278 r
.28576 .27323 .29179 .28459 .30151 .28294 .2955 .27131 Metetra
0 .258 .286 r
.2955 .27131 .30151 .28294 .31127 .28128 .30528 .26939 Metetra
0 .274 .293 r
.30528 .26939 .31127 .28128 .32109 .27961 .31512 .26747 Metetra
0 .291 .3 r
.31512 .26747 .32109 .27961 .33095 .27793 .325 .26553 Metetra
0 .308 .308 r
.325 .26553 .33095 .27793 .34086 .27625 .33492 .26358 Metetra
0 .315 .305 r
.33492 .26358 .34086 .27625 .35083 .27456 .3449 .26162 Metetra
0 .323 .302 r
.3449 .26162 .35083 .27456 .36084 .27286 .35493 .25966 Metetra
0 .33 .298 r
.35493 .25966 .36084 .27286 .37091 .27114 .36501 .25768 Metetra
0 .337 .294 r
.36501 .25768 .37091 .27114 .38102 .26938 .37513 .25566 Metetra
0 .344 .29 r
.37513 .25566 .38102 .26938 .3912 .26746 .38532 .25349 Metetra
0 .348 .287 r
.38532 .25349 .3912 .26746 .40148 .26415 .39561 .2501 Metetra
0 .346 .289 r
.39561 .2501 .40148 .26415 .41189 .25864 .40601 .24476 Metetra
0 .339 .293 r
.40601 .24476 .41189 .25864 .42233 .25291 .41645 .23923 Metetra
0 .332 .297 r
.41645 .23923 .42233 .25291 .4328 .24712 .42692 .23365 Metetra
0 .324 .301 r
.42692 .23365 .4328 .24712 .4433 .24131 .43741 .22804 Metetra
0 .317 .304 r
.43741 .22804 .4433 .24131 .45382 .23549 .44794 .22243 Metetra
0 .31 .307 r
.44794 .22243 .45382 .23549 .46437 .22965 .45849 .21679 Metetra
0 .295 .302 r
.45849 .21679 .46437 .22965 .47495 .2238 .46908 .21114 Metetra
0 .278 .295 r
.46908 .21114 .47495 .2238 .48555 .21793 .47969 .20548 Metetra
0 .262 .287 r
.47969 .20548 .48555 .21793 .49618 .21205 .49033 .1998 Metetra
0 .246 .28 r
.49033 .1998 .49618 .21205 .50684 .20616 .501 .19411 Metetra
0 .231 .273 r
.501 .19411 .50684 .20616 .51752 .20025 .5117 .1884 Metetra
0 .216 .265 r
.5117 .1884 .51752 .20025 .52824 .19432 .52242 .18267 Metetra
0 .202 .258 r
.52242 .18267 .52824 .19432 .53898 .18838 .53318 .17693 Metetra
0 .188 .25 r
.53318 .17693 .53898 .18838 .54975 .18242 .54397 .17117 Metetra
0 .175 .243 r
.54397 .17117 .54975 .18242 .56054 .17645 .55479 .1654 Metetra
0 .162 .236 r
.55479 .1654 .56054 .17645 .57137 .17047 .56563 .15962 Metetra
0 .15 .228 r
.56563 .15962 .57137 .17047 .58222 .16446 .57651 .15381 Metetra
0 .138 .221 r
.57651 .15381 .58222 .16446 .5931 .15845 .58742 .14799 Metetra
0 .126 .213 r
.58742 .14799 .5931 .15845 .60401 .15241 .59835 .14216 Metetra
0 .115 .206 r
.59835 .14216 .60401 .15241 .61495 .14636 .60932 .1363 Metetra
0 .105 .199 r
.60932 .1363 .61495 .14636 .62592 .1403 .62032 .13043 Metetra
0 .095 .191 r
.62032 .13043 .62592 .1403 .63691 .13421 .63134 .12455 Metetra
0 .085 .184 r
.63134 .12455 .63691 .13421 .64794 .12811 .6424 .11865 Metetra
0 .076 .176 r
.6424 .11865 .64794 .12811 .65899 .122 .65349 .11273 Metetra
0 .068 .169 r
.65349 .11273 .65899 .122 .67007 .11587 .66461 .10679 Metetra
0 .059 .162 r
.66461 .10679 .67007 .11587 .68118 .10972 .67576 .10084 Metetra
0 .052 .154 r
.67576 .10084 .68118 .10972 .69232 .10355 .68695 .09487 Metetra
0 .045 .147 r
.68695 .09487 .69232 .10355 .70349 .09737 .69816 .08888 Metetra
0 .038 .139 r
.69816 .08888 .70349 .09737 .71469 .09119 .70941 .08289 Metetra
0 .032 .132 r
.70941 .08289 .71469 .09119 .72593 .08506 .72069 .07695 Metetra
0 .026 .126 r
.72069 .07695 .72593 .08506 .73721 .07913 .73202 .07118 Metetra
0 .025 .124 r
.08487 .30561 .09162 .31191 .1005 .30972 .09378 .30324 Metetra
0 .029 .129 r
.09378 .30324 .1005 .30972 .10937 .30787 .10269 .30116 Metetra
0 .035 .136 r
.10269 .30116 .10937 .30787 .11827 .3061 .11163 .29916 Metetra
0 .04 .142 r
.11163 .29916 .11827 .3061 .1272 .30434 .12061 .29716 Metetra
0 .046 .149 r
.12061 .29716 .1272 .30434 .13618 .30258 .12963 .29516 Metetra
0 .053 .155 r
.12963 .29516 .13618 .30258 .1452 .30081 .13869 .29315 Metetra
0 .059 .162 r
.13869 .29315 .1452 .30081 .15426 .29904 .14779 .29113 Metetra
0 .066 .168 r
.14779 .29113 .15426 .29904 .16337 .29725 .15693 .2891 Metetra
0 .074 .175 r
.15693 .2891 .16337 .29725 .17251 .29546 .16611 .28706 Metetra
0 .082 .181 r
.16611 .28706 .17251 .29546 .18171 .29365 .17534 .28501 Metetra
0 .09 .188 r
.17534 .28501 .18171 .29365 .19094 .29184 .18461 .28295 Metetra
0 .099 .194 r
.18461 .28295 .19094 .29184 .20022 .29002 .19392 .28088 Metetra
0 .108 .201 r
.19392 .28088 .20022 .29002 .20954 .28819 .20328 .2788 Metetra
0 .117 .207 r
.20328 .2788 .20954 .28819 .21891 .28635 .21268 .27671 Metetra
0 .126 .214 r
.21268 .27671 .21891 .28635 .22832 .2845 .22212 .27461 Metetra
0 .137 .22 r
.22212 .27461 .22832 .2845 .23778 .28264 .2316 .2725 Metetra
0 .147 .227 r
.2316 .2725 .23778 .28264 .24729 .28078 .24114 .27038 Metetra
0 .158 .233 r
.24114 .27038 .24729 .28078 .25684 .2789 .25071 .26826 Metetra
0 .169 .24 r
.25071 .26826 .25684 .2789 .26643 .27702 .26033 .26612 Metetra
0 .18 .246 r
.26033 .26612 .26643 .27702 .27607 .27513 .27 .26397 Metetra
0 .192 .253 r
.27 .26397 .27607 .27513 .28576 .27323 .27971 .26181 Metetra
0 .204 .259 r
.27971 .26181 .28576 .27323 .2955 .27131 .28947 .25964 Metetra
0 .217 .266 r
.28947 .25964 .2955 .27131 .30528 .26939 .29927 .25747 Metetra
0 .23 .272 r
.29927 .25747 .30528 .26939 .31512 .26747 .30912 .25528 Metetra
0 .243 .278 r
.30912 .25528 .31512 .26747 .325 .26553 .31902 .25308 Metetra
0 .257 .285 r
.31902 .25308 .325 .26553 .33492 .26358 .32897 .25087 Metetra
0 .271 .291 r
.32897 .25087 .33492 .26358 .3449 .26162 .33896 .24865 Metetra
0 .285 .298 r
.33896 .24865 .3449 .26162 .35493 .25966 .349 .24642 Metetra
0 .3 .304 r
.349 .24642 .35493 .25966 .36501 .25768 .35909 .24418 Metetra
0 .311 .307 r
.35909 .24418 .36501 .25768 .37513 .25566 .36923 .2419 Metetra
0 .317 .304 r
.36923 .2419 .37513 .25566 .38532 .25349 .37942 .23948 Metetra
0 .321 .303 r
.37942 .23948 .38532 .25349 .39561 .2501 .38971 .23601 Metetra
0 .319 .304 r
.38971 .23601 .39561 .2501 .40601 .24476 .40011 .23084 Metetra
0 .313 .306 r
.40011 .23084 .40601 .24476 .41645 .23923 .41055 .22552 Metetra
0 .304 .306 r
.41055 .22552 .41645 .23923 .42692 .23365 .42101 .22014 Metetra
0 .289 .3 r
.42101 .22014 .42692 .23365 .43741 .22804 .43151 .21473 Metetra
0 .275 .293 r
.43151 .21473 .43741 .22804 .44794 .22243 .44204 .20932 Metetra
0 .26 .287 r
.44204 .20932 .44794 .22243 .45849 .21679 .4526 .20389 Metetra
0 .247 .28 r
.4526 .20389 .45849 .21679 .46908 .21114 .46318 .19844 Metetra
0 .233 .274 r
.46318 .19844 .46908 .21114 .47969 .20548 .4738 .19298 Metetra
0 .22 .267 r
.4738 .19298 .47969 .20548 .49033 .1998 .48445 .1875 Metetra
0 .207 .261 r
.48445 .1875 .49033 .1998 .501 .19411 .49513 .182 Metetra
0 .195 .254 r
.49513 .182 .501 .19411 .5117 .1884 .50584 .1765 Metetra
0 .183 .248 r
.50584 .1765 .5117 .1884 .52242 .18267 .51659 .17097 Metetra
0 .172 .241 r
.51659 .17097 .52242 .18267 .53318 .17693 .52736 .16543 Metetra
0 .16 .235 r
.52736 .16543 .53318 .17693 .54397 .17117 .53816 .15987 Metetra
0 .15 .228 r
.53816 .15987 .54397 .17117 .55479 .1654 .549 .1543 Metetra
0 .139 .222 r
.549 .1543 .55479 .1654 .56563 .15962 .55987 .14871 Metetra
0 .129 .215 r
.55987 .14871 .56563 .15962 .57651 .15381 .57077 .1431 Metetra
0 .119 .209 r
.57077 .1431 .57651 .15381 .58742 .14799 .5817 .13748 Metetra
0 .11 .202 r
.5817 .13748 .58742 .14799 .59835 .14216 .59266 .13184 Metetra
0 .101 .196 r
.59266 .13184 .59835 .14216 .60932 .1363 .60365 .12619 Metetra
0 .092 .189 r
.60365 .12619 .60932 .1363 .62032 .13043 .61468 .12052 Metetra
0 .084 .183 r
.61468 .12052 .62032 .13043 .63134 .12455 .62574 .11483 Metetra
0 .076 .176 r
.62574 .11483 .63134 .12455 .6424 .11865 .63683 .10912 Metetra
0 .068 .17 r
.63683 .10912 .6424 .11865 .65349 .11273 .64796 .1034 Metetra
0 .061 .163 r
.64796 .1034 .65349 .11273 .66461 .10679 .65912 .09766 Metetra
0 .054 .157 r
.65912 .09766 .66461 .10679 .67576 .10084 .67031 .0919 Metetra
0 .048 .15 r
.67031 .0919 .67576 .10084 .68695 .09487 .68153 .08612 Metetra
0 .042 .144 r
.68153 .08612 .68695 .09487 .69816 .08888 .69279 .08033 Metetra
0 .036 .137 r
.69279 .08033 .69816 .08888 .70941 .08289 .70408 .07454 Metetra
0 .031 .131 r
.70408 .07454 .70941 .08289 .72069 .07695 .71541 .06878 Metetra
0 .026 .125 r
.71541 .06878 .72069 .07695 .73202 .07118 .72678 .06317 Metetra
0 .025 .124 r
.07808 .29927 .08487 .30561 .09378 .30324 .08703 .29672 Metetra
0 .029 .128 r
.08703 .29672 .09378 .30324 .10269 .30116 .09598 .29442 Metetra
0 .033 .134 r
.09598 .29442 .10269 .30116 .11163 .29916 .10496 .29217 Metetra
0 .038 .139 r
.10496 .29217 .11163 .29916 .12061 .29716 .11398 .28993 Metetra
0 .043 .145 r
.11398 .28993 .12061 .29716 .12963 .29516 .12304 .28769 Metetra
0 .048 .15 r
.12304 .28769 .12963 .29516 .13869 .29315 .13214 .28543 Metetra
0 .053 .156 r
.13214 .28543 .13869 .29315 .14779 .29113 .14128 .28317 Metetra
0 .059 .162 r
.14128 .28317 .14779 .29113 .15693 .2891 .15046 .28089 Metetra
0 .065 .167 r
.15046 .28089 .15693 .2891 .16611 .28706 .15968 .27861 Metetra
0 .072 .173 r
.15968 .27861 .16611 .28706 .17534 .28501 .16894 .27631 Metetra
0 .078 .178 r
.16894 .27631 .17534 .28501 .18461 .28295 .17824 .274 Metetra
0 .085 .184 r
.17824 .274 .18461 .28295 .19392 .28088 .18759 .27169 Metetra
0 .093 .19 r
.18759 .27169 .19392 .28088 .20328 .2788 .19698 .26936 Metetra
0 .1 .195 r
.19698 .26936 .20328 .2788 .21268 .27671 .20641 .26702 Metetra
0 .108 .201 r
.20641 .26702 .21268 .27671 .22212 .27461 .21588 .26467 Metetra
0 .116 .206 r
.21588 .26467 .22212 .27461 .2316 .2725 .2254 .26231 Metetra
0 .124 .212 r
.2254 .26231 .2316 .2725 .24114 .27038 .23496 .25994 Metetra
0 .132 .217 r
.23496 .25994 .24114 .27038 .25071 .26826 .24456 .25756 Metetra
0 .141 .223 r
.24456 .25756 .25071 .26826 .26033 .26612 .25421 .25517 Metetra
0 .15 .229 r
.25421 .25517 .26033 .26612 .27 .26397 .2639 .25277 Metetra
0 .16 .234 r
.2639 .25277 .27 .26397 .27971 .26181 .27363 .25035 Metetra
0 .169 .24 r
.27363 .25035 .27971 .26181 .28947 .25964 .28341 .24793 Metetra
0 .179 .245 r
.28341 .24793 .28947 .25964 .29927 .25747 .29324 .24549 Metetra
0 .189 .251 r
.29324 .24549 .29927 .25747 .30912 .25528 .30311 .24305 Metetra
0 .2 .257 r
.30311 .24305 .30912 .25528 .31902 .25308 .31303 .24059 Metetra
0 .211 .262 r
.31303 .24059 .31902 .25308 .32897 .25087 .32299 .23812 Metetra
0 .222 .268 r
.32299 .23812 .32897 .25087 .33896 .24865 .333 .23564 Metetra
0 .233 .273 r
.333 .23564 .33896 .24865 .349 .24642 .34305 .23315 Metetra
0 .244 .279 r
.34305 .23315 .349 .24642 .35909 .24418 .35316 .23064 Metetra
0 .256 .285 r
.35316 .23064 .35909 .24418 .36923 .2419 .36331 .2281 Metetra
0 .267 .29 r
.36331 .2281 .36923 .2419 .37942 .23948 .37351 .22544 Metetra
0 .274 .293 r
.37351 .22544 .37942 .23948 .38971 .23601 .3838 .22188 Metetra
0 .27 .291 r
.3838 .22188 .38971 .23601 .40011 .23084 .3942 .21689 Metetra
0 .259 .286 r
.3942 .21689 .40011 .23084 .41055 .22552 .40463 .21176 Metetra
0 .247 .28 r
.40463 .21176 .41055 .22552 .42101 .22014 .41509 .20658 Metetra
0 .236 .275 r
.41509 .20658 .42101 .22014 .43151 .21473 .42559 .20138 Metetra
0 .224 .269 r
.42559 .20138 .43151 .21473 .44204 .20932 .43612 .19617 Metetra
0 .213 .264 r
.43612 .19617 .44204 .20932 .4526 .20389 .44668 .19094 Metetra
0 .202 .258 r
.44668 .19094 .4526 .20389 .46318 .19844 .45727 .18569 Metetra
0 .192 .252 r
.45727 .18569 .46318 .19844 .4738 .19298 .4679 .18043 Metetra
0 .182 .247 r
.4679 .18043 .4738 .19298 .48445 .1875 .47855 .17515 Metetra
0 .172 .241 r
.47855 .17515 .48445 .1875 .49513 .182 .48924 .16986 Metetra
0 .162 .236 r
.48924 .16986 .49513 .182 .50584 .1765 .49997 .16454 Metetra
0 .153 .23 r
.49997 .16454 .50584 .1765 .51659 .17097 .51072 .15922 Metetra
0 .144 .224 r
.51072 .15922 .51659 .17097 .52736 .16543 .52151 .15388 Metetra
0 .135 .219 r
.52151 .15388 .52736 .16543 .53816 .15987 .53233 .14852 Metetra
0 .126 .213 r
.53233 .14852 .53816 .15987 .549 .1543 .54318 .14314 Metetra
0 .118 .208 r
.54318 .14314 .549 .1543 .55987 .14871 .55407 .13775 Metetra
0 .11 .202 r
.55407 .13775 .55987 .14871 .57077 .1431 .56499 .13234 Metetra
0 .102 .197 r
.56499 .13234 .57077 .1431 .5817 .13748 .57595 .12692 Metetra
0 .094 .191 r
.57595 .12692 .5817 .13748 .59266 .13184 .58694 .12147 Metetra
0 .087 .185 r
.58694 .12147 .59266 .13184 .60365 .12619 .59796 .11602 Metetra
0 .08 .18 r
.59796 .11602 .60365 .12619 .61468 .12052 .60901 .11054 Metetra
0 .073 .174 r
.60901 .11054 .61468 .12052 .62574 .11483 .62011 .10505 Metetra
0 .067 .169 r
.62011 .10505 .62574 .11483 .63683 .10912 .63123 .09954 Metetra
0 .061 .163 r
.63123 .09954 .63683 .10912 .64796 .1034 .64239 .09401 Metetra
0 .055 .157 r
.64239 .09401 .64796 .1034 .65912 .09766 .65359 .08846 Metetra
0 .049 .152 r
.65359 .08846 .65912 .09766 .67031 .0919 .66482 .0829 Metetra
0 .044 .146 r
.66482 .0829 .67031 .0919 .68153 .08612 .67608 .07732 Metetra
0 .039 .141 r
.67608 .07732 .68153 .08612 .69279 .08033 .68738 .07172 Metetra
0 .034 .135 r
.68738 .07172 .69279 .08033 .70408 .07454 .69872 .06612 Metetra
0 .03 .13 r
.69872 .06612 .70408 .07454 .71541 .06878 .71009 .06055 Metetra
0 .026 .125 r
.71009 .06055 .71541 .06878 .72678 .06317 .72151 .0551 Metetra
0 .025 .123 r
.07124 .29289 .07808 .29927 .08703 .29672 .08022 .29016 Metetra
0 .028 .127 r
.08022 .29016 .08703 .29672 .09598 .29442 .08922 .28763 Metetra
0 .031 .132 r
.08922 .28763 .09598 .29442 .10496 .29217 .09824 .28514 Metetra
0 .035 .136 r
.09824 .28514 .10496 .29217 .11398 .28993 .10731 .28266 Metetra
0 .039 .141 r
.10731 .28266 .11398 .28993 .12304 .28769 .11641 .28017 Metetra
0 .043 .146 r
.11641 .28017 .12304 .28769 .13214 .28543 .12555 .27767 Metetra
0 .048 .15 r
.12555 .27767 .13214 .28543 .14128 .28317 .13473 .27516 Metetra
0 .053 .155 r
.13473 .27516 .14128 .28317 .15046 .28089 .14395 .27264 Metetra
0 .057 .16 r
.14395 .27264 .15046 .28089 .15968 .27861 .15321 .27011 Metetra
0 .062 .164 r
.15321 .27011 .15968 .27861 .16894 .27631 .16251 .26757 Metetra
0 .068 .169 r
.16251 .26757 .16894 .27631 .17824 .274 .17185 .26502 Metetra
0 .073 .174 r
.17185 .26502 .17824 .274 .18759 .27169 .18123 .26245 Metetra
0 .079 .179 r
.18123 .26245 .18759 .27169 .19698 .26936 .19065 .25987 Metetra
0 .084 .183 r
.19065 .25987 .19698 .26936 .20641 .26702 .20011 .25729 Metetra
0 .09 .188 r
.20011 .25729 .20641 .26702 .21588 .26467 .20962 .25469 Metetra
0 .097 .193 r
.20962 .25469 .21588 .26467 .2254 .26231 .21916 .25208 Metetra
0 .103 .197 r
.21916 .25208 .2254 .26231 .23496 .25994 .22875 .24945 Metetra
0 .109 .202 r
.22875 .24945 .23496 .25994 .24456 .25756 .23838 .24682 Metetra
0 .116 .207 r
.23838 .24682 .24456 .25756 .25421 .25517 .24806 .24418 Metetra
0 .123 .211 r
.24806 .24418 .25421 .25517 .2639 .25277 .25777 .24152 Metetra
0 .13 .216 r
.25777 .24152 .2639 .25277 .27363 .25035 .26753 .23885 Metetra
0 .137 .221 r
.26753 .23885 .27363 .25035 .28341 .24793 .27734 .23617 Metetra
0 .145 .225 r
.27734 .23617 .28341 .24793 .29324 .24549 .28718 .23348 Metetra
0 .153 .23 r
.28718 .23348 .29324 .24549 .30311 .24305 .29707 .23077 Metetra
0 .161 .235 r
.29707 .23077 .30311 .24305 .31303 .24059 .30701 .22805 Metetra
0 .169 .239 r
.30701 .22805 .31303 .24059 .32299 .23812 .31699 .22533 Metetra
0 .177 .244 r
.31699 .22533 .32299 .23812 .333 .23564 .32702 .22258 Metetra
0 .185 .249 r
.32702 .22258 .333 .23564 .34305 .23315 .33709 .21983 Metetra
0 .194 .253 r
.33709 .21983 .34305 .23315 .35316 .23064 .34721 .21706 Metetra
0 .203 .258 r
.34721 .21706 .35316 .23064 .36331 .2281 .35737 .21426 Metetra
0 .211 .263 r
.35737 .21426 .36331 .2281 .37351 .22544 .36758 .21136 Metetra
0 .216 .265 r
.36758 .21136 .37351 .22544 .3838 .22188 .37788 .20772 Metetra
0 .213 .264 r
.37788 .20772 .3838 .22188 .3942 .21689 .38827 .2029 Metetra
0 .205 .259 r
.38827 .2029 .3942 .21689 .40463 .21176 .3987 .19797 Metetra
0 .196 .255 r
.3987 .19797 .40463 .21176 .41509 .20658 .40916 .19299 Metetra
0 .187 .25 r
.40916 .19299 .41509 .20658 .42559 .20138 .41965 .18799 Metetra
0 .179 .245 r
.41965 .18799 .42559 .20138 .43612 .19617 .43018 .18297 Metetra
0 .171 .241 r
.43018 .18297 .43612 .19617 .44668 .19094 .44074 .17794 Metetra
0 .163 .236 r
.44074 .17794 .44668 .19094 .45727 .18569 .45134 .17289 Metetra
0 .155 .231 r
.45134 .17289 .45727 .18569 .4679 .18043 .46197 .16783 Metetra
0 .147 .227 r
.46197 .16783 .4679 .18043 .47855 .17515 .47263 .16275 Metetra
0 .139 .222 r
.47263 .16275 .47855 .17515 .48924 .16986 .48333 .15766 Metetra
0 .132 .217 r
.48333 .15766 .48924 .16986 .49997 .16454 .49406 .15254 Metetra
0 .125 .212 r
.49406 .15254 .49997 .16454 .51072 .15922 .50483 .14742 Metetra
0 .118 .208 r
.50483 .14742 .51072 .15922 .52151 .15388 .51563 .14227 Metetra
0 .111 .203 r
.51563 .14227 .52151 .15388 .53233 .14852 .52647 .13711 Metetra
0 .104 .198 r
.52647 .13711 .53233 .14852 .54318 .14314 .53734 .13193 Metetra
0 .098 .194 r
.53734 .13193 .54318 .14314 .55407 .13775 .54825 .12674 Metetra
0 .092 .189 r
.54825 .12674 .55407 .13775 .56499 .13234 .55919 .12152 Metetra
0 .086 .184 r
.55919 .12152 .56499 .13234 .57595 .12692 .57017 .11629 Metetra
0 .08 .18 r
.57017 .11629 .57595 .12692 .58694 .12147 .58118 .11105 Metetra
0 .074 .175 r
.58118 .11105 .58694 .12147 .59796 .11602 .59223 .10579 Metetra
0 .069 .17 r
.59223 .10579 .59796 .11602 .60901 .11054 .60331 .10051 Metetra
0 .064 .166 r
.60331 .10051 .60901 .11054 .62011 .10505 .61444 .09521 Metetra
0 .059 .161 r
.61444 .09521 .62011 .10505 .63123 .09954 .62559 .08989 Metetra
0 .054 .156 r
.62559 .08989 .63123 .09954 .64239 .09401 .63679 .08456 Metetra
0 .049 .152 r
.63679 .08456 .64239 .09401 .65359 .08846 .64802 .07921 Metetra
0 .045 .147 r
.64802 .07921 .65359 .08846 .66482 .0829 .65929 .07384 Metetra
0 .04 .142 r
.65929 .07384 .66482 .0829 .67608 .07732 .67059 .06846 Metetra
0 .036 .138 r
.67059 .06846 .67608 .07732 .68738 .07172 .68194 .06306 Metetra
0 .032 .133 r
.68194 .06306 .68738 .07172 .69872 .06612 .69332 .05764 Metetra
0 .029 .128 r
.69332 .05764 .69872 .06612 .71009 .06055 .70474 .05226 Metetra
0 .025 .124 r
.70474 .05226 .71009 .06055 .72151 .0551 .7162 .04696 Metetra
0 .025 .123 r
.06435 .28646 .07124 .29289 .08022 .29016 .07338 .28355 Metetra
0 .027 .126 r
.07338 .28355 .08022 .29016 .08922 .28763 .08242 .28079 Metetra
0 .03 .13 r
.08242 .28079 .08922 .28763 .09824 .28514 .09149 .27807 Metetra
0 .033 .133 r
.09149 .27807 .09824 .28514 .10731 .28266 .10059 .27535 Metetra
0 .036 .137 r
.10059 .27535 .10731 .28266 .11641 .28017 .10974 .27261 Metetra
0 .039 .141 r
.10974 .27261 .11641 .28017 .12555 .27767 .11892 .26987 Metetra
0 .043 .145 r
.11892 .26987 .12555 .27767 .13473 .27516 .12814 .26711 Metetra
0 .046 .149 r
.12814 .26711 .13473 .27516 .14395 .27264 .1374 .26435 Metetra
0 .05 .152 r
.1374 .26435 .14395 .27264 .15321 .27011 .1467 .26157 Metetra
0 .054 .156 r
.1467 .26157 .15321 .27011 .16251 .26757 .15604 .25878 Metetra
0 .058 .16 r
.15604 .25878 .16251 .26757 .17185 .26502 .16541 .25598 Metetra
0 .062 .164 r
.16541 .25598 .17185 .26502 .18123 .26245 .17483 .25317 Metetra
0 .066 .167 r
.17483 .25317 .18123 .26245 .19065 .25987 .18429 .25034 Metetra
0 .07 .171 r
.18429 .25034 .19065 .25987 .20011 .25729 .19378 .2475 Metetra
0 .074 .175 r
.19378 .2475 .20011 .25729 .20962 .25469 .20332 .24465 Metetra
0 .079 .179 r
.20332 .24465 .20962 .25469 .21916 .25208 .2129 .24179 Metetra
0 .084 .183 r
.2129 .24179 .21916 .25208 .22875 .24945 .22252 .23892 Metetra
0 .088 .186 r
.22252 .23892 .22875 .24945 .23838 .24682 .23218 .23603 Metetra
0 .093 .19 r
.23218 .23603 .23838 .24682 .24806 .24418 .24188 .23314 Metetra
0 .098 .194 r
.24188 .23314 .24806 .24418 .25777 .24152 .25162 .23023 Metetra
0 .104 .198 r
.25162 .23023 .25777 .24152 .26753 .23885 .26141 .2273 Metetra
0 .109 .202 r
.26141 .2273 .26753 .23885 .27734 .23617 .27124 .22437 Metetra
0 .114 .205 r
.27124 .22437 .27734 .23617 .28718 .23348 .28111 .22142 Metetra
0 .12 .209 r
.28111 .22142 .28718 .23348 .29707 .23077 .29102 .21846 Metetra
0 .125 .213 r
.29102 .21846 .29707 .23077 .30701 .22805 .30098 .21548 Metetra
0 .131 .217 r
.30098 .21548 .30701 .22805 .31699 .22533 .31098 .21249 Metetra
0 .137 .22 r
.31098 .21249 .31699 .22533 .32702 .22258 .32102 .20949 Metetra
0 .143 .224 r
.32102 .20949 .32702 .22258 .33709 .21983 .33111 .20648 Metetra
0 .149 .228 r
.33111 .20648 .33709 .21983 .34721 .21706 .34124 .20345 Metetra
0 .155 .232 r
.34124 .20345 .34721 .21706 .35737 .21426 .35142 .20039 Metetra
0 .161 .235 r
.35142 .20039 .35737 .21426 .36758 .21136 .36164 .19725 Metetra
0 .165 .237 r
.36164 .19725 .36758 .21136 .37788 .20772 .37194 .19353 Metetra
0 .163 .236 r
.37194 .19353 .37788 .20772 .38827 .2029 .38232 .18888 Metetra
0 .157 .233 r
.38232 .18888 .38827 .2029 .3987 .19797 .39275 .18413 Metetra
0 .151 .229 r
.39275 .18413 .3987 .19797 .40916 .19299 .4032 .17935 Metetra
0 .145 .225 r
.4032 .17935 .40916 .19299 .41965 .18799 .4137 .17455 Metetra
0 .139 .221 r
.4137 .17455 .41965 .18799 .43018 .18297 .42423 .16974 Metetra
0 .133 .218 r
.42423 .16974 .43018 .18297 .44074 .17794 .43479 .1649 Metetra
0 .127 .214 r
.43479 .1649 .44074 .17794 .45134 .17289 .44539 .16005 Metetra
0 .121 .21 r
.44539 .16005 .45134 .17289 .46197 .16783 .45602 .15519 Metetra
0 .116 .206 r
.45602 .15519 .46197 .16783 .47263 .16275 .46669 .15031 Metetra
0 .11 .202 r
.46669 .15031 .47263 .16275 .48333 .15766 .4774 .14541 Metetra
0 .105 .199 r
.4774 .14541 .48333 .15766 .49406 .15254 .48814 .14049 Metetra
0 .1 .195 r
.48814 .14049 .49406 .15254 .50483 .14742 .49892 .13556 Metetra
0 .095 .191 r
.49892 .13556 .50483 .14742 .51563 .14227 .50973 .13061 Metetra
0 .09 .187 r
.50973 .13061 .51563 .14227 .52647 .13711 .52058 .12565 Metetra
0 .085 .184 r
.52058 .12565 .52647 .13711 .53734 .13193 .53147 .12066 Metetra
0 .08 .18 r
.53147 .12066 .53734 .13193 .54825 .12674 .54239 .11567 Metetra
0 .076 .176 r
.54239 .11567 .54825 .12674 .55919 .12152 .55336 .11065 Metetra
0 .071 .172 r
.55336 .11065 .55919 .12152 .57017 .11629 .56436 .10562 Metetra
0 .067 .168 r
.56436 .10562 .57017 .11629 .58118 .11105 .57539 .10057 Metetra
0 .063 .165 r
.57539 .10057 .58118 .11105 .59223 .10579 .58647 .0955 Metetra
0 .058 .161 r
.58647 .0955 .59223 .10579 .60331 .10051 .59758 .09041 Metetra
0 .055 .157 r
.59758 .09041 .60331 .10051 .61444 .09521 .60873 .08531 Metetra
0 .051 .153 r
.60873 .08531 .61444 .09521 .62559 .08989 .61992 .08019 Metetra
0 .047 .15 r
.61992 .08019 .62559 .08989 .63679 .08456 .63115 .07505 Metetra
0 .043 .146 r
.63115 .07505 .63679 .08456 .64802 .07921 .64242 .0699 Metetra
0 .04 .142 r
.64242 .0699 .64802 .07921 .65929 .07384 .65372 .06473 Metetra
0 .037 .138 r
.65372 .06473 .65929 .07384 .67059 .06846 .66507 .05953 Metetra
0 .033 .134 r
.66507 .05953 .67059 .06846 .68194 .06306 .67645 .05433 Metetra
0 .03 .131 r
.67645 .05433 .68194 .06306 .69332 .05764 .68788 .04911 Metetra
0 .028 .127 r
.68788 .04911 .69332 .05764 .70474 .05226 .69934 .0439 Metetra
0 .025 .124 r
.69934 .0439 .70474 .05226 .7162 .04696 .71085 .03877 Metetra
0 .024 .123 r
.05742 .27999 .06435 .28646 .07338 .28355 .06648 .2769 Metetra
0 .026 .125 r
.06648 .2769 .07338 .28355 .08242 .28079 .07557 .27392 Metetra
0 .028 .128 r
.07557 .27392 .08242 .28079 .09149 .27807 .08468 .27095 Metetra
0 .03 .131 r
.08468 .27095 .09149 .27807 .10059 .27535 .09384 .26799 Metetra
0 .033 .133 r
.09384 .26799 .10059 .27535 .10974 .27261 .10302 .26501 Metetra
0 .035 .136 r
.10302 .26501 .10974 .27261 .11892 .26987 .11225 .26202 Metetra
0 .038 .139 r
.11225 .26202 .11892 .26987 .12814 .26711 .12151 .25902 Metetra
0 .04 .142 r
.12151 .25902 .12814 .26711 .1374 .26435 .13081 .25601 Metetra
0 .043 .145 r
.13081 .25601 .1374 .26435 .1467 .26157 .14015 .25299 Metetra
0 .045 .148 r
.14015 .25299 .1467 .26157 .15604 .25878 .14953 .24995 Metetra
0 .048 .151 r
.14953 .24995 .15604 .25878 .16541 .25598 .15895 .2469 Metetra
0 .051 .154 r
.15895 .2469 .16541 .25598 .17483 .25317 .1684 .24384 Metetra
0 .054 .156 r
.1684 .24384 .17483 .25317 .18429 .25034 .17789 .24077 Metetra
0 .057 .159 r
.17789 .24077 .18429 .25034 .19378 .2475 .18742 .23768 Metetra
0 .06 .162 r
.18742 .23768 .19378 .2475 .20332 .24465 .19699 .23458 Metetra
0 .063 .165 r
.19699 .23458 .20332 .24465 .2129 .24179 .2066 .23147 Metetra
0 .066 .168 r
.2066 .23147 .2129 .24179 .22252 .23892 .21625 .22835 Metetra
0 .07 .171 r
.21625 .22835 .22252 .23892 .23218 .23603 .22594 .22521 Metetra
0 .073 .174 r
.22594 .22521 .23218 .23603 .24188 .23314 .23568 .22206 Metetra
0 .076 .177 r
.23568 .22206 .24188 .23314 .25162 .23023 .24545 .2189 Metetra
0 .08 .179 r
.24545 .2189 .25162 .23023 .26141 .2273 .25526 .21572 Metetra
0 .083 .182 r
.25526 .21572 .26141 .2273 .27124 .22437 .26511 .21253 Metetra
0 .087 .185 r
.26511 .21253 .27124 .22437 .28111 .22142 .27501 .20932 Metetra
0 .091 .188 r
.27501 .20932 .28111 .22142 .29102 .21846 .28494 .20611 Metetra
0 .094 .191 r
.28494 .20611 .29102 .21846 .30098 .21548 .29492 .20288 Metetra
0 .098 .194 r
.29492 .20288 .30098 .21548 .31098 .21249 .30494 .19963 Metetra
0 .102 .197 r
.30494 .19963 .31098 .21249 .32102 .20949 .315 .19637 Metetra
0 .106 .2 r
.315 .19637 .32102 .20949 .33111 .20648 .32511 .1931 Metetra
0 .11 .202 r
.32511 .1931 .33111 .20648 .34124 .20345 .33525 .18981 Metetra
0 .114 .205 r
.33525 .18981 .34124 .20345 .35142 .20039 .34545 .18649 Metetra
0 .118 .208 r
.34545 .18649 .35142 .20039 .36164 .19725 .35568 .18312 Metetra
0 .121 .21 r
.35568 .18312 .36164 .19725 .37194 .19353 .36599 .17931 Metetra
0 .119 .209 r
.36599 .17931 .37194 .19353 .38232 .18888 .37636 .17483 Metetra
0 .115 .206 r
.37636 .17483 .38232 .18888 .39275 .18413 .38678 .17028 Metetra
0 .111 .203 r
.38678 .17028 .39275 .18413 .4032 .17935 .39723 .16569 Metetra
0 .107 .2 r
.39723 .16569 .4032 .17935 .4137 .17455 .40772 .16109 Metetra
0 .103 .197 r
.40772 .16109 .4137 .17455 .42423 .16974 .41825 .15647 Metetra
0 .099 .195 r
.41825 .15647 .42423 .16974 .43479 .1649 .42881 .15183 Metetra
0 .095 .192 r
.42881 .15183 .43479 .1649 .44539 .16005 .43941 .14718 Metetra
0 .092 .189 r
.43941 .14718 .44539 .16005 .45602 .15519 .45005 .14251 Metetra
0 .088 .186 r
.45005 .14251 .45602 .15519 .46669 .15031 .46072 .13782 Metetra
0 .084 .183 r
.46072 .13782 .46669 .15031 .4774 .14541 .47144 .13312 Metetra
0 .081 .18 r
.47144 .13312 .4774 .14541 .48814 .14049 .48219 .1284 Metetra
0 .077 .177 r
.48219 .1284 .48814 .14049 .49892 .13556 .49297 .12366 Metetra
0 .074 .174 r
.49297 .12366 .49892 .13556 .50973 .13061 .5038 .11891 Metetra
0 .07 .172 r
.5038 .11891 .50973 .13061 .52058 .12565 .51467 .11414 Metetra
0 .067 .169 r
.51467 .11414 .52058 .12565 .53147 .12066 .52557 .10935 Metetra
0 .064 .166 r
.52557 .10935 .53147 .12066 .54239 .11567 .53651 .10455 Metetra
0 .061 .163 r
.53651 .10455 .54239 .11567 .55336 .11065 .54749 .09973 Metetra
0 .058 .16 r
.54749 .09973 .55336 .11065 .56436 .10562 .55851 .09489 Metetra
0 .055 .157 r
.55851 .09489 .56436 .10562 .57539 .10057 .56957 .09003 Metetra
0 .052 .154 r
.56957 .09003 .57539 .10057 .58647 .0955 .58067 .08516 Metetra
0 .049 .151 r
.58067 .08516 .58647 .0955 .59758 .09041 .59181 .08027 Metetra
0 .046 .149 r
.59181 .08027 .59758 .09041 .60873 .08531 .60299 .07536 Metetra
0 .043 .146 r
.60299 .07536 .60873 .08531 .61992 .08019 .61421 .07043 Metetra
0 .041 .143 r
.61421 .07043 .61992 .08019 .63115 .07505 .62548 .06549 Metetra
0 .038 .14 r
.62548 .06549 .63115 .07505 .64242 .0699 .63678 .06053 Metetra
0 .036 .137 r
.63678 .06053 .64242 .0699 .65372 .06473 .64812 .05555 Metetra
0 .033 .134 r
.64812 .05555 .65372 .06473 .66507 .05953 .6595 .05055 Metetra
0 .031 .131 r
.6595 .05055 .66507 .05953 .67645 .05433 .67093 .04554 Metetra
0 .029 .128 r
.67093 .04554 .67645 .05433 .68788 .04911 .6824 .04051 Metetra
0 .027 .126 r
.6824 .04051 .68788 .04911 .69934 .0439 .69391 .03549 Metetra
0 .025 .123 r
.69391 .03549 .69934 .0439 .71085 .03877 .70546 .03052 Metetra
0 .024 .122 r
.05044 .27348 .05742 .27999 .06648 .2769 .05954 .27021 Metetra
0 .025 .124 r
.05954 .27021 .06648 .2769 .07557 .27392 .06867 .267 Metetra
0 .027 .126 r
.06867 .267 .07557 .27392 .08468 .27095 .07784 .2638 Metetra
0 .028 .128 r
.07784 .2638 .08468 .27095 .09384 .26799 .08704 .26059 Metetra
0 .03 .13 r
.08704 .26059 .09384 .26799 .10302 .26501 .09627 .25738 Metetra
0 .031 .132 r
.09627 .25738 .10302 .26501 .11225 .26202 .10554 .25415 Metetra
0 .033 .134 r
.10554 .25415 .11225 .26202 .12151 .25902 .11485 .2509 Metetra
0 .034 .136 r
.11485 .2509 .12151 .25902 .13081 .25601 .12419 .24765 Metetra
0 .036 .138 r
.12419 .24765 .13081 .25601 .14015 .25299 .13357 .24438 Metetra
0 .038 .14 r
.13357 .24438 .14015 .25299 .14953 .24995 .14299 .2411 Metetra
0 .04 .142 r
.14299 .2411 .14953 .24995 .15895 .2469 .15244 .23781 Metetra
0 .041 .144 r
.15244 .23781 .15895 .2469 .1684 .24384 .16193 .2345 Metetra
0 .043 .146 r
.16193 .2345 .1684 .24384 .17789 .24077 .17146 .23118 Metetra
0 .045 .147 r
.17146 .23118 .17789 .24077 .18742 .23768 .18103 .22785 Metetra
0 .047 .149 r
.18103 .22785 .18742 .23768 .19699 .23458 .19063 .22451 Metetra
0 .049 .151 r
.19063 .22451 .19699 .23458 .2066 .23147 .20028 .22115 Metetra
0 .051 .153 r
.20028 .22115 .2066 .23147 .21625 .22835 .20996 .21778 Metetra
0 .053 .155 r
.20996 .21778 .21625 .22835 .22594 .22521 .21968 .21439 Metetra
0 .055 .157 r
.21968 .21439 .22594 .22521 .23568 .22206 .22944 .21099 Metetra
0 .057 .159 r
.22944 .21099 .23568 .22206 .24545 .2189 .23924 .20758 Metetra
0 .059 .161 r
.23924 .20758 .24545 .2189 .25526 .21572 .24908 .20415 Metetra
0 .061 .163 r
.24908 .20415 .25526 .21572 .26511 .21253 .25896 .20071 Metetra
0 .063 .165 r
.25896 .20071 .26511 .21253 .27501 .20932 .26888 .19726 Metetra
0 .066 .167 r
.26888 .19726 .27501 .20932 .28494 .20611 .27884 .19379 Metetra
0 .068 .169 r
.27884 .19379 .28494 .20611 .29492 .20288 .28884 .1903 Metetra
0 .07 .171 r
.28884 .1903 .29492 .20288 .30494 .19963 .29888 .18681 Metetra
0 .072 .173 r
.29888 .18681 .30494 .19963 .315 .19637 .30896 .18329 Metetra
0 .075 .175 r
.30896 .18329 .315 .19637 .32511 .1931 .31908 .17976 Metetra
0 .077 .177 r
.31908 .17976 .32511 .1931 .33525 .18981 .32925 .17622 Metetra
0 .079 .179 r
.32925 .17622 .33525 .18981 .34545 .18649 .33945 .17265 Metetra
0 .082 .181 r
.33945 .17265 .34545 .18649 .35568 .18312 .34971 .16904 Metetra
0 .083 .182 r
.34971 .16904 .35568 .18312 .36599 .17931 .36001 .16516 Metetra
0 .082 .181 r
.36001 .16516 .36599 .17931 .37636 .17483 .37038 .16084 Metetra
0 .08 .18 r
.37038 .16084 .37636 .17483 .38678 .17028 .38079 .15647 Metetra
0 .078 .178 r
.38079 .15647 .38678 .17028 .39723 .16569 .39124 .15208 Metetra
0 .075 .176 r
.39124 .15208 .39723 .16569 .40772 .16109 .40172 .14767 Metetra
0 .073 .174 r
.40172 .14767 .40772 .16109 .41825 .15647 .41225 .14324 Metetra
0 .071 .172 r
.41225 .14324 .41825 .15647 .42881 .15183 .42281 .1388 Metetra
0 .068 .17 r
.42281 .1388 .42881 .15183 .43941 .14718 .43341 .13433 Metetra
0 .066 .168 r
.43341 .13433 .43941 .14718 .45005 .14251 .44405 .12986 Metetra
0 .064 .166 r
.44405 .12986 .45005 .14251 .46072 .13782 .45473 .12536 Metetra
0 .062 .164 r
.45473 .12536 .46072 .13782 .47144 .13312 .46545 .12085 Metetra
0 .06 .162 r
.46545 .12085 .47144 .13312 .48219 .1284 .47621 .11632 Metetra
0 .057 .16 r
.47621 .11632 .48219 .1284 .49297 .12366 .48701 .11177 Metetra
0 .055 .158 r
.48701 .11177 .49297 .12366 .5038 .11891 .49784 .10721 Metetra
0 .053 .156 r
.49784 .10721 .5038 .11891 .51467 .11414 .50872 .10263 Metetra
0 .051 .154 r
.50872 .10263 .51467 .11414 .52557 .10935 .51964 .09804 Metetra
0 .049 .152 r
.51964 .09804 .52557 .10935 .53651 .10455 .5306 .09342 Metetra
0 .047 .15 r
.5306 .09342 .53651 .10455 .54749 .09973 .5416 .08879 Metetra
0 .046 .148 r
.5416 .08879 .54749 .09973 .55851 .09489 .55264 .08414 Metetra
0 .044 .146 r
.55264 .08414 .55851 .09489 .56957 .09003 .56372 .07948 Metetra
0 .042 .144 r
.56372 .07948 .56957 .09003 .58067 .08516 .57485 .07479 Metetra
0 .04 .142 r
.57485 .07479 .58067 .08516 .59181 .08027 .58601 .07009 Metetra
0 .038 .14 r
.58601 .07009 .59181 .08027 .60299 .07536 .59722 .06538 Metetra
0 .037 .138 r
.59722 .06538 .60299 .07536 .61421 .07043 .60847 .06064 Metetra
0 .035 .136 r
.60847 .06064 .61421 .07043 .62548 .06549 .61977 .05589 Metetra
0 .033 .134 r
.61977 .05589 .62548 .06549 .63678 .06053 .6311 .05112 Metetra
0 .032 .132 r
.6311 .05112 .63678 .06053 .64812 .05555 .64248 .04633 Metetra
0 .03 .13 r
.64248 .04633 .64812 .05555 .6595 .05055 .6539 .04152 Metetra
0 .028 .128 r
.6539 .04152 .6595 .05055 .67093 .04554 .66537 .0367 Metetra
0 .027 .126 r
.66537 .0367 .67093 .04554 .6824 .04051 .67688 .03186 Metetra
0 .026 .124 r
.67688 .03186 .6824 .04051 .69391 .03549 .68843 .02702 Metetra
0 .024 .123 r
.68843 .02702 .69391 .03549 .70546 .03052 .70003 .0222 Metetra
0 .024 .122 r
.04341 .26693 .05044 .27348 .05954 .27021 .05256 .26349 Metetra
0 .024 .123 r
.05256 .26349 .05954 .27021 .06867 .267 .06173 .26007 Metetra
0 .025 .124 r
.06173 .26007 .06867 .267 .07784 .2638 .07094 .25664 Metetra
0 .026 .125 r
.07094 .25664 .07784 .2638 .08704 .26059 .08019 .25321 Metetra
0 .027 .126 r
.08019 .25321 .08704 .26059 .09627 .25738 .08946 .24976 Metetra
0 .028 .127 r
.08946 .24976 .09627 .25738 .10554 .25415 .09878 .2463 Metetra
0 .029 .128 r
.09878 .2463 .10554 .25415 .11485 .2509 .10813 .24283 Metetra
0 .029 .129 r
.10813 .24283 .11485 .2509 .12419 .24765 .11751 .23934 Metetra
0 .03 .131 r
.11751 .23934 .12419 .24765 .13357 .24438 .12693 .23585 Metetra
0 .031 .132 r
.12693 .23585 .13357 .24438 .14299 .2411 .13639 .23233 Metetra
0 .032 .133 r
.13639 .23233 .14299 .2411 .15244 .23781 .14588 .22881 Metetra
0 .033 .134 r
.14588 .22881 .15244 .23781 .16193 .2345 .15541 .22527 Metetra
0 .034 .135 r
.15541 .22527 .16193 .2345 .17146 .23118 .16498 .22172 Metetra
0 .035 .136 r
.16498 .22172 .17146 .23118 .18103 .22785 .17458 .21816 Metetra
0 .036 .137 r
.17458 .21816 .18103 .22785 .19063 .22451 .18422 .21458 Metetra
0 .037 .138 r
.18422 .21458 .19063 .22451 .20028 .22115 .1939 .21098 Metetra
0 .038 .139 r
.1939 .21098 .20028 .22115 .20996 .21778 .20361 .20738 Metetra
0 .039 .141 r
.20361 .20738 .20996 .21778 .21968 .21439 .21336 .20376 Metetra
0 .04 .142 r
.21336 .20376 .21968 .21439 .22944 .21099 .22315 .20012 Metetra
0 .041 .143 r
.22315 .20012 .22944 .21099 .23924 .20758 .23298 .19647 Metetra
0 .042 .144 r
.23298 .19647 .23924 .20758 .24908 .20415 .24285 .19281 Metetra
0 .043 .145 r
.24285 .19281 .24908 .20415 .25896 .20071 .25276 .18913 Metetra
0 .044 .146 r
.25276 .18913 .25896 .20071 .26888 .19726 .2627 .18544 Metetra
0 .045 .147 r
.2627 .18544 .26888 .19726 .27884 .19379 .27268 .18173 Metetra
0 .046 .148 r
.27268 .18173 .27884 .19379 .28884 .1903 .28271 .17801 Metetra
0 .047 .15 r
.28271 .17801 .28884 .1903 .29888 .18681 .29277 .17427 Metetra
0 .048 .151 r
.29277 .17427 .29888 .18681 .30896 .18329 .30287 .17052 Metetra
0 .049 .152 r
.30287 .17052 .30896 .18329 .31908 .17976 .31301 .16675 Metetra
0 .05 .153 r
.31301 .16675 .31908 .17976 .32925 .17622 .3232 .16297 Metetra
0 .051 .154 r
.3232 .16297 .32925 .17622 .33945 .17265 .33342 .15917 Metetra
0 .052 .155 r
.33342 .15917 .33945 .17265 .34971 .16904 .34369 .15534 Metetra
0 .053 .156 r
.34369 .15534 .34971 .16904 .36001 .16516 .354 .15137 Metetra
0 .053 .155 r
.354 .15137 .36001 .16516 .37038 .16084 .36436 .14721 Metetra
0 .052 .154 r
.36436 .14721 .37038 .16084 .38079 .15647 .37477 .14301 Metetra
0 .051 .153 r
.37477 .14301 .38079 .15647 .39124 .15208 .38521 .13879 Metetra
0 .049 .152 r
.38521 .13879 .39124 .15208 .40172 .14767 .39569 .13456 Metetra
0 .048 .151 r
.39569 .13456 .40172 .14767 .41225 .14324 .40621 .13031 Metetra
0 .047 .15 r
.40621 .13031 .41225 .14324 .42281 .1388 .41678 .12604 Metetra
0 .046 .149 r
.41678 .12604 .42281 .1388 .43341 .13433 .42738 .12176 Metetra
0 .045 .148 r
.42738 .12176 .43341 .13433 .44405 .12986 .43802 .11745 Metetra
0 .044 .146 r
.43802 .11745 .44405 .12986 .45473 .12536 .44871 .11314 Metetra
0 .043 .145 r
.44871 .11314 .45473 .12536 .46545 .12085 .45943 .1088 Metetra
0 .042 .144 r
.45943 .1088 .46545 .12085 .47621 .11632 .4702 .10445 Metetra
0 .041 .143 r
.4702 .10445 .47621 .11632 .48701 .11177 .48101 .10008 Metetra
0 .04 .142 r
.48101 .10008 .48701 .11177 .49784 .10721 .49186 .0957 Metetra
0 .039 .141 r
.49186 .0957 .49784 .10721 .50872 .10263 .50275 .09129 Metetra
0 .038 .14 r
.50275 .09129 .50872 .10263 .51964 .09804 .51368 .08688 Metetra
0 .037 .139 r
.51368 .08688 .51964 .09804 .5306 .09342 .52466 .08244 Metetra
0 .036 .137 r
.52466 .08244 .5306 .09342 .5416 .08879 .53568 .07798 Metetra
0 .035 .136 r
.53568 .07798 .5416 .08879 .55264 .08414 .54674 .07351 Metetra
0 .034 .135 r
.54674 .07351 .55264 .08414 .56372 .07948 .55784 .06903 Metetra
0 .033 .134 r
.55784 .06903 .56372 .07948 .57485 .07479 .56899 .06452 Metetra
0 .032 .133 r
.56899 .06452 .57485 .07479 .58601 .07009 .58018 .06 Metetra
0 .031 .132 r
.58018 .06 .58601 .07009 .59722 .06538 .59142 .05545 Metetra
0 .031 .131 r
.59142 .05545 .59722 .06538 .60847 .06064 .6027 .0509 Metetra
0 .03 .13 r
.6027 .0509 .60847 .06064 .61977 .05589 .61402 .04632 Metetra
0 .029 .129 r
.61402 .04632 .61977 .05589 .6311 .05112 .62539 .04173 Metetra
0 .028 .127 r
.62539 .04173 .6311 .05112 .64248 .04633 .63681 .03711 Metetra
0 .027 .126 r
.63681 .03711 .64248 .04633 .6539 .04152 .64826 .03248 Metetra
0 .026 .125 r
.64826 .03248 .6539 .04152 .66537 .0367 .65977 .02784 Metetra
0 .025 .124 r
.65977 .02784 .66537 .0367 .67688 .03186 .67132 .02317 Metetra
0 .025 .123 r
.67132 .02317 .67688 .03186 .68843 .02702 .68292 .0185 Metetra
0 .024 .122 r
.68292 .0185 .68843 .02702 .70003 .0222 .69456 .01382 Metetra
0 .024 .122 r
.03634 .26033 .04341 .26693 .05256 .26349 .04552 .25675 Metetra
0 .024 .122 r
.04552 .25675 .05256 .26349 .06173 .26007 .05473 .25316 Metetra
0 .024 .122 r
.05473 .25316 .06173 .26007 .07094 .25664 .06398 .24956 Metetra
0 .024 .123 r
.06398 .24956 .07094 .25664 .08019 .25321 .07327 .24595 Metetra
0 .025 .123 r
.07327 .24595 .08019 .25321 .08946 .24976 .08259 .24232 Metetra
0 .025 .123 r
.08259 .24232 .08946 .24976 .09878 .2463 .09194 .23867 Metetra
0 .025 .124 r
.09194 .23867 .09878 .2463 .10813 .24283 .10132 .23502 Metetra
0 .025 .124 r
.10132 .23502 .10813 .24283 .11751 .23934 .11075 .23135 Metetra
0 .026 .124 r
.11075 .23135 .11751 .23934 .12693 .23585 .1202 .22767 Metetra
0 .026 .125 r
.1202 .22767 .12693 .23585 .13639 .23233 .1297 .22397 Metetra
0 .026 .125 r
.1297 .22397 .13639 .23233 .14588 .22881 .13922 .22026 Metetra
0 .026 .126 r
.13922 .22026 .14588 .22881 .15541 .22527 .14879 .21653 Metetra
0 .027 .126 r
.14879 .21653 .15541 .22527 .16498 .22172 .15839 .21279 Metetra
0 .027 .126 r
.15839 .21279 .16498 .22172 .17458 .21816 .16802 .20904 Metetra
0 .027 .127 r
.16802 .20904 .17458 .21816 .18422 .21458 .1777 .20528 Metetra
0 .028 .127 r
.1777 .20528 .18422 .21458 .1939 .21098 .1874 .20149 Metetra
0 .028 .127 r
.1874 .20149 .1939 .21098 .20361 .20738 .19715 .1977 Metetra
0 .028 .128 r
.19715 .1977 .20361 .20738 .21336 .20376 .20693 .19389 Metetra
0 .028 .128 r
.20693 .19389 .21336 .20376 .22315 .20012 .21675 .19007 Metetra
0 .029 .129 r
.21675 .19007 .22315 .20012 .23298 .19647 .22661 .18623 Metetra
0 .029 .129 r
.22661 .18623 .23298 .19647 .24285 .19281 .2365 .18237 Metetra
0 .029 .129 r
.2365 .18237 .24285 .19281 .25276 .18913 .24643 .17851 Metetra
0 .03 .13 r
.24643 .17851 .25276 .18913 .2627 .18544 .2564 .17462 Metetra
0 .03 .13 r
.2564 .17462 .2627 .18544 .27268 .18173 .26641 .17072 Metetra
0 .03 .13 r
.26641 .17072 .27268 .18173 .28271 .17801 .27646 .16681 Metetra
0 .031 .131 r
.27646 .16681 .28271 .17801 .29277 .17427 .28655 .16288 Metetra
0 .031 .131 r
.28655 .16288 .29277 .17427 .30287 .17052 .29667 .15894 Metetra
0 .031 .132 r
.29667 .15894 .30287 .17052 .31301 .16675 .30683 .15498 Metetra
0 .031 .132 r
.30683 .15498 .31301 .16675 .3232 .16297 .31704 .15101 Metetra
0 .032 .132 r
.31704 .15101 .3232 .16297 .33342 .15917 .32728 .14702 Metetra
0 .032 .133 r
.32728 .14702 .33342 .15917 .34369 .15534 .33756 .14301 Metetra
0 .032 .133 r
.33756 .14301 .34369 .15534 .354 .15137 .34788 .13898 Metetra
0 .032 .133 r
.34788 .13898 .354 .15137 .36436 .14721 .35825 .13493 Metetra
0 .032 .132 r
.35825 .13493 .36436 .14721 .37477 .14301 .36865 .13085 Metetra
0 .031 .132 r
.36865 .13085 .37477 .14301 .38521 .13879 .3791 .12676 Metetra
0 .031 .132 r
.3791 .12676 .38521 .13879 .39569 .13456 .38958 .12266 Metetra
0 .031 .131 r
.38958 .12266 .39569 .13456 .40621 .13031 .40011 .11853 Metetra
0 .031 .131 r
.40011 .11853 .40621 .13031 .41678 .12604 .41068 .1144 Metetra
0 .03 .13 r
.41068 .1144 .41678 .12604 .42738 .12176 .42129 .11024 Metetra
0 .03 .13 r
.42129 .11024 .42738 .12176 .43802 .11745 .43194 .10607 Metetra
0 .03 .13 r
.43194 .10607 .43802 .11745 .44871 .11314 .44263 .10188 Metetra
0 .029 .129 r
.44263 .10188 .44871 .11314 .45943 .1088 .45337 .09768 Metetra
0 .029 .129 r
.45337 .09768 .45943 .1088 .4702 .10445 .46414 .09346 Metetra
0 .029 .129 r
.46414 .09346 .4702 .10445 .48101 .10008 .47497 .08922 Metetra
0 .029 .128 r
.47497 .08922 .48101 .10008 .49186 .0957 .48583 .08497 Metetra
0 .028 .128 r
.48583 .08497 .49186 .0957 .50275 .09129 .49674 .08069 Metetra
0 .028 .128 r
.49674 .08069 .50275 .09129 .51368 .08688 .50769 .07641 Metetra
0 .028 .127 r
.50769 .07641 .51368 .08688 .52466 .08244 .51868 .0721 Metetra
0 .027 .127 r
.51868 .0721 .52466 .08244 .53568 .07798 .52972 .06778 Metetra
0 .027 .126 r
.52972 .06778 .53568 .07798 .54674 .07351 .54081 .06344 Metetra
0 .027 .126 r
.54081 .06344 .54674 .07351 .55784 .06903 .55193 .05908 Metetra
0 .027 .126 r
.55193 .05908 .55784 .06903 .56899 .06452 .56311 .0547 Metetra
0 .026 .125 r
.56311 .0547 .56899 .06452 .58018 .06 .57432 .05031 Metetra
0 .026 .125 r
.57432 .05031 .58018 .06 .59142 .05545 .58559 .0459 Metetra
0 .026 .125 r
.58559 .0459 .59142 .05545 .6027 .0509 .5969 .04147 Metetra
0 .025 .124 r
.5969 .04147 .6027 .0509 .61402 .04632 .60825 .03702 Metetra
0 .025 .124 r
.60825 .03702 .61402 .04632 .62539 .04173 .61965 .03256 Metetra
0 .025 .123 r
.61965 .03256 .62539 .04173 .63681 .03711 .6311 .02808 Metetra
0 .025 .123 r
.6311 .02808 .63681 .03711 .64826 .03248 .6426 .02358 Metetra
0 .024 .123 r
.6426 .02358 .64826 .03248 .65977 .02784 .65414 .01906 Metetra
0 .024 .122 r
.65414 .01906 .65977 .02784 .67132 .02317 .66573 .01452 Metetra
0 .024 .122 r
.66573 .01452 .67132 .02317 .68292 .0185 .67736 .00996 Metetra
0 .024 .122 r
.67736 .00996 .68292 .0185 .69456 .01382 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13976 .21496 m
.1444 .2196 L
s
[(-100)] .13049 .20567 .99802 1 Mshowa
.34434 .13486 m
.34862 .13983 L
s
[(0)] .33577 .12491 .86142 1 Mshowa
.56596 .04808 m
.56981 .05339 L
s
[(100)] .55826 .03745 .72482 1 Mshowa
.125 Mabswid
.17941 .19944 m
.18215 .20226 L
s
.21968 .18367 m
.22238 .18653 L
s
.26058 .16765 m
.26323 .17056 L
s
.30212 .15139 m
.30474 .15433 L
s
.38723 .11806 m
.38975 .12108 L
s
.43082 .10099 m
.4333 .10405 L
s
.47513 .08364 m
.47755 .08675 L
s
.52017 .06601 m
.52254 .06915 L
s
.10072 .23025 m
.10354 .233 L
s
.06227 .2453 m
.06513 .24802 L
s
.61252 .02984 m
.61477 .03307 L
s
.65987 .0113 m
.66206 .01458 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00b_ooool2
o`0005Cooooo0037ooooo`Go0000E?ooool009[ooooo0ol00004ooooo`;o00001?ooool2o`0001co
oooo1Ol000000ol01Qoo0000o`00001Cooooo`00Voooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006?ooool3o`000004ooooool0003o00HO
o`0000;o00HO0ol0001Booooo`00Voooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00005Oooool3o`0000;ooooo0_l00003o`067`Go0000D_oo
ool009_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0001?ooooo0_l00002ooooo`?o000000Co00HOo`000?l01Qoo00HO0_l000000ol01Qoo
0000o`067`02o`00057ooooo002Kooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000@ooooo`?o000000Koooooo`000?l0003o0000o`067ol0
0002o`067`?o00000_l01Ql2o`000004o`067ol0003o0000o`00053ooooo002Jooooo`;o00001?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo0_l000001_oooooo
0000o`000?l0003o00HOo`0000;o00HO0ol00002o`067`03o`000?l01Qoo00HO00?o000000?o00HO
o`000?l00000D?ooool009_ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0000<oooo
o`Ko000000Co00HOo`000?l01Qoo00HO0ol00002o`067`03o`000?l01Qoo00HO00?o000000Co00HO
o`000?l01Qoo00HO0ol0001?ooooo`00/oooool5o`000003o`067ol0003o00HO00;o00HO0_l00000
0ol01R3o0000o`067`02o`067`?o000000Co00HPo`000?l01Qoo00HO0ol00002o`067`;o0000C_oo
ool00;3ooooo0ol000001?oooooo0000o`067ol00003o`067`04o`000?l01Qoo0000o`0000?o00HP
00Go0000o`067ol0003o00LPo`000002o`0680Co000000Co00HPo`000?l01Qoo00HO0_l0001>oooo
o`00[_ooool2o`0000;ooooo0_l00003o`067`03o`000?l01Qoo000000;o00000_l01b000ol0003o
00HPo`068002o`0000?o00LP0_l000001Ol01b3o0000o`068?l0003o00HP00?o000000?o00HOo`00
0?l00000COooool00:_ooooo0ol000001_oooooo0000o`000?l0003o00HOo`0000;o00HO0ol00002
o`078@03o`000?l01b3o00LP00?o000000Co00LQo`000?l01b3o00LP0_l00003o`078005o`000?l0
1R3o0000o`078?l000000_l01Ql3o`0004cooooo002Xooooo`Oo00000_l01Ql00ol0003o00HOo`00
0002o`0000;o00LQ00?o0000o`078Ol01b400ol000001?l0227o0000o`078Ol01b43o`0000;o00LQ
00?o0000o`078?l01b000ol000001Ol01b3o0000o`000?l0003o00HO00;o0000C?ooool00:Kooooo
0_l000000ooooooo0000o`000002o`000004o`067ol0003o00HOo`067`;o000000?o00LQo`000?l0
1b400_l01b43o`000004o`088_l0003o00PQo`088@?o00000_l022800ol0003o00LQo`078@03o`00
0006o`078Ol0003o0000o`000?l01b3o00000_l01Ql3o`0004_ooooo002Sooooo`Ko000000?o00HP
o`000?l01Ql00_l01Ql3o`000009o`078Ol0003o00LQo`078Ol0003o00LQo`000?l022;o000000?o
00PR0_l000000ol02B?o0000o`088P02o`088P?o000000Co00PRo`000?l01b7o00LQ0_l00003o`07
80;o00000_l01Ql2o`0004[ooooo002Qooooo`Go000000?o00HPo`000?l01R000_l01R001Ol0003o
00HOo`000?l022;o000000?o00LQ00Co0000o`078Ol0003o00000ol022801?l0003o00PRo`000?l0
0003o`098`05o`000?l022;o0000o`098ol000000_l02283o`000004o`088_l0003o00LPo`0780;o
00000ol01Ql2o`0004[ooooo002Nooooo`Go000000?o00HPo`000?l01R000_l01R000ol0003o00HP
o`068002o`0000?o00PR00?o0000o`078Ol000000_l000001?l02B?o0000o`088_l02283o`0000;o
00TS00?o0000o`098ol02B<00_l00003o`098`;o000000Co00TSo`000?l022;o00PR0ol00002o`07
8@04o`000?l01Qoo0000o`067`;o00003Oooool3o`0000Cooooo0_l00004ooooo`;o0000;Oooool0
09cooooo0_l00002ooooo`03o`000?l01R3o000000;o00HP00?o0000o`068?l01R000ol000001?l0
22;o0000o`088_l02283o`0000;o00TS00?o0000o`098ol000000_l00002o`0:9003o`000?l02B?o
00TS00?o000000Co00XTo`000?l02B?o00TS0_l00003o`098`?o000000Co00PRo`000?l01b7o00LQ
0_l00002o`067`?o00003Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo0000;?ooool009Wooooo0ol00002ooooo`;o00000ol01R000ol0003o
00HPo`000002o`000004o`088_l0003o00PRo`088P?o000000?o00XTo`000?l02B<00_l02B<2o`00
0003o`0;9Ol0003o00XT00;o00XT0ol000001?l02bGo0000o`0:9?l02R@3o`0000;o00XT00Oo0000
o`098ol0003o0000o`088_l0003o00PR00?o000000Go00LQo`000?l01Qoo0000o`068002o`0000Go
oooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000/ooooo`00Uoooool2o`0000;ooooo0ol000001?l01b3o0000o`068?l01R03
o`000003o`088_l0003o00PR00;o00PR0_l000000ol02RCo0000o`0:9002o`0:9005o`000?l02B?o
0000o`0;9_l000000_l02bD01Ol0003o00XTo`000?l032Ko000000;o00/U0ol00002o`0;9@03o`00
0?l02RCo00XT00;o00000_l02B@3o`000004o`098ol0003o00LQo`078@;o00000_l01R03o`0000co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0002cooooo002Dooooo`?o000000Koooooo`000?l0003o0000o`078?l00002o`0780?o000000?o
00TSo`000?l022800_l022801?l0003o00PRo`000?l00003o`0:9003o`000?l02RCo00XT00;o0000
0ol02bH01?l0003o00/Uo`000?l00003o`0<9P;o000000?o00`Vo`000?l02bD00_l02bD3o`000004
o`0;9Ol0003o00TTo`0990;o00000_l02B<3o`000004o`088Ol0003o00HPo`0000;o00HP00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000;?ooool0097ooooo1ol000000ol01b3o0000o`078002o`0780;o000000?o
00TSo`000?l02B<00_l02B<00ol0003o00PRo`000002o`0000;o00/U00?o0000o`0:9?l02R@00ol0
00001?l032Ko0000o`0;9_l02bH3o`000004o`0=9ol0003o00`Vo`0<9P;o00000ol032H01Ol0003o
00/Uo`000?l032Ko000000;o00/U0ol000001_l02RCo0000o`098ol0003o00TSo`0000?o00PQ00Co
0000o`068?l01R3o00HP0_l0000:ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0002cooooo002?ooooo`;o000000Koooooo`000?l0003o0000o`078?l00003
o`078004o`000?l01b3o0000o`0000?o00TS00?o0000o`098ol02B<00_l000000ol02bGo0000o`0;
9@02o`0;9@?o000000Co00dWo`000?l032Ko00`V0ol000000ol03RSo0000o`0=9`02o`0=9`;o0000
0_l03BL00ol0003o00`Vo`0<9P02o`0000?o00`V0_l000001?l032Ko0000o`0:9?l02R@2o`0000?o
00TS00So0000o`088Ol0003o00PRo`000?l01R3o0000o`0680;o00002_ooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool2o`0002gooooo001/ooooo`;o00007_ooool3o`000005ooooool0003o
0000o`078Ol000000ol01b000ol0003o00LPo`078002o`0000;o00TS00?o0000o`098ol02B<00ol0
00002Ol032Ko0000o`0;9Ol02bGo0000o`0;9Ol0003o00hXo`000003o`0=9`;o000000?o00hYo`00
0?l03RP00_l03RP01?l0003o00dWo`000?l00003o`0=9`?o000000Co00hXo`000?l032Ko00`V0_l0
0002o`0<9PCo000000Co00/Uo`000?l02B?o00TS0_l00002o`088P;o00000_l01R02o`0004Gooooo
001[ooooo`04o`000?ooooooooooo`0001_ooooo0_l000001_oooooo0000o`000?l0003o00LQo`00
00;o00LQ00?o0000o`078?l01b000ol000001?l02BCo0000o`098ol02B<3o`000003o`0<9_l0003o
00`V00;o00`V00Co0000o`0;9Ol0003o00000ol03RP01?l0003o00dWo`000?l00003o`0>:@03o`00
0?l03RSo00hX00;o00000_l03bT01Ol0003o00dWo`000?l03bWo000000;o00hX0ol000002Ol03BSo
0000o`0<9_l0003o00dWo`000?l02bGo0000o`0;9@03o`000009o`0:9?l0003o00PRo`000?l022;o
0000o`068?l0003o00LP00;o0000A?ooool006_ooooo00Co0000oooooooooooo00006?ooool6o`00
0003o`078Ol0003o00LQ00;o00LQ00?o0000o`078Ol000000_l000000ol02RCo0000o`099002o`09
90;o000000?o00dWo`000?l032H00_l032H00ol0003o00`Vo`000002o`0000;o00hX00?o0000o`0>
:?l000000_l00002o`0@:P03o`000?l03RWo00hY00?o000000Co010Zo`000?l03bWo00lY0_l00003
o`0?:@;o000000?o00lYo`000?l03BP00_l03BP01?l0003o00dWo`0=9ol03BL3o`000004o`0<9_l0
003o00XTo`0:90;o00000_l02282o`0000?o00LP0_l00013ooooo`00Joooool01?l0003ooooooooo
ool0000Fooooo`Go000000?o00LQo`000?l01b400_l01b400ol0003o00LQo`000002o`000003o`0:
9?l0003o00XT00;o00XT00Co0000o`099?l0003o00000ol03BL00ol0003o00`Vo`000002o`000003
o`0?:Ol0003o00hX00;o00hX0_l000000ol04B_o0000o`0@:P02o`0@:P?o000000Co014[o`000?l0
42[o010Z0ol000001?l04B_o0000o`0?:Ol03bT2o`0000?o00lY00Go0000o`0=:?l0003o00lYo`00
0002o`0=9`;o00000_l032H3o`000006o`0:9?l0003o00PRo`000?l022;o00000_l01b03o`0004?o
oooo001[ooooo`04o`000?ooooooooooo`0001?ooooo1Ol000000ol01b7o0000o`078@02o`078@03
o`000?l01b7o000000;o000000?o00XTo`000?l02R@00_l02R@00ol0003o00XTo`000002o`0000;o
00dW00?o0000o`0=9ol000000_l000000ol042[o0000o`0?:@02o`0?:@05o`000?l03RSo0000o`0B
;?l000000_l04B/01Ol0003o010Zo`000?l04Rco000000?o014[0_l000001?l04Rco0000o`0A:ol0
4B/3o`0000;o014[00?o0000o`0?:Ol03bT00_l00002o`0?:@?o000000Ko00hXo`000?l032Ko0000
o`0=9ol00002o`0:90;o00000ol02282o`0000;o00LP0_l00012ooooo`00Joooool01?l0003ooooo
ooooool0000@ooooo`?o00000_ooool2o`0000?o00LQ00?o0000o`078Ol01b400_l000000ol02bGo
0000o`0:9002o`0:9003o`000?l02RCo000000;o000000?o00hXo`000?l03BL00_l03BL2o`000003
o`0A:ol0003o010Z00;o010Z00?o0000o`0?:Ol03bT00_l00003o`0B;004o`000?l04B_o0000o`00
00?o018/00Co0000o`0A:ol0003o00000ol04R`2o`000003o`0C;Ol0003o014[00;o014[0ol00000
1_l04B_o0000o`0?:Ol0003o010Zo`0000;o00hX0_l00003o`0=9`;o00000_l02bD01Ol0003o00PR
o`000?l02B?o000000;o00LP0ol00011ooooo`00K?ooool2o`0000oooooo0_l00003ooooo`;o0000
0_l01b400ol0003o00LQo`078@03o`000005o`0;9Ol0003o00/Uo`0;9Ol000000_l02R@2o`000003
o`0>:?l0003o00hX00;o00hX00Go0000o`0=9ol0003o014/o`000002o`0A:`03o`000?l042[o010Z
00?o000000Co01<]o`000?l04Rco018/0ol000001?l052ko0000o`0B;?l04R`3o`0000;o01@^00Co
0000o`0B;?l0003o00000ol04bd01Ol0003o014[o`000?l04bgo000000;o014[0_l00003o`0@:PCo
00000_l03BL2o`0000?o00/U0_l00002o`098`?o000000?o00LPo`000?l00000@Oooool007[ooooo
1?l000001_oooooo0000o`000?l0003o00LQo`0000;o00LQ0ol000000ol02bGo0000o`0;9@02o`0;
9@03o`000?l02bGo000000;o000000Go00lYo`000?l03RSo00hXo`000002o`0>:0;o00000ol04B`0
0ol0003o014[o`000002o`000004o`0D;_l0003o01<]o`0C;@?o000000?o01H_o`000?l052h00_l0
52h2o`000003o`0F;ol0003o01@^00;o01@^0_l00002o`0E;P03o`000?l04bgo01<]00;o00000ol0
4bd2o`000004o`0B;?l0003o010Zo`0@:P;o000000?o00lYo`000?l03bT00_l00002o`0=9`09o`00
0?l02bGo0000o`0;9Ol0003o00TSo`000?l02B?o000000;o00LP0ol00010ooooo`00N?ooool2o`00
00;ooooo0ol000000ol01b7o0000o`078@02o`078@;o000000Go00/Vo`000?l02bGo00/Uo`000002
o`0;9@?o000000?o00lYo`000?l03bT00_l03bT00ol0003o00hXo`000002o`000004o`0B;?l0003o
014/o`0A;0?o000000?o01D_o`000?l052h00_l052h2o`000003o`0G<?l0003o01H_00;o01H_00Co
0000o`0D;_l0003o00000ol05Rl01Ol0003o01@^o`000?l05c3o000000;o01D^0ol000001?l05Boo
0000o`0C;Ol04bd2o`0000;o018/0ol00002o`0A;0?o000000Co010Zo`000?l03BOo00dW0_l00002
o`0;9@;o00000_l02B<3o`000004o`078Ol0003o0000o`0003oooooo001eooooo`?o000000Kooooo
o`000?l0003o0000o`078Ol00003o`078@04o`000?l01b7o0000o`0000?o00/V00?o0000o`0;9Ol0
2bD00_l000000ol042[o0000o`0?:@02o`0?:@03o`000?l03bWo000000;o000000?o01<]o`000?l0
4R`00_l04R`2o`000003o`0G;ol0003o01D_00;o01D_00Co0000o`0D;_l0003o00000ol05c000ol0
003o01H_o`0F;`02o`0000;o01P`00?o0000o`0F;ol05Rl00_l00003o`0G<0;o000000Co01P`o`00
0?l05Boo01D_0ol000001_l05Bko0000o`0B;?l0003o01@^o`0000?o014/0ol000004?l042[o0000
o`000?l0003o00hXo`000?l02bGo0000o`0<9_l0003o00TSo`000?l02B?o0000o`078Ol00002o`07
8@03o`000?oooooooooo03gooooo001cooooo`;o00000_ooool2o`000003o`078Ol0003o00LQ00;o
00LQ00?o0000o`078Ol01b400_l000000ol032Ko0000o`0;9P02o`0;9P04o`000?l02bGo0000o`00
00?o010Z00?o0000o`0?:Ol03bT00_l000000ol052ko0000o`0C;@02o`0C;@04o`000?l04Rco0000
o`0000?o01L_00?o0000o`0E;ol05Bl00_l000000ol06C7o0000o`0G<002o`0G<0?o000000Co01Xb
o`000?l0633o01P`0ol000001?l06C;o0000o`0G<?l05c02o`0000?o01P`0_l000000ol0637o0000
o`0E;P02o`0E;P08o`000?l052ko01@^o`0D;_l0003o014/o`000?l04bd3o`000004o`0A:ol0003o
00hXo`0>:0;o00000_l032H2o`0000?o00TS00Co0000o`078Ol01b7o00LQ0_l0000nooooo`00L?oo
ool3o`000006ooooool0003o0000o`000?l0227o00000_l01b400ol0003o00LQo`078@03o`000005
o`0<9_l0003o00`Vo`0<9_l000000_l02bH2o`000003o`0@:ol0003o010Z00;o010Z00Co0000o`0?
:Ol0003o00000ol052h00ol0003o01<]o`0C;@02o`000003o`0H<?l0003o01L_00;o01L_0ol00000
2Ol06S;o0000o`0I<Ol06C7o0000o`0G<?l0003o01`co`000003o`0J<P;o000000Co01`co`000?l0
6C;o01Tb0ol00002o`0J<P04o`000?l0633o0000o`0000?o01Pa00Go0000o`0E;_l0003o01L`o`00
0002o`0D;P;o00000_l04bd2o`0000?o014[0_l000001?l03bWo0000o`0<9_l00002o`0<9`08o`00
0?l02B?o0000o`0:9?l0003o00LQo`000?l01b42o`0003gooooo001^ooooo`;o000000Koooooo`00
0?l0003o0000o`088_l00003o`088@03o`000?l01b7o000000;o000000?o00`Vo`000?l032H00_l0
32H00ol0003o00`Vo`000002o`000005o`0A:ol0003o010[o`0@:ol000000_l042X2o`0000;o01D^
00?o0000o`0D;_l052h00ol000002Ol06C7o0000o`0H<?l0633o0000o`0G;ol0003o01`co`000003
o`0J<P04o`000?l06C7o0000o`0000?o01`c00Co0000o`0J<_l0003o00000ol073<2o`000003o`0M
=?l0003o01Xb00;o01Xb0_l00002o`0K<`03o`000?l0637o01Pa00;o00000_l05c03o`000006o`0F
;ol0003o01<]o`000?l052ko00000_l04B/2o`0000?o00lY00Co0000o`0<9ol032Oo00`W0_l00002
o`0:90;o00000_l01b42o`0003gooooo001[ooooo`?o000000Goooooo`000?l0003o00PRo`000003
o`088P03o`000?l0227o000000;o000000?o00dWo`000?l032H00_l032H00ol0003o00`Vo`000002
o`000003o`0B;?l0003o014[00;o014[00?o0000o`0@:ol000000_l000002Ol05Roo0000o`0E;_l0
5Bko0000o`0D;_l0003o01Xbo`000003o`0I<@04o`000?l0633o0000o`0000?o01`c00?o0000o`0J
<_l000000_l000001?l07SGo0000o`0L<ol073<3o`0000;o01he00Co0000o`0L<ol0003o00000ol0
7C@01Ol0003o01Xbo`000?l07SGo000000;o01/c0ol000001_l06c;o0000o`0G<?l0003o01Xbo`00
00;o01H_0_l00002o`0D;P?o00000_l04R`04?l0003o00lYo`000?l042[o0000o`0<9ol0003o00dW
o`000?l02RCo0000o`0:9?l0003o00LQo`000?l01b42o`0003cooooo001Xooooo`?o000000Kooooo
o`000?l0003o0000o`088_l00002o`088P03o`000?l022;o00PR00;o000000?o00dWo`000?l03BL0
0_l03BL00ol0003o00`Vo`000002o`000003o`0B;?l0003o018/00;o018/00?o0000o`0A:ol00000
0_l000000ol05c3o0000o`0F;`02o`0F;`04o`000?l05Bko0000o`0000?o01Xb00?o0000o`0I<Ol0
00000_l000001?l07SGo0000o`0L<ol073<3o`000003o`0P=_l0003o01he00;o01he0_l000000ol0
8COo0000o`0N=@02o`0N=@;o00000_l083H00ol0003o01ddo`0M=002o`0000?o01he0_l000001?l0
7SGo0000o`0K<_l06c82o`0000?o01Xb0_l00002o`0H<@04o`000?l052ko0000o`0000?o018/0_l0
0002o`0@:P;o00000_l03BL2o`0000;o00XT0_l00002o`078@?o0000>oooool006Kooooo0_l00000
1_oooooo0000o`000?l0003o00PQo`0000?o00PR00?o0000o`088_l000000_l000001Ol03BOo0000
o`0=9ol03BOo000000;o00dW0_l000000ol04bgo0000o`0B;002o`0B;003o`000?l04Rco000000;o
000000?o01Pao`000?l05c000_l05c000ol0003o01H_o`000002o`000003o`0L<ol0003o01Xb00;o
01Xb0_l000000ol07cKo0000o`0N=@02o`0N=@;o000000?o028ho`000?l083H00_l083H01?l0003o
01heo`000?l00003o`0Q=`05o`000?l07SGo0000o`0S>?l000000_l083H3o`000004o`0Q=ol0003o
01heo`0N=@;o00000ol07SD2o`000004o`0M=?l0003o01Xbo`0J<P;o00000ol06343o`00000Eo`0F
;ol0003o018/o`000?l04bgo0000o`0@:_l0003o014[o`000?l03BOo0000o`0>:?l0003o00XTo`00
0?l02RCo0000o`078Ol0003o00LQ00;o0000>oooool006?ooooo0ol000001Ooooooo0000o`000?l0
1b7o000000?o00PQ00?o0000o`088_l000000_l000001Ol03BOo0000o`0=9ol03BOo000000;o00dW
0ol000001Ol04bgo0000o`0C;Ol04bgo000000;o018/0_l000000ol06C7o0000o`0H<@02o`0H<@03
o`000?l05c3o000000;o000000?o01ddo`000?l073<00_l073<01?l0003o01Xbo`000?l00003o`0O
=P04o`000?l07SGo0000o`0000?o028h00?o0000o`0P=_l083H00_l00002o`0S>003o`000?l08COo
024g00;o00000ol08cP2o`000004o`0T>Ol0003o024go`0Q=`?o000000Co028go`000?l07SGo01he
0_l00003o`0M=0;o00000_l073<01?l0003o01Pao`000?l06S82o`000003o`0F;ol0003o000000;o
01<]0_l00002o`0A:`;o00000_l03RP2o`0000;o00XT0_l00003o`078@;o0000>_ooool0067ooooo
0_l000001_oooooo0000o`000?l0003o00LQo`0000;o00LQ00?o0000o`088Ol022400_l000000ol0
3BOo0000o`0=9`02o`0=9`03o`000?l03BOo00dW00;o000000Go01@^o`000?l04bgo01<]o`000002
o`0C;@05o`000?l04Rco0000o`0J<_l000000_l06C400ol0003o01Pao`0H<@02o`000003o`0N=Ol0
003o01dd00;o01dd00?o0000o`0L<ol073<00_l00002o`0Q=`03o`000?l07cKo01lf00;o000000?o
02@io`000?l08SP00_l08SP3o`000004o`0V>_l0003o02<ho`0S>0?o000000Co02Hjo`000?l08cSo
02<h0_l00003o`0T>@;o000000?o02Djo`000?l08SL00_l08SL2o`0000;o024g00Co0000o`0M=?l0
003o00000ol073<2o`0000;o01Xb0ol000004?l0633o0000o`0C;Ol0003o01D^o`000?l04B_o0000
o`0B;?l0003o00hXo`000?l03RSo0000o`0:9?l00002o`0;9@04o`000?l01b7o0000o`078@;o0000
>Oooool005kooooo1_l000000ol01b7o0000o`078@02o`078@03o`000?l01b7o000000;o000000Go
00dWo`000?l03BOo00dWo`000002o`0=9`04o`000?l03BOo0000o`0000;o01@^00Ko0000o`0C;Ol0
4bgo01<]o`000?l04bd2o`0000;o01Xb00So0000o`0I<Ol06C7o0000o`0H<Ol0003o020fo`0000;o
01he00?o0000o`0M=?l07C@00ol000002Ol08cSo0000o`0Q=ol08COo0000o`0O=_l0003o02Ljo`00
0002o`0T>@05o`000?l08SSo0000o`0X??l000000ol09SX2o`000003o`0Y??l0003o02Hj00;o02Hj
0_l000001?l0:3_o0000o`0T>Ol093T2o`0000?o02Dj00Co0000o`0R=ol0003o00000ol08CL2o`00
00;o020f00Wo0000o`0L<ol0003o01heo`000?l06S;o0000o`0L=?l000000_l06302o`0000;o01D^
0_l00003o`0B;005o`000?l03RSo00hXo`0>:?l000000ol02bD2o`0000;o00LQ0_l0000iooooo`00
G?ooool2o`000005ooooool0003o0000o`078Ol000000ol01b400ol0003o00LQo`000002o`000005
o`0<9ol0003o00dWo`0=9ol000000_l03BL00ol0003o00dWo`0=9`02o`000003o`0D;_l0003o01@^
00;o01@^00?o0000o`0C;Ol000000_l000000ol06c?o0000o`0J<P02o`0J<P04o`000?l06C7o0000
o`0000;o020f00?o0000o`0N=Ol07SD00ol000000ol09C[o0000o`0S>002o`0S>004o`000?l08COo
0000o`0000?o02Lj00Co0000o`0T>Ol0003o00000ol0:3`01?l0003o02Hjo`000?l00003o`0Y?004
o`000?l09S[o0000o`0000?o02Pk0_l000000ol0:Cco0000o`0U>P02o`0U>P;o00000_l09CX01Ol0
003o024go`000?l09CWo000000;o020f0_l00002o`0N=@;o00000_l073@3o`000004o`0I<_l0003o
01D^o`0000;o01H_013o0000o`0B;?l0003o018/o`000?l03RSo0000o`0?:Ol0003o00/Uo`000?l0
2bGo0000o`078Ol0003o00LQ0_l0000hooooo`00FOooool6o`000005o`078Ol0003o00LQo`078Ol0
00000_l01b42o`000003o`0<9_l0003o00`W00;o00`W00Go0000o`0=9ol03BOo0000o`0=9`03o`00
0006o`0E;_l0003o01@^o`0D;_l0003o01@^0ol000000ol073?o0000o`0K<`02o`0K<`03o`000?l0
6S;o000000;o000000?o028go`000?l083H00_l083H2o`000003o`0W>ol0003o02Dj00;o02Dj00?o
0000o`0S>?l000000_l000001?l0:Cco0000o`0W>_l09cX3o`000004o`0/?Ol0003o02Plo`0X?0?o
000000?o02`no`000?l0:C`00_l0:C`2o`0000;o02`m00Co0000o`0X>ol0003o00000ol0:C`01Ol0
003o02Djo`000?l0:Sco000000;o02Dj0_l00003o`0U>@;o000000Ko02<ho`000?l07SGo0000o`0Q
=ol00002o`0L=0;o00000ol06C801?l0003o01H_o`0F;ol05Rl2o`0000;o018/0_l00002o`0?:@;o
00000_l02bD2o`0000;o00LQ0ol0000gooooo`00:Oooool3o`0000Cooooo0_l00004ooooo`;o0000
7_ooool3o`000005ooooool0003o0000o`078Ol000000ol01b400ol0003o00LQo`000002o`000005
o`0<9_l0003o00`Vo`0<9_l000000_l032L00ol0003o00dWo`000002o`000003o`0D;_l0003o01D^
00;o01D^00Ko0000o`0D;_l0003o0000o`0M=?l00003o`0L<`03o`000?l06c?o000000;o000000?o
02<ho`000?l08SL00_l08SL01?l0003o020fo`000?l00003o`0W>`03o`000?l09C[o02Dj00;o0000
00?o02`mo`000?l0:C`00_l0:C`2o`000003o`0^?ol0003o02`m00;o02`m0_l000000ol0<3oo0000
o`0/?P02o`0/?P04o`000?l0:Cco0000o`0000?o02`m0_l00002o`0]?P03o`000?l0:Cco02Tl00;o
00000ol0:S`2o`000004o`0Y??l0003o02Dio`0U>@;o00000_l08cP2o`0000?o024g0ol000006Ol0
7SGo0000o`0I<_l0003o01/co`000?l05Roo0000o`0H<?l0003o018/o`000?l04bgo0000o`0?:Ol0
003o00lYo`000?l02bGo0000o`0;9Ol0003o00LQo`000?l022400_l0000gooooo`00:_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006ooo
ool2o`000006ooooool0003o0000o`000?l01b7o00000_l01b400ol0003o00LQo`000002o`000003
o`0<9_l0003o00`V00;o00`V00?o0000o`0<9_l000000_l032L2o`000003o`0D;Ol0003o01@^00;o
01@^00?o0000o`0E;_l000000_l000001Ol07SGo0000o`0M=?l07CCo000000;o01`c0_l000000ol0
9CWo0000o`0S>002o`0S>003o`000?l08SOo000000;o000000?o02Tlo`000?l09c/00_l09c/01?l0
003o02Djo`000?l00003o`0/?@04o`000?l0:Cco0000o`0000?o02ho00Co0000o`0/?Ol0003o0000
0ol0<3l00ol0003o02`no`0/?P02o`0000;o02lo00Go0000o`0/?Ol0003o0391o`000002o`0]?P?o
000000Co02hoo`000?l0:Sco02Xl0_l00002o`0Y?0?o000000Ko02Pko`000?l08cSo0000o`0V>_l0
0003o`0Q=`04o`000?l07SGo0000o`0N=@;o00000_l06c<2o`0000;o01P`0_l00002o`0C;@;o0000
0_l03bT2o`0000;o00/U0_l00002o`088@?o0000=_ooool002;ooooo1Ol00003ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Hooooo`Ko
000000?o00LQo`000?l01b400_l01b401_l0003o00LQo`000?l0003o00/Uo`0000?o00`V00?o0000
o`0<9_l000001Ol000001_l04bgo0000o`0D;Ol052go0000o`0D;P?o000000Go01heo`000?l07SGo
01heo`000002o`0M=005o`000?l073?o0000o`0V>_l000000_l09CT00ol0003o02<ho`0S>002o`00
0003o`0[?Ol0003o02Tl00;o02Tl00?o0000o`0W>ol09c/00_l00002o`0^?`03o`000?l0;3go02`m
00;o000000?o0351o`000?l0;Sl00_l0;Sl2o`000003o`0c@_l0003o030o00;o030o0ol000001?l0
<d;o0000o`0_?ol0;cl2o`0000?o03910_l000001?l0<d7o0000o`0^?ol0;Sl3o`000006o`0^?ol0
003o02Tlo`000?l0;Sko00000ol0:3/02?l0003o02Hjo`0V>_l09S[o0000o`0Q=ol0003o02@i0ol0
00006Ol08COo0000o`0K<ol0003o01ddo`000?l0633o0000o`0I<Ol0003o01<]o`000?l052ko0000
o`0?:Ol0003o010Zo`000?l02bGo0000o`0<9_l0003o00PQo`000?l022800ol0000eooooo`00:_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00005_ooool5o`000003o`078Ol0003o00LQ00;o00LQ00?o0000o`078Ol000000_l000001Ol02bGo
0000o`0;9Ol02bGo000000;o00`V0_l000001Ol04Rco0000o`0C;?l04bco000000?o01<]00Ko0000
o`0D;Ol0003o0000o`0N=Ol00003o`0N=@05o`000?l07SGo01heo`000?l07C@00_l00002o`0V>P08
o`000?l09CWo02Dio`000?l08cSo0000o`0]?_l00002o`0[?@03o`000?l0:Cco02Tl00?o000000Wo
0350o`000?l0;Soo02hoo`000?l0;3go0000o`0d@_l000000_l0<D401Ol0003o02hoo`000?l0=d?o
000000;o03=200Go0000o`0`?ol0003o03M4o`000003o`0c@P;o000000Co03I3o`000?l0<T7o0391
0_l00003o`0c@@;o000000?o03=2o`000?l0;Sl00_l0;Sl02Ol0003o02hno`0^?_l0;Sko0000o`0X
>ol0003o02`no`000002o`0V>P;o00000_l093T2o`0000;o024g0_l00002o`0M=0;o00000ol06C40
1Ol0003o01@^o`0D;_l052ko000000?o010Z00Go0000o`0<9_l032Ko00`Vo`000002o`088P?o0000
=Oooool002[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0001?ooooo1_l000001Ol01b7o0000o`078Ol01b7o000000;o00LQ0_l000000ol0
2bGo0000o`0;9@02o`0;9@03o`000?l02bGo000000;o000000Go014[o`000?l04Rco018/o`000002
o`0C;003o`000?l04bgo000000;o000000Go01ddo`000?l07SGo01heo`000002o`0N=@03o`000?l0
7SGo000000;o000000?o02Pko`000?l09SX00_l09SX01?l0003o02Dio`000?l00002o`0]?P03o`00
0?l0:cgo02/m00?o000000?o03=2o`000?l0<D000_l0<D001?l0003o02hoo`000?l00003o`0d@P04
o`000?l0<D7o0000o`0000?o03M300Co0000o`0c@_l0003o00000ol0=d@01?l0003o03=2o`000?l0
0003o`0f@`;o000000?o03Q4o`000?l0<d400_l0<d401_l0003o03=2o`0c@_l0<d;o0000o`0^?`;o
00000ol0;Sh2o`0000;o02`n0ol000003_l0:Sco0000o`0T>Ol0003o02Ljo`000?l08COo0000o`0S
>?l0003o01ddo`000?l07cKo00000_l06C42o`0000;o01@^00So0000o`0F;ol0003o010Zo`000?l0
4B_o0000o`0<9P;o000000Ko00PRo`000?l022;o0000ooooool0000dooooo`00:Oooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Aooooo`;o000000Gooooo
o`000?l0003o00LPo`000003o`078@03o`000?l01b7o000000;o000000Ko00/Uo`000?l02bGo00/U
o`000?l02bD3o`000005o`0A:ol0003o014[o`0A:ol000000_l04R`00ol0003o01</o`000002o`00
0005o`0L<ol0003o01ddo`0M=?l000000_l07SD00ol0003o01heo`0N=@02o`000003o`0Y??l0003o
02Pk00;o02Pk00?o0000o`0V>_l000000_l000000ol0;coo0000o`0]?P02o`0]?P;o000000?o03I3
o`000?l0<d800_l0<d800ol0003o0350o`000002o`000004o`0hA?l0003o03A2o`0d@P?o000000Co
03]5o`000?l0=d?o03M30ol000001?l0?4Ko0000o`0gA?l0=d@3o`0000;o03]500Co0000o`0f@ol0
003o00000ol0>4@01?l0003o03=1o`000?l00003o`0c@P;o00000_l0<d802Ol0003o02hno`000?l0
<T7o0000o`0/?_l0003o0310o`000002o`0Z?0;o00000_l09cX2o`0000?o02<h00Co0000o`0O=_l0
7cKo01lf0_l00002o`0J<P;o00000ol05Rl00ol0003o014[o`0A:`02o`0000;o00`V00Co0000o`08
8_l022;o00PR0ol0000cooooo`00:_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`00
00oooooo1_l000001Ol01b3o0000o`078?l01b3o000000;o00LQ0_l000000ol02RCo0000o`0;9@02
o`0;9@06o`000?l02bGo0000o`000?l042[o00000ol04B/01Ol0003o014[o`0A:ol0003o018/00;o
000000?o01/co`000?l073<00_l073<01Ol0003o01ddo`0M=?l0003o01he00?o000000Go02Xlo`00
0?l0:Cco02Tlo`000002o`0X>`;o000000?o0391o`000?l0;cl00_l0;cl01?l0003o02dno`000?l0
0003o`0f@`03o`000?l0<d;o03=200;o000000?o03]6o`000?l0>4@00_l0>4@2o`000003o`0nAol0
003o03]500;o03]50_l000000ol0@4So0000o`0lAP02o`0lAP;o000000?o0418o`000?l0>dD00_l0
>dD2o`0000;o03e700?o0000o`0hA?l0>4@00_l00002o`0iA@05o`000?l0<d;o0000o`0iAOl00000
0_l0<d82o`0000;o03910_l00003o`0`@0;o000000?o02dno`000?l09cX00ol00003o`0S>005o`00
0?l07cKo01lfo`0O=_l000000ol06S801?l0003o01H_o`0F;ol05Rl2o`00000:o`0A:ol0003o014[
o`000?l032Ko0000o`0<9_l0003o00PRo`0000;o00PR00?o0000ooooooooool0<Oooool004Gooooo
1Ol000000ol01b3o0000o`078002o`078003o`000?l01b3o000000;o000000Ko00XTo`000?l02RCo
00XTo`000?l02bD3o`000005o`0@:_l0003o010Zo`0@:_l000000_l04B/00ol0003o014[o`000002
o`000005o`0J<_l0003o01/co`0K<ol000000_l073<00ol0003o01ddo`000002o`000005o`0Y??l0
003o02Xlo`0Z??l000000_l0:C`01Ol0003o02Pko`000?l0=4;o000000;o039100?o0000o`0_?ol0
;cl00_l000000ol0>DCo0000o`0f@`02o`0f@`04o`000?l0<d;o0000o`0000?o03]600Co0000o`0h
A?l0003o00000ol0?TL01?l0003o03]5o`000?l00003o`10B004o`000?l0?4Ko0000o`0000?o0418
00Go0000o`0kAOl0003o04=9o`000002o`0mA`?o000000Co03m7o`000?l0>DGo03U50_l00003o`0i
A@;o000000Ko03Q4o`000?l0<T7o0000o`0g@ol00002o`0`@0;o00000ol0;Ch04ol0003o02Xlo`00
0?l0:Sco0000o`0S>?l0003o02Djo`000?l07cKo0000o`0Q=ol0003o01Xbo`000?l073?o0000o`0F
;ol000000_l05bl00ol0003o014[o`0A:`02o`0000;o00`V0_l00002o`088P?o0000<_ooool004;o
oooo1_l000001_l01b3o0000o`078?l01b3o0000o`0780?o000000?o00XTo`000?l02R@00_l02R@0
1_l0003o00XTo`000?l0003o00lYo`0000?o010Z00?o0000o`0@:_l000001?l000000ol06C7o0000
o`0J<P02o`0J<P03o`000?l06c?o000000Co000000Go02Lko`000?l0:Cco02Tlo`000003o`0Z?004
o`000?l0:Cco0000o`0000;o03A200?o0000o`0b@Ol0<T400ol000001Ol0?4Ko0000o`0iA?l0>DCo
000000;o03I30_l00002o`0oA`03o`000?l0>dKo03]600;o000000?o04=9o`000?l0?TL00_l0?TL2
o`000003o`15B_l0003o041800;o04180_l000000ol0AD[o0000o`10B002o`10B0;o00000ol0@dT2
o`000004o`15B_l0003o03m7o`0oA`?o000000Co03m8o`000?l0>DGo03U50_l00002o`0hA0;o0000
0ol0=d<2o`0000;o03A200Oo0000o`0]?_l0003o0000o`0Z??l0003o02Xl00;o00000_l09CX2o`00
00;o024g0_l00002o`0L<`;o00000_l05bl2o`00000:o`0A:ol0003o018/o`000?l032Ko0000o`0=
9ol0003o00PRo`0000;o00PR0_l0000aooooo`00?oooool3o`000005ooooool0003o0000o`068?l0
00000ol01b001_l0003o00LPo`000?l0003o00TTo`0000?o00XT00?o0000o`0:9?l000000_l00000
1_l03bWo0000o`0?:Ol03bWo0000o`0@:P?o000000Go01L`o`000?l0633o01P`o`000002o`0I<@03
o`000?l06S;o000000;o000000Go02@io`000?l09S[o02Hjo`000002o`0W>`05o`000?l0:Cco02Tl
o`000?l0:S`00ol000000ol0=T?o0000o`0d@P02o`0d@P;o000000Go03m7o`000?l0?4Ko03a6o`00
0002o`0iA0?o000000Wo0499o`000?l0?dOo03m7o`000?l0>dKo0000o`17Bol000000_l0@dT01Ol0
003o03i7o`000?l0BDco000000;o04E:00Go0000o`10B?l0003o04Y<o`000002o`15BP05o`000?l0
@4So0000o`18C?l000000_l0@dT2o`0000?o04E:0_l000001?l0AT_o0000o`0oB?l0?dP3o`000006
o`0oAol0003o03Q4o`000?l0?TOo00000ol0=d<01?l0003o03A2o`0d@_l0=482o`0000;o035001?o
0000o`0Z??l0003o02dno`000?l09C[o0000o`0X>ol0003o024go`000?l08cSo0000o`0L<ol0003o
01ddo`000?l05boo000000;o01P`00?o0000o`0B;?l04R`00_l00002o`0=9`;o00000_l02283o`00
037ooooo000mooooo`;o000000Koooooo`000?l0003o0000o`068?l00002o`068003o`000?l01b3o
000000;o00000_l02B<00ol0003o00TTo`000002o`0:90;o000000?o00hXo`000?l03bT00_l03bT0
1_l0003o00lYo`000?l0003o01H_o`0000?o01L`00Go0000o`0H<?l0633o0000o`0I<@02o`000003
o`0S>?l0003o02@i00;o02@i00Go0000o`0V>_l09S[o0000o`0W>`05o`000003o`0g@ol0003o03I3
00;o03I300Co0000o`0d@_l0003o00000_l0?dL01?l0003o03a6o`0lA_l0?4H2o`000003o`16Bol0
003o049900;o049900Co0000o`0oAol0003o00000ol0Ad/01?l0003o04=9o`000?l00003o`19C004
o`000?l0AD[o0000o`0000?o04Y<00Co0000o`15B_l0003o00000ol0B4`2o`000004o`1;COl0003o
04E:o`15BP;o00000ol0AT/2o`000003o`16Bol0003o03m700;o03m700go0000o`0nAol0?TOo03i7
o`000?l0=d?o0000o`0lA_l0003o03A2o`000?l0>4Co000000;o03500ol000000ol0;Cko0000o`00
0002o`0X>`;o00000_l08cP2o`0000;o01dd0_l00002o`0H<0;o000000_o018/o`000?l04Rco0000
o`0=9ol0003o00dWo`000?l022;o0000o`088P03o`00033ooooo000jooooo`Ko00000_l01R000ol0
003o00HPo`000004o`0000;o00TS00?o0000o`098ol02B<01Ol000001_l03RSo0000o`0>:?l03RSo
0000o`0?:@?o000000Go01D^o`000?l05Roo01H_o`000002o`0G<003o`000?l0633o000000;o0000
00Go024go`000?l08cSo02<ho`000002o`0T>@03o`000?l09S[o000000;o000000Co03=2o`000?l0
=T?o00000ol0=d<00ol0003o03I3o`000002o`000003o`12BOl0003o03m700;o03m700Co0000o`0l
A_l0003o00000_l0AT/00ol0003o0499o`12B@03o`000004o`1;COl0003o04M;o`17B`?o000000Co
04i>o`000?l0BDco04U<0ol000001?l0Cdko0000o`1:C?l0BT`3o`000004o`1>C_l0003o04Q<o`18
C0;o00000ol0Bdd2o`000003o`1=C_l0003o04I;00;o04I;00Ko0000o`16Bol0AT_o04I;o`000?l0
?dL2o`0000?o03i70_l00002o`0lAP;o00000ol0>4@2o`00000Do`0d@_l0003o0000o`000?l0<43o
0000o`0X>ol0003o02/mo`000?l08cSo0000o`0U>Ol0003o01ddo`000?l07cKo0000o`0H<?l00002
o`0I<@05o`000?l04Rco018/o`0B;?l000000_l03BL2o`000006o`088_l0003o00PRo`000?oooooo
00001oooool2o`0002Kooooo000hooooo`;o000000?oooooo`000?l000000ol00002o`0680;o0000
00?o00PRo`000?l02B<00_l02B<00ol0003o00TSo`000002o`000006o`0=9ol0003o00dWo`0=9ol0
003o00hX1Ol000000ol052go0000o`0E;P02o`0E;P03o`000?l05Roo000000Co000000?o01lfo`00
0?l08CL00_l08CL00ol0003o02<ho`000002o`0T>@;o000000Go0350o`000?l0<d;o03=2o`000002
o`0f@`03o`000?l0=d?o03M300;o000000?o04E:o`000?l0@TT00_l0@TT00ol0003o03m7o`000002
o`000003o`19C?l0003o04I;00;o04I;0_l000000ol0Cdko0000o`1;C@02o`1;C@;o000000?o051>
o`000?l0CTh00_l0CTh2o`000003o`1ACOl0003o04m>00;o04m>0_l000000ol0DDgo0000o`1>CP02
o`1>CP;o000000?o051>o`000?l0Bdd00_l0Bdd01_l0003o04e>o`1=C_l0CDko0000o`16B`;o0000
0ol0AT/2o`0000;o04E:00Wo0000o`0nAol0003o04=9o`000?l0?4Ko0000o`11B?l000000_l0>4@2
o`0000;o03A20_l00002o`0`@0;o00000ol0:cd01Ol0003o02Dio`0U>Ol09CWo000000?o01lf00Co
0000o`0I<Ol06C7o01Ta0_l000001Ol04Rco0000o`000?l03BOo000000;o00dW00Co0000o`088_l0
22;o00PR0_l00006ooooo`04o`000?ooooooooooo`0002Gooooo000eooooo`?o000000?oooooo`00
0?l000000_l01Ql00ol0003o00HPo`000002o`000005o`088_l0003o00PRo`088_l000000_l02B<2
o`000003o`0<9_l0003o00dW00;o00dW00Ko0000o`0=9ol0003o0000o`0B;?l00002o`0C;@05o`00
0?l052go01@]o`000?l05Bh00ol000001Ol07CCo0000o`0N=Ol07SGo000000;o01lf00?o0000o`0Q
=ol000001Ol000001Ol0;coo0000o`0a@?l0<D3o000000;o03=200?o0000o`0f@ol000000_l00000
1Ol0AT_o0000o`15B_l0AD[o000000;o04990_l000000ol0CDko0000o`19C002o`19C004o`000?l0
AT_o0000o`0000?o04m>00Co0000o`1;COl0003o00000ol0D4h01?l0003o04i>o`1>C_l00003o`1A
C@04o`000?l0Cdko04m>o`0000?o055=00Co0000o`1>C_l0003o00000ol0D4h01?l0003o04]=o`00
0?l00003o`1=CP;o00000_l0CTh01Ol0003o04I;o`000?l0CDko000000;o04E:0_l00002o`13B@;o
00000ol0@DP2o`000008o`0mA_l0003o03A2o`000?l0>4Co0000o`0`@?l00002o`0c@@0?o`000?l0
:cgo0000o`0]?_l0003o02Dio`000?l09c_o0000o`0O=_l0003o020go`000?l06C7o000000;o01Xb
00Co0000o`0C;Ol04bgo00000ol03BL2o`000005o`088_l0003o0000ooooool000001Oooool01?l0
003oooooooooool0000Uooooo`00<oooool2o`000004ooooool0003o0000o`0000;o00HO00Ko0000
o`067ol0003o0000o`088_l00003o`088P03o`000?l022;o000000;o000000Ko00`Vo`000?l032Ko
00`Vo`000?l03BL3o`000005o`0A:ol0003o018/o`0B;?l000000_l04bd01_l0003o01@]o`000?l0
003o01/co`0000?o01dd00Go0000o`0N=Ol07SGo0000o`0O=P02o`000005o`0[?Ol0003o02dno`0]
?_l000000ol0;cl01?l0003o0350o`000?l0<d83o`000005o`14B_l0003o04I;o`16Bol000000_l0
ADX01Ol0003o0499o`000?l0D4ko000000;o04e>00?o0000o`19C?l0BD`00_l000000ol0DDgo0000
o`1?CP02o`1?CP;o000000?o059=o`000?l0D4h00_l0D4h01?l0003o04i>o`000?l00003o`1AC@04
o`000?l0Cdko0000o`0000?o055=0_l000000ol0Ddgo0000o`1@CP02o`1@CP;o00000_l0DDd01Ol0
003o04e>o`000?l0DDgo000000;o04i>0_l00003o`1=CP;o000000Ko04a=o`000?l0@dWo0000o`19
C?l00002o`11B0;o00000ol0?DH00ol0003o03Q4o`0hA002o`0000?o03=10_l00002o`0]?P;o0000
0_l09c/2o`0000;o020g0_l00002o`0J<P;o000000Ko01<]o`000?l052go0000o`0=9ol00002o`0>
:003o`000?l022;o00PR00;o00001Oooool01?l0003oooooooooool0000Uooooo`00<?ooool6o`00
00;o00HO00?o0000o`067ol01Ql00_l000001Ol022;o0000o`088_l022;o000000;o00PR0_l00000
0ol02bGo0000o`0<9P02o`0<9P06o`000?l032Ko0000o`000?l042_o00000ol04B/00ol0003o018/
o`000004o`000005o`0J<_l0003o01/co`0K<ol000000_l07C@5o`000005o`0Y??l0003o02/mo`0[
?Ol000000_l0;Ch00ol0003o02loo`000004o`000003o`11B?l0003o04A:00;o04A:00Go0000o`16
Bol0AT_o0000o`15BP02o`0000;o051>00?o0000o`1=C_l0CDh00ol000002Ol0DTgo0000o`1ACOl0
DDgo0000o`1?C_l0003o05E<o`000002o`1BC@03o`000?l0D4ko051>00;o00000_l0Dd`00ol0003o
055=o`1AC@02o`0000;o05=<00Go0000o`1ACOl0003o05I;o`000002o`1CC@05o`000?l0D4ko0000
o`1DC?l000000_l0DDd2o`0000?o055=0_l000001?l0DDgo0000o`1=C_l0CDh2o`0000?o04a=00Co
0000o`19C?l0BDco04U<0_l00002o`16B`0Ko`000?l0?DKo0000o`12B?l0003o03Q4o`000?l0?4Ko
0000o`0c@Ol0003o03I3o`000?l0;Cko0000o`0`@?l0003o02Lko`000?l0:Cco0000o`0P=ol0003o
028ho`000?l06S;o000000;o01/c00?o0000o`0D;Ol052d00_l00002o`0>:0;o000000Go00PRo`00
0?l022;o00PRo`000004ooooo`04o`000?ooooooooooo`0002Gooooo000^ooooo`;o000000Cooooo
o`000?l0003o00000_l01Ql00ol0003o00HOo`000002o`000006o`078Ol0003o00PRo`088_l0003o
00PR0ol000001_l02bGo0000o`0;9Ol02bGo0000o`0<9P?o000000Ko010Zo`000?l042_o010[o`00
0?l04B/3o`000004o`0G<?l0003o01Tao`0000?o01Xb00?o0000o`0K<ol000000_l000001?l09CWo
0000o`0W>_l00003o`0Y?003o`000?l0:cgo000000;o02dn0_l000001Ol0>dGo0000o`0nAol0?TOo
000000;o045800Go0000o`14B_l0A4[o0000o`16B`03o`000003o`1ACOl0003o051>00;o051>0_l0
00000ol0E4co0000o`1BC@02o`1BC@04o`000?l0DDgo0000o`0000;o05E<00?o0000o`1BCOl0DTd0
0ol000001?l0ET_o0000o`1CC?l0Dd`3o`000004o`1FBol0003o05=<o`1CC0;o00000ol0ET/01?l0
003o05==o`000?l00003o`1DC0;o000000Co05A<o`000?l0DDgo055=0_l00003o`1AC@;o00000_l0
DDd01?l0003o04a=o`000?l00003o`19C004o`000?l0AT_o04I;o`16B`;o00000_l0@TP3o`0000;o
03a600Go0000o`0f@ol0=T?o03I3o`000003o`0`@005o`000?l0:Cco02Tlo`0Y??l000000_l08SP2
o`0000;o01/c0_l000001_l052go0000o`0D;_l0003o00hXo`0000;o00hX00?o0000o`088_l02280
0ol00003ooooo`04o`000?ooooooooooo`0002Gooooo000[ooooo`?o000000?oooooo`000?l00000
0_l01Ql00ol0003o00HOo`067`02o`0000;o00LQ00?o0000o`078Ol000001?l00002o`0:9003o`00
0?l02bGo000000Co00000_l03bT01Ol0003o010Zo`0@:_l0003o010[00;o000000?o01H_o`000?l0
5c000_l05c000ol0003o01Tao`000002o`0J<P;o000000Go02<ho`000?l09CWo02Dio`000002o`0W
>P03o`000?l0:Cco000000Go000000Go03Q4o`000?l0>dGo03]5o`000002o`0nA`03o`000?l0@DSo
000000;o04A:0_l000000ol0DTgo0000o`1AC@02o`1AC@04o`000?l0D4ko0000o`0000;o05A<00?o
0000o`1BCOl0DTd00ol000000ol0Ed[o0000o`1EC002o`1EC0;o000000?o05Q9o`000?l0ET/00_l0
ET/2o`000003o`1IBOl0003o05I;00;o05I;0_l000001?l0F4Wo0000o`1FBol0ET/3o`000004o`1G
B_l0003o05A<o`1DC0;o00000ol0E4`2o`0000;o05E;00Co0000o`1ACOl0003o00000ol0DDd2o`00
00;o051>00co0000o`19C?l0003o04m>o`000?l0AT_o0000o`1;COl0003o0498o`000?l0AT/2o`00
0003o`0lA_l0003o000000;o03I30_l00002o`0`@0;o00000_l0:C`2o`000006o`0R>?l0003o02@i
o`000?l06c?o00000_l073<00ol0003o01@^o`0D;P02o`0000;o00hX0_l000001Ol022;o0000o`08
8ol022?o000000Cooooo0_l0000Vooooo`00:?ooool3o`0000;ooooo0_l00002o`067`03o`000?l0
1Qoo000000;o000000Co00LQo`000?l01b7o00LQ0_l000001Ol02B?o0000o`0:9?l02RCo000000;o
00XT0_l000001Ol03BOo0000o`0>:?l03RSo000000;o00lY1Ol000001_l05Bko0000o`0F;ol05Roo
0000o`0G<0Ko000000Go024go`000?l08cSo02<ho`000002o`0U>@06o`000?l09c[o0000o`000?l0
<d7o00000_l0=T<02?l0003o03Q4o`0hA?l0>4Co0000o`0kAOl0003o03i71_l000001Ol0DDgo0000
o`1BCOl0DTgo000000;o055=0_l000000ol0ET_o0000o`1DC002o`1DC0;o000000?o05U9o`000?l0
EdX00_l0EdX01?l0003o05E<o`000?l00003o`1HB@04o`000?l0ET_o0000o`0000?o05U900Co0000
o`1FBol0003o00000ol0F4T2o`000003o`1JB?l0003o05M:00;o05M:0_l00002o`1HB@04o`000?l0
E4co0000o`0000?o05E;0_l00002o`1EC005o`000?l0DDgo0000o`1DC?l000000_l0D4h2o`0000;o
04m>0_l00003o`1;C@04o`000?l0AT_o04I;o`16B`;o00000_l0@4P2o`0000;o03Y50_l00002o`0c
@@;o00000_l0:cd00ol0003o02@io`0T>@02o`0000;o01`c0_l000001ol052ko0000o`0E;ol0003o
00hXo`000?l03RP00_l00002o`088`?o0000:oooool002Kooooo1ol000001?l01Qoo0000o`067ol0
1Ql2o`0000;o00LP00?o0000o`078Ol000000_l000001_l02B?o0000o`098ol02B?o0000o`0:90?o
000000Ko00dWo`000?l03BOo00dWo`000?l03RP3o`000005o`0B;?l0003o01@]o`0D;Ol000000_l0
5Bh01_l0003o01H_o`000?l0003o01ddo`0000?o01lf00Go0000o`0Q=ol08COo0000o`0S>005o`00
0005o`0`@?l0003o03=1o`0c@Ol000000_l0=T<00ol0003o03Q4o`000004o`000005o`1<COl0003o
04m>o`1?C_l000000_l0DDd01Ol0003o059=o`1BCOl0003o055=00;o00000ol0ET/01?l0003o05A<
o`000?l00003o`1IB@03o`000?l0Ed[o05M:00;o000000?o05]8o`000?l0F4T00_l0F4T2o`000003
o`1KAol0003o05U900;o05U90_l000000ol0FdOo0000o`1HB@02o`1HB@06o`000?l0FTSo05Y8o`1J
B?l0003o05M:0_l00003o`1HB@;o00000_l0F4T01Ol0003o05E;o`000?l0F4Wo000000;o05E<0_l0
0003o`1DC0;o000000Ko05=<o`000?l0Cdko0000o`1ACOl00002o`1;C@;o00000_l0AT/2o`0000;o
04180_l00002o`0jA@;o00000_l0<d42o`0000;o02/m0_l000001_l093Wo0000o`0U>_l0003o01`c
o`0000;o01dd00?o0000o`0E;ol05Bl00_l000001ol03RSo0000o`0?:Ol0003o00PSo`000?l02B<0
0ol0000Zooooo`008oooool3o`0000;ooooo0ol000000ol01Qoo0000o`067`03o`0000;o00LP00Co
0000o`078?l0003o00000_l022801Ol0003o00TSo`098ol0003o00TS00;o00000_l032H01Ol0003o
00dWo`0=9ol0003o00dW00;o000000?o014[o`000?l04R`00_l04R`00ol0003o01@]o`000004o`00
0005o`0K<ol0003o01ddo`0M=?l000000_l07cH5o`000004o`0[?Ol0003o02dno`0000?o031000Co
0000o`0c@Ol0003o03I30ol000001Ol0AD[o0000o`18C?l0B4co000000;o04a=00Co0000o`1?C_l0
Cdko00000_l0DDd01?l0003o059=o`000?l00002o`1HB@03o`000?l0ET_o05I;00;o000000?o05]7
o`000?l0FDT00_l0FDT01?l0003o05M:o`000?l00003o`1KB004o`000?l0F4Wo0000o`0000?o05]7
00Co0000o`1IBOl0003o00000ol0FdL01?l0003o05Q9o`000?l00003o`1JB0;o00000_l0FdL01Ol0
003o05Q9o`000?l0G4Oo000000;o05Q90_l00003o`1HB@;o000000Co05Q9o`000?l0E4co05A<0_l0
0002o`1CC0;o00000ol0DDd2o`00000Do`1?C_l0003o0000o`000?l0Bdgo0000o`10B?l0003o04E:
o`000?l0>TGo0000o`0mAol0003o03=1o`000?l0=T?o0000o`0[?Ol00002o`0]?P05o`000?l09C[o
02Djo`0U>_l000000ol07C@00ol0003o01D_o`000002o`0F;`03o`000?l03bWo00lY00;o000000?o
00TSo`000?l02B<00_l0000Zooooo`008_ooool6o`0000;o00HO1Ol000001?l01R3o0000o`078?l0
1b02o`0000;o00PR00?o0000o`088_l000001?l00002o`0;9@03o`000?l032Ko000000Co00000_l0
42X00ol0003o014[o`000002o`0B;0;o000000Go01Pao`000?l06S;o01Xbo`000002o`0K<`03o`00
0?l07CCo000000;o000000Co02Hjo`000?l0:3_o00000ol0:cd01?l0003o02dno`000?l0<405o`00
0003o`11B?l0003o04E:00;o04E:00Oo0000o`18C?l0B4co0000o`1<COl0003o04m>00Ko000000Wo
05U9o`000?l0F4Wo05Q9o`000?l0ET_o0000o`1MA_l000000_l0FdL00ol0003o05U9o`1IB@02o`00
00;o05e600?o0000o`1KB?l0FdP00_l00002o`1NA@03o`000?l0FdOo05]700;o00000_l0GTD00ol0
003o05]7o`1KA`02o`0000;o05e600Go0000o`1JB?l0003o05i4o`000002o`1KA`;o00000ol0G4L2
o`000004o`1LA_l0003o05Q9o`1HB@;o00000ol0F4T2o`000006o`1GB_l0003o05=<o`000?l0ET_o
00000_l0DDd4o`000003o`1?C_l0003o04]=00;o04]=00Go0000o`15B_l0AD[o04E:o`000003o`0m
A`05o`000?l0=T?o03I3o`0f@ol000000ol0;Ch2o`000008o`0U>_l0003o02Lko`000?l07CCo0000
o`0N=Ol00003o`0F;`03o`000?l03bWo000000;o00lY00?o0000o`098ol02B<00ol0000Yooooo`00
8_ooool01Ol0003o00HOo`067ol0003o00HO00?o000000Co00HOo`000?l01Qoo00HO1Ol000001?l0
1b7o0000o`088_l02282o`0000;o00XT00?o0000o`0;9Ol000000_l02bD2o`000005o`0>:?l0003o
00lYo`0?:Ol000000_l042X5o`000006o`0G<?l0003o01Pao`0H<Ol0003o01Xb1Ol000000ol093Wo
0000o`0V>P02o`0V>P04o`000?l0:3_o0000o`0[?@Go000000Go03Y5o`000?l0?TOo03i7o`000002
o`11B005o`000?l0AD[o04E:o`000?l0B4`01Ol000001Ol0ET_o0000o`1HB_l0F4[o000000?o05U9
00Co0000o`1HBOl0003o00000_l0GDH00ol0003o05]7o`1KA`03o`000009o`1OA?l0003o05e6o`1M
A_l0003o05]8o`000?l0HD?o000000;o05i500Go0000o`1KAol0003o0652o`000002o`1NA@?o0000
00Co0613o`000?l0GDKo05e60_l00003o`1NA0;o000000Co05m4o`000?l0G4Oo05a70_l00003o`1L
AP;o000000Co05a6o`000?l0F4Wo05Q90_l00003o`1GBP04o`000?l0ET_o05I;o`1FB`?o000001So
05A<o`000?l0Cdko0000o`1BCOl0003o04]=o`000?l0Cdko0000o`15B_l0003o04U<o`000?l0?DOo
0000o`11B?l0003o03I3o`000?l0>4Co0000o`0]?_l00002o`0`?`03o`000?l09c_o02Lk00;o0000
0_l07SD2o`000004o`0F;ol0003o01L`o`0000?o00lY00?o0000o`098ol000000_l02282o`0002So
oooo000Jooooo`;o00001_ooool00ol0003o00HOo`067`02o`0000;o00HO00?o0000o`067ol00000
0_l000001_l01b3o0000o`078Ol01b7o0000o`078@?o000000Co00TSo`000?l02RCo00XT1Ol00000
1_l03BOo0000o`0>:?l03RSo0000o`0?:@?o000000Go01@]o`000?l05Bko01D^o`000002o`0G<006
o`000?l0637o0000o`000?l07cKo00000_l08CL01Ol0003o02@io`0T>Ol0003o02Hj00Go000000Go
03A2o`000?l0=dCo03M4o`000002o`0jA@05o`000?l0?TOo03i7o`000?l0@DP01Ol000001Ol0DTgo
0000o`1DC?l0E4co000000;o05I;00Go0000o`1HB_l0F4[o0000o`1IB@03o`000003o`1OA?l0003o
05e600;o05e60_l000000ol0HT;o0000o`1OA002o`1OA004o`000?l0GDKo0000o`0000?o065300Co
0000o`1NAOl0003o00000ol0HD82o`000003o`1S@?l0003o061300;o06130_l000001?l0HT7o0000
o`1NA?l0GT@2o`0000?o05m40_l000001?l0H4?o0000o`1LA_l0G4H2o`0000?o05a60_l00002o`1K
A`03o`000?l0Ed[o000000Go00000ol0E4`2o`0000;o059=0_l00003o`1?CP05o`000?l0BDco04U<
o`19C?l000000_l0@DP2o`0000;o03Q40_l00002o`0`?`;o000000Ko02Lko`000?l0:Cco0000o`0N
=Ol00002o`0O=P03o`000?l05c3o01L`00;o000000Co00lYo`000?l03bWo00000_l02283o`0002So
oooo000Iooooo`04o`000?ooooooooooo`0000Gooooo0ol00002o`067`04o`000?l01Qoo0000o`00
00;o00HP00?o0000o`078?l000001?l00002o`088P03o`000?l02B?o000000;o000000Ko00/Vo`00
0?l032Ko00`Vo`000?l03BL5o`0000;o018/00Go0000o`0D;Ol052go0000o`0E;P05o`000006o`0M
=?l0003o01lfo`0O=_l0003o024g1Ol000001Ol0;Sko0000o`0a@?l0<D3o000000;o03A200Go0000
o`0gA?l0=dCo0000o`0jA@05o`000005o`1>C_l0003o051>o`1@C_l000000_l0DTd01_l0003o05A<
o`1DC?l0003o05I;o`0000;o05Q:0_l000000ol0H4?o0000o`1OA002o`1OA004o`000?l0GDKo05e6
o`0000;o069200?o0000o`1OA?l0Gd@00ol000001?l0Hd3o0000o`1Q@ol0HD<3o`000004o`1T?ol0
003o0652o`1Q@P;o00000_l0Hd000ol0003o0613o`1P@`02o`0000?o06910_l000000ol0Hd3o0000
o`1OA002o`1OA004o`000?l0H4?o0613o`1P@`;o000000?o0613o`000?l0G4H00_l0G4H00ol0003o
05]7o`1KA`02o`1KA`Co000000co05I;o`000?l0FDWo0000o`1DC?l0003o05M:o`000?l0DTgo0000
o`1DC?l00002o`1?CP;o00000_l0BD`2o`00000:o`11B?l0003o04E:o`000?l0>4Co0000o`0kA_l0
003o030oo`0000;o039100?o0000o`0Y??l0:C`00_l00002o`0O=P;o000000Go01L`o`000?l05c3o
01L`o`000002o`0?:@03o`000?l022;o000000;o00PR0_l0000Wooooo`006Oooool01?l0003ooooo
ooooool00004ooooo`;o000000Coooooo`000?l01Qoo00HO0_l00002o`067`04o`000?l01R3o0000
o`0000;o00LQ00Go0000o`088_l022;o0000o`088P02o`0000;o00/U00Go0000o`0;9_l02bKo0000
o`0<9P02o`000005o`0?:Ol0003o014[o`0A:ol000000_l04R`5o`000005o`0I<Ol0003o01/co`0K
<ol000000_l07C@01_l0003o01lfo`000?l0003o02Pko`0000;o02/m00Co0000o`0^?_l0;Sko0000
0_l0<D000ol0003o03A2o`000004o`000004o`16Bol0003o04Y<o`0000?o04i>00Oo0000o`1@C_l0
D4ko0000o`1BCOl0003o05A<00Ko000000Go05m4o`000?l0H4?o0613o`000002o`1OA004o`000?l0
GDKo0000o`0000?o06920_l000000ol0ISgo0000o`1S@002o`1S@0;o000000?o06Hlo`000?l0I3l0
0_l0I3l2o`000003o`1V?Ol0003o06=000;o06=00_l000000ol0ICko0000o`1R@@02o`1R@@06o`00
0?l0Hd3o06=0o`1S@?l0003o05m40_l00003o`1P@`06o`000?l0H4?o0613o`1P@ol0003o05a60_l0
00000ol0FdOo0000o`000002o`0000;o05Y80_l00002o`1IB@;o00000ol0EdX01?l0003o05A<o`1D
C?l0E4`2o`0000;o055=0_l00002o`1=CP05o`000?l0AD[o04E:o`15B_l000000_l0>dH2o`0000;o
03910_l000001_l0:Cco0000o`0Z?Ol0003o01lfo`0000;o024g00?o0000o`0G<?l05c000_l00000
0ol03bWo0000o`0>:002o`000005o`088_l0003o0000ooooool000009_ooool001Wooooo00Co0000
oooooooooooo00001?ooool01?l0003oooooooooooooool2o`000004o`067ol0003o00HOo`067`;o
00000_l01b000ol0003o00LQo`000004o`0000;o00TT00?o0000o`0;9Ol000001?l00002o`0>:004
o`000?l03bWo0000o`0A:`?o000000Go01D_o`000?l05c3o01L`o`000002o`0I<@03o`000?l06c?o
000000Co000000Go02Djo`000?l0:3_o02Pko`000002o`0[?@03o`000?l0;Sko000000Co000000Co
03i7o`000?l0@TWo00000ol0AT/00ol0003o04Y<o`000002o`1>CP03o`000?l0D4ko000000Co0000
00Go05Y8o`000?l0GDKo05e6o`000002o`1OA004o`000?l0H4?o0613o`0000;o05m40_l00002o`1T
?`04o`000?l0HT;o0692o`0000?o06Hm00Co0000o`1S@?l0Hd3o00000ol0IS`01?l0003o06@oo`1T
?ol00003o`1V?@04o`000?l0Hd3o0000o`0000?o06Dn00Co0000o`1R@Ol0003o00000ol0Hd02o`00
00;o06@o00Co0000o`1P@ol0003o00000ol0H4<5o`000004o`1KAol0003o05m4o`1OA0;o000000Ko
05e5o`000?l0FDWo0000o`1LAol00002o`1GBP;o00000_l0E4`2o`0000;o055=0ol000000ol0CDko
0000o`000002o`15BP;o000000Ko03]6o`000?l0?TOo0000o`0b@Ol00002o`0d@P03o`000?l0:Sgo
02Xm00;o00000_l08CL2o`000003o`0G<?l0003o01L`00;o000000Go00hXo`000?l03RSo00hXo`00
0002o`088P;o00009_ooool001Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`02ooooo`03o`000?l01Qoo000000;o00000_l01Ql01?l0003o00LPo`000?l00002o`088P03o`00
0?l02B?o000000;o00TT0_l00002o`0<9P03o`000?l03BOo000000;o00hX1?l00002o`0C;@05o`00
0?l05Boo01D_o`000?l05c001Ol000001Ol083Ko0000o`0S>?l08cSo000000;o02Dj00?o0000o`0X
>ol000001?l000001?l0=T?o0000o`0jAOl00003o`0nA`04o`000?l0@TWo0000o`16B`So000000Go
05I;o`000?l0F4Wo05Q9o`000002o`1JB004o`000?l0GDKo05e6o`0000;o05m400?o0000o`1P@ol0
00000_l000001_l0ISgo0000o`1T?ol0I3oo0000o`1R@P;o00000ol0ISd01?l0003o06=0o`000?l0
0003o`1V?004o`000?l0I3oo0000o`0000?o06Hm0_l000000ol0J3[o0000o`1U?P02o`1U?P;o0000
0_l0IS`01Ol0003o06=0o`000?l0Ic_o000000;o06@o0_l00002o`1T?`03o`000?l0H4?o000000;o
00000_l0Gd<2o`0000;o05m40_l00003o`1MA@04o`000?l0G4Oo05a7o`1LA`;o00000_l0FDP2o`00
0008o`1GB_l0003o055=o`000?l0Ddco0000o`1=C_l00002o`1@CP;o00000_l0B4`01Ol0003o03i7
o`0nAol0?TOo000000;o03A20_l000001ol0:Sgo0000o`0/?Ol0003o024go`000?l08CL00_l00000
1Ol05c3o0000o`0F;ol05Roo000000;o00hX0_l000001Ol022;o0000o`000?oooooo000002Gooooo
000Iooooo`04o`000?ooooooooooo`0000Cooooo0_l00004ooooo`;o000000?o00HOo`000?l00000
0ol00002o`078@03o`000?l022;o000000Co000000Co00/Uo`000?l032Ko00`V1Ol000001_l042[o
0000o`0B;?l04Rco0000o`0C;@Go000000Go01/co`000?l07CCo01ddo`000002o`0P=P03o`000?l0
8cSo000000Co000000Co02loo`000?l0<T7o00000ol0=T<01?l0003o03Y5o`000?l0?TL5o`000005
o`1@C_l0003o059=o`1BCOl000000_l0E4`01?l0003o05I;o`1FBol00002o`1HB@03o`000?l0FTSo
000000;o05e61Ol000000ol0Icco0000o`1V?@02o`1V?@04o`000?l0I3oo0000o`0000;o06Pj00?o
0000o`1V?Ol0ISd00_l00002o`1Y>@03o`000?l0ISco06Hl00;o00000_l0JCT01Ol0003o06Hmo`00
0?l0K3Ko000000;o06Pj00Go0000o`1U?_l0003o06Xho`000002o`1V?0;o00000ol0Ic/2o`000004
o`1X>ol0003o06@oo`1T?`;o00000ol0I3l2o`000006o`1S@?l0003o05m4o`000?l0HT7o00000_l0
GDD2o`0000;o05a70_l00003o`1IB005o`000?l0Ed[o05M:o`1GB_l000000ol0Dd`2o`0000;o051>
00Go0000o`18C?l0B4co04Q<o`000003o`0nA`03o`000?l0=4;o000000;o03M300Oo0000o`0/?Ol0
;3go02`mo`000?l08COo000000;o024g00?o0000o`0F;ol05Rl00_l000000ol03RSo0000o`0>:002
o`0000;o00PR0ol0000Tooooo`006_ooool2o`0000Gooooo00?o0000ooooooooool01Oooool01_l0
003o00HOo`067ol0003o00HPo`0000;o00LQ0_l00002o`088P04o`000?l02BCo0000o`0;9@?o0000
00Ko00dWo`000?l03bWo00lYo`000?l042X5o`000005o`0G<?l0003o01Tao`0I<Ol000000_l06c<0
0ol0003o01ddo`000004o`000005o`0X>ol0003o02`mo`0/?Ol000000_l0;cl01?l0003o0391o`00
0?l0=T<5o`000005o`18C?l0003o04e>o`1=C_l000000_l0D4h01?l0003o059=o`1BCOl00002o`1D
C003o`000?l0ET_o000000Oo000000Co06=0o`000?l0ISgo00000_l0Ic`00ol0003o06Hmo`1V?@03
o`000004o`1[=ol0003o06Pjo`1X>P?o000000Co06`fo`000?l0JCWo06Ti0ol000001?l0K3Go0000
o`1Y>Ol0JCT2o`0000;o06`f00?o0000o`1X>_l0J3X00_l00003o`1Z>0;o000000Co06/go`000?l0
Ic_o06Lk0_l00002o`1X>`?o000000Co06Pjo`000?l0I3oo06@o0_l00003o`1S@004o`000?l0HT7o
0691o`1R@@;o00000_l0HD<2o`0000;o05i400co0000o`1IB?l0003o05a6o`000?l0Ed[o0000o`1I
BOl0003o05=<o`000?l0ET/3o`00000:o`1BCOl0003o04Q<o`000?l0C4ko0000o`0nAol0003o0499
o`0000?o03M30_l000001?l0;3go0000o`0]?_l00003o`0Q=`04o`000?l05Roo0000o`0F;`;o0000
00Oo00hXo`000?l03BSo0000o`088_l0003o00PR00;o00009?ooool0027ooooo00?o0000oooooooo
ool01_ooool00ol0003o00HOo`000004o`000004o`078Ol0003o00PRo`088PGo000000?o00`Vo`00
0?l03BL01Ol000001Ol04Rco0000o`0D;_l052ko000000;o01L`00?o0000o`0I<Ol000001?l00000
1Ol08SSo0000o`0U>Ol09CWo000000;o02Pk00?o0000o`0/?Ol000001_l000001Ol0?dOo0000o`14
BOl0A4Wo000000;o04Q<00Ko0000o`1=C_l0CDko0000o`1@C_l00002o`1BC@Go000000Co05a6o`00
0?l0GdCo00000_l0HD801?l0003o06=0o`1S@?l00002o`1V?@03o`000?l0Icco06Ll00;o000000?o
06ddo`000?l0JcL00_l0JcL2o`000003o`1_<Ol0003o06`f00;o06`f0_l000000ol0Kc7o0000o`1/
=@02o`1/=@;o000000?o06lao`000?l0K3H00_l0K3H2o`000004o`1]<ol0003o06Xho`1Z>0;o0000
0ol0JcL2o`000003o`1/=_l0003o000000?o00000ol0J3X2o`0000;o06Pk00Co0000o`1S@?l0003o
00000ol0HT401Ol0003o0653o`1Q@ol0HD?o000000Co05i400Go0000o`1LA_l0G4Ko05a6o`000003
o`1IB@04o`000?l0ET_o05I;o`1FB`;o000000?o059=o`000?l000000_l0C4h2o`0000;o04990_l0
00001Ol0=d?o0000o`0iAOl0>DGo000000;o02dn0_l000001_l08COo0000o`0P=_l0003o01H_o`00
00;o01D^00?o0000o`0=:?l03BP00_l000000ol022;o0000o`088P02o`0002?ooooo000Pooooo`03
o`000?oooooooooo00Sooooo00Go0000o`067ol01Qoo0000o`078005o`000004o`098ol0003o00/U
o`0;9@Co00000_l03bT01ol0003o010[o`0@:ol0003o018/o`000?l052h01Ol00002o`0L=003o`00
0?l07cKo000000;o028h00?o0000o`0U>Ol000001?l000001?l0<T7o0000o`0f@ol00002o`0kA@04
o`000?l0?dOo03m7o`0000;o04A900?o0000o`18C?l000001ol000001?l0F4[o0000o`1JB?l00002
o`1LAP04o`000?l0GdCo05m4o`0000;o065200Go0000o`1S@?l0Hd3o0000o`1V?@04o`0000?o06dd
00Co0000o`1[=ol0JcOo00000_l0Kc400ol0003o06`fo`1/=P02o`0000;o06la00?o0000o`1/=Ol0
K3D00_l00003o`1_<@04o`000?l0K3Ko0000o`0000?o06dc0_l000000ol0Kc7o0000o`1[=`02o`1[
=`?o000000Go06`fo`000?l0003o06`eo`000003o`1X>P04o`000?l0J3_o06Pko`1X>`;o00000_l0
Ic`01_l0003o0691o`000?l0ICgo0000o`1Q@`;o00000ol0GT@2o`0000;o05a60_l00002o`1IB@;o
00000_l0ET/2o`00000:o`1BCOl0003o05A<o`000?l0C4ko0000o`1?C_l0003o0499o`0000;o04E:
00?o0000o`0iAOl0>DD00_l000002Ol0;Cko0000o`0]?_l0;Cko0000o`0P=_l0003o01heo`000003
o`0E;P03o`000?l03BSo000000;o00dW00?o0000o`088_l022800ol0000Rooooo`008?ooool00ol0
003oooooooooo`08ooooo`03o`000?l01Qoo00HO00;o00000_l01b000ol0003o00PRo`000004o`00
0006o`0;9_l0003o00dWo`0=9ol0003o00lY1ol00002o`0G<003o`000?l06S;o000000;o01`d1ol0
00001Ol0:cgo0000o`0^?ol0;Soo000000;o039100Co0000o`0f@ol0003o03]52?l000001?l0DDgo
0000o`1CC?l00002o`1EB`07o`000?l0F4[o05Q:o`1HB_l0003o05Y8o`000002o`1LAP03o`000?l0
GdCo000000Oo000000Co06deo`000?l0KS?o00000ol0KC@01?l0003o06/go`000?l00003o`1_<@;o
000000?o078/o`000?l0Kc400_l0Kc42o`000003o`1b;Ol0003o06la00;o06la0_l000000ol0LBko
0000o`1]<`02o`1]<`04o`000?l0Kc7o06lao`1_<@Co00000ol0K3H03Ol0003o06`eo`1/=Ol0K3Go
0000o`1X>_l0003o06`eo`000?l0J3_o0000o`1[=_l000000_l0Ic`2o`0000;o06Dm0_l00002o`1T
?`03o`000?l0GTCo000000;o06520_l00002o`1OA0;o00000_l0FdL2o`0000;o05Q90_l00002o`1D
C003o`000?l0Cdko04m>00;o00000_l0ADX2o`000005o`0iAOl0003o03]5o`0kAOl000000_l0;Ch0
0ol0003o02/mo`000002o`0N=@;o000000Co01D^o`000?l052ko00000_l03BL2o`000003o`088_l0
003o00PR00;o00008_ooool0023ooooo0_l0000:ooooo`;o000000Co00HOo`000?l01b3o00LP0_l0
0002o`088P04o`000?l02RCo0000o`0;9PGo00000_l042X00ol0003o018/o`000002o`0E;P03o`00
0?l05c3o000000Co000000Oo020fo`000?l093Wo02@io`000?l09c_o000000;o02/m00?o0000o`0^
?ol000001_l000001ol0@dWo0000o`19C?l0BDco0000o`1>C_l000000ol0DDd00ol0003o05=<o`00
0002o`1EB`03o`000?l0F4[o000000Oo000000Co06Dno`000?l0Ic_o00000_l0JSP01?l0003o06de
o`1]=Ol00002o`1^<`03o`000?l0KCCo06dd00;o00000_l0LRd01?l0003o06lao`1_<Ol00003o`1b
;004o`000?l0Kc7o06lao`0000?o078]00Co0000o`1_<Ol0003o00000ol0LBh00ol0003o06dco`00
0006o`0000;o070`00Co0000o`1/=_l0003o00000ol0K3D2o`0000?o06`e00Co0000o`1[=_l0JcKo
06/f0_l000001_l0JSSo0000o`1U?Ol0003o06Tjo`0000;o06@o0_l00002o`1Q@P;o00000_l0Gd@2
o`0000;o05]70_l00002o`1HB@;o000000[o05A<o`000?l0003o0000o`1?C_l0003o055=o`000?l0
AD[o00000_l0B4`00ol0003o03]5o`0kA@02o`000003o`0]?_l0003o02/m00;o000000?o01heo`00
0?l07C@00_l000001_l052ko0000o`000?l03BOo0000o`0=9`;o000000?o00PRo`000?l022800_l0
000Qooooo`008?ooool00ol0003oooooooooo`0;ooooo`Co00000_l01b400ol0003o00PRo`000003
o`0000;o00`V00?o0000o`0>:?l000000_l042X7o`000005o`0J<_l0003o01ddo`0M=?l000000_l0
83H00ol0003o02@io`000006o`000004o`0e@_l0003o03Y5o`0000;o03i700Co0000o`13BOl0@dWo
00000_l0BD`01?l0003o04i>o`000?l0DDd8o`000007o`1MA_l0003o0613o`1P@ol0003o0691o`00
0002o`1U?P04o`000?l0Ic_o06Lko`0000;o06Xh00Go0000o`1]=Ol0KCGo0000o`1^<`03o`000006
o`1d:Ol0003o078]o`1b;Ol0003o06la0_l00003o`1b;004o`000?l0Kc7o0000o`0000?o078]0_l0
0002o`1d:@03o`000?l0LBko074^00Go000000Co06lao`000?l0M2[o00000_l0L302o`0000;o070_
00Go0000o`1/=Ol0003o070_o`000002o`1/=@;o00000_l0JcH2o`0000?o06Xh00Co0000o`1Y>_l0
JC[o06Tj0_l000004?l0Icco0000o`1Q@_l0003o06@oo`000?l0GdCo0000o`1Q@_l0003o05]7o`00
0?l0GTGo0000o`1HBOl00002o`1JB0?o000000Co05I;o`000?l0DDgo055=0_l00002o`18C0;o0000
00?o03]5o`000?l0>TD00_l000000ol0:cgo0000o`0Y?002o`000005o`0M=?l0003o01`do`0L=?l0
00000_l04bd00ol0003o00dWo`000002o`0<9`03o`000?l022;o00PR00?o00008?ooool0023ooooo
00?o0000ooooooooool03?ooool00ol0003o00HOo`000004o`0000;o00TS00Co0000o`0;9Ol0003o
00`V1Ol000001ol04Rco0000o`0D;_l052ko0000o`0G<?l000000_l06S800ol0003o01ddo`000004
o`000004o`0X>ol0003o02`no`0000;o031000Oo0000o`0e@_l0=D;o0000o`0jAOl0003o03i700[o
000000Go05I;o`000?l0F4Wo05Q9o`000002o`1KB004o`000?l0GDKo05e6o`0000;o061300?o0000
o`1R@Ol000000_l0ICh00ol0003o06Lko`000002o`1Z>0Go000000?o07DXo`000?l0M2T00_l0M2T0
1?l0003o078]o`000?l00002o`1e9`03o`000?l0LRco078/00;o00000_l0MRL01Ol0003o078]o`00
0?l0N2?o000000;o07@Y1Ol00002o`1c;0;o00000ol0M2X2o`000004o`1d:Ol0003o070_o`1`;`;o
00000ol0L2l2o`0000;o070`0_l000001?l0Kc7o0000o`1Z>?l0JSP2o`0000;o06Tj0_l00003o`1W
?005o`000?l0I3oo06@oo`1T?ol000000ol0HD801Ol0003o05i5o`1NAOl0GTGo000000?o05Y800?o
0000o`1FBol0ET/00_l000001_l0DDgo0000o`1BCOl0003o04Q<o`0000;o04Y<00?o0000o`0jAOl0
00000_l0>4@00ol0003o02Tlo`000002o`0W>`03o`000?l073Co01`d00;o000000Co01<]o`000?l0
4bco00000ol032L01?l0003o00PRo`000?l02242o`00023ooooo000Oooooo`?o00003_ooool2o`00
0003o`067ol0003o00LQ00Oo00000_l03BL00ol0003o00lZo`000002o`0B;003o`000?l052ko0000
00Ko00000_l08CL00ol0003o02@io`000002o`0X>`04o`000?l0;3ko0000o`0`@0Oo000000Oo04M;
o`000?l0CDko04e>o`000?l0D4ko000000;o05=<00Co0000o`1FBol0ET_o00000_l0F4T01ol0003o
05]8o`1KB?l0003o05e6o`000?l0H4<02ol000001?l0LBko0000o`1c:_l00002o`1e:003o`000?l0
M2Wo07@Y00?o000000Co07PRo`000?l0MBOo07DW0ol000001?l0NB;o0000o`1f9ol0MRL2o`0000?o
07PS1?l00003o`1f9P;o000000Co07PSo`000?l0M2[o07@Z0_l00003o`1d:@;o000000Co07DXo`00
0?l0L2oo070_0_l00002o`1`<0;o00000ol0Kc42o`0000;o06hc0_l00002o`1/=@04o`000?l0Icco
0000o`0000?o06@o00Co0000o`1Q@_l0HD;o06520_l000003?l0GTGo0000o`1P@ol0003o05Y8o`00
0?l0G4Ko0000o`1FBol0003o05Q:o`0000?o059=00Co0000o`1:C?l0BTco04Y<0_l00002o`0hA003
o`000?l0=D?o000000;o02Lk0_l000000ol073Co0000o`0K<`02o`000008o`0C;?l0003o018/o`00
0?l032Oo0000o`0<9_l00002o`088@?o00007oooool000Kooooo0_l00004ooooo`04o`000?oooooo
ooooooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool04?ooool3o`0000;o00LQ00?o
0000o`098ol000000_l02bD00ol0003o00dWo`000006o`000007o`0G<?l0003o01Xbo`0J<_l0003o
01ddo`000002o`0Q=`Wo000000Go03M3o`000?l0?4Ko03a6o`000002o`11B003o`000?l0Ad_o0000
00;o04e>00Co0000o`1@C_l0003o05=<3Ol000001ol0ISgo0000o`1X>_l0J3[o0000o`1[=_l00000
0_l0KS801?l0003o074^o`1a;_l00002o`1c:P03o`000?l0MBSo07DX00;o000000?o07/Mo`000?l0
N2800_l0N282o`000003o`1l7?l0003o07TR00;o07TR0_l000000ol0Naco0000o`1h8`04o`000004
o`1j7ol0003o07HVo`1f9P;o00000ol0N2<2o`000004o`1i8_l0003o07@Yo`1d:@;o00000ol0MBP2
o`000006o`1e:?l0003o070`o`000?l0M2Wo00000ol0Kc401Ol0003o06hco`1^<ol0KS?o000000Co
06`e00[o0000o`1Z>?l0JSSo0000o`1T?ol0003o06Lko`000?l0HD;o00000_l0I3l01Ol0003o0613
o`1P@ol0H4?o000000?o05a600Co0000o`1HB_l0003o00000ol0DTd2o`000006o`1:C?l0003o04U<
o`000?l0>4Co00000_l0=D<01?l0003o02Lko`000?l09SX2o`000005o`0K<ol0003o01Xbo`0J<_l0
00000_l04R`2o`000006o`0<9_l0003o0000o`088Ol0003o00LQ0ol0000Nooooo`001Oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo013ooooo00Go0000o`067ol01Qoo0000o`078@07o`000008
o`0>:?l0003o014[o`0A:ol0003o01@]o`000?l05c08o`000009o`0T>Ol0003o02Plo`0X??l0003o
02dno`000?l0<T7o000000;o03M300Go0000o`0lA_l0?4Ko0000o`11B009o`000005o`1HB_l0003o
05Y8o`1JB?l000000_l0GDH00ol0003o0613o`000002o`1S@004o`000?l0ISgo06Hmo`0000;o06Pj
00?o0000o`1[=_l000000_l0KS801ol0003o074^o`1a;_l0003o07<Zo`000?l0MBP00_l00003o`1k
7@04o`000?l0N2;o07PRo`0000;o07`L00?o0000o`1i8_l0NB800_l000000ol0Naco0000o`000002
o`000003o`1n6?l0003o07XO00;o07XO0_l000000ol0O1co0000o`1h8`02o`1h8`04o`000?l0NB;o
07TRo`1i8P;o000000?o07TQo`000?l0MBP00_l0MBP01Ol0003o07DXo`1e:?l0MBSo000000?o07@Y
00Ko0000o`1_<Ol0003o07<[o`000?l0KS<2o`0000?o06`e0_l00002o`1Z>0;o00000_l0Ic/2o`00
00;o06@o0_l00002o`1P@`;o00000_l0G4H2o`000007o`1HB_l0003o0000o`000?l0DTgo0000o`1C
C002o`000003o`19C?l0003o04I;00;o000000Ko03E3o`000?l0<d7o0000o`0V>_l00002o`0T>@03
o`000?l06S;o01Xb00;o000000?o018/o`000?l04B/00_l00002o`0<9P04o`000?l01b7o0000o`07
8@;o00007_ooool000Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo0_l0000Booooo`Co00000_l022801?l0003o00XTo`000?l032H9
o`0000;o01Ta00?o0000o`0L=?l000000_l083H01Ol0003o02@io`0T>Ol0003o02Pl00co000000Co
04Y<o`000?l0Cdko00000_l0DTd00ol0003o05E<o`000002o`1HBP04o`000?l0FTSo05Y8o`0000;o
05e600?o0000o`1P@ol000000_l0Hd001?l0003o06Hmo`000?l0J3X=o`000003o`1l6ol0003o07/M
00;o07/M00Co0000o`1h8_l0003o00000ol0O1`5o`0000;o07/L00Go0000o`1n6?l0OQSo07hHo`00
0002o`1j7`06o`000?l0O1co07`Lo`1l7?l0003o07PS0_l00003o`1i8P06o`000?l0NB7o07TQo`1i
8Ol0003o07DX0_l00003o`1e:004o`000?l0M2Wo07@Yo`1d:@;o00000ol0Lb/01_l0003o074^o`1a
;_l0003o06`eo`0000;o06la0_l000002?l0KCCo0000o`1W>ol0003o06Xho`000?l0I3oo00000_l0
Ic`2o`0000;o06=00_l00002o`1NA003o`000?l0FTSo000000;o000000So05=<o`000?l0Ddco05=<
o`000?l0AT_o0000o`13B@;o000000?o03=1o`000?l0<4000_l000001_l093Wo0000o`000?l06S;o
0000o`0I<@;o000000So014[o`000?l04B_o0000o`0<9_l0003o00/Vo`0000;o00LQ0ol0000Moooo
o`001Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?l01Qoo000000Oo000000Ko00dWo`00
0?l03bWo0000o`0B;?l00002o`0E;`03o`000?l06C7o000000Wo000000Co02dno`000?l0<T7o0000
0_l0>4@00ol0003o03e7o`000002o`13B@06o`000?l0BTco04Y<o`000?l0Cdko00000_l0DTd01?l0
003o05E<o`000?l0F4X?o`000007o`1_<_l0003o078]o`1b;Ol0003o07@Yo`000002o`1h9004o`00
0?l0Nako07/No`0000;o07`K00?o0000o`1k7Ol0Nad00_l00002o`1o5P03o`000?l0O1co000000;o
00000_l0OaH01?l0003o07/Lo`000?l00003o`1n6004o`000?l0NQoo0000o`0000?o07`L0_l00002
o`1m6P04o`000?l0NB;o0000o`0000?o07TQ0_l00002o`1i8@09o`000?l0MBSo0000o`1i8Ol0003o
07@Yo`000?l0N2?o000000;o07<[0_l00002o`1a;P;o00000_l0Kc42o`0000;o06dd0_l00002o`1Z
>0;o00000_l0Ic`2o`0000;o06=00_l00002o`1NA0;o000000Go05Y8o`000?l0003o05]8o`000002
o`1CC005o`000?l0DDgo0000o`13BOl000000_l0?dL01_l0003o0310o`0`@?l0003o02hoo`0000;o
028h00Co0000o`0I<Ol0003o01P`0_l00002o`0A:`;o000000Wo00/Vo`000?l0003o00LQo`000?l0
1b7o0000ooooool000007?ooool000Gooooo00Co0000oooooooooooo00001oooool01_l0003ooooo
oooooooooooo0000ooooo`Co00001Oooool00ol0003oooooooooo`0Cooooo`;o000000Co00HPo`00
0?l022;o00000_l02R@;o`0000;o01/c00Go0000o`0O=_l0003o02@io`000002o`0X>`07o`000?l0
;Cko02dno`000?l0<T7o0000o`0hA00Ao`000007o`1LA_l0003o05m4o`1OA?l0003o0691o`000002
o`1U?@03o`000?l0J3[o000000;o06`f00Ko0000o`1_<_l0Kc;o0000o`1b;Ol00002o`1d:@04o`00
0?l0N2Co07PTo`0000;o07/N00So0000o`1l6ol0003o07/Mo`000?l0PPoo0000o`1o5PGo00000ol0
OaH2o`0000;o088@00?o0000o`1n6?l0OQP00_l00002o`205005o`000?l0O1co0000o`214Ol00000
0_l0OAX2o`0000;o07hH00Go0000o`1i8Ol0003o07hHo`000002o`1i8@;o00000_l0NB42o`0000?o
07PS0_l00002o`1g9@;o000001So07DXo`000?l0Kc7o0000o`1c;?l0003o06ddo`000?l0L33o0000
o`1Z>?l0003o06ddo`000?l0Icco0000o`1Y>Ol0003o06=0o`000?l0ICko0000o`1NA?l00002o`1Q
@`03o`000?l0FdSo05]800;o000000Ko05=<o`000?l0DDgo0000o`1@C_l00002o`0oA`;o000000?o
0310o`000?l0;Sl00_l000002ol08SSo0000o`0Q=ol0003o01P`o`000?l05c3o0000o`0A:ol0003o
010Z00;o00000_l02bD00ol0003o00LQo`078@03o`0001cooooo0005ooooo`04o`000?oooooooooo
o`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo0_l0000Gooooo`Ko0000
00_o00/Uo`000?l03BSo00dXo`000?l042_o0000o`0D;Ol0003o01L`o`000002o`0K<`ko000000Co
03i7o`000?l0A4[o00000_l0Bdd00ol0003o051>o`000002o`1CC006o`000?l0ET_o05I;o`000?l0
FDWo00000_l0G4H01_l0003o05m4o`1OA?l0003o0691o`0000;o06Dm00?o0000o`1X>_l000000_l0
K3H00ol0003o06lbo`000002o`1b;@03o`000?l0M2Wo000000;o07PT1ol000001Ol0PPoo0000o`00
0?l0003o07lF00;o00000_l0P`l01Ol0003o07lFo`000?l0Q@So000000;o088@00Go0000o`1n6?l0
003o08@<o`000002o`2050;o00000ol0PA42o`000004o`223ol0003o07hHo`1n60;o00000ol0OQP2
o`000006o`1n6?l0003o07TQo`000?l0OAWo00000_l0N2<2o`0000;o07LU0_l00003o`1e:005o`00
0?l0Lbco07</o`1c;?l000000ol0L3001Ol0003o06ddo`1]=?l0KCCo000000?o06Ti00Go0000o`1U
?_l0ICko06Dno`000002o`1Q@`;o000000?o05]8o`000?l0FTP00_l000000ol0DDgo0000o`1@CP02
o`000003o`0oAol0003o03a600;o000000?o02hoo`000?l0;3d00_l000001?l08COo0000o`0O=_l0
0003o`0G<008o`000?l042[o0000o`0?:Ol0003o00/Uo`000?l02bD2o`000004o`078Ol0003o0000
o`0001_ooooo0006ooooo`;o00002Oooool3o`0000;ooooo1Ol00003ooooo`03o`000?oooooooooo
01Kooooo00?o0000o`068?l01R004?l000002Ol07CCo0000o`0R>?l08SSo0000o`0W>ol0003o02`n
o`000002o`0b@@03o`000?l0>4Co000000;o03i700?o0000o`14B_l000000_l0Bdd00ol0003o051>
o`000002o`1CC003o`000?l0ET_o000001_o000000Go07hGo`000?l0PQ7o0000o`233@03o`000006
o`223ol0003o0000o`000?l0QPOo00000_l0P`l2o`0000;o08D800?o0000o`224?l0PQ000_l00003
o`2430;o000000Co08D8o`000?l0PA7o084A0_l00003o`223`;o000000Co08<>o`000?l0OQSo07hH
0_l00003o`1n6004o`000?l0OAWo07dIo`1m6@;o000000Ko07`Ko`000?l0MbGo0000o`1k7_l00003
o`1e:005o`000?l0Lbco07</o`1c;?l000000ol0L3001Ol0003o06ddo`1]=?l0KCCo000000?o06Ti
0_l000001Ol0ICko0000o`000?l0HD?o000000;o06920_l000001_l0FTSo0000o`1HBOl0003o051>
o`0000;o04e>00Co0000o`0lA_l0003o03U50_l000000ol0;3go0000o`0Y?002o`000008o`0O=_l0
003o01deo`000?l05c3o0000o`0F;ol00002o`0?:@;o000000Wo00/Uo`000?l0003o00LQo`000?l0
1b7o0000ooooool000006_ooool001kooooo00?o0000ooooooooool05oooool2o`00000;o`068?l0
003o00PRo`088_l0003o00/Uo`000?l03RSo0000o`0A:ol000000_l05Bh01?l0003o01Tao`000?l0
7C@Ko`000004o`1JB?l0003o05i5o`0000;o065200?o0000o`1T?ol000000_l0Ic/00ol0003o06/g
o`000002o`1^<`03o`000?l0LBko000000;o07@Y00?o0000o`1h8ol000000_l0Nad00ol0003o07hG
o`1n5`04o`0000;o08<=0_l000000ol0R@3o0000o`261`02o`261`;o000000?o08T0o`000?l0Q@P0
0_l0Q@P2o`000004o`280ol0003o08@<o`2430;o00000ol0Q@P2o`000004o`271_l0003o088?o`22
3`;o00000ol0P`h2o`000004o`233_l0003o07hHo`1n60;o00000ol0OAT01Ol0003o07`Ko`1l6ol0
O1_o000000?o07/N01?o0000o`1e:?l0003o07TRo`000?l0Lbco0000o`1f9_l0003o070`o`000?l0
Lb_o0000o`1]=?l0003o070`o`000?l0JCWo000000;o06`f00Co0000o`1W>ol0Ic_o00000ol0HT80
1_l0003o0652o`000?l0F4Wo0000o`1FB`;o000000Ko04e>o`000?l0BDco0000o`0iAOl00002o`0f
@`03o`000?l0:Cco000000;o02Lk00?o0000o`0M=Ol07CD00_l000001_l05Roo0000o`000?l03bWo
0000o`0?:@;o00000_l02RD2o`000004o`078Ol0003o0000o`0001[ooooo000Nooooo`;o00006_oo
oolAo`0000;o020f00?o0000o`0U>_l000000_l0:cd01Ol0003o0350o`000?l0=d?o000000;o03e7
00Go0000o`14B_l0003o04a=o`000002o`1@CP03o`000?l0E4co000000;o05M:00Ko0000o`1JB?l0
FTSo0000o`1NAOl00002o`1Q@P03o`000?l0I3oo000000;o06Lk00?o0000o`1[=ol000000_l0KS<0
0ol0003o074^o`000002o`1d:@03o`000?l0N2?o000000;o07/M1?l000000ol0PQ7o0000o`233@02
o`0000?o08T000Co0000o`261ol0QPOo00000_l0R@000ol0003o08D8o`252002o`0000?o08P30_l0
00000ol0RP3o0000o`252002o`252004o`000?l0Q`Ko08L6o`271P;o000000?o08L4o`000?l0P`h0
0_l0P`h01?l0003o08<>o`233_l0P`h2o`0000;o088?00Co0000o`1m6Ol0003o00000ol0O1/01?l0
003o07/No`1k7_l0Nah2o`0000;o07TR0_l00002o`1f9P;o00000_l0Lb/2o`0000;o070`0_l00002
o`1/=P;o00000_l0Ic/2o`000008o`1R@_l0003o0652o`000?l0GdCo0000o`1FBol00002o`1DC004
o`000?l0BDco0000o`16B`;o000000Co03I3o`000?l0<d;o00000_l09c/2o`000003o`0M=Ol0003o
01`d00;o000000[o01D^o`000?l0003o00lYo`000?l03RSo0000o`0:9Ol0003o00XT0_l00002o`07
8@;o00001oooool3o`0000Cooooo0_l00004ooooo`;o00000oooool001kooooo00?o0000oooooooo
ool06_ooool01Ol0003o00HPo`000?l02B?o000000;o00`V00Oo0000o`0?:Ol0003o01</o`000?l0
5c3o000000;o01/c00?o0000o`0P=_l00000>_l000000ol2R`3o0000o`290002o`290004o`000?l0
QPOo0000o`0000?o08T00_l000000ol5S03o0000o`280`02o`280`06o`000?l0RP3o08X0o`2:0?l0
003o08D80_l00003o`271P06o`000?l0Q`Co08L4o`271?l0003o08<>0_l00003o`233P03o`000?l0
PPoo088?00;o088?01ko0000o`224Ol0PQ7o0000o`1l6ol0003o080Co`000?l0Nako0000o`1n5ol0
003o07TRo`000?l0O1_o0000o`1f9_l0003o07XPo`000?l0Lb_o0000o`1f9_l0003o070`o`000?l0
Lbco0000o`1/=_l00002o`1^<P;o000000[o06Tjo`000?l0003o0652o`000?l0GdCo0000o`1MA_l0
003o05A<0_l000001?l0DTgo0000o`16Bol00002o`12B@07o`000?l0<d;o03=2o`000?l09c_o0000
o`0U>P02o`000003o`0L=?l0003o01/c00;o00000_l052d00ol0003o00hXo`0>:002o`000005o`0:
9?l0003o00XTo`000?l01b400_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`007_ooool00ol0
003oooooooooo`0Koooooa7o000000Co02<ho`000?l0:3_o00000_l0;Sl01Ol0003o03E2o`000?l0
?4Ko000000;o04=900Go0000o`1;COl0003o051=o`000002o`1DC003o`000?l0F4[o000000;o05]7
00?o0000o`1NA?l000000_l0HT400ol0003o06Hmo`000002o`1Y>@03o`000?l0KCGo000000;o070`
00?o0000o`1d:_l000000_l0Mb@00ol0003o07/No`000003o`000005o`224?l0003o08D9o`252Ol0
00000_l0R0801?l0003o0X/0o`:;0?l00002o`2900;o00000_l8S@001?l0003o08T0o`290?l00003
o`F<0004o`000?l0R0?o0000o`0000?o08X00_l00002o`B;0004o`000?l0Q`Ko0000o`0000?o08L4
0_l00002o`280`04o`000?l0P`ko0000o`0000?o088?0_l00002o`224@;o00000ol0P1<01Ol0003o
07hGo`1n5ol0OQOo000000?o07`K00Go0000o`1j8?l0NR3o07XPo`000003o`1f9P05o`000?l0Lbco
07</o`1c;?l000000_l0KS82o`000008o`1Y>_l0003o06Pko`1X>ol0003o05m4o`000?l0GDH2o`00
0006o`1DC?l0003o059=o`000?l0D4ko00000_l0@TT2o`000007o`0c@_l0003o0350o`000?l09C[o
0000o`0S>002o`000007o`0K<ol0003o01Tao`000?l052go0000o`0C;@02o`000003o`0>:?l0003o
000000;o00XT0_l000001?l01b7o0000o`000?l00007ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`007_ooool00ol0003ooooo
ooooo`0Moooooa;o000000Wo02Pko`000?l0;Soo02hoo`000?l0=D;o0000o`0lA_l000000_l0@dT0
1Ol0003o04]=o`000?l0D4go000000;o05A<00?o0000o`1HB_l000000_l0FdL00ol0003o05i4o`00
0002o`1R@@03o`000?l0ISgo000000;o06Ti00?o0000o`1]=Ol000000_l0L3000ol0003o07@Zo`00
0003o`000007o`1k7_l0003o07hHo`1n6?l0003o088@o`000002o`252@0:o`000?l0R0;o08P2o`00
0?l2R`3o0000o`290?l0003o4I00o`0000;o28d000Co0000o`290?l0003o00000ol5S002o`0000;o
2hh000Go0000o`2:0?l0003o3i00o`000002o`B;00;o00000_l6S0001Ol0003o08L4o`000?l7S@3o
000000;o08P30_l00002o`271003o`000?l0PPoo000000;o08L50_l000001?l0QPOo0000o`204ol0
P1<2o`0000;o07hG0_l00002o`1l6`;o00000_l0NR02o`0000;o07HV0_l00002o`1c;0;o000000Go
06hbo`000?l0L33o070`o`000002o`1X>`06o`000?l0ISgo0000o`1MA_l0003o05]80_l000000ol0
DTgo0000o`1@CP02o`000003o`12BOl0003o03i700;o000000Ko0350o`000?l0;Sko0000o`0S>?l0
0002o`0Q=`03o`000?l06C7o01Ta00;o000000Ko01<]o`000?l0003o00hXo`000?l03BL3o`000003
o`099?l0003o000000;o00LP0_l00006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`007Oooool00ol0003oooooooooo`0Noooo
o`03o`000?l01b3o000000;o00TS00Oo0000o`0=9ol0003o014[o`000?l05Bko000000;o01Xb00Co
0000o`0O=_l0003o02Dj??l00003oa6@0004o`000?l8S@3o0000o`0000;o3i0000Go0000o`F<0?l0
003o5I80o`000002o`^>00;o00000ol?T002o`000004oa:A0?l0003o1X`0o`J<00;o00000ol7S@02
o`000004o`N=0?l0003o08L4o`2710;o00000_l0Q`D2o`0000?o08H70_l00002o`242`;o00000_l0
PPl2o`0000;o080D0_l00002o`1m6P;o00000_l0NB42o`0000;o07DW00?o0000o`1`<?l0L3000_l0
00002?l0J3_o0000o`1V?Ol0003o06=0o`000?l0FdSo00000_l0F4T01?l0003o051>o`000?l0CTh2
o`000003o`0nAol0003o03]500;o000000?o02hno`000?l0:cd00_l000001_l08COo0000o`000?l0
6C7o0000o`0H<0;o000000co018/o`000?l0003o00dWo`000?l03BOo0000o`099?l0003o00TSo`00
0?l01b03o`0000Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo000Mooooo`?o00007ooooolBo`000009o`0/?Ol0003o0391o`0b
@Ol0003o03Y5o`000?l0@TSo000000;o04Y<00?o0000o`1@C_l000000_l0E4`01ol0003o05Q:o`00
0?l0FdOo0000o`1OA?l000000_l0Hd000ol0003o06Hlo`000002o`1Z>004o`000?l0KS?o0000o`1b
;@Co00000_l0NB400ol0003o07dJo`000002o`214P03o`000?l0Q0_o000000;o08P200Ko0000o`J<
0?l6S03o0000o`j?0?l00002oaBA0003o`000?lAT03o4I0000?o000000Co6I@0o`000?l?T03o3i00
0_l00003oaFB00;o000000?o6Y@0o`000?l?T0000_l?T0001?l0003o4Y40oa:A0?lBT@02o`000004
oaBA0?l0003o1hd0o`N=00;o00000ol7S@02o`000006o`J<0?l0003o08L5o`000?l4S03o00000_l0
QPL2o`0000?o08@;00Go0000o`223ol0PPoo088?o`000003o`205005o`000?l0OA[o07dJo`1m6_l0
00000ol0NB401ol0003o07DWo`1e9ol0MBOo0000o`1`<?l000000_l0Kc400ol0003o06Hmo`000002
o`1S@0?o000000Ko05Q9o`000?l0ET_o0000o`1>C_l00002o`1:C004o`000?l0>dGo0000o`0gA0;o
000000?o02/mo`000?l0:3`00_l00002o`0O=P04o`000?l0633o0000o`0G;`;o00000_l04B/00ol0
003o00dWo`0=9`02o`0000;o00TS0_l000001?l01b3o0000o`000?l00004ooooo`;o00001?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo000:ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0Pooooo`03o`000?l0
1b3o000000;o000000co00dWo`000?l04B_o014[o`000?l05Roo0000o`0L<ol0003o028go`000?l0
:3/Ho`0000;o06=000?o0000o`1V??l000000_l0JSP3o`0000;o078]00?o0000o`1f9ol000000_l0
NB401Ol0003o07dJo`000?l0PA;o000000;o08@;00?o0000o`280_l000000_l6S0001?l0003o3Xl0
o`j?0?l00002oaBA00;o000000?o8iL0o`000?lIU0000_lIU002o`000004ob6F0?l0003o5I80oaFB
00;o00000_lJU0000ol0003o3i00o`n@0002o`0000?o4Y4000Co0000oaBA0?lDT@3o59400_l00000
0olDTP3o0000o`N=0002o`N=0005o`000?l6S03o1X`0o`J<0?l000000ol4S002o`0000;o0HX000Co
0000o`242ol0003o00000ol0PPl01Ol0003o080Do`205?l0P1Co000000?o07dJ0_l000001ol0NB7o
0000o`1l6ol0003o07DWo`000?l0MbD00_l000000ol0Kc7o0000o`1]=@02o`000004o`1S@?l0003o
0000o`1NA0;o000000?o05I;o`000?l0E4`00_l000001ol0BTco0000o`16Bol0003o03M4o`000?l0
=4800_l000003Ol0:3co0000o`0V>_l0003o01lfo`000?l07CCo0000o`0G;ol0003o01D^o`000?l0
4B/00_l000000ol03BOo0000o`0<9P03o`000003o`098ol0003o000000;o00LP0_l00004ooooo`03
o`000?oooooooooo00?ooooo0_l00004ooooo`;o00000oooool000Wooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool08Oooool00ol0
003o00LPo`07800?o`000004o`0_?ol0003o03M3o`0000;o03i700Oo0000o`17Bol0003o04m>o`00
0?l0Ddco000000;o05M:00Go0000o`1KAol0003o05m4o`000002o`1S@1Oo000000Go08@;o`000?l0
R0;o08P2o`000002o`J<0004o`000?l>S`3o0000oaBA00;o00000olSU`001?l0003o6I@0oaVD0?l0
0003ob6F00;o000000?o9iP0o`000?lJU0000_lJU002o`000004oajF0?l0003o4Y40oa:A00;o0000
0olDT@001_l0003o5980oaBB0?lDTP3o0000o`N=00;o00000ol6S0001Ol0003o18`0o`B<0?l4S03o
000000Co0HX000ko0000o`280_l0R0;o0000o`223ol0003o08H7o`000?l0P1Co0000o`233Ol0003o
07dJo`0000;o080C00Go0000o`1l6ol0O1_o07`Ko`000002o`1g9@06o`000?l0MRKo0000o`1]=Ol0
003o06Xh0ol000000ol0GTCo0000o`1LAP02o`000003o`1DC?l0003o059=00;o000000Oo04I;o`00
0?l0@DSo0000o`0d@_l0003o035000;o00000_l09SX2o`000004o`0M=?l0003o01`co`0000;o01D^
0_l000003?l042[o0000o`000?l032Ko0000o`0;9_l0003o00TSo`000?l022?o0000o`0780?o0000
5Oooool000Wooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`;o0000
8oooool9o`0000;o01P`00Ko0000o`0M=?l0003o02@io`000?l0:cd>o`0000;o05M:00Ko0000o`1K
Aol0003o05m4o`000?l0Hd04o`000004o`1[=ol0003o06lao`0000;o07</00?o0000o`1g9Ol00000
0_l0Nah00ol0003o07lFo`000002o`233P03o`000?l0Q`Go000000_o000000?o9iT0o`000?lSU`00
0_lSU`001?l0003o6I@0o`000?l00003ob6F0005o`000?lWV03o9iP0obNH0?l000000_lJU0001?l0
003o7YH0oajF0?lNUP02o`0000;o8IL000Co0000oaBA0?lDT@3o00000olDTP02o`0000;o598000Ko
0000o`J<0?l0003o4Y40o`000?l4S002o`0000?o0HX00_l00002o`280P;o00000_l0QPL2o`0000;o
08<=0_l00002o`204`;o00000_l0O1/2o`00000?o`1g9Ol0003o07HVo`000?l0Lb_o0000o`1Z>?l0
003o06Lko`000?l0ICko0000o`1LA_l0003o05Y800;o000000?o059=o`000?l0D4h00_l000001_l0
@DSo0000o`0mAol0003o0350o`0000;o02dn0_l000001_l093Wo0000o`000?l073?o0000o`0J<P;o
000000Co01@]o`000?l0003o00lY0_l00002o`0;9P;o00000_l022<2o`000004o`068?l0003o0000
o`0001Cooooo0009ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Sooooo`05o`000?l01b7o0000o`0:9?l000000_l03RP:o`0000;o039100Go
0000o`0kAOl0003o04A9o`000002o`1=CP;o00000_l0ET/?o`000007o`1_<Ol0003o07</o`1c;?l0
003o07LUo`000002o`1k7P07o`000?l0OaKo0000o`233_l0003o08L5o`000002o`>;0003o`000?l=
S`3o000000;o5i<000Co0000ob6G0?lQU`3o00000_lWV@000ol0003o8iL0ob>G0002o`0000;o;9X0
00Co0000ob6F0?l0003o00000olWV0001?l0003o6Y@0o`000?l00003oajF000=o`000?lQU`3o8IL0
ob6G0?l0003o5940o`000?lRU`3o0000oaBB0?l0003o8iL0o`000002oaBB00;o00000olBT@001_l0
003o4900oa2@0?l0003o0HX0o`0000;o38h00_l000003?l7S03o0000o`261ol0003o0HX0o`000?l0
P`go0000o`271Ol0003o080Co`0000;o08<=0_l00002o`1n600@o`000?l0MRKo0000o`1c:ol0003o
074_o`000?l0Ic_o0000o`1U?_l0003o0691o`000?l0FTSo0000o`1GBP;o000000?o051>o`000?l0
C4h00_l000000ol0?DOo0000o`0iA@02o`000006o`0]?_l0003o0000o`0T>Ol0003o024g0_l00000
1_l06S;o0000o`000?l052go0000o`0C;0;o00000_l03RP2o`000005o`0;9Ol0003o0000o`000?l0
22800_l00002o`0680;o00004oooool000Wooooo00Co0000oooooooooooo00001oooool4o`0000Go
oooo00?o0000ooooooooool09?ooool;o`000004o`0O=_l0003o02Hjo`0V>Pgo000000Co05I;o`00
0?l0FTSo05Y80ol000001?l0Hd3o0000o`1W??l00002o`1[=`03o`000?l0Kc7o000000oo000000Oo
08L5o`000?l3R`3o0h/0o`000?l=S`3o000000;o5i<000[o0000ob6G0?lQU`3o0000obNI0?l0003o
8iL0o`000?lhWP3o00000_l/VP02o`0000;o<id000?o0000obNH0?lWV0000_l00002ob^J0004o`00
0?lNUP3o0000o`0000?o8IL00_l00003ob:G0004o`000?lSU`3o8iL0ob>G00;o000000Co8IL0o`00
0?lBT@3o4Y400_l00002oa2@00;o00000ol<SP001Ol0003o1h`0o`N<0?l7S03o000000?o0HX000Go
0000o`271Ol0Q`Go08L5o`000003o`233@0>o`000?l0OQSo07hHo`000?l0OA[o0000o`1c:ol0003o
074_o`000?l0KS?o0000o`1U?_l00002o`1R@@;o000000So05M:o`000?l0ED_o05E;o`000?l0C4ko
0000o`17B`;o000000?o03U5o`000?l0=T<00_l000001_l0:cgo0000o`000?l08COo0000o`0O=P;o
000000So01Pao`000?l0003o01</o`000?l04B_o0000o`0>:0;o000000Wo00/Uo`000?l02RCo0000
o`088_l0003o00PRo`000?l01R000ol0000Cooooo`002Oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00Gooooo0_l0000Xooooo`Ko000000?o01@^o`000?l06S802Ol000002?l0
?dOo0000o`19C?l0BDco0000o`1@C_l0003o05E;2_l000002ol0Icco0000o`1[=ol0JcOo0000o`1_
<Ol0003o07<Zo`000?l0N2?o000000;o07`L00?o0000o`204ol000000_l0Q0/00ol0003o08T1o`00
000@o`0000?o>9h00_l000002Om1X@3o0000oc>M0?lcW@3o0000obNH0?l0003o>Il0o`000002ob^J
00;o00000_l_V`001Ol0003o8IL0o`000?laW03o000000;o8YL00_l00002ob>G00;o00000olQU`02
o`0000;o7iH00_l000001?lKU03o0000o`b>0?l<SP02o`0000;o1h`00_l00002o`6:00;o00000_l0
Q`D2o`0000;o08<=0_l000002ol0OQSo0000o`1m6_l0003o07XOo`000?l0LBoo0000o`1^<ol0003o
06/g00;o000000?o0691o`000?l0Gd@00ol000001ol0ED_o0000o`1BCOl0003o04M;o`000?l0@dT0
0_l000000ol0=T?o0000o`0b@@02o`000006o`0W>ol0003o0000o`0O=_l0003o01dd0_l00002o`0G
<003o`000?l04B_o014[00;o000000?o00dXo`000?l000000_l02R@2o`0000;o00PR0_l000001?l0
1R3o0000o`000?l0000Booooo`002_ooool2o`0000Sooooo1Ol00003ooooo`03o`000?oooooooooo
02Oooooo00?o0000o`078Ol000000_l02bD8o`000005o`0X??l0003o0350o`000?l0>TD02_l00000
1ol0FDWo0000o`1NAOl0003o0691o`000?l0IS`02ol000002ol0N2?o0000o`1l7?l0O1co0000o`20
4ol0003o08@;o`000?l0R@7o000000;o28d000?o0000oa:A0?l000000_lNU@001_l0003o:IT0obVI
0?l0003o=Id0o`0000;o?:0000?o0000ocRN0?lhWP000_l00002od6Q0003o`000?lcW@3o<id000;o
00000oliW`02o`000004ocjP0?l0003o;i/0obnK00;o00000olaW002o`0000;o<Y`00_l000001?la
W03o0000ob6G0?lQU`02o`0000?o7iH000Co0000oa^D0?lKU03o6i@00_l00002oaNC00;o00000_lA
T002o`0000;o2Xh00_l00002o`::00;o00000_l0Q@T01_l0003o07dJo`000?l0NQoo0000o`1g90?o
000000?o06/go`000?l0J3/00_l000001?l0GdCo0000o`000?l0FTP2o`000007o`1BCOl0003o051>
o`000?l0@dWo0000o`0nA`02o`000003o`0b@Ol0003o02ho00;o000000[o02Dio`000?l0003o01dd
o`000?l06c?o0000o`0G<?l0003o01D^0_l000001?l042[o0000o`000?l03BL3o`000005o`0:9?l0
003o0000o`000?l022800_l00002o`067`;o00004Oooool001cooooo00?o0000ooooooooool0:?oo
ool9o`000003o`0K<ol0003o02<h00Oo000000?o04A9o`000?l000002_l000002?l0HT7o0000o`1V
??l0003o06/go`000?l0Kc7o00000_l0M2X00ol0003o07PSo`00000:o`000009o`290Ol0003o28d0
o`R=0?l0003o4Y40o`000?lNU@3o000000;o:IT000Co0000ocFM0?leW@3o00000_llX002o`000003
odjU0?l0003o@J4000;o@J400_l000001?m8Y03o0000ocVO0?liW`02o`0000?o?Z000_l000001?m1
X@3o0000oc6L0?laW002o`0000?o<Y`000Co0000oc6L0?laW03o<I`00_l000001?l`W03o0000oanF
0?lOUP02o`0000?o6i@000Go0000oaNC0?lGT`3o5i<0o`000003oa6@0005o`000?l:SP3o2Xh0o`Z>
0?l000000ol2RP02o`000003o`252Ol0003o08@;00?o000000Wo07LTo`000?l0M2[o0000o`1a;_l0
003o06Pko`000?l0ICh00ol000000ol0FTSo0000o`1GBP02o`000007o`1@C_l0003o04e>o`000?l0
?TOo0000o`0jA@02o`000003o`0^?ol0003o02/m00;o00000_l08SP00ol0003o01/co`0K<`02o`00
0003o`0E;_l0003o01<]00;o000000?o00lYo`000?l000000_l032H2o`000007o`098ol0003o0000
o`000?l01b7o0000o`067`03o`00017ooooo000Looooo`;o0000:oooool4o`000003o`0@:_l0003o
01H_00Co00000_l0:cd00ol0003o03A2o`000006o`000007o`1CC?l0003o05Q:o`000?l0G4Ko0000
o`1Q@P0:o`0000;o07@Z00Oo0000o`1h8ol0003o07dJo`000?l0PA;o000000;o08H800?o0000o`6:
0?l000002_l00002obVI0004o`000?leW@3o0000ocbP00;o00000om>Y@001?l0003o@J40od6Q0?l0
0003odRT00;o000000?oCZD0o`000?lnX0000_lnX0001?l0003o@J40od6Q0?m1X@02o`000003od>R
0?l0003o<Y`000;o<Y`000Go0000oc6L0?laW03o<I`0o`000003oc2L00;o00000_l/VP004ol0003o
6i@0o`000?lXV@3o0000oaNC0?l0003o8YL0o`000?lAT03o0000oa^D0?l0003o2Xh0o`000?lCT@3o
0000o`::0?l000000_l6S0002_l0003o08@;o`000?l0PA;o0000o`1n6?l0003o07@Zo`000?l0LBh3
o`000003o`1U?_l0003o069100?o000000?o05M:o`000?l0ED`00_l000000ol0CDko0000o`17B`02
o`00000;o`0jAOl0003o03E3o`000?l0:cgo0000o`0W>ol0003o028ho`000?l07cH00_l000001?l0
6C7o0000o`000?l04bd2o`000005o`0?:Ol0003o00hXo`000?l032H00_l000001?l02B?o0000o`09
8ol00002o`078@;o000000Co00HOo`000?l0003o00004?ooool001cooooo00?o0000ooooooooool0
:_ooool00ol0003o00LQo`078@0?o`000003o`18C?l0003o055=00So000000So0652o`000?l0ISgo
0000o`1Z>?l0003o06lao`0000;o07<Z2?l000001?l0PA;o0000o`262?l0QPP2o`0000;o38h000?o
0000oaNC0?l000000_lSU`000ol0003o<9`0o`000006o`000003oe>W0?l0003oCZD000;oCZD000Co
0000od6Q0?l0003o00000om8Y0001_l0003oCZD0odjU0?m>Y@3o0000ocjP00;o00000om1X@002Ol0
003o@j80od>R0?m3XP3o0000oc:L0?l0003o@j80o`000002oc6L0005o`000?l`W03o<9`0oc2L0?l0
00001?l/VP001Ol0003o:9T0obRI0?lXV@3o000000?o8YL000Go0000oa^D0?lKU03o6i@0o`000003
oa>A0009o`000?l6S03o1X`0o`000?l4R`3o0000o`214_l0003o07hH00?o000000?o074^o`000?l0
00000_l0JcL01?l0003o0691o`000?l00002o`1LAP04o`000?l0EDco0000o`1BC@;o000000?o04M;
o`000?l0@TT00_l000001?l0=D?o0000o`0a@?l00002o`0W>`;o000000?o01lfo`000?l07C@00_l0
00001?l05c3o0000o`000?l04R`2o`0000;o00hX0_l000000ol02bGo0000o`000002o`098`?o0000
00Co00LQo`000?l0003o00HO0ol0000?ooooo`007?ooool00ol0003oooooooooo`0[ooooo`Oo0000
00?o01L`o`000?l000001?l000000ol0=dCo0000o`12B@05o`000005o`1FBol0003o05Y8o`000?l0
Gd@02?l000001_l0Kc7o0000o`1c:_l0003o07PSo`0000;o07dJ00?o0000o`224Ol000001ol00002
o`b>0007o`000?lGT`3o0000ob>G0?l0003o<9`0o`000002ocjP0004o`000?m;Y03oBj@0o`0000;o
DjL000?o0000odjU0?m>Y@000_l00002oeNX0004o`000?m8Y03o0000o`0000CoCZD000Go0000oe6V
0?mAYP3o0000od6Q0002o`0000?o@j800_l00002od>R0006o`000?laW03o0000od6Q0?l0003o<9`0
0_l00003obbJ00;o00000_lXV@02o`0000;o8YL00_l00002oa^D00;o00000_lCT@02o`000007o`J<
0?l0003o18/0o`000?l0R0?o0000o`1n6002o`0000;o07LU0ol000000ol0JcOo0000o`1W>`03o`00
0007o`1LA_l0003o05U8o`000?l0DTgo0000o`1?CP02o`000003o`12BOl0003o03e600;o000000?o
0350o`000?l0;Ch00_l000001_l093Wo0000o`000?l07CCo0000o`0J<P;o000000Co01D^o`000?l0
003o010[0ol000001?l03BOo0000o`000?l02RD3o`000003o`088_l0003o000000Co000000?o00HO
o`000?l000003oooool001_ooooo0_l0000_ooooo`Wo00000_l09cX6o`000003o`1=C_l0003o05=<
00Go000000Oo05m4o`000?l0I3oo0000o`1Y>Ol0003o06hc00So00000_l0OAX2o`0000;o08H700?o
0000o`>;0?l000000_l?T008o`000007oc2L0?l0003o?Z00ocjP0?l0003oBj@0o`000002oe>W0005
o`000?m>Y@3o0000ofJ/0?l000000_mGZ002o`0000;oGZX000?o0000odjU0?m>Y@000_l00003oe6V
0008o`000?mDY`3oE:L0o`000?m3XP3o0000oeFW0?l00002od>R00;o00000om1X@001_l0003o?j40
ocnQ0?l0003o;9X0o`0000;o>il00_l00002ocFM00;o00000_l^V`02o`0000;o9YP00_l00002oaRC
0006o`000?l4R`3o0000o`280ol0003o08@;0ol000000ol0MbGo0000o`1d:P03o`000003o`1W>ol0
003o06@n00?o000000Oo05U8o`000?l0Ed[o0000o`1?C_l0003o04]=00;o000000?o03e6o`000?l0
>4@00_l000000ol0;Cko0000o`0Y?002o`000006o`0Q=ol0003o0000o`0J<_l0003o01Pa0_l00000
1?l04bgo0000o`000?l03bT3o`000004o`0<9_l0003o0000o`0990?o000000Go00PRo`000?l0003o
00LPo`000002o`067`?o00003_ooool001_ooooo00?o0000ooooooooool0;oooool=o`000003o`0k
AOl0003o04I;00Co00000_l0F4T9o`000006o`1^<ol0003o07<[o`000?l0N2?o00000_l0OAX5o`00
00;o08H700Oo0000o`>;0?l0003o3i00o`000?lKU03o000000;o:9T000?o0000ocJN0?l000002?l0
00000omCY`3o0000o`000003ofJ/00;o000000WoKjl0o`000?mNZP3oGZX0o`000?m>Y@3o0000of>/
0?l000000_mAYP02o`0000?oE:L000Co0000oeFW0?mEY`3oEJL00_l000001?mDY`3o0000od6Q0?m1
X@02o`0000;o?j400_l00002oc^O00;o00000oleW@001Ol0003o;Y/0objK0?l^V`3o000000?o9YP0
00_o0000oaRC0?lHT`3o0000oaFB0?l0003o08P3o`000?l0Q0_o0000o`214P03o`000004o`1d:_l0
003o0000o`1]=0;o000000Co06@no`000?l0003o05i50_l000000ol0Ed[o0000o`1DC003o`000003
o`15B_l0003o000000;o000000?o03=2o`000?l000000_l000001?l09S[o0000o`000?l07SD2o`00
0003o`0H<Ol0003o01H_00;o000000Co014[o`000?l0003o00hX0ol000000ol02bGo0000o`000002
o`098`;o000000?o00LQo`000?l01b000ol000001?l01Qoo0000o`000?l0000=ooooo`006oooool0
0ol0003oooooooooo`0]ooooo`;o000000?oooooo`000?l01b401?l000000ol06C7o0000o`000002
o`000003o`0c@Ol0003o000000;o00000_l0D4h6o`000004o`1R@Ol0003o06Lko`0000;o06dd1Ol0
00001_l0N2?o0000o`1m6_l0003o088Ao`0000;o08H62?l000001_lKU03o0000obRI0?l0003o=Yh0
o`0000;oA:8000Go0000oe>W0?mCY`3o0000of:[0002o`000004ofb^0?l0003oIZ`0ofJ/00;o0000
0_m_[`000ol0003oGZX0oejZ0002o`0000?oHj`00_l000001?mV[@3o0000oeBW0?mDY`02o`0000;o
EJL00_l00003oeBW00;o00000_mBY`02o`000006odnU0?l0003o>il0o`000?m9Y03o00000_leW@02
o`0000;o;Y/00_l00002obJH00;o000000Co69<0o`000?lETP3o5I801?l000001?l0PA;o0000o`00
0?l0NR03o`000003o`1]=?l0003o06Ti00?o000000?o05i5o`000?l0FdL00_l000001?l0E4co0000
o`000?l0CTh2o`000003o`0oAol0003o03Y500;o000000?o02loo`000?l000001Ol000001?l06c?o
0000o`000?l05Rl2o`000003o`0A:ol0003o010Z00;o00000_l032L2o`000003o`0:9?l0003o00TS
00;o00000_l01b42o`000005o`068?l0003o0000o`000?l01Ql00_l0000=ooooo`006oooool2o`00
02_ooooo0ol00004ooooo`Co000000Ko018/o`000?l0003o024go`000?l0:cd2o`0000;o03i71_l0
00000ol0FdOo0000o`1P@`05o`000005o`1]=?l0003o078]o`000?l0MbD01_l000001_l0PQ7o0000
o`261_l0003o18/0o`0000;o490000?o0000oafE0?l000001Ol000002OlfWP3o0000odBR0?m4XP3o
0000oe>W0?l0003oHZ/0o`000003ofb^00;o000000?oP;<0o`000?m_[`000_m_[`02o`000004ogFa
0?l0003oHj`0of>/00;o00000omV[@02o`0000;oJ:d00_l000001?mX[@3o0000oeBW0?mDY`02o`00
00?oDZL000Go0000odnU0?m?Y@3oCjD0o`000003odVT00;o00000_m3XP02o`0000;o>Yl00_l00002
obbJ00;o000000Co5I80o`000?l0003o0h/01?l000001ol0NR3o0000o`1f9_l0003o078/o`000?l0
JCT00_l00002o`1S@004o`000?l0FdOo0000o`1HB@?o000000?o04i>o`000?l0Ad/00_l000000ol0
>TGo0000o`0d@P02o`000005o`0[?Ol0003o0000o`000?l07cD00ol000001?l06C7o0000o`000?l0
4bd2o`000005o`0@:_l0003o00hXo`000?l032L00_l00002o`0:90;o000000Go00PRo`000?l0003o
0000o`078@02o`000004o`067ol0003o00HOo`067`?o00003?ooool000;ooooo0_l00004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooooooo
ool09oooool3o`0000Wooooo3ol000000ol0DTgo0000o`1HBP04o`000004o`1U?Ol0003o06/go`1[
=`Go000000Go07LUo`000?l0O1co0000o`214@08o`0000;o49000_l00002ob^J0003o`000?ljW`3o
000000So000000?oHZ/0o`000?m/[P000_l00002oh2c0003o`000?m_[`3oKjl000;o00000ome/@02
o`000004ogZb0?l0003oIZd0ofJ]00;o00000omX[@001?l0003oJ:d0ofR]0?mX[@02o`000003ofN]
0?l0003oDZL000;oDZL000Go0000odnU0?m?Y@3oCjD0o`000003odVT0005o`000?m3XP3o@j80od>R
0?l000000oljW`001?l0003o;9X0obbJ0?l/VP04o`00000<o`>;0?l0003o0000o`233Ol0003o07lE
o`000?l0MRKo0000o`1b;?l0003o06la0ol000000ol0Hd3o0000o`1O@`04o`000006o`1BCOl0003o
0000o`17Bol0003o04580_l000000ol0=4;o0000o`0`?`03o`000004o`0R>?l0003o0000o`0K<`?o
000000Co01H_o`000?l0003o014[0_l00002o`0>:0;o000000Go00/Uo`000?l0003o0000o`098`02
o`000005o`088Ol0003o0000o`000?l01R001Ol000001?l01Qoo0000o`000?l0000;ooooo`0000Go
ooooo`000?ooooooooooo`000009ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02Cooooo0ol0000<ooooo`03o`000?l0227o000000?o
000000Co01/co`000?l0003o02dn1?l000000ol0CTko0000o`000002o`000003o`1MAOl0003o06=0
00?o000000Go06/go`000?l0L33o0000o`1f9`06o`000006o`214Ol0003o08H7o`000?l4R`3o0000
0_lAT005o`0000;o:iX00_l00002odVT0003o`000?mJZ@3o000000;oJjh01?l000000on6]@3o0000
oh2c0002oh2c00;o000000?oR;H0o`000?me/@000_me/@001?l0003oN[80ogZb0?mj/P02o`000003
ogfc0?l0003oJ:d000;oJ:d000Go0000ofR]0?mX[@3oJ:d0o`000003ofN]000:o`000?mBY`3o0000
ofB/0?l0003oCjD0o`000?mOZ`3o0000odVT00;o00000om3XP02o`000005ocZO0?l0003o@Z80o`00
0?l/VP000_l000000olNU@3o0000o`000002o`000005o`233Ol0003o07lEo`000?l0O1`00ol00000
1?l0Kc7o0000o`000?l0J3/2o`000008o`1O@ol0003o0000o`1IBOl0003o059=o`000?l0Cdh2o`00
0003o`11B?l0003o03]500;o000000Oo030oo`000?l0003o0000o`0R>?l0003o01le00;o000000Go
01Tao`000?l0003o0000o`0C;@02o`000005o`0@:_l0003o0000o`000?l032L00_l000001Ol02RCo
0000o`000?l0003o00PR00;o000000Oo00LQo`000?l0003o0000o`067ol0003o00HO00?o000000?o
00HOo`000?l000002oooool00005ooooool0003oooooooooool000002_ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooooooo`;o00008oooool3o`00013ooooo1?l000001?l04bgo0000
o`000?l093T2o`000003o`0hA?l0003o04E:00;o00000_l0E4`4o`000003o`1S@?l0003o06Pj00Go
000000Go07HWo`000?l0Nako0000o`204`06o`000006o`B;0?l0003o4I00o`000?lOUP3o00000_l]
V`05o`0000;oBJ@000Go0000oeZY0?l0003oJjh0o`000002og^b0004o`000?n6]@3oQ[D0o`0000;o
P;<000Ko0000ohRf0?n8]P3oR;H0o`000?me/@02o`0000?oN[8000[o0000ogfc0?mm/`3oOK<0o`00
0?mX[@3o0000ogjc0?l0003oJ:d00_l00003ofN]00;o00000omT[0001Ol0003oGj/0oen[0?mOZ`3o
000000;oFJT000?o0000od>R0?l000000_mAYP000ol0003o@Z80od:R0003o`000003oajE0?l0003o
000000;o2Hd01?l000001?l0O1co0000o`000?l0M2X3o`000003o`1X>ol0003o06@o00?o000000?o
05U9o`000?l000000ol000000ol0B4co0000o`000002o`000005o`0e@_l0003o0000o`000?l09SX0
0_l000000ol07cGo0000o`0K<`02o`000005o`0F;ol0003o0000o`000?l04B/00_l000001Ol03RSo
0000o`000?l0003o00/U00;o000000Go00TSo`000?l0003o0000o`078@02o`000004o`068?l0003o
00HOo`067`;o000000?o00HOo`000?l000000ol0000;ooooo`0000Goooooo`000?ooooooooooo`00
000:ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Qooooo`?o0000
5Oooool7o`000003o`0_?ol0003o000000So000000?o0613o`000?l000000_l000001?l0KS;o0000
o`1d:_l0M2X5o`000005o`204ol0003o08H8o`000?l3R`001_l000001_lOUP3o0000obfK0?l0003o
?J00o`0000;oCJD01Ol00002of^^0003o`000?mk/P3o000000;oQ[D000Co0000oh2c0?l0003o0000
0on8]P02o`0000;oS[L000Co0000ogZb0?l0003o00000omm/`02o`0000?oO[<000So0000ogfc0?mm
/`3o0000ofN]0?l0003oNk80o`0000;oI:`00_l00002oen[00;o00000_mIZ@02o`0000;oDJH00_l0
00001Om2XP3o0000ocfP0?l0003o<I`000?o000000Co2Hd0o`000?l0003o08D91?l000001?l0M2[o
0000o`000?l0K3D5o`000007o`1MA_l0003o0000o`000?l0DTgo0000o`1?CP02o`000003o`11B?l0
003o000000?o000000Co02Xmo`000?l0003o028h1?l000001?l0637o0000o`000?l04bd3o`000004
o`0?:Ol0003o0000o`0<9P?o000000Co00TTo`000?l0003o00PR0ol000000ol01b3o0000o`000003
o`000003o`067ol0003o000000Cooooo00?o0000ooooooooool02Oooool00005ooooool0003ooooo
ooooool000002oooool00ol0003oooooo`000003o`0000Cooooo00?o0000ooooooooool07?ooool3
o`0001Sooooo00?o0000o`088_l000002Ol000001_l0BDco0000o`000?l0ET_o0000o`1LAP;o0000
00?o06Hmo`000?l0K3H00ol000001Ol0M2[o0000o`1i8Ol0003o07lF00Oo00000_lAT0000ol0003o
7iH0o`000005o`000006ocfP0?l0003oCJD0o`000?mNZP3o00000_ma[`06o`000003ohJe0?l0003o
000000;oVkX000Go0000ohRf0?l0003oXk`0o`000003ohjg0008o`000?nB^03oT[P0o`000?mm/`3o
0000oiBi0?l00002ogjc00;o00000omm/`001?l0003oNk80og^b0?mk/P02o`0000;oMk400_l00002
og6_00;o000000CoJ:d0o`000?mAYP3o00000_mIZ@001_l0003o?J00o`000?laW03o0000obFH00Co
000000Ko08D9o`000?l0003o07dIo`000?l0NB42o`000007o`1/=Ol0003o06Pjo`000?l0ICko0000
o`1MAP02o`0000;o05I;00Co0000o`1?C_l0003o04Q<0ol000000ol0=4;o0000o`000002o`000004
o`0U>_l0003o0000o`0N=@Co000000Co01D^o`000?l0003o010[0ol000001?l03BOo0000o`000?l0
2R@3o`000004o`088_l0003o0000o`078@?o000000?o00HOo`000?l01Ql00ol00006ooooo`03o`00
0?oooooooooo00Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000Oooooo0_l0000Jooooo`?o00007?ooool4o`000004o`0D;_l0003o0000
o`0W>`;o000000Co03i7o`000?l0003o059=1?l000001ol0Hd7o0000o`000?l0003o06`fo`000?l0
LBh01Ol000001Ol0OaKo0000o`242ol0003o0HX000?o00000_lAT002o`0000;o;Y/000?o0000ocjP
0?l000001Ol000001_mNZP3o0000og6_0?l0003oQ;@0o`0000;oU[T00_l000000onR_03o0000oi^j
0002oi^j0004o`000?nS_03oXk`0o`0000;oS[L00_l00003oi:h0004o`000?nD^@3oU;T0oiBi00;o
000000CoU;T0o`000?mm/`3oOK<00_l00002og^b00;o00000omg/@001Ol0003oLJl0og6_0?ma[`3o
000000?oJ:d000Go0000oeVY0?mIZ@3o0000oeBW0003o`000006obFH0?l0003o0000o`j?0?l0003o
18/00_l000000ol0OAWo0000o`1i8@02o`000005o`1a;_l0003o0000o`000?l0ICh01Ol000000ol0
ET_o0000o`000004o`000004o`0jAOl0003o0000o`0_?`Co000000Go024go`000?l0003o0000o`0G
<006o`000005o`0>:?l0003o0000o`000?l02bD00_l000001Ol02B?o0000o`000?l0003o00LQ00;o
000000?o00HOo`000?l000000ol0000:ooooo`03o`000?oooooooooo00Sooooo0002ooooo`;o0000
2?ooool5o`000003ooooool0003o000000?o00000oooool00ol0003oooooooooo`0Fooooo`?o0000
8Oooool7o`000004o`0d@_l0003o0000o`1=CP;o000000?o05U9o`000?l000002?l000000ol0MbCo
0000o`1m6P07o`0000;o3i001Ol00002objK00;o00000_m?YP000ol0003oHZ/0o`000002o`0000;o
LJl000Go0000ohBd0?l0003oU[T0o`000002oj:l0003o`000?nK^P3oVkX000;o00000onS_002o`00
0004ojRn0?l0003oT[P0oi:h00;o00000_nD^@02o`0000?oU;T00_l00002oi>h00;o000000CoSkP0
o`000?mg/@3oMk400_l00002og6_00;o00000_mX[@02o`000004oeVY0?l0003oE:L0oeBW00Go0000
00?o3Xl0o`000?l4R`000_l000000ol0P`ko0000o`000002o`000004o`1a;_l0003o0000o`1Y>@?o
000000?o05e6o`000?l0FDP00ol000000ol0Cdko0000o`000003o`000005o`0c@_l0003o0000o`00
0?l093T01?l000001?l06C7o0000o`000?l04bd6o`000005o`0<9_l0003o0000o`000?l02B<00_l0
00001Ol01b7o0000o`000?l0003o00HO00;o00003oooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`0Dooooo`;o00009Oooool2o`000003o`0=9ol0003o000000[o000000?o
05m4o`000?l0ICh00_l000000ol0Kc;o0000o`1e:003o`000005o`1m6_l0003o08<>o`000?l0R@40
0ol000001?l?T03o0000oafE0?l00002obfK00Go000000CoCjH0o`000?mRZ`3o00000_me/005o`00
00;oU[T000?o0000oj:l0?nR_0000_l000001?nh`P3o0000oj>l0?nS_002o`0000?oZ;h00_l00002
ojbn00;o000000Co[Kl0o`000?nD^@3oU;T00_l00003oi>h0004o`000?n?^03oSkP0ohnh00;o0000
0_n:]P02o`0000;oP[@00_l00002og:`00;o000000OoE:L0o`000?l0003o0000ob^J0?l0003o7YH0
00Co000000Go08<>o`000?l0003o0000o`1f9`03o`000004o`1Y>Ol0003o0000o`1Q@PGo000000Go
059=o`000?l0003o0000o`0oA`05o`000004o`0W>ol0003o0000o`0O=PCo000000Co01D^o`000?l0
003o010Z3Ol000001?l01Qoo0000o`000?l0000Aooooo`03o`000?oooooooooo00Sooooo000Ioooo
o`03o`000?oooooooooo01;ooooo0ol0000Xooooo`?o000000Go01D^o`000?l0003o0000o`0f@`02
o`000004o`1?C_l0003o0000o`1KA`Co000000?o06/fo`000?l000002_l00002o`b>00Go000000Co
;I/0o`000?lnX03o00000_m@YP03o`000006of:[0?l0003oMK00o`000?n9]P3o00000_nN^`06o`00
00?o^<800_l000000oo0``3o0000ojRn0002ojRn0005o`000?n/_P3o[;h0ojbn0?l000000on]_`02
o`000003ojbo0?l0003oTkP000;oTkP000Go0000ohnh0?n?^03oSkP0o`000003ohZf0005o`000?n2
]03oP[@0oh:d0?l000000omb/005o`000003ob^J0?l0003o7YH000;o000000?o1hd0o`000?l00000
0ol000001Ol0MROo0000o`1a;_l0003o06dd00;o000000?o0652o`000?l0GDH01_l000001Ol0AD[o
0000o`000?l0003o035000Co000000Go028go`000?l0003o0000o`0G;`03o`000005o`0A:ol0003o
0000o`000?l02bD00ol000001?l022;o0000o`000?l01R05o`0001Cooooo00?o0000ooooooooool0
2?ooool001Wooooo0_l0000@ooooo`?o0000;?ooool8o`000004o`14B_l0003o0000o`1FB`;o0000
00?o0652o`000?l0J3/00_l000001?l0LRgo0000o`1h8ol0N2<2o`000003o`214_l0003o08L500?o
000000Co38h0o`000?lKU03o00000_l[VP03o`000005ocjP0?l0003oD:H0o`000?mS[0001_l00000
1?n9]P3o0000oijk0?l00002ok?00003o`000?no``3o000000?o^<8000Ko0000ol330?o0``3o`<<0
o`000?nX_P02o`0000?o[;h000Go0000ojfo0?n]_`3o[Kl0o`000003ojbo0006o`000?nC^03o0000
ojVn0?l0003oSkP00_l00003ohZf0004o`000?n2]03oP[@0oh:d00;o000000KoL[00o`000?l0003o
GJX0o`000?m=Y@05o`000004o`N=0?l0003o0000o`243@;o000000Go07/No`000?l0003o0000o`1]
=007o`000003o`1EBol0003o000000Co000000Go03E3o`000?l0003o0000o`0U>@04o`000004o`0H
<Ol0003o0000o`0C;0Co000000Co00/Vo`000?l0003o00PR1_l0000Iooooo`03o`000?oooooooooo
00Sooooo000Iooooo`03o`000?oooooooooo00cooooo0ol0000`ooooo`;o000000Co00dWo`000?l0
003o01dd0ol000001?l0DDgo0000o`000?l0GDH8o`000003o`1h8ol0003o07hG00Co00000_l8S@05
o`000003ob^J0?l0003o?J0000Oo00000_mg/@000ol0003oSKL0o`000005o`000006ok?00?l0003o
_l<0oko30?l0003o^<800_l00003ol3300;o00000_o4a0001Ol0003o[;h0o`000?o5``3o000000;o
[Kl000Co0000ojbo0?n/_`3o[;l00_l00003ojVn000:o`000?nU_@3oYKd0o`000?n:]P3o0000oifk
0?l0003oP[@0o`0000;oSKL00_l000000omMZP3o0000odfU0003o`000003ob:G0?l0003o5Y8000Go
000000Co07/No`000?l0003o074^1?l000001?l0HD?o0000o`000?l0F4T3o`000003o`1;COl0003o
000000Co000000Go02Lko`000?l0003o0000o`0J<P03o`000005o`0D;Ol0003o0000o`000?l032H0
0ol000001?l02B?o0000o`000?l01b02o`0001cooooo00?o0000ooooooooool02?ooool001Wooooo
00?o0000ooooooooool02Oooool3o`0003Cooooo1_l000001Ol0:3_o0000o`000?l0003o05Q900;o
00000_l0I3l01Ol0003o06Xho`000?l0003o07DX00Co000000So08D;o`000?l0003o0000o`R=0?l0
003o5i<0o`0000;o:9T01?l00002odnV0003o`000?mS[03o000000;o00000_mg/@02o`0000;oXk`0
00?o0000ok[20?l000000ol000000ono``3o0000o`000002olRk0005o`000?o0``3o0000olZg0?l0
00000_o4a002o`0000;oaL<000Wo0000ojfo0?l0003oaL<0o`000?n/_`3o0000olG40?l000000_nY
_P02o`0000;oYKd00_l00002oifk00;o00000_n=]`02o`000003ogFa0?l0003o000000?o000000?o
8YL0o`000?lFTP000ol000000ol0Q0co0000o`000006o`000003o`1T?ol0003o000000Co000000?o
04m>o`000?l000000_l000000ol0<T7o0000o`000003o`000004o`0L<ol0003o0000o`0E;PCo0000
00?o00dWo`000?l000001ol00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2?ooool001Wooooo0_l00007ooooo`?o0000>?oooolAo`000004o`1a;_l0003o0000o`1k7@Go0000
00?o0h/0o`000?l000000ol000000olXV@3o0000ocZO0003o`0000;oCjH00_l00002ogRa00Go0000
00CoXk`0o`000?nj`P3o00000_o7_P02o`000003ol^f0?l0003ob;/000;ob;/000Co0000olZg0?o:
]`3ob[L00_l000001?o;]03o0000olG30?o5``02o`0000?oaL<000Co0000olG40?o5a03oaL@00_l0
0002ol7400;o000000Oo^/80o`000?nM^`3o0000ojVn0?l0003oSKL000;o000000CoMK40o`000?l0
003o00000_m3XP06o`000005o`243?l0003o0000o`000?l0MRL01_l000000ol0GdCo0000o`000006
o`000005o`0e@ol0003o0000o`000?l093T02?l000000ol03BOo0000o`000002o`000003o`078Ol0
003o000000Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`006Oooool0
0ol0003oooooooooo`03ooooo`?o0000??ooool4o`000005o`0B;?l0003o0000o`000?l0<T400ol0
00001?l0H4?o0000o`000?l0KC@2o`000003o`1h8ol0003o000000;o00000_l0R082o`000004oa:A
0?l0003o99L0obBG00Co000000?oCJD0o`000?l000001?l000001?mh/@3o0000ohjg0?l00002ojJm
00?o000000Co^/80o`000?o7_P3o00000_o;]P000ol0003ob;/0olRk0002o`0000?ob[L000Co0000
ol^d0?o;]03obk@00_l000001?o;]03o0000olG30?o5``02o`0000?oaL@000Go0000ol740?o1a03o
`L@0o`000003ok[20004o`000?nY_P3oZKh0ojVn00Oo000000?o@j80o`000?l000000ol00002o`29
0@Ko000000Co06`eo`000?l0003o06=01Ol000000ol0CDko0000o`000004o`000003o`0V>_l0003o
000000;o000000?o01</o`000?l000001Ol000001?l01b7o0000o`000?l0000:ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01oooool001Sooooo00Co0000oooooooooooooooo0ol0
0011ooooo`co000000Co06Llo`000?l0003o07@Z0ol000001_l0OQOo0000o`000?l0R0;o0000o`f?
00?o000000?o99L0o`000?lfWP000ol000001Om=Y@3o0000of:[0?l0003oMk4000Co000000GoS[L0
o`000?nV_@3o0000okk30006o`0000;obkH00_l000001?o@Z03o0000olZg0?o:]`02o`0000?obk@0
00Co0000ol^d0?o;]03obk@00_l000001?o;]03o0000olG40?o5a002o`0000;o`L@00_l00003ok[2
00;o000000?oZKh0o`000?nR_0000ol000000omX[@3o0000o`000006o`000003o`290Ol0003o0000
00?o000000?o070`o`000?l000001_l000000ol0D4ko0000o`000002o`000003o`0`@?l0003o0000
00Co000000Go01@]o`000?l0003o0000o`0:9006o`0000kooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`07ooooo`006?ooool4o`0004Cooooo00Co0000o`078Ol0003o00/V0_l00000
0ol06C7o0000o`000009o`000004o`1k7_l0003o0000o`252@Co00000_lNU@04o`000003odVT0?l0
003o000000Go00000_n>]`03o`0000;oY[d00_l00002olVj0003o`000?o>[03ocZ`000?o00000oo@
Z002o`000004om6T0?l0003obk@0ol^d00;o00000oo;]0001?l0003obk@0ol^d0?o;]002o`0000;o
bkH00_l00002olVj0003o`000?nj`P3o000000;oaL<000?o0000oj:l0?l000000_l000000omX[@3o
0000o`000002o`000004obJH0?l0003o0000o`^>00So000000?o06/go`000?l000002?l000000ol0
=4;o0000o`00000<o`0001Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07oooo
o`004?ooool3o`0000Gooooo0_l00017ooooo`[o000000?o03U5o`000?l000000ol000001?l0MBSo
0000o`000?l0PQ42o`000007o`J<0?l0003o0000o`000?lNU@3o0000oc2L0004o`0000;oGZX000?o
0000ogF`0?l000000_l000001?n>]`3o0000ojNm0?nW_@05o`000007olVj0?l0003ocZ`0olj/0?l0
003odJ<0o`000003om2X0004o`000?oAY03odJ@0om6T00;o00000_oBX`001?l0003obk@0ol^d0?l0
0003ol^d0005o`000?o;]P3obkH0ol^f0?l000001?o9^P000ol0003oaL<0olG3000=o`000005o`^>
0?l0003o0000o`000?l0OQL00ol000000ol0Kc;o0000o`000008o`000003o`0g@ol0003o000000So
000000Co00LQo`000?l0003o00005_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Oooooo000Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0AOoooolAo`000004
o`1l6ol0003o0000o`280P?o000000?o5i<0o`000?l000000_l000001?m4XP3o0000o`000?l00002
oejZ00;o00000_n=]`03o`000004ojNm0?l0003o`<<0o`0000;obKP00ol000001_o>[03o0000om6S
0?oAX`3o0000om2X00;o00000ooAY0002_l0003odZ<0om:S0?oBX`3o0000ol^d0?l0003odZ<0o`00
0?o;]002o`0000?obkH000Co0000olVj0?o9^P3obKX00_l000001?o5``3o0000o`000?nZ_P04o`00
0003oeVX0?l0003oAj<000?o000000?o5i<0o`000?l000002ol000000ol0ED_o0000o`000008o`00
0003o`0A:ol0003o000000Co00006_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Oooooo000Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0A_ooool7o`000003
o`0O=Ol0003o000000_o000000Co3Xl0o`000?l0003o:IT01Ol000000omJZ@3o0000o`000003o`00
0003ohfg0?l0003oY[d000Co000000Go`<<0o`000?o9^03o0000olnX0004o`000003om6S0?l0003o
000000;oei@000Co0000om6T0?l0003o00000ooBX`02o`0000?odZ<000[o0000om6T0?oAY03o0000
ol^f0?l0003od:L0o`000?o9^P3o00000_o</P09o`000005odNS0?l0003o0000o`000?lGT`001_l0
00000ol0LRco0000o`00000Co`0001oooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`07ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Gooooo00Co0000
o`078Ol0003o00/U4?l000001?l2R`3o0000o`000?lQU`02o`000004ocjP0?l0003oDjL0oe>W00;o
000000CoLJl0o`000?n9]P3oRKH01?l00002ol3300?o00000_o9^002o`0000;oeIT00_l000000ooI
SP3o0000omND0002omND0008o`000?oHT@3of940o`000?oBX`3o0000omR@0?l00002om:S00;o0000
0_oAY002o`0000?od:L000Go0000olbb0?o</P3o0000olZf0003o`000003oiRj0?l0003o0000023o
00008oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo000Aooooo`03o`00
0?oooooooooo00Wooooo0_l00016oooooaGo000000Co5980o`000?l0003o=Id00ol000000omCY`3o
0000of^^0003o`000003ohVf0?l0003oXk`000?o000000Co`<<0o`000?o:^03ob[P01Ol000001OoE
V@3o0000omV>0?oISP3o000000;oei@00_l00003omRA0004o`000?oHT03of900omR@00;o00000_oH
T002o`000004omNC0?l0003od:L0om2W00;o000000?oc;80o`000?o:]P000ol000000onH^P3o0000
o`000002o`000003odNS0?l0003o000000?o000000?o08L5o`000?l000005?l0000Uooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01_ooool0013ooooo0_l0000=ooooo`03o`000?oo
oooooooo04Gooooo1_l000000ol052ko0000o`00000?o`0000;oBj@01?l00002oh>d00Co00000_nn
``03o`000004olZh0?l0003od:L0o`0000;oeYH00ol00002omV>00;o000000CogWl0o`000?oHT@3o
f9400_l00002omR@00;o00000ooHT0001?l0003oei<0omNC0?oGT`02o`0000;odih04_l000000ol0
NB3o0000o`00000>o`0002_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06oooo
o`004Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Gooooo6?l000000om;Y03o
0000of:[0003o`000003oh>d0?l0003oW[/000?o000000?o_/<0o`000?o9^0001?l000001Oo@Y`3o
0000omJF0?l0003og8<000Co00000ooNO`02o`0000;ogg`00_l000001?oON`3o0000omR@0?oHT002
o`0000?oei<000Co0000om>N0?oCWP3odih01_l000000on3]03o0000o`000003o`000003ob:G0?l0
003o000001;o0000;_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo000Q
ooooo`03o`000?oooooooooo04Gooooo1Ol000000ol03RSo0000o`00000Co`0000;oNk801?l00002
ok[200Co00000_o@Y`03o`000004omJF0?l0003og8<0o`0000;oh7P000Go0000omio0?oNO`3ogWl0
o`000003omml0004o`000?oON`3ogg/0ommk00;o00000_oNOP001_l0003oei<0o`000?oJR@3o0000
om>N01go0000=?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo000Roooo
o`;o0000A_ooool01?l0003o00LPo`000?l02B@Go`000003og^b0?l0003oU[T000?o000000?o^/80
o`000?o9^P000ol000001?o@Y`3o0000omNE0?oGU@03o`000006omb30?l0003oh7P0on1h0?l0003o
gWl00_l00003omml0005o`000?oON`3ogg/0ommk0?l000001?oNOP000ol0003ofXT0omZ90006o`00
0005ok?00?l0003o0000o`000?mGZ0004_l0000fooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01_ooool002Cooooo00?o0000ooooooooool0A?oooolNo`0000;o//001?l00002olnY
00?o000000?oeiD0o`000?oMP@001ol00002onEX0005o`000?oOO03o0000onEU0?l000000_oON`00
1?l0003ogWh0omin0?oNOP02o`000004omZ90?l0003o0000om>P00?o000000?o/l00o`000?l00000
1ol000000ol0Q`Go0000o`000007o`0003_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`06ooooo`009Oooool00ol0003oooooooooo`14ooooo`_o000000?o01Xbo`000?l000004?l0
00000onb`03o0000olNn0003o`000004olnY0?l0003oeYH0omJF00Co00000_oSK@001?l0003oif00
onMP0?l00002onEX00;o00000_oUI@001ol0003ogg/0o`000?oUI`3o0000omin0?l000000_oRLP0H
o`0003oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`009_ooool00ol0
003oooooooooo`15ooooob3o00000_o>[003o`000003omJF0?l0003ogH4000?o000000?ohfd0o`00
0?oWH0000_oWH002o`000004ona?0?l0003oiFD0onEU00;o00000ooUI`001Ol0003ohW80on9b0?l0
003oggT000_o000000?o9IP0o`000?l000001_l00013ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01Oooool002Oooooo0_l00015ooooo`03o`000?l01R3o000001[o000000Oo_l<0
o`000?l0003o0000olj/0?l0003oeIT000Go00000_oTJ`03o`000003onMP0?l0003o000000?ok4l0
0_l000001?o/C`3o0000onEW0?oUI`02o`000003on9b0?l0003oggT000Oo000000?oNk80o`000?l0
00002?l00016ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool002Wooooo
00?o0000ooooooooool0@oooool00ol0003o00HPo`000002o`088`04o`000?l02bGo0000o`0>:1Ko
000000?ob[H0o`000?l000000_l00002omb400?o000000?oi6/0o`000?oZE@000_l000000oo^A`3o
0000ona?0002ona?0004o`000?o/C`3ok4l0ona?00;o00000_oXFP06o`000003olK10?l0003o0000
00Wo0000B_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo000Zooooo`03
o`000?oooooooooo04?ooooo8?l000001_oAX`3o0000o`000?l0003og8@0o`0000;ohfd01?l00002
oni70003o`000?o/C`3ok4l000;o00000oo/C`001?l0003oj5X0onQJ0?oXFP02o`000003omZ;0?l0
003o000000[o0000C_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000[
ooooo`03o`000?oooooooooo04Cooooo8Ol000001ooIS`3o0000o`000?l0003ohfd0o`000?oZE@00
0ol00002oni700;o00000_ob=P000ol0003ok4l0ona?0002o`000003onQJ0?l0003o000000Co0000
00?oaL<0o`000?l000001?l0001Booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1Oooool002cooooo00?o0000ooooooooool0A?oooolRo`000003on1h0?l0003o000000?o00000_oa
?003o`0000?olSH000?o0000ona?0?l000000_o`@00;o`0005Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`05ooooo`00;Oooool2o`0004Cooooo00?o0000o`067ol000002_l00002
o`0@:QKo000000Soif00o`000?l0003o0000oo4l0?l0003om2d0o`0000?olSH00_l00002oo100003
o`000?oWG`3o000000Oo0000F?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Go
oooo000_ooooo`03o`000?oooooooooo04;ooooo0_l000000ol01Qoo0000o`000009o`000003o`0?
:Ol0003o000001Go000000CokTL0o`000?oa?03o00000_od;@001_l0003olSH0o`000?of9`3o0000
oo1000So0000G?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000`oooo
o`03o`000?oooooooooo04?ooooo00Co0000o`067ol0003o00LQ2Ol000000ol03BOo0000o`000005
o`000003o`0A:ol0003o000000;o00000_l04B/=o`000003oo@]0?l0003o000000;omRL00ol00000
0ooVHP3o0000o`00001Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool0
037ooooo00?o0000ooooooooool0@oooool3o`0000;o00LQ2?l000000ol032Ko0000o`00000Bo`00
0004o`0;9Ol0003o0000o`098`?o000000GonAd0o`000?of9`3o0000oo@`0003o`0006?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`00<_ooool2o`0004Cooooo1?l00000
0ol01b7o0000o`088P07o`000003o`0;9Ol0003o000000;o000000?o00`Vo`000?l000001_l00000
0ol02RCo0000o`00000>o`0006Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04
ooooo`00=?ooool00ol0003oooooooooo`13ooooo`Go000000?o00PQo`000?l000003_l000000ol0
2B?o0000o`000006o`000003o`078?l0003o0000077ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`04ooooo`00=Oooool00ol0003oooooooooo`12ooooo`03o`000?l01Qoo000000?o
00000_l01b44o`000003o`088_l0003o000000;o00000_l02284o`000003o`088Ol0003o000000;o
00HP1?l0001dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool003Kooooo
00?o0000ooooooooool0@_ooool00ol0003o00HOo`000004o`000003o`078?l0003o000000;o0000
00?o00LQo`000?l000000ol000000ol01b7o0000o`000006o`0007Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`04ooooo`00=oooool2o`0004?ooooo00?o0000o`067ol01Ql01?l0
00000ol01R3o0000o`000002o`0000;o00HP1?l000000ol01Qoo0000o`00001nooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00oooool003Wooooo00?o0000ooooooooool0@Oooool2
o`000003o`067ol0003o00HO00;o000000?o00HOo`000?l01R000ol000000ol01Qoo0000o`000002
o`00087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`00>_ooool00ol0
003oooooooooo`12ooooo`?o000000?o00HOo`000?l000000ol000000ol01Qoo0000o`000025oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool003_ooooo00?o0000oooooooo
ool0@_ooool3o`000003o`067ol0003o000000?o0000R?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo000looooo`;o0000@oooool3o`0008kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`00?_ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo08oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`00?oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`00@?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
093ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`00@Oooool2o`0003ko
oooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo0013ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0T_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo0014ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0T_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0015
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0Toooool01Ol0003ooooooooooooo
oooo000000Cooooo0016ooooo`;o0000>Oooool00ol0003oooooooooo`2Dooooo`04o`000?oooooo
ooooo`0000Cooooo0018ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0UOooool0
0ol0003oooooo`000004ooooo`00BOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
09Gooooo00Co0000oooooooooooo00000oooool004[ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`2Fooooo`03o`000?oooooo000000?ooooo001;ooooo`;o0000=?ooool00ol0003o
ooooooooo`2Gooooo`;o00000oooool004gooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`2Fooooo`?o00000oooool004kooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`2Cooooo`Co00001_ooool004oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2?
ooooo`Co00002_ooool0053ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2<oooo
o`?o00003_ooool0057ooooo0_l0000]ooooo`03o`000?oooooooooo08Sooooo1?l0000Aooooo`00
Doooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08Cooooo1?l0000Eooooo`00E?oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo083ooooo1?l0000Iooooo`00EOooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07cooooo1?l0000Mooooo`00E_ooool2o`00
02Sooooo00?o0000ooooooooool0N?ooool4o`00027ooooo001Hooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0MOooool3o`0002Gooooo001Iooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0LOooool4o`0002Sooooo001Jooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0KOooool4o`0002cooooo001Kooooo`;o00008oooool00ol0003oooooooooo`1Y
ooooo`Co0000<?ooool005gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Uoooo
o`Co0000=?ooool005kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Qooooo`Co
0000>?ooool005oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Nooooo`?o0000
??ooool0063ooooo0_l0000Nooooo`03o`000?oooooooooo05[ooooo1?l0000oooooo`00H_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo1?l00013ooooo`00Hoooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo1?l00017ooooo`00I?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0001;ooooo`00IOooool2o`0001Wooooo
00?o0000ooooooooool0B_ooool4o`0004oooooo001Wooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0Aoooool3o`0005?ooooo001Xooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0@oooool4o`0005Kooooo001Yooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0?oooool4o`0005[ooooo001Zooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`Co
0000G_ooool006cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`Co0000
H_ooool006gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`?o0000I_oo
ool006kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`Co0000JOooool0
06oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0]ooooo`Co0000KOooool0073o
oooo0_l0000=ooooo`03o`000?oooooooooo02Wooooo1?l0001aooooo`00L_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0001eooooo`00Loooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo027ooooo1?l0001iooooo`00M?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01kooooo0ol0001mooooo`00MOooool2o`0000Sooooo00?o0000oooo
ooooool06_ooool4o`00083ooooo001gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05_ooool4o`0008Cooooo001hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4_ooool4o`0008Sooooo001iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_oo
ool4o`0008cooooo001jooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000T?ooool0
07cooooo00Co0000oooooooooooo00002Oooool3o`0009Cooooo001mooooo`03o`000?oooooo0000
00Gooooo1?l0002Gooooo`00O_ooool2o`000003ooooool0003o000000;o0000Voooool007oooooo
0_l0002Oooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00;_ooool3o`0000Cooooo0ol00002ooooo`?o00000oooool5
o`0000;ooooo0ol00003ooooo`?o00001?ooool2o`0000Sooooo0_l000001Ooooooo0000o`000?l0
003ooooo00?o00000oooool4o`0000?ooooo0_l000000ooooooo0000o`000004o`0000;ooooo1?l0
0003ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000001ooo
ool3o`0000;ooooo0ol00004ooooo`Co000000Goooooo`000?l0003o0000ooooo`06o`0000;ooooo
1Ol00002ooooo`?o00000_ooool3o`0000Wooooo0ol00005ooooo`;o000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?ooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000;o
oooo0ol000000ooooooo0000o`00000Jooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Go
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000
ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooo
o`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool0000Kooooo`00;oooool00ol0003oooooooooo`02ooooo`Go00000_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooooooo`Go000000?oooooo`000?ooool01Oooool00ol0003o
ooooooooo`08ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool3o`0000?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool3
o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oo
oooo00001_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Wooooo000_ooooo`?o00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo0_l00005ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000[ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l00003
ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00007ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000[ooooo0ol00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`00
0?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool06Oooool002oooooo00Co0000oooooooooooo00000_ooool3
o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool3o`0000?ooooo0ol00002
ooooo`Co00002?ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`?o00000_oo
ool2o`000003ooooool0003o000000?ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo1?l0
0002ooooo`?o00001?ooool3o`0000;ooooo1?l00008ooooo`06o`000?oooooo0000ooooool0003o
oooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000?ooooo1?l00002ooooo`Co
00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oooooooooo00;o
oooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co00000_ooool3o`00
00Cooooo0ol00002ooooo`Co00007?ooool002oooooo00Co0000oooooooooooo00003oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000o`00000:oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Joooo
o`05o`000?oooooo0000ooooool000006oooool00ol0003oooooooooo`0Dooooo`04o`000?oooooo
ooooo`0001Cooooo00?o0000ooooooooool0;_ooool002kooooo1?l0000Aooooo`;o00003_ooool0
0ol0003oooooooooo`08ooooo`04o`000?ooooooooooooooo`;o00002?ooool2o`0000Sooooo0ol0
000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool5o`0001cooooo0_l0
000Cooooo`Go00005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.090461, 0.0465522, \
0.00367217, 0.00367217}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -84 0 ]
[.5 .82364 84 9 ]
[.13049 .20567 -23.9762 -9 ]
[.13049 .20567 .0238 0 ]
[.33577 .12491 -5.58425 -9 ]
[.33577 .12491 .41575 0 ]
[.55826 .03745 -15.5233 -9 ]
[.55826 .03745 2.47666 0 ]
[.75923 .08444 0 -6.17413 ]
[.75923 .08444 24 2.82587 ]
[.85704 .23422 0 -6.03048 ]
[.85704 .23422 6 2.96952 ]
[.94201 .36435 0 -5.90954 ]
[.94201 .36435 18 3.09046 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01702 .3096 -18 -2.77992 ]
[.01702 .3096 0 6.22008 ]
[.00971 .35539 -18 -2.81874 ]
[.00971 .35539 0 6.18126 ]
[.00218 .40254 -18 -2.85883 ]
[.00218 .40254 0 6.14117 ]
[-0.00557 .45112 -18 -2.90026 ]
[-0.00557 .45112 0 6.09974 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Modulation Transfer Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13976 .21496 m
.1444 .2196 L
s
[(-100)] .13049 .20567 .99802 1 Mshowa
.34434 .13486 m
.34862 .13983 L
s
[(0)] .33577 .12491 .86142 1 Mshowa
.56596 .04808 m
.56981 .05339 L
s
[(100)] .55826 .03745 .72482 1 Mshowa
.125 Mabswid
.17941 .19944 m
.18215 .20226 L
s
.21968 .18367 m
.22238 .18653 L
s
.26058 .16765 m
.26323 .17056 L
s
.30212 .15139 m
.30474 .15433 L
s
.38723 .11806 m
.38975 .12108 L
s
.43082 .10099 m
.4333 .10405 L
s
.47513 .08364 m
.47755 .08675 L
s
.52017 .06601 m
.52254 .06915 L
s
.10072 .23025 m
.10354 .233 L
s
.06227 .2453 m
.06513 .24802 L
s
.61252 .02984 m
.61477 .03307 L
s
.65987 .0113 m
.66206 .01458 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74693 .08901 m
.74078 .0913 L
s
[(-100)] .75923 .08444 -1 .37203 Mshowa
.84462 .23845 m
.83841 .24056 L
s
[(0)] .85704 .23422 -1 .34011 Mshowa
.92949 .36827 m
.92323 .37023 L
s
[(100)] .94201 .36435 -1 .31323 Mshowa
.125 Mabswid
.76763 .12068 m
.76393 .12203 L
s
.78772 .15141 m
.78402 .15274 L
s
.80724 .18126 m
.80352 .18257 L
s
.82619 .21026 m
.82247 .21155 L
s
.86253 .26585 m
.8588 .2671 L
s
.87996 .2925 m
.87622 .29373 L
s
.89692 .31844 m
.89317 .31965 L
s
.91342 .34369 m
.90967 .34488 L
s
.72559 .05638 m
.72191 .05777 L
s
.70359 .02273 m
.69992 .02415 L
s
.94515 .39222 m
.94139 .39338 L
s
.9604 .41556 m
.95664 .4167 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02927 .30491 m
.0354 .30257 L
s
[(0.1)] .01702 .3096 1 -0.38224 Mshowa
.022 .3508 m
.02815 .3485 L
s
[(0.2)] .00971 .35539 1 -0.37361 Mshowa
.01451 .39805 m
.02068 .3958 L
s
[(0.3)] .00218 .40254 1 -0.3647 Mshowa
.0068 .44673 m
.01298 .44453 L
s
[(0.4)] -0.00557 .45112 1 -0.3555 Mshowa
.125 Mabswid
.03494 .26915 m
.03861 .26772 L
s
.03354 .27801 m
.03721 .27659 L
s
.03212 .28693 m
.0358 .28551 L
s
.0307 .29589 m
.03438 .29448 L
s
.02784 .31398 m
.03151 .31258 L
s
.02639 .3231 m
.03007 .32171 L
s
.02494 .33228 m
.02862 .33089 L
s
.02347 .34151 m
.02716 .34013 L
s
.02052 .36014 m
.02421 .35876 L
s
.01903 .36953 m
.02272 .36816 L
s
.01753 .37898 m
.02123 .37762 L
s
.01603 .38849 m
.01972 .38713 L
s
.01299 .40767 m
.01669 .40633 L
s
.01145 .41735 m
.01516 .41601 L
s
.00991 .42708 m
.01362 .42575 L
s
.00836 .43688 m
.01207 .43555 L
s
.00523 .45664 m
.00894 .45533 L
s
.00365 .46662 m
.00736 .46531 L
s
.00206 .47665 m
.00577 .47535 L
s
.00046 .48675 m
.00417 .48545 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .023 .121 r
.40028 .59921 .40512 .60372 .41325 .60128 .40842 .59675 Metetra
0 .023 .121 r
.40842 .59675 .41325 .60128 .4214 .59883 .41659 .5943 Metetra
0 .023 .121 r
.41659 .5943 .4214 .59883 .42958 .59638 .42478 .59183 Metetra
0 .023 .121 r
.42478 .59183 .42958 .59638 .43778 .59392 .433 .58936 Metetra
0 .023 .121 r
.433 .58936 .43778 .59392 .446 .59145 .44124 .58688 Metetra
0 .023 .121 r
.44124 .58688 .446 .59145 .45425 .58898 .44951 .58439 Metetra
0 .023 .121 r
.44951 .58439 .45425 .58898 .46253 .5865 .4578 .5819 Metetra
0 .023 .121 r
.4578 .5819 .46253 .5865 .47083 .58401 .46612 .57939 Metetra
0 .023 .121 r
.46612 .57939 .47083 .58401 .47916 .58151 .47446 .57688 Metetra
0 .023 .121 r
.47446 .57688 .47916 .58151 .48751 .57901 .48283 .57436 Metetra
0 .023 .121 r
.48283 .57436 .48751 .57901 .49589 .57649 .49123 .57183 Metetra
0 .023 .121 r
.49123 .57183 .49589 .57649 .50429 .57397 .49965 .56929 Metetra
0 .023 .121 r
.49965 .56929 .50429 .57397 .51272 .57145 .50809 .56676 Metetra
0 .023 .121 r
.50809 .56676 .51272 .57145 .52118 .5689 .51657 .5642 Metetra
0 .023 .121 r
.51657 .5642 .52118 .5689 .52966 .56636 .52506 .56165 Metetra
0 .023 .121 r
.52506 .56165 .52966 .56636 .53817 .56381 .53359 .55908 Metetra
0 .023 .121 r
.53359 .55908 .53817 .56381 .5467 .56125 .54214 .55651 Metetra
0 .023 .121 r
.54214 .55651 .5467 .56125 .55526 .55868 .55072 .55392 Metetra
0 .023 .122 r
.55072 .55392 .55526 .55868 .56385 .55612 .55932 .55134 Metetra
0 .023 .122 r
.55932 .55134 .56385 .55612 .57247 .55352 .56796 .54873 Metetra
0 .023 .121 r
.56796 .54873 .57247 .55352 .58111 .55092 .57661 .54612 Metetra
0 .023 .122 r
.57661 .54612 .58111 .55092 .58977 .54835 .5853 .54352 Metetra
0 .023 .122 r
.5853 .54352 .58977 .54835 .59847 .54572 .59401 .54088 Metetra
0 .023 .122 r
.59401 .54088 .59847 .54572 .60719 .54312 .60275 .53826 Metetra
0 .023 .122 r
.60275 .53826 .60719 .54312 .61594 .54049 .61152 .53563 Metetra
0 .023 .122 r
.61152 .53563 .61594 .54049 .62472 .53785 .62032 .53297 Metetra
0 .023 .121 r
.62032 .53297 .62472 .53785 .63352 .53521 .62914 .53031 Metetra
0 .023 .122 r
.62914 .53031 .63352 .53521 .64236 .53257 .63799 .52766 Metetra
0 .024 .122 r
.63799 .52766 .64236 .53257 .65122 .52993 .64687 .52501 Metetra
0 .024 .122 r
.64687 .52501 .65122 .52993 .66011 .52733 .65578 .52243 Metetra
0 .024 .122 r
.65578 .52243 .66011 .52733 .66903 .52469 .66472 .51974 Metetra
0 .024 .123 r
.66472 .51974 .66903 .52469 .67799 .52236 .6737 .51735 Metetra
0 .024 .123 r
.6737 .51735 .67799 .52236 .68694 .51925 .68268 .51434 Metetra
0 .024 .122 r
.68268 .51434 .68694 .51925 .69594 .51652 .69169 .51151 Metetra
0 .024 .122 r
.69169 .51151 .69594 .51652 .70497 .51378 .70074 .50876 Metetra
0 .023 .122 r
.70074 .50876 .70497 .51378 .71403 .51105 .70982 .50601 Metetra
0 .023 .121 r
.70982 .50601 .71403 .51105 .72311 .50832 .71893 .50327 Metetra
0 .023 .121 r
.71893 .50327 .72311 .50832 .73223 .5056 .72807 .50052 Metetra
0 .023 .121 r
.72807 .50052 .73223 .5056 .74138 .50284 .73723 .49776 Metetra
0 .023 .121 r
.73723 .49776 .74138 .50284 .75055 .50009 .74643 .49499 Metetra
0 .023 .121 r
.74643 .49499 .75055 .50009 .75976 .49733 .75565 .49221 Metetra
0 .023 .121 r
.75565 .49221 .75976 .49733 .76899 .49456 .76491 .48942 Metetra
0 .023 .121 r
.76491 .48942 .76899 .49456 .77826 .49178 .7742 .48663 Metetra
0 .023 .121 r
.7742 .48663 .77826 .49178 .78755 .489 .78351 .48383 Metetra
0 .023 .121 r
.78351 .48383 .78755 .489 .79688 .4862 .79286 .48101 Metetra
0 .023 .121 r
.79286 .48101 .79688 .4862 .80623 .48338 .80223 .47818 Metetra
0 .023 .121 r
.80223 .47818 .80623 .48338 .81562 .48057 .81164 .47535 Metetra
0 .023 .121 r
.81164 .47535 .81562 .48057 .82503 .47775 .82108 .47251 Metetra
0 .023 .121 r
.82108 .47251 .82503 .47775 .83448 .47491 .83055 .46966 Metetra
0 .023 .121 r
.83055 .46966 .83448 .47491 .84396 .47208 .84005 .4668 Metetra
0 .023 .121 r
.84005 .4668 .84396 .47208 .85346 .46922 .84958 .46394 Metetra
0 .023 .121 r
.84958 .46394 .85346 .46922 .863 .46636 .85914 .46105 Metetra
0 .023 .121 r
.85914 .46105 .863 .46636 .87257 .46349 .86873 .45816 Metetra
0 .023 .121 r
.86873 .45816 .87257 .46349 .88218 .46061 .87836 .45527 Metetra
0 .023 .121 r
.87836 .45527 .88218 .46061 .89181 .45771 .88801 .45235 Metetra
0 .023 .121 r
.88801 .45235 .89181 .45771 .90147 .45482 .8977 .44944 Metetra
0 .023 .121 r
.8977 .44944 .90147 .45482 .91117 .45191 .90742 .44652 Metetra
0 .023 .121 r
.90742 .44652 .91117 .45191 .9209 .44899 .91717 .44358 Metetra
0 .023 .121 r
.91717 .44358 .9209 .44899 .93066 .44606 .92696 .44063 Metetra
0 .023 .121 r
.92696 .44063 .93066 .44606 .94046 .44312 .93678 .43767 Metetra
0 .023 .121 r
.93678 .43767 .94046 .44312 .95028 .44017 .94663 .4347 Metetra
0 .023 .121 r
.94663 .4347 .95028 .44017 .96014 .43722 .95651 .43173 Metetra
0 .023 .121 r
.95651 .43173 .96014 .43722 .97003 .43425 .96643 .42874 Metetra
0 .023 .121 r
.39541 .59468 .40028 .59921 .40842 .59675 .40357 .59221 Metetra
0 .023 .121 r
.40357 .59221 .40842 .59675 .41659 .5943 .41175 .58974 Metetra
0 .023 .121 r
.41175 .58974 .41659 .5943 .42478 .59183 .41996 .58726 Metetra
0 .023 .121 r
.41996 .58726 .42478 .59183 .433 .58936 .42819 .58477 Metetra
0 .023 .121 r
.42819 .58477 .433 .58936 .44124 .58688 .43645 .58228 Metetra
0 .023 .121 r
.43645 .58228 .44124 .58688 .44951 .58439 .44474 .57978 Metetra
0 .023 .121 r
.44474 .57978 .44951 .58439 .4578 .5819 .45304 .57727 Metetra
0 .023 .121 r
.45304 .57727 .4578 .5819 .46612 .57939 .46138 .57475 Metetra
0 .023 .121 r
.46138 .57475 .46612 .57939 .47446 .57688 .46974 .57222 Metetra
0 .023 .121 r
.46974 .57222 .47446 .57688 .48283 .57436 .47812 .56969 Metetra
0 .023 .121 r
.47812 .56969 .48283 .57436 .49123 .57183 .48653 .56716 Metetra
0 .023 .121 r
.48653 .56716 .49123 .57183 .49965 .56929 .49497 .5646 Metetra
0 .023 .121 r
.49497 .5646 .49965 .56929 .50809 .56676 .50344 .56205 Metetra
0 .023 .121 r
.50344 .56205 .50809 .56676 .51657 .5642 .51193 .55947 Metetra
0 .023 .121 r
.51193 .55947 .51657 .5642 .52506 .56165 .52044 .55691 Metetra
0 .023 .122 r
.52044 .55691 .52506 .56165 .53359 .55908 .52898 .55433 Metetra
0 .023 .122 r
.52898 .55433 .53359 .55908 .54214 .55651 .53755 .55173 Metetra
0 .023 .121 r
.53755 .55173 .54214 .55651 .55072 .55392 .54615 .54913 Metetra
0 .023 .121 r
.54615 .54913 .55072 .55392 .55932 .55134 .55477 .54653 Metetra
0 .023 .121 r
.55477 .54653 .55932 .55134 .56796 .54873 .56342 .54391 Metetra
0 .023 .121 r
.56342 .54391 .56796 .54873 .57661 .54612 .5721 .5413 Metetra
0 .023 .122 r
.5721 .5413 .57661 .54612 .5853 .54352 .5808 .53867 Metetra
0 .023 .122 r
.5808 .53867 .5853 .54352 .59401 .54088 .58953 .53602 Metetra
0 .023 .122 r
.58953 .53602 .59401 .54088 .60275 .53826 .59829 .53338 Metetra
0 .023 .122 r
.59829 .53338 .60275 .53826 .61152 .53563 .60708 .53073 Metetra
0 .023 .122 r
.60708 .53073 .61152 .53563 .62032 .53297 .61589 .52806 Metetra
0 .023 .122 r
.61589 .52806 .62032 .53297 .62914 .53031 .62473 .52539 Metetra
0 .023 .122 r
.62473 .52539 .62914 .53031 .63799 .52766 .6336 .52272 Metetra
0 .024 .122 r
.6336 .52272 .63799 .52766 .64687 .52501 .6425 .52006 Metetra
0 .024 .122 r
.6425 .52006 .64687 .52501 .65578 .52243 .65144 .51757 Metetra
0 .024 .122 r
.65144 .51757 .65578 .52243 .66472 .51974 .6604 .51498 Metetra
0 .025 .123 r
.6604 .51498 .66472 .51974 .6737 .51735 .66939 .51245 Metetra
0 .025 .123 r
.66939 .51245 .6737 .51735 .68268 .51434 .6784 .50954 Metetra
0 .024 .122 r
.6784 .50954 .68268 .51434 .69169 .51151 .68742 .50651 Metetra
0 .024 .122 r
.68742 .50651 .69169 .51151 .70074 .50876 .69649 .50371 Metetra
0 .023 .122 r
.69649 .50371 .70074 .50876 .70982 .50601 .70559 .50094 Metetra
0 .023 .121 r
.70559 .50094 .70982 .50601 .71893 .50327 .71472 .49818 Metetra
0 .023 .121 r
.71472 .49818 .71893 .50327 .72807 .50052 .72387 .49542 Metetra
0 .023 .121 r
.72387 .49542 .72807 .50052 .73723 .49776 .73306 .49264 Metetra
0 .023 .121 r
.73306 .49264 .73723 .49776 .74643 .49499 .74228 .48985 Metetra
0 .023 .121 r
.74228 .48985 .74643 .49499 .75565 .49221 .75153 .48706 Metetra
0 .023 .121 r
.75153 .48706 .75565 .49221 .76491 .48942 .7608 .48425 Metetra
0 .023 .121 r
.7608 .48425 .76491 .48942 .7742 .48663 .77011 .48144 Metetra
0 .023 .121 r
.77011 .48144 .7742 .48663 .78351 .48383 .77945 .47863 Metetra
0 .023 .121 r
.77945 .47863 .78351 .48383 .79286 .48101 .78881 .4758 Metetra
0 .023 .121 r
.78881 .4758 .79286 .48101 .80223 .47818 .79821 .47295 Metetra
0 .023 .121 r
.79821 .47295 .80223 .47818 .81164 .47535 .80764 .4701 Metetra
0 .023 .121 r
.80764 .4701 .81164 .47535 .82108 .47251 .8171 .46725 Metetra
0 .023 .121 r
.8171 .46725 .82108 .47251 .83055 .46966 .82659 .46437 Metetra
0 .023 .121 r
.82659 .46437 .83055 .46966 .84005 .4668 .83611 .46151 Metetra
0 .023 .122 r
.83611 .46151 .84005 .4668 .84958 .46394 .84567 .45862 Metetra
0 .023 .121 r
.84567 .45862 .84958 .46394 .85914 .46105 .85525 .45571 Metetra
0 .023 .121 r
.85525 .45571 .85914 .46105 .86873 .45816 .86486 .45281 Metetra
0 .023 .121 r
.86486 .45281 .86873 .45816 .87836 .45527 .87451 .4499 Metetra
0 .023 .121 r
.87451 .4499 .87836 .45527 .88801 .45235 .88419 .44697 Metetra
0 .023 .121 r
.88419 .44697 .88801 .45235 .8977 .44944 .8939 .44403 Metetra
0 .023 .121 r
.8939 .44403 .8977 .44944 .90742 .44652 .90365 .44109 Metetra
0 .023 .121 r
.90365 .44109 .90742 .44652 .91717 .44358 .91342 .43813 Metetra
0 .023 .121 r
.91342 .43813 .91717 .44358 .92696 .44063 .92323 .43517 Metetra
0 .023 .121 r
.92323 .43517 .92696 .44063 .93678 .43767 .93307 .43219 Metetra
0 .023 .121 r
.93307 .43219 .93678 .43767 .94663 .4347 .94295 .4292 Metetra
0 .023 .121 r
.94295 .4292 .94663 .4347 .95651 .43173 .95286 .42621 Metetra
0 .023 .121 r
.95286 .42621 .95651 .43173 .96643 .42874 .9628 .4232 Metetra
0 .023 .121 r
.39052 .59012 .39541 .59468 .40357 .59221 .39869 .58764 Metetra
0 .023 .121 r
.39869 .58764 .40357 .59221 .41175 .58974 .40689 .58515 Metetra
0 .023 .121 r
.40689 .58515 .41175 .58974 .41996 .58726 .41511 .58266 Metetra
0 .023 .121 r
.41511 .58266 .41996 .58726 .42819 .58477 .42336 .58016 Metetra
0 .023 .121 r
.42336 .58016 .42819 .58477 .43645 .58228 .43164 .57765 Metetra
0 .023 .121 r
.43164 .57765 .43645 .58228 .44474 .57978 .43994 .57514 Metetra
0 .023 .122 r
.43994 .57514 .44474 .57978 .45304 .57727 .44826 .57263 Metetra
0 .023 .122 r
.44826 .57263 .45304 .57727 .46138 .57475 .45661 .57009 Metetra
0 .023 .121 r
.45661 .57009 .46138 .57475 .46974 .57222 .46499 .56755 Metetra
0 .023 .121 r
.46499 .56755 .46974 .57222 .47812 .56969 .47339 .565 Metetra
0 .023 .122 r
.47339 .565 .47812 .56969 .48653 .56716 .48182 .56246 Metetra
0 .023 .122 r
.48182 .56246 .48653 .56716 .49497 .5646 .49027 .55987 Metetra
0 .023 .122 r
.49027 .55987 .49497 .5646 .50344 .56205 .49875 .55731 Metetra
0 .023 .122 r
.49875 .55731 .50344 .56205 .51193 .55947 .50726 .55473 Metetra
0 .023 .122 r
.50726 .55473 .51193 .55947 .52044 .55691 .51579 .55213 Metetra
0 .023 .122 r
.51579 .55213 .52044 .55691 .52898 .55433 .52435 .54953 Metetra
0 .023 .121 r
.52435 .54953 .52898 .55433 .53755 .55173 .53294 .54693 Metetra
0 .023 .121 r
.53294 .54693 .53755 .55173 .54615 .54913 .54155 .54432 Metetra
0 .023 .122 r
.54155 .54432 .54615 .54913 .55477 .54653 .55019 .5417 Metetra
0 .023 .122 r
.55019 .5417 .55477 .54653 .56342 .54391 .55886 .53908 Metetra
0 .023 .122 r
.55886 .53908 .56342 .54391 .5721 .5413 .56755 .53644 Metetra
0 .023 .122 r
.56755 .53644 .5721 .5413 .5808 .53867 .57628 .53379 Metetra
0 .023 .122 r
.57628 .53379 .5808 .53867 .58953 .53602 .58503 .53114 Metetra
0 .023 .122 r
.58503 .53114 .58953 .53602 .59829 .53338 .5938 .52847 Metetra
0 .023 .122 r
.5938 .52847 .59829 .53338 .60708 .53073 .60261 .52581 Metetra
0 .023 .122 r
.60261 .52581 .60708 .53073 .61589 .52806 .61144 .52312 Metetra
0 .023 .122 r
.61144 .52312 .61589 .52806 .62473 .52539 .6203 .52044 Metetra
0 .024 .122 r
.6203 .52044 .62473 .52539 .6336 .52272 .62919 .51775 Metetra
0 .024 .122 r
.62919 .51775 .6336 .52272 .6425 .52006 .63811 .51513 Metetra
0 .024 .122 r
.63811 .51513 .6425 .52006 .65144 .51757 .64706 .51259 Metetra
0 .025 .123 r
.64706 .51259 .65144 .51757 .6604 .51498 .65606 .51038 Metetra
0 .026 .124 r
.65606 .51038 .6604 .51498 .66939 .51245 .66507 .50775 Metetra
0 .025 .124 r
.66507 .50775 .66939 .51245 .6784 .50954 .67408 .50448 Metetra
0 .024 .123 r
.67408 .50448 .6784 .50954 .68742 .50651 .68313 .50157 Metetra
0 .024 .122 r
.68313 .50157 .68742 .50651 .69649 .50371 .69221 .49863 Metetra
0 .023 .122 r
.69221 .49863 .69649 .50371 .70559 .50094 .70133 .49585 Metetra
0 .023 .121 r
.70133 .49585 .70559 .50094 .71472 .49818 .71048 .49307 Metetra
0 .023 .121 r
.71048 .49307 .71472 .49818 .72387 .49542 .71966 .49029 Metetra
0 .023 .121 r
.71966 .49029 .72387 .49542 .73306 .49264 .72887 .48749 Metetra
0 .023 .121 r
.72887 .48749 .73306 .49264 .74228 .48985 .7381 .48469 Metetra
0 .023 .121 r
.7381 .48469 .74228 .48985 .75153 .48706 .74737 .48188 Metetra
0 .023 .121 r
.74737 .48188 .75153 .48706 .7608 .48425 .75667 .47905 Metetra
0 .023 .121 r
.75667 .47905 .7608 .48425 .77011 .48144 .766 .47624 Metetra
0 .023 .122 r
.766 .47624 .77011 .48144 .77945 .47863 .77536 .4734 Metetra
0 .023 .122 r
.77536 .4734 .77945 .47863 .78881 .4758 .78475 .47056 Metetra
0 .023 .122 r
.78475 .47056 .78881 .4758 .79821 .47295 .79417 .4677 Metetra
0 .023 .122 r
.79417 .4677 .79821 .47295 .80764 .4701 .80362 .46483 Metetra
0 .023 .122 r
.80362 .46483 .80764 .4701 .8171 .46725 .8131 .46195 Metetra
0 .023 .122 r
.8131 .46195 .8171 .46725 .82659 .46437 .82261 .45908 Metetra
0 .023 .122 r
.82261 .45908 .82659 .46437 .83611 .46151 .83216 .45619 Metetra
0 .024 .122 r
.83216 .45619 .83611 .46151 .84567 .45862 .84173 .45326 Metetra
0 .023 .122 r
.84173 .45326 .84567 .45862 .85525 .45571 .85134 .45036 Metetra
0 .023 .122 r
.85134 .45036 .85525 .45571 .86486 .45281 .86097 .44742 Metetra
0 .023 .122 r
.86097 .44742 .86486 .45281 .87451 .4499 .87065 .44449 Metetra
0 .023 .121 r
.87065 .44449 .87451 .4499 .88419 .44697 .88035 .44155 Metetra
0 .023 .121 r
.88035 .44155 .88419 .44697 .8939 .44403 .89008 .43859 Metetra
0 .023 .122 r
.89008 .43859 .8939 .44403 .90365 .44109 .89985 .43564 Metetra
0 .023 .122 r
.89985 .43564 .90365 .44109 .91342 .43813 .90965 .43266 Metetra
0 .023 .121 r
.90965 .43266 .91342 .43813 .92323 .43517 .91948 .42967 Metetra
0 .023 .121 r
.91948 .42967 .92323 .43517 .93307 .43219 .92935 .42667 Metetra
0 .023 .121 r
.92935 .42667 .93307 .43219 .94295 .4292 .93925 .42367 Metetra
0 .023 .121 r
.93925 .42367 .94295 .4292 .95286 .42621 .94918 .42065 Metetra
0 .023 .121 r
.94918 .42065 .95286 .42621 .9628 .4232 .95915 .41763 Metetra
0 .023 .121 r
.3856 .58554 .39052 .59012 .39869 .58764 .39379 .58305 Metetra
0 .023 .121 r
.39379 .58305 .39869 .58764 .40689 .58515 .402 .58055 Metetra
0 .023 .121 r
.402 .58055 .40689 .58515 .41511 .58266 .41024 .57804 Metetra
0 .023 .121 r
.41024 .57804 .41511 .58266 .42336 .58016 .4185 .57553 Metetra
0 .023 .121 r
.4185 .57553 .42336 .58016 .43164 .57765 .42679 .573 Metetra
0 .023 .122 r
.42679 .573 .43164 .57765 .43994 .57514 .43511 .57049 Metetra
0 .024 .122 r
.43511 .57049 .43994 .57514 .44826 .57263 .44345 .56796 Metetra
0 .024 .122 r
.44345 .56796 .44826 .57263 .45661 .57009 .45182 .5654 Metetra
0 .024 .122 r
.45182 .5654 .45661 .57009 .46499 .56755 .46021 .56286 Metetra
0 .024 .122 r
.46021 .56286 .46499 .56755 .47339 .565 .46863 .56028 Metetra
0 .024 .122 r
.46863 .56028 .47339 .565 .48182 .56246 .47707 .5577 Metetra
0 .024 .122 r
.47707 .5577 .48182 .56246 .49027 .55987 .48554 .55514 Metetra
0 .024 .122 r
.48554 .55514 .49027 .55987 .49875 .55731 .49404 .55254 Metetra
0 .023 .122 r
.49404 .55254 .49875 .55731 .50726 .55473 .50256 .54993 Metetra
0 .023 .121 r
.50256 .54993 .50726 .55473 .51579 .55213 .51111 .54733 Metetra
0 .023 .121 r
.51111 .54733 .51579 .55213 .52435 .54953 .51969 .54471 Metetra
0 .023 .121 r
.51969 .54471 .52435 .54953 .53294 .54693 .5283 .54209 Metetra
0 .023 .121 r
.5283 .54209 .53294 .54693 .54155 .54432 .53693 .53947 Metetra
0 .023 .122 r
.53693 .53947 .54155 .54432 .55019 .5417 .54559 .53685 Metetra
0 .024 .122 r
.54559 .53685 .55019 .5417 .55886 .53908 .55427 .53421 Metetra
0 .023 .122 r
.55427 .53421 .55886 .53908 .56755 .53644 .56298 .53153 Metetra
0 .023 .122 r
.56298 .53153 .56755 .53644 .57628 .53379 .57172 .52889 Metetra
0 .024 .122 r
.57172 .52889 .57628 .53379 .58503 .53114 .58049 .52623 Metetra
0 .024 .122 r
.58049 .52623 .58503 .53114 .5938 .52847 .58929 .52354 Metetra
0 .023 .122 r
.58929 .52354 .5938 .52847 .60261 .52581 .59811 .52085 Metetra
0 .024 .122 r
.59811 .52085 .60261 .52581 .61144 .52312 .60696 .51816 Metetra
0 .024 .122 r
.60696 .51816 .61144 .52312 .6203 .52044 .61584 .51546 Metetra
0 .024 .122 r
.61584 .51546 .6203 .52044 .62919 .51775 .62475 .51277 Metetra
0 .024 .122 r
.62475 .51277 .62919 .51775 .63811 .51513 .6337 .51047 Metetra
0 .025 .123 r
.6337 .51047 .63811 .51513 .64706 .51259 .64268 .50805 Metetra
0 .025 .124 r
.64268 .50805 .64706 .51259 .65606 .51038 .65166 .50485 Metetra
0 .025 .124 r
.65166 .50485 .65606 .51038 .66507 .50775 .66069 .50231 Metetra
0 .025 .124 r
.66069 .50231 .66507 .50775 .67408 .50448 .66975 .49969 Metetra
0 .025 .123 r
.66975 .49969 .67408 .50448 .68313 .50157 .67882 .49665 Metetra
0 .024 .122 r
.67882 .49665 .68313 .50157 .69221 .49863 .68791 .49355 Metetra
0 .024 .122 r
.68791 .49355 .69221 .49863 .70133 .49585 .69705 .49072 Metetra
0 .023 .121 r
.69705 .49072 .70133 .49585 .71048 .49307 .70622 .48792 Metetra
0 .023 .121 r
.70622 .48792 .71048 .49307 .71966 .49029 .71542 .48513 Metetra
0 .023 .122 r
.71542 .48513 .71966 .49029 .72887 .48749 .72465 .48231 Metetra
0 .023 .121 r
.72465 .48231 .72887 .48749 .7381 .48469 .7339 .47949 Metetra
0 .023 .121 r
.7339 .47949 .7381 .48469 .74737 .48188 .74319 .47667 Metetra
0 .023 .122 r
.74319 .47667 .74737 .48188 .75667 .47905 .75251 .47384 Metetra
0 .023 .122 r
.75251 .47384 .75667 .47905 .766 .47624 .76186 .47099 Metetra
0 .023 .122 r
.76186 .47099 .766 .47624 .77536 .4734 .77124 .46814 Metetra
0 .023 .122 r
.77124 .46814 .77536 .4734 .78475 .47056 .78065 .46526 Metetra
0 .023 .122 r
.78065 .46526 .78475 .47056 .79417 .4677 .79009 .46239 Metetra
0 .023 .122 r
.79009 .46239 .79417 .4677 .80362 .46483 .79957 .45951 Metetra
0 .023 .122 r
.79957 .45951 .80362 .46483 .8131 .46195 .80907 .45661 Metetra
0 .023 .122 r
.80907 .45661 .8131 .46195 .82261 .45908 .8186 .45371 Metetra
0 .023 .122 r
.8186 .45371 .82261 .45908 .83216 .45619 .82817 .45079 Metetra
0 .024 .122 r
.82817 .45079 .83216 .45619 .84173 .45326 .83777 .44789 Metetra
0 .023 .122 r
.83777 .44789 .84173 .45326 .85134 .45036 .8474 .44494 Metetra
0 .024 .122 r
.8474 .44494 .85134 .45036 .86097 .44742 .85706 .44203 Metetra
0 .024 .122 r
.85706 .44203 .86097 .44742 .87065 .44449 .86676 .43906 Metetra
0 .023 .122 r
.86676 .43906 .87065 .44449 .88035 .44155 .87648 .4361 Metetra
0 .023 .122 r
.87648 .4361 .88035 .44155 .89008 .43859 .88624 .43313 Metetra
0 .024 .122 r
.88624 .43313 .89008 .43859 .89985 .43564 .89603 .43015 Metetra
0 .024 .122 r
.89603 .43015 .89985 .43564 .90965 .43266 .90586 .42716 Metetra
0 .023 .122 r
.90586 .42716 .90965 .43266 .91948 .42967 .91571 .42414 Metetra
0 .023 .121 r
.91571 .42414 .91948 .42967 .92935 .42667 .9256 .42113 Metetra
0 .023 .121 r
.9256 .42113 .92935 .42667 .93925 .42367 .93552 .4181 Metetra
0 .023 .121 r
.93552 .4181 .93925 .42367 .94918 .42065 .94548 .41507 Metetra
0 .023 .121 r
.94548 .41507 .94918 .42065 .95915 .41763 .95547 .41202 Metetra
0 .023 .121 r
.38065 .58093 .3856 .58554 .39379 .58305 .38885 .57843 Metetra
0 .023 .121 r
.38885 .57843 .39379 .58305 .402 .58055 .39708 .57591 Metetra
0 .023 .121 r
.39708 .57591 .402 .58055 .41024 .57804 .40534 .57339 Metetra
0 .023 .121 r
.40534 .57339 .41024 .57804 .4185 .57553 .41362 .57086 Metetra
0 .023 .122 r
.41362 .57086 .4185 .57553 .42679 .573 .42192 .56834 Metetra
0 .024 .122 r
.42192 .56834 .42679 .573 .43511 .57049 .43025 .56582 Metetra
0 .024 .122 r
.43025 .56582 .43511 .57049 .44345 .56796 .43861 .56324 Metetra
0 .024 .122 r
.43861 .56324 .44345 .56796 .45182 .5654 .44699 .56066 Metetra
0 .024 .122 r
.44699 .56066 .45182 .5654 .46021 .56286 .4554 .5581 Metetra
0 .024 .122 r
.4554 .5581 .46021 .56286 .46863 .56028 .46384 .55553 Metetra
0 .023 .122 r
.46384 .55553 .46863 .56028 .47707 .5577 .4723 .55293 Metetra
0 .023 .122 r
.4723 .55293 .47707 .5577 .48554 .55514 .48079 .55033 Metetra
0 .023 .122 r
.48079 .55033 .48554 .55514 .49404 .55254 .4893 .54773 Metetra
0 .023 .121 r
.4893 .54773 .49404 .55254 .50256 .54993 .49784 .54511 Metetra
0 .023 .121 r
.49784 .54511 .50256 .54993 .51111 .54733 .50641 .5425 Metetra
0 .023 .121 r
.50641 .5425 .51111 .54733 .51969 .54471 .51501 .53987 Metetra
0 .023 .121 r
.51501 .53987 .51969 .54471 .5283 .54209 .52363 .53724 Metetra
0 .023 .121 r
.52363 .53724 .5283 .54209 .53693 .53947 .53228 .53459 Metetra
0 .023 .122 r
.53228 .53459 .53693 .53947 .54559 .53685 .54095 .53194 Metetra
0 .023 .122 r
.54095 .53194 .54559 .53685 .55427 .53421 .54966 .52929 Metetra
0 .023 .122 r
.54966 .52929 .55427 .53421 .56298 .53153 .55839 .52662 Metetra
0 .023 .122 r
.55839 .52662 .56298 .53153 .57172 .52889 .56715 .52397 Metetra
0 .024 .122 r
.56715 .52397 .57172 .52889 .58049 .52623 .57593 .52125 Metetra
0 .024 .122 r
.57593 .52125 .58049 .52623 .58929 .52354 .58475 .51859 Metetra
0 .024 .122 r
.58475 .51859 .58929 .52354 .59811 .52085 .59359 .51587 Metetra
0 .024 .122 r
.59359 .51587 .59811 .52085 .60696 .51816 .60246 .51318 Metetra
0 .024 .122 r
.60246 .51318 .60696 .51816 .61584 .51546 .61136 .51048 Metetra
0 .024 .122 r
.61136 .51048 .61584 .51546 .62475 .51277 .62029 .50783 Metetra
0 .024 .123 r
.62029 .50783 .62475 .51277 .6337 .51047 .62925 .50538 Metetra
0 .025 .124 r
.62925 .50538 .6337 .51047 .64268 .50805 .63824 .50267 Metetra
0 .025 .124 r
.63824 .50267 .64268 .50805 .65166 .50485 .64726 .5 Metetra
0 .025 .124 r
.64726 .5 .65166 .50485 .66069 .50231 .6563 .49733 Metetra
0 .025 .124 r
.6563 .49733 .66069 .50231 .66975 .49969 .66537 .49441 Metetra
0 .025 .124 r
.66537 .49441 .66975 .49969 .67882 .49665 .67448 .49172 Metetra
0 .024 .123 r
.67448 .49172 .67882 .49665 .68791 .49355 .6836 .48863 Metetra
0 .024 .122 r
.6836 .48863 .68791 .49355 .69705 .49072 .69274 .48557 Metetra
0 .023 .122 r
.69274 .48557 .69705 .49072 .70622 .48792 .70193 .48276 Metetra
0 .023 .122 r
.70193 .48276 .70622 .48792 .71542 .48513 .71115 .47994 Metetra
0 .023 .122 r
.71115 .47994 .71542 .48513 .72465 .48231 .7204 .47712 Metetra
0 .023 .122 r
.7204 .47712 .72465 .48231 .7339 .47949 .72968 .47428 Metetra
0 .023 .122 r
.72968 .47428 .7339 .47949 .74319 .47667 .73899 .47142 Metetra
0 .023 .122 r
.73899 .47142 .74319 .47667 .75251 .47384 .74833 .46856 Metetra
0 .023 .122 r
.74833 .46856 .75251 .47384 .76186 .47099 .7577 .4657 Metetra
0 .023 .122 r
.7577 .4657 .76186 .47099 .77124 .46814 .7671 .46283 Metetra
0 .023 .122 r
.7671 .46283 .77124 .46814 .78065 .46526 .77653 .45995 Metetra
0 .023 .121 r
.77653 .45995 .78065 .46526 .79009 .46239 .786 .45705 Metetra
0 .023 .121 r
.786 .45705 .79009 .46239 .79957 .45951 .79549 .45415 Metetra
0 .023 .121 r
.79549 .45415 .79957 .45951 .80907 .45661 .80502 .45124 Metetra
0 .023 .121 r
.80502 .45124 .80907 .45661 .8186 .45371 .81457 .44832 Metetra
0 .023 .121 r
.81457 .44832 .8186 .45371 .82817 .45079 .82416 .4454 Metetra
0 .023 .122 r
.82416 .4454 .82817 .45079 .83777 .44789 .83378 .44246 Metetra
0 .023 .122 r
.83378 .44246 .83777 .44789 .8474 .44494 .84344 .4395 Metetra
0 .023 .122 r
.84344 .4395 .8474 .44494 .85706 .44203 .85312 .43654 Metetra
0 .023 .122 r
.85312 .43654 .85706 .44203 .86676 .43906 .86284 .43357 Metetra
0 .024 .122 r
.86284 .43357 .86676 .43906 .87648 .4361 .87259 .43061 Metetra
0 .024 .122 r
.87259 .43061 .87648 .4361 .88624 .43313 .88237 .42762 Metetra
0 .024 .122 r
.88237 .42762 .88624 .43313 .89603 .43015 .89219 .42463 Metetra
0 .024 .122 r
.89219 .42463 .89603 .43015 .90586 .42716 .90204 .42163 Metetra
0 .024 .122 r
.90204 .42163 .90586 .42716 .91571 .42414 .91192 .41859 Metetra
0 .023 .122 r
.91192 .41859 .91571 .42414 .9256 .42113 .92183 .41555 Metetra
0 .023 .121 r
.92183 .41555 .9256 .42113 .93552 .4181 .93178 .4125 Metetra
0 .023 .121 r
.93178 .4125 .93552 .4181 .94548 .41507 .94176 .40945 Metetra
0 .023 .121 r
.94176 .40945 .94548 .41507 .95547 .41202 .95177 .40638 Metetra
0 .023 .121 r
.37567 .5763 .38065 .58093 .38885 .57843 .38389 .57377 Metetra
0 .023 .121 r
.38389 .57377 .38885 .57843 .39708 .57591 .39213 .57125 Metetra
0 .023 .121 r
.39213 .57125 .39708 .57591 .40534 .57339 .4004 .56872 Metetra
0 .023 .122 r
.4004 .56872 .40534 .57339 .41362 .57086 .4087 .56619 Metetra
0 .024 .122 r
.4087 .56619 .41362 .57086 .42192 .56834 .41702 .56366 Metetra
0 .024 .122 r
.41702 .56366 .42192 .56834 .43025 .56582 .42537 .56108 Metetra
0 .024 .122 r
.42537 .56108 .43025 .56582 .43861 .56324 .43374 .5585 Metetra
0 .023 .122 r
.43374 .5585 .43861 .56324 .44699 .56066 .44214 .55592 Metetra
0 .023 .122 r
.44214 .55592 .44699 .56066 .4554 .5581 .45057 .55333 Metetra
0 .023 .122 r
.45057 .55333 .4554 .5581 .46384 .55553 .45902 .55074 Metetra
0 .023 .122 r
.45902 .55074 .46384 .55553 .4723 .55293 .4675 .54813 Metetra
0 .023 .122 r
.4675 .54813 .4723 .55293 .48079 .55033 .476 .54554 Metetra
0 .023 .122 r
.476 .54554 .48079 .55033 .4893 .54773 .48454 .54292 Metetra
0 .023 .122 r
.48454 .54292 .4893 .54773 .49784 .54511 .49309 .54028 Metetra
0 .023 .121 r
.49309 .54028 .49784 .54511 .50641 .5425 .50168 .53765 Metetra
0 .023 .121 r
.50168 .53765 .50641 .5425 .51501 .53987 .51029 .53501 Metetra
0 .023 .121 r
.51029 .53501 .51501 .53987 .52363 .53724 .51893 .53236 Metetra
0 .023 .121 r
.51893 .53236 .52363 .53724 .53228 .53459 .5276 .52971 Metetra
0 .023 .122 r
.5276 .52971 .53228 .53459 .54095 .53194 .53629 .52705 Metetra
0 .023 .122 r
.53629 .52705 .54095 .53194 .54966 .52929 .54501 .52437 Metetra
0 .023 .122 r
.54501 .52437 .54966 .52929 .55839 .52662 .55376 .52166 Metetra
0 .023 .122 r
.55376 .52166 .55839 .52662 .56715 .52397 .56254 .51899 Metetra
0 .024 .122 r
.56254 .51899 .56715 .52397 .57593 .52125 .57134 .5163 Metetra
0 .024 .122 r
.57134 .5163 .57593 .52125 .58475 .51859 .58018 .51358 Metetra
0 .024 .122 r
.58018 .51358 .58475 .51859 .59359 .51587 .58904 .51087 Metetra
0 .024 .122 r
.58904 .51087 .59359 .51587 .60246 .51318 .59793 .50813 Metetra
0 .024 .122 r
.59793 .50813 .60246 .51318 .61136 .51048 .60685 .50542 Metetra
0 .024 .122 r
.60685 .50542 .61136 .51048 .62029 .50783 .6158 .50308 Metetra
0 .024 .123 r
.6158 .50308 .62029 .50783 .62925 .50538 .62477 .50003 Metetra
0 .025 .123 r
.62477 .50003 .62925 .50538 .63824 .50267 .63379 .49759 Metetra
0 .025 .124 r
.63379 .49759 .63824 .50267 .64726 .5 .64282 .49479 Metetra
0 .025 .124 r
.64282 .49479 .64726 .5 .6563 .49733 .65189 .49224 Metetra
0 .025 .124 r
.65189 .49224 .6563 .49733 .66537 .49441 .66098 .48927 Metetra
0 .025 .123 r
.66098 .48927 .66537 .49441 .67448 .49172 .67008 .48613 Metetra
0 .025 .123 r
.67008 .48613 .67448 .49172 .6836 .48863 .67927 .48397 Metetra
0 .024 .123 r
.67927 .48397 .6836 .48863 .69274 .48557 .68841 .48043 Metetra
0 .024 .122 r
.68841 .48043 .69274 .48557 .70193 .48276 .69762 .47755 Metetra
0 .024 .122 r
.69762 .47755 .70193 .48276 .71115 .47994 .70686 .47472 Metetra
0 .024 .122 r
.70686 .47472 .71115 .47994 .7204 .47712 .71613 .47186 Metetra
0 .023 .122 r
.71613 .47186 .7204 .47712 .72968 .47428 .72543 .46902 Metetra
0 .023 .122 r
.72543 .46902 .72968 .47428 .73899 .47142 .73476 .46614 Metetra
0 .023 .121 r
.73476 .46614 .73899 .47142 .74833 .46856 .74412 .46327 Metetra
0 .023 .121 r
.74412 .46327 .74833 .46856 .7577 .4657 .75351 .46039 Metetra
0 .023 .122 r
.75351 .46039 .7577 .4657 .7671 .46283 .76294 .45751 Metetra
0 .023 .122 r
.76294 .45751 .7671 .46283 .77653 .45995 .77239 .4546 Metetra
0 .023 .121 r
.77239 .4546 .77653 .45995 .786 .45705 .78188 .45168 Metetra
0 .023 .121 r
.78188 .45168 .786 .45705 .79549 .45415 .79139 .44876 Metetra
0 .023 .121 r
.79139 .44876 .79549 .45415 .80502 .45124 .80094 .44584 Metetra
0 .023 .121 r
.80094 .44584 .80502 .45124 .81457 .44832 .81052 .4429 Metetra
0 .023 .121 r
.81052 .4429 .81457 .44832 .82416 .4454 .82013 .43996 Metetra
0 .023 .122 r
.82013 .43996 .82416 .4454 .83378 .44246 .82978 .43701 Metetra
0 .023 .122 r
.82978 .43701 .83378 .44246 .84344 .4395 .83945 .43402 Metetra
0 .023 .121 r
.83945 .43402 .84344 .4395 .85312 .43654 .84916 .43106 Metetra
0 .023 .121 r
.84916 .43106 .85312 .43654 .86284 .43357 .8589 .42806 Metetra
0 .023 .122 r
.8589 .42806 .86284 .43357 .87259 .43061 .86867 .42507 Metetra
0 .024 .122 r
.86867 .42507 .87259 .43061 .88237 .42762 .87848 .42206 Metetra
0 .024 .122 r
.87848 .42206 .88237 .42762 .89219 .42463 .88832 .41908 Metetra
0 .024 .122 r
.88832 .41908 .89219 .42463 .90204 .42163 .89819 .41604 Metetra
0 .024 .122 r
.89819 .41604 .90204 .42163 .91192 .41859 .9081 .41299 Metetra
0 .024 .122 r
.9081 .41299 .91192 .41859 .92183 .41555 .91804 .40993 Metetra
0 .023 .122 r
.91804 .40993 .92183 .41555 .93178 .4125 .92801 .40686 Metetra
0 .023 .121 r
.92801 .40686 .93178 .4125 .94176 .40945 .93801 .40379 Metetra
0 .023 .121 r
.93801 .40379 .94176 .40945 .95177 .40638 .94805 .4007 Metetra
0 .023 .121 r
.37066 .57165 .37567 .5763 .38389 .57377 .3789 .56911 Metetra
0 .023 .121 r
.3789 .56911 .38389 .57377 .39213 .57125 .38716 .56657 Metetra
0 .023 .122 r
.38716 .56657 .39213 .57125 .4004 .56872 .39544 .56403 Metetra
0 .024 .122 r
.39544 .56403 .4004 .56872 .4087 .56619 .40376 .56147 Metetra
0 .024 .122 r
.40376 .56147 .4087 .56619 .41702 .56366 .4121 .55889 Metetra
0 .024 .122 r
.4121 .55889 .41702 .56366 .42537 .56108 .42046 .55631 Metetra
0 .024 .122 r
.42046 .55631 .42537 .56108 .43374 .5585 .42885 .55373 Metetra
0 .023 .122 r
.42885 .55373 .43374 .5585 .44214 .55592 .43727 .55113 Metetra
0 .023 .122 r
.43727 .55113 .44214 .55592 .45057 .55333 .44571 .54854 Metetra
0 .023 .122 r
.44571 .54854 .45057 .55333 .45902 .55074 .45418 .54593 Metetra
0 .023 .122 r
.45418 .54593 .45902 .55074 .4675 .54813 .46267 .54331 Metetra
0 .023 .122 r
.46267 .54331 .4675 .54813 .476 .54554 .47119 .54069 Metetra
0 .023 .122 r
.47119 .54069 .476 .54554 .48454 .54292 .47974 .53805 Metetra
0 .023 .122 r
.47974 .53805 .48454 .54292 .49309 .54028 .48832 .53542 Metetra
0 .023 .122 r
.48832 .53542 .49309 .54028 .50168 .53765 .49692 .53277 Metetra
0 .023 .122 r
.49692 .53277 .50168 .53765 .51029 .53501 .50555 .53011 Metetra
0 .023 .122 r
.50555 .53011 .51029 .53501 .51893 .53236 .51421 .52745 Metetra
0 .023 .122 r
.51421 .52745 .51893 .53236 .5276 .52971 .52289 .52477 Metetra
0 .024 .122 r
.52289 .52477 .5276 .52971 .53629 .52705 .5316 .52209 Metetra
0 .024 .122 r
.5316 .52209 .53629 .52705 .54501 .52437 .54034 .5194 Metetra
0 .023 .122 r
.54034 .5194 .54501 .52437 .55376 .52166 .54911 .51669 Metetra
0 .023 .122 r
.54911 .51669 .55376 .52166 .56254 .51899 .55791 .51399 Metetra
0 .024 .122 r
.55791 .51399 .56254 .51899 .57134 .5163 .56673 .51128 Metetra
0 .024 .122 r
.56673 .51128 .57134 .5163 .58018 .51358 .57558 .50856 Metetra
0 .024 .122 r
.57558 .50856 .58018 .51358 .58904 .51087 .58446 .50583 Metetra
0 .024 .122 r
.58446 .50583 .58904 .51087 .59793 .50813 .59337 .50309 Metetra
0 .024 .122 r
.59337 .50309 .59793 .50813 .60685 .50542 .60231 .50047 Metetra
0 .024 .123 r
.60231 .50047 .60685 .50542 .6158 .50308 .61129 .49807 Metetra
0 .025 .123 r
.61129 .49807 .6158 .50308 .62477 .50003 .62028 .49529 Metetra
0 .025 .123 r
.62028 .49529 .62477 .50003 .63379 .49759 .6293 .49236 Metetra
0 .025 .123 r
.6293 .49236 .63379 .49759 .64282 .49479 .63835 .4894 Metetra
0 .025 .123 r
.63835 .4894 .64282 .49479 .65189 .49224 .64744 .48684 Metetra
0 .025 .124 r
.64744 .48684 .65189 .49224 .66098 .48927 .65655 .48395 Metetra
0 .025 .123 r
.65655 .48395 .66098 .48927 .67008 .48613 .6657 .48131 Metetra
0 .025 .124 r
.6657 .48131 .67008 .48613 .67927 .48397 .67488 .47873 Metetra
0 .025 .124 r
.67488 .47873 .67927 .48397 .68841 .48043 .68407 .47557 Metetra
0 .024 .122 r
.68407 .47557 .68841 .48043 .69762 .47755 .69328 .47234 Metetra
0 .024 .122 r
.69328 .47234 .69762 .47755 .70686 .47472 .70254 .46945 Metetra
0 .024 .122 r
.70254 .46945 .70686 .47472 .71613 .47186 .71183 .46661 Metetra
0 .023 .122 r
.71183 .46661 .71613 .47186 .72543 .46902 .72115 .46371 Metetra
0 .023 .121 r
.72115 .46371 .72543 .46902 .73476 .46614 .7305 .46083 Metetra
0 .023 .121 r
.7305 .46083 .73476 .46614 .74412 .46327 .73989 .45795 Metetra
0 .023 .121 r
.73989 .45795 .74412 .46327 .75351 .46039 .7493 .45505 Metetra
0 .023 .122 r
.7493 .45505 .75351 .46039 .76294 .45751 .75875 .45214 Metetra
0 .023 .122 r
.75875 .45214 .76294 .45751 .77239 .4546 .76822 .44922 Metetra
0 .023 .121 r
.76822 .44922 .77239 .4546 .78188 .45168 .77773 .4463 Metetra
0 .023 .121 r
.77773 .4463 .78188 .45168 .79139 .44876 .78727 .44336 Metetra
0 .023 .121 r
.78727 .44336 .79139 .44876 .80094 .44584 .79684 .44041 Metetra
0 .023 .121 r
.79684 .44041 .80094 .44584 .81052 .4429 .80644 .43746 Metetra
0 .023 .121 r
.80644 .43746 .81052 .4429 .82013 .43996 .81608 .43448 Metetra
0 .023 .122 r
.81608 .43448 .82013 .43996 .82978 .43701 .82574 .43151 Metetra
0 .023 .122 r
.82574 .43151 .82978 .43701 .83945 .43402 .83544 .42853 Metetra
0 .023 .122 r
.83544 .42853 .83945 .43402 .84916 .43106 .84517 .42552 Metetra
0 .023 .121 r
.84517 .42552 .84916 .43106 .8589 .42806 .85494 .42252 Metetra
0 .023 .122 r
.85494 .42252 .8589 .42806 .86867 .42507 .86473 .4195 Metetra
0 .023 .122 r
.86473 .4195 .86867 .42507 .87848 .42206 .87457 .4165 Metetra
0 .024 .122 r
.87457 .4165 .87848 .42206 .88832 .41908 .88443 .41344 Metetra
0 .024 .122 r
.88443 .41344 .88832 .41908 .89819 .41604 .89433 .41041 Metetra
0 .024 .122 r
.89433 .41041 .89819 .41604 .9081 .41299 .90426 .40735 Metetra
0 .024 .122 r
.90426 .40735 .9081 .41299 .91804 .40993 .91422 .40426 Metetra
0 .023 .122 r
.91422 .40426 .91804 .40993 .92801 .40686 .92421 .40118 Metetra
0 .023 .121 r
.92421 .40118 .92801 .40686 .93801 .40379 .93424 .39809 Metetra
0 .023 .121 r
.93424 .39809 .93801 .40379 .94805 .4007 .94431 .39499 Metetra
0 .023 .121 r
.36563 .56696 .37066 .57165 .3789 .56911 .37388 .56439 Metetra
0 .023 .121 r
.37388 .56439 .3789 .56911 .38716 .56657 .38216 .56184 Metetra
0 .023 .122 r
.38216 .56184 .38716 .56657 .39544 .56403 .39046 .55928 Metetra
0 .024 .122 r
.39046 .55928 .39544 .56403 .40376 .56147 .39879 .55672 Metetra
0 .024 .122 r
.39879 .55672 .40376 .56147 .4121 .55889 .40714 .55413 Metetra
0 .023 .122 r
.40714 .55413 .4121 .55889 .42046 .55631 .41552 .55154 Metetra
0 .023 .122 r
.41552 .55154 .42046 .55631 .42885 .55373 .42393 .54893 Metetra
0 .023 .121 r
.42393 .54893 .42885 .55373 .43727 .55113 .43236 .54632 Metetra
0 .023 .121 r
.43236 .54632 .43727 .55113 .44571 .54854 .44082 .54371 Metetra
0 .023 .122 r
.44082 .54371 .44571 .54854 .45418 .54593 .44931 .54109 Metetra
0 .023 .121 r
.44931 .54109 .45418 .54593 .46267 .54331 .45782 .53846 Metetra
0 .023 .121 r
.45782 .53846 .46267 .54331 .47119 .54069 .46636 .53581 Metetra
0 .023 .121 r
.46636 .53581 .47119 .54069 .47974 .53805 .47492 .53318 Metetra
0 .023 .122 r
.47492 .53318 .47974 .53805 .48832 .53542 .48352 .53052 Metetra
0 .023 .122 r
.48352 .53052 .48832 .53542 .49692 .53277 .49214 .52785 Metetra
0 .023 .122 r
.49214 .52785 .49692 .53277 .50555 .53011 .50078 .52518 Metetra
0 .023 .122 r
.50078 .52518 .50555 .53011 .51421 .52745 .50946 .5225 Metetra
0 .023 .122 r
.50946 .5225 .51421 .52745 .52289 .52477 .51816 .51981 Metetra
0 .023 .122 r
.51816 .51981 .52289 .52477 .5316 .52209 .52689 .51711 Metetra
0 .023 .122 r
.52689 .51711 .5316 .52209 .54034 .5194 .53565 .5144 Metetra
0 .023 .121 r
.53565 .5144 .54034 .5194 .54911 .51669 .54443 .51168 Metetra
0 .023 .122 r
.54443 .51168 .54911 .51669 .55791 .51399 .55325 .50899 Metetra
0 .023 .122 r
.55325 .50899 .55791 .51399 .56673 .51128 .56209 .50622 Metetra
0 .023 .122 r
.56209 .50622 .56673 .51128 .57558 .50856 .57096 .5035 Metetra
0 .024 .122 r
.57096 .5035 .57558 .50856 .58446 .50583 .57986 .50075 Metetra
0 .024 .122 r
.57986 .50075 .58446 .50583 .59337 .50309 .58879 .49799 Metetra
0 .024 .122 r
.58879 .49799 .59337 .50309 .60231 .50047 .59775 .49551 Metetra
0 .024 .123 r
.59775 .49551 .60231 .50047 .61129 .49807 .60673 .49268 Metetra
0 .025 .123 r
.60673 .49268 .61129 .49807 .62028 .49529 .61574 .48976 Metetra
0 .024 .123 r
.61574 .48976 .62028 .49529 .6293 .49236 .62479 .48711 Metetra
0 .024 .123 r
.62479 .48711 .6293 .49236 .63835 .4894 .63387 .48443 Metetra
0 .025 .123 r
.63387 .48443 .63835 .4894 .64744 .48684 .64298 .48175 Metetra
0 .025 .123 r
.64298 .48175 .64744 .48684 .65655 .48395 .6521 .47869 Metetra
0 .025 .123 r
.6521 .47869 .65655 .48395 .6657 .48131 .66126 .47577 Metetra
0 .025 .123 r
.66126 .47577 .6657 .48131 .67488 .47873 .67045 .47284 Metetra
0 .025 .124 r
.67045 .47284 .67488 .47873 .68407 .47557 .67969 .47057 Metetra
0 .024 .123 r
.67969 .47057 .68407 .47557 .69328 .47234 .68892 .46706 Metetra
0 .024 .122 r
.68892 .46706 .69328 .47234 .70254 .46945 .6982 .46416 Metetra
0 .024 .122 r
.6982 .46416 .70254 .46945 .71183 .46661 .70751 .4613 Metetra
0 .023 .122 r
.70751 .4613 .71183 .46661 .72115 .46371 .71685 .45839 Metetra
0 .023 .121 r
.71685 .45839 .72115 .46371 .7305 .46083 .72622 .4555 Metetra
0 .023 .121 r
.72622 .4555 .7305 .46083 .73989 .45795 .73563 .45259 Metetra
0 .023 .121 r
.73563 .45259 .73989 .45795 .7493 .45505 .74506 .44966 Metetra
0 .023 .122 r
.74506 .44966 .7493 .45505 .75875 .45214 .75453 .44675 Metetra
0 .023 .122 r
.75453 .44675 .75875 .45214 .76822 .44922 .76403 .44383 Metetra
0 .023 .122 r
.76403 .44383 .76822 .44922 .77773 .4463 .77356 .44088 Metetra
0 .023 .122 r
.77356 .44088 .77773 .4463 .78727 .44336 .78312 .43792 Metetra
0 .023 .122 r
.78312 .43792 .78727 .44336 .79684 .44041 .79271 .43495 Metetra
0 .023 .122 r
.79271 .43495 .79684 .44041 .80644 .43746 .80234 .43198 Metetra
0 .023 .122 r
.80234 .43198 .80644 .43746 .81608 .43448 .812 .429 Metetra
0 .023 .122 r
.812 .429 .81608 .43448 .82574 .43151 .82168 .42599 Metetra
0 .023 .121 r
.82168 .42599 .82574 .43151 .83544 .42853 .83141 .42298 Metetra
0 .023 .121 r
.83141 .42298 .83544 .42853 .84517 .42552 .84116 .41996 Metetra
0 .023 .121 r
.84116 .41996 .84517 .42552 .85494 .42252 .85095 .41695 Metetra
0 .023 .122 r
.85095 .41695 .85494 .42252 .86473 .4195 .86077 .4139 Metetra
0 .023 .122 r
.86077 .4139 .86473 .4195 .87457 .4165 .87062 .41086 Metetra
0 .023 .122 r
.87062 .41086 .87457 .4165 .88443 .41344 .88051 .40781 Metetra
0 .024 .122 r
.88051 .40781 .88443 .41344 .89433 .41041 .89043 .40476 Metetra
0 .024 .122 r
.89043 .40476 .89433 .41041 .90426 .40735 .90039 .40168 Metetra
0 .023 .122 r
.90039 .40168 .90426 .40735 .91422 .40426 .91037 .39858 Metetra
0 .023 .121 r
.91037 .39858 .91422 .40426 .92421 .40118 .9204 .39547 Metetra
0 .023 .121 r
.9204 .39547 .92421 .40118 .93424 .39809 .93045 .39236 Metetra
0 .023 .121 r
.93045 .39236 .93424 .39809 .94431 .39499 .94054 .38924 Metetra
0 .023 .121 r
.36056 .56223 .36563 .56696 .37388 .56439 .36883 .55966 Metetra
0 .023 .121 r
.36883 .55966 .37388 .56439 .38216 .56184 .37712 .5571 Metetra
0 .023 .121 r
.37712 .5571 .38216 .56184 .39046 .55928 .38544 .55453 Metetra
0 .024 .122 r
.38544 .55453 .39046 .55928 .39879 .55672 .39379 .55196 Metetra
0 .024 .122 r
.39379 .55196 .39879 .55672 .40714 .55413 .40216 .54934 Metetra
0 .023 .122 r
.40216 .54934 .40714 .55413 .41552 .55154 .41055 .54673 Metetra
0 .023 .122 r
.41055 .54673 .41552 .55154 .42393 .54893 .41898 .54412 Metetra
0 .023 .122 r
.41898 .54412 .42393 .54893 .43236 .54632 .42743 .54151 Metetra
0 .023 .122 r
.42743 .54151 .43236 .54632 .44082 .54371 .4359 .53887 Metetra
0 .023 .122 r
.4359 .53887 .44082 .54371 .44931 .54109 .4444 .53623 Metetra
0 .023 .121 r
.4444 .53623 .44931 .54109 .45782 .53846 .45293 .53357 Metetra
0 .023 .121 r
.45293 .53357 .45782 .53846 .46636 .53581 .46149 .53092 Metetra
0 .023 .121 r
.46149 .53092 .46636 .53581 .47492 .53318 .47007 .52827 Metetra
0 .023 .122 r
.47007 .52827 .47492 .53318 .48352 .53052 .47868 .52558 Metetra
0 .023 .121 r
.47868 .52558 .48352 .53052 .49214 .52785 .48732 .5229 Metetra
0 .023 .121 r
.48732 .5229 .49214 .52785 .50078 .52518 .49599 .52021 Metetra
0 .023 .121 r
.49599 .52021 .50078 .52518 .50946 .5225 .50468 .51752 Metetra
0 .023 .121 r
.50468 .51752 .50946 .5225 .51816 .51981 .5134 .51482 Metetra
0 .023 .122 r
.5134 .51482 .51816 .51981 .52689 .51711 .52215 .51211 Metetra
0 .023 .122 r
.52215 .51211 .52689 .51711 .53565 .5144 .53092 .50938 Metetra
0 .023 .121 r
.53092 .50938 .53565 .5144 .54443 .51168 .53973 .50664 Metetra
0 .023 .122 r
.53973 .50664 .54443 .51168 .55325 .50899 .54856 .50392 Metetra
0 .023 .122 r
.54856 .50392 .55325 .50899 .56209 .50622 .55742 .50115 Metetra
0 .023 .122 r
.55742 .50115 .56209 .50622 .57096 .5035 .56631 .49842 Metetra
0 .024 .122 r
.56631 .49842 .57096 .5035 .57986 .50075 .57523 .49565 Metetra
0 .024 .122 r
.57523 .49565 .57986 .50075 .58879 .49799 .58417 .49293 Metetra
0 .024 .123 r
.58417 .49293 .58879 .49799 .59775 .49551 .59316 .49077 Metetra
0 .025 .123 r
.59316 .49077 .59775 .49551 .60673 .49268 .60216 .48751 Metetra
0 .024 .123 r
.60216 .48751 .60673 .49268 .61574 .48976 .6112 .4849 Metetra
0 .024 .123 r
.6112 .4849 .61574 .48976 .62479 .48711 .62026 .48212 Metetra
0 .025 .123 r
.62026 .48212 .62479 .48711 .63387 .48443 .62936 .47934 Metetra
0 .025 .124 r
.62936 .47934 .63387 .48443 .64298 .48175 .63848 .47657 Metetra
0 .025 .123 r
.63848 .47657 .64298 .48175 .6521 .47869 .64763 .47361 Metetra
0 .025 .123 r
.64763 .47361 .6521 .47869 .66126 .47577 .65681 .47075 Metetra
0 .024 .123 r
.65681 .47075 .66126 .47577 .67045 .47284 .66602 .46774 Metetra
0 .025 .123 r
.66602 .46774 .67045 .47284 .67969 .47057 .67526 .46491 Metetra
0 .024 .123 r
.67526 .46491 .67969 .47057 .68892 .46706 .68453 .46185 Metetra
0 .024 .122 r
.68453 .46185 .68892 .46706 .6982 .46416 .69383 .45886 Metetra
0 .024 .122 r
.69383 .45886 .6982 .46416 .70751 .4613 .70316 .45594 Metetra
0 .023 .122 r
.70316 .45594 .70751 .4613 .71685 .45839 .71252 .45304 Metetra
0 .023 .122 r
.71252 .45304 .71685 .45839 .72622 .4555 .72192 .45014 Metetra
0 .023 .122 r
.72192 .45014 .72622 .4555 .73563 .45259 .73134 .44719 Metetra
0 .023 .121 r
.73134 .44719 .73563 .45259 .74506 .44966 .7408 .44425 Metetra
0 .023 .121 r
.7408 .44425 .74506 .44966 .75453 .44675 .75029 .44132 Metetra
0 .023 .122 r
.75029 .44132 .75453 .44675 .76403 .44383 .75981 .43836 Metetra
0 .023 .122 r
.75981 .43836 .76403 .44383 .77356 .44088 .76936 .43539 Metetra
0 .023 .121 r
.76936 .43539 .77356 .44088 .78312 .43792 .77894 .43242 Metetra
0 .023 .121 r
.77894 .43242 .78312 .43792 .79271 .43495 .78856 .42943 Metetra
0 .023 .121 r
.78856 .42943 .79271 .43495 .80234 .43198 .79821 .42644 Metetra
0 .023 .122 r
.79821 .42644 .80234 .43198 .812 .429 .80789 .42344 Metetra
0 .023 .122 r
.80789 .42344 .812 .429 .82168 .42599 .8176 .42044 Metetra
0 .023 .121 r
.8176 .42044 .82168 .42599 .83141 .42298 .82735 .4174 Metetra
0 .023 .121 r
.82735 .4174 .83141 .42298 .84116 .41996 .83713 .41438 Metetra
0 .023 .122 r
.83713 .41438 .84116 .41996 .85095 .41695 .84694 .41134 Metetra
0 .023 .122 r
.84694 .41134 .85095 .41695 .86077 .4139 .85678 .40828 Metetra
0 .023 .121 r
.85678 .40828 .86077 .4139 .87062 .41086 .86666 .40521 Metetra
0 .023 .122 r
.86666 .40521 .87062 .41086 .88051 .40781 .87657 .40213 Metetra
0 .023 .122 r
.87657 .40213 .88051 .40781 .89043 .40476 .88652 .39905 Metetra
0 .024 .122 r
.88652 .39905 .89043 .40476 .90039 .40168 .8965 .39597 Metetra
0 .023 .122 r
.8965 .39597 .90039 .40168 .91037 .39858 .90651 .39285 Metetra
0 .023 .121 r
.90651 .39285 .91037 .39858 .9204 .39547 .91655 .38973 Metetra
0 .023 .121 r
.91655 .38973 .9204 .39547 .93045 .39236 .92664 .3866 Metetra
0 .023 .121 r
.92664 .3866 .93045 .39236 .94054 .38924 .93675 .38346 Metetra
0 .023 .121 r
.35547 .5575 .36056 .56223 .36883 .55966 .36375 .55491 Metetra
0 .023 .121 r
.36375 .55491 .36883 .55966 .37712 .5571 .37206 .55233 Metetra
0 .023 .122 r
.37206 .55233 .37712 .5571 .38544 .55453 .3804 .54975 Metetra
0 .024 .122 r
.3804 .54975 .38544 .55453 .39379 .55196 .38876 .54713 Metetra
0 .023 .122 r
.38876 .54713 .39379 .55196 .40216 .54934 .39714 .54453 Metetra
0 .023 .122 r
.39714 .54453 .40216 .54934 .41055 .54673 .40556 .5419 Metetra
0 .023 .122 r
.40556 .5419 .41055 .54673 .41898 .54412 .414 .53927 Metetra
0 .023 .122 r
.414 .53927 .41898 .54412 .42743 .54151 .42246 .53663 Metetra
0 .023 .122 r
.42246 .53663 .42743 .54151 .4359 .53887 .43096 .53398 Metetra
0 .023 .121 r
.43096 .53398 .4359 .53887 .4444 .53623 .43948 .53133 Metetra
0 .023 .121 r
.43948 .53133 .4444 .53623 .45293 .53357 .44802 .52868 Metetra
0 .023 .121 r
.44802 .52868 .45293 .53357 .46149 .53092 .4566 .52599 Metetra
0 .023 .121 r
.4566 .52599 .46149 .53092 .47007 .52827 .4652 .52332 Metetra
0 .023 .121 r
.4652 .52332 .47007 .52827 .47868 .52558 .47382 .52062 Metetra
0 .023 .121 r
.47382 .52062 .47868 .52558 .48732 .5229 .48248 .51793 Metetra
0 .023 .121 r
.48248 .51793 .48732 .5229 .49599 .52021 .49116 .51523 Metetra
0 .023 .121 r
.49116 .51523 .49599 .52021 .50468 .51752 .49987 .51251 Metetra
0 .023 .121 r
.49987 .51251 .50468 .51752 .5134 .51482 .50861 .50979 Metetra
0 .023 .121 r
.50861 .50979 .5134 .51482 .52215 .51211 .51738 .50707 Metetra
0 .023 .122 r
.51738 .50707 .52215 .51211 .53092 .50938 .52617 .50433 Metetra
0 .023 .121 r
.52617 .50433 .53092 .50938 .53973 .50664 .53499 .50158 Metetra
0 .023 .122 r
.53499 .50158 .53973 .50664 .54856 .50392 .54384 .49884 Metetra
0 .023 .122 r
.54384 .49884 .54856 .50392 .55742 .50115 .55272 .49607 Metetra
0 .023 .122 r
.55272 .49607 .55742 .50115 .56631 .49842 .56163 .49331 Metetra
0 .024 .122 r
.56163 .49331 .56631 .49842 .57523 .49565 .57057 .49052 Metetra
0 .024 .122 r
.57057 .49052 .57523 .49565 .58417 .49293 .57954 .48814 Metetra
0 .025 .123 r
.57954 .48814 .58417 .49293 .59316 .49077 .58854 .48547 Metetra
0 .025 .124 r
.58854 .48547 .59316 .49077 .60216 .48751 .59757 .48267 Metetra
0 .025 .123 r
.59757 .48267 .60216 .48751 .6112 .4849 .60662 .47981 Metetra
0 .025 .124 r
.60662 .47981 .6112 .4849 .62026 .48212 .6157 .47693 Metetra
0 .025 .124 r
.6157 .47693 .62026 .48212 .62936 .47934 .62482 .47411 Metetra
0 .025 .124 r
.62482 .47411 .62936 .47934 .63848 .47657 .63396 .47132 Metetra
0 .025 .124 r
.63396 .47132 .63848 .47657 .64763 .47361 .64313 .46838 Metetra
0 .025 .124 r
.64313 .46838 .64763 .47361 .65681 .47075 .65234 .46558 Metetra
0 .025 .123 r
.65234 .46558 .65681 .47075 .66602 .46774 .66157 .46276 Metetra
0 .025 .123 r
.66157 .46276 .66602 .46774 .67526 .46491 .67084 .45987 Metetra
0 .025 .123 r
.67084 .45987 .67526 .46491 .68453 .46185 .68013 .45705 Metetra
0 .024 .122 r
.68013 .45705 .68453 .46185 .69383 .45886 .68943 .45352 Metetra
0 .024 .122 r
.68943 .45352 .69383 .45886 .70316 .45594 .69878 .45056 Metetra
0 .023 .121 r
.69878 .45056 .70316 .45594 .71252 .45304 .70817 .44765 Metetra
0 .024 .122 r
.70817 .44765 .71252 .45304 .72192 .45014 .71758 .44474 Metetra
0 .024 .122 r
.71758 .44474 .72192 .45014 .73134 .44719 .72703 .44177 Metetra
0 .023 .122 r
.72703 .44177 .73134 .44719 .7408 .44425 .73651 .43884 Metetra
0 .023 .122 r
.73651 .43884 .7408 .44425 .75029 .44132 .74602 .43585 Metetra
0 .023 .121 r
.74602 .43585 .75029 .44132 .75981 .43836 .75556 .43287 Metetra
0 .023 .121 r
.75556 .43287 .75981 .43836 .76936 .43539 .76514 .4299 Metetra
0 .023 .121 r
.76514 .4299 .76936 .43539 .77894 .43242 .77474 .42691 Metetra
0 .023 .121 r
.77474 .42691 .77894 .43242 .78856 .42943 .78438 .42391 Metetra
0 .023 .121 r
.78438 .42391 .78856 .42943 .79821 .42644 .79405 .42089 Metetra
0 .023 .121 r
.79405 .42089 .79821 .42644 .80789 .42344 .80376 .41787 Metetra
0 .023 .121 r
.80376 .41787 .80789 .42344 .8176 .42044 .81349 .41484 Metetra
0 .023 .122 r
.81349 .41484 .8176 .42044 .82735 .4174 .82326 .41181 Metetra
0 .023 .122 r
.82326 .41181 .82735 .4174 .83713 .41438 .83306 .40875 Metetra
0 .023 .122 r
.83306 .40875 .83713 .41438 .84694 .41134 .8429 .40569 Metetra
0 .023 .122 r
.8429 .40569 .84694 .41134 .85678 .40828 .85277 .4026 Metetra
0 .023 .121 r
.85277 .4026 .85678 .40828 .86666 .40521 .86267 .39952 Metetra
0 .023 .121 r
.86267 .39952 .86666 .40521 .87657 .40213 .87261 .39644 Metetra
0 .023 .121 r
.87261 .39644 .87657 .40213 .88652 .39905 .88257 .39332 Metetra
0 .023 .122 r
.88257 .39332 .88652 .39905 .8965 .39597 .89258 .39024 Metetra
0 .024 .122 r
.89258 .39024 .8965 .39597 .90651 .39285 .90262 .38709 Metetra
0 .023 .122 r
.90262 .38709 .90651 .39285 .91655 .38973 .91269 .38394 Metetra
0 .023 .121 r
.91269 .38394 .91655 .38973 .92664 .3866 .92279 .38079 Metetra
0 .023 .121 r
.92279 .38079 .92664 .3866 .93675 .38346 .93294 .37763 Metetra
0 .023 .121 r
.35035 .55274 .35547 .5575 .36375 .55491 .35865 .55014 Metetra
0 .023 .121 r
.35865 .55014 .36375 .55491 .37206 .55233 .36697 .54754 Metetra
0 .023 .122 r
.36697 .54754 .37206 .55233 .3804 .54975 .37532 .54493 Metetra
0 .023 .122 r
.37532 .54493 .3804 .54975 .38876 .54713 .3837 .54231 Metetra
0 .023 .122 r
.3837 .54231 .38876 .54713 .39714 .54453 .3921 .53967 Metetra
0 .023 .122 r
.3921 .53967 .39714 .54453 .40556 .5419 .40053 .53704 Metetra
0 .023 .122 r
.40053 .53704 .40556 .5419 .414 .53927 .40899 .5344 Metetra
0 .023 .121 r
.40899 .5344 .414 .53927 .42246 .53663 .41747 .53174 Metetra
0 .023 .121 r
.41747 .53174 .42246 .53663 .43096 .53398 .42598 .52908 Metetra
0 .023 .122 r
.42598 .52908 .43096 .53398 .43948 .53133 .43452 .52642 Metetra
0 .023 .122 r
.43452 .52642 .43948 .53133 .44802 .52868 .44308 .52373 Metetra
0 .023 .121 r
.44308 .52373 .44802 .52868 .4566 .52599 .45167 .52104 Metetra
0 .023 .121 r
.45167 .52104 .4566 .52599 .4652 .52332 .46029 .51836 Metetra
0 .023 .121 r
.46029 .51836 .4652 .52332 .47382 .52062 .46894 .51565 Metetra
0 .023 .121 r
.46894 .51565 .47382 .52062 .48248 .51793 .47761 .51293 Metetra
0 .023 .121 r
.47761 .51293 .48248 .51793 .49116 .51523 .48631 .51021 Metetra
0 .023 .121 r
.48631 .51021 .49116 .51523 .49987 .51251 .49504 .50748 Metetra
0 .023 .121 r
.49504 .50748 .49987 .51251 .50861 .50979 .50379 .50475 Metetra
0 .023 .122 r
.50379 .50475 .50861 .50979 .51738 .50707 .51258 .50202 Metetra
0 .023 .122 r
.51258 .50202 .51738 .50707 .52617 .50433 .52139 .49925 Metetra
0 .023 .121 r
.52139 .49925 .52617 .50433 .53499 .50158 .53023 .4965 Metetra
0 .023 .122 r
.53023 .4965 .53499 .50158 .54384 .49884 .5391 .49372 Metetra
0 .024 .122 r
.5391 .49372 .54384 .49884 .55272 .49607 .548 .49097 Metetra
0 .024 .122 r
.548 .49097 .55272 .49607 .56163 .49331 .55693 .48816 Metetra
0 .024 .122 r
.55693 .48816 .56163 .49331 .57057 .49052 .56588 .48542 Metetra
0 .024 .123 r
.56588 .48542 .57057 .49052 .57954 .48814 .57487 .48297 Metetra
0 .025 .124 r
.57487 .48297 .57954 .48814 .58854 .48547 .58389 .48034 Metetra
0 .025 .124 r
.58389 .48034 .58854 .48547 .59757 .48267 .59294 .47741 Metetra
0 .025 .124 r
.59294 .47741 .59757 .48267 .60662 .47981 .60201 .47449 Metetra
0 .025 .123 r
.60201 .47449 .60662 .47981 .6157 .47693 .61111 .47159 Metetra
0 .025 .123 r
.61111 .47159 .6157 .47693 .62482 .47411 .62024 .46874 Metetra
0 .025 .124 r
.62024 .46874 .62482 .47411 .63396 .47132 .62941 .46593 Metetra
0 .025 .123 r
.62941 .46593 .63396 .47132 .64313 .46838 .6386 .46296 Metetra
0 .025 .123 r
.6386 .46296 .64313 .46838 .65234 .46558 .64782 .46012 Metetra
0 .025 .124 r
.64782 .46012 .65234 .46558 .66157 .46276 .65708 .45728 Metetra
0 .025 .124 r
.65708 .45728 .66157 .46276 .67084 .45987 .66636 .45439 Metetra
0 .025 .124 r
.66636 .45439 .67084 .45987 .68013 .45705 .67567 .45125 Metetra
0 .024 .123 r
.67567 .45125 .68013 .45705 .68943 .45352 .68501 .44821 Metetra
0 .024 .122 r
.68501 .44821 .68943 .45352 .69878 .45056 .69438 .44517 Metetra
0 .023 .121 r
.69438 .44517 .69878 .45056 .70817 .44765 .70379 .44222 Metetra
0 .023 .122 r
.70379 .44222 .70817 .44765 .71758 .44474 .71322 .43928 Metetra
0 .023 .122 r
.71322 .43928 .71758 .44474 .72703 .44177 .72269 .43632 Metetra
0 .023 .122 r
.72269 .43632 .72703 .44177 .73651 .43884 .73219 .43335 Metetra
0 .023 .122 r
.73219 .43335 .73651 .43884 .74602 .43585 .74173 .43035 Metetra
0 .023 .121 r
.74173 .43035 .74602 .43585 .75556 .43287 .75129 .42736 Metetra
0 .023 .121 r
.75129 .42736 .75556 .43287 .76514 .4299 .76089 .42436 Metetra
0 .023 .121 r
.76089 .42436 .76514 .4299 .77474 .42691 .77052 .42136 Metetra
0 .023 .122 r
.77052 .42136 .77474 .42691 .78438 .42391 .78018 .41834 Metetra
0 .023 .121 r
.78018 .41834 .78438 .42391 .79405 .42089 .78987 .4153 Metetra
0 .023 .121 r
.78987 .4153 .79405 .42089 .80376 .41787 .7996 .41226 Metetra
0 .023 .121 r
.7996 .41226 .80376 .41787 .81349 .41484 .80936 .40921 Metetra
0 .023 .121 r
.80936 .40921 .81349 .41484 .82326 .41181 .81915 .40615 Metetra
0 .023 .122 r
.81915 .40615 .82326 .41181 .83306 .40875 .82898 .40309 Metetra
0 .023 .122 r
.82898 .40309 .83306 .40875 .8429 .40569 .83883 .39999 Metetra
0 .023 .121 r
.83883 .39999 .8429 .40569 .85277 .4026 .84873 .3969 Metetra
0 .023 .121 r
.84873 .3969 .85277 .4026 .86267 .39952 .85865 .39381 Metetra
0 .023 .122 r
.85865 .39381 .86267 .39952 .87261 .39644 .86861 .39068 Metetra
0 .023 .121 r
.86861 .39068 .87261 .39644 .88257 .39332 .87861 .38756 Metetra
0 .023 .122 r
.87861 .38756 .88257 .39332 .89258 .39024 .88864 .38443 Metetra
0 .024 .122 r
.88864 .38443 .89258 .39024 .90262 .38709 .8987 .3813 Metetra
0 .023 .122 r
.8987 .3813 .90262 .38709 .91269 .38394 .9088 .37812 Metetra
0 .023 .121 r
.9088 .37812 .91269 .38394 .92279 .38079 .91893 .37495 Metetra
0 .023 .121 r
.91893 .37495 .92279 .38079 .93294 .37763 .9291 .37177 Metetra
0 .023 .121 r
.3452 .54793 .35035 .55274 .35865 .55014 .35351 .54532 Metetra
0 .023 .121 r
.35351 .54532 .35865 .55014 .36697 .54754 .36185 .5427 Metetra
0 .023 .122 r
.36185 .5427 .36697 .54754 .37532 .54493 .37022 .54009 Metetra
0 .023 .122 r
.37022 .54009 .37532 .54493 .3837 .54231 .37861 .53745 Metetra
0 .023 .122 r
.37861 .53745 .3837 .54231 .3921 .53967 .38703 .5348 Metetra
0 .023 .121 r
.38703 .5348 .3921 .53967 .40053 .53704 .39548 .53215 Metetra
0 .023 .122 r
.39548 .53215 .40053 .53704 .40899 .5344 .40395 .52949 Metetra
0 .023 .121 r
.40395 .52949 .40899 .5344 .41747 .53174 .41245 .52682 Metetra
0 .023 .122 r
.41245 .52682 .41747 .53174 .42598 .52908 .42098 .52415 Metetra
0 .023 .122 r
.42098 .52415 .42598 .52908 .43452 .52642 .42953 .52146 Metetra
0 .023 .121 r
.42953 .52146 .43452 .52642 .44308 .52373 .43811 .51877 Metetra
0 .023 .121 r
.43811 .51877 .44308 .52373 .45167 .52104 .44672 .51607 Metetra
0 .023 .121 r
.44672 .51607 .45167 .52104 .46029 .51836 .45536 .51336 Metetra
0 .023 .121 r
.45536 .51336 .46029 .51836 .46894 .51565 .46402 .51063 Metetra
0 .023 .121 r
.46402 .51063 .46894 .51565 .47761 .51293 .47271 .50791 Metetra
0 .023 .121 r
.47271 .50791 .47761 .51293 .48631 .51021 .48143 .50517 Metetra
0 .023 .121 r
.48143 .50517 .48631 .51021 .49504 .50748 .49017 .50243 Metetra
0 .023 .121 r
.49017 .50243 .49504 .50748 .50379 .50475 .49895 .49968 Metetra
0 .023 .122 r
.49895 .49968 .50379 .50475 .51258 .50202 .50775 .49693 Metetra
0 .024 .122 r
.50775 .49693 .51258 .50202 .52139 .49925 .51658 .49416 Metetra
0 .023 .122 r
.51658 .49416 .52139 .49925 .53023 .4965 .52544 .49136 Metetra
0 .023 .122 r
.52544 .49136 .53023 .4965 .5391 .49372 .53433 .48859 Metetra
0 .024 .122 r
.53433 .48859 .5391 .49372 .548 .49097 .54325 .48579 Metetra
0 .024 .122 r
.54325 .48579 .548 .49097 .55693 .48816 .55219 .48298 Metetra
0 .024 .122 r
.55219 .48298 .55693 .48816 .56588 .48542 .56117 .48026 Metetra
0 .024 .123 r
.56117 .48026 .56588 .48542 .57487 .48297 .57018 .47774 Metetra
0 .025 .124 r
.57018 .47774 .57487 .48297 .58389 .48034 .57921 .47493 Metetra
0 .025 .124 r
.57921 .47493 .58389 .48034 .59294 .47741 .58828 .47204 Metetra
0 .025 .123 r
.58828 .47204 .59294 .47741 .60201 .47449 .59737 .46916 Metetra
0 .025 .123 r
.59737 .46916 .60201 .47449 .61111 .47159 .60649 .46626 Metetra
0 .025 .123 r
.60649 .46626 .61111 .47159 .62024 .46874 .61564 .46339 Metetra
0 .025 .123 r
.61564 .46339 .62024 .46874 .62941 .46593 .62483 .46058 Metetra
0 .025 .123 r
.62483 .46058 .62941 .46593 .6386 .46296 .63404 .4576 Metetra
0 .025 .123 r
.63404 .4576 .6386 .46296 .64782 .46012 .64329 .45473 Metetra
0 .025 .123 r
.64329 .45473 .64782 .46012 .65708 .45728 .65256 .45187 Metetra
0 .025 .123 r
.65256 .45187 .65708 .45728 .66636 .45439 .66187 .44908 Metetra
0 .025 .124 r
.66187 .44908 .66636 .45439 .67567 .45125 .67123 .44651 Metetra
0 .025 .123 r
.67123 .44651 .67567 .45125 .68501 .44821 .68056 .44293 Metetra
0 .024 .122 r
.68056 .44293 .68501 .44821 .69438 .44517 .68995 .43973 Metetra
0 .023 .122 r
.68995 .43973 .69438 .44517 .70379 .44222 .69938 .43677 Metetra
0 .023 .122 r
.69938 .43677 .70379 .44222 .71322 .43928 .70884 .4338 Metetra
0 .023 .121 r
.70884 .4338 .71322 .43928 .72269 .43632 .71833 .43081 Metetra
0 .023 .121 r
.71833 .43081 .72269 .43632 .73219 .43335 .72785 .42782 Metetra
0 .023 .121 r
.72785 .42782 .73219 .43335 .74173 .43035 .73741 .42484 Metetra
0 .023 .121 r
.73741 .42484 .74173 .43035 .75129 .42736 .74699 .42181 Metetra
0 .023 .121 r
.74699 .42181 .75129 .42736 .76089 .42436 .75661 .4188 Metetra
0 .023 .121 r
.75661 .4188 .76089 .42436 .77052 .42136 .76626 .41577 Metetra
0 .023 .121 r
.76626 .41577 .77052 .42136 .78018 .41834 .77595 .41273 Metetra
0 .023 .121 r
.77595 .41273 .78018 .41834 .78987 .4153 .78566 .40968 Metetra
0 .023 .121 r
.78566 .40968 .78987 .4153 .7996 .41226 .79541 .40662 Metetra
0 .023 .121 r
.79541 .40662 .7996 .41226 .80936 .40921 .8052 .40356 Metetra
0 .023 .121 r
.8052 .40356 .80936 .40921 .81915 .40615 .81501 .40047 Metetra
0 .023 .121 r
.81501 .40047 .81915 .40615 .82898 .40309 .82486 .39738 Metetra
0 .023 .121 r
.82486 .39738 .82898 .40309 .83883 .39999 .83475 .39428 Metetra
0 .023 .121 r
.83475 .39428 .83883 .39999 .84873 .3969 .84466 .39117 Metetra
0 .023 .121 r
.84466 .39117 .84873 .3969 .85865 .39381 .85461 .38805 Metetra
0 .023 .122 r
.85461 .38805 .85865 .39381 .86861 .39068 .8646 .38492 Metetra
0 .023 .122 r
.8646 .38492 .86861 .39068 .87861 .38756 .87462 .38177 Metetra
0 .023 .122 r
.87462 .38177 .87861 .38756 .88864 .38443 .88467 .37863 Metetra
0 .023 .122 r
.88467 .37863 .88864 .38443 .8987 .3813 .89476 .37545 Metetra
0 .023 .122 r
.89476 .37545 .8987 .3813 .9088 .37812 .90488 .37228 Metetra
0 .023 .121 r
.90488 .37228 .9088 .37812 .91893 .37495 .91504 .36908 Metetra
0 .023 .121 r
.91504 .36908 .91893 .37495 .9291 .37177 .92523 .36588 Metetra
0 .023 .122 r
.34001 .54312 .3452 .54793 .35351 .54532 .34835 .54049 Metetra
0 .023 .121 r
.34835 .54049 .35351 .54532 .36185 .5427 .3567 .53786 Metetra
0 .023 .122 r
.3567 .53786 .36185 .5427 .37022 .54009 .36509 .53521 Metetra
0 .023 .122 r
.36509 .53521 .37022 .54009 .37861 .53745 .3735 .53257 Metetra
0 .023 .122 r
.3735 .53257 .37861 .53745 .38703 .5348 .38193 .5299 Metetra
0 .023 .122 r
.38193 .5299 .38703 .5348 .39548 .53215 .39039 .52724 Metetra
0 .023 .121 r
.39039 .52724 .39548 .53215 .40395 .52949 .39888 .52455 Metetra
0 .023 .121 r
.39888 .52455 .40395 .52949 .41245 .52682 .4074 .52188 Metetra
0 .023 .121 r
.4074 .52188 .41245 .52682 .42098 .52415 .41594 .51918 Metetra
0 .023 .121 r
.41594 .51918 .42098 .52415 .42953 .52146 .42451 .51648 Metetra
0 .023 .121 r
.42451 .51648 .42953 .52146 .43811 .51877 .43311 .51377 Metetra
0 .023 .121 r
.43311 .51377 .43811 .51877 .44672 .51607 .44174 .51105 Metetra
0 .023 .122 r
.44174 .51105 .44672 .51607 .45536 .51336 .45039 .50834 Metetra
0 .023 .122 r
.45039 .50834 .45536 .51336 .46402 .51063 .45907 .5056 Metetra
0 .023 .121 r
.45907 .5056 .46402 .51063 .47271 .50791 .46778 .50285 Metetra
0 .023 .121 r
.46778 .50285 .47271 .50791 .48143 .50517 .47652 .5001 Metetra
0 .023 .121 r
.47652 .5001 .48143 .50517 .49017 .50243 .48528 .49734 Metetra
0 .023 .122 r
.48528 .49734 .49017 .50243 .49895 .49968 .49407 .49458 Metetra
0 .024 .122 r
.49407 .49458 .49895 .49968 .50775 .49693 .50289 .4918 Metetra
0 .024 .122 r
.50289 .4918 .50775 .49693 .51658 .49416 .51174 .48899 Metetra
0 .023 .122 r
.51174 .48899 .51658 .49416 .52544 .49136 .52062 .48622 Metetra
0 .023 .122 r
.52062 .48622 .52544 .49136 .53433 .48859 .52953 .4834 Metetra
0 .024 .122 r
.52953 .4834 .53433 .48859 .54325 .48579 .53847 .48059 Metetra
0 .024 .122 r
.53847 .48059 .54325 .48579 .55219 .48298 .54743 .47777 Metetra
0 .024 .122 r
.54743 .47777 .55219 .48298 .56117 .48026 .55643 .4751 Metetra
0 .025 .123 r
.55643 .4751 .56117 .48026 .57018 .47774 .56546 .47308 Metetra
0 .025 .124 r
.56546 .47308 .57018 .47774 .57921 .47493 .57451 .46972 Metetra
0 .025 .123 r
.57451 .46972 .57921 .47493 .58828 .47204 .58359 .46677 Metetra
0 .025 .123 r
.58359 .46677 .58828 .47204 .59737 .46916 .5927 .46386 Metetra
0 .025 .123 r
.5927 .46386 .59737 .46916 .60649 .46626 .60185 .46094 Metetra
0 .025 .123 r
.60185 .46094 .60649 .46626 .61564 .46339 .61102 .45806 Metetra
0 .025 .123 r
.61102 .45806 .61564 .46339 .62483 .46058 .62023 .45523 Metetra
0 .025 .123 r
.62023 .45523 .62483 .46058 .63404 .4576 .62946 .45224 Metetra
0 .025 .123 r
.62946 .45224 .63404 .4576 .64329 .45473 .63872 .44935 Metetra
0 .025 .123 r
.63872 .44935 .64329 .45473 .65256 .45187 .64802 .44647 Metetra
0 .025 .124 r
.64802 .44647 .65256 .45187 .66187 .44908 .65735 .44369 Metetra
0 .026 .125 r
.65735 .44369 .66187 .44908 .67123 .44651 .66673 .44115 Metetra
0 .025 .124 r
.66673 .44115 .67123 .44651 .68056 .44293 .67609 .4375 Metetra
0 .024 .122 r
.67609 .4375 .68056 .44293 .68995 .43973 .6855 .43434 Metetra
0 .024 .122 r
.6855 .43434 .68995 .43973 .69938 .43677 .69494 .43133 Metetra
0 .024 .122 r
.69494 .43133 .69938 .43677 .70884 .4338 .70442 .42831 Metetra
0 .023 .121 r
.70442 .42831 .70884 .4338 .71833 .43081 .71394 .42528 Metetra
0 .023 .121 r
.71394 .42528 .71833 .43081 .72785 .42782 .72348 .42229 Metetra
0 .023 .121 r
.72348 .42229 .72785 .42782 .73741 .42484 .73306 .41926 Metetra
0 .023 .121 r
.73306 .41926 .73741 .42484 .74699 .42181 .74267 .41624 Metetra
0 .023 .121 r
.74267 .41624 .74699 .42181 .75661 .4188 .75231 .41319 Metetra
0 .023 .121 r
.75231 .41319 .75661 .4188 .76626 .41577 .76198 .41015 Metetra
0 .023 .121 r
.76198 .41015 .76626 .41577 .77595 .41273 .77169 .40709 Metetra
0 .023 .121 r
.77169 .40709 .77595 .41273 .78566 .40968 .78143 .40402 Metetra
0 .023 .121 r
.78143 .40402 .78566 .40968 .79541 .40662 .7912 .40095 Metetra
0 .023 .121 r
.7912 .40095 .79541 .40662 .8052 .40356 .80101 .39785 Metetra
0 .023 .121 r
.80101 .39785 .8052 .40356 .81501 .40047 .81085 .39475 Metetra
0 .023 .121 r
.81085 .39475 .81501 .40047 .82486 .39738 .82072 .39164 Metetra
0 .023 .121 r
.82072 .39164 .82486 .39738 .83475 .39428 .83063 .38853 Metetra
0 .023 .122 r
.83063 .38853 .83475 .39428 .84466 .39117 .84057 .38541 Metetra
0 .023 .122 r
.84057 .38541 .84466 .39117 .85461 .38805 .85055 .38225 Metetra
0 .023 .122 r
.85055 .38225 .85461 .38805 .8646 .38492 .86056 .3791 Metetra
0 .023 .122 r
.86056 .3791 .8646 .38492 .87462 .38177 .8706 .37594 Metetra
0 .023 .122 r
.8706 .37594 .87462 .38177 .88467 .37863 .88068 .37276 Metetra
0 .024 .122 r
.88068 .37276 .88467 .37863 .89476 .37545 .8908 .3696 Metetra
0 .024 .122 r
.8908 .3696 .89476 .37545 .90488 .37228 .90094 .36638 Metetra
0 .023 .122 r
.90094 .36638 .90488 .37228 .91504 .36908 .91113 .36316 Metetra
0 .023 .121 r
.91113 .36316 .91504 .36908 .92523 .36588 .92134 .35994 Metetra
0 .023 .121 r
.3348 .53824 .34001 .54312 .34835 .54049 .34315 .5356 Metetra
0 .023 .121 r
.34315 .5356 .34835 .54049 .3567 .53786 .35152 .53297 Metetra
0 .023 .122 r
.35152 .53297 .3567 .53786 .36509 .53521 .35992 .53032 Metetra
0 .023 .122 r
.35992 .53032 .36509 .53521 .3735 .53257 .36835 .52765 Metetra
0 .023 .122 r
.36835 .52765 .3735 .53257 .38193 .5299 .3768 .52497 Metetra
0 .023 .122 r
.3768 .52497 .38193 .5299 .39039 .52724 .38528 .52229 Metetra
0 .023 .121 r
.38528 .52229 .39039 .52724 .39888 .52455 .39379 .51959 Metetra
0 .023 .121 r
.39379 .51959 .39888 .52455 .4074 .52188 .40232 .5169 Metetra
0 .023 .121 r
.40232 .5169 .4074 .52188 .41594 .51918 .41088 .51418 Metetra
0 .023 .121 r
.41088 .51418 .41594 .51918 .42451 .51648 .41947 .51147 Metetra
0 .023 .121 r
.41947 .51147 .42451 .51648 .43311 .51377 .42808 .50875 Metetra
0 .023 .121 r
.42808 .50875 .43311 .51377 .44174 .51105 .43673 .50601 Metetra
0 .023 .121 r
.43673 .50601 .44174 .51105 .45039 .50834 .4454 .50327 Metetra
0 .023 .122 r
.4454 .50327 .45039 .50834 .45907 .5056 .4541 .50052 Metetra
0 .023 .121 r
.4541 .50052 .45907 .5056 .46778 .50285 .46282 .49776 Metetra
0 .023 .121 r
.46282 .49776 .46778 .50285 .47652 .5001 .47158 .49499 Metetra
0 .023 .121 r
.47158 .49499 .47652 .5001 .48528 .49734 .48036 .49222 Metetra
0 .023 .122 r
.48036 .49222 .48528 .49734 .49407 .49458 .48917 .48943 Metetra
0 .023 .122 r
.48917 .48943 .49407 .49458 .50289 .4918 .49801 .48663 Metetra
0 .023 .121 r
.49801 .48663 .50289 .4918 .51174 .48899 .50688 .48382 Metetra
0 .023 .121 r
.50688 .48382 .51174 .48899 .52062 .48622 .51577 .48101 Metetra
0 .023 .122 r
.51577 .48101 .52062 .48622 .52953 .4834 .5247 .4782 Metetra
0 .024 .122 r
.5247 .4782 .52953 .4834 .53847 .48059 .53366 .47539 Metetra
0 .024 .122 r
.53366 .47539 .53847 .48059 .54743 .47777 .54264 .47257 Metetra
0 .024 .122 r
.54264 .47257 .54743 .47777 .55643 .4751 .55165 .46988 Metetra
0 .025 .124 r
.55165 .46988 .55643 .4751 .56546 .47308 .56071 .46789 Metetra
0 .026 .125 r
.56071 .46789 .56546 .47308 .57451 .46972 .56978 .46446 Metetra
0 .025 .123 r
.56978 .46446 .57451 .46972 .58359 .46677 .57888 .46147 Metetra
0 .025 .123 r
.57888 .46147 .58359 .46677 .5927 .46386 .58801 .45852 Metetra
0 .025 .123 r
.58801 .45852 .5927 .46386 .60185 .46094 .59717 .45559 Metetra
0 .024 .123 r
.59717 .45559 .60185 .46094 .61102 .45806 .60637 .45269 Metetra
0 .025 .123 r
.60637 .45269 .61102 .45806 .62023 .45523 .61559 .44984 Metetra
0 .025 .123 r
.61559 .44984 .62023 .45523 .62946 .45224 .62484 .44684 Metetra
0 .025 .123 r
.62484 .44684 .62946 .45224 .63872 .44935 .63413 .44392 Metetra
0 .025 .123 r
.63413 .44392 .63872 .44935 .64802 .44647 .64345 .44102 Metetra
0 .025 .123 r
.64345 .44102 .64802 .44647 .65735 .44369 .6528 .43818 Metetra
0 .026 .124 r
.6528 .43818 .65735 .44369 .66673 .44115 .66219 .43548 Metetra
0 .025 .124 r
.66219 .43548 .66673 .44115 .67609 .4375 .67158 .43194 Metetra
0 .024 .122 r
.67158 .43194 .67609 .4375 .6855 .43434 .68101 .42888 Metetra
0 .024 .122 r
.68101 .42888 .6855 .43434 .69494 .43133 .69048 .42581 Metetra
0 .024 .122 r
.69048 .42581 .69494 .43133 .70442 .42831 .69998 .42275 Metetra
0 .023 .122 r
.69998 .42275 .70442 .42831 .71394 .42528 .70952 .41974 Metetra
0 .023 .121 r
.70952 .41974 .71394 .42528 .72348 .42229 .71908 .4167 Metetra
0 .023 .121 r
.71908 .4167 .72348 .42229 .73306 .41926 .72868 .41367 Metetra
0 .023 .121 r
.72868 .41367 .73306 .41926 .74267 .41624 .73832 .41062 Metetra
0 .023 .121 r
.73832 .41062 .74267 .41624 .75231 .41319 .74798 .40756 Metetra
0 .023 .121 r
.74798 .40756 .75231 .41319 .76198 .41015 .75768 .40449 Metetra
0 .023 .121 r
.75768 .40449 .76198 .41015 .77169 .40709 .76741 .40142 Metetra
0 .023 .121 r
.76741 .40142 .77169 .40709 .78143 .40402 .77717 .39833 Metetra
0 .023 .121 r
.77717 .39833 .78143 .40402 .7912 .40095 .78697 .39523 Metetra
0 .023 .121 r
.78697 .39523 .7912 .40095 .80101 .39785 .7968 .39212 Metetra
0 .023 .121 r
.7968 .39212 .80101 .39785 .81085 .39475 .80666 .389 Metetra
0 .023 .121 r
.80666 .389 .81085 .39475 .82072 .39164 .81656 .38587 Metetra
0 .023 .121 r
.81656 .38587 .82072 .39164 .83063 .38853 .82649 .38272 Metetra
0 .023 .122 r
.82649 .38272 .83063 .38853 .84057 .38541 .83646 .3796 Metetra
0 .023 .122 r
.83646 .3796 .84057 .38541 .85055 .38225 .84646 .37642 Metetra
0 .023 .121 r
.84646 .37642 .85055 .38225 .86056 .3791 .85649 .37324 Metetra
0 .023 .121 r
.85649 .37324 .86056 .3791 .8706 .37594 .86656 .37006 Metetra
0 .023 .121 r
.86656 .37006 .8706 .37594 .88068 .37276 .87666 .36686 Metetra
0 .023 .122 r
.87666 .36686 .88068 .37276 .8908 .3696 .8868 .36368 Metetra
0 .024 .122 r
.8868 .36368 .8908 .3696 .90094 .36638 .89698 .36043 Metetra
0 .023 .121 r
.89698 .36043 .90094 .36638 .91113 .36316 .90718 .3572 Metetra
0 .023 .121 r
.90718 .3572 .91113 .36316 .92134 .35994 .91743 .35396 Metetra
0 .023 .121 r
.32956 .53337 .3348 .53824 .34315 .5356 .33793 .53071 Metetra
0 .023 .121 r
.33793 .53071 .34315 .5356 .35152 .53297 .34631 .52805 Metetra
0 .023 .122 r
.34631 .52805 .35152 .53297 .35992 .53032 .35473 .5254 Metetra
0 .023 .122 r
.35473 .5254 .35992 .53032 .36835 .52765 .36317 .5227 Metetra
0 .023 .121 r
.36317 .5227 .36835 .52765 .3768 .52497 .37164 .52001 Metetra
0 .023 .121 r
.37164 .52001 .3768 .52497 .38528 .52229 .38014 .51732 Metetra
0 .023 .121 r
.38014 .51732 .38528 .52229 .39379 .51959 .38866 .5146 Metetra
0 .023 .121 r
.38866 .5146 .39379 .51959 .40232 .5169 .39721 .51189 Metetra
0 .023 .121 r
.39721 .51189 .40232 .5169 .41088 .51418 .40579 .50916 Metetra
0 .023 .121 r
.40579 .50916 .41088 .51418 .41947 .51147 .41439 .50644 Metetra
0 .023 .121 r
.41439 .50644 .41947 .51147 .42808 .50875 .42303 .5037 Metetra
0 .023 .121 r
.42303 .5037 .42808 .50875 .43673 .50601 .43169 .50094 Metetra
0 .023 .121 r
.43169 .50094 .43673 .50601 .4454 .50327 .44037 .49818 Metetra
0 .023 .121 r
.44037 .49818 .4454 .50327 .4541 .50052 .44909 .49542 Metetra
0 .023 .121 r
.44909 .49542 .4541 .50052 .46282 .49776 .45783 .49264 Metetra
0 .023 .121 r
.45783 .49264 .46282 .49776 .47158 .49499 .46661 .48986 Metetra
0 .023 .121 r
.46661 .48986 .47158 .49499 .48036 .49222 .47541 .48706 Metetra
0 .023 .121 r
.47541 .48706 .48036 .49222 .48917 .48943 .48424 .48426 Metetra
0 .023 .122 r
.48424 .48426 .48917 .48943 .49801 .48663 .4931 .48146 Metetra
0 .023 .121 r
.4931 .48146 .49801 .48663 .50688 .48382 .50198 .47862 Metetra
0 .023 .121 r
.50198 .47862 .50688 .48382 .51577 .48101 .5109 .47579 Metetra
0 .023 .122 r
.5109 .47579 .51577 .48101 .5247 .4782 .51984 .47297 Metetra
0 .024 .122 r
.51984 .47297 .5247 .4782 .53366 .47539 .52882 .47016 Metetra
0 .024 .122 r
.52882 .47016 .53366 .47539 .54264 .47257 .53782 .46734 Metetra
0 .024 .122 r
.53782 .46734 .54264 .47257 .55165 .46988 .54685 .46458 Metetra
0 .025 .124 r
.54685 .46458 .55165 .46988 .56071 .46789 .55592 .46253 Metetra
0 .026 .125 r
.55592 .46253 .56071 .46789 .56978 .46446 .56501 .45914 Metetra
0 .025 .124 r
.56501 .45914 .56978 .46446 .57888 .46147 .57414 .45613 Metetra
0 .025 .123 r
.57414 .45613 .57888 .46147 .58801 .45852 .58329 .45316 Metetra
0 .025 .123 r
.58329 .45316 .58801 .45852 .59717 .45559 .59247 .45021 Metetra
0 .024 .123 r
.59247 .45021 .59717 .45559 .60637 .45269 .60169 .44729 Metetra
0 .025 .123 r
.60169 .44729 .60637 .45269 .61559 .44984 .61093 .44441 Metetra
0 .025 .123 r
.61093 .44441 .61559 .44984 .62484 .44684 .6202 .4414 Metetra
0 .024 .123 r
.6202 .4414 .62484 .44684 .63413 .44392 .62951 .43846 Metetra
0 .025 .123 r
.62951 .43846 .63413 .44392 .64345 .44102 .63885 .43553 Metetra
0 .025 .123 r
.63885 .43553 .64345 .44102 .6528 .43818 .64822 .43265 Metetra
0 .025 .124 r
.64822 .43265 .6528 .43818 .66219 .43548 .65763 .42984 Metetra
0 .025 .123 r
.65763 .42984 .66219 .43548 .67158 .43194 .66704 .42637 Metetra
0 .024 .122 r
.66704 .42637 .67158 .43194 .68101 .42888 .6765 .42335 Metetra
0 .024 .122 r
.6765 .42335 .68101 .42888 .69048 .42581 .68599 .42024 Metetra
0 .024 .122 r
.68599 .42024 .69048 .42581 .69998 .42275 .69551 .41717 Metetra
0 .023 .121 r
.69551 .41717 .69998 .42275 .70952 .41974 .70507 .41415 Metetra
0 .023 .121 r
.70507 .41415 .70952 .41974 .71908 .4167 .71466 .41109 Metetra
0 .023 .121 r
.71466 .41109 .71908 .4167 .72868 .41367 .72428 .40804 Metetra
0 .023 .121 r
.72428 .40804 .72868 .41367 .73832 .41062 .73394 .40496 Metetra
0 .023 .121 r
.73394 .40496 .73832 .41062 .74798 .40756 .74362 .40189 Metetra
0 .023 .121 r
.74362 .40189 .74798 .40756 .75768 .40449 .75334 .39881 Metetra
0 .023 .121 r
.75334 .39881 .75768 .40449 .76741 .40142 .7631 .39571 Metetra
0 .023 .121 r
.7631 .39571 .76741 .40142 .77717 .39833 .77288 .3926 Metetra
0 .023 .121 r
.77288 .3926 .77717 .39833 .78697 .39523 .7827 .38948 Metetra
0 .023 .121 r
.7827 .38948 .78697 .39523 .7968 .39212 .79256 .38635 Metetra
0 .023 .121 r
.79256 .38635 .7968 .39212 .80666 .389 .80245 .38322 Metetra
0 .023 .121 r
.80245 .38322 .80666 .389 .81656 .38587 .81237 .38007 Metetra
0 .023 .121 r
.81237 .38007 .81656 .38587 .82649 .38272 .82232 .3769 Metetra
0 .023 .122 r
.82232 .3769 .82649 .38272 .83646 .3796 .83232 .37375 Metetra
0 .023 .122 r
.83232 .37375 .83646 .3796 .84646 .37642 .84234 .37056 Metetra
0 .023 .121 r
.84234 .37056 .84646 .37642 .85649 .37324 .8524 .36735 Metetra
0 .023 .121 r
.8524 .36735 .85649 .37324 .86656 .37006 .86249 .36415 Metetra
0 .023 .121 r
.86249 .36415 .86656 .37006 .87666 .36686 .87262 .36094 Metetra
0 .023 .122 r
.87262 .36094 .87666 .36686 .8868 .36368 .88279 .35772 Metetra
0 .023 .122 r
.88279 .35772 .8868 .36368 .89698 .36043 .89298 .35447 Metetra
0 .023 .121 r
.89298 .35447 .89698 .36043 .90718 .3572 .90322 .35121 Metetra
0 .023 .121 r
.90322 .35121 .90718 .3572 .91743 .35396 .91349 .34795 Metetra
0 .023 .121 r
.32429 .52846 .32956 .53337 .33793 .53071 .33267 .52579 Metetra
0 .023 .121 r
.33267 .52579 .33793 .53071 .34631 .52805 .34107 .52311 Metetra
0 .023 .122 r
.34107 .52311 .34631 .52805 .35473 .5254 .34951 .52044 Metetra
0 .023 .122 r
.34951 .52044 .35473 .5254 .36317 .5227 .35797 .51773 Metetra
0 .023 .121 r
.35797 .51773 .36317 .5227 .37164 .52001 .36645 .51502 Metetra
0 .023 .121 r
.36645 .51502 .37164 .52001 .38014 .51732 .37496 .51232 Metetra
0 .023 .121 r
.37496 .51232 .38014 .51732 .38866 .5146 .3835 .50958 Metetra
0 .023 .121 r
.3835 .50958 .38866 .5146 .39721 .51189 .39207 .50686 Metetra
0 .023 .121 r
.39207 .50686 .39721 .51189 .40579 .50916 .40067 .50411 Metetra
0 .023 .121 r
.40067 .50411 .40579 .50916 .41439 .50644 .40929 .50137 Metetra
0 .023 .121 r
.40929 .50137 .41439 .50644 .42303 .5037 .41794 .49861 Metetra
0 .023 .121 r
.41794 .49861 .42303 .5037 .43169 .50094 .42662 .49584 Metetra
0 .023 .121 r
.42662 .49584 .43169 .50094 .44037 .49818 .43532 .49307 Metetra
0 .023 .121 r
.43532 .49307 .44037 .49818 .44909 .49542 .44406 .49028 Metetra
0 .023 .121 r
.44406 .49028 .44909 .49542 .45783 .49264 .45282 .48749 Metetra
0 .023 .121 r
.45282 .48749 .45783 .49264 .46661 .48986 .46161 .48469 Metetra
0 .023 .121 r
.46161 .48469 .46661 .48986 .47541 .48706 .47043 .48188 Metetra
0 .023 .121 r
.47043 .48188 .47541 .48706 .48424 .48426 .47928 .47906 Metetra
0 .023 .122 r
.47928 .47906 .48424 .48426 .4931 .48146 .48815 .47624 Metetra
0 .023 .121 r
.48815 .47624 .4931 .48146 .50198 .47862 .49706 .47338 Metetra
0 .023 .121 r
.49706 .47338 .50198 .47862 .5109 .47579 .50599 .47054 Metetra
0 .023 .122 r
.50599 .47054 .5109 .47579 .51984 .47297 .51496 .4677 Metetra
0 .024 .122 r
.51496 .4677 .51984 .47297 .52882 .47016 .52395 .46487 Metetra
0 .024 .122 r
.52395 .46487 .52882 .47016 .53782 .46734 .53297 .46204 Metetra
0 .024 .122 r
.53297 .46204 .53782 .46734 .54685 .46458 .54202 .45926 Metetra
0 .025 .124 r
.54202 .45926 .54685 .46458 .55592 .46253 .55111 .4572 Metetra
0 .026 .125 r
.55111 .4572 .55592 .46253 .56501 .45914 .56022 .4538 Metetra
0 .025 .124 r
.56022 .4538 .56501 .45914 .57414 .45613 .56937 .45076 Metetra
0 .025 .123 r
.56937 .45076 .57414 .45613 .58329 .45316 .57854 .44778 Metetra
0 .025 .123 r
.57854 .44778 .58329 .45316 .59247 .45021 .58774 .44482 Metetra
0 .024 .123 r
.58774 .44482 .59247 .45021 .60169 .44729 .59698 .44188 Metetra
0 .025 .123 r
.59698 .44188 .60169 .44729 .61093 .44441 .60624 .43898 Metetra
0 .025 .123 r
.60624 .43898 .61093 .44441 .6202 .4414 .61554 .43596 Metetra
0 .024 .123 r
.61554 .43596 .6202 .4414 .62951 .43846 .62486 .433 Metetra
0 .025 .123 r
.62486 .433 .62951 .43846 .63885 .43553 .63422 .43004 Metetra
0 .025 .123 r
.63422 .43004 .63885 .43553 .64822 .43265 .64362 .42714 Metetra
0 .025 .124 r
.64362 .42714 .64822 .43265 .65763 .42984 .65304 .42431 Metetra
0 .025 .123 r
.65304 .42431 .65763 .42984 .66704 .42637 .66248 .42081 Metetra
0 .024 .122 r
.66248 .42081 .66704 .42637 .6765 .42335 .67196 .41778 Metetra
0 .024 .122 r
.67196 .41778 .6765 .42335 .68599 .42024 .68147 .41465 Metetra
0 .024 .122 r
.68147 .41465 .68599 .42024 .69551 .41717 .69102 .41156 Metetra
0 .023 .121 r
.69102 .41156 .69551 .41717 .70507 .41415 .7006 .40852 Metetra
0 .023 .122 r
.7006 .40852 .70507 .41415 .71466 .41109 .71021 .40544 Metetra
0 .023 .121 r
.71021 .40544 .71466 .41109 .72428 .40804 .71985 .40237 Metetra
0 .023 .121 r
.71985 .40237 .72428 .40804 .73394 .40496 .72953 .39928 Metetra
0 .023 .121 r
.72953 .39928 .73394 .40496 .74362 .40189 .73924 .39619 Metetra
0 .023 .121 r
.73924 .39619 .74362 .40189 .75334 .39881 .74898 .39308 Metetra
0 .023 .121 r
.74898 .39308 .75334 .39881 .7631 .39571 .75876 .38997 Metetra
0 .023 .121 r
.75876 .38997 .7631 .39571 .77288 .3926 .76857 .38684 Metetra
0 .023 .121 r
.76857 .38684 .77288 .3926 .7827 .38948 .77841 .38369 Metetra
0 .023 .121 r
.77841 .38369 .7827 .38948 .79256 .38635 .78829 .38055 Metetra
0 .023 .121 r
.78829 .38055 .79256 .38635 .80245 .38322 .7982 .37739 Metetra
0 .023 .121 r
.7982 .37739 .80245 .38322 .81237 .38007 .80815 .37423 Metetra
0 .023 .121 r
.80815 .37423 .81237 .38007 .82232 .3769 .81813 .37103 Metetra
0 .023 .121 r
.81813 .37103 .82232 .3769 .83232 .37375 .82815 .36786 Metetra
0 .023 .122 r
.82815 .36786 .83232 .37375 .84234 .37056 .8382 .36465 Metetra
0 .023 .121 r
.8382 .36465 .84234 .37056 .8524 .36735 .84828 .36143 Metetra
0 .023 .121 r
.84828 .36143 .8524 .36735 .86249 .36415 .8584 .3582 Metetra
0 .023 .121 r
.8584 .3582 .86249 .36415 .87262 .36094 .86855 .35497 Metetra
0 .023 .122 r
.86855 .35497 .87262 .36094 .88279 .35772 .87874 .35173 Metetra
0 .023 .122 r
.87874 .35173 .88279 .35772 .89298 .35447 .88897 .34846 Metetra
0 .023 .121 r
.88897 .34846 .89298 .35447 .90322 .35121 .89923 .34518 Metetra
0 .023 .121 r
.89923 .34518 .90322 .35121 .91349 .34795 .90953 .3419 Metetra
0 .023 .121 r
.31899 .52351 .32429 .52846 .33267 .52579 .32738 .52083 Metetra
0 .023 .121 r
.32738 .52083 .33267 .52579 .34107 .52311 .3358 .51815 Metetra
0 .023 .122 r
.3358 .51815 .34107 .52311 .34951 .52044 .34425 .51545 Metetra
0 .023 .122 r
.34425 .51545 .34951 .52044 .35797 .51773 .35273 .51273 Metetra
0 .023 .121 r
.35273 .51273 .35797 .51773 .36645 .51502 .36123 .51001 Metetra
0 .023 .121 r
.36123 .51001 .36645 .51502 .37496 .51232 .36976 .50728 Metetra
0 .023 .121 r
.36976 .50728 .37496 .51232 .3835 .50958 .37832 .50453 Metetra
0 .023 .121 r
.37832 .50453 .3835 .50958 .39207 .50686 .3869 .50179 Metetra
0 .023 .121 r
.3869 .50179 .39207 .50686 .40067 .50411 .39551 .49903 Metetra
0 .023 .121 r
.39551 .49903 .40067 .50411 .40929 .50137 .40415 .49627 Metetra
0 .023 .121 r
.40415 .49627 .40929 .50137 .41794 .49861 .41282 .4935 Metetra
0 .023 .121 r
.41282 .4935 .41794 .49861 .42662 .49584 .42152 .49071 Metetra
0 .023 .121 r
.42152 .49071 .42662 .49584 .43532 .49307 .43024 .48792 Metetra
0 .023 .121 r
.43024 .48792 .43532 .49307 .44406 .49028 .43899 .48512 Metetra
0 .023 .121 r
.43899 .48512 .44406 .49028 .45282 .48749 .44777 .48231 Metetra
0 .023 .121 r
.44777 .48231 .45282 .48749 .46161 .48469 .45658 .47949 Metetra
0 .023 .121 r
.45658 .47949 .46161 .48469 .47043 .48188 .46542 .47667 Metetra
0 .023 .121 r
.46542 .47667 .47043 .48188 .47928 .47906 .47428 .47383 Metetra
0 .023 .121 r
.47428 .47383 .47928 .47906 .48815 .47624 .48318 .47098 Metetra
0 .023 .121 r
.48318 .47098 .48815 .47624 .49706 .47338 .4921 .46812 Metetra
0 .023 .121 r
.4921 .46812 .49706 .47338 .50599 .47054 .50106 .46525 Metetra
0 .023 .122 r
.50106 .46525 .50599 .47054 .51496 .4677 .51004 .4624 Metetra
0 .024 .122 r
.51004 .4624 .51496 .4677 .52395 .46487 .51905 .45954 Metetra
0 .024 .122 r
.51905 .45954 .52395 .46487 .53297 .46204 .52809 .45666 Metetra
0 .024 .122 r
.52809 .45666 .53297 .46204 .54202 .45926 .53717 .45393 Metetra
0 .026 .124 r
.53717 .45393 .54202 .45926 .55111 .4572 .54627 .45193 Metetra
0 .026 .125 r
.54627 .45193 .55111 .4572 .56022 .4538 .5554 .44845 Metetra
0 .025 .124 r
.5554 .44845 .56022 .4538 .56937 .45076 .56457 .44541 Metetra
0 .025 .123 r
.56457 .44541 .56937 .45076 .57854 .44778 .57376 .44243 Metetra
0 .025 .123 r
.57376 .44243 .57854 .44778 .58774 .44482 .58298 .43946 Metetra
0 .025 .123 r
.58298 .43946 .58774 .44482 .59698 .44188 .59224 .43651 Metetra
0 .025 .123 r
.59224 .43651 .59698 .44188 .60624 .43898 .60153 .43358 Metetra
0 .025 .123 r
.60153 .43358 .60624 .43898 .61554 .43596 .61084 .43055 Metetra
0 .025 .123 r
.61084 .43055 .61554 .43596 .62486 .433 .62019 .42757 Metetra
0 .025 .123 r
.62019 .42757 .62486 .433 .63422 .43004 .62957 .42458 Metetra
0 .025 .123 r
.62957 .42458 .63422 .43004 .64362 .42714 .63898 .42167 Metetra
0 .025 .124 r
.63898 .42167 .64362 .42714 .65304 .42431 .64844 .41889 Metetra
0 .025 .123 r
.64844 .41889 .65304 .42431 .66248 .42081 .65789 .41528 Metetra
0 .024 .122 r
.65789 .41528 .66248 .42081 .67196 .41778 .66739 .41216 Metetra
0 .024 .122 r
.66739 .41216 .67196 .41778 .68147 .41465 .67692 .40904 Metetra
0 .024 .122 r
.67692 .40904 .68147 .41465 .69102 .41156 .68649 .40591 Metetra
0 .023 .121 r
.68649 .40591 .69102 .41156 .7006 .40852 .69609 .40285 Metetra
0 .023 .121 r
.69609 .40285 .7006 .40852 .71021 .40544 .70573 .39975 Metetra
0 .023 .121 r
.70573 .39975 .71021 .40544 .71985 .40237 .7154 .39667 Metetra
0 .023 .121 r
.7154 .39667 .71985 .40237 .72953 .39928 .72509 .39355 Metetra
0 .023 .121 r
.72509 .39355 .72953 .39928 .73924 .39619 .73483 .39044 Metetra
0 .023 .121 r
.73483 .39044 .73924 .39619 .74898 .39308 .7446 .38732 Metetra
0 .023 .121 r
.7446 .38732 .74898 .39308 .75876 .38997 .7544 .38418 Metetra
0 .023 .121 r
.7544 .38418 .75876 .38997 .76857 .38684 .76423 .38103 Metetra
0 .023 .121 r
.76423 .38103 .76857 .38684 .77841 .38369 .7741 .37787 Metetra
0 .023 .121 r
.7741 .37787 .77841 .38369 .78829 .38055 .784 .37471 Metetra
0 .023 .121 r
.784 .37471 .78829 .38055 .7982 .37739 .79393 .37153 Metetra
0 .023 .121 r
.79393 .37153 .7982 .37739 .80815 .37423 .80391 .36834 Metetra
0 .023 .121 r
.80391 .36834 .80815 .37423 .81813 .37103 .81391 .36513 Metetra
0 .023 .122 r
.81391 .36513 .81813 .37103 .82815 .36786 .82395 .36194 Metetra
0 .023 .122 r
.82395 .36194 .82815 .36786 .8382 .36465 .83402 .35871 Metetra
0 .023 .121 r
.83402 .35871 .8382 .36465 .84828 .36143 .84413 .35546 Metetra
0 .023 .121 r
.84413 .35546 .84828 .36143 .8584 .3582 .85428 .35222 Metetra
0 .023 .121 r
.85428 .35222 .8584 .3582 .86855 .35497 .86446 .34896 Metetra
0 .023 .122 r
.86446 .34896 .86855 .35497 .87874 .35173 .87468 .34571 Metetra
0 .023 .122 r
.87468 .34571 .87874 .35173 .88897 .34846 .88492 .3424 Metetra
0 .023 .121 r
.88492 .3424 .88897 .34846 .89923 .34518 .89521 .33911 Metetra
0 .023 .121 r
.89521 .33911 .89923 .34518 .90953 .3419 .90554 .3358 Metetra
0 .023 .121 r
.31365 .51857 .31899 .52351 .32738 .52083 .32206 .51586 Metetra
0 .023 .121 r
.32206 .51586 .32738 .52083 .3358 .51815 .3305 .51315 Metetra
0 .023 .122 r
.3305 .51315 .3358 .51815 .34425 .51545 .33897 .51043 Metetra
0 .023 .122 r
.33897 .51043 .34425 .51545 .35273 .51273 .34746 .50771 Metetra
0 .023 .122 r
.34746 .50771 .35273 .51273 .36123 .51001 .35598 .50496 Metetra
0 .023 .122 r
.35598 .50496 .36123 .51001 .36976 .50728 .36452 .50222 Metetra
0 .023 .121 r
.36452 .50222 .36976 .50728 .37832 .50453 .3731 .49945 Metetra
0 .023 .121 r
.3731 .49945 .37832 .50453 .3869 .50179 .3817 .4967 Metetra
0 .023 .121 r
.3817 .4967 .3869 .50179 .39551 .49903 .39033 .49392 Metetra
0 .023 .121 r
.39033 .49392 .39551 .49903 .40415 .49627 .39899 .49114 Metetra
0 .023 .121 r
.39899 .49114 .40415 .49627 .41282 .4935 .40767 .48835 Metetra
0 .023 .121 r
.40767 .48835 .41282 .4935 .42152 .49071 .41638 .48555 Metetra
0 .023 .121 r
.41638 .48555 .42152 .49071 .43024 .48792 .42513 .48275 Metetra
0 .023 .121 r
.42513 .48275 .43024 .48792 .43899 .48512 .43389 .47993 Metetra
0 .023 .121 r
.43389 .47993 .43899 .48512 .44777 .48231 .44269 .4771 Metetra
0 .023 .121 r
.44269 .4771 .44777 .48231 .45658 .47949 .45152 .47426 Metetra
0 .023 .121 r
.45152 .47426 .45658 .47949 .46542 .47667 .46038 .47142 Metetra
0 .023 .122 r
.46038 .47142 .46542 .47667 .47428 .47383 .46926 .46858 Metetra
0 .023 .122 r
.46926 .46858 .47428 .47383 .48318 .47098 .47817 .46571 Metetra
0 .023 .121 r
.47817 .46571 .48318 .47098 .4921 .46812 .48712 .46282 Metetra
0 .023 .121 r
.48712 .46282 .4921 .46812 .50106 .46525 .49609 .45996 Metetra
0 .023 .122 r
.49609 .45996 .50106 .46525 .51004 .4624 .50509 .45705 Metetra
0 .024 .122 r
.50509 .45705 .51004 .4624 .51905 .45954 .51412 .45417 Metetra
0 .024 .122 r
.51412 .45417 .51905 .45954 .52809 .45666 .52318 .45127 Metetra
0 .024 .122 r
.52318 .45127 .52809 .45666 .53717 .45393 .53228 .44849 Metetra
0 .026 .124 r
.53228 .44849 .53717 .45393 .54627 .45193 .5414 .44657 Metetra
0 .026 .125 r
.5414 .44657 .54627 .45193 .5554 .44845 .55055 .44311 Metetra
0 .025 .124 r
.55055 .44311 .5554 .44845 .56457 .44541 .55974 .44012 Metetra
0 .025 .124 r
.55974 .44012 .56457 .44541 .57376 .44243 .56895 .43718 Metetra
0 .025 .124 r
.56895 .43718 .57376 .44243 .58298 .43946 .5782 .43422 Metetra
0 .025 .124 r
.5782 .43422 .58298 .43946 .59224 .43651 .58748 .43128 Metetra
0 .025 .124 r
.58748 .43128 .59224 .43651 .60153 .43358 .59678 .4283 Metetra
0 .025 .124 r
.59678 .4283 .60153 .43358 .61084 .43055 .60612 .42528 Metetra
0 .025 .124 r
.60612 .42528 .61084 .43055 .62019 .42757 .61549 .42225 Metetra
0 .025 .124 r
.61549 .42225 .62019 .42757 .62957 .42458 .62489 .41921 Metetra
0 .025 .124 r
.62489 .41921 .62957 .42458 .63898 .42167 .63433 .41628 Metetra
0 .026 .125 r
.63433 .41628 .63898 .42167 .64844 .41889 .64381 .4136 Metetra
0 .025 .124 r
.64381 .4136 .64844 .41889 .65789 .41528 .65327 .40969 Metetra
0 .024 .122 r
.65327 .40969 .65789 .41528 .66739 .41216 .66279 .40645 Metetra
0 .024 .122 r
.66279 .40645 .66739 .41216 .67692 .40904 .67235 .40336 Metetra
0 .024 .122 r
.67235 .40336 .67692 .40904 .68649 .40591 .68194 .40025 Metetra
0 .023 .122 r
.68194 .40025 .68649 .40591 .69609 .40285 .69156 .39713 Metetra
0 .023 .121 r
.69156 .39713 .69609 .40285 .70573 .39975 .70122 .39404 Metetra
0 .023 .121 r
.70122 .39404 .70573 .39975 .7154 .39667 .71091 .39092 Metetra
0 .023 .121 r
.71091 .39092 .7154 .39667 .72509 .39355 .72063 .3878 Metetra
0 .023 .121 r
.72063 .3878 .72509 .39355 .73483 .39044 .73039 .38466 Metetra
0 .023 .121 r
.73039 .38466 .73483 .39044 .7446 .38732 .74018 .38152 Metetra
0 .023 .121 r
.74018 .38152 .7446 .38732 .7544 .38418 .75 .37836 Metetra
0 .023 .121 r
.75 .37836 .7544 .38418 .76423 .38103 .75986 .37519 Metetra
0 .023 .121 r
.75986 .37519 .76423 .38103 .7741 .37787 .76975 .37202 Metetra
0 .023 .121 r
.76975 .37202 .7741 .37787 .784 .37471 .77968 .36882 Metetra
0 .023 .121 r
.77968 .36882 .784 .37471 .79393 .37153 .78964 .36563 Metetra
0 .023 .121 r
.78964 .36563 .79393 .37153 .80391 .36834 .79963 .36241 Metetra
0 .023 .121 r
.79963 .36241 .80391 .36834 .81391 .36513 .80966 .3592 Metetra
0 .023 .122 r
.80966 .3592 .81391 .36513 .82395 .36194 .81973 .35599 Metetra
0 .023 .122 r
.81973 .35599 .82395 .36194 .83402 .35871 .82983 .35272 Metetra
0 .023 .121 r
.82983 .35272 .83402 .35871 .84413 .35546 .83996 .34947 Metetra
0 .023 .121 r
.83996 .34947 .84413 .35546 .85428 .35222 .85013 .3462 Metetra
0 .023 .121 r
.85013 .3462 .85428 .35222 .86446 .34896 .86034 .34291 Metetra
0 .023 .122 r
.86034 .34291 .86446 .34896 .87468 .34571 .87058 .33965 Metetra
0 .023 .122 r
.87058 .33965 .87468 .34571 .88492 .3424 .88086 .33633 Metetra
0 .023 .121 r
.88086 .33633 .88492 .3424 .89521 .33911 .89117 .33301 Metetra
0 .023 .121 r
.89117 .33301 .89521 .33911 .90554 .3358 .90152 .32968 Metetra
0 .023 .121 r
.30829 .51356 .31365 .51857 .32206 .51586 .31672 .51084 Metetra
0 .023 .121 r
.31672 .51084 .32206 .51586 .3305 .51315 .32517 .50811 Metetra
0 .023 .121 r
.32517 .50811 .3305 .51315 .33897 .51043 .33365 .50539 Metetra
0 .023 .122 r
.33365 .50539 .33897 .51043 .34746 .50771 .34216 .50265 Metetra
0 .023 .122 r
.34216 .50265 .34746 .50771 .35598 .50496 .3507 .49988 Metetra
0 .023 .121 r
.3507 .49988 .35598 .50496 .36452 .50222 .35926 .49713 Metetra
0 .023 .121 r
.35926 .49713 .36452 .50222 .3731 .49945 .36785 .49435 Metetra
0 .023 .121 r
.36785 .49435 .3731 .49945 .3817 .4967 .37647 .49158 Metetra
0 .023 .122 r
.37647 .49158 .3817 .4967 .39033 .49392 .38511 .48879 Metetra
0 .023 .121 r
.38511 .48879 .39033 .49392 .39899 .49114 .39379 .48598 Metetra
0 .023 .121 r
.39379 .48598 .39899 .49114 .40767 .48835 .40249 .48318 Metetra
0 .023 .121 r
.40249 .48318 .40767 .48835 .41638 .48555 .41122 .48037 Metetra
0 .023 .122 r
.41122 .48037 .41638 .48555 .42513 .48275 .41998 .47754 Metetra
0 .023 .121 r
.41998 .47754 .42513 .48275 .43389 .47993 .42877 .4747 Metetra
0 .023 .121 r
.42877 .4747 .43389 .47993 .44269 .4771 .43759 .47186 Metetra
0 .023 .121 r
.43759 .47186 .44269 .4771 .45152 .47426 .44643 .469 Metetra
0 .023 .121 r
.44643 .469 .45152 .47426 .46038 .47142 .4553 .46614 Metetra
0 .023 .122 r
.4553 .46614 .46038 .47142 .46926 .46858 .46421 .46327 Metetra
0 .024 .122 r
.46421 .46327 .46926 .46858 .47817 .46571 .47314 .46042 Metetra
0 .024 .122 r
.47314 .46042 .47817 .46571 .48712 .46282 .4821 .45752 Metetra
0 .023 .122 r
.4821 .45752 .48712 .46282 .49609 .45996 .49109 .4546 Metetra
0 .024 .122 r
.49109 .4546 .49609 .45996 .50509 .45705 .50011 .45172 Metetra
0 .024 .122 r
.50011 .45172 .50509 .45705 .51412 .45417 .50917 .44884 Metetra
0 .024 .122 r
.50917 .44884 .51412 .45417 .52318 .45127 .51825 .44595 Metetra
0 .024 .122 r
.51825 .44595 .52318 .45127 .53228 .44849 .52736 .44293 Metetra
0 .025 .124 r
.52736 .44293 .53228 .44849 .5414 .44657 .5365 .4408 Metetra
0 .026 .125 r
.5365 .4408 .5414 .44657 .55055 .44311 .54568 .4379 Metetra
0 .026 .125 r
.54568 .4379 .55055 .44311 .55974 .44012 .55488 .43505 Metetra
0 .026 .125 r
.55488 .43505 .55974 .44012 .56895 .43718 .56412 .43219 Metetra
0 .026 .125 r
.56412 .43219 .56895 .43718 .5782 .43422 .57339 .42929 Metetra
0 .027 .126 r
.57339 .42929 .5782 .43422 .58748 .43128 .58269 .42638 Metetra
0 .027 .126 r
.58269 .42638 .58748 .43128 .59678 .4283 .59202 .42336 Metetra
0 .027 .126 r
.59202 .42336 .59678 .4283 .60612 .42528 .60138 .42031 Metetra
0 .026 .126 r
.60138 .42031 .60612 .42528 .61549 .42225 .61077 .41719 Metetra
0 .026 .125 r
.61077 .41719 .61549 .42225 .62489 .41921 .62019 .41404 Metetra
0 .026 .125 r
.62019 .41404 .62489 .41921 .63433 .41628 .62964 .41097 Metetra
0 .027 .126 r
.62964 .41097 .63433 .41628 .64381 .4136 .63914 .40821 Metetra
0 .026 .124 r
.63914 .40821 .64381 .4136 .65327 .40969 .64862 .40392 Metetra
0 .024 .122 r
.64862 .40392 .65327 .40969 .66279 .40645 .65816 .40079 Metetra
0 .024 .122 r
.65816 .40079 .66279 .40645 .67235 .40336 .66774 .39766 Metetra
0 .024 .122 r
.66774 .39766 .67235 .40336 .68194 .40025 .67736 .39451 Metetra
0 .023 .121 r
.67736 .39451 .68194 .40025 .69156 .39713 .687 .39139 Metetra
0 .023 .121 r
.687 .39139 .69156 .39713 .70122 .39404 .69668 .38828 Metetra
0 .023 .121 r
.69668 .38828 .70122 .39404 .71091 .39092 .7064 .38517 Metetra
0 .023 .121 r
.7064 .38517 .71091 .39092 .72063 .3878 .71614 .382 Metetra
0 .023 .121 r
.71614 .382 .72063 .3878 .73039 .38466 .72592 .37886 Metetra
0 .023 .121 r
.72592 .37886 .73039 .38466 .74018 .38152 .73574 .37569 Metetra
0 .023 .121 r
.73574 .37569 .74018 .38152 .75 .37836 .74558 .37251 Metetra
0 .023 .121 r
.74558 .37251 .75 .37836 .75986 .37519 .75546 .36933 Metetra
0 .023 .121 r
.75546 .36933 .75986 .37519 .76975 .37202 .76538 .36612 Metetra
0 .023 .121 r
.76538 .36612 .76975 .37202 .77968 .36882 .77533 .36293 Metetra
0 .023 .121 r
.77533 .36293 .77968 .36882 .78964 .36563 .78531 .35969 Metetra
0 .023 .121 r
.78531 .35969 .78964 .36563 .79963 .36241 .79533 .35646 Metetra
0 .023 .121 r
.79533 .35646 .79963 .36241 .80966 .3592 .80539 .35322 Metetra
0 .023 .122 r
.80539 .35322 .80966 .3592 .81973 .35599 .81548 .34997 Metetra
0 .023 .122 r
.81548 .34997 .81973 .35599 .82983 .35272 .8256 .34671 Metetra
0 .023 .122 r
.8256 .34671 .82983 .35272 .83996 .34947 .83576 .34344 Metetra
0 .023 .122 r
.83576 .34344 .83996 .34947 .85013 .3462 .84596 .34014 Metetra
0 .023 .122 r
.84596 .34014 .85013 .3462 .86034 .34291 .85619 .33685 Metetra
0 .023 .122 r
.85619 .33685 .86034 .34291 .87058 .33965 .86646 .33353 Metetra
0 .023 .122 r
.86646 .33353 .87058 .33965 .88086 .33633 .87676 .33021 Metetra
0 .023 .121 r
.87676 .33021 .88086 .33633 .89117 .33301 .8871 .32686 Metetra
0 .023 .121 r
.8871 .32686 .89117 .33301 .90152 .32968 .89748 .32351 Metetra
0 .023 .121 r
.30289 .50854 .30829 .51356 .31672 .51084 .31133 .5058 Metetra
0 .023 .121 r
.31133 .5058 .31672 .51084 .32517 .50811 .3198 .50307 Metetra
0 .023 .122 r
.3198 .50307 .32517 .50811 .33365 .50539 .3283 .50032 Metetra
0 .023 .122 r
.3283 .50032 .33365 .50539 .34216 .50265 .33683 .49755 Metetra
0 .023 .121 r
.33683 .49755 .34216 .50265 .3507 .49988 .34538 .49477 Metetra
0 .023 .121 r
.34538 .49477 .3507 .49988 .35926 .49713 .35396 .49199 Metetra
0 .023 .121 r
.35396 .49199 .35926 .49713 .36785 .49435 .36257 .48922 Metetra
0 .023 .121 r
.36257 .48922 .36785 .49435 .37647 .49158 .37121 .48641 Metetra
0 .023 .121 r
.37121 .48641 .37647 .49158 .38511 .48879 .37987 .48361 Metetra
0 .023 .122 r
.37987 .48361 .38511 .48879 .39379 .48598 .38856 .48081 Metetra
0 .023 .122 r
.38856 .48081 .39379 .48598 .40249 .48318 .39728 .47797 Metetra
0 .023 .121 r
.39728 .47797 .40249 .48318 .41122 .48037 .40603 .47513 Metetra
0 .023 .122 r
.40603 .47513 .41122 .48037 .41998 .47754 .41481 .47231 Metetra
0 .023 .122 r
.41481 .47231 .41998 .47754 .42877 .4747 .42361 .46945 Metetra
0 .023 .121 r
.42361 .46945 .42877 .4747 .43759 .47186 .43245 .46658 Metetra
0 .023 .121 r
.43245 .46658 .43759 .47186 .44643 .469 .44131 .46371 Metetra
0 .023 .121 r
.44131 .46371 .44643 .469 .4553 .46614 .4502 .46083 Metetra
0 .023 .122 r
.4502 .46083 .4553 .46614 .46421 .46327 .45912 .45796 Metetra
0 .024 .122 r
.45912 .45796 .46421 .46327 .47314 .46042 .46808 .45507 Metetra
0 .024 .122 r
.46808 .45507 .47314 .46042 .4821 .45752 .47706 .45215 Metetra
0 .023 .122 r
.47706 .45215 .4821 .45752 .49109 .4546 .48607 .44923 Metetra
0 .024 .122 r
.48607 .44923 .49109 .4546 .50011 .45172 .49511 .44632 Metetra
0 .024 .122 r
.49511 .44632 .50011 .45172 .50917 .44884 .50418 .44341 Metetra
0 .024 .122 r
.50418 .44341 .50917 .44884 .51825 .44595 .51328 .44062 Metetra
0 .024 .122 r
.51328 .44062 .51825 .44595 .52736 .44293 .52241 .43777 Metetra
0 .025 .123 r
.52241 .43777 .52736 .44293 .5365 .4408 .53157 .43477 Metetra
0 .026 .126 r
.53157 .43477 .5365 .4408 .54568 .4379 .54077 .43323 Metetra
0 .028 .128 r
.54077 .43323 .54568 .4379 .55488 .43505 .55 .43051 Metetra
0 .029 .128 r
.55 .43051 .55488 .43505 .56412 .43219 .55926 .42778 Metetra
0 .029 .129 r
.55926 .42778 .56412 .43219 .57339 .42929 .56855 .42497 Metetra
0 .03 .13 r
.56855 .42497 .57339 .42929 .58269 .42638 .57788 .42211 Metetra
0 .03 .13 r
.57788 .42211 .58269 .42638 .59202 .42336 .58723 .41908 Metetra
0 .03 .13 r
.58723 .41908 .59202 .42336 .60138 .42031 .59662 .41595 Metetra
0 .029 .129 r
.59662 .41595 .60138 .42031 .61077 .41719 .60603 .41268 Metetra
0 .029 .128 r
.60603 .41268 .61077 .41719 .62019 .41404 .61547 .40934 Metetra
0 .028 .128 r
.61547 .40934 .62019 .41404 .62964 .41097 .62494 .40593 Metetra
0 .027 .127 r
.62494 .40593 .62964 .41097 .63914 .40821 .63443 .40221 Metetra
0 .026 .125 r
.63443 .40221 .63914 .40821 .64862 .40392 .64395 .39844 Metetra
0 .024 .122 r
.64395 .39844 .64862 .40392 .65816 .40079 .65352 .39531 Metetra
0 .024 .122 r
.65352 .39531 .65816 .40079 .66774 .39766 .66312 .39204 Metetra
0 .024 .122 r
.66312 .39204 .66774 .39766 .67736 .39451 .67275 .38886 Metetra
0 .024 .122 r
.67275 .38886 .67736 .39451 .687 .39139 .68241 .38562 Metetra
0 .023 .121 r
.68241 .38562 .687 .39139 .69668 .38828 .69212 .38253 Metetra
0 .023 .122 r
.69212 .38253 .69668 .38828 .7064 .38517 .70185 .37933 Metetra
0 .023 .121 r
.70185 .37933 .7064 .38517 .71614 .382 .71162 .37618 Metetra
0 .023 .121 r
.71162 .37618 .71614 .382 .72592 .37886 .72143 .37299 Metetra
0 .023 .121 r
.72143 .37299 .72592 .37886 .73574 .37569 .73126 .36982 Metetra
0 .023 .121 r
.73126 .36982 .73574 .37569 .74558 .37251 .74113 .36662 Metetra
0 .023 .121 r
.74113 .36662 .74558 .37251 .75546 .36933 .75104 .3634 Metetra
0 .023 .121 r
.75104 .3634 .75546 .36933 .76538 .36612 .76098 .3602 Metetra
0 .023 .122 r
.76098 .3602 .76538 .36612 .77533 .36293 .77095 .35695 Metetra
0 .023 .121 r
.77095 .35695 .77533 .36293 .78531 .35969 .78096 .35373 Metetra
0 .023 .122 r
.78096 .35373 .78531 .35969 .79533 .35646 .79101 .35049 Metetra
0 .023 .122 r
.79101 .35049 .79533 .35646 .80539 .35322 .80109 .3472 Metetra
0 .023 .121 r
.80109 .3472 .80539 .35322 .81548 .34997 .8112 .34392 Metetra
0 .023 .122 r
.8112 .34392 .81548 .34997 .8256 .34671 .82135 .34065 Metetra
0 .023 .122 r
.82135 .34065 .8256 .34671 .83576 .34344 .83154 .33734 Metetra
0 .023 .122 r
.83154 .33734 .83576 .34344 .84596 .34014 .84176 .33403 Metetra
0 .023 .122 r
.84176 .33403 .84596 .34014 .85619 .33685 .85201 .33071 Metetra
0 .023 .122 r
.85201 .33071 .85619 .33685 .86646 .33353 .86231 .32739 Metetra
0 .023 .122 r
.86231 .32739 .86646 .33353 .87676 .33021 .87264 .32403 Metetra
0 .023 .121 r
.87264 .32403 .87676 .33021 .8871 .32686 .883 .32067 Metetra
0 .023 .121 r
.883 .32067 .8871 .32686 .89748 .32351 .89341 .3173 Metetra
0 .023 .121 r
.29746 .50348 .30289 .50854 .31133 .5058 .30592 .50072 Metetra
0 .023 .121 r
.30592 .50072 .31133 .5058 .3198 .50307 .31441 .49797 Metetra
0 .023 .121 r
.31441 .49797 .3198 .50307 .3283 .50032 .32292 .49521 Metetra
0 .023 .122 r
.32292 .49521 .3283 .50032 .33683 .49755 .33146 .49243 Metetra
0 .023 .121 r
.33146 .49243 .33683 .49755 .34538 .49477 .34003 .48965 Metetra
0 .023 .121 r
.34003 .48965 .34538 .49477 .35396 .49199 .34863 .48685 Metetra
0 .023 .121 r
.34863 .48685 .35396 .49199 .36257 .48922 .35726 .48403 Metetra
0 .023 .121 r
.35726 .48403 .36257 .48922 .37121 .48641 .36591 .48123 Metetra
0 .023 .121 r
.36591 .48123 .37121 .48641 .37987 .48361 .37459 .4784 Metetra
0 .023 .122 r
.37459 .4784 .37987 .48361 .38856 .48081 .3833 .47558 Metetra
0 .023 .122 r
.3833 .47558 .38856 .48081 .39728 .47797 .39204 .47273 Metetra
0 .023 .121 r
.39204 .47273 .39728 .47797 .40603 .47513 .4008 .46987 Metetra
0 .023 .121 r
.4008 .46987 .40603 .47513 .41481 .47231 .4096 .46701 Metetra
0 .023 .121 r
.4096 .46701 .41481 .47231 .42361 .46945 .41842 .46415 Metetra
0 .023 .121 r
.41842 .46415 .42361 .46945 .43245 .46658 .42728 .46128 Metetra
0 .023 .121 r
.42728 .46128 .43245 .46658 .44131 .46371 .43616 .4584 Metetra
0 .023 .121 r
.43616 .4584 .44131 .46371 .4502 .46083 .44507 .4555 Metetra
0 .023 .121 r
.44507 .4555 .4502 .46083 .45912 .45796 .45401 .45258 Metetra
0 .023 .122 r
.45401 .45258 .45912 .45796 .46808 .45507 .46298 .44966 Metetra
0 .023 .121 r
.46298 .44966 .46808 .45507 .47706 .45215 .47198 .44673 Metetra
0 .023 .122 r
.47198 .44673 .47706 .45215 .48607 .44923 .48101 .44383 Metetra
0 .024 .122 r
.48101 .44383 .48607 .44923 .49511 .44632 .49007 .44095 Metetra
0 .024 .122 r
.49007 .44095 .49511 .44632 .50418 .44341 .49916 .43822 Metetra
0 .024 .123 r
.49916 .43822 .50418 .44341 .51328 .44062 .50828 .43557 Metetra
0 .025 .124 r
.50828 .43557 .51328 .44062 .52241 .43777 .51743 .43297 Metetra
0 .025 .124 r
.51743 .43297 .52241 .43777 .53157 .43477 .52661 .42996 Metetra
0 .028 .128 r
.52661 .42996 .53157 .43477 .54077 .43323 .53583 .42902 Metetra
0 .032 .133 r
.53583 .42902 .54077 .43323 .55 .43051 .54509 .42662 Metetra
0 .033 .134 r
.54509 .42662 .55 .43051 .55926 .42778 .55438 .42416 Metetra
0 .035 .136 r
.55438 .42416 .55926 .42778 .56855 .42497 .5637 .42154 Metetra
0 .036 .137 r
.5637 .42154 .56855 .42497 .57788 .42211 .57305 .4188 Metetra
0 .036 .137 r
.57305 .4188 .57788 .42211 .58723 .41908 .58244 .4158 Metetra
0 .036 .137 r
.58244 .4158 .58723 .41908 .59662 .41595 .59185 .41253 Metetra
0 .035 .136 r
.59185 .41253 .59662 .41595 .60603 .41268 .60128 .40908 Metetra
0 .034 .135 r
.60128 .40908 .60603 .41268 .61547 .40934 .61074 .40547 Metetra
0 .032 .133 r
.61074 .40547 .61547 .40934 .62494 .40593 .62023 .40173 Metetra
0 .029 .129 r
.62023 .40173 .62494 .40593 .63443 .40221 .6297 .39643 Metetra
0 .026 .125 r
.6297 .39643 .63443 .40221 .64395 .39844 .63927 .39348 Metetra
0 .025 .124 r
.63927 .39348 .64395 .39844 .65352 .39531 .64885 .38997 Metetra
0 .025 .123 r
.64885 .38997 .65352 .39531 .66312 .39204 .65846 .38645 Metetra
0 .024 .122 r
.65846 .38645 .66312 .39204 .67275 .38886 .66811 .3831 Metetra
0 .024 .122 r
.66811 .3831 .67275 .38886 .68241 .38562 .6778 .37986 Metetra
0 .024 .122 r
.6778 .37986 .68241 .38562 .69212 .38253 .68752 .37665 Metetra
0 .023 .121 r
.68752 .37665 .69212 .38253 .70185 .37933 .69728 .37348 Metetra
0 .023 .121 r
.69728 .37348 .70185 .37933 .71162 .37618 .70707 .3703 Metetra
0 .023 .121 r
.70707 .3703 .71162 .37618 .72143 .37299 .7169 .36712 Metetra
0 .023 .122 r
.7169 .36712 .72143 .37299 .73126 .36982 .72676 .36392 Metetra
0 .023 .122 r
.72676 .36392 .73126 .36982 .74113 .36662 .73666 .3607 Metetra
0 .023 .121 r
.73666 .3607 .74113 .36662 .75104 .3634 .74659 .35746 Metetra
0 .023 .121 r
.74659 .35746 .75104 .3634 .76098 .3602 .75655 .35421 Metetra
0 .023 .121 r
.75655 .35421 .76098 .3602 .77095 .35695 .76655 .35096 Metetra
0 .023 .121 r
.76655 .35096 .77095 .35695 .78096 .35373 .77658 .34771 Metetra
0 .023 .122 r
.77658 .34771 .78096 .35373 .79101 .35049 .78665 .34444 Metetra
0 .023 .122 r
.78665 .34444 .79101 .35049 .80109 .3472 .79676 .34115 Metetra
0 .023 .121 r
.79676 .34115 .80109 .3472 .8112 .34392 .8069 .33785 Metetra
0 .023 .121 r
.8069 .33785 .8112 .34392 .82135 .34065 .81707 .33455 Metetra
0 .023 .121 r
.81707 .33455 .82135 .34065 .83154 .33734 .82728 .33122 Metetra
0 .023 .121 r
.82728 .33122 .83154 .33734 .84176 .33403 .83753 .32788 Metetra
0 .023 .122 r
.83753 .32788 .84176 .33403 .85201 .33071 .84781 .32456 Metetra
0 .023 .122 r
.84781 .32456 .85201 .33071 .86231 .32739 .85813 .32118 Metetra
0 .023 .121 r
.85813 .32118 .86231 .32739 .87264 .32403 .86849 .31782 Metetra
0 .023 .121 r
.86849 .31782 .87264 .32403 .883 .32067 .87888 .31443 Metetra
0 .023 .121 r
.87888 .31443 .883 .32067 .89341 .3173 .88931 .31104 Metetra
0 .023 .121 r
.292 .49839 .29746 .50348 .30592 .50072 .30048 .49562 Metetra
0 .023 .121 r
.30048 .49562 .30592 .50072 .31441 .49797 .30898 .49285 Metetra
0 .023 .121 r
.30898 .49285 .31441 .49797 .32292 .49521 .31751 .49007 Metetra
0 .023 .122 r
.31751 .49007 .32292 .49521 .33146 .49243 .32607 .48729 Metetra
0 .023 .122 r
.32607 .48729 .33146 .49243 .34003 .48965 .33466 .48447 Metetra
0 .023 .121 r
.33466 .48447 .34003 .48965 .34863 .48685 .34327 .48167 Metetra
0 .023 .121 r
.34327 .48167 .34863 .48685 .35726 .48403 .35191 .47884 Metetra
0 .023 .121 r
.35191 .47884 .35726 .48403 .36591 .48123 .36058 .47602 Metetra
0 .023 .121 r
.36058 .47602 .36591 .48123 .37459 .4784 .36928 .47318 Metetra
0 .023 .122 r
.36928 .47318 .37459 .4784 .3833 .47558 .37801 .47034 Metetra
0 .023 .122 r
.37801 .47034 .3833 .47558 .39204 .47273 .38676 .46747 Metetra
0 .023 .121 r
.38676 .46747 .39204 .47273 .4008 .46987 .39555 .46459 Metetra
0 .023 .121 r
.39555 .46459 .4008 .46987 .4096 .46701 .40436 .46175 Metetra
0 .023 .122 r
.40436 .46175 .4096 .46701 .41842 .46415 .4132 .45884 Metetra
0 .023 .121 r
.4132 .45884 .41842 .46415 .42728 .46128 .42207 .45593 Metetra
0 .023 .121 r
.42207 .45593 .42728 .46128 .43616 .4584 .43098 .45303 Metetra
0 .023 .121 r
.43098 .45303 .43616 .4584 .44507 .4555 .43991 .45011 Metetra
0 .023 .121 r
.43991 .45011 .44507 .4555 .45401 .45258 .44886 .44721 Metetra
0 .023 .121 r
.44886 .44721 .45401 .45258 .46298 .44966 .45785 .44427 Metetra
0 .024 .122 r
.45785 .44427 .46298 .44966 .47198 .44673 .46687 .44138 Metetra
0 .024 .122 r
.46687 .44138 .47198 .44673 .48101 .44383 .47592 .43847 Metetra
0 .024 .122 r
.47592 .43847 .48101 .44383 .49007 .44095 .485 .43575 Metetra
0 .025 .123 r
.485 .43575 .49007 .44095 .49916 .43822 .4941 .43312 Metetra
0 .026 .125 r
.4941 .43312 .49916 .43822 .50828 .43557 .50324 .43074 Metetra
0 .027 .127 r
.50324 .43074 .50828 .43557 .51743 .43297 .51241 .42856 Metetra
0 .029 .129 r
.51241 .42856 .51743 .43297 .52661 .42996 .52162 .42659 Metetra
0 .032 .133 r
.52162 .42659 .52661 .42996 .53583 .42902 .53086 .42391 Metetra
0 .037 .138 r
.53086 .42391 .53583 .42902 .54509 .42662 .54014 .42307 Metetra
0 .041 .143 r
.54014 .42307 .54509 .42662 .55438 .42416 .54946 .42125 Metetra
0 .044 .146 r
.54946 .42125 .55438 .42416 .5637 .42154 .55882 .41897 Metetra
0 .046 .148 r
.55882 .41897 .5637 .42154 .57305 .4188 .5682 .41641 Metetra
0 .047 .149 r
.5682 .41641 .57305 .4188 .58244 .4158 .57762 .41346 Metetra
0 .046 .149 r
.57762 .41346 .58244 .4158 .59185 .41253 .58705 .40998 Metetra
0 .045 .147 r
.58705 .40998 .59185 .41253 .60128 .40908 .59651 .40619 Metetra
0 .042 .144 r
.59651 .40619 .60128 .40908 .61074 .40547 .60599 .402 Metetra
0 .038 .14 r
.60599 .402 .61074 .40547 .62023 .40173 .61548 .39732 Metetra
0 .033 .134 r
.61548 .39732 .62023 .40173 .6297 .39643 .62501 .3929 Metetra
0 .03 .13 r
.62501 .3929 .6297 .39643 .63927 .39348 .63457 .38896 Metetra
0 .028 .127 r
.63457 .38896 .63927 .39348 .64885 .38997 .64416 .38494 Metetra
0 .026 .125 r
.64416 .38494 .64885 .38997 .65846 .38645 .65379 .38115 Metetra
0 .025 .123 r
.65379 .38115 .65846 .38645 .66811 .3831 .66346 .37761 Metetra
0 .024 .122 r
.66346 .37761 .66811 .3831 .6778 .37986 .67316 .3741 Metetra
0 .024 .122 r
.67316 .3741 .6778 .37986 .68752 .37665 .6829 .37089 Metetra
0 .024 .122 r
.6829 .37089 .68752 .37665 .69728 .37348 .69268 .36759 Metetra
0 .023 .121 r
.69268 .36759 .69728 .37348 .70707 .3703 .7025 .36442 Metetra
0 .023 .122 r
.7025 .36442 .70707 .3703 .7169 .36712 .71235 .36118 Metetra
0 .023 .121 r
.71235 .36118 .7169 .36712 .72676 .36392 .72223 .35795 Metetra
0 .023 .122 r
.72223 .35795 .72676 .36392 .73666 .3607 .73215 .35471 Metetra
0 .023 .121 r
.73215 .35471 .73666 .3607 .74659 .35746 .7421 .35147 Metetra
0 .023 .122 r
.7421 .35147 .74659 .35746 .75655 .35421 .75209 .34823 Metetra
0 .023 .121 r
.75209 .34823 .75655 .35421 .76655 .35096 .76212 .34494 Metetra
0 .023 .121 r
.76212 .34494 .76655 .35096 .77658 .34771 .77218 .34166 Metetra
0 .023 .122 r
.77218 .34166 .77658 .34771 .78665 .34444 .78227 .33838 Metetra
0 .024 .122 r
.78227 .33838 .78665 .34444 .79676 .34115 .7924 .33507 Metetra
0 .023 .122 r
.7924 .33507 .79676 .34115 .8069 .33785 .80256 .33174 Metetra
0 .023 .121 r
.80256 .33174 .8069 .33785 .81707 .33455 .81276 .3284 Metetra
0 .023 .121 r
.81276 .3284 .81707 .33455 .82728 .33122 .823 .32506 Metetra
0 .023 .121 r
.823 .32506 .82728 .33122 .83753 .32788 .83327 .32171 Metetra
0 .023 .122 r
.83327 .32171 .83753 .32788 .84781 .32456 .84358 .31835 Metetra
0 .023 .122 r
.84358 .31835 .84781 .32456 .85813 .32118 .85393 .31497 Metetra
0 .023 .121 r
.85393 .31497 .85813 .32118 .86849 .31782 .86431 .31157 Metetra
0 .023 .121 r
.86431 .31157 .86849 .31782 .87888 .31443 .87473 .30817 Metetra
0 .023 .121 r
.87473 .30817 .87888 .31443 .88931 .31104 .88519 .30475 Metetra
0 .023 .121 r
.28651 .49328 .292 .49839 .30048 .49562 .295 .49049 Metetra
0 .023 .121 r
.295 .49049 .30048 .49562 .30898 .49285 .30352 .4877 Metetra
0 .023 .121 r
.30352 .4877 .30898 .49285 .31751 .49007 .31207 .4849 Metetra
0 .023 .121 r
.31207 .4849 .31751 .49007 .32607 .48729 .32064 .4821 Metetra
0 .023 .121 r
.32064 .4821 .32607 .48729 .33466 .48447 .32925 .47927 Metetra
0 .023 .121 r
.32925 .47927 .33466 .48447 .34327 .48167 .33788 .47646 Metetra
0 .023 .122 r
.33788 .47646 .34327 .48167 .35191 .47884 .34654 .47361 Metetra
0 .023 .122 r
.34654 .47361 .35191 .47884 .36058 .47602 .35522 .47077 Metetra
0 .023 .122 r
.35522 .47077 .36058 .47602 .36928 .47318 .36394 .4679 Metetra
0 .023 .122 r
.36394 .4679 .36928 .47318 .37801 .47034 .37269 .46504 Metetra
0 .023 .122 r
.37269 .46504 .37801 .47034 .38676 .46747 .38146 .46217 Metetra
0 .023 .122 r
.38146 .46217 .38676 .46747 .39555 .46459 .39026 .45929 Metetra
0 .024 .122 r
.39026 .45929 .39555 .46459 .40436 .46175 .39909 .45642 Metetra
0 .024 .122 r
.39909 .45642 .40436 .46175 .4132 .45884 .40795 .45354 Metetra
0 .024 .122 r
.40795 .45354 .4132 .45884 .42207 .45593 .41684 .45061 Metetra
0 .024 .122 r
.41684 .45061 .42207 .45593 .43098 .45303 .42576 .44769 Metetra
0 .024 .122 r
.42576 .44769 .43098 .45303 .43991 .45011 .43471 .44477 Metetra
0 .024 .122 r
.43471 .44477 .43991 .45011 .44886 .44721 .44369 .44183 Metetra
0 .024 .122 r
.44369 .44183 .44886 .44721 .45785 .44427 .4527 .43882 Metetra
0 .024 .122 r
.4527 .43882 .45785 .44427 .46687 .44138 .46173 .43598 Metetra
0 .024 .122 r
.46173 .43598 .46687 .44138 .47592 .43847 .4708 .43313 Metetra
0 .025 .123 r
.4708 .43313 .47592 .43847 .485 .43575 .47989 .4306 Metetra
0 .026 .125 r
.47989 .4306 .485 .43575 .4941 .43312 .48901 .42825 Metetra
0 .028 .127 r
.48901 .42825 .4941 .43312 .50324 .43074 .49817 .4262 Metetra
0 .031 .131 r
.49817 .4262 .50324 .43074 .51241 .42856 .50736 .42449 Metetra
0 .035 .137 r
.50736 .42449 .51241 .42856 .52162 .42659 .51659 .42312 Metetra
0 .039 .141 r
.51659 .42312 .52162 .42659 .53086 .42391 .52585 .42134 Metetra
0 .045 .147 r
.52585 .42134 .53086 .42391 .54014 .42307 .53516 .42025 Metetra
0 .052 .155 r
.53516 .42025 .54014 .42307 .54946 .42125 .54451 .4191 Metetra
0 .058 .16 r
.54451 .4191 .54946 .42125 .55882 .41897 .5539 .41728 Metetra
0 .061 .164 r
.5539 .41728 .55882 .41897 .5682 .41641 .56332 .41499 Metetra
0 .063 .165 r
.56332 .41499 .5682 .41641 .57762 .41346 .57277 .41211 Metetra
0 .062 .164 r
.57277 .41211 .57762 .41346 .58705 .40998 .58224 .40835 Metetra
0 .059 .161 r
.58224 .40835 .58705 .40998 .59651 .40619 .59173 .40412 Metetra
0 .054 .156 r
.59173 .40412 .59651 .40619 .60599 .402 .60122 .39922 Metetra
0 .046 .149 r
.60122 .39922 .60599 .402 .61548 .39732 .61072 .39341 Metetra
0 .04 .142 r
.61072 .39341 .61548 .39732 .62501 .3929 .62029 .38975 Metetra
0 .036 .138 r
.62029 .38975 .62501 .3929 .63457 .38896 .62986 .38485 Metetra
0 .032 .133 r
.62986 .38485 .63457 .38896 .64416 .38494 .63946 .3803 Metetra
0 .029 .128 r
.63946 .3803 .64416 .38494 .65379 .38115 .64909 .37605 Metetra
0 .026 .125 r
.64909 .37605 .65379 .38115 .66346 .37761 .65877 .37213 Metetra
0 .025 .123 r
.65877 .37213 .66346 .37761 .67316 .3741 .66849 .36843 Metetra
0 .024 .122 r
.66849 .36843 .67316 .3741 .6829 .37089 .67825 .36505 Metetra
0 .024 .122 r
.67825 .36505 .6829 .37089 .69268 .36759 .68805 .36171 Metetra
0 .024 .122 r
.68805 .36171 .69268 .36759 .7025 .36442 .69789 .3585 Metetra
0 .024 .122 r
.69789 .3585 .7025 .36442 .71235 .36118 .70777 .35527 Metetra
0 .024 .122 r
.70777 .35527 .71235 .36118 .72223 .35795 .71768 .35201 Metetra
0 .024 .122 r
.71768 .35201 .72223 .35795 .73215 .35471 .72762 .34876 Metetra
0 .024 .122 r
.72762 .34876 .73215 .35471 .7421 .35147 .7376 .3455 Metetra
0 .024 .122 r
.7376 .3455 .7421 .35147 .75209 .34823 .74761 .34221 Metetra
0 .024 .122 r
.74761 .34221 .75209 .34823 .76212 .34494 .75765 .33887 Metetra
0 .023 .122 r
.75765 .33887 .76212 .34494 .77218 .34166 .76774 .33556 Metetra
0 .023 .122 r
.76774 .33556 .77218 .34166 .78227 .33838 .77786 .33225 Metetra
0 .024 .122 r
.77786 .33225 .78227 .33838 .7924 .33507 .78801 .32892 Metetra
0 .023 .122 r
.78801 .32892 .7924 .33507 .80256 .33174 .7982 .32558 Metetra
0 .023 .121 r
.7982 .32558 .80256 .33174 .81276 .3284 .80843 .32222 Metetra
0 .023 .121 r
.80843 .32222 .81276 .3284 .823 .32506 .81869 .31887 Metetra
0 .023 .122 r
.81869 .31887 .823 .32506 .83327 .32171 .82899 .3155 Metetra
0 .023 .122 r
.82899 .3155 .83327 .32171 .84358 .31835 .83932 .3121 Metetra
0 .023 .121 r
.83932 .3121 .84358 .31835 .85393 .31497 .8497 .3087 Metetra
0 .023 .121 r
.8497 .3087 .85393 .31497 .86431 .31157 .86011 .30528 Metetra
0 .023 .121 r
.86011 .30528 .86431 .31157 .87473 .30817 .87055 .30186 Metetra
0 .023 .121 r
.87055 .30186 .87473 .30817 .88519 .30475 .88104 .29842 Metetra
0 .023 .121 r
.28098 .48813 .28651 .49328 .295 .49049 .28949 .48533 Metetra
0 .023 .121 r
.28949 .48533 .295 .49049 .30352 .4877 .29803 .48252 Metetra
0 .023 .121 r
.29803 .48252 .30352 .4877 .31207 .4849 .30659 .47971 Metetra
0 .023 .121 r
.30659 .47971 .31207 .4849 .32064 .4821 .31518 .47689 Metetra
0 .023 .122 r
.31518 .47689 .32064 .4821 .32925 .47927 .3238 .47405 Metetra
0 .023 .122 r
.3238 .47405 .32925 .47927 .33788 .47646 .33245 .4712 Metetra
0 .023 .122 r
.33245 .4712 .33788 .47646 .34654 .47361 .34113 .46835 Metetra
0 .023 .122 r
.34113 .46835 .34654 .47361 .35522 .47077 .34983 .46551 Metetra
0 .023 .122 r
.34983 .46551 .35522 .47077 .36394 .4679 .35857 .4626 Metetra
0 .023 .121 r
.35857 .4626 .36394 .4679 .37269 .46504 .36733 .45972 Metetra
0 .023 .121 r
.36733 .45972 .37269 .46504 .38146 .46217 .37612 .45683 Metetra
0 .023 .122 r
.37612 .45683 .38146 .46217 .39026 .45929 .38494 .45394 Metetra
0 .024 .122 r
.38494 .45394 .39026 .45929 .39909 .45642 .39379 .45109 Metetra
0 .024 .122 r
.39379 .45109 .39909 .45642 .40795 .45354 .40266 .44823 Metetra
0 .024 .122 r
.40266 .44823 .40795 .45354 .41684 .45061 .41157 .4453 Metetra
0 .024 .122 r
.41157 .4453 .41684 .45061 .42576 .44769 .42051 .44236 Metetra
0 .024 .122 r
.42051 .44236 .42576 .44769 .43471 .44477 .42948 .43941 Metetra
0 .024 .122 r
.42948 .43941 .43471 .44477 .44369 .44183 .43848 .43642 Metetra
0 .024 .122 r
.43848 .43642 .44369 .44183 .4527 .43882 .4475 .43338 Metetra
0 .024 .122 r
.4475 .43338 .4527 .43882 .46173 .43598 .45656 .4306 Metetra
0 .024 .123 r
.45656 .4306 .46173 .43598 .4708 .43313 .46564 .42793 Metetra
0 .026 .124 r
.46564 .42793 .4708 .43313 .47989 .4306 .47475 .42559 Metetra
0 .028 .127 r
.47475 .42559 .47989 .4306 .48901 .42825 .48389 .42366 Metetra
0 .031 .132 r
.48389 .42366 .48901 .42825 .49817 .4262 .49306 .42216 Metetra
0 .036 .138 r
.49306 .42216 .49817 .4262 .50736 .42449 .50227 .42105 Metetra
0 .043 .146 r
.50227 .42105 .50736 .42449 .51659 .42312 .51151 .42029 Metetra
0 .051 .154 r
.51151 .42029 .51659 .42312 .52585 .42134 .52081 .42001 Metetra
0 .059 .161 r
.52081 .42001 .52585 .42134 .53516 .42025 .53014 .41796 Metetra
0 .067 .169 r
.53014 .41796 .53516 .42025 .54451 .4191 .53952 .41725 Metetra
0 .076 .177 r
.53952 .41725 .54451 .4191 .5539 .41728 .54895 .41594 Metetra
0 .082 .182 r
.54895 .41594 .5539 .41728 .56332 .41499 .5584 .414 Metetra
0 .086 .184 r
.5584 .414 .56332 .41499 .57277 .41211 .56789 .41121 Metetra
0 .084 .183 r
.56789 .41121 .57277 .41211 .58224 .40835 .57739 .40707 Metetra
0 .078 .178 r
.57739 .40707 .58224 .40835 .59173 .40412 .5869 .40229 Metetra
0 .07 .171 r
.5869 .40229 .59173 .40412 .60122 .39922 .59642 .39674 Metetra
0 .061 .163 r
.59642 .39674 .60122 .39922 .61072 .39341 .606 .39309 Metetra
0 .053 .156 r
.606 .39309 .61072 .39341 .62029 .38975 .61555 .38688 Metetra
0 .045 .148 r
.61555 .38688 .62029 .38975 .62986 .38485 .62513 .38136 Metetra
0 .038 .14 r
.62513 .38136 .62986 .38485 .63946 .3803 .63474 .37616 Metetra
0 .033 .133 r
.63474 .37616 .63946 .3803 .64909 .37605 .64438 .37125 Metetra
0 .029 .128 r
.64438 .37125 .64909 .37605 .65877 .37213 .65407 .36687 Metetra
0 .026 .125 r
.65407 .36687 .65877 .37213 .66849 .36843 .6638 .3629 Metetra
0 .025 .123 r
.6638 .3629 .66849 .36843 .67825 .36505 .67358 .35927 Metetra
0 .024 .122 r
.67358 .35927 .67825 .36505 .68805 .36171 .6834 .35579 Metetra
0 .024 .122 r
.6834 .35579 .68805 .36171 .69789 .3585 .69326 .35254 Metetra
0 .024 .122 r
.69326 .35254 .69789 .3585 .70777 .35527 .70316 .34934 Metetra
0 .024 .122 r
.70316 .34934 .70777 .35527 .71768 .35201 .71309 .34608 Metetra
0 .024 .122 r
.71309 .34608 .71768 .35201 .72762 .34876 .72306 .3428 Metetra
0 .024 .122 r
.72306 .3428 .72762 .34876 .7376 .3455 .73306 .33951 Metetra
0 .024 .122 r
.73306 .33951 .7376 .3455 .74761 .34221 .7431 .33616 Metetra
0 .024 .122 r
.7431 .33616 .74761 .34221 .75765 .33887 .75316 .33276 Metetra
0 .023 .122 r
.75316 .33276 .75765 .33887 .76774 .33556 .76327 .32944 Metetra
0 .023 .121 r
.76327 .32944 .76774 .33556 .77786 .33225 .77342 .32609 Metetra
0 .023 .121 r
.77342 .32609 .77786 .33225 .78801 .32892 .7836 .32274 Metetra
0 .023 .122 r
.7836 .32274 .78801 .32892 .7982 .32558 .79381 .3194 Metetra
0 .023 .122 r
.79381 .3194 .7982 .32558 .80843 .32222 .80407 .31604 Metetra
0 .023 .122 r
.80407 .31604 .80843 .32222 .81869 .31887 .81435 .31262 Metetra
0 .023 .122 r
.81435 .31262 .81869 .31887 .82899 .3155 .82468 .30924 Metetra
0 .023 .122 r
.82468 .30924 .82899 .3155 .83932 .3121 .83504 .30581 Metetra
0 .023 .121 r
.83504 .30581 .83932 .3121 .8497 .3087 .84544 .30239 Metetra
0 .023 .121 r
.84544 .30239 .8497 .3087 .86011 .30528 .85587 .29895 Metetra
0 .023 .121 r
.85587 .29895 .86011 .30528 .87055 .30186 .86635 .2955 Metetra
0 .023 .121 r
.86635 .2955 .87055 .30186 .88104 .29842 .87686 .29204 Metetra
0 .023 .121 r
.27542 .48296 .28098 .48813 .28949 .48533 .28395 .48014 Metetra
0 .023 .121 r
.28395 .48014 .28949 .48533 .29803 .48252 .2925 .47732 Metetra
0 .023 .121 r
.2925 .47732 .29803 .48252 .30659 .47971 .30108 .47448 Metetra
0 .023 .121 r
.30108 .47448 .30659 .47971 .31518 .47689 .30969 .47164 Metetra
0 .023 .122 r
.30969 .47164 .31518 .47689 .3238 .47405 .31833 .4688 Metetra
0 .023 .122 r
.31833 .4688 .3238 .47405 .33245 .4712 .32699 .46595 Metetra
0 .023 .122 r
.32699 .46595 .33245 .4712 .34113 .46835 .33569 .46307 Metetra
0 .023 .122 r
.33569 .46307 .34113 .46835 .34983 .46551 .34441 .46017 Metetra
0 .024 .122 r
.34441 .46017 .34983 .46551 .35857 .4626 .35316 .45732 Metetra
0 .024 .122 r
.35316 .45732 .35857 .4626 .36733 .45972 .36194 .45441 Metetra
0 .024 .122 r
.36194 .45441 .36733 .45972 .37612 .45683 .37075 .45155 Metetra
0 .024 .122 r
.37075 .45155 .37612 .45683 .38494 .45394 .37958 .44877 Metetra
0 .024 .122 r
.37958 .44877 .38494 .45394 .39379 .45109 .38844 .44589 Metetra
0 .024 .122 r
.38844 .44589 .39379 .45109 .40266 .44823 .39734 .44287 Metetra
0 .024 .122 r
.39734 .44287 .40266 .44823 .41157 .4453 .40627 .43985 Metetra
0 .024 .122 r
.40627 .43985 .41157 .4453 .42051 .44236 .41523 .43687 Metetra
0 .024 .122 r
.41523 .43687 .42051 .44236 .42948 .43941 .42422 .43395 Metetra
0 .024 .122 r
.42422 .43395 .42948 .43941 .43848 .43642 .43323 .43101 Metetra
0 .024 .122 r
.43323 .43101 .43848 .43642 .4475 .43338 .44228 .428 Metetra
0 .024 .122 r
.44228 .428 .4475 .43338 .45656 .4306 .45136 .42503 Metetra
0 .025 .124 r
.45136 .42503 .45656 .4306 .46564 .42793 .46045 .42273 Metetra
0 .027 .126 r
.46045 .42273 .46564 .42793 .47475 .42559 .46957 .4208 Metetra
0 .031 .131 r
.46957 .4208 .47475 .42559 .48389 .42366 .47872 .41939 Metetra
0 .036 .138 r
.47872 .41939 .48389 .42366 .49306 .42216 .48791 .41847 Metetra
0 .044 .147 r
.48791 .41847 .49306 .42216 .50227 .42105 .49713 .41805 Metetra
0 .055 .157 r
.49713 .41805 .50227 .42105 .51151 .42029 .5064 .41805 Metetra
0 .067 .169 r
.5064 .41805 .51151 .42029 .52081 .42001 .51572 .41812 Metetra
0 .081 .18 r
.51572 .41812 .52081 .42001 .53014 .41796 .52508 .41908 Metetra
0 .093 .19 r
.52508 .41908 .53014 .41796 .53952 .41725 .5345 .41737 Metetra
0 .103 .197 r
.5345 .41737 .53952 .41725 .54895 .41594 .54395 .41586 Metetra
0 .111 .203 r
.54395 .41586 .54895 .41594 .5584 .414 .55345 .41406 Metetra
0 .116 .206 r
.55345 .41406 .5584 .414 .56789 .41121 .56297 .41139 Metetra
0 .113 .205 r
.56297 .41139 .56789 .41121 .57739 .40707 .57251 .40705 Metetra
0 .105 .199 r
.57251 .40705 .57739 .40707 .5869 .40229 .58207 .40243 Metetra
0 .096 .192 r
.58207 .40243 .5869 .40229 .59642 .39674 .59166 .39824 Metetra
0 .085 .183 r
.59166 .39824 .59642 .39674 .606 .39309 .6012 .39068 Metetra
0 .071 .172 r
.6012 .39068 .606 .39309 .61555 .38688 .61078 .38448 Metetra
0 .057 .16 r
.61078 .38448 .61555 .38688 .62513 .38136 .62037 .37824 Metetra
0 .047 .149 r
.62037 .37824 .62513 .38136 .63474 .37616 .62999 .37229 Metetra
0 .038 .14 r
.62999 .37229 .63474 .37616 .64438 .37125 .63964 .36674 Metetra
0 .032 .133 r
.63964 .36674 .64438 .37125 .65407 .36687 .64934 .36182 Metetra
0 .028 .127 r
.64934 .36182 .65407 .36687 .6638 .3629 .65908 .35734 Metetra
0 .025 .124 r
.65908 .35734 .6638 .3629 .67358 .35927 .66887 .35331 Metetra
0 .024 .122 r
.66887 .35331 .67358 .35927 .6834 .35579 .67871 .34984 Metetra
0 .024 .122 r
.67871 .34984 .6834 .35579 .69326 .35254 .6886 .34667 Metetra
0 .024 .122 r
.6886 .34667 .69326 .35254 .70316 .34934 .69852 .34336 Metetra
0 .024 .122 r
.69852 .34336 .70316 .34934 .71309 .34608 .70847 .34001 Metetra
0 .024 .122 r
.70847 .34001 .71309 .34608 .72306 .3428 .71847 .33671 Metetra
0 .024 .122 r
.71847 .33671 .72306 .3428 .73306 .33951 .7285 .33346 Metetra
0 .024 .122 r
.7285 .33346 .73306 .33951 .7431 .33616 .73856 .3302 Metetra
0 .024 .122 r
.73856 .3302 .7431 .33616 .75316 .33276 .74866 .32687 Metetra
0 .024 .122 r
.74866 .32687 .75316 .33276 .76327 .32944 .75879 .32338 Metetra
0 .024 .122 r
.75879 .32338 .76327 .32944 .77342 .32609 .76895 .31995 Metetra
0 .024 .122 r
.76895 .31995 .77342 .32609 .7836 .32274 .77915 .31655 Metetra
0 .024 .122 r
.77915 .31655 .7836 .32274 .79381 .3194 .78939 .31315 Metetra
0 .024 .122 r
.78939 .31315 .79381 .3194 .80407 .31604 .79967 .30976 Metetra
0 .024 .122 r
.79967 .30976 .80407 .31604 .81435 .31262 .80999 .30636 Metetra
0 .024 .122 r
.80999 .30636 .81435 .31262 .82468 .30924 .82034 .30293 Metetra
0 .023 .122 r
.82034 .30293 .82468 .30924 .83504 .30581 .83073 .2995 Metetra
0 .023 .122 r
.83073 .2995 .83504 .30581 .84544 .30239 .84115 .29604 Metetra
0 .023 .121 r
.84115 .29604 .84544 .30239 .85587 .29895 .85162 .29258 Metetra
0 .023 .121 r
.85162 .29258 .85587 .29895 .86635 .2955 .86212 .28912 Metetra
0 .023 .121 r
.86212 .28912 .86635 .2955 .87686 .29204 .87266 .28563 Metetra
0 .023 .121 r
.26983 .47774 .27542 .48296 .28395 .48014 .27837 .47491 Metetra
0 .023 .121 r
.27837 .47491 .28395 .48014 .2925 .47732 .28694 .47207 Metetra
0 .023 .121 r
.28694 .47207 .2925 .47732 .30108 .47448 .29554 .46922 Metetra
0 .023 .121 r
.29554 .46922 .30108 .47448 .30969 .47164 .30416 .46636 Metetra
0 .023 .121 r
.30416 .46636 .30969 .47164 .31833 .4688 .31282 .46349 Metetra
0 .024 .122 r
.31282 .46349 .31833 .4688 .32699 .46595 .3215 .46063 Metetra
0 .024 .122 r
.3215 .46063 .32699 .46595 .33569 .46307 .33021 .45774 Metetra
0 .023 .122 r
.33021 .45774 .33569 .46307 .34441 .46017 .33895 .45483 Metetra
0 .024 .122 r
.33895 .45483 .34441 .46017 .35316 .45732 .34772 .45201 Metetra
0 .024 .122 r
.34772 .45201 .35316 .45732 .36194 .45441 .35649 .44962 Metetra
0 .024 .123 r
.35649 .44962 .36194 .45441 .37075 .45155 .36533 .44638 Metetra
0 .025 .123 r
.36533 .44638 .37075 .45155 .37958 .44877 .37417 .44394 Metetra
0 .025 .124 r
.37417 .44394 .37958 .44877 .38844 .44589 .38305 .44118 Metetra
0 .025 .124 r
.38305 .44118 .38844 .44589 .39734 .44287 .39197 .43801 Metetra
0 .025 .123 r
.39197 .43801 .39734 .44287 .40627 .43985 .40093 .43487 Metetra
0 .025 .123 r
.40093 .43487 .40627 .43985 .41523 .43687 .4099 .43186 Metetra
0 .025 .123 r
.4099 .43186 .41523 .43687 .42422 .43395 .41891 .42899 Metetra
0 .025 .124 r
.41891 .42899 .42422 .43395 .43323 .43101 .42793 .42629 Metetra
0 .026 .124 r
.42793 .42629 .43323 .43101 .44228 .428 .43699 .42363 Metetra
0 .026 .125 r
.43699 .42363 .44228 .428 .45136 .42503 .44609 .42049 Metetra
0 .026 .125 r
.44609 .42049 .45136 .42503 .46045 .42273 .45523 .41709 Metetra
0 .028 .128 r
.45523 .41709 .46045 .42273 .46957 .4208 .46436 .41561 Metetra
0 .034 .136 r
.46436 .41561 .46957 .4208 .47872 .41939 .47351 .41536 Metetra
0 .043 .145 r
.47351 .41536 .47872 .41939 .48791 .41847 .48271 .41498 Metetra
0 .054 .157 r
.48271 .41498 .48791 .41847 .49713 .41805 .49195 .41522 Metetra
0 .069 .17 r
.49195 .41522 .49713 .41805 .5064 .41805 .50124 .41604 Metetra
0 .087 .185 r
.50124 .41604 .5064 .41805 .51572 .41812 .51058 .41697 Metetra
0 .107 .201 r
.51058 .41697 .51572 .41812 .52508 .41908 .51997 .41753 Metetra
0 .128 .215 r
.51997 .41753 .52508 .41908 .5345 .41737 .52942 .41887 Metetra
0 .145 .225 r
.52942 .41887 .5345 .41737 .54395 .41586 .53892 .41841 Metetra
0 .157 .232 r
.53892 .41841 .54395 .41586 .55345 .41406 .54846 .41687 Metetra
0 .164 .237 r
.54846 .41687 .55345 .41406 .56297 .41139 .55804 .41437 Metetra
0 .161 .235 r
.55804 .41437 .56297 .41139 .57251 .40705 .56762 .40971 Metetra
0 .15 .228 r
.56762 .40971 .57251 .40705 .58207 .40243 .57722 .40449 Metetra
0 .133 .218 r
.57722 .40449 .58207 .40243 .59166 .39824 .58677 .39606 Metetra
0 .112 .204 r
.58677 .39606 .59166 .39824 .6012 .39068 .59638 .38974 Metetra
0 .091 .188 r
.59638 .38974 .6012 .39068 .61078 .38448 .60598 .38252 Metetra
0 .073 .174 r
.60598 .38252 .61078 .38448 .62037 .37824 .61559 .3754 Metetra
0 .057 .16 r
.61559 .3754 .62037 .37824 .62999 .37229 .62522 .36873 Metetra
0 .045 .148 r
.62522 .36873 .62999 .37229 .63964 .36674 .63489 .36256 Metetra
0 .036 .138 r
.63489 .36256 .63964 .36674 .64934 .36182 .64458 .35664 Metetra
0 .03 .13 r
.64458 .35664 .64934 .36182 .65908 .35734 .65431 .3512 Metetra
0 .026 .125 r
.65431 .3512 .65908 .35734 .66887 .35331 .66416 .34806 Metetra
0 .026 .125 r
.66416 .34806 .66887 .35331 .67871 .34984 .67405 .34507 Metetra
0 .026 .124 r
.67405 .34507 .67871 .34984 .6886 .34667 .68395 .34149 Metetra
0 .025 .124 r
.68395 .34149 .6886 .34667 .69852 .34336 .69388 .33786 Metetra
0 .025 .123 r
.69388 .33786 .69852 .34336 .70847 .34001 .70385 .33439 Metetra
0 .025 .123 r
.70385 .33439 .70847 .34001 .71847 .33671 .71387 .33107 Metetra
0 .025 .123 r
.71387 .33107 .71847 .33671 .7285 .33346 .72393 .32787 Metetra
0 .025 .124 r
.72393 .32787 .7285 .33346 .73856 .3302 .73404 .32476 Metetra
0 .025 .124 r
.73404 .32476 .73856 .3302 .74866 .32687 .74416 .32137 Metetra
0 .025 .123 r
.74416 .32137 .74866 .32687 .75879 .32338 .75427 .31731 Metetra
0 .024 .123 r
.75427 .31731 .75879 .32338 .76895 .31995 .7645 .31434 Metetra
0 .024 .122 r
.7645 .31434 .76895 .31995 .77915 .31655 .77469 .31042 Metetra
0 .024 .122 r
.77469 .31042 .77915 .31655 .78939 .31315 .78495 .3069 Metetra
0 .024 .122 r
.78495 .3069 .78939 .31315 .79967 .30976 .79525 .30349 Metetra
0 .024 .122 r
.79525 .30349 .79967 .30976 .80999 .30636 .80559 .30003 Metetra
0 .024 .122 r
.80559 .30003 .80999 .30636 .82034 .30293 .81597 .29658 Metetra
0 .023 .122 r
.81597 .29658 .82034 .30293 .83073 .2995 .82638 .29311 Metetra
0 .023 .121 r
.82638 .29311 .83073 .2995 .84115 .29604 .83684 .28964 Metetra
0 .023 .121 r
.83684 .28964 .84115 .29604 .85162 .29258 .84733 .28616 Metetra
0 .023 .121 r
.84733 .28616 .85162 .29258 .86212 .28912 .85785 .28267 Metetra
0 .023 .121 r
.85785 .28267 .86212 .28912 .87266 .28563 .86842 .27916 Metetra
0 .023 .121 r
.2642 .47251 .26983 .47774 .27837 .47491 .27276 .46966 Metetra
0 .023 .121 r
.27276 .46966 .27837 .47491 .28694 .47207 .28135 .4668 Metetra
0 .023 .121 r
.28135 .4668 .28694 .47207 .29554 .46922 .28996 .46393 Metetra
0 .023 .121 r
.28996 .46393 .29554 .46922 .30416 .46636 .2986 .46106 Metetra
0 .023 .121 r
.2986 .46106 .30416 .46636 .31282 .46349 .30728 .45818 Metetra
0 .023 .122 r
.30728 .45818 .31282 .46349 .3215 .46063 .31598 .45528 Metetra
0 .024 .122 r
.31598 .45528 .3215 .46063 .33021 .45774 .32469 .45261 Metetra
0 .024 .122 r
.32469 .45261 .33021 .45774 .33895 .45483 .33344 .44981 Metetra
0 .024 .123 r
.33344 .44981 .33895 .45483 .34772 .45201 .34222 .44706 Metetra
0 .025 .123 r
.34222 .44706 .34772 .45201 .35649 .44962 .35103 .44415 Metetra
0 .025 .124 r
.35103 .44415 .35649 .44962 .36533 .44638 .35989 .44112 Metetra
0 .025 .124 r
.35989 .44112 .36533 .44638 .37417 .44394 .36876 .43819 Metetra
0 .026 .125 r
.36876 .43819 .37417 .44394 .38305 .44118 .37766 .43527 Metetra
0 .026 .125 r
.37766 .43527 .38305 .44118 .39197 .43801 .3866 .43223 Metetra
0 .025 .124 r
.3866 .43223 .39197 .43801 .40093 .43487 .39557 .42918 Metetra
0 .025 .124 r
.39557 .42918 .40093 .43487 .4099 .43186 .40456 .42618 Metetra
0 .025 .124 r
.40456 .42618 .4099 .43186 .41891 .42899 .41359 .42323 Metetra
0 .026 .125 r
.41359 .42323 .41891 .42899 .42793 .42629 .42264 .42039 Metetra
0 .027 .126 r
.42264 .42039 .42793 .42629 .43699 .42363 .43171 .41765 Metetra
0 .027 .127 r
.43171 .41765 .43699 .42363 .44609 .42049 .44082 .41511 Metetra
0 .028 .128 r
.44082 .41511 .44609 .42049 .45523 .41709 .44994 .41331 Metetra
0 .032 .132 r
.44994 .41331 .45523 .41709 .46436 .41561 .45909 .41187 Metetra
0 .038 .14 r
.45909 .41187 .46436 .41561 .47351 .41536 .46829 .40991 Metetra
0 .05 .152 r
.46829 .40991 .47351 .41536 .48271 .41498 .47747 .41193 Metetra
0 .066 .168 r
.47747 .41193 .48271 .41498 .49195 .41522 .48673 .41241 Metetra
0 .085 .184 r
.48673 .41241 .49195 .41522 .50124 .41604 .49603 .41409 Metetra
0 .11 .202 r
.49603 .41409 .50124 .41604 .51058 .41697 .50539 .4159 Metetra
0 .137 .221 r
.50539 .4159 .51058 .41697 .51997 .41753 .51481 .41767 Metetra
0 .168 .239 r
.51481 .41767 .51997 .41753 .52942 .41887 .52429 .41962 Metetra
0 .195 .254 r
.52429 .41962 .52942 .41887 .53892 .41841 .53383 .41859 Metetra
0 .214 .264 r
.53383 .41859 .53892 .41841 .54846 .41687 .54342 .41879 Metetra
0 .227 .271 r
.54342 .41879 .54846 .41687 .55804 .41437 .55304 .41668 Metetra
0 .221 .268 r
.55304 .41668 .55804 .41437 .56762 .40971 .56265 .41041 Metetra
0 .202 .258 r
.56265 .41041 .56762 .40971 .57722 .40449 .57228 .40424 Metetra
0 .174 .243 r
.57228 .40424 .57722 .40449 .58677 .39606 .5819 .39694 Metetra
0 .144 .225 r
.5819 .39694 .58677 .39606 .59638 .38974 .59152 .3888 Metetra
0 .116 .207 r
.59152 .3888 .59638 .38974 .60598 .38252 .60114 .38065 Metetra
0 .091 .188 r
.60114 .38065 .60598 .38252 .61559 .3754 .61076 .3725 Metetra
0 .071 .172 r
.61076 .3725 .61559 .3754 .62522 .36873 .62044 .36584 Metetra
0 .053 .156 r
.62044 .36584 .62522 .36873 .63489 .36256 .63005 .35707 Metetra
0 .04 .142 r
.63005 .35707 .63489 .36256 .64458 .35664 .6398 .35204 Metetra
0 .033 .134 r
.6398 .35204 .64458 .35664 .65431 .3512 .64959 .34738 Metetra
0 .029 .129 r
.64959 .34738 .65431 .3512 .66416 .34806 .6594 .34258 Metetra
0 .028 .127 r
.6594 .34258 .66416 .34806 .67405 .34507 .66928 .33866 Metetra
0 .027 .126 r
.66928 .33866 .67405 .34507 .68395 .34149 .6792 .33503 Metetra
0 .026 .125 r
.6792 .33503 .68395 .34149 .69388 .33786 .68916 .3315 Metetra
0 .025 .124 r
.68916 .3315 .69388 .33786 .70385 .33439 .69916 .32808 Metetra
0 .025 .124 r
.69916 .32808 .70385 .33439 .71387 .33107 .70921 .32473 Metetra
0 .025 .124 r
.70921 .32473 .71387 .33107 .72393 .32787 .71929 .32143 Metetra
0 .026 .124 r
.71929 .32143 .72393 .32787 .73404 .32476 .7294 .31813 Metetra
0 .026 .125 r
.7294 .31813 .73404 .32476 .74416 .32137 .73955 .31473 Metetra
0 .025 .124 r
.73955 .31473 .74416 .32137 .75427 .31731 .74973 .31127 Metetra
0 .025 .124 r
.74973 .31127 .75427 .31731 .7645 .31434 .75996 .30801 Metetra
0 .025 .123 r
.75996 .30801 .7645 .31434 .77469 .31042 .7702 .30426 Metetra
0 .024 .123 r
.7702 .30426 .77469 .31042 .78495 .3069 .78053 .30128 Metetra
0 .024 .123 r
.78053 .30128 .78495 .3069 .79525 .30349 .79084 .29755 Metetra
0 .024 .122 r
.79084 .29755 .79525 .30349 .80559 .30003 .80117 .29373 Metetra
0 .024 .122 r
.80117 .29373 .80559 .30003 .81597 .29658 .81157 .2902 Metetra
0 .023 .122 r
.81157 .2902 .81597 .29658 .82638 .29311 .82201 .28671 Metetra
0 .023 .121 r
.82201 .28671 .82638 .29311 .83684 .28964 .83249 .28321 Metetra
0 .023 .121 r
.83249 .28321 .83684 .28964 .84733 .28616 .84301 .27971 Metetra
0 .023 .121 r
.84301 .27971 .84733 .28616 .85785 .28267 .85356 .27619 Metetra
0 .023 .121 r
.85356 .27619 .85785 .28267 .86842 .27916 .86416 .27266 Metetra
0 .023 .121 r
.25854 .46724 .2642 .47251 .27276 .46966 .26712 .46438 Metetra
0 .023 .121 r
.26712 .46438 .27276 .46966 .28135 .4668 .27572 .46151 Metetra
0 .023 .122 r
.27572 .46151 .28135 .4668 .28996 .46393 .28435 .45863 Metetra
0 .024 .122 r
.28435 .45863 .28996 .46393 .2986 .46106 .29301 .45575 Metetra
0 .024 .122 r
.29301 .45575 .2986 .46106 .30728 .45818 .30169 .45296 Metetra
0 .024 .122 r
.30169 .45296 .30728 .45818 .31598 .45528 .31039 .45036 Metetra
0 .024 .123 r
.31039 .45036 .31598 .45528 .32469 .45261 .31913 .44749 Metetra
0 .025 .123 r
.31913 .44749 .32469 .45261 .33344 .44981 .32792 .44428 Metetra
0 .025 .123 r
.32792 .44428 .33344 .44981 .34222 .44706 .33673 .44128 Metetra
0 .025 .124 r
.33673 .44128 .34222 .44706 .35103 .44415 .34554 .43872 Metetra
0 .025 .124 r
.34554 .43872 .35103 .44415 .35989 .44112 .35441 .43565 Metetra
0 .025 .123 r
.35441 .43565 .35989 .44112 .36876 .43819 .36331 .43258 Metetra
0 .025 .123 r
.36331 .43258 .36876 .43819 .37766 .43527 .37224 .4296 Metetra
0 .025 .123 r
.37224 .4296 .37766 .43527 .3866 .43223 .38119 .42658 Metetra
0 .025 .123 r
.38119 .42658 .3866 .43223 .39557 .42918 .39018 .42354 Metetra
0 .025 .123 r
.39018 .42354 .39557 .42918 .40456 .42618 .39919 .42053 Metetra
0 .025 .123 r
.39919 .42053 .40456 .42618 .41359 .42323 .40823 .41755 Metetra
0 .025 .124 r
.40823 .41755 .41359 .42323 .42264 .42039 .4173 .41468 Metetra
0 .026 .125 r
.4173 .41468 .42264 .42039 .43171 .41765 .42639 .41199 Metetra
0 .027 .127 r
.42639 .41199 .43171 .41765 .44082 .41511 .43551 .4097 Metetra
0 .031 .131 r
.43551 .4097 .44082 .41511 .44994 .41331 .44464 .40822 Metetra
0 .037 .138 r
.44464 .40822 .44994 .41331 .45909 .41187 .4538 .40734 Metetra
0 .044 .146 r
.4538 .40734 .45909 .41187 .46829 .40991 .46299 .40695 Metetra
0 .056 .159 r
.46299 .40695 .46829 .40991 .47747 .41193 .47222 .40702 Metetra
0 .078 .178 r
.47222 .40702 .47747 .41193 .48673 .41241 .48146 .41016 Metetra
0 .103 .198 r
.48146 .41016 .48673 .41241 .49603 .41409 .49079 .41134 Metetra
0 .135 .219 r
.49079 .41134 .49603 .41409 .50539 .4159 .50016 .41497 Metetra
0 .174 .243 r
.50016 .41497 .50539 .4159 .51481 .41767 .5096 .41776 Metetra
0 .216 .265 r
.5096 .41776 .51481 .41767 .52429 .41962 .51911 .42058 Metetra
0 .258 .285 r
.51911 .42058 .52429 .41962 .53383 .41859 .52869 .4241 Metetra
0 .296 .302 r
.52869 .4241 .53383 .41859 .54342 .41879 .53833 .4254 Metetra
0 .313 .306 r
.53833 .4254 .54342 .41879 .55304 .41668 .54801 .42368 Metetra
0 .308 .308 r
.54801 .42368 .55304 .41668 .56265 .41041 .55768 .41651 Metetra
0 .268 .29 r
.55768 .41651 .56265 .41041 .57228 .40424 .56732 .40608 Metetra
0 .225 .27 r
.56732 .40608 .57228 .40424 .5819 .39694 .57697 .39728 Metetra
0 .184 .248 r
.57697 .39728 .5819 .39694 .59152 .3888 .58661 .38785 Metetra
0 .144 .225 r
.58661 .38785 .59152 .3888 .60114 .38065 .59623 .37785 Metetra
0 .112 .203 r
.59623 .37785 .60114 .38065 .61076 .3725 .60593 .37095 Metetra
0 .085 .183 r
.60593 .37095 .61076 .3725 .62044 .36584 .61553 .36036 Metetra
0 .061 .163 r
.61553 .36036 .62044 .36584 .63005 .35707 .62525 .35382 Metetra
0 .046 .149 r
.62525 .35382 .63005 .35707 .6398 .35204 .635 .34754 Metetra
0 .038 .14 r
.635 .34754 .6398 .35204 .64959 .34738 .64478 .34197 Metetra
0 .032 .133 r
.64478 .34197 .64959 .34738 .6594 .34258 .65461 .33682 Metetra
0 .028 .128 r
.65461 .33682 .6594 .34258 .66928 .33866 .6645 .33256 Metetra
0 .026 .125 r
.6645 .33256 .66928 .33866 .6792 .33503 .67444 .32878 Metetra
0 .025 .124 r
.67444 .32878 .6792 .33503 .68916 .3315 .68442 .32524 Metetra
0 .025 .123 r
.68442 .32524 .68916 .3315 .69916 .32808 .69445 .32181 Metetra
0 .025 .123 r
.69445 .32181 .69916 .32808 .70921 .32473 .70452 .31843 Metetra
0 .025 .123 r
.70452 .31843 .70921 .32473 .71929 .32143 .71462 .31508 Metetra
0 .025 .123 r
.71462 .31508 .71929 .32143 .7294 .31813 .72476 .31172 Metetra
0 .025 .123 r
.72476 .31172 .7294 .31813 .73955 .31473 .73493 .30832 Metetra
0 .025 .123 r
.73493 .30832 .73955 .31473 .74973 .31127 .74515 .30495 Metetra
0 .025 .124 r
.74515 .30495 .74973 .31127 .75996 .30801 .7554 .30169 Metetra
0 .025 .123 r
.7554 .30169 .75996 .30801 .7702 .30426 .76567 .29795 Metetra
0 .025 .123 r
.76567 .29795 .7702 .30426 .78053 .30128 .77597 .29427 Metetra
0 .025 .124 r
.77597 .29427 .78053 .30128 .79084 .29755 .78638 .29152 Metetra
0 .025 .124 r
.78638 .29152 .79084 .29755 .80117 .29373 .79678 .28808 Metetra
0 .024 .123 r
.79678 .28808 .80117 .29373 .81157 .2902 .80717 .28405 Metetra
0 .024 .122 r
.80717 .28405 .81157 .2902 .82201 .28671 .81762 .2803 Metetra
0 .024 .122 r
.81762 .2803 .82201 .28671 .83249 .28321 .82812 .27675 Metetra
0 .023 .122 r
.82812 .27675 .83249 .28321 .84301 .27971 .83866 .27322 Metetra
0 .023 .122 r
.83866 .27322 .84301 .27971 .85356 .27619 .84925 .26968 Metetra
0 .023 .122 r
.84925 .26968 .85356 .27619 .86416 .27266 .85987 .26613 Metetra
0 .024 .122 r
.25284 .46197 .25854 .46724 .26712 .46438 .26144 .45909 Metetra
0 .024 .122 r
.26144 .45909 .26712 .46438 .27572 .46151 .27005 .45621 Metetra
0 .024 .122 r
.27005 .45621 .27572 .46151 .28435 .45863 .2787 .45337 Metetra
0 .024 .122 r
.2787 .45337 .28435 .45863 .29301 .45575 .28734 .45089 Metetra
0 .024 .123 r
.28734 .45089 .29301 .45575 .30169 .45296 .29606 .44784 Metetra
0 .024 .123 r
.29606 .44784 .30169 .45296 .31039 .45036 .30482 .4446 Metetra
0 .025 .123 r
.30482 .4446 .31039 .45036 .31913 .44749 .31355 .44211 Metetra
0 .025 .123 r
.31355 .44211 .31913 .44749 .32792 .44428 .32238 .43867 Metetra
0 .024 .122 r
.32238 .43867 .32792 .44428 .33673 .44128 .33118 .43601 Metetra
0 .025 .123 r
.33118 .43601 .33673 .44128 .34554 .43872 .34002 .43319 Metetra
0 .025 .124 r
.34002 .43319 .34554 .43872 .35441 .43565 .34891 .43007 Metetra
0 .025 .123 r
.34891 .43007 .35441 .43565 .36331 .43258 .35783 .427 Metetra
0 .025 .123 r
.35783 .427 .36331 .43258 .37224 .4296 .36677 .424 Metetra
0 .025 .123 r
.36677 .424 .37224 .4296 .38119 .42658 .37574 .42097 Metetra
0 .024 .123 r
.37574 .42097 .38119 .42658 .39018 .42354 .38475 .41793 Metetra
0 .024 .123 r
.38475 .41793 .39018 .42354 .39919 .42053 .39378 .41489 Metetra
0 .024 .123 r
.39378 .41489 .39919 .42053 .40823 .41755 .40284 .4119 Metetra
0 .025 .123 r
.40284 .4119 .40823 .41755 .4173 .41468 .41193 .40902 Metetra
0 .026 .125 r
.41193 .40902 .4173 .41468 .42639 .41199 .42104 .40638 Metetra
0 .028 .127 r
.42104 .40638 .42639 .41199 .43551 .4097 .43017 .40422 Metetra
0 .032 .133 r
.43017 .40422 .43551 .4097 .44464 .40822 .43931 .40294 Metetra
0 .039 .141 r
.43931 .40294 .44464 .40822 .4538 .40734 .44848 .40249 Metetra
0 .05 .153 r
.44848 .40249 .4538 .40734 .46299 .40695 .45767 .40281 Metetra
0 .065 .167 r
.45767 .40281 .46299 .40695 .47222 .40702 .46691 .40355 Metetra
0 .088 .186 r
.46691 .40355 .47222 .40702 .48146 .41016 .47618 .40563 Metetra
0 .122 .21 r
.47618 .40563 .48146 .41016 .49079 .41134 .48548 .41024 Metetra
0 .16 .235 r
.48548 .41024 .49079 .41134 .50016 .41497 .49489 .41163 Metetra
0 .21 .262 r
.49489 .41163 .50016 .41497 .5096 .41776 .50434 .41745 Metetra
0 .273 .292 r
.50434 .41745 .5096 .41776 .51911 .42058 .51386 .42316 Metetra
0 .325 .301 r
.51386 .42316 .51911 .42058 .52869 .4241 .52348 .43002 Metetra
0 .353 .284 r
.52348 .43002 .52869 .4241 .53833 .4254 .53318 .43367 Metetra
0 .368 .271 r
.53318 .43367 .53833 .4254 .54801 .42368 .54293 .43311 Metetra
0 .361 .277 r
.54293 .43311 .54801 .42368 .55768 .41651 .55264 .42297 Metetra
0 .332 .297 r
.55264 .42297 .55768 .41651 .56732 .40608 .56232 .40951 Metetra
0 .288 .299 r
.56232 .40951 .56732 .40608 .57697 .39728 .57197 .39698 Metetra
0 .225 .27 r
.57197 .39698 .57697 .39728 .58661 .38785 .58164 .38597 Metetra
0 .174 .243 r
.58164 .38597 .58661 .38785 .59623 .37785 .59133 .37721 Metetra
0 .133 .218 r
.59133 .37721 .59623 .37785 .60593 .37095 .60097 .36599 Metetra
0 .096 .192 r
.60097 .36599 .60593 .37095 .61553 .36036 .61065 .3568 Metetra
0 .07 .171 r
.61065 .3568 .61553 .36036 .62525 .35382 .62039 .34956 Metetra
0 .054 .156 r
.62039 .34956 .62525 .35382 .635 .34754 .63014 .34256 Metetra
0 .042 .144 r
.63014 .34256 .635 .34754 .64478 .34197 .63994 .33639 Metetra
0 .034 .135 r
.63994 .33639 .64478 .34197 .65461 .33682 .64978 .33097 Metetra
0 .029 .128 r
.64978 .33097 .65461 .33682 .6645 .33256 .65969 .3265 Metetra
0 .026 .125 r
.65969 .3265 .6645 .33256 .67444 .32878 .66965 .32262 Metetra
0 .025 .124 r
.66965 .32262 .67444 .32878 .68442 .32524 .67966 .31902 Metetra
0 .025 .123 r
.67966 .31902 .68442 .32524 .69445 .32181 .68971 .31555 Metetra
0 .024 .123 r
.68971 .31555 .69445 .32181 .70452 .31843 .6998 .31215 Metetra
0 .024 .123 r
.6998 .31215 .70452 .31843 .71462 .31508 .70992 .30877 Metetra
0 .025 .123 r
.70992 .30877 .71462 .31508 .72476 .31172 .72009 .30538 Metetra
0 .025 .123 r
.72009 .30538 .72476 .31172 .73493 .30832 .73029 .30195 Metetra
0 .025 .123 r
.73029 .30195 .73493 .30832 .74515 .30495 .74053 .29855 Metetra
0 .025 .124 r
.74053 .29855 .74515 .30495 .7554 .30169 .75081 .29527 Metetra
0 .025 .124 r
.75081 .29527 .7554 .30169 .76567 .29795 .76111 .29171 Metetra
0 .024 .123 r
.76111 .29171 .76567 .29795 .77597 .29427 .77144 .288 Metetra
0 .025 .123 r
.77144 .288 .77597 .29427 .78638 .29152 .78185 .28481 Metetra
0 .025 .124 r
.78185 .28481 .78638 .29152 .79678 .28808 .79224 .28096 Metetra
0 .025 .123 r
.79224 .28096 .79678 .28808 .80717 .28405 .80274 .27791 Metetra
0 .024 .123 r
.80274 .27791 .80717 .28405 .81762 .2803 .81322 .27414 Metetra
0 .024 .122 r
.81322 .27414 .81762 .2803 .82812 .27675 .82374 .27043 Metetra
0 .024 .122 r
.82374 .27043 .82812 .27675 .83866 .27322 .83429 .26674 Metetra
0 .024 .122 r
.83429 .26674 .83866 .27322 .84925 .26968 .8449 .26314 Metetra
0 .024 .122 r
.8449 .26314 .84925 .26968 .85987 .26613 .85555 .25956 Metetra
0 .024 .122 r
.2471 .45675 .25284 .46197 .26144 .45909 .25571 .45383 Metetra
0 .024 .122 r
.25571 .45383 .26144 .45909 .27005 .45621 .26435 .45093 Metetra
0 .024 .122 r
.26435 .45093 .27005 .45621 .2787 .45337 .27299 .4483 Metetra
0 .025 .123 r
.27299 .4483 .2787 .45337 .28734 .45089 .28168 .44556 Metetra
0 .025 .124 r
.28168 .44556 .28734 .45089 .29606 .44784 .29042 .44241 Metetra
0 .024 .123 r
.29042 .44241 .29606 .44784 .30482 .4446 .29918 .43937 Metetra
0 .025 .123 r
.29918 .43937 .30482 .4446 .31355 .44211 .30795 .43652 Metetra
0 .024 .123 r
.30795 .43652 .31355 .44211 .32238 .43867 .31678 .4333 Metetra
0 .024 .123 r
.31678 .4333 .32238 .43867 .33118 .43601 .3256 .43054 Metetra
0 .025 .123 r
.3256 .43054 .33118 .43601 .34002 .43319 .33447 .42761 Metetra
0 .025 .123 r
.33447 .42761 .34002 .43319 .34891 .43007 .34338 .42449 Metetra
0 .025 .123 r
.34338 .42449 .34891 .43007 .35783 .427 .35231 .42142 Metetra
0 .024 .123 r
.35231 .42142 .35783 .427 .36677 .424 .36127 .4184 Metetra
0 .024 .123 r
.36127 .4184 .36677 .424 .37574 .42097 .37026 .41536 Metetra
0 .024 .123 r
.37026 .41536 .37574 .42097 .38475 .41793 .37928 .41231 Metetra
0 .024 .123 r
.37928 .41231 .38475 .41793 .39378 .41489 .38833 .40927 Metetra
0 .024 .123 r
.38833 .40927 .39378 .41489 .40284 .4119 .39741 .40627 Metetra
0 .025 .123 r
.39741 .40627 .40284 .4119 .41193 .40902 .40652 .40341 Metetra
0 .026 .125 r
.40652 .40341 .41193 .40902 .42104 .40638 .41565 .40082 Metetra
0 .028 .128 r
.41565 .40082 .42104 .40638 .43017 .40422 .42479 .39877 Metetra
0 .033 .134 r
.42479 .39877 .43017 .40422 .43931 .40294 .43395 .39764 Metetra
0 .042 .144 r
.43395 .39764 .43931 .40294 .44848 .40249 .44312 .39747 Metetra
0 .055 .157 r
.44312 .39747 .44848 .40249 .45767 .40281 .45232 .39821 Metetra
0 .073 .174 r
.45232 .39821 .45767 .40281 .46691 .40355 .46156 .3995 Metetra
0 .097 .193 r
.46156 .3995 .46691 .40355 .47618 .40563 .47085 .40165 Metetra
0 .137 .22 r
.47085 .40165 .47618 .40563 .48548 .41024 .48017 .40631 Metetra
0 .185 .249 r
.48017 .40631 .48548 .41024 .49489 .41163 .48957 .41058 Metetra
0 .248 .281 r
.48957 .41058 .49489 .41163 .50434 .41745 .49902 .41761 Metetra
0 .32 .303 r
.49902 .41761 .50434 .41745 .51386 .42316 .50856 .42476 Metetra
0 .367 .273 r
.50856 .42476 .51386 .42316 .52348 .43002 .51819 .43834 Metetra
0 .421 .214 r
.51819 .43834 .52348 .43002 .53318 .43367 .52796 .45535 Metetra
0 .458 .16 r
.52796 .45535 .53318 .43367 .54293 .43311 .53783 .45981 Metetra
0 .44 .188 r
.53783 .45981 .54293 .43311 .55264 .42297 .54757 .43479 Metetra
0 .383 .258 r
.54757 .43479 .55264 .42297 .56232 .40951 .55726 .41384 Metetra
0 .332 .297 r
.55726 .41384 .56232 .40951 .57197 .39698 .56695 .39831 Metetra
0 .268 .29 r
.56695 .39831 .57197 .39698 .58164 .38597 .57661 .3831 Metetra
0 .202 .258 r
.57661 .3831 .58164 .38597 .59133 .37721 .58632 .37325 Metetra
0 .149 .228 r
.58632 .37325 .59133 .37721 .60097 .36599 .59599 .36147 Metetra
0 .105 .199 r
.59599 .36147 .60097 .36599 .61065 .3568 .60571 .35242 Metetra
0 .078 .178 r
.60571 .35242 .61065 .3568 .62039 .34956 .61547 .34461 Metetra
0 .059 .161 r
.61547 .34461 .62039 .34956 .63014 .34256 .62524 .33715 Metetra
0 .045 .147 r
.62524 .33715 .63014 .34256 .63994 .33639 .63505 .33063 Metetra
0 .035 .136 r
.63505 .33063 .63994 .33639 .64978 .33097 .64492 .32502 Metetra
0 .029 .129 r
.64492 .32502 .64978 .33097 .65969 .3265 .65485 .3204 Metetra
0 .026 .125 r
.65485 .3204 .65969 .3265 .66965 .32262 .66483 .31642 Metetra
0 .025 .124 r
.66483 .31642 .66965 .32262 .67966 .31902 .67486 .31277 Metetra
0 .025 .123 r
.67486 .31277 .67966 .31902 .68971 .31555 .68494 .30928 Metetra
0 .024 .123 r
.68494 .30928 .68971 .31555 .6998 .31215 .69505 .30585 Metetra
0 .024 .123 r
.69505 .30585 .6998 .31215 .70992 .30877 .7052 .30244 Metetra
0 .024 .123 r
.7052 .30244 .70992 .30877 .72009 .30538 .71539 .29901 Metetra
0 .024 .123 r
.71539 .29901 .72009 .30538 .73029 .30195 .72561 .29556 Metetra
0 .025 .123 r
.72561 .29556 .73029 .30195 .74053 .29855 .73588 .29214 Metetra
0 .025 .123 r
.73588 .29214 .74053 .29855 .75081 .29527 .74618 .2888 Metetra
0 .025 .124 r
.74618 .2888 .75081 .29527 .76111 .29171 .75652 .28529 Metetra
0 .025 .123 r
.75652 .28529 .76111 .29171 .77144 .288 .76688 .28165 Metetra
0 .025 .123 r
.76688 .28165 .77144 .288 .78185 .28481 .77729 .27816 Metetra
0 .025 .123 r
.77729 .27816 .78185 .28481 .79224 .28096 .78776 .27482 Metetra
0 .025 .123 r
.78776 .27482 .79224 .28096 .80274 .27791 .79824 .27127 Metetra
0 .025 .124 r
.79824 .27127 .80274 .27791 .81322 .27414 .80878 .26789 Metetra
0 .025 .123 r
.80878 .26789 .81322 .27414 .82374 .27043 .81932 .26406 Metetra
0 .024 .123 r
.81932 .26406 .82374 .27043 .83429 .26674 .82992 .26047 Metetra
0 .024 .122 r
.82992 .26047 .83429 .26674 .8449 .26314 .84054 .25664 Metetra
0 .024 .122 r
.84054 .25664 .8449 .26314 .85555 .25956 .85121 .25296 Metetra
0 .024 .123 r
.24131 .45177 .2471 .45675 .25571 .45383 .24995 .44865 Metetra
0 .024 .123 r
.24995 .44865 .25571 .45383 .26435 .45093 .25858 .44596 Metetra
0 .025 .123 r
.25858 .44596 .26435 .45093 .27299 .4483 .26728 .44287 Metetra
0 .025 .124 r
.26728 .44287 .27299 .4483 .28168 .44556 .27598 .44015 Metetra
0 .025 .124 r
.27598 .44015 .28168 .44556 .29042 .44241 .28472 .4371 Metetra
0 .025 .123 r
.28472 .4371 .29042 .44241 .29918 .43937 .2935 .43403 Metetra
0 .025 .123 r
.2935 .43403 .29918 .43937 .30795 .43652 .3023 .43102 Metetra
0 .025 .123 r
.3023 .43102 .30795 .43652 .31678 .4333 .31114 .42797 Metetra
0 .025 .123 r
.31114 .42797 .31678 .4333 .3256 .43054 .31999 .42513 Metetra
0 .025 .124 r
.31999 .42513 .3256 .43054 .33447 .42761 .32888 .42214 Metetra
0 .025 .123 r
.32888 .42214 .33447 .42761 .34338 .42449 .3378 .41904 Metetra
0 .025 .123 r
.3378 .41904 .34338 .42449 .35231 .42142 .34675 .41597 Metetra
0 .025 .123 r
.34675 .41597 .35231 .42142 .36127 .4184 .35573 .41295 Metetra
0 .025 .123 r
.35573 .41295 .36127 .4184 .37026 .41536 .36474 .40992 Metetra
0 .025 .123 r
.36474 .40992 .37026 .41536 .37928 .41231 .37378 .40687 Metetra
0 .025 .123 r
.37378 .40687 .37928 .41231 .38833 .40927 .38285 .40382 Metetra
0 .025 .123 r
.38285 .40382 .38833 .40927 .39741 .40627 .39194 .40079 Metetra
0 .025 .124 r
.39194 .40079 .39741 .40627 .40652 .40341 .40107 .39779 Metetra
0 .026 .125 r
.40107 .39779 .40652 .40341 .41565 .40082 .41023 .39491 Metetra
0 .028 .128 r
.41023 .39491 .41565 .40082 .42479 .39877 .4194 .39259 Metetra
0 .033 .133 r
.4194 .39259 .42479 .39877 .43395 .39764 .42857 .39131 Metetra
0 .042 .144 r
.42857 .39131 .43395 .39764 .44312 .39747 .43776 .39114 Metetra
0 .056 .158 r
.43776 .39114 .44312 .39747 .45232 .39821 .44697 .39198 Metetra
0 .075 .176 r
.44697 .39198 .45232 .39821 .46156 .3995 .45622 .39341 Metetra
0 .102 .196 r
.45622 .39341 .46156 .3995 .47085 .40165 .46552 .39557 Metetra
0 .142 .223 r
.46552 .39557 .47085 .40165 .48017 .40631 .47485 .40004 Metetra
0 .198 .256 r
.47485 .40004 .48017 .40631 .48957 .41058 .48424 .4053 Metetra
0 .273 .292 r
.48424 .4053 .48957 .41058 .49902 .41761 .4937 .41161 Metetra
0 .336 .295 r
.4937 .41161 .49902 .41761 .50856 .42476 .50324 .4214 Metetra
0 .403 .237 r
.50324 .4214 .50856 .42476 .51819 .43834 .51283 .44408 Metetra
0 .534 .011 r
.51283 .44408 .51819 .43834 .52796 .45535 .52259 .51079 Metetra
.449 .689 0 r
.52259 .51079 .52796 .45535 .53783 .45981 .53278 .57109 Metetra
.227 .623 0 r
.53278 .57109 .53783 .45981 .54757 .43479 .54243 .45069 Metetra
0 .439 .189 r
.54243 .45069 .54757 .43479 .55726 .41384 .55212 .41487 Metetra
0 .361 .278 r
.55212 .41487 .55726 .41384 .56695 .39831 .56184 .39632 Metetra
0 .308 .308 r
.56184 .39632 .56695 .39831 .57661 .3831 .57153 .38024 Metetra
0 .221 .268 r
.57153 .38024 .57661 .3831 .58632 .37325 .58126 .36873 Metetra
0 .16 .235 r
.58126 .36873 .58632 .37325 .59599 .36147 .59097 .35663 Metetra
0 .113 .205 r
.59097 .35663 .59599 .36147 .60571 .35242 .60072 .34737 Metetra
0 .084 .183 r
.60072 .34737 .60571 .35242 .61547 .34461 .6105 .33915 Metetra
0 .062 .164 r
.6105 .33915 .61547 .34461 .62524 .33715 .62029 .3314 Metetra
0 .046 .149 r
.62029 .3314 .62524 .33715 .63505 .33063 .63013 .32466 Metetra
0 .036 .137 r
.63013 .32466 .63505 .33063 .64492 .32502 .64002 .31891 Metetra
0 .03 .13 r
.64002 .31891 .64492 .32502 .65485 .3204 .64997 .3142 Metetra
0 .027 .126 r
.64997 .3142 .65485 .3204 .66483 .31642 .65998 .31019 Metetra
0 .025 .124 r
.65998 .31019 .66483 .31642 .67486 .31277 .67004 .30654 Metetra
0 .025 .123 r
.67004 .30654 .67486 .31277 .68494 .30928 .68014 .30304 Metetra
0 .025 .123 r
.68014 .30304 .68494 .30928 .69505 .30585 .69028 .2996 Metetra
0 .024 .123 r
.69028 .2996 .69505 .30585 .7052 .30244 .70045 .29617 Metetra
0 .025 .123 r
.70045 .29617 .7052 .30244 .71539 .29901 .71067 .29273 Metetra
0 .025 .123 r
.71067 .29273 .71539 .29901 .72561 .29556 .72092 .28926 Metetra
0 .025 .123 r
.72092 .28926 .72561 .29556 .73588 .29214 .73121 .28582 Metetra
0 .025 .123 r
.73121 .28582 .73588 .29214 .74618 .2888 .74154 .28244 Metetra
0 .025 .124 r
.74154 .28244 .74618 .2888 .75652 .28529 .7519 .27895 Metetra
0 .025 .123 r
.7519 .27895 .75652 .28529 .76688 .28165 .7623 .2754 Metetra
0 .025 .123 r
.7623 .2754 .76688 .28165 .77729 .27816 .77273 .27174 Metetra
0 .025 .124 r
.77273 .27174 .77729 .27816 .78776 .27482 .78323 .26847 Metetra
0 .025 .124 r
.78323 .26847 .78776 .27482 .79824 .27127 .79374 .26486 Metetra
0 .025 .124 r
.79374 .26486 .79824 .27127 .80878 .26789 .80428 .26116 Metetra
0 .025 .124 r
.80428 .26116 .80878 .26789 .81932 .26406 .81491 .25799 Metetra
0 .025 .124 r
.81491 .25799 .81932 .26406 .82992 .26047 .8255 .25403 Metetra
0 .025 .123 r
.8255 .25403 .82992 .26047 .84054 .25664 .83616 .25032 Metetra
0 .024 .123 r
.83616 .25032 .84054 .25664 .85121 .25296 .84688 .24672 Metetra
0 .025 .123 r
.23553 .44614 .24131 .45177 .24995 .44865 .24417 .44322 Metetra
0 .025 .123 r
.24417 .44322 .24995 .44865 .25858 .44596 .25282 .44048 Metetra
0 .025 .123 r
.25282 .44048 .25858 .44596 .26728 .44287 .26154 .43729 Metetra
0 .025 .124 r
.26154 .43729 .26728 .44287 .27598 .44015 .27025 .43464 Metetra
0 .025 .124 r
.27025 .43464 .27598 .44015 .28472 .4371 .27901 .43157 Metetra
0 .025 .124 r
.27901 .43157 .28472 .4371 .2935 .43403 .28781 .42842 Metetra
0 .025 .123 r
.28781 .42842 .2935 .43403 .3023 .43102 .29663 .42538 Metetra
0 .025 .123 r
.29663 .42538 .3023 .43102 .31114 .42797 .30548 .42233 Metetra
0 .025 .123 r
.30548 .42233 .31114 .42797 .31999 .42513 .31435 .41952 Metetra
0 .025 .124 r
.31435 .41952 .31999 .42513 .32888 .42214 .32325 .4165 Metetra
0 .025 .124 r
.32325 .4165 .32888 .42214 .3378 .41904 .3322 .41337 Metetra
0 .025 .123 r
.3322 .41337 .3378 .41904 .34675 .41597 .34117 .41025 Metetra
0 .025 .123 r
.34117 .41025 .34675 .41597 .35573 .41295 .35016 .40719 Metetra
0 .025 .123 r
.35016 .40719 .35573 .41295 .36474 .40992 .35919 .40411 Metetra
0 .025 .123 r
.35919 .40411 .36474 .40992 .37378 .40687 .36825 .40103 Metetra
0 .025 .123 r
.36825 .40103 .37378 .40687 .38285 .40382 .37734 .39795 Metetra
0 .025 .123 r
.37734 .39795 .38285 .40382 .39194 .40079 .38646 .39491 Metetra
0 .025 .124 r
.38646 .39491 .39194 .40079 .40107 .39779 .3956 .392 Metetra
0 .026 .125 r
.3956 .392 .40107 .39779 .41023 .39491 .40476 .38938 Metetra
0 .028 .128 r
.40476 .38938 .41023 .39491 .4194 .39259 .41394 .38735 Metetra
0 .033 .134 r
.41394 .38735 .4194 .39259 .42857 .39131 .42313 .38624 Metetra
0 .042 .144 r
.42313 .38624 .42857 .39131 .43776 .39114 .43233 .38612 Metetra
0 .056 .159 r
.43233 .38612 .43776 .39114 .44697 .39198 .44156 .38701 Metetra
0 .077 .177 r
.44156 .38701 .44697 .39198 .45622 .39341 .45082 .38847 Metetra
0 .103 .198 r
.45082 .38847 .45622 .39341 .46552 .39557 .46013 .39069 Metetra
0 .144 .225 r
.46013 .39069 .46552 .39557 .47485 .40004 .46947 .3953 Metetra
0 .203 .258 r
.46947 .3953 .47485 .40004 .48424 .4053 .47887 .40058 Metetra
0 .28 .295 r
.47887 .40058 .48424 .4053 .4937 .41161 .48834 .40718 Metetra
0 .341 .292 r
.48834 .40718 .4937 .41161 .50324 .4214 .49788 .41681 Metetra
0 .418 .218 r
.49788 .41681 .50324 .4214 .51283 .44408 .50746 .4383 Metetra
.13 .589 0 r
.50746 .4383 .51283 .44408 .52259 .51079 .51716 .48854 Metetra
.785 .731 0 r
.51716 .48854 .52259 .51079 .53278 .57109 .5272 .50209 Metetra
.449 .689 0 r
.5272 .50209 .53278 .57109 .54243 .45069 .53708 .43718 Metetra
0 .458 .16 r
.53708 .43718 .54243 .45069 .55212 .41487 .54685 .40628 Metetra
0 .368 .272 r
.54685 .40628 .55212 .41487 .56184 .39632 .55662 .38888 Metetra
0 .313 .306 r
.55662 .38888 .56184 .39632 .57153 .38024 .56636 .37316 Metetra
0 .227 .271 r
.56636 .37316 .57153 .38024 .58126 .36873 .57613 .36203 Metetra
0 .163 .236 r
.57613 .36203 .58126 .36873 .59097 .35663 .58587 .35006 Metetra
0 .116 .206 r
.58587 .35006 .59097 .35663 .60072 .34737 .59566 .34091 Metetra
0 .086 .184 r
.59566 .34091 .60072 .34737 .6105 .33915 .60547 .33278 Metetra
0 .063 .165 r
.60547 .33278 .6105 .33915 .62029 .3314 .6153 .32508 Metetra
0 .047 .149 r
.6153 .32508 .62029 .3314 .63013 .32466 .62517 .31839 Metetra
0 .036 .137 r
.62517 .31839 .63013 .32466 .64002 .31891 .63508 .31266 Metetra
0 .03 .13 r
.63508 .31266 .64002 .31891 .64997 .3142 .64506 .30793 Metetra
0 .027 .126 r
.64506 .30793 .64997 .3142 .65998 .31019 .65509 .30387 Metetra
0 .025 .124 r
.65509 .30387 .65998 .31019 .67004 .30654 .66517 .30017 Metetra
0 .025 .123 r
.66517 .30017 .67004 .30654 .68014 .30304 .6753 .29664 Metetra
0 .025 .123 r
.6753 .29664 .68014 .30304 .69028 .2996 .68546 .29316 Metetra
0 .025 .123 r
.68546 .29316 .69028 .2996 .70045 .29617 .69566 .2897 Metetra
0 .025 .123 r
.69566 .2897 .70045 .29617 .71067 .29273 .7059 .28623 Metetra
0 .025 .123 r
.7059 .28623 .71067 .29273 .72092 .28926 .71618 .28275 Metetra
0 .025 .123 r
.71618 .28275 .72092 .28926 .73121 .28582 .72649 .27929 Metetra
0 .025 .123 r
.72649 .27929 .73121 .28582 .74154 .28244 .73685 .27589 Metetra
0 .025 .124 r
.73685 .27589 .74154 .28244 .7519 .27895 .74724 .27238 Metetra
0 .025 .124 r
.74724 .27238 .7519 .27895 .7623 .2754 .75766 .26873 Metetra
0 .025 .123 r
.75766 .26873 .7623 .2754 .77273 .27174 .76811 .26492 Metetra
0 .025 .123 r
.76811 .26492 .77273 .27174 .78323 .26847 .77863 .26165 Metetra
0 .025 .124 r
.77863 .26165 .78323 .26847 .79374 .26486 .78918 .25815 Metetra
0 .025 .124 r
.78918 .25815 .79374 .26486 .80428 .26116 .79974 .25431 Metetra
0 .025 .124 r
.79974 .25431 .80428 .26116 .81491 .25799 .8104 .25122 Metetra
0 .026 .124 r
.8104 .25122 .81491 .25799 .8255 .25403 .82102 .24714 Metetra
0 .025 .123 r
.82102 .24714 .8255 .25403 .83616 .25032 .83169 .24327 Metetra
0 .024 .123 r
.83169 .24327 .83616 .25032 .84688 .24672 .84243 .23961 Metetra
0 .024 .122 r
.22971 .4405 .23553 .44614 .24417 .44322 .23837 .43753 Metetra
0 .024 .123 r
.23837 .43753 .24417 .44322 .25282 .44048 .24705 .43464 Metetra
0 .025 .123 r
.24705 .43464 .25282 .44048 .26154 .43729 .25574 .43205 Metetra
0 .025 .124 r
.25574 .43205 .26154 .43729 .27025 .43464 .26449 .42895 Metetra
0 .025 .124 r
.26449 .42895 .27025 .43464 .27901 .43157 .27327 .42596 Metetra
0 .025 .123 r
.27327 .42596 .27901 .43157 .28781 .42842 .28209 .42273 Metetra
0 .024 .123 r
.28209 .42273 .28781 .42842 .29663 .42538 .29091 .41991 Metetra
0 .024 .123 r
.29091 .41991 .29663 .42538 .30548 .42233 .29979 .41664 Metetra
0 .025 .123 r
.29979 .41664 .30548 .42233 .31435 .41952 .30867 .4139 Metetra
0 .025 .124 r
.30867 .4139 .31435 .41952 .32325 .4165 .31759 .41089 Metetra
0 .025 .123 r
.31759 .41089 .32325 .4165 .3322 .41337 .32655 .40775 Metetra
0 .025 .123 r
.32655 .40775 .3322 .41337 .34117 .41025 .33554 .40461 Metetra
0 .025 .123 r
.33554 .40461 .34117 .41025 .35016 .40719 .34456 .40153 Metetra
0 .024 .123 r
.34456 .40153 .35016 .40719 .35919 .40411 .3536 .39844 Metetra
0 .024 .123 r
.3536 .39844 .35919 .40411 .36825 .40103 .36268 .39534 Metetra
0 .025 .123 r
.36268 .39534 .36825 .40103 .37734 .39795 .37179 .39225 Metetra
0 .025 .123 r
.37179 .39225 .37734 .39795 .38646 .39491 .38093 .3892 Metetra
0 .025 .124 r
.38093 .3892 .38646 .39491 .3956 .392 .39009 .38628 Metetra
0 .026 .125 r
.39009 .38628 .3956 .392 .40476 .38938 .39927 .38363 Metetra
0 .029 .128 r
.39927 .38363 .40476 .38938 .41394 .38735 .40847 .38154 Metetra
0 .034 .135 r
.40847 .38154 .41394 .38735 .42313 .38624 .41767 .38034 Metetra
0 .043 .145 r
.41767 .38034 .42313 .38624 .43233 .38612 .4269 .38004 Metetra
0 .057 .16 r
.4269 .38004 .43233 .38612 .44156 .38701 .43614 .38071 Metetra
0 .077 .177 r
.43614 .38071 .44156 .38701 .45082 .38847 .44542 .38183 Metetra
0 .104 .198 r
.44542 .38183 .45082 .38847 .46013 .39069 .45475 .38387 Metetra
0 .145 .225 r
.45475 .38387 .46013 .39069 .46947 .3953 .46408 .38858 Metetra
0 .201 .257 r
.46408 .38858 .46947 .3953 .47887 .40058 .47351 .3923 Metetra
0 .276 .294 r
.47351 .3923 .47887 .40058 .48834 .40718 .48298 .39957 Metetra
0 .338 .294 r
.48298 .39957 .48834 .40718 .49788 .41681 .49254 .40623 Metetra
0 .4 .24 r
.49254 .40623 .49788 .41681 .50746 .4383 .50216 .41725 Metetra
0 .506 .071 r
.50216 .41725 .50746 .4383 .51716 .48854 .51191 .42927 Metetra
.131 .59 0 r
.51191 .42927 .51716 .48854 .5272 .50209 .52179 .426 Metetra
0 .534 .01 r
.52179 .426 .5272 .50209 .53708 .43718 .53169 .41103 Metetra
0 .421 .215 r
.53169 .41103 .53708 .43718 .54685 .40628 .54153 .39349 Metetra
0 .353 .284 r
.54153 .39349 .54685 .40628 .55662 .38888 .55135 .37842 Metetra
0 .295 .302 r
.55135 .37842 .55662 .38888 .56636 .37316 .56113 .36369 Metetra
0 .214 .264 r
.56113 .36369 .56636 .37316 .57613 .36203 .57095 .35433 Metetra
0 .156 .232 r
.57095 .35433 .57613 .36203 .58587 .35006 .58073 .34258 Metetra
0 .111 .203 r
.58073 .34258 .58587 .35006 .59566 .34091 .59055 .33356 Metetra
0 .083 .182 r
.59055 .33356 .59566 .34091 .60547 .33278 .60039 .32578 Metetra
0 .061 .164 r
.60039 .32578 .60547 .33278 .6153 .32508 .61026 .31834 Metetra
0 .046 .148 r
.61026 .31834 .6153 .32508 .62517 .31839 .62016 .31182 Metetra
0 .036 .137 r
.62016 .31182 .62517 .31839 .63508 .31266 .63011 .3062 Metetra
0 .03 .129 r
.63011 .3062 .63508 .31266 .64506 .30793 .64011 .30152 Metetra
0 .026 .126 r
.64011 .30152 .64506 .30793 .65509 .30387 .65017 .29749 Metetra
0 .025 .124 r
.65017 .29749 .65509 .30387 .66517 .30017 .66028 .29379 Metetra
0 .025 .123 r
.66028 .29379 .66517 .30017 .6753 .29664 .67043 .29024 Metetra
0 .024 .123 r
.67043 .29024 .6753 .29664 .68546 .29316 .68062 .28675 Metetra
0 .024 .123 r
.68062 .28675 .68546 .29316 .69566 .2897 .69085 .28326 Metetra
0 .024 .123 r
.69085 .28326 .69566 .2897 .7059 .28623 .70111 .27977 Metetra
0 .024 .123 r
.70111 .27977 .7059 .28623 .71618 .28275 .71141 .27626 Metetra
0 .025 .123 r
.71141 .27626 .71618 .28275 .72649 .27929 .72176 .27279 Metetra
0 .025 .123 r
.72176 .27279 .72649 .27929 .73685 .27589 .73214 .26935 Metetra
0 .025 .124 r
.73214 .26935 .73685 .27589 .74724 .27238 .74255 .26578 Metetra
0 .025 .123 r
.74255 .26578 .74724 .27238 .75766 .26873 .75299 .26202 Metetra
0 .024 .123 r
.75299 .26202 .75766 .26873 .76811 .26492 .76349 .2585 Metetra
0 .025 .123 r
.76349 .2585 .76811 .26492 .77863 .26165 .77403 .25507 Metetra
0 .025 .124 r
.77403 .25507 .77863 .26165 .78918 .25815 .78459 .25143 Metetra
0 .025 .124 r
.78459 .25143 .78918 .25815 .79974 .25431 .79523 .24814 Metetra
0 .025 .124 r
.79523 .24814 .79974 .25431 .8104 .25122 .80583 .24398 Metetra
0 .025 .123 r
.80583 .24398 .8104 .25122 .82102 .24714 .81651 .24031 Metetra
0 .024 .122 r
.81651 .24031 .82102 .24714 .83169 .24327 .82722 .23652 Metetra
0 .024 .122 r
.82722 .23652 .83169 .24327 .84243 .23961 .83798 .2328 Metetra
0 .024 .122 r
.22384 .43496 .22971 .4405 .23837 .43753 .23252 .432 Metetra
0 .024 .122 r
.23252 .432 .23837 .43753 .24705 .43464 .24122 .42902 Metetra
0 .024 .122 r
.24122 .42902 .24705 .43464 .25574 .43205 .24995 .42609 Metetra
0 .025 .123 r
.24995 .42609 .25574 .43205 .26449 .42895 .2587 .42329 Metetra
0 .025 .123 r
.2587 .42329 .26449 .42895 .27327 .42596 .26746 .42063 Metetra
0 .025 .123 r
.26746 .42063 .27327 .42596 .28209 .42273 .27631 .41726 Metetra
0 .025 .123 r
.27631 .41726 .28209 .42273 .29091 .41991 .28515 .41444 Metetra
0 .024 .123 r
.28515 .41444 .29091 .41991 .29979 .41664 .29406 .41098 Metetra
0 .024 .123 r
.29406 .41098 .29979 .41664 .30867 .4139 .30296 .4082 Metetra
0 .025 .123 r
.30296 .4082 .30867 .4139 .31759 .41089 .31189 .40526 Metetra
0 .025 .124 r
.31189 .40526 .31759 .41089 .32655 .40775 .32087 .40211 Metetra
0 .025 .123 r
.32087 .40211 .32655 .40775 .33554 .40461 .32988 .39893 Metetra
0 .025 .123 r
.32988 .39893 .33554 .40461 .34456 .40153 .33892 .39582 Metetra
0 .025 .123 r
.33892 .39582 .34456 .40153 .3536 .39844 .34798 .3927 Metetra
0 .025 .123 r
.34798 .3927 .3536 .39844 .36268 .39534 .35708 .38958 Metetra
0 .025 .123 r
.35708 .38958 .36268 .39534 .37179 .39225 .36621 .38646 Metetra
0 .025 .123 r
.36621 .38646 .37179 .39225 .38093 .3892 .37536 .38338 Metetra
0 .025 .124 r
.37536 .38338 .38093 .3892 .39009 .38628 .38455 .3804 Metetra
0 .026 .125 r
.38455 .3804 .39009 .38628 .39927 .38363 .39375 .37766 Metetra
0 .028 .128 r
.39375 .37766 .39927 .38363 .40847 .38154 .40297 .37542 Metetra
0 .033 .134 r
.40297 .37542 .40847 .38154 .41767 .38034 .4122 .37402 Metetra
0 .042 .144 r
.4122 .37402 .41767 .38034 .4269 .38004 .42144 .37336 Metetra
0 .054 .157 r
.42144 .37336 .4269 .38004 .43614 .38071 .43071 .37356 Metetra
0 .072 .173 r
.43071 .37356 .43614 .38071 .44542 .38183 .44002 .374 Metetra
0 .096 .192 r
.44002 .374 .44542 .38183 .45475 .38387 .44935 .37603 Metetra
0 .135 .219 r
.44935 .37603 .45475 .38387 .46408 .38858 .45869 .38072 Metetra
0 .183 .248 r
.45869 .38072 .46408 .38858 .47351 .3923 .46817 .38212 Metetra
0 .243 .278 r
.46817 .38212 .47351 .3923 .48298 .39957 .47766 .38659 Metetra
0 .315 .305 r
.47766 .38659 .48298 .39957 .49254 .40623 .48722 .39175 Metetra
0 .357 .281 r
.48722 .39175 .49254 .40623 .50216 .41725 .49687 .39709 Metetra
0 .4 .24 r
.49687 .39709 .50216 .41725 .51191 .42927 .50663 .39853 Metetra
0 .419 .217 r
.50663 .39853 .51191 .42927 .52179 .426 .51646 .39397 Metetra
0 .403 .237 r
.51646 .39397 .52179 .426 .53169 .41103 .52633 .38819 Metetra
0 .367 .273 r
.52633 .38819 .53169 .41103 .54153 .39349 .53619 .37734 Metetra
0 .324 .301 r
.53619 .37734 .54153 .39349 .55135 .37842 .54604 .36555 Metetra
0 .258 .285 r
.54604 .36555 .55135 .37842 .56113 .36369 .55588 .35538 Metetra
0 .195 .254 r
.55588 .35538 .56113 .36369 .57095 .35433 .56573 .34555 Metetra
0 .144 .225 r
.56573 .34555 .57095 .35433 .58073 .34258 .57555 .33476 Metetra
0 .102 .197 r
.57555 .33476 .58073 .34258 .59055 .33356 .58539 .32553 Metetra
0 .076 .177 r
.58539 .32553 .59055 .33356 .60039 .32578 .59528 .31827 Metetra
0 .058 .16 r
.59528 .31827 .60039 .32578 .61026 .31834 .60518 .31129 Metetra
0 .044 .146 r
.60518 .31129 .61026 .31834 .62016 .31182 .61512 .3051 Metetra
0 .035 .136 r
.61512 .3051 .62016 .31182 .63011 .3062 .6251 .29966 Metetra
0 .029 .129 r
.6251 .29966 .63011 .3062 .64011 .30152 .63514 .29508 Metetra
0 .026 .125 r
.63514 .29508 .64011 .30152 .65017 .29749 .64522 .29109 Metetra
0 .025 .124 r
.64522 .29109 .65017 .29749 .66028 .29379 .65536 .2874 Metetra
0 .025 .123 r
.65536 .2874 .66028 .29379 .67043 .29024 .66553 .28383 Metetra
0 .024 .123 r
.66553 .28383 .67043 .29024 .68062 .28675 .67575 .28032 Metetra
0 .024 .123 r
.67575 .28032 .68062 .28675 .69085 .28326 .686 .27681 Metetra
0 .024 .123 r
.686 .27681 .69085 .28326 .70111 .27977 .69629 .2733 Metetra
0 .025 .123 r
.69629 .2733 .70111 .27977 .71141 .27626 .70662 .26977 Metetra
0 .025 .123 r
.70662 .26977 .71141 .27626 .72176 .27279 .71699 .26629 Metetra
0 .025 .123 r
.71699 .26629 .72176 .27279 .73214 .26935 .7274 .26283 Metetra
0 .025 .124 r
.7274 .26283 .73214 .26935 .74255 .26578 .73783 .25916 Metetra
0 .024 .123 r
.73783 .25916 .74255 .26578 .75299 .26202 .74829 .25524 Metetra
0 .024 .123 r
.74829 .25524 .75299 .26202 .76349 .2585 .75883 .25203 Metetra
0 .025 .123 r
.75883 .25203 .76349 .2585 .77403 .25507 .76936 .24804 Metetra
0 .025 .123 r
.76936 .24804 .77403 .25507 .78459 .25143 .77998 .24469 Metetra
0 .025 .124 r
.77998 .24469 .78459 .25143 .79523 .24814 .79062 .24109 Metetra
0 .025 .123 r
.79062 .24109 .79523 .24814 .80583 .24398 .80126 .23705 Metetra
0 .024 .122 r
.80126 .23705 .80583 .24398 .81651 .24031 .81197 .23332 Metetra
0 .024 .122 r
.81197 .23332 .81651 .24031 .82722 .23652 .82272 .22962 Metetra
0 .024 .122 r
.82272 .22962 .82722 .23652 .83798 .2328 .83351 .22591 Metetra
0 .023 .122 r
.21794 .42943 .22384 .43496 .23252 .432 .22663 .42645 Metetra
0 .024 .122 r
.22663 .42645 .23252 .432 .24122 .42902 .23535 .42345 Metetra
0 .024 .122 r
.23535 .42345 .24122 .42902 .24995 .42609 .2441 .42045 Metetra
0 .024 .122 r
.2441 .42045 .24995 .42609 .2587 .42329 .25288 .41743 Metetra
0 .024 .123 r
.25288 .41743 .2587 .42329 .26746 .42063 .26169 .41448 Metetra
0 .025 .123 r
.26169 .41448 .26746 .42063 .27631 .41726 .27051 .41162 Metetra
0 .025 .123 r
.27051 .41162 .27631 .41726 .28515 .41444 .27938 .40865 Metetra
0 .025 .123 r
.27938 .40865 .28515 .41444 .29406 .41098 .28827 .40573 Metetra
0 .024 .123 r
.28827 .40573 .29406 .41098 .30296 .4082 .29722 .40231 Metetra
0 .025 .123 r
.29722 .40231 .30296 .4082 .31189 .40526 .30616 .39957 Metetra
0 .025 .124 r
.30616 .39957 .31189 .40526 .32087 .40211 .31515 .39651 Metetra
0 .025 .123 r
.31515 .39651 .32087 .40211 .32988 .39893 .32418 .39325 Metetra
0 .025 .123 r
.32418 .39325 .32988 .39893 .33892 .39582 .33324 .39012 Metetra
0 .025 .123 r
.33324 .39012 .33892 .39582 .34798 .3927 .34232 .387 Metetra
0 .025 .123 r
.34232 .387 .34798 .3927 .35708 .38958 .35144 .38385 Metetra
0 .025 .123 r
.35144 .38385 .35708 .38958 .36621 .38646 .36058 .38071 Metetra
0 .025 .123 r
.36058 .38071 .36621 .38646 .37536 .38338 .36976 .3776 Metetra
0 .025 .124 r
.36976 .3776 .37536 .38338 .38455 .3804 .37897 .37455 Metetra
0 .026 .125 r
.37897 .37455 .38455 .3804 .39375 .37766 .38819 .37169 Metetra
0 .028 .127 r
.38819 .37169 .39375 .37766 .40297 .37542 .39744 .3693 Metetra
0 .032 .133 r
.39744 .3693 .40297 .37542 .4122 .37402 .40669 .36766 Metetra
0 .039 .141 r
.40669 .36766 .4122 .37402 .42144 .37336 .41597 .36639 Metetra
0 .049 .152 r
.41597 .36639 .42144 .37336 .43071 .37356 .42527 .3659 Metetra
0 .063 .165 r
.42527 .3659 .43071 .37356 .44002 .374 .43462 .36541 Metetra
0 .086 .184 r
.43462 .36541 .44002 .374 .44935 .37603 .44391 .36917 Metetra
0 .12 .209 r
.44391 .36917 .44935 .37603 .45869 .38072 .45335 .3695 Metetra
0 .156 .232 r
.45335 .3695 .45869 .38072 .46817 .38212 .46279 .37256 Metetra
0 .201 .257 r
.46279 .37256 .46817 .38212 .47766 .38659 .47231 .37514 Metetra
0 .258 .285 r
.47231 .37514 .47766 .38659 .48722 .39175 .4819 .37733 Metetra
0 .315 .305 r
.4819 .37733 .48722 .39175 .49687 .39709 .49155 .38113 Metetra
0 .338 .294 r
.49155 .38113 .49687 .39709 .50663 .39853 .50131 .37962 Metetra
0 .342 .291 r
.50131 .37962 .50663 .39853 .51646 .39397 .51113 .37488 Metetra
0 .337 .294 r
.51113 .37488 .51646 .39397 .52633 .38819 .52098 .37169 Metetra
0 .32 .303 r
.52098 .37169 .52633 .38819 .53619 .37734 .53085 .36226 Metetra
0 .273 .292 r
.53085 .36226 .53619 .37734 .54604 .36555 .54072 .3534 Metetra
0 .216 .265 r
.54072 .3534 .54604 .36555 .55588 .35538 .55059 .3441 Metetra
0 .168 .239 r
.55059 .3441 .55588 .35538 .56573 .34555 .56046 .33475 Metetra
0 .128 .215 r
.56046 .33475 .56573 .34555 .57555 .33476 .57035 .3272 Metetra
0 .092 .19 r
.57035 .3272 .57555 .33476 .58539 .32553 .5802 .31678 Metetra
0 .067 .169 r
.5802 .31678 .58539 .32553 .59528 .31827 .59012 .31004 Metetra
0 .052 .155 r
.59012 .31004 .59528 .31827 .60518 .31129 .60006 .30373 Metetra
0 .041 .143 r
.60006 .30373 .60518 .31129 .61512 .3051 .61004 .29819 Metetra
0 .033 .134 r
.61004 .29819 .61512 .3051 .6251 .29966 .62006 .29302 Metetra
0 .029 .128 r
.62006 .29302 .6251 .29966 .63514 .29508 .63012 .28854 Metetra
0 .026 .125 r
.63012 .28854 .63514 .29508 .64522 .29109 .64024 .28465 Metetra
0 .025 .124 r
.64024 .28465 .64522 .29109 .65536 .2874 .6504 .28099 Metetra
0 .025 .123 r
.6504 .28099 .65536 .2874 .66553 .28383 .6606 .27742 Metetra
0 .025 .123 r
.6606 .27742 .66553 .28383 .67575 .28032 .67084 .27389 Metetra
0 .025 .123 r
.67084 .27389 .67575 .28032 .686 .27681 .68112 .27035 Metetra
0 .025 .123 r
.68112 .27035 .686 .27681 .69629 .2733 .69144 .2668 Metetra
0 .025 .123 r
.69144 .2668 .69629 .2733 .70662 .26977 .70179 .26323 Metetra
0 .025 .123 r
.70179 .26323 .70662 .26977 .71699 .26629 .71219 .25979 Metetra
0 .025 .124 r
.71219 .25979 .71699 .26629 .7274 .26283 .72262 .25627 Metetra
0 .025 .123 r
.72262 .25627 .7274 .26283 .73783 .25916 .73307 .25232 Metetra
0 .024 .123 r
.73307 .25232 .73783 .25916 .74829 .25524 .74357 .24866 Metetra
0 .025 .123 r
.74357 .24866 .74829 .25524 .75883 .25203 .75414 .2454 Metetra
0 .025 .123 r
.75414 .2454 .75883 .25203 .76936 .24804 .76472 .24166 Metetra
0 .024 .123 r
.76472 .24166 .76936 .24804 .77998 .24469 .77531 .23765 Metetra
0 .024 .123 r
.77531 .23765 .77998 .24469 .79062 .24109 .78597 .23387 Metetra
0 .024 .122 r
.78597 .23387 .79062 .24109 .80126 .23705 .79666 .23017 Metetra
0 .024 .122 r
.79666 .23017 .80126 .23705 .81197 .23332 .8074 .22646 Metetra
0 .024 .122 r
.8074 .22646 .81197 .23332 .82272 .22962 .81818 .22275 Metetra
0 .024 .122 r
.81818 .22275 .82272 .22962 .83351 .22591 .82901 .21902 Metetra
0 .023 .121 r
.212 .42389 .21794 .42943 .22663 .42645 .2207 .42089 Metetra
0 .023 .122 r
.2207 .42089 .22663 .42645 .23535 .42345 .22944 .41787 Metetra
0 .023 .122 r
.22944 .41787 .23535 .42345 .2441 .42045 .23821 .41484 Metetra
0 .024 .122 r
.23821 .41484 .2441 .42045 .25288 .41743 .24701 .41181 Metetra
0 .024 .122 r
.24701 .41181 .25288 .41743 .26169 .41448 .25584 .40876 Metetra
0 .024 .122 r
.25584 .40876 .26169 .41448 .27051 .41162 .26469 .40572 Metetra
0 .024 .122 r
.26469 .40572 .27051 .41162 .27938 .40865 .27358 .4027 Metetra
0 .024 .123 r
.27358 .4027 .27938 .40865 .28827 .40573 .28248 .39979 Metetra
0 .025 .123 r
.28248 .39979 .28827 .40573 .29722 .40231 .29139 .39731 Metetra
0 .025 .124 r
.29139 .39731 .29722 .40231 .30616 .39957 .3004 .3937 Metetra
0 .025 .124 r
.3004 .3937 .30616 .39957 .31515 .39651 .30939 .39091 Metetra
0 .025 .124 r
.30939 .39091 .31515 .39651 .32418 .39325 .31845 .38754 Metetra
0 .025 .123 r
.31845 .38754 .32418 .39325 .33324 .39012 .32752 .38442 Metetra
0 .025 .123 r
.32752 .38442 .33324 .39012 .34232 .387 .33662 .38132 Metetra
0 .025 .123 r
.33662 .38132 .34232 .387 .35144 .38385 .34576 .37816 Metetra
0 .025 .123 r
.34576 .37816 .35144 .38385 .36058 .38071 .35492 .37499 Metetra
0 .025 .124 r
.35492 .37499 .36058 .38071 .36976 .3776 .36412 .37185 Metetra
0 .025 .124 r
.36412 .37185 .36976 .3776 .37897 .37455 .37335 .36874 Metetra
0 .026 .125 r
.37335 .36874 .37897 .37455 .38819 .37169 .3826 .36572 Metetra
0 .027 .127 r
.3826 .36572 .38819 .37169 .39744 .3693 .39187 .36314 Metetra
0 .031 .131 r
.39187 .36314 .39744 .3693 .40669 .36766 .40115 .36129 Metetra
0 .036 .137 r
.40115 .36129 .40669 .36766 .41597 .36639 .41049 .35874 Metetra
0 .042 .145 r
.41049 .35874 .41597 .36639 .42527 .3659 .41983 .3573 Metetra
0 .055 .157 r
.41983 .3573 .42527 .3659 .43462 .36541 .42912 .35895 Metetra
0 .076 .176 r
.42912 .35895 .43462 .36541 .44391 .36917 .43851 .35907 Metetra
0 .1 .195 r
.43851 .35907 .44391 .36917 .45335 .3695 .44793 .36031 Metetra
0 .129 .215 r
.44793 .36031 .45335 .3695 .46279 .37256 .45741 .36176 Metetra
0 .165 .237 r
.45741 .36176 .46279 .37256 .47231 .37514 .46695 .36325 Metetra
0 .201 .257 r
.46695 .36325 .47231 .37514 .4819 .37733 .47656 .36359 Metetra
0 .243 .278 r
.47656 .36359 .4819 .37733 .49155 .38113 .48623 .36445 Metetra
0 .276 .294 r
.48623 .36445 .49155 .38113 .50131 .37962 .49597 .36357 Metetra
0 .28 .296 r
.49597 .36357 .50131 .37962 .51113 .37488 .50579 .35909 Metetra
0 .273 .292 r
.50579 .35909 .51113 .37488 .52098 .37169 .51563 .35517 Metetra
0 .248 .281 r
.51563 .35517 .52098 .37169 .53085 .36226 .5255 .34706 Metetra
0 .21 .262 r
.5255 .34706 .53085 .36226 .54072 .3534 .53539 .34119 Metetra
0 .174 .243 r
.53539 .34119 .54072 .3534 .55059 .3441 .54528 .33292 Metetra
0 .137 .221 r
.54528 .33292 .55059 .3441 .56046 .33475 .55518 .32479 Metetra
0 .107 .201 r
.55518 .32479 .56046 .33475 .57035 .3272 .56508 .31675 Metetra
0 .081 .18 r
.56508 .31675 .57035 .3272 .5802 .31678 .575 .30951 Metetra
0 .059 .161 r
.575 .30951 .5802 .31678 .59012 .31004 .58493 .30159 Metetra
0 .045 .147 r
.58493 .30159 .59012 .31004 .60006 .30373 .59489 .29516 Metetra
0 .037 .138 r
.59489 .29516 .60006 .30373 .61004 .29819 .60493 .29121 Metetra
0 .032 .133 r
.60493 .29121 .61004 .29819 .62006 .29302 .61498 .28633 Metetra
0 .028 .127 r
.61498 .28633 .62006 .29302 .63012 .28854 .62508 .28199 Metetra
0 .026 .125 r
.62508 .28199 .63012 .28854 .64024 .28465 .63523 .27823 Metetra
0 .025 .124 r
.63523 .27823 .64024 .28465 .6504 .28099 .64541 .27461 Metetra
0 .025 .124 r
.64541 .27461 .6504 .28099 .6606 .27742 .65564 .27103 Metetra
0 .025 .123 r
.65564 .27103 .6606 .27742 .67084 .27389 .66591 .26747 Metetra
0 .025 .123 r
.66591 .26747 .67084 .27389 .68112 .27035 .67621 .26392 Metetra
0 .025 .123 r
.67621 .26392 .68112 .27035 .69144 .2668 .68655 .26031 Metetra
0 .025 .123 r
.68655 .26031 .69144 .2668 .70179 .26323 .69693 .25668 Metetra
0 .025 .124 r
.69693 .25668 .70179 .26323 .71219 .25979 .70736 .25326 Metetra
0 .025 .124 r
.70736 .25326 .71219 .25979 .72262 .25627 .71781 .24963 Metetra
0 .025 .124 r
.71781 .24963 .72262 .25627 .73307 .25232 .72831 .24606 Metetra
0 .025 .123 r
.72831 .24606 .73307 .25232 .74357 .24866 .73882 .24205 Metetra
0 .024 .123 r
.73882 .24205 .74357 .24866 .75414 .2454 .74938 .23824 Metetra
0 .024 .123 r
.74938 .23824 .75414 .2454 .76472 .24166 .75998 .23443 Metetra
0 .024 .122 r
.75998 .23443 .76472 .24166 .77531 .23765 .77063 .23076 Metetra
0 .024 .122 r
.77063 .23076 .77531 .23765 .78597 .23387 .78132 .22704 Metetra
0 .024 .122 r
.78132 .22704 .78597 .23387 .79666 .23017 .79205 .22332 Metetra
0 .024 .122 r
.79205 .22332 .79666 .23017 .8074 .22646 .80281 .21959 Metetra
0 .023 .122 r
.80281 .21959 .8074 .22646 .81818 .22275 .81362 .21585 Metetra
0 .023 .122 r
.81362 .21585 .81818 .22275 .82901 .21902 .82447 .21209 Metetra
0 .023 .121 r
.20602 .41833 .212 .42389 .2207 .42089 .21474 .4153 Metetra
0 .023 .121 r
.21474 .4153 .2207 .42089 .22944 .41787 .2235 .41226 Metetra
0 .023 .121 r
.2235 .41226 .22944 .41787 .23821 .41484 .23228 .40921 Metetra
0 .023 .122 r
.23228 .40921 .23821 .41484 .24701 .41181 .2411 .40615 Metetra
0 .023 .122 r
.2411 .40615 .24701 .41181 .25584 .40876 .24994 .40309 Metetra
0 .024 .122 r
.24994 .40309 .25584 .40876 .26469 .40572 .25882 .40003 Metetra
0 .024 .122 r
.25882 .40003 .26469 .40572 .27358 .4027 .26772 .39694 Metetra
0 .024 .122 r
.26772 .39694 .27358 .4027 .28248 .39979 .27666 .39383 Metetra
0 .024 .123 r
.27666 .39383 .28248 .39979 .29139 .39731 .28562 .39074 Metetra
0 .025 .123 r
.28562 .39074 .29139 .39731 .3004 .3937 .2946 .38787 Metetra
0 .025 .124 r
.2946 .38787 .3004 .3937 .30939 .39091 .30362 .38497 Metetra
0 .025 .124 r
.30362 .38497 .30939 .39091 .31845 .38754 .31269 .38156 Metetra
0 .025 .124 r
.31269 .38156 .31845 .38754 .32752 .38442 .32174 .3791 Metetra
0 .026 .125 r
.32174 .3791 .32752 .38442 .33662 .38132 .33086 .37607 Metetra
0 .026 .125 r
.33086 .37607 .33662 .38132 .34576 .37816 .34002 .37282 Metetra
0 .026 .125 r
.34002 .37282 .34576 .37816 .35492 .37499 .3492 .36961 Metetra
0 .026 .125 r
.3492 .36961 .35492 .37499 .36412 .37185 .35842 .36651 Metetra
0 .026 .125 r
.35842 .36651 .36412 .37185 .37335 .36874 .36766 .36341 Metetra
0 .026 .125 r
.36766 .36341 .37335 .36874 .3826 .36572 .37696 .36002 Metetra
0 .026 .126 r
.37696 .36002 .3826 .36572 .39187 .36314 .3863 .35618 Metetra
0 .028 .127 r
.3863 .35618 .39187 .36314 .40115 .36129 .39564 .3531 Metetra
0 .031 .132 r
.39564 .3531 .40115 .36129 .41049 .35874 .40494 .35186 Metetra
0 .037 .139 r
.40494 .35186 .41049 .35874 .41983 .3573 .41429 .35072 Metetra
0 .048 .151 r
.41429 .35072 .41983 .3573 .42912 .35895 .42366 .35016 Metetra
0 .063 .165 r
.42366 .35016 .42912 .35895 .43851 .35907 .43306 .3501 Metetra
0 .081 .181 r
.43306 .3501 .43851 .35907 .44793 .36031 .44251 .35043 Metetra
0 .104 .198 r
.44251 .35043 .44793 .36031 .45741 .36176 .45201 .35095 Metetra
0 .129 .215 r
.45201 .35095 .45741 .36176 .46695 .36325 .46158 .35083 Metetra
0 .156 .232 r
.46158 .35083 .46695 .36325 .47656 .36359 .47116 .35277 Metetra
0 .183 .248 r
.47116 .35277 .47656 .36359 .48623 .36445 .48086 .35142 Metetra
0 .201 .257 r
.48086 .35142 .48623 .36445 .49597 .36357 .49062 .34894 Metetra
0 .203 .258 r
.49062 .34894 .49597 .36357 .50579 .35909 .50044 .34446 Metetra
0 .199 .256 r
.50044 .34446 .50579 .35909 .51563 .35517 .51027 .34153 Metetra
0 .186 .249 r
.51027 .34153 .51563 .35517 .5255 .34706 .52015 .33624 Metetra
0 .161 .235 r
.52015 .33624 .5255 .34706 .53539 .34119 .53004 .32805 Metetra
0 .135 .219 r
.53004 .32805 .53539 .34119 .54528 .33292 .53995 .32164 Metetra
0 .11 .202 r
.53995 .32164 .54528 .33292 .55518 .32479 .54987 .3144 Metetra
0 .087 .185 r
.54987 .3144 .55518 .32479 .56508 .31675 .5598 .30722 Metetra
0 .067 .169 r
.5598 .30722 .56508 .31675 .575 .30951 .56975 .3003 Metetra
0 .051 .154 r
.56975 .3003 .575 .30951 .58493 .30159 .57972 .29398 Metetra
0 .039 .141 r
.57972 .29398 .58493 .30159 .59489 .29516 .58973 .28833 Metetra
0 .032 .133 r
.58973 .28833 .59489 .29516 .60493 .29121 .59975 .28259 Metetra
0 .028 .128 r
.59975 .28259 .60493 .29121 .61498 .28633 .60984 .27844 Metetra
0 .027 .126 r
.60984 .27844 .61498 .28633 .62508 .28199 .62 .27552 Metetra
0 .026 .125 r
.62 .27552 .62508 .28199 .63523 .27823 .63019 .27229 Metetra
0 .026 .125 r
.63019 .27229 .63523 .27823 .64541 .27461 .64041 .26866 Metetra
0 .026 .125 r
.64041 .26866 .64541 .27461 .65564 .27103 .65066 .26499 Metetra
0 .026 .125 r
.65066 .26499 .65564 .27103 .66591 .26747 .66096 .26141 Metetra
0 .026 .125 r
.66096 .26141 .66591 .26747 .67621 .26392 .67129 .2579 Metetra
0 .026 .125 r
.67129 .2579 .67621 .26392 .68655 .26031 .68166 .25425 Metetra
0 .025 .124 r
.68166 .25425 .68655 .26031 .69693 .25668 .69204 .25006 Metetra
0 .025 .124 r
.69204 .25006 .69693 .25668 .70736 .25326 .70248 .24636 Metetra
0 .025 .124 r
.70248 .24636 .70736 .25326 .71781 .24963 .71296 .24275 Metetra
0 .025 .123 r
.71296 .24275 .71781 .24963 .72831 .24606 .72346 .2387 Metetra
0 .024 .123 r
.72346 .2387 .72831 .24606 .73882 .24205 .73401 .23497 Metetra
0 .024 .122 r
.73401 .23497 .73882 .24205 .74938 .23824 .74461 .23131 Metetra
0 .024 .122 r
.74461 .23131 .74938 .23824 .75998 .23443 .75525 .2276 Metetra
0 .024 .122 r
.75525 .2276 .75998 .23443 .77063 .23076 .76593 .22391 Metetra
0 .024 .122 r
.76593 .22391 .77063 .23076 .78132 .22704 .77664 .22018 Metetra
0 .024 .122 r
.77664 .22018 .78132 .22704 .79205 .22332 .7874 .21643 Metetra
0 .023 .122 r
.7874 .21643 .79205 .22332 .80281 .21959 .79819 .21267 Metetra
0 .023 .122 r
.79819 .21267 .80281 .21959 .81362 .21585 .80903 .20891 Metetra
0 .023 .121 r
.80903 .20891 .81362 .21585 .82447 .21209 .81991 .20513 Metetra
0 .023 .121 r
.2 .41273 .20602 .41833 .21474 .4153 .20874 .40967 Metetra
0 .023 .121 r
.20874 .40967 .21474 .4153 .2235 .41226 .21751 .40662 Metetra
0 .023 .121 r
.21751 .40662 .2235 .41226 .23228 .40921 .22632 .40355 Metetra
0 .023 .121 r
.22632 .40355 .23228 .40921 .2411 .40615 .23515 .40047 Metetra
0 .023 .122 r
.23515 .40047 .2411 .40615 .24994 .40309 .24401 .39739 Metetra
0 .024 .122 r
.24401 .39739 .24994 .40309 .25882 .40003 .2529 .39429 Metetra
0 .024 .122 r
.2529 .39429 .25882 .40003 .26772 .39694 .26183 .39121 Metetra
0 .024 .122 r
.26183 .39121 .26772 .39694 .27666 .39383 .27078 .38808 Metetra
0 .024 .122 r
.27078 .38808 .27666 .39383 .28562 .39074 .27977 .38493 Metetra
0 .024 .122 r
.27977 .38493 .28562 .39074 .2946 .38787 .28878 .38179 Metetra
0 .024 .122 r
.28878 .38179 .2946 .38787 .30362 .38497 .29783 .37868 Metetra
0 .024 .123 r
.29783 .37868 .30362 .38497 .31269 .38156 .3069 .37555 Metetra
0 .025 .123 r
.3069 .37555 .31269 .38156 .32174 .3791 .31601 .37244 Metetra
0 .025 .124 r
.31601 .37244 .32174 .3791 .33086 .37607 .32515 .36928 Metetra
0 .025 .124 r
.32515 .36928 .33086 .37607 .34002 .37282 .33432 .36606 Metetra
0 .025 .124 r
.33432 .36606 .34002 .37282 .3492 .36961 .34352 .36284 Metetra
0 .025 .124 r
.34352 .36284 .3492 .36961 .35842 .36651 .35276 .35964 Metetra
0 .026 .124 r
.35276 .35964 .35842 .36651 .36766 .36341 .36203 .35639 Metetra
0 .025 .124 r
.36203 .35639 .36766 .36341 .37696 .36002 .37134 .35303 Metetra
0 .025 .123 r
.37134 .35303 .37696 .36002 .3863 .35618 .38066 .34997 Metetra
0 .025 .124 r
.38066 .34997 .3863 .35618 .39564 .3531 .39 .34729 Metetra
0 .028 .128 r
.39 .34729 .39564 .3531 .40494 .35186 .39936 .34507 Metetra
0 .034 .135 r
.39936 .34507 .40494 .35186 .41429 .35072 .40875 .34315 Metetra
0 .041 .143 r
.40875 .34315 .41429 .35072 .42366 .35016 .41815 .34199 Metetra
0 .052 .154 r
.41815 .34199 .42366 .35016 .43306 .3501 .42759 .34116 Metetra
0 .065 .167 r
.42759 .34116 .43306 .3501 .44251 .35043 .43706 .34069 Metetra
0 .081 .181 r
.43706 .34069 .44251 .35043 .45201 .35095 .44659 .3403 Metetra
0 .1 .195 r
.44659 .3403 .45201 .35095 .46158 .35083 .45614 .3411 Metetra
0 .12 .209 r
.45614 .3411 .46158 .35083 .47116 .35277 .46581 .33866 Metetra
0 .136 .219 r
.46581 .33866 .47116 .35277 .48086 .35142 .4755 .33722 Metetra
0 .145 .225 r
.4755 .33722 .48086 .35142 .49062 .34894 .48526 .33479 Metetra
0 .144 .225 r
.48526 .33479 .49062 .34894 .50044 .34446 .49507 .33044 Metetra
0 .142 .224 r
.49507 .33044 .50044 .34446 .51027 .34153 .5049 .32731 Metetra
0 .137 .221 r
.5049 .32731 .51027 .34153 .52015 .33624 .51478 .3221 Metetra
0 .122 .211 r
.51478 .3221 .52015 .33624 .53004 .32805 .52468 .31748 Metetra
0 .103 .198 r
.52468 .31748 .53004 .32805 .53995 .32164 .5346 .31043 Metetra
0 .085 .184 r
.5346 .31043 .53995 .32164 .54987 .3144 .54454 .30406 Metetra
0 .069 .17 r
.54454 .30406 .54987 .3144 .5598 .30722 .5545 .29771 Metetra
0 .055 .157 r
.5545 .29771 .5598 .30722 .56975 .3003 .56448 .29155 Metetra
0 .043 .146 r
.56448 .29155 .56975 .3003 .57972 .29398 .57448 .28584 Metetra
0 .035 .136 r
.57448 .28584 .57972 .29398 .58973 .28833 .58452 .28081 Metetra
0 .029 .129 r
.58452 .28081 .58973 .28833 .59975 .28259 .59459 .27614 Metetra
0 .026 .124 r
.59459 .27614 .59975 .28259 .60984 .27844 .60471 .27191 Metetra
0 .025 .123 r
.60471 .27191 .60984 .27844 .62 .27552 .61487 .26806 Metetra
0 .025 .124 r
.61487 .26806 .62 .27552 .63019 .27229 .62507 .26465 Metetra
0 .026 .124 r
.62507 .26465 .63019 .27229 .64041 .26866 .63532 .26112 Metetra
0 .025 .124 r
.63532 .26112 .64041 .26866 .65066 .26499 .64559 .2575 Metetra
0 .025 .124 r
.64559 .2575 .65066 .26499 .66096 .26141 .65591 .2539 Metetra
0 .025 .124 r
.65591 .2539 .66096 .26141 .67129 .2579 .66627 .25031 Metetra
0 .025 .124 r
.66627 .25031 .67129 .2579 .68166 .25425 .67666 .24667 Metetra
0 .025 .123 r
.67666 .24667 .68166 .25425 .69204 .25006 .68709 .24296 Metetra
0 .024 .123 r
.68709 .24296 .69204 .25006 .70248 .24636 .69755 .23928 Metetra
0 .024 .123 r
.69755 .23928 .70248 .24636 .71296 .24275 .70806 .23555 Metetra
0 .024 .122 r
.70806 .23555 .71296 .24275 .72346 .2387 .7186 .23187 Metetra
0 .024 .122 r
.7186 .23187 .72346 .2387 .73401 .23497 .72919 .22817 Metetra
0 .024 .122 r
.72919 .22817 .73401 .23497 .74461 .23131 .73982 .22447 Metetra
0 .024 .122 r
.73982 .22447 .74461 .23131 .75525 .2276 .75048 .22075 Metetra
0 .024 .122 r
.75048 .22075 .75525 .2276 .76593 .22391 .76118 .217 Metetra
0 .024 .122 r
.76118 .217 .76593 .22391 .77664 .22018 .77193 .21326 Metetra
0 .024 .122 r
.77193 .21326 .77664 .22018 .7874 .21643 .78272 .2095 Metetra
0 .023 .122 r
.78272 .2095 .7874 .21643 .79819 .21267 .79354 .20572 Metetra
0 .023 .122 r
.79354 .20572 .79819 .21267 .80903 .20891 .80441 .20193 Metetra
0 .023 .122 r
.80441 .20193 .80903 .20891 .81991 .20513 .81532 .19813 Metetra
0 .023 .121 r
.19394 .4071 .2 .41273 .20874 .40967 .2027 .40402 Metetra
0 .023 .121 r
.2027 .40402 .20874 .40967 .21751 .40662 .21149 .40094 Metetra
0 .023 .121 r
.21149 .40094 .21751 .40662 .22632 .40355 .22031 .39785 Metetra
0 .023 .121 r
.22031 .39785 .22632 .40355 .23515 .40047 .22916 .39477 Metetra
0 .023 .122 r
.22916 .39477 .23515 .40047 .24401 .39739 .23804 .39166 Metetra
0 .024 .122 r
.23804 .39166 .24401 .39739 .2529 .39429 .24695 .38855 Metetra
0 .024 .122 r
.24695 .38855 .2529 .39429 .26183 .39121 .2559 .3854 Metetra
0 .024 .122 r
.2559 .3854 .26183 .39121 .27078 .38808 .26487 .38226 Metetra
0 .024 .122 r
.26487 .38226 .27078 .38808 .27977 .38493 .27387 .3791 Metetra
0 .024 .122 r
.27387 .3791 .27977 .38493 .28878 .38179 .2829 .37596 Metetra
0 .024 .122 r
.2829 .37596 .28878 .38179 .29783 .37868 .29197 .37277 Metetra
0 .024 .122 r
.29197 .37277 .29783 .37868 .3069 .37555 .30107 .36958 Metetra
0 .024 .122 r
.30107 .36958 .3069 .37555 .31601 .37244 .31019 .36641 Metetra
0 .024 .122 r
.31019 .36641 .31601 .37244 .32515 .36928 .31935 .36321 Metetra
0 .024 .122 r
.31935 .36321 .32515 .36928 .33432 .36606 .32854 .36004 Metetra
0 .024 .122 r
.32854 .36004 .33432 .36606 .34352 .36284 .33777 .35681 Metetra
0 .024 .122 r
.33777 .35681 .34352 .36284 .35276 .35964 .34702 .35355 Metetra
0 .024 .122 r
.34702 .35355 .35276 .35964 .36203 .35639 .35631 .35026 Metetra
0 .024 .122 r
.35631 .35026 .36203 .35639 .37134 .35303 .36563 .34707 Metetra
0 .024 .122 r
.36563 .34707 .37134 .35303 .38066 .34997 .37498 .34388 Metetra
0 .025 .123 r
.37498 .34388 .38066 .34997 .39 .34729 .38435 .34092 Metetra
0 .027 .126 r
.38435 .34092 .39 .34729 .39936 .34507 .39374 .33826 Metetra
0 .03 .13 r
.39374 .33826 .39936 .34507 .40875 .34315 .40316 .33587 Metetra
0 .035 .136 r
.40316 .33587 .40875 .34315 .41815 .34199 .4126 .33405 Metetra
0 .043 .145 r
.4126 .33405 .41815 .34199 .42759 .34116 .42207 .33254 Metetra
0 .052 .154 r
.42207 .33254 .42759 .34116 .43706 .34069 .43158 .33129 Metetra
0 .063 .165 r
.43158 .33129 .43706 .34069 .44659 .3403 .44112 .33073 Metetra
0 .076 .176 r
.44112 .33073 .44659 .3403 .45614 .3411 .45076 .32784 Metetra
0 .086 .185 r
.45076 .32784 .45614 .3411 .46581 .33866 .46039 .3271 Metetra
0 .096 .192 r
.46039 .3271 .46581 .33866 .4755 .33722 .47009 .32564 Metetra
0 .104 .198 r
.47009 .32564 .4755 .33722 .48526 .33479 .47985 .32304 Metetra
0 .103 .198 r
.47985 .32304 .48526 .33479 .49507 .33044 .48966 .31873 Metetra
0 .102 .196 r
.48966 .31873 .49507 .33044 .5049 .32731 .4995 .3156 Metetra
0 .097 .193 r
.4995 .3156 .5049 .32731 .51478 .3221 .50939 .31042 Metetra
0 .088 .186 r
.50939 .31042 .51478 .3221 .52468 .31748 .5193 .30467 Metetra
0 .078 .178 r
.5193 .30467 .52468 .31748 .5346 .31043 .52924 .30046 Metetra
0 .066 .168 r
.52924 .30046 .5346 .31043 .54454 .30406 .53919 .29427 Metetra
0 .054 .157 r
.53919 .29427 .54454 .30406 .5545 .29771 .54918 .28859 Metetra
0 .044 .147 r
.54918 .28859 .5545 .29771 .56448 .29155 .55918 .28312 Metetra
0 .036 .138 r
.55918 .28312 .56448 .29155 .57448 .28584 .56921 .27802 Metetra
0 .031 .131 r
.56921 .27802 .57448 .28584 .58452 .28081 .57928 .27346 Metetra
0 .027 .127 r
.57928 .27346 .58452 .28081 .59459 .27614 .58939 .26922 Metetra
0 .025 .124 r
.58939 .26922 .59459 .27614 .60471 .27191 .59954 .26524 Metetra
0 .024 .122 r
.59954 .26524 .60471 .27191 .61487 .26806 .60973 .26156 Metetra
0 .024 .122 r
.60973 .26156 .61487 .26806 .62507 .26465 .61995 .25789 Metetra
0 .024 .122 r
.61995 .25789 .62507 .26465 .63532 .26112 .63022 .25434 Metetra
0 .024 .122 r
.63022 .25434 .63532 .26112 .64559 .2575 .64052 .25077 Metetra
0 .024 .122 r
.64052 .25077 .64559 .2575 .65591 .2539 .65087 .24714 Metetra
0 .024 .122 r
.65087 .24714 .65591 .2539 .66627 .25031 .66125 .24346 Metetra
0 .024 .122 r
.66125 .24346 .66627 .25031 .67666 .24667 .67166 .23977 Metetra
0 .024 .122 r
.67166 .23977 .67666 .24667 .68709 .24296 .68212 .23611 Metetra
0 .024 .122 r
.68212 .23611 .68709 .24296 .69755 .23928 .69261 .23243 Metetra
0 .024 .122 r
.69261 .23243 .69755 .23928 .70806 .23555 .70315 .22875 Metetra
0 .024 .122 r
.70315 .22875 .70806 .23555 .7186 .23187 .71372 .22504 Metetra
0 .024 .122 r
.71372 .22504 .7186 .23187 .72919 .22817 .72434 .22132 Metetra
0 .024 .122 r
.72434 .22132 .72919 .22817 .73982 .22447 .73499 .21759 Metetra
0 .024 .122 r
.73499 .21759 .73982 .22447 .75048 .22075 .74568 .21385 Metetra
0 .024 .122 r
.74568 .21385 .75048 .22075 .76118 .217 .75642 .2101 Metetra
0 .024 .122 r
.75642 .2101 .76118 .217 .77193 .21326 .76719 .2063 Metetra
0 .023 .122 r
.76719 .2063 .77193 .21326 .78272 .2095 .778 .20251 Metetra
0 .023 .122 r
.778 .20251 .78272 .2095 .79354 .20572 .78886 .19871 Metetra
0 .023 .122 r
.78886 .19871 .79354 .20572 .80441 .20193 .79975 .19489 Metetra
0 .023 .122 r
.79975 .19489 .80441 .20193 .81532 .19813 .81069 .19107 Metetra
0 .023 .121 r
.18785 .40141 .19394 .4071 .2027 .40402 .19662 .39833 Metetra
0 .023 .121 r
.19662 .39833 .2027 .40402 .21149 .40094 .20543 .39524 Metetra
0 .023 .121 r
.20543 .39524 .21149 .40094 .22031 .39785 .21427 .39213 Metetra
0 .023 .121 r
.21427 .39213 .22031 .39785 .22916 .39477 .22314 .389 Metetra
0 .023 .122 r
.22314 .389 .22916 .39477 .23804 .39166 .23204 .38588 Metetra
0 .024 .122 r
.23204 .38588 .23804 .39166 .24695 .38855 .24097 .38274 Metetra
0 .024 .122 r
.24097 .38274 .24695 .38855 .2559 .3854 .24992 .37962 Metetra
0 .024 .122 r
.24992 .37962 .2559 .3854 .26487 .38226 .25892 .37642 Metetra
0 .023 .122 r
.25892 .37642 .26487 .38226 .27387 .3791 .26794 .37324 Metetra
0 .024 .122 r
.26794 .37324 .27387 .3791 .2829 .37596 .27699 .37008 Metetra
0 .024 .122 r
.27699 .37008 .2829 .37596 .29197 .37277 .28607 .36691 Metetra
0 .024 .122 r
.28607 .36691 .29197 .37277 .30107 .36958 .29519 .36366 Metetra
0 .024 .122 r
.29519 .36366 .30107 .36958 .31019 .36641 .30434 .36046 Metetra
0 .024 .122 r
.30434 .36046 .31019 .36641 .31935 .36321 .31351 .35724 Metetra
0 .024 .122 r
.31351 .35724 .31935 .36321 .32854 .36004 .32272 .35403 Metetra
0 .024 .122 r
.32272 .35403 .32854 .36004 .33777 .35681 .33197 .35078 Metetra
0 .024 .122 r
.33197 .35078 .33777 .35681 .34702 .35355 .34124 .34751 Metetra
0 .024 .122 r
.34124 .34751 .34702 .35355 .35631 .35026 .35055 .34419 Metetra
0 .024 .122 r
.35055 .34419 .35631 .35026 .36563 .34707 .35989 .34096 Metetra
0 .024 .122 r
.35989 .34096 .36563 .34707 .37498 .34388 .36927 .33766 Metetra
0 .024 .123 r
.36927 .33766 .37498 .34388 .38435 .34092 .37866 .33449 Metetra
0 .025 .124 r
.37866 .33449 .38435 .34092 .39374 .33826 .38809 .33159 Metetra
0 .027 .127 r
.38809 .33159 .39374 .33826 .40316 .33587 .39754 .32882 Metetra
0 .031 .131 r
.39754 .32882 .40316 .33587 .4126 .33405 .40701 .32639 Metetra
0 .035 .136 r
.40701 .32639 .4126 .33405 .42207 .33254 .41652 .32422 Metetra
0 .041 .143 r
.41652 .32422 .42207 .33254 .43158 .33129 .42606 .32237 Metetra
0 .048 .151 r
.42606 .32237 .43158 .33129 .44112 .33073 .43566 .31961 Metetra
0 .055 .157 r
.43566 .31961 .44112 .33073 .45076 .32784 .44526 .31879 Metetra
0 .063 .165 r
.44526 .31879 .45076 .32784 .46039 .3271 .45492 .31714 Metetra
0 .072 .173 r
.45492 .31714 .46039 .3271 .47009 .32564 .46463 .31502 Metetra
0 .077 .177 r
.46463 .31502 .47009 .32564 .47985 .32304 .47441 .31205 Metetra
0 .077 .177 r
.47441 .31205 .47985 .32304 .48966 .31873 .48423 .30776 Metetra
0 .075 .176 r
.48423 .30776 .48966 .31873 .4995 .3156 .49408 .30476 Metetra
0 .073 .174 r
.49408 .30476 .4995 .3156 .50939 .31042 .50397 .30012 Metetra
0 .065 .167 r
.50397 .30012 .50939 .31042 .5193 .30467 .5139 .29503 Metetra
0 .056 .159 r
.5139 .29503 .5193 .30467 .52924 .30046 .52385 .28876 Metetra
0 .05 .152 r
.52385 .28876 .52924 .30046 .53919 .29427 .53383 .28508 Metetra
0 .043 .145 r
.53383 .28508 .53919 .29427 .54918 .28859 .54383 .27992 Metetra
0 .036 .138 r
.54383 .27992 .54918 .28859 .55918 .28312 .55386 .27504 Metetra
0 .031 .132 r
.55386 .27504 .55918 .28312 .56921 .27802 .56392 .27051 Metetra
0 .028 .127 r
.56392 .27051 .56921 .27802 .57928 .27346 .57402 .26629 Metetra
0 .026 .125 r
.57402 .26629 .57928 .27346 .58939 .26922 .58416 .26232 Metetra
0 .024 .123 r
.58416 .26232 .58939 .26922 .59954 .26524 .59433 .25848 Metetra
0 .024 .122 r
.59433 .25848 .59954 .26524 .60973 .26156 .60455 .2549 Metetra
0 .024 .122 r
.60455 .2549 .60973 .26156 .61995 .25789 .6148 .25123 Metetra
0 .024 .122 r
.6148 .25123 .61995 .25789 .63022 .25434 .62509 .24764 Metetra
0 .024 .122 r
.62509 .24764 .63022 .25434 .64052 .25077 .63542 .24402 Metetra
0 .024 .122 r
.63542 .24402 .64052 .25077 .65087 .24714 .64579 .24037 Metetra
0 .024 .122 r
.64579 .24037 .65087 .24714 .66125 .24346 .65619 .23669 Metetra
0 .024 .122 r
.65619 .23669 .66125 .24346 .67166 .23977 .66664 .23299 Metetra
0 .024 .122 r
.66664 .23299 .67166 .23977 .68212 .23611 .67712 .22932 Metetra
0 .024 .122 r
.67712 .22932 .68212 .23611 .69261 .23243 .68765 .22563 Metetra
0 .024 .122 r
.68765 .22563 .69261 .23243 .70315 .22875 .69821 .22188 Metetra
0 .023 .122 r
.69821 .22188 .70315 .22875 .71372 .22504 .70881 .21814 Metetra
0 .023 .122 r
.70881 .21814 .71372 .22504 .72434 .22132 .71945 .21439 Metetra
0 .023 .122 r
.71945 .21439 .72434 .22132 .73499 .21759 .73013 .21066 Metetra
0 .024 .122 r
.73013 .21066 .73499 .21759 .74568 .21385 .74085 .2069 Metetra
0 .024 .122 r
.74085 .2069 .74568 .21385 .75642 .2101 .75161 .20308 Metetra
0 .024 .122 r
.75161 .20308 .75642 .2101 .76719 .2063 .76241 .19931 Metetra
0 .024 .122 r
.76241 .19931 .76719 .2063 .778 .20251 .77326 .19549 Metetra
0 .023 .122 r
.77326 .19549 .778 .20251 .78886 .19871 .78414 .19165 Metetra
0 .023 .122 r
.78414 .19165 .78886 .19871 .79975 .19489 .79506 .1878 Metetra
0 .023 .122 r
.79506 .1878 .79975 .19489 .81069 .19107 .80603 .18394 Metetra
0 .023 .121 r
.18172 .3957 .18785 .40141 .19662 .39833 .19051 .3926 Metetra
0 .023 .121 r
.19051 .3926 .19662 .39833 .20543 .39524 .19934 .38948 Metetra
0 .023 .121 r
.19934 .38948 .20543 .39524 .21427 .39213 .20819 .38635 Metetra
0 .023 .121 r
.20819 .38635 .21427 .39213 .22314 .389 .21707 .38324 Metetra
0 .023 .122 r
.21707 .38324 .22314 .389 .23204 .38588 .22599 .38007 Metetra
0 .023 .122 r
.22599 .38007 .23204 .38588 .24097 .38274 .23494 .37691 Metetra
0 .024 .122 r
.23494 .37691 .24097 .38274 .24992 .37962 .24392 .37374 Metetra
0 .024 .122 r
.24392 .37374 .24992 .37962 .25892 .37642 .25292 .37058 Metetra
0 .023 .122 r
.25292 .37058 .25892 .37642 .26794 .37324 .26197 .36737 Metetra
0 .024 .122 r
.26197 .36737 .26794 .37324 .27699 .37008 .27104 .36417 Metetra
0 .024 .122 r
.27104 .36417 .27699 .37008 .28607 .36691 .28014 .36097 Metetra
0 .024 .122 r
.28014 .36097 .28607 .36691 .29519 .36366 .28927 .35773 Metetra
0 .024 .122 r
.28927 .35773 .29519 .36366 .30434 .36046 .29844 .35448 Metetra
0 .024 .122 r
.29844 .35448 .30434 .36046 .31351 .35724 .30764 .35124 Metetra
0 .024 .122 r
.30764 .35124 .31351 .35724 .32272 .35403 .31687 .34797 Metetra
0 .024 .122 r
.31687 .34797 .32272 .35403 .33197 .35078 .32613 .3447 Metetra
0 .024 .122 r
.32613 .3447 .33197 .35078 .34124 .34751 .33543 .34142 Metetra
0 .024 .122 r
.33543 .34142 .34124 .34751 .35055 .34419 .34475 .33813 Metetra
0 .024 .122 r
.34475 .33813 .35055 .34419 .35989 .34096 .35411 .33485 Metetra
0 .024 .122 r
.35411 .33485 .35989 .34096 .36927 .33766 .36351 .33156 Metetra
0 .024 .122 r
.36351 .33156 .36927 .33766 .37866 .33449 .37293 .32823 Metetra
0 .024 .123 r
.37293 .32823 .37866 .33449 .38809 .33159 .38238 .32518 Metetra
0 .026 .124 r
.38238 .32518 .38809 .33159 .39754 .32882 .39187 .32207 Metetra
0 .027 .127 r
.39187 .32207 .39754 .32882 .40701 .32639 .40137 .31926 Metetra
0 .03 .13 r
.40137 .31926 .40701 .32639 .41652 .32422 .41091 .31662 Metetra
0 .034 .135 r
.41091 .31662 .41652 .32422 .42606 .32237 .42049 .31401 Metetra
0 .037 .139 r
.42049 .31401 .42606 .32237 .43566 .31961 .4301 .3114 Metetra
0 .042 .144 r
.4301 .3114 .43566 .31961 .44526 .31879 .43973 .30975 Metetra
0 .049 .152 r
.43973 .30975 .44526 .31879 .45492 .31714 .44941 .30741 Metetra
0 .054 .157 r
.44941 .30741 .45492 .31714 .46463 .31502 .45915 .3048 Metetra
0 .057 .16 r
.45915 .3048 .46463 .31502 .47441 .31205 .46894 .3016 Metetra
0 .056 .159 r
.46894 .3016 .47441 .31205 .48423 .30776 .47878 .29735 Metetra
0 .056 .158 r
.47878 .29735 .48423 .30776 .49408 .30476 .48863 .29443 Metetra
0 .055 .157 r
.48863 .29443 .49408 .30476 .50397 .30012 .49853 .29021 Metetra
0 .05 .153 r
.49853 .29021 .50397 .30012 .5139 .29503 .50847 .28582 Metetra
0 .044 .146 r
.50847 .28582 .5139 .29503 .52385 .28876 .51843 .2811 Metetra
0 .038 .14 r
.51843 .2811 .52385 .28876 .53383 .28508 .52843 .27572 Metetra
0 .034 .136 r
.52843 .27572 .53383 .28508 .54383 .27992 .53845 .27174 Metetra
0 .031 .131 r
.53845 .27174 .54383 .27992 .55386 .27504 .54851 .26738 Metetra
0 .028 .127 r
.54851 .26738 .55386 .27504 .56392 .27051 .5586 .26327 Metetra
0 .026 .125 r
.5586 .26327 .56392 .27051 .57402 .26629 .56873 .25934 Metetra
0 .025 .123 r
.56873 .25934 .57402 .26629 .58416 .26232 .57889 .25547 Metetra
0 .024 .122 r
.57889 .25547 .58416 .26232 .59433 .25848 .58909 .25181 Metetra
0 .024 .122 r
.58909 .25181 .59433 .25848 .60455 .2549 .59933 .24819 Metetra
0 .024 .122 r
.59933 .24819 .60455 .2549 .6148 .25123 .60961 .24453 Metetra
0 .024 .122 r
.60961 .24453 .6148 .25123 .62509 .24764 .61993 .24089 Metetra
0 .024 .122 r
.61993 .24089 .62509 .24764 .63542 .24402 .63028 .23723 Metetra
0 .024 .122 r
.63028 .23723 .63542 .24402 .64579 .24037 .64068 .23356 Metetra
0 .024 .122 r
.64068 .23356 .64579 .24037 .65619 .23669 .65111 .22987 Metetra
0 .024 .122 r
.65111 .22987 .65619 .23669 .66664 .23299 .66158 .22617 Metetra
0 .024 .122 r
.66158 .22617 .66664 .23299 .67712 .22932 .67209 .22247 Metetra
0 .024 .122 r
.67209 .22247 .67712 .22932 .68765 .22563 .68264 .21873 Metetra
0 .024 .122 r
.68264 .21873 .68765 .22563 .69821 .22188 .69323 .215 Metetra
0 .023 .122 r
.69323 .215 .69821 .22188 .70881 .21814 .70386 .21124 Metetra
0 .023 .122 r
.70386 .21124 .70881 .21814 .71945 .21439 .71453 .20748 Metetra
0 .023 .122 r
.71453 .20748 .71945 .21439 .73013 .21066 .72523 .20368 Metetra
0 .024 .122 r
.72523 .20368 .73013 .21066 .74085 .2069 .73598 .19988 Metetra
0 .024 .122 r
.73598 .19988 .74085 .2069 .75161 .20308 .74677 .19609 Metetra
0 .024 .122 r
.74677 .19609 .75161 .20308 .76241 .19931 .7576 .19225 Metetra
0 .024 .122 r
.7576 .19225 .76241 .19931 .77326 .19549 .76847 .1884 Metetra
0 .023 .122 r
.76847 .1884 .77326 .19549 .78414 .19165 .77939 .18454 Metetra
0 .023 .122 r
.77939 .18454 .78414 .19165 .79506 .1878 .79034 .18068 Metetra
0 .023 .122 r
.79034 .18068 .79506 .1878 .80603 .18394 .80134 .17679 Metetra
0 .023 .121 r
.17555 .38995 .18172 .3957 .19051 .3926 .18436 .38684 Metetra
0 .023 .121 r
.18436 .38684 .19051 .3926 .19934 .38948 .1932 .3837 Metetra
0 .023 .121 r
.1932 .3837 .19934 .38948 .20819 .38635 .20207 .38055 Metetra
0 .023 .122 r
.20207 .38055 .20819 .38635 .21707 .38324 .21097 .3774 Metetra
0 .023 .122 r
.21097 .3774 .21707 .38324 .22599 .38007 .21991 .37423 Metetra
0 .023 .122 r
.21991 .37423 .22599 .38007 .23494 .37691 .22887 .37106 Metetra
0 .023 .122 r
.22887 .37106 .23494 .37691 .24392 .37374 .23787 .36785 Metetra
0 .024 .122 r
.23787 .36785 .24392 .37374 .25292 .37058 .2469 .36466 Metetra
0 .024 .122 r
.2469 .36466 .25292 .37058 .26197 .36737 .25596 .36143 Metetra
0 .023 .122 r
.25596 .36143 .26197 .36737 .27104 .36417 .26505 .35821 Metetra
0 .024 .122 r
.26505 .35821 .27104 .36417 .28014 .36097 .27417 .35499 Metetra
0 .024 .122 r
.27417 .35499 .28014 .36097 .28927 .35773 .28332 .35172 Metetra
0 .024 .122 r
.28332 .35172 .28927 .35773 .29844 .35448 .29251 .34848 Metetra
0 .023 .122 r
.29251 .34848 .29844 .35448 .30764 .35124 .30173 .34519 Metetra
0 .023 .122 r
.30173 .34519 .30764 .35124 .31687 .34797 .31097 .34191 Metetra
0 .023 .122 r
.31097 .34191 .31687 .34797 .32613 .3447 .32026 .33862 Metetra
0 .023 .122 r
.32026 .33862 .32613 .3447 .33543 .34142 .32957 .3353 Metetra
0 .023 .122 r
.32957 .3353 .33543 .34142 .34475 .33813 .33892 .332 Metetra
0 .024 .122 r
.33892 .332 .34475 .33813 .35411 .33485 .3483 .32868 Metetra
0 .024 .122 r
.3483 .32868 .35411 .33485 .36351 .33156 .35771 .32533 Metetra
0 .024 .122 r
.35771 .32533 .36351 .33156 .37293 .32823 .36716 .32198 Metetra
0 .024 .122 r
.36716 .32198 .37293 .32823 .38238 .32518 .37664 .31869 Metetra
0 .024 .123 r
.37664 .31869 .38238 .32518 .39187 .32207 .38615 .31544 Metetra
0 .025 .124 r
.38615 .31544 .39187 .32207 .40137 .31926 .39568 .31238 Metetra
0 .027 .126 r
.39568 .31238 .40137 .31926 .41091 .31662 .40526 .3093 Metetra
0 .028 .128 r
.40526 .3093 .41091 .31662 .42049 .31401 .41488 .30566 Metetra
0 .031 .132 r
.41488 .30566 .42049 .31401 .4301 .3114 .42447 .30445 Metetra
0 .036 .137 r
.42447 .30445 .4301 .3114 .43973 .30975 .43415 .30147 Metetra
0 .039 .141 r
.43415 .30147 .43973 .30975 .44941 .30741 .44387 .2985 Metetra
0 .042 .144 r
.44387 .2985 .44941 .30741 .45915 .3048 .45362 .29551 Metetra
0 .043 .145 r
.45362 .29551 .45915 .3048 .46894 .3016 .46343 .29213 Metetra
0 .042 .144 r
.46343 .29213 .46894 .3016 .47878 .29735 .47328 .28791 Metetra
0 .042 .144 r
.47328 .28791 .47878 .29735 .48863 .29443 .48314 .28499 Metetra
0 .042 .144 r
.48314 .28499 .48863 .29443 .49853 .29021 .49306 .28105 Metetra
0 .039 .141 r
.49306 .28105 .49853 .29021 .50847 .28582 .50301 .2771 Metetra
0 .037 .138 r
.50301 .2771 .50847 .28582 .51843 .2811 .51299 .27299 Metetra
0 .032 .132 r
.51299 .27299 .51843 .2811 .52843 .27572 .52301 .2675 Metetra
0 .028 .128 r
.52301 .2675 .52843 .27572 .53845 .27174 .53305 .26404 Metetra
0 .027 .126 r
.53305 .26404 .53845 .27174 .54851 .26738 .54313 .26011 Metetra
0 .026 .124 r
.54313 .26011 .54851 .26738 .5586 .26327 .55325 .25619 Metetra
0 .025 .123 r
.55325 .25619 .5586 .26327 .56873 .25934 .5634 .25244 Metetra
0 .024 .122 r
.5634 .25244 .56873 .25934 .57889 .25547 .57359 .24874 Metetra
0 .024 .122 r
.57359 .24874 .57889 .25547 .58909 .25181 .58382 .24509 Metetra
0 .024 .122 r
.58382 .24509 .58909 .25181 .59933 .24819 .59408 .24145 Metetra
0 .024 .122 r
.59408 .24145 .59933 .24819 .60961 .24453 .60439 .2378 Metetra
0 .023 .122 r
.60439 .2378 .60961 .24453 .61993 .24089 .61473 .2341 Metetra
0 .023 .122 r
.61473 .2341 .61993 .24089 .63028 .23723 .62511 .23043 Metetra
0 .023 .122 r
.62511 .23043 .63028 .23723 .64068 .23356 .63553 .22673 Metetra
0 .023 .122 r
.63553 .22673 .64068 .23356 .65111 .22987 .64599 .22301 Metetra
0 .023 .122 r
.64599 .22301 .65111 .22987 .66158 .22617 .65649 .21931 Metetra
0 .023 .122 r
.65649 .21931 .66158 .22617 .67209 .22247 .66702 .21556 Metetra
0 .023 .122 r
.66702 .21556 .67209 .22247 .68264 .21873 .6776 .21182 Metetra
0 .023 .122 r
.6776 .21182 .68264 .21873 .69323 .215 .68822 .20803 Metetra
0 .023 .122 r
.68822 .20803 .69323 .215 .70386 .21124 .69887 .20425 Metetra
0 .023 .122 r
.69887 .20425 .70386 .21124 .71453 .20748 .70957 .20045 Metetra
0 .023 .122 r
.70957 .20045 .71453 .20748 .72523 .20368 .72031 .19665 Metetra
0 .023 .122 r
.72031 .19665 .72523 .20368 .73598 .19988 .73108 .19282 Metetra
0 .023 .122 r
.73108 .19282 .73598 .19988 .74677 .19609 .7419 .18899 Metetra
0 .023 .122 r
.7419 .18899 .74677 .19609 .7576 .19225 .75276 .18512 Metetra
0 .023 .122 r
.75276 .18512 .7576 .19225 .76847 .1884 .76366 .18127 Metetra
0 .023 .122 r
.76366 .18127 .76847 .1884 .77939 .18454 .7746 .17739 Metetra
0 .023 .122 r
.7746 .17739 .77939 .18454 .79034 .18068 .78559 .17348 Metetra
0 .023 .122 r
.78559 .17348 .79034 .18068 .80134 .17679 .79661 .16956 Metetra
0 .023 .121 r
.16933 .38418 .17555 .38995 .18436 .38684 .17816 .38103 Metetra
0 .023 .121 r
.17816 .38103 .18436 .38684 .1932 .3837 .18702 .37788 Metetra
0 .023 .121 r
.18702 .37788 .1932 .3837 .20207 .38055 .19591 .37473 Metetra
0 .023 .122 r
.19591 .37473 .20207 .38055 .21097 .3774 .20484 .37152 Metetra
0 .023 .121 r
.20484 .37152 .21097 .3774 .21991 .37423 .21379 .36833 Metetra
0 .023 .122 r
.21379 .36833 .21991 .37423 .22887 .37106 .22277 .36515 Metetra
0 .023 .122 r
.22277 .36515 .22887 .37106 .23787 .36785 .23179 .36192 Metetra
0 .023 .121 r
.23179 .36192 .23787 .36785 .2469 .36466 .24083 .3587 Metetra
0 .023 .122 r
.24083 .3587 .2469 .36466 .25596 .36143 .24991 .35549 Metetra
0 .023 .122 r
.24991 .35549 .25596 .36143 .26505 .35821 .25902 .35222 Metetra
0 .023 .122 r
.25902 .35222 .26505 .35821 .27417 .35499 .26816 .34898 Metetra
0 .023 .122 r
.26816 .34898 .27417 .35499 .28332 .35172 .27733 .3457 Metetra
0 .023 .122 r
.27733 .3457 .28332 .35172 .29251 .34848 .28653 .34241 Metetra
0 .023 .122 r
.28653 .34241 .29251 .34848 .30173 .34519 .29577 .33912 Metetra
0 .023 .121 r
.29577 .33912 .30173 .34519 .31097 .34191 .30504 .33581 Metetra
0 .023 .121 r
.30504 .33581 .31097 .34191 .32026 .33862 .31434 .3325 Metetra
0 .023 .121 r
.31434 .3325 .32026 .33862 .32957 .3353 .32368 .32917 Metetra
0 .023 .122 r
.32368 .32917 .32957 .3353 .33892 .332 .33305 .32584 Metetra
0 .024 .122 r
.33305 .32584 .33892 .332 .3483 .32868 .34245 .3225 Metetra
0 .024 .122 r
.34245 .3225 .3483 .32868 .35771 .32533 .35188 .31914 Metetra
0 .024 .122 r
.35188 .31914 .35771 .32533 .36716 .32198 .36135 .31576 Metetra
0 .024 .122 r
.36135 .31576 .36716 .32198 .37664 .31869 .37085 .31244 Metetra
0 .024 .122 r
.37085 .31244 .37664 .31869 .38615 .31544 .38038 .30902 Metetra
0 .024 .123 r
.38038 .30902 .38615 .31544 .39568 .31238 .38995 .30576 Metetra
0 .025 .123 r
.38995 .30576 .39568 .31238 .40526 .3093 .39955 .30239 Metetra
0 .025 .124 r
.39955 .30239 .40526 .3093 .41488 .30566 .40918 .29909 Metetra
0 .028 .127 r
.40918 .29909 .41488 .30566 .42447 .30445 .41882 .29674 Metetra
0 .031 .131 r
.41882 .29674 .42447 .30445 .43415 .30147 .42853 .29353 Metetra
0 .032 .133 r
.42853 .29353 .43415 .30147 .44387 .2985 .43827 .29031 Metetra
0 .033 .134 r
.43827 .29031 .44387 .2985 .45362 .29551 .44805 .2871 Metetra
0 .034 .135 r
.44805 .2871 .45362 .29551 .46343 .29213 .45787 .2836 Metetra
0 .033 .134 r
.45787 .2836 .46343 .29213 .47328 .28791 .46773 .27954 Metetra
0 .033 .134 r
.46773 .27954 .47328 .28791 .48314 .28499 .47762 .27648 Metetra
0 .033 .134 r
.47762 .27648 .48314 .28499 .49306 .28105 .48755 .27268 Metetra
0 .032 .133 r
.48755 .27268 .49306 .28105 .50301 .2771 .49751 .26894 Metetra
0 .031 .131 r
.49751 .26894 .50301 .2771 .51299 .27299 .50751 .26513 Metetra
0 .028 .128 r
.50751 .26513 .51299 .27299 .52301 .2675 .51755 .26127 Metetra
0 .026 .125 r
.51755 .26127 .52301 .2675 .53305 .26404 .52762 .2567 Metetra
0 .025 .124 r
.52762 .2567 .53305 .26404 .54313 .26011 .53772 .25313 Metetra
0 .024 .123 r
.53772 .25313 .54313 .26011 .55325 .25619 .54786 .2494 Metetra
0 .024 .122 r
.54786 .2494 .55325 .25619 .5634 .25244 .55804 .24572 Metetra
0 .024 .122 r
.55804 .24572 .5634 .25244 .57359 .24874 .56826 .24199 Metetra
0 .023 .122 r
.56826 .24199 .57359 .24874 .58382 .24509 .57851 .23836 Metetra
0 .023 .122 r
.57851 .23836 .58382 .24509 .59408 .24145 .5888 .2347 Metetra
0 .023 .122 r
.5888 .2347 .59408 .24145 .60439 .2378 .59913 .23099 Metetra
0 .023 .121 r
.59913 .23099 .60439 .2378 .61473 .2341 .6095 .22729 Metetra
0 .023 .121 r
.6095 .22729 .61473 .2341 .62511 .23043 .61991 .22358 Metetra
0 .023 .121 r
.61991 .22358 .62511 .23043 .63553 .22673 .63035 .21986 Metetra
0 .023 .121 r
.63035 .21986 .63553 .22673 .64599 .22301 .64084 .21612 Metetra
0 .023 .121 r
.64084 .21612 .64599 .22301 .65649 .21931 .65136 .21237 Metetra
0 .023 .122 r
.65136 .21237 .65649 .21931 .66702 .21556 .66192 .20863 Metetra
0 .023 .122 r
.66192 .20863 .66702 .21556 .6776 .21182 .67253 .20483 Metetra
0 .023 .121 r
.67253 .20483 .6776 .21182 .68822 .20803 .68317 .20104 Metetra
0 .023 .121 r
.68317 .20104 .68822 .20803 .69887 .20425 .69385 .19723 Metetra
0 .023 .121 r
.69385 .19723 .69887 .20425 .70957 .20045 .70458 .19342 Metetra
0 .023 .121 r
.70458 .19342 .70957 .20045 .72031 .19665 .71534 .18958 Metetra
0 .023 .122 r
.71534 .18958 .72031 .19665 .73108 .19282 .72615 .18574 Metetra
0 .023 .122 r
.72615 .18574 .73108 .19282 .7419 .18899 .73699 .18186 Metetra
0 .023 .122 r
.73699 .18186 .7419 .18899 .75276 .18512 .74788 .178 Metetra
0 .023 .122 r
.74788 .178 .75276 .18512 .76366 .18127 .75881 .1741 Metetra
0 .023 .122 r
.75881 .1741 .76366 .18127 .7746 .17739 .76978 .17017 Metetra
0 .023 .121 r
.76978 .17017 .7746 .17739 .78559 .17348 .7808 .16624 Metetra
0 .023 .121 r
.7808 .16624 .78559 .17348 .79661 .16956 .79185 .1623 Metetra
0 .023 .121 r
.16308 .37838 .16933 .38418 .17816 .38103 .17193 .3752 Metetra
0 .023 .121 r
.17193 .3752 .17816 .38103 .18702 .37788 .18081 .37202 Metetra
0 .023 .122 r
.18081 .37202 .18702 .37788 .19591 .37473 .18972 .36883 Metetra
0 .023 .122 r
.18972 .36883 .19591 .37473 .20484 .37152 .19866 .36565 Metetra
0 .023 .121 r
.19866 .36565 .20484 .37152 .21379 .36833 .20763 .36243 Metetra
0 .023 .122 r
.20763 .36243 .21379 .36833 .22277 .36515 .21663 .3592 Metetra
0 .023 .121 r
.21663 .3592 .22277 .36515 .23179 .36192 .22566 .35597 Metetra
0 .023 .121 r
.22566 .35597 .23179 .36192 .24083 .3587 .23472 .35273 Metetra
0 .023 .122 r
.23472 .35273 .24083 .3587 .24991 .35549 .24382 .34948 Metetra
0 .023 .122 r
.24382 .34948 .24991 .35549 .25902 .35222 .25295 .34621 Metetra
0 .023 .122 r
.25295 .34621 .25902 .35222 .26816 .34898 .26211 .34293 Metetra
0 .024 .122 r
.26211 .34293 .26816 .34898 .27733 .3457 .2713 .33964 Metetra
0 .024 .122 r
.2713 .33964 .27733 .3457 .28653 .34241 .28052 .33635 Metetra
0 .023 .122 r
.28052 .33635 .28653 .34241 .29577 .33912 .28978 .33302 Metetra
0 .023 .122 r
.28978 .33302 .29577 .33912 .30504 .33581 .29907 .32969 Metetra
0 .023 .122 r
.29907 .32969 .30504 .33581 .31434 .3325 .30839 .32636 Metetra
0 .023 .122 r
.30839 .32636 .31434 .3325 .32368 .32917 .31774 .32301 Metetra
0 .023 .122 r
.31774 .32301 .32368 .32917 .33305 .32584 .32713 .31966 Metetra
0 .024 .122 r
.32713 .31966 .33305 .32584 .34245 .3225 .33655 .31633 Metetra
0 .024 .122 r
.33655 .31633 .34245 .3225 .35188 .31914 .34601 .3129 Metetra
0 .024 .122 r
.34601 .3129 .35188 .31914 .36135 .31576 .3555 .3095 Metetra
0 .024 .122 r
.3555 .3095 .36135 .31576 .37085 .31244 .36502 .30613 Metetra
0 .024 .122 r
.36502 .30613 .37085 .31244 .38038 .30902 .37458 .30272 Metetra
0 .024 .122 r
.37458 .30272 .38038 .30902 .38995 .30576 .38416 .29934 Metetra
0 .024 .122 r
.38416 .29934 .38995 .30576 .39955 .30239 .39379 .29584 Metetra
0 .025 .123 r
.39379 .29584 .39955 .30239 .40918 .29909 .40342 .29334 Metetra
0 .026 .125 r
.40342 .29334 .40918 .29909 .41882 .29674 .41312 .28969 Metetra
0 .027 .127 r
.41312 .28969 .41882 .29674 .42853 .29353 .42285 .28629 Metetra
0 .028 .127 r
.42285 .28629 .42853 .29353 .43827 .29031 .43261 .2829 Metetra
0 .028 .128 r
.43261 .2829 .43827 .29031 .44805 .2871 .44241 .27954 Metetra
0 .029 .129 r
.44241 .27954 .44805 .2871 .45787 .2836 .45225 .27599 Metetra
0 .028 .128 r
.45225 .27599 .45787 .2836 .46773 .27954 .46214 .27221 Metetra
0 .028 .128 r
.46214 .27221 .46773 .27954 .47762 .27648 .47204 .26887 Metetra
0 .028 .128 r
.47204 .26887 .47762 .27648 .48755 .27268 .48199 .26518 Metetra
0 .028 .127 r
.48199 .26518 .48755 .27268 .49751 .26894 .49198 .26157 Metetra
0 .027 .127 r
.49198 .26157 .49751 .26894 .50751 .26513 .502 .25802 Metetra
0 .027 .127 r
.502 .25802 .50751 .26513 .51755 .26127 .51205 .25481 Metetra
0 .026 .125 r
.51205 .25481 .51755 .26127 .52762 .2567 .52215 .25001 Metetra
0 .024 .122 r
.52215 .25001 .52762 .2567 .53772 .25313 .53228 .24624 Metetra
0 .024 .122 r
.53228 .24624 .53772 .25313 .54786 .2494 .54244 .24257 Metetra
0 .024 .122 r
.54244 .24257 .54786 .2494 .55804 .24572 .55264 .23892 Metetra
0 .024 .122 r
.55264 .23892 .55804 .24572 .56826 .24199 .56288 .23524 Metetra
0 .023 .122 r
.56288 .23524 .56826 .24199 .57851 .23836 .57316 .23158 Metetra
0 .024 .122 r
.57316 .23158 .57851 .23836 .5888 .2347 .58348 .2279 Metetra
0 .024 .122 r
.58348 .2279 .5888 .2347 .59913 .23099 .59384 .22417 Metetra
0 .023 .121 r
.59384 .22417 .59913 .23099 .6095 .22729 .60423 .22044 Metetra
0 .023 .121 r
.60423 .22044 .6095 .22729 .61991 .22358 .61466 .21672 Metetra
0 .023 .121 r
.61466 .21672 .61991 .22358 .63035 .21986 .62514 .21297 Metetra
0 .023 .121 r
.62514 .21297 .63035 .21986 .64084 .21612 .63565 .2092 Metetra
0 .023 .121 r
.63565 .2092 .64084 .21612 .65136 .21237 .6462 .20543 Metetra
0 .024 .122 r
.6462 .20543 .65136 .21237 .66192 .20863 .65679 .20165 Metetra
0 .024 .122 r
.65679 .20165 .66192 .20863 .67253 .20483 .66742 .19783 Metetra
0 .023 .122 r
.66742 .19783 .67253 .20483 .68317 .20104 .67809 .19401 Metetra
0 .023 .121 r
.67809 .19401 .68317 .20104 .69385 .19723 .6888 .19018 Metetra
0 .023 .122 r
.6888 .19018 .69385 .19723 .70458 .19342 .69955 .18632 Metetra
0 .023 .122 r
.69955 .18632 .70458 .19342 .71534 .18958 .71035 .18246 Metetra
0 .024 .122 r
.71035 .18246 .71534 .18958 .72615 .18574 .72118 .17861 Metetra
0 .024 .122 r
.72118 .17861 .72615 .18574 .73699 .18186 .73205 .17468 Metetra
0 .023 .122 r
.73205 .17468 .73699 .18186 .74788 .178 .74297 .1708 Metetra
0 .024 .122 r
.74297 .1708 .74788 .178 .75881 .1741 .75393 .16686 Metetra
0 .023 .122 r
.75393 .16686 .75881 .1741 .76978 .17017 .76493 .16292 Metetra
0 .023 .121 r
.76493 .16292 .76978 .17017 .7808 .16624 .77598 .15897 Metetra
0 .023 .121 r
.77598 .15897 .7808 .16624 .79185 .1623 .78706 .155 Metetra
0 .023 .121 r
.1568 .37252 .16308 .37838 .17193 .3752 .16566 .36932 Metetra
0 .023 .121 r
.16566 .36932 .17193 .3752 .18081 .37202 .17456 .36613 Metetra
0 .023 .122 r
.17456 .36613 .18081 .37202 .18972 .36883 .18348 .36292 Metetra
0 .023 .122 r
.18348 .36292 .18972 .36883 .19866 .36565 .19244 .35971 Metetra
0 .023 .122 r
.19244 .35971 .19866 .36565 .20763 .36243 .20143 .35647 Metetra
0 .023 .122 r
.20143 .35647 .20763 .36243 .21663 .3592 .21045 .35322 Metetra
0 .023 .122 r
.21045 .35322 .21663 .3592 .22566 .35597 .2195 .34997 Metetra
0 .023 .122 r
.2195 .34997 .22566 .35597 .23472 .35273 .22858 .34671 Metetra
0 .023 .122 r
.22858 .34671 .23472 .35273 .24382 .34948 .23769 .34342 Metetra
0 .023 .122 r
.23769 .34342 .24382 .34948 .25295 .34621 .24684 .34013 Metetra
0 .023 .122 r
.24684 .34013 .25295 .34621 .26211 .34293 .25602 .33683 Metetra
0 .023 .122 r
.25602 .33683 .26211 .34293 .2713 .33964 .26523 .33352 Metetra
0 .024 .122 r
.26523 .33352 .2713 .33964 .28052 .33635 .27447 .33022 Metetra
0 .024 .122 r
.27447 .33022 .28052 .33635 .28978 .33302 .28375 .32687 Metetra
0 .023 .122 r
.28375 .32687 .28978 .33302 .29907 .32969 .29306 .32352 Metetra
0 .023 .122 r
.29306 .32352 .29907 .32969 .30839 .32636 .3024 .32016 Metetra
0 .023 .122 r
.3024 .32016 .30839 .32636 .31774 .32301 .31177 .31679 Metetra
0 .024 .122 r
.31177 .31679 .31774 .32301 .32713 .31966 .32118 .31343 Metetra
0 .024 .122 r
.32118 .31343 .32713 .31966 .33655 .31633 .33062 .31004 Metetra
0 .024 .122 r
.33062 .31004 .33655 .31633 .34601 .3129 .3401 .30661 Metetra
0 .024 .122 r
.3401 .30661 .34601 .3129 .3555 .3095 .34961 .30319 Metetra
0 .024 .122 r
.34961 .30319 .3555 .3095 .36502 .30613 .35915 .29978 Metetra
0 .024 .122 r
.35915 .29978 .36502 .30613 .37458 .30272 .36873 .29632 Metetra
0 .024 .122 r
.36873 .29632 .37458 .30272 .38416 .29934 .37834 .2929 Metetra
0 .024 .122 r
.37834 .2929 .38416 .29934 .39379 .29584 .38798 .28957 Metetra
0 .025 .124 r
.38798 .28957 .39379 .29584 .40342 .29334 .39762 .28714 Metetra
0 .026 .125 r
.39762 .28714 .40342 .29334 .41312 .28969 .40736 .28307 Metetra
0 .026 .125 r
.40736 .28307 .41312 .28969 .42285 .28629 .41712 .2795 Metetra
0 .026 .125 r
.41712 .2795 .42285 .28629 .43261 .2829 .42691 .27599 Metetra
0 .026 .125 r
.42691 .27599 .43261 .2829 .44241 .27954 .43673 .27253 Metetra
0 .026 .125 r
.43673 .27253 .44241 .27954 .45225 .27599 .44659 .26894 Metetra
0 .026 .125 r
.44659 .26894 .45225 .27599 .46214 .27221 .45649 .26542 Metetra
0 .026 .125 r
.45649 .26542 .46214 .27221 .47204 .26887 .46642 .26178 Metetra
0 .026 .125 r
.46642 .26178 .47204 .26887 .48199 .26518 .47639 .25815 Metetra
0 .026 .125 r
.47639 .25815 .48199 .26518 .49198 .26157 .4864 .25457 Metetra
0 .026 .125 r
.4864 .25457 .49198 .26157 .502 .25802 .49644 .25108 Metetra
0 .027 .126 r
.49644 .25108 .502 .25802 .51205 .25481 .50652 .24782 Metetra
0 .026 .124 r
.50652 .24782 .51205 .25481 .52215 .25001 .51664 .24334 Metetra
0 .024 .122 r
.51664 .24334 .52215 .25001 .53228 .24624 .52679 .23958 Metetra
0 .024 .122 r
.52679 .23958 .53228 .24624 .54244 .24257 .53698 .23587 Metetra
0 .024 .122 r
.53698 .23587 .54244 .24257 .55264 .23892 .54721 .23214 Metetra
0 .023 .121 r
.54721 .23214 .55264 .23892 .56288 .23524 .55748 .22843 Metetra
0 .023 .122 r
.55748 .22843 .56288 .23524 .57316 .23158 .56778 .22475 Metetra
0 .024 .122 r
.56778 .22475 .57316 .23158 .58348 .2279 .57812 .22102 Metetra
0 .024 .122 r
.57812 .22102 .58348 .2279 .59384 .22417 .5885 .21729 Metetra
0 .023 .122 r
.5885 .21729 .59384 .22417 .60423 .22044 .59892 .21353 Metetra
0 .023 .122 r
.59892 .21353 .60423 .22044 .61466 .21672 .60938 .20977 Metetra
0 .023 .122 r
.60938 .20977 .61466 .21672 .62514 .21297 .61988 .206 Metetra
0 .023 .122 r
.61988 .206 .62514 .21297 .63565 .2092 .63042 .20221 Metetra
0 .023 .122 r
.63042 .20221 .63565 .2092 .6462 .20543 .641 .19842 Metetra
0 .024 .122 r
.641 .19842 .6462 .20543 .65679 .20165 .65162 .19459 Metetra
0 .023 .122 r
.65162 .19459 .65679 .20165 .66742 .19783 .66227 .19076 Metetra
0 .023 .122 r
.66227 .19076 .66742 .19783 .67809 .19401 .67297 .1869 Metetra
0 .023 .121 r
.67297 .1869 .67809 .19401 .6888 .19018 .68371 .18305 Metetra
0 .023 .122 r
.68371 .18305 .6888 .19018 .69955 .18632 .69449 .17918 Metetra
0 .023 .122 r
.69449 .17918 .69955 .18632 .71035 .18246 .70531 .17529 Metetra
0 .024 .122 r
.70531 .17529 .71035 .18246 .72118 .17861 .71618 .17139 Metetra
0 .023 .122 r
.71618 .17139 .72118 .17861 .73205 .17468 .72708 .16745 Metetra
0 .023 .122 r
.72708 .16745 .73205 .17468 .74297 .1708 .73803 .16352 Metetra
0 .023 .122 r
.73803 .16352 .74297 .1708 .75393 .16686 .74901 .15958 Metetra
0 .023 .122 r
.74901 .15958 .75393 .16686 .76493 .16292 .76004 .1556 Metetra
0 .023 .121 r
.76004 .1556 .76493 .16292 .77598 .15897 .77112 .15162 Metetra
0 .023 .122 r
.77112 .15162 .77598 .15897 .78706 .155 .78223 .14762 Metetra
0 .023 .121 r
.15047 .36661 .1568 .37252 .16566 .36932 .15935 .3634 Metetra
0 .023 .121 r
.15935 .3634 .16566 .36932 .17456 .36613 .16826 .36019 Metetra
0 .023 .122 r
.16826 .36019 .17456 .36613 .18348 .36292 .1772 .35697 Metetra
0 .023 .122 r
.1772 .35697 .18348 .36292 .19244 .35971 .18618 .35373 Metetra
0 .023 .122 r
.18618 .35373 .19244 .35971 .20143 .35647 .19519 .35047 Metetra
0 .023 .121 r
.19519 .35047 .20143 .35647 .21045 .35322 .20422 .3472 Metetra
0 .023 .122 r
.20422 .3472 .21045 .35322 .2195 .34997 .21329 .34393 Metetra
0 .023 .122 r
.21329 .34393 .2195 .34997 .22858 .34671 .22239 .34064 Metetra
0 .023 .121 r
.22239 .34064 .22858 .34671 .23769 .34342 .23153 .33734 Metetra
0 .023 .121 r
.23153 .33734 .23769 .34342 .24684 .34013 .24069 .33403 Metetra
0 .023 .121 r
.24069 .33403 .24684 .34013 .25602 .33683 .24989 .33071 Metetra
0 .023 .121 r
.24989 .33071 .25602 .33683 .26523 .33352 .25912 .32737 Metetra
0 .023 .122 r
.25912 .32737 .26523 .33352 .27447 .33022 .26838 .32403 Metetra
0 .023 .122 r
.26838 .32403 .27447 .33022 .28375 .32687 .27768 .32068 Metetra
0 .023 .121 r
.27768 .32068 .28375 .32687 .29306 .32352 .28701 .3173 Metetra
0 .023 .121 r
.28701 .3173 .29306 .32352 .3024 .32016 .29637 .31392 Metetra
0 .023 .121 r
.29637 .31392 .3024 .32016 .31177 .31679 .30576 .31053 Metetra
0 .023 .122 r
.30576 .31053 .31177 .31679 .32118 .31343 .31519 .30713 Metetra
0 .024 .122 r
.31519 .30713 .32118 .31343 .33062 .31004 .32465 .30372 Metetra
0 .023 .122 r
.32465 .30372 .33062 .31004 .3401 .30661 .33415 .30028 Metetra
0 .023 .122 r
.33415 .30028 .3401 .30661 .34961 .30319 .34368 .29683 Metetra
0 .023 .122 r
.34368 .29683 .34961 .30319 .35915 .29978 .35324 .2934 Metetra
0 .024 .122 r
.35324 .2934 .35915 .29978 .36873 .29632 .36284 .28997 Metetra
0 .024 .122 r
.36284 .28997 .36873 .29632 .37834 .2929 .37247 .28651 Metetra
0 .024 .122 r
.37247 .28651 .37834 .2929 .38798 .28957 .38214 .28316 Metetra
0 .026 .124 r
.38214 .28316 .38798 .28957 .39762 .28714 .3918 .28059 Metetra
0 .026 .125 r
.3918 .28059 .39762 .28714 .40736 .28307 .40157 .27651 Metetra
0 .025 .124 r
.40157 .27651 .40736 .28307 .41712 .2795 .41135 .27287 Metetra
0 .025 .124 r
.41135 .27287 .41712 .2795 .42691 .27599 .42116 .26928 Metetra
0 .025 .124 r
.42116 .26928 .42691 .27599 .43673 .27253 .431 .26576 Metetra
0 .025 .124 r
.431 .26576 .43673 .27253 .44659 .26894 .44089 .26215 Metetra
0 .025 .124 r
.44089 .26215 .44659 .26894 .45649 .26542 .4508 .25872 Metetra
0 .025 .124 r
.4508 .25872 .45649 .26542 .46642 .26178 .46076 .25494 Metetra
0 .025 .123 r
.46076 .25494 .46642 .26178 .47639 .25815 .47076 .25132 Metetra
0 .025 .123 r
.47076 .25132 .47639 .25815 .4864 .25457 .48079 .24774 Metetra
0 .025 .124 r
.48079 .24774 .4864 .25457 .49644 .25108 .49085 .24421 Metetra
0 .026 .125 r
.49085 .24421 .49644 .25108 .50652 .24782 .50095 .2408 Metetra
0 .025 .124 r
.50095 .2408 .50652 .24782 .51664 .24334 .5111 .23655 Metetra
0 .024 .122 r
.5111 .23655 .51664 .24334 .52679 .23958 .52127 .23285 Metetra
0 .024 .122 r
.52127 .23285 .52679 .23958 .53698 .23587 .53149 .22907 Metetra
0 .024 .122 r
.53149 .22907 .53698 .23587 .54721 .23214 .54174 .2253 Metetra
0 .023 .121 r
.54174 .2253 .54721 .23214 .55748 .22843 .55203 .22159 Metetra
0 .023 .121 r
.55203 .22159 .55748 .22843 .56778 .22475 .56236 .21785 Metetra
0 .023 .122 r
.56236 .21785 .56778 .22475 .57812 .22102 .57273 .21411 Metetra
0 .023 .122 r
.57273 .21411 .57812 .22102 .5885 .21729 .58314 .21036 Metetra
0 .023 .122 r
.58314 .21036 .5885 .21729 .59892 .21353 .59358 .20658 Metetra
0 .023 .121 r
.59358 .20658 .59892 .21353 .60938 .20977 .60407 .20279 Metetra
0 .023 .121 r
.60407 .20279 .60938 .20977 .61988 .206 .61459 .19899 Metetra
0 .023 .121 r
.61459 .19899 .61988 .206 .63042 .20221 .62516 .19518 Metetra
0 .023 .122 r
.62516 .19518 .63042 .20221 .641 .19842 .63576 .19135 Metetra
0 .023 .122 r
.63576 .19135 .641 .19842 .65162 .19459 .64641 .1875 Metetra
0 .023 .121 r
.64641 .1875 .65162 .19459 .66227 .19076 .65709 .18364 Metetra
0 .023 .121 r
.65709 .18364 .66227 .19076 .67297 .1869 .66782 .17976 Metetra
0 .023 .121 r
.66782 .17976 .67297 .1869 .68371 .18305 .67859 .17588 Metetra
0 .023 .122 r
.67859 .17588 .68371 .18305 .69449 .17918 .6894 .17198 Metetra
0 .023 .122 r
.6894 .17198 .69449 .17918 .70531 .17529 .70025 .16807 Metetra
0 .023 .122 r
.70025 .16807 .70531 .17529 .71618 .17139 .71114 .16413 Metetra
0 .023 .122 r
.71114 .16413 .71618 .17139 .72708 .16745 .72207 .16017 Metetra
0 .023 .121 r
.72207 .16017 .72708 .16745 .73803 .16352 .73304 .15621 Metetra
0 .023 .121 r
.73304 .15621 .73803 .16352 .74901 .15958 .74406 .15224 Metetra
0 .023 .122 r
.74406 .15224 .74901 .15958 .76004 .1556 .75512 .14824 Metetra
0 .023 .121 r
.75512 .14824 .76004 .1556 .77112 .15162 .76623 .14423 Metetra
0 .023 .121 r
.76623 .14423 .77112 .15162 .78223 .14762 .77737 .1402 Metetra
0 .023 .121 r
.1441 .36068 .15047 .36661 .15935 .3634 .153 .35745 Metetra
0 .023 .121 r
.153 .35745 .15935 .3634 .16826 .36019 .16193 .35421 Metetra
0 .023 .122 r
.16193 .35421 .16826 .36019 .1772 .35697 .17089 .35098 Metetra
0 .023 .122 r
.17089 .35098 .1772 .35697 .18618 .35373 .17988 .34771 Metetra
0 .023 .121 r
.17988 .34771 .18618 .35373 .19519 .35047 .18891 .34443 Metetra
0 .023 .121 r
.18891 .34443 .19519 .35047 .20422 .3472 .19796 .34115 Metetra
0 .023 .122 r
.19796 .34115 .20422 .3472 .21329 .34393 .20705 .33786 Metetra
0 .023 .122 r
.20705 .33786 .21329 .34393 .22239 .34064 .21617 .33454 Metetra
0 .023 .121 r
.21617 .33454 .22239 .34064 .23153 .33734 .22532 .33122 Metetra
0 .023 .121 r
.22532 .33122 .23153 .33734 .24069 .33403 .2345 .32789 Metetra
0 .023 .121 r
.2345 .32789 .24069 .33403 .24989 .33071 .24372 .32454 Metetra
0 .023 .121 r
.24372 .32454 .24989 .33071 .25912 .32737 .25297 .32119 Metetra
0 .023 .121 r
.25297 .32119 .25912 .32737 .26838 .32403 .26225 .31782 Metetra
0 .023 .121 r
.26225 .31782 .26838 .32403 .27768 .32068 .27157 .31444 Metetra
0 .023 .121 r
.27157 .31444 .27768 .32068 .28701 .3173 .28092 .31105 Metetra
0 .023 .121 r
.28092 .31105 .28701 .3173 .29637 .31392 .2903 .30764 Metetra
0 .023 .121 r
.2903 .30764 .29637 .31392 .30576 .31053 .29971 .30423 Metetra
0 .023 .121 r
.29971 .30423 .30576 .31053 .31519 .30713 .30916 .30081 Metetra
0 .023 .122 r
.30916 .30081 .31519 .30713 .32465 .30372 .31864 .29738 Metetra
0 .023 .122 r
.31864 .29738 .32465 .30372 .33415 .30028 .32816 .29391 Metetra
0 .023 .121 r
.32816 .29391 .33415 .30028 .34368 .29683 .33771 .29045 Metetra
0 .023 .122 r
.33771 .29045 .34368 .29683 .35324 .2934 .3473 .28699 Metetra
0 .024 .122 r
.3473 .28699 .35324 .2934 .36284 .28997 .35692 .28355 Metetra
0 .024 .122 r
.35692 .28355 .36284 .28997 .37247 .28651 .36657 .28008 Metetra
0 .024 .122 r
.36657 .28008 .37247 .28651 .38214 .28316 .37625 .27666 Metetra
0 .025 .124 r
.37625 .27666 .38214 .28316 .3918 .28059 .38594 .27401 Metetra
0 .026 .125 r
.38594 .27401 .3918 .28059 .40157 .27651 .39573 .26995 Metetra
0 .025 .124 r
.39573 .26995 .40157 .27651 .41135 .27287 .40553 .26627 Metetra
0 .025 .123 r
.40553 .26627 .41135 .27287 .42116 .26928 .41537 .26265 Metetra
0 .025 .123 r
.41537 .26265 .42116 .26928 .431 .26576 .42524 .25909 Metetra
0 .025 .123 r
.42524 .25909 .431 .26576 .44089 .26215 .43514 .25546 Metetra
0 .025 .123 r
.43514 .25546 .44089 .26215 .4508 .25872 .44508 .25203 Metetra
0 .025 .123 r
.44508 .25203 .4508 .25872 .46076 .25494 .45506 .2482 Metetra
0 .025 .123 r
.45506 .2482 .46076 .25494 .47076 .25132 .46508 .24456 Metetra
0 .025 .123 r
.46508 .24456 .47076 .25132 .48079 .24774 .47513 .24097 Metetra
0 .025 .123 r
.47513 .24097 .48079 .24774 .49085 .24421 .48522 .2374 Metetra
0 .025 .124 r
.48522 .2374 .49085 .24421 .50095 .2408 .49534 .23391 Metetra
0 .025 .123 r
.49534 .23391 .50095 .2408 .5111 .23655 .50551 .22971 Metetra
0 .024 .122 r
.50551 .22971 .5111 .23655 .52127 .23285 .51572 .22603 Metetra
0 .024 .122 r
.51572 .22603 .52127 .23285 .53149 .22907 .52596 .22221 Metetra
0 .024 .122 r
.52596 .22221 .53149 .22907 .54174 .2253 .53623 .21843 Metetra
0 .023 .121 r
.53623 .21843 .54174 .2253 .55203 .22159 .54655 .2147 Metetra
0 .023 .121 r
.54655 .2147 .55203 .22159 .56236 .21785 .5569 .21093 Metetra
0 .023 .121 r
.5569 .21093 .56236 .21785 .57273 .21411 .5673 .20716 Metetra
0 .023 .121 r
.5673 .20716 .57273 .21411 .58314 .21036 .57773 .20337 Metetra
0 .023 .121 r
.57773 .20337 .58314 .21036 .59358 .20658 .5882 .19958 Metetra
0 .023 .121 r
.5882 .19958 .59358 .20658 .60407 .20279 .59871 .19577 Metetra
0 .023 .121 r
.59871 .19577 .60407 .20279 .61459 .19899 .60927 .19194 Metetra
0 .023 .121 r
.60927 .19194 .61459 .19899 .62516 .19518 .61986 .1881 Metetra
0 .023 .121 r
.61986 .1881 .62516 .19518 .63576 .19135 .63049 .18424 Metetra
0 .023 .121 r
.63049 .18424 .63576 .19135 .64641 .1875 .64116 .18037 Metetra
0 .023 .121 r
.64116 .18037 .64641 .1875 .65709 .18364 .65188 .17648 Metetra
0 .023 .121 r
.65188 .17648 .65709 .18364 .66782 .17976 .66263 .17257 Metetra
0 .023 .121 r
.66263 .17257 .66782 .17976 .67859 .17588 .67342 .16866 Metetra
0 .023 .121 r
.67342 .16866 .67859 .17588 .6894 .17198 .68426 .16474 Metetra
0 .023 .122 r
.68426 .16474 .6894 .17198 .70025 .16807 .69514 .1608 Metetra
0 .023 .122 r
.69514 .1608 .70025 .16807 .71114 .16413 .70606 .15683 Metetra
0 .023 .121 r
.70606 .15683 .71114 .16413 .72207 .16017 .71702 .15285 Metetra
0 .023 .121 r
.71702 .15285 .72207 .16017 .73304 .15621 .72803 .14885 Metetra
0 .023 .121 r
.72803 .14885 .73304 .15621 .74406 .15224 .73907 .14484 Metetra
0 .023 .121 r
.73907 .14484 .74406 .15224 .75512 .14824 .75017 .14083 Metetra
0 .023 .122 r
.75017 .14083 .75512 .14824 .76623 .14423 .7613 .13679 Metetra
0 .023 .121 r
.7613 .13679 .76623 .14423 .77737 .1402 .77248 .13273 Metetra
0 .023 .121 r
.13769 .35471 .1441 .36068 .153 .35745 .14661 .35146 Metetra
0 .023 .121 r
.14661 .35146 .153 .35745 .16193 .35421 .15555 .3482 Metetra
0 .023 .122 r
.15555 .3482 .16193 .35421 .17089 .35098 .16453 .34495 Metetra
0 .023 .122 r
.16453 .34495 .17089 .35098 .17988 .34771 .17354 .34166 Metetra
0 .023 .121 r
.17354 .34166 .17988 .34771 .18891 .34443 .18258 .33836 Metetra
0 .023 .121 r
.18258 .33836 .18891 .34443 .19796 .34115 .19166 .33505 Metetra
0 .023 .121 r
.19166 .33505 .19796 .34115 .20705 .33786 .20076 .33174 Metetra
0 .023 .121 r
.20076 .33174 .20705 .33786 .21617 .33454 .2099 .3284 Metetra
0 .023 .121 r
.2099 .3284 .21617 .33454 .22532 .33122 .21907 .32506 Metetra
0 .023 .121 r
.21907 .32506 .22532 .33122 .2345 .32789 .22828 .32171 Metetra
0 .023 .121 r
.22828 .32171 .2345 .32789 .24372 .32454 .23751 .31834 Metetra
0 .023 .121 r
.23751 .31834 .24372 .32454 .25297 .32119 .24678 .31496 Metetra
0 .023 .121 r
.24678 .31496 .25297 .32119 .26225 .31782 .25608 .31157 Metetra
0 .023 .121 r
.25608 .31157 .26225 .31782 .27157 .31444 .26542 .30817 Metetra
0 .023 .121 r
.26542 .30817 .27157 .31444 .28092 .31105 .27479 .30476 Metetra
0 .023 .121 r
.27479 .30476 .28092 .31105 .2903 .30764 .28419 .30133 Metetra
0 .023 .121 r
.28419 .30133 .2903 .30764 .29971 .30423 .29362 .29789 Metetra
0 .023 .121 r
.29362 .29789 .29971 .30423 .30916 .30081 .30309 .29445 Metetra
0 .023 .122 r
.30309 .29445 .30916 .30081 .31864 .29738 .31259 .29099 Metetra
0 .023 .122 r
.31259 .29099 .31864 .29738 .32816 .29391 .32213 .28751 Metetra
0 .023 .121 r
.32213 .28751 .32816 .29391 .33771 .29045 .3317 .28402 Metetra
0 .023 .122 r
.3317 .28402 .33771 .29045 .3473 .28699 .34131 .28054 Metetra
0 .024 .122 r
.34131 .28054 .3473 .28699 .35692 .28355 .35095 .27707 Metetra
0 .024 .122 r
.35095 .27707 .35692 .28355 .36657 .28008 .36063 .27357 Metetra
0 .024 .122 r
.36063 .27357 .36657 .28008 .37625 .27666 .37033 .27015 Metetra
0 .025 .124 r
.37033 .27015 .37625 .27666 .38594 .27401 .38004 .26748 Metetra
0 .026 .125 r
.38004 .26748 .38594 .27401 .39573 .26995 .38985 .26337 Metetra
0 .025 .124 r
.38985 .26337 .39573 .26995 .40553 .26627 .39967 .25967 Metetra
0 .025 .123 r
.39967 .25967 .40553 .26627 .41537 .26265 .40953 .25602 Metetra
0 .025 .123 r
.40953 .25602 .41537 .26265 .42524 .25909 .41942 .25243 Metetra
0 .025 .123 r
.41942 .25243 .42524 .25909 .43514 .25546 .42935 .24878 Metetra
0 .025 .123 r
.42935 .24878 .43514 .25546 .44508 .25203 .43931 .24531 Metetra
0 .025 .123 r
.43931 .24531 .44508 .25203 .45506 .2482 .44932 .24147 Metetra
0 .024 .123 r
.44932 .24147 .45506 .2482 .46508 .24456 .45936 .23782 Metetra
0 .024 .123 r
.45936 .23782 .46508 .24456 .47513 .24097 .46944 .2342 Metetra
0 .025 .123 r
.46944 .2342 .47513 .24097 .48522 .2374 .47955 .23062 Metetra
0 .025 .124 r
.47955 .23062 .48522 .2374 .49534 .23391 .4897 .22713 Metetra
0 .025 .123 r
.4897 .22713 .49534 .23391 .50551 .22971 .49989 .22289 Metetra
0 .024 .122 r
.49989 .22289 .50551 .22971 .51572 .22603 .51012 .21916 Metetra
0 .024 .122 r
.51012 .21916 .51572 .22603 .52596 .22221 .52038 .21532 Metetra
0 .024 .122 r
.52038 .21532 .52596 .22221 .53623 .21843 .53069 .21151 Metetra
0 .023 .121 r
.53069 .21151 .53623 .21843 .54655 .2147 .54103 .20775 Metetra
0 .023 .121 r
.54103 .20775 .54655 .2147 .5569 .21093 .55141 .20395 Metetra
0 .023 .121 r
.55141 .20395 .5569 .21093 .5673 .20716 .56183 .20017 Metetra
0 .023 .121 r
.56183 .20017 .5673 .20716 .57773 .20337 .57229 .19635 Metetra
0 .023 .121 r
.57229 .19635 .57773 .20337 .5882 .19958 .58279 .19253 Metetra
0 .023 .121 r
.58279 .19253 .5882 .19958 .59871 .19577 .59332 .18869 Metetra
0 .023 .121 r
.59332 .18869 .59871 .19577 .60927 .19194 .6039 .18483 Metetra
0 .023 .121 r
.6039 .18483 .60927 .19194 .61986 .1881 .61452 .18097 Metetra
0 .023 .121 r
.61452 .18097 .61986 .1881 .63049 .18424 .62518 .17708 Metetra
0 .023 .121 r
.62518 .17708 .63049 .18424 .64116 .18037 .63588 .17318 Metetra
0 .023 .121 r
.63588 .17318 .64116 .18037 .65188 .17648 .64662 .16926 Metetra
0 .023 .121 r
.64662 .16926 .65188 .17648 .66263 .17257 .6574 .16533 Metetra
0 .023 .121 r
.6574 .16533 .66263 .17257 .67342 .16866 .66823 .16139 Metetra
0 .023 .121 r
.66823 .16139 .67342 .16866 .68426 .16474 .67909 .15744 Metetra
0 .023 .122 r
.67909 .15744 .68426 .16474 .69514 .1608 .69 .15347 Metetra
0 .023 .122 r
.69 .15347 .69514 .1608 .70606 .15683 .70095 .14947 Metetra
0 .023 .121 r
.70095 .14947 .70606 .15683 .71702 .15285 .71194 .14546 Metetra
0 .023 .121 r
.71194 .14546 .71702 .15285 .72803 .14885 .72297 .14144 Metetra
0 .023 .121 r
.72297 .14144 .72803 .14885 .73907 .14484 .73405 .13741 Metetra
0 .023 .122 r
.73405 .13741 .73907 .14484 .75017 .14083 .74517 .13336 Metetra
0 .023 .122 r
.74517 .13336 .75017 .14083 .7613 .13679 .75634 .12929 Metetra
0 .023 .121 r
.75634 .12929 .7613 .13679 .77248 .13273 .76754 .1252 Metetra
0 .023 .121 r
.13124 .34871 .13769 .35471 .14661 .35146 .14017 .34543 Metetra
0 .023 .121 r
.14017 .34543 .14661 .35146 .15555 .3482 .14913 .34217 Metetra
0 .023 .122 r
.14913 .34217 .15555 .3482 .16453 .34495 .15813 .33888 Metetra
0 .023 .122 r
.15813 .33888 .16453 .34495 .17354 .34166 .16716 .33557 Metetra
0 .023 .122 r
.16716 .33557 .17354 .34166 .18258 .33836 .17622 .33225 Metetra
0 .023 .121 r
.17622 .33225 .18258 .33836 .19166 .33505 .18531 .32892 Metetra
0 .023 .121 r
.18531 .32892 .19166 .33505 .20076 .33174 .19444 .32558 Metetra
0 .023 .121 r
.19444 .32558 .20076 .33174 .2099 .3284 .2036 .32223 Metetra
0 .023 .121 r
.2036 .32223 .2099 .3284 .21907 .32506 .21279 .31885 Metetra
0 .023 .121 r
.21279 .31885 .21907 .32506 .22828 .32171 .22201 .31549 Metetra
0 .023 .121 r
.22201 .31549 .22828 .32171 .23751 .31834 .23126 .31209 Metetra
0 .023 .121 r
.23126 .31209 .23751 .31834 .24678 .31496 .24055 .3087 Metetra
0 .023 .121 r
.24055 .3087 .24678 .31496 .25608 .31157 .24987 .30529 Metetra
0 .023 .121 r
.24987 .30529 .25608 .31157 .26542 .30817 .25922 .30187 Metetra
0 .023 .121 r
.25922 .30187 .26542 .30817 .27479 .30476 .26861 .29842 Metetra
0 .023 .121 r
.26861 .29842 .27479 .30476 .28419 .30133 .27804 .29497 Metetra
0 .023 .121 r
.27804 .29497 .28419 .30133 .29362 .29789 .28749 .29152 Metetra
0 .023 .121 r
.28749 .29152 .29362 .29789 .30309 .29445 .29698 .28805 Metetra
0 .023 .122 r
.29698 .28805 .30309 .29445 .31259 .29099 .3065 .28456 Metetra
0 .023 .122 r
.3065 .28456 .31259 .29099 .32213 .28751 .31606 .28106 Metetra
0 .023 .121 r
.31606 .28106 .32213 .28751 .3317 .28402 .32566 .27755 Metetra
0 .023 .122 r
.32566 .27755 .3317 .28402 .34131 .28054 .33528 .27404 Metetra
0 .024 .122 r
.33528 .27404 .34131 .28054 .35095 .27707 .34495 .27051 Metetra
0 .024 .122 r
.34495 .27051 .35095 .27707 .36063 .27357 .35464 .26698 Metetra
0 .024 .122 r
.35464 .26698 .36063 .27357 .37033 .27015 .36437 .26359 Metetra
0 .025 .124 r
.36437 .26359 .37033 .27015 .38004 .26748 .37409 .26094 Metetra
0 .026 .125 r
.37409 .26094 .38004 .26748 .38985 .26337 .38393 .25675 Metetra
0 .025 .123 r
.38393 .25675 .38985 .26337 .39967 .25967 .39378 .25304 Metetra
0 .025 .123 r
.39378 .25304 .39967 .25967 .40953 .25602 .40366 .24936 Metetra
0 .025 .123 r
.40366 .24936 .40953 .25602 .41942 .25243 .41357 .24574 Metetra
0 .025 .123 r
.41357 .24574 .41942 .25243 .42935 .24878 .42353 .24207 Metetra
0 .025 .123 r
.42353 .24207 .42935 .24878 .43931 .24531 .43351 .23856 Metetra
0 .025 .123 r
.43351 .23856 .43931 .24531 .44932 .24147 .44354 .23472 Metetra
0 .024 .123 r
.44354 .23472 .44932 .24147 .45936 .23782 .4536 .23106 Metetra
0 .025 .123 r
.4536 .23106 .45936 .23782 .46944 .2342 .4637 .22742 Metetra
0 .025 .123 r
.4637 .22742 .46944 .2342 .47955 .23062 .47384 .22385 Metetra
0 .025 .124 r
.47384 .22385 .47955 .23062 .4897 .22713 .48401 .22043 Metetra
0 .025 .123 r
.48401 .22043 .4897 .22713 .49989 .22289 .49423 .21606 Metetra
0 .024 .122 r
.49423 .21606 .49989 .22289 .51012 .21916 .50448 .21223 Metetra
0 .024 .122 r
.50448 .21223 .51012 .21916 .52038 .21532 .51477 .20839 Metetra
0 .024 .122 r
.51477 .20839 .52038 .21532 .53069 .21151 .5251 .20455 Metetra
0 .023 .121 r
.5251 .20455 .53069 .21151 .54103 .20775 .53547 .20075 Metetra
0 .023 .121 r
.53547 .20075 .54103 .20775 .55141 .20395 .54588 .19694 Metetra
0 .023 .121 r
.54588 .19694 .55141 .20395 .56183 .20017 .55632 .19312 Metetra
0 .023 .121 r
.55632 .19312 .56183 .20017 .57229 .19635 .56681 .18928 Metetra
0 .023 .121 r
.56681 .18928 .57229 .19635 .58279 .19253 .57733 .18543 Metetra
0 .023 .121 r
.57733 .18543 .58279 .19253 .59332 .18869 .5879 .18156 Metetra
0 .023 .121 r
.5879 .18156 .59332 .18869 .6039 .18483 .5985 .17768 Metetra
0 .023 .121 r
.5985 .17768 .6039 .18483 .61452 .18097 .60915 .17378 Metetra
0 .023 .121 r
.60915 .17378 .61452 .18097 .62518 .17708 .61983 .16988 Metetra
0 .023 .121 r
.61983 .16988 .62518 .17708 .63588 .17318 .63056 .16594 Metetra
0 .023 .121 r
.63056 .16594 .63588 .17318 .64662 .16926 .64133 .162 Metetra
0 .023 .121 r
.64133 .162 .64662 .16926 .6574 .16533 .65214 .15803 Metetra
0 .023 .121 r
.65214 .15803 .6574 .16533 .66823 .16139 .66299 .15407 Metetra
0 .023 .121 r
.66299 .15407 .66823 .16139 .67909 .15744 .67389 .1501 Metetra
0 .023 .122 r
.67389 .1501 .67909 .15744 .69 .15347 .68482 .14609 Metetra
0 .023 .122 r
.68482 .14609 .69 .15347 .70095 .14947 .6958 .14207 Metetra
0 .023 .121 r
.6958 .14207 .70095 .14947 .71194 .14546 .70682 .13802 Metetra
0 .023 .121 r
.70682 .13802 .71194 .14546 .72297 .14144 .71789 .13397 Metetra
0 .023 .121 r
.71789 .13397 .72297 .14144 .73405 .13741 .72899 .12993 Metetra
0 .023 .122 r
.72899 .12993 .73405 .13741 .74517 .13336 .74014 .12583 Metetra
0 .023 .121 r
.74014 .12583 .74517 .13336 .75634 .12929 .75134 .12173 Metetra
0 .023 .121 r
.75134 .12173 .75634 .12929 .76754 .1252 .76258 .11761 Metetra
0 .023 .122 r
.12474 .34268 .13124 .34871 .14017 .34543 .13369 .33938 Metetra
0 .023 .122 r
.13369 .33938 .14017 .34543 .14913 .34217 .14268 .33608 Metetra
0 .023 .122 r
.14268 .33608 .14913 .34217 .15813 .33888 .15169 .33275 Metetra
0 .023 .122 r
.15169 .33275 .15813 .33888 .16716 .33557 .16074 .32945 Metetra
0 .023 .122 r
.16074 .32945 .16716 .33557 .17622 .33225 .16982 .3261 Metetra
0 .023 .122 r
.16982 .3261 .17622 .33225 .18531 .32892 .17893 .32274 Metetra
0 .023 .121 r
.17893 .32274 .18531 .32892 .19444 .32558 .18807 .31938 Metetra
0 .023 .121 r
.18807 .31938 .19444 .32558 .2036 .32223 .19725 .31601 Metetra
0 .023 .121 r
.19725 .31601 .2036 .32223 .21279 .31885 .20646 .31262 Metetra
0 .023 .121 r
.20646 .31262 .21279 .31885 .22201 .31549 .2157 .30922 Metetra
0 .023 .121 r
.2157 .30922 .22201 .31549 .23126 .31209 .22497 .30581 Metetra
0 .023 .121 r
.22497 .30581 .23126 .31209 .24055 .3087 .23428 .30239 Metetra
0 .023 .122 r
.23428 .30239 .24055 .3087 .24987 .30529 .24362 .29897 Metetra
0 .023 .122 r
.24362 .29897 .24987 .30529 .25922 .30187 .25299 .29551 Metetra
0 .023 .121 r
.25299 .29551 .25922 .30187 .26861 .29842 .2624 .29205 Metetra
0 .023 .121 r
.2624 .29205 .26861 .29842 .27804 .29497 .27184 .28858 Metetra
0 .023 .121 r
.27184 .28858 .27804 .29497 .28749 .29152 .28132 .2851 Metetra
0 .023 .122 r
.28132 .2851 .28749 .29152 .29698 .28805 .29083 .28162 Metetra
0 .024 .122 r
.29083 .28162 .29698 .28805 .3065 .28456 .30037 .27812 Metetra
0 .023 .122 r
.30037 .27812 .3065 .28456 .31606 .28106 .30995 .27457 Metetra
0 .023 .122 r
.30995 .27457 .31606 .28106 .32566 .27755 .31957 .27105 Metetra
0 .023 .122 r
.31957 .27105 .32566 .27755 .33528 .27404 .32922 .2675 Metetra
0 .024 .122 r
.32922 .2675 .33528 .27404 .34495 .27051 .3389 .26395 Metetra
0 .024 .122 r
.3389 .26395 .34495 .27051 .35464 .26698 .34862 .26039 Metetra
0 .024 .122 r
.34862 .26039 .35464 .26698 .36437 .26359 .35837 .25694 Metetra
0 .025 .124 r
.35837 .25694 .36437 .26359 .37409 .26094 .36812 .25412 Metetra
0 .026 .125 r
.36812 .25412 .37409 .26094 .38393 .25675 .37797 .25004 Metetra
0 .025 .123 r
.37797 .25004 .38393 .25675 .39378 .25304 .38784 .24634 Metetra
0 .025 .123 r
.38784 .24634 .39378 .25304 .40366 .24936 .39775 .24266 Metetra
0 .025 .123 r
.39775 .24266 .40366 .24936 .41357 .24574 .40768 .239 Metetra
0 .025 .123 r
.40768 .239 .41357 .24574 .42353 .24207 .41766 .23532 Metetra
0 .025 .123 r
.41766 .23532 .42353 .24207 .43351 .23856 .42767 .23176 Metetra
0 .025 .123 r
.42767 .23176 .43351 .23856 .44354 .23472 .43772 .22791 Metetra
0 .024 .123 r
.43772 .22791 .44354 .23472 .4536 .23106 .44781 .22424 Metetra
0 .025 .123 r
.44781 .22424 .4536 .23106 .4637 .22742 .45793 .22058 Metetra
0 .025 .123 r
.45793 .22058 .4637 .22742 .47384 .22385 .46809 .21702 Metetra
0 .026 .125 r
.46809 .21702 .47384 .22385 .48401 .22043 .47828 .21372 Metetra
0 .025 .124 r
.47828 .21372 .48401 .22043 .49423 .21606 .48853 .20921 Metetra
0 .024 .122 r
.48853 .20921 .49423 .21606 .50448 .21223 .49881 .2052 Metetra
0 .024 .122 r
.49881 .2052 .50448 .21223 .51477 .20839 .50913 .20137 Metetra
0 .024 .122 r
.50913 .20137 .51477 .20839 .5251 .20455 .51948 .19756 Metetra
0 .023 .122 r
.51948 .19756 .5251 .20455 .53547 .20075 .52987 .1937 Metetra
0 .023 .121 r
.52987 .1937 .53547 .20075 .54588 .19694 .5403 .18989 Metetra
0 .023 .122 r
.5403 .18989 .54588 .19694 .55632 .19312 .55078 .18602 Metetra
0 .023 .122 r
.55078 .18602 .55632 .19312 .56681 .18928 .56129 .18216 Metetra
0 .023 .121 r
.56129 .18216 .56681 .18928 .57733 .18543 .57184 .17827 Metetra
0 .023 .121 r
.57184 .17827 .57733 .18543 .5879 .18156 .58243 .17438 Metetra
0 .023 .121 r
.58243 .17438 .5879 .18156 .5985 .17768 .59306 .17047 Metetra
0 .023 .121 r
.59306 .17047 .5985 .17768 .60915 .17378 .60374 .16654 Metetra
0 .023 .122 r
.60374 .16654 .60915 .17378 .61983 .16988 .61445 .16262 Metetra
0 .023 .122 r
.61445 .16262 .61983 .16988 .63056 .16594 .6252 .15866 Metetra
0 .023 .121 r
.6252 .15866 .63056 .16594 .64133 .162 .636 .15469 Metetra
0 .023 .121 r
.636 .15469 .64133 .162 .65214 .15803 .64684 .15069 Metetra
0 .023 .121 r
.64684 .15069 .65214 .15803 .66299 .15407 .65772 .14671 Metetra
0 .023 .122 r
.65772 .14671 .66299 .15407 .67389 .1501 .66864 .14269 Metetra
0 .023 .122 r
.66864 .14269 .67389 .1501 .68482 .14609 .67961 .13865 Metetra
0 .023 .122 r
.67961 .13865 .68482 .14609 .6958 .14207 .69062 .13462 Metetra
0 .023 .122 r
.69062 .13462 .6958 .14207 .70682 .13802 .70167 .13054 Metetra
0 .023 .121 r
.70167 .13054 .70682 .13802 .71789 .13397 .71276 .12647 Metetra
0 .023 .122 r
.71276 .12647 .71789 .13397 .72899 .12993 .7239 .12238 Metetra
0 .023 .122 r
.7239 .12238 .72899 .12993 .74014 .12583 .73508 .11826 Metetra
0 .023 .121 r
.73508 .11826 .74014 .12583 .75134 .12173 .7463 .11413 Metetra
0 .023 .121 r
.7463 .11413 .75134 .12173 .76258 .11761 .75757 .10999 Metetra
0 .023 .121 r
.11821 .33657 .12474 .34268 .13369 .33938 .12718 .33326 Metetra
0 .023 .121 r
.12718 .33326 .13369 .33938 .14268 .33608 .13618 .32994 Metetra
0 .023 .122 r
.13618 .32994 .14268 .33608 .15169 .33275 .14521 .32662 Metetra
0 .023 .122 r
.14521 .32662 .15169 .33275 .16074 .32945 .15427 .32326 Metetra
0 .023 .122 r
.15427 .32326 .16074 .32945 .16982 .3261 .16337 .3199 Metetra
0 .023 .121 r
.16337 .3199 .16982 .3261 .17893 .32274 .1725 .31653 Metetra
0 .023 .121 r
.1725 .31653 .17893 .32274 .18807 .31938 .18166 .31314 Metetra
0 .023 .121 r
.18166 .31314 .18807 .31938 .19725 .31601 .19086 .30975 Metetra
0 .023 .122 r
.19086 .30975 .19725 .31601 .20646 .31262 .20008 .30635 Metetra
0 .023 .122 r
.20008 .30635 .20646 .31262 .2157 .30922 .20934 .30291 Metetra
0 .023 .121 r
.20934 .30291 .2157 .30922 .22497 .30581 .21864 .29949 Metetra
0 .023 .121 r
.21864 .29949 .22497 .30581 .23428 .30239 .22796 .29604 Metetra
0 .023 .122 r
.22796 .29604 .23428 .30239 .24362 .29897 .23732 .29258 Metetra
0 .023 .122 r
.23732 .29258 .24362 .29897 .25299 .29551 .24672 .28911 Metetra
0 .023 .121 r
.24672 .28911 .25299 .29551 .2624 .29205 .25615 .28563 Metetra
0 .023 .121 r
.25615 .28563 .2624 .29205 .27184 .28858 .26561 .28213 Metetra
0 .023 .121 r
.26561 .28213 .27184 .28858 .28132 .2851 .27511 .27863 Metetra
0 .023 .122 r
.27511 .27863 .28132 .2851 .29083 .28162 .28464 .27511 Metetra
0 .024 .122 r
.28464 .27511 .29083 .28162 .30037 .27812 .2942 .27159 Metetra
0 .024 .122 r
.2942 .27159 .30037 .27812 .30995 .27457 .3038 .26804 Metetra
0 .023 .122 r
.3038 .26804 .30995 .27457 .31957 .27105 .31344 .26447 Metetra
0 .024 .122 r
.31344 .26447 .31957 .27105 .32922 .2675 .32311 .26092 Metetra
0 .024 .122 r
.32311 .26092 .32922 .2675 .3389 .26395 .33282 .25732 Metetra
0 .024 .122 r
.33282 .25732 .3389 .26395 .34862 .26039 .34256 .25373 Metetra
0 .024 .122 r
.34256 .25373 .34862 .26039 .35837 .25694 .35233 .25022 Metetra
0 .025 .123 r
.35233 .25022 .35837 .25694 .36812 .25412 .36213 .24675 Metetra
0 .025 .124 r
.36213 .24675 .36812 .25412 .37797 .25004 .37197 .24332 Metetra
0 .025 .123 r
.37197 .24332 .37797 .25004 .38784 .24634 .38186 .23962 Metetra
0 .025 .123 r
.38186 .23962 .38784 .24634 .39775 .24266 .39179 .23591 Metetra
0 .025 .123 r
.39179 .23591 .39775 .24266 .40768 .239 .40175 .23223 Metetra
0 .025 .123 r
.40175 .23223 .40768 .239 .41766 .23532 .41175 .22852 Metetra
0 .025 .123 r
.41175 .22852 .41766 .23532 .42767 .23176 .42178 .22491 Metetra
0 .025 .123 r
.42178 .22491 .42767 .23176 .43772 .22791 .43186 .22105 Metetra
0 .024 .123 r
.43186 .22105 .43772 .22791 .44781 .22424 .44197 .21735 Metetra
0 .025 .123 r
.44197 .21735 .44781 .22424 .45793 .22058 .45212 .21367 Metetra
0 .025 .124 r
.45212 .21367 .45793 .22058 .46809 .21702 .4623 .21002 Metetra
0 .026 .125 r
.4623 .21002 .46809 .21702 .47828 .21372 .47252 .20651 Metetra
0 .025 .124 r
.47252 .20651 .47828 .21372 .48853 .20921 .48279 .20215 Metetra
0 .024 .122 r
.48279 .20215 .48853 .20921 .49881 .2052 .4931 .19813 Metetra
0 .024 .122 r
.4931 .19813 .49881 .2052 .50913 .20137 .50344 .19431 Metetra
0 .024 .122 r
.50344 .19431 .50913 .20137 .51948 .19756 .51382 .19046 Metetra
0 .023 .121 r
.51382 .19046 .51948 .19756 .52987 .1937 .52423 .1866 Metetra
0 .023 .121 r
.52423 .1866 .52987 .1937 .5403 .18989 .53469 .18275 Metetra
0 .023 .122 r
.53469 .18275 .5403 .18989 .55078 .18602 .54519 .17889 Metetra
0 .023 .122 r
.54519 .17889 .55078 .18602 .56129 .18216 .55573 .17497 Metetra
0 .023 .121 r
.55573 .17497 .56129 .18216 .57184 .17827 .56631 .17107 Metetra
0 .023 .121 r
.56631 .17107 .57184 .17827 .58243 .17438 .57692 .16715 Metetra
0 .023 .121 r
.57692 .16715 .58243 .17438 .59306 .17047 .58758 .16321 Metetra
0 .023 .121 r
.58758 .16321 .59306 .17047 .60374 .16654 .59828 .15926 Metetra
0 .023 .121 r
.59828 .15926 .60374 .16654 .61445 .16262 .60903 .15529 Metetra
0 .023 .122 r
.60903 .15529 .61445 .16262 .6252 .15866 .61981 .15132 Metetra
0 .023 .121 r
.61981 .15132 .6252 .15866 .636 .15469 .63063 .14731 Metetra
0 .023 .121 r
.63063 .14731 .636 .15469 .64684 .15069 .6415 .1433 Metetra
0 .023 .121 r
.6415 .1433 .64684 .15069 .65772 .14671 .65241 .13927 Metetra
0 .023 .121 r
.65241 .13927 .65772 .14671 .66864 .14269 .66336 .13522 Metetra
0 .023 .121 r
.66336 .13522 .66864 .14269 .67961 .13865 .67436 .13118 Metetra
0 .023 .122 r
.67436 .13118 .67961 .13865 .69062 .13462 .68539 .12711 Metetra
0 .023 .122 r
.68539 .12711 .69062 .13462 .70167 .13054 .69647 .12299 Metetra
0 .023 .122 r
.69647 .12299 .70167 .13054 .71276 .12647 .7076 .11892 Metetra
0 .024 .122 r
.7076 .11892 .71276 .12647 .7239 .12238 .71877 .11477 Metetra
0 .023 .122 r
.71877 .11477 .7239 .12238 .73508 .11826 .72998 .11062 Metetra
0 .023 .121 r
.72998 .11062 .73508 .11826 .7463 .11413 .74123 .10646 Metetra
0 .023 .121 r
.74123 .10646 .7463 .11413 .75757 .10999 .75253 .10229 Metetra
0 .023 .121 r
.11163 .33046 .11821 .33657 .12718 .33326 .12061 .32712 Metetra
0 .023 .121 r
.12061 .32712 .12718 .33326 .13618 .32994 .12963 .32378 Metetra
0 .023 .122 r
.12963 .32378 .13618 .32994 .14521 .32662 .13868 .32042 Metetra
0 .023 .122 r
.13868 .32042 .14521 .32662 .15427 .32326 .14777 .31706 Metetra
0 .023 .122 r
.14777 .31706 .15427 .32326 .16337 .3199 .15688 .31366 Metetra
0 .023 .121 r
.15688 .31366 .16337 .3199 .1725 .31653 .16603 .31028 Metetra
0 .023 .121 r
.16603 .31028 .1725 .31653 .18166 .31314 .17521 .30686 Metetra
0 .023 .121 r
.17521 .30686 .18166 .31314 .19086 .30975 .18442 .30345 Metetra
0 .023 .122 r
.18442 .30345 .19086 .30975 .20008 .30635 .19367 .30002 Metetra
0 .023 .122 r
.19367 .30002 .20008 .30635 .20934 .30291 .20295 .29659 Metetra
0 .023 .122 r
.20295 .29659 .20934 .30291 .21864 .29949 .21226 .29312 Metetra
0 .023 .121 r
.21226 .29312 .21864 .29949 .22796 .29604 .22161 .28965 Metetra
0 .023 .121 r
.22161 .28965 .22796 .29604 .23732 .29258 .23099 .28617 Metetra
0 .023 .121 r
.23099 .28617 .23732 .29258 .24672 .28911 .2404 .28267 Metetra
0 .023 .121 r
.2404 .28267 .24672 .28911 .25615 .28563 .24985 .27917 Metetra
0 .023 .121 r
.24985 .27917 .25615 .28563 .26561 .28213 .25933 .27565 Metetra
0 .023 .121 r
.25933 .27565 .26561 .28213 .27511 .27863 .26885 .27212 Metetra
0 .023 .121 r
.26885 .27212 .27511 .27863 .28464 .27511 .2784 .26857 Metetra
0 .023 .122 r
.2784 .26857 .28464 .27511 .2942 .27159 .28799 .26503 Metetra
0 .024 .122 r
.28799 .26503 .2942 .27159 .3038 .26804 .29761 .26147 Metetra
0 .023 .122 r
.29761 .26147 .3038 .26804 .31344 .26447 .30727 .25789 Metetra
0 .024 .122 r
.30727 .25789 .31344 .26447 .32311 .26092 .31696 .2543 Metetra
0 .024 .122 r
.31696 .2543 .32311 .26092 .33282 .25732 .32668 .25071 Metetra
0 .024 .122 r
.32668 .25071 .33282 .25732 .34256 .25373 .33645 .24705 Metetra
0 .024 .122 r
.33645 .24705 .34256 .25373 .35233 .25022 .34625 .24348 Metetra
0 .024 .123 r
.34625 .24348 .35233 .25022 .36213 .24675 .35605 .24035 Metetra
0 .025 .124 r
.35605 .24035 .36213 .24675 .37197 .24332 .36592 .23681 Metetra
0 .025 .124 r
.36592 .23681 .37197 .24332 .38186 .23962 .37584 .233 Metetra
0 .025 .123 r
.37584 .233 .38186 .23962 .39179 .23591 .38579 .22921 Metetra
0 .025 .123 r
.38579 .22921 .39179 .23591 .40175 .23223 .39578 .22547 Metetra
0 .025 .123 r
.39578 .22547 .40175 .23223 .41175 .22852 .4058 .22173 Metetra
0 .025 .123 r
.4058 .22173 .41175 .22852 .42178 .22491 .41586 .21808 Metetra
0 .025 .123 r
.41586 .21808 .42178 .22491 .43186 .22105 .42596 .21421 Metetra
0 .025 .123 r
.42596 .21421 .43186 .22105 .44197 .21735 .43609 .2105 Metetra
0 .025 .123 r
.43609 .2105 .44197 .21735 .45212 .21367 .44626 .20681 Metetra
0 .025 .124 r
.44626 .20681 .45212 .21367 .4623 .21002 .45647 .20302 Metetra
0 .025 .124 r
.45647 .20302 .4623 .21002 .47252 .20651 .46672 .19906 Metetra
0 .025 .123 r
.46672 .19906 .47252 .20651 .48279 .20215 .47702 .19497 Metetra
0 .024 .122 r
.47702 .19497 .48279 .20215 .4931 .19813 .48734 .19105 Metetra
0 .023 .122 r
.48734 .19105 .4931 .19813 .50344 .19431 .49771 .18722 Metetra
0 .023 .122 r
.49771 .18722 .50344 .19431 .51382 .19046 .50811 .18335 Metetra
0 .023 .121 r
.50811 .18335 .51382 .19046 .52423 .1866 .51856 .17947 Metetra
0 .023 .121 r
.51856 .17947 .52423 .1866 .53469 .18275 .52904 .17558 Metetra
0 .023 .121 r
.52904 .17558 .53469 .18275 .54519 .17889 .53957 .17168 Metetra
0 .023 .121 r
.53957 .17168 .54519 .17889 .55573 .17497 .55013 .16775 Metetra
0 .023 .121 r
.55013 .16775 .55573 .17497 .56631 .17107 .56073 .16382 Metetra
0 .023 .121 r
.56073 .16382 .56631 .17107 .57692 .16715 .57138 .15987 Metetra
0 .023 .121 r
.57138 .15987 .57692 .16715 .58758 .16321 .58207 .15591 Metetra
0 .023 .121 r
.58207 .15591 .58758 .16321 .59828 .15926 .59279 .15193 Metetra
0 .023 .121 r
.59279 .15193 .59828 .15926 .60903 .15529 .60356 .14793 Metetra
0 .023 .121 r
.60356 .14793 .60903 .15529 .61981 .15132 .61438 .14392 Metetra
0 .023 .121 r
.61438 .14392 .61981 .15132 .63063 .14731 .62523 .13989 Metetra
0 .023 .121 r
.62523 .13989 .63063 .14731 .6415 .1433 .63612 .13586 Metetra
0 .023 .121 r
.63612 .13586 .6415 .1433 .65241 .13927 .64706 .13179 Metetra
0 .023 .121 r
.64706 .13179 .65241 .13927 .66336 .13522 .65804 .12772 Metetra
0 .023 .121 r
.65804 .12772 .66336 .13522 .67436 .13118 .66907 .12363 Metetra
0 .023 .122 r
.66907 .12363 .67436 .13118 .68539 .12711 .68013 .11953 Metetra
0 .023 .122 r
.68013 .11953 .68539 .12711 .69647 .12299 .69124 .1154 Metetra
0 .023 .122 r
.69124 .1154 .69647 .12299 .7076 .11892 .7024 .11127 Metetra
0 .024 .122 r
.7024 .11127 .7076 .11892 .71877 .11477 .7136 .10713 Metetra
0 .023 .122 r
.7136 .10713 .71877 .11477 .72998 .11062 .72484 .10295 Metetra
0 .023 .121 r
.72484 .10295 .72998 .11062 .74123 .10646 .73612 .09875 Metetra
0 .023 .121 r
.73612 .09875 .74123 .10646 .75253 .10229 .74746 .09454 Metetra
0 .023 .121 r
.10501 .32429 .11163 .33046 .12061 .32712 .11401 .32093 Metetra
0 .023 .122 r
.11401 .32093 .12061 .32712 .12963 .32378 .12305 .31757 Metetra
0 .023 .122 r
.12305 .31757 .12963 .32378 .13868 .32042 .13212 .3142 Metetra
0 .023 .122 r
.13212 .3142 .13868 .32042 .14777 .31706 .14122 .31079 Metetra
0 .023 .122 r
.14122 .31079 .14777 .31706 .15688 .31366 .15035 .3074 Metetra
0 .023 .122 r
.15035 .3074 .15688 .31366 .16603 .31028 .15952 .30398 Metetra
0 .023 .121 r
.15952 .30398 .16603 .31028 .17521 .30686 .16872 .30054 Metetra
0 .023 .121 r
.16872 .30054 .17521 .30686 .18442 .30345 .17795 .29711 Metetra
0 .023 .121 r
.17795 .29711 .18442 .30345 .19367 .30002 .18721 .29365 Metetra
0 .023 .122 r
.18721 .29365 .19367 .30002 .20295 .29659 .19651 .29018 Metetra
0 .023 .122 r
.19651 .29018 .20295 .29659 .21226 .29312 .20584 .28672 Metetra
0 .023 .122 r
.20584 .28672 .21226 .29312 .22161 .28965 .21521 .28321 Metetra
0 .023 .121 r
.21521 .28321 .22161 .28965 .23099 .28617 .22461 .27971 Metetra
0 .023 .121 r
.22461 .27971 .23099 .28617 .2404 .28267 .23405 .27619 Metetra
0 .023 .121 r
.23405 .27619 .2404 .28267 .24985 .27917 .24351 .27267 Metetra
0 .023 .121 r
.24351 .27267 .24985 .27917 .25933 .27565 .25302 .26912 Metetra
0 .023 .121 r
.25302 .26912 .25933 .27565 .26885 .27212 .26255 .26557 Metetra
0 .023 .121 r
.26255 .26557 .26885 .27212 .2784 .26857 .27213 .262 Metetra
0 .023 .122 r
.27213 .262 .2784 .26857 .28799 .26503 .28173 .25843 Metetra
0 .023 .122 r
.28173 .25843 .28799 .26503 .29761 .26147 .29138 .25483 Metetra
0 .023 .122 r
.29138 .25483 .29761 .26147 .30727 .25789 .30105 .25122 Metetra
0 .024 .122 r
.30105 .25122 .30727 .25789 .31696 .2543 .31077 .24761 Metetra
0 .024 .122 r
.31077 .24761 .31696 .2543 .32668 .25071 .32052 .24399 Metetra
0 .024 .122 r
.32052 .24399 .32668 .25071 .33645 .24705 .3303 .24035 Metetra
0 .024 .122 r
.3303 .24035 .33645 .24705 .34625 .24348 .34012 .23668 Metetra
0 .024 .123 r
.34012 .23668 .34625 .24348 .35605 .24035 .34997 .23328 Metetra
0 .025 .123 r
.34997 .23328 .35605 .24035 .36592 .23681 .35986 .22962 Metetra
0 .025 .124 r
.35986 .22962 .36592 .23681 .37584 .233 .36978 .22612 Metetra
0 .025 .124 r
.36978 .22612 .37584 .233 .38579 .22921 .37975 .22241 Metetra
0 .025 .124 r
.37975 .22241 .38579 .22921 .39578 .22547 .38976 .21867 Metetra
0 .025 .123 r
.38976 .21867 .39578 .22547 .4058 .22173 .39981 .21492 Metetra
0 .025 .124 r
.39981 .21492 .4058 .22173 .41586 .21808 .40989 .21123 Metetra
0 .025 .124 r
.40989 .21123 .41586 .21808 .42596 .21421 .42001 .20737 Metetra
0 .025 .123 r
.42001 .20737 .42596 .21421 .43609 .2105 .43017 .20365 Metetra
0 .025 .124 r
.43017 .20365 .43609 .2105 .44626 .20681 .44036 .19989 Metetra
0 .025 .124 r
.44036 .19989 .44626 .20681 .45647 .20302 .4506 .19604 Metetra
0 .025 .124 r
.4506 .19604 .45647 .20302 .46672 .19906 .46087 .19229 Metetra
0 .024 .123 r
.46087 .19229 .46672 .19906 .47702 .19497 .4712 .18783 Metetra
0 .024 .122 r
.4712 .18783 .47702 .19497 .48734 .19105 .48155 .18394 Metetra
0 .023 .121 r
.48155 .18394 .48734 .19105 .49771 .18722 .49194 .18007 Metetra
0 .023 .122 r
.49194 .18007 .49771 .18722 .50811 .18335 .50237 .1762 Metetra
0 .023 .122 r
.50237 .1762 .50811 .18335 .51856 .17947 .51284 .17229 Metetra
0 .023 .122 r
.51284 .17229 .51856 .17947 .52904 .17558 .52335 .16838 Metetra
0 .023 .122 r
.52335 .16838 .52904 .17558 .53957 .17168 .5339 .16442 Metetra
0 .023 .121 r
.5339 .16442 .53957 .17168 .55013 .16775 .54449 .16048 Metetra
0 .023 .121 r
.54449 .16048 .55013 .16775 .56073 .16382 .55512 .15652 Metetra
0 .023 .121 r
.55512 .15652 .56073 .16382 .57138 .15987 .5658 .15254 Metetra
0 .023 .121 r
.5658 .15254 .57138 .15987 .58207 .15591 .57651 .14855 Metetra
0 .023 .121 r
.57651 .14855 .58207 .15591 .59279 .15193 .58727 .14454 Metetra
0 .023 .121 r
.58727 .14454 .59279 .15193 .60356 .14793 .59806 .14051 Metetra
0 .023 .121 r
.59806 .14051 .60356 .14793 .61438 .14392 .6089 .13647 Metetra
0 .023 .121 r
.6089 .13647 .61438 .14392 .62523 .13989 .61978 .13243 Metetra
0 .023 .122 r
.61978 .13243 .62523 .13989 .63612 .13586 .63071 .12834 Metetra
0 .023 .121 r
.63071 .12834 .63612 .13586 .64706 .13179 .64168 .12426 Metetra
0 .023 .121 r
.64168 .12426 .64706 .13179 .65804 .12772 .65268 .12016 Metetra
0 .023 .121 r
.65268 .12016 .65804 .12772 .66907 .12363 .66374 .11604 Metetra
0 .023 .122 r
.66374 .11604 .66907 .12363 .68013 .11953 .67483 .1119 Metetra
0 .023 .122 r
.67483 .1119 .68013 .11953 .69124 .1154 .68598 .10776 Metetra
0 .023 .122 r
.68598 .10776 .69124 .1154 .7024 .11127 .69716 .1036 Metetra
0 .024 .122 r
.69716 .1036 .7024 .11127 .7136 .10713 .70839 .0994 Metetra
0 .023 .122 r
.70839 .0994 .7136 .10713 .72484 .10295 .71966 .09519 Metetra
0 .023 .121 r
.71966 .09519 .72484 .10295 .73612 .09875 .73098 .09097 Metetra
0 .023 .121 r
.73098 .09097 .73612 .09875 .74746 .09454 .74234 .08673 Metetra
0 .023 .121 r
.09834 .31808 .10501 .32429 .11401 .32093 .10736 .3147 Metetra
0 .023 .121 r
.10736 .3147 .11401 .32093 .12305 .31757 .11642 .31132 Metetra
0 .023 .122 r
.11642 .31132 .12305 .31757 .13212 .3142 .1255 .30793 Metetra
0 .023 .122 r
.1255 .30793 .13212 .3142 .14122 .31079 .13462 .30451 Metetra
0 .023 .122 r
.13462 .30451 .14122 .31079 .15035 .3074 .14377 .30109 Metetra
0 .023 .122 r
.14377 .30109 .15035 .3074 .15952 .30398 .15296 .29763 Metetra
0 .023 .122 r
.15296 .29763 .15952 .30398 .16872 .30054 .16218 .2942 Metetra
0 .023 .122 r
.16218 .2942 .16872 .30054 .17795 .29711 .17143 .29072 Metetra
0 .023 .122 r
.17143 .29072 .17795 .29711 .18721 .29365 .18071 .28725 Metetra
0 .023 .121 r
.18071 .28725 .18721 .29365 .19651 .29018 .19003 .28375 Metetra
0 .023 .122 r
.19003 .28375 .19651 .29018 .20584 .28672 .19938 .28025 Metetra
0 .023 .122 r
.19938 .28025 .20584 .28672 .21521 .28321 .20877 .27675 Metetra
0 .023 .121 r
.20877 .27675 .21521 .28321 .22461 .27971 .21819 .27321 Metetra
0 .023 .121 r
.21819 .27321 .22461 .27971 .23405 .27619 .22764 .26966 Metetra
0 .023 .121 r
.22764 .26966 .23405 .27619 .24351 .27267 .23713 .26611 Metetra
0 .023 .121 r
.23713 .26611 .24351 .27267 .25302 .26912 .24666 .26255 Metetra
0 .023 .121 r
.24666 .26255 .25302 .26912 .26255 .26557 .25621 .25897 Metetra
0 .023 .121 r
.25621 .25897 .26255 .26557 .27213 .262 .26581 .25538 Metetra
0 .023 .122 r
.26581 .25538 .27213 .262 .28173 .25843 .27543 .25179 Metetra
0 .024 .122 r
.27543 .25179 .28173 .25843 .29138 .25483 .2851 .24818 Metetra
0 .023 .122 r
.2851 .24818 .29138 .25483 .30105 .25122 .2948 .24452 Metetra
0 .023 .122 r
.2948 .24452 .30105 .25122 .31077 .24761 .30453 .2409 Metetra
0 .024 .122 r
.30453 .2409 .31077 .24761 .32052 .24399 .31431 .23722 Metetra
0 .024 .122 r
.31431 .23722 .32052 .24399 .3303 .24035 .32411 .23355 Metetra
0 .024 .122 r
.32411 .23355 .3303 .24035 .34012 .23668 .33396 .22988 Metetra
0 .024 .122 r
.33396 .22988 .34012 .23668 .34997 .23328 .34383 .22621 Metetra
0 .025 .123 r
.34383 .22621 .34997 .23328 .35986 .22962 .3537 .22338 Metetra
0 .025 .123 r
.3537 .22338 .35986 .22962 .36978 .22612 .3637 .21887 Metetra
0 .025 .123 r
.3637 .21887 .36978 .22612 .37975 .22241 .37368 .21537 Metetra
0 .025 .123 r
.37368 .21537 .37975 .22241 .38976 .21867 .38371 .2117 Metetra
0 .025 .124 r
.38371 .2117 .38976 .21867 .39981 .21492 .39378 .20796 Metetra
0 .025 .124 r
.39378 .20796 .39981 .21492 .40989 .21123 .40388 .20422 Metetra
0 .025 .124 r
.40388 .20422 .40989 .21123 .42001 .20737 .41403 .2003 Metetra
0 .025 .123 r
.41403 .2003 .42001 .20737 .43017 .20365 .42421 .19644 Metetra
0 .025 .123 r
.42421 .19644 .43017 .20365 .44036 .19989 .43444 .1924 Metetra
0 .025 .123 r
.43444 .1924 .44036 .19989 .4506 .19604 .44469 .189 Metetra
0 .025 .123 r
.44469 .189 .4506 .19604 .46087 .19229 .455 .18465 Metetra
0 .024 .122 r
.455 .18465 .46087 .19229 .4712 .18783 .46534 .18071 Metetra
0 .024 .122 r
.46534 .18071 .4712 .18783 .48155 .18394 .47572 .17678 Metetra
0 .023 .121 r
.47572 .17678 .48155 .18394 .49194 .18007 .48613 .17288 Metetra
0 .023 .122 r
.48613 .17288 .49194 .18007 .50237 .1762 .49659 .16897 Metetra
0 .023 .122 r
.49659 .16897 .50237 .1762 .51284 .17229 .50708 .16503 Metetra
0 .023 .122 r
.50708 .16503 .51284 .17229 .52335 .16838 .51762 .1611 Metetra
0 .023 .122 r
.51762 .1611 .52335 .16838 .5339 .16442 .5282 .15713 Metetra
0 .023 .121 r
.5282 .15713 .5339 .16442 .54449 .16048 .53881 .15315 Metetra
0 .023 .121 r
.53881 .15315 .54449 .16048 .55512 .15652 .54947 .14915 Metetra
0 .023 .121 r
.54947 .14915 .55512 .15652 .5658 .15254 .56017 .14515 Metetra
0 .023 .121 r
.56017 .14515 .5658 .15254 .57651 .14855 .57091 .14113 Metetra
0 .023 .121 r
.57091 .14113 .57651 .14855 .58727 .14454 .5817 .13709 Metetra
0 .023 .121 r
.5817 .13709 .58727 .14454 .59806 .14051 .59252 .13304 Metetra
0 .023 .121 r
.59252 .13304 .59806 .14051 .6089 .13647 .60339 .12898 Metetra
0 .023 .122 r
.60339 .12898 .6089 .13647 .61978 .13243 .6143 .12489 Metetra
0 .023 .122 r
.6143 .12489 .61978 .13243 .63071 .12834 .62525 .12078 Metetra
0 .023 .121 r
.62525 .12078 .63071 .12834 .64168 .12426 .63625 .11668 Metetra
0 .023 .122 r
.63625 .11668 .64168 .12426 .65268 .12016 .64729 .11254 Metetra
0 .023 .122 r
.64729 .11254 .65268 .12016 .66374 .11604 .65837 .10839 Metetra
0 .023 .122 r
.65837 .10839 .66374 .11604 .67483 .1119 .6695 .10422 Metetra
0 .023 .122 r
.6695 .10422 .67483 .1119 .68598 .10776 .68067 .10004 Metetra
0 .024 .122 r
.68067 .10004 .68598 .10776 .69716 .1036 .69188 .09587 Metetra
0 .024 .122 r
.69188 .09587 .69716 .1036 .70839 .0994 .70314 .09163 Metetra
0 .023 .122 r
.70314 .09163 .70839 .0994 .71966 .09519 .71445 .08739 Metetra
0 .023 .121 r
.71445 .08739 .71966 .09519 .73098 .09097 .72579 .08313 Metetra
0 .023 .121 r
.72579 .08313 .73098 .09097 .74234 .08673 .73719 .07887 Metetra
0 .023 .121 r
.09163 .31184 .09834 .31808 .10736 .3147 .10067 .30843 Metetra
0 .023 .121 r
.10067 .30843 .10736 .3147 .11642 .31132 .10975 .30503 Metetra
0 .023 .122 r
.10975 .30503 .11642 .31132 .1255 .30793 .11885 .30161 Metetra
0 .023 .122 r
.11885 .30161 .1255 .30793 .13462 .30451 .12799 .29817 Metetra
0 .024 .122 r
.12799 .29817 .13462 .30451 .14377 .30109 .13716 .29473 Metetra
0 .023 .122 r
.13716 .29473 .14377 .30109 .15296 .29763 .14636 .29125 Metetra
0 .023 .122 r
.14636 .29125 .15296 .29763 .16218 .2942 .1556 .28778 Metetra
0 .023 .122 r
.1556 .28778 .16218 .2942 .17143 .29072 .16487 .28429 Metetra
0 .023 .121 r
.16487 .28429 .17143 .29072 .18071 .28725 .17417 .28079 Metetra
0 .023 .122 r
.17417 .28079 .18071 .28725 .19003 .28375 .18351 .27728 Metetra
0 .023 .121 r
.18351 .27728 .19003 .28375 .19938 .28025 .19288 .27375 Metetra
0 .023 .122 r
.19288 .27375 .19938 .28025 .20877 .27675 .20229 .27021 Metetra
0 .023 .122 r
.20229 .27021 .20877 .27675 .21819 .27321 .21173 .26667 Metetra
0 .023 .121 r
.21173 .26667 .21819 .27321 .22764 .26966 .2212 .2631 Metetra
0 .023 .121 r
.2212 .2631 .22764 .26966 .23713 .26611 .23071 .25952 Metetra
0 .023 .121 r
.23071 .25952 .23713 .26611 .24666 .26255 .24025 .25593 Metetra
0 .023 .121 r
.24025 .25593 .24666 .26255 .25621 .25897 .24983 .25233 Metetra
0 .023 .121 r
.24983 .25233 .25621 .25897 .26581 .25538 .25944 .24872 Metetra
0 .023 .122 r
.25944 .24872 .26581 .25538 .27543 .25179 .26909 .24509 Metetra
0 .023 .122 r
.26909 .24509 .27543 .25179 .2851 .24818 .27878 .24144 Metetra
0 .023 .122 r
.27878 .24144 .2851 .24818 .2948 .24452 .2885 .2378 Metetra
0 .024 .122 r
.2885 .2378 .2948 .24452 .30453 .2409 .29826 .23414 Metetra
0 .023 .122 r
.29826 .23414 .30453 .2409 .31431 .23722 .30805 .23043 Metetra
0 .023 .122 r
.30805 .23043 .31431 .23722 .32411 .23355 .31788 .22675 Metetra
0 .024 .122 r
.31788 .22675 .32411 .23355 .33396 .22988 .32774 .22306 Metetra
0 .024 .122 r
.32774 .22306 .33396 .22988 .34383 .22621 .33765 .21933 Metetra
0 .024 .123 r
.33765 .21933 .34383 .22621 .3537 .22338 .34757 .21585 Metetra
0 .025 .123 r
.34757 .21585 .3537 .22338 .3637 .21887 .35754 .21238 Metetra
0 .024 .123 r
.35754 .21238 .3637 .21887 .37368 .21537 .36757 .20818 Metetra
0 .024 .123 r
.36757 .20818 .37368 .21537 .38371 .2117 .37763 .2044 Metetra
0 .024 .123 r
.37763 .2044 .38371 .2117 .39378 .20796 .38771 .20072 Metetra
0 .025 .123 r
.38771 .20072 .39378 .20796 .40388 .20422 .39784 .19701 Metetra
0 .025 .123 r
.39784 .19701 .40388 .20422 .41403 .2003 .40801 .19299 Metetra
0 .024 .123 r
.40801 .19299 .41403 .2003 .42421 .19644 .41822 .18907 Metetra
0 .024 .122 r
.41822 .18907 .42421 .19644 .43444 .1924 .42846 .18542 Metetra
0 .025 .123 r
.42846 .18542 .43444 .1924 .44469 .189 .43874 .18164 Metetra
0 .024 .123 r
.43874 .18164 .44469 .189 .455 .18465 .44908 .17738 Metetra
0 .024 .122 r
.44908 .17738 .455 .18465 .46534 .18071 .45944 .17348 Metetra
0 .024 .122 r
.45944 .17348 .46534 .18071 .47572 .17678 .46984 .16959 Metetra
0 .023 .122 r
.46984 .16959 .47572 .17678 .48613 .17288 .48028 .16565 Metetra
0 .023 .122 r
.48028 .16565 .48613 .17288 .49659 .16897 .49076 .16171 Metetra
0 .023 .121 r
.49076 .16171 .49659 .16897 .50708 .16503 .50129 .15774 Metetra
0 .023 .121 r
.50129 .15774 .50708 .16503 .51762 .1611 .51185 .15376 Metetra
0 .023 .121 r
.51185 .15376 .51762 .1611 .5282 .15713 .52245 .14979 Metetra
0 .023 .122 r
.52245 .14979 .5282 .15713 .53881 .15315 .5331 .14578 Metetra
0 .023 .121 r
.5331 .14578 .53881 .15315 .54947 .14915 .54378 .14175 Metetra
0 .023 .121 r
.54378 .14175 .54947 .14915 .56017 .14515 .55451 .13772 Metetra
0 .023 .121 r
.55451 .13772 .56017 .14515 .57091 .14113 .56528 .13366 Metetra
0 .023 .121 r
.56528 .13366 .57091 .14113 .5817 .13709 .57609 .1296 Metetra
0 .023 .121 r
.57609 .1296 .5817 .13709 .59252 .13304 .58694 .12552 Metetra
0 .023 .121 r
.58694 .12552 .59252 .13304 .60339 .12898 .59784 .12142 Metetra
0 .023 .122 r
.59784 .12142 .60339 .12898 .6143 .12489 .60878 .1173 Metetra
0 .023 .121 r
.60878 .1173 .6143 .12489 .62525 .12078 .61976 .11317 Metetra
0 .023 .122 r
.61976 .11317 .62525 .12078 .63625 .11668 .63078 .10904 Metetra
0 .023 .122 r
.63078 .10904 .63625 .11668 .64729 .11254 .64185 .10486 Metetra
0 .023 .121 r
.64185 .10486 .64729 .11254 .65837 .10839 .65296 .10069 Metetra
0 .023 .122 r
.65296 .10069 .65837 .10839 .6695 .10422 .66412 .09649 Metetra
0 .023 .122 r
.66412 .09649 .6695 .10422 .68067 .10004 .67532 .09228 Metetra
0 .024 .122 r
.67532 .09228 .68067 .10004 .69188 .09587 .68657 .08807 Metetra
0 .024 .122 r
.68657 .08807 .69188 .09587 .70314 .09163 .69786 .0838 Metetra
0 .023 .121 r
.69786 .0838 .70314 .09163 .71445 .08739 .70919 .07953 Metetra
0 .023 .121 r
.70919 .07953 .71445 .08739 .72579 .08313 .72057 .07525 Metetra
0 .023 .121 r
.72057 .07525 .72579 .08313 .73719 .07887 .732 .07095 Metetra
0 .023 .122 r
.08488 .30556 .09163 .31184 .10067 .30843 .09394 .30213 Metetra
0 .023 .121 r
.09394 .30213 .10067 .30843 .10975 .30503 .10303 .29869 Metetra
0 .023 .122 r
.10303 .29869 .10975 .30503 .11885 .30161 .11215 .29525 Metetra
0 .023 .122 r
.11215 .29525 .11885 .30161 .12799 .29817 .12131 .2918 Metetra
0 .024 .122 r
.12131 .2918 .12799 .29817 .13716 .29473 .13049 .28834 Metetra
0 .023 .122 r
.13049 .28834 .13716 .29473 .14636 .29125 .13972 .28483 Metetra
0 .023 .121 r
.13972 .28483 .14636 .29125 .1556 .28778 .14897 .28133 Metetra
0 .023 .121 r
.14897 .28133 .1556 .28778 .16487 .28429 .15826 .27782 Metetra
0 .023 .122 r
.15826 .27782 .16487 .28429 .17417 .28079 .16758 .27431 Metetra
0 .023 .122 r
.16758 .27431 .17417 .28079 .18351 .27728 .17694 .27075 Metetra
0 .023 .121 r
.17694 .27075 .18351 .27728 .19288 .27375 .18633 .26721 Metetra
0 .023 .121 r
.18633 .26721 .19288 .27375 .20229 .27021 .19576 .26365 Metetra
0 .023 .121 r
.19576 .26365 .20229 .27021 .21173 .26667 .20522 .26007 Metetra
0 .023 .121 r
.20522 .26007 .21173 .26667 .2212 .2631 .21471 .25649 Metetra
0 .023 .121 r
.21471 .25649 .2212 .2631 .23071 .25952 .22424 .25289 Metetra
0 .023 .121 r
.22424 .25289 .23071 .25952 .24025 .25593 .23381 .24927 Metetra
0 .023 .122 r
.23381 .24927 .24025 .25593 .24983 .25233 .2434 .24565 Metetra
0 .023 .122 r
.2434 .24565 .24983 .25233 .25944 .24872 .25304 .24201 Metetra
0 .023 .122 r
.25304 .24201 .25944 .24872 .26909 .24509 .26271 .23835 Metetra
0 .023 .121 r
.26271 .23835 .26909 .24509 .27878 .24144 .27242 .23467 Metetra
0 .023 .121 r
.27242 .23467 .27878 .24144 .2885 .2378 .28216 .231 Metetra
0 .024 .122 r
.28216 .231 .2885 .2378 .29826 .23414 .29194 .22731 Metetra
0 .024 .122 r
.29194 .22731 .29826 .23414 .30805 .23043 .30175 .22363 Metetra
0 .024 .122 r
.30175 .22363 .30805 .23043 .31788 .22675 .3116 .21988 Metetra
0 .024 .122 r
.3116 .21988 .31788 .22675 .32774 .22306 .32149 .21617 Metetra
0 .024 .122 r
.32149 .21617 .32774 .22306 .33765 .21933 .33142 .21241 Metetra
0 .024 .122 r
.33142 .21241 .33765 .21933 .34757 .21585 .34138 .20871 Metetra
0 .024 .123 r
.34138 .20871 .34757 .21585 .35754 .21238 .35136 .20522 Metetra
0 .025 .123 r
.35136 .20522 .35754 .21238 .36757 .20818 .36139 .2016 Metetra
0 .024 .123 r
.36139 .2016 .36757 .20818 .37763 .2044 .37147 .19768 Metetra
0 .024 .123 r
.37147 .19768 .37763 .2044 .38771 .20072 .38159 .19376 Metetra
0 .025 .123 r
.38159 .19376 .38771 .20072 .39784 .19701 .39174 .19005 Metetra
0 .025 .123 r
.39174 .19005 .39784 .19701 .40801 .19299 .40193 .1862 Metetra
0 .024 .123 r
.40193 .1862 .40801 .19299 .41822 .18907 .41216 .18246 Metetra
0 .025 .123 r
.41216 .18246 .41822 .18907 .42846 .18542 .42244 .17848 Metetra
0 .025 .123 r
.42244 .17848 .42846 .18542 .43874 .18164 .43275 .17433 Metetra
0 .024 .122 r
.43275 .17433 .43874 .18164 .44908 .17738 .44311 .17019 Metetra
0 .023 .122 r
.44311 .17019 .44908 .17738 .45944 .17348 .4535 .16626 Metetra
0 .023 .122 r
.4535 .16626 .45944 .17348 .46984 .16959 .46392 .16231 Metetra
0 .023 .122 r
.46392 .16231 .46984 .16959 .48028 .16565 .47439 .15835 Metetra
0 .023 .122 r
.47439 .15835 .48028 .16565 .49076 .16171 .4849 .15438 Metetra
0 .023 .121 r
.4849 .15438 .49076 .16171 .50129 .15774 .49545 .15038 Metetra
0 .023 .121 r
.49545 .15038 .50129 .15774 .51185 .15376 .50603 .1464 Metetra
0 .023 .121 r
.50603 .1464 .51185 .15376 .52245 .14979 .51666 .14237 Metetra
0 .023 .121 r
.51666 .14237 .52245 .14979 .5331 .14578 .52734 .13833 Metetra
0 .023 .121 r
.52734 .13833 .5331 .14578 .54378 .14175 .53805 .13429 Metetra
0 .023 .121 r
.53805 .13429 .54378 .14175 .55451 .13772 .5488 .13022 Metetra
0 .023 .121 r
.5488 .13022 .55451 .13772 .56528 .13366 .5596 .12614 Metetra
0 .023 .121 r
.5596 .12614 .56528 .13366 .57609 .1296 .57044 .12205 Metetra
0 .023 .121 r
.57044 .12205 .57609 .1296 .58694 .12552 .58132 .11793 Metetra
0 .023 .121 r
.58132 .11793 .58694 .12552 .59784 .12142 .59225 .11381 Metetra
0 .023 .121 r
.59225 .11381 .59784 .12142 .60878 .1173 .60321 .10967 Metetra
0 .023 .121 r
.60321 .10967 .60878 .1173 .61976 .11317 .61422 .1055 Metetra
0 .023 .122 r
.61422 .1055 .61976 .11317 .63078 .10904 .62528 .10133 Metetra
0 .023 .122 r
.62528 .10133 .63078 .10904 .64185 .10486 .63638 .09713 Metetra
0 .023 .121 r
.63638 .09713 .64185 .10486 .65296 .10069 .64752 .09293 Metetra
0 .023 .122 r
.64752 .09293 .65296 .10069 .66412 .09649 .65871 .08871 Metetra
0 .023 .122 r
.65871 .08871 .66412 .09649 .67532 .09228 .66994 .08447 Metetra
0 .024 .122 r
.66994 .08447 .67532 .09228 .68657 .08807 .68121 .08022 Metetra
0 .024 .122 r
.68121 .08022 .68657 .08807 .69786 .0838 .69253 .07593 Metetra
0 .023 .122 r
.69253 .07593 .69786 .0838 .70919 .07953 .7039 .07162 Metetra
0 .023 .121 r
.7039 .07162 .70919 .07953 .72057 .07525 .71531 .0673 Metetra
0 .023 .121 r
.71531 .0673 .72057 .07525 .732 .07095 .72677 .06297 Metetra
0 .023 .122 r
.07808 .29922 .08488 .30556 .09394 .30213 .08716 .29577 Metetra
0 .023 .121 r
.08716 .29577 .09394 .30213 .10303 .29869 .09627 .29232 Metetra
0 .023 .122 r
.09627 .29232 .10303 .29869 .11215 .29525 .10541 .28886 Metetra
0 .024 .122 r
.10541 .28886 .11215 .29525 .12131 .2918 .11458 .28539 Metetra
0 .024 .122 r
.11458 .28539 .12131 .2918 .13049 .28834 .12379 .28189 Metetra
0 .024 .122 r
.12379 .28189 .13049 .28834 .13972 .28483 .13303 .27839 Metetra
0 .023 .122 r
.13303 .27839 .13972 .28483 .14897 .28133 .14231 .27484 Metetra
0 .023 .121 r
.14231 .27484 .14897 .28133 .15826 .27782 .15161 .2713 Metetra
0 .023 .122 r
.15161 .2713 .15826 .27782 .16758 .27431 .16096 .26776 Metetra
0 .023 .122 r
.16096 .26776 .16758 .27431 .17694 .27075 .17033 .2642 Metetra
0 .023 .122 r
.17033 .2642 .17694 .27075 .18633 .26721 .17974 .26063 Metetra
0 .023 .121 r
.17974 .26063 .18633 .26721 .19576 .26365 .18919 .25704 Metetra
0 .023 .121 r
.18919 .25704 .19576 .26365 .20522 .26007 .19867 .25344 Metetra
0 .023 .121 r
.19867 .25344 .20522 .26007 .21471 .25649 .20818 .24983 Metetra
0 .023 .121 r
.20818 .24983 .21471 .25649 .22424 .25289 .21773 .2462 Metetra
0 .023 .121 r
.21773 .2462 .22424 .25289 .23381 .24927 .22732 .24256 Metetra
0 .023 .121 r
.22732 .24256 .23381 .24927 .2434 .24565 .23694 .23891 Metetra
0 .023 .121 r
.23694 .23891 .2434 .24565 .25304 .24201 .24659 .23524 Metetra
0 .023 .121 r
.24659 .23524 .25304 .24201 .26271 .23835 .25628 .23157 Metetra
0 .023 .121 r
.25628 .23157 .26271 .23835 .27242 .23467 .26601 .22788 Metetra
0 .023 .122 r
.26601 .22788 .27242 .23467 .28216 .231 .27577 .22419 Metetra
0 .023 .122 r
.27577 .22419 .28216 .231 .29194 .22731 .28557 .22045 Metetra
0 .024 .122 r
.28557 .22045 .29194 .22731 .30175 .22363 .29541 .21671 Metetra
0 .024 .122 r
.29541 .21671 .30175 .22363 .3116 .21988 .30528 .21299 Metetra
0 .024 .122 r
.30528 .21299 .3116 .21988 .32149 .21617 .3152 .20921 Metetra
0 .024 .122 r
.3152 .20921 .32149 .21617 .33142 .21241 .32514 .20546 Metetra
0 .024 .122 r
.32514 .20546 .33142 .21241 .34138 .20871 .33513 .20167 Metetra
0 .024 .122 r
.33513 .20167 .34138 .20871 .35136 .20522 .34514 .19812 Metetra
0 .025 .123 r
.34514 .19812 .35136 .20522 .36139 .2016 .3552 .19436 Metetra
0 .025 .123 r
.3552 .19436 .36139 .2016 .37147 .19768 .3653 .19038 Metetra
0 .024 .123 r
.3653 .19038 .37147 .19768 .38159 .19376 .37544 .18667 Metetra
0 .025 .123 r
.37544 .18667 .38159 .19376 .39174 .19005 .38561 .18292 Metetra
0 .025 .123 r
.38561 .18292 .39174 .19005 .40193 .1862 .39583 .17889 Metetra
0 .025 .123 r
.39583 .17889 .40193 .1862 .41216 .18246 .40609 .17481 Metetra
0 .025 .123 r
.40609 .17481 .41216 .18246 .42244 .17848 .41638 .17123 Metetra
0 .024 .123 r
.41638 .17123 .42244 .17848 .43275 .17433 .42673 .16686 Metetra
0 .024 .122 r
.42673 .16686 .43275 .17433 .44311 .17019 .4371 .16293 Metetra
0 .024 .122 r
.4371 .16293 .44311 .17019 .4535 .16626 .44751 .15899 Metetra
0 .023 .122 r
.44751 .15899 .4535 .16626 .46392 .16231 .45796 .15499 Metetra
0 .023 .122 r
.45796 .15499 .46392 .16231 .47439 .15835 .46846 .15102 Metetra
0 .023 .122 r
.46846 .15102 .47439 .15835 .4849 .15438 .47899 .14701 Metetra
0 .023 .121 r
.47899 .14701 .4849 .15438 .49545 .15038 .48956 .14299 Metetra
0 .023 .121 r
.48956 .14299 .49545 .15038 .50603 .1464 .50018 .13895 Metetra
0 .023 .121 r
.50018 .13895 .50603 .1464 .51666 .14237 .51084 .13492 Metetra
0 .023 .121 r
.51084 .13492 .51666 .14237 .52734 .13833 .52154 .13086 Metetra
0 .023 .121 r
.52154 .13086 .52734 .13833 .53805 .13429 .53228 .12678 Metetra
0 .023 .121 r
.53228 .12678 .53805 .13429 .5488 .13022 .54306 .12269 Metetra
0 .023 .121 r
.54306 .12269 .5488 .13022 .5596 .12614 .55388 .11858 Metetra
0 .023 .121 r
.55388 .11858 .5596 .12614 .57044 .12205 .56475 .11445 Metetra
0 .023 .121 r
.56475 .11445 .57044 .12205 .58132 .11793 .57566 .11031 Metetra
0 .023 .121 r
.57566 .11031 .58132 .11793 .59225 .11381 .58661 .10615 Metetra
0 .023 .122 r
.58661 .10615 .59225 .11381 .60321 .10967 .59761 .10197 Metetra
0 .023 .122 r
.59761 .10197 .60321 .10967 .61422 .1055 .60865 .09779 Metetra
0 .023 .122 r
.60865 .09779 .61422 .1055 .62528 .10133 .61973 .09358 Metetra
0 .023 .122 r
.61973 .09358 .62528 .10133 .63638 .09713 .63086 .08936 Metetra
0 .023 .122 r
.63086 .08936 .63638 .09713 .64752 .09293 .64203 .08511 Metetra
0 .024 .122 r
.64203 .08511 .64752 .09293 .65871 .08871 .65325 .08087 Metetra
0 .024 .122 r
.65325 .08087 .65871 .08871 .66994 .08447 .66451 .07662 Metetra
0 .024 .122 r
.66451 .07662 .66994 .08447 .68121 .08022 .67582 .07229 Metetra
0 .024 .122 r
.67582 .07229 .68121 .08022 .69253 .07593 .68717 .06797 Metetra
0 .023 .122 r
.68717 .06797 .69253 .07593 .7039 .07162 .69857 .06363 Metetra
0 .023 .121 r
.69857 .06363 .7039 .07162 .71531 .0673 .71001 .05929 Metetra
0 .023 .121 r
.71001 .05929 .71531 .0673 .72677 .06297 .7215 .05493 Metetra
0 .023 .121 r
.07124 .29284 .07808 .29922 .08716 .29577 .08034 .28937 Metetra
0 .023 .121 r
.08034 .28937 .08716 .29577 .09627 .29232 .08946 .28589 Metetra
0 .023 .121 r
.08946 .28589 .09627 .29232 .10541 .28886 .09862 .2824 Metetra
0 .023 .122 r
.09862 .2824 .10541 .28886 .11458 .28539 .10781 .27891 Metetra
0 .024 .122 r
.10781 .27891 .11458 .28539 .12379 .28189 .11704 .27541 Metetra
0 .024 .122 r
.11704 .27541 .12379 .28189 .13303 .27839 .12629 .27188 Metetra
0 .024 .122 r
.12629 .27188 .13303 .27839 .14231 .27484 .13559 .26833 Metetra
0 .023 .122 r
.13559 .26833 .14231 .27484 .15161 .2713 .14492 .26476 Metetra
0 .023 .122 r
.14492 .26476 .15161 .2713 .16096 .26776 .15428 .26119 Metetra
0 .023 .122 r
.15428 .26119 .16096 .26776 .17033 .2642 .16367 .2576 Metetra
0 .023 .122 r
.16367 .2576 .17033 .2642 .17974 .26063 .17311 .25399 Metetra
0 .023 .121 r
.17311 .25399 .17974 .26063 .18919 .25704 .18257 .25038 Metetra
0 .023 .121 r
.18257 .25038 .18919 .25704 .19867 .25344 .19207 .24677 Metetra
0 .023 .122 r
.19207 .24677 .19867 .25344 .20818 .24983 .2016 .24313 Metetra
0 .023 .121 r
.2016 .24313 .20818 .24983 .21773 .2462 .21117 .23947 Metetra
0 .023 .121 r
.21117 .23947 .21773 .2462 .22732 .24256 .22078 .2358 Metetra
0 .023 .121 r
.22078 .2358 .22732 .24256 .23694 .23891 .23042 .23213 Metetra
0 .023 .121 r
.23042 .23213 .23694 .23891 .24659 .23524 .2401 .22844 Metetra
0 .023 .122 r
.2401 .22844 .24659 .23524 .25628 .23157 .24981 .22474 Metetra
0 .023 .122 r
.24981 .22474 .25628 .23157 .26601 .22788 .25956 .22101 Metetra
0 .023 .122 r
.25956 .22101 .26601 .22788 .27577 .22419 .26935 .21728 Metetra
0 .023 .122 r
.26935 .21728 .27577 .22419 .28557 .22045 .27917 .21354 Metetra
0 .023 .122 r
.27917 .21354 .28557 .22045 .29541 .21671 .28903 .20978 Metetra
0 .024 .122 r
.28903 .20978 .29541 .21671 .30528 .21299 .29892 .20601 Metetra
0 .024 .122 r
.29892 .20601 .30528 .21299 .3152 .20921 .30886 .20222 Metetra
0 .024 .122 r
.30886 .20222 .3152 .20921 .32514 .20546 .31883 .19842 Metetra
0 .024 .122 r
.31883 .19842 .32514 .20546 .33513 .20167 .32884 .1946 Metetra
0 .024 .122 r
.32884 .1946 .33513 .20167 .34514 .19812 .33888 .19087 Metetra
0 .025 .123 r
.33888 .19087 .34514 .19812 .3552 .19436 .34893 .18762 Metetra
0 .025 .123 r
.34893 .18762 .3552 .19436 .3653 .19038 .35907 .18349 Metetra
0 .025 .123 r
.35907 .18349 .3653 .19038 .37544 .18667 .36922 .17972 Metetra
0 .025 .123 r
.36922 .17972 .37544 .18667 .38561 .18292 .37942 .17587 Metetra
0 .025 .123 r
.37942 .17587 .38561 .18292 .39583 .17889 .38967 .1718 Metetra
0 .024 .123 r
.38967 .1718 .39583 .17889 .40609 .17481 .39995 .1679 Metetra
0 .024 .123 r
.39995 .1679 .40609 .17481 .41638 .17123 .41028 .16367 Metetra
0 .024 .122 r
.41028 .16367 .41638 .17123 .42673 .16686 .42065 .15958 Metetra
0 .023 .122 r
.42065 .15958 .42673 .16686 .4371 .16293 .43104 .1556 Metetra
0 .024 .122 r
.43104 .1556 .4371 .16293 .44751 .15899 .44148 .15163 Metetra
0 .023 .122 r
.44148 .15163 .44751 .15899 .45796 .15499 .45196 .14763 Metetra
0 .023 .122 r
.45196 .14763 .45796 .15499 .46846 .15102 .46248 .14361 Metetra
0 .023 .121 r
.46248 .14361 .46846 .15102 .47899 .14701 .47304 .13957 Metetra
0 .023 .121 r
.47304 .13957 .47899 .14701 .48956 .14299 .48364 .13555 Metetra
0 .023 .121 r
.48364 .13555 .48956 .14299 .50018 .13895 .49428 .13147 Metetra
0 .023 .121 r
.49428 .13147 .50018 .13895 .51084 .13492 .50497 .1274 Metetra
0 .023 .121 r
.50497 .1274 .51084 .13492 .52154 .13086 .51569 .12331 Metetra
0 .023 .122 r
.51569 .12331 .52154 .13086 .53228 .12678 .52646 .1192 Metetra
0 .023 .121 r
.52646 .1192 .53228 .12678 .54306 .12269 .53727 .11508 Metetra
0 .023 .121 r
.53727 .11508 .54306 .12269 .55388 .11858 .54812 .11094 Metetra
0 .023 .121 r
.54812 .11094 .55388 .11858 .56475 .11445 .55902 .10679 Metetra
0 .023 .122 r
.55902 .10679 .56475 .11445 .57566 .11031 .56996 .10262 Metetra
0 .023 .122 r
.56996 .10262 .57566 .11031 .58661 .10615 .58094 .09842 Metetra
0 .023 .121 r
.58094 .09842 .58661 .10615 .59761 .10197 .59196 .09421 Metetra
0 .023 .122 r
.59196 .09421 .59761 .10197 .60865 .09779 .60303 .09001 Metetra
0 .023 .122 r
.60303 .09001 .60865 .09779 .61973 .09358 .61415 .08576 Metetra
0 .023 .122 r
.61415 .08576 .61973 .09358 .63086 .08936 .6253 .08151 Metetra
0 .023 .122 r
.6253 .08151 .63086 .08936 .64203 .08511 .63651 .07724 Metetra
0 .024 .122 r
.63651 .07724 .64203 .08511 .65325 .08087 .64776 .07299 Metetra
0 .024 .122 r
.64776 .07299 .65325 .08087 .66451 .07662 .65905 .06865 Metetra
0 .024 .122 r
.65905 .06865 .66451 .07662 .67582 .07229 .67038 .06431 Metetra
0 .023 .122 r
.67038 .06431 .67582 .07229 .68717 .06797 .68177 .05996 Metetra
0 .023 .121 r
.68177 .05996 .68717 .06797 .69857 .06363 .6932 .0556 Metetra
0 .023 .121 r
.6932 .0556 .69857 .06363 .71001 .05929 .70467 .05122 Metetra
0 .023 .121 r
.70467 .05122 .71001 .05929 .7215 .05493 .71619 .04682 Metetra
0 .023 .121 r
.06435 .28642 .07124 .29284 .08034 .28937 .07347 .28293 Metetra
0 .023 .121 r
.07347 .28293 .08034 .28937 .08946 .28589 .08261 .27943 Metetra
0 .023 .121 r
.08261 .27943 .08946 .28589 .09862 .2824 .09179 .27591 Metetra
0 .023 .121 r
.09179 .27591 .09862 .2824 .10781 .27891 .101 .27239 Metetra
0 .023 .122 r
.101 .27239 .10781 .27891 .11704 .27541 .11024 .26886 Metetra
0 .024 .122 r
.11024 .26886 .11704 .27541 .12629 .27188 .11952 .26532 Metetra
0 .024 .122 r
.11952 .26532 .12629 .27188 .13559 .26833 .12883 .26174 Metetra
0 .024 .122 r
.12883 .26174 .13559 .26833 .14492 .26476 .13818 .25815 Metetra
0 .024 .122 r
.13818 .25815 .14492 .26476 .15428 .26119 .14756 .25456 Metetra
0 .023 .122 r
.14756 .25456 .15428 .26119 .16367 .2576 .15697 .25094 Metetra
0 .023 .122 r
.15697 .25094 .16367 .2576 .17311 .25399 .16642 .24733 Metetra
0 .023 .122 r
.16642 .24733 .17311 .25399 .18257 .25038 .17591 .24369 Metetra
0 .023 .122 r
.17591 .24369 .18257 .25038 .19207 .24677 .18543 .24005 Metetra
0 .023 .122 r
.18543 .24005 .19207 .24677 .2016 .24313 .19498 .23638 Metetra
0 .023 .122 r
.19498 .23638 .2016 .24313 .21117 .23947 .20457 .2327 Metetra
0 .023 .121 r
.20457 .2327 .21117 .23947 .22078 .2358 .2142 .22901 Metetra
0 .023 .121 r
.2142 .22901 .22078 .2358 .23042 .23213 .22386 .22531 Metetra
0 .023 .122 r
.22386 .22531 .23042 .23213 .2401 .22844 .23356 .2216 Metetra
0 .023 .122 r
.23356 .2216 .2401 .22844 .24981 .22474 .24329 .21787 Metetra
0 .023 .121 r
.24329 .21787 .24981 .22474 .25956 .22101 .25307 .21411 Metetra
0 .023 .121 r
.25307 .21411 .25956 .22101 .26935 .21728 .26287 .21036 Metetra
0 .023 .122 r
.26287 .21036 .26935 .21728 .27917 .21354 .27271 .2066 Metetra
0 .023 .122 r
.27271 .2066 .27917 .21354 .28903 .20978 .2826 .20279 Metetra
0 .023 .122 r
.2826 .20279 .28903 .20978 .29892 .20601 .29252 .199 Metetra
0 .023 .122 r
.29252 .199 .29892 .20601 .30886 .20222 .30247 .19518 Metetra
0 .023 .122 r
.30247 .19518 .30886 .20222 .31883 .19842 .31247 .19135 Metetra
0 .023 .122 r
.31247 .19135 .31883 .19842 .32884 .1946 .3225 .18751 Metetra
0 .024 .122 r
.3225 .18751 .32884 .1946 .33888 .19087 .33257 .18366 Metetra
0 .024 .123 r
.33257 .18366 .33888 .19087 .34893 .18762 .34266 .18009 Metetra
0 .025 .123 r
.34266 .18009 .34893 .18762 .35907 .18349 .3528 .17631 Metetra
0 .025 .124 r
.3528 .17631 .35907 .18349 .36922 .17972 .36297 .17263 Metetra
0 .025 .124 r
.36297 .17263 .36922 .17972 .37942 .17587 .3732 .16874 Metetra
0 .025 .124 r
.3732 .16874 .37942 .17587 .38967 .1718 .38347 .16477 Metetra
0 .025 .124 r
.38347 .16477 .38967 .1718 .39995 .1679 .39377 .16075 Metetra
0 .024 .123 r
.39377 .16075 .39995 .1679 .41028 .16367 .40414 .15625 Metetra
0 .024 .122 r
.40414 .15625 .41028 .16367 .42065 .15958 .41452 .15224 Metetra
0 .023 .121 r
.41452 .15224 .42065 .15958 .43104 .1556 .42495 .14823 Metetra
0 .023 .121 r
.42495 .14823 .43104 .1556 .44148 .15163 .43541 .14423 Metetra
0 .023 .122 r
.43541 .14423 .44148 .15163 .45196 .14763 .44592 .14021 Metetra
0 .023 .122 r
.44592 .14021 .45196 .14763 .46248 .14361 .45646 .13617 Metetra
0 .023 .121 r
.45646 .13617 .46248 .14361 .47304 .13957 .46705 .13212 Metetra
0 .023 .122 r
.46705 .13212 .47304 .13957 .48364 .13555 .47767 .12804 Metetra
0 .023 .121 r
.47767 .12804 .48364 .13555 .49428 .13147 .48834 .12394 Metetra
0 .023 .121 r
.48834 .12394 .49428 .13147 .50497 .1274 .49905 .11985 Metetra
0 .023 .122 r
.49905 .11985 .50497 .1274 .51569 .12331 .50981 .11573 Metetra
0 .023 .122 r
.50981 .11573 .51569 .12331 .52646 .1192 .5206 .11159 Metetra
0 .023 .121 r
.5206 .11159 .52646 .1192 .53727 .11508 .53144 .10743 Metetra
0 .023 .121 r
.53144 .10743 .53727 .11508 .54812 .11094 .54232 .10326 Metetra
0 .023 .121 r
.54232 .10326 .54812 .11094 .55902 .10679 .55324 .09908 Metetra
0 .023 .122 r
.55324 .09908 .55902 .10679 .56996 .10262 .56421 .09488 Metetra
0 .023 .122 r
.56421 .09488 .56996 .10262 .58094 .09842 .57522 .09066 Metetra
0 .023 .122 r
.57522 .09066 .58094 .09842 .59196 .09421 .58628 .08642 Metetra
0 .023 .122 r
.58628 .08642 .59196 .09421 .60303 .09001 .59738 .08216 Metetra
0 .023 .122 r
.59738 .08216 .60303 .09001 .61415 .08576 .60852 .07792 Metetra
0 .024 .122 r
.60852 .07792 .61415 .08576 .6253 .08151 .61971 .07362 Metetra
0 .024 .122 r
.61971 .07362 .6253 .08151 .63651 .07724 .63094 .06932 Metetra
0 .024 .122 r
.63094 .06932 .63651 .07724 .64776 .07299 .64222 .06499 Metetra
0 .024 .122 r
.64222 .06499 .64776 .07299 .65905 .06865 .65354 .06063 Metetra
0 .023 .122 r
.65354 .06063 .65905 .06865 .67038 .06431 .66491 .05627 Metetra
0 .023 .121 r
.66491 .05627 .67038 .06431 .68177 .05996 .67632 .05189 Metetra
0 .023 .121 r
.67632 .05189 .68177 .05996 .6932 .0556 .68778 .0475 Metetra
0 .023 .121 r
.68778 .0475 .6932 .0556 .70467 .05122 .69929 .04309 Metetra
0 .023 .121 r
.69929 .04309 .70467 .05122 .71619 .04682 .71085 .03866 Metetra
0 .023 .121 r
.05742 .27997 .06435 .28642 .07347 .28293 .06655 .27645 Metetra
0 .023 .121 r
.06655 .27645 .07347 .28293 .08261 .27943 .07571 .27292 Metetra
0 .023 .121 r
.07571 .27292 .08261 .27943 .09179 .27591 .08491 .26938 Metetra
0 .023 .121 r
.08491 .26938 .09179 .27591 .101 .27239 .09414 .26583 Metetra
0 .023 .121 r
.09414 .26583 .101 .27239 .11024 .26886 .1034 .26227 Metetra
0 .023 .122 r
.1034 .26227 .11024 .26886 .11952 .26532 .11269 .2587 Metetra
0 .024 .122 r
.11269 .2587 .11952 .26532 .12883 .26174 .12203 .25511 Metetra
0 .023 .122 r
.12203 .25511 .12883 .26174 .13818 .25815 .13139 .25151 Metetra
0 .023 .122 r
.13139 .25151 .13818 .25815 .14756 .25456 .14079 .24789 Metetra
0 .023 .122 r
.14079 .24789 .14756 .25456 .15697 .25094 .15023 .24426 Metetra
0 .023 .122 r
.15023 .24426 .15697 .25094 .16642 .24733 .1597 .2406 Metetra
0 .023 .122 r
.1597 .2406 .16642 .24733 .17591 .24369 .1692 .23696 Metetra
0 .023 .122 r
.1692 .23696 .17591 .24369 .18543 .24005 .17874 .23326 Metetra
0 .023 .122 r
.17874 .23326 .18543 .24005 .19498 .23638 .18832 .22959 Metetra
0 .023 .122 r
.18832 .22959 .19498 .23638 .20457 .2327 .19793 .22589 Metetra
0 .023 .122 r
.19793 .22589 .20457 .2327 .2142 .22901 .20757 .22217 Metetra
0 .023 .122 r
.20757 .22217 .2142 .22901 .22386 .22531 .21726 .21845 Metetra
0 .023 .122 r
.21726 .21845 .22386 .22531 .23356 .2216 .22698 .21469 Metetra
0 .023 .122 r
.22698 .21469 .23356 .2216 .24329 .21787 .23673 .21094 Metetra
0 .023 .122 r
.23673 .21094 .24329 .21787 .25307 .21411 .24652 .20718 Metetra
0 .023 .122 r
.24652 .20718 .25307 .21411 .26287 .21036 .25635 .20337 Metetra
0 .023 .122 r
.25635 .20337 .26287 .21036 .27271 .2066 .26622 .19957 Metetra
0 .023 .121 r
.26622 .19957 .27271 .2066 .2826 .20279 .27612 .19577 Metetra
0 .023 .121 r
.27612 .19577 .2826 .20279 .29252 .199 .28606 .19193 Metetra
0 .023 .121 r
.28606 .19193 .29252 .199 .30247 .19518 .29604 .18809 Metetra
0 .023 .121 r
.29604 .18809 .30247 .19518 .31247 .19135 .30606 .18424 Metetra
0 .023 .122 r
.30606 .18424 .31247 .19135 .3225 .18751 .31611 .18037 Metetra
0 .023 .122 r
.31611 .18037 .3225 .18751 .33257 .18366 .32621 .1765 Metetra
0 .024 .122 r
.32621 .1765 .33257 .18366 .34266 .18009 .33633 .17269 Metetra
0 .025 .123 r
.33633 .17269 .34266 .18009 .3528 .17631 .34648 .16924 Metetra
0 .025 .123 r
.34648 .16924 .3528 .17631 .36297 .17263 .3567 .16503 Metetra
0 .025 .124 r
.3567 .16503 .36297 .17263 .3732 .16874 .36695 .16121 Metetra
0 .025 .124 r
.36695 .16121 .3732 .16874 .38347 .16477 .37723 .15729 Metetra
0 .025 .123 r
.37723 .15729 .38347 .16477 .39377 .16075 .38758 .15297 Metetra
0 .024 .122 r
.38758 .15297 .39377 .16075 .40414 .15625 .39795 .14887 Metetra
0 .024 .122 r
.39795 .14887 .40414 .15625 .41452 .15224 .40836 .14485 Metetra
0 .023 .121 r
.40836 .14485 .41452 .15224 .42495 .14823 .41881 .14082 Metetra
0 .023 .121 r
.41881 .14082 .42495 .14823 .43541 .14423 .4293 .13678 Metetra
0 .023 .121 r
.4293 .13678 .43541 .14423 .44592 .14021 .43983 .13273 Metetra
0 .023 .121 r
.43983 .13273 .44592 .14021 .45646 .13617 .4504 .12865 Metetra
0 .023 .121 r
.4504 .12865 .45646 .13617 .46705 .13212 .46101 .12457 Metetra
0 .023 .122 r
.46101 .12457 .46705 .13212 .47767 .12804 .47166 .12048 Metetra
0 .023 .122 r
.47166 .12048 .47767 .12804 .48834 .12394 .48236 .11636 Metetra
0 .023 .122 r
.48236 .11636 .48834 .12394 .49905 .11985 .4931 .11222 Metetra
0 .023 .122 r
.4931 .11222 .49905 .11985 .50981 .11573 .50388 .10807 Metetra
0 .023 .122 r
.50388 .10807 .50981 .11573 .5206 .11159 .5147 .10391 Metetra
0 .023 .122 r
.5147 .10391 .5206 .11159 .53144 .10743 .52557 .09973 Metetra
0 .023 .122 r
.52557 .09973 .53144 .10743 .54232 .10326 .53648 .09553 Metetra
0 .023 .122 r
.53648 .09553 .54232 .10326 .55324 .09908 .54743 .09131 Metetra
0 .023 .122 r
.54743 .09131 .55324 .09908 .56421 .09488 .55842 .08706 Metetra
0 .023 .122 r
.55842 .08706 .56421 .09488 .57522 .09066 .56946 .08283 Metetra
0 .023 .122 r
.56946 .08283 .57522 .09066 .58628 .08642 .58055 .07856 Metetra
0 .023 .122 r
.58055 .07856 .58628 .08642 .59738 .08216 .59168 .07428 Metetra
0 .024 .122 r
.59168 .07428 .59738 .08216 .60852 .07792 .60285 .06997 Metetra
0 .024 .122 r
.60285 .06997 .60852 .07792 .61971 .07362 .61407 .06564 Metetra
0 .024 .122 r
.61407 .06564 .61971 .07362 .63094 .06932 .62533 .06132 Metetra
0 .024 .122 r
.62533 .06132 .63094 .06932 .64222 .06499 .63664 .05695 Metetra
0 .023 .122 r
.63664 .05695 .64222 .06499 .65354 .06063 .64799 .05257 Metetra
0 .023 .121 r
.64799 .05257 .65354 .06063 .66491 .05627 .65939 .04818 Metetra
0 .023 .121 r
.65939 .04818 .66491 .05627 .67632 .05189 .67084 .04377 Metetra
0 .023 .121 r
.67084 .04377 .67632 .05189 .68778 .0475 .68233 .03934 Metetra
0 .023 .121 r
.68233 .03934 .68778 .0475 .69929 .04309 .69387 .0349 Metetra
0 .023 .121 r
.69387 .0349 .69929 .04309 .71085 .03866 .70546 .03043 Metetra
0 .023 .121 r
.05044 .27347 .05742 .27997 .06655 .27645 .05959 .26993 Metetra
0 .023 .121 r
.05959 .26993 .06655 .27645 .07571 .27292 .06877 .26638 Metetra
0 .023 .121 r
.06877 .26638 .07571 .27292 .08491 .26938 .07798 .26281 Metetra
0 .023 .121 r
.07798 .26281 .08491 .26938 .09414 .26583 .08723 .25923 Metetra
0 .023 .121 r
.08723 .25923 .09414 .26583 .1034 .26227 .09651 .25565 Metetra
0 .023 .121 r
.09651 .25565 .1034 .26227 .11269 .2587 .10583 .25205 Metetra
0 .023 .122 r
.10583 .25205 .11269 .2587 .12203 .25511 .11518 .24844 Metetra
0 .023 .122 r
.11518 .24844 .12203 .25511 .13139 .25151 .12456 .2448 Metetra
0 .023 .122 r
.12456 .2448 .13139 .25151 .14079 .24789 .13398 .24116 Metetra
0 .023 .122 r
.13398 .24116 .14079 .24789 .15023 .24426 .14343 .23751 Metetra
0 .023 .122 r
.14343 .23751 .15023 .24426 .1597 .2406 .15292 .23384 Metetra
0 .023 .122 r
.15292 .23384 .1597 .2406 .1692 .23696 .16245 .23014 Metetra
0 .023 .122 r
.16245 .23014 .1692 .23696 .17874 .23326 .17201 .22646 Metetra
0 .023 .122 r
.17201 .22646 .17874 .23326 .18832 .22959 .1816 .22274 Metetra
0 .023 .122 r
.1816 .22274 .18832 .22959 .19793 .22589 .19124 .219 Metetra
0 .023 .122 r
.19124 .219 .19793 .22589 .20757 .22217 .2009 .21526 Metetra
0 .023 .122 r
.2009 .21526 .20757 .22217 .21726 .21845 .21061 .21151 Metetra
0 .023 .122 r
.21061 .21151 .21726 .21845 .22698 .21469 .22035 .20775 Metetra
0 .023 .122 r
.22035 .20775 .22698 .21469 .23673 .21094 .23012 .20396 Metetra
0 .023 .122 r
.23012 .20396 .23673 .21094 .24652 .20718 .23994 .20017 Metetra
0 .023 .121 r
.23994 .20017 .24652 .20718 .25635 .20337 .24979 .19635 Metetra
0 .023 .121 r
.24979 .19635 .25635 .20337 .26622 .19957 .25968 .19252 Metetra
0 .023 .121 r
.25968 .19252 .26622 .19957 .27612 .19577 .2696 .18869 Metetra
0 .023 .121 r
.2696 .18869 .27612 .19577 .28606 .19193 .27957 .18482 Metetra
0 .023 .121 r
.27957 .18482 .28606 .19193 .29604 .18809 .28957 .18095 Metetra
0 .023 .121 r
.28957 .18095 .29604 .18809 .30606 .18424 .29961 .17708 Metetra
0 .023 .121 r
.29961 .17708 .30606 .18424 .31611 .18037 .30969 .17318 Metetra
0 .023 .122 r
.30969 .17318 .31611 .18037 .32621 .1765 .3198 .16927 Metetra
0 .024 .122 r
.3198 .16927 .32621 .1765 .33633 .17269 .32995 .16538 Metetra
0 .024 .122 r
.32995 .16538 .33633 .17269 .34648 .16924 .34014 .16156 Metetra
0 .025 .123 r
.34014 .16156 .34648 .16924 .3567 .16503 .35035 .15799 Metetra
0 .025 .123 r
.35035 .15799 .3567 .16503 .36695 .16121 .36062 .15407 Metetra
0 .025 .123 r
.36062 .15407 .36695 .16121 .37723 .15729 .37096 .14962 Metetra
0 .024 .122 r
.37096 .14962 .37723 .15729 .38758 .15297 .38132 .14552 Metetra
0 .024 .122 r
.38132 .14552 .38758 .15297 .39795 .14887 .39172 .14145 Metetra
0 .023 .122 r
.39172 .14145 .39795 .14887 .40836 .14485 .40215 .1374 Metetra
0 .023 .121 r
.40215 .1374 .40836 .14485 .41881 .14082 .41262 .13334 Metetra
0 .023 .121 r
.41262 .13334 .41881 .14082 .4293 .13678 .42314 .12928 Metetra
0 .023 .121 r
.42314 .12928 .4293 .13678 .43983 .13273 .43369 .12519 Metetra
0 .023 .121 r
.43369 .12519 .43983 .13273 .4504 .12865 .44429 .1211 Metetra
0 .023 .121 r
.44429 .1211 .4504 .12865 .46101 .12457 .45493 .11698 Metetra
0 .023 .121 r
.45493 .11698 .46101 .12457 .47166 .12048 .46561 .11284 Metetra
0 .023 .121 r
.46561 .11284 .47166 .12048 .48236 .11636 .47633 .10871 Metetra
0 .023 .122 r
.47633 .10871 .48236 .11636 .4931 .11222 .4871 .10454 Metetra
0 .023 .121 r
.4871 .10454 .4931 .11222 .50388 .10807 .49791 .10037 Metetra
0 .023 .122 r
.49791 .10037 .50388 .10807 .5147 .10391 .50876 .09616 Metetra
0 .023 .122 r
.50876 .09616 .5147 .10391 .52557 .09973 .51965 .09194 Metetra
0 .023 .122 r
.51965 .09194 .52557 .09973 .53648 .09553 .53059 .08771 Metetra
0 .023 .122 r
.53059 .08771 .53648 .09553 .54743 .09131 .54157 .08347 Metetra
0 .023 .122 r
.54157 .08347 .54743 .09131 .55842 .08706 .55259 .07921 Metetra
0 .023 .122 r
.55259 .07921 .55842 .08706 .56946 .08283 .56366 .07491 Metetra
0 .023 .122 r
.56366 .07491 .56946 .08283 .58055 .07856 .57478 .07063 Metetra
0 .023 .122 r
.57478 .07063 .58055 .07856 .59168 .07428 .58593 .0663 Metetra
0 .023 .122 r
.58593 .0663 .59168 .07428 .60285 .06997 .59714 .06197 Metetra
0 .023 .121 r
.59714 .06197 .60285 .06997 .61407 .06564 .60838 .05761 Metetra
0 .023 .122 r
.60838 .05761 .61407 .06564 .62533 .06132 .61968 .05326 Metetra
0 .023 .122 r
.61968 .05326 .62533 .06132 .63664 .05695 .63102 .04886 Metetra
0 .023 .121 r
.63102 .04886 .63664 .05695 .64799 .05257 .6424 .04445 Metetra
0 .023 .121 r
.6424 .04445 .64799 .05257 .65939 .04818 .65383 .04003 Metetra
0 .023 .121 r
.65383 .04003 .65939 .04818 .67084 .04377 .66531 .03558 Metetra
0 .023 .121 r
.66531 .03558 .67084 .04377 .68233 .03934 .67684 .03112 Metetra
0 .023 .121 r
.67684 .03112 .68233 .03934 .69387 .0349 .68841 .02664 Metetra
0 .023 .121 r
.68841 .02664 .69387 .0349 .70546 .03043 .70003 .02215 Metetra
0 .023 .121 r
.04341 .26692 .05044 .27347 .05959 .26993 .05258 .26336 Metetra
0 .023 .121 r
.05258 .26336 .05959 .26993 .06877 .26638 .06178 .25978 Metetra
0 .023 .121 r
.06178 .25978 .06877 .26638 .07798 .26281 .07101 .2562 Metetra
0 .023 .121 r
.07101 .2562 .07798 .26281 .08723 .25923 .08028 .25259 Metetra
0 .023 .121 r
.08028 .25259 .08723 .25923 .09651 .25565 .08957 .24898 Metetra
0 .023 .121 r
.08957 .24898 .09651 .25565 .10583 .25205 .09891 .24536 Metetra
0 .023 .121 r
.09891 .24536 .10583 .25205 .11518 .24844 .10828 .24172 Metetra
0 .023 .121 r
.10828 .24172 .11518 .24844 .12456 .2448 .11768 .23806 Metetra
0 .023 .121 r
.11768 .23806 .12456 .2448 .13398 .24116 .12712 .23439 Metetra
0 .023 .121 r
.12712 .23439 .13398 .24116 .14343 .23751 .1366 .23071 Metetra
0 .023 .122 r
.1366 .23071 .14343 .23751 .15292 .23384 .1461 .22702 Metetra
0 .023 .121 r
.1461 .22702 .15292 .23384 .16245 .23014 .15565 .22329 Metetra
0 .023 .121 r
.15565 .22329 .16245 .23014 .17201 .22646 .16523 .21959 Metetra
0 .023 .122 r
.16523 .21959 .17201 .22646 .1816 .22274 .17485 .21583 Metetra
0 .023 .121 r
.17485 .21583 .1816 .22274 .19124 .219 .1845 .21208 Metetra
0 .023 .121 r
.1845 .21208 .19124 .219 .2009 .21526 .19419 .20832 Metetra
0 .023 .121 r
.19419 .20832 .2009 .21526 .21061 .21151 .20391 .20453 Metetra
0 .023 .121 r
.20391 .20453 .21061 .21151 .22035 .20775 .21367 .20075 Metetra
0 .023 .121 r
.21367 .20075 .22035 .20775 .23012 .20396 .22347 .19694 Metetra
0 .023 .121 r
.22347 .19694 .23012 .20396 .23994 .20017 .23331 .19311 Metetra
0 .023 .121 r
.23331 .19311 .23994 .20017 .24979 .19635 .24318 .18928 Metetra
0 .023 .121 r
.24318 .18928 .24979 .19635 .25968 .19252 .25309 .18542 Metetra
0 .023 .121 r
.25309 .18542 .25968 .19252 .2696 .18869 .26304 .18156 Metetra
0 .023 .121 r
.26304 .18156 .2696 .18869 .27957 .18482 .27302 .17767 Metetra
0 .023 .121 r
.27302 .17767 .27957 .18482 .28957 .18095 .28305 .17377 Metetra
0 .023 .121 r
.28305 .17377 .28957 .18095 .29961 .17708 .29311 .16987 Metetra
0 .023 .121 r
.29311 .16987 .29961 .17708 .30969 .17318 .30321 .16594 Metetra
0 .023 .121 r
.30321 .16594 .30969 .17318 .3198 .16927 .31335 .16201 Metetra
0 .024 .122 r
.31335 .16201 .3198 .16927 .32995 .16538 .32353 .15808 Metetra
0 .024 .122 r
.32353 .15808 .32995 .16538 .34014 .16156 .33374 .15416 Metetra
0 .024 .123 r
.33374 .15416 .34014 .16156 .35035 .15799 .34399 .15043 Metetra
0 .025 .123 r
.34399 .15043 .35035 .15799 .36062 .15407 .35428 .14644 Metetra
0 .024 .123 r
.35428 .14644 .36062 .15407 .37096 .14962 .36463 .14219 Metetra
0 .024 .122 r
.36463 .14219 .37096 .14962 .38132 .14552 .37502 .13806 Metetra
0 .024 .122 r
.37502 .13806 .38132 .14552 .39172 .14145 .38544 .13398 Metetra
0 .023 .121 r
.38544 .13398 .39172 .14145 .40215 .1374 .3959 .12991 Metetra
0 .023 .121 r
.3959 .12991 .40215 .1374 .41262 .13334 .4064 .12582 Metetra
0 .023 .121 r
.4064 .12582 .41262 .13334 .42314 .12928 .41694 .12173 Metetra
0 .023 .121 r
.41694 .12173 .42314 .12928 .43369 .12519 .42752 .11761 Metetra
0 .023 .121 r
.42752 .11761 .43369 .12519 .44429 .1211 .43814 .11348 Metetra
0 .023 .121 r
.43814 .11348 .44429 .1211 .45493 .11698 .44881 .10934 Metetra
0 .023 .121 r
.44881 .10934 .45493 .11698 .46561 .11284 .45951 .10517 Metetra
0 .023 .121 r
.45951 .10517 .46561 .11284 .47633 .10871 .47026 .101 Metetra
0 .023 .121 r
.47026 .101 .47633 .10871 .4871 .10454 .48106 .09681 Metetra
0 .023 .121 r
.48106 .09681 .4871 .10454 .49791 .10037 .49189 .0926 Metetra
0 .023 .121 r
.49189 .0926 .49791 .10037 .50876 .09616 .50277 .08836 Metetra
0 .023 .121 r
.50277 .08836 .50876 .09616 .51965 .09194 .51369 .08412 Metetra
0 .023 .121 r
.51369 .08412 .51965 .09194 .53059 .08771 .52466 .07985 Metetra
0 .023 .121 r
.52466 .07985 .53059 .08771 .54157 .08347 .53567 .07557 Metetra
0 .023 .121 r
.53567 .07557 .54157 .08347 .55259 .07921 .54672 .07129 Metetra
0 .023 .121 r
.54672 .07129 .55259 .07921 .56366 .07491 .55782 .06697 Metetra
0 .023 .121 r
.55782 .06697 .56366 .07491 .57478 .07063 .56896 .06264 Metetra
0 .023 .121 r
.56896 .06264 .57478 .07063 .58593 .0663 .58015 .05828 Metetra
0 .023 .121 r
.58015 .05828 .58593 .0663 .59714 .06197 .59138 .05391 Metetra
0 .023 .121 r
.59138 .05391 .59714 .06197 .60838 .05761 .60266 .04953 Metetra
0 .023 .121 r
.60266 .04953 .60838 .05761 .61968 .05326 .61399 .04514 Metetra
0 .023 .121 r
.61399 .04514 .61968 .05326 .63102 .04886 .62536 .04071 Metetra
0 .023 .121 r
.62536 .04071 .63102 .04886 .6424 .04445 .63677 .03627 Metetra
0 .023 .121 r
.63677 .03627 .6424 .04445 .65383 .04003 .64824 .03181 Metetra
0 .023 .121 r
.64824 .03181 .65383 .04003 .66531 .03558 .65975 .02734 Metetra
0 .023 .121 r
.65975 .02734 .66531 .03558 .67684 .03112 .6713 .02284 Metetra
0 .023 .121 r
.6713 .02284 .67684 .03112 .68841 .02664 .68291 .01833 Metetra
0 .023 .121 r
.68291 .01833 .68841 .02664 .70003 .02215 .69456 .0138 Metetra
0 .023 .121 r
.03634 .26034 .04341 .26692 .05258 .26336 .04552 .25675 Metetra
0 .023 .121 r
.04552 .25675 .05258 .26336 .06178 .25978 .05474 .25315 Metetra
0 .023 .121 r
.05474 .25315 .06178 .25978 .07101 .2562 .06399 .24953 Metetra
0 .023 .121 r
.06399 .24953 .07101 .2562 .08028 .25259 .07327 .24591 Metetra
0 .023 .121 r
.07327 .24591 .08028 .25259 .08957 .24898 .08259 .24228 Metetra
0 .023 .121 r
.08259 .24228 .08957 .24898 .09891 .24536 .09194 .23863 Metetra
0 .023 .122 r
.09194 .23863 .09891 .24536 .10828 .24172 .10133 .23497 Metetra
0 .023 .122 r
.10133 .23497 .10828 .24172 .11768 .23806 .11076 .23128 Metetra
0 .023 .121 r
.11076 .23128 .11768 .23806 .12712 .23439 .12022 .22758 Metetra
0 .023 .121 r
.12022 .22758 .12712 .23439 .1366 .23071 .12971 .22388 Metetra
0 .023 .121 r
.12971 .22388 .1366 .23071 .1461 .22702 .13924 .22016 Metetra
0 .023 .121 r
.13924 .22016 .1461 .22702 .15565 .22329 .1488 .21641 Metetra
0 .023 .121 r
.1488 .21641 .15565 .22329 .16523 .21959 .1584 .21269 Metetra
0 .023 .122 r
.1584 .21269 .16523 .21959 .17485 .21583 .16804 .2089 Metetra
0 .023 .121 r
.16804 .2089 .17485 .21583 .1845 .21208 .17771 .20512 Metetra
0 .023 .121 r
.17771 .20512 .1845 .21208 .19419 .20832 .18742 .20133 Metetra
0 .023 .121 r
.18742 .20133 .19419 .20832 .20391 .20453 .19717 .19752 Metetra
0 .023 .121 r
.19717 .19752 .20391 .20453 .21367 .20075 .20695 .19371 Metetra
0 .023 .121 r
.20695 .19371 .21367 .20075 .22347 .19694 .21677 .18988 Metetra
0 .023 .121 r
.21677 .18988 .22347 .19694 .23331 .19311 .22663 .18602 Metetra
0 .023 .121 r
.22663 .18602 .23331 .19311 .24318 .18928 .23652 .18214 Metetra
0 .023 .121 r
.23652 .18214 .24318 .18928 .25309 .18542 .24646 .17826 Metetra
0 .023 .121 r
.24646 .17826 .25309 .18542 .26304 .18156 .25643 .17437 Metetra
0 .023 .121 r
.25643 .17437 .26304 .18156 .27302 .17767 .26643 .17047 Metetra
0 .023 .121 r
.26643 .17047 .27302 .17767 .28305 .17377 .27648 .16654 Metetra
0 .023 .121 r
.27648 .16654 .28305 .17377 .29311 .16987 .28657 .1626 Metetra
0 .023 .121 r
.28657 .1626 .29311 .16987 .30321 .16594 .29669 .15864 Metetra
0 .023 .121 r
.29669 .15864 .30321 .16594 .31335 .16201 .30686 .15468 Metetra
0 .023 .122 r
.30686 .15468 .31335 .16201 .32353 .15808 .31706 .15072 Metetra
0 .024 .122 r
.31706 .15072 .32353 .15808 .33374 .15416 .32729 .14679 Metetra
0 .024 .122 r
.32729 .14679 .33374 .15416 .34399 .15043 .33756 .14301 Metetra
0 .025 .123 r
.33756 .14301 .34399 .15043 .35428 .14644 .34787 .13922 Metetra
0 .024 .123 r
.34787 .13922 .35428 .14644 .36463 .14219 .35826 .13475 Metetra
0 .024 .122 r
.35826 .13475 .36463 .14219 .37502 .13806 .36867 .13057 Metetra
0 .024 .122 r
.36867 .13057 .37502 .13806 .38544 .13398 .37911 .12646 Metetra
0 .023 .121 r
.37911 .12646 .38544 .13398 .3959 .12991 .3896 .12236 Metetra
0 .023 .121 r
.3896 .12236 .3959 .12991 .4064 .12582 .40012 .11824 Metetra
0 .023 .121 r
.40012 .11824 .4064 .12582 .41694 .12173 .41069 .11412 Metetra
0 .023 .121 r
.41069 .11412 .41694 .12173 .42752 .11761 .4213 .10997 Metetra
0 .023 .121 r
.4213 .10997 .42752 .11761 .43814 .11348 .43195 .10582 Metetra
0 .023 .121 r
.43195 .10582 .43814 .11348 .44881 .10934 .44264 .10164 Metetra
0 .023 .121 r
.44264 .10164 .44881 .10934 .45951 .10517 .45337 .09745 Metetra
0 .023 .121 r
.45337 .09745 .45951 .10517 .47026 .101 .46415 .09325 Metetra
0 .023 .121 r
.46415 .09325 .47026 .101 .48106 .09681 .47497 .08902 Metetra
0 .023 .121 r
.47497 .08902 .48106 .09681 .49189 .0926 .48583 .08478 Metetra
0 .023 .121 r
.48583 .08478 .49189 .0926 .50277 .08836 .49674 .0805 Metetra
0 .023 .121 r
.49674 .0805 .50277 .08836 .51369 .08412 .50769 .07624 Metetra
0 .023 .121 r
.50769 .07624 .51369 .08412 .52466 .07985 .51868 .07194 Metetra
0 .023 .121 r
.51868 .07194 .52466 .07985 .53567 .07557 .52972 .06762 Metetra
0 .023 .121 r
.52972 .06762 .53567 .07557 .54672 .07129 .5408 .06332 Metetra
0 .023 .122 r
.5408 .06332 .54672 .07129 .55782 .06697 .55193 .05896 Metetra
0 .023 .122 r
.55193 .05896 .55782 .06697 .56896 .06264 .5631 .05461 Metetra
0 .023 .121 r
.5631 .05461 .56896 .06264 .58015 .05828 .57432 .05021 Metetra
0 .023 .121 r
.57432 .05021 .58015 .05828 .59138 .05391 .58559 .0458 Metetra
0 .023 .121 r
.58559 .0458 .59138 .05391 .60266 .04953 .59689 .0414 Metetra
0 .023 .121 r
.59689 .0414 .60266 .04953 .61399 .04514 .60825 .03697 Metetra
0 .023 .121 r
.60825 .03697 .61399 .04514 .62536 .04071 .61965 .0325 Metetra
0 .023 .121 r
.61965 .0325 .62536 .04071 .63677 .03627 .6311 .02803 Metetra
0 .023 .121 r
.6311 .02803 .63677 .03627 .64824 .03181 .64259 .02354 Metetra
0 .023 .121 r
.64259 .02354 .64824 .03181 .65975 .02734 .65414 .01903 Metetra
0 .023 .121 r
.65414 .01903 .65975 .02734 .6713 .02284 .66573 .0145 Metetra
0 .023 .121 r
.66573 .0145 .6713 .02284 .68291 .01833 .67736 .00995 Metetra
0 .023 .121 r
.67736 .00995 .68291 .01833 .69456 .0138 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13976 .21496 m
.1444 .2196 L
s
[(-100)] .13049 .20567 .99802 1 Mshowa
.34434 .13486 m
.34862 .13983 L
s
[(0)] .33577 .12491 .86142 1 Mshowa
.56596 .04808 m
.56981 .05339 L
s
[(100)] .55826 .03745 .72482 1 Mshowa
.125 Mabswid
.17941 .19944 m
.18215 .20226 L
s
.21968 .18367 m
.22238 .18653 L
s
.26058 .16765 m
.26323 .17056 L
s
.30212 .15139 m
.30474 .15433 L
s
.38723 .11806 m
.38975 .12108 L
s
.43082 .10099 m
.4333 .10405 L
s
.47513 .08364 m
.47755 .08675 L
s
.52017 .06601 m
.52254 .06915 L
s
.10072 .23025 m
.10354 .233 L
s
.06227 .2453 m
.06513 .24802 L
s
.61252 .02984 m
.61477 .03307 L
s
.65987 .0113 m
.66206 .01458 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00b?ooool2o`0005Kooooo0035ooooo`Go0000E_oo
ool009Sooooo0ol00004ooooo`;o00001?ooool2o`0001cooooo1Ol000000ol01Ako0000o`00001E
ooooo`00VOooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00006?ooool5o`0000;o00DN00?o0000o`057_l000000_l0001Dooooo`00VOooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
5Oooool3o`000004ooooool0003o00DNo`0000?o00DN0ol000000ol01Ako0000ooooo`1Cooooo`00
VOooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00004oooool2o`0000;ooooo0_l00003o`057P04o`000?l01Ako0000o`057P;o000000?o00DN
o`000?l00000Doooool009Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`00013ooooo0ol000001?oooooo0000o`000?l00002o`057P03o`00
0?l01Ako00DN00;o00000ol01Ah2o`000003o`057_l0003o000005;ooooo002Hooooo`;o00001?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo0_l000001?oooooo
0000o`000?l00002o`057P03o`000?l01Ako00DN00?o000000Co00DNo`000?l01Ako00DN0_l00003
o`057P03o`000?oooooooooo053ooooo002Iooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`;o00003?ooool6o`0000;o00DN00?o0000o`057_l01Ah00ol000001?l01Ako0000o`057_l01Ah3
o`000003o`057_l0003o000000;o00DN0_l0001Aooooo`00/Oooool5o`0000;o00DN00?o0000o`05
7_l01Ah00ol000001?l01Ako0000o`057_l01Ah3o`0000;o00DN00?o0000o`057_l01Ah00ol00000
0ol01Ako0000o`00001@ooooo`00[_ooool3o`000004ooooool0003o00DNo`0000?o00DN0ol00000
1?l01Ako0000o`057_l01Ah3o`0000;o00DN00?o0000o`057_l01Ah01Ol00002o`057P;o0000D?oo
ool00:_ooooo0ol00002ooooo`;o00000ol01Ah01Ol0003o00DNo`000?l01Ako000000;o00DN0ol0
0002o`057P03o`000?l01Ako00DN00?o000000?o00DNo`000?l01Ah01?l00002o`057P03o`000?oo
oooooooo04gooooo002Yooooo`;o00000_ooool3o`0000;o00DN00?o0000o`057_l01Ah00_l00003
o`057P;o000000?o00DNo`000?l01Ah00_l01Ah3o`000004o`057_l0003o00DNo`057P?o00000_l0
1Ah00ol0003o00DNo`057P02o`0004kooooo002Vooooo`Oo00000_l01Ah00ol0003o00DNo`057P03
o`000004o`057_l0003o00DNo`057P;o00000ol01Ah01Ol0003o00DNo`000?l01Ako000000;o00DN
0ol00002o`057P03o`000?l01Ako00DN00?o000000?o00DNo`000?ooool0COooool00:Cooooo0_l0
00000ooooooo0000o`000002o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako
00DN0ol00002o`057`03o`000?l01Ako00DN00;o00000ol01Ah2o`000003o`057_l0003o00DN00;o
00DN0ol000001?l01Ako0000o`057_l01Ah2o`0004gooooo002Qooooo`Ko00000_l01Al00ol0003o
00DNo`057P03o`000004o`057_l0003o00DNo`057P?o00000_l01Al00ol0003o00DOo`057`03o`00
0004o`057ol0003o00DNo`057P;o00000ol01Ah00ol0003o00DNo`000002o`0000;o00DN0ol00000
0ol01Ako0000o`00001<ooooo`00Woooool5o`0000;o00DO00?o0000o`057ol01Al00ol000001?l0
1Ako0000o`057_l01Ah3o`0000;o00DN00?o0000o`057ol01Al00ol000001?l01Qoo0000o`057ol0
1Al3o`0000;o00DO00?o0000o`057_l01Ah00_l000000ol01Ako0000o`000002o`000004o`057_l0
003o00DNo`057P;o0000C?ooool009cooooo0ol000001?oooooo0000o`057_l00003o`057`?o0000
00Co00DNo`000?l01Ako00DN0ol00002o`057`03o`000?l01Ako00DN00?o000000Co00HOo`000?l0
1Qoo00HO0ol00002o`067`03o`000?l01Aoo00DO00?o000000Ko00DOo`000?l01Ako0000o`057ol0
0002o`057P?o00000_l01Ah00ol0003oooooooooo`0<ooooo`?o00001?ooool2o`0000Cooooo0_l0
000^ooooo`00V_ooool2o`000004ooooool0003o0000o`0000?o00DN00Go0000o`057ol0003o00DN
o`000002o`057P?o00000_l01Al00ol0003o00DOo`057`03o`000004o`067ol0003o00HOo`067`?o
00000_l01Ql00ol0003o00HOo`067`03o`000004o`067ol0003o00DOo`057`?o00000_l01Al2o`00
0003o`057_l0003o00DN00;o00DN0_l0000>ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000]ooooo`00Uoooool3o`000004ooooool0003o
0000o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P?o00000_l01Al00ol0003o00DOo`05
7`03o`000004o`067ol0003o00HOo`067`?o00000_l01Ql00ol0003o00HOo`067`03o`000004o`06
7ol0003o00HOo`067`?o000000Co00HOo`000?l0003o00DO0_l00003o`057P05o`000?l01Ako0000
o`057_l000001_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0002gooooo002Dooooo`?o000000Coooooo`000?l0003o0000
0_l01Ah00ol0003o00DNo`057P03o`000006o`057_l0003o00DNo`000?l01Aoo00000ol01Al3o`00
0004o`057ol0003o00HOo`067`?o00000_l01Ql00ol0003o00HOo`067`03o`000004o`067ol0003o
00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol00002o`057`03o`000?l01Ako00DN00;o0000
0ol01Ah00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000]ooooo`00T_ooool2o`0000;ooooo0_l00002o`057P03
o`000?l01Ako00DN00?o000000Co00DNo`000?l01Ako00DN0_l00003o`057`05o`000?l01Aoo0000
o`057ol000000_l01Al3o`0000;o00DO00?o0000o`067ol01Ql00ol000001?l01Aoo0000o`067ol0
1Ql3o`000004o`067ol0003o00HOo`067`?o000000?o00HOo`000?l000000_l01Al3o`000004o`05
7_l0003o00DNo`057P?o00003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000;Oooool008oooooo0ol000001_oooooo0000o`000?l0003o
00DNo`0000;o00DN0ol00002o`057P03o`000?l01Ako000000;o00000_l01Al00ol0003o00DOo`05
7`02o`0000?o00DO0_l00002o`057`03o`000?l01Aoo00DO00?o000000Co00DOo`000?l01Aoo00DO
0ol000001?l01Qoo0000o`067ol01Ql3o`0000;o00HO00?o0000o`067ol000000ol000001?l01Ako
0000o`057_l01Ah3o`0000;o00DN00?o0000ooooooooool02Oooool2o`0000Cooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000]ooooo`00SOooool2o`000006ooooool0003o
0000o`000?l01Ako00000_l01Ah3o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057`03o`00
0?l01Aoo00DO00?o000000Co00DOo`000?l01Aoo00DO0_l00003o`057`?o000000Co00DOo`000?l0
1Aoo00DO0ol000001?l01Aoo0000o`067ol01Ql3o`0000;o00DO00?o0000o`067ol01Ql00ol00000
1?l01Qoo0000o`057_l01Ah3o`0000;o00DN00?o0000o`057_l01Ah00ol0000:ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`;o0000;_ooool008[ooooo1_l000001?l01Ako0000o`057_l0
1Ah3o`0000;o00DN00?o0000o`057_l01Ah00ol000001?l01Aoo0000o`057ol01Al3o`000004o`05
7ol0003o00DOo`057`?o00000_l01Al01Ol0003o00DOo`000?l01Aoo000000;o00DO0ol00002o`05
7`03o`000?l01Aoo000000;o00000_l01Al00ol0003o00DOo`057`03o`000004o`067ol0003o0000
o`067`?o00000_l01Al00ol0003o00DNo`057P03o`000003o`057_l0003o000004Kooooo001Xoooo
o`;o00007_ooool5o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako00DN
00?o000000Co00DOo`000?l01Aoo00DO0ol00002o`057`03o`000?l01Aoo000000;o00000_l01Al0
0ol0003o00DOo`057`02o`0000?o00DO0_l00002o`057`03o`000?l01Aoo00DO00;o00000_l01Ah0
0ol0003o00DOo`057`03o`000004o`057ol0003o00HOo`067`?o00000_l01Ql00ol0003o00DOo`05
7`03o`000004o`057_l0003o00DNo`057P;o0000A_ooool006Oooooo00Co0000oooooooooooo0000
6_ooool3o`000005ooooool0003o00DNo`057_l000000_l01Ah2o`0000;o00DN00?o0000o`057_l0
1Ah00ol000001?l01Aoo0000o`057ol01Al3o`0000;o00DO00?o0000o`057ol01Al00_l00002o`05
7`03o`000?l01Aoo00DO00?o000000Co00DNo`000?l01Aoo00DO0_l00003o`057`?o000000Co00DO
o`000?l01Ako00DN0ol000001?l01Aoo0000o`057ol01Al3o`0000;o00HO00?o0000o`067ol01Ql0
0ol000001?l01Aoo0000o`057_l01Ah3o`000003o`057_l0003o000004Gooooo001Wooooo`04o`00
0?ooooooooooo`0001Oooooo0ol000001?oooooo0000o`000?l00003o`057P?o000000Co00DNo`00
0?l01Ako00DN0ol000001?l01Ako0000o`057ol01Al3o`0000;o00DO00?o0000o`057ol01Al00ol0
00001?l01Ako0000o`057ol01Al3o`000004o`057ol0003o00DNo`057P?o00000_l01Al01Ol0003o
00DOo`000?l01Aoo000000;o00DO0ol000001?l01Ako0000o`057ol01Al3o`0000;o00DO00?o0000
o`067ol01Ql00ol000001?l01Qoo0000o`057ol01Al3o`000004o`057_l0003o00DNo`057P?o0000
A?ooool006Oooooo00Co0000oooooooooooo00005Oooool2o`0000;ooooo0ol00002o`057P05o`00
0?l01Ako0000o`057_l000000_l01Ah3o`0000;o00DO00?o0000o`057_l000000_l00002o`057`03
o`000?l01Aoo00DO00?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Aoo0000o`057ol01Al3
o`0000;o00DO00?o0000o`057ol01Al00_l00003o`057`;o000000Co00DOo`000?l01Ako00DN0ol0
0002o`057`03o`000?l01Aoo00DO00Go00000_l01Ql3o`000004o`057ol0003o00DNo`057P?o0000
0_l01Ah00ol0003oooooooooo`12ooooo`00Ioooool01?l0003oooooooooool0000Booooo`?o0000
0_ooool2o`0000;o00DN00?o0000o`057_l01Ah00_l00003o`057P;o00000_l01Ah00ol0003o00DO
o`057`02o`0000;o00DO00?o0000o`057ol01Al00ol000001?l01Ako0000o`057_l01Ah3o`0000;o
00DN00?o0000o`057ol000000_l00002o`057P03o`000?l01Aoo00DO00?o000000Co00DNo`000?l0
1Aoo00DO0_l00003o`057`;o00000_l01Al00ol0003o00DOo`057`03o`000003o`057ol0003o00DO
00Co000000Co00HOo`000?l01Aoo00DO0ol00002o`057P03o`000?l01Ako00DN00;o0000@oooool0
06Oooooo00Co0000oooooooooooo00004?ooool2o`0000;ooooo0ol000001?l01Ako0000o`057_l0
1Ah3o`000004o`057_l0003o00DNo`057P;o00000ol01Ah3o`000004o`057ol0003o00DOo`057`?o
000000Co00DOo`000?l01Ako00DN0ol00002o`057P03o`000?l01Ako00DN00;o00000_l01Ah00ol0
003o00DNo`057P03o`000004o`057_l0003o00DNo`057P?o00000_l01Al01Ol0003o00DOo`000?l0
1Aoo000000;o00DO0ol000001?l01Aoo0000o`057ol01Al3o`000004o`057ol0003o00HOo`067`?o
00000_l01Al00ol0003o00DNo`057P03o`000003o`057_l0003o000004;ooooo001Xooooo`;o0000
3_ooool3o`000006ooooool0003o0000o`000?l01Ako00000_l01Ah3o`0000;o00DN00?o0000o`05
7_l000000_l00002o`057P05o`000?l01Ako0000o`057ol000000_l01Al3o`0000;o00DO00?o0000
o`057ol000000_l00002o`057P03o`000?l01Ako00DN00?o000000Co00DNo`000?l01Ako00DN0ol0
00001?l01Ako0000o`057_l01Ah3o`0000;o00DN00?o0000o`057ol01Al00_l00002o`057`?o0000
00Co00DNo`000?l01Aoo00DO0ol000001?l01Aoo0000o`000?l01Al3o`0000;o00HO00?o0000o`05
7ol01Al00ol000001?l01Ako0000o`057_l01Ah2o`0004;ooooo001fooooo`;o000000Coooooo`00
0?l0003o00000_l01Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l01Ah00_l00002
o`057P03o`000?l01Ako00DN00;o00000ol01Al2o`0000;o00DN00?o0000o`057ol01Al00_l00002
o`057`03o`000?l01Ako00DN00?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`05
7_l01Ah3o`0000;o00DO00?o0000o`057_l01Ah00ol000001_l01Ako0000o`057ol0003o00DNo`00
00;o00DN0ol00002o`057`03o`000?l01Aoo000000;o00000_l01Al00ol0003o00HOo`067`03o`00
0004o`057ol0003o00DNo`057P?o000000?o00DNo`000?l00000@Oooool007?ooooo1_l00002o`05
7P03o`000?l01Ako00DN00;o00000_l01Ah00ol0003o00DNo`057P03o`000004o`057_l0003o00DN
o`057P?o00000_l01Al01Ol0003o00DOo`000?l01Ako000000;o00DN0ol000001?l01Ako0000o`05
7ol01Al3o`000004o`057_l0003o00DNo`057P?o00000_l01Ah00ol0003o00DNo`000002o`0000;o
00DN00?o0000o`057ol01Al00ol000001?l01Aoo0000o`057_l01Ah2o`0000;o00DN0ol00002o`05
7P03o`000?l01Aoo00DO00;o000000?o00DOo`000?l000000_l01Al3o`000004o`057ol0003o00DO
o`057`?o000000Co00DNo`000?l01Ako00DN0ol00010ooooo`00L?ooool3o`000003ooooool0003o
000000;o00HO00?o0000o`057_l01Ah00ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0
003o00DNo`057P?o00000_l01Ah00ol0003o00DOo`057`02o`0000;o00DN0ol000001?l01Ako0000
o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o00000_l01Ah00ol0003o00DNo`057P02o`00
00;o00DN00?o0000o`057_l01Ah00ol000001?l01Aoo0000o`057ol01Al3o`000004o`057_l0003o
00DNo`0000;o00DN00?o0000o`057_l01Ah00ol000000ol01Aoo0000o`057`04o`000004o`057_l0
003o00DOo`057`?o000000Co00DOo`000?l01Ako00DN0ol00002o`057P03o`000?oooooooooo03ko
oooo001^ooooo`;o000000Koooooo`000?l0003o0000o`067ol00002o`067`?o00000_l01Ah00ol0
003o00DNo`000002o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako00DN
00?o000000Ko00DOo`000?l01Ako0000o`057_l00002o`057P?o00000_l01Ah00ol0003o00DNo`00
0002o`0000;o00DN00?o0000o`057_l01Ah00ol000001?l01Ako0000o`057_l01Ah3o`000004o`05
7_l0003o00DOo`057`?o000000Co00DOo`000?l01Ako00DN0_l00003o`057P?o000000Co00DNo`00
0?l01Aoo00DO0ol000001?l01Aoo0000o`057_l01Ah3o`000004o`057_l0003o00DOo`057`?o0000
0_l01Al00ol0003o00DNo`057P02o`0003oooooo001[ooooo`Co000000Koooooo`000?l01Qoo00HO
o`000?l01Ql3o`0000;o00HO00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako00DN00;o
00000_l01Ah00ol0003o00DNo`057P03o`000004o`057_l0003o00DOo`057`;o00000ol01Ah2o`00
00;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako00DN00?o000000Co00DNo`00
0?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`0000;o00DN00?o0000o`057ol000000_l0
0002o`057P05o`000?l01Ako0000o`057_l000000_l01Ah3o`000004o`057ol0003o0000o`057`?o
000000Co00DNo`000?l01Ako00DN0ol00002o`057`03o`000?l01Aoo00DO00?o000000?o00DNo`00
0?l00000?_ooool006Wooooo0_l00003ooooo`?o00000_l01Ql2o`0000;o00HO00?o0000o`067ol0
1Ql00ol000001?l01Aoo0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DO
o`000?l01Ako00DN0ol00002o`057P05o`000?l01Ako0000o`057_l000000_l01Ah3o`000004o`05
7_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol00002o`057P03o`000?l01Ako0000
00;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`05
7P?o000000Co00DOo`000?l01Aoo00DO0ol00002o`057P03o`000?l01Ako000000;o00000_l01Ah0
0ol0003o00DOo`057`03o`000004o`057ol0003o00DNo`057P;o0000?_ooool006Kooooo0ol00002
ooooo`?o00000_l01Ql3o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Aoo00DO
0ol00002o`057P03o`000?l01Ako000000;o00000_l01Al00ol0003o00DOo`000002o`0000;o00DN
00?o0000o`057_l01Ah00_l00002o`057P?o000000Co00DNo`000?l01Ako00DN0ol00002o`057P03
o`000?l01Ako000000;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l0
1Ah00ol000001?l01Ako0000o`057_l01Ah3o`000006o`057_l0003o0000o`000?l01Aoo00000_l0
1Al3o`000003o`057ol0003o000000;o00DN0_l00002o`057P03o`000?l01Ako00DN00?o000000Co
00DNo`000?l01Aoo00DO0ol000000ol01Ako0000o`00000mooooo`00I?ooool2o`0000?ooooo0_l0
0002o`067`?o00000_l01Ql00ol0003o00HOo`000002o`0000;o00HO00?o0000o`067ol000000_l0
0002o`067`03o`000?l01Ako00DN00;o00000_l01Ah00ol0003o00DOo`057`02o`0000;o00DO00?o
0000o`057_l01Ah00ol000001?l01Ako0000o`000?l00002o`057P03o`000?l01Ako000000;o0000
0_l01Al00ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l01Ah00ol000001?l01Ako0000
o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00000_l01Ah0
0ol0003o00DOo`000002o`0000;o00DO00?o0000o`057ol000000ol000001?l01Ako0000o`057_l0
1Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol0000looooo`00
HOooool3o`0000;ooooo0ol00002o`067`;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o00HO
00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Qoo00HO00?o000000Co00DNo`000?l01Ako
00DN0ol000001?l01Aoo0000o`057ol01Al3o`000004o`057ol0003o00DNo`0000;o00DN00?o0000
o`057_l01Ah00_l00002o`057P03o`000?l01Aoo00DO00?o000000Co00DNo`000?l01Ako00DN0ol0
00001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l0
1Ako00DN0ol00002o`057P;o00000_l01Ah00ol0003o00DOo`057`03o`000004o`057ol0003o00DN
o`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Aoo0000o`057_l01Ah3o`000004o`05
7ol0003o0000o`0003_ooooo001Nooooo`?o00000_ooool3o`0000;o00DO00Go0000o`067ol0003o
00HOo`000002o`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3
o`000004o`067ol0003o00DNo`057P?o00000_l01Ql00ol0003o00DOo`000002o`0000;o00DO00?o
0000o`057ol000000_l00002o`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000
o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol00002
o`057`03o`000?l01Ako000000;o00000_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co
00DOo`000?l0003o00DO0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DOo`05
7`?o00000_l01Ah00ol0003o00DOo`000002o`0003_ooooo001Looooo`;o00000oooool2o`0000;o
00DN00?o0000o`057ol01Al00_l00002o`067`?o000000Co00HOo`000?l01Qoo00HO0ol00002o`06
7`03o`000?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`000002o`0000;o00DO00?o0000o`06
7ol01Ql00_l00002o`057`03o`000?l01Aoo00DO00;o00000_l01Al3o`000004o`057_l0003o00DN
o`057P?o000000Co00DOo`000?l01Ako00DN0ol00002o`057P03o`000?l01Ako000000;o00000_l0
1Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057ol01Al00_l00002o`057P05o`000?l0
1Ako0000o`057_l000000_l01Ah3o`000004o`057_l0003o00DOo`057`?o000000Co00DOo`000?l0
1Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`0000;o00DO00?o0000o`057_l01Ah00_l00002
o`057P;o0000>_ooool005Wooooo0ol00002ooooo`?o000000Co00DNo`000?l01Ako00DN0ol00000
1?l01Qoo0000o`000?l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`06
7`02o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Aoo00DO00?o000000Co
00HOo`000?l01Aoo00DO0ol000001?l01Aoo0000o`057ol00002o`057`03o`000?l01Ako000000;o
00000_l01Al00ol0003o00DOo`000002o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03
o`000?l01Ako00DN00;o00000_l01Ah00ol0003o00DNo`057P03o`000004o`057ol0003o00DNo`05
7P;o00000_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DOo`000?l0003o00DO0ol0
0002o`057`03o`000?l01Ako000000;o00000_l01Al00ol0003o00DOo`057`03o`000004o`057_l0
003o00DNo`057P;o0000>_ooool005Oooooo0_l00002ooooo`?o00000_l01Ah00ol0003o00DNo`00
0002o`0000;o00DN0_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00HOo`06
7`03o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo
0000o`067ol01Ql3o`000004o`057ol0003o00DOo`057`?o00000_l01Al2o`0000;o00DO00?o0000
o`057ol01Al00_l00002o`057`03o`000?l01Ako00DN00?o000000Co00DNo`000?l01Ako00DN0ol0
00001?l01Ako0000o`057_l01Ah3o`000004o`057ol0003o00DOo`057`?o000000Ko00DNo`000?l0
003o0000o`057_l00002o`057P?o00000_l01Ah00ol0003o00DOo`000002o`0000;o00DO00?o0000
o`057ol01Al00_l00002o`057`03o`000?l01Aoo00DO00?o000000Co00DOo`000?l01Ako00DN0ol0
00000ol01Ako0000o`00000iooooo`00E?ooool3o`0000;ooooo0_l00002o`057P03o`000?l01Ako
00DN00;o00000_l01Ah01Ol0003o00DNo`000?l01Aoo000000;o00HO0ol000001?l01Qoo0000o`06
7ol01Ql3o`000004o`067ol0003o00HOo`067`?o00000_l01Ql00ol0003o00HOo`000002o`0000;o
00HO00?o0000o`067ol000000_l00002o`057`03o`000?l01Aoo000000;o00000_l01Al3o`000004
o`057ol0003o00DOo`057`?o000000Co00DOo`000?l01Aoo00DO0ol000001?l01Ako0000o`057_l0
1Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Aoo00DO0ol000001?l01Ako
0000o`057_l00002o`057P03o`000?l01Ako000000;o00000_l01Ah00ol0003o00DNo`057P02o`00
0003o`057ol0003o000000;o00DO0ol000001?l01Aoo0000o`057ol01Al3o`000004o`067ol0003o
00DOo`057`?o000000Co00DNo`000?l01Ako00DN0ol0000hooooo`009Oooool3o`0000Cooooo0_l0
0004ooooo`;o00007_ooool2o`0000;ooooo0ol000001?l01Ako0000o`057_l01Ah3o`000004o`05
7_l0003o00DNo`057P?o000000Co00DOo`000?l0003o00000_l01Ql00ol0003o00HOo`000002o`00
00;o00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0
003o00HOo`067`02o`0000;o00HO00?o0000o`057ol01Al00_l00002o`067`?o000000Co00DNo`00
0?l01Aoo00DO0ol000001?l01Aoo0000o`057ol01Al3o`000004o`057_l0003o00DNo`057P?o0000
00Co00DNo`000?l01Ako00DN0ol00002o`057P03o`000?l01Ako000000;o00000_l01Ah00ol0003o
00DNo`000002o`0000;o00DN0_l00002o`057P03o`000?l01Ako00DN00?o000000?o00DOo`000?l0
1Al01?l000001?l01Qoo0000o`057ol01Al3o`000004o`057ol0003o00HOo`067`?o000000Co00DO
o`000?l01Ako00DN0ol000000ol01Aoo0000o`00000hooooo`009_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006_ooool3o`000004oooo
ool0003o0000o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako000000;o
00000_l01Ah2o`0000;o00DO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Qoo00HO00;o
00000_l01Ql00ol0003o00HOo`067`03o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`00
0?l01Qoo00HO0ol00002o`067`;o00000_l01Ql00ol0003o00DNo`000002o`0000;o00DO00?o0000
o`057ol000000_l00002o`057P03o`000?l01Ako000000;o00000_l01Al00ol0003o00DNo`000002
o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako00DN00;o00000_l01Ah3
o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Aoo00DO0ol000001?l01Aoo0000
o`067ol01Ql3o`000004o`067ol0003o00DOo`057`?o000000Co00DOo`000?l01Aoo00DO0ol00000
1Ol01Aoo0000o`000?l0003o00DO00;o0000=oooool001kooooo1Ol00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Gooooo`?o0000
0_ooool2o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako00DN00;o0000
0_l01Ah3o`000004o`057ol0003o00DOo`057`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l0
1Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO
0ol00002o`067`05o`000?l01Qoo0000o`067ol000000_l01Ql2o`0000;o00DN00?o0000o`057ol0
1Al00_l00002o`057P03o`000?l01Ako00DN00;o00000_l01Al00ol0003o00DOo`057`02o`0000;o
00DN00?o0000o`057_l01Ah00ol000001?l01Ako0000o`057_l01Ah3o`000006o`057_l0003o0000
o`000?l01Ako00000_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DOo`000?l0003o
00DO0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`057ol0003o00DOo`057`?o000000Co00DO
o`000?l01Aoo00000_l01Al00ol0003o00DOo`000002o`0003Kooooo000Vooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Eooooo`;o0000
0_ooool3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l0
1Ako0000o`000?l00002o`057P03o`000?l01Aoo000000;o00000_l01Ql00ol0003o00HOo`000002
o`0000;o00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql0
0ol0003o00HOo`000002o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`067`?o000000Co00HO
o`000?l01Ako00DN0ol000001?l01Aoo0000o`057_l01Ah3o`000004o`057_l0003o00DOo`057`?o
000000Co00DOo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah3o`000006o`057_l0003o
0000o`000?l01Ako00000_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l0
1Aoo00DO0ol000001?l01Aoo0000o`067ol01Ql3o`000004o`057ol0003o00DOo`057`?o00000_l0
1Al00ol0003o00DOo`000002o`0000;o00DO0_l00002o`057`03o`000?oooooooooo03Cooooo000V
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Booooo`?o000000Coooooo`000?l0003o00000_l01Ah00ol0003o00DNo`000002o`0000;o
00DN00?o0000o`057_l000000_l00002o`057P;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o
00DO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o
00HOo`067`02o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Qoo00HO00?o
000000Ko00HOo`000?l01Qoo0000o`067ol00002o`067`?o000000Co00DOo`000?l01Aoo00DO0ol0
00001?l01Ako0000o`057_l01Ah3o`000004o`057ol0003o00DOo`057`?o000000Co00DNo`000?l0
1Ako00DN0ol000001?l01Ako0000o`000?l00002o`057P03o`000?l01Ako000000;o00000_l01Al0
0ol0003o00DNo`000002o`0000;o00DO00?o0000o`057_l000000_l000001?l01Aoo0000o`000?l0
1Al3o`0000;o00DO00?o0000o`057ol000000_l00002o`057`03o`000?l01Aoo00DO00;o00000_l0
1Al3o`000004o`057ol0003o00DOo`057`;o0000=Oooool002Gooooo0_l00004ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00004?ooool2o`0000;ooooo0_l00002o`057P03
o`000?l01Ako00DN00;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN0ol000001?l01Ako
0000o`057_l01Ah3o`000004o`057ol0003o00DOo`057`?o000000Co00HOo`000?l01Qoo00HO0ol0
00001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l0
1Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o0000o`0000;o00HO00?o
0000o`057ol000000_l00002o`067`03o`000?l01Ako000000;o00000_l01Ah00ol0003o00DOo`00
0002o`0000;o00DN00?o0000o`057_l000000_l00002o`057P;o00000_l01Ah00ol0003o00DNo`05
7P02o`0000;o00DO00?o0000o`057ol01Al00_l00002o`057`03o`000?l01Aoo00DO00;o00000_l0
1Ah00ol0003o00DOo`000002o`0000;o00DN00?o0000o`057ol01Al00_l00002o`057`03o`000?l0
1Aoo00DO00?o000000Ko00HOo`000?l0003o0000o`057ol00002o`057`?o000000?o00DOo`000?l0
0000=?ooool002Kooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0000>ooooo`?o0000
00Coooooo`000?l0003o00000_l01Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l0
00000_l00002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`0000;o00DO00?o0000o`057ol0
00000_l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`000002o`0000;o
00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql00ol0003o
00HOo`000002o`0000;o00HO0_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o
00HOo`067`02o`0000;o00DO00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako00DN00;o
00000_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DNo`000?l01Aoo00DO0ol00000
1?l01Qoo0000o`057ol01Al3o`000004o`057ol0003o00DNo`057P?o000000Co00DNo`000?l01Ako
00DN0ol000001?l01Aoo0000o`057ol01Al3o`000006o`067ol0003o0000o`000?l01Qoo00000_l0
1Al3o`000004o`057ol0003o00DOo`057`;o0000=?ooool0043ooooo0_l000001?oooooo0000o`00
0?l00002o`057P03o`000?l01Ako00DN00;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN
00Go0000o`057_l0003o00DOo`000002o`057P;o00000_l01Al00ol0003o00DOo`057`02o`0000;o
00HO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o
00HOo`067`02o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Qoo00HO00;o
00000_l01Ql3o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol00000
1?l01Qoo0000o`057ol01Al3o`000004o`057_l0003o00DNo`057P?o000000Ko00DNo`000?l01Ako
0000o`057_l00002o`057P?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Aoo0000o`067ol0
1Ql3o`000004o`067ol0003o00DOo`057`?o000000Co00DNo`000?l0003o00DN0ol000001?l01Aoo
0000o`057ol01Al3o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql3o`000004o`057ol0
003o00DOo`057`?o000000?o00DOo`000?l00000<oooool003gooooo0ol000001_oooooo0000o`00
0?l0003o00DNo`0000;o00DN0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057ol0003o00DN
o`057P?o000000Co00DOo`000?l0003o00000_l01Al00ol0003o00DOo`000002o`000004o`067ol0
003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3o`00
0004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001_l01Qoo0000o`00
0?l0003o00HOo`0000;o00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HO
o`067`?o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah2o`0000;o00DN
0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057ol0003o00DOo`057`?o000000Co00HOo`00
0?l01Qoo00HO0ol000001?l01Ako0000o`057_l01Ah3o`000004o`057ol0003o00DOo`057`?o0000
00Ko00HOo`000?l0003o0000o`067ol00002o`067`?o000000Co00DOo`000?l01Aoo00DO0ol00000
1?l01Aoo0000o`057ol01Al3o`0003;ooooo000kooooo`;o000000Coooooo`000?l0003o00000_l0
1Ah00ol0003o00DNo`000002o`0000;o00DN00?o0000o`057_l000000_l00002o`057`03o`000?l0
1Aoo000000;o00000_l01Al2o`0000;o00DO00?o0000o`057ol01Al00_l00002o`067`03o`000?l0
1Qoo000000;o00000_l01Ql00ol0003o00HOo`000002o`0000;o00HO00?o0000o`067ol000000_l0
0002o`067`03o`000?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0
003o0000o`0000;o00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo000000;o0000
0_l01Ql00ol0003o00HOo`000002o`0000;o00HO00?o0000o`057_l000000_l000001?l01Ako0000
o`057_l01Ah3o`000004o`057_l0003o0000o`0000;o00DO00?o0000o`057_l000000_l00002o`05
7`03o`000?l01Aoo000000;o00000_l01Ah00ol0003o00HOo`000002o`000004o`057ol0003o00DN
o`057P?o000000Co00DOo`000?l01Aoo00DO0ol000001_l01Aoo0000o`000?l0003o00HOo`0000;o
00HO0ol000001?l01Qoo0000o`057ol01Al3o`000004o`057ol0003o00DOo`057`?o000000Co00DN
o`000?l0003o0000<Oooool003Sooooo0ol000000ooooooo0000o`000002o`057`03o`000?l01Ako
00DN00;o00000_l01Ah00ol0003o00DNo`057P03o`000004o`057ol0003o00DOo`057`;o00000_l0
1Al3o`000004o`057_l0003o00DOo`057`?o000000Co00DOo`000?l01Qoo00HO0_l00002o`067`03
o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o00HO00?o0000o`067ol0
1Ql00_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql2o`0000;o00HO00?o0000o`067ol0
1Ql00_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o
00HO00?o0000o`067ol01Ql00_l00002o`057P03o`000?l01Ako000000;o00000_l01Ah2o`0000;o
00DO00?o0000o`057ol01Al00_l00002o`057`03o`000?l01Aoo00DO00;o00000_l01Ah00ol0003o
00DNo`057P02o`0000;o00DO00?o0000o`057ol000000_l00002o`057`03o`000?l01Aoo000000;o
00000_l01Al2o`0000;o00DO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo000000;o
00000_l01Ql00ol0003o00DOo`000002o`000004o`057ol0003o00DNo`057P?o0000<Oooool003Go
oooo1ol00002o`057P03o`000?l01Aoo000000;o00000_l01Ah00ol0003o00DNo`000002o`0000;o
00DO1Ol000001?l01Aoo0000o`000?l00002o`057P03o`000?l01Ako000000;o00000_l01Al00ol0
003o00DOo`000002o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql3
o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001_l01Qoo0000
o`000?l0003o00HOo`0000;o00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o
00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000000ol01Qoo0000o`000003o`0000;o00DN
0ol000001?l01Aoo0000o`057ol01Al3o`000004o`057ol0003o00DOo`057`?o000000Co00DNo`00
0?l01Ako00DN0ol000001?l01Ako0000o`057ol01Al2o`0000;o00DO00?o0000o`057ol01Al00ol0
00001_l01Aoo0000o`000?l0003o00DOo`0000;o00DO0_l00002o`067`03o`000?l01Qoo00HO00;o
00000_l01Ql00ol0003o00HOo`067`02o`0000;o00DO00?o0000o`057ol000000_l00002o`057`;o
00002?ooool2o`0002Kooooo000cooooo`;o00000_ooool3o`000004o`057_l0003o00DNo`057P;o
00000_l01Al00ol0003o00DNo`057P02o`0000;o00DO0ol000001?l01Aoo0000o`057ol01Al2o`00
00;o00DO00?o0000o`057_l01Ah00_l00002o`057`03o`000?l01Aoo00DO00;o00000_l01Ql00ol0
003o00HOo`067`02o`0000;o00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo0000
00;o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o0000o`0000;o00HO00?o0000
o`067ol000000_l00002o`067`03o`000?l01Qoo000000;o000000Co00HOo`000?l01Qoo00HO0ol0
00001?l01Qoo0000o`067ol01Ql3o`0000;o00HO0_l000001?l01Qoo0000o`057_l01Ah3o`000004
o`057_l0003o00DOo`057`?o000000Co00HOo`000?l01Aoo00DO0ol000001?l01Ako0000o`057_l0
1Ah3o`000004o`057_l0003o00DNo`057P?o000000Co00DOo`000?l01Aoo00DO0ol000001_l01Qoo
0000o`000?l0003o00DOo`0000;o00DO0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0
003o00HOo`067`?o000000Co00HOo`000?l01Aoo00DO0_l00002o`057`03o`000?l01Aoo00DO00;o
00001oooool01?l0003oooooooooool0000Uooooo`00<?ooool3o`000004ooooool0003o0000o`00
00;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Aoo000000;o000000Co00DOo`00
0?l0003o00000_l01Al00ol0003o00DOo`000002o`0000;o00DO00?o0000o`057ol000000_l00000
1?l01Aoo0000o`057ol01Al3o`000004o`057ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo
00HO0_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o
00HO0_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o
00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql01_l0003o
00HOo`000?l01Qoo0000o`067`?o00000_l01Ah00ol0003o00DNo`000002o`0000;o00HO00?o0000
o`067ol000000_l000001?l01Ako0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o0000
00Co00DOo`000?l01Aoo00DO0ol000001Ol01Qoo0000o`000?l0003o00HO00;o000000Ko00DOo`00
0?l0003o0000o`067ol00002o`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000
o`067ol01Ql3o`000004o`067ol0003o00DOo`057`?o000000?o00HOo`000?l000001_ooool01?l0
003oooooooooool0000Uooooo`00;_ooool2o`0000;ooooo0_l00002o`057P03o`000?l01Ako00DN
00;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DO0_l00002o`057`03o`000?l01Aoo00DO
00;o00000_l01Ah00ol0003o00DOo`057`02o`0000;o00DO00?o0000o`057ol000000_l00002o`05
7`03o`000?l01Aoo000000;o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HO
o`067`?o000000?o00HOo`000?l000001?l000001_l01Qoo0000o`000?l0003o00HOo`0000;o00HO
0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o00000_l01Ql00ol0
003o00HOo`067`02o`0000;o00HO1Ol00002o`067`;o00000_l01Ql00ol0003o00DNo`057P02o`00
00;o00DO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Ako000000;o00000_l01Ah00ol0
003o00DNo`000002o`000004o`057ol0003o00DOo`057`?o000000Ko00HOo`000?l0003o0000o`06
7ol00002o`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3o`00
0004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001_l01Qoo0000o`00
0?l0003o00HOo`0000Kooooo00Co0000oooooooooooo00009Oooool002_ooooo1ol00002o`057P03
o`000?l01Ako000000;o000000Co00DOo`000?l01Ako00DN0ol000001?l01Aoo0000o`000?l00002
o`057`03o`000?l01Aoo000000;o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`05
7ol01Al2o`0000;o00DN00?o0000o`057ol01Al00_l00002o`067`03o`000?l01Qoo00HO00;o0000
0_l01Al5o`0000;o00HO0_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00HO
o`000002o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql3o`000004
o`067ol0003o00HOo`067`?o000000Ko00HOo`000?l01Qoo0000o`067ol00002o`067`?o000000Co
00HOo`000?l01Qoo00HO0ol000001?l01Ako0000o`057ol01Al3o`000004o`067ol0003o00HOo`06
7`;o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DO1Ol00002o`067`;o00000_l01Ql00ol0
003o00HOo`000002o`000004o`067ol0003o0000o`067`?o000000Co00HOo`000?l01Qoo00HO0ol0
00001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`?o000000Ko00HOo`000?l0
003o0000o`067ol00002o`067`;o00001Oooool01?l0003oooooooooool0000Uooooo`00:Oooool2
o`0000;ooooo0_l00002o`057`03o`000?l01Ako00DN00;o00000_l01Ah00ol0003o00DOo`000002
o`0000;o00DO0_l00002o`057`03o`000?l01Aoo00DO00;o00000_l01Al00ol0003o00DNo`000002
o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l01Ako000000;o000000Co00DN
o`000?l01Qoo00HO0ol000001_l01Aoo0000o`000?l0003o00HOo`0000;o00HO0ol000001?l01Qoo
0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o00000_l01Ql00ol0003o00HOo`067`02
o`0000;o00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql0
0ol0003o00HOo`000002o`000004o`067ol0003o0000o`0000;o00HO00?o0000o`067ol000000_l0
00001?l01Qoo0000o`057_l01Ah3o`000004o`057ol0003o00HOo`067`?o000000Co00DOo`000?l0
1Ako00DN0ol000001_l01Aoo0000o`000?l0003o00HOo`0000;o00HO0ol000001?l01Qoo0000o`06
7ol01Ql2o`0000;o00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo000000;o0000
00Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000006o`067ol0003o0000
o`000?l01Qoo00000_l01Ql3o`000003o`067ol0003o000000Cooooo00Co0000oooooooooooo0000
9Oooool002Kooooo0ol000001?oooooo0000o`000?l00002o`057`03o`000?l01Aoo000000;o0000
00Co00DNo`000?l01Ako00DN0ol000001?l01Aoo0000o`000?l00002o`057`03o`000?l01Aoo0000
00;o000000Co00DOo`000?l01Aoo00DO0_l00002o`057P03o`000?l01Ako00DN00;o00000_l01Ah0
0ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l000000_l00002o`067`;o00000_l01Ql0
0ol0003o00HOo`000002o`0000;o00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo
000000;o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO
00?o0000o`067ol01Ql00_l00002o`067`Go00000_l01Ql2o`0000;o00HO00?o0000o`067ol01Ql0
0_l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql00ol0003o00DOo`000002o`000004o`05
7ol0003o00DOo`057`?o000000Ko00DOo`000?l0003o0000o`067ol00002o`067`?o000000Co00HO
o`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o
00000_l01Ql00ol0003o00HOo`000002o`0000;o00HO00?o0000o`067ol000000_l000001_l01Qoo
0000o`000?l0003o00HOo`0000;o00HO0ol000001?l01Qoo0000o`067ol01Ql3o`0000Cooooo0_l0
000Vooooo`008oooool3o`0000;ooooo0_l00002o`057P03o`000?l01Aoo00DO00;o00000_l01Ah5
o`0000;o00DO0_l00002o`057`03o`000?l01Aoo00DO00;o00000_l01Al00ol0003o00DOo`000002
o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah3o`000004o`057ol0
003o00DNo`057P;o00000_l01Al3o`000004o`057ol0003o00HOo`067`;o00000_l01Ql00ol0003o
00HOo`067`02o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`067`03o`000?l01Qoo000000;o
00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HOo`067`?o000000Ko00HOo`00
0?l0003o0000o`067ol00002o`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000
o`067ol01Ql2o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`057`03o`000?l01Aoo000000;o
000000Co00HOo`000?l0003o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HO
o`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`000?l01Ql3o`000004o`06
7ol0003o00HOo`067`;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o00HO0_l00002o`067`03
o`000?l01Qoo000000;o000000Co00HOo`000?l01Qoo00HO0ol000000ol01Qoo0000o`00000/oooo
o`008Oooool7o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`000?l00002o`05
7`03o`000?l01Aoo000000;o00000_l01Al00ol0003o00DOo`000002o`000004o`057ol0003o00DO
o`057`;o00000_l01Al00ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l000000_l00002
o`057`03o`000?l01Aoo000000;o000000Co00DOo`000?l0003o00000_l01Al00ol0003o00DOo`00
0002o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql3o`000004o`06
7ol0003o00HOo`067`;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o00HO00?o0000o`067ol0
00000_l00002o`067`;o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HOo`06
7`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0
003o00DOo`057`;o00000_l01Ql2o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`067`03o`00
0?l01Qoo000000;o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql3o`00
0004o`067ol0003o00HOo`067`?o000000?o00HOo`000?l000001?l000001_l01Qoo0000o`000?l0
003o00HOo`0000;o00HO0_l00002o`067`03o`000?l01Qoo000000;o000000Co00HOo`000?l01Qoo
00HO0ol0000[ooooo`007_ooool3o`0000;ooooo0ol000001?l01Ako0000o`057_l01Ah3o`000003
o`057_l0003o000000;o00DO00?o0000o`057ol01Al00_l00002o`057`03o`000?l01Aoo00DO00;o
00000_l01Al00ol0003o00DOo`000002o`0000;o00DN00?o0000o`057ol000000_l000001?l01Ako
0000o`057_l01Ah3o`000003o`057ol0003o000000?o00000_l01Al2o`0000;o00HO00?o0000o`05
7ol01Al00_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00HOo`000002o`00
0004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000000ol01Qoo0000o`00
0003o`0000;o00HO0ol000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`067ol00000
0_l00002o`068003o`000?l01Qoo000000;o000000Co00HOo`000?l01Qoo00HO0ol000000ol01Qoo
0000o`000004o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql3o`000004o`067ol0003o
00HOo`067`;o00000_l01Ql00ol0003o00HOo`000002o`0000;o00HO00?o0000o`067ol000000_l0
00001?l01Qoo0000o`067ol01Ql3o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql3o`00
0004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l0
1Qoo000000;o000000?o00HOo`000?l00000:oooool001gooooo0_l000001?oooooo0000o`000?l0
0002o`057PGo00000_l01Ah2o`0000;o00DN00?o0000o`057ol000000_l00002o`057`03o`000?l0
1Aoo000000;o000000Co00DOo`000?l01Aoo00DO0_l00002o`057P03o`000?l01Ako00DN00;o0000
0_l01Ah00ol0003o00DNo`000002o`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o0000
0_l01Al00ol0003o00HOo`000002o`000004o`057ol0003o00HOo`067`?o000000Co00HOo`000?l0
1Qoo00HO0_l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql00ol0003o00HOo`000002o`00
0004o`067ol0003o0000o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol0
1Ql3o`000004o`067ol0003o00HOo`067`;o00000_l01Ql00ol0003o00HPo`068002o`0000;o00HO
00?o0000o`067ol000000_l00002o`067`;o00000_l01Ql00ol0003o00HOo`000002o`000004o`06
7ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql2
o`0000;o00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo000000;o000000Ko00HO
o`000?l01Qoo0000o`067ol00002o`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo
0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o00000_l01Ql00ol0003o00HOo`000002
o`0002[ooooo000Mooooo`Co000000Co00DNo`000?l0003o00000_l01Ah00ol0003o00DNo`000002
o`000004o`057_l0003o00DNo`057P;o00000_l01Ql00ol0003o00DOo`057`02o`0000;o00HO00?o
0000o`057ol000000_l00002o`057`03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN
0ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l00002o`057P03o`000?l01Aoo00DO
00;o00000_l01Al00ol0003o00DOo`000002o`0000;o00HO00?o0000o`067ol000000_l000001?l0
1Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`067ol01Ql00_l00002o`067`;o00000_l01Ql0
0ol0003o00HOo`067`02o`0000;o00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo
000000;o000000Co00HOo`000?l01Qoo00HO0ol000001?l01R3o0000o`067ol01Ql2o`0000;o00HO
00Go0000o`067ol0003o00HOo`000002o`067`;o00000_l01Ql00ol0003o00HOo`000002o`000004
o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000000ol01Qoo0000o`067`04
o`000004o`067ol0003o00HOo`067`;o00000_l01Ql5o`000006o`067ol0003o0000o`000?l01Qoo
00000_l01Ql3o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol00000
1?l01Qoo0000o`067ol01Ql2o`0000;o00HO0_l0000Yooooo`007Oooool00ol0003o00DNo`057P02
o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Ako000000;o00000_l01Al0
0ol0003o00HOo`000002o`000004o`067ol0003o00HOo`067`;o00000_l01Al00ol0003o00DOo`05
7`02o`0000;o00DN1Ol00002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`0000;o00DN00?o
0000o`057_l000000_l000001?l01Aoo0000o`057ol01Al2o`0000;o00DO00?o0000o`067ol01Ql0
0_l00002o`067`03o`000?l01Qoo000000;o000000?o00HOo`000?l000001?l000001_l01Qoo0000
o`000?l0003o00HOo`0000;o00HO0ol000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000
o`067ol01Ql00_l00002o`067`03o`000?l01Qoo000000;o000000Co00HPo`000?l01R3o00HP0ol0
00001?l01Qoo0000o`067ol01Ql2o`0000;o00HO0ol000001?l01Qoo0000o`067ol01Ql2o`0000;o
00HO00?o0000o`067ol000000_l00002o`067`03o`000?l01Qoo000000;o000000?o00HOo`000?l0
1Ql01?l000001?l01Qoo0000o`067ol01Ql3o`000006o`067ol0003o0000o`000?l01Qoo00000_l0
1Ql2o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql3o`000004o`06
7ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001_l01Qoo0000o`000?l0003o
00HOo`0002Wooooo000Eooooo`;o00001_ooool3o`0000;o00DN00?o0000o`057_l000000_l00000
1?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057ol01Al00_l00002o`067`03o`000?l0
1Qoo000000;o00000_l01Al00ol0003o00DOo`000002o`000004o`057ol0003o0000o`0000;o00DN
00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN00?o0000o`057_l0
1Ah00_l00002o`057P03o`000?l01Aoo000000;o000000Co00HOo`000?l01Aoo00DO0ol000000ol0
1Qoo0000o`000003o`0000;o00HO0_l00002o`067`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0
003o00HOo`000002o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql3
o`000004o`067ol0003o00HOo`067`;o00000_l01b000ol0003o00HPo`000002o`0000;o00LP1Ol0
0002o`0680;o000000Co00LPo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql2o`0000;o
00HO00?o0000o`067ol01Ql00_l00002o`067`Go000000?o00HOo`000?l000001?l000001_l01Qoo
0000o`000?l0003o00HOo`0000;o00HO0ol000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o
0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`?o
000000Ko00HOo`000?l0003o0000o`067ol00002o`067`;o0000:?ooool001Cooooo00Co0000oooo
oooooooo00001?ooool2o`000004ooooool0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`00
0002o`0000;o00DN00?o0000o`057_l000000_l000001?l01Qoo0000o`067ol01Ql3o`000003o`05
7ol0003o000000?o00000_l01Al2o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057`03o`00
0?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0ol000001?l01Ako0000o`057_l01Ah2o`00
00;o00DO00?o0000o`067ol000000_l00002o`057`;o00000_l01Al00ol0003o00HOo`000002o`00
00;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000
o`067ol01Ql00_l00002o`067`03o`000?l01Qoo000000;o000000Co00HOo`000?l01Qoo00HO0ol0
00001?l01b3o0000o`078?l01b02o`0000;o00LQ00Go0000o`078?l0003o00PQo`000002o`078006
o`000?l01R3o0000o`078Ol0003o00LP0ol000001?l01b3o0000o`067ol01Ql3o`000004o`067ol0
003o00HOo`067`?o000000?o00HOo`000?l000000ol00002o`067`;o00000_l01Ql00ol0003o00HO
o`000002o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000001?l0
1Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`067ol000000_l000000ol01Qoo0000o`000004
o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql3o`000003o`057ol0003o000002Oooooo
000Dooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo0_l00002o`057P04
o`000?l01Ako0000o`0000;o00DN00?o0000o`057_l01Ah00_l00002o`057`03o`000?l01Qoo0000
00;o00000_l01Ql2o`0000;o00DN00?o0000o`057ol000000_l00002o`057`03o`000?l01Ako0000
00;o000000Co00DOo`000?l01Aoo00DO0_l00002o`057P03o`000?l01Ako000000;o00000_l01Ah0
0ol0003o00DNo`000002o`000004o`057_l0003o00DOo`057`?o000000Ko00HOo`000?l0003o0000
o`057ol00002o`057`;o00000_l01Ql00ol0003o00HOo`067`02o`0000;o00HO00?o0000o`067ol0
00000_l000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o00000_l01Ql0
0ol0003o00HOo`000002o`000004o`078?l0003o00LPo`0780?o000000Co00PRo`000?l01b7o00LQ
0_l00003o`088@04o`000?l01b3o0000o`0000;o00LQ0_l00002o`078@03o`000?l01b3o000000;o
000000Co00HPo`000?l01Qoo00HO0ol000000ol01Qoo0000o`000004o`000006o`067ol0003o0000
o`000?l01Qoo00000_l01Ql2o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`06
7ol01Ql3o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0_l00002o`06
7`;o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HOo`067`?o000000Co00DO
o`000?l01Aoo00DO0_l0000Wooooo`005?ooool01?l0003oooooooooool00004ooooo`;o00000ooo
ool00ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l000000_l00002o`057P03o`000?l0
1Aoo000000;o000000Ko00HOo`000?l0003o0000o`057ol00002o`057P;o00000_l01Al00ol0003o
00DOo`057`02o`0000;o00DN00?o0000o`057ol000000_l000001?l01Ako0000o`057_l01Ah2o`00
00;o00DN00?o0000o`057_l01Ah00_l00002o`057PGo00000_l01Ql2o`0000;o00DO00?o0000o`05
7ol000000_l000001?l01Aoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o00000_l0
1Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo
00HO0_l00002o`078003o`000?l01b3o000000;o00000_l022800ol0003o00PRo`000002o`000004
o`098ol0003o00PQo`088@?o000000Ko00PRo`000?l01b7o0000o`098ol00002o`078@;o00000_l0
1b400ol0003o00HPo`000002o`0000;o00HO1Ol000001_l01Qoo0000o`000?l0003o00HOo`0000;o
00HO0ol000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`067ol000000_l000001?l0
1Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`?o000000Ko00HOo`000?l0003o0000
o`067ol00002o`067`;o00000_l01Ql00ol0003o00HOo`000002o`000004o`057ol0003o00DOo`05
7`?o000000?o00DNo`000?l000009_ooool001Cooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`03ooooo`;o000000Co00DNo`000?l01Ako00DN0ol000000ol01Ako0000o`000003
o`0000;o00HO0_l00002o`067`03o`000?l01Aoo000000;o00000_l01Ah00ol0003o00DOo`000002
o`000004o`057ol0003o00DNo`057P;o00000_l01Al00ol0003o00DNo`000002o`0000;o00DN00?o
0000o`057_l000000_l000001_l01Ako0000o`000?l0003o00DNo`0000;o00DO0ol000001?l01Qoo
0000o`057ol01Al2o`0000;o00DN00?o0000o`057ol000000_l00002o`067`03o`000?l01Qoo0000
00;o000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Qoo000000;o00000_l01Ql0
0ol0003o00HOo`000002o`000004o`078Ol0003o00LPo`0780;o00000_l022800ol0003o00PRo`08
8P02o`0000;o00TT00?o0000o`098ol000000_l000001?l02B?o0000o`088_l02282o`0000?o00TS
0_l000001?l02B?o0000o`078Ol01b42o`0000;o00LQ0ol000001?l01b3o0000o`068?l01R02o`00
00;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o
00HOo`067`;o00000_l01Ql00ol0003o00HOo`000002o`000003o`067ol0003o000000Co000000Ko
00HOo`000?l0003o0000o`067ol00002o`067`?o000000Co00HOo`000?l01Qoo00HO0_l000001?l0
1Qoo0000o`057ol01Al3o`000004o`057_l0003o00DNo`057P?o00009Oooool001Cooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?l01Ako000000;o00000_l0
1Ah2o`0000;o00DN00?o0000o`057ol000000_l00002o`067`04o`000?l01Qoo0000o`0000;o00DN
00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Aoo000000;o00000_l01Al00ol0003o00DO
o`000002o`000003o`057_l0003o000000?o00000_l01Ah2o`0000;o00DN00?o0000o`057_l00000
0_l00002o`057`03o`000?l01Qoo000000;o000000Co00DOo`000?l01Ako00DN0_l00002o`057`03
o`000?l01Qoo00HO00;o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HOo`06
7`;o00000_l01Ql5o`0000;o00LP00?o0000o`078Ol000000_l000001?l022;o0000o`088_l02283
o`000004o`0:9?l0003o00TTo`0990;o00000_l02bD00ol0003o00TSo`000002o`000004o`0;9Ol0
003o00TSo`098`;o00000_l02B<3o`000006o`088_l0003o0000o`000?l022;o00000_l01b03o`00
0004o`078?l0003o00HOo`067`;o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o
00HOo`067`?o000000?o00HOo`000?l000000ol00002o`067`;o00000_l01Ql00ol0003o00HOo`00
0002o`000004o`067ol0003o00HOo`067`?o000000Co00HOo`000?l01Qoo00HO0ol000000ol01Qoo
0000o`067`03o`000003o`057_l0003o000000Co000000?o00DNo`000?l000009Oooool001Gooooo
0_l00004ooooo`;o00001oooool2o`000006o`057_l0003o0000o`000?l01Ako00000_l01Ah2o`00
00;o00HO00?o0000o`067ol01Ql00_l00002o`057`03o`000?l01Ako000000;o000000Co00DOo`00
0?l01Ako00DN0ol000000ol01Ako0000o`000003o`0000;o00DO0_l00002o`057P03o`000?l01Ako
000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Aoo00DO00;o00000_l0
1Al00ol0003o00DOo`000002o`000004o`057_l0003o00DOo`057`?o000000?o00HOo`000?l00000
0ol00002o`067`Go000000Ko00HOo`000?l0003o0000o`068?l00002o`078003o`000?l01b3o00LP
00;o00000_l022800ol0003o00PRo`000002o`000003o`0:9?l0003o00XT00;o00XT0_l000001?l0
32Oo0000o`0;9Ol02bD2o`000003o`0<9_l0003o00/U00;o00/U0_l000001Ol02bGo0000o`098ol0
003o00/U00?o000000?o00PRo`000?l022800_l02282o`000004o`088_l0003o00LPo`0780?o0000
00Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Qoo000000;o000000Ko00HOo`000?l0
003o0000o`067ol00002o`067`?o000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l0
1Qoo000000;o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql2o`0000;o
00DN0_l00002o`057P03o`000?l01Ako000000;o000000?o00DNo`000?l000009?ooool001_ooooo
00?o0000ooooooooool02?ooool01Ol0003o00DNo`057_l0003o00DN00?o00000_l01Al00ol0003o
00HOo`000002o`000004o`067ol0003o00DOo`057`;o00000_l01Al00ol0003o00DOo`000002o`00
00;o00DO0_l00002o`057`03o`000?l01Aoo000000;o000000Co00DNo`000?l01Ako00DN0_l00002
o`057`03o`000?l01Ako000000;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0003o
00DOo`057`;o00000_l01Al5o`0000;o00DO0_l00002o`067`03o`000?l01Qoo000000;o000000Co
00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01R3o000000Go000000Co00PRo`000?l022;o
00PR0_l00002o`0:9005o`000?l02RCo00XTo`000?l02R@00_l00003o`0<9`;o000000[o00hXo`00
0?l032Ko00`Vo`000?l02bGo0000o`0=:?l0003o00/U1_l000001Ol022;o0000o`099?l0003o00PR
00;o00000ol02282o`000004o`078?l0003o00HOo`067`?o000000?o00HOo`000?l000000ol00002
o`067`;o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HOo`067`?o000000Co
00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Qoo000000;o000000?o00HOo`000?l00000
1?l000001_l01Aoo0000o`000?l0003o00DNo`0000;o00DN0_l000001?l01Ako0000o`057_l01Ah3
o`0002?ooooo000Kooooo`;o00002_ooool01?l0003o00DNo`000?l00002o`057P03o`000?l01Aoo
00DO00;o00000_l01Al00ol0003o00HOo`000002o`000003o`057ol0003o000000Co000000Ko00DO
o`000?l0003o0000o`057_l00002o`057`;o00000_l01Al00ol0003o00DNo`000002o`0000;o00DO
00Co0000o`057ol0003o00000_l01Ah00ol0003o00DNo`057P02o`0000;o00DN00?o0000o`057_l0
00000_l000001_l01Aoo0000o`000?l0003o00DOo`0000;o00DN0ol000001?l01Aoo0000o`067ol0
1Ql2o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00LQ
00Go0000o`088_l022;o0000o`088P03o`000004o`0;9Ol0003o00XTo`0:90Go000000Co00hXo`00
0?l032Oo00`W0_l00003o`0>:004o`000?l032Ko0000o`0000;o00dX1Ol00002o`0;9@;o00000_l0
2B@2o`0000;o00TS00Ko0000o`088_l0003o00PRo`000?l01b03o`0000;o00HO0_l000001?l01Qoo
0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o000000Co00HOo`000?l01Qoo00HO0ol0
00001?l01Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o000000Ko00HOo`000?l0
003o0000o`067ol00002o`067`?o000000Co00DOo`000?l01Ako00DN0ol000000ol01Ako0000o`05
7P03o`000003o`057_l0003o000002?ooooo000Kooooo`03o`000?oooooooooo00[ooooo00Go0000
o`057ol01Aoo0000o`057P03o`000004o`057ol0003o00DOo`057`?o000000?o00HOo`000?l00000
0_l01Al00ol0003o00DOo`057`02o`0000;o00DN00?o0000o`057_l000000_l000001?l01Aoo0000
o`057ol01Al2o`0000;o00DN00?o0000o`057ol01Al00_l00002o`057`03o`000?l01Ako000000;o
000000?o00DNo`000?l000000ol00002o`057P;o00000_l01Al00ol0003o00DOo`000002o`0000;o
00DO00?o0000o`057ol000000_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`06
7ol000000_l000001?l01b3o0000o`078Ol01b45o`0000;o00XT00?o0000o`0;9Ol02bD00_l00000
1_l03RSo0000o`0>:?l03RSo0000o`0>:0?o00000_l042X00ol0003o00hXo`000002o`000003o`0@
:ol0003o000000?o00000_l03RP3o`000006o`0=9ol0003o00TTo`000?l02bGo00000_l02B<2o`00
00;o00PR0_l00002o`078@06o`000?l01Qoo0000o`068?l0003o00HO0ol000001?l01Qoo0000o`06
7ol01Ql3o`000003o`067ol0003o00HO00?o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo
0000o`067ol01Ql3o`000003o`067ol0003o000000;o00HO00?o0000o`067ol000000_l000001?l0
1Qoo0000o`057ol01Al3o`000004o`057ol0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`00
0002o`0002;ooooo000Kooooo`;o00002oooool00ol0003o00DOo`057`03o`000003o`057_l0003o
000000?o00000_l01Al2o`0000;o00DO00?o0000o`057ol000000_l000001?l01Ako0000o`057_l0
1Ah2o`0000;o00DO00?o0000o`057ol000000_l00002o`057P03o`000?l01Ako000000;o000000?o
00DOo`000?l000000ol00002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0
003o00DOo`057`;o00000_l01Al00ol0003o00DOo`057`02o`0000;o00HO00?o0000o`067ol00000
0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`078?l000000_l000001Ol02B?o
0000o`099?l02BCo000000;o00XT1?l00003o`0>:006o`000?l03RSo0000o`000?l04Rco00000ol0
42X2o`000003o`0C;Ol0003o000000?o00000ol04B/2o`000004o`0A:ol0003o00dWo`0=9`;o0000
0_l02bD3o`000006o`0:9?l0003o0000o`000?l022;o00000_l01b42o`0000;o00HP0_l000001?l0
1Qoo0000o`067ol01Ql3o`000004o`067ol0003o00HOo`067`;o00000_l01Ql00ol0003o00HOo`00
0002o`000003o`067ol0003o000000Co000000Ko00HOo`000?l0003o0000o`067ol00002o`067`;o
00000_l01Ql00ol0003o00HOo`000002o`000004o`057ol0003o00DOo`057`?o000000?o00DNo`00
0?l000000ol000001?l01Ako0000o`000?l0000Qooooo`001oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000Kooooo00?o0000ooooooooool02oooool2o`0000;o00DO0_l00002o`05
7P03o`000?l01Aoo000000;o000000Co00DOo`000?l01Aoo00DO0_l00002o`057`03o`000?l01Ako
000000;o00000_l01Ah00ol0003o00DOo`000002o`000004o`057ol0003o00DNo`057P;o00000_l0
1Ah2o`0000;o00DN00?o0000o`057_l000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN
00?o0000o`057_l000000_l00002o`067`03o`000?l01Aoo000000;o000000Co00HOo`000?l01Qoo
00HO0_l00002o`067`Go000000Co00HOo`000?l01Qoo00HO0_l00002o`078@05o`000?l02B?o00TS
o`000?l02B@00ol000001_l03BSo0000o`0>:?l03RSo0000o`0>:0?o000000So01<]o`000?l04Rco
018/o`000?l042[o0000o`0F;`Co000000?o010[o`000?l000000ol04B/01?l0003o014[o`0A:ol0
4B/2o`00000:o`0?:Ol0003o00/Uo`000?l03BOo0000o`0:9?l0003o00/Uo`0000;o00PR0ol00000
1ol01b7o0000o`000?l0003o00HPo`000?l01Ql00ol000001?l01Qoo0000o`067ol01Ql3o`000003
o`067ol0003o000000?o00000_l01Ql2o`000004o`067ol0003o0000o`067`?o000000Co00HOo`00
0?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql2o`000004o`067ol0003o00DOo`057`?o0000
00Ko00DNo`000?l0003o0000o`057_l00002o`057P;o00000_l01Ah00ol0003oooooooooo`0Ooooo
o`001_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03Oooool2o`000004o`057_l0003o00DNo`057P;o00000_l01Al00ol0003o00DOo`000002
o`0000;o00DO00?o0000o`057ol000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DO1Ol0
00001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l00002o`057P03o`000?l01Ako000000;o
000000Co00DNo`000?l01Ako00DN0_l00002o`057`03o`000?l01Qoo00HO00;o00000_l01Ql00ol0
003o00HOo`000002o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql5o`000004o`078?l0
003o00LQo`078@Go000000?o00`Vo`000?l03BP00_l03BP01_l0003o00hXo`000?l0003o01<]o`00
00?o01<]00?o0000o`0B;?l000001?l00002o`0C;@;o00000_l05Bl01?l0003o014[o`000?l00003
o`0A:`05o`000?l03bWo00lYo`0?:Ol000000ol03BL01?l0003o00/Uo`0;9Ol02bD2o`0000;o00TS
0_l000001?l01b7o0000o`068?l01R02o`0000;o00HO1Ol000001_l01Qoo0000o`000?l0003o00HO
o`0000;o00HO0ol000001?l01Qoo0000o`067ol01Ql2o`000004o`067ol0003o00HOo`067`?o0000
00Co00HOo`000?l01Qoo00HO0ol000000ol01Qoo0000o`000003o`000006o`057ol0003o0000o`00
0?l01Ako00000_l01Ah3o`000004o`057_l0003o00DNo`057P;o00008?ooool000Kooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o
0000o`057_l000000_l00002o`057P04o`000?l01Aoo0000o`0000;o00DO00?o0000o`057ol01Al0
0_l00002o`057PGo000000Ko00DNo`000?l0003o0000o`057_l00002o`057P;o00000_l01Ah00ol0
003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002
o`0000;o00DN00?o0000o`057ol000000_l000000ol01Qoo0000o`000003o`0000;o00HO0_l00002
o`067`03o`000?l01Qoo000000;o000000Co00HOo`000?l01R3o00HP1Ol000001Ol02B?o0000o`0:
9?l02RCo000000;o00`V00?o0000o`0=:?l000000_l000001_l04bgo0000o`0C;Ol04bgo0000o`0C
;@Go00000ol05Rl2o`000004o`0J<_l0003o01D_o`0E;`;o00000_l05Rl05_l0003o014[o`000?l0
52ko0000o`0?:Ol0003o014[o`000?l03BOo0000o`0>:?l0003o00/Uo`000?l02bGo0000o`098ol0
003o00TSo`000?l01b43o`000006o`068?l0003o0000o`000?l01Qoo00000_l01Ql2o`0000;o00HO
00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql3o`000003o`067ol0003o00HO00?o
000000?o00HOo`000?l000001?l000001_l01Qoo0000o`000?l0003o00DOo`0000;o00DO0_l00000
1?l01Aoo0000o`057_l01Ah3o`000004o`057_l0003o00DNo`057P?o000000?o00DNo`000?l00000
7oooool000Kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo013ooooo00Co0000o`057_l01Ako00000_l01Ah2o`0000;o00DO00?o0000o`057ol0
00000_l000001_l01Aoo0000o`000?l0003o00DNo`0000;o00DN0_l00002o`057P03o`000?l01Ako
000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako000000;o00000_l0
1Ah00ol0003o00DNo`000002o`000003o`057_l0003o000000?o00000_l01Ql2o`0000;o00HO00?o
0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`067ol00000
0_l000001_l01b7o0000o`088_l022;o0000o`098`So000000?o018/o`000?l04bd00_l04bd00ol0
003o01<]o`000003o`0000?o01Pa00Co0000o`0F;ol0003o00000ol06S82o`000004o`0L<ol0003o
01H_o`0F;`;o00000_l052h2o`0000;o014[0_l00002o`0>:0;o00000_l02bD2o`0000;o00TS0_l0
00001_l01b7o0000o`068?l0003o00HOo`0000;o00HO0ol000001?l01Qoo0000o`067ol01Ql2o`00
00;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO0_l00002
o`067`03o`000?l01Qoo000000;o000000Co00DOo`000?l01Aoo00DO0ol000000ol01Aoo0000o`05
7`03o`000004o`057ol0003o00DNo`057P?o000000Co00DNo`000?l01Ako00DN0ol0000Nooooo`00
1_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0000Booooo`03
o`000?l01Ako000000;o000000?o00DOo`000?l000000ol00002o`057`;o00000_l01Al00ol0003o
00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`00
00;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`000003o`0000;o00DN0_l00002o`05
7`03o`000?l01Aoo000000;o000000Co00DOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Qoo
000000;o000000Co00HOo`000?l01Qoo00HO0_l00002o`068005o`000?l01b7o00LQo`000?l02280
0_l000001Ol032Ko0000o`0>:?l03RSo000000;o010Z00Go0000o`0B;?l04Rco0000o`0C;@03o`00
0006o`0J<_l0003o01Xbo`0J<_l0003o01Pa0ol000001?l07cKo0000o`0J<_l06S82o`0000?o01`c
0_l000005ol06c?o0000o`0D;_l0003o01L`o`000?l04B_o0000o`0C;Ol0003o00hXo`000?l03bWo
0000o`0;9Ol0003o00`Vo`000?l02B?o0000o`098ol0003o00LQ00?o000000Ko00HOo`000?l0003o
0000o`067ol00002o`067`?o000000Co00HOo`000?l01Qoo00HO0_l000001?l01Qoo0000o`067ol0
1Ql3o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql2o`000004o`057ol0003o00DOo`05
7`?o000000Co00DNo`000?l01Aoo00DO0_l00002o`057`03o`000?l01Aoo000000;o000000?o00DN
o`000?l000001?l000000ol01Ako0000o`00000Nooooo`001_ooool01?l0003oooooooooool00008
ooooo`;o00001_ooool00ol0003oooooooooo`0Booooo`;o000000?o00DNo`000?l000000_l01Ah0
0ol0003o00DOo`000002o`0000;o00DO00Co0000o`057ol0003o00000_l01Al00ol0003o00DNo`00
0002o`0000;o00DN00?o0000o`057_l000000_l000000ol01Ako0000o`000003o`0000;o00DN0_l0
0002o`057`03o`000?l01Aoo000000;o000000Co00DOo`000?l01Aoo00DO0_l00002o`057`03o`00
0?l01Aoo000000;o000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Qoo000000;o
000000Co00HOo`000?l01R3o00HP1Ol000001_l02RCo0000o`0<9_l032Ko0000o`0>:0So000000?o
01Xbo`000?l06S800_l06S801_l0003o01Xbo`000?l0003o02<ho`0000?o01lf0_l000001?l08SSo
0000o`0L<ol073<2o`0000;o01/c0_l00002o`0G<0;o00000_l04bd2o`0000;o00lY0_l00002o`0<
9P;o00000_l02B<2o`0000;o00LQ0_l00002o`067`03o`000?l01Qoo000000;o000000Co00HOo`00
0?l01Qoo00HO0ol000000ol01Qoo0000o`000003o`000006o`067ol0003o0000o`000?l01Qoo0000
0_l01Ql3o`000003o`057_l0003o00DO00?o000000Co00DNo`000?l01Ako00DN0ol000000ol01Ako
0000o`000003o`000006o`057ol0003o0000o`000?l01Aoo00000_l01Ah3o`000003o`057_l0003o
000001gooooo0007ooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`;o00005Oooool01Ol0
003o00DNo`057_l0003o00DN00;o00000_l01Al00ol0003o00DOo`057`02o`0000;o00DO00?o0000
o`057ol000000_l000001?l01Ako0000o`057_l01Ah2o`0000;o00DN0_l00002o`057P03o`000?l0
1Ako000000;o000000Co00DNo`000?l01Aoo00DO0_l00002o`067`03o`000?l01Aoo000000;o0000
00Co00DOo`000?l01Aoo00DO0_l00002o`057`03o`000?l01Qoo000000;o000000?o00HOo`000?l0
00000ol00002o`067`Go000000Ko00LQo`000?l022;o00PRo`000?l02R@5o`000003o`0C;Ol0003o
01H_00Co00000ol06S800ol0003o01Xbo`000002o`000005o`0T>Ol0003o02<ho`0S>?l000000_l0
7cH01?l0003o028ho`0R>?l08SP2o`00000@o`0S>?l0003o01/co`000?l083Oo0000o`0G<?l0003o
01Xbo`000?l04bgo0000o`0E;_l0003o00lYo`0000;o010Z0_l00002o`0;9P;o000000Ko00PRo`00
0?l0003o0000o`078?l00002o`067`;o00000_l01Ql5o`000006o`067ol0003o0000o`000?l01Qoo
00000_l01Ql2o`000004o`067ol0003o00HOo`067`?o000000Co00DNo`000?l01Ako00DN0_l00002
o`057`03o`000?l01Ako000000;o000000Ko00DNo`000?l0003o0000o`057_l00002o`057`;o0000
00Co00DOo`000?l01Aoo00DO0ol000001?l01Ako0000o`057_l01Ah2o`0001gooooo000Jooooo`03
o`000?oooooooooo01Cooooo00?o0000o`057_l01Ah00_l00002o`057P03o`000?l01Aoo000000;o
000000Co00DOo`000?l01Aoo00DO0_l00002o`057PGo000000Ko00DNo`000?l0003o0000o`057_l0
0002o`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`067ol0003o00HOo`067`;o0000
0_l01Al00ol0003o00DOo`000002o`000003o`057_l0003o000000?o00000_l01Ql2o`0000;o00HO
00?o0000o`067ol000000_l000001_l01Qoo0000o`068?l01R3o0000o`078@Go000000Co00dWo`00
0?l042[o010Z1?l00002o`0F;`03o`000?l0637o000000;o01Xb0_l000001Ol093Wo0000o`0T>Ol0
93Wo000000;o02<h00Co0000o`0O=_l0003o00000ol08SP01Ol0003o02<ho`0S>?l08cSo000000?o
020g00Go0000o`0J<_l06S;o01Xbo`000003o`0E;P;o000000Go010Zo`000?l03bWo0000o`0;9P02
o`000004o`088_l0003o00PRo`0000;o00LP0ol000001ol01Qoo0000o`000?l0003o00HOo`000?l0
1Ql00ol000001?l01Qoo0000o`067ol01Ql3o`000003o`067ol0003o00HO00?o000000Co00DOo`00
0?l01Ako00DN0ol000000ol01Qoo0000o`000003o`000006o`057_l0003o0000o`000?l01Ako0000
0_l01Ah3o`000003o`057ol0003o00DO00?o000000Co00DOo`000?l01Ako00DN0ol000000ol01Ako
0000o`00000Looooo`006_ooool00ol0003oooooooooo`0Eooooo`;o000000Co00DNo`000?l01Ako
00DN0_l00002o`057`Go000000Ko00DOo`000?l0003o0000o`057_l00002o`057P;o00000_l01Al0
0ol0003o00DNo`000002o`000004o`057_l0003o00DNo`057P;o00000_l01Al00ol0003o00HOo`00
0002o`000003o`057ol0003o000000?o00000_l01Ah2o`0000;o00DO00?o0000o`057ol000000_l0
00001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`067ol000001?l00002o`088P03o`00
0?l02bGo000000;o00dW1?l000000ol04bgo0000o`0F;`06o`000005o`0U>Ol0003o02@io`0T>Ol0
00000_l093T01?l0003o02<ho`000?l00002o`0Y?004o`000?l08SSo0000o`0000?o02<h00Co0000
o`0P=ol083Oo020g0_l000001_l06S;o0000o`0L<ol0003o01D^o`0000;o01H_00?o0000o`0?:Ol0
3bT00_l000001Ol02bGo0000o`000?l0003o00PR00?o000000Ko00LPo`000?l0003o0000o`068?l0
0002o`067`;o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HOo`067`;o0000
0_l01Ql5o`000006o`057ol0003o0000o`000?l01Qoo00000_l01Al2o`0000;o00DN00?o0000o`05
7_l000000_l000001?l01Aoo0000o`057ol01Al2o`0000;o00DO00?o0000o`057ol000000_l00000
0ol01Ako0000o`000004o`0001_ooooo000Iooooo`;o00006Oooool4o`000004o`057ol0003o0000
o`0000;o00DO00Co0000o`057ol0003o00000_l01Ah00ol0003o00DNo`000002o`000004o`057ol0
003o00DOo`057`?o000000?o00DNo`000?l01Ah00ol000000ol01Aoo0000o`000003o`0000;o00HO
0_l00002o`057`03o`000?l01Ako000000;o000000Co00DOo`000?l01Aoo00DO0_l00002o`067`03
o`000?l01Qoo000000;o000000Co00HOo`000?l01Qoo00HO0_l00002o`068003o`000?l01b7o0000
00;o00PR3?l000001Ol07SGo0000o`0R>?l08SSo000000;o02Di00Go0000o`0T>Ol093Wo0000o`0T
>@03o`000004o`0_?ol0003o02Tlo`0Y?0;o00000_l0;3h01ol0003o02<ho`000?l0:cgo0000o`0P
=ol000000_l093T00ol0003o01`co`0L<`02o`0000;o01H_0_l000000ol03bWo0000o`0?:@02o`00
00;o00XT0_l00002o`088P;o00000_l01b000ol0003o00HPo`000002o`000004o`067ol0003o00HO
o`067`;o00000_l01Ql5o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Al2o`000004o`05
7ol0003o00HOo`067`?o000000Co00DNo`000?l01Ako00DN0_l000001?l01Aoo0000o`057ol01Al3
o`000003o`057ol0003o000000?o000000Ko00DOo`000?l0003o0000o`057_l00002o`057P;o0000
6oooool001Wooooo00?o0000ooooooooool06Oooool01?l0003o00DOo`000?l00002o`057P03o`00
0?l01Aoo00DO00;o00000_l01Al00ol0003o00DNo`000002o`000003o`057_l0003o00DO00?o0000
0_l01Al5o`000003o`057ol0003o000000;o00DO00?o0000o`067ol000000_l000001?l01Aoo0000
o`057ol01Al2o`0000;o00DO00?o0000o`057ol000000_l000001?l01Qoo0000o`067ol01Ql2o`00
00;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`068?l01R07o`0000;o00dW00Go0000
o`0@:_l0003o01@^o`000002o`0I<@06o`000?l07SGo01heo`000?l08SSo00000ol09CT01_l0003o
02@io`000?l0003o0391o`0000?o02lo0_l000001?l0=D?o0000o`0/?_l0;3h2o`0000?o02/m00?o
0000o`0T>Ol093T00_l000001ol073?o0000o`0M=?l0003o01H_o`000?l05Bh00_l000003?l03bWo
0000o`0=9ol0003o00XTo`000?l02B?o0000o`088_l0003o00LQo`0000;o00LP0_l000000ol01Qoo
0000o`000004o`000007o`067ol0003o0000o`000?l01Qoo0000o`067`03o`000004o`067ol0003o
00HOo`067`?o000000?o00DNo`000?l01Al00ol000001?l01Aoo0000o`057_l01Ah3o`000003o`05
7ol0003o000000?o000000Ko00DOo`000?l0003o0000o`057_l00002o`057`;o000000Co00DOo`00
0?l01Ako00DN0ol000000ol01Ako0000o`00000Jooooo`006Oooool2o`0001_ooooo00Go0000o`05
7_l01Ako0000o`057P03o`000004o`057ol0003o00DOo`057`;o00000_l01Ah5o`000006o`057ol0
003o0000o`000?l01Aoo00000_l01Al2o`0000;o00DO00Co0000o`057ol0003o00000_l01Al00ol0
003o00DOo`000002o`000004o`057ol0003o00DOo`057`;o00000_l01Ql00ol0003o00HOo`000002
o`000003o`067ol0003o000000?o00000_l01Ql5o`000003o`078?l0003o000000;o000000?o00XT
o`000?l000001ol00002o`0I<@03o`000?l07SGo000000;o028h00?o0000o`0U>Ol000000_l00000
1Ol0<d;o0000o`0b@Ol0<T7o000000;o02lo00Co0000o`0e@ol0=D?o03E30_l000001?l0=d?o0000
o`0[?Ol0:cd2o`000005o`0T>Ol0003o02Lko`0W>ol000000ol07C@00ol0003o01D^o`000002o`0C
;@;o000000?o00dWo`000?l000000_l02B<2o`0000;o00LQ0ol000000ol01Qoo0000o`000002o`06
7`03o`000?l01Qoo000000;o000000Co00HOo`000?l01Qoo00HO0_l00002o`067`03o`000?l01Qoo
000000;o000000Co00DNo`000?l01Ako00DN0_l00002o`057`Go000000Oo00DNo`000?l0003o0000
o`057ol0003o00DO00?o000000Co00DNo`000?l01Ako00DN0ol000000ol01Aoo0000o`057`03o`00
0004o`057_l0003o00DNo`057P?o00001oooool3o`0000Cooooo0_l00004ooooo`;o00000oooool0
00Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`0J
ooooo`03o`000?l01Ako00DN00?o000000?o00DNo`000?l000000ol000001_l01Aoo0000o`000?l0
003o00DOo`0000;o00DN0_l00002o`057`03o`000?l01Aoo000000;o000000Co00DOo`000?l01Aoo
00DO0_l00002o`057`03o`000?l01Aoo000000;o000000?o00HOo`000?l01Al00ol000000ol01Qoo
0000o`000003o`0000;o00HO0_l00002o`067`03o`000?l01Qoo000000;o000000?o00HOo`000?l0
1Ql02?l000001ol032Ko0000o`0@:_l042[o0000o`0D;_l000000_l06S89o`000005o`0c@Ol0003o
03=2o`0c@_l000000_l0<T401?l0003o02loo`000?l00003o`0e@`04o`000?l0=d?o03M3o`0g@`;o
00000_l0<D401?l0003o02Lko`0W>ol09c/2o`000003o`0M=?l0003o01`d00;o000000?o01<]o`00
0?l04B/00_l000001Ol02bKo0000o`000?l0003o00PR00?o000000Ko00HOo`000?l0003o0000o`06
7ol00002o`067`;o000000Co00HOo`000?l01Qoo00HO0ol000001?l01Qoo0000o`067ol01Ql2o`00
0003o`057ol0003o000000Co000000Oo00DNo`000?l0003o0000o`057ol0003o00DO00?o000000Co
00DOo`000?l01Aoo00DO0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Aoo
00DO0_l00002o`057`03o`000?l01Ako000000;o000000?o00DNo`000?l000002?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
00Gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo01_ooooo0_l00002o`057P;o00000_l01Ah01?l0003o00DOo`000?l00002o`057`03o`00
0?l01Aoo000000;o000000Co00DOo`000?l01Aoo00DO0_l00002o`057P03o`000?l01Aoo000000;o
000000Co00DOo`000?l01Aoo00DO0_l00002o`067`Go000000?o00HOo`000?l000000_l01Ql00ol0
003o00HOo`000002o`000004o`067ol0003o00HOo`067`;o00000_l01Ql5o`000006o`078?l0003o
00LQo`078Ol0003o00TS1?l00002o`0@:P07o`000?l052ko0000o`0J<_l0003o024go`000002o`0W
>`03o`000?l0;Soo000000;o03=100Ko0000o`0c@_l0<d;o03=2o`000?l0<T42o`0000;o03m700Co
0000o`0e@ol0=D?o00000ol0=d<01Ol0003o0351o`0a@Ol0<D7o000000;o02Lk00Ko0000o`0Y??l0
:Cco0000o`0L=?l00002o`0J<P03o`000?l04B_o000000;o00lY00?o0000o`0:9?l02R@00_l00002
o`078@;o000000Co00HOo`000?l01Qoo00HO0ol000000ol01Qoo0000o`067`03o`000003o`067ol0
003o000000Co000000?o00DNo`000?l000000_l01Ah00ol0003o00DNo`000002o`000004o`057_l0
003o00DOo`057`;o000000Co00DNo`000?l01Aoo00DO0ol000001?l01Aoo0000o`057_l01Ah2o`00
0004o`057_l0003o00DNo`057P?o000000?o00DOo`000?l000000ol000001Ol01Ako0000o`000?l0
003o00DN00;o00001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool000Gooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`03ooooo`;o00007oooool2o`000004o`057_l0003o00DNo`057P;o00000_l01Al00ol0
003o00DOo`000002o`000003o`057ol0003o00DO00?o000000?o00DNo`000?l000000ol00002o`05
7`Go000000Ko00HOo`000?l0003o0000o`067ol00002o`067`;o00000_l01Ql01?l0003o00HOo`00
0?l00002o`067`03o`000?l01Qoo000000;o000000?o00HOo`000?l000000ol00002o`068003o`00
0?l01b3o000000Co000000Co00XUo`000?l03RSo00hX2_l00002o`0W>`03o`000?l0;Soo000000;o
03=100?o0000o`0c@_l000000_l000005ol0AD[o0000o`0oAol0?dOo0000o`0e@ol0003o04E:o`00
0?l0=d?o0000o`12B?l0003o0351o`000?l0=T?o0000o`0W>ol0003o02Tlo`000?l0:3co000000;o
01Xb00?o0000o`0H<Ol000000_l03bT2o`000003o`0:9?l0003o00TS00?o000000?o00LPo`000?l0
1Ql00ol000000ol01Qoo0000o`000003o`0000;o00HO0_l000001?l01Ako0000o`057ol01Al3o`00
0004o`057_l0003o00DNo`057P;o000000Co00DOo`000?l01Ako00DN0ol000000ol01Ako0000o`05
7P03o`000004o`057ol0003o00DOo`057`?o000000?o00DNo`000?l000000ol000001_l01Ako0000
o`000?l0003o00DOo`0000;o00DO0_l000001?l01Ako0000o`057_l01Ah3o`0000Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
0005ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?l01Ako000000;o000000Co00DNo`000?l01Aoo00DO0_l00002o`057`Go
000000?o00DOo`000?l000000_l01Al00ol0003o00DNo`000002o`000004o`067ol0003o00DOo`05
7`;o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0003o00HOo`067`;o00000_l01Ql0
1?l0003o00HOo`000?l00002o`067`Go000000Co00HOo`000?l01R3o00HP0_l00002o`078@03o`00
0?l02B?o000000;o00XU00?o0000o`0>:?l000000ol000001?l06C7o0000o`0Q=ol00002o`0Z?0Wo
000000Go04M;o`000?l0AD[o04E:o`000002o`0oA`;o00000ol0ADX01Ol0003o0498o`12B?l0@TSo
000000;o03I30_l000002?l0:Cco0000o`0X??l0:3co0000o`0J<_l0003o01Pa0_l000000ol03bWo
0000o`0=9`02o`000004o`098ol0003o00PRo`0000;o00LP0_l00002o`067`;o000000Co00HOo`00
0?l01Qoo00HO0ol000000ol01Aoo0000o`057P03o`000004o`057ol0003o00DNo`057P?o000000?o
00DNo`000?l01Al00ol000000ol01Ako0000o`000003o`0000;o00DN1Ol000001ol01Aoo0000o`00
0?l0003o00DNo`000?l01Ah00ol000001?l01Ako0000o`057ol01Al3o`000003o`067ol0003o00DN
00?o000000?o00DNo`000?l000001_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool000Gooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000?ooooo0_l0000Qooooo`;o000000?o00DNo`000?l00000
0ol000001_l01Aoo0000o`000?l0003o00DOo`0000;o00DN0_l00002o`057`04o`000?l01Aoo0000
o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o
0000o`067ol000000_l000000ol01Qoo0000o`000003o`000003o`067ol0003o000000?o00000_l0
1Ql5o`000003o`068?l0003o000000So000000Co010Zo`000?l05Roo01H_0ol000001_l08COo0000
o`0Z??l0003o03=1o`0000;o03i700?o0000o`16Bol000000_l0Ad/01?l0003o04E:o`15B_l0ADX2
o`000003o`1ACOl0003o04E:00;o04E:00Oo0000o`12B?l0@TSo0498o`000?l0=T?o000000;o03Y5
00Wo0000o`0X??l0:3co0000o`0V>_l0003o01Pao`000?l05Bh01?l000001Ol02bGo0000o`000?l0
003o00PR00?o000000Oo00HOo`000?l0003o0000o`067ol0003o00HO00?o000000Co00DNo`000?l0
1Aoo00DO0_l00002o`057`03o`000?l01Aoo000000;o000000?o00DNo`000?l000000ol00002o`05
7P;o000000Co00DNo`000?l01Ako00DN0ol000000ol01Ako0000o`057`03o`000004o`057ol0003o
00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000004o`057ol0003o00HOo`067`;o0000
00?o00DOo`000?l000001?l00004ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo0005ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo02;ooooo00Go0000o`057_l01Ako0000o`05
7P02o`0000;o00DO00?o0000o`057ol000000_l000001?l01Ako0000o`057ol01Al2o`0000;o00DO
00?o0000o`067ol000000_l000000ol01Aoo0000o`000003o`000003o`067ol0003o000000?o0000
0_l01Ql2o`0000;o00HO00?o0000o`067ol000001?l000001_l01Qoo0000o`000?l0003o00HOo`00
00;o00HO0_l00002o`078003o`000?l022;o000000;o00TT00?o0000o`0<9_l000000_l042X01?l0
003o01H_o`000?l07SD6o`000004o`0c@Ol0003o03i7o`0000;o04I;00Go0000o`17Bol0Ad_o0000
o`15BP02o`0000;o055=00?o0000o`15B_l0ADX00_l00002o`12B003o`000?l0Bdgo000000;o03Y5
0_l000001?l0:3co0000o`0V>_l09SX4o`000003o`0B;?l0003o00hX00;o00000_l02B<2o`000006
o`078?l0003o0000o`000?l01Qoo00000_l01Ql2o`0000;o00HO00?o0000o`057_l000000_l00000
0ol01Ako0000o`000003o`000006o`057_l0003o0000o`000?l01Ako00000_l01Ah3o`000003o`05
7_l0003o00DN00?o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057ol01Al3o`00
0003o`057_l0003o000000?o000000?o00DNo`000?l000001?l000001Ol01Qoo0000o`000?l01Ako
000000;o00DN0ol00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00000oooool0
00Kooooo0_l00009ooooo`?o00001?ooool00ol0003oooooooooo`0Rooooo`03o`000?l01Ako00DN
00;o00000_l01Ah00ol0003o00DOo`000002o`000003o`057ol0003o00DN00?o000000?o00DOo`00
0?l000000ol00002o`067`;o00000_l01Al01?l0003o00HOo`000?l00002o`067`03o`000?l01Qoo
000000;o000000?o00HOo`000?l01Ql00ol00002o`067`04o`000?l01Qoo0000o`0000;o00HO00?o
0000o`067ol000000_l000001?l01Qoo0000o`078?l01b0?o`0000;o02Lk00?o0000o`0c@Ol00000
0_l00002o`0nA`04o`000?l0AT_o0000o`17B`?o000000?o05I;o`000?l0DDd00_l0DDd2o`0000;o
059=0_l00002o`1;C@03o`000?l0>TGo000000;o03Q40_l000001Ol09S[o0000o`000?l0003o01L`
00;o000000Co00hXo`000?l032Ko00`V0_l000000ol022;o0000o`000002o`067`03o`000?l01Qoo
000000;o000000?o00HOo`000?l000000ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN
0_l00002o`057P03o`000?l01Ako000000;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako
0000o`000?l01Ah3o`000003o`057_l0003o000000?o000000Ko00DOo`000?l0003o0000o`057_l0
0002o`057P;o000000Co00DOo`000?l01Qoo00HO0ol000000ol01Aoo0000o`057P03o`000003o`05
7_l0003o000001Gooooo000Hooooo`;o00009?ooool2o`000004o`057_l0003o00DNo`057P;o0000
0_l01Ah4o`0000;o00DO0_l00002o`057`03o`000?l01Qoo000000;o000000Co00HOo`000?l01Aoo
00DO0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO1Ol000001?l01Qoo0000o`067ol01Ql2
o`000003o`067ol0003o000000?o00000_l01Ql5o`000004o`078?l0003o00PRo`088PSo000000?o
01Pao`000?l08SP01Ol00002o`12B0?o000000Go04I;o`000?l0003o05M:o`000002o`1FB`03o`00
0?l0DDgo055=00;o00000ol0DTd01Ol0003o04]=o`1;COl0003o051>00;o000000?o03Q4o`000?l0
<d801?l000000ol05c3o0000o`0B;003o`000003o`0<9_l0003o00TS00;o000000Co00LPo`000?l0
1Qoo00HO0_l00002o`067`;o000000Co00HOo`000?l01Ako00DN0_l00002o`057P03o`000?l01Ako
000000;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah3o`000003o`05
7_l0003o000000?o000000Ko00DNo`000?l0003o0000o`057_l00002o`057`;o000000Co00DOo`00
0?l01Ako00DN0ol000000ol01Aoo0000o`057`03o`000004o`057ol0003o00DOo`057`;o000000?o
00DNo`000?l000001?l0000Dooooo`006?ooool00ol0003oooooooooo`0Uooooo`Co000000Oo00DN
o`000?l0003o0000o`057_l0003o00DO00?o000000Co00DOo`000?l01Aoo00DO0_l00002o`067`03
o`000?l01Qoo000000;o000000?o00HOo`000?l01Ql00ol000000ol01Qoo0000o`000003o`0000;o
00HO1Ol000000ol01Qoo0000o`000002o`067`03o`000?l01Qoo000000;o000000Co00HOo`000?l0
1Qoo00HO1Ol000001?l022;o0000o`0;9Ol00002o`0>:003o`000?l04bgo000000?o00000_l0;Sl3
o`000003o`12B?l0003o051>00;o000000Go05I;o`000?l0Ed[o05M:o`000002o`1FB`;o000000?o
05e5o`000?l0DTd00_l0DTd00ol0003o04]=o`000002o`1@CP04o`000?l0CTko0000o`0c@P;o0000
0_l093T4o`0000;o00hX0_l000001Ol02B?o0000o`088_l0003o00LP00?o000000Oo00HOo`000?l0
003o0000o`067ol0003o00HO00?o000000Co00DOo`000?l01Ako00DN0_l000001?l01Ako0000o`05
7_l01Ah3o`000003o`057_l0003o000000?o000000Ko00DNo`000?l0003o0000o`057_l00002o`05
7P;o000000Co00DNo`000?l01Ako00DN0ol000000ol01Aoo0000o`057`03o`000004o`057ol0003o
00DOo`057`;o000000?o00DOo`000?l000001?l000001Ol01Aoo0000o`000?l01Ako000000;o00DN
0ol0000Cooooo`005oooool2o`0002Oooooo00?o0000o`057_l01Ah00_l00002o`057P04o`000?l0
1Ako0000o`0000;o00DN00?o0000o`057ol000000_l000001?l01Qoo0000o`067ol01Ql2o`0000;o
00HO1Ol000000ol01Qoo0000o`000003o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql2
o`0000;o00HO00Co0000o`067ol0003o00000_l01Ql00ol0003o00HOo`000002o`000004o`067ol0
003o00LPo`0780[o00000_l06S82o`000004o`0^?ol0003o03i7o`0nA`Co00000_l0ET/01?l0003o
05M:o`1GB_l00002o`1FB`04o`000?l0GDGo05e5o`0000;o059=00Ko0000o`1JB?l0003o0000o`1@
C_l00002o`1>CPCo000000Go02@io`000?l0003o0000o`0B;003o`000003o`0;9Ol0003o000000;o
00PR0_l000001_l01Qoo0000o`000?l0003o00HOo`0000;o00HO0_l00002o`057PGo000000?o00DN
o`000?l000000ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l000001?l01Ako0000
o`057_l01Ah3o`000003o`057_l0003o00DN00?o000000Co00DNo`000?l01Aoo00DO0_l000000ol0
1Aoo0000o`000004o`000005o`057ol0003o0000o`057ol000000_l01Ql3o`000003o`057ol0003o
00DN00?o000000?o00DNo`000?l000004oooool001Oooooo00?o0000ooooooooool09oooool2o`00
0004o`057_l0003o00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000003o`057ol0003o
000000?o000000Oo00HOo`000?l0003o0000o`067ol0003o00HO00?o00000_l01Ql01?l0003o00HO
o`000?l00002o`067`03o`000?l01Qoo000000;o000000Co00HOo`000?l01Qoo00HO0_l000001?l0
1Qoo0000o`067ol01Ql2o`0000;o00HO1Ol000000ol01b3o0000o`088P0>o`000003o`0nAol0003o
051>00?o00000_l0ET/01?l0003o05M:o`000?l0ET/2o`0000?o05e50_l00002o`1JB005o`000?l0
D4ko051>o`000?l0CTh00_l000000ol0>DGo0000o`000003o`000003o`0B;?l0003o00dW00?o0000
00Go00TSo`000?l0003o0000o`078002o`0000;o00HO1Ol000001ol01Qoo0000o`000?l0003o00DN
o`000?l01Ah00ol000001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P?o0000
00?o00DNo`000?l01Ah00ol000000ol01Ako0000o`000003o`000003o`057_l0003o000000Co0000
00Go00DOo`000?l0003o00DNo`000002o`057`?o000000?o00DNo`000?l01Al00ol000001?l01Qoo
0000o`057ol01Al2o`000004o`057_l0003o00DNo`057P?o00004_ooool001Oooooo0_l0000Zoooo
o`Co000000?o00DNo`000?l000000ol00002o`057P;o00000_l01Al01?l0003o00HOo`000?l00002
o`067`Go000000Co00HOo`000?l01Qoo00HO0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO
1Ol000000ol01Qoo0000o`000003o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql4o`00
00;o00PR00?o0000o`0:9?l000000_l03RP00ol0003o01<]o`000008o`000006o`1KAol0003o05I;
o`1FBol0003o05M:0_l000000ol0Icco0000o`1MA@02o`1MA@04o`000?l0FTSo05Y8o`1JB0;o0000
00Go051>o`000?l0003o0000o`0iA@03o`000003o`0L=?l0003o000000?o00000_l02R@2o`000005
o`078Ol0003o0000o`000?l01Ql00ol000000ol01Qoo0000o`067`03o`000004o`057_l0003o00DN
o`057P;o000000Co00DNo`000?l01Ako00DN0ol000000ol01Ako0000o`057P03o`000003o`057_l0
003o000000?o000000Ko00DNo`000?l0003o0000o`057_l00002o`057P;o000000Co00DNo`000?l0
1Ako00DN0ol000000ol01Ako0000o`057P03o`000004o`057ol0003o00DNo`057P;o000000Co00DO
o`000?l01Qoo00HO0ol000000ol01Ako0000o`000003o`000004o`057_l0003o0000o`00017ooooo
000Gooooo`03o`000?oooooooooo02[ooooo00Co0000o`057_l0003o00000_l01Ah00ol0003o00DN
o`000002o`000004o`057_l0003o00DOo`057`;o00000_l01Ql4o`0000;o00HO00?o0000o`067ol0
00000_l000000ol01Qoo0000o`000003o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql2
o`0000;o00HO00Co0000o`067ol0003o00000_l01Ql00ol0003o00HOo`000002o`000003o`067ol0
003o00LP013o000000?o04I;o`000?l000000_l0FdL4o`000005o`1[=ol0003o06Llo`1W??l00000
0_l0GDD01?l0003o05Y8o`1JB?l00002o`1NA@co000000Go00/Vo`000?l0003o0000o`088P02o`00
00;o00HO0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`057_l000000_l00000
0ol01Ako0000o`057P03o`000003o`057_l0003o000000?o00000_l01Ah2o`000004o`057_l0003o
00DNo`057P;o00000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o00DN00?o000000Co
00DNo`000?l01Ako00DN0_l000000ol01Ako0000o`000004o`000003o`057_l0003o000000?o0000
00Oo00DOo`000?l0003o0000o`057_l0003o00DN00?o000000?o00DNo`000?l000004Oooool000Co
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo02_o
oooo00Go0000o`057_l01Ako0000o`057P03o`000003o`057_l0003o00DN00?o000000?o00DOo`00
0?l000000ol000000ol01Qoo0000o`000003o`0000;o00HO0_l00002o`067`04o`000?l01Qoo0000
o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql2o`000004o`067ol0
003o00HOo`067`;o00000_l01Ql5o`000003o`078?l0003o00PR00Wo000000?o01Pao`000?l00000
1?l000001?l0FdOo0000o`1V?Ol00002o`1[=`0:o`000?l0Icco06Llo`000?l0GDGo0000o`1[=ol0
003o05Y8o`0000;o05i50ol000000ol0>DGo0000o`000002o`000003o`0A:ol0003o000000;o0000
00Go00TSo`000?l0003o0000o`078@03o`000003o`067ol0003o00HO00?o000000?o00HOo`000?l0
00000ol000000ol01Aoo0000o`000003o`0000;o00DN0_l000001?l01Ako0000o`057_l01Ah3o`00
0003o`057_l0003o00DN00?o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l0
1Ah2o`0000;o00DN1Ol000000ol01Ako0000o`000002o`057P03o`000?l01Ako000000;o000000?o
00DOo`000?l01Ql00ol000001?l01Aoo0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P?o
00004?ooool000?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0;?ooool4o`0000;o00DN2?l00002o`057`04o`000?l01Qoo0000
o`0000;o00HO00?o0000o`067ol000000_l000001?l01Qoo0000o`067ol01Ql2o`000004o`067ol0
003o00HOo`067`;o00000_l01Ql5o`000003o`067ol0003o000000?o000000Ko00HOo`000?l0003o
0000o`067ol00002o`067`Co00000_l022800ol0003o00TTo`000002o`0<9`Wo000000Co05]7o`00
0?l0ISgo00000_l0JcL01_l0003o06Llo`1W??l0003o05e5o`0000;o06/g00?o0000o`1NAOl0GTD0
1_l00002o`0C;@?o00000_l02R@2o`0000;o00PR0_l000001?l01R3o0000o`067ol01Ql2o`0000;o
00HO0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00DN00?o0000o`057_l000000_l000000ol0
1Ako0000o`057P03o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l000001?l00000
0ol01Ako0000o`000003o`000007o`057_l0003o0000o`000?l01Aoo0000o`057`03o`000004o`05
7ol0003o00DNo`057P;o000000Co00DOo`000?l01Aoo00DO0_l00002o`067`03o`000?l01Aoo0000
00;o000000?o00DOo`000?l000000ol000001?l01Ako0000o`000?l0000?ooooo`000oooool01?l0
003oooooooooool0000;ooooo`05o`000?ooooooooooooooool00000<?ooool00ol0003o00DNo`00
0002o`000003o`057_l0003o00DN00?o000000Co00DOo`000?l01Aoo00DO0_l00002o`067`03o`00
0?l01Qoo000000;o000000?o00HOo`000?l000000ol000000ol01Qoo0000o`000003o`000006o`06
7ol0003o0000o`000?l01Qoo00000_l01Ql2o`000004o`067ol0003o00HOo`067`;o00000_l01Ql0
0ol0003o00HOo`000002o`000003o`067ol0003o00LP00So000000Co00/Uo`000?l0003o00000_l0
4bd4o`000006o`1KAol0003o06Hmo`000?l0JcOo00000ol0Ic`2o`0000;o06/g00Co0000o`1NAOl0
003o05a70ol000000ol05Bko0000o`000002o`000005o`0;9Ol0003o0000o`000?l022800ol00000
0ol01b3o0000o`000003o`000007o`067ol0003o0000o`000?l01Qoo0000o`067`03o`000004o`06
7ol0003o00DNo`057P;o000000Co00DOo`000?l01Ako00DN0_l00002o`057PGo000000?o00DNo`00
0?l000000_l01Ah00ol0003o00DNo`000002o`000003o`057_l0003o00DN00?o000000Co00DNo`00
0?l01Aoo00DO0_l000001?l01Aoo0000o`057ol01Al3o`000003o`057_l0003o000000?o000000?o
00HOo`000?l000000ol000001ol01Qoo0000o`000?l0003o00DOo`000?l01Ah00ol000000ol01Ako
0000o`00000?ooooo`000oooool01?l0003oooooooooool00009ooooo`;o00001?ooool00ol0003o
ooooooooo`0_ooooo`;o000000?o00DNo`000?l000000ol000000ol01Ako0000o`057`03o`000003
o`067ol0003o000000?o00000_l01Ql2o`000004o`067ol0003o00HOo`067`;o00000_l01Ql01?l0
003o00HOo`000?l00002o`067`03o`000?l01Qoo000000;o000000?o00HOo`000?l01Ql00ol00000
1?l01Qoo0000o`067ol01Ql2o`0000;o00HO1?l00002o`068003o`000?l01b7o000000Co000000?o
00TSo`000?l032H02?l000001Ol0ISgo0000o`1[=ol0JcOo000000;o06Ll00Go0000o`1[=ol0JcOo
0000o`1e:008o`0000;o00/V0_l00002o`088P;o000000Ko00LPo`000?l0003o0000o`067ol00002
o`0680;o000000Co00HOo`000?l01Qoo00HO0_l000000ol01Qoo0000o`000004o`000003o`057_l0
003o000000?o000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00?o000000Co00DNo`000?l0
1Ako00DN0_l000001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P?o000000?o
00DOo`000?l000000ol000001ol01Aoo0000o`000?l0003o00DOo`000?l01Al00ol000001?l01Qoo
0000o`067ol01Ql2o`000004o`067ol0003o00DOo`057`;o000000Co00DNo`000?l01Ako00DN0ol0
000>ooooo`000oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooooooo`;o0000
<Oooool4o`0000;o00DN1Ol000000ol01Qoo0000o`000002o`067`03o`000?l01Qoo000000;o0000
00?o00HOo`000?l01Ql00ol000001?l01Qoo0000o`067ol01Ql2o`000004o`067ol0003o00HOo`06
7`;o00000_l01Ql5o`000003o`067ol0003o000000?o000000Oo00HOo`000?l0003o0000o`067ol0
003o00HO00Go00000_l01b0>o`000006o`1V?Ol0003o06/go`1[=ol0003o06Ll0_l00002o`1[=`04
o`000?l0MBSo0000o`1`<0Co000000Go00`Vo`000?l0003o0000o`098`03o`000003o`078Ol0003o
000000;o00HO00?o0000o`067ol000000_l000000ol01Qoo0000o`067`03o`000003o`067ol0003o
000000;o00HO00?o0000o`067ol000000_l000000ol01Ako0000o`057P03o`000004o`057_l0003o
00DNo`057P;o000000Co00DNo`000?l01Ako00DN0ol000000ol01Ako0000o`000003o`000003o`05
7_l0003o000000?o000000Oo00DOo`000?l0003o0000o`057_l0003o00DO00?o000000Co00DOo`00
0?l01Aoo00DO0_l000001?l01Qoo0000o`067ol01Ql3o`000003o`067ol0003o00HO00?o000000?o
00DNo`000?l000000ol000001?l01Ako0000o`000?l0000=ooooo`000oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0]ooooo`?o
000000?oooooo`000?l01Ah00ol000001?l01Aoo0000o`057ol01Al2o`0000;o00HO00Co0000o`06
7ol0003o00000_l01Ql00ol0003o00HOo`000002o`000003o`067ol0003o00HO00?o000000?o00HO
o`000?l000000ol000001_l01Qoo0000o`000?l0003o00HOo`0000;o00HO0_l000001?l01Qoo0000
o`067ol01Ql2o`0000;o00HO00Co0000o`067ol0003o00000_l01R000ol0003o00HPo`000002o`00
0003o`067ol0003o00LP00Go00000_l02B<6o`0000;o06/g0_l000001_l0R0;o0000o`1[=ol0JcOo
0000o`1e:0_o000000Go00LQo`000?l0003o0000o`068005o`000003o`067ol0003o000000?o0000
00Ko00HOo`000?l0003o0000o`067ol00002o`067`;o000000Co00HOo`000?l01Ako00DN0_l00002
o`057PGo000000?o00DNo`000?l000000ol000001ol01Ako0000o`000?l0003o00DOo`000?l01Ah0
0ol000001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`00
0?l01Aoo00DO0ol000000ol01Aoo0000o`000003o`000003o`067ol0003o000000?o000000Oo00DO
o`000?l0003o0000o`057_l0003o00DN00?o000000?o00DNo`000?l000003Oooool000Cooooo0_l0
0009ooooo`?o00001?ooool2o`0002_ooooo0ol00005ooooo`;o000000?o00DNo`000?l01Al00ol0
00000ol01Qoo0000o`000003o`000003o`067ol0003o000000?o00000_l01Ql4o`0000;o00HO0_l0
0002o`067`04o`000?l01Qoo0000o`0000;o00HO00?o0000o`067ol000000_l000000ol01Qoo0000
o`067`03o`000004o`067ol0003o00HOo`067`;o000000Co00HOo`000?l01R3o00HP0_l00002o`06
7`Co00000_l01R05o`000005o`078Ol0003o00TSo`000?l0PA801?l00002o`280P03o`000?l0JcOo
000000;o07DX0_l00002o`088P;o000000Co00LQo`000?l01b7o00LQ0_l00002o`0680;o000000Co
00HOo`000?l01Qoo00HO0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`067ol0
00000_l000000ol01Qoo0000o`000003o`000007o`057ol0003o0000o`000?l01Ako0000o`057P03
o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`000?l01Aoo00DO0_l000001?l01Ako0000
o`057_l01Ah3o`000003o`057ol0003o000000?o000000?o00DNo`000?l000000ol000001ol01Aoo
0000o`000?l0003o00HOo`000?l01Ql00ol000001?l01Qoo0000o`067ol01Ql2o`000004o`057_l0
003o00DNo`057P;o000000Co00DNo`000?l01Ako00DN0ol0000<ooooo`005_ooool00ol0003ooooo
ooooo`0Wooooo`?o00002_ooool4o`000003o`067ol0003o000000;o00HO00Co0000o`067ol0003o
00000_l01Ql00ol0003o00HOo`000002o`000003o`067ol0003o00HO00?o000000Co00HOo`000?l0
1Qoo00HO0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO1?l00002o`067`Go000000?o00HO
o`000?l000000ol000001ol01Qoo0000o`000?l0003o00HOo`000?l01Ql00ol000001?l01Qoo0000
o`078?l01b05o`0000;o084B00?o0000ob6G0?l000000ol0R082o`000003o`1e:?l0003o000000?o
000000?o00LQo`000?l000000ol000001ol01R3o0000o`000?l0003o00HOo`000?l01Ql00ol00000
0ol01Qoo0000o`067`03o`000003o`067ol0003o000000?o000000Ko00HOo`000?l0003o0000o`06
7ol00002o`067`;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah3o`00
0003o`057_l0003o00DN00?o000000?o00DNo`000?l000000ol000001ol01Aoo0000o`000?l0003o
00DOo`000?l01Ah00ol000000ol01Aoo0000o`057P03o`000004o`057ol0003o00HOo`067`;o0000
00Co00HOo`000?l01Qoo00HO0ol000000ol01Aoo0000o`000003o`000003o`057_l0003o000000?o
000000Co00DNo`000?l0003o00002oooool001Gooooo00?o0000ooooooooool09Oooool3o`0000go
oooo00?o0000o`057ol01Al00_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00Co0000o`06
7ol0003o00000_l01Ql00ol0003o00HOo`000002o`000003o`067ol0003o000000?o000000?o00HO
o`000?l000000ol000001ol01Qoo0000o`000?l0003o00HOo`000?l01Ql00ol000001?l01Qoo0000
o`067ol01Ql2o`000004o`067ol0003o00HOo`067`;o00000_l01Ql4o`0000;o00HO1Ol000000ol0
1Qoo0000o`000003o`000004o`214_l0003o8IL0o`0000?o08P20_l000001?l0MBSo0000o`000?l0
1b03o`000004o`067ol0003o00HPo`0680;o000000?o00HOo`000?l000000ol000000ol01Qoo0000
o`000003o`0000;o00HO0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00?o0000o`067ol0
00000_l000000ol01Qoo0000o`057P03o`000003o`057_l0003o000000?o000000?o00DNo`000?l0
00000ol000001_l01Ako0000o`000?l0003o00DNo`0000;o00DN0_l000001?l01Aoo0000o`057ol0
1Al2o`000004o`057ol0003o00DOo`057`;o00000_l01Ah5o`000003o`067ol0003o000000?o0000
00Oo00HOo`000?l0003o0000o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol0
1Ako0000o`00000;ooooo`005Oooool2o`0002?ooooo0ol0000Aooooo`;o000000?o00HOo`000?l0
1Ql00ol000000ol01Qoo0000o`000003o`000003o`067ol0003o000000?o00000_l01Ql2o`000004
o`067ol0003o00HOo`067`;o00000_l01Ql01?l0003o00HOo`000?l00002o`067`04o`000?l01Qoo
0000o`0000;o00HO00?o0000o`067ol000000_l000000ol01Qoo0000o`000003o`000007o`067ol0
003o0000o`000?l01Qoo0000o`067`03o`000003o`067ol0003o00HO00?o000000Wo00HOo`000?l0
1Qoo00HOo`000?l0PA;o0000ob6G0?l000000ol0R0800ol0003o07DXo`1e:003o`0000;o00HO1Ol0
00000ol01Qoo0000o`000002o`067`04o`000?l01Qoo0000o`0000;o00HO00?o0000o`067ol00000
0_l000000ol01Qoo0000o`067`03o`000004o`067ol0003o00HOo`067`;o000000?o00HOo`000?l0
00000ol000001_l01Ako0000o`000?l0003o00DOo`0000;o00DO0_l000001?l01Ako0000o`057_l0
1Ah2o`000004o`057_l0003o00DNo`057P?o000000?o00DOo`000?l01Al00ol000000ol01Aoo0000
o`000003o`000007o`057_l0003o0000o`000?l01Aoo0000o`067`03o`000003o`057ol0003o00HO
00?o000000Co00DOo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah2o`000003o`057_l0
003o000000?o00002oooool001Gooooo00?o0000ooooooooool07oooool3o`0001Kooooo1?l00000
0ol01Qoo0000o`000002o`067`04o`000?l01Qoo0000o`0000;o00HO00?o0000o`067ol000000_l0
00000ol01Qoo0000o`067`03o`000004o`067ol0003o00HOo`067`;o000000?o00HOo`000?l00000
0ol000000ol01Qoo0000o`000003o`0000;o00HO0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o
00HO00Co0000o`067ol0003o00000_l01Ql01?l0003o00HOo`000?l00002o`067`Ko000000Co084B
o`000?lQU`3o00000ol0R0801Ol0003o07DXo`1e:?l0003o00HO00?o000000?o00HOo`000?l01Ql0
0ol000001?l01Qoo0000o`067ol01Ql2o`000004o`067ol0003o00HOo`067`;o000000?o00HOo`00
0?l000000ol00002o`067`Go000000Go00HOo`000?l0003o00DOo`000002o`057`;o00000_l01Al0
0ol0003o00DOo`000002o`000003o`057ol0003o00DN00?o000000?o00DOo`000?l000000ol00000
0ol01Aoo0000o`000003o`000007o`057_l0003o0000o`000?l01Aoo0000o`057`03o`000004o`05
7ol0003o00DOo`057`;o000000Co00DOo`000?l01Aoo00DO0_l000000ol01Aoo0000o`000004o`00
0003o`057_l0003o000000?o000000?o00DNo`000?l000001?ooool00ol0003oooooooooo`09oooo
o`005Oooool2o`0001gooooo0ol0000Iooooo`03o`000?l01Qoo00HO00;o000000Co00HOo`000?l0
1Qoo00HO0_l00002o`067`04o`000?l01Qoo0000o`0000;o00HO1Ol000000ol01Qoo0000o`000003
o`000003o`067ol0003o000000;o00HO00Co0000o`067ol0003o00000_l01Ql00ol0003o00HOo`00
0002o`000003o`067ol0003o00HO00?o000000?o00HOo`000?l000000ol000000ol01Qoo0000o`00
0003o`000006o`067ol0003o0000o`000?l01Qoo00000_l01Ql2o`000004o`214_l0003o8IL0o`00
00?o08P20_l000000ol0MBSo0000o`000002o`067`04o`000?l01Qoo0000o`0000;o00HO1Ol00000
0ol01Qoo0000o`000003o`000003o`067ol0003o000000;o00HO00?o0000o`067ol000000_l00000
0ol01Qoo0000o`067`03o`000003o`067ol0003o00DO00?o000000?o00DOo`000?l000000ol00000
0ol01Aoo0000o`000003o`000006o`057ol0003o0000o`000?l01Aoo00000_l01Al2o`000004o`05
7_l0003o00DNo`057P;o000000Co00DNo`000?l01Aoo00DO0_l000000ol01Aoo0000o`000004o`00
0003o`067ol0003o000000?o000000Go00DNo`000?l0003o00DNo`000002o`057P?o000000?o00DN
o`000?l01Ah00ol00006ooooo`03o`000?oooooooooo00Wooooo000Eooooo`03o`000?oooooooooo
01[ooooo0_l0000Mooooo`;o000000?o00HOo`000?l000000ol000000ol01Qoo0000o`000003o`00
0006o`067ol0003o0000o`000?l01Qoo00000_l01Ql2o`000004o`067ol0003o00HOo`067`;o0000
00Co00HOo`000?l01Qoo00HO0_l00002o`067`04o`000?l01Qoo0000o`0000;o00HO1?l00002o`06
7`;o00000_l01Ql01?l0003o00HOo`000?l00002o`057P04o`000?l01Qoo0000o`0000;o00DO00?o
0000o`067ol000000_l000001?l01Qoo0000o`214_l00002ob6G0003o`000?l0R0;o08P200?o0000
00?o00HOo`000?l000000ol000001ol01Qoo0000o`000?l0003o00HOo`000?l01Ql00ol000000ol0
1Qoo0000o`067`03o`000004o`067ol0003o00HOo`067`;o000000Co00HOo`000?l01Qoo00HO0_l0
00000ol01Qoo0000o`000003o`0000;o00DN0_l000001?l01Qoo0000o`067ol01Ql2o`000004o`05
7_l0003o00DNo`057P;o000000Co00DOo`000?l01Aoo00DO0ol000000ol01Ako0000o`057P03o`00
0003o`057_l0003o000000?o000000Go00DOo`000?l0003o00DOo`000002o`067`?o000000?o00DO
o`000?l01Ah00ol000000ol01Ako0000o`057P03o`000003o`057_l0003o00DN00?o00002_ooool0
0ol0003oooooooooo`08ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`00
00Cooooo00?o0000ooooooooool05oooool3o`00027ooooo00Go0000o`067ol01Qoo0000o`067`03
o`000003o`067ol0003o00HO00?o000000?o00HOo`000?l01Ql00ol000000ol01Qoo0000o`067`03
o`000003o`067ol0003o000000?o000000?o00HOo`000?l000000ol000001ol01Qoo0000o`000?l0
003o00HOo`000?l01Ql00ol000001?l01Qoo0000o`067ol01Ql2o`000004o`057_l0003o00DNo`05
7P;o000000?o00DNo`000?l000000ol000000ol01Qoo0000o`000004o`0000;o8IL000Go0000o`28
0_l0R0;o0000og:`0002o`000004o`067ol0003o00HOo`067`;o000000Co00HOo`000?l01Qoo00HO
0_l00002o`067`04o`000?l01Qoo0000o`0000;o00HO1Ol000000ol01Qoo0000o`000003o`000003
o`067ol0003o000000;o00HO00?o0000o`067ol000000_l000000ol01Ako0000o`067`03o`000003
o`057ol0003o00DN00?o000000?o00DOo`000?l000000ol000000ol01Ako0000o`000003o`000007
o`057_l0003o0000o`000?l01Ako0000o`057P03o`000003o`067ol0003o00DO00?o000000Co00DO
o`000?l01Aoo00DO0_l000000ol01Ako0000o`000003o`000003o`057_l0003o000000?o00003Ooo
ool00ol0003oooooooooo`08ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05?ooool3o`0002Cooooo00?o0000o`067ol01Ql00_l0
0002o`067`Co00000_l01Ql4o`0000;o00HO1?l00002o`067`;o00000_l01Ql01?l0003o00HOo`00
0?l00002o`067`04o`000?l01Qoo0000o`0000;o00HO00Co0000o`067ol0003o00000_l01Ql5o`00
0003o`057_l0003o000000?o000000?o00DOo`000?l000000_l01Ql01?l0003o00DOo`000?l00002
o`067`04o`000?l01Qoo0000o`0000;o8IL000?o0000o`280_l000000_mb/002o`000005o`067ol0
003o0000o`000?l01Ql01Ol000000ol01Qoo0000o`000003o`000007o`067ol0003o0000o`000?l0
1Qoo0000o`067`03o`000003o`067ol0003o00HO00?o000000Co00HOo`000?l01Qoo00HO0_l00000
0ol01Qoo0000o`000003o`000003o`057ol0003o000000?o000000Ko00DNo`000?l0003o0000o`05
7ol00002o`057`;o000000Co00DNo`000?l01Ako00DN0_l000001?l01Ako0000o`057_l01Ah2o`00
0003o`057ol0003o000000?o00000_l01Al5o`000005o`057_l0003o0000o`057_l000000_l01Ah2
o`0001;ooooo00?o0000ooooooooool02?ooool00005ooooool0003oooooooooool000001oooool5
o`0000?ooooo00?o0000ooooooooool04_ooool3o`0002Sooooo0_l000001ol01Qoo0000o`000?l0
003o00HOo`000?l01Ql00ol000000ol01Qoo0000o`067`03o`000003o`057ol0003o00HO00?o0000
00Co00DOo`000?l01Qoo00HO0_l000000ol01Qoo0000o`000003o`000003o`057ol0003o000000?o
000000Ko00HOo`000?l0003o0000o`057_l00002o`057P;o000000Co00DNo`000?l01Ako00DN0_l0
00001?l01Qoo0000o`067ol01Ql2o`000003o`057ol0003o000000Go00000_lQU`000ol0003o08P2
o`000002og:`00?o00000_l01Ql2o`000004o`067ol0003o00HOo`067`;o000000Co00HOo`000?l0
1Qoo00HO0_l000001?l01Qoo0000o`067ol01Ql2o`0000;o00HO00Co0000o`067ol0003o00000_l0
1Ql5o`000005o`067ol0003o0000o`067ol000000_l01Al2o`000004o`057_l0003o00DNo`057P;o
00000_l01Ah00ol0003o00DOo`000002o`000003o`057ol0003o000000?o000000?o00DNo`000?l0
00000ol000001Ol01Aoo0000o`000?l01Aoo000000;o00HO0ol000000ol01Ako0000o`057P03o`00
0003o`057_l0003o00DN00?o00005?ooool00ol0003oooooooooo`08ooooo`0000Goooooo`000?oo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03oooool3
o`0002gooooo00Go0000o`067ol01Qoo0000o`067`03o`000003o`057ol0003o00HO00?o000000?o
00DNo`000?l000000ol000000ol01Qoo0000o`000003o`000003o`067ol0003o000000;o00DN00Co
0000o`057_l0003o00000_l01Al01?l0003o00HOo`000?l00002o`057`03o`000?l01Ako000000;o
000000?o00DNo`000?l000000ol000000ol01Aoo0000o`000003o`000003o`067ol0003o000000;o
00DN00[o0000o`057ol0003o0000o`214_l0003o8IL0o`000?l0R0;o00000_mb/0000ol0003o00HO
o`000002o`000003o`067ol0003o00HO00?o000000?o00HOo`000?l01Ql00ol000000ol01Qoo0000
o`000003o`000003o`067ol0003o000000?o000000Oo00HOo`000?l0003o0000o`067ol0003o00HO
00?o000000?o00HOo`000?l01Ql00ol000000ol01Aoo0000o`000003o`000003o`057_l0003o0000
00?o000000Oo00DOo`000?l0003o0000o`057ol0003o00DN00?o000000?o00DOo`000?l01Al00ol0
00000ol01Aoo0000o`057`03o`000004o`057ol0003o00DNo`057P;o000000?o00DNo`000?l00000
0ol0000Gooooo`03o`000?oooooooooo00Sooooo00001Ooooooo0000oooooooooooo000000Sooooo
00?o0000ooooool000001?ooool2o`0000gooooo0ol0000aooooo`Co00000_l01Ah4o`0000;o00DN
0_l000001?l01Ako0000o`067ol01Ql2o`000004o`057ol0003o00DOo`057`;o000000Co00DOo`00
0?l01Ako00DN0_l000000ol01Aoo0000o`000003o`000003o`057_l0003o000000?o00000_l01Ah2
o`000004o`057_l0003o00DNo`057P;o000000Co00DOo`000?l01Qoo00HO0_l000001?l01Ako0000
o`057_l01Ah2o`000008o`057ol0003o0000o`000?lQU`3o0000o`280_l00002og:`00;o00000_l0
1Ql01?l0003o00HOo`000?l00002o`067`Co00000_l01Ql2o`000004o`067ol0003o00HOo`067`;o
000000Co00HOo`000?l01Qoo00HO0_l000001?l01Qoo0000o`067ol01Ql2o`000003o`067ol0003o
000000?o00000_l01Ql2o`000004o`057ol0003o00DNo`057P;o000000Co00DNo`000?l01Ako00DN
0_l000001?l01Aoo0000o`057ol01Al2o`000004o`057ol0003o00DOo`057`;o000000?o00DOo`00
0?l000000ol000000ol01Ako0000o`000004o`000003o`057_l0003o000001cooooo00?o0000oooo
ooooool02?ooool00005ooooool0003oooooooooool000002Oooool2o`0000Cooooo00?o0000oooo
ooooool02Oooool3o`0003Gooooo00?o0000o`057_l000000_l000000ol01Ako0000o`057P03o`00
0003o`057_l0003o00DN00?o000000?o00DOo`000?l000000ol000000ol01Aoo0000o`000003o`00
0003o`057ol0003o000000;o00DO00?o0000o`057_l000000_l000000ol01Ako0000o`057P03o`00
0003o`057_l0003o00DN00?o000000?o00DNo`000?l01Al00ol000000ol01Aoo0000o`000003o`00
0003o`057_l0003o000000?o000000Co8IL0o`000?l0R0;o00000_mb/006o`000007o`067ol0003o
0000o`000?l01Qoo0000o`067`03o`000003o`067ol0003o00HO00?o000000?o00HOo`000?l00000
0ol000000ol01Qoo0000o`000003o`000003o`067ol0003o000000;o00HO00?o0000o`067ol00000
0_l000000ol01Qoo0000o`057`03o`000003o`057ol0003o00DN00?o000000?o00DOo`000?l00000
0ol000000ol01Aoo0000o`000003o`000005o`057ol0003o0000o`057_l000000_l01Ah2o`0000;o
00DN00?o0000o`057_l000000_l000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo00So
oooo0002ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
0ol0000iooooo`03o`000?l01Ako00DN00Co00000_l01Ah4o`0000;o00DO0_l000001?l01Aoo0000
o`057ol01Al2o`000004o`057ol0003o00DOo`057`;o00000_l01Al01?l0003o00DOo`000?l00002
o`057PCo00000_l01Al4o`0000;o00DN1?l00002o`057`;o000000Co00DNo`000?l01Ako00DN0_l0
00000ol01Ako0000o`057`02o`000005ob6G0?l0003o08P2o`000?mb/0000_l000000ol01Qoo0000
o`000003o`000003o`067ol0003o000000?o000000?o00HOo`000?l000000ol000001_l01Qoo0000
o`000?l0003o00HOo`0000;o00HO0_l000001?l01Qoo0000o`067ol01Ql2o`000004o`067ol0003o
00HOo`067`;o000000?o00HOo`000?l000000ol000000ol01Aoo0000o`000003o`000007o`057ol0
003o0000o`000?l01Aoo0000o`057`03o`000003o`057ol0003o00DO00?o000000?o00DNo`000?l0
1Ah00ol000000ol01Ako0000o`000003o`0000Gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`07ooooo`005?ooool2o`0000Cooooo0ol0000mooooo`;o000000?o00DNo`000?l01Ah0
0ol000000ol01Ako0000o`057P03o`000003o`057ol0003o00DO00?o000000?o00DOo`000?l00000
0ol000000ol01Ako0000o`000003o`000007o`057ol0003o0000o`000?l01Ako0000o`057`03o`00
0003o`057_l0003o00DN00?o000000?o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P03o`00
0003o`057_l0003o000000Co000000Go8IL0o`000?l0R0;o0000og:`0003o`0000;o00HO00Co0000
o`067ol0003o00000_l01Ql01?l0003o00HOo`000?l00002o`067`04o`000?l01Qoo0000o`0000;o
00HO00?o0000o`067ol000000_l000000ol01Qoo0000o`000003o`000003o`067ol0003o000000?o
000000Go00HOo`000?l0003o00HOo`000002o`067`;o000000Co00DOo`000?l01Aoo00DO0_l00000
1?l01Aoo0000o`057ol01Al2o`000003o`057ol0003o000000?o000000?o00DNo`000?l000000ol0
0002o`057P;o00002_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo000C
ooooo`04o`000?ooooooooooooooo`?o0000@Oooool00ol0003o00DNo`000002o`000003o`057_l0
003o000000?o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000002o`057P04o`000?l0
1Ako0000o`0000;o00DN00Co0000o`057ol0003o00000_l01Al01?l0003o00DNo`000?l00002o`05
7`04o`000?l01Ako0000o`0000;o00DN1?l00002o`057PCo00000_l01Al2o`000004o`057_l0003o
00DNo`057P;o000000So8IL0o`000?l0R0;o0000og:`0?l0003o00HOo`0000;o00HO0_l000001?l0
1Qoo0000o`067ol01Ql2o`000003o`067ol0003o000000?o000000?o00HOo`000?l000000ol00000
1ol01Qoo0000o`000?l0003o00HOo`000?l01Ql00ol000000ol01Qoo0000o`067`03o`000003o`06
7ol0003o00HO00?o000000?o00DOo`000?l000000ol000000ol01Ako0000o`000003o`000003o`05
7_l0003o000000;o00DN00Co0000o`057_l0003o00000_l01Ah00ol0003o00DNo`000002o`0000go
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`004oooool4o`0004Gooooo
00?o0000o`057_l01Ah00_l000001?l01Ako0000o`057_l01Ah2o`000004o`057_l0003o00DNo`05
7P;o000000Co00DNo`000?l01Ako00DN0_l000000ol01Ako0000o`000003o`000003o`057ol0003o
000000?o000000?o00DNo`000?l000000ol000001ol01Ako0000o`000?l0003o00DNo`000?l01Ah0
0ol000000ol01Ako0000o`057P03o`000003o`057ol0003o00DN00?o000000Oo00DNo`000?lQU`3o
0000o`280_l0003oL[0000Go000000?o00HOo`000?l000000ol000001Ol01Qoo0000o`000?l01Qoo
000000;o00HO0_l000001?l01Qoo0000o`067ol01Ql2o`000004o`067ol0003o00HOo`067`;o0000
00?o00HOo`000?l000000ol000000ol01Qoo0000o`000003o`000007o`057ol0003o0000o`000?l0
1Aoo0000o`057P03o`000004o`057_l0003o00DNo`057P;o000000Co00DNo`000?l01Ako00DN0_l0
00000ol01Ako0000o`000003o`00017ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`07ooooo`004oooool2o`0004Sooooo0_l000000ol01Ako0000o`057P03o`000003o`057_l0003o
000000?o000000?o00DOo`000?l000000ol000000ol01Ako0000o`000002o`057P04o`000?l01Ako
0000o`0000;o00DN00Co0000o`057_l0003o00000_l01Ah01?l0003o00DNo`000?l00002o`057PCo
00000_l01Ah4o`0000;o00DN1?l00002o`057P?o00000_lQU`000ol0003oL[00og:`0002o`000007
o`067ol0003o0000o`000?l01Qoo0000o`067`03o`000003o`067ol0003o00HO00?o000000?o00HO
o`000?l000000ol000000ol01Qoo0000o`000003o`000003o`067ol0003o000000;o00HO00Co0000
o`067ol0003o00000_l01Ql01?l0003o00DOo`000?l00002o`057P04o`000?l01Aoo0000o`0000;o
00DN1Ol000000ol01Ako0000o`000003o`000003o`057_l0003o000001Kooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`07ooooo`005Oooool00ol0003oooooooooo`17ooooo`Co0000
00?o00DNo`000?l000000_l01Ah01_l0003o00DOo`000?l0003o00DNo`0000;o00DN0_l000001?l0
1Ako0000o`057_l01Ah2o`000003o`057ol0003o000000?o000000?o00DNo`000?l000000ol00000
1ol01Ako0000o`000?l0003o00DNo`000?l01Ah00ol000000ol01Ako0000o`057P03o`000003o`05
7ol0003o00DO00?o000000?o00HOo`000?l000000_lQU`000ol0003oL[00og:`0003o`0000;o00HO
1?l00002o`067`Co00000_l01Ql2o`000004o`067ol0003o00HOo`067`;o000000Co00HOo`000?l0
1Qoo00HO0_l000001?l01Qoo0000o`067ol01Ql2o`000003o`067ol0003o000000?o000000?o00DN
o`000?l000000ol000001ol01Ako0000o`000?l0003o00DNo`000?l01Ah00ol000000ol01Ako0000
o`057P03o`0001Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`005_oo
ool00ol0003oooooooooo`16ooooo`03o`000?l01Ako00DN00;o000000Co00DNo`000?l01Ako00DN
0_l000000ol01Aoo0000o`000003o`000003o`057_l0003o000000?o000000?o00DNo`000?l00000
0_l01Ah01?l0003o00DNo`000?l00002o`057P04o`000?l01Ako0000o`0000;o00DN00Co0000o`05
7_l0003o00000_l01Ah4o`0000;o00DN1?l000000ol01Qoo0000o`000004o`000006ob6G0?l0003o
L[00og:`0?l0003o00HO0ol000000ol01Aoo0000o`067`03o`000003o`067ol0003o00HO00?o0000
00?o00HOo`000?l01Ql00ol000000ol01Qoo0000o`000003o`000003o`067ol0003o000000?o0000
00Go00HOo`000?l0003o00HOo`000002o`067`;o000000Co00DNo`000?l01Ako00DN0_l000000ol0
1Ako0000o`000003o`000003o`057_l0003o000000?o00007Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Oooooo000Gooooo`03o`000?oooooooooo04Kooooo0_l000000ol01Ako
0000o`000003o`000003o`057_l0003o000000;o00DO00Co0000o`057_l0003o00000_l01Ah01_l0
003o00DNo`000?l0003o00DNo`0000;o00DN0_l000000ol01Ako0000o`000003o`000003o`057_l0
003o000000?o000000Oo00DNo`000?l0003o0000o`057_l0003o00DN00?o000000?o00DNo`000?l0
1Al00_l00002o`057`04o`000?l01Qoo0000olRk00;o00000_mb/002o`0000;o00DO1?l00002o`06
7`Co00000_l01Ql4o`000007o`067ol0003o0000o`000?l01Qoo0000o`067`03o`000003o`067ol0
003o00HO00?o000000?o00HOo`000?l000000ol000000ol01Aoo0000o`000003o`000005o`057_l0
003o0000o`057_l000000_l01Ah2o`0002?ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`07ooooo`006?ooool2o`0004Sooooo00?o0000o`057_l000000_l01Ah2o`000004o`057ol0
003o00DOo`057`;o000000?o00DOo`000?l000000ol000000ol01Ako0000o`000003o`000003o`05
7_l0003o000000;o00DN00Co0000o`057_l0003o00000_l01Ah01?l0003o00DNo`000?l00002o`05
7`04o`000?l01Ako0000o`0000;o00DN1?l000000ol01Ako0000o`000003o`000004o`057ol0003o
b;/0o`0000;oL[001?l000000ol01Aoo0000o`057`03o`000003o`067ol0003o00HO00?o000000?o
00HOo`000?l01Ql00_l00002o`067`Co00000_l01Ql4o`0000;o00HO0_l000000ol01Qoo0000o`06
7`03o`000003o`057ol0003o00DN00?o000000?o00DNo`000?l01Ah00ol0000Uooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01_ooool001[ooooo00?o0000ooooooooool0A_ooool4
o`000003o`057_l0003o000000?o000000?o00DOo`000?l000000_l01Al01?l0003o00DOo`000?l0
0002o`057P06o`000?l01Ako0000o`000?l01Ako00000_l01Ah2o`000003o`057_l0003o000000?o
000000?o00DNo`000?l000000ol000001ol01Ako0000o`000?l0003o00DNo`000?l01Ah00_l00002
o`057P03o`000?l01Aoo000000;o000000Gob;/0o`000?mb/03oL[00o`000002o`057`Co000000?o
00DOo`000?l000000ol000000ol01Qoo0000o`000003o`000007o`067ol0003o0000o`000?l01Qoo
0000o`067`03o`000003o`067ol0003o00HO00?o000000?o00HOo`000?l01Ql00_l00002o`067`Co
00000_l01Ah4o`0002Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`00
6oooool00ol0003oooooooooo`16ooooo`04o`000?l01Ako0000o`0000;o00DN00Go0000o`057_l0
003o0000o`057`05o`000003o`057_l0003o000000?o000000?o00DNo`000?l000000ol000000ol0
1Ako0000o`000002o`057P04o`000?l01Ako0000o`0000;o00DO00Go0000o`057ol0003o0000o`05
7P05o`000003o`057_l0003o000000?o000000Go00DNo`000?l0003ob;/0o`000002og:`00?o0000
00?o00DOo`000?l01Al00_l00002o`067`04o`000?l01Qoo0000o`0000;o00HO00Go0000o`067ol0
003o0000o`067`05o`000003o`067ol0003o000000?o000000?o00HOo`000?l000000ol000001ol0
1Qoo0000o`000?l0003o00HOo`000?l01Al00ol0000^ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01_ooool001cooooo00?o0000ooooooooool0A_ooool00ol0003o00DNo`000004
o`000007o`057ol0003o0000o`000?l01Aoo0000o`057P02o`0000;o00DN00Co0000o`057_l0003o
00000_l01Ah01Ol0003o00DNo`000?l0003o00DN00Go000000?o00DNo`000?l000000ol000000ol0
1Ako0000o`000002o`057P04o`000?l01Ako0000o`0000;o00DN00_o0000o`057_l0003o0000o`05
7ol0003ob;/0o`000?mb/03o0000o`057P05o`000003o`067ol0003o000000?o000000?o00HOo`00
0?l000000ol000000ol01Qoo0000o`000002o`067`04o`000?l01Qoo0000o`0000;o00HO00Ko0000
o`067ol0003o0000o`067ol00002o`067`;o000000?o00HOo`000?l000000ol0000booooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01_ooool001gooooo0_l00017ooooo`05o`000?l0
1Ako00DNo`000?l01Ah00_l00002o`057`Co000000?o00DNo`000?l000000ol000000ol01Ako0000
o`000003o`000003o`057_l0003o000000;o00DN00Co0000o`057_l0003o00000_l01Ah01_l0003o
00DNo`000?l0003o00DNo`0000;o00DN0_l000000ol01Ako0000o`000003o`000007o`057_l0003o
0000o`000?o8^`3o0000og:`0002o`0000;o00DO00Co0000o`057ol0003o00000_l01Ql01_l0003o
00HOo`000?l0003o00HOo`0000;o00HO0_l000000ol01Qoo0000o`000003o`000003o`067ol0003o
000000?o000000?o00HOo`000?l000000ol000000ol01Qoo0000o`00000gooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01_ooool001oooooo00?o0000ooooooooool0AOooool4o`00
0007o`057_l0003o0000o`000?l01Aoo0000o`057`03o`000003o`057_l0003o00DN00;o00000_l0
1Ah01Ol0003o00DNo`000?l0003o00DN00Go000000?o00DNo`000?l000000ol000000ol01Ako0000
o`000003o`000003o`057_l0003o000000;o00DN00Go0000o`057_l0003o0000o`057`02o`000003
olRk0?l0003oL[0000;o00000_l01Al2o`000003o`057ol0003o000000?o000000?o00HOo`000?l0
00000ol000001Ol01Qoo0000o`000?l01Aoo000000;o00HO0_l000001?l01Qoo0000o`067ol01Ql2
o`000004o`067ol0003o00HOo`067`;o0000>_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Kooooo000Pooooo`03o`000?oooooooooo04Gooooo00Co0000o`057_l0003o00000_l0
1Ah01?l0003o00DOo`000?l00002o`057`Co000000?o00DOo`000?l000000ol000001ol01Ako0000
o`000?l0003o00DOo`000?l01Al00_l00002o`057`06o`000?l01Ako0000o`000?l01Ako00000_l0
1Ah2o`000003o`057_l0003o000000?o000000?o00DOo`000?l000001?l000000omb/03o0000o`00
0002o`000005o`057ol0003o0000o`057ol000000_l01Ql2o`000004o`067ol0003o00DOo`057`;o
000000?o00DOo`000?l01Al00ol000000ol01Aoo0000o`000003o`000003o`067ol0003o000000?o
0000?Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`00
0?oooooooooo04Gooooo00?o0000o`057_l000001?l000001ol01Aoo0000o`000?l0003o00DOo`00
0?l01Al00_l00002o`057`04o`000?l01Ako0000o`0000;o00DN1?l000000ol01Aoo0000o`000003
o`000003o`057_l0003o000000?o000000?o00DOo`000?l000000_l01Al01_l0003o00DOo`000?l0
003o00DOo`0000;o00DO0_l000001?mb/03o0000o`057ol01Al2o`000003o`057ol0003o000000?o
000000?o00HOo`000?l000000ol000000ol01Aoo0000o`000002o`0000;o00DO0_l000000ol01Aoo
0000o`067`03o`0004;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`00
8_ooool00ol0003oooooooooo`15ooooo`;o000000?o00DNo`000?l01Ah00_l00002o`057`Co0000
00?o00DOo`000?l000000ol000001ol01Aoo0000o`000?l0003o00DNo`000?l01Ah00_l00002o`05
7P04o`000?l01Ako0000o`0000;o00DN00Go0000o`057_l0003o0000o`057`05o`000003o`057ol0
003o000000Go000000GoL[00o`000?l0003o0000o`057`02o`000004o`057ol0003o00DOo`057`;o
000000?o00DOo`000?l01Al00ol000000ol01Aoo0000o`057`03o`000003o`057_l0003o000000;o
0000A_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo000Sooooo`;o0000
Aoooool3o`000007o`057_l0003o0000o`000?l01Aoo0000o`057`03o`000003o`057ol0003o00DN
00;o00000_l01Al4o`000003o`057ol0003o000000?o000000?o00DNo`000?l000000ol000000ol0
1Ako0000o`000002o`057`06o`000?l01Aoo0000o`000?l01Ako00000_l01Ah3o`000003og:`0?l0
003o000000;o000000?o00HOo`000?l000000ol000000ol01Aoo0000o`000002o`0000;o00DO1?l0
00001?l01Aoo0000o`000?l0001;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
1Oooool002Gooooo00?o0000ooooooooool0AOooool4o`000003o`057_l0003o000000;o00000_l0
1Al4o`000007o`057ol0003o0000o`000?l01Aoo0000o`057`03o`000003o`057ol0003o00DO00;o
00000_l01Ah01Ol0003o00DNo`000?l0003o00DO00Go000000?o00DNo`000?l000000ol000000ol0
1Ako0000olRk0002o`0000;o00DO0_l000001?l01Aoo0000o`057ol01Al2o`000003o`057ol0003o
00DO00?o000000?o00DOo`000?l000000_l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01Oooool002Kooooo00?o0000ooooooooool0A?ooool00ol0003o00DOo`057`02o`00
0003o`057_l0003o00DO00?o000000?o00DOo`000?l01Al00ol000000ol01Aoo0000o`000002o`00
00;o00DO1?l000000ol01Aoo0000o`000003o`000003o`057ol0003o000000;o00DO00Ko0000o`05
7ol0003o0000o`057_l00002o`057P;o000000?o00DNo`000?l000000ol000000ol01Aoo0000o`00
0003o`000003o`057_l0003o000000;o00000_l01Al2o`0005?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`14ooooo`;o000000?o00DN
o`000?l000000ol000000ol01Aoo0000o`000002o`0000;o00DO0_l000000ol01Aoo0000o`057`03
o`000003o`057_l0003o00DN00;o00000_l01Al01Ol0003o00DOo`000?l0003o00DO00Go000000?o
00DNo`000?l000000ol000000ol01Ako0000o`000003o`000006o`057_l0003o0000o`057_l0003o
00DN0ol000000ol01Ako0000o`057`03o`0005Kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`05ooooo`00:?ooool2o`0004Kooooo00?o0000o`057_l000000_l01Ah2o`000003o`05
7ol0003o00HO00?o000000?o00HOo`000?l000000_l00002o`057`Co000000?o00DOo`000?l00000
0ol000000ol01Aoo0000o`000002o`057`06o`000?l01Aoo0000o`000?l01Aoo00000_l01Ah2o`00
0003o`057ol0003o000000?o000000?o00DNo`000?l000000_l00002o`057`Co0000F_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo000Zooooo`03o`000?oooooooooo04Co
oooo1?l000000ol01Ako0000o`000002o`0000;o00HO0_l000000ol01Qoo0000o`057`03o`000003
o`067ol0003o00DO00;o00000_l01Al4o`000003o`057ol0003o000000?o000000?o00HOo`000?l0
00000ol000001?l01Aoo0000o`000?l01Al2o`000006o`057ol0003o0000o`057_l0003o00DO0ol0
001Oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool002_ooooo00?o0000
ooooooooool0@oooool00ol0003o00DNo`057P02o`000003o`057_l0003o000000?o000000?o00HO
o`000?l000000_l00002o`067`Co000000Oo00DOo`000?l0003o0000o`067ol0003o00HO00;o0000
0_l01Ql01_l0003o00HOo`000?l0003o00DOo`0000;o00DO0_l000000ol01Ako0000o`000003o`00
0003o`057_l0003o000000;o0000H_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Cooooo000/ooooo`03o`000?oooooooooo04?ooooo0_l000000ol01Ako0000o`000002o`057P07
o`000?l01Aoo0000o`000?l01Qoo0000o`067`03o`000003o`067ol0003o00HO00;o00000_l01Ql4
o`000003o`067ol0003o000000?o000000?o00DOo`000?l000000ol000001_l01Ako0000o`000?l0
1Ako0000o`057P?o0000Ioooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo
000]ooooo`;o0000AOooool00ol0003o00DNo`000004o`000003o`057ol0003o000000?o000000?o
00HOo`000?l000000_l000001ol01Qoo0000o`000?l0003o00HOo`000?l01Ql00_l00002o`057P05
o`000?l01Aoo0000o`000?l01Ah01Ol000000ol01Ako0000o`000003o`0006[ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`04ooooo`00;oooool00ol0003oooooooooo`13ooooo`05
o`000?l01Ako00DNo`000?l01Ah00_l000001?l01Ako0000o`057ol01Al2o`000003o`057ol0003o
000000?o000000?o00HOo`000?l000000_l000000ol01Ako0000o`000003o`000003o`057_l0003o
000000;o00DN00Co0000o`057_l0003o00001?ooool00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01?ooool0033ooooo00?o0000ooooooooool0@oooool4
o`000003o`057_l0003o000000?o000000Go00DNo`000?l0003o00DNo`000002o`057`;o000000?o
00DOo`000?l01Al00_l00002o`057PCo000000?o00DNo`000?l000000ol0001booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01?ooool0037ooooo00?o0000ooooooooool0@oooool0
1Ol0003o00DNo`000?l0003o00DN00Go000000?o00DNo`000?l000000ol000000ol01Ako0000o`00
0002o`000007o`057_l0003o0000o`000?l01Ako0000o`057P02o`0007Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`04ooooo`00<_ooool2o`0004Cooooo00?o0000o`057_l00000
0_l000000ol01Ako0000o`057P02o`000004o`057_l0003o00DNo`057P;o000000?o00DNo`000?l0
00000_l00002o`057PCo0000Noooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Co
oooo000dooooo`03o`000?oooooooooo04;ooooo00?o0000o`057_l01Ah01?l000000ol01Ako0000
o`000003o`000006o`057_l0003o0000o`057_l0003o00DN0ol0001oooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00oooool003Gooooo00?o0000ooooooooool0@_ooool2o`000003
o`057_l0003o000000;o000000?o00DNo`000?l000000ol000000ol01Ako0000o`000002o`0008?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`00=_ooool00ol0003ooooo
ooooo`13ooooo`04o`000?l01Ako0000o`057P?o000000?o00DNo`000?l01Ah00_l00028ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool003Oooooo00?o0000ooooooooool0
@oooool3o`0000;o00DN1?l0002;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool003Sooooo0_l00013ooooo`03o`000?l01Ako000000;o0000Soooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00?ooooo000jooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool0TOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo000koooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo000looooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool0Toooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo000mooooo`;o0000
?oooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool003oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Dooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool0043ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
047ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2Fooooo`05o`000?oooooooooo
ooooool000001?ooool004;ooooo0_l0000jooooo`03o`000?oooooooooo09Kooooo00Go0000oooo
ooooooooooooo`000004ooooo`00A?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
09Oooooo00Co0000oooooooooooo00001?ooool004Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`2Hooooo`03o`000?oooooo000000Cooooo0016ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0V?ooool01?l0003oooooooooool00003ooooo`00Aoooool2o`0003Go
oooo00?o0000ooooooooool0VOooool00ol0003oooooo`000003ooooo`00BOooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo09[ooooo0_l00003ooooo`00B_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo09[ooooo0ol00003ooooo`00Boooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo09Kooooo1?l00006ooooo`00C?ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo09;ooooo1?l0000:ooooo`00COooool2o`0002kooooo00?o0000oooooooo
ool0S_ooool4o`0000kooooo001?ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
R_ooool4o`0001;ooooo001@ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Qooo
ool3o`0001Kooooo001Aooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Poooool4
o`0001Wooooo001Booooo`;o0000:Oooool00ol0003oooooooooo`1oooooo`Co00007Oooool005Co
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1kooooo`Co00008Oooool005Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1gooooo`Co00009Oooool005Kooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1cooooo`Co0000:Oooool005Oooooo0_l0000T
ooooo`03o`000?oooooooooo06oooooo1?l0000]ooooo`00FOooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo06_ooooo1?l0000aooooo`00F_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo06Oooooo1?l0000eooooo`00Foooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo06?ooooo1?l0000iooooo`00G?ooool2o`0001oooooo00?o0000ooooooooool0H?oo
ool3o`0003gooooo001Nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0G?ooool4
o`00043ooooo001Oooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0F?ooool4o`00
04Cooooo001Pooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0E?ooool4o`0004So
oooo001Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0D?ooool4o`0004cooooo
001Rooooo`;o00006Oooool00ol0003oooooooooo`1<ooooo`Co0000D?ooool006Cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`18ooooo`Co0000E?ooool006Gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`14ooooo`Co0000F?ooool006Kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`10ooooo`Co0000G?ooool006Oooooo0_l0000Dooooo`03o`00
0?oooooooooo03cooooo1?l0001Pooooo`00JOooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo03Sooooo1?l0001Tooooo`00J_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03Gooooo0ol0001Xooooo`00Joooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
037ooooo1?l0001[ooooo`00K?ooool2o`0000kooooo00?o0000ooooooooool0;_ooool4o`0006oo
oooo001^ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:_ooool4o`0007?ooooo
001_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09_ooool4o`0007Oooooo001`
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`0007_ooooo001aoooo
o`;o00002Oooool00ol0003oooooooooo`0Nooooo`Co0000Ooooool007?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Jooooo`Co0000Poooool007Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Fooooo`Co0000Qoooool007Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Booooo`Co0000Roooool007Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0?ooooo`?o0000Soooool007Oooooo0_l00003ooooo`03o`000?oooooooooo
00_ooooo1?l0002Booooo`00NOooool01?l0003oooooooooool00009ooooo`Co0000U_ooool007[o
oooo00?o0000ooooool000001Oooool4o`0009[ooooo001kooooo`;o000000?oooooo`000?l00000
0_l0002Nooooo`00O?ooool2o`000:;ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0013ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`03o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000001?l00002
ooooo`Co00000oooool2o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o
000000Oooooo0ol00002ooooo`?o00001?ooool4o`000005ooooool0003o0000o`000?ooool01_l0
0002ooooo`Go00000_ooool3o`0000;ooooo0ol00009ooooo`?o00001Oooool2o`000003ooooool0
003o000000;o000000Coooooo`000?l0003ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo
0ol00002ooooo`?o000000?oooooo`000?l00000=Oooool004?ooooo00Oo0000oooooooooooooooo
o`000?oooooo000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000foooo
o`00@oooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000002
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo
0ol00003ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004
ooooo`04o`000?ooooooooooooooo`Go00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`00
00Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0dooooo`00@oooool01ol0003ooooooooooooo
oooo0000ooooool000000oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`0000?ooooo
00Co0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000Oooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00002_ooool3o`0000?ooooo00Co
0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooo
oooooooo00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0dooooo`00@oooool01Ol0003oooooo`000?oooooo000000;ooooo
0ol00003ooooo`?o00000_ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooooooool0
0_ooool2o`0000?ooooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l00008ooooo`06o`00
0?oooooo0000ooooool0003ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool4o`00
00?ooooo1?l00002ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000008oooo
o`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00002
ooooo`Co00000_ooool3o`0000Cooooo0ol00002ooooo`Co0000=oooool004?ooooo0_l000000ooo
oooo0000o`00000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Jooooo`05o`000?oooooo0000ooooool000006oooool00ol0003oooooooooo`0D
ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0BOooool004?ooooo00Co0000
oooooooooooooooo0_l00008ooooo`;o00002?ooool3o`0000[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Cooooo`Go00007?ooool2o`0001?ooooo1Ol0000Dooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0@_ooool00?oooooo8Oooool00?oooooo8Oooool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0700433, 0.0550366, \
0.00359627, 0.00359627}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 5\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] {0.1261948886085015`, 
            0.12624689038504655`}\), ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FindPupils \[Rule] Automatic\), 
        ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrequencyCutoff \[Rule] {304.0619384331368`, 
            303.93423730280796`}\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {207.28232192993164`, 0, 0}\), 
        ",", \(ImageSampleSize \[Rule] {0.0016604590606381776`, 
            0.001661143294540086`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(IntensityTransform \[Rule] True\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", 
        RowBox[{"ModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-153.22806346236814`\), 
                  152.0309692165684`}, {\(-153.1637101368481`\), 
                  151.96711865140398`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(NormalizePlot \[Rule] True\), 
        ",", \(NumberOfPoints \[Rule] 128\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 112.44620808978891`\), 
        ",", \(OpticalLengthFunction \[Rule] OpticalLengthFunction\), 
        ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(CompiledFunction[
              If[#1 == 0 && #2 == 0, 
                0.000022271117373179214`, \(-6.853627285348719`\) - 
                  3.532109641994116`*^-9\ Cos[
                      2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                  1.9515319104050795`*^-10\ Cos[
                      4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                  10.310895376241149`\ \((\(-1\) + 
                        0.013990424917235709`\ \((#1\^2 + #2\^2)\))\) - 
                  5.251099192578527`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.020985637375853565`\)\ \
\((#1\^2 + #2\^2)\) + 0.0001957319893648098`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  3.4781206500308235`\ \((1 - 
                        0.04197127475170713`\ \((#1\^2 + #2\^2)\) + 
                        0.0002935979840472147`\ \((#1\^2 + #2\^2)\)\^2)\) + 
                  4.27139394586925`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((\(-0.00024466498670601227`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 2.0537802758321623`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  3.396256590938641`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((0.04197127475170713`\ \((#1\^2 + \
#2\^2)\) - 0.000978659946824049`\ \((#1\^2 + #2\^2)\)\^2 + 
                        5.134450689580406`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  0.02108223618211115`\ \((\(-1\) + 
                        0.08394254950341426`\ \((#1\^2 + #2\^2)\) - 
                        0.0014679899202360734`\ \((#1\^2 + #2\^2)\)\^2 + 
                        6.845934252773875`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  7.380096153526266`*^-8\ Cos[
                      6\ ArcTan[#1, #2]]\ \((\(-2.396076988470856`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 1.9155505830353006`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  3.180054365542885`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((0.0007339949601180367`\ \((#1\^2 \
+ #2\^2)\)\^2 - 0.000014376461930825136`\ \((#1\^2 + #2\^2)\)\^3 + 
                        6.704427040623552`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  1.291385970907799`*^-7\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.06995212458617854`\)\ \((#1\
\^2 + #2\^2)\) + 0.0029359798404721468`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00003594115482706284`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.3408854081247104`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.0002074059263440704`\ \((1 - 
                        0.13990424917235708`\ \((#1\^2 + #2\^2)\) + 
                        0.00440396976070822`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00004792153976941712`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.6761067601558881`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
              "-CompiledCode-"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {112.43537240553266`, 
            112.44620808978891`}\), ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      SurfaceGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      SurfaceGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      SurfaceGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      SurfaceGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PerfectModulationTransferFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      SurfaceGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"ModulationTransferFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      SurfaceGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PaddingFactor \[Rule] Automatic\), 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
        RowBox[{"PerfectModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-153.22806346236814`\), 
                  152.0309692165684`}, {\(-153.1637101368481`\), 
                  151.96711865140398`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPhaseTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-153.22806346236814`\), 
                  152.0309692165684`}, {\(-153.1637101368481`\), 
                  151.96711865140398`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.10460892082020519`\), 
                  0.10626937988084338`}, {\(-0.10465202755602541`\), 
                  0.1063131708505655`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PhaseTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-153.22806346236814`\), 
                  152.0309692165684`}, {\(-153.1637101368481`\), 
                  151.96711865140398`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] False\), 
        ",", \(PlotPoints \[Rule] 64\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.10460892082020519`\), 
                  0.10626937988084338`}, {\(-0.10465202755602541`\), 
                  0.1063131708505655`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(RayBoundary \[Rule] {{\(-8.4562214163056`\), 
              8.4562214163056`}, {\(-8.452646568455712`\), 
              8.452646568455712`}}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {ModulationTransferFunction, 
            PointSpreadFunction, OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), 
        ",", \(ResidualFitError \[Rule] 7.313862904893167`*^-7\), 
        ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
              82.9255011275954`, Astigmatism \[Rule] 0.0000417323567305451`, 
            FieldCurvature \[Rule] \(-0.24683256227325023`\), 
            Distortion \[Rule] \(-3.777962952267033`*^-13\), 
            Coma \[Rule] 1.3460273542456333`*^-12}\), 
        ",", \(ShowPerfectCase \[Rule] True\), 
        ",", \(SignalPlotCutoff \[Rule] 0.01`\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 584\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.015686737510906584`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-11.347295107870586`\), 
                  11.347295107870586`}, {\(-11.343720260020696`\), 
                  11.343720260020696`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[77]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
OpticalTransferFunction[offaxis3D, FindImagePoint->True, NumberOfPoints->512]\
\
\>", "Input",
  CellLabel->"In[81]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0575887 -0.574152 3.02406 [
[.06808 -0.0125 -12 -9 ]
[.06808 -0.0125 12 0 ]
[.21206 -0.0125 -6 -9 ]
[.21206 -0.0125 6 0 ]
[.35603 -0.0125 -12 -9 ]
[.35603 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64397 -0.0125 -9 -9 ]
[.64397 -0.0125 9 0 ]
[.78794 -0.0125 -3 -9 ]
[.78794 -0.0125 3 0 ]
[.93192 -0.0125 -9 -9 ]
[.93192 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03066 -18 -4.5 ]
[-0.0125 .03066 0 4.5 ]
[-0.0125 .18186 -24 -4.5 ]
[-0.0125 .18186 0 4.5 ]
[-0.0125 .33307 -18 -4.5 ]
[-0.0125 .33307 0 4.5 ]
[-0.0125 .48427 -24 -4.5 ]
[-0.0125 .48427 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -60 0 ]
[.5 .63053 60 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06808 0 m
.06808 .00625 L
s
[(-7.5)] .06808 -0.0125 0 1 Mshowa
.21206 0 m
.21206 .00625 L
s
[(-5)] .21206 -0.0125 0 1 Mshowa
.35603 0 m
.35603 .00625 L
s
[(-2.5)] .35603 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64397 0 m
.64397 .00625 L
s
[(2.5)] .64397 -0.0125 0 1 Mshowa
.78794 0 m
.78794 .00625 L
s
[(5)] .78794 -0.0125 0 1 Mshowa
.93192 0 m
.93192 .00625 L
s
[(7.5)] .93192 -0.0125 0 1 Mshowa
.125 Mabswid
.09688 0 m
.09688 .00375 L
s
.12567 0 m
.12567 .00375 L
s
.15447 0 m
.15447 .00375 L
s
.18326 0 m
.18326 .00375 L
s
.24085 0 m
.24085 .00375 L
s
.26965 0 m
.26965 .00375 L
s
.29844 0 m
.29844 .00375 L
s
.32723 0 m
.32723 .00375 L
s
.38482 0 m
.38482 .00375 L
s
.41362 0 m
.41362 .00375 L
s
.44241 0 m
.44241 .00375 L
s
.47121 0 m
.47121 .00375 L
s
.52879 0 m
.52879 .00375 L
s
.55759 0 m
.55759 .00375 L
s
.58638 0 m
.58638 .00375 L
s
.61518 0 m
.61518 .00375 L
s
.67277 0 m
.67277 .00375 L
s
.70156 0 m
.70156 .00375 L
s
.73035 0 m
.73035 .00375 L
s
.75915 0 m
.75915 .00375 L
s
.81674 0 m
.81674 .00375 L
s
.84553 0 m
.84553 .00375 L
s
.87433 0 m
.87433 .00375 L
s
.90312 0 m
.90312 .00375 L
s
.03929 0 m
.03929 .00375 L
s
.0105 0 m
.0105 .00375 L
s
.96071 0 m
.96071 .00375 L
s
.9895 0 m
.9895 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03066 m
.00625 .03066 L
s
[(0.2)] -0.0125 .03066 1 0 Mshowa
0 .18186 m
.00625 .18186 L
s
[(0.25)] -0.0125 .18186 1 0 Mshowa
0 .33307 m
.00625 .33307 L
s
[(0.3)] -0.0125 .33307 1 0 Mshowa
0 .48427 m
.00625 .48427 L
s
[(0.35)] -0.0125 .48427 1 0 Mshowa
.125 Mabswid
0 .0609 m
.00375 .0609 L
s
0 .09114 m
.00375 .09114 L
s
0 .12138 m
.00375 .12138 L
s
0 .15162 m
.00375 .15162 L
s
0 .21211 m
.00375 .21211 L
s
0 .24235 m
.00375 .24235 L
s
0 .27259 m
.00375 .27259 L
s
0 .30283 m
.00375 .30283 L
s
0 .36331 m
.00375 .36331 L
s
0 .39355 m
.00375 .39355 L
s
0 .42379 m
.00375 .42379 L
s
0 .45403 m
.00375 .45403 L
s
0 .00042 m
.00375 .00042 L
s
0 .51451 m
.00375 .51451 L
s
0 .54475 m
.00375 .54475 L
s
0 .57499 m
.00375 .57499 L
s
0 .60523 m
.00375 .60523 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.06808 .61178 m
.06808 .61803 L
s
.21206 .61178 m
.21206 .61803 L
s
.35603 .61178 m
.35603 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64397 .61178 m
.64397 .61803 L
s
.78794 .61178 m
.78794 .61803 L
s
.93192 .61178 m
.93192 .61803 L
s
.125 Mabswid
.09688 .61428 m
.09688 .61803 L
s
.12567 .61428 m
.12567 .61803 L
s
.15447 .61428 m
.15447 .61803 L
s
.18326 .61428 m
.18326 .61803 L
s
.24085 .61428 m
.24085 .61803 L
s
.26965 .61428 m
.26965 .61803 L
s
.29844 .61428 m
.29844 .61803 L
s
.32723 .61428 m
.32723 .61803 L
s
.38482 .61428 m
.38482 .61803 L
s
.41362 .61428 m
.41362 .61803 L
s
.44241 .61428 m
.44241 .61803 L
s
.47121 .61428 m
.47121 .61803 L
s
.52879 .61428 m
.52879 .61803 L
s
.55759 .61428 m
.55759 .61803 L
s
.58638 .61428 m
.58638 .61803 L
s
.61518 .61428 m
.61518 .61803 L
s
.67277 .61428 m
.67277 .61803 L
s
.70156 .61428 m
.70156 .61803 L
s
.73035 .61428 m
.73035 .61803 L
s
.75915 .61428 m
.75915 .61803 L
s
.81674 .61428 m
.81674 .61803 L
s
.84553 .61428 m
.84553 .61803 L
s
.87433 .61428 m
.87433 .61803 L
s
.90312 .61428 m
.90312 .61803 L
s
.03929 .61428 m
.03929 .61803 L
s
.0105 .61428 m
.0105 .61803 L
s
.96071 .61428 m
.96071 .61803 L
s
.9895 .61428 m
.9895 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03066 m
1 .03066 L
s
.99375 .18186 m
1 .18186 L
s
.99375 .33307 m
1 .33307 L
s
.99375 .48427 m
1 .48427 L
s
.125 Mabswid
.99625 .0609 m
1 .0609 L
s
.99625 .09114 m
1 .09114 L
s
.99625 .12138 m
1 .12138 L
s
.99625 .15162 m
1 .15162 L
s
.99625 .21211 m
1 .21211 L
s
.99625 .24235 m
1 .24235 L
s
.99625 .27259 m
1 .27259 L
s
.99625 .30283 m
1 .30283 L
s
.99625 .36331 m
1 .36331 L
s
.99625 .39355 m
1 .39355 L
s
.99625 .42379 m
1 .42379 L
s
.99625 .45403 m
1 .45403 L
s
.99625 .00042 m
1 .00042 L
s
.99625 .51451 m
1 .51451 L
s
.99625 .54475 m
1 .54475 L
s
.99625 .57499 m
1 .57499 L
s
.99625 .60523 m
1 .60523 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Wave Front Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.03853 .13835 L
.04619 .19066 L
.05458 .24153 L
.06238 .27605 L
.06965 .30417 L
.07058 .30777 L
.07157 .31158 L
.07182 .31254 L
.07209 .31316 L
.07238 .31379 L
.07265 .31438 L
.07365 .31653 L
.07743 .32467 L
.08451 .3399 L
.08637 .34391 L
.08691 .34507 L
.08717 .3456 L
.08741 .34586 L
.08787 .34635 L
.08836 .34689 L
.09054 .34925 L
.09256 .35145 L
.09652 .35574 L
.10021 .35975 L
.10106 .36067 L
.10199 .36168 L
.10241 .36214 L
.10287 .36239 L
.10367 .36282 L
.10561 .36386 L
.10738 .3648 L
.11526 .369 L
.12267 .37181 L
.12964 .37391 L
.14438 .37739 L
.16005 .38053 L
.17514 .38339 L
.18966 .38615 L
.20511 .3891 L
.21999 .39198 L
.23579 .39507 L
.25103 .3981 L
.26568 .40104 L
.28127 .4042 L
.29628 .40731 L
.31071 .41033 L
.32608 .4136 L
.34087 .4168 L
.35659 .42028 L
Mistroke
.37174 .42366 L
.38631 .42698 L
.40181 .43057 L
.41674 .43409 L
.4326 .4379 L
.44788 .44165 L
.46259 .44531 L
.47823 .44931 L
.49329 .45322 L
.50778 .45707 L
.5232 .46125 L
.53804 .46537 L
.55382 .46984 L
.56902 .47426 L
.58364 .47861 L
.59919 .48334 L
.61417 .48804 L
.62857 .49265 L
.64391 .4977 L
.65867 .50268 L
.67436 .50811 L
.68947 .51349 L
.70401 .51881 L
.71948 .52464 L
.73438 .53041 L
.75021 .53674 L
.76546 .54303 L
.78013 .54928 L
.79574 .55613 L
.81077 .56298 L
.82522 .56976 L
.84061 .57724 L
.85542 .5846 L
.87116 .59241 L
.87904 .59617 L
.88633 .59917 L
.8934 .60171 L
.89512 .60232 L
.89602 .60265 L
.89697 .60299 L
.89722 .60308 L
.89748 .60317 L
.89777 .6032 L
.89804 .60321 L
.89901 .60321 L
.90092 .60323 L
.90482 .60326 L
.90687 .60328 L
.90904 .60329 L
.91094 .60331 L
Mistroke
.91146 .60331 L
.91202 .60331 L
.91229 .60332 L
.91255 .60332 L
.91303 .60318 L
.91348 .60283 L
.91395 .60245 L
.9148 .60176 L
.91672 .60022 L
.92064 .59706 L
.92488 .59365 L
.92683 .59208 L
.9273 .5917 L
.92781 .59129 L
.9281 .59106 L
.92836 .59052 L
.92888 .5893 L
.93257 .58064 L
.93639 .57164 L
.94046 .56209 L
.94213 .55816 L
.943 .5561 L
.94344 .55507 L
.94392 .55278 L
.94495 .54788 L
.9459 .54339 L
.94775 .53458 L
.95482 .50098 L
.96236 .45427 L
.97619 .34105 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Joooo
o`?o00006_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001Sooooo0_l0000Joooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006oooool3o`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00004_ooool002kooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00000J
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Fooooo`04o`00
0?ooooooooooo`0001[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Wooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Aooooo`009_ooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003oooooooooo`0Aooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo0000
6oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo000_ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0000Looooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03oooool0033ooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo1?l0000Jooooo`05o`000?ooooooooooooooool000001oooool4o`0001Oooooo
00Co0000oooooooooooo00006Oooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Joooo
o`Co00007Oooool00ol0003oooooooooo`05ooooo`Co00004_ooool002cooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0
000Iooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01?o
oooo000/ooooo`Go00001oooool5o`0001Sooooo1Ol0000Jooooo`?o00002?ooool5o`0001Oooooo
0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol0000Hooooo`Go00001oooool5o`00017ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000QooooooSo0000
1oooool0027ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`008Ooo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Ooo
ool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool000ko
oooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool01Oooool000gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04
ooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07Sooooo0_l00007
ooooo`003Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool01Oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool000kooooo0_l0
0009ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`00
8Oooool2o`0000Gooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1hooooo`;o0000
1oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07Wooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo0_l00006
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0N?ooool2o`0000Oooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1ioooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Go
oooo000Qooooo`;o00001oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo07Sooooo
0_l00007ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000oooo
ooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`00
8Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool2
o`0000Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1hooooo`;o00001oooool0
027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo07Wooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool000Sooooo0_l00004
ooooo`04o`000?ooooooooooooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Ooo
ool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`001oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`05ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`1hooooo`;o00001oooool000Oooooo00Co0000oooooooooooo00001oooool01_l0003o
oooooooooooooooo0000ooooo`Co00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`001oooool01?l0
003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000008ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooooooo00Gooooo0008ooooo`;o00002Oooool3o`0000;ooooo1Ol00004ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1iooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00002_ooool00ol0003ooooo
ooooo`1/ooooo`03o`000?oooooooooo07Sooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo06_ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool2o`00
00_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1hooooo`;o00001oooool0027o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000=ooooo`03o`00
0?oooooooooo06Wooooo00?o0000ooooooooool0N?ooool2o`0000Oooooo000Qooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1iooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`;o00003oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo07Sooooo0_l00007oooo
o`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`05ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo
oooo07Wooooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool000gooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000=
ooooo`04o`000?ooooooooooo`0000Wooooo0_l00005ooooo`;o00004_ooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo07Sooooo0_l00007ooooo`003Oooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool000gooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`003_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oo
oooooooo01;ooooo0_l0001Tooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`008Oooool2o`0001Oooooo
0_l0001Pooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo
000Qooooo`03o`000?oooooooooo01Oooooo0_l0001Oooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0I
ooooo`;o0000GOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool0027ooooo00?o0000ooooooooool06oooool5o`0005Sooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo023ooooo1?l0001Dooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Tooooo`Oo0000
COooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool0027ooooo00?o0000ooooooooool0:oooool4o`0004Wooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo02oooooo1?l00015ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`008Oooool2o`0003Cooooo1ol0000nooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool00oooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo03[o
oooo1?l0000jooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0nooooo`Co0000=_ooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool0@_ooool7o`0002oooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo04Wooooo1?l0000[
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`1=ooooo`?o0000:?ooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooooooo
ool0D?ooool4o`0002Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo000Qooooo`;o0000EOooool8o`0001cooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`04ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0G?oo
ool3o`0001Wooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo05oooooo1?l0000Eooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0
003oooooooooo`1Sooooo`Co00004Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0Ioooool4o`0000go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo000Qooooo`03o`000?oooooooooo06_ooooo1?l00009ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooooooo
o`1_ooooo`?o00001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0L_ooool4o`0000;ooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`;o0000Moooool4o`00077ooooo00?o0000ooooooooool01Oooool2o`0000Oooooo000Qooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooool000000_l0001^ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0N?ooool00ol0003ooooo
ooooo`02ooooo`Co0000J_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool01_ooool4o`0006Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1h
ooooo`03o`000?oooooooooo00[ooooo1?l0001Qooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00003oooo
o`?o00001Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00kooooo1?l0001Moooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooo
oooo00001oooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool04_ooool3o`0005[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0007Wooooo00?o
0000ooooooooool05Oooool4o`0005Kooooo00?o0000ooooooooool01_ooool2o`0000Oooooo0007
ooooo`04o`000?ooooooooooo`0000Wooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`0Iooooo`Co0000D_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooool000000ol00005ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool07Ooo
ool2o`0004oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`001oooool0
1?l0003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000008ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool07oooool2o`0004gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Wooooo0ol00002ooooo`Go0000
1?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo027ooooo0ol0001:ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`0Tooooo`Co0000A_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0:?ooool3
o`0004?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000NOooool00ol0003o
ooooooooo`0/ooooo`?o0000?_ooool00ol0003oooooooooo`08ooooo`;o00001oooool0027ooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0_ooooo`Co0000>_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool0<oooool3o`0003Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0=oooool3o`0003;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo03[ooooo0ol0000_ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0mooooo`;o0000
;Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000NOoo
ool00ol0003oooooooooo`0oooooo`?o0000:_ooool00ol0003oooooooooo`09ooooo`;o00001ooo
ool0027ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`12ooooo`?o00009_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool0AOooool2o`0002Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo04Oo
oooo0_l0000Rooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo04[ooooo0ol0000Mooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1=
ooooo`?o00006_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0D?ooool2o`0001Oooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`05ooooo`008Oooool2o`0007Wooooo00?o0000oooooooo
ool0D_ooool2o`0001Gooooo00?o0000ooooooooool03?ooool2o`0000Oooooo000Qooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`1Eooooo`;o00004Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0Eoooool2
o`0000kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo05Wooooo0_l0000;ooooo`;o00004Oooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo05_o
oooo0_l00008ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1Mooooo`?o00001?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000NOooool00ol0003ooooooooo
o`1Oooooo`Ko00004oooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooo`000007oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000Oooooo000QooooooSo00001oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00=;ooooo0ol0001;ooooo`00doooool00ol0003oooooooooo`1:oooo
o`00HOooool00ol0003oooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o
00002?ooool3o`0000?ooooo0ol00004ooooo`?o00000_ooool3o`000003ooooool0003o000000;o
oooo0_l00008ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003oooo
o`?o00000_ooool3o`000003ooooool0003o000000Co00000_ooool5o`0000?ooooo0_l00004oooo
o`03o`000?oooooooooo04Wooooo001Qooooo`03o`000?oooooo000000;ooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003ooooooooo
ool00005ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo04Wooooo001Qooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`03
o`000?oooooo000000;ooooo1Ol00008ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`?o0000
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
B_ooool0063ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000008ooooo`?o00000ooo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000
oooooooooooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`00001:ooooo`00H?ooool01Ol0003oooooo`000?oooooo000000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Wooooo00?o0000ooooooooool0
0_ooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`Co00000_ooool4o`0000[ooooo
00Co0000oooooooooooooooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co
000000Coooooo`000?l0003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000019oooo
o`00H?ooool01Ol0003oooooo`000?oooooo000001[ooooo00Co0000oooooooooooo00005?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1@ooooo`00H?ooool6o`0001Sooooo1Ol0000Dooooo`03o`000?oooooooooo
00Sooooo1Ol00008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.0287, 0.173686, \
0.0702541, 0.00133789}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0575887 0.0867605 0.0128685 [
[.06808 -0.0125 -12 -9 ]
[.06808 -0.0125 12 0 ]
[.21206 -0.0125 -6 -9 ]
[.21206 -0.0125 6 0 ]
[.35603 -0.0125 -12 -9 ]
[.35603 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64397 -0.0125 -9 -9 ]
[.64397 -0.0125 9 0 ]
[.78794 -0.0125 -3 -9 ]
[.78794 -0.0125 3 0 ]
[.93192 -0.0125 -9 -9 ]
[.93192 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08676 -6 -4.5 ]
[-0.0125 .08676 0 4.5 ]
[-0.0125 .21545 -12 -4.5 ]
[-0.0125 .21545 0 4.5 ]
[-0.0125 .34413 -12 -4.5 ]
[-0.0125 .34413 0 4.5 ]
[-0.0125 .47282 -12 -4.5 ]
[-0.0125 .47282 0 4.5 ]
[-0.0125 .6015 -12 -4.5 ]
[-0.0125 .6015 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06808 0 m
.06808 .00625 L
s
[(-7.5)] .06808 -0.0125 0 1 Mshowa
.21206 0 m
.21206 .00625 L
s
[(-5)] .21206 -0.0125 0 1 Mshowa
.35603 0 m
.35603 .00625 L
s
[(-2.5)] .35603 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64397 0 m
.64397 .00625 L
s
[(2.5)] .64397 -0.0125 0 1 Mshowa
.78794 0 m
.78794 .00625 L
s
[(5)] .78794 -0.0125 0 1 Mshowa
.93192 0 m
.93192 .00625 L
s
[(7.5)] .93192 -0.0125 0 1 Mshowa
.125 Mabswid
.09688 0 m
.09688 .00375 L
s
.12567 0 m
.12567 .00375 L
s
.15447 0 m
.15447 .00375 L
s
.18326 0 m
.18326 .00375 L
s
.24085 0 m
.24085 .00375 L
s
.26965 0 m
.26965 .00375 L
s
.29844 0 m
.29844 .00375 L
s
.32723 0 m
.32723 .00375 L
s
.38482 0 m
.38482 .00375 L
s
.41362 0 m
.41362 .00375 L
s
.44241 0 m
.44241 .00375 L
s
.47121 0 m
.47121 .00375 L
s
.52879 0 m
.52879 .00375 L
s
.55759 0 m
.55759 .00375 L
s
.58638 0 m
.58638 .00375 L
s
.61518 0 m
.61518 .00375 L
s
.67277 0 m
.67277 .00375 L
s
.70156 0 m
.70156 .00375 L
s
.73035 0 m
.73035 .00375 L
s
.75915 0 m
.75915 .00375 L
s
.81674 0 m
.81674 .00375 L
s
.84553 0 m
.84553 .00375 L
s
.87433 0 m
.87433 .00375 L
s
.90312 0 m
.90312 .00375 L
s
.03929 0 m
.03929 .00375 L
s
.0105 0 m
.0105 .00375 L
s
.96071 0 m
.96071 .00375 L
s
.9895 0 m
.9895 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08676 m
.00625 .08676 L
s
[(0)] -0.0125 .08676 1 0 Mshowa
0 .21545 m
.00625 .21545 L
s
[(10)] -0.0125 .21545 1 0 Mshowa
0 .34413 m
.00625 .34413 L
s
[(20)] -0.0125 .34413 1 0 Mshowa
0 .47282 m
.00625 .47282 L
s
[(30)] -0.0125 .47282 1 0 Mshowa
0 .6015 m
.00625 .6015 L
s
[(40)] -0.0125 .6015 1 0 Mshowa
.125 Mabswid
0 .1125 m
.00375 .1125 L
s
0 .13823 m
.00375 .13823 L
s
0 .16397 m
.00375 .16397 L
s
0 .18971 m
.00375 .18971 L
s
0 .24118 m
.00375 .24118 L
s
0 .26692 m
.00375 .26692 L
s
0 .29266 m
.00375 .29266 L
s
0 .31839 m
.00375 .31839 L
s
0 .36987 m
.00375 .36987 L
s
0 .3956 m
.00375 .3956 L
s
0 .42134 m
.00375 .42134 L
s
0 .44708 m
.00375 .44708 L
s
0 .49855 m
.00375 .49855 L
s
0 .52429 m
.00375 .52429 L
s
0 .55003 m
.00375 .55003 L
s
0 .57576 m
.00375 .57576 L
s
0 .06102 m
.00375 .06102 L
s
0 .03529 m
.00375 .03529 L
s
0 .00955 m
.00375 .00955 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.06808 .61178 m
.06808 .61803 L
s
.21206 .61178 m
.21206 .61803 L
s
.35603 .61178 m
.35603 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64397 .61178 m
.64397 .61803 L
s
.78794 .61178 m
.78794 .61803 L
s
.93192 .61178 m
.93192 .61803 L
s
.125 Mabswid
.09688 .61428 m
.09688 .61803 L
s
.12567 .61428 m
.12567 .61803 L
s
.15447 .61428 m
.15447 .61803 L
s
.18326 .61428 m
.18326 .61803 L
s
.24085 .61428 m
.24085 .61803 L
s
.26965 .61428 m
.26965 .61803 L
s
.29844 .61428 m
.29844 .61803 L
s
.32723 .61428 m
.32723 .61803 L
s
.38482 .61428 m
.38482 .61803 L
s
.41362 .61428 m
.41362 .61803 L
s
.44241 .61428 m
.44241 .61803 L
s
.47121 .61428 m
.47121 .61803 L
s
.52879 .61428 m
.52879 .61803 L
s
.55759 .61428 m
.55759 .61803 L
s
.58638 .61428 m
.58638 .61803 L
s
.61518 .61428 m
.61518 .61803 L
s
.67277 .61428 m
.67277 .61803 L
s
.70156 .61428 m
.70156 .61803 L
s
.73035 .61428 m
.73035 .61803 L
s
.75915 .61428 m
.75915 .61803 L
s
.81674 .61428 m
.81674 .61803 L
s
.84553 .61428 m
.84553 .61803 L
s
.87433 .61428 m
.87433 .61803 L
s
.90312 .61428 m
.90312 .61803 L
s
.03929 .61428 m
.03929 .61803 L
s
.0105 .61428 m
.0105 .61803 L
s
.96071 .61428 m
.96071 .61803 L
s
.9895 .61428 m
.9895 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08676 m
1 .08676 L
s
.99375 .21545 m
1 .21545 L
s
.99375 .34413 m
1 .34413 L
s
.99375 .47282 m
1 .47282 L
s
.99375 .6015 m
1 .6015 L
s
.125 Mabswid
.99625 .1125 m
1 .1125 L
s
.99625 .13823 m
1 .13823 L
s
.99625 .16397 m
1 .16397 L
s
.99625 .18971 m
1 .18971 L
s
.99625 .24118 m
1 .24118 L
s
.99625 .26692 m
1 .26692 L
s
.99625 .29266 m
1 .29266 L
s
.99625 .31839 m
1 .31839 L
s
.99625 .36987 m
1 .36987 L
s
.99625 .3956 m
1 .3956 L
s
.99625 .42134 m
1 .42134 L
s
.99625 .44708 m
1 .44708 L
s
.99625 .49855 m
1 .49855 L
s
.99625 .52429 m
1 .52429 L
s
.99625 .55003 m
1 .55003 L
s
.99625 .57576 m
1 .57576 L
s
.99625 .06102 m
1 .06102 L
s
.99625 .03529 m
1 .03529 L
s
.99625 .00955 m
1 .00955 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .08676 m
1 .08676 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .50339 m
.03853 .53282 L
.05458 .55843 L
.06965 .57677 L
.08415 .58958 L
.09161 .59445 L
.09958 .59843 L
.10348 .59993 L
.1077 .60124 L
.11169 .60217 L
.11537 .60279 L
.11715 .603 L
.11813 .60309 L
.11906 .60317 L
.11992 .60322 L
.12037 .60325 L
.12086 .60327 L
.12131 .60329 L
.12171 .6033 L
.12212 .60331 L
.12251 .60331 L
.12296 .60332 L
.12346 .60332 L
.12371 .60332 L
.12398 .60332 L
.12447 .60331 L
.12496 .6033 L
.12542 .60328 L
.12628 .60325 L
.1273 .60319 L
.12824 .60312 L
.13036 .60291 L
.13213 .60269 L
.13403 .60239 L
.13747 .60171 L
.14157 .60067 L
.14532 .59949 L
.15314 .5964 L
.16042 .59278 L
.17493 .58354 L
.18981 .57152 L
.20562 .55624 L
.22085 .53936 L
.2355 .5214 L
.25109 .50069 L
.2661 .47945 L
.28053 .45802 L
.2959 .43436 L
.31069 .41096 L
.32642 .38563 L
Mistroke
.34156 .36097 L
.35613 .33719 L
.37164 .31199 L
.38656 .28799 L
.40242 .26292 L
.41771 .23935 L
.43241 .21732 L
.44805 .19473 L
.46312 .17389 L
.4776 .1548 L
.49302 .13559 L
.50786 .11826 L
.52364 .10116 L
.53884 .08604 L
.55346 .07281 L
.56902 .06017 L
.58399 .04944 L
.5984 .04049 L
.61373 .03243 L
.62849 .02612 L
.63599 .02345 L
.64418 .02094 L
.65211 .01893 L
.6593 .01745 L
.66678 .01625 L
.67089 .01574 L
.67477 .01535 L
.67848 .01507 L
.68035 .01496 L
.68241 .01486 L
.68416 .0148 L
.68515 .01477 L
.68604 .01475 L
.68688 .01473 L
.68735 .01473 L
.68779 .01472 L
.68817 .01472 L
.68859 .01472 L
.68903 .01472 L
.68944 .01472 L
.68989 .01472 L
.69037 .01472 L
.69082 .01472 L
.69123 .01472 L
.69171 .01473 L
.69223 .01474 L
.69318 .01476 L
.69418 .01478 L
.69523 .01481 L
.69712 .01489 L
Mistroke
.70047 .01507 L
.70417 .01535 L
.71157 .01613 L
.71952 .01731 L
.73523 .02061 L
.75037 .02495 L
.76493 .03009 L
.78042 .03651 L
.79533 .04348 L
.81118 .05159 L
.82645 .05994 L
.84115 .0683 L
.85677 .07735 L
.87182 .08603 L
.8863 .09412 L
.9017 .10223 L
.91653 .10931 L
.9323 .11574 L
.94019 .11843 L
.94749 .12056 L
.95443 .12223 L
.95812 .12296 L
.96209 .12361 L
.96589 .12411 L
.96755 .12429 L
.96937 .12446 L
.97097 .12458 L
.97269 .12468 L
.97364 .12472 L
.9745 .12475 L
.97492 .12476 L
.97537 .12478 L
.97619 .12479 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Joooo
o`?o00006_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001Sooooo0_l0000Joooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006oooool3o`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00006?ooool002Sooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00000J
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Fooooo`04o`00
0?ooooooooooo`0001[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Wooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Gooooo`008?ooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003oooooooooo`0Aooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo0000
6oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo000Yooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0000Looooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool05Oooool002[ooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo1?l0000Jooooo`05o`000?ooooooooooooooool000001oooool4o`0001Oooooo
00Co0000oooooooooooo00006Oooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Joooo
o`Co00007Oooool00ol0003oooooooooo`05ooooo`Co00006?ooool002Kooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0
000Iooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Wo
oooo000Vooooo`Go00001oooool5o`0001Sooooo1Ol0000Jooooo`?o00002?ooool5o`0001Oooooo
0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol0000Hooooo`Go00001oooool5o`0001Oooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000KooooooSo0000
3Oooool001_ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000=ooooo`006ooo
ool2o`0007Wooooo00?o0000ooooooooool0N?ooool2o`0000gooooo000Kooooo`03o`000?oooooo
oooo07Sooooo00?o0000ooooooooool0:Oooool9o`0004Oooooo00?o0000ooooooooool02oooool0
01_ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Rooooo`Oo00002Oooool5o`00
04;ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`0Nooooo`Co00005Oooool4o`0003kooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Looooo`;o00007Oooool3o`0003_ooooo
00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo023ooooo0ol0000hooooo`03o`000?oooooooooo00_ooooo000K
ooooo`;o0000NOooool00ol0003oooooooooo`0Iooooo`;o00009_ooool2o`0003Gooooo0_l0000=
ooooo`006oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo01Oooooo0_l0000Zoooo
o`?o0000<oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo01Gooooo0_l0000_ooooo`;o0000<Oooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo01?ooooo0_l0000cooooo`;o0000
;oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0=Oooool2o`0002gooooo00?o0000ooooooooool02ooo
ool001_ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo03Sooooo0_l0000[ooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0kooooo`;o0000:Oooool00ol0
003oooooooooo`0;ooooo`006oooool2o`0007Wooooo00?o0000ooooooooool03_ooool2o`00043o
oooo00?o0000ooooooooool09Oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo04?ooooo0_l0000Uooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02_ooool2o`0004Sooooo0_l0000S
ooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`1hoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0B_ooool2o`00027ooooo00?o0000oooo
ooooool02oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1hoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooon?l0000=oooo
o`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Booooo`;o00007?ooool00ol0003oooooooooo`0;oooo
o`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Eooooo`;o00006_ooool00ol0003oooooooooo`0;oooo
o`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Hooooo`;o00006?ooool00ol0003oooooooooo`0;oooo
o`005?ooool2o`0000Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05_ooooo0_l0000Fooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02oooool001_ooooo0_l0001iooooo`05o`000?oo
ooooooooooooool00000H_ooool3o`00017ooooo0_l0000=ooooo`006oooool00ol0003ooooooooo
o`1hooooo`04o`000?ooooooooooo`0006Kooooo0ol0000?ooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo07Sooooo00?o0000ooooool00000J_ooool4o`0000_ooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0N?ooool00ol0003oooooo`00001^
ooooo`Ko00001Oooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1hoooo
o`;o0000N_ooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
Moooool2o`0007_ooooo00?o0000ooooooooool02oooool001_ooooo0_l0001hooooo`;o0000N_oo
ool2o`0000gooooo000Kooooo`03o`000?oooooooooo07Kooooo00?o0000ooooool00000Noooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1eooooo`04o`000?oooooooooo
o`0007_ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0M?ooool01Ol0
003ooooooooooooooooo000007_ooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool02oooool001_ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool001_ooooo0_l0001cooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0N?ooool2o`0000gooooo000Kooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`;o0000K_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo07Sooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1/oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0;ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooooooo00_ooooo000>ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`0;ooooo`003_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool02oooool000kooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00004ooooo`;o0000JOooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo07Sooooo0_l0000=ooooo`003_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool02oooool000gooooo0_l00004ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool02oooool000kooooo00?o0000ooooooooool00ooo
ool2o`0000Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool0
01_ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool02oooool001_ooooo0_l0001Uooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0N?ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Koooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1ioooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooooooo00_ooooo000Kooooo`;o0000HOooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo07Sooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0NOooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`006oooool2o`0005gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`1hooooo`;o00003Oooool001_ooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool02oooool001_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0
F_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
2oooool001_ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool0
01_ooooo0_l0001Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0N?ooool2o`00
00gooooo000Kooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo05Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00_ooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000
ooooooooool0E_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00_ooooo000>ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`003oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_ooool2o`0005Gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`1hooooo`;o00003Oooool000cooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool000cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool02oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`006oooool2o`00
057ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1hooooo`;o00003Oooool001_o
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool001_ooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool02oooool001_ooooo0_l0001>ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0N?ooool2o`0000gooooo000Kooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1iooooo`03o`000?oo
oooooooo00_ooooo000Kooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo
000Kooooo`;o0000BOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo07Sooooo0_l0
000=ooooo`006oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;oooo
o`006oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`006ooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`0;ooooo`006oooool2o`0004Gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`1hooooo`;o00003Oooool001_ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool001_o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`003?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
2oooool000kooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo0_l00011ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0N?ooool2o`0000gooooo000@ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`003?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`0;ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo
000Kooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Koooo
o`;o0000??ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo07Sooooo0_l0000=oooo
o`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
oooo00_ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool001_o
oooo0_l00006ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`1hooooo`;o00003Oooool001_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0NOooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000K
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool001_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool0NOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1iooooo`03
o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
2oooool001_ooooo0_l0000:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`1hooooo`;o00003Oooool001_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0NOooool0
0ol0003oooooooooo`0;ooooo`006oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00_ooooo000Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02oooool001_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`006oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01_ooooo0_l0001;ooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool02oooool001_ooooo0_l0000?ooooo`;o00006_ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo07Sooooo0_l0000=ooooo`006oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1ioooo
o`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04oooool2o`0004oooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`00
6oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000>ooooo`?o00000ooo
ool2o`0000Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`;o0000D_oo
ool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000?ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo0_l0
000<ooooo`;o0000E?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000<
ooooo`Go00000_ooool01?l0003oooooooooool00004ooooo`;o00005oooool4o`0000Gooooo0ol0
001Fooooo`03o`000?oooooooooo07Sooooo0_l0000=ooooo`003?ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool06Oooool6o`0005Wooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`003Oooool00ol0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0N?ooool00ol0003ooooo
ooooo`1iooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00000oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00003Oooool000oooooo
00?o0000ooooooooool00_ooool2o`0000Gooooon?l0000=ooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00;Oooool3o`0008[ooooo00?o0000ooooooooool0:oooool3o`0001Go
oooo00?o0000ooooooooool07Oooool002kooooo00?o0000ooooooooool0R?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07?ooool002Sooooo0ol0
0003ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000oooool4o`000003ooooool0
003o000000?o00001oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6o`0000Kooooo1?l0
0002ooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`0000;ooooo0ol0
0002ooooo`?o00001?ooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`0000?ooooo
0ol00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool4o`0000?ooooo
00?o0000ooooooooool00_ooool3o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000004oooo
ool0003o0000ooooo`Co00000oooool2o`0000;ooooo2_l00005ooooo`03o`000?oooooooooo01_o
oooo000Wooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooool000003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;o
oooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo000Wooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooooooool5o`0000;ooooo00?o0000ooooooooool00_ooool5
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`Go00002?ooool00ol0003ooooo
ooooo`02ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000?ooooo00?o0000ooooool0
00000_ooool5o`0000?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000;o
oooo0ol00005ooooo`03o`000?oooooooooo01_ooooo000Wooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`08ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001Oooool01_l0003oooooooooool0
003oooooo`0000Sooooo00?o0000ooooooooool06oooool002Oooooo00Ko0000oooooooooooooooo
o`000?ooool4o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000?ooooo0_l00005ooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003oooo
o`?o00002Oooool01Ol0003oooooooooool0003ooooo00?o00001?ooool4o`0000;ooooo1?l00002
ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`Co00000oooool3
o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo1_l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000;ooooo1?l00003ooooo`Wo00000oooool3o`0000?ooooo1?l00004ooooo`03o`000?oooooo
oooo01_ooooo000Wooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Looooo`00:?ooool3o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0=ooooo`?o00002Oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`0000[ooooo1?l0
0004ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o0000;_ooool00ol0003ooooooooo
o`0Hooooo`?o00005_ooool00ol0003oooooooooo`02ooooo`;o00002oooool00ol0003ooooooooo
o`0Mooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.6071, -10.5433, \
0.0702541, 0.314399}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[BoxData[
    \("Warning: too few sample points."\)], "Print",
  CellLabel->"From In[81]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[BoxData[
    \("Need to increase the NumberOfPoints option."\)], "Print",
  CellLabel->"From In[81]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[BoxData[
    InterpretationBox[\("Suggestion: NumberOfPoints -> "\[InvisibleSpace]1024\
\[InvisibleSpace]"."\),
      SequenceForm[ "Suggestion: NumberOfPoints -> ", 1024, "."],
      Editable->False]], "Print",
  CellLabel->"From In[81]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.280538 2.32668 0.0147151 0.618284 [
[.04787 .00222 -12 -9 ]
[.04787 .00222 12 0 ]
[.28054 .00222 -3 -9 ]
[.28054 .00222 3 0 ]
[.51321 .00222 -9 -9 ]
[.51321 .00222 9 0 ]
[.74587 .00222 -9 -9 ]
[.74587 .00222 9 0 ]
[.97854 .00222 -9 -9 ]
[.97854 .00222 9 0 ]
[.01131 .13837 -18 -4.5 ]
[.01131 .13837 0 4.5 ]
[.01131 .26203 -18 -4.5 ]
[.01131 .26203 0 4.5 ]
[.01131 .38569 -18 -4.5 ]
[.01131 .38569 0 4.5 ]
[.01131 .50934 -18 -4.5 ]
[.01131 .50934 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04787 .01472 m
.04787 .02097 L
s
[(-0.1)] .04787 .00222 0 1 Mshowa
.28054 .01472 m
.28054 .02097 L
s
[(0)] .28054 .00222 0 1 Mshowa
.51321 .01472 m
.51321 .02097 L
s
[(0.1)] .51321 .00222 0 1 Mshowa
.74587 .01472 m
.74587 .02097 L
s
[(0.2)] .74587 .00222 0 1 Mshowa
.97854 .01472 m
.97854 .02097 L
s
[(0.3)] .97854 .00222 0 1 Mshowa
.125 Mabswid
.0944 .01472 m
.0944 .01847 L
s
.14094 .01472 m
.14094 .01847 L
s
.18747 .01472 m
.18747 .01847 L
s
.234 .01472 m
.234 .01847 L
s
.32707 .01472 m
.32707 .01847 L
s
.37361 .01472 m
.37361 .01847 L
s
.42014 .01472 m
.42014 .01847 L
s
.46667 .01472 m
.46667 .01847 L
s
.55974 .01472 m
.55974 .01847 L
s
.60627 .01472 m
.60627 .01847 L
s
.65281 .01472 m
.65281 .01847 L
s
.69934 .01472 m
.69934 .01847 L
s
.79241 .01472 m
.79241 .01847 L
s
.83894 .01472 m
.83894 .01847 L
s
.88548 .01472 m
.88548 .01847 L
s
.93201 .01472 m
.93201 .01847 L
s
.00134 .01472 m
.00134 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13837 m
.03006 .13837 L
s
[(0.2)] .01131 .13837 1 0 Mshowa
.02381 .26203 m
.03006 .26203 L
s
[(0.4)] .01131 .26203 1 0 Mshowa
.02381 .38569 m
.03006 .38569 L
s
[(0.6)] .01131 .38569 1 0 Mshowa
.02381 .50934 m
.03006 .50934 L
s
[(0.8)] .01131 .50934 1 0 Mshowa
.125 Mabswid
.02381 .04563 m
.02756 .04563 L
s
.02381 .07654 m
.02756 .07654 L
s
.02381 .10746 m
.02756 .10746 L
s
.02381 .16929 m
.02756 .16929 L
s
.02381 .2002 m
.02756 .2002 L
s
.02381 .23111 m
.02756 .23111 L
s
.02381 .29294 m
.02756 .29294 L
s
.02381 .32386 m
.02756 .32386 L
s
.02381 .35477 m
.02756 .35477 L
s
.02381 .4166 m
.02756 .4166 L
s
.02381 .44751 m
.02756 .44751 L
s
.02381 .47843 m
.02756 .47843 L
s
.02381 .54026 m
.02756 .54026 L
s
.02381 .57117 m
.02756 .57117 L
s
.02381 .60208 m
.02756 .60208 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .02868 m
.02466 .02865 L
.02558 .02862 L
.02602 .02861 L
.02644 .0286 L
.02682 .02856 L
.02723 .0285 L
.02817 .02836 L
.02869 .02829 L
.02918 .02822 L
.02959 .02825 L
.03003 .02834 L
.03097 .02852 L
.033 .02895 L
.03399 .02919 L
.03448 .02931 L
.03492 .02939 L
.03535 .02935 L
.03575 .02931 L
.03664 .02922 L
.03708 .02917 L
.03755 .02913 L
.03779 .02912 L
.03806 .02911 L
.03853 .02911 L
.03904 .0291 L
.0396 .02909 L
.03986 .02909 L
.04013 .02909 L
.04062 .02917 L
.04109 .02932 L
.04153 .02947 L
.04253 .02981 L
.04281 .0299 L
.04306 .02999 L
.04332 .03001 L
.04361 .03002 L
.0446 .03002 L
.04516 .03003 L
.04543 .03003 L
.04568 .03003 L
.04597 .03 L
.04628 .02985 L
.04683 .02959 L
.04769 .02917 L
.04817 .02894 L
.04862 .02873 L
.04888 .02871 L
.04915 .02871 L
.04964 .0287 L
Mistroke
.05059 .02869 L
.05086 .02869 L
.05112 .02869 L
.0516 .0288 L
.05186 .02897 L
.05211 .02913 L
.05266 .02948 L
.05318 .02981 L
.05367 .03013 L
.0541 .03041 L
.05458 .0305 L
.05503 .03054 L
.05551 .0306 L
.05638 .03069 L
.05685 .03074 L
.05729 .03048 L
.0583 .02972 L
.05911 .0291 L
.05956 .02877 L
.05997 .02857 L
.06042 .02843 L
.06091 .02827 L
.06176 .028 L
.06226 .02784 L
.06254 .02782 L
.06279 .02797 L
.06376 .02853 L
.0647 .02906 L
.06516 .02932 L
.06558 .02948 L
.06603 .02963 L
.06652 .02979 L
.06705 .02997 L
.06755 .03013 L
.0678 .03022 L
.06807 .03023 L
.06833 .03008 L
.06862 .02991 L
.06964 .02935 L
.07151 .02838 L
.07253 .02791 L
.07303 .02768 L
.07348 .02747 L
.0739 .02752 L
.07429 .02758 L
.07516 .02771 L
.077 .02802 L
.07797 .02821 L
.07849 .02831 L
.07898 .0284 L
Mistroke
.0794 .02833 L
.07985 .02823 L
.08081 .02803 L
.08495 .02721 L
.093 .026 L
.10066 .02513 L
.11521 .02313 L
.11619 .02316 L
.11673 .02318 L
.11723 .0232 L
.11749 .02321 L
.11777 .0232 L
.11808 .02315 L
.11836 .0231 L
.1194 .02293 L
.12129 .02253 L
.12228 .02227 L
.12255 .0222 L
.12283 .02212 L
.1231 .02205 L
.12334 .02204 L
.1238 .02205 L
.12428 .02206 L
.12481 .02208 L
.12531 .02209 L
.12573 .0221 L
.12617 .02213 L
.12667 .02217 L
.12712 .02222 L
.12801 .02229 L
.12851 .02234 L
.12897 .02225 L
.12937 .02209 L
.12981 .02191 L
.13071 .02155 L
.13261 .02083 L
.13307 .02067 L
.13355 .0205 L
.13401 .02033 L
.13442 .02029 L
.13467 .02034 L
.13494 .0204 L
.13542 .0205 L
.13651 .02073 L
.13742 .02096 L
.13841 .02126 L
.13887 .0214 L
.13936 .02155 L
.13982 .02163 L
.14024 .02142 L
Mistroke
.14217 .02048 L
.14381 .01961 L
.14468 .01913 L
.14517 .01886 L
.14562 .01888 L
.14611 .01899 L
.14657 .01908 L
.14746 .01927 L
.14794 .01937 L
.14839 .01957 L
.14941 .02007 L
.14987 .0203 L
.1503 .02051 L
.15069 .0207 L
.1511 .02063 L
.15156 .02046 L
.15205 .02028 L
.15291 .01995 L
.15473 .01895 L
.15521 .01863 L
.15573 .01829 L
.15623 .01797 L
.15668 .01795 L
.15694 .01797 L
.15723 .018 L
.1578 .01805 L
.15834 .01809 L
.15883 .01814 L
.15932 .01829 L
.15958 .01842 L
.15986 .01857 L
.16083 .01908 L
.1613 .01933 L
.16154 .01946 L
.16181 .01959 L
.16229 .01952 L
.16273 .01944 L
.16356 .01928 L
.16402 .0192 L
.16446 .01911 L
.16496 .01887 L
.16542 .01859 L
.16631 .01805 L
.16678 .01776 L
.16728 .01746 L
.16757 .01741 L
.16783 .0174 L
.16834 .01739 L
.16919 .01737 L
.16965 .01736 L
Mistroke
.17008 .01735 L
.17054 .01753 L
.17105 .01774 L
.17195 .01812 L
.17239 .0183 L
.1728 .01848 L
.17318 .01849 L
.17359 .01846 L
.1745 .0184 L
.1749 .01838 L
.17534 .01835 L
.17577 .01827 L
.17623 .01805 L
.17719 .01759 L
.17766 .01737 L
.1781 .01716 L
.1785 .01701 L
.17893 .01699 L
.17992 .01696 L
.18043 .01694 L
.18072 .01693 L
.18098 .01692 L
.18145 .01699 L
.1817 .01706 L
.18197 .01713 L
.18288 .01739 L
.18338 .01753 L
.18366 .0176 L
.18391 .01767 L
.18419 .01766 L
.18449 .01765 L
.18503 .01762 L
.18601 .01758 L
.18628 .01757 L
.18656 .01755 L
.18681 .0175 L
.18707 .01741 L
.18803 .01708 L
.18855 .01689 L
.18905 .01672 L
.18951 .01658 L
.19001 .01659 L
.19089 .01661 L
.1983 .01673 L
.19927 .01646 L
.19977 .01631 L
.20005 .01623 L
.20032 .01616 L
.20057 .01612 L
.20084 .01614 L
Mistroke
.20131 .01618 L
.20223 .01626 L
.20279 .01631 L
.2031 .01634 L
.20338 .01638 L
.20363 .01643 L
.20389 .01648 L
.20444 .0166 L
.20498 .01671 L
.2055 .01682 L
.20596 .01691 L
.20646 .01685 L
.20841 .01652 L
.2094 .01628 L
.21048 .01598 L
.21093 .01586 L
.21141 .01573 L
.21166 .01571 L
.21193 .01574 L
.2124 .0158 L
.2142 .01601 L
.21602 .01649 L
.21654 .01663 L
.21704 .01677 L
.21748 .01669 L
.21796 .01659 L
.21883 .01643 L
.21965 .01627 L
.2201 .01615 L
.22059 .016 L
.22146 .01573 L
.22192 .01559 L
.22242 .01543 L
.22289 .01542 L
.22332 .01546 L
.22423 .01555 L
.22463 .01559 L
.22506 .01563 L
.22554 .01573 L
.2258 .01583 L
.22605 .01591 L
.22711 .01628 L
.22758 .01644 L
.22804 .0166 L
.22828 .01659 L
.22856 .01654 L
.22903 .01647 L
.23007 .01631 L
.23034 .01627 L
.23058 .01623 L
Mistroke
.23105 .01612 L
.23154 .01594 L
.23207 .01576 L
.23262 .01556 L
.2332 .01536 L
.2337 .01521 L
.23415 .01524 L
.23504 .01528 L
.23553 .01531 L
.2358 .01532 L
.23607 .01533 L
.23631 .01534 L
.23658 .01543 L
.23705 .01561 L
.238 .01598 L
.2385 .01617 L
.23878 .01628 L
.23904 .01638 L
.23951 .01639 L
.23975 .01637 L
.24002 .01636 L
.24093 .01631 L
.2414 .01628 L
.24183 .01625 L
.24228 .01609 L
.24278 .01589 L
.24359 .01557 L
.24402 .01539 L
.24447 .01521 L
.24473 .01514 L
.24501 .01514 L
.24551 .01513 L
.24598 .01513 L
.24649 .01512 L
.24698 .01512 L
.24744 .01512 L
.24789 .01529 L
.24832 .01546 L
.24927 .01582 L
.2498 .01601 L
.25029 .01616 L
.25057 .01618 L
.25087 .0162 L
.2514 .01624 L
.25194 .01628 L
.25244 .01632 L
.2529 .01635 L
.25334 .01617 L
.25431 .01575 L
.25516 .01539 L
Mistroke
.25559 .0152 L
.25606 .01513 L
.25631 .01511 L
.25657 .0151 L
.25705 .01507 L
.25749 .01504 L
.25797 .015 L
.25824 .01499 L
.2585 .01498 L
.25876 .01507 L
.25905 .01517 L
.26004 .01549 L
.26108 .01583 L
.26167 .01597 L
.26221 .01608 L
.2632 .01629 L
.2637 .01639 L
.26398 .01645 L
.26425 .01633 L
.26521 .01591 L
.26574 .01568 L
.26623 .01547 L
.26669 .01526 L
.2672 .01519 L
.26807 .01508 L
.26855 .01502 L
.26906 .01495 L
.26949 .0149 L
.26997 .01502 L
.27204 .01555 L
.27298 .01585 L
.27399 .01617 L
.27448 .01633 L
.27494 .01648 L
.27535 .01638 L
.2758 .0162 L
.27672 .01583 L
.27759 .01548 L
.27802 .01536 L
.27849 .01527 L
.27948 .01508 L
.27991 .015 L
.28038 .01491 L
.28083 .01493 L
.28125 .01501 L
.28287 .01531 L
.2848 .016 L
.28533 .01621 L
.28562 .01633 L
.28589 .01644 L
Mistroke
.28637 .01641 L
.28662 .01633 L
.28689 .01624 L
.28884 .01562 L
.2898 .01537 L
.29069 .01514 L
.29113 .01502 L
.29155 .01491 L
.29198 .01495 L
.29246 .01501 L
.29347 .01513 L
.29391 .01518 L
.29439 .01526 L
.2948 .01544 L
.29518 .01561 L
.29602 .01597 L
.29646 .01617 L
.29687 .01635 L
.29734 .0164 L
.29777 .01632 L
.2987 .01613 L
.2992 .01603 L
.29969 .01593 L
.30013 .0158 L
.30062 .01564 L
.30148 .01536 L
.30194 .0152 L
.30244 .01503 L
.30292 .01499 L
.30334 .01502 L
.3054 .01515 L
.30625 .01552 L
.30717 .01592 L
.30761 .01612 L
.30803 .0163 L
.30841 .01633 L
.30882 .01631 L
.30965 .01625 L
.31011 .01623 L
.31054 .0162 L
.311 .01614 L
.31125 .01604 L
.31152 .01594 L
.31243 .01559 L
.31293 .0154 L
.3134 .01522 L
.31389 .01512 L
.31415 .01512 L
.31442 .01512 L
.3153 .01513 L
Mistroke
.3158 .01513 L
.31625 .01513 L
.31671 .01525 L
.3172 .01545 L
.3181 .01581 L
.31855 .01599 L
.31897 .01616 L
.31935 .01626 L
.31977 .01629 L
.32071 .01635 L
.3212 .01638 L
.32147 .0164 L
.32173 .01642 L
.32218 .01634 L
.32267 .01615 L
.32355 .0158 L
.32406 .0156 L
.32434 .01549 L
.32459 .01539 L
.32505 .01533 L
.32555 .0153 L
.32659 .01525 L
.32689 .01523 L
.32718 .01522 L
.32743 .0152 L
.32771 .01529 L
.32944 .01591 L
.32994 .01609 L
.33041 .01622 L
.33084 .01629 L
.33131 .01637 L
.33182 .01645 L
.33237 .01654 L
.33263 .01658 L
.33288 .01662 L
.33335 .01651 L
.33383 .01634 L
.33427 .01618 L
.33475 .01602 L
.33527 .01583 L
.33577 .01566 L
.33623 .01561 L
.33713 .01552 L
.33763 .01547 L
.33789 .01544 L
.33817 .01541 L
.33842 .01539 L
.33869 .01544 L
.33917 .01559 L
.3402 .01591 L
Mistroke
.34117 .01621 L
.34166 .01632 L
.34218 .01642 L
.34271 .01653 L
.34328 .01664 L
.34354 .0167 L
.34382 .01675 L
.34432 .01671 L
.34478 .01658 L
.3453 .01644 L
.34618 .01619 L
.34663 .01606 L
.34713 .01598 L
.34762 .01592 L
.34808 .01586 L
.34895 .01576 L
.34938 .0157 L
.34984 .01576 L
.35027 .01589 L
.35066 .01599 L
.35161 .01626 L
.35262 .01652 L
.35373 .01671 L
.35422 .0168 L
.35449 .01684 L
.35475 .01689 L
.35525 .01691 L
.3557 .01681 L
.35659 .01662 L
.35709 .01651 L
.35737 .01645 L
.35763 .0164 L
.35787 .01635 L
.35814 .01633 L
.3586 .01628 L
.35945 .0162 L
.35992 .01616 L
.36036 .01612 L
.36061 .0161 L
.36088 .01618 L
.36136 .01632 L
.36229 .01659 L
.3628 .01674 L
.36328 .01688 L
.36378 .01694 L
.36433 .017 L
.36529 .01711 L
.36577 .01716 L
.36621 .01718 L
.36662 .0171 L
Mistroke
.36705 .01701 L
.36798 .01682 L
.36835 .01674 L
.36875 .01666 L
.36918 .01663 L
.36959 .01662 L
.37052 .01659 L
.37102 .01658 L
.37149 .01657 L
.37189 .01666 L
.37232 .01681 L
.37323 .01713 L
.37374 .01732 L
.37421 .01749 L
.37471 .01757 L
.37497 .01758 L
.37526 .0176 L
.37615 .01764 L
.37662 .01766 L
.37713 .01769 L
.37744 .01761 L
.37772 .01753 L
.37826 .01738 L
.37878 .01724 L
.37934 .01708 L
.3796 .017 L
.37988 .01693 L
.38038 .01693 L
.38084 .01694 L
.38136 .01696 L
.38187 .01698 L
.38236 .01699 L
.3828 .01706 L
.38327 .01729 L
.38427 .01777 L
.38482 .01804 L
.38508 .01816 L
.38533 .01828 L
.38577 .01836 L
.38624 .01839 L
.38725 .01845 L
.3877 .01848 L
.38812 .01851 L
.38856 .01836 L
.38903 .01816 L
.38997 .01777 L
.39048 .01755 L
.39096 .01735 L
.39121 .01736 L
.39148 .01736 L
Mistroke
.39205 .01737 L
.39305 .01739 L
.39353 .0174 L
.39381 .01746 L
.39406 .01762 L
.39503 .01821 L
.39596 .01877 L
.39642 .01905 L
.39684 .01916 L
.39762 .01931 L
.39847 .01946 L
.39888 .01954 L
.39934 .01955 L
.39982 .0193 L
.40027 .01907 L
.40117 .01859 L
.40162 .01835 L
.40203 .01815 L
.40251 .01811 L
.40302 .01807 L
.40392 .01799 L
.40439 .01795 L
.40485 .01798 L
.40525 .01824 L
.40569 .01853 L
.40662 .01913 L
.40713 .01946 L
.4076 .01975 L
.40805 .01992 L
.40854 .0201 L
.40939 .02041 L
.40981 .02057 L
.41026 .02073 L
.41064 .02056 L
.41105 .02036 L
.41206 .01986 L
.41256 .01962 L
.41302 .01939 L
.41327 .01933 L
.41354 .01928 L
.41411 .01916 L
.4146 .01906 L
.41512 .01896 L
.4156 .01886 L
.41605 .01895 L
.41647 .01919 L
.41692 .01944 L
.41891 .0205 L
.41989 .02097 L
.42037 .0212 L
Mistroke
.42082 .02141 L
.42122 .0216 L
.42165 .02155 L
.42208 .02142 L
.42255 .02128 L
.42351 .02098 L
.42442 .02074 L
.42547 .02053 L
.42594 .02044 L
.42643 .02035 L
.4269 .02029 L
.42733 .02044 L
.42816 .02075 L
.43005 .02145 L
.43089 .02177 L
.43133 .02194 L
.43179 .02212 L
.4322 .02228 L
.43264 .02232 L
.43305 .02227 L
.43343 .02224 L
.43436 .02214 L
.4346 .02212 L
.43487 .02209 L
.43534 .02206 L
.43561 .02206 L
.43586 .02206 L
.43642 .02206 L
.43694 .02205 L
.43742 .02205 L
.43785 .02204 L
.4383 .02216 L
.43926 .02242 L
.44019 .02268 L
.4412 .02288 L
.44219 .02303 L
.44263 .0231 L
.44311 .02317 L
.44356 .0232 L
.44398 .02318 L
.44491 .02313 L
.44534 .02311 L
.44576 .02308 L
.44613 .02306 L
.44653 .02314 L
.44827 .02352 L
.45565 .02444 L
.45663 .02429 L
.45713 .02422 L
.45741 .02426 L
Mistroke
.45767 .02433 L
.45881 .02464 L
.45985 .02491 L
.46082 .02531 L
.46188 .02576 L
.46236 .02596 L
.46263 .02607 L
.46288 .02612 L
.46332 .02615 L
.4638 .02617 L
.46425 .02619 L
.46473 .02621 L
.46519 .02623 L
.46562 .02623 L
.46612 .02618 L
.46665 .02611 L
.4671 .02606 L
.46758 .02601 L
.46807 .02595 L
.46851 .02597 L
.46894 .02604 L
.46939 .02611 L
.47102 .02638 L
.47875 .02767 L
.48061 .02806 L
.48112 .02818 L
.48166 .0283 L
.48212 .02838 L
.48239 .02833 L
.48264 .02829 L
.48456 .02797 L
.4854 .02783 L
.48632 .02769 L
.48672 .02762 L
.48716 .02756 L
.48757 .02749 L
.48794 .02765 L
.48964 .0284 L
.4915 .02935 L
.49232 .02981 L
.49279 .03007 L
.49322 .03021 L
.49365 .03008 L
.49411 .02993 L
.49506 .02963 L
.49559 .02947 L
.4961 .02925 L
.49705 .0287 L
.49788 .02822 L
.49834 .02796 L
Mistroke
.49878 .02785 L
.49902 .02793 L
.49929 .02801 L
.49975 .02815 L
.50066 .02843 L
.50112 .02857 L
.50162 .02883 L
.50191 .02905 L
.50217 .02925 L
.50268 .02963 L
.50321 .03003 L
.50348 .03024 L
.50378 .03046 L
.50403 .03065 L
.50432 .03071 L
.50481 .03066 L
.50576 .03057 L
.50628 .03051 L
.50678 .03046 L
.50724 .03023 L
.50775 .02991 L
.50863 .02935 L
.5091 .02905 L
.5096 .02874 L
.50986 .0287 L
.51015 .0287 L
.51065 .02871 L
.51113 .02871 L
.51164 .02872 L
.51212 .02873 L
.51256 .02879 L
.51301 .02901 L
.51343 .02921 L
.51439 .02966 L
.51482 .02986 L
.51523 .03003 L
.51565 .03002 L
.51612 .03002 L
.5171 .03 L
.51759 .02999 L
.51787 .02999 L
.51812 .02992 L
.51907 .02961 L
.51996 .02932 L
.52047 .02915 L
.52075 .02907 L
.52101 .02908 L
.52197 .02911 L
.52301 .02915 L
.52326 .02915 L
Mistroke
.52353 .02917 L
.52383 .0292 L
.52411 .02922 L
.52508 .02931 L
.52561 .02936 L
.52611 .02941 L
.52658 .02933 L
.52684 .02926 L
.52708 .0292 L
.52797 .02896 L
.53001 .0285 L
.53104 .0283 L
.53132 .02825 L
.53163 .02819 L
.53191 .0282 L
.53217 .02824 L
.53309 .0284 L
.53406 .02857 L
.5343 .02861 L
.53456 .02864 L
.53485 .02865 L
.53512 .02866 L
.53611 .02869 L
.5366 .0287 L
.53705 .02871 L
.53753 .02863 L
.53778 .02855 L
.53805 .02845 L
.53983 .02785 L
.54082 .0276 L
.54186 .02735 L
.5423 .02725 L
.54276 .02714 L
.54302 .02713 L
.54327 .02712 L
.54374 .0271 L
.54478 .02706 L
.54506 .02705 L
.54537 .02704 L
.54563 .02702 L
.54591 .027 L
.54797 .0268 L
.54992 .02663 L
.5504 .02658 L
.55066 .02656 L
.5509 .02654 L
.5512 .02653 L
.55146 .02653 L
.55198 .02654 L
.55283 .02655 L
Mistroke
.5533 .02656 L
.55374 .02657 L
.55421 .02645 L
.55474 .0263 L
.55565 .02603 L
.56301 .02446 L
.56396 .02478 L
.56447 .02496 L
.56496 .02508 L
.56524 .02504 L
.56554 .02499 L
.56606 .0249 L
.56655 .02482 L
.56708 .02474 L
.56733 .0247 L
.56759 .02465 L
.56806 .02434 L
.5691 .02362 L
.56957 .0233 L
.57006 .02295 L
.57049 .0227 L
.57095 .02257 L
.57195 .0223 L
.57247 .02216 L
.57274 .02208 L
.57303 .022 L
.57328 .022 L
.57356 .02206 L
.57404 .02216 L
.57499 .02237 L
.57546 .02247 L
.57591 .02257 L
.57616 .02255 L
.57643 .02254 L
.5769 .0225 L
.57781 .02244 L
.57823 .02241 L
.57867 .02238 L
.57911 .02218 L
.57952 .022 L
.58045 .02158 L
.58089 .02139 L
.58136 .02118 L
.58163 .02111 L
.58187 .02106 L
.58234 .02096 L
.58324 .02078 L
.58368 .02069 L
.58408 .02061 L
.58447 .02057 L
Mistroke
.58487 .02056 L
.58573 .02052 L
.5862 .0205 L
.58644 .02049 L
.5867 .02048 L
.58718 .02042 L
.58762 .0203 L
.58935 .01986 L
.59031 .01959 L
.59135 .01929 L
.59185 .01914 L
.59233 .019 L
.59276 .01894 L
.59323 .01891 L
.59484 .01883 L
.59655 .01874 L
.59707 .01871 L
.59755 .01869 L
.59798 .01866 L
.59845 .01855 L
.60022 .0181 L
.60196 .0177 L
.60292 .01748 L
.6034 .01737 L
.60383 .01731 L
.60435 .01725 L
.60491 .01719 L
.60589 .01709 L
.60781 .0169 L
.60981 .01672 L
.61079 .01665 L
.61122 .01661 L
.6117 .01657 L
.61216 .01656 L
.61264 .01655 L
.61366 .01652 L
.6142 .01651 L
.61451 .0165 L
.61478 .01649 L
.61583 .01641 L
.61671 .01634 L
.6172 .01631 L
.61766 .01625 L
.61856 .01612 L
.61938 .016 L
.61979 .01594 L
.62023 .01589 L
.62071 .01589 L
.62116 .01588 L
.6217 .01587 L
Mistroke
.6222 .01587 L
.62265 .01586 L
.62313 .0159 L
.62363 .01597 L
.62418 .01605 L
.62528 .01621 L
.62623 .01633 L
.62725 .01644 L
.62778 .0165 L
.62828 .01655 L
.62873 .01653 L
.62922 .01648 L
.63018 .0164 L
.63059 .01636 L
.63105 .01632 L
.63149 .0163 L
.63194 .01629 L
.6329 .01628 L
.63334 .01627 L
.6338 .01626 L
.63424 .01634 L
.63464 .01643 L
.6367 .01692 L
.63859 .01738 L
.63909 .0175 L
.63955 .01758 L
.64004 .01757 L
.64057 .01756 L
.6416 .01755 L
.6419 .01755 L
.64218 .01755 L
.64244 .01757 L
.64271 .01759 L
.64369 .01766 L
.64423 .01769 L
.64473 .01773 L
.6452 .01784 L
.64547 .01793 L
.64571 .01802 L
.6466 .01832 L
.64704 .01848 L
.64752 .01864 L
.64798 .01875 L
.6484 .01881 L
.64941 .01896 L
.64988 .01903 L
.65032 .0191 L
.65071 .01908 L
.65113 .01903 L
.65201 .0189 L
Mistroke
.65249 .01883 L
.65294 .01877 L
.65335 .01875 L
.65379 .01883 L
.65481 .01899 L
.65531 .01907 L
.65577 .01915 L
.65603 .01921 L
.6563 .01935 L
.65688 .01963 L
.65788 .02013 L
.65833 .02035 L
.65882 .02057 L
.65927 .02065 L
.65969 .02072 L
.66167 .02101 L
.66262 .02089 L
.66312 .02082 L
.66365 .02076 L
.66411 .0207 L
.66437 .02069 L
.66461 .02071 L
.6655 .02079 L
.66743 .02098 L
.66956 .02127 L
.6705 .02134 L
.67152 .02139 L
.67199 .02141 L
.67249 .02144 L
.67291 .02154 L
.67338 .02166 L
.67519 .02213 L
.67685 .02267 L
.67728 .02281 L
.67775 .02296 L
.6782 .02303 L
.67861 .02296 L
.6805 .02263 L
.68134 .02247 L
.68226 .02229 L
.68268 .02221 L
.68312 .02212 L
.6835 .02205 L
.68391 .02214 L
.68439 .02229 L
.6849 .02246 L
.68583 .02275 L
.68756 .02314 L
.68807 .02323 L
.68861 .02333 L
Mistroke
.68886 .02338 L
.68913 .02341 L
.6896 .02326 L
.69049 .02298 L
.69099 .02282 L
.69145 .02267 L
.69189 .02254 L
.69236 .02254 L
.69332 .02253 L
.69378 .02253 L
.69422 .02253 L
.69461 .02253 L
.69503 .0227 L
.69601 .02311 L
.69654 .02333 L
.69704 .02353 L
.69746 .02367 L
.69792 .02363 L
.69889 .02356 L
.69932 .02353 L
.69978 .0235 L
.70002 .02348 L
.70029 .02341 L
.70076 .0232 L
.70161 .02283 L
.70206 .02264 L
.70253 .02243 L
.70296 .02227 L
.70342 .02222 L
.70424 .02213 L
.70585 .02195 L
.70675 .02185 L
.70769 .02175 L
.70819 .02169 L
.70847 .02165 L
.70873 .02158 L
.70969 .02132 L
.71012 .02121 L
.71059 .02108 L
.71103 .02096 L
.71144 .02092 L
.71191 .02093 L
.71242 .02093 L
.71332 .02094 L
.71358 .02094 L
.71386 .02094 L
.71416 .02095 L
.71444 .02096 L
.71551 .02099 L
.71596 .021 L
Mistroke
.71645 .02101 L
.71674 .021 L
.71699 .02087 L
.71749 .02061 L
.71934 .01965 L
.72035 .01921 L
.72129 .0188 L
.72171 .01862 L
.72216 .01843 L
.72264 .0184 L
.72309 .0184 L
.72404 .0184 L
.7243 .01839 L
.72457 .01839 L
.72507 .01837 L
.72553 .01829 L
.72602 .01819 L
.7269 .01802 L
.72733 .01794 L
.72777 .01785 L
.72815 .01769 L
.72857 .01752 L
.72958 .0171 L
.73008 .0169 L
.73054 .01672 L
.7308 .01669 L
.73107 .01665 L
.73165 .01658 L
.73266 .01645 L
.73315 .01639 L
.73343 .01637 L
.73369 .01637 L
.73466 .01634 L
.73555 .01632 L
.73599 .01631 L
.73648 .01623 L
.73744 .01605 L
.73795 .01596 L
.73848 .01587 L
.73895 .01579 L
.73922 .01577 L
.73947 .01574 L
.74038 .01565 L
.7408 .01561 L
.74126 .01557 L
.74169 .01554 L
.74209 .01553 L
.74305 .01551 L
.74351 .0155 L
.74393 .01549 L
Mistroke
.74443 .01546 L
.74469 .01541 L
.74497 .01536 L
.74595 .0152 L
.74641 .01512 L
.74684 .01504 L
.74734 .01499 L
.74779 .01497 L
.7488 .01493 L
.74926 .0149 L
.74975 .01488 L
.75001 .01489 L
.75029 .0149 L
.75078 .01493 L
.75191 .01499 L
.75237 .01502 L
.7528 .01503 L
.75331 .01503 L
.75376 .01502 L
.75459 .01502 L
.75506 .01502 L
.75549 .01503 L
.75591 .01507 L
.75637 .01511 L
.7573 .01519 L
.75779 .01524 L
.75807 .01526 L
.75832 .01531 L
.75927 .01553 L
.76029 .01576 L
.76057 .01583 L
.76086 .01589 L
.76114 .01591 L
.7614 .01592 L
.76237 .01596 L
.76288 .01598 L
.76316 .01599 L
.76342 .016 L
.7639 .01606 L
.76416 .0161 L
.76444 .01614 L
.76537 .01628 L
.76587 .01636 L
.76634 .01643 L
.76676 .01663 L
.76722 .01686 L
.76806 .01729 L
.76894 .01775 L
.76941 .01793 L
.76991 .01808 L
Mistroke
.7708 .01833 L
.77132 .01848 L
.7716 .01856 L
.77186 .01864 L
.77211 .01867 L
.77238 .01869 L
.77284 .01873 L
.77383 .01881 L
.77432 .01885 L
.77476 .01891 L
.77523 .01909 L
.77572 .01928 L
.77679 .01967 L
.77704 .01977 L
.77731 .01987 L
.77761 .01994 L
.77788 .01998 L
.77893 .02011 L
.77938 .02016 L
.77987 .02023 L
.78033 .02026 L
.78075 .02023 L
.78181 .02016 L
.78227 .02013 L
.78277 .0201 L
.78325 .02022 L
.78369 .02043 L
.78457 .02084 L
.78649 .02178 L
.78736 .02224 L
.78779 .02247 L
.78818 .02267 L
.78859 .02281 L
.78903 .02275 L
.78996 .02262 L
.79045 .02255 L
.79071 .02252 L
.79096 .02248 L
.79145 .02247 L
.79189 .02254 L
.79299 .02269 L
.79347 .02276 L
.79373 .02279 L
.794 .02284 L
.79447 .02319 L
.7949 .02352 L
.79585 .02425 L
.79638 .02466 L
.79665 .02486 L
.79689 .02498 L
Mistroke
.79735 .02509 L
.79784 .02521 L
.7987 .02542 L
.79917 .02554 L
.79961 .02561 L
.80008 .02553 L
.8006 .02545 L
.80107 .02538 L
.80151 .02531 L
.80193 .02524 L
.80238 .02522 L
.8028 .02536 L
.80318 .02549 L
.80403 .02577 L
.80451 .02593 L
.80496 .02608 L
.80545 .02611 L
.80589 .02611 L
.80677 .02612 L
.80723 .02612 L
.80773 .02613 L
.80801 .02604 L
.80827 .02594 L
.80877 .02574 L
.80977 .02533 L
.81004 .02522 L
.81033 .02511 L
.81058 .02502 L
.81085 .02508 L
.8128 .02555 L
.81376 .02579 L
.81481 .02608 L
.81529 .0262 L
.81555 .02628 L
.81579 .02634 L
.81623 .02632 L
.8167 .02601 L
.81843 .02488 L
.8193 .02444 L
.82025 .02408 L
.82076 .0239 L
.82103 .0238 L
.82129 .0237 L
.82154 .02361 L
.8218 .02365 L
.82226 .02381 L
.82313 .0241 L
.8236 .02425 L
.82409 .02442 L
.82438 .02451 L
Mistroke
.82463 .02446 L
.82514 .02437 L
.82624 .02416 L
.82673 .02407 L
.82701 .02401 L
.82726 .02391 L
.82773 .02363 L
.82823 .02333 L
.82913 .02279 L
.82963 .02249 L
.83009 .02232 L
.83048 .02229 L
.8309 .02226 L
.83179 .0222 L
.83229 .02216 L
.83257 .02214 L
.83283 .0221 L
.8338 .02191 L
.83564 .02148 L
.8426 .0199 L
.84604 .01882 L
.84695 .01844 L
.84794 .01808 L
.84839 .01792 L
.84887 .01774 L
.84933 .01765 L
.84974 .01773 L
.85083 .01796 L
.85137 .01807 L
.85186 .01817 L
.85231 .01823 L
.85279 .01828 L
.8538 .01839 L
.85425 .01844 L
.85474 .01849 L
.85519 .01834 L
.85561 .0182 L
.85656 .0179 L
.85706 .01773 L
.85732 .01765 L
.8576 .01759 L
.85809 .01758 L
.85854 .01758 L
.85943 .01757 L
.85991 .01756 L
.86036 .01761 L
.86085 .01782 L
.86138 .01805 L
.86488 .01913 L
.87279 .02124 L
Mistroke
.88861 .02695 L
.88957 .02806 L
.8901 .02867 L
.8906 .02925 L
.89106 .02949 L
.89157 .02973 L
.89246 .03017 L
.89295 .0304 L
.89322 .03053 L
.89347 .03058 L
.89396 .03044 L
.8944 .0303 L
.89543 .03 L
.89571 .02991 L
.89601 .02983 L
.89626 .02987 L
.89654 .03006 L
.89837 .03128 L
.89939 .03182 L
.90032 .03218 L
.90119 .03251 L
.90168 .03267 L
.90213 .03243 L
.90303 .03195 L
.90385 .03151 L
.90428 .03128 L
.90469 .03134 L
.90512 .03156 L
.90559 .03179 L
.90723 .03263 L
.90817 .03325 L
.90868 .03359 L
.90917 .03391 L
.90962 .03421 L
.91011 .03425 L
.91055 .03381 L
.91096 .03341 L
.91188 .0325 L
.91238 .032 L
.91286 .03161 L
.91331 .03141 L
.91379 .0312 L
.91463 .03082 L
.9151 .03061 L
.91559 .03052 L
.91602 .03076 L
.91648 .03101 L
.91698 .03129 L
.91753 .03159 L
.91778 .03173 L
Mistroke
.91804 .03187 L
.91851 .03179 L
.91898 .0315 L
.91949 .03119 L
.92041 .03062 L
.92214 .02939 L
.92313 .02865 L
.92362 .02828 L
.9239 .02822 L
.92417 .02827 L
.92512 .02846 L
.92559 .02855 L
.92603 .02864 L
.92644 .02872 L
.92687 .02843 L
.92779 .02768 L
.9294 .02633 L
.93116 .0244 L
.93159 .02393 L
.93205 .02346 L
.93256 .02353 L
.93303 .02359 L
.93358 .02366 L
.9341 .02373 L
.93456 .02379 L
.93483 .0238 L
.93507 .02373 L
.93604 .02342 L
.93695 .02312 L
.93742 .02297 L
.93769 .02278 L
.93793 .02251 L
.93901 .02134 L
.93956 .02074 L
.94008 .02018 L
.94033 .01993 L
.94061 .01986 L
.9412 .01972 L
.94327 .01922 L
.94429 .01894 L
.94473 .01881 L
.94523 .01867 L
.94567 .01855 L
.94608 .01832 L
.94698 .0177 L
.9479 .01706 L
.94815 .01689 L
.94841 .01671 L
.94888 .01656 L
.94935 .01651 L
Mistroke
.94987 .01646 L
.95079 .01637 L
.95106 .01634 L
.95131 .01632 L
.95158 .0163 L
.95187 .01629 L
.95286 .01624 L
.95335 .01621 L
.95381 .01619 L
.95423 .01613 L
.95468 .01595 L
.9556 .01558 L
.9561 .01538 L
.95637 .01527 L
.95663 .01517 L
.95711 .01508 L
.95755 .01509 L
.95841 .01512 L
.95885 .01513 L
.95931 .01515 L
.95958 .01515 L
.95982 .01515 L
.9603 .01513 L
.96195 .01508 L
.96278 .01504 L
.96369 .01499 L
.96447 .01495 L
.96491 .01493 L
.96531 .01496 L
.96568 .01507 L
.96608 .01519 L
.96682 .0154 L
.96754 .01561 L
.96791 .01572 L
.96831 .01574 L
.9697 .01581 L
.97131 .01591 L
.97216 .01597 L
.97262 .01601 L
.97305 .01604 L
.97343 .01607 L
.97383 .01628 L
.97469 .01675 L
.97619 .01756 L
Mfstroke
1 0 0 r
.02381 .01473 m
.02466 .01473 L
.02558 .01472 L
.02602 .01472 L
.02644 .01472 L
.02682 .01472 L
.02723 .01472 L
.02817 .01473 L
.02869 .01473 L
.02918 .01473 L
.02959 .01473 L
.03003 .01473 L
.03097 .01472 L
.03144 .01472 L
.03194 .01472 L
.03223 .01472 L
.03249 .01472 L
.033 .01472 L
.03392 .01473 L
.03441 .01473 L
.03467 .01473 L
.03492 .01473 L
.03538 .01473 L
.03589 .01473 L
.03678 .01472 L
.03721 .01472 L
.03762 .01472 L
.0381 .01472 L
.03853 .01472 L
.03953 .01473 L
.04002 .01473 L
.04046 .01473 L
.04093 .01473 L
.04144 .01473 L
.042 .01472 L
.04252 .01472 L
.04294 .01472 L
.04338 .01472 L
.04387 .01472 L
.04432 .01472 L
.04479 .01473 L
.0453 .01473 L
.04577 .01473 L
.04622 .01473 L
.0467 .01473 L
.04722 .01473 L
.04815 .01472 L
.04842 .01472 L
.04872 .01472 L
.049 .01472 L
Mistroke
.04926 .01472 L
.05028 .01473 L
.05084 .01473 L
.05112 .01473 L
.05137 .01474 L
.05185 .01473 L
.05236 .01473 L
.05344 .01472 L
.0537 .01472 L
.05398 .01472 L
.05429 .01472 L
.05458 .01472 L
.05556 .01473 L
.0561 .01473 L
.0566 .01473 L
.05703 .01474 L
.05749 .01473 L
.05846 .01473 L
.05902 .01472 L
.05929 .01472 L
.05954 .01472 L
.0598 .01472 L
.06008 .01472 L
.06067 .01472 L
.06118 .01473 L
.06172 .01473 L
.06218 .01474 L
.06244 .01474 L
.06269 .01474 L
.06368 .01473 L
.06458 .01472 L
.06482 .01472 L
.06509 .01472 L
.06557 .01472 L
.06584 .01472 L
.06612 .01472 L
.06663 .01473 L
.06707 .01473 L
.06755 .01474 L
.06799 .01474 L
.0684 .01474 L
.06943 .01473 L
.06987 .01472 L
.07036 .01472 L
.07084 .01472 L
.07128 .01472 L
.07216 .01473 L
.07309 .01474 L
.07356 .01474 L
.07383 .01474 L
Mistroke
.07408 .01474 L
.07494 .01473 L
.07576 .01472 L
.07621 .01472 L
.0767 .01472 L
.07756 .01473 L
.07809 .01473 L
.07859 .01474 L
.07905 .01474 L
.07954 .01474 L
.08056 .01473 L
.08112 .01472 L
.0814 .01472 L
.08164 .01472 L
.0821 .01472 L
.08259 .01472 L
.08362 .01473 L
.08407 .01474 L
.08455 .01474 L
.08501 .01474 L
.08544 .01473 L
.0863 .01473 L
.08677 .01472 L
.08721 .01472 L
.08768 .01472 L
.08793 .01472 L
.0882 .01473 L
.08911 .01474 L
.08956 .01474 L
.09004 .01475 L
.09049 .01474 L
.09091 .01474 L
.09171 .01473 L
.09214 .01472 L
.09255 .01472 L
.09304 .01472 L
.09349 .01472 L
.09437 .01473 L
.09483 .01474 L
.09533 .01474 L
.09561 .01475 L
.09587 .01474 L
.09637 .01474 L
.09737 .01473 L
.09789 .01472 L
.09816 .01472 L
.09845 .01472 L
.0987 .01472 L
.09898 .01472 L
.09947 .01473 L
Mistroke
.1004 .01474 L
.10087 .01475 L
.10114 .01475 L
.10139 .01475 L
.10243 .01473 L
.10333 .01472 L
.10359 .01472 L
.10383 .01472 L
.10429 .01472 L
.10527 .01473 L
.10581 .01474 L
.10631 .01475 L
.1066 .01475 L
.10691 .01475 L
.10746 .01474 L
.10852 .01473 L
.10896 .01472 L
.10944 .01472 L
.10972 .01472 L
.10997 .01472 L
.11046 .01473 L
.11096 .01474 L
.11151 .01475 L
.11176 .01475 L
.11203 .01475 L
.11251 .01475 L
.11295 .01474 L
.11341 .01474 L
.11426 .01472 L
.11475 .01472 L
.115 .01472 L
.11527 .01472 L
.11619 .01473 L
.11715 .01475 L
.11742 .01475 L
.1177 .01476 L
.1182 .01475 L
.11918 .01473 L
.11966 .01473 L
.1201 .01472 L
.12052 .01472 L
.12092 .01472 L
.12179 .01474 L
.12268 .01475 L
.12293 .01476 L
.12319 .01476 L
.12366 .01475 L
.12469 .01474 L
.12524 .01473 L
.12554 .01472 L
Mistroke
.12581 .01472 L
.12606 .01472 L
.12632 .01472 L
.12687 .01473 L
.12784 .01475 L
.12833 .01476 L
.12861 .01476 L
.12886 .01476 L
.12933 .01475 L
.12983 .01474 L
.13069 .01473 L
.13118 .01472 L
.13164 .01472 L
.13208 .01473 L
.13255 .01474 L
.13304 .01474 L
.1335 .01475 L
.13393 .01476 L
.1344 .01476 L
.13482 .01476 L
.13521 .01475 L
.13618 .01473 L
.13665 .01472 L
.13708 .01472 L
.13754 .01473 L
.13803 .01474 L
.13853 .01475 L
.13906 .01476 L
.13949 .01477 L
.13995 .01477 L
.14038 .01476 L
.14078 .01475 L
.14125 .01474 L
.14175 .01473 L
.14217 .01472 L
.14264 .01472 L
.14305 .01473 L
.14349 .01474 L
.14427 .01475 L
.14475 .01476 L
.14519 .01477 L
.1456 .01477 L
.14603 .01476 L
.14693 .01474 L
.14742 .01473 L
.14789 .01472 L
.14832 .01472 L
.1488 .01473 L
.14963 .01475 L
.15014 .01477 L
Mistroke
.15062 .01478 L
.15089 .01478 L
.15118 .01477 L
.15168 .01476 L
.15267 .01474 L
.15315 .01473 L
.15359 .01472 L
.15406 .01473 L
.15456 .01474 L
.15562 .01477 L
.15588 .01478 L
.15615 .01478 L
.15645 .01478 L
.15672 .01478 L
.15776 .01475 L
.15822 .01474 L
.15871 .01473 L
.15917 .01472 L
.15959 .01473 L
.16064 .01476 L
.1611 .01477 L
.1616 .01479 L
.16209 .01479 L
.16253 .01477 L
.16341 .01475 L
.16389 .01474 L
.16435 .01472 L
.16482 .01472 L
.16507 .01473 L
.16534 .01474 L
.16627 .01477 L
.16673 .01478 L
.16716 .0148 L
.16754 .0148 L
.16795 .01478 L
.16881 .01476 L
.16931 .01474 L
.16984 .01472 L
.17012 .01472 L
.17042 .01473 L
.17095 .01474 L
.17192 .01478 L
.17217 .01479 L
.17245 .0148 L
.17271 .0148 L
.17295 .01481 L
.17345 .01479 L
.17397 .01477 L
.17489 .01474 L
.17531 .01473 L
Mistroke
.17575 .01472 L
.17624 .01474 L
.1767 .01476 L
.17767 .01479 L
.17794 .0148 L
.1782 .01481 L
.17869 .01481 L
.17916 .01479 L
.17958 .01478 L
.18055 .01474 L
.18105 .01472 L
.18152 .01473 L
.18179 .01474 L
.18203 .01475 L
.18259 .01478 L
.18312 .0148 L
.1834 .01481 L
.18369 .01482 L
.18395 .01483 L
.18424 .01482 L
.18474 .0148 L
.18567 .01476 L
.18617 .01474 L
.18664 .01472 L
.18689 .01473 L
.18715 .01474 L
.18771 .01477 L
.18869 .01481 L
.18917 .01484 L
.18944 .01485 L
.18969 .01484 L
.19063 .01479 L
.19106 .01477 L
.19154 .01475 L
.19198 .01473 L
.1924 .01473 L
.19285 .01475 L
.19332 .01478 L
.19417 .01482 L
.19442 .01484 L
.19469 .01485 L
.19518 .01486 L
.19565 .01483 L
.19608 .01481 L
.19695 .01476 L
.19738 .01474 L
.19776 .01472 L
.19817 .01475 L
.19861 .01477 L
.19954 .01483 L
Mistroke
.20002 .01486 L
.20029 .01488 L
.20054 .01489 L
.20098 .01486 L
.20147 .01483 L
.20248 .01476 L
.20276 .01475 L
.20305 .01473 L
.2033 .01472 L
.20357 .01474 L
.20453 .01481 L
.20506 .01485 L
.20556 .01489 L
.20602 .01492 L
.20652 .01488 L
.2074 .01482 L
.2083 .01475 L
.20856 .01473 L
.2088 .01472 L
.20926 .01476 L
.21011 .01483 L
.21101 .01491 L
.21127 .01493 L
.21153 .01495 L
.21199 .01491 L
.21291 .01484 L
.21339 .0148 L
.2139 .01475 L
.21417 .01473 L
.21446 .01474 L
.21473 .01476 L
.21498 .01479 L
.21602 .0149 L
.21653 .01495 L
.21701 .01499 L
.21743 .01496 L
.21789 .01491 L
.21885 .01482 L
.21934 .01477 L
.21961 .01474 L
.21987 .01473 L
.22037 .01479 L
.22082 .01485 L
.22186 .01497 L
.22215 .01501 L
.22245 .01505 L
.22274 .01504 L
.223 .01501 L
.22396 .01489 L
.22485 .01478 L
Mistroke
.2253 .01473 L
.22579 .01479 L
.22681 .01495 L
.22727 .01502 L
.22776 .0151 L
.22822 .01513 L
.22865 .01506 L
.22946 .01494 L
.23033 .01481 L
.23082 .01473 L
.23127 .01481 L
.23215 .01499 L
.23314 .01518 L
.23363 .01527 L
.23391 .01521 L
.23417 .01516 L
.23519 .01496 L
.23569 .01487 L
.23615 .01478 L
.2364 .01474 L
.23668 .01482 L
.23725 .01497 L
.23826 .01523 L
.23872 .01535 L
.23922 .01544 L
.2397 .01532 L
.24014 .0152 L
.24102 .01497 L
.24145 .01486 L
.24185 .01476 L
.24232 .01491 L
.24283 .01509 L
.24372 .01542 L
.24422 .01561 L
.24469 .01576 L
.24518 .01558 L
.24571 .01538 L
.24662 .01505 L
.24706 .01489 L
.24748 .0148 L
.24785 .015 L
.24825 .01522 L
.24908 .01569 L
.24951 .01593 L
.24997 .01618 L
.2504 .01617 L
.2508 .01595 L
.25179 .01541 L
.25226 .01515 L
.25269 .01491 L
Mistroke
.25314 .01496 L
.25362 .0154 L
.2545 .0162 L
.25499 .01664 L
.25544 .01705 L
.25591 .01708 L
.25616 .01686 L
.25643 .01661 L
.25737 .01578 L
.25783 .01537 L
.25825 .01498 L
.25864 .0151 L
.25905 .01577 L
.25991 .01718 L
.26036 .01792 L
.26084 .0187 L
.26109 .01911 L
.26136 .01907 L
.26184 .01829 L
.2628 .01674 L
.26321 .01607 L
.26366 .01534 L
.26394 .01489 L
.26419 .01558 L
.2647 .01733 L
.2658 .02117 L
.26631 .02291 L
.26677 .02427 L
.26726 .02257 L
.2678 .02071 L
.26828 .01906 L
.26878 .01731 L
.26926 .01565 L
.26969 .01687 L
.26996 .01959 L
.27021 .02209 L
.27076 .02774 L
.27128 .03304 L
.27176 .03799 L
.27218 .04229 L
.27263 .03924 L
.27313 .03411 L
.27359 .02944 L
.27406 .02458 L
.27431 .02201 L
.27458 .01928 L
.27507 .01956 L
.27552 .06149 L
.27888 .41511 L
.27979 .53558 L
Mistroke
.28005 .56858 L
.28031 .60332 L
.28079 .6006 L
.28123 .54246 L
.28164 .48839 L
.28258 .3657 L
.2845 .15935 L
.28503 .11035 L
.28559 .05849 L
.28607 .01488 L
.28634 .01765 L
.28659 .02024 L
.28753 .02983 L
.28799 .03456 L
.28842 .03893 L
.28891 .0422 L
.28916 .03955 L
.28944 .03673 L
.29038 .02716 L
.29082 .02257 L
.2913 .01774 L
.29154 .01521 L
.29182 .01565 L
.29229 .0173 L
.29316 .02032 L
.29364 .02198 L
.29409 .02355 L
.29453 .02375 L
.29501 .0221 L
.29584 .01922 L
.29624 .0178 L
.29668 .01629 L
.29705 .015 L
.29746 .0154 L
.29795 .0162 L
.2984 .01694 L
.29894 .01782 L
.29944 .01862 L
.2999 .01924 L
.30035 .01852 L
.30132 .01694 L
.30175 .01623 L
.3022 .01549 L
.30259 .01486 L
.30301 .01515 L
.30395 .016 L
.30485 .0168 L
.30534 .01724 L
.30563 .01706 L
.30589 .01682 L
Mistroke
.30683 .01597 L
.30736 .01548 L
.30786 .01503 L
.30811 .01481 L
.30838 .01491 L
.30896 .01523 L
.30993 .01576 L
.31047 .01606 L
.31096 .01627 L
.31139 .01603 L
.31184 .01578 L
.3128 .01524 L
.31304 .0151 L
.31331 .01496 L
.31378 .0148 L
.31428 .01498 L
.31483 .01519 L
.31572 .01551 L
.31597 .0156 L
.31623 .0157 L
.3167 .01567 L
.317 .01555 L
.31729 .01545 L
.31783 .01525 L
.31839 .01504 L
.31864 .01495 L
.31891 .01485 L
.31938 .0148 L
.31988 .01492 L
.32093 .0152 L
.32144 .01533 L
.32193 .01546 L
.32237 .01535 L
.32284 .01523 L
.32384 .01496 L
.32434 .01483 L
.32463 .01476 L
.3249 .01477 L
.32538 .01487 L
.32582 .01495 L
.3263 .01504 L
.32682 .01515 L
.32727 .01523 L
.32769 .01523 L
.32813 .01514 L
.3286 .01505 L
.32959 .01485 L
.33009 .01476 L
.33037 .01475 L
.33064 .01479 L
Mistroke
.3316 .01494 L
.33251 .01507 L
.33276 .01511 L
.33302 .01514 L
.33331 .0151 L
.33358 .01506 L
.33455 .01491 L
.33505 .01483 L
.33532 .01479 L
.33559 .01475 L
.3359 .01474 L
.33619 .01478 L
.33674 .01485 L
.33766 .01496 L
.3379 .01499 L
.33816 .01502 L
.33864 .01504 L
.33912 .01499 L
.33957 .01493 L
.34041 .01483 L
.34086 .01477 L
.34134 .01473 L
.34161 .01476 L
.34186 .01478 L
.34236 .01483 L
.34286 .01488 L
.34342 .01494 L
.34367 .01496 L
.34394 .01499 L
.34442 .01496 L
.3449 .01491 L
.34542 .01486 L
.34592 .01481 L
.3462 .01478 L
.34646 .01475 L
.34671 .01473 L
.34697 .01473 L
.34744 .01477 L
.34834 .01485 L
.34889 .0149 L
.34916 .01492 L
.34941 .01494 L
.34967 .01494 L
.34995 .01492 L
.35054 .01487 L
.35105 .01483 L
.3516 .01478 L
.35186 .01476 L
.35211 .01474 L
.35258 .01474 L
Mistroke
.35303 .01477 L
.35344 .0148 L
.35437 .01487 L
.35482 .0149 L
.35532 .0149 L
.35557 .01488 L
.35584 .01486 L
.35632 .01483 L
.35683 .01479 L
.35738 .01475 L
.35763 .01473 L
.3579 .01472 L
.35838 .01475 L
.35928 .01481 L
.35976 .01484 L
.36027 .01487 L
.36054 .01489 L
.36078 .01488 L
.36126 .01485 L
.36231 .01478 L
.36278 .01475 L
.36328 .01472 L
.36376 .01474 L
.36419 .01476 L
.36526 .01482 L
.36551 .01483 L
.36578 .01485 L
.36625 .01486 L
.36675 .01483 L
.36729 .0148 L
.36789 .01477 L
.36844 .01474 L
.36891 .01472 L
.36936 .01474 L
.37034 .01479 L
.37119 .01483 L
.37167 .01485 L
.37211 .01483 L
.37312 .01478 L
.37361 .01475 L
.37406 .01473 L
.37454 .01472 L
.3748 .01473 L
.37505 .01474 L
.37613 .01479 L
.37656 .01481 L
.37703 .01483 L
.37747 .01482 L
.37787 .0148 L
.37879 .01476 L
Mistroke
.37928 .01474 L
.37955 .01473 L
.3798 .01472 L
.38005 .01472 L
.38032 .01473 L
.38078 .01475 L
.3817 .01478 L
.38221 .0148 L
.38248 .01481 L
.38274 .01482 L
.3832 .0148 L
.3837 .01478 L
.38461 .01475 L
.38506 .01473 L
.38547 .01472 L
.38584 .01473 L
.38624 .01474 L
.38708 .01477 L
.38756 .01479 L
.3878 .0148 L
.38807 .01481 L
.38855 .0148 L
.38899 .01478 L
.38982 .01475 L
.39025 .01474 L
.39072 .01472 L
.39096 .01472 L
.39122 .01472 L
.39169 .01474 L
.39261 .01477 L
.39304 .01478 L
.3935 .01479 L
.39393 .01479 L
.39433 .01478 L
.39531 .01475 L
.39579 .01474 L
.39622 .01472 L
.39668 .01472 L
.39717 .01474 L
.39821 .01476 L
.39864 .01478 L
.3991 .01479 L
.3995 .01479 L
.39993 .01477 L
.40083 .01475 L
.40133 .01473 L
.4018 .01472 L
.40224 .01472 L
.40272 .01473 L
.40355 .01476 L
Mistroke
.40397 .01477 L
.4044 .01478 L
.40482 .01479 L
.40519 .01478 L
.40616 .01475 L
.40706 .01473 L
.40751 .01472 L
.408 .01473 L
.40903 .01475 L
.40948 .01476 L
.40997 .01477 L
.41044 .01478 L
.41087 .01477 L
.41168 .01475 L
.41255 .01473 L
.41304 .01472 L
.41349 .01473 L
.41438 .01474 L
.41487 .01476 L
.41514 .01476 L
.41541 .01477 L
.41568 .01477 L
.41592 .01477 L
.4164 .01476 L
.41741 .01474 L
.41794 .01473 L
.41823 .01472 L
.4185 .01472 L
.41899 .01472 L
.41953 .01473 L
.42048 .01475 L
.42096 .01476 L
.42121 .01477 L
.42147 .01477 L
.42195 .01476 L
.42239 .01475 L
.42339 .01473 L
.42366 .01472 L
.42395 .01472 L
.42419 .01472 L
.42446 .01472 L
.42541 .01474 L
.42593 .01475 L
.42642 .01476 L
.42687 .01477 L
.42737 .01476 L
.42823 .01474 L
.42908 .01473 L
.42957 .01472 L
.43002 .01472 L
Mistroke
.43101 .01474 L
.43144 .01475 L
.43191 .01476 L
.43235 .01476 L
.43275 .01476 L
.43355 .01474 L
.4344 .01473 L
.43483 .01472 L
.4353 .01472 L
.43556 .01472 L
.43583 .01473 L
.43631 .01473 L
.43724 .01475 L
.43751 .01475 L
.43781 .01476 L
.43808 .01476 L
.43834 .01475 L
.43934 .01474 L
.44021 .01472 L
.44071 .01472 L
.44118 .01472 L
.44213 .01474 L
.44265 .01475 L
.44313 .01475 L
.44355 .01475 L
.44399 .01475 L
.44492 .01473 L
.44536 .01473 L
.44577 .01472 L
.44614 .01472 L
.44655 .01472 L
.44748 .01473 L
.44799 .01474 L
.44846 .01475 L
.44887 .01475 L
.4493 .01475 L
.45023 .01474 L
.4512 .01472 L
.45169 .01472 L
.45197 .01472 L
.45223 .01472 L
.45314 .01473 L
.45363 .01474 L
.45409 .01475 L
.45434 .01475 L
.4546 .01475 L
.45489 .01475 L
.45515 .01474 L
.45612 .01473 L
.45666 .01472 L
Mistroke
.45694 .01472 L
.45724 .01472 L
.45751 .01472 L
.4578 .01472 L
.4583 .01473 L
.45877 .01473 L
.45928 .01474 L
.45976 .01475 L
.46021 .01475 L
.46048 .01474 L
.46073 .01474 L
.46128 .01473 L
.46179 .01473 L
.46226 .01472 L
.46271 .01472 L
.46318 .01472 L
.46417 .01473 L
.46503 .01474 L
.46551 .01475 L
.46597 .01474 L
.46689 .01473 L
.4674 .01473 L
.46787 .01472 L
.46812 .01472 L
.46839 .01472 L
.46868 .01472 L
.46895 .01472 L
.46995 .01473 L
.47037 .01474 L
.47083 .01474 L
.47133 .01474 L
.47179 .01474 L
.47272 .01473 L
.47321 .01472 L
.47347 .01472 L
.47372 .01472 L
.4742 .01472 L
.47471 .01472 L
.47563 .01473 L
.47607 .01474 L
.4765 .01474 L
.47698 .01474 L
.47743 .01473 L
.47821 .01473 L
.47864 .01472 L
.47904 .01472 L
.47952 .01472 L
.47995 .01472 L
.48079 .01473 L
.48124 .01473 L
Mistroke
.48171 .01474 L
.48216 .01474 L
.48257 .01474 L
.48359 .01473 L
.48403 .01472 L
.48452 .01472 L
.48499 .01472 L
.48549 .01472 L
.48655 .01473 L
.48702 .01474 L
.48728 .01474 L
.48753 .01474 L
.48802 .01474 L
.48846 .01473 L
.4893 .01472 L
.48977 .01472 L
.4902 .01472 L
.49061 .01472 L
.49106 .01472 L
.49183 .01473 L
.49231 .01473 L
.49276 .01474 L
.49323 .01474 L
.49347 .01474 L
.49374 .01473 L
.49458 .01473 L
.49502 .01472 L
.4955 .01472 L
.49601 .01472 L
.49648 .01472 L
.49751 .01473 L
.49799 .01473 L
.49848 .01474 L
.49891 .01474 L
.49937 .01473 L
.50043 .01472 L
.50073 .01472 L
.50102 .01472 L
.50128 .01472 L
.50156 .01472 L
.5018 .01472 L
.50207 .01472 L
.50261 .01473 L
.50359 .01473 L
.50383 .01473 L
.5041 .01474 L
.50458 .01473 L
.5055 .01473 L
.50601 .01472 L
.50629 .01472 L
Mistroke
.50656 .01472 L
.50681 .01472 L
.50708 .01472 L
.50755 .01472 L
.50848 .01473 L
.509 .01473 L
.50948 .01473 L
.50988 .01473 L
.51032 .01473 L
.51125 .01472 L
.51176 .01472 L
.51223 .01472 L
.51272 .01472 L
.51299 .01472 L
.51327 .01472 L
.51416 .01473 L
.51463 .01473 L
.51513 .01473 L
.51542 .01473 L
.51569 .01473 L
.51621 .01473 L
.51675 .01472 L
.51733 .01472 L
.5176 .01472 L
.51787 .01472 L
.51837 .01472 L
.51935 .01472 L
.52026 .01473 L
.52052 .01473 L
.52077 .01473 L
.52124 .01473 L
.52209 .01472 L
.523 .01472 L
.52327 .01472 L
.52353 .01472 L
.524 .01472 L
.52493 .01472 L
.52542 .01473 L
.52593 .01473 L
.5262 .01473 L
.5265 .01473 L
.52702 .01473 L
.52798 .01472 L
.52849 .01472 L
.52877 .01472 L
.52903 .01472 L
.5295 .01472 L
.53001 .01472 L
.53092 .01473 L
.53138 .01473 L
Mistroke
.53182 .01473 L
.53221 .01473 L
.53263 .01473 L
.53358 .01472 L
.53405 .01472 L
.53447 .01472 L
.53472 .01472 L
.53498 .01472 L
.53552 .01472 L
.53648 .01473 L
.53673 .01473 L
.537 .01473 L
.53749 .01473 L
.53779 .01473 L
.53808 .01473 L
.53861 .01472 L
.53907 .01472 L
.53957 .01472 L
.53999 .01472 L
.54045 .01472 L
.54141 .01472 L
.54191 .01473 L
.54219 .01473 L
.54245 .01473 L
.54269 .01473 L
.54296 .01473 L
.54342 .01473 L
.54432 .01472 L
.54482 .01472 L
.54509 .01472 L
.54535 .01472 L
.5458 .01472 L
.54629 .01472 L
.54717 .01472 L
.5476 .01473 L
.54799 .01473 L
.54845 .01473 L
.54895 .01473 L
.54982 .01472 L
.55032 .01472 L
.55058 .01472 L
.55086 .01472 L
.5511 .01472 L
.55137 .01472 L
.55184 .01472 L
.5528 .01472 L
.55321 .01473 L
.55367 .01473 L
.55394 .01473 L
.55419 .01473 L
Mistroke
.55469 .01473 L
.55521 .01472 L
.55579 .01472 L
.55628 .01472 L
.55675 .01472 L
.55724 .01472 L
.55777 .01472 L
.55868 .01473 L
.55895 .01473 L
.55919 .01473 L
.55966 .01473 L
.5601 .01473 L
.56051 .01472 L
.56142 .01472 L
.5619 .01472 L
.56235 .01472 L
.56284 .01472 L
.56336 .01472 L
.56391 .01472 L
.56443 .01473 L
.5649 .01473 L
.56517 .01473 L
.56541 .01473 L
.5663 .01472 L
.56677 .01472 L
.56727 .01472 L
.56753 .01472 L
.56782 .01472 L
.56808 .01472 L
.56832 .01472 L
.56931 .01472 L
.56985 .01473 L
.57012 .01473 L
.57036 .01473 L
.57082 .01473 L
.57132 .01472 L
.57189 .01472 L
.57243 .01472 L
.57292 .01472 L
.5732 .01472 L
.57346 .01472 L
.57439 .01472 L
.57523 .01472 L
.57571 .01473 L
.57616 .01473 L
.57663 .01472 L
.57714 .01472 L
.57802 .01472 L
.57846 .01472 L
.57894 .01472 L
Mistroke
.57935 .01472 L
.5798 .01472 L
.5806 .01472 L
.58085 .01472 L
.58112 .01473 L
.58161 .01473 L
.58188 .01473 L
.58213 .01472 L
.58271 .01472 L
.58367 .01472 L
.58393 .01472 L
.58421 .01472 L
.58471 .01472 L
.58557 .01472 L
.5865 .01473 L
.58677 .01473 L
.58703 .01473 L
.58751 .01472 L
.58845 .01472 L
.58889 .01472 L
.58937 .01472 L
.58981 .01472 L
.59022 .01472 L
.59123 .01472 L
.59172 .01472 L
.59216 .01473 L
.59263 .01473 L
.59312 .01472 L
.59417 .01472 L
.59465 .01472 L
.5949 .01472 L
.59516 .01472 L
.59564 .01472 L
.59608 .01472 L
.59692 .01472 L
.59738 .01472 L
.59782 .01473 L
.59823 .01473 L
.59867 .01472 L
.59944 .01472 L
.59992 .01472 L
.60037 .01472 L
.60083 .01472 L
.60108 .01472 L
.60135 .01472 L
.60228 .01472 L
.60268 .01472 L
.60312 .01472 L
.60361 .01473 L
.60408 .01472 L
Mistroke
.60511 .01472 L
.60558 .01472 L
.60607 .01472 L
.6065 .01472 L
.60696 .01472 L
.60801 .01472 L
.60829 .01472 L
.60859 .01472 L
.60887 .01473 L
.60913 .01473 L
.60938 .01472 L
.60965 .01472 L
.61019 .01472 L
.61116 .01472 L
.61164 .01472 L
.61189 .01472 L
.61215 .01472 L
.61306 .01472 L
.61357 .01472 L
.61386 .01472 L
.61412 .01472 L
.61437 .01472 L
.61464 .01473 L
.61511 .01472 L
.61604 .01472 L
.61656 .01472 L
.61704 .01472 L
.61744 .01472 L
.61788 .01472 L
.61881 .01472 L
.61931 .01472 L
.61978 .01472 L
.62004 .01473 L
.62032 .01472 L
.62082 .01472 L
.6217 .01472 L
.62217 .01472 L
.62267 .01472 L
.62296 .01472 L
.62322 .01472 L
.62374 .01472 L
.62428 .01472 L
.62486 .01472 L
.62512 .01472 L
.6254 .01472 L
.6259 .01472 L
.62636 .01472 L
.62688 .01472 L
.62736 .01472 L
.62787 .01472 L
Mistroke
.6283 .01472 L
.62878 .01472 L
.62977 .01472 L
.63031 .01472 L
.63058 .01472 L
.63083 .01472 L
.63131 .01472 L
.63157 .01472 L
.63183 .01472 L
.63275 .01472 L
.63316 .01472 L
.6336 .01472 L
.63408 .01472 L
.63453 .01472 L
.63551 .01472 L
.63604 .01472 L
.63654 .01472 L
.63697 .01472 L
.63742 .01472 L
.6384 .01472 L
.63895 .01472 L
.63922 .01472 L
.63947 .01472 L
.63973 .01472 L
.64001 .01472 L
.6406 .01472 L
.64109 .01472 L
.64163 .01472 L
.64188 .01472 L
.64214 .01472 L
.64261 .01472 L
.64352 .01472 L
.64402 .01472 L
.64449 .01472 L
.64493 .01472 L
.64541 .01472 L
.64626 .01472 L
.64678 .01472 L
.64726 .01472 L
.64754 .01472 L
.64783 .01472 L
.64809 .01472 L
.64834 .01472 L
.64935 .01472 L
.64979 .01472 L
.65027 .01472 L
.65075 .01472 L
.65119 .01472 L
.65206 .01472 L
.65254 .01472 L
Mistroke
.65299 .01472 L
.65346 .01472 L
.65371 .01472 L
.65398 .01472 L
.65486 .01472 L
.65534 .01472 L
.65579 .01472 L
.65617 .01472 L
.65658 .01472 L
.65745 .01472 L
.65794 .01472 L
.65846 .01472 L
.65874 .01472 L
.65904 .01472 L
.65957 .01472 L
.66053 .01472 L
.66079 .01472 L
.66106 .01472 L
.66133 .01472 L
.66157 .01472 L
.66206 .01472 L
.66258 .01472 L
.66351 .01472 L
.664 .01472 L
.66446 .01472 L
.66487 .01472 L
.66532 .01472 L
.66623 .01472 L
.66649 .01472 L
.66673 .01472 L
.6672 .01472 L
.66763 .01472 L
.66804 .01472 L
.66895 .01472 L
.66939 .01472 L
.66987 .01472 L
.67014 .01472 L
.67039 .01472 L
.67088 .01472 L
.67188 .01472 L
.67238 .01472 L
.67267 .01472 L
.67293 .01472 L
.67398 .01472 L
.67449 .01472 L
.67497 .01472 L
.6754 .01472 L
.67585 .01472 L
.67681 .01472 L
.67731 .01472 L
Mistroke
.67758 .01472 L
.67784 .01472 L
.67833 .01472 L
.67879 .01472 L
.67991 .01472 L
.68018 .01472 L
.68046 .01472 L
.68096 .01472 L
.68136 .01472 L
.6818 .01472 L
.6827 .01472 L
.68319 .01472 L
.68346 .01472 L
.6837 .01472 L
.68418 .01472 L
.68463 .01472 L
.68554 .01472 L
.686 .01472 L
.68626 .01472 L
.68651 .01472 L
.68677 .01472 L
.68701 .01472 L
.68756 .01472 L
.68803 .01472 L
.68854 .01472 L
.689 .01472 L
.68943 .01472 L
.68986 .01472 L
.69026 .01472 L
.69073 .01472 L
.69123 .01472 L
.69166 .01472 L
.69213 .01472 L
.69254 .01472 L
.69298 .01472 L
.69378 .01472 L
.69425 .01472 L
.69471 .01472 L
.69511 .01472 L
.69555 .01472 L
.69644 .01472 L
.69691 .01472 L
.6974 .01472 L
.69783 .01472 L
.69831 .01472 L
.69914 .01472 L
.69965 .01472 L
.70013 .01472 L
.70039 .01472 L
.70068 .01472 L
Mistroke
.70119 .01472 L
.70166 .01472 L
.70217 .01472 L
.70265 .01472 L
.70309 .01472 L
.70359 .01472 L
.70406 .01472 L
.70461 .01472 L
.70512 .01472 L
.70561 .01472 L
.70589 .01472 L
.70614 .01472 L
.70726 .01472 L
.70772 .01472 L
.70821 .01472 L
.70847 .01472 L
.70875 .01472 L
.70924 .01472 L
.7102 .01472 L
.71063 .01472 L
.7111 .01472 L
.71156 .01472 L
.71206 .01472 L
.7131 .01472 L
.71358 .01472 L
.71384 .01472 L
.71408 .01472 L
.71455 .01472 L
.715 .01472 L
.71582 .01472 L
.71627 .01472 L
.7167 .01472 L
.71694 .01472 L
.7172 .01472 L
.71766 .01472 L
.71855 .01472 L
.71902 .01472 L
.71951 .01472 L
.7198 .01472 L
.72006 .01472 L
.72057 .01472 L
.7211 .01472 L
.72167 .01472 L
.72193 .01472 L
.72221 .01472 L
.7227 .01472 L
.72358 .01472 L
.72452 .01472 L
.72478 .01472 L
.72506 .01472 L
Mistroke
.72556 .01472 L
.72653 .01472 L
.727 .01472 L
.72724 .01472 L
.72751 .01472 L
.72799 .01472 L
.72843 .01472 L
.72927 .01472 L
.72972 .01472 L
.73016 .01472 L
.73066 .01472 L
.73112 .01472 L
.73201 .01472 L
.73248 .01472 L
.73298 .01472 L
.73327 .01472 L
.73353 .01472 L
.73405 .01472 L
.73489 .01472 L
.73535 .01472 L
.73578 .01472 L
.73624 .01472 L
.73649 .01472 L
.73675 .01472 L
.73765 .01472 L
.73809 .01472 L
.73856 .01472 L
.73901 .01472 L
.73943 .01472 L
.74021 .01472 L
.74104 .01472 L
.74148 .01472 L
.74197 .01472 L
.74281 .01472 L
.74329 .01472 L
.7438 .01472 L
.74428 .01472 L
.74472 .01472 L
.74557 .01472 L
.74602 .01472 L
.74649 .01472 L
.74691 .01472 L
.74736 .01472 L
.74778 .01472 L
.74816 .01472 L
.74865 .01472 L
.74918 .01472 L
.74968 .01472 L
.75015 .01472 L
.75056 .01472 L
Mistroke
.75102 .01472 L
.75195 .01472 L
.75221 .01472 L
.75248 .01472 L
.75296 .01472 L
.75323 .01472 L
.75348 .01472 L
.75405 .01472 L
.75454 .01472 L
.755 .01472 L
.75526 .01472 L
.75553 .01472 L
.75602 .01472 L
.75691 .01472 L
.75741 .01472 L
.75788 .01472 L
.75831 .01472 L
.75878 .01472 L
.75962 .01472 L
.76013 .01472 L
.76061 .01472 L
.76088 .01472 L
.76117 .01472 L
.76167 .01472 L
.76266 .01472 L
.76314 .01472 L
.76358 .01472 L
.76405 .01472 L
.76455 .01472 L
.76561 .01472 L
.76614 .01472 L
.76643 .01472 L
.76671 .01472 L
.76775 .01472 L
.76864 .01472 L
.76914 .01472 L
.76961 .01472 L
.77064 .01472 L
.77114 .01472 L
.77159 .01472 L
.77204 .01472 L
.77246 .01472 L
.77338 .01472 L
.77384 .01472 L
.77432 .01472 L
.77457 .01472 L
.77485 .01472 L
.77534 .01472 L
.77632 .01472 L
.77686 .01472 L
Mistroke
.77713 .01472 L
.77738 .01472 L
.77785 .01472 L
.77837 .01472 L
.77928 .01472 L
.77973 .01472 L
.78021 .01472 L
.78066 .01472 L
.78108 .01472 L
.78192 .01472 L
.78233 .01472 L
.7827 .01472 L
.78311 .01472 L
.78354 .01472 L
.78447 .01472 L
.78493 .01472 L
.78543 .01472 L
.7859 .01472 L
.78633 .01472 L
.78724 .01472 L
.78769 .01472 L
.78811 .01472 L
.78858 .01472 L
.78883 .01472 L
.7891 .01472 L
.79001 .01472 L
.79046 .01472 L
.79094 .01472 L
.7914 .01472 L
.79182 .01472 L
.79261 .01472 L
.79346 .01472 L
.79395 .01472 L
.7944 .01472 L
.79528 .01472 L
.79577 .01472 L
.79631 .01472 L
.79655 .01472 L
.79681 .01472 L
.79728 .01472 L
.7982 .01472 L
.79869 .01472 L
.7992 .01472 L
.79947 .01472 L
.79977 .01472 L
.80004 .01472 L
.80029 .01472 L
.80132 .01472 L
.8018 .01472 L
.80207 .01472 L
Mistroke
.80232 .01472 L
.80276 .01472 L
.80324 .01472 L
.8038 .01472 L
.80433 .01472 L
.8048 .01472 L
.80507 .01472 L
.80532 .01472 L
.80628 .01472 L
.80715 .01472 L
.80763 .01472 L
.80809 .01472 L
.80858 .01472 L
.80911 .01472 L
.80996 .01472 L
.81045 .01472 L
.8109 .01472 L
.81138 .01472 L
.81181 .01472 L
.81232 .01472 L
.81279 .01472 L
.8132 .01472 L
.81363 .01472 L
.81406 .01472 L
.81454 .01472 L
.81539 .01472 L
.81581 .01472 L
.81619 .01472 L
.81662 .01472 L
.81708 .01472 L
.81806 .01472 L
.81855 .01472 L
.81882 .01472 L
.81908 .01472 L
.82004 .01472 L
.82046 .01472 L
.82092 .01472 L
.82136 .01472 L
.82175 .01472 L
.82219 .01472 L
.82261 .01472 L
.82356 .01472 L
.82402 .01472 L
.82452 .01472 L
.82477 .01472 L
.82505 .01472 L
.82554 .01472 L
.82641 .01472 L
.82691 .01472 L
.82737 .01472 L
Mistroke
.82764 .01472 L
.82788 .01472 L
.82842 .01472 L
.82895 .01472 L
.82923 .01472 L
.82953 .01472 L
.82978 .01472 L
.83006 .01472 L
.83055 .01472 L
.83151 .01472 L
.83197 .01472 L
.83246 .01472 L
.83274 .01472 L
.833 .01472 L
.83349 .01472 L
.8344 .01472 L
.83487 .01472 L
.83537 .01472 L
.83583 .01472 L
.83632 .01472 L
.83719 .01472 L
.83762 .01472 L
.83808 .01472 L
.83851 .01472 L
.83891 .01472 L
.83986 .01472 L
.84038 .01472 L
.84086 .01472 L
.84112 .01472 L
.84139 .01472 L
.84197 .01472 L
.84246 .01472 L
.84299 .01472 L
.84324 .01472 L
.8435 .01472 L
.84398 .01472 L
.84425 .01472 L
.84452 .01472 L
.84501 .01472 L
.8459 .01472 L
.8464 .01472 L
.84686 .01472 L
.84777 .01472 L
.84864 .01472 L
.84912 .01472 L
.84939 .01472 L
.84964 .01472 L
.85055 .01472 L
.85101 .01472 L
.85143 .01472 L
Mistroke
.85181 .01472 L
.85223 .01472 L
.85268 .01472 L
.85316 .01472 L
.85401 .01472 L
.8545 .01472 L
.85495 .01472 L
.85519 .01472 L
.85546 .01472 L
.85595 .01472 L
.85641 .01472 L
.85689 .01472 L
.8573 .01472 L
.85776 .01472 L
.8588 .01472 L
.85976 .01472 L
.86025 .01472 L
.86052 .01472 L
.86077 .01472 L
.86187 .01472 L
.86234 .01472 L
.86283 .01472 L
.86308 .01472 L
.86336 .01472 L
.86386 .01472 L
.86476 .01472 L
.86526 .01472 L
.86573 .01472 L
.86618 .01472 L
.86668 .01472 L
.86755 .01472 L
.86798 .01472 L
.86844 .01472 L
.86883 .01472 L
.86926 .01472 L
.87022 .01472 L
.87074 .01472 L
.87123 .01472 L
.87149 .01472 L
.87176 .01472 L
.87234 .01472 L
.87336 .01472 L
.87385 .01472 L
.87413 .01472 L
.87439 .01472 L
.87537 .01472 L
.87626 .01472 L
.87671 .01472 L
.87721 .01472 L
.8777 .01472 L
Mistroke
.87816 .01472 L
.8787 .01472 L
.87919 .01472 L
.87966 .01472 L
.8801 .01472 L
.88107 .01472 L
.8815 .01472 L
.88196 .01472 L
.88235 .01472 L
.88277 .01472 L
.88371 .01472 L
.88461 .01472 L
.88511 .01472 L
.88539 .01472 L
.88565 .01472 L
.88659 .01472 L
.88713 .01472 L
.88763 .01472 L
.88788 .01472 L
.88815 .01472 L
.88872 .01472 L
.8897 .01472 L
.88996 .01472 L
.89023 .01472 L
.89073 .01472 L
.89119 .01472 L
.8916 .01472 L
.89256 .01472 L
.89299 .01472 L
.89344 .01472 L
.89395 .01472 L
.89441 .01472 L
.89489 .01472 L
.89542 .01472 L
.89591 .01472 L
.89637 .01472 L
.89684 .01472 L
.89726 .01472 L
.89771 .01472 L
.8982 .01472 L
.89865 .01472 L
.89907 .01472 L
.89946 .01472 L
.89988 .01472 L
.90082 .01472 L
.9011 .01472 L
.90135 .01472 L
.90184 .01472 L
.90229 .01472 L
.90271 .01472 L
Mistroke
.90366 .01472 L
.90415 .01472 L
.90462 .01472 L
.90488 .01472 L
.90512 .01472 L
.90567 .01472 L
.90619 .01472 L
.90647 .01472 L
.90676 .01472 L
.90705 .01472 L
.9073 .01472 L
.9078 .01472 L
.90876 .01472 L
.90923 .01472 L
.90966 .01472 L
.91011 .01472 L
.91059 .01472 L
.91162 .01472 L
.91204 .01472 L
.91248 .01472 L
.91297 .01472 L
.91342 .01472 L
.91431 .01472 L
.9147 .01472 L
.91513 .01472 L
.91559 .01472 L
.91607 .01472 L
.91708 .01472 L
.91753 .01472 L
.91802 .01472 L
.91848 .01472 L
.9189 .01472 L
.91993 .01472 L
.92047 .01472 L
.92076 .01472 L
.92104 .01472 L
.92154 .01472 L
.92209 .01472 L
.92306 .01472 L
.92354 .01472 L
.9238 .01472 L
.92405 .01472 L
.92496 .01472 L
.92547 .01472 L
.92602 .01472 L
.92628 .01472 L
.92654 .01472 L
.92702 .01472 L
.92789 .01472 L
.92837 .01472 L
Mistroke
.92882 .01472 L
.92907 .01472 L
.92935 .01472 L
.92984 .01472 L
.93079 .01472 L
.9312 .01472 L
.93163 .01472 L
.93212 .01472 L
.93257 .01472 L
.93349 .01472 L
.93399 .01472 L
.93446 .01472 L
.93487 .01472 L
.9353 .01472 L
.93623 .01472 L
.93666 .01472 L
.93708 .01472 L
.93745 .01472 L
.93785 .01472 L
.93832 .01472 L
.93875 .01472 L
.93921 .01472 L
.93972 .01472 L
.94018 .01472 L
.94061 .01472 L
.94102 .01472 L
.94146 .01472 L
.94193 .01472 L
.94243 .01472 L
.94291 .01472 L
.94335 .01472 L
.94383 .01472 L
.94436 .01472 L
.94491 .01472 L
.94518 .01472 L
.94543 .01472 L
.94568 .01472 L
.94594 .01472 L
.9462 .01472 L
.94648 .01472 L
.94744 .01472 L
.94797 .01472 L
.94827 .01472 L
.94855 .01472 L
.94881 .01472 L
.94909 .01472 L
.94958 .01472 L
.95056 .01472 L
.95083 .01472 L
.9511 .01472 L
Mistroke
.95159 .01472 L
.95206 .01472 L
.95248 .01472 L
.95298 .01472 L
.95345 .01472 L
.9539 .01472 L
.95439 .01472 L
.95483 .01472 L
.95524 .01472 L
.95617 .01472 L
.95664 .01472 L
.95691 .01472 L
.95716 .01472 L
.95883 .01472 L
.95929 .01472 L
.95977 .01472 L
.96018 .01472 L
.96063 .01472 L
.96111 .01472 L
.96164 .01472 L
.96214 .01472 L
.9626 .01472 L
.96285 .01472 L
.96313 .01472 L
.9637 .01472 L
.96423 .01472 L
.9647 .01472 L
.96519 .01472 L
.96565 .01472 L
.96666 .01472 L
.96709 .01472 L
.96754 .01472 L
.96804 .01472 L
.9685 .01472 L
.96943 .01472 L
.96993 .01472 L
.9704 .01472 L
.97065 .01472 L
.97092 .01472 L
.97148 .01472 L
.97246 .01472 L
.97294 .01472 L
.9732 .01472 L
.97346 .01472 L
.97396 .01472 L
.97441 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00033ooooo0_l0000coooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000;Oooool2o`0000Cooooo00Co0000oooo
oooooooooooo1Ol0000/ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00002oooool0
01gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0^ooooo`04o`000?oooooo
ooooo`00037ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0[ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000:oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000002_ooool001Kooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool0000aooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool0:oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`08
ooooo`007Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo02kooooo00Co0000
oooooooooooo0000<Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo02_ooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`00
00Wooooo0_l0000;ooooo`007Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
02kooooo00Co0000oooooooooooo0000<Oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo02_ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002_o
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`08ooooo`007Oooool01?l0003o
ooooooooool00008ooooo`;o0000<?ooool01?l0003oooooooooool0000aooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0000]ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`00000[ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000:
ooooo`007_ooool2o`0000[ooooo00?o0000ooooooooool0;oooool2o`0003?ooooo0_l0000:oooo
o`03o`000?oooooooooo02cooooo0_l00009ooooo`?o0000;Oooool2o`0000Wooooo0ol0000;oooo
o`007?ooool00ol0003oooooooooo`3oooooo`;ooooo000Looooo`03o`000?oooooooooo0?oooooo
0_ooool001cooooo00?o0000ooooooooool0ooooool2ooooo`007?ooool00ol0003oooooooooo`0/
ooooo`03ool00?oooooooooo0=;ooooo000Fooooo`Ko0000@?oo0003o`000:ooo`001_l0000<oooo
o`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`06ooooo`[o000000?oooooo`000?l000000_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Cooooo1Ooo00000ol0003oooooool00003ool000Ko
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<o`0000Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo1_l000000ooooooo
0000ooooo`08ooooo`So00001Oooool00ol0003oooooo`000005o`0000Cooooo00?o0000oooooooo
ool00oooool5o`000003ooooool0003ooooo00Wooooo2ol000000ooooooo0000ooooo`0:ooooo`03
o`000?oooooo000000;o00001oooool00ol0003oooooooooo`0?ooooo`007?ooool00ol0003ooooo
ooooo`0@ooooo`Wo00008_ooool3ool000;ooooo0ooo000Qooooo`Wo00006?ooool6o`0001Oooooo
2Ol0000Cooooo`Go000000?oooooo`000?l000001Ol0000;ooooo`;o00002oooool3o`0001_ooooo
000Loooooa?o0000;?ooool2ool000;ooooo0_oo000Zooooo`_o000000Coooooo`000?l0003ooooo
2_l0000nooooo`Co00004Oooool2o`0000Oooooo0_l0000Nooooo`007?ooool00ol0003ooooooooo
o`02ooooo`;o000000Coooooo`000?l0003ooooo0_l0000booooo`;oo`000_ooool2ool003;ooooo
00?o0000ooooooooool01?l0001Nooooo`So00008?ooool001cooooo00?o0000ooooooooool0??oo
ool2ool000;ooooo0_oo002Kooooo`;o00008_ooool001cooooo00?o0000ooooooooool0??ooool2
ool000;ooooo00?oo`00ooooooooool0__ooool001cooooo00?o0000ooooooooool0??ooool2ool0
00;ooooo00?oo`00ooooooooool0__ooool001cooooo0_l0000nooooo`04ool00?ooooooooooool0
0<3ooooo000Looooo`03o`000?oooooooooo03gooooo00Coo`00ooooooooooooo`00`?ooool001co
oooo00?o0000ooooooooool0?Oooool01?oo003ooooooooooooo0030ooooo`007?ooool00ol0003o
ooooooooo`0mooooo`04ool00?ooooooooooool00<3ooooo000Looooo`03o`000?oooooooooo03go
oooo00Coo`00ooooooooooooo`00`?ooool001cooooo00?o0000ooooooooool0?Oooool01?oo003o
oooooooooooo0030ooooo`007?ooool00ol0003oooooooooo`0mooooo`04ool00?ooooooooooool0
0<3ooooo000Looooo`;o0000?_ooool01?oo003ooooooooooooo0030ooooo`007?ooool00ol0003o
ooooooooo`0mooooo`04ool00?ooooooooooool00<3ooooo000Looooo`03o`000?oooooooooo03go
oooo00Coo`00ooooooooooooo`00`?ooool001cooooo00?o0000ooooooooool0?Oooool00ooo003o
ooooool00031ooooo`007?ooool00ol0003oooooooooo`0mooooo`03ool00?ooooooo`000<7ooooo
000Looooo`03o`000?oooooooooo03gooooo00?oo`00oooooooo0000`Oooool001cooooo00?o0000
ooooooooool0?Oooool00ooo003oooooool00031ooooo`007?ooool00ol0003oooooooooo`0moooo
o`03ool00?ooooooo`000<7ooooo000Looooo`;o0000?_ooool00ooo003oooooool00031ooooo`00
7?ooool00ol0003oooooooooo`0mooooo`03ool00?ooooooo`000<7ooooo000Looooo`03o`000?oo
oooooooo03gooooo00?oo`00oooooooo0000`Oooool001cooooo00?o0000ooooooooool0?Oooool0
0ooo003oooooool00031ooooo`007?ooool00ol0003oooooooooo`0mooooo`03ool00?ooooooo`00
0<7ooooo000Looooo`03o`000?oooooooooo03gooooo00?oo`00oooooooo0000`Oooool000Wooooo
0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`0mooooo`03
ool00?ooooooo`000<7ooooo0008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0mooooo`03ool00?ooooooo`000<7ooooo0008ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool3o`0003gooooo00?oo`00oooo
oooo0000`Oooool000Sooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo03gooooo00?oo`00oooooooo0000`Oooool000Sooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0?Oooool0
0ooo003oooooool00031ooooo`002?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0mooooo`03ool00?ooooooo`000<7ooooo0009
ooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool0?Oooool00ooo003oooooool00031
ooooo`007?ooool00ol0003oooooooooo`0mooooo`03ool00?ooooooo`000<7ooooo000Looooo`03
o`000?oooooooooo03gooooo00?oo`00oooooooo0000`Oooool001cooooo00?o0000ooooooooool0
?Oooool00ooo003oooooool00031ooooo`007?ooool2o`0003kooooo00?oo`00oooooooo0000`Ooo
ool001cooooo00?o0000ooooooooool0?Oooool00ooo003oooooool00031ooooo`007?ooool00ol0
003oooooooooo`0mooooo`03ool00?ooooooo`000<7ooooo000Looooo`03o`000?oooooooooo03go
oooo00?oo`00oooooooo0000`Oooool001cooooo00?o0000ooooooooool0?Oooool00ooo003ooooo
ool00031ooooo`007?ooool00ol0003oooooooooo`0mooooo`03ool00?ooooooo`000<7ooooo000L
ooooo`03o`000?oooooooooo03gooooo00?oo`00oooooooo0000`Oooool001cooooo00?o0000oooo
ooooool0?Oooool00ooo003oooooool00031ooooo`007?ooool2o`0003kooooo00?oo`00oooooooo
0000`Oooool001cooooo00?o0000ooooooooool0?Oooool00ooo003oooooool00031ooooo`007?oo
ool00ol0003oooooooooo`0mooooo`03ool00?ooooooo`000<7ooooo000Looooo`03o`000?oooooo
oooo03gooooo00?oo`00oooooooo0000`Oooool001cooooo00?o0000ooooooooool0?Oooool00ooo
003oooooool00031ooooo`007?ooool00ol0003oooooooooo`0mooooo`03ool00?ooooooo`000<7o
oooo000Looooo`03o`000?oooooooooo03gooooo00?oo`00oooooooo0000`Oooool001cooooo0_l0
000nooooo`03ool00?ooooooo`000<7ooooo000Looooo`03o`000?oooooooooo03gooooo00?oo`00
oooooooo0000`Oooool001cooooo00?o0000ooooooooool0?Oooool00ooo003oooooool00031oooo
o`007?ooool00ol0003oooooooooo`0nooooo`;oo`00`Oooool001cooooo00?o0000ooooooooool0
?_ooool2ool00<7ooooo000Looooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`002Oooool2
o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0?_ooool2
ool00<7ooooo0008ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0nooooo`;oo`00`Oooool000Sooooo00Co0000oooooooooooo00001oooool5
o`0000Cooooo0ol0000nooooo`;oo`00`Oooool000Sooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`002?ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0?_oo
ool2ool00<7ooooo0008ooooo`04o`000?ooooooooooo`0000Wooooo0_l00005ooooo`03o`000?oo
oooooooo03kooooo0_oo0031ooooo`002Oooool2o`0000_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0nooooo`;oo`00`Oooool001cooooo00?o0000ooooooooool0?_ooool2ool0
0<7ooooo000Looooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`007?ooool00ol0003ooooo
ooooo`0nooooo`;oo`00`Oooool001cooooo0_l0000oooooo`;oo`00`Oooool001cooooo00?o0000
ooooooooool0?_ooool2ool00<7ooooo000Looooo`03o`000?oooooooooo03kooooo0_oo0031oooo
o`007?ooool00ol0003oooooooooo`0nooooo`;oo`00`Oooool001cooooo00?o0000ooooooooool0
?_ooool2ool00<7ooooo000Looooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`007?ooool0
0ol0003oooooooooo`0nooooo`;oo`00`Oooool001cooooo00?o0000ooooooooool0?_ooool2ool0
0<7ooooo000Looooo`;o0000?oooool2ool00<7ooooo000Looooo`03o`000?oooooooooo03kooooo
0_oo0031ooooo`007?ooool00ol0003oooooooooo`0nooooo`;oo`00`Oooool001cooooo00?o0000
ooooooooool0?_ooool2ool00<7ooooo000Looooo`03o`000?oooooooooo03kooooo0_oo0031oooo
o`007?ooool00ol0003oooooooooo`0nooooo`;oo`00`Oooool001cooooo00?o0000ooooooooool0
?_ooool2ool00<7ooooo000Looooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`007?ooool2
o`0003oooooo0_oo0031ooooo`007?ooool00ol0003oooooooooo`0nooooo`;oo`00`Oooool001co
oooo00?o0000ooooooooool0?_ooool2ool00<7ooooo000Looooo`03o`000?oooooooooo03kooooo
0_oo0031ooooo`007?ooool00ol0003oooooooooo`0nooooo`;oo`00`Oooool000Wooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo03kooooo0_oo0031
ooooo`002?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`0nooooo`;oo`00`Oooool000Sooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0?_ooool2ool00<7ooooo
0008ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`?o0000?_ooool2ool00<7ooooo
0008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0nooooo`;oo`00`Oooool000Sooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`002Oooool2o`0000[ooooo0_l0
0005ooooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;oo`00`Oooool001cooooo00?o0000ooooooooool0?_ooool2ool00<7ooooo000Looooo`03
o`000?oooooooooo03kooooo0_oo0031ooooo`007?ooool2o`0003oooooo0_oo0031ooooo`007?oo
ool00ol0003oooooooooo`0nooooo`;oo`00`Oooool001cooooo00?o0000ooooooooool0?_ooool2
ool00<7ooooo000Looooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`007?ooool00ol0003o
ooooooooo`0nooooo`;oo`00`Oooool001cooooo00?o0000ooooooooool0?_ooool2ool00<7ooooo
000Looooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;oo`00`Oooool001cooooo0_l0000oooooo`;oo`00`Oooool001cooooo00?o0000oooooooo
ool0?_ooool2ool00<7ooooo000Looooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`007?oo
ool00ol0003oooooooooo`0nooooo`;oo`00`Oooool001cooooo00?o0000ooooooooool0?_ooool2
ool00<7ooooo000Looooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`007?ooool00ol0003o
ooooooooo`0nooooo`;oo`00`Oooool001cooooo00?o0000ooooooooool0?_ooool2ool00<7ooooo
000Looooo`;o0000?oooool2ool00<7ooooo000Looooo`03o`000?oooooooooo03kooooo0_oo0031
ooooo`007?ooool00ol0003oooooooooo`0nooooo`;oo`00`Oooool001cooooo00?o0000oooooooo
ool0?_ooool2ool00<7ooooo000Looooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`002Ooo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0?_oo
ool2ool00<7ooooo0008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo03kooooo0_oo0031ooooo`002?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0nooooo`;o
o`00`Oooool000Sooooo00Co0000oooooooooooo00002?ooool3o`0000Gooooo0ol0000nooooo`;o
o`00`Oooool000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0?_ooool2ool00<7ooooo0008ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03kooooo00?oo`00
ooooooooool0`?ooool000Wooooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`0noooo
o`03ool00?oooooooooo0<3ooooo000Looooo`03o`000?oooooooooo03kooooo00?oo`00oooooooo
ool0`?ooool001cooooo00?o0000ooooooooool0?_ooool00ooo003oooooooooo`30ooooo`007?oo
ool00ol0003oooooooooo`0nooooo`03ool00?oooooooooo0<3ooooo000Looooo`03o`000?oooooo
oooo03kooooo00?oo`00ooooooooool0`?ooool001cooooo0_l0000oooooo`03ool00?oooooooooo
0<3ooooo000Looooo`03o`000?oooooooooo03kooooo00?oo`00ooooooooool0`?ooool001cooooo
00?o0000ooooooooool0?_ooool00ooo003oooooooooo`30ooooo`007?ooool00ol0003ooooooooo
o`0nooooo`03ool00?oooooooooo0<3ooooo000Looooo`03o`000?oooooooooo03kooooo00?oo`00
ooooooooool0`?ooool001cooooo00?o0000ooooooooool0?_ooool00ooo003oooooooooo`30oooo
o`007?ooool00ol0003oooooooooo`0nooooo`03ool00?oooooooooo0<3ooooo000Looooo`;o0000
?oooool00ooo003oooooooooo`30ooooo`007?ooool00ol0003oooooooooo`0nooooo`03ool00?oo
oooooooo0<3ooooo000Looooo`03o`000?oooooooooo03kooooo00?oo`00ooooooooool0`?ooool0
01cooooo00?o0000ooooooooool0?_ooool00ooo003oooooooooo`30ooooo`007?ooool00ol0003o
ooooooooo`0nooooo`03ool00?oooooooooo0<3ooooo000Looooo`03o`000?oooooooooo03kooooo
00?oo`00ooooooooool0`?ooool001cooooo00?o0000ooooooooool0?_ooool00ooo003ooooooooo
o`30ooooo`007?ooool00ol0003oooooooooo`0nooooo`03ool00?oooooooooo0<3ooooo000Loooo
o`;o0000?oooool00ooo003oooooooooo`30ooooo`007?ooool00ol0003oooooooooo`0nooooo`03
ool00?oooooooooo0<3ooooo000Looooo`03o`000?oooooooooo0?oooooo0_ooool001cooooo00?o
0000ooooooooool0ooooool2ooooo`007?ooool00ol0003oooooooooo`3oooooo`;ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo001Rooooo`?o0000DOooool3o`0006Oooooo001S
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0I_ooool003Sooooo0ol00004oooo
o`?o00000_ooool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00002Oooool3
o`0000?ooooo0ol00002ooooo`?o00001?ooool3o`0000?ooooo1?l00002ooooo`Co00001oooool5
o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00000oooool3o`0000;ooooo0ol0
00000ooooooo0000o`000004o`0000;ooooo1Ol00003ooooo`;o00001?ooool00ol0003ooooooooo
o`07ooooo`?o00001Oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo
0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l00000
;_ooool003Wooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`00
0?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000;ooo
ool003Wooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00cooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`Go00000_ooool3o`00
00;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooooooo0000
0_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000Wooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`06
o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02gooooo
000iooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`04
o`000?ooooooooooo`0000;ooooo0_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`?o00000ooo
ool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0
003oooooooooool00006ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo02gooooo000iooooo`04o`000?ooooooooooo`0000;ooooo
0ol00002ooooo`?o00000oooool4o`0000;ooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo
1?l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo0_l00004ooooo`?o0000
2_ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000?o
oooo1?l000001?oooooo0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o0000
00Sooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool3
o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l0000`ooooo`00>Oooool01?l0
003oooooooooool0000Dooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00007?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0
@_ooool003Sooooo1?l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_oo
ool3o`0001_ooooo0_l00008ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03_ooool5o`0001Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0kooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.159322, -0.0777593, \
0.00169909, 0.00639387}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00443385 0.0280925 0.561849 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2455 -0.0125 -6 -9 ]
[.2455 -0.0125 6 0 ]
[.46719 -0.0125 -9 -9 ]
[.46719 -0.0125 9 0 ]
[.68889 -0.0125 -9 -9 ]
[.68889 -0.0125 9 0 ]
[.91058 -0.0125 -9 -9 ]
[.91058 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .14046 -18 -4.5 ]
[-0.0125 .14046 0 4.5 ]
[-0.0125 .25283 -18 -4.5 ]
[-0.0125 .25283 0 4.5 ]
[-0.0125 .3652 -18 -4.5 ]
[-0.0125 .3652 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -84 0 ]
[.5 .63053 84 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2455 0 m
.2455 .00625 L
s
[(50)] .2455 -0.0125 0 1 Mshowa
.46719 0 m
.46719 .00625 L
s
[(100)] .46719 -0.0125 0 1 Mshowa
.68889 0 m
.68889 .00625 L
s
[(150)] .68889 -0.0125 0 1 Mshowa
.91058 0 m
.91058 .00625 L
s
[(200)] .91058 -0.0125 0 1 Mshowa
.125 Mabswid
.06815 0 m
.06815 .00375 L
s
.11249 0 m
.11249 .00375 L
s
.15683 0 m
.15683 .00375 L
s
.20116 0 m
.20116 .00375 L
s
.28984 0 m
.28984 .00375 L
s
.33418 0 m
.33418 .00375 L
s
.37852 0 m
.37852 .00375 L
s
.42286 0 m
.42286 .00375 L
s
.51153 0 m
.51153 .00375 L
s
.55587 0 m
.55587 .00375 L
s
.60021 0 m
.60021 .00375 L
s
.64455 0 m
.64455 .00375 L
s
.73323 0 m
.73323 .00375 L
s
.77756 0 m
.77756 .00375 L
s
.8219 0 m
.8219 .00375 L
s
.86624 0 m
.86624 .00375 L
s
.95492 0 m
.95492 .00375 L
s
.99926 0 m
.99926 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .14046 m
.00625 .14046 L
s
[(0.2)] -0.0125 .14046 1 0 Mshowa
0 .25283 m
.00625 .25283 L
s
[(0.4)] -0.0125 .25283 1 0 Mshowa
0 .3652 m
.00625 .3652 L
s
[(0.6)] -0.0125 .3652 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(0.8)] -0.0125 .47757 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(1)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2455 .61178 m
.2455 .61803 L
s
.46719 .61178 m
.46719 .61803 L
s
.68889 .61178 m
.68889 .61803 L
s
.91058 .61178 m
.91058 .61803 L
s
.125 Mabswid
.06815 .61428 m
.06815 .61803 L
s
.11249 .61428 m
.11249 .61803 L
s
.15683 .61428 m
.15683 .61803 L
s
.20116 .61428 m
.20116 .61803 L
s
.28984 .61428 m
.28984 .61803 L
s
.33418 .61428 m
.33418 .61803 L
s
.37852 .61428 m
.37852 .61803 L
s
.42286 .61428 m
.42286 .61803 L
s
.51153 .61428 m
.51153 .61803 L
s
.55587 .61428 m
.55587 .61803 L
s
.60021 .61428 m
.60021 .61803 L
s
.64455 .61428 m
.64455 .61803 L
s
.73323 .61428 m
.73323 .61803 L
s
.77756 .61428 m
.77756 .61803 L
s
.8219 .61428 m
.8219 .61803 L
s
.86624 .61428 m
.86624 .61803 L
s
.95492 .61428 m
.95492 .61803 L
s
.99926 .61428 m
.99926 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .14046 m
1 .14046 L
s
.99375 .25283 m
1 .25283 L
s
.99375 .3652 m
1 .3652 L
s
.99375 .47757 m
1 .47757 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(Modulation Transfer Function)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .58994 m
.02466 .52942 L
.02514 .49613 L
.02558 .46467 L
.02599 .41235 L
.02644 .34826 L
.02723 .23624 L
.02768 .18177 L
.02817 .14491 L
.02866 .109 L
.02892 .0892 L
.02918 .07037 L
.02966 .06096 L
.0301 .07336 L
.03055 .08588 L
.03097 .09768 L
.03145 .09989 L
.03188 .08614 L
.03238 .07008 L
.03285 .05531 L
.03325 .05429 L
.03368 .08157 L
.03459 .13902 L
.03549 .18676 L
.03599 .2086 L
.03646 .22928 L
.03673 .24097 L
.03702 .24243 L
.03729 .23617 L
.03753 .23039 L
.03805 .2181 L
.03853 .20683 L
.03898 .18842 L
.03945 .16284 L
.03996 .13498 L
.04044 .10906 L
.04085 .09691 L
.04129 .09003 L
.04178 .08245 L
.04223 .07546 L
.04248 .07213 L
.04276 .07285 L
.04333 .07437 L
.04359 .07505 L
.04386 .07579 L
.04437 .07768 L
.04485 .08387 L
.04529 .08951 L
.04557 .09303 L
.04583 .09634 L
Mistroke
.04631 .10561 L
.04656 .11429 L
.04682 .12367 L
.04736 .14291 L
.04761 .15168 L
.04787 .16093 L
.04834 .16689 L
.0486 .16696 L
.04889 .16704 L
.0494 .16718 L
.04971 .16727 L
.05 .16419 L
.05027 .1558 L
.05055 .14669 L
.05157 .11446 L
.05208 .10218 L
.05265 .09142 L
.05313 .08227 L
.05338 .07747 L
.05364 .07276 L
.05413 .07574 L
.05458 .07846 L
.05502 .08113 L
.05548 .08395 L
.05572 .0822 L
.05599 .08006 L
.05646 .0763 L
.0569 .07276 L
.05737 .06934 L
.05782 .07882 L
.05823 .08746 L
.05873 .09809 L
.05899 .1037 L
.05927 .10924 L
.05952 .11242 L
.05979 .11593 L
.06026 .12212 L
.06072 .12807 L
.06122 .13074 L
.06169 .12366 L
.06211 .11716 L
.06297 .10418 L
.06388 .08751 L
.06432 .07943 L
.06474 .07178 L
.06512 .07292 L
.06552 .07618 L
.06596 .07964 L
.06642 .08331 L
.06681 .08475 L
Mistroke
.06724 .08266 L
.06912 .07194 L
.06958 .06842 L
.07006 .06468 L
.07035 .06252 L
.0706 .06517 L
.0711 .07296 L
.07156 .08026 L
.07207 .08815 L
.07254 .09101 L
.07298 .0906 L
.07338 .09024 L
.0738 .08984 L
.07427 .08763 L
.0747 .08151 L
.07519 .07464 L
.07565 .06813 L
.07607 .06363 L
.07652 .06582 L
.07852 .07553 L
.07901 .07786 L
.07926 .07909 L
.07953 .08038 L
.07983 .07983 L
.08011 .07621 L
.08065 .0691 L
.08111 .06309 L
.0816 .0568 L
.08206 .05667 L
.08248 .05656 L
.08297 .05643 L
.08325 .05635 L
.0835 .05668 L
.08397 .06005 L
.08447 .06361 L
.08493 .06692 L
.08544 .06886 L
.08591 .06586 L
.08635 .06308 L
.08678 .06037 L
.08718 .05786 L
.08765 .05707 L
.08807 .05636 L
.08854 .05556 L
.08904 .05471 L
.08946 .05904 L
.08993 .06381 L
.09043 .06895 L
.09071 .07178 L
.09097 .07358 L
Mistroke
.09121 .07261 L
.09147 .07156 L
.09193 .06973 L
.09236 .06804 L
.09282 .06571 L
.09326 .06009 L
.09367 .05486 L
.09414 .04881 L
.09464 .04256 L
.09511 .04419 L
.09554 .04567 L
.09594 .04709 L
.09637 .04859 L
.09684 .04964 L
.09727 .05041 L
.09765 .05108 L
.09806 .0518 L
.0985 .05164 L
.09891 .04952 L
.09937 .04715 L
.09988 .04458 L
.10035 .04398 L
.10079 .04795 L
.10168 .05594 L
.10211 .05974 L
.10251 .06129 L
.10295 .063 L
.10342 .06485 L
.10391 .06677 L
.10416 .06538 L
.10443 .06334 L
.10549 .05525 L
.10647 .04627 L
.10696 .04128 L
.10722 .03865 L
.1075 .03587 L
.10774 .03432 L
.108 .03553 L
.10847 .03766 L
.10901 .04009 L
.1093 .04143 L
.10958 .04248 L
.10984 .04202 L
.11012 .04151 L
.11061 .04064 L
.11088 .04017 L
.11112 .03973 L
.11159 .03981 L
.11208 .04143 L
.11262 .04318 L
Mistroke
.11309 .04472 L
.11359 .04773 L
.11448 .05456 L
.11494 .05813 L
.11521 .05955 L
.11545 .05937 L
.11589 .05904 L
.11637 .05867 L
.1168 .05835 L
.11721 .05657 L
.11763 .05323 L
.11809 .04963 L
.11908 .04202 L
.11962 .03809 L
.12012 .03442 L
.12054 .03128 L
.121 .0308 L
.12126 .0316 L
.12151 .03235 L
.12197 .03374 L
.12236 .03494 L
.12279 .03546 L
.1232 .03513 L
.12357 .03483 L
.12401 .03447 L
.12448 .0343 L
.12487 .03737 L
.1253 .04077 L
.12577 .04447 L
.12601 .04641 L
.12627 .04845 L
.12675 .0504 L
.12719 .05202 L
.1276 .05353 L
.12803 .05514 L
.12851 .05476 L
.12896 .05351 L
.12944 .05218 L
.12969 .05147 L
.12996 .05072 L
.13045 .04755 L
.1309 .04425 L
.13134 .04107 L
.13175 .03805 L
.13223 .03616 L
.13267 .03513 L
.13313 .03405 L
.13363 .03287 L
.1341 .03205 L
.13454 .03139 L
Mistroke
.13505 .03063 L
.13553 .0299 L
.1358 .03057 L
.13609 .03201 L
.13659 .03454 L
.13837 .04382 L
.13881 .04617 L
.13927 .04869 L
.13954 .04941 L
.13978 .04972 L
.14026 .05033 L
.14066 .05084 L
.14108 .05139 L
.14155 .05019 L
.14199 .04837 L
.14363 .0412 L
.14453 .03694 L
.14499 .03496 L
.14549 .03494 L
.14592 .03492 L
.14637 .0349 L
.1468 .03488 L
.1472 .03482 L
.14815 .03466 L
.14841 .03461 L
.14868 .03457 L
.14918 .03628 L
.15105 .04294 L
.15187 .04613 L
.15234 .04792 L
.15276 .04801 L
.15315 .04779 L
.15358 .04754 L
.15399 .04732 L
.15436 .04675 L
.15484 .04458 L
.15529 .04254 L
.1557 .04068 L
.15613 .03872 L
.1566 .0381 L
.15703 .03755 L
.1575 .03696 L
.15775 .03665 L
.15801 .03634 L
.15825 .03656 L
.15852 .03681 L
.15898 .03725 L
.15943 .03766 L
.15991 .03803 L
.16037 .03763 L
Mistroke
.1608 .03727 L
.1612 .03693 L
.16163 .03656 L
.16212 .03737 L
.16258 .0384 L
.16362 .04077 L
.16453 .04357 L
.165 .04504 L
.16526 .04585 L
.16551 .04635 L
.16598 .04558 L
.16649 .04474 L
.16696 .04397 L
.16739 .0431 L
.16784 .04147 L
.16825 .03992 L
.1687 .03826 L
.16917 .0365 L
.16957 .03685 L
.17 .03728 L
.17077 .03804 L
.17166 .03928 L
.1725 .04058 L
.17295 .04116 L
.17342 .04021 L
.17428 .03849 L
.17454 .03799 L
.17481 .03754 L
.17531 .03788 L
.17624 .03853 L
.17723 .04014 L
.17771 .04123 L
.17815 .04223 L
.17862 .0429 L
.17912 .04243 L
.18018 .04143 L
.18108 .03922 L
.18155 .03786 L
.18181 .03712 L
.18206 .03642 L
.18255 .03645 L
.18299 .03716 L
.18385 .03856 L
.18464 .04024 L
.18547 .04221 L
.18591 .04324 L
.18639 .04285 L
.18682 .04233 L
.18723 .04185 L
.18815 .04042 L
Mistroke
.18914 .03827 L
.18938 .03773 L
.18965 .03714 L
.18994 .03716 L
.19022 .03725 L
.19069 .03741 L
.19094 .0375 L
.19121 .03759 L
.19171 .03789 L
.19217 .0384 L
.19269 .03897 L
.19318 .03952 L
.19364 .03929 L
.19413 .03824 L
.19457 .0373 L
.19499 .03641 L
.1954 .0358 L
.19584 .03581 L
.19629 .03582 L
.19678 .03583 L
.19704 .03583 L
.19728 .03637 L
.19777 .03815 L
.19823 .03986 L
.19867 .04147 L
.19908 .04284 L
.19953 .04359 L
.20031 .04489 L
.20076 .04563 L
.20122 .04502 L
.20162 .04412 L
.20206 .04314 L
.20302 .0405 L
.20353 .03852 L
.20407 .03643 L
.20454 .0346 L
.2048 .03444 L
.20505 .03453 L
.20596 .03484 L
.20642 .035 L
.20686 .03506 L
.20767 .03515 L
.20813 .0352 L
.20855 .0349 L
.20902 .03424 L
.20951 .03354 L
.20978 .03317 L
.21005 .03278 L
.21055 .03357 L
.21082 .03432 L
Mistroke
.21108 .03502 L
.21167 .0366 L
.21273 .04031 L
.21319 .04213 L
.21344 .04309 L
.2137 .04411 L
.21419 .04521 L
.21464 .04562 L
.21507 .046 L
.21553 .04642 L
.21601 .04618 L
.21646 .04527 L
.21749 .0432 L
.2194 .03565 L
.22047 .03261 L
.22098 .03124 L
.22144 .03027 L
.22188 .03079 L
.22235 .03135 L
.2226 .03164 L
.22286 .03195 L
.22334 .0323 L
.22378 .03188 L
.22419 .03151 L
.22464 .03109 L
.22512 .03075 L
.22561 .03226 L
.22606 .03366 L
.22709 .03699 L
.22799 .04074 L
.22846 .04271 L
.22896 .0445 L
.22924 .04509 L
.22955 .04573 L
.2301 .04687 L
.23036 .04742 L
.23065 .04802 L
.23092 .04774 L
.23116 .04737 L
.23316 .04314 L
.23498 .03676 L
.23542 .03526 L
.23588 .03368 L
.23627 .03232 L
.23669 .03189 L
.23755 .03107 L
.23848 .03026 L
.23897 .0299 L
.2395 .02952 L
.23999 .02915 L
Mistroke
.24044 .03021 L
.24256 .03596 L
.2436 .0394 L
.24456 .04192 L
.24502 .04308 L
.24544 .04416 L
.24589 .04474 L
.24638 .04507 L
.24687 .0454 L
.24733 .04571 L
.24759 .04556 L
.24787 .04504 L
.24836 .04413 L
.25022 .03983 L
.25073 .03843 L
.2512 .03713 L
.2517 .0364 L
.25224 .03559 L
.25271 .03488 L
.25315 .03436 L
.2534 .03434 L
.25367 .03431 L
.25414 .03427 L
.25458 .03423 L
.25504 .03413 L
.25544 .0339 L
.25588 .03365 L
.25637 .03337 L
.25683 .03315 L
.25708 .03328 L
.25736 .03342 L
.25784 .03367 L
.2583 .0339 L
.2588 .03434 L
.25926 .03515 L
.25968 .03588 L
.26072 .03761 L
.26127 .03834 L
.26184 .03911 L
.26209 .03944 L
.26235 .03979 L
.26264 .03992 L
.2629 .04003 L
.26341 .04023 L
.26388 .04042 L
.26434 .04042 L
.26459 .0401 L
.26486 .03975 L
.26589 .0384 L
.26678 .03691 L
Mistroke
.26726 .03607 L
.26776 .03517 L
.26805 .03479 L
.26831 .03474 L
.26883 .03464 L
.26911 .03458 L
.26941 .03452 L
.2697 .03446 L
.26996 .03455 L
.27043 .03492 L
.27094 .03534 L
.2712 .03555 L
.27147 .03577 L
.27198 .0359 L
.27222 .03586 L
.27249 .03582 L
.27296 .03575 L
.27325 .03571 L
.27352 .03567 L
.27377 .03549 L
.27403 .03528 L
.27498 .0345 L
.27546 .03413 L
.27573 .03403 L
.27598 .03394 L
.2769 .03361 L
.27717 .03351 L
.27742 .03347 L
.27789 .03345 L
.2783 .03344 L
.27873 .03343 L
.2792 .03345 L
.27964 .03368 L
.2801 .03392 L
.2806 .03418 L
.28107 .03436 L
.28151 .03416 L
.28234 .03379 L
.2828 .03358 L
.28322 .03306 L
.28418 .03173 L
.28468 .03103 L
.28493 .03083 L
.28521 .03066 L
.28571 .03036 L
.28618 .03008 L
.28661 .02986 L
.28708 .03058 L
.28797 .03197 L
.28895 .03327 L
Mistroke
.2894 .03377 L
.28987 .03429 L
.29028 .03474 L
.29072 .0348 L
.29115 .0348 L
.29155 .0348 L
.29198 .0348 L
.29244 .0347 L
.29284 .03453 L
.29321 .03438 L
.29361 .03421 L
.29405 .03403 L
.29453 .03347 L
.29505 .03288 L
.29553 .03233 L
.29597 .03185 L
.29624 .0317 L
.29649 .03155 L
.29705 .03122 L
.29753 .03094 L
.2978 .0308 L
.29805 .0309 L
.299 .0313 L
.29946 .03149 L
.29989 .03159 L
.30038 .03165 L
.30091 .0317 L
.30136 .03175 L
.30184 .03177 L
.30228 .03178 L
.30268 .03178 L
.30314 .03179 L
.30358 .03163 L
.30399 .03132 L
.30436 .03103 L
.30477 .03071 L
.30521 .03038 L
.30565 .03038 L
.30607 .03041 L
.30652 .03044 L
.30701 .03047 L
.30749 .03067 L
.30801 .03093 L
.30892 .03139 L
.30989 .03206 L
.3104 .03242 L
.31067 .03262 L
.31093 .03278 L
.31141 .03298 L
.31193 .0332 L
Mistroke
.31237 .03338 L
.31284 .03346 L
.31329 .03326 L
.31379 .03305 L
.3147 .03267 L
.31557 .03234 L
.316 .03217 L
.3164 .03203 L
.31686 .03172 L
.31735 .03138 L
.31785 .03104 L
.31812 .03086 L
.31841 .03075 L
.31869 .03077 L
.31894 .03078 L
.31945 .03081 L
.31972 .03082 L
.32001 .03084 L
.32029 .03092 L
.32054 .03105 L
.3215 .03156 L
.32198 .03181 L
.32241 .03192 L
.32286 .03202 L
.32335 .03214 L
.32438 .03242 L
.32487 .03258 L
.32533 .03273 L
.32575 .03285 L
.3262 .03268 L
.32813 .03198 L
.32979 .03147 L
.33074 .03126 L
.33162 .03108 L
.33258 .03092 L
.33286 .03087 L
.33312 .03083 L
.33361 .03103 L
.33415 .03129 L
.33471 .03157 L
.33519 .03176 L
.33547 .03178 L
.33573 .0318 L
.33615 .03183 L
.3366 .03187 L
.33709 .03193 L
.33754 .03204 L
.33799 .03216 L
.33848 .03228 L
.33876 .03234 L
Mistroke
.33901 .03234 L
.33951 .03233 L
.34336 .03143 L
.34388 .03138 L
.34438 .03134 L
.34465 .03123 L
.34494 .03111 L
.34547 .03091 L
.34596 .03072 L
.34624 .03061 L
.34649 .03063 L
.34744 .03071 L
.34785 .03074 L
.3483 .0308 L
.34878 .0309 L
.34923 .03099 L
.34962 .03107 L
.35003 .03114 L
.35049 .03118 L
.35092 .03121 L
.35141 .03124 L
.35169 .03127 L
.35194 .03132 L
.35242 .03148 L
.35292 .03166 L
.35334 .0318 L
.35379 .03191 L
.35428 .03185 L
.35474 .03178 L
.35522 .03171 L
.35568 .03166 L
.35593 .03165 L
.3562 .03165 L
.35668 .03163 L
.35755 .0316 L
.35847 .03156 L
.35894 .03154 L
.3592 .03153 L
.35945 .03146 L
.35988 .03129 L
.36035 .03111 L
.36061 .03101 L
.3609 .0309 L
.36117 .0308 L
.36142 .0308 L
.36189 .0308 L
.36239 .0308 L
.36283 .0308 L
.36322 .03075 L
.3636 .03068 L
Mistroke
.36401 .03059 L
.36442 .03051 L
.36486 .03042 L
.36534 .03039 L
.36579 .03037 L
.36625 .03035 L
.3665 .03033 L
.36676 .03033 L
.36724 .03042 L
.36768 .03051 L
.36807 .0306 L
.3685 .03068 L
.36896 .03067 L
.3694 .03063 L
.3699 .03058 L
.37037 .03054 L
.37063 .03057 L
.37091 .03064 L
.3714 .03077 L
.37187 .03089 L
.37236 .03101 L
.37279 .03099 L
.37325 .03098 L
.37379 .03096 L
.37406 .03096 L
.3743 .03094 L
.37458 .03092 L
.37489 .03089 L
.37543 .03084 L
.37589 .0308 L
.37616 .0308 L
.37641 .03084 L
.37691 .03092 L
.37746 .03101 L
.37794 .03109 L
.37839 .031 L
.37891 .0309 L
.37938 .03082 L
.37982 .03074 L
.38023 .03074 L
.38114 .03075 L
.38162 .03075 L
.38186 .03076 L
.38213 .03076 L
.38261 .03078 L
.38305 .03079 L
.38331 .0308 L
.38356 .03079 L
.38382 .03072 L
.38411 .03064 L
Mistroke
.38463 .03049 L
.38511 .03036 L
.38559 .0303 L
.38609 .03033 L
.38663 .03036 L
.3869 .03038 L
.38714 .0304 L
.38758 .03034 L
.38806 .03026 L
.38906 .03007 L
.38994 .02996 L
.3904 .0299 L
.39089 .02983 L
.39132 .02987 L
.39179 .02993 L
.39219 .02999 L
.39263 .03005 L
.3929 .03007 L
.39316 .03003 L
.39366 .02996 L
.39415 .02989 L
.39461 .02982 L
.39488 .02984 L
.39516 .0299 L
.39565 .02999 L
.39675 .03019 L
.39773 .03033 L
.39823 .03039 L
.39851 .03041 L
.39877 .0304 L
.39966 .03034 L
.40017 .03031 L
.40062 .03038 L
.40108 .03048 L
.40157 .0306 L
.40203 .0307 L
.40245 .03071 L
.4029 .03067 L
.40338 .03063 L
.4044 .03056 L
.40482 .03053 L
.40526 .03051 L
.40568 .03049 L
.40607 .0305 L
.40652 .03057 L
.407 .03065 L
.40747 .03072 L
.40789 .03074 L
.40835 .03068 L
.40884 .03061 L
Mistroke
.40926 .03056 L
.40972 .03052 L
.41 .03055 L
.41026 .03057 L
.41077 .03062 L
.41173 .03073 L
.41222 .03081 L
.41275 .0309 L
.41324 .03098 L
.4137 .03095 L
.41396 .03091 L
.41424 .03088 L
.41451 .03084 L
.4148 .03081 L
.41507 .03077 L
.41532 .03077 L
.4158 .03084 L
.41625 .03091 L
.41675 .03098 L
.41721 .03103 L
.41763 .03103 L
.41808 .03104 L
.41856 .03105 L
.41906 .03104 L
.41933 .03099 L
.41958 .03095 L
.42004 .03088 L
.42047 .03081 L
.42086 .03077 L
.42128 .03084 L
.42173 .03091 L
.42221 .03098 L
.42266 .03105 L
.42308 .03103 L
.42403 .031 L
.42429 .03099 L
.42457 .03097 L
.42484 .03095 L
.42508 .03093 L
.42561 .03087 L
.42611 .03083 L
.42636 .0308 L
.42663 .03084 L
.4272 .03094 L
.4277 .03102 L
.42816 .0311 L
.42865 .03108 L
.4289 .03105 L
.42918 .03102 L
.42959 .03098 L
Mistroke
.43004 .03093 L
.43053 .0309 L
.43099 .03087 L
.4315 .03085 L
.43198 .03082 L
.43224 .03086 L
.43252 .03091 L
.43302 .03099 L
.43349 .03107 L
.43399 .03111 L
.43446 .03105 L
.43489 .03101 L
.4354 .03095 L
.43565 .03092 L
.43593 .03092 L
.43624 .03092 L
.43652 .03093 L
.43706 .03093 L
.43733 .03094 L
.43758 .03094 L
.43805 .031 L
.43856 .03107 L
.43883 .0311 L
.43911 .03114 L
.43959 .03114 L
.44004 .03106 L
.44052 .03097 L
.44078 .03092 L
.44102 .03088 L
.44146 .03083 L
.44194 .03082 L
.44235 .03082 L
.44279 .03081 L
.44306 .03081 L
.44331 .03082 L
.4438 .03085 L
.44428 .03089 L
.44472 .03092 L
.4452 .03091 L
.44545 .03087 L
.44573 .03083 L
.44628 .03074 L
.44652 .0307 L
.44679 .03066 L
.44729 .03067 L
.44776 .0307 L
.44826 .03073 L
.44853 .03074 L
.44879 .03076 L
.44925 .0308 L
Mistroke
.44976 .03085 L
.45019 .0309 L
.45065 .03093 L
.45093 .03087 L
.4512 .03082 L
.45171 .03072 L
.45221 .03063 L
.45268 .03057 L
.45318 .03056 L
.45374 .03056 L
.45401 .03055 L
.45428 .03055 L
.45458 .03055 L
.45486 .03056 L
.45533 .03058 L
.45577 .03059 L
.45602 .0306 L
.45629 .03059 L
.45675 .03051 L
.4572 .03044 L
.45767 .03036 L
.45807 .0303 L
.45852 .03033 L
.4595 .03039 L
.45977 .03041 L
.46006 .03044 L
.4603 .03048 L
.46057 .03052 L
.46105 .0306 L
.46131 .03064 L
.46157 .03068 L
.46206 .03069 L
.46252 .03064 L
.46298 .03059 L
.46348 .03054 L
.46394 .03053 L
.46437 .03055 L
.46487 .03057 L
.46513 .03058 L
.46541 .03059 L
.46566 .03061 L
.46593 .03064 L
.4664 .0307 L
.46685 .03076 L
.46728 .03082 L
.46778 .03078 L
.46823 .03073 L
.46863 .03068 L
.46905 .03063 L
.46951 .03061 L
Mistroke
.46994 .03062 L
.47044 .03064 L
.47072 .03064 L
.47098 .03065 L
.47125 .03067 L
.47156 .0307 L
.47209 .03075 L
.4726 .03081 L
.47307 .03083 L
.47334 .03078 L
.47362 .03072 L
.47412 .03063 L
.47461 .03054 L
.47507 .03048 L
.47556 .03044 L
.47609 .0304 L
.47654 .03037 L
.47696 .03037 L
.47742 .0304 L
.47791 .03043 L
.47838 .03046 L
.47864 .03046 L
.47889 .03043 L
.47982 .0303 L
.48025 .03024 L
.48066 .03021 L
.48108 .03019 L
.48155 .03017 L
.48205 .03014 L
.48253 .03016 L
.48296 .03021 L
.48342 .03027 L
.48368 .03031 L
.48393 .03034 L
.48421 .03036 L
.48447 .03034 L
.48544 .03024 L
.48629 .03016 L
.48719 .03008 L
.48756 .03005 L
.48796 .03003 L
.4884 .0301 L
.4888 .03017 L
.48927 .03025 L
.48952 .0303 L
.48978 .03034 L
.49026 .03035 L
.4907 .03037 L
.4911 .03038 L
.49153 .03039 L
Mistroke
.492 .03036 L
.49244 .03032 L
.49293 .03028 L
.4934 .03023 L
.49366 .03025 L
.49394 .03027 L
.49443 .03032 L
.4949 .03037 L
.4954 .0304 L
.49582 .03038 L
.49628 .03036 L
.49654 .03034 L
.49682 .03033 L
.49709 .03031 L
.49733 .03028 L
.49762 .03022 L
.49792 .03016 L
.49846 .03005 L
.49896 .02996 L
.49942 .02995 L
.49969 .02996 L
.49993 .02998 L
.50049 .03 L
.50135 .03006 L
.50227 .03012 L
.50254 .03014 L
.5028 .03016 L
.50328 .0301 L
.50421 .02999 L
.50469 .02994 L
.50493 .02994 L
.50519 .02995 L
.50567 .02996 L
.5061 .02997 L
.50636 .02998 L
.50661 .03 L
.50687 .03004 L
.50715 .03008 L
.50767 .03016 L
.50814 .03023 L
.50861 .03026 L
.50912 .03023 L
.51017 .03019 L
.51116 .03014 L
.51164 .03011 L
.51208 .03009 L
.5125 .03012 L
.5129 .03016 L
.51333 .03019 L
.51378 .03023 L
Mistroke
.51425 .03022 L
.51468 .03018 L
.51565 .03007 L
.51659 .02995 L
.51709 .02988 L
.51736 .02984 L
.51761 .02981 L
.51807 .02985 L
.51857 .02992 L
.51945 .03005 L
.52049 .0302 L
.52101 .03027 L
.52148 .03033 L
.52174 .03031 L
.52202 .03028 L
.52261 .03022 L
.52311 .03018 L
.52338 .03015 L
.52364 .03015 L
.52411 .03013 L
.52461 .03012 L
.52505 .03011 L
.52553 .03012 L
.52596 .03014 L
.52642 .03016 L
.52682 .03017 L
.52725 .03016 L
.52774 .03011 L
.52821 .03007 L
.52848 .03004 L
.52875 .03001 L
.52924 .02998 L
.53015 .02994 L
.53061 .02991 L
.53111 .02997 L
.53202 .03012 L
.53247 .03019 L
.53288 .03024 L
.53331 .03028 L
.53377 .03032 L
.53427 .03037 L
.53474 .03036 L
.53515 .03032 L
.53558 .03028 L
.53595 .03024 L
.53635 .0302 L
.53682 .0302 L
.53726 .0302 L
.53769 .0302 L
.5381 .0302 L
Mistroke
.53857 .03021 L
.539 .03023 L
.5395 .03024 L
.53997 .03025 L
.54038 .03022 L
.54081 .03016 L
.54128 .03011 L
.54172 .03005 L
.54219 .03001 L
.54244 .03 L
.5427 .02999 L
.54314 .02997 L
.54361 .02995 L
.54388 .02996 L
.54413 .03002 L
.54461 .03012 L
.54514 .03023 L
.54543 .0303 L
.5457 .03035 L
.54619 .03042 L
.54673 .0305 L
.54719 .03056 L
.54768 .03058 L
.54795 .03054 L
.54825 .0305 L
.5488 .03041 L
.54983 .03028 L
.55033 .03023 L
.55081 .03018 L
.55107 .03015 L
.55135 .03015 L
.55185 .03021 L
.55372 .03043 L
.55419 .03049 L
.55463 .03054 L
.55488 .03057 L
.55514 .03057 L
.5556 .03055 L
.55736 .03049 L
.56134 .03036 L
.56184 .03032 L
.56212 .0303 L
.56238 .03028 L
.56263 .03027 L
.5629 .03028 L
.56336 .03028 L
.56362 .03029 L
.56389 .03029 L
.56439 .03031 L
.56469 .03035 L
Mistroke
.56498 .0304 L
.56551 .03048 L
.56598 .03055 L
.56648 .03058 L
.5669 .0306 L
.56737 .03061 L
.56787 .03062 L
.56815 .03061 L
.5684 .03056 L
.56937 .03037 L
.56979 .0303 L
.57024 .03024 L
.57073 .0302 L
.5712 .03016 L
.57169 .03011 L
.57194 .03013 L
.57221 .03017 L
.57314 .03031 L
.57402 .03041 L
.5745 .03046 L
.57495 .0305 L
.57538 .03054 L
.57583 .0305 L
.57625 .03045 L
.57664 .03039 L
.57752 .03028 L
.57846 .03016 L
.57874 .03012 L
.57901 .03009 L
.5795 .03008 L
.57997 .03012 L
.58048 .03016 L
.58148 .03027 L
.58201 .03035 L
.58257 .03044 L
.58306 .03049 L
.58334 .03049 L
.5836 .03049 L
.58405 .03049 L
.58454 .03048 L
.58481 .03048 L
.58505 .03046 L
.58554 .03042 L
.58601 .03039 L
.58644 .03035 L
.58691 .03033 L
.58716 .03033 L
.58743 .03033 L
.58793 .03033 L
.5882 .03033 L
Mistroke
.58848 .03032 L
.58895 .03035 L
.58939 .03037 L
.58988 .0304 L
.59034 .03043 L
.59077 .03044 L
.59124 .03046 L
.59163 .03047 L
.59205 .03048 L
.59255 .03047 L
.59301 .03045 L
.59352 .03043 L
.59379 .03042 L
.59407 .03041 L
.59437 .03039 L
.59464 .03036 L
.59519 .03032 L
.59621 .03024 L
.59708 .03018 L
.59758 .03014 L
.59803 .03013 L
.59827 .03014 L
.59853 .03015 L
.59907 .03017 L
.59931 .03018 L
.59957 .03019 L
.60004 .0302 L
.6005 .03021 L
.601 .03021 L
.60126 .03021 L
.60154 .03022 L
.60181 .0302 L
.60205 .03019 L
.60296 .03013 L
.60395 .03006 L
.6044 .03003 L
.60489 .02999 L
.60535 .02996 L
.60577 .03 L
.60661 .03009 L
.60707 .03013 L
.6075 .03016 L
.60799 .03018 L
.60853 .03021 L
.60898 .03024 L
.60947 .03022 L
.61005 .03019 L
.61059 .03016 L
.61108 .03013 L
.61161 .03009 L
Mistroke
.61211 .03005 L
.61258 .03001 L
.61307 .03002 L
.61334 .03005 L
.61362 .03008 L
.61412 .03012 L
.61459 .03017 L
.61502 .03018 L
.61548 .0302 L
.61592 .03021 L
.61639 .03023 L
.61663 .03022 L
.6169 .0302 L
.61737 .03015 L
.61912 .02997 L
.61963 .02991 L
.62012 .02986 L
.62038 .02986 L
.62067 .02989 L
.62118 .02993 L
.62167 .02998 L
.62193 .03 L
.62218 .03002 L
.62267 .03003 L
.62311 .03004 L
.62358 .03005 L
.62384 .03006 L
.62409 .03004 L
.62459 .02997 L
.62513 .02989 L
.62562 .02982 L
.62609 .02978 L
.62652 .02975 L
.62698 .02972 L
.62748 .02969 L
.62776 .0297 L
.62803 .02975 L
.62861 .02987 L
.62915 .02999 L
.62962 .03007 L
.63011 .0301 L
.63061 .03013 L
.63087 .03014 L
.63115 .03016 L
.63139 .03017 L
.63166 .03012 L
.63213 .03004 L
.63258 .02995 L
.63306 .02987 L
.63353 .02982 L
Mistroke
.63396 .0298 L
.63437 .02978 L
.6348 .02977 L
.63529 .02979 L
.63575 .02989 L
.63629 .03002 L
.63655 .03008 L
.63679 .03013 L
.63723 .03018 L
.63769 .03019 L
.63817 .0302 L
.63844 .03021 L
.63869 .03021 L
.63913 .03014 L
.63953 .03003 L
.64032 .02981 L
.64076 .0297 L
.64117 .02965 L
.64165 .0296 L
.6421 .02956 L
.6425 .02952 L
.64293 .02959 L
.64384 .02979 L
.64434 .0299 L
.64481 .02994 L
.64523 .02997 L
.64569 .02999 L
.64594 .03 L
.6462 .03002 L
.64666 .02995 L
.64721 .02983 L
.64772 .02972 L
.64816 .02962 L
.64863 .02962 L
.6489 .02962 L
.64915 .02962 L
.64963 .02961 L
.65006 .02962 L
.65051 .02972 L
.65133 .0299 L
.65176 .03 L
.65222 .03005 L
.65272 .03009 L
.65319 .03012 L
.6537 .03015 L
.65416 .0301 L
.65472 .03001 L
.65522 .02994 L
.65548 .0299 L
.65576 .02988 L
Mistroke
.65626 .02987 L
.65678 .02986 L
.65706 .02986 L
.65736 .02985 L
.65786 .02987 L
.65833 .0299 L
.65885 .02992 L
.65935 .02995 L
.65981 .02994 L
.66031 .02992 L
.66118 .02989 L
.66216 .02985 L
.66243 .02984 L
.66271 .02982 L
.66295 .02981 L
.66322 .02983 L
.6637 .02988 L
.66421 .02994 L
.66469 .03 L
.66513 .03002 L
.66559 .03001 L
.66609 .03 L
.66653 .02999 L
.667 .02996 L
.66742 .0299 L
.66781 .02985 L
.66827 .02979 L
.6687 .02974 L
.66919 .02977 L
.66973 .0298 L
.67 .02981 L
.67025 .02983 L
.67071 .02987 L
.67114 .02994 L
.6716 .03002 L
.67209 .0301 L
.67255 .03013 L
.67305 .03007 L
.6736 .03001 L
.67471 .02985 L
.67521 .02976 L
.67574 .02966 L
.6762 .02959 L
.6767 .02965 L
.6786 .0299 L
.67912 .02999 L
.67939 .03003 L
.67967 .03008 L
.67992 .03011 L
.6802 .0301 L
Mistroke
.68068 .03008 L
.68116 .03006 L
.68162 .03005 L
.68188 .03004 L
.68215 .03004 L
.68263 .03003 L
.68309 .03003 L
.68358 .03002 L
.68399 .03004 L
.68445 .03006 L
.68492 .03009 L
.68537 .03011 L
.68577 .03008 L
.68621 .03004 L
.68713 .02996 L
.68764 .02992 L
.6881 .02989 L
.68854 .02987 L
.68901 .02984 L
.68946 .02989 L
.68987 .02998 L
.69028 .03006 L
.69072 .03015 L
.69113 .03022 L
.69152 .03023 L
.69197 .03025 L
.69246 .03027 L
.69286 .03029 L
.69331 .0302 L
.69424 .02999 L
.69449 .02994 L
.69476 .02988 L
.69523 .02988 L
.69609 .0299 L
.69657 .02991 L
.69702 .02997 L
.69783 .03011 L
.69828 .03019 L
.6987 .0302 L
.6992 .03014 L
.69973 .03009 L
.7007 .02999 L
.70156 .0299 L
.70205 .02986 L
.70251 .02989 L
.70276 .02994 L
.70304 .02999 L
.70354 .03008 L
.70402 .03018 L
.70447 .03015 L
Mistroke
.70496 .03011 L
.70549 .03007 L
.70576 .03005 L
.70605 .03001 L
.70633 .02996 L
.70658 .02991 L
.70706 .02982 L
.70752 .02974 L
.70793 .02972 L
.70838 .02983 L
.70931 .03007 L
.7103 .03026 L
.71072 .03033 L
.71116 .0304 L
.71165 .03042 L
.71211 .03026 L
.71253 .03012 L
.71297 .02997 L
.71339 .02982 L
.71378 .02982 L
.71403 .02981 L
.7143 .02981 L
.71479 .02981 L
.71506 .0298 L
.71536 .02983 L
.71561 .02991 L
.71589 .03 L
.71639 .03016 L
.71666 .03025 L
.71692 .03033 L
.71717 .03039 L
.71743 .03037 L
.71789 .03034 L
.71835 .0303 L
.71883 .03027 L
.71908 .03023 L
.71935 .03017 L
.71984 .03005 L
.72029 .02993 L
.72078 .02981 L
.72124 .02993 L
.72166 .03008 L
.72209 .03023 L
.72254 .03039 L
.72304 .03047 L
.7235 .03049 L
.7239 .03052 L
.72433 .03054 L
.7248 .03046 L
.72524 .03026 L
Mistroke
.72575 .03004 L
.72602 .02992 L
.7263 .02979 L
.72658 .02973 L
.72682 .02975 L
.72731 .02977 L
.72777 .02979 L
.72802 .0298 L
.72828 .02982 L
.72876 .03003 L
.72919 .03023 L
.72969 .03046 L
.73015 .03068 L
.73041 .03066 L
.73068 .03062 L
.73117 .03055 L
.73164 .03049 L
.73213 .0304 L
.73255 .0302 L
.73301 .02999 L
.73327 .02987 L
.73355 .02975 L
.73381 .02963 L
.73405 .02964 L
.73434 .02974 L
.73464 .02984 L
.73517 .03003 L
.73564 .03019 L
.73614 .03031 L
.73669 .03042 L
.7372 .03052 L
.73747 .03058 L
.73772 .03058 L
.73819 .03041 L
.73924 .03003 L
.74014 .0298 L
.74064 .02969 L
.74111 .02958 L
.74136 .02953 L
.74162 .02968 L
.74218 .03002 L
.74273 .03034 L
.74303 .03052 L
.74331 .03063 L
.74356 .03063 L
.74382 .03062 L
.74438 .03061 L
.74464 .03061 L
.74489 .0306 L
.74535 .03043 L
Mistroke
.74628 .02981 L
.74675 .0295 L
.74702 .02938 L
.74727 .02942 L
.7477 .02949 L
.74817 .02957 L
.74862 .02964 L
.74904 .0298 L
.74952 .03008 L
.75004 .03037 L
.75052 .03064 L
.75096 .03068 L
.75123 .03063 L
.75147 .03058 L
.75203 .03049 L
.75252 .0304 L
.75276 .03025 L
.75303 .03008 L
.7535 .02979 L
.75399 .02948 L
.75425 .02932 L
.75453 .0293 L
.75503 .0296 L
.75594 .03015 L
.75619 .0303 L
.75646 .03039 L
.75693 .0305 L
.75735 .03061 L
.7578 .03072 L
.7583 .03072 L
.75876 .03048 L
.76047 .02966 L
.76098 .02947 L
.76151 .02927 L
.76178 .02916 L
.76209 .02932 L
.76237 .02954 L
.76262 .02974 L
.76313 .03014 L
.7636 .03051 L
.76387 .03063 L
.76415 .03069 L
.76465 .03078 L
.76514 .03088 L
.76561 .03095 L
.76609 .03063 L
.76662 .03028 L
.76705 .03 L
.7675 .02972 L
.76799 .02961 L
Mistroke
.76845 .0295 L
.76891 .0294 L
.76918 .02934 L
.76942 .02938 L
.76987 .02968 L
.77034 .02999 L
.77074 .03026 L
.77117 .03054 L
.77163 .03063 L
.77207 .03071 L
.77257 .0308 L
.77285 .03085 L
.77311 .03085 L
.77359 .03059 L
.7741 .03031 L
.7746 .03004 L
.77507 .02984 L
.77549 .02976 L
.77595 .02967 L
.77636 .02959 L
.7768 .02952 L
.77727 .02986 L
.77772 .03018 L
.77822 .03053 L
.7787 .03082 L
.77913 .03084 L
.77959 .03086 L
.78003 .03087 L
.78044 .03089 L
.78086 .03068 L
.78133 .0304 L
.78211 .02995 L
.78255 .02977 L
.78294 .0297 L
.78342 .02961 L
.78387 .02952 L
.78428 .0295 L
.78473 .0298 L
.78566 .03042 L
.78592 .03059 L
.78619 .03073 L
.78669 .03084 L
.7872 .03096 L
.78769 .03107 L
.78795 .03113 L
.78824 .03102 L
.78874 .03082 L
.78973 .03042 L
.79063 .03011 L
.79107 .02996 L
Mistroke
.79154 .02979 L
.79199 .02986 L
.7924 .03 L
.7933 .03031 L
.79429 .03067 L
.7947 .03082 L
.79514 .03098 L
.79556 .03106 L
.79594 .03105 L
.79637 .03103 L
.79684 .031 L
.79728 .03098 L
.79768 .03087 L
.79854 .03064 L
.79898 .03053 L
.79945 .03051 L
.7997 .03053 L
.79997 .03056 L
.80045 .0306 L
.80093 .03064 L
.80136 .03072 L
.80221 .0309 L
.80266 .031 L
.80313 .03104 L
.80355 .03105 L
.804 .03106 L
.80442 .03106 L
.80481 .03106 L
.80529 .03102 L
.80582 .03098 L
.80629 .03094 L
.80679 .03092 L
.80723 .03092 L
.80773 .03092 L
.80817 .03092 L
.8086 .03094 L
.80953 .03109 L
.81005 .03118 L
.81054 .03123 L
.81081 .03125 L
.81111 .03127 L
.81164 .03131 L
.81189 .03133 L
.81217 .03134 L
.81266 .03124 L
.81359 .03103 L
.81459 .03079 L
.81508 .03067 L
.81554 .03055 L
.81595 .03046 L
Mistroke
.8164 .03051 L
.81828 .03082 L
.81883 .03097 L
.81911 .03105 L
.81936 .03111 L
.81983 .03119 L
.82008 .03119 L
.82034 .03119 L
.82075 .03119 L
.82118 .03119 L
.82166 .03114 L
.82211 .03099 L
.824 .03027 L
.82443 .03005 L
.82491 .02982 L
.82536 .02964 L
.82577 .02958 L
.82655 .02948 L
.82695 .02942 L
.82739 .02956 L
.82925 .03057 L
.83016 .03104 L
.83055 .03124 L
.83098 .0314 L
.83143 .03148 L
.83185 .03156 L
.8323 .03163 L
.83279 .03169 L
.83329 .03164 L
.83382 .03159 L
.83476 .03147 L
.8358 .03127 L
.83607 .03122 L
.83637 .03116 L
.83665 .03113 L
.83691 .0311 L
.83741 .03106 L
.83769 .03103 L
.83795 .03101 L
.83846 .03102 L
.83891 .0311 L
.84072 .03148 L
.84122 .0316 L
.84168 .03172 L
.84194 .03178 L
.84222 .03181 L
.84271 .03182 L
.8432 .03184 L
.84346 .03185 L
.84371 .03185 L
Mistroke
.84416 .03182 L
.84464 .03175 L
.84644 .03147 L
.8485 .03108 L
.84893 .03099 L
.8494 .0309 L
.84967 .03086 L
.84991 .03083 L
.85038 .03077 L
.85081 .03072 L
.85128 .03067 L
.85172 .03071 L
.85212 .03076 L
.85377 .03101 L
.85555 .03139 L
.85742 .03188 L
.85831 .03216 L
.85928 .03243 L
.85972 .03254 L
.86019 .03265 L
.86059 .03274 L
.86103 .03276 L
.86153 .03276 L
.8618 .03277 L
.86208 .03277 L
.86232 .03277 L
.86259 .03276 L
.86306 .03271 L
.8649 .03251 L
.86665 .03237 L
.86711 .03233 L
.86761 .03228 L
.86808 .03225 L
.86852 .03216 L
.87028 .03181 L
.87189 .03141 L
.8728 .03122 L
.87325 .03113 L
.87366 .03104 L
.87414 .03097 L
.87466 .03091 L
.87558 .03078 L
.87903 .03029 L
.87997 .03012 L
.88047 .03003 L
.88099 .02994 L
.88145 .02987 L
.88195 .02981 L
.88242 .02976 L
.88284 .02971 L
Mistroke
.88311 .02969 L
.88337 .02968 L
.88394 .02966 L
.88447 .02965 L
.88496 .02963 L
.88589 .02958 L
.88689 .02952 L
.89462 .02897 L
.89646 .02882 L
.89747 .02872 L
.8984 .02865 L
.89927 .02859 L
.89965 .02857 L
.90006 .02856 L
.90051 .02855 L
.90093 .02854 L
.90142 .02854 L
.90187 .02854 L
.90227 .02855 L
.9027 .02857 L
.90347 .02859 L
.90432 .02862 L
.90476 .02864 L
.90523 .02866 L
.90573 .02864 L
.90619 .02861 L
.9071 .02855 L
.90798 .02849 L
.9088 .02843 L
.90923 .02841 L
.90968 .02841 L
.91017 .0284 L
.91063 .0284 L
.91102 .0284 L
.91145 .0284 L
.91234 .02841 L
.91259 .02841 L
.91285 .02841 L
.91314 .02842 L
.9134 .02843 L
.9144 .02846 L
.91528 .0285 L
.91579 .02853 L
.91626 .02855 L
.91672 .02856 L
.91721 .02854 L
.91774 .02851 L
.91824 .02849 L
.91872 .02847 L
.91923 .02845 L
Mistroke
.92013 .02843 L
.92181 .02837 L
.9227 .02833 L
.92319 .02831 L
.92366 .0283 L
.92392 .02828 L
.9242 .02829 L
.9247 .02831 L
.92567 .02834 L
.92671 .02838 L
.92727 .0284 L
.92755 .02841 L
.9278 .02842 L
.92826 .0284 L
.92874 .02838 L
.92924 .02836 L
.92952 .02834 L
.92978 .02834 L
.93021 .02834 L
.93067 .02835 L
.93117 .02835 L
.93161 .02835 L
.93257 .0283 L
.93285 .02828 L
.93311 .02827 L
.9336 .02827 L
.93407 .02829 L
.93449 .02831 L
.93496 .02833 L
.93546 .02834 L
.93572 .02833 L
.93599 .02833 L
.93648 .02832 L
.93696 .02832 L
.93741 .02832 L
.9379 .02832 L
.93844 .02833 L
.93872 .02833 L
.93901 .02833 L
.93929 .02832 L
.93954 .02832 L
.94138 .02824 L
.94187 .02821 L
.94214 .02819 L
.94239 .02818 L
.94289 .02816 L
.94334 .02817 L
.94501 .02818 L
.94589 .02819 L
.94639 .0282 L
Mistroke
.94685 .02818 L
.94728 .02816 L
.94775 .02814 L
.94819 .02812 L
.9486 .02812 L
.94907 .02812 L
.94957 .02813 L
.95 .02813 L
.95046 .02815 L
.95235 .02825 L
.9529 .02827 L
.95341 .02829 L
.95388 .02831 L
.95414 .02829 L
.95438 .02828 L
.95482 .02826 L
.9553 .02824 L
.95575 .02823 L
.95617 .02822 L
.95707 .02821 L
.95755 .02821 L
.9578 .0282 L
.95806 .02819 L
.95893 .02817 L
.95941 .02815 L
.95985 .02819 L
.96026 .02822 L
.9607 .02825 L
.96112 .02828 L
.96151 .02829 L
.96194 .02828 L
.96235 .02827 L
.96284 .02827 L
.96328 .02826 L
.96372 .02827 L
.96419 .02827 L
.96445 .02827 L
.9647 .02828 L
.96517 .02826 L
.96558 .02823 L
.96602 .02819 L
.96639 .02816 L
.96679 .02813 L
.96723 .02815 L
.96763 .02817 L
.96808 .0282 L
.96855 .02823 L
.96879 .02824 L
.96906 .02825 L
.96953 .02825 L
Mistroke
.97005 .02825 L
.97032 .02825 L
.9706 .02825 L
.97085 .02826 L
.97113 .02827 L
.97161 .02828 L
.97209 .02829 L
.97255 .0283 L
.97302 .02826 L
.97347 .02822 L
.97388 .02819 L
.97431 .02816 L
.97478 .02817 L
.97521 .02819 L
.97619 .02822 L
Mfstroke
1 0 0 r
.02381 .58994 m
.03853 .58345 L
.05458 .57503 L
.06965 .56646 L
.08415 .55789 L
.09958 .5486 L
.11444 .5396 L
.13023 .53003 L
.14544 .52081 L
.16007 .51196 L
.17564 .50255 L
.19063 .4935 L
.20504 .48482 L
.22039 .47559 L
.23516 .46672 L
.25087 .45729 L
.26599 .44822 L
.28054 .43951 L
.29603 .43025 L
.31093 .42134 L
.32678 .41188 L
.34204 .40278 L
.35672 .39402 L
.37234 .38472 L
.38739 .37576 L
.40185 .36716 L
.41725 .358 L
.43208 .34918 L
.44783 .33982 L
.46301 .3308 L
.47761 .32213 L
.49315 .31291 L
.50811 .30402 L
.52249 .29549 L
.5378 .28639 L
.55254 .27764 L
.56821 .26834 L
.58331 .25938 L
.59783 .25075 L
.61328 .24157 L
.62815 .23273 L
.64396 .22333 L
.65919 .21428 L
.67385 .20555 L
.68943 .19627 L
.70445 .18733 L
.71888 .17872 L
.73425 .16956 L
.74904 .16072 L
.76476 .15132 L
Mistroke
.77991 .14226 L
.79448 .13354 L
.80998 .12424 L
.82491 .11528 L
.84077 .10575 L
.85605 .09655 L
.87076 .0877 L
.8864 .07829 L
.90146 .06926 L
.91595 .06065 L
.93137 .05168 L
.94621 .04341 L
.96198 .03529 L
.97619 .02872 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008oooool2o`00037ooooo0ol00004ooooo`;o0000:_ooool3o`0000Cooooo0_l00004oooo
o`;o0000:?ooool3o`0000?ooooo0ol00004ooooo`;o00009oooool5o`0000?ooooo0_l00004oooo
o`;o00006_ooool002;ooooo00Co0000oooooooooooo0000;oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo0000:_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Uooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Iooooo`00
8_ooool01?l0003oooooooooool0000cooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo0000:?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00006Oooool002;ooooo00Co0000oooooooooooo0000<oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02Oooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool05oooool0
02;ooooo00Co0000oooooooooooo0000;oooool4o`0000?ooooo00Co0000oooooooooooo0000:_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
0000:?ooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00009_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Iooooo`008_ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo0000:Oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0000Wooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0002Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00006Oooool002?ooooo0_l0000`ooooo`Go00000oooool2o`00
02_ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0000Yooooo`04o`000?oooooooooo
ooooo`Go00000oooool2o`0002Sooooo0ol00004ooooo`;o00001?ooool2o`0001[ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000NooooooSo00002_ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0m?ooool00ol0003oooooooooo`08ooooo`005oooool2o`0000Gooooo00?o
0000ooooooooool0m?ooool00ol0003oooooooooo`08ooooo`005_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000F
ooooo`04o`000?ooooooooooo`0000Cooooo0_l0000Looooo`04o`000?ooooooooooo`0001Gooooo
0_l00002ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000o`000002o`000004oooo
ool0003o0000ooooo`?o000000?oooooo`000?l00000OOl00003oooooaWo00000_oo0004ooooo`;o
00002_ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`03o`000?oooooo0000
00;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0ol000000ooooooo0000o`000006
o`000003ooooool0003o000000Go000000?oooooo`000?l000000_ooool2o`0007Oooooo0_l00002
ooooo`Co00005Oooool3ool000Oooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?ooool01?l00000
0ooooooo0000o`000003o`000006ooooool0003o0000ooooool0003ooooo1?l000003Ooooooo0000
ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?ooool01?l0002Wooooo`;oo`00
2_ooool00ol0003oooooooooo`08ooooo`005oooool2o`0000Gooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`04o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o
oooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo0_l000003?oooooo0000o`000?l0003o
ooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooooooool0YOooool2ool0
00cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool05?ooool4o`000004
ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`03o`000?oooooo
oooo00Gooooo0_l00002ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`2W
ooooo`;oo`003_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Doooo
o`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0ZOooool2ool0013ooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`;o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000033ooooo`03ool00?oooooooooo013ooooo00?o0000
ooooooooool02?ooool001kooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo1?l000001?oo
oooo0000o`000?ooool2o`000<Gooooo00?oo`00ooooooooool04?ooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`000?oooooo000000Co000000?oooooo`00
0?l00000a_ooool2ool001Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool01?ooool2o`0000Sooooo00?o0000ooooool000001?l000000ooooooo0000o`000035ooooo`03
ool00?oooooooooo01Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1?ooool2o`000003ooooool0003ooooo00;ooooo00Go0000ooooool0003o0000ooooo`05o`000<Ko
oooo0_oo000Gooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o000000?oooooo`000?oo
ool0a?ooool2ool001Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000ol00035ooooo`;o
o`006oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Gooooo0_l000001?oooooo0000
o`000?ooool2o`000006ooooool0003o0000o`000?oooooo0000`oooool2ool001cooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
1?oooooo0000ooooool00033ooooo`;oo`007oooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`04ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000oooo
ool00032ooooo`03ool00?oooooooooo01oooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool01?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?ooool0
`_ooool00ooo003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Cooooo0_l000001?oooooo0000o`000?ooool3o`000<;ooooo0_oo000Sooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l000001?oooooo0000o`00
0?ooool3o`000<7ooooo00?oo`00ooooooooool08oooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`;o000000Coooooo`000?l0003ooooo0ol0002oooooo`;oo`00
9_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Gooooo0_l000001ooooooo0000o`00
0?oooooo0000ooooool00000_Oooool2ool002Oooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`;o000000Ooooooo`000?l0003oooooo`000?oooooo00000;_ooooo0_oo000Zoooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l000001ooooooo
0000o`000?oooooo0000ooooool00000^Oooool2ool002cooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01?ooool2o`000007ooooool0003o0000ooooool0003oooooo`00
002gooooo`;oo`00;_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04
ooooo`;o000000Ooooooo`000?l0003oooooo`000?oooooo00000;Kooooo00?oo`00ooooooooool0
;_ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Cooooo00Co0000oooooooooooooooo
1Ol00004ooooo`03o`000?oooooooooo00Cooooo0_l000001ooooooo0000o`000?oooooo0000oooo
ool00000]Oooool00ooo003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04
ooooo`;o000000Coooooo`000?oooooo0000]_ooool2ool003;ooooo00?o0000ooooooooool02?oo
ool000[ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o00001Ooo
ool2o`000004ooooool0003oooooo`000;Gooooo00?oo`00ooooooooool0<Oooool2o`0000[ooooo
000:ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`;o000000Coooooo`000?oooooo0000/oooool2ool003Gooooo00?o0000oooooooo
ool02?ooool000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool01?ooool2o`000004ooooool0003oooooo`000;7ooooo0_oo000g
ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo0_l000001?oooooo0000oooo
ool0002_ooooo`;oo`00>Oooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Wooooo0ol0
0005ooooo`03o`000?oooooooooo00Cooooo0_l000001?oooooo0000ooooool0002]ooooo`;oo`00
>oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o000000Co
ooooo`000?oooooo0000Zoooool2ool003gooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool01?ooool2o`000004ooooool0003oooooo`000:[ooooo00?oo`00ooooooooool0
?Oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Gooooo00Ko0000ooooool0003o0000
ooooool0002Yooooo`03ool00?oooooooooo03gooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?oooooo0000o`000:Wooooo0_oo0011ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00Cooooo00Co0000ooooool0003o0000Z?ooool00ooo003o
ooooooooo`11ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo
00Co0000ooooool0003o0000Y_ooool2ool004Cooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool01?ooool01?l0003oooooo`000?l0002Tooooo`;oo`00A_ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo0000o`000:;o
oooo0_oo0018ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo
00Co0000ooooool0003o0000X?ooool2ool004[ooooo00?o0000ooooooooool02?ooool001kooooo
0_l00005ooooo`04o`000?oooooo0000o`0009kooooo0_oo001;ooooo`;o00002_ooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooo`00002Mooooo`;oo`00C_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000009cooooo00?o
o`00ooooooooool0C_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooo000009_ooooo00?oo`00ooooooooool0Coooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000009[ooooo00?oo`00oooo
ooooool0D?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo000009Sooooo0_oo001Cooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooool00000U_ooool2ool005Gooooo00?o0000ooooooooool0
2?ooool001kooooo0_l00005ooooo`03o`000?oooooo000009Cooooo0_oo001Fooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00002Booooo`;oo`00FOooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
093ooooo0_oo001Kooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooool00000S_ooool2ool005gooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooo`00002=ooooo`03ool00?oooooooooo05gooooo
00?o0000ooooooooool02?ooool000_ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol0
0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000S?ooool00ooo003ooooooooo
o`1Nooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08_ooooo00?o
o`00ooooooooool0Goooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool0
0007ooooo`Go00001?ooool2o`0000Gooooo00?o0000ooooooooool0ROooool2ool0067ooooo0_l0
000:ooooo`002_ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`27ooooo`;oo`00I?ooool00ol0003ooooo
ooooo`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`25ooooo`;oo`00I_ooool00ol0003ooooo
ooooo`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`;o00001Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo08?ooooo0_oo001Xooooo`03o`000?oooooooooo00Sooooo
000;ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0POooool2ool006[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1oooooo`;oo`00K?ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07gooooo0_oo001^oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1looooo`03
ool00?oooooooooo06gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo07[ooooo0_oo001aooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`1aooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N?ooool0
0ooo003oooooooooo`1booooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Moooool2ool007Gooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1eooooo`;oo`00Moooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07?ooooo
0_oo001iooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003ooooooooo
o`1booooo`03ool00?oooooooooo07Sooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo073ooooo0_oo001looooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0K_ooool2ool007kooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1/ooooo`;o
o`00P?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo06[ooooo0_oo0022ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0JOooool00ooo003oooooooooo`22ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0J?ooool0
0ooo003oooooooooo`23ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0
003oooooooooo`1Wooooo`03ool00?oooooooooo08?ooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo06Gooooo0_oo0027ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool2ool008Wooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Qooooo`;oo`00Roooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1O
ooooo`;oo`00SOooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05gooooo0_oo002?ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0Foooool2ool0097ooooo00?o0000ooooooooool02?ooool000[ooooo00Co
0000oooooooooooo00001oooool4o`0000Gooooo0_l00004ooooo`03o`000?oooooooooo05[ooooo
00?oo`00ooooooooool0T?ooool2o`0000[ooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Wooooo
00?oo`00ooooooooool0T_ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Hooooo`03ool00?oooooooooo09?ooooo00?o0000ooooooooool02?ooool000_ooooo0_l0
000:ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo0_oo
002Fooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0E?ooool2ool009Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Booooo`;oo`00V_ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo053ooooo0_oo002Looooo`03
o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`1>ooooo`;oo`00
WOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C?oo
ool2ool00:3ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1:ooooo`;oo`00X_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04Wooooo00?oo`00ooooooooool0X_ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oo
oooo0_oo002Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0A_ooool00ooo003oooooooooo`2Uooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool00ooo003ooooooooo
o`2Vooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`13
ooooo`;oo`00Z?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0@Oooool2ool00:_ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0oooooo`;oo`00[Oooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo0_oo002_ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>ooo
ool2ool00;7ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0jooooo`03ool00?oooooooooo0;7ooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0hooooo`;oo`00]?ooool00ol0
003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0=oooool00ooo003o
ooooooooo`2cooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0fooooo`03ool00?oooooooooo0;Gooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`;oo`00^?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo0_oo002j
ooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo0_oo002loooo
o`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool2
ool00;kooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0/ooooo`;oo`00`?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool0
0008ooooo`?o00001Oooool2o`0000Cooooo00?o0000ooooooooool0:oooool00ooo003ooooooooo
o`2oooooo`;o00002_ooool000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`;oo`00
`oooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02So
oooo00?oo`00ooooooooool0`oooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Wooooo
0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool00ooo003ooooo
ooooo`34ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool09Oooool2ool00<Oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Sooooo`;oo`00bOooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo0_oo003;oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003oooooooooo`0Oooooo`;o
o`00c?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7Oooool2ool00<oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo0<oooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`;oo`00d_ooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Wooooo00?oo`00ooooooooool0d_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool0doooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo
0_oo003Fooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0003ooooooooo
o`0Dooooo`;oo`00eoooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04_ooool2ool00=[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo0=[ooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;o
o`00gOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00kooooo00?oo`00ooooooooool0gOooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0g_oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00_ooooo0_oo003Qooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001?ooool00ol0
003oooooooooo`09ooooo`;oo`00h_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01oooool2ool00>Gooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`;oo`00ioooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_oo
003Yooooo`03o`000?oooooooooo00Sooooo000Fooooo`?o00001Oooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooooooo`;oo`00joooool00ol0003oooooooooo`08ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo003oo`00kOoo
ool00ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04ooooo`;o00001?ooool2
ool00>kooooo0_l0000:ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?Cooooo00?o0000ooooooooool02?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000Fooooo`;o00001_ooool00ol0003ooooo
ooooo`3dooooo`03o`000?oooooooooo00Sooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0m?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`3d
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`007_oooooho`0000[ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0015ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`03o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l0
00001?l00002ooooo`Co00000oooool2o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000003
ooooool0003o000000Oooooo0ol00002ooooo`?o00001?ooool4o`000005ooooool0003o0000o`00
0?ooool01_l00002ooooo`Go00000_ooool3o`0000;ooooo0ol00009ooooo`?o00001Oooool2o`00
0003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0ol00004ooooo`;o00000_ooool5
o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l00000<oooool004Gooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool0000dooooo`00AOooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003o
ooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000Cooooo0ol00003ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;o
oooo0ol00004ooooo`04o`000?ooooooooooooooo`Go00000_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0
003oooooo`0000Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0booooo`00AOooool01ol0003o
oooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000002ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2
o`0000?ooooo00Co0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00002_ooool3o`00
00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0booooo`00AOooool01Ol0003oooooo`000?oooooo
000000;ooooo0ol00003ooooo`?o00000_ooool2o`000003ooooool0003o000000?ooooo00?o0000
ooooooooool00_ooool2o`0000?ooooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l00008
ooooo`06o`000?oooooo0000ooooool0003ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0oooool4o`0000?ooooo1?l00002ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000
o`000008ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000o`000?ooool4o`0000?o
oooo0ol00002ooooo`Co00000_ooool3o`0000Cooooo0ol00002ooooo`Co0000=Oooool004Gooooo
0_l000000ooooooo0000o`00000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Jooooo`05o`000?oooooo0000ooooool000006oooool00ol0003o
ooooooooo`0Dooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0Aoooool004Go
oooo00Co0000oooooooooooooooo0_l00008ooooo`;o00002?ooool3o`0000[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Cooooo`Go00007?ooool2o`0001?ooooo1Ol0000Doooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-33.1085, -0.137062, \
0.91249, 0.00720095}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-1.2464337861714014`\)\), 
        ",", \(BackFocalLength \[Rule] 39.485013802263495`\), 
        ",", \(BackFocalPoint \[Rule] {57.847139891996214`, \
\(-14.815427008975622`\), 0}\), 
        ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                1, #1\ 0.9` + 0.1`] &)\)\), 
        ",", \(ComponentNumber \[Rule] 3\), 
        ",", \(CosineCompensation \[Rule] True\), 
        ",", \(DiffractionSpotSize \[Rule] {0.40933005701242714`, 
            0.5987843656327787`}\), ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-57.42551421082294`\), \
\(-57.42551421082294`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-14.85946576992335`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {14.537193111455208`, \
\(-3.077944022847568`\), 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] \
{{\(-0.9783119619871903`\), 0.2071369233931379`, 
              0}, {\(-0.2071369233931379`\), \(-0.9783119619871903`\), 
              0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] 0\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {19.817012764638733`, \
\(-4.195834472443554`\), 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{0.9631534464647291`, \
\(-0.2689524838389013`\), 0}, {0.26895248383890136`, 0.963153446464729`, 
              0}, {0, 0, 1}}\), ",", \(FieldStopPosition \[Rule] 2\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 2, 
            SurfaceNumber \[Rule] 2, ComponentNumber \[Rule] 1}\), 
        ",", \(FilterTrace \[Rule] True\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FindPupils \[Rule] Automatic\), 
        ",", \(FocalFraction \[Rule] Automatic\), 
        ",", \(FocalLength \[Rule] 45.79737407145489`\), 
        ",", \(FrequencyCutoff \[Rule] {429.59548993358186`, 
            435.19029630761975`}\), 
        ",", \(FrontFocalLength \[Rule] 38.259408199433885`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-36.31607577162287`\), 
            12.038478156339174`, 0}\), 
        ",", \(GeometricPointSpreadFunction \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {0.9631534464647278`, \
\(-0.26895248383890547`\), 0}\), 
        ",", \(ImagePoint \[Rule] {89.10212862492328`, \(-23.359686080275853`\
\), 0}\), 
        ",", \(ImageSampleSize \[Rule] {0.001186463933369354`, 
            0.0011717893652304866`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(BiConvexLens[50, 50, 20]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-54\), \(-54\)}, {108, 54, 
                        54}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], ",", \(IntensityScale \[Rule] 1\), 
        ",", \(IntensitySetting \[Rule] Automatic\), 
        ",", \(IntensityTransform \[Rule] True\), 
        ",", \(InterceptHole \[Rule] True\), 
        ",", \(InterpolationOrder \[Rule] 1\), 
        ",", \(KernelScale \[Rule] Relative\), 
        ",", \(LensABCDMatrix \[Rule] {{0.8621676373989785`, 
              10.290804067447606`}, {\(-0.021835313056153834`\), 
              0.8992416763944976`}}\), ",", 
        RowBox[{"ModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-215.21809280429932`\), 
                  214.7977449667909`}, {\(-218.02097036154726`\), 
                  217.59514815380987`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(NormalizePlot \[Rule] True\), 
        ",", \(NumberOfPoints \[Rule] 512\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              
              TagBox[\(Move[
                  PointOfRays[{10, 10}], {\(-90.5`\), 
                    30.`}, \(-18.33993103355537`\)]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(Offset \[Rule] 126.14688831655164`\), 
        ",", \(OpticalLengthFunction \[Rule] OpticalLengthFunction\), 
        ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(CompiledFunction[
              If[#1 == 0 && #2 == 0, 
                3.149852620040084`, \(\(61.263559006376596`\)\(\
\[InvisibleSpace]\)\) - 
                  0.5995013053549445`\ Cos[
                      ArcTan[#1, #2]]\ \@\(#1\^2 + #2\^2\) - 
                  0.827998126926662`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) - 
                  0.0005780932196429912`\ Cos[
                      3\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(3/2\) - 
                  2.7883176369774045`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 - 
                  6.166951977329706`*^-8\ Cos[
                      5\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(5/2\) + 
                  5.50593448371445`*^-10\ Cos[
                      6\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^3 + 
                  35.76918571206005`\ \((\(-1\) + 
                        0.014433811738429392`\ \((#1\^2 + #2\^2)\))\) + 
                  26.61233421594999`\ Cos[
                      ArcTan[#1, #2]]\ \((\(-0.169904748246948`\)\ \@\(#1\^2 \
+ #2\^2\) + 0.0018392798622462667`\ \((#1\^2 + #2\^2)\)\^\(3/2\))\) - 
                  3.6394995515708306`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.021650717607644088`\)\ \
\((#1\^2 + #2\^2)\) + 0.0002083349213004221`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  23.370714360729597`\ \((1 - 
                        0.043301435215288175`\ \((#1\^2 + #2\^2)\) + 
                        0.0003125023819506331`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                  0.22381221088389475`\ Cos[
                      3\ ArcTan[#1, #2]]\ \((\(-0.0024523731496616887`\)\ \
\((#1\^2 + #2\^2)\)\^\(3/2\) + 
                        0.000022123182721622465`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) - 
                  0.6006852931258754`\ Cos[
                      ArcTan[#1, #2]]\ \((0.254857122370422`\ \@\(#1\^2 + \
#2\^2\) - 0.007357119448985067`\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                        0.00004424636544324493`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) - 
                  0.0031318094445710086`\ Cos[
                      4\ ArcTan[#1, #2]]\ \((\(-0.0002604186516255276`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 2.255300274443097`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  0.2053592225731745`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((0.043301435215288175`\ \((#1\^2 \
+ #2\^2)\) - 0.0010416746065021105`\ \((#1\^2 + #2\^2)\)\^2 + 
                        5.6382506861077425`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  1.0866615810366962`\ \((\(-1\) + 
                        0.08660287043057635`\ \((#1\^2 + #2\^2)\) - 
                        0.0015625119097531657`\ \((#1\^2 + #2\^2)\)\^2 + 
                        7.51766758147699`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) + 
                  0.00223708546918555`\ Cos[
                      5\ ArcTan[#1, #2]]\ \((\(-0.000026547819265946955`\)\ \
\((#1\^2 + #2\^2)\)\^\(5/2\) + 
                        2.235252981211408`*^-7\ \((#1\^2 + #2\^2)\)\^\(7/2\))\
\) - 0.015043047509433327`\ Cos[
                      3\ ArcTan[#1, #2]]\ \((0.006130932874154222`\ \((#1\^2 \
+ #2\^2)\)\^\(3/2\) - 0.0001327390963297348`\ \((#1\^2 + #2\^2)\)\^\(5/2\) + 
                        6.705758943634224`*^-7\ \((#1\^2 + #2\^2)\)\^\(7/2\))\
\) - 0.1094298986441623`\ Cos[
                      ArcTan[#1, #2]]\ \((\(-0.339809496493896`\)\ \@\(#1\^2 \
+ #2\^2\) + 0.018392798622462667`\ \((#1\^2 + #2\^2)\)\^\(3/2\) - 
                        0.0002654781926594696`\ \((#1\^2 + #2\^2)\)\^\(5/2\) \
+ 1.117626490605704`*^-6\ \((#1\^2 + #2\^2)\)\^\(7/2\))\) + 
                  0.0008506612405088334`\ Cos[
                      6\ ArcTan[#1, #2]]\ \((\(-2.6311836535169465`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 2.1701719716626532`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  0.0032414341117366617`\ Cos[
                      4\ ArcTan[#1, #2]]\ \((0.0007812559548765829`\ \((#1\^2 \
+ #2\^2)\)\^2 - 0.00001578710192110168`\ \((#1\^2 + #2\^2)\)\^3 + 
                        7.595601900819286`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.014822549949117863`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.07216905869214696`\)\ \((#1\
\^2 + #2\^2)\) + 0.0031250238195063315`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.000039467754802754194`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.5191203801638572`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.06046789458356166`\ \((1 - 
                        0.14433811738429392`\ \((#1\^2 + #2\^2)\) + 
                        0.004687535729259497`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00005262367307033893`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.8989004752048216`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
              "-CompiledCode-"]\),
            False,
            Editable->False]}], 
        ",", \(OpticalPathRange \[Rule] {126.14399097269657`, 
            126.21551088581438`}\), ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"ModulationTransferFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PaddingFactor \[Rule] Automatic\), 
        ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
        RowBox[{"PerfectModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-215.21809280429932`\), 
                  214.7977449667909`}, {\(-218.02097036154726`\), 
                  217.59514815380987`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPhaseTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-215.21809280429932`\), 
                  214.7977449667909`}, {\(-218.02097036154726`\), 
                  217.59514815380987`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.3025483030091853`\), 
                  0.3037347669425546`}, {\(-0.2988062881337741`\), 
                  0.2999780774990046`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PhaseTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-215.21809280429932`\), 
                  214.7977449667909`}, {\(-218.02097036154726`\), 
                  217.59514815380987`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(Plot2D \[Rule] True\), 
        ",", \(PlotPoints \[Rule] 64\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.3025483030091853`\), 
                  0.3037347669425546`}, {\(-0.2988062881337741`\), 
                  0.2999780774990046`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{7.155085576474569`, \
\(-2.37185157231203`\), 0}, {13.737241216040012`, \(-2.4981094991585326`\), 
              0}}\), ",", \(PrinciplePointSeparation \[Rule] 
          6.583366458549512`\), 
        ",", \(RayBoundary \[Rule] {{\(-8.268817395408577`\), 
              8.268817395408577`}, {\(-8.377958904500504`\), 
              8.377958904500504`}}\), 
        ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
        ",", \(RenderedParameters \[Rule] {ModulationTransferFunction, 
            PointSpreadFunction, OpticalPathDifference}\), 
        ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
            WaveFrontIntensity}\), 
        ",", \(ResidualFitError \[Rule] 0.0016102275055979252`\), 
        ",", \(SampleFactor \[Rule] 2\), 
        ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
              591.9715477220698`, Astigmatism \[Rule] 220.6525325044598`, 
            FieldCurvature \[Rule] \(-661.5986912990095`\), 
            Distortion \[Rule] \(-61.04182755608818`\), 
            Coma \[Rule] 81.71148989922129`}\), 
        ",", \(ShowPerfectCase \[Rule] True\), 
        ",", \(SignalPlotCutoff \[Rule] 0.01`\), 
        ",", \(SmoothKernelRange \[Rule] 3\), 
        ",", \(SmoothKernelSize \[Rule] 1.25`\), 
        ",", \(SourceID \[Rule] 1351\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(StrehlRatio \[Rule] 0.00039016404605558125`\), 
        ",", \(SurfaceNumber \[Rule] 1\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.1369978533943406`\), \
\(-19.106322781000188`\)}, {\(-0.021835313056153834`\), \
\(-1.2464337861714014`\)}}\), 
        ",", \(TransverseMagnification \[Rule] \(-1.1369978533943406`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-11.151970343382732`\), 
                  11.151970343382732`}, {\(-11.26111185247466`\), 
                  11.26111185247466`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(ZernikeFit \[Rule] True\), ",", \(ZernikeOrder \[Rule] 8\)}], 
      "}"}]], "Output",
  CellLabel->"Out[81]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[" ", "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.500423 0.0579036 0.47636 0.0134692 [
[.06615 .46386 -12 -9 ]
[.06615 .46386 12 0 ]
[.21091 .46386 -6 -9 ]
[.21091 .46386 6 0 ]
[.35566 .46386 -12 -9 ]
[.35566 .46386 12 0 ]
[.50042 .46386 -3 -9 ]
[.50042 .46386 3 0 ]
[.64518 .46386 -9 -9 ]
[.64518 .46386 9 0 ]
[.78994 .46386 -3 -9 ]
[.78994 .46386 3 0 ]
[.9347 .46386 -9 -9 ]
[.9347 .46386 9 0 ]
[-0.95724 .07229 -18 -4.5 ]
[-0.95724 .07229 0 4.5 ]
[-0.95724 .20698 -18 -4.5 ]
[-0.95724 .20698 0 4.5 ]
[-0.95724 .34167 -18 -4.5 ]
[-0.95724 .34167 0 4.5 ]
[-0.95724 .61105 -12 -4.5 ]
[-0.95724 .61105 0 4.5 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ -0.94474 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06615 .47636 m
.06615 .48261 L
s
[(-7.5)] .06615 .46386 0 1 Mshowa
.21091 .47636 m
.21091 .48261 L
s
[(-5)] .21091 .46386 0 1 Mshowa
.35566 .47636 m
.35566 .48261 L
s
[(-2.5)] .35566 .46386 0 1 Mshowa
.50042 .47636 m
.50042 .48261 L
s
[(0)] .50042 .46386 0 1 Mshowa
.64518 .47636 m
.64518 .48261 L
s
[(2.5)] .64518 .46386 0 1 Mshowa
.78994 .47636 m
.78994 .48261 L
s
[(5)] .78994 .46386 0 1 Mshowa
.9347 .47636 m
.9347 .48261 L
s
[(7.5)] .9347 .46386 0 1 Mshowa
.125 Mabswid
.0951 .47636 m
.0951 .48011 L
s
.12405 .47636 m
.12405 .48011 L
s
.153 .47636 m
.153 .48011 L
s
.18195 .47636 m
.18195 .48011 L
s
.23986 .47636 m
.23986 .48011 L
s
.26881 .47636 m
.26881 .48011 L
s
.29776 .47636 m
.29776 .48011 L
s
.32671 .47636 m
.32671 .48011 L
s
.38462 .47636 m
.38462 .48011 L
s
.41357 .47636 m
.41357 .48011 L
s
.44252 .47636 m
.44252 .48011 L
s
.47147 .47636 m
.47147 .48011 L
s
.52937 .47636 m
.52937 .48011 L
s
.55833 .47636 m
.55833 .48011 L
s
.58728 .47636 m
.58728 .48011 L
s
.61623 .47636 m
.61623 .48011 L
s
.67413 .47636 m
.67413 .48011 L
s
.70309 .47636 m
.70309 .48011 L
s
.73204 .47636 m
.73204 .48011 L
s
.76099 .47636 m
.76099 .48011 L
s
.81889 .47636 m
.81889 .48011 L
s
.84784 .47636 m
.84784 .48011 L
s
.8768 .47636 m
.8768 .48011 L
s
.90575 .47636 m
.90575 .48011 L
s
.03719 .47636 m
.03719 .48011 L
s
.00824 .47636 m
.00824 .48011 L
s
.96365 .47636 m
.96365 .48011 L
s
.9926 .47636 m
.9926 .48011 L
s
.25 Mabswid
0 .47636 m
1 .47636 L
s
-0.94474 .07229 m
-0.93849 .07229 L
s
[(-30)] -0.95724 .07229 1 0 Mshowa
-0.94474 .20698 m
-0.93849 .20698 L
s
[(-20)] -0.95724 .20698 1 0 Mshowa
-0.94474 .34167 m
-0.93849 .34167 L
s
[(-10)] -0.95724 .34167 1 0 Mshowa
-0.94474 .61105 m
-0.93849 .61105 L
s
[(10)] -0.95724 .61105 1 0 Mshowa
.125 Mabswid
-0.94474 .09922 m
-0.94099 .09922 L
s
-0.94474 .12616 m
-0.94099 .12616 L
s
-0.94474 .1531 m
-0.94099 .1531 L
s
-0.94474 .18004 m
-0.94099 .18004 L
s
-0.94474 .23392 m
-0.94099 .23392 L
s
-0.94474 .26085 m
-0.94099 .26085 L
s
-0.94474 .28779 m
-0.94099 .28779 L
s
-0.94474 .31473 m
-0.94099 .31473 L
s
-0.94474 .36861 m
-0.94099 .36861 L
s
-0.94474 .39555 m
-0.94099 .39555 L
s
-0.94474 .42248 m
-0.94099 .42248 L
s
-0.94474 .44942 m
-0.94099 .44942 L
s
-0.94474 .5033 m
-0.94099 .5033 L
s
-0.94474 .53024 m
-0.94099 .53024 L
s
-0.94474 .55718 m
-0.94099 .55718 L
s
-0.94474 .58411 m
-0.94099 .58411 L
s
-0.94474 .04535 m
-0.94099 .04535 L
s
-0.94474 .01841 m
-0.94099 .01841 L
s
.25 Mabswid
-0.94474 0 m
-0.94474 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .1402 m
.03853 .1063 L
.05458 .07618 L
.06965 .05393 L
.08415 .03762 L
.09223 .03056 L
.09958 .02534 L
.10722 .02107 L
.11444 .01808 L
.11813 .01692 L
.12205 .01597 L
.12539 .01537 L
.12729 .01512 L
.12907 .01493 L
.13005 .01486 L
.13096 .0148 L
.13196 .01476 L
.13252 .01474 L
.13277 .01473 L
.13303 .01473 L
.13351 .01472 L
.13396 .01472 L
.13444 .01472 L
.13471 .01472 L
.13496 .01472 L
.13542 .01473 L
.13584 .01474 L
.13633 .01475 L
.13679 .01477 L
.13764 .01481 L
.13854 .01487 L
.14017 .015 L
.14191 .0152 L
.14384 .01547 L
.14769 .01617 L
.15121 .01702 L
.15916 .01959 L
.16637 .0227 L
.17425 .02689 L
.1897 .03734 L
.20458 .04995 L
.22039 .06578 L
.23562 .0831 L
.25027 .10141 L
.26586 .12242 L
.28087 .14389 L
.2953 .16547 L
.31067 .18922 L
.32546 .21266 L
.34119 .23797 L
Mistroke
.35633 .26256 L
.3709 .28622 L
.38641 .31125 L
.40133 .33505 L
.41719 .35986 L
.43248 .38316 L
.44718 .40489 L
.46282 .42714 L
.47789 .44763 L
.49237 .46638 L
.50779 .48521 L
.52263 .50218 L
.53841 .51889 L
.55361 .53364 L
.56823 .54654 L
.58379 .55884 L
.59877 .56927 L
.61317 .57797 L
.6285 .5858 L
.64326 .59195 L
.65895 .597 L
.66679 .59895 L
.67407 .60044 L
.6811 .60158 L
.6886 .60247 L
.69252 .60281 L
.69457 .60296 L
.69675 .60308 L
.69866 .60317 L
.69967 .60321 L
.70075 .60324 L
.70175 .60327 L
.70265 .60329 L
.70309 .6033 L
.70357 .6033 L
.70399 .60331 L
.70443 .60331 L
.70489 .60332 L
.70532 .60332 L
.70578 .60332 L
.70628 .60332 L
.70671 .60332 L
.70717 .60332 L
.70761 .60331 L
.70801 .60331 L
.70898 .6033 L
.71004 .60328 L
.71104 .60325 L
.71196 .60322 L
.71381 .60316 L
Mistroke
.71584 .60306 L
.71996 .6028 L
.72382 .60248 L
.72736 .60212 L
.73531 .60108 L
.75045 .59828 L
.765 .59464 L
.78049 .58986 L
.79541 .58451 L
.81126 .57815 L
.82653 .57153 L
.84122 .56487 L
.85685 .55766 L
.8719 .55081 L
.88637 .54451 L
.90178 .53834 L
.91661 .53319 L
.92416 .53094 L
.93237 .52885 L
.9396 .52734 L
.94371 .52664 L
.94756 .52609 L
.95119 .52568 L
.9551 .52535 L
.95714 .52522 L
.95825 .52517 L
.95928 .52513 L
.96016 .5251 L
.96061 .52509 L
.96111 .52508 L
.96139 .52508 L
.96165 .52508 L
.96189 .52507 L
.96215 .52507 L
.96262 .52507 L
.96311 .52507 L
.96353 .52507 L
.96392 .52507 L
.96434 .52507 L
.9648 .52508 L
.96523 .52509 L
.96564 .5251 L
.9664 .52512 L
.96785 .52517 L
.96942 .52525 L
.97113 .52537 L
.97295 .52553 L
.97619 .52589 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[349]:=",
  ImageSize->{288, 174.938},
  ImageMargins->{{0, 0}, {0, 3}},
  ImageRegion->{{0, 1}, {0, 1.01715}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000[R000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3oool00`000000oooo0?oo
o`3o0?ooo`/0oooo000C0?ooo`030000003oool0oooo0?l0oooo2`3oool001<0oooo00<000000?oo
o`3oool0L03oool6000009@0oooo000C0?ooo`030000003oool0oooo06h0oooo0P0000050?ooo`<0
0000TP3oool001<0oooo00<000000?ooo`3oool0K03oool2000000X0oooo00<000000?ooo`3oool0
S`3oool001<0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo08l0oooo00070?ooo`<00000103oool2000000<0oooo00<000000?ooo`3oool0J`3oool0
0`000000oooo0?ooo`0;0?ooo`800000S`3oool000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo08`0oooo0005000000D0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`02000006/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`2;0?ooo`00203oool2000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`1Y0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0RP3oool000X0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0RP3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo08T0oooo00070?ooo`<00000103oool2000000<0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo08T0oooo000C0?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`280?ooo`004`3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0Q`3oool0
01<0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
08H0oooo000C0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`250?ooo`004`3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo08D0oooo
000C0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0Q03oool001<0oooo00<00000
0?ooo`3oool0P`3oool00`000000oooo0?ooo`240?ooo`001P3oool5000000<0oooo0P0000030?oo
o`030000003oool0oooo08@0oooo00<000000?ooo`3oool0P`3oool000L0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0PP3oool000D000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`210?ooo`002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P0000280?ooo`030000003oool0
oooo0800oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0P03oool000H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`1o0?ooo`001`3oool3000000@0oooo0P0000030?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0O`3oool001<0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`1o0?ooo`004`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
07h0oooo000C0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0O@3oool001<0oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`1l0?ooo`004`3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo07/0oooo000C0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0N`3oool001<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1j0?oo
o`004`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo07X0oooo00070?ooo`<00000
103oool2000000<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1j0?ooo`00203o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`1i0?ooo`001@0000030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool200000900oooo00<000000?ooo`3oool0N03oool000P0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool0M`3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0MP3oool000L0oooo0P00
00040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`1f0?ooo`00203oool00`000000oooo0?ooo`030?ooo`8000000`3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo07D0oooo000C0?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool0M@3oool001<0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo0`0000070?ooo`<000001P3oool5000000<0oooo00<000000?oo
o`3oool00P3oool3000000D0oooo0P0000050?ooo`D000000`3oool00`000000oooo0?ooo`020?oo
o`<000001`3oool3000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`<00000>P3oool001<0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`070?ooo`05
0000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000H0oooo00@00000
0?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool0
00001@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000001@3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?oo
o`3oool0000003T0oooo000C0?ooo`030000003oool0oooo05h0oooo1@0000040?ooo`030000003o
ool0oooo00X0oooo1@0000050?ooo`D000000`3oool00`000000oooo0?ooo`0;0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0=`3oool001<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0:0?ooo`8000000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0=`3oool001<0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?oo
o`050?ooo`@000001P3oool4000000H0oooo00D000000?ooo`3oool0oooo000000070?ooo`@00000
00D0oooo0000003oool0oooo000000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000070?ooo`@000001P3oool4000000X0oooo00<000000?ooo`3oool01@3oool40000
03X0oooo000C0?ooo`030000003oool0oooo06@0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0
000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0
>`3oool001<0oooo00<000000?ooo`3oool0I03oool5000000L0oooo1@0000050?ooo`D000001P3o
ool3000000P0oooo1@0000020?ooo`040000003oool00000000000H0oooo0`0000080?ooo`D00000
1@3oool5000000D0oooo1@0000070?ooo`D00000>@3oool001<0oooo00<000000?ooo`3oool0V03o
ool00`000000oooo0?ooo`1_0?ooo`004`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0
oooo06h0oooo000C0?ooo`030000003oool0oooo06<0ooooKP00000i0?ooo`004`3oool00`000000
oooo0?ooo`1Z0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo03h0oooo000C0?ooo`030000003oool0oooo09/0oooo
00<000000?ooo`3oool0K03oool001<0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?oo
o`1[0?ooo`004`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo06X0oooo000C0?oo
o`030000003oool0oooo09h0oooo00<000000?ooo`3oool0:@3oool4000003`0oooo000C0?ooo`03
0000003oool0oooo09l0oooo00<000000?ooo`3oool0903oool400000400oooo000C0?ooo`030000
003oool0oooo0:00oooo00<000000?ooo`3oool0803oool3000004@0oooo000C0?ooo`030000003o
ool0oooo0:40oooo0P00000N0?ooo`800000A`3oool001<0oooo00<000000?ooo`3oool0X`3oool0
0`000000oooo0?ooo`0I0?ooo`800000B@3oool001<0oooo00<000000?ooo`3oool0Y03oool20000
01H0oooo0`00001;0?ooo`004`3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0C03oool000L0oooo0`0000040?ooo`8000000`3oool00`000000oooo
0?ooo`2W0?ooo`8000003P3oool4000004l0oooo00080?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`2Y0?ooo`@000001`3oool3000005<0oooo
00080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`2]0?ooo`L00000EP3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`800000o`3oool<0?ooo`00203oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000?l0oooo403oool000L0oooo0P0000040?ooo`040000003oool0oooo00000?l0oooo
403oool000P0oooo00<000000?ooo`3oool00`3oool2000003L0oooo0`00002:0?ooo`030000003o
ool0oooo02/0oooo0`00000E0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0080oooo00120?ooo`<000000`3oool3000000@0oooo0P0000020?ooo`D000000P3oool30000
00<0oooo100000000`3oool0000000000003000000L0oooo0`0000040?ooo`@000000`3oool20000
0080oooo1P0000060?ooo`@000000P3oool5000000030?ooo`000000000000<0000000<0oooo0000
000000000`0000020?ooo`<000000P3oool3000000@0oooo0`0000020?ooo`<0000000@0oooo0000
00000000oooo0`0000030?ooo`<000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000<0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D000000P3oool3
00000080oooo0`000000103oool000000000003oool4000000<0oooo0P0000020?ooo`X000001@3o
ool00`000000oooo0?ooo`010?ooo`00@@3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0
oooo000000070?ooo`050000003oool0oooo0?ooo`0000001P3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00
@@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3oool3000000@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`03
0000003oool0oooo0080oooo1@0000020?ooo`060000003oool0oooo0000003oool000001@3oool5
000000P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool000000080oooo0`00
00030?ooo`030000003oool000000080oooo1@0000030?ooo`040000003oool0oooo0?ooo`D00000
0P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`0000020?ooo`<000001@3oool00`000000oooo0?ooo`010?ooo`00@@3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool300000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo008000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`040000003oool0oooo000000D0
oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`030000003oool0oooo0040oooo00110?oo
o`060000003oool0oooo0?ooo`000000oooo100000020?ooo`@000000P3oool3000000@0oooo0`00
00030?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo00000080oooo
0P0000030?ooo`@000000`3oool3000000T0oooo00D000000?ooo`3oool000000?ooo`03000000@0
oooo100000020?ooo`@000000P3oool300000080oooo0P0000000`3oool00000000000020?ooo`<0
00000P3oool4000000<0oooo0`0000030?ooo`<000002@3oool00`000000oooo0?ooo`020?ooo`H0
000000<0oooo0000000000000`3oool2000000030?ooo`00000000000080oooo0`0000040?ooo`03
0000003oool0oooo0080oooo0`0000020?ooo`@000000`3oool9000000<0oooo0`0000030?ooo`@0
0000103oool00`000000oooo0?ooo`010?ooo`00@@3oool01@000000oooo0?ooo`3oool0000000P0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0000
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool00480oooo0`0000090?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03@3oool3000000T0oooo100000090?ooo`030000003oool0oooo
0080oooo0P00000:0?ooo`@00000103oool00`000000oooo0?ooo`040?ooo`800000103oool20000
02h0oooo00<000000?ooo`3oool0603oool3000001H0oooo00<000000?ooo`3oool00P3oool20000
00/0oooo00<000000?ooo`3oool00`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {173.938, -3}} -> {-28.0412, -71.5127, \
0.159284, 0.684757}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[BoxData[
    \("Warning: too few sample points."\)], "Print",
  CellLabel->"From In[349]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[BoxData[
    \("Need to increase the NumberOfPoints option."\)], "Print",
  CellLabel->"From In[349]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[BoxData[
    InterpretationBox[\("Suggestion: NumberOfPoints -> "\[InvisibleSpace]128\
\[InvisibleSpace]"."\),
      SequenceForm[ "Suggestion: NumberOfPoints -> ", 128, "."],
      Editable->False]], "Print",
  CellLabel->"From In[349]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.492441 12.6429 0.0147151 0.590452 [
[.11315 .00222 -15 -9 ]
[.11315 .00222 15 0 ]
[.23958 .00222 -15 -9 ]
[.23958 .00222 15 0 ]
[.36601 .00222 -15 -9 ]
[.36601 .00222 15 0 ]
[.49244 .00222 -3 -9 ]
[.49244 .00222 3 0 ]
[.61887 .00222 -12 -9 ]
[.61887 .00222 12 0 ]
[.7453 .00222 -12 -9 ]
[.7453 .00222 12 0 ]
[.87173 .00222 -12 -9 ]
[.87173 .00222 12 0 ]
[.99816 .00222 -12 -9 ]
[.99816 .00222 12 0 ]
[.01131 .13281 -18 -4.5 ]
[.01131 .13281 0 4.5 ]
[.01131 .2509 -18 -4.5 ]
[.01131 .2509 0 4.5 ]
[.01131 .36899 -18 -4.5 ]
[.01131 .36899 0 4.5 ]
[.01131 .48708 -18 -4.5 ]
[.01131 .48708 0 4.5 ]
[.01131 .60517 -6 -4.5 ]
[.01131 .60517 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11315 .01472 m
.11315 .02097 L
s
[(-0.03)] .11315 .00222 0 1 Mshowa
.23958 .01472 m
.23958 .02097 L
s
[(-0.02)] .23958 .00222 0 1 Mshowa
.36601 .01472 m
.36601 .02097 L
s
[(-0.01)] .36601 .00222 0 1 Mshowa
.49244 .01472 m
.49244 .02097 L
s
[(0)] .49244 .00222 0 1 Mshowa
.61887 .01472 m
.61887 .02097 L
s
[(0.01)] .61887 .00222 0 1 Mshowa
.7453 .01472 m
.7453 .02097 L
s
[(0.02)] .7453 .00222 0 1 Mshowa
.87173 .01472 m
.87173 .02097 L
s
[(0.03)] .87173 .00222 0 1 Mshowa
.99816 .01472 m
.99816 .02097 L
s
[(0.04)] .99816 .00222 0 1 Mshowa
.125 Mabswid
.13844 .01472 m
.13844 .01847 L
s
.16372 .01472 m
.16372 .01847 L
s
.18901 .01472 m
.18901 .01847 L
s
.2143 .01472 m
.2143 .01847 L
s
.26487 .01472 m
.26487 .01847 L
s
.29015 .01472 m
.29015 .01847 L
s
.31544 .01472 m
.31544 .01847 L
s
.34073 .01472 m
.34073 .01847 L
s
.3913 .01472 m
.3913 .01847 L
s
.41658 .01472 m
.41658 .01847 L
s
.44187 .01472 m
.44187 .01847 L
s
.46716 .01472 m
.46716 .01847 L
s
.51773 .01472 m
.51773 .01847 L
s
.54301 .01472 m
.54301 .01847 L
s
.5683 .01472 m
.5683 .01847 L
s
.59358 .01472 m
.59358 .01847 L
s
.64416 .01472 m
.64416 .01847 L
s
.66944 .01472 m
.66944 .01847 L
s
.69473 .01472 m
.69473 .01847 L
s
.72001 .01472 m
.72001 .01847 L
s
.77059 .01472 m
.77059 .01847 L
s
.79587 .01472 m
.79587 .01847 L
s
.82116 .01472 m
.82116 .01847 L
s
.84644 .01472 m
.84644 .01847 L
s
.89702 .01472 m
.89702 .01847 L
s
.9223 .01472 m
.9223 .01847 L
s
.94759 .01472 m
.94759 .01847 L
s
.97287 .01472 m
.97287 .01847 L
s
.08787 .01472 m
.08787 .01847 L
s
.06258 .01472 m
.06258 .01847 L
s
.0373 .01472 m
.0373 .01847 L
s
.01201 .01472 m
.01201 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13281 m
.03006 .13281 L
s
[(0.2)] .01131 .13281 1 0 Mshowa
.02381 .2509 m
.03006 .2509 L
s
[(0.4)] .01131 .2509 1 0 Mshowa
.02381 .36899 m
.03006 .36899 L
s
[(0.6)] .01131 .36899 1 0 Mshowa
.02381 .48708 m
.03006 .48708 L
s
[(0.8)] .01131 .48708 1 0 Mshowa
.02381 .60517 m
.03006 .60517 L
s
[(1)] .01131 .60517 1 0 Mshowa
.125 Mabswid
.02381 .04424 m
.02756 .04424 L
s
.02381 .07376 m
.02756 .07376 L
s
.02381 .10328 m
.02756 .10328 L
s
.02381 .16233 m
.02756 .16233 L
s
.02381 .19185 m
.02756 .19185 L
s
.02381 .22137 m
.02756 .22137 L
s
.02381 .28042 m
.02756 .28042 L
s
.02381 .30994 m
.02756 .30994 L
s
.02381 .33946 m
.02756 .33946 L
s
.02381 .39851 m
.02756 .39851 L
s
.02381 .42803 m
.02756 .42803 L
s
.02381 .45755 m
.02756 .45755 L
s
.02381 .5166 m
.02756 .5166 L
s
.02381 .54612 m
.02756 .54612 L
s
.02381 .57564 m
.02756 .57564 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .10532 m
.03853 .06219 L
.04619 .03907 L
.05024 .02682 L
.05131 .02358 L
.05247 .02008 L
.053 .01847 L
.05357 .01676 L
.05405 .01533 L
.05432 .01547 L
.05458 .0156 L
.05867 .01767 L
.06238 .01956 L
.06589 .02133 L
.0669 .02184 L
.06785 .02233 L
.06827 .02254 L
.06871 .02277 L
.0692 .02316 L
.06965 .02495 L
.07726 .05513 L
.08127 .07101 L
.08345 .07968 L
.0855 .08574 L
.08928 .09443 L
.09344 .10397 L
.09697 .11206 L
.09799 .11439 L
.09849 .11554 L
.09895 .1166 L
.09937 .11756 L
.09982 .11609 L
.10076 .11269 L
.11514 .06116 L
.12313 .03775 L
.12663 .0275 L
.12759 .02469 L
.12861 .02169 L
.12911 .02023 L
.12958 .01886 L
.13 .01928 L
.13046 .02 L
.13763 .03129 L
.14154 .03743 L
.1433 .0402 L
.14377 .04093 L
.14427 .04173 L
.14475 .04249 L
.14519 .04401 L
.14708 .05048 L
Mistroke
.1488 .05638 L
.15276 .07 L
.1569 .08417 L
.15788 .08756 L
.15892 .09112 L
.15935 .0926 L
.15981 .09417 L
.16031 .09423 L
.16078 .09408 L
.16455 .09294 L
.16861 .09171 L
.17052 .09113 L
.17233 .09058 L
.17395 .09009 L
.17439 .08996 L
.17486 .08981 L
.17526 .08876 L
.17571 .08718 L
.17961 .07323 L
.18371 .05856 L
.18722 .04604 L
.18818 .04261 L
.1892 .03895 L
.1897 .03717 L
.19017 .03626 L
.19059 .03954 L
.19104 .04309 L
.19808 .09785 L
.20207 .12894 L
.20402 .14413 L
.20447 .14762 L
.20494 .15133 L
.20535 .1536 L
.2058 .15414 L
.2067 .15523 L
.20768 .15641 L
.20946 .15856 L
.21339 .16329 L
.21538 .16569 L
.21752 .16828 L
.21851 .16947 L
.21905 .17012 L
.21955 .17072 L
.21998 .17124 L
.22044 .17072 L
.2207 .16834 L
.22095 .16609 L
.22141 .16188 L
.22838 .09853 L
.23234 .06251 L
Mistroke
.23333 .05347 L
.23428 .04489 L
.23469 .04116 L
.23513 .03718 L
.23561 .03456 L
.23605 .03548 L
.23969 .043 L
.24361 .05108 L
.24779 .05969 L
.24962 .06347 L
.25012 .0645 L
.2504 .06507 L
.25066 .06549 L
.2509 .06567 L
.25116 .06586 L
.25163 .06619 L
.25353 .06756 L
.25555 .06901 L
.25979 .07206 L
.26173 .07345 L
.26378 .07493 L
.26463 .07554 L
.26507 .07586 L
.26554 .07619 L
.26579 .07623 L
.26606 .07605 L
.26654 .07573 L
.26747 .0751 L
.27495 .07011 L
.2771 .06868 L
.27816 .06797 L
.27913 .06732 L
.28002 .06673 L
.28047 .06643 L
.28096 .06683 L
.28145 .06878 L
.28198 .07088 L
.28293 .07466 L
.29046 .10451 L
.29444 .12027 L
.29499 .12245 L
.29558 .12481 L
.29585 .12589 L
.29614 .12637 L
.29639 .12663 L
.29666 .1269 L
.29867 .12897 L
.30274 .13315 L
.30653 .13705 L
.30834 .13891 L
Mistroke
.31005 .14066 L
.31051 .14113 L
.311 .14163 L
.31125 .14033 L
.31153 .13861 L
.31203 .13556 L
.31382 .12448 L
.32183 .07504 L
.32367 .06368 L
.32468 .05745 L
.32563 .05158 L
.32607 .04891 L
.32652 .04763 L
.32702 .04661 L
.32748 .04569 L
.32916 .0423 L
.33278 .035 L
.33673 .02704 L
.33839 .0237 L
.34016 .02012 L
.34069 .01906 L
.34118 .01806 L
.34163 .01819 L
.34211 .01861 L
.34393 .02018 L
.35131 .02656 L
.35946 .03266 L
.36317 .03471 L
.36717 .03693 L
.36901 .03795 L
.37002 .0385 L
.37051 .03877 L
.37095 .03902 L
.37136 .03925 L
.37175 .03895 L
.37216 .03833 L
.3726 .03766 L
.37441 .0349 L
.38198 .02339 L
.38382 .0206 L
.38484 .01906 L
.3858 .01759 L
.38634 .01677 L
.38665 .01639 L
.38693 .01696 L
.38797 .01902 L
.39 .02305 L
.39717 .03731 L
.39912 .04118 L
.40094 .0448 L
Mistroke
.40141 .04573 L
.40186 .04646 L
.4021 .04662 L
.40237 .0468 L
.40284 .0471 L
.40492 .04846 L
.40918 .05123 L
.41309 .05378 L
.41503 .05504 L
.41554 .05537 L
.41609 .05573 L
.41634 .0559 L
.41661 .05607 L
.41708 .05602 L
.41752 .05563 L
.41792 .05526 L
.41884 .05442 L
.42078 .05265 L
.42792 .04611 L
.42988 .04432 L
.43095 .04334 L
.43148 .04286 L
.43195 .04243 L
.43239 .04243 L
.43281 .04245 L
.43372 .04249 L
.43567 .04257 L
.43956 .04275 L
.44162 .04284 L
.44381 .04294 L
.4457 .04302 L
.44622 .04304 L
.44649 .04306 L
.44678 .04307 L
.44703 .04308 L
.44731 .04343 L
.4478 .04419 L
.45149 .04996 L
.45532 .05595 L
.45895 .06162 L
.46095 .06475 L
.4615 .0656 L
.4618 .06607 L
.46208 .06651 L
.46258 .06647 L
.46284 .0663 L
.46312 .06611 L
.46692 .06363 L
.47077 .06112 L
.47281 .0598 L
Mistroke
.47498 .05838 L
.47605 .05768 L
.47658 .05734 L
.47706 .05702 L
.4775 .05702 L
.47797 .05746 L
.47895 .05839 L
.48263 .06188 L
.48624 .0653 L
.48823 .06719 L
.49011 .06897 L
.49096 .06978 L
.49187 .07063 L
.49234 .07108 L
.4926 .07102 L
.49285 .07079 L
.49377 .06992 L
.4971 .06676 L
.50085 .06321 L
.50289 .06128 L
.50479 .05947 L
.50642 .05793 L
.50689 .05749 L
.50733 .05707 L
.50773 .05696 L
.50816 .05724 L
.51184 .05964 L
.51575 .0622 L
.51941 .06458 L
.52126 .06578 L
.52179 .06613 L
.52229 .06646 L
.52274 .06661 L
.52323 .06584 L
.52743 .05928 L
.5313 .05323 L
.53494 .04754 L
.53696 .04438 L
.53751 .04352 L
.53779 .04308 L
.5381 .04307 L
.53914 .04302 L
.54294 .04285 L
.54677 .04268 L
.55039 .04252 L
.55136 .04248 L
.55189 .04245 L
.55239 .04243 L
.55265 .04242 L
.55293 .04242 L
Mistroke
.55323 .04271 L
.55352 .04297 L
.55456 .04392 L
.55836 .04739 L
.56186 .05059 L
.56559 .054 L
.56669 .05501 L
.56723 .05551 L
.56773 .05596 L
.56819 .05613 L
.56867 .05582 L
.56968 .05516 L
.57348 .05268 L
.57708 .05033 L
.57907 .04904 L
.58095 .04781 L
.5818 .04726 L
.5827 .04667 L
.58317 .04633 L
.58344 .0458 L
.58369 .0453 L
.5846 .04349 L
.58793 .03687 L
.59168 .02943 L
.59372 .02538 L
.59562 .0216 L
.59724 .01837 L
.59771 .01744 L
.59815 .01656 L
.59855 .01678 L
.59898 .01743 L
.60266 .02303 L
.61023 .03454 L
.61207 .03733 L
.6126 .03814 L
.6131 .0389 L
.61355 .03923 L
.61404 .03896 L
.61621 .03776 L
.61824 .03663 L
.62637 .03213 L
.63374 .02642 L
.63743 .02323 L
.63937 .02155 L
.64142 .01978 L
.64229 .01903 L
.64277 .01862 L
.64322 .01823 L
.64347 .01801 L
.64375 .01816 L
Mistroke
.64424 .01914 L
.64519 .02106 L
.64865 .02805 L
.65254 .0359 L
.65619 .04326 L
.65709 .04506 L
.65803 .04695 L
.65852 .04795 L
.6588 .04879 L
.65906 .05039 L
.66 .05622 L
.6642 .08213 L
.66821 .10691 L
.67019 .11907 L
.672 .13028 L
.67286 .13555 L
.67327 .13813 L
.67365 .14048 L
.67406 .14146 L
.67449 .14102 L
.6754 .14008 L
.67908 .13629 L
.6826 .13268 L
.68634 .12884 L
.68745 .1277 L
.68799 .12714 L
.68849 .12663 L
.68895 .12616 L
.68943 .1243 L
.69044 .12029 L
.69424 .10522 L
.69787 .09084 L
.69986 .08294 L
.70175 .07547 L
.7026 .07209 L
.7035 .06851 L
.70397 .06664 L
.70424 .06631 L
.70449 .06648 L
.70541 .06709 L
.70874 .06932 L
.71269 .07195 L
.71464 .07326 L
.71645 .07446 L
.71808 .07555 L
.71855 .07587 L
.719 .07616 L
.71939 .07616 L
.71982 .07585 L
.72351 .0732 L
Mistroke
.7311 .06774 L
.73295 .06641 L
.73348 .06603 L
.73398 .06567 L
.73443 .06518 L
.73493 .06417 L
.7371 .05969 L
.73913 .0555 L
.74301 .04749 L
.74666 .03997 L
.74755 .03813 L
.74849 .03619 L
.74898 .03518 L
.74926 .0346 L
.74952 .035 L
.74997 .03915 L
.75046 .04358 L
.75466 .08175 L
.75856 .11721 L
.76061 .13589 L
.76279 .15566 L
.76371 .164 L
.76395 .16619 L
.76421 .16859 L
.76469 .1715 L
.76498 .17114 L
.76526 .17082 L
.76577 .17019 L
.76678 .16897 L
.77047 .16453 L
.7745 .15967 L
.77648 .15728 L
.77735 .15624 L
.7783 .15509 L
.77871 .15459 L
.77916 .15405 L
.77958 .15355 L
.77996 .15118 L
.78171 .13755 L
.78539 .10887 L
.78892 .08136 L
.79267 .05216 L
.79362 .04483 L
.79411 .04098 L
.79438 .03888 L
.79463 .03693 L
.79491 .03618 L
.79521 .03726 L
.79574 .03916 L
.79679 .0429 L
Mistroke
.80059 .05648 L
.80461 .07085 L
.80658 .0779 L
.8084 .08439 L
.80925 .08745 L
.80967 .08894 L
.81005 .08982 L
.81045 .08994 L
.81088 .09007 L
.8118 .09035 L
.81548 .09147 L
.819 .09254 L
.82274 .09367 L
.82368 .09396 L
.82417 .09411 L
.82469 .09426 L
.82497 .09435 L
.82527 .0935 L
.8258 .09168 L
.82685 .0881 L
.83065 .07505 L
.8348 .06078 L
.83685 .05377 L
.83873 .0473 L
.83961 .04427 L
.84005 .04278 L
.84044 .04199 L
.84086 .04134 L
.84131 .04064 L
.84226 .03914 L
.84608 .03312 L
.84973 .02739 L
.85165 .02437 L
.85271 .02271 L
.8537 .02114 L
.85465 .01965 L
.85491 .01925 L
.85518 .01882 L
.85567 .01994 L
.85746 .02517 L
.86094 .03538 L
.87541 .08122 L
.87923 .09502 L
.88285 .10809 L
.88382 .11159 L
.88485 .11531 L
.88511 .11624 L
.88539 .11724 L
.88569 .11715 L
.88598 .11649 L
Mistroke
.88702 .1141 L
.89082 .10539 L
.9065 .05958 L
.91028 .04457 L
.91236 .03632 L
.91432 .02854 L
.91521 .02502 L
.91566 .02324 L
.91615 .02278 L
.91641 .02265 L
.91669 .0225 L
.91718 .02225 L
.91814 .02177 L
.9216 .02001 L
.92549 .01804 L
.92741 .01706 L
.92919 .01616 L
.93002 .01574 L
.93042 .01553 L
.9308 .01534 L
.93123 .0165 L
.93169 .01791 L
.93251 .02037 L
.93612 .0313 L
.94392 .05487 L
.95119 .07636 L
.95479 .0869 L
.95819 .09687 L
.96007 .10238 L
.96059 .10389 L
.96085 .10465 L
.96113 .105 L
.96138 .10366 L
.96164 .10222 L
.96211 .09962 L
.96568 .08006 L
.97619 .02246 L
Mfstroke
1 0 0 r
.02381 .01502 m
.03097 .01487 L
.03462 .0148 L
.03663 .01476 L
.03762 .01474 L
.03805 .01473 L
.03853 .01472 L
.03901 .01472 L
.03928 .01472 L
.03952 .01473 L
.0406 .01475 L
.04249 .01479 L
.04619 .01488 L
.05049 .01497 L
.05152 .015 L
.05261 .01502 L
.05314 .01503 L
.05364 .01504 L
.05409 .01505 L
.05458 .01504 L
.05827 .01496 L
.06229 .01487 L
.06594 .01479 L
.06772 .01475 L
.0685 .01473 L
.06894 .01472 L
.06935 .01472 L
.06978 .01473 L
.07025 .01474 L
.0711 .01476 L
.07297 .01481 L
.07695 .01491 L
.08081 .01501 L
.08186 .01504 L
.08298 .01506 L
.08344 .01507 L
.08393 .01509 L
.08421 .01509 L
.08447 .01509 L
.08497 .01508 L
.09239 .01489 L
.09577 .01481 L
.09762 .01476 L
.09852 .01474 L
.09892 .01473 L
.09935 .01472 L
.0998 .01473 L
.10022 .01474 L
.10116 .01477 L
.10315 .01482 L
Mistroke
.10666 .01492 L
.11082 .01504 L
.11278 .0151 L
.11364 .01512 L
.11413 .01514 L
.11458 .01515 L
.11502 .01514 L
.11549 .01512 L
.11644 .01509 L
.11845 .01504 L
.12209 .01493 L
.12625 .01481 L
.12807 .01476 L
.12857 .01475 L
.12911 .01473 L
.12936 .01472 L
.12962 .01472 L
.13009 .01473 L
.13197 .01479 L
.13397 .01486 L
.13819 .015 L
.1419 .01512 L
.14297 .01516 L
.1435 .01518 L
.14398 .01519 L
.14442 .01521 L
.14488 .01521 L
.14535 .0152 L
.14586 .01518 L
.1534 .01493 L
.15512 .01487 L
.15699 .01481 L
.15785 .01478 L
.15876 .01475 L
.15914 .01474 L
.15954 .01473 L
.15998 .01472 L
.1604 .01474 L
.16428 .01489 L
.16782 .01503 L
.17162 .01518 L
.17267 .01522 L
.17378 .01526 L
.17432 .01528 L
.17459 .01529 L
.17483 .0153 L
.17529 .0153 L
.17579 .01528 L
.18341 .01498 L
.18731 .01482 L
Mistroke
.18826 .01479 L
.18928 .01475 L
.18958 .01474 L
.18987 .01472 L
.19012 .01472 L
.1904 .01473 L
.19145 .01478 L
.19563 .01498 L
.19957 .01516 L
.20311 .01533 L
.20408 .01537 L
.20461 .0154 L
.20511 .01542 L
.20553 .01541 L
.20598 .01539 L
.20694 .01535 L
.21408 .01501 L
.21604 .01492 L
.21812 .01482 L
.21897 .01478 L
.21942 .01476 L
.2199 .01474 L
.22015 .01472 L
.22042 .01472 L
.22091 .01475 L
.22185 .0148 L
.22605 .01505 L
.22995 .01527 L
.23366 .01549 L
.23417 .01552 L
.23473 .01555 L
.23498 .01557 L
.23525 .01558 L
.23573 .01558 L
.2362 .01555 L
.23663 .01552 L
.23762 .01547 L
.2447 .01506 L
.24664 .01494 L
.2487 .01482 L
.24971 .01476 L
.2502 .01474 L
.25065 .01472 L
.25106 .01475 L
.2515 .01478 L
.25241 .01485 L
.25627 .01513 L
.26049 .01545 L
.2624 .01559 L
.26346 .01566 L
Mistroke
.26445 .01574 L
.2649 .01577 L
.26538 .01581 L
.26563 .01582 L
.2659 .01581 L
.26639 .01578 L
.26815 .01565 L
.27554 .0151 L
.27767 .01495 L
.27872 .01487 L
.27969 .0148 L
.28014 .01476 L
.28057 .01473 L
.28106 .01474 L
.28151 .01478 L
.28349 .01498 L
.28721 .01534 L
.29114 .01572 L
.29275 .01587 L
.29449 .01604 L
.295 .01609 L
.29548 .01614 L
.29592 .01618 L
.29639 .01613 L
.29817 .01596 L
.3057 .01523 L
.30753 .01505 L
.3095 .01486 L
.31005 .01481 L
.31035 .01478 L
.31063 .01475 L
.31113 .01473 L
.31139 .01476 L
.31167 .0148 L
.3137 .01507 L
.3176 .0156 L
.32183 .01616 L
.32377 .01642 L
.32483 .01656 L
.32535 .01663 L
.32582 .0167 L
.32626 .01673 L
.32667 .01667 L
.32758 .01655 L
.32951 .01629 L
.33317 .0158 L
.33706 .01528 L
.33896 .01503 L
.33989 .0149 L
.34029 .01485 L
Mistroke
.34074 .01479 L
.34114 .01473 L
.34152 .01476 L
.34192 .01484 L
.34234 .01493 L
.34407 .01527 L
.34795 .01604 L
.35217 .01688 L
.35411 .01727 L
.35517 .01748 L
.35569 .01758 L
.35616 .01767 L
.35657 .01768 L
.357 .0176 L
.35791 .01742 L
.35984 .01703 L
.36349 .01631 L
.36738 .01554 L
.36926 .01516 L
.37019 .01498 L
.3706 .0149 L
.37104 .01481 L
.37145 .01473 L
.37182 .01482 L
.37264 .01509 L
.37438 .01565 L
.37835 .01695 L
.38212 .01818 L
.38375 .01871 L
.3855 .01928 L
.38593 .01942 L
.38641 .01958 L
.38668 .01963 L
.38692 .01955 L
.38741 .01939 L
.38918 .01881 L
.39638 .01646 L
.39835 .01582 L
.39943 .01547 L
.40046 .01513 L
.40092 .01498 L
.40141 .01482 L
.40167 .01474 L
.40195 .01485 L
.40245 .01517 L
.40426 .01632 L
.41166 .02103 L
.41379 .02238 L
.41483 .02305 L
.41581 .02367 L
Mistroke
.41626 .02396 L
.41669 .02423 L
.41718 .02413 L
.41763 .02384 L
.41961 .02258 L
.42333 .02021 L
.42726 .01771 L
.42888 .01668 L
.43062 .01558 L
.43113 .01525 L
.43161 .01494 L
.43205 .01485 L
.43252 .01568 L
.4343 .01881 L
.44183 .03209 L
.44366 .03532 L
.44564 .03879 L
.44619 .03976 L
.44649 .04029 L
.44677 .04079 L
.44726 .04105 L
.44753 .04059 L
.4478 .04009 L
.44984 .03651 L
.45374 .02963 L
.45797 .02218 L
.45991 .01876 L
.46097 .01689 L
.46149 .01597 L
.46197 .01514 L
.4624 .01777 L
.46281 .02429 L
.46372 .03867 L
.46565 .06921 L
.48022 .32135 L
.48442 .41876 L
.48836 .51038 L
.49008 .55041 L
.49103 .57227 L
.4919 .59265 L
.49236 .60332 L
.49285 .59559 L
.49313 .58908 L
.4934 .58292 L
.4939 .57137 L
.49573 .52883 L
.50349 .34859 L
.51066 .205 L
.51775 .09264 L
.51948 .06533 L
Mistroke
.52134 .03594 L
.52188 .02731 L
.52215 .02305 L
.5224 .0191 L
.52286 .01505 L
.52311 .01548 L
.52337 .01594 L
.52528 .01931 L
.5292 .0262 L
.53343 .03367 L
.53538 .03709 L
.53644 .03897 L
.53696 .03988 L
.53743 .04072 L
.53787 .04122 L
.53828 .0405 L
.53919 .0389 L
.54111 .0355 L
.54805 .02328 L
.54995 .01994 L
.55095 .01818 L
.552 .01633 L
.55244 .01554 L
.55292 .01472 L
.55319 .0149 L
.55344 .01505 L
.55393 .01536 L
.55571 .01649 L
.56323 .02128 L
.56521 .02254 L
.56624 .0232 L
.56681 .02356 L
.56735 .0239 L
.56781 .0242 L
.56831 .02416 L
.56859 .02398 L
.56886 .0238 L
.56937 .02348 L
.57123 .0223 L
.57517 .01979 L
.57887 .01743 L
.58049 .0164 L
.5822 .01532 L
.58263 .01504 L
.58309 .01475 L
.58336 .01478 L
.5836 .01486 L
.58407 .01502 L
.58579 .01558 L
.5933 .01803 L
Mistroke
.59526 .01867 L
.5963 .01901 L
.5974 .01937 L
.59786 .01952 L
.59836 .01961 L
.59865 .01952 L
.59891 .01944 L
.59942 .01927 L
.60129 .01866 L
.6085 .01631 L
.61048 .01566 L
.61157 .01531 L
.61259 .01497 L
.61306 .01482 L
.61355 .01475 L
.6138 .0148 L
.61409 .01486 L
.61458 .01495 L
.61639 .01531 L
.62381 .01679 L
.62594 .01721 L
.627 .01742 L
.62751 .01752 L
.62797 .01761 L
.62842 .0177 L
.62885 .01765 L
.6293 .01756 L
.62979 .01746 L
.63177 .01707 L
.63939 .01555 L
.64124 .01519 L
.64226 .01498 L
.64276 .01488 L
.64322 .01479 L
.64349 .01474 L
.64377 .01474 L
.64405 .01477 L
.64436 .01482 L
.6454 .01495 L
.64742 .01523 L
.65481 .01622 L
.65694 .0165 L
.65745 .01657 L
.65799 .01664 L
.65826 .01668 L
.6585 .01671 L
.65897 .01671 L
.65942 .01665 L
.65984 .01659 L
.66078 .01647 L
Mistroke
.66277 .0162 L
.66994 .01524 L
.6719 .01498 L
.67298 .01483 L
.67324 .0148 L
.67352 .01476 L
.67401 .01473 L
.67446 .01477 L
.67496 .01482 L
.676 .01492 L
.67781 .0151 L
.68518 .01581 L
.6872 .01601 L
.68821 .01611 L
.68849 .01613 L
.68879 .01616 L
.68907 .01617 L
.68932 .01615 L
.69312 .01578 L
.70043 .01507 L
.70243 .01488 L
.70344 .01478 L
.70372 .01475 L
.70401 .01472 L
.70429 .01473 L
.70455 .01475 L
.70835 .01503 L
.7156 .01556 L
.71758 .01571 L
.71815 .01575 L
.71869 .01579 L
.71917 .01583 L
.71945 .01581 L
.7197 .01579 L
.7235 .01551 L
.73068 .01498 L
.73265 .01484 L
.73322 .0148 L
.73375 .01476 L
.73423 .01472 L
.73451 .01473 L
.73476 .01474 L
.73856 .01496 L
.74568 .01538 L
.74763 .01549 L
.74866 .01555 L
.74917 .01558 L
.74946 .01559 L
.74973 .01558 L
.75172 .01546 L
Mistroke
.75353 .01535 L
.75755 .01512 L
.76134 .0149 L
.76299 .01481 L
.76343 .01478 L
.7639 .01475 L
.76434 .01473 L
.76474 .01472 L
.76521 .01475 L
.76566 .01477 L
.76666 .01481 L
.76843 .0149 L
.7721 .01507 L
.776 .01526 L
.7776 .01533 L
.77845 .01537 L
.7789 .01539 L
.77933 .01541 L
.77981 .01542 L
.78006 .01541 L
.78032 .0154 L
.78123 .01535 L
.78301 .01527 L
.78691 .01509 L
.79114 .01489 L
.79307 .0148 L
.79405 .01475 L
.79432 .01474 L
.79461 .01472 L
.79488 .01472 L
.79513 .01473 L
.79881 .01487 L
.80605 .01516 L
.80803 .01523 L
.80855 .01526 L
.80912 .01528 L
.80938 .01529 L
.80965 .0153 L
.81014 .0153 L
.81063 .01528 L
.81109 .01526 L
.81213 .01522 L
.81394 .01515 L
.81793 .01499 L
.8217 .01485 L
.82334 .01478 L
.82424 .01475 L
.82468 .01473 L
.82509 .01472 L
.82552 .01473 L
Mistroke
.826 .01475 L
.827 .01478 L
.82877 .01484 L
.83598 .01508 L
.83796 .01515 L
.83905 .01518 L
.83958 .0152 L
.84007 .01522 L
.84053 .01521 L
.84103 .01519 L
.84206 .01515 L
.84387 .01509 L
.84747 .01497 L
.85133 .01485 L
.8532 .01478 L
.85412 .01475 L
.85457 .01474 L
.85498 .01472 L
.85538 .01472 L
.85575 .01473 L
.85657 .01475 L
.85831 .0148 L
.86204 .01491 L
.86598 .01502 L
.8676 .01507 L
.86934 .01512 L
.86985 .01513 L
.87034 .01515 L
.87077 .01514 L
.87124 .01512 L
.87302 .01507 L
.88057 .01486 L
.88241 .0148 L
.88438 .01475 L
.88496 .01473 L
.88525 .01472 L
.88552 .01472 L
.88601 .01473 L
.88655 .01474 L
.88858 .01479 L
.89261 .01489 L
.8964 .01499 L
.89805 .01503 L
.8998 .01508 L
.90024 .01509 L
.90071 .01509 L
.90099 .01509 L
.90123 .01508 L
.90172 .01507 L
.90348 .01502 L
Mistroke
.91075 .01484 L
.91274 .01479 L
.91383 .01476 L
.91486 .01474 L
.91528 .01473 L
.91572 .01472 L
.91621 .01473 L
.91666 .01474 L
.91866 .01478 L
.92229 .01486 L
.92617 .01495 L
.92806 .01499 L
.92898 .01501 L
.92984 .01503 L
.93024 .01504 L
.93061 .01505 L
.931 .01505 L
.93143 .01504 L
.93317 .015 L
.94024 .01484 L
.94218 .0148 L
.94424 .01475 L
.94472 .01474 L
.94524 .01473 L
.94573 .01472 L
.94619 .01472 L
.9466 .01473 L
.94704 .01474 L
.94795 .01476 L
.95212 .01484 L
.95601 .01492 L
.95791 .01495 L
.95971 .01499 L
.96019 .015 L
.9607 .01501 L
.96097 .01502 L
.96126 .01501 L
.96153 .01501 L
.96178 .015 L
.96367 .01497 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[349]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`00000<0?oo
o`800000103oool00`000000oooo0?ooo`030?ooo`8000000P3oool5000000/0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<000004P3oool2000001D0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000303oool2000000@0oooo00<000000?oo
o`3oool00`3oool200000080oooo1@00000;0?ooo`800000103oool00`000000oooo0?ooo`030?oo
o`8000000`3oool3000000`0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`<000001P3oool002L0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0403oool010000000oooo0?oo
o`00000C0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`0:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo000P0?ooo`D000000P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3o
ool0oooo1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`030?ooo`D000000P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000C0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`080?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3oool00000
0?ooo`05000000H0oooo000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool2000000/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000004`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
2@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P00000;0?oo
o`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000
003oool0oooo00D0oooo000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000P0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0100oooo00@000000?ooo`3o
ool000004`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003o
ool000000`3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo000000070?ooo`009`3oool010000000oooo
0?ooo`0000080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`08
0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`03
0000003oool0oooo00P0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000002
0?ooo`8000004P3oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool2000000`0oooo00@000000?ooo`3oool00000203oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0203oool010000000oooo0?oo
o`0000080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`080?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool2000000L0oooo000X
0?ooo`8000002P3oool2000000<0oooo0`00000<0?ooo`8000002P3oool2000000<0oooo0`00000<
0?ooo`8000002P3oool2000000@0oooo00<000000?ooo`3oool04@3oool2000001D0oooo0P00000:
0?ooo`800000103oool00`000000oooo0?ooo`0;0?ooo`8000002P3oool2000000<0oooo0`00000<
0?ooo`8000002P3oool2000000<0oooo0`00000<0?ooo`8000002P3oool2000000D0oooo00<00000
0?ooo`3oool01@3oool001P0oooo00<000000?ooo`3oool0o`3oool60?ooo`00603oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000H0?ooo`030000003oool0oooo0?l0oooo1P3oool001P0oooo00<0
00000?ooo`3oool0o`3oool60?ooo`004P3oool6000005/0o`000`0000040?l000@000000`3o0006
000000030?l000000000000000d0000000<0o`00000000000000100000030?l000@000000`3o0003
000005l0o`001P00000@0?ooo`005@3oool010000000oooo0?ooo`0000030?ooo`060000003oool0
oooo0?ooo`000000oooo0P0000050?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0
oooo0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool2000000D0oooo00@000000?oo
o`3oool0oooo0`3o00040?ooo`040?l0003oool000000?l00080oooo00<0o`000?ooo`000000103o
ool00`3o000000000?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?l0003o0000103o
ool00`000000o`000?l000020?ooo`040?l000000000oooo0?l000<0oooo0`3o00040?ooo`030000
003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`000000
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000000`3oool0
00000?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`80
00003P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0000000P0oooo00<000000?ooo`00
00001@3oool20?l000<0oooo00<0o`000?ooo`3oool00`3oool20?l000h0oooo0P3o00050?ooo`04
0?l0003oool0oooo0?ooo`<0o`001@3oool00`000000oooo000000080?ooo`030000003oool00000
03<0oooo0P00000>0?ooo`8000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01@0oooo000H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0000003<0oooo00<000000?ooo`3oool00P0000060?ooo`03
0000003oool0000000/0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0o`0000h0oooo00<0o`00
0?ooo`3o0000103oool00`3o0000oooo0?ooo`080?ooo`040000003oool0oooo000000H0oooo0P00
00020?ooo`030000003oool0oooo0300oooo00<000000?ooo`0000003P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool001P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00@00000
0?ooo`3oool00000<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`060?l0003oool0oooo0?l0003oool0o`003P3oool00`3o
0000oooo0?l000030?ooo`030?l0003oool0oooo00T0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`800000103oool00`000000oooo0?ooo`0_0?ooo`050000003oool0oooo0?ooo`0000003@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503o
ool001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`80000000<0oooo
0000003oool0103oool00`000000oooo0?ooo`090?ooo`80o`000`3oool00`3o0000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00<0o`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00X0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`00603oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo0P00000:0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool01P3oool2000000D0oooo00<000000?ooo`3oool02@3oool20?l000<0oooo00<0o`00
0?ooo`3oool02`3oool0103o0000oooo0?ooo`3oool20?l000/0oooo00<000000?ooo`3oool00`3o
ool2000000P0oooo00<000000?ooo`3oool05@3oool2000000X0oooo0P00000:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool05@3oool001P0oooo0P0000040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00P0oooo0P00000:0?ooo`8000005P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00@0oooo1P0000030?ooo`030?l0003oool0oooo00/0oooo00@0o`000?ooo`3oool0oooo1P00
00060?ooo`030000003oool0oooo00l0oooo0P00000E0?ooo`8000002P3oool2000000X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`00603oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00P0oooo0P00000:0?ooo`8000005@3oool00`000000oooo0?ooo`0@
0?ooo`800000103oool2000000@0oooo00D000000?ooo`3oool0oooo0?l0000=0?ooo`050?l0003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`8000004P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0000000X0oooo0P0000090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool05@3oool001P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`8000002@3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo0180oooo
00@000000?ooo`3oool000001`3oool010000000oooo0?ooo`3o000=0?ooo`040?l0003oool0oooo
000000H0oooo00<000000?ooo`3oool00P00000D0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`0000002P3oool00`000000oooo000000080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05@3oool001P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0000000T0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`0C
0?ooo`8000002@3oool00`000000oooo0?l000020?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool0o`000P3oool00`000000oooo0?ooo`050?ooo`8000005P3oool00`000000oooo0?oo
o`0A0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`000000203oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01D0oooo000H0?ooo`050000003oool0oooo0?ooo`000000
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo000000090?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0o`0000<000001P3oool3000000040?ooo`3o0000oooo0000
0200oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`00603oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000002@3oool010000000oooo0?ooo`3o
ool200000140oooo00<000000?ooo`3oool07`3oool2000000050?l0003oool0oooo0?ooo`000000
103oool200000080oooo00@000000?l0003oool00000803oool00`000000oooo0?ooo`0@0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool00`000000oooo000000070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool05@3oool001P0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0000000T0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0`0000090?oo
o`030000003oool0oooo0200oooo00<000000?l0003oool00`3oool2000000030?ooo`000000oooo
00@0oooo00<0o`000000003oool0803oool00`000000oooo0?ooo`080?ooo`8000001@3oool20000
00@0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool05P3oool001P0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P00
00000`3oool000000?ooo`080?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool01`3o
ool010000000oooo0000000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0F0?ooo`00603oool2000000030?ooo`000000oooo00X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000080?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0240
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03000000L0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000H
0?ooo`00603oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000203o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3o
ool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0240oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000603oool001P0oooo00<000000?ooo`000000
303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000H0?ooo`00603oool00`000000oooo0000000=0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0280
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000001P0oooo000H0?oo
o`030000003oool0000000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0000000800000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030?l0003oool0oooo
00X0oooo00<0o`000?ooo`3oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo0000
003oool0303oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`0000006@3oool0
01P0oooo0P00000?0?ooo`050000003oool0oooo0?ooo`0000003@3oool2000000L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool08P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0280oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool2000000d0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`8000006@3o
ool001P0oooo0P00000?0?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0R0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool08`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0E0?ooo`050000003oool0oooo0?ooo`0000003`3oool2000001T0oooo000H0?ooo`800000403o
ool010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`000000
403oool2000001T0oooo000H0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool00000
5P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0
8`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0F0?ooo`030000003oool000000100oooo00<000000?ooo`3oool0
603oool001P0oooo00<000000?ooo`3oool0403oool2000001L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3o
ool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo02<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0000000[0?ooo`00603oool00`000000oooo0?ooo`0@0?ooo`8000005`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0903oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0F0?ooo`800000;03oool001P0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0:`3oool000D0
oooo0P0000040?ooo`040000003oool0oooo0?ooo`D00000103oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0T0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo04@0oooo00040?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00<0o`00
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0T0?ooo`040000003oool0oooo0?ooo`800000403o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00040?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000W0?ooo`030?l0
003oool0oooo00T0oooo00<0o`000?ooo`3oool0903oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`150?ooo`00103oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo0`00000Z0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000W0?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool09@3oool3000001<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`150?ooo`00103oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool04P3oool2000002L0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0U0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`150?oo
o`00103oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A@3oool0
00D0oooo0P0000090?ooo`<000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo
03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`150?ooo`00603oool00`000000
oooo0?ooo`0[0?ooo`050000003oool0oooo0?ooo`000000?P3oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`150?oo
o`00603oool00`000000oooo0?ooo`0[0?ooo`8000000P3oool00`000000oooo0?ooo`0l0?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0?03oool010000000oooo0?ooo`3oool20000
04L0oooo000H0?ooo`030000003oool0oooo02`0oooo00@000000?ooo`3oool00000?P3oool00`3o
0000oooo0?ooo`080?ooo`030?l0003oool0oooo03`0oooo00<000000?ooo`3oool00P0000180?oo
o`00603oool2000002h0oooo00<000000?ooo`000000?P3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo03d0oooo00<000000?ooo`000000B@3oool001P0oooo00<000000?ooo`3oool0
;P3oool2000003h0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0m0?ooo`800000
BP3oool001P0oooo00<000000?ooo`3oool0;P3oool2000003l0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0m0?ooo`030000003oool0oooo04T0oooo000H0?ooo`030000003oool0
oooo06l0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`290?ooo`00603oool00`00
0000oooo0?ooo`1_0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0R@3oool001P0
oooo00<000000?ooo`3oool0K`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo08T0
oooo000H0?ooo`030000003oool0oooo06l0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`290?ooo`00603oool00`000000oooo0?ooo`1_0?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool0R@3oool001P0oooo0P00001`0?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool0R@3oool001P0oooo00<000000?ooo`3oool0K`3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo08T0oooo000H0?ooo`030000003oool0oooo06l0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`290?ooo`00603oool00`000000oooo0?ooo`1_0?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool0R@3oool001P0oooo00<000000?ooo`3oool0K`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo08T0oooo000H0?ooo`030000003oool0
oooo06l0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`290?ooo`00603oool00`00
0000oooo0?ooo`1_0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0R@3oool001P0
oooo0P00001`0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0R@3oool001P0oooo
00<000000?ooo`3oool0K`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo08T0oooo
000H0?ooo`030000003oool0oooo0700oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`290?ooo`00603oool00`000000oooo0?ooo`1`0?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool0R@3oool001P0oooo00<000000?ooo`3oool0L03oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo08T0oooo00050?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<0
0000103oool00`000000oooo0?ooo`1`0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool0R@3oool000@0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0700oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`2:0?ooo`00
103oool010000000oooo0?ooo`0000070?ooo`D00000103oool300000700oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`2:0?ooo`00103oool010000000oooo0?ooo`0000070?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0L03oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo08X0oooo00040?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`1`0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool0RP3oool000@0oooo00@000000?ooo`3oool000002@3oool2000000D0oooo00<000000?oo
o`3oool0L03oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo08X0oooo00050?ooo`80
00002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0700oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`2:0?ooo`00603oool00`000000oooo0?ooo`1`0?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool0RP3oool001P0oooo00<000000?ooo`3oool0L03o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo08X0oooo000H0?ooo`030000003oool0
oooo0700oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`2:0?ooo`00603oool20000
0740oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`2:0?ooo`00603oool00`000000
oooo0?ooo`1`0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0RP3oool001P0oooo
00<000000?ooo`3oool0L03oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo08X0oooo
000H0?ooo`030000003oool0oooo0740oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`2:0?ooo`00603oool00`000000oooo0?ooo`1a0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0RP3oool001P0oooo00<000000?ooo`3oool0L@3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo08X0oooo000H0?ooo`030000003oool0oooo0740oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`2:0?ooo`00603oool200000780oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`2:0?ooo`00603oool00`000000oooo0?ooo`1a0?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool0RP3oool001P0oooo00<000000?ooo`3oool0L@3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo08/0oooo000H0?ooo`030000003oool0oooo
0740oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`2;0?ooo`00603oool00`000000
oooo0?ooo`1a0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0R`3oool001P0oooo
00<000000?ooo`3oool0L@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo08/0oooo
000H0?ooo`030000003oool0oooo0740oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`2;0?ooo`00603oool00`000000oooo0?ooo`1a0?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool0R`3oool001P0oooo0P00001b0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool0R`3oool001P0oooo00<000000?ooo`3oool0L@3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo08/0oooo000H0?ooo`030000003oool0oooo0740oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`2;0?ooo`00603oool00`000000oooo0?ooo`1a0?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool0R`3oool001P0oooo00<000000?ooo`3oool0L@3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo08/0oooo00050?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`1a0?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0R`3oool000@0oooo00@000000?ooo`3oool000001`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0L@3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo08/0oooo00040?ooo`040000003oool0oooo000000L0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`<00000L@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo08/0oooo00040?ooo`040000003oool0oooo000000L0oooo100000050?ooo`030000003o
ool0oooo0780oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`2;0?ooo`00103oool0
10000000oooo0?ooo`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0LP3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo08/0oooo00040?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1b0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool0R`3oool000D0oooo0P00000:0?ooo`8000001@3oool0
0`000000oooo0?ooo`1b0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0R`3oool0
01P0oooo00<000000?ooo`3oool0LP3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
08/0oooo000H0?ooo`030000003oool0oooo0780oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`2;0?ooo`00603oool00`000000oooo0?ooo`1b0?ooo`050?l0003oool0oooo0?ooo`3o
0000SP3oool001P0oooo0P00001c0?ooo`050?l0003oool0oooo0?ooo`3o0000SP3oool001P0oooo
00<000000?ooo`3oool0LP3oool01@3o0000oooo0?ooo`3oool0o`0008h0oooo000H0?ooo`030000
003oool0oooo0780oooo00D0o`000?ooo`3oool0oooo0?l0002>0?ooo`00603oool00`000000oooo
0?ooo`1b0?ooo`050?l0003oool0oooo0?ooo`3o0000SP3oool001P0oooo00<000000?ooo`3oool0
LP3oool01@3o0000oooo0?ooo`3oool0o`0008h0oooo000H0?ooo`030000003oool0oooo0780oooo
00D0o`000?ooo`3oool0oooo0?l0002>0?ooo`00603oool00`000000oooo0?ooo`1b0?ooo`050?l0
003oool0oooo0?ooo`3o0000SP3oool001P0oooo0P00001c0?ooo`050?l0003oool0oooo0?ooo`3o
0000SP3oool001P0oooo00<000000?ooo`3oool0LP3oool01@3o0000oooo0?ooo`3oool0o`0008h0
oooo000H0?ooo`030000003oool0oooo0780oooo00D0o`000?ooo`3oool0oooo0?l0002>0?ooo`00
603oool00`000000oooo0?ooo`1b0?ooo`050?l0003oool0oooo0?ooo`3o0000SP3oool001P0oooo
00<000000?ooo`3oool0LP3oool01@3o0000oooo0?ooo`3oool0o`0008h0oooo000H0?ooo`030000
003oool0oooo0780oooo00D0o`000?ooo`3oool0oooo0?l0002>0?ooo`00603oool00`000000oooo
0?ooo`1b0?ooo`050?l0003oool0oooo0?ooo`3o0000SP3oool001P0oooo00<000000?ooo`3oool0
LP3oool01@3o0000oooo0?ooo`3oool0o`0008h0oooo000H0?ooo`800000L`3oool01@3o0000oooo
0?ooo`3oool0o`0008h0oooo000H0?ooo`030000003oool0oooo0780oooo00D0o`000?ooo`3oool0
oooo0?l0002>0?ooo`00603oool00`000000oooo0?ooo`1c0?ooo`040?l0003oool0oooo0?l008h0
oooo000H0?ooo`030000003oool0oooo07<0oooo00@0o`000?ooo`3oool0o`00SP3oool001P0oooo
00<000000?ooo`3oool0L`3oool0103o0000oooo0?ooo`3o002>0?ooo`001@3oool2000000@0oooo
00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0L`3oool0103o0000oooo
0?ooo`3o002>0?ooo`00103oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`1c0?ooo`040?l0003oool0oooo0?l008h0oooo00040?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`<00000L`3o
ool00`3o0000oooo0?l0002?0?ooo`00103oool010000000oooo0?ooo`0000080?ooo`<000001@3o
ool00`000000oooo0?ooo`1c0?ooo`030?l0003oool0o`0008l0oooo00040?ooo`040000003oool0
oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo07<0oooo
00<0o`000?ooo`3o0000S`3oool000@0oooo00@000000?ooo`3oool000001`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0L`3oool00`3o0000oooo0?l0002?0?ooo`00
1@3oool2000000T0oooo0`0000050?ooo`030000003oool0oooo07<0oooo00<0o`000?ooo`3o0000
S`3oool001P0oooo00<000000?ooo`3oool0L`3oool00`3o0000oooo0?l0002?0?ooo`00603oool0
0`000000oooo0?ooo`1c0?ooo`030?l0003oool0o`0008l0oooo000H0?ooo`030000003oool0oooo
07<0oooo00<0o`000?ooo`3o0000S`3oool001P0oooo0P00001d0?ooo`030?l0003oool0o`0008l0
oooo000H0?ooo`030000003oool0oooo07<0oooo00<0o`000?ooo`3o0000S`3oool001P0oooo00<0
00000?ooo`3oool0L`3oool00`3o0000oooo0?l0002?0?ooo`00603oool00`000000oooo0?ooo`1c
0?ooo`030?l0003oool0o`0008l0oooo000H0?ooo`030000003oool0oooo07<0oooo00<0o`000?oo
o`3o0000S`3oool001P0oooo00<000000?ooo`3oool0L`3oool00`3o0000oooo0?l0002?0?ooo`00
603oool00`000000oooo0?ooo`1c0?ooo`030?l0003oool0o`0008l0oooo000H0?ooo`800000M03o
ool00`3o0000oooo0?l0002?0?ooo`00603oool00`000000oooo0?ooo`1c0?ooo`030?l0003oool0
o`0008l0oooo000H0?ooo`030000003oool0oooo07<0oooo0P3o002@0?ooo`00603oool00`000000
oooo0?ooo`1c0?ooo`80o`00T03oool001P0oooo00<000000?ooo`3oool0L`3oool20?l00900oooo
000H0?ooo`030000003oool0oooo07@0oooo00<0o`000?ooo`3oool0SP3oool001P0oooo00<00000
0?ooo`3oool0M03oool00`3o0000oooo0?ooo`2>0?ooo`00603oool00`000000oooo0?ooo`1d0?oo
o`030?l0003oool0oooo08h0oooo000H0?ooo`800000M@3oool00`3o0000oooo0?ooo`2>0?ooo`00
603oool00`000000oooo0?ooo`1d0?ooo`030?l0003oool0oooo08h0oooo000H0?ooo`030000003o
ool0oooo07@0oooo00<0o`000?ooo`3oool0SP3oool001P0oooo00<000000?ooo`3oool0M03oool0
0`3o0000oooo0?ooo`2>0?ooo`00603oool00`000000oooo0?ooo`1d0?ooo`030?l0003oool0oooo
08h0oooo000@0?ooo`<000001@3oool00`000000oooo0?ooo`1d0?ooo`030?l0003oool0oooo08h0
oooo000A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0M03oool00`3o0000oooo
0?ooo`2>0?ooo`004@3oool00`000000oooo0?ooo`040?ooo`<00000M03oool00`3o0000oooo0?oo
o`2>0?ooo`004@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo1P3oool0
0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`H0oooo000@0?ooo`80
00001P3oool00`000000oooo0?ooo`3o0?ooo`H0oooo000A0?ooo`030000003oool0oooo0?l0oooo
3@3oool00?l0oooo8@3oool00?l0oooo8@3oool005h0oooo0`00001A0?ooo`<00000J`3oool005l0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1Z0?ooo`00=03oool3000000@0oooo
0`0000020?ooo`D0000000D0oooo00000000000000000?ooo`0200000080oooo0P0000090?ooo`<0
00000`3oool300000080oooo0`0000040?ooo`<000000`3oool400000080oooo100000070?ooo`D0
000000D0oooo00000000000000000?ooo`0200000080oooo0P0000030?ooo`<000000P3oool30000
00030?ooo`000000000000@000000P3oool5000000<0oooo0P0000040?ooo`030000003oool0oooo
00L0oooo0`0000050?ooo`80000000<0oooo0000000000000P000000103oool000000000003oool3
000000@0oooo0P0000020?ooo`D000000P3oool300000080oooo0`0000000`3oool000000000000b
0?ooo`00=@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00H000000?ooo`3oool000000?ooo`0000060?ooo`040000003oool0oooo000000D0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000c0?oo
o`00=@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0303oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo1@0000020?ooo`<00000
0P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`020?ooo`D000000P3oool010000000oooo0?ooo`000002
0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00H0
00000?ooo`3oool000000?ooo`0000060?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0<@3oool0
03D0oooo0`0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool2000000<0oooo00@0
00000?ooo`3oool000000P3oool2000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000000L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000T0oooo0`0000030?oo
o`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000
003oool0oooo000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0<@3oool003D0oooo00@000000?ooo`3oool000000P3oool3
00000080oooo0`0000030?ooo`@000000P3oool4000000T0oooo00<000000?ooo`3oool00P3oool4
00000080oooo0P0000000`3oool00000000000020?ooo`<000000`3oool2000000@0oooo0`00000:
0?ooo`040000003oool0oooo0?ooo`@000000P3oool4000000<0oooo0`0000020?ooo`@000000`3o
ool4000000040?ooo`0000000000000000<0oooo100000020?ooo`80000000<0oooo000000000000
203oool00`000000oooo0?ooo`020?ooo`80000000@0oooo000000000000oooo100000030?ooo`<0
00000P3oool400000080oooo0`0000040?ooo`<000000P3oool4000003@0oooo000e0?ooo`040000
003oool0oooo000001@0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000L0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00l0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`16
0?ooo`00=03oool4000000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?oo
o`<000006`3oool2000000P0oooo1@0000080?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`D00000503oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0448358, -0.0814246, \
0.000312684, 0.00669526}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00223485 0.0280925 0.561849 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2473 -0.0125 -9 -9 ]
[.2473 -0.0125 9 0 ]
[.47078 -0.0125 -9 -9 ]
[.47078 -0.0125 9 0 ]
[.69427 -0.0125 -9 -9 ]
[.69427 -0.0125 9 0 ]
[.91775 -0.0125 -9 -9 ]
[.91775 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .14046 -18 -4.5 ]
[-0.0125 .14046 0 4.5 ]
[-0.0125 .25283 -18 -4.5 ]
[-0.0125 .25283 0 4.5 ]
[-0.0125 .3652 -18 -4.5 ]
[-0.0125 .3652 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -84 0 ]
[.5 .63053 84 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2473 0 m
.2473 .00625 L
s
[(100)] .2473 -0.0125 0 1 Mshowa
.47078 0 m
.47078 .00625 L
s
[(200)] .47078 -0.0125 0 1 Mshowa
.69427 0 m
.69427 .00625 L
s
[(300)] .69427 -0.0125 0 1 Mshowa
.91775 0 m
.91775 .00625 L
s
[(400)] .91775 -0.0125 0 1 Mshowa
.125 Mabswid
.06851 0 m
.06851 .00375 L
s
.1132 0 m
.1132 .00375 L
s
.1579 0 m
.1579 .00375 L
s
.2026 0 m
.2026 .00375 L
s
.29199 0 m
.29199 .00375 L
s
.33669 0 m
.33669 .00375 L
s
.38139 0 m
.38139 .00375 L
s
.42608 0 m
.42608 .00375 L
s
.51548 0 m
.51548 .00375 L
s
.56017 0 m
.56017 .00375 L
s
.60487 0 m
.60487 .00375 L
s
.64957 0 m
.64957 .00375 L
s
.73896 0 m
.73896 .00375 L
s
.78366 0 m
.78366 .00375 L
s
.82836 0 m
.82836 .00375 L
s
.87305 0 m
.87305 .00375 L
s
.96245 0 m
.96245 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .14046 m
.00625 .14046 L
s
[(0.2)] -0.0125 .14046 1 0 Mshowa
0 .25283 m
.00625 .25283 L
s
[(0.4)] -0.0125 .25283 1 0 Mshowa
0 .3652 m
.00625 .3652 L
s
[(0.6)] -0.0125 .3652 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(0.8)] -0.0125 .47757 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(1)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2473 .61178 m
.2473 .61803 L
s
.47078 .61178 m
.47078 .61803 L
s
.69427 .61178 m
.69427 .61803 L
s
.91775 .61178 m
.91775 .61803 L
s
.125 Mabswid
.06851 .61428 m
.06851 .61803 L
s
.1132 .61428 m
.1132 .61803 L
s
.1579 .61428 m
.1579 .61803 L
s
.2026 .61428 m
.2026 .61803 L
s
.29199 .61428 m
.29199 .61803 L
s
.33669 .61428 m
.33669 .61803 L
s
.38139 .61428 m
.38139 .61803 L
s
.42608 .61428 m
.42608 .61803 L
s
.51548 .61428 m
.51548 .61803 L
s
.56017 .61428 m
.56017 .61803 L
s
.60487 .61428 m
.60487 .61803 L
s
.64957 .61428 m
.64957 .61803 L
s
.73896 .61428 m
.73896 .61803 L
s
.78366 .61428 m
.78366 .61803 L
s
.82836 .61428 m
.82836 .61803 L
s
.87305 .61428 m
.87305 .61803 L
s
.96245 .61428 m
.96245 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .14046 m
1 .14046 L
s
.99375 .25283 m
1 .25283 L
s
.99375 .3652 m
1 .3652 L
s
.99375 .47757 m
1 .47757 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(Modulation Transfer Function)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .58994 m
.03853 .38125 L
.04619 .22769 L
.05024 .14512 L
.05131 .12335 L
.05247 .09971 L
.053 .08888 L
.05357 .07739 L
.05405 .06772 L
.05432 .06935 L
.05458 .07088 L
.05867 .09522 L
.06238 .11737 L
.06586 .13808 L
.0677 .14902 L
.06823 .15217 L
.06872 .15514 L
.06917 .15768 L
.06965 .15441 L
.0717 .14054 L
.07361 .12766 L
.07737 .10224 L
.08102 .07756 L
.0828 .06551 L
.08358 .06024 L
.08399 .05747 L
.08442 .05616 L
.08489 .05824 L
.08532 .06017 L
.08617 .06398 L
.08805 .07236 L
.09202 .09014 L
.09588 .10741 L
.09694 .11215 L
.09805 .11713 L
.09851 .11919 L
.099 .12138 L
.09929 .12265 L
.09954 .12225 L
.10004 .11926 L
.10746 .07507 L
.11084 .05491 L
.11269 .04389 L
.1136 .0385 L
.11399 .03614 L
.11443 .03358 L
.11487 .0347 L
.1153 .03662 L
.11624 .04087 L
.11823 .04988 L
Mistroke
.12173 .06576 L
.12589 .08458 L
.12785 .09346 L
.12871 .09736 L
.1292 .09956 L
.12966 .10138 L
.13009 .09957 L
.13056 .09762 L
.13152 .09365 L
.13353 .0853 L
.13717 .07017 L
.14132 .05289 L
.14315 .0453 L
.14365 .04322 L
.14419 .04098 L
.14443 .03995 L
.1447 .03886 L
.14516 .04001 L
.14705 .0462 L
.14905 .05276 L
.15327 .06662 L
.15698 .0788 L
.15805 .0823 L
.15905 .08561 L
.15949 .08705 L
.15996 .08799 L
.1602 .08726 L
.16047 .08646 L
.16094 .08505 L
.16847 .06243 L
.17207 .05164 L
.17292 .04906 L
.17384 .04633 L
.17421 .0452 L
.17461 .04399 L
.17506 .04308 L
.17547 .0441 L
.17733 .04865 L
.17936 .05361 L
.1829 .06228 L
.1867 .07159 L
.18871 .07651 L
.18929 .07793 L
.18958 .07863 L
.18984 .07927 L
.19033 .0797 L
.19059 .07947 L
.19086 .07923 L
.19481 .07571 L
.19849 .07243 L
Mistroke
.20652 .06514 L
.22094 .05084 L
.22506 .04659 L
.22896 .04255 L
.23247 .03892 L
.23343 .03793 L
.23446 .03687 L
.23495 .03636 L
.23542 .03587 L
.23584 .03682 L
.2363 .03795 L
.24335 .05544 L
.24734 .06536 L
.24835 .06785 L
.2493 .07021 L
.25015 .07233 L
.25063 .0733 L
.25108 .07289 L
.25475 .06947 L
.25868 .06581 L
.2667 .05816 L
.27443 .04961 L
.28167 .04189 L
.2886 .03659 L
.29246 .03364 L
.29435 .03219 L
.29517 .03157 L
.29563 .03121 L
.29606 .03116 L
.2965 .0317 L
.29697 .03226 L
.29782 .0333 L
.29971 .03557 L
.3037 .04039 L
.30758 .04507 L
.3086 .0463 L
.30971 .04765 L
.31022 .04826 L
.3105 .0486 L
.31076 .04892 L
.31101 .04922 L
.31128 .04907 L
.31174 .04874 L
.31564 .04594 L
.3192 .04339 L
.32281 .04079 L
.32458 .03953 L
.32535 .03898 L
.32575 .03869 L
.32618 .03841 L
Mistroke
.32665 .03863 L
.32708 .03883 L
.32794 .03922 L
.32981 .0401 L
.3338 .04195 L
.33766 .04374 L
.3398 .04473 L
.34031 .04497 L
.34085 .04522 L
.34111 .04535 L
.34136 .04542 L
.34183 .04543 L
.34368 .04546 L
.34571 .0455 L
.34927 .04557 L
.35259 .04563 L
.35435 .04567 L
.35532 .04568 L
.3558 .04569 L
.35624 .0457 L
.35672 .04536 L
.35697 .0451 L
.35724 .04482 L
.35816 .04387 L
.35995 .04201 L
.36388 .03794 L
.36755 .03414 L
.36916 .03248 L
.37007 .03154 L
.37051 .03108 L
.37092 .03066 L
.37135 .03021 L
.37176 .03021 L
.37219 .03047 L
.37266 .03075 L
.37449 .03186 L
.37833 .03419 L
.38193 .03637 L
.38529 .03841 L
.38572 .03867 L
.38619 .03895 L
.38662 .03921 L
.38703 .03929 L
.38801 .03946 L
.3889 .03962 L
.39286 .04034 L
.39699 .04108 L
.39902 .04145 L
.3999 .04161 L
.40037 .04169 L
Mistroke
.40088 .04178 L
.40137 .04187 L
.40183 .04204 L
.40228 .04258 L
.40271 .04309 L
.40464 .04538 L
.40871 .05021 L
.4158 .05863 L
.41948 .06174 L
.4234 .0645 L
.42706 .06709 L
.42866 .06822 L
.42957 .06886 L
.43042 .06946 L
.43126 .07006 L
.43173 .07039 L
.43216 .0703 L
.43261 .06967 L
.4331 .06898 L
.43399 .06774 L
.43785 .06236 L
.44145 .05733 L
.44481 .05263 L
.44571 .05138 L
.44656 .0502 L
.44702 .04955 L
.44729 .04969 L
.44753 .04998 L
.44843 .05105 L
.4524 .05578 L
.45653 .06071 L
.45856 .06313 L
.46042 .06535 L
.46128 .06637 L
.4617 .06687 L
.46208 .06733 L
.46248 .06745 L
.46291 .0674 L
.46383 .0673 L
.46751 .06689 L
.47159 .06644 L
.47338 .06624 L
.47536 .06602 L
.47624 .06593 L
.47672 .06587 L
.47719 .06582 L
.47761 .06556 L
.47808 .06517 L
.4789 .06448 L
.48265 .06131 L
Mistroke
.48681 .05781 L
.49057 .05463 L
.49443 .05209 L
.49807 .05032 L
.50195 .04843 L
.50408 .0474 L
.50606 .04644 L
.50696 .046 L
.50741 .04578 L
.50782 .04569 L
.50829 .04564 L
.50881 .04559 L
.50971 .0455 L
.51371 .04512 L
.5171 .04479 L
.52075 .04444 L
.52168 .04435 L
.52219 .0443 L
.52266 .04425 L
.52307 .04414 L
.5235 .04402 L
.52442 .04375 L
.52786 .04276 L
.53194 .04159 L
.53571 .04051 L
.53669 .04023 L
.53717 .04009 L
.53761 .03996 L
.53807 .04001 L
.53856 .0402 L
.53961 .04059 L
.54384 .04219 L
.54783 .04368 L
.54977 .04441 L
.55152 .04507 L
.55239 .0454 L
.55288 .04559 L
.55333 .0455 L
.55503 .04512 L
.55877 .04428 L
.56286 .04337 L
.56485 .04292 L
.56572 .04272 L
.56667 .04251 L
.56712 .04241 L
.5676 .0423 L
.56801 .04221 L
.56845 .04193 L
.57014 .04084 L
.57386 .03842 L
Mistroke
.57797 .03575 L
.57992 .03449 L
.5808 .03392 L
.58174 .03331 L
.58222 .03299 L
.58269 .0327 L
.5831 .03243 L
.58355 .03254 L
.58552 .03326 L
.58912 .03456 L
.59291 .03593 L
.59492 .03665 L
.59603 .03705 L
.59707 .03743 L
.59755 .0376 L
.59806 .03778 L
.59832 .03785 L
.59861 .03782 L
.59913 .03778 L
.601 .0376 L
.60466 .03726 L
.60885 .03687 L
.61068 .0367 L
.61165 .03661 L
.61218 .03656 L
.61269 .03651 L
.61315 .03646 L
.61342 .03648 L
.61366 .03669 L
.61454 .03746 L
.61627 .03898 L
.62005 .0423 L
.62415 .04589 L
.62616 .04765 L
.62703 .04842 L
.6275 .04883 L
.62799 .04926 L
.62847 .04969 L
.62891 .04979 L
.62976 .04996 L
.63143 .05029 L
.63513 .05103 L
.63923 .05184 L
.64102 .0522 L
.64197 .05239 L
.6425 .05249 L
.64299 .05259 L
.64346 .05268 L
.64396 .05262 L
.64442 .0525 L
Mistroke
.64484 .05239 L
.64656 .05193 L
.65033 .05094 L
.65443 .04985 L
.65643 .04932 L
.65731 .04909 L
.65777 .04896 L
.65827 .04883 L
.65872 .04871 L
.65913 .04839 L
.65994 .04776 L
.66169 .04637 L
.66538 .04345 L
.66947 .04021 L
.67126 .03879 L
.67222 .03804 L
.67274 .03763 L
.67324 .03723 L
.6737 .03687 L
.6742 .03683 L
.67465 .03693 L
.67507 .03702 L
.67679 .0374 L
.68055 .03823 L
.68464 .03913 L
.68664 .03958 L
.68752 .03977 L
.68798 .03987 L
.68848 .03998 L
.68898 .04008 L
.68943 .03986 L
.69031 .03941 L
.69225 .03843 L
.69632 .03638 L
.69976 .03464 L
.70165 .03369 L
.70257 .03323 L
.70341 .0328 L
.70386 .03258 L
.70428 .03274 L
.70473 .03335 L
.70522 .03401 L
.70721 .03671 L
.71071 .04146 L
.71486 .0471 L
.71682 .04977 L
.71862 .05222 L
.71909 .05285 L
.71953 .05322 L
.71998 .05353 L
Mistroke
.72048 .05387 L
.72248 .05523 L
.72612 .0577 L
.73022 .06049 L
.73224 .06186 L
.73313 .06246 L
.7336 .06278 L
.73385 .06295 L
.73411 .06313 L
.73459 .06283 L
.73503 .06212 L
.73591 .06072 L
.73782 .05766 L
.74186 .05119 L
.74556 .04526 L
.74718 .04267 L
.74803 .04131 L
.74893 .03987 L
.74939 .03913 L
.74965 .03907 L
.7499 .03908 L
.7508 .03911 L
.75256 .03919 L
.75645 .03935 L
.75979 .03948 L
.76156 .03956 L
.76344 .03963 L
.764 .03966 L
.76427 .03967 L
.76452 .03968 L
.76499 .03948 L
.7655 .03925 L
.76741 .03839 L
.77117 .03669 L
.77458 .03515 L
.77646 .0343 L
.77823 .0335 L
.77916 .03307 L
.77942 .03296 L
.77969 .03288 L
.78018 .0335 L
.78195 .03576 L
.78542 .04018 L
.78921 .04501 L
.7912 .04755 L
.79329 .05022 L
.79419 .05137 L
.79469 .052 L
.79515 .05189 L
.7954 .05172 L
Mistroke
.79569 .05154 L
.7962 .0512 L
.79717 .05056 L
.80072 .04824 L
.80432 .04588 L
.80769 .04367 L
.80859 .04309 L
.80943 .04253 L
.8099 .04223 L
.81017 .04219 L
.81041 .04215 L
.81131 .04202 L
.81528 .04142 L
.81941 .0408 L
.82144 .04049 L
.8233 .04021 L
.82416 .04008 L
.82458 .04002 L
.82496 .03996 L
.82536 .04004 L
.8258 .04015 L
.82671 .04038 L
.8304 .04132 L
.83448 .04235 L
.83627 .0428 L
.83824 .0433 L
.83912 .04353 L
.83961 .04365 L
.84007 .04377 L
.8405 .04344 L
.84097 .043 L
.84179 .04223 L
.84554 .03871 L
.84969 .03481 L
.85346 .03127 L
.85436 .03042 L
.85485 .02996 L
.85531 .0296 L
.85581 .0297 L
.85636 .02981 L
.85732 .03001 L
.86096 .03076 L
.86506 .03161 L
.86895 .03241 L
.87267 .03297 L
.87671 .03344 L
.88035 .03385 L
.88378 .03425 L
.88462 .03434 L
.88508 .0344 L
Mistroke
.8855 .03444 L
.88596 .03436 L
.88647 .03427 L
.88736 .03411 L
.89131 .03339 L
.89543 .03265 L
.89745 .03229 L
.89834 .03213 L
.89932 .03195 L
.89977 .03187 L
.90026 .03178 L
.90072 .03178 L
.90114 .03201 L
.90306 .03307 L
.90712 .03529 L
.91055 .03717 L
.9142 .03918 L
.91469 .03945 L
.91522 .03974 L
.91572 .04001 L
.91617 .04002 L
.91659 .04002 L
.91704 .04002 L
.91796 .04003 L
.92145 .04005 L
.92559 .04008 L
.92754 .04009 L
.92935 .0401 L
.93024 .04011 L
.93069 .04011 L
.93119 .03987 L
.93168 .03951 L
.93222 .03913 L
.93318 .03844 L
.9368 .03585 L
.94094 .03289 L
.94295 .03145 L
.94478 .03014 L
.94524 .02981 L
.94574 .02946 L
.94621 .02937 L
.94664 .0295 L
.94862 .03008 L
.95282 .0313 L
.95678 .03246 L
.95871 .03302 L
.95963 .03329 L
.96048 .03353 L
.96089 .03365 L
.96133 .03367 L
Mistroke
.96176 .0336 L
.96225 .03352 L
.96393 .03325 L
.96764 .03265 L
.97551 .03138 L
.97619 .03127 L
Mfstroke
1 0 0 r
.02381 .58994 m
.03097 .58785 L
.03462 .58679 L
.03663 .5862 L
.03762 .58591 L
.03853 .58565 L
.03901 .58547 L
.03925 .58531 L
.03952 .58513 L
.0406 .58442 L
.04249 .58316 L
.04619 .58071 L
.05458 .57514 L
.06993 .56506 L
.0847 .55709 L
.1004 .54855 L
.11553 .53926 L
.13008 .53034 L
.14556 .52167 L
.16047 .51329 L
.17631 .50375 L
.19157 .4946 L
.20626 .48627 L
.22188 .47736 L
.23692 .46836 L
.25139 .45974 L
.26679 .45095 L
.28161 .44247 L
.29737 .43308 L
.31255 .42408 L
.32715 .41572 L
.34268 .40679 L
.35764 .39791 L
.37202 .38938 L
.38734 .38059 L
.40208 .37213 L
.41775 .36283 L
.43284 .35389 L
.44736 .34555 L
.46281 .33667 L
.47769 .32785 L
.4935 .3185 L
.50873 .30975 L
.52338 .30132 L
.53897 .29208 L
.55398 .2832 L
.56841 .27491 L
.58378 .26607 L
.59857 .2573 L
.6143 .24799 L
Mistroke
.62944 .2393 L
.64401 .23093 L
.65952 .22172 L
.67444 .21287 L
.6903 .20379 L
.70559 .195 L
.72029 .18624 L
.73593 .17697 L
.75099 .16837 L
.76548 .16008 L
.7809 .15086 L
.79574 .14202 L
.81152 .13307 L
.82672 .12438 L
.84134 .11557 L
.8569 .10626 L
.87187 .09787 L
.88627 .08976 L
.90161 .08034 L
.91637 .07133 L
.93206 .06286 L
.94718 .05456 L
.96171 .04492 L
.97619 .03531 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[349]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`008`3oool2000002h0oooo0`0000040?ooo`800000103oool2000002L0oooo1@0000030?oo
o`800000103oool2000002T0oooo0`0000040?ooo`800000103oool2000002T0oooo0`0000030?oo
o`800000103oool2000001P0oooo000R0?ooo`040000003oool0oooo000002h0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
02L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000:@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0E0?ooo`008P3oool010000000oooo0?ooo`00000^0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000X0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00000[0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0T0?ooo`D000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000001L0oooo000R0?ooo`040000003oool0oooo000002h0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool09`3o
ool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000V0?ooo`04
0000003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000G0?ooo`008P3oool010000000oooo0?ooo`00000^0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000V0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002/0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000001L0oooo000R0?ooo`040000003oool0oooo000002d0oooo0P0000040?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000009P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000W0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002P0
oooo0P0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000005`3oool0
02<0oooo0P00000_0?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000:03oool30000
00@0oooo0P0000040?ooo`800000:@3oool3000000@0oooo0P0000040?ooo`800000:P3oool00`00
0000oooo0?ooo`020?ooo`800000103oool2000001P0oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo000N0?ooooP000002P3oool001h0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo0?@0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0m03o
ool00`000000oooo0?ooo`080?ooo`005`3oool2000000D0oooo00<000000?ooo`3oool0m03oool0
0`000000oooo0?ooo`080?ooo`005P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0?@0oooo00<000000?ooo`3oool0203oool001H0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`3d0?ooo`030000003oool0oooo00P0oooo000F0?ooo`040000003oool0oooo
000000@0oooo0P0000170?ooo`030000003oool0oooo00l0oooo0P00001f0?ooo`@000004P3oool3
000000@0oooo0P0000040?ooo`8000002P3oool001H0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02T0oooo0`00000@0?ooo`<00000<@3oool4
000001X0oooo0P00000@0?ooo`<00000403oool00`000000oooo0?ooo`020?ooo`X000001`3oool0
10000000oooo0?ooo`3oool4000000030?ooo`3o0000oooo00@0oooo00<000000?ooo`3oool0203o
ool001H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04P3oool2000000`0oooo00@000000?ooo`3oool00000
1@3oool2000000P0oooo00@000000?ooo`3oool0oooo0`00000]0?ooo`040000003oool0oooo0?oo
o`L000003@3oool700000080oooo00<000000?ooo`3oool01`3oool7000000030?ooo`000000oooo
00h0oooo00<000000?ooo`3oool03@3oool2000000<0oooo0P0000080?ooo`030?l0003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool001L0oooo0P0000050?ooo`030000003oool0oooo01T0
oooo0P0000050?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000/0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool5000000@0oooo0P0000070?oo
o`<000007P3oool6000000<0oooo0`00000;0?ooo`030000003oool0oooo00P0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00<0oooo2@00000A0?ooo`D00000203oool00`3o0000oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo01T0oooo0P0000050?ooo`80
00001P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0103oool00`000000oooo000000050?ooo`D000002`3oool00`000000oooo0?ooo`0E0?oo
o`H000001P3oool3000000l0oooo0P0000070?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000009@3oool2
0?l000P0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0603oool00`00
0000oooo000000050?ooo`8000001@3oool3000000X0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`06
0?ooo`8000002`3oool2000001h0oooo100000000`3oool0000000000002000000d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`<00000903oool20?l000X0oooo00<00000
0?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0603oool00`000000oooo000000050?oo
o`030000003oool0000000@0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`050?oo
o`030000003oool0000000P0oooo0P00000S0?ooo`8000004P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool08P3oool20?l000`0oooo00<000000?oo
o`3oool0203oool001h0oooo0P00000C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00001@3oool00`000000oooo000000040?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo03P0oooo00@000000?oo
o`3oool00000<03oool20?l000d0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00030?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool0000002H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0>P3oool3000002h0oooo0P3o000@0?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool2000000@0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
:03oool00`000000oooo000000060?ooo`D00000K03oool20?l00180oooo00<000000?ooo`3oool0
203oool001h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002`3oool20000
02X0oooo0P00001f0?ooo`030?l0003oool0oooo0180oooo00<000000?ooo`3oool0203oool001h0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`000000103oool010000000oooo00000000000<0?ooo`030000003oool0oooo0:00oooo00<0o`00
0?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`2^
0?ooo`030?l0003oool0oooo01@0oooo00<000000?ooo`3oool0203oool001h0oooo0P00000;0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000D0oooo0P00002e0?ooo`80o`005P3oool2000000X0oooo000N0?ooo`03
0000003oool0oooo00X0oooo0P0000050?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000050?ooo`800000/`3oool20?l001T0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool02P3oool2000000D0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool000000;P0oooo0P3o000K0?oo
o`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00X0oooo0P0000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0;D0oooo0P3o000M0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00X0
oooo0P0000040?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000003oool0
oooo0;<0oooo0P3o000O0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo
00X0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P0000060?ooo`030000003oool0oooo
0;80oooo00<0o`000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000
oooo0?ooo`0:0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`800000^@3oool20?l00280
oooo00<000000?ooo`3oool0203oool001h0oooo0P00000;0?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool200000;L0oooo0P3o000S0?ooo`8000002P3oool001h0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo0P00
002e0?ooo`80o`009P3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool200000;<0oooo0P3o000X
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`800000/@3oool20?l002X0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000020?ooo`03
0000003oool0oooo0;D0oooo00<0o`000?ooo`3oool0:P3oool00`000000oooo0?ooo`080?ooo`00
2`3oool2000000@0oooo00@000000?ooo`3oool0oooo1@0000040?ooo`030000003oool0oooo00X0
oooo00H000000?ooo`3oool000000?ooo`00002f0?ooo`030?l0003oool0oooo02/0oooo00<00000
0?ooo`3oool0203oool000X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00X0oooo00H000000?ooo`3oool000000?ooo`00002d0?ooo`80
o`00;P3oool00`000000oooo0?ooo`080?ooo`002P3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00@0oooo0P00000:0?ooo`070000003oool0oooo0?ooo`000000oooo0000002c
0?ooo`030?l0003oool0oooo02d0oooo0P00000:0?ooo`002P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool01`000000oooo0?ooo`3o
ool000000?ooo`000000/@3oool20?l00340oooo00<000000?ooo`3oool0203oool000X0oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`020?ooo`800000[`3oool20?l003<0oooo00<000000?ooo`3o
ool0203oool000X0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0:`0oooo0P3o000e0?ooo`030000003oool0oooo00P0oooo000;0?ooo`8000002@3oool3000000D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:X0
oooo0P3o000g0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2X0?ooo`80o`00>@3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0:`0oooo00<0
o`000?ooo`3oool0>@3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000X0oooo00<00000
0?ooo`3oool0ZP3oool20?l003/0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0:P0oooo0P3o000n0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0YP3oool20?l00400oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2U0?ooo`030?l0
003oool0oooo0400oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`2T0?ooo`030?l0003oool0oooo0440oooo00<000000?ooo`3oool0203o
ool001h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2R0?ooo`80o`00A03oool0
0`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0:40oooo0P3o00160?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000002@3oool00`000000
oooo0?ooo`2O0?ooo`80o`00A`3oool2000000X0oooo000N0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0WP3oool00`3o0000oooo0?ooo`180?ooo`030000003oool0oooo00P0oooo
000N0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0W03oool20?l004/0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2J
0?ooo`80o`00C@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo09P0oooo0P3o001?0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0UP3oool20?l00540oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2D0?ooo`80o`00
D`3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000T0oooo00<000000?ooo`3oool0T`3o
ool00`3o0000oooo0?ooo`1B0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`2B0?ooo`030?l0003oool0oooo05@0oooo00<000000?ooo`3oool0203oool0
01h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2@0?ooo`80o`00E`3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08h0
oooo0P3o001I0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0S03oool20?l005/0oooo00<000000?ooo`3oool0203oool000/0oooo0P00
00040?ooo`030000003oool0oooo00<0oooo0`0000040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0R`3oool00`3o0000oooo0?ooo`1K0?ooo`030000003oool0oooo00P0oooo000:
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo08T0oooo0P3o001N0?ooo`030000003oool0oooo00P0oooo000:
0?ooo`040000003oool0oooo000000L0oooo1@0000040?ooo`8000002@3oool00`000000oooo0?oo
o`270?ooo`80o`00G`3oool2000000X0oooo000:0?ooo`040000003oool0oooo000000L0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08D0oooo
0P3o001R0?ooo`030000003oool0oooo00P0oooo000:0?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08<0oooo
0P3o001T0?ooo`030000003oool0oooo00P0oooo000:0?ooo`040000003oool0oooo000000T0oooo
0P0000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P@3oool20?l006H0oooo
00<000000?ooo`3oool0203oool000/0oooo0P00000;0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`210?ooo`030?l0003oool0oooo06H0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`20
0?ooo`030?l0003oool0oooo06L0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`1n0?ooo`80o`00JP3oool00`000000oooo0?ooo`080?oo
o`007P3oool2000000P0oooo00<000000?ooo`3oool0O@3oool00`3o0000oooo0?ooo`1Y0?ooo`80
00002P3oool001h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1k0?ooo`80o`00
K@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo07T0oooo0P3o001_0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0M`3oool20?l00740oooo00<000000?ooo`3oool0203oool0
01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1e0?ooo`80o`00L`3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07<0
oooo0P3o001e0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0LP3oool00`3o0000oooo0?ooo`1e0?ooo`030000003oool0oooo00P0oooo
000N0?ooo`800000203oool00`000000oooo0?ooo`1`0?ooo`80o`00M`3oool2000000X0oooo000N
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0KP3oool20?l007X0oooo00<00000
0?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1/0?oo
o`80o`00O03oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo06/0oooo00<0o`000?ooo`3oool0O03oool00`000000oooo0?ooo`080?ooo`00
7P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06X0oooo00<0o`000?ooo`3oool0
O@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo06P0oooo0P3o00200?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0IP3oool20?l00880oooo00<000000?ooo`3oool0203oool0
01h0oooo0P0000080?ooo`030000003oool0oooo06@0oooo0P3o00230?ooo`8000002P3oool001h0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1R0?ooo`80o`00QP3oool00`000000
oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0640oooo
0P3o00280?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0H03oool00`3o0000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo000;
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo05h0oooo0P3o002;0?ooo`030000003oool0oooo00P0oooo000:0?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0G03oool20?l008d0oooo00<000000?ooo`3oool0203o
ool000X0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1J0?ooo`80o`00S`3oool00`000000oooo
0?ooo`080?ooo`002P3oool010000000oooo0?ooo`0000070?ooo`@000001@3oool2000000L0oooo
00<000000?ooo`3oool0F@3oool00`3o0000oooo0?ooo`2>0?ooo`8000002P3oool000X0oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0F03oool00`3o0000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo
000:0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo05H0oooo0P3o002C0?ooo`030000003oool0oooo00P0oooo
000;0?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`1E0?ooo`030?l0003oool0oooo09<0oooo00<000000?ooo`3oool0203oool001h0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`80o`00UP3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0540oooo0P3o002H0?oo
o`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0C`3oool20?l009X0oooo00<000000?ooo`3oool0203oool001h0oooo0P0000070?ooo`030000
003oool0oooo04d0oooo0P3o002K0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1;0?ooo`80o`00WP3oool00`000000oooo0?ooo`080?ooo`007P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo04X0oooo00<0o`000?ooo`3oool0WP3oool0
0`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
04P0oooo0P3o002Q0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0AP3oool20?l00:<0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`140?ooo`80o`00Y@3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04<0oooo0P3o
002W0?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000001P3oool00`000000oooo0?ooo`11
0?ooo`80o`00Z03oool2000000X0oooo000N0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0@03oool00`3o0000oooo0?ooo`2Y0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
?@3oool20?l00:d0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo0:d0oooo00<000000?ooo`3oool0203o
ool001h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0j0?ooo`80o`00/03oool0
0`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
03P0oooo0P3o002b0?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000001P3oool00`000000
oooo0?ooo`0f0?ooo`80o`00/`3oool2000000X0oooo000N0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0=03oool20?l00;H0oooo00<000000?ooo`3oool0203oool001h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0b0?ooo`80o`00^03oool00`000000oooo0?oo
o`080?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0300oooo0P3o002j
0?ooo`030000003oool0oooo00P0oooo000;0?ooo`800000103oool00`000000oooo0?ooo`020?oo
o`<000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02l0oooo00<0o`000?oo
o`3oool0^P3oool00`000000oooo0?ooo`080?ooo`002P3oool010000000oooo0?ooo`0000070?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02h0oooo00<0o`000?ooo`3oool0^`3oool00`000000oooo0?ooo`080?ooo`002P3oool01000
0000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool0_03oool00`000000oooo0?oo
o`080?ooo`002P3oool010000000oooo0?ooo`0000080?ooo`<000001@3oool2000000H0oooo00<0
00000?ooo`3oool0:`3oool20?l00;h0oooo0P00000:0?ooo`002P3oool010000000oooo0?ooo`00
00070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02T0oooo0P3o00310?ooo`030000003oool0oooo00P0oooo000:0?ooo`040000003o
ool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0:03oool20?l00<<0oooo00<000000?ooo`3oool0203oool000/0oooo
0P0000090?ooo`<000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo
0P3o00350?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0903oool20?l00<L0oooo00<000000?ooo`3oool0203oool001h0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`80o`00b@3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<0o`000?oo
o`3oool0b@3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000D0oooo00<000000?ooo`3o
ool0803oool00`3o0000oooo0?ooo`390?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0</0oooo00<000000?ooo`3oool0
203oool001h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`80o`00cP3o
ool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01/0oooo0P3o003@0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool06@3oool20?l00=80oooo00<000000?ooo`3oool0203oool001h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`80o`00e03oool00`000000
oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo
0P3o003F0?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000001@3oool00`000000oooo0?oo
o`0C0?ooo`80o`00e`3oool2000000X0oooo000N0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool04@3oool20?l00=X0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo0=X0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`80
o`00g@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00`0oooo0P3o003O0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02`3oool20?l00>40oooo00<000000?ooo`3oool0203o
ool001h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`80o`00h`3oool0
0`000000oooo0?ooo`080?ooo`007P3oool2000000@0oooo00<000000?ooo`3oool01`3oool20?l0
0>@0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<0o`000?ooo`3oool0i@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0iP3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P3o
003Y0?ooo`030000003oool0oooo00P0oooo000F0?ooo`<000001@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0j@3oool00`000000oooo0?ooo`08
0?ooo`005`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3o003/0?ooo`030000003oool0oooo00P0oooo000G0?ooo`030000003oool0oooo00@0
oooo0P0000040?ooo`@0o`00k03oool2000000X0oooo000G0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`080?ooo`005`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0203oool001H0oooo0P000006
0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0203oool001L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo0?@0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo000N0?ooooP000002P3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool004D0oooo0P0000001@3oool00000000000000000oooo00<000000`3oool4000000<0oooo0P00
00000`3oool000000000000400000080oooo100000030?ooo`8000000P3oool500000080oooo0`00
00020?ooo`<0000000<0oooo0000000000001`3oool300000080oooo0`0000040?ooo`@0000000D0
oooo00000000000000000?ooo`0600000080oooo1@0000020?ooo`<000000P3oool3000000T0oooo
0`0000050?ooo`80000000<0oooo0000000000000P000000103oool000000000003oool3000000@0
oooo0P0000020?ooo`D000000P3oool300000080oooo0`0000000`3oool000000000000c0?ooo`00
A@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00@0
00000?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000003@0oooo00150?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`000000103oool3000000<0oooo00<000000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool3000000<0oooo00@00000
0?ooo`3oool000000P3oool3000000@0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`06
0000003oool0oooo0000003oool000001P3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0380oooo
00150?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`8000000`3oool010000000oooo0?ooo`0000030?ooo`060000003oool0oooo
0000003oool000001`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P00000:0?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000
003oool000000`3oool010000000oooo0?ooo`0000060?ooo`050000003oool0oooo0?ooo`000000
0`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0380oooo00150?ooo`050000
003oool000000?ooo`0000000P3oool3000000<0oooo0`0000020?ooo`80000000<0oooo00000000
00000`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool400000080oooo0`0000040?ooo`<0
00000P3oool4000000P0oooo00H000000?ooo`000000oooo0000003oool2000000030?ooo`000000
00000080oooo0P0000030?ooo`@000000`3oool400000080oooo100000020?ooo`<000000P3oool2
000000030?ooo`000000000000P0oooo00<000000?ooo`3oool00P3oool2000000040?ooo`000000
00000?ooo`@000000`3oool300000080oooo100000020?ooo`<00000103oool300000080oooo1000
000e0?ooo`00A@3oool2000000030?ooo`000000000000X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo00D000000?ooo`000000oooo0000
000K0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000503oool00`000000oooo
0?ooo`170?ooo`00A@3oool010000000oooo0?ooo`3oool2000000P0oooo0P0000080?ooo`<00000
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo1@00000L0?ooo`800000
4`3oool5000001@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`100?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-65.6858, -0.137062, \
1.81034, 0.00720095}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-1.24805753933827`\)\), 
        ",", \(BackFocalLength \[Rule] 39.452587761207255`\), 
        ",", \(BackFocalPoint \[Rule] {57.81626618220312`, \
\(-14.804628830614078`\), 0}\), 
        ",", \(DiffractionSpotSize \[Rule] {0.07532906005834204`, 
            0.0797305898399846`}\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-57.42987001984857`\), \
\(-57.42987001984857`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-14.856306942661192`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {14.534278282384541`, \
\(-3.076460756253562`\), 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] \
{{\(-0.9783237744400718`\), 0.20708112508225274`, 
              0}, {\(-0.20708112508225274`\), \(-0.9783237744400719`\), 
              0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] 0\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {19.817114076226126`, \
\(-4.194675000244022`\), 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{0.9631599411418232`, \
\(-0.268929224480493`\), 0}, {0.26892922448049306`, 0.9631599411418234`, 
              0}, {0, 0, 1}}\), ",", \(FieldStopPosition \[Rule] 2\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 2, 
            SurfaceNumber \[Rule] 2, ComponentNumber \[Rule] 1}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalLength \[Rule] 45.76341881553137`\), 
        ",", \(FrequencyCutoff \[Rule] {426.148921484837`, 
            401.7927730835545`}\), 
        ",", \(FrontFocalLength \[Rule] 38.22742268140686`\), 
        ",", \(FrontFocalPoint \[Rule] {\(-36.2857149126623`\), 
            12.028413783202518`, 0}\), 
        ",", \(ImagePlaneTilt \[Rule] {0.9631599411418242`, \
\(-0.2689292244804903`\), 0}\), 
        ",", \(ImagePoint \[Rule] {89.29058412337928`, \
\(-23.40875619853795`\), 0}\), 
        ",", \(ImageSampleSize \[Rule] {0.0011956993660054292`, 
            0.0012655649180949937`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[\(BiConvexLens[50, 50, 20]\),
                HoldForm], ",", 
              
              TagBox[\(Boundary[{0, \(-54\), \(-54\)}, {108, 54, 
                    54}, {GraphicDesign \[Rule] Off}]\),
                HoldForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8620987850631842`, 
              10.286236147872614`}, {\(-0.021851514285480263`\), 
              0.8992358849155792`}}\), ",", 
        RowBox[{"ModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-432.9131900798344`\), 
                  426.14892148483693`}, {\(-408.1704361483728`\), 
                  401.7927730835545`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(NumberOfRays \[Rule] 32\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          
          TagBox[\(Move[
              PointOfRays[{10, 10}], {\(-90.5`\), 
                30.`}, \(-18.33993103355537`\)]\),
            HoldForm]}], ",", \(OpticalMedium \[Rule] Vacuum\), ",", 
        RowBox[{"OpticalPathDifference", "\[Rule]", 
          
          TagBox[\(CompiledFunction[
              If[#1 == 0 && #2 == 0, 
                0, \(-53.72718114236101`\) + 
                  0.6841371088014239`\ Cos[
                      ArcTan[#1, #2]]\ \@\(#1\^2 + #2\^2\) + 
                  0.8268093141217056`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                  0.0005237305828471303`\ Cos[
                      3\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                  2.3803779152066745`*^-6\ Cos[
                      4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 + 
                  6.24215618261316`*^-8\ Cos[
                      5\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(5/2\) - 
                  7.527615744092852`*^-10\ Cos[
                      6\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^3 - 
                  33.31794942773539`\ \((\(-1\) + 
                        0.015051573550946112`\ \((#1\^2 + #2\^2)\))\) - 
                  25.754451349852992`\ Cos[
                      ArcTan[#1, #2]]\ \((\(-0.17350258528878532`\)\ \
\@\(#1\^2 + #2\^2\) + 
                        0.0019586151928150898`\ \((#1\^2 + #2\^2)\)\^\(3/2\))\
\) + 3.287431629560916`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.022577360326419167`\)\ \
\((#1\^2 + #2\^2)\) + 0.00022654986635954055`\ \((#1\^2 + #2\^2)\)\^2)\) + 
                  21.298061392948092`\ \((1 - 
                        0.045154720652838334`\ \((#1\^2 + #2\^2)\) + 
                        0.0003398247995393108`\ \((#1\^2 + #2\^2)\)\^2)\) + 
                  0.19315969483556109`\ Cos[
                      3\ ArcTan[#1, #2]]\ \((\(-0.002611486923753453`\)\ \
\((#1\^2 + #2\^2)\)\^\(3/2\) + 
                        0.000024566867193880685`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) + 
                  0.4704005777779072`\ Cos[
                      ArcTan[#1, #2]]\ \((0.260253877933178`\ \@\(#1\^2 + \
#2\^2\) - 0.007834460771260359`\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                        0.00004913373438776137`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) + 
                  0.0016547481948091633`\ Cos[
                      4\ ArcTan[#1, #2]]\ \((\(-0.0002831873329494257`\)\ \
\((#1\^2 + #2\^2)\)\^2 + 2.557448982350728`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) + 
                  0.1718629415149294`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((0.045154720652838334`\ \((#1\^2 \
+ #2\^2)\) - 0.0011327493317977028`\ \((#1\^2 + #2\^2)\)\^2 + 
                        6.393622455876819`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) + 
                  0.9380778830716434`\ \((\(-1\) + 
                        0.09030944130567667`\ \((#1\^2 + #2\^2)\) - 
                        0.0016991239976965541`\ \((#1\^2 + #2\^2)\)\^2 + 
                        8.524829941169092`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) - 
                  0.0016008379852500145`\ Cos[
                      5\ ArcTan[#1, #2]]\ \((\(-0.000029480240632656822`\)\ \
\((#1\^2 + #2\^2)\)\^\(5/2\) + 
                        2.5883900593951417`*^-7\ \((#1\^2 + \
#2\^2)\)\^\(7/2\))\) + 
                  0.012789488355240854`\ Cos[
                      3\ ArcTan[#1, #2]]\ \((0.006528717309383633`\ \((#1\^2 \
+ #2\^2)\)\^\(3/2\) - 0.00014740120316328412`\ \((#1\^2 + #2\^2)\)\^\(5/2\) + 
                        7.765170178185426`*^-7\ \((#1\^2 + #2\^2)\)\^\(7/2\))\
\) + 0.08841213124458154`\ Cos[
                      ArcTan[#1, #2]]\ \((\(-0.34700517057757063`\)\ \
\@\(#1\^2 + #2\^2\) + 0.0195861519281509`\ \((#1\^2 + #2\^2)\)\^\(3/2\) - 
                        0.00029480240632656825`\ \((#1\^2 + #2\^2)\)\^\(5/2\) \
+ 1.294195029697571`*^-6\ \((#1\^2 + #2\^2)\)\^\(7/2\))\) - 
                  0.0008583985197702541`\ Cos[
                      6\ ArcTan[#1, #2]]\ \((\(-2.9836904794091823`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 2.566242097376284`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) - 
                  0.0027483272708150224`\ Cos[
                      4\ ArcTan[#1, #2]]\ \((0.0008495619988482771`\ \((#1\^2 \
+ #2\^2)\)\^2 - 0.000017902142876455095`\ \((#1\^2 + #2\^2)\)\^3 + 
                        8.981847340816994`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  0.011493681863773962`\ Cos[
                      2\ ArcTan[#1, #2]]\ \((\(-0.07525786775473056`\)\ \((#1\
\^2 + #2\^2)\) + 0.0033982479953931083`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.00004475535719113773`\ \((#1\^2 + #2\^2)\)\^3 + 
                        1.7963694681633989`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) + 
                  0.04924820474947301`\ \((1 - 
                        0.15051573550946112`\ \((#1\^2 + #2\^2)\) + 
                        0.0050973719930896624`\ \((#1\^2 + #2\^2)\)\^2 - 
                        0.000059673809588183645`\ \((#1\^2 + #2\^2)\)\^3 + 
                        2.2454618352042486`*^-7\ \((#1\^2 + #2\^2)\)\^4)\)], 
              "-CompiledCode-"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"ModulationTransferFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], ",", 
        RowBox[{"PerfectModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-432.9131900798344`\), 
                  426.14892148483693`}, {\(-408.1704361483728`\), 
                  401.7927730835545`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PerfectPhaseTransferFunction \[Rule] 
          PerfectPhaseTransferFunction\), ",", 
        RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.03706668034616831`\), 
                  0.038262379712173736`}, {\(-0.03923251246094481`\), 
                  0.04049807737903979`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PhaseTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-432.9131900798344`\), 
                  426.14892148483693`}, {\(-408.1704361483728`\), 
                  401.7927730835545`}}, "<>"]\),
            False,
            Editable->False]}], ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.03706668034616831`\), 
                  0.038262379712173736`}, {\(-0.03923251246094481`\), 
                  0.04049807737903979`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PrinciplePoints \[Rule] {{7.153215888623535`, \
\(-2.371231786283955`\), 0}, {13.738774409387325`, \(-2.4975080989772263`\), 
              0}}\), ",", \(PrinciplePointSeparation \[Rule] 
          6.586769066663258`\), 
        ",", \(RayBoundary \[Rule] {{\(-8.231158584074413`\), 
              8.216542722183906`}, {\(-7.748226433108913`\), 
              7.748226433108913`}}\), 
        ",", \(ResidualFitError \[Rule] 0.0012111204519945535`\), 
        ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] \
\(-486.4441966590851`\), Asigmatism \[Rule] \(-211.53223095724226`\), 
            FieldCurvature \[Rule] 589.2350321728392`, 
            Distortion \[Rule] 60.322515368991525`, 
            Coma \[Rule] \(-79.54013761616795`\)}\), 
        ",", \(SourceID \[Rule] 90485\), 
        ",", \(StrehlRatio \[Rule] 513.7333007724889`\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.1385342450167921`\), \
\(-19.264397093419163`\)}, {\(-0.021851514285480256`\), \
\(-1.24805753933827`\)}}\), 
        ",", \(TransverseMagnification \[Rule] \(-1.1385342450167921`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", 
        RowBox[{"WaveFrontIntensity", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-8.231158584074413`\), 
                  8.216542722183906`}, {\(-7.748226433108913`\), 
                  7.748226433108913`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\)}], 
      "}"}]], "Output",
  CellLabel->"Out[349]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell["\<\
(*Note NumberOfPoints->256 can run out of Kernal memory sometimes*)\
\>", "Input",
  CellLabel->"In[350]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{

Cell["\<\
MTF[sys3D, FindImagePoint->True, FocalFraction->1, \
NumberOfPoints->256]//Timing\
\>", "Input",
  CellLabel->"In[78]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0563246 -1.06805 5.07029 [
[.07757 -0.0125 -12 -9 ]
[.07757 -0.0125 12 0 ]
[.21838 -0.0125 -6 -9 ]
[.21838 -0.0125 6 0 ]
[.35919 -0.0125 -12 -9 ]
[.35919 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64081 -0.0125 -9 -9 ]
[.64081 -0.0125 9 0 ]
[.78162 -0.0125 -3 -9 ]
[.78162 -0.0125 3 0 ]
[.92243 -0.0125 -9 -9 ]
[.92243 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04741 -24 -4.5 ]
[-0.0125 .04741 0 4.5 ]
[-0.0125 .14881 -24 -4.5 ]
[-0.0125 .14881 0 4.5 ]
[-0.0125 .25022 -24 -4.5 ]
[-0.0125 .25022 0 4.5 ]
[-0.0125 .35163 -24 -4.5 ]
[-0.0125 .35163 0 4.5 ]
[-0.0125 .45303 -18 -4.5 ]
[-0.0125 .45303 0 4.5 ]
[-0.0125 .55444 -24 -4.5 ]
[-0.0125 .55444 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -60 0 ]
[.5 .63053 60 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07757 0 m
.07757 .00625 L
s
[(-7.5)] .07757 -0.0125 0 1 Mshowa
.21838 0 m
.21838 .00625 L
s
[(-5)] .21838 -0.0125 0 1 Mshowa
.35919 0 m
.35919 .00625 L
s
[(-2.5)] .35919 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64081 0 m
.64081 .00625 L
s
[(2.5)] .64081 -0.0125 0 1 Mshowa
.78162 0 m
.78162 .00625 L
s
[(5)] .78162 -0.0125 0 1 Mshowa
.92243 0 m
.92243 .00625 L
s
[(7.5)] .92243 -0.0125 0 1 Mshowa
.125 Mabswid
.10573 0 m
.10573 .00375 L
s
.13389 0 m
.13389 .00375 L
s
.16205 0 m
.16205 .00375 L
s
.19021 0 m
.19021 .00375 L
s
.24654 0 m
.24654 .00375 L
s
.2747 0 m
.2747 .00375 L
s
.30286 0 m
.30286 .00375 L
s
.33103 0 m
.33103 .00375 L
s
.38735 0 m
.38735 .00375 L
s
.41551 0 m
.41551 .00375 L
s
.44368 0 m
.44368 .00375 L
s
.47184 0 m
.47184 .00375 L
s
.52816 0 m
.52816 .00375 L
s
.55632 0 m
.55632 .00375 L
s
.58449 0 m
.58449 .00375 L
s
.61265 0 m
.61265 .00375 L
s
.66897 0 m
.66897 .00375 L
s
.69714 0 m
.69714 .00375 L
s
.7253 0 m
.7253 .00375 L
s
.75346 0 m
.75346 .00375 L
s
.80979 0 m
.80979 .00375 L
s
.83795 0 m
.83795 .00375 L
s
.86611 0 m
.86611 .00375 L
s
.89427 0 m
.89427 .00375 L
s
.0494 0 m
.0494 .00375 L
s
.02124 0 m
.02124 .00375 L
s
.9506 0 m
.9506 .00375 L
s
.97876 0 m
.97876 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04741 m
.00625 .04741 L
s
[(0.22)] -0.0125 .04741 1 0 Mshowa
0 .14881 m
.00625 .14881 L
s
[(0.24)] -0.0125 .14881 1 0 Mshowa
0 .25022 m
.00625 .25022 L
s
[(0.26)] -0.0125 .25022 1 0 Mshowa
0 .35163 m
.00625 .35163 L
s
[(0.28)] -0.0125 .35163 1 0 Mshowa
0 .45303 m
.00625 .45303 L
s
[(0.3)] -0.0125 .45303 1 0 Mshowa
0 .55444 m
.00625 .55444 L
s
[(0.32)] -0.0125 .55444 1 0 Mshowa
.125 Mabswid
0 .07276 m
.00375 .07276 L
s
0 .09811 m
.00375 .09811 L
s
0 .12346 m
.00375 .12346 L
s
0 .17417 m
.00375 .17417 L
s
0 .19952 m
.00375 .19952 L
s
0 .22487 m
.00375 .22487 L
s
0 .27557 m
.00375 .27557 L
s
0 .30092 m
.00375 .30092 L
s
0 .32627 m
.00375 .32627 L
s
0 .37698 m
.00375 .37698 L
s
0 .40233 m
.00375 .40233 L
s
0 .42768 m
.00375 .42768 L
s
0 .47838 m
.00375 .47838 L
s
0 .50373 m
.00375 .50373 L
s
0 .52909 m
.00375 .52909 L
s
0 .02206 m
.00375 .02206 L
s
0 .57979 m
.00375 .57979 L
s
0 .60514 m
.00375 .60514 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07757 .61178 m
.07757 .61803 L
s
.21838 .61178 m
.21838 .61803 L
s
.35919 .61178 m
.35919 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64081 .61178 m
.64081 .61803 L
s
.78162 .61178 m
.78162 .61803 L
s
.92243 .61178 m
.92243 .61803 L
s
.125 Mabswid
.10573 .61428 m
.10573 .61803 L
s
.13389 .61428 m
.13389 .61803 L
s
.16205 .61428 m
.16205 .61803 L
s
.19021 .61428 m
.19021 .61803 L
s
.24654 .61428 m
.24654 .61803 L
s
.2747 .61428 m
.2747 .61803 L
s
.30286 .61428 m
.30286 .61803 L
s
.33103 .61428 m
.33103 .61803 L
s
.38735 .61428 m
.38735 .61803 L
s
.41551 .61428 m
.41551 .61803 L
s
.44368 .61428 m
.44368 .61803 L
s
.47184 .61428 m
.47184 .61803 L
s
.52816 .61428 m
.52816 .61803 L
s
.55632 .61428 m
.55632 .61803 L
s
.58449 .61428 m
.58449 .61803 L
s
.61265 .61428 m
.61265 .61803 L
s
.66897 .61428 m
.66897 .61803 L
s
.69714 .61428 m
.69714 .61803 L
s
.7253 .61428 m
.7253 .61803 L
s
.75346 .61428 m
.75346 .61803 L
s
.80979 .61428 m
.80979 .61803 L
s
.83795 .61428 m
.83795 .61803 L
s
.86611 .61428 m
.86611 .61803 L
s
.89427 .61428 m
.89427 .61803 L
s
.0494 .61428 m
.0494 .61803 L
s
.02124 .61428 m
.02124 .61803 L
s
.9506 .61428 m
.9506 .61803 L
s
.97876 .61428 m
.97876 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04741 m
1 .04741 L
s
.99375 .14881 m
1 .14881 L
s
.99375 .25022 m
1 .25022 L
s
.99375 .35163 m
1 .35163 L
s
.99375 .45303 m
1 .45303 L
s
.99375 .55444 m
1 .55444 L
s
.125 Mabswid
.99625 .07276 m
1 .07276 L
s
.99625 .09811 m
1 .09811 L
s
.99625 .12346 m
1 .12346 L
s
.99625 .17417 m
1 .17417 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .22487 m
1 .22487 L
s
.99625 .27557 m
1 .27557 L
s
.99625 .30092 m
1 .30092 L
s
.99625 .32627 m
1 .32627 L
s
.99625 .37698 m
1 .37698 L
s
.99625 .40233 m
1 .40233 L
s
.99625 .42768 m
1 .42768 L
s
.99625 .47838 m
1 .47838 L
s
.99625 .50373 m
1 .50373 L
s
.99625 .52909 m
1 .52909 L
s
.99625 .02206 m
1 .02206 L
s
.99625 .57979 m
1 .57979 L
s
.99625 .60514 m
1 .60514 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Wave Front Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.03853 .23241 L
.04619 .32737 L
.05458 .4081 L
.06247 .46947 L
.06965 .5102 L
.07139 .52004 L
.07323 .53048 L
.07369 .5331 L
.07419 .53538 L
.07447 .53618 L
.07474 .53692 L
.07525 .53837 L
.07711 .54365 L
.08121 .55528 L
.08509 .56626 L
.08689 .57137 L
.08859 .57618 L
.08904 .57748 L
.08953 .57833 L
.08978 .57862 L
.09006 .57895 L
.09054 .57953 L
.09232 .58162 L
.09641 .58646 L
.10021 .59094 L
.10204 .5931 L
.10301 .59424 L
.10353 .59487 L
.10403 .59545 L
.10446 .59593 L
.10492 .59612 L
.10591 .59651 L
.10765 .59721 L
.11181 .59888 L
.11561 .6004 L
.11738 .6011 L
.11834 .60149 L
.11926 .60185 L
.11951 .60196 L
.11978 .60202 L
.12007 .60204 L
.12034 .60207 L
.12133 .60215 L
.12325 .60231 L
.12712 .60265 L
.13129 .603 L
.13328 .60317 L
.13376 .60321 L
.13427 .60325 L
Mistroke
.13475 .6033 L
.13518 .6033 L
.1356 .6033 L
.13606 .60329 L
.13689 .60328 L
.13874 .60326 L
.14572 .60318 L
.14747 .60316 L
.14844 .60315 L
.14935 .60314 L
.1496 .60313 L
.14987 .60313 L
.15016 .60312 L
.15043 .60311 L
.15141 .60307 L
.15333 .60299 L
.16136 .60265 L
.17576 .60203 L
.1911 .60132 L
.20585 .60071 L
.22155 .60005 L
.23666 .5995 L
.2512 .59896 L
.26667 .59846 L
.28156 .59797 L
.29739 .59752 L
.31264 .59709 L
.32732 .59674 L
.34292 .59637 L
.35796 .59608 L
.37241 .59579 L
.3878 .59555 L
.40261 .59532 L
.41835 .59513 L
.42217 .5951 L
.42623 .59506 L
.43352 .59496 L
.43685 .59491 L
.4386 .59489 L
.43903 .59489 L
.43948 .59488 L
.43998 .59488 L
.44045 .59488 L
.44251 .59487 L
.4444 .59486 L
.44811 .59485 L
.452 .59484 L
.45307 .59483 L
.45365 .59483 L
.45394 .59483 L
Mistroke
.4542 .59483 L
.45467 .59482 L
.45517 .59482 L
.45623 .59481 L
.4639 .59473 L
.46741 .5947 L
.46842 .59469 L
.46891 .59469 L
.46937 .59468 L
.46978 .59468 L
.47022 .59468 L
.47114 .59468 L
.47524 .59468 L
.47904 .59468 L
.48265 .59469 L
.48369 .59469 L
.4842 .59469 L
.48468 .59469 L
.48511 .59468 L
.48556 .59468 L
.48652 .59468 L
.49351 .59464 L
.49708 .59462 L
.49806 .59461 L
.49909 .59461 L
.49952 .5946 L
.49997 .5946 L
.50047 .5946 L
.50093 .5946 L
.5079 .59464 L
.51181 .59465 L
.51386 .59466 L
.51436 .59467 L
.5149 .59467 L
.51521 .59467 L
.51549 .59467 L
.51604 .59467 L
.52003 .59466 L
.52372 .59465 L
.52554 .59465 L
.52748 .59465 L
.52842 .59465 L
.52931 .59465 L
.5297 .59464 L
.53011 .59464 L
.53056 .59464 L
.53097 .59465 L
.53887 .59472 L
.54249 .59475 L
.54449 .59477 L
Mistroke
.54496 .59477 L
.54522 .59477 L
.54547 .59477 L
.5459 .59478 L
.54637 .59478 L
.54813 .59478 L
.55003 .59479 L
.55336 .59479 L
.55732 .5948 L
.55826 .5948 L
.55926 .59481 L
.55975 .59481 L
.56021 .59481 L
.56063 .59481 L
.56107 .59481 L
.56148 .59482 L
.56193 .59482 L
.56283 .59484 L
.56445 .59486 L
.56813 .5949 L
.58352 .59505 L
.59834 .59522 L
.61409 .59544 L
.62927 .59568 L
.64386 .59597 L
.6594 .59628 L
.67435 .59661 L
.68873 .59695 L
.70404 .59735 L
.71877 .59777 L
.73444 .59824 L
.74953 .59873 L
.76404 .59924 L
.77949 .59981 L
.79436 .60039 L
.81016 .60105 L
.82539 .60172 L
.84004 .60238 L
.84746 .6027 L
.85562 .603 L
.85936 .60312 L
.86142 .60319 L
.86337 .60326 L
.86425 .60329 L
.86473 .60331 L
.86519 .60332 L
.86544 .60331 L
.86572 .60331 L
.86621 .6033 L
.86716 .60328 L
Mistroke
.87063 .60322 L
.87456 .60314 L
.87823 .60307 L
.87918 .60305 L
.87965 .60305 L
.88008 .60304 L
.88058 .60299 L
.88084 .60294 L
.88112 .60289 L
.88206 .60271 L
.88626 .60191 L
.88984 .60122 L
.89172 .60087 L
.89369 .60049 L
.89453 .60033 L
.89499 .60024 L
.89543 .60016 L
.89568 .60006 L
.89595 .59988 L
.89641 .59956 L
.89733 .59894 L
.90066 .59668 L
.90458 .59401 L
.90824 .59153 L
.90919 .59088 L
.91009 .59027 L
.91058 .58994 L
.91086 .58967 L
.91112 .5892 L
.91206 .58749 L
.91626 .5799 L
.91997 .5732 L
.92191 .56968 L
.92396 .56597 L
.92484 .5644 L
.92531 .56353 L
.92577 .56272 L
.92602 .56221 L
.9263 .5611 L
.92679 .55916 L
.92774 .55537 L
.9312 .54158 L
.93804 .51435 L
.93991 .50689 L
.94041 .50493 L
.94095 .50278 L
.94145 .49995 L
.94193 .49646 L
.94383 .48242 L
.94557 .46959 L
Mistroke
.95313 .41379 L
.96114 .33478 L
.97605 .14466 L
.97619 .14247 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Joooo
o`?o00006Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo0_l0000Ioooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006_ooool3o`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00005?ooool0033ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00000I
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`00
0?ooooooooooo`0001Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Sooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Cooooo`00:?ooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003oooooooooo`0@ooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo000aooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04Oooool003;ooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo1?l0000Iooooo`05o`000?ooooooooooooooool000001oooool4o`0001Kooooo
00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Ioooo
o`Co00007Oooool00ol0003oooooooooo`05ooooo`Co00005?ooool002kooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
000Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Go
oooo000^ooooo`Go00001oooool5o`0001Sooooo1Ol0000Iooooo`?o00002?ooool5o`0001Kooooo
0_l0000Jooooo`?o00002?ooool5o`0001Sooooo1Ol0000Hooooo`Go00001oooool5o`0001?ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000QooooooSo0000
1oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001?ooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo07Sooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol000000ooooooo0000o`000003o`00
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Ooo
ool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo0_l00004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0N?oo
ool2o`0000Oooooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?oooooo
ooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00007ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool01Oooool000Sooooo0_l00009ooooo`?o00000oooool3o`0000Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
1Oooool0027ooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0N?oo
ool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001Oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo07Sooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool2o`00
00Gooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1hooooo`;o00001oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool01Oooool000Sooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00000ooo
ool3o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00009ooooo`04o`00
0?ooooooooooooooo`Go00001?ooool2o`0000Kooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`1cooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`001oooool01?l0003ooooo
ooooool0000:ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000000oooool2o`0000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool0027ooooo0_l00006ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`;o00001oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001ooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool00ooo
ool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`008Oooool2o`0000Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`002?oo
ool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00009oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`;o00001oooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01?ooool2
o`0000Oooooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01?l00005
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooo
oooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Wooooo0ol00004ooooo`;o0000
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`008Oooool2o`0000Sooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`008Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo0_l00008ooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05ooooo`;o
00001oooool0027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo000Qooooo`;o00002Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06oooooo
00?o0000ooooooooool01_ooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0008ooooo`;o
00001?ooool01?l0003oooooooooooooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool0000:ooooo`04o`00
0?ooooooooooooooo`?o00001Oooool2o`0000[ooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`001oooool01?l0003ooooo
ooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`001oooool01?l0
003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`002?oo
ool2o`0000Wooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`008Oooool2o`0000[o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oo
oooo0_l00007ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01Oooool0027ooooo0_l0000;ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`08ooooo`;o00001oooool0027ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo06_ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00002oooool00ol0003ooooooooo
o`1[ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02?ooool2o`0000Oooooo000Q
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000=ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool000gooooo
00Co0000oooooooooooo00002Oooool2o`0000Gooooo0_l0000<ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`09ooooo`;o00001oooool000gooooo
00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yoooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05oooo
o`003_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0K?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00003Oooool0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02_ooool2
o`0000Oooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05
ooooo`008Oooool2o`0000oooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo00_ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1Oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`008Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000@ooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0<ooooo`;o00001oooool0027ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo06Wooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0I_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00002oooo
o`Go00001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`001oooool0
1?l0003oooooooooool0000;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo
0_l00005ooooo`03o`000?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0>ooooo`;o00001oooool000Oooooo00Co
0000oooooooooooo00002oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003ooooooooo
ool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
06Kooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo0008ooooo`;o00002Oooool3o`0000?o
oooo0ol00005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00005?ooool2o`0006?ooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0Aooooo`;o00001oooool0027ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`1Qooooo`?o00005Oooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0Fooooo`?o0000:?oooomao`0002[ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Iooooo`?o00002ooooolJ
o`0003Oooooo00?o0000ooooooooool0=ooooolJo`0000cooooo1?l0000Hooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`;o00007?ooool<o`00057ooooo00?o0000ooooooooool0DOooool<o`00
01_ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0027ooooon?l0
0007ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00d_ooool3o`0004_ooooo
003Cooooo`03o`000?oooooooooo04[ooooo001Qooooo`03o`000?oooooo000000?ooooo1?l00003
ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`?o00000oooool3o`0000Cooooo0ol00002
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Sooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l0
0002ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool0BOooool0067ooooo00?o0000
ooooool000000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool00000
3?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00006ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0BOooool0067ooooo00?o0000
ooooool000000oooool3o`0000?ooooo00?o0000ooooool000000_ooool5o`0000Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`00001:ooooo`00H?ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooo
oooooooooooo000000Sooooo0ol00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000004[ooooo001Pooooo`05
o`000?oooooo0000ooooool000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`?o00002Oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00;ooooo1?l00002ooooo`Co00002_ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00003
ooooo`?o00000_ooool4o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co00000_oo
ool2o`000003ooooool0003o000004Wooooo001Pooooo`05o`000?oooooo0000ooooool000006_oo
ool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo053ooooo001Pooooo`Ko00006?oo
ool5o`0001Cooooo00?o0000ooooooooool02?ooool5o`0000Sooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo053ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.2762, 0.201001, \
0.0718309, 0.000797951}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0563246 0.0163308 0.0379396 [
[.07757 -0.0125 -12 -9 ]
[.07757 -0.0125 12 0 ]
[.21838 -0.0125 -6 -9 ]
[.21838 -0.0125 6 0 ]
[.35919 -0.0125 -12 -9 ]
[.35919 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64081 -0.0125 -9 -9 ]
[.64081 -0.0125 9 0 ]
[.78162 -0.0125 -3 -9 ]
[.78162 -0.0125 3 0 ]
[.92243 -0.0125 -9 -9 ]
[.92243 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01633 -6 -4.5 ]
[-0.0125 .01633 0 4.5 ]
[-0.0125 .11118 -18 -4.5 ]
[-0.0125 .11118 0 4.5 ]
[-0.0125 .20603 -6 -4.5 ]
[-0.0125 .20603 0 4.5 ]
[-0.0125 .30088 -18 -4.5 ]
[-0.0125 .30088 0 4.5 ]
[-0.0125 .39573 -12 -4.5 ]
[-0.0125 .39573 0 4.5 ]
[-0.0125 .49058 -24 -4.5 ]
[-0.0125 .49058 0 4.5 ]
[-0.0125 .58542 -12 -4.5 ]
[-0.0125 .58542 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07757 0 m
.07757 .00625 L
s
[(-7.5)] .07757 -0.0125 0 1 Mshowa
.21838 0 m
.21838 .00625 L
s
[(-5)] .21838 -0.0125 0 1 Mshowa
.35919 0 m
.35919 .00625 L
s
[(-2.5)] .35919 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64081 0 m
.64081 .00625 L
s
[(2.5)] .64081 -0.0125 0 1 Mshowa
.78162 0 m
.78162 .00625 L
s
[(5)] .78162 -0.0125 0 1 Mshowa
.92243 0 m
.92243 .00625 L
s
[(7.5)] .92243 -0.0125 0 1 Mshowa
.125 Mabswid
.10573 0 m
.10573 .00375 L
s
.13389 0 m
.13389 .00375 L
s
.16205 0 m
.16205 .00375 L
s
.19021 0 m
.19021 .00375 L
s
.24654 0 m
.24654 .00375 L
s
.2747 0 m
.2747 .00375 L
s
.30286 0 m
.30286 .00375 L
s
.33103 0 m
.33103 .00375 L
s
.38735 0 m
.38735 .00375 L
s
.41551 0 m
.41551 .00375 L
s
.44368 0 m
.44368 .00375 L
s
.47184 0 m
.47184 .00375 L
s
.52816 0 m
.52816 .00375 L
s
.55632 0 m
.55632 .00375 L
s
.58449 0 m
.58449 .00375 L
s
.61265 0 m
.61265 .00375 L
s
.66897 0 m
.66897 .00375 L
s
.69714 0 m
.69714 .00375 L
s
.7253 0 m
.7253 .00375 L
s
.75346 0 m
.75346 .00375 L
s
.80979 0 m
.80979 .00375 L
s
.83795 0 m
.83795 .00375 L
s
.86611 0 m
.86611 .00375 L
s
.89427 0 m
.89427 .00375 L
s
.0494 0 m
.0494 .00375 L
s
.02124 0 m
.02124 .00375 L
s
.9506 0 m
.9506 .00375 L
s
.97876 0 m
.97876 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01633 m
.00625 .01633 L
s
[(0)] -0.0125 .01633 1 0 Mshowa
0 .11118 m
.00625 .11118 L
s
[(2.5)] -0.0125 .11118 1 0 Mshowa
0 .20603 m
.00625 .20603 L
s
[(5)] -0.0125 .20603 1 0 Mshowa
0 .30088 m
.00625 .30088 L
s
[(7.5)] -0.0125 .30088 1 0 Mshowa
0 .39573 m
.00625 .39573 L
s
[(10)] -0.0125 .39573 1 0 Mshowa
0 .49058 m
.00625 .49058 L
s
[(12.5)] -0.0125 .49058 1 0 Mshowa
0 .58542 m
.00625 .58542 L
s
[(15)] -0.0125 .58542 1 0 Mshowa
.125 Mabswid
0 .0353 m
.00375 .0353 L
s
0 .05427 m
.00375 .05427 L
s
0 .07324 m
.00375 .07324 L
s
0 .09221 m
.00375 .09221 L
s
0 .13015 m
.00375 .13015 L
s
0 .14912 m
.00375 .14912 L
s
0 .16809 m
.00375 .16809 L
s
0 .18706 m
.00375 .18706 L
s
0 .225 m
.00375 .225 L
s
0 .24397 m
.00375 .24397 L
s
0 .26294 m
.00375 .26294 L
s
0 .28191 m
.00375 .28191 L
s
0 .31985 m
.00375 .31985 L
s
0 .33882 m
.00375 .33882 L
s
0 .35779 m
.00375 .35779 L
s
0 .37676 m
.00375 .37676 L
s
0 .4147 m
.00375 .4147 L
s
0 .43367 m
.00375 .43367 L
s
0 .45264 m
.00375 .45264 L
s
0 .47161 m
.00375 .47161 L
s
0 .50955 m
.00375 .50955 L
s
0 .52852 m
.00375 .52852 L
s
0 .54749 m
.00375 .54749 L
s
0 .56645 m
.00375 .56645 L
s
0 .60439 m
.00375 .60439 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07757 .61178 m
.07757 .61803 L
s
.21838 .61178 m
.21838 .61803 L
s
.35919 .61178 m
.35919 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64081 .61178 m
.64081 .61803 L
s
.78162 .61178 m
.78162 .61803 L
s
.92243 .61178 m
.92243 .61803 L
s
.125 Mabswid
.10573 .61428 m
.10573 .61803 L
s
.13389 .61428 m
.13389 .61803 L
s
.16205 .61428 m
.16205 .61803 L
s
.19021 .61428 m
.19021 .61803 L
s
.24654 .61428 m
.24654 .61803 L
s
.2747 .61428 m
.2747 .61803 L
s
.30286 .61428 m
.30286 .61803 L
s
.33103 .61428 m
.33103 .61803 L
s
.38735 .61428 m
.38735 .61803 L
s
.41551 .61428 m
.41551 .61803 L
s
.44368 .61428 m
.44368 .61803 L
s
.47184 .61428 m
.47184 .61803 L
s
.52816 .61428 m
.52816 .61803 L
s
.55632 .61428 m
.55632 .61803 L
s
.58449 .61428 m
.58449 .61803 L
s
.61265 .61428 m
.61265 .61803 L
s
.66897 .61428 m
.66897 .61803 L
s
.69714 .61428 m
.69714 .61803 L
s
.7253 .61428 m
.7253 .61803 L
s
.75346 .61428 m
.75346 .61803 L
s
.80979 .61428 m
.80979 .61803 L
s
.83795 .61428 m
.83795 .61803 L
s
.86611 .61428 m
.86611 .61803 L
s
.89427 .61428 m
.89427 .61803 L
s
.0494 .61428 m
.0494 .61803 L
s
.02124 .61428 m
.02124 .61803 L
s
.9506 .61428 m
.9506 .61803 L
s
.97876 .61428 m
.97876 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01633 m
1 .01633 L
s
.99375 .11118 m
1 .11118 L
s
.99375 .20603 m
1 .20603 L
s
.99375 .30088 m
1 .30088 L
s
.99375 .39573 m
1 .39573 L
s
.99375 .49058 m
1 .49058 L
s
.99375 .58542 m
1 .58542 L
s
.125 Mabswid
.99625 .0353 m
1 .0353 L
s
.99625 .05427 m
1 .05427 L
s
.99625 .07324 m
1 .07324 L
s
.99625 .09221 m
1 .09221 L
s
.99625 .13015 m
1 .13015 L
s
.99625 .14912 m
1 .14912 L
s
.99625 .16809 m
1 .16809 L
s
.99625 .18706 m
1 .18706 L
s
.99625 .225 m
1 .225 L
s
.99625 .24397 m
1 .24397 L
s
.99625 .26294 m
1 .26294 L
s
.99625 .28191 m
1 .28191 L
s
.99625 .31985 m
1 .31985 L
s
.99625 .33882 m
1 .33882 L
s
.99625 .35779 m
1 .35779 L
s
.99625 .37676 m
1 .37676 L
s
.99625 .4147 m
1 .4147 L
s
.99625 .43367 m
1 .43367 L
s
.99625 .45264 m
1 .45264 L
s
.99625 .47161 m
1 .47161 L
s
.99625 .50955 m
1 .50955 L
s
.99625 .52852 m
1 .52852 L
s
.99625 .54749 m
1 .54749 L
s
.99625 .56645 m
1 .56645 L
s
.99625 .60439 m
1 .60439 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .60332 m
.03853 .57862 L
.05458 .55098 L
.06965 .52453 L
.08415 .49875 L
.09958 .4711 L
.11444 .44439 L
.13023 .41605 L
.14544 .38891 L
.16007 .36306 L
.17564 .33596 L
.19063 .31036 L
.20504 .28628 L
.22039 .26133 L
.23516 .23807 L
.25087 .21424 L
.26599 .19224 L
.28054 .17203 L
.29603 .15163 L
.31093 .13313 L
.32678 .11476 L
.34204 .09837 L
.35672 .08388 L
.37234 .06988 L
.38739 .05781 L
.40185 .04756 L
.41725 .03813 L
.43208 .03053 L
.44783 .02406 L
.45572 .02146 L
.46301 .01942 L
.47054 .0177 L
.47761 .01644 L
.48472 .01552 L
.4885 .01517 L
.49061 .01502 L
.49257 .01491 L
.49433 .01483 L
.49524 .01479 L
.49622 .01476 L
.49678 .01475 L
.49729 .01474 L
.49778 .01473 L
.49831 .01472 L
.49878 .01472 L
.49923 .01472 L
.4997 .01472 L
.49996 .01472 L
.50021 .01472 L
.5007 .01472 L
Mistroke
.50098 .01472 L
.50123 .01472 L
.50172 .01473 L
.50218 .01473 L
.50321 .01475 L
.50433 .01478 L
.50637 .01485 L
.50824 .01495 L
.51196 .01521 L
.51543 .01554 L
.52331 .01659 L
.53107 .01804 L
.53815 .01972 L
.55335 .02449 L
.56797 .03055 L
.58353 .03857 L
.5985 .0478 L
.6129 .05803 L
.62824 .07037 L
.643 .08362 L
.65869 .09913 L
.67381 .11541 L
.68834 .13226 L
.70381 .15143 L
.71871 .17102 L
.73454 .19299 L
.74979 .21521 L
.76446 .23749 L
.78007 .26207 L
.7951 .28652 L
.80955 .31067 L
.82494 .33696 L
.83975 .36275 L
.8555 .39057 L
.87066 .41764 L
.88525 .44384 L
.90078 .47174 L
.91572 .49853 L
.93009 .52408 L
.94539 .55094 L
.96012 .57631 L
.97578 .60264 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Joooo
o`?o00006Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo0_l0000Ioooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006_ooool3o`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00005?ooool0033ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00000I
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Eooooo`04o`00
0?ooooooooooo`0001Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Sooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Cooooo`00:?ooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003oooooooooo`0@ooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo000aooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04Oooool003;ooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo1?l0000Iooooo`05o`000?ooooooooooooooool000001oooool4o`0001Kooooo
00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Ioooo
o`Co00007Oooool00ol0003oooooooooo`05ooooo`Co00005?ooool002kooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
000Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Go
oooo000^ooooo`Go00001oooool5o`0001Sooooo1Ol0000Iooooo`?o00002?ooool5o`0001Kooooo
0_l0000Jooooo`?o00002?ooool5o`0001Sooooo1Ol0000Hooooo`Go00001oooool5o`0001?ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000QooooooSo0000
1oooool001[ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo000Iooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`03o`000?oo
oooooooo00Gooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0M?oo
ool:o`0007Kooooo00?o0000ooooooooool01Oooool001Wooooo00Co0000oooooooooooo00001?oo
ool2o`00073ooooo1Ol00004ooooo`03o`000?oooooooooo00?ooooo1?l0001aooooo`;o00001ooo
ool001Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1]ooooo`;o00002Ooo
ool00ol0003oooooooooo`07ooooo`?o0000Koooool00ol0003oooooooooo`05ooooo`006Oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo06[ooooo0ol0000;ooooo`03o`000?oo
oooooooo00[ooooo1?l0001[ooooo`03o`000?oooooooooo00Gooooo000Jooooo`;o00001Oooool0
0ol0003oooooooooo`1Wooooo`?o00003_ooool00ol0003oooooooooo`0>ooooo`;o0000JOooool0
0ol0003oooooooooo`05ooooo`008Oooool2o`0006Kooooo0_l0000Aooooo`03o`000?oooooooooo
013ooooo0_l0001Vooooo`;o00001oooool0027ooooo00?o0000ooooooooool0Hoooool2o`0001?o
oooo00?o0000ooooooooool04_ooool2o`0006Gooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool0HOooool2o`0001Gooooo00?o0000ooooooooool05?ooool2o`0006?ooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`;o0000Goooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0GOooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo05cooooo0_l0000Jooooo`03
o`000?oooooooooo01Wooooo0_l0001Nooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1Hooooo`;o00007_ooool0
0ol0003oooooooooo`0Mooooo`;o0000F_ooool00ol0003oooooooooo`05ooooo`008Oooool2o`00
05Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
05Kooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Go
oooo000Qooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`05ooooo`008Oooool2o`0005Cooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05;ooooo0_l00007
ooooo`008Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool01Oooool000cooooo1Ol00003ooooo`03o`00
0?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0
1Oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`05ooooo`003_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l0001@ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`1>ooooo`;o00001oooool000oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool01Oooool000cooooo00Go0000ooooooooooooooooo`000007ooooo`Co00001Ooo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Gooooo000<ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool01Oooool000gooooo0ol00008ooooo`Go00001?ooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000C?ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0BOooool2o`0000Oooooo000Qooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01Oooool0
027ooooo0_l00017ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`15ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`05ooooo`008Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool01Oooool0027ooooo0_l00014
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`12
ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`05ooooo`008Oooool2o`00047ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo03oooooo0_l00007ooooo`008Oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00Gooooo000Iooooo`?o00001Oooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00Gooooo000Hooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo000Looooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`007?oo
ool00ol0003oooooooooo`02ooooo`;o0000?_ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0??ooool2o`0000Oooooo000Hooooo`Co00001Oooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00Gooooo000Hooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`006?ooool5o`0000Co
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`008Oooool2o`0003_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03Wooooo
0_l00007ooooo`008Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Gooooo000Q
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00Gooooo000Qooooo`;o0000=oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool0=Oooool2o`0000Oooooo000Qooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool0027ooooo
0_l0000dooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0booooo`;o00001oooool0027ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000booooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0`ooooo`;o
00001oooool0027ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo000?oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool2o`0002oooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02gooooo0_l00007oooo
o`003oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`05ooooo`004?ooool00ol0003oooooooooo`05ooooo`Co0000
1Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo000<ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool01Oooool000cooooo1Ol00007ooooo`Go00001?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000;?ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0:_ooool2o`0000Oooooo000Qoooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00Gooooo000Qooooo`;o0000:Oooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool09oooool2o`0000Oooooo000Qooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Go
oooo000Qooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool0027ooooo0_l0
000Vooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Uooooo`;o00001oooool0027ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`05ooooo`008Oooool2o`0002?ooooo00?o0000ooooooooool0Dooo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02;ooooo0_l00007ooooo`008Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo000Cooooo`?o00001?ooool2o`00
00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`005?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`05ooooo`005?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Cooooo0_l0000Rooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`0Pooooo`;o00001oooool001Cooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool001Co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool01Oooool001?ooooo0_l00004ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`005?ooool00ol0003o
ooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Oo
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Go
oooo000Qooooo`;o00007_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool07Oooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0F?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000Kooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Jooooo`;o0000
1oooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`008Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`1Mooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`05ooooo`008Oooool2o`0001Wooooo00?o0000ooooooooool0GOooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo01Oooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool01Oooool0027ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05oooo
o`008Oooool2o`0001Oooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo01Cooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Gooooo0007ooooo`?o00000_ooool5o`0000?ooooo00?o0000ooooooooool00_oo
ool3o`0000Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`002?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool000Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`002?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool2o`0001Cooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01;ooooo0_l00007
ooooo`002?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool4
o`0000Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`001oooool2o`00
00?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`05ooooo`002?ooool00ol0003oooooooooo`02oooo
o`?o00002?ooool5o`0000Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000
4Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0
3oooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Ooo
ool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00003oooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool03Oooool2o`0000Oo
oooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`1Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool0027ooooo0_l0000<ooooo`03o`000?oooooooooo06[ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`0:ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo06_ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`008Oooool2o`0000Wo
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oo
oooo0_l00007ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo
000Cooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`05ooooo`005?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0Kooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Dooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool2o`0000Oooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`005?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`005?ooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`004oooool2o`0000?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo000Dooooo`04o`00
0?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo000Qooooo`;o00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07?ooooo
00?o0000ooooooooool00_ooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`008Ooooooho`0000Oooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000c
ooooo`?o0000R_ooool00ol0003oooooooooo`0[ooooo`?o00005Oooool00ol0003oooooooooo`0G
ooooo`00=?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Fooooo`00;_ooool3o`0000?ooooo0ol00004ooooo`;o
00000_ooool5o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000ol00007ooooo`?o
00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001_ooool4o`0000;ooooo1Ol000000ooooooo
0000o`000003o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo0ol00004ooooo`?o
00000_ooool3o`000004ooooool0003o0000ooooo`?o00000oooool3o`0000Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02oooo
o`?o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003
ooooo`;o00000_ooool:o`0000Gooooo00?o0000ooooooooool05Oooool002gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00000<
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool0
0004ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool05Oooool002gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool3o`00
00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01_l0003ooooo
ooooool0003oooooo`0000Gooooo1Ol00008ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ool0003oooooo`000002ooooo`?o00000oooool00ol0003oooooo`000002ooooo`Go00000oooool0
1?l0003oooooooooooooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00000_ooool3o`0000Gooooo00?o0000
ooooooooool05Oooool002gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooo
oooooooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000ooo
ool01?l0003oooooooooool00005ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0
003oooooooooo`0Eooooo`00;Oooool01_l0003ooooooooooooooooo0000ooooo`Co00000_ooool4
o`0000;ooooo0ol00004ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool02?ooool0
1?l0003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00009ooooo`05o`000?oo
ooooooooo`000?ooool00ol00004ooooo`Co00000_ooool4o`0000;ooooo0ol00002ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000;ooooo1?l00003ooooo`?o00000oooool3o`0000Wooooo
00?o0000ooooooooool00_ooool6o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000002ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool4o`0000?ooooo
2Ol00003ooooo`?o00000oooool4o`0000Cooooo00?o0000ooooooooool05Oooool002gooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo000^ooooo`?o
00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0ol00009ooooo`Co
00002Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool4o`0000Cooooo00?o0000oooooooo
ool01?ooool2o`0000Cooooo0_l0000^ooooo`03o`000?oooooooooo01Sooooo0ol0000Fooooo`03
o`000?oooooooooo00;ooooo0_l0000;ooooo`03o`000?oooooooooo01Oooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.2762, -1.71975, \
0.0718309, 0.106639}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 2.9862 0.014715 0.606202 [
[.05207 .00222 -15 -9 ]
[.05207 .00222 15 0 ]
[.20138 .00222 -12 -9 ]
[.20138 .00222 12 0 ]
[.35069 .00222 -15 -9 ]
[.35069 .00222 15 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.64931 .00222 -12 -9 ]
[.64931 .00222 12 0 ]
[.79862 .00222 -9 -9 ]
[.79862 .00222 9 0 ]
[.94793 .00222 -12 -9 ]
[.94793 .00222 12 0 ]
[.01131 .13596 -18 -4.5 ]
[.01131 .13596 0 4.5 ]
[.01131 .2572 -18 -4.5 ]
[.01131 .2572 0 4.5 ]
[.01131 .37844 -18 -4.5 ]
[.01131 .37844 0 4.5 ]
[.01131 .49968 -18 -4.5 ]
[.01131 .49968 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05207 .01472 m
.05207 .02097 L
s
[(-0.15)] .05207 .00222 0 1 Mshowa
.20138 .01472 m
.20138 .02097 L
s
[(-0.1)] .20138 .00222 0 1 Mshowa
.35069 .01472 m
.35069 .02097 L
s
[(-0.05)] .35069 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0)] .5 .00222 0 1 Mshowa
.64931 .01472 m
.64931 .02097 L
s
[(0.05)] .64931 .00222 0 1 Mshowa
.79862 .01472 m
.79862 .02097 L
s
[(0.1)] .79862 .00222 0 1 Mshowa
.94793 .01472 m
.94793 .02097 L
s
[(0.15)] .94793 .00222 0 1 Mshowa
.125 Mabswid
.08193 .01472 m
.08193 .01847 L
s
.11179 .01472 m
.11179 .01847 L
s
.14166 .01472 m
.14166 .01847 L
s
.17152 .01472 m
.17152 .01847 L
s
.23124 .01472 m
.23124 .01847 L
s
.2611 .01472 m
.2611 .01847 L
s
.29097 .01472 m
.29097 .01847 L
s
.32083 .01472 m
.32083 .01847 L
s
.38055 .01472 m
.38055 .01847 L
s
.41041 .01472 m
.41041 .01847 L
s
.44028 .01472 m
.44028 .01847 L
s
.47014 .01472 m
.47014 .01847 L
s
.52986 .01472 m
.52986 .01847 L
s
.55972 .01472 m
.55972 .01847 L
s
.58959 .01472 m
.58959 .01847 L
s
.61945 .01472 m
.61945 .01847 L
s
.67917 .01472 m
.67917 .01847 L
s
.70903 .01472 m
.70903 .01847 L
s
.7389 .01472 m
.7389 .01847 L
s
.76876 .01472 m
.76876 .01847 L
s
.82848 .01472 m
.82848 .01847 L
s
.85834 .01472 m
.85834 .01847 L
s
.88821 .01472 m
.88821 .01847 L
s
.91807 .01472 m
.91807 .01847 L
s
.02221 .01472 m
.02221 .01847 L
s
.97779 .01472 m
.97779 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13596 m
.03006 .13596 L
s
[(0.2)] .01131 .13596 1 0 Mshowa
.02381 .2572 m
.03006 .2572 L
s
[(0.4)] .01131 .2572 1 0 Mshowa
.02381 .37844 m
.03006 .37844 L
s
[(0.6)] .01131 .37844 1 0 Mshowa
.02381 .49968 m
.03006 .49968 L
s
[(0.8)] .01131 .49968 1 0 Mshowa
.125 Mabswid
.02381 .04503 m
.02756 .04503 L
s
.02381 .07534 m
.02756 .07534 L
s
.02381 .10565 m
.02756 .10565 L
s
.02381 .16627 m
.02756 .16627 L
s
.02381 .19658 m
.02756 .19658 L
s
.02381 .22689 m
.02756 .22689 L
s
.02381 .28751 m
.02756 .28751 L
s
.02381 .31782 m
.02756 .31782 L
s
.02381 .34813 m
.02756 .34813 L
s
.02381 .40875 m
.02756 .40875 L
s
.02381 .43906 m
.02756 .43906 L
s
.02381 .46937 m
.02756 .46937 L
s
.02381 .52999 m
.02756 .52999 L
s
.02381 .5603 m
.02756 .5603 L
s
.02381 .59061 m
.02756 .59061 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .0236 m
.02558 .02574 L
.02723 .02774 L
.02768 .02828 L
.02816 .02886 L
.02862 .02942 L
.02904 .03049 L
.03005 .03306 L
.03097 .0354 L
.03487 .04584 L
.03678 .05138 L
.03762 .0538 L
.03806 .05509 L
.03853 .05734 L
.039 .0602 L
.03944 .06284 L
.04031 .06807 L
.04224 .07961 L
.04632 .10136 L
.04739 .10689 L
.04768 .10841 L
.04799 .1108 L
.04826 .11373 L
.04855 .11694 L
.05065 .14016 L
.05458 .17559 L
.06263 .27101 L
.06998 .33846 L
.07089 .35127 L
.07134 .35755 L
.07175 .3633 L
.07218 .36588 L
.07264 .3664 L
.07362 .36749 L
.07463 .36861 L
.07568 .36978 L
.07612 .37027 L
.07659 .37079 L
.07687 .37153 L
.07711 .37255 L
.07759 .37453 L
.07937 .38189 L
.08031 .38576 L
.08082 .38788 L
.0813 .38987 L
.08172 .38955 L
.08217 .38651 L
.08312 .38007 L
.0848 .36872 L
.08866 .33341 L
Mistroke
.09287 .28508 L
.09684 .22951 L
.09876 .19321 L
.0996 .1773 L
.10053 .15985 L
.10101 .15256 L
.10147 .14756 L
.10247 .13664 L
.10456 .11367 L
.10655 .09146 L
.10836 .07085 L
.1092 .06124 L
.10965 .05618 L
.11012 .0508 L
.11053 .04737 L
.11098 .04625 L
.11178 .04428 L
.11354 .03996 L
.11402 .03877 L
.11453 .03751 L
.11501 .03632 L
.11545 .03694 L
.11592 .03895 L
.11642 .04112 L
.11733 .04505 L
.11931 .05358 L
.12284 .06998 L
.12388 .0749 L
.12439 .07731 L
.12485 .07963 L
.12534 .08402 L
.12586 .08873 L
.12698 .09873 L
.12882 .11532 L
.12927 .11935 L
.12976 .123 L
.13003 .12397 L
.13029 .12485 L
.13079 .12659 L
.13262 .13298 L
.13362 .13647 L
.13411 .13817 L
.13456 .13904 L
.13497 .13813 L
.13536 .13728 L
.13622 .13539 L
.13805 .13138 L
.14184 .12224 L
.14288 .11963 L
.14345 .1182 L
Mistroke
.14373 .1175 L
.14398 .11687 L
.14443 .11308 L
.14492 .1084 L
.14595 .09846 L
.14777 .081 L
.14825 .0764 L
.1485 .07398 L
.14877 .07142 L
.14926 .06908 L
.14971 .06749 L
.15154 .06102 L
.1524 .05796 L
.15319 .05517 L
.15368 .05346 L
.15413 .05312 L
.15514 .05241 L
.15696 .05113 L
.15746 .05078 L
.15799 .0504 L
.15844 .05008 L
.15894 .05052 L
.16109 .05277 L
.16206 .05379 L
.16253 .05429 L
.16296 .05474 L
.16342 .05587 L
.16391 .05902 L
.16494 .06567 L
.16677 .07752 L
.16758 .08273 L
.16801 .08548 L
.16846 .08703 L
.16896 .08826 L
.16942 .0894 L
.17043 .0919 L
.17152 .09461 L
.17206 .09595 L
.17255 .09718 L
.17302 .09789 L
.17352 .09692 L
.17457 .09487 L
.17641 .09128 L
.18459 .07117 L
.18553 .06527 L
.18653 .05896 L
.18701 .0559 L
.18747 .05358 L
.18789 .05291 L
.18833 .05218 L
Mistroke
.19022 .04913 L
.1912 .04754 L
.19147 .04711 L
.19176 .04664 L
.19203 .04619 L
.19228 .04635 L
.19275 .04777 L
.19327 .04933 L
.19422 .05217 L
.19521 .05516 L
.19627 .05835 L
.19652 .05909 L
.19678 .0599 L
.19727 .0608 L
.19774 .06134 L
.19818 .06183 L
.19995 .06383 L
.20074 .06473 L
.20117 .06522 L
.20158 .06568 L
.20207 .06675 L
.20251 .06805 L
.20337 .07061 L
.20524 .07611 L
.20608 .07859 L
.20656 .07999 L
.20699 .08041 L
.20874 .08183 L
.20966 .08258 L
.21015 .08298 L
.21067 .08341 L
.21093 .08362 L
.21119 .08383 L
.21165 .0826 L
.21209 .08018 L
.21257 .07755 L
.21457 .06652 L
.21549 .06148 L
.21594 .05901 L
.21635 .05737 L
.21678 .05691 L
.21724 .05641 L
.21822 .05534 L
.21913 .05436 L
.21999 .05344 L
.22037 .05303 L
.22076 .05261 L
.22119 .05237 L
.22159 .05247 L
.22341 .05294 L
Mistroke
.22441 .0532 L
.2249 .05333 L
.22535 .05344 L
.22576 .05355 L
.22615 .05356 L
.22656 .05355 L
.22701 .05354 L
.22883 .05351 L
.22978 .05349 L
.23004 .05349 L
.23032 .05348 L
.23058 .05348 L
.23083 .05422 L
.23294 .06269 L
.23477 .07004 L
.23503 .07106 L
.2353 .07216 L
.2358 .07302 L
.23629 .07339 L
.23673 .07373 L
.23855 .07513 L
.23947 .07583 L
.23972 .07602 L
.23999 .07623 L
.24048 .07546 L
.24092 .07343 L
.24141 .07123 L
.24229 .06721 L
.24395 .05969 L
.24441 .05763 L
.2449 .05541 L
.24518 .05458 L
.24543 .05448 L
.24594 .05429 L
.24805 .05348 L
.24901 .05312 L
.24947 .05294 L
.2499 .05278 L
.25035 .05276 L
.25083 .05274 L
.25184 .05269 L
.25369 .0526 L
.25413 .05258 L
.25461 .05256 L
.25489 .05249 L
.25514 .05242 L
.25564 .05227 L
.25745 .05171 L
.25834 .05144 L
.25872 .05132 L
Mistroke
.25914 .05119 L
.25962 .05154 L
.26008 .05325 L
.26108 .05699 L
.26211 .06084 L
.2632 .0649 L
.26366 .06663 L
.26416 .06848 L
.26444 .0691 L
.2647 .06919 L
.26521 .06938 L
.26706 .07007 L
.268 .07042 L
.26847 .07059 L
.26889 .07075 L
.26933 .06983 L
.26981 .06759 L
.27084 .06283 L
.27265 .05438 L
.2731 .05226 L
.27353 .05026 L
.27391 .04846 L
.27433 .04839 L
.27479 .04839 L
.27522 .04839 L
.27617 .0484 L
.27713 .0484 L
.27764 .04841 L
.27818 .04841 L
.27846 .04841 L
.27872 .04841 L
.2792 .04916 L
.28015 .05071 L
.28123 .05245 L
.28224 .05409 L
.28269 .05482 L
.28316 .05559 L
.28341 .05599 L
.28368 .05616 L
.28416 .05596 L
.2859 .05523 L
.28688 .05483 L
.28741 .05461 L
.28768 .0545 L
.28792 .0544 L
.28839 .05428 L
.28864 .05483 L
.28891 .0554 L
.2898 .05735 L
.29141 .06084 L
Mistroke
.29229 .06277 L
.29273 .06372 L
.29314 .0646 L
.29361 .06473 L
.29386 .06476 L
.29413 .0648 L
.29503 .06492 L
.29681 .06517 L
.29732 .06524 L
.2978 .0653 L
.2983 .0638 L
.29857 .06254 L
.29885 .0612 L
.30073 .05229 L
.30186 .0469 L
.30242 .04424 L
.30267 .04307 L
.30294 .04251 L
.30341 .04254 L
.30391 .04256 L
.30496 .04263 L
.30589 .04268 L
.30687 .04274 L
.30711 .04275 L
.30738 .04277 L
.30767 .04306 L
.30794 .04413 L
.30892 .04806 L
.31073 .05526 L
.31121 .05716 L
.31172 .05921 L
.3122 .06113 L
.31264 .06174 L
.31314 .06126 L
.31361 .0608 L
.31467 .05977 L
.31654 .05796 L
.31705 .05746 L
.31733 .05709 L
.31759 .05661 L
.31856 .05481 L
.31971 .05269 L
.32077 .05073 L
.32125 .04985 L
.32169 .04902 L
.32216 .0485 L
.3224 .04869 L
.32267 .04889 L
.32472 .05046 L
.32572 .05122 L
Mistroke
.32621 .0516 L
.32667 .05195 L
.32708 .05207 L
.32752 .05207 L
.32844 .05206 L
.32935 .05204 L
.33031 .05203 L
.33112 .05202 L
.33159 .05201 L
.33202 .05239 L
.33404 .05443 L
.33492 .05533 L
.33538 .0558 L
.33587 .05629 L
.3363 .05673 L
.33677 .05884 L
.3376 .06403 L
.33924 .07425 L
.34013 .07985 L
.34063 .08294 L
.3411 .08587 L
.34153 .08677 L
.342 .08645 L
.34283 .08588 L
.34381 .08522 L
.34487 .08449 L
.34535 .08416 L
.34562 .08398 L
.34587 .08381 L
.3463 .08203 L
.34678 .07852 L
.34862 .06503 L
.34952 .0584 L
.35035 .05228 L
.35082 .04882 L
.35132 .04777 L
.35182 .04713 L
.35237 .04643 L
.35422 .04409 L
.35524 .04278 L
.35554 .04241 L
.35582 .04218 L
.35607 .04213 L
.35635 .04208 L
.35835 .04171 L
.35932 .04152 L
.35983 .04143 L
.36011 .04137 L
.36037 .04133 L
.36085 .04048 L
Mistroke
.36137 .03922 L
.36228 .03699 L
.36411 .03253 L
.36454 .03147 L
.36501 .03034 L
.3654 .0295 L
.36584 .02908 L
.36681 .02815 L
.36786 .02715 L
.36882 .02623 L
.36924 .02583 L
.3697 .02539 L
.3702 .02527 L
.37047 .02647 L
.37072 .02758 L
.37183 .03243 L
.37383 .04121 L
.37575 .05193 L
.37784 .0669 L
.3788 .07377 L
.37932 .07753 L
.37981 .08058 L
.38022 .08019 L
.38067 .07976 L
.38162 .07887 L
.38253 .07801 L
.38352 .07708 L
.38397 .07665 L
.38446 .07619 L
.38491 .07614 L
.38532 .0762 L
.38694 .07643 L
.38779 .07654 L
.3887 .07667 L
.38896 .07671 L
.38921 .07674 L
.38967 .07464 L
.3901 .07156 L
.39057 .06822 L
.39253 .05418 L
.39342 .04785 L
.3939 .04438 L
.39436 .04199 L
.39475 .0411 L
.39516 .04013 L
.39605 .03808 L
.3971 .03565 L
.39807 .03339 L
.39856 .03225 L
.39883 .03162 L
Mistroke
.39908 .03185 L
.39936 .03361 L
.39965 .03552 L
.40019 .03899 L
.40399 .06503 L
.40588 .09391 L
.40692 .10981 L
.40743 .11764 L
.40791 .12489 L
.40835 .13168 L
.40882 .1345 L
.4093 .13199 L
.40982 .12921 L
.41157 .11994 L
.41252 .11492 L
.41302 .11228 L
.41327 .11095 L
.41354 .1082 L
.41404 .10019 L
.41451 .09272 L
.41539 .07852 L
.41741 .04622 L
.41796 .03738 L
.41824 .033 L
.41854 .03233 L
.41959 .03005 L
.42059 .02788 L
.42166 .02555 L
.42218 .02442 L
.42267 .02335 L
.42311 .02357 L
.42359 .03069 L
.42542 .05768 L
.42643 .07249 L
.42737 .08644 L
.42782 .09307 L
.4283 .0963 L
.42882 .0996 L
.4293 .10263 L
.43104 .11367 L
.43183 .11863 L
.43226 .12137 L
.43267 .1238 L
.43315 .11878 L
.43359 .11421 L
.43445 .10526 L
.43635 .0855 L
.43813 .0695 L
.43999 .05728 L
.44099 .05071 L
Mistroke
.44153 .04712 L
.4418 .04538 L
.44204 .04379 L
.44245 .04241 L
.44288 .04291 L
.4438 .04398 L
.44542 .04585 L
.44632 .0469 L
.44656 .04718 L
.44682 .04748 L
.44729 .04946 L
.44773 .05307 L
.44813 .05644 L
.44906 .06411 L
.45096 .07984 L
.45148 .08415 L
.45176 .08652 L
.45203 .08756 L
.45228 .08738 L
.45255 .08719 L
.45303 .08686 L
.45486 .08557 L
.45586 .08487 L
.45635 .08453 L
.45679 .08413 L
.45723 .0834 L
.45764 .08271 L
.45855 .08119 L
.45955 .07951 L
.46047 .07796 L
.46088 .07728 L
.46126 .07664 L
.46166 .07504 L
.46209 .07135 L
.46386 .05647 L
.46477 .04875 L
.46574 .04052 L
.46603 .03808 L
.4663 .03578 L
.46655 .03649 L
.46681 .0376 L
.46781 .0418 L
.47156 .05735 L
.47521 .07 L
.47862 .0853 L
.47952 .08957 L
.47996 .09168 L
.48036 .09363 L
.48083 .09467 L
.48108 .09185 L
Mistroke
.48134 .08884 L
.48224 .07864 L
.48322 .06737 L
.48429 .05522 L
.48477 .04963 L
.48504 .04659 L
.48529 .04375 L
.48573 .04058 L
.48621 .04068 L
.48821 .04113 L
.48908 .04133 L
.48954 .04143 L
.49002 .04154 L
.49028 .0416 L
.49057 .04224 L
.49107 .0439 L
.49206 .04717 L
.49423 .05437 L
.49469 .05587 L
.49511 .05728 L
.4956 .06132 L
.49605 .0654 L
.49708 .0748 L
.49803 .08352 L
.49887 .09124 L
.49933 .09545 L
.49976 .09938 L
.50023 .09918 L
.50048 .09662 L
.50074 .09388 L
.50164 .08458 L
.50275 .07299 L
.50381 .06201 L
.50427 .05724 L
.50476 .05216 L
.50502 .05121 L
.5053 .0506 L
.50579 .04952 L
.50761 .04557 L
.50864 .04333 L
.50914 .04224 L
.50959 .04125 L
.51006 .04155 L
.5105 .0419 L
.51147 .04269 L
.5125 .04352 L
.51345 .04429 L
.51387 .04463 L
.51427 .04496 L
.51468 .04786 L
Mistroke
.51514 .05285 L
.51697 .07293 L
.518 .08418 L
.51851 .08972 L
.51898 .09486 L
.5194 .09668 L
.51985 .09376 L
.52081 .08759 L
.52295 .07371 L
.52341 .07077 L
.52389 .06763 L
.52417 .06631 L
.52443 .06568 L
.52492 .06444 L
.52666 .06013 L
.52848 .05558 L
.53033 .04939 L
.5313 .04591 L
.53233 .04222 L
.53275 .04069 L
.53321 .03904 L
.53371 .03779 L
.53419 .04198 L
.5359 .05724 L
.53754 .07178 L
.53801 .07597 L
.53846 .07991 L
.53885 .08014 L
.53928 .08015 L
.54128 .08018 L
.54217 .08019 L
.54263 .0802 L
.54313 .08021 L
.54342 .08038 L
.54369 .08072 L
.5442 .08139 L
.54532 .08284 L
.54637 .0842 L
.54683 .08479 L
.54734 .08545 L
.54781 .08606 L
.54825 .08515 L
.54872 .08115 L
.54922 .07683 L
.55127 .05925 L
.55221 .05112 L
.55269 .04704 L
.55296 .04515 L
.55321 .04517 L
.55499 .04536 L
Mistroke
.55593 .04545 L
.55691 .04555 L
.55716 .04558 L
.55743 .04561 L
.55772 .04566 L
.558 .04727 L
.559 .0531 L
.56094 .06442 L
.5619 .06999 L
.56236 .07271 L
.56278 .07641 L
.56364 .08563 L
.56456 .09543 L
.56548 .1054 L
.56649 .11617 L
.56693 .12092 L
.56739 .12493 L
.56779 .12172 L
.56823 .1182 L
.56987 .10497 L
.57369 .06569 L
.57558 .04026 L
.5764 .02909 L
.57687 .02273 L
.57731 .02255 L
.57778 .02388 L
.57828 .02531 L
.57931 .02823 L
.58037 .03124 L
.58095 .03287 L
.58123 .03367 L
.58149 .0344 L
.58195 .03814 L
.58244 .04634 L
.58347 .06369 L
.58529 .09412 L
.58575 .10187 L
.58624 .11017 L
.58671 .11618 L
.58714 .11745 L
.58807 .12021 L
.5891 .12325 L
.58996 .1258 L
.59042 .12715 L
.5909 .12858 L
.59132 .12983 L
.59179 .12403 L
.59261 .11168 L
.59458 .08212 L
.59561 .06659 L
Mistroke
.59588 .0625 L
.59617 .05812 L
.59645 .05635 L
.5967 .05496 L
.59765 .04967 L
.5987 .04388 L
.59965 .03863 L
.60008 .03626 L
.60054 .03371 L
.601 .03117 L
.60142 .03234 L
.60238 .0353 L
.60434 .04127 L
.6052 .0439 L
.60565 .04528 L
.60613 .04776 L
.60702 .0533 L
.60784 .05843 L
.60887 .06486 L
.60941 .06824 L
.60998 .07181 L
.61048 .07494 L
.61076 .07587 L
.61103 .07584 L
.61199 .07573 L
.61381 .07553 L
.61434 .07548 L
.61483 .07542 L
.61528 .07537 L
.61576 .07571 L
.61622 .07623 L
.61665 .07671 L
.61761 .07779 L
.61934 .07974 L
.61979 .08024 L
.62026 .08065 L
.62054 .07859 L
.62079 .07671 L
.62127 .07304 L
.6233 .0577 L
.62426 .05043 L
.62478 .04645 L
.62528 .04346 L
.62553 .04239 L
.62581 .04123 L
.62639 .03878 L
.62742 .03447 L
.62846 .0301 L
.62897 .02794 L
.62945 .02594 L
Mistroke
.62988 .02418 L
.63034 .02474 L
.6313 .02591 L
.64717 .04695 L
.65105 .06442 L
.65208 .07215 L
.65317 .08041 L
.65343 .08234 L
.6537 .08442 L
.6542 .08595 L
.65469 .08573 L
.65514 .08554 L
.65681 .08482 L
.65769 .08444 L
.65818 .08423 L
.65864 .08403 L
.65914 .08153 L
.6596 .07877 L
.6605 .07336 L
.66153 .06714 L
.66247 .0615 L
.6629 .05887 L
.66337 .05603 L
.66382 .05491 L
.66423 .05473 L
.66611 .05394 L
.66776 .05324 L
.66816 .05307 L
.66859 .05297 L
.66906 .05295 L
.6695 .05293 L
.67049 .05288 L
.67156 .05282 L
.67205 .0528 L
.67258 .05277 L
.67302 .05275 L
.67352 .05235 L
.67527 .05044 L
.67626 .04936 L
.67674 .04883 L
.67718 .04835 L
.67765 .04784 L
.67808 .04773 L
.67855 .04873 L
.67905 .04981 L
.68102 .05404 L
.68191 .05595 L
.6824 .057 L
.68286 .05787 L
.68324 .05815 L
Mistroke
.68366 .05845 L
.68455 .05909 L
.68557 .05983 L
.6861 .06022 L
.68668 .06063 L
.68696 .06084 L
.68723 .06103 L
.68773 .06075 L
.68819 .05887 L
.6887 .05685 L
.69066 .04897 L
.69162 .04512 L
.69207 .0433 L
.69249 .04202 L
.69292 .0422 L
.69339 .0424 L
.69424 .04275 L
.69612 .04353 L
.69656 .04372 L
.69704 .04392 L
.69731 .04447 L
.69756 .04566 L
.69805 .04799 L
.7001 .05773 L
.701 .06204 L
.7015 .0644 L
.70197 .06663 L
.70224 .06668 L
.70252 .06642 L
.70303 .06597 L
.70401 .06509 L
.70504 .06417 L
.70614 .06319 L
.7064 .06296 L
.70667 .06271 L
.70694 .06238 L
.70718 .06192 L
.70813 .06015 L
.70984 .05695 L
.71076 .05524 L
.71124 .05435 L
.7115 .05386 L
.71174 .05366 L
.71199 .05383 L
.71226 .054 L
.71273 .05432 L
.71367 .05493 L
.71472 .05563 L
.71523 .05597 L
.71571 .05629 L
Mistroke
.71618 .0566 L
.71669 .05637 L
.71719 .05549 L
.71774 .05453 L
.71959 .05133 L
.72062 .04954 L
.72092 .04903 L
.7212 .04854 L
.72145 .04846 L
.72173 .0485 L
.72373 .0488 L
.72471 .04894 L
.72522 .04902 L
.7255 .04906 L
.72576 .0491 L
.72623 .04991 L
.72648 .05111 L
.72675 .05238 L
.72767 .05673 L
.72937 .06485 L
.73027 .06913 L
.73073 .07129 L
.73123 .07163 L
.73151 .07132 L
.73181 .07099 L
.73235 .0704 L
.73338 .06927 L
.73437 .06818 L
.73491 .06759 L
.73541 .06704 L
.73587 .06612 L
.73636 .06443 L
.7374 .06086 L
.73922 .05459 L
.73973 .05284 L
.74021 .0512 L
.74071 .05034 L
.74097 .05054 L
.74125 .05074 L
.74312 .05213 L
.74426 .05296 L
.74482 .05337 L
.74509 .05357 L
.74534 .05374 L
.7458 .05369 L
.7463 .05365 L
.74736 .05355 L
.74828 .05346 L
.74926 .05337 L
.74977 .05333 L
Mistroke
.75006 .0533 L
.75033 .05337 L
.75131 .05375 L
.75225 .05411 L
.75325 .05448 L
.7541 .05481 L
.75458 .05499 L
.75503 .0556 L
.75551 .05782 L
.75596 .05985 L
.75695 .06443 L
.75794 .06901 L
.75847 .07144 L
.75903 .07402 L
.7593 .07527 L
.75955 .07645 L
.76003 .07687 L
.76048 .07621 L
.76096 .07549 L
.7628 .07275 L
.76373 .07138 L
.76418 .07071 L
.7646 .07 L
.76503 .0684 L
.7655 .06669 L
.76649 .06305 L
.7681 .05715 L
.76854 .05553 L
.76902 .05378 L
.76947 .05257 L
.76988 .05275 L
.77171 .05356 L
.77264 .05398 L
.77313 .05419 L
.77365 .05443 L
.77411 .05463 L
.77453 .05453 L
.77495 .05438 L
.77535 .05424 L
.77714 .0536 L
.7781 .05326 L
.77859 .05309 L
.77886 .05299 L
.77912 .05311 L
.77957 .05366 L
.77999 .05416 L
.78094 .05529 L
.78195 .0565 L
.78248 .05713 L
.78305 .05781 L
Mistroke
.78333 .05815 L
.78359 .05846 L
.78409 .06032 L
.78455 .06285 L
.78505 .06558 L
.7868 .07514 L
.78776 .0804 L
.78824 .08299 L
.78868 .08484 L
.78893 .08443 L
.78919 .084 L
.78975 .08308 L
.79073 .08148 L
.79265 .07834 L
.80068 .0624 L
.80159 .06152 L
.80242 .06071 L
.80285 .0603 L
.8033 .05934 L
.80426 .05658 L
.80627 .05077 L
.80673 .04942 L
.80723 .048 L
.80765 .04679 L
.80811 .04679 L
.80857 .04778 L
.80901 .04871 L
.80999 .05078 L
.81091 .05275 L
.81176 .05455 L
.81215 .05538 L
.81258 .05629 L
.81298 .05848 L
.81336 .06077 L
.81508 .07126 L
.81602 .07704 L
.81702 .08314 L
.81727 .08468 L
.81754 .08586 L
.81784 .08593 L
.81811 .08599 L
.81912 .08622 L
.82014 .08646 L
.82111 .08669 L
.82153 .08678 L
.82198 .08689 L
.82247 .08737 L
.82292 .08834 L
.82454 .09182 L
.82544 .09373 L
Mistroke
.82629 .09556 L
.82677 .09658 L
.82704 .09716 L
.8273 .09657 L
.82821 .09373 L
.83001 .08817 L
.83349 .07274 L
.8354 .06131 L
.83587 .05845 L
.83633 .05573 L
.83673 .05347 L
.83717 .05329 L
.8381 .05289 L
.8391 .05246 L
.84012 .05202 L
.84068 .05178 L
.84096 .05167 L
.84121 .05156 L
.84165 .05154 L
.84212 .05193 L
.84314 .05275 L
.84492 .05421 L
.84539 .0546 L
.84566 .05481 L
.8459 .05501 L
.84638 .05558 L
.84682 .05723 L
.84889 .06512 L
.84987 .06882 L
.8504 .07084 L
.8509 .07274 L
.85116 .07389 L
.85144 .07653 L
.85203 .08216 L
.85308 .09206 L
.85406 .10141 L
.85513 .1116 L
.85563 .11626 L
.8559 .11886 L
.85615 .11953 L
.85663 .12023 L
.85709 .12088 L
.85899 .12359 L
.85992 .12491 L
.86032 .12549 L
.86076 .12612 L
.8612 .12717 L
.86162 .12816 L
.86254 .13033 L
.86449 .13495 L
Mistroke
.865 .13616 L
.86548 .1373 L
.86598 .13563 L
.86653 .1332 L
.86842 .12487 L
.87181 .10405 L
.87358 .08909 L
.87455 .08087 L
.87503 .07684 L
.87546 .07431 L
.87594 .07226 L
.87646 .07004 L
.87736 .06617 L
.87912 .05861 L
.88102 .05093 L
.88203 .04709 L
.88311 .04297 L
.88366 .04091 L
.88417 .03895 L
.88463 .03719 L
.88513 .03763 L
.88561 .03917 L
.88611 .04081 L
.88702 .04375 L
.88797 .04682 L
.88899 .05012 L
.88927 .05105 L
.88957 .05202 L
.88983 .05468 L
.8901 .05797 L
.89116 .07034 L
.89531 .11816 L
.89736 .13965 L
.89825 .14909 L
.89873 .15409 L
.89899 .15685 L
.89924 .15957 L
.8997 .16849 L
.90013 .17665 L
.90095 .19264 L
.90277 .22769 L
.90659 .28001 L
.91004 .31782 L
.91192 .33902 L
.91285 .34942 L
.91326 .35398 L
.9137 .35872 L
.91419 .36118 L
.91472 .36378 L
.91581 .36925 L
Mistroke
.91681 .37425 L
.91772 .3788 L
.9182 .38119 L
.91866 .38184 L
.91913 .38007 L
.91965 .37815 L
.92146 .37149 L
.92237 .36812 L
.92287 .36628 L
.92333 .36465 L
.92383 .36369 L
.92438 .36265 L
.92535 .36081 L
.92711 .35744 L
.92762 .35647 L
.9281 .35547 L
.92853 .34952 L
.92899 .34307 L
.93084 .3175 L
.93185 .30351 L
.93235 .29668 L
.9328 .29043 L
.9333 .28671 L
.93384 .28358 L
.93499 .27692 L
.93604 .27078 L
.937 .26522 L
.93745 .26259 L
.93794 .25759 L
.9384 .25055 L
.93882 .24408 L
.94076 .21443 L
.94164 .20099 L
.94207 .19444 L
.94246 .18848 L
.94287 .1854 L
.94331 .18268 L
.94425 .17694 L
.9462 .16498 L
.94831 .14701 L
.95029 .12477 L
.95127 .11389 L
.95169 .10913 L
.95215 .10402 L
.95261 .10197 L
.95304 .10007 L
.95388 .09631 L
.95575 .08802 L
.95971 .0656 L
.96066 .05966 L
Mistroke
.96117 .05653 L
.96144 .05483 L
.9617 .05323 L
.96217 .05187 L
.96268 .05062 L
.96358 .04843 L
.96575 .04314 L
.96772 .03806 L
.96999 .03193 L
.97053 .03047 L
.97111 .02892 L
.9716 .02798 L
.97188 .0277 L
.97215 .02745 L
.97408 .02557 L
.97619 .02352 L
Mfstroke
1 0 0 r
.02381 .01473 m
.03097 .01472 L
.03187 .01473 L
.03235 .01473 L
.03285 .01473 L
.03329 .01473 L
.03377 .01473 L
.03421 .01473 L
.03462 .01473 L
.03561 .01473 L
.03667 .01472 L
.03717 .01472 L
.03764 .01472 L
.03806 .01472 L
.03853 .01472 L
.0388 .01472 L
.03905 .01472 L
.03952 .01472 L
.04058 .01473 L
.04158 .01473 L
.04201 .01473 L
.04249 .01473 L
.04294 .01474 L
.04336 .01473 L
.0438 .01473 L
.04427 .01473 L
.04619 .01472 L
.04727 .01472 L
.04756 .01472 L
.04788 .01472 L
.04815 .01472 L
.04844 .01472 L
.05058 .01473 L
.05157 .01473 L
.05209 .01473 L
.05238 .01474 L
.05264 .01474 L
.05312 .01473 L
.05365 .01473 L
.05458 .01473 L
.0565 .01472 L
.05703 .01472 L
.0573 .01472 L
.05759 .01472 L
.05784 .01472 L
.0581 .01472 L
.05859 .01472 L
.06053 .01473 L
.06149 .01473 L
.06195 .01474 L
Mistroke
.06237 .01474 L
.06281 .01473 L
.06323 .01473 L
.06414 .01473 L
.06515 .01472 L
.06607 .01472 L
.06648 .01472 L
.06686 .01472 L
.06726 .01472 L
.0677 .01472 L
.06945 .01473 L
.07038 .01473 L
.07137 .01474 L
.07161 .01474 L
.07188 .01474 L
.07217 .01474 L
.07245 .01474 L
.07345 .01473 L
.07529 .01472 L
.07621 .01472 L
.07646 .01472 L
.07674 .01472 L
.07722 .01472 L
.07916 .01473 L
.08 .01473 L
.08045 .01473 L
.08091 .01474 L
.08135 .01474 L
.08182 .01474 L
.08225 .01474 L
.08265 .01473 L
.0843 .01473 L
.08522 .01472 L
.08572 .01472 L
.0862 .01472 L
.08644 .01472 L
.08671 .01472 L
.08727 .01472 L
.08827 .01473 L
.08923 .01473 L
.09024 .01474 L
.09065 .01474 L
.0911 .01474 L
.09158 .01474 L
.09204 .01474 L
.09394 .01473 L
.09488 .01472 L
.09529 .01472 L
.09574 .01472 L
.09615 .01472 L
Mistroke
.09652 .01472 L
.09735 .01472 L
.09911 .01473 L
.10002 .01474 L
.10029 .01474 L
.10053 .01474 L
.101 .01474 L
.10127 .01474 L
.10151 .01474 L
.10207 .01473 L
.10306 .01473 L
.10401 .01472 L
.10489 .01472 L
.10534 .01472 L
.10581 .01472 L
.10609 .01472 L
.10634 .01472 L
.10682 .01472 L
.10846 .01473 L
.10936 .01474 L
.1098 .01474 L
.11021 .01474 L
.11064 .01474 L
.11111 .01474 L
.11212 .01473 L
.11388 .01472 L
.11437 .01472 L
.11483 .01472 L
.11524 .01472 L
.11569 .01472 L
.11762 .01473 L
.1185 .01473 L
.11898 .01474 L
.11943 .01474 L
.11981 .01474 L
.12023 .01474 L
.12068 .01474 L
.1211 .01474 L
.12304 .01473 L
.12357 .01472 L
.12413 .01472 L
.12441 .01472 L
.12466 .01472 L
.12515 .01472 L
.12561 .01472 L
.12611 .01472 L
.12699 .01473 L
.12802 .01474 L
.12852 .01474 L
.12899 .01474 L
Mistroke
.12943 .01474 L
.1299 .01474 L
.13037 .01474 L
.13088 .01474 L
.13261 .01473 L
.13357 .01472 L
.13385 .01472 L
.13412 .01472 L
.13461 .01472 L
.13508 .01472 L
.13551 .01472 L
.13649 .01473 L
.1374 .01473 L
.13826 .01474 L
.13864 .01474 L
.13903 .01475 L
.13947 .01475 L
.13987 .01474 L
.14172 .01473 L
.14264 .01472 L
.14348 .01472 L
.14392 .01472 L
.14438 .01472 L
.14485 .01472 L
.14537 .01472 L
.14709 .01474 L
.14805 .01474 L
.14831 .01474 L
.14859 .01475 L
.14908 .01475 L
.14955 .01474 L
.14998 .01474 L
.15096 .01473 L
.15187 .01473 L
.15272 .01472 L
.1531 .01472 L
.1535 .01472 L
.15393 .01472 L
.15433 .01472 L
.15622 .01473 L
.15711 .01474 L
.15794 .01475 L
.15837 .01475 L
.15882 .01475 L
.15908 .01475 L
.15933 .01474 L
.15978 .01474 L
.16153 .01473 L
.16244 .01472 L
.16293 .01472 L
Mistroke
.16339 .01472 L
.16389 .01472 L
.16443 .01472 L
.16539 .01473 L
.1663 .01474 L
.16716 .01474 L
.16753 .01475 L
.16793 .01475 L
.16836 .01475 L
.16876 .01475 L
.17064 .01473 L
.17154 .01473 L
.17237 .01472 L
.17277 .01472 L
.1732 .01472 L
.17368 .01472 L
.17411 .01472 L
.17595 .01474 L
.1769 .01475 L
.17716 .01475 L
.17743 .01475 L
.17793 .01475 L
.17839 .01475 L
.17882 .01475 L
.1798 .01474 L
.1807 .01473 L
.18155 .01472 L
.18193 .01472 L
.18232 .01472 L
.18276 .01472 L
.18316 .01472 L
.18504 .01474 L
.18593 .01474 L
.18633 .01475 L
.18676 .01475 L
.1872 .01476 L
.18759 .01475 L
.18806 .01475 L
.1885 .01475 L
.19033 .01473 L
.19122 .01472 L
.19171 .01472 L
.19217 .01472 L
.19266 .01472 L
.19321 .01472 L
.19417 .01473 L
.19507 .01474 L
.19592 .01475 L
.19629 .01475 L
.19669 .01476 L
Mistroke
.19712 .01476 L
.19752 .01475 L
.19928 .01474 L
.20023 .01473 L
.20113 .01472 L
.2016 .01472 L
.2021 .01472 L
.20239 .01472 L
.20266 .01472 L
.20317 .01473 L
.20505 .01475 L
.20556 .01475 L
.2061 .01476 L
.20657 .01476 L
.20683 .01476 L
.20708 .01476 L
.20929 .01474 L
.21023 .01473 L
.21074 .01472 L
.21122 .01472 L
.21163 .01472 L
.21206 .01472 L
.21299 .01473 L
.21406 .01474 L
.21508 .01475 L
.21552 .01476 L
.21599 .01476 L
.21623 .01476 L
.2165 .01476 L
.21697 .01476 L
.21896 .01474 L
.21994 .01473 L
.22041 .01472 L
.22085 .01472 L
.22127 .01472 L
.22167 .01472 L
.22254 .01473 L
.22438 .01475 L
.22535 .01476 L
.22584 .01477 L
.22612 .01477 L
.22638 .01476 L
.22821 .01474 L
.22924 .01473 L
.22974 .01473 L
.23021 .01472 L
.23047 .01472 L
.23074 .01472 L
.23102 .01472 L
.23132 .01472 L
Mistroke
.23234 .01474 L
.23329 .01475 L
.23432 .01476 L
.23479 .01476 L
.23529 .01477 L
.23577 .01477 L
.2362 .01476 L
.23804 .01474 L
.23884 .01473 L
.23973 .01472 L
.24022 .01472 L
.24069 .01472 L
.2417 .01473 L
.24281 .01475 L
.24382 .01476 L
.24428 .01477 L
.24478 .01477 L
.24525 .01477 L
.24568 .01477 L
.24768 .01474 L
.24854 .01473 L
.24944 .01472 L
.24992 .01472 L
.25018 .01472 L
.25043 .01472 L
.25134 .01474 L
.25311 .01476 L
.25398 .01477 L
.25436 .01478 L
.25478 .01478 L
.25525 .01477 L
.25574 .01477 L
.25677 .01475 L
.25858 .01473 L
.25882 .01472 L
.25909 .01472 L
.25959 .01472 L
.25988 .01472 L
.26015 .01472 L
.26067 .01473 L
.26263 .01476 L
.26357 .01478 L
.26405 .01478 L
.26432 .01479 L
.26457 .01478 L
.26566 .01477 L
.26666 .01475 L
.2676 .01474 L
.26849 .01472 L
.26899 .01472 L
Mistroke
.26926 .01472 L
.26952 .01472 L
.27046 .01474 L
.27223 .01477 L
.2731 .01478 L
.27348 .01479 L
.2739 .01479 L
.2743 .01479 L
.27473 .01478 L
.27563 .01477 L
.27755 .01473 L
.27802 .01473 L
.27852 .01472 L
.27878 .01472 L
.27906 .01472 L
.27956 .01473 L
.28147 .01476 L
.28235 .01478 L
.28284 .01479 L
.28331 .0148 L
.28374 .0148 L
.28421 .01479 L
.28503 .01477 L
.28703 .01474 L
.28761 .01473 L
.2879 .01472 L
.28816 .01472 L
.28864 .01472 L
.2889 .01473 L
.28917 .01473 L
.29118 .01477 L
.29213 .01479 L
.29255 .0148 L
.29301 .0148 L
.29344 .0148 L
.2939 .01479 L
.29487 .01477 L
.29664 .01474 L
.29713 .01473 L
.2976 .01472 L
.29786 .01472 L
.29814 .01472 L
.29864 .01473 L
.30051 .01477 L
.30142 .01479 L
.30227 .01481 L
.30274 .01482 L
.30301 .01481 L
.30325 .01481 L
.30414 .01479 L
Mistroke
.3059 .01475 L
.30667 .01474 L
.30707 .01473 L
.30751 .01472 L
.30798 .01472 L
.30842 .01473 L
.3093 .01475 L
.31028 .01478 L
.31121 .0148 L
.31201 .01482 L
.31245 .01483 L
.31286 .01482 L
.31468 .01477 L
.31556 .01475 L
.31651 .01473 L
.31679 .01473 L
.31705 .01472 L
.31754 .01472 L
.31801 .01474 L
.31851 .01475 L
.31952 .01477 L
.3206 .0148 L
.32112 .01482 L
.32161 .01483 L
.32206 .01484 L
.32255 .01483 L
.32429 .01478 L
.32525 .01476 L
.32615 .01473 L
.3264 .01473 L
.32667 .01472 L
.32696 .01472 L
.32723 .01473 L
.32821 .01476 L
.33012 .01481 L
.33107 .01484 L
.33135 .01485 L
.33161 .01485 L
.3321 .01484 L
.33394 .01479 L
.33492 .01476 L
.33595 .01473 L
.33621 .01472 L
.33649 .01472 L
.3368 .01473 L
.33708 .01474 L
.33813 .01477 L
.3399 .01483 L
.34041 .01484 L
.34089 .01486 L
Mistroke
.34132 .01487 L
.34179 .01486 L
.34386 .01479 L
.34485 .01476 L
.34534 .01474 L
.34578 .01473 L
.34625 .01472 L
.34675 .01474 L
.34782 .01478 L
.34885 .01482 L
.34997 .01486 L
.35047 .01488 L
.35072 .01489 L
.351 .01489 L
.35149 .01487 L
.35195 .01485 L
.35382 .01479 L
.35469 .01475 L
.35516 .01474 L
.35561 .01472 L
.35586 .01472 L
.35614 .01473 L
.35662 .01476 L
.35756 .01479 L
.35856 .01484 L
.35961 .01488 L
.36004 .0149 L
.36051 .01492 L
.36078 .01491 L
.36102 .0149 L
.3615 .01488 L
.36323 .0148 L
.36414 .01477 L
.36464 .01475 L
.36511 .01473 L
.36556 .01473 L
.36605 .01475 L
.36689 .01479 L
.36855 .01487 L
.36945 .01492 L
.36971 .01493 L
.36996 .01494 L
.37042 .01494 L
.37086 .01492 L
.37126 .0149 L
.37217 .01485 L
.37317 .0148 L
.3741 .01476 L
.37457 .01474 L
.37483 .01472 L
Mistroke
.37507 .01472 L
.37532 .01474 L
.3756 .01475 L
.37615 .01479 L
.37816 .0149 L
.37874 .01494 L
.37928 .01497 L
.37977 .01499 L
.38005 .01498 L
.38031 .01496 L
.38217 .01485 L
.3832 .0148 L
.3837 .01477 L
.38417 .01474 L
.38462 .01472 L
.3851 .01475 L
.38611 .01482 L
.38787 .01494 L
.38832 .01498 L
.3888 .01501 L
.38926 .01504 L
.38968 .01503 L
.39006 .015 L
.39048 .01497 L
.39133 .01491 L
.39234 .01484 L
.39329 .01478 L
.39382 .01474 L
.39412 .01472 L
.39439 .01474 L
.39488 .01478 L
.3954 .01482 L
.39738 .01498 L
.39783 .01502 L
.39832 .01506 L
.39877 .0151 L
.39919 .0151 L
.39964 .01507 L
.40007 .01503 L
.40103 .01495 L
.40277 .01481 L
.40324 .01477 L
.40374 .01473 L
.40416 .01476 L
.40462 .01481 L
.40663 .01501 L
.40752 .01511 L
.40796 .01515 L
.40837 .01519 L
.40883 .0152 L
Mistroke
.40908 .01517 L
.40934 .01514 L
.41023 .01505 L
.41187 .01488 L
.4123 .01484 L
.41276 .01479 L
.4132 .01475 L
.4136 .01475 L
.41405 .01481 L
.41449 .01486 L
.41546 .01499 L
.41716 .01522 L
.41763 .01528 L
.41812 .01535 L
.41854 .01532 L
.41901 .01526 L
.42101 .01499 L
.4219 .01488 L
.42234 .01482 L
.42274 .01477 L
.42321 .01476 L
.42345 .0148 L
.42372 .01484 L
.42461 .015 L
.42624 .01529 L
.42714 .01545 L
.42757 .01552 L
.42797 .01555 L
.42844 .01547 L
.42895 .01538 L
.43002 .01519 L
.43099 .01502 L
.4319 .01486 L
.4324 .01478 L
.43266 .01473 L
.43294 .0148 L
.43408 .01507 L
.43515 .01534 L
.43614 .01558 L
.43707 .0158 L
.43754 .01588 L
.4378 .01582 L
.43805 .01576 L
.44011 .01526 L
.44103 .01504 L
.44149 .01493 L
.4419 .01483 L
.44239 .01477 L
.44264 .01486 L
.44291 .01496 L
Mistroke
.44383 .01529 L
.44471 .0156 L
.44567 .01594 L
.44612 .0161 L
.44658 .01626 L
.44698 .01641 L
.44743 .01633 L
.44793 .01615 L
.44847 .01596 L
.44945 .01561 L
.45033 .0153 L
.45079 .01513 L
.45129 .01496 L
.45177 .01479 L
.45221 .01492 L
.45265 .01516 L
.45306 .01539 L
.45493 .01643 L
.45571 .01687 L
.45614 .0171 L
.45653 .01733 L
.45696 .01728 L
.45744 .01702 L
.45827 .01656 L
.46016 .0155 L
.46068 .01522 L
.46097 .01506 L
.46123 .01491 L
.46148 .01477 L
.46175 .01498 L
.46223 .01544 L
.46406 .0172 L
.46505 .01817 L
.46554 .01864 L
.46599 .01907 L
.46642 .01932 L
.46683 .01892 L
.46774 .01804 L
.46966 .01619 L
.47045 .01543 L
.47084 .01504 L
.47128 .01504 L
.47175 .01598 L
.4722 .01685 L
.47304 .01853 L
.47483 .02207 L
.47532 .02304 L
.47559 .02358 L
.47585 .02408 L
.47634 .02351 L
Mistroke
.47679 .02262 L
.47884 .01856 L
.47974 .01678 L
.48022 .01583 L
.48048 .01531 L
.48073 .01482 L
.48118 .01713 L
.48158 .01944 L
.48238 .02395 L
.48412 .03383 L
.48456 .03634 L
.48503 .03901 L
.48547 .04152 L
.48587 .04039 L
.48634 .03769 L
.48686 .03479 L
.48778 .02952 L
.48869 .02437 L
.48919 .02153 L
.48966 .01885 L
.4901 .01635 L
.49058 .02512 L
.49101 .04766 L
.49141 .06849 L
.49539 .27978 L
.49741 .42874 L
.49839 .50163 L
.49929 .56838 L
.49975 .60257 L
.50024 .60332 L
.50072 .56723 L
.50126 .52782 L
.50342 .36729 L
.50544 .23168 L
.50735 .13274 L
.50818 .08955 L
.50906 .0439 L
.50952 .02004 L
.50978 .01567 L
.51002 .01706 L
.51091 .0221 L
.51186 .02748 L
.51289 .03334 L
.51336 .03602 L
.51386 .03887 L
.51429 .0413 L
.51476 .0402 L
.51504 .03861 L
.5153 .03715 L
.51588 .03387 L
Mistroke
.51692 .02792 L
.51796 .02205 L
.51841 .01949 L
.5189 .01671 L
.51938 .01504 L
.51982 .01592 L
.5207 .01765 L
.52162 .01947 L
.52263 .02147 L
.52305 .0223 L
.5235 .02319 L
.52392 .02403 L
.52431 .02376 L
.52475 .0229 L
.52523 .02195 L
.5261 .02023 L
.52712 .01821 L
.52808 .01631 L
.52861 .01526 L
.52891 .01481 L
.52918 .01507 L
.53019 .01604 L
.53202 .01781 L
.53255 .01832 L
.53305 .0188 L
.53349 .01923 L
.53398 .0191 L
.53443 .01867 L
.53492 .0182 L
.53591 .01724 L
.53769 .01551 L
.53811 .01511 L
.53855 .01479 L
.53904 .01506 L
.53948 .01531 L
.54116 .01624 L
.5421 .01676 L
.54262 .01705 L
.54311 .01732 L
.54356 .01727 L
.54406 .017 L
.54492 .01652 L
.54596 .01594 L
.54706 .01532 L
.54751 .01507 L
.548 .0148 L
.54828 .01481 L
.54853 .0149 L
.54903 .01507 L
.55086 .01572 L
Mistroke
.55186 .01607 L
.55235 .01625 L
.5528 .0164 L
.55323 .01633 L
.55368 .01617 L
.55463 .01583 L
.55629 .01525 L
.55723 .01491 L
.5575 .01481 L
.55776 .01474 L
.55824 .01486 L
.56006 .0153 L
.56102 .01553 L
.56204 .01578 L
.56229 .01584 L
.56257 .01589 L
.56287 .01582 L
.56316 .01575 L
.56419 .0155 L
.56515 .01526 L
.56618 .01501 L
.56668 .01489 L
.56715 .01478 L
.56758 .01477 L
.56804 .01485 L
.57008 .01521 L
.57119 .0154 L
.57147 .01545 L
.57174 .0155 L
.57224 .01556 L
.57268 .01548 L
.57315 .01539 L
.57414 .01522 L
.57515 .01504 L
.5757 .01495 L
.57622 .01486 L
.57666 .01478 L
.57713 .01475 L
.57738 .01478 L
.57765 .01482 L
.57813 .01488 L
.57989 .01511 L
.58087 .01524 L
.58135 .0153 L
.58179 .01536 L
.5822 .0153 L
.58262 .01525 L
.58352 .01513 L
.58537 .01488 L
.58588 .01482 L
Mistroke
.58616 .01478 L
.58642 .01474 L
.58667 .01473 L
.58694 .01476 L
.58741 .01481 L
.58916 .01499 L
.59013 .01509 L
.5906 .01514 L
.59104 .01518 L
.59145 .01521 L
.59189 .01517 L
.5928 .01507 L
.5944 .01491 L
.59538 .01481 L
.59585 .01476 L
.5963 .01473 L
.5967 .01476 L
.59712 .0148 L
.59802 .01487 L
.59986 .01502 L
.60037 .01507 L
.60063 .01509 L
.60091 .01511 L
.60116 .01511 L
.60143 .01508 L
.6019 .01505 L
.60365 .0149 L
.60461 .01482 L
.60508 .01478 L
.60552 .01474 L
.60593 .01473 L
.60637 .01476 L
.60728 .01482 L
.60888 .01493 L
.60935 .01496 L
.60985 .01499 L
.61033 .01503 L
.61077 .01504 L
.61116 .01501 L
.6116 .01498 L
.61249 .01492 L
.61345 .01485 L
.61448 .01478 L
.61496 .01475 L
.61546 .01472 L
.61589 .01474 L
.61635 .01477 L
.6181 .01487 L
.61906 .01493 L
.61953 .01495 L
Mistroke
.61997 .01498 L
.62038 .01499 L
.62081 .01496 L
.62173 .01491 L
.62333 .01482 L
.62379 .01479 L
.62429 .01476 L
.62477 .01473 L
.62521 .01472 L
.62564 .01475 L
.62604 .01476 L
.62692 .01481 L
.62788 .01485 L
.62891 .01491 L
.62938 .01493 L
.62988 .01495 L
.63031 .01493 L
.63078 .01491 L
.63252 .01482 L
.63348 .01478 L
.63395 .01475 L
.63439 .01473 L
.63479 .01472 L
.63523 .01474 L
.63615 .01478 L
.63775 .01485 L
.63866 .01488 L
.63915 .01491 L
.63962 .01491 L
.64001 .0149 L
.64043 .01488 L
.64132 .01484 L
.64236 .0148 L
.64334 .01476 L
.64377 .01474 L
.64422 .01472 L
.64472 .01473 L
.64517 .01475 L
.64677 .01481 L
.64765 .01484 L
.64849 .01487 L
.64896 .01489 L
.64923 .01489 L
.64947 .01488 L
.65037 .01485 L
.65214 .01478 L
.65308 .01475 L
.65356 .01473 L
.65383 .01472 L
.65408 .01472 L
Mistroke
.65435 .01473 L
.65461 .01474 L
.65517 .01476 L
.65618 .01479 L
.65711 .01482 L
.6576 .01484 L
.65813 .01485 L
.65858 .01487 L
.65909 .01486 L
.65954 .01485 L
.65997 .01483 L
.66172 .01477 L
.66259 .01475 L
.66301 .01473 L
.66339 .01472 L
.66383 .01472 L
.66431 .01474 L
.66531 .01477 L
.66707 .01482 L
.66749 .01483 L
.66795 .01484 L
.66845 .01485 L
.66892 .01484 L
.67088 .01478 L
.67182 .01475 L
.67229 .01474 L
.67272 .01473 L
.67311 .01472 L
.67352 .01472 L
.67439 .01475 L
.67621 .01479 L
.67716 .01482 L
.67764 .01483 L
.67791 .01484 L
.67816 .01483 L
.67844 .01483 L
.6787 .01482 L
.67928 .01481 L
.68031 .01478 L
.68127 .01475 L
.68178 .01474 L
.68232 .01473 L
.68282 .01472 L
.68328 .01473 L
.68417 .01475 L
.6851 .01477 L
.68612 .01479 L
.68657 .0148 L
.68705 .01481 L
.68751 .01483 L
Mistroke
.68792 .01482 L
.68834 .01481 L
.6888 .0148 L
.68962 .01478 L
.69066 .01476 L
.69163 .01473 L
.69212 .01472 L
.69239 .01472 L
.69264 .01472 L
.69375 .01474 L
.69559 .01478 L
.69652 .0148 L
.69678 .01481 L
.69705 .01481 L
.69755 .01481 L
.698 .0148 L
.69851 .01479 L
.69952 .01477 L
.70047 .01475 L
.70133 .01473 L
.70178 .01472 L
.7022 .01472 L
.70265 .01473 L
.70314 .01474 L
.70482 .01477 L
.70586 .01479 L
.70636 .0148 L
.70683 .01481 L
.70731 .0148 L
.70783 .01479 L
.70894 .01477 L
.70987 .01475 L
.71037 .01474 L
.71089 .01473 L
.71139 .01472 L
.71185 .01472 L
.71231 .01473 L
.71274 .01473 L
.71467 .01477 L
.71561 .01478 L
.71602 .01479 L
.71647 .0148 L
.71694 .01479 L
.71738 .01478 L
.71835 .01477 L
.71933 .01475 L
.72041 .01473 L
.72085 .01472 L
.72133 .01472 L
.72178 .01472 L
Mistroke
.72219 .01473 L
.72407 .01476 L
.7249 .01477 L
.72534 .01478 L
.72581 .01479 L
.72625 .01479 L
.72666 .01478 L
.72745 .01477 L
.72931 .01474 L
.73025 .01473 L
.7305 .01472 L
.73078 .01472 L
.73127 .01472 L
.73172 .01473 L
.73222 .01474 L
.73311 .01475 L
.73479 .01477 L
.73524 .01478 L
.73573 .01479 L
.73602 .01478 L
.73628 .01478 L
.73678 .01477 L
.7389 .01474 L
.73937 .01473 L
.73987 .01472 L
.74034 .01472 L
.74076 .01472 L
.74124 .01473 L
.7417 .01473 L
.74272 .01475 L
.74357 .01476 L
.74448 .01477 L
.74475 .01477 L
.745 .01478 L
.74548 .01478 L
.74593 .01477 L
.74642 .01477 L
.74832 .01474 L
.74882 .01473 L
.74936 .01473 L
.74961 .01472 L
.74987 .01472 L
.75034 .01472 L
.75081 .01472 L
.75125 .01473 L
.75225 .01474 L
.75316 .01475 L
.75399 .01476 L
.75439 .01477 L
.75483 .01478 L
Mistroke
.75524 .01477 L
.75562 .01477 L
.75737 .01475 L
.75823 .01473 L
.75914 .01472 L
.75962 .01472 L
.75988 .01472 L
.76014 .01472 L
.76105 .01473 L
.76282 .01475 L
.76369 .01476 L
.76407 .01477 L
.76449 .01477 L
.76496 .01477 L
.76545 .01476 L
.76649 .01475 L
.76829 .01473 L
.76881 .01472 L
.7693 .01472 L
.76958 .01472 L
.76987 .01472 L
.77039 .01473 L
.77235 .01475 L
.77323 .01476 L
.7737 .01476 L
.77419 .01477 L
.77462 .01476 L
.77509 .01476 L
.77592 .01475 L
.77691 .01474 L
.77797 .01473 L
.77848 .01472 L
.77896 .01472 L
.7794 .01472 L
.77987 .01472 L
.78189 .01475 L
.78242 .01475 L
.783 .01476 L
.78327 .01476 L
.78354 .01476 L
.78403 .01476 L
.78448 .01476 L
.7849 .01475 L
.78586 .01474 L
.78691 .01473 L
.78737 .01473 L
.78787 .01472 L
.78836 .01472 L
.78881 .01472 L
.78929 .01472 L
Mistroke
.78981 .01473 L
.79088 .01474 L
.7919 .01475 L
.79285 .01476 L
.79311 .01476 L
.79339 .01476 L
.79388 .01476 L
.79569 .01474 L
.79653 .01473 L
.79743 .01472 L
.79785 .01472 L
.79828 .01472 L
.79866 .01472 L
.79906 .01472 L
.80085 .01474 L
.80179 .01475 L
.8023 .01475 L
.80278 .01476 L
.80328 .01476 L
.80355 .01475 L
.80383 .01475 L
.8048 .01474 L
.80578 .01473 L
.8067 .01473 L
.80713 .01472 L
.80759 .01472 L
.80809 .01472 L
.80856 .01472 L
.81026 .01474 L
.8113 .01474 L
.81184 .01475 L
.81214 .01475 L
.81242 .01475 L
.81266 .01476 L
.81292 .01475 L
.81348 .01475 L
.81445 .01474 L
.81547 .01473 L
.81644 .01472 L
.81686 .01472 L
.8173 .01472 L
.81779 .01472 L
.81824 .01472 L
.82008 .01474 L
.82098 .01474 L
.82183 .01475 L
.82229 .01475 L
.82279 .01475 L
.82384 .01474 L
.82568 .01473 L
Mistroke
.82658 .01472 L
.82683 .01472 L
.82709 .01472 L
.82756 .01472 L
.82934 .01473 L
.83092 .01474 L
.83135 .01475 L
.83181 .01475 L
.83225 .01475 L
.83265 .01475 L
.83448 .01473 L
.83548 .01472 L
.83597 .01472 L
.83642 .01472 L
.83681 .01472 L
.83722 .01472 L
.83808 .01473 L
.83992 .01474 L
.84086 .01475 L
.84113 .01475 L
.84139 .01475 L
.84187 .01475 L
.84233 .01474 L
.84275 .01474 L
.84369 .01473 L
.84473 .01473 L
.8457 .01472 L
.84619 .01472 L
.84646 .01472 L
.84671 .01472 L
.84782 .01473 L
.84964 .01474 L
.85017 .01474 L
.85066 .01475 L
.8511 .01475 L
.85158 .01475 L
.85324 .01473 L
.85412 .01473 L
.85507 .01472 L
.85535 .01472 L
.85561 .01472 L
.8561 .01472 L
.85657 .01472 L
.85707 .01472 L
.85809 .01473 L
.85918 .01474 L
.86012 .01474 L
.86037 .01474 L
.86065 .01475 L
.86115 .01474 L
Mistroke
.86161 .01474 L
.8621 .01474 L
.86297 .01473 L
.86395 .01473 L
.86443 .01472 L
.86488 .01472 L
.86528 .01472 L
.86571 .01472 L
.86614 .01472 L
.86661 .01472 L
.86848 .01473 L
.86952 .01474 L
.86976 .01474 L
.87003 .01474 L
.8705 .01474 L
.87093 .01474 L
.8714 .01474 L
.87239 .01473 L
.87412 .01472 L
.87452 .01472 L
.87495 .01472 L
.87543 .01472 L
.87586 .01472 L
.8775 .01473 L
.87847 .01473 L
.87895 .01474 L
.8794 .01474 L
.8798 .01474 L
.88023 .01474 L
.88065 .01474 L
.88113 .01474 L
.88299 .01473 L
.88349 .01472 L
.88403 .01472 L
.88427 .01472 L
.88453 .01472 L
.88501 .01472 L
.88525 .01472 L
.88551 .01472 L
.88599 .01472 L
.88689 .01473 L
.88862 .01474 L
.88906 .01474 L
.88947 .01474 L
.8899 .01474 L
.89038 .01474 L
.892 .01473 L
.89292 .01472 L
.89391 .01472 L
.89415 .01472 L
Mistroke
.89442 .01472 L
.89471 .01472 L
.89498 .01472 L
.89598 .01472 L
.89782 .01473 L
.89874 .01474 L
.899 .01474 L
.89927 .01474 L
.89975 .01474 L
.90169 .01473 L
.90253 .01472 L
.90297 .01472 L
.90344 .01472 L
.90387 .01472 L
.90435 .01472 L
.90478 .01472 L
.90518 .01472 L
.90682 .01473 L
.90774 .01473 L
.90825 .01474 L
.90872 .01474 L
.90899 .01474 L
.90928 .01474 L
.90979 .01474 L
.91079 .01473 L
.91174 .01473 L
.91275 .01472 L
.91317 .01472 L
.91361 .01472 L
.9141 .01472 L
.91455 .01472 L
.91645 .01473 L
.91739 .01473 L
.9178 .01474 L
.91825 .01474 L
.91865 .01474 L
.91903 .01474 L
.91986 .01473 L
.92161 .01472 L
.92248 .01472 L
.92296 .01472 L
.92341 .01472 L
.92367 .01472 L
.92394 .01472 L
.92443 .01472 L
.92537 .01473 L
.92637 .01473 L
.92692 .01473 L
.92743 .01473 L
.92786 .01474 L
Mistroke
.92833 .01474 L
.9286 .01474 L
.92885 .01473 L
.92932 .01473 L
.93096 .01472 L
.93185 .01472 L
.93229 .01472 L
.9327 .01472 L
.93313 .01472 L
.93361 .01472 L
.93461 .01472 L
.93637 .01473 L
.93686 .01473 L
.93732 .01474 L
.93773 .01474 L
.93818 .01474 L
.9401 .01473 L
.94098 .01472 L
.94146 .01472 L
.94191 .01472 L
.94229 .01472 L
.9427 .01472 L
.94316 .01472 L
.94358 .01472 L
.94551 .01473 L
.94653 .01473 L
.94683 .01473 L
.9471 .01474 L
.94735 .01474 L
.94762 .01474 L
.94961 .01473 L
.95058 .01472 L
.95146 .01472 L
.95192 .01472 L
.95237 .01472 L
.95283 .01472 L
.95334 .01472 L
.95509 .01473 L
.95609 .01473 L
.95659 .01473 L
.95688 .01474 L
.95715 .01473 L
.95763 .01473 L
.95807 .01473 L
.95906 .01473 L
.95997 .01472 L
.96093 .01472 L
.96122 .01472 L
.96149 .01472 L
.96199 .01472 L
Mistroke
.96246 .01472 L
.96297 .01472 L
.964 .01472 L
.9651 .01473 L
.96563 .01473 L
.96614 .01473 L
.96659 .01473 L
.96709 .01473 L
.9692 .01472 L
.97041 .01472 L
.97094 .01472 L
.97124 .01472 L
.97151 .01472 L
.97181 .01472 L
.97212 .01472 L
.97269 .01472 L
.97394 .01473 L
.97619 .01473 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol0000Eoooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00005Oooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol0000Hooooo`;o00006_ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol0000Eooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`?o00005Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol0000>oooo
o`007Oooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool04ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`0Dooooo`04o`000?ooooooooooo`0001Sooooo00Co0000oooooooooooo00002?oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool04Oooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00002Oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02oooool001Kooooo1Ol00002
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0:ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`0Dooooo`04o`000?ooooooooooo`0001Sooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`007Oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00006?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool04Oooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo000Mooooo`04o`000?oo
ooooooooo`0000Wooooo00Co0000oooooooooooooooo1?l0000Dooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool04oooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooo`000?ooool01?l0000Gooooo`04o`000?ooooooooooo`0001Sooooo00Co0000oooooooooooo
00002?ooool01Ol0003oooooooooool0003ooooo00Co00005?ooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00002Oooool01?l0003ooooooooo
ooooool4o`0000kooooo000Mooooo`04o`000?ooooooooooo`0000Sooooo0_l00003ooooo`03o`00
0?oooooooooo01Gooooo00Co0000oooooooooooo00002?ooool2o`0001Gooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0001[ooooo00Co0000oooooooooooo0000
6?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00005oooool0
1?l0003oooooooooool00008ooooo`;o00005Oooool01?l0003oooooooooool00008ooooo`;o0000
0oooool00ol0003oooooooooo`0?ooooo`007_ooool2o`0000[ooooo00Co0000oooooooooooooooo
1Ol0000Dooooo`;o00002_ooool00ol0003oooooooooo`0Dooooo`;o00002_ooool2o`0000;ooooo
1Ol0000Gooooo`;o00006_ooool2o`0000[ooooo0_l00002ooooo`Go00005?ooool2o`0000[ooooo
00?o0000ooooooooool05?ooool2o`0000[ooooo00Co0000oooooooooooooooo1Ol0000=ooooo`00
7_ooool00ol0003oooooooooo`3oooooo`007_ooool00ol0003oooooooooo`3oooooo`007_ooool0
0ol0003oooooooooo`3oooooo`007_ooool00ol0003oooooooooo`3oooooo`006?ooool6o`00073o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00o`000003o`000007ool00?l0003oo`00ool0
0?l0003oo`00o`00001`ool000Ko00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oo`00o`000?oo00000_oo00002?oo
ooooo`00oooooooooooo0000oooooooo003ooooo0ooo00000ol0003oo`00ooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`007_oo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool3ool00003oooooooo003ooooo00?ooooo00?oo`00oooooooo00000_oo000<ooooo`03o`000?oo
oooooooo00[ooooo0_l0001Eooooo`;o00004?ooool001kooooo0_l0001Eooooo`;o00002oooool2
o`0000kooooo0ooo0004ooooo`?oo`003_ooool2o`0000_ooooo0_l0001Eooooo`03o`000?oooooo
oooo00oooooo000Nooooo`?o0000Doooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo
00;ooooo0_l0000?ooooo`;oo`001?ooool3ool000kooooo0_l00004ooooo`03o`000?oooooooooo
00Cooooo0_l0001Dooooo`;o00004Oooool001kooooo00?o0000ooooool000005?ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00_ooool2o`0000[o
oooo00?o0000ooooooooool00_ooool2ool000Cooooo0ooo000>ooooo`;o00001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooo000003kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0@ooooo`007_ooool00ol0003oooooo`00000Dooooo`;o0000??ooool2o`0000;ooooo
00?o0000ooooooooool00_ooool2o`0000Cooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo
0_oo0004ooooo`;oo`001?ooool00ol0003oooooooooo`08ooooo`;o00001?ooool2o`0000Cooooo
0_l00002ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0@ooooo`007_ooool2o`000003ooooool0003ooooo017ooooo00?o0000ooooool00000;_oo
ool2o`0000_ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_oo0004ooooo`03ool00?l0
003ooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l00004ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo0_l0000^ooooo`;o00004ooo
ool00ol0003oooooooooo`0Aooooo`007_ooool01?l0003oooooooooool0000Booooo`03o`000?oo
oooo0000017ooooo0_l0000Cooooo`?o00001?ooool00ol0003oooooo`000002ooooo`;o00001_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`000?oo
oooo000000?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?l000000_oo
ool00ol0003oo`00o`000003ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`03o`000?oo
oooo000000Cooooo0ol0000Cooooo`;o00004Oooool00ol0003oooooo`00000Booooo`03o`000?oo
oooooooo017ooooo000Nooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooool000002?oo
ool3o`0000Kooooo0_l00006ooooo`;o00001Oooool4o`0000;ooooo00?o0000ooooool000001?oo
ool00ol0003oooooo`000002ooooo`Co00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo0_l00004ooooo`03o`000?oooooo000000?ooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ool00?l000000_ooool00ol0003oo`00o`000003ooooo`03o`000?oo
oooo000000?ooooo0_l00004ooooo`;o00000oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool4o`0000;ooooo00?o0000ooooool00000
1?ooool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?ooool00oooool00ol0003ooooo
o`000006ooooo`;o00001_ooool2o`0000Wooooo00?o0000ooooool000004Oooool2o`0001?ooooo
000Nooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooo`000008ooooo`03o`00
0?oooooo000000Gooooo0ol00005ooooo`Co00000oooool2o`0000;ooooo00Go0000oooooooooooo
0000ooooo`03o`0000;ooooo00?o0000ooooooooool00ol00003ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000;ooooo00?o0000ooooool000000oooool00ol0003oooooo`000003ooooo`03o`00
0?oo003o000000;ooooo00?o0000ool00?l000000oooool00ol0003oooooo`000003ooooo`;o0000
0oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooooooool2o`0000;ooooo0ol00002ooooo`03o`000?oooooooooo
00?o000000Koooooo`000?ooooooooooo`000?ooool3o`0000;ooooo1Ol00005ooooo`?o00001Ooo
ool00ol0003oooooo`000008ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool04_oo
ool001kooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooo000000Oooooo0_l0
0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooooooool2
o`000004ooooool0003oooooooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000Gooooo
00Go0000ooooooooooooooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000oooool00ol0003oo`00o`000002
ooooo`03o`000?oo003o000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo0_l00002ooooo`03o`000?oooooo0000
00Cooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000007ooooo`04o`00
0?ooooooooooo`00017ooooo00?o0000ooooooooool04_ooool001kooooo00Go0000oooooooooooo
ooooo`00000Aooooo`03o`000?oooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooo`000004ooooo`?o00000_ooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00000_ooool01ol0003ooooo
oooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
000000;ooooo00Co0000oooooooo003o00000_ooool01_l0003oo`00ooooool0003oooooo`0000;o
oooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00002?ooool3o`0000Gooooo0_l00005ooooo`03o`000?oooooo000000Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool04_ooool001kooooo00Go0000
ooooooooooooooooo`00000Aooooo`04o`000?ooooooooooo`0000Kooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooo000000Gooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`0>o`000?oooooo0000
oooooooo003oooooo`000?oooooo0000ool00?oooooo0000ooooool00002ooooo`07o`000?oooooo
ooooooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000[ooooo00?o0000oooo
ooooool01?ooool2o`0000Gooooo00?o0000ooooool000001?ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo01;ooooo000Nooooo`05o`000?oo
ooooooooooooool000004Oooool01?l0003oooooooooool00006ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Cooooo0ol00005oooo
o`;o00004Oooool00ol0003oooooo`000007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Ko0000ooooool0003oooooool00?ooool2o`000003oooooooo003ooooo00;o00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo0000017ooooo0_l00005oooo
o`?o00001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003ooooo
ooooo`0Booooo`007_ooool2o`0000?ooooo00?o0000ooooooooool03_ooool01?l0003ooooooooo
ool00006ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000Gooooo0_l0000Hooooo`03o`000?oooooo000000Oooooo1?l00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`06o`000?oooooo0000oooooooo003ooooo0_l000000oooooooo`00ooooo`02o`0000?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000?ooooo0ol00007ooooo`03o`000?oooooo000001Sooooo0_l00005ooooo`04o`000?oo
ooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
oooo0_l00003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool001kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooo`00000Oooooo`03o`000?oooooo000000Oooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l00002ooooo`06o`00
0?oooooo0000oooooooo003ooooo0_l000000oooooooo`00ooooo`02o`0000?ooooo1?l00002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001Oooool2o`0000Oooooo00?o0000
ooooool000007oooool00ol0003oooooo`000005ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Cooooo`007_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o00007oooool3o`0000kooooo00?o
0000ooooool000000_ooool00ol0003oooooo`000003ooooo`?o00001?ooool2o`000003oooooooo
003ooooo00;o000000?oooooool00?ooool00_l00005ooooo`;o00000oooool00ol0003oooooo`00
0002ooooo`03o`000?oooooo000000kooooo0ol0000Oooooo`;o00001_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool0000Wooooo`;o00003oooool00ol0003ooooo
o`000002ooooo`03o`000?oooooo000000?ooooo0_l00005ooooo`;o000000?oooooool00?ooool0
0_l000000oooooooo`00ooooo`02o`0000Kooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00;ooooo00?o0000ooooool000003oooool00ol0003oooooooooo`0Vooooo`;o000000?oooooo`00
0?ooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Cooooo`007_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool00000>Oooool00ol0003oooooo`000002ooooo`03
o`000?oooooo000000[ooooo0_l000000oooooooo`00ooooo`02o`000003oooooooo003ooooo00;o
00002_ooool2o`0000?ooooo00?o0000ooooool00000>_ooool2o`0000Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool04oooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o0000
>_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000_ooooo00Co0000oooooooo003o
oooo0_l000000oooooooo`00ooooo`02o`0000[ooooo0_l00003ooooo`03o`000?oooooo000003[o
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo000Nooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo000000?ooooo
0_l0000=ooooo`06ool00?ooooooooooo`000?ooooooo`003Oooool2o`0000?ooooo00?o0000oooo
ool00000>_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`000003ooooo`;o
00003Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00_ooooo0_l00003ooooo`03
o`000?oooooo0000047ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool001kooooo0_l00004ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooool000000oooool2o`0000gooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0;ooooo`;o00000oooool00ol0003oooooo`000011ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Cooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000@Oooool00ol0003ooooo
o`000003ooooo`;o00003Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00_ooooo
0_l00003ooooo`03o`000?oooooo0000047ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool001kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000011ooooo`;o00001?ooool2o`0000gooooo00Goo`00oooooooooooo
ooooool0000>ooooo`;o00001?ooool2o`0004;ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool001kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_l00011ooooo`;o00001?ooool2o`0000gooooo00Goo`00ooooooooooooooooool0000>oooo
o`;o00001?ooool2o`0004;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Cooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0004;ooooo0_l00004
ooooo`;o00003Oooool01Ooo003oooooooooooooooooo`0000oooooo00?o0000ooooooooool00_oo
ool2o`0004;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01Gooooo000;ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo0000@_ooool2o`0001?ooooo00Goo`00ooooooooooooooooool0000?oooo
o`03o`000?oooooooooo00;ooooo0_l00013ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Eooooo`002_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000@oooool2o`0001?ooooo00Goo`00
ooooooooooooooooool0000Eooooo`03o`000?oooooooooo047ooooo00?o0000ooooool000001_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo000:ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01?ooool3o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`05ooooo`;o0000A?ooool00ol0003oooooooooo`0Aooooo`05ool00?oo
oooooooooooooooo0000F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool05Oooool000[ooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo05Oooooo00Goo`00ooooooooooooooooool0001Jooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`00
2_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Goooool01Ooo
003oooooooooooooooooo`0006;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0E
ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Gooo
ool01Ooo003oooooooooooooooooo`0006;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Eooooo`002oooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Oooooo`05ool00?oooooooooooooooooo0000
H_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo000Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Oooooo`05ool00?oo
oooooooooooooooo0000H_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo
000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Oooooo`05ool00?oooooooooooooooooo0000H_ooool2o`0000[ooooo00?o0000ooooooooool0
5_ooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo05oooooo00Goo`00ooooooooooooooooool0001Sooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool05_ooool001kooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0Goooool01Ooo003oooooooooooooooooo`0006?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Fooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0H?ooool01Ooo003oooooooooooooooooo`0006?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`007_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0H?ooool01Ooo003ooooooooo
ooooooooo`0006?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`007_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0HOoo
ool01?oo003ooooooooooooo001Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
5_ooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo067ooooo00Coo`00ooooooooooooo`00Hoooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01Kooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Qooooo`04ool00?ooooooooooool006?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Fooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0HOooool01?oo003ooooooooooooo001Sooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05oooool001kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo067ooooo00Coo`00ooooooooooooo`00
Hoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo000Nooooo`;o00001_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo067ooooo00Coo`00ooooooooooooo`00
Hoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Qooooo`04ool00?oo
ooooooooool006?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`007_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0HOoo
ool01?oo003ooooooooooooo001Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
5oooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo067ooooo00Coo`00ooooooooooooo`00Hoooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Qooooo`04ool00?ooooooooooool006?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Gooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0HOooool01?oo003ooooooooooooo001Sooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05oooool001kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo067ooooo00Coo`00ooooooooooooo`00
Hoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo000Nooooo`;o00001ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo067ooooo00Coo`00ooooooooooooo`00
Hoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Qooooo`04ool00?oo
ooooooooool006?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`007_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0HOoo
ool01?oo003ooooooooooooo001Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
5oooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo067ooooo00Coo`00ooooooooooooo`00Hoooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Qooooo`04ool00?ooooooooooool006?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Gooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0HOooool01?oo003ooooooooooooo001Sooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05oooool000_ooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0ol00004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Qooooo`04ool00?ooooooooooool006?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Hooooo`002_ooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo067ooooo00Coo`00ooooooooooooo`00Hoooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00004ooooo`?o
00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo067ooooo00Coo`00oooooooo
ooooo`00I?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo000:ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0H_ooool01?oo003ooooooooooooo
001Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool000[ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Rooooo`04ool00?ooooooooooool006Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`002_ooool01?l0003ooooooooo
ool00009ooooo`;o00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0H_ooool01?oo003ooooooooooooo001Tooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool06?ooool000_ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;ooooo
00Coo`00ooooooooooooo`00I?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01So
oooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Rooooo`04ool00?ooooooooooool006Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Hooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0H_ooool01?oo003ooooooooooooo001Tooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool06?ooool001kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06;ooooo00Coo`00ooooooooooooo`00I?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Wooooo000Nooooo`;o00002?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06;ooooo00Coo`00ooooooooooooo`00I?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`04ool00?ooooooooooool006Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_ooool01?oo003ooooo
oooooooo001Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool001kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06;ooooo
00Coo`00ooooooooooooo`00IOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wo
oooo000Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Rooooo`03ool00?ooooooo`0006Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Iooooo`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0H_ooool00ooo003oooooool0001Vooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool06Oooool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo06?ooooo00?oo`00oooooooo0000I_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Wooooo000Nooooo`;o00002Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo06?ooooo00?oo`00oooooooo0000I_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Sooooo`03ool00?ooooooo`0006Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool00ooo003oooooool0001Vooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool06Oooool001kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06?ooooo00?oo`00oooooooo0000I_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Sooooo`03ool00?oooooo
o`0006Oooooo00Go0000ooooooooooooooooo`00000Looooo`007_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Hoooool00ooo003oooooool0001W
ooooo`05o`000?ooooooooooooooool000007?ooool001kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06?ooooo00?oo`00oooooooo0000Ioooool0
1Ol0003ooooooooooooooooo000001cooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Sooooo`03ool00?ooooooo`0006Oooooo00Go0000
ooooooooooooooooo`00000Looooo`007_ooool2o`0000[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Sooooo`03ool00?ooooooo`0006Oooooo00Go0000ooooooooooooooooo`00
000Looooo`007_ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool00000I_oo
ool00ooo003oooooool0001Wooooo`05o`000?ooooooooooooooool000007?ooool001kooooo00?o
0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000006Oooooo0_oo001Wooooo`05o`00
0?ooooooooooooooool000007?ooool001kooooo00?o0000ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000006Oooooo0_oo001Wooooo`04o`000?ooooooooooo`0001gooooo000Nooooo`03
o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00001Wooooo`;oo`00Ioooool01?l0
003oooooooooool0000Mooooo`002oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00?o0000ooooooooool02Oooool2o`0000;ooooo00?o0000ooooooooool0IOooool2ool0
06Sooooo0ol0000Mooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool0I_ooool2
ool006Sooooo0_l0000Nooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`;o0000J?ooool2ool006Sooooo0_l0
000Nooooo`002_ooool01?l0003oooooooooool00007ooooo`Co00001Oooool3o`0000_ooooo0_l0
001Xooooo`;oo`00J?ooool2o`0001kooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`;o0000J?ooool2ool006Sooooo00?o
0000ooooooooool07Oooool000[ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo0_l0001Xooooo`;oo`00R?ooool000_ooooo0_l0000:
ooooo`;o00001Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Kooooo0_oo0028
ooooo`007_ooool00ol0003oooooooooo`1eooooo`;oo`00R?ooool001kooooo00?o0000oooooooo
ool0MOooool2ool008Sooooo000Nooooo`03o`000?oooooooooo07Gooooo0_oo0028ooooo`007_oo
ool2o`0007Kooooo0_oo0028ooooo`007_ooool00ol0003oooooooooo`1eooooo`;oo`00R?ooool0
01kooooo00?o0000ooooooooool0MOooool2ool008Sooooo000Nooooo`03o`000?oooooooooo07Go
oooo0_oo0028ooooo`007_ooool00ol0003oooooooooo`1eooooo`;oo`00R?ooool001kooooo00?o
0000ooooooooool0MOooool2ool008Sooooo000Nooooo`03o`000?oooooooooo07Gooooo0_oo0028
ooooo`007_ooool00ol0003oooooooooo`1eooooo`;oo`00R?ooool001kooooo0_l0001fooooo`;o
o`00R?ooool001kooooo00?o0000ooooooooool0MOooool2ool008Sooooo000Nooooo`03o`000?oo
oooooooo07Gooooo0_oo0028ooooo`007_ooool00ol0003oooooooooo`1eooooo`;oo`00R?ooool0
01kooooo00?o0000ooooooooool0MOooool2ool008Sooooo000Nooooo`03o`000?oooooooooo07Go
oooo0_oo0028ooooo`007_ooool00ol0003oooooooooo`1eooooo`;oo`00R?ooool001kooooo00?o
0000ooooooooool0MOooool2ool008Sooooo000Nooooo`;o0000M_ooool2ool008Sooooo000Noooo
o`03o`000?oooooooooo07Gooooo0_oo0028ooooo`007_ooool00ol0003oooooooooo`1eooooo`;o
o`00R?ooool001kooooo00?o0000ooooooooool0MOooool2ool008Sooooo000Nooooo`03o`000?oo
oooooooo07Gooooo0_oo0028ooooo`002oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0MOooool2ool008Sooooo000:ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07Gooooo0_oo
0028ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1?ooool3o`0007Gooooo0_oo0028ooooo`002_ooool01?l0003oooooooooool00008ooooo`?o0000
1Oooool00ol0003oooooooooo`1eooooo`;oo`00R?ooool000[ooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0MOooool2ool008So
oooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo07Gooooo0_oo0028ooooo`002oooool2o`0000Wooooo0ol00005ooooo`03
o`000?oooooooooo07Gooooo0_oo0028ooooo`007_ooool00ol0003oooooooooo`1eooooo`;oo`00
R?ooool001kooooo00?o0000ooooooooool0MOooool2ool008Sooooo000Nooooo`03o`000?oooooo
oooo07Gooooo0_oo0028ooooo`007_ooool2o`0007Kooooo0_oo0028ooooo`007_ooool00ol0003o
ooooooooo`1eooooo`;oo`00R?ooool001kooooo00?o0000ooooooooool0MOooool2ool008Sooooo
000Nooooo`03o`000?oooooooooo07Gooooo0_oo0028ooooo`007_ooool00ol0003oooooooooo`1e
ooooo`;oo`00R?ooool001kooooo00?o0000ooooooooool0MOooool2ool008Sooooo000Nooooo`03
o`000?oooooooooo07Gooooo0_oo0028ooooo`007_ooool00ol0003oooooooooo`1eooooo`;oo`00
R?ooool001kooooo0_l0001fooooo`;oo`00R?ooool001kooooo00?o0000ooooooooool0MOooool2
ool008Sooooo000Nooooo`03o`000?oooooooooo07Gooooo0_oo0028ooooo`007_ooool00ol0003o
ooooooooo`1eooooo`;oo`00R?ooool001kooooo00?o0000ooooooooool0MOooool2ool008Sooooo
000Nooooo`03o`000?oooooooooo07Gooooo0_oo0028ooooo`007_ooool00ol0003oooooooooo`1e
ooooo`;oo`00R?ooool001kooooo0_l0001gooooo`03ool00?oooooooooo08Kooooo000Nooooo`03
o`000?oooooooooo07Kooooo00?oo`00ooooooooool0Q_ooool001kooooo00?o0000ooooooooool0
M_ooool00ooo003oooooooooo`26ooooo`007_ooool00ol0003oooooooooo`1fooooo`03ool00?oo
oooooooo08Kooooo000Nooooo`03o`000?oooooooooo07Kooooo00?oo`00ooooooooool0Q_ooool0
01kooooo00?o0000ooooooooool0ooooool001kooooo00?o0000ooooooooool0ooooool001kooooo
00?o0000ooooooooool0ooooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool006Co
oooo0ol0001Aooooo`?o0000IOooool006Gooooo00?o0000ooooooooool0DOooool00ol0003ooooo
ooooo`1Tooooo`00>_ooool3o`0000Cooooo0ol00002ooooo`Go000000Goooooo`000?l0003o0000
ooooo`02o`0000;ooooo0_l00009ooooo`?o00000oooool3o`0000;ooooo0ol00004ooooo`?o0000
0oooool4o`0000;ooooo1?l00007ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000;o
oooo0_l00003ooooo`?o00000_ooool3o`000003ooooool0003o000000Co00000_ooool5o`0000?o
oooo0_l00004ooooo`03o`000?oooooooooo00Oooooo0ol00005ooooo`;o000000?oooooo`000?l0
00000_l000001?oooooo0000o`000?ooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`00
00;ooooo0ol000000ooooooo0000o`00000/ooooo`00>oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04
o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool0000]ooooo`00>oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo1Ol00002ooooo`?o00000_ooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go
00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool0:oooool003_ooooo0ol00002ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool02_ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00Oo
0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooo
ool0003oooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Wooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0:oooool003_o
oooo00Co0000oooooooooooo00000_ooool3o`0000;ooooo0ol00003ooooo`Co00000_ooool4o`00
00Wooooo00?o0000ooooooooool00_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`?o00000oooool2o`0000Cooooo0ol0000:ooooo`04o`000?ooooooooooooooo`Co00000_ooool4
o`0000?ooooo0ol00002ooooo`Co00000oooool4o`000004ooooool0003o0000o`0000?ooooo1?l0
0002ooooo`;o000000?oooooo`000?l000002?ooool00ol0003oooooooooo`02ooooo`;o000000Co
ooooo`000?l0003ooooo1?l00003ooooo`?o00000_ooool4o`0000;ooooo0ol00004ooooo`?o0000
0_ooool4o`0002kooooo000kooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooo00005?ooool00ol0003oooooooooo`10ooooo`00>_ooool4o`0000[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0:ooooo`?o00006oooool2o`0000Sooooo1Ol00008ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`Go
00005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.199991, -0.0793089, \
0.00132383, 0.00652131}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0060731 0.0280925 0.561849 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17564 -0.0125 -6 -9 ]
[.17564 -0.0125 6 0 ]
[.32746 -0.0125 -6 -9 ]
[.32746 -0.0125 6 0 ]
[.47929 -0.0125 -6 -9 ]
[.47929 -0.0125 6 0 ]
[.63112 -0.0125 -9 -9 ]
[.63112 -0.0125 9 0 ]
[.78295 -0.0125 -9 -9 ]
[.78295 -0.0125 9 0 ]
[.93477 -0.0125 -9 -9 ]
[.93477 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .14046 -18 -4.5 ]
[-0.0125 .14046 0 4.5 ]
[-0.0125 .25283 -18 -4.5 ]
[-0.0125 .25283 0 4.5 ]
[-0.0125 .3652 -18 -4.5 ]
[-0.0125 .3652 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -84 0 ]
[.5 .63053 84 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.17564 0 m
.17564 .00625 L
s
[(25)] .17564 -0.0125 0 1 Mshowa
.32746 0 m
.32746 .00625 L
s
[(50)] .32746 -0.0125 0 1 Mshowa
.47929 0 m
.47929 .00625 L
s
[(75)] .47929 -0.0125 0 1 Mshowa
.63112 0 m
.63112 .00625 L
s
[(100)] .63112 -0.0125 0 1 Mshowa
.78295 0 m
.78295 .00625 L
s
[(125)] .78295 -0.0125 0 1 Mshowa
.93477 0 m
.93477 .00625 L
s
[(150)] .93477 -0.0125 0 1 Mshowa
.125 Mabswid
.05418 0 m
.05418 .00375 L
s
.08454 0 m
.08454 .00375 L
s
.11491 0 m
.11491 .00375 L
s
.14527 0 m
.14527 .00375 L
s
.206 0 m
.206 .00375 L
s
.23637 0 m
.23637 .00375 L
s
.26673 0 m
.26673 .00375 L
s
.2971 0 m
.2971 .00375 L
s
.35783 0 m
.35783 .00375 L
s
.3882 0 m
.3882 .00375 L
s
.41856 0 m
.41856 .00375 L
s
.44893 0 m
.44893 .00375 L
s
.50966 0 m
.50966 .00375 L
s
.54002 0 m
.54002 .00375 L
s
.57039 0 m
.57039 .00375 L
s
.60075 0 m
.60075 .00375 L
s
.66149 0 m
.66149 .00375 L
s
.69185 0 m
.69185 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75258 0 m
.75258 .00375 L
s
.81331 0 m
.81331 .00375 L
s
.84368 0 m
.84368 .00375 L
s
.87404 0 m
.87404 .00375 L
s
.90441 0 m
.90441 .00375 L
s
.96514 0 m
.96514 .00375 L
s
.99551 0 m
.99551 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .14046 m
.00625 .14046 L
s
[(0.2)] -0.0125 .14046 1 0 Mshowa
0 .25283 m
.00625 .25283 L
s
[(0.4)] -0.0125 .25283 1 0 Mshowa
0 .3652 m
.00625 .3652 L
s
[(0.6)] -0.0125 .3652 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(0.8)] -0.0125 .47757 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(1)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17564 .61178 m
.17564 .61803 L
s
.32746 .61178 m
.32746 .61803 L
s
.47929 .61178 m
.47929 .61803 L
s
.63112 .61178 m
.63112 .61803 L
s
.78295 .61178 m
.78295 .61803 L
s
.93477 .61178 m
.93477 .61803 L
s
.125 Mabswid
.05418 .61428 m
.05418 .61803 L
s
.08454 .61428 m
.08454 .61803 L
s
.11491 .61428 m
.11491 .61803 L
s
.14527 .61428 m
.14527 .61803 L
s
.206 .61428 m
.206 .61803 L
s
.23637 .61428 m
.23637 .61803 L
s
.26673 .61428 m
.26673 .61803 L
s
.2971 .61428 m
.2971 .61803 L
s
.35783 .61428 m
.35783 .61803 L
s
.3882 .61428 m
.3882 .61803 L
s
.41856 .61428 m
.41856 .61803 L
s
.44893 .61428 m
.44893 .61803 L
s
.50966 .61428 m
.50966 .61803 L
s
.54002 .61428 m
.54002 .61803 L
s
.57039 .61428 m
.57039 .61803 L
s
.60075 .61428 m
.60075 .61803 L
s
.66149 .61428 m
.66149 .61803 L
s
.69185 .61428 m
.69185 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75258 .61428 m
.75258 .61803 L
s
.81331 .61428 m
.81331 .61803 L
s
.84368 .61428 m
.84368 .61803 L
s
.87404 .61428 m
.87404 .61803 L
s
.90441 .61428 m
.90441 .61803 L
s
.96514 .61428 m
.96514 .61803 L
s
.99551 .61428 m
.99551 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .14046 m
1 .14046 L
s
.99375 .25283 m
1 .25283 L
s
.99375 .3652 m
1 .3652 L
s
.99375 .47757 m
1 .47757 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(Modulation Transfer Function)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .58994 m
.02558 .53314 L
.02643 .50595 L
.02723 .48023 L
.02768 .45986 L
.02818 .42346 L
.02904 .35984 L
.02996 .29186 L
.03045 .25579 L
.03097 .21699 L
.03124 .19754 L
.03149 .18983 L
.03196 .17934 L
.03288 .15878 L
.03393 .1354 L
.03444 .12402 L
.0349 .1137 L
.03533 .11882 L
.03574 .12852 L
.03664 .14982 L
.03761 .17313 L
.03809 .18451 L
.03853 .19489 L
.03898 .19614 L
.03946 .18765 L
.04048 .16964 L
.04147 .15223 L
.04199 .14304 L
.04228 .13801 L
.04254 .13266 L
.04301 .11949 L
.04353 .10495 L
.04444 .07932 L
.0453 .05519 L
.04575 .04242 L
.04624 .02957 L
.04652 .03272 L
.04677 .03557 L
.04726 .04115 L
.04833 .05334 L
.04882 .05885 L
.04933 .06468 L
.04977 .06966 L
.05025 .06872 L
.05052 .06603 L
.0508 .06314 L
.05132 .05792 L
.05248 .04622 L
.05304 .04053 L
.05332 .03773 L
Mistroke
.05358 .03512 L
.05406 .03803 L
.05431 .04081 L
.05458 .04378 L
.05649 .06477 L
.05696 .06987 L
.05745 .07503 L
.05774 .07524 L
.058 .07542 L
.05851 .07579 L
.05964 .07661 L
.0602 .07701 L
.06045 .07718 L
.06072 .07738 L
.06119 .07725 L
.06169 .07068 L
.06275 .05681 L
.06368 .0446 L
.06419 .03794 L
.06466 .03176 L
.06491 .02896 L
.06518 .03228 L
.06574 .03931 L
.06672 .05163 L
.06772 .06421 L
.06822 .07039 L
.06867 .07555 L
.06908 .07569 L
.06952 .07584 L
.07044 .07614 L
.07141 .07646 L
.07188 .07662 L
.07232 .07677 L
.07272 .07299 L
.07315 .06854 L
.07404 .05914 L
.07493 .04987 L
.07539 .045 L
.07588 .03987 L
.07614 .0378 L
.07643 .03898 L
.07693 .04105 L
.07791 .04513 L
.07881 .04885 L
.07925 .05068 L
.07966 .05236 L
.08013 .05282 L
.08038 .05261 L
.08064 .05239 L
.08153 .05162 L
Mistroke
.0823 .05095 L
.08313 .05024 L
.0836 .04973 L
.08404 .04819 L
.08489 .04517 L
.08583 .04186 L
.08671 .03874 L
.0872 .03701 L
.08747 .03757 L
.08773 .03893 L
.08865 .04389 L
.08952 .04862 L
.09034 .05302 L
.09075 .05524 L
.0912 .05625 L
.09168 .05466 L
.09213 .05322 L
.09407 .04692 L
.09461 .04519 L
.09488 .04458 L
.09517 .04434 L
.09619 .04353 L
.09714 .04277 L
.09764 .04238 L
.09791 .04216 L
.09817 .04196 L
.09863 .04225 L
.09888 .04333 L
.09914 .04449 L
.10003 .04843 L
.10102 .0528 L
.10156 .05519 L
.10182 .05636 L
.10206 .05743 L
.10249 .05743 L
.10295 .05594 L
.10393 .0528 L
.10596 .0463 L
.10703 .04315 L
.10817 .0398 L
.10872 .03817 L
.10924 .03664 L
.10971 .03527 L
.10997 .03609 L
.11021 .03686 L
.11111 .03977 L
.11211 .04296 L
.11256 .04442 L
.11305 .04599 L
.11351 .04708 L
Mistroke
.11393 .04583 L
.11484 .04309 L
.11584 .04007 L
.1163 .0387 L
.11679 .03722 L
.11726 .03613 L
.11768 .03654 L
.11963 .03841 L
.12145 .04048 L
.12313 .04316 L
.12407 .04465 L
.12434 .04508 L
.1246 .04548 L
.12507 .04405 L
.12618 .0401 L
.12719 .03647 L
.12766 .03481 L
.12809 .03325 L
.12855 .03264 L
.12905 .03394 L
.13105 .03919 L
.13153 .04044 L
.13197 .04162 L
.13244 .04239 L
.13296 .04302 L
.13403 .04434 L
.13452 .04493 L
.13503 .04556 L
.13548 .04611 L
.13598 .04618 L
.13643 .04474 L
.13684 .04341 L
.13785 .0402 L
.1388 .03716 L
.13922 .03583 L
.13966 .03468 L
.14014 .03493 L
.14059 .03517 L
.14222 .03603 L
.14396 .03721 L
.14587 .03898 L
.14633 .03941 L
.14682 .03987 L
.1471 .03998 L
.14735 .03932 L
.14785 .03802 L
.14876 .03566 L
.14974 .0331 L
.1502 .0319 L
.15069 .03063 L
Mistroke
.1511 .03092 L
.15156 .03177 L
.15327 .03496 L
.15381 .03595 L
.15407 .03644 L
.15431 .03689 L
.15477 .03737 L
.15526 .03754 L
.15627 .03787 L
.15681 .03805 L
.15739 .03824 L
.15789 .03841 L
.15835 .0383 L
.15879 .03716 L
.15925 .03596 L
.16027 .03331 L
.16077 .03201 L
.16123 .03082 L
.16168 .02966 L
.16215 .0292 L
.16262 .03037 L
.16314 .03166 L
.16487 .03596 L
.16537 .03719 L
.16584 .03813 L
.1661 .03825 L
.16639 .03837 L
.16688 .03859 L
.16778 .03899 L
.16825 .03919 L
.16876 .03942 L
.16924 .03963 L
.16967 .0393 L
.17009 .03841 L
.17052 .03747 L
.17149 .03539 L
.1724 .03346 L
.1728 .03261 L
.17317 .0318 L
.17361 .03195 L
.174 .03216 L
.17576 .03308 L
.17767 .03409 L
.17946 .03506 L
.17992 .03531 L
.18036 .03554 L
.1806 .03568 L
.18086 .03542 L
.18132 .03469 L
.1824 .03299 L
Mistroke
.18338 .03145 L
.18381 .03076 L
.18428 .03001 L
.18473 .03014 L
.18514 .03055 L
.18702 .03242 L
.18743 .03282 L
.18787 .03326 L
.18828 .03359 L
.18866 .03373 L
.18949 .03405 L
.1904 .0344 L
.19127 .03474 L
.19177 .03493 L
.19223 .03447 L
.19272 .03378 L
.19317 .03315 L
.19418 .03172 L
.19461 .03112 L
.19506 .03047 L
.19549 .02987 L
.19588 .02996 L
.19632 .0304 L
.19674 .03081 L
.19767 .03174 L
.19863 .03268 L
.19952 .03351 L
.20045 .03413 L
.20147 .03482 L
.2025 .03552 L
.2028 .03572 L
.20308 .03591 L
.20333 .03567 L
.20361 .03541 L
.20558 .03356 L
.20761 .03182 L
.20861 .0311 L
.20952 .03043 L
.20996 .03011 L
.21036 .02982 L
.21078 .02987 L
.21124 .03026 L
.21309 .03182 L
.21359 .03223 L
.21385 .03246 L
.21413 .03269 L
.21438 .03277 L
.21464 .03265 L
.21512 .03243 L
.21696 .03156 L
Mistroke
.21907 .03063 L
.22012 .0302 L
.22063 .02999 L
.22109 .0298 L
.22155 .02961 L
.22198 .0297 L
.22244 .03006 L
.22293 .03044 L
.22391 .03119 L
.22445 .0316 L
.22495 .03199 L
.22537 .03231 L
.22582 .03232 L
.22633 .03218 L
.22678 .03206 L
.2276 .03184 L
.22848 .03161 L
.22896 .03148 L
.22923 .0314 L
.22949 .03121 L
.23043 .0305 L
.23154 .02967 L
.23203 .02931 L
.23228 .02911 L
.23256 .02891 L
.23303 .02867 L
.23346 .02908 L
.23442 .02998 L
.23538 .03088 L
.23592 .03139 L
.23618 .03164 L
.23643 .03187 L
.2369 .03216 L
.23716 .03221 L
.23741 .03225 L
.23845 .03245 L
.23936 .03261 L
.23986 .0327 L
.24032 .03279 L
.24059 .03271 L
.24088 .03253 L
.24137 .03223 L
.24235 .03163 L
.24455 .03035 L
.2465 .02952 L
.24697 .02932 L
.24748 .0291 L
.24777 .02898 L
.24803 .02898 L
.2483 .02911 L
Mistroke
.24855 .02922 L
.24946 .02965 L
.25045 .0301 L
.2509 .03031 L
.25138 .03053 L
.25178 .03062 L
.25223 .03053 L
.25398 .03017 L
.25591 .0297 L
.2578 .02905 L
.25835 .02887 L
.25861 .02878 L
.25886 .02869 L
.25932 .02872 L
.25982 .02897 L
.26159 .02986 L
.26248 .0303 L
.26272 .03043 L
.26298 .03049 L
.26346 .0305 L
.26436 .03053 L
.26523 .03055 L
.266 .03057 L
.26643 .03058 L
.26684 .03047 L
.26878 .02961 L
.26932 .02938 L
.26988 .02913 L
.27036 .02895 L
.27063 .02899 L
.27088 .02902 L
.27468 .02975 L
.27633 .0304 L
.27677 .03057 L
.27724 .03075 L
.27768 .03093 L
.27808 .03096 L
.27855 .03094 L
.279 .03093 L
.28 .03091 L
.28085 .03088 L
.28133 .03087 L
.28178 .03077 L
.28203 .03067 L
.2823 .03057 L
.28279 .03039 L
.28371 .03005 L
.28577 .02932 L
.28673 .02904 L
.28774 .02874 L
Mistroke
.28816 .02862 L
.2886 .02848 L
.2891 .0284 L
.28955 .02851 L
.29046 .02873 L
.29145 .02897 L
.29191 .02909 L
.29239 .0292 L
.2928 .02928 L
.29325 .02925 L
.29487 .02916 L
.29572 .02911 L
.2962 .02908 L
.29663 .02903 L
.29713 .0289 L
.2976 .02879 L
.2985 .02857 L
.29945 .02833 L
.29971 .02827 L
.29998 .0282 L
.30047 .02823 L
.30089 .02836 L
.30134 .02849 L
.30215 .02872 L
.30311 .029 L
.30358 .02913 L
.304 .02925 L
.30449 .02932 L
.30502 .0294 L
.30613 .02956 L
.30663 .02964 L
.30717 .02971 L
.30742 .02975 L
.30768 .02978 L
.30815 .02974 L
.30917 .02966 L
.31013 .02957 L
.31055 .02954 L
.311 .0295 L
.31149 .02944 L
.31194 .02931 L
.31284 .02906 L
.31381 .0288 L
.31426 .02867 L
.31472 .02854 L
.31512 .02843 L
.31556 .0285 L
.31741 .02876 L
.31944 .0291 L
.32116 .02948 L
Mistroke
.32207 .02969 L
.32253 .02979 L
.32303 .02983 L
.32347 .02985 L
.32395 .02987 L
.3248 .02992 L
.32558 .02996 L
.32602 .02998 L
.32643 .02999 L
.32667 .02996 L
.32694 .02993 L
.32748 .02987 L
.32848 .02976 L
.32938 .02967 L
.32985 .02961 L
.33035 .02953 L
.33131 .02934 L
.33219 .02916 L
.33391 .02882 L
.33575 .02846 L
.33624 .02837 L
.33677 .02827 L
.33726 .02817 L
.33772 .02814 L
.33798 .02817 L
.33827 .02821 L
.33885 .02828 L
.33988 .0284 L
.34038 .02846 L
.34066 .02849 L
.34092 .02852 L
.34117 .02855 L
.34143 .02856 L
.3419 .02856 L
.34287 .02856 L
.34392 .02856 L
.34441 .02856 L
.34467 .02856 L
.34492 .02856 L
.34535 .02853 L
.34583 .02848 L
.34755 .02832 L
.34805 .02827 L
.34852 .02822 L
.34894 .02822 L
.34939 .02825 L
.35319 .02857 L
.35521 .02881 L
.35739 .029 L
.35837 .02906 L
Mistroke
.35891 .02909 L
.35941 .02912 L
.35984 .02915 L
.3603 .02915 L
.36056 .02915 L
.36081 .02914 L
.36127 .02913 L
.36212 .02912 L
.36303 .0291 L
.3635 .02909 L
.36376 .02908 L
.36401 .02905 L
.36492 .02896 L
.36689 .02877 L
.36903 .02849 L
.37001 .02835 L
.37055 .02827 L
.37081 .02823 L
.37105 .0282 L
.37153 .02822 L
.37177 .02825 L
.37204 .02827 L
.37293 .02835 L
.37662 .02874 L
.37762 .02886 L
.37811 .02892 L
.37857 .02897 L
.37882 .02899 L
.37909 .02901 L
.37966 .02905 L
.38066 .02913 L
.3815 .02919 L
.38196 .02923 L
.3824 .02926 L
.38265 .02926 L
.38292 .02927 L
.38339 .02928 L
.38432 .02929 L
.38517 .02931 L
.38564 .02932 L
.38608 .02933 L
.3865 .02931 L
.38694 .0293 L
.38772 .02927 L
.39134 .02909 L
.3934 .02894 L
.39531 .02879 L
.39943 .02847 L
.40146 .02832 L
.40235 .02826 L
Mistroke
.40334 .0282 L
.40378 .02817 L
.40426 .02814 L
.40472 .02811 L
.40514 .02812 L
.40705 .02821 L
.40754 .02823 L
.40807 .02825 L
.40856 .02827 L
.40901 .02828 L
.41 .02829 L
.41109 .02831 L
.41153 .02831 L
.41199 .02832 L
.41239 .02832 L
.41283 .02832 L
.41472 .0283 L
.41557 .02829 L
.41605 .02828 L
.41649 .02828 L
.41815 .02824 L
.41997 .0282 L
.42097 .02817 L
.42191 .02815 L
.42279 .02812 L
.42328 .02811 L
.42374 .02812 L
.42412 .02813 L
.42454 .02815 L
.4254 .02819 L
.42953 .02836 L
.43329 .02849 L
.43712 .02859 L
.44074 .02867 L
.4417 .02869 L
.44272 .0287 L
.44456 .02872 L
.44505 .02873 L
.4453 .02873 L
.44557 .02873 L
.44607 .02874 L
.44653 .02873 L
.44765 .02873 L
.44871 .02873 L
.44915 .02873 L
.44962 .02873 L
.44987 .02872 L
.45014 .02872 L
.45062 .02872 L
.45235 .0287 L
Mistroke
.45624 .02867 L
.45798 .02865 L
.45986 .02863 L
.46162 .0286 L
.46324 .02857 L
.47111 .02844 L
.4784 .02834 L
.48015 .02832 L
.48204 .02829 L
.48291 .02828 L
.48335 .02827 L
.48383 .02827 L
.48546 .02826 L
.48903 .02824 L
.49298 .02822 L
.49499 .02821 L
.49597 .02821 L
.49689 .0282 L
.49771 .0282 L
.49813 .0282 L
.49859 .0282 L
.50044 .0282 L
.50146 .02821 L
.50174 .02821 L
.50204 .02821 L
.50257 .02821 L
.50362 .02822 L
.5046 .02822 L
.50507 .02822 L
.50556 .02823 L
.50582 .02823 L
.5061 .02823 L
.5066 .02823 L
.50841 .02823 L
.50891 .02823 L
.50938 .02823 L
.5098 .02823 L
.51026 .02823 L
.51122 .02824 L
.51224 .02824 L
.51266 .02824 L
.51312 .02824 L
.51362 .02825 L
.51409 .02825 L
.51581 .02827 L
.52376 .02835 L
.53125 .02843 L
.53328 .02845 L
.53429 .02847 L
.53521 .02848 L
Mistroke
.53547 .02849 L
.53572 .02849 L
.53598 .02849 L
.53627 .02849 L
.53742 .0285 L
.53944 .02852 L
.54321 .02854 L
.54528 .02856 L
.54631 .02857 L
.54726 .02857 L
.54908 .02858 L
.54957 .02859 L
.55004 .02859 L
.55029 .02859 L
.55057 .02859 L
.55106 .02859 L
.55274 .02858 L
.55318 .02858 L
.55366 .02858 L
.55411 .02857 L
.55453 .02857 L
.55552 .02856 L
.55641 .02855 L
.55816 .02853 L
.56006 .02851 L
.56214 .02849 L
.56415 .02846 L
.56604 .02842 L
.57017 .0283 L
.57393 .02819 L
.57484 .02816 L
.57582 .02813 L
.5761 .02812 L
.57638 .02812 L
.57662 .02811 L
.57689 .02812 L
.57788 .02814 L
.58493 .02831 L
.58668 .02835 L
.58714 .02836 L
.58764 .02837 L
.58811 .02838 L
.58855 .02838 L
.58962 .02839 L
.5906 .02839 L
.59108 .0284 L
.59153 .0284 L
.592 .0284 L
.59252 .02839 L
.5944 .02838 L
Mistroke
.59486 .02838 L
.59534 .02838 L
.59562 .02837 L
.59588 .02837 L
.59638 .02837 L
.5975 .02835 L
.59804 .02834 L
.59855 .02834 L
.59901 .02833 L
.59951 .02832 L
.60054 .0283 L
.60413 .0282 L
.60516 .02817 L
.60567 .02815 L
.60615 .02813 L
.60657 .02813 L
.60703 .02813 L
.60799 .02815 L
.61162 .02822 L
.61322 .02826 L
.61365 .02827 L
.61412 .02827 L
.61456 .02828 L
.61496 .02828 L
.61588 .02829 L
.61687 .0283 L
.61713 .0283 L
.61741 .0283 L
.61791 .0283 L
.61837 .0283 L
.61889 .0283 L
.61994 .0283 L
.62049 .02829 L
.62079 .02829 L
.62107 .02829 L
.62132 .02829 L
.62159 .02829 L
.62215 .02828 L
.62313 .02826 L
.6252 .02821 L
.62716 .02816 L
.62801 .02814 L
.62847 .02812 L
.62891 .02812 L
.62938 .02813 L
.6299 .02816 L
.63081 .02819 L
.63173 .02823 L
.63224 .02825 L
.63271 .02827 L
Mistroke
.63328 .02828 L
.63379 .0283 L
.63478 .02832 L
.63566 .02835 L
.63614 .02836 L
.63659 .02837 L
.63708 .02837 L
.63761 .02838 L
.63855 .02839 L
.63899 .02839 L
.63947 .02839 L
.63992 .0284 L
.64033 .02839 L
.64071 .02839 L
.64112 .02839 L
.64196 .02838 L
.64287 .02837 L
.64337 .02836 L
.64385 .02835 L
.64429 .02834 L
.64477 .02832 L
.64561 .02829 L
.64658 .02826 L
.64709 .02824 L
.64737 .02823 L
.64763 .02823 L
.64811 .02822 L
.64863 .02821 L
.64954 .02819 L
.65042 .02817 L
.65086 .02817 L
.65126 .02816 L
.65172 .02818 L
.65222 .02821 L
.6531 .02825 L
.65407 .0283 L
.65457 .02833 L
.65485 .02834 L
.6551 .02835 L
.65557 .02836 L
.65608 .02838 L
.65698 .0284 L
.658 .02843 L
.65845 .02844 L
.65893 .02845 L
.65921 .02845 L
.65947 .02844 L
.65998 .02844 L
.66109 .02844 L
.66157 .02843 L
Mistroke
.66202 .02843 L
.66243 .02843 L
.66287 .02842 L
.66478 .02836 L
.66824 .02822 L
.66873 .02819 L
.66926 .02817 L
.66975 .02814 L
.67021 .02814 L
.67047 .02815 L
.67075 .02816 L
.67132 .02818 L
.67232 .02821 L
.67413 .02827 L
.6761 .02833 L
.6766 .02834 L
.67688 .02835 L
.67714 .02836 L
.6776 .02837 L
.67784 .02836 L
.6781 .02836 L
.67902 .02835 L
.68 .02834 L
.68042 .02834 L
.68088 .02833 L
.68138 .02832 L
.68185 .0283 L
.68354 .02823 L
.68405 .02821 L
.68458 .02818 L
.68485 .02817 L
.68516 .02817 L
.68544 .02817 L
.68569 .02817 L
.68675 .02818 L
.68772 .02818 L
.68817 .02818 L
.68866 .02819 L
.68912 .0282 L
.68955 .02821 L
.69058 .02824 L
.69152 .02827 L
.69196 .02828 L
.69237 .02829 L
.6928 .02829 L
.69328 .02829 L
.69427 .02829 L
.69518 .02829 L
.69558 .02829 L
.69603 .02828 L
Mistroke
.69645 .02827 L
.69684 .02826 L
.69861 .02819 L
.69907 .02817 L
.69955 .02815 L
.70001 .02815 L
.70043 .02816 L
.70242 .02823 L
.70438 .0283 L
.70545 .02834 L
.70646 .02838 L
.70692 .0284 L
.7074 .02841 L
.70766 .02841 L
.70794 .02841 L
.70843 .0284 L
.71021 .02839 L
.71066 .02838 L
.71108 .02837 L
.71157 .02835 L
.71201 .02832 L
.71369 .02823 L
.71419 .02821 L
.71465 .02818 L
.71513 .02818 L
.71538 .02819 L
.71566 .02819 L
.71748 .02823 L
.71802 .02824 L
.71852 .02825 L
.71878 .02826 L
.71905 .02828 L
.71962 .0283 L
.72056 .02834 L
.72109 .02836 L
.72159 .02838 L
.72207 .0284 L
.72233 .02841 L
.72258 .02841 L
.72362 .0284 L
.72459 .0284 L
.72507 .0284 L
.72549 .0284 L
.726 .02839 L
.72627 .02838 L
.72653 .02837 L
.72766 .02831 L
.72867 .02826 L
.72921 .02823 L
.72948 .02822 L
Mistroke
.72972 .02821 L
.73017 .02821 L
.73064 .02821 L
.73165 .02822 L
.73257 .02822 L
.73297 .02822 L
.73342 .02822 L
.73389 .02824 L
.7344 .02825 L
.73546 .02828 L
.73595 .0283 L
.73647 .02832 L
.73696 .02833 L
.7374 .02833 L
.73789 .02832 L
.73835 .0283 L
.73938 .02827 L
.74036 .02824 L
.74079 .02823 L
.74126 .02822 L
.74208 .02822 L
.74295 .02821 L
.74341 .0282 L
.7439 .0282 L
.74437 .02819 L
.74479 .0282 L
.74679 .02828 L
.7478 .02832 L
.74808 .02833 L
.74838 .02834 L
.74866 .02834 L
.74892 .02833 L
.75074 .02831 L
.75124 .0283 L
.75152 .02829 L
.75178 .02829 L
.75202 .02829 L
.75228 .02828 L
.75274 .02826 L
.75364 .02822 L
.75458 .02818 L
.75539 .02814 L
.75585 .02812 L
.75628 .02815 L
.75819 .02828 L
.75865 .02831 L
.75913 .02834 L
.75959 .02837 L
.76001 .02838 L
.76096 .0284 L
Mistroke
.762 .02842 L
.76245 .02843 L
.76293 .02844 L
.76339 .02845 L
.76382 .02843 L
.76579 .02834 L
.76632 .02832 L
.76659 .02831 L
.76688 .02829 L
.76714 .02829 L
.76742 .02828 L
.76791 .02827 L
.76892 .02825 L
.76986 .02823 L
.77027 .02822 L
.77071 .02821 L
.77119 .02823 L
.77163 .02825 L
.7733 .02833 L
.77379 .02836 L
.77424 .02838 L
.77465 .02839 L
.77509 .02838 L
.77704 .02833 L
.77885 .02827 L
.77989 .02823 L
.78099 .02819 L
.78145 .02818 L
.78193 .02816 L
.78221 .02817 L
.78247 .02818 L
.78297 .0282 L
.78479 .02827 L
.78504 .02828 L
.78532 .0283 L
.78581 .02831 L
.78629 .0283 L
.78673 .02829 L
.78761 .02826 L
.78854 .02824 L
.78899 .02823 L
.78942 .02822 L
.7898 .02822 L
.79022 .02822 L
.79206 .02823 L
.79257 .02823 L
.79284 .02823 L
.7931 .02823 L
.79356 .02825 L
.79407 .02828 L
Mistroke
.79602 .02838 L
.79629 .0284 L
.79659 .02841 L
.79686 .02843 L
.79712 .02843 L
.79761 .02842 L
.79813 .02841 L
.79911 .0284 L
.80003 .02838 L
.80049 .02838 L
.80099 .02835 L
.80204 .02828 L
.8032 .02819 L
.8037 .02816 L
.80397 .02814 L
.80425 .02812 L
.80451 .02812 L
.80479 .02814 L
.80529 .02818 L
.80628 .02826 L
.80721 .02833 L
.80772 .02837 L
.80819 .0284 L
.80844 .0284 L
.8087 .0284 L
.80926 .0284 L
.81024 .02841 L
.81073 .02841 L
.81125 .02841 L
.81174 .02841 L
.81219 .02839 L
.81397 .02826 L
.81488 .02819 L
.81533 .02815 L
.81575 .02814 L
.81622 .02816 L
.81675 .02819 L
.81766 .02823 L
.81852 .02827 L
.81894 .02829 L
.81933 .02831 L
.81978 .0283 L
.82027 .02829 L
.82111 .02828 L
.82199 .02826 L
.82248 .02826 L
.82294 .02825 L
.8232 .02825 L
.82348 .02825 L
.82397 .02825 L
Mistroke
.82494 .02825 L
.82596 .02825 L
.82647 .02825 L
.82676 .02825 L
.82704 .02826 L
.82898 .02837 L
.82984 .02842 L
.83033 .02845 L
.83077 .02845 L
.83102 .02845 L
.83129 .02844 L
.83179 .02842 L
.83273 .02839 L
.83465 .02833 L
.8357 .02828 L
.83668 .02824 L
.83752 .0282 L
.838 .02818 L
.83843 .02821 L
.84035 .02835 L
.84118 .02841 L
.84165 .02844 L
.84209 .02844 L
.84247 .02844 L
.84288 .02844 L
.84373 .02843 L
.8442 .02842 L
.8447 .02841 L
.84517 .02841 L
.8456 .0284 L
.84609 .02836 L
.84654 .02832 L
.84757 .02824 L
.84839 .02817 L
.84884 .02814 L
.84926 .02811 L
.84971 .02814 L
.85021 .02816 L
.85109 .02821 L
.85212 .02826 L
.85236 .02828 L
.85262 .02829 L
.85309 .0283 L
.85355 .02829 L
.85397 .02827 L
.85492 .02824 L
.85594 .02821 L
.85622 .0282 L
.85651 .02819 L
.85676 .02819 L
Mistroke
.85704 .0282 L
.85904 .02831 L
.86103 .02841 L
.86202 .02846 L
.86293 .0285 L
.86375 .02854 L
.86417 .02856 L
.86463 .02852 L
.86647 .02839 L
.86698 .02835 L
.86751 .02831 L
.86796 .02829 L
.86845 .0283 L
.86948 .02831 L
.87058 .02833 L
.87112 .02834 L
.87139 .02834 L
.87163 .02835 L
.87209 .02837 L
.87258 .02839 L
.87355 .02843 L
.87444 .02847 L
.87488 .02849 L
.87536 .0285 L
.87581 .02847 L
.87622 .02845 L
.87723 .02838 L
.87814 .02832 L
.87855 .02829 L
.879 .02826 L
.87942 .02826 L
.87981 .02825 L
.88159 .02824 L
.88248 .02824 L
.88297 .02824 L
.88342 .02824 L
.88446 .02823 L
.88542 .02823 L
.88591 .02823 L
.88617 .02823 L
.88642 .02823 L
.88668 .02823 L
.88698 .02824 L
.8875 .02825 L
.88851 .02826 L
.88901 .02827 L
.88946 .02828 L
.88993 .02829 L
.89037 .0283 L
.89084 .02834 L
Mistroke
.89135 .02839 L
.89235 .02849 L
.8929 .02854 L
.89341 .02859 L
.89386 .02863 L
.89434 .02865 L
.89462 .02865 L
.89488 .02865 L
.89537 .02865 L
.89624 .02865 L
.89672 .02865 L
.89717 .02865 L
.89757 .02865 L
.898 .02862 L
.89848 .02857 L
.89892 .02853 L
.90055 .02835 L
.90096 .02831 L
.9014 .02826 L
.90189 .02826 L
.90234 .02828 L
.90422 .02833 L
.90473 .02834 L
.90521 .02836 L
.90571 .02836 L
.90597 .02836 L
.90625 .02835 L
.90715 .02835 L
.90812 .02835 L
.90841 .02835 L
.90871 .02834 L
.909 .02834 L
.90926 .02834 L
.91033 .02832 L
.91138 .0283 L
.91185 .02829 L
.91209 .02828 L
.91235 .02828 L
.91283 .02828 L
.91328 .02831 L
.91425 .02838 L
.91531 .02846 L
.91583 .0285 L
.91631 .02853 L
.91676 .02851 L
.91724 .02847 L
.91825 .02838 L
.9191 .02831 L
.91958 .02826 L
.92003 .02823 L
Mistroke
.92047 .02825 L
.92094 .0283 L
.92189 .0284 L
.9236 .02859 L
.92559 .02876 L
.92656 .02885 L
.92699 .02888 L
.92746 .02892 L
.9279 .02892 L
.92831 .0289 L
.92921 .02884 L
.9302 .02878 L
.93064 .02876 L
.93111 .02873 L
.93153 .0287 L
.93193 .02866 L
.93271 .02858 L
.93442 .0284 L
.93487 .02836 L
.93534 .02833 L
.93574 .02832 L
.93618 .02832 L
.9371 .0283 L
.93761 .0283 L
.93808 .02829 L
.93853 .02828 L
.93901 .0283 L
.93946 .02834 L
.93986 .02839 L
.94152 .02857 L
.94557 .02918 L
.94755 .02942 L
.94842 .0295 L
.94888 .02954 L
.94936 .02959 L
.94984 .02963 L
.95028 .02963 L
.95072 .0296 L
.95113 .02956 L
.9528 .02942 L
.95325 .02938 L
.95373 .02934 L
.95413 .02927 L
.95458 .02919 L
.9565 .02882 L
.95703 .02872 L
.95753 .02863 L
.95797 .0286 L
.95846 .02858 L
.95948 .02852 L
Mistroke
.96004 .02849 L
.96056 .02846 L
.96101 .02844 L
.9615 .02848 L
.96176 .02854 L
.96204 .0286 L
.96253 .0287 L
.96436 .0291 L
.96732 .02988 L
.96773 .03 L
.96817 .03012 L
.96859 .03024 L
.96898 .03028 L
.96933 .03028 L
.96971 .03028 L
.97049 .03028 L
.97122 .03029 L
.97191 .03029 L
.97229 .03029 L
.97271 .03023 L
.97308 .03013 L
.97343 .03003 L
.97619 .0293 L
Mfstroke
1 0 0 r
.02381 .58994 m
.03853 .58385 L
.05458 .57563 L
.06965 .56721 L
.08415 .55877 L
.09958 .54962 L
.11444 .54074 L
.13023 .53129 L
.14544 .52217 L
.16007 .51339 L
.17564 .50406 L
.19063 .49508 L
.20504 .48645 L
.22039 .47726 L
.23516 .46841 L
.25087 .45901 L
.26599 .44996 L
.28054 .44126 L
.29603 .432 L
.31093 .42308 L
.32678 .41361 L
.34204 .40449 L
.35672 .39571 L
.37234 .38637 L
.38739 .37738 L
.40185 .36874 L
.41725 .35954 L
.43208 .35068 L
.44783 .34127 L
.46301 .3322 L
.47761 .32348 L
.49315 .3142 L
.50811 .30527 L
.52249 .29668 L
.5378 .28753 L
.55254 .27873 L
.56821 .26936 L
.58331 .26034 L
.59783 .25167 L
.61328 .24244 L
.62815 .23355 L
.64396 .2241 L
.65919 .21499 L
.67385 .20623 L
.68943 .19691 L
.70445 .18794 L
.71888 .1793 L
.73425 .17011 L
.74904 .16126 L
.76476 .15184 L
Mistroke
.77991 .14277 L
.79448 .13405 L
.80998 .12476 L
.82491 .11582 L
.84077 .10631 L
.85605 .09714 L
.87076 .08833 L
.8864 .07896 L
.90146 .06998 L
.91595 .06142 L
.93137 .05247 L
.94621 .0442 L
.96198 .03605 L
.97619 .02936 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008oooool2o`0001kooooo1Ol00002ooooo`?o00007Oooool3o`0000Cooooo0_l0000Moooo
o`03o`000?oooooooooo00;ooooo0ol0000Jooooo`?o00001?ooool2o`0000Cooooo0_l0000Foooo
o`?o00000_ooool5o`0000;ooooo0ol0000Gooooo`?o00000oooool3o`0000Cooooo0_l0000Doooo
o`008_ooool01?l0003oooooooooool0000Nooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool0000Looooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Fooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool04Oooool002;ooooo00Co0000oooooooooooo00007oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool04Oooool002;ooooo00Co0000oooooooooooo00008?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool04Oooool002;ooooo
00Co0000oooooooooooo00007Oooool01_l0003ooooooooooooooooo0000ooooo`Co00007?ooool4
o`0000?ooooo00Co0000oooooooooooo00007_ooool00ol0003oooooo`000003o`0001_ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Ko
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?o00006?ooool01?l0
003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00004oooool002;ooooo00Co0000
oooooooooooo00007Oooool01ol0003ooooooooooooooooo0000ooooool000007oooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001[ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000001gooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00005Oooool2o`0000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000001[ooooo0_l00003
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00004oooool002?ooooo0_l0000O
ooooo`?o00000_ooool5o`0001_ooooo1Ol00003ooooo`;o00006oooool5o`000003ooooool0003o
000000?o00006_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0001Oooooo00?o0000
ooooooooool00_ooool3o`0000;ooooo1Ol0000Gooooo`04o`000?ooooooooooooooo`Go00000ooo
ool2o`0001Cooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
000NooooooSo00002_ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`3doooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo0?Cooooo00?o0000oooooooo
ool02?ooool001Oooooo0_l00005ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool0
2?ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3dooooo`03o`00
0?oooooooooo00Sooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
m?ooool00ol0003oooooooooo`08ooooo`005_ooool01?l0003oooooooooool00004ooooo`;o0000
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo
00001?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000ol000000ooo
oooo0000o`00002bo`0000;oo`001?ooool2o`0000[ooooo000Fooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003ooooo00[o000000Koooooo`000?ooooooooooo`000?ooool3o`000;;ooooo00?oo`00oooooooo
ool01Oooool00ol0003oooooooooo`08ooooo`005_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooool000000_ooool01Ol0003oooooooooool0003ooooo
00;o00001?ooool01?l0003oooooo`000?ooool2o`000005ooooool0003o0000o`000?ooool00_l0
00000ooooooo0000o`000007ooooo`03o`000?oooooooooo0;Sooooo0_oo0008ooooo`03o`000?oo
oooooooo00Sooooo000Gooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`?o00000_ooool0
1Ol0003oooooooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`07o`000003oooo
ool0003ooooo0<Gooooo0_oo000:ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Sooooo0ol00002ooooo`05o`000?ooooooooooo`000?ooool01?l000001?oooooo0000
ooooool00002ooooo`04o`000?oooooo0000o`000<Kooooo0_oo000<ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`03o`000?oooooo000000Go
000000?oooooo`000?l00000c?ooool2ool000kooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool02?ooool3o`000008ooooool0003o0000ooooool0003oooooo`000?ooool2
o`000003ooooool0003o00000<[ooooo0_oo000@ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`;o00002Oooool6o`000003ooooool0003ooooo00;ooooo00Co0000oooooooooooo0000bOooool2
ool0017ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0003>ooooo`;oo`005?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`08ooooo`;o000000Coooooo`000?l0003ooooo0_l0003=ooooo`03ool00?oooooo
oooo01Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02?ooool2o`00
0004ooooool0003o0000ooooo`;o0000boooool2ool001Oooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02o`000003ooooool0003o0000
0<Wooooo0_oo000Iooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00So
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo0<Gooooo0_oo000Koooo
o`03o`000?oooooooooo00Sooooo000Nooooo`;o00002Oooool00ol0003oooooooooo`3:ooooo`;o
o`007?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
b?ooool2ool001oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`37ooooo`03ool00?oooooooooo01oooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`36ooooo`03ool00?oooooo
oooo023ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`34ooooo`;oo`008oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0<?ooooo00?oo`00ooooooooool08oooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<7ooooo
0_oo000Vooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00002Oooool00ol0003ooooooooo
o`2oooooo`;oo`009oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooool00000_oooool2ool002[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooo`00002mooooo`;oo`00;?ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`000?ooool0^_ooool2ool002ko
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool3o`000;_ooooo
00?oo`00ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Cooooo00Co
0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo00Gooooo0ol0002jooooo`03ool0
0?oooooooooo02oooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo0ol0002hooooo`;o
o`00<_ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00Cooooo0_l00006ooooo`?o0000]oooool00ooo003oooooooooo`0aooooo`;o
00002_ooool000[ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo0ol0002eooooo`;oo`00=Oooool00ol0003oooooooooo`08ooooo`00
2_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`05ooooo`?o0000/oooool2ool003Oooooo00?o0000ooooooooool02?ooool000[o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool01Oooool3o`000;7ooooo0_oo000iooooo`03o`000?oooooooooo00Sooooo000;oooo
o`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo00?oo`00oooo
ooooool0>Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`?o
0000[oooool00ooo003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Gooooo0ol0002]ooooo`;oo`00?Oooool00ol0003oooooooooo`08ooooo`007_oo
ool2o`0000Kooooo0ol0002[ooooo`;oo`00?_ooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo0ol0002Yooooo`;oo`00@Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`05ooooo`?o0000Z?ooool00ooo003oooooooooo`11ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo0ol0002Vooooo`;oo`00A?ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`?o0000Y?ooool2ool004Kooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool3o`000:;ooooo0_oo
0018ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo0ol0002P
ooooo`;oo`00B_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Kooooo0ol0002Noooo
o`;oo`00Boooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0WOooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0W?ooool00ooo003oooooooooo`1=ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0V_oo
ool2ool0053ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2Iooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Gooooo`;oo`00Doooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Go
oooo0_oo001Eooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001_ooool00ol0003ooooo
ooooo`2Cooooo`;oo`00E_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0TOooool2ool005Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2?ooooo`;oo`00Foooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08kooooo00?oo`00oooo
ooooool0Foooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo08kooooo00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`08ooooo`00
2oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2<ooooo`;oo`00Goooool00ol0003oooooooooo`08ooooo`002_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2;ooooo`03ool00?oooooooooo05oooooo00?o0000ooooooooool0
2?ooool000[ooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo08Wooooo0_oo001Qooooo`;o00002_ooool000[ooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Qoooool2ool006Cooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0QOooool2ool006Kooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo
00002Oooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`23ooooo`;o
o`00J?ooool00ol0003oooooooooo`08ooooo`002oooool2o`0000_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo087ooooo0_oo001Zooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0P?oo
ool00ooo003oooooooooo`1Zooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Ooooool00ooo003oooooooooo`1[ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1mooooo`;oo`00KOooool2o`00
00[ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0O?ooool00ooo003o
ooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0N_ooool2ool0077ooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1hooooo`;oo`00Loooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Kooooo0_oo001e
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0M?ooool2ool007Oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1booooo`;oo`00NOooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0000Gooooo00?o0000ooooooooool0LOooool00ooo003oooooooooo`1hooooo`;o0000
2_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1_ooooo`;oo`00O?oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06kooooo00?oo`00ooooooooool0O?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo00?oo`00ooooooooool0OOooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06_o
oooo0_oo0020ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0JOooool2ool008;ooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`;oo`00Q?ooool00ol0003ooooooooo
o`08ooooo`007_ooool2o`0000Gooooo00?o0000ooooooooool0I_ooool00ooo003oooooooooo`23
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Toooo
o`;oo`00Qoooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06;ooooo0_oo0029ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0H?ooool2ool008_ooooo00?o0000ooooooooool0
2?ooool000_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Goooool00ooo003oooooooooo`2;ooooo`03o`000?oo
oooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0G_ooool00ooo003ooooo
ooooo`2<ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0G?ooool2ool008oooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo
00001oooool4o`0000Gooooo0_l00005ooooo`03o`000?oooooooooo05[ooooo0_oo002@ooooo`;o
00002_ooool000[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0F?ooool2ool009?ooooo00?o0000oooooooo
ool02?ooool000[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Eoooool00ooo003oooooooooo`2Cooooo`03
o`000?oooooooooo00Sooooo000;ooooo`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Eooooo`;oo`00U_ooool00ol0003oooooooooo`08ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05?ooooo0_oo002Hooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0DOooool2
ool009[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1?ooooo`;oo`00W?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Go
oooo00?o0000ooooooooool0COooool2ool009gooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool0W_ooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_ooooo00?o
o`00ooooooooool0Woooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo04Wooooo0_oo002Rooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0B?ooool00ooo003oooooooooo`2Roooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0A_ooool2ool00:Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`14ooooo`;oo`00Yoooool00ol0003oooooooooo`08ooooo`007_oo
ool2o`0000Gooooo00?o0000ooooooooool0@_ooool2ool00:Sooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo0_oo002[ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool2ool0
0:gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0mooooo`03ool00?oooooooooo0:gooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0looooo`03ool00?oooooooooo0:kooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0jooooo`;oo`00/Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03Wooooo00?oo`00ooooooooool0/Oooool00ol0003oooooooooo`08
ooooo`007_ooool2o`0000Gooooo00?o0000ooooooooool0=oooool2ool00;?ooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Gooooo0_oo002fooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
<oooool2ool00;Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0aooooo`;oo`00^_ooool00ol0003oooooooooo`08ooooo`002oooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0_ooooo`;oo`00_?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02kooooo00?oo`00ooooooooool0_?ooool00ol0003ooooooooo
o`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00?oo`00ooooooooool0
_Oooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00008ooooo`?o0000
1Oooool2o`0000Gooooo00?o0000ooooooooool0:oooool2ool00;oooooo0_l0000:ooooo`002_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0`?ooool00ol0003o
ooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo0_oo0033oooo
o`03o`000?oooooooooo00Sooooo000;ooooo`;o00002Oooool3o`0000Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Vooooo`;oo`00aOooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo0_oo0037ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08ooo
ool2ool00<Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Qooooo`;oo`00boooool00ol0003oooooooooo`08ooooo`007_ooool2o`00
00Cooooo00?o0000ooooooooool08?ooool00ooo003oooooooooo`3:ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03ool00?oooooooooo0<co
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Mooooo`;oo`00coooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0coooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo0_oo003B
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06?ooool2ool00=Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Fooooo`;oo`00e_ooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0000Cooooo00?o0000ooooooooool05?ooool2ool00=Oooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo0_oo003Jooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool0
0ooo003oooooooooo`3Jooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03oooool2ool00=gooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo0=go
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0=ooooo`03ool00?oooooooooo0=kooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`;oo`00hOooool00ol0003ooooooooo
o`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool02Oooool2ool00>;ooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0_oo003Uoooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool2ool00>Oooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`;oo`00jOooool00ol0003oooooooooo`08ooooo`005_oo
ool3o`0000Gooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2ool00>_ooooo
00?o0000ooooooooool02?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooo`00ool00>gooooo00?o0000ooooooooool02?ooool001Oooooo00?o
0000ooooooooool01?ooool2o`0000Cooooo0_oo003^ooooo`;o00002_ooool001Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000Goooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`08oooo
o`005_ooool2o`0000Kooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`08ooooo`00
5oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool2
o`0000[ooooo000NooooooSo00002_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool004Gooooo0_l000001Ooooooo0000o`000?l0003ooooo
00?o00000oooool4o`0000?ooooo0_l000000ooooooo0000o`000004o`0000;ooooo1?l00003oooo
o`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000001oooool3o`00
00;ooooo0ol00004ooooo`Co000000Goooooo`000?l0003o0000ooooo`06o`0000;ooooo1Ol00002
ooooo`?o00000_ooool3o`0000Wooooo0ol00005ooooo`;o000000?oooooo`000?l000000_l00000
1?oooooo0000o`000?ooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000;ooooo0ol0
00000ooooooo0000o`00000cooooo`00AOooool01ol0003ooooooooooooooooo0000ooooool00000
0oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0003Cooooo0015ooooo`07o`00
0?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool3o`0000?ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool3o`0000Cooooo00Co0000oooo
oooooooooooo1Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo03;ooooo0015ooooo`07o`000?ooooooooooooooool0003oooooo`00
0003ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`;o00000oooool01?l0003ooooooooo
ool00003ooooo`06o`000?ooooooooooo`000?oooooo00001oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_l0000:ooooo`?o00000oooool01?l0003oooooooooool0
0002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00006oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo03;ooooo0015ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000?ooooo0ol0
0002ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02ooooo`;o00000ooo
ool4o`0000;ooooo0ol00004ooooo`?o00000_ooool4o`0000Sooooo00Ko0000ooooool0003ooooo
o`000?ooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co00000oooool4o`0000;o
oooo1?l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000Sooooo00?o0000oooooooo
ool00_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool3o`0000;ooooo1?l00002oooo
o`?o00001?ooool3o`0000;ooooo1?l0000eooooo`00AOooool2o`000003ooooool0003o000000[o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[o
oooo00Go0000ooooool0003oooooo`00000Kooooo`03o`000?oooooooooo01Cooooo00Co0000oooo
oooooooo00005?ooool00ol0003oooooooooo`17ooooo`00AOooool01?l0003oooooooooooooool2
o`0000Sooooo0_l00008ooooo`?o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01?ooooo1Ol0000Looooo`;o00004oooool5o`0001Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`10ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.1718, -0.137062, \
0.666191, 0.00720095}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(56.069999999999936`\ Second\), ",", 
        RowBox[{"{", 
          
          RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
            ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
            ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
            ",", \(ColorFunction \[Rule] \
\((Hue[\(\(0.65`\)\(\[InvisibleSpace]\)\) - #1\ 0.65`, 
                    1, #1\ 0.9` + 0.1`] &)\)\), 
            ",", \(ComponentNumber \[Rule] 5\), 
            ",", \(CosineCompensation \[Rule] True\), 
            ",", \(DiffractionSpotSize \[Rule] {0.31892791998540704`, 
                0.31902530378278937`}\), ",", \(Energy \[Rule] 100.`\), 
            ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
            ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
            ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
            ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\),
             ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
                  0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
            ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
            ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
            ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
            ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
            ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 
                  0, 1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
            ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
                SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
            ",", \(FilterTrace \[Rule] True\), 
            ",", \(FindImagePoint \[Rule] True\), 
            ",", \(FindPupils \[Rule] Automatic\), 
            ",", \(FocalFraction \[Rule] 1\), 
            ",", \(FocalLength \[Rule] 50.218237368297935`\), 
            ",", \(FrequencyCutoff \[Rule] {313.63906357794895`, 
                313.5413257777562`}\), 
            ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
            ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
            ",", \(GeometricPointSpreadFunction \[Rule] False\), 
            ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
            ",", \(ImagePoint \[Rule] {204.05713195686332`, 
                0, \(-0.00005753365477167982`\)}\), 
            ",", \(ImageSampleSize \[Rule] {0.0016107470706333688`, 
                0.0016112389079938857`}\), ",", 
            RowBox[{"ImagingOptics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      
                      TagBox[\(Move[
                          PlanoConvexLens[{f1, 100}, 50, 
                            9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                        HoldForm],
                      FontColor->RGBColor[0, 0.392187, 0]],
                    DisplayForm], ",", 
                  TagBox[
                    StyleBox[
                      TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                        HoldForm],
                      FontColor->RGBColor[0, 0.392187, 0]],
                    DisplayForm], ",", 
                  TagBox[
                    StyleBox[
                      
                      TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 
                          100.5`]\),
                        HoldForm],
                      FontColor->RGBColor[0, 0.392187, 0]],
                    DisplayForm], ",", 
                  TagBox[
                    StyleBox[
                      
                      TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                            104}, {GraphicDesign \[Rule] Off}]\),
                        HoldForm],
                      FontColor->RGBColor[0, 0.392187, 0]],
                    DisplayForm]}], "}"}]}], 
            ",", \(IntensityScale \[Rule] 1\), 
            ",", \(IntensitySetting \[Rule] Automatic\), 
            ",", \(IntensityTransform \[Rule] True\), 
            ",", \(InterceptHole \[Rule] True\), 
            ",", \(InterpolationOrder \[Rule] 1\), 
            ",", \(KernelScale \[Rule] Relative\), 
            ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
                  12.031844948762183`}, {\(-0.019913084417241732`\), 
                  0.8720142520854433`}}\), ",", 
            RowBox[{"ModulationTransferFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-157.43451034500967`\), 
                      156.8195317889745`}, {\(-157.3854498021678`\), 
                      156.7706628888781`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(NormalizePlot \[Rule] True\), 
            ",", \(NumberOfPoints \[Rule] 256\), ",", 
            RowBox[{"ObjectSource", "\[Rule]", 
              TagBox[
                StyleBox[
                  TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], ",", \(Offset \[Rule] 112.44623075723894`\), 
            ",", \(OpticalLengthFunction \[Rule] OpticalLengthFunction\), 
            ",", \(OpticalMedium \[Rule] Air\), ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(CompiledFunction[
                  If[#1 == 0 && #2 == 
                        0, \(-0.04258581442730779`\), \(\(13.740815548199524`\
\)\(\[InvisibleSpace]\)\) + 
                      0.001071207261289709`\ Sin[
                          ArcTan[#1, #2]]\ \@\(#1\^2 + #2\^2\) - 
                      3.725888253390231`*^-9\ Cos[
                          2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                      2.073954830140741`*^-10\ Cos[
                          4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 + 
                      10.349811461600856`\ \((\(-1\) + 
                            0.013994945211085998`\ \((#1\^2 + #2\^2)\))\) + 
                      2.6593311422795596`*^-7\ Sin[
                          ArcTan[#1, #2]]\ \((\(-0.1673017944379916`\)\ \
\@\(#1\^2 + #2\^2\) + 
                            0.0017560345851570483`\ \((#1\^2 + \
#2\^2)\)\^\(3/2\))\) - 
                      5.535676851136646`*^-7\ Cos[
                          2\ ArcTan[#1, #2]]\ \((\(-0.020992417816628996`\)\ \
\((#1\^2 + #2\^2)\) + 0.0001958584914612989`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                      3.455317518679625`\ \((1 - 
                            0.04198483563325799`\ \((#1\^2 + #2\^2)\) + 
                            0.0002937877371919484`\ \((#1\^2 + #2\^2)\)\^2)\) \
- 1.68436899812057`*^-10\ Sin[
                          3\ ArcTan[#1, #2]]\ \((\(-0.0023413794468760646`\)\ \
\((#1\^2 + #2\^2)\)\^\(3/2\) + 
                            0.000020479673173370852`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) - 2.784064156212324`*^-7\ Sin[
                          ArcTan[#1, #2]]\ \((0.2509526916569874`\ \@\(#1\^2 \
+ #2\^2\) - 0.007024138340628193`\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                            0.000040959346346741704`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) + 
                      4.523897543979615`*^-6\ Cos[
                          4\ ArcTan[#1, #2]]\ \((\(-0.00024482311432662366`\)\
\ \((#1\^2 + #2\^2)\)\^2 + 
                            2.0557716428451247`*^-6\ \((#1\^2 + \
#2\^2)\)\^3)\) - 3.580794259874557`*^-7\ Cos[
                          2\ ArcTan[#1, #2]]\ \((0.04198483563325799`\ \
\((#1\^2 + #2\^2)\) - 0.0009792924573064946`\ \((#1\^2 + #2\^2)\)\^2 + 
                            5.139429107112812`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) \
- 0.021947830907166472`\ \((\(-1\) + 
                            0.08396967126651599`\ \((#1\^2 + #2\^2)\) - 
                            0.0014689386859597418`\ \((#1\^2 + #2\^2)\)\^2 + 
                            6.852572142817083`*^-6\ \((#1\^2 + #2\^2)\)\^3)\) \
- 1.0028711408069819`*^-10\ Sin[
                          3\ ArcTan[#1, #2]]\ \((0.005853448617190162`\ \((#1\
\^2 + #2\^2)\)\^\(3/2\) - 
                            0.0001228780390402251`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\) + 6.018849984047728`*^-7\ \((#1\^2 + #2\^2)\)\^\(7/2\))\) - 
                      4.711797018772064`*^-9\ Sin[
                          ArcTan[#1, #2]]\ \((\(-0.3346035888759832`\)\ \
\@\(#1\^2 + #2\^2\) + 0.017560345851570486`\ \((#1\^2 + #2\^2)\)\^\(3/2\) - 
                            0.0002457560780804502`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\) + 
                            1.0031416640079548`*^-6\ \((#1\^2 + \
#2\^2)\)\^\(7/2\))\) - 
                      7.766973189673772`*^-8\ Cos[
                          6\ ArcTan[#1, #2]]\ \((\(-2.398400249985979`*^-6\)\ \
\((#1\^2 + #2\^2)\)\^3 + 1.918027433874785`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) + 
                      3.3609248320370405`*^-6\ Cos[
                          4\ ArcTan[#1, #2]]\ \((0.0007344693429798709`\ \
\((#1\^2 + #2\^2)\)\^2 - 0.000014390401499915874`\ \((#1\^2 + #2\^2)\)\^3 + 
                            6.713096018561747`*^-8\ \((#1\^2 + #2\^2)\)\^4)\) \
- 1.3617876806168808`*^-7\ Cos[
                          2\ ArcTan[#1, #2]]\ \((\(-0.06997472605542998`\)\ \
\((#1\^2 + #2\^2)\) + 0.0029378773719194837`\ \((#1\^2 + #2\^2)\)\^2 - 
                            0.000035976003749789686`\ \((#1\^2 + #2\^2)\)\^3 \
+ 1.3426192037123494`*^-7\ \((#1\^2 + #2\^2)\)\^4)\) - 
                      0.00022021325351762418`\ \((1 - 
                            0.13994945211085996`\ \((#1\^2 + #2\^2)\) + 
                            0.004406816057879226`\ \((#1\^2 + #2\^2)\)\^2 - 
                            0.00004796800499971958`\ \((#1\^2 + #2\^2)\)\^3 + 
                            1.678274004640437`*^-7\ \((#1\^2 + \
#2\^2)\)\^4)\)], "-CompiledCode-"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {112.44623075723894`, 
                112.45720228085494`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"PointSpreadFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"ModulationTransferFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(PaddingFactor \[Rule] Automatic\), 
            ",", \(ParaxialReductionRatio \[Rule] 0.001`\), ",", 
            RowBox[{"PerfectModulationTransferFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-157.43451034500967`\), 
                      156.8195317889745`}, {\(-157.3854498021678`\), 
                      156.7706628888781`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"PerfectPhaseTransferFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-157.43451034500967`\), 
                      156.8195317889745`}, {\(-157.3854498021678`\), 
                      156.7706628888781`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"PerfectPointSpreadFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-0.20456487797043785`\), 
                      0.2061756250410712`}, {\(-0.20462734131522348`\), 
                      0.20623858022321734`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"PhaseTransferFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-157.43451034500967`\), 
                      156.8195317889745`}, {\(-157.3854498021678`\), 
                      156.7706628888781`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(Plot2D \[Rule] True\), 
            ",", \(PlotPoints \[Rule] 64\), ",", 
            RowBox[{"PointSpreadFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-0.20456487797043785`\), 
                      0.2061756250410712`}, {\(-0.20462734131522348`\), 
                      0.20623858022321734`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
                  0}, {103.07278133146767`, 0, 0}}\), 
            ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
            ",", \(RayBoundary \[Rule] {{\(-8.454395127478403`\), 
                  8.454395127478403`}, {\(-8.451742068600495`\), 
                  8.451742068600495`}}\), 
            ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
            ",", \(RenderedParameters \[Rule] {ModulationTransferFunction, 
                PointSpreadFunction, OpticalPathDifference}\), 
            ",", \(ReportedParameters \[Rule] {OpticalPathDifference, 
                WaveFrontIntensity}\), 
            ",", \(ResidualFitError \[Rule] 7.717226219458099`*^-7\), 
            ",", \(SampleFactor \[Rule] 2\), 
            ",", \(SeidelAberrations \[Rule] {SphericalAberration \[Rule] 
                  81.57005140127133`, 
                Astigmatism \[Rule] 0.00011213737170258195`, 
                FieldCurvature \[Rule] \(-82.20473562570747`\), 
                Distortion \[Rule] 9.023259485118572`*^-13, 
                Coma \[Rule] \(-4.774894363465989`*^-13\)}\), 
            ",", \(ShowPerfectCase \[Rule] True\), 
            ",", \(SignalPlotCutoff \[Rule] 0.01`\), 
            ",", \(SmoothKernelRange \[Rule] 3\), 
            ",", \(SmoothKernelSize \[Rule] 1.25`\), 
            ",", \(SourceID \[Rule] 584\), ",", \(SpatialScale \[Rule] 1\), 
            ",", \(StrehlRatio \[Rule] 0.0006611096674480712`\), 
            ",", \(SurfaceNumber \[Rule] 1\), 
            ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
            ",", \(WaveFrontID \[Rule] 1\), ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.345028852686074`\), 
                      11.345028852686074`}, {\(-11.342375793808166`\), 
                      11.342375793808166`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
            ",", \(ZernikeFit \[Rule] True\), 
            ",", \(ZernikeOrder \[Rule] 8\)}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[78]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
MTF[sys3D, FindImagePoint->True, FocalFraction->1, NumberOfPoints->256, \
Plot2D->False, PlotPoints->100, ColorFunction->Automatic, Mesh->False];\
\>", "Input",
  CellLabel->"In[80]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.14858 .19855 -11.9132 -9 ]
[.14858 .19855 .08677 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.53441 .04682 -5.21679 -9 ]
[.53441 .04682 .78321 0 ]
[.76878 .09907 0 -6.15989 ]
[.76878 .09907 12 2.84011 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93375 .35169 0 -5.92115 ]
[.93375 .35169 6 3.07885 ]
[.02106 .28427 -24 -2.7585 ]
[.02106 .28427 0 6.2415 ]
[.01244 .33827 -18 -2.80421 ]
[.01244 .33827 0 6.19579 ]
[.00352 .39419 -24 -2.85172 ]
[.00352 .39419 0 6.14828 ]
[-0.00573 .45213 -18 -2.90112 ]
[-0.00573 .45213 0 6.09888 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.1578 .2079 m
.1624 .21257 L
s
[(-5)] .14858 .19855 .98554 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54221 .05738 m
.54611 .06265 L
s
[(5)] .53441 .04682 .73893 1 Mshowa
.125 Mabswid
.19381 .1938 m
.19654 .19664 L
s
.23033 .1795 m
.23302 .18237 L
s
.26737 .16499 m
.27003 .1679 L
s
.30495 .15028 m
.30756 .15322 L
s
.38174 .12021 m
.38426 .12323 L
s
.42097 .10485 m
.42346 .1079 L
s
.46079 .08926 m
.46322 .09235 L
s
.5012 .07344 m
.50358 .07656 L
s
.12228 .22181 m
.12508 .22458 L
s
.08725 .23552 m
.09008 .23826 L
s
.0527 .24905 m
.05557 .25175 L
s
.58384 .04107 m
.58613 .04428 L
s
.62611 .02452 m
.62834 .02776 L
s
.66902 .00772 m
.6712 .011 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75647 .10361 m
.75032 .10588 L
s
[(-5)] .76878 .09907 -1 .36886 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92124 .35564 m
.91498 .35762 L
s
[(5)] .93375 .35169 -1 .31581 Mshowa
.125 Mabswid
.77493 .13184 m
.77123 .13319 L
s
.7929 .15933 m
.78919 .16065 L
s
.8104 .1861 m
.80669 .18741 L
s
.82745 .21219 m
.82373 .21348 L
s
.86028 .2624 m
.85655 .26365 L
s
.87608 .28658 m
.87235 .28781 L
s
.8915 .31016 m
.88776 .31138 L
s
.90655 .33318 m
.9028 .33438 L
s
.73751 .0746 m
.73382 .07599 L
s
.71802 .04479 m
.71434 .04619 L
s
.69798 .01413 m
.69431 .01556 L
s
.93558 .37758 m
.93182 .37875 L
s
.94958 .39901 m
.94582 .40016 L
s
.96327 .41994 m
.9595 .42108 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03329 .27953 m
.03941 .27716 L
s
[(0.15)] .02106 .28427 1 -0.387 Mshowa
.02472 .33364 m
.03086 .33133 L
s
[(0.2)] .01244 .33827 1 -0.37684 Mshowa
.01584 .38968 m
.022 .38742 L
s
[(0.25)] .00352 .39419 1 -0.36628 Mshowa
.00664 .44773 m
.01282 .44554 L
s
[(0.3)] -0.00573 .45213 1 -0.35531 Mshowa
.125 Mabswid
.0316 .2902 m
.03528 .28879 L
s
.0299 .30095 m
.03358 .29954 L
s
.02819 .31177 m
.03186 .31037 L
s
.02646 .32267 m
.03014 .32127 L
s
.02297 .34469 m
.02665 .34331 L
s
.02121 .35582 m
.02489 .35444 L
s
.01943 .36702 m
.02312 .36566 L
s
.01764 .37831 m
.02133 .37695 L
s
.01403 .40112 m
.01772 .39977 L
s
.0122 .41265 m
.0159 .41131 L
s
.01036 .42426 m
.01406 .42293 L
s
.00851 .43595 m
.01221 .43463 L
s
.03497 .26893 m
.03864 .2675 L
s
.03664 .2584 m
.04031 .25697 L
s
.00476 .4596 m
.00847 .45829 L
s
.00287 .47155 m
.00658 .47025 L
s
.00096 .48359 m
.00467 .48229 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.779 .499 .513 r
.40084 .63451 .40454 .6203 .40907 .63863 .40529 .65538 Mtetra
.754 .479 .516 r
.40529 .65538 .40907 .63863 .41372 .65531 .40988 .67442 Mtetra
.707 .437 .513 r
.40988 .67442 .41372 .65531 .41859 .66697 .41473 .68778 Mtetra
.682 .416 .513 r
.41473 .68778 .41859 .66697 .42357 .67655 .41969 .69878 Mtetra
.646 .384 .508 r
.41969 .69878 .42357 .67655 .42868 .68289 .42481 .7061 Mtetra
.611 .354 .503 r
.42481 .7061 .42868 .68289 .4339 .68631 .43006 .71011 Mtetra
.595 .34 .5 r
.43006 .71011 .4339 .68631 .43918 .68848 .43537 .7127 Mtetra
.571 .319 .495 r
.43537 .7127 .43918 .68848 .44452 .6889 .44075 .71328 Mtetra
.561 .311 .493 r
.44075 .71328 .44452 .6889 .44989 .68866 .44617 .71314 Mtetra
.555 .305 .492 r
.44617 .71314 .44989 .68866 .45528 .688 .45161 .71251 Mtetra
.549 .3 .49 r
.45161 .71251 .45528 .688 .46069 .68693 .45707 .71142 Mtetra
.548 .299 .49 r
.45707 .71142 .46069 .68693 .46612 .68579 .46255 .71024 Mtetra
.547 .298 .489 r
.46255 .71024 .46612 .68579 .47156 .68457 .46804 .70898 Mtetra
.546 .297 .489 r
.46804 .70898 .47156 .68457 .47702 .68329 .47354 .70767 Mtetra
.47354 .70767 .47702 .68329 .48248 .682 .47905 .70634 Mtetra
.546 .296 .489 r
.47905 .70634 .48248 .682 .48796 .6807 .48458 .70499 Mtetra
.545 .296 .488 r
.48458 .70499 .48796 .6807 .49345 .67938 .49012 .70363 Mtetra
.49012 .70363 .49345 .67938 .49895 .67805 .49567 .70226 Mtetra
.49567 .70226 .49895 .67805 .50446 .67672 .50123 .70089 Mtetra
.545 .295 .488 r
.50123 .70089 .50446 .67672 .50998 .67537 .50681 .69951 Mtetra
.50681 .69951 .50998 .67537 .51552 .67401 .51239 .69811 Mtetra
.51239 .69811 .51552 .67401 .52107 .67264 .51799 .69671 Mtetra
.545 .295 .487 r
.51799 .69671 .52107 .67264 .52663 .67127 .5236 .69531 Mtetra
.544 .294 .487 r
.5236 .69531 .52663 .67127 .5322 .66987 .52922 .69388 Mtetra
.52922 .69388 .5322 .66987 .53778 .66848 .53485 .69246 Mtetra
.53485 .69246 .53778 .66848 .54338 .66707 .5405 .69103 Mtetra
.5405 .69103 .54338 .66707 .54898 .66565 .54616 .68958 Mtetra
.54616 .68958 .54898 .66565 .5546 .66422 .55183 .68813 Mtetra
.544 .294 .486 r
.55183 .68813 .5546 .66422 .56023 .66279 .55751 .68667 Mtetra
.544 .293 .486 r
.55751 .68667 .56023 .66279 .56587 .66134 .5632 .68519 Mtetra
.5632 .68519 .56587 .66134 .57153 .65988 .56891 .68372 Mtetra
.56891 .68372 .57153 .65988 .57719 .65842 .57463 .68224 Mtetra
.543 .293 .486 r
.57463 .68224 .57719 .65842 .58287 .65693 .58035 .68074 Mtetra
.58035 .68074 .58287 .65693 .58856 .65545 .5861 .67923 Mtetra
.5861 .67923 .58856 .65545 .59426 .65395 .59185 .67772 Mtetra
.543 .292 .486 r
.59185 .67772 .59426 .65395 .59998 .65244 .59762 .6762 Mtetra
.59762 .6762 .59998 .65244 .6057 .65092 .60339 .67467 Mtetra
.543 .292 .485 r
.60339 .67467 .6057 .65092 .61144 .6494 .60918 .67314 Mtetra
.60918 .67314 .61144 .6494 .61719 .64786 .61499 .67159 Mtetra
.61499 .67159 .61719 .64786 .62295 .64631 .6208 .67003 Mtetra
.6208 .67003 .62295 .64631 .62873 .64476 .62663 .66847 Mtetra
.542 .292 .485 r
.62663 .66847 .62873 .64476 .63451 .64319 .63246 .6669 Mtetra
.63246 .6669 .63451 .64319 .64031 .64161 .63831 .66532 Mtetra
.63831 .66532 .64031 .64161 .64612 .64002 .64418 .66373 Mtetra
.64418 .66373 .64612 .64002 .65194 .63843 .65005 .66214 Mtetra
.542 .291 .485 r
.65005 .66214 .65194 .63843 .65777 .63682 .65594 .66053 Mtetra
.65594 .66053 .65777 .63682 .66362 .6352 .66184 .65892 Mtetra
.66184 .65892 .66362 .6352 .66947 .63358 .66775 .6573 Mtetra
.66775 .6573 .66947 .63358 .67534 .63193 .67367 .65566 Mtetra
.67367 .65566 .67534 .63193 .68122 .63029 .67961 .65402 Mtetra
.67961 .65402 .68122 .63029 .68711 .62864 .68556 .65238 Mtetra
.68556 .65238 .68711 .62864 .69302 .62696 .69152 .65072 Mtetra
.69152 .65072 .69302 .62696 .69894 .62528 .69749 .64905 Mtetra
.69749 .64905 .69894 .62528 .70486 .6236 .70348 .64739 Mtetra
.541 .291 .485 r
.70348 .64739 .70486 .6236 .7108 .6219 .70947 .6457 Mtetra
.70947 .6457 .7108 .6219 .71676 .62019 .71548 .644 Mtetra
.542 .291 .485 r
.71548 .644 .71676 .62019 .72272 .61847 .7215 .64231 Mtetra
.541 .291 .485 r
.7215 .64231 .72272 .61847 .7287 .61674 .72754 .6406 Mtetra
.72754 .6406 .7287 .61674 .73469 .615 .73359 .63888 Mtetra
.73359 .63888 .73469 .615 .74069 .61325 .73964 .63716 Mtetra
.73964 .63716 .74069 .61325 .7467 .61149 .74572 .63542 Mtetra
.74572 .63542 .7467 .61149 .75272 .60972 .7518 .63367 Mtetra
.7518 .63367 .75272 .60972 .75876 .60794 .7579 .63192 Mtetra
.7579 .63192 .75876 .60794 .76481 .60615 .76401 .63017 Mtetra
.76401 .63017 .76481 .60615 .77087 .60435 .77013 .6284 Mtetra
.77013 .6284 .77087 .60435 .77694 .60254 .77626 .62661 Mtetra
.77626 .62661 .77694 .60254 .78302 .60072 .78241 .62483 Mtetra
.78241 .62483 .78302 .60072 .78912 .59888 .78856 .62303 Mtetra
.541 .291 .486 r
.78856 .62303 .78912 .59888 .79523 .59703 .79473 .62122 Mtetra
.79473 .62122 .79523 .59703 .80135 .59518 .80092 .6194 Mtetra
.80092 .6194 .80135 .59518 .80748 .59331 .80711 .61758 Mtetra
.80711 .61758 .80748 .59331 .81362 .59143 .81332 .61574 Mtetra
.81332 .61574 .81362 .59143 .81978 .58955 .81954 .6139 Mtetra
.81954 .6139 .81978 .58955 .82595 .58765 .82578 .61204 Mtetra
.82578 .61204 .82595 .58765 .83213 .58574 .83202 .61018 Mtetra
.83202 .61018 .83213 .58574 .83832 .58381 .83828 .60831 Mtetra
.83828 .60831 .83832 .58381 .84452 .58188 .84455 .60642 Mtetra
.541 .292 .487 r
.84455 .60642 .84452 .58188 .85074 .57994 .85083 .60453 Mtetra
.85083 .60453 .85074 .57994 .85696 .57798 .85713 .60263 Mtetra
.85713 .60263 .85696 .57798 .8632 .57601 .86344 .60071 Mtetra
.86344 .60071 .8632 .57601 .86945 .57404 .86976 .59879 Mtetra
.86976 .59879 .86945 .57404 .87572 .57205 .87609 .59686 Mtetra
.87609 .59686 .87572 .57205 .88199 .57005 .88244 .59492 Mtetra
.88244 .59492 .88199 .57005 .88828 .56803 .88879 .59297 Mtetra
.541 .292 .488 r
.88879 .59297 .88828 .56803 .89458 .566 .89516 .591 Mtetra
.89516 .591 .89458 .566 .90089 .56396 .90155 .58902 Mtetra
.90155 .58902 .90089 .56396 .90721 .56189 .90794 .58701 Mtetra
.54 .292 .488 r
.90794 .58701 .90721 .56189 .91353 .55976 .91434 .58494 Mtetra
.91434 .58494 .91353 .55976 .91987 .55759 .92075 .58283 Mtetra
.537 .29 .488 r
.92075 .58283 .91987 .55759 .92618 .55518 .92713 .58043 Mtetra
.533 .287 .488 r
.92713 .58043 .92618 .55518 .93248 .55248 .93349 .57772 Mtetra
.528 .283 .488 r
.93349 .57772 .93248 .55248 .93873 .54935 .93981 .57452 Mtetra
.511 .27 .486 r
.93981 .57452 .93873 .54935 .94484 .54495 .94595 .56987 Mtetra
.496 .259 .484 r
.94595 .56987 .94484 .54495 .95082 .53957 .95196 .56411 Mtetra
.46 .231 .479 r
.95196 .56411 .95082 .53957 .9565 .53181 .95762 .55565 Mtetra
.407 .191 .47 r
.95762 .55565 .9565 .53181 .96178 .52108 .96282 .5438 Mtetra
.361 .155 .46 r
.96282 .5438 .96178 .52108 .96678 .50836 .96771 .52969 Mtetra
.224 .054 .428 r
.96771 .52969 .96678 .50836 .97102 .49024 .97173 .50946 Mtetra
.115 0 .392 r
.97173 .50946 .97102 .49024 .97489 .46979 .97534 .48659 Mtetra
.801 .518 .509 r
.39716 .64683 .40084 .63451 .40529 .65538 .40154 .67 Mtetra
.777 .498 .512 r
.40154 .67 .40529 .65538 .40988 .67442 .40607 .69116 Mtetra
.729 .453 .509 r
.40607 .69116 .40988 .67442 .41473 .68778 .41089 .70604 Mtetra
.703 .43 .508 r
.41089 .70604 .41473 .68778 .41969 .69878 .41584 .71832 Mtetra
.662 .393 .503 r
.41584 .71832 .41969 .69878 .42481 .7061 .42097 .72651 Mtetra
.621 .356 .495 r
.42097 .72651 .42481 .7061 .43006 .71011 .42624 .73104 Mtetra
.601 .339 .492 r
.42624 .73104 .43006 .71011 .43537 .7127 .43158 .73398 Mtetra
.571 .312 .485 r
.43158 .73398 .43537 .7127 .44075 .71328 .437 .73472 Mtetra
.56 .302 .482 r
.437 .73472 .44075 .71328 .44617 .71314 .44246 .73463 Mtetra
.552 .295 .48 r
.44246 .73463 .44617 .71314 .45161 .71251 .44794 .73402 Mtetra
.544 .288 .478 r
.44794 .73402 .45161 .71251 .45707 .71142 .45345 .73289 Mtetra
.543 .287 .477 r
.45345 .73289 .45707 .71142 .46255 .71024 .45897 .73167 Mtetra
.541 .285 .477 r
.45897 .73167 .46255 .71024 .46804 .70898 .4645 .73036 Mtetra
.54 .284 .476 r
.4645 .73036 .46804 .70898 .47354 .70767 .47005 .72899 Mtetra
.47005 .72899 .47354 .70767 .47905 .70634 .47561 .72761 Mtetra
.54 .283 .476 r
.47561 .72761 .47905 .70634 .48458 .70499 .48118 .72621 Mtetra
.539 .283 .475 r
.48118 .72621 .48458 .70499 .49012 .70363 .48677 .7248 Mtetra
.48677 .7248 .49012 .70363 .49567 .70226 .49236 .72338 Mtetra
.539 .282 .475 r
.49236 .72338 .49567 .70226 .50123 .70089 .49797 .72197 Mtetra
.539 .282 .474 r
.49797 .72197 .50123 .70089 .50681 .69951 .50359 .72054 Mtetra
.50359 .72054 .50681 .69951 .51239 .69811 .50922 .7191 Mtetra
.50922 .7191 .51239 .69811 .51799 .69671 .51486 .71766 Mtetra
.538 .281 .474 r
.51486 .71766 .51799 .69671 .5236 .69531 .52052 .71621 Mtetra
.538 .281 .473 r
.52052 .71621 .5236 .69531 .52922 .69388 .52619 .71475 Mtetra
.52619 .71475 .52922 .69388 .53485 .69246 .53187 .71329 Mtetra
.53187 .71329 .53485 .69246 .5405 .69103 .53756 .71182 Mtetra
.538 .28 .473 r
.53756 .71182 .5405 .69103 .54616 .68958 .54326 .71034 Mtetra
.54326 .71034 .54616 .68958 .55183 .68813 .54898 .70886 Mtetra
.538 .28 .472 r
.54898 .70886 .55183 .68813 .55751 .68667 .5547 .70737 Mtetra
.537 .279 .472 r
.5547 .70737 .55751 .68667 .5632 .68519 .56044 .70587 Mtetra
.56044 .70587 .5632 .68519 .56891 .68372 .56619 .70436 Mtetra
.56619 .70436 .56891 .68372 .57463 .68224 .57196 .70286 Mtetra
.57196 .70286 .57463 .68224 .58035 .68074 .57773 .70134 Mtetra
.57773 .70134 .58035 .68074 .5861 .67923 .58352 .69981 Mtetra
.537 .279 .471 r
.58352 .69981 .5861 .67923 .59185 .67772 .58932 .69829 Mtetra
.537 .278 .471 r
.58932 .69829 .59185 .67772 .59762 .6762 .59513 .69674 Mtetra
.59513 .69674 .59762 .6762 .60339 .67467 .60096 .69519 Mtetra
.60096 .69519 .60339 .67467 .60918 .67314 .60679 .69365 Mtetra
.536 .278 .471 r
.60679 .69365 .60918 .67314 .61499 .67159 .61264 .69209 Mtetra
.61264 .69209 .61499 .67159 .6208 .67003 .6185 .69052 Mtetra
.6185 .69052 .6208 .67003 .62663 .66847 .62438 .68895 Mtetra
.62438 .68895 .62663 .66847 .63246 .6669 .63027 .68738 Mtetra
.536 .277 .47 r
.63027 .68738 .63246 .6669 .63831 .66532 .63616 .68578 Mtetra
.63616 .68578 .63831 .66532 .64418 .66373 .64207 .6842 Mtetra
.64207 .6842 .64418 .66373 .65005 .66214 .648 .6826 Mtetra
.648 .6826 .65005 .66214 .65594 .66053 .65393 .68099 Mtetra
.65393 .68099 .65594 .66053 .66184 .65892 .65988 .67938 Mtetra
.65988 .67938 .66184 .65892 .66775 .6573 .66584 .67777 Mtetra
.535 .277 .47 r
.66584 .67777 .66775 .6573 .67367 .65566 .67182 .67613 Mtetra
.536 .277 .47 r
.67182 .67613 .67367 .65566 .67961 .65402 .6778 .6745 Mtetra
.6778 .6745 .67961 .65402 .68556 .65238 .6838 .67287 Mtetra
.535 .277 .47 r
.6838 .67287 .68556 .65238 .69152 .65072 .68981 .67122 Mtetra
.68981 .67122 .69152 .65072 .69749 .64905 .69583 .66956 Mtetra
.69583 .66956 .69749 .64905 .70348 .64739 .70187 .66791 Mtetra
.70187 .66791 .70348 .64739 .70947 .6457 .70792 .66624 Mtetra
.70792 .66624 .70947 .6457 .71548 .644 .71398 .66456 Mtetra
.71398 .66456 .71548 .644 .7215 .64231 .72005 .66288 Mtetra
.72005 .66288 .7215 .64231 .72754 .6406 .72614 .66119 Mtetra
.72614 .66119 .72754 .6406 .73359 .63888 .73224 .65949 Mtetra
.73224 .65949 .73359 .63888 .73964 .63716 .73835 .6578 Mtetra
.73835 .6578 .73964 .63716 .74572 .63542 .74448 .65609 Mtetra
.535 .277 .471 r
.74448 .65609 .74572 .63542 .7518 .63367 .75062 .65436 Mtetra
.75062 .65436 .7518 .63367 .7579 .63192 .75677 .65265 Mtetra
.75677 .65265 .7579 .63192 .76401 .63017 .76293 .65092 Mtetra
.76293 .65092 .76401 .63017 .77013 .6284 .76911 .64918 Mtetra
.76911 .64918 .77013 .6284 .77626 .62661 .7753 .64744 Mtetra
.7753 .64744 .77626 .62661 .78241 .62483 .7815 .64569 Mtetra
.7815 .64569 .78241 .62483 .78856 .62303 .78771 .64393 Mtetra
.78771 .64393 .78856 .62303 .79473 .62122 .79394 .64216 Mtetra
.535 .278 .471 r
.79394 .64216 .79473 .62122 .80092 .6194 .80018 .64039 Mtetra
.535 .278 .472 r
.80018 .64039 .80092 .6194 .80711 .61758 .80644 .6386 Mtetra
.80644 .6386 .80711 .61758 .81332 .61574 .8127 .63681 Mtetra
.8127 .63681 .81332 .61574 .81954 .6139 .81898 .63502 Mtetra
.81898 .63502 .81954 .6139 .82578 .61204 .82528 .63321 Mtetra
.82528 .63321 .82578 .61204 .83202 .61018 .83158 .6314 Mtetra
.535 .278 .473 r
.83158 .6314 .83202 .61018 .83828 .60831 .8379 .62958 Mtetra
.8379 .62958 .83828 .60831 .84455 .60642 .84423 .62775 Mtetra
.535 .279 .473 r
.84423 .62775 .84455 .60642 .85083 .60453 .85058 .62592 Mtetra
.85058 .62592 .85083 .60453 .85713 .60263 .85694 .62407 Mtetra
.536 .279 .473 r
.85694 .62407 .85713 .60263 .86344 .60071 .86331 .62222 Mtetra
.536 .279 .474 r
.86331 .62222 .86344 .60071 .86976 .59879 .86969 .62036 Mtetra
.86969 .62036 .86976 .59879 .87609 .59686 .87609 .61849 Mtetra
.536 .28 .474 r
.87609 .61849 .87609 .59686 .88244 .59492 .8825 .61662 Mtetra
.8825 .61662 .88244 .59492 .88879 .59297 .88893 .61473 Mtetra
.536 .28 .475 r
.88893 .61473 .88879 .59297 .89516 .591 .89536 .61283 Mtetra
.89536 .61283 .89516 .591 .90155 .58902 .90181 .61092 Mtetra
.90181 .61092 .90155 .58902 .90794 .58701 .90828 .60899 Mtetra
.535 .28 .475 r
.90828 .60899 .90794 .58701 .91434 .58494 .91474 .60699 Mtetra
.534 .28 .476 r
.91474 .60699 .91434 .58494 .92075 .58283 .92122 .60494 Mtetra
.531 .277 .475 r
.92122 .60494 .92075 .58283 .92713 .58043 .92767 .60258 Mtetra
.526 .274 .475 r
.92767 .60258 .92713 .58043 .93349 .57772 .9341 .59987 Mtetra
.519 .268 .475 r
.9341 .59987 .93349 .57772 .93981 .57452 .94047 .59662 Mtetra
.497 .252 .472 r
.94047 .59662 .93981 .57452 .94595 .56987 .94665 .59177 Mtetra
.479 .237 .47 r
.94665 .59177 .94595 .56987 .95196 .56411 .95268 .58568 Mtetra
.431 .201 .463 r
.95268 .58568 .95196 .56411 .95762 .55565 .95832 .57658 Mtetra
.36 .147 .449 r
.95832 .57658 .95762 .55565 .96282 .5438 .96346 .56373 Mtetra
.297 .099 .434 r
.96346 .56373 .96282 .5438 .96771 .52969 .96825 .54838 Mtetra
.112 0 .384 r
.96825 .54838 .96771 .52969 .97173 .50946 .97209 .52624 Mtetra
0 0 .33 r
.97209 .52624 .97173 .50946 .97534 .48659 .97546 .50119 Mtetra
.843 .549 .491 r
.39362 .65433 .39716 .64683 .40154 .67 .39794 .67908 Mtetra
.823 .53 .494 r
.39794 .67908 .40154 .67 .40607 .69116 .40243 .7017 Mtetra
.777 .482 .488 r
.40243 .7017 .40607 .69116 .41089 .70604 .40722 .71762 Mtetra
.748 .454 .485 r
.40722 .71762 .41089 .70604 .41584 .71832 .41216 .73077 Mtetra
.7 .407 .476 r
.41216 .73077 .41584 .71832 .42097 .72651 .4173 .73955 Mtetra
.645 .353 .462 r
.4173 .73955 .42097 .72651 .42624 .73104 .42258 .74442 Mtetra
.616 .326 .455 r
.42258 .74442 .42624 .73104 .43158 .73398 .42794 .7476 Mtetra
.569 .282 .44 r
.42794 .7476 .43158 .73398 .437 .73472 .43339 .74841 Mtetra
.55 .264 .434 r
.43339 .74841 .437 .73472 .44246 .73463 .43888 .74834 Mtetra
.536 .251 .43 r
.43888 .74834 .44246 .73463 .44794 .73402 .44439 .74772 Mtetra
.523 .238 .424 r
.44439 .74772 .44794 .73402 .45345 .73289 .44993 .74654 Mtetra
.52 .236 .423 r
.44993 .74654 .45345 .73289 .45897 .73167 .45549 .74528 Mtetra
.517 .233 .422 r
.45549 .74528 .45897 .73167 .4645 .73036 .46105 .74391 Mtetra
.516 .231 .42 r
.46105 .74391 .4645 .73036 .47005 .72899 .46664 .74249 Mtetra
.515 .23 .42 r
.46664 .74249 .47005 .72899 .47561 .72761 .47223 .74105 Mtetra
.515 .229 .419 r
.47223 .74105 .47561 .72761 .48118 .72621 .47783 .7396 Mtetra
.514 .228 .418 r
.47783 .7396 .48118 .72621 .48677 .7248 .48345 .73814 Mtetra
.48345 .73814 .48677 .7248 .49236 .72338 .48908 .73667 Mtetra
.514 .227 .417 r
.48908 .73667 .49236 .72338 .49797 .72197 .49472 .73521 Mtetra
.513 .226 .416 r
.49472 .73521 .49797 .72197 .50359 .72054 .50037 .73373 Mtetra
.50037 .73373 .50359 .72054 .50922 .7191 .50604 .73225 Mtetra
.513 .225 .415 r
.50604 .73225 .50922 .7191 .51486 .71766 .51171 .73077 Mtetra
.512 .225 .415 r
.51171 .73077 .51486 .71766 .52052 .71621 .5174 .72928 Mtetra
.512 .224 .414 r
.5174 .72928 .52052 .71621 .52619 .71475 .5231 .72778 Mtetra
.512 .224 .413 r
.5231 .72778 .52619 .71475 .53187 .71329 .52882 .72628 Mtetra
.511 .223 .413 r
.52882 .72628 .53187 .71329 .53756 .71182 .53454 .72478 Mtetra
.511 .222 .412 r
.53454 .72478 .53756 .71182 .54326 .71034 .54028 .72326 Mtetra
.54028 .72326 .54326 .71034 .54898 .70886 .54602 .72174 Mtetra
.511 .222 .411 r
.54602 .72174 .54898 .70886 .5547 .70737 .55178 .72023 Mtetra
.51 .221 .411 r
.55178 .72023 .5547 .70737 .56044 .70587 .55756 .71869 Mtetra
.55756 .71869 .56044 .70587 .56619 .70436 .56334 .71716 Mtetra
.51 .22 .41 r
.56334 .71716 .56619 .70436 .57196 .70286 .56914 .71563 Mtetra
.509 .22 .41 r
.56914 .71563 .57196 .70286 .57773 .70134 .57495 .71408 Mtetra
.509 .219 .409 r
.57495 .71408 .57773 .70134 .58352 .69981 .58077 .71253 Mtetra
.58077 .71253 .58352 .69981 .58932 .69829 .5866 .71098 Mtetra
.5866 .71098 .58932 .69829 .59513 .69674 .59245 .70942 Mtetra
.509 .218 .408 r
.59245 .70942 .59513 .69674 .60096 .69519 .59831 .70785 Mtetra
.59831 .70785 .60096 .69519 .60679 .69365 .60418 .70629 Mtetra
.508 .218 .408 r
.60418 .70629 .60679 .69365 .61264 .69209 .61006 .70472 Mtetra
.508 .217 .407 r
.61006 .70472 .61264 .69209 .6185 .69052 .61596 .70313 Mtetra
.61596 .70313 .6185 .69052 .62438 .68895 .62187 .70155 Mtetra
.62187 .70155 .62438 .68895 .63027 .68738 .62779 .69997 Mtetra
.62779 .69997 .63027 .68738 .63616 .68578 .63372 .69836 Mtetra
.63372 .69836 .63616 .68578 .64207 .6842 .63967 .69677 Mtetra
.63967 .69677 .64207 .6842 .648 .6826 .64562 .69517 Mtetra
.507 .216 .406 r
.64562 .69517 .648 .6826 .65393 .68099 .6516 .69355 Mtetra
.508 .216 .406 r
.6516 .69355 .65393 .68099 .65988 .67938 .65758 .69194 Mtetra
.65758 .69194 .65988 .67938 .66584 .67777 .66358 .69033 Mtetra
.507 .216 .406 r
.66358 .69033 .66584 .67777 .67182 .67613 .66958 .68869 Mtetra
.66958 .68869 .67182 .67613 .6778 .6745 .67561 .68706 Mtetra
.67561 .68706 .6778 .6745 .6838 .67287 .68164 .68543 Mtetra
.68164 .68543 .6838 .67287 .68981 .67122 .68769 .68379 Mtetra
.68769 .68379 .68981 .67122 .69583 .66956 .69375 .68214 Mtetra
.69375 .68214 .69583 .66956 .70187 .66791 .69982 .68049 Mtetra
.69982 .68049 .70187 .66791 .70792 .66624 .70591 .67883 Mtetra
.70591 .67883 .70792 .66624 .71398 .66456 .71201 .67717 Mtetra
.71201 .67717 .71398 .66456 .72005 .66288 .71812 .67551 Mtetra
.507 .216 .407 r
.71812 .67551 .72005 .66288 .72614 .66119 .72424 .67383 Mtetra
.72424 .67383 .72614 .66119 .73224 .65949 .73038 .67215 Mtetra
.507 .217 .407 r
.73038 .67215 .73224 .65949 .73835 .6578 .73653 .67047 Mtetra
.73653 .67047 .73835 .6578 .74448 .65609 .7427 .66878 Mtetra
.7427 .66878 .74448 .65609 .75062 .65436 .74887 .66708 Mtetra
.507 .217 .408 r
.74887 .66708 .75062 .65436 .75677 .65265 .75507 .66538 Mtetra
.508 .217 .408 r
.75507 .66538 .75677 .65265 .76293 .65092 .76127 .66369 Mtetra
.76127 .66369 .76293 .65092 .76911 .64918 .76749 .66197 Mtetra
.508 .218 .408 r
.76749 .66197 .76911 .64918 .7753 .64744 .77372 .66026 Mtetra
.508 .218 .409 r
.77372 .66026 .7753 .64744 .7815 .64569 .77996 .65854 Mtetra
.77996 .65854 .7815 .64569 .78771 .64393 .78622 .65681 Mtetra
.78622 .65681 .78771 .64393 .79394 .64216 .79249 .65507 Mtetra
.508 .219 .41 r
.79249 .65507 .79394 .64216 .80018 .64039 .79877 .65334 Mtetra
.79877 .65334 .80018 .64039 .80644 .6386 .80507 .65159 Mtetra
.508 .22 .411 r
.80507 .65159 .80644 .6386 .8127 .63681 .81138 .64984 Mtetra
.509 .22 .411 r
.81138 .64984 .8127 .63681 .81898 .63502 .8177 .64808 Mtetra
.8177 .64808 .81898 .63502 .82528 .63321 .82404 .64632 Mtetra
.509 .221 .412 r
.82404 .64632 .82528 .63321 .83158 .6314 .83039 .64455 Mtetra
.83039 .64455 .83158 .6314 .8379 .62958 .83676 .64278 Mtetra
.509 .222 .413 r
.83676 .64278 .8379 .62958 .84423 .62775 .84313 .641 Mtetra
.84313 .641 .84423 .62775 .85058 .62592 .84953 .63921 Mtetra
.51 .223 .414 r
.84953 .63921 .85058 .62592 .85694 .62407 .85593 .63742 Mtetra
.85593 .63742 .85694 .62407 .86331 .62222 .86235 .63562 Mtetra
.51 .224 .415 r
.86235 .63562 .86331 .62222 .86969 .62036 .86878 .63382 Mtetra
.51 .224 .416 r
.86878 .63382 .86969 .62036 .87609 .61849 .87523 .632 Mtetra
.51 .225 .416 r
.87523 .632 .87609 .61849 .8825 .61662 .88169 .63019 Mtetra
.511 .225 .417 r
.88169 .63019 .8825 .61662 .88893 .61473 .88817 .62836 Mtetra
.511 .226 .418 r
.88817 .62836 .88893 .61473 .89536 .61283 .89465 .62653 Mtetra
.89465 .62653 .89536 .61283 .90181 .61092 .90115 .62468 Mtetra
.511 .226 .419 r
.90115 .62468 .90181 .61092 .90828 .60899 .90767 .62281 Mtetra
.51 .226 .419 r
.90767 .62281 .90828 .60899 .91474 .60699 .91419 .62087 Mtetra
.509 .226 .42 r
.91419 .62087 .91474 .60699 .92122 .60494 .92071 .61888 Mtetra
.503 .221 .419 r
.92071 .61888 .92122 .60494 .92767 .60258 .92722 .61657 Mtetra
.495 .215 .419 r
.92722 .61657 .92767 .60258 .9341 .59987 .93369 .61388 Mtetra
.483 .206 .417 r
.93369 .61388 .9341 .59987 .94047 .59662 .94011 .61061 Mtetra
.443 .175 .411 r
.94011 .61061 .94047 .59662 .94665 .59177 .94632 .60563 Mtetra
.409 .149 .404 r
.94632 .60563 .94665 .59177 .95268 .58568 .95237 .59933 Mtetra
.318 .079 .385 r
.95237 .59933 .95268 .58568 .95832 .57658 .95801 .58981 Mtetra
.178 0 .349 r
.95801 .58981 .95832 .57658 .96346 .56373 .96312 .57627 Mtetra
.054 0 .307 r
.96312 .57627 .96346 .56373 .96825 .54838 .96784 .56007 Mtetra
0 0 .185 r
.96784 .56007 .96825 .54838 .97209 .52624 .97156 .53661 Mtetra
0 0 .083 r
.97156 .53661 .97209 .52624 .97546 .50119 .97479 .51006 Mtetra
.862 .564 .483 r
.39012 .65999 .39362 .65433 .39794 .67908 .39439 .68605 Mtetra
.844 .547 .485 r
.39439 .68605 .39794 .67908 .40243 .7017 .39883 .70988 Mtetra
.802 .499 .476 r
.39883 .70988 .40243 .7017 .40722 .71762 .4036 .72666 Mtetra
.774 .47 .472 r
.4036 .72666 .40722 .71762 .41216 .73077 .40853 .74053 Mtetra
.724 .418 .459 r
.40853 .74053 .41216 .73077 .4173 .73955 .41366 .74981 Mtetra
.662 .353 .44 r
.41366 .74981 .4173 .73955 .42258 .74442 .41896 .75495 Mtetra
.627 .319 .429 r
.41896 .75495 .42258 .74442 .42794 .7476 .42434 .75832 Mtetra
.567 .26 .407 r
.42434 .75832 .42794 .7476 .43339 .74841 .42981 .75919 Mtetra
.541 .235 .398 r
.42981 .75919 .43339 .74841 .43888 .74834 .43533 .75914 Mtetra
.523 .218 .39 r
.43533 .75914 .43888 .74834 .44439 .74772 .44087 .7585 Mtetra
.504 .199 .382 r
.44087 .7585 .44439 .74772 .44993 .74654 .44644 .75728 Mtetra
.501 .195 .38 r
.44644 .75728 .44993 .74654 .45549 .74528 .45202 .75597 Mtetra
.497 .191 .378 r
.45202 .75597 .45549 .74528 .46105 .74391 .45762 .75455 Mtetra
.494 .188 .376 r
.45762 .75455 .46105 .74391 .46664 .74249 .46323 .75308 Mtetra
.494 .187 .375 r
.46323 .75308 .46664 .74249 .47223 .74105 .46885 .75159 Mtetra
.493 .186 .374 r
.46885 .75159 .47223 .74105 .47783 .7396 .47449 .75009 Mtetra
.492 .185 .373 r
.47449 .75009 .47783 .7396 .48345 .73814 .48013 .74858 Mtetra
.492 .184 .372 r
.48013 .74858 .48345 .73814 .48908 .73667 .48579 .74706 Mtetra
.492 .183 .371 r
.48579 .74706 .48908 .73667 .49472 .73521 .49146 .74556 Mtetra
.491 .182 .37 r
.49146 .74556 .49472 .73521 .50037 .73373 .49714 .74404 Mtetra
.49 .181 .369 r
.49714 .74404 .50037 .73373 .50604 .73225 .50283 .74251 Mtetra
.49 .181 .368 r
.50283 .74251 .50604 .73225 .51171 .73077 .50854 .74099 Mtetra
.49 .18 .367 r
.50854 .74099 .51171 .73077 .5174 .72928 .51426 .73946 Mtetra
.489 .179 .366 r
.51426 .73946 .5174 .72928 .5231 .72778 .51998 .73792 Mtetra
.489 .178 .366 r
.51998 .73792 .5231 .72778 .52882 .72628 .52572 .73639 Mtetra
.489 .177 .365 r
.52572 .73639 .52882 .72628 .53454 .72478 .53148 .73485 Mtetra
.488 .176 .364 r
.53148 .73485 .53454 .72478 .54028 .72326 .53724 .7333 Mtetra
.488 .176 .363 r
.53724 .7333 .54028 .72326 .54602 .72174 .54302 .73175 Mtetra
.488 .175 .363 r
.54302 .73175 .54602 .72174 .55178 .72023 .54881 .73021 Mtetra
.487 .174 .362 r
.54881 .73021 .55178 .72023 .55756 .71869 .55461 .72864 Mtetra
.487 .174 .361 r
.55461 .72864 .55756 .71869 .56334 .71716 .56042 .72708 Mtetra
.56042 .72708 .56334 .71716 .56914 .71563 .56625 .72553 Mtetra
.486 .173 .36 r
.56625 .72553 .56914 .71563 .57495 .71408 .57209 .72396 Mtetra
.486 .172 .359 r
.57209 .72396 .57495 .71408 .58077 .71253 .57794 .72238 Mtetra
.57794 .72238 .58077 .71253 .5866 .71098 .5838 .72082 Mtetra
.485 .171 .358 r
.5838 .72082 .5866 .71098 .59245 .70942 .58968 .71924 Mtetra
.58968 .71924 .59245 .70942 .59831 .70785 .59556 .71765 Mtetra
.59556 .71765 .59831 .70785 .60418 .70629 .60147 .71607 Mtetra
.485 .17 .357 r
.60147 .71607 .60418 .70629 .61006 .70472 .60738 .71448 Mtetra
.484 .169 .357 r
.60738 .71448 .61006 .70472 .61596 .70313 .6133 .71288 Mtetra
.485 .17 .357 r
.6133 .71288 .61596 .70313 .62187 .70155 .61924 .71129 Mtetra
.484 .169 .356 r
.61924 .71129 .62187 .70155 .62779 .69997 .62519 .70969 Mtetra
.62519 .70969 .62779 .69997 .63372 .69836 .63115 .70808 Mtetra
.63115 .70808 .63372 .69836 .63967 .69677 .63713 .70648 Mtetra
.484 .169 .355 r
.63713 .70648 .63967 .69677 .64562 .69517 .64312 .70487 Mtetra
.483 .168 .355 r
.64312 .70487 .64562 .69517 .6516 .69355 .64912 .70325 Mtetra
.484 .168 .355 r
.64912 .70325 .6516 .69355 .65758 .69194 .65514 .70163 Mtetra
.65514 .70163 .65758 .69194 .66358 .69033 .66116 .70002 Mtetra
.483 .168 .355 r
.66116 .70002 .66358 .69033 .66958 .68869 .6672 .69838 Mtetra
.484 .168 .355 r
.6672 .69838 .66958 .68869 .67561 .68706 .67326 .69675 Mtetra
.67326 .69675 .67561 .68706 .68164 .68543 .67932 .69513 Mtetra
.483 .168 .355 r
.67932 .69513 .68164 .68543 .68769 .68379 .6854 .69348 Mtetra
.6854 .69348 .68769 .68379 .69375 .68214 .69149 .69184 Mtetra
.484 .168 .355 r
.69149 .69184 .69375 .68214 .69982 .68049 .6976 .6902 Mtetra
.483 .168 .355 r
.6976 .6902 .69982 .68049 .70591 .67883 .70372 .68855 Mtetra
.70372 .68855 .70591 .67883 .71201 .67717 .70985 .68689 Mtetra
.484 .169 .355 r
.70985 .68689 .71201 .67717 .71812 .67551 .71599 .68524 Mtetra
.484 .168 .356 r
.71599 .68524 .71812 .67551 .72424 .67383 .72215 .68358 Mtetra
.72215 .68358 .72424 .67383 .73038 .67215 .72832 .68191 Mtetra
.484 .169 .356 r
.72832 .68191 .73038 .67215 .73653 .67047 .73451 .68025 Mtetra
.73451 .68025 .73653 .67047 .7427 .66878 .7407 .67858 Mtetra
.484 .169 .357 r
.7407 .67858 .7427 .66878 .74887 .66708 .74692 .67689 Mtetra
.485 .17 .357 r
.74692 .67689 .74887 .66708 .75507 .66538 .75314 .67522 Mtetra
.485 .17 .358 r
.75314 .67522 .75507 .66538 .76127 .66369 .75938 .67354 Mtetra
.485 .171 .358 r
.75938 .67354 .76127 .66369 .76749 .66197 .76563 .67185 Mtetra
.76563 .67185 .76749 .66197 .77372 .66026 .7719 .67016 Mtetra
.485 .172 .359 r
.7719 .67016 .77372 .66026 .77996 .65854 .77818 .66846 Mtetra
.486 .172 .359 r
.77818 .66846 .77996 .65854 .78622 .65681 .78447 .66676 Mtetra
.486 .173 .36 r
.78447 .66676 .78622 .65681 .79249 .65507 .79078 .66506 Mtetra
.486 .173 .361 r
.79078 .66506 .79249 .65507 .79877 .65334 .7971 .66335 Mtetra
.486 .174 .361 r
.7971 .66335 .79877 .65334 .80507 .65159 .80343 .66164 Mtetra
.487 .174 .362 r
.80343 .66164 .80507 .65159 .81138 .64984 .80978 .65992 Mtetra
.487 .175 .362 r
.80978 .65992 .81138 .64984 .8177 .64808 .81614 .6582 Mtetra
.487 .175 .363 r
.81614 .6582 .8177 .64808 .82404 .64632 .82252 .65647 Mtetra
.488 .176 .364 r
.82252 .65647 .82404 .64632 .83039 .64455 .82891 .65474 Mtetra
.488 .177 .365 r
.82891 .65474 .83039 .64455 .83676 .64278 .83531 .65301 Mtetra
.488 .178 .365 r
.83531 .65301 .83676 .64278 .84313 .641 .84173 .65127 Mtetra
.489 .178 .366 r
.84173 .65127 .84313 .641 .84953 .63921 .84816 .64953 Mtetra
.489 .179 .367 r
.84816 .64953 .84953 .63921 .85593 .63742 .85461 .64778 Mtetra
.489 .18 .368 r
.85461 .64778 .85593 .63742 .86235 .63562 .86107 .64603 Mtetra
.49 .181 .369 r
.86107 .64603 .86235 .63562 .86878 .63382 .86755 .64427 Mtetra
.49 .181 .37 r
.86755 .64427 .86878 .63382 .87523 .632 .87404 .64251 Mtetra
.491 .182 .371 r
.87404 .64251 .87523 .632 .88169 .63019 .88054 .64075 Mtetra
.491 .183 .372 r
.88054 .64075 .88169 .63019 .88817 .62836 .88706 .63898 Mtetra
.491 .184 .373 r
.88706 .63898 .88817 .62836 .89465 .62653 .89359 .6372 Mtetra
.492 .185 .373 r
.89359 .6372 .89465 .62653 .90115 .62468 .90013 .6354 Mtetra
.491 .185 .374 r
.90013 .6354 .90115 .62468 .90767 .62281 .90669 .63359 Mtetra
.49 .185 .375 r
.90669 .63359 .90767 .62281 .91419 .62087 .91326 .63171 Mtetra
.489 .185 .376 r
.91326 .63171 .91419 .62087 .92071 .61888 .91983 .62977 Mtetra
.48 .178 .375 r
.91983 .62977 .92071 .61888 .92722 .61657 .92638 .6275 Mtetra
.47 .17 .374 r
.92638 .6275 .92722 .61657 .93369 .61388 .9329 .62483 Mtetra
.453 .156 .371 r
.9329 .62483 .93369 .61388 .94011 .61061 .93935 .62156 Mtetra
.397 .113 .36 r
.93935 .62156 .94011 .61061 .94632 .60563 .94559 .61647 Mtetra
.348 .074 .349 r
.94559 .61647 .94632 .60563 .95237 .59933 .95166 .60999 Mtetra
.215 0 .315 r
.95166 .60999 .95237 .59933 .95801 .58981 .9573 .60013 Mtetra
.011 0 .252 r
.9573 .60013 .95801 .58981 .96312 .57627 .96238 .58602 Mtetra
0 0 .187 r
.96238 .58602 .96312 .57627 .96784 .56007 .96706 .56911 Mtetra
0 0 .026 r
.96706 .56911 .96784 .56007 .97156 .53661 .97068 .54455 Mtetra
0 0 0 r
.97068 .54455 .97156 .53661 .97479 .51006 .97379 .51675 Mtetra
.889 .585 .466 r
.38671 .66286 .39012 .65999 .39439 .68605 .39093 .68981 Mtetra
.876 .57 .465 r
.39093 .68981 .39439 .68605 .39883 .70988 .39534 .71446 Mtetra
.843 .524 .449 r
.39534 .71446 .39883 .70988 .4036 .72666 .40009 .73183 Mtetra
.818 .494 .441 r
.40009 .73183 .4036 .72666 .40853 .74053 .405 .74619 Mtetra
.769 .433 .417 r
.405 .74619 .40853 .74053 .41366 .74981 .41013 .75579 Mtetra
.696 .346 .38 r
.41013 .75579 .41366 .74981 .41896 .75495 .41544 .76111 Mtetra
.648 .293 .356 r
.41544 .76111 .41896 .75495 .42434 .75832 .42083 .7646 Mtetra
.556 .193 .307 r
.42083 .7646 .42434 .75832 .42981 .75919 .42632 .7655 Mtetra
.51 .145 .282 r
.42632 .7655 .42981 .75919 .43533 .75914 .43185 .76545 Mtetra
.477 .11 .264 r
.43185 .76545 .43533 .75914 .44087 .7585 .43742 .76479 Mtetra
.44 .072 .242 r
.43742 .76479 .44087 .7585 .44644 .75728 .44301 .76353 Mtetra
.433 .064 .237 r
.44301 .76353 .44644 .75728 .45202 .75597 .44861 .76218 Mtetra
.425 .055 .231 r
.44861 .76218 .45202 .75597 .45762 .75455 .45423 .76072 Mtetra
.42 .049 .226 r
.45423 .76072 .45762 .75455 .46323 .75308 .45987 .7592 Mtetra
.418 .046 .224 r
.45987 .7592 .46323 .75308 .46885 .75159 .46551 .75767 Mtetra
.416 .044 .221 r
.46551 .75767 .46885 .75159 .47449 .75009 .47117 .75613 Mtetra
.414 .041 .218 r
.47117 .75613 .47449 .75009 .48013 .74858 .47683 .75458 Mtetra
.413 .039 .216 r
.47683 .75458 .48013 .74858 .48579 .74706 .48251 .75302 Mtetra
.413 .038 .214 r
.48251 .75302 .48579 .74706 .49146 .74556 .48821 .75147 Mtetra
.411 .035 .211 r
.48821 .75147 .49146 .74556 .49714 .74404 .49391 .74992 Mtetra
.409 .032 .209 r
.49391 .74992 .49714 .74404 .50283 .74251 .49962 .74835 Mtetra
.409 .032 .207 r
.49962 .74835 .50283 .74251 .50854 .74099 .50535 .7468 Mtetra
.408 .029 .205 r
.50535 .7468 .50854 .74099 .51426 .73946 .51109 .74524 Mtetra
.406 .027 .203 r
.51109 .74524 .51426 .73946 .51998 .73792 .51684 .74367 Mtetra
.406 .026 .201 r
.51684 .74367 .51998 .73792 .52572 .73639 .5226 .7421 Mtetra
.405 .024 .199 r
.5226 .7421 .52572 .73639 .53148 .73485 .52838 .74054 Mtetra
.403 .022 .197 r
.52838 .74054 .53148 .73485 .53724 .7333 .53416 .73895 Mtetra
.403 .021 .195 r
.53416 .73895 .53724 .7333 .54302 .73175 .53996 .73738 Mtetra
.403 .02 .194 r
.53996 .73738 .54302 .73175 .54881 .73021 .54577 .73581 Mtetra
.401 .017 .192 r
.54577 .73581 .54881 .73021 .55461 .72864 .5516 .73422 Mtetra
.401 .016 .19 r
.5516 .73422 .55461 .72864 .56042 .72708 .55743 .73264 Mtetra
.4 .015 .189 r
.55743 .73264 .56042 .72708 .56625 .72553 .56328 .73106 Mtetra
.399 .013 .187 r
.56328 .73106 .56625 .72553 .57209 .72396 .56914 .72947 Mtetra
.398 .012 .186 r
.56914 .72947 .57209 .72396 .57794 .72238 .57501 .72787 Mtetra
.398 .012 .185 r
.57501 .72787 .57794 .72238 .5838 .72082 .5809 .72629 Mtetra
.397 .01 .183 r
.5809 .72629 .5838 .72082 .58968 .71924 .5868 .72469 Mtetra
.396 .009 .182 r
.5868 .72469 .58968 .71924 .59556 .71765 .59271 .72309 Mtetra
.397 .009 .182 r
.59271 .72309 .59556 .71765 .60147 .71607 .59863 .72149 Mtetra
.396 .007 .18 r
.59863 .72149 .60147 .71607 .60738 .71448 .60456 .71989 Mtetra
.395 .006 .179 r
.60456 .71989 .60738 .71448 .6133 .71288 .61051 .71827 Mtetra
.61051 .71827 .6133 .71288 .61924 .71129 .61647 .71667 Mtetra
.395 .005 .178 r
.61647 .71667 .61924 .71129 .62519 .70969 .62244 .71506 Mtetra
.394 .004 .177 r
.62244 .71506 .62519 .70969 .63115 .70808 .62843 .71344 Mtetra
.394 .005 .177 r
.62843 .71344 .63115 .70808 .63713 .70648 .63443 .71183 Mtetra
.394 .004 .176 r
.63443 .71183 .63713 .70648 .64312 .70487 .64044 .71022 Mtetra
.393 .003 .175 r
.64044 .71022 .64312 .70487 .64912 .70325 .64646 .70859 Mtetra
.394 .003 .175 r
.64646 .70859 .64912 .70325 .65514 .70163 .6525 .70697 Mtetra
.6525 .70697 .65514 .70163 .66116 .70002 .65855 .70535 Mtetra
.393 .002 .175 r
.65855 .70535 .66116 .70002 .6672 .69838 .66462 .70371 Mtetra
.393 .003 .175 r
.66462 .70371 .6672 .69838 .67326 .69675 .67069 .70208 Mtetra
.394 .003 .175 r
.67069 .70208 .67326 .69675 .67932 .69513 .67678 .70045 Mtetra
.393 .003 .175 r
.67678 .70045 .67932 .69513 .6854 .69348 .68289 .69881 Mtetra
.68289 .69881 .6854 .69348 .69149 .69184 .689 .69717 Mtetra
.394 .004 .176 r
.689 .69717 .69149 .69184 .6976 .6902 .69513 .69553 Mtetra
.394 .003 .176 r
.69513 .69553 .6976 .6902 .70372 .68855 .70127 .69388 Mtetra
.394 .004 .176 r
.70127 .69388 .70372 .68855 .70985 .68689 .70743 .69223 Mtetra
.395 .005 .177 r
.70743 .69223 .70985 .68689 .71599 .68524 .7136 .69059 Mtetra
.7136 .69059 .71599 .68524 .72215 .68358 .71978 .68893 Mtetra
.395 .005 .178 r
.71978 .68893 .72215 .68358 .72832 .68191 .72598 .68727 Mtetra
.396 .007 .179 r
.72598 .68727 .72832 .68191 .73451 .68025 .73219 .68562 Mtetra
.73219 .68562 .73451 .68025 .7407 .67858 .73841 .68396 Mtetra
.396 .007 .18 r
.73841 .68396 .7407 .67858 .74692 .67689 .74465 .68228 Mtetra
.398 .009 .181 r
.74465 .68228 .74692 .67689 .75314 .67522 .7509 .68062 Mtetra
.398 .01 .182 r
.7509 .68062 .75314 .67522 .75938 .67354 .75717 .67896 Mtetra
.398 .011 .183 r
.75717 .67896 .75938 .67354 .76563 .67185 .76345 .67729 Mtetra
.399 .012 .185 r
.76345 .67729 .76563 .67185 .7719 .67016 .76974 .67561 Mtetra
.4 .013 .186 r
.76974 .67561 .7719 .67016 .77818 .66846 .77605 .67393 Mtetra
.4 .014 .187 r
.77605 .67393 .77818 .66846 .78447 .66676 .78237 .67225 Mtetra
.401 .016 .189 r
.78237 .67225 .78447 .66676 .79078 .66506 .7887 .67057 Mtetra
.402 .017 .19 r
.7887 .67057 .79078 .66506 .7971 .66335 .79505 .66888 Mtetra
.403 .019 .192 r
.79505 .66888 .7971 .66335 .80343 .66164 .80141 .66719 Mtetra
.404 .02 .193 r
.80141 .66719 .80343 .66164 .80978 .65992 .80779 .6655 Mtetra
.405 .022 .195 r
.80779 .6655 .80978 .65992 .81614 .6582 .81418 .6638 Mtetra
.406 .023 .197 r
.81418 .6638 .81614 .6582 .82252 .65647 .82059 .66211 Mtetra
.407 .025 .199 r
.82059 .66211 .82252 .65647 .82891 .65474 .82701 .6604 Mtetra
.408 .027 .2 r
.82701 .6604 .82891 .65474 .83531 .65301 .83344 .6587 Mtetra
.409 .029 .202 r
.83344 .6587 .83531 .65301 .84173 .65127 .83989 .65699 Mtetra
.41 .03 .204 r
.83989 .65699 .84173 .65127 .84816 .64953 .84635 .65528 Mtetra
.411 .032 .207 r
.84635 .65528 .84816 .64953 .85461 .64778 .85283 .65357 Mtetra
.412 .034 .209 r
.85283 .65357 .85461 .64778 .86107 .64603 .85932 .65185 Mtetra
.413 .036 .211 r
.85932 .65185 .86107 .64603 .86755 .64427 .86583 .65013 Mtetra
.415 .038 .213 r
.86583 .65013 .86755 .64427 .87404 .64251 .87235 .64841 Mtetra
.416 .04 .215 r
.87235 .64841 .87404 .64251 .88054 .64075 .87889 .64668 Mtetra
.417 .043 .218 r
.87889 .64668 .88054 .64075 .88706 .63898 .88544 .64495 Mtetra
.418 .045 .22 r
.88544 .64495 .88706 .63898 .89359 .6372 .892 .64322 Mtetra
.419 .046 .222 r
.892 .64322 .89359 .6372 .90013 .6354 .89858 .64147 Mtetra
.419 .048 .225 r
.89858 .64147 .90013 .6354 .90669 .63359 .90518 .6397 Mtetra
.417 .047 .226 r
.90518 .6397 .90669 .63359 .91326 .63171 .91178 .63786 Mtetra
.416 .047 .228 r
.91178 .63786 .91326 .63171 .91983 .62977 .91838 .63597 Mtetra
.4 .035 .225 r
.91838 .63597 .91983 .62977 .92638 .6275 .92497 .63372 Mtetra
.38 .019 .221 r
.92497 .63372 .92638 .6275 .9329 .62483 .93152 .63108 Mtetra
.346 0 .213 r
.93152 .63108 .9329 .62483 .93935 .62156 .938 .6278 Mtetra
.235 0 .181 r
.938 .6278 .93935 .62156 .94559 .61647 .94427 .62265 Mtetra
.135 0 .149 r
.94427 .62265 .94559 .61647 .95166 .60999 .95036 .61606 Mtetra
0 0 .06 r
.95036 .61606 .95166 .60999 .9573 .60013 .95601 .60596 Mtetra
0 0 0 r
.95601 .60596 .9573 .60013 .96238 .58602 .96108 .59147 Mtetra
.96108 .59147 .96238 .58602 .96706 .56911 .96573 .57407 Mtetra
.863 .759 .25 r
.96573 .57407 .96706 .56911 .97068 .54455 .9693 .54876 Mtetra
.923 .774 .295 r
.9693 .54876 .97068 .54455 .97379 .51675 .97233 .52011 Mtetra
.912 .602 .447 r
.38337 .66338 .38671 .66286 .39093 .68981 .38755 .69086 Mtetra
.904 .59 .442 r
.38755 .69086 .39093 .68981 .39534 .71446 .39193 .716 Mtetra
.881 .547 .413 r
.39193 .716 .39534 .71446 .40009 .73183 .39666 .73373 Mtetra
.863 .518 .395 r
.39666 .73373 .40009 .73183 .405 .74619 .40157 .74837 Mtetra
.821 .447 .348 r
.40157 .74837 .405 .74619 .41013 .75579 .40669 .75817 Mtetra
.739 .324 .263 r
.40669 .75817 .41013 .75579 .41544 .76111 .41201 .7636 Mtetra
.671 .233 .2 r
.41201 .7636 .41544 .76111 .42083 .7646 .41741 .76715 Mtetra
.499 .019 .048 r
.41741 .76715 .42083 .7646 .42632 .7655 .42291 .76807 Mtetra
.393 0 0 r
.42291 .76807 .42632 .7655 .43185 .76545 .42845 .76801 Mtetra
.307 0 0 r
.42845 .76801 .43185 .76545 .43742 .76479 .43403 .76733 Mtetra
.206 0 0 r
.43403 .76733 .43742 .76479 .44301 .76353 .43964 .76604 Mtetra
.186 0 0 r
.43964 .76604 .44301 .76353 .44861 .76218 .44526 .76466 Mtetra
.163 0 0 r
.44526 .76466 .44861 .76218 .45423 .76072 .4509 .76317 Mtetra
.148 0 0 r
.4509 .76317 .45423 .76072 .45987 .7592 .45655 .76162 Mtetra
.141 0 0 r
.45655 .76162 .45987 .7592 .46551 .75767 .46221 .76005 Mtetra
.137 0 0 r
.46221 .76005 .46551 .75767 .47117 .75613 .46788 .75849 Mtetra
.13 0 0 r
.46788 .75849 .47117 .75613 .47683 .75458 .47356 .75691 Mtetra
.126 0 0 r
.47356 .75691 .47683 .75458 .48251 .75302 .47926 .75532 Mtetra
.124 0 0 r
.47926 .75532 .48251 .75302 .48821 .75147 .48497 .75375 Mtetra
.119 0 0 r
.48497 .75375 .48821 .75147 .49391 .74992 .49068 .75216 Mtetra
.114 0 0 r
.49068 .75216 .49391 .74992 .49962 .74835 .49642 .75057 Mtetra
.113 0 0 r
.49642 .75057 .49962 .74835 .50535 .7468 .50216 .74899 Mtetra
.108 0 0 r
.50216 .74899 .50535 .7468 .51109 .74524 .50791 .74741 Mtetra
.103 0 0 r
.50791 .74741 .51109 .74524 .51684 .74367 .51368 .74581 Mtetra
.102 0 0 r
.51368 .74581 .51684 .74367 .5226 .7421 .51946 .74422 Mtetra
.099 0 0 r
.51946 .74422 .5226 .7421 .52838 .74054 .52525 .74263 Mtetra
.093 0 0 r
.52525 .74263 .52838 .74054 .53416 .73895 .53105 .74103 Mtetra
.092 0 0 r
.53105 .74103 .53416 .73895 .53996 .73738 .53687 .73944 Mtetra
.09 0 0 r
.53687 .73944 .53996 .73738 .54577 .73581 .54269 .73785 Mtetra
.085 0 0 r
.54269 .73785 .54577 .73581 .5516 .73422 .54853 .73624 Mtetra
.084 0 0 r
.54853 .73624 .5516 .73422 .55743 .73264 .55439 .73464 Mtetra
.083 0 0 r
.55439 .73464 .55743 .73264 .56328 .73106 .56025 .73304 Mtetra
.078 0 0 r
.56025 .73304 .56328 .73106 .56914 .72947 .56613 .73143 Mtetra
.076 0 0 r
.56613 .73143 .56914 .72947 .57501 .72787 .57201 .72982 Mtetra
.57201 .72982 .57501 .72787 .5809 .72629 .57792 .72822 Mtetra
.072 0 0 r
.57792 .72822 .5809 .72629 .5868 .72469 .58383 .72661 Mtetra
.07 0 0 r
.58383 .72661 .5868 .72469 .59271 .72309 .58976 .72499 Mtetra
.071 0 0 r
.58976 .72499 .59271 .72309 .59863 .72149 .59569 .72339 Mtetra
.068 0 0 r
.59569 .72339 .59863 .72149 .60456 .71989 .60165 .72177 Mtetra
.065 0 0 r
.60165 .72177 .60456 .71989 .61051 .71827 .60761 .72014 Mtetra
.067 0 0 r
.60761 .72014 .61051 .71827 .61647 .71667 .61359 .71853 Mtetra
.064 0 0 r
.61359 .71853 .61647 .71667 .62244 .71506 .61958 .71691 Mtetra
.062 0 0 r
.61958 .71691 .62244 .71506 .62843 .71344 .62558 .71528 Mtetra
.064 0 0 r
.62558 .71528 .62843 .71344 .63443 .71183 .6316 .71366 Mtetra
.063 0 0 r
.6316 .71366 .63443 .71183 .64044 .71022 .63762 .71204 Mtetra
.06 0 0 r
.63762 .71204 .64044 .71022 .64646 .70859 .64367 .71041 Mtetra
.062 0 0 r
.64367 .71041 .64646 .70859 .6525 .70697 .64972 .70878 Mtetra
.64972 .70878 .6525 .70697 .65855 .70535 .65579 .70715 Mtetra
.059 0 0 r
.65579 .70715 .65855 .70535 .66462 .70371 .66187 .70551 Mtetra
.061 0 0 r
.66187 .70551 .66462 .70371 .67069 .70208 .66796 .70388 Mtetra
.063 0 0 r
.66796 .70388 .67069 .70208 .67678 .70045 .67407 .70225 Mtetra
.06 0 0 r
.67407 .70225 .67678 .70045 .68289 .69881 .68019 .7006 Mtetra
.061 0 0 r
.68019 .7006 .68289 .69881 .689 .69717 .68632 .69896 Mtetra
.064 0 0 r
.68632 .69896 .689 .69717 .69513 .69553 .69247 .69732 Mtetra
.063 0 0 r
.69247 .69732 .69513 .69553 .70127 .69388 .69863 .69567 Mtetra
.69863 .69567 .70127 .69388 .70743 .69223 .70481 .69402 Mtetra
.067 0 0 r
.70481 .69402 .70743 .69223 .7136 .69059 .711 .69238 Mtetra
.711 .69238 .7136 .69059 .71978 .68893 .7172 .69073 Mtetra
.7172 .69073 .71978 .68893 .72598 .68727 .72341 .68906 Mtetra
.071 0 0 r
.72341 .68906 .72598 .68727 .73219 .68562 .72964 .68742 Mtetra
.072 0 0 r
.72964 .68742 .73219 .68562 .73841 .68396 .73588 .68576 Mtetra
.73588 .68576 .73841 .68396 .74465 .68228 .74214 .68409 Mtetra
.076 0 0 r
.74214 .68409 .74465 .68228 .7509 .68062 .74841 .68244 Mtetra
.078 0 0 r
.74841 .68244 .7509 .68062 .75717 .67896 .7547 .68078 Mtetra
.079 0 0 r
.7547 .68078 .75717 .67896 .76345 .67729 .76099 .67912 Mtetra
.082 0 0 r
.76099 .67912 .76345 .67729 .76974 .67561 .76731 .67745 Mtetra
.084 0 0 r
.76731 .67745 .76974 .67561 .77605 .67393 .77363 .67578 Mtetra
.087 0 0 r
.77363 .67578 .77605 .67393 .78237 .67225 .77997 .67411 Mtetra
.09 0 0 r
.77997 .67411 .78237 .67225 .7887 .67057 .78633 .67244 Mtetra
.093 0 0 r
.78633 .67244 .7887 .67057 .79505 .66888 .7927 .67076 Mtetra
.096 0 0 r
.7927 .67076 .79505 .66888 .80141 .66719 .79908 .66909 Mtetra
.099 0 0 r
.79908 .66909 .80141 .66719 .80779 .6655 .80548 .66741 Mtetra
.102 0 0 r
.80548 .66741 .80779 .6655 .81418 .6638 .81189 .66573 Mtetra
.105 0 0 r
.81189 .66573 .81418 .6638 .82059 .66211 .81832 .66404 Mtetra
.109 0 0 r
.81832 .66404 .82059 .66211 .82701 .6604 .82476 .66236 Mtetra
.113 0 0 r
.82476 .66236 .82701 .6604 .83344 .6587 .83122 .66067 Mtetra
.116 0 0 r
.83122 .66067 .83344 .6587 .83989 .65699 .83769 .65898 Mtetra
.12 0 0 r
.83769 .65898 .83989 .65699 .84635 .65528 .84417 .65729 Mtetra
.124 0 0 r
.84417 .65729 .84635 .65528 .85283 .65357 .85068 .65559 Mtetra
.128 0 0 r
.85068 .65559 .85283 .65357 .85932 .65185 .85719 .6539 Mtetra
.132 0 0 r
.85719 .6539 .85932 .65185 .86583 .65013 .86372 .6522 Mtetra
.136 0 0 r
.86372 .6522 .86583 .65013 .87235 .64841 .87027 .6505 Mtetra
.141 0 0 r
.87027 .6505 .87235 .64841 .87889 .64668 .87683 .6488 Mtetra
.145 0 0 r
.87683 .6488 .87889 .64668 .88544 .64495 .8834 .64709 Mtetra
.149 0 0 r
.8834 .64709 .88544 .64495 .892 .64322 .88999 .64538 Mtetra
.153 0 0 r
.88999 .64538 .892 .64322 .89858 .64147 .8966 .64366 Mtetra
.155 0 0 r
.8966 .64366 .89858 .64147 .90518 .6397 .90321 .64191 Mtetra
.151 0 0 r
.90321 .64191 .90518 .6397 .91178 .63786 .90984 .6401 Mtetra
.149 0 0 r
.90984 .6401 .91178 .63786 .91838 .63597 .91648 .63824 Mtetra
.109 0 0 r
.91648 .63824 .91838 .63597 .92497 .63372 .92308 .63602 Mtetra
.059 0 0 r
.92308 .63602 .92497 .63372 .93152 .63108 .92966 .63338 Mtetra
0 0 0 r
.92966 .63338 .93152 .63108 .938 .6278 .93617 .63011 Mtetra
.93617 .63011 .938 .6278 .94427 .62265 .94246 .62492 Mtetra
.94246 .62492 .94427 .62265 .95036 .61606 .94857 .61825 Mtetra
.76 .885 .473 r
.94857 .61825 .95036 .61606 .95601 .60596 .95422 .60801 Mtetra
.911 .888 .468 r
.95422 .60801 .95601 .60596 .96108 .59147 .95929 .59328 Mtetra
.955 .869 .461 r
.95929 .59328 .96108 .59147 .96573 .57407 .96394 .57559 Mtetra
.987 .816 .426 r
.96394 .57559 .96573 .57407 .9693 .54876 .96748 .54983 Mtetra
.993 .798 .422 r
.96748 .54983 .9693 .54876 .97233 .52011 .97048 .52065 Mtetra
.921 .61 .438 r
.38005 .66292 .38337 .66338 .38755 .69086 .3842 .69078 Mtetra
.915 .599 .431 r
.3842 .69078 .38755 .69086 .39193 .716 .38855 .71629 Mtetra
.898 .558 .393 r
.38855 .71629 .39193 .716 .39666 .73373 .39326 .73427 Mtetra
.884 .529 .369 r
.39326 .73427 .39666 .73373 .40157 .74837 .39816 .74913 Mtetra
.846 .453 .302 r
.39816 .74913 .40157 .74837 .40669 .75817 .40328 .75906 Mtetra
.758 .302 .169 r
.40328 .75906 .40669 .75817 .41201 .7636 .4086 .76456 Mtetra
.671 .174 .058 r
.4086 .76456 .41201 .7636 .41741 .76715 .414 .76816 Mtetra
.397 0 0 r
.414 .76816 .41741 .76715 .42291 .76807 .41952 .76909 Mtetra
.21 0 0 r
.41952 .76909 .42291 .76807 .42845 .76801 .42507 .76902 Mtetra
.059 0 0 r
.42507 .76902 .42845 .76801 .43403 .76733 .43067 .76833 Mtetra
0 0 0 r
.43067 .76833 .43403 .76733 .43964 .76604 .43629 .76702 Mtetra
.43629 .76702 .43964 .76604 .44526 .76466 .44192 .76561 Mtetra
.44192 .76561 .44526 .76466 .4509 .76317 .44757 .76409 Mtetra
.192 .713 .684 r
.44757 .76409 .4509 .76317 .45655 .76162 .45323 .76251 Mtetra
.2 .719 .692 r
.45323 .76251 .45655 .76162 .46221 .76005 .45891 .76092 Mtetra
.206 .724 .698 r
.45891 .76092 .46221 .76005 .46788 .75849 .46459 .75933 Mtetra
.214 .731 .706 r
.46459 .75933 .46788 .75849 .47356 .75691 .47029 .75772 Mtetra
.22 .735 .712 r
.47029 .75772 .47356 .75691 .47926 .75532 .476 .75611 Mtetra
.221 .736 .716 r
.476 .75611 .47926 .75532 .48497 .75375 .48172 .75452 Mtetra
.227 .742 .722 r
.48172 .75452 .48497 .75375 .49068 .75216 .48745 .75291 Mtetra
.234 .746 .728 r
.48745 .75291 .49068 .75216 .49642 .75057 .4932 .75129 Mtetra
.234 .747 .731 r
.4932 .75129 .49642 .75057 .50216 .74899 .49896 .7497 Mtetra
.239 .751 .737 r
.49896 .7497 .50216 .74899 .50791 .74741 .50472 .74809 Mtetra
.245 .756 .742 r
.50472 .74809 .50791 .74741 .51368 .74581 .5105 .74647 Mtetra
.246 .756 .745 r
.5105 .74647 .51368 .74581 .51946 .74422 .5163 .74487 Mtetra
.249 .759 .749 r
.5163 .74487 .51946 .74422 .52525 .74263 .5221 .74326 Mtetra
.255 .763 .754 r
.5221 .74326 .52525 .74263 .53105 .74103 .52792 .74164 Mtetra
.256 .764 .757 r
.52792 .74164 .53105 .74103 .53687 .73944 .53375 .74003 Mtetra
.258 .766 .76 r
.53375 .74003 .53687 .73944 .54269 .73785 .53959 .73842 Mtetra
.264 .77 .765 r
.53959 .73842 .54269 .73785 .54853 .73624 .54544 .7368 Mtetra
.265 .771 .767 r
.54544 .7368 .54853 .73624 .55439 .73464 .55131 .73518 Mtetra
.265 .771 .769 r
.55131 .73518 .55439 .73464 .56025 .73304 .55718 .73357 Mtetra
.271 .775 .773 r
.55718 .73357 .56025 .73304 .56613 .73143 .56307 .73194 Mtetra
.272 .776 .775 r
.56307 .73194 .56613 .73143 .57201 .72982 .56898 .73032 Mtetra
.272 .776 .777 r
.56898 .73032 .57201 .72982 .57792 .72822 .57489 .72871 Mtetra
.276 .779 .78 r
.57489 .72871 .57792 .72822 .58383 .72661 .58082 .72708 Mtetra
.278 .78 .782 r
.58082 .72708 .58383 .72661 .58976 .72499 .58676 .72545 Mtetra
.276 .779 .783 r
.58676 .72545 .58976 .72499 .59569 .72339 .59271 .72383 Mtetra
.28 .782 .785 r
.59271 .72383 .59569 .72339 .60165 .72177 .59868 .72221 Mtetra
.283 .784 .788 r
.59868 .72221 .60165 .72177 .60761 .72014 .60466 .72057 Mtetra
.28 .782 .787 r
.60466 .72057 .60761 .72014 .61359 .71853 .61065 .71895 Mtetra
.282 .783 .789 r
.61065 .71895 .61359 .71853 .61958 .71691 .61665 .71732 Mtetra
.285 .785 .791 r
.61665 .71732 .61958 .71691 .62558 .71528 .62267 .71568 Mtetra
.283 .784 .791 r
.62267 .71568 .62558 .71528 .6316 .71366 .6287 .71406 Mtetra
.284 .784 .792 r
.6287 .71406 .6316 .71366 .63762 .71204 .63474 .71243 Mtetra
.287 .786 .793 r
.63474 .71243 .63762 .71204 .64367 .71041 .6408 .71078 Mtetra
.284 .785 .793 r
.6408 .71078 .64367 .71041 .64972 .70878 .64687 .70915 Mtetra
.284 .784 .793 r
.64687 .70915 .64972 .70878 .65579 .70715 .65295 .70752 Mtetra
.287 .786 .794 r
.65295 .70752 .65579 .70715 .66187 .70551 .65905 .70587 Mtetra
.285 .785 .794 r
.65905 .70587 .66187 .70551 .66796 .70388 .66516 .70423 Mtetra
.282 .784 .793 r
.66516 .70423 .66796 .70388 .67407 .70225 .67128 .7026 Mtetra
.285 .785 .794 r
.67128 .7026 .67407 .70225 .68019 .7006 .67741 .70095 Mtetra
.284 .784 .793 r
.67741 .70095 .68019 .7006 .68632 .69896 .68356 .6993 Mtetra
.28 .782 .791 r
.68356 .6993 .68632 .69896 .69247 .69732 .68973 .69766 Mtetra
.282 .783 .792 r
.68973 .69766 .69247 .69732 .69863 .69567 .6959 .69601 Mtetra
.281 .783 .791 r
.6959 .69601 .69863 .69567 .70481 .69402 .70209 .69436 Mtetra
.277 .78 .789 r
.70209 .69436 .70481 .69402 .711 .69238 .7083 .69272 Mtetra
.7083 .69272 .711 .69238 .7172 .69073 .71451 .69106 Mtetra
.278 .78 .788 r
.71451 .69106 .7172 .69073 .72341 .68906 .72074 .6894 Mtetra
.272 .776 .785 r
.72074 .6894 .72341 .68906 .72964 .68742 .72699 .68776 Mtetra
.272 .776 .784 r
.72699 .68776 .72964 .68742 .73588 .68576 .73325 .6861 Mtetra
.272 .776 .783 r
.73325 .6861 .73588 .68576 .74214 .68409 .73952 .68444 Mtetra
.266 .773 .78 r
.73952 .68444 .74214 .68409 .74841 .68244 .74581 .68278 Mtetra
.264 .771 .777 r
.74581 .68278 .74841 .68244 .7547 .68078 .75211 .68113 Mtetra
.263 .77 .776 r
.75211 .68113 .7547 .68078 .76099 .67912 .75843 .67947 Mtetra
.26 .768 .773 r
.75843 .67947 .76099 .67912 .76731 .67745 .76476 .67781 Mtetra
.257 .766 .77 r
.76476 .67781 .76731 .67745 .77363 .67578 .7711 .67614 Mtetra
.254 .764 .768 r
.7711 .67614 .77363 .67578 .77997 .67411 .77746 .67448 Mtetra
.251 .762 .765 r
.77746 .67448 .77997 .67411 .78633 .67244 .78383 .67281 Mtetra
.248 .759 .761 r
.78383 .67281 .78633 .67244 .7927 .67076 .79022 .67114 Mtetra
.244 .757 .758 r
.79022 .67114 .7927 .67076 .79908 .66909 .79662 .66948 Mtetra
.241 .754 .754 r
.79662 .66948 .79908 .66909 .80548 .66741 .80303 .66781 Mtetra
.237 .751 .751 r
.80303 .66781 .80548 .66741 .81189 .66573 .80946 .66613 Mtetra
.233 .748 .747 r
.80946 .66613 .81189 .66573 .81832 .66404 .81591 .66446 Mtetra
.229 .745 .742 r
.81591 .66446 .81832 .66404 .82476 .66236 .82237 .66278 Mtetra
.225 .742 .738 r
.82237 .66278 .82476 .66236 .83122 .66067 .82885 .66111 Mtetra
.22 .738 .733 r
.82885 .66111 .83122 .66067 .83769 .65898 .83534 .65943 Mtetra
.215 .735 .729 r
.83534 .65943 .83769 .65898 .84417 .65729 .84184 .65775 Mtetra
.21 .731 .724 r
.84184 .65775 .84417 .65729 .85068 .65559 .84836 .65607 Mtetra
.205 .727 .718 r
.84836 .65607 .85068 .65559 .85719 .6539 .8549 .65439 Mtetra
.2 .723 .713 r
.8549 .65439 .85719 .6539 .86372 .6522 .86145 .65271 Mtetra
.195 .719 .707 r
.86145 .65271 .86372 .6522 .87027 .6505 .86801 .65102 Mtetra
.189 .714 .701 r
.86801 .65102 .87027 .6505 .87683 .6488 .87459 .64933 Mtetra
.183 .709 .695 r
.87459 .64933 .87683 .6488 .8834 .64709 .88119 .64765 Mtetra
.179 .705 .689 r
.88119 .64765 .8834 .64709 .88999 .64538 .8878 .64595 Mtetra
0 0 0 r
.8878 .64595 .88999 .64538 .8966 .64366 .89442 .64425 Mtetra
.89442 .64425 .8966 .64366 .90321 .64191 .90106 .64252 Mtetra
.90106 .64252 .90321 .64191 .90984 .6401 .90771 .64073 Mtetra
.90771 .64073 .90984 .6401 .91648 .63824 .91437 .63888 Mtetra
.236 .741 .686 r
.91437 .63888 .91648 .63824 .92308 .63602 .921 .63668 Mtetra
.302 .783 .702 r
.921 .63668 .92308 .63602 .92966 .63338 .92759 .63405 Mtetra
.403 .843 .724 r
.92759 .63405 .92966 .63338 .93617 .63011 .93412 .63078 Mtetra
.653 .955 .746 r
.93412 .63078 .93617 .63011 .94246 .62492 .94043 .62556 Mtetra
.78 .984 .729 r
.94043 .62556 .94246 .62492 .94857 .61825 .94656 .61884 Mtetra
.926 .962 .652 r
.94656 .61884 .94857 .61825 .95422 .60801 .95223 .6085 Mtetra
.98 .903 .572 r
.95223 .6085 .95422 .60801 .95929 .59328 .9573 .59359 Mtetra
.993 .869 .537 r
.9573 .59359 .95929 .59328 .96394 .57559 .96195 .57568 Mtetra
.999 .81 .472 r
.96195 .57568 .96394 .57559 .96748 .54983 .96548 .54958 Mtetra
.999 .792 .458 r
.96548 .54958 .96748 .54983 .97048 .52065 .96847 .52003 Mtetra
.933 .619 .423 r
.37677 .66115 .38005 .66292 .3842 .69078 .38089 .68921 Mtetra
.93 .61 .412 r
.38089 .68921 .3842 .69078 .38855 .71629 .38521 .71489 Mtetra
.92 .571 .359 r
.38521 .71489 .38855 .71629 .39326 .73427 .38991 .733 Mtetra
.909 .54 .32 r
.38991 .733 .39326 .73427 .39816 .74913 .3948 .74796 Mtetra
.873 .452 .208 r
.3948 .74796 .39816 .74913 .40328 .75906 .39992 .75796 Mtetra
.748 .23 0 r
.39992 .75796 .40328 .75906 .4086 .76456 .40524 .7635 Mtetra
.578 .001 0 r
.40524 .7635 .4086 .76456 .414 .76816 .41065 .76712 Mtetra
.006 .557 .825 r
.41065 .76712 .414 .76816 .41952 .76909 .41617 .76804 Mtetra
.278 .739 .951 r
.41617 .76804 .41952 .76909 .42507 .76902 .42173 .76797 Mtetra
.427 .816 .987 r
.42173 .76797 .42507 .76902 .43067 .76833 .42733 .76727 Mtetra
.544 .863 .996 r
.42733 .76727 .43067 .76833 .43629 .76702 .43297 .76594 Mtetra
.559 .867 .996 r
.43297 .76594 .43629 .76702 .44192 .76561 .43861 .76451 Mtetra
.577 .872 .995 r
.43861 .76451 .44192 .76561 .44757 .76409 .44427 .76298 Mtetra
.586 .874 .994 r
.44427 .76298 .44757 .76409 .45323 .76251 .44994 .76138 Mtetra
.588 .874 .994 r
.44994 .76138 .45323 .76251 .45891 .76092 .45563 .75977 Mtetra
.59 .873 .994 r
.45563 .75977 .45891 .76092 .46459 .75933 .46133 .75816 Mtetra
.592 .873 .994 r
.46133 .75816 .46459 .75933 .47029 .75772 .46703 .75654 Mtetra
.593 .872 .993 r
.46703 .75654 .47029 .75772 .476 .75611 .47275 .75492 Mtetra
.591 .871 .994 r
.47275 .75492 .476 .75611 .48172 .75452 .47848 .75331 Mtetra
.593 .871 .994 r
.47848 .75331 .48172 .75452 .48745 .75291 .48423 .75168 Mtetra
.594 .871 .993 r
.48423 .75168 .48745 .75291 .4932 .75129 .48998 .75005 Mtetra
.592 .869 .994 r
.48998 .75005 .4932 .75129 .49896 .7497 .49575 .74844 Mtetra
.594 .869 .994 r
.49575 .74844 .49896 .7497 .50472 .74809 .50153 .74682 Mtetra
.595 .869 .993 r
.50153 .74682 .50472 .74809 .5105 .74647 .50732 .74519 Mtetra
.594 .868 .994 r
.50732 .74519 .5105 .74647 .5163 .74487 .51312 .74357 Mtetra
.594 .867 .994 r
.51312 .74357 .5163 .74487 .5221 .74326 .51894 .74195 Mtetra
.596 .867 .993 r
.51894 .74195 .5221 .74326 .52792 .74164 .52477 .74032 Mtetra
.595 .866 .994 r
.52477 .74032 .52792 .74164 .53375 .74003 .5306 .73869 Mtetra
.5306 .73869 .53375 .74003 .53959 .73842 .53646 .73707 Mtetra
.596 .866 .993 r
.53646 .73707 .53959 .73842 .54544 .7368 .54232 .73544 Mtetra
.596 .865 .993 r
.54232 .73544 .54544 .7368 .55131 .73518 .5482 .73381 Mtetra
.595 .864 .994 r
.5482 .73381 .55131 .73518 .55718 .73357 .55409 .73219 Mtetra
.597 .865 .993 r
.55409 .73219 .55718 .73357 .56307 .73194 .55999 .73055 Mtetra
.596 .864 .993 r
.55999 .73055 .56307 .73194 .56898 .73032 .5659 .72892 Mtetra
.595 .863 .994 r
.5659 .72892 .56898 .73032 .57489 .72871 .57183 .7273 Mtetra
.596 .863 .993 r
.57183 .7273 .57489 .72871 .58082 .72708 .57776 .72566 Mtetra
.597 .863 .993 r
.57776 .72566 .58082 .72708 .58676 .72545 .58372 .72402 Mtetra
.595 .862 .994 r
.58372 .72402 .58676 .72545 .59271 .72383 .58968 .7224 Mtetra
.596 .862 .993 r
.58968 .7224 .59271 .72383 .59868 .72221 .59566 .72076 Mtetra
.597 .862 .993 r
.59566 .72076 .59868 .72221 .60466 .72057 .60165 .71911 Mtetra
.595 .861 .994 r
.60165 .71911 .60466 .72057 .61065 .71895 .60765 .71749 Mtetra
.595 .861 .993 r
.60765 .71749 .61065 .71895 .61665 .71732 .61366 .71585 Mtetra
.597 .862 .993 r
.61366 .71585 .61665 .71732 .62267 .71568 .61969 .7142 Mtetra
.595 .861 .994 r
.61969 .7142 .62267 .71568 .6287 .71406 .62573 .71257 Mtetra
.62573 .71257 .6287 .71406 .63474 .71243 .63179 .71093 Mtetra
.596 .861 .993 r
.63179 .71093 .63474 .71243 .6408 .71078 .63786 .70928 Mtetra
.594 .86 .994 r
.63786 .70928 .6408 .71078 .64687 .70915 .64394 .70764 Mtetra
.64394 .70764 .64687 .70915 .65295 .70752 .65003 .706 Mtetra
.595 .86 .993 r
.65003 .706 .65295 .70752 .65905 .70587 .65614 .70435 Mtetra
.594 .86 .994 r
.65614 .70435 .65905 .70587 .66516 .70423 .66226 .7027 Mtetra
.593 .86 .994 r
.66226 .7027 .66516 .70423 .67128 .7026 .66839 .70106 Mtetra
.594 .86 .994 r
.66839 .70106 .67128 .7026 .67741 .70095 .67454 .69941 Mtetra
.593 .86 .994 r
.67454 .69941 .67741 .70095 .68356 .6993 .6807 .69776 Mtetra
.592 .859 .994 r
.6807 .69776 .68356 .6993 .68973 .69766 .68688 .69612 Mtetra
.593 .86 .994 r
.68688 .69612 .68973 .69766 .6959 .69601 .69307 .69446 Mtetra
.69307 .69446 .6959 .69601 .70209 .69436 .69927 .6928 Mtetra
.59 .859 .994 r
.69927 .6928 .70209 .69436 .7083 .69272 .70548 .69116 Mtetra
.591 .86 .994 r
.70548 .69116 .7083 .69272 .71451 .69106 .71171 .6895 Mtetra
.592 .86 .994 r
.71171 .6895 .71451 .69106 .72074 .6894 .71796 .68784 Mtetra
.589 .859 .994 r
.71796 .68784 .72074 .6894 .72699 .68776 .72421 .68619 Mtetra
.589 .86 .994 r
.72421 .68619 .72699 .68776 .73325 .6861 .73049 .68453 Mtetra
.59 .86 .994 r
.73049 .68453 .73325 .6861 .73952 .68444 .73677 .68286 Mtetra
.588 .859 .995 r
.73677 .68286 .73952 .68444 .74581 .68278 .74307 .68121 Mtetra
.587 .86 .995 r
.74307 .68121 .74581 .68278 .75211 .68113 .74939 .67956 Mtetra
.74939 .67956 .75211 .68113 .75843 .67947 .75571 .67789 Mtetra
.75571 .67789 .75843 .67947 .76476 .67781 .76206 .67623 Mtetra
.586 .86 .995 r
.76206 .67623 .76476 .67781 .7711 .67614 .76841 .67457 Mtetra
.585 .86 .995 r
.76841 .67457 .7711 .67614 .77746 .67448 .77478 .6729 Mtetra
.585 .861 .995 r
.77478 .6729 .77746 .67448 .78383 .67281 .78117 .67123 Mtetra
.584 .861 .995 r
.78117 .67123 .78383 .67281 .79022 .67114 .78757 .66957 Mtetra
.583 .861 .995 r
.78757 .66957 .79022 .67114 .79662 .66948 .79399 .6679 Mtetra
.582 .861 .995 r
.79399 .6679 .79662 .66948 .80303 .66781 .80042 .66623 Mtetra
.581 .861 .995 r
.80042 .66623 .80303 .66781 .80946 .66613 .80686 .66456 Mtetra
.58 .861 .995 r
.80686 .66456 .80946 .66613 .81591 .66446 .81332 .66288 Mtetra
.58 .862 .995 r
.81332 .66288 .81591 .66446 .82237 .66278 .81979 .66121 Mtetra
.579 .862 .996 r
.81979 .66121 .82237 .66278 .82885 .66111 .82628 .65954 Mtetra
.577 .862 .996 r
.82628 .65954 .82885 .66111 .83534 .65943 .83279 .65786 Mtetra
.577 .863 .996 r
.83279 .65786 .83534 .65943 .84184 .65775 .83931 .65619 Mtetra
.575 .863 .996 r
.83931 .65619 .84184 .65775 .84836 .65607 .84584 .65451 Mtetra
.574 .863 .996 r
.84584 .65451 .84836 .65607 .8549 .65439 .85239 .65283 Mtetra
.573 .863 .996 r
.85239 .65283 .8549 .65439 .86145 .65271 .85896 .65115 Mtetra
.572 .864 .996 r
.85896 .65115 .86145 .65271 .86801 .65102 .86554 .64947 Mtetra
.571 .864 .996 r
.86554 .64947 .86801 .65102 .87459 .64933 .87213 .64779 Mtetra
.569 .864 .996 r
.87213 .64779 .87459 .64933 .88119 .64765 .87874 .64611 Mtetra
.569 .865 .996 r
.87874 .64611 .88119 .64765 .8878 .64595 .88537 .64442 Mtetra
.568 .866 .996 r
.88537 .64442 .8878 .64595 .89442 .64425 .89201 .64272 Mtetra
.569 .867 .996 r
.89201 .64272 .89442 .64425 .90106 .64252 .89867 .641 Mtetra
.575 .87 .995 r
.89867 .641 .90106 .64252 .90771 .64073 .90533 .63922 Mtetra
.58 .873 .994 r
.90533 .63922 .90771 .64073 .91437 .63888 .912 .63738 Mtetra
.618 .889 .989 r
.912 .63738 .91437 .63888 .921 .63668 .91865 .63517 Mtetra
.658 .905 .98 r
.91865 .63517 .921 .63668 .92759 .63405 .92526 .63255 Mtetra
.714 .922 .963 r
.92526 .63255 .92759 .63405 .93412 .63078 .93181 .62927 Mtetra
.832 .94 .896 r
.93181 .62927 .93412 .63078 .94043 .62556 .93813 .62403 Mtetra
.887 .934 .842 r
.93813 .62403 .94043 .62556 .94656 .61884 .94427 .61729 Mtetra
.954 .9 .732 r
.94427 .61729 .94656 .61884 .95223 .6085 .94996 .60688 Mtetra
.983 .858 .638 r
.94996 .60688 .95223 .6085 .9573 .59359 .95504 .59189 Mtetra
.99 .834 .594 r
.95504 .59189 .9573 .59359 .96195 .57568 .9597 .57387 Mtetra
.995 .791 .516 r
.9597 .57387 .96195 .57568 .96548 .54958 .96324 .54759 Mtetra
.995 .776 .494 r
.96324 .54759 .96548 .54958 .96847 .52003 .96623 .51785 Mtetra
.937 .623 .418 r
.37349 .65891 .37677 .66115 .38089 .68921 .37759 .68709 Mtetra
.935 .614 .405 r
.37759 .68709 .38089 .68921 .38521 .71489 .38189 .7129 Mtetra
.926 .575 .344 r
.38189 .7129 .38521 .71489 .38991 .733 .38657 .73108 Mtetra
.917 .544 .299 r
.38657 .73108 .38991 .733 .3948 .74796 .39145 .74611 Mtetra
.878 .447 .163 r
.39145 .74611 .3948 .74796 .39992 .75796 .39657 .75615 Mtetra
.716 .184 0 r
.39657 .75615 .39992 .75796 .40524 .7635 .40188 .76171 Mtetra
.48 0 0 r
.40188 .76171 .40524 .7635 .41065 .76712 .4073 .76534 Mtetra
.178 .63 .939 r
.4073 .76534 .41065 .76712 .41617 .76804 .41282 .76626 Mtetra
.404 .752 .994 r
.41282 .76626 .41617 .76804 .42173 .76797 .4184 .76619 Mtetra
.515 .798 .997 r
.4184 .76619 .42173 .76797 .42733 .76727 .42401 .76547 Mtetra
.601 .826 .986 r
.42401 .76547 .42733 .76727 .43297 .76594 .42965 .76413 Mtetra
.612 .828 .983 r
.42965 .76413 .43297 .76594 .43861 .76451 .4353 .7627 Mtetra
.624 .831 .98 r
.4353 .7627 .43861 .76451 .44427 .76298 .44097 .76115 Mtetra
.63 .832 .978 r
.44097 .76115 .44427 .76298 .44994 .76138 .44665 .75954 Mtetra
.632 .831 .977 r
.44665 .75954 .44994 .76138 .45563 .75977 .45235 .75792 Mtetra
.45235 .75792 .45563 .75977 .46133 .75816 .45805 .7563 Mtetra
.633 .83 .976 r
.45805 .7563 .46133 .75816 .46703 .75654 .46377 .75466 Mtetra
.46377 .75466 .46703 .75654 .47275 .75492 .4695 .75303 Mtetra
.632 .829 .976 r
.4695 .75303 .47275 .75492 .47848 .75331 .47524 .7514 Mtetra
.47524 .7514 .47848 .75331 .48423 .75168 .48099 .74977 Mtetra
.633 .829 .976 r
.48099 .74977 .48423 .75168 .48998 .75005 .48676 .74813 Mtetra
.631 .828 .976 r
.48676 .74813 .48998 .75005 .49575 .74844 .49254 .74651 Mtetra
.632 .827 .976 r
.49254 .74651 .49575 .74844 .50153 .74682 .49832 .74487 Mtetra
.633 .827 .975 r
.49832 .74487 .50153 .74682 .50732 .74519 .50412 .74323 Mtetra
.631 .826 .975 r
.50412 .74323 .50732 .74519 .51312 .74357 .50994 .7416 Mtetra
.50994 .7416 .51312 .74357 .51894 .74195 .51576 .73997 Mtetra
.632 .826 .975 r
.51576 .73997 .51894 .74195 .52477 .74032 .5216 .73833 Mtetra
.631 .825 .975 r
.5216 .73833 .52477 .74032 .5306 .73869 .52745 .7367 Mtetra
.52745 .7367 .5306 .73869 .53646 .73707 .53331 .73507 Mtetra
.632 .825 .975 r
.53331 .73507 .53646 .73707 .54232 .73544 .53918 .73342 Mtetra
.631 .824 .975 r
.53918 .73342 .54232 .73544 .5482 .73381 .54507 .73178 Mtetra
.63 .824 .975 r
.54507 .73178 .5482 .73381 .55409 .73219 .55097 .73015 Mtetra
.631 .824 .974 r
.55097 .73015 .55409 .73219 .55999 .73055 .55688 .72851 Mtetra
.631 .823 .974 r
.55688 .72851 .55999 .73055 .5659 .72892 .5628 .72687 Mtetra
.63 .823 .975 r
.5628 .72687 .5659 .72892 .57183 .7273 .56874 .72523 Mtetra
.631 .823 .974 r
.56874 .72523 .57183 .7273 .57776 .72566 .57469 .72359 Mtetra
.57469 .72359 .57776 .72566 .58372 .72402 .58065 .72194 Mtetra
.629 .822 .975 r
.58065 .72194 .58372 .72402 .58968 .7224 .58662 .72031 Mtetra
.63 .822 .974 r
.58662 .72031 .58968 .7224 .59566 .72076 .59261 .71866 Mtetra
.631 .822 .974 r
.59261 .71866 .59566 .72076 .60165 .71911 .59861 .71701 Mtetra
.629 .821 .975 r
.59861 .71701 .60165 .71911 .60765 .71749 .60462 .71538 Mtetra
.629 .821 .974 r
.60462 .71538 .60765 .71749 .61366 .71585 .61065 .71373 Mtetra
.63 .822 .974 r
.61065 .71373 .61366 .71585 .61969 .7142 .61668 .71208 Mtetra
.628 .821 .974 r
.61668 .71208 .61969 .7142 .62573 .71257 .62274 .71043 Mtetra
.62274 .71043 .62573 .71257 .63179 .71093 .6288 .70879 Mtetra
.629 .821 .974 r
.6288 .70879 .63179 .71093 .63786 .70928 .63488 .70713 Mtetra
.628 .821 .974 r
.63488 .70713 .63786 .70928 .64394 .70764 .64097 .70549 Mtetra
.627 .82 .975 r
.64097 .70549 .64394 .70764 .65003 .706 .64708 .70384 Mtetra
.628 .821 .974 r
.64708 .70384 .65003 .706 .65614 .70435 .65319 .70218 Mtetra
.627 .82 .975 r
.65319 .70218 .65614 .70435 .66226 .7027 .65932 .70053 Mtetra
.626 .82 .975 r
.65932 .70053 .66226 .7027 .66839 .70106 .66547 .69889 Mtetra
.628 .82 .975 r
.66547 .69889 .66839 .70106 .67454 .69941 .67163 .69723 Mtetra
.627 .82 .975 r
.67163 .69723 .67454 .69941 .6807 .69776 .6778 .69557 Mtetra
.626 .82 .975 r
.6778 .69557 .6807 .69776 .68688 .69612 .68399 .69392 Mtetra
.627 .82 .975 r
.68399 .69392 .68688 .69612 .69307 .69446 .69018 .69226 Mtetra
.626 .82 .975 r
.69018 .69226 .69307 .69446 .69927 .6928 .6964 .6906 Mtetra
.625 .82 .975 r
.6964 .6906 .69927 .6928 .70548 .69116 .70262 .68895 Mtetra
.70262 .68895 .70548 .69116 .71171 .6895 .70887 .68728 Mtetra
.626 .82 .975 r
.70887 .68728 .71171 .6895 .71796 .68784 .71512 .68561 Mtetra
.624 .82 .976 r
.71512 .68561 .71796 .68784 .72421 .68619 .72139 .68396 Mtetra
.72139 .68396 .72421 .68619 .73049 .68453 .72767 .6823 Mtetra
.625 .82 .976 r
.72767 .6823 .73049 .68453 .73677 .68286 .73397 .68063 Mtetra
.623 .82 .976 r
.73397 .68063 .73677 .68286 .74307 .68121 .74028 .67897 Mtetra
.74028 .67897 .74307 .68121 .74939 .67956 .74661 .67731 Mtetra
.74661 .67731 .74939 .67956 .75571 .67789 .75295 .67565 Mtetra
.75295 .67565 .75571 .67789 .76206 .67623 .7593 .67398 Mtetra
.622 .821 .977 r
.7593 .67398 .76206 .67623 .76841 .67457 .76567 .67231 Mtetra
.76567 .67231 .76841 .67457 .77478 .6729 .77205 .67064 Mtetra
.621 .821 .977 r
.77205 .67064 .77478 .6729 .78117 .67123 .77845 .66898 Mtetra
.77845 .66898 .78117 .67123 .78757 .66957 .78486 .6673 Mtetra
.78486 .6673 .78757 .66957 .79399 .6679 .79129 .66563 Mtetra
.62 .821 .978 r
.79129 .66563 .79399 .6679 .80042 .66623 .79773 .66396 Mtetra
.79773 .66396 .80042 .66623 .80686 .66456 .80419 .66229 Mtetra
.619 .822 .978 r
.80419 .66229 .80686 .66456 .81332 .66288 .81066 .66062 Mtetra
.81066 .66062 .81332 .66288 .81979 .66121 .81715 .65894 Mtetra
.618 .822 .979 r
.81715 .65894 .81979 .66121 .82628 .65954 .82365 .65726 Mtetra
.82365 .65726 .82628 .65954 .83279 .65786 .83017 .65559 Mtetra
.617 .822 .979 r
.83017 .65559 .83279 .65786 .83931 .65619 .8367 .65391 Mtetra
.617 .823 .979 r
.8367 .65391 .83931 .65619 .84584 .65451 .84325 .65223 Mtetra
.616 .823 .98 r
.84325 .65223 .84584 .65451 .85239 .65283 .84981 .65055 Mtetra
.84981 .65055 .85239 .65283 .85896 .65115 .85639 .64888 Mtetra
.615 .823 .98 r
.85639 .64888 .85896 .65115 .86554 .64947 .86298 .6472 Mtetra
.615 .824 .981 r
.86298 .6472 .86554 .64947 .87213 .64779 .86959 .64551 Mtetra
.614 .824 .981 r
.86959 .64551 .87213 .64779 .87874 .64611 .87621 .64383 Mtetra
.614 .825 .981 r
.87621 .64383 .87874 .64611 .88537 .64442 .88285 .64214 Mtetra
.88285 .64214 .88537 .64442 .89201 .64272 .88951 .64045 Mtetra
.616 .826 .981 r
.88951 .64045 .89201 .64272 .89867 .641 .89618 .63873 Mtetra
.621 .829 .98 r
.89618 .63873 .89867 .641 .90533 .63922 .90286 .63695 Mtetra
.625 .831 .98 r
.90286 .63695 .90533 .63922 .912 .63738 .90954 .6351 Mtetra
.655 .843 .972 r
.90954 .6351 .912 .63738 .91865 .63517 .9162 .6329 Mtetra
.687 .855 .963 r
.9162 .6329 .91865 .63517 .92526 .63255 .92283 .63028 Mtetra
.732 .868 .945 r
.92283 .63028 .92526 .63255 .93181 .62927 .92939 .62699 Mtetra
.829 .886 .883 r
.92939 .62699 .93181 .62927 .93813 .62403 .93573 .62174 Mtetra
.877 .885 .836 r
.93573 .62174 .93813 .62403 .94427 .61729 .94188 .61497 Mtetra
.941 .866 .737 r
.94188 .61497 .94427 .61729 .94996 .60688 .94758 .60453 Mtetra
.972 .836 .648 r
.94758 .60453 .94996 .60688 .95504 .59189 .95268 .58947 Mtetra
.981 .817 .605 r
.95268 .58947 .95504 .59189 .9597 .57387 .95736 .57137 Mtetra
.99 .782 .527 r
.95736 .57137 .9597 .57387 .96324 .54759 .96091 .54498 Mtetra
.991 .77 .504 r
.96091 .54498 .96324 .54759 .96623 .51785 .96391 .5151 Mtetra
.94 .625 .414 r
.37022 .65638 .37349 .65891 .37759 .68709 .37429 .68464 Mtetra
.938 .616 .4 r
.37429 .68464 .37759 .68709 .38189 .7129 .37856 .71052 Mtetra
.93 .577 .335 r
.37856 .71052 .38189 .7129 .38657 .73108 .38324 .72875 Mtetra
.921 .545 .284 r
.38324 .72875 .38657 .73108 .39145 .74611 .3881 .74382 Mtetra
.878 .443 .131 r
.3881 .74382 .39145 .74611 .39657 .75615 .39321 .7539 Mtetra
.681 .147 0 r
.39321 .7539 .39657 .75615 .40188 .76171 .39853 .75947 Mtetra
.396 0 0 r
.39853 .75947 .40188 .76171 .4073 .76534 .40395 .76311 Mtetra
.264 .644 .965 r
.40395 .76311 .4073 .76534 .41282 .76626 .40948 .76402 Mtetra
.456 .739 .989 r
.40948 .76402 .41282 .76626 .4184 .76619 .41506 .76394 Mtetra
.549 .774 .982 r
.41506 .76394 .4184 .76619 .42401 .76547 .42068 .76322 Mtetra
.62 .795 .966 r
.42068 .76322 .42401 .76547 .42965 .76413 .42633 .76187 Mtetra
.629 .797 .963 r
.42633 .76187 .42965 .76413 .4353 .7627 .43199 .76042 Mtetra
.639 .8 .96 r
.43199 .76042 .4353 .7627 .44097 .76115 .43767 .75886 Mtetra
.644 .801 .958 r
.43767 .75886 .44097 .76115 .44665 .75954 .44336 .75725 Mtetra
.645 .8 .957 r
.44336 .75725 .44665 .75954 .45235 .75792 .44906 .75562 Mtetra
.44906 .75562 .45235 .75792 .45805 .7563 .45478 .75398 Mtetra
.646 .8 .957 r
.45478 .75398 .45805 .7563 .46377 .75466 .4605 .75234 Mtetra
.4605 .75234 .46377 .75466 .4695 .75303 .46624 .75069 Mtetra
.645 .799 .957 r
.46624 .75069 .4695 .75303 .47524 .7514 .47199 .74906 Mtetra
.47199 .74906 .47524 .7514 .48099 .74977 .47775 .74742 Mtetra
.646 .799 .956 r
.47775 .74742 .48099 .74977 .48676 .74813 .48353 .74577 Mtetra
.644 .798 .957 r
.48353 .74577 .48676 .74813 .49254 .74651 .48931 .74414 Mtetra
.644 .798 .956 r
.48931 .74414 .49254 .74651 .49832 .74487 .49511 .74249 Mtetra
.645 .798 .956 r
.49511 .74249 .49832 .74487 .50412 .74323 .50092 .74084 Mtetra
.644 .797 .956 r
.50092 .74084 .50412 .74323 .50994 .7416 .50674 .73921 Mtetra
.50674 .73921 .50994 .7416 .51576 .73997 .51257 .73757 Mtetra
.51257 .73757 .51576 .73997 .5216 .73833 .51842 .73592 Mtetra
.643 .797 .956 r
.51842 .73592 .5216 .73833 .52745 .7367 .52428 .73427 Mtetra
.643 .796 .956 r
.52428 .73427 .52745 .7367 .53331 .73507 .53015 .73263 Mtetra
.644 .796 .956 r
.53015 .73263 .53331 .73507 .53918 .73342 .53603 .73098 Mtetra
.643 .796 .956 r
.53603 .73098 .53918 .73342 .54507 .73178 .54192 .72934 Mtetra
.642 .796 .956 r
.54192 .72934 .54507 .73178 .55097 .73015 .54783 .7277 Mtetra
.643 .796 .956 r
.54783 .7277 .55097 .73015 .55688 .72851 .55375 .72605 Mtetra
.643 .795 .956 r
.55375 .72605 .55688 .72851 .5628 .72687 .55968 .72439 Mtetra
.641 .795 .956 r
.55968 .72439 .5628 .72687 .56874 .72523 .56563 .72275 Mtetra
.642 .795 .956 r
.56563 .72275 .56874 .72523 .57469 .72359 .57159 .7211 Mtetra
.57159 .7211 .57469 .72359 .58065 .72194 .57756 .71945 Mtetra
.641 .794 .956 r
.57756 .71945 .58065 .72194 .58662 .72031 .58354 .71781 Mtetra
.641 .795 .956 r
.58354 .71781 .58662 .72031 .59261 .71866 .58954 .71615 Mtetra
.642 .795 .956 r
.58954 .71615 .59261 .71866 .59861 .71701 .59555 .71449 Mtetra
.64 .794 .956 r
.59555 .71449 .59861 .71701 .60462 .71538 .60157 .71285 Mtetra
.60157 .71285 .60462 .71538 .61065 .71373 .6076 .7112 Mtetra
.641 .794 .956 r
.6076 .7112 .61065 .71373 .61668 .71208 .61365 .70954 Mtetra
.64 .794 .956 r
.61365 .70954 .61668 .71208 .62274 .71043 .61971 .70789 Mtetra
.61971 .70789 .62274 .71043 .6288 .70879 .62579 .70624 Mtetra
.62579 .70624 .6288 .70879 .63488 .70713 .63188 .70457 Mtetra
.639 .793 .956 r
.63188 .70457 .63488 .70713 .64097 .70549 .63798 .70292 Mtetra
.639 .793 .957 r
.63798 .70292 .64097 .70549 .64708 .70384 .64409 .70127 Mtetra
.64 .794 .956 r
.64409 .70127 .64708 .70384 .65319 .70218 .65022 .6996 Mtetra
.639 .793 .956 r
.65022 .6996 .65319 .70218 .65932 .70053 .65636 .69795 Mtetra
.638 .793 .957 r
.65636 .69795 .65932 .70053 .66547 .69889 .66252 .69629 Mtetra
.639 .793 .956 r
.66252 .69629 .66547 .69889 .67163 .69723 .66868 .69463 Mtetra
.638 .793 .957 r
.66868 .69463 .67163 .69723 .6778 .69557 .67487 .69296 Mtetra
.637 .793 .957 r
.67487 .69296 .6778 .69557 .68399 .69392 .68106 .69131 Mtetra
.638 .793 .957 r
.68106 .69131 .68399 .69392 .69018 .69226 .68727 .68964 Mtetra
.68727 .68964 .69018 .69226 .6964 .6906 .69349 .68797 Mtetra
.636 .793 .957 r
.69349 .68797 .6964 .6906 .70262 .68895 .69973 .68632 Mtetra
.637 .793 .957 r
.69973 .68632 .70262 .68895 .70887 .68728 .70598 .68465 Mtetra
.70598 .68465 .70887 .68728 .71512 .68561 .71225 .68298 Mtetra
.635 .792 .958 r
.71225 .68298 .71512 .68561 .72139 .68396 .71853 .68132 Mtetra
.636 .793 .958 r
.71853 .68132 .72139 .68396 .72767 .6823 .72482 .67965 Mtetra
.637 .793 .957 r
.72482 .67965 .72767 .6823 .73397 .68063 .73113 .67797 Mtetra
.635 .793 .958 r
.73113 .67797 .73397 .68063 .74028 .67897 .73745 .67631 Mtetra
.73745 .67631 .74028 .67897 .74661 .67731 .74379 .67465 Mtetra
.74379 .67465 .74661 .67731 .75295 .67565 .75014 .67298 Mtetra
.75014 .67298 .75295 .67565 .7593 .67398 .7565 .67131 Mtetra
.634 .793 .958 r
.7565 .67131 .7593 .67398 .76567 .67231 .76288 .66963 Mtetra
.76288 .66963 .76567 .67231 .77205 .67064 .76928 .66796 Mtetra
.634 .793 .959 r
.76928 .66796 .77205 .67064 .77845 .66898 .77569 .66629 Mtetra
.77569 .66629 .77845 .66898 .78486 .6673 .78211 .66461 Mtetra
.633 .793 .959 r
.78211 .66461 .78486 .6673 .79129 .66563 .78855 .66294 Mtetra
.78855 .66294 .79129 .66563 .79773 .66396 .795 .66126 Mtetra
.795 .66126 .79773 .66396 .80419 .66229 .80147 .65958 Mtetra
.632 .793 .96 r
.80147 .65958 .80419 .66229 .81066 .66062 .80795 .6579 Mtetra
.80795 .6579 .81066 .66062 .81715 .65894 .81445 .65623 Mtetra
.81445 .65623 .81715 .65894 .82365 .65726 .82097 .65455 Mtetra
.631 .794 .96 r
.82097 .65455 .82365 .65726 .83017 .65559 .82749 .65287 Mtetra
.82749 .65287 .83017 .65559 .8367 .65391 .83404 .65119 Mtetra
.631 .794 .961 r
.83404 .65119 .8367 .65391 .84325 .65223 .8406 .6495 Mtetra
.63 .794 .961 r
.8406 .6495 .84325 .65223 .84981 .65055 .84717 .64782 Mtetra
.84717 .64782 .84981 .65055 .85639 .64888 .85376 .64614 Mtetra
.85376 .64614 .85639 .64888 .86298 .6472 .86037 .64446 Mtetra
.629 .794 .961 r
.86037 .64446 .86298 .6472 .86959 .64551 .86699 .64277 Mtetra
.629 .794 .962 r
.86699 .64277 .86959 .64551 .87621 .64383 .87363 .64109 Mtetra
.629 .795 .962 r
.87363 .64109 .87621 .64383 .88285 .64214 .88028 .6394 Mtetra
.88028 .6394 .88285 .64214 .88951 .64045 .88695 .6377 Mtetra
.631 .796 .962 r
.88695 .6377 .88951 .64045 .89618 .63873 .89363 .63598 Mtetra
.635 .798 .961 r
.89363 .63598 .89618 .63873 .90286 .63695 .90032 .63419 Mtetra
.639 .8 .96 r
.90032 .63419 .90286 .63695 .90954 .6351 .90702 .63235 Mtetra
.666 .811 .953 r
.90702 .63235 .90954 .6351 .9162 .6329 .91369 .63014 Mtetra
.694 .821 .943 r
.91369 .63014 .9162 .6329 .92283 .63028 .92033 .62751 Mtetra
.734 .833 .926 r
.92033 .62751 .92283 .63028 .92939 .62699 .92691 .62422 Mtetra
.822 .852 .871 r
.92691 .62422 .92939 .62699 .93573 .62174 .93326 .61895 Mtetra
.867 .855 .827 r
.93326 .61895 .93573 .62174 .94188 .61497 .93943 .61216 Mtetra
.931 .844 .737 r
.93943 .61216 .94188 .61497 .94758 .60453 .94514 .60169 Mtetra
.964 .821 .653 r
.94514 .60169 .94758 .60453 .95268 .58947 .95026 .58659 Mtetra
.975 .807 .611 r
.95026 .58659 .95268 .58947 .95736 .57137 .95495 .56843 Mtetra
.987 .776 .533 r
.95495 .56843 .95736 .57137 .96091 .54498 .95852 .54196 Mtetra
.988 .765 .509 r
.95852 .54196 .96091 .54498 .96391 .5151 .96154 .51199 Mtetra
.942 .627 .411 r
.36694 .65357 .37022 .65638 .37429 .68464 .37099 .68187 Mtetra
.941 .618 .396 r
.37099 .68187 .37429 .68464 .37856 .71052 .37524 .70779 Mtetra
.934 .579 .325 r
.37524 .70779 .37856 .71052 .38324 .72875 .3799 .72605 Mtetra
.924 .546 .269 r
.3799 .72605 .38324 .72875 .3881 .74382 .38476 .74115 Mtetra
.876 .437 .099 r
.38476 .74115 .3881 .74382 .39321 .7539 .38986 .75123 Mtetra
.637 .109 0 r
.38986 .75123 .39321 .7539 .39853 .75947 .39518 .75681 Mtetra
0 .21 .669 r
.39518 .75681 .39853 .75947 .40395 .76311 .4006 .76045 Mtetra
.324 .644 .967 r
.4006 .76045 .40395 .76311 .40948 .76402 .40614 .76137 Mtetra
.489 .72 .974 r
.40614 .76137 .40948 .76402 .41506 .76394 .41173 .76128 Mtetra
.568 .75 .963 r
.41173 .76128 .41506 .76394 .42068 .76322 .41735 .76055 Mtetra
.63 .768 .946 r
.41735 .76055 .42068 .76322 .42633 .76187 .42301 .75919 Mtetra
.637 .77 .943 r
.42301 .75919 .42633 .76187 .43199 .76042 .42868 .75774 Mtetra
.646 .773 .94 r
.42868 .75774 .43199 .76042 .43767 .75886 .43436 .75618 Mtetra
.651 .774 .938 r
.43436 .75618 .43767 .75886 .44336 .75725 .44006 .75455 Mtetra
.652 .774 .938 r
.44006 .75455 .44336 .75725 .44906 .75562 .44577 .75291 Mtetra
.44577 .75291 .44906 .75562 .45478 .75398 .45149 .75127 Mtetra
.45149 .75127 .45478 .75398 .4605 .75234 .45723 .74962 Mtetra
.45723 .74962 .4605 .75234 .46624 .75069 .46297 .74797 Mtetra
.651 .773 .938 r
.46297 .74797 .46624 .75069 .47199 .74906 .46873 .74633 Mtetra
.46873 .74633 .47199 .74906 .47775 .74742 .4745 .74468 Mtetra
.652 .773 .938 r
.4745 .74468 .47775 .74742 .48353 .74577 .48028 .74302 Mtetra
.65 .773 .938 r
.48028 .74302 .48353 .74577 .48931 .74414 .48608 .74138 Mtetra
.48608 .74138 .48931 .74414 .49511 .74249 .49188 .73973 Mtetra
.651 .773 .938 r
.49188 .73973 .49511 .74249 .50092 .74084 .4977 .73808 Mtetra
.65 .772 .938 r
.4977 .73808 .50092 .74084 .50674 .73921 .50353 .73643 Mtetra
.50353 .73643 .50674 .73921 .51257 .73757 .50937 .73478 Mtetra
.50937 .73478 .51257 .73757 .51842 .73592 .51523 .73313 Mtetra
.649 .772 .938 r
.51523 .73313 .51842 .73592 .52428 .73427 .52109 .73148 Mtetra
.649 .772 .939 r
.52109 .73148 .52428 .73427 .53015 .73263 .52697 .72983 Mtetra
.65 .772 .938 r
.52697 .72983 .53015 .73263 .53603 .73098 .53286 .72817 Mtetra
.649 .772 .938 r
.53286 .72817 .53603 .73098 .54192 .72934 .53877 .72652 Mtetra
.648 .772 .939 r
.53877 .72652 .54192 .72934 .54783 .7277 .54468 .72487 Mtetra
.649 .772 .938 r
.54468 .72487 .54783 .7277 .55375 .72605 .55061 .72322 Mtetra
.648 .772 .939 r
.55061 .72322 .55375 .72605 .55968 .72439 .55655 .72156 Mtetra
.647 .771 .939 r
.55655 .72156 .55968 .72439 .56563 .72275 .56251 .71991 Mtetra
.648 .771 .939 r
.56251 .71991 .56563 .72275 .57159 .7211 .56847 .71825 Mtetra
.56847 .71825 .57159 .7211 .57756 .71945 .57445 .71659 Mtetra
.647 .771 .939 r
.57445 .71659 .57756 .71945 .58354 .71781 .58044 .71494 Mtetra
.58044 .71494 .58354 .71781 .58954 .71615 .58645 .71328 Mtetra
.58645 .71328 .58954 .71615 .59555 .71449 .59247 .71162 Mtetra
.646 .771 .939 r
.59247 .71162 .59555 .71449 .60157 .71285 .5985 .70997 Mtetra
.5985 .70997 .60157 .71285 .6076 .7112 .60454 .70831 Mtetra
.647 .771 .939 r
.60454 .70831 .6076 .7112 .61365 .70954 .6106 .70664 Mtetra
.646 .771 .939 r
.6106 .70664 .61365 .70954 .61971 .70789 .61667 .70498 Mtetra
.645 .771 .939 r
.61667 .70498 .61971 .70789 .62579 .70624 .62275 .70333 Mtetra
.646 .771 .939 r
.62275 .70333 .62579 .70624 .63188 .70457 .62885 .70166 Mtetra
.645 .77 .939 r
.62885 .70166 .63188 .70457 .63798 .70292 .63496 .7 Mtetra
.645 .77 .94 r
.63496 .7 .63798 .70292 .64409 .70127 .64108 .69834 Mtetra
.645 .77 .939 r
.64108 .69834 .64409 .70127 .65022 .6996 .64722 .69667 Mtetra
.645 .77 .94 r
.64722 .69667 .65022 .6996 .65636 .69795 .65337 .695 Mtetra
.644 .77 .94 r
.65337 .695 .65636 .69795 .66252 .69629 .65954 .69334 Mtetra
.645 .77 .94 r
.65954 .69334 .66252 .69629 .66868 .69463 .66571 .69167 Mtetra
.644 .77 .94 r
.66571 .69167 .66868 .69463 .67487 .69296 .67191 .69 Mtetra
.643 .77 .94 r
.67191 .69 .67487 .69296 .68106 .69131 .67811 .68834 Mtetra
.644 .77 .94 r
.67811 .68834 .68106 .69131 .68727 .68964 .68433 .68667 Mtetra
.68433 .68667 .68727 .68964 .69349 .68797 .69056 .68499 Mtetra
.642 .77 .94 r
.69056 .68499 .69349 .68797 .69973 .68632 .69681 .68333 Mtetra
.643 .77 .94 r
.69681 .68333 .69973 .68632 .70598 .68465 .70307 .68165 Mtetra
.70307 .68165 .70598 .68465 .71225 .68298 .70935 .67997 Mtetra
.642 .769 .941 r
.70935 .67997 .71225 .68298 .71853 .68132 .71564 .67831 Mtetra
.642 .77 .94 r
.71564 .67831 .71853 .68132 .72482 .67965 .72194 .67664 Mtetra
.643 .77 .94 r
.72194 .67664 .72482 .67965 .73113 .67797 .72826 .67495 Mtetra
.641 .769 .941 r
.72826 .67495 .73113 .67797 .73745 .67631 .73459 .67328 Mtetra
.73459 .67328 .73745 .67631 .74379 .67465 .74093 .67161 Mtetra
.74093 .67161 .74379 .67465 .75014 .67298 .7473 .66993 Mtetra
.7473 .66993 .75014 .67298 .7565 .67131 .75367 .66826 Mtetra
.75367 .66826 .7565 .67131 .76288 .66963 .76006 .66658 Mtetra
.76006 .66658 .76288 .66963 .76928 .66796 .76647 .6649 Mtetra
.76647 .6649 .76928 .66796 .77569 .66629 .77288 .66322 Mtetra
.64 .769 .941 r
.77288 .66322 .77569 .66629 .78211 .66461 .77932 .66154 Mtetra
.77932 .66154 .78211 .66461 .78855 .66294 .78577 .65985 Mtetra
.78577 .65985 .78855 .66294 .795 .66126 .79223 .65817 Mtetra
.79223 .65817 .795 .66126 .80147 .65958 .79871 .65649 Mtetra
.639 .769 .942 r
.79871 .65649 .80147 .65958 .80795 .6579 .8052 .6548 Mtetra
.8052 .6548 .80795 .6579 .81445 .65623 .81171 .65312 Mtetra
.81171 .65312 .81445 .65623 .82097 .65455 .81824 .65143 Mtetra
.81824 .65143 .82097 .65455 .82749 .65287 .82478 .64975 Mtetra
.638 .769 .942 r
.82478 .64975 .82749 .65287 .83404 .65119 .83133 .64806 Mtetra
.83133 .64806 .83404 .65119 .8406 .6495 .8379 .64637 Mtetra
.8379 .64637 .8406 .6495 .84717 .64782 .84449 .64469 Mtetra
.84449 .64469 .84717 .64782 .85376 .64614 .85109 .643 Mtetra
.637 .769 .942 r
.85109 .643 .85376 .64614 .86037 .64446 .85771 .64131 Mtetra
.637 .769 .943 r
.85771 .64131 .86037 .64446 .86699 .64277 .86434 .63962 Mtetra
.86434 .63962 .86699 .64277 .87363 .64109 .87099 .63793 Mtetra
.87099 .63793 .87363 .64109 .88028 .6394 .87765 .63623 Mtetra
.87765 .63623 .88028 .6394 .88695 .6377 .88433 .63452 Mtetra
.639 .77 .942 r
.88433 .63452 .88695 .6377 .89363 .63598 .89102 .6328 Mtetra
.643 .771 .941 r
.89102 .6328 .89363 .63598 .90032 .63419 .89772 .631 Mtetra
.646 .773 .94 r
.89772 .631 .90032 .63419 .90702 .63235 .90444 .62915 Mtetra
.67 .782 .933 r
.90444 .62915 .90702 .63235 .91369 .63014 .91112 .62694 Mtetra
.696 .792 .924 r
.91112 .62694 .91369 .63014 .92033 .62751 .91777 .6243 Mtetra
.732 .804 .909 r
.91777 .6243 .92033 .62751 .92691 .62422 .92436 .621 Mtetra
.814 .824 .858 r
.92436 .621 .92691 .62422 .93326 .61895 .93073 .61572 Mtetra
.857 .83 .819 r
.93073 .61572 .93326 .61895 .93943 .61216 .93691 .60892 Mtetra
.92 .825 .735 r
.93691 .60892 .93943 .61216 .94514 .60169 .94264 .59842 Mtetra
.957 .809 .656 r
.94264 .59842 .94514 .60169 .95026 .58659 .94777 .58329 Mtetra
.969 .797 .615 r
.94777 .58329 .95026 .58659 .95495 .56843 .95248 .5651 Mtetra
.983 .771 .539 r
.95248 .5651 .95495 .56843 .95852 .54196 .95607 .53858 Mtetra
.986 .761 .514 r
.95607 .53858 .95852 .54196 .96154 .51199 .95911 .50856 Mtetra
.942 .627 .41 r
.36365 .65071 .36694 .65357 .37099 .68187 .36768 .67905 Mtetra
.941 .619 .395 r
.36768 .67905 .37099 .68187 .37524 .70779 .37191 .705 Mtetra
.934 .58 .324 r
.37191 .705 .37524 .70779 .3799 .72605 .37655 .72329 Mtetra
.925 .546 .267 r
.37655 .72329 .3799 .72605 .38476 .74115 .3814 .7384 Mtetra
.876 .436 .094 r
.3814 .7384 .38476 .74115 .38986 .75123 .3865 .7485 Mtetra
.63 .103 0 r
.3865 .7485 .38986 .75123 .39518 .75681 .39182 .75408 Mtetra
0 .218 .68 r
.39182 .75408 .39518 .75681 .4006 .76045 .39724 .75772 Mtetra
.332 .643 .966 r
.39724 .75772 .4006 .76045 .40614 .76137 .40278 .75863 Mtetra
.493 .717 .971 r
.40278 .75863 .40614 .76137 .41173 .76128 .40838 .75854 Mtetra
.571 .746 .96 r
.40838 .75854 .41173 .76128 .41735 .76055 .41401 .75781 Mtetra
.631 .764 .943 r
.41401 .75781 .41735 .76055 .42301 .75919 .41967 .75645 Mtetra
.638 .766 .94 r
.41967 .75645 .42301 .75919 .42868 .75774 .42535 .75499 Mtetra
.647 .769 .937 r
.42535 .75499 .42868 .75774 .43436 .75618 .43104 .75342 Mtetra
.652 .77 .935 r
.43104 .75342 .43436 .75618 .44006 .75455 .43675 .75178 Mtetra
.43675 .75178 .44006 .75455 .44577 .75291 .44247 .75014 Mtetra
.44247 .75014 .44577 .75291 .45149 .75127 .4482 .74849 Mtetra
.653 .77 .935 r
.4482 .74849 .45149 .75127 .45723 .74962 .45394 .74684 Mtetra
.45394 .74684 .45723 .74962 .46297 .74797 .45969 .74517 Mtetra
.652 .769 .935 r
.45969 .74517 .46297 .74797 .46873 .74633 .46546 .74353 Mtetra
.46546 .74353 .46873 .74633 .4745 .74468 .47124 .74187 Mtetra
.47124 .74187 .4745 .74468 .48028 .74302 .47703 .74021 Mtetra
.651 .769 .935 r
.47703 .74021 .48028 .74302 .48608 .74138 .48283 .73856 Mtetra
.48283 .73856 .48608 .74138 .49188 .73973 .48864 .73691 Mtetra
.652 .769 .935 r
.48864 .73691 .49188 .73973 .4977 .73808 .49447 .73524 Mtetra
.65 .769 .936 r
.49447 .73524 .4977 .73808 .50353 .73643 .50031 .73359 Mtetra
.50031 .73359 .50353 .73643 .50937 .73478 .50616 .73194 Mtetra
.651 .769 .935 r
.50616 .73194 .50937 .73478 .51523 .73313 .51202 .73027 Mtetra
.65 .769 .936 r
.51202 .73027 .51523 .73313 .52109 .73148 .51789 .72862 Mtetra
.649 .768 .936 r
.51789 .72862 .52109 .73148 .52697 .72983 .52378 .72696 Mtetra
.65 .769 .935 r
.52378 .72696 .52697 .72983 .53286 .72817 .52968 .7253 Mtetra
.649 .768 .936 r
.52968 .7253 .53286 .72817 .53877 .72652 .53559 .72364 Mtetra
.53559 .72364 .53877 .72652 .54468 .72487 .54152 .72199 Mtetra
.54152 .72199 .54468 .72487 .55061 .72322 .54746 .72032 Mtetra
.54746 .72032 .55061 .72322 .55655 .72156 .5534 .71866 Mtetra
.648 .768 .936 r
.5534 .71866 .55655 .72156 .56251 .71991 .55937 .717 Mtetra
.649 .768 .936 r
.55937 .717 .56251 .71991 .56847 .71825 .56534 .71534 Mtetra
.56534 .71534 .56847 .71825 .57445 .71659 .57133 .71367 Mtetra
.647 .768 .936 r
.57133 .71367 .57445 .71659 .58044 .71494 .57733 .71201 Mtetra
.648 .768 .936 r
.57733 .71201 .58044 .71494 .58645 .71328 .58335 .71035 Mtetra
.58335 .71035 .58645 .71328 .59247 .71162 .58937 .70867 Mtetra
.647 .767 .937 r
.58937 .70867 .59247 .71162 .5985 .70997 .59541 .70702 Mtetra
.647 .767 .936 r
.59541 .70702 .5985 .70997 .60454 .70831 .60147 .70535 Mtetra
.647 .768 .936 r
.60147 .70535 .60454 .70831 .6106 .70664 .60753 .70368 Mtetra
.646 .767 .937 r
.60753 .70368 .6106 .70664 .61667 .70498 .61361 .70202 Mtetra
.61361 .70202 .61667 .70498 .62275 .70333 .6197 .70035 Mtetra
.647 .767 .937 r
.6197 .70035 .62275 .70333 .62885 .70166 .62581 .69867 Mtetra
.646 .767 .937 r
.62581 .69867 .62885 .70166 .63496 .7 .63193 .69701 Mtetra
.645 .767 .937 r
.63193 .69701 .63496 .7 .64108 .69834 .63806 .69534 Mtetra
.646 .767 .937 r
.63806 .69534 .64108 .69834 .64722 .69667 .64421 .69366 Mtetra
.645 .767 .937 r
.64421 .69366 .64722 .69667 .65337 .695 .65037 .69199 Mtetra
.65037 .69199 .65337 .695 .65954 .69334 .65654 .69033 Mtetra
.65654 .69033 .65954 .69334 .66571 .69167 .66273 .68865 Mtetra
.66273 .68865 .66571 .69167 .67191 .69 .66893 .68697 Mtetra
.644 .766 .937 r
.66893 .68697 .67191 .69 .67811 .68834 .67515 .6853 Mtetra
.645 .767 .937 r
.67515 .6853 .67811 .68834 .68433 .68667 .68137 .68362 Mtetra
.68137 .68362 .68433 .68667 .69056 .68499 .68762 .68194 Mtetra
.643 .766 .938 r
.68762 .68194 .69056 .68499 .69681 .68333 .69387 .68027 Mtetra
.644 .766 .938 r
.69387 .68027 .69681 .68333 .70307 .68165 .70014 .67859 Mtetra
.644 .766 .937 r
.70014 .67859 .70307 .68165 .70935 .67997 .70643 .6769 Mtetra
.642 .766 .938 r
.70643 .6769 .70935 .67997 .71564 .67831 .71273 .67523 Mtetra
.643 .766 .938 r
.71273 .67523 .71564 .67831 .72194 .67664 .71904 .67355 Mtetra
.644 .766 .938 r
.71904 .67355 .72194 .67664 .72826 .67495 .72537 .67186 Mtetra
.642 .766 .938 r
.72537 .67186 .72826 .67495 .73459 .67328 .73171 .67019 Mtetra
.73171 .67019 .73459 .67328 .74093 .67161 .73807 .66851 Mtetra
.73807 .66851 .74093 .67161 .7473 .66993 .74444 .66682 Mtetra
.74444 .66682 .7473 .66993 .75367 .66826 .75082 .66514 Mtetra
.75082 .66514 .75367 .66826 .76006 .66658 .75722 .66345 Mtetra
.641 .766 .938 r
.75722 .66345 .76006 .66658 .76647 .6649 .76364 .66177 Mtetra
.76364 .66177 .76647 .6649 .77288 .66322 .77007 .66008 Mtetra
.77007 .66008 .77288 .66322 .77932 .66154 .77651 .65839 Mtetra
.641 .765 .939 r
.77651 .65839 .77932 .66154 .78577 .65985 .78297 .6567 Mtetra
.78297 .6567 .78577 .65985 .79223 .65817 .78944 .65501 Mtetra
.64 .765 .939 r
.78944 .65501 .79223 .65817 .79871 .65649 .79593 .65332 Mtetra
.79593 .65332 .79871 .65649 .8052 .6548 .80244 .65163 Mtetra
.80244 .65163 .8052 .6548 .81171 .65312 .80896 .64994 Mtetra
.80896 .64994 .81171 .65312 .81824 .65143 .81549 .64825 Mtetra
.639 .765 .939 r
.81549 .64825 .81824 .65143 .82478 .64975 .82204 .64656 Mtetra
.82204 .64656 .82478 .64975 .83133 .64806 .82861 .64486 Mtetra
.82861 .64486 .83133 .64806 .8379 .64637 .83519 .64317 Mtetra
.83519 .64317 .8379 .64637 .84449 .64469 .84179 .64147 Mtetra
.638 .765 .939 r
.84179 .64147 .84449 .64469 .85109 .643 .8484 .63978 Mtetra
.638 .765 .94 r
.8484 .63978 .85109 .643 .85771 .64131 .85503 .63808 Mtetra
.85503 .63808 .85771 .64131 .86434 .63962 .86167 .63639 Mtetra
.86167 .63639 .86434 .63962 .87099 .63793 .86833 .63469 Mtetra
.86833 .63469 .87099 .63793 .87765 .63623 .875 .63299 Mtetra
.875 .63299 .87765 .63623 .88433 .63452 .88169 .63127 Mtetra
.639 .766 .939 r
.88169 .63127 .88433 .63452 .89102 .6328 .8884 .62954 Mtetra
.644 .767 .938 r
.8884 .62954 .89102 .6328 .89772 .631 .89511 .62774 Mtetra
.647 .769 .937 r
.89511 .62774 .89772 .631 .90444 .62915 .90183 .62588 Mtetra
.671 .778 .93 r
.90183 .62588 .90444 .62915 .91112 .62694 .90853 .62366 Mtetra
.696 .787 .921 r
.90853 .62366 .91112 .62694 .91777 .6243 .9152 .62102 Mtetra
.732 .799 .906 r
.9152 .62102 .91777 .6243 .92436 .621 .9218 .6177 Mtetra
.813 .82 .856 r
.9218 .6177 .92436 .621 .93073 .61572 .92817 .61241 Mtetra
.856 .826 .818 r
.92817 .61241 .93073 .61572 .93691 .60892 .93437 .6056 Mtetra
.919 .822 .735 r
.93437 .6056 .93691 .60892 .94264 .59842 .94011 .59508 Mtetra
.956 .807 .656 r
.94011 .59508 .94264 .59842 .94777 .58329 .94526 .57992 Mtetra
.968 .795 .616 r
.94526 .57992 .94777 .58329 .95248 .5651 .94999 .56169 Mtetra
.983 .77 .539 r
.94999 .56169 .95248 .5651 .95607 .53858 .9536 .53513 Mtetra
.985 .76 .515 r
.9536 .53513 .95607 .53858 .95911 .50856 .95667 .50507 Mtetra
.943 .627 .41 r
.36036 .64779 .36365 .65071 .36768 .67905 .36436 .67616 Mtetra
.942 .619 .394 r
.36436 .67616 .36768 .67905 .37191 .705 .36856 .70214 Mtetra
.935 .58 .322 r
.36856 .70214 .37191 .705 .37655 .72329 .3732 .72044 Mtetra
.925 .547 .264 r
.3732 .72044 .37655 .72329 .3814 .7384 .37803 .73557 Mtetra
.875 .435 .088 r
.37803 .73557 .3814 .7384 .3865 .7485 .38313 .74568 Mtetra
.621 .096 0 r
.38313 .74568 .3865 .7485 .39182 .75408 .38845 .75126 Mtetra
0 .227 .692 r
.38845 .75126 .39182 .75408 .39724 .75772 .39387 .75491 Mtetra
.341 .642 .965 r
.39387 .75491 .39724 .75772 .40278 .75863 .39942 .75582 Mtetra
.498 .714 .968 r
.39942 .75582 .40278 .75863 .40838 .75854 .40502 .75572 Mtetra
.573 .742 .956 r
.40502 .75572 .40838 .75854 .41401 .75781 .41066 .75499 Mtetra
.632 .76 .939 r
.41066 .75499 .41401 .75781 .41967 .75645 .41633 .75362 Mtetra
.639 .762 .937 r
.41633 .75362 .41967 .75645 .42535 .75499 .42201 .75215 Mtetra
.648 .764 .933 r
.42201 .75215 .42535 .75499 .43104 .75342 .42771 .75057 Mtetra
.652 .765 .932 r
.42771 .75057 .43104 .75342 .43675 .75178 .43343 .74893 Mtetra
.653 .765 .932 r
.43343 .74893 .43675 .75178 .44247 .75014 .43915 .74728 Mtetra
.43915 .74728 .44247 .75014 .4482 .74849 .44489 .74563 Mtetra
.654 .765 .931 r
.44489 .74563 .4482 .74849 .45394 .74684 .45064 .74397 Mtetra
.45064 .74397 .45394 .74684 .45969 .74517 .4564 .7423 Mtetra
.652 .765 .932 r
.4564 .7423 .45969 .74517 .46546 .74353 .46218 .74065 Mtetra
.653 .765 .932 r
.46218 .74065 .46546 .74353 .47124 .74187 .46796 .73898 Mtetra
.46796 .73898 .47124 .74187 .47703 .74021 .47376 .73731 Mtetra
.652 .765 .932 r
.47376 .73731 .47703 .74021 .48283 .73856 .47957 .73566 Mtetra
.47957 .73566 .48283 .73856 .48864 .73691 .48539 .734 Mtetra
.48539 .734 .48864 .73691 .49447 .73524 .49123 .73233 Mtetra
.651 .764 .932 r
.49123 .73233 .49447 .73524 .50031 .73359 .49707 .73067 Mtetra
.49707 .73067 .50031 .73359 .50616 .73194 .50293 .72901 Mtetra
.652 .765 .932 r
.50293 .72901 .50616 .73194 .51202 .73027 .5088 .72734 Mtetra
.651 .764 .932 r
.5088 .72734 .51202 .73027 .51789 .72862 .51468 .72568 Mtetra
.65 .764 .933 r
.51468 .72568 .51789 .72862 .52378 .72696 .52058 .72402 Mtetra
.651 .764 .932 r
.52058 .72402 .52378 .72696 .52968 .7253 .52649 .72235 Mtetra
.65 .764 .933 r
.52649 .72235 .52968 .7253 .53559 .72364 .53241 .72068 Mtetra
.649 .764 .933 r
.53241 .72068 .53559 .72364 .54152 .72199 .53834 .71902 Mtetra
.65 .764 .933 r
.53834 .71902 .54152 .72199 .54746 .72032 .54429 .71735 Mtetra
.54429 .71735 .54746 .72032 .5534 .71866 .55025 .71568 Mtetra
.649 .764 .933 r
.55025 .71568 .5534 .71866 .55937 .717 .55622 .71402 Mtetra
.55622 .71402 .55937 .717 .56534 .71534 .5622 .71235 Mtetra
.5622 .71235 .56534 .71534 .57133 .71367 .5682 .71067 Mtetra
.648 .764 .933 r
.5682 .71067 .57133 .71367 .57733 .71201 .57421 .70901 Mtetra
.57421 .70901 .57733 .71201 .58335 .71035 .58023 .70734 Mtetra
.649 .764 .933 r
.58023 .70734 .58335 .71035 .58937 .70867 .58627 .70566 Mtetra
.647 .763 .934 r
.58627 .70566 .58937 .70867 .59541 .70702 .59231 .70399 Mtetra
.648 .763 .933 r
.59231 .70399 .59541 .70702 .60147 .70535 .59838 .70232 Mtetra
.648 .764 .933 r
.59838 .70232 .60147 .70535 .60753 .70368 .60445 .70064 Mtetra
.647 .763 .934 r
.60445 .70064 .60753 .70368 .61361 .70202 .61054 .69897 Mtetra
.61054 .69897 .61361 .70202 .6197 .70035 .61664 .6973 Mtetra
.647 .763 .933 r
.61664 .6973 .6197 .70035 .62581 .69867 .62276 .69562 Mtetra
.646 .763 .934 r
.62276 .69562 .62581 .69867 .63193 .69701 .62888 .69394 Mtetra
.62888 .69394 .63193 .69701 .63806 .69534 .63503 .69227 Mtetra
.647 .763 .934 r
.63503 .69227 .63806 .69534 .64421 .69366 .64118 .69059 Mtetra
.646 .763 .934 r
.64118 .69059 .64421 .69366 .65037 .69199 .64735 .68891 Mtetra
.645 .763 .934 r
.64735 .68891 .65037 .69199 .65654 .69033 .65353 .68724 Mtetra
.646 .763 .934 r
.65353 .68724 .65654 .69033 .66273 .68865 .65973 .68555 Mtetra
.65973 .68555 .66273 .68865 .66893 .68697 .66594 .68387 Mtetra
.645 .762 .934 r
.66594 .68387 .66893 .68697 .67515 .6853 .67217 .68219 Mtetra
.645 .763 .934 r
.67217 .68219 .67515 .6853 .68137 .68362 .6784 .68051 Mtetra
.6784 .68051 .68137 .68362 .68762 .68194 .68465 .67882 Mtetra
.644 .762 .935 r
.68465 .67882 .68762 .68194 .69387 .68027 .69092 .67714 Mtetra
.644 .762 .934 r
.69092 .67714 .69387 .68027 .70014 .67859 .6972 .67545 Mtetra
.645 .763 .934 r
.6972 .67545 .70014 .67859 .70643 .6769 .7035 .67376 Mtetra
.643 .762 .935 r
.7035 .67376 .70643 .6769 .71273 .67523 .7098 .67208 Mtetra
.644 .762 .935 r
.7098 .67208 .71273 .67523 .71904 .67355 .71613 .67039 Mtetra
.71613 .67039 .71904 .67355 .72537 .67186 .72246 .66869 Mtetra
.643 .762 .935 r
.72246 .66869 .72537 .67186 .73171 .67019 .72882 .66701 Mtetra
.72882 .66701 .73171 .67019 .73807 .66851 .73518 .66533 Mtetra
.73518 .66533 .73807 .66851 .74444 .66682 .74156 .66364 Mtetra
.74156 .66364 .74444 .66682 .75082 .66514 .74796 .66195 Mtetra
.642 .762 .935 r
.74796 .66195 .75082 .66514 .75722 .66345 .75437 .66025 Mtetra
.75437 .66025 .75722 .66345 .76364 .66177 .76079 .65856 Mtetra
.76079 .65856 .76364 .66177 .77007 .66008 .76723 .65687 Mtetra
.642 .761 .935 r
.76723 .65687 .77007 .66008 .77651 .65839 .77369 .65517 Mtetra
.77369 .65517 .77651 .65839 .78297 .6567 .78016 .65347 Mtetra
.641 .761 .935 r
.78016 .65347 .78297 .6567 .78944 .65501 .78664 .65178 Mtetra
.641 .761 .936 r
.78664 .65178 .78944 .65501 .79593 .65332 .79314 .65008 Mtetra
.79314 .65008 .79593 .65332 .80244 .65163 .79966 .64838 Mtetra
.79966 .64838 .80244 .65163 .80896 .64994 .80619 .64668 Mtetra
.64 .761 .936 r
.80619 .64668 .80896 .64994 .81549 .64825 .81273 .64498 Mtetra
.81273 .64498 .81549 .64825 .82204 .64656 .81929 .64328 Mtetra
.81929 .64328 .82204 .64656 .82861 .64486 .82587 .64158 Mtetra
.82587 .64158 .82861 .64486 .83519 .64317 .83246 .63988 Mtetra
.83246 .63988 .83519 .64317 .84179 .64147 .83907 .63818 Mtetra
.639 .761 .936 r
.83907 .63818 .84179 .64147 .8484 .63978 .84569 .63648 Mtetra
.639 .76 .936 r
.84569 .63648 .8484 .63978 .85503 .63808 .85233 .63477 Mtetra
.85233 .63477 .85503 .63808 .86167 .63639 .85898 .63307 Mtetra
.85898 .63307 .86167 .63639 .86833 .63469 .86565 .63137 Mtetra
.86565 .63137 .86833 .63469 .875 .63299 .87234 .62965 Mtetra
.639 .761 .936 r
.87234 .62965 .875 .63299 .88169 .63127 .87904 .62793 Mtetra
.64 .761 .936 r
.87904 .62793 .88169 .63127 .8884 .62954 .88576 .62619 Mtetra
.645 .763 .935 r
.88576 .62619 .8884 .62954 .89511 .62774 .89248 .62439 Mtetra
.648 .764 .934 r
.89248 .62439 .89511 .62774 .90183 .62588 .89921 .62252 Mtetra
.671 .773 .927 r
.89921 .62252 .90183 .62588 .90853 .62366 .90592 .62029 Mtetra
.696 .782 .918 r
.90592 .62029 .90853 .62366 .9152 .62102 .9126 .61764 Mtetra
.731 .794 .903 r
.9126 .61764 .9152 .62102 .9218 .6177 .91921 .61431 Mtetra
.811 .815 .854 r
.91921 .61431 .9218 .6177 .92817 .61241 .9256 .60901 Mtetra
.854 .821 .816 r
.9256 .60901 .92817 .61241 .93437 .6056 .93181 .60218 Mtetra
.917 .819 .734 r
.93181 .60218 .93437 .6056 .94011 .59508 .93757 .59164 Mtetra
.954 .805 .656 r
.93757 .59164 .94011 .59508 .94526 .57992 .94274 .57646 Mtetra
.967 .794 .616 r
.94274 .57646 .94526 .57992 .94999 .56169 .94749 .5582 Mtetra
.982 .769 .54 r
.94749 .5582 .94999 .56169 .9536 .53513 .95112 .53161 Mtetra
.985 .76 .516 r
.95112 .53161 .9536 .53513 .95667 .50507 .95421 .5015 Mtetra
.943 .627 .409 r
.35705 .64485 .36036 .64779 .36436 .67616 .36102 .67324 Mtetra
.942 .619 .394 r
.36102 .67324 .36436 .67616 .36856 .70214 .36521 .69924 Mtetra
.935 .58 .321 r
.36521 .69924 .36856 .70214 .3732 .72044 .36983 .71756 Mtetra
.925 .547 .264 r
.36983 .71756 .3732 .72044 .37803 .73557 .37465 .73271 Mtetra
.875 .434 .086 r
.37465 .73271 .37803 .73557 .38313 .74568 .37975 .74282 Mtetra
.617 .093 0 r
.37975 .74282 .38313 .74568 .38845 .75126 .38507 .74841 Mtetra
0 .23 .696 r
.38507 .74841 .38845 .75126 .39387 .75491 .39049 .75206 Mtetra
.344 .641 .964 r
.39049 .75206 .39387 .75491 .39942 .75582 .39604 .75297 Mtetra
.499 .712 .966 r
.39604 .75297 .39942 .75582 .40502 .75572 .40165 .75287 Mtetra
.574 .74 .955 r
.40165 .75287 .40502 .75572 .41066 .75499 .40729 .75213 Mtetra
.632 .758 .938 r
.40729 .75213 .41066 .75499 .41633 .75362 .41297 .75075 Mtetra
.64 .76 .935 r
.41297 .75075 .41633 .75362 .42201 .75215 .41866 .74928 Mtetra
.648 .762 .932 r
.41866 .74928 .42201 .75215 .42771 .75057 .42437 .74769 Mtetra
.653 .763 .931 r
.42437 .74769 .42771 .75057 .43343 .74893 .43009 .74605 Mtetra
.653 .763 .93 r
.43009 .74605 .43343 .74893 .43915 .74728 .43583 .74439 Mtetra
.43583 .74439 .43915 .74728 .44489 .74563 .44157 .74273 Mtetra
.654 .764 .93 r
.44157 .74273 .44489 .74563 .45064 .74397 .44733 .74106 Mtetra
.44733 .74106 .45064 .74397 .4564 .7423 .4531 .73939 Mtetra
.652 .763 .931 r
.4531 .73939 .4564 .7423 .46218 .74065 .45888 .73773 Mtetra
.653 .763 .931 r
.45888 .73773 .46218 .74065 .46796 .73898 .46468 .73606 Mtetra
.653 .764 .93 r
.46468 .73606 .46796 .73898 .47376 .73731 .47048 .73439 Mtetra
.652 .763 .931 r
.47048 .73439 .47376 .73731 .47957 .73566 .4763 .73273 Mtetra
.4763 .73273 .47957 .73566 .48539 .734 .48213 .73106 Mtetra
.48213 .73106 .48539 .734 .49123 .73233 .48797 .72938 Mtetra
.651 .763 .931 r
.48797 .72938 .49123 .73233 .49707 .73067 .49383 .72772 Mtetra
.49383 .72772 .49707 .73067 .50293 .72901 .49969 .72605 Mtetra
.652 .763 .931 r
.49969 .72605 .50293 .72901 .5088 .72734 .50557 .72437 Mtetra
.651 .763 .931 r
.50557 .72437 .5088 .72734 .51468 .72568 .51146 .72271 Mtetra
.65 .763 .932 r
.51146 .72271 .51468 .72568 .52058 .72402 .51737 .72104 Mtetra
.651 .763 .931 r
.51737 .72104 .52058 .72402 .52649 .72235 .52328 .71936 Mtetra
.65 .763 .932 r
.52328 .71936 .52649 .72235 .53241 .72068 .52921 .71769 Mtetra
.52921 .71769 .53241 .72068 .53834 .71902 .53515 .71602 Mtetra
.53515 .71602 .53834 .71902 .54429 .71735 .54111 .71435 Mtetra
.54111 .71435 .54429 .71735 .55025 .71568 .54707 .71267 Mtetra
.649 .762 .932 r
.54707 .71267 .55025 .71568 .55622 .71402 .55305 .711 Mtetra
.649 .763 .932 r
.55305 .711 .55622 .71402 .5622 .71235 .55905 .70932 Mtetra
.55905 .70932 .5622 .71235 .5682 .71067 .56505 .70764 Mtetra
.648 .762 .932 r
.56505 .70764 .5682 .71067 .57421 .70901 .57107 .70597 Mtetra
.649 .762 .932 r
.57107 .70597 .57421 .70901 .58023 .70734 .5771 .7043 Mtetra
.5771 .7043 .58023 .70734 .58627 .70566 .58314 .70261 Mtetra
.647 .762 .933 r
.58314 .70261 .58627 .70566 .59231 .70399 .5892 .70094 Mtetra
.648 .762 .932 r
.5892 .70094 .59231 .70399 .59838 .70232 .59527 .69926 Mtetra
.59527 .69926 .59838 .70232 .60445 .70064 .60136 .69757 Mtetra
.647 .762 .933 r
.60136 .69757 .60445 .70064 .61054 .69897 .60745 .6959 Mtetra
.60745 .6959 .61054 .69897 .61664 .6973 .61357 .69422 Mtetra
.648 .762 .933 r
.61357 .69422 .61664 .6973 .62276 .69562 .61969 .69253 Mtetra
.647 .762 .933 r
.61969 .69253 .62276 .69562 .62888 .69394 .62583 .69085 Mtetra
.646 .762 .933 r
.62583 .69085 .62888 .69394 .63503 .69227 .63198 .68917 Mtetra
.647 .762 .933 r
.63198 .68917 .63503 .69227 .64118 .69059 .63814 .68748 Mtetra
.646 .762 .933 r
.63814 .68748 .64118 .69059 .64735 .68891 .64432 .68579 Mtetra
.645 .761 .933 r
.64432 .68579 .64735 .68891 .65353 .68724 .65051 .68411 Mtetra
.646 .762 .933 r
.65051 .68411 .65353 .68724 .65973 .68555 .65672 .68242 Mtetra
.646 .761 .933 r
.65672 .68242 .65973 .68555 .66594 .68387 .66294 .68073 Mtetra
.645 .761 .933 r
.66294 .68073 .66594 .68387 .67217 .68219 .66917 .67905 Mtetra
.646 .761 .933 r
.66917 .67905 .67217 .68219 .6784 .68051 .67542 .67735 Mtetra
.645 .761 .933 r
.67542 .67735 .6784 .68051 .68465 .67882 .68168 .67566 Mtetra
.644 .761 .934 r
.68168 .67566 .68465 .67882 .69092 .67714 .68796 .67398 Mtetra
.645 .761 .933 r
.68796 .67398 .69092 .67714 .6972 .67545 .69425 .67228 Mtetra
.69425 .67228 .6972 .67545 .7035 .67376 .70055 .67058 Mtetra
.643 .761 .934 r
.70055 .67058 .7035 .67376 .7098 .67208 .70687 .66889 Mtetra
.644 .761 .934 r
.70687 .66889 .7098 .67208 .71613 .67039 .7132 .6672 Mtetra
.7132 .6672 .71613 .67039 .72246 .66869 .71955 .66549 Mtetra
.643 .76 .934 r
.71955 .66549 .72246 .66869 .72882 .66701 .72591 .66381 Mtetra
.72591 .66381 .72882 .66701 .73518 .66533 .73229 .66211 Mtetra
.643 .761 .934 r
.73229 .66211 .73518 .66533 .74156 .66364 .73868 .66042 Mtetra
.643 .76 .934 r
.73868 .66042 .74156 .66364 .74796 .66195 .74508 .65872 Mtetra
.74508 .65872 .74796 .66195 .75437 .66025 .7515 .65702 Mtetra
.642 .76 .934 r
.7515 .65702 .75437 .66025 .76079 .65856 .75794 .65532 Mtetra
.75794 .65532 .76079 .65856 .76723 .65687 .76439 .65362 Mtetra
.76439 .65362 .76723 .65687 .77369 .65517 .77085 .65191 Mtetra
.77085 .65191 .77369 .65517 .78016 .65347 .77733 .65021 Mtetra
.77733 .65021 .78016 .65347 .78664 .65178 .78382 .64851 Mtetra
.641 .76 .934 r
.78382 .64851 .78664 .65178 .79314 .65008 .79033 .6468 Mtetra
.641 .76 .935 r
.79033 .6468 .79314 .65008 .79966 .64838 .79686 .6451 Mtetra
.79686 .6451 .79966 .64838 .80619 .64668 .8034 .64339 Mtetra
.8034 .64339 .80619 .64668 .81273 .64498 .80996 .64168 Mtetra
.641 .759 .935 r
.80996 .64168 .81273 .64498 .81929 .64328 .81653 .63997 Mtetra
.64 .759 .935 r
.81653 .63997 .81929 .64328 .82587 .64158 .82311 .63827 Mtetra
.82311 .63827 .82587 .64158 .83246 .63988 .82972 .63656 Mtetra
.82972 .63656 .83246 .63988 .83907 .63818 .83633 .63485 Mtetra
.83633 .63485 .83907 .63818 .84569 .63648 .84297 .63314 Mtetra
.639 .759 .935 r
.84297 .63314 .84569 .63648 .85233 .63477 .84962 .63143 Mtetra
.84962 .63143 .85233 .63477 .85898 .63307 .85628 .62971 Mtetra
.85628 .62971 .85898 .63307 .86565 .63137 .86296 .628 Mtetra
.86296 .628 .86565 .63137 .87234 .62965 .86966 .62628 Mtetra
.86966 .62628 .87234 .62965 .87904 .62793 .87637 .62456 Mtetra
.641 .759 .935 r
.87637 .62456 .87904 .62793 .88576 .62619 .8831 .62281 Mtetra
.645 .761 .933 r
.8831 .62281 .88576 .62619 .89248 .62439 .88983 .62099 Mtetra
.648 .762 .932 r
.88983 .62099 .89248 .62439 .89921 .62252 .89658 .61912 Mtetra
.671 .771 .925 r
.89658 .61912 .89921 .62252 .90592 .62029 .9033 .61688 Mtetra
.696 .781 .917 r
.9033 .61688 .90592 .62029 .9126 .61764 .90999 .61422 Mtetra
.731 .793 .901 r
.90999 .61422 .9126 .61764 .91921 .61431 .91661 .61088 Mtetra
.81 .814 .853 r
.91661 .61088 .91921 .61431 .9256 .60901 .92302 .60557 Mtetra
.853 .82 .815 r
.92302 .60557 .9256 .60901 .93181 .60218 .92924 .59872 Mtetra
.916 .818 .734 r
.92924 .59872 .93181 .60218 .93757 .59164 .93502 .58817 Mtetra
.954 .804 .656 r
.93502 .58817 .93757 .59164 .94274 .57646 .9402 .57296 Mtetra
.967 .793 .616 r
.9402 .57296 .94274 .57646 .94749 .5582 .94497 .55468 Mtetra
.982 .768 .54 r
.94497 .55468 .94749 .5582 .95112 .53161 .94862 .52804 Mtetra
.985 .759 .516 r
.94862 .52804 .95112 .53161 .95421 .5015 .95174 .4979 Mtetra
.943 .627 .409 r
.35373 .64189 .35705 .64485 .36102 .67324 .35768 .67031 Mtetra
.942 .619 .394 r
.35768 .67031 .36102 .67324 .36521 .69924 .36184 .69633 Mtetra
.935 .58 .321 r
.36184 .69633 .36521 .69924 .36983 .71756 .36645 .71467 Mtetra
.925 .547 .263 r
.36645 .71467 .36983 .71756 .37465 .73271 .37126 .72983 Mtetra
.875 .434 .085 r
.37126 .72983 .37465 .73271 .37975 .74282 .37635 .73995 Mtetra
.617 .093 0 r
.37635 .73995 .37975 .74282 .38507 .74841 .38167 .74554 Mtetra
0 .23 .697 r
.38167 .74554 .38507 .74841 .39049 .75206 .3871 .74919 Mtetra
.344 .641 .964 r
.3871 .74919 .39049 .75206 .39604 .75297 .39265 .75009 Mtetra
.5 .712 .966 r
.39265 .75009 .39604 .75297 .40165 .75287 .39826 .74999 Mtetra
.574 .74 .954 r
.39826 .74999 .40165 .75287 .40729 .75213 .40392 .74925 Mtetra
.632 .757 .938 r
.40392 .74925 .40729 .75213 .41297 .75075 .4096 .74786 Mtetra
.64 .759 .935 r
.4096 .74786 .41297 .75075 .41866 .74928 .4153 .74639 Mtetra
.648 .762 .932 r
.4153 .74639 .41866 .74928 .42437 .74769 .42102 .7448 Mtetra
.653 .763 .93 r
.42102 .7448 .42437 .74769 .43009 .74605 .42675 .74315 Mtetra
.42675 .74315 .43009 .74605 .43583 .74439 .43249 .74149 Mtetra
.43249 .74149 .43583 .74439 .44157 .74273 .43824 .73982 Mtetra
.654 .763 .93 r
.43824 .73982 .44157 .74273 .44733 .74106 .44401 .73814 Mtetra
.44401 .73814 .44733 .74106 .4531 .73939 .44979 .73646 Mtetra
.652 .763 .93 r
.44979 .73646 .4531 .73939 .45888 .73773 .45557 .7348 Mtetra
.653 .763 .93 r
.45557 .7348 .45888 .73773 .46468 .73606 .46138 .73312 Mtetra
.46138 .73312 .46468 .73606 .47048 .73439 .46719 .73144 Mtetra
.652 .763 .931 r
.46719 .73144 .47048 .73439 .4763 .73273 .47302 .72978 Mtetra
.47302 .72978 .4763 .73273 .48213 .73106 .47885 .7281 Mtetra
.652 .763 .93 r
.47885 .7281 .48213 .73106 .48797 .72938 .4847 .72642 Mtetra
.651 .763 .931 r
.4847 .72642 .48797 .72938 .49383 .72772 .49057 .72475 Mtetra
.49057 .72475 .49383 .72772 .49969 .72605 .49644 .72308 Mtetra
.652 .763 .931 r
.49644 .72308 .49969 .72605 .50557 .72437 .50233 .72139 Mtetra
.651 .763 .931 r
.50233 .72139 .50557 .72437 .51146 .72271 .50823 .71972 Mtetra
.65 .762 .931 r
.50823 .71972 .51146 .72271 .51737 .72104 .51414 .71805 Mtetra
.651 .763 .931 r
.51414 .71805 .51737 .72104 .52328 .71936 .52006 .71636 Mtetra
.65 .762 .931 r
.52006 .71636 .52328 .71936 .52921 .71769 .526 .71468 Mtetra
.65 .762 .932 r
.526 .71468 .52921 .71769 .53515 .71602 .53195 .71301 Mtetra
.65 .762 .931 r
.53195 .71301 .53515 .71602 .54111 .71435 .53791 .71133 Mtetra
.53791 .71133 .54111 .71435 .54707 .71267 .54389 .70964 Mtetra
.649 .762 .932 r
.54389 .70964 .54707 .71267 .55305 .711 .54988 .70797 Mtetra
.54988 .70797 .55305 .711 .55905 .70932 .55588 .70628 Mtetra
.55588 .70628 .55905 .70932 .56505 .70764 .56189 .70459 Mtetra
.648 .762 .932 r
.56189 .70459 .56505 .70764 .57107 .70597 .56792 .70292 Mtetra
.649 .762 .932 r
.56792 .70292 .57107 .70597 .5771 .7043 .57396 .70124 Mtetra
.57396 .70124 .5771 .7043 .58314 .70261 .58001 .69954 Mtetra
.648 .762 .932 r
.58001 .69954 .58314 .70261 .5892 .70094 .58608 .69787 Mtetra
.58608 .69787 .5892 .70094 .59527 .69926 .59216 .69618 Mtetra
.59216 .69618 .59527 .69926 .60136 .69757 .59825 .69449 Mtetra
.647 .762 .932 r
.59825 .69449 .60136 .69757 .60745 .6959 .60436 .6928 Mtetra
.60436 .6928 .60745 .6959 .61357 .69422 .61048 .69112 Mtetra
.648 .762 .932 r
.61048 .69112 .61357 .69422 .61969 .69253 .61661 .68942 Mtetra
.647 .761 .933 r
.61661 .68942 .61969 .69253 .62583 .69085 .62276 .68773 Mtetra
.646 .761 .933 r
.62276 .68773 .62583 .69085 .63198 .68917 .62892 .68605 Mtetra
.647 .762 .932 r
.62892 .68605 .63198 .68917 .63814 .68748 .63509 .68435 Mtetra
.646 .761 .933 r
.63509 .68435 .63814 .68748 .64432 .68579 .64128 .68266 Mtetra
.64128 .68266 .64432 .68579 .65051 .68411 .64748 .68097 Mtetra
.64748 .68097 .65051 .68411 .65672 .68242 .65369 .67927 Mtetra
.65369 .67927 .65672 .68242 .66294 .68073 .65992 .67757 Mtetra
.645 .761 .933 r
.65992 .67757 .66294 .68073 .66917 .67905 .66617 .67589 Mtetra
.646 .761 .933 r
.66617 .67589 .66917 .67905 .67542 .67735 .67242 .67419 Mtetra
.67242 .67419 .67542 .67735 .68168 .67566 .67869 .67248 Mtetra
.644 .761 .933 r
.67869 .67248 .68168 .67566 .68796 .67398 .68498 .67079 Mtetra
.645 .761 .933 r
.68498 .67079 .68796 .67398 .69425 .67228 .69128 .66909 Mtetra
.69128 .66909 .69425 .67228 .70055 .67058 .69759 .66738 Mtetra
.644 .76 .934 r
.69759 .66738 .70055 .67058 .70687 .66889 .70392 .66569 Mtetra
.644 .76 .933 r
.70392 .66569 .70687 .66889 .7132 .6672 .71026 .66399 Mtetra
.645 .761 .933 r
.71026 .66399 .7132 .6672 .71955 .66549 .71662 .66228 Mtetra
.643 .76 .934 r
.71662 .66228 .71955 .66549 .72591 .66381 .72299 .66058 Mtetra
.72299 .66058 .72591 .66381 .73229 .66211 .72938 .65888 Mtetra
.72938 .65888 .73229 .66211 .73868 .66042 .73578 .65718 Mtetra
.73578 .65718 .73868 .66042 .74508 .65872 .74219 .65547 Mtetra
.74219 .65547 .74508 .65872 .7515 .65702 .74862 .65376 Mtetra
.74862 .65376 .7515 .65702 .75794 .65532 .75507 .65205 Mtetra
.642 .76 .934 r
.75507 .65205 .75794 .65532 .76439 .65362 .76153 .65035 Mtetra
.76153 .65035 .76439 .65362 .77085 .65191 .768 .64863 Mtetra
.768 .64863 .77085 .65191 .77733 .65021 .77449 .64693 Mtetra
.77449 .64693 .77733 .65021 .78382 .64851 .781 .64521 Mtetra
.642 .759 .934 r
.781 .64521 .78382 .64851 .79033 .6468 .78752 .6435 Mtetra
.641 .759 .934 r
.78752 .6435 .79033 .6468 .79686 .6451 .79405 .64179 Mtetra
.79405 .64179 .79686 .6451 .8034 .64339 .8006 .64007 Mtetra
.8006 .64007 .8034 .64339 .80996 .64168 .80717 .63836 Mtetra
.80717 .63836 .80996 .64168 .81653 .63997 .81375 .63664 Mtetra
.64 .759 .934 r
.81375 .63664 .81653 .63997 .82311 .63827 .82035 .63493 Mtetra
.64 .759 .935 r
.82035 .63493 .82311 .63827 .82972 .63656 .82696 .63321 Mtetra
.82696 .63321 .82972 .63656 .83633 .63485 .83359 .63149 Mtetra
.83359 .63149 .83633 .63485 .84297 .63314 .84023 .62978 Mtetra
.639 .759 .935 r
.84023 .62978 .84297 .63314 .84962 .63143 .84689 .62806 Mtetra
.84689 .62806 .84962 .63143 .85628 .62971 .85357 .62634 Mtetra
.639 .758 .935 r
.85357 .62634 .85628 .62971 .86296 .628 .86026 .62462 Mtetra
.86026 .62462 .86296 .628 .86966 .62628 .86697 .62289 Mtetra
.64 .759 .935 r
.86697 .62289 .86966 .62628 .87637 .62456 .87369 .62116 Mtetra
.641 .759 .934 r
.87369 .62116 .87637 .62456 .8831 .62281 .88043 .6194 Mtetra
.645 .761 .933 r
.88043 .6194 .8831 .62281 .88983 .62099 .88718 .61758 Mtetra
.648 .762 .932 r
.88718 .61758 .88983 .62099 .89658 .61912 .89393 .6157 Mtetra
.671 .771 .925 r
.89393 .6157 .89658 .61912 .9033 .61688 .90067 .61345 Mtetra
.696 .78 .916 r
.90067 .61345 .9033 .61688 .90999 .61422 .90736 .61078 Mtetra
.731 .792 .901 r
.90736 .61078 .90999 .61422 .91661 .61088 .914 .60743 Mtetra
.81 .813 .853 r
.914 .60743 .91661 .61088 .92302 .60557 .92042 .6021 Mtetra
.853 .819 .815 r
.92042 .6021 .92302 .60557 .92924 .59872 .92666 .59524 Mtetra
.916 .818 .734 r
.92666 .59524 .92924 .59872 .93502 .58817 .93245 .58467 Mtetra
.953 .804 .656 r
.93245 .58467 .93502 .58817 .9402 .57296 .93765 .56943 Mtetra
.966 .793 .616 r
.93765 .56943 .9402 .57296 .94497 .55468 .94244 .55113 Mtetra
.982 .768 .541 r
.94244 .55113 .94497 .55468 .94862 .52804 .94612 .52446 Mtetra
.985 .759 .516 r
.94612 .52446 .94862 .52804 .95174 .4979 .94926 .49428 Mtetra
.943 .627 .409 r
.35039 .63892 .35373 .64189 .35768 .67031 .35432 .66736 Mtetra
.942 .619 .394 r
.35432 .66736 .35768 .67031 .36184 .69633 .35846 .6934 Mtetra
.935 .58 .321 r
.35846 .6934 .36184 .69633 .36645 .71467 .36305 .71176 Mtetra
.925 .547 .263 r
.36305 .71176 .36645 .71467 .37126 .72983 .36786 .72693 Mtetra
.874 .434 .085 r
.36786 .72693 .37126 .72983 .37635 .73995 .37294 .73706 Mtetra
.616 .092 0 r
.37294 .73706 .37635 .73995 .38167 .74554 .37826 .74265 Mtetra
0 .231 .698 r
.37826 .74265 .38167 .74554 .3871 .74919 .38369 .7463 Mtetra
.345 .641 .964 r
.38369 .7463 .3871 .74919 .39265 .75009 .38925 .74721 Mtetra
.5 .712 .966 r
.38925 .74721 .39265 .75009 .39826 .74999 .39487 .7471 Mtetra
.574 .739 .954 r
.39487 .7471 .39826 .74999 .40392 .74925 .40052 .74635 Mtetra
.632 .757 .937 r
.40052 .74635 .40392 .74925 .4096 .74786 .40622 .74496 Mtetra
.64 .759 .935 r
.40622 .74496 .4096 .74786 .4153 .74639 .41193 .74348 Mtetra
.648 .761 .932 r
.41193 .74348 .4153 .74639 .42102 .7448 .41765 .74188 Mtetra
.653 .762 .93 r
.41765 .74188 .42102 .7448 .42675 .74315 .42339 .74023 Mtetra
.653 .763 .93 r
.42339 .74023 .42675 .74315 .43249 .74149 .42914 .73856 Mtetra
.42914 .73856 .43249 .74149 .43824 .73982 .4349 .73689 Mtetra
.654 .763 .93 r
.4349 .73689 .43824 .73982 .44401 .73814 .44067 .73521 Mtetra
.44067 .73521 .44401 .73814 .44979 .73646 .44646 .73352 Mtetra
.652 .762 .93 r
.44646 .73352 .44979 .73646 .45557 .7348 .45225 .73185 Mtetra
.653 .763 .93 r
.45225 .73185 .45557 .7348 .46138 .73312 .45806 .73017 Mtetra
.45806 .73017 .46138 .73312 .46719 .73144 .46388 .72848 Mtetra
.652 .762 .93 r
.46388 .72848 .46719 .73144 .47302 .72978 .46972 .72681 Mtetra
.46972 .72681 .47302 .72978 .47885 .7281 .47556 .72513 Mtetra
.653 .763 .93 r
.47556 .72513 .47885 .7281 .4847 .72642 .48142 .72344 Mtetra
.651 .762 .931 r
.48142 .72344 .4847 .72642 .49057 .72475 .48729 .72176 Mtetra
.48729 .72176 .49057 .72475 .49644 .72308 .49318 .72008 Mtetra
.652 .762 .93 r
.49318 .72008 .49644 .72308 .50233 .72139 .49907 .71839 Mtetra
.651 .762 .931 r
.49907 .71839 .50233 .72139 .50823 .71972 .50498 .71671 Mtetra
.65 .762 .931 r
.50498 .71671 .50823 .71972 .51414 .71805 .5109 .71503 Mtetra
.651 .762 .931 r
.5109 .71503 .51414 .71805 .52006 .71636 .51683 .71334 Mtetra
.65 .762 .931 r
.51683 .71334 .52006 .71636 .526 .71468 .52278 .71166 Mtetra
.52278 .71166 .526 .71468 .53195 .71301 .52874 .70998 Mtetra
.52874 .70998 .53195 .71301 .53791 .71133 .53471 .70829 Mtetra
.53471 .70829 .53791 .71133 .54389 .70964 .54069 .7066 Mtetra
.649 .762 .932 r
.54069 .7066 .54389 .70964 .54988 .70797 .54669 .70492 Mtetra
.65 .762 .931 r
.54669 .70492 .54988 .70797 .55588 .70628 .5527 .70322 Mtetra
.5527 .70322 .55588 .70628 .56189 .70459 .55872 .70153 Mtetra
.648 .761 .932 r
.55872 .70153 .56189 .70459 .56792 .70292 .56476 .69985 Mtetra
.649 .762 .932 r
.56476 .69985 .56792 .70292 .57396 .70124 .5708 .69816 Mtetra
.649 .762 .931 r
.5708 .69816 .57396 .70124 .58001 .69954 .57687 .69646 Mtetra
.648 .761 .932 r
.57687 .69646 .58001 .69954 .58608 .69787 .58294 .69477 Mtetra
.58294 .69477 .58608 .69787 .59216 .69618 .58903 .69308 Mtetra
.648 .762 .932 r
.58903 .69308 .59216 .69618 .59825 .69449 .59513 .69138 Mtetra
.647 .761 .932 r
.59513 .69138 .59825 .69449 .60436 .6928 .60125 .68969 Mtetra
.60125 .68969 .60436 .6928 .61048 .69112 .60738 .688 Mtetra
.648 .761 .932 r
.60738 .688 .61048 .69112 .61661 .68942 .61352 .6863 Mtetra
.647 .761 .932 r
.61352 .6863 .61661 .68942 .62276 .68773 .61967 .6846 Mtetra
.646 .761 .932 r
.61967 .6846 .62276 .68773 .62892 .68605 .62584 .68291 Mtetra
.647 .761 .932 r
.62584 .68291 .62892 .68605 .63509 .68435 .63203 .6812 Mtetra
.646 .761 .932 r
.63203 .6812 .63509 .68435 .64128 .68266 .63822 .67951 Mtetra
.646 .761 .933 r
.63822 .67951 .64128 .68266 .64748 .68097 .64443 .67781 Mtetra
.646 .761 .932 r
.64443 .67781 .64748 .68097 .65369 .67927 .65066 .67611 Mtetra
.646 .761 .933 r
.65066 .67611 .65369 .67927 .65992 .67757 .65689 .6744 Mtetra
.645 .76 .933 r
.65689 .6744 .65992 .67757 .66617 .67589 .66315 .67271 Mtetra
.646 .761 .933 r
.66315 .67271 .66617 .67589 .67242 .67419 .66941 .671 Mtetra
.66941 .671 .67242 .67419 .67869 .67248 .67569 .66929 Mtetra
.644 .76 .933 r
.67569 .66929 .67869 .67248 .68498 .67079 .68199 .66759 Mtetra
.645 .76 .933 r
.68199 .66759 .68498 .67079 .69128 .66909 .6883 .66588 Mtetra
.6883 .66588 .69128 .66909 .69759 .66738 .69462 .66416 Mtetra
.644 .76 .933 r
.69462 .66416 .69759 .66738 .70392 .66569 .70096 .66247 Mtetra
.70096 .66247 .70392 .66569 .71026 .66399 .70731 .66076 Mtetra
.645 .76 .933 r
.70731 .66076 .71026 .66399 .71662 .66228 .71368 .65904 Mtetra
.643 .76 .933 r
.71368 .65904 .71662 .66228 .72299 .66058 .72006 .65733 Mtetra
.72006 .65733 .72299 .66058 .72938 .65888 .72645 .65563 Mtetra
.72645 .65563 .72938 .65888 .73578 .65718 .73286 .65392 Mtetra
.73286 .65392 .73578 .65718 .74219 .65547 .73929 .6522 Mtetra
.643 .76 .934 r
.73929 .6522 .74219 .65547 .74862 .65376 .74573 .65049 Mtetra
.74573 .65049 .74862 .65376 .75507 .65205 .75218 .64877 Mtetra
.642 .759 .934 r
.75218 .64877 .75507 .65205 .76153 .65035 .75865 .64706 Mtetra
.75865 .64706 .76153 .65035 .768 .64863 .76514 .64534 Mtetra
.76514 .64534 .768 .64863 .77449 .64693 .77164 .64362 Mtetra
.77164 .64362 .77449 .64693 .781 .64521 .77815 .6419 Mtetra
.77815 .6419 .781 .64521 .78752 .6435 .78468 .64018 Mtetra
.641 .759 .934 r
.78468 .64018 .78752 .6435 .79405 .64179 .79123 .63846 Mtetra
.79123 .63846 .79405 .64179 .8006 .64007 .79779 .63674 Mtetra
.79779 .63674 .8006 .64007 .80717 .63836 .80437 .63502 Mtetra
.80437 .63502 .80717 .63836 .81375 .63664 .81096 .63329 Mtetra
.81096 .63329 .81375 .63664 .82035 .63493 .81757 .63157 Mtetra
.64 .758 .934 r
.81757 .63157 .82035 .63493 .82696 .63321 .82419 .62985 Mtetra
.82419 .62985 .82696 .63321 .83359 .63149 .83083 .62812 Mtetra
.83083 .62812 .83359 .63149 .84023 .62978 .83749 .62639 Mtetra
.83749 .62639 .84023 .62978 .84689 .62806 .84416 .62467 Mtetra
.639 .758 .934 r
.84416 .62467 .84689 .62806 .85357 .62634 .85084 .62294 Mtetra
.85084 .62294 .85357 .62634 .86026 .62462 .85755 .62121 Mtetra
.85755 .62121 .86026 .62462 .86697 .62289 .86427 .61948 Mtetra
.64 .758 .934 r
.86427 .61948 .86697 .62289 .87369 .62116 .871 .61773 Mtetra
.641 .759 .934 r
.871 .61773 .87369 .62116 .88043 .6194 .87775 .61597 Mtetra
.645 .76 .933 r
.87775 .61597 .88043 .6194 .88718 .61758 .88451 .61414 Mtetra
.648 .762 .932 r
.88451 .61414 .88718 .61758 .89393 .6157 .89127 .61225 Mtetra
.671 .771 .925 r
.89127 .61225 .89393 .6157 .90067 .61345 .89802 .60999 Mtetra
.696 .78 .916 r
.89802 .60999 .90067 .61345 .90736 .61078 .90473 .60731 Mtetra
.731 .792 .901 r
.90473 .60731 .90736 .61078 .914 .60743 .91138 .60396 Mtetra
.81 .813 .852 r
.91138 .60396 .914 .60743 .92042 .6021 .91781 .59862 Mtetra
.853 .819 .815 r
.91781 .59862 .92042 .6021 .92666 .59524 .92406 .59174 Mtetra
.916 .817 .734 r
.92406 .59174 .92666 .59524 .93245 .58467 .92987 .58115 Mtetra
.953 .803 .657 r
.92987 .58115 .93245 .58467 .93765 .56943 .93509 .56589 Mtetra
.966 .793 .616 r
.93509 .56589 .93765 .56943 .94244 .55113 .93989 .54756 Mtetra
.982 .768 .541 r
.93989 .54756 .94244 .55113 .94612 .52446 .9436 .52085 Mtetra
.985 .759 .516 r
.9436 .52085 .94612 .52446 .94926 .49428 .94676 .49064 Mtetra
.943 .627 .409 r
.34705 .63593 .35039 .63892 .35432 .66736 .35095 .66439 Mtetra
.942 .619 .394 r
.35095 .66439 .35432 .66736 .35846 .6934 .35507 .69046 Mtetra
.935 .58 .321 r
.35507 .69046 .35846 .6934 .36305 .71176 .35965 .70884 Mtetra
.925 .547 .263 r
.35965 .70884 .36305 .71176 .36786 .72693 .36444 .72402 Mtetra
.875 .434 .085 r
.36444 .72402 .36786 .72693 .37294 .73706 .36952 .73416 Mtetra
.616 .093 0 r
.36952 .73416 .37294 .73706 .37826 .74265 .37484 .73976 Mtetra
0 .231 .698 r
.37484 .73976 .37826 .74265 .38369 .7463 .38027 .74341 Mtetra
.345 .641 .964 r
.38027 .74341 .38369 .7463 .38925 .74721 .38583 .74431 Mtetra
.5 .712 .966 r
.38583 .74431 .38925 .74721 .39487 .7471 .39146 .7442 Mtetra
.574 .739 .954 r
.39146 .7442 .39487 .7471 .40052 .74635 .39712 .74344 Mtetra
.632 .757 .937 r
.39712 .74344 .40052 .74635 .40622 .74496 .40282 .74205 Mtetra
.64 .759 .935 r
.40282 .74205 .40622 .74496 .41193 .74348 .40854 .74056 Mtetra
.648 .761 .932 r
.40854 .74056 .41193 .74348 .41765 .74188 .41427 .73896 Mtetra
.653 .763 .93 r
.41427 .73896 .41765 .74188 .42339 .74023 .42001 .7373 Mtetra
.42001 .7373 .42339 .74023 .42914 .73856 .42577 .73562 Mtetra
.42577 .73562 .42914 .73856 .4349 .73689 .43154 .73395 Mtetra
.654 .763 .93 r
.43154 .73395 .4349 .73689 .44067 .73521 .43732 .73226 Mtetra
.43732 .73226 .44067 .73521 .44646 .73352 .44311 .73056 Mtetra
.652 .763 .93 r
.44311 .73056 .44646 .73352 .45225 .73185 .44892 .72889 Mtetra
.653 .763 .93 r
.44892 .72889 .45225 .73185 .45806 .73017 .45474 .7272 Mtetra
.45474 .7272 .45806 .73017 .46388 .72848 .46057 .72551 Mtetra
.652 .762 .93 r
.46057 .72551 .46388 .72848 .46972 .72681 .46641 .72383 Mtetra
.652 .763 .93 r
.46641 .72383 .46972 .72681 .47556 .72513 .47226 .72214 Mtetra
.653 .763 .93 r
.47226 .72214 .47556 .72513 .48142 .72344 .47813 .72044 Mtetra
.651 .762 .931 r
.47813 .72044 .48142 .72344 .48729 .72176 .48401 .71876 Mtetra
.48401 .71876 .48729 .72176 .49318 .72008 .4899 .71708 Mtetra
.652 .763 .93 r
.4899 .71708 .49318 .72008 .49907 .71839 .4958 .71538 Mtetra
.651 .762 .931 r
.4958 .71538 .49907 .71839 .50498 .71671 .50172 .71369 Mtetra
.65 .762 .931 r
.50172 .71369 .50498 .71671 .5109 .71503 .50765 .71201 Mtetra
.651 .762 .931 r
.50765 .71201 .5109 .71503 .51683 .71334 .51359 .71031 Mtetra
.65 .762 .931 r
.51359 .71031 .51683 .71334 .52278 .71166 .51954 .70862 Mtetra
.51954 .70862 .52278 .71166 .52874 .70998 .52551 .70693 Mtetra
.52551 .70693 .52874 .70998 .53471 .70829 .53149 .70524 Mtetra
.53149 .70524 .53471 .70829 .54069 .7066 .53748 .70354 Mtetra
.649 .762 .932 r
.53748 .70354 .54069 .7066 .54669 .70492 .54349 .70185 Mtetra
.649 .762 .931 r
.54349 .70185 .54669 .70492 .5527 .70322 .5495 .70016 Mtetra
.5495 .70016 .5527 .70322 .55872 .70153 .55554 .69845 Mtetra
.648 .762 .932 r
.55554 .69845 .55872 .70153 .56476 .69985 .56158 .69677 Mtetra
.649 .762 .932 r
.56158 .69677 .56476 .69985 .5708 .69816 .56764 .69507 Mtetra
.56764 .69507 .5708 .69816 .57687 .69646 .57371 .69336 Mtetra
.648 .761 .932 r
.57371 .69336 .57687 .69646 .58294 .69477 .57979 .69167 Mtetra
.57979 .69167 .58294 .69477 .58903 .69308 .58589 .68997 Mtetra
.648 .762 .932 r
.58589 .68997 .58903 .69308 .59513 .69138 .592 .68826 Mtetra
.647 .761 .932 r
.592 .68826 .59513 .69138 .60125 .68969 .59812 .68657 Mtetra
.59812 .68657 .60125 .68969 .60738 .688 .60426 .68487 Mtetra
.648 .761 .932 r
.60426 .68487 .60738 .688 .61352 .6863 .61041 .68316 Mtetra
.647 .761 .932 r
.61041 .68316 .61352 .6863 .61967 .6846 .61658 .68146 Mtetra
.646 .761 .933 r
.61658 .68146 .61967 .6846 .62584 .68291 .62276 .67976 Mtetra
.647 .761 .932 r
.62276 .67976 .62584 .68291 .63203 .6812 .62895 .67805 Mtetra
.646 .761 .933 r
.62895 .67805 .63203 .6812 .63822 .67951 .63515 .67634 Mtetra
.63515 .67634 .63822 .67951 .64443 .67781 .64137 .67464 Mtetra
.64137 .67464 .64443 .67781 .65066 .67611 .64761 .67293 Mtetra
.64761 .67293 .65066 .67611 .65689 .6744 .65385 .67121 Mtetra
.645 .761 .933 r
.65385 .67121 .65689 .6744 .66315 .67271 .66012 .66951 Mtetra
.646 .761 .933 r
.66012 .66951 .66315 .67271 .66941 .671 .66639 .6678 Mtetra
.66639 .6678 .66941 .671 .67569 .66929 .67268 .66608 Mtetra
.644 .76 .933 r
.67268 .66608 .67569 .66929 .68199 .66759 .67899 .66438 Mtetra
.645 .76 .933 r
.67899 .66438 .68199 .66759 .6883 .66588 .6853 .66266 Mtetra
.645 .761 .933 r
.6853 .66266 .6883 .66588 .69462 .66416 .69164 .66094 Mtetra
.644 .76 .933 r
.69164 .66094 .69462 .66416 .70096 .66247 .69799 .65923 Mtetra
.69799 .65923 .70096 .66247 .70731 .66076 .70435 .65752 Mtetra
.645 .76 .933 r
.70435 .65752 .70731 .66076 .71368 .65904 .71072 .65579 Mtetra
.643 .76 .934 r
.71072 .65579 .71368 .65904 .72006 .65733 .71711 .65408 Mtetra
.71711 .65408 .72006 .65733 .72645 .65563 .72352 .65236 Mtetra
.643 .76 .933 r
.72352 .65236 .72645 .65563 .73286 .65392 .72994 .65064 Mtetra
.643 .76 .934 r
.72994 .65064 .73286 .65392 .73929 .6522 .73638 .64892 Mtetra
.73638 .64892 .73929 .6522 .74573 .65049 .74283 .6472 Mtetra
.74283 .6472 .74573 .65049 .75218 .64877 .74929 .64548 Mtetra
.642 .76 .934 r
.74929 .64548 .75218 .64877 .75865 .64706 .75577 .64375 Mtetra
.642 .759 .934 r
.75577 .64375 .75865 .64706 .76514 .64534 .76227 .64203 Mtetra
.76227 .64203 .76514 .64534 .77164 .64362 .76878 .6403 Mtetra
.76878 .6403 .77164 .64362 .77815 .6419 .7753 .63858 Mtetra
.7753 .63858 .77815 .6419 .78468 .64018 .78184 .63685 Mtetra
.641 .759 .934 r
.78184 .63685 .78468 .64018 .79123 .63846 .7884 .63512 Mtetra
.7884 .63512 .79123 .63846 .79779 .63674 .79497 .63339 Mtetra
.79497 .63339 .79779 .63674 .80437 .63502 .80156 .63166 Mtetra
.80156 .63166 .80437 .63502 .81096 .63329 .80816 .62993 Mtetra
.80816 .62993 .81096 .63329 .81757 .63157 .81478 .6282 Mtetra
.64 .759 .934 r
.81478 .6282 .81757 .63157 .82419 .62985 .82141 .62647 Mtetra
.82141 .62647 .82419 .62985 .83083 .62812 .82806 .62473 Mtetra
.64 .758 .934 r
.82806 .62473 .83083 .62812 .83749 .62639 .83473 .623 Mtetra
.83473 .623 .83749 .62639 .84416 .62467 .84141 .62127 Mtetra
.639 .758 .934 r
.84141 .62127 .84416 .62467 .85084 .62294 .84811 .61953 Mtetra
.639 .758 .935 r
.84811 .61953 .85084 .62294 .85755 .62121 .85482 .61779 Mtetra
.639 .758 .934 r
.85482 .61779 .85755 .62121 .86427 .61948 .86155 .61605 Mtetra
.64 .758 .934 r
.86155 .61605 .86427 .61948 .871 .61773 .8683 .6143 Mtetra
.641 .759 .934 r
.8683 .6143 .871 .61773 .87775 .61597 .87506 .61253 Mtetra
.645 .76 .933 r
.87506 .61253 .87775 .61597 .88451 .61414 .88183 .61069 Mtetra
.648 .762 .932 r
.88183 .61069 .88451 .61414 .89127 .61225 .88861 .60879 Mtetra
.671 .771 .925 r
.88861 .60879 .89127 .61225 .89802 .60999 .89536 .60653 Mtetra
.696 .78 .916 r
.89536 .60653 .89802 .60999 .90473 .60731 .90208 .60383 Mtetra
.731 .792 .901 r
.90208 .60383 .90473 .60731 .91138 .60396 .90874 .60047 Mtetra
.81 .813 .852 r
.90874 .60047 .91138 .60396 .91781 .59862 .91519 .59512 Mtetra
.853 .819 .815 r
.91519 .59512 .91781 .59862 .92406 .59174 .92145 .58823 Mtetra
.916 .817 .734 r
.92145 .58823 .92406 .59174 .92987 .58115 .92728 .57761 Mtetra
.953 .803 .656 r
.92728 .57761 .92987 .58115 .93509 .56589 .93252 .56233 Mtetra
.966 .793 .616 r
.93252 .56233 .93509 .56589 .93989 .54756 .93734 .54397 Mtetra
.982 .768 .541 r
.93734 .54397 .93989 .54756 .9436 .52085 .94107 .51723 Mtetra
.985 .759 .516 r
.94107 .51723 .9436 .52085 .94676 .49064 .94426 .48698 Mtetra
.943 .627 .409 r
.34369 .63294 .34705 .63593 .35095 .66439 .34757 .66142 Mtetra
.942 .619 .394 r
.34757 .66142 .35095 .66439 .35507 .69046 .35166 .68751 Mtetra
.935 .58 .321 r
.35166 .68751 .35507 .69046 .35965 .70884 .35623 .7059 Mtetra
.925 .547 .263 r
.35623 .7059 .35965 .70884 .36444 .72402 .36101 .7211 Mtetra
.875 .434 .085 r
.36101 .7211 .36444 .72402 .36952 .73416 .36608 .73125 Mtetra
.617 .093 0 r
.36608 .73125 .36952 .73416 .37484 .73976 .3714 .73685 Mtetra
0 .23 .698 r
.3714 .73685 .37484 .73976 .38027 .74341 .37683 .7405 Mtetra
.344 .641 .964 r
.37683 .7405 .38027 .74341 .38583 .74431 .38241 .7414 Mtetra
.5 .712 .966 r
.38241 .7414 .38583 .74431 .39146 .7442 .38803 .74128 Mtetra
.574 .739 .954 r
.38803 .74128 .39146 .7442 .39712 .74344 .3937 .74052 Mtetra
.632 .757 .938 r
.3937 .74052 .39712 .74344 .40282 .74205 .39941 .73912 Mtetra
.64 .759 .935 r
.39941 .73912 .40282 .74205 .40854 .74056 .40513 .73763 Mtetra
.648 .761 .932 r
.40513 .73763 .40854 .74056 .41427 .73896 .41087 .73602 Mtetra
.653 .763 .93 r
.41087 .73602 .41427 .73896 .42001 .7373 .41663 .73435 Mtetra
.41663 .73435 .42001 .7373 .42577 .73562 .42239 .73268 Mtetra
.42239 .73268 .42577 .73562 .43154 .73395 .42817 .73099 Mtetra
.654 .763 .93 r
.42817 .73099 .43154 .73395 .43732 .73226 .43396 .7293 Mtetra
.43396 .7293 .43732 .73226 .44311 .73056 .43976 .7276 Mtetra
.652 .763 .93 r
.43976 .7276 .44311 .73056 .44892 .72889 .44557 .72592 Mtetra
.653 .763 .93 r
.44557 .72592 .44892 .72889 .45474 .7272 .4514 .72422 Mtetra
.4514 .72422 .45474 .7272 .46057 .72551 .45724 .72252 Mtetra
.652 .762 .93 r
.45724 .72252 .46057 .72551 .46641 .72383 .46309 .72084 Mtetra
.652 .763 .93 r
.46309 .72084 .46641 .72383 .47226 .72214 .46895 .71914 Mtetra
.46895 .71914 .47226 .72214 .47813 .72044 .47482 .71744 Mtetra
.651 .762 .931 r
.47482 .71744 .47813 .72044 .48401 .71876 .48071 .71575 Mtetra
.48071 .71575 .48401 .71876 .4899 .71708 .48661 .71406 Mtetra
.652 .763 .931 r
.48661 .71406 .4899 .71708 .4958 .71538 .49252 .71236 Mtetra
.651 .762 .931 r
.49252 .71236 .4958 .71538 .50172 .71369 .49844 .71066 Mtetra
.65 .762 .931 r
.49844 .71066 .50172 .71369 .50765 .71201 .50438 .70897 Mtetra
.651 .762 .931 r
.50438 .70897 .50765 .71201 .51359 .71031 .51033 .70727 Mtetra
.65 .762 .931 r
.51033 .70727 .51359 .71031 .51954 .70862 .51629 .70557 Mtetra
.51629 .70557 .51954 .70862 .52551 .70693 .52227 .70388 Mtetra
.52227 .70388 .52551 .70693 .53149 .70524 .52826 .70218 Mtetra
.52826 .70218 .53149 .70524 .53748 .70354 .53426 .70047 Mtetra
.649 .762 .932 r
.53426 .70047 .53748 .70354 .54349 .70185 .54027 .69878 Mtetra
.649 .762 .931 r
.54027 .69878 .54349 .70185 .5495 .70016 .5463 .69707 Mtetra
.5463 .69707 .5495 .70016 .55554 .69845 .55234 .69537 Mtetra
.648 .762 .932 r
.55234 .69537 .55554 .69845 .56158 .69677 .55839 .69367 Mtetra
.649 .762 .932 r
.55839 .69367 .56158 .69677 .56764 .69507 .56446 .69197 Mtetra
.56446 .69197 .56764 .69507 .57371 .69336 .57054 .69025 Mtetra
.648 .761 .932 r
.57054 .69025 .57371 .69336 .57979 .69167 .57663 .68856 Mtetra
.648 .762 .932 r
.57663 .68856 .57979 .69167 .58589 .68997 .58274 .68685 Mtetra
.58274 .68685 .58589 .68997 .592 .68826 .58886 .68514 Mtetra
.647 .761 .932 r
.58886 .68514 .592 .68826 .59812 .68657 .59499 .68343 Mtetra
.59499 .68343 .59812 .68657 .60426 .68487 .60114 .68173 Mtetra
.648 .762 .932 r
.60114 .68173 .60426 .68487 .61041 .68316 .6073 .68001 Mtetra
.647 .761 .932 r
.6073 .68001 .61041 .68316 .61658 .68146 .61347 .6783 Mtetra
.646 .761 .933 r
.61347 .6783 .61658 .68146 .62276 .67976 .61966 .6766 Mtetra
.647 .761 .932 r
.61966 .6766 .62276 .67976 .62895 .67805 .62586 .67488 Mtetra
.646 .761 .933 r
.62586 .67488 .62895 .67805 .63515 .67634 .63207 .67316 Mtetra
.63207 .67316 .63515 .67634 .64137 .67464 .6383 .67146 Mtetra
.6383 .67146 .64137 .67464 .64761 .67293 .64455 .66974 Mtetra
.64455 .66974 .64761 .67293 .65385 .67121 .6508 .66802 Mtetra
.645 .761 .933 r
.6508 .66802 .65385 .67121 .66012 .66951 .65707 .66631 Mtetra
.646 .761 .933 r
.65707 .66631 .66012 .66951 .66639 .6678 .66336 .66459 Mtetra
.66336 .66459 .66639 .6678 .67268 .66608 .66966 .66286 Mtetra
.644 .76 .933 r
.66966 .66286 .67268 .66608 .67899 .66438 .67597 .66115 Mtetra
.645 .761 .933 r
.67597 .66115 .67899 .66438 .6853 .66266 .6823 .65943 Mtetra
.6823 .65943 .6853 .66266 .69164 .66094 .68864 .6577 Mtetra
.644 .76 .933 r
.68864 .6577 .69164 .66094 .69799 .65923 .695 .65598 Mtetra
.695 .65598 .69799 .65923 .70435 .65752 .70137 .65426 Mtetra
.645 .76 .933 r
.70137 .65426 .70435 .65752 .71072 .65579 .70776 .65253 Mtetra
.643 .76 .934 r
.70776 .65253 .71072 .65579 .71711 .65408 .71416 .65081 Mtetra
.71416 .65081 .71711 .65408 .72352 .65236 .72057 .64909 Mtetra
.72057 .64909 .72352 .65236 .72994 .65064 .727 .64736 Mtetra
.727 .64736 .72994 .65064 .73638 .64892 .73345 .64563 Mtetra
.73345 .64563 .73638 .64892 .74283 .6472 .73991 .6439 Mtetra
.73991 .6439 .74283 .6472 .74929 .64548 .74638 .64217 Mtetra
.642 .76 .934 r
.74638 .64217 .74929 .64548 .75577 .64375 .75287 .64044 Mtetra
.75287 .64044 .75577 .64375 .76227 .64203 .75938 .63871 Mtetra
.642 .759 .934 r
.75938 .63871 .76227 .64203 .76878 .6403 .7659 .63697 Mtetra
.7659 .63697 .76878 .6403 .7753 .63858 .77244 .63524 Mtetra
.77244 .63524 .7753 .63858 .78184 .63685 .77899 .6335 Mtetra
.641 .759 .934 r
.77899 .6335 .78184 .63685 .7884 .63512 .78555 .63177 Mtetra
.78555 .63177 .7884 .63512 .79497 .63339 .79214 .63003 Mtetra
.79214 .63003 .79497 .63339 .80156 .63166 .79873 .62829 Mtetra
.79873 .62829 .80156 .63166 .80816 .62993 .80535 .62656 Mtetra
.80535 .62656 .80816 .62993 .81478 .6282 .81198 .62482 Mtetra
.64 .759 .934 r
.81198 .62482 .81478 .6282 .82141 .62647 .81862 .62308 Mtetra
.81862 .62308 .82141 .62647 .82806 .62473 .82528 .62133 Mtetra
.64 .758 .934 r
.82528 .62133 .82806 .62473 .83473 .623 .83196 .61959 Mtetra
.83196 .61959 .83473 .623 .84141 .62127 .83865 .61785 Mtetra
.639 .758 .934 r
.83865 .61785 .84141 .62127 .84811 .61953 .84536 .61611 Mtetra
.639 .758 .935 r
.84536 .61611 .84811 .61953 .85482 .61779 .85209 .61436 Mtetra
.639 .758 .934 r
.85209 .61436 .85482 .61779 .86155 .61605 .85883 .61261 Mtetra
.64 .758 .934 r
.85883 .61261 .86155 .61605 .8683 .6143 .86558 .61085 Mtetra
.641 .759 .934 r
.86558 .61085 .8683 .6143 .87506 .61253 .87235 .60907 Mtetra
.645 .76 .933 r
.87235 .60907 .87506 .61253 .88183 .61069 .87913 .60722 Mtetra
.648 .762 .932 r
.87913 .60722 .88183 .61069 .88861 .60879 .88592 .60532 Mtetra
.671 .771 .925 r
.88592 .60532 .88861 .60879 .89536 .60653 .89269 .60304 Mtetra
.696 .78 .916 r
.89269 .60304 .89536 .60653 .90208 .60383 .89943 .60034 Mtetra
.731 .792 .901 r
.89943 .60034 .90208 .60383 .90874 .60047 .9061 .59697 Mtetra
.81 .813 .852 r
.9061 .59697 .90874 .60047 .91519 .59512 .91256 .5916 Mtetra
.853 .819 .815 r
.91256 .5916 .91519 .59512 .92145 .58823 .91884 .5847 Mtetra
.916 .817 .734 r
.91884 .5847 .92145 .58823 .92728 .57761 .92467 .57407 Mtetra
.953 .803 .656 r
.92467 .57407 .92728 .57761 .93252 .56233 .92993 .55876 Mtetra
.966 .793 .616 r
.92993 .55876 .93252 .56233 .93734 .54397 .93478 .54037 Mtetra
.982 .768 .541 r
.93478 .54037 .93734 .54397 .94107 .51723 .93853 .5136 Mtetra
.985 .759 .516 r
.93853 .5136 .94107 .51723 .94426 .48698 .94175 .48331 Mtetra
.943 .627 .409 r
.34032 .62993 .34369 .63294 .34757 .66142 .34417 .65844 Mtetra
.942 .619 .394 r
.34417 .65844 .34757 .66142 .35166 .68751 .34824 .68456 Mtetra
.935 .58 .321 r
.34824 .68456 .35166 .68751 .35623 .7059 .35279 .70296 Mtetra
.925 .547 .263 r
.35279 .70296 .35623 .7059 .36101 .7211 .35757 .71817 Mtetra
.875 .434 .085 r
.35757 .71817 .36101 .7211 .36608 .73125 .36263 .72833 Mtetra
.617 .093 0 r
.36263 .72833 .36608 .73125 .3714 .73685 .36795 .73393 Mtetra
0 .23 .697 r
.36795 .73393 .3714 .73685 .37683 .7405 .37339 .73758 Mtetra
.344 .641 .964 r
.37339 .73758 .37683 .7405 .38241 .7414 .37896 .73848 Mtetra
.499 .712 .966 r
.37896 .73848 .38241 .7414 .38803 .74128 .3846 .73836 Mtetra
.574 .739 .954 r
.3846 .73836 .38803 .74128 .3937 .74052 .39027 .7376 Mtetra
.632 .757 .938 r
.39027 .7376 .3937 .74052 .39941 .73912 .39599 .73619 Mtetra
.64 .759 .935 r
.39599 .73619 .39941 .73912 .40513 .73763 .40172 .73469 Mtetra
.648 .762 .932 r
.40172 .73469 .40513 .73763 .41087 .73602 .40747 .73308 Mtetra
.653 .763 .93 r
.40747 .73308 .41087 .73602 .41663 .73435 .41323 .7314 Mtetra
.41323 .7314 .41663 .73435 .42239 .73268 .419 .72972 Mtetra
.419 .72972 .42239 .73268 .42817 .73099 .42478 .72803 Mtetra
.654 .763 .93 r
.42478 .72803 .42817 .73099 .43396 .7293 .43058 .72633 Mtetra
.43058 .72633 .43396 .7293 .43976 .7276 .43639 .72462 Mtetra
.652 .763 .93 r
.43639 .72462 .43976 .7276 .44557 .72592 .44221 .72293 Mtetra
.653 .763 .93 r
.44221 .72293 .44557 .72592 .4514 .72422 .44805 .72123 Mtetra
.44805 .72123 .4514 .72422 .45724 .72252 .45389 .71953 Mtetra
.652 .763 .931 r
.45389 .71953 .45724 .72252 .46309 .72084 .45975 .71783 Mtetra
.652 .763 .93 r
.45975 .71783 .46309 .72084 .46895 .71914 .46562 .71614 Mtetra
.46562 .71614 .46895 .71914 .47482 .71744 .4715 .71443 Mtetra
.651 .762 .931 r
.4715 .71443 .47482 .71744 .48071 .71575 .4774 .71273 Mtetra
.4774 .71273 .48071 .71575 .48661 .71406 .4833 .71103 Mtetra
.652 .763 .931 r
.4833 .71103 .48661 .71406 .49252 .71236 .48922 .70932 Mtetra
.651 .762 .931 r
.48922 .70932 .49252 .71236 .49844 .71066 .49516 .70762 Mtetra
.65 .762 .931 r
.49516 .70762 .49844 .71066 .50438 .70897 .5011 .70593 Mtetra
.651 .762 .931 r
.5011 .70593 .50438 .70897 .51033 .70727 .50706 .70422 Mtetra
.65 .762 .931 r
.50706 .70422 .51033 .70727 .51629 .70557 .51303 .70251 Mtetra
.51303 .70251 .51629 .70557 .52227 .70388 .51902 .70081 Mtetra
.51902 .70081 .52227 .70388 .52826 .70218 .52501 .6991 Mtetra
.52501 .6991 .52826 .70218 .53426 .70047 .53102 .69739 Mtetra
.649 .762 .932 r
.53102 .69739 .53426 .70047 .54027 .69878 .53704 .69569 Mtetra
.649 .762 .931 r
.53704 .69569 .54027 .69878 .5463 .69707 .54308 .69398 Mtetra
.54308 .69398 .5463 .69707 .55234 .69537 .54913 .69227 Mtetra
.648 .762 .932 r
.54913 .69227 .55234 .69537 .55839 .69367 .55519 .69057 Mtetra
.649 .762 .932 r
.55519 .69057 .55839 .69367 .56446 .69197 .56126 .68885 Mtetra
.56126 .68885 .56446 .69197 .57054 .69025 .56735 .68713 Mtetra
.648 .761 .932 r
.56735 .68713 .57054 .69025 .57663 .68856 .57345 .68543 Mtetra
.648 .762 .932 r
.57345 .68543 .57663 .68856 .58274 .68685 .57957 .68372 Mtetra
.57957 .68372 .58274 .68685 .58886 .68514 .5857 .682 Mtetra
.647 .761 .932 r
.5857 .682 .58886 .68514 .59499 .68343 .59184 .68029 Mtetra
.59184 .68029 .59499 .68343 .60114 .68173 .598 .67857 Mtetra
.648 .762 .932 r
.598 .67857 .60114 .68173 .6073 .68001 .60417 .67685 Mtetra
.647 .761 .932 r
.60417 .67685 .6073 .68001 .61347 .6783 .61035 .67514 Mtetra
.646 .761 .933 r
.61035 .67514 .61347 .6783 .61966 .6766 .61655 .67342 Mtetra
.647 .761 .932 r
.61655 .67342 .61966 .6766 .62586 .67488 .62276 .6717 Mtetra
.646 .761 .933 r
.62276 .6717 .62586 .67488 .63207 .67316 .62898 .66998 Mtetra
.62898 .66998 .63207 .67316 .6383 .67146 .63522 .66826 Mtetra
.63522 .66826 .6383 .67146 .64455 .66974 .64147 .66653 Mtetra
.64147 .66653 .64455 .66974 .6508 .66802 .64774 .66481 Mtetra
.645 .761 .933 r
.64774 .66481 .6508 .66802 .65707 .66631 .65402 .66309 Mtetra
.646 .761 .933 r
.65402 .66309 .65707 .66631 .66336 .66459 .66031 .66136 Mtetra
.66031 .66136 .66336 .66459 .66966 .66286 .66662 .65963 Mtetra
.644 .76 .933 r
.66662 .65963 .66966 .66286 .67597 .66115 .67295 .65791 Mtetra
.645 .761 .933 r
.67295 .65791 .67597 .66115 .6823 .65943 .67928 .65618 Mtetra
.67928 .65618 .6823 .65943 .68864 .6577 .68563 .65444 Mtetra
.644 .76 .933 r
.68563 .65444 .68864 .6577 .695 .65598 .692 .65272 Mtetra
.692 .65272 .695 .65598 .70137 .65426 .69838 .65099 Mtetra
.645 .76 .933 r
.69838 .65099 .70137 .65426 .70776 .65253 .70478 .64925 Mtetra
.643 .76 .934 r
.70478 .64925 .70776 .65253 .71416 .65081 .71119 .64752 Mtetra
.71119 .64752 .71416 .65081 .72057 .64909 .71762 .6458 Mtetra
.71762 .6458 .72057 .64909 .727 .64736 .72406 .64406 Mtetra
.72406 .64406 .727 .64736 .73345 .64563 .73051 .64233 Mtetra
.73051 .64233 .73345 .64563 .73991 .6439 .73698 .64059 Mtetra
.73698 .64059 .73991 .6439 .74638 .64217 .74347 .63885 Mtetra
.642 .76 .934 r
.74347 .63885 .74638 .64217 .75287 .64044 .74997 .63711 Mtetra
.74997 .63711 .75287 .64044 .75938 .63871 .75648 .63537 Mtetra
.642 .759 .934 r
.75648 .63537 .75938 .63871 .7659 .63697 .76301 .63363 Mtetra
.76301 .63363 .7659 .63697 .77244 .63524 .76956 .63189 Mtetra
.76956 .63189 .77244 .63524 .77899 .6335 .77612 .63014 Mtetra
.641 .759 .934 r
.77612 .63014 .77899 .6335 .78555 .63177 .7827 .6284 Mtetra
.7827 .6284 .78555 .63177 .79214 .63003 .78929 .62666 Mtetra
.78929 .62666 .79214 .63003 .79873 .62829 .7959 .62491 Mtetra
.7959 .62491 .79873 .62829 .80535 .62656 .80252 .62317 Mtetra
.80252 .62317 .80535 .62656 .81198 .62482 .80916 .62142 Mtetra
.64 .759 .934 r
.80916 .62142 .81198 .62482 .81862 .62308 .81582 .61967 Mtetra
.81582 .61967 .81862 .62308 .82528 .62133 .82249 .61792 Mtetra
.82249 .61792 .82528 .62133 .83196 .61959 .82918 .61617 Mtetra
.64 .758 .934 r
.82918 .61617 .83196 .61959 .83865 .61785 .83588 .61442 Mtetra
.639 .758 .935 r
.83588 .61442 .83865 .61785 .84536 .61611 .8426 .61267 Mtetra
.8426 .61267 .84536 .61611 .85209 .61436 .84934 .61092 Mtetra
.84934 .61092 .85209 .61436 .85883 .61261 .85609 .60916 Mtetra
.64 .758 .934 r
.85609 .60916 .85883 .61261 .86558 .61085 .86286 .60739 Mtetra
.641 .759 .934 r
.86286 .60739 .86558 .61085 .87235 .60907 .86964 .6056 Mtetra
.645 .761 .933 r
.86964 .6056 .87235 .60907 .87913 .60722 .87643 .60375 Mtetra
.648 .762 .932 r
.87643 .60375 .87913 .60722 .88592 .60532 .88323 .60183 Mtetra
.671 .771 .925 r
.88323 .60183 .88592 .60532 .89269 .60304 .89001 .59955 Mtetra
.696 .78 .916 r
.89001 .59955 .89269 .60304 .89943 .60034 .89676 .59684 Mtetra
.731 .792 .901 r
.89676 .59684 .89943 .60034 .9061 .59697 .90344 .59345 Mtetra
.81 .813 .853 r
.90344 .59345 .9061 .59697 .91256 .5916 .90991 .58807 Mtetra
.853 .819 .815 r
.90991 .58807 .91256 .5916 .91884 .5847 .91621 .58115 Mtetra
.916 .818 .734 r
.91621 .58115 .91884 .5847 .92467 .57407 .92206 .5705 Mtetra
.953 .803 .656 r
.92206 .5705 .92467 .57407 .92993 .55876 .92734 .55517 Mtetra
.966 .793 .616 r
.92734 .55517 .92993 .55876 .93478 .54037 .9322 .53676 Mtetra
.982 .768 .541 r
.9322 .53676 .93478 .54037 .93853 .5136 .93598 .50995 Mtetra
.985 .759 .516 r
.93598 .50995 .93853 .5136 .94175 .48331 .93922 .47962 Mtetra
.943 .627 .409 r
.33694 .62691 .34032 .62993 .34417 .65844 .34076 .65545 Mtetra
.942 .619 .394 r
.34076 .65545 .34417 .65844 .34824 .68456 .34481 .68159 Mtetra
.935 .58 .321 r
.34481 .68159 .34824 .68456 .35279 .70296 .34935 .70001 Mtetra
.925 .547 .263 r
.34935 .70001 .35279 .70296 .35757 .71817 .35411 .71523 Mtetra
.875 .434 .085 r
.35411 .71523 .35757 .71817 .36263 .72833 .35917 .7254 Mtetra
.617 .093 0 r
.35917 .7254 .36263 .72833 .36795 .73393 .36449 .731 Mtetra
0 .23 .697 r
.36449 .731 .36795 .73393 .37339 .73758 .36993 .73465 Mtetra
.344 .641 .964 r
.36993 .73465 .37339 .73758 .37896 .73848 .37551 .73555 Mtetra
.499 .712 .966 r
.37551 .73555 .37896 .73848 .3846 .73836 .38115 .73543 Mtetra
.574 .739 .954 r
.38115 .73543 .3846 .73836 .39027 .7376 .38683 .73466 Mtetra
.632 .757 .938 r
.38683 .73466 .39027 .7376 .39599 .73619 .39255 .73325 Mtetra
.64 .759 .935 r
.39255 .73325 .39599 .73619 .40172 .73469 .39829 .73174 Mtetra
.648 .762 .932 r
.39829 .73174 .40172 .73469 .40747 .73308 .40404 .73012 Mtetra
.653 .763 .93 r
.40404 .73012 .40747 .73308 .41323 .7314 .40981 .72844 Mtetra
.40981 .72844 .41323 .7314 .419 .72972 .41559 .72675 Mtetra
.41559 .72675 .419 .72972 .42478 .72803 .42139 .72505 Mtetra
.654 .763 .93 r
.42139 .72505 .42478 .72803 .43058 .72633 .42719 .72335 Mtetra
.42719 .72335 .43058 .72633 .43639 .72462 .43301 .72164 Mtetra
.652 .763 .93 r
.43301 .72164 .43639 .72462 .44221 .72293 .43884 .71994 Mtetra
.653 .763 .93 r
.43884 .71994 .44221 .72293 .44805 .72123 .44468 .71823 Mtetra
.44468 .71823 .44805 .72123 .45389 .71953 .45053 .71652 Mtetra
.652 .763 .931 r
.45053 .71652 .45389 .71953 .45975 .71783 .4564 .71482 Mtetra
.652 .763 .93 r
.4564 .71482 .45975 .71783 .46562 .71614 .46228 .71312 Mtetra
.46228 .71312 .46562 .71614 .4715 .71443 .46817 .7114 Mtetra
.651 .762 .931 r
.46817 .7114 .4715 .71443 .4774 .71273 .47407 .7097 Mtetra
.47407 .7097 .4774 .71273 .4833 .71103 .47999 .708 Mtetra
.652 .763 .931 r
.47999 .708 .4833 .71103 .48922 .70932 .48592 .70628 Mtetra
.651 .762 .931 r
.48592 .70628 .48922 .70932 .49516 .70762 .49186 .70457 Mtetra
.65 .762 .931 r
.49186 .70457 .49516 .70762 .5011 .70593 .49781 .70287 Mtetra
.651 .762 .931 r
.49781 .70287 .5011 .70593 .50706 .70422 .50378 .70115 Mtetra
.65 .762 .931 r
.50378 .70115 .50706 .70422 .51303 .70251 .50976 .69944 Mtetra
.50976 .69944 .51303 .70251 .51902 .70081 .51575 .69774 Mtetra
.51575 .69774 .51902 .70081 .52501 .6991 .52175 .69602 Mtetra
.52175 .69602 .52501 .6991 .53102 .69739 .52777 .6943 Mtetra
.649 .762 .932 r
.52777 .6943 .53102 .69739 .53704 .69569 .5338 .6926 Mtetra
.5338 .6926 .53704 .69569 .54308 .69398 .53985 .69088 Mtetra
.53985 .69088 .54308 .69398 .54913 .69227 .5459 .68916 Mtetra
.648 .762 .932 r
.5459 .68916 .54913 .69227 .55519 .69057 .55198 .68745 Mtetra
.649 .762 .932 r
.55198 .68745 .55519 .69057 .56126 .68885 .55806 .68573 Mtetra
.55806 .68573 .56126 .68885 .56735 .68713 .56416 .684 Mtetra
.648 .762 .932 r
.56416 .684 .56735 .68713 .57345 .68543 .57027 .68229 Mtetra
.57027 .68229 .57345 .68543 .57957 .68372 .57639 .68057 Mtetra
.57639 .68057 .57957 .68372 .5857 .682 .58253 .67884 Mtetra
.647 .761 .932 r
.58253 .67884 .5857 .682 .59184 .68029 .58868 .67713 Mtetra
.58868 .67713 .59184 .68029 .598 .67857 .59484 .67541 Mtetra
.648 .762 .932 r
.59484 .67541 .598 .67857 .60417 .67685 .60102 .67368 Mtetra
.647 .761 .932 r
.60102 .67368 .60417 .67685 .61035 .67514 .60721 .67196 Mtetra
.646 .761 .933 r
.60721 .67196 .61035 .67514 .61655 .67342 .61342 .67024 Mtetra
.647 .761 .932 r
.61342 .67024 .61655 .67342 .62276 .6717 .61964 .6685 Mtetra
.646 .761 .933 r
.61964 .6685 .62276 .6717 .62898 .66998 .62587 .66677 Mtetra
.62587 .66677 .62898 .66998 .63522 .66826 .63212 .66505 Mtetra
.63212 .66505 .63522 .66826 .64147 .66653 .63838 .66332 Mtetra
.63838 .66332 .64147 .66653 .64774 .66481 .64466 .66158 Mtetra
.645 .761 .933 r
.64466 .66158 .64774 .66481 .65402 .66309 .65095 .65986 Mtetra
.646 .761 .933 r
.65095 .65986 .65402 .66309 .66031 .66136 .65725 .65812 Mtetra
.65725 .65812 .66031 .66136 .66662 .65963 .66357 .65638 Mtetra
.644 .76 .933 r
.66357 .65638 .66662 .65963 .67295 .65791 .66991 .65466 Mtetra
.645 .761 .933 r
.66991 .65466 .67295 .65791 .67928 .65618 .67625 .65292 Mtetra
.67625 .65292 .67928 .65618 .68563 .65444 .68261 .65118 Mtetra
.644 .76 .934 r
.68261 .65118 .68563 .65444 .692 .65272 .68899 .64945 Mtetra
.644 .76 .933 r
.68899 .64945 .692 .65272 .69838 .65099 .69538 .64771 Mtetra
.645 .761 .933 r
.69538 .64771 .69838 .65099 .70478 .64925 .70179 .64596 Mtetra
.643 .76 .934 r
.70179 .64596 .70478 .64925 .71119 .64752 .70821 .64423 Mtetra
.70821 .64423 .71119 .64752 .71762 .6458 .71464 .64249 Mtetra
.71464 .64249 .71762 .6458 .72406 .64406 .7211 .64075 Mtetra
.7211 .64075 .72406 .64406 .73051 .64233 .72756 .63901 Mtetra
.72756 .63901 .73051 .64233 .73698 .64059 .73404 .63726 Mtetra
.73404 .63726 .73698 .64059 .74347 .63885 .74054 .63552 Mtetra
.642 .76 .934 r
.74054 .63552 .74347 .63885 .74997 .63711 .74705 .63377 Mtetra
.74705 .63377 .74997 .63711 .75648 .63537 .75357 .63202 Mtetra
.75357 .63202 .75648 .63537 .76301 .63363 .76011 .63027 Mtetra
.642 .759 .934 r
.76011 .63027 .76301 .63363 .76956 .63189 .76667 .62852 Mtetra
.76667 .62852 .76956 .63189 .77612 .63014 .77324 .62677 Mtetra
.641 .759 .934 r
.77324 .62677 .77612 .63014 .7827 .6284 .77983 .62502 Mtetra
.77983 .62502 .7827 .6284 .78929 .62666 .78643 .62327 Mtetra
.78643 .62327 .78929 .62666 .7959 .62491 .79305 .62152 Mtetra
.79305 .62152 .7959 .62491 .80252 .62317 .79969 .61976 Mtetra
.79969 .61976 .80252 .62317 .80916 .62142 .80634 .61801 Mtetra
.64 .759 .934 r
.80634 .61801 .80916 .62142 .81582 .61967 .813 .61625 Mtetra
.813 .61625 .81582 .61967 .82249 .61792 .81969 .61449 Mtetra
.81969 .61449 .82249 .61792 .82918 .61617 .82639 .61274 Mtetra
.64 .758 .935 r
.82639 .61274 .82918 .61617 .83588 .61442 .8331 .61098 Mtetra
.639 .758 .935 r
.8331 .61098 .83588 .61442 .8426 .61267 .83983 .60922 Mtetra
.83983 .60922 .8426 .61267 .84934 .61092 .84658 .60746 Mtetra
.84658 .60746 .84934 .61092 .85609 .60916 .85334 .60569 Mtetra
.64 .758 .934 r
.85334 .60569 .85609 .60916 .86286 .60739 .86012 .60392 Mtetra
.641 .759 .934 r
.86012 .60392 .86286 .60739 .86964 .6056 .86691 .60212 Mtetra
.645 .761 .933 r
.86691 .60212 .86964 .6056 .87643 .60375 .87372 .60025 Mtetra
.649 .762 .932 r
.87372 .60025 .87643 .60375 .88323 .60183 .88053 .59833 Mtetra
.671 .771 .925 r
.88053 .59833 .88323 .60183 .89001 .59955 .88732 .59604 Mtetra
.696 .78 .916 r
.88732 .59604 .89001 .59955 .89676 .59684 .89408 .59332 Mtetra
.731 .792 .901 r
.89408 .59332 .89676 .59684 .90344 .59345 .90077 .58992 Mtetra
.81 .813 .853 r
.90077 .58992 .90344 .59345 .90991 .58807 .90726 .58453 Mtetra
.853 .819 .815 r
.90726 .58453 .90991 .58807 .91621 .58115 .91357 .5776 Mtetra
.916 .818 .734 r
.91357 .5776 .91621 .58115 .92206 .5705 .91944 .56693 Mtetra
.953 .803 .656 r
.91944 .56693 .92206 .5705 .92734 .55517 .92473 .55157 Mtetra
.966 .793 .616 r
.92473 .55157 .92734 .55517 .9322 .53676 .92962 .53313 Mtetra
.982 .768 .541 r
.92962 .53313 .9322 .53676 .93598 .50995 .93341 .50629 Mtetra
.985 .759 .516 r
.93341 .50629 .93598 .50995 .93922 .47962 .93668 .47593 Mtetra
.943 .627 .409 r
.33354 .62389 .33694 .62691 .34076 .65545 .33734 .65245 Mtetra
.942 .619 .394 r
.33734 .65245 .34076 .65545 .34481 .68159 .34137 .67861 Mtetra
.935 .58 .321 r
.34137 .67861 .34481 .68159 .34935 .70001 .34589 .69705 Mtetra
.925 .547 .263 r
.34589 .69705 .34935 .70001 .35411 .71523 .35064 .71228 Mtetra
.875 .435 .085 r
.35064 .71228 .35411 .71523 .35917 .7254 .3557 .72246 Mtetra
.617 .094 0 r
.3557 .72246 .35917 .7254 .36449 .731 .36101 .72807 Mtetra
0 .229 .697 r
.36101 .72807 .36449 .731 .36993 .73465 .36645 .73172 Mtetra
.344 .641 .964 r
.36645 .73172 .36993 .73465 .37551 .73555 .37204 .73261 Mtetra
.499 .712 .966 r
.37204 .73261 .37551 .73555 .38115 .73543 .37768 .73248 Mtetra
.574 .739 .954 r
.37768 .73248 .38115 .73543 .38683 .73466 .38337 .73171 Mtetra
.632 .757 .938 r
.38337 .73171 .38683 .73466 .39255 .73325 .3891 .73029 Mtetra
.64 .759 .935 r
.3891 .73029 .39255 .73325 .39829 .73174 .39485 .72878 Mtetra
.648 .762 .932 r
.39485 .72878 .39829 .73174 .40404 .73012 .40061 .72715 Mtetra
.653 .763 .93 r
.40061 .72715 .40404 .73012 .40981 .72844 .40639 .72547 Mtetra
.40639 .72547 .40981 .72844 .41559 .72675 .41217 .72377 Mtetra
.41217 .72377 .41559 .72675 .42139 .72505 .41798 .72207 Mtetra
.654 .763 .93 r
.41798 .72207 .42139 .72505 .42719 .72335 .42379 .72035 Mtetra
.42379 .72035 .42719 .72335 .43301 .72164 .42961 .71864 Mtetra
.652 .763 .93 r
.42961 .71864 .43301 .72164 .43884 .71994 .43545 .71693 Mtetra
.653 .763 .93 r
.43545 .71693 .43884 .71994 .44468 .71823 .4413 .71522 Mtetra
.4413 .71522 .44468 .71823 .45053 .71652 .44716 .7135 Mtetra
.652 .763 .931 r
.44716 .7135 .45053 .71652 .4564 .71482 .45304 .7118 Mtetra
.45304 .7118 .4564 .71482 .46228 .71312 .45892 .71009 Mtetra
.652 .763 .93 r
.45892 .71009 .46228 .71312 .46817 .7114 .46482 .70837 Mtetra
.651 .763 .931 r
.46482 .70837 .46817 .7114 .47407 .7097 .47073 .70666 Mtetra
.47073 .70666 .47407 .7097 .47999 .708 .47666 .70495 Mtetra
.652 .763 .931 r
.47666 .70495 .47999 .708 .48592 .70628 .48259 .70322 Mtetra
.651 .762 .931 r
.48259 .70322 .48592 .70628 .49186 .70457 .48854 .70151 Mtetra
.65 .762 .931 r
.48854 .70151 .49186 .70457 .49781 .70287 .49451 .6998 Mtetra
.651 .763 .931 r
.49451 .6998 .49781 .70287 .50378 .70115 .50048 .69808 Mtetra
.65 .762 .931 r
.50048 .69808 .50378 .70115 .50976 .69944 .50647 .69636 Mtetra
.65 .762 .932 r
.50647 .69636 .50976 .69944 .51575 .69774 .51247 .69465 Mtetra
.65 .762 .931 r
.51247 .69465 .51575 .69774 .52175 .69602 .51848 .69292 Mtetra
.51848 .69292 .52175 .69602 .52777 .6943 .52451 .6912 Mtetra
.649 .762 .932 r
.52451 .6912 .52777 .6943 .5338 .6926 .53055 .68949 Mtetra
.53055 .68949 .5338 .6926 .53985 .69088 .5366 .68776 Mtetra
.5366 .68776 .53985 .69088 .5459 .68916 .54267 .68603 Mtetra
.648 .762 .932 r
.54267 .68603 .5459 .68916 .55198 .68745 .54875 .68432 Mtetra
.649 .762 .932 r
.54875 .68432 .55198 .68745 .55806 .68573 .55484 .68259 Mtetra
.55484 .68259 .55806 .68573 .56416 .684 .56095 .68086 Mtetra
.648 .762 .932 r
.56095 .68086 .56416 .684 .57027 .68229 .56707 .67914 Mtetra
.56707 .67914 .57027 .68229 .57639 .68057 .5732 .67742 Mtetra
.5732 .67742 .57639 .68057 .58253 .67884 .57935 .67568 Mtetra
.647 .761 .932 r
.57935 .67568 .58253 .67884 .58868 .67713 .58551 .67396 Mtetra
.58551 .67396 .58868 .67713 .59484 .67541 .59168 .67223 Mtetra
.648 .762 .932 r
.59168 .67223 .59484 .67541 .60102 .67368 .59787 .67049 Mtetra
.647 .761 .933 r
.59787 .67049 .60102 .67368 .60721 .67196 .60407 .66876 Mtetra
.646 .761 .933 r
.60407 .66876 .60721 .67196 .61342 .67024 .61028 .66704 Mtetra
.647 .761 .932 r
.61028 .66704 .61342 .67024 .61964 .6685 .61651 .6653 Mtetra
.646 .761 .933 r
.61651 .6653 .61964 .6685 .62587 .66677 .62276 .66356 Mtetra
.62276 .66356 .62587 .66677 .63212 .66505 .62901 .66183 Mtetra
.62901 .66183 .63212 .66505 .63838 .66332 .63528 .66009 Mtetra
.63528 .66009 .63838 .66332 .64466 .66158 .64157 .65835 Mtetra
.645 .761 .933 r
.64157 .65835 .64466 .66158 .65095 .65986 .64787 .65662 Mtetra
.646 .761 .933 r
.64787 .65662 .65095 .65986 .65725 .65812 .65418 .65488 Mtetra
.65418 .65488 .65725 .65812 .66357 .65638 .66051 .65313 Mtetra
.644 .76 .933 r
.66051 .65313 .66357 .65638 .66991 .65466 .66685 .6514 Mtetra
.645 .761 .933 r
.66685 .6514 .66991 .65466 .67625 .65292 .67321 .64965 Mtetra
.67321 .64965 .67625 .65292 .68261 .65118 .67958 .6479 Mtetra
.644 .76 .934 r
.67958 .6479 .68261 .65118 .68899 .64945 .68597 .64616 Mtetra
.644 .76 .933 r
.68597 .64616 .68899 .64945 .69538 .64771 .69237 .64442 Mtetra
.645 .761 .933 r
.69237 .64442 .69538 .64771 .70179 .64596 .69879 .64266 Mtetra
.643 .76 .934 r
.69879 .64266 .70179 .64596 .70821 .64423 .70522 .64092 Mtetra
.70522 .64092 .70821 .64423 .71464 .64249 .71166 .63918 Mtetra
.71166 .63918 .71464 .64249 .7211 .64075 .71812 .63743 Mtetra
.71812 .63743 .7211 .64075 .72756 .63901 .7246 .63568 Mtetra
.7246 .63568 .72756 .63901 .73404 .63726 .73109 .63392 Mtetra
.73109 .63392 .73404 .63726 .74054 .63552 .73759 .63217 Mtetra
.642 .76 .934 r
.73759 .63217 .74054 .63552 .74705 .63377 .74411 .63042 Mtetra
.74411 .63042 .74705 .63377 .75357 .63202 .75065 .62866 Mtetra
.75065 .62866 .75357 .63202 .76011 .63027 .7572 .6269 Mtetra
.7572 .6269 .76011 .63027 .76667 .62852 .76377 .62515 Mtetra
.642 .759 .934 r
.76377 .62515 .76667 .62852 .77324 .62677 .77035 .62339 Mtetra
.641 .759 .934 r
.77035 .62339 .77324 .62677 .77983 .62502 .77695 .62163 Mtetra
.77695 .62163 .77983 .62502 .78643 .62327 .78356 .61987 Mtetra
.78356 .61987 .78643 .62327 .79305 .62152 .79019 .61811 Mtetra
.79019 .61811 .79305 .62152 .79969 .61976 .79684 .61635 Mtetra
.79684 .61635 .79969 .61976 .80634 .61801 .8035 .61458 Mtetra
.64 .759 .934 r
.8035 .61458 .80634 .61801 .813 .61625 .81018 .61282 Mtetra
.81018 .61282 .813 .61625 .81969 .61449 .81687 .61105 Mtetra
.64 .759 .935 r
.81687 .61105 .81969 .61449 .82639 .61274 .82358 .60929 Mtetra
.82358 .60929 .82639 .61274 .8331 .61098 .83031 .60752 Mtetra
.639 .758 .935 r
.83031 .60752 .8331 .61098 .83983 .60922 .83705 .60575 Mtetra
.83705 .60575 .83983 .60922 .84658 .60746 .84381 .60399 Mtetra
.84381 .60399 .84658 .60746 .85334 .60569 .85058 .60221 Mtetra
.64 .758 .935 r
.85058 .60221 .85334 .60569 .86012 .60392 .85737 .60043 Mtetra
.641 .759 .934 r
.85737 .60043 .86012 .60392 .86691 .60212 .86417 .59862 Mtetra
.645 .761 .933 r
.86417 .59862 .86691 .60212 .87372 .60025 .87099 .59675 Mtetra
.649 .762 .932 r
.87099 .59675 .87372 .60025 .88053 .59833 .87781 .59482 Mtetra
.671 .771 .925 r
.87781 .59482 .88053 .59833 .88732 .59604 .88462 .59252 Mtetra
.696 .78 .916 r
.88462 .59252 .88732 .59604 .89408 .59332 .89139 .58979 Mtetra
.731 .792 .901 r
.89139 .58979 .89408 .59332 .90077 .58992 .8981 .58638 Mtetra
.81 .813 .853 r
.8981 .58638 .90077 .58992 .90726 .58453 .90459 .58098 Mtetra
.853 .819 .815 r
.90459 .58098 .90726 .58453 .91357 .5776 .91092 .57403 Mtetra
.916 .818 .734 r
.91092 .57403 .91357 .5776 .91944 .56693 .9168 .56334 Mtetra
.953 .803 .656 r
.9168 .56334 .91944 .56693 .92473 .55157 .92212 .54796 Mtetra
.966 .793 .616 r
.92212 .54796 .92473 .55157 .92962 .53313 .92702 .52949 Mtetra
.982 .768 .541 r
.92702 .52949 .92962 .53313 .93341 .50629 .93084 .50261 Mtetra
.985 .759 .516 r
.93084 .50261 .93341 .50629 .93668 .47593 .93414 .47221 Mtetra
.943 .627 .409 r
.33013 .62085 .33354 .62389 .33734 .65245 .3339 .64944 Mtetra
.942 .619 .394 r
.3339 .64944 .33734 .65245 .34137 .67861 .33791 .67562 Mtetra
.935 .58 .321 r
.33791 .67562 .34137 .67861 .34589 .69705 .34241 .69407 Mtetra
.925 .547 .263 r
.34241 .69407 .34589 .69705 .35064 .71228 .34715 .70932 Mtetra
.875 .435 .086 r
.34715 .70932 .35064 .71228 .3557 .72246 .35221 .7195 Mtetra
.618 .094 0 r
.35221 .7195 .3557 .72246 .36101 .72807 .35752 .72512 Mtetra
0 .229 .696 r
.35752 .72512 .36101 .72807 .36645 .73172 .36296 .72877 Mtetra
.343 .641 .964 r
.36296 .72877 .36645 .73172 .37204 .73261 .36855 .72966 Mtetra
.499 .712 .966 r
.36855 .72966 .37204 .73261 .37768 .73248 .37421 .72953 Mtetra
.574 .739 .954 r
.37421 .72953 .37768 .73248 .38337 .73171 .3799 .72875 Mtetra
.632 .757 .938 r
.3799 .72875 .38337 .73171 .3891 .73029 .38564 .72733 Mtetra
.64 .759 .935 r
.38564 .72733 .3891 .73029 .39485 .72878 .39139 .72581 Mtetra
.648 .762 .932 r
.39139 .72581 .39485 .72878 .40061 .72715 .39716 .72418 Mtetra
.652 .763 .93 r
.39716 .72418 .40061 .72715 .40639 .72547 .40295 .72248 Mtetra
.653 .763 .93 r
.40295 .72248 .40639 .72547 .41217 .72377 .40874 .72078 Mtetra
.40874 .72078 .41217 .72377 .41798 .72207 .41455 .71907 Mtetra
.654 .763 .93 r
.41455 .71907 .41798 .72207 .42379 .72035 .42037 .71735 Mtetra
.42037 .71735 .42379 .72035 .42961 .71864 .4262 .71563 Mtetra
.652 .763 .93 r
.4262 .71563 .42961 .71864 .43545 .71693 .43205 .71392 Mtetra
.653 .763 .93 r
.43205 .71392 .43545 .71693 .4413 .71522 .43791 .7122 Mtetra
.43791 .7122 .4413 .71522 .44716 .7135 .44378 .71047 Mtetra
.652 .763 .931 r
.44378 .71047 .44716 .7135 .45304 .7118 .44966 .70876 Mtetra
.44966 .70876 .45304 .7118 .45892 .71009 .45555 .70705 Mtetra
.652 .763 .93 r
.45555 .70705 .45892 .71009 .46482 .70837 .46146 .70532 Mtetra
.651 .763 .931 r
.46146 .70532 .46482 .70837 .47073 .70666 .46738 .7036 Mtetra
.46738 .7036 .47073 .70666 .47666 .70495 .47331 .70189 Mtetra
.652 .763 .931 r
.47331 .70189 .47666 .70495 .48259 .70322 .47926 .70016 Mtetra
.651 .762 .931 r
.47926 .70016 .48259 .70322 .48854 .70151 .48522 .69844 Mtetra
.65 .762 .931 r
.48522 .69844 .48854 .70151 .49451 .6998 .49119 .69672 Mtetra
.651 .763 .931 r
.49119 .69672 .49451 .6998 .50048 .69808 .49717 .69499 Mtetra
.65 .762 .931 r
.49717 .69499 .50048 .69808 .50647 .69636 .50317 .69326 Mtetra
.649 .762 .932 r
.50317 .69326 .50647 .69636 .51247 .69465 .50918 .69155 Mtetra
.65 .762 .931 r
.50918 .69155 .51247 .69465 .51848 .69292 .5152 .68981 Mtetra
.5152 .68981 .51848 .69292 .52451 .6912 .52123 .68808 Mtetra
.649 .762 .932 r
.52123 .68808 .52451 .6912 .53055 .68949 .52728 .68637 Mtetra
.52728 .68637 .53055 .68949 .5366 .68776 .53334 .68463 Mtetra
.53334 .68463 .5366 .68776 .54267 .68603 .53942 .6829 Mtetra
.648 .762 .932 r
.53942 .6829 .54267 .68603 .54875 .68432 .54551 .68118 Mtetra
.649 .762 .932 r
.54551 .68118 .54875 .68432 .55484 .68259 .55161 .67944 Mtetra
.55161 .67944 .55484 .68259 .56095 .68086 .55772 .6777 Mtetra
.647 .762 .932 r
.55772 .6777 .56095 .68086 .56707 .67914 .56385 .67598 Mtetra
.648 .762 .932 r
.56385 .67598 .56707 .67914 .5732 .67742 .56999 .67425 Mtetra
.56999 .67425 .5732 .67742 .57935 .67568 .57615 .6725 Mtetra
.647 .761 .932 r
.57615 .6725 .57935 .67568 .58551 .67396 .58232 .67077 Mtetra
.58232 .67077 .58551 .67396 .59168 .67223 .5885 .66904 Mtetra
.648 .762 .932 r
.5885 .66904 .59168 .67223 .59787 .67049 .5947 .66729 Mtetra
.647 .761 .933 r
.5947 .66729 .59787 .67049 .60407 .66876 .60091 .66556 Mtetra
.646 .761 .933 r
.60091 .66556 .60407 .66876 .61028 .66704 .60713 .66383 Mtetra
.647 .761 .932 r
.60713 .66383 .61028 .66704 .61651 .6653 .61337 .66208 Mtetra
.646 .761 .933 r
.61337 .66208 .61651 .6653 .62276 .66356 .61962 .66034 Mtetra
.61962 .66034 .62276 .66356 .62901 .66183 .62589 .6586 Mtetra
.62589 .6586 .62901 .66183 .63528 .66009 .63217 .65685 Mtetra
.63217 .65685 .63528 .66009 .64157 .65835 .63847 .6551 Mtetra
.645 .761 .933 r
.63847 .6551 .64157 .65835 .64787 .65662 .64478 .65336 Mtetra
.646 .761 .933 r
.64478 .65336 .64787 .65662 .65418 .65488 .6511 .65161 Mtetra
.6511 .65161 .65418 .65488 .66051 .65313 .65744 .64986 Mtetra
.644 .761 .933 r
.65744 .64986 .66051 .65313 .66685 .6514 .66379 .64812 Mtetra
.645 .761 .933 r
.66379 .64812 .66685 .6514 .67321 .64965 .67016 .64637 Mtetra
.67016 .64637 .67321 .64965 .67958 .6479 .67654 .64461 Mtetra
.644 .76 .934 r
.67654 .64461 .67958 .6479 .68597 .64616 .68293 .64286 Mtetra
.644 .76 .933 r
.68293 .64286 .68597 .64616 .69237 .64442 .68934 .64111 Mtetra
.645 .761 .933 r
.68934 .64111 .69237 .64442 .69879 .64266 .69577 .63935 Mtetra
.643 .76 .934 r
.69577 .63935 .69879 .64266 .70522 .64092 .70221 .6376 Mtetra
.70221 .6376 .70522 .64092 .71166 .63918 .70867 .63585 Mtetra
.70867 .63585 .71166 .63918 .71812 .63743 .71514 .63409 Mtetra
.71514 .63409 .71812 .63743 .7246 .63568 .72162 .63233 Mtetra
.72162 .63233 .7246 .63568 .73109 .63392 .72812 .63057 Mtetra
.72812 .63057 .73109 .63392 .73759 .63217 .73464 .62881 Mtetra
.642 .76 .934 r
.73464 .62881 .73759 .63217 .74411 .63042 .74117 .62705 Mtetra
.74117 .62705 .74411 .63042 .75065 .62866 .74772 .62528 Mtetra
.74772 .62528 .75065 .62866 .7572 .6269 .75428 .62352 Mtetra
.75428 .62352 .7572 .6269 .76377 .62515 .76086 .62176 Mtetra
.642 .759 .934 r
.76086 .62176 .76377 .62515 .77035 .62339 .76745 .61999 Mtetra
.641 .759 .934 r
.76745 .61999 .77035 .62339 .77695 .62163 .77406 .61822 Mtetra
.77406 .61822 .77695 .62163 .78356 .61987 .78068 .61645 Mtetra
.78068 .61645 .78356 .61987 .79019 .61811 .78732 .61469 Mtetra
.78732 .61469 .79019 .61811 .79684 .61635 .79398 .61292 Mtetra
.79398 .61292 .79684 .61635 .8035 .61458 .80065 .61114 Mtetra
.64 .759 .934 r
.80065 .61114 .8035 .61458 .81018 .61282 .80734 .60937 Mtetra
.64 .759 .935 r
.80734 .60937 .81018 .61282 .81687 .61105 .81404 .6076 Mtetra
.81404 .6076 .81687 .61105 .82358 .60929 .82076 .60583 Mtetra
.82076 .60583 .82358 .60929 .83031 .60752 .8275 .60405 Mtetra
.639 .759 .935 r
.8275 .60405 .83031 .60752 .83705 .60575 .83425 .60227 Mtetra
.639 .758 .935 r
.83425 .60227 .83705 .60575 .84381 .60399 .84102 .6005 Mtetra
.84102 .6005 .84381 .60399 .85058 .60221 .84781 .59872 Mtetra
.64 .759 .935 r
.84781 .59872 .85058 .60221 .85737 .60043 .85461 .59692 Mtetra
.641 .759 .934 r
.85461 .59692 .85737 .60043 .86417 .59862 .86142 .59511 Mtetra
.645 .761 .933 r
.86142 .59511 .86417 .59862 .87099 .59675 .86825 .59323 Mtetra
.649 .762 .932 r
.86825 .59323 .87099 .59675 .87781 .59482 .87509 .59129 Mtetra
.671 .771 .925 r
.87509 .59129 .87781 .59482 .88462 .59252 .8819 .58898 Mtetra
.696 .78 .916 r
.8819 .58898 .88462 .59252 .89139 .58979 .88868 .58624 Mtetra
.731 .792 .901 r
.88868 .58624 .89139 .58979 .8981 .58638 .89541 .58282 Mtetra
.81 .813 .853 r
.89541 .58282 .8981 .58638 .90459 .58098 .90192 .5774 Mtetra
.853 .819 .815 r
.90192 .5774 .90459 .58098 .91092 .57403 .90825 .57044 Mtetra
.916 .818 .734 r
.90825 .57044 .91092 .57403 .9168 .56334 .91416 .55973 Mtetra
.954 .803 .656 r
.91416 .55973 .9168 .56334 .92212 .54796 .91949 .54433 Mtetra
.966 .793 .616 r
.91949 .54433 .92212 .54796 .92702 .52949 .92441 .52583 Mtetra
.982 .768 .541 r
.92441 .52583 .92702 .52949 .93084 .50261 .92826 .49892 Mtetra
.985 .759 .516 r
.92826 .49892 .93084 .50261 .93414 .47221 .93158 .46848 Mtetra
.943 .627 .409 r
.32671 .6178 .33013 .62085 .3339 .64944 .33046 .64641 Mtetra
.942 .619 .394 r
.33046 .64641 .3339 .64944 .33791 .67562 .33444 .67262 Mtetra
.935 .58 .321 r
.33444 .67262 .33791 .67562 .34241 .69407 .33893 .69109 Mtetra
.925 .547 .264 r
.33893 .69109 .34241 .69407 .34715 .70932 .34366 .70635 Mtetra
.875 .435 .086 r
.34366 .70635 .34715 .70932 .35221 .7195 .3487 .71654 Mtetra
.618 .094 0 r
.3487 .71654 .35221 .7195 .35752 .72512 .35402 .72216 Mtetra
0 .229 .696 r
.35402 .72216 .35752 .72512 .36296 .72877 .35946 .72581 Mtetra
.343 .641 .964 r
.35946 .72581 .36296 .72877 .36855 .72966 .36506 .72669 Mtetra
.499 .712 .966 r
.36506 .72669 .36855 .72966 .37421 .72953 .37071 .72656 Mtetra
.574 .739 .954 r
.37071 .72656 .37421 .72953 .3799 .72875 .37642 .72578 Mtetra
.632 .757 .938 r
.37642 .72578 .3799 .72875 .38564 .72733 .38216 .72435 Mtetra
.64 .759 .935 r
.38216 .72435 .38564 .72733 .39139 .72581 .38792 .72283 Mtetra
.648 .762 .932 r
.38792 .72283 .39139 .72581 .39716 .72418 .3937 .72119 Mtetra
.652 .763 .93 r
.3937 .72119 .39716 .72418 .40295 .72248 .39949 .71949 Mtetra
.653 .763 .93 r
.39949 .71949 .40295 .72248 .40874 .72078 .4053 .71778 Mtetra
.4053 .71778 .40874 .72078 .41455 .71907 .41111 .71606 Mtetra
.654 .763 .93 r
.41111 .71606 .41455 .71907 .42037 .71735 .41694 .71434 Mtetra
.41694 .71434 .42037 .71735 .4262 .71563 .42278 .71261 Mtetra
.652 .763 .93 r
.42278 .71261 .4262 .71563 .43205 .71392 .42864 .71089 Mtetra
.653 .763 .93 r
.42864 .71089 .43205 .71392 .43791 .7122 .4345 .70917 Mtetra
.4345 .70917 .43791 .7122 .44378 .71047 .44038 .70743 Mtetra
.652 .763 .931 r
.44038 .70743 .44378 .71047 .44966 .70876 .44627 .70572 Mtetra
.44627 .70572 .44966 .70876 .45555 .70705 .45217 .70399 Mtetra
.652 .763 .93 r
.45217 .70399 .45555 .70705 .46146 .70532 .45809 .70226 Mtetra
.651 .763 .931 r
.45809 .70226 .46146 .70532 .46738 .7036 .46402 .70054 Mtetra
.46402 .70054 .46738 .7036 .47331 .70189 .46996 .69881 Mtetra
.652 .763 .931 r
.46996 .69881 .47331 .70189 .47926 .70016 .47591 .69708 Mtetra
.651 .763 .931 r
.47591 .69708 .47926 .70016 .48522 .69844 .48188 .69535 Mtetra
.65 .762 .931 r
.48188 .69535 .48522 .69844 .49119 .69672 .48786 .69363 Mtetra
.651 .763 .931 r
.48786 .69363 .49119 .69672 .49717 .69499 .49385 .69189 Mtetra
.65 .762 .931 r
.49385 .69189 .49717 .69499 .50317 .69326 .49985 .69016 Mtetra
.649 .762 .932 r
.49985 .69016 .50317 .69326 .50918 .69155 .50587 .68843 Mtetra
.65 .762 .931 r
.50587 .68843 .50918 .69155 .5152 .68981 .5119 .6867 Mtetra
.5119 .6867 .5152 .68981 .52123 .68808 .51795 .68496 Mtetra
.649 .762 .932 r
.51795 .68496 .52123 .68808 .52728 .68637 .524 .68323 Mtetra
.524 .68323 .52728 .68637 .53334 .68463 .53007 .68149 Mtetra
.53007 .68149 .53334 .68463 .53942 .6829 .53616 .67975 Mtetra
.648 .762 .932 r
.53616 .67975 .53942 .6829 .54551 .68118 .54225 .67802 Mtetra
.649 .762 .932 r
.54225 .67802 .54551 .68118 .55161 .67944 .54836 .67628 Mtetra
.54836 .67628 .55161 .67944 .55772 .6777 .55449 .67454 Mtetra
.647 .762 .932 r
.55449 .67454 .55772 .6777 .56385 .67598 .56063 .6728 Mtetra
.648 .762 .932 r
.56063 .6728 .56385 .67598 .56999 .67425 .56678 .67107 Mtetra
.56678 .67107 .56999 .67425 .57615 .6725 .57294 .66931 Mtetra
.647 .762 .932 r
.57294 .66931 .57615 .6725 .58232 .67077 .57912 .66758 Mtetra
.57912 .66758 .58232 .67077 .5885 .66904 .58531 .66584 Mtetra
.648 .762 .932 r
.58531 .66584 .5885 .66904 .5947 .66729 .59152 .66408 Mtetra
.647 .761 .933 r
.59152 .66408 .5947 .66729 .60091 .66556 .59774 .66234 Mtetra
.646 .761 .933 r
.59774 .66234 .60091 .66556 .60713 .66383 .60397 .6606 Mtetra
.647 .762 .932 r
.60397 .6606 .60713 .66383 .61337 .66208 .61022 .65885 Mtetra
.646 .761 .933 r
.61022 .65885 .61337 .66208 .61962 .66034 .61648 .6571 Mtetra
.61648 .6571 .61962 .66034 .62589 .6586 .62276 .65535 Mtetra
.62276 .65535 .62589 .6586 .63217 .65685 .62905 .6536 Mtetra
.62905 .6536 .63217 .65685 .63847 .6551 .63535 .65184 Mtetra
.645 .761 .933 r
.63535 .65184 .63847 .6551 .64478 .65336 .64167 .6501 Mtetra
.646 .761 .933 r
.64167 .6501 .64478 .65336 .6511 .65161 .648 .64834 Mtetra
.648 .64834 .6511 .65161 .65744 .64986 .65435 .64658 Mtetra
.644 .761 .933 r
.65435 .64658 .65744 .64986 .66379 .64812 .66071 .64483 Mtetra
.645 .761 .933 r
.66071 .64483 .66379 .64812 .67016 .64637 .66709 .64307 Mtetra
.66709 .64307 .67016 .64637 .67654 .64461 .67348 .6413 Mtetra
.644 .76 .934 r
.67348 .6413 .67654 .64461 .68293 .64286 .67989 .63955 Mtetra
.644 .76 .933 r
.67989 .63955 .68293 .64286 .68934 .64111 .68631 .63779 Mtetra
.645 .761 .933 r
.68631 .63779 .68934 .64111 .69577 .63935 .69274 .63602 Mtetra
.643 .76 .934 r
.69274 .63602 .69577 .63935 .70221 .6376 .69919 .63426 Mtetra
.69919 .63426 .70221 .6376 .70867 .63585 .70566 .63251 Mtetra
.70566 .63251 .70867 .63585 .71514 .63409 .71214 .63074 Mtetra
.71214 .63074 .71514 .63409 .72162 .63233 .71864 .62897 Mtetra
.71864 .62897 .72162 .63233 .72812 .63057 .72515 .62721 Mtetra
.72515 .62721 .72812 .63057 .73464 .62881 .73167 .62544 Mtetra
.642 .76 .934 r
.73167 .62544 .73464 .62881 .74117 .62705 .73821 .62367 Mtetra
.73821 .62367 .74117 .62705 .74772 .62528 .74477 .6219 Mtetra
.74477 .6219 .74772 .62528 .75428 .62352 .75134 .62012 Mtetra
.75134 .62012 .75428 .62352 .76086 .62176 .75793 .61835 Mtetra
.75793 .61835 .76086 .62176 .76745 .61999 .76453 .61658 Mtetra
.641 .759 .934 r
.76453 .61658 .76745 .61999 .77406 .61822 .77115 .6148 Mtetra
.77115 .6148 .77406 .61822 .78068 .61645 .77779 .61303 Mtetra
.77779 .61303 .78068 .61645 .78732 .61469 .78444 .61125 Mtetra
.78444 .61125 .78732 .61469 .79398 .61292 .79111 .60947 Mtetra
.79111 .60947 .79398 .61292 .80065 .61114 .79779 .60769 Mtetra
.64 .759 .934 r
.79779 .60769 .80065 .61114 .80734 .60937 .80449 .60591 Mtetra
.64 .759 .935 r
.80449 .60591 .80734 .60937 .81404 .6076 .8112 .60413 Mtetra
.8112 .60413 .81404 .6076 .82076 .60583 .81794 .60235 Mtetra
.81794 .60235 .82076 .60583 .8275 .60405 .82468 .60057 Mtetra
.639 .759 .935 r
.82468 .60057 .8275 .60405 .83425 .60227 .83145 .59878 Mtetra
.639 .758 .935 r
.83145 .59878 .83425 .60227 .84102 .6005 .83823 .597 Mtetra
.639 .759 .935 r
.83823 .597 .84102 .6005 .84781 .59872 .84502 .59521 Mtetra
.64 .759 .935 r
.84502 .59521 .84781 .59872 .85461 .59692 .85184 .59341 Mtetra
.641 .759 .934 r
.85184 .59341 .85461 .59692 .86142 .59511 .85866 .59158 Mtetra
.645 .761 .933 r
.85866 .59158 .86142 .59511 .86825 .59323 .8655 .58969 Mtetra
.649 .762 .932 r
.8655 .58969 .86825 .59323 .87509 .59129 .87235 .58775 Mtetra
.671 .771 .925 r
.87235 .58775 .87509 .59129 .8819 .58898 .87917 .58543 Mtetra
.696 .78 .916 r
.87917 .58543 .8819 .58898 .88868 .58624 .88597 .58268 Mtetra
.731 .792 .901 r
.88597 .58268 .88868 .58624 .89541 .58282 .8927 .57925 Mtetra
.811 .813 .853 r
.8927 .57925 .89541 .58282 .90192 .5774 .89923 .57382 Mtetra
.853 .82 .815 r
.89923 .57382 .90192 .5774 .90825 .57044 .90558 .56684 Mtetra
.916 .818 .734 r
.90558 .56684 .90825 .57044 .91416 .55973 .9115 .55611 Mtetra
.954 .803 .656 r
.9115 .55611 .91416 .55973 .91949 .54433 .91685 .54069 Mtetra
.966 .793 .616 r
.91685 .54069 .91949 .54433 .92441 .52583 .92179 .52216 Mtetra
.982 .768 .54 r
.92179 .52216 .92441 .52583 .92826 .49892 .92567 .49522 Mtetra
.985 .759 .516 r
.92567 .49522 .92826 .49892 .93158 .46848 .92901 .46474 Mtetra
.943 .627 .409 r
.32328 .61475 .32671 .6178 .33046 .64641 .327 .64338 Mtetra
.942 .619 .394 r
.327 .64338 .33046 .64641 .33444 .67262 .33095 .66961 Mtetra
.935 .58 .321 r
.33095 .66961 .33444 .67262 .33893 .69109 .33543 .6881 Mtetra
.925 .547 .264 r
.33543 .6881 .33893 .69109 .34366 .70635 .34015 .70337 Mtetra
.875 .435 .086 r
.34015 .70337 .34366 .70635 .3487 .71654 .34519 .71357 Mtetra
.618 .094 0 r
.34519 .71357 .3487 .71654 .35402 .72216 .3505 .71919 Mtetra
0 .229 .696 r
.3505 .71919 .35402 .72216 .35946 .72581 .35594 .72284 Mtetra
.343 .641 .964 r
.35594 .72284 .35946 .72581 .36506 .72669 .36154 .72372 Mtetra
.499 .712 .966 r
.36154 .72372 .36506 .72669 .37071 .72656 .36721 .72358 Mtetra
.574 .739 .954 r
.36721 .72358 .37071 .72656 .37642 .72578 .37292 .72279 Mtetra
.632 .757 .938 r
.37292 .72279 .37642 .72578 .38216 .72435 .37867 .72136 Mtetra
.64 .759 .935 r
.37867 .72136 .38216 .72435 .38792 .72283 .38444 .71983 Mtetra
.648 .762 .932 r
.38444 .71983 .38792 .72283 .3937 .72119 .39022 .71819 Mtetra
.652 .763 .93 r
.39022 .71819 .3937 .72119 .39949 .71949 .39602 .71648 Mtetra
.653 .763 .93 r
.39602 .71648 .39949 .71949 .4053 .71778 .40184 .71476 Mtetra
.40184 .71476 .4053 .71778 .41111 .71606 .40766 .71304 Mtetra
.654 .763 .93 r
.40766 .71304 .41111 .71606 .41694 .71434 .4135 .71131 Mtetra
.4135 .71131 .41694 .71434 .42278 .71261 .41935 .70958 Mtetra
.652 .763 .93 r
.41935 .70958 .42278 .71261 .42864 .71089 .42521 .70785 Mtetra
.653 .763 .93 r
.42521 .70785 .42864 .71089 .4345 .70917 .43108 .70612 Mtetra
.43108 .70612 .4345 .70917 .44038 .70743 .43697 .70438 Mtetra
.652 .763 .931 r
.43697 .70438 .44038 .70743 .44627 .70572 .44287 .70266 Mtetra
.44287 .70266 .44627 .70572 .45217 .70399 .44878 .70093 Mtetra
.652 .763 .93 r
.44878 .70093 .45217 .70399 .45809 .70226 .4547 .69919 Mtetra
.651 .763 .931 r
.4547 .69919 .45809 .70226 .46402 .70054 .46064 .69746 Mtetra
.46064 .69746 .46402 .70054 .46996 .69881 .46659 .69573 Mtetra
.652 .763 .931 r
.46659 .69573 .46996 .69881 .47591 .69708 .47255 .69399 Mtetra
.651 .763 .931 r
.47255 .69399 .47591 .69708 .48188 .69535 .47852 .69225 Mtetra
.65 .762 .931 r
.47852 .69225 .48188 .69535 .48786 .69363 .48451 .69052 Mtetra
.651 .763 .931 r
.48451 .69052 .48786 .69363 .49385 .69189 .49051 .68878 Mtetra
.65 .762 .931 r
.49051 .68878 .49385 .69189 .49985 .69016 .49652 .68704 Mtetra
.649 .762 .932 r
.49652 .68704 .49985 .69016 .50587 .68843 .50255 .68531 Mtetra
.65 .762 .931 r
.50255 .68531 .50587 .68843 .5119 .6867 .50859 .68356 Mtetra
.65 .762 .932 r
.50859 .68356 .5119 .6867 .51795 .68496 .51464 .68182 Mtetra
.649 .762 .932 r
.51464 .68182 .51795 .68496 .524 .68323 .52071 .68009 Mtetra
.52071 .68009 .524 .68323 .53007 .68149 .52679 .67834 Mtetra
.52679 .67834 .53007 .68149 .53616 .67975 .53288 .67659 Mtetra
.648 .762 .932 r
.53288 .67659 .53616 .67975 .54225 .67802 .53899 .67486 Mtetra
.649 .762 .932 r
.53899 .67486 .54225 .67802 .54836 .67628 .54511 .67311 Mtetra
.54511 .67311 .54836 .67628 .55449 .67454 .55124 .67136 Mtetra
.647 .762 .932 r
.55124 .67136 .55449 .67454 .56063 .6728 .55738 .66962 Mtetra
.648 .762 .932 r
.55738 .66962 .56063 .6728 .56678 .67107 .56354 .66787 Mtetra
.56354 .66787 .56678 .67107 .57294 .66931 .56972 .66611 Mtetra
.647 .762 .933 r
.56972 .66611 .57294 .66931 .57912 .66758 .57591 .66437 Mtetra
.57591 .66437 .57912 .66758 .58531 .66584 .58211 .66262 Mtetra
.648 .762 .932 r
.58211 .66262 .58531 .66584 .59152 .66408 .58832 .66086 Mtetra
.647 .761 .933 r
.58832 .66086 .59152 .66408 .59774 .66234 .59455 .65911 Mtetra
.646 .761 .933 r
.59455 .65911 .59774 .66234 .60397 .6606 .60079 .65736 Mtetra
.647 .762 .933 r
.60079 .65736 .60397 .6606 .61022 .65885 .60705 .6556 Mtetra
.646 .761 .933 r
.60705 .6556 .61022 .65885 .61648 .6571 .61332 .65385 Mtetra
.61332 .65385 .61648 .6571 .62276 .65535 .61961 .6521 Mtetra
.61961 .6521 .62276 .65535 .62905 .6536 .62591 .65033 Mtetra
.62591 .65033 .62905 .6536 .63535 .65184 .63222 .64857 Mtetra
.645 .761 .933 r
.63222 .64857 .63535 .65184 .64167 .6501 .63855 .64682 Mtetra
.646 .761 .933 r
.63855 .64682 .64167 .6501 .648 .64834 .64489 .64505 Mtetra
.64489 .64505 .648 .64834 .65435 .64658 .65125 .64328 Mtetra
.644 .761 .933 r
.65125 .64328 .65435 .64658 .66071 .64483 .65762 .64153 Mtetra
.645 .761 .933 r
.65762 .64153 .66071 .64483 .66709 .64307 .66401 .63976 Mtetra
.66401 .63976 .66709 .64307 .67348 .6413 .67041 .63798 Mtetra
.644 .76 .934 r
.67041 .63798 .67348 .6413 .67989 .63955 .67683 .63623 Mtetra
.644 .761 .934 r
.67683 .63623 .67989 .63955 .68631 .63779 .68326 .63446 Mtetra
.645 .761 .933 r
.68326 .63446 .68631 .63779 .69274 .63602 .6897 .63268 Mtetra
.643 .76 .934 r
.6897 .63268 .69274 .63602 .69919 .63426 .69616 .63091 Mtetra
.69616 .63091 .69919 .63426 .70566 .63251 .70264 .62915 Mtetra
.70264 .62915 .70566 .63251 .71214 .63074 .70913 .62738 Mtetra
.70913 .62738 .71214 .63074 .71864 .62897 .71563 .6256 Mtetra
.71563 .6256 .71864 .62897 .72515 .62721 .72216 .62383 Mtetra
.72216 .62383 .72515 .62721 .73167 .62544 .72869 .62205 Mtetra
.642 .76 .934 r
.72869 .62205 .73167 .62544 .73821 .62367 .73524 .62027 Mtetra
.73524 .62027 .73821 .62367 .74477 .6219 .74181 .61849 Mtetra
.74181 .61849 .74477 .6219 .75134 .62012 .74839 .61671 Mtetra
.74839 .61671 .75134 .62012 .75793 .61835 .75499 .61493 Mtetra
.75499 .61493 .75793 .61835 .76453 .61658 .76161 .61315 Mtetra
.641 .759 .934 r
.76161 .61315 .76453 .61658 .77115 .6148 .76824 .61137 Mtetra
.76824 .61137 .77115 .6148 .77779 .61303 .77488 .60958 Mtetra
.77488 .60958 .77779 .61303 .78444 .61125 .78154 .6078 Mtetra
.78154 .6078 .78444 .61125 .79111 .60947 .78822 .60601 Mtetra
.78822 .60601 .79111 .60947 .79779 .60769 .79492 .60423 Mtetra
.64 .759 .935 r
.79492 .60423 .79779 .60769 .80449 .60591 .80163 .60244 Mtetra
.80163 .60244 .80449 .60591 .8112 .60413 .80835 .60065 Mtetra
.80835 .60065 .8112 .60413 .81794 .60235 .81509 .59886 Mtetra
.81509 .59886 .81794 .60235 .82468 .60057 .82185 .59707 Mtetra
.639 .759 .935 r
.82185 .59707 .82468 .60057 .83145 .59878 .82863 .59528 Mtetra
.639 .758 .935 r
.82863 .59528 .83145 .59878 .83823 .597 .83542 .59348 Mtetra
.639 .759 .935 r
.83542 .59348 .83823 .597 .84502 .59521 .84223 .59168 Mtetra
.64 .759 .935 r
.84223 .59168 .84502 .59521 .85184 .59341 .84905 .58987 Mtetra
.641 .759 .934 r
.84905 .58987 .85184 .59341 .85866 .59158 .85589 .58804 Mtetra
.645 .761 .933 r
.85589 .58804 .85866 .59158 .8655 .58969 .86274 .58614 Mtetra
.649 .762 .932 r
.86274 .58614 .8655 .58969 .87235 .58775 .8696 .58419 Mtetra
.671 .771 .925 r
.8696 .58419 .87235 .58775 .87917 .58543 .87644 .58186 Mtetra
.696 .78 .916 r
.87644 .58186 .87917 .58543 .88597 .58268 .88324 .5791 Mtetra
.731 .792 .901 r
.88324 .5791 .88597 .58268 .8927 .57925 .88999 .57566 Mtetra
.811 .813 .853 r
.88999 .57566 .8927 .57925 .89923 .57382 .89653 .57022 Mtetra
.853 .82 .815 r
.89653 .57022 .89923 .57382 .90558 .56684 .90289 .56323 Mtetra
.916 .818 .734 r
.90289 .56323 .90558 .56684 .9115 .55611 .90883 .55248 Mtetra
.954 .804 .656 r
.90883 .55248 .9115 .55611 .91685 .54069 .9142 .53703 Mtetra
.966 .793 .616 r
.9142 .53703 .91685 .54069 .92179 .52216 .91916 .51848 Mtetra
.982 .768 .54 r
.91916 .51848 .92179 .52216 .92567 .49522 .92306 .4915 Mtetra
.985 .759 .516 r
.92306 .4915 .92567 .49522 .92901 .46474 .92644 .46098 Mtetra
.943 .627 .409 r
.31983 .61168 .32328 .61475 .327 .64338 .32352 .64033 Mtetra
.942 .619 .394 r
.32352 .64033 .327 .64338 .33095 .66961 .32746 .66659 Mtetra
.935 .58 .321 r
.32746 .66659 .33095 .66961 .33543 .6881 .33191 .68509 Mtetra
.925 .547 .264 r
.33191 .68509 .33543 .6881 .34015 .70337 .33662 .70038 Mtetra
.875 .435 .086 r
.33662 .70038 .34015 .70337 .34519 .71357 .34165 .71059 Mtetra
.618 .095 0 r
.34165 .71059 .34519 .71357 .3505 .71919 .34697 .71621 Mtetra
0 .228 .695 r
.34697 .71621 .3505 .71919 .35594 .72284 .35241 .71986 Mtetra
.343 .641 .964 r
.35241 .71986 .35594 .72284 .36154 .72372 .35802 .72074 Mtetra
.499 .712 .966 r
.35802 .72074 .36154 .72372 .36721 .72358 .36369 .7206 Mtetra
.574 .74 .954 r
.36369 .7206 .36721 .72358 .37292 .72279 .36941 .7198 Mtetra
.632 .758 .938 r
.36941 .7198 .37292 .72279 .37867 .72136 .37517 .71836 Mtetra
.64 .76 .935 r
.37517 .71836 .37867 .72136 .38444 .71983 .38094 .71683 Mtetra
.648 .762 .932 r
.38094 .71683 .38444 .71983 .39022 .71819 .38673 .71518 Mtetra
.652 .763 .93 r
.38673 .71518 .39022 .71819 .39602 .71648 .39254 .71347 Mtetra
.653 .763 .93 r
.39254 .71347 .39602 .71648 .40184 .71476 .39836 .71174 Mtetra
.39836 .71174 .40184 .71476 .40766 .71304 .40419 .71001 Mtetra
.654 .763 .93 r
.40419 .71001 .40766 .71304 .4135 .71131 .41004 .70828 Mtetra
.41004 .70828 .4135 .71131 .41935 .70958 .4159 .70653 Mtetra
.652 .763 .931 r
.4159 .70653 .41935 .70958 .42521 .70785 .42177 .7048 Mtetra
.653 .763 .93 r
.42177 .7048 .42521 .70785 .43108 .70612 .42765 .70307 Mtetra
.42765 .70307 .43108 .70612 .43697 .70438 .43354 .70132 Mtetra
.652 .763 .931 r
.43354 .70132 .43697 .70438 .44287 .70266 .43945 .69959 Mtetra
.43945 .69959 .44287 .70266 .44878 .70093 .44537 .69785 Mtetra
.44537 .69785 .44878 .70093 .4547 .69919 .4513 .6961 Mtetra
.651 .763 .931 r
.4513 .6961 .4547 .69919 .46064 .69746 .45725 .69437 Mtetra
.45725 .69437 .46064 .69746 .46659 .69573 .4632 .69263 Mtetra
.652 .763 .931 r
.4632 .69263 .46659 .69573 .47255 .69399 .46917 .69088 Mtetra
.651 .763 .931 r
.46917 .69088 .47255 .69399 .47852 .69225 .47516 .68914 Mtetra
.65 .762 .931 r
.47516 .68914 .47852 .69225 .48451 .69052 .48115 .68741 Mtetra
.651 .763 .931 r
.48115 .68741 .48451 .69052 .49051 .68878 .48716 .68566 Mtetra
.65 .763 .931 r
.48716 .68566 .49051 .68878 .49652 .68704 .49318 .68391 Mtetra
.649 .762 .932 r
.49318 .68391 .49652 .68704 .50255 .68531 .49922 .68217 Mtetra
.65 .763 .931 r
.49922 .68217 .50255 .68531 .50859 .68356 .50527 .68042 Mtetra
.65 .762 .932 r
.50527 .68042 .50859 .68356 .51464 .68182 .51133 .67867 Mtetra
.649 .762 .932 r
.51133 .67867 .51464 .68182 .52071 .68009 .5174 .67693 Mtetra
.5174 .67693 .52071 .68009 .52679 .67834 .52349 .67518 Mtetra
.52349 .67518 .52679 .67834 .53288 .67659 .52959 .67342 Mtetra
.648 .762 .932 r
.52959 .67342 .53288 .67659 .53899 .67486 .53571 .67168 Mtetra
.649 .762 .932 r
.53571 .67168 .53899 .67486 .54511 .67311 .54183 .66993 Mtetra
.54183 .66993 .54511 .67311 .55124 .67136 .54798 .66816 Mtetra
.647 .762 .932 r
.54798 .66816 .55124 .67136 .55738 .66962 .55413 .66642 Mtetra
.648 .762 .932 r
.55413 .66642 .55738 .66962 .56354 .66787 .5603 .66467 Mtetra
.5603 .66467 .56354 .66787 .56972 .66611 .56648 .6629 Mtetra
.647 .762 .933 r
.56648 .6629 .56972 .66611 .57591 .66437 .57268 .66115 Mtetra
.57268 .66115 .57591 .66437 .58211 .66262 .57889 .6594 Mtetra
.648 .762 .932 r
.57889 .6594 .58211 .66262 .58832 .66086 .58511 .65763 Mtetra
.647 .761 .933 r
.58511 .65763 .58832 .66086 .59455 .65911 .59135 .65587 Mtetra
.646 .761 .933 r
.59135 .65587 .59455 .65911 .60079 .65736 .59761 .65412 Mtetra
.647 .762 .933 r
.59761 .65412 .60079 .65736 .60705 .6556 .60387 .65235 Mtetra
.646 .761 .933 r
.60387 .65235 .60705 .6556 .61332 .65385 .61015 .65058 Mtetra
.645 .761 .933 r
.61015 .65058 .61332 .65385 .61961 .6521 .61645 .64883 Mtetra
.646 .761 .933 r
.61645 .64883 .61961 .6521 .62591 .65033 .62276 .64705 Mtetra
.62276 .64705 .62591 .65033 .63222 .64857 .62908 .64528 Mtetra
.645 .761 .933 r
.62908 .64528 .63222 .64857 .63855 .64682 .63542 .64352 Mtetra
.646 .761 .933 r
.63542 .64352 .63855 .64682 .64489 .64505 .64177 .64175 Mtetra
.64177 .64175 .64489 .64505 .65125 .64328 .64814 .63997 Mtetra
.644 .761 .933 r
.64814 .63997 .65125 .64328 .65762 .64153 .65452 .63821 Mtetra
.645 .761 .933 r
.65452 .63821 .65762 .64153 .66401 .63976 .66092 .63644 Mtetra
.66092 .63644 .66401 .63976 .67041 .63798 .66733 .63465 Mtetra
.644 .76 .934 r
.66733 .63465 .67041 .63798 .67683 .63623 .67375 .63289 Mtetra
.644 .761 .934 r
.67375 .63289 .67683 .63623 .68326 .63446 .68019 .63111 Mtetra
.645 .761 .933 r
.68019 .63111 .68326 .63446 .6897 .63268 .68665 .62932 Mtetra
.643 .76 .934 r
.68665 .62932 .6897 .63268 .69616 .63091 .69312 .62755 Mtetra
.69312 .62755 .69616 .63091 .70264 .62915 .6996 .62578 Mtetra
.6996 .62578 .70264 .62915 .70913 .62738 .70611 .624 Mtetra
.70611 .624 .70913 .62738 .71563 .6256 .71262 .62222 Mtetra
.71262 .62222 .71563 .6256 .72216 .62383 .71915 .62043 Mtetra
.71915 .62043 .72216 .62383 .72869 .62205 .7257 .61865 Mtetra
.642 .76 .934 r
.7257 .61865 .72869 .62205 .73524 .62027 .73226 .61686 Mtetra
.73226 .61686 .73524 .62027 .74181 .61849 .73884 .61508 Mtetra
.73884 .61508 .74181 .61849 .74839 .61671 .74543 .61329 Mtetra
.74543 .61329 .74839 .61671 .75499 .61493 .75204 .6115 Mtetra
.75204 .6115 .75499 .61493 .76161 .61315 .75867 .60971 Mtetra
.641 .76 .934 r
.75867 .60971 .76161 .61315 .76824 .61137 .76531 .60792 Mtetra
.641 .759 .934 r
.76531 .60792 .76824 .61137 .77488 .60958 .77196 .60613 Mtetra
.77196 .60613 .77488 .60958 .78154 .6078 .77864 .60434 Mtetra
.77864 .60434 .78154 .6078 .78822 .60601 .78533 .60254 Mtetra
.78533 .60254 .78822 .60601 .79492 .60423 .79203 .60075 Mtetra
.64 .759 .935 r
.79203 .60075 .79492 .60423 .80163 .60244 .79875 .59895 Mtetra
.79875 .59895 .80163 .60244 .80835 .60065 .80549 .59715 Mtetra
.80549 .59715 .80835 .60065 .81509 .59886 .81224 .59535 Mtetra
.81224 .59535 .81509 .59886 .82185 .59707 .81901 .59356 Mtetra
.639 .759 .935 r
.81901 .59356 .82185 .59707 .82863 .59528 .8258 .59175 Mtetra
.8258 .59175 .82863 .59528 .83542 .59348 .8326 .58995 Mtetra
.8326 .58995 .83542 .59348 .84223 .59168 .83942 .58815 Mtetra
.64 .759 .935 r
.83942 .58815 .84223 .59168 .84905 .58987 .84626 .58633 Mtetra
.641 .759 .934 r
.84626 .58633 .84905 .58987 .85589 .58804 .85311 .58449 Mtetra
.645 .761 .933 r
.85311 .58449 .85589 .58804 .86274 .58614 .85997 .58258 Mtetra
.649 .762 .932 r
.85997 .58258 .86274 .58614 .8696 .58419 .86684 .58062 Mtetra
.671 .771 .925 r
.86684 .58062 .8696 .58419 .87644 .58186 .87369 .57828 Mtetra
.696 .78 .916 r
.87369 .57828 .87644 .58186 .88324 .5791 .8805 .57551 Mtetra
.731 .792 .901 r
.8805 .57551 .88324 .5791 .88999 .57566 .88726 .57206 Mtetra
.811 .813 .853 r
.88726 .57206 .88999 .57566 .89653 .57022 .89382 .56661 Mtetra
.853 .82 .815 r
.89382 .56661 .89653 .57022 .90289 .56323 .9002 .5596 Mtetra
.917 .818 .734 r
.9002 .5596 .90289 .56323 .90883 .55248 .90615 .54883 Mtetra
.954 .804 .656 r
.90615 .54883 .90883 .55248 .9142 .53703 .91154 .53335 Mtetra
.967 .793 .616 r
.91154 .53335 .9142 .53703 .91916 .51848 .91652 .51478 Mtetra
.982 .768 .54 r
.91652 .51478 .91916 .51848 .92306 .4915 .92045 .48776 Mtetra
.985 .759 .516 r
.92045 .48776 .92306 .4915 .92644 .46098 .92385 .45721 Mtetra
.943 .627 .409 r
.31637 .6086 .31983 .61168 .32352 .64033 .32003 .63728 Mtetra
.942 .619 .394 r
.32003 .63728 .32352 .64033 .32746 .66659 .32394 .66356 Mtetra
.935 .58 .321 r
.32394 .66356 .32746 .66659 .33191 .68509 .32839 .68208 Mtetra
.925 .547 .264 r
.32839 .68208 .33191 .68509 .33662 .70038 .33308 .69738 Mtetra
.875 .435 .086 r
.33308 .69738 .33662 .70038 .34165 .71059 .33811 .70759 Mtetra
.619 .095 0 r
.33811 .70759 .34165 .71059 .34697 .71621 .34342 .71321 Mtetra
0 .228 .695 r
.34342 .71321 .34697 .71621 .35241 .71986 .34887 .71687 Mtetra
.343 .641 .964 r
.34887 .71687 .35241 .71986 .35802 .72074 .35448 .71774 Mtetra
.499 .712 .966 r
.35448 .71774 .35802 .72074 .36369 .7206 .36016 .7176 Mtetra
.574 .74 .955 r
.36016 .7176 .36369 .7206 .36941 .7198 .36588 .7168 Mtetra
.632 .758 .938 r
.36588 .7168 .36941 .7198 .37517 .71836 .37165 .71535 Mtetra
.64 .76 .935 r
.37165 .71535 .37517 .71836 .38094 .71683 .37743 .71381 Mtetra
.648 .762 .932 r
.37743 .71381 .38094 .71683 .38673 .71518 .38323 .71215 Mtetra
.652 .763 .93 r
.38323 .71215 .38673 .71518 .39254 .71347 .38905 .71044 Mtetra
.653 .763 .93 r
.38905 .71044 .39254 .71347 .39836 .71174 .39487 .70871 Mtetra
.39487 .70871 .39836 .71174 .40419 .71001 .40071 .70697 Mtetra
.654 .763 .93 r
.40071 .70697 .40419 .71001 .41004 .70828 .40657 .70523 Mtetra
.40657 .70523 .41004 .70828 .4159 .70653 .41243 .70348 Mtetra
.652 .763 .931 r
.41243 .70348 .4159 .70653 .42177 .7048 .41831 .70174 Mtetra
.653 .763 .93 r
.41831 .70174 .42177 .7048 .42765 .70307 .4242 .7 Mtetra
.4242 .7 .42765 .70307 .43354 .70132 .4301 .69825 Mtetra
.652 .763 .931 r
.4301 .69825 .43354 .70132 .43945 .69959 .43602 .69651 Mtetra
.43602 .69651 .43945 .69959 .44537 .69785 .44195 .69476 Mtetra
.44195 .69476 .44537 .69785 .4513 .6961 .44789 .69301 Mtetra
.651 .763 .931 r
.44789 .69301 .4513 .6961 .45725 .69437 .45384 .69127 Mtetra
.45384 .69127 .45725 .69437 .4632 .69263 .4598 .68953 Mtetra
.652 .763 .931 r
.4598 .68953 .4632 .69263 .46917 .69088 .46578 .68777 Mtetra
.651 .763 .931 r
.46578 .68777 .46917 .69088 .47516 .68914 .47177 .68602 Mtetra
.65 .763 .931 r
.47177 .68602 .47516 .68914 .48115 .68741 .47778 .68428 Mtetra
.651 .763 .931 r
.47778 .68428 .48115 .68741 .48716 .68566 .4838 .68252 Mtetra
.65 .763 .931 r
.4838 .68252 .48716 .68566 .49318 .68391 .48983 .68077 Mtetra
.649 .762 .932 r
.48983 .68077 .49318 .68391 .49922 .68217 .49587 .67902 Mtetra
.65 .763 .931 r
.49587 .67902 .49922 .68217 .50527 .68042 .50193 .67726 Mtetra
.65 .762 .932 r
.50193 .67726 .50527 .68042 .51133 .67867 .508 .67551 Mtetra
.649 .762 .932 r
.508 .67551 .51133 .67867 .5174 .67693 .51408 .67376 Mtetra
.51408 .67376 .5174 .67693 .52349 .67518 .52018 .672 Mtetra
.52018 .672 .52349 .67518 .52959 .67342 .52629 .67024 Mtetra
.648 .762 .932 r
.52629 .67024 .52959 .67342 .53571 .67168 .53241 .66849 Mtetra
.649 .762 .932 r
.53241 .66849 .53571 .67168 .54183 .66993 .53855 .66673 Mtetra
.53855 .66673 .54183 .66993 .54798 .66816 .5447 .66496 Mtetra
.647 .762 .932 r
.5447 .66496 .54798 .66816 .55413 .66642 .55086 .66321 Mtetra
.648 .762 .932 r
.55086 .66321 .55413 .66642 .5603 .66467 .55704 .66145 Mtetra
.55704 .66145 .5603 .66467 .56648 .6629 .56323 .65967 Mtetra
.647 .762 .933 r
.56323 .65967 .56648 .6629 .57268 .66115 .56944 .65792 Mtetra
.56944 .65792 .57268 .66115 .57889 .6594 .57566 .65615 Mtetra
.648 .762 .932 r
.57566 .65615 .57889 .6594 .58511 .65763 .58189 .65438 Mtetra
.647 .762 .933 r
.58189 .65438 .58511 .65763 .59135 .65587 .58814 .65262 Mtetra
.646 .761 .933 r
.58814 .65262 .59135 .65587 .59761 .65412 .5944 .65085 Mtetra
.647 .762 .933 r
.5944 .65085 .59761 .65412 .60387 .65235 .60068 .64908 Mtetra
.646 .761 .933 r
.60068 .64908 .60387 .65235 .61015 .65058 .60697 .6473 Mtetra
.645 .761 .933 r
.60697 .6473 .61015 .65058 .61645 .64883 .61327 .64554 Mtetra
.646 .761 .933 r
.61327 .64554 .61645 .64883 .62276 .64705 .61959 .64376 Mtetra
.61959 .64376 .62276 .64705 .62908 .64528 .62592 .64198 Mtetra
.645 .761 .933 r
.62592 .64198 .62908 .64528 .63542 .64352 .63227 .64022 Mtetra
.646 .761 .933 r
.63227 .64022 .63542 .64352 .64177 .64175 .63863 .63844 Mtetra
.63863 .63844 .64177 .64175 .64814 .63997 .64501 .63665 Mtetra
.644 .761 .933 r
.64501 .63665 .64814 .63997 .65452 .63821 .6514 .63488 Mtetra
.645 .761 .933 r
.6514 .63488 .65452 .63821 .66092 .63644 .65781 .6331 Mtetra
.65781 .6331 .66092 .63644 .66733 .63465 .66423 .63131 Mtetra
.644 .76 .934 r
.66423 .63131 .66733 .63465 .67375 .63289 .67067 .62954 Mtetra
.644 .761 .934 r
.67067 .62954 .67375 .63289 .68019 .63111 .67712 .62775 Mtetra
.645 .761 .933 r
.67712 .62775 .68019 .63111 .68665 .62932 .68358 .62596 Mtetra
.643 .76 .934 r
.68358 .62596 .68665 .62932 .69312 .62755 .69006 .62418 Mtetra
.69006 .62418 .69312 .62755 .6996 .62578 .69656 .6224 Mtetra
.69656 .6224 .6996 .62578 .70611 .624 .70307 .62061 Mtetra
.70307 .62061 .70611 .624 .71262 .62222 .7096 .61882 Mtetra
.7096 .61882 .71262 .62222 .71915 .62043 .71614 .61703 Mtetra
.71614 .61703 .71915 .62043 .7257 .61865 .7227 .61524 Mtetra
.642 .76 .934 r
.7227 .61524 .7257 .61865 .73226 .61686 .72927 .61344 Mtetra
.72927 .61344 .73226 .61686 .73884 .61508 .73586 .61165 Mtetra
.73586 .61165 .73884 .61508 .74543 .61329 .74246 .60985 Mtetra
.74246 .60985 .74543 .61329 .75204 .6115 .74908 .60806 Mtetra
.74908 .60806 .75204 .6115 .75867 .60971 .75572 .60626 Mtetra
.641 .76 .934 r
.75572 .60626 .75867 .60971 .76531 .60792 .76237 .60446 Mtetra
.76237 .60446 .76531 .60792 .77196 .60613 .76903 .60266 Mtetra
.641 .759 .934 r
.76903 .60266 .77196 .60613 .77864 .60434 .77572 .60086 Mtetra
.77572 .60086 .77864 .60434 .78533 .60254 .78242 .59906 Mtetra
.641 .759 .935 r
.78242 .59906 .78533 .60254 .79203 .60075 .78913 .59725 Mtetra
.64 .759 .935 r
.78913 .59725 .79203 .60075 .79875 .59895 .79586 .59545 Mtetra
.79586 .59545 .79875 .59895 .80549 .59715 .80261 .59364 Mtetra
.80261 .59364 .80549 .59715 .81224 .59535 .80938 .59184 Mtetra
.80938 .59184 .81224 .59535 .81901 .59356 .81616 .59003 Mtetra
.639 .759 .935 r
.81616 .59003 .81901 .59356 .8258 .59175 .82296 .58822 Mtetra
.82296 .58822 .8258 .59175 .8326 .58995 .82977 .58641 Mtetra
.82977 .58641 .8326 .58995 .83942 .58815 .8366 .58459 Mtetra
.64 .759 .935 r
.8366 .58459 .83942 .58815 .84626 .58633 .84345 .58277 Mtetra
.641 .759 .934 r
.84345 .58277 .84626 .58633 .85311 .58449 .85031 .58092 Mtetra
.645 .761 .933 r
.85031 .58092 .85311 .58449 .85997 .58258 .85718 .579 Mtetra
.649 .762 .932 r
.85718 .579 .85997 .58258 .86684 .58062 .86406 .57703 Mtetra
.672 .771 .925 r
.86406 .57703 .86684 .58062 .87369 .57828 .87092 .57468 Mtetra
.696 .781 .916 r
.87092 .57468 .87369 .57828 .8805 .57551 .87775 .5719 Mtetra
.731 .792 .901 r
.87775 .5719 .8805 .57551 .88726 .57206 .88453 .56845 Mtetra
.811 .813 .853 r
.88453 .56845 .88726 .57206 .89382 .56661 .89109 .56298 Mtetra
.854 .82 .815 r
.89109 .56298 .89382 .56661 .9002 .5596 .89749 .55595 Mtetra
.917 .818 .734 r
.89749 .55595 .9002 .5596 .90615 .54883 .90346 .54517 Mtetra
.954 .804 .656 r
.90346 .54517 .90615 .54883 .91154 .53335 .90887 .52967 Mtetra
.967 .793 .616 r
.90887 .52967 .91154 .53335 .91652 .51478 .91387 .51106 Mtetra
.982 .768 .54 r
.91387 .51106 .91652 .51478 .92045 .48776 .91782 .48401 Mtetra
.985 .759 .516 r
.91782 .48401 .92045 .48776 .92385 .45721 .92125 .45342 Mtetra
.943 .627 .409 r
.31289 .60551 .31637 .6086 .32003 .63728 .31653 .63421 Mtetra
.942 .619 .394 r
.31653 .63421 .32003 .63728 .32394 .66356 .32042 .66051 Mtetra
.935 .58 .321 r
.32042 .66051 .32394 .66356 .32839 .68208 .32485 .67905 Mtetra
.925 .547 .264 r
.32485 .67905 .32839 .68208 .33308 .69738 .32953 .69436 Mtetra
.875 .435 .086 r
.32953 .69436 .33308 .69738 .33811 .70759 .33455 .70459 Mtetra
.619 .095 0 r
.33455 .70459 .33811 .70759 .34342 .71321 .33986 .71021 Mtetra
0 .228 .695 r
.33986 .71021 .34342 .71321 .34887 .71687 .34531 .71387 Mtetra
.342 .641 .964 r
.34531 .71387 .34887 .71687 .35448 .71774 .35093 .71474 Mtetra
.498 .712 .966 r
.35093 .71474 .35448 .71774 .36016 .7176 .35661 .71459 Mtetra
.573 .74 .955 r
.35661 .71459 .36016 .7176 .36588 .7168 .36234 .71378 Mtetra
.632 .758 .938 r
.36234 .71378 .36588 .7168 .37165 .71535 .36811 .71233 Mtetra
.639 .76 .935 r
.36811 .71233 .37165 .71535 .37743 .71381 .3739 .71078 Mtetra
.648 .762 .932 r
.3739 .71078 .37743 .71381 .38323 .71215 .37971 .70912 Mtetra
.652 .763 .931 r
.37971 .70912 .38323 .71215 .38905 .71044 .38554 .7074 Mtetra
.653 .763 .93 r
.38554 .7074 .38905 .71044 .39487 .70871 .39137 .70566 Mtetra
.39137 .70566 .39487 .70871 .40071 .70697 .39722 .70392 Mtetra
.654 .763 .93 r
.39722 .70392 .40071 .70697 .40657 .70523 .40308 .70217 Mtetra
.40308 .70217 .40657 .70523 .41243 .70348 .40896 .70041 Mtetra
.652 .763 .931 r
.40896 .70041 .41243 .70348 .41831 .70174 .41484 .69867 Mtetra
.653 .763 .93 r
.41484 .69867 .41831 .70174 .4242 .7 .42074 .69692 Mtetra
.42074 .69692 .4242 .7 .4301 .69825 .42665 .69516 Mtetra
.652 .763 .931 r
.42665 .69516 .4301 .69825 .43602 .69651 .43257 .69342 Mtetra
.43257 .69342 .43602 .69651 .44195 .69476 .43851 .69167 Mtetra
.43851 .69167 .44195 .69476 .44789 .69301 .44446 .6899 Mtetra
.651 .763 .931 r
.44446 .6899 .44789 .69301 .45384 .69127 .45042 .68816 Mtetra
.45042 .68816 .45384 .69127 .4598 .68953 .45639 .68641 Mtetra
.652 .763 .931 r
.45639 .68641 .4598 .68953 .46578 .68777 .46238 .68464 Mtetra
.651 .763 .931 r
.46238 .68464 .46578 .68777 .47177 .68602 .46838 .68289 Mtetra
.65 .763 .931 r
.46838 .68289 .47177 .68602 .47778 .68428 .47439 .68114 Mtetra
.651 .763 .931 r
.47439 .68114 .47778 .68428 .4838 .68252 .48042 .67937 Mtetra
.65 .763 .931 r
.48042 .67937 .4838 .68252 .48983 .68077 .48646 .67762 Mtetra
.649 .762 .932 r
.48646 .67762 .48983 .68077 .49587 .67902 .49251 .67586 Mtetra
.65 .763 .931 r
.49251 .67586 .49587 .67902 .50193 .67726 .49858 .6741 Mtetra
.65 .762 .932 r
.49858 .6741 .50193 .67726 .508 .67551 .50466 .67233 Mtetra
.649 .762 .932 r
.50466 .67233 .508 .67551 .51408 .67376 .51075 .67058 Mtetra
.51075 .67058 .51408 .67376 .52018 .672 .51685 .66881 Mtetra
.51685 .66881 .52018 .672 .52629 .67024 .52297 .66704 Mtetra
.648 .762 .932 r
.52297 .66704 .52629 .67024 .53241 .66849 .5291 .66529 Mtetra
.649 .762 .932 r
.5291 .66529 .53241 .66849 .53855 .66673 .53525 .66352 Mtetra
.53525 .66352 .53855 .66673 .5447 .66496 .54141 .66174 Mtetra
.647 .762 .932 r
.54141 .66174 .5447 .66496 .55086 .66321 .54758 .65998 Mtetra
.648 .762 .932 r
.54758 .65998 .55086 .66321 .55704 .66145 .55377 .65821 Mtetra
.55377 .65821 .55704 .66145 .56323 .65967 .55997 .65644 Mtetra
.647 .762 .933 r
.55997 .65644 .56323 .65967 .56944 .65792 .56619 .65467 Mtetra
.56619 .65467 .56944 .65792 .57566 .65615 .57242 .6529 Mtetra
.648 .762 .932 r
.57242 .6529 .57566 .65615 .58189 .65438 .57866 .65112 Mtetra
.647 .762 .933 r
.57866 .65112 .58189 .65438 .58814 .65262 .58492 .64935 Mtetra
.646 .761 .933 r
.58492 .64935 .58814 .65262 .5944 .65085 .59119 .64758 Mtetra
.647 .762 .933 r
.59119 .64758 .5944 .65085 .60068 .64908 .59747 .64579 Mtetra
.646 .761 .933 r
.59747 .64579 .60068 .64908 .60697 .6473 .60377 .64401 Mtetra
.645 .761 .933 r
.60377 .64401 .60697 .6473 .61327 .64554 .61009 .64224 Mtetra
.646 .761 .933 r
.61009 .64224 .61327 .64554 .61959 .64376 .61641 .64046 Mtetra
.61641 .64046 .61959 .64376 .62592 .64198 .62276 .63867 Mtetra
.645 .761 .933 r
.62276 .63867 .62592 .64198 .63227 .64022 .62911 .6369 Mtetra
.646 .761 .933 r
.62911 .6369 .63227 .64022 .63863 .63844 .63549 .63511 Mtetra
.63549 .63511 .63863 .63844 .64501 .63665 .64187 .63332 Mtetra
.644 .761 .934 r
.64187 .63332 .64501 .63665 .6514 .63488 .64827 .63154 Mtetra
.645 .761 .933 r
.64827 .63154 .6514 .63488 .65781 .6331 .65469 .62975 Mtetra
.65469 .62975 .65781 .6331 .66423 .63131 .66112 .62795 Mtetra
.644 .761 .934 r
.66112 .62795 .66423 .63131 .67067 .62954 .66757 .62617 Mtetra
.66757 .62617 .67067 .62954 .67712 .62775 .67403 .62438 Mtetra
.645 .761 .933 r
.67403 .62438 .67712 .62775 .68358 .62596 .6805 .62258 Mtetra
.643 .76 .934 r
.6805 .62258 .68358 .62596 .69006 .62418 .68699 .62079 Mtetra
.68699 .62079 .69006 .62418 .69656 .6224 .6935 .619 Mtetra
.6935 .619 .69656 .6224 .70307 .62061 .70002 .6172 Mtetra
.70002 .6172 .70307 .62061 .7096 .61882 .70656 .61541 Mtetra
.70656 .61541 .7096 .61882 .71614 .61703 .71311 .61361 Mtetra
.71311 .61361 .71614 .61703 .7227 .61524 .71968 .61181 Mtetra
.642 .76 .934 r
.71968 .61181 .7227 .61524 .72927 .61344 .72626 .61001 Mtetra
.72626 .61001 .72927 .61344 .73586 .61165 .73286 .6082 Mtetra
.73286 .6082 .73586 .61165 .74246 .60985 .73947 .6064 Mtetra
.73947 .6064 .74246 .60985 .74908 .60806 .7461 .6046 Mtetra
.7461 .6046 .74908 .60806 .75572 .60626 .75275 .60279 Mtetra
.641 .76 .934 r
.75275 .60279 .75572 .60626 .76237 .60446 .75941 .60098 Mtetra
.75941 .60098 .76237 .60446 .76903 .60266 .76609 .59917 Mtetra
.641 .759 .934 r
.76609 .59917 .76903 .60266 .77572 .60086 .77279 .59737 Mtetra
.641 .759 .935 r
.77279 .59737 .77572 .60086 .78242 .59906 .7795 .59556 Mtetra
.7795 .59556 .78242 .59906 .78913 .59725 .78622 .59374 Mtetra
.64 .759 .935 r
.78622 .59374 .78913 .59725 .79586 .59545 .79296 .59193 Mtetra
.79296 .59193 .79586 .59545 .80261 .59364 .79972 .59012 Mtetra
.79972 .59012 .80261 .59364 .80938 .59184 .8065 .5883 Mtetra
.8065 .5883 .80938 .59184 .81616 .59003 .81329 .58649 Mtetra
.639 .759 .935 r
.81329 .58649 .81616 .59003 .82296 .58822 .8201 .58467 Mtetra
.8201 .58467 .82296 .58822 .82977 .58641 .82693 .58285 Mtetra
.82693 .58285 .82977 .58641 .8366 .58459 .83377 .58103 Mtetra
.64 .759 .935 r
.83377 .58103 .8366 .58459 .84345 .58277 .84063 .57919 Mtetra
.641 .759 .934 r
.84063 .57919 .84345 .58277 .85031 .58092 .8475 .57734 Mtetra
.645 .761 .933 r
.8475 .57734 .85031 .58092 .85718 .579 .85438 .57541 Mtetra
.649 .762 .932 r
.85438 .57541 .85718 .579 .86406 .57703 .86128 .57343 Mtetra
.672 .771 .925 r
.86128 .57343 .86406 .57703 .87092 .57468 .86815 .57107 Mtetra
.696 .781 .916 r
.86815 .57107 .87092 .57468 .87775 .5719 .87499 .56828 Mtetra
.731 .792 .901 r
.87499 .56828 .87775 .5719 .88453 .56845 .88178 .56481 Mtetra
.811 .813 .853 r
.88178 .56481 .88453 .56845 .89109 .56298 .88836 .55933 Mtetra
.854 .82 .815 r
.88836 .55933 .89109 .56298 .89749 .55595 .89477 .55229 Mtetra
.917 .818 .734 r
.89477 .55229 .89749 .55595 .90346 .54517 .90075 .54149 Mtetra
.954 .804 .656 r
.90075 .54149 .90346 .54517 .90887 .52967 .90618 .52596 Mtetra
.967 .793 .616 r
.90618 .52596 .90887 .52967 .91387 .51106 .91121 .50733 Mtetra
.982 .768 .54 r
.91121 .50733 .91387 .51106 .91782 .48401 .91518 .48024 Mtetra
.985 .759 .516 r
.91518 .48024 .91782 .48401 .92125 .45342 .91864 .44962 Mtetra
.943 .627 .409 r
.30941 .60241 .31289 .60551 .31653 .63421 .31302 .63114 Mtetra
.942 .619 .394 r
.31302 .63114 .31653 .63421 .32042 .66051 .31688 .65746 Mtetra
.935 .58 .321 r
.31688 .65746 .32042 .66051 .32485 .67905 .32129 .67601 Mtetra
.925 .547 .264 r
.32129 .67601 .32485 .67905 .32953 .69436 .32596 .69134 Mtetra
.875 .435 .087 r
.32596 .69134 .32953 .69436 .33455 .70459 .33098 .70157 Mtetra
.619 .095 0 r
.33098 .70157 .33455 .70459 .33986 .71021 .33629 .7072 Mtetra
0 .227 .694 r
.33629 .7072 .33986 .71021 .34531 .71387 .34174 .71085 Mtetra
.342 .641 .964 r
.34174 .71085 .34531 .71387 .35093 .71474 .34736 .71172 Mtetra
.498 .712 .966 r
.34736 .71172 .35093 .71474 .35661 .71459 .35305 .71157 Mtetra
.573 .74 .955 r
.35305 .71157 .35661 .71459 .36234 .71378 .35879 .71076 Mtetra
.632 .758 .938 r
.35879 .71076 .36234 .71378 .36811 .71233 .36457 .7093 Mtetra
.639 .76 .935 r
.36457 .7093 .36811 .71233 .3739 .71078 .37037 .70775 Mtetra
.648 .762 .932 r
.37037 .70775 .3739 .71078 .37971 .70912 .37618 .70608 Mtetra
.652 .763 .931 r
.37618 .70608 .37971 .70912 .38554 .7074 .38201 .70435 Mtetra
.653 .763 .93 r
.38201 .70435 .38554 .7074 .39137 .70566 .38786 .7026 Mtetra
.38786 .7026 .39137 .70566 .39722 .70392 .39371 .70086 Mtetra
.654 .763 .93 r
.39371 .70086 .39722 .70392 .40308 .70217 .39958 .6991 Mtetra
.39958 .6991 .40308 .70217 .40896 .70041 .40546 .69733 Mtetra
.652 .763 .931 r
.40546 .69733 .40896 .70041 .41484 .69867 .41136 .69559 Mtetra
.653 .763 .93 r
.41136 .69559 .41484 .69867 .42074 .69692 .41726 .69383 Mtetra
.41726 .69383 .42074 .69692 .42665 .69516 .42318 .69206 Mtetra
.652 .763 .931 r
.42318 .69206 .42665 .69516 .43257 .69342 .42911 .69031 Mtetra
.42911 .69031 .43257 .69342 .43851 .69167 .43506 .68855 Mtetra
.43506 .68855 .43851 .69167 .44446 .6899 .44102 .68679 Mtetra
.651 .763 .931 r
.44102 .68679 .44446 .6899 .45042 .68816 .44698 .68503 Mtetra
.44698 .68503 .45042 .68816 .45639 .68641 .45297 .68327 Mtetra
.652 .763 .931 r
.45297 .68327 .45639 .68641 .46238 .68464 .45896 .6815 Mtetra
.651 .763 .931 r
.45896 .6815 .46238 .68464 .46838 .68289 .46497 .67974 Mtetra
.65 .763 .931 r
.46497 .67974 .46838 .68289 .47439 .68114 .47099 .67799 Mtetra
.651 .763 .931 r
.47099 .67799 .47439 .68114 .48042 .67937 .47703 .67621 Mtetra
.65 .763 .931 r
.47703 .67621 .48042 .67937 .48646 .67762 .48308 .67445 Mtetra
.649 .762 .932 r
.48308 .67445 .48646 .67762 .49251 .67586 .48914 .67269 Mtetra
.65 .763 .932 r
.48914 .67269 .49251 .67586 .49858 .6741 .49521 .67092 Mtetra
.49521 .67092 .49858 .6741 .50466 .67233 .5013 .66915 Mtetra
.649 .762 .932 r
.5013 .66915 .50466 .67233 .51075 .67058 .5074 .66738 Mtetra
.5074 .66738 .51075 .67058 .51685 .66881 .51351 .66561 Mtetra
.51351 .66561 .51685 .66881 .52297 .66704 .51964 .66383 Mtetra
.648 .762 .932 r
.51964 .66383 .52297 .66704 .5291 .66529 .52578 .66207 Mtetra
.649 .762 .932 r
.52578 .66207 .5291 .66529 .53525 .66352 .53194 .6603 Mtetra
.53194 .6603 .53525 .66352 .54141 .66174 .53811 .65851 Mtetra
.647 .762 .932 r
.53811 .65851 .54141 .66174 .54758 .65998 .54429 .65675 Mtetra
.648 .762 .932 r
.54429 .65675 .54758 .65998 .55377 .65821 .55049 .65497 Mtetra
.55049 .65497 .55377 .65821 .55997 .65644 .5567 .65318 Mtetra
.647 .762 .933 r
.5567 .65318 .55997 .65644 .56619 .65467 .56292 .65141 Mtetra
.56292 .65141 .56619 .65467 .57242 .6529 .56916 .64964 Mtetra
.648 .762 .932 r
.56916 .64964 .57242 .6529 .57866 .65112 .57541 .64785 Mtetra
.647 .762 .933 r
.57541 .64785 .57866 .65112 .58492 .64935 .58168 .64607 Mtetra
.646 .761 .933 r
.58168 .64607 .58492 .64935 .59119 .64758 .58796 .64429 Mtetra
.647 .762 .933 r
.58796 .64429 .59119 .64758 .59747 .64579 .59425 .6425 Mtetra
.646 .761 .933 r
.59425 .6425 .59747 .64579 .60377 .64401 .60056 .64071 Mtetra
.645 .761 .933 r
.60056 .64071 .60377 .64401 .61009 .64224 .60689 .63893 Mtetra
.646 .762 .933 r
.60689 .63893 .61009 .64224 .61641 .64046 .61322 .63714 Mtetra
.646 .761 .933 r
.61322 .63714 .61641 .64046 .62276 .63867 .61958 .63535 Mtetra
.645 .761 .933 r
.61958 .63535 .62276 .63867 .62911 .6369 .62594 .63356 Mtetra
.646 .761 .933 r
.62594 .63356 .62911 .6369 .63549 .63511 .63232 .63177 Mtetra
.63232 .63177 .63549 .63511 .64187 .63332 .63872 .62997 Mtetra
.644 .761 .934 r
.63872 .62997 .64187 .63332 .64827 .63154 .64513 .62818 Mtetra
.645 .761 .933 r
.64513 .62818 .64827 .63154 .65469 .62975 .65156 .62639 Mtetra
.65156 .62639 .65469 .62975 .66112 .62795 .658 .62458 Mtetra
.644 .761 .934 r
.658 .62458 .66112 .62795 .66757 .62617 .66445 .62279 Mtetra
.66445 .62279 .66757 .62617 .67403 .62438 .67092 .62099 Mtetra
.645 .761 .933 r
.67092 .62099 .67403 .62438 .6805 .62258 .67741 .61918 Mtetra
.643 .76 .934 r
.67741 .61918 .6805 .62258 .68699 .62079 .68391 .61739 Mtetra
.68391 .61739 .68699 .62079 .6935 .619 .69043 .61559 Mtetra
.69043 .61559 .6935 .619 .70002 .6172 .69696 .61379 Mtetra
.69696 .61379 .70002 .6172 .70656 .61541 .70351 .61198 Mtetra
.70351 .61198 .70656 .61541 .71311 .61361 .71007 .61017 Mtetra
.71007 .61017 .71311 .61361 .71968 .61181 .71665 .60837 Mtetra
.642 .76 .934 r
.71665 .60837 .71968 .61181 .72626 .61001 .72324 .60656 Mtetra
.72324 .60656 .72626 .61001 .73286 .6082 .72985 .60475 Mtetra
.72985 .60475 .73286 .6082 .73947 .6064 .73648 .60294 Mtetra
.73648 .60294 .73947 .6064 .7461 .6046 .74312 .60112 Mtetra
.74312 .60112 .7461 .6046 .75275 .60279 .74977 .59931 Mtetra
.641 .76 .934 r
.74977 .59931 .75275 .60279 .75941 .60098 .75645 .59749 Mtetra
.75645 .59749 .75941 .60098 .76609 .59917 .76314 .59568 Mtetra
.76314 .59568 .76609 .59917 .77279 .59737 .76984 .59386 Mtetra
.641 .759 .935 r
.76984 .59386 .77279 .59737 .7795 .59556 .77656 .59204 Mtetra
.77656 .59204 .7795 .59556 .78622 .59374 .7833 .59022 Mtetra
.64 .759 .935 r
.7833 .59022 .78622 .59374 .79296 .59193 .79005 .5884 Mtetra
.79005 .5884 .79296 .59193 .79972 .59012 .79682 .58658 Mtetra
.79682 .58658 .79972 .59012 .8065 .5883 .80361 .58475 Mtetra
.80361 .58475 .8065 .5883 .81329 .58649 .81041 .58293 Mtetra
.639 .759 .935 r
.81041 .58293 .81329 .58649 .8201 .58467 .81723 .5811 Mtetra
.81723 .5811 .8201 .58467 .82693 .58285 .82407 .57928 Mtetra
.82407 .57928 .82693 .58285 .83377 .58103 .83092 .57745 Mtetra
.64 .759 .935 r
.83092 .57745 .83377 .58103 .84063 .57919 .83779 .5756 Mtetra
.641 .759 .934 r
.83779 .5756 .84063 .57919 .8475 .57734 .84468 .57374 Mtetra
.645 .761 .933 r
.84468 .57374 .8475 .57734 .85438 .57541 .85157 .5718 Mtetra
.649 .762 .932 r
.85157 .5718 .85438 .57541 .86128 .57343 .85848 .56981 Mtetra
.672 .772 .925 r
.85848 .56981 .86128 .57343 .86815 .57107 .86536 .56745 Mtetra
.696 .781 .916 r
.86536 .56745 .86815 .57107 .87499 .56828 .87222 .56465 Mtetra
.731 .793 .901 r
.87222 .56465 .87499 .56828 .88178 .56481 .87902 .56117 Mtetra
.811 .814 .853 r
.87902 .56117 .88178 .56481 .88836 .55933 .88561 .55567 Mtetra
.854 .82 .815 r
.88561 .55567 .88836 .55933 .89477 .55229 .89204 .54862 Mtetra
.917 .818 .734 r
.89204 .54862 .89477 .55229 .90075 .54149 .89804 .53779 Mtetra
.954 .804 .656 r
.89804 .53779 .90075 .54149 .90618 .52596 .90349 .52225 Mtetra
.967 .793 .616 r
.90349 .52225 .90618 .52596 .91121 .50733 .90853 .50359 Mtetra
.982 .768 .54 r
.90853 .50359 .91121 .50733 .91518 .48024 .91253 .47646 Mtetra
.985 .76 .516 r
.91253 .47646 .91518 .48024 .91864 .44962 .91601 .4458 Mtetra
.943 .627 .409 r
.30591 .5993 .30941 .60241 .31302 .63114 .30949 .62805 Mtetra
.942 .619 .394 r
.30949 .62805 .31302 .63114 .31688 .65746 .31332 .6544 Mtetra
.935 .58 .322 r
.31332 .6544 .31688 .65746 .32129 .67601 .31772 .67296 Mtetra
.925 .547 .264 r
.31772 .67296 .32129 .67601 .32596 .69134 .32238 .68831 Mtetra
.875 .435 .087 r
.32238 .68831 .32596 .69134 .33098 .70157 .32739 .69854 Mtetra
.619 .095 0 r
.32739 .69854 .33098 .70157 .33629 .7072 .3327 .70417 Mtetra
0 .227 .694 r
.3327 .70417 .33629 .7072 .34174 .71085 .33815 .70783 Mtetra
.342 .641 .964 r
.33815 .70783 .34174 .71085 .34736 .71172 .34378 .7087 Mtetra
.498 .712 .966 r
.34378 .7087 .34736 .71172 .35305 .71157 .34947 .70854 Mtetra
.573 .74 .955 r
.34947 .70854 .35305 .71157 .35879 .71076 .35522 .70772 Mtetra
.632 .758 .938 r
.35522 .70772 .35879 .71076 .36457 .7093 .361 .70626 Mtetra
.639 .76 .935 r
.361 .70626 .36457 .7093 .37037 .70775 .36681 .7047 Mtetra
.648 .762 .932 r
.36681 .7047 .37037 .70775 .37618 .70608 .37264 .70302 Mtetra
.652 .763 .931 r
.37264 .70302 .37618 .70608 .38201 .70435 .37847 .70128 Mtetra
.653 .763 .93 r
.37847 .70128 .38201 .70435 .38786 .7026 .38433 .69953 Mtetra
.38433 .69953 .38786 .7026 .39371 .70086 .39019 .69778 Mtetra
.654 .763 .93 r
.39019 .69778 .39371 .70086 .39958 .6991 .39607 .69601 Mtetra
.654 .764 .93 r
.39607 .69601 .39958 .6991 .40546 .69733 .40196 .69425 Mtetra
.652 .763 .931 r
.40196 .69425 .40546 .69733 .41136 .69559 .40786 .69249 Mtetra
.653 .763 .931 r
.40786 .69249 .41136 .69559 .41726 .69383 .41377 .69073 Mtetra
.653 .763 .93 r
.41377 .69073 .41726 .69383 .42318 .69206 .4197 .68895 Mtetra
.652 .763 .931 r
.4197 .68895 .42318 .69206 .42911 .69031 .42564 .6872 Mtetra
.42564 .6872 .42911 .69031 .43506 .68855 .43159 .68543 Mtetra
.43159 .68543 .43506 .68855 .44102 .68679 .43756 .68366 Mtetra
.651 .763 .931 r
.43756 .68366 .44102 .68679 .44698 .68503 .44354 .68189 Mtetra
.44354 .68189 .44698 .68503 .45297 .68327 .44953 .68013 Mtetra
.652 .763 .931 r
.44953 .68013 .45297 .68327 .45896 .6815 .45553 .67835 Mtetra
.651 .763 .931 r
.45553 .67835 .45896 .6815 .46497 .67974 .46155 .67659 Mtetra
.65 .763 .932 r
.46155 .67659 .46497 .67974 .47099 .67799 .46758 .67482 Mtetra
.651 .763 .931 r
.46758 .67482 .47099 .67799 .47703 .67621 .47362 .67304 Mtetra
.65 .763 .932 r
.47362 .67304 .47703 .67621 .48308 .67445 .47968 .67127 Mtetra
.649 .762 .932 r
.47968 .67127 .48308 .67445 .48914 .67269 .48575 .66951 Mtetra
.65 .763 .932 r
.48575 .66951 .48914 .67269 .49521 .67092 .49183 .66772 Mtetra
.49183 .66772 .49521 .67092 .5013 .66915 .49793 .66595 Mtetra
.649 .762 .932 r
.49793 .66595 .5013 .66915 .5074 .66738 .50404 .66418 Mtetra
.50404 .66418 .5074 .66738 .51351 .66561 .51016 .6624 Mtetra
.51016 .6624 .51351 .66561 .51964 .66383 .5163 .66061 Mtetra
.648 .762 .932 r
.5163 .66061 .51964 .66383 .52578 .66207 .52245 .65884 Mtetra
.649 .762 .932 r
.52245 .65884 .52578 .66207 .53194 .6603 .52861 .65706 Mtetra
.52861 .65706 .53194 .6603 .53811 .65851 .53479 .65527 Mtetra
.647 .762 .933 r
.53479 .65527 .53811 .65851 .54429 .65675 .54098 .6535 Mtetra
.648 .762 .932 r
.54098 .6535 .54429 .65675 .55049 .65497 .54719 .65171 Mtetra
.54719 .65171 .55049 .65497 .5567 .65318 .55341 .64992 Mtetra
.647 .762 .933 r
.55341 .64992 .5567 .65318 .56292 .65141 .55964 .64814 Mtetra
.55964 .64814 .56292 .65141 .56916 .64964 .56589 .64636 Mtetra
.648 .762 .932 r
.56589 .64636 .56916 .64964 .57541 .64785 .57215 .64456 Mtetra
.647 .762 .933 r
.57215 .64456 .57541 .64785 .58168 .64607 .57843 .64277 Mtetra
.646 .762 .933 r
.57843 .64277 .58168 .64607 .58796 .64429 .58472 .64099 Mtetra
.647 .762 .933 r
.58472 .64099 .58796 .64429 .59425 .6425 .59102 .63919 Mtetra
.646 .762 .933 r
.59102 .63919 .59425 .6425 .60056 .64071 .59734 .6374 Mtetra
.645 .761 .933 r
.59734 .6374 .60056 .64071 .60689 .63893 .60367 .63561 Mtetra
.646 .762 .933 r
.60367 .63561 .60689 .63893 .61322 .63714 .61002 .63381 Mtetra
.646 .761 .933 r
.61002 .63381 .61322 .63714 .61958 .63535 .61638 .63201 Mtetra
.645 .761 .933 r
.61638 .63201 .61958 .63535 .62594 .63356 .62276 .63022 Mtetra
.646 .761 .933 r
.62276 .63022 .62594 .63356 .63232 .63177 .62915 .62841 Mtetra
.62915 .62841 .63232 .63177 .63872 .62997 .63555 .62661 Mtetra
.644 .761 .934 r
.63555 .62661 .63872 .62997 .64513 .62818 .64198 .62481 Mtetra
.645 .761 .933 r
.64198 .62481 .64513 .62818 .65156 .62639 .64841 .62301 Mtetra
.64841 .62301 .65156 .62639 .658 .62458 .65486 .62119 Mtetra
.644 .761 .934 r
.65486 .62119 .658 .62458 .66445 .62279 .66133 .6194 Mtetra
.66133 .6194 .66445 .62279 .67092 .62099 .66781 .61759 Mtetra
.645 .761 .933 r
.66781 .61759 .67092 .62099 .67741 .61918 .67431 .61577 Mtetra
.643 .76 .934 r
.67431 .61577 .67741 .61918 .68391 .61739 .68082 .61397 Mtetra
.68082 .61397 .68391 .61739 .69043 .61559 .68734 .61217 Mtetra
.68734 .61217 .69043 .61559 .69696 .61379 .69389 .61036 Mtetra
.69389 .61036 .69696 .61379 .70351 .61198 .70044 .60854 Mtetra
.70044 .60854 .70351 .61198 .71007 .61017 .70702 .60673 Mtetra
.70702 .60673 .71007 .61017 .71665 .60837 .7136 .60491 Mtetra
.642 .76 .934 r
.7136 .60491 .71665 .60837 .72324 .60656 .72021 .60309 Mtetra
.72021 .60309 .72324 .60656 .72985 .60475 .72683 .60128 Mtetra
.72683 .60128 .72985 .60475 .73648 .60294 .73346 .59946 Mtetra
.73346 .59946 .73648 .60294 .74312 .60112 .74012 .59763 Mtetra
.74012 .59763 .74312 .60112 .74977 .59931 .74678 .59581 Mtetra
.641 .76 .934 r
.74678 .59581 .74977 .59931 .75645 .59749 .75347 .59399 Mtetra
.75347 .59399 .75645 .59749 .76314 .59568 .76017 .59216 Mtetra
.641 .76 .935 r
.76017 .59216 .76314 .59568 .76984 .59386 .76688 .59034 Mtetra
.641 .759 .935 r
.76688 .59034 .76984 .59386 .77656 .59204 .77361 .58851 Mtetra
.77361 .58851 .77656 .59204 .7833 .59022 .78036 .58668 Mtetra
.64 .759 .935 r
.78036 .58668 .7833 .59022 .79005 .5884 .78713 .58485 Mtetra
.78713 .58485 .79005 .5884 .79682 .58658 .79391 .58302 Mtetra
.79391 .58302 .79682 .58658 .80361 .58475 .80071 .58119 Mtetra
.80071 .58119 .80361 .58475 .81041 .58293 .80752 .57936 Mtetra
.639 .759 .935 r
.80752 .57936 .81041 .58293 .81723 .5811 .81435 .57753 Mtetra
.81435 .57753 .81723 .5811 .82407 .57928 .8212 .57569 Mtetra
.8212 .57569 .82407 .57928 .83092 .57745 .82807 .57385 Mtetra
.64 .759 .935 r
.82807 .57385 .83092 .57745 .83779 .5756 .83495 .572 Mtetra
.641 .759 .934 r
.83495 .572 .83779 .5756 .84468 .57374 .84184 .57012 Mtetra
.645 .761 .933 r
.84184 .57012 .84468 .57374 .85157 .5718 .84875 .56818 Mtetra
.649 .763 .932 r
.84875 .56818 .85157 .5718 .85848 .56981 .85567 .56618 Mtetra
.672 .772 .925 r
.85567 .56618 .85848 .56981 .86536 .56745 .86257 .56381 Mtetra
.696 .781 .916 r
.86257 .56381 .86536 .56745 .87222 .56465 .86943 .561 Mtetra
.731 .793 .901 r
.86943 .561 .87222 .56465 .87902 .56117 .87624 .55751 Mtetra
.811 .814 .853 r
.87624 .55751 .87902 .56117 .88561 .55567 .88285 .552 Mtetra
.854 .82 .815 r
.88285 .552 .88561 .55567 .89204 .54862 .88929 .54493 Mtetra
.917 .818 .734 r
.88929 .54493 .89204 .54862 .89804 .53779 .89531 .53409 Mtetra
.954 .804 .656 r
.89531 .53409 .89804 .53779 .90349 .52225 .90078 .51851 Mtetra
.967 .793 .616 r
.90078 .51851 .90349 .52225 .90853 .50359 .90585 .49983 Mtetra
.982 .768 .54 r
.90585 .49983 .90853 .50359 .91253 .47646 .90987 .47267 Mtetra
.985 .76 .516 r
.90987 .47267 .91253 .47646 .91601 .4458 .91338 .44197 Mtetra
.943 .627 .409 r
.30239 .59617 .30591 .5993 .30949 .62805 .30595 .62495 Mtetra
.942 .619 .394 r
.30595 .62495 .30949 .62805 .31332 .6544 .30976 .65132 Mtetra
.935 .58 .322 r
.30976 .65132 .31332 .6544 .31772 .67296 .31414 .66991 Mtetra
.925 .547 .264 r
.31414 .66991 .31772 .67296 .32238 .68831 .31878 .68526 Mtetra
.875 .435 .087 r
.31878 .68526 .32238 .68831 .32739 .69854 .32379 .6955 Mtetra
.619 .095 0 r
.32379 .6955 .32739 .69854 .3327 .70417 .3291 .70114 Mtetra
0 .227 .694 r
.3291 .70114 .3327 .70417 .33815 .70783 .33455 .70479 Mtetra
.342 .64 .964 r
.33455 .70479 .33815 .70783 .34378 .7087 .34018 .70566 Mtetra
.498 .712 .966 r
.34018 .70566 .34378 .7087 .34947 .70854 .34588 .70549 Mtetra
.573 .74 .955 r
.34588 .70549 .34947 .70854 .35522 .70772 .35163 .70467 Mtetra
.632 .758 .938 r
.35163 .70467 .35522 .70772 .361 .70626 .35743 .7032 Mtetra
.639 .76 .935 r
.35743 .7032 .361 .70626 .36681 .7047 .36324 .70164 Mtetra
.648 .762 .932 r
.36324 .70164 .36681 .7047 .37264 .70302 .36907 .69995 Mtetra
.652 .763 .931 r
.36907 .69995 .37264 .70302 .37847 .70128 .37492 .69821 Mtetra
.653 .763 .93 r
.37492 .69821 .37847 .70128 .38433 .69953 .38078 .69645 Mtetra
.38078 .69645 .38433 .69953 .39019 .69778 .38665 .69469 Mtetra
.654 .764 .93 r
.38665 .69469 .39019 .69778 .39607 .69601 .39254 .69292 Mtetra
.39254 .69292 .39607 .69601 .40196 .69425 .39844 .69114 Mtetra
.652 .763 .931 r
.39844 .69114 .40196 .69425 .40786 .69249 .40435 .68938 Mtetra
.653 .763 .931 r
.40435 .68938 .40786 .69249 .41377 .69073 .41027 .68761 Mtetra
.653 .763 .93 r
.41027 .68761 .41377 .69073 .4197 .68895 .41621 .68583 Mtetra
.652 .763 .931 r
.41621 .68583 .4197 .68895 .42564 .6872 .42215 .68407 Mtetra
.42215 .68407 .42564 .6872 .43159 .68543 .42811 .6823 Mtetra
.42811 .6823 .43159 .68543 .43756 .68366 .43409 .68051 Mtetra
.651 .763 .931 r
.43409 .68051 .43756 .68366 .44354 .68189 .44007 .67875 Mtetra
.44007 .67875 .44354 .68189 .44953 .68013 .44607 .67697 Mtetra
.652 .763 .931 r
.44607 .67697 .44953 .68013 .45553 .67835 .45209 .67519 Mtetra
.651 .763 .931 r
.45209 .67519 .45553 .67835 .46155 .67659 .45811 .67342 Mtetra
.65 .763 .932 r
.45811 .67342 .46155 .67659 .46758 .67482 .46415 .67165 Mtetra
.651 .763 .931 r
.46415 .67165 .46758 .67482 .47362 .67304 .4702 .66986 Mtetra
.65 .763 .932 r
.4702 .66986 .47362 .67304 .47968 .67127 .47627 .66808 Mtetra
.649 .762 .932 r
.47627 .66808 .47968 .67127 .48575 .66951 .48235 .66631 Mtetra
.65 .763 .932 r
.48235 .66631 .48575 .66951 .49183 .66772 .48844 .66452 Mtetra
.48844 .66452 .49183 .66772 .49793 .66595 .49454 .66273 Mtetra
.649 .762 .932 r
.49454 .66273 .49793 .66595 .50404 .66418 .50066 .66096 Mtetra
.50066 .66096 .50404 .66418 .51016 .6624 .50679 .65917 Mtetra
.649 .763 .932 r
.50679 .65917 .51016 .6624 .5163 .66061 .51294 .65738 Mtetra
.648 .762 .932 r
.51294 .65738 .5163 .66061 .52245 .65884 .5191 .6556 Mtetra
.649 .762 .932 r
.5191 .6556 .52245 .65884 .52861 .65706 .52527 .65381 Mtetra
.52527 .65381 .52861 .65706 .53479 .65527 .53146 .65201 Mtetra
.647 .762 .933 r
.53146 .65201 .53479 .65527 .54098 .6535 .53766 .65023 Mtetra
.648 .762 .932 r
.53766 .65023 .54098 .6535 .54719 .65171 .54388 .64844 Mtetra
.54388 .64844 .54719 .65171 .55341 .64992 .5501 .64664 Mtetra
.647 .762 .933 r
.5501 .64664 .55341 .64992 .55964 .64814 .55635 .64486 Mtetra
.55635 .64486 .55964 .64814 .56589 .64636 .5626 .64306 Mtetra
.648 .762 .932 r
.5626 .64306 .56589 .64636 .57215 .64456 .56887 .64126 Mtetra
.647 .762 .933 r
.56887 .64126 .57215 .64456 .57843 .64277 .57516 .63947 Mtetra
.646 .762 .933 r
.57516 .63947 .57843 .64277 .58472 .64099 .58146 .63767 Mtetra
.647 .762 .933 r
.58146 .63767 .58472 .64099 .59102 .63919 .58777 .63587 Mtetra
.646 .762 .933 r
.58777 .63587 .59102 .63919 .59734 .6374 .5941 .63407 Mtetra
.645 .761 .933 r
.5941 .63407 .59734 .6374 .60367 .63561 .60044 .63227 Mtetra
.646 .762 .933 r
.60044 .63227 .60367 .63561 .61002 .63381 .6068 .63046 Mtetra
.646 .761 .933 r
.6068 .63046 .61002 .63381 .61638 .63201 .61317 .62865 Mtetra
.645 .761 .933 r
.61317 .62865 .61638 .63201 .62276 .63022 .61956 .62686 Mtetra
.646 .761 .933 r
.61956 .62686 .62276 .63022 .62915 .62841 .62596 .62505 Mtetra
.62596 .62505 .62915 .62841 .63555 .62661 .63238 .62323 Mtetra
.644 .761 .934 r
.63238 .62323 .63555 .62661 .64198 .62481 .63881 .62143 Mtetra
.645 .761 .933 r
.63881 .62143 .64198 .62481 .64841 .62301 .64525 .61962 Mtetra
.64525 .61962 .64841 .62301 .65486 .62119 .65171 .6178 Mtetra
.644 .761 .934 r
.65171 .6178 .65486 .62119 .66133 .6194 .65819 .61599 Mtetra
.65819 .61599 .66133 .6194 .66781 .61759 .66468 .61418 Mtetra
.645 .761 .933 r
.66468 .61418 .66781 .61759 .67431 .61577 .67119 .61235 Mtetra
.643 .76 .934 r
.67119 .61235 .67431 .61577 .68082 .61397 .67771 .61054 Mtetra
.67771 .61054 .68082 .61397 .68734 .61217 .68425 .60873 Mtetra
.643 .761 .934 r
.68425 .60873 .68734 .61217 .69389 .61036 .6908 .60691 Mtetra
.643 .76 .934 r
.6908 .60691 .69389 .61036 .70044 .60854 .69737 .60509 Mtetra
.69737 .60509 .70044 .60854 .70702 .60673 .70395 .60327 Mtetra
.70395 .60327 .70702 .60673 .7136 .60491 .71055 .60144 Mtetra
.642 .76 .934 r
.71055 .60144 .7136 .60491 .72021 .60309 .71716 .59962 Mtetra
.71716 .59962 .72021 .60309 .72683 .60128 .72379 .59779 Mtetra
.72379 .59779 .72683 .60128 .73346 .59946 .73044 .59596 Mtetra
.73044 .59596 .73346 .59946 .74012 .59763 .7371 .59413 Mtetra
.7371 .59413 .74012 .59763 .74678 .59581 .74378 .5923 Mtetra
.641 .76 .934 r
.74378 .5923 .74678 .59581 .75347 .59399 .75047 .59047 Mtetra
.75047 .59047 .75347 .59399 .76017 .59216 .75719 .58864 Mtetra
.641 .76 .935 r
.75719 .58864 .76017 .59216 .76688 .59034 .76391 .5868 Mtetra
.641 .759 .935 r
.76391 .5868 .76688 .59034 .77361 .58851 .77066 .58497 Mtetra
.77066 .58497 .77361 .58851 .78036 .58668 .77741 .58313 Mtetra
.64 .759 .935 r
.77741 .58313 .78036 .58668 .78713 .58485 .78419 .58129 Mtetra
.78419 .58129 .78713 .58485 .79391 .58302 .79098 .57946 Mtetra
.79098 .57946 .79391 .58302 .80071 .58119 .79779 .57762 Mtetra
.79779 .57762 .80071 .58119 .80752 .57936 .80462 .57577 Mtetra
.639 .759 .935 r
.80462 .57577 .80752 .57936 .81435 .57753 .81146 .57393 Mtetra
.81146 .57393 .81435 .57753 .8212 .57569 .81832 .57209 Mtetra
.81832 .57209 .8212 .57569 .82807 .57385 .8252 .57024 Mtetra
.64 .759 .935 r
.8252 .57024 .82807 .57385 .83495 .572 .83209 .56838 Mtetra
.641 .759 .934 r
.83209 .56838 .83495 .572 .84184 .57012 .839 .5665 Mtetra
.645 .761 .933 r
.839 .5665 .84184 .57012 .84875 .56818 .84592 .56455 Mtetra
.649 .763 .932 r
.84592 .56455 .84875 .56818 .85567 .56618 .85285 .56254 Mtetra
.672 .772 .925 r
.85285 .56254 .85567 .56618 .86257 .56381 .85975 .56015 Mtetra
.696 .781 .916 r
.85975 .56015 .86257 .56381 .86943 .561 .86664 .55733 Mtetra
.731 .793 .901 r
.86664 .55733 .86943 .561 .87624 .55751 .87346 .55383 Mtetra
.811 .814 .853 r
.87346 .55383 .87624 .55751 .88285 .552 .88008 .54831 Mtetra
.854 .82 .815 r
.88008 .54831 .88285 .552 .88929 .54493 .88654 .54122 Mtetra
.917 .818 .734 r
.88654 .54122 .88929 .54493 .89531 .53409 .89257 .53036 Mtetra
.954 .804 .656 r
.89257 .53036 .89531 .53409 .90078 .51851 .89806 .51476 Mtetra
.967 .793 .616 r
.89806 .51476 .90078 .51851 .90585 .49983 .90315 .49605 Mtetra
.982 .768 .54 r
.90315 .49605 .90585 .49983 .90987 .47267 .9072 .46886 Mtetra
.985 .76 .516 r
.9072 .46886 .90987 .47267 .91338 .44197 .91074 .43812 Mtetra
.943 .627 .409 r
.29887 .59304 .30239 .59617 .30595 .62495 .30239 .62184 Mtetra
.942 .619 .394 r
.30239 .62184 .30595 .62495 .30976 .65132 .30618 .64823 Mtetra
.935 .58 .322 r
.30618 .64823 .30976 .65132 .31414 .66991 .31054 .66684 Mtetra
.925 .547 .264 r
.31054 .66684 .31414 .66991 .31878 .68526 .31517 .6822 Mtetra
.875 .435 .087 r
.31517 .6822 .31878 .68526 .32379 .6955 .32017 .69246 Mtetra
.62 .096 0 r
.32017 .69246 .32379 .6955 .3291 .70114 .32548 .69809 Mtetra
0 .227 .694 r
.32548 .69809 .3291 .70114 .33455 .70479 .33094 .70175 Mtetra
.342 .64 .964 r
.33094 .70175 .33455 .70479 .34018 .70566 .33657 .70261 Mtetra
.498 .712 .967 r
.33657 .70261 .34018 .70566 .34588 .70549 .34228 .70244 Mtetra
.573 .74 .955 r
.34228 .70244 .34588 .70549 .35163 .70467 .34803 .70161 Mtetra
.632 .758 .938 r
.34803 .70161 .35163 .70467 .35743 .7032 .35384 .70014 Mtetra
.639 .76 .936 r
.35384 .70014 .35743 .7032 .36324 .70164 .35966 .69856 Mtetra
.648 .762 .932 r
.35966 .69856 .36324 .70164 .36907 .69995 .3655 .69687 Mtetra
.652 .763 .931 r
.3655 .69687 .36907 .69995 .37492 .69821 .37136 .69512 Mtetra
.653 .763 .93 r
.37136 .69512 .37492 .69821 .38078 .69645 .37722 .69336 Mtetra
.37722 .69336 .38078 .69645 .38665 .69469 .3831 .69159 Mtetra
.653 .764 .93 r
.3831 .69159 .38665 .69469 .39254 .69292 .389 .68981 Mtetra
.654 .764 .93 r
.389 .68981 .39254 .69292 .39844 .69114 .3949 .68803 Mtetra
.652 .763 .931 r
.3949 .68803 .39844 .69114 .40435 .68938 .40082 .68626 Mtetra
.653 .763 .931 r
.40082 .68626 .40435 .68938 .41027 .68761 .40675 .68448 Mtetra
.653 .763 .93 r
.40675 .68448 .41027 .68761 .41621 .68583 .4127 .6827 Mtetra
.652 .763 .931 r
.4127 .6827 .41621 .68583 .42215 .68407 .41865 .68093 Mtetra
.41865 .68093 .42215 .68407 .42811 .6823 .42462 .67915 Mtetra
.42462 .67915 .42811 .6823 .43409 .68051 .4306 .67736 Mtetra
.651 .763 .931 r
.4306 .67736 .43409 .68051 .44007 .67875 .4366 .67559 Mtetra
.4366 .67559 .44007 .67875 .44607 .67697 .44261 .67381 Mtetra
.652 .763 .931 r
.44261 .67381 .44607 .67697 .45209 .67519 .44863 .67202 Mtetra
.651 .763 .931 r
.44863 .67202 .45209 .67519 .45811 .67342 .45466 .67024 Mtetra
.65 .763 .932 r
.45466 .67024 .45811 .67342 .46415 .67165 .46071 .66846 Mtetra
.651 .763 .931 r
.46071 .66846 .46415 .67165 .4702 .66986 .46677 .66666 Mtetra
.65 .763 .932 r
.46677 .66666 .4702 .66986 .47627 .66808 .47284 .66488 Mtetra
.649 .763 .932 r
.47284 .66488 .47627 .66808 .48235 .66631 .47893 .6631 Mtetra
.65 .763 .932 r
.47893 .6631 .48235 .66631 .48844 .66452 .48503 .6613 Mtetra
.48503 .6613 .48844 .66452 .49454 .66273 .49115 .65951 Mtetra
.649 .762 .932 r
.49115 .65951 .49454 .66273 .50066 .66096 .49727 .65773 Mtetra
.649 .763 .932 r
.49727 .65773 .50066 .66096 .50679 .65917 .50341 .65593 Mtetra
.50341 .65593 .50679 .65917 .51294 .65738 .50957 .65413 Mtetra
.648 .762 .932 r
.50957 .65413 .51294 .65738 .5191 .6556 .51574 .65235 Mtetra
.649 .762 .932 r
.51574 .65235 .5191 .6556 .52527 .65381 .52192 .65055 Mtetra
.52192 .65055 .52527 .65381 .53146 .65201 .52812 .64875 Mtetra
.647 .762 .933 r
.52812 .64875 .53146 .65201 .53766 .65023 .53433 .64696 Mtetra
.648 .762 .932 r
.53433 .64696 .53766 .65023 .54388 .64844 .54055 .64516 Mtetra
.54055 .64516 .54388 .64844 .5501 .64664 .54679 .64335 Mtetra
.647 .762 .933 r
.54679 .64335 .5501 .64664 .55635 .64486 .55304 .64156 Mtetra
.55304 .64156 .55635 .64486 .5626 .64306 .55931 .63976 Mtetra
.648 .762 .933 r
.55931 .63976 .5626 .64306 .56887 .64126 .56559 .63795 Mtetra
.647 .762 .933 r
.56559 .63795 .56887 .64126 .57516 .63947 .57188 .63615 Mtetra
.646 .762 .933 r
.57188 .63615 .57516 .63947 .58146 .63767 .57819 .63435 Mtetra
.647 .762 .933 r
.57819 .63435 .58146 .63767 .58777 .63587 .58451 .63253 Mtetra
.646 .762 .933 r
.58451 .63253 .58777 .63587 .5941 .63407 .59085 .63072 Mtetra
.645 .761 .933 r
.59085 .63072 .5941 .63407 .60044 .63227 .5972 .62892 Mtetra
.646 .762 .933 r
.5972 .62892 .60044 .63227 .6068 .63046 .60357 .6271 Mtetra
.646 .761 .933 r
.60357 .6271 .6068 .63046 .61317 .62865 .60995 .62529 Mtetra
.645 .761 .933 r
.60995 .62529 .61317 .62865 .61956 .62686 .61635 .62348 Mtetra
.646 .761 .933 r
.61635 .62348 .61956 .62686 .62596 .62505 .62276 .62166 Mtetra
.62276 .62166 .62596 .62505 .63238 .62323 .62918 .61984 Mtetra
.644 .761 .934 r
.62918 .61984 .63238 .62323 .63881 .62143 .63563 .61803 Mtetra
.645 .761 .933 r
.63563 .61803 .63881 .62143 .64525 .61962 .64208 .61621 Mtetra
.64208 .61621 .64525 .61962 .65171 .6178 .64855 .61438 Mtetra
.644 .761 .934 r
.64855 .61438 .65171 .6178 .65819 .61599 .65504 .61257 Mtetra
.65504 .61257 .65819 .61599 .66468 .61418 .66154 .61075 Mtetra
.645 .761 .934 r
.66154 .61075 .66468 .61418 .67119 .61235 .66805 .60892 Mtetra
.643 .761 .934 r
.66805 .60892 .67119 .61235 .67771 .61054 .67459 .6071 Mtetra
.643 .76 .934 r
.67459 .6071 .67771 .61054 .68425 .60873 .68113 .60528 Mtetra
.643 .761 .934 r
.68113 .60528 .68425 .60873 .6908 .60691 .6877 .60345 Mtetra
.643 .76 .934 r
.6877 .60345 .6908 .60691 .69737 .60509 .69428 .60162 Mtetra
.69428 .60162 .69737 .60509 .70395 .60327 .70087 .59979 Mtetra
.70087 .59979 .70395 .60327 .71055 .60144 .70748 .59796 Mtetra
.642 .76 .934 r
.70748 .59796 .71055 .60144 .71716 .59962 .7141 .59612 Mtetra
.7141 .59612 .71716 .59962 .72379 .59779 .72075 .59429 Mtetra
.72075 .59429 .72379 .59779 .73044 .59596 .7274 .59245 Mtetra
.7274 .59245 .73044 .59596 .7371 .59413 .73408 .59062 Mtetra
.73408 .59062 .7371 .59413 .74378 .5923 .74076 .58878 Mtetra
.641 .76 .934 r
.74076 .58878 .74378 .5923 .75047 .59047 .74747 .58694 Mtetra
.641 .76 .935 r
.74747 .58694 .75047 .59047 .75719 .58864 .75419 .5851 Mtetra
.75419 .5851 .75719 .58864 .76391 .5868 .76093 .58325 Mtetra
.76093 .58325 .76391 .5868 .77066 .58497 .76768 .58141 Mtetra
.641 .759 .935 r
.76768 .58141 .77066 .58497 .77741 .58313 .77445 .57956 Mtetra
.64 .759 .935 r
.77445 .57956 .77741 .58313 .78419 .58129 .78124 .57772 Mtetra
.78124 .57772 .78419 .58129 .79098 .57946 .78804 .57587 Mtetra
.78804 .57587 .79098 .57946 .79779 .57762 .79487 .57402 Mtetra
.79487 .57402 .79779 .57762 .80462 .57577 .8017 .57217 Mtetra
.639 .759 .935 r
.8017 .57217 .80462 .57577 .81146 .57393 .80856 .57032 Mtetra
.80856 .57032 .81146 .57393 .81832 .57209 .81543 .56847 Mtetra
.81543 .56847 .81832 .57209 .8252 .57024 .82232 .56661 Mtetra
.64 .759 .935 r
.82232 .56661 .8252 .57024 .83209 .56838 .82922 .56474 Mtetra
.641 .76 .935 r
.82922 .56474 .83209 .56838 .839 .5665 .83614 .56285 Mtetra
.645 .761 .933 r
.83614 .56285 .839 .5665 .84592 .56455 .84307 .56089 Mtetra
.649 .763 .932 r
.84307 .56089 .84592 .56455 .85285 .56254 .85001 .55887 Mtetra
.672 .772 .925 r
.85001 .55887 .85285 .56254 .85975 .56015 .85693 .55648 Mtetra
.696 .781 .916 r
.85693 .55648 .85975 .56015 .86664 .55733 .86383 .55365 Mtetra
.731 .793 .901 r
.86383 .55365 .86664 .55733 .87346 .55383 .87066 .55014 Mtetra
.811 .814 .853 r
.87066 .55014 .87346 .55383 .88008 .54831 .8773 .5446 Mtetra
.854 .82 .815 r
.8773 .5446 .88008 .54831 .88654 .54122 .88377 .5375 Mtetra
.917 .818 .734 r
.88377 .5375 .88654 .54122 .89257 .53036 .88982 .52662 Mtetra
.954 .804 .656 r
.88982 .52662 .89257 .53036 .89806 .51476 .89533 .511 Mtetra
.967 .793 .616 r
.89533 .511 .89806 .51476 .90315 .49605 .90044 .49226 Mtetra
.982 .768 .54 r
.90044 .49226 .90315 .49605 .9072 .46886 .90452 .46503 Mtetra
.985 .76 .516 r
.90452 .46503 .9072 .46886 .91074 .43812 .90808 .43425 Mtetra
.943 .627 .409 r
.29532 .58989 .29887 .59304 .30239 .62184 .29882 .61872 Mtetra
.942 .619 .394 r
.29882 .61872 .30239 .62184 .30618 .64823 .30258 .64514 Mtetra
.935 .58 .322 r
.30258 .64514 .30618 .64823 .31054 .66684 .30693 .66375 Mtetra
.925 .547 .264 r
.30693 .66375 .31054 .66684 .31517 .6822 .31155 .67913 Mtetra
.875 .435 .087 r
.31155 .67913 .31517 .6822 .32017 .69246 .31654 .6894 Mtetra
.62 .096 0 r
.31654 .6894 .32017 .69246 .32548 .69809 .32185 .69503 Mtetra
0 .227 .693 r
.32185 .69503 .32548 .69809 .33094 .70175 .32731 .69869 Mtetra
.341 .64 .964 r
.32731 .69869 .33094 .70175 .33657 .70261 .33295 .69955 Mtetra
.498 .712 .967 r
.33295 .69955 .33657 .70261 .34228 .70244 .33866 .69937 Mtetra
.573 .74 .955 r
.33866 .69937 .34228 .70244 .34803 .70161 .34442 .69854 Mtetra
.632 .758 .938 r
.34442 .69854 .34803 .70161 .35384 .70014 .35023 .69706 Mtetra
.639 .76 .936 r
.35023 .69706 .35384 .70014 .35966 .69856 .35606 .69548 Mtetra
.648 .762 .932 r
.35606 .69548 .35966 .69856 .3655 .69687 .36191 .69378 Mtetra
.652 .763 .931 r
.36191 .69378 .3655 .69687 .37136 .69512 .36777 .69203 Mtetra
.653 .763 .931 r
.36777 .69203 .37136 .69512 .37722 .69336 .37365 .69026 Mtetra
.37365 .69026 .37722 .69336 .3831 .69159 .37954 .68848 Mtetra
.653 .764 .93 r
.37954 .68848 .3831 .69159 .389 .68981 .38544 .6867 Mtetra
.654 .764 .93 r
.38544 .6867 .389 .68981 .3949 .68803 .39135 .68491 Mtetra
.652 .763 .931 r
.39135 .68491 .3949 .68803 .40082 .68626 .39728 .68313 Mtetra
.653 .763 .931 r
.39728 .68313 .40082 .68626 .40675 .68448 .40322 .68135 Mtetra
.653 .764 .931 r
.40322 .68135 .40675 .68448 .4127 .6827 .40917 .67955 Mtetra
.651 .763 .931 r
.40917 .67955 .4127 .6827 .41865 .68093 .41514 .67778 Mtetra
.652 .763 .931 r
.41514 .67778 .41865 .68093 .42462 .67915 .42111 .67599 Mtetra
.42111 .67599 .42462 .67915 .4306 .67736 .4271 .67419 Mtetra
.651 .763 .931 r
.4271 .67419 .4306 .67736 .4366 .67559 .43311 .67241 Mtetra
.43311 .67241 .4366 .67559 .44261 .67381 .43912 .67063 Mtetra
.652 .763 .931 r
.43912 .67063 .44261 .67381 .44863 .67202 .44515 .66883 Mtetra
.651 .763 .931 r
.44515 .66883 .44863 .67202 .45466 .67024 .4512 .66704 Mtetra
.65 .763 .932 r
.4512 .66704 .45466 .67024 .46071 .66846 .45725 .66526 Mtetra
.651 .763 .931 r
.45725 .66526 .46071 .66846 .46677 .66666 .46332 .66346 Mtetra
.65 .763 .932 r
.46332 .66346 .46677 .66666 .47284 .66488 .4694 .66166 Mtetra
.649 .763 .932 r
.4694 .66166 .47284 .66488 .47893 .6631 .4755 .65987 Mtetra
.65 .763 .932 r
.4755 .65987 .47893 .6631 .48503 .6613 .48161 .65807 Mtetra
.48161 .65807 .48503 .6613 .49115 .65951 .48773 .65627 Mtetra
.649 .762 .932 r
.48773 .65627 .49115 .65951 .49727 .65773 .49387 .65448 Mtetra
.649 .763 .932 r
.49387 .65448 .49727 .65773 .50341 .65593 .50002 .65268 Mtetra
.50002 .65268 .50341 .65593 .50957 .65413 .50618 .65087 Mtetra
.648 .762 .932 r
.50618 .65087 .50957 .65413 .51574 .65235 .51236 .64908 Mtetra
.649 .762 .932 r
.51236 .64908 .51574 .65235 .52192 .65055 .51855 .64728 Mtetra
.51855 .64728 .52192 .65055 .52812 .64875 .52476 .64547 Mtetra
.647 .762 .933 r
.52476 .64547 .52812 .64875 .53433 .64696 .53098 .64367 Mtetra
.648 .762 .932 r
.53098 .64367 .53433 .64696 .54055 .64516 .53721 .64187 Mtetra
.53721 .64187 .54055 .64516 .54679 .64335 .54346 .64005 Mtetra
.647 .762 .933 r
.54346 .64005 .54679 .64335 .55304 .64156 .54972 .63825 Mtetra
.54972 .63825 .55304 .64156 .55931 .63976 .55599 .63644 Mtetra
.648 .762 .933 r
.55599 .63644 .55931 .63976 .56559 .63795 .56228 .63462 Mtetra
.647 .762 .933 r
.56228 .63462 .56559 .63795 .57188 .63615 .56859 .63281 Mtetra
.646 .762 .933 r
.56859 .63281 .57188 .63615 .57819 .63435 .57491 .63101 Mtetra
.647 .762 .933 r
.57491 .63101 .57819 .63435 .58451 .63253 .58124 .62918 Mtetra
.646 .762 .933 r
.58124 .62918 .58451 .63253 .59085 .63072 .58759 .62737 Mtetra
.645 .761 .933 r
.58759 .62737 .59085 .63072 .5972 .62892 .59395 .62556 Mtetra
.646 .762 .933 r
.59395 .62556 .5972 .62892 .60357 .6271 .60032 .62373 Mtetra
.60032 .62373 .60357 .6271 .60995 .62529 .60672 .62191 Mtetra
.645 .761 .933 r
.60672 .62191 .60995 .62529 .61635 .62348 .61312 .6201 Mtetra
.646 .761 .933 r
.61312 .6201 .61635 .62348 .62276 .62166 .61954 .61827 Mtetra
.61954 .61827 .62276 .62166 .62918 .61984 .62598 .61644 Mtetra
.644 .761 .934 r
.62598 .61644 .62918 .61984 .63563 .61803 .63243 .61462 Mtetra
.645 .761 .933 r
.63243 .61462 .63563 .61803 .64208 .61621 .6389 .6128 Mtetra
.6389 .6128 .64208 .61621 .64855 .61438 .64538 .61096 Mtetra
.644 .761 .934 r
.64538 .61096 .64855 .61438 .65504 .61257 .65187 .60914 Mtetra
.65187 .60914 .65504 .61257 .66154 .61075 .65838 .60731 Mtetra
.645 .761 .934 r
.65838 .60731 .66154 .61075 .66805 .60892 .66491 .60547 Mtetra
.643 .761 .934 r
.66491 .60547 .66805 .60892 .67459 .6071 .67145 .60364 Mtetra
.67145 .60364 .67459 .6071 .68113 .60528 .67801 .60181 Mtetra
.67801 .60181 .68113 .60528 .6877 .60345 .68458 .59998 Mtetra
.68458 .59998 .6877 .60345 .69428 .60162 .69117 .59814 Mtetra
.643 .76 .934 r
.69117 .59814 .69428 .60162 .70087 .59979 .69778 .5963 Mtetra
.69778 .5963 .70087 .59979 .70748 .59796 .7044 .59446 Mtetra
.642 .76 .934 r
.7044 .59446 .70748 .59796 .7141 .59612 .71103 .59262 Mtetra
.71103 .59262 .7141 .59612 .72075 .59429 .71768 .59077 Mtetra
.71768 .59077 .72075 .59429 .7274 .59245 .72435 .58893 Mtetra
.72435 .58893 .7274 .59245 .73408 .59062 .73104 .58708 Mtetra
.73104 .58708 .73408 .59062 .74076 .58878 .73774 .58524 Mtetra
.641 .76 .935 r
.73774 .58524 .74076 .58878 .74747 .58694 .74445 .58339 Mtetra
.74445 .58339 .74747 .58694 .75419 .5851 .75118 .58154 Mtetra
.75118 .58154 .75419 .5851 .76093 .58325 .75793 .57969 Mtetra
.75793 .57969 .76093 .58325 .76768 .58141 .7647 .57784 Mtetra
.7647 .57784 .76768 .58141 .77445 .57956 .77148 .57598 Mtetra
.64 .759 .935 r
.77148 .57598 .77445 .57956 .78124 .57772 .77828 .57413 Mtetra
.77828 .57413 .78124 .57772 .78804 .57587 .78509 .57227 Mtetra
.78509 .57227 .78804 .57587 .79487 .57402 .79193 .57042 Mtetra
.79193 .57042 .79487 .57402 .8017 .57217 .79877 .56856 Mtetra
.639 .759 .935 r
.79877 .56856 .8017 .57217 .80856 .57032 .80564 .5667 Mtetra
.80564 .5667 .80856 .57032 .81543 .56847 .81252 .56484 Mtetra
.81252 .56484 .81543 .56847 .82232 .56661 .81942 .56297 Mtetra
.64 .759 .935 r
.81942 .56297 .82232 .56661 .82922 .56474 .82634 .56109 Mtetra
.641 .76 .935 r
.82634 .56109 .82922 .56474 .83614 .56285 .83327 .55919 Mtetra
.645 .761 .933 r
.83327 .55919 .83614 .56285 .84307 .56089 .84021 .55723 Mtetra
.649 .763 .932 r
.84021 .55723 .84307 .56089 .85001 .55887 .84716 .5552 Mtetra
.672 .772 .925 r
.84716 .5552 .85001 .55887 .85693 .55648 .8541 .5528 Mtetra
.696 .781 .916 r
.8541 .5528 .85693 .55648 .86383 .55365 .861 .54996 Mtetra
.731 .793 .901 r
.861 .54996 .86383 .55365 .87066 .55014 .86785 .54643 Mtetra
.811 .814 .853 r
.86785 .54643 .87066 .55014 .8773 .5446 .8745 .54088 Mtetra
.854 .82 .815 r
.8745 .54088 .8773 .5446 .88377 .5375 .88099 .53377 Mtetra
.917 .818 .734 r
.88099 .53377 .88377 .5375 .88982 .52662 .88706 .52287 Mtetra
.954 .804 .656 r
.88706 .52287 .88982 .52662 .89533 .511 .89259 .50722 Mtetra
.967 .793 .616 r
.89259 .50722 .89533 .511 .90044 .49226 .89772 .48845 Mtetra
.982 .769 .54 r
.89772 .48845 .90044 .49226 .90452 .46503 .90182 .46119 Mtetra
.985 .76 .516 r
.90182 .46119 .90452 .46503 .90808 .43425 .90541 .43037 Mtetra
.943 .627 .409 r
.29177 .58674 .29532 .58989 .29882 .61872 .29524 .61559 Mtetra
.942 .619 .394 r
.29524 .61559 .29882 .61872 .30258 .64514 .29897 .64203 Mtetra
.935 .58 .322 r
.29897 .64203 .30258 .64514 .30693 .66375 .3033 .66066 Mtetra
.925 .547 .264 r
.3033 .66066 .30693 .66375 .31155 .67913 .30791 .67605 Mtetra
.875 .435 .087 r
.30791 .67605 .31155 .67913 .31654 .6894 .3129 .68632 Mtetra
.62 .096 0 r
.3129 .68632 .31654 .6894 .32185 .69503 .31821 .69196 Mtetra
0 .226 .693 r
.31821 .69196 .32185 .69503 .32731 .69869 .32366 .69562 Mtetra
.341 .64 .964 r
.32366 .69562 .32731 .69869 .33295 .69955 .32931 .69647 Mtetra
.498 .712 .967 r
.32931 .69647 .33295 .69955 .33866 .69937 .33502 .69629 Mtetra
.573 .74 .955 r
.33502 .69629 .33866 .69937 .34442 .69854 .3408 .69546 Mtetra
.632 .758 .938 r
.3408 .69546 .34442 .69854 .35023 .69706 .34661 .69397 Mtetra
.639 .76 .936 r
.34661 .69397 .35023 .69706 .35606 .69548 .35245 .69238 Mtetra
.648 .762 .932 r
.35245 .69238 .35606 .69548 .36191 .69378 .35831 .69068 Mtetra
.652 .763 .931 r
.35831 .69068 .36191 .69378 .36777 .69203 .36418 .68892 Mtetra
.653 .763 .931 r
.36418 .68892 .36777 .69203 .37365 .69026 .37006 .68714 Mtetra
.37006 .68714 .37365 .69026 .37954 .68848 .37596 .68536 Mtetra
.653 .764 .93 r
.37596 .68536 .37954 .68848 .38544 .6867 .38187 .68357 Mtetra
.38187 .68357 .38544 .6867 .39135 .68491 .38779 .68177 Mtetra
.652 .763 .931 r
.38779 .68177 .39135 .68491 .39728 .68313 .39373 .67999 Mtetra
.653 .763 .931 r
.39373 .67999 .39728 .68313 .40322 .68135 .39967 .6782 Mtetra
.653 .764 .931 r
.39967 .6782 .40322 .68135 .40917 .67955 .40563 .67639 Mtetra
.651 .763 .931 r
.40563 .67639 .40917 .67955 .41514 .67778 .41161 .67461 Mtetra
.652 .763 .931 r
.41161 .67461 .41514 .67778 .42111 .67599 .41759 .67282 Mtetra
.41759 .67282 .42111 .67599 .4271 .67419 .42359 .67102 Mtetra
.651 .763 .931 r
.42359 .67102 .4271 .67419 .43311 .67241 .4296 .66923 Mtetra
.4296 .66923 .43311 .67241 .43912 .67063 .43563 .66743 Mtetra
.652 .763 .931 r
.43563 .66743 .43912 .67063 .44515 .66883 .44167 .66563 Mtetra
.651 .763 .931 r
.44167 .66563 .44515 .66883 .4512 .66704 .44772 .66383 Mtetra
.65 .763 .932 r
.44772 .66383 .4512 .66704 .45725 .66526 .45378 .66204 Mtetra
.651 .763 .931 r
.45378 .66204 .45725 .66526 .46332 .66346 .45986 .66023 Mtetra
.65 .763 .932 r
.45986 .66023 .46332 .66346 .4694 .66166 .46595 .65843 Mtetra
.649 .763 .932 r
.46595 .65843 .4694 .66166 .4755 .65987 .47206 .65664 Mtetra
.65 .763 .932 r
.47206 .65664 .4755 .65987 .48161 .65807 .47817 .65483 Mtetra
.47817 .65483 .48161 .65807 .48773 .65627 .48431 .65302 Mtetra
.649 .762 .932 r
.48431 .65302 .48773 .65627 .49387 .65448 .49045 .65123 Mtetra
.649 .763 .932 r
.49045 .65123 .49387 .65448 .50002 .65268 .49661 .64942 Mtetra
.49661 .64942 .50002 .65268 .50618 .65087 .50278 .6476 Mtetra
.648 .762 .932 r
.50278 .6476 .50618 .65087 .51236 .64908 .50897 .6458 Mtetra
.649 .762 .932 r
.50897 .6458 .51236 .64908 .51855 .64728 .51517 .64399 Mtetra
.51517 .64399 .51855 .64728 .52476 .64547 .52139 .64217 Mtetra
.647 .762 .933 r
.52139 .64217 .52476 .64547 .53098 .64367 .52761 .64037 Mtetra
.648 .762 .933 r
.52761 .64037 .53098 .64367 .53721 .64187 .53386 .63856 Mtetra
.648 .762 .932 r
.53386 .63856 .53721 .64187 .54346 .64005 .54011 .63673 Mtetra
.647 .762 .933 r
.54011 .63673 .54346 .64005 .54972 .63825 .54638 .63492 Mtetra
.54638 .63492 .54972 .63825 .55599 .63644 .55267 .63311 Mtetra
.648 .762 .933 r
.55267 .63311 .55599 .63644 .56228 .63462 .55897 .63128 Mtetra
.647 .762 .933 r
.55897 .63128 .56228 .63462 .56859 .63281 .56528 .62947 Mtetra
.646 .762 .933 r
.56528 .62947 .56859 .63281 .57491 .63101 .57161 .62765 Mtetra
.647 .762 .933 r
.57161 .62765 .57491 .63101 .58124 .62918 .57795 .62582 Mtetra
.646 .762 .933 r
.57795 .62582 .58124 .62918 .58759 .62737 .58431 .624 Mtetra
.645 .761 .933 r
.58431 .624 .58759 .62737 .59395 .62556 .59068 .62218 Mtetra
.646 .762 .933 r
.59068 .62218 .59395 .62556 .60032 .62373 .59707 .62035 Mtetra
.59707 .62035 .60032 .62373 .60672 .62191 .60347 .61852 Mtetra
.645 .761 .933 r
.60347 .61852 .60672 .62191 .61312 .6201 .60988 .6167 Mtetra
.646 .761 .933 r
.60988 .6167 .61312 .6201 .61954 .61827 .61631 .61486 Mtetra
.61631 .61486 .61954 .61827 .62598 .61644 .62276 .61302 Mtetra
.644 .761 .934 r
.62276 .61302 .62598 .61644 .63243 .61462 .62922 .6112 Mtetra
.645 .761 .934 r
.62922 .6112 .63243 .61462 .6389 .6128 .6357 .60936 Mtetra
.645 .761 .933 r
.6357 .60936 .6389 .6128 .64538 .61096 .64219 .60752 Mtetra
.644 .761 .934 r
.64219 .60752 .64538 .61096 .65187 .60914 .64869 .60569 Mtetra
.64869 .60569 .65187 .60914 .65838 .60731 .65521 .60385 Mtetra
.645 .761 .934 r
.65521 .60385 .65838 .60731 .66491 .60547 .66175 .602 Mtetra
.643 .761 .934 r
.66175 .602 .66491 .60547 .67145 .60364 .6683 .60017 Mtetra
.6683 .60017 .67145 .60364 .67801 .60181 .67487 .59833 Mtetra
.67487 .59833 .67801 .60181 .68458 .59998 .68146 .59649 Mtetra
.68146 .59649 .68458 .59998 .69117 .59814 .68805 .59464 Mtetra
.643 .76 .934 r
.68805 .59464 .69117 .59814 .69778 .5963 .69467 .59279 Mtetra
.69467 .59279 .69778 .5963 .7044 .59446 .7013 .59095 Mtetra
.642 .76 .934 r
.7013 .59095 .7044 .59446 .71103 .59262 .70795 .5891 Mtetra
.70795 .5891 .71103 .59262 .71768 .59077 .71461 .58724 Mtetra
.71461 .58724 .71768 .59077 .72435 .58893 .72129 .58539 Mtetra
.72129 .58539 .72435 .58893 .73104 .58708 .72798 .58354 Mtetra
.72798 .58354 .73104 .58708 .73774 .58524 .73469 .58168 Mtetra
.641 .76 .935 r
.73469 .58168 .73774 .58524 .74445 .58339 .74142 .57983 Mtetra
.74142 .57983 .74445 .58339 .75118 .58154 .74816 .57797 Mtetra
.74816 .57797 .75118 .58154 .75793 .57969 .75492 .57611 Mtetra
.75492 .57611 .75793 .57969 .7647 .57784 .7617 .57425 Mtetra
.7617 .57425 .7647 .57784 .77148 .57598 .76849 .57239 Mtetra
.64 .759 .935 r
.76849 .57239 .77148 .57598 .77828 .57413 .7753 .57052 Mtetra
.7753 .57052 .77828 .57413 .78509 .57227 .78213 .56866 Mtetra
.78213 .56866 .78509 .57227 .79193 .57042 .78897 .56679 Mtetra
.78897 .56679 .79193 .57042 .79877 .56856 .79583 .56493 Mtetra
.639 .759 .935 r
.79583 .56493 .79877 .56856 .80564 .5667 .80271 .56306 Mtetra
.80271 .56306 .80564 .5667 .81252 .56484 .8096 .56119 Mtetra
.8096 .56119 .81252 .56484 .81942 .56297 .81651 .55931 Mtetra
.64 .759 .935 r
.81651 .55931 .81942 .56297 .82634 .56109 .82344 .55743 Mtetra
.641 .76 .935 r
.82344 .55743 .82634 .56109 .83327 .55919 .83038 .55552 Mtetra
.645 .761 .933 r
.83038 .55552 .83327 .55919 .84021 .55723 .83734 .55354 Mtetra
.649 .763 .932 r
.83734 .55354 .84021 .55723 .84716 .5552 .8443 .55151 Mtetra
.672 .772 .925 r
.8443 .55151 .84716 .5552 .8541 .5528 .85125 .54909 Mtetra
.696 .781 .916 r
.85125 .54909 .8541 .5528 .861 .54996 .85817 .54624 Mtetra
.731 .793 .901 r
.85817 .54624 .861 .54996 .86785 .54643 .86503 .54271 Mtetra
.811 .814 .853 r
.86503 .54271 .86785 .54643 .8745 .54088 .87169 .53715 Mtetra
.854 .82 .815 r
.87169 .53715 .8745 .54088 .88099 .53377 .8782 .53002 Mtetra
.917 .818 .734 r
.8782 .53002 .88099 .53377 .88706 .52287 .88428 .5191 Mtetra
.954 .804 .656 r
.88428 .5191 .88706 .52287 .89259 .50722 .88983 .50342 Mtetra
.967 .793 .616 r
.88983 .50342 .89259 .50722 .89772 .48845 .89499 .48463 Mtetra
.982 .769 .54 r
.89499 .48463 .89772 .48845 .90182 .46119 .89911 .45733 Mtetra
.985 .76 .516 r
.89911 .45733 .90182 .46119 .90541 .43037 .90274 .42648 Mtetra
.943 .627 .409 r
.2882 .58357 .29177 .58674 .29524 .61559 .29164 .61245 Mtetra
.942 .619 .394 r
.29164 .61245 .29524 .61559 .29897 .64203 .29535 .63891 Mtetra
.935 .58 .322 r
.29535 .63891 .29897 .64203 .3033 .66066 .29966 .65756 Mtetra
.925 .547 .264 r
.29966 .65756 .3033 .66066 .30791 .67605 .30426 .67296 Mtetra
.875 .435 .087 r
.30426 .67296 .30791 .67605 .3129 .68632 .30924 .68324 Mtetra
.62 .096 0 r
.30924 .68324 .3129 .68632 .31821 .69196 .31455 .68888 Mtetra
0 .226 .693 r
.31455 .68888 .31821 .69196 .32366 .69562 .32 .69254 Mtetra
.341 .64 .964 r
.32 .69254 .32366 .69562 .32931 .69647 .32565 .69339 Mtetra
.498 .712 .967 r
.32565 .69339 .32931 .69647 .33502 .69629 .33138 .69321 Mtetra
.573 .74 .955 r
.33138 .69321 .33502 .69629 .3408 .69546 .33715 .69236 Mtetra
.632 .758 .938 r
.33715 .69236 .3408 .69546 .34661 .69397 .34298 .69087 Mtetra
.639 .76 .936 r
.34298 .69087 .34661 .69397 .35245 .69238 .34883 .68927 Mtetra
.648 .762 .932 r
.34883 .68927 .35245 .69238 .35831 .69068 .35469 .68757 Mtetra
.652 .763 .931 r
.35469 .68757 .35831 .69068 .36418 .68892 .36057 .68579 Mtetra
.653 .764 .931 r
.36057 .68579 .36418 .68892 .37006 .68714 .36646 .68401 Mtetra
.36646 .68401 .37006 .68714 .37596 .68536 .37236 .68222 Mtetra
.653 .764 .93 r
.37236 .68222 .37596 .68536 .38187 .68357 .37828 .68042 Mtetra
.37828 .68042 .38187 .68357 .38779 .68177 .38421 .67862 Mtetra
.652 .763 .931 r
.38421 .67862 .38779 .68177 .39373 .67999 .39016 .67683 Mtetra
.653 .763 .931 r
.39016 .67683 .39373 .67999 .39967 .6782 .39611 .67503 Mtetra
.653 .764 .931 r
.39611 .67503 .39967 .6782 .40563 .67639 .40208 .67322 Mtetra
.651 .763 .931 r
.40208 .67322 .40563 .67639 .41161 .67461 .40806 .67143 Mtetra
.652 .763 .931 r
.40806 .67143 .41161 .67461 .41759 .67282 .41406 .66963 Mtetra
.41406 .66963 .41759 .67282 .42359 .67102 .42006 .66782 Mtetra
.651 .763 .931 r
.42006 .66782 .42359 .67102 .4296 .66923 .42608 .66603 Mtetra
.42608 .66603 .4296 .66923 .43563 .66743 .43212 .66423 Mtetra
.652 .763 .931 r
.43212 .66423 .43563 .66743 .44167 .66563 .43816 .66242 Mtetra
.651 .763 .931 r
.43816 .66242 .44167 .66563 .44772 .66383 .44422 .66061 Mtetra
.65 .763 .932 r
.44422 .66061 .44772 .66383 .45378 .66204 .4503 .65881 Mtetra
.651 .763 .931 r
.4503 .65881 .45378 .66204 .45986 .66023 .45638 .657 Mtetra
.65 .763 .932 r
.45638 .657 .45986 .66023 .46595 .65843 .46248 .65519 Mtetra
.649 .763 .932 r
.46248 .65519 .46595 .65843 .47206 .65664 .4686 .65339 Mtetra
.65 .763 .932 r
.4686 .65339 .47206 .65664 .47817 .65483 .47473 .65157 Mtetra
.47473 .65157 .47817 .65483 .48431 .65302 .48087 .64976 Mtetra
.649 .762 .932 r
.48087 .64976 .48431 .65302 .49045 .65123 .48702 .64795 Mtetra
.649 .763 .932 r
.48702 .64795 .49045 .65123 .49661 .64942 .49319 .64614 Mtetra
.49319 .64614 .49661 .64942 .50278 .6476 .49937 .64432 Mtetra
.648 .762 .932 r
.49937 .64432 .50278 .6476 .50897 .6458 .50557 .64251 Mtetra
.649 .762 .932 r
.50557 .64251 .50897 .6458 .51517 .64399 .51178 .64069 Mtetra
.649 .763 .932 r
.51178 .64069 .51517 .64399 .52139 .64217 .518 .63886 Mtetra
.647 .762 .933 r
.518 .63886 .52139 .64217 .52761 .64037 .52424 .63705 Mtetra
.648 .762 .933 r
.52424 .63705 .52761 .64037 .53386 .63856 .53049 .63523 Mtetra
.648 .762 .932 r
.53049 .63523 .53386 .63856 .54011 .63673 .53675 .6334 Mtetra
.647 .762 .933 r
.53675 .6334 .54011 .63673 .54638 .63492 .54303 .63159 Mtetra
.54303 .63159 .54638 .63492 .55267 .63311 .54933 .62976 Mtetra
.648 .762 .933 r
.54933 .62976 .55267 .63311 .55897 .63128 .55564 .62793 Mtetra
.647 .762 .933 r
.55564 .62793 .55897 .63128 .56528 .62947 .56196 .62611 Mtetra
.646 .762 .933 r
.56196 .62611 .56528 .62947 .57161 .62765 .5683 .62428 Mtetra
.647 .762 .933 r
.5683 .62428 .57161 .62765 .57795 .62582 .57465 .62245 Mtetra
.646 .762 .933 r
.57465 .62245 .57795 .62582 .58431 .624 .58102 .62061 Mtetra
.645 .761 .933 r
.58102 .62061 .58431 .624 .59068 .62218 .5874 .61879 Mtetra
.646 .762 .933 r
.5874 .61879 .59068 .62218 .59707 .62035 .59379 .61695 Mtetra
.59379 .61695 .59707 .62035 .60347 .61852 .6002 .61511 Mtetra
.645 .761 .934 r
.6002 .61511 .60347 .61852 .60988 .6167 .60663 .61328 Mtetra
.646 .761 .933 r
.60663 .61328 .60988 .6167 .61631 .61486 .61307 .61144 Mtetra
.61307 .61144 .61631 .61486 .62276 .61302 .61953 .60959 Mtetra
.644 .761 .934 r
.61953 .60959 .62276 .61302 .62922 .6112 .626 .60776 Mtetra
.645 .761 .934 r
.626 .60776 .62922 .6112 .6357 .60936 .63248 .60592 Mtetra
.645 .761 .933 r
.63248 .60592 .6357 .60936 .64219 .60752 .63898 .60406 Mtetra
.644 .761 .934 r
.63898 .60406 .64219 .60752 .64869 .60569 .6455 .60223 Mtetra
.6455 .60223 .64869 .60569 .65521 .60385 .65203 .60038 Mtetra
.645 .761 .934 r
.65203 .60038 .65521 .60385 .66175 .602 .65858 .59852 Mtetra
.643 .761 .934 r
.65858 .59852 .66175 .602 .6683 .60017 .66514 .59668 Mtetra
.66514 .59668 .6683 .60017 .67487 .59833 .67172 .59484 Mtetra
.67172 .59484 .67487 .59833 .68146 .59649 .67831 .59298 Mtetra
.67831 .59298 .68146 .59649 .68805 .59464 .68492 .59113 Mtetra
.68492 .59113 .68805 .59464 .69467 .59279 .69155 .58928 Mtetra
.643 .76 .934 r
.69155 .58928 .69467 .59279 .7013 .59095 .69819 .58742 Mtetra
.642 .76 .934 r
.69819 .58742 .7013 .59095 .70795 .5891 .70485 .58556 Mtetra
.70485 .58556 .70795 .5891 .71461 .58724 .71152 .5837 Mtetra
.71152 .5837 .71461 .58724 .72129 .58539 .71821 .58184 Mtetra
.71821 .58184 .72129 .58539 .72798 .58354 .72492 .57998 Mtetra
.72492 .57998 .72798 .58354 .73469 .58168 .73164 .57811 Mtetra
.641 .76 .935 r
.73164 .57811 .73469 .58168 .74142 .57983 .73838 .57625 Mtetra
.73838 .57625 .74142 .57983 .74816 .57797 .74513 .57438 Mtetra
.74513 .57438 .74816 .57797 .75492 .57611 .7519 .57252 Mtetra
.7519 .57252 .75492 .57611 .7617 .57425 .75869 .57065 Mtetra
.75869 .57065 .7617 .57425 .76849 .57239 .76549 .56878 Mtetra
.64 .759 .935 r
.76549 .56878 .76849 .57239 .7753 .57052 .77231 .5669 Mtetra
.77231 .5669 .7753 .57052 .78213 .56866 .77915 .56503 Mtetra
.77915 .56503 .78213 .56866 .78897 .56679 .78601 .56316 Mtetra
.78601 .56316 .78897 .56679 .79583 .56493 .79288 .56128 Mtetra
.639 .759 .935 r
.79288 .56128 .79583 .56493 .80271 .56306 .79977 .5594 Mtetra
.79977 .5594 .80271 .56306 .8096 .56119 .80667 .55753 Mtetra
.80667 .55753 .8096 .56119 .81651 .55931 .81359 .55564 Mtetra
.64 .759 .935 r
.81359 .55564 .81651 .55931 .82344 .55743 .82053 .55375 Mtetra
.641 .76 .935 r
.82053 .55375 .82344 .55743 .83038 .55552 .82749 .55183 Mtetra
.645 .761 .933 r
.82749 .55183 .83038 .55552 .83734 .55354 .83445 .54984 Mtetra
.649 .763 .932 r
.83445 .54984 .83734 .55354 .8443 .55151 .84143 .5478 Mtetra
.672 .772 .925 r
.84143 .5478 .8443 .55151 .85125 .54909 .84839 .54538 Mtetra
.696 .781 .916 r
.84839 .54538 .85125 .54909 .85817 .54624 .85532 .54252 Mtetra
.731 .793 .901 r
.85532 .54252 .85817 .54624 .86503 .54271 .8622 .53897 Mtetra
.811 .814 .853 r
.8622 .53897 .86503 .54271 .87169 .53715 .86887 .53339 Mtetra
.854 .82 .815 r
.86887 .53339 .87169 .53715 .8782 .53002 .87539 .52625 Mtetra
.917 .818 .734 r
.87539 .52625 .8782 .53002 .88428 .5191 .8815 .51531 Mtetra
.954 .804 .656 r
.8815 .51531 .88428 .5191 .88983 .50342 .88706 .49961 Mtetra
.967 .793 .616 r
.88706 .49961 .88983 .50342 .89499 .48463 .89224 .48079 Mtetra
.982 .769 .54 r
.89224 .48079 .89499 .48463 .89911 .45733 .89639 .45345 Mtetra
.985 .76 .516 r
.89639 .45345 .89911 .45733 .90274 .42648 .90005 .42256 Mtetra
.943 .627 .409 r
.28462 .58039 .2882 .58357 .29164 .61245 .28803 .60929 Mtetra
.942 .619 .394 r
.28803 .60929 .29164 .61245 .29535 .63891 .29171 .63578 Mtetra
.935 .58 .322 r
.29171 .63578 .29535 .63891 .29966 .65756 .29601 .65444 Mtetra
.925 .547 .264 r
.29601 .65444 .29966 .65756 .30426 .67296 .30059 .66986 Mtetra
.875 .435 .087 r
.30059 .66986 .30426 .67296 .30924 .68324 .30556 .68014 Mtetra
.621 .096 0 r
.30556 .68014 .30924 .68324 .31455 .68888 .31087 .68579 Mtetra
0 .226 .693 r
.31087 .68579 .31455 .68888 .32 .69254 .31633 .68944 Mtetra
.341 .64 .964 r
.31633 .68944 .32 .69254 .32565 .69339 .32198 .69029 Mtetra
.498 .712 .967 r
.32198 .69029 .32565 .69339 .33138 .69321 .32771 .6901 Mtetra
.573 .74 .955 r
.32771 .6901 .33138 .69321 .33715 .69236 .3335 .68926 Mtetra
.632 .758 .938 r
.3335 .68926 .33715 .69236 .34298 .69087 .33933 .68775 Mtetra
.639 .76 .936 r
.33933 .68775 .34298 .69087 .34883 .68927 .34518 .68616 Mtetra
.648 .762 .933 r
.34518 .68616 .34883 .68927 .35469 .68757 .35106 .68444 Mtetra
.652 .763 .931 r
.35106 .68444 .35469 .68757 .36057 .68579 .35694 .68266 Mtetra
.653 .764 .931 r
.35694 .68266 .36057 .68579 .36646 .68401 .36284 .68087 Mtetra
.36284 .68087 .36646 .68401 .37236 .68222 .36876 .67908 Mtetra
.653 .764 .93 r
.36876 .67908 .37236 .68222 .37828 .68042 .37468 .67727 Mtetra
.37468 .67727 .37828 .68042 .38421 .67862 .38062 .67546 Mtetra
.652 .763 .931 r
.38062 .67546 .38421 .67862 .39016 .67683 .38657 .67366 Mtetra
.653 .764 .931 r
.38657 .67366 .39016 .67683 .39611 .67503 .39254 .67186 Mtetra
.39254 .67186 .39611 .67503 .40208 .67322 .39851 .67004 Mtetra
.651 .763 .931 r
.39851 .67004 .40208 .67322 .40806 .67143 .4045 .66824 Mtetra
.652 .763 .931 r
.4045 .66824 .40806 .67143 .41406 .66963 .41051 .66644 Mtetra
.41051 .66644 .41406 .66963 .42006 .66782 .41652 .66462 Mtetra
.651 .763 .931 r
.41652 .66462 .42006 .66782 .42608 .66603 .42255 .66282 Mtetra
.42255 .66282 .42608 .66603 .43212 .66423 .42859 .66101 Mtetra
.652 .763 .931 r
.42859 .66101 .43212 .66423 .43816 .66242 .43465 .65919 Mtetra
.651 .763 .932 r
.43465 .65919 .43816 .66242 .44422 .66061 .44072 .65738 Mtetra
.65 .763 .932 r
.44072 .65738 .44422 .66061 .4503 .65881 .4468 .65558 Mtetra
.651 .763 .931 r
.4468 .65558 .4503 .65881 .45638 .657 .45289 .65375 Mtetra
.65 .763 .932 r
.45289 .65375 .45638 .657 .46248 .65519 .459 .65194 Mtetra
.649 .763 .932 r
.459 .65194 .46248 .65519 .4686 .65339 .46513 .65013 Mtetra
.65 .763 .932 r
.46513 .65013 .4686 .65339 .47473 .65157 .47126 .64831 Mtetra
.47126 .64831 .47473 .65157 .48087 .64976 .47741 .64648 Mtetra
.649 .763 .932 r
.47741 .64648 .48087 .64976 .48702 .64795 .48357 .64467 Mtetra
.48357 .64467 .48702 .64795 .49319 .64614 .48975 .64285 Mtetra
.48975 .64285 .49319 .64614 .49937 .64432 .49594 .64102 Mtetra
.648 .762 .932 r
.49594 .64102 .49937 .64432 .50557 .64251 .50215 .6392 Mtetra
.649 .762 .932 r
.50215 .6392 .50557 .64251 .51178 .64069 .50837 .63738 Mtetra
.649 .763 .932 r
.50837 .63738 .51178 .64069 .518 .63886 .5146 .63554 Mtetra
.647 .762 .933 r
.5146 .63554 .518 .63886 .52424 .63705 .52084 .63373 Mtetra
.648 .762 .933 r
.52084 .63373 .52424 .63705 .53049 .63523 .52711 .6319 Mtetra
.648 .762 .932 r
.52711 .6319 .53049 .63523 .53675 .6334 .53338 .63006 Mtetra
.647 .762 .933 r
.53338 .63006 .53675 .6334 .54303 .63159 .53967 .62823 Mtetra
.53967 .62823 .54303 .63159 .54933 .62976 .54597 .62641 Mtetra
.648 .762 .933 r
.54597 .62641 .54933 .62976 .55564 .62793 .55229 .62456 Mtetra
.647 .762 .933 r
.55229 .62456 .55564 .62793 .56196 .62611 .55862 .62273 Mtetra
.646 .762 .933 r
.55862 .62273 .56196 .62611 .5683 .62428 .56497 .6209 Mtetra
.647 .762 .933 r
.56497 .6209 .5683 .62428 .57465 .62245 .57133 .61906 Mtetra
.646 .762 .933 r
.57133 .61906 .57465 .62245 .58102 .62061 .57771 .61722 Mtetra
.645 .762 .933 r
.57771 .61722 .58102 .62061 .5874 .61879 .5841 .61538 Mtetra
.646 .762 .933 r
.5841 .61538 .5874 .61879 .59379 .61695 .59051 .61354 Mtetra
.59051 .61354 .59379 .61695 .6002 .61511 .59693 .61169 Mtetra
.645 .761 .934 r
.59693 .61169 .6002 .61511 .60663 .61328 .60336 .60985 Mtetra
.646 .762 .933 r
.60336 .60985 .60663 .61328 .61307 .61144 .60981 .608 Mtetra
.645 .762 .933 r
.60981 .608 .61307 .61144 .61953 .60959 .61628 .60615 Mtetra
.644 .761 .934 r
.61628 .60615 .61953 .60959 .626 .60776 .62276 .60431 Mtetra
.645 .761 .934 r
.62276 .60431 .626 .60776 .63248 .60592 .62926 .60246 Mtetra
.645 .761 .933 r
.62926 .60246 .63248 .60592 .63898 .60406 .63577 .60059 Mtetra
.644 .761 .934 r
.63577 .60059 .63898 .60406 .6455 .60223 .64229 .59875 Mtetra
.64229 .59875 .6455 .60223 .65203 .60038 .64884 .5969 Mtetra
.645 .761 .934 r
.64884 .5969 .65203 .60038 .65858 .59852 .65539 .59503 Mtetra
.643 .761 .934 r
.65539 .59503 .65858 .59852 .66514 .59668 .66197 .59318 Mtetra
.66197 .59318 .66514 .59668 .67172 .59484 .66856 .59133 Mtetra
.66856 .59133 .67172 .59484 .67831 .59298 .67516 .58947 Mtetra
.67516 .58947 .67831 .59298 .68492 .59113 .68178 .58761 Mtetra
.68178 .58761 .68492 .59113 .69155 .58928 .68842 .58574 Mtetra
.643 .76 .934 r
.68842 .58574 .69155 .58928 .69819 .58742 .69507 .58388 Mtetra
.642 .76 .934 r
.69507 .58388 .69819 .58742 .70485 .58556 .70174 .58201 Mtetra
.70174 .58201 .70485 .58556 .71152 .5837 .70842 .58014 Mtetra
.70842 .58014 .71152 .5837 .71821 .58184 .71512 .57827 Mtetra
.71512 .57827 .71821 .58184 .72492 .57998 .72184 .5764 Mtetra
.642 .76 .935 r
.72184 .5764 .72492 .57998 .73164 .57811 .72857 .57453 Mtetra
.641 .76 .935 r
.72857 .57453 .73164 .57811 .73838 .57625 .73532 .57266 Mtetra
.73532 .57266 .73838 .57625 .74513 .57438 .74208 .57078 Mtetra
.74208 .57078 .74513 .57438 .7519 .57252 .74887 .56891 Mtetra
.74887 .56891 .7519 .57252 .75869 .57065 .75567 .56703 Mtetra
.75567 .56703 .75869 .57065 .76549 .56878 .76248 .56515 Mtetra
.64 .76 .935 r
.76248 .56515 .76549 .56878 .77231 .5669 .76931 .56327 Mtetra
.64 .759 .935 r
.76931 .56327 .77231 .5669 .77915 .56503 .77616 .56139 Mtetra
.77616 .56139 .77915 .56503 .78601 .56316 .78303 .55951 Mtetra
.78303 .55951 .78601 .56316 .79288 .56128 .78991 .55762 Mtetra
.639 .759 .935 r
.78991 .55762 .79288 .56128 .79977 .5594 .79681 .55574 Mtetra
.79681 .55574 .79977 .5594 .80667 .55753 .80373 .55385 Mtetra
.80373 .55385 .80667 .55753 .81359 .55564 .81066 .55195 Mtetra
.64 .759 .935 r
.81066 .55195 .81359 .55564 .82053 .55375 .81761 .55005 Mtetra
.641 .76 .935 r
.81761 .55005 .82053 .55375 .82749 .55183 .82458 .54813 Mtetra
.645 .761 .934 r
.82458 .54813 .82749 .55183 .83445 .54984 .83156 .54613 Mtetra
.649 .763 .933 r
.83156 .54613 .83445 .54984 .84143 .5478 .83855 .54408 Mtetra
.672 .772 .925 r
.83855 .54408 .84143 .5478 .84839 .54538 .84552 .54164 Mtetra
.696 .781 .916 r
.84552 .54164 .84839 .54538 .85532 .54252 .85246 .53877 Mtetra
.731 .793 .901 r
.85246 .53877 .85532 .54252 .8622 .53897 .85935 .53522 Mtetra
.811 .814 .853 r
.85935 .53522 .8622 .53897 .86887 .53339 .86604 .52963 Mtetra
.854 .82 .815 r
.86604 .52963 .86887 .53339 .87539 .52625 .87257 .52247 Mtetra
.917 .818 .734 r
.87257 .52247 .87539 .52625 .8815 .51531 .8787 .51151 Mtetra
.954 .804 .656 r
.8787 .51151 .8815 .51531 .88706 .49961 .88428 .49579 Mtetra
.967 .793 .616 r
.88428 .49579 .88706 .49961 .89224 .48079 .88948 .47693 Mtetra
.982 .769 .54 r
.88948 .47693 .89224 .48079 .89639 .45345 .89366 .44956 Mtetra
.985 .76 .516 r
.89366 .44956 .89639 .45345 .90005 .42256 .89734 .41864 Mtetra
.943 .627 .409 r
.28102 .5772 .28462 .58039 .28803 .60929 .2844 .60613 Mtetra
.942 .619 .394 r
.2844 .60613 .28803 .60929 .29171 .63578 .28806 .63264 Mtetra
.935 .58 .322 r
.28806 .63264 .29171 .63578 .29601 .65444 .29234 .65132 Mtetra
.925 .547 .264 r
.29234 .65132 .29601 .65444 .30059 .66986 .29691 .66675 Mtetra
.875 .435 .087 r
.29691 .66675 .30059 .66986 .30556 .68014 .30187 .67704 Mtetra
.621 .097 0 r
.30187 .67704 .30556 .68014 .31087 .68579 .30718 .68268 Mtetra
0 .226 .693 r
.30718 .68268 .31087 .68579 .31633 .68944 .31264 .68634 Mtetra
.341 .64 .964 r
.31264 .68634 .31633 .68944 .32198 .69029 .3183 .68718 Mtetra
.498 .712 .967 r
.3183 .68718 .32198 .69029 .32771 .6901 .32403 .68699 Mtetra
.573 .74 .955 r
.32403 .68699 .32771 .6901 .3335 .68926 .32983 .68614 Mtetra
.632 .758 .938 r
.32983 .68614 .3335 .68926 .33933 .68775 .33567 .68463 Mtetra
.639 .76 .936 r
.33567 .68463 .33933 .68775 .34518 .68616 .34153 .68302 Mtetra
.648 .762 .933 r
.34153 .68302 .34518 .68616 .35106 .68444 .34741 .6813 Mtetra
.652 .763 .931 r
.34741 .6813 .35106 .68444 .35694 .68266 .3533 .67952 Mtetra
.653 .764 .931 r
.3533 .67952 .35694 .68266 .36284 .68087 .35921 .67772 Mtetra
.35921 .67772 .36284 .68087 .36876 .67908 .36513 .67592 Mtetra
.653 .764 .93 r
.36513 .67592 .36876 .67908 .37468 .67727 .37107 .6741 Mtetra
.37107 .6741 .37468 .67727 .38062 .67546 .37701 .67229 Mtetra
.652 .763 .931 r
.37701 .67229 .38062 .67546 .38657 .67366 .38297 .67048 Mtetra
.653 .764 .931 r
.38297 .67048 .38657 .67366 .39254 .67186 .38894 .66867 Mtetra
.38894 .66867 .39254 .67186 .39851 .67004 .39493 .66685 Mtetra
.651 .763 .931 r
.39493 .66685 .39851 .67004 .4045 .66824 .40093 .66504 Mtetra
.652 .763 .931 r
.40093 .66504 .4045 .66824 .41051 .66644 .40694 .66323 Mtetra
.40694 .66323 .41051 .66644 .41652 .66462 .41296 .66141 Mtetra
.651 .763 .931 r
.41296 .66141 .41652 .66462 .42255 .66282 .419 .65959 Mtetra
.419 .65959 .42255 .66282 .42859 .66101 .42505 .65778 Mtetra
.652 .763 .931 r
.42505 .65778 .42859 .66101 .43465 .65919 .43112 .65595 Mtetra
.651 .763 .931 r
.43112 .65595 .43465 .65919 .44072 .65738 .43719 .65414 Mtetra
.65 .763 .932 r
.43719 .65414 .44072 .65738 .4468 .65558 .44328 .65232 Mtetra
.651 .763 .931 r
.44328 .65232 .4468 .65558 .45289 .65375 .44939 .65049 Mtetra
.65 .763 .932 r
.44939 .65049 .45289 .65375 .459 .65194 .45551 .64867 Mtetra
.649 .762 .932 r
.45551 .64867 .459 .65194 .46513 .65013 .46164 .64685 Mtetra
.65 .763 .932 r
.46164 .64685 .46513 .65013 .47126 .64831 .46778 .64502 Mtetra
.46778 .64502 .47126 .64831 .47741 .64648 .47394 .64319 Mtetra
.649 .762 .932 r
.47394 .64319 .47741 .64648 .48357 .64467 .48011 .64137 Mtetra
.48011 .64137 .48357 .64467 .48975 .64285 .4863 .63954 Mtetra
.4863 .63954 .48975 .64285 .49594 .64102 .4925 .6377 Mtetra
.648 .762 .932 r
.4925 .6377 .49594 .64102 .50215 .6392 .49871 .63588 Mtetra
.649 .762 .932 r
.49871 .63588 .50215 .6392 .50837 .63738 .50494 .63404 Mtetra
.50494 .63404 .50837 .63738 .5146 .63554 .51118 .6322 Mtetra
.647 .762 .932 r
.51118 .6322 .5146 .63554 .52084 .63373 .51744 .63038 Mtetra
.648 .762 .932 r
.51744 .63038 .52084 .63373 .52711 .6319 .52371 .62854 Mtetra
.52371 .62854 .52711 .6319 .53338 .63006 .52999 .6267 Mtetra
.647 .762 .933 r
.52999 .6267 .53338 .63006 .53967 .62823 .53629 .62486 Mtetra
.53629 .62486 .53967 .62823 .54597 .62641 .54261 .62303 Mtetra
.648 .762 .932 r
.54261 .62303 .54597 .62641 .55229 .62456 .54893 .62118 Mtetra
.647 .761 .933 r
.54893 .62118 .55229 .62456 .55862 .62273 .55528 .61934 Mtetra
.646 .761 .933 r
.55528 .61934 .55862 .62273 .56497 .6209 .56163 .6175 Mtetra
.647 .762 .933 r
.56163 .6175 .56497 .6209 .57133 .61906 .568 .61565 Mtetra
.646 .761 .933 r
.568 .61565 .57133 .61906 .57771 .61722 .57439 .6138 Mtetra
.645 .761 .933 r
.57439 .6138 .57771 .61722 .5841 .61538 .58079 .61196 Mtetra
.646 .761 .933 r
.58079 .61196 .5841 .61538 .59051 .61354 .58721 .6101 Mtetra
.58721 .6101 .59051 .61354 .59693 .61169 .59364 .60825 Mtetra
.645 .761 .933 r
.59364 .60825 .59693 .61169 .60336 .60985 .60008 .6064 Mtetra
.646 .761 .933 r
.60008 .6064 .60336 .60985 .60981 .608 .60654 .60454 Mtetra
.60654 .60454 .60981 .608 .61628 .60615 .61302 .60268 Mtetra
.644 .761 .933 r
.61302 .60268 .61628 .60615 .62276 .60431 .61951 .60084 Mtetra
.645 .761 .933 r
.61951 .60084 .62276 .60431 .62926 .60246 .62602 .59897 Mtetra
.62602 .59897 .62926 .60246 .63577 .60059 .63254 .5971 Mtetra
.644 .76 .934 r
.63254 .5971 .63577 .60059 .64229 .59875 .63907 .59525 Mtetra
.644 .761 .934 r
.63907 .59525 .64229 .59875 .64884 .5969 .64563 .59339 Mtetra
.645 .761 .933 r
.64563 .59339 .64884 .5969 .65539 .59503 .65219 .59152 Mtetra
.643 .76 .934 r
.65219 .59152 .65539 .59503 .66197 .59318 .65878 .58966 Mtetra
.65878 .58966 .66197 .59318 .66856 .59133 .66538 .5878 Mtetra
.66538 .5878 .66856 .59133 .67516 .58947 .67199 .58593 Mtetra
.67199 .58593 .67516 .58947 .68178 .58761 .67862 .58406 Mtetra
.67862 .58406 .68178 .58761 .68842 .58574 .68527 .58219 Mtetra
.68527 .58219 .68842 .58574 .69507 .58388 .69193 .58032 Mtetra
.642 .76 .934 r
.69193 .58032 .69507 .58388 .70174 .58201 .69861 .57844 Mtetra
.69861 .57844 .70174 .58201 .70842 .58014 .70531 .57657 Mtetra
.70531 .57657 .70842 .58014 .71512 .57827 .71202 .57469 Mtetra
.71202 .57469 .71512 .57827 .72184 .5764 .71874 .57281 Mtetra
.71874 .57281 .72184 .5764 .72857 .57453 .72549 .57093 Mtetra
.641 .76 .935 r
.72549 .57093 .72857 .57453 .73532 .57266 .73225 .56905 Mtetra
.73225 .56905 .73532 .57266 .74208 .57078 .73902 .56717 Mtetra
.73902 .56717 .74208 .57078 .74887 .56891 .74582 .56528 Mtetra
.74582 .56528 .74887 .56891 .75567 .56703 .75263 .5634 Mtetra
.75263 .5634 .75567 .56703 .76248 .56515 .75945 .56151 Mtetra
.64 .76 .935 r
.75945 .56151 .76248 .56515 .76931 .56327 .7663 .55962 Mtetra
.64 .759 .935 r
.7663 .55962 .76931 .56327 .77616 .56139 .77316 .55773 Mtetra
.77316 .55773 .77616 .56139 .78303 .55951 .78004 .55584 Mtetra
.78004 .55584 .78303 .55951 .78991 .55762 .78693 .55394 Mtetra
.639 .759 .935 r
.78693 .55394 .78991 .55762 .79681 .55574 .79384 .55205 Mtetra
.79384 .55205 .79681 .55574 .80373 .55385 .80077 .55016 Mtetra
.80077 .55016 .80373 .55385 .81066 .55195 .80772 .54825 Mtetra
.64 .759 .935 r
.80772 .54825 .81066 .55195 .81761 .55005 .81468 .54634 Mtetra
.641 .76 .935 r
.81468 .54634 .81761 .55005 .82458 .54813 .82166 .5444 Mtetra
.645 .761 .934 r
.82166 .5444 .82458 .54813 .83156 .54613 .82865 .5424 Mtetra
.649 .763 .933 r
.82865 .5424 .83156 .54613 .83855 .54408 .83565 .54034 Mtetra
.672 .772 .925 r
.83565 .54034 .83855 .54408 .84552 .54164 .84263 .53789 Mtetra
.696 .781 .916 r
.84263 .53789 .84552 .54164 .85246 .53877 .84959 .53502 Mtetra
.731 .793 .901 r
.84959 .53502 .85246 .53877 .85935 .53522 .85649 .53145 Mtetra
.811 .814 .853 r
.85649 .53145 .85935 .53522 .86604 .52963 .8632 .52584 Mtetra
.854 .82 .815 r
.8632 .52584 .86604 .52963 .87257 .52247 .86974 .51867 Mtetra
.917 .818 .734 r
.86974 .51867 .87257 .52247 .8787 .51151 .87589 .50769 Mtetra
.954 .804 .656 r
.87589 .50769 .8787 .51151 .88428 .49579 .88149 .49194 Mtetra
.967 .793 .616 r
.88149 .49194 .88428 .49579 .88948 .47693 .88671 .47306 Mtetra
.982 .769 .54 r
.88671 .47306 .88948 .47693 .89366 .44956 .89092 .44566 Mtetra
.985 .76 .516 r
.89092 .44566 .89366 .44956 .89734 .41864 .89463 .41469 Mtetra
.943 .627 .409 r
.27741 .574 .28102 .5772 .2844 .60613 .28076 .60295 Mtetra
.942 .619 .394 r
.28076 .60295 .2844 .60613 .28806 .63264 .28439 .62948 Mtetra
.935 .58 .322 r
.28439 .62948 .28806 .63264 .29234 .65132 .28865 .64818 Mtetra
.925 .547 .264 r
.28865 .64818 .29234 .65132 .29691 .66675 .29321 .66362 Mtetra
.875 .435 .088 r
.29321 .66362 .29691 .66675 .30187 .67704 .29817 .67392 Mtetra
.621 .097 0 r
.29817 .67392 .30187 .67704 .30718 .68268 .30347 .67957 Mtetra
0 .226 .692 r
.30347 .67957 .30718 .68268 .31264 .68634 .30894 .68322 Mtetra
.341 .64 .964 r
.30894 .68322 .31264 .68634 .3183 .68718 .3146 .68406 Mtetra
.498 .712 .967 r
.3146 .68406 .3183 .68718 .32403 .68699 .32034 .68387 Mtetra
.573 .74 .955 r
.32034 .68387 .32403 .68699 .32983 .68614 .32614 .68301 Mtetra
.632 .758 .938 r
.32614 .68301 .32983 .68614 .33567 .68463 .33199 .68149 Mtetra
.639 .76 .936 r
.33199 .68149 .33567 .68463 .34153 .68302 .33786 .67988 Mtetra
.648 .762 .933 r
.33786 .67988 .34153 .68302 .34741 .6813 .34374 .67815 Mtetra
.652 .763 .931 r
.34374 .67815 .34741 .6813 .3533 .67952 .34965 .67636 Mtetra
.653 .764 .931 r
.34965 .67636 .3533 .67952 .35921 .67772 .35556 .67455 Mtetra
.35556 .67455 .35921 .67772 .36513 .67592 .36149 .67274 Mtetra
.653 .764 .93 r
.36149 .67274 .36513 .67592 .37107 .6741 .36744 .67092 Mtetra
.36744 .67092 .37107 .6741 .37701 .67229 .37339 .6691 Mtetra
.652 .763 .931 r
.37339 .6691 .37701 .67229 .38297 .67048 .37936 .66729 Mtetra
.653 .764 .931 r
.37936 .66729 .38297 .67048 .38894 .66867 .38534 .66547 Mtetra
.38534 .66547 .38894 .66867 .39493 .66685 .39133 .66364 Mtetra
.651 .763 .931 r
.39133 .66364 .39493 .66685 .40093 .66504 .39734 .66183 Mtetra
.652 .763 .931 r
.39734 .66183 .40093 .66504 .40694 .66323 .40336 .66001 Mtetra
.40336 .66001 .40694 .66323 .41296 .66141 .40939 .65818 Mtetra
.651 .763 .931 r
.40939 .65818 .41296 .66141 .419 .65959 .41544 .65636 Mtetra
.41544 .65636 .419 .65959 .42505 .65778 .4215 .65454 Mtetra
.652 .763 .931 r
.4215 .65454 .42505 .65778 .43112 .65595 .42757 .6527 Mtetra
.651 .763 .931 r
.42757 .6527 .43112 .65595 .43719 .65414 .43366 .65088 Mtetra
.65 .763 .932 r
.43366 .65088 .43719 .65414 .44328 .65232 .43976 .64905 Mtetra
.651 .763 .931 r
.43976 .64905 .44328 .65232 .44939 .65049 .44587 .64722 Mtetra
.65 .763 .932 r
.44587 .64722 .44939 .65049 .45551 .64867 .452 .64538 Mtetra
.649 .763 .932 r
.452 .64538 .45551 .64867 .46164 .64685 .45814 .64356 Mtetra
.65 .763 .932 r
.45814 .64356 .46164 .64685 .46778 .64502 .46429 .64172 Mtetra
.46429 .64172 .46778 .64502 .47394 .64319 .47046 .63988 Mtetra
.649 .762 .932 r
.47046 .63988 .47394 .64319 .48011 .64137 .47664 .63805 Mtetra
.47664 .63805 .48011 .64137 .4863 .63954 .48283 .63621 Mtetra
.48283 .63621 .4863 .63954 .4925 .6377 .48904 .63437 Mtetra
.648 .762 .932 r
.48904 .63437 .4925 .6377 .49871 .63588 .49527 .63254 Mtetra
.649 .762 .932 r
.49527 .63254 .49871 .63588 .50494 .63404 .5015 .6307 Mtetra
.5015 .6307 .50494 .63404 .51118 .6322 .50775 .62885 Mtetra
.647 .762 .932 r
.50775 .62885 .51118 .6322 .51744 .63038 .51402 .62701 Mtetra
.648 .762 .932 r
.51402 .62701 .51744 .63038 .52371 .62854 .5203 .62517 Mtetra
.5203 .62517 .52371 .62854 .52999 .6267 .52659 .62332 Mtetra
.647 .762 .933 r
.52659 .62332 .52999 .6267 .53629 .62486 .5329 .62148 Mtetra
.5329 .62148 .53629 .62486 .54261 .62303 .53922 .61963 Mtetra
.648 .762 .932 r
.53922 .61963 .54261 .62303 .54893 .62118 .54556 .61778 Mtetra
.647 .762 .933 r
.54556 .61778 .54893 .62118 .55528 .61934 .55191 .61593 Mtetra
.646 .761 .933 r
.55191 .61593 .55528 .61934 .56163 .6175 .55828 .61408 Mtetra
.647 .762 .933 r
.55828 .61408 .56163 .6175 .568 .61565 .56466 .61222 Mtetra
.646 .761 .933 r
.56466 .61222 .568 .61565 .57439 .6138 .57106 .61037 Mtetra
.645 .761 .933 r
.57106 .61037 .57439 .6138 .58079 .61196 .57747 .60852 Mtetra
.646 .761 .933 r
.57747 .60852 .58079 .61196 .58721 .6101 .58389 .60665 Mtetra
.58389 .60665 .58721 .6101 .59364 .60825 .59033 .60479 Mtetra
.645 .761 .933 r
.59033 .60479 .59364 .60825 .60008 .6064 .59679 .60294 Mtetra
.646 .761 .933 r
.59679 .60294 .60008 .6064 .60654 .60454 .60326 .60107 Mtetra
.60326 .60107 .60654 .60454 .61302 .60268 .60974 .5992 Mtetra
.644 .761 .933 r
.60974 .5992 .61302 .60268 .61951 .60084 .61625 .59735 Mtetra
.645 .761 .933 r
.61625 .59735 .61951 .60084 .62602 .59897 .62276 .59548 Mtetra
.62276 .59548 .62602 .59897 .63254 .5971 .62929 .5936 Mtetra
.644 .76 .934 r
.62929 .5936 .63254 .5971 .63907 .59525 .63584 .59174 Mtetra
.644 .761 .934 r
.63584 .59174 .63907 .59525 .64563 .59339 .6424 .58987 Mtetra
.645 .761 .933 r
.6424 .58987 .64563 .59339 .65219 .59152 .64898 .58799 Mtetra
.643 .76 .934 r
.64898 .58799 .65219 .59152 .65878 .58966 .65557 .58612 Mtetra
.65557 .58612 .65878 .58966 .66538 .5878 .66218 .58425 Mtetra
.66218 .58425 .66538 .5878 .67199 .58593 .66881 .58238 Mtetra
.66881 .58238 .67199 .58593 .67862 .58406 .67545 .5805 Mtetra
.67545 .5805 .67862 .58406 .68527 .58219 .68211 .57862 Mtetra
.68211 .57862 .68527 .58219 .69193 .58032 .68878 .57674 Mtetra
.642 .76 .934 r
.68878 .57674 .69193 .58032 .69861 .57844 .69547 .57486 Mtetra
.69547 .57486 .69861 .57844 .70531 .57657 .70218 .57297 Mtetra
.70218 .57297 .70531 .57657 .71202 .57469 .7089 .57109 Mtetra
.7089 .57109 .71202 .57469 .71874 .57281 .71564 .5692 Mtetra
.71564 .5692 .71874 .57281 .72549 .57093 .72239 .56731 Mtetra
.641 .76 .935 r
.72239 .56731 .72549 .57093 .73225 .56905 .72916 .56543 Mtetra
.72916 .56543 .73225 .56905 .73902 .56717 .73595 .56353 Mtetra
.73595 .56353 .73902 .56717 .74582 .56528 .74276 .56164 Mtetra
.74276 .56164 .74582 .56528 .75263 .5634 .74958 .55975 Mtetra
.74958 .55975 .75263 .5634 .75945 .56151 .75642 .55785 Mtetra
.64 .76 .935 r
.75642 .55785 .75945 .56151 .7663 .55962 .76327 .55595 Mtetra
.64 .759 .935 r
.76327 .55595 .7663 .55962 .77316 .55773 .77014 .55405 Mtetra
.77014 .55405 .77316 .55773 .78004 .55584 .77703 .55215 Mtetra
.77703 .55215 .78004 .55584 .78693 .55394 .78394 .55025 Mtetra
.639 .759 .935 r
.78394 .55025 .78693 .55394 .79384 .55205 .79086 .54835 Mtetra
.79086 .54835 .79384 .55205 .80077 .55016 .7978 .54644 Mtetra
.7978 .54644 .80077 .55016 .80772 .54825 .80476 .54453 Mtetra
.64 .759 .935 r
.80476 .54453 .80772 .54825 .81468 .54634 .81173 .54261 Mtetra
.641 .76 .935 r
.81173 .54261 .81468 .54634 .82166 .5444 .81872 .54067 Mtetra
.645 .761 .934 r
.81872 .54067 .82166 .5444 .82865 .5424 .82572 .53865 Mtetra
.649 .763 .933 r
.82572 .53865 .82865 .5424 .83565 .54034 .83274 .53658 Mtetra
.672 .772 .925 r
.83274 .53658 .83565 .54034 .84263 .53789 .83973 .53413 Mtetra
.696 .781 .916 r
.83973 .53413 .84263 .53789 .84959 .53502 .8467 .53124 Mtetra
.731 .793 .901 r
.8467 .53124 .84959 .53502 .85649 .53145 .85362 .52766 Mtetra
.811 .814 .853 r
.85362 .52766 .85649 .53145 .8632 .52584 .86034 .52204 Mtetra
.854 .82 .815 r
.86034 .52204 .8632 .52584 .86974 .51867 .8669 .51485 Mtetra
.917 .818 .734 r
.8669 .51485 .86974 .51867 .87589 .50769 .87306 .50385 Mtetra
.954 .804 .656 r
.87306 .50385 .87589 .50769 .88149 .49194 .87869 .48808 Mtetra
.967 .793 .616 r
.87869 .48808 .88149 .49194 .88671 .47306 .88393 .46918 Mtetra
.982 .769 .54 r
.88393 .46918 .88671 .47306 .89092 .44566 .88817 .44173 Mtetra
.985 .76 .516 r
.88817 .44173 .89092 .44566 .89463 .41469 .89191 .41073 Mtetra
.943 .627 .409 r
.27379 .57079 .27741 .574 .28076 .60295 .27711 .59976 Mtetra
.942 .619 .394 r
.27711 .59976 .28076 .60295 .28439 .62948 .28071 .62632 Mtetra
.935 .58 .322 r
.28071 .62632 .28439 .62948 .28865 .64818 .28496 .64503 Mtetra
.925 .547 .264 r
.28496 .64503 .28865 .64818 .29321 .66362 .2895 .66049 Mtetra
.875 .435 .088 r
.2895 .66049 .29321 .66362 .29817 .67392 .29445 .67079 Mtetra
.621 .097 0 r
.29445 .67079 .29817 .67392 .30347 .67957 .29975 .67644 Mtetra
0 .225 .692 r
.29975 .67644 .30347 .67957 .30894 .68322 .30522 .68009 Mtetra
.34 .64 .964 r
.30522 .68009 .30894 .68322 .3146 .68406 .31088 .68093 Mtetra
.497 .712 .967 r
.31088 .68093 .3146 .68406 .32034 .68387 .31663 .68073 Mtetra
.573 .74 .955 r
.31663 .68073 .32034 .68387 .32614 .68301 .32244 .67986 Mtetra
.632 .758 .939 r
.32244 .67986 .32614 .68301 .33199 .68149 .3283 .67834 Mtetra
.639 .76 .936 r
.3283 .67834 .33199 .68149 .33786 .67988 .33417 .67672 Mtetra
.648 .762 .933 r
.33417 .67672 .33786 .67988 .34374 .67815 .34007 .67499 Mtetra
.652 .764 .931 r
.34007 .67499 .34374 .67815 .34965 .67636 .34598 .67319 Mtetra
.653 .764 .931 r
.34598 .67319 .34965 .67636 .35556 .67455 .3519 .67138 Mtetra
.3519 .67138 .35556 .67455 .36149 .67274 .35784 .66956 Mtetra
.35784 .66956 .36149 .67274 .36744 .67092 .36379 .66773 Mtetra
.36379 .66773 .36744 .67092 .37339 .6691 .36975 .6659 Mtetra
.652 .764 .931 r
.36975 .6659 .37339 .6691 .37936 .66729 .37573 .66409 Mtetra
.653 .764 .931 r
.37573 .66409 .37936 .66729 .38534 .66547 .38172 .66226 Mtetra
.38172 .66226 .38534 .66547 .39133 .66364 .38772 .66042 Mtetra
.651 .763 .931 r
.38772 .66042 .39133 .66364 .39734 .66183 .39374 .6586 Mtetra
.652 .763 .931 r
.39374 .6586 .39734 .66183 .40336 .66001 .39976 .65677 Mtetra
.652 .764 .931 r
.39976 .65677 .40336 .66001 .40939 .65818 .40581 .65494 Mtetra
.651 .763 .931 r
.40581 .65494 .40939 .65818 .41544 .65636 .41186 .65311 Mtetra
.651 .763 .932 r
.41186 .65311 .41544 .65636 .4215 .65454 .41793 .65128 Mtetra
.651 .764 .931 r
.41793 .65128 .4215 .65454 .42757 .6527 .42401 .64944 Mtetra
.651 .763 .932 r
.42401 .64944 .42757 .6527 .43366 .65088 .43011 .64761 Mtetra
.65 .763 .932 r
.43011 .64761 .43366 .65088 .43976 .64905 .43621 .64578 Mtetra
.651 .763 .932 r
.43621 .64578 .43976 .64905 .44587 .64722 .44234 .64393 Mtetra
.65 .763 .932 r
.44234 .64393 .44587 .64722 .452 .64538 .44847 .6421 Mtetra
.649 .763 .932 r
.44847 .6421 .452 .64538 .45814 .64356 .45462 .64026 Mtetra
.65 .763 .932 r
.45462 .64026 .45814 .64356 .46429 .64172 .46078 .63842 Mtetra
.46078 .63842 .46429 .64172 .47046 .63988 .46696 .63657 Mtetra
.649 .763 .933 r
.46696 .63657 .47046 .63988 .47664 .63805 .47315 .63474 Mtetra
.649 .763 .932 r
.47315 .63474 .47664 .63805 .48283 .63621 .47935 .63289 Mtetra
.649 .763 .933 r
.47935 .63289 .48283 .63621 .48904 .63437 .48557 .63104 Mtetra
.648 .763 .933 r
.48557 .63104 .48904 .63437 .49527 .63254 .4918 .6292 Mtetra
.4918 .6292 .49527 .63254 .5015 .6307 .49805 .62735 Mtetra
.649 .763 .933 r
.49805 .62735 .5015 .6307 .50775 .62885 .50431 .6255 Mtetra
.647 .763 .933 r
.50431 .6255 .50775 .62885 .51402 .62701 .51058 .62366 Mtetra
.648 .763 .933 r
.51058 .62366 .51402 .62701 .5203 .62517 .51687 .62181 Mtetra
.51687 .62181 .5203 .62517 .52659 .62332 .52318 .61994 Mtetra
.647 .763 .933 r
.52318 .61994 .52659 .62332 .5329 .62148 .52949 .6181 Mtetra
.52949 .6181 .5329 .62148 .53922 .61963 .53583 .61624 Mtetra
.648 .763 .933 r
.53583 .61624 .53922 .61963 .54556 .61778 .54217 .61438 Mtetra
.647 .763 .933 r
.54217 .61438 .54556 .61778 .55191 .61593 .54854 .61252 Mtetra
.646 .762 .934 r
.54854 .61252 .55191 .61593 .55828 .61408 .55491 .61067 Mtetra
.647 .763 .933 r
.55491 .61067 .55828 .61408 .56466 .61222 .5613 .6088 Mtetra
.646 .762 .934 r
.5613 .6088 .56466 .61222 .57106 .61037 .56771 .60694 Mtetra
.645 .762 .934 r
.56771 .60694 .57106 .61037 .57747 .60852 .57413 .60508 Mtetra
.646 .762 .934 r
.57413 .60508 .57747 .60852 .58389 .60665 .58056 .60321 Mtetra
.58056 .60321 .58389 .60665 .59033 .60479 .58701 .60134 Mtetra
.645 .762 .934 r
.58701 .60134 .59033 .60479 .59679 .60294 .59348 .59948 Mtetra
.59348 .59948 .59679 .60294 .60326 .60107 .59996 .5976 Mtetra
.59996 .5976 .60326 .60107 .60974 .5992 .60646 .59573 Mtetra
.644 .762 .934 r
.60646 .59573 .60974 .5992 .61625 .59735 .61297 .59386 Mtetra
.645 .762 .934 r
.61297 .59386 .61625 .59735 .62276 .59548 .61949 .59199 Mtetra
.61949 .59199 .62276 .59548 .62929 .5936 .62604 .5901 Mtetra
.643 .762 .934 r
.62604 .5901 .62929 .5936 .63584 .59174 .63259 .58823 Mtetra
.644 .762 .934 r
.63259 .58823 .63584 .59174 .6424 .58987 .63917 .58635 Mtetra
.63917 .58635 .6424 .58987 .64898 .58799 .64575 .58446 Mtetra
.643 .761 .935 r
.64575 .58446 .64898 .58799 .65557 .58612 .65236 .58259 Mtetra
.65236 .58259 .65557 .58612 .66218 .58425 .65898 .58071 Mtetra
.65898 .58071 .66218 .58425 .66881 .58238 .66562 .57882 Mtetra
.66562 .57882 .66881 .58238 .67545 .5805 .67227 .57694 Mtetra
.67227 .57694 .67545 .5805 .68211 .57862 .67894 .57505 Mtetra
.67894 .57505 .68211 .57862 .68878 .57674 .68562 .57316 Mtetra
.642 .761 .935 r
.68562 .57316 .68878 .57674 .69547 .57486 .69232 .57127 Mtetra
.69232 .57127 .69547 .57486 .70218 .57297 .69904 .56938 Mtetra
.69904 .56938 .70218 .57297 .7089 .57109 .70577 .56748 Mtetra
.642 .76 .935 r
.70577 .56748 .7089 .57109 .71564 .5692 .71252 .56559 Mtetra
.71252 .56559 .71564 .5692 .72239 .56731 .71928 .56369 Mtetra
.641 .76 .935 r
.71928 .56369 .72239 .56731 .72916 .56543 .72607 .56179 Mtetra
.72607 .56179 .72916 .56543 .73595 .56353 .73287 .55989 Mtetra
.73287 .55989 .73595 .56353 .74276 .56164 .73968 .55799 Mtetra
.73968 .55799 .74276 .56164 .74958 .55975 .74651 .55608 Mtetra
.74651 .55608 .74958 .55975 .75642 .55785 .75336 .55418 Mtetra
.64 .76 .935 r
.75336 .55418 .75642 .55785 .76327 .55595 .76023 .55227 Mtetra
.76023 .55227 .76327 .55595 .77014 .55405 .76711 .55036 Mtetra
.76711 .55036 .77014 .55405 .77703 .55215 .77401 .54846 Mtetra
.64 .759 .935 r
.77401 .54846 .77703 .55215 .78394 .55025 .78093 .54655 Mtetra
.639 .759 .935 r
.78093 .54655 .78394 .55025 .79086 .54835 .78787 .54463 Mtetra
.78787 .54463 .79086 .54835 .7978 .54644 .79482 .54272 Mtetra
.79482 .54272 .7978 .54644 .80476 .54453 .80179 .5408 Mtetra
.64 .759 .935 r
.80179 .5408 .80476 .54453 .81173 .54261 .80877 .53887 Mtetra
.641 .76 .935 r
.80877 .53887 .81173 .54261 .81872 .54067 .81578 .53692 Mtetra
.645 .762 .934 r
.81578 .53692 .81872 .54067 .82572 .53865 .82279 .53489 Mtetra
.649 .763 .933 r
.82279 .53489 .82572 .53865 .83274 .53658 .82981 .53281 Mtetra
.672 .772 .926 r
.82981 .53281 .83274 .53658 .83973 .53413 .83682 .53035 Mtetra
.696 .781 .917 r
.83682 .53035 .83973 .53413 .8467 .53124 .8438 .52745 Mtetra
.731 .793 .901 r
.8438 .52745 .8467 .53124 .85362 .52766 .85073 .52386 Mtetra
.811 .814 .853 r
.85073 .52386 .85362 .52766 .86034 .52204 .85747 .51823 Mtetra
.854 .82 .815 r
.85747 .51823 .86034 .52204 .8669 .51485 .86405 .51102 Mtetra
.917 .818 .734 r
.86405 .51102 .8669 .51485 .87306 .50385 .87022 .5 Mtetra
.954 .804 .656 r
.87022 .5 .87306 .50385 .87869 .48808 .87587 .48421 Mtetra
.967 .793 .616 r
.87587 .48421 .87869 .48808 .88393 .46918 .88114 .46527 Mtetra
.982 .769 .54 r
.88114 .46527 .88393 .46918 .88817 .44173 .8854 .4378 Mtetra
.985 .76 .516 r
.8854 .4378 .88817 .44173 .89191 .41073 .88917 .40675 Mtetra
.943 .627 .409 r
.27015 .56756 .27379 .57079 .27711 .59976 .27344 .59656 Mtetra
.942 .619 .394 r
.27344 .59656 .27711 .59976 .28071 .62632 .27701 .62314 Mtetra
.935 .58 .322 r
.27701 .62314 .28071 .62632 .28496 .64503 .28124 .64186 Mtetra
.925 .547 .264 r
.28124 .64186 .28496 .64503 .2895 .66049 .28577 .65733 Mtetra
.875 .435 .087 r
.28577 .65733 .2895 .66049 .29445 .67079 .29072 .66764 Mtetra
.621 .097 0 r
.29072 .66764 .29445 .67079 .29975 .67644 .29602 .6733 Mtetra
0 .226 .693 r
.29602 .6733 .29975 .67644 .30522 .68009 .30148 .67695 Mtetra
.341 .64 .964 r
.30148 .67695 .30522 .68009 .31088 .68093 .30716 .67778 Mtetra
.498 .712 .967 r
.30716 .67778 .31088 .68093 .31663 .68073 .31291 .67758 Mtetra
.573 .74 .955 r
.31291 .67758 .31663 .68073 .32244 .67986 .31872 .6767 Mtetra
.632 .758 .938 r
.31872 .6767 .32244 .67986 .3283 .67834 .32459 .67518 Mtetra
.639 .76 .936 r
.32459 .67518 .3283 .67834 .33417 .67672 .33047 .67355 Mtetra
.648 .762 .932 r
.33047 .67355 .33417 .67672 .34007 .67499 .33637 .67181 Mtetra
.652 .763 .931 r
.33637 .67181 .34007 .67499 .34598 .67319 .34229 .67 Mtetra
.653 .763 .931 r
.34229 .67 .34598 .67319 .3519 .67138 .34823 .66818 Mtetra
.34823 .66818 .3519 .67138 .35784 .66956 .35417 .66636 Mtetra
.653 .764 .93 r
.35417 .66636 .35784 .66956 .36379 .66773 .36013 .66453 Mtetra
.36013 .66453 .36379 .66773 .36975 .6659 .3661 .66269 Mtetra
.652 .763 .931 r
.3661 .66269 .36975 .6659 .37573 .66409 .37209 .66086 Mtetra
.653 .763 .931 r
.37209 .66086 .37573 .66409 .38172 .66226 .37808 .65903 Mtetra
.653 .763 .93 r
.37808 .65903 .38172 .66226 .38772 .66042 .38409 .65718 Mtetra
.651 .763 .931 r
.38409 .65718 .38772 .66042 .39374 .6586 .39012 .65536 Mtetra
.652 .763 .931 r
.39012 .65536 .39374 .6586 .39976 .65677 .39615 .65352 Mtetra
.39615 .65352 .39976 .65677 .40581 .65494 .40221 .65168 Mtetra
.651 .763 .931 r
.40221 .65168 .40581 .65494 .41186 .65311 .40827 .64984 Mtetra
.40827 .64984 .41186 .65311 .41793 .65128 .41434 .64801 Mtetra
.652 .763 .931 r
.41434 .64801 .41793 .65128 .42401 .64944 .42044 .64616 Mtetra
.651 .763 .931 r
.42044 .64616 .42401 .64944 .43011 .64761 .42654 .64432 Mtetra
.65 .763 .932 r
.42654 .64432 .43011 .64761 .43621 .64578 .43266 .64248 Mtetra
.651 .763 .931 r
.43266 .64248 .43621 .64578 .44234 .64393 .43879 .64063 Mtetra
.65 .763 .932 r
.43879 .64063 .44234 .64393 .44847 .6421 .44493 .63879 Mtetra
.649 .763 .932 r
.44493 .63879 .44847 .6421 .45462 .64026 .45109 .63695 Mtetra
.65 .763 .932 r
.45109 .63695 .45462 .64026 .46078 .63842 .45726 .63509 Mtetra
.45726 .63509 .46078 .63842 .46696 .63657 .46345 .63324 Mtetra
.649 .763 .932 r
.46345 .63324 .46696 .63657 .47315 .63474 .46964 .6314 Mtetra
.46964 .6314 .47315 .63474 .47935 .63289 .47586 .62955 Mtetra
.47586 .62955 .47935 .63289 .48557 .63104 .48209 .62769 Mtetra
.648 .762 .933 r
.48209 .62769 .48557 .63104 .4918 .6292 .48833 .62584 Mtetra
.648 .763 .932 r
.48833 .62584 .4918 .6292 .49805 .62735 .49458 .62399 Mtetra
.649 .763 .932 r
.49458 .62399 .49805 .62735 .50431 .6255 .50085 .62212 Mtetra
.647 .762 .933 r
.50085 .62212 .50431 .6255 .51058 .62366 .50714 .62027 Mtetra
.648 .762 .933 r
.50714 .62027 .51058 .62366 .51687 .62181 .51343 .61841 Mtetra
.648 .762 .932 r
.51343 .61841 .51687 .62181 .52318 .61994 .51975 .61654 Mtetra
.647 .762 .933 r
.51975 .61654 .52318 .61994 .52949 .6181 .52607 .61469 Mtetra
.52607 .61469 .52949 .6181 .53583 .61624 .53242 .61283 Mtetra
.648 .762 .933 r
.53242 .61283 .53583 .61624 .54217 .61438 .53877 .61096 Mtetra
.647 .762 .933 r
.53877 .61096 .54217 .61438 .54854 .61252 .54514 .60909 Mtetra
.646 .762 .933 r
.54514 .60909 .54854 .61252 .55491 .61067 .55153 .60723 Mtetra
.647 .762 .933 r
.55153 .60723 .55491 .61067 .5613 .6088 .55793 .60535 Mtetra
.646 .762 .933 r
.55793 .60535 .5613 .6088 .56771 .60694 .56434 .60348 Mtetra
.645 .762 .933 r
.56434 .60348 .56771 .60694 .57413 .60508 .57078 .60162 Mtetra
.646 .762 .933 r
.57078 .60162 .57413 .60508 .58056 .60321 .57722 .59974 Mtetra
.57722 .59974 .58056 .60321 .58701 .60134 .58368 .59786 Mtetra
.645 .761 .934 r
.58368 .59786 .58701 .60134 .59348 .59948 .59016 .59599 Mtetra
.646 .762 .933 r
.59016 .59599 .59348 .59948 .59996 .5976 .59665 .59411 Mtetra
.645 .762 .933 r
.59665 .59411 .59996 .5976 .60646 .59573 .60315 .59222 Mtetra
.644 .761 .934 r
.60315 .59222 .60646 .59573 .61297 .59386 .60967 .59035 Mtetra
.645 .761 .934 r
.60967 .59035 .61297 .59386 .61949 .59199 .61621 .58847 Mtetra
.645 .761 .933 r
.61621 .58847 .61949 .59199 .62604 .5901 .62276 .58657 Mtetra
.644 .761 .934 r
.62276 .58657 .62604 .5901 .63259 .58823 .62933 .5847 Mtetra
.62933 .5847 .63259 .58823 .63917 .58635 .63591 .58281 Mtetra
.645 .761 .934 r
.63591 .58281 .63917 .58635 .64575 .58446 .64251 .58091 Mtetra
.643 .761 .934 r
.64251 .58091 .64575 .58446 .65236 .58259 .64913 .57903 Mtetra
.64913 .57903 .65236 .58259 .65898 .58071 .65576 .57714 Mtetra
.65576 .57714 .65898 .58071 .66562 .57882 .66241 .57525 Mtetra
.66241 .57525 .66562 .57882 .67227 .57694 .66907 .57335 Mtetra
.66907 .57335 .67227 .57694 .67894 .57505 .67575 .57145 Mtetra
.643 .76 .934 r
.67575 .57145 .67894 .57505 .68562 .57316 .68244 .56956 Mtetra
.642 .76 .934 r
.68244 .56956 .68562 .57316 .69232 .57127 .68915 .56766 Mtetra
.68915 .56766 .69232 .57127 .69904 .56938 .69588 .56575 Mtetra
.69588 .56575 .69904 .56938 .70577 .56748 .70262 .56385 Mtetra
.70262 .56385 .70577 .56748 .71252 .56559 .70938 .56195 Mtetra
.70938 .56195 .71252 .56559 .71928 .56369 .71616 .56004 Mtetra
.641 .76 .934 r
.71616 .56004 .71928 .56369 .72607 .56179 .72295 .55813 Mtetra
.72295 .55813 .72607 .56179 .73287 .55989 .72976 .55622 Mtetra
.641 .76 .935 r
.72976 .55622 .73287 .55989 .73968 .55799 .73659 .55431 Mtetra
.73659 .55431 .73968 .55799 .74651 .55608 .74344 .5524 Mtetra
.641 .759 .935 r
.74344 .5524 .74651 .55608 .75336 .55418 .7503 .55048 Mtetra
.64 .759 .935 r
.7503 .55048 .75336 .55418 .76023 .55227 .75717 .54857 Mtetra
.75717 .54857 .76023 .55227 .76711 .55036 .76407 .54665 Mtetra
.76407 .54665 .76711 .55036 .77401 .54846 .77098 .54474 Mtetra
.77098 .54474 .77401 .54846 .78093 .54655 .77791 .54282 Mtetra
.77791 .54282 .78093 .54655 .78787 .54463 .78486 .54089 Mtetra
.639 .759 .935 r
.78486 .54089 .78787 .54463 .79482 .54272 .79182 .53897 Mtetra
.79182 .53897 .79482 .54272 .80179 .5408 .7988 .53704 Mtetra
.64 .759 .935 r
.7988 .53704 .80179 .5408 .80877 .53887 .8058 .5351 Mtetra
.641 .76 .935 r
.8058 .5351 .80877 .53887 .81578 .53692 .81281 .53314 Mtetra
.645 .761 .933 r
.81281 .53314 .81578 .53692 .82279 .53489 .81984 .53111 Mtetra
.649 .763 .932 r
.81984 .53111 .82279 .53489 .82981 .53281 .82688 .52902 Mtetra
.672 .772 .925 r
.82688 .52902 .82981 .53281 .83682 .53035 .8339 .52655 Mtetra
.696 .781 .916 r
.8339 .52655 .83682 .53035 .8438 .52745 .84089 .52364 Mtetra
.731 .793 .901 r
.84089 .52364 .8438 .52745 .85073 .52386 .84783 .52003 Mtetra
.811 .814 .853 r
.84783 .52003 .85073 .52386 .85747 .51823 .85458 .51439 Mtetra
.854 .82 .815 r
.85458 .51439 .85747 .51823 .86405 .51102 .86118 .50717 Mtetra
.917 .818 .734 r
.86118 .50717 .86405 .51102 .87022 .5 .86737 .49613 Mtetra
.954 .804 .656 r
.86737 .49613 .87022 .5 .87587 .48421 .87304 .48031 Mtetra
.967 .793 .616 r
.87304 .48031 .87587 .48421 .88114 .46527 .87833 .46135 Mtetra
.982 .769 .54 r
.87833 .46135 .88114 .46527 .8854 .4378 .88262 .43384 Mtetra
.985 .76 .516 r
.88262 .43384 .8854 .4378 .88917 .40675 .88642 .40276 Mtetra
.943 .627 .409 r
.2665 .56432 .27015 .56756 .27344 .59656 .26976 .59334 Mtetra
.942 .619 .394 r
.26976 .59334 .27344 .59656 .27701 .62314 .2733 .61994 Mtetra
.935 .58 .322 r
.2733 .61994 .27701 .62314 .28124 .64186 .27751 .63868 Mtetra
.925 .547 .264 r
.27751 .63868 .28124 .64186 .28577 .65733 .28203 .65416 Mtetra
.875 .435 .087 r
.28203 .65416 .28577 .65733 .29072 .66764 .28697 .66448 Mtetra
.62 .096 0 r
.28697 .66448 .29072 .66764 .29602 .6733 .29227 .67013 Mtetra
0 .226 .693 r
.29227 .67013 .29602 .6733 .30148 .67695 .29774 .67379 Mtetra
.341 .64 .964 r
.29774 .67379 .30148 .67695 .30716 .67778 .30341 .67462 Mtetra
.498 .712 .966 r
.30341 .67462 .30716 .67778 .31291 .67758 .30917 .6744 Mtetra
.573 .739 .955 r
.30917 .6744 .31291 .67758 .31872 .6767 .31499 .67353 Mtetra
.632 .758 .938 r
.31499 .67353 .31872 .6767 .32459 .67518 .32086 .67199 Mtetra
.639 .76 .935 r
.32086 .67199 .32459 .67518 .33047 .67355 .32675 .67036 Mtetra
.648 .762 .932 r
.32675 .67036 .33047 .67355 .33637 .67181 .33267 .66861 Mtetra
.652 .763 .931 r
.33267 .66861 .33637 .67181 .34229 .67 .33859 .6668 Mtetra
.653 .763 .93 r
.33859 .6668 .34229 .67 .34823 .66818 .34453 .66497 Mtetra
.34453 .66497 .34823 .66818 .35417 .66636 .35049 .66314 Mtetra
.35049 .66314 .35417 .66636 .36013 .66453 .35646 .6613 Mtetra
.35646 .6613 .36013 .66453 .3661 .66269 .36244 .65945 Mtetra
.652 .763 .931 r
.36244 .65945 .3661 .66269 .37209 .66086 .36843 .65762 Mtetra
.653 .763 .93 r
.36843 .65762 .37209 .66086 .37808 .65903 .37443 .65578 Mtetra
.37443 .65578 .37808 .65903 .38409 .65718 .38045 .65393 Mtetra
.651 .763 .931 r
.38045 .65393 .38409 .65718 .39012 .65536 .38649 .65209 Mtetra
.652 .763 .931 r
.38649 .65209 .39012 .65536 .39615 .65352 .39253 .65025 Mtetra
.39253 .65025 .39615 .65352 .40221 .65168 .39859 .6484 Mtetra
.651 .763 .931 r
.39859 .6484 .40221 .65168 .40827 .64984 .40466 .64656 Mtetra
.40466 .64656 .40827 .64984 .41434 .64801 .41075 .64472 Mtetra
.652 .763 .931 r
.41075 .64472 .41434 .64801 .42044 .64616 .41685 .64286 Mtetra
.651 .763 .931 r
.41685 .64286 .42044 .64616 .42654 .64432 .42296 .64101 Mtetra
.65 .762 .931 r
.42296 .64101 .42654 .64432 .43266 .64248 .42908 .63917 Mtetra
.651 .763 .931 r
.42908 .63917 .43266 .64248 .43879 .64063 .43522 .63731 Mtetra
.65 .762 .931 r
.43522 .63731 .43879 .64063 .44493 .63879 .44138 .63546 Mtetra
.649 .762 .932 r
.44138 .63546 .44493 .63879 .45109 .63695 .44754 .63361 Mtetra
.65 .762 .931 r
.44754 .63361 .45109 .63695 .45726 .63509 .45372 .63175 Mtetra
.65 .762 .932 r
.45372 .63175 .45726 .63509 .46345 .63324 .45992 .62989 Mtetra
.649 .762 .932 r
.45992 .62989 .46345 .63324 .46964 .6314 .46613 .62804 Mtetra
.46613 .62804 .46964 .6314 .47586 .62955 .47235 .62618 Mtetra
.47235 .62618 .47586 .62955 .48209 .62769 .47858 .62431 Mtetra
.648 .762 .932 r
.47858 .62431 .48209 .62769 .48833 .62584 .48484 .62246 Mtetra
.649 .762 .932 r
.48484 .62246 .48833 .62584 .49458 .62399 .4911 .6206 Mtetra
.4911 .6206 .49458 .62399 .50085 .62212 .49738 .61872 Mtetra
.647 .762 .932 r
.49738 .61872 .50085 .62212 .50714 .62027 .50367 .61687 Mtetra
.648 .762 .932 r
.50367 .61687 .50714 .62027 .51343 .61841 .50998 .615 Mtetra
.50998 .615 .51343 .61841 .51975 .61654 .5163 .61312 Mtetra
.647 .762 .933 r
.5163 .61312 .51975 .61654 .52607 .61469 .52264 .61126 Mtetra
.52264 .61126 .52607 .61469 .53242 .61283 .52899 .60939 Mtetra
.648 .762 .932 r
.52899 .60939 .53242 .61283 .53877 .61096 .53536 .60751 Mtetra
.647 .761 .933 r
.53536 .60751 .53877 .61096 .54514 .60909 .54174 .60564 Mtetra
.646 .761 .933 r
.54174 .60564 .54514 .60909 .55153 .60723 .54813 .60377 Mtetra
.647 .762 .933 r
.54813 .60377 .55153 .60723 .55793 .60535 .55454 .60188 Mtetra
.646 .761 .933 r
.55454 .60188 .55793 .60535 .56434 .60348 .56097 .60001 Mtetra
.645 .761 .933 r
.56097 .60001 .56434 .60348 .57078 .60162 .56741 .59813 Mtetra
.646 .761 .933 r
.56741 .59813 .57078 .60162 .57722 .59974 .57386 .59624 Mtetra
.57386 .59624 .57722 .59974 .58368 .59786 .58033 .59436 Mtetra
.645 .761 .933 r
.58033 .59436 .58368 .59786 .59016 .59599 .58682 .59248 Mtetra
.646 .761 .933 r
.58682 .59248 .59016 .59599 .59665 .59411 .59332 .59059 Mtetra
.59332 .59059 .59665 .59411 .60315 .59222 .59984 .5887 Mtetra
.644 .761 .933 r
.59984 .5887 .60315 .59222 .60967 .59035 .60637 .58682 Mtetra
.645 .761 .933 r
.60637 .58682 .60967 .59035 .61621 .58847 .61291 .58492 Mtetra
.61291 .58492 .61621 .58847 .62276 .58657 .61948 .58302 Mtetra
.644 .76 .934 r
.61948 .58302 .62276 .58657 .62933 .5847 .62605 .58114 Mtetra
.644 .761 .933 r
.62605 .58114 .62933 .5847 .63591 .58281 .63265 .57924 Mtetra
.645 .761 .933 r
.63265 .57924 .63591 .58281 .64251 .58091 .63926 .57733 Mtetra
.643 .76 .934 r
.63926 .57733 .64251 .58091 .64913 .57903 .64588 .57544 Mtetra
.64588 .57544 .64913 .57903 .65576 .57714 .65252 .57355 Mtetra
.65252 .57355 .65576 .57714 .66241 .57525 .65918 .57164 Mtetra
.65918 .57164 .66241 .57525 .66907 .57335 .66586 .56974 Mtetra
.66586 .56974 .66907 .57335 .67575 .57145 .67254 .56784 Mtetra
.67254 .56784 .67575 .57145 .68244 .56956 .67925 .56593 Mtetra
.642 .76 .934 r
.67925 .56593 .68244 .56956 .68915 .56766 .68597 .56402 Mtetra
.68597 .56402 .68915 .56766 .69588 .56575 .69271 .56211 Mtetra
.69271 .56211 .69588 .56575 .70262 .56385 .69947 .5602 Mtetra
.69947 .5602 .70262 .56385 .70938 .56195 .70624 .55828 Mtetra
.70624 .55828 .70938 .56195 .71616 .56004 .71302 .55637 Mtetra
.641 .76 .934 r
.71302 .55637 .71616 .56004 .72295 .55813 .71983 .55445 Mtetra
.71983 .55445 .72295 .55813 .72976 .55622 .72665 .55253 Mtetra
.641 .759 .934 r
.72665 .55253 .72976 .55622 .73659 .55431 .73349 .55061 Mtetra
.73349 .55061 .73659 .55431 .74344 .5524 .74034 .54869 Mtetra
.74034 .54869 .74344 .5524 .7503 .55048 .74722 .54677 Mtetra
.64 .759 .935 r
.74722 .54677 .7503 .55048 .75717 .54857 .7541 .54485 Mtetra
.7541 .54485 .75717 .54857 .76407 .54665 .76101 .54292 Mtetra
.76101 .54292 .76407 .54665 .77098 .54474 .76793 .54099 Mtetra
.76793 .54099 .77098 .54474 .77791 .54282 .77488 .53907 Mtetra
.77488 .53907 .77791 .54282 .78486 .54089 .78183 .53714 Mtetra
.639 .759 .935 r
.78183 .53714 .78486 .54089 .79182 .53897 .78881 .5352 Mtetra
.64 .759 .935 r
.78881 .5352 .79182 .53897 .7988 .53704 .7958 .53327 Mtetra
.7958 .53327 .7988 .53704 .8058 .5351 .80281 .53132 Mtetra
.641 .759 .934 r
.80281 .53132 .8058 .5351 .81281 .53314 .80984 .52935 Mtetra
.645 .761 .933 r
.80984 .52935 .81281 .53314 .81984 .53111 .81688 .5273 Mtetra
.649 .762 .932 r
.81688 .5273 .81984 .53111 .82688 .52902 .82393 .5252 Mtetra
.672 .771 .925 r
.82393 .5252 .82688 .52902 .8339 .52655 .83096 .52272 Mtetra
.696 .781 .916 r
.83096 .52272 .8339 .52655 .84089 .52364 .83797 .5198 Mtetra
.731 .793 .901 r
.83797 .5198 .84089 .52364 .84783 .52003 .84492 .51619 Mtetra
.811 .813 .852 r
.84492 .51619 .84783 .52003 .85458 .51439 .85169 .51053 Mtetra
.854 .82 .815 r
.85169 .51053 .85458 .51439 .86118 .50717 .8583 .50329 Mtetra
.917 .818 .734 r
.8583 .50329 .86118 .50717 .86737 .49613 .86451 .49224 Mtetra
.954 .804 .656 r
.86451 .49224 .86737 .49613 .87304 .48031 .8702 .47639 Mtetra
.967 .793 .616 r
.8702 .47639 .87304 .48031 .87833 .46135 .87551 .4574 Mtetra
.982 .768 .54 r
.87551 .4574 .87833 .46135 .88262 .43384 .87983 .42986 Mtetra
.985 .76 .516 r
.87983 .42986 .88262 .43384 .88642 .40276 .88366 .39874 Mtetra
.943 .627 .41 r
.26283 .56108 .2665 .56432 .26976 .59334 .26606 .59012 Mtetra
.942 .619 .394 r
.26606 .59012 .26976 .59334 .2733 .61994 .26958 .61675 Mtetra
.935 .58 .322 r
.26958 .61675 .2733 .61994 .27751 .63868 .27377 .6355 Mtetra
.925 .547 .265 r
.27377 .6355 .27751 .63868 .28203 .65416 .27827 .651 Mtetra
.875 .436 .089 r
.27827 .651 .28203 .65416 .28697 .66448 .2832 .66132 Mtetra
.623 .098 0 r
.2832 .66132 .28697 .66448 .29227 .67013 .2885 .66698 Mtetra
0 .224 .69 r
.2885 .66698 .29227 .67013 .29774 .67379 .29397 .67063 Mtetra
.339 .64 .964 r
.29397 .67063 .29774 .67379 .30341 .67462 .29965 .67146 Mtetra
.497 .713 .967 r
.29965 .67146 .30341 .67462 .30917 .6744 .30542 .67124 Mtetra
.573 .741 .956 r
.30542 .67124 .30917 .6744 .31499 .67353 .31124 .67036 Mtetra
.632 .759 .939 r
.31124 .67036 .31499 .67353 .32086 .67199 .31712 .66882 Mtetra
.639 .761 .936 r
.31712 .66882 .32086 .67199 .32675 .67036 .32302 .66718 Mtetra
.648 .763 .933 r
.32302 .66718 .32675 .67036 .33267 .66861 .32894 .66542 Mtetra
.652 .764 .931 r
.32894 .66542 .33267 .66861 .33859 .6668 .33488 .6636 Mtetra
.653 .764 .931 r
.33488 .6636 .33859 .6668 .34453 .66497 .34083 .66177 Mtetra
.34083 .66177 .34453 .66497 .35049 .66314 .34679 .65993 Mtetra
.653 .765 .931 r
.34679 .65993 .35049 .66314 .35646 .6613 .35276 .65808 Mtetra
.35276 .65808 .35646 .6613 .36244 .65945 .35875 .65623 Mtetra
.652 .764 .932 r
.35875 .65623 .36244 .65945 .36843 .65762 .36475 .65439 Mtetra
.652 .764 .931 r
.36475 .65439 .36843 .65762 .37443 .65578 .37077 .65254 Mtetra
.653 .764 .931 r
.37077 .65254 .37443 .65578 .38045 .65393 .3768 .65068 Mtetra
.651 .764 .932 r
.3768 .65068 .38045 .65393 .38649 .65209 .38284 .64884 Mtetra
.652 .764 .932 r
.38284 .64884 .38649 .65209 .39253 .65025 .38889 .64699 Mtetra
.38889 .64699 .39253 .65025 .39859 .6484 .39496 .64513 Mtetra
.651 .764 .932 r
.39496 .64513 .39859 .6484 .40466 .64656 .40104 .64328 Mtetra
.40104 .64328 .40466 .64656 .41075 .64472 .40713 .64143 Mtetra
.40713 .64143 .41075 .64472 .41685 .64286 .41324 .63957 Mtetra
.65 .764 .932 r
.41324 .63957 .41685 .64286 .42296 .64101 .41936 .63771 Mtetra
.41936 .63771 .42296 .64101 .42908 .63917 .42549 .63586 Mtetra
.651 .764 .932 r
.42549 .63586 .42908 .63917 .43522 .63731 .43164 .63399 Mtetra
.65 .764 .932 r
.43164 .63399 .43522 .63731 .44138 .63546 .43781 .63213 Mtetra
.649 .763 .933 r
.43781 .63213 .44138 .63546 .44754 .63361 .44398 .63028 Mtetra
.65 .764 .932 r
.44398 .63028 .44754 .63361 .45372 .63175 .45017 .62841 Mtetra
.45017 .62841 .45372 .63175 .45992 .62989 .45637 .62654 Mtetra
.649 .763 .933 r
.45637 .62654 .45992 .62989 .46613 .62804 .46259 .62469 Mtetra
.46259 .62469 .46613 .62804 .47235 .62618 .46882 .62282 Mtetra
.46882 .62282 .47235 .62618 .47858 .62431 .47507 .62094 Mtetra
.648 .763 .933 r
.47507 .62094 .47858 .62431 .48484 .62246 .48133 .61908 Mtetra
.48133 .61908 .48484 .62246 .4911 .6206 .4876 .61721 Mtetra
.649 .763 .933 r
.4876 .61721 .4911 .6206 .49738 .61872 .49389 .61533 Mtetra
.647 .763 .933 r
.49389 .61533 .49738 .61872 .50367 .61687 .50019 .61346 Mtetra
.648 .763 .933 r
.50019 .61346 .50367 .61687 .50998 .615 .50651 .61159 Mtetra
.50651 .61159 .50998 .615 .5163 .61312 .51284 .60971 Mtetra
.647 .763 .933 r
.51284 .60971 .5163 .61312 .52264 .61126 .51919 .60783 Mtetra
.51919 .60783 .52264 .61126 .52899 .60939 .52555 .60596 Mtetra
.648 .763 .933 r
.52555 .60596 .52899 .60939 .53536 .60751 .53193 .60407 Mtetra
.647 .763 .934 r
.53193 .60407 .53536 .60751 .54174 .60564 .53832 .60219 Mtetra
.646 .762 .934 r
.53832 .60219 .54174 .60564 .54813 .60377 .54472 .60031 Mtetra
.647 .763 .933 r
.54472 .60031 .54813 .60377 .55454 .60188 .55114 .59842 Mtetra
.646 .763 .934 r
.55114 .59842 .55454 .60188 .56097 .60001 .55758 .59653 Mtetra
.645 .762 .934 r
.55758 .59653 .56097 .60001 .56741 .59813 .56403 .59465 Mtetra
.646 .763 .934 r
.56403 .59465 .56741 .59813 .57386 .59624 .57049 .59276 Mtetra
.646 .762 .934 r
.57049 .59276 .57386 .59624 .58033 .59436 .57697 .59086 Mtetra
.645 .762 .934 r
.57697 .59086 .58033 .59436 .58682 .59248 .58347 .58898 Mtetra
.58347 .58898 .58682 .59248 .59332 .59059 .58998 .58708 Mtetra
.58998 .58708 .59332 .59059 .59984 .5887 .5965 .58517 Mtetra
.644 .762 .934 r
.5965 .58517 .59984 .5887 .60637 .58682 .60305 .58329 Mtetra
.645 .762 .934 r
.60305 .58329 .60637 .58682 .61291 .58492 .6096 .58139 Mtetra
.6096 .58139 .61291 .58492 .61948 .58302 .61618 .57947 Mtetra
.643 .762 .935 r
.61618 .57947 .61948 .58302 .62605 .58114 .62276 .57758 Mtetra
.644 .762 .934 r
.62276 .57758 .62605 .58114 .63265 .57924 .62937 .57568 Mtetra
.62937 .57568 .63265 .57924 .63926 .57733 .63599 .57376 Mtetra
.643 .761 .935 r
.63599 .57376 .63926 .57733 .64588 .57544 .64263 .57186 Mtetra
.64263 .57186 .64588 .57544 .65252 .57355 .64928 .56996 Mtetra
.64928 .56996 .65252 .57355 .65918 .57164 .65595 .56805 Mtetra
.65595 .56805 .65918 .57164 .66586 .56974 .66263 .56614 Mtetra
.66263 .56614 .66586 .56974 .67254 .56784 .66933 .56422 Mtetra
.66933 .56422 .67254 .56784 .67925 .56593 .67605 .56231 Mtetra
.642 .761 .935 r
.67605 .56231 .67925 .56593 .68597 .56402 .68278 .56039 Mtetra
.68278 .56039 .68597 .56402 .69271 .56211 .68953 .55847 Mtetra
.68953 .55847 .69271 .56211 .69947 .5602 .69629 .55655 Mtetra
.69629 .55655 .69947 .5602 .70624 .55828 .70308 .55463 Mtetra
.70308 .55463 .70624 .55828 .71302 .55637 .70988 .5527 Mtetra
.641 .761 .935 r
.70988 .5527 .71302 .55637 .71983 .55445 .71669 .55078 Mtetra
.71669 .55078 .71983 .55445 .72665 .55253 .72352 .54885 Mtetra
.72352 .54885 .72665 .55253 .73349 .55061 .73037 .54692 Mtetra
.73037 .54692 .73349 .55061 .74034 .54869 .73724 .54499 Mtetra
.64 .76 .935 r
.73724 .54499 .74034 .54869 .74722 .54677 .74412 .54306 Mtetra
.74412 .54306 .74722 .54677 .7541 .54485 .75102 .54113 Mtetra
.64 .76 .936 r
.75102 .54113 .7541 .54485 .76101 .54292 .75794 .53919 Mtetra
.75794 .53919 .76101 .54292 .76793 .54099 .76488 .53726 Mtetra
.76488 .53726 .76793 .54099 .77488 .53907 .77183 .53532 Mtetra
.639 .76 .936 r
.77183 .53532 .77488 .53907 .78183 .53714 .7788 .53338 Mtetra
.7788 .53338 .78183 .53714 .78881 .5352 .78579 .53144 Mtetra
.78579 .53144 .78881 .5352 .7958 .53327 .79279 .52949 Mtetra
.64 .76 .936 r
.79279 .52949 .7958 .53327 .80281 .53132 .79981 .52754 Mtetra
.641 .761 .935 r
.79981 .52754 .80281 .53132 .80984 .52935 .80685 .52555 Mtetra
.645 .762 .934 r
.80685 .52555 .80984 .52935 .81688 .5273 .8139 .5235 Mtetra
.649 .764 .933 r
.8139 .5235 .81688 .5273 .82393 .5252 .82096 .52139 Mtetra
.672 .773 .926 r
.82096 .52139 .82393 .5252 .83096 .52272 .82801 .5189 Mtetra
.697 .782 .917 r
.82801 .5189 .83096 .52272 .83797 .5198 .83503 .51597 Mtetra
.732 .794 .902 r
.83503 .51597 .83797 .5198 .84492 .51619 .842 .51235 Mtetra
.811 .815 .853 r
.842 .51235 .84492 .51619 .85169 .51053 .84878 .50668 Mtetra
.854 .821 .815 r
.84878 .50668 .85169 .51053 .8583 .50329 .8554 .49942 Mtetra
.917 .819 .734 r
.8554 .49942 .8583 .50329 .86451 .49224 .86164 .48835 Mtetra
.954 .804 .656 r
.86164 .48835 .86451 .49224 .8702 .47639 .86735 .47248 Mtetra
.967 .794 .616 r
.86735 .47248 .8702 .47639 .87551 .4574 .87268 .45346 Mtetra
.982 .769 .54 r
.87268 .45346 .87551 .4574 .87983 .42986 .87703 .42588 Mtetra
.985 .76 .516 r
.87703 .42588 .87983 .42986 .88366 .39874 .88089 .39472 Mtetra
.943 .627 .41 r
.25915 .55782 .26283 .56108 .26606 .59012 .26234 .58689 Mtetra
.942 .619 .394 r
.26234 .58689 .26606 .59012 .26958 .61675 .26583 .61354 Mtetra
.935 .58 .322 r
.26583 .61354 .26958 .61675 .27377 .6355 .27001 .63231 Mtetra
.925 .547 .265 r
.27001 .63231 .27377 .6355 .27827 .651 .2745 .64782 Mtetra
.875 .436 .088 r
.2745 .64782 .27827 .651 .2832 .66132 .27942 .65815 Mtetra
.622 .098 0 r
.27942 .65815 .2832 .66132 .2885 .66698 .28472 .66381 Mtetra
0 .225 .691 r
.28472 .66381 .2885 .66698 .29397 .67063 .29019 .66746 Mtetra
.34 .64 .964 r
.29019 .66746 .29397 .67063 .29965 .67146 .29587 .66828 Mtetra
.497 .712 .967 r
.29587 .66828 .29965 .67146 .30542 .67124 .30165 .66806 Mtetra
.573 .74 .955 r
.30165 .66806 .30542 .67124 .31124 .67036 .30748 .66717 Mtetra
.632 .758 .939 r
.30748 .66717 .31124 .67036 .31712 .66882 .31337 .66562 Mtetra
.639 .76 .936 r
.31337 .66562 .31712 .66882 .32302 .66718 .31927 .66397 Mtetra
.648 .763 .933 r
.31927 .66397 .32302 .66718 .32894 .66542 .3252 .66221 Mtetra
.652 .764 .931 r
.3252 .66221 .32894 .66542 .33488 .6636 .33115 .66038 Mtetra
.653 .764 .931 r
.33115 .66038 .33488 .6636 .34083 .66177 .3371 .65854 Mtetra
.3371 .65854 .34083 .66177 .34679 .65993 .34307 .6567 Mtetra
.34307 .6567 .34679 .65993 .35276 .65808 .34906 .65484 Mtetra
.34906 .65484 .35276 .65808 .35875 .65623 .35505 .65298 Mtetra
.652 .764 .931 r
.35505 .65298 .35875 .65623 .36475 .65439 .36106 .65113 Mtetra
.36106 .65113 .36475 .65439 .37077 .65254 .36709 .64928 Mtetra
.653 .764 .931 r
.36709 .64928 .37077 .65254 .3768 .65068 .37312 .64741 Mtetra
.651 .764 .931 r
.37312 .64741 .3768 .65068 .38284 .64884 .37917 .64556 Mtetra
.652 .764 .931 r
.37917 .64556 .38284 .64884 .38889 .64699 .38523 .6437 Mtetra
.38523 .6437 .38889 .64699 .39496 .64513 .39131 .64184 Mtetra
.651 .763 .932 r
.39131 .64184 .39496 .64513 .40104 .64328 .3974 .63998 Mtetra
.3974 .63998 .40104 .64328 .40713 .64143 .4035 .63812 Mtetra
.651 .764 .931 r
.4035 .63812 .40713 .64143 .41324 .63957 .40962 .63625 Mtetra
.65 .763 .932 r
.40962 .63625 .41324 .63957 .41936 .63771 .41575 .63439 Mtetra
.41575 .63439 .41936 .63771 .42549 .63586 .42189 .63253 Mtetra
.651 .763 .932 r
.42189 .63253 .42549 .63586 .43164 .63399 .42805 .63066 Mtetra
.65 .763 .932 r
.42805 .63066 .43164 .63399 .43781 .63213 .43422 .62879 Mtetra
.649 .763 .932 r
.43422 .62879 .43781 .63213 .44398 .63028 .4404 .62693 Mtetra
.65 .763 .932 r
.4404 .62693 .44398 .63028 .45017 .62841 .4466 .62505 Mtetra
.4466 .62505 .45017 .62841 .45637 .62654 .45282 .62318 Mtetra
.649 .763 .932 r
.45282 .62318 .45637 .62654 .46259 .62469 .45904 .62131 Mtetra
.45904 .62131 .46259 .62469 .46882 .62282 .46528 .61943 Mtetra
.46528 .61943 .46882 .62282 .47507 .62094 .47154 .61755 Mtetra
.648 .763 .933 r
.47154 .61755 .47507 .62094 .48133 .61908 .47781 .61568 Mtetra
.47781 .61568 .48133 .61908 .4876 .61721 .48409 .6138 Mtetra
.649 .763 .932 r
.48409 .6138 .4876 .61721 .49389 .61533 .49039 .61191 Mtetra
.647 .762 .933 r
.49039 .61191 .49389 .61533 .50019 .61346 .4967 .61004 Mtetra
.648 .763 .933 r
.4967 .61004 .50019 .61346 .50651 .61159 .50303 .60816 Mtetra
.50303 .60816 .50651 .61159 .51284 .60971 .50937 .60627 Mtetra
.647 .762 .933 r
.50937 .60627 .51284 .60971 .51919 .60783 .51572 .60439 Mtetra
.51572 .60439 .51919 .60783 .52555 .60596 .5221 .6025 Mtetra
.648 .763 .933 r
.5221 .6025 .52555 .60596 .53193 .60407 .52848 .60061 Mtetra
.647 .762 .933 r
.52848 .60061 .53193 .60407 .53832 .60219 .53488 .59872 Mtetra
.646 .762 .933 r
.53488 .59872 .53832 .60219 .54472 .60031 .5413 .59684 Mtetra
.647 .762 .933 r
.5413 .59684 .54472 .60031 .55114 .59842 .54773 .59493 Mtetra
.646 .762 .933 r
.54773 .59493 .55114 .59842 .55758 .59653 .55417 .59304 Mtetra
.645 .762 .934 r
.55417 .59304 .55758 .59653 .56403 .59465 .56063 .59115 Mtetra
.646 .762 .933 r
.56063 .59115 .56403 .59465 .57049 .59276 .56711 .58924 Mtetra
.56711 .58924 .57049 .59276 .57697 .59086 .5736 .58734 Mtetra
.645 .762 .934 r
.5736 .58734 .57697 .59086 .58347 .58898 .5801 .58545 Mtetra
.646 .762 .934 r
.5801 .58545 .58347 .58898 .58998 .58708 .58662 .58354 Mtetra
.645 .762 .934 r
.58662 .58354 .58998 .58708 .5965 .58517 .59316 .58163 Mtetra
.644 .761 .934 r
.59316 .58163 .5965 .58517 .60305 .58329 .59971 .57973 Mtetra
.645 .762 .934 r
.59971 .57973 .60305 .58329 .6096 .58139 .60628 .57782 Mtetra
.60628 .57782 .6096 .58139 .61618 .57947 .61286 .5759 Mtetra
.643 .761 .934 r
.61286 .5759 .61618 .57947 .62276 .57758 .61946 .574 Mtetra
.644 .761 .934 r
.61946 .574 .62276 .57758 .62937 .57568 .62608 .57209 Mtetra
.645 .762 .934 r
.62608 .57209 .62937 .57568 .63599 .57376 .63271 .57017 Mtetra
.643 .761 .934 r
.63271 .57017 .63599 .57376 .64263 .57186 .63935 .56826 Mtetra
.63935 .56826 .64263 .57186 .64928 .56996 .64601 .56635 Mtetra
.64601 .56635 .64928 .56996 .65595 .56805 .65269 .56443 Mtetra
.65269 .56443 .65595 .56805 .66263 .56614 .65939 .56251 Mtetra
.65939 .56251 .66263 .56614 .66933 .56422 .6661 .56058 Mtetra
.6661 .56058 .66933 .56422 .67605 .56231 .67283 .55866 Mtetra
.642 .761 .935 r
.67283 .55866 .67605 .56231 .68278 .56039 .67957 .55673 Mtetra
.67957 .55673 .68278 .56039 .68953 .55847 .68633 .55481 Mtetra
.68633 .55481 .68953 .55847 .69629 .55655 .69311 .55288 Mtetra
.69311 .55288 .69629 .55655 .70308 .55463 .6999 .55095 Mtetra
.642 .76 .935 r
.6999 .55095 .70308 .55463 .70988 .5527 .70671 .54901 Mtetra
.641 .76 .935 r
.70671 .54901 .70988 .5527 .71669 .55078 .71354 .54708 Mtetra
.71354 .54708 .71669 .55078 .72352 .54885 .72038 .54514 Mtetra
.72038 .54514 .72352 .54885 .73037 .54692 .72724 .54321 Mtetra
.72724 .54321 .73037 .54692 .73724 .54499 .73412 .54127 Mtetra
.73412 .54127 .73724 .54499 .74412 .54306 .74102 .53933 Mtetra
.64 .76 .935 r
.74102 .53933 .74412 .54306 .75102 .54113 .74793 .53739 Mtetra
.74793 .53739 .75102 .54113 .75794 .53919 .75486 .53544 Mtetra
.75486 .53544 .75794 .53919 .76488 .53726 .7618 .5335 Mtetra
.7618 .5335 .76488 .53726 .77183 .53532 .76877 .53155 Mtetra
.639 .76 .935 r
.76877 .53155 .77183 .53532 .7788 .53338 .77575 .5296 Mtetra
.639 .759 .935 r
.77575 .5296 .7788 .53338 .78579 .53144 .78275 .52765 Mtetra
.639 .76 .935 r
.78275 .52765 .78579 .53144 .79279 .52949 .78977 .5257 Mtetra
.64 .76 .935 r
.78977 .5257 .79279 .52949 .79981 .52754 .7968 .52373 Mtetra
.641 .76 .935 r
.7968 .52373 .79981 .52754 .80685 .52555 .80385 .52174 Mtetra
.645 .762 .934 r
.80385 .52174 .80685 .52555 .8139 .5235 .81091 .51968 Mtetra
.649 .763 .933 r
.81091 .51968 .8139 .5235 .82096 .52139 .81799 .51756 Mtetra
.672 .772 .926 r
.81799 .51756 .82096 .52139 .82801 .5189 .82505 .51506 Mtetra
.696 .782 .917 r
.82505 .51506 .82801 .5189 .83503 .51597 .83208 .51212 Mtetra
.731 .793 .902 r
.83208 .51212 .83503 .51597 .842 .51235 .83906 .50848 Mtetra
.811 .814 .853 r
.83906 .50848 .842 .51235 .84878 .50668 .84586 .5028 Mtetra
.854 .821 .815 r
.84586 .5028 .84878 .50668 .8554 .49942 .8525 .49553 Mtetra
.917 .818 .734 r
.8525 .49553 .8554 .49942 .86164 .48835 .85875 .48443 Mtetra
.954 .804 .656 r
.85875 .48443 .86164 .48835 .86735 .47248 .86448 .46854 Mtetra
.967 .793 .616 r
.86448 .46854 .86735 .47248 .87268 .45346 .86984 .44949 Mtetra
.982 .769 .54 r
.86984 .44949 .87268 .45346 .87703 .42588 .87422 .42187 Mtetra
.985 .76 .516 r
.87422 .42187 .87703 .42588 .88089 .39472 .8781 .39068 Mtetra
.943 .627 .409 r
.25545 .55454 .25915 .55782 .26234 .58689 .25862 .58363 Mtetra
.942 .619 .394 r
.25862 .58363 .26234 .58689 .26583 .61354 .26208 .6103 Mtetra
.935 .58 .322 r
.26208 .6103 .26583 .61354 .27001 .63231 .26624 .62909 Mtetra
.925 .547 .264 r
.26624 .62909 .27001 .63231 .2745 .64782 .27071 .64461 Mtetra
.875 .435 .087 r
.27071 .64461 .2745 .64782 .27942 .65815 .27563 .65495 Mtetra
.621 .097 0 r
.27563 .65495 .27942 .65815 .28472 .66381 .28092 .66061 Mtetra
0 .226 .693 r
.28092 .66061 .28472 .66381 .29019 .66746 .28639 .66426 Mtetra
.341 .64 .964 r
.28639 .66426 .29019 .66746 .29587 .66828 .29208 .66508 Mtetra
.498 .712 .967 r
.29208 .66508 .29587 .66828 .30165 .66806 .29786 .66485 Mtetra
.573 .74 .955 r
.29786 .66485 .30165 .66806 .30748 .66717 .3037 .66395 Mtetra
.632 .758 .938 r
.3037 .66395 .30748 .66717 .31337 .66562 .3096 .6624 Mtetra
.639 .76 .936 r
.3096 .6624 .31337 .66562 .31927 .66397 .31551 .66075 Mtetra
.648 .762 .932 r
.31551 .66075 .31927 .66397 .3252 .66221 .32145 .65897 Mtetra
.652 .763 .931 r
.32145 .65897 .3252 .66221 .33115 .66038 .3274 .65714 Mtetra
.653 .763 .93 r
.3274 .65714 .33115 .66038 .3371 .65854 .33337 .65529 Mtetra
.33337 .65529 .3371 .65854 .34307 .6567 .33934 .65344 Mtetra
.33934 .65344 .34307 .6567 .34906 .65484 .34534 .65158 Mtetra
.34534 .65158 .34906 .65484 .35505 .65298 .35134 .64971 Mtetra
.652 .763 .931 r
.35134 .64971 .35505 .65298 .36106 .65113 .35736 .64785 Mtetra
.653 .763 .931 r
.35736 .64785 .36106 .65113 .36709 .64928 .36339 .64599 Mtetra
.653 .763 .93 r
.36339 .64599 .36709 .64928 .37312 .64741 .36944 .64412 Mtetra
.651 .763 .931 r
.36944 .64412 .37312 .64741 .37917 .64556 .37549 .64226 Mtetra
.652 .763 .931 r
.37549 .64226 .37917 .64556 .38523 .6437 .38156 .6404 Mtetra
.38156 .6404 .38523 .6437 .39131 .64184 .38765 .63852 Mtetra
.651 .763 .931 r
.38765 .63852 .39131 .64184 .3974 .63998 .39375 .63666 Mtetra
.39375 .63666 .3974 .63998 .4035 .63812 .39986 .63479 Mtetra
.652 .763 .931 r
.39986 .63479 .4035 .63812 .40962 .63625 .40598 .63291 Mtetra
.651 .763 .931 r
.40598 .63291 .40962 .63625 .41575 .63439 .41212 .63104 Mtetra
.65 .763 .932 r
.41212 .63104 .41575 .63439 .42189 .63253 .41827 .62918 Mtetra
.651 .763 .931 r
.41827 .62918 .42189 .63253 .42805 .63066 .42444 .6273 Mtetra
.65 .763 .931 r
.42444 .6273 .42805 .63066 .43422 .62879 .43062 .62542 Mtetra
.649 .762 .932 r
.43062 .62542 .43422 .62879 .4404 .62693 .43681 .62355 Mtetra
.65 .763 .932 r
.43681 .62355 .4404 .62693 .4466 .62505 .44302 .62167 Mtetra
.65 .762 .932 r
.44302 .62167 .4466 .62505 .45282 .62318 .44924 .61978 Mtetra
.649 .762 .932 r
.44924 .61978 .45282 .62318 .45904 .62131 .45548 .61791 Mtetra
.45548 .61791 .45904 .62131 .46528 .61943 .46173 .61603 Mtetra
.46173 .61603 .46528 .61943 .47154 .61755 .46799 .61414 Mtetra
.648 .762 .932 r
.46799 .61414 .47154 .61755 .47781 .61568 .47427 .61226 Mtetra
.649 .762 .932 r
.47427 .61226 .47781 .61568 .48409 .6138 .48056 .61037 Mtetra
.48056 .61037 .48409 .6138 .49039 .61191 .48687 .60847 Mtetra
.647 .762 .932 r
.48687 .60847 .49039 .61191 .4967 .61004 .49319 .60659 Mtetra
.648 .762 .932 r
.49319 .60659 .4967 .61004 .50303 .60816 .49953 .60471 Mtetra
.49953 .60471 .50303 .60816 .50937 .60627 .50588 .6028 Mtetra
.647 .762 .933 r
.50588 .6028 .50937 .60627 .51572 .60439 .51225 .60092 Mtetra
.51225 .60092 .51572 .60439 .5221 .6025 .51863 .59902 Mtetra
.648 .762 .932 r
.51863 .59902 .5221 .6025 .52848 .60061 .52502 .59712 Mtetra
.647 .762 .933 r
.52502 .59712 .52848 .60061 .53488 .59872 .53143 .59522 Mtetra
.646 .761 .933 r
.53143 .59522 .53488 .59872 .5413 .59684 .53785 .59333 Mtetra
.647 .762 .933 r
.53785 .59333 .5413 .59684 .54773 .59493 .54429 .59142 Mtetra
.646 .761 .933 r
.54429 .59142 .54773 .59493 .55417 .59304 .55075 .58952 Mtetra
.645 .761 .933 r
.55075 .58952 .55417 .59304 .56063 .59115 .55722 .58762 Mtetra
.646 .761 .933 r
.55722 .58762 .56063 .59115 .56711 .58924 .5637 .58571 Mtetra
.5637 .58571 .56711 .58924 .5736 .58734 .5702 .5838 Mtetra
.645 .761 .933 r
.5702 .5838 .5736 .58734 .5801 .58545 .57672 .5819 Mtetra
.646 .761 .933 r
.57672 .5819 .5801 .58545 .58662 .58354 .58325 .57998 Mtetra
.58325 .57998 .58662 .58354 .59316 .58163 .5898 .57806 Mtetra
.644 .761 .934 r
.5898 .57806 .59316 .58163 .59971 .57973 .59636 .57616 Mtetra
.645 .761 .933 r
.59636 .57616 .59971 .57973 .60628 .57782 .60294 .57424 Mtetra
.60294 .57424 .60628 .57782 .61286 .5759 .60953 .57231 Mtetra
.644 .761 .934 r
.60953 .57231 .61286 .5759 .61946 .574 .61614 .5704 Mtetra
.61614 .5704 .61946 .574 .62608 .57209 .62277 .56848 Mtetra
.645 .761 .933 r
.62277 .56848 .62608 .57209 .63271 .57017 .62941 .56655 Mtetra
.643 .76 .934 r
.62941 .56655 .63271 .57017 .63935 .56826 .63606 .56463 Mtetra
.63606 .56463 .63935 .56826 .64601 .56635 .64274 .56271 Mtetra
.64274 .56271 .64601 .56635 .65269 .56443 .64943 .56078 Mtetra
.64943 .56078 .65269 .56443 .65939 .56251 .65613 .55885 Mtetra
.65613 .55885 .65939 .56251 .6661 .56058 .66285 .55692 Mtetra
.66285 .55692 .6661 .56058 .67283 .55866 .66959 .55499 Mtetra
.642 .76 .934 r
.66959 .55499 .67283 .55866 .67957 .55673 .67635 .55305 Mtetra
.67635 .55305 .67957 .55673 .68633 .55481 .68312 .55112 Mtetra
.68312 .55112 .68633 .55481 .69311 .55288 .68991 .54918 Mtetra
.68991 .54918 .69311 .55288 .6999 .55095 .69671 .54724 Mtetra
.69671 .54724 .6999 .55095 .70671 .54901 .70353 .5453 Mtetra
.641 .76 .934 r
.70353 .5453 .70671 .54901 .71354 .54708 .71037 .54335 Mtetra
.71037 .54335 .71354 .54708 .72038 .54514 .71723 .54141 Mtetra
.71723 .54141 .72038 .54514 .72724 .54321 .7241 .53946 Mtetra
.641 .759 .935 r
.7241 .53946 .72724 .54321 .73412 .54127 .73099 .53752 Mtetra
.73099 .53752 .73412 .54127 .74102 .53933 .73789 .53557 Mtetra
.64 .759 .935 r
.73789 .53557 .74102 .53933 .74793 .53739 .74482 .53362 Mtetra
.74482 .53362 .74793 .53739 .75486 .53544 .75176 .53166 Mtetra
.75176 .53166 .75486 .53544 .7618 .5335 .75872 .52971 Mtetra
.75872 .52971 .7618 .5335 .76877 .53155 .76569 .52775 Mtetra
.76569 .52775 .76877 .53155 .77575 .5296 .77269 .52579 Mtetra
.639 .759 .935 r
.77269 .52579 .77575 .5296 .78275 .52765 .7797 .52384 Mtetra
.64 .759 .935 r
.7797 .52384 .78275 .52765 .78977 .5257 .78673 .52187 Mtetra
.78673 .52187 .78977 .5257 .7968 .52373 .79377 .51989 Mtetra
.641 .759 .934 r
.79377 .51989 .7968 .52373 .80385 .52174 .80084 .51789 Mtetra
.645 .761 .933 r
.80084 .51789 .80385 .52174 .81091 .51968 .80791 .51582 Mtetra
.649 .763 .932 r
.80791 .51582 .81091 .51968 .81799 .51756 .815 .5137 Mtetra
.672 .772 .925 r
.815 .5137 .81799 .51756 .82505 .51506 .82207 .51119 Mtetra
.696 .781 .916 r
.82207 .51119 .82505 .51506 .83208 .51212 .82911 .50823 Mtetra
.731 .793 .901 r
.82911 .50823 .83208 .51212 .83906 .50848 .83611 .50459 Mtetra
.811 .814 .852 r
.83611 .50459 .83906 .50848 .84586 .5028 .84292 .49889 Mtetra
.854 .82 .815 r
.84292 .49889 .84586 .5028 .8525 .49553 .84958 .4916 Mtetra
.917 .818 .734 r
.84958 .4916 .8525 .49553 .85875 .48443 .85585 .48049 Mtetra
.954 .804 .656 r
.85585 .48049 .85875 .48443 .86448 .46854 .8616 .46457 Mtetra
.967 .793 .616 r
.8616 .46457 .86448 .46854 .86984 .44949 .86698 .4455 Mtetra
.982 .769 .54 r
.86698 .4455 .86984 .44949 .87422 .42187 .87139 .41784 Mtetra
.985 .76 .516 r
.87139 .41784 .87422 .42187 .8781 .39068 .8753 .38661 Mtetra
.943 .627 .41 r
.25174 .55126 .25545 .55454 .25862 .58363 .25487 .58038 Mtetra
.942 .619 .394 r
.25487 .58038 .25862 .58363 .26208 .6103 .25831 .60707 Mtetra
.935 .58 .322 r
.25831 .60707 .26208 .6103 .26624 .62909 .26245 .62588 Mtetra
.925 .547 .265 r
.26245 .62588 .26624 .62909 .27071 .64461 .26691 .64141 Mtetra
.875 .436 .089 r
.26691 .64141 .27071 .64461 .27563 .65495 .27182 .65175 Mtetra
.623 .098 0 r
.27182 .65175 .27563 .65495 .28092 .66061 .27711 .65741 Mtetra
0 .224 .69 r
.27711 .65741 .28092 .66061 .28639 .66426 .28258 .66106 Mtetra
.339 .64 .964 r
.28258 .66106 .28639 .66426 .29208 .66508 .28828 .66188 Mtetra
.497 .713 .967 r
.28828 .66188 .29208 .66508 .29786 .66485 .29406 .66165 Mtetra
.573 .741 .956 r
.29406 .66165 .29786 .66485 .3037 .66395 .29991 .66074 Mtetra
.632 .759 .939 r
.29991 .66074 .3037 .66395 .3096 .6624 .30581 .65918 Mtetra
.639 .761 .936 r
.30581 .65918 .3096 .6624 .31551 .66075 .31173 .65752 Mtetra
.648 .763 .933 r
.31173 .65752 .31551 .66075 .32145 .65897 .31768 .65574 Mtetra
.652 .764 .931 r
.31768 .65574 .32145 .65897 .3274 .65714 .32364 .6539 Mtetra
.653 .764 .931 r
.32364 .6539 .3274 .65714 .33337 .65529 .32961 .65205 Mtetra
.32961 .65205 .33337 .65529 .33934 .65344 .3356 .65019 Mtetra
.3356 .65019 .33934 .65344 .34534 .65158 .3416 .64832 Mtetra
.3416 .64832 .34534 .65158 .35134 .64971 .34761 .64644 Mtetra
.652 .764 .931 r
.34761 .64644 .35134 .64971 .35736 .64785 .35364 .64458 Mtetra
.35364 .64458 .35736 .64785 .36339 .64599 .35968 .64271 Mtetra
.653 .764 .931 r
.35968 .64271 .36339 .64599 .36944 .64412 .36573 .64083 Mtetra
.651 .764 .932 r
.36573 .64083 .36944 .64412 .37549 .64226 .3718 .63896 Mtetra
.652 .764 .932 r
.3718 .63896 .37549 .64226 .38156 .6404 .37788 .63709 Mtetra
.652 .764 .931 r
.37788 .63709 .38156 .6404 .38765 .63852 .38397 .63521 Mtetra
.651 .764 .932 r
.38397 .63521 .38765 .63852 .39375 .63666 .39008 .63334 Mtetra
.39008 .63334 .39375 .63666 .39986 .63479 .3962 .63146 Mtetra
.3962 .63146 .39986 .63479 .40598 .63291 .40233 .62958 Mtetra
.65 .764 .932 r
.40233 .62958 .40598 .63291 .41212 .63104 .40848 .6277 Mtetra
.40848 .6277 .41212 .63104 .41827 .62918 .41464 .62583 Mtetra
.651 .764 .932 r
.41464 .62583 .41827 .62918 .42444 .6273 .42082 .62394 Mtetra
.65 .764 .932 r
.42082 .62394 .42444 .6273 .43062 .62542 .427 .62205 Mtetra
.649 .763 .932 r
.427 .62205 .43062 .62542 .43681 .62355 .43321 .62018 Mtetra
.65 .764 .932 r
.43321 .62018 .43681 .62355 .44302 .62167 .43942 .61828 Mtetra
.65 .763 .932 r
.43942 .61828 .44302 .62167 .44924 .61978 .44565 .61639 Mtetra
.649 .763 .933 r
.44565 .61639 .44924 .61978 .45548 .61791 .4519 .61451 Mtetra
.4519 .61451 .45548 .61791 .46173 .61603 .45816 .61262 Mtetra
.45816 .61262 .46173 .61603 .46799 .61414 .46443 .61072 Mtetra
.648 .763 .933 r
.46443 .61072 .46799 .61414 .47427 .61226 .47072 .60884 Mtetra
.47072 .60884 .47427 .61226 .48056 .61037 .47702 .60694 Mtetra
.649 .763 .933 r
.47702 .60694 .48056 .61037 .48687 .60847 .48334 .60504 Mtetra
.647 .763 .933 r
.48334 .60504 .48687 .60847 .49319 .60659 .48967 .60315 Mtetra
.648 .763 .933 r
.48967 .60315 .49319 .60659 .49953 .60471 .49602 .60125 Mtetra
.49602 .60125 .49953 .60471 .50588 .6028 .50238 .59934 Mtetra
.647 .763 .933 r
.50238 .59934 .50588 .6028 .51225 .60092 .50875 .59745 Mtetra
.50875 .59745 .51225 .60092 .51863 .59902 .51514 .59555 Mtetra
.648 .763 .933 r
.51514 .59555 .51863 .59902 .52502 .59712 .52155 .59363 Mtetra
.647 .763 .933 r
.52155 .59363 .52502 .59712 .53143 .59522 .52796 .59173 Mtetra
.646 .762 .934 r
.52796 .59173 .53143 .59522 .53785 .59333 .5344 .58983 Mtetra
.647 .763 .933 r
.5344 .58983 .53785 .59333 .54429 .59142 .54085 .58791 Mtetra
.646 .762 .934 r
.54085 .58791 .54429 .59142 .55075 .58952 .54731 .586 Mtetra
.645 .762 .934 r
.54731 .586 .55075 .58952 .55722 .58762 .55379 .58409 Mtetra
.646 .762 .934 r
.55379 .58409 .55722 .58762 .5637 .58571 .56029 .58217 Mtetra
.56029 .58217 .5637 .58571 .5702 .5838 .5668 .58025 Mtetra
.645 .762 .934 r
.5668 .58025 .5702 .5838 .57672 .5819 .57333 .57834 Mtetra
.57333 .57834 .57672 .5819 .58325 .57998 .57987 .57642 Mtetra
.57987 .57642 .58325 .57998 .5898 .57806 .58642 .57449 Mtetra
.644 .762 .934 r
.58642 .57449 .5898 .57806 .59636 .57616 .593 .57258 Mtetra
.645 .762 .934 r
.593 .57258 .59636 .57616 .60294 .57424 .59958 .57065 Mtetra
.59958 .57065 .60294 .57424 .60953 .57231 .60619 .56871 Mtetra
.643 .761 .934 r
.60619 .56871 .60953 .57231 .61614 .5704 .61281 .5668 Mtetra
.644 .762 .934 r
.61281 .5668 .61614 .5704 .62277 .56848 .61944 .56487 Mtetra
.61944 .56487 .62277 .56848 .62941 .56655 .6261 .56293 Mtetra
.643 .761 .935 r
.6261 .56293 .62941 .56655 .63606 .56463 .63276 .561 Mtetra
.63276 .561 .63606 .56463 .64274 .56271 .63945 .55907 Mtetra
.63945 .55907 .64274 .56271 .64943 .56078 .64615 .55713 Mtetra
.64615 .55713 .64943 .56078 .65613 .55885 .65286 .5552 Mtetra
.65286 .5552 .65613 .55885 .66285 .55692 .6596 .55326 Mtetra
.6596 .55326 .66285 .55692 .66959 .55499 .66635 .55131 Mtetra
.642 .761 .935 r
.66635 .55131 .66959 .55499 .67635 .55305 .67311 .54937 Mtetra
.67311 .54937 .67635 .55305 .68312 .55112 .67989 .54743 Mtetra
.67989 .54743 .68312 .55112 .68991 .54918 .68669 .54548 Mtetra
.68669 .54548 .68991 .54918 .69671 .54724 .69351 .54353 Mtetra
.69351 .54353 .69671 .54724 .70353 .5453 .70034 .54158 Mtetra
.641 .761 .935 r
.70034 .54158 .70353 .5453 .71037 .54335 .70719 .53963 Mtetra
.70719 .53963 .71037 .54335 .71723 .54141 .71406 .53768 Mtetra
.71406 .53768 .71723 .54141 .7241 .53946 .72094 .53572 Mtetra
.641 .76 .935 r
.72094 .53572 .7241 .53946 .73099 .53752 .72784 .53376 Mtetra
.72784 .53376 .73099 .53752 .73789 .53557 .73476 .5318 Mtetra
.64 .76 .935 r
.73476 .5318 .73789 .53557 .74482 .53362 .7417 .52984 Mtetra
.7417 .52984 .74482 .53362 .75176 .53166 .74865 .52788 Mtetra
.74865 .52788 .75176 .53166 .75872 .52971 .75562 .52592 Mtetra
.64 .76 .936 r
.75562 .52592 .75872 .52971 .76569 .52775 .76261 .52396 Mtetra
.639 .76 .936 r
.76261 .52396 .76569 .52775 .77269 .52579 .76961 .52199 Mtetra
.76961 .52199 .77269 .52579 .7797 .52384 .77664 .52002 Mtetra
.77664 .52002 .7797 .52384 .78673 .52187 .78368 .51804 Mtetra
.64 .76 .936 r
.78368 .51804 .78673 .52187 .79377 .51989 .79073 .51606 Mtetra
.641 .761 .935 r
.79073 .51606 .79377 .51989 .80084 .51789 .79781 .51405 Mtetra
.645 .762 .934 r
.79781 .51405 .80084 .51789 .80791 .51582 .8049 .51197 Mtetra
.649 .764 .933 r
.8049 .51197 .80791 .51582 .815 .5137 .812 .50983 Mtetra
.672 .773 .926 r
.812 .50983 .815 .5137 .82207 .51119 .81908 .50731 Mtetra
.697 .782 .917 r
.81908 .50731 .82207 .51119 .82911 .50823 .82614 .50435 Mtetra
.732 .794 .902 r
.82614 .50435 .82911 .50823 .83611 .50459 .83315 .50069 Mtetra
.811 .815 .853 r
.83315 .50069 .83611 .50459 .84292 .49889 .83997 .49498 Mtetra
.854 .821 .815 r
.83997 .49498 .84292 .49889 .84958 .4916 .84665 .48768 Mtetra
.917 .819 .734 r
.84665 .48768 .84958 .4916 .85585 .48049 .85293 .47654 Mtetra
.954 .804 .656 r
.85293 .47654 .85585 .48049 .8616 .46457 .85871 .4606 Mtetra
.967 .794 .616 r
.85871 .4606 .8616 .46457 .86698 .4455 .86411 .4415 Mtetra
.982 .769 .54 r
.86411 .4415 .86698 .4455 .87139 .41784 .86855 .41381 Mtetra
.985 .76 .516 r
.86855 .41381 .87139 .41784 .8753 .38661 .8725 .38254 Mtetra
.943 .627 .41 r
.24801 .54797 .25174 .55126 .25487 .58038 .25112 .57711 Mtetra
.942 .619 .394 r
.25112 .57711 .25487 .58038 .25831 .60707 .25452 .60383 Mtetra
.935 .58 .322 r
.25452 .60383 .25831 .60707 .26245 .62588 .25864 .62265 Mtetra
.925 .547 .265 r
.25864 .62265 .26245 .62588 .26691 .64141 .26309 .63819 Mtetra
.875 .436 .089 r
.26309 .63819 .26691 .64141 .27182 .65175 .26799 .64854 Mtetra
.622 .098 0 r
.26799 .64854 .27182 .65175 .27711 .65741 .27328 .65421 Mtetra
0 .224 .69 r
.27328 .65421 .27711 .65741 .28258 .66106 .27875 .65786 Mtetra
.339 .64 .964 r
.27875 .65786 .28258 .66106 .28828 .66188 .28445 .65866 Mtetra
.497 .712 .967 r
.28445 .65866 .28828 .66188 .29406 .66165 .29024 .65843 Mtetra
.573 .74 .956 r
.29024 .65843 .29406 .66165 .29991 .66074 .2961 .65752 Mtetra
.632 .759 .939 r
.2961 .65752 .29991 .66074 .30581 .65918 .30201 .65595 Mtetra
.639 .761 .936 r
.30201 .65595 .30581 .65918 .31173 .65752 .30794 .65428 Mtetra
.648 .763 .933 r
.30794 .65428 .31173 .65752 .31768 .65574 .31389 .6525 Mtetra
.652 .764 .931 r
.31389 .6525 .31768 .65574 .32364 .6539 .31986 .65065 Mtetra
.653 .764 .931 r
.31986 .65065 .32364 .6539 .32961 .65205 .32584 .64879 Mtetra
.32584 .64879 .32961 .65205 .3356 .65019 .33184 .64692 Mtetra
.33184 .64692 .3356 .65019 .3416 .64832 .33785 .64504 Mtetra
.33785 .64504 .3416 .64832 .34761 .64644 .34387 .64316 Mtetra
.652 .764 .931 r
.34387 .64316 .34761 .64644 .35364 .64458 .3499 .64129 Mtetra
.3499 .64129 .35364 .64458 .35968 .64271 .35595 .63941 Mtetra
.653 .764 .931 r
.35595 .63941 .35968 .64271 .36573 .64083 .36201 .63752 Mtetra
.651 .764 .932 r
.36201 .63752 .36573 .64083 .3718 .63896 .36809 .63565 Mtetra
.652 .764 .932 r
.36809 .63565 .3718 .63896 .37788 .63709 .37418 .63377 Mtetra
.652 .764 .931 r
.37418 .63377 .37788 .63709 .38397 .63521 .38028 .63188 Mtetra
.651 .764 .932 r
.38028 .63188 .38397 .63521 .39008 .63334 .38639 .63 Mtetra
.38639 .63 .39008 .63334 .3962 .63146 .39252 .62812 Mtetra
.39252 .62812 .3962 .63146 .40233 .62958 .39867 .62623 Mtetra
.65 .764 .932 r
.39867 .62623 .40233 .62958 .40848 .6277 .40482 .62434 Mtetra
.65 .763 .932 r
.40482 .62434 .40848 .6277 .41464 .62583 .41099 .62246 Mtetra
.651 .764 .932 r
.41099 .62246 .41464 .62583 .42082 .62394 .41718 .62056 Mtetra
.65 .764 .932 r
.41718 .62056 .42082 .62394 .427 .62205 .42337 .61867 Mtetra
.649 .763 .932 r
.42337 .61867 .427 .62205 .43321 .62018 .42959 .61678 Mtetra
.65 .764 .932 r
.42959 .61678 .43321 .62018 .43942 .61828 .43581 .61489 Mtetra
.65 .763 .932 r
.43581 .61489 .43942 .61828 .44565 .61639 .44205 .61299 Mtetra
.649 .763 .933 r
.44205 .61299 .44565 .61639 .4519 .61451 .44831 .6111 Mtetra
.649 .763 .932 r
.44831 .6111 .4519 .61451 .45816 .61262 .45457 .6092 Mtetra
.45457 .6092 .45816 .61262 .46443 .61072 .46086 .60729 Mtetra
.648 .763 .933 r
.46086 .60729 .46443 .61072 .47072 .60884 .46715 .6054 Mtetra
.46715 .6054 .47072 .60884 .47702 .60694 .47346 .6035 Mtetra
.649 .763 .933 r
.47346 .6035 .47702 .60694 .48334 .60504 .47979 .60158 Mtetra
.647 .763 .933 r
.47979 .60158 .48334 .60504 .48967 .60315 .48613 .59969 Mtetra
.648 .763 .933 r
.48613 .59969 .48967 .60315 .49602 .60125 .49249 .59778 Mtetra
.49249 .59778 .49602 .60125 .50238 .59934 .49886 .59586 Mtetra
.647 .763 .933 r
.49886 .59586 .50238 .59934 .50875 .59745 .50524 .59396 Mtetra
.50524 .59396 .50875 .59745 .51514 .59555 .51164 .59205 Mtetra
.648 .763 .933 r
.51164 .59205 .51514 .59555 .52155 .59363 .51806 .59013 Mtetra
.647 .762 .933 r
.51806 .59013 .52155 .59363 .52796 .59173 .52448 .58822 Mtetra
.646 .762 .934 r
.52448 .58822 .52796 .59173 .5344 .58983 .53093 .58631 Mtetra
.647 .763 .933 r
.53093 .58631 .5344 .58983 .54085 .58791 .53739 .58438 Mtetra
.646 .762 .934 r
.53739 .58438 .54085 .58791 .54731 .586 .54386 .58246 Mtetra
.645 .762 .934 r
.54386 .58246 .54731 .586 .55379 .58409 .55035 .58055 Mtetra
.646 .762 .934 r
.55035 .58055 .55379 .58409 .56029 .58217 .55686 .57862 Mtetra
.55686 .57862 .56029 .58217 .5668 .58025 .56338 .57669 Mtetra
.645 .762 .934 r
.56338 .57669 .5668 .58025 .57333 .57834 .56992 .57477 Mtetra
.56992 .57477 .57333 .57834 .57987 .57642 .57647 .57284 Mtetra
.57647 .57284 .57987 .57642 .58642 .57449 .58303 .5709 Mtetra
.644 .762 .934 r
.58303 .5709 .58642 .57449 .593 .57258 .58962 .56898 Mtetra
.645 .762 .934 r
.58962 .56898 .593 .57258 .59958 .57065 .59622 .56705 Mtetra
.59622 .56705 .59958 .57065 .60619 .56871 .60283 .5651 Mtetra
.643 .761 .934 r
.60283 .5651 .60619 .56871 .61281 .5668 .60946 .56318 Mtetra
.644 .762 .934 r
.60946 .56318 .61281 .5668 .61944 .56487 .61611 .56124 Mtetra
.61611 .56124 .61944 .56487 .6261 .56293 .62277 .55929 Mtetra
.643 .761 .935 r
.62277 .55929 .6261 .56293 .63276 .561 .62945 .55735 Mtetra
.62945 .55735 .63276 .561 .63945 .55907 .63614 .55542 Mtetra
.643 .761 .934 r
.63614 .55542 .63945 .55907 .64615 .55713 .64285 .55347 Mtetra
.643 .761 .935 r
.64285 .55347 .64615 .55713 .65286 .5552 .64958 .55152 Mtetra
.64958 .55152 .65286 .5552 .6596 .55326 .65632 .54958 Mtetra
.65632 .54958 .6596 .55326 .66635 .55131 .66308 .54763 Mtetra
.642 .761 .935 r
.66308 .54763 .66635 .55131 .67311 .54937 .66986 .54567 Mtetra
.66986 .54567 .67311 .54937 .67989 .54743 .67665 .54372 Mtetra
.67665 .54372 .67989 .54743 .68669 .54548 .68346 .54176 Mtetra
.68346 .54176 .68669 .54548 .69351 .54353 .69029 .53981 Mtetra
.69029 .53981 .69351 .54353 .70034 .54158 .69714 .53785 Mtetra
.641 .761 .935 r
.69714 .53785 .70034 .54158 .70719 .53963 .704 .53589 Mtetra
.704 .53589 .70719 .53963 .71406 .53768 .71087 .53392 Mtetra
.641 .76 .935 r
.71087 .53392 .71406 .53768 .72094 .53572 .71777 .53196 Mtetra
.71777 .53196 .72094 .53572 .72784 .53376 .72468 .52999 Mtetra
.72468 .52999 .72784 .53376 .73476 .5318 .73161 .52803 Mtetra
.64 .76 .935 r
.73161 .52803 .73476 .5318 .7417 .52984 .73856 .52606 Mtetra
.73856 .52606 .7417 .52984 .74865 .52788 .74552 .52409 Mtetra
.74552 .52409 .74865 .52788 .75562 .52592 .75251 .52211 Mtetra
.64 .76 .936 r
.75251 .52211 .75562 .52592 .76261 .52396 .75951 .52014 Mtetra
.639 .76 .936 r
.75951 .52014 .76261 .52396 .76961 .52199 .76652 .51816 Mtetra
.76652 .51816 .76961 .52199 .77664 .52002 .77356 .51619 Mtetra
.77356 .51619 .77664 .52002 .78368 .51804 .78061 .5142 Mtetra
.64 .76 .935 r
.78061 .5142 .78368 .51804 .79073 .51606 .78768 .51221 Mtetra
.641 .76 .935 r
.78768 .51221 .79073 .51606 .79781 .51405 .79477 .51019 Mtetra
.645 .762 .934 r
.79477 .51019 .79781 .51405 .8049 .51197 .80187 .5081 Mtetra
.649 .764 .933 r
.80187 .5081 .8049 .51197 .812 .50983 .80898 .50595 Mtetra
.672 .773 .926 r
.80898 .50595 .812 .50983 .81908 .50731 .81608 .50342 Mtetra
.697 .782 .917 r
.81608 .50342 .81908 .50731 .82614 .50435 .82315 .50045 Mtetra
.732 .794 .902 r
.82315 .50045 .82614 .50435 .83315 .50069 .83017 .49678 Mtetra
.811 .815 .853 r
.83017 .49678 .83315 .50069 .83997 .49498 .83701 .49105 Mtetra
.854 .821 .815 r
.83701 .49105 .83997 .49498 .84665 .48768 .8437 .48374 Mtetra
.917 .819 .734 r
.8437 .48374 .84665 .48768 .85293 .47654 .85001 .47258 Mtetra
.954 .804 .656 r
.85001 .47258 .85293 .47654 .85871 .4606 .8558 .45661 Mtetra
.967 .793 .616 r
.8558 .45661 .85871 .4606 .86411 .4415 .86123 .43748 Mtetra
.982 .769 .54 r
.86123 .43748 .86411 .4415 .86855 .41381 .8657 .40976 Mtetra
.985 .76 .516 r
.8657 .40976 .86855 .41381 .8725 .38254 .86967 .37845 Mtetra
.943 .627 .409 r
.24427 .54466 .24801 .54797 .25112 .57711 .24734 .57382 Mtetra
.942 .619 .394 r
.24734 .57382 .25112 .57711 .25452 .60383 .25072 .60056 Mtetra
.935 .58 .322 r
.25072 .60056 .25452 .60383 .25864 .62265 .25482 .61939 Mtetra
.925 .547 .264 r
.25482 .61939 .25864 .62265 .26309 .63819 .25925 .63495 Mtetra
.875 .435 .088 r
.25925 .63495 .26309 .63819 .26799 .64854 .26415 .64531 Mtetra
.621 .097 0 r
.26415 .64531 .26799 .64854 .27328 .65421 .26944 .65097 Mtetra
0 .225 .692 r
.26944 .65097 .27328 .65421 .27875 .65786 .27491 .65462 Mtetra
.341 .64 .964 r
.27491 .65462 .27875 .65786 .28445 .65866 .28062 .65542 Mtetra
.498 .712 .967 r
.28062 .65542 .28445 .65866 .29024 .65843 .28641 .65518 Mtetra
.573 .74 .955 r
.28641 .65518 .29024 .65843 .2961 .65752 .29227 .65427 Mtetra
.632 .758 .938 r
.29227 .65427 .2961 .65752 .30201 .65595 .29819 .65269 Mtetra
.639 .76 .936 r
.29819 .65269 .30201 .65595 .30794 .65428 .30413 .65102 Mtetra
.648 .762 .932 r
.30413 .65102 .30794 .65428 .31389 .6525 .31009 .64922 Mtetra
.652 .763 .931 r
.31009 .64922 .31389 .6525 .31986 .65065 .31607 .64737 Mtetra
.653 .763 .931 r
.31607 .64737 .31986 .65065 .32584 .64879 .32206 .6455 Mtetra
.32206 .6455 .32584 .64879 .33184 .64692 .32806 .64362 Mtetra
.653 .764 .93 r
.32806 .64362 .33184 .64692 .33785 .64504 .33408 .64174 Mtetra
.33408 .64174 .33785 .64504 .34387 .64316 .34011 .63985 Mtetra
.652 .763 .931 r
.34011 .63985 .34387 .64316 .3499 .64129 .34615 .63797 Mtetra
.653 .763 .931 r
.34615 .63797 .3499 .64129 .35595 .63941 .35221 .63608 Mtetra
.35221 .63608 .35595 .63941 .36201 .63752 .35828 .63419 Mtetra
.651 .763 .931 r
.35828 .63419 .36201 .63752 .36809 .63565 .36436 .63231 Mtetra
.652 .763 .931 r
.36436 .63231 .36809 .63565 .37418 .63377 .37046 .63042 Mtetra
.37046 .63042 .37418 .63377 .38028 .63188 .37657 .62852 Mtetra
.651 .763 .931 r
.37657 .62852 .38028 .63188 .38639 .63 .38269 .62664 Mtetra
.38269 .62664 .38639 .63 .39252 .62812 .38883 .62475 Mtetra
.38883 .62475 .39252 .62812 .39867 .62623 .39498 .62285 Mtetra
.39498 .62285 .39867 .62623 .40482 .62434 .40115 .62095 Mtetra
.65 .763 .932 r
.40115 .62095 .40482 .62434 .41099 .62246 .40733 .61906 Mtetra
.651 .763 .931 r
.40733 .61906 .41099 .62246 .41718 .62056 .41352 .61716 Mtetra
.65 .763 .932 r
.41352 .61716 .41718 .62056 .42337 .61867 .41973 .61526 Mtetra
.649 .762 .932 r
.41973 .61526 .42337 .61867 .42959 .61678 .42595 .61337 Mtetra
.65 .763 .932 r
.42595 .61337 .42959 .61678 .43581 .61489 .43218 .61146 Mtetra
.43218 .61146 .43581 .61489 .44205 .61299 .43843 .60955 Mtetra
.649 .762 .932 r
.43843 .60955 .44205 .61299 .44831 .6111 .4447 .60766 Mtetra
.4447 .60766 .44831 .6111 .45457 .6092 .45097 .60575 Mtetra
.45097 .60575 .45457 .6092 .46086 .60729 .45727 .60383 Mtetra
.648 .762 .932 r
.45727 .60383 .46086 .60729 .46715 .6054 .46357 .60193 Mtetra
.649 .762 .932 r
.46357 .60193 .46715 .6054 .47346 .6035 .46989 .60002 Mtetra
.46989 .60002 .47346 .6035 .47979 .60158 .47623 .5981 Mtetra
.647 .762 .933 r
.47623 .5981 .47979 .60158 .48613 .59969 .48258 .5962 Mtetra
.648 .762 .932 r
.48258 .5962 .48613 .59969 .49249 .59778 .48894 .59428 Mtetra
.48894 .59428 .49249 .59778 .49886 .59586 .49532 .59236 Mtetra
.647 .762 .933 r
.49532 .59236 .49886 .59586 .50524 .59396 .50172 .59044 Mtetra
.50172 .59044 .50524 .59396 .51164 .59205 .50813 .58853 Mtetra
.648 .762 .932 r
.50813 .58853 .51164 .59205 .51806 .59013 .51455 .5866 Mtetra
.647 .762 .933 r
.51455 .5866 .51806 .59013 .52448 .58822 .52099 .58468 Mtetra
.646 .762 .933 r
.52099 .58468 .52448 .58822 .53093 .58631 .52744 .58276 Mtetra
.647 .762 .933 r
.52744 .58276 .53093 .58631 .53739 .58438 .53391 .58083 Mtetra
.646 .762 .933 r
.53391 .58083 .53739 .58438 .54386 .58246 .5404 .5789 Mtetra
.645 .761 .933 r
.5404 .5789 .54386 .58246 .55035 .58055 .5469 .57698 Mtetra
.646 .762 .933 r
.5469 .57698 .55035 .58055 .55686 .57862 .55341 .57504 Mtetra
.646 .761 .933 r
.55341 .57504 .55686 .57862 .56338 .57669 .55994 .5731 Mtetra
.645 .761 .933 r
.55994 .5731 .56338 .57669 .56992 .57477 .56649 .57118 Mtetra
.646 .761 .933 r
.56649 .57118 .56992 .57477 .57647 .57284 .57305 .56923 Mtetra
.57305 .56923 .57647 .57284 .58303 .5709 .57963 .56729 Mtetra
.644 .761 .934 r
.57963 .56729 .58303 .5709 .58962 .56898 .58622 .56536 Mtetra
.645 .761 .933 r
.58622 .56536 .58962 .56898 .59622 .56705 .59283 .56342 Mtetra
.59283 .56342 .59622 .56705 .60283 .5651 .59946 .56146 Mtetra
.644 .761 .934 r
.59946 .56146 .60283 .5651 .60946 .56318 .6061 .55953 Mtetra
.6061 .55953 .60946 .56318 .61611 .56124 .61275 .55758 Mtetra
.645 .761 .933 r
.61275 .55758 .61611 .56124 .62277 .55929 .61943 .55562 Mtetra
.643 .76 .934 r
.61943 .55562 .62277 .55929 .62945 .55735 .62612 .55368 Mtetra
.62612 .55368 .62945 .55735 .63614 .55542 .63282 .55173 Mtetra
.643 .761 .934 r
.63282 .55173 .63614 .55542 .64285 .55347 .63954 .54978 Mtetra
.643 .76 .934 r
.63954 .54978 .64285 .55347 .64958 .55152 .64628 .54782 Mtetra
.64628 .54782 .64958 .55152 .65632 .54958 .65304 .54586 Mtetra
.65304 .54586 .65632 .54958 .66308 .54763 .65981 .54391 Mtetra
.642 .76 .934 r
.65981 .54391 .66308 .54763 .66986 .54567 .6666 .54194 Mtetra
.6666 .54194 .66986 .54567 .67665 .54372 .6734 .53998 Mtetra
.6734 .53998 .67665 .54372 .68346 .54176 .68022 .53802 Mtetra
.68022 .53802 .68346 .54176 .69029 .53981 .68706 .53605 Mtetra
.68706 .53605 .69029 .53981 .69714 .53785 .69391 .53408 Mtetra
.641 .76 .934 r
.69391 .53408 .69714 .53785 .704 .53589 .70079 .53211 Mtetra
.70079 .53211 .704 .53589 .71087 .53392 .70768 .53014 Mtetra
.641 .76 .935 r
.70768 .53014 .71087 .53392 .71777 .53196 .71458 .52817 Mtetra
.71458 .52817 .71777 .53196 .72468 .52999 .72151 .52619 Mtetra
.72151 .52619 .72468 .52999 .73161 .52803 .72845 .52421 Mtetra
.64 .759 .935 r
.72845 .52421 .73161 .52803 .73856 .52606 .73541 .52224 Mtetra
.73541 .52224 .73856 .52606 .74552 .52409 .74238 .52026 Mtetra
.74238 .52026 .74552 .52409 .75251 .52211 .74938 .51827 Mtetra
.74938 .51827 .75251 .52211 .75951 .52014 .75639 .51629 Mtetra
.75639 .51629 .75951 .52014 .76652 .51816 .76342 .51431 Mtetra
.639 .759 .935 r
.76342 .51431 .76652 .51816 .77356 .51619 .77047 .51232 Mtetra
.77047 .51232 .77356 .51619 .78061 .5142 .77753 .51033 Mtetra
.64 .759 .935 r
.77753 .51033 .78061 .5142 .78768 .51221 .78461 .50832 Mtetra
.641 .76 .935 r
.78461 .50832 .78768 .51221 .79477 .51019 .79171 .50629 Mtetra
.645 .761 .933 r
.79171 .50629 .79477 .51019 .80187 .5081 .79882 .5042 Mtetra
.649 .763 .932 r
.79882 .5042 .80187 .5081 .80898 .50595 .80595 .50204 Mtetra
.672 .772 .925 r
.80595 .50204 .80898 .50595 .81608 .50342 .81306 .4995 Mtetra
.696 .781 .916 r
.81306 .4995 .81608 .50342 .82315 .50045 .82014 .49651 Mtetra
.731 .793 .901 r
.82014 .49651 .82315 .50045 .83017 .49678 .82718 .49283 Mtetra
.811 .814 .853 r
.82718 .49283 .83017 .49678 .83701 .49105 .83403 .48709 Mtetra
.854 .82 .815 r
.83403 .48709 .83701 .49105 .8437 .48374 .84074 .47976 Mtetra
.917 .818 .734 r
.84074 .47976 .8437 .48374 .85001 .47258 .84707 .46858 Mtetra
.954 .804 .656 r
.84707 .46858 .85001 .47258 .8558 .45661 .85289 .45259 Mtetra
.967 .793 .616 r
.85289 .45259 .8558 .45661 .86123 .43748 .85834 .43344 Mtetra
.982 .769 .54 r
.85834 .43344 .86123 .43748 .8657 .40976 .86283 .40567 Mtetra
.985 .76 .516 r
.86283 .40567 .8657 .40976 .86967 .37845 .86684 .37433 Mtetra
.943 .627 .41 r
.24052 .54134 .24427 .54466 .24734 .57382 .24355 .57053 Mtetra
.942 .619 .394 r
.24355 .57053 .24734 .57382 .25072 .60056 .2469 .59729 Mtetra
.935 .58 .322 r
.2469 .59729 .25072 .60056 .25482 .61939 .25098 .61614 Mtetra
.925 .547 .265 r
.25098 .61614 .25482 .61939 .25925 .63495 .2554 .63171 Mtetra
.875 .436 .089 r
.2554 .63171 .25925 .63495 .26415 .64531 .26029 .64207 Mtetra
.622 .098 0 r
.26029 .64207 .26415 .64531 .26944 .65097 .26558 .64774 Mtetra
0 .224 .69 r
.26558 .64774 .26944 .65097 .27491 .65462 .27105 .65138 Mtetra
.339 .64 .964 r
.27105 .65138 .27491 .65462 .28062 .65542 .27676 .65218 Mtetra
.497 .712 .967 r
.27676 .65218 .28062 .65542 .28641 .65518 .28256 .65194 Mtetra
.573 .74 .956 r
.28256 .65194 .28641 .65518 .29227 .65427 .28843 .65102 Mtetra
.632 .759 .939 r
.28843 .65102 .29227 .65427 .29819 .65269 .29436 .64943 Mtetra
.639 .761 .936 r
.29436 .64943 .29819 .65269 .30413 .65102 .3003 .64775 Mtetra
.648 .763 .933 r
.3003 .64775 .30413 .65102 .31009 .64922 .30627 .64595 Mtetra
.652 .764 .931 r
.30627 .64595 .31009 .64922 .31607 .64737 .31226 .64409 Mtetra
.653 .764 .931 r
.31226 .64409 .31607 .64737 .32206 .6455 .31826 .64221 Mtetra
.31826 .64221 .32206 .6455 .32806 .64362 .32427 .64033 Mtetra
.32427 .64033 .32806 .64362 .33408 .64174 .33029 .63843 Mtetra
.33029 .63843 .33408 .64174 .34011 .63985 .33633 .63653 Mtetra
.652 .764 .931 r
.33633 .63653 .34011 .63985 .34615 .63797 .34238 .63465 Mtetra
.34238 .63465 .34615 .63797 .35221 .63608 .34845 .63276 Mtetra
.653 .764 .931 r
.34845 .63276 .35221 .63608 .35828 .63419 .35453 .63085 Mtetra
.651 .764 .932 r
.35453 .63085 .35828 .63419 .36436 .63231 .36062 .62897 Mtetra
.652 .764 .932 r
.36062 .62897 .36436 .63231 .37046 .63042 .36673 .62707 Mtetra
.652 .764 .931 r
.36673 .62707 .37046 .63042 .37657 .62852 .37285 .62516 Mtetra
.651 .764 .932 r
.37285 .62516 .37657 .62852 .38269 .62664 .37898 .62327 Mtetra
.37898 .62327 .38269 .62664 .38883 .62475 .38512 .62137 Mtetra
.38512 .62137 .38883 .62475 .39498 .62285 .39129 .61946 Mtetra
.65 .764 .932 r
.39129 .61946 .39498 .62285 .40115 .62095 .39746 .61756 Mtetra
.65 .763 .932 r
.39746 .61756 .40115 .62095 .40733 .61906 .40365 .61567 Mtetra
.651 .764 .932 r
.40365 .61567 .40733 .61906 .41352 .61716 .40985 .61375 Mtetra
.65 .763 .932 r
.40985 .61375 .41352 .61716 .41973 .61526 .41607 .61185 Mtetra
.649 .763 .932 r
.41607 .61185 .41973 .61526 .42595 .61337 .4223 .60995 Mtetra
.65 .763 .932 r
.4223 .60995 .42595 .61337 .43218 .61146 .42854 .60803 Mtetra
.42854 .60803 .43218 .61146 .43843 .60955 .4348 .60612 Mtetra
.649 .763 .933 r
.4348 .60612 .43843 .60955 .4447 .60766 .44107 .60421 Mtetra
.649 .763 .932 r
.44107 .60421 .4447 .60766 .45097 .60575 .44736 .60229 Mtetra
.44736 .60229 .45097 .60575 .45727 .60383 .45366 .60037 Mtetra
.648 .763 .933 r
.45366 .60037 .45727 .60383 .46357 .60193 .45997 .59846 Mtetra
.45997 .59846 .46357 .60193 .46989 .60002 .4663 .59654 Mtetra
.649 .763 .933 r
.4663 .59654 .46989 .60002 .47623 .5981 .47265 .59462 Mtetra
.647 .763 .933 r
.47265 .59462 .47623 .5981 .48258 .5962 .47901 .5927 Mtetra
.648 .763 .933 r
.47901 .5927 .48258 .5962 .48894 .59428 .48538 .59078 Mtetra
.48538 .59078 .48894 .59428 .49532 .59236 .49177 .58885 Mtetra
.647 .763 .933 r
.49177 .58885 .49532 .59236 .50172 .59044 .49818 .58693 Mtetra
.49818 .58693 .50172 .59044 .50813 .58853 .5046 .585 Mtetra
.648 .763 .933 r
.5046 .585 .50813 .58853 .51455 .5866 .51103 .58306 Mtetra
.647 .762 .933 r
.51103 .58306 .51455 .5866 .52099 .58468 .51748 .58114 Mtetra
.646 .762 .934 r
.51748 .58114 .52099 .58468 .52744 .58276 .52394 .57921 Mtetra
.647 .763 .933 r
.52394 .57921 .52744 .58276 .53391 .58083 .53042 .57727 Mtetra
.646 .762 .933 r
.53042 .57727 .53391 .58083 .5404 .5789 .53692 .57533 Mtetra
.645 .762 .934 r
.53692 .57533 .5404 .5789 .5469 .57698 .54343 .5734 Mtetra
.646 .762 .933 r
.54343 .5734 .5469 .57698 .55341 .57504 .54995 .57145 Mtetra
.646 .762 .934 r
.54995 .57145 .55341 .57504 .55994 .5731 .55649 .56951 Mtetra
.645 .762 .934 r
.55649 .56951 .55994 .5731 .56649 .57118 .56305 .56757 Mtetra
.56305 .56757 .56649 .57118 .57305 .56923 .56962 .56562 Mtetra
.56962 .56562 .57305 .56923 .57963 .56729 .57621 .56367 Mtetra
.644 .762 .934 r
.57621 .56367 .57963 .56729 .58622 .56536 .58281 .56173 Mtetra
.645 .762 .934 r
.58281 .56173 .58622 .56536 .59283 .56342 .58943 .55978 Mtetra
.58943 .55978 .59283 .56342 .59946 .56146 .59607 .55782 Mtetra
.643 .761 .934 r
.59607 .55782 .59946 .56146 .6061 .55953 .60272 .55587 Mtetra
.644 .762 .934 r
.60272 .55587 .6061 .55953 .61275 .55758 .60939 .55392 Mtetra
.645 .762 .934 r
.60939 .55392 .61275 .55758 .61943 .55562 .61607 .55195 Mtetra
.643 .761 .934 r
.61607 .55195 .61943 .55562 .62612 .55368 .62277 .55 Mtetra
.643 .761 .935 r
.62277 .55 .62612 .55368 .63282 .55173 .62949 .54804 Mtetra
.643 .761 .934 r
.62949 .54804 .63282 .55173 .63954 .54978 .63622 .54608 Mtetra
.643 .761 .935 r
.63622 .54608 .63954 .54978 .64628 .54782 .64297 .54412 Mtetra
.64297 .54412 .64628 .54782 .65304 .54586 .64973 .54215 Mtetra
.64973 .54215 .65304 .54586 .65981 .54391 .65652 .54018 Mtetra
.642 .761 .935 r
.65652 .54018 .65981 .54391 .6666 .54194 .66332 .53821 Mtetra
.66332 .53821 .6666 .54194 .6734 .53998 .67013 .53624 Mtetra
.67013 .53624 .6734 .53998 .68022 .53802 .67696 .53427 Mtetra
.67696 .53427 .68022 .53802 .68706 .53605 .68381 .53229 Mtetra
.68381 .53229 .68706 .53605 .69391 .53408 .69068 .53031 Mtetra
.641 .761 .935 r
.69068 .53031 .69391 .53408 .70079 .53211 .69756 .52834 Mtetra
.69756 .52834 .70079 .53211 .70768 .53014 .70446 .52635 Mtetra
.641 .76 .935 r
.70446 .52635 .70768 .53014 .71458 .52817 .71138 .52437 Mtetra
.71138 .52437 .71458 .52817 .72151 .52619 .71832 .52239 Mtetra
.71832 .52239 .72151 .52619 .72845 .52421 .72527 .5204 Mtetra
.64 .76 .935 r
.72527 .5204 .72845 .52421 .73541 .52224 .73224 .51841 Mtetra
.73224 .51841 .73541 .52224 .74238 .52026 .73923 .51642 Mtetra
.73923 .51642 .74238 .52026 .74938 .51827 .74624 .51443 Mtetra
.74624 .51443 .74938 .51827 .75639 .51629 .75326 .51244 Mtetra
.639 .76 .936 r
.75326 .51244 .75639 .51629 .76342 .51431 .7603 .51045 Mtetra
.7603 .51045 .76342 .51431 .77047 .51232 .76736 .50845 Mtetra
.76736 .50845 .77047 .51232 .77753 .51033 .77444 .50645 Mtetra
.64 .76 .935 r
.77444 .50645 .77753 .51033 .78461 .50832 .78153 .50443 Mtetra
.641 .76 .935 r
.78153 .50443 .78461 .50832 .79171 .50629 .78864 .5024 Mtetra
.645 .762 .934 r
.78864 .5024 .79171 .50629 .79882 .5042 .79577 .50029 Mtetra
.649 .764 .933 r
.79577 .50029 .79882 .5042 .80595 .50204 .8029 .49812 Mtetra
.672 .773 .926 r
.8029 .49812 .80595 .50204 .81306 .4995 .81003 .49557 Mtetra
.697 .782 .917 r
.81003 .49557 .81306 .4995 .82014 .49651 .81712 .49257 Mtetra
.732 .794 .902 r
.81712 .49257 .82014 .49651 .82718 .49283 .82417 .48888 Mtetra
.811 .815 .853 r
.82417 .48888 .82718 .49283 .83403 .48709 .83105 .48313 Mtetra
.854 .821 .815 r
.83105 .48313 .83403 .48709 .84074 .47976 .83777 .47578 Mtetra
.917 .819 .734 r
.83777 .47578 .84074 .47976 .84707 .46858 .84411 .46459 Mtetra
.954 .804 .656 r
.84411 .46459 .84707 .46858 .85289 .45259 .84995 .44857 Mtetra
.967 .793 .616 r
.84995 .44857 .85289 .45259 .85834 .43344 .85543 .42939 Mtetra
.982 .769 .54 r
.85543 .42939 .85834 .43344 .86283 .40567 .85995 .40159 Mtetra
.985 .76 .516 r
.85995 .40159 .86283 .40567 .86684 .37433 .86399 .3702 Mtetra
.943 .627 .41 r
.23675 .53801 .24052 .54134 .24355 .57053 .23975 .56723 Mtetra
.942 .619 .394 r
.23975 .56723 .24355 .57053 .2469 .59729 .24307 .59401 Mtetra
.935 .58 .322 r
.24307 .59401 .2469 .59729 .25098 .61614 .24713 .61288 Mtetra
.925 .547 .265 r
.24713 .61288 .25098 .61614 .2554 .63171 .25154 .62846 Mtetra
.875 .436 .089 r
.25154 .62846 .2554 .63171 .26029 .64207 .25641 .63883 Mtetra
.623 .099 0 r
.25641 .63883 .26029 .64207 .26558 .64774 .2617 .64449 Mtetra
0 .224 .69 r
.2617 .64449 .26558 .64774 .27105 .65138 .26718 .64814 Mtetra
.339 .64 .964 r
.26718 .64814 .27105 .65138 .27676 .65218 .27289 .64894 Mtetra
.497 .713 .967 r
.27289 .64894 .27676 .65218 .28256 .65194 .2787 .64868 Mtetra
.572 .741 .956 r
.2787 .64868 .28256 .65194 .28843 .65102 .28457 .64776 Mtetra
.632 .759 .939 r
.28457 .64776 .28843 .65102 .29436 .64943 .29051 .64617 Mtetra
.639 .761 .936 r
.29051 .64617 .29436 .64943 .3003 .64775 .29646 .64448 Mtetra
.648 .763 .933 r
.29646 .64448 .3003 .64775 .30627 .64595 .30244 .64267 Mtetra
.652 .764 .932 r
.30244 .64267 .30627 .64595 .31226 .64409 .30843 .6408 Mtetra
.653 .765 .931 r
.30843 .6408 .31226 .64409 .31826 .64221 .31444 .63891 Mtetra
.31444 .63891 .31826 .64221 .32427 .64033 .32046 .63702 Mtetra
.32046 .63702 .32427 .64033 .33029 .63843 .32649 .63512 Mtetra
.32649 .63512 .33029 .63843 .33633 .63653 .33254 .63322 Mtetra
.652 .764 .932 r
.33254 .63322 .33633 .63653 .34238 .63465 .3386 .63132 Mtetra
.652 .764 .931 r
.3386 .63132 .34238 .63465 .34845 .63276 .34467 .62942 Mtetra
.653 .765 .931 r
.34467 .62942 .34845 .63276 .35453 .63085 .35076 .62751 Mtetra
.651 .764 .932 r
.35076 .62751 .35453 .63085 .36062 .62897 .35686 .62562 Mtetra
.652 .764 .932 r
.35686 .62562 .36062 .62897 .36673 .62707 .36298 .62371 Mtetra
.36298 .62371 .36673 .62707 .37285 .62516 .36911 .6218 Mtetra
.651 .764 .932 r
.36911 .6218 .37285 .62516 .37898 .62327 .37525 .6199 Mtetra
.37525 .6199 .37898 .62327 .38512 .62137 .3814 .61799 Mtetra
.3814 .61799 .38512 .62137 .39129 .61946 .38757 .61608 Mtetra
.65 .764 .932 r
.38757 .61608 .39129 .61946 .39746 .61756 .39375 .61417 Mtetra
.39375 .61417 .39746 .61756 .40365 .61567 .39995 .61226 Mtetra
.651 .764 .932 r
.39995 .61226 .40365 .61567 .40985 .61375 .40616 .61034 Mtetra
.65 .764 .932 r
.40616 .61034 .40985 .61375 .41607 .61185 .41239 .60843 Mtetra
.649 .764 .933 r
.41239 .60843 .41607 .61185 .4223 .60995 .41863 .60652 Mtetra
.65 .764 .932 r
.41863 .60652 .4223 .60995 .42854 .60803 .42488 .60459 Mtetra
.65 .764 .933 r
.42488 .60459 .42854 .60803 .4348 .60612 .43115 .60267 Mtetra
.649 .763 .933 r
.43115 .60267 .4348 .60612 .44107 .60421 .43743 .60076 Mtetra
.649 .764 .933 r
.43743 .60076 .44107 .60421 .44736 .60229 .44373 .59883 Mtetra
.44373 .59883 .44736 .60229 .45366 .60037 .45004 .5969 Mtetra
.648 .763 .933 r
.45004 .5969 .45366 .60037 .45997 .59846 .45636 .59499 Mtetra
.45636 .59499 .45997 .59846 .4663 .59654 .4627 .59306 Mtetra
.649 .763 .933 r
.4627 .59306 .4663 .59654 .47265 .59462 .46906 .59112 Mtetra
.647 .763 .933 r
.46906 .59112 .47265 .59462 .47901 .5927 .47543 .5892 Mtetra
.648 .763 .933 r
.47543 .5892 .47901 .5927 .48538 .59078 .48181 .58727 Mtetra
.48181 .58727 .48538 .59078 .49177 .58885 .48821 .58533 Mtetra
.647 .763 .933 r
.48821 .58533 .49177 .58885 .49818 .58693 .49462 .5834 Mtetra
.49462 .5834 .49818 .58693 .5046 .585 .50105 .58147 Mtetra
.648 .763 .933 r
.50105 .58147 .5046 .585 .51103 .58306 .50749 .57952 Mtetra
.646 .763 .934 r
.50749 .57952 .51103 .58306 .51748 .58114 .51395 .57758 Mtetra
.51395 .57758 .51748 .58114 .52394 .57921 .52043 .57565 Mtetra
.647 .763 .933 r
.52043 .57565 .52394 .57921 .53042 .57727 .52692 .5737 Mtetra
.646 .763 .934 r
.52692 .5737 .53042 .57727 .53692 .57533 .53342 .57175 Mtetra
.645 .762 .934 r
.53342 .57175 .53692 .57533 .54343 .5734 .53994 .56981 Mtetra
.646 .763 .934 r
.53994 .56981 .54343 .5734 .54995 .57145 .54648 .56786 Mtetra
.646 .762 .934 r
.54648 .56786 .54995 .57145 .55649 .56951 .55303 .56591 Mtetra
.645 .762 .934 r
.55303 .56591 .55649 .56951 .56305 .56757 .55959 .56396 Mtetra
.55959 .56396 .56305 .56757 .56962 .56562 .56618 .562 Mtetra
.56618 .562 .56962 .56562 .57621 .56367 .57278 .56004 Mtetra
.644 .762 .934 r
.57278 .56004 .57621 .56367 .58281 .56173 .57939 .55809 Mtetra
.645 .762 .934 r
.57939 .55809 .58281 .56173 .58943 .55978 .58602 .55613 Mtetra
.58602 .55613 .58943 .55978 .59607 .55782 .59267 .55416 Mtetra
.643 .762 .935 r
.59267 .55416 .59607 .55782 .60272 .55587 .59933 .55221 Mtetra
.644 .762 .934 r
.59933 .55221 .60272 .55587 .60939 .55392 .60601 .55025 Mtetra
.60601 .55025 .60939 .55392 .61607 .55195 .6127 .54827 Mtetra
.643 .762 .935 r
.6127 .54827 .61607 .55195 .62277 .55 .61941 .54631 Mtetra
.643 .761 .935 r
.61941 .54631 .62277 .55 .62949 .54804 .62614 .54435 Mtetra
.643 .762 .935 r
.62614 .54435 .62949 .54804 .63622 .54608 .63288 .54237 Mtetra
.643 .761 .935 r
.63288 .54237 .63622 .54608 .64297 .54412 .63964 .5404 Mtetra
.63964 .5404 .64297 .54412 .64973 .54215 .64642 .53842 Mtetra
.64642 .53842 .64973 .54215 .65652 .54018 .65321 .53645 Mtetra
.642 .761 .935 r
.65321 .53645 .65652 .54018 .66332 .53821 .66002 .53447 Mtetra
.66002 .53447 .66332 .53821 .67013 .53624 .66685 .53249 Mtetra
.66685 .53249 .67013 .53624 .67696 .53427 .67369 .53051 Mtetra
.67369 .53051 .67696 .53427 .68381 .53229 .68055 .52852 Mtetra
.68055 .52852 .68381 .53229 .69068 .53031 .68743 .52653 Mtetra
.641 .761 .935 r
.68743 .52653 .69068 .53031 .69756 .52834 .69433 .52455 Mtetra
.69433 .52455 .69756 .52834 .70446 .52635 .70124 .52256 Mtetra
.70124 .52256 .70446 .52635 .71138 .52437 .70817 .52056 Mtetra
.70817 .52056 .71138 .52437 .71832 .52239 .71512 .51857 Mtetra
.64 .761 .935 r
.71512 .51857 .71832 .52239 .72527 .5204 .72208 .51658 Mtetra
.64 .76 .936 r
.72208 .51658 .72527 .5204 .73224 .51841 .72906 .51458 Mtetra
.72906 .51458 .73224 .51841 .73923 .51642 .73606 .51258 Mtetra
.73606 .51258 .73923 .51642 .74624 .51443 .74308 .51058 Mtetra
.74308 .51058 .74624 .51443 .75326 .51244 .75012 .50858 Mtetra
.639 .76 .936 r
.75012 .50858 .75326 .51244 .7603 .51045 .75717 .50657 Mtetra
.75717 .50657 .7603 .51045 .76736 .50845 .76424 .50457 Mtetra
.76424 .50457 .76736 .50845 .77444 .50645 .77133 .50256 Mtetra
.64 .76 .936 r
.77133 .50256 .77444 .50645 .78153 .50443 .77844 .50053 Mtetra
.641 .761 .935 r
.77844 .50053 .78153 .50443 .78864 .5024 .78556 .49849 Mtetra
.645 .762 .934 r
.78556 .49849 .78864 .5024 .79577 .50029 .7927 .49637 Mtetra
.649 .764 .933 r
.7927 .49637 .79577 .50029 .8029 .49812 .79985 .49419 Mtetra
.672 .773 .926 r
.79985 .49419 .8029 .49812 .81003 .49557 .80698 .49163 Mtetra
.697 .782 .917 r
.80698 .49163 .81003 .49557 .81712 .49257 .81409 .48862 Mtetra
.732 .794 .902 r
.81409 .48862 .81712 .49257 .82417 .48888 .82116 .48492 Mtetra
.811 .815 .853 r
.82116 .48492 .82417 .48888 .83105 .48313 .82804 .47915 Mtetra
.854 .821 .815 r
.82804 .47915 .83105 .48313 .83777 .47578 .83478 .47179 Mtetra
.917 .819 .734 r
.83478 .47179 .83777 .47578 .84411 .46459 .84114 .46057 Mtetra
.954 .804 .656 r
.84114 .46057 .84411 .46459 .84995 .44857 .84701 .44453 Mtetra
.967 .794 .616 r
.84701 .44453 .84995 .44857 .85543 .42939 .85251 .42532 Mtetra
.982 .769 .54 r
.85251 .42532 .85543 .42939 .85995 .40159 .85706 .39749 Mtetra
.985 .76 .516 r
.85706 .39749 .85995 .40159 .86399 .3702 .86113 .36606 Mtetra
.943 .627 .409 r
.23296 .53466 .23675 .53801 .23975 .56723 .23593 .5639 Mtetra
.942 .619 .394 r
.23593 .5639 .23975 .56723 .24307 .59401 .23922 .59071 Mtetra
.935 .58 .322 r
.23922 .59071 .24307 .59401 .24713 .61288 .24327 .60959 Mtetra
.925 .547 .265 r
.24327 .60959 .24713 .61288 .25154 .62846 .24765 .62518 Mtetra
.875 .436 .088 r
.24765 .62518 .25154 .62846 .25641 .63883 .25252 .63556 Mtetra
.621 .097 0 r
.25252 .63556 .25641 .63883 .2617 .64449 .25781 .64122 Mtetra
0 .225 .692 r
.25781 .64122 .2617 .64449 .26718 .64814 .26329 .64487 Mtetra
.34 .64 .964 r
.26329 .64487 .26718 .64814 .27289 .64894 .269 .64566 Mtetra
.497 .712 .967 r
.269 .64566 .27289 .64894 .2787 .64868 .27482 .6454 Mtetra
.573 .74 .955 r
.27482 .6454 .2787 .64868 .28457 .64776 .2807 .64447 Mtetra
.632 .758 .938 r
.2807 .64447 .28457 .64776 .29051 .64617 .28664 .64287 Mtetra
.639 .76 .936 r
.28664 .64287 .29051 .64617 .29646 .64448 .2926 .64117 Mtetra
.648 .762 .933 r
.2926 .64117 .29646 .64448 .30244 .64267 .29859 .63936 Mtetra
.652 .763 .931 r
.29859 .63936 .30244 .64267 .30843 .6408 .30459 .63748 Mtetra
.653 .764 .931 r
.30459 .63748 .30843 .6408 .31444 .63891 .31061 .63558 Mtetra
.31061 .63558 .31444 .63891 .32046 .63702 .31663 .63369 Mtetra
.653 .764 .93 r
.31663 .63369 .32046 .63702 .32649 .63512 .32268 .63178 Mtetra
.32268 .63178 .32649 .63512 .33254 .63322 .32873 .62986 Mtetra
.652 .763 .931 r
.32873 .62986 .33254 .63322 .3386 .63132 .3348 .62797 Mtetra
.653 .763 .931 r
.3348 .62797 .3386 .63132 .34467 .62942 .34088 .62606 Mtetra
.653 .764 .931 r
.34088 .62606 .34467 .62942 .35076 .62751 .34698 .62414 Mtetra
.651 .763 .931 r
.34698 .62414 .35076 .62751 .35686 .62562 .35309 .62223 Mtetra
.652 .763 .931 r
.35309 .62223 .35686 .62562 .36298 .62371 .35921 .62032 Mtetra
.35921 .62032 .36298 .62371 .36911 .6218 .36535 .6184 Mtetra
.651 .763 .931 r
.36535 .6184 .36911 .6218 .37525 .6199 .3715 .61649 Mtetra
.3715 .61649 .37525 .6199 .3814 .61799 .37766 .61458 Mtetra
.37766 .61458 .3814 .61799 .38757 .61608 .38384 .61265 Mtetra
.651 .763 .932 r
.38384 .61265 .38757 .61608 .39375 .61417 .39003 .61074 Mtetra
.65 .763 .932 r
.39003 .61074 .39375 .61417 .39995 .61226 .39624 .60882 Mtetra
.651 .763 .931 r
.39624 .60882 .39995 .61226 .40616 .61034 .40246 .6069 Mtetra
.65 .763 .932 r
.40246 .6069 .40616 .61034 .41239 .60843 .40869 .60497 Mtetra
.649 .763 .932 r
.40869 .60497 .41239 .60843 .41863 .60652 .41494 .60306 Mtetra
.65 .763 .932 r
.41494 .60306 .41863 .60652 .42488 .60459 .42121 .60112 Mtetra
.42121 .60112 .42488 .60459 .43115 .60267 .42748 .59919 Mtetra
.649 .762 .932 r
.42748 .59919 .43115 .60267 .43743 .60076 .43377 .59727 Mtetra
.649 .763 .932 r
.43377 .59727 .43743 .60076 .44373 .59883 .44008 .59534 Mtetra
.44008 .59534 .44373 .59883 .45004 .5969 .4464 .5934 Mtetra
.648 .762 .932 r
.4464 .5934 .45004 .5969 .45636 .59499 .45273 .59148 Mtetra
.45273 .59148 .45636 .59499 .4627 .59306 .45908 .58954 Mtetra
.649 .762 .932 r
.45908 .58954 .4627 .59306 .46906 .59112 .46545 .5876 Mtetra
.647 .762 .933 r
.46545 .5876 .46906 .59112 .47543 .5892 .47183 .58567 Mtetra
.648 .762 .933 r
.47183 .58567 .47543 .5892 .48181 .58727 .47822 .58373 Mtetra
.648 .762 .932 r
.47822 .58373 .48181 .58727 .48821 .58533 .48463 .58178 Mtetra
.647 .762 .933 r
.48463 .58178 .48821 .58533 .49462 .5834 .49105 .57984 Mtetra
.49105 .57984 .49462 .5834 .50105 .58147 .49749 .5779 Mtetra
.648 .762 .933 r
.49749 .5779 .50105 .58147 .50749 .57952 .50394 .57594 Mtetra
.647 .762 .933 r
.50394 .57594 .50749 .57952 .51395 .57758 .51041 .574 Mtetra
.646 .762 .933 r
.51041 .574 .51395 .57758 .52043 .57565 .5169 .57206 Mtetra
.647 .762 .933 r
.5169 .57206 .52043 .57565 .52692 .5737 .5234 .5701 Mtetra
.646 .762 .933 r
.5234 .5701 .52692 .5737 .53342 .57175 .52991 .56814 Mtetra
.645 .761 .933 r
.52991 .56814 .53342 .57175 .53994 .56981 .53644 .5662 Mtetra
.646 .762 .933 r
.53644 .5662 .53994 .56981 .54648 .56786 .54299 .56423 Mtetra
.54299 .56423 .54648 .56786 .55303 .56591 .54955 .56227 Mtetra
.645 .761 .933 r
.54955 .56227 .55303 .56591 .55959 .56396 .55612 .56032 Mtetra
.646 .761 .933 r
.55612 .56032 .55959 .56396 .56618 .562 .56272 .55835 Mtetra
.56272 .55835 .56618 .562 .57278 .56004 .56933 .55638 Mtetra
.644 .761 .934 r
.56933 .55638 .57278 .56004 .57939 .55809 .57595 .55442 Mtetra
.645 .761 .933 r
.57595 .55442 .57939 .55809 .58602 .55613 .58259 .55245 Mtetra
.58259 .55245 .58602 .55613 .59267 .55416 .58925 .55047 Mtetra
.644 .761 .934 r
.58925 .55047 .59267 .55416 .59933 .55221 .59592 .54851 Mtetra
.59592 .54851 .59933 .55221 .60601 .55025 .60261 .54654 Mtetra
.645 .761 .934 r
.60261 .54654 .60601 .55025 .6127 .54827 .60931 .54456 Mtetra
.643 .761 .934 r
.60931 .54456 .6127 .54827 .61941 .54631 .61603 .54259 Mtetra
.61603 .54259 .61941 .54631 .62614 .54435 .62277 .54061 Mtetra
.62277 .54061 .62614 .54435 .63288 .54237 .62953 .53863 Mtetra
.62953 .53863 .63288 .54237 .63964 .5404 .6363 .53665 Mtetra
.643 .76 .934 r
.6363 .53665 .63964 .5404 .64642 .53842 .64309 .53467 Mtetra
.64309 .53467 .64642 .53842 .65321 .53645 .64989 .53268 Mtetra
.642 .76 .934 r
.64989 .53268 .65321 .53645 .66002 .53447 .65671 .53069 Mtetra
.65671 .53069 .66002 .53447 .66685 .53249 .66355 .5287 Mtetra
.66355 .5287 .66685 .53249 .67369 .53051 .6704 .52671 Mtetra
.6704 .52671 .67369 .53051 .68055 .52852 .67728 .52472 Mtetra
.67728 .52472 .68055 .52852 .68743 .52653 .68417 .52272 Mtetra
.641 .76 .935 r
.68417 .52272 .68743 .52653 .69433 .52455 .69107 .52072 Mtetra
.69107 .52072 .69433 .52455 .70124 .52256 .698 .51872 Mtetra
.698 .51872 .70124 .52256 .70817 .52056 .70494 .51672 Mtetra
.70494 .51672 .70817 .52056 .71512 .51857 .7119 .51472 Mtetra
.7119 .51472 .71512 .51857 .72208 .51658 .71887 .51272 Mtetra
.64 .76 .935 r
.71887 .51272 .72208 .51658 .72906 .51458 .72587 .51071 Mtetra
.64 .759 .935 r
.72587 .51071 .72906 .51458 .73606 .51258 .73288 .5087 Mtetra
.73288 .5087 .73606 .51258 .74308 .51058 .73991 .50669 Mtetra
.73991 .50669 .74308 .51058 .75012 .50858 .74696 .50468 Mtetra
.74696 .50468 .75012 .50858 .75717 .50657 .75402 .50267 Mtetra
.639 .759 .935 r
.75402 .50267 .75717 .50657 .76424 .50457 .76111 .50065 Mtetra
.76111 .50065 .76424 .50457 .77133 .50256 .76821 .49863 Mtetra
.64 .759 .935 r
.76821 .49863 .77133 .50256 .77844 .50053 .77533 .4966 Mtetra
.641 .76 .935 r
.77533 .4966 .77844 .50053 .78556 .49849 .78246 .49454 Mtetra
.645 .761 .933 r
.78246 .49454 .78556 .49849 .7927 .49637 .78961 .49241 Mtetra
.649 .763 .932 r
.78961 .49241 .7927 .49637 .79985 .49419 .79677 .49022 Mtetra
.672 .772 .925 r
.79677 .49022 .79985 .49419 .80698 .49163 .80392 .48765 Mtetra
.697 .781 .916 r
.80392 .48765 .80698 .49163 .81409 .48862 .81105 .48464 Mtetra
.731 .793 .901 r
.81105 .48464 .81409 .48862 .82116 .48492 .81812 .48092 Mtetra
.811 .814 .853 r
.81812 .48092 .82116 .48492 .82804 .47915 .82503 .47514 Mtetra
.854 .82 .815 r
.82503 .47514 .82804 .47915 .83478 .47179 .83178 .46776 Mtetra
.917 .818 .734 r
.83178 .46776 .83478 .47179 .84114 .46057 .83816 .45653 Mtetra
.954 .804 .656 r
.83816 .45653 .84114 .46057 .84701 .44453 .84405 .44046 Mtetra
.967 .793 .616 r
.84405 .44046 .84701 .44453 .85251 .42532 .84957 .42122 Mtetra
.982 .769 .54 r
.84957 .42122 .85251 .42532 .85706 .39749 .85415 .39335 Mtetra
.985 .76 .516 r
.85415 .39335 .85706 .39749 .86113 .36606 .85826 .36189 Mtetra
.943 .627 .41 r
.22916 .5313 .23296 .53466 .23593 .5639 .2321 .56057 Mtetra
.942 .619 .394 r
.2321 .56057 .23593 .5639 .23922 .59071 .23536 .5874 Mtetra
.935 .58 .322 r
.23536 .5874 .23922 .59071 .24327 .60959 .23938 .60629 Mtetra
.925 .547 .265 r
.23938 .60629 .24327 .60959 .24765 .62518 .24376 .62189 Mtetra
.875 .436 .089 r
.24376 .62189 .24765 .62518 .25252 .63556 .24862 .63228 Mtetra
.622 .098 0 r
.24862 .63228 .25252 .63556 .25781 .64122 .2539 .63795 Mtetra
0 .224 .69 r
.2539 .63795 .25781 .64122 .26329 .64487 .25938 .64159 Mtetra
.339 .64 .964 r
.25938 .64159 .26329 .64487 .269 .64566 .2651 .64238 Mtetra
.497 .712 .967 r
.2651 .64238 .269 .64566 .27482 .6454 .27092 .64211 Mtetra
.573 .74 .955 r
.27092 .64211 .27482 .6454 .2807 .64447 .27681 .64117 Mtetra
.632 .759 .939 r
.27681 .64117 .2807 .64447 .28664 .64287 .28276 .63957 Mtetra
.639 .761 .936 r
.28276 .63957 .28664 .64287 .2926 .64117 .28873 .63786 Mtetra
.648 .763 .933 r
.28873 .63786 .2926 .64117 .29859 .63936 .29472 .63604 Mtetra
.652 .764 .931 r
.29472 .63604 .29859 .63936 .30459 .63748 .30073 .63415 Mtetra
.653 .764 .931 r
.30073 .63415 .30459 .63748 .31061 .63558 .30676 .63225 Mtetra
.30676 .63225 .31061 .63558 .31663 .63369 .31279 .63035 Mtetra
.31279 .63035 .31663 .63369 .32268 .63178 .31884 .62843 Mtetra
.31884 .62843 .32268 .63178 .32873 .62986 .32491 .62651 Mtetra
.652 .764 .931 r
.32491 .62651 .32873 .62986 .3348 .62797 .33099 .6246 Mtetra
.33099 .6246 .3348 .62797 .34088 .62606 .33708 .62269 Mtetra
.653 .764 .931 r
.33708 .62269 .34088 .62606 .34698 .62414 .34318 .62076 Mtetra
.651 .764 .932 r
.34318 .62076 .34698 .62414 .35309 .62223 .3493 .61885 Mtetra
.652 .764 .931 r
.3493 .61885 .35309 .62223 .35921 .62032 .35543 .61693 Mtetra
.35543 .61693 .35921 .62032 .36535 .6184 .36158 .615 Mtetra
.651 .764 .932 r
.36158 .615 .36535 .6184 .3715 .61649 .36774 .61308 Mtetra
.36774 .61308 .3715 .61649 .37766 .61458 .37391 .61116 Mtetra
.37391 .61116 .37766 .61458 .38384 .61265 .3801 .60923 Mtetra
.65 .764 .932 r
.3801 .60923 .38384 .61265 .39003 .61074 .3863 .6073 Mtetra
.65 .763 .932 r
.3863 .6073 .39003 .61074 .39624 .60882 .39251 .60538 Mtetra
.651 .764 .932 r
.39251 .60538 .39624 .60882 .40246 .6069 .39874 .60345 Mtetra
.65 .763 .932 r
.39874 .60345 .40246 .6069 .40869 .60497 .40499 .60151 Mtetra
.649 .763 .932 r
.40499 .60151 .40869 .60497 .41494 .60306 .41124 .59959 Mtetra
.65 .763 .932 r
.41124 .59959 .41494 .60306 .42121 .60112 .41751 .59765 Mtetra
.41751 .59765 .42121 .60112 .42748 .59919 .4238 .59571 Mtetra
.649 .763 .933 r
.4238 .59571 .42748 .59919 .43377 .59727 .4301 .59378 Mtetra
.649 .763 .932 r
.4301 .59378 .43377 .59727 .44008 .59534 .43642 .59184 Mtetra
.43642 .59184 .44008 .59534 .4464 .5934 .44275 .58989 Mtetra
.648 .763 .933 r
.44275 .58989 .4464 .5934 .45273 .59148 .44909 .58796 Mtetra
.44909 .58796 .45273 .59148 .45908 .58954 .45545 .58602 Mtetra
.649 .763 .933 r
.45545 .58602 .45908 .58954 .46545 .5876 .46182 .58406 Mtetra
.647 .763 .933 r
.46182 .58406 .46545 .5876 .47183 .58567 .46821 .58213 Mtetra
.648 .763 .933 r
.46821 .58213 .47183 .58567 .47822 .58373 .47461 .58018 Mtetra
.47461 .58018 .47822 .58373 .48463 .58178 .48103 .57822 Mtetra
.647 .762 .933 r
.48103 .57822 .48463 .58178 .49105 .57984 .48746 .57628 Mtetra
.48746 .57628 .49105 .57984 .49749 .5779 .49391 .57433 Mtetra
.648 .763 .933 r
.49391 .57433 .49749 .5779 .50394 .57594 .50038 .57236 Mtetra
.647 .762 .933 r
.50038 .57236 .50394 .57594 .51041 .574 .50686 .57041 Mtetra
.646 .762 .933 r
.50686 .57041 .51041 .574 .5169 .57206 .51335 .56846 Mtetra
.647 .762 .933 r
.51335 .56846 .5169 .57206 .5234 .5701 .51986 .56649 Mtetra
.646 .762 .933 r
.51986 .56649 .5234 .5701 .52991 .56814 .52638 .56453 Mtetra
.645 .762 .934 r
.52638 .56453 .52991 .56814 .53644 .5662 .53292 .56257 Mtetra
.646 .762 .933 r
.53292 .56257 .53644 .5662 .54299 .56423 .53948 .5606 Mtetra
.646 .762 .934 r
.53948 .5606 .54299 .56423 .54955 .56227 .54605 .55863 Mtetra
.645 .762 .934 r
.54605 .55863 .54955 .56227 .55612 .56032 .55264 .55667 Mtetra
.55264 .55667 .55612 .56032 .56272 .55835 .55924 .55469 Mtetra
.55924 .55469 .56272 .55835 .56933 .55638 .56586 .55271 Mtetra
.644 .762 .934 r
.56586 .55271 .56933 .55638 .57595 .55442 .5725 .55075 Mtetra
.645 .762 .934 r
.5725 .55075 .57595 .55442 .58259 .55245 .57915 .54877 Mtetra
.57915 .54877 .58259 .55245 .58925 .55047 .58581 .54678 Mtetra
.643 .761 .934 r
.58581 .54678 .58925 .55047 .59592 .54851 .5925 .54481 Mtetra
.644 .761 .934 r
.5925 .54481 .59592 .54851 .60261 .54654 .5992 .54283 Mtetra
.645 .762 .934 r
.5992 .54283 .60261 .54654 .60931 .54456 .60591 .54083 Mtetra
.643 .761 .934 r
.60591 .54083 .60931 .54456 .61603 .54259 .61264 .53886 Mtetra
.61264 .53886 .61603 .54259 .62277 .54061 .61939 .53688 Mtetra
.61939 .53688 .62277 .54061 .62953 .53863 .62616 .53489 Mtetra
.62616 .53489 .62953 .53863 .6363 .53665 .63294 .53289 Mtetra
.63294 .53289 .6363 .53665 .64309 .53467 .63974 .5309 Mtetra
.643 .761 .935 r
.63974 .5309 .64309 .53467 .64989 .53268 .64656 .5289 Mtetra
.642 .761 .935 r
.64656 .5289 .64989 .53268 .65671 .53069 .65339 .52691 Mtetra
.65339 .52691 .65671 .53069 .66355 .5287 .66024 .52491 Mtetra
.66024 .52491 .66355 .5287 .6704 .52671 .6671 .52291 Mtetra
.6671 .52291 .6704 .52671 .67728 .52472 .67399 .5209 Mtetra
.67399 .5209 .67728 .52472 .68417 .52272 .68089 .5189 Mtetra
.641 .76 .935 r
.68089 .5189 .68417 .52272 .69107 .52072 .68781 .51689 Mtetra
.68781 .51689 .69107 .52072 .698 .51872 .69474 .51488 Mtetra
.69474 .51488 .698 .51872 .70494 .51672 .70169 .51287 Mtetra
.70169 .51287 .70494 .51672 .7119 .51472 .70867 .51086 Mtetra
.70867 .51086 .7119 .51472 .71887 .51272 .71565 .50885 Mtetra
.64 .76 .935 r
.71565 .50885 .71887 .51272 .72587 .51071 .72266 .50683 Mtetra
.72266 .50683 .72587 .51071 .73288 .5087 .72968 .50482 Mtetra
.72968 .50482 .73288 .5087 .73991 .50669 .73672 .5028 Mtetra
.73672 .5028 .73991 .50669 .74696 .50468 .74378 .50077 Mtetra
.639 .76 .935 r
.74378 .50077 .74696 .50468 .75402 .50267 .75086 .49875 Mtetra
.639 .76 .936 r
.75086 .49875 .75402 .50267 .76111 .50065 .75796 .49673 Mtetra
.639 .76 .935 r
.75796 .49673 .76111 .50065 .76821 .49863 .76507 .49469 Mtetra
.64 .76 .935 r
.76507 .49469 .76821 .49863 .77533 .4966 .7722 .49265 Mtetra
.641 .76 .935 r
.7722 .49265 .77533 .4966 .78246 .49454 .77935 .49059 Mtetra
.645 .762 .934 r
.77935 .49059 .78246 .49454 .78961 .49241 .78651 .48845 Mtetra
.649 .763 .933 r
.78651 .48845 .78961 .49241 .79677 .49022 .79369 .48625 Mtetra
.672 .773 .926 r
.79369 .48625 .79677 .49022 .80392 .48765 .80085 .48367 Mtetra
.697 .782 .917 r
.80085 .48367 .80392 .48765 .81105 .48464 .80799 .48064 Mtetra
.732 .794 .902 r
.80799 .48064 .81105 .48464 .81812 .48092 .81508 .47691 Mtetra
.811 .815 .853 r
.81508 .47691 .81812 .48092 .82503 .47514 .822 .47112 Mtetra
.854 .821 .815 r
.822 .47112 .82503 .47514 .83178 .46776 .82877 .46373 Mtetra
.917 .819 .734 r
.82877 .46373 .83178 .46776 .83816 .45653 .83517 .45247 Mtetra
.954 .804 .656 r
.83517 .45247 .83816 .45653 .84405 .44046 .84108 .43638 Mtetra
.967 .793 .616 r
.84108 .43638 .84405 .44046 .84957 .42122 .84663 .41712 Mtetra
.982 .769 .54 r
.84663 .41712 .84957 .42122 .85415 .39335 .85124 .38921 Mtetra
.985 .76 .516 r
.85124 .38921 .85415 .39335 .85826 .36189 .85538 .35771 Mtetra
.943 .627 .41 r
.22534 .52794 .22916 .5313 .2321 .56057 .22825 .55723 Mtetra
.942 .619 .394 r
.22825 .55723 .2321 .56057 .23536 .5874 .23148 .58408 Mtetra
.935 .58 .322 r
.23148 .58408 .23536 .5874 .23938 .60629 .23548 .60299 Mtetra
.925 .547 .265 r
.23548 .60299 .23938 .60629 .24376 .62189 .23984 .61861 Mtetra
.875 .436 .089 r
.23984 .61861 .24376 .62189 .24862 .63228 .24469 .629 Mtetra
.623 .099 0 r
.24469 .629 .24862 .63228 .2539 .63795 .24998 .63467 Mtetra
0 .223 .689 r
.24998 .63467 .2539 .63795 .25938 .64159 .25545 .63831 Mtetra
.338 .641 .964 r
.25545 .63831 .25938 .64159 .2651 .64238 .26118 .63909 Mtetra
.496 .713 .968 r
.26118 .63909 .2651 .64238 .27092 .64211 .26701 .63882 Mtetra
.572 .741 .956 r
.26701 .63882 .27092 .64211 .27681 .64117 .2729 .63787 Mtetra
.631 .759 .939 r
.2729 .63787 .27681 .64117 .28276 .63957 .27886 .63626 Mtetra
.639 .761 .937 r
.27886 .63626 .28276 .63957 .28873 .63786 .28484 .63455 Mtetra
.648 .763 .933 r
.28484 .63455 .28873 .63786 .29472 .63604 .29084 .63272 Mtetra
.652 .765 .932 r
.29084 .63272 .29472 .63604 .30073 .63415 .29686 .63083 Mtetra
.653 .765 .931 r
.29686 .63083 .30073 .63415 .30676 .63225 .30289 .62892 Mtetra
.30289 .62892 .30676 .63225 .31279 .63035 .30894 .62701 Mtetra
.30894 .62701 .31279 .63035 .31884 .62843 .315 .62508 Mtetra
.315 .62508 .31884 .62843 .32491 .62651 .32107 .62315 Mtetra
.652 .765 .932 r
.32107 .62315 .32491 .62651 .33099 .6246 .32715 .62124 Mtetra
.32715 .62124 .33099 .6246 .33708 .62269 .33325 .61931 Mtetra
.653 .765 .931 r
.33325 .61931 .33708 .62269 .34318 .62076 .33937 .61738 Mtetra
.651 .764 .932 r
.33937 .61738 .34318 .62076 .3493 .61885 .34549 .61546 Mtetra
.652 .764 .932 r
.34549 .61546 .3493 .61885 .35543 .61693 .35163 .61353 Mtetra
.652 .765 .932 r
.35163 .61353 .35543 .61693 .36158 .615 .35779 .61159 Mtetra
.651 .764 .932 r
.35779 .61159 .36158 .615 .36774 .61308 .36396 .60967 Mtetra
.36396 .60967 .36774 .61308 .37391 .61116 .37014 .60774 Mtetra
.37014 .60774 .37391 .61116 .3801 .60923 .37634 .6058 Mtetra
.65 .764 .932 r
.37634 .6058 .3801 .60923 .3863 .6073 .38255 .60387 Mtetra
.65 .764 .933 r
.38255 .60387 .3863 .6073 .39251 .60538 .38877 .60194 Mtetra
.651 .764 .932 r
.38877 .60194 .39251 .60538 .39874 .60345 .39501 .59999 Mtetra
.65 .764 .932 r
.39501 .59999 .39874 .60345 .40499 .60151 .40126 .59805 Mtetra
.649 .764 .933 r
.40126 .59805 .40499 .60151 .41124 .59959 .40753 .59612 Mtetra
.65 .764 .932 r
.40753 .59612 .41124 .59959 .41751 .59765 .41381 .59417 Mtetra
.65 .764 .933 r
.41381 .59417 .41751 .59765 .4238 .59571 .4201 .59222 Mtetra
.649 .764 .933 r
.4201 .59222 .4238 .59571 .4301 .59378 .42641 .59029 Mtetra
.42641 .59029 .4301 .59378 .43642 .59184 .43274 .58834 Mtetra
.43274 .58834 .43642 .59184 .44275 .58989 .43908 .58638 Mtetra
.648 .763 .933 r
.43908 .58638 .44275 .58989 .44909 .58796 .44543 .58444 Mtetra
.44543 .58444 .44909 .58796 .45545 .58602 .4518 .58249 Mtetra
.649 .764 .933 r
.4518 .58249 .45545 .58602 .46182 .58406 .45818 .58053 Mtetra
.647 .763 .933 r
.45818 .58053 .46182 .58406 .46821 .58213 .46458 .57858 Mtetra
.648 .763 .933 r
.46458 .57858 .46821 .58213 .47461 .58018 .47099 .57663 Mtetra
.47099 .57663 .47461 .58018 .48103 .57822 .47742 .57466 Mtetra
.647 .763 .934 r
.47742 .57466 .48103 .57822 .48746 .57628 .48386 .5727 Mtetra
.48386 .5727 .48746 .57628 .49391 .57433 .49032 .57075 Mtetra
.648 .763 .933 r
.49032 .57075 .49391 .57433 .50038 .57236 .49679 .56877 Mtetra
.646 .763 .934 r
.49679 .56877 .50038 .57236 .50686 .57041 .50328 .56681 Mtetra
.50328 .56681 .50686 .57041 .51335 .56846 .50979 .56485 Mtetra
.647 .763 .934 r
.50979 .56485 .51335 .56846 .51986 .56649 .51631 .56288 Mtetra
.646 .763 .934 r
.51631 .56288 .51986 .56649 .52638 .56453 .52284 .5609 Mtetra
.645 .762 .934 r
.52284 .5609 .52638 .56453 .53292 .56257 .52939 .55894 Mtetra
.646 .763 .934 r
.52939 .55894 .53292 .56257 .53948 .5606 .53596 .55696 Mtetra
.53596 .55696 .53948 .5606 .54605 .55863 .54254 .55498 Mtetra
.645 .762 .934 r
.54254 .55498 .54605 .55863 .55264 .55667 .54914 .55301 Mtetra
.645 .763 .934 r
.54914 .55301 .55264 .55667 .55924 .55469 .55575 .55103 Mtetra
.645 .762 .934 r
.55575 .55103 .55924 .55469 .56586 .55271 .56238 .54904 Mtetra
.644 .762 .934 r
.56238 .54904 .56586 .55271 .5725 .55075 .56903 .54706 Mtetra
.645 .762 .934 r
.56903 .54706 .5725 .55075 .57915 .54877 .57569 .54508 Mtetra
.57569 .54508 .57915 .54877 .58581 .54678 .58237 .54308 Mtetra
.643 .762 .935 r
.58237 .54308 .58581 .54678 .5925 .54481 .58906 .5411 Mtetra
.644 .762 .935 r
.58906 .5411 .5925 .54481 .5992 .54283 .59577 .53911 Mtetra
.644 .762 .934 r
.59577 .53911 .5992 .54283 .60591 .54083 .6025 .53711 Mtetra
.643 .762 .935 r
.6025 .53711 .60591 .54083 .61264 .53886 .60924 .53512 Mtetra
.60924 .53512 .61264 .53886 .61939 .53688 .616 .53313 Mtetra
.616 .53313 .61939 .53688 .62616 .53489 .62278 .53113 Mtetra
.62278 .53113 .62616 .53489 .63294 .53289 .62957 .52913 Mtetra
.62957 .52913 .63294 .53289 .63974 .5309 .63638 .52713 Mtetra
.642 .761 .935 r
.63638 .52713 .63974 .5309 .64656 .5289 .64321 .52512 Mtetra
.64321 .52512 .64656 .5289 .65339 .52691 .65005 .52312 Mtetra
.65005 .52312 .65339 .52691 .66024 .52491 .65691 .52111 Mtetra
.65691 .52111 .66024 .52491 .6671 .52291 .66379 .5191 Mtetra
.66379 .5191 .6671 .52291 .67399 .5209 .67068 .51709 Mtetra
.641 .761 .935 r
.67068 .51709 .67399 .5209 .68089 .5189 .67759 .51507 Mtetra
.67759 .51507 .68089 .5189 .68781 .51689 .68452 .51306 Mtetra
.68452 .51306 .68781 .51689 .69474 .51488 .69147 .51104 Mtetra
.69147 .51104 .69474 .51488 .70169 .51287 .69844 .50902 Mtetra
.641 .761 .936 r
.69844 .50902 .70169 .51287 .70867 .51086 .70542 .507 Mtetra
.64 .761 .936 r
.70542 .507 .70867 .51086 .71565 .50885 .71242 .50497 Mtetra
.71242 .50497 .71565 .50885 .72266 .50683 .71944 .50295 Mtetra
.71944 .50295 .72266 .50683 .72968 .50482 .72647 .50092 Mtetra
.64 .76 .936 r
.72647 .50092 .72968 .50482 .73672 .5028 .73353 .49889 Mtetra
.73353 .49889 .73672 .5028 .74378 .50077 .7406 .49686 Mtetra
.639 .76 .936 r
.7406 .49686 .74378 .50077 .75086 .49875 .74769 .49483 Mtetra
.74769 .49483 .75086 .49875 .75796 .49673 .7548 .4928 Mtetra
.7548 .4928 .75796 .49673 .76507 .49469 .76192 .49075 Mtetra
.64 .76 .936 r
.76192 .49075 .76507 .49469 .7722 .49265 .76907 .4887 Mtetra
.641 .761 .936 r
.76907 .4887 .7722 .49265 .77935 .49059 .77623 .48663 Mtetra
.645 .763 .934 r
.77623 .48663 .77935 .49059 .78651 .48845 .7834 .48448 Mtetra
.649 .764 .933 r
.7834 .48448 .78651 .48845 .79369 .48625 .79059 .48227 Mtetra
.672 .773 .926 r
.79059 .48227 .79369 .48625 .80085 .48367 .79776 .47968 Mtetra
.697 .782 .917 r
.79776 .47968 .80085 .48367 .80799 .48064 .80491 .47664 Mtetra
.732 .794 .902 r
.80491 .47664 .80799 .48064 .81508 .47691 .81202 .4729 Mtetra
.812 .815 .853 r
.81202 .4729 .81508 .47691 .822 .47112 .81895 .46709 Mtetra
.854 .821 .815 r
.81895 .46709 .822 .47112 .82877 .46373 .82574 .45968 Mtetra
.917 .819 .734 r
.82574 .45968 .82877 .46373 .83517 .45247 .83216 .44841 Mtetra
.954 .804 .656 r
.83216 .44841 .83517 .45247 .84108 .43638 .83809 .43229 Mtetra
.967 .794 .616 r
.83809 .43229 .84108 .43638 .84663 .41712 .84367 .413 Mtetra
.982 .769 .54 r
.84367 .413 .84663 .41712 .85124 .38921 .84831 .38506 Mtetra
.985 .76 .516 r
.84831 .38506 .85124 .38921 .85538 .35771 .85248 .35352 Mtetra
.943 .627 .41 r
.22151 .52456 .22534 .52794 .22825 .55723 .22438 .55387 Mtetra
.942 .619 .394 r
.22438 .55387 .22825 .55723 .23148 .58408 .22758 .58074 Mtetra
.935 .58 .322 r
.22758 .58074 .23148 .58408 .23548 .60299 .23157 .59967 Mtetra
.925 .547 .265 r
.23157 .59967 .23548 .60299 .23984 .61861 .23591 .61529 Mtetra
.875 .436 .088 r
.23591 .61529 .23984 .61861 .24469 .629 .24076 .62569 Mtetra
.622 .098 0 r
.24076 .62569 .24469 .629 .24998 .63467 .24604 .63136 Mtetra
0 .225 .691 r
.24604 .63136 .24998 .63467 .25545 .63831 .25151 .635 Mtetra
.34 .64 .964 r
.25151 .635 .25545 .63831 .26118 .63909 .25725 .63578 Mtetra
.497 .712 .967 r
.25725 .63578 .26118 .63909 .26701 .63882 .26308 .6355 Mtetra
.573 .74 .955 r
.26308 .6355 .26701 .63882 .2729 .63787 .26898 .63455 Mtetra
.632 .758 .939 r
.26898 .63455 .2729 .63787 .27886 .63626 .27495 .63293 Mtetra
.639 .76 .936 r
.27495 .63293 .27886 .63626 .28484 .63455 .28093 .63121 Mtetra
.648 .762 .933 r
.28093 .63121 .28484 .63455 .29084 .63272 .28694 .62937 Mtetra
.652 .764 .931 r
.28694 .62937 .29084 .63272 .29686 .63083 .29297 .62747 Mtetra
.653 .764 .931 r
.29297 .62747 .29686 .63083 .30289 .62892 .29901 .62555 Mtetra
.29901 .62555 .30289 .62892 .30894 .62701 .30506 .62363 Mtetra
.30506 .62363 .30894 .62701 .315 .62508 .31113 .6217 Mtetra
.31113 .6217 .315 .62508 .32107 .62315 .31721 .61976 Mtetra
.652 .764 .931 r
.31721 .61976 .32107 .62315 .32715 .62124 .32331 .61784 Mtetra
.32331 .61784 .32715 .62124 .33325 .61931 .32942 .61591 Mtetra
.653 .764 .931 r
.32942 .61591 .33325 .61931 .33937 .61738 .33554 .61396 Mtetra
.651 .763 .931 r
.33554 .61396 .33937 .61738 .34549 .61546 .34167 .61204 Mtetra
.652 .763 .931 r
.34167 .61204 .34549 .61546 .35163 .61353 .34782 .6101 Mtetra
.652 .764 .931 r
.34782 .6101 .35163 .61353 .35779 .61159 .35399 .60816 Mtetra
.651 .763 .931 r
.35399 .60816 .35779 .61159 .36396 .60967 .36016 .60622 Mtetra
.651 .763 .932 r
.36016 .60622 .36396 .60967 .37014 .60774 .36635 .60429 Mtetra
.651 .763 .931 r
.36635 .60429 .37014 .60774 .37634 .6058 .37256 .60234 Mtetra
.65 .763 .932 r
.37256 .60234 .37634 .6058 .38255 .60387 .37878 .6004 Mtetra
.37878 .6004 .38255 .60387 .38877 .60194 .38501 .59846 Mtetra
.651 .763 .932 r
.38501 .59846 .38877 .60194 .39501 .59999 .39126 .59651 Mtetra
.65 .763 .932 r
.39126 .59651 .39501 .59999 .40126 .59805 .39752 .59456 Mtetra
.649 .763 .932 r
.39752 .59456 .40126 .59805 .40753 .59612 .40379 .59262 Mtetra
.65 .763 .932 r
.40379 .59262 .40753 .59612 .41381 .59417 .41009 .59066 Mtetra
.41009 .59066 .41381 .59417 .4201 .59222 .41639 .58871 Mtetra
.649 .763 .932 r
.41639 .58871 .4201 .59222 .42641 .59029 .42271 .58676 Mtetra
.42271 .58676 .42641 .59029 .43274 .58834 .42904 .5848 Mtetra
.42904 .5848 .43274 .58834 .43908 .58638 .43539 .58284 Mtetra
.648 .762 .933 r
.43539 .58284 .43908 .58638 .44543 .58444 .44175 .58089 Mtetra
.648 .763 .932 r
.44175 .58089 .44543 .58444 .4518 .58249 .44813 .57893 Mtetra
.649 .763 .932 r
.44813 .57893 .4518 .58249 .45818 .58053 .45452 .57696 Mtetra
.647 .762 .933 r
.45452 .57696 .45818 .58053 .46458 .57858 .46093 .575 Mtetra
.648 .762 .933 r
.46093 .575 .46458 .57858 .47099 .57663 .46735 .57304 Mtetra
.648 .762 .932 r
.46735 .57304 .47099 .57663 .47742 .57466 .47379 .57106 Mtetra
.647 .762 .933 r
.47379 .57106 .47742 .57466 .48386 .5727 .48025 .5691 Mtetra
.48025 .5691 .48386 .5727 .49032 .57075 .48671 .56714 Mtetra
.648 .762 .933 r
.48671 .56714 .49032 .57075 .49679 .56877 .4932 .56516 Mtetra
.647 .762 .933 r
.4932 .56516 .49679 .56877 .50328 .56681 .4997 .56318 Mtetra
.646 .762 .933 r
.4997 .56318 .50328 .56681 .50979 .56485 .50621 .56122 Mtetra
.647 .762 .933 r
.50621 .56122 .50979 .56485 .51631 .56288 .51274 .55923 Mtetra
.646 .762 .933 r
.51274 .55923 .51631 .56288 .52284 .5609 .51928 .55725 Mtetra
.645 .762 .933 r
.51928 .55725 .52284 .5609 .52939 .55894 .52584 .55528 Mtetra
.646 .762 .933 r
.52584 .55528 .52939 .55894 .53596 .55696 .53242 .55329 Mtetra
.53242 .55329 .53596 .55696 .54254 .55498 .53901 .5513 Mtetra
.645 .761 .934 r
.53901 .5513 .54254 .55498 .54914 .55301 .54562 .54932 Mtetra
.646 .762 .933 r
.54562 .54932 .54914 .55301 .55575 .55103 .55225 .54733 Mtetra
.645 .762 .933 r
.55225 .54733 .55575 .55103 .56238 .54904 .55888 .54533 Mtetra
.644 .761 .934 r
.55888 .54533 .56238 .54904 .56903 .54706 .56554 .54335 Mtetra
.645 .761 .934 r
.56554 .54335 .56903 .54706 .57569 .54508 .57221 .54135 Mtetra
.57221 .54135 .57569 .54508 .58237 .54308 .5789 .53935 Mtetra
.644 .761 .934 r
.5789 .53935 .58237 .54308 .58906 .5411 .58561 .53736 Mtetra
.58561 .53736 .58906 .5411 .59577 .53911 .59233 .53536 Mtetra
.645 .761 .934 r
.59233 .53536 .59577 .53911 .6025 .53711 .59906 .53335 Mtetra
.643 .761 .934 r
.59906 .53335 .6025 .53711 .60924 .53512 .60582 .53135 Mtetra
.60582 .53135 .60924 .53512 .616 .53313 .61259 .52935 Mtetra
.61259 .52935 .616 .53313 .62278 .53113 .61938 .52734 Mtetra
.61938 .52734 .62278 .53113 .62957 .52913 .62618 .52533 Mtetra
.62618 .52533 .62957 .52913 .63638 .52713 .633 .52332 Mtetra
.633 .52332 .63638 .52713 .64321 .52512 .63984 .52131 Mtetra
.642 .761 .934 r
.63984 .52131 .64321 .52512 .65005 .52312 .64669 .51929 Mtetra
.642 .76 .934 r
.64669 .51929 .65005 .52312 .65691 .52111 .65357 .51727 Mtetra
.65357 .51727 .65691 .52111 .66379 .5191 .66046 .51525 Mtetra
.642 .76 .935 r
.66046 .51525 .66379 .5191 .67068 .51709 .66736 .51323 Mtetra
.66736 .51323 .67068 .51709 .67759 .51507 .67429 .51121 Mtetra
.641 .76 .935 r
.67429 .51121 .67759 .51507 .68452 .51306 .68123 .50918 Mtetra
.68123 .50918 .68452 .51306 .69147 .51104 .68819 .50716 Mtetra
.68819 .50716 .69147 .51104 .69844 .50902 .69516 .50513 Mtetra
.69516 .50513 .69844 .50902 .70542 .507 .70216 .5031 Mtetra
.70216 .5031 .70542 .507 .71242 .50497 .70917 .50106 Mtetra
.64 .76 .935 r
.70917 .50106 .71242 .50497 .71944 .50295 .7162 .49903 Mtetra
.7162 .49903 .71944 .50295 .72647 .50092 .72325 .49699 Mtetra
.72325 .49699 .72647 .50092 .73353 .49889 .73031 .49495 Mtetra
.64 .759 .935 r
.73031 .49495 .73353 .49889 .7406 .49686 .7374 .49291 Mtetra
.639 .759 .935 r
.7374 .49291 .7406 .49686 .74769 .49483 .7445 .49087 Mtetra
.7445 .49087 .74769 .49483 .7548 .4928 .75162 .48883 Mtetra
.75162 .48883 .7548 .4928 .76192 .49075 .75876 .48678 Mtetra
.64 .759 .935 r
.75876 .48678 .76192 .49075 .76907 .4887 .76591 .48471 Mtetra
.641 .76 .935 r
.76591 .48471 .76907 .4887 .77623 .48663 .77309 .48263 Mtetra
.645 .762 .934 r
.77309 .48263 .77623 .48663 .7834 .48448 .78027 .48047 Mtetra
.649 .763 .933 r
.78027 .48047 .7834 .48448 .79059 .48227 .78747 .47825 Mtetra
.672 .772 .926 r
.78747 .47825 .79059 .48227 .79776 .47968 .79466 .47565 Mtetra
.697 .781 .917 r
.79466 .47565 .79776 .47968 .80491 .47664 .80183 .4726 Mtetra
.731 .793 .901 r
.80183 .4726 .80491 .47664 .81202 .4729 .80895 .46885 Mtetra
.811 .814 .853 r
.80895 .46885 .81202 .4729 .81895 .46709 .81589 .46303 Mtetra
.854 .82 .815 r
.81589 .46303 .81895 .46709 .82574 .45968 .8227 .4556 Mtetra
.917 .818 .734 r
.8227 .4556 .82574 .45968 .83216 .44841 .82914 .44431 Mtetra
.954 .804 .656 r
.82914 .44431 .83216 .44841 .83809 .43229 .83509 .42817 Mtetra
.967 .793 .616 r
.83509 .42817 .83809 .43229 .84367 .413 .84069 .40885 Mtetra
.982 .769 .54 r
.84069 .40885 .84367 .413 .84831 .38506 .84536 .38087 Mtetra
.985 .76 .516 r
.84536 .38087 .84831 .38506 .85248 .35352 .84957 .3493 Mtetra
.943 .627 .41 r
.21767 .52116 .22151 .52456 .22438 .55387 .2205 .55049 Mtetra
.942 .619 .394 r
.2205 .55049 .22438 .55387 .22758 .58074 .22367 .57739 Mtetra
.935 .58 .322 r
.22367 .57739 .22758 .58074 .23157 .59967 .22763 .59633 Mtetra
.925 .547 .265 r
.22763 .59633 .23157 .59967 .23591 .61529 .23196 .61197 Mtetra
.875 .436 .089 r
.23196 .61197 .23591 .61529 .24076 .62569 .2368 .62237 Mtetra
.622 .098 0 r
.2368 .62237 .24076 .62569 .24604 .63136 .24208 .62804 Mtetra
0 .224 .691 r
.24208 .62804 .24604 .63136 .25151 .635 .24756 .63168 Mtetra
.339 .64 .964 r
.24756 .63168 .25151 .635 .25725 .63578 .25329 .63245 Mtetra
.497 .712 .967 r
.25329 .63245 .25725 .63578 .26308 .6355 .25913 .63217 Mtetra
.573 .74 .955 r
.25913 .63217 .26308 .6355 .26898 .63455 .26504 .63121 Mtetra
.632 .758 .939 r
.26504 .63121 .26898 .63455 .27495 .63293 .27101 .62958 Mtetra
.639 .761 .936 r
.27101 .62958 .27495 .63293 .28093 .63121 .27701 .62786 Mtetra
.648 .763 .933 r
.27701 .62786 .28093 .63121 .28694 .62937 .28303 .62601 Mtetra
.652 .764 .931 r
.28303 .62601 .28694 .62937 .29297 .62747 .28906 .6241 Mtetra
.653 .764 .931 r
.28906 .6241 .29297 .62747 .29901 .62555 .29511 .62218 Mtetra
.29511 .62218 .29901 .62555 .30506 .62363 .30117 .62025 Mtetra
.30117 .62025 .30506 .62363 .31113 .6217 .30725 .61831 Mtetra
.30725 .61831 .31113 .6217 .31721 .61976 .31334 .61636 Mtetra
.652 .764 .931 r
.31334 .61636 .31721 .61976 .32331 .61784 .31944 .61443 Mtetra
.31944 .61443 .32331 .61784 .32942 .61591 .32556 .61249 Mtetra
.653 .764 .931 r
.32556 .61249 .32942 .61591 .33554 .61396 .33169 .61054 Mtetra
.651 .764 .932 r
.33169 .61054 .33554 .61396 .34167 .61204 .33784 .60861 Mtetra
.652 .764 .931 r
.33784 .60861 .34167 .61204 .34782 .6101 .34399 .60666 Mtetra
.34399 .60666 .34782 .6101 .35399 .60816 .35017 .60471 Mtetra
.651 .764 .932 r
.35017 .60471 .35399 .60816 .36016 .60622 .35635 .60277 Mtetra
.35635 .60277 .36016 .60622 .36635 .60429 .36255 .60082 Mtetra
.36255 .60082 .36635 .60429 .37256 .60234 .36877 .59887 Mtetra
.65 .763 .932 r
.36877 .59887 .37256 .60234 .37878 .6004 .37499 .59692 Mtetra
.37499 .59692 .37878 .6004 .38501 .59846 .38123 .59497 Mtetra
.651 .764 .932 r
.38123 .59497 .38501 .59846 .39126 .59651 .38749 .59301 Mtetra
.65 .763 .932 r
.38749 .59301 .39126 .59651 .39752 .59456 .39376 .59105 Mtetra
.649 .763 .932 r
.39376 .59105 .39752 .59456 .40379 .59262 .40005 .5891 Mtetra
.65 .763 .932 r
.40005 .5891 .40379 .59262 .41009 .59066 .40635 .58714 Mtetra
.40635 .58714 .41009 .59066 .41639 .58871 .41266 .58518 Mtetra
.649 .763 .933 r
.41266 .58518 .41639 .58871 .42271 .58676 .41899 .58322 Mtetra
.649 .763 .932 r
.41899 .58322 .42271 .58676 .42904 .5848 .42533 .58126 Mtetra
.42533 .58126 .42904 .5848 .43539 .58284 .43169 .57928 Mtetra
.648 .763 .933 r
.43169 .57928 .43539 .58284 .44175 .58089 .43806 .57733 Mtetra
.43806 .57733 .44175 .58089 .44813 .57893 .44445 .57536 Mtetra
.649 .763 .932 r
.44445 .57536 .44813 .57893 .45452 .57696 .45085 .57338 Mtetra
.647 .762 .933 r
.45085 .57338 .45452 .57696 .46093 .575 .45727 .57142 Mtetra
.648 .763 .933 r
.45727 .57142 .46093 .575 .46735 .57304 .4637 .56944 Mtetra
.4637 .56944 .46735 .57304 .47379 .57106 .47015 .56746 Mtetra
.647 .762 .933 r
.47015 .56746 .47379 .57106 .48025 .5691 .47661 .56549 Mtetra
.47661 .56549 .48025 .5691 .48671 .56714 .48309 .56351 Mtetra
.648 .763 .933 r
.48309 .56351 .48671 .56714 .4932 .56516 .48958 .56152 Mtetra
.647 .762 .933 r
.48958 .56152 .4932 .56516 .4997 .56318 .49609 .55955 Mtetra
.646 .762 .933 r
.49609 .55955 .4997 .56318 .50621 .56122 .50262 .55757 Mtetra
.647 .762 .933 r
.50262 .55757 .50621 .56122 .51274 .55923 .50916 .55557 Mtetra
.646 .762 .933 r
.50916 .55557 .51274 .55923 .51928 .55725 .51571 .55358 Mtetra
.645 .762 .934 r
.51571 .55358 .51928 .55725 .52584 .55528 .52228 .5516 Mtetra
.646 .762 .933 r
.52228 .5516 .52584 .55528 .53242 .55329 .52887 .5496 Mtetra
.52887 .5496 .53242 .55329 .53901 .5513 .53547 .54761 Mtetra
.645 .762 .934 r
.53547 .54761 .53901 .5513 .54562 .54932 .54209 .54562 Mtetra
.54209 .54562 .54562 .54932 .55225 .54733 .54872 .54362 Mtetra
.54872 .54362 .55225 .54733 .55888 .54533 .55537 .54161 Mtetra
.644 .761 .934 r
.55537 .54161 .55888 .54533 .56554 .54335 .56204 .53962 Mtetra
.645 .762 .934 r
.56204 .53962 .56554 .54335 .57221 .54135 .56872 .53762 Mtetra
.56872 .53762 .57221 .54135 .5789 .53935 .57542 .5356 Mtetra
.643 .761 .934 r
.57542 .5356 .5789 .53935 .58561 .53736 .58214 .5336 Mtetra
.644 .761 .934 r
.58214 .5336 .58561 .53736 .59233 .53536 .58887 .5316 Mtetra
.645 .762 .934 r
.58887 .5316 .59233 .53536 .59906 .53335 .59562 .52957 Mtetra
.643 .761 .934 r
.59562 .52957 .59906 .53335 .60582 .53135 .60238 .52757 Mtetra
.60238 .52757 .60582 .53135 .61259 .52935 .60916 .52556 Mtetra
.60916 .52556 .61259 .52935 .61938 .52734 .61596 .52354 Mtetra
.61596 .52354 .61938 .52734 .62618 .52533 .62278 .52152 Mtetra
.62278 .52152 .62618 .52533 .633 .52332 .62961 .5195 Mtetra
.643 .761 .935 r
.62961 .5195 .633 .52332 .63984 .52131 .63646 .51748 Mtetra
.642 .761 .935 r
.63646 .51748 .63984 .52131 .64669 .51929 .64333 .51545 Mtetra
.64333 .51545 .64669 .51929 .65357 .51727 .65021 .51343 Mtetra
.65021 .51343 .65357 .51727 .66046 .51525 .65711 .5114 Mtetra
.65711 .5114 .66046 .51525 .66736 .51323 .66403 .50937 Mtetra
.642 .76 .935 r
.66403 .50937 .66736 .51323 .67429 .51121 .67096 .50734 Mtetra
.641 .76 .935 r
.67096 .50734 .67429 .51121 .68123 .50918 .67792 .5053 Mtetra
.67792 .5053 .68123 .50918 .68819 .50716 .68489 .50326 Mtetra
.68489 .50326 .68819 .50716 .69516 .50513 .69187 .50123 Mtetra
.69187 .50123 .69516 .50513 .70216 .5031 .69888 .49919 Mtetra
.69888 .49919 .70216 .5031 .70917 .50106 .7059 .49714 Mtetra
.64 .76 .935 r
.7059 .49714 .70917 .50106 .7162 .49903 .71295 .4951 Mtetra
.71295 .4951 .7162 .49903 .72325 .49699 .72001 .49305 Mtetra
.72001 .49305 .72325 .49699 .73031 .49495 .72708 .491 Mtetra
.72708 .491 .73031 .49495 .7374 .49291 .73418 .48895 Mtetra
.639 .76 .935 r
.73418 .48895 .7374 .49291 .7445 .49087 .74129 .4869 Mtetra
.639 .76 .936 r
.74129 .4869 .7445 .49087 .75162 .48883 .74843 .48485 Mtetra
.639 .76 .935 r
.74843 .48485 .75162 .48883 .75876 .48678 .75558 .48279 Mtetra
.64 .76 .935 r
.75558 .48279 .75876 .48678 .76591 .48471 .76275 .48071 Mtetra
.641 .76 .935 r
.76275 .48071 .76591 .48471 .77309 .48263 .76993 .47862 Mtetra
.645 .762 .934 r
.76993 .47862 .77309 .48263 .78027 .48047 .77713 .47645 Mtetra
.649 .763 .933 r
.77713 .47645 .78027 .48047 .78747 .47825 .78434 .47422 Mtetra
.672 .772 .926 r
.78434 .47422 .78747 .47825 .79466 .47565 .79154 .47161 Mtetra
.697 .782 .917 r
.79154 .47161 .79466 .47565 .80183 .4726 .79872 .46855 Mtetra
.732 .794 .902 r
.79872 .46855 .80183 .4726 .80895 .46885 .80586 .46479 Mtetra
.811 .814 .853 r
.80586 .46479 .80895 .46885 .81589 .46303 .81282 .45895 Mtetra
.854 .821 .815 r
.81282 .45895 .81589 .46303 .8227 .4556 .81964 .45151 Mtetra
.917 .819 .734 r
.81964 .45151 .8227 .4556 .82914 .44431 .8261 .4402 Mtetra
.954 .804 .656 r
.8261 .4402 .82914 .44431 .83509 .42817 .83208 .42403 Mtetra
.967 .793 .616 r
.83208 .42403 .83509 .42817 .84069 .40885 .8377 .40468 Mtetra
.982 .769 .54 r
.8377 .40468 .84069 .40885 .84536 .38087 .84241 .37667 Mtetra
.985 .76 .516 r
.84241 .37667 .84536 .38087 .84957 .3493 .84664 .34506 Mtetra
.942 .627 .41 r
.2138 .51776 .21767 .52116 .2205 .55049 .2166 .54712 Mtetra
.942 .619 .394 r
.2166 .54712 .2205 .55049 .22367 .57739 .21974 .57404 Mtetra
.935 .58 .322 r
.21974 .57404 .22367 .57739 .22763 .59633 .22369 .59299 Mtetra
.925 .547 .265 r
.22369 .59299 .22763 .59633 .23196 .61197 .228 .60864 Mtetra
.875 .436 .089 r
.228 .60864 .23196 .61197 .2368 .62237 .23283 .61905 Mtetra
.624 .099 0 r
.23283 .61905 .2368 .62237 .24208 .62804 .2381 .62472 Mtetra
0 .223 .689 r
.2381 .62472 .24208 .62804 .24756 .63168 .24358 .62836 Mtetra
.338 .641 .964 r
.24358 .62836 .24756 .63168 .25329 .63245 .24932 .62913 Mtetra
.496 .713 .968 r
.24932 .62913 .25329 .63245 .25913 .63217 .25517 .62884 Mtetra
.572 .741 .956 r
.25517 .62884 .25913 .63217 .26504 .63121 .26108 .62787 Mtetra
.631 .759 .939 r
.26108 .62787 .26504 .63121 .27101 .62958 .26707 .62624 Mtetra
.639 .761 .937 r
.26707 .62624 .27101 .62958 .27701 .62786 .27307 .6245 Mtetra
.648 .764 .933 r
.27307 .6245 .27701 .62786 .28303 .62601 .27909 .62265 Mtetra
.652 .765 .932 r
.27909 .62265 .28303 .62601 .28906 .6241 .28514 .62073 Mtetra
.653 .765 .932 r
.28514 .62073 .28906 .6241 .29511 .62218 .29119 .6188 Mtetra
.29119 .6188 .29511 .62218 .30117 .62025 .29727 .61686 Mtetra
.653 .765 .931 r
.29727 .61686 .30117 .62025 .30725 .61831 .30335 .61492 Mtetra
.30335 .61492 .30725 .61831 .31334 .61636 .30945 .61296 Mtetra
.652 .765 .932 r
.30945 .61296 .31334 .61636 .31944 .61443 .31556 .61102 Mtetra
.31556 .61102 .31944 .61443 .32556 .61249 .32169 .60907 Mtetra
.653 .765 .932 r
.32169 .60907 .32556 .61249 .33169 .61054 .32783 .60712 Mtetra
.651 .764 .932 r
.32783 .60712 .33169 .61054 .33784 .60861 .33398 .60517 Mtetra
.652 .764 .932 r
.33398 .60517 .33784 .60861 .34399 .60666 .34015 .60322 Mtetra
.652 .765 .932 r
.34015 .60322 .34399 .60666 .35017 .60471 .34633 .60126 Mtetra
.651 .764 .932 r
.34633 .60126 .35017 .60471 .35635 .60277 .35252 .59931 Mtetra
.35252 .59931 .35635 .60277 .36255 .60082 .35873 .59736 Mtetra
.35873 .59736 .36255 .60082 .36877 .59887 .36495 .59539 Mtetra
.65 .764 .932 r
.36495 .59539 .36877 .59887 .37499 .59692 .37119 .59344 Mtetra
.65 .764 .933 r
.37119 .59344 .37499 .59692 .38123 .59497 .37744 .59148 Mtetra
.651 .764 .932 r
.37744 .59148 .38123 .59497 .38749 .59301 .38371 .58951 Mtetra
.65 .764 .933 r
.38371 .58951 .38749 .59301 .39376 .59105 .38999 .58755 Mtetra
.649 .764 .933 r
.38999 .58755 .39376 .59105 .40005 .5891 .39628 .58559 Mtetra
.65 .764 .933 r
.39628 .58559 .40005 .5891 .40635 .58714 .40259 .58362 Mtetra
.40259 .58362 .40635 .58714 .41266 .58518 .40891 .58164 Mtetra
.649 .764 .933 r
.40891 .58164 .41266 .58518 .41899 .58322 .41525 .57968 Mtetra
.41525 .57968 .41899 .58322 .42533 .58126 .4216 .57771 Mtetra
.4216 .57771 .42533 .58126 .43169 .57928 .42797 .57573 Mtetra
.648 .763 .933 r
.42797 .57573 .43169 .57928 .43806 .57733 .43435 .57376 Mtetra
.648 .764 .933 r
.43435 .57376 .43806 .57733 .44445 .57536 .44075 .57178 Mtetra
.649 .764 .933 r
.44075 .57178 .44445 .57536 .45085 .57338 .44716 .5698 Mtetra
.647 .763 .933 r
.44716 .5698 .45085 .57338 .45727 .57142 .45359 .56782 Mtetra
.648 .763 .933 r
.45359 .56782 .45727 .57142 .4637 .56944 .46003 .56584 Mtetra
.46003 .56584 .4637 .56944 .47015 .56746 .46649 .56385 Mtetra
.647 .763 .934 r
.46649 .56385 .47015 .56746 .47661 .56549 .47296 .56187 Mtetra
.47296 .56187 .47661 .56549 .48309 .56351 .47945 .55989 Mtetra
.647 .763 .933 r
.47945 .55989 .48309 .56351 .48958 .56152 .48595 .55789 Mtetra
.646 .763 .934 r
.48595 .55789 .48958 .56152 .49609 .55955 .49247 .5559 Mtetra
.49247 .5559 .49609 .55955 .50262 .55757 .49901 .55392 Mtetra
.647 .763 .934 r
.49901 .55392 .50262 .55757 .50916 .55557 .50556 .55191 Mtetra
.646 .763 .934 r
.50556 .55191 .50916 .55557 .51571 .55358 .51212 .54992 Mtetra
.645 .763 .934 r
.51212 .54992 .51571 .55358 .52228 .5516 .5187 .54793 Mtetra
.646 .763 .934 r
.5187 .54793 .52228 .5516 .52887 .5496 .5253 .54592 Mtetra
.5253 .54592 .52887 .5496 .53547 .54761 .53191 .54391 Mtetra
.645 .762 .934 r
.53191 .54391 .53547 .54761 .54209 .54562 .53854 .54192 Mtetra
.645 .763 .934 r
.53854 .54192 .54209 .54562 .54872 .54362 .54519 .53991 Mtetra
.54519 .53991 .54872 .54362 .55537 .54161 .55185 .53789 Mtetra
.644 .762 .935 r
.55185 .53789 .55537 .54161 .56204 .53962 .55852 .53589 Mtetra
.645 .762 .934 r
.55852 .53589 .56204 .53962 .56872 .53762 .56522 .53388 Mtetra
.56522 .53388 .56872 .53762 .57542 .5356 .57193 .53185 Mtetra
.643 .762 .935 r
.57193 .53185 .57542 .5356 .58214 .5336 .57865 .52984 Mtetra
.644 .762 .935 r
.57865 .52984 .58214 .5336 .58887 .5316 .5854 .52783 Mtetra
.644 .762 .934 r
.5854 .52783 .58887 .5316 .59562 .52957 .59216 .5258 Mtetra
.643 .762 .935 r
.59216 .5258 .59562 .52957 .60238 .52757 .59893 .52378 Mtetra
.59893 .52378 .60238 .52757 .60916 .52556 .60572 .52176 Mtetra
.60572 .52176 .60916 .52556 .61596 .52354 .61253 .51974 Mtetra
.61253 .51974 .61596 .52354 .62278 .52152 .61936 .51771 Mtetra
.61936 .51771 .62278 .52152 .62961 .5195 .6262 .51568 Mtetra
.642 .762 .935 r
.6262 .51568 .62961 .5195 .63646 .51748 .63306 .51365 Mtetra
.63306 .51365 .63646 .51748 .64333 .51545 .63994 .51161 Mtetra
.642 .761 .935 r
.63994 .51161 .64333 .51545 .65021 .51343 .64684 .50958 Mtetra
.64684 .50958 .65021 .51343 .65711 .5114 .65375 .50754 Mtetra
.65375 .50754 .65711 .5114 .66403 .50937 .66068 .5055 Mtetra
.641 .761 .935 r
.66068 .5055 .66403 .50937 .67096 .50734 .66762 .50346 Mtetra
.66762 .50346 .67096 .50734 .67792 .5053 .67459 .50141 Mtetra
.67459 .50141 .67792 .5053 .68489 .50326 .68157 .49937 Mtetra
.641 .761 .936 r
.68157 .49937 .68489 .50326 .69187 .50123 .68857 .49732 Mtetra
.68857 .49732 .69187 .50123 .69888 .49919 .69559 .49527 Mtetra
.64 .761 .936 r
.69559 .49527 .69888 .49919 .7059 .49714 .70262 .49322 Mtetra
.70262 .49322 .7059 .49714 .71295 .4951 .70968 .49116 Mtetra
.70968 .49116 .71295 .4951 .72001 .49305 .71675 .48911 Mtetra
.71675 .48911 .72001 .49305 .72708 .491 .72384 .48705 Mtetra
.64 .76 .936 r
.72384 .48705 .72708 .491 .73418 .48895 .73095 .48499 Mtetra
.639 .76 .936 r
.73095 .48499 .73418 .48895 .74129 .4869 .73808 .48293 Mtetra
.73808 .48293 .74129 .4869 .74843 .48485 .74522 .48086 Mtetra
.74522 .48086 .74843 .48485 .75558 .48279 .75238 .47879 Mtetra
.64 .761 .936 r
.75238 .47879 .75558 .48279 .76275 .48071 .75956 .47671 Mtetra
.641 .761 .936 r
.75956 .47671 .76275 .48071 .76993 .47862 .76676 .47461 Mtetra
.645 .763 .934 r
.76676 .47461 .76993 .47862 .77713 .47645 .77397 .47243 Mtetra
.649 .764 .933 r
.77397 .47243 .77713 .47645 .78434 .47422 .7812 .47019 Mtetra
.672 .773 .926 r
.7812 .47019 .78434 .47422 .79154 .47161 .78841 .46757 Mtetra
.697 .782 .917 r
.78841 .46757 .79154 .47161 .79872 .46855 .79561 .46449 Mtetra
.732 .794 .902 r
.79561 .46449 .79872 .46855 .80586 .46479 .80276 .46072 Mtetra
.812 .815 .853 r
.80276 .46072 .80586 .46479 .81282 .45895 .80974 .45487 Mtetra
.854 .821 .815 r
.80974 .45487 .81282 .45895 .81964 .45151 .81657 .44741 Mtetra
.917 .819 .734 r
.81657 .44741 .81964 .45151 .8261 .4402 .82305 .43608 Mtetra
.954 .804 .656 r
.82305 .43608 .8261 .4402 .83208 .42403 .82905 .41989 Mtetra
.967 .794 .616 r
.82905 .41989 .83208 .42403 .8377 .40468 .8347 .40051 Mtetra
.982 .769 .54 r
.8347 .40051 .8377 .40468 .84241 .37667 .83944 .37246 Mtetra
.985 .76 .516 r
.83944 .37246 .84241 .37667 .84664 .34506 .84371 .34081 Mtetra
.943 .627 .41 r
.20993 .51434 .2138 .51776 .2166 .54712 .21269 .54372 Mtetra
.942 .619 .394 r
.21269 .54372 .2166 .54712 .21974 .57404 .2158 .57066 Mtetra
.935 .58 .322 r
.2158 .57066 .21974 .57404 .22369 .59299 .21972 .58963 Mtetra
.925 .547 .265 r
.21972 .58963 .22369 .59299 .228 .60864 .22402 .60529 Mtetra
.875 .436 .089 r
.22402 .60529 .228 .60864 .23283 .61905 .22884 .6157 Mtetra
.622 .098 0 r
.22884 .6157 .23283 .61905 .2381 .62472 .23411 .62138 Mtetra
0 .224 .691 r
.23411 .62138 .2381 .62472 .24358 .62836 .23959 .62501 Mtetra
.34 .64 .964 r
.23959 .62501 .24358 .62836 .24932 .62913 .24534 .62578 Mtetra
.497 .712 .967 r
.24534 .62578 .24932 .62913 .25517 .62884 .25119 .62548 Mtetra
.573 .74 .955 r
.25119 .62548 .25517 .62884 .26108 .62787 .25711 .62451 Mtetra
.632 .758 .939 r
.25711 .62451 .26108 .62787 .26707 .62624 .2631 .62287 Mtetra
.639 .761 .936 r
.2631 .62287 .26707 .62624 .27307 .6245 .26911 .62112 Mtetra
.648 .763 .933 r
.26911 .62112 .27307 .6245 .27909 .62265 .27515 .61926 Mtetra
.652 .764 .931 r
.27515 .61926 .27909 .62265 .28514 .62073 .2812 .61734 Mtetra
.653 .764 .931 r
.2812 .61734 .28514 .62073 .29119 .6188 .28726 .6154 Mtetra
.28726 .6154 .29119 .6188 .29727 .61686 .29334 .61345 Mtetra
.29334 .61345 .29727 .61686 .30335 .61492 .29944 .6115 Mtetra
.29944 .6115 .30335 .61492 .30945 .61296 .30554 .60953 Mtetra
.652 .764 .931 r
.30554 .60953 .30945 .61296 .31556 .61102 .31166 .60759 Mtetra
.31166 .60759 .31556 .61102 .32169 .60907 .3178 .60563 Mtetra
.653 .764 .931 r
.3178 .60563 .32169 .60907 .32783 .60712 .32395 .60366 Mtetra
.651 .764 .932 r
.32395 .60366 .32783 .60712 .33398 .60517 .33011 .60171 Mtetra
.652 .764 .931 r
.33011 .60171 .33398 .60517 .34015 .60322 .33628 .59975 Mtetra
.33628 .59975 .34015 .60322 .34633 .60126 .34247 .59778 Mtetra
.651 .764 .932 r
.34247 .59778 .34633 .60126 .35252 .59931 .34868 .59583 Mtetra
.34868 .59583 .35252 .59931 .35873 .59736 .3549 .59386 Mtetra
.651 .764 .931 r
.3549 .59386 .35873 .59736 .36495 .59539 .36113 .59189 Mtetra
.65 .763 .932 r
.36113 .59189 .36495 .59539 .37119 .59344 .36737 .58993 Mtetra
.36737 .58993 .37119 .59344 .37744 .59148 .37363 .58796 Mtetra
.651 .763 .932 r
.37363 .58796 .37744 .59148 .38371 .58951 .37991 .58598 Mtetra
.65 .763 .932 r
.37991 .58598 .38371 .58951 .38999 .58755 .3862 .58401 Mtetra
.649 .763 .932 r
.3862 .58401 .38999 .58755 .39628 .58559 .3925 .58205 Mtetra
.65 .763 .932 r
.3925 .58205 .39628 .58559 .40259 .58362 .39882 .58007 Mtetra
.39882 .58007 .40259 .58362 .40891 .58164 .40515 .57808 Mtetra
.649 .763 .933 r
.40515 .57808 .40891 .58164 .41525 .57968 .4115 .57611 Mtetra
.649 .763 .932 r
.4115 .57611 .41525 .57968 .4216 .57771 .41786 .57413 Mtetra
.41786 .57413 .4216 .57771 .42797 .57573 .42424 .57214 Mtetra
.648 .763 .933 r
.42424 .57214 .42797 .57573 .43435 .57376 .43063 .57017 Mtetra
.43063 .57017 .43435 .57376 .44075 .57178 .43704 .56818 Mtetra
.649 .763 .932 r
.43704 .56818 .44075 .57178 .44716 .5698 .44346 .56618 Mtetra
.647 .762 .933 r
.44346 .56618 .44716 .5698 .45359 .56782 .4499 .56421 Mtetra
.648 .763 .933 r
.4499 .56421 .45359 .56782 .46003 .56584 .45635 .56222 Mtetra
.45635 .56222 .46003 .56584 .46649 .56385 .46281 .56021 Mtetra
.647 .762 .933 r
.46281 .56021 .46649 .56385 .47296 .56187 .4693 .55823 Mtetra
.4693 .55823 .47296 .56187 .47945 .55989 .47579 .55623 Mtetra
.648 .763 .933 r
.47579 .55623 .47945 .55989 .48595 .55789 .48231 .55423 Mtetra
.647 .762 .933 r
.48231 .55423 .48595 .55789 .49247 .5559 .48884 .55223 Mtetra
.646 .762 .933 r
.48884 .55223 .49247 .5559 .49901 .55392 .49538 .55024 Mtetra
.647 .762 .933 r
.49538 .55024 .49901 .55392 .50556 .55191 .50194 .54822 Mtetra
.646 .762 .933 r
.50194 .54822 .50556 .55191 .51212 .54992 .50852 .54622 Mtetra
.645 .762 .934 r
.50852 .54622 .51212 .54992 .5187 .54793 .51511 .54422 Mtetra
.646 .762 .933 r
.51511 .54422 .5187 .54793 .5253 .54592 .52172 .5422 Mtetra
.52172 .5422 .5253 .54592 .53191 .54391 .52834 .54019 Mtetra
.645 .762 .934 r
.52834 .54019 .53191 .54391 .53854 .54192 .53498 .53818 Mtetra
.53498 .53818 .53854 .54192 .54519 .53991 .54163 .53616 Mtetra
.54163 .53616 .54519 .53991 .55185 .53789 .5483 .53414 Mtetra
.644 .761 .934 r
.5483 .53414 .55185 .53789 .55852 .53589 .55499 .53213 Mtetra
.645 .762 .934 r
.55499 .53213 .55852 .53589 .56522 .53388 .5617 .53011 Mtetra
.5617 .53011 .56522 .53388 .57193 .53185 .56842 .52807 Mtetra
.643 .761 .934 r
.56842 .52807 .57193 .53185 .57865 .52984 .57515 .52606 Mtetra
.644 .761 .934 r
.57515 .52606 .57865 .52984 .5854 .52783 .58191 .52403 Mtetra
.645 .762 .934 r
.58191 .52403 .5854 .52783 .59216 .5258 .58868 .52199 Mtetra
.643 .761 .934 r
.58868 .52199 .59216 .5258 .59893 .52378 .59546 .51997 Mtetra
.59546 .51997 .59893 .52378 .60572 .52176 .60227 .51794 Mtetra
.60227 .51794 .60572 .52176 .61253 .51974 .60909 .5159 Mtetra
.60909 .5159 .61253 .51974 .61936 .51771 .61593 .51387 Mtetra
.61593 .51387 .61936 .51771 .6262 .51568 .62278 .51183 Mtetra
.62278 .51183 .6262 .51568 .63306 .51365 .62965 .50979 Mtetra
.642 .761 .935 r
.62965 .50979 .63306 .51365 .63994 .51161 .63654 .50774 Mtetra
.63654 .50774 .63994 .51161 .64684 .50958 .64345 .5057 Mtetra
.64345 .5057 .64684 .50958 .65375 .50754 .65037 .50365 Mtetra
.65037 .50365 .65375 .50754 .66068 .5055 .65731 .5016 Mtetra
.642 .76 .935 r
.65731 .5016 .66068 .5055 .66762 .50346 .66427 .49955 Mtetra
.641 .76 .935 r
.66427 .49955 .66762 .50346 .67459 .50141 .67125 .49749 Mtetra
.67125 .49749 .67459 .50141 .68157 .49937 .67824 .49544 Mtetra
.67824 .49544 .68157 .49937 .68857 .49732 .68525 .49338 Mtetra
.68525 .49338 .68857 .49732 .69559 .49527 .69228 .49132 Mtetra
.69228 .49132 .69559 .49527 .70262 .49322 .69933 .48926 Mtetra
.64 .76 .935 r
.69933 .48926 .70262 .49322 .70968 .49116 .7064 .48719 Mtetra
.7064 .48719 .70968 .49116 .71675 .48911 .71348 .48513 Mtetra
.71348 .48513 .71675 .48911 .72384 .48705 .72058 .48306 Mtetra
.72058 .48306 .72384 .48705 .73095 .48499 .7277 .48099 Mtetra
.639 .76 .935 r
.7277 .48099 .73095 .48499 .73808 .48293 .73484 .47892 Mtetra
.73484 .47892 .73808 .48293 .74522 .48086 .742 .47685 Mtetra
.742 .47685 .74522 .48086 .75238 .47879 .74917 .47477 Mtetra
.64 .76 .935 r
.74917 .47477 .75238 .47879 .75956 .47671 .75637 .47267 Mtetra
.641 .76 .935 r
.75637 .47267 .75956 .47671 .76676 .47461 .76358 .47056 Mtetra
.645 .762 .934 r
.76358 .47056 .76676 .47461 .77397 .47243 .7708 .46837 Mtetra
.649 .763 .933 r
.7708 .46837 .77397 .47243 .7812 .47019 .77804 .46612 Mtetra
.672 .772 .926 r
.77804 .46612 .7812 .47019 .78841 .46757 .78527 .46349 Mtetra
.697 .782 .917 r
.78527 .46349 .78841 .46757 .79561 .46449 .79248 .46041 Mtetra
.732 .794 .902 r
.79248 .46041 .79561 .46449 .80276 .46072 .79964 .45662 Mtetra
.811 .814 .853 r
.79964 .45662 .80276 .46072 .80974 .45487 .80663 .45075 Mtetra
.854 .821 .815 r
.80663 .45075 .80974 .45487 .81657 .44741 .81349 .44328 Mtetra
.917 .819 .734 r
.81349 .44328 .81657 .44741 .82305 .43608 .81999 .43193 Mtetra
.954 .804 .656 r
.81999 .43193 .82305 .43608 .82905 .41989 .82601 .41571 Mtetra
.967 .793 .616 r
.82601 .41571 .82905 .41989 .8347 .40051 .83169 .39631 Mtetra
.982 .769 .54 r
.83169 .39631 .8347 .40051 .83944 .37246 .83645 .36822 Mtetra
.985 .76 .516 r
.83645 .36822 .83944 .37246 .84371 .34081 .84075 .33654 Mtetra
.943 .627 .41 r
.20603 .5109 .20993 .51434 .21269 .54372 .20876 .54031 Mtetra
.942 .619 .394 r
.20876 .54031 .21269 .54372 .2158 .57066 .21184 .56727 Mtetra
.935 .58 .322 r
.21184 .56727 .2158 .57066 .21972 .58963 .21574 .58625 Mtetra
.925 .547 .265 r
.21574 .58625 .21972 .58963 .22402 .60529 .22002 .60192 Mtetra
.875 .436 .089 r
.22002 .60192 .22402 .60529 .22884 .6157 .22483 .61234 Mtetra
.622 .098 0 r
.22483 .61234 .22884 .6157 .23411 .62138 .2301 .61802 Mtetra
0 .224 .691 r
.2301 .61802 .23411 .62138 .23959 .62501 .23559 .62165 Mtetra
.34 .64 .964 r
.23559 .62165 .23959 .62501 .24534 .62578 .24134 .62241 Mtetra
.497 .712 .967 r
.24134 .62241 .24534 .62578 .25119 .62548 .24719 .62211 Mtetra
.573 .74 .955 r
.24719 .62211 .25119 .62548 .25711 .62451 .25312 .62113 Mtetra
.632 .758 .939 r
.25312 .62113 .25711 .62451 .2631 .62287 .25912 .61948 Mtetra
.639 .76 .936 r
.25912 .61948 .2631 .62287 .26911 .62112 .26514 .61773 Mtetra
.648 .763 .933 r
.26514 .61773 .26911 .62112 .27515 .61926 .27118 .61586 Mtetra
.652 .764 .931 r
.27118 .61586 .27515 .61926 .2812 .61734 .27724 .61392 Mtetra
.653 .764 .931 r
.27724 .61392 .2812 .61734 .28726 .6154 .28331 .61198 Mtetra
.28331 .61198 .28726 .6154 .29334 .61345 .2894 .61002 Mtetra
.2894 .61002 .29334 .61345 .29944 .6115 .29551 .60806 Mtetra
.29551 .60806 .29944 .6115 .30554 .60953 .30162 .60609 Mtetra
.652 .764 .931 r
.30162 .60609 .30554 .60953 .31166 .60759 .30775 .60414 Mtetra
.30775 .60414 .31166 .60759 .3178 .60563 .31389 .60217 Mtetra
.653 .764 .931 r
.31389 .60217 .3178 .60563 .32395 .60366 .32005 .6002 Mtetra
.651 .764 .931 r
.32005 .6002 .32395 .60366 .33011 .60171 .32622 .59824 Mtetra
.652 .764 .931 r
.32622 .59824 .33011 .60171 .33628 .59975 .33241 .59627 Mtetra
.33241 .59627 .33628 .59975 .34247 .59778 .33861 .59429 Mtetra
.651 .763 .932 r
.33861 .59429 .34247 .59778 .34868 .59583 .34482 .59232 Mtetra
.34482 .59232 .34868 .59583 .3549 .59386 .35104 .59036 Mtetra
.651 .764 .931 r
.35104 .59036 .3549 .59386 .36113 .59189 .35729 .58837 Mtetra
.65 .763 .932 r
.35729 .58837 .36113 .59189 .36737 .58993 .36354 .5864 Mtetra
.36354 .5864 .36737 .58993 .37363 .58796 .36981 .58443 Mtetra
.651 .763 .932 r
.36981 .58443 .37363 .58796 .37991 .58598 .37609 .58244 Mtetra
.65 .763 .932 r
.37609 .58244 .37991 .58598 .3862 .58401 .38239 .58046 Mtetra
.649 .763 .932 r
.38239 .58046 .3862 .58401 .3925 .58205 .3887 .57849 Mtetra
.65 .763 .932 r
.3887 .57849 .3925 .58205 .39882 .58007 .39503 .5765 Mtetra
.39503 .5765 .39882 .58007 .40515 .57808 .40137 .57451 Mtetra
.649 .763 .932 r
.40137 .57451 .40515 .57808 .4115 .57611 .40773 .57253 Mtetra
.40773 .57253 .4115 .57611 .41786 .57413 .4141 .57054 Mtetra
.4141 .57054 .41786 .57413 .42424 .57214 .42049 .56854 Mtetra
.648 .763 .933 r
.42049 .56854 .42424 .57214 .43063 .57017 .42689 .56656 Mtetra
.42689 .56656 .43063 .57017 .43704 .56818 .43331 .56456 Mtetra
.649 .763 .932 r
.43331 .56456 .43704 .56818 .44346 .56618 .43974 .56256 Mtetra
.647 .762 .933 r
.43974 .56256 .44346 .56618 .4499 .56421 .44618 .56057 Mtetra
.648 .763 .933 r
.44618 .56057 .4499 .56421 .45635 .56222 .45265 .55857 Mtetra
.45265 .55857 .45635 .56222 .46281 .56021 .45912 .55656 Mtetra
.647 .762 .933 r
.45912 .55656 .46281 .56021 .4693 .55823 .46562 .55456 Mtetra
.46562 .55456 .4693 .55823 .47579 .55623 .47212 .55256 Mtetra
.648 .762 .933 r
.47212 .55256 .47579 .55623 .48231 .55423 .47865 .55055 Mtetra
.647 .762 .933 r
.47865 .55055 .48231 .55423 .48884 .55223 .48519 .54854 Mtetra
.646 .762 .933 r
.48519 .54854 .48884 .55223 .49538 .55024 .49174 .54654 Mtetra
.647 .762 .933 r
.49174 .54654 .49538 .55024 .50194 .54822 .49831 .54452 Mtetra
.646 .762 .933 r
.49831 .54452 .50194 .54822 .50852 .54622 .5049 .5425 Mtetra
.645 .762 .934 r
.5049 .5425 .50852 .54622 .51511 .54422 .5115 .54049 Mtetra
.646 .762 .933 r
.5115 .54049 .51511 .54422 .52172 .5422 .51811 .53847 Mtetra
.51811 .53847 .52172 .5422 .52834 .54019 .52475 .53644 Mtetra
.645 .762 .934 r
.52475 .53644 .52834 .54019 .53498 .53818 .5314 .53443 Mtetra
.646 .762 .934 r
.5314 .53443 .53498 .53818 .54163 .53616 .53806 .5324 Mtetra
.645 .762 .934 r
.53806 .5324 .54163 .53616 .5483 .53414 .54475 .53037 Mtetra
.644 .761 .934 r
.54475 .53037 .5483 .53414 .55499 .53213 .55144 .52835 Mtetra
.645 .762 .934 r
.55144 .52835 .55499 .53213 .5617 .53011 .55816 .52632 Mtetra
.55816 .52632 .5617 .53011 .56842 .52807 .56489 .52427 Mtetra
.643 .761 .934 r
.56489 .52427 .56842 .52807 .57515 .52606 .57164 .52225 Mtetra
.644 .761 .934 r
.57164 .52225 .57515 .52606 .58191 .52403 .5784 .52021 Mtetra
.645 .761 .934 r
.5784 .52021 .58191 .52403 .58868 .52199 .58518 .51816 Mtetra
.643 .761 .934 r
.58518 .51816 .58868 .52199 .59546 .51997 .59198 .51613 Mtetra
.59198 .51613 .59546 .51997 .60227 .51794 .5988 .5141 Mtetra
.5988 .5141 .60227 .51794 .60909 .5159 .60563 .51205 Mtetra
.60563 .51205 .60909 .5159 .61593 .51387 .61248 .51 Mtetra
.61248 .51 .61593 .51387 .62278 .51183 .61934 .50795 Mtetra
.61934 .50795 .62278 .51183 .62965 .50979 .62623 .5059 Mtetra
.642 .761 .935 r
.62623 .5059 .62965 .50979 .63654 .50774 .63313 .50385 Mtetra
.63313 .50385 .63654 .50774 .64345 .5057 .64004 .5018 Mtetra
.64004 .5018 .64345 .5057 .65037 .50365 .64698 .49974 Mtetra
.64698 .49974 .65037 .50365 .65731 .5016 .65393 .49768 Mtetra
.642 .76 .935 r
.65393 .49768 .65731 .5016 .66427 .49955 .6609 .49562 Mtetra
.641 .76 .935 r
.6609 .49562 .66427 .49955 .67125 .49749 .66789 .49355 Mtetra
.66789 .49355 .67125 .49749 .67824 .49544 .6749 .49149 Mtetra
.6749 .49149 .67824 .49544 .68525 .49338 .68192 .48942 Mtetra
.68192 .48942 .68525 .49338 .69228 .49132 .68896 .48735 Mtetra
.68896 .48735 .69228 .49132 .69933 .48926 .69602 .48528 Mtetra
.64 .76 .935 r
.69602 .48528 .69933 .48926 .7064 .48719 .7031 .48321 Mtetra
.7031 .48321 .7064 .48719 .71348 .48513 .71019 .48113 Mtetra
.71019 .48113 .71348 .48513 .72058 .48306 .71731 .47905 Mtetra
.71731 .47905 .72058 .48306 .7277 .48099 .72444 .47698 Mtetra
.639 .76 .935 r
.72444 .47698 .7277 .48099 .73484 .47892 .73159 .47489 Mtetra
.639 .759 .935 r
.73159 .47489 .73484 .47892 .742 .47685 .73876 .47281 Mtetra
.639 .76 .935 r
.73876 .47281 .742 .47685 .74917 .47477 .74595 .47072 Mtetra
.64 .76 .935 r
.74595 .47072 .74917 .47477 .75637 .47267 .75316 .46862 Mtetra
.641 .76 .935 r
.75316 .46862 .75637 .47267 .76358 .47056 .76038 .46649 Mtetra
.645 .762 .934 r
.76038 .46649 .76358 .47056 .7708 .46837 .76762 .46429 Mtetra
.649 .763 .933 r
.76762 .46429 .7708 .46837 .77804 .46612 .77487 .46204 Mtetra
.672 .772 .926 r
.77487 .46204 .77804 .46612 .78527 .46349 .78211 .45939 Mtetra
.697 .782 .917 r
.78211 .45939 .78527 .46349 .79248 .46041 .78933 .4563 Mtetra
.731 .794 .902 r
.78933 .4563 .79248 .46041 .79964 .45662 .79651 .4525 Mtetra
.811 .814 .853 r
.79651 .4525 .79964 .45662 .80663 .45075 .80352 .44662 Mtetra
.854 .821 .815 r
.80352 .44662 .80663 .45075 .81349 .44328 .81039 .43913 Mtetra
.917 .819 .734 r
.81039 .43913 .81349 .44328 .81999 .43193 .81691 .42776 Mtetra
.954 .804 .656 r
.81691 .42776 .81999 .43193 .82601 .41571 .82296 .41152 Mtetra
.967 .793 .616 r
.82296 .41152 .82601 .41571 .83169 .39631 .82866 .39209 Mtetra
.982 .769 .54 r
.82866 .39209 .83169 .39631 .83645 .36822 .83345 .36397 Mtetra
.985 .76 .516 r
.83345 .36397 .83645 .36822 .84075 .33654 .83779 .33224 Mtetra
.942 .627 .41 r
.20212 .50746 .20603 .5109 .20876 .54031 .20482 .53689 Mtetra
.942 .619 .394 r
.20482 .53689 .20876 .54031 .21184 .56727 .20786 .56388 Mtetra
.935 .58 .322 r
.20786 .56388 .21184 .56727 .21574 .58625 .21174 .58288 Mtetra
.925 .547 .265 r
.21174 .58288 .21574 .58625 .22002 .60192 .21601 .59856 Mtetra
.875 .436 .09 r
.21601 .59856 .22002 .60192 .22483 .61234 .22081 .60898 Mtetra
.624 .099 0 r
.22081 .60898 .22483 .61234 .2301 .61802 .22608 .61466 Mtetra
0 .223 .689 r
.22608 .61466 .2301 .61802 .23559 .62165 .23156 .61829 Mtetra
.338 .641 .965 r
.23156 .61829 .23559 .62165 .24134 .62241 .23731 .61904 Mtetra
.496 .713 .968 r
.23731 .61904 .24134 .62241 .24719 .62211 .24318 .61874 Mtetra
.572 .741 .956 r
.24318 .61874 .24719 .62211 .25312 .62113 .24911 .61775 Mtetra
.631 .759 .939 r
.24911 .61775 .25312 .62113 .25912 .61948 .25512 .61609 Mtetra
.639 .761 .937 r
.25512 .61609 .25912 .61948 .26514 .61773 .26115 .61433 Mtetra
.648 .764 .934 r
.26115 .61433 .26514 .61773 .27118 .61586 .2672 .61246 Mtetra
.652 .765 .932 r
.2672 .61246 .27118 .61586 .27724 .61392 .27327 .61051 Mtetra
.653 .765 .932 r
.27327 .61051 .27724 .61392 .28331 .61198 .27935 .60856 Mtetra
.27935 .60856 .28331 .61198 .2894 .61002 .28545 .6066 Mtetra
.653 .765 .931 r
.28545 .6066 .2894 .61002 .29551 .60806 .29156 .60463 Mtetra
.29156 .60463 .29551 .60806 .30162 .60609 .29768 .60265 Mtetra
.652 .765 .932 r
.29768 .60265 .30162 .60609 .30775 .60414 .30382 .60069 Mtetra
.30382 .60069 .30775 .60414 .31389 .60217 .30997 .59871 Mtetra
.653 .765 .932 r
.30997 .59871 .31389 .60217 .32005 .6002 .31614 .59673 Mtetra
.651 .765 .932 r
.31614 .59673 .32005 .6002 .32622 .59824 .32232 .59476 Mtetra
.652 .765 .932 r
.32232 .59476 .32622 .59824 .33241 .59627 .32851 .59279 Mtetra
.32851 .59279 .33241 .59627 .33861 .59429 .33472 .5908 Mtetra
.651 .764 .932 r
.33472 .5908 .33861 .59429 .34482 .59232 .34094 .58882 Mtetra
.34094 .58882 .34482 .59232 .35104 .59036 .34717 .58685 Mtetra
.651 .765 .932 r
.34717 .58685 .35104 .59036 .35729 .58837 .35343 .58486 Mtetra
.65 .764 .932 r
.35343 .58486 .35729 .58837 .36354 .5864 .35969 .58287 Mtetra
.65 .764 .933 r
.35969 .58287 .36354 .5864 .36981 .58443 .36597 .58089 Mtetra
.651 .764 .932 r
.36597 .58089 .36981 .58443 .37609 .58244 .37226 .5789 Mtetra
.65 .764 .933 r
.37226 .5789 .37609 .58244 .38239 .58046 .37857 .57691 Mtetra
.649 .764 .933 r
.37857 .57691 .38239 .58046 .3887 .57849 .38489 .57493 Mtetra
.65 .764 .933 r
.38489 .57493 .3887 .57849 .39503 .5765 .39123 .57293 Mtetra
.39123 .57293 .39503 .5765 .40137 .57451 .39758 .57093 Mtetra
.649 .764 .933 r
.39758 .57093 .40137 .57451 .40773 .57253 .40395 .56894 Mtetra
.40395 .56894 .40773 .57253 .4141 .57054 .41033 .56694 Mtetra
.41033 .56694 .4141 .57054 .42049 .56854 .41672 .56494 Mtetra
.648 .763 .933 r
.41672 .56494 .42049 .56854 .42689 .56656 .42313 .56295 Mtetra
.648 .764 .933 r
.42313 .56295 .42689 .56656 .43331 .56456 .42956 .56094 Mtetra
.649 .764 .933 r
.42956 .56094 .43331 .56456 .43974 .56256 .436 .55893 Mtetra
.647 .763 .934 r
.436 .55893 .43974 .56256 .44618 .56057 .44246 .55693 Mtetra
.648 .763 .933 r
.44246 .55693 .44618 .56057 .45265 .55857 .44893 .55492 Mtetra
.648 .764 .933 r
.44893 .55492 .45265 .55857 .45912 .55656 .45542 .55291 Mtetra
.647 .763 .934 r
.45542 .55291 .45912 .55656 .46562 .55456 .46192 .5509 Mtetra
.46192 .5509 .46562 .55456 .47212 .55256 .46843 .54889 Mtetra
.647 .763 .933 r
.46843 .54889 .47212 .55256 .47865 .55055 .47497 .54687 Mtetra
.646 .763 .934 r
.47497 .54687 .47865 .55055 .48519 .54854 .48152 .54485 Mtetra
.48152 .54485 .48519 .54854 .49174 .54654 .48808 .54284 Mtetra
.647 .763 .934 r
.48808 .54284 .49174 .54654 .49831 .54452 .49466 .54081 Mtetra
.646 .763 .934 r
.49466 .54081 .49831 .54452 .5049 .5425 .50126 .53878 Mtetra
.645 .763 .934 r
.50126 .53878 .5049 .5425 .5115 .54049 .50787 .53677 Mtetra
.646 .763 .934 r
.50787 .53677 .5115 .54049 .51811 .53847 .5145 .53473 Mtetra
.5145 .53473 .51811 .53847 .52475 .53644 .52114 .5327 Mtetra
.645 .762 .934 r
.52114 .5327 .52475 .53644 .5314 .53443 .5278 .53068 Mtetra
.645 .763 .934 r
.5278 .53068 .5314 .53443 .53806 .5324 .53448 .52864 Mtetra
.53448 .52864 .53806 .5324 .54475 .53037 .54117 .5266 Mtetra
.644 .762 .935 r
.54117 .5266 .54475 .53037 .55144 .52835 .54788 .52457 Mtetra
.645 .762 .934 r
.54788 .52457 .55144 .52835 .55816 .52632 .55461 .52253 Mtetra
.645 .763 .934 r
.55461 .52253 .55816 .52632 .56489 .52427 .56135 .52047 Mtetra
.643 .762 .935 r
.56135 .52047 .56489 .52427 .57164 .52225 .56811 .51844 Mtetra
.644 .762 .935 r
.56811 .51844 .57164 .52225 .5784 .52021 .57488 .5164 Mtetra
.644 .762 .934 r
.57488 .5164 .5784 .52021 .58518 .51816 .58167 .51434 Mtetra
.643 .762 .935 r
.58167 .51434 .58518 .51816 .59198 .51613 .58848 .5123 Mtetra
.58848 .5123 .59198 .51613 .5988 .5141 .59531 .51025 Mtetra
.59531 .51025 .5988 .5141 .60563 .51205 .60215 .5082 Mtetra
.60215 .5082 .60563 .51205 .61248 .51 .60901 .50614 Mtetra
.60901 .50614 .61248 .51 .61934 .50795 .61589 .50408 Mtetra
.642 .762 .935 r
.61589 .50408 .61934 .50795 .62623 .5059 .62278 .50202 Mtetra
.62278 .50202 .62623 .5059 .63313 .50385 .6297 .49996 Mtetra
.6297 .49996 .63313 .50385 .64004 .5018 .63663 .49789 Mtetra
.642 .761 .935 r
.63663 .49789 .64004 .5018 .64698 .49974 .64357 .49583 Mtetra
.64357 .49583 .64698 .49974 .65393 .49768 .65054 .49376 Mtetra
.641 .761 .935 r
.65054 .49376 .65393 .49768 .6609 .49562 .65752 .49169 Mtetra
.65752 .49169 .6609 .49562 .66789 .49355 .66452 .48961 Mtetra
.641 .761 .936 r
.66452 .48961 .66789 .49355 .6749 .49149 .67154 .48754 Mtetra
.67154 .48754 .6749 .49149 .68192 .48942 .67857 .48546 Mtetra
.67857 .48546 .68192 .48942 .68896 .48735 .68562 .48338 Mtetra
.64 .761 .936 r
.68562 .48338 .68896 .48735 .69602 .48528 .6927 .4813 Mtetra
.6927 .4813 .69602 .48528 .7031 .48321 .69979 .47922 Mtetra
.69979 .47922 .7031 .48321 .71019 .48113 .70689 .47713 Mtetra
.70689 .47713 .71019 .48113 .71731 .47905 .71402 .47505 Mtetra
.639 .761 .936 r
.71402 .47505 .71731 .47905 .72444 .47698 .72117 .47296 Mtetra
.72117 .47296 .72444 .47698 .73159 .47489 .72833 .47086 Mtetra
.639 .76 .936 r
.72833 .47086 .73159 .47489 .73876 .47281 .73551 .46877 Mtetra
.639 .761 .936 r
.73551 .46877 .73876 .47281 .74595 .47072 .74271 .46667 Mtetra
.64 .761 .936 r
.74271 .46667 .74595 .47072 .75316 .46862 .74993 .46456 Mtetra
.641 .761 .936 r
.74993 .46456 .75316 .46862 .76038 .46649 .75717 .46242 Mtetra
.645 .763 .935 r
.75717 .46242 .76038 .46649 .76762 .46429 .76442 .46022 Mtetra
.649 .764 .934 r
.76442 .46022 .76762 .46429 .77487 .46204 .77168 .45795 Mtetra
.672 .773 .926 r
.77168 .45795 .77487 .46204 .78211 .45939 .77894 .45529 Mtetra
.697 .783 .917 r
.77894 .45529 .78211 .45939 .78933 .4563 .78617 .45219 Mtetra
.732 .794 .902 r
.78617 .45219 .78933 .4563 .79651 .4525 .79336 .44838 Mtetra
.812 .815 .853 r
.79336 .44838 .79651 .4525 .80352 .44662 .80039 .44248 Mtetra
.855 .821 .815 r
.80039 .44248 .80352 .44662 .81039 .43913 .80728 .43498 Mtetra
.917 .819 .734 r
.80728 .43498 .81039 .43913 .81691 .42776 .81382 .42358 Mtetra
.954 .805 .656 r
.81382 .42358 .81691 .42776 .82296 .41152 .81989 .40732 Mtetra
.967 .794 .616 r
.81989 .40732 .82296 .41152 .82866 .39209 .82561 .38786 Mtetra
.982 .769 .54 r
.82561 .38786 .82866 .39209 .83345 .36397 .83044 .3597 Mtetra
.985 .76 .516 r
.83044 .3597 .83345 .36397 .83779 .33224 .83481 .32794 Mtetra
.943 .627 .41 r
.1982 .504 .20212 .50746 .20482 .53689 .20086 .53346 Mtetra
.942 .619 .394 r
.20086 .53346 .20482 .53689 .20786 .56388 .20386 .56047 Mtetra
.935 .58 .322 r
.20386 .56047 .20786 .56388 .21174 .58288 .20773 .57948 Mtetra
.925 .547 .265 r
.20773 .57948 .21174 .58288 .21601 .59856 .21198 .59517 Mtetra
.875 .436 .089 r
.21198 .59517 .21601 .59856 .22081 .60898 .21677 .6056 Mtetra
.623 .098 0 r
.21677 .6056 .22081 .60898 .22608 .61466 .22204 .61127 Mtetra
0 .224 .69 r
.22204 .61127 .22608 .61466 .23156 .61829 .22752 .61491 Mtetra
.339 .641 .964 r
.22752 .61491 .23156 .61829 .23731 .61904 .23328 .61565 Mtetra
.497 .713 .967 r
.23328 .61565 .23731 .61904 .24318 .61874 .23915 .61534 Mtetra
.573 .741 .956 r
.23915 .61534 .24318 .61874 .24911 .61775 .24509 .61435 Mtetra
.632 .759 .939 r
.24509 .61435 .24911 .61775 .25512 .61609 .2511 .61268 Mtetra
.639 .761 .936 r
.2511 .61268 .25512 .61609 .26115 .61433 .25714 .61092 Mtetra
.648 .763 .933 r
.25714 .61092 .26115 .61433 .2672 .61246 .2632 .60903 Mtetra
.652 .764 .931 r
.2632 .60903 .2672 .61246 .27327 .61051 .26927 .60708 Mtetra
.653 .764 .931 r
.26927 .60708 .27327 .61051 .27935 .60856 .27537 .60512 Mtetra
.27537 .60512 .27935 .60856 .28545 .6066 .28147 .60315 Mtetra
.28147 .60315 .28545 .6066 .29156 .60463 .28759 .60117 Mtetra
.28759 .60117 .29156 .60463 .29768 .60265 .29372 .59918 Mtetra
.652 .764 .931 r
.29372 .59918 .29768 .60265 .30382 .60069 .29987 .59721 Mtetra
.29987 .59721 .30382 .60069 .30997 .59871 .30603 .59523 Mtetra
.653 .764 .931 r
.30603 .59523 .30997 .59871 .31614 .59673 .31221 .59324 Mtetra
.651 .764 .932 r
.31221 .59324 .31614 .59673 .32232 .59476 .31839 .59126 Mtetra
.652 .764 .932 r
.31839 .59126 .32232 .59476 .32851 .59279 .3246 .58928 Mtetra
.652 .764 .931 r
.3246 .58928 .32851 .59279 .33472 .5908 .33081 .58728 Mtetra
.651 .764 .932 r
.33081 .58728 .33472 .5908 .34094 .58882 .33704 .5853 Mtetra
.33704 .5853 .34094 .58882 .34717 .58685 .34329 .58331 Mtetra
.34329 .58331 .34717 .58685 .35343 .58486 .34955 .58131 Mtetra
.65 .764 .932 r
.34955 .58131 .35343 .58486 .35969 .58287 .35582 .57932 Mtetra
.35582 .57932 .35969 .58287 .36597 .58089 .36211 .57734 Mtetra
.651 .764 .932 r
.36211 .57734 .36597 .58089 .37226 .5789 .36841 .57533 Mtetra
.65 .764 .932 r
.36841 .57533 .37226 .5789 .37857 .57691 .37473 .57333 Mtetra
.649 .763 .932 r
.37473 .57333 .37857 .57691 .38489 .57493 .38106 .57134 Mtetra
.65 .764 .932 r
.38106 .57134 .38489 .57493 .39123 .57293 .38741 .56934 Mtetra
.65 .763 .932 r
.38741 .56934 .39123 .57293 .39758 .57093 .39377 .56733 Mtetra
.649 .763 .933 r
.39377 .56733 .39758 .57093 .40395 .56894 .40014 .56533 Mtetra
.649 .763 .932 r
.40014 .56533 .40395 .56894 .41033 .56694 .40653 .56332 Mtetra
.40653 .56332 .41033 .56694 .41672 .56494 .41294 .56131 Mtetra
.648 .763 .933 r
.41294 .56131 .41672 .56494 .42313 .56295 .41936 .55931 Mtetra
.41936 .55931 .42313 .56295 .42956 .56094 .4258 .5573 Mtetra
.649 .763 .933 r
.4258 .5573 .42956 .56094 .436 .55893 .43225 .55527 Mtetra
.647 .763 .933 r
.43225 .55527 .436 .55893 .44246 .55693 .43871 .55327 Mtetra
.648 .763 .933 r
.43871 .55327 .44246 .55693 .44893 .55492 .44519 .55125 Mtetra
.44519 .55125 .44893 .55492 .45542 .55291 .45169 .54922 Mtetra
.647 .763 .933 r
.45169 .54922 .45542 .55291 .46192 .5509 .4582 .54721 Mtetra
.4582 .54721 .46192 .5509 .46843 .54889 .46473 .54519 Mtetra
.648 .763 .933 r
.46473 .54519 .46843 .54889 .47497 .54687 .47127 .54316 Mtetra
.647 .762 .933 r
.47127 .54316 .47497 .54687 .48152 .54485 .47783 .54113 Mtetra
.646 .762 .934 r
.47783 .54113 .48152 .54485 .48808 .54284 .48441 .53911 Mtetra
.647 .763 .933 r
.48441 .53911 .48808 .54284 .49466 .54081 .491 .53707 Mtetra
.646 .762 .934 r
.491 .53707 .49466 .54081 .50126 .53878 .4976 .53504 Mtetra
.645 .762 .934 r
.4976 .53504 .50126 .53878 .50787 .53677 .50423 .53301 Mtetra
.646 .762 .934 r
.50423 .53301 .50787 .53677 .5145 .53473 .51087 .53097 Mtetra
.51087 .53097 .5145 .53473 .52114 .5327 .51752 .52893 Mtetra
.645 .762 .934 r
.51752 .52893 .52114 .5327 .5278 .53068 .52419 .5269 Mtetra
.52419 .5269 .5278 .53068 .53448 .52864 .53088 .52485 Mtetra
.53088 .52485 .53448 .52864 .54117 .5266 .53758 .5228 Mtetra
.644 .762 .934 r
.53758 .5228 .54117 .5266 .54788 .52457 .5443 .52076 Mtetra
.645 .762 .934 r
.5443 .52076 .54788 .52457 .55461 .52253 .55104 .51871 Mtetra
.55104 .51871 .55461 .52253 .56135 .52047 .55779 .51665 Mtetra
.643 .761 .934 r
.55779 .51665 .56135 .52047 .56811 .51844 .56456 .51461 Mtetra
.644 .762 .934 r
.56456 .51461 .56811 .51844 .57488 .5164 .57135 .51255 Mtetra
.57135 .51255 .57488 .5164 .58167 .51434 .57815 .51048 Mtetra
.643 .761 .935 r
.57815 .51048 .58167 .51434 .58848 .5123 .58497 .50843 Mtetra
.58497 .50843 .58848 .5123 .59531 .51025 .59181 .50638 Mtetra
.643 .761 .934 r
.59181 .50638 .59531 .51025 .60215 .5082 .59866 .50431 Mtetra
.643 .761 .935 r
.59866 .50431 .60215 .5082 .60901 .50614 .60553 .50225 Mtetra
.60553 .50225 .60901 .50614 .61589 .50408 .61242 .50018 Mtetra
.61242 .50018 .61589 .50408 .62278 .50202 .61933 .49811 Mtetra
.642 .761 .935 r
.61933 .49811 .62278 .50202 .6297 .49996 .62625 .49604 Mtetra
.62625 .49604 .6297 .49996 .63663 .49789 .63319 .49396 Mtetra
.63319 .49396 .63663 .49789 .64357 .49583 .64015 .49189 Mtetra
.64015 .49189 .64357 .49583 .65054 .49376 .64712 .48981 Mtetra
.64712 .48981 .65054 .49376 .65752 .49169 .65412 .48773 Mtetra
.641 .761 .935 r
.65412 .48773 .65752 .49169 .66452 .48961 .66113 .48565 Mtetra
.66113 .48565 .66452 .48961 .67154 .48754 .66816 .48356 Mtetra
.641 .76 .935 r
.66816 .48356 .67154 .48754 .67857 .48546 .67521 .48147 Mtetra
.67521 .48147 .67857 .48546 .68562 .48338 .68227 .47938 Mtetra
.64 .76 .935 r
.68227 .47938 .68562 .48338 .6927 .4813 .68936 .47729 Mtetra
.68936 .47729 .6927 .4813 .69979 .47922 .69646 .4752 Mtetra
.69646 .4752 .69979 .47922 .70689 .47713 .70358 .4731 Mtetra
.64 .76 .936 r
.70358 .4731 .70689 .47713 .71402 .47505 .71072 .47101 Mtetra
.71072 .47101 .71402 .47505 .72117 .47296 .71787 .46891 Mtetra
.639 .76 .936 r
.71787 .46891 .72117 .47296 .72833 .47086 .72505 .46681 Mtetra
.72505 .46681 .72833 .47086 .73551 .46877 .73225 .4647 Mtetra
.73225 .4647 .73551 .46877 .74271 .46667 .73946 .46259 Mtetra
.64 .76 .936 r
.73946 .46259 .74271 .46667 .74993 .46456 .74669 .46047 Mtetra
.641 .761 .935 r
.74669 .46047 .74993 .46456 .75717 .46242 .75394 .45832 Mtetra
.645 .762 .934 r
.75394 .45832 .75717 .46242 .76442 .46022 .7612 .45611 Mtetra
.649 .764 .933 r
.7612 .45611 .76442 .46022 .77168 .45795 .76848 .45383 Mtetra
.672 .773 .926 r
.76848 .45383 .77168 .45795 .77894 .45529 .77575 .45116 Mtetra
.697 .782 .917 r
.77575 .45116 .77894 .45529 .78617 .45219 .78299 .44804 Mtetra
.732 .794 .902 r
.78299 .44804 .78617 .45219 .79336 .44838 .7902 .44422 Mtetra
.811 .815 .853 r
.7902 .44422 .79336 .44838 .80039 .44248 .79724 .43831 Mtetra
.854 .821 .815 r
.79724 .43831 .80039 .44248 .80728 .43498 .80415 .43079 Mtetra
.917 .819 .734 r
.80415 .43079 .80728 .43498 .81382 .42358 .81071 .41938 Mtetra
.954 .804 .656 r
.81071 .41938 .81382 .42358 .81989 .40732 .8168 .40309 Mtetra
.967 .794 .616 r
.8168 .40309 .81989 .40732 .82561 .38786 .82256 .38361 Mtetra
.982 .769 .54 r
.82256 .38361 .82561 .38786 .83044 .3597 .82742 .35541 Mtetra
.985 .76 .516 r
.82742 .35541 .83044 .3597 .83481 .32794 .83182 .32361 Mtetra
.943 .627 .41 r
.19426 .50052 .1982 .504 .20086 .53346 .19688 .53 Mtetra
.942 .619 .394 r
.19688 .53 .20086 .53346 .20386 .56047 .19985 .55703 Mtetra
.935 .58 .322 r
.19985 .55703 .20386 .56047 .20773 .57948 .2037 .57606 Mtetra
.925 .547 .265 r
.2037 .57606 .20773 .57948 .21198 .59517 .20793 .59176 Mtetra
.875 .436 .088 r
.20793 .59176 .21198 .59517 .21677 .6056 .21271 .6022 Mtetra
.622 .098 0 r
.21271 .6022 .21677 .6056 .22204 .61127 .21798 .60787 Mtetra
0 .225 .691 r
.21798 .60787 .22204 .61127 .22752 .61491 .22346 .6115 Mtetra
.34 .64 .964 r
.22346 .6115 .22752 .61491 .23328 .61565 .22922 .61224 Mtetra
.497 .712 .967 r
.22922 .61224 .23328 .61565 .23915 .61534 .2351 .61192 Mtetra
.573 .74 .955 r
.2351 .61192 .23915 .61534 .24509 .61435 .24105 .61092 Mtetra
.632 .758 .939 r
.24105 .61092 .24509 .61435 .2511 .61268 .24707 .60925 Mtetra
.639 .76 .936 r
.24707 .60925 .2511 .61268 .25714 .61092 .25311 .60748 Mtetra
.648 .763 .933 r
.25311 .60748 .25714 .61092 .2632 .60903 .25918 .60558 Mtetra
.652 .764 .931 r
.25918 .60558 .2632 .60903 .26927 .60708 .26527 .60362 Mtetra
.653 .764 .931 r
.26527 .60362 .26927 .60708 .27537 .60512 .27137 .60165 Mtetra
.27137 .60165 .27537 .60512 .28147 .60315 .27748 .59967 Mtetra
.27748 .59967 .28147 .60315 .28759 .60117 .28361 .59769 Mtetra
.28361 .59769 .28759 .60117 .29372 .59918 .28975 .59569 Mtetra
.652 .764 .931 r
.28975 .59569 .29372 .59918 .29987 .59721 .29591 .59371 Mtetra
.29591 .59371 .29987 .59721 .30603 .59523 .30208 .59172 Mtetra
.653 .764 .931 r
.30208 .59172 .30603 .59523 .31221 .59324 .30826 .58972 Mtetra
.651 .764 .931 r
.30826 .58972 .31221 .59324 .31839 .59126 .31446 .58774 Mtetra
.652 .764 .931 r
.31446 .58774 .31839 .59126 .3246 .58928 .32067 .58575 Mtetra
.32067 .58575 .3246 .58928 .33081 .58728 .32689 .58374 Mtetra
.651 .763 .932 r
.32689 .58374 .33081 .58728 .33704 .5853 .33313 .58175 Mtetra
.33313 .58175 .33704 .5853 .34329 .58331 .33939 .57976 Mtetra
.651 .764 .931 r
.33939 .57976 .34329 .58331 .34955 .58131 .34566 .57775 Mtetra
.65 .763 .932 r
.34566 .57775 .34955 .58131 .35582 .57932 .35194 .57575 Mtetra
.35194 .57575 .35582 .57932 .36211 .57734 .35823 .57375 Mtetra
.651 .763 .932 r
.35823 .57375 .36211 .57734 .36841 .57533 .36455 .57174 Mtetra
.65 .763 .932 r
.36455 .57174 .36841 .57533 .37473 .57333 .37087 .56974 Mtetra
.649 .763 .932 r
.37087 .56974 .37473 .57333 .38106 .57134 .37721 .56773 Mtetra
.65 .763 .932 r
.37721 .56773 .38106 .57134 .38741 .56934 .38357 .56572 Mtetra
.38357 .56572 .38741 .56934 .39377 .56733 .38994 .5637 Mtetra
.649 .763 .932 r
.38994 .5637 .39377 .56733 .40014 .56533 .39632 .5617 Mtetra
.39632 .5617 .40014 .56533 .40653 .56332 .40272 .55968 Mtetra
.40272 .55968 .40653 .56332 .41294 .56131 .40914 .55766 Mtetra
.648 .763 .933 r
.40914 .55766 .41294 .56131 .41936 .55931 .41557 .55565 Mtetra
.648 .763 .932 r
.41557 .55565 .41936 .55931 .4258 .5573 .42202 .55363 Mtetra
.649 .763 .932 r
.42202 .55363 .4258 .5573 .43225 .55527 .42848 .5516 Mtetra
.647 .762 .933 r
.42848 .5516 .43225 .55527 .43871 .55327 .43495 .54958 Mtetra
.648 .762 .933 r
.43495 .54958 .43871 .55327 .44519 .55125 .44144 .54756 Mtetra
.648 .763 .933 r
.44144 .54756 .44519 .55125 .45169 .54922 .44795 .54552 Mtetra
.647 .762 .933 r
.44795 .54552 .45169 .54922 .4582 .54721 .45447 .5435 Mtetra
.45447 .5435 .4582 .54721 .46473 .54519 .46101 .54147 Mtetra
.648 .762 .933 r
.46101 .54147 .46473 .54519 .47127 .54316 .46756 .53943 Mtetra
.647 .762 .933 r
.46756 .53943 .47127 .54316 .47783 .54113 .47413 .53739 Mtetra
.646 .762 .933 r
.47413 .53739 .47783 .54113 .48441 .53911 .48072 .53536 Mtetra
.647 .762 .933 r
.48072 .53536 .48441 .53911 .491 .53707 .48732 .53332 Mtetra
.646 .762 .933 r
.48732 .53332 .491 .53707 .4976 .53504 .49394 .53127 Mtetra
.645 .762 .934 r
.49394 .53127 .4976 .53504 .50423 .53301 .50057 .52924 Mtetra
.646 .762 .933 r
.50057 .52924 .50423 .53301 .51087 .53097 .50722 .52719 Mtetra
.50722 .52719 .51087 .53097 .51752 .52893 .51388 .52513 Mtetra
.645 .761 .934 r
.51388 .52513 .51752 .52893 .52419 .5269 .52056 .52309 Mtetra
.646 .762 .933 r
.52056 .52309 .52419 .5269 .53088 .52485 .52726 .52104 Mtetra
.645 .762 .934 r
.52726 .52104 .53088 .52485 .53758 .5228 .53397 .51898 Mtetra
.644 .761 .934 r
.53397 .51898 .53758 .5228 .5443 .52076 .54071 .51693 Mtetra
.645 .761 .934 r
.54071 .51693 .5443 .52076 .55104 .51871 .54745 .51487 Mtetra
.645 .762 .934 r
.54745 .51487 .55104 .51871 .55779 .51665 .55422 .5128 Mtetra
.643 .761 .934 r
.55422 .5128 .55779 .51665 .56456 .51461 .561 .51075 Mtetra
.644 .761 .934 r
.561 .51075 .56456 .51461 .57135 .51255 .56779 .50868 Mtetra
.645 .761 .934 r
.56779 .50868 .57135 .51255 .57815 .51048 .57461 .50661 Mtetra
.643 .761 .934 r
.57461 .50661 .57815 .51048 .58497 .50843 .58144 .50454 Mtetra
.58144 .50454 .58497 .50843 .59181 .50638 .58829 .50248 Mtetra
.58829 .50248 .59181 .50638 .59866 .50431 .59515 .50041 Mtetra
.59515 .50041 .59866 .50431 .60553 .50225 .60204 .49833 Mtetra
.60204 .49833 .60553 .50225 .61242 .50018 .60894 .49625 Mtetra
.60894 .49625 .61242 .50018 .61933 .49811 .61585 .49417 Mtetra
.642 .761 .934 r
.61585 .49417 .61933 .49811 .62625 .49604 .62279 .49209 Mtetra
.642 .761 .935 r
.62279 .49209 .62625 .49604 .63319 .49396 .62974 .49001 Mtetra
.642 .76 .935 r
.62974 .49001 .63319 .49396 .64015 .49189 .63671 .48792 Mtetra
.63671 .48792 .64015 .49189 .64712 .48981 .6437 .48583 Mtetra
.6437 .48583 .64712 .48981 .65412 .48773 .6507 .48374 Mtetra
.641 .76 .935 r
.6507 .48374 .65412 .48773 .66113 .48565 .65773 .48165 Mtetra
.65773 .48165 .66113 .48565 .66816 .48356 .66477 .47956 Mtetra
.66477 .47956 .66816 .48356 .67521 .48147 .67183 .47746 Mtetra
.67183 .47746 .67521 .48147 .68227 .47938 .6789 .47536 Mtetra
.6789 .47536 .68227 .47938 .68936 .47729 .686 .47326 Mtetra
.64 .76 .935 r
.686 .47326 .68936 .47729 .69646 .4752 .69311 .47116 Mtetra
.69311 .47116 .69646 .4752 .70358 .4731 .70025 .46905 Mtetra
.70025 .46905 .70358 .4731 .71072 .47101 .7074 .46694 Mtetra
.7074 .46694 .71072 .47101 .71787 .46891 .71457 .46483 Mtetra
.639 .76 .935 r
.71457 .46483 .71787 .46891 .72505 .46681 .72176 .46272 Mtetra
.639 .759 .935 r
.72176 .46272 .72505 .46681 .73225 .4647 .72896 .46061 Mtetra
.639 .76 .935 r
.72896 .46061 .73225 .4647 .73946 .46259 .73619 .45849 Mtetra
.64 .76 .935 r
.73619 .45849 .73946 .46259 .74669 .46047 .74343 .45636 Mtetra
.641 .76 .935 r
.74343 .45636 .74669 .46047 .75394 .45832 .7507 .4542 Mtetra
.645 .762 .934 r
.7507 .4542 .75394 .45832 .7612 .45611 .75797 .45197 Mtetra
.649 .763 .933 r
.75797 .45197 .7612 .45611 .76848 .45383 .76526 .44968 Mtetra
.672 .772 .926 r
.76526 .44968 .76848 .45383 .77575 .45116 .77254 .447 Mtetra
.696 .782 .917 r
.77254 .447 .77575 .45116 .78299 .44804 .7798 .44388 Mtetra
.731 .793 .902 r
.7798 .44388 .78299 .44804 .7902 .44422 .78702 .44004 Mtetra
.811 .814 .853 r
.78702 .44004 .7902 .44422 .79724 .43831 .79408 .43412 Mtetra
.854 .821 .815 r
.79408 .43412 .79724 .43831 .80415 .43079 .80101 .42658 Mtetra
.917 .819 .734 r
.80101 .42658 .80415 .43079 .81071 .41938 .80759 .41515 Mtetra
.954 .804 .656 r
.80759 .41515 .81071 .41938 .8168 .40309 .81371 .39884 Mtetra
.967 .793 .616 r
.81371 .39884 .8168 .40309 .82256 .38361 .81948 .37932 Mtetra
.982 .769 .54 r
.81948 .37932 .82256 .38361 .82742 .35541 .82438 .3511 Mtetra
.985 .76 .516 r
.82438 .3511 .82742 .35541 .83182 .32361 .82882 .31925 Mtetra
.942 .627 .41 r
.1903 .49705 .19426 .50052 .19688 .53 .19288 .52655 Mtetra
.942 .619 .394 r
.19288 .52655 .19688 .53 .19985 .55703 .19583 .5536 Mtetra
.935 .58 .323 r
.19583 .5536 .19985 .55703 .2037 .57606 .19965 .57264 Mtetra
.925 .547 .265 r
.19965 .57264 .2037 .57606 .20793 .59176 .20386 .58836 Mtetra
.875 .436 .09 r
.20386 .58836 .20793 .59176 .21271 .6022 .20864 .5988 Mtetra
.624 .099 0 r
.20864 .5988 .21271 .6022 .21798 .60787 .2139 .60447 Mtetra
0 .223 .689 r
.2139 .60447 .21798 .60787 .22346 .6115 .21938 .6081 Mtetra
.338 .641 .965 r
.21938 .6081 .22346 .6115 .22922 .61224 .22515 .60884 Mtetra
.496 .713 .968 r
.22515 .60884 .22922 .61224 .2351 .61192 .23103 .60851 Mtetra
.572 .741 .956 r
.23103 .60851 .2351 .61192 .24105 .61092 .23699 .6075 Mtetra
.631 .759 .94 r
.23699 .6075 .24105 .61092 .24707 .60925 .24302 .60582 Mtetra
.639 .762 .937 r
.24302 .60582 .24707 .60925 .25311 .60748 .24907 .60404 Mtetra
.648 .764 .934 r
.24907 .60404 .25311 .60748 .25918 .60558 .25515 .60214 Mtetra
.652 .765 .932 r
.25515 .60214 .25918 .60558 .26527 .60362 .26124 .60017 Mtetra
.653 .765 .932 r
.26124 .60017 .26527 .60362 .27137 .60165 .26735 .59819 Mtetra
.26735 .59819 .27137 .60165 .27748 .59967 .27347 .59621 Mtetra
.653 .765 .931 r
.27347 .59621 .27748 .59967 .28361 .59769 .27961 .59421 Mtetra
.27961 .59421 .28361 .59769 .28975 .59569 .28576 .59221 Mtetra
.652 .765 .932 r
.28576 .59221 .28975 .59569 .29591 .59371 .29192 .59022 Mtetra
.29192 .59022 .29591 .59371 .30208 .59172 .2981 .58822 Mtetra
.653 .765 .932 r
.2981 .58822 .30208 .59172 .30826 .58972 .30429 .58621 Mtetra
.651 .765 .932 r
.30429 .58621 .30826 .58972 .31446 .58774 .3105 .58422 Mtetra
.652 .765 .932 r
.3105 .58422 .31446 .58774 .32067 .58575 .31672 .58222 Mtetra
.31672 .58222 .32067 .58575 .32689 .58374 .32296 .58021 Mtetra
.651 .764 .932 r
.32296 .58021 .32689 .58374 .33313 .58175 .3292 .57821 Mtetra
.3292 .57821 .33313 .58175 .33939 .57976 .33547 .5762 Mtetra
.651 .765 .932 r
.33547 .5762 .33939 .57976 .34566 .57775 .34174 .57419 Mtetra
.65 .764 .933 r
.34174 .57419 .34566 .57775 .35194 .57575 .34804 .57218 Mtetra
.34804 .57218 .35194 .57575 .35823 .57375 .35434 .57017 Mtetra
.651 .764 .932 r
.35434 .57017 .35823 .57375 .36455 .57174 .36066 .56815 Mtetra
.65 .764 .933 r
.36066 .56815 .36455 .57174 .37087 .56974 .367 .56614 Mtetra
.649 .764 .933 r
.367 .56614 .37087 .56974 .37721 .56773 .37335 .56413 Mtetra
.65 .764 .933 r
.37335 .56413 .37721 .56773 .38357 .56572 .37971 .56211 Mtetra
.37971 .56211 .38357 .56572 .38994 .5637 .38609 .56008 Mtetra
.649 .764 .933 r
.38609 .56008 .38994 .5637 .39632 .5617 .39249 .55807 Mtetra
.39249 .55807 .39632 .5617 .40272 .55968 .3989 .55604 Mtetra
.3989 .55604 .40272 .55968 .40914 .55766 .40532 .55401 Mtetra
.648 .764 .933 r
.40532 .55401 .40914 .55766 .41557 .55565 .41176 .55199 Mtetra
.41176 .55199 .41557 .55565 .42202 .55363 .41822 .54996 Mtetra
.649 .764 .933 r
.41822 .54996 .42202 .55363 .42848 .5516 .42469 .54792 Mtetra
.647 .763 .934 r
.42469 .54792 .42848 .5516 .43495 .54958 .43117 .5459 Mtetra
.648 .763 .933 r
.43117 .5459 .43495 .54958 .44144 .54756 .43768 .54386 Mtetra
.648 .764 .933 r
.43768 .54386 .44144 .54756 .44795 .54552 .44419 .54182 Mtetra
.647 .763 .934 r
.44419 .54182 .44795 .54552 .45447 .5435 .45072 .53979 Mtetra
.45072 .53979 .45447 .5435 .46101 .54147 .45727 .53775 Mtetra
.45727 .53775 .46101 .54147 .46756 .53943 .46384 .5357 Mtetra
.646 .763 .934 r
.46384 .5357 .46756 .53943 .47413 .53739 .47042 .53366 Mtetra
.47042 .53366 .47413 .53739 .48072 .53536 .47701 .53162 Mtetra
.647 .763 .934 r
.47701 .53162 .48072 .53536 .48732 .53332 .48362 .52956 Mtetra
.646 .763 .934 r
.48362 .52956 .48732 .53332 .49394 .53127 .49025 .52751 Mtetra
.645 .763 .934 r
.49025 .52751 .49394 .53127 .50057 .52924 .49689 .52546 Mtetra
.646 .763 .934 r
.49689 .52546 .50057 .52924 .50722 .52719 .50355 .5234 Mtetra
.50355 .5234 .50722 .52719 .51388 .52513 .51023 .52134 Mtetra
.645 .762 .934 r
.51023 .52134 .51388 .52513 .52056 .52309 .51692 .51929 Mtetra
.645 .763 .934 r
.51692 .51929 .52056 .52309 .52726 .52104 .52363 .51723 Mtetra
.52363 .51723 .52726 .52104 .53397 .51898 .53035 .51516 Mtetra
.644 .762 .935 r
.53035 .51516 .53397 .51898 .54071 .51693 .53709 .5131 Mtetra
.645 .762 .934 r
.53709 .5131 .54071 .51693 .54745 .51487 .54385 .51103 Mtetra
.645 .763 .934 r
.54385 .51103 .54745 .51487 .55422 .5128 .55063 .50895 Mtetra
.643 .762 .935 r
.55063 .50895 .55422 .5128 .561 .51075 .55742 .50689 Mtetra
.644 .762 .935 r
.55742 .50689 .561 .51075 .56779 .50868 .56423 .50482 Mtetra
.56423 .50482 .56779 .50868 .57461 .50661 .57105 .50273 Mtetra
.643 .762 .935 r
.57105 .50273 .57461 .50661 .58144 .50454 .57789 .50066 Mtetra
.57789 .50066 .58144 .50454 .58829 .50248 .58475 .49858 Mtetra
.58475 .49858 .58829 .50248 .59515 .50041 .59163 .4965 Mtetra
.59163 .4965 .59515 .50041 .60204 .49833 .59852 .49442 Mtetra
.59852 .49442 .60204 .49833 .60894 .49625 .60543 .49233 Mtetra
.642 .762 .935 r
.60543 .49233 .60894 .49625 .61585 .49417 .61236 .49024 Mtetra
.61236 .49024 .61585 .49417 .62279 .49209 .61931 .48815 Mtetra
.61931 .48815 .62279 .49209 .62974 .49001 .62627 .48605 Mtetra
.62627 .48605 .62974 .49001 .63671 .48792 .63325 .48396 Mtetra
.642 .761 .935 r
.63325 .48396 .63671 .48792 .6437 .48583 .64025 .48186 Mtetra
.641 .761 .935 r
.64025 .48186 .6437 .48583 .6507 .48374 .64727 .47976 Mtetra
.641 .761 .936 r
.64727 .47976 .6507 .48374 .65773 .48165 .65431 .47766 Mtetra
.65431 .47766 .65773 .48165 .66477 .47956 .66136 .47555 Mtetra
.66136 .47555 .66477 .47956 .67183 .47746 .66843 .47345 Mtetra
.66843 .47345 .67183 .47746 .6789 .47536 .67552 .47134 Mtetra
.64 .761 .936 r
.67552 .47134 .6789 .47536 .686 .47326 .68263 .46923 Mtetra
.68263 .46923 .686 .47326 .69311 .47116 .68976 .46711 Mtetra
.68976 .46711 .69311 .47116 .70025 .46905 .6969 .465 Mtetra
.6969 .465 .70025 .46905 .7074 .46694 .70406 .46288 Mtetra
.639 .761 .936 r
.70406 .46288 .7074 .46694 .71457 .46483 .71125 .46076 Mtetra
.71125 .46076 .71457 .46483 .72176 .46272 .71845 .45864 Mtetra
.71845 .45864 .72176 .46272 .72896 .46061 .72567 .45652 Mtetra
.72567 .45652 .72896 .46061 .73619 .45849 .73291 .45438 Mtetra
.64 .761 .936 r
.73291 .45438 .73619 .45849 .74343 .45636 .74016 .45224 Mtetra
.641 .761 .936 r
.74016 .45224 .74343 .45636 .7507 .4542 .74744 .45008 Mtetra
.645 .763 .935 r
.74744 .45008 .7507 .4542 .75797 .45197 .75473 .44784 Mtetra
.649 .764 .934 r
.75473 .44784 .75797 .45197 .76526 .44968 .76203 .44554 Mtetra
.672 .773 .926 r
.76203 .44554 .76526 .44968 .77254 .447 .76932 .44285 Mtetra
.697 .783 .918 r
.76932 .44285 .77254 .447 .7798 .44388 .7766 .43971 Mtetra
.732 .795 .902 r
.7766 .43971 .7798 .44388 .78702 .44004 .78383 .43586 Mtetra
.812 .815 .853 r
.78383 .43586 .78702 .44004 .79408 .43412 .79091 .42993 Mtetra
.855 .822 .816 r
.79091 .42993 .79408 .43412 .80101 .42658 .79785 .42238 Mtetra
.917 .819 .734 r
.79785 .42238 .80101 .42658 .80759 .41515 .80445 .41092 Mtetra
.954 .805 .656 r
.80445 .41092 .80759 .41515 .81371 .39884 .81059 .39458 Mtetra
.967 .794 .616 r
.81059 .39458 .81371 .39884 .81948 .37932 .8164 .37504 Mtetra
.982 .769 .54 r
.8164 .37504 .81948 .37932 .82438 .3511 .82132 .34678 Mtetra
.985 .76 .516 r
.82132 .34678 .82438 .3511 .82882 .31925 .8258 .3149 Mtetra
.942 .627 .41 r
.18632 .49355 .1903 .49705 .19288 .52655 .18887 .52308 Mtetra
.942 .619 .394 r
.18887 .52308 .19288 .52655 .19583 .5536 .19178 .55015 Mtetra
.935 .58 .322 r
.19178 .55015 .19583 .5536 .19965 .57264 .19558 .56921 Mtetra
.925 .547 .265 r
.19558 .56921 .19965 .57264 .20386 .58836 .19978 .58493 Mtetra
.875 .436 .089 r
.19978 .58493 .20386 .58836 .20864 .5988 .20455 .59538 Mtetra
.623 .098 0 r
.20455 .59538 .20864 .5988 .2139 .60447 .20981 .60105 Mtetra
0 .224 .69 r
.20981 .60105 .2139 .60447 .21938 .6081 .21529 .60468 Mtetra
.339 .641 .964 r
.21529 .60468 .21938 .6081 .22515 .60884 .22106 .60541 Mtetra
.497 .713 .968 r
.22106 .60541 .22515 .60884 .23103 .60851 .22695 .60508 Mtetra
.572 .741 .956 r
.22695 .60508 .23103 .60851 .23699 .6075 .23291 .60406 Mtetra
.632 .759 .939 r
.23291 .60406 .23699 .6075 .24302 .60582 .23895 .60237 Mtetra
.639 .761 .937 r
.23895 .60237 .24302 .60582 .24907 .60404 .24501 .60058 Mtetra
.648 .763 .933 r
.24501 .60058 .24907 .60404 .25515 .60214 .25109 .59867 Mtetra
.652 .764 .932 r
.25109 .59867 .25515 .60214 .26124 .60017 .2572 .5967 Mtetra
.653 .765 .931 r
.2572 .5967 .26124 .60017 .26735 .59819 .26331 .59471 Mtetra
.26331 .59471 .26735 .59819 .27347 .59621 .26945 .59272 Mtetra
.26945 .59272 .27347 .59621 .27961 .59421 .27559 .59071 Mtetra
.27559 .59071 .27961 .59421 .28576 .59221 .28175 .5887 Mtetra
.652 .764 .932 r
.28175 .5887 .28576 .59221 .29192 .59022 .28792 .5867 Mtetra
.652 .765 .931 r
.28792 .5867 .29192 .59022 .2981 .58822 .29411 .58469 Mtetra
.653 .765 .931 r
.29411 .58469 .2981 .58822 .30429 .58621 .30031 .58268 Mtetra
.651 .764 .932 r
.30031 .58268 .30429 .58621 .3105 .58422 .30653 .58068 Mtetra
.652 .764 .932 r
.30653 .58068 .3105 .58422 .31672 .58222 .31276 .57867 Mtetra
.31276 .57867 .31672 .58222 .32296 .58021 .319 .57665 Mtetra
.651 .764 .932 r
.319 .57665 .32296 .58021 .3292 .57821 .32526 .57464 Mtetra
.32526 .57464 .3292 .57821 .33547 .5762 .33153 .57263 Mtetra
.33153 .57263 .33547 .5762 .34174 .57419 .33782 .5706 Mtetra
.65 .764 .932 r
.33782 .5706 .34174 .57419 .34804 .57218 .34412 .56859 Mtetra
.34412 .56859 .34804 .57218 .35434 .57017 .35043 .56657 Mtetra
.651 .764 .932 r
.35043 .56657 .35434 .57017 .36066 .56815 .35676 .56454 Mtetra
.65 .764 .932 r
.35676 .56454 .36066 .56815 .367 .56614 .36311 .56252 Mtetra
.649 .764 .933 r
.36311 .56252 .367 .56614 .37335 .56413 .36947 .5605 Mtetra
.65 .764 .932 r
.36947 .5605 .37335 .56413 .37971 .56211 .37584 .55847 Mtetra
.65 .764 .933 r
.37584 .55847 .37971 .56211 .38609 .56008 .38223 .55644 Mtetra
.649 .763 .933 r
.38223 .55644 .38609 .56008 .39249 .55807 .38864 .55441 Mtetra
.649 .764 .933 r
.38864 .55441 .39249 .55807 .3989 .55604 .39506 .55238 Mtetra
.39506 .55238 .3989 .55604 .40532 .55401 .40149 .55034 Mtetra
.648 .763 .933 r
.40149 .55034 .40532 .55401 .41176 .55199 .40794 .54831 Mtetra
.40794 .54831 .41176 .55199 .41822 .54996 .4144 .54627 Mtetra
.649 .763 .933 r
.4144 .54627 .41822 .54996 .42469 .54792 .42088 .54422 Mtetra
.647 .763 .933 r
.42088 .54422 .42469 .54792 .43117 .5459 .42738 .54219 Mtetra
.648 .763 .933 r
.42738 .54219 .43117 .5459 .43768 .54386 .43389 .54015 Mtetra
.43389 .54015 .43768 .54386 .44419 .54182 .44042 .53809 Mtetra
.647 .763 .933 r
.44042 .53809 .44419 .54182 .45072 .53979 .44696 .53605 Mtetra
.44696 .53605 .45072 .53979 .45727 .53775 .45352 .53401 Mtetra
.648 .763 .933 r
.45352 .53401 .45727 .53775 .46384 .5357 .46009 .53194 Mtetra
.647 .763 .934 r
.46009 .53194 .46384 .5357 .47042 .53366 .46668 .52989 Mtetra
.646 .763 .934 r
.46668 .52989 .47042 .53366 .47701 .53162 .47329 .52785 Mtetra
.647 .763 .933 r
.47329 .52785 .47701 .53162 .48362 .52956 .47991 .52578 Mtetra
.646 .763 .934 r
.47991 .52578 .48362 .52956 .49025 .52751 .48655 .52372 Mtetra
.645 .762 .934 r
.48655 .52372 .49025 .52751 .49689 .52546 .4932 .52166 Mtetra
.646 .763 .934 r
.4932 .52166 .49689 .52546 .50355 .5234 .49987 .51959 Mtetra
.646 .762 .934 r
.49987 .51959 .50355 .5234 .51023 .52134 .50656 .51752 Mtetra
.645 .762 .934 r
.50656 .51752 .51023 .52134 .51692 .51929 .51326 .51546 Mtetra
.51326 .51546 .51692 .51929 .52363 .51723 .51998 .51339 Mtetra
.51998 .51339 .52363 .51723 .53035 .51516 .52671 .51131 Mtetra
.644 .762 .934 r
.52671 .51131 .53035 .51516 .53709 .5131 .53346 .50924 Mtetra
.645 .762 .934 r
.53346 .50924 .53709 .5131 .54385 .51103 .54023 .50717 Mtetra
.54023 .50717 .54385 .51103 .55063 .50895 .54702 .50508 Mtetra
.643 .762 .935 r
.54702 .50508 .55063 .50895 .55742 .50689 .55382 .50301 Mtetra
.644 .762 .934 r
.55382 .50301 .55742 .50689 .56423 .50482 .56064 .50092 Mtetra
.56064 .50092 .56423 .50482 .57105 .50273 .56748 .49883 Mtetra
.643 .762 .935 r
.56748 .49883 .57105 .50273 .57789 .50066 .57433 .49675 Mtetra
.643 .761 .935 r
.57433 .49675 .57789 .50066 .58475 .49858 .5812 .49466 Mtetra
.643 .762 .935 r
.5812 .49466 .58475 .49858 .59163 .4965 .58809 .49257 Mtetra
.643 .761 .935 r
.58809 .49257 .59163 .4965 .59852 .49442 .59499 .49048 Mtetra
.59499 .49048 .59852 .49442 .60543 .49233 .60192 .48838 Mtetra
.642 .761 .935 r
.60192 .48838 .60543 .49233 .61236 .49024 .60886 .48628 Mtetra
.60886 .48628 .61236 .49024 .61931 .48815 .61582 .48418 Mtetra
.61582 .48418 .61931 .48815 .62627 .48605 .62279 .48207 Mtetra
.62279 .48207 .62627 .48605 .63325 .48396 .62978 .47997 Mtetra
.62978 .47997 .63325 .48396 .64025 .48186 .6368 .47786 Mtetra
.641 .761 .935 r
.6368 .47786 .64025 .48186 .64727 .47976 .64382 .47575 Mtetra
.64382 .47575 .64727 .47976 .65431 .47766 .65087 .47364 Mtetra
.65087 .47364 .65431 .47766 .66136 .47555 .65794 .47152 Mtetra
.65794 .47152 .66136 .47555 .66843 .47345 .66502 .46941 Mtetra
.66502 .46941 .66843 .47345 .67552 .47134 .67212 .46729 Mtetra
.64 .761 .936 r
.67212 .46729 .67552 .47134 .68263 .46923 .67924 .46517 Mtetra
.67924 .46517 .68263 .46923 .68976 .46711 .68638 .46304 Mtetra
.64 .76 .936 r
.68638 .46304 .68976 .46711 .6969 .465 .69354 .46092 Mtetra
.69354 .46092 .6969 .465 .70406 .46288 .70071 .45879 Mtetra
.70071 .45879 .70406 .46288 .71125 .46076 .70791 .45666 Mtetra
.639 .76 .936 r
.70791 .45666 .71125 .46076 .71845 .45864 .71512 .45453 Mtetra
.71512 .45453 .71845 .45864 .72567 .45652 .72235 .4524 Mtetra
.72235 .4524 .72567 .45652 .73291 .45438 .72961 .45025 Mtetra
.64 .76 .936 r
.72961 .45025 .73291 .45438 .74016 .45224 .73688 .4481 Mtetra
.641 .761 .935 r
.73688 .4481 .74016 .45224 .74744 .45008 .74416 .44592 Mtetra
.645 .763 .934 r
.74416 .44592 .74744 .45008 .75473 .44784 .75147 .44368 Mtetra
.649 .764 .933 r
.75147 .44368 .75473 .44784 .76203 .44554 .75878 .44136 Mtetra
.672 .773 .926 r
.75878 .44136 .76203 .44554 .76932 .44285 .76609 .43867 Mtetra
.696 .782 .917 r
.76609 .43867 .76932 .44285 .7766 .43971 .77338 .43551 Mtetra
.732 .794 .902 r
.77338 .43551 .7766 .43971 .78383 .43586 .78063 .43166 Mtetra
.811 .815 .853 r
.78063 .43166 .78383 .43586 .79091 .42993 .78772 .4257 Mtetra
.854 .821 .815 r
.78772 .4257 .79091 .42993 .79785 .42238 .79468 .41814 Mtetra
.917 .819 .734 r
.79468 .41814 .79785 .42238 .80445 .41092 .8013 .40666 Mtetra
.954 .804 .656 r
.8013 .40666 .80445 .41092 .81059 .39458 .80747 .3903 Mtetra
.967 .794 .616 r
.80747 .3903 .81059 .39458 .8164 .37504 .8133 .37073 Mtetra
.982 .769 .54 r
.8133 .37073 .8164 .37504 .82132 .34678 .81826 .34243 Mtetra
.985 .76 .516 r
.81826 .34243 .82132 .34678 .8258 .3149 .82277 .31051 Mtetra
.943 .627 .41 r
.18233 .49003 .18632 .49355 .18887 .52308 .18485 .51958 Mtetra
.942 .619 .394 r
.18485 .51958 .18887 .52308 .19178 .55015 .18772 .54668 Mtetra
.935 .58 .322 r
.18772 .54668 .19178 .55015 .19558 .56921 .1915 .56575 Mtetra
.925 .547 .265 r
.1915 .56575 .19558 .56921 .19978 .58493 .19568 .58148 Mtetra
.875 .435 .089 r
.19568 .58148 .19978 .58493 .20455 .59538 .20044 .59193 Mtetra
.622 .098 0 r
.20044 .59193 .20455 .59538 .20981 .60105 .20569 .59761 Mtetra
0 .225 .691 r
.20569 .59761 .20981 .60105 .21529 .60468 .21118 .60123 Mtetra
.34 .641 .964 r
.21118 .60123 .21529 .60468 .22106 .60541 .21696 .60196 Mtetra
.497 .712 .967 r
.21696 .60196 .22106 .60541 .22695 .60508 .22285 .60162 Mtetra
.573 .74 .955 r
.22285 .60162 .22695 .60508 .23291 .60406 .22882 .60059 Mtetra
.632 .758 .939 r
.22882 .60059 .23291 .60406 .23895 .60237 .23487 .5989 Mtetra
.639 .761 .936 r
.23487 .5989 .23895 .60237 .24501 .60058 .24093 .5971 Mtetra
.648 .763 .933 r
.24093 .5971 .24501 .60058 .25109 .59867 .24703 .59518 Mtetra
.652 .764 .931 r
.24703 .59518 .25109 .59867 .2572 .5967 .25314 .5932 Mtetra
.653 .764 .931 r
.25314 .5932 .2572 .5967 .26331 .59471 .25926 .5912 Mtetra
.25926 .5912 .26331 .59471 .26945 .59272 .2654 .5892 Mtetra
.2654 .5892 .26945 .59272 .27559 .59071 .27156 .58719 Mtetra
.27156 .58719 .27559 .59071 .28175 .5887 .27773 .58517 Mtetra
.652 .764 .931 r
.27773 .58517 .28175 .5887 .28792 .5867 .28391 .58316 Mtetra
.653 .764 .931 r
.28391 .58316 .28792 .5867 .29411 .58469 .2901 .58115 Mtetra
.2901 .58115 .29411 .58469 .30031 .58268 .29631 .57912 Mtetra
.651 .764 .932 r
.29631 .57912 .30031 .58268 .30653 .58068 .30254 .57711 Mtetra
.652 .764 .931 r
.30254 .57711 .30653 .58068 .31276 .57867 .30878 .57509 Mtetra
.30878 .57509 .31276 .57867 .319 .57665 .31503 .57306 Mtetra
.651 .764 .932 r
.31503 .57306 .319 .57665 .32526 .57464 .32129 .57105 Mtetra
.32129 .57105 .32526 .57464 .33153 .57263 .32758 .56903 Mtetra
.651 .764 .931 r
.32758 .56903 .33153 .57263 .33782 .5706 .33387 .56699 Mtetra
.65 .763 .932 r
.33387 .56699 .33782 .5706 .34412 .56859 .34018 .56497 Mtetra
.34018 .56497 .34412 .56859 .35043 .56657 .34651 .56295 Mtetra
.651 .763 .932 r
.34651 .56295 .35043 .56657 .35676 .56454 .35285 .56091 Mtetra
.65 .763 .932 r
.35285 .56091 .35676 .56454 .36311 .56252 .3592 .55887 Mtetra
.649 .763 .932 r
.3592 .55887 .36311 .56252 .36947 .5605 .36557 .55685 Mtetra
.65 .763 .932 r
.36557 .55685 .36947 .5605 .37584 .55847 .37195 .55481 Mtetra
.37195 .55481 .37584 .55847 .38223 .55644 .37835 .55277 Mtetra
.649 .763 .933 r
.37835 .55277 .38223 .55644 .38864 .55441 .38477 .55073 Mtetra
.649 .763 .932 r
.38477 .55073 .38864 .55441 .39506 .55238 .3912 .54869 Mtetra
.3912 .54869 .39506 .55238 .40149 .55034 .39764 .54664 Mtetra
.648 .763 .933 r
.39764 .54664 .40149 .55034 .40794 .54831 .4041 .5446 Mtetra
.4041 .5446 .40794 .54831 .4144 .54627 .41057 .54256 Mtetra
.649 .763 .932 r
.41057 .54256 .4144 .54627 .42088 .54422 .41706 .5405 Mtetra
.647 .762 .933 r
.41706 .5405 .42088 .54422 .42738 .54219 .42357 .53846 Mtetra
.648 .763 .933 r
.42357 .53846 .42738 .54219 .43389 .54015 .43009 .5364 Mtetra
.43009 .5364 .43389 .54015 .44042 .53809 .43663 .53434 Mtetra
.647 .762 .933 r
.43663 .53434 .44042 .53809 .44696 .53605 .44318 .53229 Mtetra
.44318 .53229 .44696 .53605 .45352 .53401 .44975 .53024 Mtetra
.648 .763 .933 r
.44975 .53024 .45352 .53401 .46009 .53194 .45633 .52817 Mtetra
.647 .762 .933 r
.45633 .52817 .46009 .53194 .46668 .52989 .46293 .52611 Mtetra
.646 .762 .933 r
.46293 .52611 .46668 .52989 .47329 .52785 .46955 .52405 Mtetra
.647 .762 .933 r
.46955 .52405 .47329 .52785 .47991 .52578 .47618 .52197 Mtetra
.646 .762 .933 r
.47618 .52197 .47991 .52578 .48655 .52372 .48283 .5199 Mtetra
.645 .762 .934 r
.48283 .5199 .48655 .52372 .4932 .52166 .48949 .51784 Mtetra
.646 .762 .933 r
.48949 .51784 .4932 .52166 .49987 .51959 .49617 .51576 Mtetra
.49617 .51576 .49987 .51959 .50656 .51752 .50287 .51368 Mtetra
.645 .762 .934 r
.50287 .51368 .50656 .51752 .51326 .51546 .50958 .51161 Mtetra
.50958 .51161 .51326 .51546 .51998 .51339 .51631 .50953 Mtetra
.51631 .50953 .51998 .51339 .52671 .51131 .52306 .50744 Mtetra
.644 .761 .934 r
.52306 .50744 .52671 .51131 .53346 .50924 .52982 .50536 Mtetra
.645 .762 .934 r
.52982 .50536 .53346 .50924 .54023 .50717 .5366 .50327 Mtetra
.5366 .50327 .54023 .50717 .54702 .50508 .5434 .50117 Mtetra
.643 .761 .934 r
.5434 .50117 .54702 .50508 .55382 .50301 .55021 .49909 Mtetra
.644 .761 .934 r
.55021 .49909 .55382 .50301 .56064 .50092 .55704 .497 Mtetra
.645 .762 .934 r
.55704 .497 .56064 .50092 .56748 .49883 .56389 .4949 Mtetra
.643 .761 .934 r
.56389 .4949 .56748 .49883 .57433 .49675 .57075 .49281 Mtetra
.57075 .49281 .57433 .49675 .5812 .49466 .57763 .49071 Mtetra
.57763 .49071 .5812 .49466 .58809 .49257 .58453 .48861 Mtetra
.58453 .48861 .58809 .49257 .59499 .49048 .59145 .48651 Mtetra
.59145 .48651 .59499 .49048 .60192 .48838 .59838 .4844 Mtetra
.59838 .4844 .60192 .48838 .60886 .48628 .60534 .48229 Mtetra
.642 .761 .935 r
.60534 .48229 .60886 .48628 .61582 .48418 .61231 .48018 Mtetra
.61231 .48018 .61582 .48418 .62279 .48207 .61929 .47807 Mtetra
.61929 .47807 .62279 .48207 .62978 .47997 .6263 .47595 Mtetra
.6263 .47595 .62978 .47997 .6368 .47786 .63332 .47383 Mtetra
.642 .76 .935 r
.63332 .47383 .6368 .47786 .64382 .47575 .64036 .47171 Mtetra
.641 .76 .935 r
.64036 .47171 .64382 .47575 .65087 .47364 .64742 .46959 Mtetra
.64742 .46959 .65087 .47364 .65794 .47152 .6545 .46747 Mtetra
.6545 .46747 .65794 .47152 .66502 .46941 .66159 .46534 Mtetra
.66159 .46534 .66502 .46941 .67212 .46729 .66871 .46321 Mtetra
.66871 .46321 .67212 .46729 .67924 .46517 .67584 .46108 Mtetra
.64 .76 .935 r
.67584 .46108 .67924 .46517 .68638 .46304 .68299 .45895 Mtetra
.68299 .45895 .68638 .46304 .69354 .46092 .69016 .45681 Mtetra
.69016 .45681 .69354 .46092 .70071 .45879 .69735 .45467 Mtetra
.69735 .45467 .70071 .45879 .70791 .45666 .70455 .45253 Mtetra
.639 .76 .935 r
.70455 .45253 .70791 .45666 .71512 .45453 .71178 .45039 Mtetra
.639 .76 .936 r
.71178 .45039 .71512 .45453 .72235 .4524 .71903 .44825 Mtetra
.639 .76 .935 r
.71903 .44825 .72235 .4524 .72961 .45025 .72629 .44609 Mtetra
.64 .76 .935 r
.72629 .44609 .72961 .45025 .73688 .4481 .73357 .44393 Mtetra
.641 .76 .935 r
.73357 .44393 .73688 .4481 .74416 .44592 .74087 .44174 Mtetra
.645 .762 .934 r
.74087 .44174 .74416 .44592 .75147 .44368 .74819 .43948 Mtetra
.649 .763 .933 r
.74819 .43948 .75147 .44368 .75878 .44136 .75552 .43716 Mtetra
.672 .772 .926 r
.75552 .43716 .75878 .44136 .76609 .43867 .76284 .43445 Mtetra
.696 .782 .917 r
.76284 .43445 .76609 .43867 .77338 .43551 .77014 .43129 Mtetra
.731 .794 .902 r
.77014 .43129 .77338 .43551 .78063 .43166 .77741 .42742 Mtetra
.811 .814 .853 r
.77741 .42742 .78063 .43166 .78772 .4257 .78452 .42145 Mtetra
.854 .821 .815 r
.78452 .42145 .78772 .4257 .79468 .41814 .79149 .41387 Mtetra
.917 .819 .734 r
.79149 .41387 .79468 .41814 .8013 .40666 .79813 .40238 Mtetra
.954 .804 .656 r
.79813 .40238 .8013 .40666 .80747 .3903 .80433 .38599 Mtetra
.967 .794 .616 r
.80433 .38599 .80747 .3903 .8133 .37073 .81018 .36639 Mtetra
.982 .769 .54 r
.81018 .36639 .8133 .37073 .81826 .34243 .81517 .33806 Mtetra
.985 .76 .516 r
.81517 .33806 .81826 .34243 .82277 .31051 .81972 .3061 Mtetra
.942 .627 .41 r
.17833 .48651 .18233 .49003 .18485 .51958 .1808 .51609 Mtetra
.942 .619 .394 r
.1808 .51609 .18485 .51958 .18772 .54668 .18364 .54321 Mtetra
.935 .58 .322 r
.18364 .54321 .18772 .54668 .1915 .56575 .1874 .56229 Mtetra
.925 .547 .265 r
.1874 .56229 .1915 .56575 .19568 .58148 .19156 .57803 Mtetra
.875 .436 .09 r
.19156 .57803 .19568 .58148 .20044 .59193 .19631 .58849 Mtetra
.624 .099 0 r
.19631 .58849 .20044 .59193 .20569 .59761 .20156 .59416 Mtetra
0 .223 .689 r
.20156 .59416 .20569 .59761 .21118 .60123 .20705 .59778 Mtetra
.338 .641 .965 r
.20705 .59778 .21118 .60123 .21696 .60196 .21283 .59851 Mtetra
.496 .713 .968 r
.21283 .59851 .21696 .60196 .22285 .60162 .21873 .59816 Mtetra
.572 .741 .956 r
.21873 .59816 .22285 .60162 .22882 .60059 .22471 .59713 Mtetra
.632 .759 .939 r
.22471 .59713 .22882 .60059 .23487 .5989 .23076 .59543 Mtetra
.639 .761 .937 r
.23076 .59543 .23487 .5989 .24093 .5971 .23684 .59362 Mtetra
.648 .764 .934 r
.23684 .59362 .24093 .5971 .24703 .59518 .24294 .59169 Mtetra
.652 .765 .932 r
.24294 .59169 .24703 .59518 .25314 .5932 .24906 .5897 Mtetra
.653 .765 .932 r
.24906 .5897 .25314 .5932 .25926 .5912 .25519 .58769 Mtetra
.25519 .58769 .25926 .5912 .2654 .5892 .26134 .58568 Mtetra
.653 .765 .931 r
.26134 .58568 .2654 .5892 .27156 .58719 .2675 .58366 Mtetra
.2675 .58366 .27156 .58719 .27773 .58517 .27368 .58163 Mtetra
.652 .765 .932 r
.27368 .58163 .27773 .58517 .28391 .58316 .27987 .57962 Mtetra
.27987 .57962 .28391 .58316 .2901 .58115 .28608 .5776 Mtetra
.653 .765 .932 r
.28608 .5776 .2901 .58115 .29631 .57912 .2923 .57556 Mtetra
.651 .765 .932 r
.2923 .57556 .29631 .57912 .30254 .57711 .29853 .57354 Mtetra
.652 .765 .932 r
.29853 .57354 .30254 .57711 .30878 .57509 .30478 .57152 Mtetra
.30478 .57152 .30878 .57509 .31503 .57306 .31104 .56948 Mtetra
.651 .764 .932 r
.31104 .56948 .31503 .57306 .32129 .57105 .31731 .56745 Mtetra
.31731 .56745 .32129 .57105 .32758 .56903 .3236 .56543 Mtetra
.651 .765 .932 r
.3236 .56543 .32758 .56903 .33387 .56699 .32991 .56338 Mtetra
.65 .764 .932 r
.32991 .56338 .33387 .56699 .34018 .56497 .33623 .56135 Mtetra
.65 .764 .933 r
.33623 .56135 .34018 .56497 .34651 .56295 .34256 .55932 Mtetra
.651 .764 .932 r
.34256 .55932 .34651 .56295 .35285 .56091 .34891 .55727 Mtetra
.65 .764 .933 r
.34891 .55727 .35285 .56091 .3592 .55887 .35528 .55523 Mtetra
.649 .764 .933 r
.35528 .55523 .3592 .55887 .36557 .55685 .36165 .55319 Mtetra
.65 .764 .933 r
.36165 .55319 .36557 .55685 .37195 .55481 .36805 .55114 Mtetra
.36805 .55114 .37195 .55481 .37835 .55277 .37446 .54909 Mtetra
.649 .764 .933 r
.37446 .54909 .37835 .55277 .38477 .55073 .38088 .54705 Mtetra
.38088 .54705 .38477 .55073 .3912 .54869 .38732 .545 Mtetra
.38732 .545 .3912 .54869 .39764 .54664 .39377 .54294 Mtetra
.648 .764 .933 r
.39377 .54294 .39764 .54664 .4041 .5446 .40024 .5409 Mtetra
.40024 .5409 .4041 .5446 .41057 .54256 .40673 .53884 Mtetra
.649 .764 .933 r
.40673 .53884 .41057 .54256 .41706 .5405 .41323 .53677 Mtetra
.647 .763 .934 r
.41323 .53677 .41706 .5405 .42357 .53846 .41974 .53472 Mtetra
.648 .763 .933 r
.41974 .53472 .42357 .53846 .43009 .5364 .42627 .53266 Mtetra
.648 .764 .933 r
.42627 .53266 .43009 .5364 .43663 .53434 .43282 .53059 Mtetra
.647 .763 .934 r
.43282 .53059 .43663 .53434 .44318 .53229 .43938 .52853 Mtetra
.43938 .52853 .44318 .53229 .44975 .53024 .44596 .52646 Mtetra
.648 .763 .933 r
.44596 .52646 .44975 .53024 .45633 .52817 .45255 .52438 Mtetra
.646 .763 .934 r
.45255 .52438 .45633 .52817 .46293 .52611 .45916 .52232 Mtetra
.45916 .52232 .46293 .52611 .46955 .52405 .46579 .52025 Mtetra
.647 .763 .934 r
.46579 .52025 .46955 .52405 .47618 .52197 .47243 .51816 Mtetra
.646 .763 .934 r
.47243 .51816 .47618 .52197 .48283 .5199 .47909 .51608 Mtetra
.645 .763 .934 r
.47909 .51608 .48283 .5199 .48949 .51784 .48576 .51401 Mtetra
.646 .763 .934 r
.48576 .51401 .48949 .51784 .49617 .51576 .49246 .51192 Mtetra
.49246 .51192 .49617 .51576 .50287 .51368 .49916 .50983 Mtetra
.645 .762 .934 r
.49916 .50983 .50287 .51368 .50958 .51161 .50589 .50776 Mtetra
.645 .763 .934 r
.50589 .50776 .50958 .51161 .51631 .50953 .51263 .50566 Mtetra
.51263 .50566 .51631 .50953 .52306 .50744 .51938 .50356 Mtetra
.644 .762 .935 r
.51938 .50356 .52306 .50744 .52982 .50536 .52616 .50148 Mtetra
.645 .762 .934 r
.52616 .50148 .52982 .50536 .5366 .50327 .53295 .49938 Mtetra
.645 .763 .934 r
.53295 .49938 .5366 .50327 .5434 .50117 .53976 .49727 Mtetra
.643 .762 .935 r
.53976 .49727 .5434 .50117 .55021 .49909 .54658 .49518 Mtetra
.644 .762 .935 r
.54658 .49518 .55021 .49909 .55704 .497 .55342 .49308 Mtetra
.55342 .49308 .55704 .497 .56389 .4949 .56028 .49096 Mtetra
.643 .762 .935 r
.56028 .49096 .56389 .4949 .57075 .49281 .56716 .48886 Mtetra
.56716 .48886 .57075 .49281 .57763 .49071 .57405 .48676 Mtetra
.57405 .48676 .57763 .49071 .58453 .48861 .58096 .48465 Mtetra
.58096 .48465 .58453 .48861 .59145 .48651 .58789 .48254 Mtetra
.58789 .48254 .59145 .48651 .59838 .4844 .59483 .48042 Mtetra
.642 .762 .935 r
.59483 .48042 .59838 .4844 .60534 .48229 .6018 .4783 Mtetra
.6018 .4783 .60534 .48229 .61231 .48018 .60878 .47618 Mtetra
.60878 .47618 .61231 .48018 .61929 .47807 .61578 .47405 Mtetra
.642 .761 .935 r
.61578 .47405 .61929 .47807 .6263 .47595 .62279 .47193 Mtetra
.62279 .47193 .6263 .47595 .63332 .47383 .62983 .4698 Mtetra
.641 .761 .935 r
.62983 .4698 .63332 .47383 .64036 .47171 .63688 .46767 Mtetra
.641 .761 .936 r
.63688 .46767 .64036 .47171 .64742 .46959 .64395 .46554 Mtetra
.64395 .46554 .64742 .46959 .6545 .46747 .65104 .4634 Mtetra
.65104 .4634 .6545 .46747 .66159 .46534 .65815 .46127 Mtetra
.65815 .46127 .66159 .46534 .66871 .46321 .66528 .45913 Mtetra
.64 .761 .936 r
.66528 .45913 .66871 .46321 .67584 .46108 .67242 .45699 Mtetra
.67242 .45699 .67584 .46108 .68299 .45895 .67958 .45484 Mtetra
.67958 .45484 .68299 .45895 .69016 .45681 .68677 .4527 Mtetra
.68677 .4527 .69016 .45681 .69735 .45467 .69397 .45055 Mtetra
.639 .761 .936 r
.69397 .45055 .69735 .45467 .70455 .45253 .70119 .4484 Mtetra
.70119 .4484 .70455 .45253 .71178 .45039 .70843 .44625 Mtetra
.639 .76 .936 r
.70843 .44625 .71178 .45039 .71903 .44825 .71568 .44409 Mtetra
.639 .761 .936 r
.71568 .44409 .71903 .44825 .72629 .44609 .72296 .44193 Mtetra
.64 .761 .936 r
.72296 .44193 .72629 .44609 .73357 .44393 .73026 .43976 Mtetra
.641 .761 .936 r
.73026 .43976 .73357 .44393 .74087 .44174 .73757 .43756 Mtetra
.645 .763 .935 r
.73757 .43756 .74087 .44174 .74819 .43948 .7449 .43529 Mtetra
.648 .764 .934 r
.7449 .43529 .74819 .43948 .75552 .43716 .75224 .43296 Mtetra
.672 .773 .926 r
.75224 .43296 .75552 .43716 .76284 .43445 .75957 .43024 Mtetra
.696 .783 .918 r
.75957 .43024 .76284 .43445 .77014 .43129 .76689 .42706 Mtetra
.732 .795 .902 r
.76689 .42706 .77014 .43129 .77741 .42742 .77417 .42318 Mtetra
.812 .815 .853 r
.77417 .42318 .77741 .42742 .78452 .42145 .7813 .4172 Mtetra
.854 .822 .816 r
.7813 .4172 .78452 .42145 .79149 .41387 .78829 .4096 Mtetra
.917 .819 .734 r
.78829 .4096 .79149 .41387 .79813 .40238 .79495 .39809 Mtetra
.954 .805 .656 r
.79495 .39809 .79813 .40238 .80433 .38599 .80117 .38167 Mtetra
.967 .794 .616 r
.80117 .38167 .80433 .38599 .81018 .36639 .80705 .36205 Mtetra
.982 .769 .54 r
.80705 .36205 .81018 .36639 .81517 .33806 .81208 .33368 Mtetra
.985 .76 .516 r
.81208 .33368 .81517 .33806 .81972 .3061 .81666 .30168 Mtetra
.942 .627 .41 r
.1743 .48298 .17833 .48651 .1808 .51609 .17674 .51257 Mtetra
.942 .619 .394 r
.17674 .51257 .1808 .51609 .18364 .54321 .17955 .53972 Mtetra
.935 .58 .322 r
.17955 .53972 .18364 .54321 .1874 .56229 .18328 .55881 Mtetra
.925 .547 .265 r
.18328 .55881 .1874 .56229 .19156 .57803 .18743 .57457 Mtetra
.875 .436 .089 r
.18743 .57457 .19156 .57803 .19631 .58849 .19216 .58503 Mtetra
.623 .099 0 r
.19216 .58503 .19631 .58849 .20156 .59416 .19742 .5907 Mtetra
0 .224 .689 r
.19742 .5907 .20156 .59416 .20705 .59778 .2029 .59432 Mtetra
.339 .641 .965 r
.2029 .59432 .20705 .59778 .21283 .59851 .20869 .59504 Mtetra
.497 .713 .968 r
.20869 .59504 .21283 .59851 .21873 .59816 .21459 .59469 Mtetra
.572 .741 .956 r
.21459 .59469 .21873 .59816 .22471 .59713 .22058 .59365 Mtetra
.632 .759 .939 r
.22058 .59365 .22471 .59713 .23076 .59543 .22664 .59194 Mtetra
.639 .761 .937 r
.22664 .59194 .23076 .59543 .23684 .59362 .23273 .59012 Mtetra
.648 .764 .934 r
.23273 .59012 .23684 .59362 .24294 .59169 .23883 .58819 Mtetra
.652 .765 .932 r
.23883 .58819 .24294 .59169 .24906 .5897 .24496 .58619 Mtetra
.653 .765 .932 r
.24496 .58619 .24906 .5897 .25519 .58769 .25111 .58417 Mtetra
.25111 .58417 .25519 .58769 .26134 .58568 .25726 .58215 Mtetra
.653 .765 .931 r
.25726 .58215 .26134 .58568 .2675 .58366 .26343 .58012 Mtetra
.26343 .58012 .2675 .58366 .27368 .58163 .26962 .57808 Mtetra
.652 .765 .932 r
.26962 .57808 .27368 .58163 .27987 .57962 .27582 .57606 Mtetra
.27582 .57606 .27987 .57962 .28608 .5776 .28203 .57403 Mtetra
.653 .765 .932 r
.28203 .57403 .28608 .5776 .2923 .57556 .28826 .57199 Mtetra
.651 .764 .932 r
.28826 .57199 .2923 .57556 .29853 .57354 .2945 .56996 Mtetra
.652 .765 .932 r
.2945 .56996 .29853 .57354 .30478 .57152 .30076 .56793 Mtetra
.30076 .56793 .30478 .57152 .31104 .56948 .30703 .56588 Mtetra
.651 .764 .932 r
.30703 .56588 .31104 .56948 .31731 .56745 .31332 .56384 Mtetra
.31332 .56384 .31731 .56745 .3236 .56543 .31961 .56181 Mtetra
.31961 .56181 .3236 .56543 .32991 .56338 .32593 .55976 Mtetra
.65 .764 .932 r
.32593 .55976 .32991 .56338 .33623 .56135 .33226 .55771 Mtetra
.65 .764 .933 r
.33226 .55771 .33623 .56135 .34256 .55932 .3386 .55567 Mtetra
.651 .764 .932 r
.3386 .55567 .34256 .55932 .34891 .55727 .34496 .55362 Mtetra
.65 .764 .933 r
.34496 .55362 .34891 .55727 .35528 .55523 .35133 .55157 Mtetra
.649 .764 .933 r
.35133 .55157 .35528 .55523 .36165 .55319 .35772 .54952 Mtetra
.65 .764 .933 r
.35772 .54952 .36165 .55319 .36805 .55114 .36412 .54746 Mtetra
.36412 .54746 .36805 .55114 .37446 .54909 .37054 .5454 Mtetra
.649 .764 .933 r
.37054 .5454 .37446 .54909 .38088 .54705 .37697 .54336 Mtetra
.37697 .54336 .38088 .54705 .38732 .545 .38342 .54129 Mtetra
.38342 .54129 .38732 .545 .39377 .54294 .38989 .53922 Mtetra
.648 .763 .933 r
.38989 .53922 .39377 .54294 .40024 .5409 .39637 .53717 Mtetra
.648 .764 .933 r
.39637 .53717 .40024 .5409 .40673 .53884 .40286 .5351 Mtetra
.649 .764 .933 r
.40286 .5351 .40673 .53884 .41323 .53677 .40937 .53303 Mtetra
.647 .763 .934 r
.40937 .53303 .41323 .53677 .41974 .53472 .4159 .53097 Mtetra
.648 .763 .933 r
.4159 .53097 .41974 .53472 .42627 .53266 .42244 .5289 Mtetra
.42244 .5289 .42627 .53266 .43282 .53059 .42899 .52682 Mtetra
.647 .763 .934 r
.42899 .52682 .43282 .53059 .43938 .52853 .43557 .52475 Mtetra
.43557 .52475 .43938 .52853 .44596 .52646 .44215 .52267 Mtetra
.648 .763 .933 r
.44215 .52267 .44596 .52646 .45255 .52438 .44876 .52059 Mtetra
.646 .763 .934 r
.44876 .52059 .45255 .52438 .45916 .52232 .45538 .51851 Mtetra
.45538 .51851 .45916 .52232 .46579 .52025 .46202 .51643 Mtetra
.647 .763 .934 r
.46202 .51643 .46579 .52025 .47243 .51816 .46867 .51434 Mtetra
.646 .763 .934 r
.46867 .51434 .47243 .51816 .47909 .51608 .47534 .51225 Mtetra
.645 .763 .934 r
.47534 .51225 .47909 .51608 .48576 .51401 .48202 .51017 Mtetra
.646 .763 .934 r
.48202 .51017 .48576 .51401 .49246 .51192 .48872 .50807 Mtetra
.48872 .50807 .49246 .51192 .49916 .50983 .49544 .50597 Mtetra
.645 .762 .934 r
.49544 .50597 .49916 .50983 .50589 .50776 .50218 .50388 Mtetra
.645 .763 .934 r
.50218 .50388 .50589 .50776 .51263 .50566 .50893 .50178 Mtetra
.50893 .50178 .51263 .50566 .51938 .50356 .5157 .49967 Mtetra
.644 .762 .935 r
.5157 .49967 .51938 .50356 .52616 .50148 .52248 .49758 Mtetra
.645 .762 .934 r
.52248 .49758 .52616 .50148 .53295 .49938 .52928 .49547 Mtetra
.52928 .49547 .53295 .49938 .53976 .49727 .5361 .49335 Mtetra
.643 .762 .935 r
.5361 .49335 .53976 .49727 .54658 .49518 .54294 .49125 Mtetra
.644 .762 .935 r
.54294 .49125 .54658 .49518 .55342 .49308 .54979 .48914 Mtetra
.644 .762 .934 r
.54979 .48914 .55342 .49308 .56028 .49096 .55666 .48701 Mtetra
.643 .762 .935 r
.55666 .48701 .56028 .49096 .56716 .48886 .56355 .4849 Mtetra
.56355 .4849 .56716 .48886 .57405 .48676 .57045 .48279 Mtetra
.57045 .48279 .57405 .48676 .58096 .48465 .57737 .48067 Mtetra
.57737 .48067 .58096 .48465 .58789 .48254 .58431 .47854 Mtetra
.58431 .47854 .58789 .48254 .59483 .48042 .59127 .47642 Mtetra
.642 .762 .935 r
.59127 .47642 .59483 .48042 .6018 .4783 .59824 .47429 Mtetra
.59824 .47429 .6018 .4783 .60878 .47618 .60524 .47216 Mtetra
.642 .761 .935 r
.60524 .47216 .60878 .47618 .61578 .47405 .61225 .47002 Mtetra
.61225 .47002 .61578 .47405 .62279 .47193 .61928 .46789 Mtetra
.61928 .46789 .62279 .47193 .62983 .4698 .62632 .46575 Mtetra
.641 .761 .935 r
.62632 .46575 .62983 .4698 .63688 .46767 .63339 .46361 Mtetra
.63339 .46361 .63688 .46767 .64395 .46554 .64047 .46147 Mtetra
.641 .761 .936 r
.64047 .46147 .64395 .46554 .65104 .4634 .64757 .45932 Mtetra
.64757 .45932 .65104 .4634 .65815 .46127 .65469 .45718 Mtetra
.65469 .45718 .65815 .46127 .66528 .45913 .66183 .45503 Mtetra
.64 .761 .936 r
.66183 .45503 .66528 .45913 .67242 .45699 .66899 .45288 Mtetra
.66899 .45288 .67242 .45699 .67958 .45484 .67616 .45072 Mtetra
.67616 .45072 .67958 .45484 .68677 .4527 .68336 .44857 Mtetra
.68336 .44857 .68677 .4527 .69397 .45055 .69057 .44641 Mtetra
.639 .761 .936 r
.69057 .44641 .69397 .45055 .70119 .4484 .6978 .44425 Mtetra
.639 .76 .936 r
.6978 .44425 .70119 .4484 .70843 .44625 .70505 .44208 Mtetra
.70505 .44208 .70843 .44625 .71568 .44409 .71232 .43992 Mtetra
.71232 .43992 .71568 .44409 .72296 .44193 .71961 .43775 Mtetra
.64 .761 .936 r
.71961 .43775 .72296 .44193 .73026 .43976 .72692 .43556 Mtetra
.641 .761 .936 r
.72692 .43556 .73026 .43976 .73757 .43756 .73425 .43335 Mtetra
.645 .763 .935 r
.73425 .43335 .73757 .43756 .7449 .43529 .74159 .43107 Mtetra
.648 .764 .934 r
.74159 .43107 .7449 .43529 .75224 .43296 .74895 .42873 Mtetra
.672 .773 .926 r
.74895 .42873 .75224 .43296 .75957 .43024 .75629 .426 Mtetra
.696 .783 .917 r
.75629 .426 .75957 .43024 .76689 .42706 .76363 .42281 Mtetra
.732 .794 .902 r
.76363 .42281 .76689 .42706 .77417 .42318 .77092 .41892 Mtetra
.811 .815 .853 r
.77092 .41892 .77417 .42318 .7813 .4172 .77806 .41292 Mtetra
.854 .822 .816 r
.77806 .41292 .7813 .4172 .78829 .4096 .78507 .40531 Mtetra
.917 .819 .734 r
.78507 .40531 .78829 .4096 .79495 .39809 .79176 .39377 Mtetra
.954 .805 .656 r
.79176 .39377 .79495 .39809 .80117 .38167 .798 .37734 Mtetra
.967 .794 .616 r
.798 .37734 .80117 .38167 .80705 .36205 .80391 .35768 Mtetra
.982 .769 .54 r
.80391 .35768 .80705 .36205 .81208 .33368 .80897 .32928 Mtetra
.985 .76 .516 r
.80897 .32928 .81208 .33368 .81666 .30168 .81359 .29724 Mtetra
.942 .627 .41 r
.17026 .47942 .1743 .48298 .17674 .51257 .17266 .50904 Mtetra
.942 .619 .394 r
.17266 .50904 .17674 .51257 .17955 .53972 .17544 .5362 Mtetra
.935 .58 .322 r
.17544 .5362 .17955 .53972 .18328 .55881 .17915 .55531 Mtetra
.925 .547 .265 r
.17915 .55531 .18328 .55881 .18743 .57457 .18328 .57108 Mtetra
.875 .435 .089 r
.18328 .57108 .18743 .57457 .19216 .58503 .188 .58155 Mtetra
.622 .098 0 r
.188 .58155 .19216 .58503 .19742 .5907 .19325 .58722 Mtetra
0 .225 .691 r
.19325 .58722 .19742 .5907 .2029 .59432 .19874 .59083 Mtetra
.34 .641 .964 r
.19874 .59083 .2029 .59432 .20869 .59504 .20453 .59154 Mtetra
.497 .713 .967 r
.20453 .59154 .20869 .59504 .21459 .59469 .21044 .59118 Mtetra
.573 .741 .955 r
.21044 .59118 .21459 .59469 .22058 .59365 .21643 .59014 Mtetra
.632 .759 .939 r
.21643 .59014 .22058 .59365 .22664 .59194 .2225 .58842 Mtetra
.639 .761 .936 r
.2225 .58842 .22664 .59194 .23273 .59012 .2286 .5866 Mtetra
.648 .763 .933 r
.2286 .5866 .23273 .59012 .23883 .58819 .23471 .58465 Mtetra
.652 .764 .931 r
.23471 .58465 .23883 .58819 .24496 .58619 .24085 .58264 Mtetra
.653 .764 .931 r
.24085 .58264 .24496 .58619 .25111 .58417 .247 .58062 Mtetra
.247 .58062 .25111 .58417 .25726 .58215 .25317 .57859 Mtetra
.25317 .57859 .25726 .58215 .26343 .58012 .25935 .57655 Mtetra
.25935 .57655 .26343 .58012 .26962 .57808 .26554 .57451 Mtetra
.652 .764 .931 r
.26554 .57451 .26962 .57808 .27582 .57606 .27175 .57248 Mtetra
.653 .764 .931 r
.27175 .57248 .27582 .57606 .28203 .57403 .27797 .57044 Mtetra
.27797 .57044 .28203 .57403 .28826 .57199 .28421 .56838 Mtetra
.651 .764 .932 r
.28421 .56838 .28826 .57199 .2945 .56996 .29046 .56635 Mtetra
.652 .764 .931 r
.29046 .56635 .2945 .56996 .30076 .56793 .29673 .5643 Mtetra
.29673 .5643 .30076 .56793 .30703 .56588 .30301 .56225 Mtetra
.651 .764 .932 r
.30301 .56225 .30703 .56588 .31332 .56384 .3093 .56021 Mtetra
.3093 .56021 .31332 .56384 .31961 .56181 .31561 .55816 Mtetra
.31561 .55816 .31961 .56181 .32593 .55976 .32193 .5561 Mtetra
.32193 .5561 .32593 .55976 .33226 .55771 .32827 .55405 Mtetra
.65 .763 .932 r
.32827 .55405 .33226 .55771 .3386 .55567 .33462 .552 Mtetra
.651 .764 .932 r
.33462 .552 .3386 .55567 .34496 .55362 .34099 .54994 Mtetra
.65 .763 .932 r
.34099 .54994 .34496 .55362 .35133 .55157 .34737 .54788 Mtetra
.649 .763 .932 r
.34737 .54788 .35133 .55157 .35772 .54952 .35377 .54582 Mtetra
.65 .763 .932 r
.35377 .54582 .35772 .54952 .36412 .54746 .36018 .54375 Mtetra
.36018 .54375 .36412 .54746 .37054 .5454 .36661 .54169 Mtetra
.649 .763 .933 r
.36661 .54169 .37054 .5454 .37697 .54336 .37305 .53963 Mtetra
.649 .763 .932 r
.37305 .53963 .37697 .54336 .38342 .54129 .37951 .53756 Mtetra
.37951 .53756 .38342 .54129 .38989 .53922 .38599 .53548 Mtetra
.648 .763 .933 r
.38599 .53548 .38989 .53922 .39637 .53717 .39247 .53342 Mtetra
.39247 .53342 .39637 .53717 .40286 .5351 .39898 .53134 Mtetra
.649 .763 .933 r
.39898 .53134 .40286 .5351 .40937 .53303 .4055 .52925 Mtetra
.647 .763 .933 r
.4055 .52925 .40937 .53303 .4159 .53097 .41203 .52719 Mtetra
.648 .763 .933 r
.41203 .52719 .4159 .53097 .42244 .5289 .41858 .52511 Mtetra
.41858 .52511 .42244 .5289 .42899 .52682 .42515 .52302 Mtetra
.647 .762 .933 r
.42515 .52302 .42899 .52682 .43557 .52475 .43173 .52094 Mtetra
.43173 .52094 .43557 .52475 .44215 .52267 .43833 .51885 Mtetra
.648 .763 .933 r
.43833 .51885 .44215 .52267 .44876 .52059 .44495 .51676 Mtetra
.647 .762 .933 r
.44495 .51676 .44876 .52059 .45538 .51851 .45158 .51467 Mtetra
.646 .762 .933 r
.45158 .51467 .45538 .51851 .46202 .51643 .45822 .51258 Mtetra
.647 .762 .933 r
.45822 .51258 .46202 .51643 .46867 .51434 .46489 .51048 Mtetra
.646 .762 .933 r
.46489 .51048 .46867 .51434 .47534 .51225 .47157 .50838 Mtetra
.645 .762 .934 r
.47157 .50838 .47534 .51225 .48202 .51017 .47826 .50629 Mtetra
.646 .762 .933 r
.47826 .50629 .48202 .51017 .48872 .50807 .48497 .50418 Mtetra
.646 .762 .934 r
.48497 .50418 .48872 .50807 .49544 .50597 .4917 .50207 Mtetra
.645 .762 .934 r
.4917 .50207 .49544 .50597 .50218 .50388 .49845 .49998 Mtetra
.49845 .49998 .50218 .50388 .50893 .50178 .50521 .49786 Mtetra
.50521 .49786 .50893 .50178 .5157 .49967 .51199 .49574 Mtetra
.644 .761 .934 r
.51199 .49574 .5157 .49967 .52248 .49758 .51878 .49364 Mtetra
.645 .762 .934 r
.51878 .49364 .52248 .49758 .52928 .49547 .5256 .49152 Mtetra
.5256 .49152 .52928 .49547 .5361 .49335 .53243 .4894 Mtetra
.643 .761 .934 r
.53243 .4894 .5361 .49335 .54294 .49125 .53927 .48729 Mtetra
.644 .761 .934 r
.53927 .48729 .54294 .49125 .54979 .48914 .54614 .48517 Mtetra
.644 .762 .934 r
.54614 .48517 .54979 .48914 .55666 .48701 .55302 .48303 Mtetra
.643 .761 .934 r
.55302 .48303 .55666 .48701 .56355 .4849 .55992 .48091 Mtetra
.55992 .48091 .56355 .4849 .57045 .48279 .56683 .47879 Mtetra
.56683 .47879 .57045 .48279 .57737 .48067 .57377 .47666 Mtetra
.57377 .47666 .57737 .48067 .58431 .47854 .58072 .47452 Mtetra
.643 .761 .935 r
.58072 .47452 .58431 .47854 .59127 .47642 .58769 .47239 Mtetra
.58769 .47239 .59127 .47642 .59824 .47429 .59467 .47025 Mtetra
.642 .761 .935 r
.59467 .47025 .59824 .47429 .60524 .47216 .60168 .46811 Mtetra
.60168 .46811 .60524 .47216 .61225 .47002 .6087 .46596 Mtetra
.6087 .46596 .61225 .47002 .61928 .46789 .61574 .46382 Mtetra
.61574 .46382 .61928 .46789 .62632 .46575 .6228 .46167 Mtetra
.6228 .46167 .62632 .46575 .63339 .46361 .62987 .45952 Mtetra
.641 .76 .935 r
.62987 .45952 .63339 .46361 .64047 .46147 .63697 .45737 Mtetra
.63697 .45737 .64047 .46147 .64757 .45932 .64408 .45521 Mtetra
.64408 .45521 .64757 .45932 .65469 .45718 .65122 .45305 Mtetra
.65122 .45305 .65469 .45718 .66183 .45503 .65837 .45089 Mtetra
.64 .76 .935 r
.65837 .45089 .66183 .45503 .66899 .45288 .66554 .44873 Mtetra
.66554 .44873 .66899 .45288 .67616 .45072 .67272 .44657 Mtetra
.67272 .44657 .67616 .45072 .68336 .44857 .67993 .4444 Mtetra
.67993 .4444 .68336 .44857 .69057 .44641 .68716 .44223 Mtetra
.68716 .44223 .69057 .44641 .6978 .44425 .6944 .44006 Mtetra
.639 .76 .936 r
.6944 .44006 .6978 .44425 .70505 .44208 .70167 .43789 Mtetra
.70167 .43789 .70505 .44208 .71232 .43992 .70895 .43571 Mtetra
.70895 .43571 .71232 .43992 .71961 .43775 .71625 .43353 Mtetra
.64 .76 .935 r
.71625 .43353 .71961 .43775 .72692 .43556 .72357 .43133 Mtetra
.641 .76 .935 r
.72357 .43133 .72692 .43556 .73425 .43335 .73091 .42912 Mtetra
.645 .762 .934 r
.73091 .42912 .73425 .43335 .74159 .43107 .73827 .42682 Mtetra
.649 .764 .933 r
.73827 .42682 .74159 .43107 .74895 .42873 .74564 .42447 Mtetra
.672 .773 .926 r
.74564 .42447 .74895 .42873 .75629 .426 .753 .42173 Mtetra
.696 .782 .917 r
.753 .42173 .75629 .426 .76363 .42281 .76034 .41853 Mtetra
.731 .794 .902 r
.76034 .41853 .76363 .42281 .77092 .41892 .76765 .41462 Mtetra
.811 .815 .853 r
.76765 .41462 .77092 .41892 .77806 .41292 .77481 .40861 Mtetra
.854 .821 .815 r
.77481 .40861 .77806 .41292 .78507 .40531 .78184 .40098 Mtetra
.917 .819 .734 r
.78184 .40098 .78507 .40531 .79176 .39377 .78855 .38943 Mtetra
.954 .804 .656 r
.78855 .38943 .79176 .39377 .798 .37734 .79481 .37297 Mtetra
.967 .794 .616 r
.79481 .37297 .798 .37734 .80391 .35768 .80075 .35329 Mtetra
.982 .769 .54 r
.80075 .35329 .80391 .35768 .80897 .32928 .80584 .32484 Mtetra
.985 .76 .516 r
.80584 .32484 .80897 .32928 .81359 .29724 .8105 .29277 Mtetra
.942 .627 .41 r
.1662 .47586 .17026 .47942 .17266 .50904 .16857 .5055 Mtetra
.942 .619 .394 r
.16857 .5055 .17266 .50904 .17544 .5362 .17131 .53269 Mtetra
.935 .58 .322 r
.17131 .53269 .17544 .5362 .17915 .55531 .17499 .55181 Mtetra
.925 .547 .265 r
.17499 .55181 .17915 .55531 .18328 .57108 .1791 .56759 Mtetra
.875 .436 .089 r
.1791 .56759 .18328 .57108 .188 .58155 .18382 .57806 Mtetra
.623 .098 0 r
.18382 .57806 .188 .58155 .19325 .58722 .18907 .58373 Mtetra
0 .224 .689 r
.18907 .58373 .19325 .58722 .19874 .59083 .19455 .58734 Mtetra
.339 .641 .965 r
.19455 .58734 .19874 .59083 .20453 .59154 .20035 .58805 Mtetra
.497 .713 .968 r
.20035 .58805 .20453 .59154 .21044 .59118 .20627 .58768 Mtetra
.572 .741 .956 r
.20627 .58768 .21044 .59118 .21643 .59014 .21227 .58663 Mtetra
.632 .759 .939 r
.21227 .58663 .21643 .59014 .2225 .58842 .21834 .5849 Mtetra
.639 .761 .937 r
.21834 .5849 .2225 .58842 .2286 .5866 .22445 .58307 Mtetra
.648 .764 .934 r
.22445 .58307 .2286 .5866 .23471 .58465 .23057 .58112 Mtetra
.652 .765 .932 r
.23057 .58112 .23471 .58465 .24085 .58264 .23672 .5791 Mtetra
.653 .765 .932 r
.23672 .5791 .24085 .58264 .247 .58062 .24288 .57707 Mtetra
.24288 .57707 .247 .58062 .25317 .57859 .24905 .57503 Mtetra
.653 .765 .931 r
.24905 .57503 .25317 .57859 .25935 .57655 .25524 .57298 Mtetra
.25524 .57298 .25935 .57655 .26554 .57451 .26145 .57093 Mtetra
.652 .765 .932 r
.26145 .57093 .26554 .57451 .27175 .57248 .26766 .56889 Mtetra
.26766 .56889 .27175 .57248 .27797 .57044 .27389 .56684 Mtetra
.653 .765 .932 r
.27389 .56684 .27797 .57044 .28421 .56838 .28014 .56478 Mtetra
.651 .765 .932 r
.28014 .56478 .28421 .56838 .29046 .56635 .2864 .56273 Mtetra
.652 .765 .932 r
.2864 .56273 .29046 .56635 .29673 .5643 .29267 .56068 Mtetra
.29267 .56068 .29673 .5643 .30301 .56225 .29896 .55862 Mtetra
.651 .764 .932 r
.29896 .55862 .30301 .56225 .3093 .56021 .30527 .55656 Mtetra
.30527 .55656 .3093 .56021 .31561 .55816 .31158 .55451 Mtetra
.651 .765 .932 r
.31158 .55451 .31561 .55816 .32193 .5561 .31792 .55244 Mtetra
.65 .764 .932 r
.31792 .55244 .32193 .5561 .32827 .55405 .32426 .55038 Mtetra
.65 .764 .933 r
.32426 .55038 .32827 .55405 .33462 .552 .33063 .54832 Mtetra
.651 .764 .932 r
.33063 .54832 .33462 .552 .34099 .54994 .337 .54625 Mtetra
.65 .764 .933 r
.337 .54625 .34099 .54994 .34737 .54788 .3434 .54418 Mtetra
.649 .764 .933 r
.3434 .54418 .34737 .54788 .35377 .54582 .3498 .54212 Mtetra
.65 .764 .933 r
.3498 .54212 .35377 .54582 .36018 .54375 .35622 .54004 Mtetra
.35622 .54004 .36018 .54375 .36661 .54169 .36266 .53796 Mtetra
.649 .764 .933 r
.36266 .53796 .36661 .54169 .37305 .53963 .36911 .5359 Mtetra
.36911 .5359 .37305 .53963 .37951 .53756 .37558 .53382 Mtetra
.37558 .53382 .37951 .53756 .38599 .53548 .38207 .53173 Mtetra
.648 .763 .933 r
.38207 .53173 .38599 .53548 .39247 .53342 .38856 .52966 Mtetra
.648 .764 .933 r
.38856 .52966 .39247 .53342 .39898 .53134 .39508 .52757 Mtetra
.649 .764 .933 r
.39508 .52757 .39898 .53134 .4055 .52925 .40161 .52548 Mtetra
.647 .763 .934 r
.40161 .52548 .4055 .52925 .41203 .52719 .40815 .5234 Mtetra
.648 .763 .933 r
.40815 .5234 .41203 .52719 .41858 .52511 .41471 .52131 Mtetra
.648 .764 .933 r
.41471 .52131 .41858 .52511 .42515 .52302 .42129 .51921 Mtetra
.647 .763 .934 r
.42129 .51921 .42515 .52302 .43173 .52094 .42788 .51712 Mtetra
.42788 .51712 .43173 .52094 .43833 .51885 .43449 .51503 Mtetra
.648 .763 .933 r
.43449 .51503 .43833 .51885 .44495 .51676 .44112 .51292 Mtetra
.646 .763 .934 r
.44112 .51292 .44495 .51676 .45158 .51467 .44776 .51083 Mtetra
.44776 .51083 .45158 .51467 .45822 .51258 .45442 .50873 Mtetra
.647 .763 .934 r
.45442 .50873 .45822 .51258 .46489 .51048 .46109 .50662 Mtetra
.646 .763 .934 r
.46109 .50662 .46489 .51048 .47157 .50838 .46778 .50451 Mtetra
.645 .763 .934 r
.46778 .50451 .47157 .50838 .47826 .50629 .47449 .50241 Mtetra
.646 .763 .934 r
.47449 .50241 .47826 .50629 .48497 .50418 .48121 .50029 Mtetra
.48121 .50029 .48497 .50418 .4917 .50207 .48795 .49817 Mtetra
.645 .762 .934 r
.48795 .49817 .4917 .50207 .49845 .49998 .4947 .49607 Mtetra
.645 .763 .934 r
.4947 .49607 .49845 .49998 .50521 .49786 .50148 .49394 Mtetra
.50148 .49394 .50521 .49786 .51199 .49574 .50827 .49182 Mtetra
.644 .762 .935 r
.50827 .49182 .51199 .49574 .51878 .49364 .51507 .4897 Mtetra
.645 .762 .934 r
.51507 .4897 .51878 .49364 .5256 .49152 .5219 .48758 Mtetra
.5219 .48758 .5256 .49152 .53243 .4894 .52874 .48544 Mtetra
.643 .762 .935 r
.52874 .48544 .53243 .4894 .53927 .48729 .53559 .48332 Mtetra
.644 .762 .935 r
.53559 .48332 .53927 .48729 .54614 .48517 .54247 .48119 Mtetra
.644 .762 .934 r
.54247 .48119 .54614 .48517 .55302 .48303 .54936 .47904 Mtetra
.643 .762 .935 r
.54936 .47904 .55302 .48303 .55992 .48091 .55627 .47691 Mtetra
.55627 .47691 .55992 .48091 .56683 .47879 .5632 .47478 Mtetra
.5632 .47478 .56683 .47879 .57377 .47666 .57014 .47264 Mtetra
.57014 .47264 .57377 .47666 .58072 .47452 .57711 .47049 Mtetra
.57711 .47049 .58072 .47452 .58769 .47239 .58409 .46835 Mtetra
.642 .762 .935 r
.58409 .46835 .58769 .47239 .59467 .47025 .59109 .4662 Mtetra
.59109 .4662 .59467 .47025 .60168 .46811 .5981 .46405 Mtetra
.642 .761 .935 r
.5981 .46405 .60168 .46811 .6087 .46596 .60514 .46189 Mtetra
.60514 .46189 .6087 .46596 .61574 .46382 .61219 .45974 Mtetra
.61219 .45974 .61574 .46382 .6228 .46167 .61926 .45758 Mtetra
.641 .761 .935 r
.61926 .45758 .6228 .46167 .62987 .45952 .62635 .45542 Mtetra
.62635 .45542 .62987 .45952 .63697 .45737 .63345 .45326 Mtetra
.641 .761 .936 r
.63345 .45326 .63697 .45737 .64408 .45521 .64058 .45109 Mtetra
.64058 .45109 .64408 .45521 .65122 .45305 .64772 .44892 Mtetra
.64772 .44892 .65122 .45305 .65837 .45089 .65489 .44675 Mtetra
.64 .761 .936 r
.65489 .44675 .65837 .45089 .66554 .44873 .66207 .44458 Mtetra
.66207 .44458 .66554 .44873 .67272 .44657 .66927 .44241 Mtetra
.66927 .44241 .67272 .44657 .67993 .4444 .67649 .44023 Mtetra
.67649 .44023 .67993 .4444 .68716 .44223 .68373 .43805 Mtetra
.639 .761 .936 r
.68373 .43805 .68716 .44223 .6944 .44006 .69098 .43587 Mtetra
.639 .76 .936 r
.69098 .43587 .6944 .44006 .70167 .43789 .69826 .43369 Mtetra
.69826 .43369 .70167 .43789 .70895 .43571 .70556 .4315 Mtetra
.70556 .4315 .70895 .43571 .71625 .43353 .71287 .42931 Mtetra
.639 .761 .936 r
.71287 .42931 .71625 .43353 .72357 .43133 .72021 .4271 Mtetra
.641 .761 .936 r
.72021 .4271 .72357 .43133 .73091 .42912 .72756 .42487 Mtetra
.645 .763 .935 r
.72756 .42487 .73091 .42912 .73827 .42682 .73493 .42257 Mtetra
.648 .764 .934 r
.73493 .42257 .73827 .42682 .74564 .42447 .74231 .4202 Mtetra
.672 .773 .926 r
.74231 .4202 .74564 .42447 .753 .42173 .74969 .41745 Mtetra
.696 .783 .918 r
.74969 .41745 .753 .42173 .76034 .41853 .75705 .41424 Mtetra
.732 .794 .902 r
.75705 .41424 .76034 .41853 .76765 .41462 .76437 .41032 Mtetra
.811 .815 .853 r
.76437 .41032 .76765 .41462 .77481 .40861 .77154 .4043 Mtetra
.854 .822 .816 r
.77154 .4043 .77481 .40861 .78184 .40098 .77859 .39665 Mtetra
.917 .819 .734 r
.77859 .39665 .78184 .40098 .78855 .38943 .78532 .38508 Mtetra
.954 .805 .656 r
.78532 .38508 .78855 .38943 .79481 .37297 .79161 .36859 Mtetra
.967 .794 .616 r
.79161 .36859 .79481 .37297 .80075 .35329 .79758 .34888 Mtetra
.982 .769 .54 r
.79758 .34888 .80075 .35329 .80584 .32484 .8027 .3204 Mtetra
.985 .76 .516 r
.8027 .3204 .80584 .32484 .8105 .29277 .80739 .28829 Mtetra
.942 .627 .41 r
.16213 .47228 .1662 .47586 .16857 .5055 .16445 .50195 Mtetra
.942 .619 .394 r
.16445 .50195 .16857 .5055 .17131 .53269 .16716 .52916 Mtetra
.935 .58 .323 r
.16716 .52916 .17131 .53269 .17499 .55181 .17082 .54829 Mtetra
.925 .547 .265 r
.17082 .54829 .17499 .55181 .1791 .56759 .17492 .56408 Mtetra
.875 .436 .09 r
.17492 .56408 .1791 .56759 .18382 .57806 .17962 .57456 Mtetra
.624 .099 0 r
.17962 .57456 .18382 .57806 .18907 .58373 .18487 .58023 Mtetra
0 .224 .689 r
.18487 .58023 .18907 .58373 .19455 .58734 .19035 .58384 Mtetra
.338 .641 .965 r
.19035 .58384 .19455 .58734 .20035 .58805 .19615 .58454 Mtetra
.496 .713 .968 r
.19615 .58454 .20035 .58805 .20627 .58768 .20208 .58417 Mtetra
.572 .742 .956 r
.20208 .58417 .20627 .58768 .21227 .58663 .20808 .58311 Mtetra
.632 .76 .94 r
.20808 .58311 .21227 .58663 .21834 .5849 .21417 .58137 Mtetra
.639 .762 .937 r
.21417 .58137 .21834 .5849 .22445 .58307 .22028 .57953 Mtetra
.648 .764 .934 r
.22028 .57953 .22445 .58307 .23057 .58112 .22641 .57757 Mtetra
.652 .765 .932 r
.22641 .57757 .23057 .58112 .23672 .5791 .23257 .57554 Mtetra
.653 .765 .932 r
.23257 .57554 .23672 .5791 .24288 .57707 .23874 .5735 Mtetra
.23874 .5735 .24288 .57707 .24905 .57503 .24492 .57146 Mtetra
.24492 .57146 .24905 .57503 .25524 .57298 .25112 .5694 Mtetra
.25112 .5694 .25524 .57298 .26145 .57093 .25733 .56734 Mtetra
.652 .765 .932 r
.25733 .56734 .26145 .57093 .26766 .56889 .26356 .56529 Mtetra
.26356 .56529 .26766 .56889 .27389 .56684 .2698 .56323 Mtetra
.653 .765 .932 r
.2698 .56323 .27389 .56684 .28014 .56478 .27605 .56116 Mtetra
.651 .765 .932 r
.27605 .56116 .28014 .56478 .2864 .56273 .28232 .55911 Mtetra
.652 .765 .932 r
.28232 .55911 .2864 .56273 .29267 .56068 .2886 .55705 Mtetra
.2886 .55705 .29267 .56068 .29896 .55862 .2949 .55497 Mtetra
.651 .765 .932 r
.2949 .55497 .29896 .55862 .30527 .55656 .30121 .55291 Mtetra
.30121 .55291 .30527 .55656 .31158 .55451 .30754 .55085 Mtetra
.30754 .55085 .31158 .55451 .31792 .55244 .31388 .54877 Mtetra
.65 .764 .933 r
.31388 .54877 .31792 .55244 .32426 .55038 .32024 .5467 Mtetra
.32024 .5467 .32426 .55038 .33063 .54832 .32661 .54463 Mtetra
.651 .765 .932 r
.32661 .54463 .33063 .54832 .337 .54625 .333 .54255 Mtetra
.65 .764 .933 r
.333 .54255 .337 .54625 .3434 .54418 .3394 .54047 Mtetra
.649 .764 .933 r
.3394 .54047 .3434 .54418 .3498 .54212 .34582 .5384 Mtetra
.65 .764 .933 r
.34582 .5384 .3498 .54212 .35622 .54004 .35225 .53632 Mtetra
.35225 .53632 .35622 .54004 .36266 .53796 .35869 .53423 Mtetra
.649 .764 .933 r
.35869 .53423 .36266 .53796 .36911 .5359 .36516 .53215 Mtetra
.36516 .53215 .36911 .5359 .37558 .53382 .37163 .53006 Mtetra
.37163 .53006 .37558 .53382 .38207 .53173 .37813 .52797 Mtetra
.648 .764 .933 r
.37813 .52797 .38207 .53173 .38856 .52966 .38464 .52589 Mtetra
.38464 .52589 .38856 .52966 .39508 .52757 .39116 .52379 Mtetra
.649 .764 .933 r
.39116 .52379 .39508 .52757 .40161 .52548 .3977 .52169 Mtetra
.647 .763 .934 r
.3977 .52169 .40161 .52548 .40815 .5234 .40425 .5196 Mtetra
.648 .764 .934 r
.40425 .5196 .40815 .5234 .41471 .52131 .41083 .5175 Mtetra
.648 .764 .933 r
.41083 .5175 .41471 .52131 .42129 .51921 .41741 .51539 Mtetra
.647 .763 .934 r
.41741 .51539 .42129 .51921 .42788 .51712 .42402 .51329 Mtetra
.42402 .51329 .42788 .51712 .43449 .51503 .43064 .51119 Mtetra
.647 .764 .934 r
.43064 .51119 .43449 .51503 .44112 .51292 .43727 .50908 Mtetra
.646 .763 .934 r
.43727 .50908 .44112 .51292 .44776 .51083 .44392 .50697 Mtetra
.44392 .50697 .44776 .51083 .45442 .50873 .45059 .50486 Mtetra
.647 .763 .934 r
.45059 .50486 .45442 .50873 .46109 .50662 .45727 .50274 Mtetra
.646 .763 .934 r
.45727 .50274 .46109 .50662 .46778 .50451 .46397 .50062 Mtetra
.645 .763 .934 r
.46397 .50062 .46778 .50451 .47449 .50241 .47069 .49851 Mtetra
.646 .763 .934 r
.47069 .49851 .47449 .50241 .48121 .50029 .47742 .49639 Mtetra
.47742 .49639 .48121 .50029 .48795 .49817 .48417 .49426 Mtetra
.645 .763 .935 r
.48417 .49426 .48795 .49817 .4947 .49607 .49094 .49214 Mtetra
.645 .763 .934 r
.49094 .49214 .4947 .49607 .50148 .49394 .49773 .49001 Mtetra
.49773 .49001 .50148 .49394 .50827 .49182 .50453 .48787 Mtetra
.644 .762 .935 r
.50453 .48787 .50827 .49182 .51507 .4897 .51134 .48575 Mtetra
.645 .763 .935 r
.51134 .48575 .51507 .4897 .5219 .48758 .51818 .48361 Mtetra
.645 .763 .934 r
.51818 .48361 .5219 .48758 .52874 .48544 .52503 .48146 Mtetra
.643 .762 .935 r
.52503 .48146 .52874 .48544 .53559 .48332 .5319 .47934 Mtetra
.644 .762 .935 r
.5319 .47934 .53559 .48332 .54247 .48119 .53879 .47719 Mtetra
.644 .763 .935 r
.53879 .47719 .54247 .48119 .54936 .47904 .54569 .47504 Mtetra
.643 .762 .935 r
.54569 .47504 .54936 .47904 .55627 .47691 .55261 .4729 Mtetra
.55261 .4729 .55627 .47691 .5632 .47478 .55955 .47076 Mtetra
.55955 .47076 .5632 .47478 .57014 .47264 .56651 .46861 Mtetra
.56651 .46861 .57014 .47264 .57711 .47049 .57348 .46645 Mtetra
.57348 .46645 .57711 .47049 .58409 .46835 .58047 .4643 Mtetra
.642 .762 .935 r
.58047 .4643 .58409 .46835 .59109 .4662 .58748 .46214 Mtetra
.58748 .46214 .59109 .4662 .5981 .46405 .59451 .45998 Mtetra
.59451 .45998 .5981 .46405 .60514 .46189 .60156 .45781 Mtetra
.60156 .45781 .60514 .46189 .61219 .45974 .60862 .45565 Mtetra
.642 .762 .936 r
.60862 .45565 .61219 .45974 .61926 .45758 .6157 .45348 Mtetra
.641 .761 .936 r
.6157 .45348 .61926 .45758 .62635 .45542 .6228 .45131 Mtetra
.6228 .45131 .62635 .45542 .63345 .45326 .62992 .44913 Mtetra
.62992 .44913 .63345 .45326 .64058 .45109 .63706 .44696 Mtetra
.63706 .44696 .64058 .45109 .64772 .44892 .64422 .44478 Mtetra
.64422 .44478 .64772 .44892 .65489 .44675 .65139 .4426 Mtetra
.64 .761 .936 r
.65139 .4426 .65489 .44675 .66207 .44458 .65859 .44042 Mtetra
.65859 .44042 .66207 .44458 .66927 .44241 .6658 .43823 Mtetra
.6658 .43823 .66927 .44241 .67649 .44023 .67303 .43604 Mtetra
.67303 .43604 .67649 .44023 .68373 .43805 .68028 .43385 Mtetra
.639 .761 .936 r
.68028 .43385 .68373 .43805 .69098 .43587 .68755 .43166 Mtetra
.68755 .43166 .69098 .43587 .69826 .43369 .69484 .42947 Mtetra
.69484 .42947 .69826 .43369 .70556 .4315 .70215 .42727 Mtetra
.70215 .42727 .70556 .4315 .71287 .42931 .70948 .42507 Mtetra
.70948 .42507 .71287 .42931 .72021 .4271 .71683 .42285 Mtetra
.641 .761 .936 r
.71683 .42285 .72021 .4271 .72756 .42487 .72419 .42061 Mtetra
.645 .763 .935 r
.72419 .42061 .72756 .42487 .73493 .42257 .73157 .4183 Mtetra
.648 .765 .934 r
.73157 .4183 .73493 .42257 .74231 .4202 .73897 .41592 Mtetra
.672 .774 .927 r
.73897 .41592 .74231 .4202 .74969 .41745 .74636 .41316 Mtetra
.696 .783 .918 r
.74636 .41316 .74969 .41745 .75705 .41424 .75373 .40993 Mtetra
.732 .795 .902 r
.75373 .40993 .75705 .41424 .76437 .41032 .76107 .406 Mtetra
.812 .816 .854 r
.76107 .406 .76437 .41032 .77154 .4043 .76826 .39996 Mtetra
.855 .822 .816 r
.76826 .39996 .77154 .4043 .77859 .39665 .77533 .3923 Mtetra
.917 .819 .734 r
.77533 .3923 .77859 .39665 .78532 .38508 .78208 .38071 Mtetra
.954 .805 .656 r
.78208 .38071 .78532 .38508 .79161 .36859 .78839 .3642 Mtetra
.967 .794 .616 r
.78839 .3642 .79161 .36859 .79758 .34888 .79439 .34446 Mtetra
.982 .769 .54 r
.79439 .34446 .79758 .34888 .8027 .3204 .79955 .31594 Mtetra
.985 .76 .516 r
.79955 .31594 .8027 .3204 .80739 .28829 .80428 .28379 Mtetra
.942 .627 .41 r
.15804 .46868 .16213 .47228 .16445 .50195 .16032 .49837 Mtetra
.942 .619 .394 r
.16032 .49837 .16445 .50195 .16716 .52916 .16299 .5256 Mtetra
.935 .58 .322 r
.16299 .5256 .16716 .52916 .17082 .54829 .16663 .54475 Mtetra
.925 .547 .265 r
.16663 .54475 .17082 .54829 .17492 .56408 .17071 .56055 Mtetra
.875 .435 .089 r
.17071 .56055 .17492 .56408 .17962 .57456 .17541 .57103 Mtetra
.622 .098 0 r
.17541 .57103 .17962 .57456 .18487 .58023 .18065 .5767 Mtetra
0 .225 .691 r
.18065 .5767 .18487 .58023 .19035 .58384 .18613 .58031 Mtetra
.34 .641 .964 r
.18613 .58031 .19035 .58384 .19615 .58454 .19194 .581 Mtetra
.497 .713 .967 r
.19194 .581 .19615 .58454 .20208 .58417 .19787 .58062 Mtetra
.573 .741 .956 r
.19787 .58062 .20208 .58417 .20808 .58311 .20388 .57955 Mtetra
.632 .759 .939 r
.20388 .57955 .20808 .58311 .21417 .58137 .20998 .57781 Mtetra
.639 .761 .936 r
.20998 .57781 .21417 .58137 .22028 .57953 .21609 .57596 Mtetra
.648 .763 .933 r
.21609 .57596 .22028 .57953 .22641 .57757 .22224 .57399 Mtetra
.652 .764 .931 r
.22224 .57399 .22641 .57757 .23257 .57554 .2284 .57196 Mtetra
.653 .764 .931 r
.2284 .57196 .23257 .57554 .23874 .5735 .23458 .56991 Mtetra
.23458 .56991 .23874 .5735 .24492 .57146 .24077 .56785 Mtetra
.653 .765 .931 r
.24077 .56785 .24492 .57146 .25112 .5694 .24698 .56579 Mtetra
.24698 .56579 .25112 .5694 .25733 .56734 .2532 .56372 Mtetra
.652 .764 .931 r
.2532 .56372 .25733 .56734 .26356 .56529 .25943 .56166 Mtetra
.653 .764 .931 r
.25943 .56166 .26356 .56529 .2698 .56323 .26568 .55959 Mtetra
.26568 .55959 .2698 .56323 .27605 .56116 .27195 .55751 Mtetra
.651 .764 .932 r
.27195 .55751 .27605 .56116 .28232 .55911 .27822 .55545 Mtetra
.652 .764 .932 r
.27822 .55545 .28232 .55911 .2886 .55705 .28452 .55338 Mtetra
.652 .764 .931 r
.28452 .55338 .2886 .55705 .2949 .55497 .29082 .5513 Mtetra
.651 .764 .932 r
.29082 .5513 .2949 .55497 .30121 .55291 .29715 .54923 Mtetra
.29715 .54923 .30121 .55291 .30754 .55085 .30348 .54715 Mtetra
.30348 .54715 .30754 .55085 .31388 .54877 .30983 .54507 Mtetra
.30983 .54507 .31388 .54877 .32024 .5467 .3162 .54299 Mtetra
.65 .764 .932 r
.3162 .54299 .32024 .5467 .32661 .54463 .32258 .54091 Mtetra
.651 .764 .932 r
.32258 .54091 .32661 .54463 .333 .54255 .32898 .53882 Mtetra
.65 .764 .932 r
.32898 .53882 .333 .54255 .3394 .54047 .33539 .53673 Mtetra
.649 .763 .932 r
.33539 .53673 .3394 .54047 .34582 .5384 .34181 .53465 Mtetra
.65 .764 .932 r
.34181 .53465 .34582 .5384 .35225 .53632 .34825 .53256 Mtetra
.65 .763 .932 r
.34825 .53256 .35225 .53632 .35869 .53423 .35471 .53046 Mtetra
.649 .763 .933 r
.35471 .53046 .35869 .53423 .36516 .53215 .36118 .52838 Mtetra
.649 .763 .932 r
.36118 .52838 .36516 .53215 .37163 .53006 .36767 .52628 Mtetra
.36767 .52628 .37163 .53006 .37813 .52797 .37417 .52417 Mtetra
.648 .763 .933 r
.37417 .52417 .37813 .52797 .38464 .52589 .38069 .52208 Mtetra
.38069 .52208 .38464 .52589 .39116 .52379 .38722 .51998 Mtetra
.649 .763 .933 r
.38722 .51998 .39116 .52379 .3977 .52169 .39377 .51787 Mtetra
.647 .763 .933 r
.39377 .51787 .3977 .52169 .40425 .5196 .40034 .51577 Mtetra
.648 .763 .933 r
.40034 .51577 .40425 .5196 .41083 .5175 .40692 .51366 Mtetra
.40692 .51366 .41083 .5175 .41741 .51539 .41352 .51154 Mtetra
.647 .763 .933 r
.41352 .51154 .41741 .51539 .42402 .51329 .42013 .50943 Mtetra
.42013 .50943 .42402 .51329 .43064 .51119 .42676 .50732 Mtetra
.648 .763 .933 r
.42676 .50732 .43064 .51119 .43727 .50908 .43341 .5052 Mtetra
.647 .762 .933 r
.43341 .5052 .43727 .50908 .44392 .50697 .44007 .50308 Mtetra
.646 .762 .934 r
.44007 .50308 .44392 .50697 .45059 .50486 .44675 .50097 Mtetra
.647 .763 .933 r
.44675 .50097 .45059 .50486 .45727 .50274 .45344 .49883 Mtetra
.646 .762 .933 r
.45344 .49883 .45727 .50274 .46397 .50062 .46015 .49671 Mtetra
.645 .762 .934 r
.46015 .49671 .46397 .50062 .47069 .49851 .46688 .49459 Mtetra
.646 .762 .933 r
.46688 .49459 .47069 .49851 .47742 .49639 .47362 .49245 Mtetra
.646 .762 .934 r
.47362 .49245 .47742 .49639 .48417 .49426 .48038 .49031 Mtetra
.645 .762 .934 r
.48038 .49031 .48417 .49426 .49094 .49214 .48716 .48819 Mtetra
.48716 .48819 .49094 .49214 .49773 .49001 .49396 .48604 Mtetra
.49396 .48604 .49773 .49001 .50453 .48787 .50077 .4839 Mtetra
.644 .762 .934 r
.50077 .4839 .50453 .48787 .51134 .48575 .5076 .48176 Mtetra
.645 .762 .934 r
.5076 .48176 .51134 .48575 .51818 .48361 .51444 .47962 Mtetra
.51444 .47962 .51818 .48361 .52503 .48146 .52131 .47746 Mtetra
.643 .761 .934 r
.52131 .47746 .52503 .48146 .5319 .47934 .52819 .47532 Mtetra
.644 .762 .934 r
.52819 .47532 .5319 .47934 .53879 .47719 .53508 .47317 Mtetra
.53508 .47317 .53879 .47719 .54569 .47504 .542 .471 Mtetra
.643 .761 .935 r
.542 .471 .54569 .47504 .55261 .4729 .54893 .46885 Mtetra
.54893 .46885 .55261 .4729 .55955 .47076 .55588 .4667 Mtetra
.643 .761 .934 r
.55588 .4667 .55955 .47076 .56651 .46861 .56285 .46454 Mtetra
.643 .761 .935 r
.56285 .46454 .56651 .46861 .57348 .46645 .56983 .46238 Mtetra
.56983 .46238 .57348 .46645 .58047 .4643 .57684 .46021 Mtetra
.642 .761 .935 r
.57684 .46021 .58047 .4643 .58748 .46214 .58386 .45804 Mtetra
.58386 .45804 .58748 .46214 .59451 .45998 .5909 .45587 Mtetra
.5909 .45587 .59451 .45998 .60156 .45781 .59796 .45369 Mtetra
.59796 .45369 .60156 .45781 .60862 .45565 .60503 .45152 Mtetra
.60503 .45152 .60862 .45565 .6157 .45348 .61213 .44934 Mtetra
.641 .761 .935 r
.61213 .44934 .6157 .45348 .6228 .45131 .61924 .44716 Mtetra
.61924 .44716 .6228 .45131 .62992 .44913 .62637 .44498 Mtetra
.62637 .44498 .62992 .44913 .63706 .44696 .63352 .44279 Mtetra
.641 .76 .935 r
.63352 .44279 .63706 .44696 .64422 .44478 .64069 .4406 Mtetra
.64069 .4406 .64422 .44478 .65139 .4426 .64788 .43841 Mtetra
.64 .76 .935 r
.64788 .43841 .65139 .4426 .65859 .44042 .65509 .43622 Mtetra
.65509 .43622 .65859 .44042 .6658 .43823 .66231 .43402 Mtetra
.66231 .43402 .6658 .43823 .67303 .43604 .66956 .43182 Mtetra
.64 .76 .936 r
.66956 .43182 .67303 .43604 .68028 .43385 .67682 .42962 Mtetra
.639 .76 .936 r
.67682 .42962 .68028 .43385 .68755 .43166 .6841 .42742 Mtetra
.6841 .42742 .68755 .43166 .69484 .42947 .69141 .42521 Mtetra
.69141 .42521 .69484 .42947 .70215 .42727 .69873 .42301 Mtetra
.69873 .42301 .70215 .42727 .70948 .42507 .70607 .42079 Mtetra
.64 .76 .936 r
.70607 .42079 .70948 .42507 .71683 .42285 .71343 .41856 Mtetra
.641 .761 .935 r
.71343 .41856 .71683 .42285 .72419 .42061 .72081 .41631 Mtetra
.645 .762 .934 r
.72081 .41631 .72419 .42061 .73157 .4183 .7282 .41399 Mtetra
.648 .764 .933 r
.7282 .41399 .73157 .4183 .73897 .41592 .73561 .4116 Mtetra
.672 .773 .926 r
.73561 .4116 .73897 .41592 .74636 .41316 .74302 .40883 Mtetra
.696 .782 .917 r
.74302 .40883 .74636 .41316 .75373 .40993 .7504 .40559 Mtetra
.731 .794 .902 r
.7504 .40559 .75373 .40993 .76107 .406 .75776 .40165 Mtetra
.811 .815 .853 r
.75776 .40165 .76107 .406 .76826 .39996 .76497 .39559 Mtetra
.854 .821 .815 r
.76497 .39559 .76826 .39996 .77533 .3923 .77205 .38791 Mtetra
.917 .819 .734 r
.77205 .38791 .77533 .3923 .78208 .38071 .77882 .3763 Mtetra
.954 .804 .656 r
.77882 .3763 .78208 .38071 .78839 .3642 .78516 .35977 Mtetra
.967 .794 .616 r
.78516 .35977 .78839 .3642 .79439 .34446 .79118 .34 Mtetra
.982 .769 .54 r
.79118 .34 .79439 .34446 .79955 .31594 .79638 .31145 Mtetra
.985 .76 .516 r
.79638 .31145 .79955 .31594 .80428 .28379 .80114 .27926 Mtetra
.942 .627 .41 r
.15393 .46508 .15804 .46868 .16032 .49837 .15618 .49479 Mtetra
.942 .619 .394 r
.15618 .49479 .16032 .49837 .16299 .5256 .15881 .52204 Mtetra
.935 .58 .322 r
.15881 .52204 .16299 .5256 .16663 .54475 .16243 .5412 Mtetra
.925 .547 .265 r
.16243 .5412 .16663 .54475 .17071 .56055 .16649 .55701 Mtetra
.875 .435 .089 r
.16649 .55701 .17071 .56055 .17541 .57103 .17117 .5675 Mtetra
.623 .098 0 r
.17117 .5675 .17541 .57103 .18065 .5767 .17641 .57317 Mtetra
0 .224 .69 r
.17641 .57317 .18065 .5767 .18613 .58031 .1819 .57677 Mtetra
.339 .641 .965 r
.1819 .57677 .18613 .58031 .19194 .581 .1877 .57746 Mtetra
.497 .713 .968 r
.1877 .57746 .19194 .581 .19787 .58062 .19364 .57707 Mtetra
.573 .741 .956 r
.19364 .57707 .19787 .58062 .20388 .57955 .19966 .576 Mtetra
.632 .759 .939 r
.19966 .576 .20388 .57955 .20998 .57781 .20576 .57424 Mtetra
.639 .761 .937 r
.20576 .57424 .20998 .57781 .21609 .57596 .21189 .57239 Mtetra
.648 .764 .934 r
.21189 .57239 .21609 .57596 .22224 .57399 .21804 .57041 Mtetra
.652 .765 .932 r
.21804 .57041 .22224 .57399 .2284 .57196 .22421 .56836 Mtetra
.653 .765 .932 r
.22421 .56836 .2284 .57196 .23458 .56991 .2304 .56631 Mtetra
.2304 .56631 .23458 .56991 .24077 .56785 .2366 .56424 Mtetra
.653 .765 .931 r
.2366 .56424 .24077 .56785 .24698 .56579 .24282 .56217 Mtetra
.24282 .56217 .24698 .56579 .2532 .56372 .24905 .56009 Mtetra
.652 .765 .932 r
.24905 .56009 .2532 .56372 .25943 .56166 .25529 .55802 Mtetra
.653 .765 .932 r
.25529 .55802 .25943 .56166 .26568 .55959 .26155 .55595 Mtetra
.26155 .55595 .26568 .55959 .27195 .55751 .26782 .55386 Mtetra
.651 .764 .932 r
.26782 .55386 .27195 .55751 .27822 .55545 .27411 .55179 Mtetra
.652 .765 .932 r
.27411 .55179 .27822 .55545 .28452 .55338 .28041 .54971 Mtetra
.28041 .54971 .28452 .55338 .29082 .5513 .28673 .54762 Mtetra
.651 .764 .932 r
.28673 .54762 .29082 .5513 .29715 .54923 .29306 .54554 Mtetra
.29306 .54554 .29715 .54923 .30348 .54715 .2994 .54345 Mtetra
.2994 .54345 .30348 .54715 .30983 .54507 .30576 .54136 Mtetra
.65 .764 .932 r
.30576 .54136 .30983 .54507 .3162 .54299 .31214 .53927 Mtetra
.65 .764 .933 r
.31214 .53927 .3162 .54299 .32258 .54091 .31853 .53719 Mtetra
.651 .764 .932 r
.31853 .53719 .32258 .54091 .32898 .53882 .32494 .53508 Mtetra
.65 .764 .933 r
.32494 .53508 .32898 .53882 .33539 .53673 .33136 .53299 Mtetra
.649 .764 .933 r
.33136 .53299 .33539 .53673 .34181 .53465 .33779 .5309 Mtetra
.65 .764 .933 r
.33779 .5309 .34181 .53465 .34825 .53256 .34424 .52879 Mtetra
.34424 .52879 .34825 .53256 .35471 .53046 .35071 .52669 Mtetra
.649 .764 .933 r
.35071 .52669 .35471 .53046 .36118 .52838 .35719 .52459 Mtetra
.35719 .52459 .36118 .52838 .36767 .52628 .36369 .52249 Mtetra
.36369 .52249 .36767 .52628 .37417 .52417 .3702 .52037 Mtetra
.648 .763 .933 r
.3702 .52037 .37417 .52417 .38069 .52208 .37673 .51827 Mtetra
.648 .764 .933 r
.37673 .51827 .38069 .52208 .38722 .51998 .38327 .51616 Mtetra
.649 .764 .933 r
.38327 .51616 .38722 .51998 .39377 .51787 .38983 .51404 Mtetra
.647 .763 .933 r
.38983 .51404 .39377 .51787 .40034 .51577 .39641 .51193 Mtetra
.648 .763 .933 r
.39641 .51193 .40034 .51577 .40692 .51366 .403 .50981 Mtetra
.403 .50981 .40692 .51366 .41352 .51154 .40961 .50768 Mtetra
.647 .763 .934 r
.40961 .50768 .41352 .51154 .42013 .50943 .41623 .50557 Mtetra
.41623 .50557 .42013 .50943 .42676 .50732 .42287 .50345 Mtetra
.648 .763 .933 r
.42287 .50345 .42676 .50732 .43341 .5052 .42953 .50131 Mtetra
.646 .763 .934 r
.42953 .50131 .43341 .5052 .44007 .50308 .4362 .49918 Mtetra
.4362 .49918 .44007 .50308 .44675 .50097 .44289 .49706 Mtetra
.647 .763 .934 r
.44289 .49706 .44675 .50097 .45344 .49883 .44959 .49492 Mtetra
.646 .763 .934 r
.44959 .49492 .45344 .49883 .46015 .49671 .45631 .49278 Mtetra
.645 .763 .934 r
.45631 .49278 .46015 .49671 .46688 .49459 .46305 .49065 Mtetra
.646 .763 .934 r
.46305 .49065 .46688 .49459 .47362 .49245 .46981 .4885 Mtetra
.46981 .4885 .47362 .49245 .48038 .49031 .47658 .48636 Mtetra
.645 .762 .934 r
.47658 .48636 .48038 .49031 .48716 .48819 .48337 .48422 Mtetra
.645 .763 .934 r
.48337 .48422 .48716 .48819 .49396 .48604 .49017 .48207 Mtetra
.49017 .48207 .49396 .48604 .50077 .4839 .49699 .47991 Mtetra
.644 .762 .935 r
.49699 .47991 .50077 .4839 .5076 .48176 .50383 .47777 Mtetra
.645 .762 .934 r
.50383 .47777 .5076 .48176 .51444 .47962 .51069 .47561 Mtetra
.51069 .47561 .51444 .47962 .52131 .47746 .51756 .47344 Mtetra
.643 .762 .935 r
.51756 .47344 .52131 .47746 .52819 .47532 .52446 .4713 Mtetra
.644 .762 .935 r
.52446 .4713 .52819 .47532 .53508 .47317 .53136 .46913 Mtetra
.644 .762 .934 r
.53136 .46913 .53508 .47317 .542 .471 .53829 .46696 Mtetra
.643 .762 .935 r
.53829 .46696 .542 .471 .54893 .46885 .54523 .4648 Mtetra
.54523 .4648 .54893 .46885 .55588 .4667 .5522 .46264 Mtetra
.5522 .46264 .55588 .4667 .56285 .46454 .55918 .46046 Mtetra
.55918 .46046 .56285 .46454 .56983 .46238 .56617 .45829 Mtetra
.56617 .45829 .56983 .46238 .57684 .46021 .57319 .45611 Mtetra
.642 .762 .935 r
.57319 .45611 .57684 .46021 .58386 .45804 .58022 .45393 Mtetra
.642 .761 .935 r
.58022 .45393 .58386 .45804 .5909 .45587 .58727 .45175 Mtetra
.58727 .45175 .5909 .45587 .59796 .45369 .59434 .44957 Mtetra
.59434 .44957 .59796 .45369 .60503 .45152 .60143 .44738 Mtetra
.60143 .44738 .60503 .45152 .61213 .44934 .60854 .44519 Mtetra
.641 .761 .935 r
.60854 .44519 .61213 .44934 .61924 .44716 .61566 .443 Mtetra
.61566 .443 .61924 .44716 .62637 .44498 .62281 .44081 Mtetra
.62281 .44081 .62637 .44498 .63352 .44279 .62997 .43861 Mtetra
.641 .761 .936 r
.62997 .43861 .63352 .44279 .64069 .4406 .63715 .43641 Mtetra
.63715 .43641 .64069 .4406 .64788 .43841 .64435 .43421 Mtetra
.64 .761 .936 r
.64435 .43421 .64788 .43841 .65509 .43622 .65157 .43201 Mtetra
.65157 .43201 .65509 .43622 .66231 .43402 .65881 .4298 Mtetra
.65881 .4298 .66231 .43402 .66956 .43182 .66606 .42759 Mtetra
.66606 .42759 .66956 .43182 .67682 .42962 .67334 .42538 Mtetra
.639 .76 .936 r
.67334 .42538 .67682 .42962 .6841 .42742 .68064 .42317 Mtetra
.68064 .42317 .6841 .42742 .69141 .42521 .68795 .42095 Mtetra
.68795 .42095 .69141 .42521 .69873 .42301 .69529 .41873 Mtetra
.69529 .41873 .69873 .42301 .70607 .42079 .70264 .41651 Mtetra
.639 .761 .936 r
.70264 .41651 .70607 .42079 .71343 .41856 .71002 .41427 Mtetra
.641 .761 .936 r
.71002 .41427 .71343 .41856 .72081 .41631 .71741 .41201 Mtetra
.645 .763 .935 r
.71741 .41201 .72081 .41631 .7282 .41399 .72482 .40967 Mtetra
.648 .764 .934 r
.72482 .40967 .7282 .41399 .73561 .4116 .73224 .40727 Mtetra
.672 .773 .926 r
.73224 .40727 .73561 .4116 .74302 .40883 .73966 .40448 Mtetra
.696 .783 .917 r
.73966 .40448 .74302 .40883 .7504 .40559 .74706 .40124 Mtetra
.731 .794 .902 r
.74706 .40124 .7504 .40559 .75776 .40165 .75443 .39728 Mtetra
.811 .815 .853 r
.75443 .39728 .75776 .40165 .76497 .39559 .76165 .39121 Mtetra
.854 .822 .816 r
.76165 .39121 .76497 .39559 .77205 .38791 .76876 .38352 Mtetra
.917 .819 .734 r
.76876 .38352 .77205 .38791 .77882 .3763 .77555 .37189 Mtetra
.954 .805 .656 r
.77555 .37189 .77882 .3763 .78516 .35977 .78191 .35532 Mtetra
.967 .794 .616 r
.78191 .35532 .78516 .35977 .79118 .34 .78796 .33553 Mtetra
.982 .769 .54 r
.78796 .33553 .79118 .34 .79638 .31145 .79319 .30695 Mtetra
.985 .76 .516 r
.79319 .30695 .79638 .31145 .80114 .27926 .798 .27472 Mtetra
.942 .627 .41 r
.14981 .46146 .15393 .46508 .15618 .49479 .15201 .4912 Mtetra
.942 .619 .394 r
.15201 .4912 .15618 .49479 .15881 .52204 .15461 .51847 Mtetra
.935 .58 .323 r
.15461 .51847 .15881 .52204 .16243 .5412 .1582 .53765 Mtetra
.925 .547 .265 r
.1582 .53765 .16243 .5412 .16649 .55701 .16224 .55347 Mtetra
.875 .435 .09 r
.16224 .55347 .16649 .55701 .17117 .5675 .16692 .56396 Mtetra
.624 .099 0 r
.16692 .56396 .17117 .5675 .17641 .57317 .17215 .56963 Mtetra
0 .224 .689 r
.17215 .56963 .17641 .57317 .1819 .57677 .17764 .57323 Mtetra
.338 .641 .965 r
.17764 .57323 .1819 .57677 .1877 .57746 .18345 .57391 Mtetra
.496 .714 .968 r
.18345 .57391 .1877 .57746 .19364 .57707 .18939 .57352 Mtetra
.572 .742 .956 r
.18939 .57352 .19364 .57707 .19966 .576 .19542 .57243 Mtetra
.632 .76 .94 r
.19542 .57243 .19966 .576 .20576 .57424 .20153 .57067 Mtetra
.639 .762 .937 r
.20153 .57067 .20576 .57424 .21189 .57239 .20767 .56881 Mtetra
.648 .764 .934 r
.20767 .56881 .21189 .57239 .21804 .57041 .21383 .56682 Mtetra
.652 .765 .932 r
.21383 .56682 .21804 .57041 .22421 .56836 .22001 .56477 Mtetra
.653 .765 .932 r
.22001 .56477 .22421 .56836 .2304 .56631 .2262 .5627 Mtetra
.2262 .5627 .2304 .56631 .2366 .56424 .23241 .56063 Mtetra
.653 .766 .932 r
.23241 .56063 .2366 .56424 .24282 .56217 .23864 .55854 Mtetra
.23864 .55854 .24282 .56217 .24905 .56009 .24488 .55645 Mtetra
.652 .765 .932 r
.24488 .55645 .24905 .56009 .25529 .55802 .25113 .55438 Mtetra
.25113 .55438 .25529 .55802 .26155 .55595 .2574 .55229 Mtetra
.653 .765 .932 r
.2574 .55229 .26155 .55595 .26782 .55386 .26368 .5502 Mtetra
.651 .765 .932 r
.26368 .5502 .26782 .55386 .27411 .55179 .26997 .54812 Mtetra
.652 .765 .932 r
.26997 .54812 .27411 .55179 .28041 .54971 .27628 .54603 Mtetra
.27628 .54603 .28041 .54971 .28673 .54762 .28261 .54393 Mtetra
.651 .765 .933 r
.28261 .54393 .28673 .54762 .29306 .54554 .28895 .54184 Mtetra
.28895 .54184 .29306 .54554 .2994 .54345 .29531 .53975 Mtetra
.651 .765 .932 r
.29531 .53975 .2994 .54345 .30576 .54136 .30168 .53764 Mtetra
.65 .765 .933 r
.30168 .53764 .30576 .54136 .31214 .53927 .30806 .53555 Mtetra
.30806 .53555 .31214 .53927 .31853 .53719 .31446 .53345 Mtetra
.651 .765 .933 r
.31446 .53345 .31853 .53719 .32494 .53508 .32088 .53134 Mtetra
.65 .765 .933 r
.32088 .53134 .32494 .53508 .33136 .53299 .32731 .52924 Mtetra
.649 .764 .933 r
.32731 .52924 .33136 .53299 .33779 .5309 .33375 .52714 Mtetra
.65 .765 .933 r
.33375 .52714 .33779 .5309 .34424 .52879 .34021 .52502 Mtetra
.65 .764 .933 r
.34021 .52502 .34424 .52879 .35071 .52669 .34669 .52291 Mtetra
.649 .764 .933 r
.34669 .52291 .35071 .52669 .35719 .52459 .35318 .5208 Mtetra
.35318 .5208 .35719 .52459 .36369 .52249 .35969 .51869 Mtetra
.35969 .51869 .36369 .52249 .3702 .52037 .36621 .51656 Mtetra
.648 .764 .934 r
.36621 .51656 .3702 .52037 .37673 .51827 .37275 .51445 Mtetra
.648 .764 .933 r
.37275 .51445 .37673 .51827 .38327 .51616 .3793 .51233 Mtetra
.649 .764 .933 r
.3793 .51233 .38327 .51616 .38983 .51404 .38587 .5102 Mtetra
.647 .764 .934 r
.38587 .5102 .38983 .51404 .39641 .51193 .39246 .50808 Mtetra
.648 .764 .934 r
.39246 .50808 .39641 .51193 .403 .50981 .39906 .50595 Mtetra
.39906 .50595 .403 .50981 .40961 .50768 .40568 .50382 Mtetra
.647 .764 .934 r
.40568 .50382 .40961 .50768 .41623 .50557 .41231 .50169 Mtetra
.41231 .50169 .41623 .50557 .42287 .50345 .41896 .49956 Mtetra
.41896 .49956 .42287 .50345 .42953 .50131 .42563 .49741 Mtetra
.646 .763 .934 r
.42563 .49741 .42953 .50131 .4362 .49918 .43231 .49528 Mtetra
.43231 .49528 .4362 .49918 .44289 .49706 .43901 .49314 Mtetra
.647 .764 .934 r
.43901 .49314 .44289 .49706 .44959 .49492 .44572 .49099 Mtetra
.646 .763 .934 r
.44572 .49099 .44959 .49492 .45631 .49278 .45246 .48885 Mtetra
.645 .763 .934 r
.45246 .48885 .45631 .49278 .46305 .49065 .4592 .48671 Mtetra
.646 .763 .934 r
.4592 .48671 .46305 .49065 .46981 .4885 .46597 .48455 Mtetra
.46597 .48455 .46981 .4885 .47658 .48636 .47275 .48239 Mtetra
.645 .763 .935 r
.47275 .48239 .47658 .48636 .48337 .48422 .47955 .48025 Mtetra
.645 .763 .934 r
.47955 .48025 .48337 .48422 .49017 .48207 .48637 .47808 Mtetra
.48637 .47808 .49017 .48207 .49699 .47991 .4932 .47592 Mtetra
.644 .763 .935 r
.4932 .47592 .49699 .47991 .50383 .47777 .50005 .47377 Mtetra
.645 .763 .935 r
.50005 .47377 .50383 .47777 .51069 .47561 .50692 .4716 Mtetra
.50692 .4716 .51069 .47561 .51756 .47344 .51381 .46942 Mtetra
.643 .762 .935 r
.51381 .46942 .51756 .47344 .52446 .4713 .52071 .46726 Mtetra
.644 .762 .935 r
.52071 .46726 .52446 .4713 .53136 .46913 .52763 .46509 Mtetra
.644 .763 .935 r
.52763 .46509 .53136 .46913 .53829 .46696 .53457 .4629 Mtetra
.643 .762 .935 r
.53457 .4629 .53829 .46696 .54523 .4648 .54152 .46073 Mtetra
.54152 .46073 .54523 .4648 .5522 .46264 .54849 .45856 Mtetra
.54849 .45856 .5522 .46264 .55918 .46046 .55549 .45638 Mtetra
.55549 .45638 .55918 .46046 .56617 .45829 .56249 .4542 Mtetra
.56249 .4542 .56617 .45829 .57319 .45611 .56952 .45201 Mtetra
.642 .762 .935 r
.56952 .45201 .57319 .45611 .58022 .45393 .57657 .44982 Mtetra
.57657 .44982 .58022 .45393 .58727 .45175 .58363 .44763 Mtetra
.642 .762 .936 r
.58363 .44763 .58727 .45175 .59434 .44957 .59071 .44543 Mtetra
.59071 .44543 .59434 .44957 .60143 .44738 .59781 .44323 Mtetra
.59781 .44323 .60143 .44738 .60854 .44519 .60493 .44103 Mtetra
.641 .762 .936 r
.60493 .44103 .60854 .44519 .61566 .443 .61207 .43883 Mtetra
.61207 .43883 .61566 .443 .62281 .44081 .61922 .43663 Mtetra
.61922 .43663 .62281 .44081 .62997 .43861 .6264 .43442 Mtetra
.641 .761 .936 r
.6264 .43442 .62997 .43861 .63715 .43641 .63359 .43221 Mtetra
.64 .761 .936 r
.63359 .43221 .63715 .43641 .64435 .43421 .6408 .43 Mtetra
.6408 .43 .64435 .43421 .65157 .43201 .64804 .42778 Mtetra
.64804 .42778 .65157 .43201 .65881 .4298 .65529 .42557 Mtetra
.65529 .42557 .65881 .4298 .66606 .42759 .66256 .42335 Mtetra
.66256 .42335 .66606 .42759 .67334 .42538 .66985 .42113 Mtetra
.639 .761 .936 r
.66985 .42113 .67334 .42538 .68064 .42317 .67716 .4189 Mtetra
.67716 .4189 .68064 .42317 .68795 .42095 .68448 .41668 Mtetra
.639 .761 .937 r
.68448 .41668 .68795 .42095 .69529 .41873 .69183 .41445 Mtetra
.639 .761 .936 r
.69183 .41445 .69529 .41873 .70264 .41651 .6992 .41221 Mtetra
.6992 .41221 .70264 .41651 .71002 .41427 .70659 .40996 Mtetra
.641 .762 .936 r
.70659 .40996 .71002 .41427 .71741 .41201 .71399 .40769 Mtetra
.645 .763 .935 r
.71399 .40769 .71741 .41201 .72482 .40967 .72141 .40534 Mtetra
.648 .765 .934 r
.72141 .40534 .72482 .40967 .73224 .40727 .72885 .40293 Mtetra
.671 .774 .927 r
.72885 .40293 .73224 .40727 .73966 .40448 .73628 .40013 Mtetra
.696 .783 .918 r
.73628 .40013 .73966 .40448 .74706 .40124 .7437 .39688 Mtetra
.732 .795 .903 r
.7437 .39688 .74706 .40124 .75443 .39728 .75108 .39291 Mtetra
.812 .816 .854 r
.75108 .39291 .75443 .39728 .76165 .39121 .75832 .38682 Mtetra
.855 .822 .816 r
.75832 .38682 .76165 .39121 .76876 .38352 .76545 .37911 Mtetra
.918 .82 .734 r
.76545 .37911 .76876 .38352 .77555 .37189 .77226 .36746 Mtetra
.954 .805 .656 r
.77226 .36746 .77555 .37189 .78191 .35532 .77865 .35087 Mtetra
.967 .794 .616 r
.77865 .35087 .78191 .35532 .78796 .33553 .78473 .33105 Mtetra
.982 .769 .54 r
.78473 .33105 .78796 .33553 .79319 .30695 .78999 .30243 Mtetra
.985 .76 .516 r
.78999 .30243 .79319 .30695 .798 .27472 .79483 .27016 Mtetra
.942 .627 .41 r
.14566 .45782 .14981 .46146 .15201 .4912 .14783 .48758 Mtetra
.942 .619 .394 r
.14783 .48758 .15201 .4912 .15461 .51847 .15039 .51488 Mtetra
.935 .58 .322 r
.15039 .51488 .15461 .51847 .1582 .53765 .15396 .53407 Mtetra
.925 .547 .265 r
.15396 .53407 .1582 .53765 .16224 .55347 .15798 .5499 Mtetra
.875 .435 .089 r
.15798 .5499 .16224 .55347 .16692 .56396 .16265 .56039 Mtetra
.622 .097 0 r
.16265 .56039 .16692 .56396 .17215 .56963 .16788 .56606 Mtetra
0 .225 .691 r
.16788 .56606 .17215 .56963 .17764 .57323 .17337 .56966 Mtetra
.34 .641 .965 r
.17337 .56966 .17764 .57323 .18345 .57391 .17918 .57033 Mtetra
.497 .713 .967 r
.17918 .57033 .18345 .57391 .18939 .57352 .18513 .56993 Mtetra
.573 .741 .956 r
.18513 .56993 .18939 .57352 .19542 .57243 .19117 .56884 Mtetra
.632 .759 .939 r
.19117 .56884 .19542 .57243 .20153 .57067 .19728 .56707 Mtetra
.639 .761 .936 r
.19728 .56707 .20153 .57067 .20767 .56881 .20343 .56519 Mtetra
.648 .763 .933 r
.20343 .56519 .20767 .56881 .21383 .56682 .2096 .5632 Mtetra
.652 .764 .932 r
.2096 .5632 .21383 .56682 .22001 .56477 .21578 .56113 Mtetra
.653 .765 .931 r
.21578 .56113 .22001 .56477 .2262 .5627 .22199 .55906 Mtetra
.22199 .55906 .2262 .5627 .23241 .56063 .22821 .55698 Mtetra
.22821 .55698 .23241 .56063 .23864 .55854 .23444 .55489 Mtetra
.23444 .55489 .23864 .55854 .24488 .55645 .24069 .55279 Mtetra
.652 .764 .932 r
.24069 .55279 .24488 .55645 .25113 .55438 .24695 .5507 Mtetra
.653 .764 .931 r
.24695 .5507 .25113 .55438 .2574 .55229 .25323 .54861 Mtetra
.653 .765 .931 r
.25323 .54861 .2574 .55229 .26368 .5502 .25952 .5465 Mtetra
.651 .764 .932 r
.25952 .5465 .26368 .5502 .26997 .54812 .26582 .54441 Mtetra
.652 .764 .932 r
.26582 .54441 .26997 .54812 .27628 .54603 .27214 .54232 Mtetra
.27214 .54232 .27628 .54603 .28261 .54393 .27848 .54021 Mtetra
.651 .764 .932 r
.27848 .54021 .28261 .54393 .28895 .54184 .28483 .53811 Mtetra
.28483 .53811 .28895 .54184 .29531 .53975 .29119 .53601 Mtetra
.29119 .53601 .29531 .53975 .30168 .53764 .29757 .53389 Mtetra
.29757 .53389 .30168 .53764 .30806 .53555 .30396 .53179 Mtetra
.65 .764 .932 r
.30396 .53179 .30806 .53555 .31446 .53345 .31037 .52968 Mtetra
.651 .764 .932 r
.31037 .52968 .31446 .53345 .32088 .53134 .3168 .52756 Mtetra
.65 .764 .932 r
.3168 .52756 .32088 .53134 .32731 .52924 .32324 .52545 Mtetra
.649 .763 .933 r
.32324 .52545 .32731 .52924 .33375 .52714 .32969 .52334 Mtetra
.65 .764 .932 r
.32969 .52334 .33375 .52714 .34021 .52502 .33616 .52122 Mtetra
.33616 .52122 .34021 .52502 .34669 .52291 .34265 .51909 Mtetra
.649 .763 .933 r
.34265 .51909 .34669 .52291 .35318 .5208 .34915 .51698 Mtetra
.34915 .51698 .35318 .5208 .35969 .51869 .35567 .51485 Mtetra
.35567 .51485 .35969 .51869 .36621 .51656 .3622 .51272 Mtetra
.648 .763 .933 r
.3622 .51272 .36621 .51656 .37275 .51445 .36875 .5106 Mtetra
.36875 .5106 .37275 .51445 .3793 .51233 .37531 .50847 Mtetra
.649 .763 .933 r
.37531 .50847 .3793 .51233 .38587 .5102 .38189 .50633 Mtetra
.647 .763 .933 r
.38189 .50633 .38587 .5102 .39246 .50808 .38849 .5042 Mtetra
.648 .763 .933 r
.38849 .5042 .39246 .50808 .39906 .50595 .3951 .50206 Mtetra
.3951 .50206 .39906 .50595 .40568 .50382 .40173 .49992 Mtetra
.647 .763 .933 r
.40173 .49992 .40568 .50382 .41231 .50169 .40837 .49778 Mtetra
.40837 .49778 .41231 .50169 .41896 .49956 .41503 .49564 Mtetra
.648 .763 .933 r
.41503 .49564 .41896 .49956 .42563 .49741 .42171 .49349 Mtetra
.647 .763 .933 r
.42171 .49349 .42563 .49741 .43231 .49528 .4284 .49134 Mtetra
.646 .762 .934 r
.4284 .49134 .43231 .49528 .43901 .49314 .43511 .4892 Mtetra
.647 .763 .933 r
.43511 .4892 .43901 .49314 .44572 .49099 .44184 .48703 Mtetra
.646 .762 .934 r
.44184 .48703 .44572 .49099 .45246 .48885 .44858 .48488 Mtetra
.645 .762 .934 r
.44858 .48488 .45246 .48885 .4592 .48671 .45534 .48273 Mtetra
.646 .762 .934 r
.45534 .48273 .4592 .48671 .46597 .48455 .46212 .48056 Mtetra
.46212 .48056 .46597 .48455 .47275 .48239 .46891 .47839 Mtetra
.645 .762 .934 r
.46891 .47839 .47275 .48239 .47955 .48025 .47572 .47624 Mtetra
.47572 .47624 .47955 .48025 .48637 .47808 .48255 .47407 Mtetra
.48255 .47407 .48637 .47808 .4932 .47592 .48939 .47189 Mtetra
.644 .762 .934 r
.48939 .47189 .4932 .47592 .50005 .47377 .49625 .46973 Mtetra
.645 .762 .934 r
.49625 .46973 .50005 .47377 .50692 .4716 .50313 .46755 Mtetra
.50313 .46755 .50692 .4716 .51381 .46942 .51003 .46536 Mtetra
.643 .762 .935 r
.51003 .46536 .51381 .46942 .52071 .46726 .51694 .46319 Mtetra
.644 .762 .934 r
.51694 .46319 .52071 .46726 .52763 .46509 .52387 .46101 Mtetra
.52387 .46101 .52763 .46509 .53457 .4629 .53082 .45882 Mtetra
.643 .761 .935 r
.53082 .45882 .53457 .4629 .54152 .46073 .53779 .45664 Mtetra
.53779 .45664 .54152 .46073 .54849 .45856 .54478 .45445 Mtetra
.54478 .45445 .54849 .45856 .55549 .45638 .55178 .45226 Mtetra
.55178 .45226 .55549 .45638 .56249 .4542 .5588 .45007 Mtetra
.5588 .45007 .56249 .4542 .56952 .45201 .56584 .44787 Mtetra
.642 .761 .935 r
.56584 .44787 .56952 .45201 .57657 .44982 .57289 .44567 Mtetra
.57289 .44567 .57657 .44982 .58363 .44763 .57997 .44346 Mtetra
.57997 .44346 .58363 .44763 .59071 .44543 .58706 .44126 Mtetra
.58706 .44126 .59071 .44543 .59781 .44323 .59418 .43905 Mtetra
.59418 .43905 .59781 .44323 .60493 .44103 .60131 .43684 Mtetra
.641 .761 .935 r
.60131 .43684 .60493 .44103 .61207 .43883 .60846 .43463 Mtetra
.60846 .43463 .61207 .43883 .61922 .43663 .61562 .43241 Mtetra
.61562 .43241 .61922 .43663 .6264 .43442 .62281 .4302 Mtetra
.62281 .4302 .6264 .43442 .63359 .43221 .63002 .42798 Mtetra
.63002 .42798 .63359 .43221 .6408 .43 .63724 .42575 Mtetra
.64 .76 .935 r
.63724 .42575 .6408 .43 .64804 .42778 .64449 .42353 Mtetra
.64 .76 .936 r
.64449 .42353 .64804 .42778 .65529 .42557 .65175 .4213 Mtetra
.65175 .4213 .65529 .42557 .66256 .42335 .65903 .41907 Mtetra
.65903 .41907 .66256 .42335 .66985 .42113 .66633 .41684 Mtetra
.639 .76 .936 r
.66633 .41684 .66985 .42113 .67716 .4189 .67366 .4146 Mtetra
.67366 .4146 .67716 .4189 .68448 .41668 .681 .41237 Mtetra
.681 .41237 .68448 .41668 .69183 .41445 .68836 .41013 Mtetra
.68836 .41013 .69183 .41445 .6992 .41221 .69574 .40788 Mtetra
.69574 .40788 .6992 .41221 .70659 .40996 .70314 .40562 Mtetra
.641 .761 .935 r
.70314 .40562 .70659 .40996 .71399 .40769 .71056 .40333 Mtetra
.645 .762 .934 r
.71056 .40333 .71399 .40769 .72141 .40534 .71799 .40098 Mtetra
.648 .764 .933 r
.71799 .40098 .72141 .40534 .72885 .40293 .72544 .39856 Mtetra
.671 .773 .926 r
.72544 .39856 .72885 .40293 .73628 .40013 .73289 .39574 Mtetra
.696 .782 .917 r
.73289 .39574 .73628 .40013 .7437 .39688 .74032 .39248 Mtetra
.731 .794 .902 r
.74032 .39248 .7437 .39688 .75108 .39291 .74772 .38849 Mtetra
.811 .815 .853 r
.74772 .38849 .75108 .39291 .75832 .38682 .75498 .38239 Mtetra
.854 .821 .816 r
.75498 .38239 .75832 .38682 .76545 .37911 .76212 .37467 Mtetra
.917 .819 .734 r
.76212 .37467 .76545 .37911 .77226 .36746 .76895 .36299 Mtetra
.954 .804 .656 r
.76895 .36299 .77226 .36746 .77865 .35087 .77537 .34638 Mtetra
.967 .794 .616 r
.77537 .34638 .77865 .35087 .78473 .33105 .78148 .32653 Mtetra
.982 .769 .54 r
.78148 .32653 .78473 .33105 .78999 .30243 .78678 .29788 Mtetra
.985 .76 .516 r
.78678 .29788 .78999 .30243 .79483 .27016 .79166 .26557 Mtetra
.942 .627 .41 r
.1415 .45417 .14566 .45782 .14783 .48758 .14363 .48396 Mtetra
.942 .619 .394 r
.14363 .48396 .14783 .48758 .15039 .51488 .14615 .51127 Mtetra
.935 .58 .322 r
.14615 .51127 .15039 .51488 .15396 .53407 .1497 .53047 Mtetra
.925 .547 .265 r
.1497 .53047 .15396 .53407 .15798 .5499 .1537 .54631 Mtetra
.875 .435 .089 r
.1537 .54631 .15798 .5499 .16265 .56039 .15836 .55681 Mtetra
.623 .098 0 r
.15836 .55681 .16265 .56039 .16788 .56606 .16359 .56248 Mtetra
0 .225 .69 r
.16359 .56248 .16788 .56606 .17337 .56966 .16907 .56607 Mtetra
.339 .641 .965 r
.16907 .56607 .17337 .56966 .17918 .57033 .17489 .56674 Mtetra
.497 .713 .968 r
.17489 .56674 .17918 .57033 .18513 .56993 .18085 .56633 Mtetra
.573 .741 .956 r
.18085 .56633 .18513 .56993 .19117 .56884 .18689 .56523 Mtetra
.632 .759 .939 r
.18689 .56523 .19117 .56884 .19728 .56707 .19302 .56345 Mtetra
.639 .761 .937 r
.19302 .56345 .19728 .56707 .20343 .56519 .19917 .56157 Mtetra
.648 .764 .933 r
.19917 .56157 .20343 .56519 .2096 .5632 .20534 .55957 Mtetra
.652 .765 .932 r
.20534 .55957 .2096 .5632 .21578 .56113 .21154 .55749 Mtetra
.653 .765 .932 r
.21154 .55749 .21578 .56113 .22199 .55906 .21775 .55541 Mtetra
.21775 .55541 .22199 .55906 .22821 .55698 .22398 .55332 Mtetra
.653 .765 .931 r
.22398 .55332 .22821 .55698 .23444 .55489 .23022 .55122 Mtetra
.23022 .55122 .23444 .55489 .24069 .55279 .23648 .54911 Mtetra
.652 .765 .932 r
.23648 .54911 .24069 .55279 .24695 .5507 .24275 .54702 Mtetra
.653 .765 .932 r
.24275 .54702 .24695 .5507 .25323 .54861 .24904 .54491 Mtetra
.653 .765 .931 r
.24904 .54491 .25323 .54861 .25952 .5465 .25534 .5428 Mtetra
.651 .764 .932 r
.25534 .5428 .25952 .5465 .26582 .54441 .26165 .5407 Mtetra
.652 .765 .932 r
.26165 .5407 .26582 .54441 .27214 .54232 .26798 .53859 Mtetra
.26798 .53859 .27214 .54232 .27848 .54021 .27433 .53647 Mtetra
.651 .764 .932 r
.27433 .53647 .27848 .54021 .28483 .53811 .28068 .53437 Mtetra
.28068 .53437 .28483 .53811 .29119 .53601 .28706 .53226 Mtetra
.28706 .53226 .29119 .53601 .29757 .53389 .29345 .53013 Mtetra
.29345 .53013 .29757 .53389 .30396 .53179 .29985 .52802 Mtetra
.65 .764 .933 r
.29985 .52802 .30396 .53179 .31037 .52968 .30627 .52591 Mtetra
.651 .764 .932 r
.30627 .52591 .31037 .52968 .3168 .52756 .3127 .52378 Mtetra
.65 .764 .932 r
.3127 .52378 .3168 .52756 .32324 .52545 .31915 .52165 Mtetra
.649 .764 .933 r
.31915 .52165 .32324 .52545 .32969 .52334 .32562 .51953 Mtetra
.65 .764 .932 r
.32562 .51953 .32969 .52334 .33616 .52122 .3321 .5174 Mtetra
.65 .764 .933 r
.3321 .5174 .33616 .52122 .34265 .51909 .33859 .51527 Mtetra
.649 .764 .933 r
.33859 .51527 .34265 .51909 .34915 .51698 .3451 .51314 Mtetra
.3451 .51314 .34915 .51698 .35567 .51485 .35163 .51101 Mtetra
.35163 .51101 .35567 .51485 .3622 .51272 .35817 .50887 Mtetra
.648 .763 .933 r
.35817 .50887 .3622 .51272 .36875 .5106 .36473 .50674 Mtetra
.648 .764 .933 r
.36473 .50674 .36875 .5106 .37531 .50847 .3713 .50459 Mtetra
.649 .764 .933 r
.3713 .50459 .37531 .50847 .38189 .50633 .37789 .50244 Mtetra
.647 .763 .933 r
.37789 .50244 .38189 .50633 .38849 .5042 .3845 .50031 Mtetra
.648 .763 .933 r
.3845 .50031 .38849 .5042 .3951 .50206 .39112 .49816 Mtetra
.39112 .49816 .3951 .50206 .40173 .49992 .39776 .496 Mtetra
.647 .763 .934 r
.39776 .496 .40173 .49992 .40837 .49778 .40442 .49386 Mtetra
.40442 .49386 .40837 .49778 .41503 .49564 .41109 .49171 Mtetra
.648 .763 .933 r
.41109 .49171 .41503 .49564 .42171 .49349 .41777 .48954 Mtetra
.647 .763 .934 r
.41777 .48954 .42171 .49349 .4284 .49134 .42448 .48739 Mtetra
.646 .763 .934 r
.42448 .48739 .4284 .49134 .43511 .4892 .4312 .48523 Mtetra
.647 .763 .934 r
.4312 .48523 .43511 .4892 .44184 .48703 .43793 .48306 Mtetra
.646 .763 .934 r
.43793 .48306 .44184 .48703 .44858 .48488 .44469 .4809 Mtetra
.645 .762 .934 r
.44469 .4809 .44858 .48488 .45534 .48273 .45146 .47874 Mtetra
.646 .763 .934 r
.45146 .47874 .45534 .48273 .46212 .48056 .45824 .47656 Mtetra
.45824 .47656 .46212 .48056 .46891 .47839 .46505 .47438 Mtetra
.645 .762 .934 r
.46505 .47438 .46891 .47839 .47572 .47624 .47187 .47222 Mtetra
.645 .763 .934 r
.47187 .47222 .47572 .47624 .48255 .47407 .47871 .47004 Mtetra
.47871 .47004 .48255 .47407 .48939 .47189 .48556 .46785 Mtetra
.644 .762 .935 r
.48556 .46785 .48939 .47189 .49625 .46973 .49244 .46568 Mtetra
.645 .762 .934 r
.49244 .46568 .49625 .46973 .50313 .46755 .49933 .46349 Mtetra
.49933 .46349 .50313 .46755 .51003 .46536 .50624 .46129 Mtetra
.643 .762 .935 r
.50624 .46129 .51003 .46536 .51694 .46319 .51316 .45911 Mtetra
.644 .762 .935 r
.51316 .45911 .51694 .46319 .52387 .46101 .5201 .45692 Mtetra
.644 .762 .934 r
.5201 .45692 .52387 .46101 .53082 .45882 .52706 .45471 Mtetra
.643 .762 .935 r
.52706 .45471 .53082 .45882 .53779 .45664 .53404 .45252 Mtetra
.53404 .45252 .53779 .45664 .54478 .45445 .54104 .45033 Mtetra
.54104 .45033 .54478 .45445 .55178 .45226 .54805 .44813 Mtetra
.54805 .44813 .55178 .45226 .5588 .45007 .55509 .44592 Mtetra
.55509 .44592 .5588 .45007 .56584 .44787 .56214 .44371 Mtetra
.642 .762 .935 r
.56214 .44371 .56584 .44787 .57289 .44567 .56921 .4415 Mtetra
.642 .761 .935 r
.56921 .4415 .57289 .44567 .57997 .44346 .57629 .43929 Mtetra
.57629 .43929 .57997 .44346 .58706 .44126 .5834 .43707 Mtetra
.5834 .43707 .58706 .44126 .59418 .43905 .59052 .43486 Mtetra
.59052 .43486 .59418 .43905 .60131 .43684 .59767 .43263 Mtetra
.641 .761 .935 r
.59767 .43263 .60131 .43684 .60846 .43463 .60483 .43041 Mtetra
.60483 .43041 .60846 .43463 .61562 .43241 .61201 .42819 Mtetra
.61201 .42819 .61562 .43241 .62281 .4302 .61921 .42596 Mtetra
.641 .761 .936 r
.61921 .42596 .62281 .4302 .63002 .42798 .62643 .42373 Mtetra
.64 .761 .936 r
.62643 .42373 .63002 .42798 .63724 .42575 .63366 .42149 Mtetra
.63366 .42149 .63724 .42575 .64449 .42353 .64092 .41926 Mtetra
.64092 .41926 .64449 .42353 .65175 .4213 .6482 .41702 Mtetra
.6482 .41702 .65175 .4213 .65903 .41907 .65549 .41478 Mtetra
.65549 .41478 .65903 .41907 .66633 .41684 .66281 .41253 Mtetra
.639 .76 .936 r
.66281 .41253 .66633 .41684 .67366 .4146 .67014 .41029 Mtetra
.67014 .41029 .67366 .4146 .681 .41237 .67749 .40804 Mtetra
.67749 .40804 .681 .41237 .68836 .41013 .68487 .40579 Mtetra
.68487 .40579 .68836 .41013 .69574 .40788 .69226 .40353 Mtetra
.639 .761 .936 r
.69226 .40353 .69574 .40788 .70314 .40562 .69968 .40126 Mtetra
.641 .761 .936 r
.69968 .40126 .70314 .40562 .71056 .40333 .70711 .39896 Mtetra
.645 .763 .935 r
.70711 .39896 .71056 .40333 .71799 .40098 .71456 .39659 Mtetra
.648 .764 .934 r
.71456 .39659 .71799 .40098 .72544 .39856 .72202 .39416 Mtetra
.671 .773 .926 r
.72202 .39416 .72544 .39856 .73289 .39574 .72948 .39134 Mtetra
.696 .782 .918 r
.72948 .39134 .73289 .39574 .74032 .39248 .73693 .38806 Mtetra
.731 .794 .902 r
.73693 .38806 .74032 .39248 .74772 .38849 .74434 .38406 Mtetra
.811 .815 .853 r
.74434 .38406 .74772 .38849 .75498 .38239 .75162 .37795 Mtetra
.854 .821 .816 r
.75162 .37795 .75498 .38239 .76212 .37467 .75878 .37021 Mtetra
.917 .819 .734 r
.75878 .37021 .76212 .37467 .76895 .36299 .76563 .35851 Mtetra
.954 .805 .656 r
.76563 .35851 .76895 .36299 .77537 .34638 .77208 .34188 Mtetra
.967 .794 .616 r
.77208 .34188 .77537 .34638 .78148 .32653 .77821 .322 Mtetra
.982 .769 .54 r
.77821 .322 .78148 .32653 .78678 .29788 .78355 .29331 Mtetra
.985 .76 .516 r
.78355 .29331 .78678 .29788 .79166 .26557 .78847 .26097 Mtetra
.942 .627 .41 r
.13733 .45051 .1415 .45417 .14363 .48396 .13941 .48032 Mtetra
.942 .619 .394 r
.13941 .48032 .14363 .48396 .14615 .51127 .1419 .50766 Mtetra
.935 .58 .323 r
.1419 .50766 .14615 .51127 .1497 .53047 .14542 .52688 Mtetra
.925 .547 .265 r
.14542 .52688 .1497 .53047 .1537 .54631 .1494 .54272 Mtetra
.875 .435 .09 r
.1494 .54272 .1537 .54631 .15836 .55681 .15405 .55323 Mtetra
.624 .098 0 r
.15405 .55323 .15836 .55681 .16359 .56248 .15927 .55889 Mtetra
0 .224 .689 r
.15927 .55889 .16359 .56248 .16907 .56607 .16476 .56249 Mtetra
.338 .642 .965 r
.16476 .56249 .16907 .56607 .17489 .56674 .17058 .56315 Mtetra
.497 .714 .968 r
.17058 .56315 .17489 .56674 .18085 .56633 .17654 .56273 Mtetra
.572 .742 .956 r
.17654 .56273 .18085 .56633 .18689 .56523 .18259 .56162 Mtetra
.632 .76 .94 r
.18259 .56162 .18689 .56523 .19302 .56345 .18873 .55984 Mtetra
.639 .762 .937 r
.18873 .55984 .19302 .56345 .19917 .56157 .19489 .55794 Mtetra
.648 .764 .934 r
.19489 .55794 .19917 .56157 .20534 .55957 .20107 .55593 Mtetra
.652 .765 .932 r
.20107 .55593 .20534 .55957 .21154 .55749 .20728 .55385 Mtetra
.653 .766 .932 r
.20728 .55385 .21154 .55749 .21775 .55541 .2135 .55176 Mtetra
.2135 .55176 .21775 .55541 .22398 .55332 .21974 .54966 Mtetra
.21974 .54966 .22398 .55332 .23022 .55122 .22599 .54755 Mtetra
.22599 .54755 .23022 .55122 .23648 .54911 .23226 .54543 Mtetra
.652 .765 .932 r
.23226 .54543 .23648 .54911 .24275 .54702 .23853 .54333 Mtetra
.653 .765 .932 r
.23853 .54333 .24275 .54702 .24904 .54491 .24483 .54121 Mtetra
.653 .766 .932 r
.24483 .54121 .24904 .54491 .25534 .5428 .25114 .53909 Mtetra
.651 .765 .933 r
.25114 .53909 .25534 .5428 .26165 .5407 .25746 .53698 Mtetra
.652 .765 .932 r
.25746 .53698 .26165 .5407 .26798 .53859 .2638 .53487 Mtetra
.2638 .53487 .26798 .53859 .27433 .53647 .27015 .53274 Mtetra
.651 .765 .933 r
.27015 .53274 .27433 .53647 .28068 .53437 .27652 .53062 Mtetra
.27652 .53062 .28068 .53437 .28706 .53226 .2829 .5285 Mtetra
.651 .765 .932 r
.2829 .5285 .28706 .53226 .29345 .53013 .2893 .52637 Mtetra
.65 .765 .933 r
.2893 .52637 .29345 .53013 .29985 .52802 .29572 .52424 Mtetra
.29572 .52424 .29985 .52802 .30627 .52591 .30214 .52212 Mtetra
.651 .765 .933 r
.30214 .52212 .30627 .52591 .3127 .52378 .30859 .51998 Mtetra
.65 .765 .933 r
.30859 .51998 .3127 .52378 .31915 .52165 .31505 .51785 Mtetra
.649 .764 .933 r
.31505 .51785 .31915 .52165 .32562 .51953 .32152 .51572 Mtetra
.65 .765 .933 r
.32152 .51572 .32562 .51953 .3321 .5174 .32801 .51358 Mtetra
.32801 .51358 .3321 .5174 .33859 .51527 .33452 .51144 Mtetra
.649 .764 .933 r
.33452 .51144 .33859 .51527 .3451 .51314 .34104 .5093 Mtetra
.34104 .5093 .3451 .51314 .35163 .51101 .34757 .50716 Mtetra
.34757 .50716 .35163 .51101 .35817 .50887 .35413 .505 Mtetra
.648 .764 .934 r
.35413 .505 .35817 .50887 .36473 .50674 .36069 .50287 Mtetra
.36069 .50287 .36473 .50674 .3713 .50459 .36728 .50072 Mtetra
.649 .764 .933 r
.36728 .50072 .3713 .50459 .37789 .50244 .37388 .49855 Mtetra
.647 .764 .934 r
.37388 .49855 .37789 .50244 .3845 .50031 .38049 .49641 Mtetra
.648 .764 .934 r
.38049 .49641 .3845 .50031 .39112 .49816 .38713 .49425 Mtetra
.38713 .49425 .39112 .49816 .39776 .496 .39378 .49208 Mtetra
.647 .764 .934 r
.39378 .49208 .39776 .496 .40442 .49386 .40044 .48993 Mtetra
.40044 .48993 .40442 .49386 .41109 .49171 .40712 .48777 Mtetra
.40712 .48777 .41109 .49171 .41777 .48954 .41382 .4856 Mtetra
.646 .764 .934 r
.41382 .4856 .41777 .48954 .42448 .48739 .42053 .48343 Mtetra
.646 .763 .934 r
.42053 .48343 .42448 .48739 .4312 .48523 .42726 .48127 Mtetra
.647 .764 .934 r
.42726 .48127 .4312 .48523 .43793 .48306 .43401 .47908 Mtetra
.646 .763 .934 r
.43401 .47908 .43793 .48306 .44469 .4809 .44078 .47691 Mtetra
.645 .763 .935 r
.44078 .47691 .44469 .4809 .45146 .47874 .44756 .47474 Mtetra
.646 .763 .934 r
.44756 .47474 .45146 .47874 .45824 .47656 .45436 .47255 Mtetra
.45436 .47255 .45824 .47656 .46505 .47438 .46117 .47037 Mtetra
.645 .763 .935 r
.46117 .47037 .46505 .47438 .47187 .47222 .468 .46819 Mtetra
.468 .46819 .47187 .47222 .47871 .47004 .47485 .466 Mtetra
.47485 .466 .47871 .47004 .48556 .46785 .48172 .4638 Mtetra
.644 .763 .935 r
.48172 .4638 .48556 .46785 .49244 .46568 .4886 .46162 Mtetra
.645 .763 .935 r
.4886 .46162 .49244 .46568 .49933 .46349 .4955 .45942 Mtetra
.4955 .45942 .49933 .46349 .50624 .46129 .50242 .45721 Mtetra
.643 .762 .935 r
.50242 .45721 .50624 .46129 .51316 .45911 .50936 .45502 Mtetra
.644 .763 .935 r
.50936 .45502 .51316 .45911 .5201 .45692 .51631 .45282 Mtetra
.51631 .45282 .5201 .45692 .52706 .45471 .52329 .4506 Mtetra
.643 .762 .935 r
.52329 .4506 .52706 .45471 .53404 .45252 .53028 .4484 Mtetra
.53028 .4484 .53404 .45252 .54104 .45033 .53728 .4462 Mtetra
.53728 .4462 .54104 .45033 .54805 .44813 .54431 .44399 Mtetra
.54431 .44399 .54805 .44813 .55509 .44592 .55136 .44177 Mtetra
.55136 .44177 .55509 .44592 .56214 .44371 .55842 .43955 Mtetra
.642 .762 .935 r
.55842 .43955 .56214 .44371 .56921 .4415 .5655 .43733 Mtetra
.642 .762 .936 r
.5655 .43733 .56921 .4415 .57629 .43929 .5726 .43511 Mtetra
.5726 .43511 .57629 .43929 .5834 .43707 .57972 .43288 Mtetra
.57972 .43288 .5834 .43707 .59052 .43486 .58685 .43065 Mtetra
.58685 .43065 .59052 .43486 .59767 .43263 .59401 .42842 Mtetra
.641 .762 .936 r
.59401 .42842 .59767 .43263 .60483 .43041 .60118 .42619 Mtetra
.60118 .42619 .60483 .43041 .61201 .42819 .60837 .42395 Mtetra
.60837 .42395 .61201 .42819 .61921 .42596 .61559 .42171 Mtetra
.61559 .42171 .61921 .42596 .62643 .42373 .62282 .41947 Mtetra
.64 .761 .936 r
.62282 .41947 .62643 .42373 .63366 .42149 .63007 .41722 Mtetra
.63007 .41722 .63366 .42149 .64092 .41926 .63734 .41498 Mtetra
.63734 .41498 .64092 .41926 .6482 .41702 .64462 .41273 Mtetra
.64462 .41273 .6482 .41702 .65549 .41478 .65193 .41048 Mtetra
.65193 .41048 .65549 .41478 .66281 .41253 .65926 .40822 Mtetra
.639 .761 .936 r
.65926 .40822 .66281 .41253 .67014 .41029 .66661 .40597 Mtetra
.639 .761 .937 r
.66661 .40597 .67014 .41029 .67749 .40804 .67398 .40371 Mtetra
.67398 .40371 .67749 .40804 .68487 .40579 .68136 .40144 Mtetra
.68136 .40144 .68487 .40579 .69226 .40353 .68877 .39917 Mtetra
.639 .761 .936 r
.68877 .39917 .69226 .40353 .69968 .40126 .6962 .39689 Mtetra
.641 .762 .936 r
.6962 .39689 .69968 .40126 .70711 .39896 .70364 .39458 Mtetra
.645 .763 .935 r
.70364 .39458 .70711 .39896 .71456 .39659 .7111 .39221 Mtetra
.648 .765 .934 r
.7111 .39221 .71456 .39659 .72202 .39416 .71858 .38976 Mtetra
.671 .774 .927 r
.71858 .38976 .72202 .39416 .72948 .39134 .72605 .38693 Mtetra
.696 .783 .918 r
.72605 .38693 .72948 .39134 .73693 .38806 .73352 .38363 Mtetra
.731 .795 .903 r
.73352 .38363 .73693 .38806 .74434 .38406 .74095 .37962 Mtetra
.812 .816 .854 r
.74095 .37962 .74434 .38406 .75162 .37795 .74824 .3735 Mtetra
.855 .822 .816 r
.74824 .3735 .75162 .37795 .75878 .37021 .75542 .36574 Mtetra
.918 .82 .734 r
.75542 .36574 .75878 .37021 .76563 .35851 .7623 .35402 Mtetra
.954 .805 .656 r
.7623 .35402 .76563 .35851 .77208 .34188 .76877 .33736 Mtetra
.967 .794 .616 r
.76877 .33736 .77208 .34188 .77821 .322 .77493 .31746 Mtetra
.982 .769 .54 r
.77493 .31746 .77821 .322 .78355 .29331 .7803 .28873 Mtetra
.985 .76 .516 r
.7803 .28873 .78355 .29331 .78847 .26097 .78526 .25635 Mtetra
.942 .627 .41 r
.13313 .44683 .13733 .45051 .13941 .48032 .13517 .47666 Mtetra
.942 .619 .394 r
.13517 .47666 .13941 .48032 .1419 .50766 .13762 .50402 Mtetra
.935 .58 .322 r
.13762 .50402 .1419 .50766 .14542 .52688 .14112 .52325 Mtetra
.925 .547 .265 r
.14112 .52325 .14542 .52688 .1494 .54272 .14508 .53911 Mtetra
.875 .435 .089 r
.14508 .53911 .1494 .54272 .15405 .55323 .14972 .54962 Mtetra
.622 .097 0 r
.14972 .54962 .15405 .55323 .15927 .55889 .15494 .55528 Mtetra
0 .225 .69 r
.15494 .55528 .15927 .55889 .16476 .56249 .16043 .55887 Mtetra
.34 .641 .965 r
.16043 .55887 .16476 .56249 .17058 .56315 .16626 .55953 Mtetra
.497 .713 .968 r
.16626 .55953 .17058 .56315 .17654 .56273 .17222 .5591 Mtetra
.573 .741 .956 r
.17222 .5591 .17654 .56273 .18259 .56162 .17828 .55799 Mtetra
.632 .759 .939 r
.17828 .55799 .18259 .56162 .18873 .55984 .18442 .55619 Mtetra
.639 .761 .937 r
.18442 .55619 .18873 .55984 .19489 .55794 .19059 .55429 Mtetra
.648 .764 .933 r
.19059 .55429 .19489 .55794 .20107 .55593 .19678 .55227 Mtetra
.652 .765 .932 r
.19678 .55227 .20107 .55593 .20728 .55385 .203 .55018 Mtetra
.653 .765 .932 r
.203 .55018 .20728 .55385 .2135 .55176 .20923 .54807 Mtetra
.653 .765 .931 r
.20923 .54807 .2135 .55176 .21974 .54966 .21548 .54597 Mtetra
.21548 .54597 .21974 .54966 .22599 .54755 .22174 .54385 Mtetra
.22174 .54385 .22599 .54755 .23226 .54543 .22801 .54172 Mtetra
.652 .765 .932 r
.22801 .54172 .23226 .54543 .23853 .54333 .2343 .53961 Mtetra
.653 .765 .932 r
.2343 .53961 .23853 .54333 .24483 .54121 .2406 .53749 Mtetra
.653 .765 .931 r
.2406 .53749 .24483 .54121 .25114 .53909 .24692 .53535 Mtetra
.651 .764 .932 r
.24692 .53535 .25114 .53909 .25746 .53698 .25325 .53324 Mtetra
.652 .765 .932 r
.25325 .53324 .25746 .53698 .2638 .53487 .2596 .53111 Mtetra
.2596 .53111 .2638 .53487 .27015 .53274 .26597 .52897 Mtetra
.651 .764 .932 r
.26597 .52897 .27015 .53274 .27652 .53062 .27234 .52685 Mtetra
.27234 .52685 .27652 .53062 .2829 .5285 .27873 .52472 Mtetra
.27873 .52472 .2829 .5285 .2893 .52637 .28514 .52257 Mtetra
.28514 .52257 .2893 .52637 .29572 .52424 .29156 .52044 Mtetra
.65 .764 .932 r
.29156 .52044 .29572 .52424 .30214 .52212 .298 .51831 Mtetra
.651 .764 .932 r
.298 .51831 .30214 .52212 .30859 .51998 .30446 .51616 Mtetra
.65 .764 .932 r
.30446 .51616 .30859 .51998 .31505 .51785 .31092 .51402 Mtetra
.649 .764 .933 r
.31092 .51402 .31505 .51785 .32152 .51572 .31741 .51188 Mtetra
.65 .764 .932 r
.31741 .51188 .32152 .51572 .32801 .51358 .32391 .50973 Mtetra
.65 .764 .933 r
.32391 .50973 .32801 .51358 .33452 .51144 .33042 .50758 Mtetra
.649 .764 .933 r
.33042 .50758 .33452 .51144 .34104 .5093 .33695 .50543 Mtetra
.33695 .50543 .34104 .5093 .34757 .50716 .3435 .50328 Mtetra
.3435 .50328 .34757 .50716 .35413 .505 .35006 .50111 Mtetra
.648 .763 .933 r
.35006 .50111 .35413 .505 .36069 .50287 .35664 .49897 Mtetra
.35664 .49897 .36069 .50287 .36728 .50072 .36323 .49681 Mtetra
.649 .764 .933 r
.36323 .49681 .36728 .50072 .37388 .49855 .36985 .49463 Mtetra
.647 .763 .933 r
.36985 .49463 .37388 .49855 .38049 .49641 .37647 .49248 Mtetra
.648 .763 .933 r
.37647 .49248 .38049 .49641 .38713 .49425 .38311 .49031 Mtetra
.38311 .49031 .38713 .49425 .39378 .49208 .38977 .48814 Mtetra
.647 .763 .934 r
.38977 .48814 .39378 .49208 .40044 .48993 .39645 .48597 Mtetra
.39645 .48597 .40044 .48993 .40712 .48777 .40314 .4838 Mtetra
.648 .763 .933 r
.40314 .4838 .40712 .48777 .41382 .4856 .40985 .48162 Mtetra
.647 .763 .934 r
.40985 .48162 .41382 .4856 .42053 .48343 .41657 .47944 Mtetra
.646 .763 .934 r
.41657 .47944 .42053 .48343 .42726 .48127 .42331 .47727 Mtetra
.647 .763 .934 r
.42331 .47727 .42726 .48127 .43401 .47908 .43007 .47508 Mtetra
.646 .763 .934 r
.43007 .47508 .43401 .47908 .44078 .47691 .43685 .47289 Mtetra
.645 .762 .934 r
.43685 .47289 .44078 .47691 .44756 .47474 .44364 .47071 Mtetra
.646 .763 .934 r
.44364 .47071 .44756 .47474 .45436 .47255 .45045 .46851 Mtetra
.45045 .46851 .45436 .47255 .46117 .47037 .45727 .46632 Mtetra
.645 .762 .934 r
.45727 .46632 .46117 .47037 .468 .46819 .46412 .46413 Mtetra
.46412 .46413 .468 .46819 .47485 .466 .47098 .46193 Mtetra
.47098 .46193 .47485 .466 .48172 .4638 .47786 .45972 Mtetra
.644 .762 .934 r
.47786 .45972 .48172 .4638 .4886 .46162 .48475 .45753 Mtetra
.645 .762 .934 r
.48475 .45753 .4886 .46162 .4955 .45942 .49166 .45532 Mtetra
.49166 .45532 .4955 .45942 .50242 .45721 .49859 .4531 Mtetra
.643 .762 .935 r
.49859 .4531 .50242 .45721 .50936 .45502 .50554 .4509 Mtetra
.644 .762 .935 r
.50554 .4509 .50936 .45502 .51631 .45282 .51251 .44869 Mtetra
.644 .762 .934 r
.51251 .44869 .51631 .45282 .52329 .4506 .51949 .44646 Mtetra
.643 .762 .935 r
.51949 .44646 .52329 .4506 .53028 .4484 .52649 .44425 Mtetra
.52649 .44425 .53028 .4484 .53728 .4462 .53351 .44204 Mtetra
.53351 .44204 .53728 .4462 .54431 .44399 .54055 .43981 Mtetra
.54055 .43981 .54431 .44399 .55136 .44177 .54761 .43759 Mtetra
.54761 .43759 .55136 .44177 .55842 .43955 .55468 .43536 Mtetra
.642 .761 .935 r
.55468 .43536 .55842 .43955 .5655 .43733 .56177 .43312 Mtetra
.56177 .43312 .5655 .43733 .5726 .43511 .56889 .43089 Mtetra
.56889 .43089 .5726 .43511 .57972 .43288 .57601 .42865 Mtetra
.57601 .42865 .57972 .43288 .58685 .43065 .58316 .42641 Mtetra
.58316 .42641 .58685 .43065 .59401 .42842 .59033 .42417 Mtetra
.641 .761 .935 r
.59033 .42417 .59401 .42842 .60118 .42619 .59752 .42193 Mtetra
.59752 .42193 .60118 .42619 .60837 .42395 .60472 .41968 Mtetra
.60472 .41968 .60837 .42395 .61559 .42171 .61195 .41743 Mtetra
.641 .761 .936 r
.61195 .41743 .61559 .42171 .62282 .41947 .61919 .41518 Mtetra
.64 .761 .936 r
.61919 .41518 .62282 .41947 .63007 .41722 .62645 .41292 Mtetra
.62645 .41292 .63007 .41722 .63734 .41498 .63373 .41066 Mtetra
.63373 .41066 .63734 .41498 .64462 .41273 .64104 .4084 Mtetra
.64104 .4084 .64462 .41273 .65193 .41048 .64836 .40614 Mtetra
.64836 .40614 .65193 .41048 .65926 .40822 .6557 .40388 Mtetra
.639 .76 .936 r
.6557 .40388 .65926 .40822 .66661 .40597 .66306 .40161 Mtetra
.66306 .40161 .66661 .40597 .67398 .40371 .67044 .39934 Mtetra
.67044 .39934 .67398 .40371 .68136 .40144 .67784 .39706 Mtetra
.67784 .39706 .68136 .40144 .68877 .39917 .68526 .39478 Mtetra
.68526 .39478 .68877 .39917 .6962 .39689 .6927 .39249 Mtetra
.641 .761 .936 r
.6927 .39249 .6962 .39689 .70364 .39458 .70016 .39017 Mtetra
.645 .763 .935 r
.70016 .39017 .70364 .39458 .7111 .39221 .70763 .38778 Mtetra
.648 .764 .934 r
.70763 .38778 .7111 .39221 .71858 .38976 .71513 .38533 Mtetra
.671 .773 .926 r
.71513 .38533 .71858 .38976 .72605 .38693 .72261 .38248 Mtetra
.696 .782 .918 r
.72261 .38248 .72605 .38693 .73352 .38363 .73009 .37917 Mtetra
.731 .794 .902 r
.73009 .37917 .73352 .38363 .74095 .37962 .73753 .37515 Mtetra
.811 .815 .854 r
.73753 .37515 .74095 .37962 .74824 .3735 .74484 .36901 Mtetra
.854 .821 .816 r
.74484 .36901 .74824 .3735 .75542 .36574 .75204 .36123 Mtetra
.917 .819 .734 r
.75204 .36123 .75542 .36574 .7623 .35402 .75894 .3495 Mtetra
.954 .805 .656 r
.75894 .3495 .7623 .35402 .76877 .33736 .76544 .33281 Mtetra
.967 .794 .616 r
.76544 .33281 .76877 .33736 .77493 .31746 .77163 .31288 Mtetra
.982 .769 .54 r
.77163 .31288 .77493 .31746 .7803 .28873 .77704 .28411 Mtetra
.985 .76 .516 r
.77704 .28411 .7803 .28873 .78526 .25635 .78204 .2517 Mtetra
.942 .627 .41 r
.12892 .44313 .13313 .44683 .13517 .47666 .13092 .47299 Mtetra
.942 .619 .394 r
.13092 .47299 .13517 .47666 .13762 .50402 .13333 .50037 Mtetra
.935 .58 .322 r
.13333 .50037 .13762 .50402 .14112 .52325 .1368 .51961 Mtetra
.925 .547 .265 r
.1368 .51961 .14112 .52325 .14508 .53911 .14075 .53548 Mtetra
.875 .435 .089 r
.14075 .53548 .14508 .53911 .14972 .54962 .14537 .54599 Mtetra
.622 .097 0 r
.14537 .54599 .14972 .54962 .15494 .55528 .15059 .55165 Mtetra
0 .225 .691 r
.15059 .55165 .15494 .55528 .16043 .55887 .15608 .55524 Mtetra
.34 .642 .965 r
.15608 .55524 .16043 .55887 .16626 .55953 .16191 .55589 Mtetra
.497 .713 .968 r
.16191 .55589 .16626 .55953 .17222 .5591 .16788 .55546 Mtetra
.573 .741 .956 r
.16788 .55546 .17222 .5591 .17828 .55799 .17395 .55433 Mtetra
.632 .759 .939 r
.17395 .55433 .17828 .55799 .18442 .55619 .1801 .55253 Mtetra
.639 .761 .937 r
.1801 .55253 .18442 .55619 .19059 .55429 .18627 .55062 Mtetra
.648 .764 .933 r
.18627 .55062 .19059 .55429 .19678 .55227 .19248 .54859 Mtetra
.652 .765 .932 r
.19248 .54859 .19678 .55227 .203 .55018 .1987 .54649 Mtetra
.653 .765 .932 r
.1987 .54649 .203 .55018 .20923 .54807 .20494 .54438 Mtetra
.653 .765 .931 r
.20494 .54438 .20923 .54807 .21548 .54597 .21119 .54226 Mtetra
.21119 .54226 .21548 .54597 .22174 .54385 .21746 .54013 Mtetra
.21746 .54013 .22174 .54385 .22801 .54172 .22375 .53799 Mtetra
.652 .765 .932 r
.22375 .53799 .22801 .54172 .2343 .53961 .23005 .53587 Mtetra
.653 .765 .932 r
.23005 .53587 .2343 .53961 .2406 .53749 .23636 .53374 Mtetra
.653 .765 .931 r
.23636 .53374 .2406 .53749 .24692 .53535 .24269 .5316 Mtetra
.651 .764 .932 r
.24269 .5316 .24692 .53535 .25325 .53324 .24903 .52947 Mtetra
.652 .765 .932 r
.24903 .52947 .25325 .53324 .2596 .53111 .25538 .52734 Mtetra
.25538 .52734 .2596 .53111 .26597 .52897 .26176 .52519 Mtetra
.651 .764 .932 r
.26176 .52519 .26597 .52897 .27234 .52685 .26814 .52305 Mtetra
.26814 .52305 .27234 .52685 .27873 .52472 .27454 .52092 Mtetra
.652 .764 .932 r
.27454 .52092 .27873 .52472 .28514 .52257 .28096 .51876 Mtetra
.651 .764 .932 r
.28096 .51876 .28514 .52257 .29156 .52044 .28739 .51662 Mtetra
.65 .764 .932 r
.28739 .51662 .29156 .52044 .298 .51831 .29384 .51448 Mtetra
.651 .764 .932 r
.29384 .51448 .298 .51831 .30446 .51616 .3003 .51232 Mtetra
.65 .764 .932 r
.3003 .51232 .30446 .51616 .31092 .51402 .30678 .51017 Mtetra
.649 .764 .933 r
.30678 .51017 .31092 .51402 .31741 .51188 .31328 .50802 Mtetra
.65 .764 .932 r
.31328 .50802 .31741 .51188 .32391 .50973 .31979 .50586 Mtetra
.65 .764 .933 r
.31979 .50586 .32391 .50973 .33042 .50758 .32631 .5037 Mtetra
.649 .764 .933 r
.32631 .5037 .33042 .50758 .33695 .50543 .33285 .50155 Mtetra
.33285 .50155 .33695 .50543 .3435 .50328 .33941 .49938 Mtetra
.33941 .49938 .3435 .50328 .35006 .50111 .34598 .49721 Mtetra
.648 .763 .933 r
.34598 .49721 .35006 .50111 .35664 .49897 .35257 .49505 Mtetra
.35257 .49505 .35664 .49897 .36323 .49681 .35917 .49288 Mtetra
.649 .764 .933 r
.35917 .49288 .36323 .49681 .36985 .49463 .36579 .4907 Mtetra
.647 .763 .933 r
.36579 .4907 .36985 .49463 .37647 .49248 .37243 .48853 Mtetra
.648 .763 .933 r
.37243 .48853 .37647 .49248 .38311 .49031 .37908 .48636 Mtetra
.37908 .48636 .38311 .49031 .38977 .48814 .38575 .48417 Mtetra
.647 .763 .934 r
.38575 .48417 .38977 .48814 .39645 .48597 .39244 .48199 Mtetra
.39244 .48199 .39645 .48597 .40314 .4838 .39914 .47981 Mtetra
.648 .763 .933 r
.39914 .47981 .40314 .4838 .40985 .48162 .40586 .47762 Mtetra
.647 .763 .934 r
.40586 .47762 .40985 .48162 .41657 .47944 .41259 .47543 Mtetra
.646 .763 .934 r
.41259 .47543 .41657 .47944 .42331 .47727 .41934 .47325 Mtetra
.647 .763 .934 r
.41934 .47325 .42331 .47727 .43007 .47508 .42611 .47105 Mtetra
.646 .763 .934 r
.42611 .47105 .43007 .47508 .43685 .47289 .4329 .46885 Mtetra
.645 .762 .934 r
.4329 .46885 .43685 .47289 .44364 .47071 .4397 .46666 Mtetra
.646 .763 .934 r
.4397 .46666 .44364 .47071 .45045 .46851 .44652 .46446 Mtetra
.44652 .46446 .45045 .46851 .45727 .46632 .45336 .46225 Mtetra
.645 .762 .934 r
.45336 .46225 .45727 .46632 .46412 .46413 .46021 .46005 Mtetra
.46021 .46005 .46412 .46413 .47098 .46193 .46709 .45784 Mtetra
.46709 .45784 .47098 .46193 .47786 .45972 .47397 .45562 Mtetra
.644 .762 .934 r
.47397 .45562 .47786 .45972 .48475 .45753 .48088 .45342 Mtetra
.645 .762 .934 r
.48088 .45342 .48475 .45753 .49166 .45532 .4878 .4512 Mtetra
.4878 .4512 .49166 .45532 .49859 .4531 .49475 .44897 Mtetra
.643 .762 .935 r
.49475 .44897 .49859 .4531 .50554 .4509 .50171 .44676 Mtetra
.644 .762 .935 r
.50171 .44676 .50554 .4509 .51251 .44869 .50868 .44454 Mtetra
.644 .762 .934 r
.50868 .44454 .51251 .44869 .51949 .44646 .51568 .4423 Mtetra
.643 .762 .935 r
.51568 .4423 .51949 .44646 .52649 .44425 .52269 .44008 Mtetra
.52269 .44008 .52649 .44425 .53351 .44204 .52972 .43785 Mtetra
.52972 .43785 .53351 .44204 .54055 .43981 .53677 .43562 Mtetra
.53677 .43562 .54055 .43981 .54761 .43759 .54384 .43338 Mtetra
.54384 .43338 .54761 .43759 .55468 .43536 .55093 .43114 Mtetra
.642 .761 .935 r
.55093 .43114 .55468 .43536 .56177 .43312 .55803 .4289 Mtetra
.55803 .4289 .56177 .43312 .56889 .43089 .56515 .42665 Mtetra
.56515 .42665 .56889 .43089 .57601 .42865 .5723 .42441 Mtetra
.5723 .42441 .57601 .42865 .58316 .42641 .57946 .42216 Mtetra
.57946 .42216 .58316 .42641 .59033 .42417 .58664 .4199 Mtetra
.641 .761 .935 r
.58664 .4199 .59033 .42417 .59752 .42193 .59384 .41765 Mtetra
.59384 .41765 .59752 .42193 .60472 .41968 .60105 .41539 Mtetra
.60105 .41539 .60472 .41968 .61195 .41743 .60829 .41313 Mtetra
.641 .761 .936 r
.60829 .41313 .61195 .41743 .61919 .41518 .61555 .41087 Mtetra
.64 .761 .936 r
.61555 .41087 .61919 .41518 .62645 .41292 .62282 .4086 Mtetra
.62282 .4086 .62645 .41292 .63373 .41066 .63012 .40633 Mtetra
.63012 .40633 .63373 .41066 .64104 .4084 .63743 .40406 Mtetra
.63743 .40406 .64104 .4084 .64836 .40614 .64476 .40179 Mtetra
.64476 .40179 .64836 .40614 .6557 .40388 .65212 .39951 Mtetra
.639 .76 .936 r
.65212 .39951 .6557 .40388 .66306 .40161 .65949 .39723 Mtetra
.65949 .39723 .66306 .40161 .67044 .39934 .66689 .39495 Mtetra
.66689 .39495 .67044 .39934 .67784 .39706 .6743 .39266 Mtetra
.6743 .39266 .67784 .39706 .68526 .39478 .68173 .39037 Mtetra
.68173 .39037 .68526 .39478 .6927 .39249 .68919 .38807 Mtetra
.641 .761 .936 r
.68919 .38807 .6927 .39249 .70016 .39017 .69666 .38574 Mtetra
.645 .763 .935 r
.69666 .38574 .70016 .39017 .70763 .38778 .70415 .38333 Mtetra
.648 .764 .934 r
.70415 .38333 .70763 .38778 .71513 .38533 .71165 .38087 Mtetra
.671 .773 .926 r
.71165 .38087 .71513 .38533 .72261 .38248 .71915 .37801 Mtetra
.696 .782 .918 r
.71915 .37801 .72261 .38248 .73009 .37917 .72664 .37469 Mtetra
.731 .794 .902 r
.72664 .37469 .73009 .37917 .73753 .37515 .7341 .37066 Mtetra
.811 .815 .854 r
.7341 .37066 .73753 .37515 .74484 .36901 .74143 .3645 Mtetra
.854 .821 .816 r
.74143 .3645 .74484 .36901 .75204 .36123 .74865 .35671 Mtetra
.917 .819 .734 r
.74865 .35671 .75204 .36123 .75894 .3495 .75557 .34495 Mtetra
.954 .805 .656 r
.75557 .34495 .75894 .3495 .76544 .33281 .7621 .32824 Mtetra
.967 .794 .616 r
.7621 .32824 .76544 .33281 .77163 .31288 .76832 .30828 Mtetra
.982 .769 .54 r
.76832 .30828 .77163 .31288 .77704 .28411 .77376 .27948 Mtetra
.985 .76 .516 r
.77376 .27948 .77704 .28411 .78204 .2517 .7788 .24702 Mtetra
.942 .627 .41 r
.12469 .43943 .12892 .44313 .13092 .47299 .12664 .46931 Mtetra
.942 .619 .394 r
.12664 .46931 .13092 .47299 .13333 .50037 .12902 .49671 Mtetra
.935 .58 .323 r
.12902 .49671 .13333 .50037 .1368 .51961 .13247 .51597 Mtetra
.925 .547 .265 r
.13247 .51597 .1368 .51961 .14075 .53548 .13639 .53185 Mtetra
.875 .435 .09 r
.13639 .53185 .14075 .53548 .14537 .54599 .141 .54236 Mtetra
.624 .098 0 r
.141 .54236 .14537 .54599 .15059 .55165 .14622 .54803 Mtetra
0 .224 .689 r
.14622 .54803 .15059 .55165 .15608 .55524 .1517 .55161 Mtetra
.339 .642 .965 r
.1517 .55161 .15608 .55524 .16191 .55589 .15754 .55225 Mtetra
.497 .714 .968 r
.15754 .55225 .16191 .55589 .16788 .55546 .16352 .55181 Mtetra
.573 .742 .957 r
.16352 .55181 .16788 .55546 .17395 .55433 .16959 .55068 Mtetra
.632 .76 .94 r
.16959 .55068 .17395 .55433 .1801 .55253 .17575 .54887 Mtetra
.639 .762 .937 r
.17575 .54887 .1801 .55253 .18627 .55062 .18194 .54695 Mtetra
.648 .765 .934 r
.18194 .54695 .18627 .55062 .19248 .54859 .18815 .5449 Mtetra
.652 .766 .932 r
.18815 .5449 .19248 .54859 .1987 .54649 .19438 .5428 Mtetra
.653 .766 .932 r
.19438 .5428 .1987 .54649 .20494 .54438 .20063 .54068 Mtetra
.20063 .54068 .20494 .54438 .21119 .54226 .20689 .53855 Mtetra
.20689 .53855 .21119 .54226 .21746 .54013 .21317 .53641 Mtetra
.21317 .53641 .21746 .54013 .22375 .53799 .21946 .53427 Mtetra
.652 .766 .932 r
.21946 .53427 .22375 .53799 .23005 .53587 .22577 .53214 Mtetra
.653 .766 .932 r
.22577 .53214 .23005 .53587 .23636 .53374 .23209 .52999 Mtetra
.23209 .52999 .23636 .53374 .24269 .5316 .23843 .52784 Mtetra
.651 .765 .933 r
.23843 .52784 .24269 .5316 .24903 .52947 .24478 .52571 Mtetra
.652 .765 .932 r
.24478 .52571 .24903 .52947 .25538 .52734 .25115 .52356 Mtetra
.25115 .52356 .25538 .52734 .26176 .52519 .25753 .5214 Mtetra
.651 .765 .933 r
.25753 .5214 .26176 .52519 .26814 .52305 .26392 .51926 Mtetra
.26392 .51926 .26814 .52305 .27454 .52092 .27034 .51711 Mtetra
.27034 .51711 .27454 .52092 .28096 .51876 .27676 .51495 Mtetra
.65 .765 .933 r
.27676 .51495 .28096 .51876 .28739 .51662 .2832 .5128 Mtetra
.2832 .5128 .28739 .51662 .29384 .51448 .28966 .51065 Mtetra
.651 .765 .933 r
.28966 .51065 .29384 .51448 .3003 .51232 .29613 .50848 Mtetra
.65 .765 .933 r
.29613 .50848 .3003 .51232 .30678 .51017 .30262 .50632 Mtetra
.649 .765 .933 r
.30262 .50632 .30678 .51017 .31328 .50802 .30912 .50416 Mtetra
.65 .765 .933 r
.30912 .50416 .31328 .50802 .31979 .50586 .31564 .50199 Mtetra
.31564 .50199 .31979 .50586 .32631 .5037 .32218 .49982 Mtetra
.649 .764 .934 r
.32218 .49982 .32631 .5037 .33285 .50155 .32873 .49765 Mtetra
.649 .765 .933 r
.32873 .49765 .33285 .50155 .33941 .49938 .3353 .49548 Mtetra
.3353 .49548 .33941 .49938 .34598 .49721 .34188 .4933 Mtetra
.648 .764 .934 r
.34188 .4933 .34598 .49721 .35257 .49505 .34848 .49113 Mtetra
.34848 .49113 .35257 .49505 .35917 .49288 .35509 .48895 Mtetra
.649 .764 .933 r
.35509 .48895 .35917 .49288 .36579 .4907 .36172 .48676 Mtetra
.647 .764 .934 r
.36172 .48676 .36579 .4907 .37243 .48853 .36837 .48458 Mtetra
.648 .764 .934 r
.36837 .48458 .37243 .48853 .37908 .48636 .37503 .4824 Mtetra
.37503 .4824 .37908 .48636 .38575 .48417 .38171 .4802 Mtetra
.647 .764 .934 r
.38171 .4802 .38575 .48417 .39244 .48199 .38841 .47801 Mtetra
.38841 .47801 .39244 .48199 .39914 .47981 .39512 .47582 Mtetra
.39512 .47582 .39914 .47981 .40586 .47762 .40185 .47362 Mtetra
.646 .764 .934 r
.40185 .47362 .40586 .47762 .41259 .47543 .40859 .47142 Mtetra
.646 .763 .934 r
.40859 .47142 .41259 .47543 .41934 .47325 .41536 .46923 Mtetra
.647 .764 .934 r
.41536 .46923 .41934 .47325 .42611 .47105 .42214 .46702 Mtetra
.646 .763 .934 r
.42214 .46702 .42611 .47105 .4329 .46885 .42893 .46481 Mtetra
.645 .763 .935 r
.42893 .46481 .4329 .46885 .4397 .46666 .43575 .46261 Mtetra
.646 .764 .934 r
.43575 .46261 .4397 .46666 .44652 .46446 .44258 .46039 Mtetra
.646 .763 .934 r
.44258 .46039 .44652 .46446 .45336 .46225 .44943 .45818 Mtetra
.645 .763 .935 r
.44943 .45818 .45336 .46225 .46021 .46005 .45629 .45597 Mtetra
.45629 .45597 .46021 .46005 .46709 .45784 .46317 .45375 Mtetra
.46317 .45375 .46709 .45784 .47397 .45562 .47007 .45152 Mtetra
.644 .763 .935 r
.47007 .45152 .47397 .45562 .48088 .45342 .47699 .4493 Mtetra
.645 .763 .935 r
.47699 .4493 .48088 .45342 .4878 .4512 .48393 .44708 Mtetra
.48393 .44708 .4878 .4512 .49475 .44897 .49088 .44484 Mtetra
.643 .763 .935 r
.49088 .44484 .49475 .44897 .50171 .44676 .49785 .44261 Mtetra
.644 .763 .935 r
.49785 .44261 .50171 .44676 .50868 .44454 .50484 .44038 Mtetra
.50484 .44038 .50868 .44454 .51568 .4423 .51185 .43813 Mtetra
.643 .762 .935 r
.51185 .43813 .51568 .4423 .52269 .44008 .51887 .4359 Mtetra
.51887 .4359 .52269 .44008 .52972 .43785 .52592 .43367 Mtetra
.52592 .43367 .52972 .43785 .53677 .43562 .53298 .43142 Mtetra
.53298 .43142 .53677 .43562 .54384 .43338 .54006 .42917 Mtetra
.643 .762 .936 r
.54006 .42917 .54384 .43338 .55093 .43114 .54715 .42692 Mtetra
.642 .762 .936 r
.54715 .42692 .55093 .43114 .55803 .4289 .55427 .42467 Mtetra
.55427 .42467 .55803 .4289 .56515 .42665 .56141 .42241 Mtetra
.56141 .42241 .56515 .42665 .5723 .42441 .56856 .42016 Mtetra
.56856 .42016 .5723 .42441 .57946 .42216 .57573 .41789 Mtetra
.57573 .41789 .57946 .42216 .58664 .4199 .58293 .41563 Mtetra
.641 .762 .936 r
.58293 .41563 .58664 .4199 .59384 .41765 .59014 .41336 Mtetra
.59014 .41336 .59384 .41765 .60105 .41539 .59737 .4111 Mtetra
.59737 .4111 .60105 .41539 .60829 .41313 .60462 .40882 Mtetra
.60462 .40882 .60829 .41313 .61555 .41087 .61188 .40655 Mtetra
.64 .762 .936 r
.61188 .40655 .61555 .41087 .62282 .4086 .61917 .40427 Mtetra
.61917 .40427 .62282 .4086 .63012 .40633 .62648 .40199 Mtetra
.64 .761 .936 r
.62648 .40199 .63012 .40633 .63743 .40406 .63381 .39971 Mtetra
.63381 .39971 .63743 .40406 .64476 .40179 .64115 .39742 Mtetra
.639 .761 .936 r
.64115 .39742 .64476 .40179 .65212 .39951 .64852 .39514 Mtetra
.639 .761 .937 r
.64852 .39514 .65212 .39951 .65949 .39723 .65591 .39285 Mtetra
.65591 .39285 .65949 .39723 .66689 .39495 .66331 .39055 Mtetra
.66331 .39055 .66689 .39495 .6743 .39266 .67074 .38826 Mtetra
.67074 .38826 .6743 .39266 .68173 .39037 .67819 .38595 Mtetra
.67819 .38595 .68173 .39037 .68919 .38807 .68566 .38364 Mtetra
.64 .762 .936 r
.68566 .38364 .68919 .38807 .69666 .38574 .69314 .3813 Mtetra
.645 .764 .935 r
.69314 .3813 .69666 .38574 .70415 .38333 .70064 .37888 Mtetra
.648 .765 .934 r
.70064 .37888 .70415 .38333 .71165 .38087 .70816 .37641 Mtetra
.671 .774 .927 r
.70816 .37641 .71165 .38087 .71915 .37801 .71568 .37353 Mtetra
.696 .783 .918 r
.71568 .37353 .71915 .37801 .72664 .37469 .72318 .3702 Mtetra
.731 .795 .903 r
.72318 .3702 .72664 .37469 .7341 .37066 .73066 .36616 Mtetra
.811 .816 .854 r
.73066 .36616 .7341 .37066 .74143 .3645 .73801 .35998 Mtetra
.855 .822 .816 r
.73801 .35998 .74143 .3645 .74865 .35671 .74524 .35217 Mtetra
.918 .82 .734 r
.74524 .35217 .74865 .35671 .75557 .34495 .75219 .3404 Mtetra
.955 .805 .656 r
.75219 .3404 .75557 .34495 .7621 .32824 .75874 .32366 Mtetra
.967 .794 .616 r
.75874 .32366 .7621 .32824 .76832 .30828 .76499 .30367 Mtetra
.982 .769 .54 r
.76499 .30367 .76832 .30828 .77376 .27948 .77047 .27484 Mtetra
.985 .76 .516 r
.77047 .27484 .77376 .27948 .7788 .24702 .77555 .24234 Mtetra
.942 .627 .41 r
.12044 .43571 .12469 .43943 .12664 .46931 .12235 .46561 Mtetra
.942 .619 .394 r
.12235 .46561 .12664 .46931 .12902 .49671 .12469 .49304 Mtetra
.935 .58 .322 r
.12469 .49304 .12902 .49671 .13247 .51597 .12811 .5123 Mtetra
.925 .547 .265 r
.12811 .5123 .13247 .51597 .13639 .53185 .13202 .52819 Mtetra
.875 .435 .089 r
.13202 .52819 .13639 .53185 .141 .54236 .13662 .53871 Mtetra
.623 .097 0 r
.13662 .53871 .141 .54236 .14622 .54803 .14183 .54437 Mtetra
0 .225 .69 r
.14183 .54437 .14622 .54803 .1517 .55161 .14731 .54795 Mtetra
.339 .642 .965 r
.14731 .54795 .1517 .55161 .15754 .55225 .15316 .54859 Mtetra
.497 .714 .968 r
.15316 .54859 .15754 .55225 .16352 .55181 .15914 .54814 Mtetra
.573 .742 .956 r
.15914 .54814 .16352 .55181 .16959 .55068 .16522 .547 Mtetra
.632 .76 .94 r
.16522 .547 .16959 .55068 .17575 .54887 .17139 .54518 Mtetra
.639 .762 .937 r
.17139 .54518 .17575 .54887 .18194 .54695 .17758 .54325 Mtetra
.648 .764 .934 r
.17758 .54325 .18194 .54695 .18815 .5449 .1838 .5412 Mtetra
.652 .765 .932 r
.1838 .5412 .18815 .5449 .19438 .5428 .19004 .53908 Mtetra
.653 .765 .932 r
.19004 .53908 .19438 .5428 .20063 .54068 .1963 .53695 Mtetra
.1963 .53695 .20063 .54068 .20689 .53855 .20257 .53481 Mtetra
.653 .765 .931 r
.20257 .53481 .20689 .53855 .21317 .53641 .20886 .53267 Mtetra
.654 .765 .931 r
.20886 .53267 .21317 .53641 .21946 .53427 .21516 .53051 Mtetra
.652 .765 .932 r
.21516 .53051 .21946 .53427 .22577 .53214 .22148 .52837 Mtetra
.653 .765 .932 r
.22148 .52837 .22577 .53214 .23209 .52999 .22781 .52622 Mtetra
.22781 .52622 .23209 .52999 .23843 .52784 .23416 .52406 Mtetra
.651 .765 .932 r
.23416 .52406 .23843 .52784 .24478 .52571 .24052 .52191 Mtetra
.652 .765 .932 r
.24052 .52191 .24478 .52571 .25115 .52356 .24689 .51976 Mtetra
.24689 .51976 .25115 .52356 .25753 .5214 .25328 .51759 Mtetra
.651 .765 .932 r
.25328 .51759 .25753 .5214 .26392 .51926 .25969 .51544 Mtetra
.25969 .51544 .26392 .51926 .27034 .51711 .26611 .51328 Mtetra
.652 .765 .932 r
.26611 .51328 .27034 .51711 .27676 .51495 .27254 .51111 Mtetra
.651 .764 .933 r
.27254 .51111 .27676 .51495 .2832 .5128 .279 .50895 Mtetra
.65 .764 .933 r
.279 .50895 .2832 .5128 .28966 .51065 .28546 .50679 Mtetra
.651 .764 .932 r
.28546 .50679 .28966 .51065 .29613 .50848 .29194 .50461 Mtetra
.65 .764 .933 r
.29194 .50461 .29613 .50848 .30262 .50632 .29844 .50244 Mtetra
.649 .764 .933 r
.29844 .50244 .30262 .50632 .30912 .50416 .30495 .50027 Mtetra
.65 .764 .933 r
.30495 .50027 .30912 .50416 .31564 .50199 .31148 .49809 Mtetra
.31148 .49809 .31564 .50199 .32218 .49982 .31803 .49591 Mtetra
.649 .764 .933 r
.31803 .49591 .32218 .49982 .32873 .49765 .32459 .49374 Mtetra
.32459 .49374 .32873 .49765 .3353 .49548 .33117 .49155 Mtetra
.33117 .49155 .3353 .49548 .34188 .4933 .33776 .48936 Mtetra
.648 .764 .933 r
.33776 .48936 .34188 .4933 .34848 .49113 .34437 .48718 Mtetra
.34437 .48718 .34848 .49113 .35509 .48895 .35099 .48499 Mtetra
.649 .764 .933 r
.35099 .48499 .35509 .48895 .36172 .48676 .35763 .48279 Mtetra
.647 .763 .934 r
.35763 .48279 .36172 .48676 .36837 .48458 .36429 .4806 Mtetra
.648 .763 .933 r
.36429 .4806 .36837 .48458 .37503 .4824 .37096 .47841 Mtetra
.648 .764 .933 r
.37096 .47841 .37503 .4824 .38171 .4802 .37765 .4762 Mtetra
.647 .763 .934 r
.37765 .4762 .38171 .4802 .38841 .47801 .38436 .474 Mtetra
.38436 .474 .38841 .47801 .39512 .47582 .39108 .47181 Mtetra
.648 .763 .934 r
.39108 .47181 .39512 .47582 .40185 .47362 .39782 .46959 Mtetra
.646 .763 .934 r
.39782 .46959 .40185 .47362 .40859 .47142 .40458 .46738 Mtetra
.40458 .46738 .40859 .47142 .41536 .46923 .41135 .46518 Mtetra
.647 .763 .934 r
.41135 .46518 .41536 .46923 .42214 .46702 .41814 .46296 Mtetra
.646 .763 .934 r
.41814 .46296 .42214 .46702 .42893 .46481 .42495 .46074 Mtetra
.645 .763 .934 r
.42495 .46074 .42893 .46481 .43575 .46261 .43177 .45853 Mtetra
.646 .763 .934 r
.43177 .45853 .43575 .46261 .44258 .46039 .43862 .4563 Mtetra
.43862 .4563 .44258 .46039 .44943 .45818 .44547 .45408 Mtetra
.645 .763 .934 r
.44547 .45408 .44943 .45818 .45629 .45597 .45235 .45186 Mtetra
.45235 .45186 .45629 .45597 .46317 .45375 .45924 .44962 Mtetra
.45924 .44962 .46317 .45375 .47007 .45152 .46616 .44739 Mtetra
.644 .762 .935 r
.46616 .44739 .47007 .45152 .47699 .4493 .47309 .44516 Mtetra
.645 .762 .934 r
.47309 .44516 .47699 .4493 .48393 .44708 .48003 .44292 Mtetra
.645 .763 .934 r
.48003 .44292 .48393 .44708 .49088 .44484 .487 .44067 Mtetra
.643 .762 .935 r
.487 .44067 .49088 .44484 .49785 .44261 .49398 .43844 Mtetra
.644 .762 .935 r
.49398 .43844 .49785 .44261 .50484 .44038 .50098 .4362 Mtetra
.50098 .4362 .50484 .44038 .51185 .43813 .508 .43394 Mtetra
.643 .762 .935 r
.508 .43394 .51185 .43813 .51887 .4359 .51503 .4317 Mtetra
.51503 .4317 .51887 .4359 .52592 .43367 .52209 .42945 Mtetra
.52209 .42945 .52592 .43367 .53298 .43142 .52916 .42719 Mtetra
.52916 .42719 .53298 .43142 .54006 .42917 .53625 .42494 Mtetra
.53625 .42494 .54006 .42917 .54715 .42692 .54336 .42267 Mtetra
.642 .762 .935 r
.54336 .42267 .54715 .42692 .55427 .42467 .55049 .42041 Mtetra
.55049 .42041 .55427 .42467 .56141 .42241 .55764 .41814 Mtetra
.55764 .41814 .56141 .42241 .56856 .42016 .56481 .41587 Mtetra
.56481 .41587 .56856 .42016 .57573 .41789 .57199 .4136 Mtetra
.642 .761 .935 r
.57199 .4136 .57573 .41789 .58293 .41563 .5792 .41133 Mtetra
.641 .761 .936 r
.5792 .41133 .58293 .41563 .59014 .41336 .58642 .40905 Mtetra
.58642 .40905 .59014 .41336 .59737 .4111 .59366 .40677 Mtetra
.59366 .40677 .59737 .4111 .60462 .40882 .60092 .40449 Mtetra
.60092 .40449 .60462 .40882 .61188 .40655 .60821 .4022 Mtetra
.64 .761 .936 r
.60821 .4022 .61188 .40655 .61917 .40427 .61551 .39991 Mtetra
.61551 .39991 .61917 .40427 .62648 .40199 .62283 .39762 Mtetra
.62283 .39762 .62648 .40199 .63381 .39971 .63017 .39533 Mtetra
.63017 .39533 .63381 .39971 .64115 .39742 .63753 .39303 Mtetra
.63753 .39303 .64115 .39742 .64852 .39514 .64491 .39073 Mtetra
.639 .761 .936 r
.64491 .39073 .64852 .39514 .65591 .39285 .65231 .38843 Mtetra
.65231 .38843 .65591 .39285 .66331 .39055 .65973 .38613 Mtetra
.65973 .38613 .66331 .39055 .67074 .38826 .66717 .38382 Mtetra
.66717 .38382 .67074 .38826 .67819 .38595 .67463 .3815 Mtetra
.67463 .3815 .67819 .38595 .68566 .38364 .68211 .37918 Mtetra
.641 .761 .936 r
.68211 .37918 .68566 .38364 .69314 .3813 .68961 .37683 Mtetra
.645 .763 .935 r
.68961 .37683 .69314 .3813 .70064 .37888 .69712 .3744 Mtetra
.648 .764 .934 r
.69712 .3744 .70064 .37888 .70816 .37641 .70466 .37191 Mtetra
.671 .773 .927 r
.70466 .37191 .70816 .37641 .71568 .37353 .71219 .36903 Mtetra
.696 .783 .918 r
.71219 .36903 .71568 .37353 .72318 .3702 .71971 .36568 Mtetra
.731 .795 .903 r
.71971 .36568 .72318 .3702 .73066 .36616 .7272 .36162 Mtetra
.811 .816 .854 r
.7272 .36162 .73066 .36616 .73801 .35998 .73456 .35544 Mtetra
.854 .822 .816 r
.73456 .35544 .73801 .35998 .74524 .35217 .74182 .34761 Mtetra
.917 .819 .734 r
.74182 .34761 .74524 .35217 .75219 .3404 .74878 .33581 Mtetra
.954 .805 .656 r
.74878 .33581 .75219 .3404 .75874 .32366 .75536 .31905 Mtetra
.967 .794 .616 r
.75536 .31905 .75874 .32366 .76499 .30367 .76164 .29904 Mtetra
.982 .769 .54 r
.76164 .29904 .76499 .30367 .77047 .27484 .76716 .27016 Mtetra
.985 .76 .516 r
.76716 .27016 .77047 .27484 .77555 .24234 .77228 .23763 Mtetra
.942 .627 .41 r
.11617 .43197 .12044 .43571 .12235 .46561 .11804 .46189 Mtetra
.942 .619 .394 r
.11804 .46189 .12235 .46561 .12469 .49304 .12034 .48934 Mtetra
.935 .58 .322 r
.12034 .48934 .12469 .49304 .12811 .5123 .12374 .50862 Mtetra
.925 .547 .265 r
.12374 .50862 .12811 .5123 .13202 .52819 .12762 .52451 Mtetra
.875 .435 .089 r
.12762 .52451 .13202 .52819 .13662 .53871 .13221 .53503 Mtetra
.622 .097 0 r
.13221 .53503 .13662 .53871 .14183 .54437 .13742 .5407 Mtetra
0 .226 .691 r
.13742 .5407 .14183 .54437 .14731 .54795 .14291 .54427 Mtetra
.34 .642 .965 r
.14291 .54427 .14731 .54795 .15316 .54859 .14875 .5449 Mtetra
.497 .714 .968 r
.14875 .5449 .15316 .54859 .15914 .54814 .15474 .54445 Mtetra
.573 .741 .956 r
.15474 .54445 .15914 .54814 .16522 .547 .16083 .5433 Mtetra
.632 .759 .939 r
.16083 .5433 .16522 .547 .17139 .54518 .16701 .54146 Mtetra
.639 .761 .937 r
.16701 .54146 .17139 .54518 .17758 .54325 .17321 .53953 Mtetra
.648 .764 .933 r
.17321 .53953 .17758 .54325 .1838 .5412 .17944 .53747 Mtetra
.652 .765 .932 r
.17944 .53747 .1838 .5412 .19004 .53908 .18569 .53534 Mtetra
.653 .765 .931 r
.18569 .53534 .19004 .53908 .1963 .53695 .19195 .5332 Mtetra
.19195 .5332 .1963 .53695 .20257 .53481 .19823 .53106 Mtetra
.654 .765 .931 r
.19823 .53106 .20257 .53481 .20886 .53267 .20453 .5289 Mtetra
.20453 .5289 .20886 .53267 .21516 .53051 .21084 .52673 Mtetra
.652 .765 .932 r
.21084 .52673 .21516 .53051 .22148 .52837 .21717 .52458 Mtetra
.653 .765 .932 r
.21717 .52458 .22148 .52837 .22781 .52622 .22351 .52242 Mtetra
.653 .765 .931 r
.22351 .52242 .22781 .52622 .23416 .52406 .22986 .52025 Mtetra
.651 .764 .932 r
.22986 .52025 .23416 .52406 .24052 .52191 .23623 .5181 Mtetra
.652 .764 .932 r
.23623 .5181 .24052 .52191 .24689 .51976 .24262 .51593 Mtetra
.652 .765 .932 r
.24262 .51593 .24689 .51976 .25328 .51759 .24902 .51376 Mtetra
.651 .764 .932 r
.24902 .51376 .25328 .51759 .25969 .51544 .25543 .51159 Mtetra
.25543 .51159 .25969 .51544 .26611 .51328 .26186 .50943 Mtetra
.652 .764 .932 r
.26186 .50943 .26611 .51328 .27254 .51111 .26831 .50725 Mtetra
.651 .764 .932 r
.26831 .50725 .27254 .51111 .279 .50895 .27477 .50507 Mtetra
.65 .764 .932 r
.27477 .50507 .279 .50895 .28546 .50679 .28124 .5029 Mtetra
.651 .764 .932 r
.28124 .5029 .28546 .50679 .29194 .50461 .28774 .50072 Mtetra
.65 .764 .932 r
.28774 .50072 .29194 .50461 .29844 .50244 .29424 .49853 Mtetra
.649 .764 .933 r
.29424 .49853 .29844 .50244 .30495 .50027 .30077 .49636 Mtetra
.65 .764 .932 r
.30077 .49636 .30495 .50027 .31148 .49809 .3073 .49417 Mtetra
.65 .764 .933 r
.3073 .49417 .31148 .49809 .31803 .49591 .31386 .49197 Mtetra
.649 .764 .933 r
.31386 .49197 .31803 .49591 .32459 .49374 .32043 .48979 Mtetra
.32043 .48979 .32459 .49374 .33117 .49155 .32702 .4876 Mtetra
.32702 .4876 .33117 .49155 .33776 .48936 .33362 .4854 Mtetra
.648 .763 .933 r
.33362 .4854 .33776 .48936 .34437 .48718 .34024 .48321 Mtetra
.34024 .48321 .34437 .48718 .35099 .48499 .34687 .48101 Mtetra
.649 .764 .933 r
.34687 .48101 .35099 .48499 .35763 .48279 .35352 .4788 Mtetra
.647 .763 .933 r
.35352 .4788 .35763 .48279 .36429 .4806 .36019 .4766 Mtetra
.648 .763 .933 r
.36019 .4766 .36429 .4806 .37096 .47841 .36687 .4744 Mtetra
.36687 .4744 .37096 .47841 .37765 .4762 .37357 .47218 Mtetra
.647 .763 .934 r
.37357 .47218 .37765 .4762 .38436 .474 .38029 .46997 Mtetra
.38029 .46997 .38436 .474 .39108 .47181 .38702 .46776 Mtetra
.648 .763 .933 r
.38702 .46776 .39108 .47181 .39782 .46959 .39378 .46554 Mtetra
.647 .763 .934 r
.39378 .46554 .39782 .46959 .40458 .46738 .40054 .46332 Mtetra
.646 .763 .934 r
.40054 .46332 .40458 .46738 .41135 .46518 .40733 .46111 Mtetra
.647 .763 .934 r
.40733 .46111 .41135 .46518 .41814 .46296 .41413 .45887 Mtetra
.646 .763 .934 r
.41413 .45887 .41814 .46296 .42495 .46074 .42095 .45665 Mtetra
.645 .762 .934 r
.42095 .45665 .42495 .46074 .43177 .45853 .42778 .45443 Mtetra
.646 .763 .934 r
.42778 .45443 .43177 .45853 .43862 .4563 .43463 .45219 Mtetra
.43463 .45219 .43862 .4563 .44547 .45408 .4415 .44995 Mtetra
.645 .762 .934 r
.4415 .44995 .44547 .45408 .45235 .45186 .44839 .44772 Mtetra
.44839 .44772 .45235 .45186 .45924 .44962 .4553 .44548 Mtetra
.4553 .44548 .45924 .44962 .46616 .44739 .46222 .44323 Mtetra
.644 .762 .934 r
.46222 .44323 .46616 .44739 .47309 .44516 .46916 .44099 Mtetra
.645 .762 .934 r
.46916 .44099 .47309 .44516 .48003 .44292 .47612 .43874 Mtetra
.47612 .43874 .48003 .44292 .487 .44067 .48309 .43648 Mtetra
.643 .762 .935 r
.48309 .43648 .487 .44067 .49398 .43844 .49009 .43424 Mtetra
.644 .762 .935 r
.49009 .43424 .49398 .43844 .50098 .4362 .4971 .43199 Mtetra
.644 .762 .934 r
.4971 .43199 .50098 .4362 .508 .43394 .50413 .42972 Mtetra
.643 .762 .935 r
.50413 .42972 .508 .43394 .51503 .4317 .51118 .42746 Mtetra
.51118 .42746 .51503 .4317 .52209 .42945 .51825 .42521 Mtetra
.51825 .42521 .52209 .42945 .52916 .42719 .52533 .42294 Mtetra
.52533 .42294 .52916 .42719 .53625 .42494 .53243 .42067 Mtetra
.53243 .42067 .53625 .42494 .54336 .42267 .53956 .4184 Mtetra
.642 .761 .935 r
.53956 .4184 .54336 .42267 .55049 .42041 .5467 .41612 Mtetra
.5467 .41612 .55049 .42041 .55764 .41814 .55386 .41385 Mtetra
.55386 .41385 .55764 .41814 .56481 .41587 .56104 .41156 Mtetra
.56104 .41156 .56481 .41587 .57199 .4136 .56823 .40928 Mtetra
.56823 .40928 .57199 .4136 .5792 .41133 .57545 .407 Mtetra
.641 .761 .935 r
.57545 .407 .5792 .41133 .58642 .40905 .58269 .40471 Mtetra
.58269 .40471 .58642 .40905 .59366 .40677 .58994 .40242 Mtetra
.58994 .40242 .59366 .40677 .60092 .40449 .59721 .40012 Mtetra
.641 .761 .936 r
.59721 .40012 .60092 .40449 .60821 .4022 .60451 .39783 Mtetra
.64 .761 .936 r
.60451 .39783 .60821 .4022 .61551 .39991 .61182 .39553 Mtetra
.61182 .39553 .61551 .39991 .62283 .39762 .61916 .39322 Mtetra
.61916 .39322 .62283 .39762 .63017 .39533 .62651 .39092 Mtetra
.62651 .39092 .63017 .39533 .63753 .39303 .63388 .38861 Mtetra
.64 .76 .936 r
.63388 .38861 .63753 .39303 .64491 .39073 .64127 .3863 Mtetra
.639 .76 .936 r
.64127 .3863 .64491 .39073 .65231 .38843 .64869 .38399 Mtetra
.64869 .38399 .65231 .38843 .65973 .38613 .65612 .38167 Mtetra
.65612 .38167 .65973 .38613 .66717 .38382 .66357 .37935 Mtetra
.66357 .37935 .66717 .38382 .67463 .3815 .67105 .37703 Mtetra
.67105 .37703 .67463 .3815 .68211 .37918 .67854 .37469 Mtetra
.641 .761 .936 r
.67854 .37469 .68211 .37918 .68961 .37683 .68605 .37232 Mtetra
.645 .763 .935 r
.68605 .37232 .68961 .37683 .69712 .3744 .69358 .36989 Mtetra
.648 .764 .934 r
.69358 .36989 .69712 .3744 .70466 .37191 .70113 .36739 Mtetra
.671 .773 .926 r
.70113 .36739 .70466 .37191 .71219 .36903 .70868 .36449 Mtetra
.696 .782 .918 r
.70868 .36449 .71219 .36903 .71971 .36568 .71621 .36114 Mtetra
.731 .794 .902 r
.71621 .36114 .71971 .36568 .7272 .36162 .72372 .35706 Mtetra
.811 .815 .854 r
.72372 .35706 .7272 .36162 .73456 .35544 .7311 .35086 Mtetra
.854 .821 .816 r
.7311 .35086 .73456 .35544 .74182 .34761 .73837 .34302 Mtetra
.917 .819 .734 r
.73837 .34302 .74182 .34761 .74878 .33581 .74536 .3312 Mtetra
.954 .805 .656 r
.74536 .3312 .74878 .33581 .75536 .31905 .75197 .31441 Mtetra
.967 .794 .616 r
.75197 .31441 .75536 .31905 .76164 .29904 .75828 .29437 Mtetra
.982 .769 .54 r
.75828 .29437 .76164 .29904 .76716 .27016 .76384 .26546 Mtetra
.985 .76 .516 r
.76384 .26546 .76716 .27016 .77228 .23763 .76899 .23289 Mtetra
.942 .627 .41 r
.11188 .42822 .11617 .43197 .11804 .46189 .11371 .45817 Mtetra
.942 .619 .394 r
.11371 .45817 .11804 .46189 .12034 .48934 .11597 .48564 Mtetra
.935 .58 .323 r
.11597 .48564 .12034 .48934 .12374 .50862 .11934 .50493 Mtetra
.925 .546 .265 r
.11934 .50493 .12374 .50862 .12762 .52451 .12321 .52084 Mtetra
.875 .435 .09 r
.12321 .52084 .12762 .52451 .13221 .53503 .12779 .53136 Mtetra
.623 .098 0 r
.12779 .53136 .13221 .53503 .13742 .5407 .13299 .53702 Mtetra
0 .224 .689 r
.13299 .53702 .13742 .5407 .14291 .54427 .13848 .54059 Mtetra
.339 .642 .965 r
.13848 .54059 .14291 .54427 .14875 .5449 .14433 .54122 Mtetra
.497 .714 .968 r
.14433 .54122 .14875 .5449 .15474 .54445 .15032 .54076 Mtetra
.573 .742 .957 r
.15032 .54076 .15474 .54445 .16083 .5433 .15642 .5396 Mtetra
.632 .76 .94 r
.15642 .5396 .16083 .5433 .16701 .54146 .1626 .53776 Mtetra
.639 .762 .937 r
.1626 .53776 .16701 .54146 .17321 .53953 .16881 .53581 Mtetra
.648 .765 .934 r
.16881 .53581 .17321 .53953 .17944 .53747 .17505 .53374 Mtetra
.652 .766 .932 r
.17505 .53374 .17944 .53747 .18569 .53534 .18131 .5316 Mtetra
.653 .766 .932 r
.18131 .5316 .18569 .53534 .19195 .5332 .18758 .52945 Mtetra
.18758 .52945 .19195 .5332 .19823 .53106 .19387 .5273 Mtetra
.19387 .5273 .19823 .53106 .20453 .5289 .20018 .52513 Mtetra
.654 .766 .932 r
.20018 .52513 .20453 .5289 .21084 .52673 .2065 .52296 Mtetra
.652 .766 .932 r
.2065 .52296 .21084 .52673 .21717 .52458 .21283 .5208 Mtetra
.653 .766 .932 r
.21283 .5208 .21717 .52458 .22351 .52242 .21918 .51863 Mtetra
.21918 .51863 .22351 .52242 .22986 .52025 .22555 .51645 Mtetra
.651 .765 .933 r
.22555 .51645 .22986 .52025 .23623 .5181 .23193 .51428 Mtetra
.652 .766 .933 r
.23193 .51428 .23623 .5181 .24262 .51593 .23832 .51211 Mtetra
.652 .766 .932 r
.23832 .51211 .24262 .51593 .24902 .51376 .24473 .50992 Mtetra
.651 .765 .933 r
.24473 .50992 .24902 .51376 .25543 .51159 .25115 .50775 Mtetra
.25115 .50775 .25543 .51159 .26186 .50943 .25759 .50557 Mtetra
.25759 .50557 .26186 .50943 .26831 .50725 .26405 .50338 Mtetra
.26405 .50338 .26831 .50725 .27477 .50507 .27052 .5012 Mtetra
.65 .765 .933 r
.27052 .5012 .27477 .50507 .28124 .5029 .277 .49902 Mtetra
.651 .765 .933 r
.277 .49902 .28124 .5029 .28774 .50072 .28351 .49682 Mtetra
.65 .765 .933 r
.28351 .49682 .28774 .50072 .29424 .49853 .29002 .49463 Mtetra
.649 .765 .933 r
.29002 .49463 .29424 .49853 .30077 .49636 .29656 .49245 Mtetra
.65 .765 .933 r
.29656 .49245 .30077 .49636 .3073 .49417 .30311 .49024 Mtetra
.30311 .49024 .3073 .49417 .31386 .49197 .30967 .48804 Mtetra
.649 .764 .934 r
.30967 .48804 .31386 .49197 .32043 .48979 .31625 .48585 Mtetra
.649 .765 .933 r
.31625 .48585 .32043 .48979 .32702 .4876 .32285 .48364 Mtetra
.32285 .48364 .32702 .4876 .33362 .4854 .32946 .48143 Mtetra
.648 .764 .934 r
.32946 .48143 .33362 .4854 .34024 .48321 .33609 .47923 Mtetra
.33609 .47923 .34024 .48321 .34687 .48101 .34273 .47702 Mtetra
.649 .765 .934 r
.34273 .47702 .34687 .48101 .35352 .4788 .34939 .4748 Mtetra
.647 .764 .934 r
.34939 .4748 .35352 .4788 .36019 .4766 .35607 .4726 Mtetra
.648 .764 .934 r
.35607 .4726 .36019 .4766 .36687 .4744 .36277 .47038 Mtetra
.36277 .47038 .36687 .4744 .37357 .47218 .36948 .46815 Mtetra
.647 .764 .934 r
.36948 .46815 .37357 .47218 .38029 .46997 .3762 .46594 Mtetra
.3762 .46594 .38029 .46997 .38702 .46776 .38295 .46372 Mtetra
.38295 .46372 .38702 .46776 .39378 .46554 .38971 .46148 Mtetra
.646 .764 .934 r
.38971 .46148 .39378 .46554 .40054 .46332 .39649 .45926 Mtetra
.39649 .45926 .40054 .46332 .40733 .46111 .40328 .45703 Mtetra
.647 .764 .934 r
.40328 .45703 .40733 .46111 .41413 .45887 .4101 .45479 Mtetra
.646 .764 .934 r
.4101 .45479 .41413 .45887 .42095 .45665 .41692 .45255 Mtetra
.645 .763 .935 r
.41692 .45255 .42095 .45665 .42778 .45443 .42377 .45032 Mtetra
.646 .764 .934 r
.42377 .45032 .42778 .45443 .43463 .45219 .43063 .44807 Mtetra
.646 .764 .935 r
.43063 .44807 .43463 .45219 .4415 .44995 .43752 .44582 Mtetra
.645 .763 .935 r
.43752 .44582 .4415 .44995 .44839 .44772 .44441 .44358 Mtetra
.44441 .44358 .44839 .44772 .4553 .44548 .45133 .44133 Mtetra
.45133 .44133 .4553 .44548 .46222 .44323 .45826 .43907 Mtetra
.644 .763 .935 r
.45826 .43907 .46222 .44323 .46916 .44099 .46522 .43682 Mtetra
.645 .763 .935 r
.46522 .43682 .46916 .44099 .47612 .43874 .47219 .43456 Mtetra
.47219 .43456 .47612 .43874 .48309 .43648 .47917 .43229 Mtetra
.643 .763 .935 r
.47917 .43229 .48309 .43648 .49009 .43424 .48618 .43004 Mtetra
.644 .763 .935 r
.48618 .43004 .49009 .43424 .4971 .43199 .4932 .42777 Mtetra
.4932 .42777 .4971 .43199 .50413 .42972 .50024 .42549 Mtetra
.643 .763 .936 r
.50024 .42549 .50413 .42972 .51118 .42746 .5073 .42323 Mtetra
.5073 .42323 .51118 .42746 .51825 .42521 .51438 .42096 Mtetra
.643 .763 .935 r
.51438 .42096 .51825 .42521 .52533 .42294 .52148 .41868 Mtetra
.643 .763 .936 r
.52148 .41868 .52533 .42294 .53243 .42067 .5286 .4164 Mtetra
.643 .762 .936 r
.5286 .4164 .53243 .42067 .53956 .4184 .53573 .41412 Mtetra
.642 .762 .936 r
.53573 .41412 .53956 .4184 .5467 .41612 .54288 .41184 Mtetra
.54288 .41184 .5467 .41612 .55386 .41385 .55005 .40955 Mtetra
.55005 .40955 .55386 .41385 .56104 .41156 .55725 .40725 Mtetra
.55725 .40725 .56104 .41156 .56823 .40928 .56446 .40496 Mtetra
.641 .762 .936 r
.56446 .40496 .56823 .40928 .57545 .407 .57168 .40266 Mtetra
.57168 .40266 .57545 .407 .58269 .40471 .57893 .40036 Mtetra
.57893 .40036 .58269 .40471 .58994 .40242 .5862 .39806 Mtetra
.5862 .39806 .58994 .40242 .59721 .40012 .59349 .39576 Mtetra
.59349 .39576 .59721 .40012 .60451 .39783 .60079 .39345 Mtetra
.64 .762 .936 r
.60079 .39345 .60451 .39783 .61182 .39553 .60812 .39114 Mtetra
.60812 .39114 .61182 .39553 .61916 .39322 .61547 .38882 Mtetra
.61547 .38882 .61916 .39322 .62651 .39092 .62283 .38651 Mtetra
.64 .762 .937 r
.62283 .38651 .62651 .39092 .63388 .38861 .63022 .38419 Mtetra
.639 .761 .937 r
.63022 .38419 .63388 .38861 .64127 .3863 .63762 .38187 Mtetra
.63762 .38187 .64127 .3863 .64869 .38399 .64505 .37954 Mtetra
.64505 .37954 .64869 .38399 .65612 .38167 .6525 .37722 Mtetra
.6525 .37722 .65612 .38167 .66357 .37935 .65996 .37489 Mtetra
.65996 .37489 .66357 .37935 .67105 .37703 .66745 .37255 Mtetra
.66745 .37255 .67105 .37703 .67854 .37469 .67496 .3702 Mtetra
.64 .762 .936 r
.67496 .3702 .67854 .37469 .68605 .37232 .68249 .36782 Mtetra
.645 .764 .935 r
.68249 .36782 .68605 .37232 .69358 .36989 .69003 .36537 Mtetra
.648 .765 .934 r
.69003 .36537 .69358 .36989 .70113 .36739 .69759 .36286 Mtetra
.671 .774 .927 r
.69759 .36286 .70113 .36739 .70868 .36449 .70515 .35995 Mtetra
.696 .783 .918 r
.70515 .35995 .70868 .36449 .71621 .36114 .7127 .35659 Mtetra
.731 .795 .903 r
.7127 .35659 .71621 .36114 .72372 .35706 .72022 .3525 Mtetra
.811 .816 .854 r
.72022 .3525 .72372 .35706 .7311 .35086 .72762 .34628 Mtetra
.855 .822 .816 r
.72762 .34628 .7311 .35086 .73837 .34302 .73491 .33842 Mtetra
.918 .82 .734 r
.73491 .33842 .73837 .34302 .74536 .3312 .74193 .32658 Mtetra
.955 .805 .656 r
.74193 .32658 .74536 .3312 .75197 .31441 .74856 .30977 Mtetra
.967 .794 .616 r
.74856 .30977 .75197 .31441 .75828 .29437 .7549 .2897 Mtetra
.982 .769 .54 r
.7549 .2897 .75828 .29437 .76384 .26546 .7605 .26075 Mtetra
.985 .76 .516 r
.7605 .26075 .76384 .26546 .76899 .23289 .76569 .22814 Mtetra
.942 .627 .41 r
.10758 .42445 .11188 .42822 .11371 .45817 .10937 .45443 Mtetra
.942 .619 .394 r
.10937 .45443 .11371 .45817 .11597 .48564 .11159 .48192 Mtetra
.935 .58 .323 r
.11159 .48192 .11597 .48564 .11934 .50493 .11493 .50122 Mtetra
.925 .546 .265 r
.11493 .50122 .11934 .50493 .12321 .52084 .11878 .51714 Mtetra
.875 .435 .089 r
.11878 .51714 .12321 .52084 .12779 .53136 .12334 .52767 Mtetra
.623 .097 0 r
.12334 .52767 .12779 .53136 .13299 .53702 .12854 .53333 Mtetra
0 .225 .69 r
.12854 .53333 .13299 .53702 .13848 .54059 .13403 .53689 Mtetra
.339 .642 .965 r
.13403 .53689 .13848 .54059 .14433 .54122 .13988 .53751 Mtetra
.497 .714 .968 r
.13988 .53751 .14433 .54122 .15032 .54076 .14589 .53704 Mtetra
.573 .742 .956 r
.14589 .53704 .15032 .54076 .15642 .5396 .15198 .53587 Mtetra
.632 .76 .94 r
.15198 .53587 .15642 .5396 .1626 .53776 .15818 .53402 Mtetra
.639 .762 .937 r
.15818 .53402 .1626 .53776 .16881 .53581 .1644 .53207 Mtetra
.648 .764 .934 r
.1644 .53207 .16881 .53581 .17505 .53374 .17064 .52999 Mtetra
.652 .765 .932 r
.17064 .52999 .17505 .53374 .18131 .5316 .17691 .52784 Mtetra
.653 .766 .932 r
.17691 .52784 .18131 .5316 .18758 .52945 .18319 .52568 Mtetra
.18319 .52568 .18758 .52945 .19387 .5273 .18949 .52352 Mtetra
.654 .766 .932 r
.18949 .52352 .19387 .5273 .20018 .52513 .19581 .52134 Mtetra
.19581 .52134 .20018 .52513 .2065 .52296 .20214 .51916 Mtetra
.652 .765 .932 r
.20214 .51916 .2065 .52296 .21283 .5208 .20848 .51699 Mtetra
.653 .765 .932 r
.20848 .51699 .21283 .5208 .21918 .51863 .21484 .51481 Mtetra
.21484 .51481 .21918 .51863 .22555 .51645 .22121 .51262 Mtetra
.651 .765 .932 r
.22121 .51262 .22555 .51645 .23193 .51428 .2276 .51044 Mtetra
.652 .765 .932 r
.2276 .51044 .23193 .51428 .23832 .51211 .23401 .50826 Mtetra
.23401 .50826 .23832 .51211 .24473 .50992 .24042 .50607 Mtetra
.651 .765 .933 r
.24042 .50607 .24473 .50992 .25115 .50775 .24686 .50388 Mtetra
.24686 .50388 .25115 .50775 .25759 .50557 .25331 .5017 Mtetra
.652 .765 .932 r
.25331 .5017 .25759 .50557 .26405 .50338 .25977 .49949 Mtetra
.651 .765 .933 r
.25977 .49949 .26405 .50338 .27052 .5012 .26625 .4973 Mtetra
.65 .765 .933 r
.26625 .4973 .27052 .5012 .277 .49902 .27275 .49511 Mtetra
.651 .765 .933 r
.27275 .49511 .277 .49902 .28351 .49682 .27926 .4929 Mtetra
.65 .765 .933 r
.27926 .4929 .28351 .49682 .29002 .49463 .28579 .4907 Mtetra
.649 .764 .933 r
.28579 .4907 .29002 .49463 .29656 .49245 .29233 .48851 Mtetra
.65 .765 .933 r
.29233 .48851 .29656 .49245 .30311 .49024 .29889 .4863 Mtetra
.65 .764 .933 r
.29889 .4863 .30311 .49024 .30967 .48804 .30546 .48408 Mtetra
.649 .764 .933 r
.30546 .48408 .30967 .48804 .31625 .48585 .31205 .48188 Mtetra
.31205 .48188 .31625 .48585 .32285 .48364 .31866 .47967 Mtetra
.31866 .47967 .32285 .48364 .32946 .48143 .32528 .47744 Mtetra
.648 .764 .934 r
.32528 .47744 .32946 .48143 .33609 .47923 .33192 .47524 Mtetra
.648 .764 .933 r
.33192 .47524 .33609 .47923 .34273 .47702 .33858 .47302 Mtetra
.649 .764 .933 r
.33858 .47302 .34273 .47702 .34939 .4748 .34525 .47078 Mtetra
.647 .764 .934 r
.34525 .47078 .34939 .4748 .35607 .4726 .35194 .46857 Mtetra
.648 .764 .934 r
.35194 .46857 .35607 .4726 .36277 .47038 .35864 .46634 Mtetra
.648 .764 .933 r
.35864 .46634 .36277 .47038 .36948 .46815 .36536 .4641 Mtetra
.647 .764 .934 r
.36536 .4641 .36948 .46815 .3762 .46594 .3721 .46188 Mtetra
.3721 .46188 .3762 .46594 .38295 .46372 .37885 .45965 Mtetra
.648 .764 .934 r
.37885 .45965 .38295 .46372 .38971 .46148 .38563 .4574 Mtetra
.646 .763 .934 r
.38563 .4574 .38971 .46148 .39649 .45926 .39241 .45517 Mtetra
.39241 .45517 .39649 .45926 .40328 .45703 .39922 .45293 Mtetra
.647 .764 .934 r
.39922 .45293 .40328 .45703 .4101 .45479 .40604 .45068 Mtetra
.646 .763 .934 r
.40604 .45068 .4101 .45479 .41692 .45255 .41288 .44843 Mtetra
.645 .763 .934 r
.41288 .44843 .41692 .45255 .42377 .45032 .41974 .44619 Mtetra
.646 .763 .934 r
.41974 .44619 .42377 .45032 .43063 .44807 .42662 .44393 Mtetra
.42662 .44393 .43063 .44807 .43752 .44582 .43351 .44167 Mtetra
.645 .763 .935 r
.43351 .44167 .43752 .44582 .44441 .44358 .44042 .43942 Mtetra
.645 .763 .934 r
.44042 .43942 .44441 .44358 .45133 .44133 .44735 .43715 Mtetra
.44735 .43715 .45133 .44133 .45826 .43907 .45429 .43488 Mtetra
.644 .763 .935 r
.45429 .43488 .45826 .43907 .46522 .43682 .46125 .43263 Mtetra
.645 .763 .935 r
.46125 .43263 .46522 .43682 .47219 .43456 .46823 .43036 Mtetra
.46823 .43036 .47219 .43456 .47917 .43229 .47523 .42807 Mtetra
.643 .762 .935 r
.47523 .42807 .47917 .43229 .48618 .43004 .48225 .42581 Mtetra
.644 .762 .935 r
.48225 .42581 .48618 .43004 .4932 .42777 .48929 .42353 Mtetra
.644 .763 .935 r
.48929 .42353 .4932 .42777 .50024 .42549 .49634 .42124 Mtetra
.643 .762 .935 r
.49634 .42124 .50024 .42549 .5073 .42323 .50341 .41897 Mtetra
.50341 .41897 .5073 .42323 .51438 .42096 .5105 .41669 Mtetra
.5105 .41669 .51438 .42096 .52148 .41868 .51761 .4144 Mtetra
.51761 .4144 .52148 .41868 .5286 .4164 .52474 .41211 Mtetra
.52474 .41211 .5286 .4164 .53573 .41412 .53188 .40982 Mtetra
.642 .762 .935 r
.53188 .40982 .53573 .41412 .54288 .41184 .53905 .40752 Mtetra
.53905 .40752 .54288 .41184 .55005 .40955 .54623 .40522 Mtetra
.642 .762 .936 r
.54623 .40522 .55005 .40955 .55725 .40725 .55344 .40292 Mtetra
.55344 .40292 .55725 .40725 .56446 .40496 .56066 .40061 Mtetra
.641 .762 .936 r
.56066 .40061 .56446 .40496 .57168 .40266 .5679 .3983 Mtetra
.5679 .3983 .57168 .40266 .57893 .40036 .57516 .39599 Mtetra
.57516 .39599 .57893 .40036 .5862 .39806 .58244 .39368 Mtetra
.58244 .39368 .5862 .39806 .59349 .39576 .58974 .39136 Mtetra
.641 .761 .936 r
.58974 .39136 .59349 .39576 .60079 .39345 .59706 .38904 Mtetra
.64 .761 .936 r
.59706 .38904 .60079 .39345 .60812 .39114 .6044 .38672 Mtetra
.6044 .38672 .60812 .39114 .61547 .38882 .61176 .3844 Mtetra
.61176 .3844 .61547 .38882 .62283 .38651 .61914 .38207 Mtetra
.61914 .38207 .62283 .38651 .63022 .38419 .62654 .37974 Mtetra
.639 .761 .936 r
.62654 .37974 .63022 .38419 .63762 .38187 .63396 .3774 Mtetra
.63396 .3774 .63762 .38187 .64505 .37954 .6414 .37507 Mtetra
.6414 .37507 .64505 .37954 .6525 .37722 .64886 .37273 Mtetra
.639 .761 .937 r
.64886 .37273 .6525 .37722 .65996 .37489 .65634 .37039 Mtetra
.65634 .37039 .65996 .37489 .66745 .37255 .66384 .36804 Mtetra
.639 .761 .936 r
.66384 .36804 .66745 .37255 .67496 .3702 .67136 .36568 Mtetra
.64 .762 .936 r
.67136 .36568 .67496 .3702 .68249 .36782 .6789 .36329 Mtetra
.645 .763 .935 r
.6789 .36329 .68249 .36782 .69003 .36537 .68646 .36083 Mtetra
.648 .765 .934 r
.68646 .36083 .69003 .36537 .69759 .36286 .69403 .3583 Mtetra
.671 .774 .927 r
.69403 .3583 .69759 .36286 .70515 .35995 .70161 .35538 Mtetra
.696 .783 .918 r
.70161 .35538 .70515 .35995 .7127 .35659 .70917 .352 Mtetra
.731 .795 .903 r
.70917 .352 .7127 .35659 .72022 .3525 .71671 .3479 Mtetra
.811 .816 .854 r
.71671 .3479 .72022 .3525 .72762 .34628 .72413 .34167 Mtetra
.854 .822 .816 r
.72413 .34167 .72762 .34628 .73491 .33842 .73144 .33379 Mtetra
.917 .82 .734 r
.73144 .33379 .73491 .33842 .74193 .32658 .73848 .32193 Mtetra
.954 .805 .656 r
.73848 .32193 .74193 .32658 .74856 .30977 .74514 .3051 Mtetra
.967 .794 .616 r
.74514 .3051 .74856 .30977 .7549 .2897 .75151 .285 Mtetra
.982 .769 .54 r
.75151 .285 .7549 .2897 .7605 .26075 .75714 .25601 Mtetra
.985 .76 .516 r
.75714 .25601 .7605 .26075 .76569 .22814 .76238 .22336 Mtetra
.942 .627 .41 r
.10326 .42067 .10758 .42445 .10937 .45443 .105 .45066 Mtetra
.942 .619 .394 r
.105 .45066 .10937 .45443 .11159 .48192 .10718 .47817 Mtetra
.935 .58 .322 r
.10718 .47817 .11159 .48192 .11493 .50122 .1105 .49749 Mtetra
.925 .547 .265 r
.1105 .49749 .11493 .50122 .11878 .51714 .11432 .51342 Mtetra
.875 .435 .089 r
.11432 .51342 .11878 .51714 .12334 .52767 .11888 .52395 Mtetra
.622 .097 0 r
.11888 .52395 .12334 .52767 .12854 .53333 .12407 .5296 Mtetra
0 .226 .691 r
.12407 .5296 .12854 .53333 .13403 .53689 .12956 .53317 Mtetra
.34 .642 .965 r
.12956 .53317 .13403 .53689 .13988 .53751 .13542 .53378 Mtetra
.498 .714 .968 r
.13542 .53378 .13988 .53751 .14589 .53704 .14143 .5333 Mtetra
.573 .742 .956 r
.14143 .5333 .14589 .53704 .15198 .53587 .14753 .53213 Mtetra
.632 .76 .939 r
.14753 .53213 .15198 .53587 .15818 .53402 .15373 .53026 Mtetra
.639 .762 .937 r
.15373 .53026 .15818 .53402 .1644 .53207 .15996 .5283 Mtetra
.648 .764 .933 r
.15996 .5283 .1644 .53207 .17064 .52999 .16622 .52621 Mtetra
.652 .765 .932 r
.16622 .52621 .17064 .52999 .17691 .52784 .17249 .52406 Mtetra
.653 .765 .932 r
.17249 .52406 .17691 .52784 .18319 .52568 .17879 .52189 Mtetra
.17879 .52189 .18319 .52568 .18949 .52352 .1851 .51971 Mtetra
.654 .765 .931 r
.1851 .51971 .18949 .52352 .19581 .52134 .19142 .51753 Mtetra
.19142 .51753 .19581 .52134 .20214 .51916 .19776 .51533 Mtetra
.652 .765 .932 r
.19776 .51533 .20214 .51916 .20848 .51699 .20411 .51315 Mtetra
.653 .765 .932 r
.20411 .51315 .20848 .51699 .21484 .51481 .21048 .51096 Mtetra
.653 .765 .931 r
.21048 .51096 .21484 .51481 .22121 .51262 .21686 .50876 Mtetra
.652 .765 .932 r
.21686 .50876 .22121 .51262 .2276 .51044 .22326 .50658 Mtetra
.22326 .50658 .2276 .51044 .23401 .50826 .22967 .50439 Mtetra
.22967 .50439 .23401 .50826 .24042 .50607 .2361 .50218 Mtetra
.651 .764 .932 r
.2361 .50218 .24042 .50607 .24686 .50388 .24254 .49999 Mtetra
.24254 .49999 .24686 .50388 .25331 .5017 .249 .49779 Mtetra
.652 .765 .932 r
.249 .49779 .25331 .5017 .25977 .49949 .25548 .49558 Mtetra
.651 .764 .932 r
.25548 .49558 .25977 .49949 .26625 .4973 .26197 .49338 Mtetra
.65 .764 .933 r
.26197 .49338 .26625 .4973 .27275 .49511 .26847 .49118 Mtetra
.651 .764 .932 r
.26847 .49118 .27275 .49511 .27926 .4929 .27499 .48896 Mtetra
.65 .764 .933 r
.27499 .48896 .27926 .4929 .28579 .4907 .28153 .48675 Mtetra
.649 .764 .933 r
.28153 .48675 .28579 .4907 .29233 .48851 .28808 .48454 Mtetra
.65 .764 .933 r
.28808 .48454 .29233 .48851 .29889 .4863 .29465 .48232 Mtetra
.29465 .48232 .29889 .4863 .30546 .48408 .30123 .4801 Mtetra
.649 .764 .933 r
.30123 .4801 .30546 .48408 .31205 .48188 .30783 .47789 Mtetra
.30783 .47789 .31205 .48188 .31866 .47967 .31445 .47566 Mtetra
.31445 .47566 .31866 .47967 .32528 .47744 .32108 .47343 Mtetra
.648 .763 .933 r
.32108 .47343 .32528 .47744 .33192 .47524 .32773 .47121 Mtetra
.648 .764 .933 r
.32773 .47121 .33192 .47524 .33858 .47302 .3344 .46898 Mtetra
.649 .764 .933 r
.3344 .46898 .33858 .47302 .34525 .47078 .34108 .46674 Mtetra
.647 .763 .933 r
.34108 .46674 .34525 .47078 .35194 .46857 .34778 .46451 Mtetra
.648 .763 .933 r
.34778 .46451 .35194 .46857 .35864 .46634 .35449 .46228 Mtetra
.35449 .46228 .35864 .46634 .36536 .4641 .36123 .46003 Mtetra
.647 .763 .934 r
.36123 .46003 .36536 .4641 .3721 .46188 .36798 .45779 Mtetra
.36798 .45779 .3721 .46188 .37885 .45965 .37474 .45555 Mtetra
.648 .763 .933 r
.37474 .45555 .37885 .45965 .38563 .4574 .38152 .45329 Mtetra
.647 .763 .934 r
.38152 .45329 .38563 .4574 .39241 .45517 .38832 .45105 Mtetra
.646 .763 .934 r
.38832 .45105 .39241 .45517 .39922 .45293 .39514 .4488 Mtetra
.647 .763 .934 r
.39514 .4488 .39922 .45293 .40604 .45068 .40197 .44654 Mtetra
.646 .763 .934 r
.40197 .44654 .40604 .45068 .41288 .44843 .40882 .44428 Mtetra
.645 .763 .934 r
.40882 .44428 .41288 .44843 .41974 .44619 .41569 .44203 Mtetra
.646 .763 .934 r
.41569 .44203 .41974 .44619 .42662 .44393 .42258 .43976 Mtetra
.42258 .43976 .42662 .44393 .43351 .44167 .42948 .43749 Mtetra
.645 .762 .934 r
.42948 .43749 .43351 .44167 .44042 .43942 .4364 .43523 Mtetra
.645 .763 .934 r
.4364 .43523 .44042 .43942 .44735 .43715 .44334 .43295 Mtetra
.44334 .43295 .44735 .43715 .45429 .43488 .4503 .43067 Mtetra
.644 .762 .935 r
.4503 .43067 .45429 .43488 .46125 .43263 .45727 .4284 Mtetra
.645 .762 .934 r
.45727 .4284 .46125 .43263 .46823 .43036 .46426 .42612 Mtetra
.46426 .42612 .46823 .43036 .47523 .42807 .47128 .42383 Mtetra
.643 .762 .935 r
.47128 .42383 .47523 .42807 .48225 .42581 .4783 .42155 Mtetra
.644 .762 .935 r
.4783 .42155 .48225 .42581 .48929 .42353 .48535 .41926 Mtetra
.644 .762 .934 r
.48535 .41926 .48929 .42353 .49634 .42124 .49242 .41696 Mtetra
.643 .762 .935 r
.49242 .41696 .49634 .42124 .50341 .41897 .4995 .41468 Mtetra
.4995 .41468 .50341 .41897 .5105 .41669 .5066 .41239 Mtetra
.5066 .41239 .5105 .41669 .51761 .4144 .51372 .41009 Mtetra
.51372 .41009 .51761 .4144 .52474 .41211 .52086 .40779 Mtetra
.52086 .40779 .52474 .41211 .53188 .40982 .52802 .40548 Mtetra
.642 .762 .935 r
.52802 .40548 .53188 .40982 .53905 .40752 .5352 .40317 Mtetra
.642 .761 .935 r
.5352 .40317 .53905 .40752 .54623 .40522 .54239 .40086 Mtetra
.54239 .40086 .54623 .40522 .55344 .40292 .54961 .39855 Mtetra
.54961 .39855 .55344 .40292 .56066 .40061 .55684 .39623 Mtetra
.55684 .39623 .56066 .40061 .5679 .3983 .5641 .39391 Mtetra
.641 .761 .935 r
.5641 .39391 .5679 .3983 .57516 .39599 .57137 .39159 Mtetra
.641 .761 .936 r
.57137 .39159 .57516 .39599 .58244 .39368 .57867 .38927 Mtetra
.57867 .38927 .58244 .39368 .58974 .39136 .58598 .38694 Mtetra
.58598 .38694 .58974 .39136 .59706 .38904 .59331 .38461 Mtetra
.64 .761 .936 r
.59331 .38461 .59706 .38904 .6044 .38672 .60066 .38227 Mtetra
.60066 .38227 .6044 .38672 .61176 .3844 .60803 .37994 Mtetra
.60803 .37994 .61176 .3844 .61914 .38207 .61543 .3776 Mtetra
.61543 .3776 .61914 .38207 .62654 .37974 .62284 .37526 Mtetra
.639 .761 .936 r
.62284 .37526 .62654 .37974 .63396 .3774 .63027 .37291 Mtetra
.639 .76 .936 r
.63027 .37291 .63396 .3774 .6414 .37507 .63772 .37056 Mtetra
.63772 .37056 .6414 .37507 .64886 .37273 .6452 .36821 Mtetra
.6452 .36821 .64886 .37273 .65634 .37039 .65269 .36586 Mtetra
.65269 .36586 .65634 .37039 .66384 .36804 .6602 .3635 Mtetra
.639 .761 .936 r
.6602 .3635 .66384 .36804 .67136 .36568 .66774 .36112 Mtetra
.64 .761 .936 r
.66774 .36112 .67136 .36568 .6789 .36329 .67529 .35873 Mtetra
.645 .763 .935 r
.67529 .35873 .6789 .36329 .68646 .36083 .68287 .35625 Mtetra
.648 .764 .934 r
.68287 .35625 .68646 .36083 .69403 .3583 .69045 .35372 Mtetra
.671 .773 .927 r
.69045 .35372 .69403 .3583 .70161 .35538 .69804 .35078 Mtetra
.696 .783 .918 r
.69804 .35078 .70161 .35538 .70917 .352 .70562 .34739 Mtetra
.731 .794 .903 r
.70562 .34739 .70917 .352 .71671 .3479 .71318 .34328 Mtetra
.811 .815 .854 r
.71318 .34328 .71671 .3479 .72413 .34167 .72061 .33703 Mtetra
.854 .822 .816 r
.72061 .33703 .72413 .34167 .73144 .33379 .72794 .32913 Mtetra
.917 .819 .734 r
.72794 .32913 .73144 .33379 .73848 .32193 .735 .31726 Mtetra
.954 .805 .656 r
.735 .31726 .73848 .32193 .74514 .3051 .74169 .30039 Mtetra
.967 .794 .616 r
.74169 .30039 .74514 .3051 .75151 .285 .74809 .28027 Mtetra
.982 .769 .54 r
.74809 .28027 .75151 .285 .75714 .25601 .75377 .25125 Mtetra
.985 .76 .516 r
.75377 .25125 .75714 .25601 .76238 .22336 .75905 .21856 Mtetra
.942 .627 .41 r
.09892 .41687 .10326 .42067 .105 .45066 .10061 .44689 Mtetra
.942 .619 .394 r
.10061 .44689 .105 .45066 .10718 .47817 .10275 .47442 Mtetra
.935 .58 .323 r
.10275 .47442 .10718 .47817 .1105 .49749 .10605 .49376 Mtetra
.925 .546 .265 r
.10605 .49376 .1105 .49749 .11432 .51342 .10985 .50969 Mtetra
.875 .435 .09 r
.10985 .50969 .11432 .51342 .11888 .52395 .11439 .52023 Mtetra
.623 .098 0 r
.11439 .52023 .11888 .52395 .12407 .5296 .11958 .52588 Mtetra
0 .225 .689 r
.11958 .52588 .12407 .5296 .12956 .53317 .12507 .52944 Mtetra
.339 .642 .965 r
.12507 .52944 .12956 .53317 .13542 .53378 .13093 .53005 Mtetra
.497 .715 .968 r
.13093 .53005 .13542 .53378 .14143 .5333 .13695 .52956 Mtetra
.573 .743 .957 r
.13695 .52956 .14143 .5333 .14753 .53213 .14306 .52838 Mtetra
.632 .761 .94 r
.14306 .52838 .14753 .53213 .15373 .53026 .14927 .52651 Mtetra
.639 .763 .937 r
.14927 .52651 .15373 .53026 .15996 .5283 .15551 .52453 Mtetra
.648 .765 .934 r
.15551 .52453 .15996 .5283 .16622 .52621 .16177 .52243 Mtetra
.652 .766 .932 r
.16177 .52243 .16622 .52621 .17249 .52406 .16806 .52027 Mtetra
.653 .766 .932 r
.16806 .52027 .17249 .52406 .17879 .52189 .17436 .51809 Mtetra
.17436 .51809 .17879 .52189 .1851 .51971 .18068 .51591 Mtetra
.654 .766 .932 r
.18068 .51591 .1851 .51971 .19142 .51753 .18701 .51371 Mtetra
.18701 .51371 .19142 .51753 .19776 .51533 .19336 .51151 Mtetra
.652 .766 .932 r
.19336 .51151 .19776 .51533 .20411 .51315 .19972 .50932 Mtetra
.653 .766 .932 r
.19972 .50932 .20411 .51315 .21048 .51096 .20609 .50712 Mtetra
.20609 .50712 .21048 .51096 .21686 .50876 .21249 .50491 Mtetra
.652 .765 .933 r
.21249 .50491 .21686 .50876 .22326 .50658 .21889 .50271 Mtetra
.652 .766 .933 r
.21889 .50271 .22326 .50658 .22967 .50439 .22532 .50051 Mtetra
.652 .766 .932 r
.22532 .50051 .22967 .50439 .2361 .50218 .23175 .49829 Mtetra
.651 .765 .933 r
.23175 .49829 .2361 .50218 .24254 .49999 .23821 .49609 Mtetra
.23821 .49609 .24254 .49999 .249 .49779 .24468 .49388 Mtetra
.652 .765 .933 r
.24468 .49388 .249 .49779 .25548 .49558 .25116 .49166 Mtetra
.651 .765 .933 r
.25116 .49166 .25548 .49558 .26197 .49338 .25766 .48945 Mtetra
.65 .765 .933 r
.25766 .48945 .26197 .49338 .26847 .49118 .26417 .48724 Mtetra
.651 .765 .933 r
.26417 .48724 .26847 .49118 .27499 .48896 .27071 .48501 Mtetra
.65 .765 .933 r
.27071 .48501 .27499 .48896 .28153 .48675 .27725 .48279 Mtetra
.649 .765 .933 r
.27725 .48279 .28153 .48675 .28808 .48454 .28381 .48058 Mtetra
.65 .765 .933 r
.28381 .48058 .28808 .48454 .29465 .48232 .29039 .47834 Mtetra
.29039 .47834 .29465 .48232 .30123 .4801 .29699 .47611 Mtetra
.649 .765 .934 r
.29699 .47611 .30123 .4801 .30783 .47789 .3036 .47389 Mtetra
.649 .765 .933 r
.3036 .47389 .30783 .47789 .31445 .47566 .31022 .47165 Mtetra
.31022 .47165 .31445 .47566 .32108 .47343 .31687 .46941 Mtetra
.648 .764 .934 r
.31687 .46941 .32108 .47343 .32773 .47121 .32353 .46718 Mtetra
.32353 .46718 .32773 .47121 .3344 .46898 .3302 .46494 Mtetra
.649 .765 .934 r
.3302 .46494 .3344 .46898 .34108 .46674 .3369 .46269 Mtetra
.647 .764 .934 r
.3369 .46269 .34108 .46674 .34778 .46451 .3436 .46045 Mtetra
.648 .764 .934 r
.3436 .46045 .34778 .46451 .35449 .46228 .35033 .45821 Mtetra
.35033 .45821 .35449 .46228 .36123 .46003 .35707 .45595 Mtetra
.647 .764 .934 r
.35707 .45595 .36123 .46003 .36798 .45779 .36383 .4537 Mtetra
.36383 .4537 .36798 .45779 .37474 .45555 .37061 .45145 Mtetra
.37061 .45145 .37474 .45555 .38152 .45329 .3774 .44918 Mtetra
.646 .764 .934 r
.3774 .44918 .38152 .45329 .38832 .45105 .38421 .44692 Mtetra
.38421 .44692 .38832 .45105 .39514 .4488 .39104 .44467 Mtetra
.647 .764 .934 r
.39104 .44467 .39514 .4488 .40197 .44654 .39788 .44239 Mtetra
.646 .764 .934 r
.39788 .44239 .40197 .44654 .40882 .44428 .40474 .44012 Mtetra
.645 .763 .935 r
.40474 .44012 .40882 .44428 .41569 .44203 .41162 .43786 Mtetra
.646 .764 .934 r
.41162 .43786 .41569 .44203 .42258 .43976 .41852 .43558 Mtetra
.646 .764 .935 r
.41852 .43558 .42258 .43976 .42948 .43749 .42544 .4333 Mtetra
.645 .763 .935 r
.42544 .4333 .42948 .43749 .4364 .43523 .43237 .43103 Mtetra
.43237 .43103 .4364 .43523 .44334 .43295 .43932 .42874 Mtetra
.43932 .42874 .44334 .43295 .4503 .43067 .44629 .42645 Mtetra
.644 .763 .935 r
.44629 .42645 .4503 .43067 .45727 .4284 .45327 .42417 Mtetra
.645 .763 .935 r
.45327 .42417 .45727 .4284 .46426 .42612 .46028 .42188 Mtetra
.46028 .42188 .46426 .42612 .47128 .42383 .4673 .41958 Mtetra
.643 .763 .935 r
.4673 .41958 .47128 .42383 .4783 .42155 .47434 .41729 Mtetra
.644 .763 .935 r
.47434 .41729 .4783 .42155 .48535 .41926 .4814 .41499 Mtetra
.4814 .41499 .48535 .41926 .49242 .41696 .48847 .41268 Mtetra
.643 .763 .936 r
.48847 .41268 .49242 .41696 .4995 .41468 .49557 .41038 Mtetra
.49557 .41038 .4995 .41468 .5066 .41239 .50268 .40808 Mtetra
.643 .763 .935 r
.50268 .40808 .5066 .41239 .51372 .41009 .50982 .40577 Mtetra
.643 .763 .936 r
.50982 .40577 .51372 .41009 .52086 .40779 .51697 .40346 Mtetra
.643 .762 .936 r
.51697 .40346 .52086 .40779 .52802 .40548 .52414 .40114 Mtetra
.642 .762 .936 r
.52414 .40114 .52802 .40548 .5352 .40317 .53133 .39882 Mtetra
.53133 .39882 .5352 .40317 .54239 .40086 .53854 .3965 Mtetra
.53854 .3965 .54239 .40086 .54961 .39855 .54577 .39417 Mtetra
.54577 .39417 .54961 .39855 .55684 .39623 .55301 .39185 Mtetra
.641 .762 .936 r
.55301 .39185 .55684 .39623 .5641 .39391 .56028 .38952 Mtetra
.56028 .38952 .5641 .39391 .57137 .39159 .56756 .38718 Mtetra
.56756 .38718 .57137 .39159 .57867 .38927 .57487 .38485 Mtetra
.57487 .38485 .57867 .38927 .58598 .38694 .5822 .38251 Mtetra
.5822 .38251 .58598 .38694 .59331 .38461 .58954 .38017 Mtetra
.64 .762 .936 r
.58954 .38017 .59331 .38461 .60066 .38227 .59691 .37782 Mtetra
.59691 .37782 .60066 .38227 .60803 .37994 .60429 .37547 Mtetra
.64 .762 .937 r
.60429 .37547 .60803 .37994 .61543 .3776 .6117 .37312 Mtetra
.6117 .37312 .61543 .3776 .62284 .37526 .61912 .37077 Mtetra
.639 .761 .937 r
.61912 .37077 .62284 .37526 .63027 .37291 .62657 .36841 Mtetra
.62657 .36841 .63027 .37291 .63772 .37056 .63403 .36605 Mtetra
.63403 .36605 .63772 .37056 .6452 .36821 .64152 .36369 Mtetra
.64152 .36369 .6452 .36821 .65269 .36586 .64903 .36133 Mtetra
.64903 .36133 .65269 .36586 .6602 .3635 .65656 .35895 Mtetra
.65656 .35895 .6602 .3635 .66774 .36112 .6641 .35657 Mtetra
.64 .762 .936 r
.6641 .35657 .66774 .36112 .67529 .35873 .67167 .35416 Mtetra
.645 .764 .935 r
.67167 .35416 .67529 .35873 .68287 .35625 .67926 .35167 Mtetra
.648 .765 .934 r
.67926 .35167 .68287 .35625 .69045 .35372 .68686 .34912 Mtetra
.671 .774 .927 r
.68686 .34912 .69045 .35372 .69804 .35078 .69446 .34618 Mtetra
.696 .783 .918 r
.69446 .34618 .69804 .35078 .70562 .34739 .70206 .34277 Mtetra
.731 .795 .903 r
.70206 .34277 .70562 .34739 .71318 .34328 .70963 .33864 Mtetra
.811 .816 .854 r
.70963 .33864 .71318 .34328 .72061 .33703 .71708 .33238 Mtetra
.854 .822 .816 r
.71708 .33238 .72061 .33703 .72794 .32913 .72443 .32447 Mtetra
.918 .82 .735 r
.72443 .32447 .72794 .32913 .735 .31726 .73152 .31257 Mtetra
.955 .805 .656 r
.73152 .31257 .735 .31726 .74169 .30039 .73823 .29568 Mtetra
.967 .794 .616 r
.73823 .29568 .74169 .30039 .74809 .28027 .74467 .27553 Mtetra
.982 .769 .54 r
.74467 .27553 .74809 .28027 .75377 .25125 .75038 .24647 Mtetra
.985 .76 .516 r
.75038 .24647 .75377 .25125 .75905 .21856 .7557 .21374 Mtetra
.942 .627 .41 r
.09456 .41306 .09892 .41687 .10061 .44689 .09621 .44311 Mtetra
.942 .619 .394 r
.09621 .44311 .10061 .44689 .10275 .47442 .09831 .47066 Mtetra
.935 .58 .323 r
.09831 .47066 .10275 .47442 .10605 .49376 .10157 .49 Mtetra
.925 .546 .265 r
.10157 .49 .10605 .49376 .10985 .50969 .10536 .50595 Mtetra
.875 .435 .089 r
.10536 .50595 .10985 .50969 .11439 .52023 .10989 .51649 Mtetra
.623 .097 0 r
.10989 .51649 .11439 .52023 .11958 .52588 .11507 .52214 Mtetra
0 .225 .69 r
.11507 .52214 .11958 .52588 .12507 .52944 .12056 .5257 Mtetra
.339 .642 .965 r
.12056 .5257 .12507 .52944 .13093 .53005 .12643 .52629 Mtetra
.497 .714 .968 r
.12643 .52629 .13093 .53005 .13695 .52956 .13245 .5258 Mtetra
.573 .742 .957 r
.13245 .5258 .13695 .52956 .14306 .52838 .13857 .52461 Mtetra
.632 .76 .94 r
.13857 .52461 .14306 .52838 .14927 .52651 .14479 .52273 Mtetra
.639 .762 .937 r
.14479 .52273 .14927 .52651 .15551 .52453 .15103 .52074 Mtetra
.648 .765 .934 r
.15103 .52074 .15551 .52453 .16177 .52243 .1573 .51864 Mtetra
.652 .766 .932 r
.1573 .51864 .16177 .52243 .16806 .52027 .1636 .51646 Mtetra
.653 .766 .932 r
.1636 .51646 .16806 .52027 .17436 .51809 .16991 .51427 Mtetra
.16991 .51427 .17436 .51809 .18068 .51591 .17624 .51208 Mtetra
.654 .766 .932 r
.17624 .51208 .18068 .51591 .18701 .51371 .18258 .50987 Mtetra
.18258 .50987 .18701 .51371 .19336 .51151 .18893 .50766 Mtetra
.652 .766 .932 r
.18893 .50766 .19336 .51151 .19972 .50932 .19531 .50546 Mtetra
.653 .766 .932 r
.19531 .50546 .19972 .50932 .20609 .50712 .20169 .50325 Mtetra
.20169 .50325 .20609 .50712 .21249 .50491 .20809 .50103 Mtetra
.652 .765 .933 r
.20809 .50103 .21249 .50491 .21889 .50271 .21451 .49883 Mtetra
.652 .765 .932 r
.21451 .49883 .21889 .50271 .22532 .50051 .22094 .49661 Mtetra
.652 .766 .932 r
.22094 .49661 .22532 .50051 .23175 .49829 .22739 .49439 Mtetra
.651 .765 .933 r
.22739 .49439 .23175 .49829 .23821 .49609 .23385 .49218 Mtetra
.23385 .49218 .23821 .49609 .24468 .49388 .24033 .48996 Mtetra
.652 .765 .933 r
.24033 .48996 .24468 .49388 .25116 .49166 .24682 .48773 Mtetra
.651 .765 .933 r
.24682 .48773 .25116 .49166 .25766 .48945 .25333 .48551 Mtetra
.65 .765 .933 r
.25333 .48551 .25766 .48945 .26417 .48724 .25986 .48328 Mtetra
.651 .765 .933 r
.25986 .48328 .26417 .48724 .27071 .48501 .2664 .48105 Mtetra
.65 .765 .933 r
.2664 .48105 .27071 .48501 .27725 .48279 .27295 .47882 Mtetra
.649 .765 .933 r
.27295 .47882 .27725 .48279 .28381 .48058 .27953 .47659 Mtetra
.65 .765 .933 r
.27953 .47659 .28381 .48058 .29039 .47834 .28612 .47435 Mtetra
.28612 .47435 .29039 .47834 .29699 .47611 .29272 .4721 Mtetra
.649 .764 .934 r
.29272 .4721 .29699 .47611 .3036 .47389 .29934 .46987 Mtetra
.649 .765 .933 r
.29934 .46987 .3036 .47389 .31022 .47165 .30598 .46762 Mtetra
.30598 .46762 .31022 .47165 .31687 .46941 .31263 .46537 Mtetra
.648 .764 .934 r
.31263 .46537 .31687 .46941 .32353 .46718 .3193 .46313 Mtetra
.3193 .46313 .32353 .46718 .3302 .46494 .32599 .46088 Mtetra
.649 .764 .933 r
.32599 .46088 .3302 .46494 .3369 .46269 .33269 .45862 Mtetra
.647 .764 .934 r
.33269 .45862 .3369 .46269 .3436 .46045 .33941 .45637 Mtetra
.648 .764 .934 r
.33941 .45637 .3436 .46045 .35033 .45821 .34614 .45412 Mtetra
.34614 .45412 .35033 .45821 .35707 .45595 .3529 .45185 Mtetra
.647 .764 .934 r
.3529 .45185 .35707 .45595 .36383 .4537 .35967 .44959 Mtetra
.35967 .44959 .36383 .4537 .37061 .45145 .36645 .44733 Mtetra
.36645 .44733 .37061 .45145 .3774 .44918 .37326 .44505 Mtetra
.646 .764 .934 r
.37326 .44505 .3774 .44918 .38421 .44692 .38008 .44278 Mtetra
.38008 .44278 .38421 .44692 .39104 .44467 .38692 .44051 Mtetra
.647 .764 .934 r
.38692 .44051 .39104 .44467 .39788 .44239 .39377 .43823 Mtetra
.646 .764 .934 r
.39377 .43823 .39788 .44239 .40474 .44012 .40065 .43595 Mtetra
.645 .763 .935 r
.40065 .43595 .40474 .44012 .41162 .43786 .40754 .43368 Mtetra
.646 .764 .934 r
.40754 .43368 .41162 .43786 .41852 .43558 .41444 .43138 Mtetra
.646 .763 .935 r
.41444 .43138 .41852 .43558 .42544 .4333 .42137 .42909 Mtetra
.645 .763 .935 r
.42137 .42909 .42544 .4333 .43237 .43103 .42831 .42681 Mtetra
.42831 .42681 .43237 .43103 .43932 .42874 .43528 .42451 Mtetra
.43528 .42451 .43932 .42874 .44629 .42645 .44225 .42221 Mtetra
.644 .763 .935 r
.44225 .42221 .44629 .42645 .45327 .42417 .44925 .41992 Mtetra
.645 .763 .935 r
.44925 .41992 .45327 .42417 .46028 .42188 .45627 .41762 Mtetra
.45627 .41762 .46028 .42188 .4673 .41958 .4633 .4153 Mtetra
.643 .763 .935 r
.4633 .4153 .4673 .41958 .47434 .41729 .47035 .41301 Mtetra
.644 .763 .935 r
.47035 .41301 .47434 .41729 .4814 .41499 .47742 .4107 Mtetra
.47742 .4107 .4814 .41499 .48847 .41268 .48451 .40837 Mtetra
.643 .762 .935 r
.48451 .40837 .48847 .41268 .49557 .41038 .49162 .40606 Mtetra
.643 .762 .936 r
.49162 .40606 .49557 .41038 .50268 .40808 .49875 .40375 Mtetra
.643 .763 .935 r
.49875 .40375 .50268 .40808 .50982 .40577 .50589 .40143 Mtetra
.643 .762 .936 r
.50589 .40143 .50982 .40577 .51697 .40346 .51306 .39911 Mtetra
.51306 .39911 .51697 .40346 .52414 .40114 .52024 .39678 Mtetra
.642 .762 .936 r
.52024 .39678 .52414 .40114 .53133 .39882 .52744 .39445 Mtetra
.52744 .39445 .53133 .39882 .53854 .3965 .53466 .39212 Mtetra
.53466 .39212 .53854 .3965 .54577 .39417 .5419 .38978 Mtetra
.5419 .38978 .54577 .39417 .55301 .39185 .54916 .38744 Mtetra
.641 .762 .936 r
.54916 .38744 .55301 .39185 .56028 .38952 .55644 .3851 Mtetra
.55644 .3851 .56028 .38952 .56756 .38718 .56374 .38275 Mtetra
.56374 .38275 .56756 .38718 .57487 .38485 .57106 .38041 Mtetra
.57106 .38041 .57487 .38485 .5822 .38251 .5784 .37805 Mtetra
.5784 .37805 .5822 .38251 .58954 .38017 .58575 .3757 Mtetra
.64 .762 .936 r
.58575 .3757 .58954 .38017 .59691 .37782 .59313 .37334 Mtetra
.59313 .37334 .59691 .37782 .60429 .37547 .60053 .37098 Mtetra
.64 .761 .936 r
.60053 .37098 .60429 .37547 .6117 .37312 .60795 .36862 Mtetra
.64 .761 .937 r
.60795 .36862 .6117 .37312 .61912 .37077 .61539 .36626 Mtetra
.639 .761 .937 r
.61539 .36626 .61912 .37077 .62657 .36841 .62285 .36389 Mtetra
.62285 .36389 .62657 .36841 .63403 .36605 .63032 .36152 Mtetra
.63032 .36152 .63403 .36605 .64152 .36369 .63782 .35914 Mtetra
.63782 .35914 .64152 .36369 .64903 .36133 .64535 .35677 Mtetra
.64535 .35677 .64903 .36133 .65656 .35895 .65289 .35438 Mtetra
.65289 .35438 .65656 .35895 .6641 .35657 .66045 .35198 Mtetra
.64 .762 .936 r
.66045 .35198 .6641 .35657 .67167 .35416 .66803 .34956 Mtetra
.645 .764 .935 r
.66803 .34956 .67167 .35416 .67926 .35167 .67563 .34707 Mtetra
.648 .765 .934 r
.67563 .34707 .67926 .35167 .68686 .34912 .68325 .34451 Mtetra
.671 .774 .927 r
.68325 .34451 .68686 .34912 .69446 .34618 .69087 .34155 Mtetra
.696 .783 .918 r
.69087 .34155 .69446 .34618 .70206 .34277 .69848 .33813 Mtetra
.731 .795 .903 r
.69848 .33813 .70206 .34277 .70963 .33864 .70606 .33399 Mtetra
.811 .816 .854 r
.70606 .33399 .70963 .33864 .71708 .33238 .71353 .32771 Mtetra
.854 .822 .816 r
.71353 .32771 .71708 .33238 .72443 .32447 .72091 .31978 Mtetra
.918 .82 .735 r
.72091 .31978 .72443 .32447 .73152 .31257 .72801 .30786 Mtetra
.955 .805 .656 r
.72801 .30786 .73152 .31257 .73823 .29568 .73476 .29095 Mtetra
.967 .794 .616 r
.73476 .29095 .73823 .29568 .74467 .27553 .74122 .27076 Mtetra
.982 .769 .54 r
.74122 .27076 .74467 .27553 .75038 .24647 .74697 .24167 Mtetra
.985 .76 .516 r
.74697 .24167 .75038 .24647 .7557 .21374 .75233 .2089 Mtetra
.942 .627 .41 r
.09018 .40923 .09456 .41306 .09621 .44311 .09179 .4393 Mtetra
.942 .619 .394 r
.09179 .4393 .09621 .44311 .09831 .47066 .09384 .46687 Mtetra
.935 .58 .322 r
.09384 .46687 .09831 .47066 .10157 .49 .09708 .48623 Mtetra
.925 .546 .265 r
.09708 .48623 .10157 .49 .10536 .50595 .10084 .50218 Mtetra
.875 .435 .089 r
.10084 .50218 .10536 .50595 .10989 .51649 .10536 .51272 Mtetra
.622 .097 0 r
.10536 .51272 .10989 .51649 .11507 .52214 .11055 .51837 Mtetra
0 .226 .691 r
.11055 .51837 .11507 .52214 .12056 .5257 .11603 .52193 Mtetra
.34 .642 .965 r
.11603 .52193 .12056 .5257 .12643 .52629 .1219 .52251 Mtetra
.498 .714 .968 r
.1219 .52251 .12643 .52629 .13245 .5258 .12793 .52201 Mtetra
.573 .742 .956 r
.12793 .52201 .13245 .5258 .13857 .52461 .13406 .52081 Mtetra
.632 .76 .939 r
.13406 .52081 .13857 .52461 .14479 .52273 .14028 .51892 Mtetra
.64 .762 .937 r
.14028 .51892 .14479 .52273 .15103 .52074 .14654 .51693 Mtetra
.648 .764 .934 r
.14654 .51693 .15103 .52074 .1573 .51864 .15282 .51481 Mtetra
.652 .765 .932 r
.15282 .51481 .1573 .51864 .1636 .51646 .15912 .51263 Mtetra
.653 .765 .932 r
.15912 .51263 .1636 .51646 .16991 .51427 .16544 .51043 Mtetra
.16544 .51043 .16991 .51427 .17624 .51208 .17178 .50822 Mtetra
.654 .765 .931 r
.17178 .50822 .17624 .51208 .18258 .50987 .17813 .50601 Mtetra
.17813 .50601 .18258 .50987 .18893 .50766 .18449 .50378 Mtetra
.652 .765 .932 r
.18449 .50378 .18893 .50766 .19531 .50546 .19087 .50158 Mtetra
.653 .765 .932 r
.19087 .50158 .19531 .50546 .20169 .50325 .19727 .49936 Mtetra
.19727 .49936 .20169 .50325 .20809 .50103 .20368 .49713 Mtetra
.652 .765 .932 r
.20368 .49713 .20809 .50103 .21451 .49883 .21011 .49491 Mtetra
.21011 .49491 .21451 .49883 .22094 .49661 .21655 .49269 Mtetra
.21655 .49269 .22094 .49661 .22739 .49439 .22301 .49045 Mtetra
.651 .765 .932 r
.22301 .49045 .22739 .49439 .23385 .49218 .22948 .48823 Mtetra
.22948 .48823 .23385 .49218 .24033 .48996 .23596 .486 Mtetra
.652 .765 .932 r
.23596 .486 .24033 .48996 .24682 .48773 .24247 .48376 Mtetra
.651 .764 .932 r
.24247 .48376 .24682 .48773 .25333 .48551 .24899 .48153 Mtetra
.65 .764 .933 r
.24899 .48153 .25333 .48551 .25986 .48328 .25552 .4793 Mtetra
.651 .764 .932 r
.25552 .4793 .25986 .48328 .2664 .48105 .26207 .47705 Mtetra
.65 .764 .933 r
.26207 .47705 .2664 .48105 .27295 .47882 .26864 .47481 Mtetra
.649 .764 .933 r
.26864 .47481 .27295 .47882 .27953 .47659 .27522 .47257 Mtetra
.65 .764 .933 r
.27522 .47257 .27953 .47659 .28612 .47435 .28182 .47032 Mtetra
.28182 .47032 .28612 .47435 .29272 .4721 .28843 .46807 Mtetra
.649 .764 .933 r
.28843 .46807 .29272 .4721 .29934 .46987 .29506 .46582 Mtetra
.29506 .46582 .29934 .46987 .30598 .46762 .30171 .46357 Mtetra
.30171 .46357 .30598 .46762 .31263 .46537 .30837 .4613 Mtetra
.648 .764 .933 r
.30837 .4613 .31263 .46537 .3193 .46313 .31505 .45905 Mtetra
.31505 .45905 .3193 .46313 .32599 .46088 .32175 .45679 Mtetra
.649 .764 .933 r
.32175 .45679 .32599 .46088 .33269 .45862 .32846 .45452 Mtetra
.647 .763 .934 r
.32846 .45452 .33269 .45862 .33941 .45637 .33519 .45226 Mtetra
.648 .763 .933 r
.33519 .45226 .33941 .45637 .34614 .45412 .34194 .44999 Mtetra
.648 .764 .933 r
.34194 .44999 .34614 .45412 .3529 .45185 .3487 .44771 Mtetra
.647 .763 .934 r
.3487 .44771 .3529 .45185 .35967 .44959 .35548 .44545 Mtetra
.35548 .44545 .35967 .44959 .36645 .44733 .36228 .44317 Mtetra
.648 .763 .933 r
.36228 .44317 .36645 .44733 .37326 .44505 .3691 .44088 Mtetra
.647 .763 .934 r
.3691 .44088 .37326 .44505 .38008 .44278 .37593 .43861 Mtetra
.646 .763 .934 r
.37593 .43861 .38008 .44278 .38692 .44051 .38278 .43633 Mtetra
.647 .763 .934 r
.38278 .43633 .38692 .44051 .39377 .43823 .38964 .43403 Mtetra
.646 .763 .934 r
.38964 .43403 .39377 .43823 .40065 .43595 .39653 .43174 Mtetra
.645 .763 .934 r
.39653 .43174 .40065 .43595 .40754 .43368 .40343 .42946 Mtetra
.646 .763 .934 r
.40343 .42946 .40754 .43368 .41444 .43138 .41035 .42715 Mtetra
.41035 .42715 .41444 .43138 .42137 .42909 .41729 .42485 Mtetra
.645 .762 .934 r
.41729 .42485 .42137 .42909 .42831 .42681 .42424 .42256 Mtetra
.645 .763 .934 r
.42424 .42256 .42831 .42681 .43528 .42451 .43121 .42025 Mtetra
.43121 .42025 .43528 .42451 .44225 .42221 .4382 .41794 Mtetra
.644 .762 .935 r
.4382 .41794 .44225 .42221 .44925 .41992 .44521 .41564 Mtetra
.645 .762 .934 r
.44521 .41564 .44925 .41992 .45627 .41762 .45224 .41332 Mtetra
.645 .763 .934 r
.45224 .41332 .45627 .41762 .4633 .4153 .45929 .411 Mtetra
.643 .762 .935 r
.45929 .411 .4633 .4153 .47035 .41301 .46635 .40869 Mtetra
.644 .762 .935 r
.46635 .40869 .47035 .41301 .47742 .4107 .47343 .40637 Mtetra
.47343 .40637 .47742 .4107 .48451 .40837 .48053 .40403 Mtetra
.643 .762 .935 r
.48053 .40403 .48451 .40837 .49162 .40606 .48765 .40171 Mtetra
.48765 .40171 .49162 .40606 .49875 .40375 .49479 .39939 Mtetra
.49479 .39939 .49875 .40375 .50589 .40143 .50195 .39706 Mtetra
.50195 .39706 .50589 .40143 .51306 .39911 .50912 .39472 Mtetra
.50912 .39472 .51306 .39911 .52024 .39678 .51632 .39238 Mtetra
.642 .762 .935 r
.51632 .39238 .52024 .39678 .52744 .39445 .52353 .39004 Mtetra
.52353 .39004 .52744 .39445 .53466 .39212 .53077 .3877 Mtetra
.53077 .3877 .53466 .39212 .5419 .38978 .53802 .38535 Mtetra
.642 .761 .935 r
.53802 .38535 .5419 .38978 .54916 .38744 .54529 .383 Mtetra
.641 .761 .935 r
.54529 .383 .54916 .38744 .55644 .3851 .55258 .38065 Mtetra
.641 .761 .936 r
.55258 .38065 .55644 .3851 .56374 .38275 .55989 .37829 Mtetra
.55989 .37829 .56374 .38275 .57106 .38041 .56722 .37593 Mtetra
.56722 .37593 .57106 .38041 .5784 .37805 .57458 .37357 Mtetra
.57458 .37357 .5784 .37805 .58575 .3757 .58195 .3712 Mtetra
.64 .761 .936 r
.58195 .3712 .58575 .3757 .59313 .37334 .58934 .36883 Mtetra
.58934 .36883 .59313 .37334 .60053 .37098 .59675 .36646 Mtetra
.59675 .36646 .60053 .37098 .60795 .36862 .60418 .36409 Mtetra
.60418 .36409 .60795 .36862 .61539 .36626 .61163 .36171 Mtetra
.639 .761 .936 r
.61163 .36171 .61539 .36626 .62285 .36389 .6191 .35933 Mtetra
.6191 .35933 .62285 .36389 .63032 .36152 .6266 .35695 Mtetra
.6266 .35695 .63032 .36152 .63782 .35914 .63411 .35456 Mtetra
.639 .76 .936 r
.63411 .35456 .63782 .35914 .64535 .35677 .64165 .35217 Mtetra
.639 .761 .936 r
.64165 .35217 .64535 .35677 .65289 .35438 .6492 .34978 Mtetra
.6492 .34978 .65289 .35438 .66045 .35198 .65678 .34737 Mtetra
.64 .761 .936 r
.65678 .34737 .66045 .35198 .66803 .34956 .66437 .34493 Mtetra
.645 .763 .935 r
.66437 .34493 .66803 .34956 .67563 .34707 .67199 .34242 Mtetra
.648 .764 .934 r
.67199 .34242 .67563 .34707 .68325 .34451 .67962 .33985 Mtetra
.671 .773 .927 r
.67962 .33985 .68325 .34451 .69087 .34155 .68725 .33688 Mtetra
.696 .783 .918 r
.68725 .33688 .69087 .34155 .69848 .33813 .69488 .33345 Mtetra
.731 .795 .903 r
.69488 .33345 .69848 .33813 .70606 .33399 .70248 .32929 Mtetra
.811 .816 .854 r
.70248 .32929 .70606 .33399 .71353 .32771 .70997 .323 Mtetra
.854 .822 .816 r
.70997 .323 .71353 .32771 .72091 .31978 .71736 .31505 Mtetra
.917 .82 .735 r
.71736 .31505 .72091 .31978 .72801 .30786 .72449 .30311 Mtetra
.954 .805 .656 r
.72449 .30311 .72801 .30786 .73476 .29095 .73126 .28617 Mtetra
.967 .794 .616 r
.73126 .28617 .73476 .29095 .74122 .27076 .73776 .26596 Mtetra
.982 .769 .54 r
.73776 .26596 .74122 .27076 .74697 .24167 .74355 .23683 Mtetra
.985 .76 .516 r
.74355 .23683 .74697 .24167 .75233 .2089 .74895 .20403 Mtetra
.942 .627 .41 r
.08578 .40537 .09018 .40923 .09179 .4393 .08734 .43546 Mtetra
.942 .619 .394 r
.08734 .43546 .09179 .4393 .09384 .46687 .08936 .46306 Mtetra
.935 .58 .322 r
.08936 .46306 .09384 .46687 .09708 .48623 .09257 .48242 Mtetra
.925 .546 .265 r
.09257 .48242 .09708 .48623 .10084 .50218 .09631 .49839 Mtetra
.875 .435 .088 r
.09631 .49839 .10084 .50218 .10536 .51272 .10082 .50893 Mtetra
.621 .096 0 r
.10082 .50893 .10536 .51272 .11055 .51837 .106 .51458 Mtetra
0 .227 .692 r
.106 .51458 .11055 .51837 .11603 .52193 .11148 .51813 Mtetra
.341 .642 .965 r
.11148 .51813 .11603 .52193 .1219 .52251 .11736 .51871 Mtetra
.498 .714 .968 r
.11736 .51871 .1219 .52251 .12793 .52201 .12339 .5182 Mtetra
.573 .742 .956 r
.12339 .5182 .12793 .52201 .13406 .52081 .12953 .51699 Mtetra
.632 .759 .939 r
.12953 .51699 .13406 .52081 .14028 .51892 .13576 .51509 Mtetra
.64 .761 .937 r
.13576 .51509 .14028 .51892 .14654 .51693 .14202 .51309 Mtetra
.648 .764 .933 r
.14202 .51309 .14654 .51693 .15282 .51481 .14831 .51096 Mtetra
.652 .765 .932 r
.14831 .51096 .15282 .51481 .15912 .51263 .15463 .50877 Mtetra
.653 .765 .931 r
.15463 .50877 .15912 .51263 .16544 .51043 .16095 .50656 Mtetra
.16095 .50656 .16544 .51043 .17178 .50822 .1673 .50435 Mtetra
.654 .765 .931 r
.1673 .50435 .17178 .50822 .17813 .50601 .17366 .50212 Mtetra
.17366 .50212 .17813 .50601 .18449 .50378 .18003 .49989 Mtetra
.652 .765 .932 r
.18003 .49989 .18449 .50378 .19087 .50158 .18642 .49767 Mtetra
.653 .765 .932 r
.18642 .49767 .19087 .50158 .19727 .49936 .19283 .49544 Mtetra
.653 .765 .931 r
.19283 .49544 .19727 .49936 .20368 .49713 .19925 .4932 Mtetra
.652 .765 .932 r
.19925 .4932 .20368 .49713 .21011 .49491 .20568 .49097 Mtetra
.20568 .49097 .21011 .49491 .21655 .49269 .21213 .48874 Mtetra
.21213 .48874 .21655 .49269 .22301 .49045 .2186 .4865 Mtetra
.651 .764 .932 r
.2186 .4865 .22301 .49045 .22948 .48823 .22508 .48426 Mtetra
.22508 .48426 .22948 .48823 .23596 .486 .23158 .48203 Mtetra
.652 .765 .932 r
.23158 .48203 .23596 .486 .24247 .48376 .23809 .47977 Mtetra
.651 .764 .932 r
.23809 .47977 .24247 .48376 .24899 .48153 .24462 .47753 Mtetra
.65 .764 .932 r
.24462 .47753 .24899 .48153 .25552 .4793 .25116 .47529 Mtetra
.651 .764 .932 r
.25116 .47529 .25552 .4793 .26207 .47705 .25773 .47303 Mtetra
.65 .764 .932 r
.25773 .47303 .26207 .47705 .26864 .47481 .2643 .47078 Mtetra
.649 .764 .933 r
.2643 .47078 .26864 .47481 .27522 .47257 .27089 .46853 Mtetra
.65 .764 .932 r
.27089 .46853 .27522 .47257 .28182 .47032 .2775 .46627 Mtetra
.65 .764 .933 r
.2775 .46627 .28182 .47032 .28843 .46807 .28413 .46401 Mtetra
.649 .764 .933 r
.28413 .46401 .28843 .46807 .29506 .46582 .29077 .46175 Mtetra
.29077 .46175 .29506 .46582 .30171 .46357 .29742 .45949 Mtetra
.29742 .45949 .30171 .46357 .30837 .4613 .3041 .45721 Mtetra
.648 .763 .933 r
.3041 .45721 .30837 .4613 .31505 .45905 .31079 .45495 Mtetra
.648 .764 .933 r
.31079 .45495 .31505 .45905 .32175 .45679 .3175 .45268 Mtetra
.649 .764 .933 r
.3175 .45268 .32175 .45679 .32846 .45452 .32422 .4504 Mtetra
.647 .763 .933 r
.32422 .4504 .32846 .45452 .33519 .45226 .33096 .44813 Mtetra
.648 .763 .933 r
.33096 .44813 .33519 .45226 .34194 .44999 .33772 .44585 Mtetra
.33772 .44585 .34194 .44999 .3487 .44771 .34449 .44356 Mtetra
.647 .763 .934 r
.34449 .44356 .3487 .44771 .35548 .44545 .35128 .44128 Mtetra
.35128 .44128 .35548 .44545 .36228 .44317 .35809 .439 Mtetra
.648 .763 .933 r
.35809 .439 .36228 .44317 .3691 .44088 .36492 .4367 Mtetra
.647 .763 .934 r
.36492 .4367 .3691 .44088 .37593 .43861 .37176 .43441 Mtetra
.646 .763 .934 r
.37176 .43441 .37593 .43861 .38278 .43633 .37862 .43212 Mtetra
.647 .763 .934 r
.37862 .43212 .38278 .43633 .38964 .43403 .3855 .42981 Mtetra
.646 .763 .934 r
.3855 .42981 .38964 .43403 .39653 .43174 .39239 .42751 Mtetra
.645 .763 .934 r
.39239 .42751 .39653 .43174 .40343 .42946 .3993 .42522 Mtetra
.646 .763 .934 r
.3993 .42522 .40343 .42946 .41035 .42715 .40623 .4229 Mtetra
.40623 .4229 .41035 .42715 .41729 .42485 .41318 .42059 Mtetra
.645 .762 .934 r
.41318 .42059 .41729 .42485 .42424 .42256 .42015 .41829 Mtetra
.645 .763 .934 r
.42015 .41829 .42424 .42256 .43121 .42025 .42713 .41597 Mtetra
.42713 .41597 .43121 .42025 .4382 .41794 .43413 .41364 Mtetra
.644 .762 .935 r
.43413 .41364 .4382 .41794 .44521 .41564 .44115 .41133 Mtetra
.645 .762 .934 r
.44115 .41133 .44521 .41564 .45224 .41332 .44819 .40901 Mtetra
.44819 .40901 .45224 .41332 .45929 .411 .45525 .40667 Mtetra
.643 .762 .935 r
.45525 .40667 .45929 .411 .46635 .40869 .46233 .40435 Mtetra
.644 .762 .935 r
.46233 .40435 .46635 .40869 .47343 .40637 .46942 .40202 Mtetra
.644 .762 .934 r
.46942 .40202 .47343 .40637 .48053 .40403 .47653 .39967 Mtetra
.643 .762 .935 r
.47653 .39967 .48053 .40403 .48765 .40171 .48366 .39734 Mtetra
.48366 .39734 .48765 .40171 .49479 .39939 .49081 .39501 Mtetra
.49081 .39501 .49479 .39939 .50195 .39706 .49798 .39266 Mtetra
.49798 .39266 .50195 .39706 .50912 .39472 .50517 .39031 Mtetra
.50517 .39031 .50912 .39472 .51632 .39238 .51238 .38796 Mtetra
.642 .762 .935 r
.51238 .38796 .51632 .39238 .52353 .39004 .51961 .38561 Mtetra
.642 .761 .935 r
.51961 .38561 .52353 .39004 .53077 .3877 .52685 .38325 Mtetra
.52685 .38325 .53077 .3877 .53802 .38535 .53412 .38089 Mtetra
.53412 .38089 .53802 .38535 .54529 .383 .5414 .37853 Mtetra
.641 .761 .935 r
.5414 .37853 .54529 .383 .55258 .38065 .54871 .37617 Mtetra
.54871 .37617 .55258 .38065 .55989 .37829 .55603 .3738 Mtetra
.641 .761 .936 r
.55603 .3738 .55989 .37829 .56722 .37593 .56337 .37143 Mtetra
.56337 .37143 .56722 .37593 .57458 .37357 .57074 .36905 Mtetra
.57074 .36905 .57458 .37357 .58195 .3712 .57812 .36668 Mtetra
.64 .761 .936 r
.57812 .36668 .58195 .3712 .58934 .36883 .58553 .3643 Mtetra
.58553 .3643 .58934 .36883 .59675 .36646 .59295 .36191 Mtetra
.59295 .36191 .59675 .36646 .60418 .36409 .60039 .35953 Mtetra
.60039 .35953 .60418 .36409 .61163 .36171 .60786 .35714 Mtetra
.639 .76 .936 r
.60786 .35714 .61163 .36171 .6191 .35933 .61534 .35475 Mtetra
.61534 .35475 .6191 .35933 .6266 .35695 .62285 .35235 Mtetra
.62285 .35235 .6266 .35695 .63411 .35456 .63038 .34995 Mtetra
.63038 .34995 .63411 .35456 .64165 .35217 .63793 .34755 Mtetra
.63793 .34755 .64165 .35217 .6492 .34978 .6455 .34514 Mtetra
.6455 .34514 .6492 .34978 .65678 .34737 .65308 .34272 Mtetra
.64 .761 .936 r
.65308 .34272 .65678 .34737 .66437 .34493 .66069 .34027 Mtetra
.645 .763 .935 r
.66069 .34027 .66437 .34493 .67199 .34242 .66832 .33775 Mtetra
.648 .764 .934 r
.66832 .33775 .67199 .34242 .67962 .33985 .67597 .33517 Mtetra
.671 .773 .927 r
.67597 .33517 .67962 .33985 .68725 .33688 .68362 .33219 Mtetra
.696 .782 .918 r
.68362 .33219 .68725 .33688 .69488 .33345 .69126 .32874 Mtetra
.731 .794 .903 r
.69126 .32874 .69488 .33345 .70248 .32929 .69887 .32457 Mtetra
.811 .815 .854 r
.69887 .32457 .70248 .32929 .70997 .323 .70638 .31826 Mtetra
.854 .821 .816 r
.70638 .31826 .70997 .323 .71736 .31505 .71379 .3103 Mtetra
.917 .819 .735 r
.71379 .3103 .71736 .31505 .72449 .30311 .72095 .29834 Mtetra
.954 .805 .656 r
.72095 .29834 .72449 .30311 .73126 .28617 .72775 .28137 Mtetra
.967 .794 .616 r
.72775 .28137 .73126 .28617 .73776 .26596 .73428 .26113 Mtetra
.982 .769 .54 r
.73428 .26113 .73776 .26596 .74355 .23683 .74011 .23197 Mtetra
.985 .76 .516 r
.74011 .23197 .74355 .23683 .74895 .20403 .74555 .19912 Mtetra
.942 .627 .41 r
.08137 .40149 .08578 .40537 .08734 .43546 .08288 .4316 Mtetra
.942 .619 .394 r
.08288 .4316 .08734 .43546 .08936 .46306 .08486 .45922 Mtetra
.935 .58 .322 r
.08486 .45922 .08936 .46306 .09257 .48242 .08804 .47859 Mtetra
.925 .547 .265 r
.08804 .47859 .09257 .48242 .09631 .49839 .09176 .49456 Mtetra
.875 .435 .087 r
.09176 .49456 .09631 .49839 .10082 .50893 .09626 .50511 Mtetra
.62 .095 0 r
.09626 .50511 .10082 .50893 .106 .51458 .10143 .51076 Mtetra
0 .228 .694 r
.10143 .51076 .106 .51458 .11148 .51813 .10691 .5143 Mtetra
.342 .642 .965 r
.10691 .5143 .11148 .51813 .11736 .51871 .11279 .51488 Mtetra
.498 .713 .967 r
.11279 .51488 .11736 .51871 .12339 .5182 .11883 .51436 Mtetra
.574 .741 .955 r
.11883 .51436 .12339 .5182 .12953 .51699 .12498 .51314 Mtetra
.632 .759 .939 r
.12498 .51314 .12953 .51699 .13576 .51509 .13122 .51123 Mtetra
.64 .761 .936 r
.13122 .51123 .13576 .51509 .14202 .51309 .13749 .50922 Mtetra
.648 .763 .933 r
.13749 .50922 .14202 .51309 .14831 .51096 .14379 .50708 Mtetra
.652 .764 .931 r
.14379 .50708 .14831 .51096 .15463 .50877 .15011 .50488 Mtetra
.653 .764 .931 r
.15011 .50488 .15463 .50877 .16095 .50656 .15645 .50266 Mtetra
.15645 .50266 .16095 .50656 .1673 .50435 .1628 .50044 Mtetra
.654 .764 .931 r
.1628 .50044 .1673 .50435 .17366 .50212 .16917 .4982 Mtetra
.16917 .4982 .17366 .50212 .18003 .49989 .17555 .49596 Mtetra
.652 .764 .931 r
.17555 .49596 .18003 .49989 .18642 .49767 .18195 .49373 Mtetra
.653 .764 .931 r
.18195 .49373 .18642 .49767 .19283 .49544 .18837 .49149 Mtetra
.18837 .49149 .19283 .49544 .19925 .4932 .1948 .48924 Mtetra
.652 .764 .932 r
.1948 .48924 .19925 .4932 .20568 .49097 .20124 .48701 Mtetra
.652 .764 .931 r
.20124 .48701 .20568 .49097 .21213 .48874 .2077 .48476 Mtetra
.2077 .48476 .21213 .48874 .2186 .4865 .21418 .48251 Mtetra
.651 .764 .932 r
.21418 .48251 .2186 .4865 .22508 .48426 .22067 .48026 Mtetra
.22067 .48026 .22508 .48426 .23158 .48203 .22717 .47802 Mtetra
.652 .764 .932 r
.22717 .47802 .23158 .48203 .23809 .47977 .2337 .47576 Mtetra
.651 .764 .932 r
.2337 .47576 .23809 .47977 .24462 .47753 .24024 .4735 Mtetra
.65 .764 .932 r
.24024 .4735 .24462 .47753 .25116 .47529 .24679 .47125 Mtetra
.651 .764 .932 r
.24679 .47125 .25116 .47529 .25773 .47303 .25336 .46898 Mtetra
.65 .764 .932 r
.25336 .46898 .25773 .47303 .2643 .47078 .25995 .46672 Mtetra
.649 .763 .932 r
.25995 .46672 .2643 .47078 .27089 .46853 .26655 .46446 Mtetra
.65 .764 .932 r
.26655 .46446 .27089 .46853 .2775 .46627 .27317 .46219 Mtetra
.65 .763 .932 r
.27317 .46219 .2775 .46627 .28413 .46401 .2798 .45992 Mtetra
.649 .763 .933 r
.2798 .45992 .28413 .46401 .29077 .46175 .28645 .45765 Mtetra
.649 .763 .932 r
.28645 .45765 .29077 .46175 .29742 .45949 .29312 .45538 Mtetra
.29312 .45538 .29742 .45949 .3041 .45721 .2998 .45309 Mtetra
.648 .763 .933 r
.2998 .45309 .3041 .45721 .31079 .45495 .3065 .45082 Mtetra
.649 .763 .933 r
.3065 .45082 .31079 .45495 .3175 .45268 .31322 .44854 Mtetra
.31322 .44854 .3175 .45268 .32422 .4504 .31996 .44624 Mtetra
.647 .763 .933 r
.31996 .44624 .32422 .4504 .33096 .44813 .32671 .44397 Mtetra
.648 .763 .933 r
.32671 .44397 .33096 .44813 .33772 .44585 .33347 .44168 Mtetra
.33347 .44168 .33772 .44585 .34449 .44356 .34026 .43937 Mtetra
.647 .763 .933 r
.34026 .43937 .34449 .44356 .35128 .44128 .34706 .43709 Mtetra
.34706 .43709 .35128 .44128 .35809 .439 .35388 .43479 Mtetra
.648 .763 .933 r
.35388 .43479 .35809 .439 .36492 .4367 .36072 .43248 Mtetra
.647 .762 .933 r
.36072 .43248 .36492 .4367 .37176 .43441 .36757 .43018 Mtetra
.646 .762 .934 r
.36757 .43018 .37176 .43441 .37862 .43212 .37444 .42788 Mtetra
.647 .763 .933 r
.37444 .42788 .37862 .43212 .3855 .42981 .38133 .42556 Mtetra
.646 .762 .933 r
.38133 .42556 .3855 .42981 .39239 .42751 .38823 .42325 Mtetra
.645 .762 .934 r
.38823 .42325 .39239 .42751 .3993 .42522 .39516 .42095 Mtetra
.646 .762 .933 r
.39516 .42095 .3993 .42522 .40623 .4229 .4021 .41862 Mtetra
.646 .762 .934 r
.4021 .41862 .40623 .4229 .41318 .42059 .40906 .4163 Mtetra
.645 .762 .934 r
.40906 .4163 .41318 .42059 .42015 .41829 .41604 .41398 Mtetra
.41604 .41398 .42015 .41829 .42713 .41597 .42303 .41165 Mtetra
.42303 .41165 .42713 .41597 .43413 .41364 .43005 .40931 Mtetra
.644 .762 .934 r
.43005 .40931 .43413 .41364 .44115 .41133 .43708 .40699 Mtetra
.645 .762 .934 r
.43708 .40699 .44115 .41133 .44819 .40901 .44413 .40466 Mtetra
.44413 .40466 .44819 .40901 .45525 .40667 .4512 .40231 Mtetra
.643 .761 .934 r
.4512 .40231 .45525 .40667 .46233 .40435 .45828 .39998 Mtetra
.644 .761 .934 r
.45828 .39998 .46233 .40435 .46942 .40202 .46539 .39763 Mtetra
.644 .762 .934 r
.46539 .39763 .46942 .40202 .47653 .39967 .47251 .39528 Mtetra
.643 .761 .935 r
.47251 .39528 .47653 .39967 .48366 .39734 .47966 .39293 Mtetra
.47966 .39293 .48366 .39734 .49081 .39501 .48682 .39059 Mtetra
.643 .761 .934 r
.48682 .39059 .49081 .39501 .49798 .39266 .494 .38823 Mtetra
.643 .761 .935 r
.494 .38823 .49798 .39266 .50517 .39031 .5012 .38587 Mtetra
.5012 .38587 .50517 .39031 .51238 .38796 .50842 .38351 Mtetra
.642 .761 .935 r
.50842 .38351 .51238 .38796 .51961 .38561 .51566 .38115 Mtetra
.51566 .38115 .51961 .38561 .52685 .38325 .52292 .37878 Mtetra
.52292 .37878 .52685 .38325 .53412 .38089 .5302 .37641 Mtetra
.5302 .37641 .53412 .38089 .5414 .37853 .53749 .37403 Mtetra
.53749 .37403 .5414 .37853 .54871 .37617 .54481 .37166 Mtetra
.641 .761 .935 r
.54481 .37166 .54871 .37617 .55603 .3738 .55215 .36927 Mtetra
.641 .76 .935 r
.55215 .36927 .55603 .3738 .56337 .37143 .5595 .36689 Mtetra
.5595 .36689 .56337 .37143 .57074 .36905 .56688 .36451 Mtetra
.56688 .36451 .57074 .36905 .57812 .36668 .57428 .36212 Mtetra
.64 .76 .935 r
.57428 .36212 .57812 .36668 .58553 .3643 .58169 .35972 Mtetra
.58169 .35972 .58553 .3643 .59295 .36191 .58913 .35733 Mtetra
.58913 .35733 .59295 .36191 .60039 .35953 .59659 .35493 Mtetra
.59659 .35493 .60039 .35953 .60786 .35714 .60407 .35253 Mtetra
.639 .76 .936 r
.60407 .35253 .60786 .35714 .61534 .35475 .61157 .35013 Mtetra
.61157 .35013 .61534 .35475 .62285 .35235 .61909 .34772 Mtetra
.61909 .34772 .62285 .35235 .63038 .34995 .62663 .34531 Mtetra
.62663 .34531 .63038 .34995 .63793 .34755 .63419 .3429 Mtetra
.63419 .3429 .63793 .34755 .6455 .34514 .64177 .34047 Mtetra
.64177 .34047 .6455 .34514 .65308 .34272 .64937 .33804 Mtetra
.64 .76 .935 r
.64937 .33804 .65308 .34272 .66069 .34027 .657 .33558 Mtetra
.645 .762 .934 r
.657 .33558 .66069 .34027 .66832 .33775 .66464 .33305 Mtetra
.648 .763 .933 r
.66464 .33305 .66832 .33775 .67597 .33517 .6723 .33045 Mtetra
.671 .772 .926 r
.6723 .33045 .67597 .33517 .68362 .33219 .67996 .32745 Mtetra
.696 .782 .917 r
.67996 .32745 .68362 .33219 .69126 .32874 .68762 .32399 Mtetra
.731 .794 .902 r
.68762 .32399 .69126 .32874 .69887 .32457 .69525 .31981 Mtetra
.811 .815 .853 r
.69525 .31981 .69887 .32457 .70638 .31826 .70278 .31348 Mtetra
.854 .821 .816 r
.70278 .31348 .70638 .31826 .71379 .3103 .71021 .3055 Mtetra
.917 .819 .734 r
.71021 .3055 .71379 .3103 .72095 .29834 .71739 .29352 Mtetra
.954 .804 .656 r
.71739 .29352 .72095 .29834 .72775 .28137 .72422 .27653 Mtetra
.967 .794 .616 r
.72422 .27653 .72775 .28137 .73428 .26113 .73078 .25627 Mtetra
.982 .769 .54 r
.73078 .25627 .73428 .26113 .74011 .23197 .73665 .22707 Mtetra
.985 .76 .516 r
.73665 .22707 .74011 .23197 .74555 .19912 .74214 .19419 Mtetra
.943 .627 .409 r
.07694 .39755 .08137 .40149 .08288 .4316 .07841 .42767 Mtetra
.942 .619 .394 r
.07841 .42767 .08288 .4316 .08486 .45922 .08035 .45529 Mtetra
.935 .58 .321 r
.08035 .45529 .08486 .45922 .08804 .47859 .08351 .47468 Mtetra
.926 .547 .263 r
.08351 .47468 .08804 .47859 .09176 .49456 .0872 .49065 Mtetra
.874 .434 .083 r
.0872 .49065 .09176 .49456 .09626 .50511 .09168 .5012 Mtetra
.613 .091 0 r
.09168 .5012 .09626 .50511 .10143 .51076 .09685 .50684 Mtetra
0 .233 .702 r
.09685 .50684 .10143 .51076 .10691 .5143 .10233 .51038 Mtetra
.348 .64 .963 r
.10233 .51038 .10691 .5143 .11279 .51488 .10822 .51095 Mtetra
.501 .71 .964 r
.10822 .51095 .11279 .51488 .11883 .51436 .11426 .51042 Mtetra
.575 .737 .952 r
.11426 .51042 .11883 .51436 .12498 .51314 .12041 .50919 Mtetra
.633 .755 .936 r
.12041 .50919 .12498 .51314 .13122 .51123 .12666 .50728 Mtetra
.64 .757 .933 r
.12666 .50728 .13122 .51123 .13749 .50922 .13294 .50526 Mtetra
.648 .759 .93 r
.13294 .50526 .13749 .50922 .14379 .50708 .13925 .50311 Mtetra
.653 .76 .928 r
.13925 .50311 .14379 .50708 .15011 .50488 .14558 .5009 Mtetra
.14558 .5009 .15011 .50488 .15645 .50266 .15193 .49867 Mtetra
.15193 .49867 .15645 .50266 .1628 .50044 .15829 .49644 Mtetra
.654 .761 .928 r
.15829 .49644 .1628 .50044 .16917 .4982 .16467 .49419 Mtetra
.16467 .49419 .16917 .4982 .17555 .49596 .17106 .49194 Mtetra
.652 .76 .929 r
.17106 .49194 .17555 .49596 .18195 .49373 .17747 .4897 Mtetra
.653 .76 .928 r
.17747 .4897 .18195 .49373 .18837 .49149 .18389 .48745 Mtetra
.653 .761 .928 r
.18389 .48745 .18837 .49149 .1948 .48924 .19033 .48519 Mtetra
.652 .76 .929 r
.19033 .48519 .1948 .48924 .20124 .48701 .19679 .48295 Mtetra
.19679 .48295 .20124 .48701 .2077 .48476 .20325 .4807 Mtetra
.20325 .4807 .2077 .48476 .21418 .48251 .20974 .47843 Mtetra
.651 .76 .929 r
.20974 .47843 .21418 .48251 .22067 .48026 .21624 .47618 Mtetra
.21624 .47618 .22067 .48026 .22717 .47802 .22276 .47392 Mtetra
.652 .76 .929 r
.22276 .47392 .22717 .47802 .2337 .47576 .22929 .47165 Mtetra
.651 .76 .929 r
.22929 .47165 .2337 .47576 .24024 .4735 .23584 .46939 Mtetra
.65 .76 .93 r
.23584 .46939 .24024 .4735 .24679 .47125 .2424 .46713 Mtetra
.651 .76 .929 r
.2424 .46713 .24679 .47125 .25336 .46898 .24898 .46485 Mtetra
.65 .76 .93 r
.24898 .46485 .25336 .46898 .25995 .46672 .25558 .46257 Mtetra
.25558 .46257 .25995 .46672 .26655 .46446 .26219 .46031 Mtetra
.26219 .46031 .26655 .46446 .27317 .46219 .26882 .45802 Mtetra
.26882 .45802 .27317 .46219 .2798 .45992 .27546 .45574 Mtetra
.649 .76 .93 r
.27546 .45574 .2798 .45992 .28645 .45765 .28212 .45347 Mtetra
.28212 .45347 .28645 .45765 .29312 .45538 .2888 .45118 Mtetra
.2888 .45118 .29312 .45538 .2998 .45309 .29549 .44888 Mtetra
.648 .759 .93 r
.29549 .44888 .2998 .45309 .3065 .45082 .3022 .4466 Mtetra
.649 .76 .93 r
.3022 .4466 .3065 .45082 .31322 .44854 .30893 .44431 Mtetra
.30893 .44431 .31322 .44854 .31996 .44624 .31568 .442 Mtetra
.648 .759 .931 r
.31568 .442 .31996 .44624 .32671 .44397 .32244 .43972 Mtetra
.32244 .43972 .32671 .44397 .33347 .44168 .32921 .43742 Mtetra
.648 .76 .93 r
.32921 .43742 .33347 .44168 .34026 .43937 .33601 .4351 Mtetra
.647 .759 .931 r
.33601 .4351 .34026 .43937 .34706 .43709 .34282 .4328 Mtetra
.34282 .4328 .34706 .43709 .35388 .43479 .34965 .4305 Mtetra
.648 .759 .931 r
.34965 .4305 .35388 .43479 .36072 .43248 .3565 .42818 Mtetra
.647 .759 .931 r
.3565 .42818 .36072 .43248 .36757 .43018 .36336 .42587 Mtetra
.646 .759 .931 r
.36336 .42587 .36757 .43018 .37444 .42788 .37024 .42356 Mtetra
.647 .759 .931 r
.37024 .42356 .37444 .42788 .38133 .42556 .37714 .42123 Mtetra
.646 .759 .931 r
.37714 .42123 .38133 .42556 .38823 .42325 .38406 .4189 Mtetra
.38406 .4189 .38823 .42325 .39516 .42095 .391 .41659 Mtetra
.391 .41659 .39516 .42095 .4021 .41862 .39795 .41425 Mtetra
.39795 .41425 .4021 .41862 .40906 .4163 .40492 .41192 Mtetra
.645 .758 .932 r
.40492 .41192 .40906 .4163 .41604 .41398 .41191 .40959 Mtetra
.646 .759 .931 r
.41191 .40959 .41604 .41398 .42303 .41165 .41891 .40725 Mtetra
.41891 .40725 .42303 .41165 .43005 .40931 .42594 .4049 Mtetra
.644 .758 .932 r
.42594 .4049 .43005 .40931 .43708 .40699 .43298 .40257 Mtetra
.645 .758 .932 r
.43298 .40257 .43708 .40699 .44413 .40466 .44004 .40022 Mtetra
.645 .758 .931 r
.44004 .40022 .44413 .40466 .4512 .40231 .44712 .39786 Mtetra
.644 .758 .932 r
.44712 .39786 .4512 .40231 .45828 .39998 .45422 .39552 Mtetra
.45422 .39552 .45828 .39998 .46539 .39763 .46134 .39316 Mtetra
.645 .758 .932 r
.46134 .39316 .46539 .39763 .47251 .39528 .46848 .39079 Mtetra
.643 .758 .932 r
.46848 .39079 .47251 .39528 .47966 .39293 .47563 .38844 Mtetra
.47563 .38844 .47966 .39293 .48682 .39059 .48281 .38608 Mtetra
.48281 .38608 .48682 .39059 .494 .38823 .49 .38371 Mtetra
.49 .38371 .494 .38823 .5012 .38587 .49721 .38134 Mtetra
.49721 .38134 .5012 .38587 .50842 .38351 .50444 .37897 Mtetra
.643 .757 .932 r
.50444 .37897 .50842 .38351 .51566 .38115 .51169 .37659 Mtetra
.642 .757 .932 r
.51169 .37659 .51566 .38115 .52292 .37878 .51897 .37421 Mtetra
.51897 .37421 .52292 .37878 .5302 .37641 .52626 .37183 Mtetra
.52626 .37183 .5302 .37641 .53749 .37403 .53356 .36944 Mtetra
.53356 .36944 .53749 .37403 .54481 .37166 .54089 .36705 Mtetra
.54089 .36705 .54481 .37166 .55215 .36927 .54824 .36466 Mtetra
.641 .757 .932 r
.54824 .36466 .55215 .36927 .5595 .36689 .55561 .36226 Mtetra
.641 .757 .933 r
.55561 .36226 .5595 .36689 .56688 .36451 .563 .35986 Mtetra
.563 .35986 .56688 .36451 .57428 .36212 .57041 .35746 Mtetra
.57041 .35746 .57428 .36212 .58169 .35972 .57784 .35506 Mtetra
.64 .756 .933 r
.57784 .35506 .58169 .35972 .58913 .35733 .58529 .35265 Mtetra
.58529 .35265 .58913 .35733 .59659 .35493 .59276 .35024 Mtetra
.59276 .35024 .59659 .35493 .60407 .35253 .60025 .34782 Mtetra
.60025 .34782 .60407 .35253 .61157 .35013 .60777 .34541 Mtetra
.60777 .34541 .61157 .35013 .61909 .34772 .6153 .34299 Mtetra
.639 .756 .933 r
.6153 .34299 .61909 .34772 .62663 .34531 .62285 .34056 Mtetra
.62285 .34056 .62663 .34531 .63419 .3429 .63043 .33814 Mtetra
.63043 .33814 .63419 .3429 .64177 .34047 .63803 .3357 Mtetra
.64 .756 .933 r
.63803 .3357 .64177 .34047 .64937 .33804 .64564 .33325 Mtetra
.641 .756 .932 r
.64564 .33325 .64937 .33804 .657 .33558 .65328 .33078 Mtetra
.645 .758 .931 r
.65328 .33078 .657 .33558 .66464 .33305 .66094 .32823 Mtetra
.648 .759 .93 r
.66094 .32823 .66464 .33305 .6723 .33045 .66861 .32562 Mtetra
.671 .768 .923 r
.66861 .32562 .6723 .33045 .67996 .32745 .67629 .32261 Mtetra
.696 .777 .914 r
.67629 .32261 .67996 .32745 .68762 .32399 .68396 .31914 Mtetra
.73 .789 .9 r
.68396 .31914 .68762 .32399 .69525 .31981 .69161 .31494 Mtetra
.809 .811 .852 r
.69161 .31494 .69525 .31981 .70278 .31348 .69915 .3086 Mtetra
.852 .817 .814 r
.69915 .3086 .70278 .31348 .71021 .3055 .7066 .3006 Mtetra
.915 .816 .734 r
.7066 .3006 .71021 .3055 .71739 .29352 .71381 .2886 Mtetra
.953 .803 .657 r
.71381 .2886 .71739 .29352 .72422 .27653 .72066 .27159 Mtetra
.966 .792 .617 r
.72066 .27159 .72422 .27653 .73078 .25627 .72726 .2513 Mtetra
.982 .768 .541 r
.72726 .2513 .73078 .25627 .73665 .22707 .73317 .22208 Mtetra
.985 .759 .516 r
.73317 .22208 .73665 .22707 .74214 .19419 .7387 .18917 Mtetra
.943 .628 .409 r
.07251 .39349 .07694 .39755 .07841 .42767 .07394 .42361 Mtetra
.943 .62 .392 r
.07394 .42361 .07841 .42767 .08035 .45529 .07583 .45123 Mtetra
.936 .581 .319 r
.07583 .45123 .08035 .45529 .08351 .47468 .07896 .47061 Mtetra
.926 .548 .259 r
.07896 .47061 .08351 .47468 .0872 .49065 .08264 .48658 Mtetra
.874 .433 .075 r
.08264 .48658 .0872 .49065 .09168 .5012 .08711 .49712 Mtetra
.601 .082 0 r
.08711 .49712 .09168 .5012 .09685 .50684 .09228 .50276 Mtetra
0 .242 .716 r
.09228 .50276 .09685 .50684 .10233 .51038 .09775 .50629 Mtetra
.357 .636 .96 r
.09775 .50629 .10233 .51038 .10822 .51095 .10364 .50685 Mtetra
.506 .703 .959 r
.10364 .50685 .10822 .51095 .11426 .51042 .10969 .50632 Mtetra
.577 .73 .947 r
.10969 .50632 .11426 .51042 .12041 .50919 .11585 .50509 Mtetra
.633 .747 .93 r
.11585 .50509 .12041 .50919 .12666 .50728 .12211 .50316 Mtetra
.64 .749 .928 r
.12211 .50316 .12666 .50728 .13294 .50526 .12839 .50113 Mtetra
.648 .752 .925 r
.12839 .50113 .13294 .50526 .13925 .50311 .13471 .49898 Mtetra
.653 .753 .923 r
.13471 .49898 .13925 .50311 .14558 .5009 .14105 .49676 Mtetra
.14105 .49676 .14558 .5009 .15193 .49867 .1474 .49452 Mtetra
.1474 .49452 .15193 .49867 .15829 .49644 .15378 .49228 Mtetra
.654 .753 .923 r
.15378 .49228 .15829 .49644 .16467 .49419 .16016 .49003 Mtetra
.654 .754 .923 r
.16016 .49003 .16467 .49419 .17106 .49194 .16656 .48777 Mtetra
.652 .753 .924 r
.16656 .48777 .17106 .49194 .17747 .4897 .17298 .48552 Mtetra
.653 .753 .924 r
.17298 .48552 .17747 .4897 .18389 .48745 .17941 .48326 Mtetra
.653 .754 .923 r
.17941 .48326 .18389 .48745 .19033 .48519 .18586 .48099 Mtetra
.652 .753 .924 r
.18586 .48099 .19033 .48519 .19679 .48295 .19232 .47874 Mtetra
.19232 .47874 .19679 .48295 .20325 .4807 .1988 .47648 Mtetra
.652 .754 .924 r
.1988 .47648 .20325 .4807 .20974 .47843 .2053 .47421 Mtetra
.651 .753 .924 r
.2053 .47421 .20974 .47843 .21624 .47618 .21181 .47194 Mtetra
.21181 .47194 .21624 .47618 .22276 .47392 .21833 .46968 Mtetra
.652 .754 .924 r
.21833 .46968 .22276 .47392 .22929 .47165 .22487 .4674 Mtetra
.651 .753 .925 r
.22487 .4674 .22929 .47165 .23584 .46939 .23143 .46512 Mtetra
.65 .753 .925 r
.23143 .46512 .23584 .46939 .2424 .46713 .238 .46285 Mtetra
.651 .754 .925 r
.238 .46285 .2424 .46713 .24898 .46485 .24459 .46057 Mtetra
.65 .753 .925 r
.24459 .46057 .24898 .46485 .25558 .46257 .2512 .45828 Mtetra
.2512 .45828 .25558 .46257 .26219 .46031 .25782 .45601 Mtetra
.65 .754 .925 r
.25782 .45601 .26219 .46031 .26882 .45802 .26446 .45371 Mtetra
.65 .753 .925 r
.26446 .45371 .26882 .45802 .27546 .45574 .27111 .45142 Mtetra
.649 .753 .926 r
.27111 .45142 .27546 .45574 .28212 .45347 .27778 .44914 Mtetra
.65 .753 .925 r
.27778 .44914 .28212 .45347 .2888 .45118 .28447 .44684 Mtetra
.28447 .44684 .2888 .45118 .29549 .44888 .29117 .44453 Mtetra
.648 .753 .926 r
.29117 .44453 .29549 .44888 .3022 .4466 .29789 .44224 Mtetra
.649 .753 .926 r
.29789 .44224 .3022 .4466 .30893 .44431 .30463 .43994 Mtetra
.30463 .43994 .30893 .44431 .31568 .442 .31138 .43762 Mtetra
.648 .753 .926 r
.31138 .43762 .31568 .442 .32244 .43972 .31815 .43532 Mtetra
.31815 .43532 .32244 .43972 .32921 .43742 .32494 .43301 Mtetra
.649 .753 .926 r
.32494 .43301 .32921 .43742 .33601 .4351 .33175 .43069 Mtetra
.647 .753 .926 r
.33175 .43069 .33601 .4351 .34282 .4328 .33857 .42838 Mtetra
.33857 .42838 .34282 .4328 .34965 .4305 .34541 .42606 Mtetra
.648 .753 .926 r
.34541 .42606 .34965 .4305 .3565 .42818 .35227 .42373 Mtetra
.647 .753 .926 r
.35227 .42373 .3565 .42818 .36336 .42587 .35914 .42141 Mtetra
.646 .753 .927 r
.35914 .42141 .36336 .42587 .37024 .42356 .36604 .41909 Mtetra
.647 .753 .926 r
.36604 .41909 .37024 .42356 .37714 .42123 .37295 .41675 Mtetra
.647 .753 .927 r
.37295 .41675 .37714 .42123 .38406 .4189 .37987 .41441 Mtetra
.646 .752 .927 r
.37987 .41441 .38406 .4189 .391 .41659 .38682 .41209 Mtetra
.647 .753 .927 r
.38682 .41209 .391 .41659 .39795 .41425 .39378 .40974 Mtetra
.646 .753 .927 r
.39378 .40974 .39795 .41425 .40492 .41192 .40076 .40739 Mtetra
.645 .752 .927 r
.40076 .40739 .40492 .41192 .41191 .40959 .40776 .40505 Mtetra
.646 .752 .927 r
.40776 .40505 .41191 .40959 .41891 .40725 .41478 .4027 Mtetra
.41478 .4027 .41891 .40725 .42594 .4049 .42182 .40034 Mtetra
.644 .752 .927 r
.42182 .40034 .42594 .4049 .43298 .40257 .42887 .398 Mtetra
.645 .752 .927 r
.42887 .398 .43298 .40257 .44004 .40022 .43594 .39564 Mtetra
.43594 .39564 .44004 .40022 .44712 .39786 .44304 .39326 Mtetra
.644 .752 .927 r
.44304 .39326 .44712 .39786 .45422 .39552 .45015 .39091 Mtetra
.45015 .39091 .45422 .39552 .46134 .39316 .45728 .38854 Mtetra
.645 .752 .927 r
.45728 .38854 .46134 .39316 .46848 .39079 .46442 .38616 Mtetra
.643 .751 .927 r
.46442 .38616 .46848 .39079 .47563 .38844 .47159 .38379 Mtetra
.643 .751 .928 r
.47159 .38379 .47563 .38844 .48281 .38608 .47878 .38142 Mtetra
.644 .751 .927 r
.47878 .38142 .48281 .38608 .49 .38371 .48598 .37904 Mtetra
.643 .751 .927 r
.48598 .37904 .49 .38371 .49721 .38134 .4932 .37666 Mtetra
.4932 .37666 .49721 .38134 .50444 .37897 .50045 .37427 Mtetra
.643 .751 .928 r
.50045 .37427 .50444 .37897 .51169 .37659 .50771 .37188 Mtetra
.50771 .37188 .51169 .37659 .51897 .37421 .51499 .36949 Mtetra
.51499 .36949 .51897 .37421 .52626 .37183 .5223 .36709 Mtetra
.642 .751 .928 r
.5223 .36709 .52626 .37183 .53356 .36944 .52962 .36469 Mtetra
.52962 .36469 .53356 .36944 .54089 .36705 .53696 .36229 Mtetra
.642 .75 .928 r
.53696 .36229 .54089 .36705 .54824 .36466 .54432 .35989 Mtetra
.54432 .35989 .54824 .36466 .55561 .36226 .5517 .35748 Mtetra
.5517 .35748 .55561 .36226 .563 .35986 .5591 .35506 Mtetra
.641 .75 .928 r
.5591 .35506 .563 .35986 .57041 .35746 .56653 .35265 Mtetra
.56653 .35265 .57041 .35746 .57784 .35506 .57397 .35023 Mtetra
.57397 .35023 .57784 .35506 .58529 .35265 .58143 .34781 Mtetra
.58143 .34781 .58529 .35265 .59276 .35024 .58892 .34538 Mtetra
.64 .749 .928 r
.58892 .34538 .59276 .35024 .60025 .34782 .59642 .34296 Mtetra
.59642 .34296 .60025 .34782 .60777 .34541 .60395 .34052 Mtetra
.60395 .34052 .60777 .34541 .6153 .34299 .61149 .33809 Mtetra
.61149 .33809 .6153 .34299 .62285 .34056 .61906 .33565 Mtetra
.61906 .33565 .62285 .34056 .63043 .33814 .62665 .33321 Mtetra
.62665 .33321 .63043 .33814 .63803 .3357 .63426 .33076 Mtetra
.63426 .33076 .63803 .3357 .64564 .33325 .64189 .3283 Mtetra
.641 .749 .927 r
.64189 .3283 .64564 .33325 .65328 .33078 .64954 .32581 Mtetra
.645 .751 .926 r
.64954 .32581 .65328 .33078 .66094 .32823 .65721 .32325 Mtetra
.649 .752 .925 r
.65721 .32325 .66094 .32823 .66861 .32562 .66489 .32062 Mtetra
.671 .761 .918 r
.66489 .32062 .66861 .32562 .67629 .32261 .67258 .3176 Mtetra
.695 .77 .909 r
.67258 .3176 .67629 .32261 .68396 .31914 .68027 .31411 Mtetra
.729 .782 .895 r
.68027 .31411 .68396 .31914 .69161 .31494 .68794 .3099 Mtetra
.807 .803 .848 r
.68794 .3099 .69161 .31494 .69915 .3086 .6955 .30354 Mtetra
.849 .811 .812 r
.6955 .30354 .69915 .3086 .7066 .3006 .70297 .29553 Mtetra
.913 .811 .733 r
.70297 .29553 .7066 .3006 .71381 .2886 .7102 .28351 Mtetra
.951 .799 .657 r
.7102 .28351 .71381 .2886 .72066 .27159 .71708 .26648 Mtetra
.964 .79 .617 r
.71708 .26648 .72066 .27159 .72726 .2513 .72371 .24618 Mtetra
.981 .766 .542 r
.72371 .24618 .72726 .2513 .73317 .22208 .72966 .21694 Mtetra
.984 .758 .517 r
.72966 .21694 .73317 .22208 .7387 .18917 .73524 .18401 Mtetra
.944 .629 .408 r
.06807 .38934 .07251 .39349 .07394 .42361 .06946 .41945 Mtetra
.944 .621 .391 r
.06946 .41945 .07394 .42361 .07583 .45123 .07131 .44705 Mtetra
.937 .582 .316 r
.07131 .44705 .07583 .45123 .07896 .47061 .07442 .46642 Mtetra
.927 .548 .256 r
.07442 .46642 .07896 .47061 .08264 .48658 .07807 .48238 Mtetra
.873 .432 .068 r
.07807 .48238 .08264 .48658 .08711 .49712 .08253 .49291 Mtetra
.589 .075 0 r
.08253 .49291 .08711 .49712 .09228 .50276 .08769 .49854 Mtetra
0 .25 .728 r
.08769 .49854 .09228 .50276 .09775 .50629 .09317 .50206 Mtetra
.365 .632 .956 r
.09317 .50206 .09775 .50629 .10364 .50685 .09906 .50262 Mtetra
.509 .697 .954 r
.09906 .50262 .10364 .50685 .10969 .50632 .10512 .50208 Mtetra
.578 .723 .942 r
.10512 .50208 .10969 .50632 .11585 .50509 .11128 .50083 Mtetra
.633 .741 .926 r
.11128 .50083 .11585 .50509 .12211 .50316 .11755 .4989 Mtetra
.64 .743 .923 r
.11755 .4989 .12211 .50316 .12839 .50113 .12384 .49687 Mtetra
.648 .745 .92 r
.12384 .49687 .12839 .50113 .13471 .49898 .13016 .4947 Mtetra
.652 .747 .919 r
.13016 .4947 .13471 .49898 .14105 .49676 .13651 .49248 Mtetra
.653 .747 .919 r
.13651 .49248 .14105 .49676 .1474 .49452 .14287 .49023 Mtetra
.14287 .49023 .1474 .49452 .15378 .49228 .14925 .48799 Mtetra
.14925 .48799 .15378 .49228 .16016 .49003 .15565 .48573 Mtetra
.653 .748 .919 r
.15565 .48573 .16016 .49003 .16656 .48777 .16206 .48346 Mtetra
.652 .747 .919 r
.16206 .48346 .16656 .48777 .17298 .48552 .16848 .4812 Mtetra
.653 .748 .919 r
.16848 .4812 .17298 .48552 .17941 .48326 .17492 .47894 Mtetra
.17492 .47894 .17941 .48326 .18586 .48099 .18138 .47666 Mtetra
.652 .747 .92 r
.18138 .47666 .18586 .48099 .19232 .47874 .18785 .4744 Mtetra
.652 .748 .92 r
.18785 .4744 .19232 .47874 .1988 .47648 .19434 .47213 Mtetra
.19434 .47213 .1988 .47648 .2053 .47421 .20084 .46985 Mtetra
.651 .748 .92 r
.20084 .46985 .2053 .47421 .21181 .47194 .20736 .46758 Mtetra
.20736 .46758 .21181 .47194 .21833 .46968 .21389 .4653 Mtetra
.652 .748 .92 r
.21389 .4653 .21833 .46968 .22487 .4674 .22044 .46301 Mtetra
.651 .748 .921 r
.22044 .46301 .22487 .4674 .23143 .46512 .22701 .46073 Mtetra
.65 .748 .921 r
.22701 .46073 .23143 .46512 .238 .46285 .23359 .45845 Mtetra
.651 .748 .921 r
.23359 .45845 .238 .46285 .24459 .46057 .24019 .45616 Mtetra
.65 .748 .921 r
.24019 .45616 .24459 .46057 .2512 .45828 .24681 .45386 Mtetra
.24681 .45386 .2512 .45828 .25782 .45601 .25344 .45158 Mtetra
.25344 .45158 .25782 .45601 .26446 .45371 .26008 .44928 Mtetra
.26008 .44928 .26446 .45371 .27111 .45142 .26675 .44697 Mtetra
.649 .748 .922 r
.26675 .44697 .27111 .45142 .27778 .44914 .27343 .44468 Mtetra
.65 .748 .921 r
.27343 .44468 .27778 .44914 .28447 .44684 .28012 .44237 Mtetra
.65 .748 .922 r
.28012 .44237 .28447 .44684 .29117 .44453 .28684 .44006 Mtetra
.648 .748 .922 r
.28684 .44006 .29117 .44453 .29789 .44224 .29357 .43776 Mtetra
.649 .748 .922 r
.29357 .43776 .29789 .44224 .30463 .43994 .30031 .43544 Mtetra
.30031 .43544 .30463 .43994 .31138 .43762 .30708 .43312 Mtetra
.648 .748 .922 r
.30708 .43312 .31138 .43762 .31815 .43532 .31386 .43081 Mtetra
.31386 .43081 .31815 .43532 .32494 .43301 .32066 .42849 Mtetra
.649 .748 .922 r
.32066 .42849 .32494 .43301 .33175 .43069 .32747 .42615 Mtetra
.647 .748 .922 r
.32747 .42615 .33175 .43069 .33857 .42838 .33431 .42383 Mtetra
.647 .748 .923 r
.33431 .42383 .33857 .42838 .34541 .42606 .34116 .4215 Mtetra
.648 .748 .922 r
.34116 .4215 .34541 .42606 .35227 .42373 .34802 .41916 Mtetra
.647 .748 .923 r
.34802 .41916 .35227 .42373 .35914 .42141 .35491 .41683 Mtetra
.647 .747 .923 r
.35491 .41683 .35914 .42141 .36604 .41909 .36181 .4145 Mtetra
.647 .748 .923 r
.36181 .4145 .36604 .41909 .37295 .41675 .36873 .41214 Mtetra
.647 .747 .923 r
.36873 .41214 .37295 .41675 .37987 .41441 .37567 .4098 Mtetra
.646 .747 .923 r
.37567 .4098 .37987 .41441 .38682 .41209 .38263 .40746 Mtetra
.647 .747 .923 r
.38263 .40746 .38682 .41209 .39378 .40974 .3896 .4051 Mtetra
.646 .747 .923 r
.3896 .4051 .39378 .40974 .40076 .40739 .39659 .40274 Mtetra
.645 .747 .923 r
.39659 .40274 .40076 .40739 .40776 .40505 .4036 .40039 Mtetra
.646 .747 .923 r
.4036 .40039 .40776 .40505 .41478 .4027 .41063 .39803 Mtetra
.41063 .39803 .41478 .4027 .42182 .40034 .41768 .39565 Mtetra
.645 .747 .923 r
.41768 .39565 .42182 .40034 .42887 .398 .42474 .3933 Mtetra
.42474 .3933 .42887 .398 .43594 .39564 .43183 .39092 Mtetra
.646 .747 .923 r
.43183 .39092 .43594 .39564 .44304 .39326 .43893 .38854 Mtetra
.644 .746 .924 r
.43893 .38854 .44304 .39326 .45015 .39091 .44605 .38617 Mtetra
.644 .747 .923 r
.44605 .38617 .45015 .39091 .45728 .38854 .45319 .38379 Mtetra
.645 .747 .923 r
.45319 .38379 .45728 .38854 .46442 .38616 .46035 .3814 Mtetra
.644 .746 .924 r
.46035 .3814 .46442 .38616 .47159 .38379 .46753 .37902 Mtetra
.46753 .37902 .47159 .38379 .47878 .38142 .47473 .37664 Mtetra
.644 .746 .923 r
.47473 .37664 .47878 .38142 .48598 .37904 .48194 .37424 Mtetra
.644 .746 .924 r
.48194 .37424 .48598 .37904 .4932 .37666 .48918 .37185 Mtetra
.643 .746 .924 r
.48918 .37185 .4932 .37666 .50045 .37427 .49643 .36945 Mtetra
.49643 .36945 .50045 .37427 .50771 .37188 .50371 .36704 Mtetra
.50371 .36704 .50771 .37188 .51499 .36949 .511 .36464 Mtetra
.643 .745 .924 r
.511 .36464 .51499 .36949 .5223 .36709 .51832 .36223 Mtetra
.51832 .36223 .5223 .36709 .52962 .36469 .52565 .35981 Mtetra
.642 .745 .924 r
.52565 .35981 .52962 .36469 .53696 .36229 .53301 .3574 Mtetra
.53301 .3574 .53696 .36229 .54432 .35989 .54038 .35498 Mtetra
.54038 .35498 .54432 .35989 .5517 .35748 .54777 .35255 Mtetra
.54777 .35255 .5517 .35748 .5591 .35506 .55519 .35013 Mtetra
.642 .744 .924 r
.55519 .35013 .5591 .35506 .56653 .35265 .56262 .3477 Mtetra
.641 .744 .924 r
.56262 .3477 .56653 .35265 .57397 .35023 .57008 .34526 Mtetra
.641 .744 .923 r
.57008 .34526 .57397 .35023 .58143 .34781 .57755 .34283 Mtetra
.57755 .34283 .58143 .34781 .58892 .34538 .58505 .34039 Mtetra
.58505 .34039 .58892 .34538 .59642 .34296 .59256 .33794 Mtetra
.59256 .33794 .59642 .34296 .60395 .34052 .6001 .3355 Mtetra
.64 .743 .923 r
.6001 .3355 .60395 .34052 .61149 .33809 .60766 .33305 Mtetra
.60766 .33305 .61149 .33809 .61906 .33565 .61524 .33059 Mtetra
.61524 .33059 .61906 .33565 .62665 .33321 .62284 .32814 Mtetra
.62284 .32814 .62665 .33321 .63426 .33076 .63046 .32567 Mtetra
.63046 .32567 .63426 .33076 .64189 .3283 .63811 .32319 Mtetra
.642 .743 .923 r
.63811 .32319 .64189 .3283 .64954 .32581 .64577 .32069 Mtetra
.646 .745 .921 r
.64577 .32069 .64954 .32581 .65721 .32325 .65345 .31811 Mtetra
.649 .746 .92 r
.65345 .31811 .65721 .32325 .66489 .32062 .66115 .31547 Mtetra
.671 .755 .913 r
.66115 .31547 .66489 .32062 .67258 .3176 .66886 .31243 Mtetra
.694 .763 .905 r
.66886 .31243 .67258 .3176 .68027 .31411 .67656 .30892 Mtetra
.727 .775 .891 r
.67656 .30892 .68027 .31411 .68794 .3099 .68424 .30469 Mtetra
.805 .797 .845 r
.68424 .30469 .68794 .3099 .6955 .30354 .69182 .29832 Mtetra
.847 .805 .81 r
.69182 .29832 .6955 .30354 .70297 .29553 .69931 .29029 Mtetra
.91 .807 .733 r
.69931 .29029 .70297 .29553 .7102 .28351 .70656 .27826 Mtetra
.949 .796 .657 r
.70656 .27826 .7102 .28351 .71708 .26648 .71348 .26123 Mtetra
.963 .787 .618 r
.71348 .26123 .71708 .26648 .72371 .24618 .72014 .24091 Mtetra
.98 .765 .543 r
.72014 .24091 .72371 .24618 .72966 .21694 .72613 .21166 Mtetra
.983 .757 .518 r
.72613 .21166 .72966 .21694 .73524 .18401 .73175 .17874 Mtetra
.947 .632 .403 r
.06369 .38466 .06807 .38934 .06946 .41945 .06504 .41468 Mtetra
.948 .625 .385 r
.06504 .41468 .06946 .41945 .07131 .44705 .06687 .4422 Mtetra
.942 .586 .304 r
.06687 .4422 .07131 .44705 .07442 .46642 .06995 .4615 Mtetra
.931 .551 .236 r
.06995 .4615 .07442 .46642 .07807 .48238 .07359 .47741 Mtetra
.864 .425 .021 r
.07359 .47741 .07807 .48238 .08253 .49291 .07804 .4879 Mtetra
0 0 .49 r
.07804 .4879 .08253 .49291 .08769 .49854 .0832 .49351 Mtetra
0 .288 .78 r
.0832 .49351 .08769 .49854 .09317 .50206 .08867 .49701 Mtetra
.405 .607 .93 r
.08867 .49701 .09317 .50206 .09906 .50262 .09457 .49756 Mtetra
.526 .662 .922 r
.09457 .49756 .09906 .50262 .10512 .50208 .10063 .49701 Mtetra
.585 .685 .91 r
.10063 .49701 .10512 .50208 .11128 .50083 .10679 .49577 Mtetra
.633 .702 .896 r
.10679 .49577 .11128 .50083 .11755 .4989 .11306 .49383 Mtetra
.639 .705 .894 r
.11306 .49383 .11755 .4989 .12384 .49687 .11936 .49179 Mtetra
.646 .707 .892 r
.11936 .49179 .12384 .49687 .13016 .4947 .12569 .48963 Mtetra
.65 .709 .891 r
.12569 .48963 .13016 .4947 .13651 .49248 .13205 .4874 Mtetra
.13205 .4874 .13651 .49248 .14287 .49023 .13842 .48516 Mtetra
.65 .71 .891 r
.13842 .48516 .14287 .49023 .14925 .48799 .1448 .48291 Mtetra
.651 .71 .891 r
.1448 .48291 .14925 .48799 .15565 .48573 .1512 .48064 Mtetra
.651 .711 .891 r
.1512 .48064 .15565 .48573 .16206 .48346 .15762 .47837 Mtetra
.65 .711 .892 r
.15762 .47837 .16206 .48346 .16848 .4812 .16405 .47611 Mtetra
.16405 .47611 .16848 .4812 .17492 .47894 .1705 .47384 Mtetra
.651 .712 .892 r
.1705 .47384 .17492 .47894 .18138 .47666 .17696 .47156 Mtetra
.649 .711 .893 r
.17696 .47156 .18138 .47666 .18785 .4744 .18344 .4693 Mtetra
.65 .712 .893 r
.18344 .4693 .18785 .4744 .19434 .47213 .18993 .46702 Mtetra
.18993 .46702 .19434 .47213 .20084 .46985 .19644 .46474 Mtetra
.649 .712 .894 r
.19644 .46474 .20084 .46985 .20736 .46758 .20297 .46246 Mtetra
.20297 .46246 .20736 .46758 .21389 .4653 .20951 .46018 Mtetra
.65 .713 .894 r
.20951 .46018 .21389 .4653 .22044 .46301 .21607 .45788 Mtetra
.649 .713 .894 r
.21607 .45788 .22044 .46301 .22701 .46073 .22264 .4556 Mtetra
.648 .713 .895 r
.22264 .4556 .22701 .46073 .23359 .45845 .22923 .45331 Mtetra
.649 .713 .895 r
.22923 .45331 .23359 .45845 .24019 .45616 .23584 .45101 Mtetra
.23584 .45101 .24019 .45616 .24681 .45386 .24246 .44871 Mtetra
.648 .713 .895 r
.24246 .44871 .24681 .45386 .25344 .45158 .2491 .44642 Mtetra
.649 .714 .895 r
.2491 .44642 .25344 .45158 .26008 .44928 .25575 .4441 Mtetra
.648 .714 .896 r
.25575 .4441 .26008 .44928 .26675 .44697 .26242 .44179 Mtetra
.647 .714 .896 r
.26242 .44179 .26675 .44697 .27343 .44468 .26911 .43949 Mtetra
.648 .714 .896 r
.26911 .43949 .27343 .44468 .28012 .44237 .27581 .43718 Mtetra
.27581 .43718 .28012 .44237 .28684 .44006 .28254 .43485 Mtetra
.647 .714 .897 r
.28254 .43485 .28684 .44006 .29357 .43776 .28927 .43254 Mtetra
.647 .714 .896 r
.28927 .43254 .29357 .43776 .30031 .43544 .29603 .43022 Mtetra
.648 .714 .896 r
.29603 .43022 .30031 .43544 .30708 .43312 .3028 .42789 Mtetra
.646 .714 .897 r
.3028 .42789 .30708 .43312 .31386 .43081 .30959 .42557 Mtetra
.647 .714 .897 r
.30959 .42557 .31386 .43081 .32066 .42849 .3164 .42324 Mtetra
.3164 .42324 .32066 .42849 .32747 .42615 .32322 .42089 Mtetra
.646 .714 .897 r
.32322 .42089 .32747 .42615 .33431 .42383 .33006 .41856 Mtetra
.33006 .41856 .33431 .42383 .34116 .4215 .33692 .41622 Mtetra
.647 .714 .897 r
.33692 .41622 .34116 .4215 .34802 .41916 .3438 .41387 Mtetra
.646 .714 .897 r
.3438 .41387 .34802 .41916 .35491 .41683 .35069 .41153 Mtetra
.646 .714 .898 r
.35069 .41153 .35491 .41683 .36181 .4145 .3576 .40918 Mtetra
.646 .714 .897 r
.3576 .40918 .36181 .4145 .36873 .41214 .36453 .40682 Mtetra
.646 .714 .898 r
.36453 .40682 .36873 .41214 .37567 .4098 .37148 .40446 Mtetra
.645 .714 .898 r
.37148 .40446 .37567 .4098 .38263 .40746 .37845 .40211 Mtetra
.646 .714 .898 r
.37845 .40211 .38263 .40746 .3896 .4051 .38543 .39974 Mtetra
.645 .714 .898 r
.38543 .39974 .3896 .4051 .39659 .40274 .39243 .39737 Mtetra
.644 .714 .898 r
.39243 .39737 .39659 .40274 .4036 .40039 .39945 .39501 Mtetra
.645 .714 .898 r
.39945 .39501 .4036 .40039 .41063 .39803 .40649 .39263 Mtetra
.40649 .39263 .41063 .39803 .41768 .39565 .41355 .39024 Mtetra
.644 .713 .898 r
.41355 .39024 .41768 .39565 .42474 .3933 .42062 .38787 Mtetra
.42062 .38787 .42474 .3933 .43183 .39092 .42772 .38549 Mtetra
.645 .714 .898 r
.42772 .38549 .43183 .39092 .43893 .38854 .43483 .38309 Mtetra
.643 .713 .898 r
.43483 .38309 .43893 .38854 .44605 .38617 .44196 .38071 Mtetra
.644 .713 .898 r
.44196 .38071 .44605 .38617 .45319 .38379 .44911 .37831 Mtetra
.44911 .37831 .45319 .38379 .46035 .3814 .45628 .3759 Mtetra
.643 .712 .898 r
.45628 .3759 .46035 .3814 .46753 .37902 .46347 .37351 Mtetra
.46347 .37351 .46753 .37902 .47473 .37664 .47067 .37111 Mtetra
.47067 .37111 .47473 .37664 .48194 .37424 .4779 .3687 Mtetra
.4779 .3687 .48194 .37424 .48918 .37185 .48514 .36629 Mtetra
.48514 .36629 .48918 .37185 .49643 .36945 .49241 .36387 Mtetra
.643 .712 .897 r
.49241 .36387 .49643 .36945 .50371 .36704 .49969 .36145 Mtetra
.642 .711 .897 r
.49969 .36145 .50371 .36704 .511 .36464 .507 .35903 Mtetra
.507 .35903 .511 .36464 .51832 .36223 .51432 .3566 Mtetra
.51432 .3566 .51832 .36223 .52565 .35981 .52167 .35417 Mtetra
.52167 .35417 .52565 .35981 .53301 .3574 .52903 .35174 Mtetra
.642 .71 .897 r
.52903 .35174 .53301 .3574 .54038 .35498 .53642 .3493 Mtetra
.53642 .3493 .54038 .35498 .54777 .35255 .54382 .34686 Mtetra
.641 .71 .897 r
.54382 .34686 .54777 .35255 .55519 .35013 .55124 .34441 Mtetra
.641 .709 .897 r
.55124 .34441 .55519 .35013 .56262 .3477 .55869 .34196 Mtetra
.641 .709 .896 r
.55869 .34196 .56262 .3477 .57008 .34526 .56615 .33951 Mtetra
.56615 .33951 .57008 .34526 .57755 .34283 .57364 .33705 Mtetra
.641 .708 .896 r
.57364 .33705 .57755 .34283 .58505 .34039 .58115 .3346 Mtetra
.64 .708 .896 r
.58115 .3346 .58505 .34039 .59256 .33794 .58867 .33213 Mtetra
.58867 .33213 .59256 .33794 .6001 .3355 .59622 .32966 Mtetra
.64 .707 .895 r
.59622 .32966 .6001 .3355 .60766 .33305 .60379 .32719 Mtetra
.60379 .32719 .60766 .33305 .61524 .33059 .61138 .32472 Mtetra
.64 .706 .895 r
.61138 .32472 .61524 .33059 .62284 .32814 .61899 .32224 Mtetra
.61899 .32224 .62284 .32814 .63046 .32567 .62663 .31975 Mtetra
.64 .706 .894 r
.62663 .31975 .63046 .32567 .63811 .32319 .63428 .31725 Mtetra
.641 .706 .894 r
.63428 .31725 .63811 .32319 .64577 .32069 .64196 .31473 Mtetra
.645 .707 .893 r
.64196 .31473 .64577 .32069 .65345 .31811 .64965 .31213 Mtetra
.648 .708 .891 r
.64965 .31213 .65345 .31811 .66115 .31547 .65736 .30946 Mtetra
.667 .716 .885 r
.65736 .30946 .66115 .31547 .66886 .31243 .66508 .3064 Mtetra
.688 .725 .878 r
.66508 .3064 .66886 .31243 .67656 .30892 .67279 .30287 Mtetra
.718 .736 .865 r
.67279 .30287 .67656 .30892 .68424 .30469 .68048 .29862 Mtetra
.79 .76 .826 r
.68048 .29862 .68424 .30469 .69182 .29832 .68808 .29224 Mtetra
.831 .771 .795 r
.68808 .29224 .69182 .29832 .69931 .29029 .69559 .2842 Mtetra
.895 .78 .727 r
.69559 .2842 .69931 .29029 .70656 .27826 .70286 .27218 Mtetra
.937 .777 .658 r
.70286 .27218 .70656 .27826 .71348 .26123 .70981 .25516 Mtetra
.953 .772 .621 r
.70981 .25516 .71348 .26123 .72014 .24091 .7165 .23488 Mtetra
.974 .756 .548 r
.7165 .23488 .72014 .24091 .72613 .21166 .72254 .20569 Mtetra
.979 .75 .523 r
.72254 .20569 .72613 .21166 .73175 .17874 .72821 .17283 Mtetra
.95 .635 .398 r
.05936 .37947 .06369 .38466 .06504 .41468 .06069 .40931 Mtetra
.951 .628 .379 r
.06069 .40931 .06504 .41468 .06687 .4422 .06249 .43668 Mtetra
.945 .589 .289 r
.06249 .43668 .06687 .4422 .06995 .4615 .06556 .45587 Mtetra
.933 .553 .213 r
.06556 .45587 .06995 .4615 .07359 .47741 .06919 .47168 Mtetra
.846 .412 0 r
.06919 .47168 .07359 .47741 .07804 .4879 .07363 .48211 Mtetra
0 .021 .565 r
.07363 .48211 .07804 .4879 .0832 .49351 .07879 .48767 Mtetra
0 .314 .804 r
.07879 .48767 .0832 .49351 .08867 .49701 .08426 .49115 Mtetra
.432 .581 .901 r
.08426 .49115 .08867 .49701 .09457 .49756 .09016 .49168 Mtetra
.535 .629 .891 r
.09016 .49168 .09457 .49756 .10063 .49701 .09622 .49113 Mtetra
.587 .651 .88 r
.09622 .49113 .10063 .49701 .10679 .49577 .10239 .48989 Mtetra
.629 .668 .868 r
.10239 .48989 .10679 .49577 .11306 .49383 .10866 .48795 Mtetra
.635 .67 .867 r
.10866 .48795 .11306 .49383 .11936 .49179 .11497 .48592 Mtetra
.641 .673 .865 r
.11497 .48592 .11936 .49179 .12569 .48963 .1213 .48376 Mtetra
.645 .675 .864 r
.1213 .48376 .12569 .48963 .13205 .4874 .12766 .48153 Mtetra
.645 .676 .864 r
.12766 .48153 .13205 .4874 .13842 .48516 .13403 .47929 Mtetra
.645 .676 .865 r
.13403 .47929 .13842 .48516 .1448 .48291 .14042 .47704 Mtetra
.646 .677 .865 r
.14042 .47704 .1448 .48291 .1512 .48064 .14682 .47477 Mtetra
.14682 .47477 .1512 .48064 .15762 .47837 .15325 .4725 Mtetra
.645 .678 .866 r
.15325 .4725 .15762 .47837 .16405 .47611 .15968 .47025 Mtetra
.646 .678 .866 r
.15968 .47025 .16405 .47611 .1705 .47384 .16613 .46798 Mtetra
.646 .679 .867 r
.16613 .46798 .1705 .47384 .17696 .47156 .1726 .46569 Mtetra
.645 .679 .867 r
.1726 .46569 .17696 .47156 .18344 .4693 .17908 .46343 Mtetra
.645 .679 .868 r
.17908 .46343 .18344 .4693 .18993 .46702 .18558 .46115 Mtetra
.646 .68 .868 r
.18558 .46115 .18993 .46702 .19644 .46474 .1921 .45886 Mtetra
.645 .68 .868 r
.1921 .45886 .19644 .46474 .20297 .46246 .19863 .45658 Mtetra
.645 .68 .869 r
.19863 .45658 .20297 .46246 .20951 .46018 .20518 .4543 Mtetra
.645 .681 .869 r
.20518 .4543 .20951 .46018 .21607 .45788 .21174 .452 Mtetra
.21174 .452 .21607 .45788 .22264 .4556 .21832 .44971 Mtetra
.645 .681 .87 r
.21832 .44971 .22264 .4556 .22923 .45331 .22491 .44742 Mtetra
.22491 .44742 .22923 .45331 .23584 .45101 .23153 .44511 Mtetra
.645 .682 .87 r
.23153 .44511 .23584 .45101 .24246 .44871 .23815 .44281 Mtetra
.644 .682 .871 r
.23815 .44281 .24246 .44871 .2491 .44642 .2448 .44051 Mtetra
.645 .682 .871 r
.2448 .44051 .2491 .44642 .25575 .4441 .25146 .43819 Mtetra
.25146 .43819 .25575 .4441 .26242 .44179 .25814 .43588 Mtetra
.644 .682 .871 r
.25814 .43588 .26242 .44179 .26911 .43949 .26483 .43357 Mtetra
.644 .683 .871 r
.26483 .43357 .26911 .43949 .27581 .43718 .27154 .43124 Mtetra
.27154 .43124 .27581 .43718 .28254 .43485 .27827 .42891 Mtetra
.643 .683 .872 r
.27827 .42891 .28254 .43485 .28927 .43254 .28502 .4266 Mtetra
.644 .683 .872 r
.28502 .4266 .28927 .43254 .29603 .43022 .29178 .42427 Mtetra
.29178 .42427 .29603 .43022 .3028 .42789 .29856 .42192 Mtetra
.643 .683 .872 r
.29856 .42192 .3028 .42789 .30959 .42557 .30535 .41959 Mtetra
.30535 .41959 .30959 .42557 .3164 .42324 .31217 .41726 Mtetra
.644 .683 .872 r
.31217 .41726 .3164 .42324 .32322 .42089 .319 .4149 Mtetra
.643 .683 .873 r
.319 .4149 .32322 .42089 .33006 .41856 .32585 .41256 Mtetra
.32585 .41256 .33006 .41856 .33692 .41622 .33271 .41021 Mtetra
.644 .684 .873 r
.33271 .41021 .33692 .41622 .3438 .41387 .3396 .40785 Mtetra
.643 .683 .873 r
.3396 .40785 .3438 .41387 .35069 .41153 .3465 .40549 Mtetra
.642 .683 .873 r
.3465 .40549 .35069 .41153 .3576 .40918 .35342 .40314 Mtetra
.643 .684 .873 r
.35342 .40314 .3576 .40918 .36453 .40682 .36036 .40076 Mtetra
.643 .683 .873 r
.36036 .40076 .36453 .40682 .37148 .40446 .36731 .39839 Mtetra
.642 .683 .873 r
.36731 .39839 .37148 .40446 .37845 .40211 .37428 .39603 Mtetra
.643 .683 .873 r
.37428 .39603 .37845 .40211 .38543 .39974 .38127 .39365 Mtetra
.642 .683 .873 r
.38127 .39365 .38543 .39974 .39243 .39737 .38828 .39126 Mtetra
.38828 .39126 .39243 .39737 .39945 .39501 .39531 .38889 Mtetra
.39531 .38889 .39945 .39501 .40649 .39263 .40236 .38649 Mtetra
.40236 .38649 .40649 .39263 .41355 .39024 .40942 .38409 Mtetra
.641 .682 .873 r
.40942 .38409 .41355 .39024 .42062 .38787 .4165 .38171 Mtetra
.642 .683 .873 r
.4165 .38171 .42062 .38787 .42772 .38549 .42361 .37931 Mtetra
.42361 .37931 .42772 .38549 .43483 .38309 .43073 .37689 Mtetra
.641 .682 .873 r
.43073 .37689 .43483 .38309 .44196 .38071 .43787 .3745 Mtetra
.43787 .3745 .44196 .38071 .44911 .37831 .44502 .37209 Mtetra
.44502 .37209 .44911 .37831 .45628 .3759 .4522 .36966 Mtetra
.64 .681 .873 r
.4522 .36966 .45628 .3759 .46347 .37351 .4594 .36725 Mtetra
.4594 .36725 .46347 .37351 .47067 .37111 .46661 .36483 Mtetra
.46661 .36483 .47067 .37111 .4779 .3687 .47385 .3624 Mtetra
.47385 .3624 .4779 .3687 .48514 .36629 .4811 .35997 Mtetra
.64 .681 .872 r
.4811 .35997 .48514 .36629 .49241 .36387 .48838 .35754 Mtetra
.64 .68 .872 r
.48838 .35754 .49241 .36387 .49969 .36145 .49567 .3551 Mtetra
.49567 .3551 .49969 .36145 .507 .35903 .50298 .35266 Mtetra
.50298 .35266 .507 .35903 .51432 .3566 .51032 .35021 Mtetra
.639 .679 .872 r
.51032 .35021 .51432 .3566 .52167 .35417 .51767 .34776 Mtetra
.51767 .34776 .52167 .35417 .52903 .35174 .52504 .3453 Mtetra
.639 .679 .871 r
.52504 .3453 .52903 .35174 .53642 .3493 .53243 .34284 Mtetra
.639 .678 .871 r
.53243 .34284 .53642 .3493 .54382 .34686 .53985 .34038 Mtetra
.53985 .34038 .54382 .34686 .55124 .34441 .54728 .33791 Mtetra
.54728 .33791 .55124 .34441 .55869 .34196 .55473 .33544 Mtetra
.638 .677 .87 r
.55473 .33544 .55869 .34196 .56615 .33951 .56221 .33297 Mtetra
.56221 .33297 .56615 .33951 .57364 .33705 .5697 .33049 Mtetra
.638 .676 .87 r
.5697 .33049 .57364 .33705 .58115 .3346 .57722 .328 Mtetra
.57722 .328 .58115 .3346 .58867 .33213 .58475 .32551 Mtetra
.638 .675 .869 r
.58475 .32551 .58867 .33213 .59622 .32966 .59231 .32302 Mtetra
.59231 .32302 .59622 .32966 .60379 .32719 .59989 .32053 Mtetra
.637 .674 .869 r
.59989 .32053 .60379 .32719 .61138 .32472 .60749 .31803 Mtetra
.637 .674 .868 r
.60749 .31803 .61138 .32472 .61899 .32224 .61511 .31552 Mtetra
.637 .673 .868 r
.61511 .31552 .61899 .32224 .62663 .31975 .62275 .31301 Mtetra
.637 .673 .867 r
.62275 .31301 .62663 .31975 .63428 .31725 .63041 .31048 Mtetra
.638 .673 .867 r
.63041 .31048 .63428 .31725 .64196 .31473 .6381 .30792 Mtetra
.642 .674 .865 r
.6381 .30792 .64196 .31473 .64965 .31213 .6458 .30529 Mtetra
.644 .674 .864 r
.6458 .30529 .64965 .31213 .65736 .30946 .65352 .3026 Mtetra
.662 .682 .859 r
.65352 .3026 .65736 .30946 .66508 .3064 .66124 .29951 Mtetra
.681 .69 .852 r
.66124 .29951 .66508 .3064 .67279 .30287 .66897 .29596 Mtetra
.709 .702 .841 r
.66897 .29596 .67279 .30287 .68048 .29862 .67667 .29169 Mtetra
.776 .727 .808 r
.67667 .29169 .68048 .29862 .68808 .29224 .68428 .2853 Mtetra
.815 .74 .782 r
.68428 .2853 .68808 .29224 .69559 .2842 .69181 .27727 Mtetra
.88 .756 .721 r
.69181 .27727 .69559 .2842 .70286 .27218 .6991 .26527 Mtetra
.925 .759 .658 r
.6991 .26527 .70286 .27218 .70981 .25516 .70608 .24831 Mtetra
.943 .758 .623 r
.70608 .24831 .70981 .25516 .7165 .23488 .7128 .2281 Mtetra
.968 .747 .552 r
.7128 .2281 .7165 .23488 .72254 .20569 .71889 .19903 Mtetra
.974 .743 .528 r
.71889 .19903 .72254 .20569 .72821 .17283 .72461 .16632 Mtetra
.955 .64 .39 r
.05513 .37347 .05936 .37947 .06069 .40931 .05645 .40303 Mtetra
.957 .634 .367 r
.05645 .40303 .06069 .40931 .06249 .43668 .05825 .43012 Mtetra
.949 .594 .263 r
.05825 .43012 .06249 .43668 .06556 .45587 .06132 .44911 Mtetra
.93 .553 .172 r
.06132 .44911 .06556 .45587 .06919 .47168 .06494 .46476 Mtetra
.799 .383 0 r
.06494 .46476 .06919 .47168 .07363 .48211 .06938 .47508 Mtetra
0 .089 .646 r
.06938 .47508 .07363 .48211 .07879 .48767 .07453 .48058 Mtetra
.102 .335 .806 r
.07453 .48058 .07879 .48767 .08426 .49115 .08001 .48402 Mtetra
.459 .542 .854 r
.08001 .48402 .08426 .49115 .09016 .49168 .0859 .48453 Mtetra
.543 .584 .846 r
.0859 .48453 .09016 .49168 .09622 .49113 .09196 .48398 Mtetra
.586 .604 .838 r
.09196 .48398 .09622 .49113 .10239 .48989 .09813 .48273 Mtetra
.622 .621 .829 r
.09813 .48273 .10239 .48989 .10866 .48795 .1044 .48081 Mtetra
.627 .624 .828 r
.1044 .48081 .10866 .48795 .11497 .48592 .11071 .47878 Mtetra
.632 .627 .827 r
.11071 .47878 .11497 .48592 .1213 .48376 .11704 .47663 Mtetra
.635 .629 .827 r
.11704 .47663 .1213 .48376 .12766 .48153 .1234 .47441 Mtetra
.636 .63 .827 r
.1234 .47441 .12766 .48153 .13403 .47929 .12977 .47218 Mtetra
.636 .63 .828 r
.12977 .47218 .13403 .47929 .14042 .47704 .13616 .46993 Mtetra
.637 .631 .828 r
.13616 .46993 .14042 .47704 .14682 .47477 .14257 .46768 Mtetra
.637 .632 .829 r
.14257 .46768 .14682 .47477 .15325 .4725 .149 .46541 Mtetra
.636 .632 .829 r
.149 .46541 .15325 .4725 .15968 .47025 .15543 .46316 Mtetra
.637 .633 .83 r
.15543 .46316 .15968 .47025 .16613 .46798 .16189 .4609 Mtetra
.637 .634 .83 r
.16189 .4609 .16613 .46798 .1726 .46569 .16836 .45862 Mtetra
.636 .634 .831 r
.16836 .45862 .1726 .46569 .17908 .46343 .17484 .45636 Mtetra
.637 .634 .831 r
.17484 .45636 .17908 .46343 .18558 .46115 .18134 .45408 Mtetra
.637 .635 .832 r
.18134 .45408 .18558 .46115 .1921 .45886 .18786 .4518 Mtetra
.18786 .4518 .1921 .45886 .19863 .45658 .1944 .44952 Mtetra
.637 .636 .833 r
.1944 .44952 .19863 .45658 .20518 .4543 .20094 .44724 Mtetra
.20094 .44724 .20518 .4543 .21174 .452 .20751 .44494 Mtetra
.637 .637 .833 r
.20751 .44494 .21174 .452 .21832 .44971 .21409 .44265 Mtetra
.636 .637 .834 r
.21409 .44265 .21832 .44971 .22491 .44742 .22069 .44036 Mtetra
.637 .638 .834 r
.22069 .44036 .22491 .44742 .23153 .44511 .22731 .43805 Mtetra
.22731 .43805 .23153 .44511 .23815 .44281 .23394 .43574 Mtetra
.636 .638 .835 r
.23394 .43574 .23815 .44281 .2448 .44051 .24059 .43344 Mtetra
.637 .638 .835 r
.24059 .43344 .2448 .44051 .25146 .43819 .24725 .43112 Mtetra
.637 .639 .835 r
.24725 .43112 .25146 .43819 .25814 .43588 .25393 .4288 Mtetra
.636 .639 .836 r
.25393 .4288 .25814 .43588 .26483 .43357 .26063 .42649 Mtetra
.637 .639 .836 r
.26063 .42649 .26483 .43357 .27154 .43124 .26735 .42416 Mtetra
.26735 .42416 .27154 .43124 .27827 .42891 .27408 .42182 Mtetra
.636 .639 .836 r
.27408 .42182 .27827 .42891 .28502 .4266 .28083 .4195 Mtetra
.637 .64 .837 r
.28083 .4195 .28502 .4266 .29178 .42427 .28759 .41716 Mtetra
.28759 .41716 .29178 .42427 .29856 .42192 .29438 .41481 Mtetra
.636 .64 .837 r
.29438 .41481 .29856 .42192 .30535 .41959 .30118 .41248 Mtetra
.30118 .41248 .30535 .41959 .31217 .41726 .308 .41013 Mtetra
.637 .64 .837 r
.308 .41013 .31217 .41726 .319 .4149 .31483 .40777 Mtetra
.636 .64 .838 r
.31483 .40777 .319 .4149 .32585 .41256 .32169 .40541 Mtetra
.32169 .40541 .32585 .41256 .33271 .41021 .32856 .40306 Mtetra
.637 .641 .838 r
.32856 .40306 .33271 .41021 .3396 .40785 .33545 .40068 Mtetra
.636 .64 .838 r
.33545 .40068 .3396 .40785 .3465 .40549 .34235 .39832 Mtetra
.34235 .39832 .3465 .40549 .35342 .40314 .34928 .39595 Mtetra
.636 .641 .838 r
.34928 .39595 .35342 .40314 .36036 .40076 .35622 .39356 Mtetra
.35622 .39356 .36036 .40076 .36731 .39839 .36318 .39118 Mtetra
.635 .64 .838 r
.36318 .39118 .36731 .39839 .37428 .39603 .37016 .3888 Mtetra
.636 .641 .838 r
.37016 .3888 .37428 .39603 .38127 .39365 .37715 .3864 Mtetra
.636 .64 .838 r
.37715 .3864 .38127 .39365 .38828 .39126 .38417 .38401 Mtetra
.635 .64 .838 r
.38417 .38401 .38828 .39126 .39531 .38889 .3912 .38162 Mtetra
.636 .64 .838 r
.3912 .38162 .39531 .38889 .40236 .38649 .39825 .37921 Mtetra
.39825 .37921 .40236 .38649 .40942 .38409 .40532 .37679 Mtetra
.635 .64 .838 r
.40532 .37679 .40942 .38409 .4165 .38171 .41241 .37439 Mtetra
.41241 .37439 .4165 .38171 .42361 .37931 .41952 .37197 Mtetra
.41952 .37197 .42361 .37931 .43073 .37689 .42665 .36954 Mtetra
.634 .639 .838 r
.42665 .36954 .43073 .37689 .43787 .3745 .43379 .36712 Mtetra
.635 .639 .837 r
.43379 .36712 .43787 .3745 .44502 .37209 .44095 .36469 Mtetra
.44095 .36469 .44502 .37209 .4522 .36966 .44814 .36225 Mtetra
.634 .639 .837 r
.44814 .36225 .4522 .36966 .4594 .36725 .45534 .35982 Mtetra
.634 .638 .837 r
.45534 .35982 .4594 .36725 .46661 .36483 .46256 .35738 Mtetra
.46256 .35738 .46661 .36483 .47385 .3624 .4698 .35493 Mtetra
.4698 .35493 .47385 .3624 .4811 .35997 .47706 .35248 Mtetra
.634 .638 .836 r
.47706 .35248 .4811 .35997 .48838 .35754 .48434 .35002 Mtetra
.634 .637 .836 r
.48434 .35002 .48838 .35754 .49567 .3551 .49164 .34756 Mtetra
.49164 .34756 .49567 .3551 .50298 .35266 .49896 .34509 Mtetra
.633 .636 .836 r
.49896 .34509 .50298 .35266 .51032 .35021 .5063 .34262 Mtetra
.633 .636 .835 r
.5063 .34262 .51032 .35021 .51767 .34776 .51366 .34014 Mtetra
.51366 .34014 .51767 .34776 .52504 .3453 .52104 .33766 Mtetra
.633 .635 .835 r
.52104 .33766 .52504 .3453 .53243 .34284 .52843 .33517 Mtetra
.633 .635 .834 r
.52843 .33517 .53243 .34284 .53985 .34038 .53585 .33268 Mtetra
.633 .634 .834 r
.53585 .33268 .53985 .34038 .54728 .33791 .54329 .33019 Mtetra
.632 .634 .834 r
.54329 .33019 .54728 .33791 .55473 .33544 .55075 .32769 Mtetra
.632 .633 .833 r
.55075 .32769 .55473 .33544 .56221 .33297 .55823 .32518 Mtetra
.55823 .32518 .56221 .33297 .5697 .33049 .56573 .32267 Mtetra
.632 .632 .833 r
.56573 .32267 .5697 .33049 .57722 .328 .57325 .32016 Mtetra
.632 .632 .832 r
.57325 .32016 .57722 .328 .58475 .32551 .5808 .31764 Mtetra
.631 .631 .832 r
.5808 .31764 .58475 .32551 .59231 .32302 .58836 .31512 Mtetra
.631 .63 .831 r
.58836 .31512 .59231 .32302 .59989 .32053 .59594 .31259 Mtetra
.59594 .31259 .59989 .32053 .60749 .31803 .60355 .31005 Mtetra
.631 .629 .83 r
.60355 .31005 .60749 .31803 .61511 .31552 .61117 .30751 Mtetra
.631 .628 .83 r
.61117 .30751 .61511 .31552 .62275 .31301 .61882 .30496 Mtetra
.631 .628 .829 r
.61882 .30496 .62275 .31301 .63041 .31048 .62649 .3024 Mtetra
.632 .628 .828 r
.62649 .3024 .63041 .31048 .6381 .30792 .63418 .29981 Mtetra
.634 .628 .827 r
.63418 .29981 .6381 .30792 .6458 .30529 .64188 .29714 Mtetra
.637 .629 .826 r
.64188 .29714 .6458 .30529 .65352 .3026 .64961 .29441 Mtetra
.652 .636 .821 r
.64961 .29441 .65352 .3026 .66124 .29951 .65734 .29129 Mtetra
.668 .643 .816 r
.65734 .29129 .66124 .29951 .66897 .29596 .66507 .28771 Mtetra
.693 .655 .807 r
.66507 .28771 .66897 .29596 .67667 .29169 .67278 .28342 Mtetra
.754 .682 .781 r
.67278 .28342 .67667 .29169 .68428 .2853 .6804 .27702 Mtetra
.791 .697 .76 r
.6804 .27702 .68428 .2853 .69181 .27727 .68794 .269 Mtetra
.856 .72 .711 r
.68794 .269 .69181 .27727 .6991 .26527 .69526 .25706 Mtetra
.905 .731 .656 r
.69526 .25706 .6991 .26527 .70608 .24831 .70226 .2402 Mtetra
.926 .735 .625 r
.70226 .2402 .70608 .24831 .7128 .2281 .70902 .22013 Mtetra
.957 .733 .559 r
.70902 .22013 .7128 .2281 .71889 .19903 .71516 .19129 Mtetra
.966 .732 .535 r
.71516 .19129 .71889 .19903 .72461 .16632 .72094 .15884 Mtetra
.966 .652 .366 r
.05118 .36543 .05513 .37347 .05645 .40303 .05254 .39438 Mtetra
.968 .647 .333 r
.05254 .39438 .05645 .40303 .05825 .43012 .05438 .4209 Mtetra
.942 .596 .182 r
.05438 .4209 .05825 .43012 .06132 .44911 .05747 .43949 Mtetra
.882 .53 .04 r
.05747 .43949 .06132 .44911 .06494 .46476 .06111 .4548 Mtetra
0 0 .345 r
.06111 .4548 .06494 .46476 .06938 .47508 .06555 .46489 Mtetra
.051 .193 .693 r
.06555 .46489 .06938 .47508 .07453 .48058 .07071 .47026 Mtetra
.278 .34 .747 r
.07071 .47026 .07453 .48058 .08001 .48402 .07618 .4736 Mtetra
.49 .47 .762 r
.07618 .4736 .08001 .48402 .0859 .48453 .08207 .47409 Mtetra
.545 .501 .758 r
.08207 .47409 .0859 .48453 .09196 .48398 .08812 .47353 Mtetra
.575 .519 .755 r
.08812 .47353 .09196 .48398 .09813 .48273 .09429 .47229 Mtetra
.601 .534 .751 r
.09429 .47229 .09813 .48273 .1044 .48081 .10056 .47039 Mtetra
.605 .537 .751 r
.10056 .47039 .1044 .48081 .11071 .47878 .10685 .46838 Mtetra
.609 .54 .751 r
.10685 .46838 .11071 .47878 .11704 .47663 .11318 .46625 Mtetra
.612 .542 .752 r
.11318 .46625 .11704 .47663 .1234 .47441 .11953 .46405 Mtetra
.612 .543 .752 r
.11953 .46405 .1234 .47441 .12977 .47218 .1259 .46184 Mtetra
.613 .544 .753 r
.1259 .46184 .12977 .47218 .13616 .46993 .13228 .45962 Mtetra
.613 .545 .753 r
.13228 .45962 .13616 .46993 .14257 .46768 .13868 .45738 Mtetra
.614 .545 .754 r
.13868 .45738 .14257 .46768 .149 .46541 .1451 .45513 Mtetra
.613 .546 .755 r
.1451 .45513 .149 .46541 .15543 .46316 .15153 .45289 Mtetra
.614 .546 .755 r
.15153 .45289 .15543 .46316 .16189 .4609 .15798 .45064 Mtetra
.614 .547 .756 r
.15798 .45064 .16189 .4609 .16836 .45862 .16445 .44838 Mtetra
.16445 .44838 .16836 .45862 .17484 .45636 .17093 .44613 Mtetra
.614 .548 .757 r
.17093 .44613 .17484 .45636 .18134 .45408 .17742 .44387 Mtetra
.615 .549 .757 r
.17742 .44387 .18134 .45408 .18786 .4518 .18394 .44159 Mtetra
.614 .549 .758 r
.18394 .44159 .18786 .4518 .1944 .44952 .19047 .43933 Mtetra
.614 .55 .758 r
.19047 .43933 .1944 .44952 .20094 .44724 .19701 .43705 Mtetra
.615 .55 .759 r
.19701 .43705 .20094 .44724 .20751 .44494 .20357 .43476 Mtetra
.615 .551 .759 r
.20357 .43476 .20751 .44494 .21409 .44265 .21015 .43248 Mtetra
.615 .551 .76 r
.21015 .43248 .21409 .44265 .22069 .44036 .21675 .43019 Mtetra
.615 .552 .76 r
.21675 .43019 .22069 .44036 .22731 .43805 .22336 .42789 Mtetra
.22336 .42789 .22731 .43805 .23394 .43574 .22999 .42559 Mtetra
.615 .552 .761 r
.22999 .42559 .23394 .43574 .24059 .43344 .23663 .42329 Mtetra
.615 .553 .761 r
.23663 .42329 .24059 .43344 .24725 .43112 .2433 .42097 Mtetra
.2433 .42097 .24725 .43112 .25393 .4288 .24997 .41865 Mtetra
.615 .553 .762 r
.24997 .41865 .25393 .4288 .26063 .42649 .25667 .41634 Mtetra
.615 .554 .762 r
.25667 .41634 .26063 .42649 .26735 .42416 .26338 .41401 Mtetra
.616 .554 .762 r
.26338 .41401 .26735 .42416 .27408 .42182 .27011 .41167 Mtetra
.615 .554 .763 r
.27011 .41167 .27408 .42182 .28083 .4195 .27686 .40935 Mtetra
.616 .554 .763 r
.27686 .40935 .28083 .4195 .28759 .41716 .28362 .407 Mtetra
.616 .555 .763 r
.28362 .407 .28759 .41716 .29438 .41481 .29041 .40465 Mtetra
.615 .555 .763 r
.29041 .40465 .29438 .41481 .30118 .41248 .29721 .40231 Mtetra
.29721 .40231 .30118 .41248 .308 .41013 .30402 .39995 Mtetra
.616 .555 .763 r
.30402 .39995 .308 .41013 .31483 .40777 .31086 .39758 Mtetra
.615 .555 .764 r
.31086 .39758 .31483 .40777 .32169 .40541 .31771 .39522 Mtetra
.31771 .39522 .32169 .40541 .32856 .40306 .32458 .39286 Mtetra
.616 .556 .764 r
.32458 .39286 .32856 .40306 .33545 .40068 .33146 .39047 Mtetra
.615 .555 .764 r
.33146 .39047 .33545 .40068 .34235 .39832 .33837 .38809 Mtetra
.33837 .38809 .34235 .39832 .34928 .39595 .34529 .38571 Mtetra
.616 .556 .764 r
.34529 .38571 .34928 .39595 .35622 .39356 .35223 .38331 Mtetra
.615 .556 .764 r
.35223 .38331 .35622 .39356 .36318 .39118 .35919 .38092 Mtetra
.615 .555 .764 r
.35919 .38092 .36318 .39118 .37016 .3888 .36617 .37852 Mtetra
.616 .556 .764 r
.36617 .37852 .37016 .3888 .37715 .3864 .37317 .37611 Mtetra
.615 .556 .764 r
.37317 .37611 .37715 .3864 .38417 .38401 .38018 .37369 Mtetra
.615 .555 .764 r
.38018 .37369 .38417 .38401 .3912 .38162 .38721 .37129 Mtetra
.38721 .37129 .3912 .38162 .39825 .37921 .39426 .36886 Mtetra
.39426 .36886 .39825 .37921 .40532 .37679 .40133 .36642 Mtetra
.40133 .36642 .40532 .37679 .41241 .37439 .40842 .364 Mtetra
.40842 .364 .41241 .37439 .41952 .37197 .41553 .36156 Mtetra
.615 .555 .763 r
.41553 .36156 .41952 .37197 .42665 .36954 .42265 .3591 Mtetra
.615 .554 .763 r
.42265 .3591 .42665 .36954 .43379 .36712 .42979 .35666 Mtetra
.42979 .35666 .43379 .36712 .44095 .36469 .43696 .35421 Mtetra
.43696 .35421 .44095 .36469 .44814 .36225 .44414 .35174 Mtetra
.614 .554 .763 r
.44414 .35174 .44814 .36225 .45534 .35982 .45134 .34928 Mtetra
.614 .553 .763 r
.45134 .34928 .45534 .35982 .46256 .35738 .45856 .34681 Mtetra
.614 .553 .762 r
.45856 .34681 .46256 .35738 .4698 .35493 .4658 .34433 Mtetra
.4658 .34433 .4698 .35493 .47706 .35248 .47306 .34185 Mtetra
.47306 .34185 .47706 .35248 .48434 .35002 .48034 .33936 Mtetra
.614 .552 .762 r
.48034 .33936 .48434 .35002 .49164 .34756 .48764 .33687 Mtetra
.614 .552 .761 r
.48764 .33687 .49164 .34756 .49896 .34509 .49495 .33437 Mtetra
.614 .551 .761 r
.49495 .33437 .49896 .34509 .5063 .34262 .50229 .33186 Mtetra
.50229 .33186 .5063 .34262 .51366 .34014 .50965 .32935 Mtetra
.613 .551 .76 r
.50965 .32935 .51366 .34014 .52104 .33766 .51703 .32683 Mtetra
.613 .55 .76 r
.51703 .32683 .52104 .33766 .52843 .33517 .52442 .32431 Mtetra
.613 .55 .759 r
.52442 .32431 .52843 .33517 .53585 .33268 .53184 .32178 Mtetra
.613 .549 .759 r
.53184 .32178 .53585 .33268 .54329 .33019 .53928 .31924 Mtetra
.53928 .31924 .54329 .33019 .55075 .32769 .54674 .3167 Mtetra
.613 .548 .758 r
.54674 .3167 .55075 .32769 .55823 .32518 .55421 .31416 Mtetra
.612 .548 .758 r
.55421 .31416 .55823 .32518 .56573 .32267 .56171 .3116 Mtetra
.612 .547 .757 r
.56171 .3116 .56573 .32267 .57325 .32016 .56923 .30904 Mtetra
.612 .546 .757 r
.56923 .30904 .57325 .32016 .5808 .31764 .57677 .30648 Mtetra
.612 .546 .756 r
.57677 .30648 .5808 .31764 .58836 .31512 .58433 .30391 Mtetra
.612 .545 .755 r
.58433 .30391 .58836 .31512 .59594 .31259 .59191 .30133 Mtetra
.611 .544 .755 r
.59191 .30133 .59594 .31259 .60355 .31005 .59951 .29875 Mtetra
.611 .544 .754 r
.59951 .29875 .60355 .31005 .61117 .30751 .60714 .29616 Mtetra
.611 .543 .754 r
.60714 .29616 .61117 .30751 .61882 .30496 .61478 .29356 Mtetra
.611 .543 .753 r
.61478 .29356 .61882 .30496 .62649 .3024 .62244 .29094 Mtetra
.612 .542 .752 r
.62244 .29094 .62649 .3024 .63418 .29981 .63013 .28829 Mtetra
.613 .543 .751 r
.63013 .28829 .63418 .29981 .64188 .29714 .63783 .28558 Mtetra
.615 .543 .75 r
.63783 .28558 .64188 .29714 .64961 .29441 .64556 .28279 Mtetra
.626 .549 .748 r
.64556 .28279 .64961 .29441 .65734 .29129 .65328 .27962 Mtetra
.639 .555 .744 r
.65328 .27962 .65734 .29129 .66507 .28771 .66101 .27601 Mtetra
.658 .566 .74 r
.66101 .27601 .66507 .28771 .67278 .28342 .66872 .27169 Mtetra
.707 .593 .725 r
.66872 .27169 .67278 .28342 .6804 .27702 .67635 .26532 Mtetra
.74 .61 .714 r
.67635 .26532 .6804 .27702 .68794 .269 .68389 .25735 Mtetra
.802 .642 .683 r
.68389 .25735 .68794 .269 .69526 .25706 .69122 .24555 Mtetra
.856 .668 .646 r
.69122 .24555 .69526 .25706 .70226 .2402 .69826 .22893 Mtetra
.884 .681 .623 r
.69826 .22893 .70226 .2402 .70902 .22013 .70505 .20917 Mtetra
.928 .697 .569 r
.70505 .20917 .70902 .22013 .71516 .19129 .71125 .18082 Mtetra
.942 .703 .547 r
.71125 .18082 .71516 .19129 .72094 .15884 .7171 .14892 Mtetra
.972 .659 .342 r
.04745 .35596 .05118 .36543 .05254 .39438 .04888 .38408 Mtetra
.97 .653 .299 r
.04888 .38408 .05254 .39438 .05438 .4209 .05077 .40984 Mtetra
.908 .58 .101 r
.05077 .40984 .05438 .4209 .05747 .43949 .0539 .42788 Mtetra
.789 .477 0 r
.0539 .42788 .05747 .43949 .06111 .4548 .05757 .44272 Mtetra
0 0 .46 r
.05757 .44272 .06111 .4548 .06555 .46489 .06204 .45249 Mtetra
.178 .229 .678 r
.06204 .45249 .06555 .46489 .07071 .47026 .0672 .45769 Mtetra
.341 .335 .708 r
.0672 .45769 .07071 .47026 .07618 .4736 .07267 .46091 Mtetra
.499 .436 .718 r
.07267 .46091 .07618 .4736 .08207 .47409 .07855 .46136 Mtetra
.542 .464 .716 r
.07855 .46136 .08207 .47409 .08812 .47353 .08459 .46078 Mtetra
.566 .479 .715 r
.08459 .46078 .08812 .47353 .09429 .47229 .09075 .45955 Mtetra
.588 .493 .714 r
.09075 .45955 .09429 .47229 .10056 .47039 .097 .45767 Mtetra
.592 .495 .714 r
.097 .45767 .10056 .47039 .10685 .46838 .10329 .45569 Mtetra
.595 .498 .714 r
.10329 .45569 .10685 .46838 .11318 .46625 .1096 .45359 Mtetra
.598 .5 .714 r
.1096 .45359 .11318 .46625 .11953 .46405 .11594 .45142 Mtetra
.598 .501 .715 r
.11594 .45142 .11953 .46405 .1259 .46184 .1223 .44923 Mtetra
.599 .502 .716 r
.1223 .44923 .1259 .46184 .13228 .45962 .12867 .44703 Mtetra
.599 .503 .716 r
.12867 .44703 .13228 .45962 .13868 .45738 .13506 .44482 Mtetra
.599 .503 .717 r
.13506 .44482 .13868 .45738 .1451 .45513 .14147 .4426 Mtetra
.599 .504 .717 r
.14147 .4426 .1451 .45513 .15153 .45289 .14789 .44038 Mtetra
.6 .504 .718 r
.14789 .44038 .15153 .45289 .15798 .45064 .15433 .43815 Mtetra
.6 .505 .718 r
.15433 .43815 .15798 .45064 .16445 .44838 .16078 .43591 Mtetra
.6 .505 .719 r
.16078 .43591 .16445 .44838 .17093 .44613 .16725 .43368 Mtetra
.6 .506 .719 r
.16725 .43368 .17093 .44613 .17742 .44387 .17374 .43143 Mtetra
.601 .507 .72 r
.17374 .43143 .17742 .44387 .18394 .44159 .18024 .42917 Mtetra
.6 .507 .72 r
.18024 .42917 .18394 .44159 .19047 .43933 .18676 .42692 Mtetra
.601 .508 .721 r
.18676 .42692 .19047 .43933 .19701 .43705 .1933 .42466 Mtetra
.1933 .42466 .19701 .43705 .20357 .43476 .19985 .42238 Mtetra
.601 .509 .722 r
.19985 .42238 .20357 .43476 .21015 .43248 .20642 .42011 Mtetra
.20642 .42011 .21015 .43248 .21675 .43019 .21301 .41783 Mtetra
.602 .51 .722 r
.21301 .41783 .21675 .43019 .22336 .42789 .21961 .41554 Mtetra
.602 .51 .723 r
.21961 .41554 .22336 .42789 .22999 .42559 .22624 .41324 Mtetra
.601 .51 .723 r
.22624 .41324 .22999 .42559 .23663 .42329 .23287 .41095 Mtetra
.602 .511 .723 r
.23287 .41095 .23663 .42329 .2433 .42097 .23953 .40864 Mtetra
.602 .511 .724 r
.23953 .40864 .2433 .42097 .24997 .41865 .2462 .40632 Mtetra
.2462 .40632 .24997 .41865 .25667 .41634 .25289 .40401 Mtetra
.602 .512 .724 r
.25289 .40401 .25667 .41634 .26338 .41401 .25959 .40168 Mtetra
.25959 .40168 .26338 .41401 .27011 .41167 .26632 .39934 Mtetra
.602 .512 .725 r
.26632 .39934 .27011 .41167 .27686 .40935 .27306 .39702 Mtetra
.27306 .39702 .27686 .40935 .28362 .407 .27981 .39467 Mtetra
.603 .513 .725 r
.27981 .39467 .28362 .407 .29041 .40465 .28659 .39231 Mtetra
.602 .512 .725 r
.28659 .39231 .29041 .40465 .29721 .40231 .29338 .38997 Mtetra
.602 .513 .725 r
.29338 .38997 .29721 .40231 .30402 .39995 .30019 .38761 Mtetra
.603 .513 .726 r
.30019 .38761 .30402 .39995 .31086 .39758 .30702 .38523 Mtetra
.602 .513 .726 r
.30702 .38523 .31086 .39758 .31771 .39522 .31387 .38286 Mtetra
.603 .513 .726 r
.31387 .38286 .31771 .39522 .32458 .39286 .32073 .38048 Mtetra
.603 .514 .726 r
.32073 .38048 .32458 .39286 .33146 .39047 .32761 .37809 Mtetra
.603 .513 .726 r
.32761 .37809 .33146 .39047 .33837 .38809 .33451 .3757 Mtetra
.33451 .3757 .33837 .38809 .34529 .38571 .34143 .37331 Mtetra
.603 .514 .726 r
.34143 .37331 .34529 .38571 .35223 .38331 .34836 .37089 Mtetra
.34836 .37089 .35223 .38331 .35919 .38092 .35532 .36848 Mtetra
.603 .513 .726 r
.35532 .36848 .35919 .38092 .36617 .37852 .36229 .36607 Mtetra
.603 .514 .726 r
.36229 .36607 .36617 .37852 .37317 .37611 .36928 .36364 Mtetra
.36928 .36364 .37317 .37611 .38018 .37369 .37629 .3612 Mtetra
.603 .513 .726 r
.37629 .3612 .38018 .37369 .38721 .37129 .38331 .35877 Mtetra
.603 .514 .726 r
.38331 .35877 .38721 .37129 .39426 .36886 .39036 .35632 Mtetra
.603 .513 .726 r
.39036 .35632 .39426 .36886 .40133 .36642 .39742 .35387 Mtetra
.602 .513 .726 r
.39742 .35387 .40133 .36642 .40842 .364 .4045 .35142 Mtetra
.603 .513 .726 r
.4045 .35142 .40842 .364 .41553 .36156 .4116 .34895 Mtetra
.4116 .34895 .41553 .36156 .42265 .3591 .41872 .34647 Mtetra
.602 .513 .725 r
.41872 .34647 .42265 .3591 .42979 .35666 .42586 .344 Mtetra
.42586 .344 .42979 .35666 .43696 .35421 .43302 .34152 Mtetra
.603 .513 .725 r
.43302 .34152 .43696 .35421 .44414 .35174 .4402 .33902 Mtetra
.602 .512 .725 r
.4402 .33902 .44414 .35174 .45134 .34928 .44739 .33653 Mtetra
.44739 .33653 .45134 .34928 .45856 .34681 .45461 .33403 Mtetra
.602 .512 .724 r
.45461 .33403 .45856 .34681 .4658 .34433 .46184 .33152 Mtetra
.602 .511 .724 r
.46184 .33152 .4658 .34433 .47306 .34185 .46909 .329 Mtetra
.46909 .329 .47306 .34185 .48034 .33936 .47637 .32648 Mtetra
.47637 .32648 .48034 .33936 .48764 .33687 .48366 .32394 Mtetra
.602 .511 .723 r
.48366 .32394 .48764 .33687 .49495 .33437 .49097 .3214 Mtetra
.602 .51 .723 r
.49097 .3214 .49495 .33437 .50229 .33186 .4983 .31886 Mtetra
.4983 .31886 .50229 .33186 .50965 .32935 .50565 .3163 Mtetra
.602 .509 .722 r
.50565 .3163 .50965 .32935 .51703 .32683 .51302 .31374 Mtetra
.601 .509 .722 r
.51302 .31374 .51703 .32683 .52442 .32431 .52041 .31118 Mtetra
.52041 .31118 .52442 .32431 .53184 .32178 .52782 .3086 Mtetra
.601 .508 .721 r
.52782 .3086 .53184 .32178 .53928 .31924 .53525 .30602 Mtetra
.53525 .30602 .53928 .31924 .54674 .3167 .5427 .30343 Mtetra
.601 .507 .72 r
.5427 .30343 .54674 .3167 .55421 .31416 .55017 .30084 Mtetra
.55017 .30084 .55421 .31416 .56171 .3116 .55766 .29823 Mtetra
.601 .506 .719 r
.55766 .29823 .56171 .3116 .56923 .30904 .56518 .29562 Mtetra
.6 .506 .719 r
.56518 .29562 .56923 .30904 .57677 .30648 .57271 .293 Mtetra
.6 .505 .718 r
.57271 .293 .57677 .30648 .58433 .30391 .58026 .29038 Mtetra
.58026 .29038 .58433 .30391 .59191 .30133 .58783 .28774 Mtetra
.6 .504 .717 r
.58783 .28774 .59191 .30133 .59951 .29875 .59542 .2851 Mtetra
.6 .503 .717 r
.59542 .2851 .59951 .29875 .60714 .29616 .60304 .28245 Mtetra
.6 .503 .716 r
.60304 .28245 .60714 .29616 .61478 .29356 .61067 .27979 Mtetra
.6 .502 .715 r
.61067 .27979 .61478 .29356 .62244 .29094 .61833 .27711 Mtetra
.61833 .27711 .62244 .29094 .63013 .28829 .626 .2744 Mtetra
.602 .502 .714 r
.626 .2744 .63013 .28829 .63783 .28558 .6337 .27162 Mtetra
.603 .503 .713 r
.6337 .27162 .63783 .28558 .64556 .28279 .64141 .26877 Mtetra
.612 .508 .711 r
.64141 .26877 .64556 .28279 .65328 .27962 .64913 .26555 Mtetra
.623 .514 .709 r
.64913 .26555 .65328 .27962 .66101 .27601 .65685 .26189 Mtetra
.639 .523 .706 r
.65685 .26189 .66101 .27601 .66872 .27169 .66455 .25756 Mtetra
.682 .548 .696 r
.66455 .25756 .66872 .27169 .67635 .26532 .67217 .25122 Mtetra
.711 .566 .688 r
.67217 .25122 .67635 .26532 .68389 .25735 .67972 .24334 Mtetra
.77 .599 .667 r
.67972 .24334 .68389 .25735 .69122 .24555 .68706 .23173 Mtetra
.825 .63 .639 r
.68706 .23173 .69122 .24555 .69826 .22893 .69412 .21546 Mtetra
.855 .647 .621 r
.69412 .21546 .69826 .22893 .70505 .20917 .70096 .19612 Mtetra
.905 .672 .574 r
.70096 .19612 .70505 .20917 .71125 .18082 .70721 .16844 Mtetra
.924 .683 .555 r
.70721 .16844 .71125 .18082 .7171 .14892 .71314 .13731 Mtetra
.969 .667 .274 r
.0442 .3432 .04745 .35596 .04888 .38408 .04577 .36999 Mtetra
.944 .649 .196 r
.04577 .36999 .04888 .38408 .05077 .40984 .0478 .39452 Mtetra
.713 .471 0 r
.0478 .39452 .05077 .40984 .0539 .42788 .05101 .41167 Mtetra
0 0 .322 r
.05101 .41167 .0539 .42788 .05757 .44272 .05475 .42577 Mtetra
.014 .047 .549 r
.05475 .42577 .05757 .44272 .06204 .45249 .05925 .43503 Mtetra
.318 .259 .632 r
.05925 .43503 .06204 .45249 .0672 .45769 .06442 .43992 Mtetra
.409 .322 .645 r
.06442 .43992 .0672 .45769 .07267 .46091 .06989 .44295 Mtetra
.506 .389 .654 r
.06989 .44295 .07267 .46091 .07855 .46136 .07576 .44332 Mtetra
.535 .409 .655 r
.07576 .44332 .07855 .46136 .08459 .46078 .08179 .44272 Mtetra
.552 .42 .655 r
.08179 .44272 .08459 .46078 .09075 .45955 .08792 .4415 Mtetra
.568 .432 .656 r
.08792 .4415 .09075 .45955 .097 .45767 .09415 .43965 Mtetra
.57 .434 .656 r
.09415 .43965 .097 .45767 .10329 .45569 .10041 .4377 Mtetra
.573 .436 .656 r
.10041 .4377 .10329 .45569 .1096 .45359 .1067 .43564 Mtetra
.575 .438 .657 r
.1067 .43564 .1096 .45359 .11594 .45142 .11302 .43351 Mtetra
.11302 .43351 .11594 .45142 .1223 .44923 .11935 .43136 Mtetra
.575 .439 .658 r
.11935 .43136 .1223 .44923 .12867 .44703 .1257 .42921 Mtetra
.576 .44 .658 r
.1257 .42921 .12867 .44703 .13506 .44482 .13207 .42703 Mtetra
.576 .44 .659 r
.13207 .42703 .13506 .44482 .14147 .4426 .13846 .42484 Mtetra
.576 .441 .659 r
.13846 .42484 .14147 .4426 .14789 .44038 .14486 .42266 Mtetra
.577 .441 .66 r
.14486 .42266 .14789 .44038 .15433 .43815 .15127 .42046 Mtetra
.577 .442 .66 r
.15127 .42046 .15433 .43815 .16078 .43591 .15771 .41825 Mtetra
.577 .442 .661 r
.15771 .41825 .16078 .43591 .16725 .43368 .16416 .41605 Mtetra
.577 .443 .661 r
.16416 .41605 .16725 .43368 .17374 .43143 .17062 .41383 Mtetra
.578 .443 .661 r
.17062 .41383 .17374 .43143 .18024 .42917 .17711 .41159 Mtetra
.577 .443 .662 r
.17711 .41159 .18024 .42917 .18676 .42692 .18361 .40936 Mtetra
.578 .444 .662 r
.18361 .40936 .18676 .42692 .1933 .42466 .19012 .40713 Mtetra
.19012 .40713 .1933 .42466 .19985 .42238 .19666 .40487 Mtetra
.578 .445 .663 r
.19666 .40487 .19985 .42238 .20642 .42011 .20321 .40261 Mtetra
.20321 .40261 .20642 .42011 .21301 .41783 .20978 .40035 Mtetra
.579 .445 .663 r
.20978 .40035 .21301 .41783 .21961 .41554 .21636 .39807 Mtetra
.579 .446 .664 r
.21636 .39807 .21961 .41554 .22624 .41324 .22296 .39579 Mtetra
.22296 .39579 .22624 .41324 .23287 .41095 .22958 .39351 Mtetra
.22958 .39351 .23287 .41095 .23953 .40864 .23622 .3912 Mtetra
.579 .447 .664 r
.23622 .3912 .23953 .40864 .2462 .40632 .24287 .3889 Mtetra
.579 .447 .665 r
.24287 .3889 .2462 .40632 .25289 .40401 .24954 .38659 Mtetra
.24954 .38659 .25289 .40401 .25959 .40168 .25623 .38427 Mtetra
.58 .447 .665 r
.25623 .38427 .25959 .40168 .26632 .39934 .26294 .38193 Mtetra
.579 .447 .665 r
.26294 .38193 .26632 .39934 .27306 .39702 .26966 .37961 Mtetra
.58 .448 .665 r
.26966 .37961 .27306 .39702 .27981 .39467 .2764 .37726 Mtetra
.58 .448 .666 r
.2764 .37726 .27981 .39467 .28659 .39231 .28316 .3749 Mtetra
.28316 .3749 .28659 .39231 .29338 .38997 .28993 .37255 Mtetra
.28993 .37255 .29338 .38997 .30019 .38761 .29673 .37018 Mtetra
.58 .449 .666 r
.29673 .37018 .30019 .38761 .30702 .38523 .30354 .3678 Mtetra
.30354 .3678 .30702 .38523 .31387 .38286 .31037 .36542 Mtetra
.31037 .36542 .31387 .38286 .32073 .38048 .31721 .36304 Mtetra
.31721 .36304 .32073 .38048 .32761 .37809 .32408 .36063 Mtetra
.32408 .36063 .32761 .37809 .33451 .3757 .33096 .35823 Mtetra
.33096 .35823 .33451 .3757 .34143 .37331 .33786 .35582 Mtetra
.581 .449 .666 r
.33786 .35582 .34143 .37331 .34836 .37089 .34478 .35339 Mtetra
.34478 .35339 .34836 .37089 .35532 .36848 .35172 .35096 Mtetra
.58 .449 .666 r
.35172 .35096 .35532 .36848 .36229 .36607 .35867 .34853 Mtetra
.581 .449 .666 r
.35867 .34853 .36229 .36607 .36928 .36364 .36565 .34607 Mtetra
.36565 .34607 .36928 .36364 .37629 .3612 .37264 .34362 Mtetra
.58 .449 .666 r
.37264 .34362 .37629 .3612 .38331 .35877 .37965 .34116 Mtetra
.581 .449 .666 r
.37965 .34116 .38331 .35877 .39036 .35632 .38668 .33869 Mtetra
.38668 .33869 .39036 .35632 .39742 .35387 .39372 .3362 Mtetra
.58 .449 .666 r
.39372 .3362 .39742 .35387 .4045 .35142 .40079 .33372 Mtetra
.581 .449 .666 r
.40079 .33372 .4045 .35142 .4116 .34895 .40787 .33123 Mtetra
.40787 .33123 .4116 .34895 .41872 .34647 .41498 .32871 Mtetra
.58 .449 .666 r
.41498 .32871 .41872 .34647 .42586 .344 .4221 .32621 Mtetra
.581 .449 .666 r
.4221 .32621 .42586 .344 .43302 .34152 .42924 .32369 Mtetra
.581 .449 .665 r
.42924 .32369 .43302 .34152 .4402 .33902 .4364 .32115 Mtetra
.58 .448 .665 r
.4364 .32115 .4402 .33902 .44739 .33653 .44358 .31862 Mtetra
.44358 .31862 .44739 .33653 .45461 .33403 .45077 .31608 Mtetra
.581 .448 .665 r
.45077 .31608 .45461 .33403 .46184 .33152 .45799 .31353 Mtetra
.58 .448 .665 r
.45799 .31353 .46184 .33152 .46909 .329 .46523 .31097 Mtetra
.46523 .31097 .46909 .329 .47637 .32648 .47248 .3084 Mtetra
.58 .447 .664 r
.47248 .3084 .47637 .32648 .48366 .32394 .47975 .30581 Mtetra
.47975 .30581 .48366 .32394 .49097 .3214 .48705 .30323 Mtetra
.48705 .30323 .49097 .3214 .4983 .31886 .49436 .30063 Mtetra
.49436 .30063 .4983 .31886 .50565 .3163 .50169 .29802 Mtetra
.58 .446 .663 r
.50169 .29802 .50565 .3163 .51302 .31374 .50904 .29541 Mtetra
.50904 .29541 .51302 .31374 .52041 .31118 .51642 .29278 Mtetra
.51642 .29278 .52041 .31118 .52782 .3086 .52381 .29015 Mtetra
.58 .445 .662 r
.52381 .29015 .52782 .3086 .53525 .30602 .53122 .28751 Mtetra
.53122 .28751 .53525 .30602 .5427 .30343 .53865 .28485 Mtetra
.53865 .28485 .5427 .30343 .55017 .30084 .5461 .28219 Mtetra
.58 .444 .661 r
.5461 .28219 .55017 .30084 .55766 .29823 .55357 .27952 Mtetra
.579 .444 .661 r
.55357 .27952 .55766 .29823 .56518 .29562 .56106 .27684 Mtetra
.579 .444 .66 r
.56106 .27684 .56518 .29562 .57271 .293 .56857 .27415 Mtetra
.579 .443 .66 r
.56857 .27415 .57271 .293 .58026 .29038 .5761 .27146 Mtetra
.5761 .27146 .58026 .29038 .58783 .28774 .58365 .26875 Mtetra
.579 .442 .659 r
.58365 .26875 .58783 .28774 .59542 .2851 .59122 .26603 Mtetra
.59122 .26603 .59542 .2851 .60304 .28245 .59881 .26331 Mtetra
.579 .442 .658 r
.59881 .26331 .60304 .28245 .61067 .27979 .60642 .26056 Mtetra
.579 .441 .658 r
.60642 .26056 .61067 .27979 .61833 .27711 .61406 .2578 Mtetra
.579 .441 .657 r
.61406 .2578 .61833 .27711 .626 .2744 .62171 .25501 Mtetra
.58 .441 .657 r
.62171 .25501 .626 .2744 .6337 .27162 .62938 .25215 Mtetra
.581 .441 .656 r
.62938 .25215 .6337 .27162 .64141 .26877 .63706 .24922 Mtetra
.588 .446 .655 r
.63706 .24922 .64141 .26877 .64913 .26555 .64476 .24594 Mtetra
.596 .45 .654 r
.64476 .24594 .64913 .26555 .65685 .26189 .65245 .24223 Mtetra
.607 .458 .653 r
.65245 .24223 .65685 .26189 .66455 .25756 .66014 .23788 Mtetra
.64 .479 .648 r
.66014 .23788 .66455 .25756 .67217 .25122 .66774 .23163 Mtetra
.664 .494 .645 r
.66774 .23163 .67217 .25122 .67972 .24334 .67528 .22391 Mtetra
.714 .526 .634 r
.67528 .22391 .67972 .24334 .68706 .23173 .68263 .21263 Mtetra
.766 .56 .619 r
.68263 .21263 .68706 .23173 .69412 .21546 .68972 .19691 Mtetra
.797 .582 .609 r
.68972 .19691 .69412 .21546 .70096 .19612 .69659 .17828 Mtetra
.857 .619 .578 r
.69659 .17828 .70096 .19612 .70721 .16844 .70292 .1517 Mtetra
.882 .637 .564 r
.70292 .1517 .70721 .16844 .71314 .13731 .70894 .12181 Mtetra
.92 .647 .158 r
.04149 .327 .0442 .3432 .04577 .36999 .04328 .35195 Mtetra
.822 .584 .03 r
.04328 .35195 .04577 .36999 .0478 .39452 .0455 .37474 Mtetra
0 0 .324 r
.0455 .37474 .0478 .39452 .05101 .41167 .04884 .39066 Mtetra
0 0 .455 r
.04884 .39066 .05101 .41167 .05475 .42577 .05268 .40371 Mtetra
.205 .142 .561 r
.05268 .40371 .05475 .42577 .05925 .43503 .05724 .41225 Mtetra
.386 .272 .6 r
.05724 .41225 .05925 .43503 .06442 .43992 .06244 .41673 Mtetra
.444 .313 .608 r
.06244 .41673 .06442 .43992 .06989 .44295 .06792 .41945 Mtetra
.509 .36 .615 r
.06792 .41945 .06989 .44295 .07576 .44332 .07377 .41971 Mtetra
.529 .375 .616 r
.07377 .41971 .07576 .44332 .08179 .44272 .07977 .41906 Mtetra
.541 .384 .617 r
.07977 .41906 .08179 .44272 .08792 .4415 .08588 .41783 Mtetra
.553 .393 .618 r
.08588 .41783 .08792 .4415 .09415 .43965 .09207 .41602 Mtetra
.555 .395 .619 r
.09207 .41602 .09415 .43965 .10041 .4377 .0983 .41411 Mtetra
.557 .397 .619 r
.0983 .41411 .10041 .4377 .1067 .43564 .10456 .41209 Mtetra
.559 .398 .62 r
.10456 .41209 .1067 .43564 .11302 .43351 .11084 .41 Mtetra
.11084 .41 .11302 .43351 .11935 .43136 .11714 .4079 Mtetra
.559 .399 .62 r
.11714 .4079 .11935 .43136 .1257 .42921 .12345 .40579 Mtetra
.56 .399 .621 r
.12345 .40579 .1257 .42921 .13207 .42703 .12979 .40365 Mtetra
.56 .4 .621 r
.12979 .40365 .13207 .42703 .13846 .42484 .13614 .4015 Mtetra
.13614 .4015 .13846 .42484 .14486 .42266 .1425 .39936 Mtetra
.56 .401 .622 r
.1425 .39936 .14486 .42266 .15127 .42046 .14889 .3972 Mtetra
.561 .401 .622 r
.14889 .3972 .15127 .42046 .15771 .41825 .15529 .39502 Mtetra
.56 .401 .622 r
.15529 .39502 .15771 .41825 .16416 .41605 .16171 .39284 Mtetra
.561 .402 .623 r
.16171 .39284 .16416 .41605 .17062 .41383 .16814 .39065 Mtetra
.16814 .39065 .17062 .41383 .17711 .41159 .17459 .38845 Mtetra
.17459 .38845 .17711 .41159 .18361 .40936 .18106 .38624 Mtetra
.561 .403 .623 r
.18106 .38624 .18361 .40936 .19012 .40713 .18755 .38403 Mtetra
.562 .403 .624 r
.18755 .38403 .19012 .40713 .19666 .40487 .19405 .38179 Mtetra
.19405 .38179 .19666 .40487 .20321 .40261 .20057 .37955 Mtetra
.20057 .37955 .20321 .40261 .20978 .40035 .20711 .37731 Mtetra
.562 .404 .624 r
.20711 .37731 .20978 .40035 .21636 .39807 .21367 .37505 Mtetra
.562 .404 .625 r
.21367 .37505 .21636 .39807 .22296 .39579 .22024 .37278 Mtetra
.22024 .37278 .22296 .39579 .22958 .39351 .22683 .37051 Mtetra
.563 .405 .625 r
.22683 .37051 .22958 .39351 .23622 .3912 .23343 .36822 Mtetra
.23343 .36822 .23622 .3912 .24287 .3889 .24006 .36592 Mtetra
.24006 .36592 .24287 .3889 .24954 .38659 .2467 .36362 Mtetra
.2467 .36362 .24954 .38659 .25623 .38427 .25336 .3613 Mtetra
.563 .405 .626 r
.25336 .3613 .25623 .38427 .26294 .38193 .26004 .35897 Mtetra
.563 .406 .626 r
.26004 .35897 .26294 .38193 .26966 .37961 .26673 .35665 Mtetra
.26673 .35665 .26966 .37961 .2764 .37726 .27344 .3543 Mtetra
.27344 .3543 .2764 .37726 .28316 .3749 .28017 .35194 Mtetra
.28017 .35194 .28316 .3749 .28993 .37255 .28692 .34958 Mtetra
.564 .406 .626 r
.28692 .34958 .28993 .37255 .29673 .37018 .29368 .34721 Mtetra
.29368 .34721 .29673 .37018 .30354 .3678 .30047 .34482 Mtetra
.30047 .34482 .30354 .3678 .31037 .36542 .30727 .34243 Mtetra
.564 .407 .626 r
.30727 .34243 .31037 .36542 .31721 .36304 .31408 .34004 Mtetra
.31408 .34004 .31721 .36304 .32408 .36063 .32092 .33762 Mtetra
.32092 .33762 .32408 .36063 .33096 .35823 .32777 .3352 Mtetra
.564 .407 .627 r
.32777 .3352 .33096 .35823 .33786 .35582 .33465 .33277 Mtetra
.33465 .33277 .33786 .35582 .34478 .35339 .34154 .33032 Mtetra
.34154 .33032 .34478 .35339 .35172 .35096 .34845 .32787 Mtetra
.34845 .32787 .35172 .35096 .35867 .34853 .35537 .32542 Mtetra
.565 .407 .627 r
.35537 .32542 .35867 .34853 .36565 .34607 .36232 .32294 Mtetra
.36232 .32294 .36565 .34607 .37264 .34362 .36928 .32046 Mtetra
.564 .407 .627 r
.36928 .32046 .37264 .34362 .37965 .34116 .37626 .31797 Mtetra
.565 .407 .626 r
.37626 .31797 .37965 .34116 .38668 .33869 .38326 .31547 Mtetra
.38326 .31547 .38668 .33869 .39372 .3362 .39028 .31295 Mtetra
.39028 .31295 .39372 .3362 .40079 .33372 .39732 .31044 Mtetra
.39732 .31044 .40079 .33372 .40787 .33123 .40437 .30791 Mtetra
.40437 .30791 .40787 .33123 .41498 .32871 .41145 .30536 Mtetra
.41145 .30536 .41498 .32871 .4221 .32621 .41854 .30281 Mtetra
.41854 .30281 .4221 .32621 .42924 .32369 .42565 .30025 Mtetra
.42565 .30025 .42924 .32369 .4364 .32115 .43278 .29767 Mtetra
.43278 .29767 .4364 .32115 .44358 .31862 .43993 .29509 Mtetra
.43993 .29509 .44358 .31862 .45077 .31608 .4471 .29251 Mtetra
.4471 .29251 .45077 .31608 .45799 .31353 .45428 .2899 Mtetra
.565 .407 .625 r
.45428 .2899 .45799 .31353 .46523 .31097 .46149 .28729 Mtetra
.565 .406 .625 r
.46149 .28729 .46523 .31097 .47248 .3084 .46871 .28467 Mtetra
.46871 .28467 .47248 .3084 .47975 .30581 .47596 .28203 Mtetra
.47596 .28203 .47975 .30581 .48705 .30323 .48322 .27939 Mtetra
.48322 .27939 .48705 .30323 .49436 .30063 .4905 .27673 Mtetra
.565 .406 .624 r
.4905 .27673 .49436 .30063 .50169 .29802 .4978 .27406 Mtetra
.4978 .27406 .50169 .29802 .50904 .29541 .50512 .27138 Mtetra
.565 .405 .624 r
.50512 .27138 .50904 .29541 .51642 .29278 .51246 .26869 Mtetra
.51246 .26869 .51642 .29278 .52381 .29015 .51982 .26599 Mtetra
.51982 .26599 .52381 .29015 .53122 .28751 .52719 .26328 Mtetra
.565 .405 .623 r
.52719 .26328 .53122 .28751 .53865 .28485 .53459 .26056 Mtetra
.53459 .26056 .53865 .28485 .5461 .28219 .54201 .25783 Mtetra
.565 .404 .623 r
.54201 .25783 .5461 .28219 .55357 .27952 .54944 .25508 Mtetra
.54944 .25508 .55357 .27952 .56106 .27684 .5569 .25233 Mtetra
.564 .404 .622 r
.5569 .25233 .56106 .27684 .56857 .27415 .56437 .24956 Mtetra
.56437 .24956 .56857 .27415 .5761 .27146 .57187 .24678 Mtetra
.564 .403 .622 r
.57187 .24678 .5761 .27146 .58365 .26875 .57938 .24399 Mtetra
.564 .403 .621 r
.57938 .24399 .58365 .26875 .59122 .26603 .58692 .24119 Mtetra
.58692 .24119 .59122 .26603 .59881 .26331 .59447 .23837 Mtetra
.59447 .23837 .59881 .26331 .60642 .26056 .60204 .23554 Mtetra
.564 .402 .62 r
.60204 .23554 .60642 .26056 .61406 .2578 .60964 .23269 Mtetra
.60964 .23269 .61406 .2578 .62171 .25501 .61725 .22981 Mtetra
.565 .403 .62 r
.61725 .22981 .62171 .25501 .62938 .25215 .62488 .22686 Mtetra
.566 .403 .619 r
.62488 .22686 .62938 .25215 .63706 .24922 .63253 .22384 Mtetra
.571 .406 .619 r
.63253 .22384 .63706 .24922 .64476 .24594 .64018 .22049 Mtetra
.577 .41 .618 r
.64018 .22049 .64476 .24594 .65245 .24223 .64784 .21675 Mtetra
.586 .416 .618 r
.64784 .21675 .65245 .24223 .66014 .23788 .65549 .2124 Mtetra
.611 .433 .616 r
.65549 .2124 .66014 .23788 .66774 .23163 .66307 .20629 Mtetra
.63 .446 .615 r
.66307 .20629 .66774 .23163 .67528 .22391 .67059 .1988 Mtetra
.671 .474 .61 r
.67059 .1988 .67528 .22391 .68263 .21263 .67793 .18801 Mtetra
.717 .506 .602 r
.67793 .18801 .68263 .21263 .68972 .19691 .68504 .17309 Mtetra
.747 .528 .597 r
.68504 .17309 .68972 .19691 .69659 .17828 .69195 .15545 Mtetra
.808 .57 .577 r
.69195 .15545 .69659 .17828 .70292 .1517 .69837 .1304 Mtetra
.838 .592 .568 r
.69837 .1304 .70292 .1517 .70894 .12181 .7045 .10225 Mtetra
.817 .585 .029 r
.03915 .30859 .04149 .327 .04328 .35195 .0412 .33136 Mtetra
0 0 .128 r
.0412 .33136 .04328 .35195 .0455 .37474 .04367 .35214 Mtetra
0 0 .422 r
.04367 .35214 .0455 .37474 .04884 .39066 .04717 .36659 Mtetra
.073 .032 .5 r
.04717 .36659 .04884 .39066 .05268 .40371 .05114 .37842 Mtetra
.287 .186 .561 r
.05114 .37842 .05268 .40371 .05724 .41225 .05577 .38612 Mtetra
.416 .28 .586 r
.05577 .38612 .05724 .41225 .06244 .41673 .06099 .39009 Mtetra
.46 .311 .592 r
.06099 .39009 .06244 .41673 .06792 .41945 .06648 .39247 Mtetra
.51 .348 .598 r
.06648 .39247 .06792 .41945 .07377 .41971 .07231 .39259 Mtetra
.526 .361 .599 r
.07231 .39259 .07377 .41971 .07977 .41906 .07829 .39187 Mtetra
.536 .368 .6 r
.07829 .39187 .07977 .41906 .08588 .41783 .08436 .39062 Mtetra
.546 .375 .601 r
.08436 .39062 .08588 .41783 .09207 .41602 .09051 .38884 Mtetra
.547 .377 .602 r
.09051 .38884 .09207 .41602 .0983 .41411 .0967 .38697 Mtetra
.549 .378 .602 r
.0967 .38697 .0983 .41411 .10456 .41209 .10291 .38499 Mtetra
.55 .379 .602 r
.10291 .38499 .10456 .41209 .11084 .41 .10915 .38295 Mtetra
.551 .38 .603 r
.10915 .38295 .11084 .41 .11714 .4079 .11541 .3809 Mtetra
.11541 .3809 .11714 .4079 .12345 .40579 .12169 .37882 Mtetra
.551 .381 .603 r
.12169 .37882 .12345 .40579 .12979 .40365 .12798 .37673 Mtetra
.552 .381 .604 r
.12798 .37673 .12979 .40365 .13614 .4015 .13429 .37462 Mtetra
.13429 .37462 .13614 .4015 .1425 .39936 .14062 .37252 Mtetra
.552 .382 .604 r
.14062 .37252 .1425 .39936 .14889 .3972 .14696 .37039 Mtetra
.14696 .37039 .14889 .3972 .15529 .39502 .15332 .36825 Mtetra
.552 .382 .605 r
.15332 .36825 .15529 .39502 .16171 .39284 .1597 .3661 Mtetra
.553 .383 .605 r
.1597 .3661 .16171 .39284 .16814 .39065 .1661 .36394 Mtetra
.1661 .36394 .16814 .39065 .17459 .38845 .17251 .36176 Mtetra
.17251 .36176 .17459 .38845 .18106 .38624 .17894 .35958 Mtetra
.553 .384 .606 r
.17894 .35958 .18106 .38624 .18755 .38403 .18539 .35739 Mtetra
.18539 .35739 .18755 .38403 .19405 .38179 .19185 .35518 Mtetra
.19185 .35518 .19405 .38179 .20057 .37955 .19834 .35296 Mtetra
.554 .384 .606 r
.19834 .35296 .20057 .37955 .20711 .37731 .20484 .35074 Mtetra
.554 .385 .606 r
.20484 .35074 .20711 .37731 .21367 .37505 .21135 .34849 Mtetra
.554 .385 .607 r
.21135 .34849 .21367 .37505 .22024 .37278 .21789 .34624 Mtetra
.21789 .34624 .22024 .37278 .22683 .37051 .22444 .34398 Mtetra
.22444 .34398 .22683 .37051 .23343 .36822 .23101 .3417 Mtetra
.555 .386 .607 r
.23101 .3417 .23343 .36822 .24006 .36592 .2376 .33941 Mtetra
.2376 .33941 .24006 .36592 .2467 .36362 .2442 .33712 Mtetra
.2442 .33712 .2467 .36362 .25336 .3613 .25083 .3348 Mtetra
.25083 .3348 .25336 .3613 .26004 .35897 .25747 .33248 Mtetra
.555 .386 .608 r
.25747 .33248 .26004 .35897 .26673 .35665 .26412 .33015 Mtetra
.555 .387 .608 r
.26412 .33015 .26673 .35665 .27344 .3543 .2708 .3278 Mtetra
.2708 .3278 .27344 .3543 .28017 .35194 .27749 .32544 Mtetra
.27749 .32544 .28017 .35194 .28692 .34958 .2842 .32308 Mtetra
.556 .387 .608 r
.2842 .32308 .28692 .34958 .29368 .34721 .29093 .3207 Mtetra
.29093 .3207 .29368 .34721 .30047 .34482 .29768 .3183 Mtetra
.29768 .3183 .30047 .34482 .30727 .34243 .30445 .3159 Mtetra
.30445 .3159 .30727 .34243 .31408 .34004 .31123 .31349 Mtetra
.556 .388 .608 r
.31123 .31349 .31408 .34004 .32092 .33762 .31803 .31106 Mtetra
.31803 .31106 .32092 .33762 .32777 .3352 .32485 .30862 Mtetra
.32485 .30862 .32777 .3352 .33465 .33277 .33168 .30618 Mtetra
.557 .388 .608 r
.33168 .30618 .33465 .33277 .34154 .33032 .33854 .30371 Mtetra
.556 .388 .608 r
.33854 .30371 .34154 .33032 .34845 .32787 .34541 .30124 Mtetra
.34541 .30124 .34845 .32787 .35537 .32542 .3523 .29876 Mtetra
.557 .388 .608 r
.3523 .29876 .35537 .32542 .36232 .32294 .35921 .29626 Mtetra
.35921 .29626 .36232 .32294 .36928 .32046 .36614 .29374 Mtetra
.36614 .29374 .36928 .32046 .37626 .31797 .37308 .29123 Mtetra
.37308 .29123 .37626 .31797 .38326 .31547 .38005 .28869 Mtetra
.38005 .28869 .38326 .31547 .39028 .31295 .38703 .28614 Mtetra
.38703 .28614 .39028 .31295 .39732 .31044 .39403 .28359 Mtetra
.39403 .28359 .39732 .31044 .40437 .30791 .40105 .28102 Mtetra
.40105 .28102 .40437 .30791 .41145 .30536 .40808 .27844 Mtetra
.40808 .27844 .41145 .30536 .41854 .30281 .41514 .27585 Mtetra
.41514 .27585 .41854 .30281 .42565 .30025 .42221 .27324 Mtetra
.42221 .27324 .42565 .30025 .43278 .29767 .42931 .27062 Mtetra
.42931 .27062 .43278 .29767 .43993 .29509 .43642 .26799 Mtetra
.43642 .26799 .43993 .29509 .4471 .29251 .44355 .26536 Mtetra
.557 .388 .607 r
.44355 .26536 .4471 .29251 .45428 .2899 .45069 .2627 Mtetra
.45069 .2627 .45428 .2899 .46149 .28729 .45786 .26003 Mtetra
.45786 .26003 .46149 .28729 .46871 .28467 .46505 .25736 Mtetra
.558 .388 .607 r
.46505 .25736 .46871 .28467 .47596 .28203 .47225 .25466 Mtetra
.47225 .25466 .47596 .28203 .48322 .27939 .47947 .25196 Mtetra
.47947 .25196 .48322 .27939 .4905 .27673 .48671 .24924 Mtetra
.558 .387 .607 r
.48671 .24924 .4905 .27673 .4978 .27406 .49397 .24651 Mtetra
.558 .387 .606 r
.49397 .24651 .4978 .27406 .50512 .27138 .50125 .24376 Mtetra
.50125 .24376 .50512 .27138 .51246 .26869 .50855 .24101 Mtetra
.50855 .24101 .51246 .26869 .51982 .26599 .51587 .23823 Mtetra
.51587 .23823 .51982 .26599 .52719 .26328 .5232 .23545 Mtetra
.5232 .23545 .52719 .26328 .53459 .26056 .53056 .23265 Mtetra
.53056 .23265 .53459 .26056 .54201 .25783 .53793 .22984 Mtetra
.558 .386 .605 r
.53793 .22984 .54201 .25783 .54944 .25508 .54532 .22702 Mtetra
.54532 .22702 .54944 .25508 .5569 .25233 .55274 .22418 Mtetra
.55274 .22418 .5569 .25233 .56437 .24956 .56017 .22133 Mtetra
.56017 .22133 .56437 .24956 .57187 .24678 .56762 .21847 Mtetra
.558 .386 .604 r
.56762 .21847 .57187 .24678 .57938 .24399 .57509 .21559 Mtetra
.57509 .21559 .57938 .24399 .58692 .24119 .58257 .2127 Mtetra
.557 .385 .604 r
.58257 .2127 .58692 .24119 .59447 .23837 .59008 .2098 Mtetra
.558 .385 .604 r
.59008 .2098 .59447 .23837 .60204 .23554 .59761 .20687 Mtetra
.558 .385 .603 r
.59761 .20687 .60204 .23554 .60964 .23269 .60515 .20393 Mtetra
.60515 .20393 .60964 .23269 .61725 .22981 .61272 .20095 Mtetra
.559 .385 .603 r
.61272 .20095 .61725 .22981 .62488 .22686 .6203 .19791 Mtetra
.559 .385 .602 r
.6203 .19791 .62488 .22686 .63253 .22384 .6279 .1948 Mtetra
.563 .388 .602 r
.6279 .1948 .63253 .22384 .64018 .22049 .6355 .19139 Mtetra
.568 .391 .602 r
.6355 .19139 .64018 .22049 .64784 .21675 .64311 .18762 Mtetra
.575 .396 .601 r
.64311 .18762 .64784 .21675 .65549 .2124 .65072 .18329 Mtetra
.596 .41 .601 r
.65072 .18329 .65549 .2124 .66307 .20629 .65826 .17734 Mtetra
.612 .422 .6 r
.65826 .17734 .66307 .20629 .67059 .1988 .66575 .17015 Mtetra
.648 .446 .597 r
.66575 .17015 .67059 .1988 .67793 .18801 .67309 .15994 Mtetra
.689 .476 .593 r
.67309 .15994 .67793 .18801 .68504 .17309 .68021 .14595 Mtetra
.716 .496 .59 r
.68021 .14595 .68504 .17309 .69195 .15545 .68716 .12947 Mtetra
.776 .538 .576 r
.68716 .12947 .69195 .15545 .69837 .1304 .69367 .10621 Mtetra
.806 .562 .57 r
.69367 .10621 .69837 .1304 .7045 .10225 .69992 .0801 Mtetra
0 0 .233 r
.03761 .28517 .03915 .30859 .0412 .33136 .04005 .30502 Mtetra
0 0 .354 r
.04005 .30502 .0412 .33136 .04367 .35214 .04285 .32309 Mtetra
.143 .06 .494 r
.04285 .32309 .04367 .35214 .04717 .36659 .04659 .33558 Mtetra
.258 .142 .524 r
.04659 .33558 .04717 .36659 .05114 .37842 .05074 .34576 Mtetra
.375 .228 .55 r
.05074 .34576 .05114 .37842 .05577 .38612 .05548 .35231 Mtetra
.451 .284 .563 r
.05548 .35231 .05577 .38612 .06099 .39009 .06075 .35559 Mtetra
.478 .304 .567 r
.06075 .35559 .06099 .39009 .06648 .39247 .06625 .35747 Mtetra
.511 .33 .571 r
.06625 .35747 .06648 .39247 .07231 .39259 .07206 .35737 Mtetra
.522 .338 .573 r
.07206 .35737 .07231 .39259 .07829 .39187 .078 .35654 Mtetra
.528 .343 .574 r
.078 .35654 .07829 .39187 .08436 .39062 .08402 .35523 Mtetra
.535 .348 .575 r
.08402 .35523 .08436 .39062 .09051 .38884 .09013 .35346 Mtetra
.536 .349 .575 r
.09013 .35346 .09051 .38884 .0967 .38697 .09626 .35161 Mtetra
.537 .35 .575 r
.09626 .35161 .0967 .38697 .10291 .38499 .10242 .34966 Mtetra
.538 .351 .575 r
.10242 .34966 .10291 .38499 .10915 .38295 .1086 .34765 Mtetra
.539 .351 .575 r
.1086 .34765 .10915 .38295 .11541 .3809 .1148 .34563 Mtetra
.539 .352 .576 r
.1148 .34563 .11541 .3809 .12169 .37882 .12102 .34359 Mtetra
.12102 .34359 .12169 .37882 .12798 .37673 .12726 .34152 Mtetra
.12726 .34152 .12798 .37673 .13429 .37462 .13352 .33945 Mtetra
.13352 .33945 .13429 .37462 .14062 .37252 .13979 .33736 Mtetra
.54 .353 .576 r
.13979 .33736 .14062 .37252 .14696 .37039 .14608 .33526 Mtetra
.14608 .33526 .14696 .37039 .15332 .36825 .15239 .33314 Mtetra
.54 .353 .577 r
.15239 .33314 .15332 .36825 .1597 .3661 .15871 .33102 Mtetra
.15871 .33102 .1597 .3661 .1661 .36394 .16505 .32888 Mtetra
.54 .354 .577 r
.16505 .32888 .1661 .36394 .17251 .36176 .17141 .32672 Mtetra
.17141 .32672 .17251 .36176 .17894 .35958 .17779 .32456 Mtetra
.17779 .32456 .17894 .35958 .18539 .35739 .18418 .32238 Mtetra
.541 .354 .577 r
.18418 .32238 .18539 .35739 .19185 .35518 .19059 .32019 Mtetra
.19059 .32019 .19185 .35518 .19834 .35296 .19702 .31798 Mtetra
.541 .355 .578 r
.19702 .31798 .19834 .35296 .20484 .35074 .20347 .31577 Mtetra
.20347 .31577 .20484 .35074 .21135 .34849 .20993 .31353 Mtetra
.20993 .31353 .21135 .34849 .21789 .34624 .21641 .31128 Mtetra
.21641 .31128 .21789 .34624 .22444 .34398 .22291 .30903 Mtetra
.542 .355 .578 r
.22291 .30903 .22444 .34398 .23101 .3417 .22943 .30675 Mtetra
.22943 .30675 .23101 .3417 .2376 .33941 .23596 .30446 Mtetra
.542 .356 .578 r
.23596 .30446 .2376 .33941 .2442 .33712 .24251 .30217 Mtetra
.24251 .30217 .2442 .33712 .25083 .3348 .24908 .29986 Mtetra
.24908 .29986 .25083 .3348 .25747 .33248 .25567 .29753 Mtetra
.25567 .29753 .25747 .33248 .26412 .33015 .26228 .29519 Mtetra
.26228 .29519 .26412 .33015 .2708 .3278 .2689 .29284 Mtetra
.2689 .29284 .2708 .3278 .27749 .32544 .27554 .29047 Mtetra
.542 .356 .579 r
.27554 .29047 .27749 .32544 .2842 .32308 .2822 .2881 Mtetra
.543 .357 .579 r
.2822 .2881 .2842 .32308 .29093 .3207 .28887 .28571 Mtetra
.28887 .28571 .29093 .3207 .29768 .3183 .29557 .2833 Mtetra
.29557 .2833 .29768 .3183 .30445 .3159 .30228 .28088 Mtetra
.30228 .28088 .30445 .3159 .31123 .31349 .30901 .27845 Mtetra
.30901 .27845 .31123 .31349 .31803 .31106 .31575 .276 Mtetra
.31575 .276 .31803 .31106 .32485 .30862 .32252 .27354 Mtetra
.32252 .27354 .32485 .30862 .33168 .30618 .3293 .27108 Mtetra
.3293 .27108 .33168 .30618 .33854 .30371 .3361 .26859 Mtetra
.3361 .26859 .33854 .30371 .34541 .30124 .34292 .26609 Mtetra
.34292 .26609 .34541 .30124 .3523 .29876 .34976 .26358 Mtetra
.544 .357 .579 r
.34976 .26358 .3523 .29876 .35921 .29626 .35661 .26105 Mtetra
.35661 .26105 .35921 .29626 .36614 .29374 .36348 .25851 Mtetra
.36348 .25851 .36614 .29374 .37308 .29123 .37037 .25596 Mtetra
.544 .358 .579 r
.37037 .25596 .37308 .29123 .38005 .28869 .37728 .25339 Mtetra
.37728 .25339 .38005 .28869 .38703 .28614 .38421 .2508 Mtetra
.38421 .2508 .38703 .28614 .39403 .28359 .39115 .24821 Mtetra
.39115 .24821 .39403 .28359 .40105 .28102 .39811 .2456 Mtetra
.39811 .2456 .40105 .28102 .40808 .27844 .4051 .24297 Mtetra
.4051 .24297 .40808 .27844 .41514 .27585 .41209 .24034 Mtetra
.41209 .24034 .41514 .27585 .42221 .27324 .41911 .23769 Mtetra
.41911 .23769 .42221 .27324 .42931 .27062 .42615 .23502 Mtetra
.42615 .23502 .42931 .27062 .43642 .26799 .4332 .23234 Mtetra
.4332 .23234 .43642 .26799 .44355 .26536 .44027 .22966 Mtetra
.545 .358 .578 r
.44027 .22966 .44355 .26536 .45069 .2627 .44736 .22695 Mtetra
.44736 .22695 .45069 .2627 .45786 .26003 .45447 .22423 Mtetra
.45447 .22423 .45786 .26003 .46505 .25736 .4616 .22149 Mtetra
.4616 .22149 .46505 .25736 .47225 .25466 .46874 .21874 Mtetra
.46874 .21874 .47225 .25466 .47947 .25196 .4759 .21597 Mtetra
.4759 .21597 .47947 .25196 .48671 .24924 .48309 .2132 Mtetra
.48309 .2132 .48671 .24924 .49397 .24651 .49029 .2104 Mtetra
.49029 .2104 .49397 .24651 .50125 .24376 .4975 .20759 Mtetra
.4975 .20759 .50125 .24376 .50855 .24101 .50474 .20477 Mtetra
.50474 .20477 .50855 .24101 .51587 .23823 .51199 .20193 Mtetra
.51199 .20193 .51587 .23823 .5232 .23545 .51927 .19908 Mtetra
.545 .357 .577 r
.51927 .19908 .5232 .23545 .53056 .23265 .52656 .19621 Mtetra
.52656 .19621 .53056 .23265 .53793 .22984 .53387 .19332 Mtetra
.53387 .19332 .53793 .22984 .54532 .22702 .5412 .19043 Mtetra
.5412 .19043 .54532 .22702 .55274 .22418 .54855 .18751 Mtetra
.54855 .18751 .55274 .22418 .56017 .22133 .55591 .18458 Mtetra
.55591 .18458 .56017 .22133 .56762 .21847 .56329 .18164 Mtetra
.56329 .18164 .56762 .21847 .57509 .21559 .5707 .17867 Mtetra
.5707 .17867 .57509 .21559 .58257 .2127 .57812 .1757 Mtetra
.545 .357 .576 r
.57812 .1757 .58257 .2127 .59008 .2098 .58556 .17271 Mtetra
.58556 .17271 .59008 .2098 .59761 .20687 .59302 .1697 Mtetra
.59302 .1697 .59761 .20687 .60515 .20393 .60049 .16667 Mtetra
.546 .357 .576 r
.60049 .16667 .60515 .20393 .61272 .20095 .60799 .1636 Mtetra
.60799 .1636 .61272 .20095 .6203 .19791 .6155 .16047 Mtetra
.547 .357 .576 r
.6155 .16047 .6203 .19791 .6279 .1948 .62303 .15729 Mtetra
.55 .359 .576 r
.62303 .15729 .6279 .1948 .6355 .19139 .63056 .15384 Mtetra
.553 .362 .576 r
.63056 .15384 .6355 .19139 .64311 .18762 .63811 .15006 Mtetra
.558 .365 .576 r
.63811 .15006 .64311 .18762 .65072 .18329 .64564 .1458 Mtetra
.573 .376 .576 r
.64564 .1458 .65072 .18329 .65826 .17734 .65313 .14013 Mtetra
.585 .384 .576 r
.65313 .14013 .65826 .17734 .66575 .17015 .66058 .13335 Mtetra
.611 .404 .575 r
.66058 .13335 .66575 .17015 .67309 .15994 .6679 .12395 Mtetra
.644 .427 .574 r
.6679 .12395 .67309 .15994 .68021 .14595 .67503 .11123 Mtetra
.667 .445 .574 r
.67503 .11123 .68021 .14595 .68716 .12947 .68202 .09633 Mtetra
.719 .484 .569 r
.68202 .09633 .68716 .12947 .69367 .10621 .68863 .07548 Mtetra
.748 .508 .567 r
.68863 .07548 .69367 .10621 .69992 .0801 .69501 .0521 Mtetra
0 0 .363 r
.03634 .26033 .03761 .28517 .04005 .30502 .03919 .27709 Mtetra
0 0 .437 r
.03919 .27709 .04005 .30502 .04285 .32309 .04237 .29228 Mtetra
.243 .129 .518 r
.04237 .29228 .04285 .32309 .04659 .33558 .04636 .3027 Mtetra
.324 .186 .534 r
.04636 .3027 .04659 .33558 .05074 .34576 .05071 .31113 Mtetra
.409 .249 .55 r
.05071 .31113 .05074 .34576 .05548 .35231 .05557 .31645 Mtetra
.466 .291 .56 r
.05557 .31645 .05548 .35231 .06075 .35559 .06089 .31899 Mtetra
.487 .307 .562 r
.06089 .31899 .06075 .35559 .06625 .35747 .06641 .32032 Mtetra
.513 .327 .566 r
.06641 .32032 .06625 .35747 .07206 .35737 .0722 .31998 Mtetra
.521 .333 .567 r
.0722 .31998 .07206 .35737 .078 .35654 .0781 .319 Mtetra
.527 .338 .567 r
.0781 .319 .078 .35654 .08402 .35523 .08408 .31762 Mtetra
.532 .342 .568 r
.08408 .31762 .08402 .35523 .09013 .35346 .09013 .31584 Mtetra
.533 .343 .568 r
.09013 .31584 .09013 .35346 .09626 .35161 .09621 .31399 Mtetra
.534 .343 .568 r
.09621 .31399 .09626 .35161 .10242 .34966 .10231 .31205 Mtetra
.535 .344 .569 r
.10231 .31205 .10242 .34966 .1086 .34765 .10843 .31006 Mtetra
.10843 .31006 .1086 .34765 .1148 .34563 .11458 .30805 Mtetra
.11458 .30805 .1148 .34563 .12102 .34359 .12074 .30603 Mtetra
.536 .345 .569 r
.12074 .30603 .12102 .34359 .12726 .34152 .12692 .30398 Mtetra
.12692 .30398 .12726 .34152 .13352 .33945 .13312 .30192 Mtetra
.13312 .30192 .13352 .33945 .13979 .33736 .13933 .29985 Mtetra
.13933 .29985 .13979 .33736 .14608 .33526 .14556 .29776 Mtetra
.536 .346 .569 r
.14556 .29776 .14608 .33526 .15239 .33314 .15181 .29565 Mtetra
.536 .346 .57 r
.15181 .29565 .15239 .33314 .15871 .33102 .15808 .29353 Mtetra
.15808 .29353 .15871 .33102 .16505 .32888 .16436 .2914 Mtetra
.537 .346 .57 r
.16436 .2914 .16505 .32888 .17141 .32672 .17066 .28925 Mtetra
.17066 .28925 .17141 .32672 .17779 .32456 .17698 .2871 Mtetra
.17698 .2871 .17779 .32456 .18418 .32238 .18332 .28492 Mtetra
.537 .347 .57 r
.18332 .28492 .18418 .32238 .19059 .32019 .18967 .28273 Mtetra
.18967 .28273 .19059 .32019 .19702 .31798 .19604 .28053 Mtetra
.19604 .28053 .19702 .31798 .20347 .31577 .20243 .27831 Mtetra
.538 .347 .57 r
.20243 .27831 .20347 .31577 .20993 .31353 .20884 .27607 Mtetra
.20884 .27607 .20993 .31353 .21641 .31128 .21526 .27383 Mtetra
.21526 .27383 .21641 .31128 .22291 .30903 .2217 .27157 Mtetra
.538 .348 .571 r
.2217 .27157 .22291 .30903 .22943 .30675 .22816 .26929 Mtetra
.22816 .26929 .22943 .30675 .23596 .30446 .23464 .267 Mtetra
.23464 .267 .23596 .30446 .24251 .30217 .24113 .2647 Mtetra
.24113 .2647 .24251 .30217 .24908 .29986 .24764 .26237 Mtetra
.539 .348 .571 r
.24764 .26237 .24908 .29986 .25567 .29753 .25417 .26004 Mtetra
.25417 .26004 .25567 .29753 .26228 .29519 .26072 .25769 Mtetra
.26072 .25769 .26228 .29519 .2689 .29284 .26728 .25533 Mtetra
.26728 .25533 .2689 .29284 .27554 .29047 .27386 .25295 Mtetra
.539 .349 .571 r
.27386 .25295 .27554 .29047 .2822 .2881 .28046 .25056 Mtetra
.28046 .25056 .2822 .2881 .28887 .28571 .28708 .24815 Mtetra
.28708 .24815 .28887 .28571 .29557 .2833 .29371 .24572 Mtetra
.29371 .24572 .29557 .2833 .30228 .28088 .30037 .24329 Mtetra
.30037 .24329 .30228 .28088 .30901 .27845 .30704 .24084 Mtetra
.54 .349 .571 r
.30704 .24084 .30901 .27845 .31575 .276 .31372 .23837 Mtetra
.31372 .23837 .31575 .276 .32252 .27354 .32043 .23589 Mtetra
.32043 .23589 .32252 .27354 .3293 .27108 .32715 .2334 Mtetra
.32715 .2334 .3293 .27108 .3361 .26859 .33389 .23088 Mtetra
.33389 .23088 .3361 .26859 .34292 .26609 .34065 .22835 Mtetra
.34065 .22835 .34292 .26609 .34976 .26358 .34743 .22582 Mtetra
.54 .35 .571 r
.34743 .22582 .34976 .26358 .35661 .26105 .35422 .22326 Mtetra
.35422 .22326 .35661 .26105 .36348 .25851 .36103 .22069 Mtetra
.36103 .22069 .36348 .25851 .37037 .25596 .36786 .21811 Mtetra
.541 .35 .571 r
.36786 .21811 .37037 .25596 .37728 .25339 .37471 .2155 Mtetra
.37471 .2155 .37728 .25339 .38421 .2508 .38158 .21288 Mtetra
.38158 .21288 .38421 .2508 .39115 .24821 .38846 .21026 Mtetra
.38846 .21026 .39115 .24821 .39811 .2456 .39536 .20761 Mtetra
.39536 .20761 .39811 .2456 .4051 .24297 .40228 .20494 Mtetra
.40228 .20494 .4051 .24297 .41209 .24034 .40921 .20227 Mtetra
.40921 .20227 .41209 .24034 .41911 .23769 .41617 .19958 Mtetra
.41617 .19958 .41911 .23769 .42615 .23502 .42314 .19687 Mtetra
.42314 .19687 .42615 .23502 .4332 .23234 .43013 .19415 Mtetra
.43013 .19415 .4332 .23234 .44027 .22966 .43714 .19141 Mtetra
.43714 .19141 .44027 .22966 .44736 .22695 .44416 .18866 Mtetra
.44416 .18866 .44736 .22695 .45447 .22423 .45121 .18589 Mtetra
.45121 .18589 .45447 .22423 .4616 .22149 .45827 .1831 Mtetra
.542 .35 .571 r
.45827 .1831 .4616 .22149 .46874 .21874 .46535 .1803 Mtetra
.46535 .1803 .46874 .21874 .4759 .21597 .47244 .17748 Mtetra
.47244 .17748 .4759 .21597 .48309 .2132 .47956 .17465 Mtetra
.47956 .17465 .48309 .2132 .49029 .2104 .48669 .1718 Mtetra
.48669 .1718 .49029 .2104 .4975 .20759 .49384 .16894 Mtetra
.49384 .16894 .4975 .20759 .50474 .20477 .50101 .16606 Mtetra
.50101 .16606 .50474 .20477 .51199 .20193 .5082 .16316 Mtetra
.542 .35 .57 r
.5082 .16316 .51199 .20193 .51927 .19908 .5154 .16025 Mtetra
.5154 .16025 .51927 .19908 .52656 .19621 .52263 .15732 Mtetra
.52263 .15732 .52656 .19621 .53387 .19332 .52987 .15437 Mtetra
.52987 .15437 .53387 .19332 .5412 .19043 .53713 .15141 Mtetra
.53713 .15141 .5412 .19043 .54855 .18751 .5444 .14843 Mtetra
.5444 .14843 .54855 .18751 .55591 .18458 .5517 .14544 Mtetra
.5517 .14544 .55591 .18458 .56329 .18164 .55901 .14243 Mtetra
.55901 .14243 .56329 .18164 .5707 .17867 .56634 .1394 Mtetra
.543 .35 .57 r
.56634 .1394 .5707 .17867 .57812 .1757 .57369 .13635 Mtetra
.57369 .13635 .57812 .1757 .58556 .17271 .58105 .13329 Mtetra
.58105 .13329 .58556 .17271 .59302 .1697 .58844 .13021 Mtetra
.543 .35 .569 r
.58844 .13021 .59302 .1697 .60049 .16667 .59584 .12711 Mtetra
.59584 .12711 .60049 .16667 .60799 .1636 .60326 .12397 Mtetra
.60326 .12397 .60799 .1636 .6155 .16047 .61069 .12078 Mtetra
.544 .351 .569 r
.61069 .12078 .6155 .16047 .62303 .15729 .61815 .11754 Mtetra
.546 .352 .569 r
.61815 .11754 .62303 .15729 .63056 .15384 .62561 .11406 Mtetra
.549 .354 .569 r
.62561 .11406 .63056 .15384 .63811 .15006 .63308 .11031 Mtetra
.553 .357 .569 r
.63308 .11031 .63811 .15006 .64564 .1458 .64054 .10614 Mtetra
.566 .366 .569 r
.64054 .10614 .64564 .1458 .65313 .14013 .64798 .10077 Mtetra
.575 .373 .57 r
.64798 .10077 .65313 .14013 .66058 .13335 .65537 .09447 Mtetra
.598 .39 .57 r
.65537 .09447 .66058 .13335 .6679 .12395 .66266 .08591 Mtetra
.625 .41 .57 r
.66266 .08591 .6679 .12395 .67503 .11123 .66981 .07455 Mtetra
.645 .426 .571 r
.66981 .07455 .67503 .11123 .68202 .09633 .67683 .06131 Mtetra
.692 .461 .568 r
.67683 .06131 .68202 .09633 .68863 .07548 .68353 .043 Mtetra
.72 .484 .568 r
.68353 .043 .68863 .07548 .69501 .0521 .69004 .0225 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.1578 .2079 m
.1624 .21257 L
s
[(-5)] .14858 .19855 .98554 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54221 .05738 m
.54611 .06265 L
s
[(5)] .53441 .04682 .73893 1 Mshowa
.125 Mabswid
.19381 .1938 m
.19654 .19664 L
s
.23033 .1795 m
.23302 .18237 L
s
.26737 .16499 m
.27003 .1679 L
s
.30495 .15028 m
.30756 .15322 L
s
.38174 .12021 m
.38426 .12323 L
s
.42097 .10485 m
.42346 .1079 L
s
.46079 .08926 m
.46322 .09235 L
s
.5012 .07344 m
.50358 .07656 L
s
.12228 .22181 m
.12508 .22458 L
s
.08725 .23552 m
.09008 .23826 L
s
.0527 .24905 m
.05557 .25175 L
s
.58384 .04107 m
.58613 .04428 L
s
.62611 .02452 m
.62834 .02776 L
s
.66902 .00772 m
.6712 .011 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[80]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00boooool2o`0005?ooooo0038ooooo`?o000000?o
ooooo`000?ooool0D_ooool00<Kooooo0_l00004ooooo`;o0000D_ooool00<?ooooo0ol00002oooo
o`07o`000?ooooooooooooooool0003oooooo`00001Aooooo`00Woooool3o`0001kooooo0ol00009
ooooo`04o`000?oooooo0000o`00053ooooo002Nooooo`05o`000?ooooooooooooooool000006ooo
ool2o`0000cooooo00Co0000oooooooooooo0000D?ooool00:;ooooo00?o0000ooooooooool05_oo
ool3o`0000kooooo00Go0000ooooooooooooooooo`00001?ooooo`00X_ooool00ol0003ooooooooo
o`0Dooooo`;o000000?oooooo`000?ooool03_ooool01Ol0003ooooooooooooooooo000004oooooo
002Nooooo`Co00005?ooool3o`0001?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1<ooooo`00W_ooool00ol0003oooooooooo`0Cooooo`;o00005_ooool00onhNi7o0000ooooo`03
ooooo`03o`000?oooooooooo04_ooooo002Nooooo`Go00003_ooool3o`0001Sooooo00?o^7^Ao`00
0?ooool00oooool00ol0003oooooooooo`1;ooooo`00[_ooool4o`0001[ooooo00?o^7^Ao`000?oo
ool01?ooool00ol0003oooooooooo`1:ooooo`00[?ooool2o`0000?ooooo00?o0000ooooooooool0
5oooool2okQkT@03o`000?oooooooooo00?ooooo0_l0001;ooooo`00ZOooool3o`0001oooooo0_nh
Ni400ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Wooooo002Wooooo`;o00008Oooool0
1?naMY7o^7^AokQkTOl00007ooooo`03o`000?oooooooooo04Sooooo002Tooooo`?o00008oooool0
1?naMY7o^7^AokQkTOl00007ooooo`03o`000?oooooooooo04Sooooo002Rooooo`;o00000_ooool0
0ol0003oooooooooo`0Qooooo`;o/GJA00?o^7^Ao`000?ooool01oooool00ol0003oooooooooo`17
ooooo`00Woooool3o`0000Gooooo00?o0000ooooooooool07oooool3ok5fT@03okQkTOl0003ooooo
00Sooooo00?o0000ooooooooool0A_ooool009gooooo0_l0000Zooooo`?o/GJA00?o^7^Ao`000?no
PY402?ooool00ol0003oooooooooo`16ooooo`00V_ooool3o`0002_ooooo0_nUKI82ok5fT@03okQk
TOl0003o_h:A00Wooooo00?o0000ooooooooool0AOooool009Oooooo0ol000000ooooooo0000oooo
o`0[ooooo`;oYFfB0_naMY400onoPY7o0000okn2T@09ooooo`;o0000A_ooool009Gooooo0_l0000`
ooooo`?oYFfB0_naMY400onoPY7o0000okn2T@0:ooooo`03o`000?oooooooooo04Cooooo002Boooo
o`?o0000<_ooool3ojE]TP;o/GJA00?o_h:Ao`000?noPY402oooool00ol0003oooooooooo`0;oooo
o`?o0000=Oooool0093ooooo0_l0000dooooo`;oWfRA0_nUKI82ok5fT@04okQkTOl0003o_h:Aolj?
T@_ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000003Cooooo002=oooo
o`Go0000<oooool3oimXT@?oYFfB0_nhNi400ol0003o_h:Aolj?T@0;ooooo`03o`000?oooooooooo
00?ooooo1Ol00005ooooo`03o`000?oooooooooo03;ooooo001[ooooo`;o00007_ooool2o`0003So
oooo0onOJ943ojE]TP;o^7^A00?o_h:Ao`000?o>Si403?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03;ooooo001Zooooo`04o`000?ooooooooooo`0001[ooooo0ol0000iooooo`;o
VF>A0_nOJ943ojE]TP;o^7^A00Co_h:Ao`000?o>Si7ocXnA3?ooool00ol0003oooooooooo`07oooo
o`Co0000=Oooool006[ooooo00Co0000oooooooooooo00005oooool3o`0003_ooooo00?oTenAoiUS
TOnIHi400_nOJ943ojE]TP?o^7^A00?o0000olj?TOo>Si403?ooool2o`0000Sooooo00?o0000oooo
ooooool0=_ooool006[ooooo00Co0000oooooooooooo00005Oooool2o`000003ooooool0003ooooo
03Wooooo00?oT5fAoi=OTOnCGi400_nIHi43oimXT@03ojE]T_nZLI;o^7^A00;o^7^A00?o0000olj?
TOo>Si403?ooool2o`0000Sooooo1Ol0000dooooo`00J_ooool01?l0003oooooooooool0000Boooo
o`?o00000oooool00ol0003oooooooooo`0fooooo`03oheKTOn@GI7oT5fA00;oTenA0_nIHi43oimX
T@03ojE]T_nZLI;o^7^A00;o^7^A00?o0000olj?TOo>Si403_ooool00ol0003oooooooooo`0noooo
o`00J_ooool01?l0003oooooooooool0000@ooooo`;o0000?Oooool00on<FY7oSE^AoheKT@02oi1M
T@;oTenA0_nIHi43oimXT@?oZW6B0_nhNi401?l0003ocXnAolj?TOoFUi4=ooooo`03o`000?oooooo
oooo03kooooo001[ooooo`;o00003_ooool3o`0003gooooo00?oReZAohaJTOn<FY400_n=Fi42oi1M
T@?oTenA0_nIHi42oimXT@?oZW6B00Co^7^AolJ9Tol0003ocXnA0_oFUi4>ooooo`03o`000?oooooo
oooo03gooooo001iooooo`?o0000?Oooool00on;FI7oReZAoh]JT@02ohaJT@;oSE^A0_n@GI43oi=O
T@;oVF>A00?oWfRAojA]T_nZLI800_nZLI801?nhNi7oaXVCo`000?o>Si42omJGT@oooooo00?o0000
ooooooooool0??ooool007Kooooo0ol00003ooooo`03o`000?oooooooooo03Sooooo0on;FI42oh]J
T@;oS5ZA0_n=Fi43oi1MT@;oTenA0_nIHi400onOJ97oY6fBojYaTP02ojYaTP04okQkTOo6RI?o0000
olj?T@;oeYNA3oooool00ol0003oooooooooo`0looooo`00Loooool3o`0003oooooo1On;FI42oh]J
T@;oS5ZA0on=Fi42oi1MT@;oTenA0_nIHi42ojA]TP?oZW6B0_o6RI<01?l0003oeYNAomJGTOoFUi4@
ooooo`03o`000?oooooooooo03_ooooo001aooooo`;o0000?_ooool9oh]IT@;oReZA0on<FY42oheK
T@;oT5fA0_nCGi400onIHi7oW6NCojA]TP02ojA]TP;oZW6B0_o6RI<01Ol0003oeYNAomJGTOoFUi7o
hJ>@00oooooo0_l0000looooo`00K_ooool4o`0003gooooo2on;FI43oh]JT@;oS5ZA0_n=Fi42oi1M
T@;oTenA0_nLIi<3ojA]TP;oZW6B0_o6RI<00ol0003oeYNAomJGT@02on6ST13ooooo00?o0000oooo
ooooool0>_ooool006cooooo0_l00004ooooo`03o`000?oooooooooo03Sooooo3_n;FI42oh]JT@;o
S5ZA0_n=Fi42oi1MT@04oi=OTOnEHY?oW6NCoiaWT`?oY6fB00GoZW6BokMnUoo6RI?oaXVCo`000002
omJGT@;ohJ>@4Oooool00ol0003oooooooooo`0iooooo`00JOooool3o`0003oooooo00?oRUVAoh]I
TOn;FI403On;FI42oh]JT@;oS5ZA0_n=Fi42oi1MT@;oUF:C0onLIi<2ojA]TP07ojYaT_ngOYOo]gjG
olJ9Tol0003ocY6ComJGT@02on6ST003onb^S_oooooooooo00oooooo00?o0000ooooooooool0>?oo
ool006Oooooo0_l0000nooooo`GoRUVA3on;FI42oh]JT@;oS5ZA0_n=Fi401?n@GI7oTV2CoiERTonE
HY<3oiaWT`;oY6fB00OoZW6BokMnUongOYOoaXVCo`000?o>TI?oeYNA00;ohJ>@00?ok:j>oooooooo
ool03oooool00ol0003oooooooooo`0hooooo`00I?ooool5o`0003cooooo1on:FI4?oh]IT@;oReZA
0_n<FY401?n=Fi7oSUfCoi9PTonBH9<2oiERT`?oW6NC0_nTKI83okMnU`03olJ9Tol0003ocY6C00;o
hJ>@0_o/[XhBooooo`03o`000?oooooooooo03Oooooo001Qooooo`?o0000?oooool9ohYIT@ooReVA
0_n;FY401?n<FY7oSEbCohiMTon>GI<2oi9PT`?oUF:C0_nLIi<2ojA]TP?o]gjG00?ocY6Co`000?o>
TI<00_oQXi02onb^SP03oo6cS?oooooooooo013ooooo00?o0000ooooooooool0=_ooool005oooooo
0_l00011ooooo`[oRUVA3on;FI401?n;FY7oS5^CoheLTon=G9<2ohiMT`;oTV2C0onEHY<2oiaWT`03
ojA]T_n`NIOo]gjG00;o]gjG0_o>TI<00ol0003ohJ>@on6ST002onb^SP03oo6cS?oooooooooo013o
oooo0_l0000gooooo`00G?ooool3o`0003oooooo3on:FI4;oh]IT@03oh]KTon<Fi?oS5^C00;oS5^C
0_n=G9<2ohiMT`?oTV2C0_nEHY<2oiaWT`?o/7VG0_ngOYL2oljAT`04o`000?oKWY?ohJ>@onb^SP;o
lK><4oooool00ol0003oooooooooo`0eooooo`00>Oooool3o`0001kooooo0_l000000ooooooo0000
o`00000mooooo`03ohYIT_n:FI7oRUVA00koRUVA2On;FI43oh]KT`CoS5^C0_n=G9<3ohiMT`;oTV2C
0_nEHY<2oiaWT`?o/7VG00Ko]gjGokn7V?o>TI?ocY6Co`000?oKWY<2onb^SP;olK><00?omk^8oooo
ooooool04?ooool00ol0003oooooooooo`0eooooo`00>?ooool01Ol0003ooooooooooooooooo0000
01[ooooo0ol00010ooooo`?oRUVB4?n:FI47oh]IT@GoRe^C1?n<Fi<2oheLT`?oSUfC0_nBH9<2oiER
T`03oiaWTonULYSo/7VG00;o/7VG00Ko]gjGokn7V?noQiSocY6Co`000?oKWY<2onb^SP;olK><00?o
mk^8ooooooooool04Oooool00ol0003oooooooooo`0dooooo`00<_ooool5o`0000Gooooo00?o0000
ooooooooool05_ooool2o`0003oooooo1on:FI8@ohYIT@GoReVA1on;Fi<4ohaKT`?oSEbC0_n>GI<2
oi9PT`;oUF:C0_nULYP3ok1iU`06okMnUonoQiSo_hNHoljATol0003ofijC0_o/[Xh01?oa/hcomk^8
ooNkR?oi_XLCooooo`03o`000?oooooooooo03?ooooo000looooo`03o`000?oooooooooo01?ooooo
0ol0000oooooo`WoRUVB4?n:FI400on;FI7oRe^Coh]KT`09oh]KT`GoS5^C0_n=G9<2ohiMT`;oTV2C
00?oUF:Coia/VOnULYP00_nULYP2ok1iU`?o_hNH00KofijCo`000?oKWY?oijbBonb^S_oa/h`2ooNk
R003ooVnQooj_hGooooo017ooooo00?o0000ooooooooool0<oooool003Sooooo1?l0000Cooooo`?o
00000_ooool00ol0003oooooooooo`0kooooo`_oRUVB3on:FI4>oh]KT`CoS5^C0_n=G9<2ohiMT`03
oi9PTonHJ9WoW6bI00;oW6bI0_nULYP2ok1iU`07okN1V_noQiSo_hNHom^NTol0003ofijConN/TP02
oo6cS004ooNkR?oi_XOonKj7ooZoQA?ooooo00?o0000ooooooooool0<_ooool003Sooooo00?o0000
ooooooooool04_ooool2o`00043ooooo3on:FI8<ohYITA3oRe^C1?n<Fi<2oheLT`;oSUfC0_nHJ9T3
oia/V@;oYG:H00?o/7VGokN1V_ngPIX00_noQiP01?o<U9_o0000om^NTooW[982oo6cS005ooNkR?oi
_XOonKj7ooZoQOok`H@04_ooool2o`0003?ooooo000hooooo`Go00003Oooool3o`00043ooooo4On:
FI8:ohYITA;oRe^C1?n<Fi<2oheLT`03ohiMTonCIIWoV6RI00;oV6RI0_nLK9T2ojEbV003ok1iUong
PI[o]h6J00;o_hNH00Soc9BKo`000?oW[9;oijbBonfbTOoa/hcomk^8ooVnQ`;on[n500?onl64oo_2
Q?ooool04Oooool00ol0003oooooooooo`0aooooo`00B?ooool3o`00043ooooo4on:FI86ohYITAKo
Re^C1?n<Fi<00on=G9?oTFBJoi=UV@02oi=UV@;oV6RI0onLK9T00onULYSo]h6JokN1VP02okN1VP;o
c9BK00Co0000onN/T_oW[9;okK:A0_og^hP01Ooi_XOon[n5oo_1Q?ok`HConl:401?ooooo00?o0000
ooooooooool0<?ooool004Gooooo0ol00002ooooo`03o`000?oooooooooo03[ooooo5on:FI85ohYI
TAOoRe^C00CoS5^CohmRV_n@Hi[oT6>J0_nAI9X3oi=UV@;oV6RI0onLK9T00onULYSoZgVLokN1VP02
okN1VP;oc9BK00Co0000onN/T_oW[9;okK:A0_og^hP01Ooi_XOon[n5oo_1Q?ok`HConl:401Cooooo
00?o0000ooooooooool0;oooool004?ooooo0_l00010oooooaWoRUVB0on:FI4Hoh]KT`?oSf:J0_n@
HiX3oi5TVP;oTfFI0onHJ9T2oia/V@;oZgVL0ongPIX2olbDV`05o`000?oW[9;okK:AonfbTOod^hl0
0_oi_XL01Ooj_hGonl64oo_2Q?ok`XCoo<:401?ooooo00?o0000ooooooooool0;oooool0043ooooo
0ol0000ooooooa_oRUVB6_n;Fi<00on>HY[oSf:JohmRVP03ohmRVP;oT6>J0_nAI9X2oi=UV@?oV6RI
00CoW6bIoj5bWOn[NIcoZgVL0ongPIX2olbDV`06o`000?oJYIkokK:AonfbTOod^hoomkn=0_oj_hD0
0ook`HConl:4ooc2Q002ooc2Q1?ooooo00?o0000ooooooooool0;_ooool003kooooo0ol0000ooooo
oa_oRUVB6_n;Fi<3ohiRVPGoSf:J0_n@HiX2oi5TVP?oTfFI0_nHJ9T2oj5bW@?oZgVL00Ko]h6JolB?
W_o4Sikoc9BKo`000?oJYIh2onfbT@06ooBkSoog_hgon[n5ooZoQOok`HConl:41?ol`X@Cooooo`03
o`000?oooooooooo02gooooo000kooooo`?o00000oooool00ol0003oooooooooo`0joooooa_oRUVB
6?n;Fi<7ohiRVPGoSf:J0_n@HiX3oi5TVP;oTfFI00?oV6RIoia^WOnQLYd00_nQLYd2oj]iW007okN1
V_o4Sikoa8nNolbDVol0003ofZFNonfbT@02ooBkS`05ooNoSOoi`Hconl64oo_1Q?ok`X@01Ool`X@B
ooooo`;o0000;_ooool003Sooooo0ol0000ooooooa_oRUVB6_n;Fi<9ohiRVPGoSf:J0on@HiX2oi5T
VP04oi=UVOnFJYkoW6jMoia^W@?oXG:M0_n[NI`3olB?WP04olbDVol0003ofZFNon:^W`;om;^?00?o
mkn=ooW1S?oj`h/00_ok`X@5ooc2Q1?ooooo00?o0000ooooooooool01oooool2o`0002?ooooo000f
ooooo`;o0000@OoooolJohYITQ[oRe^C3?n>HYX5ohmRVP;oT6>J00CoTFBJoi=XW_nFJYkoUVZN0onL
KYd2oj5bW@;oZgVL0oo4Sih2omZUWP03o`000?oR[Yoom;^?00;omkn=00ConL6<oo[3Rook`XConl:4
1_ol`X@Cooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00008_ooool003?ooooo
0ol000000ooooooo0000o`00000loooooa_oRUVB6On;Fi<@ohiRVPGoSf:J00CoT6>Joi9WW_nCJ9ko
TfRN0_nFJYh3oia^W@;oXG:M00?oZgVLokJ6X_nfQZ800_o4Sih01OoCXJ?ofZFNo`000?oR[Yoom;^?
00;omkn=00?onL6<oo[3Rooka8X02?ol`X@Booooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00008_ooool0037ooooo0_l00010oooooa_oRUVB6On;Fi<BohiRVPCoSf:J00?oT6NNoi9W
W_nBIih00_nCJ9h3oiIZWP;oW6jM0_nQLYd3okJ6XP08olB?W_oCXJ?odj6SomZUW_l0003ohZjOonfl
Woog_hd2ooW1S003oo[3Rooka8[onlB:00Soo<:44_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`0002;ooooo000^ooooo`?o0000?ooooolLohYITQ[oRe^C4on>HYX00on?HY[oT6NN
oi1WWP02oi1WWP;oTVNN0onCJ9h2oiIZWP;oW6jM00?oXG:MojUnYOnfQZ800_nfQZ801Oo4Sikodj6S
om>QXooR[Yoo000000;okKbO00Comkn=ooW1S?oi`Hcon/>;0ooka8X8ooc2Q1;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool0000Rooooo`00;?ooool3o`0003oooooo6_n:FI83oh]K
U1OoRe^C0on>Hi/AohiRVP?oT6JN1On@Iih3oi9WWP;oTfRN0_nFJYh2oia^W@?oZGjU0_nfQZ83om>Q
X`06om^[YOl0003okKbOonflWooa`YoonL6<0_oj`h/3oo_4RPSoo<:44_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0002;ooooo000Yooooo`?o00000_ooool00ol0003ooooooooo
o`0ioooooacoRUVB1On;Fi@Eoh]KT`GoSV>K3on>HYX00on@IikoT6JNoi1VWP03oi1VWPGoT6NN0_nB
Iih2oi=XWP;oUVZN00?oW6jMoj=jYOnYOZD00_nYOZD2okJ6XP;odj6S0_oKZjD01_l0003okKbOoo72
Wooa`YoonL6<oo[3R`GonlB:1ool`X@Booooo`;o00001Oooool2o`0002?ooooo000Vooooo`?o0000
@?oooolIohYITPWoRe^D4on;Fi<7ohiSV`goSV:J0on@Iih5oi1VWPGoT6NN0_nBIih2oi=XWP03oiIZ
W_nKMJOoXgZU00;oXgZU0_nYOZD01?nfQZ;oaIVZolFIZ_oCXJ<2om^[Y@06o`000?o]_9oolL:Ooo72
WoocaIkon/>;1_oka8X7ooc2Q1?ooooo00?o0000ooooooooool09oooool002Cooooo0_l0000ooooo
o`?oREVB6On:FI8:oh]KU0ooRe^C3?n>Hi/9ohiRVPOoT6NN1?n@IYh5oi1WWP;oTVNN00CoTfRNoiQc
YonKMJOoVgFW0onSNZD2ojUnY@?oaIVZ00Kodj6Som^[YOl0003o0000onflWooa`Yl2oo?5WP03ooK9
W_oka8[onlB:00GonlB:1ool`X@Booooo`03o`000?oooooooooo02Oooooo000Qooooo`Go0000?Ooo
ool5ohUITQOoRUVB3On;Fi@<oh]KT`koSV>K1on>HYX2oi1WW`OoT6NN1On@IYh4oi1WWP04oi9WW_nF
LZOoV7>WoiQcY`?oVgFW0_nSNZD01?nYOZGo]Y2`olFIZ_o5VJX3o`000004onNkYol0003olL:Ooo72
W`;ollFN00?om/VNooK:WOoka8X01_oka8X7ooc2Q1;ooooo00?o0000ooooooooool09_ooool0023o
oooo0_l0000nooooo`SoREVB4on:FI8Aoh]KU0[oRe^C4?n>Hi/5ohiRVPGoT6NO1_n@Iih5oi1VWP?o
T6NN00?oU72WoiIbYonFLZL00onHLjL2oi]eY`;oXgZU00Oo]Y2`o`000?l0003o0000olFIZ_o=Y:ko
fj^U00;oik^W00?o0000oo72WoocaIh00_ofbIh00oofbYgonlB:oo_4RP05oo_4RPOoo<:44oooool0
0ol0003oooooooooo`0Uooooo`008?ooool3o`0003Wooooo3?n9FI8AohYITQ?oRe^D1_n;Fi<DohiS
V`03ohiRV_n@IiooT6NO00OoT6NO1on@Iih3oi1VWP?oU72X0_nDL:L3oiIbY`;oV7>W0_nKMJL3o`00
00;o]Y2`00CoaIVZolfT[_o=Y:kofj^U0_oW^jL01?o/`ZSo0000oo?5W_ofbIh2ooK:W@OonlB:2?ol
`X@Booooo`03o`000?oooooooooo02Gooooo000Pooooo`04o`000?ooooooooooo`0003Oooooo3On9
FI8>ohYITQKoRe^D1?n;Fi<EohiSV`_oT6NO1on@Iih00on@IYkoU72XoiA`Z003oiA`Z0?oU72W0_nF
LZL01?nHLjOo0000o`000?l00003ojj</P;o]Y2`0oo=Y:h2onNkY`;ok<:X00KoklJXo`000?ofbIko
m/ZMooO:WOogbid7oo_4RPSoo<:44_ooool2o`0002Gooooo000Pooooo`05o`000?oooooooooooooo
ool00000<_oooolAohUITPcoRUVB6?n;Fi@00on;Fi?oSV>KohiSV`0DohiSV`koT6NO1On@Iih00onD
LJSoU72XoiA`Z005oiA`Z0;oU72W0ol000000onOPkGoXhFdoj>5]003ojj</P03okJ@/?nmW;Ko_Ibf
00;ocJB^00?ofkRfonNkYoo/`ZP00_o_aZP01?l0003om/VNooK:WOogbYd2ooO;W@OonlB:2?ol`X@A
ooooo`;o00009Oooool001oooooo0ol00003ooooo`03o`000?oooooooooo02cooooo5?n9FI88ohYI
TQ_oRe^D5?n>Hi/Boi1WW`03oi1WW_nDLJSoU76X00?oU76X1_nDL:P3o`000004oiIbYonLP[KoWh>e
oin3]@?oXhFd0_n^S;83okfL]P03olfT[_oK^;KofkRf00;ok<:X0_o_aZP01?obbjSo0000ooK:WOog
bYd3ooO;W@OonlB:1ool`X@Booooo`03o`000?oooooooooo02?ooooo000Oooooo`03o`000?l005co
oooo00Cooooo00?o0000ooooooooool0:OoooolFohUITPKoRUVB6On;Fi@FohiSVa?oT6NO2?nDLJP2
oiA`Z0?o000000?oU72XoiA`YonJP;H00_nLP[H3oin3]@;oXhFd00?o[XbbokBG^OndUkT00_nmW;H3
om^h]P03on71^?o/`ZSoklJX00;ol/^X00?ollbXo`000?ogbid00oogbid7oo_4RPOoo<:44oooool0
0ol0003oooooooooo`0Rooooo`007oooool3o`0000Gooooo00?o0000ooooooooool09Oooool2ohUH
TAOoREVB0on:FI8Joh]KU1CoSV>K4on@Iil;oiAaZ0?o000000?oU72XoiV0]onJP;H00onJP;H3oib2
]P;oWh>e00?oXhFdojR@_OndUkT00_ndUkT01?nmW;Kob[;2olZb`_oK^;H2on71^003onG7^_o_aZSo
l/^X00;ollbX00?o0000ooO;WOogbid00oogbid7oo_4RPOoo<:44_ooool00ol0003oooooooooo`0R
ooooo`007oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023ooooo1_n9F94GohUI
TP03ohYIT_n;FiCoRe^D01SoRe^D5?n>Hi/Coi1WW`03oiAaZOnDLJSoU76X00SoU76X0_l000000onD
LJSoU72XoiV0]`02oiV0]`GoVX2f0_nLP[H00onOPkGoXhjnojR@_@02ojR@_@;o]9Ni0oo://83on71
^003onG7^_obbjSol/^X00;ollbX00?ollfXo`000?ogbid01?ogbid7oo_4RPOoo<:44_ooool00ol0
003oooooooooo`0Qooooo`001_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?o
oooo0ol00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool7ohUHTAGo
REVB6_n;Fi@CohiSVaGoT6NO0onDLJT7oiAaZ0?o00000_nDLJP6oiV0]`CoVX2f00?oW8:foj2<_onS
S[h00_nSS[h2ojR@_@04okBG^Oo1[/Oo`Jk7olZb`P;od;g800KohL6honG7^_oUak[oj<jkoo;;Z?oc
c:P2oo?=Z003ooC=Yol0003oml^M00Coml^M1ooka8X7ooc2Q1;ooooo00?o0000ooooooooool08?oo
ool000Gooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool2o`000003o`00Kooooooooooo00Kooooo00?o0000ooooooooool0
6Oooool;ohUHTA7oREVB7?n;Fi@CohiSVa?oT6NO2?nDLJT3oiAaZ0?o000000?oU76XoiV1]onIP;L0
2?nIP;L01?nJP;KoW8_0oif;_onMRkl3oj2<_`;oXhjn00?oZ92mok6Wc_o1[/L00_o1[/L3om2mb0;o
iLNj0_oXc[/00ooYck_ollbXoo?=Z002ooC=Y`03ooC>Yol0003oml^M00Coml^M1ooka8X7ooc2Q17o
oooo0_l0000Qooooo`001Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`00K`09ooooo`03o`000?oooooooooo01Go
oooo3_n9F94?ohUITP03ohYKU?n;FiCoRe^D01OoRe^D5On>Hi/00on@J9ooT6NOoi1WW`0@oi1WW`[o
U76Y0ol00002oiAaZ0?oVH6g2?nIP;L01?nLR/3oW8_0oib;`?nLRl02oif;_`;oX8bo00?oXhjnoj^T
d?naYlh00_naYlh01?o1[/Ooa[[>olJjc_o@_LP2omC5b`07onG7^_oXc[_oj<jkonW?^ooZd;_ollfX
ooC=Y`02ooC>Y`03o`000?ogbigoml^M00?oml^M1ooka8X7ooc2Q1;ooooo00?o0000ooooooooool0
7oooool000Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol006ooooooooooo`08ooooo`03o`000?oooooooooo017o
oooo4On9F94<ohUITP;oRU^C0_n:Fi@Goh]KU1CoSV>K0_n@J:02oi1XW`koT6NO0onDLZT8oiAaZ@?o
000000?oU76XoiV1^?nIPKL01_nIPKL5oiV0]`04oib;`?nLR/3oW8[0oib:`0;oW8_00_nMRkl00onP
S;ooYZ;Boj^Td002oj^Td003ok6Wc_ne/mOoa[[>00;oa[[>0ooDaL/01OoHc/ooj<jkonW?^ooYck_o
j]2k00;om<fW0oodcZL00ol0003oml^MooO;W@03ooO;W@KonlB:2?ol`X@Booooo`03o`000?oooooo
oooo01kooooo0005ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooooooo1?l0
0004ooooo`;o000000?oooooo`00Koln8H@02_ooool00ol0003oooooooooo`0>oooooa?oRERA2_n9
FI84ohYKT`;oRU^D5?n;Fi@EohiSV`CoT6RP0_n@J9l<oi1WW`GoU7:Y1OnDLJT3o`0000;oU76Y0onI
PKP7oiV1]`04oiV0]onLRl7oW8_1oib;`@?oW8_00_nLR/001?nLRl3oXZ3Coj>QdonSXM<3ojJRdP03
oj^Td?n^/=[o]K?G00;o]K?G00Coa[[>ol[2doo:`]?oe<G;0_oHc/l01_oIcloojLnkon[@^ooZd;_o
j]6kooC=Y`Com<jW00?o0000ooO;WOogbid00oogbid6oo_4RPOoo<:44_ooool00ol0003ooooooooo
o`0Nooooo`001Oooool01?l0003oooooooooool00008ooooo`;o00000oooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooo`00Koln8H@02oooool2o`0000_ooooo5_n9F947ohUITPOoRU^C
0_n:Fi@Boh]KU1?oSV>K2?n@J:03oi1XW`OoT6NO2_nDLZT01OnDLJWo0000o`000?l0003oU76Y00So
VH6h1OnIPKL6oib;`@;oW8_000?oW8[0oj6PdonRX=<00_nRX=<2oj>Qd`03ojJRd_nY[]_o[[3J00;o
[[3J00Co]K?GokNlgOng_=gob/;C0_o>c=P00ooHc/oofLo?omW?c`02on[@^`;oj]6k00?oj]6looC>
YoodcZL00_odcZL00oogbigo0000ooO;W@03ooO;W@OonlB:1ool`X@Booooo`03o`000?oooooooooo
01gooooo0006ooooo`;o00002_ooool01?l0003oooooooooooooool5o`0000?ooooo00Go0000oooo
oooooooo001_ochQQ00=ooooo`03o`000?oooooooooo00Cooooo6_n9F943ohUITP03ohYJTon:Fi?o
RU^C00SoRU^C0on:Fi@=oh]KU1GoSV>K2on@J:02oi1XW`GoT6NO2_nDLZT3o`0000;oU76Y00?oVH:h
oiV1^?nIPKP01onIPKP00onIPKOoW8_1oib;`@08oib;`@03oib;`?nQX=CoXJ3C00;oXJ3C0_nRX=<0
0onSXM?oY:cMojV^f`02ojV^f`03ojj`f_n`^N3o]kcM00;o]kcM0oo>c=P01Oo>cMWofLo?om[Ad?oJ
dM3oj]2k00;oj]6k0_oZdK`4ooC>Y`03o`000?ogbigoml^M00?oml^M1ooka8X7ooc2Q1;ooooo00?o
0000ooooooooool07?ooool001kooooo0_l000001?oooooo001_ochQQ?mB;hP=ooooo`03o`000?oo
oooooooo00;oR5RA6on9F9401?n9FI;oRUZCohYJTon:FY<;ohYKT`;oRU^D2_n;Fi@DohiSV`ooT6RP
0_n@J9l00on@IiooU7:ZoiAbZ@09oiAbZ@?o000000?oU7:YoiV2^?nIP[P00onIP[P8oiV1^0WoW8_1
00?oXJ7Doj6Pe?nQX=@00onQX=@00onQX=?oXjcMojB/g@04ojB/g@03ojV^fonZ]n;oZ[OR00;o/;WP
00Co]kcMok[6i?nja^Coc/cH0_o>cMT3om[Ad003om[Bd?oZdK_oj]6l00;oj]6l1OodcZL00ol0003o
ml^MooO;W@02ooO;W@SonlB:1ool`X@Aooooo`;o00007Oooool001kooooo00Ko0000oooooooooooo
001_ochQQ?mB;hP=ooooo`03ohQGTOn8F97oR5RA00;oR5RA6On9F946ohYJT`_oRU^C0_n:Fi@8oh]K
U1GoSV>K4?n@J:001?n@J9ooU7:ZoiAbZ_nDLZX8oiAbZ@;o00000_nDLZT8oiV2^0?oVH6h00?oW8c2
oib<`OnLS<402?nLRl44oj6Qe0?oXJ3D1?nS[=d00onT[=goYKCTojFei002ojFei003ojZgh_n[`NWo
/L?W00;o/L?W00Co^/KTok[8iOnjb>Goc/gI0_o?cmX01?oJdM3of];@om[Bd?oJd]03on[A_003on_A
_?odcZOom<jW00?om<jW00?o0000ooO;WOogbid00_ogbid8oo_4RPOoo<:44Oooool00ol0003ooooo
ooooo`0Kooooo`007_ooool01ol0003oooooooooool005[o?R64oe8_R?mX?h`02Oooool4ohQGT@Co
R5RA5_n9F949ohYJT`_oRU^C0_n:Fi@4oh]KU1GoSV>K4_n@J:07oiAbZPCoU7:Y0ol00002oiAbZ@03
oiZ2^?nIP[SoVH:h00OoVH:h00?oVH6hoib<`_nLS<800_nLS<82oib<`@?oW8_11onQXM@4oj>/gP?o
XjcM00KoY;CTojFdi?nU]>CoYKCTojFei?nV_^/3oj_1j@04ok73ionaaNSo/LGXok[8i@;o^/WV00?o
cloJolo@f_o?d=X01?oJd]001?oZdKcojm6lon_A_?o[dK`5ooC>Y`03o`000?ogbigoml^M00;oml^M
1ooka8X7ooc2Q1;ooooo00?o0000ooooooooool06_ooool001gooooo0ol000001Ooooooo001JochQ
Q?mB;hSoJ3n<00;oMdZ?00CoO4j?oooooon3Di3oQEFA0_n6EY45ohQGT@CoR5RA5?n9F94;ohYJT`_o
RU^C0_n:Fi@2oh]KU1GoSV>K4_n@J:09oiAbZP05oiAbZOl0003o0000o`000?nDLZT00onJP[T3oiZ2
^0GoVH:h2?nLS<82oib<`@03oib;`OnQXMCoXJ7D00GoXJ7D1OnS[=h01?nS]>GoXkCToj>di?nS]>@2
ojBdi003ojFdi?nU_^_oYKk[00;oY[k[00GoZl7Yoj_2jon[`^_o/LGXok;6j@03ok[9iPCocm3J0ooJ
d]04on_A_0Gom<jW00?o0000ooO;WOogbid00oogbid6oo_4RPSoo<:44Oooool00ol0003ooooooooo
o`0Jooooo`007Oooool02?l0003ooooooooooooooooo001JochQQ?mB;hSoJ3n<0_mgBXl01?mlCXoo
Pe>@oh=CT?n5EI42ohIFT@GoR5NA1?n8F94@ohUHT@ooRUZC2on:Fi<00on:FiCoSV>KohiSV`0BohiS
Va;oT6RP2onDLZX3o`0000;oU7:Y1_nJP[T2oiZ2^0?oVH:h2OnLS<800onQX]GoXJ7Eoj6Qe@04oj6Q
e0OoXjcN1?nS]>D00onS]>CoXkk/ojBnk002ojBnk003ojFnjonU`>goY/3/00;oY/3/00?oZl;[oj_4
k?n[a>`00_nba^T00onjbNKo^l_Vok_;iP03olo@fPCof];@0oo[dK`00ooZdK_om<jWooC>Y`03ooC>
Y`03o`000?ogbigoml^M00?oml^M1_oka8X7ooc2Q1;ooooo00?o0000ooooooooool06Oooool001go
oooo0ol000001Ooooooo001JochQQ?mB;hSoJ3n<00;oMdZ?00CoO4j?oh=CT?n3Di3oQEFA0_n6EY45
ohQGT@GoR5RA3?n9F94BohYJT`[oRU^C5On>Hi/Aoi1XX0[oU7:Z0ol000000onDLZ[oVX:ioiZ2^@08
oiZ2^@03oiZ2^?nLSL;oW8c200WoW8c21?nQX]D2oj6Qe@03oj6Qe?nS[MkoXjcN00?oXjcN1onS]>D4
oj>nk003ojBnk?nT_ngoY;o]00;oYL3]00GoY/3/ojG2k_nU`^koZlC/oj_5k@03ok;8jP03ok_;i_nk
bnOo^l_W00?ocm3J1?oJd]001?o[dKcoj]6kon[A^oo[dK/5ooC>Y`03o`000?ogbigoml^M00?oml^M
1_oka8X7ooc2Q1;ooooo00?o0000ooooooooool06?ooool001gooooo00So0000oooooooooooooooo
o`00F_lT3gkoDRn8ofPoS0;oMdZ?00CoO4j?oh=CT?n3Di3oQEFA0_n6EY45ohQGT@GoR5RA2On9F94E
ohYJT`OoRU^C5?n>Hi/Aoi1XX0_oU7:Z0ol00002oiAbZP_oVX:i00CoWHg2oib=`_nLSL;oW8g21OnL
S<800onRX]GoXJ;Eoj6Re@04oj6Re@KoXjgN00?oXjcNoj>eiOnS]>D00onS]>D5oj>nk0CoXko]00?o
Y;o]ojC1k_nU`^h00onU`^h2ojG3kP;oZlG]00?o//SZok;8jonbb>/00onkbnL3olo@fPCof];@0_oZ
dK/00oo[dK_om<jWooC>Y`03ooC>Y`03o`000?ogbigoml^M00?oml^M1ooka8X7ooc2Q17ooooo0_l0
000Iooooo`002_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`08o`000?oo
ooooooooooooool005[o90mnoe8_R?mX?h`2ogM:S`04oga>Son3Di3oPe>@ohEET@;oQUJA1On8Ei45
ohQHT@OoRERA5on:FY<3ohYKT`CoSV:K4?n>Hi/Coi1XX0[oU7:Z0ol00002oiAbZP;oVX>i2?nJP[T6
oif=`P;oW8g200?oW8c2oj:ReOnRX]D01?nRX]D3oj6Re@GoXjgN00?oY;GUoj>eiOnS]ND00onS]ND0
0onS]>GoXkk/oj>nk003oj>nk0GoXko]0_nS`Nh2ojC1kP05ojG2k_nU`nooYL?_ojG3k_nU`nl00on[
aNd3ok;8j`?o^l_W0oo?d=X4om[Bd0;ojm6k00?oj]6kooC>YoodcZL00oodcZL00ol0003oml^MooO;
W@03ooO;W@OonlB:1_ol`X@Booooo`03o`000?oooooooooo00Gooooo0ol0000?ooooo`002Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00So0000oooooooooooo
ooooo`00F_lT3gkoDRn8ofPoS0;oMdZ?00CoO4j?oh=CT?n3Di3oQEFA0_n6EY45ohQGT@GoR5RA1?n9
F94JohYJT`03ohYKTon>HY_oSV:K00CoSV:K3_n>Hi/Boi1XX0[oU7:Z0ol00003oiAbZPGoVX>i1OnJ
P[T00onMSL?oWHg2oif=`P05oif=`P03oib=`_nRX]GoXZ;E00GoXZ;E1onS[Mh4ojBei@03oj>eiOnT
_^coY;k/00;oY;k/00?oXkk/oj>okOnS_nd00onS_nd5oj?1kPCoXl;_1OnU`nl3oj_5k@?o//S[0_nk
bnL4olo@fP?of];@00Cojm6kon[A^ooZdK_oj]6k1OodcZL00ol0003oml^MooO;W@02ooO;W@SonlB:
1_ol`X@Booooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`00
2Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`03
ob@?O_m298KoJ3n<00;oMdZ?00CoO4j?oh=CT?n3Di3oQEFA0_n6EY45ohQGT@GoR5RA00CoRERAohUJ
Ton9FY?oREZC6?n:FY<00on=HY_oSV:KohiRV`07ohiRV`[oSV>K00?oT6NPoi1XX?n@J:004?n@J:09
oiAbZP?o00000_nDLZX:oiZ3^@03oiZ2^OnMSL?oWHg300?oWHg30onMSL800onRX]KoXZ;Eoj:Re@06
oj:Re@GoXjgN1onT]ND5ojBnk0GoXko]1OnS`Nh7oj?2k`GoYL?_00?oZlG]oj_6kOn[a^d00_nbb>/3
ok_;i`Cocm3J0_oJd]001Oo[dK_oj]6kon[A^ooZdK_ojm6k00Gom<jW00?o0000ooO;WOogbid00_og
bid7oo_4RPOoo<:44Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo0009
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03ob@?O_m298KoJ3n<00;oMdZ?00CoO4j?oh=CT?n3Di3oQEFA0_n6EY45ohQGT@;oR5RA
00?oREVCohUJTon9FY<01?n9FY<DohYJT`GoSF:K2On>HY/8ohiSV`?oT6NP3_n@J:0;oiAbZP;o0000
00?oU7:ZoiZ3^OnJPkT02onJPkT7oif=``03oif=`_nRXmKoXZ;F00;oXZ;F0onRX]D00onS[MooXjgN
oj>]gP04oj>]gPGoY;GU1OnT_^`2ojBok@?oXko]1OnS`Nh<oj?2k`GoYL?_0_n[a^d3ok;8j`?o^l_W
0oo?d=X3om[Bd0?oj]6k00?ojm6kon[A^oodcZL00oodcZL00ol0003oml^MooO;W@03ooO;W@KonlB:
2?ol`X@Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool000Wooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00oooool00olT3gko@RB6oeljS002ogM:S`04oga>Son3Di3oPe>@ohEET@;oQUJA1?n8Ei44ohUI
T`KoREZC4on:FY<6oheRV`WoSV:K1On>Hi/6oi1WX0coT6RP2_nDLZX3o`000003oiAbZ_nJPkWoVX>i
00WoVX>i2?nMSL<6oj:SeP03oj:Re_nS[]ooXjgO00CoXjgO00?oXjgNojBeiOnT]ND00onT]ND5ojBn
k0GoY;o]1OnS`Nh?oj?2k`;oXl?_1OnU`nl2oj_6k@?o//S[0onkbnL3olo@fP?of];@00?oj]6kon_A
^oo[dK/00_oZdK/3ooC>Y`03ooC=Yol0003oml^M00Coml^M1_oka8X8ooc2Q17ooooo00Co0000oooo
oooooooooooo1?l0000?ooooo`002Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000000oooool2o`0000Cooooo00?o90mnod8TQ_mO>X`00_mcB9001?mlCXooPe>@oh=C
T?n5EI42ohIFT@03ohQGTOn9FI?oREVC00GoREVC1on9FY<>ohYJT`[oSF:K2On>HY/3ohiSV`SoT6NP
2On@J:0:oiAbZP?o000000?oU7:ZoiZ3^OnJPkT02_nJPkT9oif=``KoXZ?F1?nS[]l3oj>]g`;oY;KU
0onT]ND5ojBnk0GoY;o]1OnS`NhAoj?2k`;oXl?_1OnU`nl3oj_5k@?o//S[0onkbnL2olo@fPCof];@
00Cojm6kon[A^ooZdK_oj]6k0oodcZL00oodcJOom<jWo`000005ooO;W@KonlB:1ool`X@@ooooo`?o
00000_ooool00ol0003oooooooooo`0@ooooo`002_ooool2o`0000Wooooo0ol00004ooooo`03o`00
0?oooooooooo00?ooooo00?o90mnod8TQ_mO>X`00_mcB9001?mjCI7oPUBBoh9DT_n5EY82ohMGTP03
ohQITon9FI?oREVC00GoREVC1on9FY<;ohYJT`goSF:K2?n>HY/<oi1WX0OoT6RP2OnDLZX3o`0000;o
U7:Z2_nJPkT9oif=``OoXZ?F1_nS[]l5ojBfi@GoY;k/1OnT_nd4ojC1kP03oj?1k_nS`^ooXl;_01Co
Xl;_0_nS`nl5ojG3k`03oj_5kOn[a^goZlK]00?o//S[00?o^l_Wok_;i_nkbnH00_o?d=X4om[Bd0?o
j]6k00Cojm6kooC>YoodcJOom<fW0_odcZL00ol0003oml^MooO;W@02ooO;W@OonlB:1_ol`X@Boooo
o`03o`000?oooooooooo00Go00003_ooool001cooooo00?o0000ooooooooool00oooool00ol006co
@RB6oeljS002og=8T004ogY=TOn2E9;oPUBBohEFTP;oQeNB00?oR5VCohUITon9FI<01On9FI<7ohUJ
T`WoRUZC00?oSF:JoheRVon=HY/03?n=HY/5ohiRV`ooT6NP0on@J:0:oiAbZP?o000000?oU7:ZoiZ3
^OnJPkT02?nJPkT3oif>``SoWHg31onRXmH5oj>^g`KoY;KU1OnT_^`5ojBok@GoY<7^6onS`^l5ojG3
k`?oZlK]0_nbb>/3ok_;iP?ocm3J0ooJd]02on[A^`;ojm6k00?oj]6kooC=YoodcZL00_odcZL00ol0
003oml^MooO;W@03ooO;W@OonlB:1_ol`X@Booooo`03o`000?oooooooooo01;ooooo000Looooo`;o
00001Oooool01Om298KoGcZ<og=8T?mcB93oNTfA00;oPUBB00CoQEJBohMGT_n7Ei;oR5VC1on9FI<7
ohUJT`KoRUZC1?n=HYX>oheRV`?oSV:K0_n@Iil?oi1WX0[oU7:Z0ol00002oiAbZP[oVX>i1_nMS/<3
oif=``OoXZ?F1onS[]l5ojBfi@CoY;k/1?nT`>d00onT_ngoY<7^ojC1kP03ojC1kPCoY<;_6_nS`^l2
oj?3k`GoYL?_00?oZlK]oj_5kOn[aNd00_nbb>/00onkbnKo^l_Wolo@fP03olo@fP?of];@00Goj]6k
on_A^oo[dK_oj]6kooC=Y`03ooC>Y`03ooC=Yol0003oml^M00?oml^M1ooka8X7ooc2Q17ooooo00?o
0000ooooooooool04_ooool001cooooo00?o0000ooooooooool01?ooool01Om298KoGcZ<og=8T?mc
B93oNTfA00;oPUBB00CoQEJBohMGT_n7Ei;oR5VC1on9FI<7ohUJT`;oRUZC0on=HIX5oheRVPgoSF:K
1_n@Iil=oi1WX0WoU7:Z0ol00002oiAbZP[oVX>i2OnMS/<00onMSL?oXZ?Foj:SeP05oj:SePGoXjkO
1onT]^D4ojBnk0GoY<3]0onT`Nh9ojC2kaWoXl;_0onS`nl5ojG3k`;oZlG]0_nbb>/3ok_;i`?ocm3J
1?oJd]001?o[dK_oj]6kon[A^oo[dK/2ooC>Y`;om<fW00?om<jWo`000?ogbid00oogbid7oo_4RPOo
o<:44Oooool00ol0003oooooooooo`0Aooooo`006oooool00ol0003oooooooooo`05ooooo`05oa88
OomO>XcoLdR@og=8T?mjCI400_n2E9801?n5EY;oQeNBohMGT_n8FI<7ohUIT`KoREZC1_n=HIX5oheR
VP[oSF:K0_n?Iil8oi1WW`SoT6NP2_nDLZX3o`0000?oU7:Z2_nJPkT8oif>``OoXZ?F1?nT[]l3oj>^
g`GoY;KU1OnT_^`5ojC0k@CoY<7^3?nT`^l3oj?2k`;oXl?_0onS`^l2oj?3k`ooXl;_00?oXl?_ojC2
konT`^l01?nU`nl2oj_5k@?o//S[00?o^l_Wok_;i_nkbnH00oo?d=X4om[Bd0;oj]6k00Cojm6kon[A
^oodcZOom<fW0_odcZL00oogbigo0000ooO;W@03ooO;W@OonlB:1_ol`X@Booooo`03o`000?oooooo
oooo013ooooo000Kooooo`;o00001_ooool01OlB27ooGcZ<og=8T?mcB93oNTfA00;oPUBB00CoQEJB
ohMGT_n7Ei;oR5VC1on9FI<3ohUJT`WoSF6J1On=HYX8oheRV`CoSfNO2?n@Iil7oi1WX0SoU7:Z0ol0
0002oiAbZP[oVX>i2OnMS/<6oj:SePOoY:kO1OnT]^D5ojBnk0GoY<3]1OnT`Nh>ojC2k`;oY<?_2?nS
`nlAoj?2k`;oY<;_1?nU`nl3oj_6k@?o//S[0onkbnH3olo@fPCof];@0_o[dK/00ooZdK_om<fWooC=
Y`02ooC>Y`03ooC=Yol0003oml^M00Coml^M1_oka8X7ooc2Q17ooooo00?o0000ooooooooool04?oo
ool001_ooooo00?o0000ooooooooool01Oooool01OlB27ooGcZ<og=8T?mcB93oNTfA00;oPUBB00Co
QEJBohMGT_n7Ei;oR5VC1on9FI<00on9FY?oSF6JoheQVP09oheQVPGoSF:J1On=HY/7ohmWW`SoT6NO
0on@Ij09oiAbZP?o000000?oU7:ZoiZ3^OnJPkT02_nJPkT9oif>``KoXZ?F1onT[]l5ojBfi@GoY;k/
1OnT`>d2ojC2kP?oY<7^3?nT`^l6ojC3k`CoXl?_5_nS`^l2ojC2k`CoYL?_00?oZlK]oj_5kOn[aNd0
0onbb>/00onkbnKo^l_Wok_;i`03olo@fP?of];@00Gojm6kon[A^ooZdK_oj]6kooC=Y`02ooC>Y`03
ooC=YoodcZOo000000Goml^M1_oka8X7ooc2Q17ooooo00?o0000ooooooooool03oooool001_ooooo
0_l00006ooooo`05oa88Oom9;hooLdR@og=8T?mjCI400_n2E9801?n5EY;oQeNBohMGT_n8FI<5ohUI
T`koSF6J1On=HYX00on=HY_oSfNOohmWW`0:ohmWW`KoT6NO2onDLZX2o`0000?oU7:Z2_nJPkT8oif>
``OoXZ?F1_nT[]l00onU]^GoY;KUojBfi@02ojBfi@05ojBok?nU_ncoYKo/ojFok?nT_^`01OnT`>d5
ojC2kPkoY<;_2OnT`nl00onS`nooXl;_oj?2k`06oj?2k`03oj?3konS`^ooXl;_00goXl;_0_nS`nl5
ojG3k`?oZlG]0onbb>/00onkbnOo^l_Volo@fP03olo@fP?of];@1?oZdK/00oodcZOom<fWooC=Y`02
ooC>Y`03o`000?ogbigoml^M00;oml^M1_oka8X8ooc2Q13ooooo00?o0000ooooooooool03oooool0
01_ooooo00?o0000ooooooooool01Oooool01OlB27ooBBn?ofY7U_mZAiKoNTfA00;oPUBB00GoQEJB
ohMGT_n7Ei;oR5VCohUIT`03ohaPVP03ohaQV_n=HI[oSF6J00coSF6J1On=HYX=ohmWW`GoT6NO2OnD
LZX3o`000003oiAbZ_nJPkWoVX>i00SoVX>i2_nMS/<00onRY=KoXZ?Foj:SeP04oj:SePGoY:kO1?nT
]^D01?nU]^GoY;KUojBnk?nT_^`2ojBok003ojFok?nU`>goYL3]00?oY<3]0onT`^h5ojC2k`CoY<?_
00?oY<;_ojC3konT`nl00_nT`nl00onT`^ooY<?_ojC3k`07ojC3k`CoY<;_1_nS`^l4oj?3k`koXl;_
0onT`^l5ojG3k`03oj_5kOn[a^goZlK]00;o//S[0onkbnH4olo@fP;of];@1OoZdK/2ooC=Y`;om<jW
00?o0000ooO;WOogbid00_ogbid7oo_4RPOoo<:44Oooool00ol0003oooooooooo`0>ooooo`000_oo
ool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00001Oooool00ol0003ooooo
ooooo`05ooooo`05oa88Oom9;hooJTNFofY7U_meCiL00_n2E9801?n5EY;oREjIohUNVOn;GiT4ohaP
VP03ohaQV_n=HI[oSF6J00coSF6J00?oSF:JohmVWon?IYl00_n?IYl=ohmWW`04oi1WWonDLZWoU7:Y
oiAbZ@OoU7:Z0ol00002oiAbZP[oVX>i2OnMS/<00onRY=KoXZ?Foj:TeP02oj:TeP03oj:Se_nT[]oo
Y:kO00GoY:kO0_nU]^D3ojBfi@CoYKo/00GoY;k/ojC0kOnT`>goY<3]ojG0k@02ojG2kP?oY<;^1OnT
`^lAojC3k`GoY<;_0_nT`nl2ojC2k`03oj?2konS`nooXl?_00?oXl?_4_nS`^l3ojC2k`GoYL?_00?o
ZlK]oj_5kOn[aNd00_nbb>/3ok_;iP?ocm3J0ooJd]05on[A^`?om<jW00?om<fWo`000?ogbid00oog
bid7oo_4RPOoo<:44Oooool00ol0003oooooooooo`0=ooooo`0000Goooooo`000?ooooooooooo`00
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Go4PQoodT_SomZAiKoJTNFogE?U`02oh9IV@04ohILVOn9GYWoREjI
oh]OV@CoS62J0_n<HIX;oheQVPOoSfJO2on?Iil6oiAbZ@CoU7:Z0ol00002oiAbZP[oVX>i2_nMS/<4
oj:TeP03oj:Se_nRY=KoY:kO00CoY:kO00?oY;KUojFfiOnU]^D00_nU]^D5ojFok0CoYL3]00KoY<3]
ojC2k_nT`^koY<;^ojG2k_nT`nl4ojC2kaCoY<?_1?nT`^l7ojC3k`03oj?3konS`^ooXl;_01GoXl;_
00?oY<;_ojC3konT`nl01OnU`nl2oj_5k@?o//SZ00?o^l_Vok_;ionkbnL00_o?d=X4om[Bd0Coj]6k
0_odcZL3ooC=Y`03o`000?ogbigoml^M00;oml^M1ooka8X7ooc2Q13ooooo0_l0000>ooooo`0000Go
ooooo`000?ooooooooooo`000009ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
oooo0_l00007ooooo`05o`00M?m9;hooBBn?ofY7U_meCiL00_n2FIT01?n6G9WoREjIohUNVOn;GiT4
ohaPVP;oS66J2?n=HIX;ohmVW`SoSfNO00?oU76YoiAbZOnDLZT01_nDLZT3o`000003oiAbZ_nJPkWo
VX>i00[oVX>i2?nMS/<4oj:SeP?oXZCF1_nT[]l2ojFfi@;oY;KU00?oYKKUojFok?nU_n`00onU_n`2
ojC0k@?oYL3]0_nU`^h3ojC2kP04ojC2konT`nooY<?_ojC2ka;oY<?_1OnT`^l9ojC3k`;oY<;_6?nS
`^l00onT`nooY<;_ojC2k`03ojG3k`;oYL?^0_n[aNd01?nbb>[o//S[ok;8jonkbnL2ok_;iP;ocm3J
1?oJd]04on[A^`03ooC>YoodcJOom<fW00;om<fW00?o0000ooO;WOogbid00_ogbid7oo_4RPOoo<:4
3oooool2o`0000kooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Wooooo0_m9;hl01OmZAiKoMDnGoh9IVOn2FIWoQUbI
00;oREjI0_n;GiT3ohaPVP;oS66J1_n=HIX2ohmVWP_oSfJO1?n?Iil3oi=aZ@;oU76Y1OnDLZT3o`00
00;oU7:Z2_nJPkT8oif>``03oj:Se_nSY=KoXjCF00CoXZ?F00CoY:kOojB_gonT[mooY:oO0onT[]l4
ojFfi@GoYKo/1?nU`>d00onT`>goY<;^ojC2kP03ojG2kP;oYL?_0onT`^lBojC3k`CoY<;_2OnT`nl7
ojC2k`?oXl;_0_nS`nlCoj?2k`;oY<;_0onU`nl00onU`nkoYL?_oj_6k@02oj_6k@03ok;8jonbb>[o
//SZ00;o^l_V0oo?d=X4om[Bd0Coj]6k0_odcJL00oodcZOom<fWo`000005ooO;W@KonlB:1ool`X@A
ooooo`03o`000?oooooooooo00_ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Ko0000
ooooooooooooooooo`000?ooool4o`0000Cooooo00?o0000ooooooooool01oooool00old98ooBBn?
ofY7UP02ogE?U`04oh9IVOn6G9WoQUbIohUNV@;oRenI0on<H9X2ohaQVP;oSF6J1_n?IYh;ohmVW`03
ohmWWonCLJWoTg6Y00CoTg6Y0onDLJT01?nDLZWo0000o`000?l00002oiAbZ@;oVX:i2?nJPkT:oif>
``?oXZ?F0_nSY=H00onRXmKoY:kOojB^g`02ojB^g`03ojB_gonU]^GoYKKU00GoYKKU1?nU_n`5ojG0
k@;oYL;^00?oY<;^ojC3konU`nl01?nU`nlFojC3k`03ojC2konT`nooY<?_00KoY<?_2OnT`^l2ojC3
k`?oXl?_5OnS`^l2ojC2k`GoYL?_00?oZlK]ojc5kOn/aNd00onbb>X2ok_;iP?ocm3J1?oJd]04on[A
^`05ooC=YoodcZOom<fWooC=Yol000001?ogbid7oo_4RPOoo<:44?ooool00ol0003oooooooooo`0;
ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`07o`000?ooooooooooooooool0003ooooo
o`000007ooooo`;o00002?ooool2oc@TS`04ofY7U_meCiOoMDnGoh9IV@;oQUbI00?oREjIoh]OVOn;
GiT00on<H9X00on<HI[oSfFNohmUWP08ohmVWPWoSfJO2OnCLJT3o`000003oiAbZOnIP[WoVX:i00Go
VX:i1OnJPkT3oif=``GoWHk300?oXZ?Foj>Se_nSXmH01?nRXmH3ojB_g`?oY:kO1OnU]^D5ojFok0Co
YL3]1OnU`^h2ojG3k`;oY<?_1OnU`nlLojC3k`WoY<;_0onT`nl00onT`^ooXl;_oj?2k`0Goj?2k`;o
Y<?_1OnU`nl3ojc5k@03ok;8j_nbb>_o^l_V00;o^l_V0oo?d=X3om[Bd0Coj]6k00Kom<jWooC=Yood
cJOom<fWooC>Yol00004ooO;W@OonlB:1ool`X@@ooooo`03o`000?oooooooooo00[ooooo0002oooo
o`;o00002Oooool3o`0000;ooooo1Ol00003ooooo`03o`000?oooooooooo00Oooooo00?o001doc@T
SomRAIT00_meCiL01?n2FIWoQUbIohILVOn9GYT2oh]OV@03ohaPV_n>IIkoSVFN00?oSfFN2?n?IYh6
ohmVW`WoTg6Y0ol00002oiAaZ@03oiAbZOnIP[WoVH:i00KoVX:i00?oVX>ioif=`onMSL<01OnMSL<3
oif>``CoXZ?F0_nSXmH01OnRXmKoY:kOojB^gonT[]ooY:oO00GoYKKU1OnU_n`5ojG0k@GoYL;^1_nU
`nl2ojC3k`GoYL?_5onT`nl5ojC2k`;oY<?_0_nT`^l5ojC3k`CoY<;_6OnS`^l2ojC2k`?oYL?_0_nU
`nh00on/aNgo[<K]ok;8j`02ok;8j`;o^l_V1?o?d=X3om[Bd0Coj]6k0oodcJL00oodcZOom<fWo`00
0004ooO;W@OonlB:1_ol`X@Aooooo`03o`000?oooooooooo00Wooooo000Jooooo`03o`000?oooooo
oooo00Oooooo00?o001Boc@TSomRAIT00_maD9/01?n2FIWoQUbIohILVOn9GYT2oheTWP?oSVFN0on?
IIh8ohmVWP;oSfJO00?oTg6Xoi=aZOnCLJT02?nCLJT2o`0000;oTg6Y00?oVH:hoiZ2^?nJP[P00_nJ
P[T2oiV2^@GoVX:i2?nMSL<3oj>SeP?oXZ?F1OnT[]l6ojFfi@GoYKo/1OnU`>d5ojG2kPWoYL?_0_nT
`nl5ojG3ka?oY<?_1?nT`^l9ojC3k`WoY<;_6?nS`^l3ojC2k`CoYL?_00Go[<K]ojc5kOn/aNgo//S[
ok;8jP03ok_;iPCocm3J0_oJd]05on[A^`05ooC=YoodcZOom<jWooC=Yol000001Oogbid6oo_4RPKo
o<:44Oooool2o`0000[ooooo000Iooooo`;o00002_ooool01Old98ooHTFIog5@VomaD9_oPUbM00;o
QenM00?oRV:MoheTW_n=I9h00on>IIh4ohmUWPOoSfJN00?oSfJOoi=aZ?nCLJP01onCLJT3o`0000;o
Tg6Y0onIP[P3oiZ2^004oiZ2^OnIP[WoVH:ioiZ2^@?oWHg21OnMSL<00onSXmKoXZ?Foj:SeP04oj>S
ePKoY:kO1OnU]^D5ojFok0CoYL3]1OnU`^h2ojG3k`;oYL?^2OnU`nl3ojC3k`GoYL?_4onT`nl00onT
`^ooY<?_ojC3k`06ojC3k`WoY<;_1?nT`nlHoj?2k`?oY<;_1?nU`nl3ojc5k@;o//SZ0onkbnH3olo@
fP?of];@1?oZdK/00oodcJOom<jWooC=Y`02ooC=Y`03o`000?ogbigoml^M00?oml^M1_oka8X6ooc2
Q17ooooo00?o0000ooooooooool02?ooool001Wooooo00?o0000ooooooooool02Oooool01Old98oo
HTFIog5@VomaD9_oPUbM00;oQenM00?oRV:MoheTW_n=I9h01?n>IIh3ohmUWPCoSfJN1?nCL:P3oi=a
Z0?oTg6Y0ol00002oi=aZ@OoVH:h0_nJP[P00onJP[WoWHg2oif=`P05oif=`P;oWHg31?nSXmH2oj:S
eP03oj>Se_nT[]ooY:kO00;oY:kO1OnU]^D00onV_ncoYKo/ojFok002ojFok0GoYL3]1?nU`^h4ojG3
kPkoYL?_0onT`nl5ojG3kaWoY<?_2OnT`^l3ojC3k`CoY<;_00?oXl;_ojC2konS`^l05OnS`^l2ojC2
k`?oYL?_0_nV`nh2ojc5k@?o//SZ0onkbnH3olo@fP?of];@1?oZdK/00oodcZOom<fWooC=Y`02ooC=
Y`03o`000?ogbigoml^M00;oml^M1ooka8X6ooc2Q0oooooo0ol00009ooooo`006Oooool00ol0003o
ooooooooo`09ooooo`05o`<<S?mRAIWoHTFIog5@Von2G9d00_n7Gid2ohYRW@03oheTW_n>IIkoSVFN
00;oSVFN0on?IIh00on?IYkoTg2Xoi=`Z006oi=`Z0;oTg6X0ol000001?nCLJWoVH6hoiV1^?nIPKP8
oiV2^003oiZ2^?nMSL;oWHg200KoWHg200?oXj?Eoj:Se_nRXmH00onSXmH00onT[]koY:kOojB^g`04
ojB^g`CoYKKU0_nU_n`2ojJok003ojFok?nU`>goYL3]00?oYL3]1OnU`^h2ojG3k`03ojG3k_nU`noo
YL?_00ooYL?_0onT`nl5ojG3kaCoY<?_2OnT`^l5ojC3k`WoY<;_5_nS`^l2ojC2k`;oYL?_00?oY/?^
ojG3konU`nl00_n/aNd00onbb>[o//S[ok;8j`03ok_;iP;ocm3J1?oJd]04on[A^`Com<fW00?o0000
ooO;WOogbid00oogbid6oo_4RPOoo<:42oooool3o`0000;ooooo00?o0000ooooooooool01oooool0
01Wooooo0_l0000:ooooo`04o`00D_mRAIWoHTFIog5@V`;oPUbM00CoQenMohYRWOn:HYgoSFBN1?n>
IIh00on?IIkoTg2Xoi=`Z008oi=`Z0?o000000?oTg6YoiV1^?nIPKP01OnIPKP4oiV2^0SoWHg200?o
XZ?Eoj>SeOnSXmD00onSXmD00onRXmKoY:kNojB^gP03ojB^gP03ojB^gonU]^GoYKKU00?oYKKU00?o
Y[o/ojFok?nU_n`00_nU_n`01?nU`>goY/3]ojK0kOnU`>d5ojG2kPCoYL?^5OnU`nl3ojC3k`GoYL?_
4onT`nl6ojC2k`CoY<?_3?nT`^lGoj?2k`;oY<;_1_nU`nl2ojc5k@03ok;8jonbb>[o//SZ00;o^l_V
0oo?d=X4om[Bd0Coj]6k1?odcJL00ol0003oml^MooO;W@03ooO;W@KonlB:1_ol`X@8ooooo`?o0000
1Oooool00ol0003oooooooooo`07ooooo`006Oooool00ol0003oooooooooo`0:ooooo`;oDD:Q00Co
LE2Koh9LWOn2G9goQenM0_n:HYd01On=I9koSVFNohiUW_n>IIkoTVnW00SoTg2X0ol000000onCL:So
Tg6XoiV1]`08oiV1^003oiV2^?nMS<;oWHc200SoWHg20onRXmD3oj>Se@03ojF^g_nT[]koY:kN00;o
Y:kN1_nU]^D4ojJok004ojFok?nU`>goYL3]ojG0k@CoYL;^1onU`nhHojG3k`;oY<?_1OnU`nlCojC3
k`03ojC2konT`nooY<?_00?oY<?_2OnT`^l4ojC3k`GoY<;_5OnS`^l2ojC2k`CoYL?_00CoY/?^ojc5
kOn/aNgo[<G]0onbb>X2ok_;iP?ocm3J0ooJd]05on[A^`Com<fW00?o0000ooO;WOogbid00_ogbid6
oo_4RPOoo<:40oooool4o`0000Sooooo00?o0000ooooooooool01oooool001Wooooo00?o0000oooo
ooooool02_ooool2oe52X@04ofQBYOn2G9goPUbMohMOW@;oRV:M00?oSFBNoi5_YonAKjL00_nBKjL5
oi=`Z0?o00000_nCL:P5oiV1]`KoVH6h1OnMS<83oif=`P03oj:SeOnSXmGoXj?E00;oXj?E00?oXZ?E
ojB^g_nU[]h01?nU[]h00onT[]koYKKUojFfi@03ojFfi@04ojJok?nU_ncoYKo/ojJok0CoY/3]00?o
YL3]ojG2k_nU`^h00onU`^h2ojG3kPCoYL?_0onU`nhHojG3k`03ojC3konU`nooYL?_00CoYL?_5_nT
`nl7ojC2k`GoY<?_2?nT`^lFoj?2k`;oY<;_0onU`nl2ojK3kP?o[<G]00?o//SZok;8jonkbnH00_nk
bnH3olo@fP?of];@1?oZdK/5ooC=Y`03o`000?ogbigoml^M00;oml^M1_oka8X7ooc2Q0;o00003Ooo
ool00ol0003oooooooooo`06ooooo`006?ooool3o`0000_ooooo00?o0`b<oe52XOmXDZD00_n1HjL0
1?n8J:OoSF^Wohe[YonAKZL2oi5_Y`?oTVnW00CoTg2Xo`000?l0003o00000_nCL:P2oiV0]`KoVH6g
0onIPKP2oif<`@KoWHc20_nSXmD3oj:Se@?oXj?E0_nU[]h00onT[]koYJkNojJfi@04ojFfi@05ojJo
k?nV_n_oY[o[ojJojonV_n`00_nV`>`00onU`>goY/3]ojK2kP03ojK2kP03ojG2k_nU`nkoYL?^00Go
YL?^1?nU`nl00onU`nkoYL?_ojG3k`0HojG3k`03ojC3konU`nooYL?_00?oYL?_5_nT`nl5ojC2k`Go
Y<?_2onT`^lFoj?2k`;oY<;_0onU`nl2ojK3kP;o[<G]00?o//S[ok;8j_nbb>X00onkbnH3olo@fP?o
f];@1?oZdK/4ooC=Y`03o`000?ogbigoml^M00;oml^M1ooka8X6ooc2Q0oooooo00?o0000oooooooo
ool01_ooool000Gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00006ooooo`03o`00
0?oooooooooo00_ooooo00GoDD:QofQBYOn1HjOoPF>WohQXY`02ohe[Y`;oTFjW0_nAKjL3o`0000?o
Tg2X1OnIP;L4oiV1]`OoWHc10onMS<83oj>Re@;oXj?E00?oXZ?EojF^g_nU[]h00onU[]h00onV]^Go
YKKUojFfi@02ojJfi@03ojFfiOnV_n_oY[o[00;oY[o/00GoY[o[ojK0k?nV`>coY/3/ojK2kP02ojG2
kP03ojK2k_nV`nkoY/?^00;oY/?^2?nU`nhOojG3k`03ojC3konU`nooYL?_00?oYL?_4_nT`nl5ojC2
k`CoY<?_4?nT`^lFoj?2k`;oY<;_0onU`nl2ojK3k`;o[<G]0onbb>X3ok_;iP;ocm3J1?oJd]04on[A
^`Com<fW00?o0000ooO;WOogbid00_ogbid6oo_4RPOoo<:43_ooool00ol0003oooooooooo`06oooo
o`001?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0<ooooo`04oe52XOmXDZGoJ5:Uoh5SY`;oR6RW0_n=JjL00onAKZOo0000o`00
0002oi9_Y`03oi=`Z?nIP;OoVH2g00KoVH2g0onIPKL7oif<`@?oXj;D1?nSX]D6ojF^gPCoY[KU00?o
YKKUojJojonV_n/00_nV_n/2ojK0k0;oY/3]00?oY/3/ojK2k_nV`^h00_nV`^h00onU`^koYL?^ojG3
kP04ojK3kP03ojG3k_nU`nooYL?_00?oYL?^8OnU`nl00onT`nooYL?_ojG3k`03ojG3k`goY<?_1OnT
`^l5ojC3kaCoY<;_5_nS`^l2ojC2k`;oYL?_0_nV`nh3ojc5k@?o//SZ0_nkbnH3olo@fPCof];@0ooZ
dK/5ooC=Y`03o`000?ogbigoml^M00;oml^M1_oka8X7ooc2Q0gooooo00?o0000ooooooooool01_oo
ool000Cooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`;o00003Ooo
ool01?l]>ZgoJ5:UofQBYOn1HjL2ohQXY`?o000000GoTFnWoiMn]_nHOkKoV7nfoiUo]P07oiV0]`03
oif;`OnLRl7oW8_100;oWH_10onMS<400onRX]CoXj;Doj>Re004oj>Re003oj>ReOnU[]koYJkN00?o
YJkN0onU]^D00onV]^GoY[o[ojJoj`03ojJoj`05ojK0k?nV`NcoY/7/ojK1k?nV`>`01?nV`^h4ojK3
kPCoYL?^0onV`nh=ojG3k`03ojG3k_nU`nooYL?_01OoYL?_0_nT`nl4ojG3k`_oY<?_0_nT`^l9ojC3
k`GoY<;_1?nT`nl<ojC2kaGoXl;_0onT`^l2ojG3k`;oY/?^0on/aNd2ok;8jP?o^l_V0oo?d=X3om[B
d004om[Ad?oZdK_oj]6kon[A^`Com<fW00?oml^Mo`000?ogbid00oogbid6oo_4RPKoo<:43Oooool0
0ol0003oooooooooo`06ooooo`001?ooool01?l0003oooooooooool00009ooooo`;o00001Oooool0
0ol0003oooooooooo`0=ooooo`;oEeFe0ol000000on=JjOoT7ZgoiIn]P02oiMn]P;oV7nf0_nIOkH3
oiV0]`;oW8_00onMRl42oib;`@03oif;`OnMS<7oXj;D00?oXZ;D0onSX]@4ojF^gPGoY[KT00?oYKKU
ojJojonV_n/00onV_n/4ojK0k004ojK1k?nV`^koY/;^ojK2kPSoY/?^1OnU`nh2ojK3kPKoYL?_00?o
YL?^ojG3konU`nl07_nU`nl2ojC3k`CoYL?_2?nT`nl2ojC2k`SoY<?_1OnT`^l4ojC3ka3oY<;_5OnS
`^l2ojC2k`;oYL?_0onV`nl3ojc5k@;o//SZ0_nkbnH4olo@fP03om[Bd?oJdM3of]7@00Coj]6k1?od
cJL00ol0003oml^MooO;W@02ooO;W@OonlB:1_ol`X@<ooooo`03o`000?oooooooooo00Kooooo0004
ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0<ooooo`?o000000?oOfngohYf]on:M[L00_n@N[L2oiIn]P;oUgjf00CoV7nfoiUo]_nIOkKoVH2g
1OnLRl02oif;`@03oib;`OnRXMCoXj;D00?oXj;D00?oXZ;DojF]gOnU[Mh00_nU[Mh2ojF^gPGoY[KT
1OnV_n/2ojK0k003ojK1k?nV`>coY/;^00CoY/;^2onV`nh00onU`nkoYL?_ojG3k`02ojG3k`03ojK3
k_nV`nooY/?_00;oYL?_1?nU`nhOojG3k`?oY<?_1?nU`nl?ojC3k`GoY<;_1?nT`nlEojC2ka?oXl;_
0_nT`^l2ojG3k`03ojK3konV`nkoY/?^00?o[<G]0_nbb>X2ok_;iPCocm3J00?of]7@om[Bd?oJd]00
0ooZdK/5ooC=Y`03o`000?ogbigoml^M00;oml^M1_oka8X7ooc2Q0_ooooo00?o0000ooooooooool0
1_ooool000Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?o
oooo0_l0000;ooooo`?o000000Goooooo`da/OmGEKGoEeFeogm_]`02ohYf]`03oi1j]onFO[KoUWjf
00;oUgjf00?oV7nfoib:`?nLR/001_nLRl02oj>Qe0?oXZ7D0_nSX]@4ojF]g@03ojF]g_nV]^CoY[KT
00?oY[KT1?nV_n/00onV`NcoY/3/ojK0k002ojK0k0;oY/;^00?oY/;]ojK2k_nV`nh03onV`nh5ojG3
k`03ojK3konV`nkoY/?^00;oYL?^0_nU`nl2ojG3kPGoYL?_0onU`nhGojG3k`?oY<?_1?nU`nl:ojC3
k`GoY<;_2?nT`nlDojC2kaCoXl;_0onT`^l2ojG3k`?oY/?^0_n/aNd2ok;8jP?o^l_V1?o?d=X2om[B
d0Coj]6k1OodcJL00ol0003oml^MooO;W@02ooO;W@KonlB:1_ol`X@<ooooo`03o`000?oooooooooo
00Gooooo0005ooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool01_ooool3o`0000Go
oooo0_m7Ekl01_moKkOoRWJgohYf]on@N[OoUWjfoiV8`0;oVXW00_nKR/02oib:`0?oW8_000?oXZ7C
oj>QdonSXM<00_nSXM@00onRXMCoYJgMojF]g@03ojF]g@KoY[KT1?nV_n/2ojK0k0;oY/7/00CoY/3/
ojK2kOnV`^goY/;^3_nV`nh2ojK3k`CoY/?^00?oYL?_ojG3k_nU`nh00_nU`nh3ojK3kP_oYL?_00?o
YL?^ojG3konU`nl05onU`nl3ojC3k`CoYL?_2?nT`nl2ojC2k`[oY<?_5onT`^lDoj?2k`?oY<;_0_nU
`nl3ojK3kP04ojc5kOnbb>[o//SZok;8jP?o^l_V0oo?d=X00ooJd]3of]7@om[Ad004on[A^`Com<fW
00?oml^Mo`000?ogbid00oogbid6oo_4RPKoo<:42oooool00ol0003oooooooooo`05ooooo`006?oo
ool00ol0003oooooooooo`03ooooo`?o00002?ooool00ol=<K7oAeNoogeh``02oh^0`P04oi>4`OnI
R<3oVHS0oiV8`0;oVXW000?oVh[0oib:`?nRXM<01OnRXM<00onSXM?oYJgMojF]g@04ojF]g@CoY[KT
1OnV_n/2ojK1k0?oY/3/1?nV`^d@ojK3kP?oY/?_1?nV`nh00onU`nkoYL?_ojG3kP02ojG3kP03ojK3
k_nV`nooY/?_00?oYL?_0onU`nhOojG3k`?oY<?_1?nU`nl00onT`nooY<;_ojC3k`0<ojC3k`GoY<;_
0onT`nl00onT`^ooY<?_ojC3k`0CojC2ka;oXl;_0onT`^l2ojG3k`;oY/?^0_n/aNd00onbb>[o//OZ
ok;7jP03ok_;iP?ocm3J00?of]7@om[Bd?oJd]001?oZdK/4ooC=Y`03o`000?ogbigoml^M00;oml^M
1_oka8X7ooc2Q0[ooooo00?o0000ooooooooool01Oooool001Oooooo0_l00002ooooo`?o00003?oo
ool2odMG_`04ogeh`on;P<;oRh32oi>4`@;oVHS000CoVXW0oj2OdonQX=?oXJ3C1OnRXM<4ojF]g@Go
Y[KT1?nW_n/01OnV_n_oY/3/ojK0k?nV`>coY/7/00GoY/;]5?nV`nh00onV`nooY/?^ojK3kP05ojK3
kP05ojG3konU`nkoYL?_ojG3konV`nl00_nV`nh6ojG3kPKoYL?_0_nU`nhGojG3k`?oY<?_1?nU`nl2
ojC2k`SoY<?_1OnT`^l9ojC3ka?oY<;_5?nS`^l3ojC2k`;oYL?_0_nV`nh2ojc5k@03ok;7j_nbb>[o
//SZ00;o^l_V0oo?d=X3om[Bd0Coj]6k1OodcJL00ol0003oml^MooO;W@02ooO;W@KonlB:1_ol`X@:
ooooo`03o`000?oooooooooo00Gooooo000Gooooo`Co00003oooool2oaYEcP06ogeh`on;P<;oRh32
oi>4`OnFV]KoWikD0onPWm<2oj6Pd`03oj:QdonU[MgoYJgM00;oYJgM1?nV]N@2ojJfi0;oY[o[0onW
_n/2ojO1k003ojK0k?nV`^goY/;]00;oY/;]8OnV`nh2ojG3k`;oYL?^0onV`nh2ojG3k`03ojG3k_nU
`nooYL?_00KoYL?_0onU`nhGojG3k`?oY<?_1?nU`nl8ojC3k`;oY<;_2_nT`nlFojC2kaGoXl;_0_nT
`^l2ojG3k`?oY/?^0_n/aNd3ok;8jP;o^l_V0oo?d=X2om[Bd003om[Ad?oZdK_oj]6k00;oj]6k1Ood
cJL00ol0003oml^MooO;W@02ooO;W@KonlB:1_ol`X@8ooooo`03oad0I?l0003ooooo00Kooooo000G
ooooo`;o00004_ooool01?lJELkoMH[Joh^Ef?n;UMP3oiJJeP03oinNe?nPWm?oXZ_M00?oY:cM00?o
YJcMojF]gOnV]N@01?nV]N@4ojNoj`05ojJojonV`>coYl3/ojO0k?nW`N`00_nW`^d3ojK2kAcoY/?^
0_nV`nl5ojK3kPCoYL?^0_nV`nh4ojG3k`?oYL?^1OnU`nl00onU`nkoYL?_ojG3k`0GojG3k`?oY<?_
1?nU`nl3ojC3k`;oY<;_00?oY<?_ojC2konT`nl01onT`nl9ojC2k`CoY<?_3OnT`^l00onS`^ooY<;_
ojC2k`0Coj?2k`04ojC2konU`nooYL?_ojG3k`?oY/?^0_n/aNd00onbb>[o//OZok_;iP02ok_;iP?o
cm3J00?of];@om[Ad?oJd]001?oZdK/4ooC=Y`03o`000?ogbigoml^M00?oml^M1_oka8X6ooc2Q0Oo
oooo00?o7@1To`000?ooool01_ooool001Wooooo00?o0000ooooooooool04?ooool01_l007goMH[J
oh^Ef?n;UMSoUY[FoiJVh@;oXJ_N0_nRZmd00onT[=goYKCTojJei003ojJei0CoYko[0_nW`>`2ojO1
k003ojK0k?nV`^goY/;]00;oYl;]0_nW`nhNojK3kP03ojK3konV`nkoY/?^00GoY/?^0onU`nh01?nU
`nooY/?^ojK3k_nU`nl7ojG3kPGoYL?_0_nU`nh4ojG3k`;oYL?^4OnU`nl2ojC3k`GoYL?_0onT`^l9
ojC3k`OoY<;_1OnT`nlDojC2ka;oXl;_0_nT`^l3ojG3k`?oY/?^0_n/aN`00onban[o//SZok_;iP02
ok_;iP;ocm3J00Cof]7@om[Bd?oJd]3of];@1?oZdK/4ooC=Y`03o`000?ogbigoml^M00;oml^M1_ok
a8X6ooc2Q0Oooooo00?o7@1To`000?ooool01_ooool001[ooooo00?o0000ooooooooool04?ooool0
1?l0BLOoKYCVofjDi_n8XN@2oiJVh@04oj6[g_nR/nGoXkCToj>di0;oYKCT00?oY[GTojJojonV_n/0
0_nW_n/3ojO0k0CoYl;]00?oY/;]ojK3k_nV`nh01?nW`nhVojK3kP?oYL?_00?oYL?^ojK3k_nV`nh0
1?nU`nh8ojG3k`GoYL?^2_nU`nl2ojG3kPWoYL?_00?oY<?_ojC2konU`nl01?nU`nl7ojC3k`GoY<;_
0_nT`nl3ojC2k`;oY<?_5onT`^lDoj?2k`;oY<;_00?oYL?_ojG2k_nU`^h00_nV`nh2ojc5k@?o//SZ
0onkbnH2olo@fP?of];@00Cof]7@on[A^ooZdK_oj]6k1OodcJL00ol0003oml^MooO;W@02ooO;W@Ko
nlB:1ool`X@5ooooo`03oad0I?oooooo000000Kooooo000Kooooo`03o`000?oooooooooo013ooooo
0_mWVnh01?n6ZNcoUJoXoiF_j?nE[nP2oj:ci@05oj>di?nS_^coYKk[ojFnjonV_n/01OnW`>`4ojO2
k@;oYl?^0onV`nh4ojO3kPGoY/?^0_nVa>hIojK3kP03ojK3konV`nkoY/?^00?oY/?^1OnU`nh00onV
`nkoYL?^ojG3k`04ojG3k`;oYL?^00?oYL?_ojG3k_nU`nh00_nU`nh9ojG3k`;oYL?^0_nU`nl00onU
`nkoYL?_ojG3k`09ojG3k`03ojC2konT`nooYL?_00CoYL?_0onT`nl2ojC2k`04ojG3konT`^ooY<?_
ojC3k`;oY<;_1OnT`nl8ojC2k`03ojC3konT`^ooY<;_00koY<;_00?oXl;_ojC2konT`^l04_nS`^l2
ojC2k`04ojG2k_nU`nooYL?_ojK3kP?o[<G]00?o//SZok;7j_nbanX00_nkbnH3olo@fP03om[Bd?oJ
dM3of]7@00Coj]6k1OodcJL00ol0003oml^MooO;W@02ooO;W@KonlB:1_ol`X@5ooooo`03oad0I?oo
oooo000000Kooooo000Looooo`;o00004Oooool2ofNKkP04ohJYk?nE[nSoTkWaoi>il@;oX[g]00Go
Xkk/oj>okOnS_ngoYL3/ojO0k005ojO2k@KoYl?^0onV`nh3ojO3kP;oYlC^0_nV`nh4ojK4kQSoY/?^
00?oY/?_ojK3k_nV`nh01?nV`nh3ojG3kP;oYL?_00?oY/?^ojG3konU`nh01onU`nh4ojG3k`;oYL?^
1?nU`nl3ojG3kQ3oYL?_0_nT`nl5ojG3k`?oY<;_2OnT`nl9ojC2k`?oY<?_5?nT`^lBoj?2k`;oY<;_
0_nU`nl2ojK3kP04ojc5kOn/aNco[<G/ok;7jP;o//SZ0_nkbnH3olo@fP03om[Ad?oJd]3of];@00Co
j]6k1?odcJL00ol0003oml^MooO;W@02ooO;W@KonlB:1ool`X@3ooooo`04ocT=KOl005Coooooo`00
00Kooooo000Nooooo`03o`000?oooooooooo00oooooo0_mMXO@2oh:bm005oi>ilOnC^_;oX[o^oj:o
k_nS_nd00_nS`Nh2ojG2kP03ojO2kOnV`nkoYl?^00SoYl?^00?oY/?^ojK4k_nVa>h01OnWa>h00onV
`nkoY/C^ojK3kP0RojK3kP?oYL?_0_nU`nh00onV`nkoYL?^ojG3kP04ojG3kPKoYL?_1OnU`nh:ojG3
k`;oYL?^2OnU`nl00onT`nooY<;_ojG3k`04ojG3k`OoY<?_2OnT`^l5ojC3kaGoY<;_5?nS`^l2ojC2
k`05ojG3konU`^koY/?^ojK3k_n/aN`00_n/aNd2ok;8jP?o^l_V0oo?d=X2om[Bd003om[Ad?oZdK_o
j]6k00;oj]6k1?odcJL00ol0003oml^MooO;W@02ooO;W@KonlB:1_ol`X@01ool`X?oooooooooooli
3Fgo001Dooooool000001_ooool001oooooo00?o0000ooooooooool03oooool01Ol0>k?oFj;eoh6c
mOn1/oGoTk[b00;oTkcc00CoX/7_oj?1k_nS`^ooXl;_0_nU`nh3ojK3kPOoYl?^0_nWa>h2ojK4kP?o
YlC^0_nW`nhUojK3kPGoYL?^00?oY/?^ojG3k_nU`nl01?nU`nl2ojG3kP03ojG3konU`nkoYL?^00;o
YL?^2OnU`nl2ojG3kP;oYL?_00?oYL?^ojG3konU`nl02OnU`nl00onT`^ooY<?_ojG3k`04ojG3k`?o
Y<?_00?oY<;_ojG2konU`^l01_nT`^l4ojC3kaWoY<;_00?oXl;_ojC2konS`^l04OnS`^l2ojC2k`03
ojG2k_nU`nooYL?_00;oY/?^0on/aNd00onbb>[o//OZok_;iP02ok_;iP;ocm3J00Cof];@om[Ad?oJ
dM3of]7@0ooZdK/5ooC=Y`03o`000?ogbigoml^M00;oml^M1_oka8X5ooc2Q007ooc2Pooooooooooo
ocT=KOl005Coooooo`000006ooooo`008?ooool00ol0003oooooooooo`0@ooooo`04oeVSm_n0]OKo
P;Gfoi>ll`;oT[gd00CoXL;`oj?2konS`^ooXl;_0_nU`nh3ojK3kP;oYl?^1onWa>h00onVa>koY/?^
ojK3kP04ojO3kP?oY/?^0onVa>hOojK3kPGoYL?^00?oY/?^ojG3konU`nh01onU`nh4ojG3k`;oYL?^
0onU`nl4ojG3kQ3oYL?_0_nT`nl5ojG3k`?oY<;_0onT`nl00onT`^ooY<?_ojC3k`03ojC3k`WoY<;_
00?oY<?_ojC2konT`^l04onT`^lBoj?2k`;oY<;_0onU`nl2ojK3kP03ojc5kOn/aNco//OZ00;o//SZ
0onkbnH2olo@fP?of]7@1?oZdK/5ooC=Y`04o`000?ogbigoml^MooO;W@KonlB:1Ool`X@01ool`X?o
o<>2ooooooli3Fgo001Dooooool000001_ooool0027ooooo0_l0000Aooooo`;oEjCg00CoOkKgoi:m
m?nB_OCoT[gd0_nQ`_001OnS`^ooXl?_ojG3konU`nooY/?^00;oY/C^1onWa>h2ojO3kP?oY/?^0_nW
`nh2ojO4kP;oY/?^00?oY/C^ojK3k_nV`nh08?nV`nh2ojG3k`?oYL?^0_nV`nh7ojG3kPCoYL?_1_nU
`nh9ojG3k`?oYL?^2?nU`nl01?nT`nooY<;_ojG2konU`^l3ojG3k`;oY<;_1OnT`nl9ojC2k`GoY<?_
5?nT`^lDoj?2k`;oY<;_00GoYL?_ojG2k_nU`^koY/?^ojc5k002ojc5k@?o//SZ0_nkbnH3olo@fP?o
f]7@1?oZdK/4ooC=Y`03o`000?ogbigoml^M00;oml^M1_oka8X4ooc2Q005ooc2Pool`h;ooLF1ocT=
KOl001D00_ooool00ol0003oooooooooo`03ooooo`008oooool00ol0003oooooooooo`0?ooooo`;o
EjCg00CoOkKgoi:mm?nB_OCoT[gd0_nQ`_03oj?3k`04ojG3konVa>koY/C^ojK4kP?oYlC^1?nW`nh2
ojO4kP03ojK3k_nVa>koY/C^00?oYlC^00?oYl?^ojK3k_nV`nh08onV`nh5ojG3kP;oY/?^00CoYL?^
ojG3konU`nooYL?_0onU`nh3ojG3k`CoYL?^1onU`nl2ojG3kP;oYL?_00?oYL?^ojG3konU`nl02?nU
`nl00onT`^ooY<?_ojC3k`05ojG3k`;oY<?_0_nT`^l2ojG2k`GoY<;_1OnT`nlHojC2k`03oj?2konT
`^ooY<;_01;oXl;_0_nT`^l01?nU`^koYL?_ojK3k_nV`nh3ojc5k@03ok;8j_nban[o//OZ00;o^l_V
0oo?d=X3om[Ad0Coj]6k1?odcJL00ol0003oml^MooO;W@02ooO;W@KonlB:0ool`X@01Ool`X?oo<>2
oog5POoobWGok<I;00;ooooo00?o0000ooooooooool00oooool002Cooooo00?o0000ooooooooool0
3oooool2oeNTm`;oOkKg0_nB_O@2oj72l0?oXl?_00CoYL?_ojK4k_nV`nkoY/?^0onW`nh6ojO4kP03
ojK4k_nV`nkoY/?^00GoYl?^9?nV`nh5ojG3kP;oY/?^0_nU`nl8ojG3kP04ojG3konU`nkoYL?^ojG3
kP?oYL?_1?nU`nh9ojG3k`;oYL;_0_nU`nh2ojG3k`?oY<?_1OnU`nl4ojC2k`;oYL?_00?oY<;_ojC3
konT`nl00_nT`nlPojC2ka;oXl;_0_nT`^l2ojG3k`;oY/?^00?o[<G]ojc5k?n/aN`00_nbanX3ok_;
iP;ocm3J1?oJdM03on[A^`Gom<fW00?o0000ooO;WOogbid00_ogbid6oo_4RP07ooc2Q?ol`X?oo<:3
ooc3P_omaH7oolYeonc6B`02ooooo`03o`000?oooooooooo00?ooooo000Uooooo`03o`000?oooooo
oooo00oooooo00Go03V`oeJTmomo]_OoOkKgoi:mm002oi:nm004oj72l?nS`nooXl?_oj?3k`;oYL?^
0_nV`nh8ojO4kP04ojO3k_nV`nkoY/?^ojK3kP?oYl?^0_nWa>hTojK3kPGoYL?^0_nV`nh00onU`noo
YL?^ojG3kP04ojG3kPCoYL?_1_nU`nh00onU`nooYL?^ojG3kP06ojG3k`?oYL?^00?oYL;_ojG3konU
`nl01?nU`nl00onT`nooY<;_ojC2k`05ojG3k`;oY<;_1OnT`nl9ojC2k`03ojC3konT`^ooY<;_01Oo
Y<;_4_nS`^l2ojC2k`03ojG3konU`^koYL;^00;oY/?^0_n/aN`3ok;7jP?o^l_V0_o?d=X3om[Ad0Co
j]6k1?odcJL00ol0003oml^MooO;W@02ooO;W@OonlB:0_ol`X<01?ol`h;ooLF1ooo:MOo/aT/2oooo
o`03o`000?oooooooooo00?ooooo000Vooooo`03o`000?oooooooooo00oooooo00Go03V`oeJTmomo
]oOoOkOgoi:nm002oi:mm004oj72l?nS`nooXl?_oj?3k`;oYL?_00?oY/?^ojK4k_nVa>h00_nWa>h6
ojO3kP03ojK3k_nVa>koY/C^00?oYlC^0_nW`nhTojK3kPGoYL?^0_nV`nh00onU`nkoYL?_ojG3kP04
ojG3kP?oYL?_1?nU`nh7ojG3k`;oYL?^0_nU`nl00onU`nkoYL?_ojG3k`08ojG3k`?oY<;_1?nU`nl3
ojC3k`;oY<;_0_nU`nl5ojC2k`GoY<?_6_nT`^lBoj?2k`;oY<;_0onU`^h2ojK3kP03ojc5k?n/aNgo
//OZ00;o//OZ0_nkbnH3olo@fP?of]7@1?oZdK/4ooC=Y`03o`000?ogbigoml^M00;oml^M1_oka8X2
ooc2P`04ooc3P_omaH7oolYeonc6B`;ooooo00?o0000ooooooooool00oooool002Oooooo0_l0000A
ooooo`03oeNTmomo]_OoOkKg00?oT[gd00CoXL;`oj?3konS`nooXl?_0_nU`nl00onVa>koY/?^ojK3
kP07ojO3kP;oYlC^00?oY/C^ojK3k_nW`nh01?nW`nhTojK3kPGoYL?^0_nV`nh2ojG3k`[oYL?^1OnU
`nl4ojG3kPooYL?_00?oY<;_ojC3konT`nl01?nU`nl5ojC2k`;oYL;_00?oY<;_ojC3konT`nl00_nT
`nlOojC2ka;oXl;_0_nT`^l01OnU`^koYL?_ojG3konV`nko[<G]00;o[<G/0onbanX2ok_;iP?ocm3J
0ooJdM04on[A^`Com<fW00?o0000ooO;WOogbid00_ogbid5oo_4RP05oo_5ROol`X?ooLF1oog5POoo
bWD00oooool00ol0003oooooooooo`03ooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;oEZCg
00CoOkKgoi:mm?nB_OCoT[gd0_nQ`_001?nS`nooXl;_ojG3k_nU`nh3ojK3kP?oYl?^1?nWa>h2ojO3
kP?oY/?^0_nW`nh2ojO4kRGoY/?^1?nU`nh2ojK3kP03ojG3konU`nkoYL?^00GoYL?^1?nU`nl5ojG3
kP03ojG3konU`nkoYL?^00KoYL?_0onU`nh7ojG3k`03ojC3konT`^ooY<;_00?oYL?_00CoYL;_ojC2
konT`^ooY<;_1?nT`nlTojC2ka;oXl;_0_nT`^l01?nU`nooYL;_ojK3k_nV`nh3ojc5k0;o//OZ0onk
bnH2olo@fPCof]7@0ooZdK/5ooC=Y`04o`000?ogbigoml^MooO;W@GonlB:0_okaHT00oomaH7oolYe
onc6B`03ooooo`03o`000?oooooooooo00?ooooo000Zooooo`03o`000?oooooooooo00oooooo0_mF
Y?L01?mo]_OoT[gdoi:mm?nB_O@2oj72l005oj?2konS`nooXl?_ojG3konV`nh00_nVa>h3ojO4kPKo
Yl?^0onV`nh01?nW`nkoYlC^ojO3k_nW`nhUojK3kPCoYL?^0_nV`nh7ojG3kP03ojG3konU`nkoYL?^
00KoYL?^1OnU`nl2ojG3kP;oYL?_1?nU`nh7ojG3k`?oY<;_0onU`^l01?nU`nooY<?_ojC3konT`nl2
ojC2k`03ojG3konT`^ooY<;_00CoY<;_00?oY<?_ojC2konT`^l06_nT`^lDoj?2k`04ojC2konU`^oo
YL;_ojG2k`;oY/?^0_n/aN`3ok;7jP?o^l_V0_o?d=X3om[Ad0Coj]6k1?odcJL00ol0003oml^MooO;
W@02ooO;W@ConlB:0_okaHT00oomaH7oolYeonc6B`04ooooo`03o`000?oooooooooo00;ooooo000[
ooooo`03o`000?oooooooooo00oooooo0_mGY?L2ognfm`;oT[gd0_nQ`_03oj?3k`04ojG3konVa>ko
Y/?^ojK3kPOoYl?^0_nWa>h3ojK3kPCoYl?^9OnV`nh4ojG3kP;oY/?^00?oYL?^ojG3konU`nh02onU
`nh3ojG3k`KoYL?^00?oYL?_ojG3k_nU`nl01onU`nl3ojG3kP03ojC2konT`nooY<?_00CoYL?_1OnT
`^l01?nU`^ooY<;_ojC3konT`nl2ojC2k`03ojC3konT`^ooY<;_01[oY<;_00?oXl;_ojC2konT`^l0
4OnS`^l2ojC2k`?oYL;_0_nV`nh2ojc5k0?o//OZ0_nkbnH3olo@fP?of]7@1?oZdK/4ooC=Y`03o`00
0?ogbigoml^M00;oml^M0ooka8X2oo_5R@03oog8Q_oobWGok<I;00Cooooo00?o0000ooooooooool0
0_ooool002cooooo0_l0000@ooooo`04o`0i/?mFY?OoOkKgognfm`;oT[gd0_nQ`_000onS`nooXl;_
oj?2k`02ojG3kP;oY/?^0onW`nh4ojO4kP;oYl?^0onV`nh4ojO3kRGoY/?^1?nU`nh2ojK3kP03ojG3
konU`nkoYL?^00GoYL?^0onU`nl:ojG3kPCoYL?_1?nU`nh01?nU`nooYL;_ojG2konU`nh3ojG3k`?o
Y<?_0_nU`nl2ojG2kP?oY<;_1?nT`nlSojC2ka;oXl;_0_nT`^l01?nU`^ooYL;^ojG2k_nV`nh3ojc5
k0?o//OZ0_nkbnH3olo@fP?of]7@0ooZdK/4ooC=Y`03oo?=Yol0003oml^M00?oml^M00OonlB:oo_5
ROokaHWonlF9oog8Q_oocgSog<8o00Cooooo00?o0000ooooooooool00_ooool002kooooo00?o0000
ooooooooool03_ooool01?l0>K3oEZCgognfmomo]_L3oi:mm004oj72l?nS`^ooXl;_oj?2k`;oYL?^
0_nV`nh3ojO4kPKoYl?^1OnV`nh2ojO3kRGoY/?^1?nU`nh2ojK3kPOoYL?^00?oYL?_ojG3k_nU`nh0
1onU`nh4ojG3k`;oYL?^00?oYL?_ojG3k_nU`nh00onU`nh00onU`^ooYL?_ojG3k`04ojG3k`03ojC3
konT`^ooYL;^00;oYL;^0_nU`nl4ojC3k`;oYL?_9?nT`^lBoj?2k`;oY<;_0_nU`^h2ojK3kP?o[<G/
0_nbanX3ok_;iP;ocm3J0ooJdM04on[A^`?om<fW00?ollfWooO;WOl000001?ogbid3oo_5R@03oog8
Q_oocgSog<8o00Cooooo00?o0000ooooooooool00_ooool002oooooo00?o0000ooooooooool03ooo
ool00omGY?OoOkKgognfm`03oi:mm004oj72l?nS`^ooXl?_oj?3k`;oYL?_0onV`nh5ojO3kP?oYlC^
0onV`nh4ojO3kRGoY/?^1?nU`nh2ojK3kP03ojG3k_nU`nooYL?^00_oYL?^0onU`nl8ojG3kPOoYL?_
1?nU`^h00onT`^ooY<?_ojG3k`04ojG3k`;oY<;_00CoY<?_ojC2konU`^koYL;^9?nT`^lBoj?2k`04
ojC2konU`^koYL;^ojG2kP;oY/?^0_n/aN`3ok;7jP?o^l_V0_o?d=X3om[Ad0Coj]6k0_odcJL2oo?=
Y`03o`000?ogbigoml^M00;oml^M0_okaHT01?olaXSooLR6ooo?N?oL`Sl4ooooo`03o`000?oooooo
oooo00;ooooo000`ooooo`03o`000?oooooooooo013ooooo00?oEZCgognfmonB_O@00_nB_O@2oj72
l004oj?3konS`^ooYL?^ojG3kP?oY/?^1?nW`nh01?nWa>koYl?^ojO3k_nW`nh3ojK3kPGoYl?^9?nV
`nh4ojG3kP;oY/?^00?oYL?_ojG3k_nU`nh01OnU`nh3ojG3k`[oYL?^1?nU`nl2ojG3kP03ojG3konU
`nkoYL?^00;oYL;^1?nU`nl2ojC3k`?oYL?_0_nU`^h2ojC2k`CoY<?_9?nT`^lAoj?2k`;oY<;_0onU
`^h2ojK3kP;o[<G/0onbanX2ok_;iP?ocm3J0ooJdM04on[A^`CollfW00?o0000ooO;WOogbid00_og
bid01?okaHWooLR6oog8Q_oocgP5ooooo`03o`000?oooooooooo00;ooooo000aooooo`;o00004Ooo
ool00omFY?OoOkKgognfm`02oi:mm0;oXL;`0_nS`^l2ojG3kP?oY/?^2?nW`nh5ojK3kP?oYl?^9?nV
`nh4ojG3kP?oY/?^1_nU`nh00onU`nooYL?^ojG3kP06ojG3kPGoYL?_00CoYL?^ojG3konU`^koYL;^
0onU`nh8ojG3k`03ojC3konT`^ooYL;^00;oYL;^0_nU`nl00onT`^ooY<?_ojC3k`03ojC3kbCoY<;_
4OnS`^l2ojC2k`?oYL;^0_nV`nh2ojc5k0?o//OZ00Co^l_Vok_:i_o?d=[ocm3J1?oJdM03on[A^`Co
llfW00?ollfXo`000?ogbid00_ogbid01?ohc9gooLR6ooo?N?oL`Sl5ooooo`03o`000?oooooooooo
00;ooooo000cooooo`03o`000?oooooooooo00oooooo00GoEjCgognfmomo]_OoOkKgoi:mm002oj72
l004oj?2konS`nooYL?_ojG3k`?oY/?^2OnW`nh4ojK3kP?oYl?^9?nV`nh4ojG3kP?oY/?^3OnU`nh2
ojG3k`KoYL?^00?oYL;^ojG3konU`nl01onU`nl3ojG2kP03ojC2konT`nooY<?_00CoYL?_0_nT`^l0
0onT`nooY<;_ojC2k`02ojG2kR?oY<;_4_nS`^l3ojC2k`04ojG2k_nV`nkoY/?^ojK3kP;o[<G/0_nb
anX3ok_:iP;ocm3J0ooJdM04on[A^`?ollfW00?ollfXoo?=Yol000000_ogbid01?ohc9gooLR6ooo?
N?oL`Sl6ooooo`03o`000?oooooooooo007ooooo000dooooo`03o`000?oooooooooo00oooooo00Go
03V`oeJTmomn]_OoO[Kgoi:mm002oj72l004oj?3konS`^ooXl;_ojG3k`?oY/?^2OnW`nh2ojK3kPGo
Yl?^9?nV`nh4ojG3kP?oY/?^1onU`nh3ojG3k`[oYL?^1?nU`nl2ojG3kP03ojG3konU`^koYL;^00;o
YL;^0onU`nl3ojC3k`?oYL?_00?oYL;^ojC2konT`^l00onT`^l00onU`nooY<?_ojC2k`0RojC2ka;o
Xl;_0_nT`^l2ojG2kP?oY/?^00Co[<G/ok;7j_nban[o//OZ0_nkb^H4olo@fP;of]7@1?oZdK/2oo?=
Y`03oo?=Z?occJOo000000;oml^M00Con<bMoo_AV_oocgSog<8o1_ooool00ol0003oooooooooo`01
ooooo`00=Oooool00ol0003oooooooooo`0?ooooo`05o`0i/?mFY?OoOkKgognfmonB_O@00_nQ`_03
oj?2k`04ojG3k_nU`nooY/?^ojK3kPWoYl?^1OnV`nh2ojO3kRCoY/?^1?nU`nh3ojK3kPKoYL?^00?o
YL?_ojG3k_nU`nh01OnU`nh3ojG3k`CoYL?^00?oYL?_ojG2k_nU`^h00_nU`nh00onU`^koYL?_ojG3
k`05ojG3k`03ojC3konT`^ooY<;_00?oYL;^00?oYL?_ojC2konT`nl01?nT`nl00onU`^koY<;_ojC2
k`0QojC2ka7oXl;_0onT`^l2ojG2kP;oY/?^0_n/aN`3ok;7jP;o^l[V0oo?d=X3om[Ad0Coj]6k0_oc
cJP02?occJOom<jWo`000?ohc9gonLjLoo_AV_ongXWo00001_ooool00ol0003oooooooooo`01oooo
o`00=_ooool2o`00013ooooo00Go03V`oeNTm_mo]_OoOkKgoi:mm003oj72l0;oXl?_0onU`nl00onV
`nkoYl?^ojO3kP07ojO3kPCoY/?^0onW`nhSojK3kPGoYL?^0_nV`nh=ojG3kP03ojG3konU`nkoYL?^
00;oYL?_1?nU`nh00onU`^koYL?_ojG3k`07ojG3k`?oYL;^0onT`^l4ojG3k`05ojC3konT`^ooY<;_
ojC2k_nU`^h00_nU`^lSojC2ka7oXl;_0onT`^l2ojG2kP;oY/?^0_n[aN`2ok;7jP?o^l[V0oo?d=X3
om[Ad0Coj]6k00SollfWooC=YoodcZOom<jWo`000?oicYconm6JookNR@Oooooo00?o0000oooooooo
ool00Oooool003Sooooo00?o0000ooooooooool03oooool00omFY?OoO[Kgogjfm`02oi:mm0;oXL;`
0_nS`^l01?nU`nooYL?^ojG3k_nV`nh:ojO3kP;oY/?^00CoYl?^ojK3k_nW`nkoYl?^8onV`nh5ojG3
kP;oY/?^5?nU`nh7ojG3k`GoYL;^1?nU`nl2ojC3k`04ojG3konU`^koYL;^ojG2kPCoY<;_00?oYL;_
ojC3konT`nl08onT`^lAoj?2k`;oY<;_0_nU`^h3ojK3kP;oZlG/0_nbanX3ok_:iP?ocm3J0ooJdM03
on[A^`08oo?=YoodcJOom<jWooC>Yol0003onm6JoogEV?ongXT7ooooo`03o`000?oooooooooo007o
oooo000iooooo`03o`000?oooooooooo00oooooo0_mFY?L00omo]_OoT[gdoi:mm002oj72l0;oXl;_
00CoYL?^ojG3konU`nooY/?^2_nW`nh4ojK3kP;oYl?^8onV`nh5ojG3kP;oY/?^4?nU`nh2ojG3k`;o
YL?^0onU`nl4ojG2kP;oYL?^1OnU`nl2ojG2kP04ojC2k_nU`^koYL;_ojG2k`;oYL;^00?oY<;_ojC3
konT`nl00_nT`nl2ojG2kR;oY<;_4_nS`^l2ojC2k`;oYL;^0onV`nh2oj_5k0;o//OZ0_nkb^H3olo@
fP?of]7@1?oZdK/3ooC>Y`04ooKBYol0003oo]j9o`0000Oooooo00?o0000ooooooooool00Oooool0
03[ooooo00?o0000ooooooooool03oooool2oeNTmP03ognfmonB_OCoT[gd00;oXL;`0_nS`^l3ojG3
k`03ojK3k_nW`nkoYl?^00SoYl?^1?nV`nh2ojO3kR?oY/?^1OnU`nh2ojK3kQ3oYL?^0_nU`nl2ojG3
kP?oYL;^00?oYL?_ojG3k_nU`nl01?nU`nl4ojG2kP;oYL?^00?oY<;_ojG2konU`nl00onU`nl01?nT
`nooY<;_ojC2konT`^l3ojG2kR;oY<;_4OnS`^l3ojC2k`;oYL;^0_nV`nh3oj_5k0;o//OZ0_nkb^H3
olo@fP?of]7@1?oZdK/01?odcZOom<nWooKBYooheZD2o`0000Sooooo0Ol00001ooooo`7ooooo000k
ooooo`03o`000?oooooooooo00oooooo0_mFY?L00omo]_OoT[gdoi:mm003oj72l005oj?2konU`noo
YL?^ojG3k_nV`nh02_nW`nh4ojK3kP;oYl?^8onV`nh6ojG3kP03ojK3k_nU`nkoYL?^00koYL?^00?o
YL;^ojG3k_nU`nh00_nU`nh4ojG3k`GoYL;^00CoYL;_ojG3k_nU`nkoYL?^0_nU`nl00onT`nooYL?_
ojG2kP03ojG2kPCoY<;_00?oYL;^ojG2konT`^l08_nT`^lAoj?2k`?oY<;_00CoYL;^ojK3k_nV`nko
Y/?^0_n[aN`2ok;7jP?o^l[V0oo?d=X3om[Ad0?oj]6k00Kom<jWooC?YoofdZOon=JUoo[WT_l00008
ooooo`7o00000Oooool1ooooo`00??ooool2o`00013ooooo0_mFY?L00omn]_OoT[gdoi:mm003oj72
l004oj?2konU`nkoYL?^ojG3kP?oY/?^2?nW`nh4ojK3kP?oYl?^8onV`nh3ojG3kP?oY/?^4OnU`nh0
1?nU`nooYL?^ojG3k_nU`nl4ojG2kPCoYL?^00?oYL;_ojG3konU`nl00_nU`nl00onU`^koY<;^ojC2
kP04ojG2kPKoY<;_00?oYL;_ojC2konT`^l08OnT`^lBoj?2k`04ojC2konU`^koYL;^ojG2kP;oY/?^
0_n[aN`3ok;7jP04ok_:i_o?d=[ocm3Jolo@fPCof]7@0_oZdK/01_o[dkcom]:WooKBYookfj?on^NB
o`0000Sooooo0Ol00001ooooo`7ooooo000nooooo`03o`000?oooooooooo00kooooo0_mGY?H01?mo
]_OoT[gdoi:mm?nB_O@2oj72l004oj?2konS`nooYL?_ojG3k`?oY/?^2?nW`nh4ojK3kP?oYl?^8onV
`nh2ojG3kP04ojK3k_nU`nkoY/?^ojK3kPkoYL?^0onU`nl01?nU`^koYL?^ojG3k_nU`^h4ojG3kPCo
YL?_1_nU`^h2ojC2kP03ojG2k_nU`^ooYL;_00;oYL;^1?nT`^l2ojG2kb?oY<;_4OnS`^l2ojC2k`?o
YL;^00CoYL?^oj_5k?n[aNcoZlG/0_nbanX3ok_:iP;ocm3J0ooJdM001_oZdK_ojm:lon_C_?o^f;co
n=JUoo_KX`;ooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool003oooooo00?o0000
ooooooooool03_ooool2oeJTmP;oOkKg0_nB_O@2oj72l004oj?3konS`^ooYL?^ojG3kP?oY/?^2?nW
`nh4ojK3kP?oYl?^8onV`nh4ojG3kP;oY/?^3_nU`nh2ojG2kPGoYL?^1?nU`nl7ojG2kP?oYL?^0onT
`^l01?nU`^ooYL;^ojG2k_nU`^h4ojC2k`;oYL;_8onT`^lAoj?2k`;oY<;_0_nU`^h2ojG3kP?oZlG/
0_nbanX2ok_:iP?ocm3J00?of]7@om[Bd?oKdm400_o[dk`00oo^f;com>Jkol;RN@03ooooo`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`7ooooo0010ooooo`03o`000?oooooooooo00oooooo00?o
03V`ogjfmomn]_L00_nB_O@2oj72l0;oXl;_0_nU`nh3ojK3kPSoYl?^1?nV`nh3ojO3kR?oY/?^0onU
`nh3ojK3kQ3oYL?^0_nU`nl2ojG3kP03ojG3konU`^koYL;^00CoYL;^0_nU`nh2ojG2k`04ojG3k_nU
`^koYL;^ojG2kP;oY<;_0_nU`^l3ojG2kPCoY<;_0_nU`^lSojC2ka7oXl;_0_nT`^l2ojG2kP;oYL?^
0_n[aN`3ok;7jP03ok_:i_nkbnKocm3J00;ocm3J00Oof];@om_CdOoKe=7ok]Rloo3M_?odi[_o`^9i
00Cooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool0047ooooo0_l0000@ooooo`05
o`0i/?mo]_OoOkKgognfmonB_O@00_nQ`_03oj?2k`04ojG3konV`nkoY/?^ojK3kPSoYl?^1OnV`nh2
ojO3kR?oY/?^0_nU`nh00onV`nkoYL?^ojK3kP02ojK3kPkoYL?^00CoYL?_ojG2k_nU`^koYL?^1?nU
`^h6ojG3kP;oYL;_1?nU`^h2ojC2k`GoYL;^1?nT`^l2ojG2kR;oY<;_4OnS`^l2ojC2k`?oYL;^0_nU
`nh2oj_5k0;o//OZ00_o^l_Vok_;ionkbnOocm3Jom3AfooKdm7ofmCAomgJdooPh]Kom>Jkol;RN@05
ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oooooooooo
00kooooo00Go03V`oeJTmomn]_OoO[Kgoi:mm002oj72l0?oXl;_0_nU`nh2ojK3kPSoYl?^1_nV`nh0
0onW`nkoY/?^ojK3kP0QojK3kPCoYL?^0onV`nh=ojG3kPCoYL;^1OnU`nh00onU`^koYL?^ojG3kP03
ojG3kPKoYL;^0_nT`^l4ojG2kPGoY<;_0_nU`^hRojC2ka7oXl;_0_nT`^l2ojG2kP?oYL?^0_n[aN`0
0onban[o//S[ok_;i`02ok_<i`06om3Afoo@d]_od][NomgJdooPh]Koao^j1oooool00ol0003ooooo
ooooo`03ooooo`7o00000Oooool004Cooooo00?o0000ooooooooool03_ooool01Ol0>K3oEj?fognf
momo]_OoT[gd00?oXL;`0_nS`^l2ojG3kP;oY/?^2OnW`nh5ojK3kP03ojO3k_nV`nkoY/?^027oY/?^
0_nU`nh5ojK3kPcoYL?^00?oYL;^ojG3k_nU`nh01_nU`nh2ojG2kPGoYL?^1OnU`^h3ojC2k`CoYL;^
1?nT`^l3ojG2kR;oY<;_4OnS`^l2ojC2k`;oYL;^00GoYL?^ojG3konU`nooZlG]ok;8j`02ok;9j`03
ok_<ionkcNSod=;K00;od][N00?oh>;Fon?_eoooool02?ooool00ol0003oooooooooo`02ooooo`7o
00000Oooool004Gooooo00?o0000ooooooooool03_ooool01Ol0>K3oEj?fognfmomo]_OoT[gd00?o
XL;`0_nS`^l2ojG3kP;oY/?^2OnW`nh3ojK3kP?oYl?^8onV`nh4ojG3kP?oY/?^5OnU`nh2ojG2kP?o
YL?^2?nU`^h2ojC2k`CoYL;^1?nT`^l3ojG2kR;oY<;_4OnS`^l00onT`^ooXl;_ojG3k`02ojG3k`06
ojG4kon[ankoZlS^oj_8k_nbb^co^lgX0_nkeNd00ooBf]koe>;RomC`i@0;ooooo`05o`000?oooooo
ooooooooool000000Oooool004Kooooo0_l0000@ooooo`03oeJTm_mn]_OoO[Kg00;oT[gd0_nQ`_02
oj?2k`;oYL?^0_nV`nh9ojO3kP;oY/?^00CoYl?^ojK3k_nV`nkoYl?^8onV`nh3ojG3kP?oY/?^5_nU
`nh2ojG2kP?oYL?^2?nU`^h2ojC2k`CoYL;^1?nT`^l3ojG2kR7oY<;_4_nS`^l2oj?4l0;oY<C`00Go
YLC_ojG5l?n[b>koZ/ocok7Bl@02ojoJmP03ok_NlOnfk?Koe?3U00cooooo00Go0000oooooooooooo
ooooo`000001ooooo`00B?ooool00ol0003oooooooooo`0>ooooo`03oeJSm_mo]_OoOkKg00;oT[gd
0_nQ`_02oj?2k`;oYL?^0onV`nh8ojO3kPGoY/?^0_nW`nhSojK3kP03ojG3k_nV`nkoY/?^00;oY/?^
5_nU`nh2ojG2kP;oYL?^2OnU`^h00onT`^ooYL;^ojG2kP03ojG2kPGoY<;_00?oYL;^ojC2konT`^l0
8?nT`^l>oj?2k`;oXl?`0_nSa?401?nSaO7oY<G`oj;<m_nRc?H2oj?<m@04oj[?lonWeoSo[m[fojSW
nQ3ooooo00Co0000oooooooooooo00000Oooool004Wooooo00?o0000ooooooooool03_ooool00onN
603oEZCfognfm`03oi:mm005oj72l?nS`^ooXl;_oj?2konU`nh00onV`nh8ojO3kP?oY/?^1?nW`nhR
ojK3kP;oYL?^1?nV`nhFojG3kP;oYL;^0_nU`nh9ojG2kP;oY<;^1?nU`^h3ojC2k`;oY<;^00?oYL;^
ojC2konT`^l07_nT`^l9oj?2k`GoXl?`1?nSa?43oj7;mP06oj;<m_nNe?[oW]CjoioDn_nDgokoW^?m
4oooool00ol0003oooooo`000001ooooo`00B_ooool00ol0003oooooooooo`0?ooooo`03oeJSm_mn
]_OoOkKg00;oT[gd00GoXL;`oj?2konS`^ooXl;_ojG3kP03ojK3kPSoYl?^1OnV`nh2ojO3kR;oY/?^
0_nU`nh4ojK3kQCoYL?^1?nU`^h00onU`nkoYL;^ojG2kP07ojG2kP?oY<;^1?nU`^h2ojC2k`;oY<;^
0_nU`^hPojC2k`GoXl;_1?nS`o04oj?4l@GoXL_f0_nMdo/00onAgOkoTmknooooo`0Fooooo`03o`00
0?oooooo0000007ooooo001;ooooo`;o00004?ooool2oeNSmP04ognfmonB_OCoT[gdoj72l0?oXl;_
00CoYL?^ojK3k_nV`nkoY/?^2?nW`nh4ojK3kP?oYl?^8_nV`nh3ojG3kPCoY/?^3onU`nh2ojG2kP;o
YL?^3_nU`^h3ojC2kPCoYL;^0_nT`^l2ojC2kP;oYL;^7?nT`^l5oj?2k`CoXl?`1?nSa?42oj7;mP?o
WM;k00CoWM?koi7Mo_nAgOkoTMgn6oooool1o`00007ooooo0Ol0000004gooooo00?o0000oooooooo
ool03_ooool2oeJSmP03ognfmonB_OCoT[gd00;oXL;`0_nS`^l2ojG3kP;oY/?^2?nW`nh3ojK3kP04
ojO3k_nV`nkoYl?^ojO3kR;oY/?^0onU`nh4ojK3kPooYL?^00CoYL;^ojG3k_nU`nkoYL?^3_nU`^h3
ojC2kPCoYL;^0_nT`^l2ojC2kP;oYL;^6onT`^l00onS`^ooXl?`oj?3l002oj?3l0?oXlCa1?nQboH2
oigBnP?oT]gn8Oooool2o`000000C_ooool00ol0003oooooooooo`0>ooooo`;oEZ?f00?oOkKgoi:m
m?nB_O@00_nQ`_02oj?2k`;oYL?^0_nV`nh9ojO3kPCoY/?^0_nW`nhRojK3kP?oYL?^1?nV`nh?ojG3
kP04ojG2k_nU`nkoYL?^ojG3kPooYL;^00?oY<;^ojG2k_nU`^h00onU`^h01?nT`^ooY<;^ojC2k_nT
`^h2ojG2kPCoY<;_0_nT`^h00onT`^ooY<;^ojC2k`0=ojC2k`CoXl?`1?nSa?43oj7;m@04oj7;m_nM
d_[oWM;joigBnP;oT]cn00?o<kVfooooooooool08Oooool3o`000000Coooool00ol0003ooooooooo
o`0>ooooo`;oEj?f00?oOkKgoi:mm?nB_O@00_nQ`_02oj?2k`;oYL?^0onV`nh8ojO3kP?oY/?^1?nW
`nhQojK3kP;oYL?^1OnV`nh=ojG3kP?oYL;^0onU`nh?ojG2kP03ojC2k_nU`^koYL;^00;oYL;^1?nT
`^h3ojG2kP?oY<;_0_nT`^h8ojC2k`;oY<?_0onT`^l3ojC3l003oj?3l?nSa?3oXlCa00;oXlCa0_nQ
boD3oikBnP04oigBn_nCg?koTmcnoi?LoR?ooooo1?l00003ooooo`00D?ooool00ol0003ooooooooo
o`0>ooooo`03oilI0?mFXoKoOkKg00?oT[gd00GoXL;`oj?2konS`^ooXl;_ojG3kP03ojK3kPSoYl?^
0onV`nh4ojO3kR;oY/?^00?oYL?^ojK3k_nV`nh00_nV`nh>ojG3kPCoYL;^00?oYL?^ojG2k_nU`^h0
3OnU`^h2ojC2kPGoYL;^1?nT`^h2ojG2kP03ojC2k_nT`^ooY<;_00KoY<;_1?nT`nl3ojC4l003ojC3
l?nSa?3oXlC`00;oXlC`0_nRboD00onQboGoW];joikBnP02oikBnP03oiCLo_nCg?kooooo02;ooooo
1?l00007ooooo`00DOooool2o`00013ooooo00?oEj?fognfmomo]_L00_nB_O@01OnQ`_3oXl;_oj?2
konS`^ooYL?^00?oY/?^2?nW`nh3ojK3kPCoYl?^8_nV`nh00onU`nkoY/?^ojK3kP02ojK3kPkoYL?^
5?nU`^h3ojC2kPCoYL;^1?nT`^h00onU`^koY<;_ojC2k`04ojC2k`CoY<?_1OnTa?000onSa?3oX/_e
oj;;m@02oj;;m@?oW];j0_nDg?h00olk_kooooooooooo`0Qooooo`Co00002oooool005?ooooo00?o
0000ooooooooool03_ooool2oeNSmP04ognfmonB_OCoT[gdoj72l0?oXl;_0_nU`nh2ojK3kPSoYl?^
0onV`nh4ojO3kR7oY/?^0onU`nh4ojK3kPcoYL?^5OnU`^h2ojC2kPCoYL;^0_nT`^l00onT`^koY<;_
ojC2k`02ojC2k`?oY<?_2?nTa?04oj;;m@;oW];j0_nEg?h00onDg?koooooooooo`0Rooooo`?o0000
3oooool005Cooooo00?o0000ooooooooool03_ooool2oeJSmP03ognfmonB_OCoT[gd00;oXL;`0_nS
`^l2ojG3kP;oY/?^2OnW`nh2ojK3kPCoYl?^8OnV`nh3ojG3kPCoY/?^1onU`nh4ojG2kP03ojG3k_nU
`^koYL;^01?oYL;^0_nT`^h4ojG2kP03ojC2konT`nooY<?_00;oY<?_2OnTa?02oj;;m@?oWm;j00Co
W];joiGLo_nEg?ko?l;28oooool4o`0001;ooooo001Eooooo`03o`000?oooooooooo00kooooo0_mG
XoH00omo]_OoT[gdoi:mm002oj72l0;oXl;_0_nU`nh2ojK3kPWoYl?^0_nV`nh4ojO3kR7oY/?^0onU
`nh4ojK3kPKoYL?^1?nU`^h2ojG3kQGoYL;^0_nT`^l01OnU`^koY<?_ojG3konU`nooY<?_00CoY<C`
0_nTaO02ojC4l0?oX/_e0onOdOT00onOd_[o@LC5ooooo`0Sooooo`Co00005_ooool005Kooooo0_l0
000?ooooo`;oEj?f00GoOkKgoi:mm?nB_OCoT[gdoj72l003oj?2k`04ojG3k_nV`nkoY/?^ojK3kPSo
Yl?^0_nV`nh4ojO3kR;oY/?^0_nU`nh4ojK3kPKoYL?^1?nU`^h3ojG3kQ?oYL;^00KoYL?_ojC3konT
`nooY<?_ojC4l?nTa>l2ojC5l006ojC4l?nTaO3oX/_eoj;;mOnSboCoX/_e0onOdOT2oiKLoP03od?5
a_oooooooooo027ooooo1?l0000Jooooo`00F?ooool00ol0003oooooooooo`0>ooooo`03oeNSm_mo
]_OoT[gd00;oT[gd00GoXL;`oj?2konS`^ooXl;_ojG3kP03ojK3kPSoYl?^0_nV`nh4ojO3kR;oY/?^
00?oYL?^ojK3k_nV`nh00_nV`nh7ojG3kPCoYL;^00?oYL?^ojG2k_nU`^h02_nU`^h2ojG3kP;oYL;^
0onU`nl3ojG4k`03ojC4l?nTaO3oY<G`00;oY<G`00CoXl_doj;:mOnRb_GoX/_e0_nOdOT2oiOLoP03
oiKKo_oooooooooo027ooooo1?l0000Nooooo`00FOooool00ol0003oooooooooo`0>ooooo`;oEj?f
00CoOkKgoi:mm?nB_OCoXL;`0onS`^l2ojG3kP;oY/?^2?nW`nh2ojK3kPCoYl?^8_nV`nh2ojG3kPCo
Y/?^0_nU`^h4ojG3kP[oYL;^1?nU`nh00onU`^koYL?_ojG3k`02ojG3k`;oYLC_0_nTa>l00onUa>oo
Y<G`ojC5l002ojC5l003oj;;m?nSboCoWm7i00;oX=7i00?oWm7ioiKKo_nFg?h08oooool4o`0002;o
oooo001Jooooo`03o`000?oooooooooo00kooooo0_mGXoH00omo]_OoT[gdoi:mm002oj72l0;oXl;_
0_nU`nh2ojK3kPWoYl?^00?oY/?^ojO3k_nW`nh00_nW`nhRojK3kP;oYL?^1?nV`nh2ojG2kP04ojG3
k_nU`^koYL?^ojG3kP?oYL;^0onU`nh00onU`^koYL?^ojG3kP02ojG3kPCoYL?_1?nUa>l3ojC5l0Co
Xl_d00GoX=7ioioAnOnGfokoUm_noiOLoP0Sooooo`Co00009_ooool005_ooooo0_l0000?ooooo`03
oeNSm_mo]_OoOkKg00;oT[gd0_nQ`_02oj?2k`;oYL?^0onV`nh8ojO3kP03ojK3k_nW`nkoYl?^00?o
Yl?^8?nV`nh3ojG3kPCoY/?^1?nU`^h9ojG3kPCoYL?_0_nUa>l2ojG5l003ojC5l?nUaO3oXl_d00?o
Xl_d0onPdOT2oiOLoP03odO8b_oooooooooo023ooooo1?l0000Zooooo`00GOooool00ol0003ooooo
ooooo`0=ooooo`03o`0j/Omo]_OoOkKg00;oT[gd0_nQ`_02oj?2k`;oYL?^0_nV`nh9ojO3kP;oY/?^
1?nW`nhQojK3kP;oYL?^1?nV`nh00onU`^koYL?^ojG3kP06ojG3kP03ojG3konU`nkoYLC_00?oYLC_
1?nUaO03oj?;m0CoX=7i00?oUmcnoiOKo_m7b<X08_ooool3o`0002kooooo001Nooooo`03o`000?oo
oooooooo00gooooo00Go03ZaoeNSm_mo]_OoOkKgoi:mm002oj72l0;oXl;_0_nU`nh2ojK3kPSoYl?^
0onV`nh4ojO3kR7oY/?^00?oYL;^ojK3k_nV`nh00onV`nh6ojG3kP03ojG3konUa>ooYLC_00;oYLC_
1?nUaO02oj?;m0;oX=;i00CoX=7ioiSLo_nGg?koB<S;8oooool4o`00037ooooo001Oooooo`03o`00
0?oooooooooo00gooooo00Go03ZaoeNSm_mo]_OoOkKgoi:mm003oj72l005oj?2konU`nkoYL?^ojG3
k_nV`nh02OnW`nh2ojK3kPCoYl?^8OnV`nh2ojG3kPCoY/?^0_nU`nl00onU`nkoYLC_ojG4k`02ojG4
k`;oYLG`1?nSbo@2oj3Bn@04oj3AnOnHg?koV=cnodW9bb;ooooo1?l0000eooooo`00H?ooool2o`00
00oooooo00CoEjCfognfmomo]_OoT[gd0onQ`_001OnS`^ooYL?^ojG3k_nU`nkoY/?^00WoYl?^0_nV
`nh4ojO3kR7oY/?^1?nU`nh00onV`nkoYLC_ojG4k`04ojG5l006ojC;m?nSboCoXl_doj?;m?nPd_Wo
XM;i0onHg?hRooooo`Co0000>Oooool006;ooooo00?o0000ooooooooool03Oooool00ol0>[7oOkKg
ognfm`02oi:mm0;oXL;`0_nS`^l2ojG3kP;oY/?^2?nW`nh3ojK3kP?oYl?^8?nV`nh01?nVa>ooYLC_
ojG4konUa>l4ojG5l0;oXl_d0onQd_T00onPd_WoV=cnodS8bP0Rooooo`Co0000?Oooool006?ooooo
00?o0000ooooooooool03Oooool01Ol0>[7oEjCfognfmomo]_OoT[gd00;oXL;`0_nS`^l2ojG3kP;o
Y/?^2?nW`nh2ojK3kPCoYl?^7?nV`nh01?nUa>ooY/C_ojK4konVa>l2ojG5l0CoY<_d0_nQd_T3oiSL
oP03odS8bOoooooooooo01oooooo1?l00011ooooo`00I?ooool00ol0003oooooooooo`0=ooooo`03
o`0j/_mGY?KoOkKg00;oT[gd00CoXL;`oj71l?nS`^ooXl;_0_nU`nh2ojK3kPWoYl?^00?oY/?^ojO3
k_nW`nh00_nW`nh5ojK3kP;oYl?^4?nV`nh3ojK4k`CoYLG`1?nTbo@2oj7Bn@?oV=cn8Oooool4o`00
04Gooooo001Uooooo`03o`000?oooooooooo00gooooo0_mGY?H00omo]_OoT[gdoi:mm002oj71l0;o
Xl;_0_nU`nh00onV`nkoYl?^ojO3kP08ojO3kP03ojK3k_nW`nkoYl?^00;oYl?^1OnV`nh00onW`nko
Y/?^ojK3kP0:ojK3kPCoY/C_00CoYLG`ojK5l?nVaO3oYLG`0_nTbo@4oj7Bn@03oiSLo_m7alSooooo
023ooooo1?l00019ooooo`00I_ooool2o`0000oooooo00?oEjCfognfmonB_O@00_nB_O@01OnQ`O3o
Xl;_oj?2konS`^ooYL?^00_oYl?^0_nV`nh4ojO3kPgoY/?^1?nVa>l3ojK5l003ojG5l?nTboCoY<_d
00;oXM;i0_nHgOh00onHg?koALK6ooooo`0Oooooo`Co0000COooool006Sooooo00?o0000oooooooo
ool03Oooool2oeRTmP04ognfmonB_OCoT[gdoj71l0?oXl;_00?oYL?^ojO3k_nW`nh02?nW`nh3ojK3
kPCoYl?^2OnV`nh4ojK4k`;oY/G`1?nTbo@2oj7Bn@?oV=gn8Oooool3o`00057ooooo001Yooooo`03
o`000?oooooooooo00gooooo0_mHY?H00omo]_OoT[gdoi:mm002oj71l004oj?2konU`nkoYL;^ojG2
kP[oYl?^0_nV`nh4ojO3kPGoY/?^0_nVa>l4ojK5l0;oY<cd1?nQdoT00onHgOko@lG3ooooo`0Poooo
o`Co0000E?ooool006[ooooo00?o0000ooooooooool03Oooool00ol0>k;oF:Cfognfm`02oi:mm0;o
XL7`0_nS`^l2ojG2kP[oYl?^0_nV`nh3ojO3kPCoY/C_1?nVaO02ojC<m0?oXM?i0_nHgOh00om1`l7o
ooooooooo`0Nooooo`Co0000F?ooool006_ooooo0_l0000>ooooo`05o`0k/_mHY?KoOkKgognfmonB
_O@00_nQ`Nl2oj?2k`;oYL;^2_nW`nh00onV`nkoY/C_ojK4k`02ojK4k`;oY/G`0onTc?@00onUc?Co
X]?ioj7Cn@02oiSNoP03oiSMo_oooooooooo01kooooo1?l0001Looooo`00KOooool00ol0003ooooo
ooooo`0<ooooo`06o`0j/_mHY?KoOkKgognfmonB_OCoXL7_0_nQ`O000onS`^ooYL?^ojG3kP07ojO3
kP;oYlG_0_nVa_02ojK5l0?oYLcd00GoX]Cioj7CnOnQdoWoV=knocg0_00Pooooo`Co0000H?ooool0
06kooooo00?o0000ooooooooool03Oooool01_mHY?KoOkKgognfmonB_OCoXL7`oj72l0;oXl;_0_nU
`nh00onV`nkoY/G_ojK5k`02ojK5k`CoY/K`0_nUc?@3oj7Dn@03oiONo_nHg_ko>kjj01oooooo1?l0
001Tooooo`00Koooool00ol0003oooooooooo`0=ooooo`03oeNTmomo]_OoOkKg00;oT[gd00KoXL;`
oj?3konSa?3oXlC`ojG4konVaNl3ojK6l0?oYLcd0onRe?T00onGgokoUmknooooo`0Nooooo`Co0000
J?ooool0073ooooo0_l0000>ooooo`;oE:Cg00GoO[Ohoi:nmOnB__GoXL?aoj74lP02oj?5l@03ojG5
l?nSc?GoY<ge00CoXMCj00?oUmonocBi/_ooool07Oooool4o`0006cooooo001booooo`03o`000?oo
oooooooo00_ooooo00Ko0000oooooom3Y?OoOKSioi6om_n<a_/2oik;m`03oj7<m_nLdo_oWmCj00;o
Tmon00?oU]onooooooooool07Oooool3o`00073ooooo001cooooo`03o`000?oooooooooo00[ooooo
00Co0000oooooooooooooooo0_mW`?h01?n3c?ooVM?loh_Lo_l0000Oooooo`Co0000Loooool007Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`Co0000Moooool007Gooooo
0_l00009ooooo`03o`000?oooooooooo01kooooo1?l0001kooooo`00Moooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01[ooooo1?l0001oooooo`00N?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo1?l00023ooooo`00NOooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01;ooooo1?l00027ooooo`00N_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00kooooo1?l0002;ooooo`00Noooool2o`0000?ooooo00?o0000ooooooooool0
2oooool3o`0008oooooo001mooooo`04o`000?ooooooooooo`0000Wooooo1?l0002Booooo`00O_oo
ool00ol0003oooooo`000005ooooo`Co0000U_ooool007oooooo0_l000000ooooooo0000o`000002
o`0009[ooooo0020ooooo`;o0000W_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00=7ooooo0ol0001<ooooo`00d_ooool00ol0003oooooooooo`1;ooooo`00H?ooool00ol0003o
ooooo`000003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00002?ooool3o`0000?o
oooo0ol00004ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00008ooooo`Go
000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003ooooo`?o00000_ooool3o`00
0003ooooool0003o000000Co00000_ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo
04[ooooo001Pooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`00
0?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
04[ooooo001Pooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`03o`000?oooooo000000;o
oooo1Ol00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000Boooool005oooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000;ooooo00Go0000ooooooooooooooooo`000008ooooo`?o00000oooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000oooo
ool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`00001;ooooo`00Goooool01Ol0003oooooo`000?oooooo000000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000Wooooo00?o0000ooooooooool00_ooool2o`000003oooo
ool0003o000000;ooooo0ol00002ooooo`Co00000_ooool4o`0000[ooooo00Co0000oooooooooooo
oooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0
003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`00001:ooooo`00Goooool01Ol0003o
ooooo`000?oooooo000001[ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1A
ooooo`00Goooool6o`0001Sooooo1Ol0000Dooooo`03o`000?oooooooooo00Sooooo1Ol00008oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Aoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0832748, 0.0535801, \
0.0036093, 0.0036093}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.14858 .19855 -11.9132 -9 ]
[.14858 .19855 .08677 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.53441 .04682 -5.21679 -9 ]
[.53441 .04682 .78321 0 ]
[.76878 .09907 0 -6.15989 ]
[.76878 .09907 12 2.84011 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93375 .35169 0 -5.92115 ]
[.93375 .35169 6 3.07885 ]
[.02405 .26549 -6 -2.74264 ]
[.02405 .26549 0 6.25736 ]
[.01589 .31663 -6 -2.78588 ]
[.01589 .31663 0 6.21412 ]
[.00746 .3695 -12 -2.83072 ]
[.00746 .3695 0 6.16928 ]
[-0.00127 .42418 -12 -2.87727 ]
[-0.00127 .42418 0 6.12273 ]
[-0.0103 .48077 -12 -2.92561 ]
[-0.0103 .48077 0 6.07439 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.1578 .2079 m
.1624 .21257 L
s
[(-5)] .14858 .19855 .98554 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54221 .05738 m
.54611 .06265 L
s
[(5)] .53441 .04682 .73893 1 Mshowa
.125 Mabswid
.19381 .1938 m
.19654 .19664 L
s
.23033 .1795 m
.23302 .18237 L
s
.26737 .16499 m
.27003 .1679 L
s
.30495 .15028 m
.30756 .15322 L
s
.38174 .12021 m
.38426 .12323 L
s
.42097 .10485 m
.42346 .1079 L
s
.46079 .08926 m
.46322 .09235 L
s
.5012 .07344 m
.50358 .07656 L
s
.12228 .22181 m
.12508 .22458 L
s
.08725 .23552 m
.09008 .23826 L
s
.0527 .24905 m
.05557 .25175 L
s
.58384 .04107 m
.58613 .04428 L
s
.62611 .02452 m
.62834 .02776 L
s
.66902 .00772 m
.6712 .011 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75647 .10361 m
.75032 .10588 L
s
[(-5)] .76878 .09907 -1 .36886 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92124 .35564 m
.91498 .35762 L
s
[(5)] .93375 .35169 -1 .31581 Mshowa
.125 Mabswid
.77493 .13184 m
.77123 .13319 L
s
.7929 .15933 m
.78919 .16065 L
s
.8104 .1861 m
.80669 .18741 L
s
.82745 .21219 m
.82373 .21348 L
s
.86028 .2624 m
.85655 .26365 L
s
.87608 .28658 m
.87235 .28781 L
s
.8915 .31016 m
.88776 .31138 L
s
.90655 .33318 m
.9028 .33438 L
s
.73751 .0746 m
.73382 .07599 L
s
.71802 .04479 m
.71434 .04619 L
s
.69798 .01413 m
.69431 .01556 L
s
.93558 .37758 m
.93182 .37875 L
s
.94958 .39901 m
.94582 .40016 L
s
.96327 .41994 m
.9595 .42108 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03628 .26072 m
.04239 .25833 L
s
[(0)] .02405 .26549 1 -0.39052 Mshowa
.02816 .31196 m
.03429 .30963 L
s
[(5)] .01589 .31663 1 -0.38092 Mshowa
.01976 .36493 m
.02591 .36265 L
s
[(10)] .00746 .3695 1 -0.37095 Mshowa
.01108 .41973 m
.01725 .4175 L
s
[(15)] -0.00127 .42418 1 -0.36061 Mshowa
.00209 .47644 m
.00828 .47427 L
s
[(20)] -0.0103 .48077 1 -0.34986 Mshowa
.125 Mabswid
.03467 .27084 m
.03834 .26941 L
s
.03306 .28102 m
.03673 .2796 L
s
.03144 .29126 m
.03511 .28985 L
s
.0298 .30158 m
.03348 .30017 L
s
.0265 .32241 m
.03018 .32102 L
s
.02483 .33294 m
.02851 .33155 L
s
.02315 .34353 m
.02684 .34215 L
s
.02146 .3542 m
.02515 .35282 L
s
.01805 .37574 m
.02174 .37438 L
s
.01632 .38663 m
.02002 .38527 L
s
.01459 .39758 m
.01828 .39624 L
s
.01284 .40862 m
.01654 .40727 L
s
.00931 .43091 m
.01301 .42958 L
s
.00752 .44217 m
.01123 .44085 L
s
.00572 .45352 m
.00943 .4522 L
s
.00391 .46494 m
.00763 .46363 L
s
.00026 .48802 m
.00397 .48672 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.662 .764 .926 r
.39479 .8031 .39806 .80578 .40353 .80432 .40027 .80145 Mtetra
.674 .755 .912 r
.40027 .80145 .40353 .80432 .40901 .80268 .40577 .79963 Mtetra
.684 .746 .898 r
.40577 .79963 .40901 .80268 .41451 .80088 .41128 .79766 Mtetra
.692 .738 .886 r
.41128 .79766 .41451 .80088 .42002 .79892 .4168 .79553 Mtetra
.697 .73 .875 r
.4168 .79553 .42002 .79892 .42555 .79682 .42234 .79326 Mtetra
.702 .722 .865 r
.42234 .79326 .42555 .79682 .43109 .79459 .42789 .79086 Mtetra
.706 .715 .856 r
.42789 .79086 .43109 .79459 .43665 .79224 .43346 .78835 Mtetra
.708 .708 .848 r
.43346 .78835 .43665 .79224 .44221 .78977 .43903 .78572 Mtetra
.711 .702 .84 r
.43903 .78572 .44221 .78977 .44778 .78719 .44461 .78299 Mtetra
.712 .696 .833 r
.44461 .78299 .44778 .78719 .45337 .78453 .45021 .78017 Mtetra
.713 .69 .827 r
.45021 .78017 .45337 .78453 .45896 .78177 .45581 .77727 Mtetra
.714 .685 .821 r
.45581 .77727 .45896 .78177 .46456 .77894 .46142 .7743 Mtetra
.714 .68 .816 r
.46142 .7743 .46456 .77894 .47017 .77604 .46703 .77126 Mtetra
.714 .675 .811 r
.46703 .77126 .47017 .77604 .47579 .77307 .47266 .76816 Mtetra
.714 .671 .806 r
.47266 .76816 .47579 .77307 .48141 .77006 .47829 .76501 Mtetra
.713 .666 .802 r
.47829 .76501 .48141 .77006 .48705 .76699 .48393 .76182 Mtetra
.713 .662 .798 r
.48393 .76182 .48705 .76699 .49269 .76389 .48958 .7586 Mtetra
.712 .658 .795 r
.48958 .7586 .49269 .76389 .49833 .76076 .49523 .75535 Mtetra
.711 .654 .792 r
.49523 .75535 .49833 .76076 .50399 .75761 .50089 .75208 Mtetra
.71 .651 .789 r
.50089 .75208 .50399 .75761 .50965 .75444 .50655 .74879 Mtetra
.708 .647 .786 r
.50655 .74879 .50965 .75444 .51531 .75126 .51222 .7455 Mtetra
.707 .644 .784 r
.51222 .7455 .51531 .75126 .52098 .74808 .5179 .74221 Mtetra
.706 .641 .782 r
.5179 .74221 .52098 .74808 .52666 .74489 .52358 .73893 Mtetra
.704 .637 .78 r
.52358 .73893 .52666 .74489 .53235 .74172 .52927 .73566 Mtetra
.702 .634 .778 r
.52927 .73566 .53235 .74172 .53804 .73856 .53497 .7324 Mtetra
.7 .631 .776 r
.53497 .7324 .53804 .73856 .54374 .73542 .54067 .72917 Mtetra
.698 .628 .775 r
.54067 .72917 .54374 .73542 .54944 .73231 .54638 .72597 Mtetra
.696 .626 .773 r
.54638 .72597 .54944 .73231 .55515 .72922 .55209 .7228 Mtetra
.694 .623 .772 r
.55209 .7228 .55515 .72922 .56087 .72617 .55782 .71967 Mtetra
.692 .62 .771 r
.55782 .71967 .56087 .72617 .5666 .72315 .56355 .71657 Mtetra
.69 .617 .77 r
.56355 .71657 .5666 .72315 .57234 .72018 .56928 .71353 Mtetra
.688 .615 .769 r
.56928 .71353 .57234 .72018 .57808 .71726 .57503 .71054 Mtetra
.686 .612 .768 r
.57503 .71054 .57808 .71726 .58383 .71439 .58078 .7076 Mtetra
.683 .61 .768 r
.58078 .7076 .58383 .71439 .58959 .71157 .58654 .70472 Mtetra
.681 .608 .767 r
.58654 .70472 .58959 .71157 .59536 .70881 .59231 .7019 Mtetra
.678 .605 .767 r
.59231 .7019 .59536 .70881 .60114 .70611 .59809 .69914 Mtetra
.676 .603 .766 r
.59809 .69914 .60114 .70611 .60693 .70347 .60388 .69645 Mtetra
.673 .601 .766 r
.60388 .69645 .60693 .70347 .61273 .7009 .60968 .69383 Mtetra
.67 .598 .766 r
.60968 .69383 .61273 .7009 .61854 .6984 .61549 .69129 Mtetra
.668 .596 .766 r
.61549 .69129 .61854 .6984 .62436 .69598 .62131 .68882 Mtetra
.665 .594 .766 r
.62131 .68882 .62436 .69598 .63019 .69362 .62715 .68643 Mtetra
.662 .592 .766 r
.62715 .68643 .63019 .69362 .63603 .69135 .63299 .68411 Mtetra
.659 .59 .766 r
.63299 .68411 .63603 .69135 .64189 .68915 .63885 .68188 Mtetra
.657 .588 .767 r
.63885 .68188 .64189 .68915 .64776 .68703 .64472 .67973 Mtetra
.654 .586 .767 r
.64472 .67973 .64776 .68703 .65365 .68499 .65061 .67767 Mtetra
.651 .584 .767 r
.65061 .67767 .65365 .68499 .65955 .68303 .65651 .67569 Mtetra
.648 .583 .768 r
.65651 .67569 .65955 .68303 .66546 .68115 .66242 .67379 Mtetra
.645 .581 .768 r
.66242 .67379 .66546 .68115 .67139 .67936 .66835 .67198 Mtetra
.642 .579 .769 r
.66835 .67198 .67139 .67936 .67733 .67765 .6743 .67026 Mtetra
.639 .577 .769 r
.6743 .67026 .67733 .67765 .68329 .67603 .68026 .66863 Mtetra
.636 .576 .77 r
.68026 .66863 .68329 .67603 .68927 .67449 .68624 .66708 Mtetra
.633 .574 .771 r
.68624 .66708 .68927 .67449 .69526 .67303 .69223 .66563 Mtetra
.63 .573 .772 r
.69223 .66563 .69526 .67303 .70128 .67166 .69825 .66426 Mtetra
.627 .571 .773 r
.69825 .66426 .70128 .67166 .70731 .67037 .70428 .66297 Mtetra
.623 .57 .774 r
.70428 .66297 .70731 .67037 .71336 .66917 .71033 .66178 Mtetra
.62 .569 .775 r
.71033 .66178 .71336 .66917 .71942 .66805 .7164 .66067 Mtetra
.617 .568 .776 r
.7164 .66067 .71942 .66805 .72551 .667 .72249 .65964 Mtetra
.614 .567 .777 r
.72249 .65964 .72551 .667 .73162 .66604 .7286 .6587 Mtetra
.611 .566 .778 r
.7286 .6587 .73162 .66604 .73775 .66516 .73473 .65784 Mtetra
.608 .565 .78 r
.73473 .65784 .73775 .66516 .7439 .66435 .74088 .65705 Mtetra
.605 .564 .781 r
.74088 .65705 .7439 .66435 .75007 .66362 .74705 .65635 Mtetra
.602 .563 .783 r
.74705 .65635 .75007 .66362 .75626 .66296 .75325 .65572 Mtetra
.599 .562 .784 r
.75325 .65572 .75626 .66296 .76247 .66237 .75946 .65517 Mtetra
.597 .562 .786 r
.75946 .65517 .76247 .66237 .7687 .66185 .7657 .65469 Mtetra
.594 .562 .788 r
.7657 .65469 .7687 .66185 .77496 .66139 .77196 .65427 Mtetra
.591 .561 .79 r
.77196 .65427 .77496 .66139 .78124 .661 .77825 .65392 Mtetra
.588 .561 .792 r
.77825 .65392 .78124 .661 .78754 .66066 .78456 .65364 Mtetra
.586 .561 .794 r
.78456 .65364 .78754 .66066 .79387 .66038 .79089 .65341 Mtetra
.583 .562 .796 r
.79089 .65341 .79387 .66038 .80022 .66015 .79724 .65323 Mtetra
.581 .562 .798 r
.79724 .65323 .80022 .66015 .80659 .65996 .80362 .65311 Mtetra
.579 .563 .8 r
.80362 .65311 .80659 .65996 .81298 .65982 .81002 .65303 Mtetra
.577 .564 .803 r
.81002 .65303 .81298 .65982 .8194 .65972 .81645 .653 Mtetra
.575 .565 .805 r
.81645 .653 .8194 .65972 .82584 .65965 .8229 .653 Mtetra
.573 .566 .808 r
.8229 .653 .82584 .65965 .8323 .65961 .82937 .65304 Mtetra
.571 .567 .811 r
.82937 .65304 .8323 .65961 .83878 .65959 .83586 .65311 Mtetra
.569 .569 .813 r
.83586 .65311 .83878 .65959 .84529 .65959 .84238 .65319 Mtetra
.568 .571 .816 r
.84238 .65319 .84529 .65959 .85182 .65961 .84892 .65329 Mtetra
.567 .574 .82 r
.84892 .65329 .85182 .65961 .85837 .65963 .85548 .65341 Mtetra
.566 .576 .823 r
.85548 .65341 .85837 .65963 .86494 .65965 .86206 .65352 Mtetra
.565 .579 .826 r
.86206 .65352 .86494 .65965 .87153 .65966 .86867 .65364 Mtetra
.565 .583 .83 r
.86867 .65364 .87153 .65966 .87814 .65966 .8753 .65374 Mtetra
.565 .586 .834 r
.8753 .65374 .87814 .65966 .88477 .65964 .88194 .65383 Mtetra
.565 .59 .838 r
.88194 .65383 .88477 .65964 .89142 .65959 .88861 .65389 Mtetra
.565 .595 .842 r
.88861 .65389 .89142 .65959 .89808 .65951 .89529 .65392 Mtetra
.566 .6 .846 r
.89529 .65392 .89808 .65951 .90476 .65938 .90199 .65392 Mtetra
.567 .606 .851 r
.90199 .65392 .90476 .65938 .91146 .6592 .9087 .65386 Mtetra
.569 .612 .856 r
.9087 .65386 .91146 .6592 .91817 .65895 .91544 .65375 Mtetra
.571 .618 .861 r
.91544 .65375 .91817 .65895 .92489 .65864 .92218 .65357 Mtetra
.574 .626 .866 r
.92218 .65357 .92489 .65864 .93163 .65825 .92894 .65332 Mtetra
.577 .634 .871 r
.92894 .65332 .93163 .65825 .93837 .65778 .93571 .65299 Mtetra
.581 .642 .877 r
.93571 .65299 .93837 .65778 .94513 .6572 .94249 .65256 Mtetra
.585 .652 .882 r
.94249 .65256 .94513 .6572 .95189 .65651 .94927 .65202 Mtetra
.59 .662 .888 r
.94927 .65202 .95189 .65651 .95865 .65571 .95607 .65138 Mtetra
.595 .673 .894 r
.95607 .65138 .95865 .65571 .96542 .65478 .96286 .65061 Mtetra
.601 .685 .901 r
.96286 .65061 .96542 .65478 .97219 .65371 .96966 .6497 Mtetra
.608 .698 .907 r
.96966 .6497 .97219 .65371 .97895 .65249 .97646 .64865 Mtetra
.616 .712 .914 r
.97646 .64865 .97895 .65249 .98572 .6511 .98326 .64743 Mtetra
.625 .727 .92 r
.98326 .64743 .98572 .6511 .99247 .64955 .99005 .64605 Mtetra
.634 .743 .927 r
.99005 .64605 .99247 .64955 .99922 .6478 .99683 .64449 Mtetra
.675 .755 .912 r
.39151 .80023 .39479 .8031 .40027 .80145 .397 .79841 Mtetra
.685 .747 .898 r
.397 .79841 .40027 .80145 .40577 .79963 .40251 .79641 Mtetra
.693 .738 .886 r
.40251 .79641 .40577 .79963 .41128 .79766 .40804 .79426 Mtetra
.699 .73 .875 r
.40804 .79426 .41128 .79766 .4168 .79553 .41358 .79197 Mtetra
.704 .723 .865 r
.41358 .79197 .4168 .79553 .42234 .79326 .41913 .78953 Mtetra
.707 .716 .855 r
.41913 .78953 .42234 .79326 .42789 .79086 .42469 .78698 Mtetra
.71 .709 .847 r
.42469 .78698 .42789 .79086 .43346 .78835 .43026 .7843 Mtetra
.713 .703 .839 r
.43026 .7843 .43346 .78835 .43903 .78572 .43584 .78152 Mtetra
.714 .697 .832 r
.43584 .78152 .43903 .78572 .44461 .78299 .44144 .77864 Mtetra
.715 .691 .826 r
.44144 .77864 .44461 .78299 .45021 .78017 .44704 .77567 Mtetra
.716 .686 .82 r
.44704 .77567 .45021 .78017 .45581 .77727 .45265 .77263 Mtetra
.717 .681 .814 r
.45265 .77263 .45581 .77727 .46142 .7743 .45827 .76951 Mtetra
.717 .676 .809 r
.45827 .76951 .46142 .7743 .46703 .77126 .46389 .76634 Mtetra
.716 .672 .805 r
.46389 .76634 .46703 .77126 .47266 .76816 .46953 .7631 Mtetra
.716 .667 .801 r
.46953 .7631 .47266 .76816 .47829 .76501 .47516 .75983 Mtetra
.715 .663 .797 r
.47516 .75983 .47829 .76501 .48393 .76182 .48081 .75651 Mtetra
.715 .659 .794 r
.48081 .75651 .48393 .76182 .48958 .7586 .48646 .75317 Mtetra
.714 .655 .79 r
.48646 .75317 .48958 .7586 .49523 .75535 .49212 .7498 Mtetra
.713 .652 .787 r
.49212 .7498 .49523 .75535 .50089 .75208 .49778 .74642 Mtetra
.711 .648 .785 r
.49778 .74642 .50089 .75208 .50655 .74879 .50345 .74302 Mtetra
.71 .645 .782 r
.50345 .74302 .50655 .74879 .51222 .7455 .50913 .73962 Mtetra
.709 .642 .78 r
.50913 .73962 .51222 .7455 .5179 .74221 .51481 .73623 Mtetra
.707 .638 .778 r
.51481 .73623 .5179 .74221 .52358 .73893 .5205 .73285 Mtetra
.705 .635 .776 r
.5205 .73285 .52358 .73893 .52927 .73566 .52619 .72948 Mtetra
.703 .632 .775 r
.52619 .72948 .52927 .73566 .53497 .7324 .53189 .72613 Mtetra
.702 .629 .773 r
.53189 .72613 .53497 .7324 .54067 .72917 .5376 .72281 Mtetra
.7 .627 .772 r
.5376 .72281 .54067 .72917 .54638 .72597 .54331 .71952 Mtetra
.698 .624 .77 r
.54331 .71952 .54638 .72597 .55209 .7228 .54903 .71627 Mtetra
.695 .621 .769 r
.54903 .71627 .55209 .7228 .55782 .71967 .55475 .71306 Mtetra
.693 .618 .768 r
.55475 .71306 .55782 .71967 .56355 .71657 .56048 .70989 Mtetra
.691 .616 .767 r
.56048 .70989 .56355 .71657 .56928 .71353 .56622 .70678 Mtetra
.689 .613 .767 r
.56622 .70678 .56928 .71353 .57503 .71054 .57197 .70372 Mtetra
.686 .611 .766 r
.57197 .70372 .57503 .71054 .58078 .7076 .57772 .70071 Mtetra
.684 .608 .765 r
.57772 .70071 .58078 .7076 .58654 .70472 .58349 .69777 Mtetra
.681 .606 .765 r
.58349 .69777 .58654 .70472 .59231 .7019 .58926 .69489 Mtetra
.679 .604 .765 r
.58926 .69489 .59231 .7019 .59809 .69914 .59504 .69208 Mtetra
.676 .601 .764 r
.59504 .69208 .59809 .69914 .60388 .69645 .60083 .68934 Mtetra
.674 .599 .764 r
.60083 .68934 .60388 .69645 .60968 .69383 .60663 .68667 Mtetra
.671 .597 .764 r
.60663 .68667 .60968 .69383 .61549 .69129 .61244 .68408 Mtetra
.668 .595 .764 r
.61244 .68408 .61549 .69129 .62131 .68882 .61827 .68157 Mtetra
.665 .593 .764 r
.61827 .68157 .62131 .68882 .62715 .68643 .6241 .67914 Mtetra
.662 .591 .764 r
.6241 .67914 .62715 .68643 .63299 .68411 .62995 .67679 Mtetra
.66 .589 .764 r
.62995 .67679 .63299 .68411 .63885 .68188 .63581 .67453 Mtetra
.657 .587 .765 r
.63581 .67453 .63885 .68188 .64472 .67973 .64168 .67235 Mtetra
.654 .585 .765 r
.64168 .67235 .64472 .67973 .65061 .67767 .64756 .67026 Mtetra
.651 .583 .765 r
.64756 .67026 .65061 .67767 .65651 .67569 .65346 .66826 Mtetra
.648 .581 .766 r
.65346 .66826 .65651 .67569 .66242 .67379 .65938 .66634 Mtetra
.645 .579 .766 r
.65938 .66634 .66242 .67379 .66835 .67198 .66531 .66452 Mtetra
.641 .577 .767 r
.66531 .66452 .66835 .67198 .6743 .67026 .67126 .66279 Mtetra
.638 .576 .768 r
.67126 .66279 .6743 .67026 .68026 .66863 .67722 .66115 Mtetra
.635 .574 .769 r
.67722 .66115 .68026 .66863 .68624 .66708 .6832 .6596 Mtetra
.632 .572 .769 r
.6832 .6596 .68624 .66708 .69223 .66563 .68919 .65814 Mtetra
.629 .571 .77 r
.68919 .65814 .69223 .66563 .69825 .66426 .69521 .65677 Mtetra
.626 .569 .771 r
.69521 .65677 .69825 .66426 .70428 .66297 .70124 .65549 Mtetra
.623 .568 .772 r
.70124 .65549 .70428 .66297 .71033 .66178 .70729 .6543 Mtetra
.619 .567 .773 r
.70729 .6543 .71033 .66178 .7164 .66067 .71336 .6532 Mtetra
.616 .565 .774 r
.71336 .6532 .7164 .66067 .72249 .65964 .71946 .65219 Mtetra
.613 .564 .776 r
.71946 .65219 .72249 .65964 .7286 .6587 .72557 .65126 Mtetra
.61 .563 .777 r
.72557 .65126 .7286 .6587 .73473 .65784 .7317 .65042 Mtetra
.607 .562 .778 r
.7317 .65042 .73473 .65784 .74088 .65705 .73785 .64966 Mtetra
.604 .561 .78 r
.73785 .64966 .74088 .65705 .74705 .65635 .74403 .64899 Mtetra
.601 .56 .781 r
.74403 .64899 .74705 .65635 .75325 .65572 .75023 .64839 Mtetra
.598 .56 .783 r
.75023 .64839 .75325 .65572 .75946 .65517 .75645 .64787 Mtetra
.595 .559 .784 r
.75645 .64787 .75946 .65517 .7657 .65469 .76269 .64743 Mtetra
.592 .559 .786 r
.76269 .64743 .7657 .65469 .77196 .65427 .76896 .64705 Mtetra
.589 .558 .788 r
.76896 .64705 .77196 .65427 .77825 .65392 .77525 .64675 Mtetra
.586 .558 .79 r
.77525 .64675 .77825 .65392 .78456 .65364 .78156 .64651 Mtetra
.583 .558 .792 r
.78156 .64651 .78456 .65364 .79089 .65341 .7879 .64633 Mtetra
.581 .558 .794 r
.7879 .64633 .79089 .65341 .79724 .65323 .79426 .64621 Mtetra
.578 .558 .796 r
.79426 .64621 .79724 .65323 .80362 .65311 .80064 .64615 Mtetra
.576 .559 .798 r
.80064 .64615 .80362 .65311 .81002 .65303 .80705 .64614 Mtetra
.574 .559 .8 r
.80705 .64614 .81002 .65303 .81645 .653 .81348 .64617 Mtetra
.571 .56 .803 r
.81348 .64617 .81645 .653 .8229 .653 .81994 .64625 Mtetra
.569 .561 .805 r
.81994 .64625 .8229 .653 .82937 .65304 .82642 .64636 Mtetra
.567 .563 .808 r
.82642 .64636 .82937 .65304 .83586 .65311 .83292 .6465 Mtetra
.566 .564 .811 r
.83292 .6465 .83586 .65311 .84238 .65319 .83945 .64667 Mtetra
.564 .566 .814 r
.83945 .64667 .84238 .65319 .84892 .65329 .846 .64686 Mtetra
.563 .568 .817 r
.846 .64686 .84892 .65329 .85548 .65341 .85258 .64706 Mtetra
.562 .571 .82 r
.85258 .64706 .85548 .65341 .86206 .65352 .85917 .64727 Mtetra
.561 .573 .823 r
.85917 .64727 .86206 .65352 .86867 .65364 .86579 .64748 Mtetra
.56 .576 .827 r
.86579 .64748 .86867 .65364 .8753 .65374 .87243 .64768 Mtetra
.56 .58 .831 r
.87243 .64768 .8753 .65374 .88194 .65383 .87909 .64788 Mtetra
.56 .584 .834 r
.87909 .64788 .88194 .65383 .88861 .65389 .88577 .64805 Mtetra
.56 .588 .838 r
.88577 .64805 .88861 .65389 .89529 .65392 .89247 .6482 Mtetra
.561 .593 .843 r
.89247 .6482 .89529 .65392 .90199 .65392 .89919 .64831 Mtetra
.562 .598 .847 r
.89919 .64831 .90199 .65392 .9087 .65386 .90593 .64838 Mtetra
.563 .603 .851 r
.90593 .64838 .9087 .65386 .91544 .65375 .91268 .64839 Mtetra
.565 .61 .856 r
.91268 .64839 .91544 .65375 .92218 .65357 .91944 .64835 Mtetra
.567 .617 .861 r
.91944 .64835 .92218 .65357 .92894 .65332 .92623 .64823 Mtetra
.57 .624 .866 r
.92623 .64823 .92894 .65332 .93571 .65299 .93302 .64803 Mtetra
.574 .632 .872 r
.93302 .64803 .93571 .65299 .94249 .65256 .93982 .64775 Mtetra
.577 .641 .877 r
.93982 .64775 .94249 .65256 .94927 .65202 .94663 .64736 Mtetra
.582 .651 .883 r
.94663 .64736 .94927 .65202 .95607 .65138 .95345 .64687 Mtetra
.587 .661 .889 r
.95345 .64687 .95607 .65138 .96286 .65061 .96028 .64625 Mtetra
.593 .672 .895 r
.96028 .64625 .96286 .65061 .96966 .6497 .96711 .64551 Mtetra
.6 .685 .901 r
.96711 .64551 .96966 .6497 .97646 .64865 .97394 .64462 Mtetra
.607 .698 .908 r
.97394 .64462 .97646 .64865 .98326 .64743 .98077 .64357 Mtetra
.615 .712 .914 r
.98077 .64357 .98326 .64743 .99005 .64605 .98759 .64237 Mtetra
.624 .727 .921 r
.98759 .64237 .99005 .64605 .99683 .64449 .99441 .64098 Mtetra
.685 .748 .899 r
.38823 .7972 .39151 .80023 .397 .79841 .39373 .79519 Mtetra
.693 .739 .886 r
.39373 .79519 .397 .79841 .40251 .79641 .39926 .79303 Mtetra
.7 .731 .875 r
.39926 .79303 .40251 .79641 .40804 .79426 .40479 .79071 Mtetra
.705 .724 .864 r
.40479 .79071 .40804 .79426 .41358 .79197 .41034 .78825 Mtetra
.709 .717 .855 r
.41034 .78825 .41358 .79197 .41913 .78953 .4159 .78565 Mtetra
.712 .71 .846 r
.4159 .78565 .41913 .78953 .42469 .78698 .42148 .78294 Mtetra
.715 .704 .839 r
.42148 .78294 .42469 .78698 .43026 .7843 .42706 .78011 Mtetra
.716 .698 .831 r
.42706 .78011 .43026 .7843 .43584 .78152 .43265 .77717 Mtetra
.718 .692 .825 r
.43265 .77717 .43584 .78152 .44144 .77864 .43825 .77415 Mtetra
.718 .687 .819 r
.43825 .77415 .44144 .77864 .44704 .77567 .44387 .77104 Mtetra
.719 .682 .813 r
.44387 .77104 .44704 .77567 .45265 .77263 .44948 .76785 Mtetra
.719 .677 .808 r
.44948 .76785 .45265 .77263 .45827 .76951 .45511 .7646 Mtetra
.719 .673 .804 r
.45511 .7646 .45827 .76951 .46389 .76634 .46074 .76129 Mtetra
.719 .668 .8 r
.46074 .76129 .46389 .76634 .46953 .7631 .46638 .75793 Mtetra
.718 .664 .796 r
.46638 .75793 .46953 .7631 .47516 .75983 .47203 .75452 Mtetra
.717 .66 .792 r
.47203 .75452 .47516 .75983 .48081 .75651 .47768 .75109 Mtetra
.717 .657 .789 r
.47768 .75109 .48081 .75651 .48646 .75317 .48334 .74762 Mtetra
.715 .653 .786 r
.48334 .74762 .48646 .75317 .49212 .7498 .48901 .74414 Mtetra
.714 .65 .784 r
.48901 .74414 .49212 .7498 .49778 .74642 .49468 .74064 Mtetra
.713 .646 .781 r
.49468 .74064 .49778 .74642 .50345 .74302 .50035 .73714 Mtetra
.711 .643 .779 r
.50035 .73714 .50345 .74302 .50913 .73962 .50603 .73364 Mtetra
.71 .64 .777 r
.50603 .73364 .50913 .73962 .51481 .73623 .51172 .73014 Mtetra
.708 .637 .775 r
.51172 .73014 .51481 .73623 .5205 .73285 .51741 .72666 Mtetra
.707 .634 .773 r
.51741 .72666 .5205 .73285 .52619 .72948 .52311 .7232 Mtetra
.705 .631 .772 r
.52311 .7232 .52619 .72948 .53189 .72613 .52881 .71976 Mtetra
.703 .628 .77 r
.52881 .71976 .53189 .72613 .5376 .72281 .53452 .71636 Mtetra
.701 .625 .769 r
.53452 .71636 .5376 .72281 .54331 .71952 .54023 .71298 Mtetra
.699 .622 .768 r
.54023 .71298 .54331 .71952 .54903 .71627 .54595 .70965 Mtetra
.696 .62 .767 r
.54595 .70965 .54903 .71627 .55475 .71306 .55168 .70636 Mtetra
.694 .617 .766 r
.55168 .70636 .55475 .71306 .56048 .70989 .55741 .70312 Mtetra
.692 .614 .765 r
.55741 .70312 .56048 .70989 .56622 .70678 .56316 .69994 Mtetra
.69 .612 .764 r
.56316 .69994 .56622 .70678 .57197 .70372 .5689 .69681 Mtetra
.687 .61 .764 r
.5689 .69681 .57197 .70372 .57772 .70071 .57466 .69374 Mtetra
.685 .607 .763 r
.57466 .69374 .57772 .70071 .58349 .69777 .58043 .69074 Mtetra
.682 .605 .763 r
.58043 .69074 .58349 .69777 .58926 .69489 .5862 .6878 Mtetra
.679 .602 .763 r
.5862 .6878 .58926 .69489 .59504 .69208 .59198 .68494 Mtetra
.677 .6 .762 r
.59198 .68494 .59504 .69208 .60083 .68934 .59777 .68215 Mtetra
.674 .598 .762 r
.59777 .68215 .60083 .68934 .60663 .68667 .60358 .67943 Mtetra
.671 .596 .762 r
.60358 .67943 .60663 .68667 .61244 .68408 .60939 .6768 Mtetra
.668 .594 .762 r
.60939 .6768 .61244 .68408 .61827 .68157 .61521 .67425 Mtetra
.666 .591 .762 r
.61521 .67425 .61827 .68157 .6241 .67914 .62105 .67178 Mtetra
.663 .589 .763 r
.62105 .67178 .6241 .67914 .62995 .67679 .62689 .6694 Mtetra
.66 .587 .763 r
.62689 .6694 .62995 .67679 .63581 .67453 .63275 .6671 Mtetra
.657 .585 .763 r
.63275 .6671 .63581 .67453 .64168 .67235 .63863 .66489 Mtetra
.654 .583 .763 r
.63863 .66489 .64168 .67235 .64756 .67026 .64451 .66278 Mtetra
.651 .581 .764 r
.64451 .66278 .64756 .67026 .65346 .66826 .65041 .66075 Mtetra
.648 .579 .764 r
.65041 .66075 .65346 .66826 .65938 .66634 .65633 .65882 Mtetra
.644 .578 .765 r
.65633 .65882 .65938 .66634 .66531 .66452 .66226 .65698 Mtetra
.641 .576 .766 r
.66226 .65698 .66531 .66452 .67126 .66279 .66821 .65524 Mtetra
.638 .574 .766 r
.66821 .65524 .67126 .66279 .67722 .66115 .67417 .65359 Mtetra
.635 .572 .767 r
.67417 .65359 .67722 .66115 .6832 .6596 .68015 .65203 Mtetra
.632 .571 .768 r
.68015 .65203 .6832 .6596 .68919 .65814 .68615 .65057 Mtetra
.628 .569 .769 r
.68615 .65057 .68919 .65814 .69521 .65677 .69216 .6492 Mtetra
.625 .568 .77 r
.69216 .6492 .69521 .65677 .70124 .65549 .6982 .64792 Mtetra
.622 .566 .771 r
.6982 .64792 .70124 .65549 .70729 .6543 .70425 .64674 Mtetra
.619 .565 .772 r
.70425 .64674 .70729 .6543 .71336 .6532 .71032 .64565 Mtetra
.615 .563 .773 r
.71032 .64565 .71336 .6532 .71946 .65219 .71641 .64465 Mtetra
.612 .562 .774 r
.71641 .64465 .71946 .65219 .72557 .65126 .72253 .64374 Mtetra
.609 .561 .775 r
.72253 .64374 .72557 .65126 .7317 .65042 .72866 .64292 Mtetra
.606 .56 .777 r
.72866 .64292 .7317 .65042 .73785 .64966 .73482 .64219 Mtetra
.602 .559 .778 r
.73482 .64219 .73785 .64966 .74403 .64899 .741 .64154 Mtetra
.599 .558 .78 r
.741 .64154 .74403 .64899 .75023 .64839 .7472 .64097 Mtetra
.596 .557 .781 r
.7472 .64097 .75023 .64839 .75645 .64787 .75342 .64049 Mtetra
.593 .556 .783 r
.75342 .64049 .75645 .64787 .76269 .64743 .75967 .64008 Mtetra
.59 .556 .784 r
.75967 .64008 .76269 .64743 .76896 .64705 .76594 .63974 Mtetra
.587 .555 .786 r
.76594 .63974 .76896 .64705 .77525 .64675 .77223 .63948 Mtetra
.584 .555 .788 r
.77223 .63948 .77525 .64675 .78156 .64651 .77855 .63929 Mtetra
.581 .555 .79 r
.77855 .63929 .78156 .64651 .7879 .64633 .78489 .63917 Mtetra
.578 .555 .792 r
.78489 .63917 .7879 .64633 .79426 .64621 .79126 .6391 Mtetra
.576 .555 .794 r
.79126 .6391 .79426 .64621 .80064 .64615 .79765 .6391 Mtetra
.573 .555 .796 r
.79765 .6391 .80064 .64615 .80705 .64614 .80406 .63914 Mtetra
.571 .556 .798 r
.80406 .63914 .80705 .64614 .81348 .64617 .8105 .63924 Mtetra
.568 .556 .801 r
.8105 .63924 .81348 .64617 .81994 .64625 .81697 .63939 Mtetra
.566 .557 .803 r
.81697 .63939 .81994 .64625 .82642 .64636 .82346 .63957 Mtetra
.564 .558 .806 r
.82346 .63957 .82642 .64636 .83292 .6465 .82997 .63979 Mtetra
.562 .56 .809 r
.82997 .63979 .83292 .6465 .83945 .64667 .83651 .64003 Mtetra
.56 .561 .811 r
.83651 .64003 .83945 .64667 .846 .64686 .84307 .64031 Mtetra
.559 .563 .814 r
.84307 .64031 .846 .64686 .85258 .64706 .84966 .64059 Mtetra
.558 .565 .817 r
.84966 .64059 .85258 .64706 .85917 .64727 .85626 .6409 Mtetra
.557 .568 .821 r
.85626 .6409 .85917 .64727 .86579 .64748 .8629 .6412 Mtetra
.556 .571 .824 r
.8629 .6412 .86579 .64748 .87243 .64768 .86955 .64151 Mtetra
.555 .574 .828 r
.86955 .64151 .87243 .64768 .87909 .64788 .87622 .6418 Mtetra
.555 .577 .831 r
.87622 .6418 .87909 .64788 .88577 .64805 .88292 .64208 Mtetra
.555 .581 .835 r
.88292 .64208 .88577 .64805 .89247 .6482 .88964 .64234 Mtetra
.555 .586 .839 r
.88964 .64234 .89247 .6482 .89919 .64831 .89637 .64257 Mtetra
.556 .59 .843 r
.89637 .64257 .89919 .64831 .90593 .64838 .90313 .64275 Mtetra
.557 .596 .848 r
.90313 .64275 .90593 .64838 .91268 .64839 .9099 .64289 Mtetra
.559 .602 .852 r
.9099 .64289 .91268 .64839 .91944 .64835 .91669 .64297 Mtetra
.561 .608 .857 r
.91669 .64297 .91944 .64835 .92623 .64823 .92349 .64299 Mtetra
.564 .615 .862 r
.92349 .64299 .92623 .64823 .93302 .64803 .9303 .64293 Mtetra
.567 .623 .867 r
.9303 .64293 .93302 .64803 .93982 .64775 .93713 .64278 Mtetra
.57 .631 .873 r
.93713 .64278 .93982 .64775 .94663 .64736 .94397 .64254 Mtetra
.574 .64 .878 r
.94397 .64254 .94663 .64736 .95345 .64687 .95081 .6422 Mtetra
.579 .65 .884 r
.95081 .6422 .95345 .64687 .96028 .64625 .95767 .64173 Mtetra
.585 .661 .89 r
.95767 .64173 .96028 .64625 .96711 .64551 .96453 .64114 Mtetra
.591 .672 .896 r
.96453 .64114 .96711 .64551 .97394 .64462 .97139 .64042 Mtetra
.598 .685 .902 r
.97139 .64042 .97394 .64462 .98077 .64357 .97825 .63954 Mtetra
.606 .698 .909 r
.97825 .63954 .98077 .64357 .98759 .64237 .98511 .6385 Mtetra
.615 .712 .915 r
.98511 .6385 .98759 .64237 .99441 .64098 .99196 .63729 Mtetra
.694 .74 .887 r
.38494 .794 .38823 .7972 .39373 .79519 .39046 .79182 Mtetra
.701 .732 .875 r
.39046 .79182 .39373 .79519 .39926 .79303 .39599 .78949 Mtetra
.706 .725 .865 r
.39599 .78949 .39926 .79303 .40479 .79071 .40154 .787 Mtetra
.71 .718 .855 r
.40154 .787 .40479 .79071 .41034 .78825 .4071 .78438 Mtetra
.714 .711 .846 r
.4071 .78438 .41034 .78825 .4159 .78565 .41267 .78163 Mtetra
.716 .705 .838 r
.41267 .78163 .4159 .78565 .42148 .78294 .41826 .77875 Mtetra
.718 .699 .831 r
.41826 .77875 .42148 .78294 .42706 .78011 .42385 .77577 Mtetra
.72 .694 .824 r
.42385 .77577 .42706 .78011 .43265 .77717 .42945 .77269 Mtetra
.721 .688 .818 r
.42945 .77269 .43265 .77717 .43825 .77415 .43507 .76952 Mtetra
.721 .683 .813 r
.43507 .76952 .43825 .77415 .44387 .77104 .44069 .76627 Mtetra
.722 .679 .808 r
.44069 .76627 .44387 .77104 .44948 .76785 .44631 .76295 Mtetra
.722 .674 .803 r
.44631 .76295 .44948 .76785 .45511 .7646 .45195 .75956 Mtetra
.721 .67 .799 r
.45195 .75956 .45511 .7646 .46074 .76129 .45759 .75612 Mtetra
.721 .666 .795 r
.45759 .75612 .46074 .76129 .46638 .75793 .46324 .75263 Mtetra
.72 .662 .792 r
.46324 .75263 .46638 .75793 .47203 .75452 .46889 .7491 Mtetra
.719 .658 .788 r
.46889 .7491 .47203 .75452 .47768 .75109 .47455 .74555 Mtetra
.718 .654 .785 r
.47455 .74555 .47768 .75109 .48334 .74762 .48021 .74197 Mtetra
.717 .651 .783 r
.48021 .74197 .48334 .74762 .48901 .74414 .48588 .73837 Mtetra
.716 .648 .78 r
.48588 .73837 .48901 .74414 .49468 .74064 .49156 .73476 Mtetra
.715 .644 .778 r
.49156 .73476 .49468 .74064 .50035 .73714 .49724 .73116 Mtetra
.713 .641 .776 r
.49724 .73116 .50035 .73714 .50603 .73364 .50293 .72755 Mtetra
.711 .638 .774 r
.50293 .72755 .50603 .73364 .51172 .73014 .50862 .72396 Mtetra
.71 .635 .772 r
.50862 .72396 .51172 .73014 .51741 .72666 .51431 .72038 Mtetra
.708 .632 .77 r
.51431 .72038 .51741 .72666 .52311 .7232 .52001 .71683 Mtetra
.706 .629 .769 r
.52001 .71683 .52311 .7232 .52881 .71976 .52572 .7133 Mtetra
.704 .627 .768 r
.52572 .7133 .52881 .71976 .53452 .71636 .53143 .70981 Mtetra
.702 .624 .766 r
.53143 .70981 .53452 .71636 .54023 .71298 .53715 .70636 Mtetra
.7 .621 .765 r
.53715 .70636 .54023 .71298 .54595 .70965 .54287 .70294 Mtetra
.698 .619 .765 r
.54287 .70294 .54595 .70965 .55168 .70636 .5486 .69958 Mtetra
.695 .616 .764 r
.5486 .69958 .55168 .70636 .55741 .70312 .55434 .69627 Mtetra
.693 .613 .763 r
.55434 .69627 .55741 .70312 .56316 .69994 .56008 .69301 Mtetra
.69 .611 .762 r
.56008 .69301 .56316 .69994 .5689 .69681 .56583 .68982 Mtetra
.688 .609 .762 r
.56583 .68982 .5689 .69681 .57466 .69374 .57159 .68669 Mtetra
.685 .606 .761 r
.57159 .68669 .57466 .69374 .58043 .69074 .57736 .68363 Mtetra
.683 .604 .761 r
.57736 .68363 .58043 .69074 .5862 .6878 .58313 .68064 Mtetra
.68 .601 .761 r
.58313 .68064 .5862 .6878 .59198 .68494 .58892 .67772 Mtetra
.677 .599 .761 r
.58892 .67772 .59198 .68494 .59777 .68215 .59471 .67488 Mtetra
.675 .597 .761 r
.59471 .67488 .59777 .68215 .60358 .67943 .60051 .67212 Mtetra
.672 .595 .761 r
.60051 .67212 .60358 .67943 .60939 .6768 .60633 .66944 Mtetra
.669 .593 .761 r
.60633 .66944 .60939 .6768 .61521 .67425 .61215 .66685 Mtetra
.666 .59 .761 r
.61215 .66685 .61521 .67425 .62105 .67178 .61799 .66435 Mtetra
.663 .588 .761 r
.61799 .66435 .62105 .67178 .62689 .6694 .62384 .66193 Mtetra
.66 .586 .761 r
.62384 .66193 .62689 .6694 .63275 .6671 .6297 .6596 Mtetra
.657 .584 .762 r
.6297 .6596 .63275 .6671 .63863 .66489 .63557 .65737 Mtetra
.654 .582 .762 r
.63557 .65737 .63863 .66489 .64451 .66278 .64146 .65523 Mtetra
.651 .58 .763 r
.64146 .65523 .64451 .66278 .65041 .66075 .64736 .65318 Mtetra
.648 .578 .763 r
.64736 .65318 .65041 .66075 .65633 .65882 .65327 .65123 Mtetra
.644 .576 .764 r
.65327 .65123 .65633 .65882 .66226 .65698 .6592 .64938 Mtetra
.641 .575 .764 r
.6592 .64938 .66226 .65698 .66821 .65524 .66515 .64762 Mtetra
.638 .573 .765 r
.66515 .64762 .66821 .65524 .67417 .65359 .67111 .64596 Mtetra
.634 .571 .766 r
.67111 .64596 .67417 .65359 .68015 .65203 .67709 .6444 Mtetra
.631 .569 .767 r
.67709 .6444 .68015 .65203 .68615 .65057 .68309 .64293 Mtetra
.628 .568 .768 r
.68309 .64293 .68615 .65057 .69216 .6492 .68911 .64157 Mtetra
.624 .566 .769 r
.68911 .64157 .69216 .6492 .6982 .64792 .69514 .64029 Mtetra
.621 .565 .77 r
.69514 .64029 .6982 .64792 .70425 .64674 .7012 .63912 Mtetra
.618 .563 .771 r
.7012 .63912 .70425 .64674 .71032 .64565 .70727 .63804 Mtetra
.614 .562 .772 r
.70727 .63804 .71032 .64565 .71641 .64465 .71337 .63705 Mtetra
.611 .56 .773 r
.71337 .63705 .71641 .64465 .72253 .64374 .71948 .63616 Mtetra
.608 .559 .774 r
.71948 .63616 .72253 .64374 .72866 .64292 .72562 .63536 Mtetra
.604 .558 .776 r
.72562 .63536 .72866 .64292 .73482 .64219 .73178 .63464 Mtetra
.601 .557 .777 r
.73178 .63464 .73482 .64219 .741 .64154 .73796 .63402 Mtetra
.598 .556 .778 r
.73796 .63402 .741 .64154 .7472 .64097 .74416 .63348 Mtetra
.594 .555 .78 r
.74416 .63348 .7472 .64097 .75342 .64049 .75039 .63303 Mtetra
.591 .554 .781 r
.75039 .63303 .75342 .64049 .75967 .64008 .75664 .63265 Mtetra
.588 .553 .783 r
.75664 .63265 .75967 .64008 .76594 .63974 .76291 .63236 Mtetra
.585 .553 .785 r
.76291 .63236 .76594 .63974 .77223 .63948 .76921 .63214 Mtetra
.582 .552 .787 r
.76921 .63214 .77223 .63948 .77855 .63929 .77553 .632 Mtetra
.579 .552 .788 r
.77553 .632 .77855 .63929 .78489 .63917 .78188 .63192 Mtetra
.576 .552 .79 r
.78188 .63192 .78489 .63917 .79126 .6391 .78825 .63191 Mtetra
.573 .552 .792 r
.78825 .63191 .79126 .6391 .79765 .6391 .79465 .63196 Mtetra
.57 .552 .795 r
.79465 .63196 .79765 .6391 .80406 .63914 .80107 .63206 Mtetra
.568 .552 .797 r
.80107 .63206 .80406 .63914 .8105 .63924 .80752 .63222 Mtetra
.565 .553 .799 r
.80752 .63222 .8105 .63924 .81697 .63939 .81399 .63243 Mtetra
.563 .553 .802 r
.81399 .63243 .81697 .63939 .82346 .63957 .82048 .63269 Mtetra
.561 .554 .804 r
.82048 .63269 .82346 .63957 .82997 .63979 .82701 .63298 Mtetra
.559 .556 .807 r
.82701 .63298 .82997 .63979 .83651 .64003 .83355 .6333 Mtetra
.557 .557 .809 r
.83355 .6333 .83651 .64003 .84307 .64031 .84012 .63365 Mtetra
.555 .559 .812 r
.84012 .63365 .84307 .64031 .84966 .64059 .84672 .63403 Mtetra
.554 .561 .815 r
.84672 .63403 .84966 .64059 .85626 .6409 .85334 .63442 Mtetra
.552 .563 .818 r
.85334 .63442 .85626 .6409 .8629 .6412 .85998 .63482 Mtetra
.551 .565 .822 r
.85998 .63482 .8629 .6412 .86955 .64151 .86665 .63522 Mtetra
.551 .568 .825 r
.86665 .63522 .86955 .64151 .87622 .6418 .87334 .63561 Mtetra
.55 .571 .829 r
.87334 .63561 .87622 .6418 .88292 .64208 .88005 .636 Mtetra
.55 .575 .832 r
.88005 .636 .88292 .64208 .88964 .64234 .88678 .63637 Mtetra
.55 .579 .836 r
.88678 .63637 .88964 .64234 .89637 .64257 .89354 .6367 Mtetra
.551 .584 .84 r
.89354 .6367 .89637 .64257 .90313 .64275 .90031 .63701 Mtetra
.552 .589 .845 r
.90031 .63701 .90313 .64275 .9099 .64289 .9071 .63726 Mtetra
.553 .594 .849 r
.9071 .63726 .9099 .64289 .91669 .64297 .9139 .63747 Mtetra
.555 .6 .854 r
.9139 .63747 .91669 .64297 .92349 .64299 .92073 .63761 Mtetra
.557 .607 .858 r
.92073 .63761 .92349 .64299 .9303 .64293 .92756 .63768 Mtetra
.56 .614 .863 r
.92756 .63768 .9303 .64293 .93713 .64278 .93441 .63767 Mtetra
.563 .622 .869 r
.93441 .63767 .93713 .64278 .94397 .64254 .94128 .63757 Mtetra
.567 .63 .874 r
.94128 .63757 .94397 .64254 .95081 .6422 .94815 .63737 Mtetra
.572 .64 .88 r
.94815 .63737 .95081 .6422 .95767 .64173 .95503 .63706 Mtetra
.577 .65 .885 r
.95503 .63706 .95767 .64173 .96453 .64114 .96191 .63662 Mtetra
.583 .661 .891 r
.96191 .63662 .96453 .64114 .97139 .64042 .9688 .63605 Mtetra
.59 .673 .897 r
.9688 .63605 .97139 .64042 .97825 .63954 .9757 .63534 Mtetra
.597 .685 .903 r
.9757 .63534 .97825 .63954 .98511 .6385 .98259 .63446 Mtetra
.605 .699 .91 r
.98259 .63446 .98511 .6385 .99196 .63729 .98947 .63342 Mtetra
.701 .734 .876 r
.38164 .79065 .38494 .794 .39046 .79182 .38718 .78831 Mtetra
.707 .727 .865 r
.38718 .78831 .39046 .79182 .39599 .78949 .39272 .78581 Mtetra
.712 .72 .856 r
.39272 .78581 .39599 .78949 .40154 .787 .39828 .78316 Mtetra
.715 .713 .847 r
.39828 .78316 .40154 .787 .4071 .78438 .40386 .78038 Mtetra
.718 .707 .839 r
.40386 .78038 .4071 .78438 .41267 .78163 .40944 .77747 Mtetra
.72 .701 .831 r
.40944 .77747 .41267 .78163 .41826 .77875 .41503 .77444 Mtetra
.722 .695 .824 r
.41503 .77444 .41826 .77875 .42385 .77577 .42064 .77131 Mtetra
.723 .69 .818 r
.42064 .77131 .42385 .77577 .42945 .77269 .42625 .76809 Mtetra
.724 .685 .813 r
.42625 .76809 .42945 .77269 .43507 .76952 .43187 .76477 Mtetra
.724 .68 .807 r
.43187 .76477 .43507 .76952 .44069 .76627 .4375 .76138 Mtetra
.724 .676 .803 r
.4375 .76138 .44069 .76627 .44631 .76295 .44314 .75793 Mtetra
.724 .672 .798 r
.44314 .75793 .44631 .76295 .45195 .75956 .44878 .75441 Mtetra
.723 .667 .794 r
.44878 .75441 .45195 .75956 .45759 .75612 .45443 .75084 Mtetra
.723 .664 .791 r
.45443 .75084 .45759 .75612 .46324 .75263 .46008 .74723 Mtetra
.722 .66 .788 r
.46008 .74723 .46324 .75263 .46889 .7491 .46574 .74358 Mtetra
.721 .656 .784 r
.46574 .74358 .46889 .7491 .47455 .74555 .47141 .73991 Mtetra
.72 .653 .782 r
.47141 .73991 .47455 .74555 .48021 .74197 .47708 .73621 Mtetra
.719 .649 .779 r
.47708 .73621 .48021 .74197 .48588 .73837 .48276 .73251 Mtetra
.718 .646 .777 r
.48276 .73251 .48588 .73837 .49156 .73476 .48844 .72879 Mtetra
.716 .643 .775 r
.48844 .72879 .49156 .73476 .49724 .73116 .49412 .72508 Mtetra
.715 .64 .773 r
.49412 .72508 .49724 .73116 .50293 .72755 .49981 .72138 Mtetra
.713 .637 .771 r
.49981 .72138 .50293 .72755 .50862 .72396 .50551 .71769 Mtetra
.711 .634 .769 r
.50551 .71769 .50862 .72396 .51431 .72038 .51121 .71402 Mtetra
.709 .631 .768 r
.51121 .71402 .51431 .72038 .52001 .71683 .51691 .71038 Mtetra
.707 .628 .767 r
.51691 .71038 .52001 .71683 .52572 .7133 .52263 .70676 Mtetra
.705 .626 .765 r
.52263 .70676 .52572 .7133 .53143 .70981 .52834 .70319 Mtetra
.703 .623 .764 r
.52834 .70319 .53143 .70981 .53715 .70636 .53406 .69965 Mtetra
.701 .62 .763 r
.53406 .69965 .53715 .70636 .54287 .70294 .53979 .69616 Mtetra
.699 .618 .763 r
.53979 .69616 .54287 .70294 .5486 .69958 .54552 .69273 Mtetra
.696 .615 .762 r
.54552 .69273 .5486 .69958 .55434 .69627 .55126 .68935 Mtetra
.694 .613 .761 r
.55126 .68935 .55434 .69627 .56008 .69301 .55701 .68602 Mtetra
.691 .61 .761 r
.55701 .68602 .56008 .69301 .56583 .68982 .56276 .68277 Mtetra
.689 .608 .76 r
.56276 .68277 .56583 .68982 .57159 .68669 .56852 .67958 Mtetra
.686 .605 .76 r
.56852 .67958 .57159 .68669 .57736 .68363 .57429 .67646 Mtetra
.684 .603 .76 r
.57429 .67646 .57736 .68363 .58313 .68064 .58006 .67341 Mtetra
.681 .601 .759 r
.58006 .67341 .58313 .68064 .58892 .67772 .58585 .67044 Mtetra
.678 .599 .759 r
.58585 .67044 .58892 .67772 .59471 .67488 .59164 .66755 Mtetra
.675 .596 .759 r
.59164 .66755 .59471 .67488 .60051 .67212 .59745 .66475 Mtetra
.672 .594 .759 r
.59745 .66475 .60051 .67212 .60633 .66944 .60326 .66203 Mtetra
.669 .592 .76 r
.60326 .66203 .60633 .66944 .61215 .66685 .60909 .6594 Mtetra
.666 .59 .76 r
.60909 .6594 .61215 .66685 .61799 .66435 .61492 .65686 Mtetra
.663 .588 .76 r
.61492 .65686 .61799 .66435 .62384 .66193 .62077 .65441 Mtetra
.66 .586 .76 r
.62077 .65441 .62384 .66193 .6297 .6596 .62663 .65205 Mtetra
.657 .583 .761 r
.62663 .65205 .6297 .6596 .63557 .65737 .63251 .64979 Mtetra
.654 .581 .761 r
.63251 .64979 .63557 .65737 .64146 .65523 .63839 .64763 Mtetra
.651 .579 .762 r
.63839 .64763 .64146 .65523 .64736 .65318 .64429 .64556 Mtetra
.648 .577 .762 r
.64429 .64556 .64736 .65318 .65327 .65123 .65021 .64359 Mtetra
.644 .576 .763 r
.65021 .64359 .65327 .65123 .6592 .64938 .65614 .64172 Mtetra
.641 .574 .763 r
.65614 .64172 .6592 .64938 .66515 .64762 .66209 .63995 Mtetra
.638 .572 .764 r
.66209 .63995 .66515 .64762 .67111 .64596 .66805 .63828 Mtetra
.634 .57 .765 r
.66805 .63828 .67111 .64596 .67709 .6444 .67403 .63671 Mtetra
.631 .568 .766 r
.67403 .63671 .67709 .6444 .68309 .64293 .68003 .63525 Mtetra
.627 .567 .767 r
.68003 .63525 .68309 .64293 .68911 .64157 .68605 .63388 Mtetra
.624 .565 .768 r
.68605 .63388 .68911 .64157 .69514 .64029 .69209 .63261 Mtetra
.62 .563 .769 r
.69209 .63261 .69514 .64029 .7012 .63912 .69814 .63144 Mtetra
.617 .562 .77 r
.69814 .63144 .7012 .63912 .70727 .63804 .70422 .63037 Mtetra
.614 .56 .771 r
.70422 .63037 .70727 .63804 .71337 .63705 .71031 .62939 Mtetra
.61 .559 .772 r
.71031 .62939 .71337 .63705 .71948 .63616 .71643 .62851 Mtetra
.607 .557 .773 r
.71643 .62851 .71948 .63616 .72562 .63536 .72257 .62773 Mtetra
.603 .556 .775 r
.72257 .62773 .72562 .63536 .73178 .63464 .72873 .62704 Mtetra
.6 .555 .776 r
.72873 .62704 .73178 .63464 .73796 .63402 .73491 .62644 Mtetra
.596 .554 .777 r
.73491 .62644 .73796 .63402 .74416 .63348 .74112 .62593 Mtetra
.593 .553 .779 r
.74112 .62593 .74416 .63348 .75039 .63303 .74735 .62551 Mtetra
.59 .552 .78 r
.74735 .62551 .75039 .63303 .75664 .63265 .7536 .62517 Mtetra
.586 .551 .782 r
.7536 .62517 .75664 .63265 .76291 .63236 .75988 .62491 Mtetra
.583 .55 .784 r
.75988 .62491 .76291 .63236 .76921 .63214 .76618 .62473 Mtetra
.58 .55 .785 r
.76618 .62473 .76921 .63214 .77553 .632 .7725 .62463 Mtetra
.577 .549 .787 r
.7725 .62463 .77553 .632 .78188 .63192 .77886 .6246 Mtetra
.574 .549 .789 r
.77886 .6246 .78188 .63192 .78825 .63191 .78523 .62464 Mtetra
.571 .549 .791 r
.78523 .62464 .78825 .63191 .79465 .63196 .79163 .62474 Mtetra
.568 .549 .793 r
.79163 .62474 .79465 .63196 .80107 .63206 .79806 .6249 Mtetra
.565 .549 .795 r
.79806 .6249 .80107 .63206 .80752 .63222 .80451 .62513 Mtetra
.562 .549 .798 r
.80451 .62513 .80752 .63222 .81399 .63243 .81099 .6254 Mtetra
.56 .55 .8 r
.81099 .6254 .81399 .63243 .82048 .63269 .8175 .62572 Mtetra
.557 .551 .802 r
.8175 .62572 .82048 .63269 .82701 .63298 .82403 .62608 Mtetra
.555 .552 .805 r
.82403 .62608 .82701 .63298 .83355 .6333 .83058 .62648 Mtetra
.553 .553 .808 r
.83058 .62648 .83355 .6333 .84012 .63365 .83717 .62691 Mtetra
.551 .554 .81 r
.83717 .62691 .84012 .63365 .84672 .63403 .84377 .62737 Mtetra
.55 .556 .813 r
.84377 .62737 .84672 .63403 .85334 .63442 .8504 .62784 Mtetra
.548 .558 .816 r
.8504 .62784 .85334 .63442 .85998 .63482 .85706 .62833 Mtetra
.547 .56 .82 r
.85706 .62833 .85998 .63482 .86665 .63522 .86374 .62883 Mtetra
.546 .563 .823 r
.86374 .62883 .86665 .63522 .87334 .63561 .87044 .62932 Mtetra
.546 .566 .826 r
.87044 .62932 .87334 .63561 .88005 .636 .87717 .62981 Mtetra
.545 .569 .83 r
.87717 .62981 .88005 .636 .88678 .63637 .88391 .63028 Mtetra
.545 .573 .834 r
.88391 .63028 .88678 .63637 .89354 .6367 .89068 .63072 Mtetra
.546 .577 .838 r
.89068 .63072 .89354 .6367 .90031 .63701 .89747 .63114 Mtetra
.546 .582 .842 r
.89747 .63114 .90031 .63701 .9071 .63726 .90428 .63151 Mtetra
.547 .587 .846 r
.90428 .63151 .9071 .63726 .9139 .63747 .9111 .63184 Mtetra
.549 .593 .85 r
.9111 .63184 .9139 .63747 .92073 .63761 .91795 .63211 Mtetra
.551 .599 .855 r
.91795 .63211 .92073 .63761 .92756 .63768 .9248 .63231 Mtetra
.553 .606 .86 r
.9248 .63231 .92756 .63768 .93441 .63767 .93168 .63243 Mtetra
.557 .613 .865 r
.93168 .63243 .93441 .63767 .94128 .63757 .93856 .63247 Mtetra
.56 .621 .87 r
.93856 .63247 .94128 .63757 .94815 .63737 .94546 .63241 Mtetra
.564 .63 .875 r
.94546 .63241 .94815 .63737 .95503 .63706 .95237 .63224 Mtetra
.569 .64 .881 r
.95237 .63224 .95503 .63706 .96191 .63662 .95928 .63195 Mtetra
.575 .65 .887 r
.95928 .63195 .96191 .63662 .9688 .63605 .9662 .63154 Mtetra
.581 .661 .893 r
.9662 .63154 .9688 .63605 .9757 .63534 .97312 .63098 Mtetra
.588 .673 .899 r
.97312 .63098 .9757 .63534 .98259 .63446 .98004 .63026 Mtetra
.596 .686 .905 r
.98004 .63026 .98259 .63446 .98947 .63342 .98696 .62939 Mtetra
.708 .728 .867 r
.37834 .78716 .38164 .79065 .38718 .78831 .38389 .78465 Mtetra
.713 .721 .857 r
.38389 .78465 .38718 .78831 .39272 .78581 .38945 .78199 Mtetra
.716 .715 .847 r
.38945 .78199 .39272 .78581 .39828 .78316 .39502 .77918 Mtetra
.719 .709 .839 r
.39502 .77918 .39828 .78316 .40386 .78038 .4006 .77624 Mtetra
.722 .703 .831 r
.4006 .77624 .40386 .78038 .40944 .77747 .4062 .77318 Mtetra
.724 .697 .825 r
.4062 .77318 .40944 .77747 .41503 .77444 .4118 .77001 Mtetra
.725 .692 .818 r
.4118 .77001 .41503 .77444 .42064 .77131 .41742 .76673 Mtetra
.726 .687 .813 r
.41742 .76673 .42064 .77131 .42625 .76809 .42304 .76337 Mtetra
.726 .682 .807 r
.42304 .76337 .42625 .76809 .43187 .76477 .42867 .75991 Mtetra
.726 .678 .803 r
.42867 .75991 .43187 .76477 .4375 .76138 .43431 .75639 Mtetra
.726 .673 .798 r
.43431 .75639 .4375 .76138 .44314 .75793 .43995 .7528 Mtetra
.726 .669 .794 r
.43995 .7528 .44314 .75793 .44878 .75441 .44561 .74915 Mtetra
.726 .665 .79 r
.44561 .74915 .44878 .75441 .45443 .75084 .45126 .74546 Mtetra
.725 .662 .787 r
.45126 .74546 .45443 .75084 .46008 .74723 .45693 .74173 Mtetra
.724 .658 .784 r
.45693 .74173 .46008 .74723 .46574 .74358 .46259 .73796 Mtetra
.723 .655 .781 r
.46259 .73796 .46574 .74358 .47141 .73991 .46827 .73417 Mtetra
.722 .651 .779 r
.46827 .73417 .47141 .73991 .47708 .73621 .47394 .73037 Mtetra
.721 .648 .776 r
.47394 .73037 .47708 .73621 .48276 .73251 .47963 .72656 Mtetra
.719 .645 .774 r
.47963 .72656 .48276 .73251 .48844 .72879 .48531 .72274 Mtetra
.718 .642 .772 r
.48531 .72274 .48844 .72879 .49412 .72508 .491 .71893 Mtetra
.716 .639 .77 r
.491 .71893 .49412 .72508 .49981 .72138 .4967 .71513 Mtetra
.714 .636 .769 r
.4967 .71513 .49981 .72138 .50551 .71769 .5024 .71134 Mtetra
.712 .633 .767 r
.5024 .71134 .50551 .71769 .51121 .71402 .5081 .70758 Mtetra
.711 .63 .766 r
.5081 .70758 .51121 .71402 .51691 .71038 .51381 .70385 Mtetra
.709 .627 .764 r
.51381 .70385 .51691 .71038 .52263 .70676 .51953 .70015 Mtetra
.706 .625 .763 r
.51953 .70015 .52263 .70676 .52834 .70319 .52524 .6965 Mtetra
.704 .622 .762 r
.52524 .6965 .52834 .70319 .53406 .69965 .53097 .69288 Mtetra
.702 .62 .762 r
.53097 .69288 .53406 .69965 .53979 .69616 .5367 .68932 Mtetra
.7 .617 .761 r
.5367 .68932 .53979 .69616 .54552 .69273 .54243 .68581 Mtetra
.697 .615 .76 r
.54243 .68581 .54552 .69273 .55126 .68935 .54818 .68236 Mtetra
.695 .612 .76 r
.54818 .68236 .55126 .68935 .55701 .68602 .55392 .67897 Mtetra
.692 .61 .759 r
.55392 .67897 .55701 .68602 .56276 .68277 .55968 .67565 Mtetra
.69 .607 .759 r
.55968 .67565 .56276 .68277 .56852 .67958 .56544 .6724 Mtetra
.687 .605 .759 r
.56544 .6724 .56852 .67958 .57429 .67646 .57121 .66923 Mtetra
.684 .603 .758 r
.57121 .66923 .57429 .67646 .58006 .67341 .57699 .66613 Mtetra
.682 .6 .758 r
.57699 .66613 .58006 .67341 .58585 .67044 .58277 .66311 Mtetra
.679 .598 .758 r
.58277 .66311 .58585 .67044 .59164 .66755 .58857 .66018 Mtetra
.676 .596 .758 r
.58857 .66018 .59164 .66755 .59745 .66475 .59438 .65733 Mtetra
.673 .594 .758 r
.59438 .65733 .59745 .66475 .60326 .66203 .60019 .65457 Mtetra
.67 .591 .758 r
.60019 .65457 .60326 .66203 .60909 .6594 .60602 .6519 Mtetra
.667 .589 .759 r
.60602 .6519 .60909 .6594 .61492 .65686 .61185 .64932 Mtetra
.664 .587 .759 r
.61185 .64932 .61492 .65686 .62077 .65441 .6177 .64684 Mtetra
.661 .585 .759 r
.6177 .64684 .62077 .65441 .62663 .65205 .62356 .64445 Mtetra
.657 .583 .76 r
.62356 .64445 .62663 .65205 .63251 .64979 .62944 .64216 Mtetra
.654 .581 .76 r
.62944 .64216 .63251 .64979 .63839 .64763 .63533 .63998 Mtetra
.651 .579 .761 r
.63533 .63998 .63839 .64763 .64429 .64556 .64123 .63789 Mtetra
.648 .577 .761 r
.64123 .63789 .64429 .64556 .65021 .64359 .64714 .6359 Mtetra
.644 .575 .762 r
.64714 .6359 .65021 .64359 .65614 .64172 .65308 .63402 Mtetra
.641 .573 .763 r
.65308 .63402 .65614 .64172 .66209 .63995 .65902 .63224 Mtetra
.637 .571 .763 r
.65902 .63224 .66209 .63995 .66805 .63828 .66499 .63056 Mtetra
.634 .569 .764 r
.66499 .63056 .66805 .63828 .67403 .63671 .67097 .62898 Mtetra
.63 .567 .765 r
.67097 .62898 .67403 .63671 .68003 .63525 .67697 .62751 Mtetra
.627 .566 .766 r
.67697 .62751 .68003 .63525 .68605 .63388 .68299 .62614 Mtetra
.623 .564 .767 r
.68299 .62614 .68605 .63388 .69209 .63261 .68902 .62488 Mtetra
.62 .562 .768 r
.68902 .62488 .69209 .63261 .69814 .63144 .69508 .62371 Mtetra
.616 .561 .769 r
.69508 .62371 .69814 .63144 .70422 .63037 .70116 .62265 Mtetra
.613 .559 .77 r
.70116 .62265 .70422 .63037 .71031 .62939 .70725 .62168 Mtetra
.609 .557 .771 r
.70725 .62168 .71031 .62939 .71643 .62851 .71337 .62082 Mtetra
.605 .556 .773 r
.71337 .62082 .71643 .62851 .72257 .62773 .71951 .62005 Mtetra
.602 .555 .774 r
.71951 .62005 .72257 .62773 .72873 .62704 .72567 .61938 Mtetra
.598 .553 .775 r
.72567 .61938 .72873 .62704 .73491 .62644 .73186 .61881 Mtetra
.595 .552 .777 r
.73186 .61881 .73491 .62644 .74112 .62593 .73807 .61832 Mtetra
.591 .551 .778 r
.73807 .61832 .74112 .62593 .74735 .62551 .7443 .61793 Mtetra
.588 .55 .78 r
.7443 .61793 .74735 .62551 .7536 .62517 .75055 .61762 Mtetra
.584 .549 .781 r
.75055 .61762 .7536 .62517 .75988 .62491 .75683 .6174 Mtetra
.581 .548 .783 r
.75683 .6174 .75988 .62491 .76618 .62473 .76314 .61726 Mtetra
.578 .548 .785 r
.76314 .61726 .76618 .62473 .7725 .62463 .76947 .6172 Mtetra
.574 .547 .786 r
.76947 .6172 .7725 .62463 .77886 .6246 .77582 .61722 Mtetra
.571 .547 .788 r
.77582 .61722 .77886 .6246 .78523 .62464 .7822 .6173 Mtetra
.568 .546 .79 r
.7822 .6173 .78523 .62464 .79163 .62474 .78861 .61746 Mtetra
.565 .546 .792 r
.78861 .61746 .79163 .62474 .79806 .6249 .79505 .61768 Mtetra
.562 .546 .794 r
.79505 .61768 .79806 .6249 .80451 .62513 .8015 .61796 Mtetra
.559 .546 .797 r
.8015 .61796 .80451 .62513 .81099 .6254 .80799 .61829 Mtetra
.557 .547 .799 r
.80799 .61829 .81099 .6254 .8175 .62572 .8145 .61868 Mtetra
.554 .547 .801 r
.8145 .61868 .8175 .62572 .82403 .62608 .82104 .61911 Mtetra
.552 .548 .804 r
.82104 .61911 .82403 .62608 .83058 .62648 .8276 .61958 Mtetra
.55 .549 .806 r
.8276 .61958 .83058 .62648 .83717 .62691 .8342 .62009 Mtetra
.548 .55 .809 r
.8342 .62009 .83717 .62691 .84377 .62737 .84081 .62063 Mtetra
.546 .552 .812 r
.84081 .62063 .84377 .62737 .8504 .62784 .84745 .62119 Mtetra
.544 .554 .815 r
.84745 .62119 .8504 .62784 .85706 .62833 .85412 .62176 Mtetra
.543 .556 .818 r
.85412 .62176 .85706 .62833 .86374 .62883 .86081 .62235 Mtetra
.542 .558 .821 r
.86081 .62235 .86374 .62883 .87044 .62932 .86753 .62294 Mtetra
.541 .561 .824 r
.86753 .62294 .87044 .62932 .87717 .62981 .87426 .62352 Mtetra
.54 .564 .828 r
.87426 .62352 .87717 .62981 .88391 .63028 .88103 .62409 Mtetra
.54 .568 .831 r
.88103 .62409 .88391 .63028 .89068 .63072 .88781 .62464 Mtetra
.54 .572 .835 r
.88781 .62464 .89068 .63072 .89747 .63114 .89461 .62517 Mtetra
.541 .576 .839 r
.89461 .62517 .89747 .63114 .90428 .63151 .90144 .62566 Mtetra
.542 .581 .843 r
.90144 .62566 .90428 .63151 .9111 .63184 .90828 .6261 Mtetra
.543 .586 .848 r
.90828 .6261 .9111 .63184 .91795 .63211 .91515 .62649 Mtetra
.545 .592 .852 r
.91515 .62649 .91795 .63211 .9248 .63231 .92202 .62682 Mtetra
.547 .598 .857 r
.92202 .62682 .9248 .63231 .93168 .63243 .92892 .62707 Mtetra
.55 .605 .862 r
.92892 .62707 .93168 .63243 .93856 .63247 .93583 .62724 Mtetra
.553 .613 .867 r
.93583 .62724 .93856 .63247 .94546 .63241 .94275 .62732 Mtetra
.557 .621 .872 r
.94275 .62732 .94546 .63241 .95237 .63224 .94968 .62729 Mtetra
.562 .63 .877 r
.94968 .62729 .95237 .63224 .95928 .63195 .95662 .62715 Mtetra
.567 .64 .883 r
.95662 .62715 .95928 .63195 .9662 .63154 .96356 .62688 Mtetra
.573 .651 .889 r
.96356 .62688 .9662 .63154 .97312 .63098 .97051 .62647 Mtetra
.58 .662 .894 r
.97051 .62647 .97312 .63098 .98004 .63026 .97747 .62592 Mtetra
.588 .675 .9 r
.97747 .62592 .98004 .63026 .98696 .62939 .98442 .6252 Mtetra
.713 .723 .858 r
.37504 .78354 .37834 .78716 .38389 .78465 .38059 .78087 Mtetra
.717 .717 .848 r
.38059 .78087 .38389 .78465 .38945 .78199 .38617 .77805 Mtetra
.721 .711 .84 r
.38617 .77805 .38945 .78199 .39502 .77918 .39175 .77508 Mtetra
.723 .705 .832 r
.39175 .77508 .39502 .77918 .4006 .77624 .39735 .77199 Mtetra
.725 .699 .825 r
.39735 .77199 .4006 .77624 .4062 .77318 .40295 .76878 Mtetra
.727 .694 .819 r
.40295 .76878 .4062 .77318 .4118 .77001 .40857 .76546 Mtetra
.728 .689 .813 r
.40857 .76546 .4118 .77001 .41742 .76673 .41419 .76205 Mtetra
.728 .684 .808 r
.41419 .76205 .41742 .76673 .42304 .76337 .41983 .75854 Mtetra
.729 .68 .803 r
.41983 .75854 .42304 .76337 .42867 .75991 .42547 .75495 Mtetra
.729 .676 .798 r
.42547 .75495 .42867 .75991 .43431 .75639 .43111 .7513 Mtetra
.729 .671 .794 r
.43111 .7513 .43431 .75639 .43995 .7528 .43677 .74758 Mtetra
.728 .668 .79 r
.43677 .74758 .43995 .7528 .44561 .74915 .44243 .74381 Mtetra
.728 .664 .787 r
.44243 .74381 .44561 .74915 .45126 .74546 .44809 .73999 Mtetra
.727 .66 .784 r
.44809 .73999 .45126 .74546 .45693 .74173 .45376 .73614 Mtetra
.726 .657 .781 r
.45376 .73614 .45693 .74173 .46259 .73796 .45944 .73226 Mtetra
.725 .653 .778 r
.45944 .73226 .46259 .73796 .46827 .73417 .46511 .72836 Mtetra
.724 .65 .776 r
.46511 .72836 .46827 .73417 .47394 .73037 .4708 .72445 Mtetra
.722 .647 .773 r
.4708 .72445 .47394 .73037 .47963 .72656 .47649 .72053 Mtetra
.721 .644 .771 r
.47649 .72053 .47963 .72656 .48531 .72274 .48218 .71661 Mtetra
.719 .641 .77 r
.48218 .71661 .48531 .72274 .491 .71893 .48788 .7127 Mtetra
.718 .638 .768 r
.48788 .7127 .491 .71893 .4967 .71513 .49358 .7088 Mtetra
.716 .635 .766 r
.49358 .7088 .4967 .71513 .5024 .71134 .49928 .70493 Mtetra
.714 .632 .765 r
.49928 .70493 .5024 .71134 .5081 .70758 .50499 .70108 Mtetra
.712 .63 .764 r
.50499 .70108 .5081 .70758 .51381 .70385 .5107 .69726 Mtetra
.71 .627 .763 r
.5107 .69726 .51381 .70385 .51953 .70015 .51642 .69348 Mtetra
.708 .624 .762 r
.51642 .69348 .51953 .70015 .52524 .6965 .52214 .68975 Mtetra
.706 .622 .761 r
.52214 .68975 .52524 .6965 .53097 .69288 .52787 .68606 Mtetra
.703 .619 .76 r
.52787 .68606 .53097 .69288 .5367 .68932 .5336 .68242 Mtetra
.701 .617 .759 r
.5336 .68242 .5367 .68932 .54243 .68581 .53934 .67884 Mtetra
.699 .614 .759 r
.53934 .67884 .54243 .68581 .54818 .68236 .54509 .67533 Mtetra
.696 .612 .758 r
.54509 .67533 .54818 .68236 .55392 .67897 .55084 .67187 Mtetra
.693 .609 .758 r
.55084 .67187 .55392 .67897 .55968 .67565 .55659 .66849 Mtetra
.691 .607 .758 r
.55659 .66849 .55968 .67565 .56544 .6724 .56236 .66519 Mtetra
.688 .605 .757 r
.56236 .66519 .56544 .6724 .57121 .66923 .56813 .66195 Mtetra
.685 .602 .757 r
.56813 .66195 .57121 .66923 .57699 .66613 .57391 .6588 Mtetra
.683 .6 .757 r
.57391 .6588 .57699 .66613 .58277 .66311 .5797 .65574 Mtetra
.68 .598 .757 r
.5797 .65574 .58277 .66311 .58857 .66018 .58549 .65275 Mtetra
.677 .596 .757 r
.58549 .65275 .58857 .66018 .59438 .65733 .5913 .64986 Mtetra
.674 .593 .757 r
.5913 .64986 .59438 .65733 .60019 .65457 .59711 .64706 Mtetra
.671 .591 .758 r
.59711 .64706 .60019 .65457 .60602 .6519 .60294 .64435 Mtetra
.667 .589 .758 r
.60294 .64435 .60602 .6519 .61185 .64932 .60878 .64174 Mtetra
.664 .587 .758 r
.60878 .64174 .61185 .64932 .6177 .64684 .61463 .63923 Mtetra
.661 .585 .759 r
.61463 .63923 .6177 .64684 .62356 .64445 .62049 .63681 Mtetra
.658 .583 .759 r
.62049 .63681 .62356 .64445 .62944 .64216 .62636 .6345 Mtetra
.654 .58 .76 r
.62636 .6345 .62944 .64216 .63533 .63998 .63225 .63229 Mtetra
.651 .578 .76 r
.63225 .63229 .63533 .63998 .64123 .63789 .63815 .63018 Mtetra
.648 .576 .761 r
.63815 .63018 .64123 .63789 .64714 .6359 .64407 .62818 Mtetra
.644 .574 .761 r
.64407 .62818 .64714 .6359 .65308 .63402 .65 .62628 Mtetra
.641 .572 .762 r
.65 .62628 .65308 .63402 .65902 .63224 .65595 .62448 Mtetra
.637 .57 .763 r
.65595 .62448 .65902 .63224 .66499 .63056 .66192 .6228 Mtetra
.634 .569 .764 r
.66192 .6228 .66499 .63056 .67097 .62898 .6679 .62121 Mtetra
.63 .567 .765 r
.6679 .62121 .67097 .62898 .67697 .62751 .6739 .61974 Mtetra
.626 .565 .766 r
.6739 .61974 .67697 .62751 .68299 .62614 .67992 .61837 Mtetra
.623 .563 .766 r
.67992 .61837 .68299 .62614 .68902 .62488 .68595 .61711 Mtetra
.619 .561 .768 r
.68595 .61711 .68902 .62488 .69508 .62371 .69201 .61595 Mtetra
.616 .56 .769 r
.69201 .61595 .69508 .62371 .70116 .62265 .69809 .61489 Mtetra
.612 .558 .77 r
.69809 .61489 .70116 .62265 .70725 .62168 .70419 .61394 Mtetra
.608 .556 .771 r
.70419 .61394 .70725 .62168 .71337 .62082 .71031 .61309 Mtetra
.604 .555 .772 r
.71031 .61309 .71337 .62082 .71951 .62005 .71645 .61234 Mtetra
.601 .553 .773 r
.71645 .61234 .71951 .62005 .72567 .61938 .72261 .61169 Mtetra
.597 .552 .775 r
.72261 .61169 .72567 .61938 .73186 .61881 .7288 .61113 Mtetra
.593 .551 .776 r
.7288 .61113 .73186 .61881 .73807 .61832 .73501 .61067 Mtetra
.59 .55 .778 r
.73501 .61067 .73807 .61832 .7443 .61793 .74124 .61031 Mtetra
.586 .548 .779 r
.74124 .61031 .7443 .61793 .75055 .61762 .7475 .61003 Mtetra
.583 .547 .781 r
.7475 .61003 .75055 .61762 .75683 .6174 .75378 .60985 Mtetra
.579 .546 .782 r
.75378 .60985 .75683 .6174 .76314 .61726 .76009 .60975 Mtetra
.576 .546 .784 r
.76009 .60975 .76314 .61726 .76947 .6172 .76642 .60973 Mtetra
.572 .545 .786 r
.76642 .60973 .76947 .6172 .77582 .61722 .77278 .60978 Mtetra
.569 .544 .788 r
.77278 .60978 .77582 .61722 .7822 .6173 .77917 .60992 Mtetra
.566 .544 .789 r
.77917 .60992 .7822 .6173 .78861 .61746 .78558 .61012 Mtetra
.563 .544 .791 r
.78558 .61012 .78861 .61746 .79505 .61768 .79202 .6104 Mtetra
.559 .544 .794 r
.79202 .6104 .79505 .61768 .8015 .61796 .79849 .61073 Mtetra
.557 .544 .796 r
.79849 .61073 .8015 .61796 .80799 .61829 .80498 .61113 Mtetra
.554 .544 .798 r
.80498 .61113 .80799 .61829 .8145 .61868 .8115 .61158 Mtetra
.551 .544 .8 r
.8115 .61158 .8145 .61868 .82104 .61911 .81804 .61208 Mtetra
.549 .545 .803 r
.81804 .61208 .82104 .61911 .8276 .61958 .82461 .61262 Mtetra
.546 .546 .805 r
.82461 .61262 .8276 .61958 .8342 .62009 .83121 .6132 Mtetra
.544 .547 .808 r
.83121 .6132 .8342 .62009 .84081 .62063 .83784 .61381 Mtetra
.542 .548 .81 r
.83784 .61381 .84081 .62063 .84745 .62119 .84449 .61445 Mtetra
.54 .55 .813 r
.84449 .61445 .84745 .62119 .85412 .62176 .85117 .61511 Mtetra
.539 .552 .816 r
.85117 .61511 .85412 .62176 .86081 .62235 .85787 .61579 Mtetra
.537 .554 .819 r
.85787 .61579 .86081 .62235 .86753 .62294 .8646 .61647 Mtetra
.536 .556 .823 r
.8646 .61647 .86753 .62294 .87426 .62352 .87135 .61714 Mtetra
.536 .559 .826 r
.87135 .61714 .87426 .62352 .88103 .62409 .87812 .61782 Mtetra
.535 .563 .829 r
.87812 .61782 .88103 .62409 .88781 .62464 .88492 .61847 Mtetra
.535 .566 .833 r
.88492 .61847 .88781 .62464 .89461 .62517 .89174 .6191 Mtetra
.535 .57 .837 r
.89174 .6191 .89461 .62517 .90144 .62566 .89859 .6197 Mtetra
.536 .575 .841 r
.89859 .6197 .90144 .62566 .90828 .6261 .90545 .62026 Mtetra
.537 .58 .845 r
.90545 .62026 .90828 .6261 .91515 .62649 .91233 .62077 Mtetra
.539 .585 .849 r
.91233 .62077 .91515 .62649 .92202 .62682 .91923 .62121 Mtetra
.541 .591 .854 r
.91923 .62121 .92202 .62682 .92892 .62707 .92614 .62159 Mtetra
.543 .598 .859 r
.92614 .62159 .92892 .62707 .93583 .62724 .93307 .62189 Mtetra
.546 .605 .863 r
.93307 .62189 .93583 .62724 .94275 .62732 .94001 .6221 Mtetra
.55 .613 .869 r
.94001 .6221 .94275 .62732 .94968 .62729 .94697 .62221 Mtetra
.555 .622 .874 r
.94697 .62221 .94968 .62729 .95662 .62715 .95393 .62221 Mtetra
.56 .631 .879 r
.95393 .62221 .95662 .62715 .96356 .62688 .96091 .62209 Mtetra
.565 .641 .885 r
.96091 .62209 .96356 .62688 .97051 .62647 .96788 .62183 Mtetra
.572 .652 .89 r
.96788 .62183 .97051 .62647 .97747 .62592 .97487 .62143 Mtetra
.579 .664 .896 r
.97487 .62143 .97747 .62592 .98442 .6252 .98185 .62087 Mtetra
.718 .719 .85 r
.37172 .7798 .37504 .78354 .38059 .78087 .37729 .77697 Mtetra
.722 .713 .841 r
.37729 .77697 .38059 .78087 .38617 .77805 .38288 .77399 Mtetra
.725 .707 .833 r
.38288 .77399 .38617 .77805 .39175 .77508 .38847 .77088 Mtetra
.727 .701 .826 r
.38847 .77088 .39175 .77508 .39735 .77199 .39408 .76764 Mtetra
.729 .696 .819 r
.39408 .76764 .39735 .77199 .40295 .76878 .3997 .76428 Mtetra
.73 .691 .813 r
.3997 .76428 .40295 .76878 .40857 .76546 .40533 .76082 Mtetra
.731 .687 .808 r
.40533 .76082 .40857 .76546 .41419 .76205 .41096 .75726 Mtetra
.731 .682 .803 r
.41096 .75726 .41419 .76205 .41983 .75854 .4166 .75362 Mtetra
.731 .678 .798 r
.4166 .75362 .41983 .75854 .42547 .75495 .42225 .7499 Mtetra
.731 .674 .794 r
.42225 .7499 .42547 .75495 .43111 .7513 .42791 .74612 Mtetra
.731 .67 .79 r
.42791 .74612 .43111 .7513 .43677 .74758 .43357 .74227 Mtetra
.73 .666 .787 r
.43357 .74227 .43677 .74758 .44243 .74381 .43924 .73838 Mtetra
.73 .662 .784 r
.43924 .73838 .44243 .74381 .44809 .73999 .44491 .73445 Mtetra
.729 .659 .781 r
.44491 .73445 .44809 .73999 .45376 .73614 .45059 .73048 Mtetra
.728 .656 .778 r
.45059 .73048 .45376 .73614 .45944 .73226 .45627 .72649 Mtetra
.727 .652 .775 r
.45627 .72649 .45944 .73226 .46511 .72836 .46196 .72248 Mtetra
.725 .649 .773 r
.46196 .72248 .46511 .72836 .4708 .72445 .46765 .71846 Mtetra
.724 .646 .771 r
.46765 .71846 .4708 .72445 .47649 .72053 .47334 .71444 Mtetra
.722 .643 .769 r
.47334 .71444 .47649 .72053 .48218 .71661 .47904 .71042 Mtetra
.721 .64 .767 r
.47904 .71042 .48218 .71661 .48788 .7127 .48474 .70641 Mtetra
.719 .637 .766 r
.48474 .70641 .48788 .7127 .49358 .7088 .49045 .70242 Mtetra
.717 .635 .764 r
.49045 .70242 .49358 .7088 .49928 .70493 .49616 .69846 Mtetra
.715 .632 .763 r
.49616 .69846 .49928 .70493 .50499 .70108 .50187 .69452 Mtetra
.713 .629 .762 r
.50187 .69452 .50499 .70108 .5107 .69726 .50759 .69062 Mtetra
.711 .627 .761 r
.50759 .69062 .5107 .69726 .51642 .69348 .51331 .68676 Mtetra
.709 .624 .76 r
.51331 .68676 .51642 .69348 .52214 .68975 .51904 .68295 Mtetra
.707 .622 .759 r
.51904 .68295 .52214 .68975 .52787 .68606 .52477 .67919 Mtetra
.705 .619 .759 r
.52477 .67919 .52787 .68606 .5336 .68242 .5305 .67548 Mtetra
.702 .617 .758 r
.5305 .67548 .5336 .68242 .53934 .67884 .53624 .67183 Mtetra
.7 .614 .758 r
.53624 .67183 .53934 .67884 .54509 .67533 .54199 .66825 Mtetra
.697 .612 .757 r
.54199 .66825 .54509 .67533 .55084 .67187 .54774 .66474 Mtetra
.695 .609 .757 r
.54774 .66474 .55084 .67187 .55659 .66849 .5535 .66129 Mtetra
.692 .607 .757 r
.5535 .66129 .55659 .66849 .56236 .66519 .55927 .65793 Mtetra
.689 .605 .756 r
.55927 .65793 .56236 .66519 .56813 .66195 .56504 .65464 Mtetra
.686 .602 .756 r
.56504 .65464 .56813 .66195 .57391 .6588 .57082 .65144 Mtetra
.683 .6 .756 r
.57082 .65144 .57391 .6588 .5797 .65574 .57661 .64833 Mtetra
.68 .598 .756 r
.57661 .64833 .5797 .65574 .58549 .65275 .58241 .6453 Mtetra
.677 .595 .757 r
.58241 .6453 .58549 .65275 .5913 .64986 .58822 .64237 Mtetra
.674 .593 .757 r
.58822 .64237 .5913 .64986 .59711 .64706 .59403 .63953 Mtetra
.671 .591 .757 r
.59403 .63953 .59711 .64706 .60294 .64435 .59986 .63678 Mtetra
.668 .589 .757 r
.59986 .63678 .60294 .64435 .60878 .64174 .6057 .63414 Mtetra
.665 .587 .758 r
.6057 .63414 .60878 .64174 .61463 .63923 .61155 .63159 Mtetra
.662 .584 .758 r
.61155 .63159 .61463 .63923 .62049 .63681 .61741 .62915 Mtetra
.658 .582 .759 r
.61741 .62915 .62049 .63681 .62636 .6345 .62329 .62681 Mtetra
.655 .58 .759 r
.62329 .62681 .62636 .6345 .63225 .63229 .62918 .62458 Mtetra
.651 .578 .76 r
.62918 .62458 .63225 .63229 .63815 .63018 .63508 .62245 Mtetra
.648 .576 .76 r
.63508 .62245 .63815 .63018 .64407 .62818 .641 .62043 Mtetra
.644 .574 .761 r
.641 .62043 .64407 .62818 .65 .62628 .64693 .61851 Mtetra
.641 .572 .762 r
.64693 .61851 .65 .62628 .65595 .62448 .65288 .61671 Mtetra
.637 .57 .763 r
.65288 .61671 .65595 .62448 .66192 .6228 .65884 .61501 Mtetra
.634 .568 .763 r
.65884 .61501 .66192 .6228 .6679 .62121 .66482 .61342 Mtetra
.63 .566 .764 r
.66482 .61342 .6679 .62121 .6739 .61974 .67082 .61194 Mtetra
.626 .564 .765 r
.67082 .61194 .6739 .61974 .67992 .61837 .67684 .61057 Mtetra
.622 .562 .766 r
.67684 .61057 .67992 .61837 .68595 .61711 .68288 .60931 Mtetra
.619 .561 .767 r
.68288 .60931 .68595 .61711 .69201 .61595 .68894 .60815 Mtetra
.615 .559 .768 r
.68894 .60815 .69201 .61595 .69809 .61489 .69502 .6071 Mtetra
.611 .557 .769 r
.69502 .6071 .69809 .61489 .70419 .61394 .70112 .60616 Mtetra
.607 .556 .771 r
.70112 .60616 .70419 .61394 .71031 .61309 .70724 .60532 Mtetra
.603 .554 .772 r
.70724 .60532 .71031 .61309 .71645 .61234 .71338 .60459 Mtetra
.6 .552 .773 r
.71338 .60459 .71645 .61234 .72261 .61169 .71954 .60396 Mtetra
.596 .551 .774 r
.71954 .60396 .72261 .61169 .7288 .61113 .72573 .60343 Mtetra
.592 .55 .776 r
.72573 .60343 .7288 .61113 .73501 .61067 .73194 .60299 Mtetra
.588 .548 .777 r
.73194 .60299 .73501 .61067 .74124 .61031 .73818 .60265 Mtetra
.585 .547 .779 r
.73818 .60265 .74124 .61031 .7475 .61003 .74444 .60241 Mtetra
.581 .546 .78 r
.74444 .60241 .7475 .61003 .75378 .60985 .75073 .60225 Mtetra
.577 .545 .782 r
.75073 .60225 .75378 .60985 .76009 .60975 .75704 .60219 Mtetra
.574 .544 .784 r
.75704 .60219 .76009 .60975 .76642 .60973 .76337 .60221 Mtetra
.57 .543 .785 r
.76337 .60221 .76642 .60973 .77278 .60978 .76974 .60231 Mtetra
.567 .542 .787 r
.76974 .60231 .77278 .60978 .77917 .60992 .77613 .60249 Mtetra
.563 .542 .789 r
.77613 .60249 .77917 .60992 .78558 .61012 .78254 .60274 Mtetra
.56 .541 .791 r
.78254 .60274 .78558 .61012 .79202 .6104 .78899 .60307 Mtetra
.557 .541 .793 r
.78899 .60307 .79202 .6104 .79849 .61073 .79546 .60346 Mtetra
.554 .541 .795 r
.79546 .60346 .79849 .61073 .80498 .61113 .80196 .60391 Mtetra
.551 .541 .797 r
.80196 .60391 .80498 .61113 .8115 .61158 .80848 .60442 Mtetra
.548 .541 .799 r
.80848 .60442 .8115 .61158 .81804 .61208 .81503 .60499 Mtetra
.545 .542 .802 r
.81503 .60499 .81804 .61208 .82461 .61262 .82161 .6056 Mtetra
.543 .543 .804 r
.82161 .6056 .82461 .61262 .83121 .6132 .82822 .60625 Mtetra
.54 .544 .807 r
.82822 .60625 .83121 .6132 .83784 .61381 .83486 .60694 Mtetra
.538 .545 .809 r
.83486 .60694 .83784 .61381 .84449 .61445 .84152 .60765 Mtetra
.536 .546 .812 r
.84152 .60765 .84449 .61445 .85117 .61511 .8482 .6084 Mtetra
.534 .548 .815 r
.8482 .6084 .85117 .61511 .85787 .61579 .85492 .60915 Mtetra
.533 .55 .818 r
.85492 .60915 .85787 .61579 .8646 .61647 .86166 .60992 Mtetra
.532 .552 .821 r
.86166 .60992 .8646 .61647 .87135 .61714 .86842 .61069 Mtetra
.531 .555 .824 r
.86842 .61069 .87135 .61714 .87812 .61782 .87521 .61146 Mtetra
.53 .558 .828 r
.87521 .61146 .87812 .61782 .88492 .61847 .88202 .61221 Mtetra
.53 .561 .831 r
.88202 .61221 .88492 .61847 .89174 .6191 .88886 .61295 Mtetra
.53 .565 .835 r
.88886 .61295 .89174 .6191 .89859 .6197 .89572 .61365 Mtetra
.531 .569 .839 r
.89572 .61365 .89859 .6197 .90545 .62026 .90259 .61432 Mtetra
.532 .574 .843 r
.90259 .61432 .90545 .62026 .91233 .62077 .90949 .61495 Mtetra
.533 .579 .847 r
.90949 .61495 .91233 .62077 .91923 .62121 .91641 .61551 Mtetra
.535 .585 .851 r
.91641 .61551 .91923 .62121 .92614 .62159 .92335 .61601 Mtetra
.537 .591 .856 r
.92335 .61601 .92614 .62159 .93307 .62189 .9303 .61644 Mtetra
.54 .598 .861 r
.9303 .61644 .93307 .62189 .94001 .6221 .93726 .61678 Mtetra
.543 .606 .866 r
.93726 .61678 .94001 .6221 .94697 .62221 .94424 .61702 Mtetra
.547 .614 .871 r
.94424 .61702 .94697 .62221 .95393 .62221 .95123 .61716 Mtetra
.552 .623 .876 r
.95123 .61716 .95393 .62221 .96091 .62209 .95823 .61718 Mtetra
.558 .632 .881 r
.95823 .61718 .96091 .62209 .96788 .62183 .96523 .61707 Mtetra
.564 .643 .887 r
.96523 .61707 .96788 .62183 .97487 .62143 .97224 .61681 Mtetra
.571 .654 .893 r
.97224 .61681 .97487 .62143 .98185 .62087 .97925 .61641 Mtetra
.723 .715 .843 r
.3684 .77594 .37172 .7798 .37729 .77697 .37399 .77295 Mtetra
.726 .709 .835 r
.37399 .77295 .37729 .77697 .38288 .77399 .37958 .76983 Mtetra
.728 .704 .827 r
.37958 .76983 .38288 .77399 .38847 .77088 .38519 .76656 Mtetra
.73 .699 .82 r
.38519 .76656 .38847 .77088 .39408 .76764 .39081 .76318 Mtetra
.732 .694 .814 r
.39081 .76318 .39408 .76764 .3997 .76428 .39644 .75968 Mtetra
.733 .689 .809 r
.39644 .75968 .3997 .76428 .40533 .76082 .40208 .75608 Mtetra
.733 .685 .804 r
.40208 .75608 .40533 .76082 .41096 .75726 .40772 .75239 Mtetra
.734 .68 .799 r
.40772 .75239 .41096 .75726 .4166 .75362 .41338 .74861 Mtetra
.734 .676 .794 r
.41338 .74861 .4166 .75362 .42225 .7499 .41903 .74477 Mtetra
.733 .672 .791 r
.41903 .74477 .42225 .7499 .42791 .74612 .4247 .74086 Mtetra
.733 .669 .787 r
.4247 .74086 .42791 .74612 .43357 .74227 .43037 .73689 Mtetra
.732 .665 .784 r
.43037 .73689 .43357 .74227 .43924 .73838 .43605 .73288 Mtetra
.732 .661 .781 r
.43605 .73288 .43924 .73838 .44491 .73445 .44173 .72883 Mtetra
.731 .658 .778 r
.44173 .72883 .44491 .73445 .45059 .73048 .44741 .72475 Mtetra
.73 .655 .775 r
.44741 .72475 .45059 .73048 .45627 .72649 .4531 .72065 Mtetra
.728 .652 .773 r
.4531 .72065 .45627 .72649 .46196 .72248 .4588 .71653 Mtetra
.727 .649 .771 r
.4588 .71653 .46196 .72248 .46765 .71846 .46449 .71241 Mtetra
.726 .646 .769 r
.46449 .71241 .46765 .71846 .47334 .71444 .47019 .70829 Mtetra
.724 .643 .767 r
.47019 .70829 .47334 .71444 .47904 .71042 .4759 .70417 Mtetra
.722 .64 .766 r
.4759 .70417 .47904 .71042 .48474 .70641 .4816 .70007 Mtetra
.721 .637 .764 r
.4816 .70007 .48474 .70641 .49045 .70242 .48732 .69599 Mtetra
.719 .634 .763 r
.48732 .69599 .49045 .70242 .49616 .69846 .49303 .69194 Mtetra
.717 .632 .762 r
.49303 .69194 .49616 .69846 .50187 .69452 .49875 .68792 Mtetra
.715 .629 .761 r
.49875 .68792 .50187 .69452 .50759 .69062 .50447 .68394 Mtetra
.713 .627 .76 r
.50447 .68394 .50759 .69062 .51331 .68676 .5102 .68 Mtetra
.711 .624 .759 r
.5102 .68 .51331 .68676 .51904 .68295 .51593 .67611 Mtetra
.708 .622 .758 r
.51593 .67611 .51904 .68295 .52477 .67919 .52166 .67227 Mtetra
.706 .619 .757 r
.52166 .67227 .52477 .67919 .5305 .67548 .5274 .6685 Mtetra
.703 .617 .757 r
.5274 .6685 .5305 .67548 .53624 .67183 .53314 .66478 Mtetra
.701 .614 .757 r
.53314 .66478 .53624 .67183 .54199 .66825 .53889 .66114 Mtetra
.698 .612 .756 r
.53889 .66114 .54199 .66825 .54774 .66474 .54465 .65756 Mtetra
.696 .609 .756 r
.54465 .65756 .54774 .66474 .5535 .66129 .55041 .65407 Mtetra
.693 .607 .756 r
.55041 .65407 .5535 .66129 .55927 .65793 .55618 .65065 Mtetra
.69 .605 .756 r
.55618 .65065 .55927 .65793 .56504 .65464 .56195 .64731 Mtetra
.687 .602 .756 r
.56195 .64731 .56504 .65464 .57082 .65144 .56773 .64406 Mtetra
.684 .6 .756 r
.56773 .64406 .57082 .65144 .57661 .64833 .57352 .64089 Mtetra
.681 .598 .756 r
.57352 .64089 .57661 .64833 .58241 .6453 .57932 .63782 Mtetra
.678 .596 .756 r
.57932 .63782 .58241 .6453 .58822 .64237 .58513 .63485 Mtetra
.675 .593 .756 r
.58513 .63485 .58822 .64237 .59403 .63953 .59095 .63197 Mtetra
.672 .591 .756 r
.59095 .63197 .59403 .63953 .59986 .63678 .59678 .62919 Mtetra
.669 .589 .757 r
.59678 .62919 .59986 .63678 .6057 .63414 .60262 .62651 Mtetra
.665 .587 .757 r
.60262 .62651 .6057 .63414 .61155 .63159 .60847 .62393 Mtetra
.662 .585 .758 r
.60847 .62393 .61155 .63159 .61741 .62915 .61433 .62146 Mtetra
.659 .582 .758 r
.61433 .62146 .61741 .62915 .62329 .62681 .62021 .6191 Mtetra
.655 .58 .759 r
.62021 .6191 .62329 .62681 .62918 .62458 .6261 .61684 Mtetra
.652 .578 .759 r
.6261 .61684 .62918 .62458 .63508 .62245 .632 .61469 Mtetra
.648 .576 .76 r
.632 .61469 .63508 .62245 .641 .62043 .63792 .61266 Mtetra
.644 .574 .761 r
.63792 .61266 .641 .62043 .64693 .61851 .64385 .61073 Mtetra
.641 .572 .762 r
.64385 .61073 .64693 .61851 .65288 .61671 .6498 .60891 Mtetra
.637 .57 .762 r
.6498 .60891 .65288 .61671 .65884 .61501 .65576 .6072 Mtetra
.633 .568 .763 r
.65576 .6072 .65884 .61501 .66482 .61342 .66175 .60561 Mtetra
.63 .566 .764 r
.66175 .60561 .66482 .61342 .67082 .61194 .66775 .60413 Mtetra
.626 .564 .765 r
.66775 .60413 .67082 .61194 .67684 .61057 .67377 .60275 Mtetra
.622 .562 .766 r
.67377 .60275 .67684 .61057 .68288 .60931 .6798 .60149 Mtetra
.618 .56 .767 r
.6798 .60149 .68288 .60931 .68894 .60815 .68586 .60034 Mtetra
.614 .558 .768 r
.68586 .60034 .68894 .60815 .69502 .6071 .69194 .5993 Mtetra
.61 .557 .769 r
.69194 .5993 .69502 .6071 .70112 .60616 .69804 .59837 Mtetra
.606 .555 .771 r
.69804 .59837 .70112 .60616 .70724 .60532 .70416 .59754 Mtetra
.603 .553 .772 r
.70416 .59754 .70724 .60532 .71338 .60459 .7103 .59682 Mtetra
.599 .552 .773 r
.7103 .59682 .71338 .60459 .71954 .60396 .71647 .59621 Mtetra
.595 .55 .774 r
.71647 .59621 .71954 .60396 .72573 .60343 .72266 .5957 Mtetra
.591 .549 .776 r
.72266 .5957 .72573 .60343 .73194 .60299 .72887 .59528 Mtetra
.587 .547 .777 r
.72887 .59528 .73194 .60299 .73818 .60265 .73511 .59497 Mtetra
.583 .546 .779 r
.73511 .59497 .73818 .60265 .74444 .60241 .74138 .59476 Mtetra
.579 .545 .78 r
.74138 .59476 .74444 .60241 .75073 .60225 .74766 .59463 Mtetra
.575 .543 .782 r
.74766 .59463 .75073 .60225 .75704 .60219 .75398 .5946 Mtetra
.572 .542 .783 r
.75398 .5946 .75704 .60219 .76337 .60221 .76032 .59466 Mtetra
.568 .541 .785 r
.76032 .59466 .76337 .60221 .76974 .60231 .76669 .5948 Mtetra
.564 .541 .787 r
.76669 .5948 .76974 .60231 .77613 .60249 .77308 .59503 Mtetra
.561 .54 .789 r
.77308 .59503 .77613 .60249 .78254 .60274 .7795 .59533 Mtetra
.557 .539 .791 r
.7795 .59533 .78254 .60274 .78899 .60307 .78595 .5957 Mtetra
.554 .539 .793 r
.78595 .5957 .78899 .60307 .79546 .60346 .79242 .59615 Mtetra
.551 .539 .795 r
.79242 .59615 .79546 .60346 .80196 .60391 .79893 .59665 Mtetra
.548 .539 .797 r
.79893 .59665 .80196 .60391 .80848 .60442 .80546 .59722 Mtetra
.545 .539 .799 r
.80546 .59722 .80848 .60442 .81503 .60499 .81202 .59785 Mtetra
.542 .539 .801 r
.81202 .59785 .81503 .60499 .82161 .6056 .81861 .59853 Mtetra
.539 .54 .804 r
.81861 .59853 .82161 .6056 .82822 .60625 .82522 .59925 Mtetra
.537 .54 .806 r
.82522 .59925 .82822 .60625 .83486 .60694 .83186 .60001 Mtetra
.534 .541 .809 r
.83186 .60001 .83486 .60694 .84152 .60765 .83853 .6008 Mtetra
.532 .543 .811 r
.83853 .6008 .84152 .60765 .8482 .6084 .84523 .60162 Mtetra
.53 .544 .814 r
.84523 .60162 .8482 .6084 .85492 .60915 .85195 .60246 Mtetra
.529 .546 .817 r
.85195 .60246 .85492 .60915 .86166 .60992 .8587 .60331 Mtetra
.527 .548 .82 r
.8587 .60331 .86166 .60992 .86842 .61069 .86548 .60418 Mtetra
.526 .551 .823 r
.86548 .60418 .86842 .61069 .87521 .61146 .87228 .60504 Mtetra
.525 .553 .827 r
.87228 .60504 .87521 .61146 .88202 .61221 .87911 .60589 Mtetra
.525 .556 .83 r
.87911 .60589 .88202 .61221 .88886 .61295 .88596 .60672 Mtetra
.525 .56 .834 r
.88596 .60672 .88886 .61295 .89572 .61365 .89283 .60753 Mtetra
.525 .564 .837 r
.89283 .60753 .89572 .61365 .90259 .61432 .89973 .60831 Mtetra
.526 .568 .841 r
.89973 .60831 .90259 .61432 .90949 .61495 .90664 .60904 Mtetra
.527 .573 .845 r
.90664 .60904 .90949 .61495 .91641 .61551 .91358 .60972 Mtetra
.529 .579 .849 r
.91358 .60972 .91641 .61551 .92335 .61601 .92053 .61034 Mtetra
.531 .585 .854 r
.92053 .61034 .92335 .61601 .9303 .61644 .9275 .61089 Mtetra
.533 .591 .858 r
.9275 .61089 .9303 .61644 .93726 .61678 .93449 .61135 Mtetra
.537 .598 .863 r
.93449 .61135 .93726 .61678 .94424 .61702 .94149 .61173 Mtetra
.54 .606 .868 r
.94149 .61173 .94424 .61702 .95123 .61716 .9485 .612 Mtetra
.545 .615 .873 r
.9485 .612 .95123 .61716 .95823 .61718 .95553 .61215 Mtetra
.55 .624 .878 r
.95553 .61215 .95823 .61718 .96523 .61707 .96256 .61218 Mtetra
.556 .634 .884 r
.96256 .61218 .96523 .61707 .97224 .61681 .9696 .61208 Mtetra
.563 .645 .889 r
.9696 .61208 .97224 .61681 .97925 .61641 .97664 .61182 Mtetra
.727 .712 .836 r
.36508 .77198 .3684 .77594 .37399 .77295 .37067 .76884 Mtetra
.73 .707 .829 r
.37067 .76884 .37399 .77295 .37958 .76983 .37628 .76556 Mtetra
.732 .701 .822 r
.37628 .76556 .37958 .76983 .38519 .76656 .3819 .76216 Mtetra
.733 .696 .815 r
.3819 .76216 .38519 .76656 .39081 .76318 .38753 .75863 Mtetra
.734 .692 .81 r
.38753 .75863 .39081 .76318 .39644 .75968 .39317 .75499 Mtetra
.735 .687 .804 r
.39317 .75499 .39644 .75968 .40208 .75608 .39882 .75126 Mtetra
.736 .683 .8 r
.39882 .75126 .40208 .75608 .40772 .75239 .40448 .74743 Mtetra
.736 .679 .795 r
.40448 .74743 .40772 .75239 .41338 .74861 .41014 .74353 Mtetra
.736 .675 .791 r
.41014 .74353 .41338 .74861 .41903 .74477 .41581 .73956 Mtetra
.736 .671 .787 r
.41581 .73956 .41903 .74477 .4247 .74086 .42148 .73552 Mtetra
.735 .668 .784 r
.42148 .73552 .4247 .74086 .43037 .73689 .42716 .73144 Mtetra
.734 .664 .781 r
.42716 .73144 .43037 .73689 .43605 .73288 .43285 .72731 Mtetra
.734 .661 .778 r
.43285 .72731 .43605 .73288 .44173 .72883 .43854 .72315 Mtetra
.733 .657 .775 r
.43854 .72315 .44173 .72883 .44741 .72475 .44423 .71896 Mtetra
.732 .654 .773 r
.44423 .71896 .44741 .72475 .4531 .72065 .44993 .71475 Mtetra
.73 .651 .771 r
.44993 .71475 .4531 .72065 .4588 .71653 .45563 .71053 Mtetra
.729 .648 .769 r
.45563 .71053 .4588 .71653 .46449 .71241 .46133 .70631 Mtetra
.727 .645 .767 r
.46133 .70631 .46449 .71241 .47019 .70829 .46704 .70209 Mtetra
.726 .643 .765 r
.46704 .70209 .47019 .70829 .4759 .70417 .47275 .69788 Mtetra
.724 .64 .764 r
.47275 .69788 .4759 .70417 .4816 .70007 .47846 .69369 Mtetra
.722 .637 .763 r
.47846 .69369 .4816 .70007 .48732 .69599 .48418 .68952 Mtetra
.72 .634 .761 r
.48418 .68952 .48732 .69599 .49303 .69194 .4899 .68538 Mtetra
.718 .632 .76 r
.4899 .68538 .49303 .69194 .49875 .68792 .49562 .68128 Mtetra
.716 .629 .759 r
.49562 .68128 .49875 .68792 .50447 .68394 .50135 .67722 Mtetra
.714 .627 .758 r
.50135 .67722 .50447 .68394 .5102 .68 .50707 .6732 Mtetra
.712 .624 .758 r
.50707 .6732 .5102 .68 .51593 .67611 .51281 .66924 Mtetra
.71 .622 .757 r
.51281 .66924 .51593 .67611 .52166 .67227 .51855 .66534 Mtetra
.707 .619 .757 r
.51855 .66534 .52166 .67227 .5274 .6685 .52429 .66149 Mtetra
.705 .617 .756 r
.52429 .66149 .5274 .6685 .53314 .66478 .53004 .65771 Mtetra
.702 .614 .756 r
.53004 .65771 .53314 .66478 .53889 .66114 .53579 .654 Mtetra
.7 .612 .755 r
.53579 .654 .53889 .66114 .54465 .65756 .54155 .65037 Mtetra
.697 .61 .755 r
.54155 .65037 .54465 .65756 .55041 .65407 .54731 .64681 Mtetra
.694 .607 .755 r
.54731 .64681 .55041 .65407 .55618 .65065 .55308 .64334 Mtetra
.691 .605 .755 r
.55308 .64334 .55618 .65065 .56195 .64731 .55886 .63995 Mtetra
.688 .603 .755 r
.55886 .63995 .56195 .64731 .56773 .64406 .56464 .63665 Mtetra
.685 .6 .755 r
.56464 .63665 .56773 .64406 .57352 .64089 .57043 .63345 Mtetra
.682 .598 .755 r
.57043 .63345 .57352 .64089 .57932 .63782 .57623 .63033 Mtetra
.679 .596 .756 r
.57623 .63033 .57932 .63782 .58513 .63485 .58204 .62732 Mtetra
.676 .594 .756 r
.58204 .62732 .58513 .63485 .59095 .63197 .58786 .6244 Mtetra
.673 .591 .756 r
.58786 .6244 .59095 .63197 .59678 .62919 .59369 .62158 Mtetra
.669 .589 .757 r
.59369 .62158 .59678 .62919 .60262 .62651 .59953 .61887 Mtetra
.666 .587 .757 r
.59953 .61887 .60262 .62651 .60847 .62393 .60538 .61627 Mtetra
.663 .585 .757 r
.60538 .61627 .60847 .62393 .61433 .62146 .61125 .61377 Mtetra
.659 .583 .758 r
.61125 .61377 .61433 .62146 .62021 .6191 .61712 .61138 Mtetra
.656 .58 .759 r
.61712 .61138 .62021 .6191 .6261 .61684 .62301 .6091 Mtetra
.652 .578 .759 r
.62301 .6091 .6261 .61684 .632 .61469 .62891 .60693 Mtetra
.648 .576 .76 r
.62891 .60693 .632 .61469 .63792 .61266 .63483 .60488 Mtetra
.645 .574 .761 r
.63483 .60488 .63792 .61266 .64385 .61073 .64077 .60293 Mtetra
.641 .572 .762 r
.64077 .60293 .64385 .61073 .6498 .60891 .64671 .6011 Mtetra
.637 .57 .762 r
.64671 .6011 .6498 .60891 .65576 .6072 .65268 .59939 Mtetra
.633 .568 .763 r
.65268 .59939 .65576 .6072 .66175 .60561 .65866 .59779 Mtetra
.629 .566 .764 r
.65866 .59779 .66175 .60561 .66775 .60413 .66466 .5963 Mtetra
.626 .564 .765 r
.66466 .5963 .66775 .60413 .67377 .60275 .67068 .59493 Mtetra
.622 .562 .766 r
.67068 .59493 .67377 .60275 .6798 .60149 .67672 .59367 Mtetra
.618 .56 .767 r
.67672 .59367 .6798 .60149 .68586 .60034 .68278 .59252 Mtetra
.614 .558 .768 r
.68278 .59252 .68586 .60034 .69194 .5993 .68886 .59148 Mtetra
.61 .556 .769 r
.68886 .59148 .69194 .5993 .69804 .59837 .69496 .59056 Mtetra
.606 .554 .771 r
.69496 .59056 .69804 .59837 .70416 .59754 .70108 .58975 Mtetra
.602 .553 .772 r
.70108 .58975 .70416 .59754 .7103 .59682 .70723 .58904 Mtetra
.598 .551 .773 r
.70723 .58904 .7103 .59682 .71647 .59621 .7134 .58844 Mtetra
.594 .549 .774 r
.7134 .58844 .71647 .59621 .72266 .5957 .71959 .58795 Mtetra
.589 .548 .776 r
.71959 .58795 .72266 .5957 .72887 .59528 .7258 .58756 Mtetra
.585 .546 .777 r
.7258 .58756 .72887 .59528 .73511 .59497 .73204 .58727 Mtetra
.581 .545 .779 r
.73204 .58727 .73511 .59497 .74138 .59476 .73831 .58709 Mtetra
.578 .543 .78 r
.73831 .58709 .74138 .59476 .74766 .59463 .7446 .587 Mtetra
.574 .542 .782 r
.7446 .587 .74766 .59463 .75398 .5946 .75091 .587 Mtetra
.57 .541 .783 r
.75091 .587 .75398 .5946 .76032 .59466 .75726 .58709 Mtetra
.566 .54 .785 r
.75726 .58709 .76032 .59466 .76669 .5948 .76363 .58727 Mtetra
.562 .539 .787 r
.76363 .58727 .76669 .5948 .77308 .59503 .77003 .58754 Mtetra
.558 .538 .789 r
.77003 .58754 .77308 .59503 .7795 .59533 .77645 .58788 Mtetra
.555 .538 .791 r
.77645 .58788 .7795 .59533 .78595 .5957 .7829 .58831 Mtetra
.551 .537 .792 r
.7829 .58831 .78595 .5957 .79242 .59615 .78938 .5888 Mtetra
.548 .537 .794 r
.78938 .5888 .79242 .59615 .79893 .59665 .79589 .58936 Mtetra
.545 .537 .797 r
.79589 .58936 .79893 .59665 .80546 .59722 .80243 .58999 Mtetra
.542 .537 .799 r
.80243 .58999 .80546 .59722 .81202 .59785 .809 .59068 Mtetra
.539 .537 .801 r
.809 .59068 .81202 .59785 .81861 .59853 .81559 .59142 Mtetra
.536 .537 .803 r
.81559 .59142 .81861 .59853 .82522 .59925 .82221 .5922 Mtetra
.533 .538 .806 r
.82221 .5922 .82522 .59925 .83186 .60001 .82886 .59303 Mtetra
.531 .538 .808 r
.82886 .59303 .83186 .60001 .83853 .6008 .83554 .5939 Mtetra
.528 .54 .811 r
.83554 .5939 .83853 .6008 .84523 .60162 .84225 .59479 Mtetra
.526 .541 .813 r
.84225 .59479 .84523 .60162 .85195 .60246 .84898 .59572 Mtetra
.524 .542 .816 r
.84898 .59572 .85195 .60246 .8587 .60331 .85574 .59665 Mtetra
.523 .544 .819 r
.85574 .59665 .8587 .60331 .86548 .60418 .86253 .5976 Mtetra
.522 .547 .822 r
.86253 .5976 .86548 .60418 .87228 .60504 .86934 .59855 Mtetra
.521 .549 .825 r
.86934 .59855 .87228 .60504 .87911 .60589 .87618 .59949 Mtetra
.52 .552 .829 r
.87618 .59949 .87911 .60589 .88596 .60672 .88305 .60043 Mtetra
.52 .555 .832 r
.88305 .60043 .88596 .60672 .89283 .60753 .88993 .60134 Mtetra
.52 .559 .836 r
.88993 .60134 .89283 .60753 .89973 .60831 .89685 .60222 Mtetra
.52 .563 .84 r
.89685 .60222 .89973 .60831 .90664 .60904 .90378 .60306 Mtetra
.521 .568 .844 r
.90378 .60306 .90664 .60904 .91358 .60972 .91073 .60385 Mtetra
.523 .573 .848 r
.91073 .60385 .91358 .60972 .92053 .61034 .9177 .60458 Mtetra
.525 .579 .852 r
.9177 .60458 .92053 .61034 .9275 .61089 .9247 .60525 Mtetra
.527 .585 .856 r
.9247 .60525 .9275 .61089 .93449 .61135 .9317 .60584 Mtetra
.53 .592 .861 r
.9317 .60584 .93449 .61135 .94149 .61173 .93872 .60634 Mtetra
.534 .599 .866 r
.93872 .60634 .94149 .61173 .9485 .612 .94576 .60674 Mtetra
.538 .607 .871 r
.94576 .60674 .9485 .612 .95553 .61215 .95281 .60703 Mtetra
.543 .616 .876 r
.95281 .60703 .95553 .61215 .96256 .61218 .95986 .6072 Mtetra
.548 .626 .881 r
.95986 .6072 .96256 .61218 .9696 .61208 .96693 .60723 Mtetra
.555 .636 .886 r
.96693 .60723 .9696 .61208 .97664 .61182 .974 .60712 Mtetra
.731 .709 .831 r
.36174 .76792 .36508 .77198 .37067 .76884 .36735 .76464 Mtetra
.733 .704 .823 r
.36735 .76464 .37067 .76884 .37628 .76556 .37298 .76121 Mtetra
.735 .699 .817 r
.37298 .76121 .37628 .76556 .3819 .76216 .37861 .75767 Mtetra
.736 .694 .811 r
.37861 .75767 .3819 .76216 .38753 .75863 .38425 .754 Mtetra
.737 .69 .805 r
.38425 .754 .38753 .75863 .39317 .75499 .3899 .75023 Mtetra
.738 .686 .8 r
.3899 .75023 .39317 .75499 .39882 .75126 .39556 .74636 Mtetra
.738 .682 .796 r
.39556 .74636 .39882 .75126 .40448 .74743 .40123 .74241 Mtetra
.738 .678 .792 r
.40123 .74241 .40448 .74743 .41014 .74353 .4069 .73838 Mtetra
.738 .674 .788 r
.4069 .73838 .41014 .74353 .41581 .73956 .41258 .73428 Mtetra
.738 .67 .784 r
.41258 .73428 .41581 .73956 .42148 .73552 .41826 .73013 Mtetra
.737 .667 .781 r
.41826 .73013 .42148 .73552 .42716 .73144 .42395 .72593 Mtetra
.736 .663 .778 r
.42395 .72593 .42716 .73144 .43285 .72731 .42964 .72169 Mtetra
.736 .66 .776 r
.42964 .72169 .43285 .72731 .43854 .72315 .43534 .71741 Mtetra
.735 .657 .773 r
.43534 .71741 .43854 .72315 .44423 .71896 .44104 .71312 Mtetra
.733 .654 .771 r
.44104 .71312 .44423 .71896 .44993 .71475 .44675 .70881 Mtetra
.732 .651 .769 r
.44675 .70881 .44993 .71475 .45563 .71053 .45245 .70449 Mtetra
.731 .648 .767 r
.45245 .70449 .45563 .71053 .46133 .70631 .45816 .70017 Mtetra
.729 .645 .765 r
.45816 .70017 .46133 .70631 .46704 .70209 .46388 .69585 Mtetra
.728 .643 .764 r
.46388 .69585 .46704 .70209 .47275 .69788 .46959 .69155 Mtetra
.726 .64 .762 r
.46959 .69155 .47275 .69788 .47846 .69369 .47531 .68727 Mtetra
.724 .637 .761 r
.47531 .68727 .47846 .69369 .48418 .68952 .48103 .68302 Mtetra
.722 .635 .76 r
.48103 .68302 .48418 .68952 .4899 .68538 .48676 .6788 Mtetra
.72 .632 .759 r
.48676 .6788 .4899 .68538 .49562 .68128 .49249 .67461 Mtetra
.718 .63 .758 r
.49249 .67461 .49562 .68128 .50135 .67722 .49822 .67047 Mtetra
.716 .627 .757 r
.49822 .67047 .50135 .67722 .50707 .6732 .50395 .66639 Mtetra
.713 .625 .757 r
.50395 .66639 .50707 .6732 .51281 .66924 .50969 .66235 Mtetra
.711 .622 .756 r
.50969 .66235 .51281 .66924 .51855 .66534 .51543 .65838 Mtetra
.709 .62 .756 r
.51543 .65838 .51855 .66534 .52429 .66149 .52117 .65447 Mtetra
.706 .617 .755 r
.52117 .65447 .52429 .66149 .53004 .65771 .52692 .65062 Mtetra
.704 .615 .755 r
.52692 .65062 .53004 .65771 .53579 .654 .53268 .64685 Mtetra
.701 .613 .755 r
.53268 .64685 .53579 .654 .54155 .65037 .53844 .64316 Mtetra
.698 .61 .755 r
.53844 .64316 .54155 .65037 .54731 .64681 .54421 .63955 Mtetra
.695 .608 .755 r
.54421 .63955 .54731 .64681 .55308 .64334 .54998 .63603 Mtetra
.692 .606 .755 r
.54998 .63603 .55308 .64334 .55886 .63995 .55576 .63259 Mtetra
.689 .603 .755 r
.55576 .63259 .55886 .63995 .56464 .63665 .56154 .62924 Mtetra
.686 .601 .755 r
.56154 .62924 .56464 .63665 .57043 .63345 .56734 .62599 Mtetra
.683 .599 .755 r
.56734 .62599 .57043 .63345 .57623 .63033 .57314 .62283 Mtetra
.68 .596 .755 r
.57314 .62283 .57623 .63033 .58204 .62732 .57895 .61978 Mtetra
.677 .594 .756 r
.57895 .61978 .58204 .62732 .58786 .6244 .58477 .61682 Mtetra
.674 .592 .756 r
.58477 .61682 .58786 .6244 .59369 .62158 .5906 .61397 Mtetra
.67 .59 .756 r
.5906 .61397 .59369 .62158 .59953 .61887 .59644 .61123 Mtetra
.667 .587 .757 r
.59644 .61123 .59953 .61887 .60538 .61627 .60229 .6086 Mtetra
.663 .585 .757 r
.60229 .6086 .60538 .61627 .61125 .61377 .60816 .60607 Mtetra
.66 .583 .758 r
.60816 .60607 .61125 .61377 .61712 .61138 .61403 .60366 Mtetra
.656 .581 .759 r
.61403 .60366 .61712 .61138 .62301 .6091 .61992 .60136 Mtetra
.652 .579 .759 r
.61992 .60136 .62301 .6091 .62891 .60693 .62583 .59917 Mtetra
.649 .576 .76 r
.62583 .59917 .62891 .60693 .63483 .60488 .63174 .5971 Mtetra
.645 .574 .761 r
.63174 .5971 .63483 .60488 .64077 .60293 .63768 .59514 Mtetra
.641 .572 .762 r
.63768 .59514 .64077 .60293 .64671 .6011 .64363 .5933 Mtetra
.637 .57 .763 r
.64363 .5933 .64671 .6011 .65268 .59939 .64959 .59157 Mtetra
.633 .568 .763 r
.64959 .59157 .65268 .59939 .65866 .59779 .65558 .58997 Mtetra
.629 .566 .764 r
.65558 .58997 .65866 .59779 .66466 .5963 .66158 .58847 Mtetra
.625 .564 .765 r
.66158 .58847 .66466 .5963 .67068 .59493 .6676 .5871 Mtetra
.621 .562 .766 r
.6676 .5871 .67068 .59493 .67672 .59367 .67364 .58584 Mtetra
.617 .56 .767 r
.67364 .58584 .67672 .59367 .68278 .59252 .6797 .58469 Mtetra
.613 .558 .769 r
.6797 .58469 .68278 .59252 .68886 .59148 .68578 .58367 Mtetra
.609 .556 .77 r
.68578 .58367 .68886 .59148 .69496 .59056 .69188 .58275 Mtetra
.605 .554 .771 r
.69188 .58275 .69496 .59056 .70108 .58975 .698 .58195 Mtetra
.601 .552 .772 r
.698 .58195 .70108 .58975 .70723 .58904 .70415 .58126 Mtetra
.597 .55 .773 r
.70415 .58126 .70723 .58904 .7134 .58844 .71032 .58067 Mtetra
.592 .549 .775 r
.71032 .58067 .7134 .58844 .71959 .58795 .71651 .5802 Mtetra
.588 .547 .776 r
.71651 .5802 .71959 .58795 .7258 .58756 .72272 .57983 Mtetra
.584 .546 .778 r
.72272 .57983 .7258 .58756 .73204 .58727 .72897 .57957 Mtetra
.58 .544 .779 r
.72897 .57957 .73204 .58727 .73831 .58709 .73523 .57941 Mtetra
.576 .543 .781 r
.73523 .57941 .73831 .58709 .7446 .587 .74153 .57935 Mtetra
.572 .541 .782 r
.74153 .57935 .7446 .587 .75091 .587 .74785 .57938 Mtetra
.568 .54 .784 r
.74785 .57938 .75091 .587 .75726 .58709 .75419 .57951 Mtetra
.564 .539 .785 r
.75419 .57951 .75726 .58709 .76363 .58727 .76057 .57973 Mtetra
.56 .538 .787 r
.76057 .57973 .76363 .58727 .77003 .58754 .76697 .58003 Mtetra
.556 .537 .789 r
.76697 .58003 .77003 .58754 .77645 .58788 .77339 .58042 Mtetra
.552 .536 .791 r
.77339 .58042 .77645 .58788 .7829 .58831 .77985 .58089 Mtetra
.549 .535 .793 r
.77985 .58089 .7829 .58831 .78938 .5888 .78634 .58143 Mtetra
.545 .535 .794 r
.78634 .58143 .78938 .5888 .79589 .58936 .79285 .58205 Mtetra
.542 .535 .797 r
.79285 .58205 .79589 .58936 .80243 .58999 .79939 .58273 Mtetra
.538 .534 .799 r
.79939 .58273 .80243 .58999 .809 .59068 .80597 .58347 Mtetra
.535 .534 .801 r
.80597 .58347 .809 .59068 .81559 .59142 .81257 .58427 Mtetra
.532 .535 .803 r
.81257 .58427 .81559 .59142 .82221 .5922 .8192 .58513 Mtetra
.529 .535 .805 r
.8192 .58513 .82221 .5922 .82886 .59303 .82585 .58602 Mtetra
.527 .536 .808 r
.82585 .58602 .82886 .59303 .83554 .5939 .83254 .58696 Mtetra
.524 .537 .81 r
.83254 .58696 .83554 .5939 .84225 .59479 .83926 .58793 Mtetra
.522 .538 .813 r
.83926 .58793 .84225 .59479 .84898 .59572 .846 .58893 Mtetra
.52 .539 .816 r
.846 .58893 .84898 .59572 .85574 .59665 .85277 .58995 Mtetra
.518 .541 .819 r
.85277 .58995 .85574 .59665 .86253 .5976 .85957 .59098 Mtetra
.517 .543 .822 r
.85957 .59098 .86253 .5976 .86934 .59855 .86639 .59201 Mtetra
.516 .545 .825 r
.86639 .59201 .86934 .59855 .87618 .59949 .87325 .59305 Mtetra
.515 .548 .828 r
.87325 .59305 .87618 .59949 .88305 .60043 .88012 .59407 Mtetra
.514 .551 .831 r
.88012 .59407 .88305 .60043 .88993 .60134 .88703 .59508 Mtetra
.514 .555 .835 r
.88703 .59508 .88993 .60134 .89685 .60222 .89395 .59606 Mtetra
.515 .559 .838 r
.89395 .59606 .89685 .60222 .90378 .60306 .9009 .59701 Mtetra
.515 .563 .842 r
.9009 .59701 .90378 .60306 .91073 .60385 .90787 .59791 Mtetra
.517 .568 .846 r
.90787 .59791 .91073 .60385 .9177 .60458 .91486 .59875 Mtetra
.518 .573 .85 r
.91486 .59875 .9177 .60458 .9247 .60525 .92187 .59954 Mtetra
.521 .579 .855 r
.92187 .59954 .9247 .60525 .9317 .60584 .9289 .60024 Mtetra
.523 .586 .859 r
.9289 .60024 .9317 .60584 .93872 .60634 .93594 .60087 Mtetra
.527 .593 .864 r
.93594 .60087 .93872 .60634 .94576 .60674 .943 .60139 Mtetra
.531 .601 .868 r
.943 .60139 .94576 .60674 .95281 .60703 .95007 .60181 Mtetra
.535 .609 .873 r
.95007 .60181 .95281 .60703 .95986 .6072 .95715 .60211 Mtetra
.541 .618 .879 r
.95715 .60211 .95986 .6072 .96693 .60723 .96424 .60228 Mtetra
.547 .628 .884 r
.96424 .60228 .96693 .60723 .974 .60712 .97134 .60231 Mtetra
.734 .707 .825 r
.3584 .76378 .36174 .76792 .36735 .76464 .36403 .76035 Mtetra
.736 .702 .819 r
.36403 .76035 .36735 .76464 .37298 .76121 .36966 .75679 Mtetra
.738 .697 .812 r
.36966 .75679 .37298 .76121 .37861 .75767 .37531 .7531 Mtetra
.739 .693 .807 r
.37531 .7531 .37861 .75767 .38425 .754 .38096 .7493 Mtetra
.74 .688 .802 r
.38096 .7493 .38425 .754 .3899 .75023 .38662 .7454 Mtetra
.74 .684 .797 r
.38662 .7454 .3899 .75023 .39556 .74636 .39229 .7414 Mtetra
.741 .681 .793 r
.39229 .7414 .39556 .74636 .40123 .74241 .39797 .73732 Mtetra
.741 .677 .789 r
.39797 .73732 .40123 .74241 .4069 .73838 .40365 .73317 Mtetra
.74 .673 .785 r
.40365 .73317 .4069 .73838 .41258 .73428 .40934 .72895 Mtetra
.74 .67 .782 r
.40934 .72895 .41258 .73428 .41826 .73013 .41503 .72468 Mtetra
.739 .666 .779 r
.41503 .72468 .41826 .73013 .42395 .72593 .42073 .72037 Mtetra
.738 .663 .776 r
.42073 .72037 .42395 .72593 .42964 .72169 .42643 .71602 Mtetra
.738 .66 .774 r
.42643 .71602 .42964 .72169 .43534 .71741 .43214 .71164 Mtetra
.736 .657 .771 r
.43214 .71164 .43534 .71741 .44104 .71312 .43785 .70724 Mtetra
.735 .654 .769 r
.43785 .70724 .44104 .71312 .44675 .70881 .44356 .70282 Mtetra
.734 .651 .767 r
.44356 .70282 .44675 .70881 .45245 .70449 .44927 .6984 Mtetra
.732 .648 .765 r
.44927 .6984 .45245 .70449 .45816 .70017 .45499 .69399 Mtetra
.731 .646 .764 r
.45499 .69399 .45816 .70017 .46388 .69585 .46071 .68958 Mtetra
.729 .643 .762 r
.46071 .68958 .46388 .69585 .46959 .69155 .46643 .68519 Mtetra
.727 .64 .761 r
.46643 .68519 .46959 .69155 .47531 .68727 .47216 .68083 Mtetra
.726 .638 .76 r
.47216 .68083 .47531 .68727 .48103 .68302 .47788 .67649 Mtetra
.724 .635 .759 r
.47788 .67649 .48103 .68302 .48676 .6788 .48361 .67219 Mtetra
.722 .633 .758 r
.48361 .67219 .48676 .6788 .49249 .67461 .48935 .66793 Mtetra
.719 .63 .757 r
.48935 .66793 .49249 .67461 .49822 .67047 .49508 .66371 Mtetra
.717 .628 .757 r
.49508 .66371 .49822 .67047 .50395 .66639 .50082 .65955 Mtetra
.715 .625 .756 r
.50082 .65955 .50395 .66639 .50969 .66235 .50656 .65545 Mtetra
.713 .623 .756 r
.50656 .65545 .50969 .66235 .51543 .65838 .51231 .6514 Mtetra
.71 .62 .755 r
.51231 .6514 .51543 .65838 .52117 .65447 .51805 .64743 Mtetra
.708 .618 .755 r
.51805 .64743 .52117 .65447 .52692 .65062 .52381 .64353 Mtetra
.705 .616 .755 r
.52381 .64353 .52692 .65062 .53268 .64685 .52957 .6397 Mtetra
.702 .613 .754 r
.52957 .6397 .53268 .64685 .53844 .64316 .53533 .63595 Mtetra
.699 .611 .754 r
.53533 .63595 .53844 .64316 .54421 .63955 .5411 .63229 Mtetra
.697 .609 .754 r
.5411 .63229 .54421 .63955 .54998 .63603 .54687 .62871 Mtetra
.694 .606 .754 r
.54687 .62871 .54998 .63603 .55576 .63259 .55265 .62522 Mtetra
.691 .604 .754 r
.55265 .62522 .55576 .63259 .56154 .62924 .55844 .62183 Mtetra
.687 .602 .755 r
.55844 .62183 .56154 .62924 .56734 .62599 .56424 .61853 Mtetra
.684 .599 .755 r
.56424 .61853 .56734 .62599 .57314 .62283 .57004 .61534 Mtetra
.681 .597 .755 r
.57004 .61534 .57314 .62283 .57895 .61978 .57585 .61224 Mtetra
.678 .595 .756 r
.57585 .61224 .57895 .61978 .58477 .61682 .58167 .60925 Mtetra
.674 .593 .756 r
.58167 .60925 .58477 .61682 .5906 .61397 .5875 .60637 Mtetra
.671 .59 .757 r
.5875 .60637 .5906 .61397 .59644 .61123 .59335 .6036 Mtetra
.667 .588 .757 r
.59335 .6036 .59644 .61123 .60229 .6086 .5992 .60093 Mtetra
.664 .586 .758 r
.5992 .60093 .60229 .6086 .60816 .60607 .60506 .59838 Mtetra
.66 .584 .758 r
.60506 .59838 .60816 .60607 .61403 .60366 .61094 .59594 Mtetra
.657 .581 .759 r
.61094 .59594 .61403 .60366 .61992 .60136 .61683 .59362 Mtetra
.653 .579 .76 r
.61683 .59362 .61992 .60136 .62583 .59917 .62274 .59141 Mtetra
.649 .577 .76 r
.62274 .59141 .62583 .59917 .63174 .5971 .62865 .58933 Mtetra
.645 .575 .761 r
.62865 .58933 .63174 .5971 .63768 .59514 .63459 .58735 Mtetra
.641 .573 .762 r
.63459 .58735 .63768 .59514 .64363 .5933 .64054 .5855 Mtetra
.637 .57 .763 r
.64054 .5855 .64363 .5933 .64959 .59157 .6465 .58377 Mtetra
.633 .568 .764 r
.6465 .58377 .64959 .59157 .65558 .58997 .65249 .58215 Mtetra
.629 .566 .765 r
.65249 .58215 .65558 .58997 .66158 .58847 .65849 .58066 Mtetra
.625 .564 .766 r
.65849 .58066 .66158 .58847 .6676 .5871 .66451 .57928 Mtetra
.621 .562 .767 r
.66451 .57928 .6676 .5871 .67364 .58584 .67055 .57802 Mtetra
.617 .56 .768 r
.67055 .57802 .67364 .58584 .6797 .58469 .67661 .57688 Mtetra
.613 .558 .769 r
.67661 .57688 .6797 .58469 .68578 .58367 .68269 .57585 Mtetra
.608 .556 .77 r
.68269 .57585 .68578 .58367 .69188 .58275 .68879 .57495 Mtetra
.604 .554 .771 r
.68879 .57495 .69188 .58275 .698 .58195 .69492 .57415 Mtetra
.6 .552 .773 r
.69492 .57415 .698 .58195 .70415 .58126 .70106 .57347 Mtetra
.596 .55 .774 r
.70106 .57347 .70415 .58126 .71032 .58067 .70723 .57291 Mtetra
.591 .548 .775 r
.70723 .57291 .71032 .58067 .71651 .5802 .71343 .57245 Mtetra
.587 .547 .777 r
.71343 .57245 .71651 .5802 .72272 .57983 .71964 .5721 Mtetra
.583 .545 .778 r
.71964 .5721 .72272 .57983 .72897 .57957 .72589 .57186 Mtetra
.578 .543 .779 r
.72589 .57186 .72897 .57957 .73523 .57941 .73216 .57173 Mtetra
.574 .542 .781 r
.73216 .57173 .73523 .57941 .74153 .57935 .73845 .57169 Mtetra
.57 .54 .783 r
.73845 .57169 .74153 .57935 .74785 .57938 .74477 .57176 Mtetra
.566 .539 .784 r
.74477 .57176 .74785 .57938 .75419 .57951 .75112 .57192 Mtetra
.562 .538 .786 r
.75112 .57192 .75419 .57951 .76057 .57973 .7575 .57217 Mtetra
.558 .537 .787 r
.7575 .57217 .76057 .57973 .76697 .58003 .7639 .57252 Mtetra
.554 .536 .789 r
.7639 .57252 .76697 .58003 .77339 .58042 .77033 .57295 Mtetra
.55 .535 .791 r
.77033 .57295 .77339 .58042 .77985 .58089 .7768 .57346 Mtetra
.546 .534 .793 r
.7768 .57346 .77985 .58089 .78634 .58143 .78329 .57405 Mtetra
.542 .533 .795 r
.78329 .57405 .78634 .58143 .79285 .58205 .7898 .57472 Mtetra
.539 .533 .797 r
.7898 .57472 .79285 .58205 .79939 .58273 .79635 .57545 Mtetra
.535 .533 .799 r
.79635 .57545 .79939 .58273 .80597 .58347 .80293 .57625 Mtetra
.532 .532 .801 r
.80293 .57625 .80597 .58347 .81257 .58427 .80954 .57711 Mtetra
.529 .532 .803 r
.80954 .57711 .81257 .58427 .8192 .58513 .81617 .57803 Mtetra
.526 .533 .805 r
.81617 .57803 .8192 .58513 .82585 .58602 .82284 .57899 Mtetra
.523 .533 .808 r
.82284 .57899 .82585 .58602 .83254 .58696 .82953 .57999 Mtetra
.52 .534 .81 r
.82953 .57999 .83254 .58696 .83926 .58793 .83626 .58103 Mtetra
.518 .535 .813 r
.83626 .58103 .83926 .58793 .846 .58893 .84301 .58211 Mtetra
.516 .536 .815 r
.84301 .58211 .846 .58893 .85277 .58995 .84979 .5832 Mtetra
.514 .538 .818 r
.84979 .5832 .85277 .58995 .85957 .59098 .8566 .58431 Mtetra
.512 .54 .821 r
.8566 .58431 .85957 .59098 .86639 .59201 .86344 .58543 Mtetra
.511 .542 .824 r
.86344 .58543 .86639 .59201 .87325 .59305 .8703 .58656 Mtetra
.51 .544 .827 r
.8703 .58656 .87325 .59305 .88012 .59407 .87719 .58767 Mtetra
.509 .547 .83 r
.87719 .58767 .88012 .59407 .88703 .59508 .88411 .58877 Mtetra
.509 .55 .834 r
.88411 .58877 .88703 .59508 .89395 .59606 .89105 .58985 Mtetra
.509 .554 .837 r
.89105 .58985 .89395 .59606 .9009 .59701 .89801 .5909 Mtetra
.51 .558 .841 r
.89801 .5909 .9009 .59701 .90787 .59791 .905 .5919 Mtetra
.511 .563 .845 r
.905 .5919 .90787 .59791 .91486 .59875 .912 .59286 Mtetra
.512 .568 .849 r
.912 .59286 .91486 .59875 .92187 .59954 .91903 .59375 Mtetra
.514 .574 .853 r
.91903 .59375 .92187 .59954 .9289 .60024 .92608 .59458 Mtetra
.517 .58 .857 r
.92608 .59458 .9289 .60024 .93594 .60087 .93314 .59532 Mtetra
.52 .587 .862 r
.93314 .59532 .93594 .60087 .943 .60139 .94022 .59597 Mtetra
.524 .594 .867 r
.94022 .59597 .943 .60139 .95007 .60181 .94732 .59651 Mtetra
.528 .602 .871 r
.94732 .59651 .95007 .60181 .95715 .60211 .95442 .59694 Mtetra
.534 .611 .876 r
.95442 .59694 .95715 .60211 .96424 .60228 .96153 .59725 Mtetra
.54 .621 .881 r
.96153 .59725 .96424 .60228 .97134 .60231 .96866 .59741 Mtetra
.737 .705 .821 r
.35506 .75955 .3584 .76378 .36403 .76035 .36069 .75598 Mtetra
.739 .7 .814 r
.36069 .75598 .36403 .76035 .36966 .75679 .36634 .75228 Mtetra
.741 .696 .808 r
.36634 .75228 .36966 .75679 .37531 .7531 .372 .74846 Mtetra
.742 .692 .803 r
.372 .74846 .37531 .7531 .38096 .7493 .37766 .74453 Mtetra
.742 .687 .798 r
.37766 .74453 .38096 .7493 .38662 .7454 .38334 .7405 Mtetra
.743 .684 .794 r
.38334 .7405 .38662 .7454 .39229 .7414 .38902 .73638 Mtetra
.743 .68 .79 r
.38902 .73638 .39229 .7414 .39797 .73732 .39471 .73218 Mtetra
.743 .676 .786 r
.39471 .73218 .39797 .73732 .40365 .73317 .4004 .72791 Mtetra
.743 .673 .783 r
.4004 .72791 .40365 .73317 .40934 .72895 .4061 .72358 Mtetra
.742 .669 .779 r
.4061 .72358 .40934 .72895 .41503 .72468 .4118 .71919 Mtetra
.741 .666 .777 r
.4118 .71919 .41503 .72468 .42073 .72037 .41751 .71477 Mtetra
.74 .663 .774 r
.41751 .71477 .42073 .72037 .42643 .71602 .42322 .71031 Mtetra
.74 .66 .772 r
.42322 .71031 .42643 .71602 .43214 .71164 .42893 .70582 Mtetra
.738 .657 .769 r
.42893 .70582 .43214 .71164 .43785 .70724 .43465 .70132 Mtetra
.737 .654 .768 r
.43465 .70132 .43785 .70724 .44356 .70282 .44037 .69681 Mtetra
.736 .651 .766 r
.44037 .69681 .44356 .70282 .44927 .6984 .44609 .69229 Mtetra
.734 .649 .764 r
.44609 .69229 .44927 .6984 .45499 .69399 .45181 .68779 Mtetra
.733 .646 .763 r
.45181 .68779 .45499 .69399 .46071 .68958 .45754 .68329 Mtetra
.731 .643 .761 r
.45754 .68329 .46071 .68958 .46643 .68519 .46327 .67881 Mtetra
.729 .641 .76 r
.46327 .67881 .46643 .68519 .47216 .68083 .469 .67436 Mtetra
.727 .638 .759 r
.469 .67436 .47216 .68083 .47788 .67649 .47473 .66994 Mtetra
.725 .636 .758 r
.47473 .66994 .47788 .67649 .48361 .67219 .48046 .66556 Mtetra
.723 .633 .757 r
.48046 .66556 .48361 .67219 .48935 .66793 .4862 .66123 Mtetra
.721 .631 .757 r
.4862 .66123 .48935 .66793 .49508 .66371 .49194 .65694 Mtetra
.719 .628 .756 r
.49194 .65694 .49508 .66371 .50082 .65955 .49768 .65271 Mtetra
.716 .626 .755 r
.49768 .65271 .50082 .65955 .50656 .65545 .50343 .64853 Mtetra
.714 .624 .755 r
.50343 .64853 .50656 .65545 .51231 .6514 .50918 .64443 Mtetra
.712 .621 .755 r
.50918 .64443 .51231 .6514 .51805 .64743 .51493 .64039 Mtetra
.709 .619 .754 r
.51493 .64039 .51805 .64743 .52381 .64353 .52069 .63643 Mtetra
.706 .617 .754 r
.52069 .63643 .52381 .64353 .52957 .6397 .52645 .63254 Mtetra
.704 .614 .754 r
.52645 .63254 .52957 .6397 .53533 .63595 .53221 .62874 Mtetra
.701 .612 .754 r
.53221 .62874 .53533 .63595 .5411 .63229 .53798 .62502 Mtetra
.698 .61 .754 r
.53798 .62502 .5411 .63229 .54687 .62871 .54376 .6214 Mtetra
.695 .607 .754 r
.54376 .6214 .54687 .62871 .55265 .62522 .54954 .61786 Mtetra
.692 .605 .754 r
.54954 .61786 .55265 .62522 .55844 .62183 .55533 .61442 Mtetra
.689 .603 .755 r
.55533 .61442 .55844 .62183 .56424 .61853 .56113 .61109 Mtetra
.685 .6 .755 r
.56113 .61109 .56424 .61853 .57004 .61534 .56694 .60785 Mtetra
.682 .598 .755 r
.56694 .60785 .57004 .61534 .57585 .61224 .57275 .60472 Mtetra
.679 .596 .756 r
.57275 .60472 .57585 .61224 .58167 .60925 .57857 .60169 Mtetra
.675 .594 .756 r
.57857 .60169 .58167 .60925 .5875 .60637 .58441 .59878 Mtetra
.672 .591 .757 r
.58441 .59878 .5875 .60637 .59335 .6036 .59025 .59597 Mtetra
.668 .589 .757 r
.59025 .59597 .59335 .6036 .5992 .60093 .5961 .59328 Mtetra
.665 .587 .758 r
.5961 .59328 .5992 .60093 .60506 .59838 .60197 .5907 Mtetra
.661 .584 .759 r
.60197 .5907 .60506 .59838 .61094 .59594 .60785 .58824 Mtetra
.657 .582 .759 r
.60785 .58824 .61094 .59594 .61683 .59362 .61374 .5859 Mtetra
.653 .58 .76 r
.61374 .5859 .61683 .59362 .62274 .59141 .61964 .58367 Mtetra
.649 .578 .761 r
.61964 .58367 .62274 .59141 .62865 .58933 .62556 .58157 Mtetra
.645 .575 .762 r
.62556 .58157 .62865 .58933 .63459 .58735 .6315 .57958 Mtetra
.641 .573 .763 r
.6315 .57958 .63459 .58735 .64054 .5855 .63745 .57772 Mtetra
.637 .571 .763 r
.63745 .57772 .64054 .5855 .6465 .58377 .64341 .57598 Mtetra
.633 .569 .764 r
.64341 .57598 .6465 .58377 .65249 .58215 .6494 .57435 Mtetra
.629 .567 .765 r
.6494 .57435 .65249 .58215 .65849 .58066 .6554 .57285 Mtetra
.625 .564 .766 r
.6554 .57285 .65849 .58066 .66451 .57928 .66142 .57147 Mtetra
.621 .562 .767 r
.66142 .57147 .66451 .57928 .67055 .57802 .66746 .57021 Mtetra
.616 .56 .769 r
.66746 .57021 .67055 .57802 .67661 .57688 .67352 .56907 Mtetra
.612 .558 .77 r
.67352 .56907 .67661 .57688 .68269 .57585 .6796 .56806 Mtetra
.608 .556 .771 r
.6796 .56806 .68269 .57585 .68879 .57495 .6857 .56715 Mtetra
.603 .554 .772 r
.6857 .56715 .68879 .57495 .69492 .57415 .69183 .56637 Mtetra
.599 .552 .773 r
.69183 .56637 .69492 .57415 .70106 .57347 .69798 .5657 Mtetra
.595 .55 .775 r
.69798 .5657 .70106 .57347 .70723 .57291 .70415 .56515 Mtetra
.59 .548 .776 r
.70415 .56515 .70723 .57291 .71343 .57245 .71034 .56471 Mtetra
.586 .546 .777 r
.71034 .56471 .71343 .57245 .71964 .5721 .71656 .56438 Mtetra
.581 .545 .779 r
.71656 .56438 .71964 .5721 .72589 .57186 .72281 .56417 Mtetra
.577 .543 .78 r
.72281 .56417 .72589 .57186 .73216 .57173 .72908 .56405 Mtetra
.573 .541 .782 r
.72908 .56405 .73216 .57173 .73845 .57169 .73537 .56405 Mtetra
.568 .54 .783 r
.73537 .56405 .73845 .57169 .74477 .57176 .7417 .56414 Mtetra
.564 .538 .785 r
.7417 .56414 .74477 .57176 .75112 .57192 .74805 .56433 Mtetra
.56 .537 .786 r
.74805 .56433 .75112 .57192 .7575 .57217 .75443 .56462 Mtetra
.555 .536 .788 r
.75443 .56462 .7575 .57217 .7639 .57252 .76083 .56501 Mtetra
.551 .535 .79 r
.76083 .56501 .7639 .57252 .77033 .57295 .76727 .56548 Mtetra
.547 .534 .791 r
.76727 .56548 .77033 .57295 .7768 .57346 .77373 .56603 Mtetra
.543 .533 .793 r
.77373 .56603 .7768 .57346 .78329 .57405 .78023 .56667 Mtetra
.539 .532 .795 r
.78023 .56667 .78329 .57405 .7898 .57472 .78675 .56738 Mtetra
.536 .531 .797 r
.78675 .56738 .7898 .57472 .79635 .57545 .79331 .56817 Mtetra
.532 .531 .799 r
.79331 .56817 .79635 .57545 .80293 .57625 .79989 .56902 Mtetra
.529 .531 .801 r
.79989 .56902 .80293 .57625 .80954 .57711 .8065 .56994 Mtetra
.525 .53 .803 r
.8065 .56994 .80954 .57711 .81617 .57803 .81314 .57091 Mtetra
.522 .531 .806 r
.81314 .57091 .81617 .57803 .82284 .57899 .81982 .57193 Mtetra
.519 .531 .808 r
.81982 .57193 .82284 .57899 .82953 .57999 .82652 .573 Mtetra
.516 .532 .81 r
.82652 .573 .82953 .57999 .83626 .58103 .83325 .57411 Mtetra
.514 .532 .813 r
.83325 .57411 .83626 .58103 .84301 .58211 .84001 .57526 Mtetra
.511 .533 .815 r
.84001 .57526 .84301 .58211 .84979 .5832 .8468 .57643 Mtetra
.509 .535 .818 r
.8468 .57643 .84979 .5832 .8566 .58431 .85362 .57762 Mtetra
.508 .536 .821 r
.85362 .57762 .8566 .58431 .86344 .58543 .86047 .57882 Mtetra
.506 .538 .824 r
.86047 .57882 .86344 .58543 .8703 .58656 .86734 .58003 Mtetra
.505 .541 .827 r
.86734 .58003 .8703 .58656 .87719 .58767 .87425 .58123 Mtetra
.504 .543 .83 r
.87425 .58123 .87719 .58767 .88411 .58877 .88118 .58242 Mtetra
.504 .547 .833 r
.88118 .58242 .88411 .58877 .89105 .58985 .88813 .5836 Mtetra
.504 .55 .837 r
.88813 .5836 .89105 .58985 .89801 .5909 .89511 .58474 Mtetra
.504 .554 .84 r
.89511 .58474 .89801 .5909 .905 .5919 .90211 .58585 Mtetra
.505 .558 .844 r
.90211 .58585 .905 .5919 .912 .59286 .90914 .58691 Mtetra
.506 .563 .848 r
.90914 .58691 .912 .59286 .91903 .59375 .91618 .58791 Mtetra
.508 .569 .852 r
.91618 .58791 .91903 .59375 .92608 .59458 .92325 .58884 Mtetra
.51 .575 .856 r
.92325 .58884 .92608 .59458 .93314 .59532 .93033 .5897 Mtetra
.513 .581 .86 r
.93033 .5897 .93314 .59532 .94022 .59597 .93743 .59047 Mtetra
.517 .588 .865 r
.93743 .59047 .94022 .59597 .94732 .59651 .94454 .59114 Mtetra
.521 .596 .87 r
.94454 .59114 .94732 .59651 .95442 .59694 .95167 .59169 Mtetra
.526 .605 .875 r
.95167 .59169 .95442 .59694 .96153 .59725 .95881 .59213 Mtetra
.532 .614 .879 r
.95881 .59213 .96153 .59725 .96866 .59741 .96596 .59242 Mtetra
.74 .704 .816 r
.3517 .75526 .35506 .75955 .36069 .75598 .35735 .75155 Mtetra
.742 .699 .81 r
.35735 .75155 .36069 .75598 .36634 .75228 .36301 .74772 Mtetra
.743 .695 .805 r
.36301 .74772 .36634 .75228 .372 .74846 .36868 .74377 Mtetra
.744 .691 .8 r
.36868 .74377 .372 .74846 .37766 .74453 .37436 .73971 Mtetra
.745 .687 .795 r
.37436 .73971 .37766 .74453 .38334 .7405 .38004 .73555 Mtetra
.745 .683 .791 r
.38004 .73555 .38334 .7405 .38902 .73638 .38574 .73131 Mtetra
.745 .679 .787 r
.38574 .73131 .38902 .73638 .39471 .73218 .39143 .72699 Mtetra
.745 .676 .784 r
.39143 .72699 .39471 .73218 .4004 .72791 .39714 .7226 Mtetra
.745 .673 .78 r
.39714 .7226 .4004 .72791 .4061 .72358 .40285 .71816 Mtetra
.744 .669 .777 r
.40285 .71816 .4061 .72358 .4118 .71919 .40856 .71366 Mtetra
.743 .666 .775 r
.40856 .71366 .4118 .71919 .41751 .71477 .41427 .70913 Mtetra
.743 .663 .772 r
.41427 .70913 .41751 .71477 .42322 .71031 .41999 .70457 Mtetra
.741 .66 .77 r
.41999 .70457 .42322 .71031 .42893 .70582 .42571 .69998 Mtetra
.74 .657 .768 r
.42571 .69998 .42893 .70582 .43465 .70132 .43144 .69538 Mtetra
.739 .655 .766 r
.43144 .69538 .43465 .70132 .44037 .69681 .43717 .69077 Mtetra
.738 .652 .764 r
.43717 .69077 .44037 .69681 .44609 .69229 .4429 .68617 Mtetra
.736 .649 .763 r
.4429 .68617 .44609 .69229 .45181 .68779 .44863 .68157 Mtetra
.735 .647 .762 r
.44863 .68157 .45181 .68779 .45754 .68329 .45436 .67698 Mtetra
.733 .644 .76 r
.45436 .67698 .45754 .68329 .46327 .67881 .46009 .67242 Mtetra
.731 .642 .759 r
.46009 .67242 .46327 .67881 .469 .67436 .46583 .66789 Mtetra
.729 .639 .758 r
.46583 .66789 .469 .67436 .47473 .66994 .47157 .66339 Mtetra
.727 .637 .757 r
.47157 .66339 .47473 .66994 .48046 .66556 .47731 .65893 Mtetra
.725 .634 .757 r
.47731 .65893 .48046 .66556 .4862 .66123 .48305 .65452 Mtetra
.723 .632 .756 r
.48305 .65452 .4862 .66123 .49194 .65694 .48879 .65016 Mtetra
.72 .629 .755 r
.48879 .65016 .49194 .65694 .49768 .65271 .49454 .64586 Mtetra
.718 .627 .755 r
.49454 .64586 .49768 .65271 .50343 .64853 .50029 .64163 Mtetra
.716 .625 .755 r
.50029 .64163 .50343 .64853 .50918 .64443 .50604 .63746 Mtetra
.713 .622 .754 r
.50604 .63746 .50918 .64443 .51493 .64039 .5118 .63336 Mtetra
.71 .62 .754 r
.5118 .63336 .51493 .64039 .52069 .63643 .51756 .62934 Mtetra
.708 .618 .754 r
.51756 .62934 .52069 .63643 .52645 .63254 .52332 .62539 Mtetra
.705 .615 .754 r
.52332 .62539 .52645 .63254 .53221 .62874 .52909 .62154 Mtetra
.702 .613 .754 r
.52909 .62154 .53221 .62874 .53798 .62502 .53487 .61777 Mtetra
.699 .611 .754 r
.53487 .61777 .53798 .62502 .54376 .6214 .54065 .6141 Mtetra
.696 .608 .754 r
.54065 .6141 .54376 .6214 .54954 .61786 .54643 .61052 Mtetra
.693 .606 .755 r
.54643 .61052 .54954 .61786 .55533 .61442 .55222 .60703 Mtetra
.69 .604 .755 r
.55222 .60703 .55533 .61442 .56113 .61109 .55802 .60365 Mtetra
.687 .601 .755 r
.55802 .60365 .56113 .61109 .56694 .60785 .56383 .60038 Mtetra
.683 .599 .756 r
.56383 .60038 .56694 .60785 .57275 .60472 .56965 .59721 Mtetra
.68 .597 .756 r
.56965 .59721 .57275 .60472 .57857 .60169 .57547 .59415 Mtetra
.676 .595 .757 r
.57547 .59415 .57857 .60169 .58441 .59878 .5813 .5912 Mtetra
.673 .592 .757 r
.5813 .5912 .58441 .59878 .59025 .59597 .58715 .58837 Mtetra
.669 .59 .758 r
.58715 .58837 .59025 .59597 .5961 .59328 .593 .58565 Mtetra
.665 .588 .758 r
.593 .58565 .5961 .59328 .60197 .5907 .59887 .58305 Mtetra
.662 .585 .759 r
.59887 .58305 .60197 .5907 .60785 .58824 .60475 .58056 Mtetra
.658 .583 .76 r
.60475 .58056 .60785 .58824 .61374 .5859 .61064 .5782 Mtetra
.654 .581 .761 r
.61064 .5782 .61374 .5859 .61964 .58367 .61655 .57596 Mtetra
.65 .579 .761 r
.61655 .57596 .61964 .58367 .62556 .58157 .62246 .57384 Mtetra
.646 .576 .762 r
.62246 .57384 .62556 .58157 .6315 .57958 .6284 .57184 Mtetra
.642 .574 .763 r
.6284 .57184 .6315 .57958 .63745 .57772 .63435 .56996 Mtetra
.638 .572 .764 r
.63435 .56996 .63745 .57772 .64341 .57598 .64032 .56821 Mtetra
.633 .57 .765 r
.64032 .56821 .64341 .57598 .6494 .57435 .6463 .56658 Mtetra
.629 .567 .766 r
.6463 .56658 .6494 .57435 .6554 .57285 .6523 .56507 Mtetra
.625 .565 .767 r
.6523 .56507 .6554 .57285 .66142 .57147 .65833 .56369 Mtetra
.62 .563 .768 r
.65833 .56369 .66142 .57147 .66746 .57021 .66437 .56243 Mtetra
.616 .561 .769 r
.66437 .56243 .66746 .57021 .67352 .56907 .67043 .56129 Mtetra
.612 .559 .771 r
.67043 .56129 .67352 .56907 .6796 .56806 .67651 .56028 Mtetra
.607 .556 .772 r
.67651 .56028 .6796 .56806 .6857 .56715 .68261 .55938 Mtetra
.603 .554 .773 r
.68261 .55938 .6857 .56715 .69183 .56637 .68874 .55861 Mtetra
.598 .552 .774 r
.68874 .55861 .69183 .56637 .69798 .5657 .69489 .55795 Mtetra
.594 .55 .775 r
.69489 .55795 .69798 .5657 .70415 .56515 .70106 .55741 Mtetra
.589 .548 .777 r
.70106 .55741 .70415 .56515 .71034 .56471 .70725 .55699 Mtetra
.584 .546 .778 r
.70725 .55699 .71034 .56471 .71656 .56438 .71347 .55668 Mtetra
.58 .545 .78 r
.71347 .55668 .71656 .56438 .72281 .56417 .71972 .55648 Mtetra
.575 .543 .781 r
.71972 .55648 .72281 .56417 .72908 .56405 .72599 .5564 Mtetra
.571 .541 .782 r
.72599 .5564 .72908 .56405 .73537 .56405 .73229 .55641 Mtetra
.566 .539 .784 r
.73229 .55641 .73537 .56405 .7417 .56414 .73862 .55654 Mtetra
.562 .538 .786 r
.73862 .55654 .7417 .56414 .74805 .56433 .74497 .55676 Mtetra
.558 .536 .787 r
.74497 .55676 .74805 .56433 .75443 .56462 .75135 .55708 Mtetra
.553 .535 .789 r
.75135 .55708 .75443 .56462 .76083 .56501 .75776 .5575 Mtetra
.549 .534 .79 r
.75776 .5575 .76083 .56501 .76727 .56548 .7642 .55801 Mtetra
.545 .533 .792 r
.7642 .55801 .76727 .56548 .77373 .56603 .77067 .55861 Mtetra
.541 .531 .794 r
.77067 .55861 .77373 .56603 .78023 .56667 .77717 .55929 Mtetra
.537 .531 .796 r
.77717 .55929 .78023 .56667 .78675 .56738 .7837 .56005 Mtetra
.533 .53 .798 r
.7837 .56005 .78675 .56738 .79331 .56817 .79025 .56088 Mtetra
.529 .529 .8 r
.79025 .56088 .79331 .56817 .79989 .56902 .79684 .56179 Mtetra
.525 .529 .802 r
.79684 .56179 .79989 .56902 .8065 .56994 .80346 .56276 Mtetra
.522 .529 .804 r
.80346 .56276 .8065 .56994 .81314 .57091 .81011 .56379 Mtetra
.518 .529 .806 r
.81011 .56379 .81314 .57091 .81982 .57193 .81679 .56487 Mtetra
.515 .529 .808 r
.81679 .56487 .81982 .57193 .82652 .573 .8235 .566 Mtetra
.512 .529 .811 r
.8235 .566 .82652 .573 .83325 .57411 .83024 .56718 Mtetra
.51 .53 .813 r
.83024 .56718 .83325 .57411 .84001 .57526 .83701 .56839 Mtetra
.507 .531 .816 r
.83701 .56839 .84001 .57526 .8468 .57643 .84381 .56964 Mtetra
.505 .532 .818 r
.84381 .56964 .8468 .57643 .85362 .57762 .85064 .5709 Mtetra
.503 .534 .821 r
.85064 .5709 .85362 .57762 .86047 .57882 .85749 .57218 Mtetra
.501 .535 .824 r
.85749 .57218 .86047 .57882 .86734 .58003 .86438 .57347 Mtetra
.5 .537 .827 r
.86438 .57347 .86734 .58003 .87425 .58123 .8713 .57476 Mtetra
.499 .54 .83 r
.8713 .57476 .87425 .58123 .88118 .58242 .87824 .57604 Mtetra
.498 .543 .833 r
.87824 .57604 .88118 .58242 .88813 .5836 .8852 .5773 Mtetra
.498 .546 .836 r
.8852 .5773 .88813 .5836 .89511 .58474 .8922 .57854 Mtetra
.498 .55 .84 r
.8922 .57854 .89511 .58474 .90211 .58585 .89921 .57975 Mtetra
.499 .554 .843 r
.89921 .57975 .90211 .58585 .90914 .58691 .90626 .58091 Mtetra
.5 .559 .847 r
.90626 .58091 .90914 .58691 .91618 .58791 .91332 .58201 Mtetra
.502 .564 .851 r
.91332 .58201 .91618 .58791 .92325 .58884 .9204 .58306 Mtetra
.504 .569 .855 r
.9204 .58306 .92325 .58884 .93033 .5897 .9275 .58402 Mtetra
.507 .576 .859 r
.9275 .58402 .93033 .5897 .93743 .59047 .93462 .58491 Mtetra
.51 .583 .864 r
.93462 .58491 .93743 .59047 .94454 .59114 .94176 .58569 Mtetra
.514 .59 .868 r
.94176 .58569 .94454 .59114 .95167 .59169 .94891 .58637 Mtetra
.519 .598 .873 r
.94891 .58637 .95167 .59169 .95881 .59213 .95607 .58693 Mtetra
.525 .607 .878 r
.95607 .58693 .95881 .59213 .96596 .59242 .96324 .58736 Mtetra
.743 .702 .812 r
.34834 .7509 .3517 .75526 .35735 .75155 .354 .74706 Mtetra
.745 .698 .807 r
.354 .74706 .35735 .75155 .36301 .74772 .35967 .7431 Mtetra
.746 .694 .802 r
.35967 .7431 .36301 .74772 .36868 .74377 .36536 .73902 Mtetra
.747 .69 .797 r
.36536 .73902 .36868 .74377 .37436 .73971 .37105 .73484 Mtetra
.747 .686 .792 r
.37105 .73484 .37436 .73971 .38004 .73555 .37674 .73056 Mtetra
.748 .683 .788 r
.37674 .73056 .38004 .73555 .38574 .73131 .38245 .7262 Mtetra
.748 .679 .785 r
.38245 .7262 .38574 .73131 .39143 .72699 .38815 .72176 Mtetra
.747 .676 .781 r
.38815 .72176 .39143 .72699 .39714 .7226 .39387 .71726 Mtetra
.747 .673 .778 r
.39387 .71726 .39714 .7226 .40285 .71816 .39959 .71271 Mtetra
.746 .67 .776 r
.39959 .71271 .40285 .71816 .40856 .71366 .40531 .70811 Mtetra
.745 .666 .773 r
.40531 .70811 .40856 .71366 .41427 .70913 .41103 .70347 Mtetra
.745 .664 .771 r
.41103 .70347 .41427 .70913 .41999 .70457 .41676 .6988 Mtetra
.743 .661 .769 r
.41676 .6988 .41999 .70457 .42571 .69998 .42249 .69412 Mtetra
.742 .658 .767 r
.42249 .69412 .42571 .69998 .43144 .69538 .42823 .68942 Mtetra
.741 .655 .765 r
.42823 .68942 .43144 .69538 .43717 .69077 .43396 .68472 Mtetra
.74 .653 .763 r
.43396 .68472 .43717 .69077 .4429 .68617 .4397 .68002 Mtetra
.738 .65 .762 r
.4397 .68002 .4429 .68617 .44863 .68157 .44543 .67534 Mtetra
.736 .647 .761 r
.44543 .67534 .44863 .68157 .45436 .67698 .45117 .67067 Mtetra
.735 .645 .76 r
.45117 .67067 .45436 .67698 .46009 .67242 .45691 .66602 Mtetra
.733 .642 .758 r
.45691 .66602 .46009 .67242 .46583 .66789 .46266 .66141 Mtetra
.731 .64 .758 r
.46266 .66141 .46583 .66789 .47157 .66339 .4684 .65684 Mtetra
.729 .638 .757 r
.4684 .65684 .47157 .66339 .47731 .65893 .47415 .65231 Mtetra
.727 .635 .756 r
.47415 .65231 .47731 .65893 .48305 .65452 .47989 .64782 Mtetra
.724 .633 .756 r
.47989 .64782 .48305 .65452 .48879 .65016 .48564 .6434 Mtetra
.722 .63 .755 r
.48564 .6434 .48879 .65016 .49454 .64586 .4914 .63903 Mtetra
.72 .628 .755 r
.4914 .63903 .49454 .64586 .50029 .64163 .49715 .63473 Mtetra
.717 .626 .754 r
.49715 .63473 .50029 .64163 .50604 .63746 .50291 .63049 Mtetra
.715 .623 .754 r
.50291 .63049 .50604 .63746 .5118 .63336 .50867 .62634 Mtetra
.712 .621 .754 r
.50867 .62634 .5118 .63336 .51756 .62934 .51443 .62226 Mtetra
.709 .619 .754 r
.51443 .62226 .51756 .62934 .52332 .62539 .5202 .61826 Mtetra
.706 .616 .754 r
.5202 .61826 .52332 .62539 .52909 .62154 .52597 .61435 Mtetra
.704 .614 .754 r
.52597 .61435 .52909 .62154 .53487 .61777 .53175 .61054 Mtetra
.701 .612 .754 r
.53175 .61054 .53487 .61777 .54065 .6141 .53753 .60682 Mtetra
.697 .61 .755 r
.53753 .60682 .54065 .6141 .54643 .61052 .54332 .60319 Mtetra
.694 .607 .755 r
.54332 .60319 .54643 .61052 .55222 .60703 .54911 .59967 Mtetra
.691 .605 .755 r
.54911 .59967 .55222 .60703 .55802 .60365 .55491 .59625 Mtetra
.688 .603 .756 r
.55491 .59625 .55802 .60365 .56383 .60038 .56072 .59293 Mtetra
.684 .6 .756 r
.56072 .59293 .56383 .60038 .56965 .59721 .56654 .58973 Mtetra
.681 .598 .756 r
.56654 .58973 .56965 .59721 .57547 .59415 .57236 .58664 Mtetra
.677 .596 .757 r
.57236 .58664 .57547 .59415 .5813 .5912 .5782 .58366 Mtetra
.674 .593 .758 r
.5782 .58366 .5813 .5912 .58715 .58837 .58404 .58079 Mtetra
.67 .591 .758 r
.58404 .58079 .58715 .58837 .593 .58565 .5899 .57805 Mtetra
.666 .589 .759 r
.5899 .57805 .593 .58565 .59887 .58305 .59577 .57542 Mtetra
.662 .587 .76 r
.59577 .57542 .59887 .58305 .60475 .58056 .60165 .57292 Mtetra
.658 .584 .76 r
.60165 .57292 .60475 .58056 .61064 .5782 .60754 .57053 Mtetra
.654 .582 .761 r
.60754 .57053 .61064 .5782 .61655 .57596 .61345 .56827 Mtetra
.65 .58 .762 r
.61345 .56827 .61655 .57596 .62246 .57384 .61937 .56613 Mtetra
.646 .577 .763 r
.61937 .56613 .62246 .57384 .6284 .57184 .6253 .56412 Mtetra
.642 .575 .764 r
.6253 .56412 .6284 .57184 .63435 .56996 .63125 .56223 Mtetra
.638 .573 .765 r
.63125 .56223 .63435 .56996 .64032 .56821 .63722 .56047 Mtetra
.633 .57 .766 r
.63722 .56047 .64032 .56821 .6463 .56658 .64321 .55883 Mtetra
.629 .568 .767 r
.64321 .55883 .6463 .56658 .6523 .56507 .64921 .55732 Mtetra
.625 .566 .768 r
.64921 .55732 .6523 .56507 .65833 .56369 .65523 .55594 Mtetra
.62 .564 .769 r
.65523 .55594 .65833 .56369 .66437 .56243 .66127 .55468 Mtetra
.616 .561 .77 r
.66127 .55468 .66437 .56243 .67043 .56129 .66733 .55354 Mtetra
.611 .559 .772 r
.66733 .55354 .67043 .56129 .67651 .56028 .67341 .55253 Mtetra
.607 .557 .773 r
.67341 .55253 .67651 .56028 .68261 .55938 .67952 .55164 Mtetra
.602 .555 .774 r
.67952 .55164 .68261 .55938 .68874 .55861 .68564 .55088 Mtetra
.597 .553 .775 r
.68564 .55088 .68874 .55861 .69489 .55795 .69179 .55023 Mtetra
.593 .551 .777 r
.69179 .55023 .69489 .55795 .70106 .55741 .69797 .5497 Mtetra
.588 .548 .778 r
.69797 .5497 .70106 .55741 .70725 .55699 .70416 .5493 Mtetra
.583 .546 .779 r
.70416 .5493 .70725 .55699 .71347 .55668 .71039 .549 Mtetra
.579 .545 .781 r
.71039 .549 .71347 .55668 .71972 .55648 .71663 .54883 Mtetra
.574 .543 .782 r
.71663 .54883 .71972 .55648 .72599 .5564 .72291 .54876 Mtetra
.569 .541 .784 r
.72291 .54876 .72599 .5564 .73229 .55641 .72921 .5488 Mtetra
.565 .539 .785 r
.72921 .5488 .73229 .55641 .73862 .55654 .73554 .54895 Mtetra
.56 .537 .787 r
.73554 .54895 .73862 .55654 .74497 .55676 .74189 .5492 Mtetra
.555 .536 .788 r
.74189 .5492 .74497 .55676 .75135 .55708 .74828 .54956 Mtetra
.551 .534 .79 r
.74828 .54956 .75135 .55708 .75776 .5575 .75469 .55001 Mtetra
.546 .533 .791 r
.75469 .55001 .75776 .5575 .7642 .55801 .76113 .55056 Mtetra
.542 .532 .793 r
.76113 .55056 .7642 .55801 .77067 .55861 .7676 .55119 Mtetra
.538 .531 .795 r
.7676 .55119 .77067 .55861 .77717 .55929 .7741 .55191 Mtetra
.534 .53 .797 r
.7741 .55191 .77717 .55929 .7837 .56005 .78064 .55272 Mtetra
.53 .529 .799 r
.78064 .55272 .7837 .56005 .79025 .56088 .7872 .5536 Mtetra
.526 .528 .8 r
.7872 .5536 .79025 .56088 .79684 .56179 .79379 .55455 Mtetra
.522 .527 .802 r
.79379 .55455 .79684 .56179 .80346 .56276 .80042 .55558 Mtetra
.518 .527 .805 r
.80042 .55558 .80346 .56276 .81011 .56379 .80707 .55666 Mtetra
.515 .527 .807 r
.80707 .55666 .81011 .56379 .81679 .56487 .81376 .55781 Mtetra
.511 .527 .809 r
.81376 .55781 .81679 .56487 .8235 .566 .82047 .559 Mtetra
.508 .527 .811 r
.82047 .559 .8235 .566 .83024 .56718 .82722 .56024 Mtetra
.505 .528 .813 r
.82722 .56024 .83024 .56718 .83701 .56839 .834 .56152 Mtetra
.503 .528 .816 r
.834 .56152 .83701 .56839 .84381 .56964 .84081 .56283 Mtetra
.5 .53 .818 r
.84081 .56283 .84381 .56964 .85064 .5709 .84764 .56417 Mtetra
.498 .531 .821 r
.84764 .56417 .85064 .5709 .85749 .57218 .85451 .56553 Mtetra
.496 .532 .824 r
.85451 .56553 .85749 .57218 .86438 .57347 .86141 .56689 Mtetra
.495 .534 .827 r
.86141 .56689 .86438 .57347 .8713 .57476 .86834 .56826 Mtetra
.494 .537 .83 r
.86834 .56826 .8713 .57476 .87824 .57604 .87529 .56963 Mtetra
.493 .539 .833 r
.87529 .56963 .87824 .57604 .8852 .5773 .88227 .57098 Mtetra
.493 .543 .836 r
.88227 .57098 .8852 .5773 .8922 .57854 .88928 .57231 Mtetra
.493 .546 .839 r
.88928 .57231 .8922 .57854 .89921 .57975 .89631 .57361 Mtetra
.493 .55 .843 r
.89631 .57361 .89921 .57975 .90626 .58091 .90336 .57487 Mtetra
.494 .554 .847 r
.90336 .57487 .90626 .58091 .91332 .58201 .91044 .57608 Mtetra
.496 .559 .85 r
.91044 .57608 .91332 .58201 .9204 .58306 .91754 .57722 Mtetra
.498 .565 .854 r
.91754 .57722 .9204 .58306 .9275 .58402 .92467 .5783 Mtetra
.5 .571 .858 r
.92467 .5783 .9275 .58402 .93462 .58491 .9318 .57929 Mtetra
.504 .577 .863 r
.9318 .57929 .93462 .58491 .94176 .58569 .93896 .58019 Mtetra
.507 .585 .867 r
.93896 .58019 .94176 .58569 .94891 .58637 .94613 .58099 Mtetra
.512 .592 .872 r
.94613 .58099 .94891 .58637 .95607 .58693 .95332 .58167 Mtetra
.517 .601 .876 r
.95332 .58167 .95607 .58693 .96324 .58736 .96051 .58222 Mtetra
.746 .701 .809 r
.34497 .74649 .34834 .7509 .354 .74706 .35065 .74252 Mtetra
.748 .697 .804 r
.35065 .74252 .354 .74706 .35967 .7431 .35633 .73843 Mtetra
.749 .693 .799 r
.35633 .73843 .35967 .7431 .36536 .73902 .36202 .73423 Mtetra
.749 .69 .794 r
.36202 .73423 .36536 .73902 .37105 .73484 .36773 .72993 Mtetra
.75 .686 .79 r
.36773 .72993 .37105 .73484 .37674 .73056 .37343 .72553 Mtetra
.75 .683 .786 r
.37343 .72553 .37674 .73056 .38245 .7262 .37915 .72105 Mtetra
.75 .679 .783 r
.37915 .72105 .38245 .7262 .38815 .72176 .38487 .7165 Mtetra
.749 .676 .78 r
.38487 .7165 .38815 .72176 .39387 .71726 .39059 .71189 Mtetra
.749 .673 .777 r
.39059 .71189 .39387 .71726 .39959 .71271 .39632 .70723 Mtetra
.748 .67 .774 r
.39632 .70723 .39959 .71271 .40531 .70811 .40205 .70253 Mtetra
.748 .667 .772 r
.40205 .70253 .40531 .70811 .41103 .70347 .40779 .69779 Mtetra
.747 .664 .769 r
.40779 .69779 .41103 .70347 .41676 .6988 .41352 .69302 Mtetra
.745 .661 .767 r
.41352 .69302 .41676 .6988 .42249 .69412 .41926 .68824 Mtetra
.744 .659 .766 r
.41926 .68824 .42249 .69412 .42823 .68942 .425 .68345 Mtetra
.743 .656 .764 r
.425 .68345 .42823 .68942 .43396 .68472 .43075 .67866 Mtetra
.741 .653 .762 r
.43075 .67866 .43396 .68472 .4397 .68002 .43649 .67388 Mtetra
.74 .651 .761 r
.43649 .67388 .4397 .68002 .44543 .67534 .44224 .6691 Mtetra
.738 .648 .76 r
.44224 .6691 .44543 .67534 .45117 .67067 .44798 .66435 Mtetra
.737 .646 .759 r
.44798 .66435 .45117 .67067 .45691 .66602 .45373 .65963 Mtetra
.735 .644 .758 r
.45373 .65963 .45691 .66602 .46266 .66141 .45948 .65494 Mtetra
.733 .641 .757 r
.45948 .65494 .46266 .66141 .4684 .65684 .46523 .65029 Mtetra
.731 .639 .756 r
.46523 .65029 .4684 .65684 .47415 .65231 .47098 .64569 Mtetra
.728 .636 .756 r
.47098 .64569 .47415 .65231 .47989 .64782 .47673 .64113 Mtetra
.726 .634 .755 r
.47673 .64113 .47989 .64782 .48564 .6434 .48249 .63664 Mtetra
.724 .632 .755 r
.48249 .63664 .48564 .6434 .4914 .63903 .48824 .63221 Mtetra
.721 .629 .755 r
.48824 .63221 .4914 .63903 .49715 .63473 .494 .62784 Mtetra
.719 .627 .754 r
.494 .62784 .49715 .63473 .50291 .63049 .49976 .62355 Mtetra
.716 .625 .754 r
.49976 .62355 .50291 .63049 .50867 .62634 .50553 .61934 Mtetra
.714 .622 .754 r
.50553 .61934 .50867 .62634 .51443 .62226 .51129 .6152 Mtetra
.711 .62 .754 r
.51129 .6152 .51443 .62226 .5202 .61826 .51707 .61115 Mtetra
.708 .618 .754 r
.51707 .61115 .5202 .61826 .52597 .61435 .52284 .6072 Mtetra
.705 .616 .754 r
.52284 .6072 .52597 .61435 .53175 .61054 .52862 .60333 Mtetra
.702 .613 .755 r
.52862 .60333 .53175 .61054 .53753 .60682 .53441 .59956 Mtetra
.699 .611 .755 r
.53441 .59956 .53753 .60682 .54332 .60319 .5402 .59589 Mtetra
.696 .609 .755 r
.5402 .59589 .54332 .60319 .54911 .59967 .54599 .59233 Mtetra
.692 .606 .756 r
.54599 .59233 .54911 .59967 .55491 .59625 .5518 .58887 Mtetra
.689 .604 .756 r
.5518 .58887 .55491 .59625 .56072 .59293 .55761 .58552 Mtetra
.686 .602 .757 r
.55761 .58552 .56072 .59293 .56654 .58973 .56343 .58228 Mtetra
.682 .6 .757 r
.56343 .58228 .56654 .58973 .57236 .58664 .56925 .57915 Mtetra
.678 .597 .758 r
.56925 .57915 .57236 .58664 .5782 .58366 .57509 .57615 Mtetra
.675 .595 .758 r
.57509 .57615 .5782 .58366 .58404 .58079 .58094 .57325 Mtetra
.671 .593 .759 r
.58094 .57325 .58404 .58079 .5899 .57805 .58679 .57048 Mtetra
.667 .59 .76 r
.58679 .57048 .5899 .57805 .59577 .57542 .59266 .56783 Mtetra
.663 .588 .761 r
.59266 .56783 .59577 .57542 .60165 .57292 .59854 .5653 Mtetra
.659 .586 .761 r
.59854 .5653 .60165 .57292 .60754 .57053 .60444 .5629 Mtetra
.655 .583 .762 r
.60444 .5629 .60754 .57053 .61345 .56827 .61034 .56062 Mtetra
.651 .581 .763 r
.61034 .56062 .61345 .56827 .61937 .56613 .61626 .55847 Mtetra
.647 .578 .764 r
.61626 .55847 .61937 .56613 .6253 .56412 .6222 .55644 Mtetra
.642 .576 .765 r
.6222 .55644 .6253 .56412 .63125 .56223 .62815 .55454 Mtetra
.638 .574 .766 r
.62815 .55454 .63125 .56223 .63722 .56047 .63412 .55277 Mtetra
.634 .571 .767 r
.63412 .55277 .63722 .56047 .64321 .55883 .64011 .55113 Mtetra
.629 .569 .768 r
.64011 .55113 .64321 .55883 .64921 .55732 .64611 .54961 Mtetra
.625 .567 .769 r
.64611 .54961 .64921 .55732 .65523 .55594 .65213 .54822 Mtetra
.62 .564 .77 r
.65213 .54822 .65523 .55594 .66127 .55468 .65817 .54696 Mtetra
.615 .562 .772 r
.65817 .54696 .66127 .55468 .66733 .55354 .66424 .54583 Mtetra
.611 .56 .773 r
.66424 .54583 .66733 .55354 .67341 .55253 .67032 .54482 Mtetra
.606 .558 .774 r
.67032 .54482 .67341 .55253 .67952 .55164 .67642 .54394 Mtetra
.601 .555 .775 r
.67642 .54394 .67952 .55164 .68564 .55088 .68255 .54318 Mtetra
.597 .553 .776 r
.68255 .54318 .68564 .55088 .69179 .55023 .6887 .54254 Mtetra
.592 .551 .778 r
.6887 .54254 .69179 .55023 .69797 .5497 .69487 .54203 Mtetra
.587 .549 .779 r
.69487 .54203 .69797 .5497 .70416 .5493 .70107 .54163 Mtetra
.582 .547 .78 r
.70107 .54163 .70416 .5493 .71039 .549 .7073 .54136 Mtetra
.577 .545 .782 r
.7073 .54136 .71039 .549 .71663 .54883 .71354 .5412 Mtetra
.572 .543 .783 r
.71354 .5412 .71663 .54883 .72291 .54876 .71982 .54115 Mtetra
.568 .541 .785 r
.71982 .54115 .72291 .54876 .72921 .5488 .72612 .54122 Mtetra
.563 .539 .786 r
.72612 .54122 .72921 .5488 .73554 .54895 .73245 .54139 Mtetra
.558 .537 .788 r
.73245 .54139 .73554 .54895 .74189 .5492 .73881 .54167 Mtetra
.553 .536 .789 r
.73881 .54167 .74189 .5492 .74828 .54956 .7452 .54206 Mtetra
.549 .534 .791 r
.7452 .54206 .74828 .54956 .75469 .55001 .75161 .54254 Mtetra
.544 .532 .793 r
.75161 .54254 .75469 .55001 .76113 .55056 .75806 .54312 Mtetra
.54 .531 .794 r
.75806 .54312 .76113 .55056 .7676 .55119 .76453 .5438 Mtetra
.535 .53 .796 r
.76453 .5438 .7676 .55119 .7741 .55191 .77104 .54456 Mtetra
.531 .529 .798 r
.77104 .54456 .7741 .55191 .78064 .55272 .77757 .54541 Mtetra
.526 .528 .8 r
.77757 .54541 .78064 .55272 .7872 .5536 .78414 .54633 Mtetra
.522 .527 .801 r
.78414 .54633 .7872 .5536 .79379 .55455 .79074 .54734 Mtetra
.518 .526 .803 r
.79074 .54734 .79379 .55455 .80042 .55558 .79737 .54841 Mtetra
.514 .526 .805 r
.79737 .54841 .80042 .55558 .80707 .55666 .80403 .54955 Mtetra
.511 .525 .807 r
.80403 .54955 .80707 .55666 .81376 .55781 .81072 .55075 Mtetra
.507 .525 .81 r
.81072 .55075 .81376 .55781 .82047 .559 .81744 .552 Mtetra
.504 .525 .812 r
.81744 .552 .82047 .559 .82722 .56024 .8242 .5533 Mtetra
.501 .526 .814 r
.8242 .5533 .82722 .56024 .834 .56152 .83098 .55465 Mtetra
.498 .526 .816 r
.83098 .55465 .834 .56152 .84081 .56283 .8378 .55602 Mtetra
.496 .527 .819 r
.8378 .55602 .84081 .56283 .84764 .56417 .84465 .55743 Mtetra
.493 .528 .822 r
.84465 .55743 .84764 .56417 .85451 .56553 .85152 .55886 Mtetra
.491 .53 .824 r
.85152 .55886 .85451 .56553 .86141 .56689 .85843 .5603 Mtetra
.49 .532 .827 r
.85843 .5603 .86141 .56689 .86834 .56826 .86537 .56175 Mtetra
.488 .534 .83 r
.86537 .56175 .86834 .56826 .87529 .56963 .87233 .5632 Mtetra
.487 .536 .833 r
.87233 .5632 .87529 .56963 .88227 .57098 .87933 .56464 Mtetra
.487 .539 .836 r
.87933 .56464 .88227 .57098 .88928 .57231 .88635 .56606 Mtetra
.487 .542 .839 r
.88635 .56606 .88928 .57231 .89631 .57361 .89339 .56745 Mtetra
.487 .546 .843 r
.89339 .56745 .89631 .57361 .90336 .57487 .90046 .5688 Mtetra
.488 .55 .846 r
.90046 .5688 .90336 .57487 .91044 .57608 .90756 .5701 Mtetra
.489 .555 .85 r
.90756 .5701 .91044 .57608 .91754 .57722 .91468 .57135 Mtetra
.491 .56 .854 r
.91468 .57135 .91754 .57722 .92467 .5783 .92182 .57253 Mtetra
.494 .566 .858 r
.92182 .57253 .92467 .5783 .9318 .57929 .92897 .57363 Mtetra
.497 .572 .862 r
.92897 .57363 .9318 .57929 .93896 .58019 .93615 .57464 Mtetra
.501 .579 .866 r
.93615 .57464 .93896 .58019 .94613 .58099 .94334 .57555 Mtetra
.505 .587 .871 r
.94334 .57555 .94613 .58099 .95332 .58167 .95055 .57635 Mtetra
.51 .595 .875 r
.95055 .57635 .95332 .58167 .96051 .58222 .95776 .57702 Mtetra
.749 .701 .806 r
.34159 .74203 .34497 .74649 .35065 .74252 .34728 .73794 Mtetra
.75 .697 .801 r
.34728 .73794 .35065 .74252 .35633 .73843 .35298 .73373 Mtetra
.751 .693 .796 r
.35298 .73373 .35633 .73843 .36202 .73423 .35868 .7294 Mtetra
.752 .689 .792 r
.35868 .7294 .36202 .73423 .36773 .72993 .3644 .72498 Mtetra
.752 .686 .788 r
.3644 .72498 .36773 .72993 .37343 .72553 .37012 .72047 Mtetra
.752 .683 .784 r
.37012 .72047 .37343 .72553 .37915 .72105 .37584 .71588 Mtetra
.752 .679 .781 r
.37584 .71588 .37915 .72105 .38487 .7165 .38157 .71122 Mtetra
.752 .676 .778 r
.38157 .71122 .38487 .7165 .39059 .71189 .38731 .70651 Mtetra
.751 .673 .775 r
.38731 .70651 .39059 .71189 .39632 .70723 .39305 .70174 Mtetra
.75 .67 .773 r
.39305 .70174 .39632 .70723 .40205 .70253 .39879 .69693 Mtetra
.75 .668 .77 r
.39879 .69693 .40205 .70253 .40779 .69779 .40453 .6921 Mtetra
.749 .665 .768 r
.40453 .6921 .40779 .69779 .41352 .69302 .41028 .68724 Mtetra
.748 .662 .766 r
.41028 .68724 .41352 .69302 .41926 .68824 .41603 .68236 Mtetra
.746 .66 .765 r
.41603 .68236 .41926 .68824 .425 .68345 .42178 .67748 Mtetra
.745 .657 .763 r
.42178 .67748 .425 .68345 .43075 .67866 .42753 .6726 Mtetra
.743 .654 .762 r
.42753 .6726 .43075 .67866 .43649 .67388 .43328 .66773 Mtetra
.742 .652 .76 r
.43328 .66773 .43649 .67388 .44224 .6691 .43903 .66288 Mtetra
.74 .65 .759 r
.43903 .66288 .44224 .6691 .44798 .66435 .44478 .65805 Mtetra
.738 .647 .758 r
.44478 .65805 .44798 .66435 .45373 .65963 .45054 .65325 Mtetra
.737 .645 .758 r
.45054 .65325 .45373 .65963 .45948 .65494 .45629 .64848 Mtetra
.735 .642 .757 r
.45629 .64848 .45948 .65494 .46523 .65029 .46205 .64376 Mtetra
.732 .64 .756 r
.46205 .64376 .46523 .65029 .47098 .64569 .46781 .63908 Mtetra
.73 .638 .756 r
.46781 .63908 .47098 .64569 .47673 .64113 .47356 .63446 Mtetra
.728 .635 .755 r
.47356 .63446 .47673 .64113 .48249 .63664 .47932 .6299 Mtetra
.726 .633 .755 r
.47932 .6299 .48249 .63664 .48824 .63221 .48509 .62541 Mtetra
.723 .631 .755 r
.48509 .62541 .48824 .63221 .494 .62784 .49085 .62098 Mtetra
.721 .629 .754 r
.49085 .62098 .494 .62784 .49976 .62355 .49661 .61663 Mtetra
.718 .626 .754 r
.49661 .61663 .49976 .62355 .50553 .61934 .50238 .61236 Mtetra
.715 .624 .754 r
.50238 .61236 .50553 .61934 .51129 .6152 .50815 .60818 Mtetra
.712 .622 .754 r
.50815 .60818 .51129 .6152 .51707 .61115 .51393 .60408 Mtetra
.71 .619 .755 r
.51393 .60408 .51707 .61115 .52284 .6072 .51971 .60007 Mtetra
.707 .617 .755 r
.51971 .60007 .52284 .6072 .52862 .60333 .52549 .59616 Mtetra
.703 .615 .755 r
.52549 .59616 .52862 .60333 .53441 .59956 .53128 .59234 Mtetra
.7 .613 .755 r
.53128 .59234 .53441 .59956 .5402 .59589 .53707 .58863 Mtetra
.697 .61 .756 r
.53707 .58863 .5402 .59589 .54599 .59233 .54287 .58503 Mtetra
.694 .608 .756 r
.54287 .58503 .54599 .59233 .5518 .58887 .54868 .58153 Mtetra
.69 .606 .757 r
.54868 .58153 .5518 .58887 .55761 .58552 .55449 .57814 Mtetra
.687 .603 .757 r
.55449 .57814 .55761 .58552 .56343 .58228 .56031 .57487 Mtetra
.683 .601 .758 r
.56031 .57487 .56343 .58228 .56925 .57915 .56614 .57171 Mtetra
.679 .599 .758 r
.56614 .57171 .56925 .57915 .57509 .57615 .57198 .56867 Mtetra
.676 .596 .759 r
.57198 .56867 .57509 .57615 .58094 .57325 .57782 .56575 Mtetra
.672 .594 .76 r
.57782 .56575 .58094 .57325 .58679 .57048 .58368 .56296 Mtetra
.668 .592 .761 r
.58368 .56296 .58679 .57048 .59266 .56783 .58955 .56028 Mtetra
.664 .589 .761 r
.58955 .56028 .59266 .56783 .59854 .5653 .59544 .55773 Mtetra
.66 .587 .762 r
.59544 .55773 .59854 .5653 .60444 .5629 .60133 .55531 Mtetra
.656 .585 .763 r
.60133 .55531 .60444 .5629 .61034 .56062 .60724 .55301 Mtetra
.651 .582 .764 r
.60724 .55301 .61034 .56062 .61626 .55847 .61316 .55085 Mtetra
.647 .58 .765 r
.61316 .55085 .61626 .55847 .6222 .55644 .6191 .54881 Mtetra
.643 .577 .766 r
.6191 .54881 .6222 .55644 .62815 .55454 .62505 .5469 Mtetra
.638 .575 .767 r
.62505 .5469 .62815 .55454 .63412 .55277 .63102 .54511 Mtetra
.634 .573 .768 r
.63102 .54511 .63412 .55277 .64011 .55113 .637 .54346 Mtetra
.629 .57 .769 r
.637 .54346 .64011 .55113 .64611 .54961 .64301 .54194 Mtetra
.625 .568 .77 r
.64301 .54194 .64611 .54961 .65213 .54822 .64903 .54055 Mtetra
.62 .566 .772 r
.64903 .54055 .65213 .54822 .65817 .54696 .65507 .53929 Mtetra
.615 .563 .773 r
.65507 .53929 .65817 .54696 .66424 .54583 .66114 .53815 Mtetra
.61 .561 .774 r
.66114 .53815 .66424 .54583 .67032 .54482 .66722 .53715 Mtetra
.606 .558 .775 r
.66722 .53715 .67032 .54482 .67642 .54394 .67333 .53627 Mtetra
.601 .556 .777 r
.67333 .53627 .67642 .54394 .68255 .54318 .67945 .53552 Mtetra
.596 .554 .778 r
.67945 .53552 .68255 .54318 .6887 .54254 .6856 .53489 Mtetra
.591 .552 .779 r
.6856 .53489 .6887 .54254 .69487 .54203 .69178 .53439 Mtetra
.586 .549 .78 r
.69178 .53439 .69487 .54203 .70107 .54163 .69798 .53401 Mtetra
.581 .547 .782 r
.69798 .53401 .70107 .54163 .7073 .54136 .7042 .53375 Mtetra
.576 .545 .783 r
.7042 .53375 .7073 .54136 .71354 .5412 .71045 .53361 Mtetra
.571 .543 .785 r
.71045 .53361 .71354 .5412 .71982 .54115 .71673 .53358 Mtetra
.566 .541 .786 r
.71673 .53358 .71982 .54115 .72612 .54122 .72303 .53367 Mtetra
.561 .539 .788 r
.72303 .53367 .72612 .54122 .73245 .54139 .72937 .53387 Mtetra
.556 .537 .789 r
.72937 .53387 .73245 .54139 .73881 .54167 .73573 .53418 Mtetra
.551 .535 .791 r
.73573 .53418 .73881 .54167 .7452 .54206 .74212 .53459 Mtetra
.546 .534 .792 r
.74212 .53459 .7452 .54206 .75161 .54254 .74853 .53511 Mtetra
.542 .532 .794 r
.74853 .53511 .75161 .54254 .75806 .54312 .75498 .53572 Mtetra
.537 .531 .796 r
.75498 .53572 .75806 .54312 .76453 .5438 .76146 .53643 Mtetra
.532 .529 .797 r
.76146 .53643 .76453 .5438 .77104 .54456 .76797 .53723 Mtetra
.528 .528 .799 r
.76797 .53723 .77104 .54456 .77757 .54541 .77451 .53812 Mtetra
.523 .527 .801 r
.77451 .53812 .77757 .54541 .78414 .54633 .78108 .53909 Mtetra
.519 .526 .803 r
.78108 .53909 .78414 .54633 .79074 .54734 .78768 .54014 Mtetra
.515 .525 .805 r
.78768 .54014 .79074 .54734 .79737 .54841 .79432 .54126 Mtetra
.511 .524 .806 r
.79432 .54126 .79737 .54841 .80403 .54955 .80098 .54245 Mtetra
.507 .524 .809 r
.80098 .54245 .80403 .54955 .81072 .55075 .80768 .5437 Mtetra
.503 .524 .811 r
.80768 .5437 .81072 .55075 .81744 .552 .81441 .54501 Mtetra
.5 .524 .813 r
.81441 .54501 .81744 .552 .8242 .5533 .82117 .54637 Mtetra
.497 .524 .815 r
.82117 .54637 .8242 .5533 .83098 .55465 .82796 .54778 Mtetra
.494 .524 .817 r
.82796 .54778 .83098 .55465 .8378 .55602 .83479 .54922 Mtetra
.491 .525 .82 r
.83479 .54922 .8378 .55602 .84465 .55743 .84164 .55069 Mtetra
.489 .526 .822 r
.84164 .55069 .84465 .55743 .85152 .55886 .84853 .55219 Mtetra
.486 .527 .825 r
.84853 .55219 .85152 .55886 .85843 .5603 .85545 .55371 Mtetra
.485 .529 .827 r
.85545 .55371 .85843 .5603 .86537 .56175 .8624 .55524 Mtetra
.483 .531 .83 r
.8624 .55524 .86537 .56175 .87233 .5632 .86937 .55676 Mtetra
.482 .533 .833 r
.86937 .55676 .87233 .5632 .87933 .56464 .87638 .55828 Mtetra
.481 .536 .836 r
.87638 .55828 .87933 .56464 .88635 .56606 .88341 .55978 Mtetra
.481 .539 .839 r
.88341 .55978 .88635 .56606 .89339 .56745 .89047 .56126 Mtetra
.481 .543 .843 r
.89047 .56126 .89339 .56745 .90046 .5688 .89756 .5627 Mtetra
.482 .547 .846 r
.89756 .5627 .90046 .5688 .90756 .5701 .90467 .5641 Mtetra
.483 .551 .85 r
.90467 .5641 .90756 .5701 .91468 .57135 .9118 .56545 Mtetra
.485 .556 .853 r
.9118 .56545 .91468 .57135 .92182 .57253 .91895 .56673 Mtetra
.487 .562 .857 r
.91895 .56673 .92182 .57253 .92897 .57363 .92613 .56793 Mtetra
.49 .568 .861 r
.92613 .56793 .92897 .57363 .93615 .57464 .93333 .56905 Mtetra
.494 .575 .865 r
.93333 .56905 .93615 .57464 .94334 .57555 .94054 .57007 Mtetra
.498 .582 .87 r
.94054 .57007 .94334 .57555 .95055 .57635 .94776 .57098 Mtetra
.503 .59 .874 r
.94776 .57098 .95055 .57635 .95776 .57702 .955 .57177 Mtetra
.752 .7 .803 r
.33821 .73753 .34159 .74203 .34728 .73794 .34391 .73332 Mtetra
.753 .697 .798 r
.34391 .73332 .34728 .73794 .35298 .73373 .34962 .72898 Mtetra
.754 .693 .794 r
.34962 .72898 .35298 .73373 .35868 .7294 .35534 .72454 Mtetra
.754 .69 .789 r
.35534 .72454 .35868 .7294 .3644 .72498 .36106 .72001 Mtetra
.754 .686 .786 r
.36106 .72001 .3644 .72498 .37012 .72047 .36679 .71539 Mtetra
.754 .683 .782 r
.36679 .71539 .37012 .72047 .37584 .71588 .37253 .71069 Mtetra
.754 .68 .779 r
.37253 .71069 .37584 .71588 .38157 .71122 .37827 .70592 Mtetra
.754 .677 .776 r
.37827 .70592 .38157 .71122 .38731 .70651 .38402 .7011 Mtetra
.753 .674 .774 r
.38402 .7011 .38731 .70651 .39305 .70174 .38976 .69624 Mtetra
.753 .671 .771 r
.38976 .69624 .39305 .70174 .39879 .69693 .39552 .69133 Mtetra
.752 .668 .769 r
.39552 .69133 .39879 .69693 .40453 .6921 .40127 .6864 Mtetra
.751 .666 .767 r
.40127 .6864 .40453 .6921 .41028 .68724 .40702 .68145 Mtetra
.75 .663 .765 r
.40702 .68145 .41028 .68724 .41603 .68236 .41278 .67648 Mtetra
.748 .661 .764 r
.41278 .67648 .41603 .68236 .42178 .67748 .41854 .67151 Mtetra
.747 .658 .762 r
.41854 .67151 .42178 .67748 .42753 .6726 .4243 .66655 Mtetra
.745 .656 .761 r
.4243 .66655 .42753 .6726 .43328 .66773 .43006 .6616 Mtetra
.744 .653 .76 r
.43006 .6616 .43328 .66773 .43903 .66288 .43582 .65666 Mtetra
.742 .651 .759 r
.43582 .65666 .43903 .66288 .44478 .65805 .44158 .65175 Mtetra
.74 .649 .758 r
.44158 .65175 .44478 .65805 .45054 .65325 .44734 .64688 Mtetra
.738 .646 .757 r
.44734 .64688 .45054 .65325 .45629 .64848 .4531 .64204 Mtetra
.736 .644 .757 r
.4531 .64204 .45629 .64848 .46205 .64376 .45886 .63725 Mtetra
.734 .642 .756 r
.45886 .63725 .46205 .64376 .46781 .63908 .46463 .6325 Mtetra
.732 .639 .756 r
.46463 .6325 .46781 .63908 .47356 .63446 .47039 .62782 Mtetra
.73 .637 .755 r
.47039 .62782 .47356 .63446 .47932 .6299 .47616 .6232 Mtetra
.727 .635 .755 r
.47616 .6232 .47932 .6299 .48509 .62541 .48192 .61864 Mtetra
.725 .632 .755 r
.48192 .61864 .48509 .62541 .49085 .62098 .48769 .61416 Mtetra
.722 .63 .755 r
.48769 .61416 .49085 .62098 .49661 .61663 .49346 .60975 Mtetra
.72 .628 .755 r
.49346 .60975 .49661 .61663 .50238 .61236 .49923 .60542 Mtetra
.717 .626 .755 r
.49923 .60542 .50238 .61236 .50815 .60818 .50501 .60118 Mtetra
.714 .623 .755 r
.50501 .60118 .50815 .60818 .51393 .60408 .51079 .59704 Mtetra
.711 .621 .755 r
.51079 .59704 .51393 .60408 .51971 .60007 .51657 .59298 Mtetra
.708 .619 .755 r
.51657 .59298 .51971 .60007 .52549 .59616 .52235 .58902 Mtetra
.705 .617 .756 r
.52235 .58902 .52549 .59616 .53128 .59234 .52814 .58517 Mtetra
.702 .614 .756 r
.52814 .58517 .53128 .59234 .53707 .58863 .53394 .58141 Mtetra
.699 .612 .756 r
.53394 .58141 .53707 .58863 .54287 .58503 .53974 .57777 Mtetra
.695 .61 .757 r
.53974 .57777 .54287 .58503 .54868 .58153 .54555 .57423 Mtetra
.692 .608 .757 r
.54555 .57423 .54868 .58153 .55449 .57814 .55137 .57081 Mtetra
.688 .605 .758 r
.55137 .57081 .55449 .57814 .56031 .57487 .55719 .56751 Mtetra
.684 .603 .759 r
.55719 .56751 .56031 .57487 .56614 .57171 .56302 .56432 Mtetra
.681 .601 .759 r
.56302 .56432 .56614 .57171 .57198 .56867 .56886 .56125 Mtetra
.677 .598 .76 r
.56886 .56125 .57198 .56867 .57782 .56575 .57471 .5583 Mtetra
.673 .596 .761 r
.57471 .5583 .57782 .56575 .58368 .56296 .58057 .55548 Mtetra
.669 .593 .762 r
.58057 .55548 .58368 .56296 .58955 .56028 .58644 .55278 Mtetra
.665 .591 .763 r
.58644 .55278 .58955 .56028 .59544 .55773 .59233 .55021 Mtetra
.661 .589 .763 r
.59233 .55021 .59544 .55773 .60133 .55531 .59822 .54777 Mtetra
.656 .586 .764 r
.59822 .54777 .60133 .55531 .60724 .55301 .60413 .54546 Mtetra
.652 .584 .765 r
.60413 .54546 .60724 .55301 .61316 .55085 .61005 .54327 Mtetra
.648 .581 .766 r
.61005 .54327 .61316 .55085 .6191 .54881 .61599 .54122 Mtetra
.643 .579 .767 r
.61599 .54122 .6191 .54881 .62505 .5469 .62194 .5393 Mtetra
.639 .577 .769 r
.62194 .5393 .62505 .5469 .63102 .54511 .62791 .53751 Mtetra
.634 .574 .77 r
.62791 .53751 .63102 .54511 .637 .54346 .6339 .53585 Mtetra
.629 .572 .771 r
.6339 .53585 .637 .54346 .64301 .54194 .63991 .53432 Mtetra
.625 .569 .772 r
.63991 .53432 .64301 .54194 .64903 .54055 .64593 .53293 Mtetra
.62 .567 .773 r
.64593 .53293 .64903 .54055 .65507 .53929 .65197 .53167 Mtetra
.615 .564 .774 r
.65197 .53167 .65507 .53929 .66114 .53815 .65804 .53053 Mtetra
.61 .562 .776 r
.65804 .53053 .66114 .53815 .66722 .53715 .66412 .52953 Mtetra
.605 .56 .777 r
.66412 .52953 .66722 .53715 .67333 .53627 .67023 .52866 Mtetra
.6 .557 .778 r
.67023 .52866 .67333 .53627 .67945 .53552 .67635 .52791 Mtetra
.595 .555 .779 r
.67635 .52791 .67945 .53552 .6856 .53489 .68251 .52729 Mtetra
.59 .552 .781 r
.68251 .52729 .6856 .53489 .69178 .53439 .68868 .5268 Mtetra
.585 .55 .782 r
.68868 .5268 .69178 .53439 .69798 .53401 .69488 .52643 Mtetra
.58 .548 .783 r
.69488 .52643 .69798 .53401 .7042 .53375 .70111 .52619 Mtetra
.575 .546 .785 r
.70111 .52619 .7042 .53375 .71045 .53361 .70736 .52606 Mtetra
.569 .543 .786 r
.70736 .52606 .71045 .53361 .71673 .53358 .71364 .52606 Mtetra
.564 .541 .788 r
.71364 .52606 .71673 .53358 .72303 .53367 .71994 .52616 Mtetra
.559 .539 .789 r
.71994 .52616 .72303 .53367 .72937 .53387 .72628 .52639 Mtetra
.554 .537 .791 r
.72628 .52639 .72937 .53387 .73573 .53418 .73264 .52672 Mtetra
.549 .535 .792 r
.73264 .52672 .73573 .53418 .74212 .53459 .73903 .52716 Mtetra
.544 .534 .794 r
.73903 .52716 .74212 .53459 .74853 .53511 .74545 .52771 Mtetra
.539 .532 .795 r
.74545 .52771 .74853 .53511 .75498 .53572 .7519 .52835 Mtetra
.534 .53 .797 r
.7519 .52835 .75498 .53572 .76146 .53643 .75839 .5291 Mtetra
.529 .529 .799 r
.75839 .5291 .76146 .53643 .76797 .53723 .7649 .52993 Mtetra
.525 .527 .8 r
.7649 .52993 .76797 .53723 .77451 .53812 .77144 .53086 Mtetra
.52 .526 .802 r
.77144 .53086 .77451 .53812 .78108 .53909 .77802 .53187 Mtetra
.516 .525 .804 r
.77802 .53187 .78108 .53909 .78768 .54014 .78462 .53296 Mtetra
.511 .524 .806 r
.78462 .53296 .78768 .54014 .79432 .54126 .79126 .53413 Mtetra
.507 .523 .808 r
.79126 .53413 .79432 .54126 .80098 .54245 .79793 .53537 Mtetra
.503 .523 .81 r
.79793 .53537 .80098 .54245 .80768 .5437 .80464 .53667 Mtetra
.499 .522 .812 r
.80464 .53667 .80768 .5437 .81441 .54501 .81137 .53804 Mtetra
.496 .522 .814 r
.81137 .53804 .81441 .54501 .82117 .54637 .81814 .53946 Mtetra
.492 .522 .816 r
.81814 .53946 .82117 .54637 .82796 .54778 .82494 .54092 Mtetra
.489 .523 .818 r
.82494 .54092 .82796 .54778 .83479 .54922 .83177 .54242 Mtetra
.486 .523 .821 r
.83177 .54242 .83479 .54922 .84164 .55069 .83864 .54396 Mtetra
.484 .524 .823 r
.83864 .54396 .84164 .55069 .84853 .55219 .84553 .54553 Mtetra
.481 .525 .826 r
.84553 .54553 .84853 .55219 .85545 .55371 .85246 .54712 Mtetra
.479 .527 .828 r
.85246 .54712 .85545 .55371 .8624 .55524 .85942 .54872 Mtetra
.478 .528 .831 r
.85942 .54872 .8624 .55524 .86937 .55676 .8664 .55032 Mtetra
.477 .531 .834 r
.8664 .55032 .86937 .55676 .87638 .55828 .87342 .55192 Mtetra
.476 .533 .837 r
.87342 .55192 .87638 .55828 .88341 .55978 .88047 .5535 Mtetra
.475 .536 .84 r
.88047 .5535 .88341 .55978 .89047 .56126 .88754 .55506 Mtetra
.475 .539 .843 r
.88754 .55506 .89047 .56126 .89756 .5627 .89464 .55659 Mtetra
.476 .543 .846 r
.89464 .55659 .89756 .5627 .90467 .5641 .90176 .55808 Mtetra
.477 .547 .85 r
.90176 .55808 .90467 .5641 .9118 .56545 .90891 .55952 Mtetra
.478 .552 .853 r
.90891 .55952 .9118 .56545 .91895 .56673 .91609 .5609 Mtetra
.481 .558 .857 r
.91609 .5609 .91895 .56673 .92613 .56793 .92328 .5622 Mtetra
.483 .564 .861 r
.92328 .5622 .92613 .56793 .93333 .56905 .93049 .56343 Mtetra
.487 .57 .865 r
.93049 .56343 .93333 .56905 .94054 .57007 .93772 .56455 Mtetra
.491 .577 .869 r
.93772 .56455 .94054 .57007 .94776 .57098 .94497 .56557 Mtetra
.496 .585 .874 r
.94497 .56557 .94776 .57098 .955 .57177 .95223 .56647 Mtetra
.754 .7 .8 r
.33481 .733 .33821 .73753 .34391 .73332 .34052 .72867 Mtetra
.755 .697 .796 r
.34052 .72867 .34391 .73332 .34962 .72898 .34625 .72422 Mtetra
.756 .693 .791 r
.34625 .72422 .34962 .72898 .35534 .72454 .35198 .71966 Mtetra
.757 .69 .788 r
.35198 .71966 .35534 .72454 .36106 .72001 .35772 .71502 Mtetra
.757 .687 .784 r
.35772 .71502 .36106 .72001 .36679 .71539 .36346 .71029 Mtetra
.757 .684 .781 r
.36346 .71029 .36679 .71539 .37253 .71069 .36921 .70548 Mtetra
.756 .681 .778 r
.36921 .70548 .37253 .71069 .37827 .70592 .37496 .70062 Mtetra
.756 .678 .775 r
.37496 .70062 .37827 .70592 .38402 .7011 .38072 .6957 Mtetra
.755 .675 .773 r
.38072 .6957 .38402 .7011 .38976 .69624 .38647 .69073 Mtetra
.755 .672 .77 r
.38647 .69073 .38976 .69624 .39552 .69133 .39224 .68573 Mtetra
.754 .67 .768 r
.39224 .68573 .39552 .69133 .40127 .6864 .398 .68071 Mtetra
.753 .667 .766 r
.398 .68071 .40127 .6864 .40702 .68145 .40376 .67566 Mtetra
.752 .664 .765 r
.40376 .67566 .40702 .68145 .41278 .67648 .40953 .67061 Mtetra
.75 .662 .763 r
.40953 .67061 .41278 .67648 .41854 .67151 .4153 .66556 Mtetra
.749 .659 .762 r
.4153 .66556 .41854 .67151 .4243 .66655 .42106 .66051 Mtetra
.747 .657 .761 r
.42106 .66051 .4243 .66655 .43006 .6616 .42683 .65548 Mtetra
.746 .655 .76 r
.42683 .65548 .43006 .6616 .43582 .65666 .4326 .65047 Mtetra
.744 .652 .759 r
.4326 .65047 .43582 .65666 .44158 .65175 .43837 .64548 Mtetra
.742 .65 .758 r
.43837 .64548 .44158 .65175 .44734 .64688 .44413 .64053 Mtetra
.74 .648 .757 r
.44413 .64053 .44734 .64688 .4531 .64204 .4499 .63562 Mtetra
.738 .646 .757 r
.4499 .63562 .4531 .64204 .45886 .63725 .45567 .63076 Mtetra
.736 .643 .756 r
.45567 .63076 .45886 .63725 .46463 .6325 .46144 .62595 Mtetra
.734 .641 .756 r
.46144 .62595 .46463 .6325 .47039 .62782 .46721 .62121 Mtetra
.732 .639 .755 r
.46721 .62121 .47039 .62782 .47616 .6232 .47298 .61652 Mtetra
.729 .637 .755 r
.47298 .61652 .47616 .6232 .48192 .61864 .47875 .61191 Mtetra
.727 .634 .755 r
.47875 .61191 .48192 .61864 .48769 .61416 .48452 .60736 Mtetra
.724 .632 .755 r
.48452 .60736 .48769 .61416 .49346 .60975 .4903 .6029 Mtetra
.721 .63 .755 r
.4903 .6029 .49346 .60975 .49923 .60542 .49608 .59853 Mtetra
.719 .628 .755 r
.49608 .59853 .49923 .60542 .50501 .60118 .50186 .59424 Mtetra
.716 .625 .755 r
.50186 .59424 .50501 .60118 .51079 .59704 .50764 .59004 Mtetra
.713 .623 .756 r
.50764 .59004 .51079 .59704 .51657 .59298 .51342 .58594 Mtetra
.71 .621 .756 r
.51342 .58594 .51657 .59298 .52235 .58902 .51921 .58193 Mtetra
.707 .619 .756 r
.51921 .58193 .52235 .58902 .52814 .58517 .52501 .57804 Mtetra
.703 .616 .757 r
.52501 .57804 .52814 .58517 .53394 .58141 .53081 .57424 Mtetra
.7 .614 .757 r
.53081 .57424 .53394 .58141 .53974 .57777 .53661 .57056 Mtetra
.697 .612 .758 r
.53661 .57056 .53974 .57777 .54555 .57423 .54242 .56699 Mtetra
.693 .609 .758 r
.54242 .56699 .54555 .57423 .55137 .57081 .54824 .56353 Mtetra
.689 .607 .759 r
.54824 .56353 .55137 .57081 .55719 .56751 .55407 .5602 Mtetra
.686 .605 .76 r
.55407 .5602 .55719 .56751 .56302 .56432 .5599 .55698 Mtetra
.682 .602 .76 r
.5599 .55698 .56302 .56432 .56886 .56125 .56574 .55388 Mtetra
.678 .6 .761 r
.56574 .55388 .56886 .56125 .57471 .5583 .57159 .55091 Mtetra
.674 .598 .762 r
.57159 .55091 .57471 .5583 .58057 .55548 .57745 .54806 Mtetra
.67 .595 .763 r
.57745 .54806 .58057 .55548 .58644 .55278 .58333 .54534 Mtetra
.666 .593 .764 r
.58333 .54534 .58644 .55278 .59233 .55021 .58921 .54275 Mtetra
.662 .59 .765 r
.58921 .54275 .59233 .55021 .59822 .54777 .59511 .54029 Mtetra
.657 .588 .766 r
.59511 .54029 .59822 .54777 .60413 .54546 .60102 .53796 Mtetra
.653 .586 .767 r
.60102 .53796 .60413 .54546 .61005 .54327 .60694 .53576 Mtetra
.648 .583 .768 r
.60694 .53576 .61005 .54327 .61599 .54122 .61288 .53369 Mtetra
.644 .581 .769 r
.61288 .53369 .61599 .54122 .62194 .5393 .61884 .53176 Mtetra
.639 .578 .77 r
.61884 .53176 .62194 .5393 .62791 .53751 .62481 .52996 Mtetra
.634 .576 .771 r
.62481 .52996 .62791 .53751 .6339 .53585 .63079 .5283 Mtetra
.63 .573 .772 r
.63079 .5283 .6339 .53585 .63991 .53432 .6368 .52676 Mtetra
.625 .571 .774 r
.6368 .52676 .63991 .53432 .64593 .53293 .64283 .52537 Mtetra
.62 .568 .775 r
.64283 .52537 .64593 .53293 .65197 .53167 .64887 .5241 Mtetra
.615 .566 .776 r
.64887 .5241 .65197 .53167 .65804 .53053 .65493 .52297 Mtetra
.61 .563 .777 r
.65493 .52297 .65804 .53053 .66412 .52953 .66102 .52197 Mtetra
.605 .561 .779 r
.66102 .52197 .66412 .52953 .67023 .52866 .66713 .5211 Mtetra
.599 .558 .78 r
.66713 .5211 .67023 .52866 .67635 .52791 .67325 .52036 Mtetra
.594 .556 .781 r
.67325 .52036 .67635 .52791 .68251 .52729 .67941 .51975 Mtetra
.589 .553 .782 r
.67941 .51975 .68251 .52729 .68868 .5268 .68558 .51927 Mtetra
.584 .551 .784 r
.68558 .51927 .68868 .5268 .69488 .52643 .69179 .51891 Mtetra
.578 .549 .785 r
.69179 .51891 .69488 .52643 .70111 .52619 .69801 .51868 Mtetra
.573 .546 .787 r
.69801 .51868 .70111 .52619 .70736 .52606 .70427 .51857 Mtetra
.568 .544 .788 r
.70427 .51857 .70736 .52606 .71364 .52606 .71055 .51858 Mtetra
.563 .542 .79 r
.71055 .51858 .71364 .52606 .71994 .52616 .71685 .51871 Mtetra
.557 .54 .791 r
.71685 .51871 .71994 .52616 .72628 .52639 .72319 .51895 Mtetra
.552 .538 .792 r
.72319 .51895 .72628 .52639 .73264 .52672 .72955 .51931 Mtetra
.547 .536 .794 r
.72955 .51931 .73264 .52672 .73903 .52716 .73595 .51978 Mtetra
.542 .534 .796 r
.73595 .51978 .73903 .52716 .74545 .52771 .74237 .52035 Mtetra
.537 .532 .797 r
.74237 .52035 .74545 .52771 .7519 .52835 .74882 .52103 Mtetra
.531 .53 .799 r
.74882 .52103 .7519 .52835 .75839 .5291 .75531 .5218 Mtetra
.527 .528 .8 r
.75531 .5218 .75839 .5291 .7649 .52993 .76182 .52268 Mtetra
.522 .527 .802 r
.76182 .52268 .7649 .52993 .77144 .53086 .76837 .52364 Mtetra
.517 .526 .804 r
.76837 .52364 .77144 .53086 .77802 .53187 .77495 .52469 Mtetra
.512 .524 .806 r
.77495 .52469 .77802 .53187 .78462 .53296 .78156 .52582 Mtetra
.508 .523 .807 r
.78156 .52582 .78462 .53296 .79126 .53413 .78821 .52704 Mtetra
.503 .522 .809 r
.78821 .52704 .79126 .53413 .79793 .53537 .79488 .52832 Mtetra
.499 .522 .811 r
.79488 .52832 .79793 .53537 .80464 .53667 .80159 .52968 Mtetra
.495 .521 .813 r
.80159 .52968 .80464 .53667 .81137 .53804 .80833 .53109 Mtetra
.491 .521 .815 r
.80833 .53109 .81137 .53804 .81814 .53946 .81511 .53256 Mtetra
.488 .521 .817 r
.81511 .53256 .81814 .53946 .82494 .54092 .82191 .53408 Mtetra
.484 .521 .819 r
.82191 .53408 .82494 .54092 .83177 .54242 .82875 .53565 Mtetra
.481 .521 .822 r
.82875 .53565 .83177 .54242 .83864 .54396 .83563 .53725 Mtetra
.479 .522 .824 r
.83563 .53725 .83864 .54396 .84553 .54553 .84253 .53888 Mtetra
.476 .523 .826 r
.84253 .53888 .84553 .54553 .85246 .54712 .84947 .54053 Mtetra
.474 .524 .829 r
.84947 .54053 .85246 .54712 .85942 .54872 .85643 .5422 Mtetra
.472 .526 .832 r
.85643 .5422 .85942 .54872 .8664 .55032 .86343 .54388 Mtetra
.471 .528 .834 r
.86343 .54388 .8664 .55032 .87342 .55192 .87046 .54555 Mtetra
.47 .53 .837 r
.87046 .54555 .87342 .55192 .88047 .5535 .87752 .54722 Mtetra
.469 .533 .84 r
.87752 .54722 .88047 .5535 .88754 .55506 .8846 .54886 Mtetra
.469 .536 .843 r
.8846 .54886 .88754 .55506 .89464 .55659 .89172 .55047 Mtetra
.47 .54 .847 r
.89172 .55047 .89464 .55659 .90176 .55808 .89885 .55205 Mtetra
.471 .544 .85 r
.89885 .55205 .90176 .55808 .90891 .55952 .90602 .55358 Mtetra
.472 .549 .853 r
.90602 .55358 .90891 .55952 .91609 .5609 .91321 .55505 Mtetra
.474 .554 .857 r
.91321 .55505 .91609 .5609 .92328 .5622 .92042 .55645 Mtetra
.477 .559 .861 r
.92042 .55645 .92328 .5622 .93049 .56343 .92765 .55777 Mtetra
.48 .566 .865 r
.92765 .55777 .93049 .56343 .93772 .56455 .9349 .559 Mtetra
.484 .573 .869 r
.9349 .559 .93772 .56455 .94497 .56557 .94217 .56013 Mtetra
.489 .58 .873 r
.94217 .56013 .94497 .56557 .95223 .56647 .94945 .56113 Mtetra
.757 .7 .798 r
.33141 .72844 .33481 .733 .34052 .72867 .33713 .72399 Mtetra
.758 .697 .794 r
.33713 .72399 .34052 .72867 .34625 .72422 .34287 .71943 Mtetra
.758 .694 .79 r
.34287 .71943 .34625 .72422 .35198 .71966 .34861 .71477 Mtetra
.759 .69 .786 r
.34861 .71477 .35198 .71966 .35772 .71502 .35436 .71001 Mtetra
.759 .687 .782 r
.35436 .71001 .35772 .71502 .36346 .71029 .36012 .70518 Mtetra
.759 .684 .779 r
.36012 .70518 .36346 .71029 .36921 .70548 .36588 .70027 Mtetra
.759 .681 .777 r
.36588 .70027 .36921 .70548 .37496 .70062 .37164 .69531 Mtetra
.758 .679 .774 r
.37164 .69531 .37496 .70062 .38072 .6957 .37741 .69029 Mtetra
.758 .676 .772 r
.37741 .69029 .38072 .6957 .38647 .69073 .38318 .68523 Mtetra
.757 .673 .769 r
.38318 .68523 .38647 .69073 .39224 .68573 .38895 .68014 Mtetra
.756 .671 .768 r
.38895 .68014 .39224 .68573 .398 .68071 .39472 .67502 Mtetra
.755 .668 .766 r
.39472 .67502 .398 .68071 .40376 .67566 .40049 .66989 Mtetra
.754 .666 .764 r
.40049 .66989 .40376 .67566 .40953 .67061 .40627 .66476 Mtetra
.752 .663 .763 r
.40627 .66476 .40953 .67061 .4153 .66556 .41204 .65962 Mtetra
.751 .661 .762 r
.41204 .65962 .4153 .66556 .42106 .66051 .41782 .65449 Mtetra
.75 .659 .76 r
.41782 .65449 .42106 .66051 .42683 .65548 .42359 .64938 Mtetra
.748 .656 .759 r
.42359 .64938 .42683 .65548 .4326 .65047 .42937 .64429 Mtetra
.746 .654 .759 r
.42937 .64429 .4326 .65047 .43837 .64548 .43515 .63924 Mtetra
.744 .652 .758 r
.43515 .63924 .43837 .64548 .44413 .64053 .44092 .63422 Mtetra
.742 .65 .757 r
.44092 .63422 .44413 .64053 .4499 .63562 .4467 .62924 Mtetra
.74 .647 .757 r
.4467 .62924 .4499 .63562 .45567 .63076 .45247 .62431 Mtetra
.738 .645 .756 r
.45247 .62431 .45567 .63076 .46144 .62595 .45825 .61944 Mtetra
.736 .643 .756 r
.45825 .61944 .46144 .62595 .46721 .62121 .46402 .61463 Mtetra
.734 .641 .756 r
.46402 .61463 .46721 .62121 .47298 .61652 .4698 .60988 Mtetra
.731 .638 .756 r
.4698 .60988 .47298 .61652 .47875 .61191 .47558 .60521 Mtetra
.729 .636 .755 r
.47558 .60521 .47875 .61191 .48452 .60736 .48135 .60062 Mtetra
.726 .634 .755 r
.48135 .60062 .48452 .60736 .4903 .6029 .48713 .5961 Mtetra
.723 .632 .756 r
.48713 .5961 .4903 .6029 .49608 .59853 .49291 .59167 Mtetra
.721 .63 .756 r
.49291 .59167 .49608 .59853 .50186 .59424 .4987 .58733 Mtetra
.718 .627 .756 r
.4987 .58733 .50186 .59424 .50764 .59004 .50448 .58309 Mtetra
.715 .625 .756 r
.50448 .58309 .50764 .59004 .51342 .58594 .51027 .57894 Mtetra
.711 .623 .757 r
.51027 .57894 .51342 .58594 .51921 .58193 .51607 .5749 Mtetra
.708 .621 .757 r
.51607 .5749 .51921 .58193 .52501 .57804 .52187 .57096 Mtetra
.705 .618 .758 r
.52187 .57096 .52501 .57804 .53081 .57424 .52767 .56713 Mtetra
.702 .616 .758 r
.52767 .56713 .53081 .57424 .53661 .57056 .53348 .56341 Mtetra
.698 .614 .759 r
.53348 .56341 .53661 .57056 .54242 .56699 .53929 .5598 Mtetra
.695 .612 .759 r
.53929 .5598 .54242 .56699 .54824 .56353 .54511 .55631 Mtetra
.691 .609 .76 r
.54511 .55631 .54824 .56353 .55407 .5602 .55094 .55294 Mtetra
.687 .607 .761 r
.55094 .55294 .55407 .5602 .5599 .55698 .55677 .5497 Mtetra
.683 .605 .762 r
.55677 .5497 .5599 .55698 .56574 .55388 .56262 .54657 Mtetra
.679 .602 .762 r
.56262 .54657 .56574 .55388 .57159 .55091 .56847 .54357 Mtetra
.675 .6 .763 r
.56847 .54357 .57159 .55091 .57745 .54806 .57433 .5407 Mtetra
.671 .597 .764 r
.57433 .5407 .57745 .54806 .58333 .54534 .58021 .53796 Mtetra
.667 .595 .765 r
.58021 .53796 .58333 .54534 .58921 .54275 .5861 .53535 Mtetra
.662 .592 .766 r
.5861 .53535 .58921 .54275 .59511 .54029 .59199 .53287 Mtetra
.658 .59 .767 r
.59199 .53287 .59511 .54029 .60102 .53796 .59791 .53052 Mtetra
.654 .587 .768 r
.59791 .53052 .60102 .53796 .60694 .53576 .60383 .52831 Mtetra
.649 .585 .769 r
.60383 .52831 .60694 .53576 .61288 .53369 .60977 .52623 Mtetra
.644 .582 .771 r
.60977 .52623 .61288 .53369 .61884 .53176 .61573 .52429 Mtetra
.639 .58 .772 r
.61573 .52429 .61884 .53176 .62481 .52996 .6217 .52248 Mtetra
.635 .577 .773 r
.6217 .52248 .62481 .52996 .63079 .5283 .62769 .5208 Mtetra
.63 .575 .774 r
.62769 .5208 .63079 .5283 .6368 .52676 .63369 .51927 Mtetra
.625 .572 .775 r
.63369 .51927 .6368 .52676 .64283 .52537 .63972 .51786 Mtetra
.62 .57 .777 r
.63972 .51786 .64283 .52537 .64887 .5241 .64576 .5166 Mtetra
.615 .567 .778 r
.64576 .5166 .64887 .5241 .65493 .52297 .65183 .51546 Mtetra
.609 .565 .779 r
.65183 .51546 .65493 .52297 .66102 .52197 .65791 .51446 Mtetra
.604 .562 .78 r
.65791 .51446 .66102 .52197 .66713 .5211 .66402 .5136 Mtetra
.599 .56 .782 r
.66402 .5136 .66713 .5211 .67325 .52036 .67015 .51286 Mtetra
.593 .557 .783 r
.67015 .51286 .67325 .52036 .67941 .51975 .67631 .51226 Mtetra
.588 .555 .784 r
.67631 .51226 .67941 .51975 .68558 .51927 .68249 .51179 Mtetra
.583 .552 .786 r
.68249 .51179 .68558 .51927 .69179 .51891 .68869 .51144 Mtetra
.577 .55 .787 r
.68869 .51144 .69179 .51891 .69801 .51868 .69492 .51122 Mtetra
.572 .547 .789 r
.69492 .51122 .69801 .51868 .70427 .51857 .70117 .51113 Mtetra
.566 .545 .79 r
.70117 .51113 .70427 .51857 .71055 .51858 .70745 .51116 Mtetra
.561 .543 .791 r
.70745 .51116 .71055 .51858 .71685 .51871 .71376 .51131 Mtetra
.555 .54 .793 r
.71376 .51131 .71685 .51871 .72319 .51895 .7201 .51157 Mtetra
.55 .538 .794 r
.7201 .51157 .72319 .51895 .72955 .51931 .72647 .51195 Mtetra
.545 .536 .796 r
.72647 .51195 .72955 .51931 .73595 .51978 .73286 .51244 Mtetra
.539 .534 .797 r
.73286 .51244 .73595 .51978 .74237 .52035 .73929 .51304 Mtetra
.534 .532 .799 r
.73929 .51304 .74237 .52035 .74882 .52103 .74574 .51375 Mtetra
.529 .53 .801 r
.74574 .51375 .74882 .52103 .75531 .5218 .75223 .51456 Mtetra
.524 .528 .802 r
.75223 .51456 .75531 .5218 .76182 .52268 .75875 .51546 Mtetra
.519 .527 .804 r
.75875 .51546 .76182 .52268 .76837 .52364 .7653 .51646 Mtetra
.514 .525 .806 r
.7653 .51646 .76837 .52364 .77495 .52469 .77188 .51755 Mtetra
.509 .524 .807 r
.77188 .51755 .77495 .52469 .78156 .52582 .7785 .51873 Mtetra
.504 .523 .809 r
.7785 .51873 .78156 .52582 .78821 .52704 .78515 .51998 Mtetra
.5 .522 .811 r
.78515 .51998 .78821 .52704 .79488 .52832 .79183 .52131 Mtetra
.495 .521 .813 r
.79183 .52131 .79488 .52832 .80159 .52968 .79854 .52271 Mtetra
.491 .52 .815 r
.79854 .52271 .80159 .52968 .80833 .53109 .80529 .52417 Mtetra
.487 .52 .817 r
.80529 .52417 .80833 .53109 .81511 .53256 .81207 .5257 Mtetra
.483 .519 .819 r
.81207 .5257 .81511 .53256 .82191 .53408 .81888 .52727 Mtetra
.48 .519 .821 r
.81888 .52727 .82191 .53408 .82875 .53565 .82573 .5289 Mtetra
.477 .52 .823 r
.82573 .5289 .82875 .53565 .83563 .53725 .83261 .53056 Mtetra
.474 .52 .825 r
.83261 .53056 .83563 .53725 .84253 .53888 .83952 .53225 Mtetra
.471 .521 .828 r
.83952 .53225 .84253 .53888 .84947 .54053 .84647 .53397 Mtetra
.469 .522 .83 r
.84647 .53397 .84947 .54053 .85643 .5422 .85345 .5357 Mtetra
.467 .524 .833 r
.85345 .5357 .85643 .5422 .86343 .54388 .86045 .53745 Mtetra
.465 .526 .835 r
.86045 .53745 .86343 .54388 .87046 .54555 .86749 .5392 Mtetra
.464 .528 .838 r
.86749 .5392 .87046 .54555 .87752 .54722 .87456 .54093 Mtetra
.463 .53 .841 r
.87456 .54093 .87752 .54722 .8846 .54886 .88166 .54266 Mtetra
.463 .533 .844 r
.88166 .54266 .8846 .54886 .89172 .55047 .88879 .54435 Mtetra
.463 .537 .847 r
.88879 .54435 .89172 .55047 .89885 .55205 .89594 .54601 Mtetra
.464 .541 .85 r
.89594 .54601 .89885 .55205 .90602 .55358 .90312 .54763 Mtetra
.466 .545 .854 r
.90312 .54763 .90602 .55358 .91321 .55505 .91032 .54919 Mtetra
.468 .55 .857 r
.91032 .54919 .91321 .55505 .92042 .55645 .91755 .55068 Mtetra
.47 .556 .861 r
.91755 .55068 .92042 .55645 .92765 .55777 .9248 .5521 Mtetra
.473 .562 .865 r
.9248 .5521 .92765 .55777 .9349 .559 .93206 .55343 Mtetra
.477 .568 .869 r
.93206 .55343 .9349 .559 .94217 .56013 .93935 .55465 Mtetra
.482 .576 .873 r
.93935 .55465 .94217 .56013 .94945 .56113 .94665 .55577 Mtetra
.759 .701 .796 r
.32799 .72386 .33141 .72844 .33713 .72399 .33373 .7193 Mtetra
.76 .697 .792 r
.33373 .7193 .33713 .72399 .34287 .71943 .33948 .71463 Mtetra
.761 .694 .788 r
.33948 .71463 .34287 .71943 .34861 .71477 .34524 .70986 Mtetra
.761 .691 .784 r
.34524 .70986 .34861 .71477 .35436 .71001 .351 .705 Mtetra
.761 .688 .781 r
.351 .705 .35436 .71001 .36012 .70518 .35676 .70007 Mtetra
.761 .685 .778 r
.35676 .70007 .36012 .70518 .36588 .70027 .36254 .69506 Mtetra
.761 .682 .776 r
.36254 .69506 .36588 .70027 .37164 .69531 .36831 .69 Mtetra
.76 .68 .773 r
.36831 .69 .37164 .69531 .37741 .69029 .37409 .68489 Mtetra
.76 .677 .771 r
.37409 .68489 .37741 .69029 .38318 .68523 .37987 .67974 Mtetra
.759 .675 .769 r
.37987 .67974 .38318 .68523 .38895 .68014 .38565 .67456 Mtetra
.758 .672 .767 r
.38565 .67456 .38895 .68014 .39472 .67502 .39143 .66935 Mtetra
.757 .67 .765 r
.39143 .66935 .39472 .67502 .40049 .66989 .39722 .66414 Mtetra
.756 .667 .764 r
.39722 .66414 .40049 .66989 .40627 .66476 .403 .65892 Mtetra
.755 .665 .762 r
.403 .65892 .40627 .66476 .41204 .65962 .40878 .6537 Mtetra
.753 .663 .761 r
.40878 .6537 .41204 .65962 .41782 .65449 .41457 .6485 Mtetra
.752 .66 .76 r
.41457 .6485 .41782 .65449 .42359 .64938 .42035 .64331 Mtetra
.75 .658 .759 r
.42035 .64331 .42359 .64938 .42937 .64429 .42613 .63815 Mtetra
.748 .656 .759 r
.42613 .63815 .42937 .64429 .43515 .63924 .43192 .63302 Mtetra
.746 .654 .758 r
.43192 .63302 .43515 .63924 .44092 .63422 .4377 .62794 Mtetra
.744 .651 .757 r
.4377 .62794 .44092 .63422 .4467 .62924 .44348 .62289 Mtetra
.742 .649 .757 r
.44348 .62289 .4467 .62924 .45247 .62431 .44926 .6179 Mtetra
.74 .647 .756 r
.44926 .6179 .45247 .62431 .45825 .61944 .45505 .61297 Mtetra
.738 .645 .756 r
.45505 .61297 .45825 .61944 .46402 .61463 .46083 .6081 Mtetra
.736 .643 .756 r
.46083 .6081 .46402 .61463 .4698 .60988 .46661 .6033 Mtetra
.733 .641 .756 r
.46661 .6033 .4698 .60988 .47558 .60521 .47239 .59857 Mtetra
.731 .638 .756 r
.47239 .59857 .47558 .60521 .48135 .60062 .47818 .59392 Mtetra
.728 .636 .756 r
.47818 .59392 .48135 .60062 .48713 .5961 .48396 .58935 Mtetra
.725 .634 .756 r
.48396 .58935 .48713 .5961 .49291 .59167 .48975 .58487 Mtetra
.722 .632 .756 r
.48975 .58487 .49291 .59167 .4987 .58733 .49554 .58049 Mtetra
.719 .63 .757 r
.49554 .58049 .4987 .58733 .50448 .58309 .50133 .5762 Mtetra
.716 .627 .757 r
.50133 .5762 .50448 .58309 .51027 .57894 .50712 .57201 Mtetra
.713 .625 .758 r
.50712 .57201 .51027 .57894 .51607 .5749 .51292 .56792 Mtetra
.71 .623 .758 r
.51292 .56792 .51607 .5749 .52187 .57096 .51872 .56394 Mtetra
.707 .621 .759 r
.51872 .56394 .52187 .57096 .52767 .56713 .52452 .56007 Mtetra
.703 .618 .759 r
.52452 .56007 .52767 .56713 .53348 .56341 .53033 .55632 Mtetra
.7 .616 .76 r
.53033 .55632 .53348 .56341 .53929 .5598 .53615 .55268 Mtetra
.696 .614 .761 r
.53615 .55268 .53929 .5598 .54511 .55631 .54197 .54915 Mtetra
.692 .612 .761 r
.54197 .54915 .54511 .55631 .55094 .55294 .54781 .54575 Mtetra
.688 .609 .762 r
.54781 .54575 .55094 .55294 .55677 .5497 .55364 .54248 Mtetra
.685 .607 .763 r
.55364 .54248 .55677 .5497 .56262 .54657 .55949 .53933 Mtetra
.681 .604 .764 r
.55949 .53933 .56262 .54657 .56847 .54357 .56535 .5363 Mtetra
.676 .602 .765 r
.56535 .5363 .56847 .54357 .57433 .5407 .57121 .53341 Mtetra
.672 .6 .766 r
.57121 .53341 .57433 .5407 .58021 .53796 .57709 .53065 Mtetra
.668 .597 .767 r
.57709 .53065 .58021 .53796 .5861 .53535 .58298 .52802 Mtetra
.663 .595 .768 r
.58298 .52802 .5861 .53535 .59199 .53287 .58888 .52552 Mtetra
.659 .592 .769 r
.58888 .52552 .59199 .53287 .59791 .53052 .59479 .52316 Mtetra
.654 .59 .77 r
.59479 .52316 .59791 .53052 .60383 .52831 .60072 .52093 Mtetra
.65 .587 .771 r
.60072 .52093 .60383 .52831 .60977 .52623 .60666 .51884 Mtetra
.645 .585 .772 r
.60666 .51884 .60977 .52623 .61573 .52429 .61261 .51688 Mtetra
.64 .582 .774 r
.61261 .51688 .61573 .52429 .6217 .52248 .61859 .51506 Mtetra
.635 .579 .775 r
.61859 .51506 .6217 .52248 .62769 .5208 .62458 .51338 Mtetra
.63 .577 .776 r
.62458 .51338 .62769 .5208 .63369 .51927 .63058 .51184 Mtetra
.625 .574 .777 r
.63058 .51184 .63369 .51927 .63972 .51786 .63661 .51043 Mtetra
.62 .572 .779 r
.63661 .51043 .63972 .51786 .64576 .5166 .64266 .50916 Mtetra
.614 .569 .78 r
.64266 .50916 .64576 .5166 .65183 .51546 .64872 .50803 Mtetra
.609 .566 .781 r
.64872 .50803 .65183 .51546 .65791 .51446 .65481 .50703 Mtetra
.604 .564 .782 r
.65481 .50703 .65791 .51446 .66402 .5136 .66092 .50617 Mtetra
.598 .561 .784 r
.66092 .50617 .66402 .5136 .67015 .51286 .66705 .50544 Mtetra
.593 .559 .785 r
.66705 .50544 .67015 .51286 .67631 .51226 .67321 .50484 Mtetra
.587 .556 .787 r
.67321 .50484 .67631 .51226 .68249 .51179 .67938 .50438 Mtetra
.582 .553 .788 r
.67938 .50438 .68249 .51179 .68869 .51144 .68559 .50404 Mtetra
.576 .551 .789 r
.68559 .50404 .68869 .51144 .69492 .51122 .69182 .50383 Mtetra
.57 .548 .791 r
.69182 .50383 .69492 .51122 .70117 .51113 .69807 .50375 Mtetra
.565 .546 .792 r
.69807 .50375 .70117 .51113 .70745 .51116 .70436 .5038 Mtetra
.559 .543 .794 r
.70436 .5038 .70745 .51116 .71376 .51131 .71067 .50396 Mtetra
.554 .541 .795 r
.71067 .50396 .71376 .51131 .7201 .51157 .71701 .50425 Mtetra
.548 .539 .797 r
.71701 .50425 .7201 .51157 .72647 .51195 .72338 .50465 Mtetra
.542 .537 .798 r
.72338 .50465 .72647 .51195 .73286 .51244 .72977 .50517 Mtetra
.537 .534 .8 r
.72977 .50517 .73286 .51244 .73929 .51304 .7362 .50579 Mtetra
.531 .532 .801 r
.7362 .50579 .73929 .51304 .74574 .51375 .74266 .50653 Mtetra
.526 .53 .803 r
.74266 .50653 .74574 .51375 .75223 .51456 .74915 .50736 Mtetra
.521 .528 .804 r
.74915 .50736 .75223 .51456 .75875 .51546 .75567 .5083 Mtetra
.515 .527 .806 r
.75567 .5083 .75875 .51546 .7653 .51646 .76223 .50933 Mtetra
.51 .525 .808 r
.76223 .50933 .7653 .51646 .77188 .51755 .76881 .51046 Mtetra
.505 .524 .809 r
.76881 .51046 .77188 .51755 .7785 .51873 .77543 .51167 Mtetra
.5 .522 .811 r
.77543 .51167 .7785 .51873 .78515 .51998 .78209 .51297 Mtetra
.496 .521 .813 r
.78209 .51297 .78515 .51998 .79183 .52131 .78877 .51434 Mtetra
.491 .52 .815 r
.78877 .51434 .79183 .52131 .79854 .52271 .79549 .51578 Mtetra
.487 .519 .816 r
.79549 .51578 .79854 .52271 .80529 .52417 .80225 .5173 Mtetra
.483 .519 .818 r
.80225 .5173 .80529 .52417 .81207 .5257 .80903 .51887 Mtetra
.479 .518 .82 r
.80903 .51887 .81207 .5257 .81888 .52727 .81585 .5205 Mtetra
.475 .518 .822 r
.81585 .5205 .81888 .52727 .82573 .5289 .82271 .52217 Mtetra
.472 .518 .824 r
.82271 .52217 .82573 .5289 .83261 .53056 .82959 .52389 Mtetra
.468 .519 .827 r
.82959 .52389 .83261 .53056 .83952 .53225 .83651 .52564 Mtetra
.466 .519 .829 r
.83651 .52564 .83952 .53225 .84647 .53397 .84347 .52742 Mtetra
.463 .52 .831 r
.84347 .52742 .84647 .53397 .85345 .5357 .85045 .52922 Mtetra
.461 .522 .834 r
.85045 .52922 .85345 .5357 .86045 .53745 .85747 .53104 Mtetra
.459 .523 .836 r
.85747 .53104 .86045 .53745 .86749 .5392 .86452 .53285 Mtetra
.458 .525 .839 r
.86452 .53285 .86749 .5392 .87456 .54093 .8716 .53466 Mtetra
.457 .528 .842 r
.8716 .53466 .87456 .54093 .88166 .54266 .87871 .53646 Mtetra
.457 .531 .845 r
.87871 .53646 .88166 .54266 .88879 .54435 .88585 .53824 Mtetra
.457 .534 .848 r
.88585 .53824 .88879 .54435 .89594 .54601 .89302 .53998 Mtetra
.458 .538 .851 r
.89302 .53998 .89594 .54601 .90312 .54763 .90021 .54168 Mtetra
.459 .542 .854 r
.90021 .54168 .90312 .54763 .91032 .54919 .90743 .54332 Mtetra
.461 .547 .858 r
.90743 .54332 .91032 .54919 .91755 .55068 .91467 .54491 Mtetra
.463 .552 .861 r
.91467 .54491 .91755 .55068 .9248 .5521 .92193 .54641 Mtetra
.466 .558 .865 r
.92193 .54641 .9248 .5521 .93206 .55343 .92922 .54784 Mtetra
.47 .564 .869 r
.92922 .54784 .93206 .55343 .93935 .55465 .93653 .54916 Mtetra
.475 .572 .873 r
.93653 .54916 .93935 .55465 .94665 .55577 .94385 .55037 Mtetra
.762 .701 .794 r
.32457 .71927 .32799 .72386 .33373 .7193 .33032 .7146 Mtetra
.763 .698 .79 r
.33032 .7146 .33373 .7193 .33948 .71463 .33608 .70983 Mtetra
.763 .695 .787 r
.33608 .70983 .33948 .71463 .34524 .70986 .34185 .70495 Mtetra
.763 .692 .783 r
.34185 .70495 .34524 .70986 .351 .705 .34762 .7 Mtetra
.764 .689 .78 r
.34762 .7 .351 .705 .35676 .70007 .3534 .69496 Mtetra
.763 .686 .777 r
.3534 .69496 .35676 .70007 .36254 .69506 .35919 .68986 Mtetra
.763 .684 .775 r
.35919 .68986 .36254 .69506 .36831 .69 .36497 .6847 Mtetra
.763 .681 .772 r
.36497 .6847 .36831 .69 .37409 .68489 .37076 .6795 Mtetra
.762 .679 .77 r
.37076 .6795 .37409 .68489 .37987 .67974 .37655 .67426 Mtetra
.761 .676 .768 r
.37655 .67426 .37987 .67974 .38565 .67456 .38234 .66899 Mtetra
.76 .674 .766 r
.38234 .66899 .38565 .67456 .39143 .66935 .38813 .66371 Mtetra
.759 .671 .765 r
.38813 .66371 .39143 .66935 .39722 .66414 .39393 .65841 Mtetra
.758 .669 .764 r
.39393 .65841 .39722 .66414 .403 .65892 .39972 .65311 Mtetra
.757 .667 .762 r
.39972 .65311 .403 .65892 .40878 .6537 .40551 .64782 Mtetra
.755 .664 .761 r
.40551 .64782 .40878 .6537 .41457 .6485 .41131 .64254 Mtetra
.754 .662 .76 r
.41131 .64254 .41457 .6485 .42035 .64331 .4171 .63728 Mtetra
.752 .66 .759 r
.4171 .63728 .42035 .64331 .42613 .63815 .42289 .63205 Mtetra
.75 .658 .759 r
.42289 .63205 .42613 .63815 .43192 .63302 .42868 .62685 Mtetra
.749 .656 .758 r
.42868 .62685 .43192 .63302 .4377 .62794 .43447 .6217 Mtetra
.747 .653 .758 r
.43447 .6217 .4377 .62794 .44348 .62289 .44026 .61659 Mtetra
.744 .651 .757 r
.44026 .61659 .44348 .62289 .44926 .6179 .44605 .61154 Mtetra
.742 .649 .757 r
.44605 .61154 .44926 .6179 .45505 .61297 .45184 .60654 Mtetra
.74 .647 .757 r
.45184 .60654 .45505 .61297 .46083 .6081 .45763 .60161 Mtetra
.738 .645 .757 r
.45763 .60161 .46083 .6081 .46661 .6033 .46341 .59676 Mtetra
.735 .643 .757 r
.46341 .59676 .46661 .6033 .47239 .59857 .4692 .59197 Mtetra
.733 .641 .757 r
.4692 .59197 .47239 .59857 .47818 .59392 .47499 .58727 Mtetra
.73 .639 .757 r
.47499 .58727 .47818 .59392 .48396 .58935 .48078 .58266 Mtetra
.727 .636 .757 r
.48078 .58266 .48396 .58935 .48975 .58487 .48657 .57813 Mtetra
.724 .634 .757 r
.48657 .57813 .48975 .58487 .49554 .58049 .49237 .5737 Mtetra
.721 .632 .758 r
.49237 .5737 .49554 .58049 .50133 .5762 .49816 .56936 Mtetra
.718 .63 .758 r
.49816 .56936 .50133 .5762 .50712 .57201 .50396 .56513 Mtetra
.715 .628 .759 r
.50396 .56513 .50712 .57201 .51292 .56792 .50976 .56101 Mtetra
.712 .625 .759 r
.50976 .56101 .51292 .56792 .51872 .56394 .51557 .55699 Mtetra
.708 .623 .76 r
.51557 .55699 .51872 .56394 .52452 .56007 .52137 .55308 Mtetra
.705 .621 .76 r
.52137 .55308 .52452 .56007 .53033 .55632 .52719 .54929 Mtetra
.701 .619 .761 r
.52719 .54929 .53033 .55632 .53615 .55268 .53301 .54562 Mtetra
.698 .616 .762 r
.53301 .54562 .53615 .55268 .54197 .54915 .53884 .54207 Mtetra
.694 .614 .763 r
.53884 .54207 .54197 .54915 .54781 .54575 .54467 .53864 Mtetra
.69 .612 .764 r
.54467 .53864 .54781 .54575 .55364 .54248 .55051 .53533 Mtetra
.686 .609 .764 r
.55051 .53533 .55364 .54248 .55949 .53933 .55636 .53215 Mtetra
.682 .607 .765 r
.55636 .53215 .55949 .53933 .56535 .5363 .56222 .52911 Mtetra
.678 .604 .766 r
.56222 .52911 .56535 .5363 .57121 .53341 .56808 .52619 Mtetra
.673 .602 .767 r
.56808 .52619 .57121 .53341 .57709 .53065 .57396 .52341 Mtetra
.669 .599 .769 r
.57396 .52341 .57709 .53065 .58298 .52802 .57985 .52076 Mtetra
.664 .597 .77 r
.57985 .52076 .58298 .52802 .58888 .52552 .58575 .51824 Mtetra
.66 .594 .771 r
.58575 .51824 .58888 .52552 .59479 .52316 .59167 .51586 Mtetra
.655 .592 .772 r
.59167 .51586 .59479 .52316 .60072 .52093 .5976 .51362 Mtetra
.65 .589 .773 r
.5976 .51362 .60072 .52093 .60666 .51884 .60354 .51152 Mtetra
.645 .587 .774 r
.60354 .51152 .60666 .51884 .61261 .51688 .6095 .50955 Mtetra
.64 .584 .776 r
.6095 .50955 .61261 .51688 .61859 .51506 .61547 .50772 Mtetra
.635 .582 .777 r
.61547 .50772 .61859 .51506 .62458 .51338 .62146 .50603 Mtetra
.63 .579 .778 r
.62146 .50603 .62458 .51338 .63058 .51184 .62747 .50448 Mtetra
.625 .576 .779 r
.62747 .50448 .63058 .51184 .63661 .51043 .6335 .50307 Mtetra
.62 .574 .781 r
.6335 .50307 .63661 .51043 .64266 .50916 .63955 .5018 Mtetra
.614 .571 .782 r
.63955 .5018 .64266 .50916 .64872 .50803 .64562 .50067 Mtetra
.609 .568 .783 r
.64562 .50067 .64872 .50803 .65481 .50703 .6517 .49967 Mtetra
.603 .565 .785 r
.6517 .49967 .65481 .50703 .66092 .50617 .65781 .49881 Mtetra
.598 .563 .786 r
.65781 .49881 .66092 .50617 .66705 .50544 .66395 .49808 Mtetra
.592 .56 .787 r
.66395 .49808 .66705 .50544 .67321 .50484 .6701 .49749 Mtetra
.586 .557 .789 r
.6701 .49749 .67321 .50484 .67938 .50438 .67628 .49704 Mtetra
.581 .555 .79 r
.67628 .49704 .67938 .50438 .68559 .50404 .68249 .49671 Mtetra
.575 .552 .792 r
.68249 .49671 .68559 .50404 .69182 .50383 .68872 .49652 Mtetra
.569 .55 .793 r
.68872 .49652 .69182 .50383 .69807 .50375 .69498 .49645 Mtetra
.563 .547 .795 r
.69498 .49645 .69807 .50375 .70436 .5038 .70126 .49651 Mtetra
.557 .545 .796 r
.70126 .49651 .70436 .5038 .71067 .50396 .70757 .49669 Mtetra
.552 .542 .797 r
.70757 .49669 .71067 .50396 .71701 .50425 .71392 .49699 Mtetra
.546 .54 .799 r
.71392 .49699 .71701 .50425 .72338 .50465 .72029 .49741 Mtetra
.54 .537 .8 r
.72029 .49741 .72338 .50465 .72977 .50517 .72669 .49795 Mtetra
.534 .535 .802 r
.72669 .49795 .72977 .50517 .7362 .50579 .73312 .4986 Mtetra
.529 .533 .803 r
.73312 .4986 .7362 .50579 .74266 .50653 .73958 .49936 Mtetra
.523 .531 .805 r
.73958 .49936 .74266 .50653 .74915 .50736 .74607 .50023 Mtetra
.518 .529 .807 r
.74607 .50023 .74915 .50736 .75567 .5083 .7526 .50119 Mtetra
.512 .527 .808 r
.7526 .50119 .75567 .5083 .76223 .50933 .75915 .50226 Mtetra
.507 .525 .81 r
.75915 .50226 .76223 .50933 .76881 .51046 .76574 .50342 Mtetra
.502 .523 .811 r
.76574 .50342 .76881 .51046 .77543 .51167 .77237 .50467 Mtetra
.496 .522 .813 r
.77237 .50467 .77543 .51167 .78209 .51297 .77903 .506 Mtetra
.492 .521 .815 r
.77903 .506 .78209 .51297 .78877 .51434 .78572 .50742 Mtetra
.487 .519 .817 r
.78572 .50742 .78877 .51434 .79549 .51578 .79244 .5089 Mtetra
.482 .518 .818 r
.79244 .5089 .79549 .51578 .80225 .5173 .7992 .51046 Mtetra
.478 .518 .82 r
.7992 .51046 .80225 .5173 .80903 .51887 .80599 .51208 Mtetra
.474 .517 .822 r
.80599 .51208 .80903 .51887 .81585 .5205 .81282 .51376 Mtetra
.47 .517 .824 r
.81282 .51376 .81585 .5205 .82271 .52217 .81968 .51549 Mtetra
.466 .517 .826 r
.81968 .51549 .82271 .52217 .82959 .52389 .82657 .51726 Mtetra
.463 .517 .828 r
.82657 .51726 .82959 .52389 .83651 .52564 .8335 .51907 Mtetra
.46 .518 .83 r
.8335 .51907 .83651 .52564 .84347 .52742 .84046 .52091 Mtetra
.458 .519 .833 r
.84046 .52091 .84347 .52742 .85045 .52922 .84746 .52277 Mtetra
.455 .52 .835 r
.84746 .52277 .85045 .52922 .85747 .53104 .85449 .52465 Mtetra
.454 .521 .838 r
.85449 .52465 .85747 .53104 .86452 .53285 .86155 .52653 Mtetra
.452 .523 .84 r
.86155 .52653 .86452 .53285 .8716 .53466 .86864 .52841 Mtetra
.451 .525 .843 r
.86864 .52841 .8716 .53466 .87871 .53646 .87576 .53028 Mtetra
.451 .528 .846 r
.87576 .53028 .87871 .53646 .88585 .53824 .88291 .53213 Mtetra
.451 .531 .849 r
.88291 .53213 .88585 .53824 .89302 .53998 .89009 .53395 Mtetra
.451 .535 .852 r
.89009 .53395 .89302 .53998 .90021 .54168 .89729 .53573 Mtetra
.452 .539 .855 r
.89729 .53573 .90021 .54168 .90743 .54332 .90453 .53746 Mtetra
.454 .544 .858 r
.90453 .53746 .90743 .54332 .91467 .54491 .91179 .53913 Mtetra
.456 .549 .862 r
.91179 .53913 .91467 .54491 .92193 .54641 .91907 .54072 Mtetra
.46 .554 .865 r
.91907 .54072 .92193 .54641 .92922 .54784 .92637 .54223 Mtetra
.463 .561 .869 r
.92637 .54223 .92922 .54784 .93653 .54916 .93369 .54365 Mtetra
.468 .568 .873 r
.93369 .54365 .93653 .54916 .94385 .55037 .94103 .54496 Mtetra
.764 .702 .793 r
.32113 .71467 .32457 .71927 .33032 .7146 .3269 .7099 Mtetra
.765 .699 .789 r
.3269 .7099 .33032 .7146 .33608 .70983 .33267 .70502 Mtetra
.766 .696 .785 r
.33267 .70502 .33608 .70983 .34185 .70495 .33845 .70005 Mtetra
.766 .693 .782 r
.33845 .70005 .34185 .70495 .34762 .7 .34424 .69499 Mtetra
.766 .69 .779 r
.34424 .69499 .34762 .7 .3534 .69496 .35003 .68986 Mtetra
.766 .688 .776 r
.35003 .68986 .3534 .69496 .35919 .68986 .35583 .68467 Mtetra
.765 .685 .774 r
.35583 .68467 .35919 .68986 .36497 .6847 .36162 .67942 Mtetra
.765 .683 .772 r
.36162 .67942 .36497 .6847 .37076 .6795 .36742 .67413 Mtetra
.764 .68 .77 r
.36742 .67413 .37076 .6795 .37655 .67426 .37322 .66881 Mtetra
.763 .678 .768 r
.37322 .66881 .37655 .67426 .38234 .66899 .37903 .66346 Mtetra
.762 .675 .766 r
.37903 .66346 .38234 .66899 .38813 .66371 .38483 .65809 Mtetra
.761 .673 .765 r
.38483 .65809 .38813 .66371 .39393 .65841 .39063 .65271 Mtetra
.76 .671 .763 r
.39063 .65271 .39393 .65841 .39972 .65311 .39643 .64734 Mtetra
.759 .669 .762 r
.39643 .64734 .39972 .65311 .40551 .64782 .40224 .64197 Mtetra
.757 .666 .761 r
.40224 .64197 .40551 .64782 .41131 .64254 .40804 .63662 Mtetra
.756 .664 .76 r
.40804 .63662 .41131 .64254 .4171 .63728 .41384 .63129 Mtetra
.754 .662 .76 r
.41384 .63129 .4171 .63728 .42289 .63205 .41964 .62599 Mtetra
.753 .66 .759 r
.41964 .62599 .42289 .63205 .42868 .62685 .42544 .62073 Mtetra
.751 .658 .758 r
.42544 .62073 .42868 .62685 .43447 .6217 .43123 .61551 Mtetra
.749 .656 .758 r
.43123 .61551 .43447 .6217 .44026 .61659 .43703 .61034 Mtetra
.747 .654 .758 r
.43703 .61034 .44026 .61659 .44605 .61154 .44283 .60522 Mtetra
.744 .652 .757 r
.44283 .60522 .44605 .61154 .45184 .60654 .44862 .60017 Mtetra
.742 .649 .757 r
.44862 .60017 .45184 .60654 .45763 .60161 .45442 .59519 Mtetra
.74 .647 .757 r
.45442 .59519 .45763 .60161 .46341 .59676 .46021 .59028 Mtetra
.737 .645 .757 r
.46021 .59028 .46341 .59676 .4692 .59197 .466 .58544 Mtetra
.735 .643 .757 r
.466 .58544 .4692 .59197 .47499 .58727 .4718 .58069 Mtetra
.732 .641 .758 r
.4718 .58069 .47499 .58727 .48078 .58266 .4776 .57603 Mtetra
.729 .639 .758 r
.4776 .57603 .48078 .58266 .48657 .57813 .48339 .57145 Mtetra
.726 .637 .758 r
.48339 .57145 .48657 .57813 .49237 .5737 .48919 .56698 Mtetra
.723 .635 .759 r
.48919 .56698 .49237 .5737 .49816 .56936 .49499 .5626 Mtetra
.72 .632 .759 r
.49499 .5626 .49816 .56936 .50396 .56513 .50079 .55833 Mtetra
.717 .63 .76 r
.50079 .55833 .50396 .56513 .50976 .56101 .5066 .55416 Mtetra
.714 .628 .76 r
.5066 .55416 .50976 .56101 .51557 .55699 .51241 .55011 Mtetra
.71 .626 .761 r
.51241 .55011 .51557 .55699 .52137 .55308 .51822 .54616 Mtetra
.707 .623 .762 r
.51822 .54616 .52137 .55308 .52719 .54929 .52404 .54234 Mtetra
.703 .621 .763 r
.52404 .54234 .52719 .54929 .53301 .54562 .52986 .53863 Mtetra
.699 .619 .763 r
.52986 .53863 .53301 .54562 .53884 .54207 .53569 .53505 Mtetra
.695 .617 .764 r
.53569 .53505 .53884 .54207 .54467 .53864 .54153 .53159 Mtetra
.691 .614 .765 r
.54153 .53159 .54467 .53864 .55051 .53533 .54737 .52826 Mtetra
.687 .612 .766 r
.54737 .52826 .55051 .53533 .55636 .53215 .55322 .52506 Mtetra
.683 .609 .767 r
.55322 .52506 .55636 .53215 .56222 .52911 .55908 .52199 Mtetra
.679 .607 .768 r
.55908 .52199 .56222 .52911 .56808 .52619 .56495 .51905 Mtetra
.675 .605 .769 r
.56495 .51905 .56808 .52619 .57396 .52341 .57083 .51624 Mtetra
.67 .602 .77 r
.57083 .51624 .57396 .52341 .57985 .52076 .57673 .51357 Mtetra
.666 .6 .772 r
.57673 .51357 .57985 .52076 .58575 .51824 .58263 .51104 Mtetra
.661 .597 .773 r
.58263 .51104 .58575 .51824 .59167 .51586 .58855 .50865 Mtetra
.656 .594 .774 r
.58855 .50865 .59167 .51586 .5976 .51362 .59448 .50639 Mtetra
.651 .592 .775 r
.59448 .50639 .5976 .51362 .60354 .51152 .60042 .50427 Mtetra
.646 .589 .776 r
.60042 .50427 .60354 .51152 .6095 .50955 .60638 .5023 Mtetra
.641 .587 .778 r
.60638 .5023 .6095 .50955 .61547 .50772 .61236 .50046 Mtetra
.636 .584 .779 r
.61236 .50046 .61547 .50772 .62146 .50603 .61835 .49876 Mtetra
.631 .581 .78 r
.61835 .49876 .62146 .50603 .62747 .50448 .62436 .49721 Mtetra
.625 .578 .782 r
.62436 .49721 .62747 .50448 .6335 .50307 .63039 .49579 Mtetra
.62 .576 .783 r
.63039 .49579 .6335 .50307 .63955 .5018 .63644 .49452 Mtetra
.614 .573 .784 r
.63644 .49452 .63955 .5018 .64562 .50067 .64251 .49338 Mtetra
.609 .57 .786 r
.64251 .49338 .64562 .50067 .6517 .49967 .6486 .49239 Mtetra
.603 .567 .787 r
.6486 .49239 .6517 .49967 .65781 .49881 .65471 .49153 Mtetra
.597 .565 .789 r
.65471 .49153 .65781 .49881 .66395 .49808 .66084 .49081 Mtetra
.591 .562 .79 r
.66084 .49081 .66395 .49808 .6701 .49749 .667 .49022 Mtetra
.585 .559 .791 r
.667 .49022 .6701 .49749 .67628 .49704 .67318 .48977 Mtetra
.58 .556 .793 r
.67318 .48977 .67628 .49704 .68249 .49671 .67939 .48946 Mtetra
.574 .554 .794 r
.67939 .48946 .68249 .49671 .68872 .49652 .68562 .48927 Mtetra
.568 .551 .796 r
.68562 .48927 .68872 .49652 .69498 .49645 .69188 .48921 Mtetra
.562 .548 .797 r
.69188 .48921 .69498 .49645 .70126 .49651 .69817 .48929 Mtetra
.556 .546 .799 r
.69817 .48929 .70126 .49651 .70757 .49669 .70448 .48948 Mtetra
.55 .543 .8 r
.70448 .48948 .70757 .49669 .71392 .49699 .71082 .48981 Mtetra
.544 .541 .801 r
.71082 .48981 .71392 .49699 .72029 .49741 .7172 .49025 Mtetra
.538 .538 .803 r
.7172 .49025 .72029 .49741 .72669 .49795 .7236 .49081 Mtetra
.532 .536 .804 r
.7236 .49081 .72669 .49795 .73312 .4986 .73003 .49148 Mtetra
.526 .533 .806 r
.73003 .49148 .73312 .4986 .73958 .49936 .7365 .49226 Mtetra
.52 .531 .807 r
.7365 .49226 .73958 .49936 .74607 .50023 .74299 .49316 Mtetra
.514 .529 .809 r
.74299 .49316 .74607 .50023 .7526 .50119 .74952 .49415 Mtetra
.509 .527 .811 r
.74952 .49415 .7526 .50119 .75915 .50226 .75608 .49525 Mtetra
.503 .525 .812 r
.75608 .49525 .75915 .50226 .76574 .50342 .76267 .49644 Mtetra
.498 .523 .814 r
.76267 .49644 .76574 .50342 .77237 .50467 .7693 .49773 Mtetra
.493 .522 .815 r
.7693 .49773 .77237 .50467 .77903 .506 .77596 .4991 Mtetra
.487 .52 .817 r
.77596 .4991 .77903 .506 .78572 .50742 .78266 .50055 Mtetra
.483 .519 .819 r
.78266 .50055 .78572 .50742 .79244 .5089 .78939 .50208 Mtetra
.478 .518 .82 r
.78939 .50208 .79244 .5089 .7992 .51046 .79615 .50368 Mtetra
.473 .517 .822 r
.79615 .50368 .7992 .51046 .80599 .51208 .80295 .50534 Mtetra
.469 .516 .824 r
.80295 .50534 .80599 .51208 .81282 .51376 .80978 .50707 Mtetra
.465 .516 .826 r
.80978 .50707 .81282 .51376 .81968 .51549 .81665 .50885 Mtetra
.461 .516 .828 r
.81665 .50885 .81968 .51549 .82657 .51726 .82355 .51067 Mtetra
.458 .516 .83 r
.82355 .51067 .82657 .51726 .8335 .51907 .83049 .51253 Mtetra
.455 .516 .832 r
.83049 .51253 .8335 .51907 .84046 .52091 .83746 .51443 Mtetra
.452 .517 .834 r
.83746 .51443 .84046 .52091 .84746 .52277 .84446 .51635 Mtetra
.45 .518 .837 r
.84446 .51635 .84746 .52277 .85449 .52465 .8515 .51829 Mtetra
.448 .519 .839 r
.8515 .51829 .85449 .52465 .86155 .52653 .85857 .52024 Mtetra
.446 .521 .842 r
.85857 .52024 .86155 .52653 .86864 .52841 .86567 .52218 Mtetra
.445 .523 .844 r
.86567 .52218 .86864 .52841 .87576 .53028 .8728 .52412 Mtetra
.444 .526 .847 r
.8728 .52412 .87576 .53028 .88291 .53213 .87996 .52604 Mtetra
.444 .529 .85 r
.87996 .52604 .88291 .53213 .89009 .53395 .88715 .52794 Mtetra
.445 .532 .853 r
.88715 .52794 .89009 .53395 .89729 .53573 .89437 .52979 Mtetra
.446 .536 .856 r
.89437 .52979 .89729 .53573 .90453 .53746 .90162 .5316 Mtetra
.447 .541 .859 r
.90162 .5316 .90453 .53746 .91179 .53913 .90889 .53335 Mtetra
.45 .546 .862 r
.90889 .53335 .91179 .53913 .91907 .54072 .91619 .53503 Mtetra
.453 .551 .866 r
.91619 .53503 .91907 .54072 .92637 .54223 .92351 .53663 Mtetra
.456 .557 .87 r
.92351 .53663 .92637 .54223 .93369 .54365 .93085 .53814 Mtetra
.461 .564 .873 r
.93085 .53814 .93369 .54365 .94103 .54496 .93821 .53954 Mtetra
.767 .703 .792 r
.31769 .71007 .32113 .71467 .3269 .7099 .32347 .7052 Mtetra
.767 .7 .788 r
.32347 .7052 .3269 .7099 .33267 .70502 .32925 .70022 Mtetra
.768 .697 .784 r
.32925 .70022 .33267 .70502 .33845 .70005 .33505 .69515 Mtetra
.768 .694 .781 r
.33505 .69515 .33845 .70005 .34424 .69499 .34085 .69 Mtetra
.768 .692 .778 r
.34085 .69 .34424 .69499 .35003 .68986 .34665 .68478 Mtetra
.768 .689 .776 r
.34665 .68478 .35003 .68986 .35583 .68467 .35245 .6795 Mtetra
.768 .687 .773 r
.35245 .6795 .35583 .68467 .36162 .67942 .35826 .67416 Mtetra
.767 .684 .771 r
.35826 .67416 .36162 .67942 .36742 .67413 .36407 .66879 Mtetra
.766 .682 .769 r
.36407 .66879 .36742 .67413 .37322 .66881 .36989 .66338 Mtetra
.766 .68 .768 r
.36989 .66338 .37322 .66881 .37903 .66346 .3757 .65795 Mtetra
.765 .677 .766 r
.3757 .65795 .37903 .66346 .38483 .65809 .38151 .6525 Mtetra
.764 .675 .765 r
.38151 .6525 .38483 .65809 .39063 .65271 .38732 .64705 Mtetra
.762 .673 .763 r
.38732 .64705 .39063 .65271 .39643 .64734 .39314 .6416 Mtetra
.761 .671 .762 r
.39314 .6416 .39643 .64734 .40224 .64197 .39895 .63616 Mtetra
.76 .669 .761 r
.39895 .63616 .40224 .64197 .40804 .63662 .40476 .63074 Mtetra
.758 .666 .761 r
.40476 .63074 .40804 .63662 .41384 .63129 .41057 .62534 Mtetra
.756 .664 .76 r
.41057 .62534 .41384 .63129 .41964 .62599 .41638 .61998 Mtetra
.755 .662 .759 r
.41638 .61998 .41964 .62599 .42544 .62073 .42218 .61465 Mtetra
.753 .66 .759 r
.42218 .61465 .42544 .62073 .43123 .61551 .42799 .60937 Mtetra
.751 .658 .758 r
.42799 .60937 .43123 .61551 .43703 .61034 .43379 .60414 Mtetra
.749 .656 .758 r
.43379 .60414 .43703 .61034 .44283 .60522 .4396 .59897 Mtetra
.747 .654 .758 r
.4396 .59897 .44283 .60522 .44862 .60017 .4454 .59386 Mtetra
.744 .652 .758 r
.4454 .59386 .44862 .60017 .45442 .59519 .4512 .58882 Mtetra
.742 .65 .758 r
.4512 .58882 .45442 .59519 .46021 .59028 .457 .58386 Mtetra
.739 .648 .758 r
.457 .58386 .46021 .59028 .466 .58544 .4628 .57897 Mtetra
.737 .646 .758 r
.4628 .57897 .466 .58544 .4718 .58069 .4686 .57417 Mtetra
.734 .644 .759 r
.4686 .57417 .4718 .58069 .4776 .57603 .4744 .56946 Mtetra
.731 .642 .759 r
.4744 .56946 .4776 .57603 .48339 .57145 .4802 .56484 Mtetra
.728 .639 .759 r
.4802 .56484 .48339 .57145 .48919 .56698 .48601 .56032 Mtetra
.725 .637 .76 r
.48601 .56032 .48919 .56698 .49499 .5626 .49181 .55591 Mtetra
.722 .635 .76 r
.49181 .55591 .49499 .5626 .50079 .55833 .49762 .55159 Mtetra
.719 .633 .761 r
.49762 .55159 .50079 .55833 .5066 .55416 .50343 .54739 Mtetra
.716 .631 .762 r
.50343 .54739 .5066 .55416 .51241 .55011 .50924 .5433 Mtetra
.712 .629 .762 r
.50924 .5433 .51241 .55011 .51822 .54616 .51506 .53932 Mtetra
.708 .626 .763 r
.51506 .53932 .51822 .54616 .52404 .54234 .52088 .53546 Mtetra
.705 .624 .764 r
.52088 .53546 .52404 .54234 .52986 .53863 .52671 .53173 Mtetra
.701 .622 .765 r
.52671 .53173 .52986 .53863 .53569 .53505 .53254 .52812 Mtetra
.697 .619 .766 r
.53254 .52812 .53569 .53505 .54153 .53159 .53838 .52463 Mtetra
.693 .617 .767 r
.53838 .52463 .54153 .53159 .54737 .52826 .54423 .52127 Mtetra
.689 .615 .768 r
.54423 .52127 .54737 .52826 .55322 .52506 .55008 .51804 Mtetra
.685 .612 .769 r
.55008 .51804 .55322 .52506 .55908 .52199 .55595 .51495 Mtetra
.68 .61 .77 r
.55595 .51495 .55908 .52199 .56495 .51905 .56182 .51199 Mtetra
.676 .607 .771 r
.56182 .51199 .56495 .51905 .57083 .51624 .5677 .50916 Mtetra
.671 .605 .772 r
.5677 .50916 .57083 .51624 .57673 .51357 .5736 .50648 Mtetra
.667 .602 .774 r
.5736 .50648 .57673 .51357 .58263 .51104 .5795 .50393 Mtetra
.662 .6 .775 r
.5795 .50393 .58263 .51104 .58855 .50865 .58542 .50152 Mtetra
.657 .597 .776 r
.58542 .50152 .58855 .50865 .59448 .50639 .59135 .49925 Mtetra
.652 .594 .777 r
.59135 .49925 .59448 .50639 .60042 .50427 .5973 .49712 Mtetra
.647 .592 .779 r
.5973 .49712 .60042 .50427 .60638 .5023 .60326 .49513 Mtetra
.642 .589 .78 r
.60326 .49513 .60638 .5023 .61236 .50046 .60924 .49328 Mtetra
.636 .586 .781 r
.60924 .49328 .61236 .50046 .61835 .49876 .61523 .49158 Mtetra
.631 .584 .783 r
.61523 .49158 .61835 .49876 .62436 .49721 .62124 .49002 Mtetra
.625 .581 .784 r
.62124 .49002 .62436 .49721 .63039 .49579 .62727 .4886 Mtetra
.62 .578 .785 r
.62727 .4886 .63039 .49579 .63644 .49452 .63332 .48732 Mtetra
.614 .575 .787 r
.63332 .48732 .63644 .49452 .64251 .49338 .63939 .48618 Mtetra
.608 .572 .788 r
.63939 .48618 .64251 .49338 .6486 .49239 .64549 .48519 Mtetra
.602 .57 .79 r
.64549 .48519 .6486 .49239 .65471 .49153 .6516 .48433 Mtetra
.597 .567 .791 r
.6516 .48433 .65471 .49153 .66084 .49081 .65773 .48361 Mtetra
.591 .564 .793 r
.65773 .48361 .66084 .49081 .667 .49022 .66389 .48303 Mtetra
.585 .561 .794 r
.66389 .48303 .667 .49022 .67318 .48977 .67008 .48259 Mtetra
.578 .558 .795 r
.67008 .48259 .67318 .48977 .67939 .48946 .67628 .48228 Mtetra
.572 .555 .797 r
.67628 .48228 .67939 .48946 .68562 .48927 .68252 .48211 Mtetra
.566 .553 .798 r
.68252 .48211 .68562 .48927 .69188 .48921 .68878 .48206 Mtetra
.56 .55 .8 r
.68878 .48206 .69188 .48921 .69817 .48929 .69507 .48215 Mtetra
.554 .547 .801 r
.69507 .48215 .69817 .48929 .70448 .48948 .70138 .48236 Mtetra
.548 .544 .803 r
.70138 .48236 .70448 .48948 .71082 .48981 .70773 .4827 Mtetra
.541 .542 .804 r
.70773 .4827 .71082 .48981 .7172 .49025 .7141 .48316 Mtetra
.535 .539 .806 r
.7141 .48316 .7172 .49025 .7236 .49081 .72051 .48373 Mtetra
.529 .537 .807 r
.72051 .48373 .7236 .49081 .73003 .49148 .72694 .48443 Mtetra
.523 .534 .809 r
.72694 .48443 .73003 .49148 .7365 .49226 .73341 .48524 Mtetra
.517 .532 .81 r
.73341 .48524 .7365 .49226 .74299 .49316 .73991 .48616 Mtetra
.511 .53 .812 r
.73991 .48616 .74299 .49316 .74952 .49415 .74644 .48718 Mtetra
.505 .527 .813 r
.74644 .48718 .74952 .49415 .75608 .49525 .75301 .4883 Mtetra
.5 .525 .815 r
.75301 .4883 .75608 .49525 .76267 .49644 .7596 .48953 Mtetra
.494 .523 .816 r
.7596 .48953 .76267 .49644 .7693 .49773 .76623 .49084 Mtetra
.489 .522 .818 r
.76623 .49084 .7693 .49773 .77596 .4991 .7729 .49225 Mtetra
.483 .52 .819 r
.7729 .49225 .77596 .4991 .78266 .50055 .7796 .49374 Mtetra
.478 .519 .821 r
.7796 .49374 .78266 .50055 .78939 .50208 .78633 .49531 Mtetra
.473 .517 .823 r
.78633 .49531 .78939 .50208 .79615 .50368 .7931 .49695 Mtetra
.469 .516 .824 r
.7931 .49695 .79615 .50368 .80295 .50534 .79991 .49866 Mtetra
.464 .516 .826 r
.79991 .49866 .80295 .50534 .80978 .50707 .80675 .50043 Mtetra
.46 .515 .828 r
.80675 .50043 .80978 .50707 .81665 .50885 .81362 .50225 Mtetra
.456 .515 .83 r
.81362 .50225 .81665 .50885 .82355 .51067 .82053 .50413 Mtetra
.452 .515 .832 r
.82053 .50413 .82355 .51067 .83049 .51253 .82747 .50604 Mtetra
.449 .515 .834 r
.82747 .50604 .83049 .51253 .83746 .51443 .83445 .50799 Mtetra
.446 .515 .836 r
.83445 .50799 .83746 .51443 .84446 .51635 .84146 .50997 Mtetra
.444 .516 .838 r
.84146 .50997 .84446 .51635 .8515 .51829 .84851 .51197 Mtetra
.442 .518 .841 r
.84851 .51197 .8515 .51829 .85857 .52024 .85559 .51397 Mtetra
.44 .519 .843 r
.85559 .51397 .85857 .52024 .86567 .52218 .8627 .51598 Mtetra
.439 .521 .846 r
.8627 .51598 .86567 .52218 .8728 .52412 .86984 .51799 Mtetra
.438 .524 .848 r
.86984 .51799 .8728 .52412 .87996 .52604 .87701 .51998 Mtetra
.438 .526 .851 r
.87701 .51998 .87996 .52604 .88715 .52794 .88422 .52194 Mtetra
.438 .53 .854 r
.88422 .52194 .88715 .52794 .89437 .52979 .89145 .52387 Mtetra
.439 .534 .857 r
.89145 .52387 .89437 .52979 .90162 .5316 .89871 .52575 Mtetra
.441 .538 .86 r
.89871 .52575 .90162 .5316 .90889 .53335 .906 .52758 Mtetra
.443 .543 .863 r
.906 .52758 .90889 .53335 .91619 .53503 .91331 .52934 Mtetra
.446 .548 .867 r
.91331 .52934 .91619 .53503 .92351 .53663 .92065 .53103 Mtetra
.449 .554 .87 r
.92065 .53103 .92351 .53663 .93085 .53814 .928 .53262 Mtetra
.453 .561 .874 r
.928 .53262 .93085 .53814 .93821 .53954 .93538 .53411 Mtetra
.769 .704 .79 r
.31423 .70547 .31769 .71007 .32347 .7052 .32002 .7005 Mtetra
.77 .701 .787 r
.32002 .7005 .32347 .7052 .32925 .70022 .32582 .69543 Mtetra
.77 .698 .783 r
.32582 .69543 .32925 .70022 .33505 .69515 .33163 .69027 Mtetra
.77 .696 .78 r
.33163 .69027 .33505 .69515 .34085 .69 .33744 .68503 Mtetra
.77 .693 .778 r
.33744 .68503 .34085 .69 .34665 .68478 .34326 .67972 Mtetra
.77 .691 .775 r
.34326 .67972 .34665 .68478 .35245 .6795 .34907 .67435 Mtetra
.77 .688 .773 r
.34907 .67435 .35245 .6795 .35826 .67416 .35489 .66893 Mtetra
.769 .686 .771 r
.35489 .66893 .35826 .67416 .36407 .66879 .36072 .66348 Mtetra
.769 .684 .769 r
.36072 .66348 .36407 .66879 .36989 .66338 .36654 .65799 Mtetra
.768 .681 .767 r
.36654 .65799 .36989 .66338 .3757 .65795 .37236 .65248 Mtetra
.767 .679 .766 r
.37236 .65248 .3757 .65795 .38151 .6525 .37819 .64696 Mtetra
.766 .677 .765 r
.37819 .64696 .38151 .6525 .38732 .64705 .38401 .64143 Mtetra
.765 .675 .763 r
.38401 .64143 .38732 .64705 .39314 .6416 .38983 .63591 Mtetra
.763 .673 .762 r
.38983 .63591 .39314 .6416 .39895 .63616 .39565 .6304 Mtetra
.762 .671 .762 r
.39565 .6304 .39895 .63616 .40476 .63074 .40147 .62491 Mtetra
.76 .669 .761 r
.40147 .62491 .40476 .63074 .41057 .62534 .40729 .61945 Mtetra
.759 .667 .76 r
.40729 .61945 .41057 .62534 .41638 .61998 .41311 .61402 Mtetra
.757 .665 .76 r
.41311 .61402 .41638 .61998 .42218 .61465 .41892 .60863 Mtetra
.755 .663 .759 r
.41892 .60863 .42218 .61465 .42799 .60937 .42473 .60329 Mtetra
.753 .661 .759 r
.42473 .60329 .42799 .60937 .43379 .60414 .43055 .598 Mtetra
.751 .659 .759 r
.43055 .598 .43379 .60414 .4396 .59897 .43636 .59277 Mtetra
.749 .657 .759 r
.43636 .59277 .4396 .59897 .4454 .59386 .44217 .58761 Mtetra
.746 .655 .759 r
.44217 .58761 .4454 .59386 .4512 .58882 .44797 .58252 Mtetra
.744 .653 .759 r
.44797 .58252 .4512 .58882 .457 .58386 .45378 .57751 Mtetra
.742 .651 .759 r
.45378 .57751 .457 .58386 .4628 .57897 .45959 .57257 Mtetra
.739 .648 .759 r
.45959 .57257 .4628 .57897 .4686 .57417 .46539 .56773 Mtetra
.736 .646 .76 r
.46539 .56773 .4686 .57417 .4744 .56946 .4712 .56297 Mtetra
.733 .644 .76 r
.4712 .56297 .4744 .56946 .4802 .56484 .47701 .55831 Mtetra
.73 .642 .761 r
.47701 .55831 .4802 .56484 .48601 .56032 .48282 .55375 Mtetra
.727 .64 .761 r
.48282 .55375 .48601 .56032 .49181 .55591 .48863 .54929 Mtetra
.724 .638 .762 r
.48863 .54929 .49181 .55591 .49762 .55159 .49444 .54494 Mtetra
.721 .636 .762 r
.49444 .54494 .49762 .55159 .50343 .54739 .50025 .5407 Mtetra
.717 .634 .763 r
.50025 .5407 .50343 .54739 .50924 .5433 .50607 .53657 Mtetra
.714 .631 .764 r
.50607 .53657 .50924 .5433 .51506 .53932 .51189 .53256 Mtetra
.71 .629 .765 r
.51189 .53256 .51506 .53932 .52088 .53546 .51772 .52867 Mtetra
.707 .627 .766 r
.51772 .52867 .52088 .53546 .52671 .53173 .52355 .52491 Mtetra
.703 .625 .767 r
.52355 .52491 .52671 .53173 .53254 .52812 .52939 .52127 Mtetra
.699 .622 .768 r
.52939 .52127 .53254 .52812 .53838 .52463 .53523 .51775 Mtetra
.695 .62 .769 r
.53523 .51775 .53838 .52463 .54423 .52127 .54108 .51437 Mtetra
.691 .618 .77 r
.54108 .51437 .54423 .52127 .55008 .51804 .54694 .51112 Mtetra
.686 .615 .771 r
.54694 .51112 .55008 .51804 .55595 .51495 .5528 .508 Mtetra
.682 .613 .772 r
.5528 .508 .55595 .51495 .56182 .51199 .55868 .50502 Mtetra
.677 .61 .773 r
.55868 .50502 .56182 .51199 .5677 .50916 .56456 .50217 Mtetra
.673 .608 .775 r
.56456 .50217 .5677 .50916 .5736 .50648 .57046 .49947 Mtetra
.668 .605 .776 r
.57046 .49947 .5736 .50648 .5795 .50393 .57637 .4969 Mtetra
.663 .603 .777 r
.57637 .4969 .5795 .50393 .58542 .50152 .58229 .49448 Mtetra
.658 .6 .778 r
.58229 .49448 .58542 .50152 .59135 .49925 .58823 .49219 Mtetra
.653 .597 .78 r
.58823 .49219 .59135 .49925 .5973 .49712 .59417 .49005 Mtetra
.648 .595 .781 r
.59417 .49005 .5973 .49712 .60326 .49513 .60014 .48805 Mtetra
.642 .592 .782 r
.60014 .48805 .60326 .49513 .60924 .49328 .60612 .4862 Mtetra
.637 .589 .784 r
.60612 .4862 .60924 .49328 .61523 .49158 .61211 .48449 Mtetra
.631 .586 .785 r
.61211 .48449 .61523 .49158 .62124 .49002 .61813 .48292 Mtetra
.626 .583 .787 r
.61813 .48292 .62124 .49002 .62727 .4886 .62416 .48149 Mtetra
.62 .581 .788 r
.62416 .48149 .62727 .4886 .63332 .48732 .63021 .48021 Mtetra
.614 .578 .79 r
.63021 .48021 .63332 .48732 .63939 .48618 .63628 .47907 Mtetra
.608 .575 .791 r
.63628 .47907 .63939 .48618 .64549 .48519 .64237 .47808 Mtetra
.602 .572 .793 r
.64237 .47808 .64549 .48519 .6516 .48433 .64849 .47722 Mtetra
.596 .569 .794 r
.64849 .47722 .6516 .48433 .65773 .48361 .65463 .47651 Mtetra
.59 .566 .795 r
.65463 .47651 .65773 .48361 .66389 .48303 .66079 .47593 Mtetra
.584 .563 .797 r
.66079 .47593 .66389 .48303 .67008 .48259 .66697 .47549 Mtetra
.577 .56 .798 r
.66697 .47549 .67008 .48259 .67628 .48228 .67318 .47519 Mtetra
.571 .557 .8 r
.67318 .47519 .67628 .48228 .68252 .48211 .67942 .47502 Mtetra
.565 .554 .801 r
.67942 .47502 .68252 .48211 .68878 .48206 .68568 .47499 Mtetra
.558 .552 .803 r
.68568 .47499 .68878 .48206 .69507 .48215 .69197 .47509 Mtetra
.552 .549 .804 r
.69197 .47509 .69507 .48215 .70138 .48236 .69829 .47532 Mtetra
.546 .546 .806 r
.69829 .47532 .70138 .48236 .70773 .4827 .70464 .47567 Mtetra
.539 .543 .807 r
.70464 .47567 .70773 .4827 .7141 .48316 .71101 .47614 Mtetra
.533 .54 .809 r
.71101 .47614 .7141 .48316 .72051 .48373 .71742 .47674 Mtetra
.527 .538 .81 r
.71742 .47674 .72051 .48373 .72694 .48443 .72386 .47746 Mtetra
.52 .535 .811 r
.72386 .47746 .72694 .48443 .73341 .48524 .73033 .47829 Mtetra
.514 .533 .813 r
.73033 .47829 .73341 .48524 .73991 .48616 .73683 .47923 Mtetra
.508 .53 .814 r
.73683 .47923 .73991 .48616 .74644 .48718 .74336 .48028 Mtetra
.502 .528 .816 r
.74336 .48028 .74644 .48718 .75301 .4883 .74993 .48143 Mtetra
.496 .526 .817 r
.74993 .48143 .75301 .4883 .7596 .48953 .75653 .48268 Mtetra
.49 .524 .819 r
.75653 .48268 .7596 .48953 .76623 .49084 .76317 .48403 Mtetra
.484 .522 .82 r
.76317 .48403 .76623 .49084 .7729 .49225 .76984 .48547 Mtetra
.479 .52 .822 r
.76984 .48547 .7729 .49225 .7796 .49374 .77654 .48699 Mtetra
.474 .519 .824 r
.77654 .48699 .7796 .49374 .78633 .49531 .78328 .4886 Mtetra
.468 .517 .825 r
.78328 .4886 .78633 .49531 .7931 .49695 .79005 .49028 Mtetra
.464 .516 .827 r
.79005 .49028 .7931 .49695 .79991 .49866 .79686 .49203 Mtetra
.459 .515 .829 r
.79686 .49203 .79991 .49866 .80675 .50043 .80371 .49384 Mtetra
.455 .514 .83 r
.80371 .49384 .80675 .50043 .81362 .50225 .81059 .49571 Mtetra
.451 .514 .832 r
.81059 .49571 .81362 .50225 .82053 .50413 .8175 .49763 Mtetra
.447 .514 .834 r
.8175 .49763 .82053 .50413 .82747 .50604 .82445 .4996 Mtetra
.443 .514 .836 r
.82445 .4996 .82747 .50604 .83445 .50799 .83144 .5016 Mtetra
.44 .514 .838 r
.83144 .5016 .83445 .50799 .84146 .50997 .83846 .50363 Mtetra
.438 .515 .84 r
.83846 .50363 .84146 .50997 .84851 .51197 .84551 .50568 Mtetra
.435 .516 .842 r
.84551 .50568 .84851 .51197 .85559 .51397 .8526 .50775 Mtetra
.434 .517 .845 r
.8526 .50775 .85559 .51397 .8627 .51598 .85972 .50982 Mtetra
.432 .519 .847 r
.85972 .50982 .8627 .51598 .86984 .51799 .86688 .51189 Mtetra
.431 .522 .85 r
.86688 .51189 .86984 .51799 .87701 .51998 .87406 .51394 Mtetra
.431 .524 .852 r
.87406 .51394 .87701 .51998 .88422 .52194 .88128 .51597 Mtetra
.431 .527 .855 r
.88128 .51597 .88422 .52194 .89145 .52387 .88852 .51797 Mtetra
.432 .531 .858 r
.88852 .51797 .89145 .52387 .89871 .52575 .8958 .51993 Mtetra
.434 .535 .861 r
.8958 .51993 .89871 .52575 .906 .52758 .9031 .52183 Mtetra
.436 .54 .864 r
.9031 .52183 .906 .52758 .91331 .52934 .91042 .52367 Mtetra
.438 .545 .868 r
.91042 .52367 .91331 .52934 .92065 .53103 .91777 .52543 Mtetra
.442 .551 .871 r
.91777 .52543 .92065 .53103 .928 .53262 .92515 .52711 Mtetra
.446 .557 .875 r
.92515 .52711 .928 .53262 .93538 .53411 .93254 .52869 Mtetra
.771 .705 .789 r
.31076 .70088 .31423 .70547 .32002 .7005 .31657 .69582 Mtetra
.772 .702 .786 r
.31657 .69582 .32002 .7005 .32582 .69543 .32238 .69066 Mtetra
.772 .7 .783 r
.32238 .69066 .32582 .69543 .33163 .69027 .3282 .68541 Mtetra
.773 .697 .78 r
.3282 .68541 .33163 .69027 .33744 .68503 .33402 .68008 Mtetra
.773 .695 .777 r
.33402 .68008 .33744 .68503 .34326 .67972 .33985 .67469 Mtetra
.773 .692 .775 r
.33985 .67469 .34326 .67972 .34907 .67435 .34568 .66923 Mtetra
.772 .69 .773 r
.34568 .66923 .34907 .67435 .35489 .66893 .35151 .66373 Mtetra
.772 .688 .771 r
.35151 .66373 .35489 .66893 .36072 .66348 .35735 .6582 Mtetra
.771 .686 .769 r
.35735 .6582 .36072 .66348 .36654 .65799 .36318 .65263 Mtetra
.77 .684 .767 r
.36318 .65263 .36654 .65799 .37236 .65248 .36901 .64705 Mtetra
.769 .681 .766 r
.36901 .64705 .37236 .65248 .37819 .64696 .37485 .64145 Mtetra
.768 .679 .765 r
.37485 .64145 .37819 .64696 .38401 .64143 .38068 .63586 Mtetra
.767 .677 .764 r
.38068 .63586 .38401 .64143 .38983 .63591 .38651 .63027 Mtetra
.766 .675 .763 r
.38651 .63027 .38983 .63591 .39565 .6304 .39234 .62469 Mtetra
.764 .673 .762 r
.39234 .62469 .39565 .6304 .40147 .62491 .39817 .61914 Mtetra
.763 .671 .761 r
.39817 .61914 .40147 .62491 .40729 .61945 .404 .61361 Mtetra
.761 .669 .761 r
.404 .61361 .40729 .61945 .41311 .61402 .40982 .60812 Mtetra
.759 .667 .76 r
.40982 .60812 .41311 .61402 .41892 .60863 .41565 .60267 Mtetra
.757 .665 .76 r
.41565 .60267 .41892 .60863 .42473 .60329 .42147 .59727 Mtetra
.755 .663 .76 r
.42147 .59727 .42473 .60329 .43055 .598 .42729 .59193 Mtetra
.753 .661 .76 r
.42729 .59193 .43055 .598 .43636 .59277 .43311 .58665 Mtetra
.751 .659 .76 r
.43311 .58665 .43636 .59277 .44217 .58761 .43892 .58143 Mtetra
.749 .657 .76 r
.43892 .58143 .44217 .58761 .44797 .58252 .44474 .57629 Mtetra
.746 .655 .76 r
.44474 .57629 .44797 .58252 .45378 .57751 .45055 .57123 Mtetra
.744 .653 .76 r
.45055 .57123 .45378 .57751 .45959 .57257 .45637 .56625 Mtetra
.741 .651 .76 r
.45637 .56625 .45959 .57257 .46539 .56773 .46218 .56136 Mtetra
.738 .649 .761 r
.46218 .56136 .46539 .56773 .4712 .56297 .46799 .55656 Mtetra
.736 .647 .761 r
.46799 .55656 .4712 .56297 .47701 .55831 .47381 .55185 Mtetra
.733 .645 .762 r
.47381 .55185 .47701 .55831 .48282 .55375 .47962 .54725 Mtetra
.729 .643 .763 r
.47962 .54725 .48282 .55375 .48863 .54929 .48544 .54276 Mtetra
.726 .641 .763 r
.48544 .54276 .48863 .54929 .49444 .54494 .49125 .53837 Mtetra
.723 .639 .764 r
.49125 .53837 .49444 .54494 .50025 .5407 .49707 .53409 Mtetra
.72 .637 .765 r
.49707 .53409 .50025 .5407 .50607 .53657 .50289 .52993 Mtetra
.716 .635 .766 r
.50289 .52993 .50607 .53657 .51189 .53256 .50872 .52589 Mtetra
.712 .632 .767 r
.50872 .52589 .51189 .53256 .51772 .52867 .51455 .52197 Mtetra
.709 .63 .768 r
.51455 .52197 .51772 .52867 .52355 .52491 .52039 .51817 Mtetra
.705 .628 .769 r
.52039 .51817 .52355 .52491 .52939 .52127 .52623 .5145 Mtetra
.701 .626 .77 r
.52623 .5145 .52939 .52127 .53523 .51775 .53207 .51096 Mtetra
.696 .623 .771 r
.53207 .51096 .53523 .51775 .54108 .51437 .53793 .50756 Mtetra
.692 .621 .772 r
.53793 .50756 .54108 .51437 .54694 .51112 .54379 .50428 Mtetra
.688 .618 .773 r
.54379 .50428 .54694 .51112 .5528 .508 .54966 .50114 Mtetra
.683 .616 .774 r
.54966 .50114 .5528 .508 .55868 .50502 .55554 .49814 Mtetra
.679 .613 .776 r
.55554 .49814 .55868 .50502 .56456 .50217 .56142 .49528 Mtetra
.674 .611 .777 r
.56142 .49528 .56456 .50217 .57046 .49947 .56732 .49255 Mtetra
.669 .608 .778 r
.56732 .49255 .57046 .49947 .57637 .4969 .57323 .48997 Mtetra
.664 .606 .78 r
.57323 .48997 .57637 .4969 .58229 .49448 .57916 .48753 Mtetra
.659 .603 .781 r
.57916 .48753 .58229 .49448 .58823 .49219 .58509 .48523 Mtetra
.654 .6 .782 r
.58509 .48523 .58823 .49219 .59417 .49005 .59105 .48308 Mtetra
.648 .598 .784 r
.59105 .48308 .59417 .49005 .60014 .48805 .59701 .48107 Mtetra
.643 .595 .785 r
.59701 .48107 .60014 .48805 .60612 .4862 .60299 .47921 Mtetra
.637 .592 .787 r
.60299 .47921 .60612 .4862 .61211 .48449 .60899 .47749 Mtetra
.632 .589 .788 r
.60899 .47749 .61211 .48449 .61813 .48292 .61501 .47591 Mtetra
.626 .586 .79 r
.61501 .47591 .61813 .48292 .62416 .48149 .62104 .47448 Mtetra
.62 .583 .791 r
.62104 .47448 .62416 .48149 .63021 .48021 .62709 .4732 Mtetra
.614 .58 .793 r
.62709 .4732 .63021 .48021 .63628 .47907 .63317 .47206 Mtetra
.608 .577 .794 r
.63317 .47206 .63628 .47907 .64237 .47808 .63926 .47106 Mtetra
.602 .574 .796 r
.63926 .47106 .64237 .47808 .64849 .47722 .64538 .47021 Mtetra
.595 .571 .797 r
.64538 .47021 .64849 .47722 .65463 .47651 .65152 .46949 Mtetra
.589 .568 .798 r
.65152 .46949 .65463 .47651 .66079 .47593 .65768 .46892 Mtetra
.583 .565 .8 r
.65768 .46892 .66079 .47593 .66697 .47549 .66386 .46849 Mtetra
.576 .562 .801 r
.66386 .46849 .66697 .47549 .67318 .47519 .67008 .46819 Mtetra
.57 .559 .803 r
.67008 .46819 .67318 .47519 .67942 .47502 .67631 .46803 Mtetra
.563 .556 .804 r
.67631 .46803 .67942 .47502 .68568 .47499 .68258 .46801 Mtetra
.557 .553 .806 r
.68258 .46801 .68568 .47499 .69197 .47509 .68887 .46812 Mtetra
.55 .55 .807 r
.68887 .46812 .69197 .47509 .69829 .47532 .69519 .46836 Mtetra
.544 .548 .809 r
.69519 .46836 .69829 .47532 .70464 .47567 .70154 .46873 Mtetra
.537 .545 .81 r
.70154 .46873 .70464 .47567 .71101 .47614 .70792 .46922 Mtetra
.53 .542 .812 r
.70792 .46922 .71101 .47614 .71742 .47674 .71433 .46983 Mtetra
.524 .539 .813 r
.71433 .46983 .71742 .47674 .72386 .47746 .72077 .47057 Mtetra
.517 .536 .815 r
.72077 .47057 .72386 .47746 .73033 .47829 .72724 .47142 Mtetra
.511 .534 .816 r
.72724 .47142 .73033 .47829 .73683 .47923 .73375 .47238 Mtetra
.504 .531 .817 r
.73375 .47238 .73683 .47923 .74336 .48028 .74028 .47346 Mtetra
.498 .529 .819 r
.74028 .47346 .74336 .48028 .74993 .48143 .74685 .47463 Mtetra
.492 .526 .82 r
.74685 .47463 .74993 .48143 .75653 .48268 .75346 .47591 Mtetra
.486 .524 .822 r
.75346 .47591 .75653 .48268 .76317 .48403 .7601 .47729 Mtetra
.48 .522 .823 r
.7601 .47729 .76317 .48403 .76984 .48547 .76677 .47876 Mtetra
.474 .52 .825 r
.76677 .47876 .76984 .48547 .77654 .48699 .77348 .48032 Mtetra
.469 .519 .826 r
.77348 .48032 .77654 .48699 .78328 .4886 .78022 .48196 Mtetra
.464 .517 .828 r
.78022 .48196 .78328 .4886 .79005 .49028 .787 .48367 Mtetra
.459 .516 .829 r
.787 .48367 .79005 .49028 .79686 .49203 .79382 .48546 Mtetra
.454 .515 .831 r
.79382 .48546 .79686 .49203 .80371 .49384 .80067 .48732 Mtetra
.449 .514 .833 r
.80067 .48732 .80371 .49384 .81059 .49571 .80755 .48923 Mtetra
.445 .513 .835 r
.80755 .48923 .81059 .49571 .8175 .49763 .81448 .4912 Mtetra
.441 .513 .836 r
.81448 .4912 .8175 .49763 .82445 .4996 .82143 .49321 Mtetra
.437 .513 .838 r
.82143 .49321 .82445 .4996 .83144 .5016 .82843 .49526 Mtetra
.434 .513 .84 r
.82843 .49526 .83144 .5016 .83846 .50363 .83546 .49734 Mtetra
.431 .514 .842 r
.83546 .49734 .83846 .50363 .84551 .50568 .84252 .49945 Mtetra
.429 .515 .844 r
.84252 .49945 .84551 .50568 .8526 .50775 .84961 .50157 Mtetra
.427 .516 .847 r
.84961 .50157 .8526 .50775 .85972 .50982 .85675 .5037 Mtetra
.426 .518 .849 r
.85675 .5037 .85972 .50982 .86688 .51189 .86391 .50582 Mtetra
.425 .52 .851 r
.86391 .50582 .86688 .51189 .87406 .51394 .87111 .50794 Mtetra
.424 .522 .854 r
.87111 .50794 .87406 .51394 .88128 .51597 .87833 .51004 Mtetra
.424 .525 .857 r
.87833 .51004 .88128 .51597 .88852 .51797 .88559 .5121 Mtetra
.425 .529 .859 r
.88559 .5121 .88852 .51797 .8958 .51993 .89288 .51413 Mtetra
.427 .533 .862 r
.89288 .51413 .8958 .51993 .9031 .52183 .90019 .5161 Mtetra
.429 .537 .865 r
.90019 .5161 .9031 .52183 .91042 .52367 .90753 .51801 Mtetra
.431 .542 .869 r
.90753 .51801 .91042 .52367 .91777 .52543 .9149 .51985 Mtetra
.435 .548 .872 r
.9149 .51985 .91777 .52543 .92515 .52711 .92229 .52161 Mtetra
.439 .554 .875 r
.92229 .52161 .92515 .52711 .93254 .52869 .9297 .52327 Mtetra
.774 .707 .789 r
.30728 .69631 .31076 .70088 .31657 .69582 .3131 .69116 Mtetra
.774 .704 .785 r
.3131 .69116 .31657 .69582 .32238 .69066 .31893 .68591 Mtetra
.775 .701 .782 r
.31893 .68591 .32238 .69066 .3282 .68541 .32476 .68057 Mtetra
.775 .699 .779 r
.32476 .68057 .3282 .68541 .33402 .68008 .33059 .67516 Mtetra
.775 .697 .777 r
.33059 .67516 .33402 .68008 .33985 .67469 .33643 .66968 Mtetra
.775 .694 .775 r
.33643 .66968 .33985 .67469 .34568 .66923 .34228 .66415 Mtetra
.774 .692 .773 r
.34228 .66415 .34568 .66923 .35151 .66373 .34812 .65857 Mtetra
.774 .69 .771 r
.34812 .65857 .35151 .66373 .35735 .6582 .35396 .65296 Mtetra
.773 .688 .769 r
.35396 .65296 .35735 .6582 .36318 .65263 .35981 .64732 Mtetra
.772 .686 .768 r
.35981 .64732 .36318 .65263 .36901 .64705 .36565 .64167 Mtetra
.772 .684 .766 r
.36565 .64167 .36901 .64705 .37485 .64145 .3715 .636 Mtetra
.77 .682 .765 r
.3715 .636 .37485 .64145 .38068 .63586 .37734 .63034 Mtetra
.769 .68 .764 r
.37734 .63034 .38068 .63586 .38651 .63027 .38318 .62468 Mtetra
.768 .678 .763 r
.38318 .62468 .38651 .63027 .39234 .62469 .38902 .61904 Mtetra
.767 .676 .762 r
.38902 .61904 .39234 .62469 .39817 .61914 .39486 .61342 Mtetra
.765 .674 .762 r
.39486 .61342 .39817 .61914 .404 .61361 .4007 .60783 Mtetra
.763 .672 .761 r
.4007 .60783 .404 .61361 .40982 .60812 .40653 .60228 Mtetra
.762 .67 .761 r
.40653 .60228 .40982 .60812 .41565 .60267 .41237 .59678 Mtetra
.76 .668 .761 r
.41237 .59678 .41565 .60267 .42147 .59727 .4182 .59132 Mtetra
.758 .666 .761 r
.4182 .59132 .42147 .59727 .42729 .59193 .42402 .58593 Mtetra
.756 .664 .761 r
.42402 .58593 .42729 .59193 .43311 .58665 .42985 .58059 Mtetra
.753 .662 .761 r
.42985 .58059 .43311 .58665 .43892 .58143 .43567 .57533 Mtetra
.751 .66 .761 r
.43567 .57533 .43892 .58143 .44474 .57629 .4415 .57014 Mtetra
.749 .658 .761 r
.4415 .57014 .44474 .57629 .45055 .57123 .44732 .56503 Mtetra
.746 .656 .761 r
.44732 .56503 .45055 .57123 .45637 .56625 .45314 .56 Mtetra
.743 .654 .762 r
.45314 .56 .45637 .56625 .46218 .56136 .45896 .55507 Mtetra
.741 .652 .762 r
.45896 .55507 .46218 .56136 .46799 .55656 .46478 .55023 Mtetra
.738 .65 .763 r
.46478 .55023 .46799 .55656 .47381 .55185 .4706 .54548 Mtetra
.735 .648 .763 r
.4706 .54548 .47381 .55185 .47962 .54725 .47641 .54084 Mtetra
.732 .646 .764 r
.47641 .54084 .47962 .54725 .48544 .54276 .48224 .53631 Mtetra
.728 .644 .765 r
.48224 .53631 .48544 .54276 .49125 .53837 .48806 .53188 Mtetra
.725 .642 .766 r
.48806 .53188 .49125 .53837 .49707 .53409 .49388 .52757 Mtetra
.722 .64 .766 r
.49388 .52757 .49707 .53409 .50289 .52993 .49971 .52338 Mtetra
.718 .638 .767 r
.49971 .52338 .50289 .52993 .50872 .52589 .50554 .51931 Mtetra
.714 .636 .768 r
.50554 .51931 .50872 .52589 .51455 .52197 .51138 .51536 Mtetra
.71 .633 .769 r
.51138 .51536 .51455 .52197 .52039 .51817 .51721 .51153 Mtetra
.707 .631 .771 r
.51721 .51153 .52039 .51817 .52623 .5145 .52306 .50784 Mtetra
.702 .629 .772 r
.52306 .50784 .52623 .5145 .53207 .51096 .52891 .50427 Mtetra
.698 .627 .773 r
.52891 .50427 .53207 .51096 .53793 .50756 .53477 .50084 Mtetra
.694 .624 .774 r
.53477 .50084 .53793 .50756 .54379 .50428 .54063 .49754 Mtetra
.689 .622 .775 r
.54063 .49754 .54379 .50428 .54966 .50114 .5465 .49438 Mtetra
.685 .619 .777 r
.5465 .49438 .54966 .50114 .55554 .49814 .55239 .49136 Mtetra
.68 .617 .778 r
.55239 .49136 .55554 .49814 .56142 .49528 .55828 .48848 Mtetra
.675 .614 .779 r
.55828 .48848 .56142 .49528 .56732 .49255 .56418 .48574 Mtetra
.67 .612 .781 r
.56418 .48574 .56732 .49255 .57323 .48997 .57009 .48314 Mtetra
.665 .609 .782 r
.57009 .48314 .57323 .48997 .57916 .48753 .57602 .48068 Mtetra
.66 .606 .784 r
.57602 .48068 .57916 .48753 .58509 .48523 .58196 .47837 Mtetra
.655 .604 .785 r
.58196 .47837 .58509 .48523 .59105 .48308 .58791 .47621 Mtetra
.649 .601 .787 r
.58791 .47621 .59105 .48308 .59701 .48107 .59388 .47419 Mtetra
.644 .598 .788 r
.59388 .47419 .59701 .48107 .60299 .47921 .59986 .47231 Mtetra
.638 .595 .79 r
.59986 .47231 .60299 .47921 .60899 .47749 .60586 .47059 Mtetra
.632 .592 .791 r
.60586 .47059 .60899 .47749 .61501 .47591 .61188 .46901 Mtetra
.626 .589 .793 r
.61188 .46901 .61501 .47591 .62104 .47448 .61792 .46757 Mtetra
.62 .586 .794 r
.61792 .46757 .62104 .47448 .62709 .4732 .62397 .46628 Mtetra
.614 .583 .796 r
.62397 .46628 .62709 .4732 .63317 .47206 .63005 .46514 Mtetra
.608 .58 .797 r
.63005 .46514 .63317 .47206 .63926 .47106 .63615 .46414 Mtetra
.601 .577 .799 r
.63615 .46414 .63926 .47106 .64538 .47021 .64226 .46329 Mtetra
.595 .574 .8 r
.64226 .46329 .64538 .47021 .65152 .46949 .6484 .46258 Mtetra
.588 .571 .802 r
.6484 .46258 .65152 .46949 .65768 .46892 .65457 .46201 Mtetra
.582 .568 .803 r
.65457 .46201 .65768 .46892 .66386 .46849 .66076 .46158 Mtetra
.575 .565 .805 r
.66076 .46158 .66386 .46849 .67008 .46819 .66697 .46129 Mtetra
.568 .562 .806 r
.66697 .46129 .67008 .46819 .67631 .46803 .67321 .46114 Mtetra
.562 .559 .808 r
.67321 .46114 .67631 .46803 .68258 .46801 .67948 .46112 Mtetra
.555 .555 .809 r
.67948 .46112 .68258 .46801 .68887 .46812 .68577 .46124 Mtetra
.548 .552 .811 r
.68577 .46124 .68887 .46812 .69519 .46836 .69209 .46149 Mtetra
.541 .549 .812 r
.69209 .46149 .69519 .46836 .70154 .46873 .69845 .46187 Mtetra
.535 .546 .814 r
.69845 .46187 .70154 .46873 .70792 .46922 .70483 .46238 Mtetra
.528 .543 .815 r
.70483 .46238 .70792 .46922 .71433 .46983 .71124 .46301 Mtetra
.521 .54 .816 r
.71124 .46301 .71433 .46983 .72077 .47057 .71768 .46376 Mtetra
.514 .538 .818 r
.71768 .46376 .72077 .47057 .72724 .47142 .72416 .46463 Mtetra
.508 .535 .819 r
.72416 .46463 .72724 .47142 .73375 .47238 .73066 .46562 Mtetra
.501 .532 .821 r
.73066 .46562 .73375 .47238 .74028 .47346 .7372 .46672 Mtetra
.494 .53 .822 r
.7372 .46672 .74028 .47346 .74685 .47463 .74378 .46792 Mtetra
.488 .527 .823 r
.74378 .46792 .74685 .47463 .75346 .47591 .75039 .46923 Mtetra
.482 .525 .825 r
.75039 .46923 .75346 .47591 .7601 .47729 .75703 .47063 Mtetra
.476 .523 .826 r
.75703 .47063 .7601 .47729 .76677 .47876 .76371 .47213 Mtetra
.47 .521 .828 r
.76371 .47213 .76677 .47876 .77348 .48032 .77042 .47372 Mtetra
.464 .519 .829 r
.77042 .47372 .77348 .48032 .78022 .48196 .77717 .47539 Mtetra
.459 .517 .831 r
.77717 .47539 .78022 .48196 .787 .48367 .78395 .47714 Mtetra
.453 .516 .832 r
.78395 .47714 .787 .48367 .79382 .48546 .79077 .47897 Mtetra
.448 .514 .834 r
.79077 .47897 .79382 .48546 .80067 .48732 .79763 .48086 Mtetra
.444 .513 .835 r
.79763 .48086 .80067 .48732 .80755 .48923 .80452 .48281 Mtetra
.439 .512 .837 r
.80452 .48281 .80755 .48923 .81448 .4912 .81145 .48482 Mtetra
.435 .512 .839 r
.81145 .48482 .81448 .4912 .82143 .49321 .81841 .48688 Mtetra
.431 .512 .841 r
.81841 .48688 .82143 .49321 .82843 .49526 .82541 .48898 Mtetra
.428 .512 .842 r
.82541 .48898 .82843 .49526 .83546 .49734 .83245 .49111 Mtetra
.425 .512 .844 r
.83245 .49111 .83546 .49734 .84252 .49945 .83952 .49326 Mtetra
.422 .513 .846 r
.83952 .49326 .84252 .49945 .84961 .50157 .84663 .49544 Mtetra
.42 .514 .849 r
.84663 .49544 .84961 .50157 .85675 .5037 .85377 .49762 Mtetra
.419 .516 .851 r
.85377 .49762 .85675 .5037 .86391 .50582 .86094 .4998 Mtetra
.418 .518 .853 r
.86094 .4998 .86391 .50582 .87111 .50794 .86815 .50198 Mtetra
.417 .52 .856 r
.86815 .50198 .87111 .50794 .87833 .51004 .87538 .50414 Mtetra
.417 .523 .858 r
.87538 .50414 .87833 .51004 .88559 .5121 .88265 .50627 Mtetra
.418 .527 .861 r
.88265 .50627 .88559 .5121 .89288 .51413 .88995 .50836 Mtetra
.419 .531 .864 r
.88995 .50836 .89288 .51413 .90019 .5161 .89728 .5104 Mtetra
.421 .535 .867 r
.89728 .5104 .90019 .5161 .90753 .51801 .90464 .51238 Mtetra
.424 .54 .87 r
.90464 .51238 .90753 .51801 .9149 .51985 .91202 .51429 Mtetra
.427 .545 .873 r
.91202 .51429 .9149 .51985 .92229 .52161 .91942 .51612 Mtetra
.432 .552 .877 r
.91942 .51612 .92229 .52161 .9297 .52327 .92685 .51786 Mtetra
.776 .708 .788 r
.30379 .69176 .30728 .69631 .3131 .69116 .30962 .68652 Mtetra
.777 .706 .785 r
.30962 .68652 .3131 .69116 .31893 .68591 .31546 .68118 Mtetra
.777 .703 .782 r
.31546 .68118 .31893 .68591 .32476 .68057 .3213 .67577 Mtetra
.777 .701 .779 r
.3213 .67577 .32476 .68057 .33059 .67516 .32715 .67027 Mtetra
.777 .699 .777 r
.32715 .67027 .33059 .67516 .33643 .66968 .33301 .66472 Mtetra
.777 .696 .774 r
.33301 .66472 .33643 .66968 .34228 .66415 .33886 .65911 Mtetra
.777 .694 .773 r
.33886 .65911 .34228 .66415 .34812 .65857 .34472 .65346 Mtetra
.776 .692 .771 r
.34472 .65346 .34812 .65857 .35396 .65296 .35057 .64777 Mtetra
.776 .69 .769 r
.35057 .64777 .35396 .65296 .35981 .64732 .35643 .64206 Mtetra
.775 .688 .768 r
.35643 .64206 .35981 .64732 .36565 .64167 .36228 .63633 Mtetra
.774 .686 .767 r
.36228 .63633 .36565 .64167 .3715 .636 .36814 .6306 Mtetra
.773 .684 .765 r
.36814 .6306 .3715 .636 .37734 .63034 .37399 .62487 Mtetra
.772 .682 .765 r
.37399 .62487 .37734 .63034 .38318 .62468 .37984 .61915 Mtetra
.77 .68 .764 r
.37984 .61915 .38318 .62468 .38902 .61904 .38569 .61345 Mtetra
.769 .678 .763 r
.38569 .61345 .38902 .61904 .39486 .61342 .39154 .60777 Mtetra
.767 .677 .763 r
.39154 .60777 .39486 .61342 .4007 .60783 .39739 .60212 Mtetra
.766 .675 .762 r
.39739 .60212 .4007 .60783 .40653 .60228 .40323 .59652 Mtetra
.764 .673 .762 r
.40323 .59652 .40653 .60228 .41237 .59678 .40907 .59096 Mtetra
.762 .671 .762 r
.40907 .59096 .41237 .59678 .4182 .59132 .41491 .58545 Mtetra
.76 .669 .762 r
.41491 .58545 .4182 .59132 .42402 .58593 .42075 .58 Mtetra
.758 .667 .762 r
.42075 .58 .42402 .58593 .42985 .58059 .42658 .57462 Mtetra
.756 .665 .762 r
.42658 .57462 .42985 .58059 .43567 .57533 .43241 .5693 Mtetra
.753 .663 .762 r
.43241 .5693 .43567 .57533 .4415 .57014 .43824 .56407 Mtetra
.751 .662 .762 r
.43824 .56407 .4415 .57014 .44732 .56503 .44407 .55891 Mtetra
.748 .66 .763 r
.44407 .55891 .44732 .56503 .45314 .56 .4499 .55384 Mtetra
.746 .658 .763 r
.4499 .55384 .45314 .56 .45896 .55507 .45572 .54886 Mtetra
.743 .656 .764 r
.45572 .54886 .45896 .55507 .46478 .55023 .46155 .54398 Mtetra
.74 .654 .764 r
.46155 .54398 .46478 .55023 .4706 .54548 .46738 .5392 Mtetra
.737 .652 .765 r
.46738 .5392 .4706 .54548 .47641 .54084 .4732 .53452 Mtetra
.734 .65 .766 r
.4732 .53452 .47641 .54084 .48224 .53631 .47903 .52995 Mtetra
.731 .648 .767 r
.47903 .52995 .48224 .53631 .48806 .53188 .48486 .52549 Mtetra
.727 .646 .767 r
.48486 .52549 .48806 .53188 .49388 .52757 .49069 .52115 Mtetra
.724 .644 .768 r
.49069 .52115 .49388 .52757 .49971 .52338 .49652 .51692 Mtetra
.72 .641 .769 r
.49652 .51692 .49971 .52338 .50554 .51931 .50235 .51282 Mtetra
.716 .639 .77 r
.50235 .51282 .50554 .51931 .51138 .51536 .50819 .50884 Mtetra
.712 .637 .772 r
.50819 .50884 .51138 .51536 .51721 .51153 .51404 .50499 Mtetra
.708 .635 .773 r
.51404 .50499 .51721 .51153 .52306 .50784 .51989 .50127 Mtetra
.704 .632 .774 r
.51989 .50127 .52306 .50784 .52891 .50427 .52574 .49768 Mtetra
.7 .63 .775 r
.52574 .49768 .52891 .50427 .53477 .50084 .5316 .49422 Mtetra
.696 .628 .776 r
.5316 .49422 .53477 .50084 .54063 .49754 .53747 .4909 Mtetra
.691 .625 .778 r
.53747 .4909 .54063 .49754 .5465 .49438 .54335 .48772 Mtetra
.686 .623 .779 r
.54335 .48772 .5465 .49438 .55239 .49136 .54923 .48468 Mtetra
.682 .62 .781 r
.54923 .48468 .55239 .49136 .55828 .48848 .55513 .48178 Mtetra
.677 .618 .782 r
.55513 .48178 .55828 .48848 .56418 .48574 .56103 .47902 Mtetra
.672 .615 .783 r
.56103 .47902 .56418 .48574 .57009 .48314 .56695 .47641 Mtetra
.666 .612 .785 r
.56695 .47641 .57009 .48314 .57602 .48068 .57288 .47394 Mtetra
.661 .61 .786 r
.57288 .47394 .57602 .48068 .58196 .47837 .57882 .47161 Mtetra
.656 .607 .788 r
.57882 .47161 .58196 .47837 .58791 .47621 .58478 .46944 Mtetra
.65 .604 .789 r
.58478 .46944 .58791 .47621 .59388 .47419 .59075 .46741 Mtetra
.644 .601 .791 r
.59075 .46741 .59388 .47419 .59986 .47231 .59673 .46552 Mtetra
.639 .598 .793 r
.59673 .46552 .59986 .47231 .60586 .47059 .60274 .46379 Mtetra
.633 .595 .794 r
.60274 .46379 .60586 .47059 .61188 .46901 .60876 .4622 Mtetra
.626 .592 .796 r
.60876 .4622 .61188 .46901 .61792 .46757 .61479 .46076 Mtetra
.62 .589 .797 r
.61479 .46076 .61792 .46757 .62397 .46628 .62085 .45947 Mtetra
.614 .586 .799 r
.62085 .45947 .62397 .46628 .63005 .46514 .62693 .45832 Mtetra
.608 .583 .801 r
.62693 .45832 .63005 .46514 .63615 .46414 .63303 .45732 Mtetra
.601 .58 .802 r
.63303 .45732 .63615 .46414 .64226 .46329 .63915 .45647 Mtetra
.594 .577 .804 r
.63915 .45647 .64226 .46329 .6484 .46258 .64529 .45576 Mtetra
.588 .574 .805 r
.64529 .45576 .6484 .46258 .65457 .46201 .65146 .45519 Mtetra
.581 .571 .807 r
.65146 .45519 .65457 .46201 .66076 .46158 .65765 .45477 Mtetra
.574 .567 .808 r
.65765 .45477 .66076 .46158 .66697 .46129 .66386 .45449 Mtetra
.567 .564 .81 r
.66386 .45449 .66697 .46129 .67321 .46114 .67011 .45434 Mtetra
.56 .561 .811 r
.67011 .45434 .67321 .46114 .67948 .46112 .67637 .45433 Mtetra
.553 .558 .813 r
.67637 .45433 .67948 .46112 .68577 .46124 .68267 .45446 Mtetra
.546 .555 .814 r
.68267 .45446 .68577 .46124 .69209 .46149 .689 .45472 Mtetra
.539 .551 .816 r
.689 .45472 .69209 .46149 .69845 .46187 .69535 .45512 Mtetra
.532 .548 .817 r
.69535 .45512 .69845 .46187 .70483 .46238 .70173 .45564 Mtetra
.525 .545 .819 r
.70173 .45564 .70483 .46238 .71124 .46301 .70815 .45628 Mtetra
.518 .542 .82 r
.70815 .45628 .71124 .46301 .71768 .46376 .71459 .45705 Mtetra
.511 .539 .821 r
.71459 .45705 .71768 .46376 .72416 .46463 .72107 .45794 Mtetra
.504 .536 .823 r
.72107 .45794 .72416 .46463 .73066 .46562 .72758 .45895 Mtetra
.497 .533 .824 r
.72758 .45895 .73066 .46562 .7372 .46672 .73413 .46006 Mtetra
.491 .531 .825 r
.73413 .46006 .7372 .46672 .74378 .46792 .7407 .46129 Mtetra
.484 .528 .827 r
.7407 .46129 .74378 .46792 .75039 .46923 .74731 .46262 Mtetra
.478 .526 .828 r
.74731 .46262 .75039 .46923 .75703 .47063 .75396 .46405 Mtetra
.471 .523 .83 r
.75396 .46405 .75703 .47063 .76371 .47213 .76064 .46558 Mtetra
.465 .521 .831 r
.76064 .46558 .76371 .47213 .77042 .47372 .76736 .4672 Mtetra
.459 .519 .832 r
.76736 .4672 .77042 .47372 .77717 .47539 .77411 .4689 Mtetra
.453 .517 .834 r
.77411 .4689 .77717 .47539 .78395 .47714 .7809 .47068 Mtetra
.448 .515 .835 r
.7809 .47068 .78395 .47714 .79077 .47897 .78773 .47254 Mtetra
.443 .514 .837 r
.78773 .47254 .79077 .47897 .79763 .48086 .79459 .47447 Mtetra
.438 .513 .838 r
.79459 .47447 .79763 .48086 .80452 .48281 .80149 .47647 Mtetra
.433 .512 .84 r
.80149 .47647 .80452 .48281 .81145 .48482 .80842 .47851 Mtetra
.429 .511 .841 r
.80842 .47851 .81145 .48482 .81841 .48688 .81539 .48061 Mtetra
.425 .511 .843 r
.81539 .48061 .81841 .48688 .82541 .48898 .8224 .48275 Mtetra
.421 .511 .845 r
.8224 .48275 .82541 .48898 .83245 .49111 .82944 .48493 Mtetra
.418 .511 .847 r
.82944 .48493 .83245 .49111 .83952 .49326 .83652 .48713 Mtetra
.416 .512 .849 r
.83652 .48713 .83952 .49326 .84663 .49544 .84364 .48936 Mtetra
.414 .513 .851 r
.84364 .48936 .84663 .49544 .85377 .49762 .85079 .49159 Mtetra
.412 .514 .853 r
.85079 .49159 .85377 .49762 .86094 .4998 .85797 .49383 Mtetra
.411 .516 .855 r
.85797 .49383 .86094 .4998 .86815 .50198 .86519 .49606 Mtetra
.41 .519 .857 r
.86519 .49606 .86815 .50198 .87538 .50414 .87244 .49828 Mtetra
.41 .521 .86 r
.87244 .49828 .87538 .50414 .88265 .50627 .87972 .50047 Mtetra
.411 .525 .863 r
.87972 .50047 .88265 .50627 .88995 .50836 .88703 .50262 Mtetra
.412 .528 .865 r
.88703 .50262 .88995 .50836 .89728 .5104 .89437 .50473 Mtetra
.414 .533 .868 r
.89437 .50473 .89728 .5104 .90464 .51238 .90174 .50678 Mtetra
.417 .538 .871 r
.90174 .50678 .90464 .51238 .91202 .51429 .90913 .50876 Mtetra
.42 .543 .874 r
.90913 .50876 .91202 .51429 .91942 .51612 .91655 .51066 Mtetra
.424 .549 .878 r
.91655 .51066 .91942 .51612 .92685 .51786 .92399 .51247 Mtetra
.778 .71 .787 r
.30028 .68723 .30379 .69176 .30962 .68652 .30613 .68191 Mtetra
.779 .707 .784 r
.30613 .68191 .30962 .68652 .31546 .68118 .31198 .67649 Mtetra
.779 .705 .781 r
.31198 .67649 .31546 .68118 .3213 .67577 .31784 .67099 Mtetra
.78 .703 .779 r
.31784 .67099 .3213 .67577 .32715 .67027 .3237 .66542 Mtetra
.78 .701 .777 r
.3237 .66542 .32715 .67027 .33301 .66472 .32956 .65979 Mtetra
.779 .699 .775 r
.32956 .65979 .33301 .66472 .33886 .65911 .33543 .65411 Mtetra
.779 .697 .773 r
.33543 .65411 .33886 .65911 .34472 .65346 .3413 .64838 Mtetra
.779 .695 .771 r
.3413 .64838 .34472 .65346 .35057 .64777 .34717 .64263 Mtetra
.778 .693 .769 r
.34717 .64263 .35057 .64777 .35643 .64206 .35303 .63685 Mtetra
.777 .691 .768 r
.35303 .63685 .35643 .64206 .36228 .63633 .3589 .63106 Mtetra
.776 .689 .767 r
.3589 .63106 .36228 .63633 .36814 .6306 .36477 .62526 Mtetra
.775 .687 .766 r
.36477 .62526 .36814 .6306 .37399 .62487 .37063 .61947 Mtetra
.774 .685 .765 r
.37063 .61947 .37399 .62487 .37984 .61915 .37649 .61368 Mtetra
.773 .683 .764 r
.37649 .61368 .37984 .61915 .38569 .61345 .38235 .60792 Mtetra
.771 .681 .764 r
.38235 .60792 .38569 .61345 .39154 .60777 .38821 .60218 Mtetra
.77 .679 .763 r
.38821 .60218 .39154 .60777 .39739 .60212 .39407 .59648 Mtetra
.768 .678 .763 r
.39407 .59648 .39739 .60212 .40323 .59652 .39992 .59082 Mtetra
.766 .676 .763 r
.39992 .59082 .40323 .59652 .40907 .59096 .40577 .58521 Mtetra
.764 .674 .763 r
.40577 .58521 .40907 .59096 .41491 .58545 .41162 .57965 Mtetra
.762 .672 .763 r
.41162 .57965 .41491 .58545 .42075 .58 .41746 .57415 Mtetra
.76 .67 .763 r
.41746 .57415 .42075 .58 .42658 .57462 .4233 .56872 Mtetra
.758 .669 .763 r
.4233 .56872 .42658 .57462 .43241 .5693 .42914 .56336 Mtetra
.756 .667 .763 r
.42914 .56336 .43241 .5693 .43824 .56407 .43498 .55808 Mtetra
.753 .665 .764 r
.43498 .55808 .43824 .56407 .44407 .55891 .44082 .55288 Mtetra
.751 .663 .764 r
.44082 .55288 .44407 .55891 .4499 .55384 .44665 .54777 Mtetra
.748 .661 .765 r
.44665 .54777 .4499 .55384 .45572 .54886 .45248 .54275 Mtetra
.745 .659 .765 r
.45248 .54275 .45572 .54886 .46155 .54398 .45832 .53783 Mtetra
.742 .657 .766 r
.45832 .53783 .46155 .54398 .46738 .5392 .46415 .53301 Mtetra
.739 .655 .767 r
.46415 .53301 .46738 .5392 .4732 .53452 .46998 .52829 Mtetra
.736 .653 .767 r
.46998 .52829 .4732 .53452 .47903 .52995 .47581 .52369 Mtetra
.733 .651 .768 r
.47581 .52369 .47903 .52995 .48486 .52549 .48165 .5192 Mtetra
.729 .649 .769 r
.48165 .5192 .48486 .52549 .49069 .52115 .48748 .51482 Mtetra
.726 .647 .77 r
.48748 .51482 .49069 .52115 .49652 .51692 .49332 .51056 Mtetra
.722 .645 .771 r
.49332 .51056 .49652 .51692 .50235 .51282 .49916 .50643 Mtetra
.718 .643 .773 r
.49916 .50643 .50235 .51282 .50819 .50884 .50501 .50242 Mtetra
.715 .641 .774 r
.50501 .50242 .50819 .50884 .51404 .50499 .51085 .49855 Mtetra
.71 .638 .775 r
.51085 .49855 .51404 .50499 .51989 .50127 .51671 .4948 Mtetra
.706 .636 .776 r
.51671 .4948 .51989 .50127 .52574 .49768 .52257 .49118 Mtetra
.702 .634 .778 r
.52257 .49118 .52574 .49768 .5316 .49422 .52843 .48771 Mtetra
.697 .631 .779 r
.52843 .48771 .5316 .49422 .53747 .4909 .5343 .48436 Mtetra
.693 .629 .78 r
.5343 .48436 .53747 .4909 .54335 .48772 .54018 .48116 Mtetra
.688 .627 .782 r
.54018 .48116 .54335 .48772 .54923 .48468 .54607 .4781 Mtetra
.683 .624 .783 r
.54607 .4781 .54923 .48468 .55513 .48178 .55197 .47518 Mtetra
.678 .621 .785 r
.55197 .47518 .55513 .48178 .56103 .47902 .55788 .47241 Mtetra
.673 .619 .786 r
.55788 .47241 .56103 .47902 .56695 .47641 .5638 .46978 Mtetra
.668 .616 .788 r
.5638 .46978 .56695 .47641 .57288 .47394 .56973 .4673 Mtetra
.662 .613 .789 r
.56973 .4673 .57288 .47394 .57882 .47161 .57568 .46496 Mtetra
.657 .611 .791 r
.57568 .46496 .57882 .47161 .58478 .46944 .58164 .46277 Mtetra
.651 .608 .793 r
.58164 .46277 .58478 .46944 .59075 .46741 .58761 .46073 Mtetra
.645 .605 .794 r
.58761 .46073 .59075 .46741 .59673 .46552 .5936 .45884 Mtetra
.639 .602 .796 r
.5936 .45884 .59673 .46552 .60274 .46379 .5996 .4571 Mtetra
.633 .599 .798 r
.5996 .4571 .60274 .46379 .60876 .4622 .60563 .45551 Mtetra
.627 .596 .799 r
.60563 .45551 .60876 .4622 .61479 .46076 .61167 .45406 Mtetra
.62 .593 .801 r
.61167 .45406 .61479 .46076 .62085 .45947 .61773 .45276 Mtetra
.614 .59 .802 r
.61773 .45276 .62085 .45947 .62693 .45832 .62381 .45161 Mtetra
.607 .587 .804 r
.62381 .45161 .62693 .45832 .63303 .45732 .62991 .45061 Mtetra
.601 .583 .806 r
.62991 .45061 .63303 .45732 .63915 .45647 .63603 .44976 Mtetra
.594 .58 .807 r
.63603 .44976 .63915 .45647 .64529 .45576 .64218 .44905 Mtetra
.587 .577 .809 r
.64218 .44905 .64529 .45576 .65146 .45519 .64834 .44848 Mtetra
.58 .573 .81 r
.64834 .44848 .65146 .45519 .65765 .45477 .65454 .44806 Mtetra
.573 .57 .812 r
.65454 .44806 .65765 .45477 .66386 .45449 .66075 .44778 Mtetra
.566 .567 .814 r
.66075 .44778 .66386 .45449 .67011 .45434 .667 .44765 Mtetra
.559 .564 .815 r
.667 .44765 .67011 .45434 .67637 .45433 .67327 .44765 Mtetra
.551 .56 .817 r
.67327 .44765 .67637 .45433 .68267 .45446 .67957 .44778 Mtetra
.544 .557 .818 r
.67957 .44778 .68267 .45446 .689 .45472 .6859 .44806 Mtetra
.537 .554 .819 r
.6859 .44806 .689 .45472 .69535 .45512 .69225 .44846 Mtetra
.53 .55 .821 r
.69225 .44846 .69535 .45512 .70173 .45564 .69864 .44899 Mtetra
.522 .547 .822 r
.69864 .44899 .70173 .45564 .70815 .45628 .70506 .44965 Mtetra
.515 .544 .824 r
.70506 .44965 .70815 .45628 .71459 .45705 .7115 .45044 Mtetra
.508 .541 .825 r
.7115 .45044 .71459 .45705 .72107 .45794 .71799 .45134 Mtetra
.501 .538 .826 r
.71799 .45134 .72107 .45794 .72758 .45895 .7245 .45237 Mtetra
.494 .535 .828 r
.7245 .45237 .72758 .45895 .73413 .46006 .73105 .4535 Mtetra
.487 .532 .829 r
.73105 .4535 .73413 .46006 .7407 .46129 .73763 .45475 Mtetra
.48 .529 .83 r
.73763 .45475 .7407 .46129 .74731 .46262 .74424 .4561 Mtetra
.473 .526 .832 r
.74424 .4561 .74731 .46262 .75396 .46405 .75089 .45756 Mtetra
.467 .524 .833 r
.75089 .45756 .75396 .46405 .76064 .46558 .75758 .45911 Mtetra
.46 .522 .834 r
.75758 .45911 .76064 .46558 .76736 .4672 .7643 .46076 Mtetra
.454 .519 .836 r
.7643 .46076 .76736 .4672 .77411 .4689 .77106 .46249 Mtetra
.448 .517 .837 r
.77106 .46249 .77411 .4689 .7809 .47068 .77785 .46431 Mtetra
.442 .516 .838 r
.77785 .46431 .7809 .47068 .78773 .47254 .78468 .4662 Mtetra
.437 .514 .84 r
.78468 .4662 .78773 .47254 .79459 .47447 .79155 .46816 Mtetra
.432 .513 .841 r
.79155 .46816 .79459 .47447 .80149 .47647 .79845 .47019 Mtetra
.427 .512 .843 r
.79845 .47019 .80149 .47647 .80842 .47851 .80539 .47228 Mtetra
.423 .511 .844 r
.80539 .47228 .80842 .47851 .81539 .48061 .81237 .47442 Mtetra
.419 .51 .846 r
.81237 .47442 .81539 .48061 .8224 .48275 .81939 .4766 Mtetra
.415 .51 .847 r
.81939 .4766 .8224 .48275 .82944 .48493 .82644 .47882 Mtetra
.412 .51 .849 r
.82644 .47882 .82944 .48493 .83652 .48713 .83352 .48107 Mtetra
.409 .511 .851 r
.83352 .48107 .83652 .48713 .84364 .48936 .84065 .48334 Mtetra
.407 .512 .853 r
.84065 .48334 .84364 .48936 .85079 .49159 .8478 .48562 Mtetra
.405 .513 .855 r
.8478 .48562 .85079 .49159 .85797 .49383 .855 .48791 Mtetra
.404 .515 .857 r
.855 .48791 .85797 .49383 .86519 .49606 .86222 .4902 Mtetra
.403 .517 .859 r
.86222 .4902 .86519 .49606 .87244 .49828 .86948 .49247 Mtetra
.403 .52 .862 r
.86948 .49247 .87244 .49828 .87972 .50047 .87677 .49471 Mtetra
.403 .523 .864 r
.87677 .49471 .87972 .50047 .88703 .50262 .8841 .49693 Mtetra
.405 .526 .867 r
.8841 .49693 .88703 .50262 .89437 .50473 .89145 .49909 Mtetra
.407 .531 .87 r
.89145 .49909 .89437 .50473 .90174 .50678 .89883 .50121 Mtetra
.409 .535 .873 r
.89883 .50121 .90174 .50678 .90913 .50876 .90624 .50325 Mtetra
.413 .541 .876 r
.90624 .50325 .90913 .50876 .91655 .51066 .91367 .50522 Mtetra
.417 .547 .879 r
.91367 .50522 .91655 .51066 .92399 .51247 .92113 .5071 Mtetra
.781 .712 .787 r
.29676 .68273 .30028 .68723 .30613 .68191 .30262 .67733 Mtetra
.781 .709 .784 r
.30262 .67733 .30613 .68191 .31198 .67649 .30849 .67183 Mtetra
.782 .707 .781 r
.30849 .67183 .31198 .67649 .31784 .67099 .31436 .66626 Mtetra
.782 .705 .779 r
.31436 .66626 .31784 .67099 .3237 .66542 .32023 .66062 Mtetra
.782 .703 .777 r
.32023 .66062 .3237 .66542 .32956 .65979 .32611 .65491 Mtetra
.782 .701 .775 r
.32611 .65491 .32956 .65979 .33543 .65411 .33199 .64916 Mtetra
.781 .699 .773 r
.33199 .64916 .33543 .65411 .3413 .64838 .33787 .64337 Mtetra
.781 .697 .771 r
.33787 .64337 .3413 .64838 .34717 .64263 .34375 .63754 Mtetra
.78 .695 .77 r
.34375 .63754 .34717 .64263 .35303 .63685 .34963 .6317 Mtetra
.779 .693 .769 r
.34963 .6317 .35303 .63685 .3589 .63106 .3555 .62584 Mtetra
.779 .691 .768 r
.3555 .62584 .3589 .63106 .36477 .62526 .36138 .61998 Mtetra
.778 .69 .767 r
.36138 .61998 .36477 .62526 .37063 .61947 .36726 .61413 Mtetra
.776 .688 .766 r
.36726 .61413 .37063 .61947 .37649 .61368 .37313 .60829 Mtetra
.775 .686 .765 r
.37313 .60829 .37649 .61368 .38235 .60792 .379 .60247 Mtetra
.774 .684 .765 r
.379 .60247 .38235 .60792 .38821 .60218 .38487 .59667 Mtetra
.772 .682 .764 r
.38487 .59667 .38821 .60218 .39407 .59648 .39073 .59092 Mtetra
.771 .681 .764 r
.39073 .59092 .39407 .59648 .39992 .59082 .39659 .5852 Mtetra
.769 .679 .764 r
.39659 .5852 .39992 .59082 .40577 .58521 .40245 .57954 Mtetra
.767 .677 .764 r
.40245 .57954 .40577 .58521 .41162 .57965 .40831 .57393 Mtetra
.765 .675 .764 r
.40831 .57393 .41162 .57965 .41746 .57415 .41416 .56839 Mtetra
.763 .674 .764 r
.41416 .56839 .41746 .57415 .4233 .56872 .42001 .56291 Mtetra
.761 .672 .764 r
.42001 .56291 .4233 .56872 .42914 .56336 .42586 .5575 Mtetra
.758 .67 .765 r
.42586 .5575 .42914 .56336 .43498 .55808 .43171 .55218 Mtetra
.756 .668 .765 r
.43171 .55218 .43498 .55808 .44082 .55288 .43755 .54694 Mtetra
.753 .667 .766 r
.43755 .54694 .44082 .55288 .44665 .54777 .44339 .54179 Mtetra
.751 .665 .766 r
.44339 .54179 .44665 .54777 .45248 .54275 .44923 .53673 Mtetra
.748 .663 .767 r
.44923 .53673 .45248 .54275 .45832 .53783 .45507 .53177 Mtetra
.745 .661 .768 r
.45507 .53177 .45832 .53783 .46415 .53301 .46091 .52691 Mtetra
.742 .659 .768 r
.46091 .52691 .46415 .53301 .46998 .52829 .46675 .52216 Mtetra
.739 .657 .769 r
.46675 .52216 .46998 .52829 .47581 .52369 .47259 .51752 Mtetra
.735 .655 .77 r
.47259 .51752 .47581 .52369 .48165 .5192 .47843 .513 Mtetra
.732 .653 .771 r
.47843 .513 .48165 .5192 .48748 .51482 .48427 .50859 Mtetra
.728 .651 .772 r
.48427 .50859 .48748 .51482 .49332 .51056 .49011 .50431 Mtetra
.724 .649 .774 r
.49011 .50431 .49332 .51056 .49916 .50643 .49596 .50015 Mtetra
.721 .647 .775 r
.49596 .50015 .49916 .50643 .50501 .50242 .50181 .49611 Mtetra
.717 .645 .776 r
.50181 .49611 .50501 .50242 .51085 .49855 .50766 .49221 Mtetra
.713 .642 .777 r
.50766 .49221 .51085 .49855 .51671 .4948 .51352 .48844 Mtetra
.708 .64 .779 r
.51352 .48844 .51671 .4948 .52257 .49118 .51938 .4848 Mtetra
.704 .638 .78 r
.51938 .4848 .52257 .49118 .52843 .48771 .52525 .4813 Mtetra
.699 .635 .782 r
.52525 .4813 .52843 .48771 .5343 .48436 .53113 .47794 Mtetra
.695 .633 .783 r
.53113 .47794 .5343 .48436 .54018 .48116 .53702 .47471 Mtetra
.69 .631 .785 r
.53702 .47471 .54018 .48116 .54607 .4781 .54291 .47164 Mtetra
.685 .628 .786 r
.54291 .47164 .54607 .4781 .55197 .47518 .54881 .4687 Mtetra
.68 .625 .788 r
.54881 .4687 .55197 .47518 .55788 .47241 .55472 .46591 Mtetra
.675 .623 .789 r
.55472 .46591 .55788 .47241 .5638 .46978 .56065 .46327 Mtetra
.669 .62 .791 r
.56065 .46327 .5638 .46978 .56973 .4673 .56658 .46077 Mtetra
.664 .617 .793 r
.56658 .46077 .56973 .4673 .57568 .46496 .57253 .45842 Mtetra
.658 .615 .794 r
.57253 .45842 .57568 .46496 .58164 .46277 .57849 .45622 Mtetra
.652 .612 .796 r
.57849 .45622 .58164 .46277 .58761 .46073 .58447 .45417 Mtetra
.646 .609 .798 r
.58447 .45417 .58761 .46073 .5936 .45884 .59046 .45227 Mtetra
.64 .606 .799 r
.59046 .45227 .5936 .45884 .5996 .4571 .59647 .45052 Mtetra
.634 .603 .801 r
.59647 .45052 .5996 .4571 .60563 .45551 .60249 .44892 Mtetra
.627 .6 .803 r
.60249 .44892 .60563 .45551 .61167 .45406 .60854 .44747 Mtetra
.621 .596 .804 r
.60854 .44747 .61167 .45406 .61773 .45276 .6146 .44617 Mtetra
.614 .593 .806 r
.6146 .44617 .61773 .45276 .62381 .45161 .62068 .44501 Mtetra
.607 .59 .808 r
.62068 .44501 .62381 .45161 .62991 .45061 .62679 .44401 Mtetra
.6 .587 .809 r
.62679 .44401 .62991 .45061 .63603 .44976 .63291 .44316 Mtetra
.593 .583 .811 r
.63291 .44316 .63603 .44976 .64218 .44905 .63906 .44245 Mtetra
.586 .58 .813 r
.63906 .44245 .64218 .44905 .64834 .44848 .64523 .44188 Mtetra
.579 .577 .814 r
.64523 .44188 .64834 .44848 .65454 .44806 .65142 .44147 Mtetra
.572 .573 .816 r
.65142 .44147 .65454 .44806 .66075 .44778 .65764 .44119 Mtetra
.564 .57 .817 r
.65764 .44119 .66075 .44778 .667 .44765 .66389 .44106 Mtetra
.557 .566 .819 r
.66389 .44106 .667 .44765 .67327 .44765 .67016 .44106 Mtetra
.549 .563 .82 r
.67016 .44106 .67327 .44765 .67957 .44778 .67647 .44121 Mtetra
.542 .559 .822 r
.67647 .44121 .67957 .44778 .6859 .44806 .6828 .44149 Mtetra
.534 .556 .823 r
.6828 .44149 .6859 .44806 .69225 .44846 .68915 .4419 Mtetra
.527 .553 .825 r
.68915 .4419 .69225 .44846 .69864 .44899 .69554 .44245 Mtetra
.519 .549 .826 r
.69554 .44245 .69864 .44899 .70506 .44965 .70196 .44312 Mtetra
.512 .546 .828 r
.70196 .44312 .70506 .44965 .7115 .45044 .70842 .44392 Mtetra
.504 .543 .829 r
.70842 .44392 .7115 .45044 .71799 .45134 .7149 .44484 Mtetra
.497 .539 .83 r
.7149 .44484 .71799 .45134 .7245 .45237 .72142 .44588 Mtetra
.49 .536 .831 r
.72142 .44588 .7245 .45237 .73105 .4535 .72797 .44704 Mtetra
.482 .533 .833 r
.72797 .44704 .73105 .4535 .73763 .45475 .73455 .44831 Mtetra
.475 .53 .834 r
.73455 .44831 .73763 .45475 .74424 .4561 .74117 .44968 Mtetra
.468 .527 .835 r
.74117 .44968 .74424 .4561 .75089 .45756 .74782 .45116 Mtetra
.462 .525 .837 r
.74782 .45116 .75089 .45756 .75758 .45911 .75451 .45274 Mtetra
.455 .522 .838 r
.75451 .45274 .75758 .45911 .7643 .46076 .76124 .45441 Mtetra
.449 .52 .839 r
.76124 .45441 .7643 .46076 .77106 .46249 .768 .45617 Mtetra
.443 .518 .84 r
.768 .45617 .77106 .46249 .77785 .46431 .7748 .45801 Mtetra
.437 .516 .842 r
.7748 .45801 .77785 .46431 .78468 .4662 .78164 .45994 Mtetra
.431 .514 .843 r
.78164 .45994 .78468 .4662 .79155 .46816 .78851 .46193 Mtetra
.426 .513 .844 r
.78851 .46193 .79155 .46816 .79845 .47019 .79542 .46399 Mtetra
.421 .511 .846 r
.79542 .46399 .79845 .47019 .80539 .47228 .80236 .46612 Mtetra
.416 .51 .847 r
.80236 .46612 .80539 .47228 .81237 .47442 .80935 .46829 Mtetra
.412 .51 .849 r
.80935 .46829 .81237 .47442 .81939 .4766 .81637 .47051 Mtetra
.408 .51 .85 r
.81637 .47051 .81939 .4766 .82644 .47882 .82343 .47277 Mtetra
.405 .51 .852 r
.82343 .47277 .82644 .47882 .83352 .48107 .83052 .47507 Mtetra
.402 .51 .854 r
.83052 .47507 .83352 .48107 .84065 .48334 .83765 .47738 Mtetra
.399 .511 .855 r
.83765 .47738 .84065 .48334 .8478 .48562 .84482 .47971 Mtetra
.398 .512 .857 r
.84482 .47971 .8478 .48562 .855 .48791 .85202 .48205 Mtetra
.396 .514 .859 r
.85202 .48205 .855 .48791 .86222 .4902 .85926 .48438 Mtetra
.396 .516 .862 r
.85926 .48438 .86222 .4902 .86948 .49247 .86653 .48671 Mtetra
.395 .518 .864 r
.86653 .48671 .86948 .49247 .87677 .49471 .87383 .48901 Mtetra
.396 .521 .866 r
.87383 .48901 .87677 .49471 .8841 .49693 .88117 .49128 Mtetra
.397 .525 .869 r
.88117 .49128 .8841 .49693 .89145 .49909 .88853 .4935 Mtetra
.399 .529 .871 r
.88853 .4935 .89145 .49909 .89883 .50121 .89593 .49568 Mtetra
.402 .533 .874 r
.89593 .49568 .89883 .50121 .90624 .50325 .90335 .49778 Mtetra
.405 .539 .877 r
.90335 .49778 .90624 .50325 .91367 .50522 .9108 .49982 Mtetra
.409 .544 .88 r
.9108 .49982 .91367 .50522 .92113 .5071 .91827 .50176 Mtetra
.783 .714 .787 r
.29323 .67826 .29676 .68273 .30262 .67733 .2991 .67279 Mtetra
.784 .711 .784 r
.2991 .67279 .30262 .67733 .30849 .67183 .30498 .66722 Mtetra
.784 .709 .781 r
.30498 .66722 .30849 .67183 .31436 .66626 .31086 .66157 Mtetra
.784 .707 .779 r
.31086 .66157 .31436 .66626 .32023 .66062 .31675 .65586 Mtetra
.784 .705 .777 r
.31675 .65586 .32023 .66062 .32611 .65491 .32264 .65008 Mtetra
.784 .703 .775 r
.32264 .65008 .32611 .65491 .33199 .64916 .32853 .64426 Mtetra
.784 .701 .773 r
.32853 .64426 .33199 .64916 .33787 .64337 .33442 .6384 Mtetra
.783 .7 .772 r
.33442 .6384 .33787 .64337 .34375 .63754 .34032 .63251 Mtetra
.783 .698 .77 r
.34032 .63251 .34375 .63754 .34963 .6317 .34621 .62661 Mtetra
.782 .696 .769 r
.34621 .62661 .34963 .6317 .3555 .62584 .3521 .62069 Mtetra
.781 .694 .768 r
.3521 .62069 .3555 .62584 .36138 .61998 .35798 .61477 Mtetra
.78 .692 .767 r
.35798 .61477 .36138 .61998 .36726 .61413 .36387 .60886 Mtetra
.779 .691 .767 r
.36387 .60886 .36726 .61413 .37313 .60829 .36975 .60296 Mtetra
.778 .689 .766 r
.36975 .60296 .37313 .60829 .379 .60247 .37563 .59708 Mtetra
.776 .687 .766 r
.37563 .59708 .379 .60247 .38487 .59667 .38151 .59124 Mtetra
.775 .686 .765 r
.38151 .59124 .38487 .59667 .39073 .59092 .38739 .58543 Mtetra
.773 .684 .765 r
.38739 .58543 .39073 .59092 .39659 .5852 .39326 .57967 Mtetra
.771 .682 .765 r
.39326 .57967 .39659 .5852 .40245 .57954 .39913 .57396 Mtetra
.769 .681 .765 r
.39913 .57396 .40245 .57954 .40831 .57393 .40499 .5683 Mtetra
.767 .679 .765 r
.40499 .5683 .40831 .57393 .41416 .56839 .41085 .56271 Mtetra
.765 .677 .765 r
.41085 .56271 .41416 .56839 .42001 .56291 .41671 .55719 Mtetra
.763 .675 .766 r
.41671 .55719 .42001 .56291 .42586 .5575 .42257 .55174 Mtetra
.761 .674 .766 r
.42257 .55174 .42586 .5575 .43171 .55218 .42842 .54637 Mtetra
.758 .672 .767 r
.42842 .54637 .43171 .55218 .43755 .54694 .43427 .54109 Mtetra
.756 .67 .767 r
.43427 .54109 .43755 .54694 .44339 .54179 .44012 .5359 Mtetra
.753 .668 .768 r
.44012 .5359 .44339 .54179 .44923 .53673 .44597 .5308 Mtetra
.75 .667 .769 r
.44597 .5308 .44923 .53673 .45507 .53177 .45182 .52581 Mtetra
.747 .665 .769 r
.45182 .52581 .45507 .53177 .46091 .52691 .45766 .52092 Mtetra
.744 .663 .77 r
.45766 .52092 .46091 .52691 .46675 .52216 .46351 .51613 Mtetra
.741 .661 .771 r
.46351 .51613 .46675 .52216 .47259 .51752 .46935 .51146 Mtetra
.738 .659 .772 r
.46935 .51146 .47259 .51752 .47843 .513 .4752 .50691 Mtetra
.734 .657 .773 r
.4752 .50691 .47843 .513 .48427 .50859 .48105 .50247 Mtetra
.731 .655 .775 r
.48105 .50247 .48427 .50859 .49011 .50431 .4869 .49816 Mtetra
.727 .653 .776 r
.4869 .49816 .49011 .50431 .49596 .50015 .49275 .49397 Mtetra
.723 .651 .777 r
.49275 .49397 .49596 .50015 .50181 .49611 .4986 .48991 Mtetra
.719 .649 .778 r
.4986 .48991 .50181 .49611 .50766 .49221 .50446 .48598 Mtetra
.715 .647 .78 r
.50446 .48598 .50766 .49221 .51352 .48844 .51033 .48218 Mtetra
.71 .644 .781 r
.51033 .48218 .51352 .48844 .51938 .4848 .5162 .47852 Mtetra
.706 .642 .783 r
.5162 .47852 .51938 .4848 .52525 .4813 .52207 .475 Mtetra
.701 .64 .784 r
.52207 .475 .52525 .4813 .53113 .47794 .52795 .47162 Mtetra
.697 .637 .786 r
.52795 .47162 .53113 .47794 .53702 .47471 .53384 .46838 Mtetra
.692 .635 .788 r
.53384 .46838 .53702 .47471 .54291 .47164 .53974 .46528 Mtetra
.687 .632 .789 r
.53974 .46528 .54291 .47164 .54881 .4687 .54564 .46233 Mtetra
.681 .63 .791 r
.54564 .46233 .54881 .4687 .55472 .46591 .55156 .45952 Mtetra
.676 .627 .793 r
.55156 .45952 .55472 .46591 .56065 .46327 .55749 .45687 Mtetra
.67 .624 .794 r
.55749 .45687 .56065 .46327 .56658 .46077 .56343 .45436 Mtetra
.665 .621 .796 r
.56343 .45436 .56658 .46077 .57253 .45842 .56938 .452 Mtetra
.659 .619 .798 r
.56938 .452 .57253 .45842 .57849 .45622 .57534 .44978 Mtetra
.653 .616 .799 r
.57534 .44978 .57849 .45622 .58447 .45417 .58132 .44772 Mtetra
.647 .613 .801 r
.58132 .44772 .58447 .45417 .59046 .45227 .58732 .44581 Mtetra
.641 .61 .803 r
.58732 .44581 .59046 .45227 .59647 .45052 .59333 .44406 Mtetra
.634 .607 .805 r
.59333 .44406 .59647 .45052 .60249 .44892 .59936 .44245 Mtetra
.628 .603 .807 r
.59936 .44245 .60249 .44892 .60854 .44747 .6054 .44099 Mtetra
.621 .6 .808 r
.6054 .44099 .60854 .44747 .6146 .44617 .61147 .43968 Mtetra
.614 .597 .81 r
.61147 .43968 .6146 .44617 .62068 .44501 .61755 .43853 Mtetra
.607 .594 .812 r
.61755 .43853 .62068 .44501 .62679 .44401 .62366 .43752 Mtetra
.6 .59 .813 r
.62366 .43752 .62679 .44401 .63291 .44316 .62979 .43667 Mtetra
.593 .587 .815 r
.62979 .43667 .63291 .44316 .63906 .44245 .63594 .43596 Mtetra
.585 .583 .817 r
.63594 .43596 .63906 .44245 .64523 .44188 .64211 .4354 Mtetra
.578 .58 .818 r
.64211 .4354 .64523 .44188 .65142 .44147 .64831 .43498 Mtetra
.57 .576 .82 r
.64831 .43498 .65142 .44147 .65764 .44119 .65453 .43471 Mtetra
.563 .573 .822 r
.65453 .43471 .65764 .44119 .66389 .44106 .66078 .43458 Mtetra
.555 .569 .823 r
.66078 .43458 .66389 .44106 .67016 .44106 .66706 .43459 Mtetra
.547 .566 .825 r
.66706 .43459 .67016 .44106 .67647 .44121 .67336 .43474 Mtetra
.54 .562 .826 r
.67336 .43474 .67647 .44121 .6828 .44149 .67969 .43503 Mtetra
.532 .559 .828 r
.67969 .43503 .6828 .44149 .68915 .4419 .68606 .43546 Mtetra
.524 .555 .829 r
.68606 .43546 .68915 .4419 .69554 .44245 .69245 .43601 Mtetra
.516 .551 .83 r
.69245 .43601 .69554 .44245 .70196 .44312 .69887 .4367 Mtetra
.509 .548 .832 r
.69887 .4367 .70196 .44312 .70842 .44392 .70533 .43751 Mtetra
.501 .545 .833 r
.70533 .43751 .70842 .44392 .7149 .44484 .71181 .43845 Mtetra
.493 .541 .834 r
.71181 .43845 .7149 .44484 .72142 .44588 .71833 .4395 Mtetra
.486 .538 .836 r
.71833 .4395 .72142 .44588 .72797 .44704 .72489 .44067 Mtetra
.478 .535 .837 r
.72489 .44067 .72797 .44704 .73455 .44831 .73147 .44196 Mtetra
.471 .532 .838 r
.73147 .44196 .73455 .44831 .74117 .44968 .7381 .44335 Mtetra
.464 .529 .839 r
.7381 .44335 .74117 .44968 .74782 .45116 .74475 .44485 Mtetra
.457 .526 .84 r
.74475 .44485 .74782 .45116 .75451 .45274 .75145 .44645 Mtetra
.45 .523 .841 r
.75145 .44645 .75451 .45274 .76124 .45441 .75818 .44815 Mtetra
.443 .521 .843 r
.75818 .44815 .76124 .45441 .768 .45617 .76494 .44994 Mtetra
.437 .518 .844 r
.76494 .44994 .768 .45617 .7748 .45801 .77175 .45181 Mtetra
.431 .516 .845 r
.77175 .45181 .7748 .45801 .78164 .45994 .77859 .45376 Mtetra
.425 .514 .846 r
.77859 .45376 .78164 .45994 .78851 .46193 .78547 .45579 Mtetra
.419 .513 .847 r
.78547 .45579 .78851 .46193 .79542 .46399 .79238 .45788 Mtetra
.414 .511 .849 r
.79238 .45788 .79542 .46399 .80236 .46612 .79934 .46003 Mtetra
.409 .51 .85 r
.79934 .46003 .80236 .46612 .80935 .46829 .80633 .46224 Mtetra
.405 .509 .852 r
.80633 .46224 .80935 .46829 .81637 .47051 .81335 .4645 Mtetra
.401 .509 .853 r
.81335 .4645 .81637 .47051 .82343 .47277 .82042 .4668 Mtetra
.398 .509 .855 r
.82042 .4668 .82343 .47277 .83052 .47507 .82752 .46913 Mtetra
.395 .509 .856 r
.82752 .46913 .83052 .47507 .83765 .47738 .83466 .47149 Mtetra
.392 .51 .858 r
.83466 .47149 .83765 .47738 .84482 .47971 .84184 .47387 Mtetra
.39 .511 .86 r
.84184 .47387 .84482 .47971 .85202 .48205 .84905 .47625 Mtetra
.389 .512 .862 r
.84905 .47625 .85202 .48205 .85926 .48438 .85629 .47863 Mtetra
.388 .514 .864 r
.85629 .47863 .85926 .48438 .86653 .48671 .86357 .481 Mtetra
.388 .517 .866 r
.86357 .481 .86653 .48671 .87383 .48901 .87089 .48335 Mtetra
.388 .52 .868 r
.87089 .48335 .87383 .48901 .88117 .49128 .87823 .48567 Mtetra
.389 .523 .871 r
.87823 .48567 .88117 .49128 .88853 .4935 .88561 .48796 Mtetra
.391 .527 .873 r
.88561 .48796 .88853 .4935 .89593 .49568 .89302 .49019 Mtetra
.394 .531 .876 r
.89302 .49019 .89593 .49568 .90335 .49778 .90045 .49235 Mtetra
.397 .537 .879 r
.90045 .49235 .90335 .49778 .9108 .49982 .90791 .49444 Mtetra
.402 .542 .882 r
.90791 .49444 .9108 .49982 .91827 .50176 .9154 .49645 Mtetra
.785 .716 .787 r
.28968 .67383 .29323 .67826 .2991 .67279 .29557 .66828 Mtetra
.786 .714 .784 r
.29557 .66828 .2991 .67279 .30498 .66722 .30146 .66265 Mtetra
.786 .712 .781 r
.30146 .66265 .30498 .66722 .31086 .66157 .30736 .65693 Mtetra
.786 .71 .779 r
.30736 .65693 .31086 .66157 .31675 .65586 .31326 .65115 Mtetra
.787 .708 .777 r
.31326 .65115 .31675 .65586 .32264 .65008 .31916 .64531 Mtetra
.786 .706 .775 r
.31916 .64531 .32264 .65008 .32853 .64426 .32506 .63942 Mtetra
.786 .704 .774 r
.32506 .63942 .32853 .64426 .33442 .6384 .33097 .6335 Mtetra
.786 .702 .772 r
.33097 .6335 .33442 .6384 .34032 .63251 .33687 .62755 Mtetra
.785 .701 .771 r
.33687 .62755 .34032 .63251 .34621 .62661 .34277 .62158 Mtetra
.784 .699 .77 r
.34277 .62158 .34621 .62661 .3521 .62069 .34867 .61561 Mtetra
.783 .697 .769 r
.34867 .61561 .3521 .62069 .35798 .61477 .35457 .60963 Mtetra
.782 .695 .768 r
.35457 .60963 .35798 .61477 .36387 .60886 .36047 .60366 Mtetra
.781 .694 .767 r
.36047 .60366 .36387 .60886 .36975 .60296 .36636 .59771 Mtetra
.78 .692 .767 r
.36636 .59771 .36975 .60296 .37563 .59708 .37226 .59178 Mtetra
.779 .691 .767 r
.37226 .59178 .37563 .59708 .38151 .59124 .37814 .58589 Mtetra
.777 .689 .766 r
.37814 .58589 .38151 .59124 .38739 .58543 .38403 .58003 Mtetra
.776 .687 .766 r
.38403 .58003 .38739 .58543 .39326 .57967 .38991 .57422 Mtetra
.774 .686 .766 r
.38991 .57422 .39326 .57967 .39913 .57396 .39579 .56846 Mtetra
.772 .684 .766 r
.39579 .56846 .39913 .57396 .40499 .5683 .40166 .56276 Mtetra
.77 .682 .766 r
.40166 .56276 .40499 .5683 .41085 .56271 .40753 .55712 Mtetra
.768 .681 .767 r
.40753 .55712 .41085 .56271 .41671 .55719 .4134 .55156 Mtetra
.766 .679 .767 r
.4134 .55156 .41671 .55719 .42257 .55174 .41927 .54607 Mtetra
.763 .677 .768 r
.41927 .54607 .42257 .55174 .42842 .54637 .42513 .54066 Mtetra
.761 .676 .768 r
.42513 .54066 .42842 .54637 .43427 .54109 .43099 .53534 Mtetra
.758 .674 .769 r
.43099 .53534 .43427 .54109 .44012 .5359 .43684 .53011 Mtetra
.756 .672 .77 r
.43684 .53011 .44012 .5359 .44597 .5308 .4427 .52498 Mtetra
.753 .671 .77 r
.4427 .52498 .44597 .5308 .45182 .52581 .44855 .51995 Mtetra
.75 .669 .771 r
.44855 .51995 .45182 .52581 .45766 .52092 .45441 .51503 Mtetra
.747 .667 .772 r
.45441 .51503 .45766 .52092 .46351 .51613 .46026 .51021 Mtetra
.743 .665 .773 r
.46026 .51021 .46351 .51613 .46935 .51146 .46611 .50551 Mtetra
.74 .663 .775 r
.46611 .50551 .46935 .51146 .4752 .50691 .47196 .50092 Mtetra
.737 .661 .776 r
.47196 .50092 .4752 .50691 .48105 .50247 .47782 .49646 Mtetra
.733 .659 .777 r
.47782 .49646 .48105 .50247 .4869 .49816 .48367 .49212 Mtetra
.729 .657 .778 r
.48367 .49212 .4869 .49816 .49275 .49397 .48953 .4879 Mtetra
.725 .655 .78 r
.48953 .4879 .49275 .49397 .4986 .48991 .49539 .48382 Mtetra
.721 .653 .781 r
.49539 .48382 .4986 .48991 .50446 .48598 .50126 .47986 Mtetra
.717 .651 .783 r
.50126 .47986 .50446 .48598 .51033 .48218 .50712 .47604 Mtetra
.713 .649 .784 r
.50712 .47604 .51033 .48218 .5162 .47852 .513 .47236 Mtetra
.708 .646 .786 r
.513 .47236 .5162 .47852 .52207 .475 .51888 .46882 Mtetra
.703 .644 .787 r
.51888 .46882 .52207 .475 .52795 .47162 .52476 .46542 Mtetra
.699 .642 .789 r
.52476 .46542 .52795 .47162 .53384 .46838 .53066 .46216 Mtetra
.694 .639 .791 r
.53066 .46216 .53384 .46838 .53974 .46528 .53656 .45904 Mtetra
.688 .637 .792 r
.53656 .45904 .53974 .46528 .54564 .46233 .54247 .45608 Mtetra
.683 .634 .794 r
.54247 .45608 .54564 .46233 .55156 .45952 .54839 .45326 Mtetra
.678 .631 .796 r
.54839 .45326 .55156 .45952 .55749 .45687 .55432 .45058 Mtetra
.672 .629 .798 r
.55432 .45058 .55749 .45687 .56343 .45436 .56027 .44806 Mtetra
.666 .626 .8 r
.56027 .44806 .56343 .45436 .56938 .452 .56622 .44569 Mtetra
.66 .623 .801 r
.56622 .44569 .56938 .452 .57534 .44978 .57219 .44346 Mtetra
.654 .62 .803 r
.57219 .44346 .57534 .44978 .58132 .44772 .57817 .44139 Mtetra
.648 .617 .805 r
.57817 .44139 .58132 .44772 .58732 .44581 .58417 .43947 Mtetra
.641 .614 .807 r
.58417 .43947 .58732 .44581 .59333 .44406 .59019 .43771 Mtetra
.635 .611 .809 r
.59019 .43771 .59333 .44406 .59936 .44245 .59622 .43609 Mtetra
.628 .608 .811 r
.59622 .43609 .59936 .44245 .6054 .44099 .60227 .43463 Mtetra
.621 .604 .812 r
.60227 .43463 .6054 .44099 .61147 .43968 .60833 .43332 Mtetra
.614 .601 .814 r
.60833 .43332 .61147 .43968 .61755 .43853 .61442 .43216 Mtetra
.607 .598 .816 r
.61442 .43216 .61755 .43853 .62366 .43752 .62053 .43115 Mtetra
.6 .594 .818 r
.62053 .43115 .62366 .43752 .62979 .43667 .62666 .43029 Mtetra
.592 .591 .819 r
.62666 .43029 .62979 .43667 .63594 .43596 .63282 .42958 Mtetra
.585 .587 .821 r
.63282 .42958 .63594 .43596 .64211 .4354 .63899 .42902 Mtetra
.577 .583 .823 r
.63899 .42902 .64211 .4354 .64831 .43498 .64519 .42861 Mtetra
.569 .58 .824 r
.64519 .42861 .64831 .43498 .65453 .43471 .65142 .42834 Mtetra
.561 .576 .826 r
.65142 .42834 .65453 .43471 .66078 .43458 .65767 .42822 Mtetra
.553 .572 .828 r
.65767 .42822 .66078 .43458 .66706 .43459 .66395 .42823 Mtetra
.545 .569 .829 r
.66395 .42823 .66706 .43459 .67336 .43474 .67026 .42839 Mtetra
.537 .565 .831 r
.67026 .42839 .67336 .43474 .67969 .43503 .67659 .42869 Mtetra
.529 .561 .832 r
.67659 .42869 .67969 .43503 .68606 .43546 .68296 .42912 Mtetra
.521 .558 .833 r
.68296 .42912 .68606 .43546 .69245 .43601 .68935 .42968 Mtetra
.513 .554 .835 r
.68935 .42968 .69245 .43601 .69887 .4367 .69578 .43038 Mtetra
.505 .55 .836 r
.69578 .43038 .69887 .4367 .70533 .43751 .70223 .4312 Mtetra
.497 .547 .837 r
.70223 .4312 .70533 .43751 .71181 .43845 .70872 .43215 Mtetra
.489 .543 .839 r
.70872 .43215 .71181 .43845 .71833 .4395 .71525 .43322 Mtetra
.481 .54 .84 r
.71525 .43322 .71833 .4395 .72489 .44067 .7218 .43441 Mtetra
.474 .536 .841 r
.7218 .43441 .72489 .44067 .73147 .44196 .7284 .43572 Mtetra
.466 .533 .842 r
.7284 .43572 .73147 .44196 .7381 .44335 .73502 .43713 Mtetra
.459 .53 .843 r
.73502 .43713 .7381 .44335 .74475 .44485 .74169 .43865 Mtetra
.451 .527 .844 r
.74169 .43865 .74475 .44485 .75145 .44645 .74838 .44027 Mtetra
.444 .524 .845 r
.74838 .44027 .75145 .44645 .75818 .44815 .75512 .44199 Mtetra
.437 .521 .846 r
.75512 .44199 .75818 .44815 .76494 .44994 .76189 .4438 Mtetra
.431 .519 .847 r
.76189 .4438 .76494 .44994 .77175 .45181 .7687 .44569 Mtetra
.424 .517 .849 r
.7687 .44569 .77175 .45181 .77859 .45376 .77554 .44767 Mtetra
.418 .515 .85 r
.77554 .44767 .77859 .45376 .78547 .45579 .78243 .44973 Mtetra
.413 .513 .851 r
.78243 .44973 .78547 .45579 .79238 .45788 .78935 .45185 Mtetra
.407 .511 .852 r
.78935 .45185 .79238 .45788 .79934 .46003 .79631 .45404 Mtetra
.402 .51 .853 r
.79631 .45404 .79934 .46003 .80633 .46224 .8033 .45628 Mtetra
.398 .509 .855 r
.8033 .45628 .80633 .46224 .81335 .4645 .81034 .45857 Mtetra
.394 .508 .856 r
.81034 .45857 .81335 .4645 .82042 .4668 .81741 .46091 Mtetra
.39 .508 .857 r
.81741 .46091 .82042 .4668 .82752 .46913 .82452 .46328 Mtetra
.387 .508 .859 r
.82452 .46328 .82752 .46913 .83466 .47149 .83167 .46567 Mtetra
.384 .509 .861 r
.83167 .46567 .83466 .47149 .84184 .47387 .83885 .46809 Mtetra
.382 .51 .862 r
.83885 .46809 .84184 .47387 .84905 .47625 .84607 .47051 Mtetra
.381 .511 .864 r
.84607 .47051 .84905 .47625 .85629 .47863 .85333 .47294 Mtetra
.38 .513 .866 r
.85333 .47294 .85629 .47863 .86357 .481 .86062 .47536 Mtetra
.38 .515 .868 r
.86062 .47536 .86357 .481 .87089 .48335 .86794 .47776 Mtetra
.38 .518 .87 r
.86794 .47776 .87089 .48335 .87823 .48567 .8753 .48013 Mtetra
.382 .521 .873 r
.8753 .48013 .87823 .48567 .88561 .48796 .88268 .48246 Mtetra
.384 .525 .875 r
.88268 .48246 .88561 .48796 .89302 .49019 .8901 .48474 Mtetra
.386 .53 .878 r
.8901 .48474 .89302 .49019 .90045 .49235 .89755 .48696 Mtetra
.39 .535 .881 r
.89755 .48696 .90045 .49235 .90791 .49444 .90503 .48911 Mtetra
.394 .54 .884 r
.90503 .48911 .90791 .49444 .9154 .49645 .91253 .49118 Mtetra
.787 .718 .787 r
.28611 .66945 .28968 .67383 .29557 .66828 .29202 .66383 Mtetra
.788 .716 .784 r
.29202 .66383 .29557 .66828 .30146 .66265 .29792 .65812 Mtetra
.789 .714 .782 r
.29792 .65812 .30146 .66265 .30736 .65693 .30383 .65234 Mtetra
.789 .712 .78 r
.30383 .65234 .30736 .65693 .31326 .65115 .30975 .64649 Mtetra
.789 .71 .778 r
.30975 .64649 .31326 .65115 .31916 .64531 .31566 .64059 Mtetra
.789 .709 .776 r
.31566 .64059 .31916 .64531 .32506 .63942 .32158 .63464 Mtetra
.788 .707 .774 r
.32158 .63464 .32506 .63942 .33097 .6335 .32749 .62866 Mtetra
.788 .705 .773 r
.32749 .62866 .33097 .6335 .33687 .62755 .33341 .62265 Mtetra
.787 .704 .772 r
.33341 .62265 .33687 .62755 .34277 .62158 .33932 .61663 Mtetra
.787 .702 .771 r
.33932 .61663 .34277 .62158 .34867 .61561 .34524 .61059 Mtetra
.786 .7 .77 r
.34524 .61059 .34867 .61561 .35457 .60963 .35115 .60456 Mtetra
.785 .699 .769 r
.35115 .60456 .35457 .60963 .36047 .60366 .35706 .59854 Mtetra
.784 .697 .768 r
.35706 .59854 .36047 .60366 .36636 .59771 .36296 .59254 Mtetra
.783 .695 .768 r
.36296 .59254 .36636 .59771 .37226 .59178 .36886 .58656 Mtetra
.781 .694 .768 r
.36886 .58656 .37226 .59178 .37814 .58589 .37476 .58062 Mtetra
.78 .692 .767 r
.37476 .58062 .37814 .58589 .38403 .58003 .38066 .57471 Mtetra
.778 .691 .767 r
.38066 .57471 .38403 .58003 .38991 .57422 .38655 .56885 Mtetra
.776 .689 .767 r
.38655 .56885 .38991 .57422 .39579 .56846 .39244 .56305 Mtetra
.774 .688 .768 r
.39244 .56305 .39579 .56846 .40166 .56276 .39832 .55731 Mtetra
.773 .686 .768 r
.39832 .55731 .40166 .56276 .40753 .55712 .4042 .55163 Mtetra
.77 .685 .768 r
.4042 .55163 .40753 .55712 .4134 .55156 .41008 .54602 Mtetra
.768 .683 .769 r
.41008 .54602 .4134 .55156 .41927 .54607 .41595 .54049 Mtetra
.766 .681 .769 r
.41595 .54049 .41927 .54607 .42513 .54066 .42182 .53505 Mtetra
.763 .68 .77 r
.42182 .53505 .42513 .54066 .43099 .53534 .42769 .52969 Mtetra
.761 .678 .771 r
.42769 .52969 .43099 .53534 .43684 .53011 .43355 .52443 Mtetra
.758 .676 .772 r
.43355 .52443 .43684 .53011 .4427 .52498 .43942 .51926 Mtetra
.755 .675 .772 r
.43942 .51926 .4427 .52498 .44855 .51995 .44528 .5142 Mtetra
.752 .673 .773 r
.44528 .5142 .44855 .51995 .45441 .51503 .45114 .50924 Mtetra
.749 .671 .774 r
.45114 .50924 .45441 .51503 .46026 .51021 .457 .5044 Mtetra
.746 .669 .776 r
.457 .5044 .46026 .51021 .46611 .50551 .46286 .49966 Mtetra
.743 .667 .777 r
.46286 .49966 .46611 .50551 .47196 .50092 .46872 .49505 Mtetra
.739 .666 .778 r
.46872 .49505 .47196 .50092 .47782 .49646 .47458 .49056 Mtetra
.735 .664 .779 r
.47458 .49056 .47782 .49646 .48367 .49212 .48044 .48619 Mtetra
.732 .662 .781 r
.48044 .48619 .48367 .49212 .48953 .4879 .4863 .48195 Mtetra
.728 .66 .782 r
.4863 .48195 .48953 .4879 .49539 .48382 .49217 .47784 Mtetra
.723 .657 .784 r
.49217 .47784 .49539 .48382 .50126 .47986 .49804 .47386 Mtetra
.719 .655 .785 r
.49804 .47386 .50126 .47986 .50712 .47604 .50391 .47002 Mtetra
.715 .653 .787 r
.50391 .47002 .50712 .47604 .513 .47236 .50979 .46632 Mtetra
.71 .651 .789 r
.50979 .46632 .513 .47236 .51888 .46882 .51568 .46276 Mtetra
.705 .649 .79 r
.51568 .46276 .51888 .46882 .52476 .46542 .52157 .45933 Mtetra
.7 .646 .792 r
.52157 .45933 .52476 .46542 .53066 .46216 .52747 .45606 Mtetra
.695 .644 .794 r
.52747 .45606 .53066 .46216 .53656 .45904 .53337 .45293 Mtetra
.69 .641 .796 r
.53337 .45293 .53656 .45904 .54247 .45608 .53929 .44994 Mtetra
.685 .639 .798 r
.53929 .44994 .54247 .45608 .54839 .45326 .54522 .44711 Mtetra
.679 .636 .799 r
.54522 .44711 .54839 .45326 .55432 .45058 .55115 .44442 Mtetra
.673 .633 .801 r
.55115 .44442 .55432 .45058 .56027 .44806 .5571 .44188 Mtetra
.667 .63 .803 r
.5571 .44188 .56027 .44806 .56622 .44569 .56306 .4395 Mtetra
.661 .628 .805 r
.56306 .4395 .56622 .44569 .57219 .44346 .56903 .43727 Mtetra
.655 .625 .807 r
.56903 .43727 .57219 .44346 .57817 .44139 .57502 .43518 Mtetra
.649 .622 .809 r
.57502 .43518 .57817 .44139 .58417 .43947 .58102 .43326 Mtetra
.642 .618 .811 r
.58102 .43326 .58417 .43947 .59019 .43771 .58704 .43148 Mtetra
.635 .615 .813 r
.58704 .43148 .59019 .43771 .59622 .43609 .59307 .42986 Mtetra
.628 .612 .815 r
.59307 .42986 .59622 .43609 .60227 .43463 .59913 .42839 Mtetra
.621 .609 .817 r
.59913 .42839 .60227 .43463 .60833 .43332 .6052 .42708 Mtetra
.614 .605 .818 r
.6052 .42708 .60833 .43332 .61442 .43216 .61129 .42591 Mtetra
.607 .602 .82 r
.61129 .42591 .61442 .43216 .62053 .43115 .6174 .4249 Mtetra
.599 .598 .822 r
.6174 .4249 .62053 .43115 .62666 .43029 .62353 .42404 Mtetra
.591 .595 .824 r
.62353 .42404 .62666 .43029 .63282 .42958 .62969 .42333 Mtetra
.584 .591 .826 r
.62969 .42333 .63282 .42958 .63899 .42902 .63587 .42277 Mtetra
.576 .587 .827 r
.63587 .42277 .63899 .42902 .64519 .42861 .64207 .42236 Mtetra
.568 .584 .829 r
.64207 .42236 .64519 .42861 .65142 .42834 .6483 .42209 Mtetra
.56 .58 .831 r
.6483 .42209 .65142 .42834 .65767 .42822 .65456 .42197 Mtetra
.552 .576 .832 r
.65456 .42197 .65767 .42822 .66395 .42823 .66084 .42199 Mtetra
.543 .572 .834 r
.66084 .42199 .66395 .42823 .67026 .42839 .66715 .42215 Mtetra
.535 .568 .835 r
.66715 .42215 .67026 .42839 .67659 .42869 .67349 .42246 Mtetra
.527 .564 .837 r
.67349 .42246 .67659 .42869 .68296 .42912 .67985 .42289 Mtetra
.518 .56 .838 r
.67985 .42289 .68296 .42912 .68935 .42968 .68625 .42347 Mtetra
.51 .557 .839 r
.68625 .42347 .68935 .42968 .69578 .43038 .69268 .42417 Mtetra
.502 .553 .841 r
.69268 .42417 .69578 .43038 .70223 .4312 .69914 .42501 Mtetra
.493 .549 .842 r
.69914 .42501 .70223 .4312 .70872 .43215 .70564 .42597 Mtetra
.485 .545 .843 r
.70564 .42597 .70872 .43215 .71525 .43322 .71216 .42705 Mtetra
.477 .542 .844 r
.71216 .42705 .71525 .43322 .7218 .43441 .71872 .42826 Mtetra
.469 .538 .845 r
.71872 .42826 .7218 .43441 .7284 .43572 .72532 .42958 Mtetra
.461 .535 .846 r
.72532 .42958 .7284 .43572 .73502 .43713 .73195 .43101 Mtetra
.453 .531 .847 r
.73195 .43101 .73502 .43713 .74169 .43865 .73862 .43254 Mtetra
.446 .528 .848 r
.73862 .43254 .74169 .43865 .74838 .44027 .74532 .43418 Mtetra
.439 .525 .849 r
.74532 .43418 .74838 .44027 .75512 .44199 .75206 .43592 Mtetra
.431 .522 .85 r
.75206 .43592 .75512 .44199 .76189 .4438 .75883 .43776 Mtetra
.425 .52 .851 r
.75883 .43776 .76189 .4438 .7687 .44569 .76565 .43968 Mtetra
.418 .517 .852 r
.76565 .43968 .7687 .44569 .77554 .44767 .7725 .44168 Mtetra
.412 .515 .853 r
.7725 .44168 .77554 .44767 .78243 .44973 .77939 .44376 Mtetra
.406 .513 .854 r
.77939 .44376 .78243 .44973 .78935 .45185 .78631 .44591 Mtetra
.4 .511 .855 r
.78631 .44591 .78935 .45185 .79631 .45404 .79328 .44813 Mtetra
.395 .51 .857 r
.79328 .44813 .79631 .45404 .8033 .45628 .80028 .4504 Mtetra
.391 .509 .858 r
.80028 .4504 .8033 .45628 .81034 .45857 .80732 .45272 Mtetra
.386 .508 .859 r
.80732 .45272 .81034 .45857 .81741 .46091 .8144 .45509 Mtetra
.383 .508 .86 r
.8144 .45509 .81741 .46091 .82452 .46328 .82152 .4575 Mtetra
.379 .508 .862 r
.82152 .4575 .82452 .46328 .83167 .46567 .82867 .45993 Mtetra
.377 .508 .863 r
.82867 .45993 .83167 .46567 .83885 .46809 .83587 .46238 Mtetra
.375 .509 .865 r
.83587 .46238 .83885 .46809 .84607 .47051 .84309 .46485 Mtetra
.373 .51 .867 r
.84309 .46485 .84607 .47051 .85333 .47294 .85036 .46732 Mtetra
.372 .512 .868 r
.85036 .46732 .85333 .47294 .86062 .47536 .85766 .46978 Mtetra
.372 .514 .87 r
.85766 .46978 .86062 .47536 .86794 .47776 .86499 .47222 Mtetra
.372 .517 .873 r
.86499 .47222 .86794 .47776 .8753 .48013 .87236 .47464 Mtetra
.374 .52 .875 r
.87236 .47464 .8753 .48013 .88268 .48246 .87976 .47702 Mtetra
.376 .524 .877 r
.87976 .47702 .88268 .48246 .8901 .48474 .88719 .47935 Mtetra
.378 .528 .88 r
.88719 .47935 .8901 .48474 .89755 .48696 .89465 .48162 Mtetra
.382 .533 .882 r
.89465 .48162 .89755 .48696 .90503 .48911 .90214 .48383 Mtetra
.386 .539 .885 r
.90214 .48383 .90503 .48911 .91253 .49118 .90965 .48595 Mtetra
.79 .72 .787 r
.28254 .6651 .28611 .66945 .29202 .66383 .28845 .65942 Mtetra
.79 .718 .784 r
.28845 .65942 .29202 .66383 .29792 .65812 .29437 .65365 Mtetra
.791 .717 .782 r
.29437 .65365 .29792 .65812 .30383 .65234 .30029 .64781 Mtetra
.791 .715 .78 r
.30029 .64781 .30383 .65234 .30975 .64649 .30622 .6419 Mtetra
.791 .713 .778 r
.30622 .6419 .30975 .64649 .31566 .64059 .31215 .63593 Mtetra
.791 .711 .776 r
.31215 .63593 .31566 .64059 .32158 .63464 .31808 .62993 Mtetra
.791 .71 .775 r
.31808 .62993 .32158 .63464 .32749 .62866 .32401 .62389 Mtetra
.79 .708 .774 r
.32401 .62389 .32749 .62866 .33341 .62265 .32993 .61782 Mtetra
.79 .707 .772 r
.32993 .61782 .33341 .62265 .33932 .61663 .33586 .61174 Mtetra
.789 .705 .771 r
.33586 .61174 .33932 .61663 .34524 .61059 .34178 .60566 Mtetra
.788 .703 .771 r
.34178 .60566 .34524 .61059 .35115 .60456 .34771 .59958 Mtetra
.787 .702 .77 r
.34771 .59958 .35115 .60456 .35706 .59854 .35363 .5935 Mtetra
.786 .7 .769 r
.35363 .5935 .35706 .59854 .36296 .59254 .35954 .58745 Mtetra
.785 .699 .769 r
.35954 .58745 .36296 .59254 .36886 .58656 .36546 .58143 Mtetra
.784 .697 .769 r
.36546 .58143 .36886 .58656 .37476 .58062 .37137 .57543 Mtetra
.782 .696 .769 r
.37137 .57543 .37476 .58062 .38066 .57471 .37727 .56948 Mtetra
.781 .694 .769 r
.37727 .56948 .38066 .57471 .38655 .56885 .38317 .56358 Mtetra
.779 .693 .769 r
.38317 .56358 .38655 .56885 .39244 .56305 .38907 .55774 Mtetra
.777 .691 .769 r
.38907 .55774 .39244 .56305 .39832 .55731 .39496 .55195 Mtetra
.775 .69 .769 r
.39496 .55195 .39832 .55731 .4042 .55163 .40085 .54623 Mtetra
.773 .688 .77 r
.40085 .54623 .4042 .55163 .41008 .54602 .40674 .54059 Mtetra
.771 .687 .77 r
.40674 .54059 .41008 .54602 .41595 .54049 .41262 .53502 Mtetra
.769 .685 .771 r
.41262 .53502 .41595 .54049 .42182 .53505 .4185 .52954 Mtetra
.766 .684 .772 r
.4185 .52954 .42182 .53505 .42769 .52969 .42438 .52415 Mtetra
.763 .682 .773 r
.42438 .52415 .42769 .52969 .43355 .52443 .43025 .51885 Mtetra
.761 .681 .774 r
.43025 .51885 .43355 .52443 .43942 .51926 .43612 .51365 Mtetra
.758 .679 .775 r
.43612 .51365 .43942 .51926 .44528 .5142 .44199 .50856 Mtetra
.755 .677 .776 r
.44199 .50856 .44528 .5142 .45114 .50924 .44786 .50357 Mtetra
.752 .675 .777 r
.44786 .50357 .45114 .50924 .457 .5044 .45373 .49869 Mtetra
.749 .674 .778 r
.45373 .49869 .457 .5044 .46286 .49966 .45959 .49393 Mtetra
.745 .672 .779 r
.45959 .49393 .46286 .49966 .46872 .49505 .46546 .48929 Mtetra
.742 .67 .781 r
.46546 .48929 .46872 .49505 .47458 .49056 .47133 .48477 Mtetra
.738 .668 .782 r
.47133 .48477 .47458 .49056 .48044 .48619 .4772 .48038 Mtetra
.734 .666 .784 r
.4772 .48038 .48044 .48619 .4863 .48195 .48307 .47611 Mtetra
.73 .664 .785 r
.48307 .47611 .4863 .48195 .49217 .47784 .48894 .47198 Mtetra
.726 .662 .787 r
.48894 .47198 .49217 .47784 .49804 .47386 .49482 .46798 Mtetra
.722 .66 .788 r
.49482 .46798 .49804 .47386 .50391 .47002 .5007 .46412 Mtetra
.717 .658 .79 r
.5007 .46412 .50391 .47002 .50979 .46632 .50658 .46039 Mtetra
.712 .656 .792 r
.50658 .46039 .50979 .46632 .51568 .46276 .51247 .45681 Mtetra
.708 .653 .794 r
.51247 .45681 .51568 .46276 .52157 .45933 .51837 .45337 Mtetra
.703 .651 .795 r
.51837 .45337 .52157 .45933 .52747 .45606 .52427 .45008 Mtetra
.697 .649 .797 r
.52427 .45008 .52747 .45606 .53337 .45293 .53018 .44693 Mtetra
.692 .646 .799 r
.53018 .44693 .53337 .45293 .53929 .44994 .5361 .44393 Mtetra
.687 .643 .801 r
.5361 .44393 .53929 .44994 .54522 .44711 .54203 .44108 Mtetra
.681 .641 .803 r
.54203 .44108 .54522 .44711 .55115 .44442 .54797 .43838 Mtetra
.675 .638 .805 r
.54797 .43838 .55115 .44442 .5571 .44188 .55392 .43583 Mtetra
.669 .635 .807 r
.55392 .43583 .5571 .44188 .56306 .4395 .55989 .43343 Mtetra
.663 .632 .809 r
.55989 .43343 .56306 .4395 .56903 .43727 .56587 .43119 Mtetra
.656 .629 .811 r
.56587 .43119 .56903 .43727 .57502 .43518 .57186 .4291 Mtetra
.65 .626 .813 r
.57186 .4291 .57502 .43518 .58102 .43326 .57786 .42716 Mtetra
.643 .623 .815 r
.57786 .42716 .58102 .43326 .58704 .43148 .58388 .42538 Mtetra
.636 .62 .817 r
.58388 .42538 .58704 .43148 .59307 .42986 .58992 .42375 Mtetra
.629 .617 .819 r
.58992 .42375 .59307 .42986 .59913 .42839 .59598 .42228 Mtetra
.621 .613 .821 r
.59598 .42228 .59913 .42839 .6052 .42708 .60205 .42096 Mtetra
.614 .61 .823 r
.60205 .42096 .6052 .42708 .61129 .42591 .60815 .41979 Mtetra
.606 .606 .825 r
.60815 .41979 .61129 .42591 .6174 .4249 .61426 .41877 Mtetra
.599 .603 .827 r
.61426 .41877 .6174 .4249 .62353 .42404 .6204 .41791 Mtetra
.591 .599 .829 r
.6204 .41791 .62353 .42404 .62969 .42333 .62656 .4172 Mtetra
.583 .595 .83 r
.62656 .4172 .62969 .42333 .63587 .42277 .63274 .41664 Mtetra
.575 .591 .832 r
.63274 .41664 .63587 .42277 .64207 .42236 .63895 .41622 Mtetra
.566 .587 .834 r
.63895 .41622 .64207 .42236 .6483 .42209 .64518 .41596 Mtetra
.558 .584 .836 r
.64518 .41596 .6483 .42209 .65456 .42197 .65144 .41584 Mtetra
.55 .58 .837 r
.65144 .41584 .65456 .42197 .66084 .42199 .65773 .41587 Mtetra
.541 .576 .839 r
.65773 .41587 .66084 .42199 .66715 .42215 .66404 .41603 Mtetra
.532 .572 .84 r
.66404 .41603 .66715 .42215 .67349 .42246 .67038 .41634 Mtetra
.524 .568 .842 r
.67038 .41634 .67349 .42246 .67985 .42289 .67675 .41679 Mtetra
.515 .564 .843 r
.67675 .41679 .67985 .42289 .68625 .42347 .68315 .41737 Mtetra
.507 .56 .844 r
.68315 .41737 .68625 .42347 .69268 .42417 .68959 .41808 Mtetra
.498 .556 .845 r
.68959 .41808 .69268 .42417 .69914 .42501 .69605 .41893 Mtetra
.489 .552 .847 r
.69605 .41893 .69914 .42501 .70564 .42597 .70255 .4199 Mtetra
.481 .548 .848 r
.70255 .4199 .70564 .42597 .71216 .42705 .70908 .421 Mtetra
.473 .544 .849 r
.70908 .421 .71216 .42705 .71872 .42826 .71564 .42221 Mtetra
.464 .54 .85 r
.71564 .42221 .71872 .42826 .72532 .42958 .72224 .42355 Mtetra
.456 .537 .851 r
.72224 .42355 .72532 .42958 .73195 .43101 .72888 .42499 Mtetra
.448 .533 .852 r
.72888 .42499 .73195 .43101 .73862 .43254 .73555 .42655 Mtetra
.44 .53 .853 r
.73555 .42655 .73862 .43254 .74532 .43418 .74225 .4282 Mtetra
.433 .526 .854 r
.74225 .4282 .74532 .43418 .75206 .43592 .749 .42996 Mtetra
.425 .523 .854 r
.749 .42996 .75206 .43592 .75883 .43776 .75578 .43181 Mtetra
.418 .521 .855 r
.75578 .43181 .75883 .43776 .76565 .43968 .76259 .43376 Mtetra
.411 .518 .856 r
.76259 .43376 .76565 .43968 .7725 .44168 .76945 .43578 Mtetra
.405 .516 .857 r
.76945 .43578 .7725 .44168 .77939 .44376 .77635 .43789 Mtetra
.399 .513 .858 r
.77635 .43789 .77939 .44376 .78631 .44591 .78328 .44006 Mtetra
.393 .512 .859 r
.78328 .44006 .78631 .44591 .79328 .44813 .79025 .44231 Mtetra
.388 .51 .86 r
.79025 .44231 .79328 .44813 .80028 .4504 .79726 .44461 Mtetra
.383 .509 .861 r
.79726 .44461 .80028 .4504 .80732 .45272 .80431 .44696 Mtetra
.379 .508 .862 r
.80431 .44696 .80732 .45272 .8144 .45509 .81139 .44936 Mtetra
.375 .507 .863 r
.81139 .44936 .8144 .45509 .82152 .4575 .81852 .4518 Mtetra
.371 .507 .865 r
.81852 .4518 .82152 .4575 .82867 .45993 .82568 .45427 Mtetra
.369 .507 .866 r
.82568 .45427 .82867 .45993 .83587 .46238 .83288 .45676 Mtetra
.366 .508 .868 r
.83288 .45676 .83587 .46238 .84309 .46485 .84012 .45926 Mtetra
.365 .509 .869 r
.84012 .45926 .84309 .46485 .85036 .46732 .84739 .46176 Mtetra
.364 .511 .871 r
.84739 .46176 .85036 .46732 .85766 .46978 .8547 .46426 Mtetra
.364 .513 .873 r
.8547 .46426 .85766 .46978 .86499 .47222 .86204 .46675 Mtetra
.364 .516 .875 r
.86204 .46675 .86499 .47222 .87236 .47464 .86942 .46921 Mtetra
.365 .519 .877 r
.86942 .46921 .87236 .47464 .87976 .47702 .87683 .47163 Mtetra
.367 .522 .879 r
.87683 .47163 .87976 .47702 .88719 .47935 .88427 .47401 Mtetra
.37 .527 .882 r
.88427 .47401 .88719 .47935 .89465 .48162 .89174 .47633 Mtetra
.374 .532 .884 r
.89174 .47633 .89465 .48162 .90214 .48383 .89925 .47859 Mtetra
.378 .537 .887 r
.89925 .47859 .90214 .48383 .90965 .48595 .90677 .48076 Mtetra
.792 .723 .787 r
.27894 .66081 .28254 .6651 .28845 .65942 .28487 .65507 Mtetra
.793 .721 .785 r
.28487 .65507 .28845 .65942 .29437 .65365 .2908 .64923 Mtetra
.793 .719 .783 r
.2908 .64923 .29437 .65365 .30029 .64781 .29674 .64333 Mtetra
.793 .718 .78 r
.29674 .64333 .30029 .64781 .30622 .6419 .30268 .63736 Mtetra
.794 .716 .779 r
.30268 .63736 .30622 .6419 .31215 .63593 .30862 .63134 Mtetra
.793 .714 .777 r
.30862 .63134 .31215 .63593 .31808 .62993 .31456 .62528 Mtetra
.793 .713 .776 r
.31456 .62528 .31808 .62993 .32401 .62389 .3205 .61919 Mtetra
.793 .711 .774 r
.3205 .61919 .32401 .62389 .32993 .61782 .32644 .61307 Mtetra
.792 .71 .773 r
.32644 .61307 .32993 .61782 .33586 .61174 .33238 .60694 Mtetra
.792 .708 .772 r
.33238 .60694 .33586 .61174 .34178 .60566 .33832 .6008 Mtetra
.791 .707 .772 r
.33832 .6008 .34178 .60566 .34771 .59958 .34425 .59467 Mtetra
.79 .705 .771 r
.34425 .59467 .34771 .59958 .35363 .5935 .35018 .58855 Mtetra
.789 .704 .771 r
.35018 .58855 .35363 .5935 .35954 .58745 .35611 .58245 Mtetra
.788 .703 .77 r
.35611 .58245 .35954 .58745 .36546 .58143 .36203 .57638 Mtetra
.786 .701 .77 r
.36203 .57638 .36546 .58143 .37137 .57543 .36795 .57034 Mtetra
.785 .7 .77 r
.36795 .57034 .37137 .57543 .37727 .56948 .37387 .56435 Mtetra
.783 .698 .77 r
.37387 .56435 .37727 .56948 .38317 .56358 .37978 .55841 Mtetra
.782 .697 .77 r
.37978 .55841 .38317 .56358 .38907 .55774 .38569 .55252 Mtetra
.78 .695 .771 r
.38569 .55252 .38907 .55774 .39496 .55195 .39159 .54669 Mtetra
.778 .694 .771 r
.39159 .54669 .39496 .55195 .40085 .54623 .39749 .54094 Mtetra
.776 .693 .772 r
.39749 .54094 .40085 .54623 .40674 .54059 .40339 .53526 Mtetra
.774 .691 .772 r
.40339 .53526 .40674 .54059 .41262 .53502 .40928 .52965 Mtetra
.771 .69 .773 r
.40928 .52965 .41262 .53502 .4185 .52954 .41517 .52414 Mtetra
.769 .688 .774 r
.41517 .52414 .4185 .52954 .42438 .52415 .42106 .51871 Mtetra
.766 .687 .775 r
.42106 .51871 .42438 .52415 .43025 .51885 .42694 .51338 Mtetra
.763 .685 .776 r
.42694 .51338 .43025 .51885 .43612 .51365 .43282 .50815 Mtetra
.761 .683 .777 r
.43282 .50815 .43612 .51365 .44199 .50856 .4387 .50302 Mtetra
.758 .682 .778 r
.4387 .50302 .44199 .50856 .44786 .50357 .44457 .49801 Mtetra
.754 .68 .779 r
.44457 .49801 .44786 .50357 .45373 .49869 .45045 .4931 Mtetra
.751 .678 .78 r
.45045 .4931 .45373 .49869 .45959 .49393 .45632 .48831 Mtetra
.748 .677 .782 r
.45632 .48831 .45959 .49393 .46546 .48929 .46219 .48365 Mtetra
.744 .675 .783 r
.46219 .48365 .46546 .48929 .47133 .48477 .46807 .4791 Mtetra
.74 .673 .785 r
.46807 .4791 .47133 .48477 .4772 .48038 .47394 .47468 Mtetra
.737 .671 .786 r
.47394 .47468 .4772 .48038 .48307 .47611 .47982 .4704 Mtetra
.733 .669 .788 r
.47982 .4704 .48307 .47611 .48894 .47198 .4857 .46624 Mtetra
.728 .667 .79 r
.4857 .46624 .48894 .47198 .49482 .46798 .49158 .46222 Mtetra
.724 .665 .791 r
.49158 .46222 .49482 .46798 .5007 .46412 .49747 .45834 Mtetra
.719 .663 .793 r
.49747 .45834 .5007 .46412 .50658 .46039 .50336 .45459 Mtetra
.715 .661 .795 r
.50336 .45459 .50658 .46039 .51247 .45681 .50926 .45099 Mtetra
.71 .658 .797 r
.50926 .45099 .51247 .45681 .51837 .45337 .51516 .44754 Mtetra
.705 .656 .799 r
.51516 .44754 .51837 .45337 .52427 .45008 .52107 .44422 Mtetra
.699 .654 .801 r
.52107 .44422 .52427 .45008 .53018 .44693 .52698 .44106 Mtetra
.694 .651 .803 r
.52698 .44106 .53018 .44693 .5361 .44393 .53291 .43805 Mtetra
.688 .649 .805 r
.53291 .43805 .5361 .44393 .54203 .44108 .53884 .43518 Mtetra
.683 .646 .807 r
.53884 .43518 .54203 .44108 .54797 .43838 .54479 .43247 Mtetra
.677 .643 .809 r
.54479 .43247 .54797 .43838 .55392 .43583 .55074 .42991 Mtetra
.67 .64 .811 r
.55074 .42991 .55392 .43583 .55989 .43343 .55671 .4275 Mtetra
.664 .637 .813 r
.55671 .4275 .55989 .43343 .56587 .43119 .56269 .42524 Mtetra
.657 .634 .815 r
.56269 .42524 .56587 .43119 .57186 .4291 .56869 .42314 Mtetra
.651 .631 .818 r
.56869 .42314 .57186 .4291 .57786 .42716 .5747 .4212 Mtetra
.644 .628 .82 r
.5747 .4212 .57786 .42716 .58388 .42538 .58073 .41941 Mtetra
.637 .625 .822 r
.58073 .41941 .58388 .42538 .58992 .42375 .58677 .41777 Mtetra
.629 .621 .824 r
.58677 .41777 .58992 .42375 .59598 .42228 .59283 .41629 Mtetra
.622 .618 .826 r
.59283 .41629 .59598 .42228 .60205 .42096 .59891 .41496 Mtetra
.614 .614 .828 r
.59891 .41496 .60205 .42096 .60815 .41979 .60501 .41379 Mtetra
.606 .611 .83 r
.60501 .41379 .60815 .41979 .61426 .41877 .61113 .41277 Mtetra
.598 .607 .832 r
.61113 .41277 .61426 .41877 .6204 .41791 .61727 .41191 Mtetra
.59 .603 .834 r
.61727 .41191 .6204 .41791 .62656 .4172 .62343 .41119 Mtetra
.582 .599 .835 r
.62343 .41119 .62656 .4172 .63274 .41664 .62961 .41063 Mtetra
.573 .596 .837 r
.62961 .41063 .63274 .41664 .63895 .41622 .63582 .41022 Mtetra
.565 .592 .839 r
.63582 .41022 .63895 .41622 .64518 .41596 .64206 .40995 Mtetra
.556 .588 .841 r
.64206 .40995 .64518 .41596 .65144 .41584 .64832 .40984 Mtetra
.547 .583 .842 r
.64832 .40984 .65144 .41584 .65773 .41587 .65461 .40986 Mtetra
.539 .579 .844 r
.65461 .40986 .65773 .41587 .66404 .41603 .66093 .41004 Mtetra
.53 .575 .845 r
.66093 .41004 .66404 .41603 .67038 .41634 .66727 .41035 Mtetra
.521 .571 .847 r
.66727 .41035 .67038 .41634 .67675 .41679 .67365 .4108 Mtetra
.512 .567 .848 r
.67365 .4108 .67675 .41679 .68315 .41737 .68005 .41139 Mtetra
.503 .563 .849 r
.68005 .41139 .68315 .41737 .68959 .41808 .68649 .41211 Mtetra
.494 .558 .85 r
.68649 .41211 .68959 .41808 .69605 .41893 .69296 .41297 Mtetra
.485 .554 .851 r
.69296 .41297 .69605 .41893 .70255 .4199 .69946 .41395 Mtetra
.476 .55 .853 r
.69946 .41395 .70255 .4199 .70908 .421 .70599 .41505 Mtetra
.468 .546 .854 r
.70599 .41505 .70908 .421 .71564 .42221 .71256 .41628 Mtetra
.459 .542 .855 r
.71256 .41628 .71564 .42221 .72224 .42355 .71916 .41763 Mtetra
.451 .539 .855 r
.71916 .41763 .72224 .42355 .72888 .42499 .7258 .41909 Mtetra
.442 .535 .856 r
.7258 .41909 .72888 .42499 .73555 .42655 .73248 .42066 Mtetra
.434 .531 .857 r
.73248 .42066 .73555 .42655 .74225 .4282 .73919 .42233 Mtetra
.426 .528 .858 r
.73919 .42233 .74225 .4282 .749 .42996 .74593 .42411 Mtetra
.419 .525 .859 r
.74593 .42411 .749 .42996 .75578 .43181 .75272 .42598 Mtetra
.411 .522 .859 r
.75272 .42598 .75578 .43181 .76259 .43376 .75954 .42794 Mtetra
.404 .519 .86 r
.75954 .42794 .76259 .43376 .76945 .43578 .7664 .42999 Mtetra
.398 .516 .861 r
.7664 .42999 .76945 .43578 .77635 .43789 .7733 .43211 Mtetra
.391 .514 .862 r
.7733 .43211 .77635 .43789 .78328 .44006 .78024 .43431 Mtetra
.386 .512 .863 r
.78024 .43431 .78328 .44006 .79025 .44231 .78722 .43658 Mtetra
.38 .51 .864 r
.78722 .43658 .79025 .44231 .79726 .44461 .79424 .43891 Mtetra
.375 .509 .864 r
.79424 .43891 .79726 .44461 .80431 .44696 .80129 .44129 Mtetra
.371 .508 .866 r
.80129 .44129 .80431 .44696 .81139 .44936 .80838 .44372 Mtetra
.367 .507 .867 r
.80838 .44372 .81139 .44936 .81852 .4518 .81552 .44619 Mtetra
.363 .507 .868 r
.81552 .44619 .81852 .4518 .82568 .45427 .82269 .44868 Mtetra
.36 .507 .869 r
.82269 .44868 .82568 .45427 .83288 .45676 .82989 .45121 Mtetra
.358 .507 .87 r
.82989 .45121 .83288 .45676 .84012 .45926 .83714 .45374 Mtetra
.357 .508 .872 r
.83714 .45374 .84012 .45926 .84739 .46176 .84442 .45628 Mtetra
.356 .51 .874 r
.84442 .45628 .84739 .46176 .8547 .46426 .85174 .45882 Mtetra
.355 .512 .875 r
.85174 .45882 .8547 .46426 .86204 .46675 .85909 .46134 Mtetra
.356 .514 .877 r
.85909 .46134 .86204 .46675 .86942 .46921 .86648 .46385 Mtetra
.357 .517 .879 r
.86648 .46385 .86942 .46921 .87683 .47163 .8739 .46631 Mtetra
.359 .521 .881 r
.8739 .46631 .87683 .47163 .88427 .47401 .88135 .46873 Mtetra
.362 .525 .884 r
.88135 .46873 .88427 .47401 .89174 .47633 .88884 .4711 Mtetra
.366 .53 .886 r
.88884 .4711 .89174 .47633 .89925 .47859 .89635 .4734 Mtetra
.37 .536 .889 r
.89635 .4734 .89925 .47859 .90677 .48076 .90389 .47562 Mtetra
.794 .725 .788 r
.27533 .65657 .27894 .66081 .28487 .65507 .28127 .65077 Mtetra
.795 .724 .785 r
.28127 .65077 .28487 .65507 .2908 .64923 .28722 .64488 Mtetra
.795 .722 .783 r
.28722 .64488 .2908 .64923 .29674 .64333 .29317 .63892 Mtetra
.796 .72 .781 r
.29317 .63892 .29674 .64333 .30268 .63736 .29912 .63289 Mtetra
.796 .719 .779 r
.29912 .63289 .30268 .63736 .30862 .63134 .30507 .62682 Mtetra
.796 .717 .778 r
.30507 .62682 .30862 .63134 .31456 .62528 .31103 .6207 Mtetra
.796 .716 .776 r
.31103 .6207 .31456 .62528 .3205 .61919 .31698 .61456 Mtetra
.795 .714 .775 r
.31698 .61456 .3205 .61919 .32644 .61307 .32294 .60839 Mtetra
.795 .713 .774 r
.32294 .60839 .32644 .61307 .33238 .60694 .32889 .60221 Mtetra
.794 .712 .773 r
.32889 .60221 .33238 .60694 .33832 .6008 .33484 .59603 Mtetra
.793 .71 .773 r
.33484 .59603 .33832 .6008 .34425 .59467 .34078 .58985 Mtetra
.792 .709 .772 r
.34078 .58985 .34425 .59467 .35018 .58855 .34672 .58368 Mtetra
.791 .708 .772 r
.34672 .58368 .35018 .58855 .35611 .58245 .35266 .57754 Mtetra
.79 .706 .772 r
.35266 .57754 .35611 .58245 .36203 .57638 .3586 .57142 Mtetra
.789 .705 .772 r
.3586 .57142 .36203 .57638 .36795 .57034 .36453 .56535 Mtetra
.787 .704 .772 r
.36453 .56535 .36795 .57034 .37387 .56435 .37046 .55931 Mtetra
.786 .702 .772 r
.37046 .55931 .37387 .56435 .37978 .55841 .37638 .55333 Mtetra
.784 .701 .772 r
.37638 .55333 .37978 .55841 .38569 .55252 .3823 .5474 Mtetra
.782 .699 .772 r
.3823 .5474 .38569 .55252 .39159 .54669 .38821 .54154 Mtetra
.781 .698 .773 r
.38821 .54154 .39159 .54669 .39749 .54094 .39412 .53575 Mtetra
.778 .697 .773 r
.39412 .53575 .39749 .54094 .40339 .53526 .40003 .53003 Mtetra
.776 .695 .774 r
.40003 .53003 .40339 .53526 .40928 .52965 .40593 .52439 Mtetra
.774 .694 .775 r
.40593 .52439 .40928 .52965 .41517 .52414 .41183 .51884 Mtetra
.772 .692 .776 r
.41183 .51884 .41517 .52414 .42106 .51871 .41772 .51339 Mtetra
.769 .691 .777 r
.41772 .51339 .42106 .51871 .42694 .51338 .42361 .50802 Mtetra
.766 .69 .778 r
.42361 .50802 .42694 .51338 .43282 .50815 .4295 .50276 Mtetra
.763 .688 .779 r
.4295 .50276 .43282 .50815 .4387 .50302 .43539 .49761 Mtetra
.76 .686 .78 r
.43539 .49761 .4387 .50302 .44457 .49801 .44127 .49256 Mtetra
.757 .685 .782 r
.44127 .49256 .44457 .49801 .45045 .4931 .44715 .48763 Mtetra
.754 .683 .783 r
.44715 .48763 .45045 .4931 .45632 .48831 .45303 .48282 Mtetra
.75 .681 .784 r
.45303 .48282 .45632 .48831 .46219 .48365 .45892 .47812 Mtetra
.747 .68 .786 r
.45892 .47812 .46219 .48365 .46807 .4791 .4648 .47355 Mtetra
.743 .678 .788 r
.4648 .47355 .46807 .4791 .47394 .47468 .47068 .46911 Mtetra
.739 .676 .789 r
.47068 .46911 .47394 .47468 .47982 .4704 .47656 .4648 Mtetra
.735 .674 .791 r
.47656 .4648 .47982 .4704 .4857 .46624 .48245 .46062 Mtetra
.731 .672 .793 r
.48245 .46062 .4857 .46624 .49158 .46222 .48834 .45658 Mtetra
.726 .67 .795 r
.48834 .45658 .49158 .46222 .49747 .45834 .49423 .45268 Mtetra
.722 .668 .797 r
.49423 .45268 .49747 .45834 .50336 .45459 .50013 .44892 Mtetra
.717 .666 .799 r
.50013 .44892 .50336 .45459 .50926 .45099 .50603 .4453 Mtetra
.712 .664 .801 r
.50603 .4453 .50926 .45099 .51516 .44754 .51194 .44182 Mtetra
.707 .661 .803 r
.51194 .44182 .51516 .44754 .52107 .44422 .51785 .4385 Mtetra
.701 .659 .805 r
.51785 .4385 .52107 .44422 .52698 .44106 .52378 .43532 Mtetra
.696 .656 .807 r
.52378 .43532 .52698 .44106 .53291 .43805 .52971 .43229 Mtetra
.69 .654 .809 r
.52971 .43229 .53291 .43805 .53884 .43518 .53565 .42941 Mtetra
.684 .651 .811 r
.53565 .42941 .53884 .43518 .54479 .43247 .5416 .42668 Mtetra
.678 .649 .813 r
.5416 .42668 .54479 .43247 .55074 .42991 .54756 .42411 Mtetra
.672 .646 .816 r
.54756 .42411 .55074 .42991 .55671 .4275 .55353 .42169 Mtetra
.665 .643 .818 r
.55353 .42169 .55671 .4275 .56269 .42524 .55952 .41942 Mtetra
.659 .64 .82 r
.55952 .41942 .56269 .42524 .56869 .42314 .56552 .41731 Mtetra
.652 .637 .822 r
.56552 .41731 .56869 .42314 .5747 .4212 .57153 .41536 Mtetra
.644 .633 .824 r
.57153 .41536 .5747 .4212 .58073 .41941 .57756 .41356 Mtetra
.637 .63 .827 r
.57756 .41356 .58073 .41941 .58677 .41777 .58361 .41192 Mtetra
.63 .627 .829 r
.58361 .41192 .58677 .41777 .59283 .41629 .58967 .41043 Mtetra
.622 .623 .831 r
.58967 .41043 .59283 .41629 .59891 .41496 .59576 .4091 Mtetra
.614 .619 .833 r
.59576 .4091 .59891 .41496 .60501 .41379 .60186 .40792 Mtetra
.606 .616 .835 r
.60186 .40792 .60501 .41379 .61113 .41277 .60798 .4069 Mtetra
.598 .612 .837 r
.60798 .4069 .61113 .41277 .61727 .41191 .61413 .40603 Mtetra
.589 .608 .839 r
.61413 .40603 .61727 .41191 .62343 .41119 .62029 .40531 Mtetra
.581 .604 .841 r
.62029 .40531 .62343 .41119 .62961 .41063 .62648 .40475 Mtetra
.572 .6 .842 r
.62648 .40475 .62961 .41063 .63582 .41022 .6327 .40434 Mtetra
.563 .596 .844 r
.6327 .40434 .63582 .41022 .64206 .40995 .63894 .40407 Mtetra
.554 .592 .846 r
.63894 .40407 .64206 .40995 .64832 .40984 .6452 .40396 Mtetra
.545 .588 .848 r
.6452 .40396 .64832 .40984 .65461 .40986 .65149 .40399 Mtetra
.536 .583 .849 r
.65149 .40399 .65461 .40986 .66093 .41004 .65781 .40416 Mtetra
.527 .579 .851 r
.65781 .40416 .66093 .41004 .66727 .41035 .66416 .40448 Mtetra
.518 .575 .852 r
.66416 .40448 .66727 .41035 .67365 .4108 .67054 .40494 Mtetra
.509 .57 .853 r
.67054 .40494 .67365 .4108 .68005 .41139 .67695 .40553 Mtetra
.499 .566 .854 r
.67695 .40553 .68005 .41139 .68649 .41211 .68339 .40626 Mtetra
.49 .562 .856 r
.68339 .40626 .68649 .41211 .69296 .41297 .68986 .40712 Mtetra
.481 .557 .857 r
.68986 .40712 .69296 .41297 .69946 .41395 .69636 .40811 Mtetra
.472 .553 .858 r
.69636 .40811 .69946 .41395 .70599 .41505 .7029 .40923 Mtetra
.463 .549 .859 r
.7029 .40923 .70599 .41505 .71256 .41628 .70948 .41047 Mtetra
.454 .545 .859 r
.70948 .41047 .71256 .41628 .71916 .41763 .71608 .41182 Mtetra
.445 .541 .86 r
.71608 .41182 .71916 .41763 .7258 .41909 .72273 .4133 Mtetra
.436 .537 .861 r
.72273 .4133 .7258 .41909 .73248 .42066 .7294 .41488 Mtetra
.428 .533 .862 r
.7294 .41488 .73248 .42066 .73919 .42233 .73612 .41657 Mtetra
.42 .529 .862 r
.73612 .41657 .73919 .42233 .74593 .42411 .74287 .41836 Mtetra
.412 .526 .863 r
.74287 .41836 .74593 .42411 .75272 .42598 .74966 .42025 Mtetra
.404 .523 .864 r
.74966 .42025 .75272 .42598 .75954 .42794 .75649 .42223 Mtetra
.397 .52 .864 r
.75649 .42223 .75954 .42794 .7664 .42999 .76336 .42429 Mtetra
.39 .517 .865 r
.76336 .42429 .7664 .42999 .7733 .43211 .77026 .42644 Mtetra
.384 .514 .866 r
.77026 .42644 .7733 .43211 .78024 .43431 .77721 .42866 Mtetra
.378 .512 .866 r
.77721 .42866 .78024 .43431 .78722 .43658 .78419 .43095 Mtetra
.372 .51 .867 r
.78419 .43095 .78722 .43658 .79424 .43891 .79121 .4333 Mtetra
.367 .509 .868 r
.79121 .4333 .79424 .43891 .80129 .44129 .79827 .43571 Mtetra
.362 .508 .869 r
.79827 .43571 .80129 .44129 .80838 .44372 .80537 .43817 Mtetra
.358 .507 .87 r
.80537 .43817 .80838 .44372 .81552 .44619 .81251 .44066 Mtetra
.355 .506 .871 r
.81251 .44066 .81552 .44619 .82269 .44868 .81969 .44319 Mtetra
.352 .506 .872 r
.81969 .44319 .82269 .44868 .82989 .45121 .82691 .44574 Mtetra
.35 .507 .873 r
.82691 .44574 .82989 .45121 .83714 .45374 .83416 .44831 Mtetra
.348 .508 .875 r
.83416 .44831 .83714 .45374 .84442 .45628 .84145 .45088 Mtetra
.347 .509 .876 r
.84145 .45088 .84442 .45628 .85174 .45882 .84878 .45345 Mtetra
.347 .511 .878 r
.84878 .45345 .85174 .45882 .85909 .46134 .85614 .45601 Mtetra
.347 .513 .88 r
.85614 .45601 .85909 .46134 .86648 .46385 .86354 .45855 Mtetra
.349 .516 .882 r
.86354 .45855 .86648 .46385 .8739 .46631 .87097 .46105 Mtetra
.351 .52 .884 r
.87097 .46105 .8739 .46631 .88135 .46873 .87843 .46352 Mtetra
.354 .524 .886 r
.87843 .46352 .88135 .46873 .88884 .4711 .88593 .46592 Mtetra
.357 .529 .888 r
.88593 .46592 .88884 .4711 .89635 .4734 .89345 .46826 Mtetra
.362 .534 .891 r
.89345 .46826 .89635 .4734 .90389 .47562 .90101 .47053 Mtetra
.796 .728 .788 r
.2717 .65238 .27533 .65657 .28127 .65077 .27766 .64652 Mtetra
.797 .727 .786 r
.27766 .64652 .28127 .65077 .28722 .64488 .28362 .64058 Mtetra
.798 .725 .784 r
.28362 .64058 .28722 .64488 .29317 .63892 .28958 .63457 Mtetra
.798 .723 .782 r
.28958 .63457 .29317 .63892 .29912 .63289 .29555 .62849 Mtetra
.798 .722 .78 r
.29555 .62849 .29912 .63289 .30507 .62682 .30151 .62237 Mtetra
.798 .721 .779 r
.30151 .62237 .30507 .62682 .31103 .6207 .30748 .6162 Mtetra
.798 .719 .777 r
.30748 .6162 .31103 .6207 .31698 .61456 .31345 .61001 Mtetra
.798 .718 .776 r
.31345 .61001 .31698 .61456 .32294 .60839 .31941 .60379 Mtetra
.797 .716 .775 r
.31941 .60379 .32294 .60839 .32889 .60221 .32538 .59757 Mtetra
.797 .715 .775 r
.32538 .59757 .32889 .60221 .33484 .59603 .33134 .59134 Mtetra
.796 .714 .774 r
.33134 .59134 .33484 .59603 .34078 .58985 .33729 .58511 Mtetra
.795 .713 .774 r
.33729 .58511 .34078 .58985 .34672 .58368 .34325 .57891 Mtetra
.794 .711 .773 r
.34325 .57891 .34672 .58368 .35266 .57754 .3492 .57272 Mtetra
.793 .71 .773 r
.3492 .57272 .35266 .57754 .3586 .57142 .35515 .56656 Mtetra
.792 .709 .773 r
.35515 .56656 .3586 .57142 .36453 .56535 .36109 .56045 Mtetra
.79 .708 .773 r
.36109 .56045 .36453 .56535 .37046 .55931 .36703 .55437 Mtetra
.789 .706 .773 r
.36703 .55437 .37046 .55931 .37638 .55333 .37296 .54835 Mtetra
.787 .705 .774 r
.37296 .54835 .37638 .55333 .3823 .5474 .37889 .54239 Mtetra
.785 .704 .774 r
.37889 .54239 .3823 .5474 .38821 .54154 .38481 .53649 Mtetra
.783 .702 .775 r
.38481 .53649 .38821 .54154 .39412 .53575 .39073 .53066 Mtetra
.781 .701 .775 r
.39073 .53066 .39412 .53575 .40003 .53003 .39665 .52491 Mtetra
.779 .7 .776 r
.39665 .52491 .40003 .53003 .40593 .52439 .40256 .51924 Mtetra
.777 .698 .777 r
.40256 .51924 .40593 .52439 .41183 .51884 .40847 .51366 Mtetra
.774 .697 .778 r
.40847 .51366 .41183 .51884 .41772 .51339 .41437 .50817 Mtetra
.772 .696 .779 r
.41437 .50817 .41772 .51339 .42361 .50802 .42027 .50278 Mtetra
.769 .694 .78 r
.42027 .50278 .42361 .50802 .4295 .50276 .42617 .49749 Mtetra
.766 .693 .781 r
.42617 .49749 .4295 .50276 .43539 .49761 .43206 .49231 Mtetra
.763 .691 .783 r
.43206 .49231 .43539 .49761 .44127 .49256 .43796 .48724 Mtetra
.76 .69 .784 r
.43796 .48724 .44127 .49256 .44715 .48763 .44385 .48228 Mtetra
.757 .688 .786 r
.44385 .48228 .44715 .48763 .45303 .48282 .44974 .47744 Mtetra
.753 .687 .787 r
.44974 .47744 .45303 .48282 .45892 .47812 .45563 .47272 Mtetra
.75 .685 .789 r
.45563 .47272 .45892 .47812 .4648 .47355 .46151 .46813 Mtetra
.746 .683 .791 r
.46151 .46813 .4648 .47355 .47068 .46911 .4674 .46366 Mtetra
.742 .681 .792 r
.4674 .46366 .47068 .46911 .47656 .4648 .4733 .45933 Mtetra
.738 .679 .794 r
.4733 .45933 .47656 .4648 .48245 .46062 .47919 .45513 Mtetra
.733 .678 .796 r
.47919 .45513 .48245 .46062 .48834 .45658 .48508 .45107 Mtetra
.729 .676 .798 r
.48508 .45107 .48834 .45658 .49423 .45268 .49098 .44715 Mtetra
.724 .674 .8 r
.49098 .44715 .49423 .45268 .50013 .44892 .49689 .44337 Mtetra
.719 .671 .802 r
.49689 .44337 .50013 .44892 .50603 .4453 .5028 .43973 Mtetra
.714 .669 .804 r
.5028 .43973 .50603 .4453 .51194 .44182 .50871 .43624 Mtetra
.709 .667 .807 r
.50871 .43624 .51194 .44182 .51785 .4385 .51463 .4329 Mtetra
.704 .665 .809 r
.51463 .4329 .51785 .4385 .52378 .43532 .52056 .42971 Mtetra
.698 .662 .811 r
.52056 .42971 .52378 .43532 .52971 .43229 .5265 .42666 Mtetra
.692 .66 .813 r
.5265 .42666 .52971 .43229 .53565 .42941 .53244 .42377 Mtetra
.686 .657 .815 r
.53244 .42377 .53565 .42941 .5416 .42668 .5384 .42103 Mtetra
.68 .654 .818 r
.5384 .42103 .5416 .42668 .54756 .42411 .54436 .41844 Mtetra
.673 .651 .82 r
.54436 .41844 .54756 .42411 .55353 .42169 .55034 .41601 Mtetra
.667 .648 .822 r
.55034 .41601 .55353 .42169 .55952 .41942 .55633 .41374 Mtetra
.66 .645 .825 r
.55633 .41374 .55952 .41942 .56552 .41731 .56234 .41162 Mtetra
.653 .642 .827 r
.56234 .41162 .56552 .41731 .57153 .41536 .56836 .40966 Mtetra
.645 .639 .829 r
.56836 .40966 .57153 .41536 .57756 .41356 .57439 .40785 Mtetra
.638 .635 .831 r
.57439 .40785 .57756 .41356 .58361 .41192 .58044 .4062 Mtetra
.63 .632 .834 r
.58044 .4062 .58361 .41192 .58967 .41043 .58651 .4047 Mtetra
.622 .628 .836 r
.58651 .4047 .58967 .41043 .59576 .4091 .5926 .40337 Mtetra
.614 .625 .838 r
.5926 .40337 .59576 .4091 .60186 .40792 .59871 .40218 Mtetra
.606 .621 .84 r
.59871 .40218 .60186 .40792 .60798 .4069 .60483 .40116 Mtetra
.597 .617 .842 r
.60483 .40116 .60798 .4069 .61413 .40603 .61098 .40029 Mtetra
.589 .613 .844 r
.61098 .40029 .61413 .40603 .62029 .40531 .61715 .39957 Mtetra
.58 .609 .846 r
.61715 .39957 .62029 .40531 .62648 .40475 .62335 .399 Mtetra
.571 .605 .848 r
.62335 .399 .62648 .40475 .6327 .40434 .62956 .39859 Mtetra
.562 .601 .85 r
.62956 .39859 .6327 .40434 .63894 .40407 .63581 .39832 Mtetra
.552 .596 .851 r
.63581 .39832 .63894 .40407 .6452 .40396 .64208 .39821 Mtetra
.543 .592 .853 r
.64208 .39821 .6452 .40396 .65149 .40399 .64837 .39824 Mtetra
.534 .587 .855 r
.64837 .39824 .65149 .40399 .65781 .40416 .6547 .39842 Mtetra
.524 .583 .856 r
.6547 .39842 .65781 .40416 .66416 .40448 .66105 .39874 Mtetra
.515 .578 .857 r
.66105 .39874 .66416 .40448 .67054 .40494 .66743 .3992 Mtetra
.505 .574 .859 r
.66743 .3992 .67054 .40494 .67695 .40553 .67384 .3998 Mtetra
.495 .569 .86 r
.67384 .3998 .67695 .40553 .68339 .40626 .68029 .40053 Mtetra
.486 .565 .861 r
.68029 .40053 .68339 .40626 .68986 .40712 .68676 .4014 Mtetra
.476 .56 .862 r
.68676 .4014 .68986 .40712 .69636 .40811 .69327 .4024 Mtetra
.467 .556 .863 r
.69327 .4024 .69636 .40811 .7029 .40923 .69981 .40352 Mtetra
.457 .551 .864 r
.69981 .40352 .7029 .40923 .70948 .41047 .70639 .40477 Mtetra
.448 .547 .865 r
.70639 .40477 .70948 .41047 .71608 .41182 .713 .40614 Mtetra
.439 .543 .865 r
.713 .40614 .71608 .41182 .72273 .4133 .71965 .40762 Mtetra
.43 .539 .866 r
.71965 .40762 .72273 .4133 .7294 .41488 .72633 .40922 Mtetra
.422 .535 .866 r
.72633 .40922 .7294 .41488 .73612 .41657 .73305 .41092 Mtetra
.413 .531 .867 r
.73305 .41092 .73612 .41657 .74287 .41836 .73981 .41272 Mtetra
.405 .527 .868 r
.73981 .41272 .74287 .41836 .74966 .42025 .74661 .41463 Mtetra
.397 .524 .868 r
.74661 .41463 .74966 .42025 .75649 .42223 .75344 .41662 Mtetra
.39 .521 .869 r
.75344 .41662 .75649 .42223 .76336 .42429 .76031 .41871 Mtetra
.383 .518 .869 r
.76031 .41871 .76336 .42429 .77026 .42644 .76722 .42087 Mtetra
.376 .515 .87 r
.76722 .42087 .77026 .42644 .77721 .42866 .77417 .42311 Mtetra
.37 .513 .87 r
.77417 .42311 .77721 .42866 .78419 .43095 .78116 .42542 Mtetra
.364 .511 .871 r
.78116 .42542 .78419 .43095 .79121 .4333 .78819 .4278 Mtetra
.359 .509 .872 r
.78819 .4278 .79121 .4333 .79827 .43571 .79526 .43023 Mtetra
.354 .507 .872 r
.79526 .43023 .79827 .43571 .80537 .43817 .80236 .43271 Mtetra
.35 .507 .873 r
.80236 .43271 .80537 .43817 .81251 .44066 .80951 .43523 Mtetra
.346 .506 .874 r
.80951 .43523 .81251 .44066 .81969 .44319 .8167 .43778 Mtetra
.343 .506 .875 r
.8167 .43778 .81969 .44319 .82691 .44574 .82392 .44036 Mtetra
.341 .506 .876 r
.82392 .44036 .82691 .44574 .83416 .44831 .83118 .44295 Mtetra
.339 .507 .877 r
.83118 .44295 .83416 .44831 .84145 .45088 .83848 .44556 Mtetra
.338 .508 .879 r
.83848 .44556 .84145 .45088 .84878 .45345 .84582 .44816 Mtetra
.338 .51 .88 r
.84582 .44816 .84878 .45345 .85614 .45601 .85319 .45075 Mtetra
.338 .512 .882 r
.85319 .45075 .85614 .45601 .86354 .45855 .8606 .45333 Mtetra
.34 .515 .884 r
.8606 .45333 .86354 .45855 .87097 .46105 .86804 .45587 Mtetra
.342 .519 .886 r
.86804 .45587 .87097 .46105 .87843 .46352 .87551 .45836 Mtetra
.345 .523 .888 r
.87551 .45836 .87843 .46352 .88593 .46592 .88302 .46081 Mtetra
.349 .528 .891 r
.88302 .46081 .88593 .46592 .89345 .46826 .89056 .46319 Mtetra
.354 .533 .893 r
.89056 .46319 .89345 .46826 .90101 .47053 .89812 .46549 Mtetra
.799 .731 .789 r
.26805 .64826 .2717 .65238 .27766 .64652 .27402 .64234 Mtetra
.799 .729 .787 r
.27402 .64234 .27766 .64652 .28362 .64058 .28 .63635 Mtetra
.8 .728 .785 r
.28 .63635 .28362 .64058 .28958 .63457 .28598 .63028 Mtetra
.8 .727 .783 r
.28598 .63028 .28958 .63457 .29555 .62849 .29195 .62416 Mtetra
.801 .725 .781 r
.29195 .62416 .29555 .62849 .30151 .62237 .29793 .61799 Mtetra
.801 .724 .78 r
.29793 .61799 .30151 .62237 .30748 .6162 .30391 .61178 Mtetra
.8 .723 .778 r
.30391 .61178 .30748 .6162 .31345 .61001 .30989 .60554 Mtetra
.8 .721 .777 r
.30989 .60554 .31345 .61001 .31941 .60379 .31587 .59928 Mtetra
.8 .72 .777 r
.31587 .59928 .31941 .60379 .32538 .59757 .32185 .59301 Mtetra
.799 .719 .776 r
.32185 .59301 .32538 .59757 .33134 .59134 .32782 .58673 Mtetra
.798 .718 .775 r
.32782 .58673 .33134 .59134 .33729 .58511 .33379 .58047 Mtetra
.798 .716 .775 r
.33379 .58047 .33729 .58511 .34325 .57891 .33976 .57422 Mtetra
.797 .715 .775 r
.33976 .57422 .34325 .57891 .3492 .57272 .34572 .568 Mtetra
.795 .714 .775 r
.34572 .568 .3492 .57272 .35515 .56656 .35168 .5618 Mtetra
.794 .713 .775 r
.35168 .5618 .35515 .56656 .36109 .56045 .35763 .55565 Mtetra
.793 .712 .775 r
.35763 .55565 .36109 .56045 .36703 .55437 .36358 .54954 Mtetra
.791 .71 .775 r
.36358 .54954 .36703 .55437 .37296 .54835 .36953 .54348 Mtetra
.79 .709 .775 r
.36953 .54348 .37296 .54835 .37889 .54239 .37546 .53748 Mtetra
.788 .708 .776 r
.37546 .53748 .37889 .54239 .38481 .53649 .3814 .53155 Mtetra
.786 .707 .777 r
.3814 .53155 .38481 .53649 .39073 .53066 .38733 .52569 Mtetra
.784 .706 .777 r
.38733 .52569 .39073 .53066 .39665 .52491 .39326 .51991 Mtetra
.782 .704 .778 r
.39326 .51991 .39665 .52491 .40256 .51924 .39918 .51421 Mtetra
.78 .703 .779 r
.39918 .51421 .40256 .51924 .40847 .51366 .40509 .50859 Mtetra
.777 .702 .78 r
.40509 .50859 .40847 .51366 .41437 .50817 .41101 .50308 Mtetra
.775 .7 .781 r
.41101 .50308 .41437 .50817 .42027 .50278 .41692 .49766 Mtetra
.772 .699 .783 r
.41692 .49766 .42027 .50278 .42617 .49749 .42282 .49234 Mtetra
.769 .698 .784 r
.42282 .49234 .42617 .49749 .43206 .49231 .42873 .48713 Mtetra
.766 .696 .785 r
.42873 .48713 .43206 .49231 .43796 .48724 .43463 .48203 Mtetra
.763 .695 .787 r
.43463 .48203 .43796 .48724 .44385 .48228 .44053 .47705 Mtetra
.759 .693 .788 r
.44053 .47705 .44385 .48228 .44974 .47744 .44643 .47219 Mtetra
.756 .692 .79 r
.44643 .47219 .44974 .47744 .45563 .47272 .45232 .46744 Mtetra
.752 .69 .792 r
.45232 .46744 .45563 .47272 .46151 .46813 .45822 .46283 Mtetra
.749 .689 .794 r
.45822 .46283 .46151 .46813 .4674 .46366 .46412 .45834 Mtetra
.745 .687 .796 r
.46412 .45834 .4674 .46366 .4733 .45933 .47002 .45399 Mtetra
.74 .685 .798 r
.47002 .45399 .4733 .45933 .47919 .45513 .47592 .44977 Mtetra
.736 .683 .8 r
.47592 .44977 .47919 .45513 .48508 .45107 .48182 .44569 Mtetra
.731 .681 .802 r
.48182 .44569 .48508 .45107 .49098 .44715 .48773 .44175 Mtetra
.727 .679 .804 r
.48773 .44175 .49098 .44715 .49689 .44337 .49364 .43795 Mtetra
.722 .677 .806 r
.49364 .43795 .49689 .44337 .5028 .43973 .49955 .4343 Mtetra
.717 .675 .808 r
.49955 .4343 .5028 .43973 .50871 .43624 .50547 .43079 Mtetra
.711 .673 .811 r
.50547 .43079 .50871 .43624 .51463 .4329 .5114 .42744 Mtetra
.706 .67 .813 r
.5114 .42744 .51463 .4329 .52056 .42971 .51733 .42423 Mtetra
.7 .668 .815 r
.51733 .42423 .52056 .42971 .5265 .42666 .52328 .42117 Mtetra
.694 .665 .818 r
.52328 .42117 .5265 .42666 .53244 .42377 .52923 .41826 Mtetra
.688 .663 .82 r
.52923 .41826 .53244 .42377 .5384 .42103 .53519 .41551 Mtetra
.681 .66 .822 r
.53519 .41551 .5384 .42103 .54436 .41844 .54116 .41291 Mtetra
.675 .657 .825 r
.54116 .41291 .54436 .41844 .55034 .41601 .54714 .41047 Mtetra
.668 .654 .827 r
.54714 .41047 .55034 .41601 .55633 .41374 .55314 .40819 Mtetra
.661 .651 .83 r
.55314 .40819 .55633 .41374 .56234 .41162 .55915 .40606 Mtetra
.654 .648 .832 r
.55915 .40606 .56234 .41162 .56836 .40966 .56517 .40409 Mtetra
.646 .645 .834 r
.56517 .40409 .56836 .40966 .57439 .40785 .57121 .40227 Mtetra
.638 .641 .837 r
.57121 .40227 .57439 .40785 .58044 .4062 .57727 .40061 Mtetra
.63 .638 .839 r
.57727 .40061 .58044 .4062 .58651 .4047 .58334 .39911 Mtetra
.622 .634 .841 r
.58334 .39911 .58651 .4047 .5926 .40337 .58944 .39777 Mtetra
.614 .63 .844 r
.58944 .39777 .5926 .40337 .59871 .40218 .59555 .39658 Mtetra
.605 .626 .846 r
.59555 .39658 .59871 .40218 .60483 .40116 .60168 .39555 Mtetra
.597 .622 .848 r
.60168 .39555 .60483 .40116 .61098 .40029 .60783 .39467 Mtetra
.588 .618 .85 r
.60783 .39467 .61098 .40029 .61715 .39957 .61401 .39395 Mtetra
.579 .614 .852 r
.61401 .39395 .61715 .39957 .62335 .399 .6202 .39338 Mtetra
.569 .61 .854 r
.6202 .39338 .62335 .399 .62956 .39859 .62643 .39297 Mtetra
.56 .606 .856 r
.62643 .39297 .62956 .39859 .63581 .39832 .63267 .3927 Mtetra
.55 .601 .857 r
.63267 .3927 .63581 .39832 .64208 .39821 .63895 .39259 Mtetra
.541 .597 .859 r
.63895 .39259 .64208 .39821 .64837 .39824 .64525 .39262 Mtetra
.531 .592 .86 r
.64525 .39262 .64837 .39824 .6547 .39842 .65158 .3928 Mtetra
.521 .587 .862 r
.65158 .3928 .6547 .39842 .66105 .39874 .65793 .39312 Mtetra
.511 .583 .863 r
.65793 .39312 .66105 .39874 .66743 .3992 .66432 .39359 Mtetra
.501 .578 .864 r
.66432 .39359 .66743 .3992 .67384 .3998 .67074 .39419 Mtetra
.491 .573 .866 r
.67074 .39419 .67384 .3998 .68029 .40053 .67718 .39493 Mtetra
.481 .568 .867 r
.67718 .39493 .68029 .40053 .68676 .4014 .68366 .3958 Mtetra
.471 .564 .867 r
.68366 .3958 .68676 .4014 .69327 .4024 .69018 .39681 Mtetra
.462 .559 .868 r
.69018 .39681 .69327 .4024 .69981 .40352 .69672 .39794 Mtetra
.452 .554 .869 r
.69672 .39794 .69981 .40352 .70639 .40477 .7033 .39919 Mtetra
.442 .55 .87 r
.7033 .39919 .70639 .40477 .713 .40614 .70992 .40057 Mtetra
.433 .545 .87 r
.70992 .40057 .713 .40614 .71965 .40762 .71657 .40206 Mtetra
.424 .541 .871 r
.71657 .40206 .71965 .40762 .72633 .40922 .72326 .40367 Mtetra
.415 .537 .871 r
.72326 .40367 .72633 .40922 .73305 .41092 .72998 .40538 Mtetra
.406 .533 .872 r
.72998 .40538 .73305 .41092 .73981 .41272 .73675 .4072 Mtetra
.398 .529 .872 r
.73675 .4072 .73981 .41272 .74661 .41463 .74355 .40912 Mtetra
.39 .525 .873 r
.74355 .40912 .74661 .41463 .75344 .41662 .75039 .41113 Mtetra
.382 .522 .873 r
.75039 .41113 .75344 .41662 .76031 .41871 .75726 .41323 Mtetra
.375 .519 .873 r
.75726 .41323 .76031 .41871 .76722 .42087 .76418 .41541 Mtetra
.368 .516 .874 r
.76418 .41541 .76722 .42087 .77417 .42311 .77114 .41767 Mtetra
.361 .513 .874 r
.77114 .41767 .77417 .42311 .78116 .42542 .77813 .42 Mtetra
.355 .511 .875 r
.77813 .42 .78116 .42542 .78819 .4278 .78517 .42239 Mtetra
.35 .509 .875 r
.78517 .42239 .78819 .4278 .79526 .43023 .79224 .42484 Mtetra
.345 .508 .876 r
.79224 .42484 .79526 .43023 .80236 .43271 .79935 .42734 Mtetra
.341 .506 .876 r
.79935 .42734 .80236 .43271 .80951 .43523 .80651 .42988 Mtetra
.337 .506 .877 r
.80651 .42988 .80951 .43523 .8167 .43778 .8137 .43246 Mtetra
.334 .505 .878 r
.8137 .43246 .8167 .43778 .82392 .44036 .82093 .43507 Mtetra
.332 .506 .879 r
.82093 .43507 .82392 .44036 .83118 .44295 .8282 .43769 Mtetra
.33 .506 .88 r
.8282 .43769 .83118 .44295 .83848 .44556 .83551 .44032 Mtetra
.329 .508 .882 r
.83551 .44032 .83848 .44556 .84582 .44816 .84285 .44295 Mtetra
.329 .509 .883 r
.84285 .44295 .84582 .44816 .85319 .45075 .85024 .44557 Mtetra
.33 .512 .885 r
.85024 .44557 .85319 .45075 .8606 .45333 .85765 .44818 Mtetra
.331 .514 .886 r
.85765 .44818 .8606 .45333 .86804 .45587 .8651 .45075 Mtetra
.333 .518 .888 r
.8651 .45075 .86804 .45587 .87551 .45836 .87259 .45328 Mtetra
.336 .522 .89 r
.87259 .45328 .87551 .45836 .88302 .46081 .88011 .45576 Mtetra
.341 .527 .893 r
.88011 .45576 .88302 .46081 .89056 .46319 .88766 .45817 Mtetra
.346 .532 .895 r
.88766 .45817 .89056 .46319 .89812 .46549 .89523 .46051 Mtetra
.801 .734 .79 r
.26439 .64419 .26805 .64826 .27402 .64234 .27037 .63823 Mtetra
.802 .732 .787 r
.27037 .63823 .27402 .64234 .28 .63635 .27636 .63218 Mtetra
.802 .731 .785 r
.27636 .63218 .28 .63635 .28598 .63028 .28235 .62607 Mtetra
.803 .73 .784 r
.28235 .62607 .28598 .63028 .29195 .62416 .28834 .6199 Mtetra
.803 .728 .782 r
.28834 .6199 .29195 .62416 .29793 .61799 .29434 .61369 Mtetra
.803 .727 .781 r
.29434 .61369 .29793 .61799 .30391 .61178 .30033 .60743 Mtetra
.803 .726 .78 r
.30033 .60743 .30391 .61178 .30989 .60554 .30632 .60115 Mtetra
.803 .725 .779 r
.30632 .60115 .30989 .60554 .31587 .59928 .31231 .59484 Mtetra
.802 .724 .778 r
.31231 .59484 .31587 .59928 .32185 .59301 .3183 .58853 Mtetra
.802 .723 .777 r
.3183 .58853 .32185 .59301 .32782 .58673 .32429 .58222 Mtetra
.801 .721 .777 r
.32429 .58222 .32782 .58673 .33379 .58047 .33027 .57592 Mtetra
.8 .72 .776 r
.33027 .57592 .33379 .58047 .33976 .57422 .33625 .56963 Mtetra
.799 .719 .776 r
.33625 .56963 .33976 .57422 .34572 .568 .34222 .56337 Mtetra
.798 .718 .776 r
.34222 .56337 .34572 .568 .35168 .5618 .34819 .55714 Mtetra
.797 .717 .776 r
.34819 .55714 .35168 .5618 .35763 .55565 .35416 .55095 Mtetra
.795 .716 .776 r
.35416 .55095 .35763 .55565 .36358 .54954 .36012 .5448 Mtetra
.794 .715 .777 r
.36012 .5448 .36358 .54954 .36953 .54348 .36607 .53871 Mtetra
.792 .714 .777 r
.36607 .53871 .36953 .54348 .37546 .53748 .37203 .53268 Mtetra
.791 .713 .778 r
.37203 .53268 .37546 .53748 .3814 .53155 .37797 .52672 Mtetra
.789 .711 .779 r
.37797 .52672 .3814 .53155 .38733 .52569 .38391 .52083 Mtetra
.787 .71 .779 r
.38391 .52083 .38733 .52569 .39326 .51991 .38985 .51501 Mtetra
.785 .709 .78 r
.38985 .51501 .39326 .51991 .39918 .51421 .39578 .50928 Mtetra
.782 .708 .781 r
.39578 .50928 .39918 .51421 .40509 .50859 .40171 .50364 Mtetra
.78 .707 .783 r
.40171 .50364 .40509 .50859 .41101 .50308 .40763 .4981 Mtetra
.777 .705 .784 r
.40763 .4981 .41101 .50308 .41692 .49766 .41355 .49265 Mtetra
.775 .704 .785 r
.41355 .49265 .41692 .49766 .42282 .49234 .41946 .48731 Mtetra
.772 .703 .787 r
.41946 .48731 .42282 .49234 .42873 .48713 .42538 .48207 Mtetra
.769 .702 .788 r
.42538 .48207 .42873 .48713 .43463 .48203 .43129 .47695 Mtetra
.766 .7 .79 r
.43129 .47695 .43463 .48203 .44053 .47705 .43719 .47194 Mtetra
.762 .699 .791 r
.43719 .47194 .44053 .47705 .44643 .47219 .4431 .46706 Mtetra
.759 .697 .793 r
.4431 .46706 .44643 .47219 .45232 .46744 .44901 .4623 Mtetra
.755 .696 .795 r
.44901 .4623 .45232 .46744 .45822 .46283 .45491 .45766 Mtetra
.751 .694 .797 r
.45491 .45766 .45822 .46283 .46412 .45834 .46082 .45315 Mtetra
.747 .692 .799 r
.46082 .45315 .46412 .45834 .47002 .45399 .46673 .44878 Mtetra
.743 .691 .801 r
.46673 .44878 .47002 .45399 .47592 .44977 .47263 .44454 Mtetra
.739 .689 .803 r
.47263 .44454 .47592 .44977 .48182 .44569 .47854 .44044 Mtetra
.734 .687 .805 r
.47854 .44044 .48182 .44569 .48773 .44175 .48446 .43649 Mtetra
.729 .685 .808 r
.48446 .43649 .48773 .44175 .49364 .43795 .49037 .43267 Mtetra
.724 .683 .81 r
.49037 .43267 .49364 .43795 .49955 .4343 .4963 .429 Mtetra
.719 .681 .812 r
.4963 .429 .49955 .4343 .50547 .43079 .50222 .42548 Mtetra
.714 .679 .815 r
.50222 .42548 .50547 .43079 .5114 .42744 .50816 .42211 Mtetra
.708 .676 .817 r
.50816 .42211 .5114 .42744 .51733 .42423 .5141 .41888 Mtetra
.702 .674 .82 r
.5141 .41888 .51733 .42423 .52328 .42117 .52005 .41581 Mtetra
.696 .671 .822 r
.52005 .41581 .52328 .42117 .52923 .41826 .526 .41289 Mtetra
.69 .669 .825 r
.526 .41289 .52923 .41826 .53519 .41551 .53197 .41013 Mtetra
.683 .666 .827 r
.53197 .41013 .53519 .41551 .54116 .41291 .53795 .40752 Mtetra
.676 .663 .83 r
.53795 .40752 .54116 .41291 .54714 .41047 .54394 .40507 Mtetra
.669 .66 .832 r
.54394 .40507 .54714 .41047 .55314 .40819 .54994 .40277 Mtetra
.662 .657 .835 r
.54994 .40277 .55314 .40819 .55915 .40606 .55596 .40063 Mtetra
.655 .654 .837 r
.55596 .40063 .55915 .40606 .56517 .40409 .56199 .39865 Mtetra
.647 .651 .84 r
.56199 .39865 .56517 .40409 .57121 .40227 .56803 .39683 Mtetra
.639 .647 .842 r
.56803 .39683 .57121 .40227 .57727 .40061 .57409 .39516 Mtetra
.631 .644 .845 r
.57409 .39516 .57727 .40061 .58334 .39911 .58017 .39366 Mtetra
.622 .64 .847 r
.58017 .39366 .58334 .39911 .58944 .39777 .58627 .39231 Mtetra
.614 .636 .849 r
.58627 .39231 .58944 .39777 .59555 .39658 .59238 .39111 Mtetra
.605 .632 .851 r
.59238 .39111 .59555 .39658 .60168 .39555 .59852 .39008 Mtetra
.596 .628 .854 r
.59852 .39008 .60168 .39555 .60783 .39467 .60468 .3892 Mtetra
.587 .624 .856 r
.60468 .3892 .60783 .39467 .61401 .39395 .61086 .38847 Mtetra
.577 .62 .858 r
.61086 .38847 .61401 .39395 .6202 .39338 .61706 .3879 Mtetra
.568 .615 .86 r
.61706 .3879 .6202 .39338 .62643 .39297 .62329 .38748 Mtetra
.558 .611 .862 r
.62329 .38748 .62643 .39297 .63267 .3927 .62954 .38722 Mtetra
.548 .606 .863 r
.62954 .38722 .63267 .3927 .63895 .39259 .63582 .3871 Mtetra
.538 .601 .865 r
.63582 .3871 .63895 .39259 .64525 .39262 .64212 .38714 Mtetra
.528 .597 .866 r
.64212 .38714 .64525 .39262 .65158 .3928 .64845 .38731 Mtetra
.518 .592 .868 r
.64845 .38731 .65158 .3928 .65793 .39312 .65481 .38764 Mtetra
.507 .587 .869 r
.65481 .38764 .65793 .39312 .66432 .39359 .6612 .3881 Mtetra
.497 .582 .87 r
.6612 .3881 .66432 .39359 .67074 .39419 .66762 .38871 Mtetra
.487 .577 .871 r
.66762 .38871 .67074 .39419 .67718 .39493 .67408 .38945 Mtetra
.477 .572 .872 r
.67408 .38945 .67718 .39493 .68366 .3958 .68056 .39033 Mtetra
.466 .567 .873 r
.68056 .39033 .68366 .3958 .69018 .39681 .68708 .39134 Mtetra
.456 .562 .874 r
.68708 .39134 .69018 .39681 .69672 .39794 .69363 .39248 Mtetra
.446 .557 .875 r
.69363 .39248 .69672 .39794 .7033 .39919 .70022 .39374 Mtetra
.436 .553 .875 r
.70022 .39374 .7033 .39919 .70992 .40057 .70684 .39513 Mtetra
.426 .548 .876 r
.70684 .39513 .70992 .40057 .71657 .40206 .71349 .39663 Mtetra
.417 .543 .876 r
.71349 .39663 .71657 .40206 .72326 .40367 .72019 .39824 Mtetra
.408 .539 .876 r
.72019 .39824 .72326 .40367 .72998 .40538 .72692 .39997 Mtetra
.399 .535 .877 r
.72692 .39997 .72998 .40538 .73675 .4072 .73368 .4018 Mtetra
.39 .531 .877 r
.73368 .4018 .73675 .4072 .74355 .40912 .74049 .40372 Mtetra
.382 .527 .877 r
.74049 .40372 .74355 .40912 .75039 .41113 .74733 .40575 Mtetra
.374 .523 .877 r
.74733 .40575 .75039 .41113 .75726 .41323 .75422 .40786 Mtetra
.366 .52 .878 r
.75422 .40786 .75726 .41323 .76418 .41541 .76114 .41006 Mtetra
.359 .517 .878 r
.76114 .41006 .76418 .41541 .77114 .41767 .7681 .41233 Mtetra
.352 .514 .878 r
.7681 .41233 .77114 .41767 .77813 .42 .7751 .41468 Mtetra
.346 .511 .878 r
.7751 .41468 .77813 .42 .78517 .42239 .78214 .41709 Mtetra
.341 .509 .879 r
.78214 .41709 .78517 .42239 .79224 .42484 .78922 .41956 Mtetra
.336 .508 .879 r
.78922 .41956 .79224 .42484 .79935 .42734 .79634 .42208 Mtetra
.331 .506 .88 r
.79634 .42208 .79935 .42734 .80651 .42988 .8035 .42464 Mtetra
.328 .506 .88 r
.8035 .42464 .80651 .42988 .8137 .43246 .8107 .42724 Mtetra
.325 .505 .881 r
.8107 .42724 .8137 .43246 .82093 .43507 .81794 .42987 Mtetra
.322 .505 .882 r
.81794 .42987 .82093 .43507 .8282 .43769 .82522 .43251 Mtetra
.321 .506 .883 r
.82522 .43251 .8282 .43769 .83551 .44032 .83254 .43517 Mtetra
.32 .507 .884 r
.83254 .43517 .83551 .44032 .84285 .44295 .83989 .43782 Mtetra
.32 .509 .886 r
.83989 .43782 .84285 .44295 .85024 .44557 .84728 .44047 Mtetra
.32 .511 .887 r
.84728 .44047 .85024 .44557 .85765 .44818 .85471 .4431 Mtetra
.322 .514 .889 r
.85471 .4431 .85765 .44818 .8651 .45075 .86217 .4457 Mtetra
.324 .517 .891 r
.86217 .4457 .8651 .45075 .87259 .45328 .86967 .44826 Mtetra
.328 .521 .893 r
.86967 .44826 .87259 .45328 .88011 .45576 .87719 .45077 Mtetra
.332 .526 .895 r
.87719 .45077 .88011 .45576 .88766 .45817 .88475 .45322 Mtetra
.337 .531 .897 r
.88475 .45322 .88766 .45817 .89523 .46051 .89234 .4556 Mtetra
.803 .737 .791 r
.26071 .64018 .26439 .64419 .27037 .63823 .26671 .63418 Mtetra
.804 .736 .788 r
.26671 .63418 .27037 .63823 .27636 .63218 .27271 .62809 Mtetra
.804 .734 .786 r
.27271 .62809 .27636 .63218 .28235 .62607 .27871 .62194 Mtetra
.805 .733 .785 r
.27871 .62194 .28235 .62607 .28834 .6199 .28472 .61572 Mtetra
.805 .732 .783 r
.28472 .61572 .28834 .6199 .29434 .61369 .29072 .60946 Mtetra
.805 .731 .782 r
.29072 .60946 .29434 .61369 .30033 .60743 .29673 .60317 Mtetra
.805 .73 .781 r
.29673 .60317 .30033 .60743 .30632 .60115 .30273 .59684 Mtetra
.805 .729 .78 r
.30273 .59684 .30632 .60115 .31231 .59484 .30874 .5905 Mtetra
.805 .727 .779 r
.30874 .5905 .31231 .59484 .3183 .58853 .31474 .58415 Mtetra
.804 .726 .779 r
.31474 .58415 .3183 .58853 .32429 .58222 .32074 .5778 Mtetra
.803 .725 .778 r
.32074 .5778 .32429 .58222 .33027 .57592 .32673 .57146 Mtetra
.803 .724 .778 r
.32673 .57146 .33027 .57592 .33625 .56963 .33272 .56514 Mtetra
.802 .723 .778 r
.33272 .56514 .33625 .56963 .34222 .56337 .33871 .55884 Mtetra
.801 .722 .778 r
.33871 .55884 .34222 .56337 .34819 .55714 .34469 .55258 Mtetra
.8 .721 .778 r
.34469 .55258 .34819 .55714 .35416 .55095 .35067 .54635 Mtetra
.798 .72 .778 r
.35067 .54635 .35416 .55095 .36012 .5448 .35664 .54018 Mtetra
.797 .719 .779 r
.35664 .54018 .36012 .5448 .36607 .53871 .36261 .53405 Mtetra
.795 .718 .779 r
.36261 .53405 .36607 .53871 .37203 .53268 .36857 .52799 Mtetra
.793 .717 .78 r
.36857 .52799 .37203 .53268 .37797 .52672 .37453 .522 Mtetra
.792 .716 .781 r
.37453 .522 .37797 .52672 .38391 .52083 .38048 .51608 Mtetra
.79 .715 .782 r
.38048 .51608 .38391 .52083 .38985 .51501 .38642 .51024 Mtetra
.788 .714 .783 r
.38642 .51024 .38985 .51501 .39578 .50928 .39236 .50448 Mtetra
.785 .713 .784 r
.39236 .50448 .39578 .50928 .40171 .50364 .3983 .49881 Mtetra
.783 .712 .785 r
.3983 .49881 .40171 .50364 .40763 .4981 .40424 .49324 Mtetra
.78 .711 .786 r
.40424 .49324 .40763 .4981 .41355 .49265 .41016 .48777 Mtetra
.778 .709 .788 r
.41016 .48777 .41355 .49265 .41946 .48731 .41609 .4824 Mtetra
.775 .708 .789 r
.41609 .4824 .41946 .48731 .42538 .48207 .42201 .47714 Mtetra
.772 .707 .791 r
.42201 .47714 .42538 .48207 .43129 .47695 .42793 .472 Mtetra
.769 .706 .793 r
.42793 .472 .43129 .47695 .43719 .47194 .43385 .46697 Mtetra
.765 .704 .794 r
.43385 .46697 .43719 .47194 .4431 .46706 .43976 .46206 Mtetra
.762 .703 .796 r
.43976 .46206 .4431 .46706 .44901 .4623 .44568 .45727 Mtetra
.758 .701 .798 r
.44568 .45727 .44901 .4623 .45491 .45766 .45159 .45262 Mtetra
.754 .7 .8 r
.45159 .45262 .45491 .45766 .46082 .45315 .45751 .44809 Mtetra
.75 .698 .802 r
.45751 .44809 .46082 .45315 .46673 .44878 .46342 .4437 Mtetra
.746 .697 .805 r
.46342 .4437 .46673 .44878 .47263 .44454 .46934 .43945 Mtetra
.741 .695 .807 r
.46934 .43945 .47263 .44454 .47854 .44044 .47526 .43533 Mtetra
.737 .693 .809 r
.47526 .43533 .47854 .44044 .48446 .43649 .48118 .43135 Mtetra
.732 .691 .812 r
.48118 .43135 .48446 .43649 .49037 .43267 .4871 .42752 Mtetra
.727 .689 .814 r
.4871 .42752 .49037 .43267 .4963 .429 .49303 .42384 Mtetra
.722 .687 .816 r
.49303 .42384 .4963 .429 .50222 .42548 .49897 .4203 Mtetra
.716 .685 .819 r
.49897 .4203 .50222 .42548 .50816 .42211 .50491 .41691 Mtetra
.71 .683 .822 r
.50491 .41691 .50816 .42211 .5141 .41888 .51085 .41368 Mtetra
.704 .68 .824 r
.51085 .41368 .5141 .41888 .52005 .41581 .51681 .41059 Mtetra
.698 .678 .827 r
.51681 .41059 .52005 .41581 .526 .41289 .52277 .40766 Mtetra
.692 .675 .829 r
.52277 .40766 .526 .41289 .53197 .41013 .52875 .40488 Mtetra
.685 .673 .832 r
.52875 .40488 .53197 .41013 .53795 .40752 .53473 .40226 Mtetra
.678 .67 .835 r
.53473 .40226 .53795 .40752 .54394 .40507 .54073 .3998 Mtetra
.671 .667 .837 r
.54073 .3998 .54394 .40507 .54994 .40277 .54673 .3975 Mtetra
.663 .664 .84 r
.54673 .3975 .54994 .40277 .55596 .40063 .55275 .39535 Mtetra
.656 .66 .843 r
.55275 .39535 .55596 .40063 .56199 .39865 .55879 .39336 Mtetra
.648 .657 .845 r
.55879 .39336 .56199 .39865 .56803 .39683 .56484 .39153 Mtetra
.64 .654 .848 r
.56484 .39153 .56803 .39683 .57409 .39516 .57091 .38985 Mtetra
.631 .65 .85 r
.57091 .38985 .57409 .39516 .58017 .39366 .57699 .38834 Mtetra
.623 .646 .853 r
.57699 .38834 .58017 .39366 .58627 .39231 .58309 .38698 Mtetra
.614 .642 .855 r
.58309 .38698 .58627 .39231 .59238 .39111 .58921 .38579 Mtetra
.605 .638 .858 r
.58921 .38579 .59238 .39111 .59852 .39008 .59535 .38474 Mtetra
.595 .634 .86 r
.59535 .38474 .59852 .39008 .60468 .3892 .60152 .38386 Mtetra
.586 .63 .862 r
.60152 .38386 .60468 .3892 .61086 .38847 .6077 .38313 Mtetra
.576 .625 .864 r
.6077 .38313 .61086 .38847 .61706 .3879 .61391 .38256 Mtetra
.566 .621 .866 r
.61391 .38256 .61706 .3879 .62329 .38748 .62014 .38214 Mtetra
.556 .616 .868 r
.62014 .38214 .62329 .38748 .62954 .38722 .6264 .38187 Mtetra
.546 .611 .87 r
.6264 .38187 .62954 .38722 .63582 .3871 .63268 .38175 Mtetra
.535 .606 .871 r
.63268 .38175 .63582 .3871 .64212 .38714 .63899 .38178 Mtetra
.525 .602 .873 r
.63899 .38178 .64212 .38714 .64845 .38731 .64532 .38196 Mtetra
.514 .596 .874 r
.64532 .38196 .64845 .38731 .65481 .38764 .65169 .38229 Mtetra
.504 .591 .875 r
.65169 .38229 .65481 .38764 .6612 .3881 .65809 .38275 Mtetra
.493 .586 .876 r
.65809 .38275 .6612 .3881 .66762 .38871 .66451 .38336 Mtetra
.482 .581 .877 r
.66451 .38336 .66762 .38871 .67408 .38945 .67097 .38411 Mtetra
.472 .576 .878 r
.67097 .38411 .67408 .38945 .68056 .39033 .67746 .38499 Mtetra
.461 .571 .879 r
.67746 .38499 .68056 .39033 .68708 .39134 .68398 .386 Mtetra
.45 .566 .88 r
.68398 .386 .68708 .39134 .69363 .39248 .69053 .38715 Mtetra
.44 .561 .88 r
.69053 .38715 .69363 .39248 .70022 .39374 .69712 .38841 Mtetra
.43 .555 .881 r
.69712 .38841 .70022 .39374 .70684 .39513 .70375 .3898 Mtetra
.42 .551 .881 r
.70375 .3898 .70684 .39513 .71349 .39663 .71041 .39131 Mtetra
.41 .546 .881 r
.71041 .39131 .71349 .39663 .72019 .39824 .71711 .39294 Mtetra
.4 .541 .881 r
.71711 .39294 .72019 .39824 .72692 .39997 .72384 .39467 Mtetra
.391 .537 .882 r
.72384 .39467 .72692 .39997 .73368 .4018 .73062 .39651 Mtetra
.382 .532 .882 r
.73062 .39651 .73368 .4018 .74049 .40372 .73743 .39845 Mtetra
.373 .528 .882 r
.73743 .39845 .74049 .40372 .74733 .40575 .74428 .40048 Mtetra
.365 .524 .882 r
.74428 .40048 .74733 .40575 .75422 .40786 .75117 .40261 Mtetra
.357 .521 .882 r
.75117 .40261 .75422 .40786 .76114 .41006 .75809 .40482 Mtetra
.35 .517 .882 r
.75809 .40482 .76114 .41006 .7681 .41233 .76506 .4071 Mtetra
.343 .514 .882 r
.76506 .4071 .7681 .41233 .7751 .41468 .77207 .40946 Mtetra
.337 .512 .882 r
.77207 .40946 .7751 .41468 .78214 .41709 .77912 .41189 Mtetra
.331 .51 .882 r
.77912 .41189 .78214 .41709 .78922 .41956 .7862 .41437 Mtetra
.326 .508 .883 r
.7862 .41437 .78922 .41956 .79634 .42208 .79333 .41691 Mtetra
.322 .506 .883 r
.79333 .41691 .79634 .42208 .8035 .42464 .8005 .41949 Mtetra
.318 .505 .884 r
.8005 .41949 .8035 .42464 .8107 .42724 .80771 .42211 Mtetra
.315 .505 .884 r
.80771 .42211 .8107 .42724 .81794 .42987 .81495 .42476 Mtetra
.313 .505 .885 r
.81495 .42476 .81794 .42987 .82522 .43251 .82224 .42742 Mtetra
.311 .505 .886 r
.82224 .42742 .82522 .43251 .83254 .43517 .82956 .4301 Mtetra
.31 .506 .887 r
.82956 .4301 .83254 .43517 .83989 .43782 .83693 .43278 Mtetra
.31 .508 .888 r
.83693 .43278 .83989 .43782 .84728 .44047 .84433 .43545 Mtetra
.311 .51 .89 r
.84433 .43545 .84728 .44047 .85471 .4431 .85176 .43811 Mtetra
.313 .513 .891 r
.85176 .43811 .85471 .4431 .86217 .4457 .85923 .44073 Mtetra
.315 .516 .893 r
.85923 .44073 .86217 .4457 .86967 .44826 .86674 .44332 Mtetra
.319 .52 .895 r
.86674 .44332 .86967 .44826 .87719 .45077 .87428 .44586 Mtetra
.323 .525 .897 r
.87428 .44586 .87719 .45077 .88475 .45322 .88185 .44834 Mtetra
.329 .53 .899 r
.88185 .44834 .88475 .45322 .89234 .4556 .88945 .45074 Mtetra
.805 .74 .791 r
.25701 .63625 .26071 .64018 .26671 .63418 .26302 .6302 Mtetra
.806 .739 .789 r
.26302 .6302 .26671 .63418 .27271 .62809 .26903 .62407 Mtetra
.807 .738 .787 r
.26903 .62407 .27271 .62809 .27871 .62194 .27505 .61787 Mtetra
.807 .736 .786 r
.27505 .61787 .27871 .62194 .28472 .61572 .28107 .61162 Mtetra
.807 .735 .784 r
.28107 .61162 .28472 .61572 .29072 .60946 .28709 .60532 Mtetra
.808 .734 .783 r
.28709 .60532 .29072 .60946 .29673 .60317 .29311 .59899 Mtetra
.808 .733 .782 r
.29311 .59899 .29673 .60317 .30273 .59684 .29913 .59263 Mtetra
.807 .732 .781 r
.29913 .59263 .30273 .59684 .30874 .5905 .30514 .58625 Mtetra
.807 .731 .781 r
.30514 .58625 .30874 .5905 .31474 .58415 .31116 .57986 Mtetra
.807 .73 .78 r
.31116 .57986 .31474 .58415 .32074 .5778 .31717 .57348 Mtetra
.806 .729 .78 r
.31717 .57348 .32074 .5778 .32673 .57146 .32318 .5671 Mtetra
.805 .728 .78 r
.32318 .5671 .32673 .57146 .33272 .56514 .32918 .56075 Mtetra
.804 .728 .779 r
.32918 .56075 .33272 .56514 .33871 .55884 .33518 .55442 Mtetra
.803 .727 .78 r
.33518 .55442 .33871 .55884 .34469 .55258 .34117 .54812 Mtetra
.802 .726 .78 r
.34117 .54812 .34469 .55258 .35067 .54635 .34716 .54186 Mtetra
.801 .725 .78 r
.34716 .54186 .35067 .54635 .35664 .54018 .35314 .53566 Mtetra
.8 .724 .781 r
.35314 .53566 .35664 .54018 .36261 .53405 .35912 .5295 Mtetra
.798 .723 .781 r
.35912 .5295 .36261 .53405 .36857 .52799 .3651 .52341 Mtetra
.796 .722 .782 r
.3651 .52341 .36857 .52799 .37453 .522 .37106 .51739 Mtetra
.794 .721 .783 r
.37106 .51739 .37453 .522 .38048 .51608 .37703 .51144 Mtetra
.793 .72 .784 r
.37703 .51144 .38048 .51608 .38642 .51024 .38298 .50558 Mtetra
.79 .719 .785 r
.38298 .50558 .38642 .51024 .39236 .50448 .38894 .49979 Mtetra
.788 .718 .786 r
.38894 .49979 .39236 .50448 .3983 .49881 .39488 .4941 Mtetra
.786 .717 .788 r
.39488 .4941 .3983 .49881 .40424 .49324 .40083 .4885 Mtetra
.783 .716 .789 r
.40083 .4885 .40424 .49324 .41016 .48777 .40677 .48301 Mtetra
.781 .715 .79 r
.40677 .48301 .41016 .48777 .41609 .4824 .4127 .47762 Mtetra
.778 .714 .792 r
.4127 .47762 .41609 .4824 .42201 .47714 .41863 .47234 Mtetra
.775 .713 .794 r
.41863 .47234 .42201 .47714 .42793 .472 .42456 .46717 Mtetra
.772 .711 .796 r
.42456 .46717 .42793 .472 .43385 .46697 .43049 .46212 Mtetra
.768 .71 .798 r
.43049 .46212 .43385 .46697 .43976 .46206 .43641 .45719 Mtetra
.765 .709 .8 r
.43641 .45719 .43976 .46206 .44568 .45727 .44234 .45239 Mtetra
.761 .707 .802 r
.44234 .45239 .44568 .45727 .45159 .45262 .44826 .44771 Mtetra
.757 .706 .804 r
.44826 .44771 .45159 .45262 .45751 .44809 .45418 .44317 Mtetra
.753 .704 .806 r
.45418 .44317 .45751 .44809 .46342 .4437 .4601 .43876 Mtetra
.749 .703 .808 r
.4601 .43876 .46342 .4437 .46934 .43945 .46603 .43448 Mtetra
.744 .701 .811 r
.46603 .43448 .46934 .43945 .47526 .43533 .47196 .43035 Mtetra
.739 .699 .813 r
.47196 .43035 .47526 .43533 .48118 .43135 .47788 .42636 Mtetra
.735 .698 .816 r
.47788 .42636 .48118 .43135 .4871 .42752 .48382 .42251 Mtetra
.729 .696 .818 r
.48382 .42251 .4871 .42752 .49303 .42384 .48975 .41881 Mtetra
.724 .694 .821 r
.48975 .41881 .49303 .42384 .49897 .4203 .4957 .41526 Mtetra
.718 .692 .823 r
.4957 .41526 .49897 .4203 .50491 .41691 .50164 .41186 Mtetra
.713 .689 .826 r
.50164 .41186 .50491 .41691 .51085 .41368 .5076 .40861 Mtetra
.706 .687 .829 r
.5076 .40861 .51085 .41368 .51681 .41059 .51356 .40551 Mtetra
.7 .685 .832 r
.51356 .40551 .51681 .41059 .52277 .40766 .51953 .40257 Mtetra
.694 .682 .834 r
.51953 .40257 .52277 .40766 .52875 .40488 .52551 .39978 Mtetra
.687 .679 .837 r
.52551 .39978 .52875 .40488 .53473 .40226 .5315 .39715 Mtetra
.68 .676 .84 r
.5315 .39715 .53473 .40226 .54073 .3998 .5375 .39468 Mtetra
.672 .674 .843 r
.5375 .39468 .54073 .3998 .54673 .3975 .54352 .39236 Mtetra
.665 .67 .846 r
.54352 .39236 .54673 .3975 .55275 .39535 .54954 .3902 Mtetra
.657 .667 .848 r
.54954 .3902 .55275 .39535 .55879 .39336 .55558 .3882 Mtetra
.649 .664 .851 r
.55558 .3882 .55879 .39336 .56484 .39153 .56164 .38636 Mtetra
.64 .66 .854 r
.56164 .38636 .56484 .39153 .57091 .38985 .56771 .38468 Mtetra
.632 .657 .856 r
.56771 .38468 .57091 .38985 .57699 .38834 .5738 .38316 Mtetra
.623 .653 .859 r
.5738 .38316 .57699 .38834 .58309 .38698 .57991 .3818 Mtetra
.613 .649 .861 r
.57991 .3818 .58309 .38698 .58921 .38579 .58604 .3806 Mtetra
.604 .645 .864 r
.58604 .3806 .58921 .38579 .59535 .38474 .59218 .37955 Mtetra
.594 .64 .866 r
.59218 .37955 .59535 .38474 .60152 .38386 .59835 .37866 Mtetra
.585 .636 .868 r
.59835 .37866 .60152 .38386 .6077 .38313 .60454 .37793 Mtetra
.574 .631 .87 r
.60454 .37793 .6077 .38313 .61391 .38256 .61075 .37735 Mtetra
.564 .627 .872 r
.61075 .37735 .61391 .38256 .62014 .38214 .61699 .37693 Mtetra
.554 .622 .874 r
.61699 .37693 .62014 .38214 .6264 .38187 .62325 .37666 Mtetra
.543 .617 .876 r
.62325 .37666 .6264 .38187 .63268 .38175 .62954 .37654 Mtetra
.532 .612 .878 r
.62954 .37654 .63268 .38175 .63899 .38178 .63585 .37657 Mtetra
.521 .607 .879 r
.63585 .37657 .63899 .38178 .64532 .38196 .64219 .37675 Mtetra
.511 .601 .88 r
.64219 .37675 .64532 .38196 .65169 .38229 .64856 .37707 Mtetra
.499 .596 .882 r
.64856 .37707 .65169 .38229 .65809 .38275 .65496 .37754 Mtetra
.488 .591 .883 r
.65496 .37754 .65809 .38275 .66451 .38336 .66139 .37815 Mtetra
.477 .585 .884 r
.66139 .37815 .66451 .38336 .67097 .38411 .66786 .3789 Mtetra
.466 .58 .884 r
.66786 .3789 .67097 .38411 .67746 .38499 .67435 .37978 Mtetra
.455 .575 .885 r
.67435 .37978 .67746 .38499 .68398 .386 .68088 .3808 Mtetra
.444 .569 .886 r
.68088 .3808 .68398 .386 .69053 .38715 .68744 .38194 Mtetra
.434 .564 .886 r
.68744 .38194 .69053 .38715 .69712 .38841 .69403 .38322 Mtetra
.423 .559 .886 r
.69403 .38322 .69712 .38841 .70375 .3898 .70066 .38461 Mtetra
.413 .553 .887 r
.70066 .38461 .70375 .3898 .71041 .39131 .70733 .38613 Mtetra
.402 .548 .887 r
.70733 .38613 .71041 .39131 .71711 .39294 .71403 .38776 Mtetra
.392 .543 .887 r
.71403 .38776 .71711 .39294 .72384 .39467 .72077 .3895 Mtetra
.383 .539 .887 r
.72077 .3895 .72384 .39467 .73062 .39651 .72755 .39134 Mtetra
.374 .534 .887 r
.72755 .39134 .73062 .39651 .73743 .39845 .73437 .39329 Mtetra
.365 .53 .886 r
.73437 .39329 .73743 .39845 .74428 .40048 .74122 .39533 Mtetra
.356 .526 .886 r
.74122 .39533 .74428 .40048 .75117 .40261 .74812 .39747 Mtetra
.348 .522 .886 r
.74812 .39747 .75117 .40261 .75809 .40482 .75505 .39969 Mtetra
.341 .518 .886 r
.75505 .39969 .75809 .40482 .76506 .4071 .76202 .40199 Mtetra
.334 .515 .886 r
.76202 .40199 .76506 .4071 .77207 .40946 .76904 .40436 Mtetra
.327 .512 .886 r
.76904 .40436 .77207 .40946 .77912 .41189 .77609 .4068 Mtetra
.322 .51 .886 r
.77609 .4068 .77912 .41189 .7862 .41437 .78319 .4093 Mtetra
.316 .508 .886 r
.78319 .4093 .7862 .41437 .79333 .41691 .79032 .41185 Mtetra
.312 .506 .886 r
.79032 .41185 .79333 .41691 .8005 .41949 .7975 .41445 Mtetra
.308 .505 .887 r
.7975 .41445 .8005 .41949 .80771 .42211 .80471 .41708 Mtetra
.305 .505 .887 r
.80471 .41708 .80771 .42211 .81495 .42476 .81196 .41975 Mtetra
.303 .505 .888 r
.81196 .41975 .81495 .42476 .82224 .42742 .81926 .42243 Mtetra
.301 .505 .889 r
.81926 .42243 .82224 .42742 .82956 .4301 .82659 .42513 Mtetra
.3 .506 .89 r
.82659 .42513 .82956 .4301 .83693 .43278 .83396 .42783 Mtetra
.3 .508 .891 r
.83396 .42783 .83693 .43278 .84433 .43545 .84137 .43052 Mtetra
.301 .51 .892 r
.84137 .43052 .84433 .43545 .85176 .43811 .84882 .4332 Mtetra
.303 .512 .894 r
.84882 .4332 .85176 .43811 .85923 .44073 .8563 .43585 Mtetra
.306 .516 .895 r
.8563 .43585 .85923 .44073 .86674 .44332 .86381 .43846 Mtetra
.31 .52 .897 r
.86381 .43846 .86674 .44332 .87428 .44586 .87136 .44102 Mtetra
.314 .524 .899 r
.87136 .44102 .87428 .44586 .88185 .44834 .87894 .44352 Mtetra
.32 .53 .901 r
.87894 .44352 .88185 .44834 .88945 .45074 .88656 .44595 Mtetra
.807 .743 .793 r
.25329 .63237 .25701 .63625 .26302 .6302 .25931 .62629 Mtetra
.808 .742 .79 r
.25931 .62629 .26302 .6302 .26903 .62407 .26534 .62012 Mtetra
.809 .741 .789 r
.26534 .62012 .26903 .62407 .27505 .61787 .27137 .61389 Mtetra
.809 .74 .787 r
.27137 .61389 .27505 .61787 .28107 .61162 .2774 .6076 Mtetra
.81 .739 .786 r
.2774 .6076 .28107 .61162 .28709 .60532 .28343 .60126 Mtetra
.81 .738 .784 r
.28343 .60126 .28709 .60532 .29311 .59899 .28947 .59489 Mtetra
.81 .737 .784 r
.28947 .59489 .29311 .59899 .29913 .59263 .2955 .5885 Mtetra
.81 .736 .783 r
.2955 .5885 .29913 .59263 .30514 .58625 .30153 .58208 Mtetra
.81 .735 .782 r
.30153 .58208 .30514 .58625 .31116 .57986 .30756 .57567 Mtetra
.809 .734 .782 r
.30756 .57567 .31116 .57986 .31717 .57348 .31358 .56925 Mtetra
.809 .734 .781 r
.31358 .56925 .31717 .57348 .32318 .5671 .3196 .56284 Mtetra
.808 .733 .781 r
.3196 .56284 .32318 .5671 .32918 .56075 .32562 .55646 Mtetra
.807 .732 .781 r
.32562 .55646 .32918 .56075 .33518 .55442 .33163 .55009 Mtetra
.806 .731 .781 r
.33163 .55009 .33518 .55442 .34117 .54812 .33763 .54377 Mtetra
.805 .73 .782 r
.33763 .54377 .34117 .54812 .34716 .54186 .34363 .53748 Mtetra
.804 .729 .782 r
.34363 .53748 .34716 .54186 .35314 .53566 .34963 .53125 Mtetra
.802 .729 .783 r
.34963 .53125 .35314 .53566 .35912 .5295 .35562 .52507 Mtetra
.801 .728 .783 r
.35562 .52507 .35912 .5295 .3651 .52341 .3616 .51895 Mtetra
.799 .727 .784 r
.3616 .51895 .3651 .52341 .37106 .51739 .36758 .5129 Mtetra
.797 .726 .785 r
.36758 .5129 .37106 .51739 .37703 .51144 .37356 .50693 Mtetra
.795 .725 .786 r
.37356 .50693 .37703 .51144 .38298 .50558 .37953 .50104 Mtetra
.793 .724 .787 r
.37953 .50104 .38298 .50558 .38894 .49979 .38549 .49523 Mtetra
.791 .723 .789 r
.38549 .49523 .38894 .49979 .39488 .4941 .39145 .48951 Mtetra
.789 .722 .79 r
.39145 .48951 .39488 .4941 .40083 .4885 .3974 .48389 Mtetra
.786 .721 .792 r
.3974 .48389 .40083 .4885 .40677 .48301 .40335 .47837 Mtetra
.784 .72 .793 r
.40335 .47837 .40677 .48301 .4127 .47762 .4093 .47296 Mtetra
.781 .719 .795 r
.4093 .47296 .4127 .47762 .41863 .47234 .41524 .46766 Mtetra
.778 .718 .797 r
.41524 .46766 .41863 .47234 .42456 .46717 .42118 .46247 Mtetra
.775 .717 .799 r
.42118 .46247 .42456 .46717 .43049 .46212 .42711 .4574 Mtetra
.771 .716 .801 r
.42711 .4574 .43049 .46212 .43641 .45719 .43305 .45245 Mtetra
.768 .715 .803 r
.43305 .45245 .43641 .45719 .44234 .45239 .43898 .44763 Mtetra
.764 .713 .805 r
.43898 .44763 .44234 .45239 .44826 .44771 .44491 .44293 Mtetra
.76 .712 .807 r
.44491 .44293 .44826 .44771 .45418 .44317 .45084 .43837 Mtetra
.756 .711 .81 r
.45084 .43837 .45418 .44317 .4601 .43876 .45677 .43395 Mtetra
.752 .709 .812 r
.45677 .43395 .4601 .43876 .46603 .43448 .46271 .42966 Mtetra
.747 .708 .815 r
.46271 .42966 .46603 .43448 .47196 .43035 .46864 .42551 Mtetra
.742 .706 .817 r
.46864 .42551 .47196 .43035 .47788 .42636 .47458 .4215 Mtetra
.737 .704 .82 r
.47458 .4215 .47788 .42636 .48382 .42251 .48052 .41764 Mtetra
.732 .702 .823 r
.48052 .41764 .48382 .42251 .48975 .41881 .48646 .41392 Mtetra
.727 .7 .825 r
.48646 .41392 .48975 .41881 .4957 .41526 .49241 .41036 Mtetra
.721 .698 .828 r
.49241 .41036 .4957 .41526 .50164 .41186 .49837 .40694 Mtetra
.715 .696 .831 r
.49837 .40694 .50164 .41186 .5076 .40861 .50433 .40368 Mtetra
.709 .694 .834 r
.50433 .40368 .5076 .40861 .51356 .40551 .5103 .40057 Mtetra
.702 .692 .837 r
.5103 .40057 .51356 .40551 .51953 .40257 .51628 .39762 Mtetra
.696 .689 .84 r
.51628 .39762 .51953 .40257 .52551 .39978 .52226 .39482 Mtetra
.689 .686 .843 r
.52226 .39482 .52551 .39978 .5315 .39715 .52826 .39218 Mtetra
.681 .683 .846 r
.52826 .39218 .5315 .39715 .5375 .39468 .53427 .38969 Mtetra
.674 .681 .848 r
.53427 .38969 .5375 .39468 .54352 .39236 .54029 .38737 Mtetra
.666 .677 .851 r
.54029 .38737 .54352 .39236 .54954 .3902 .54632 .3852 Mtetra
.658 .674 .854 r
.54632 .3852 .54954 .3902 .55558 .3882 .55237 .38319 Mtetra
.649 .671 .857 r
.55237 .38319 .55558 .3882 .56164 .38636 .55843 .38134 Mtetra
.641 .667 .86 r
.55843 .38134 .56164 .38636 .56771 .38468 .56451 .37966 Mtetra
.632 .663 .863 r
.56451 .37966 .56771 .38468 .5738 .38316 .57061 .37813 Mtetra
.623 .66 .865 r
.57061 .37813 .5738 .38316 .57991 .3818 .57672 .37676 Mtetra
.613 .655 .868 r
.57672 .37676 .57991 .3818 .58604 .3806 .58285 .37555 Mtetra
.603 .651 .87 r
.58285 .37555 .58604 .3806 .59218 .37955 .589 .3745 Mtetra
.593 .647 .873 r
.589 .3745 .59218 .37955 .59835 .37866 .59518 .3736 Mtetra
.583 .642 .875 r
.59518 .3736 .59835 .37866 .60454 .37793 .60137 .37287 Mtetra
.573 .638 .877 r
.60137 .37287 .60454 .37793 .61075 .37735 .60759 .37228 Mtetra
.562 .633 .879 r
.60759 .37228 .61075 .37735 .61699 .37693 .61383 .37186 Mtetra
.551 .628 .881 r
.61383 .37186 .61699 .37693 .62325 .37666 .6201 .37158 Mtetra
.54 .623 .883 r
.6201 .37158 .62325 .37666 .62954 .37654 .62639 .37146 Mtetra
.529 .617 .884 r
.62639 .37146 .62954 .37654 .63585 .37657 .63271 .37149 Mtetra
.518 .612 .886 r
.63271 .37149 .63585 .37657 .64219 .37675 .63906 .37167 Mtetra
.507 .607 .887 r
.63906 .37167 .64219 .37675 .64856 .37707 .64543 .37199 Mtetra
.495 .601 .888 r
.64543 .37199 .64856 .37707 .65496 .37754 .65184 .37246 Mtetra
.484 .596 .889 r
.65184 .37246 .65496 .37754 .66139 .37815 .65827 .37307 Mtetra
.472 .59 .89 r
.65827 .37307 .66139 .37815 .66786 .3789 .66474 .37382 Mtetra
.461 .584 .891 r
.66474 .37382 .66786 .3789 .67435 .37978 .67124 .3747 Mtetra
.449 .579 .891 r
.67124 .3747 .67435 .37978 .68088 .3808 .67777 .37572 Mtetra
.438 .573 .892 r
.67777 .37572 .68088 .3808 .68744 .38194 .68434 .37687 Mtetra
.427 .567 .892 r
.68434 .37687 .68744 .38194 .69403 .38322 .69094 .37815 Mtetra
.416 .562 .892 r
.69094 .37815 .69403 .38322 .70066 .38461 .69757 .37954 Mtetra
.405 .556 .892 r
.69757 .37954 .70066 .38461 .70733 .38613 .70424 .38106 Mtetra
.394 .551 .892 r
.70424 .38106 .70733 .38613 .71403 .38776 .71095 .3827 Mtetra
.384 .546 .892 r
.71095 .3827 .71403 .38776 .72077 .3895 .7177 .38444 Mtetra
.374 .541 .892 r
.7177 .38444 .72077 .3895 .72755 .39134 .72448 .3863 Mtetra
.365 .536 .891 r
.72448 .3863 .72755 .39134 .73437 .39329 .7313 .38825 Mtetra
.356 .531 .891 r
.7313 .38825 .73437 .39329 .74122 .39533 .73816 .3903 Mtetra
.347 .527 .891 r
.73816 .3903 .74122 .39533 .74812 .39747 .74506 .39245 Mtetra
.339 .523 .89 r
.74506 .39245 .74812 .39747 .75505 .39969 .752 .39468 Mtetra
.331 .519 .89 r
.752 .39468 .75505 .39969 .76202 .40199 .75898 .39698 Mtetra
.324 .516 .89 r
.75898 .39698 .76202 .40199 .76904 .40436 .766 .39937 Mtetra
.317 .513 .89 r
.766 .39937 .76904 .40436 .77609 .4068 .77307 .40182 Mtetra
.311 .51 .89 r
.77307 .40182 .77609 .4068 .78319 .4093 .78017 .40433 Mtetra
.306 .508 .89 r
.78017 .40433 .78319 .4093 .79032 .41185 .78731 .40689 Mtetra
.302 .507 .89 r
.78731 .40689 .79032 .41185 .7975 .41445 .79449 .4095 Mtetra
.298 .505 .89 r
.79449 .4095 .7975 .41445 .80471 .41708 .80171 .41215 Mtetra
.295 .505 .89 r
.80171 .41215 .80471 .41708 .81196 .41975 .80897 .41483 Mtetra
.292 .504 .891 r
.80897 .41483 .81196 .41975 .81926 .42243 .81628 .41753 Mtetra
.291 .505 .891 r
.81628 .41753 .81926 .42243 .82659 .42513 .82362 .42024 Mtetra
.29 .506 .892 r
.82362 .42024 .82659 .42513 .83396 .42783 .831 .42296 Mtetra
.291 .507 .893 r
.831 .42296 .83396 .42783 .84137 .43052 .83841 .42567 Mtetra
.292 .509 .894 r
.83841 .42567 .84137 .43052 .84882 .4332 .84587 .42837 Mtetra
.294 .512 .896 r
.84587 .42837 .84882 .4332 .8563 .43585 .85336 .43104 Mtetra
.297 .515 .897 r
.85336 .43104 .8563 .43585 .86381 .43846 .86088 .43367 Mtetra
.301 .519 .899 r
.86088 .43367 .86381 .43846 .87136 .44102 .86844 .43625 Mtetra
.305 .524 .901 r
.86844 .43625 .87136 .44102 .87894 .44352 .87604 .43877 Mtetra
.311 .529 .903 r
.87604 .43877 .87894 .44352 .88656 .44595 .88366 .44123 Mtetra
.809 .746 .794 r
.24954 .62857 .25329 .63237 .25931 .62629 .25558 .62245 Mtetra
.81 .745 .792 r
.25558 .62245 .25931 .62629 .26534 .62012 .26162 .61625 Mtetra
.811 .744 .79 r
.26162 .61625 .26534 .62012 .27137 .61389 .26767 .60998 Mtetra
.812 .744 .788 r
.26767 .60998 .27137 .61389 .2774 .6076 .27371 .60366 Mtetra
.812 .743 .787 r
.27371 .60366 .2774 .6076 .28343 .60126 .27976 .59729 Mtetra
.812 .742 .786 r
.27976 .59729 .28343 .60126 .28947 .59489 .28581 .59089 Mtetra
.812 .741 .785 r
.28581 .59089 .28947 .59489 .2955 .5885 .29185 .58446 Mtetra
.812 .74 .784 r
.29185 .58446 .2955 .5885 .30153 .58208 .2979 .57802 Mtetra
.812 .739 .784 r
.2979 .57802 .30153 .58208 .30756 .57567 .30394 .57157 Mtetra
.812 .739 .783 r
.30394 .57157 .30756 .57567 .31358 .56925 .30997 .56512 Mtetra
.811 .738 .783 r
.30997 .56512 .31358 .56925 .3196 .56284 .316 .55868 Mtetra
.81 .737 .783 r
.316 .55868 .3196 .56284 .32562 .55646 .32203 .55227 Mtetra
.81 .736 .783 r
.32203 .55227 .32562 .55646 .33163 .55009 .32806 .54588 Mtetra
.809 .736 .783 r
.32806 .54588 .33163 .55009 .33763 .54377 .33408 .53952 Mtetra
.808 .735 .784 r
.33408 .53952 .33763 .54377 .34363 .53748 .34009 .53321 Mtetra
.806 .734 .784 r
.34009 .53321 .34363 .53748 .34963 .53125 .3461 .52695 Mtetra
.805 .733 .785 r
.3461 .52695 .34963 .53125 .35562 .52507 .3521 .52075 Mtetra
.804 .733 .786 r
.3521 .52075 .35562 .52507 .3616 .51895 .35809 .5146 Mtetra
.802 .732 .787 r
.35809 .5146 .3616 .51895 .36758 .5129 .36409 .50853 Mtetra
.8 .731 .788 r
.36409 .50853 .36758 .5129 .37356 .50693 .37007 .50253 Mtetra
.798 .73 .789 r
.37007 .50253 .37356 .50693 .37953 .50104 .37605 .49662 Mtetra
.796 .73 .79 r
.37605 .49662 .37953 .50104 .38549 .49523 .38202 .49079 Mtetra
.794 .729 .791 r
.38202 .49079 .38549 .49523 .39145 .48951 .38799 .48505 Mtetra
.792 .728 .793 r
.38799 .48505 .39145 .48951 .3974 .48389 .39396 .47941 Mtetra
.789 .727 .794 r
.39396 .47941 .3974 .48389 .40335 .47837 .39992 .47387 Mtetra
.787 .726 .796 r
.39992 .47387 .40335 .47837 .4093 .47296 .40587 .46843 Mtetra
.784 .725 .798 r
.40587 .46843 .4093 .47296 .41524 .46766 .41183 .46311 Mtetra
.781 .724 .8 r
.41183 .46311 .41524 .46766 .42118 .46247 .41778 .4579 Mtetra
.778 .723 .802 r
.41778 .4579 .42118 .46247 .42711 .4574 .42372 .45281 Mtetra
.774 .722 .804 r
.42372 .45281 .42711 .4574 .43305 .45245 .42967 .44785 Mtetra
.771 .721 .806 r
.42967 .44785 .43305 .45245 .43898 .44763 .43561 .44301 Mtetra
.767 .72 .809 r
.43561 .44301 .43898 .44763 .44491 .44293 .44155 .4383 Mtetra
.763 .719 .811 r
.44155 .4383 .44491 .44293 .45084 .43837 .44749 .43372 Mtetra
.759 .717 .814 r
.44749 .43372 .45084 .43837 .45677 .43395 .45343 .42927 Mtetra
.754 .716 .816 r
.45343 .42927 .45677 .43395 .46271 .42966 .45937 .42497 Mtetra
.75 .714 .819 r
.45937 .42497 .46271 .42966 .46864 .42551 .46531 .4208 Mtetra
.745 .713 .821 r
.46531 .4208 .46864 .42551 .47458 .4215 .47126 .41678 Mtetra
.74 .711 .824 r
.47126 .41678 .47458 .4215 .48052 .41764 .47721 .41291 Mtetra
.735 .709 .827 r
.47721 .41291 .48052 .41764 .48646 .41392 .48316 .40918 Mtetra
.729 .707 .83 r
.48316 .40918 .48646 .41392 .49241 .41036 .48912 .4056 Mtetra
.723 .705 .833 r
.48912 .4056 .49241 .41036 .49837 .40694 .49508 .40217 Mtetra
.717 .703 .836 r
.49508 .40217 .49837 .40694 .50433 .40368 .50105 .39889 Mtetra
.711 .701 .839 r
.50105 .39889 .50433 .40368 .5103 .40057 .50703 .39577 Mtetra
.704 .699 .842 r
.50703 .39577 .5103 .40057 .51628 .39762 .51301 .39281 Mtetra
.697 .696 .845 r
.51301 .39281 .51628 .39762 .52226 .39482 .51901 .39 Mtetra
.69 .694 .848 r
.51901 .39 .52226 .39482 .52826 .39218 .52501 .38735 Mtetra
.683 .691 .851 r
.52501 .38735 .52826 .39218 .53427 .38969 .53103 .38485 Mtetra
.675 .688 .854 r
.53103 .38485 .53427 .38969 .54029 .38737 .53705 .38252 Mtetra
.667 .685 .857 r
.53705 .38252 .54029 .38737 .54632 .3852 .54309 .38034 Mtetra
.659 .681 .86 r
.54309 .38034 .54632 .3852 .55237 .38319 .54915 .37833 Mtetra
.65 .678 .863 r
.54915 .37833 .55237 .38319 .55843 .38134 .55522 .37647 Mtetra
.641 .674 .866 r
.55522 .37647 .55843 .38134 .56451 .37966 .5613 .37477 Mtetra
.632 .671 .869 r
.5613 .37477 .56451 .37966 .57061 .37813 .5674 .37324 Mtetra
.623 .667 .872 r
.5674 .37324 .57061 .37813 .57672 .37676 .57352 .37186 Mtetra
.613 .663 .874 r
.57352 .37186 .57672 .37676 .58285 .37555 .57966 .37064 Mtetra
.603 .658 .877 r
.57966 .37064 .58285 .37555 .589 .3745 .58582 .36959 Mtetra
.592 .654 .879 r
.58582 .36959 .589 .3745 .59518 .3736 .592 .36869 Mtetra
.582 .649 .882 r
.592 .36869 .59518 .3736 .60137 .37287 .5982 .36794 Mtetra
.571 .644 .884 r
.5982 .36794 .60137 .37287 .60759 .37228 .60442 .36736 Mtetra
.56 .639 .886 r
.60442 .36736 .60759 .37228 .61383 .37186 .61067 .36693 Mtetra
.549 .634 .888 r
.61067 .36693 .61383 .37186 .6201 .37158 .61694 .36665 Mtetra
.537 .629 .89 r
.61694 .36665 .6201 .37158 .62639 .37146 .62324 .36653 Mtetra
.526 .623 .891 r
.62324 .36653 .62639 .37146 .63271 .37149 .62956 .36655 Mtetra
.514 .618 .893 r
.62956 .36655 .63271 .37149 .63906 .37167 .63592 .36673 Mtetra
.502 .612 .894 r
.63592 .36673 .63906 .37167 .64543 .37199 .6423 .36705 Mtetra
.49 .606 .895 r
.6423 .36705 .64543 .37199 .65184 .37246 .64871 .36752 Mtetra
.479 .6 .896 r
.64871 .36752 .65184 .37246 .65827 .37307 .65515 .36812 Mtetra
.467 .595 .897 r
.65515 .36812 .65827 .37307 .66474 .37382 .66162 .36887 Mtetra
.455 .589 .897 r
.66162 .36887 .66474 .37382 .67124 .3747 .66812 .36976 Mtetra
.443 .583 .898 r
.66812 .36976 .67124 .3747 .67777 .37572 .67466 .37078 Mtetra
.431 .577 .898 r
.67466 .37078 .67777 .37572 .68434 .37687 .68123 .37193 Mtetra
.42 .571 .898 r
.68123 .37193 .68434 .37687 .69094 .37815 .68784 .37321 Mtetra
.408 .565 .898 r
.68784 .37321 .69094 .37815 .69757 .37954 .69448 .37461 Mtetra
.397 .559 .898 r
.69448 .37461 .69757 .37954 .70424 .38106 .70116 .37613 Mtetra
.386 .554 .897 r
.70116 .37613 .70424 .38106 .71095 .3827 .70787 .37777 Mtetra
.376 .548 .897 r
.70787 .37777 .71095 .3827 .7177 .38444 .71462 .37952 Mtetra
.365 .543 .897 r
.71462 .37952 .7177 .38444 .72448 .3863 .72141 .38138 Mtetra
.355 .538 .896 r
.72141 .38138 .72448 .3863 .7313 .38825 .72824 .38334 Mtetra
.346 .533 .896 r
.72824 .38334 .7313 .38825 .73816 .3903 .73511 .38539 Mtetra
.337 .529 .895 r
.73511 .38539 .73816 .3903 .74506 .39245 .74201 .38754 Mtetra
.329 .524 .895 r
.74201 .38754 .74506 .39245 .752 .39468 .74896 .38978 Mtetra
.321 .52 .894 r
.74896 .38978 .752 .39468 .75898 .39698 .75594 .3921 Mtetra
.314 .517 .894 r
.75594 .3921 .75898 .39698 .766 .39937 .76297 .39449 Mtetra
.307 .514 .893 r
.76297 .39449 .766 .39937 .77307 .40182 .77004 .39695 Mtetra
.301 .511 .893 r
.77004 .39695 .77307 .40182 .78017 .40433 .77715 .39947 Mtetra
.296 .509 .893 r
.77715 .39947 .78017 .40433 .78731 .40689 .78429 .40204 Mtetra
.291 .507 .893 r
.78429 .40204 .78731 .40689 .79449 .4095 .79148 .40466 Mtetra
.287 .505 .893 r
.79148 .40466 .79449 .4095 .80171 .41215 .79871 .40733 Mtetra
.284 .504 .893 r
.79871 .40733 .80171 .41215 .80897 .41483 .80598 .41002 Mtetra
.282 .504 .893 r
.80598 .41002 .80897 .41483 .81628 .41753 .81329 .41273 Mtetra
.281 .504 .894 r
.81329 .41273 .81628 .41753 .82362 .42024 .82064 .41546 Mtetra
.28 .505 .895 r
.82064 .41546 .82362 .42024 .831 .42296 .82803 .41819 Mtetra
.28 .507 .896 r
.82803 .41819 .831 .42296 .83841 .42567 .83545 .42091 Mtetra
.282 .509 .897 r
.83545 .42091 .83841 .42567 .84587 .42837 .84292 .42362 Mtetra
.284 .511 .898 r
.84292 .42362 .84587 .42837 .85336 .43104 .85042 .42631 Mtetra
.287 .515 .9 r
.85042 .42631 .85336 .43104 .86088 .43367 .85795 .42896 Mtetra
.291 .519 .901 r
.85795 .42896 .86088 .43367 .86844 .43625 .86552 .43156 Mtetra
.296 .523 .903 r
.86552 .43156 .86844 .43625 .87604 .43877 .87313 .4341 Mtetra
.303 .529 .906 r
.87313 .4341 .87604 .43877 .88366 .44123 .88076 .43657 Mtetra
.811 .75 .795 r
.24578 .62484 .24954 .62857 .25558 .62245 .25183 .61868 Mtetra
.812 .749 .793 r
.25183 .61868 .25558 .62245 .26162 .61625 .25789 .61245 Mtetra
.813 .748 .791 r
.25789 .61245 .26162 .61625 .26767 .60998 .26395 .60615 Mtetra
.814 .747 .79 r
.26395 .60615 .26767 .60998 .27371 .60366 .27001 .5998 Mtetra
.814 .746 .788 r
.27001 .5998 .27371 .60366 .27976 .59729 .27607 .5934 Mtetra
.815 .746 .787 r
.27607 .5934 .27976 .59729 .28581 .59089 .28213 .58697 Mtetra
.815 .745 .787 r
.28213 .58697 .28581 .59089 .29185 .58446 .28819 .58051 Mtetra
.815 .744 .786 r
.28819 .58051 .29185 .58446 .2979 .57802 .29424 .57404 Mtetra
.815 .744 .785 r
.29424 .57404 .2979 .57802 .30394 .57157 .30029 .56756 Mtetra
.814 .743 .785 r
.30029 .56756 .30394 .57157 .30997 .56512 .30634 .56109 Mtetra
.814 .742 .785 r
.30634 .56109 .30997 .56512 .316 .55868 .31239 .55463 Mtetra
.813 .742 .785 r
.31239 .55463 .316 .55868 .32203 .55227 .31843 .54818 Mtetra
.812 .741 .785 r
.31843 .54818 .32203 .55227 .32806 .54588 .32447 .54177 Mtetra
.811 .74 .785 r
.32447 .54177 .32806 .54588 .33408 .53952 .3305 .53539 Mtetra
.81 .74 .786 r
.3305 .53539 .33408 .53952 .34009 .53321 .33652 .52905 Mtetra
.809 .739 .786 r
.33652 .52905 .34009 .53321 .3461 .52695 .34254 .52277 Mtetra
.808 .738 .787 r
.34254 .52277 .3461 .52695 .3521 .52075 .34856 .51654 Mtetra
.806 .738 .788 r
.34856 .51654 .3521 .52075 .35809 .5146 .35457 .51037 Mtetra
.805 .737 .789 r
.35457 .51037 .35809 .5146 .36409 .50853 .36057 .50428 Mtetra
.803 .737 .79 r
.36057 .50428 .36409 .50853 .37007 .50253 .36657 .49826 Mtetra
.801 .736 .791 r
.36657 .49826 .37007 .50253 .37605 .49662 .37256 .49232 Mtetra
.799 .735 .793 r
.37256 .49232 .37605 .49662 .38202 .49079 .37854 .48647 Mtetra
.797 .734 .794 r
.37854 .48647 .38202 .49079 .38799 .48505 .38452 .48071 Mtetra
.795 .734 .796 r
.38452 .48071 .38799 .48505 .39396 .47941 .3905 .47505 Mtetra
.792 .733 .797 r
.3905 .47505 .39396 .47941 .39992 .47387 .39647 .46949 Mtetra
.79 .732 .799 r
.39647 .46949 .39992 .47387 .40587 .46843 .40244 .46404 Mtetra
.787 .731 .801 r
.40244 .46404 .40587 .46843 .41183 .46311 .4084 .45869 Mtetra
.784 .73 .803 r
.4084 .45869 .41183 .46311 .41778 .4579 .41436 .45347 Mtetra
.781 .73 .805 r
.41436 .45347 .41778 .4579 .42372 .45281 .42031 .44836 Mtetra
.777 .729 .808 r
.42031 .44836 .42372 .45281 .42967 .44785 .42627 .44338 Mtetra
.774 .728 .81 r
.42627 .44338 .42967 .44785 .43561 .44301 .43222 .43852 Mtetra
.77 .726 .812 r
.43222 .43852 .43561 .44301 .44155 .4383 .43817 .43379 Mtetra
.766 .725 .815 r
.43817 .43379 .44155 .4383 .44749 .43372 .44412 .4292 Mtetra
.762 .724 .818 r
.44412 .4292 .44749 .43372 .45343 .42927 .45007 .42474 Mtetra
.757 .723 .82 r
.45007 .42474 .45343 .42927 .45937 .42497 .45602 .42042 Mtetra
.753 .721 .823 r
.45602 .42042 .45937 .42497 .46531 .4208 .46197 .41624 Mtetra
.748 .72 .826 r
.46197 .41624 .46531 .4208 .47126 .41678 .46793 .4122 Mtetra
.743 .718 .829 r
.46793 .4122 .47126 .41678 .47721 .41291 .47389 .40831 Mtetra
.737 .717 .832 r
.47389 .40831 .47721 .41291 .48316 .40918 .47985 .40457 Mtetra
.732 .715 .835 r
.47985 .40457 .48316 .40918 .48912 .4056 .48581 .40098 Mtetra
.726 .713 .838 r
.48581 .40098 .48912 .4056 .49508 .40217 .49178 .39754 Mtetra
.72 .711 .841 r
.49178 .39754 .49508 .40217 .50105 .39889 .49776 .39425 Mtetra
.713 .709 .844 r
.49776 .39425 .50105 .39889 .50703 .39577 .50375 .39112 Mtetra
.706 .706 .847 r
.50375 .39112 .50703 .39577 .51301 .39281 .50974 .38814 Mtetra
.699 .704 .851 r
.50974 .38814 .51301 .39281 .51901 .39 .51574 .38532 Mtetra
.692 .701 .854 r
.51574 .38532 .51901 .39 .52501 .38735 .52175 .38266 Mtetra
.684 .698 .857 r
.52175 .38266 .52501 .38735 .53103 .38485 .52777 .38016 Mtetra
.677 .695 .86 r
.52777 .38016 .53103 .38485 .53705 .38252 .53381 .37781 Mtetra
.668 .692 .863 r
.53381 .37781 .53705 .38252 .54309 .38034 .53986 .37563 Mtetra
.66 .689 .867 r
.53986 .37563 .54309 .38034 .54915 .37833 .54592 .3736 Mtetra
.651 .686 .87 r
.54592 .3736 .54915 .37833 .55522 .37647 .55199 .37174 Mtetra
.642 .682 .873 r
.55199 .37174 .55522 .37647 .5613 .37477 .55808 .37004 Mtetra
.632 .678 .876 r
.55808 .37004 .5613 .37477 .5674 .37324 .56419 .36849 Mtetra
.622 .674 .878 r
.56419 .36849 .5674 .37324 .57352 .37186 .57032 .36711 Mtetra
.612 .67 .881 r
.57032 .36711 .57352 .37186 .57966 .37064 .57646 .36589 Mtetra
.602 .665 .884 r
.57646 .36589 .57966 .37064 .58582 .36959 .58263 .36482 Mtetra
.591 .661 .886 r
.58263 .36482 .58582 .36959 .592 .36869 .58881 .36392 Mtetra
.58 .656 .889 r
.58881 .36392 .592 .36869 .5982 .36794 .59502 .36317 Mtetra
.569 .651 .891 r
.59502 .36317 .5982 .36794 .60442 .36736 .60125 .36258 Mtetra
.558 .646 .893 r
.60125 .36258 .60442 .36736 .61067 .36693 .6075 .36214 Mtetra
.546 .641 .895 r
.6075 .36214 .61067 .36693 .61694 .36665 .61378 .36186 Mtetra
.534 .635 .897 r
.61378 .36186 .61694 .36665 .62324 .36653 .62008 .36173 Mtetra
.522 .629 .898 r
.62008 .36173 .62324 .36653 .62956 .36655 .62641 .36175 Mtetra
.51 .624 .9 r
.62641 .36175 .62956 .36655 .63592 .36673 .63277 .36193 Mtetra
.498 .618 .901 r
.63277 .36193 .63592 .36673 .6423 .36705 .63915 .36225 Mtetra
.485 .612 .902 r
.63915 .36225 .6423 .36705 .64871 .36752 .64557 .36271 Mtetra
.473 .606 .903 r
.64557 .36271 .64871 .36752 .65515 .36812 .65202 .36332 Mtetra
.461 .599 .903 r
.65202 .36332 .65515 .36812 .66162 .36887 .65849 .36407 Mtetra
.448 .593 .904 r
.65849 .36407 .66162 .36887 .66812 .36976 .665 .36495 Mtetra
.436 .587 .904 r
.665 .36495 .66812 .36976 .67466 .37078 .67155 .36597 Mtetra
.424 .581 .904 r
.67155 .36597 .67466 .37078 .68123 .37193 .67812 .36712 Mtetra
.412 .575 .904 r
.67812 .36712 .68123 .37193 .68784 .37321 .68474 .3684 Mtetra
.4 .568 .904 r
.68474 .3684 .68784 .37321 .69448 .37461 .69138 .3698 Mtetra
.389 .562 .903 r
.69138 .3698 .69448 .37461 .70116 .37613 .69807 .37133 Mtetra
.377 .556 .903 r
.69807 .37133 .70116 .37613 .70787 .37777 .70479 .37297 Mtetra
.366 .551 .902 r
.70479 .37297 .70787 .37777 .71462 .37952 .71154 .37472 Mtetra
.356 .545 .902 r
.71154 .37472 .71462 .37952 .72141 .38138 .71834 .37658 Mtetra
.346 .54 .901 r
.71834 .37658 .72141 .38138 .72824 .38334 .72517 .37855 Mtetra
.336 .535 .9 r
.72517 .37855 .72824 .38334 .73511 .38539 .73204 .38061 Mtetra
.327 .53 .9 r
.73204 .38061 .73511 .38539 .74201 .38754 .73896 .38276 Mtetra
.318 .525 .899 r
.73896 .38276 .74201 .38754 .74896 .38978 .74591 .385 Mtetra
.31 .521 .898 r
.74591 .385 .74896 .38978 .75594 .3921 .7529 .38733 Mtetra
.303 .518 .898 r
.7529 .38733 .75594 .3921 .76297 .39449 .75993 .38972 Mtetra
.296 .514 .897 r
.75993 .38972 .76297 .39449 .77004 .39695 .76701 .39219 Mtetra
.29 .511 .896 r
.76701 .39219 .77004 .39695 .77715 .39947 .77412 .39472 Mtetra
.285 .509 .896 r
.77412 .39472 .77715 .39947 .78429 .40204 .78128 .3973 Mtetra
.28 .507 .896 r
.78128 .3973 .78429 .40204 .79148 .40466 .78847 .39993 Mtetra
.276 .505 .896 r
.78847 .39993 .79148 .40466 .79871 .40733 .79571 .4026 Mtetra
.273 .504 .896 r
.79571 .4026 .79871 .40733 .80598 .41002 .80299 .4053 Mtetra
.271 .504 .896 r
.80299 .4053 .80598 .41002 .81329 .41273 .81031 .40803 Mtetra
.27 .504 .896 r
.81031 .40803 .81329 .41273 .82064 .41546 .81766 .41076 Mtetra
.27 .505 .897 r
.81766 .41076 .82064 .41546 .82803 .41819 .82506 .41351 Mtetra
.27 .506 .898 r
.82506 .41351 .82803 .41819 .83545 .42091 .83249 .41624 Mtetra
.272 .508 .899 r
.83249 .41624 .83545 .42091 .84292 .42362 .83997 .41897 Mtetra
.274 .511 .9 r
.83997 .41897 .84292 .42362 .85042 .42631 .84748 .42167 Mtetra
.277 .514 .902 r
.84748 .42167 .85042 .42631 .85795 .42896 .85502 .42433 Mtetra
.282 .518 .904 r
.85502 .42433 .85795 .42896 .86552 .43156 .8626 .42694 Mtetra
.287 .523 .905 r
.8626 .42694 .86552 .43156 .87313 .4341 .87021 .4295 Mtetra
.294 .528 .908 r
.87021 .4295 .87313 .4341 .88076 .43657 .87786 .43199 Mtetra
.813 .753 .796 r
.242 .62118 .24578 .62484 .25183 .61868 .24806 .615 Mtetra
.814 .752 .794 r
.24806 .615 .25183 .61868 .25789 .61245 .25413 .60873 Mtetra
.815 .752 .793 r
.25413 .60873 .25789 .61245 .26395 .60615 .26021 .60241 Mtetra
.816 .751 .791 r
.26021 .60241 .26395 .60615 .27001 .5998 .26628 .59603 Mtetra
.817 .75 .79 r
.26628 .59603 .27001 .5998 .27607 .5934 .27235 .5896 Mtetra
.817 .75 .789 r
.27235 .5896 .27607 .5934 .28213 .58697 .27843 .58314 Mtetra
.817 .749 .788 r
.27843 .58314 .28213 .58697 .28819 .58051 .2845 .57666 Mtetra
.817 .748 .788 r
.2845 .57666 .28819 .58051 .29424 .57404 .29057 .57016 Mtetra
.817 .748 .787 r
.29057 .57016 .29424 .57404 .30029 .56756 .29663 .56366 Mtetra
.817 .747 .787 r
.29663 .56366 .30029 .56756 .30634 .56109 .3027 .55716 Mtetra
.816 .747 .787 r
.3027 .55716 .30634 .56109 .31239 .55463 .30875 .55067 Mtetra
.816 .746 .787 r
.30875 .55067 .31239 .55463 .31843 .54818 .31481 .54421 Mtetra
.815 .746 .787 r
.31481 .54421 .31843 .54818 .32447 .54177 .32086 .53777 Mtetra
.814 .745 .787 r
.32086 .53777 .32447 .54177 .3305 .53539 .3269 .53137 Mtetra
.813 .745 .788 r
.3269 .53137 .3305 .53539 .33652 .52905 .33294 .52501 Mtetra
.812 .744 .789 r
.33294 .52501 .33652 .52905 .34254 .52277 .33897 .5187 Mtetra
.811 .744 .789 r
.33897 .5187 .34254 .52277 .34856 .51654 .345 .51245 Mtetra
.809 .743 .79 r
.345 .51245 .34856 .51654 .35457 .51037 .35102 .50626 Mtetra
.808 .742 .791 r
.35102 .50626 .35457 .51037 .36057 .50428 .35703 .50015 Mtetra
.806 .742 .793 r
.35703 .50015 .36057 .50428 .36657 .49826 .36304 .49411 Mtetra
.804 .741 .794 r
.36304 .49411 .36657 .49826 .37256 .49232 .36904 .48815 Mtetra
.802 .741 .795 r
.36904 .48815 .37256 .49232 .37854 .48647 .37504 .48228 Mtetra
.8 .74 .797 r
.37504 .48228 .37854 .48647 .38452 .48071 .38103 .4765 Mtetra
.798 .74 .799 r
.38103 .4765 .38452 .48071 .3905 .47505 .38702 .47082 Mtetra
.795 .739 .8 r
.38702 .47082 .3905 .47505 .39647 .46949 .393 .46524 Mtetra
.793 .738 .802 r
.393 .46524 .39647 .46949 .40244 .46404 .39898 .45977 Mtetra
.79 .738 .804 r
.39898 .45977 .40244 .46404 .4084 .45869 .40495 .45441 Mtetra
.787 .737 .807 r
.40495 .45441 .4084 .45869 .41436 .45347 .41092 .44917 Mtetra
.784 .736 .809 r
.41092 .44917 .41436 .45347 .42031 .44836 .41689 .44404 Mtetra
.78 .735 .811 r
.41689 .44404 .42031 .44836 .42627 .44338 .42285 .43904 Mtetra
.777 .734 .814 r
.42285 .43904 .42627 .44338 .43222 .43852 .42882 .43417 Mtetra
.773 .733 .816 r
.42882 .43417 .43222 .43852 .43817 .43379 .43478 .42943 Mtetra
.769 .732 .819 r
.43478 .42943 .43817 .43379 .44412 .4292 .44074 .42482 Mtetra
.765 .731 .822 r
.44074 .42482 .44412 .4292 .45007 .42474 .4467 .42035 Mtetra
.76 .73 .824 r
.4467 .42035 .45007 .42474 .45602 .42042 .45266 .41601 Mtetra
.756 .728 .827 r
.45266 .41601 .45602 .42042 .46197 .41624 .45862 .41182 Mtetra
.751 .727 .83 r
.45862 .41182 .46197 .41624 .46793 .4122 .46458 .40777 Mtetra
.745 .726 .833 r
.46458 .40777 .46793 .4122 .47389 .40831 .47055 .40387 Mtetra
.74 .724 .837 r
.47055 .40387 .47389 .40831 .47985 .40457 .47652 .40011 Mtetra
.734 .722 .84 r
.47652 .40011 .47985 .40457 .48581 .40098 .48249 .39651 Mtetra
.728 .72 .843 r
.48249 .39651 .48581 .40098 .49178 .39754 .48847 .39306 Mtetra
.722 .718 .846 r
.48847 .39306 .49178 .39754 .49776 .39425 .49446 .38976 Mtetra
.715 .716 .85 r
.49446 .38976 .49776 .39425 .50375 .39112 .50045 .38661 Mtetra
.709 .714 .853 r
.50045 .38661 .50375 .39112 .50974 .38814 .50645 .38362 Mtetra
.701 .712 .856 r
.50645 .38362 .50974 .38814 .51574 .38532 .51246 .38079 Mtetra
.694 .709 .86 r
.51246 .38079 .51574 .38532 .52175 .38266 .51848 .37812 Mtetra
.686 .706 .863 r
.51848 .37812 .52175 .38266 .52777 .38016 .52451 .37561 Mtetra
.678 .703 .866 r
.52451 .37561 .52777 .38016 .53381 .37781 .53055 .37325 Mtetra
.669 .7 .87 r
.53055 .37325 .53381 .37781 .53986 .37563 .53661 .37106 Mtetra
.661 .697 .873 r
.53661 .37106 .53986 .37563 .54592 .3736 .54267 .36903 Mtetra
.652 .694 .876 r
.54267 .36903 .54592 .3736 .55199 .37174 .54876 .36715 Mtetra
.642 .69 .879 r
.54876 .36715 .55199 .37174 .55808 .37004 .55485 .36544 Mtetra
.632 .686 .882 r
.55485 .36544 .55808 .37004 .56419 .36849 .56097 .36389 Mtetra
.622 .682 .885 r
.56097 .36389 .56419 .36849 .57032 .36711 .5671 .3625 Mtetra
.612 .678 .888 r
.5671 .3625 .57032 .36711 .57646 .36589 .57325 .36127 Mtetra
.601 .673 .891 r
.57325 .36127 .57646 .36589 .58263 .36482 .57942 .3602 Mtetra
.59 .668 .894 r
.57942 .3602 .58263 .36482 .58881 .36392 .58561 .35929 Mtetra
.579 .663 .896 r
.58561 .35929 .58881 .36392 .59502 .36317 .59183 .35854 Mtetra
.567 .658 .898 r
.59183 .35854 .59502 .36317 .60125 .36258 .59806 .35794 Mtetra
.555 .653 .9 r
.59806 .35794 .60125 .36258 .6075 .36214 .60432 .3575 Mtetra
.543 .647 .902 r
.60432 .3575 .6075 .36214 .61378 .36186 .61061 .35721 Mtetra
.531 .642 .904 r
.61061 .35721 .61378 .36186 .62008 .36173 .61692 .35708 Mtetra
.518 .636 .905 r
.61692 .35708 .62008 .36173 .62641 .36175 .62325 .3571 Mtetra
.506 .63 .907 r
.62325 .3571 .62641 .36175 .63277 .36193 .62962 .35727 Mtetra
.493 .624 .908 r
.62962 .35727 .63277 .36193 .63915 .36225 .63601 .35758 Mtetra
.48 .617 .909 r
.63601 .35758 .63915 .36225 .64557 .36271 .64243 .35805 Mtetra
.467 .611 .909 r
.64243 .35805 .64557 .36271 .65202 .36332 .64888 .35865 Mtetra
.454 .604 .91 r
.64888 .35865 .65202 .36332 .65849 .36407 .65537 .3594 Mtetra
.442 .598 .91 r
.65537 .3594 .65849 .36407 .665 .36495 .66188 .36028 Mtetra
.429 .591 .91 r
.66188 .36028 .665 .36495 .67155 .36597 .66843 .3613 Mtetra
.416 .585 .91 r
.66843 .3613 .67155 .36597 .67812 .36712 .67501 .36245 Mtetra
.404 .578 .91 r
.67501 .36245 .67812 .36712 .68474 .3684 .68163 .36373 Mtetra
.392 .572 .91 r
.68163 .36373 .68474 .3684 .69138 .3698 .68828 .36513 Mtetra
.38 .566 .909 r
.68828 .36513 .69138 .3698 .69807 .37133 .69497 .36666 Mtetra
.368 .559 .908 r
.69497 .36666 .69807 .37133 .70479 .37297 .7017 .3683 Mtetra
.357 .553 .908 r
.7017 .3683 .70479 .37297 .71154 .37472 .70846 .37005 Mtetra
.346 .547 .907 r
.70846 .37005 .71154 .37472 .71834 .37658 .71526 .37191 Mtetra
.336 .542 .906 r
.71526 .37191 .71834 .37658 .72517 .37855 .7221 .37388 Mtetra
.326 .537 .905 r
.7221 .37388 .72517 .37855 .73204 .38061 .72898 .37594 Mtetra
.316 .531 .904 r
.72898 .37594 .73204 .38061 .73896 .38276 .7359 .3781 Mtetra
.308 .527 .903 r
.7359 .3781 .73896 .38276 .74591 .385 .74286 .38035 Mtetra
.299 .522 .902 r
.74286 .38035 .74591 .385 .7529 .38733 .74986 .38267 Mtetra
.292 .518 .901 r
.74986 .38267 .7529 .38733 .75993 .38972 .7569 .38508 Mtetra
.285 .515 .9 r
.7569 .38508 .75993 .38972 .76701 .39219 .76398 .38755 Mtetra
.279 .512 .9 r
.76398 .38755 .76701 .39219 .77412 .39472 .7711 .39008 Mtetra
.274 .509 .899 r
.7711 .39008 .77412 .39472 .78128 .3973 .77826 .39267 Mtetra
.269 .507 .899 r
.77826 .39267 .78128 .3973 .78847 .39993 .78547 .39531 Mtetra
.265 .505 .898 r
.78547 .39531 .78847 .39993 .79571 .4026 .79271 .39798 Mtetra
.262 .504 .898 r
.79271 .39798 .79571 .4026 .80299 .4053 .79999 .40069 Mtetra
.26 .504 .899 r
.79999 .40069 .80299 .4053 .81031 .40803 .80732 .40342 Mtetra
.259 .504 .899 r
.80732 .40342 .81031 .40803 .81766 .41076 .81469 .40617 Mtetra
.259 .505 .899 r
.81469 .40617 .81766 .41076 .82506 .41351 .82209 .40892 Mtetra
.26 .506 .9 r
.82209 .40892 .82506 .41351 .83249 .41624 .82953 .41167 Mtetra
.261 .508 .901 r
.82953 .41167 .83249 .41624 .83997 .41897 .83702 .4144 Mtetra
.264 .511 .902 r
.83702 .4144 .83997 .41897 .84748 .42167 .84453 .41711 Mtetra
.268 .514 .904 r
.84453 .41711 .84748 .42167 .85502 .42433 .85209 .41978 Mtetra
.272 .518 .906 r
.85209 .41978 .85502 .42433 .8626 .42694 .85968 .42241 Mtetra
.278 .523 .907 r
.85968 .42241 .8626 .42694 .87021 .4295 .8673 .42498 Mtetra
.285 .528 .91 r
.8673 .42498 .87021 .4295 .87786 .43199 .87495 .42748 Mtetra
.815 .757 .798 r
.23819 .61759 .242 .62118 .24806 .615 .24427 .61138 Mtetra
.817 .756 .796 r
.24427 .61138 .24806 .615 .25413 .60873 .25036 .6051 Mtetra
.817 .755 .794 r
.25036 .6051 .25413 .60873 .26021 .60241 .25644 .59875 Mtetra
.818 .755 .793 r
.25644 .59875 .26021 .60241 .26628 .59603 .26253 .59234 Mtetra
.819 .754 .792 r
.26253 .59234 .26628 .59603 .27235 .5896 .26862 .58589 Mtetra
.819 .754 .791 r
.26862 .58589 .27235 .5896 .27843 .58314 .2747 .57941 Mtetra
.819 .753 .79 r
.2747 .57941 .27843 .58314 .2845 .57666 .28079 .5729 Mtetra
.819 .753 .789 r
.28079 .5729 .2845 .57666 .29057 .57016 .28687 .56638 Mtetra
.819 .752 .789 r
.28687 .56638 .29057 .57016 .29663 .56366 .29295 .55986 Mtetra
.29295 .55986 .29663 .56366 .3027 .55716 .29903 .55334 Mtetra
.819 .751 .789 r
.29903 .55334 .3027 .55716 .30875 .55067 .3051 .54683 Mtetra
.818 .751 .789 r
.3051 .54683 .30875 .55067 .31481 .54421 .31116 .54034 Mtetra
.818 .75 .789 r
.31116 .54034 .31481 .54421 .32086 .53777 .31723 .53388 Mtetra
.817 .75 .789 r
.31723 .53388 .32086 .53777 .3269 .53137 .32328 .52746 Mtetra
.816 .75 .79 r
.32328 .52746 .3269 .53137 .33294 .52501 .32933 .52108 Mtetra
.815 .749 .791 r
.32933 .52108 .33294 .52501 .33897 .5187 .33538 .51475 Mtetra
.814 .749 .792 r
.33538 .51475 .33897 .5187 .345 .51245 .34142 .50848 Mtetra
.812 .748 .793 r
.34142 .50848 .345 .51245 .35102 .50626 .34745 .50227 Mtetra
.811 .748 .794 r
.34745 .50227 .35102 .50626 .35703 .50015 .35348 .49614 Mtetra
.809 .748 .795 r
.35348 .49614 .35703 .50015 .36304 .49411 .3595 .49008 Mtetra
.807 .747 .797 r
.3595 .49008 .36304 .49411 .36904 .48815 .36551 .4841 Mtetra
.805 .747 .798 r
.36551 .4841 .36904 .48815 .37504 .48228 .37152 .47821 Mtetra
.803 .746 .8 r
.37152 .47821 .37504 .48228 .38103 .4765 .37753 .47242 Mtetra
.801 .746 .802 r
.37753 .47242 .38103 .4765 .38702 .47082 .38352 .46672 Mtetra
.798 .745 .803 r
.38352 .46672 .38702 .47082 .393 .46524 .38952 .46112 Mtetra
.796 .745 .805 r
.38952 .46112 .393 .46524 .39898 .45977 .39551 .45564 Mtetra
.793 .744 .808 r
.39551 .45564 .39898 .45977 .40495 .45441 .40149 .45026 Mtetra
.79 .743 .81 r
.40149 .45026 .40495 .45441 .41092 .44917 .40747 .445 Mtetra
.787 .743 .812 r
.40747 .445 .41092 .44917 .41689 .44404 .41345 .43986 Mtetra
.783 .742 .815 r
.41345 .43986 .41689 .44404 .42285 .43904 .41942 .43485 Mtetra
.78 .741 .817 r
.41942 .43485 .42285 .43904 .42882 .43417 .4254 .42996 Mtetra
.776 .74 .82 r
.4254 .42996 .42882 .43417 .43478 .42943 .43137 .4252 Mtetra
.772 .739 .823 r
.43137 .4252 .43478 .42943 .44074 .42482 .43734 .42058 Mtetra
.768 .738 .826 r
.43734 .42058 .44074 .42482 .4467 .42035 .44331 .41609 Mtetra
.763 .737 .829 r
.44331 .41609 .4467 .42035 .45266 .41601 .44928 .41174 Mtetra
.758 .736 .832 r
.44928 .41174 .45266 .41601 .45862 .41182 .45525 .40754 Mtetra
.753 .735 .835 r
.45525 .40754 .45862 .41182 .46458 .40777 .46122 .40348 Mtetra
.748 .733 .838 r
.46122 .40348 .46458 .40777 .47055 .40387 .4672 .39956 Mtetra
.743 .732 .842 r
.4672 .39956 .47055 .40387 .47652 .40011 .47317 .3958 Mtetra
.737 .73 .845 r
.47317 .3958 .47652 .40011 .48249 .39651 .47916 .39218 Mtetra
.731 .728 .848 r
.47916 .39218 .48249 .39651 .48847 .39306 .48515 .38872 Mtetra
.724 .726 .852 r
.48515 .38872 .48847 .39306 .49446 .38976 .49114 .38541 Mtetra
.718 .724 .855 r
.49114 .38541 .49446 .38976 .50045 .38661 .49714 .38225 Mtetra
.711 .722 .859 r
.49714 .38225 .50045 .38661 .50645 .38362 .50315 .37925 Mtetra
.703 .72 .862 r
.50315 .37925 .50645 .38362 .51246 .38079 .50917 .37641 Mtetra
.696 .717 .866 r
.50917 .37641 .51246 .38079 .51848 .37812 .5152 .37373 Mtetra
.688 .715 .869 r
.5152 .37373 .51848 .37812 .52451 .37561 .52123 .37121 Mtetra
.679 .712 .873 r
.52123 .37121 .52451 .37561 .53055 .37325 .52728 .36884 Mtetra
.671 .709 .876 r
.52728 .36884 .53055 .37325 .53661 .37106 .53334 .36664 Mtetra
.661 .705 .88 r
.53334 .36664 .53661 .37106 .54267 .36903 .53942 .3646 Mtetra
.652 .702 .883 r
.53942 .3646 .54267 .36903 .54876 .36715 .54551 .36272 Mtetra
.642 .698 .886 r
.54551 .36272 .54876 .36715 .55485 .36544 .55162 .361 Mtetra
.632 .694 .889 r
.55162 .361 .55485 .36544 .56097 .36389 .55774 .35944 Mtetra
.622 .69 .893 r
.55774 .35944 .56097 .36389 .5671 .3625 .56388 .35804 Mtetra
.611 .686 .895 r
.56388 .35804 .5671 .3625 .57325 .36127 .57004 .35681 Mtetra
.6 .681 .898 r
.57004 .35681 .57325 .36127 .57942 .3602 .57621 .35573 Mtetra
.588 .676 .901 r
.57621 .35573 .57942 .3602 .58561 .35929 .58241 .35481 Mtetra
.577 .671 .903 r
.58241 .35481 .58561 .35929 .59183 .35854 .58863 .35405 Mtetra
.565 .666 .906 r
.58863 .35405 .59183 .35854 .59806 .35794 .59487 .35345 Mtetra
.552 .66 .908 r
.59487 .35345 .59806 .35794 .60432 .3575 .60114 .353 Mtetra
.54 .654 .91 r
.60114 .353 .60432 .3575 .61061 .35721 .60743 .35271 Mtetra
.527 .648 .911 r
.60743 .35271 .61061 .35721 .61692 .35708 .61374 .35257 Mtetra
.514 .642 .913 r
.61374 .35257 .61692 .35708 .62325 .3571 .62009 .35259 Mtetra
.501 .636 .914 r
.62009 .35259 .62325 .3571 .62962 .35727 .62646 .35275 Mtetra
.488 .63 .915 r
.62646 .35275 .62962 .35727 .63601 .35758 .63286 .35307 Mtetra
.474 .623 .916 r
.63286 .35307 .63601 .35758 .64243 .35805 .63928 .35352 Mtetra
.461 .616 .916 r
.63928 .35352 .64243 .35805 .64888 .35865 .64574 .35413 Mtetra
.448 .61 .917 r
.64574 .35413 .64888 .35865 .65537 .3594 .65223 .35487 Mtetra
.434 .603 .917 r
.65223 .35487 .65537 .3594 .66188 .36028 .65875 .35575 Mtetra
.421 .596 .917 r
.65875 .35575 .66188 .36028 .66843 .3613 .66531 .35676 Mtetra
.408 .589 .916 r
.66531 .35676 .66843 .3613 .67501 .36245 .6719 .35791 Mtetra
.395 .582 .916 r
.6719 .35791 .67501 .36245 .68163 .36373 .67852 .35919 Mtetra
.383 .575 .915 r
.67852 .35919 .68163 .36373 .68828 .36513 .68518 .36059 Mtetra
.371 .569 .914 r
.68518 .36059 .68828 .36513 .69497 .36666 .69187 .36212 Mtetra
.359 .562 .914 r
.69187 .36212 .69497 .36666 .7017 .3683 .69861 .36376 Mtetra
.347 .556 .913 r
.69861 .36376 .7017 .3683 .70846 .37005 .70537 .36551 Mtetra
.336 .55 .911 r
.70537 .36551 .70846 .37005 .71526 .37191 .71218 .36737 Mtetra
.325 .544 .91 r
.71218 .36737 .71526 .37191 .7221 .37388 .71903 .36934 Mtetra
.315 .538 .909 r
.71903 .36934 .7221 .37388 .72898 .37594 .72591 .37141 Mtetra
.305 .533 .908 r
.72591 .37141 .72898 .37594 .7359 .3781 .73284 .37357 Mtetra
.296 .528 .907 r
.73284 .37357 .7359 .3781 .74286 .38035 .7398 .37581 Mtetra
.288 .523 .906 r
.7398 .37581 .74286 .38035 .74986 .38267 .74681 .37814 Mtetra
.28 .519 .905 r
.74681 .37814 .74986 .38267 .7569 .38508 .75386 .38055 Mtetra
.273 .515 .904 r
.75386 .38055 .7569 .38508 .76398 .38755 .76094 .38302 Mtetra
.267 .512 .903 r
.76094 .38302 .76398 .38755 .7711 .39008 .76807 .38556 Mtetra
.262 .509 .902 r
.76807 .38556 .7711 .39008 .77826 .39267 .77524 .38815 Mtetra
.257 .507 .901 r
.77524 .38815 .77826 .39267 .78547 .39531 .78245 .39079 Mtetra
.254 .505 .901 r
.78245 .39079 .78547 .39531 .79271 .39798 .78971 .39347 Mtetra
.251 .504 .901 r
.78971 .39347 .79271 .39798 .79999 .40069 .797 .39618 Mtetra
.249 .504 .901 r
.797 .39618 .79999 .40069 .80732 .40342 .80433 .39892 Mtetra
.248 .504 .901 r
.80433 .39892 .80732 .40342 .81469 .40617 .81171 .40167 Mtetra
.248 .504 .902 r
.81171 .40167 .81469 .40617 .82209 .40892 .81912 .40443 Mtetra
.249 .506 .902 r
.81912 .40443 .82209 .40892 .82953 .41167 .82657 .40718 Mtetra
.251 .508 .903 r
.82657 .40718 .82953 .41167 .83702 .4144 .83406 .40992 Mtetra
.254 .51 .904 r
.83406 .40992 .83702 .4144 .84453 .41711 .84159 .41264 Mtetra
.258 .514 .906 r
.84159 .41264 .84453 .41711 .85209 .41978 .84915 .41532 Mtetra
.263 .518 .907 r
.84915 .41532 .85209 .41978 .85968 .42241 .85675 .41795 Mtetra
.269 .523 .909 r
.85675 .41795 .85968 .42241 .8673 .42498 .86438 .42053 Mtetra
.276 .528 .911 r
.86438 .42053 .8673 .42498 .87495 .42748 .87205 .42304 Mtetra
.817 .76 .799 r
.23437 .61408 .23819 .61759 .24427 .61138 .24046 .60785 Mtetra
.819 .76 .797 r
.24046 .60785 .24427 .61138 .25036 .6051 .24656 .60154 Mtetra
.82 .759 .796 r
.24656 .60154 .25036 .6051 .25644 .59875 .25266 .59517 Mtetra
.82 .759 .794 r
.25266 .59517 .25644 .59875 .26253 .59234 .25876 .58874 Mtetra
.821 .758 .793 r
.25876 .58874 .26253 .59234 .26862 .58589 .26486 .58227 Mtetra
.821 .758 .792 r
.26486 .58227 .26862 .58589 .2747 .57941 .27096 .57577 Mtetra
.822 .757 .792 r
.27096 .57577 .2747 .57941 .28079 .5729 .27705 .56924 Mtetra
.822 .757 .791 r
.27705 .56924 .28079 .5729 .28687 .56638 .28315 .5627 Mtetra
.28315 .5627 .28687 .56638 .29295 .55986 .28924 .55616 Mtetra
.822 .756 .791 r
.28924 .55616 .29295 .55986 .29903 .55334 .29533 .54961 Mtetra
.821 .756 .791 r
.29533 .54961 .29903 .55334 .3051 .54683 .30142 .54309 Mtetra
.30142 .54309 .3051 .54683 .31116 .54034 .3075 .53658 Mtetra
.82 .755 .791 r
.3075 .53658 .31116 .54034 .31723 .53388 .31357 .5301 Mtetra
.819 .755 .792 r
.31357 .5301 .31723 .53388 .32328 .52746 .31964 .52366 Mtetra
.31964 .52366 .32328 .52746 .32933 .52108 .32571 .51726 Mtetra
.818 .754 .793 r
.32571 .51726 .32933 .52108 .33538 .51475 .33177 .51091 Mtetra
.816 .754 .794 r
.33177 .51091 .33538 .51475 .34142 .50848 .33782 .50462 Mtetra
.815 .754 .795 r
.33782 .50462 .34142 .50848 .34745 .50227 .34386 .4984 Mtetra
.814 .754 .796 r
.34386 .4984 .34745 .50227 .35348 .49614 .3499 .49225 Mtetra
.812 .753 .798 r
.3499 .49225 .35348 .49614 .3595 .49008 .35593 .48617 Mtetra
.81 .753 .799 r
.35593 .48617 .3595 .49008 .36551 .4841 .36196 .48018 Mtetra
.808 .753 .801 r
.36196 .48018 .36551 .4841 .37152 .47821 .36798 .47427 Mtetra
.806 .752 .803 r
.36798 .47427 .37152 .47821 .37753 .47242 .374 .46846 Mtetra
.804 .752 .805 r
.374 .46846 .37753 .47242 .38352 .46672 .38001 .46275 Mtetra
.801 .751 .807 r
.38001 .46275 .38352 .46672 .38952 .46112 .38601 .45714 Mtetra
.799 .751 .809 r
.38601 .45714 .38952 .46112 .39551 .45564 .39201 .45164 Mtetra
.796 .75 .811 r
.39201 .45164 .39551 .45564 .40149 .45026 .39801 .44625 Mtetra
.793 .75 .813 r
.39801 .44625 .40149 .45026 .40747 .445 .404 .44097 Mtetra
.79 .749 .816 r
.404 .44097 .40747 .445 .41345 .43986 .40999 .43582 Mtetra
.786 .749 .819 r
.40999 .43582 .41345 .43986 .41942 .43485 .41597 .43079 Mtetra
.783 .748 .821 r
.41597 .43079 .41942 .43485 .4254 .42996 .42196 .42589 Mtetra
.779 .747 .824 r
.42196 .42589 .4254 .42996 .43137 .4252 .42794 .42112 Mtetra
.775 .746 .827 r
.42794 .42112 .43137 .4252 .43734 .42058 .43392 .41648 Mtetra
.771 .746 .83 r
.43392 .41648 .43734 .42058 .44331 .41609 .4399 .41198 Mtetra
.766 .745 .833 r
.4399 .41198 .44331 .41609 .44928 .41174 .44588 .40762 Mtetra
.761 .744 .836 r
.44588 .40762 .44928 .41174 .45525 .40754 .45186 .4034 Mtetra
.756 .742 .84 r
.45186 .4034 .45525 .40754 .46122 .40348 .45784 .39933 Mtetra
.751 .741 .843 r
.45784 .39933 .46122 .40348 .4672 .39956 .46383 .3954 Mtetra
.745 .74 .847 r
.46383 .3954 .4672 .39956 .47317 .3958 .46982 .39162 Mtetra
.739 .738 .85 r
.46982 .39162 .47317 .3958 .47916 .39218 .47581 .388 Mtetra
.733 .736 .854 r
.47581 .388 .47916 .39218 .48515 .38872 .48181 .38452 Mtetra
.727 .735 .857 r
.48181 .38452 .48515 .38872 .49114 .38541 .48781 .3812 Mtetra
.72 .733 .861 r
.48781 .3812 .49114 .38541 .49714 .38225 .49382 .37804 Mtetra
.713 .731 .865 r
.49382 .37804 .49714 .38225 .50315 .37925 .49984 .37503 Mtetra
.705 .728 .868 r
.49984 .37503 .50315 .37925 .50917 .37641 .50586 .37218 Mtetra
.697 .726 .872 r
.50586 .37218 .50917 .37641 .5152 .37373 .5119 .36948 Mtetra
.689 .723 .876 r
.5119 .36948 .5152 .37373 .52123 .37121 .51794 .36695 Mtetra
.68 .72 .879 r
.51794 .36695 .52123 .37121 .52728 .36884 .524 .36458 Mtetra
.672 .717 .883 r
.524 .36458 .52728 .36884 .53334 .36664 .53007 .36237 Mtetra
.662 .714 .887 r
.53007 .36237 .53334 .36664 .53942 .3646 .53616 .36032 Mtetra
.652 .71 .89 r
.53616 .36032 .53942 .3646 .54551 .36272 .54225 .35843 Mtetra
.642 .707 .893 r
.54225 .35843 .54551 .36272 .55162 .361 .54837 .3567 Mtetra
.632 .703 .897 r
.54837 .3567 .55162 .361 .55774 .35944 .5545 .35514 Mtetra
.621 .698 .9 r
.5545 .35514 .55774 .35944 .56388 .35804 .56064 .35373 Mtetra
.61 .694 .903 r
.56064 .35373 .56388 .35804 .57004 .35681 .56681 .35249 Mtetra
.598 .689 .906 r
.56681 .35249 .57004 .35681 .57621 .35573 .57299 .3514 Mtetra
.587 .684 .908 r
.57299 .3514 .57621 .35573 .58241 .35481 .5792 .35048 Mtetra
.574 .679 .911 r
.5792 .35048 .58241 .35481 .58863 .35405 .58542 .34971 Mtetra
.562 .673 .913 r
.58542 .34971 .58863 .35405 .59487 .35345 .59167 .3491 Mtetra
.549 .668 .915 r
.59167 .3491 .59487 .35345 .60114 .353 .59795 .34865 Mtetra
.536 .662 .917 r
.59795 .34865 .60114 .353 .60743 .35271 .60424 .34835 Mtetra
.523 .655 .919 r
.60424 .34835 .60743 .35271 .61374 .35257 .61057 .34821 Mtetra
.509 .649 .92 r
.61057 .34821 .61374 .35257 .62009 .35259 .61691 .34822 Mtetra
.496 .643 .921 r
.61691 .34822 .62009 .35259 .62646 .35275 .62329 .34838 Mtetra
.482 .636 .922 r
.62329 .34838 .62646 .35275 .63286 .35307 .6297 .34869 Mtetra
.468 .629 .923 r
.6297 .34869 .63286 .35307 .63928 .35352 .63613 .34914 Mtetra
.454 .622 .923 r
.63613 .34914 .63928 .35352 .64574 .35413 .64259 .34974 Mtetra
.441 .615 .923 r
.64259 .34974 .64574 .35413 .65223 .35487 .64909 .35048 Mtetra
.427 .608 .923 r
.64909 .35048 .65223 .35487 .65875 .35575 .65562 .35136 Mtetra
.413 .6 .923 r
.65562 .35136 .65875 .35575 .66531 .35676 .66218 .35237 Mtetra
.4 .593 .923 r
.66218 .35237 .66531 .35676 .6719 .35791 .66878 .35351 Mtetra
.386 .586 .922 r
.66878 .35351 .6719 .35791 .67852 .35919 .6754 .35479 Mtetra
.373 .579 .921 r
.6754 .35479 .67852 .35919 .68518 .36059 .68207 .35619 Mtetra
.361 .572 .92 r
.68207 .35619 .68518 .36059 .69187 .36212 .68877 .35771 Mtetra
.348 .565 .919 r
.68877 .35771 .69187 .36212 .69861 .36376 .69551 .35935 Mtetra
.336 .558 .917 r
.69551 .35935 .69861 .36376 .70537 .36551 .70228 .3611 Mtetra
.325 .552 .916 r
.70228 .3611 .70537 .36551 .71218 .36737 .7091 .36296 Mtetra
.314 .546 .915 r
.7091 .36296 .71218 .36737 .71903 .36934 .71595 .36493 Mtetra
.304 .54 .913 r
.71595 .36493 .71903 .36934 .72591 .37141 .72284 .36699 Mtetra
.294 .534 .912 r
.72284 .36699 .72591 .37141 .73284 .37357 .72978 .36915 Mtetra
.285 .529 .91 r
.72978 .36915 .73284 .37357 .7398 .37581 .73675 .3714 Mtetra
.276 .524 .909 r
.73675 .3714 .7398 .37581 .74681 .37814 .74376 .37373 Mtetra
.268 .52 .908 r
.74376 .37373 .74681 .37814 .75386 .38055 .75081 .37613 Mtetra
.262 .516 .907 r
.75081 .37613 .75386 .38055 .76094 .38302 .75791 .37861 Mtetra
.255 .513 .905 r
.75791 .37861 .76094 .38302 .76807 .38556 .76504 .38115 Mtetra
.25 .51 .905 r
.76504 .38115 .76807 .38556 .77524 .38815 .77222 .38374 Mtetra
.245 .507 .904 r
.77222 .38374 .77524 .38815 .78245 .39079 .77944 .38638 Mtetra
.242 .505 .903 r
.77944 .38638 .78245 .39079 .78971 .39347 .7867 .38907 Mtetra
.239 .504 .903 r
.7867 .38907 .78971 .39347 .797 .39618 .794 .39178 Mtetra
.237 .504 .903 r
.794 .39178 .797 .39618 .80433 .39892 .80134 .39452 Mtetra
.80134 .39452 .80433 .39892 .81171 .40167 .80872 .39727 Mtetra
.80872 .39727 .81171 .40167 .81912 .40443 .81615 .40004 Mtetra
.238 .506 .904 r
.81615 .40004 .81912 .40443 .82657 .40718 .82361 .40279 Mtetra
.24 .508 .905 r
.82361 .40279 .82657 .40718 .83406 .40992 .8311 .40554 Mtetra
.243 .51 .906 r
.8311 .40554 .83406 .40992 .84159 .41264 .83864 .40826 Mtetra
.248 .514 .908 r
.83864 .40826 .84159 .41264 .84915 .41532 .84621 .41094 Mtetra
.253 .518 .909 r
.84621 .41094 .84915 .41532 .85675 .41795 .85382 .41358 Mtetra
.26 .523 .911 r
.85382 .41358 .85675 .41795 .86438 .42053 .86147 .41616 Mtetra
.267 .528 .913 r
.86147 .41616 .86438 .42053 .87205 .42304 .86914 .41867 Mtetra
.819 .764 .801 r
.23052 .61065 .23437 .61408 .24046 .60785 .23662 .6044 Mtetra
.82 .763 .799 r
.23662 .6044 .24046 .60785 .24656 .60154 .24273 .59807 Mtetra
.822 .763 .797 r
.24273 .59807 .24656 .60154 .25266 .59517 .24885 .59168 Mtetra
.822 .763 .796 r
.24885 .59168 .25266 .59517 .25876 .58874 .25496 .58523 Mtetra
.823 .762 .795 r
.25496 .58523 .25876 .58874 .26486 .58227 .26107 .57874 Mtetra
.824 .762 .794 r
.26107 .57874 .26486 .58227 .27096 .57577 .26719 .57222 Mtetra
.26719 .57222 .27096 .57577 .27705 .56924 .2733 .56568 Mtetra
.824 .761 .793 r
.2733 .56568 .27705 .56924 .28315 .5627 .27941 .55912 Mtetra
.27941 .55912 .28315 .5627 .28924 .55616 .28552 .55256 Mtetra
.28552 .55256 .28924 .55616 .29533 .54961 .29162 .546 Mtetra
.29162 .546 .29533 .54961 .30142 .54309 .29772 .53945 Mtetra
.823 .76 .793 r
.29772 .53945 .30142 .54309 .3075 .53658 .30381 .53293 Mtetra
.30381 .53293 .3075 .53658 .31357 .5301 .3099 .52643 Mtetra
.822 .76 .794 r
.3099 .52643 .31357 .5301 .31964 .52366 .31598 .51997 Mtetra
.821 .76 .795 r
.31598 .51997 .31964 .52366 .32571 .51726 .32206 .51356 Mtetra
.82 .76 .796 r
.32206 .51356 .32571 .51726 .33177 .51091 .32813 .5072 Mtetra
.819 .76 .797 r
.32813 .5072 .33177 .51091 .33782 .50462 .33419 .50089 Mtetra
.818 .759 .798 r
.33419 .50089 .33782 .50462 .34386 .4984 .34025 .49465 Mtetra
.816 .759 .799 r
.34025 .49465 .34386 .4984 .3499 .49225 .3463 .48848 Mtetra
.815 .759 .8 r
.3463 .48848 .3499 .49225 .35593 .48617 .35235 .48239 Mtetra
.813 .759 .802 r
.35235 .48239 .35593 .48617 .36196 .48018 .35839 .47638 Mtetra
.811 .759 .804 r
.35839 .47638 .36196 .48018 .36798 .47427 .36442 .47046 Mtetra
.809 .758 .806 r
.36442 .47046 .36798 .47427 .374 .46846 .37045 .46464 Mtetra
.807 .758 .808 r
.37045 .46464 .374 .46846 .38001 .46275 .37647 .45891 Mtetra
.804 .758 .81 r
.37647 .45891 .38001 .46275 .38601 .45714 .38249 .45329 Mtetra
.802 .758 .812 r
.38249 .45329 .38601 .45714 .39201 .45164 .3885 .44777 Mtetra
.799 .757 .814 r
.3885 .44777 .39201 .45164 .39801 .44625 .39451 .44237 Mtetra
.796 .757 .817 r
.39451 .44237 .39801 .44625 .404 .44097 .40051 .43708 Mtetra
.793 .756 .82 r
.40051 .43708 .404 .44097 .40999 .43582 .40651 .43191 Mtetra
.789 .756 .822 r
.40651 .43191 .40999 .43582 .41597 .43079 .41251 .42687 Mtetra
.786 .755 .825 r
.41251 .42687 .41597 .43079 .42196 .42589 .4185 .42196 Mtetra
.782 .755 .828 r
.4185 .42196 .42196 .42589 .42794 .42112 .42449 .41717 Mtetra
.778 .754 .831 r
.42449 .41717 .42794 .42112 .43392 .41648 .43048 .41253 Mtetra
.774 .753 .834 r
.43048 .41253 .43392 .41648 .4399 .41198 .43647 .40801 Mtetra
.769 .752 .838 r
.43647 .40801 .4399 .41198 .44588 .40762 .44247 .40364 Mtetra
.764 .751 .841 r
.44247 .40364 .44588 .40762 .45186 .4034 .44846 .39941 Mtetra
.759 .75 .845 r
.44846 .39941 .45186 .4034 .45784 .39933 .45445 .39533 Mtetra
.754 .749 .848 r
.45445 .39533 .45784 .39933 .46383 .3954 .46044 .39139 Mtetra
.748 .748 .852 r
.46044 .39139 .46383 .3954 .46982 .39162 .46644 .3876 Mtetra
.742 .746 .855 r
.46644 .3876 .46982 .39162 .47581 .388 .47244 .38396 Mtetra
.736 .745 .859 r
.47244 .38396 .47581 .388 .48181 .38452 .47845 .38048 Mtetra
.729 .743 .863 r
.47845 .38048 .48181 .38452 .48781 .3812 .48446 .37715 Mtetra
.722 .741 .867 r
.48446 .37715 .48781 .3812 .49382 .37804 .49048 .37397 Mtetra
.715 .739 .871 r
.49048 .37397 .49382 .37804 .49984 .37503 .49651 .37095 Mtetra
.707 .737 .875 r
.49651 .37095 .49984 .37503 .50586 .37218 .50254 .36809 Mtetra
.699 .735 .878 r
.50254 .36809 .50586 .37218 .5119 .36948 .50859 .36539 Mtetra
.69 .732 .882 r
.50859 .36539 .5119 .36948 .51794 .36695 .51464 .36285 Mtetra
.682 .729 .886 r
.51464 .36285 .51794 .36695 .524 .36458 .52071 .36047 Mtetra
.672 .726 .89 r
.52071 .36047 .524 .36458 .53007 .36237 .52679 .35825 Mtetra
.663 .723 .893 r
.52679 .35825 .53007 .36237 .53616 .36032 .53288 .35619 Mtetra
.653 .719 .897 r
.53288 .35619 .53616 .36032 .54225 .35843 .53898 .35429 Mtetra
.642 .715 .901 r
.53898 .35429 .54225 .35843 .54837 .3567 .54511 .35256 Mtetra
.632 .711 .904 r
.54511 .35256 .54837 .3567 .5545 .35514 .55124 .35098 Mtetra
.62 .707 .907 r
.55124 .35098 .5545 .35514 .56064 .35373 .5574 .34957 Mtetra
.609 .702 .91 r
.5574 .34957 .56064 .35373 .56681 .35249 .56357 .34832 Mtetra
.597 .697 .913 r
.56357 .34832 .56681 .35249 .57299 .3514 .56976 .34722 Mtetra
.585 .692 .916 r
.56976 .34722 .57299 .3514 .5792 .35048 .57597 .34629 Mtetra
.572 .687 .919 r
.57597 .34629 .5792 .35048 .58542 .34971 .58221 .34552 Mtetra
.559 .681 .921 r
.58221 .34552 .58542 .34971 .59167 .3491 .58846 .34491 Mtetra
.546 .675 .923 r
.58846 .34491 .59167 .3491 .59795 .34865 .59474 .34445 Mtetra
.532 .669 .925 r
.59474 .34445 .59795 .34865 .60424 .34835 .60105 .34414 Mtetra
.518 .663 .926 r
.60105 .34414 .60424 .34835 .61057 .34821 .60738 .34399 Mtetra
.504 .656 .928 r
.60738 .34399 .61057 .34821 .61691 .34822 .61373 .344 Mtetra
.49 .649 .929 r
.61373 .344 .61691 .34822 .62329 .34838 .62012 .34415 Mtetra
.476 .642 .929 r
.62012 .34415 .62329 .34838 .6297 .34869 .62653 .34445 Mtetra
.462 .635 .93 r
.62653 .34445 .6297 .34869 .63613 .34914 .63297 .3449 Mtetra
.447 .628 .93 r
.63297 .3449 .63613 .34914 .64259 .34974 .63944 .3455 Mtetra
.433 .62 .93 r
.63944 .3455 .64259 .34974 .64909 .35048 .64594 .34623 Mtetra
.419 .613 .93 r
.64594 .34623 .64909 .35048 .65562 .35136 .65248 .3471 Mtetra
.405 .605 .929 r
.65248 .3471 .65562 .35136 .66218 .35237 .65905 .34811 Mtetra
.391 .598 .928 r
.65905 .34811 .66218 .35237 .66878 .35351 .66565 .34925 Mtetra
.377 .59 .928 r
.66565 .34925 .66878 .35351 .6754 .35479 .67228 .35052 Mtetra
.363 .583 .926 r
.67228 .35052 .6754 .35479 .68207 .35619 .67896 .35192 Mtetra
.35 .575 .925 r
.67896 .35192 .68207 .35619 .68877 .35771 .68566 .35344 Mtetra
.338 .568 .924 r
.68566 .35344 .68877 .35771 .69551 .35935 .69241 .35507 Mtetra
.325 .561 .922 r
.69241 .35507 .69551 .35935 .70228 .3611 .69919 .35682 Mtetra
.314 .554 .92 r
.69919 .35682 .70228 .3611 .7091 .36296 .70601 .35868 Mtetra
.302 .548 .919 r
.70601 .35868 .7091 .36296 .71595 .36493 .71287 .36065 Mtetra
.292 .542 .917 r
.71287 .36065 .71595 .36493 .72284 .36699 .71977 .36271 Mtetra
.282 .536 .915 r
.71977 .36271 .72284 .36699 .72978 .36915 .72671 .36486 Mtetra
.273 .53 .914 r
.72671 .36486 .72978 .36915 .73675 .3714 .73369 .36711 Mtetra
.264 .525 .912 r
.73369 .36711 .73675 .3714 .74376 .37373 .74071 .36944 Mtetra
.256 .521 .911 r
.74071 .36944 .74376 .37373 .75081 .37613 .74777 .37184 Mtetra
.249 .516 .909 r
.74777 .37184 .75081 .37613 .75791 .37861 .75487 .37431 Mtetra
.243 .513 .908 r
.75487 .37431 .75791 .37861 .76504 .38115 .76201 .37685 Mtetra
.238 .51 .907 r
.76201 .37685 .76504 .38115 .77222 .38374 .7692 .37944 Mtetra
.233 .507 .906 r
.7692 .37944 .77222 .38374 .77944 .38638 .77642 .38209 Mtetra
.23 .505 .905 r
.77642 .38209 .77944 .38638 .7867 .38907 .78369 .38477 Mtetra
.227 .504 .905 r
.78369 .38477 .7867 .38907 .794 .39178 .791 .38748 Mtetra
.226 .503 .905 r
.791 .38748 .794 .39178 .80134 .39452 .79835 .39022 Mtetra
.225 .503 .905 r
.79835 .39022 .80134 .39452 .80872 .39727 .80574 .39298 Mtetra
.226 .504 .905 r
.80574 .39298 .80872 .39727 .81615 .40004 .81317 .39574 Mtetra
.227 .505 .906 r
.81317 .39574 .81615 .40004 .82361 .40279 .82064 .3985 Mtetra
.23 .507 .907 r
.82064 .3985 .82361 .40279 .8311 .40554 .82815 .40124 Mtetra
.233 .51 .908 r
.82815 .40124 .8311 .40554 .83864 .40826 .83569 .40396 Mtetra
.238 .514 .909 r
.83569 .40396 .83864 .40826 .84621 .41094 .84327 .40665 Mtetra
.244 .518 .911 r
.84327 .40665 .84621 .41094 .85382 .41358 .85089 .40929 Mtetra
.25 .523 .913 r
.85089 .40929 .85382 .41358 .86147 .41616 .85854 .41187 Mtetra
.258 .528 .915 r
.85854 .41187 .86147 .41616 .86914 .41867 .86623 .41438 Mtetra
.821 .768 .802 r
.22665 .60729 .23052 .61065 .23662 .6044 .23277 .60102 Mtetra
.822 .767 .801 r
.23277 .60102 .23662 .6044 .24273 .59807 .23889 .59468 Mtetra
.824 .767 .799 r
.23889 .59468 .24273 .59807 .24885 .59168 .24501 .58827 Mtetra
.824 .767 .798 r
.24501 .58827 .24885 .59168 .25496 .58523 .25114 .58181 Mtetra
.825 .766 .797 r
.25114 .58181 .25496 .58523 .26107 .57874 .25727 .57531 Mtetra
.826 .766 .796 r
.25727 .57531 .26107 .57874 .26719 .57222 .2634 .56877 Mtetra
.826 .766 .795 r
.2634 .56877 .26719 .57222 .2733 .56568 .26952 .56221 Mtetra
.26952 .56221 .2733 .56568 .27941 .55912 .27565 .55564 Mtetra
.827 .766 .795 r
.27565 .55564 .27941 .55912 .28552 .55256 .28177 .54906 Mtetra
.826 .766 .795 r
.28177 .54906 .28552 .55256 .29162 .546 .28788 .54249 Mtetra
.28788 .54249 .29162 .546 .29772 .53945 .29399 .53593 Mtetra
.826 .765 .795 r
.29399 .53593 .29772 .53945 .30381 .53293 .3001 .52939 Mtetra
.825 .765 .796 r
.3001 .52939 .30381 .53293 .3099 .52643 .3062 .52288 Mtetra
.3062 .52288 .3099 .52643 .31598 .51997 .3123 .5164 Mtetra
.824 .765 .797 r
.3123 .5164 .31598 .51997 .32206 .51356 .31839 .50997 Mtetra
.823 .765 .798 r
.31839 .50997 .32206 .51356 .32813 .5072 .32447 .5036 Mtetra
.822 .765 .799 r
.32447 .5036 .32813 .5072 .33419 .50089 .33055 .49728 Mtetra
.821 .765 .8 r
.33055 .49728 .33419 .50089 .34025 .49465 .33662 .49103 Mtetra
.819 .765 .802 r
.33662 .49103 .34025 .49465 .3463 .48848 .34269 .48484 Mtetra
.818 .765 .803 r
.34269 .48484 .3463 .48848 .35235 .48239 .34874 .47874 Mtetra
.816 .765 .805 r
.34874 .47874 .35235 .48239 .35839 .47638 .3548 .47272 Mtetra
.814 .765 .807 r
.3548 .47272 .35839 .47638 .36442 .47046 .36084 .46678 Mtetra
.812 .765 .809 r
.36084 .46678 .36442 .47046 .37045 .46464 .36688 .46095 Mtetra
.81 .765 .811 r
.36688 .46095 .37045 .46464 .37647 .45891 .37292 .4552 Mtetra
.807 .764 .813 r
.37292 .4552 .37647 .45891 .38249 .45329 .37895 .44957 Mtetra
.805 .764 .815 r
.37895 .44957 .38249 .45329 .3885 .44777 .38497 .44404 Mtetra
.802 .764 .818 r
.38497 .44404 .3885 .44777 .39451 .44237 .39099 .43862 Mtetra
.799 .764 .821 r
.39099 .43862 .39451 .44237 .40051 .43708 .397 .43333 Mtetra
.796 .764 .823 r
.397 .43333 .40051 .43708 .40651 .43191 .40301 .42815 Mtetra
.793 .763 .826 r
.40301 .42815 .40651 .43191 .41251 .42687 .40902 .42309 Mtetra
.789 .763 .829 r
.40902 .42309 .41251 .42687 .4185 .42196 .41503 .41817 Mtetra
.785 .762 .832 r
.41503 .41817 .4185 .42196 .42449 .41717 .42103 .41337 Mtetra
.781 .762 .836 r
.42103 .41337 .42449 .41717 .43048 .41253 .42703 .40871 Mtetra
.777 .761 .839 r
.42703 .40871 .43048 .41253 .43647 .40801 .43303 .40419 Mtetra
.772 .76 .842 r
.43303 .40419 .43647 .40801 .44247 .40364 .43903 .39981 Mtetra
.767 .759 .846 r
.43903 .39981 .44247 .40364 .44846 .39941 .44504 .39556 Mtetra
.762 .759 .85 r
.44504 .39556 .44846 .39941 .45445 .39533 .45104 .39147 Mtetra
.756 .757 .853 r
.45104 .39147 .45445 .39533 .46044 .39139 .45704 .38752 Mtetra
.751 .756 .857 r
.45704 .38752 .46044 .39139 .46644 .3876 .46305 .38372 Mtetra
.745 .755 .861 r
.46305 .38372 .46644 .3876 .47244 .38396 .46906 .38007 Mtetra
.738 .754 .865 r
.46906 .38007 .47244 .38396 .47845 .38048 .47508 .37658 Mtetra
.731 .752 .869 r
.47508 .37658 .47845 .38048 .48446 .37715 .4811 .37324 Mtetra
.724 .75 .873 r
.4811 .37324 .48446 .37715 .49048 .37397 .48713 .37005 Mtetra
.717 .748 .877 r
.48713 .37005 .49048 .37397 .49651 .37095 .49317 .36702 Mtetra
.709 .746 .881 r
.49317 .36702 .49651 .37095 .50254 .36809 .49921 .36415 Mtetra
.7 .744 .885 r
.49921 .36415 .50254 .36809 .50859 .36539 .50527 .36144 Mtetra
.692 .741 .889 r
.50527 .36144 .50859 .36539 .51464 .36285 .51133 .35889 Mtetra
.683 .738 .893 r
.51133 .35889 .51464 .36285 .52071 .36047 .5174 .3565 Mtetra
.673 .735 .897 r
.5174 .3565 .52071 .36047 .52679 .35825 .52349 .35427 Mtetra
.663 .732 .901 r
.52349 .35427 .52679 .35825 .53288 .35619 .52959 .35221 Mtetra
.653 .728 .904 r
.52959 .35221 .53288 .35619 .53898 .35429 .5357 .3503 Mtetra
.642 .724 .908 r
.5357 .3503 .53898 .35429 .54511 .35256 .54183 .34856 Mtetra
.631 .72 .911 r
.54183 .34856 .54511 .35256 .55124 .35098 .54798 .34698 Mtetra
.619 .716 .915 r
.54798 .34698 .55124 .35098 .5574 .34957 .55414 .34556 Mtetra
.607 .711 .918 r
.55414 .34556 .5574 .34957 .56357 .34832 .56032 .3443 Mtetra
.595 .706 .921 r
.56032 .3443 .56357 .34832 .56976 .34722 .56652 .3432 Mtetra
.582 .701 .924 r
.56652 .3432 .56976 .34722 .57597 .34629 .57274 .34226 Mtetra
.569 .695 .926 r
.57274 .34226 .57597 .34629 .58221 .34552 .57898 .34148 Mtetra
.556 .689 .929 r
.57898 .34148 .58221 .34552 .58846 .34491 .58525 .34085 Mtetra
.542 .683 .931 r
.58525 .34085 .58846 .34491 .59474 .34445 .59153 .34039 Mtetra
.528 .677 .932 r
.59153 .34039 .59474 .34445 .60105 .34414 .59785 .34008 Mtetra
.514 .67 .934 r
.59785 .34008 .60105 .34414 .60738 .34399 .60418 .33992 Mtetra
.499 .663 .935 r
.60418 .33992 .60738 .34399 .61373 .344 .61055 .33992 Mtetra
.484 .656 .936 r
.61055 .33992 .61373 .344 .62012 .34415 .61694 .34007 Mtetra
.47 .649 .937 r
.61694 .34007 .62012 .34415 .62653 .34445 .62335 .34037 Mtetra
.455 .641 .937 r
.62335 .34037 .62653 .34445 .63297 .3449 .6298 .34081 Mtetra
.44 .633 .937 r
.6298 .34081 .63297 .3449 .63944 .3455 .63628 .34139 Mtetra
.425 .626 .937 r
.63628 .34139 .63944 .3455 .64594 .34623 .64279 .34212 Mtetra
.41 .618 .936 r
.64279 .34212 .64594 .34623 .65248 .3471 .64933 .34299 Mtetra
.395 .61 .935 r
.64933 .34299 .65248 .3471 .65905 .34811 .65591 .34399 Mtetra
.381 .602 .934 r
.65591 .34399 .65905 .34811 .66565 .34925 .66252 .34513 Mtetra
.367 .594 .933 r
.66252 .34513 .66565 .34925 .67228 .35052 .66916 .3464 Mtetra
.353 .586 .932 r
.66916 .3464 .67228 .35052 .67896 .35192 .67584 .34779 Mtetra
.339 .578 .93 r
.67584 .34779 .67896 .35192 .68566 .35344 .68255 .3493 Mtetra
.326 .571 .928 r
.68255 .3493 .68566 .35344 .69241 .35507 .6893 .35093 Mtetra
.314 .564 .926 r
.6893 .35093 .69241 .35507 .69919 .35682 .69609 .35268 Mtetra
.302 .556 .924 r
.69609 .35268 .69919 .35682 .70601 .35868 .70292 .35453 Mtetra
.29 .55 .923 r
.70292 .35453 .70601 .35868 .71287 .36065 .70979 .35649 Mtetra
.28 .543 .921 r
.70979 .35649 .71287 .36065 .71977 .36271 .71669 .35855 Mtetra
.269 .537 .919 r
.71669 .35855 .71977 .36271 .72671 .36486 .72364 .3607 Mtetra
.26 .531 .917 r
.72364 .3607 .72671 .36486 .73369 .36711 .73063 .36294 Mtetra
.251 .526 .915 r
.73063 .36294 .73369 .36711 .74071 .36944 .73765 .36527 Mtetra
.243 .521 .913 r
.73765 .36527 .74071 .36944 .74777 .37184 .74472 .36767 Mtetra
.236 .517 .912 r
.74472 .36767 .74777 .37184 .75487 .37431 .75183 .37014 Mtetra
.23 .513 .91 r
.75183 .37014 .75487 .37431 .76201 .37685 .75898 .37267 Mtetra
.225 .51 .909 r
.75898 .37267 .76201 .37685 .7692 .37944 .76617 .37526 Mtetra
.221 .507 .908 r
.76617 .37526 .7692 .37944 .77642 .38209 .77341 .3779 Mtetra
.217 .505 .907 r
.77341 .3779 .77642 .38209 .78369 .38477 .78068 .38058 Mtetra
.215 .504 .907 r
.78068 .38058 .78369 .38477 .791 .38748 .788 .38329 Mtetra
.214 .503 .906 r
.788 .38329 .791 .38748 .79835 .39022 .79535 .38603 Mtetra
.213 .503 .906 r
.79535 .38603 .79835 .39022 .80574 .39298 .80275 .38878 Mtetra
.214 .504 .907 r
.80275 .38878 .80574 .39298 .81317 .39574 .81019 .39154 Mtetra
.216 .505 .907 r
.81019 .39154 .81317 .39574 .82064 .3985 .81767 .39429 Mtetra
.219 .507 .908 r
.81767 .39429 .82064 .3985 .82815 .40124 .82519 .39704 Mtetra
.223 .51 .909 r
.82519 .39704 .82815 .40124 .83569 .40396 .83274 .39976 Mtetra
.228 .514 .911 r
.83274 .39976 .83569 .40396 .84327 .40665 .84033 .40244 Mtetra
.234 .518 .913 r
.84033 .40244 .84327 .40665 .85089 .40929 .84796 .40508 Mtetra
.241 .523 .914 r
.84796 .40508 .85089 .40929 .85854 .41187 .85562 .40766 Mtetra
.25 .529 .917 r
.85562 .40766 .85854 .41187 .86623 .41438 .86331 .41017 Mtetra
.823 .771 .804 r
.22275 .604 .22665 .60729 .23277 .60102 .22888 .59773 Mtetra
.824 .771 .802 r
.22888 .59773 .23277 .60102 .23889 .59468 .23502 .59137 Mtetra
.825 .771 .801 r
.23502 .59137 .23889 .59468 .24501 .58827 .24116 .58495 Mtetra
.826 .771 .8 r
.24116 .58495 .24501 .58827 .25114 .58181 .2473 .57848 Mtetra
.827 .771 .799 r
.2473 .57848 .25114 .58181 .25727 .57531 .25344 .57196 Mtetra
.828 .771 .798 r
.25344 .57196 .25727 .57531 .2634 .56877 .25958 .56541 Mtetra
.828 .771 .797 r
.25958 .56541 .2634 .56877 .26952 .56221 .26572 .55884 Mtetra
.829 .77 .797 r
.26572 .55884 .26952 .56221 .27565 .55564 .27186 .55226 Mtetra
.27186 .55226 .27565 .55564 .28177 .54906 .27799 .54567 Mtetra
.27799 .54567 .28177 .54906 .28788 .54249 .28412 .53908 Mtetra
.28412 .53908 .28788 .54249 .29399 .53593 .29025 .53251 Mtetra
.828 .771 .797 r
.29025 .53251 .29399 .53593 .3001 .52939 .29637 .52596 Mtetra
.828 .771 .798 r
.29637 .52596 .3001 .52939 .3062 .52288 .30248 .51943 Mtetra
.827 .771 .799 r
.30248 .51943 .3062 .52288 .3123 .5164 .30859 .51295 Mtetra
.827 .771 .8 r
.30859 .51295 .3123 .5164 .31839 .50997 .3147 .50651 Mtetra
.826 .771 .801 r
.3147 .50651 .31839 .50997 .32447 .5036 .32079 .50012 Mtetra
.825 .771 .802 r
.32079 .50012 .32447 .5036 .33055 .49728 .32688 .49379 Mtetra
.823 .771 .803 r
.32688 .49379 .33055 .49728 .33662 .49103 .33297 .48752 Mtetra
.822 .771 .805 r
.33297 .48752 .33662 .49103 .34269 .48484 .33905 .48133 Mtetra
.821 .771 .806 r
.33905 .48133 .34269 .48484 .34874 .47874 .34512 .47521 Mtetra
.819 .771 .808 r
.34512 .47521 .34874 .47874 .3548 .47272 .35118 .46918 Mtetra
.817 .771 .81 r
.35118 .46918 .3548 .47272 .36084 .46678 .35724 .46323 Mtetra
.815 .771 .812 r
.35724 .46323 .36084 .46678 .36688 .46095 .36329 .45738 Mtetra
.813 .771 .814 r
.36329 .45738 .36688 .46095 .37292 .4552 .36934 .45163 Mtetra
.81 .771 .816 r
.36934 .45163 .37292 .4552 .37895 .44957 .37538 .44598 Mtetra
.808 .771 .819 r
.37538 .44598 .37895 .44957 .38497 .44404 .38142 .44044 Mtetra
.805 .771 .822 r
.38142 .44044 .38497 .44404 .39099 .43862 .38745 .43502 Mtetra
.802 .771 .824 r
.38745 .43502 .39099 .43862 .397 .43333 .39347 .42971 Mtetra
.799 .771 .827 r
.39347 .42971 .397 .43333 .40301 .42815 .3995 .42452 Mtetra
.796 .771 .83 r
.3995 .42452 .40301 .42815 .40902 .42309 .40552 .41945 Mtetra
.792 .77 .833 r
.40552 .41945 .40902 .42309 .41503 .41817 .41153 .41452 Mtetra
.788 .77 .837 r
.41153 .41452 .41503 .41817 .42103 .41337 .41755 .40971 Mtetra
.784 .77 .84 r
.41755 .40971 .42103 .41337 .42703 .40871 .42356 .40504 Mtetra
.78 .769 .843 r
.42356 .40504 .42703 .40871 .43303 .40419 .42957 .40051 Mtetra
.775 .768 .847 r
.42957 .40051 .43303 .40419 .43903 .39981 .43559 .39611 Mtetra
.77 .768 .851 r
.43559 .39611 .43903 .39981 .44504 .39556 .4416 .39186 Mtetra
.765 .767 .855 r
.4416 .39186 .44504 .39556 .45104 .39147 .44761 .38776 Mtetra
.759 .766 .858 r
.44761 .38776 .45104 .39147 .45704 .38752 .45363 .3838 Mtetra
.753 .765 .862 r
.45363 .3838 .45704 .38752 .46305 .38372 .45965 .37999 Mtetra
.747 .764 .866 r
.45965 .37999 .46305 .38372 .46906 .38007 .46567 .37633 Mtetra
.74 .762 .871 r
.46567 .37633 .46906 .38007 .47508 .37658 .47169 .37283 Mtetra
.734 .761 .875 r
.47169 .37283 .47508 .37658 .4811 .37324 .47773 .36948 Mtetra
.726 .759 .879 r
.47773 .36948 .4811 .37324 .48713 .37005 .48376 .36628 Mtetra
.718 .757 .883 r
.48376 .36628 .48713 .37005 .49317 .36702 .48981 .36325 Mtetra
.71 .755 .887 r
.48981 .36325 .49317 .36702 .49921 .36415 .49586 .36037 Mtetra
.702 .753 .891 r
.49586 .36037 .49921 .36415 .50527 .36144 .50193 .35765 Mtetra
.693 .75 .896 r
.50193 .35765 .50527 .36144 .51133 .35889 .508 .35509 Mtetra
.684 .748 .9 r
.508 .35509 .51133 .35889 .5174 .3565 .51408 .35269 Mtetra
.674 .745 .904 r
.51408 .35269 .5174 .3565 .52349 .35427 .52018 .35045 Mtetra
.664 .741 .908 r
.52018 .35045 .52349 .35427 .52959 .35221 .52629 .34838 Mtetra
.653 .738 .912 r
.52629 .34838 .52959 .35221 .5357 .3503 .53241 .34646 Mtetra
.642 .734 .915 r
.53241 .34646 .5357 .3503 .54183 .34856 .53855 .34471 Mtetra
.63 .729 .919 r
.53855 .34471 .54183 .34856 .54798 .34698 .5447 .34312 Mtetra
.618 .725 .922 r
.5447 .34312 .54798 .34698 .55414 .34556 .55087 .34169 Mtetra
.606 .72 .926 r
.55087 .34169 .55414 .34556 .56032 .3443 .55706 .34042 Mtetra
.593 .715 .929 r
.55706 .34042 .56032 .3443 .56652 .3432 .56327 .33932 Mtetra
.58 .71 .932 r
.56327 .33932 .56652 .3432 .57274 .34226 .5695 .33837 Mtetra
.566 .704 .934 r
.5695 .33837 .57274 .34226 .57898 .34148 .57575 .33758 Mtetra
.552 .698 .936 r
.57575 .33758 .57898 .34148 .58525 .34085 .58202 .33695 Mtetra
.538 .691 .938 r
.58202 .33695 .58525 .34085 .59153 .34039 .58831 .33648 Mtetra
.523 .685 .94 r
.58831 .33648 .59153 .34039 .59785 .34008 .59463 .33616 Mtetra
.508 .678 .941 r
.59463 .33616 .59785 .34008 .60418 .33992 .60098 .336 Mtetra
.493 .67 .942 r
.60098 .336 .60418 .33992 .61055 .33992 .60735 .33599 Mtetra
.478 .663 .943 r
.60735 .33599 .61055 .33992 .61694 .34007 .61375 .33613 Mtetra
.462 .655 .944 r
.61375 .33613 .61694 .34007 .62335 .34037 .62017 .33642 Mtetra
.447 .647 .944 r
.62017 .33642 .62335 .34037 .6298 .34081 .62663 .33686 Mtetra
.432 .639 .944 r
.62663 .33686 .6298 .34081 .63628 .34139 .63311 .33744 Mtetra
.416 .631 .943 r
.63311 .33744 .63628 .34139 .64279 .34212 .63963 .33816 Mtetra
.401 .623 .942 r
.63963 .33816 .64279 .34212 .64933 .34299 .64618 .33902 Mtetra
.386 .614 .941 r
.64618 .33902 .64933 .34299 .65591 .34399 .65276 .34002 Mtetra
.371 .606 .94 r
.65276 .34002 .65591 .34399 .66252 .34513 .65938 .34115 Mtetra
.356 .598 .938 r
.65938 .34115 .66252 .34513 .66916 .3464 .66603 .34241 Mtetra
.342 .59 .937 r
.66603 .34241 .66916 .3464 .67584 .34779 .67271 .34379 Mtetra
.328 .581 .935 r
.67271 .34379 .67584 .34779 .68255 .3493 .67943 .3453 Mtetra
.315 .574 .933 r
.67943 .3453 .68255 .3493 .6893 .35093 .68619 .34692 Mtetra
.302 .566 .93 r
.68619 .34692 .6893 .35093 .69609 .35268 .69299 .34866 Mtetra
.289 .558 .928 r
.69299 .34866 .69609 .35268 .70292 .35453 .69982 .35051 Mtetra
.278 .551 .926 r
.69982 .35051 .70292 .35453 .70979 .35649 .7067 .35246 Mtetra
.267 .545 .924 r
.7067 .35246 .70979 .35649 .71669 .35855 .71361 .35452 Mtetra
.256 .538 .921 r
.71361 .35452 .71669 .35855 .72364 .3607 .72056 .35666 Mtetra
.247 .532 .919 r
.72056 .35666 .72364 .3607 .73063 .36294 .72756 .3589 Mtetra
.238 .527 .917 r
.72756 .3589 .73063 .36294 .73765 .36527 .73459 .36122 Mtetra
.23 .522 .915 r
.73459 .36122 .73765 .36527 .74472 .36767 .74167 .36361 Mtetra
.223 .517 .914 r
.74167 .36361 .74472 .36767 .75183 .37014 .74878 .36608 Mtetra
.217 .513 .912 r
.74878 .36608 .75183 .37014 .75898 .37267 .75594 .36861 Mtetra
.212 .51 .911 r
.75594 .36861 .75898 .37267 .76617 .37526 .76314 .37119 Mtetra
.208 .507 .909 r
.76314 .37119 .76617 .37526 .77341 .3779 .77038 .37383 Mtetra
.205 .505 .909 r
.77038 .37383 .77341 .3779 .78068 .38058 .77767 .3765 Mtetra
.203 .504 .908 r
.77767 .3765 .78068 .38058 .788 .38329 .78499 .37921 Mtetra
.202 .503 .908 r
.78499 .37921 .788 .38329 .79535 .38603 .79236 .38194 Mtetra
.79236 .38194 .79535 .38603 .80275 .38878 .79976 .38469 Mtetra
.203 .504 .908 r
.79976 .38469 .80275 .38878 .81019 .39154 .80721 .38744 Mtetra
.205 .505 .909 r
.80721 .38744 .81019 .39154 .81767 .39429 .8147 .39019 Mtetra
.208 .507 .909 r
.8147 .39019 .81767 .39429 .82519 .39704 .82222 .39293 Mtetra
.212 .51 .911 r
.82222 .39293 .82519 .39704 .83274 .39976 .82978 .39564 Mtetra
.218 .514 .912 r
.82978 .39564 .83274 .39976 .84033 .40244 .83738 .39832 Mtetra
.224 .518 .914 r
.83738 .39832 .84033 .40244 .84796 .40508 .84502 .40095 Mtetra
.232 .523 .916 r
.84502 .40095 .84796 .40508 .85562 .40766 .85269 .40353 Mtetra
.241 .529 .918 r
.85269 .40353 .85562 .40766 .86331 .41017 .8604 .40603 Mtetra
.825 .775 .806 r
.21883 .6008 .22275 .604 .22888 .59773 .22498 .59451 Mtetra
.826 .775 .804 r
.22498 .59451 .22888 .59773 .23502 .59137 .23113 .58815 Mtetra
.827 .775 .803 r
.23113 .58815 .23502 .59137 .24116 .58495 .23728 .58172 Mtetra
.828 .775 .802 r
.23728 .58172 .24116 .58495 .2473 .57848 .24343 .57524 Mtetra
.829 .775 .801 r
.24343 .57524 .2473 .57848 .25344 .57196 .24959 .56871 Mtetra
.83 .775 .8 r
.24959 .56871 .25344 .57196 .25958 .56541 .25574 .56215 Mtetra
.831 .775 .8 r
.25574 .56215 .25958 .56541 .26572 .55884 .2619 .55557 Mtetra
.831 .775 .799 r
.2619 .55557 .26572 .55884 .27186 .55226 .26805 .54898 Mtetra
.26805 .54898 .27186 .55226 .27799 .54567 .27419 .54238 Mtetra
.27419 .54238 .27799 .54567 .28412 .53908 .28034 .53578 Mtetra
.28034 .53578 .28412 .53908 .29025 .53251 .28648 .5292 Mtetra
.831 .776 .8 r
.28648 .5292 .29025 .53251 .29637 .52596 .29261 .52264 Mtetra
.83 .776 .8 r
.29261 .52264 .29637 .52596 .30248 .51943 .29874 .5161 Mtetra
.83 .776 .801 r
.29874 .5161 .30248 .51943 .30859 .51295 .30486 .50961 Mtetra
.829 .776 .802 r
.30486 .50961 .30859 .51295 .3147 .50651 .31098 .50316 Mtetra
.828 .776 .803 r
.31098 .50316 .3147 .50651 .32079 .50012 .31709 .49676 Mtetra
.827 .777 .804 r
.31709 .49676 .32079 .50012 .32688 .49379 .32319 .49042 Mtetra
.826 .777 .806 r
.32319 .49042 .32688 .49379 .33297 .48752 .32929 .48414 Mtetra
.825 .777 .807 r
.32929 .48414 .33297 .48752 .33905 .48133 .33538 .47794 Mtetra
.823 .777 .809 r
.33538 .47794 .33905 .48133 .34512 .47521 .34147 .47181 Mtetra
.822 .777 .811 r
.34147 .47181 .34512 .47521 .35118 .46918 .34754 .46577 Mtetra
.82 .778 .813 r
.34754 .46577 .35118 .46918 .35724 .46323 .35362 .45981 Mtetra
.818 .778 .815 r
.35362 .45981 .35724 .46323 .36329 .45738 .35968 .45395 Mtetra
.816 .778 .817 r
.35968 .45395 .36329 .45738 .36934 .45163 .36574 .44819 Mtetra
.813 .778 .82 r
.36574 .44819 .36934 .45163 .37538 .44598 .37179 .44253 Mtetra
.811 .778 .822 r
.37179 .44253 .37538 .44598 .38142 .44044 .37784 .43699 Mtetra
.808 .778 .825 r
.37784 .43699 .38142 .44044 .38745 .43502 .38389 .43155 Mtetra
.805 .778 .828 r
.38389 .43155 .38745 .43502 .39347 .42971 .38993 .42623 Mtetra
.802 .778 .831 r
.38993 .42623 .39347 .42971 .3995 .42452 .39596 .42103 Mtetra
.799 .778 .834 r
.39596 .42103 .3995 .42452 .40552 .41945 .40199 .41596 Mtetra
.795 .778 .838 r
.40199 .41596 .40552 .41945 .41153 .41452 .40802 .41101 Mtetra
.791 .778 .841 r
.40802 .41101 .41153 .41452 .41755 .40971 .41405 .40619 Mtetra
.787 .778 .844 r
.41405 .40619 .41755 .40971 .42356 .40504 .42007 .40151 Mtetra
.782 .777 .848 r
.42007 .40151 .42356 .40504 .42957 .40051 .42609 .39697 Mtetra
.778 .777 .852 r
.42609 .39697 .42957 .40051 .43559 .39611 .43212 .39257 Mtetra
.773 .776 .856 r
.43212 .39257 .43559 .39611 .4416 .39186 .43814 .38831 Mtetra
.767 .776 .86 r
.43814 .38831 .4416 .39186 .44761 .38776 .44417 .38419 Mtetra
.762 .775 .864 r
.44417 .38419 .44761 .38776 .45363 .3838 .45019 .38023 Mtetra
.756 .774 .868 r
.45019 .38023 .45363 .3838 .45965 .37999 .45622 .37641 Mtetra
.749 .773 .872 r
.45622 .37641 .45965 .37999 .46567 .37633 .46225 .37274 Mtetra
.743 .772 .876 r
.46225 .37274 .46567 .37633 .47169 .37283 .46829 .36923 Mtetra
.736 .77 .881 r
.46829 .36923 .47169 .37283 .47773 .36948 .47433 .36587 Mtetra
.728 .769 .885 r
.47433 .36587 .47773 .36948 .48376 .36628 .48038 .36266 Mtetra
.72 .767 .889 r
.48038 .36266 .48376 .36628 .48981 .36325 .48644 .35962 Mtetra
.712 .765 .894 r
.48644 .35962 .48981 .36325 .49586 .36037 .4925 .35673 Mtetra
.703 .762 .898 r
.4925 .35673 .49586 .36037 .50193 .35765 .49857 .354 Mtetra
.694 .76 .902 r
.49857 .354 .50193 .35765 .508 .35509 .50466 .35143 Mtetra
.684 .757 .907 r
.50466 .35143 .508 .35509 .51408 .35269 .51075 .34903 Mtetra
.674 .754 .911 r
.51075 .34903 .51408 .35269 .52018 .35045 .51685 .34678 Mtetra
.664 .751 .915 r
.51685 .34678 .52018 .35045 .52629 .34838 .52297 .3447 Mtetra
.653 .747 .919 r
.52297 .3447 .52629 .34838 .53241 .34646 .5291 .34277 Mtetra
.641 .743 .923 r
.5291 .34277 .53241 .34646 .53855 .34471 .53525 .34101 Mtetra
.629 .739 .927 r
.53525 .34101 .53855 .34471 .5447 .34312 .54141 .33942 Mtetra
.617 .734 .93 r
.54141 .33942 .5447 .34312 .55087 .34169 .54759 .33798 Mtetra
.604 .729 .933 r
.54759 .33798 .55087 .34169 .55706 .34042 .55379 .3367 Mtetra
.59 .724 .936 r
.55379 .3367 .55706 .34042 .56327 .33932 .56001 .33559 Mtetra
.577 .718 .939 r
.56001 .33559 .56327 .33932 .5695 .33837 .56624 .33463 Mtetra
.562 .712 .942 r
.56624 .33463 .5695 .33837 .57575 .33758 .5725 .33384 Mtetra
.548 .706 .944 r
.5725 .33384 .57575 .33758 .58202 .33695 .57878 .3332 Mtetra
.533 .699 .946 r
.57878 .3332 .58202 .33695 .58831 .33648 .58508 .33272 Mtetra
.518 .693 .948 r
.58508 .33272 .58831 .33648 .59463 .33616 .59141 .33239 Mtetra
.502 .685 .949 r
.59141 .33239 .59463 .33616 .60098 .336 .59776 .33222 Mtetra
.487 .678 .95 r
.59776 .33222 .60098 .336 .60735 .33599 .60414 .33221 Mtetra
.471 .67 .95 r
.60414 .33221 .60735 .33599 .61375 .33613 .61055 .33234 Mtetra
.455 .662 .95 r
.61055 .33234 .61375 .33613 .62017 .33642 .61698 .33262 Mtetra
.439 .653 .95 r
.61698 .33262 .62017 .33642 .62663 .33686 .62344 .33305 Mtetra
.423 .645 .95 r
.62344 .33305 .62663 .33686 .63311 .33744 .62994 .33362 Mtetra
.407 .636 .949 r
.62994 .33362 .63311 .33744 .63963 .33816 .63646 .33434 Mtetra
.391 .628 .948 r
.63646 .33434 .63963 .33816 .64618 .33902 .64302 .33519 Mtetra
.375 .619 .947 r
.64302 .33519 .64618 .33902 .65276 .34002 .64961 .33618 Mtetra
.36 .61 .945 r
.64961 .33618 .65276 .34002 .65938 .34115 .65623 .3373 Mtetra
.345 .602 .943 r
.65623 .3373 .65938 .34115 .66603 .34241 .66289 .33855 Mtetra
.33 .593 .941 r
.66289 .33855 .66603 .34241 .67271 .34379 .66958 .33993 Mtetra
.316 .584 .939 r
.66958 .33993 .67271 .34379 .67943 .3453 .67631 .34143 Mtetra
.302 .576 .936 r
.67631 .34143 .67943 .3453 .68619 .34692 .68308 .34305 Mtetra
.289 .568 .934 r
.68308 .34305 .68619 .34692 .69299 .34866 .68988 .34478 Mtetra
.276 .56 .931 r
.68988 .34478 .69299 .34866 .69982 .35051 .69672 .34662 Mtetra
.265 .553 .929 r
.69672 .34662 .69982 .35051 .7067 .35246 .7036 .34857 Mtetra
.253 .546 .926 r
.7036 .34857 .7067 .35246 .71361 .35452 .71052 .35061 Mtetra
.243 .539 .924 r
.71052 .35061 .71361 .35452 .72056 .35666 .71749 .35275 Mtetra
.233 .533 .921 r
.71749 .35275 .72056 .35666 .72756 .3589 .72449 .35498 Mtetra
.225 .527 .919 r
.72449 .35498 .72756 .3589 .73459 .36122 .73153 .35729 Mtetra
.217 .522 .917 r
.73153 .35729 .73459 .36122 .74167 .36361 .73861 .35968 Mtetra
.21 .517 .915 r
.73861 .35968 .74167 .36361 .74878 .36608 .74574 .36214 Mtetra
.204 .513 .913 r
.74574 .36214 .74878 .36608 .75594 .36861 .7529 .36466 Mtetra
.199 .51 .912 r
.7529 .36466 .75594 .36861 .76314 .37119 .76011 .36724 Mtetra
.195 .507 .911 r
.76011 .36724 .76314 .37119 .77038 .37383 .76736 .36986 Mtetra
.192 .505 .91 r
.76736 .36986 .77038 .37383 .77767 .3765 .77465 .37253 Mtetra
.19 .504 .909 r
.77465 .37253 .77767 .3765 .78499 .37921 .78198 .37523 Mtetra
.189 .503 .909 r
.78198 .37523 .78499 .37921 .79236 .38194 .78936 .37795 Mtetra
.19 .503 .909 r
.78936 .37795 .79236 .38194 .79976 .38469 .79677 .38069 Mtetra
.191 .504 .909 r
.79677 .38069 .79976 .38469 .80721 .38744 .80423 .38344 Mtetra
.193 .505 .91 r
.80423 .38344 .80721 .38744 .8147 .39019 .81172 .38618 Mtetra
.197 .507 .91 r
.81172 .38618 .8147 .39019 .82222 .39293 .81925 .38891 Mtetra
.202 .51 .912 r
.81925 .38891 .82222 .39293 .82978 .39564 .82683 .39161 Mtetra
.208 .514 .913 r
.82683 .39161 .82978 .39564 .83738 .39832 .83444 .39428 Mtetra
.215 .518 .915 r
.83444 .39428 .83738 .39832 .84502 .40095 .84208 .39691 Mtetra
.223 .524 .917 r
.84208 .39691 .84502 .40095 .85269 .40353 .84976 .39948 Mtetra
.233 .53 .92 r
.84976 .39948 .85269 .40353 .8604 .40603 .85748 .40197 Mtetra
.826 .779 .808 r
.21489 .59767 .21883 .6008 .22498 .59451 .22105 .59137 Mtetra
.828 .779 .806 r
.22105 .59137 .22498 .59451 .23113 .58815 .22721 .58501 Mtetra
.829 .779 .805 r
.22721 .58501 .23113 .58815 .23728 .58172 .23337 .57857 Mtetra
.83 .779 .804 r
.23337 .57857 .23728 .58172 .24343 .57524 .23954 .57208 Mtetra
.831 .779 .803 r
.23954 .57208 .24343 .57524 .24959 .56871 .24571 .56555 Mtetra
.832 .779 .802 r
.24571 .56555 .24959 .56871 .25574 .56215 .25188 .55899 Mtetra
.833 .78 .802 r
.25188 .55899 .25574 .56215 .2619 .55557 .25804 .5524 Mtetra
.833 .78 .801 r
.25804 .5524 .2619 .55557 .26805 .54898 .26421 .5458 Mtetra
.26421 .5458 .26805 .54898 .27419 .54238 .27037 .53919 Mtetra
.27037 .53919 .27419 .54238 .28034 .53578 .27653 .53259 Mtetra
.833 .781 .802 r
.27653 .53259 .28034 .53578 .28648 .5292 .28268 .526 Mtetra
.28268 .526 .28648 .5292 .29261 .52264 .28883 .51943 Mtetra
.833 .781 .803 r
.28883 .51943 .29261 .52264 .29874 .5161 .29497 .51289 Mtetra
.832 .781 .804 r
.29497 .51289 .29874 .5161 .30486 .50961 .30111 .50638 Mtetra
.832 .782 .805 r
.30111 .50638 .30486 .50961 .31098 .50316 .30724 .49993 Mtetra
.831 .782 .806 r
.30724 .49993 .31098 .50316 .31709 .49676 .31336 .49352 Mtetra
.83 .782 .807 r
.31336 .49352 .31709 .49676 .32319 .49042 .31948 .48717 Mtetra
.829 .783 .809 r
.31948 .48717 .32319 .49042 .32929 .48414 .32559 .48089 Mtetra
.828 .783 .81 r
.32559 .48089 .32929 .48414 .33538 .47794 .3317 .47467 Mtetra
.826 .784 .812 r
.3317 .47467 .33538 .47794 .34147 .47181 .33779 .46854 Mtetra
.825 .784 .814 r
.33779 .46854 .34147 .47181 .34754 .46577 .34388 .46249 Mtetra
.823 .784 .816 r
.34388 .46249 .34754 .46577 .35362 .45981 .34997 .45652 Mtetra
.821 .785 .818 r
.34997 .45652 .35362 .45981 .35968 .45395 .35605 .45066 Mtetra
.819 .785 .821 r
.35605 .45066 .35968 .45395 .36574 .44819 .36212 .44489 Mtetra
.816 .785 .823 r
.36212 .44489 .36574 .44819 .37179 .44253 .36819 .43922 Mtetra
.814 .785 .826 r
.36819 .43922 .37179 .44253 .37784 .43699 .37425 .43366 Mtetra
.811 .786 .829 r
.37425 .43366 .37784 .43699 .38389 .43155 .3803 .42822 Mtetra
.808 .786 .832 r
.3803 .42822 .38389 .43155 .38993 .42623 .38635 .42289 Mtetra
.805 .786 .835 r
.38635 .42289 .38993 .42623 .39596 .42103 .3924 .41768 Mtetra
.802 .786 .838 r
.3924 .41768 .39596 .42103 .40199 .41596 .39845 .4126 Mtetra
.798 .786 .842 r
.39845 .4126 .40199 .41596 .40802 .41101 .40449 .40764 Mtetra
.794 .786 .845 r
.40449 .40764 .40802 .41101 .41405 .40619 .41052 .40282 Mtetra
.79 .786 .849 r
.41052 .40282 .41405 .40619 .42007 .40151 .41656 .39813 Mtetra
.785 .786 .853 r
.41656 .39813 .42007 .40151 .42609 .39697 .4226 .39358 Mtetra
.781 .785 .857 r
.4226 .39358 .42609 .39697 .43212 .39257 .42863 .38917 Mtetra
.775 .785 .861 r
.42863 .38917 .43212 .39257 .43814 .38831 .43467 .3849 Mtetra
.77 .784 .865 r
.43467 .3849 .43814 .38831 .44417 .38419 .4407 .38077 Mtetra
.764 .784 .869 r
.4407 .38077 .44417 .38419 .45019 .38023 .44674 .3768 Mtetra
.758 .783 .873 r
.44674 .3768 .45019 .38023 .45622 .37641 .45278 .37297 Mtetra
.752 .782 .878 r
.45278 .37297 .45622 .37641 .46225 .37274 .45882 .3693 Mtetra
.745 .781 .882 r
.45882 .3693 .46225 .37274 .46829 .36923 .46487 .36577 Mtetra
.738 .78 .887 r
.46487 .36577 .46829 .36923 .47433 .36587 .47092 .36241 Mtetra
.73 .778 .891 r
.47092 .36241 .47433 .36587 .48038 .36266 .47698 .35919 Mtetra
.722 .776 .896 r
.47698 .35919 .48038 .36266 .48644 .35962 .48305 .35614 Mtetra
.713 .774 .9 r
.48305 .35614 .48644 .35962 .4925 .35673 .48912 .35324 Mtetra
.704 .772 .905 r
.48912 .35324 .4925 .35673 .49857 .354 .4952 .35051 Mtetra
.695 .77 .909 r
.4952 .35051 .49857 .354 .50466 .35143 .5013 .34793 Mtetra
.685 .767 .914 r
.5013 .34793 .50466 .35143 .51075 .34903 .5074 .34552 Mtetra
.674 .764 .918 r
.5074 .34552 .51075 .34903 .51685 .34678 .51351 .34326 Mtetra
.663 .761 .922 r
.51351 .34326 .51685 .34678 .52297 .3447 .51964 .34117 Mtetra
.652 .757 .927 r
.51964 .34117 .52297 .3447 .5291 .34277 .52578 .33924 Mtetra
.64 .753 .93 r
.52578 .33924 .5291 .34277 .53525 .34101 .53194 .33747 Mtetra
.628 .749 .934 r
.53194 .33747 .53525 .34101 .54141 .33942 .53811 .33586 Mtetra
.615 .744 .938 r
.53811 .33586 .54141 .33942 .54759 .33798 .5443 .33442 Mtetra
.601 .739 .941 r
.5443 .33442 .54759 .33798 .55379 .3367 .55051 .33313 Mtetra
.588 .733 .944 r
.55051 .33313 .55379 .3367 .56001 .33559 .55673 .33201 Mtetra
.573 .728 .947 r
.55673 .33201 .56001 .33559 .56624 .33463 .56298 .33105 Mtetra
.559 .721 .949 r
.56298 .33105 .56624 .33463 .5725 .33384 .56924 .33024 Mtetra
.543 .715 .952 r
.56924 .33024 .5725 .33384 .57878 .3332 .57553 .3296 Mtetra
.528 .708 .953 r
.57553 .3296 .57878 .3332 .58508 .33272 .58184 .32911 Mtetra
.512 .701 .955 r
.58184 .32911 .58508 .33272 .59141 .33239 .58818 .32877 Mtetra
.496 .693 .956 r
.58818 .32877 .59141 .33239 .59776 .33222 .59454 .32859 Mtetra
.48 .685 .957 r
.59454 .32859 .59776 .33222 .60414 .33221 .60093 .32857 Mtetra
.463 .677 .957 r
.60093 .32857 .60414 .33221 .61055 .33234 .60734 .32869 Mtetra
.447 .668 .957 r
.60734 .32869 .61055 .33234 .61698 .33262 .61378 .32897 Mtetra
.43 .66 .957 r
.61378 .32897 .61698 .33262 .62344 .33305 .62025 .32939 Mtetra
.414 .651 .956 r
.62025 .32939 .62344 .33305 .62994 .33362 .62675 .32995 Mtetra
.397 .642 .955 r
.62675 .32995 .62994 .33362 .63646 .33434 .63329 .33066 Mtetra
.381 .633 .953 r
.63329 .33066 .63646 .33434 .64302 .33519 .63985 .3315 Mtetra
.364 .623 .952 r
.63985 .3315 .64302 .33519 .64961 .33618 .64645 .33248 Mtetra
.349 .614 .95 r
.64645 .33248 .64961 .33618 .65623 .3373 .65308 .3336 Mtetra
.333 .605 .947 r
.65308 .3336 .65623 .3373 .66289 .33855 .65974 .33484 Mtetra
.318 .596 .945 r
.65974 .33484 .66289 .33855 .66958 .33993 .66644 .33621 Mtetra
.303 .587 .942 r
.66644 .33621 .66958 .33993 .67631 .34143 .67318 .3377 Mtetra
.289 .579 .94 r
.67318 .3377 .67631 .34143 .68308 .34305 .67995 .33931 Mtetra
.276 .57 .937 r
.67995 .33931 .68308 .34305 .68988 .34478 .68677 .34103 Mtetra
.263 .562 .934 r
.68677 .34103 .68988 .34478 .69672 .34662 .69362 .34286 Mtetra
.251 .554 .931 r
.69362 .34286 .69672 .34662 .7036 .34857 .7005 .3448 Mtetra
.24 .547 .928 r
.7005 .3448 .7036 .34857 .71052 .35061 .70743 .34684 Mtetra
.229 .54 .926 r
.70743 .34684 .71052 .35061 .71749 .35275 .7144 .34897 Mtetra
.22 .534 .923 r
.7144 .34897 .71749 .35275 .72449 .35498 .72141 .35119 Mtetra
.211 .528 .92 r
.72141 .35119 .72449 .35498 .73153 .35729 .72846 .35349 Mtetra
.203 .522 .918 r
.72846 .35349 .73153 .35729 .73861 .35968 .73555 .35587 Mtetra
.196 .518 .916 r
.73555 .35587 .73861 .35968 .74574 .36214 .74268 .35832 Mtetra
.19 .513 .914 r
.74268 .35832 .74574 .36214 .7529 .36466 .74986 .36083 Mtetra
.186 .51 .913 r
.74986 .36083 .7529 .36466 .76011 .36724 .75707 .3634 Mtetra
.182 .507 .911 r
.75707 .3634 .76011 .36724 .76736 .36986 .76433 .36601 Mtetra
.179 .505 .91 r
.76433 .36601 .76736 .36986 .77465 .37253 .77163 .36867 Mtetra
.177 .503 .91 r
.77163 .36867 .77465 .37253 .78198 .37523 .77897 .37136 Mtetra
.177 .503 .909 r
.77897 .37136 .78198 .37523 .78936 .37795 .78635 .37407 Mtetra
.178 .503 .909 r
.78635 .37407 .78936 .37795 .79677 .38069 .79377 .3768 Mtetra
.179 .504 .91 r
.79377 .3768 .79677 .38069 .80423 .38344 .80124 .37953 Mtetra
.182 .505 .91 r
.80124 .37953 .80423 .38344 .81172 .38618 .80874 .38227 Mtetra
.186 .507 .911 r
.80874 .38227 .81172 .38618 .81925 .38891 .81628 .38498 Mtetra
.191 .51 .913 r
.81628 .38498 .81925 .38891 .82683 .39161 .82386 .38768 Mtetra
.198 .514 .914 r
.82386 .38768 .82683 .39161 .83444 .39428 .83148 .39034 Mtetra
.206 .519 .916 r
.83148 .39034 .83444 .39428 .84208 .39691 .83914 .39295 Mtetra
.214 .524 .918 r
.83914 .39295 .84208 .39691 .84976 .39948 .84683 .3955 Mtetra
.224 .531 .921 r
.84683 .3955 .84976 .39948 .85748 .40197 .85455 .39799 Mtetra
.828 .783 .81 r
.21092 .59461 .21489 .59767 .22105 .59137 .21709 .58832 Mtetra
.829 .783 .808 r
.21709 .58832 .22105 .59137 .22721 .58501 .22327 .58195 Mtetra
.831 .783 .807 r
.22327 .58195 .22721 .58501 .23337 .57857 .22944 .57551 Mtetra
.832 .783 .806 r
.22944 .57551 .23337 .57857 .23954 .57208 .23563 .56902 Mtetra
.833 .784 .805 r
.23563 .56902 .23954 .57208 .24571 .56555 .24181 .56248 Mtetra
.834 .784 .804 r
.24181 .56248 .24571 .56555 .25188 .55899 .24799 .55592 Mtetra
.835 .784 .804 r
.24799 .55592 .25188 .55899 .25804 .5524 .25417 .54932 Mtetra
.835 .785 .804 r
.25417 .54932 .25804 .5524 .26421 .5458 .26035 .54272 Mtetra
.26035 .54272 .26421 .5458 .27037 .53919 .26652 .5361 Mtetra
.836 .785 .804 r
.26652 .5361 .27037 .53919 .27653 .53259 .27269 .5295 Mtetra
.836 .786 .804 r
.27269 .5295 .27653 .53259 .28268 .526 .27886 .5229 Mtetra
.836 .786 .805 r
.27886 .5229 .28268 .526 .28883 .51943 .28502 .51633 Mtetra
.835 .787 .805 r
.28502 .51633 .28883 .51943 .29497 .51289 .29118 .50978 Mtetra
.835 .787 .806 r
.29118 .50978 .29497 .51289 .30111 .50638 .29733 .50327 Mtetra
.834 .787 .807 r
.29733 .50327 .30111 .50638 .30724 .49993 .30347 .49681 Mtetra
.833 .788 .808 r
.30347 .49681 .30724 .49993 .31336 .49352 .30961 .4904 Mtetra
.833 .788 .81 r
.30961 .4904 .31336 .49352 .31948 .48717 .31574 .48404 Mtetra
.831 .789 .811 r
.31574 .48404 .31948 .48717 .32559 .48089 .32187 .47775 Mtetra
.83 .789 .813 r
.32187 .47775 .32559 .48089 .3317 .47467 .32798 .47154 Mtetra
.829 .79 .815 r
.32798 .47154 .3317 .47467 .33779 .46854 .3341 .46539 Mtetra
.827 .79 .817 r
.3341 .46539 .33779 .46854 .34388 .46249 .3402 .45934 Mtetra
.826 .791 .819 r
.3402 .45934 .34388 .46249 .34997 .45652 .3463 .45337 Mtetra
.824 .791 .822 r
.3463 .45337 .34997 .45652 .35605 .45066 .35239 .44749 Mtetra
.822 .792 .824 r
.35239 .44749 .35605 .45066 .36212 .44489 .35848 .44171 Mtetra
.819 .792 .827 r
.35848 .44171 .36212 .44489 .36819 .43922 .36455 .43604 Mtetra
.817 .793 .83 r
.36455 .43604 .36819 .43922 .37425 .43366 .37063 .43047 Mtetra
.814 .793 .833 r
.37063 .43047 .37425 .43366 .3803 .42822 .3767 .42502 Mtetra
.811 .793 .836 r
.3767 .42502 .3803 .42822 .38635 .42289 .38276 .41969 Mtetra
.808 .794 .839 r
.38276 .41969 .38635 .42289 .3924 .41768 .38882 .41447 Mtetra
.804 .794 .842 r
.38882 .41447 .3924 .41768 .39845 .4126 .39488 .40938 Mtetra
.801 .794 .846 r
.39488 .40938 .39845 .4126 .40449 .40764 .40093 .40442 Mtetra
.797 .794 .85 r
.40093 .40442 .40449 .40764 .41052 .40282 .40698 .39959 Mtetra
.793 .794 .854 r
.40698 .39959 .41052 .40282 .41656 .39813 .41303 .39489 Mtetra
.788 .794 .857 r
.41303 .39489 .41656 .39813 .4226 .39358 .41908 .39033 Mtetra
.783 .794 .862 r
.41908 .39033 .4226 .39358 .42863 .38917 .42512 .38591 Mtetra
.778 .794 .866 r
.42512 .38591 .42863 .38917 .43467 .3849 .43117 .38163 Mtetra
.773 .793 .87 r
.43117 .38163 .43467 .3849 .4407 .38077 .43722 .3775 Mtetra
.767 .793 .874 r
.43722 .3775 .4407 .38077 .44674 .3768 .44327 .37352 Mtetra
.76 .792 .879 r
.44327 .37352 .44674 .3768 .45278 .37297 .44932 .36968 Mtetra
.754 .792 .884 r
.44932 .36968 .45278 .37297 .45882 .3693 .45537 .366 Mtetra
.747 .791 .888 r
.45537 .366 .45882 .3693 .46487 .36577 .46143 .36247 Mtetra
.739 .789 .893 r
.46143 .36247 .46487 .36577 .47092 .36241 .4675 .35909 Mtetra
.732 .788 .898 r
.4675 .35909 .47092 .36241 .47698 .35919 .47357 .35587 Mtetra
.723 .786 .902 r
.47357 .35587 .47698 .35919 .48305 .35614 .47964 .35281 Mtetra
.714 .784 .907 r
.47964 .35281 .48305 .35614 .48912 .35324 .48573 .34991 Mtetra
.705 .782 .912 r
.48573 .34991 .48912 .35324 .4952 .35051 .49182 .34716 Mtetra
.695 .78 .916 r
.49182 .34716 .4952 .35051 .5013 .34793 .49792 .34458 Mtetra
.685 .777 .921 r
.49792 .34458 .5013 .34793 .5074 .34552 .50404 .34215 Mtetra
.674 .774 .925 r
.50404 .34215 .5074 .34552 .51351 .34326 .51016 .33989 Mtetra
.663 .771 .93 r
.51016 .33989 .51351 .34326 .51964 .34117 .5163 .33779 Mtetra
.651 .767 .934 r
.5163 .33779 .51964 .34117 .52578 .33924 .52245 .33585 Mtetra
.639 .763 .938 r
.52245 .33585 .52578 .33924 .53194 .33747 .52861 .33407 Mtetra
.626 .759 .942 r
.52861 .33407 .53194 .33747 .53811 .33586 .5348 .33246 Mtetra
.613 .754 .945 r
.5348 .33246 .53811 .33586 .5443 .33442 .54099 .331 Mtetra
.599 .748 .949 r
.54099 .331 .5443 .33442 .55051 .33313 .54721 .32971 Mtetra
.584 .743 .952 r
.54721 .32971 .55051 .33313 .55673 .33201 .55344 .32858 Mtetra
.569 .737 .955 r
.55344 .32858 .55673 .33201 .56298 .33105 .5597 .32761 Mtetra
.554 .73 .957 r
.5597 .32761 .56298 .33105 .56924 .33024 .56597 .32679 Mtetra
.538 .723 .959 r
.56597 .32679 .56924 .33024 .57553 .3296 .57227 .32614 Mtetra
.522 .716 .961 r
.57227 .32614 .57553 .3296 .58184 .32911 .57859 .32564 Mtetra
.506 .709 .962 r
.57859 .32564 .58184 .32911 .58818 .32877 .58493 .3253 Mtetra
.489 .701 .963 r
.58493 .3253 .58818 .32877 .59454 .32859 .5913 .32511 Mtetra
.472 .692 .963 r
.5913 .32511 .59454 .32859 .60093 .32857 .5977 .32508 Mtetra
.455 .684 .964 r
.5977 .32508 .60093 .32857 .60734 .32869 .60412 .32519 Mtetra
.438 .675 .963 r
.60412 .32519 .60734 .32869 .61378 .32897 .61057 .32546 Mtetra
.421 .666 .963 r
.61057 .32546 .61378 .32897 .62025 .32939 .61705 .32587 Mtetra
.404 .656 .961 r
.61705 .32587 .62025 .32939 .62675 .32995 .62356 .32642 Mtetra
.386 .647 .96 r
.62356 .32642 .62675 .32995 .63329 .33066 .6301 .32712 Mtetra
.37 .637 .958 r
.6301 .32712 .63329 .33066 .63985 .3315 .63667 .32795 Mtetra
.353 .628 .956 r
.63667 .32795 .63985 .3315 .64645 .33248 .64328 .32892 Mtetra
.337 .618 .954 r
.64328 .32892 .64645 .33248 .65308 .3336 .64992 .33003 Mtetra
.321 .609 .951 r
.64992 .33003 .65308 .3336 .65974 .33484 .65659 .33126 Mtetra
.305 .599 .948 r
.65659 .33126 .65974 .33484 .66644 .33621 .6633 .33262 Mtetra
.29 .59 .945 r
.6633 .33262 .66644 .33621 .67318 .3377 .67004 .3341 Mtetra
.276 .581 .942 r
.67004 .3341 .67318 .3377 .67995 .33931 .67683 .3357 Mtetra
.262 .572 .939 r
.67683 .3357 .67995 .33931 .68677 .34103 .68364 .33742 Mtetra
.249 .564 .936 r
.68364 .33742 .68677 .34103 .69362 .34286 .6905 .33924 Mtetra
.237 .556 .933 r
.6905 .33924 .69362 .34286 .7005 .3448 .6974 .34116 Mtetra
.226 .548 .93 r
.6974 .34116 .7005 .3448 .70743 .34684 .70433 .34319 Mtetra
.215 .541 .927 r
.70433 .34319 .70743 .34684 .7144 .34897 .71131 .34531 Mtetra
.205 .534 .924 r
.71131 .34531 .7144 .34897 .72141 .35119 .71833 .34752 Mtetra
.197 .528 .921 r
.71833 .34752 .72141 .35119 .72846 .35349 .72538 .34981 Mtetra
.189 .522 .919 r
.72538 .34981 .72846 .35349 .73555 .35587 .73248 .35218 Mtetra
.182 .518 .917 r
.73248 .35218 .73555 .35587 .74268 .35832 .73962 .35461 Mtetra
.177 .513 .915 r
.73962 .35461 .74268 .35832 .74986 .36083 .74681 .35711 Mtetra
.172 .51 .913 r
.74681 .35711 .74986 .36083 .75707 .3634 .75403 .35967 Mtetra
.168 .507 .912 r
.75403 .35967 .75707 .3634 .76433 .36601 .76129 .36227 Mtetra
.166 .505 .91 r
.76129 .36227 .76433 .36601 .77163 .36867 .7686 .36492 Mtetra
.165 .503 .91 r
.7686 .36492 .77163 .36867 .77897 .37136 .77595 .36759 Mtetra
.165 .503 .909 r
.77595 .36759 .77897 .37136 .78635 .37407 .78334 .37029 Mtetra
.78334 .37029 .78635 .37407 .79377 .3768 .79077 .37301 Mtetra
.168 .503 .91 r
.79077 .37301 .79377 .3768 .80124 .37953 .79825 .37573 Mtetra
.171 .505 .911 r
.79825 .37573 .80124 .37953 .80874 .38227 .80576 .37845 Mtetra
.176 .508 .912 r
.80576 .37845 .80874 .38227 .81628 .38498 .81331 .38115 Mtetra
.181 .511 .913 r
.81331 .38115 .81628 .38498 .82386 .38768 .8209 .38383 Mtetra
.188 .515 .915 r
.8209 .38383 .82386 .38768 .83148 .39034 .82853 .38647 Mtetra
.196 .52 .917 r
.82853 .38647 .83148 .39034 .83914 .39295 .83619 .38907 Mtetra
.206 .525 .919 r
.83619 .38907 .83914 .39295 .84683 .3955 .84389 .39161 Mtetra
.216 .531 .922 r
.84389 .39161 .84683 .3955 .85455 .39799 .85162 .39408 Mtetra
.829 .787 .812 r
.20692 .59163 .21092 .59461 .21709 .58832 .21311 .58534 Mtetra
.831 .787 .81 r
.21311 .58534 .21709 .58832 .22327 .58195 .2193 .57897 Mtetra
.832 .787 .809 r
.2193 .57897 .22327 .58195 .22944 .57551 .22549 .57254 Mtetra
.834 .788 .808 r
.22549 .57254 .22944 .57551 .23563 .56902 .23168 .56604 Mtetra
.835 .788 .807 r
.23168 .56604 .23563 .56902 .24181 .56248 .23788 .55951 Mtetra
.836 .788 .806 r
.23788 .55951 .24181 .56248 .24799 .55592 .24407 .55294 Mtetra
.837 .789 .806 r
.24407 .55294 .24799 .55592 .25417 .54932 .25027 .54635 Mtetra
.25027 .54635 .25417 .54932 .26035 .54272 .25646 .53974 Mtetra
.838 .79 .806 r
.25646 .53974 .26035 .54272 .26652 .5361 .26265 .53312 Mtetra
.26265 .53312 .26652 .5361 .27269 .5295 .26883 .52651 Mtetra
.838 .791 .807 r
.26883 .52651 .27269 .5295 .27886 .5229 .27501 .51992 Mtetra
.27501 .51992 .27886 .5229 .28502 .51633 .28119 .51334 Mtetra
.838 .792 .808 r
.28119 .51334 .28502 .51633 .29118 .50978 .28736 .50679 Mtetra
.837 .793 .809 r
.28736 .50679 .29118 .50978 .29733 .50327 .29352 .50028 Mtetra
.837 .793 .81 r
.29352 .50028 .29733 .50327 .30347 .49681 .29968 .49381 Mtetra
.836 .794 .811 r
.29968 .49381 .30347 .49681 .30961 .4904 .30583 .4874 Mtetra
.835 .794 .813 r
.30583 .4874 .30961 .4904 .31574 .48404 .31198 .48104 Mtetra
.834 .795 .814 r
.31198 .48104 .31574 .48404 .32187 .47775 .31812 .47474 Mtetra
.833 .796 .816 r
.31812 .47474 .32187 .47775 .32798 .47154 .32425 .46852 Mtetra
.832 .796 .818 r
.32425 .46852 .32798 .47154 .3341 .46539 .33037 .46237 Mtetra
.83 .797 .82 r
.33037 .46237 .3341 .46539 .3402 .45934 .33649 .45631 Mtetra
.828 .798 .822 r
.33649 .45631 .3402 .45934 .3463 .45337 .3426 .45034 Mtetra
.826 .798 .825 r
.3426 .45034 .3463 .45337 .35239 .44749 .34871 .44445 Mtetra
.824 .799 .828 r
.34871 .44445 .35239 .44749 .35848 .44171 .35481 .43867 Mtetra
.822 .8 .83 r
.35481 .43867 .35848 .44171 .36455 .43604 .3609 .43299 Mtetra
.819 .8 .833 r
.3609 .43299 .36455 .43604 .37063 .43047 .36699 .42742 Mtetra
.817 .801 .836 r
.36699 .42742 .37063 .43047 .3767 .42502 .37307 .42196 Mtetra
.814 .801 .84 r
.37307 .42196 .3767 .42502 .38276 .41969 .37915 .41662 Mtetra
.811 .802 .843 r
.37915 .41662 .38276 .41969 .38882 .41447 .38522 .4114 Mtetra
.807 .802 .847 r
.38522 .4114 .38882 .41447 .39488 .40938 .39129 .4063 Mtetra
.803 .802 .85 r
.39129 .4063 .39488 .40938 .40093 .40442 .39735 .40133 Mtetra
.8 .803 .854 r
.39735 .40133 .40093 .40442 .40698 .39959 .40342 .3965 Mtetra
.795 .803 .858 r
.40342 .3965 .40698 .39959 .41303 .39489 .40948 .39179 Mtetra
.791 .803 .862 r
.40948 .39179 .41303 .39489 .41908 .39033 .41554 .38723 Mtetra
.786 .803 .866 r
.41554 .38723 .41908 .39033 .42512 .38591 .4216 .3828 Mtetra
.781 .803 .871 r
.4216 .3828 .42512 .38591 .43117 .38163 .42766 .37852 Mtetra
.775 .803 .875 r
.42766 .37852 .43117 .38163 .43722 .3775 .43371 .37438 Mtetra
.769 .802 .88 r
.43371 .37438 .43722 .3775 .44327 .37352 .43978 .37039 Mtetra
.763 .802 .884 r
.43978 .37039 .44327 .37352 .44932 .36968 .44584 .36654 Mtetra
.756 .801 .889 r
.44584 .36654 .44932 .36968 .45537 .366 .4519 .36285 Mtetra
.749 .8 .894 r
.4519 .36285 .45537 .366 .46143 .36247 .45798 .35932 Mtetra
.741 .799 .899 r
.45798 .35932 .46143 .36247 .4675 .35909 .46405 .35593 Mtetra
.733 .798 .904 r
.46405 .35593 .4675 .35909 .47357 .35587 .47013 .3527 Mtetra
.724 .796 .909 r
.47013 .3527 .47357 .35587 .47964 .35281 .47622 .34963 Mtetra
.715 .795 .913 r
.47622 .34963 .47964 .35281 .48573 .34991 .48231 .34672 Mtetra
.706 .793 .918 r
.48231 .34672 .48573 .34991 .49182 .34716 .48842 .34397 Mtetra
.696 .79 .923 r
.48842 .34397 .49182 .34716 .49792 .34458 .49453 .34138 Mtetra
.685 .787 .928 r
.49453 .34138 .49792 .34458 .50404 .34215 .50065 .33894 Mtetra
.674 .784 .932 r
.50065 .33894 .50404 .34215 .51016 .33989 .50679 .33667 Mtetra
.662 .781 .937 r
.50679 .33667 .51016 .33989 .5163 .33779 .51294 .33456 Mtetra
.65 .777 .941 r
.51294 .33456 .5163 .33779 .52245 .33585 .5191 .33261 Mtetra
.637 .773 .945 r
.5191 .33261 .52245 .33585 .52861 .33407 .52527 .33083 Mtetra
.624 .769 .949 r
.52527 .33083 .52861 .33407 .5348 .33246 .53146 .3292 Mtetra
.61 .764 .953 r
.53146 .3292 .5348 .33246 .54099 .331 .53767 .32774 Mtetra
.595 .758 .956 r
.53767 .32774 .54099 .331 .54721 .32971 .5439 .32644 Mtetra
.581 .752 .959 r
.5439 .32644 .54721 .32971 .55344 .32858 .55014 .3253 Mtetra
.565 .746 .962 r
.55014 .3253 .55344 .32858 .5597 .32761 .55641 .32432 Mtetra
.549 .739 .964 r
.55641 .32432 .5597 .32761 .56597 .32679 .56269 .3235 Mtetra
.533 .732 .966 r
.56269 .3235 .56597 .32679 .57227 .32614 .569 .32283 Mtetra
.516 .724 .968 r
.569 .32283 .57227 .32614 .57859 .32564 .57533 .32233 Mtetra
.499 .717 .969 r
.57533 .32233 .57859 .32564 .58493 .3253 .58168 .32197 Mtetra
.482 .708 .969 r
.58168 .32197 .58493 .3253 .5913 .32511 .58806 .32178 Mtetra
.464 .699 .97 r
.58806 .32178 .5913 .32511 .5977 .32508 .59446 .32173 Mtetra
.446 .69 .97 r
.59446 .32173 .5977 .32508 .60412 .32519 .60089 .32184 Mtetra
.429 .681 .969 r
.60089 .32184 .60412 .32519 .61057 .32546 .60735 .32209 Mtetra
.411 .671 .968 r
.60735 .32209 .61057 .32546 .61705 .32587 .61384 .32249 Mtetra
.393 .662 .966 r
.61384 .32249 .61705 .32587 .62356 .32642 .62036 .32304 Mtetra
.375 .652 .965 r
.62036 .32304 .62356 .32642 .6301 .32712 .62691 .32372 Mtetra
.358 .642 .962 r
.62691 .32372 .6301 .32712 .63667 .32795 .63349 .32455 Mtetra
.341 .632 .96 r
.63349 .32455 .63667 .32795 .64328 .32892 .6401 .32551 Mtetra
.324 .622 .957 r
.6401 .32551 .64328 .32892 .64992 .33003 .64675 .3266 Mtetra
.308 .612 .954 r
.64675 .3266 .64992 .33003 .65659 .33126 .65343 .32782 Mtetra
.292 .602 .951 r
.65343 .32782 .65659 .33126 .6633 .33262 .66015 .32917 Mtetra
.276 .592 .948 r
.66015 .32917 .6633 .33262 .67004 .3341 .6669 .33064 Mtetra
.262 .583 .944 r
.6669 .33064 .67004 .3341 .67683 .3357 .67369 .33223 Mtetra
.248 .574 .941 r
.67369 .33223 .67683 .3357 .68364 .33742 .68052 .33393 Mtetra
.235 .565 .937 r
.68052 .33393 .68364 .33742 .6905 .33924 .68738 .33574 Mtetra
.222 .556 .934 r
.68738 .33574 .6905 .33924 .6974 .34116 .69429 .33766 Mtetra
.211 .549 .931 r
.69429 .33766 .6974 .34116 .70433 .34319 .70123 .33967 Mtetra
.2 .541 .927 r
.70123 .33967 .70433 .34319 .71131 .34531 .70821 .34178 Mtetra
.191 .534 .924 r
.70821 .34178 .71131 .34531 .71833 .34752 .71524 .34397 Mtetra
.182 .528 .921 r
.71524 .34397 .71833 .34752 .72538 .34981 .72231 .34625 Mtetra
.175 .522 .919 r
.72231 .34625 .72538 .34981 .73248 .35218 .72941 .3486 Mtetra
.168 .517 .916 r
.72941 .3486 .73248 .35218 .73962 .35461 .73656 .35103 Mtetra
.163 .513 .914 r
.73656 .35103 .73962 .35461 .74681 .35711 .74375 .35351 Mtetra
.158 .509 .913 r
.74375 .35351 .74681 .35711 .75403 .35967 .75098 .35605 Mtetra
.155 .507 .911 r
.75098 .35605 .75403 .35967 .76129 .36227 .75826 .35864 Mtetra
.153 .504 .91 r
.75826 .35864 .76129 .36227 .7686 .36492 .76557 .36127 Mtetra
.152 .503 .91 r
.76557 .36127 .7686 .36492 .77595 .36759 .77293 .36393 Mtetra
.152 .502 .909 r
.77293 .36393 .77595 .36759 .78334 .37029 .78033 .36662 Mtetra
.153 .502 .909 r
.78033 .36662 .78334 .37029 .79077 .37301 .78777 .36932 Mtetra
.156 .503 .91 r
.78777 .36932 .79077 .37301 .79825 .37573 .79525 .37202 Mtetra
.16 .505 .911 r
.79525 .37202 .79825 .37573 .80576 .37845 .80277 .37473 Mtetra
.165 .508 .912 r
.80277 .37473 .80576 .37845 .81331 .38115 .81033 .37741 Mtetra
.171 .511 .914 r
.81033 .37741 .81331 .38115 .8209 .38383 .81793 .38007 Mtetra
.179 .515 .916 r
.81793 .38007 .8209 .38383 .82853 .38647 .82556 .3827 Mtetra
.187 .52 .918 r
.82556 .3827 .82853 .38647 .83619 .38907 .83324 .38528 Mtetra
.197 .526 .92 r
.83324 .38528 .83619 .38907 .84389 .39161 .84095 .3878 Mtetra
.208 .533 .923 r
.84095 .3878 .84389 .39161 .85162 .39408 .84869 .39025 Mtetra
.831 .791 .814 r
.2029 .58873 .20692 .59163 .21311 .58534 .2091 .58244 Mtetra
.832 .791 .812 r
.2091 .58244 .21311 .58534 .2193 .57897 .2153 .57608 Mtetra
.834 .792 .811 r
.2153 .57608 .2193 .57897 .22549 .57254 .22151 .56965 Mtetra
.835 .792 .81 r
.22151 .56965 .22549 .57254 .23168 .56604 .22772 .56316 Mtetra
.837 .793 .809 r
.22772 .56316 .23168 .56604 .23788 .55951 .23392 .55663 Mtetra
.838 .793 .809 r
.23392 .55663 .23788 .55951 .24407 .55294 .24013 .55006 Mtetra
.838 .794 .808 r
.24013 .55006 .24407 .55294 .25027 .54635 .24634 .54347 Mtetra
.839 .794 .808 r
.24634 .54347 .25027 .54635 .25646 .53974 .25255 .53686 Mtetra
.84 .795 .808 r
.25255 .53686 .25646 .53974 .26265 .53312 .25875 .53025 Mtetra
.84 .795 .809 r
.25875 .53025 .26265 .53312 .26883 .52651 .26495 .52364 Mtetra
.84 .796 .809 r
.26495 .52364 .26883 .52651 .27501 .51992 .27114 .51704 Mtetra
.84 .797 .81 r
.27114 .51704 .27501 .51992 .28119 .51334 .27733 .51046 Mtetra
.84 .798 .81 r
.27733 .51046 .28119 .51334 .28736 .50679 .28352 .50391 Mtetra
.839 .798 .811 r
.28352 .50391 .28736 .50679 .29352 .50028 .28969 .4974 Mtetra
.839 .799 .813 r
.28969 .4974 .29352 .50028 .29968 .49381 .29587 .49093 Mtetra
.838 .8 .814 r
.29587 .49093 .29968 .49381 .30583 .4874 .30203 .48451 Mtetra
.838 .801 .816 r
.30203 .48451 .30583 .4874 .31198 .48104 .30819 .47815 Mtetra
.837 .801 .817 r
.30819 .47815 .31198 .48104 .31812 .47474 .31434 .47186 Mtetra
.835 .802 .819 r
.31434 .47186 .31812 .47474 .32425 .46852 .32049 .46563 Mtetra
.834 .803 .821 r
.32049 .46563 .32425 .46852 .33037 .46237 .32663 .45948 Mtetra
.833 .804 .823 r
.32663 .45948 .33037 .46237 .33649 .45631 .33276 .45341 Mtetra
.831 .805 .826 r
.33276 .45341 .33649 .45631 .3426 .45034 .33888 .44744 Mtetra
.829 .805 .828 r
.33888 .44744 .3426 .45034 .34871 .44445 .345 .44155 Mtetra
.827 .806 .831 r
.345 .44155 .34871 .44445 .35481 .43867 .35112 .43576 Mtetra
.825 .807 .834 r
.35112 .43576 .35481 .43867 .3609 .43299 .35722 .43008 Mtetra
.822 .808 .837 r
.35722 .43008 .3609 .43299 .36699 .42742 .36332 .42451 Mtetra
.819 .808 .84 r
.36332 .42451 .36699 .42742 .37307 .42196 .36942 .41904 Mtetra
.817 .809 .844 r
.36942 .41904 .37307 .42196 .37915 .41662 .37551 .4137 Mtetra
.813 .81 .847 r
.37551 .4137 .37915 .41662 .38522 .4114 .38159 .40847 Mtetra
.81 .81 .851 r
.38159 .40847 .38522 .4114 .39129 .4063 .38768 .40337 Mtetra
.806 .811 .855 r
.38768 .40337 .39129 .4063 .39735 .40133 .39376 .39839 Mtetra
.802 .811 .859 r
.39376 .39839 .39735 .40133 .40342 .3965 .39983 .39355 Mtetra
.798 .812 .863 r
.39983 .39355 .40342 .3965 .40948 .39179 .4059 .38884 Mtetra
.793 .812 .867 r
.4059 .38884 .40948 .39179 .41554 .38723 .41198 .38427 Mtetra
.788 .812 .871 r
.41198 .38427 .41554 .38723 .4216 .3828 .41805 .37983 Mtetra
.783 .812 .876 r
.41805 .37983 .4216 .3828 .42766 .37852 .42412 .37554 Mtetra
.777 .812 .88 r
.42412 .37554 .42766 .37852 .43371 .37438 .43019 .3714 Mtetra
.771 .812 .885 r
.43019 .3714 .43371 .37438 .43978 .37039 .43626 .3674 Mtetra
.765 .811 .89 r
.43626 .3674 .43978 .37039 .44584 .36654 .44234 .36355 Mtetra
.758 .811 .895 r
.44234 .36355 .44584 .36654 .4519 .36285 .44842 .35985 Mtetra
.75 .81 .9 r
.44842 .35985 .4519 .36285 .45798 .35932 .4545 .35631 Mtetra
.743 .809 .905 r
.4545 .35631 .45798 .35932 .46405 .35593 .46059 .35292 Mtetra
.734 .808 .91 r
.46059 .35292 .46405 .35593 .47013 .3527 .46668 .34968 Mtetra
.725 .807 .915 r
.46668 .34968 .47013 .3527 .47622 .34963 .47278 .3466 Mtetra
.716 .805 .92 r
.47278 .3466 .47622 .34963 .48231 .34672 .47888 .34369 Mtetra
.706 .803 .925 r
.47888 .34369 .48231 .34672 .48842 .34397 .485 .34092 Mtetra
.696 .801 .93 r
.485 .34092 .48842 .34397 .49453 .34138 .49112 .33832 Mtetra
.685 .798 .935 r
.49112 .33832 .49453 .34138 .50065 .33894 .49726 .33588 Mtetra
.673 .795 .939 r
.49726 .33588 .50065 .33894 .50679 .33667 .5034 .3336 Mtetra
.661 .791 .944 r
.5034 .3336 .50679 .33667 .51294 .33456 .50956 .33149 Mtetra
.648 .788 .948 r
.50956 .33149 .51294 .33456 .5191 .33261 .51573 .32953 Mtetra
.635 .783 .953 r
.51573 .32953 .5191 .33261 .52527 .33083 .52192 .32773 Mtetra
.621 .779 .956 r
.52192 .32773 .52527 .33083 .53146 .3292 .52812 .3261 Mtetra
.607 .773 .96 r
.52812 .3261 .53146 .3292 .53767 .32774 .53434 .32463 Mtetra
.592 .768 .963 r
.53434 .32463 .53767 .32774 .5439 .32644 .54057 .32332 Mtetra
.576 .762 .966 r
.54057 .32332 .5439 .32644 .55014 .3253 .54683 .32217 Mtetra
.56 .755 .969 r
.54683 .32217 .55014 .3253 .55641 .32432 .5531 .32118 Mtetra
.544 .748 .971 r
.5531 .32118 .55641 .32432 .56269 .3235 .55939 .32035 Mtetra
.527 .741 .973 r
.55939 .32035 .56269 .3235 .569 .32283 .56571 .31967 Mtetra
.509 .733 .974 r
.56571 .31967 .569 .32283 .57533 .32233 .57205 .31916 Mtetra
.491 .724 .975 r
.57205 .31916 .57533 .32233 .58168 .32197 .57841 .3188 Mtetra
.473 .716 .975 r
.57841 .3188 .58168 .32197 .58806 .32178 .5848 .31859 Mtetra
.455 .706 .975 r
.5848 .31859 .58806 .32178 .59446 .32173 .59121 .31853 Mtetra
.437 .697 .975 r
.59121 .31853 .59446 .32173 .60089 .32184 .59765 .31863 Mtetra
.418 .687 .974 r
.59765 .31863 .60089 .32184 .60735 .32209 .60412 .31887 Mtetra
.4 .677 .973 r
.60412 .31887 .60735 .32209 .61384 .32249 .61062 .31926 Mtetra
.382 .667 .971 r
.61062 .31926 .61384 .32249 .62036 .32304 .61714 .31979 Mtetra
.363 .656 .969 r
.61714 .31979 .62036 .32304 .62691 .32372 .6237 .32047 Mtetra
.345 .646 .966 r
.6237 .32047 .62691 .32372 .63349 .32455 .63029 .32128 Mtetra
.328 .635 .963 r
.63029 .32128 .63349 .32455 .6401 .32551 .63691 .32223 Mtetra
.311 .625 .96 r
.63691 .32223 .6401 .32551 .64675 .3266 .64357 .32331 Mtetra
.294 .614 .957 r
.64357 .32331 .64675 .3266 .65343 .32782 .65026 .32452 Mtetra
.278 .604 .953 r
.65026 .32452 .65343 .32782 .66015 .32917 .65698 .32586 Mtetra
.262 .594 .949 r
.65698 .32586 .66015 .32917 .6669 .33064 .66375 .32732 Mtetra
.247 .584 .946 r
.66375 .32732 .6669 .33064 .67369 .33223 .67054 .32889 Mtetra
.233 .575 .942 r
.67054 .32889 .67369 .33223 .68052 .33393 .67738 .33058 Mtetra
.22 .566 .938 r
.67738 .33058 .68052 .33393 .68738 .33574 .68425 .33238 Mtetra
.207 .557 .934 r
.68425 .33238 .68738 .33574 .69429 .33766 .69117 .33428 Mtetra
.196 .549 .931 r
.69117 .33428 .69429 .33766 .70123 .33967 .69812 .33628 Mtetra
.185 .541 .927 r
.69812 .33628 .70123 .33967 .70821 .34178 .70511 .33837 Mtetra
.176 .534 .924 r
.70511 .33837 .70821 .34178 .71524 .34397 .71215 .34055 Mtetra
.167 .528 .921 r
.71215 .34055 .71524 .34397 .72231 .34625 .71922 .34281 Mtetra
.16 .522 .918 r
.71922 .34281 .72231 .34625 .72941 .3486 .72633 .34515 Mtetra
.154 .517 .916 r
.72633 .34515 .72941 .3486 .73656 .35103 .73349 .34756 Mtetra
.148 .513 .914 r
.73349 .34756 .73656 .35103 .74375 .35351 .74069 .35003 Mtetra
.144 .509 .912 r
.74069 .35003 .74375 .35351 .75098 .35605 .74793 .35255 Mtetra
.141 .506 .91 r
.74793 .35255 .75098 .35605 .75826 .35864 .75521 .35513 Mtetra
.14 .504 .909 r
.75521 .35513 .75826 .35864 .76557 .36127 .76254 .35774 Mtetra
.139 .503 .909 r
.76254 .35774 .76557 .36127 .77293 .36393 .7699 .36038 Mtetra
.14 .502 .909 r
.7699 .36038 .77293 .36393 .78033 .36662 .77731 .36305 Mtetra
.141 .502 .909 r
.77731 .36305 .78033 .36662 .78777 .36932 .78476 .36573 Mtetra
.145 .503 .91 r
.78476 .36573 .78777 .36932 .79525 .37202 .79225 .36842 Mtetra
.149 .505 .911 r
.79225 .36842 .79525 .37202 .80277 .37473 .79978 .3711 Mtetra
.154 .508 .912 r
.79978 .3711 .80277 .37473 .81033 .37741 .80735 .37376 Mtetra
.161 .512 .914 r
.80735 .37376 .81033 .37741 .81793 .38007 .81495 .3764 Mtetra
.169 .516 .916 r
.81495 .3764 .81793 .38007 .82556 .3827 .8226 .37901 Mtetra
.179 .521 .918 r
.8226 .37901 .82556 .3827 .83324 .38528 .83028 .38156 Mtetra
.189 .527 .921 r
.83028 .38156 .83324 .38528 .84095 .3878 .838 .38406 Mtetra
.201 .534 .924 r
.838 .38406 .84095 .3878 .84869 .39025 .84575 .38649 Mtetra
.832 .795 .816 r
.19886 .5859 .2029 .58873 .2091 .58244 .20507 .57962 Mtetra
.834 .795 .815 r
.20507 .57962 .2091 .58244 .2153 .57608 .21128 .57327 Mtetra
.836 .796 .813 r
.21128 .57327 .2153 .57608 .22151 .56965 .2175 .56684 Mtetra
.837 .796 .812 r
.2175 .56684 .22151 .56965 .22772 .56316 .22372 .56036 Mtetra
.838 .797 .812 r
.22372 .56036 .22772 .56316 .23392 .55663 .22994 .55383 Mtetra
.839 .798 .811 r
.22994 .55383 .23392 .55663 .24013 .55006 .23617 .54727 Mtetra
.84 .798 .811 r
.23617 .54727 .24013 .55006 .24634 .54347 .24239 .54068 Mtetra
.841 .799 .811 r
.24239 .54068 .24634 .54347 .25255 .53686 .24861 .53408 Mtetra
.841 .8 .811 r
.24861 .53408 .25255 .53686 .25875 .53025 .25482 .52747 Mtetra
.842 .801 .811 r
.25482 .52747 .25875 .53025 .26495 .52364 .26103 .52086 Mtetra
.842 .801 .812 r
.26103 .52086 .26495 .52364 .27114 .51704 .26724 .51427 Mtetra
.842 .802 .812 r
.26724 .51427 .27114 .51704 .27733 .51046 .27345 .50769 Mtetra
.842 .803 .813 r
.27345 .50769 .27733 .51046 .28352 .50391 .27964 .50115 Mtetra
.842 .804 .814 r
.27964 .50115 .28352 .50391 .28969 .4974 .28584 .49464 Mtetra
.841 .805 .815 r
.28584 .49464 .28969 .4974 .29587 .49093 .29202 .48817 Mtetra
.841 .806 .817 r
.29202 .48817 .29587 .49093 .30203 .48451 .2982 .48175 Mtetra
.84 .807 .818 r
.2982 .48175 .30203 .48451 .30819 .47815 .30438 .47539 Mtetra
.839 .808 .82 r
.30438 .47539 .30819 .47815 .31434 .47186 .31054 .46909 Mtetra
.838 .809 .822 r
.31054 .46909 .31434 .47186 .32049 .46563 .3167 .46286 Mtetra
.837 .81 .824 r
.3167 .46286 .32049 .46563 .32663 .45948 .32285 .45671 Mtetra
.835 .811 .827 r
.32285 .45671 .32663 .45948 .33276 .45341 .329 .45065 Mtetra
.833 .811 .829 r
.329 .45065 .33276 .45341 .33888 .44744 .33514 .44467 Mtetra
.832 .812 .832 r
.33514 .44467 .33888 .44744 .345 .44155 .34127 .43878 Mtetra
.83 .813 .834 r
.34127 .43878 .345 .44155 .35112 .43576 .3474 .43299 Mtetra
.827 .814 .837 r
.3474 .43299 .35112 .43576 .35722 .43008 .35352 .4273 Mtetra
.825 .815 .841 r
.35352 .4273 .35722 .43008 .36332 .42451 .35963 .42172 Mtetra
.822 .816 .844 r
.35963 .42172 .36332 .42451 .36942 .41904 .36574 .41626 Mtetra
.819 .817 .847 r
.36574 .41626 .36942 .41904 .37551 .4137 .37185 .41091 Mtetra
.816 .818 .851 r
.37185 .41091 .37551 .4137 .38159 .40847 .37795 .40568 Mtetra
.812 .818 .855 r
.37795 .40568 .38159 .40847 .38768 .40337 .38404 .40057 Mtetra
.809 .819 .859 r
.38404 .40057 .38768 .40337 .39376 .39839 .39013 .39559 Mtetra
.805 .82 .863 r
.39013 .39559 .39376 .39839 .39983 .39355 .39622 .39074 Mtetra
.8 .82 .867 r
.39622 .39074 .39983 .39355 .4059 .38884 .40231 .38603 Mtetra
.796 .821 .872 r
.40231 .38603 .4059 .38884 .41198 .38427 .40839 .38145 Mtetra
.79 .821 .876 r
.40839 .38145 .41198 .38427 .41805 .37983 .41448 .37701 Mtetra
.785 .821 .881 r
.41448 .37701 .41805 .37983 .42412 .37554 .42056 .37272 Mtetra
.779 .821 .886 r
.42056 .37272 .42412 .37554 .43019 .3714 .42665 .36857 Mtetra
.773 .821 .891 r
.42665 .36857 .43019 .3714 .43626 .3674 .43273 .36456 Mtetra
.766 .821 .896 r
.43273 .36456 .43626 .3674 .44234 .36355 .43882 .36071 Mtetra
.759 .821 .901 r
.43882 .36071 .44234 .36355 .44842 .35985 .44491 .357 Mtetra
.752 .82 .906 r
.44491 .357 .44842 .35985 .4545 .35631 .451 .35345 Mtetra
.744 .819 .911 r
.451 .35345 .4545 .35631 .46059 .35292 .4571 .35005 Mtetra
.735 .818 .916 r
.4571 .35005 .46059 .35292 .46668 .34968 .46321 .34681 Mtetra
.726 .817 .921 r
.46321 .34681 .46668 .34968 .47278 .3466 .46932 .34373 Mtetra
.717 .815 .926 r
.46932 .34373 .47278 .3466 .47888 .34369 .47543 .3408 Mtetra
.706 .813 .932 r
.47543 .3408 .47888 .34369 .485 .34092 .48156 .33803 Mtetra
.696 .811 .937 r
.48156 .33803 .485 .34092 .49112 .33832 .4877 .33542 Mtetra
.684 .808 .941 r
.4877 .33542 .49112 .33832 .49726 .33588 .49384 .33297 Mtetra
.672 .805 .946 r
.49384 .33297 .49726 .33588 .5034 .3336 .5 .33068 Mtetra
.66 .802 .951 r
.5 .33068 .5034 .3336 .50956 .33149 .50617 .32856 Mtetra
.646 .798 .955 r
.50617 .32856 .50956 .33149 .51573 .32953 .51235 .32659 Mtetra
.633 .793 .959 r
.51235 .32659 .51573 .32953 .52192 .32773 .51855 .32479 Mtetra
.618 .789 .963 r
.51855 .32479 .52192 .32773 .52812 .3261 .52476 .32315 Mtetra
.603 .783 .967 r
.52476 .32315 .52812 .3261 .53434 .32463 .53099 .32167 Mtetra
.588 .777 .97 r
.53099 .32167 .53434 .32463 .54057 .32332 .53723 .32035 Mtetra
.571 .771 .973 r
.53723 .32035 .54057 .32332 .54683 .32217 .5435 .31919 Mtetra
.555 .764 .976 r
.5435 .31919 .54683 .32217 .5531 .32118 .54978 .31819 Mtetra
.537 .757 .978 r
.54978 .31819 .5531 .32118 .55939 .32035 .55608 .31735 Mtetra
.52 .749 .979 r
.55608 .31735 .55939 .32035 .56571 .31967 .56241 .31666 Mtetra
.502 .741 .98 r
.56241 .31666 .56571 .31967 .57205 .31916 .56876 .31614 Mtetra
.483 .732 .981 r
.56876 .31614 .57205 .31916 .57841 .3188 .57513 .31576 Mtetra
.465 .723 .981 r
.57513 .31576 .57841 .3188 .5848 .31859 .58153 .31555 Mtetra
.446 .713 .981 r
.58153 .31555 .5848 .31859 .59121 .31853 .58795 .31548 Mtetra
.427 .703 .98 r
.58795 .31548 .59121 .31853 .59765 .31863 .5944 .31556 Mtetra
.408 .693 .978 r
.5944 .31556 .59765 .31863 .60412 .31887 .60088 .31579 Mtetra
.388 .682 .977 r
.60088 .31579 .60412 .31887 .61062 .31926 .60738 .31617 Mtetra
.37 .672 .974 r
.60738 .31617 .61062 .31926 .61714 .31979 .61392 .31669 Mtetra
.351 .661 .972 r
.61392 .31669 .61714 .31979 .6237 .32047 .62049 .31736 Mtetra
.332 .65 .969 r
.62049 .31736 .6237 .32047 .63029 .32128 .62708 .31816 Mtetra
.314 .639 .965 r
.62708 .31816 .63029 .32128 .63691 .32223 .63372 .31909 Mtetra
.297 .628 .962 r
.63372 .31909 .63691 .32223 .64357 .32331 .64038 .32016 Mtetra
.28 .617 .958 r
.64038 .32016 .64357 .32331 .65026 .32452 .64708 .32136 Mtetra
.263 .606 .954 r
.64708 .32136 .65026 .32452 .65698 .32586 .65381 .32268 Mtetra
.247 .596 .95 r
.65381 .32268 .65698 .32586 .66375 .32732 .66058 .32413 Mtetra
.232 .586 .946 r
.66058 .32413 .66375 .32732 .67054 .32889 .66739 .32569 Mtetra
.218 .576 .942 r
.66739 .32569 .67054 .32889 .67738 .33058 .67424 .32736 Mtetra
.205 .566 .938 r
.67424 .32736 .67738 .33058 .68425 .33238 .68112 .32914 Mtetra
.192 .558 .934 r
.68112 .32914 .68425 .33238 .69117 .33428 .68804 .33103 Mtetra
.181 .549 .93 r
.68804 .33103 .69117 .33428 .69812 .33628 .695 .33301 Mtetra
.17 .541 .926 r
.695 .33301 .69812 .33628 .70511 .33837 .702 .33509 Mtetra
.161 .534 .923 r
.702 .33509 .70511 .33837 .71215 .34055 .70904 .33725 Mtetra
.152 .528 .92 r
.70904 .33725 .71215 .34055 .71922 .34281 .71613 .3395 Mtetra
.145 .522 .917 r
.71613 .3395 .71922 .34281 .72633 .34515 .72325 .34182 Mtetra
.139 .517 .914 r
.72325 .34182 .72633 .34515 .73349 .34756 .73042 .34421 Mtetra
.134 .512 .912 r
.73042 .34421 .73349 .34756 .74069 .35003 .73762 .34666 Mtetra
.13 .508 .91 r
.73762 .34666 .74069 .35003 .74793 .35255 .74487 .34917 Mtetra
.128 .506 .909 r
.74487 .34917 .74793 .35255 .75521 .35513 .75216 .35172 Mtetra
.126 .504 .908 r
.75216 .35172 .75521 .35513 .76254 .35774 .7595 .35431 Mtetra
.126 .502 .908 r
.7595 .35431 .76254 .35774 .7699 .36038 .76687 .35694 Mtetra
.127 .502 .908 r
.76687 .35694 .7699 .36038 .77731 .36305 .77429 .35958 Mtetra
.13 .502 .908 r
.77429 .35958 .77731 .36305 .78476 .36573 .78174 .36224 Mtetra
.133 .503 .909 r
.78174 .36224 .78476 .36573 .79225 .36842 .78924 .3649 Mtetra
.138 .506 .91 r
.78924 .3649 .79225 .36842 .79978 .3711 .79678 .36756 Mtetra
.144 .508 .912 r
.79678 .36756 .79978 .3711 .80735 .37376 .80436 .3702 Mtetra
.152 .512 .914 r
.80436 .3702 .80735 .37376 .81495 .3764 .81197 .37282 Mtetra
.16 .517 .916 r
.81197 .37282 .81495 .3764 .8226 .37901 .81963 .3754 Mtetra
.17 .522 .919 r
.81963 .3754 .8226 .37901 .83028 .38156 .82732 .37793 Mtetra
.181 .528 .922 r
.82732 .37793 .83028 .38156 .838 .38406 .83504 .3804 Mtetra
.194 .535 .925 r
.83504 .3804 .838 .38406 .84575 .38649 .84281 .3828 Mtetra
.833 .799 .818 r
.19479 .58315 .19886 .5859 .20507 .57962 .20101 .57688 Mtetra
.835 .799 .817 r
.20101 .57688 .20507 .57962 .21128 .57327 .20724 .57053 Mtetra
.837 .8 .816 r
.20724 .57053 .21128 .57327 .2175 .56684 .21347 .56412 Mtetra
.838 .801 .815 r
.21347 .56412 .2175 .56684 .22372 .56036 .2197 .55765 Mtetra
.84 .802 .814 r
.2197 .55765 .22372 .56036 .22994 .55383 .22594 .55113 Mtetra
.841 .802 .813 r
.22594 .55113 .22994 .55383 .23617 .54727 .23217 .54458 Mtetra
.842 .803 .813 r
.23217 .54458 .23617 .54727 .24239 .54068 .23841 .538 Mtetra
.843 .804 .813 r
.23841 .538 .24239 .54068 .24861 .53408 .24464 .5314 Mtetra
.843 .805 .813 r
.24464 .5314 .24861 .53408 .25482 .52747 .25087 .5248 Mtetra
.844 .806 .814 r
.25087 .5248 .25482 .52747 .26103 .52086 .25709 .5182 Mtetra
.844 .807 .814 r
.25709 .5182 .26103 .52086 .26724 .51427 .26332 .51161 Mtetra
.844 .808 .815 r
.26332 .51161 .26724 .51427 .27345 .50769 .26953 .50503 Mtetra
.844 .809 .816 r
.26953 .50503 .27345 .50769 .27964 .50115 .27575 .49849 Mtetra
.844 .81 .817 r
.27575 .49849 .27964 .50115 .28584 .49464 .28195 .49198 Mtetra
.843 .811 .818 r
.28195 .49198 .28584 .49464 .29202 .48817 .28815 .48552 Mtetra
.843 .812 .82 r
.28815 .48552 .29202 .48817 .2982 .48175 .29435 .4791 Mtetra
.842 .813 .821 r
.29435 .4791 .2982 .48175 .30438 .47539 .30054 .47274 Mtetra
.841 .814 .823 r
.30054 .47274 .30438 .47539 .31054 .46909 .30672 .46645 Mtetra
.84 .815 .825 r
.30672 .46645 .31054 .46909 .3167 .46286 .31289 .46022 Mtetra
.839 .816 .827 r
.31289 .46022 .3167 .46286 .32285 .45671 .31906 .45407 Mtetra
.838 .817 .83 r
.31906 .45407 .32285 .45671 .329 .45065 .32522 .448 Mtetra
.836 .818 .832 r
.32522 .448 .329 .45065 .33514 .44467 .33137 .44202 Mtetra
.834 .82 .835 r
.33137 .44202 .33514 .44467 .34127 .43878 .33752 .43614 Mtetra
.832 .821 .838 r
.33752 .43614 .34127 .43878 .3474 .43299 .34366 .43035 Mtetra
.83 .822 .841 r
.34366 .43035 .3474 .43299 .35352 .4273 .34979 .42466 Mtetra
.827 .823 .844 r
.34979 .42466 .35352 .4273 .35963 .42172 .35592 .41908 Mtetra
.825 .824 .848 r
.35592 .41908 .35963 .42172 .36574 .41626 .36204 .41361 Mtetra
.822 .825 .851 r
.36204 .41361 .36574 .41626 .37185 .41091 .36816 .40826 Mtetra
.818 .826 .855 r
.36816 .40826 .37185 .41091 .37795 .40568 .37427 .40302 Mtetra
.815 .827 .859 r
.37427 .40302 .37795 .40568 .38404 .40057 .38038 .39791 Mtetra
.811 .828 .863 r
.38038 .39791 .38404 .40057 .39013 .39559 .38649 .39293 Mtetra
.807 .829 .867 r
.38649 .39293 .39013 .39559 .39622 .39074 .39259 .38808 Mtetra
.803 .829 .872 r
.39259 .38808 .39622 .39074 .40231 .38603 .39869 .38336 Mtetra
.798 .83 .876 r
.39869 .38336 .40231 .38603 .40839 .38145 .40479 .37878 Mtetra
.793 .83 .881 r
.40479 .37878 .40839 .38145 .41448 .37701 .41088 .37434 Mtetra
.787 .831 .886 r
.41088 .37434 .41448 .37701 .42056 .37272 .41698 .37003 Mtetra
.781 .831 .891 r
.41698 .37003 .42056 .37272 .42665 .36857 .42308 .36588 Mtetra
.775 .831 .896 r
.42308 .36588 .42665 .36857 .43273 .36456 .42918 .36187 Mtetra
.768 .831 .901 r
.42918 .36187 .43273 .36456 .43882 .36071 .43528 .35801 Mtetra
.761 .831 .906 r
.43528 .35801 .43882 .36071 .44491 .357 .44138 .3543 Mtetra
.753 .83 .911 r
.44138 .3543 .44491 .357 .451 .35345 .44749 .35074 Mtetra
.745 .83 .917 r
.44749 .35074 .451 .35345 .4571 .35005 .4536 .34734 Mtetra
.736 .829 .922 r
.4536 .34734 .4571 .35005 .46321 .34681 .45971 .34409 Mtetra
.727 .827 .927 r
.45971 .34409 .46321 .34681 .46932 .34373 .46584 .34099 Mtetra
.717 .826 .933 r
.46584 .34099 .46932 .34373 .47543 .3408 .47197 .33806 Mtetra
.706 .824 .938 r
.47197 .33806 .47543 .3408 .48156 .33803 .4781 .33528 Mtetra
.695 .821 .943 r
.4781 .33528 .48156 .33803 .4877 .33542 .48425 .33267 Mtetra
.683 .819 .948 r
.48425 .33267 .4877 .33542 .49384 .33297 .49041 .33021 Mtetra
.671 .816 .953 r
.49041 .33021 .49384 .33297 .5 .33068 .49658 .32792 Mtetra
.658 .812 .958 r
.49658 .32792 .5 .33068 .50617 .32856 .50276 .32578 Mtetra
.644 .808 .962 r
.50276 .32578 .50617 .32856 .51235 .32659 .50895 .32381 Mtetra
.63 .804 .966 r
.50895 .32381 .51235 .32659 .51855 .32479 .51516 .322 Mtetra
.615 .799 .97 r
.51516 .322 .51855 .32479 .52476 .32315 .52138 .32034 Mtetra
.599 .793 .973 r
.52138 .32034 .52476 .32315 .53099 .32167 .52762 .31885 Mtetra
.583 .787 .977 r
.52762 .31885 .53099 .32167 .53723 .32035 .53387 .31752 Mtetra
.566 .78 .979 r
.53387 .31752 .53723 .32035 .5435 .31919 .54015 .31636 Mtetra
.548 .773 .982 r
.54015 .31636 .5435 .31919 .54978 .31819 .54644 .31535 Mtetra
.531 .766 .983 r
.54644 .31535 .54978 .31819 .55608 .31735 .55276 .31449 Mtetra
.512 .757 .985 r
.55276 .31449 .55608 .31735 .56241 .31666 .55909 .3138 Mtetra
.493 .749 .986 r
.55909 .3138 .56241 .31666 .56876 .31614 .56545 .31326 Mtetra
.474 .739 .986 r
.56545 .31326 .56876 .31614 .57513 .31576 .57184 .31288 Mtetra
.455 .73 .986 r
.57184 .31288 .57513 .31576 .58153 .31555 .57824 .31265 Mtetra
.435 .72 .985 r
.57824 .31265 .58153 .31555 .58795 .31548 .58467 .31257 Mtetra
.416 .709 .984 r
.58467 .31257 .58795 .31548 .5944 .31556 .59113 .31264 Mtetra
.396 .698 .982 r
.59113 .31264 .5944 .31556 .60088 .31579 .59762 .31286 Mtetra
.376 .687 .98 r
.59762 .31286 .60088 .31579 .60738 .31617 .60414 .31323 Mtetra
.357 .676 .977 r
.60414 .31323 .60738 .31617 .61392 .31669 .61068 .31374 Mtetra
.338 .665 .974 r
.61068 .31374 .61392 .31669 .62049 .31736 .61726 .31439 Mtetra
.319 .653 .97 r
.61726 .31439 .62049 .31736 .62708 .31816 .62387 .31517 Mtetra
.3 .642 .967 r
.62387 .31517 .62708 .31816 .63372 .31909 .63051 .3161 Mtetra
.282 .63 .963 r
.63051 .3161 .63372 .31909 .64038 .32016 .63718 .31715 Mtetra
.265 .619 .958 r
.63718 .31715 .64038 .32016 .64708 .32136 .64389 .31833 Mtetra
.248 .608 .954 r
.64389 .31833 .64708 .32136 .65381 .32268 .65063 .31964 Mtetra
.232 .597 .95 r
.65063 .31964 .65381 .32268 .66058 .32413 .65741 .32107 Mtetra
.217 .586 .945 r
.65741 .32107 .66058 .32413 .66739 .32569 .66423 .32261 Mtetra
.202 .576 .941 r
.66423 .32261 .66739 .32569 .67424 .32736 .67108 .32427 Mtetra
.189 .567 .936 r
.67108 .32427 .67424 .32736 .68112 .32914 .67797 .32604 Mtetra
.177 .558 .932 r
.67797 .32604 .68112 .32914 .68804 .33103 .6849 .3279 Mtetra
.165 .549 .928 r
.6849 .3279 .68804 .33103 .695 .33301 .69187 .32987 Mtetra
.155 .541 .924 r
.69187 .32987 .695 .33301 .702 .33509 .69888 .33193 Mtetra
.146 .534 .921 r
.69888 .33193 .702 .33509 .70904 .33725 .70594 .33408 Mtetra
.137 .527 .918 r
.70594 .33408 .70904 .33725 .71613 .3395 .71303 .3363 Mtetra
.13 .521 .915 r
.71303 .3363 .71613 .3395 .72325 .34182 .72016 .3386 Mtetra
.125 .516 .912 r
.72016 .3386 .72325 .34182 .73042 .34421 .72733 .34097 Mtetra
.12 .511 .91 r
.72733 .34097 .73042 .34421 .73762 .34666 .73455 .3434 Mtetra
.117 .508 .908 r
.73455 .3434 .73762 .34666 .74487 .34917 .74181 .34589 Mtetra
.114 .505 .907 r
.74181 .34589 .74487 .34917 .75216 .35172 .74911 .34842 Mtetra
.113 .503 .906 r
.74911 .34842 .75216 .35172 .7595 .35431 .75645 .35099 Mtetra
.114 .502 .906 r
.75645 .35099 .7595 .35431 .76687 .35694 .76383 .35359 Mtetra
.115 .502 .906 r
.76383 .35359 .76687 .35694 .77429 .35958 .77126 .35621 Mtetra
.118 .502 .907 r
.77126 .35621 .77429 .35958 .78174 .36224 .77872 .35885 Mtetra
.122 .504 .908 r
.77872 .35885 .78174 .36224 .78924 .3649 .78623 .36149 Mtetra
.128 .506 .909 r
.78623 .36149 .78924 .3649 .79678 .36756 .79378 .36412 Mtetra
.134 .509 .911 r
.79378 .36412 .79678 .36756 .80436 .3702 .80136 .36674 Mtetra
.142 .513 .913 r
.80136 .36674 .80436 .3702 .81197 .37282 .80899 .36933 Mtetra
.151 .518 .916 r
.80899 .36933 .81197 .37282 .81963 .3754 .81665 .37188 Mtetra
.162 .523 .919 r
.81665 .37188 .81963 .3754 .82732 .37793 .82435 .37438 Mtetra
.174 .53 .922 r
.82435 .37438 .82732 .37793 .83504 .3804 .83209 .37682 Mtetra
.187 .537 .925 r
.83209 .37682 .83504 .3804 .84281 .3828 .83986 .37919 Mtetra
.834 .803 .821 r
.19069 .58047 .19479 .58315 .20101 .57688 .19692 .57421 Mtetra
.836 .803 .819 r
.19692 .57421 .20101 .57688 .20724 .57053 .20316 .56788 Mtetra
.838 .804 .818 r
.20316 .56788 .20724 .57053 .21347 .56412 .2094 .56148 Mtetra
.84 .805 .817 r
.2094 .56148 .21347 .56412 .2197 .55765 .21565 .55502 Mtetra
.841 .806 .816 r
.21565 .55502 .2197 .55765 .22594 .55113 .2219 .54851 Mtetra
.842 .807 .816 r
.2219 .54851 .22594 .55113 .23217 .54458 .22815 .54197 Mtetra
.844 .808 .816 r
.22815 .54197 .23217 .54458 .23841 .538 .2344 .5354 Mtetra
.844 .809 .816 r
.2344 .5354 .23841 .538 .24464 .5314 .24064 .52882 Mtetra
.845 .81 .816 r
.24064 .52882 .24464 .5314 .25087 .5248 .24689 .52222 Mtetra
.846 .811 .816 r
.24689 .52222 .25087 .5248 .25709 .5182 .25313 .51563 Mtetra
.846 .812 .817 r
.25313 .51563 .25709 .5182 .26332 .51161 .25936 .50905 Mtetra
.846 .813 .818 r
.25936 .50905 .26332 .51161 .26953 .50503 .26559 .50248 Mtetra
.846 .814 .819 r
.26559 .50248 .26953 .50503 .27575 .49849 .27182 .49595 Mtetra
.846 .816 .82 r
.27182 .49595 .27575 .49849 .28195 .49198 .27804 .48944 Mtetra
.846 .817 .821 r
.27804 .48944 .28195 .49198 .28815 .48552 .28426 .48298 Mtetra
.845 .818 .823 r
.28426 .48298 .28815 .48552 .29435 .4791 .29047 .47657 Mtetra
.844 .819 .824 r
.29047 .47657 .29435 .4791 .30054 .47274 .29667 .47022 Mtetra
.844 .82 .826 r
.29667 .47022 .30054 .47274 .30672 .46645 .30286 .46392 Mtetra
.842 .822 .828 r
.30286 .46392 .30672 .46645 .31289 .46022 .30905 .4577 Mtetra
.841 .823 .831 r
.30905 .4577 .31289 .46022 .31906 .45407 .31523 .45155 Mtetra
.84 .824 .833 r
.31523 .45155 .31906 .45407 .32522 .448 .32141 .44549 Mtetra
.838 .826 .836 r
.32141 .44549 .32522 .448 .33137 .44202 .32757 .43951 Mtetra
.836 .827 .838 r
.32757 .43951 .33137 .44202 .33752 .43614 .33373 .43362 Mtetra
.834 .828 .841 r
.33373 .43362 .33752 .43614 .34366 .43035 .33989 .42783 Mtetra
.832 .829 .845 r
.33989 .42783 .34366 .43035 .34979 .42466 .34604 .42214 Mtetra
.83 .831 .848 r
.34604 .42214 .34979 .42466 .35592 .41908 .35218 .41656 Mtetra
.827 .832 .852 r
.35218 .41656 .35592 .41908 .36204 .41361 .35832 .41109 Mtetra
.824 .833 .855 r
.35832 .41109 .36204 .41361 .36816 .40826 .36445 .40574 Mtetra
.821 .834 .859 r
.36445 .40574 .36816 .40826 .37427 .40302 .37058 .4005 Mtetra
.817 .835 .863 r
.37058 .4005 .37427 .40302 .38038 .39791 .3767 .39539 Mtetra
.813 .836 .867 r
.3767 .39539 .38038 .39791 .38649 .39293 .38282 .39041 Mtetra
.809 .837 .872 r
.38282 .39041 .38649 .39293 .39259 .38808 .38893 .38555 Mtetra
.805 .838 .876 r
.38893 .38555 .39259 .38808 .39869 .38336 .39505 .38083 Mtetra
.8 .839 .881 r
.39505 .38083 .39869 .38336 .40479 .37878 .40116 .37625 Mtetra
.794 .84 .886 r
.40116 .37625 .40479 .37878 .41088 .37434 .40727 .3718 Mtetra
.789 .84 .891 r
.40727 .3718 .41088 .37434 .41698 .37003 .41338 .3675 Mtetra
.783 .841 .896 r
.41338 .3675 .41698 .37003 .42308 .36588 .41949 .36334 Mtetra
.776 .841 .901 r
.41949 .36334 .42308 .36588 .42918 .36187 .4256 .35932 Mtetra
.769 .841 .906 r
.4256 .35932 .42918 .36187 .43528 .35801 .43171 .35545 Mtetra
.762 .841 .912 r
.43171 .35545 .43528 .35801 .44138 .3543 .43783 .35174 Mtetra
.754 .84 .917 r
.43783 .35174 .44138 .3543 .44749 .35074 .44395 .34818 Mtetra
.745 .84 .922 r
.44395 .34818 .44749 .35074 .4536 .34734 .45007 .34477 Mtetra
.736 .839 .928 r
.45007 .34477 .4536 .34734 .45971 .34409 .4562 .34151 Mtetra
.727 .838 .933 r
.4562 .34151 .45971 .34409 .46584 .34099 .46233 .33841 Mtetra
.716 .836 .939 r
.46233 .33841 .46584 .34099 .47197 .33806 .46848 .33547 Mtetra
.705 .834 .944 r
.46848 .33547 .47197 .33806 .4781 .33528 .47463 .33269 Mtetra
.694 .832 .949 r
.47463 .33269 .4781 .33528 .48425 .33267 .48079 .33006 Mtetra
.682 .829 .954 r
.48079 .33006 .48425 .33267 .49041 .33021 .48695 .3276 Mtetra
.669 .826 .959 r
.48695 .3276 .49041 .33021 .49658 .32792 .49313 .3253 Mtetra
.655 .822 .964 r
.49313 .3253 .49658 .32792 .50276 .32578 .49933 .32315 Mtetra
.641 .818 .968 r
.49933 .32315 .50276 .32578 .50895 .32381 .50553 .32117 Mtetra
.626 .814 .972 r
.50553 .32117 .50895 .32381 .51516 .322 .51175 .31935 Mtetra
.61 .808 .976 r
.51175 .31935 .51516 .322 .52138 .32034 .51798 .31769 Mtetra
.594 .803 .979 r
.51798 .31769 .52138 .32034 .52762 .31885 .52423 .31619 Mtetra
.577 .796 .982 r
.52423 .31619 .52762 .31885 .53387 .31752 .5305 .31485 Mtetra
.56 .789 .985 r
.5305 .31485 .53387 .31752 .54015 .31636 .53679 .31367 Mtetra
.542 .782 .987 r
.53679 .31367 .54015 .31636 .54644 .31535 .54309 .31265 Mtetra
.523 .774 .989 r
.54309 .31265 .54644 .31535 .55276 .31449 .54942 .31179 Mtetra
.504 .765 .99 r
.54942 .31179 .55276 .31449 .55909 .3138 .55576 .31108 Mtetra
.484 .756 .99 r
.55576 .31108 .55909 .3138 .56545 .31326 .56213 .31053 Mtetra
.465 .746 .99 r
.56213 .31053 .56545 .31326 .57184 .31288 .56853 .31014 Mtetra
.445 .736 .989 r
.56853 .31014 .57184 .31288 .57824 .31265 .57494 .3099 Mtetra
.424 .725 .988 r
.57494 .3099 .57824 .31265 .58467 .31257 .58139 .30981 Mtetra
.404 .714 .987 r
.58139 .30981 .58467 .31257 .59113 .31264 .58786 .30987 Mtetra
.384 .703 .984 r
.58786 .30987 .59113 .31264 .59762 .31286 .59435 .31007 Mtetra
.363 .692 .982 r
.59435 .31007 .59762 .31286 .60414 .31323 .60088 .31042 Mtetra
.343 .68 .978 r
.60088 .31042 .60414 .31323 .61068 .31374 .60743 .31092 Mtetra
.324 .668 .975 r
.60743 .31092 .61068 .31374 .61726 .31439 .61402 .31155 Mtetra
.304 .656 .971 r
.61402 .31155 .61726 .31439 .62387 .31517 .62064 .31233 Mtetra
.285 .644 .967 r
.62064 .31233 .62387 .31517 .63051 .3161 .62729 .31323 Mtetra
.267 .632 .962 r
.62729 .31323 .63051 .3161 .63718 .31715 .63397 .31427 Mtetra
.249 .62 .958 r
.63397 .31427 .63718 .31715 .64389 .31833 .64069 .31544 Mtetra
.232 .609 .953 r
.64069 .31544 .64389 .31833 .65063 .31964 .64744 .31673 Mtetra
.216 .598 .948 r
.64744 .31673 .65063 .31964 .65741 .32107 .65423 .31814 Mtetra
.201 .587 .944 r
.65423 .31814 .65741 .32107 .66423 .32261 .66106 .31967 Mtetra
.187 .576 .939 r
.66106 .31967 .66423 .32261 .67108 .32427 .66792 .32131 Mtetra
.173 .566 .934 r
.66792 .32131 .67108 .32427 .67797 .32604 .67482 .32306 Mtetra
.161 .557 .93 r
.67482 .32306 .67797 .32604 .6849 .3279 .68176 .32491 Mtetra
.15 .548 .926 r
.68176 .32491 .6849 .3279 .69187 .32987 .68874 .32686 Mtetra
.139 .54 .922 r
.68874 .32686 .69187 .32987 .69888 .33193 .69576 .32889 Mtetra
.13 .533 .918 r
.69576 .32889 .69888 .33193 .70594 .33408 .70282 .33102 Mtetra
.122 .526 .915 r
.70282 .33102 .70594 .33408 .71303 .3363 .70992 .33323 Mtetra
.116 .52 .912 r
.70992 .33323 .71303 .3363 .72016 .3386 .71706 .33551 Mtetra
.11 .515 .91 r
.71706 .33551 .72016 .3386 .72733 .34097 .72424 .33785 Mtetra
.106 .511 .907 r
.72424 .33785 .72733 .34097 .73455 .3434 .73147 .34026 Mtetra
.103 .507 .906 r
.73147 .34026 .73455 .3434 .74181 .34589 .73874 .34272 Mtetra
.101 .504 .905 r
.73874 .34272 .74181 .34589 .74911 .34842 .74604 .34523 Mtetra
.101 .503 .904 r
.74604 .34523 .74911 .34842 .75645 .35099 .75339 .34778 Mtetra
.101 .502 .904 r
.75339 .34778 .75645 .35099 .76383 .35359 .76079 .35035 Mtetra
.103 .501 .904 r
.76079 .35035 .76383 .35359 .77126 .35621 .76822 .35295 Mtetra
.107 .502 .905 r
.76822 .35295 .77126 .35621 .77872 .35885 .7757 .35556 Mtetra
.111 .504 .906 r
.7757 .35556 .77872 .35885 .78623 .36149 .78321 .35817 Mtetra
.117 .506 .908 r
.78321 .35817 .78623 .36149 .79378 .36412 .79077 .36077 Mtetra
.125 .51 .91 r
.79077 .36077 .79378 .36412 .80136 .36674 .79836 .36336 Mtetra
.133 .514 .913 r
.79836 .36336 .80136 .36674 .80899 .36933 .806 .36592 Mtetra
.143 .519 .916 r
.806 .36592 .80899 .36933 .81665 .37188 .81367 .36844 Mtetra
.154 .525 .919 r
.81367 .36844 .81665 .37188 .82435 .37438 .82138 .37091 Mtetra
.167 .532 .922 r
.82138 .37091 .82435 .37438 .83209 .37682 .82912 .37331 Mtetra
.181 .539 .926 r
.82912 .37331 .83209 .37682 .83986 .37919 .8369 .37565 Mtetra
.835 .806 .823 r
.18656 .57785 .19069 .58047 .19692 .57421 .19281 .57162 Mtetra
.837 .807 .822 r
.19281 .57162 .19692 .57421 .20316 .56788 .19906 .56531 Mtetra
.839 .808 .821 r
.19906 .56531 .20316 .56788 .2094 .56148 .20532 .55892 Mtetra
.841 .809 .82 r
.20532 .55892 .2094 .56148 .21565 .55502 .21158 .55248 Mtetra
.843 .811 .819 r
.21158 .55248 .21565 .55502 .2219 .54851 .21784 .54599 Mtetra
.844 .812 .818 r
.21784 .54599 .2219 .54851 .22815 .54197 .2241 .53946 Mtetra
.845 .813 .818 r
.2241 .53946 .22815 .54197 .2344 .5354 .23036 .5329 Mtetra
.846 .814 .818 r
.23036 .5329 .2344 .5354 .24064 .52882 .23662 .52633 Mtetra
.847 .815 .818 r
.23662 .52633 .24064 .52882 .24689 .52222 .24288 .51975 Mtetra
.847 .816 .819 r
.24288 .51975 .24689 .52222 .25313 .51563 .24913 .51316 Mtetra
.848 .817 .819 r
.24913 .51316 .25313 .51563 .25936 .50905 .25538 .50659 Mtetra
.848 .819 .82 r
.25538 .50659 .25936 .50905 .26559 .50248 .26163 .50004 Mtetra
.848 .82 .821 r
.26163 .50004 .26559 .50248 .27182 .49595 .26787 .49351 Mtetra
.848 .821 .822 r
.26787 .49351 .27182 .49595 .27804 .48944 .2741 .48701 Mtetra
.848 .823 .824 r
.2741 .48701 .27804 .48944 .28426 .48298 .28033 .48056 Mtetra
.847 .824 .825 r
.28033 .48056 .28426 .48298 .29047 .47657 .28655 .47416 Mtetra
.846 .825 .827 r
.28655 .47416 .29047 .47657 .29667 .47022 .29277 .46781 Mtetra
.846 .827 .829 r
.29277 .46781 .29667 .47022 .30286 .46392 .29898 .46152 Mtetra
.845 .828 .831 r
.29898 .46152 .30286 .46392 .30905 .4577 .30518 .4553 Mtetra
.843 .83 .834 r
.30518 .4553 .30905 .4577 .31523 .45155 .31138 .44916 Mtetra
.842 .831 .836 r
.31138 .44916 .31523 .45155 .32141 .44549 .31757 .4431 Mtetra
.84 .833 .839 r
.31757 .4431 .32141 .44549 .32757 .43951 .32375 .43712 Mtetra
.839 .834 .842 r
.32375 .43712 .32757 .43951 .33373 .43362 .32993 .43124 Mtetra
.837 .835 .845 r
.32993 .43124 .33373 .43362 .33989 .42783 .33609 .42545 Mtetra
.834 .837 .848 r
.33609 .42545 .33989 .42783 .34604 .42214 .34226 .41976 Mtetra
.832 .838 .852 r
.34226 .41976 .34604 .42214 .35218 .41656 .34841 .41418 Mtetra
.829 .84 .855 r
.34841 .41418 .35218 .41656 .35832 .41109 .35457 .40871 Mtetra
.826 .841 .859 r
.35457 .40871 .35832 .41109 .36445 .40574 .36071 .40336 Mtetra
.823 .842 .863 r
.36071 .40336 .36445 .40574 .37058 .4005 .36685 .39812 Mtetra
.819 .844 .867 r
.36685 .39812 .37058 .4005 .3767 .39539 .37299 .39301 Mtetra
.815 .845 .872 r
.37299 .39301 .3767 .39539 .38282 .39041 .37912 .38803 Mtetra
.811 .846 .876 r
.37912 .38803 .38282 .39041 .38893 .38555 .38525 .38317 Mtetra
.806 .847 .881 r
.38525 .38317 .38893 .38555 .39505 .38083 .39138 .37844 Mtetra
.801 .848 .886 r
.39138 .37844 .39505 .38083 .40116 .37625 .39751 .37386 Mtetra
.796 .849 .89 r
.39751 .37386 .40116 .37625 .40727 .3718 .40363 .36941 Mtetra
.79 .85 .896 r
.40363 .36941 .40727 .3718 .41338 .3675 .40975 .3651 Mtetra
.784 .85 .901 r
.40975 .3651 .41338 .3675 .41949 .36334 .41588 .36094 Mtetra
.777 .851 .906 r
.41588 .36094 .41949 .36334 .4256 .35932 .422 .35692 Mtetra
.77 .851 .911 r
.422 .35692 .4256 .35932 .43171 .35545 .42813 .35305 Mtetra
.763 .851 .917 r
.42813 .35305 .43171 .35545 .43783 .35174 .43426 .34933 Mtetra
.754 .851 .922 r
.43426 .34933 .43783 .35174 .44395 .34818 .44039 .34576 Mtetra
.746 .85 .928 r
.44039 .34576 .44395 .34818 .45007 .34477 .44652 .34234 Mtetra
.736 .849 .933 r
.44652 .34234 .45007 .34477 .4562 .34151 .45267 .33908 Mtetra
.726 .848 .939 r
.45267 .33908 .4562 .34151 .46233 .33841 .45881 .33597 Mtetra
.716 .847 .944 r
.45881 .33597 .46233 .33841 .46848 .33547 .46497 .33303 Mtetra
.704 .845 .95 r
.46497 .33303 .46848 .33547 .47463 .33269 .47113 .33024 Mtetra
.692 .842 .955 r
.47113 .33024 .47463 .33269 .48079 .33006 .4773 .32761 Mtetra
.68 .84 .96 r
.4773 .32761 .48079 .33006 .48695 .3276 .48348 .32513 Mtetra
.666 .836 .965 r
.48348 .32513 .48695 .3276 .49313 .3253 .48967 .32282 Mtetra
.652 .833 .97 r
.48967 .32282 .49313 .3253 .49933 .32315 .49588 .32067 Mtetra
.637 .828 .974 r
.49588 .32067 .49933 .32315 .50553 .32117 .5021 .31868 Mtetra
.622 .823 .978 r
.5021 .31868 .50553 .32117 .51175 .31935 .50833 .31685 Mtetra
.606 .818 .982 r
.50833 .31685 .51175 .31935 .51798 .31769 .51457 .31518 Mtetra
.589 .812 .985 r
.51457 .31518 .51798 .31769 .52423 .31619 .52083 .31367 Mtetra
.571 .805 .988 r
.52083 .31367 .52423 .31619 .5305 .31485 .52711 .31232 Mtetra
.553 .798 .99 r
.52711 .31232 .5305 .31485 .53679 .31367 .53341 .31113 Mtetra
.534 .79 .992 r
.53341 .31113 .53679 .31367 .54309 .31265 .53973 .3101 Mtetra
.515 .782 .993 r
.53973 .3101 .54309 .31265 .54942 .31179 .54606 .30923 Mtetra
.495 .773 .994 r
.54606 .30923 .54942 .31179 .55576 .31108 .55242 .30851 Mtetra
.475 .763 .994 r
.55242 .30851 .55576 .31108 .56213 .31053 .5588 .30795 Mtetra
.454 .753 .993 r
.5588 .30795 .56213 .31053 .56853 .31014 .5652 .30754 Mtetra
.433 .742 .992 r
.5652 .30754 .56853 .31014 .57494 .3099 .57163 .30729 Mtetra
.412 .731 .991 r
.57163 .30729 .57494 .3099 .58139 .30981 .57808 .30718 Mtetra
.391 .719 .988 r
.57808 .30718 .58139 .30981 .58786 .30987 .58456 .30723 Mtetra
.371 .707 .986 r
.58456 .30723 .58786 .30987 .59435 .31007 .59107 .30742 Mtetra
.35 .695 .982 r
.59107 .30742 .59435 .31007 .60088 .31042 .59761 .30776 Mtetra
.329 .683 .979 r
.59761 .30776 .60088 .31042 .60743 .31092 .60417 .30824 Mtetra
.309 .671 .975 r
.60417 .30824 .60743 .31092 .61402 .31155 .61077 .30886 Mtetra
.289 .658 .971 r
.61077 .30886 .61402 .31155 .62064 .31233 .6174 .30962 Mtetra
.27 .646 .966 r
.6174 .30962 .62064 .31233 .62729 .31323 .62406 .31051 Mtetra
.251 .633 .961 r
.62406 .31051 .62729 .31323 .63397 .31427 .63075 .31153 Mtetra
.234 .621 .956 r
.63075 .31153 .63397 .31427 .64069 .31544 .63748 .31268 Mtetra
.216 .609 .951 r
.63748 .31268 .64069 .31544 .64744 .31673 .64424 .31396 Mtetra
.2 .598 .946 r
.64424 .31396 .64744 .31673 .65423 .31814 .65104 .31535 Mtetra
.185 .587 .941 r
.65104 .31535 .65423 .31814 .66106 .31967 .65787 .31686 Mtetra
.17 .576 .936 r
.65787 .31686 .66106 .31967 .66792 .32131 .66475 .31848 Mtetra
.157 .566 .931 r
.66475 .31848 .66792 .32131 .67482 .32306 .67166 .32021 Mtetra
.145 .556 .927 r
.67166 .32021 .67482 .32306 .68176 .32491 .67861 .32204 Mtetra
.134 .548 .922 r
.67861 .32204 .68176 .32491 .68874 .32686 .6856 .32396 Mtetra
.124 .539 .918 r
.6856 .32396 .68874 .32686 .69576 .32889 .69262 .32598 Mtetra
.115 .532 .915 r
.69262 .32598 .69576 .32889 .70282 .33102 .69969 .32808 Mtetra
.107 .525 .911 r
.69969 .32808 .70282 .33102 .70992 .33323 .7068 .33027 Mtetra
.101 .519 .908 r
.7068 .33027 .70992 .33323 .71706 .33551 .71395 .33252 Mtetra
.096 .514 .906 r
.71395 .33252 .71706 .33551 .72424 .33785 .72115 .33485 Mtetra
.092 .51 .904 r
.72115 .33485 .72424 .33785 .73147 .34026 .72838 .33723 Mtetra
.089 .506 .903 r
.72838 .33723 .73147 .34026 .73874 .34272 .73566 .33967 Mtetra
.088 .504 .902 r
.73566 .33967 .73874 .34272 .74604 .34523 .74297 .34215 Mtetra
.088 .502 .901 r
.74297 .34215 .74604 .34523 .75339 .34778 .75033 .34467 Mtetra
.089 .501 .901 r
.75033 .34467 .75339 .34778 .76079 .35035 .75773 .34721 Mtetra
.092 .501 .902 r
.75773 .34721 .76079 .35035 .76822 .35295 .76518 .34978 Mtetra
.096 .502 .903 r
.76518 .34978 .76822 .35295 .7757 .35556 .77266 .35236 Mtetra
.101 .504 .905 r
.77266 .35236 .7757 .35556 .78321 .35817 .78019 .35494 Mtetra
.108 .507 .907 r
.78019 .35494 .78321 .35817 .79077 .36077 .78775 .35751 Mtetra
.115 .51 .909 r
.78775 .35751 .79077 .36077 .79836 .36336 .79535 .36006 Mtetra
.125 .515 .912 r
.79535 .36006 .79836 .36336 .806 .36592 .803 .36259 Mtetra
.135 .52 .915 r
.803 .36259 .806 .36592 .81367 .36844 .81068 .36507 Mtetra
.147 .526 .919 r
.81068 .36507 .81367 .36844 .82138 .37091 .8184 .36751 Mtetra
.16 .533 .923 r
.8184 .36751 .82138 .37091 .82912 .37331 .82615 .36988 Mtetra
.175 .541 .927 r
.82615 .36988 .82912 .37331 .8369 .37565 .83394 .37218 Mtetra
.836 .81 .826 r
.18241 .57531 .18656 .57785 .19281 .57162 .18867 .5691 Mtetra
.838 .812 .824 r
.18867 .5691 .19281 .57162 .19906 .56531 .19493 .56281 Mtetra
.84 .813 .823 r
.19493 .56281 .19906 .56531 .20532 .55892 .2012 .55644 Mtetra
.842 .814 .822 r
.2012 .55644 .20532 .55892 .21158 .55248 .20747 .55002 Mtetra
.844 .815 .821 r
.20747 .55002 .21158 .55248 .21784 .54599 .21374 .54354 Mtetra
.845 .816 .821 r
.21374 .54354 .21784 .54599 .2241 .53946 .22002 .53703 Mtetra
.846 .818 .821 r
.22002 .53703 .2241 .53946 .23036 .5329 .22629 .53049 Mtetra
.847 .819 .821 r
.22629 .53049 .23036 .5329 .23662 .52633 .23257 .52393 Mtetra
.848 .82 .821 r
.23257 .52393 .23662 .52633 .24288 .51975 .23884 .51737 Mtetra
.849 .821 .822 r
.23884 .51737 .24288 .51975 .24913 .51316 .24511 .5108 Mtetra
.849 .823 .822 r
.24511 .5108 .24913 .51316 .25538 .50659 .25137 .50424 Mtetra
.85 .824 .823 r
.25137 .50424 .25538 .50659 .26163 .50004 .25763 .4977 Mtetra
.85 .826 .824 r
.25763 .4977 .26163 .50004 .26787 .49351 .26389 .49118 Mtetra
.85 .827 .825 r
.26389 .49118 .26787 .49351 .2741 .48701 .27014 .48469 Mtetra
.849 .829 .827 r
.27014 .48469 .2741 .48701 .28033 .48056 .27638 .47825 Mtetra
.849 .83 .828 r
.27638 .47825 .28033 .48056 .28655 .47416 .28262 .47186 Mtetra
.848 .832 .83 r
.28262 .47186 .28655 .47416 .29277 .46781 .28885 .46551 Mtetra
.848 .833 .832 r
.28885 .46551 .29277 .46781 .29898 .46152 .29507 .45924 Mtetra
.847 .835 .834 r
.29507 .45924 .29898 .46152 .30518 .4553 .30129 .45302 Mtetra
.845 .836 .837 r
.30129 .45302 .30518 .4553 .31138 .44916 .3075 .44689 Mtetra
.844 .838 .839 r
.3075 .44689 .31138 .44916 .31757 .4431 .3137 .44083 Mtetra
.842 .84 .842 r
.3137 .44083 .31757 .4431 .32375 .43712 .3199 .43486 Mtetra
.841 .841 .845 r
.3199 .43486 .32375 .43712 .32993 .43124 .32609 .42898 Mtetra
.839 .843 .848 r
.32609 .42898 .32993 .43124 .33609 .42545 .33227 .42319 Mtetra
.836 .845 .852 r
.33227 .42319 .33609 .42545 .34226 .41976 .33845 .41751 Mtetra
.834 .846 .855 r
.33845 .41751 .34226 .41976 .34841 .41418 .34462 .41193 Mtetra
.831 .848 .859 r
.34462 .41193 .34841 .41418 .35457 .40871 .35079 .40646 Mtetra
.828 .849 .863 r
.35079 .40646 .35457 .40871 .36071 .40336 .35695 .40111 Mtetra
.825 .851 .867 r
.35695 .40111 .36071 .40336 .36685 .39812 .3631 .39588 Mtetra
.821 .852 .871 r
.3631 .39588 .36685 .39812 .37299 .39301 .36925 .39077 Mtetra
.817 .854 .876 r
.36925 .39077 .37299 .39301 .37912 .38803 .3754 .38578 Mtetra
.813 .855 .88 r
.3754 .38578 .37912 .38803 .38525 .38317 .38155 .38092 Mtetra
.808 .856 .885 r
.38155 .38092 .38525 .38317 .39138 .37844 .38769 .3762 Mtetra
.803 .857 .89 r
.38769 .3762 .39138 .37844 .39751 .37386 .39383 .37161 Mtetra
.797 .858 .895 r
.39383 .37161 .39751 .37386 .40363 .36941 .39997 .36716 Mtetra
.792 .859 .9 r
.39997 .36716 .40363 .36941 .40975 .3651 .4061 .36285 Mtetra
.785 .86 .905 r
.4061 .36285 .40975 .3651 .41588 .36094 .41224 .35868 Mtetra
.778 .86 .911 r
.41224 .35868 .41588 .36094 .422 .35692 .41838 .35466 Mtetra
.771 .861 .916 r
.41838 .35466 .422 .35692 .42813 .35305 .42452 .35078 Mtetra
.763 .861 .922 r
.42452 .35078 .42813 .35305 .43426 .34933 .43066 .34706 Mtetra
.754 .861 .927 r
.43066 .34706 .43426 .34933 .44039 .34576 .43681 .34348 Mtetra
.745 .86 .933 r
.43681 .34348 .44039 .34576 .44652 .34234 .44296 .34006 Mtetra
.736 .859 .939 r
.44296 .34006 .44652 .34234 .45267 .33908 .44911 .3368 Mtetra
.725 .858 .944 r
.44911 .3368 .45267 .33908 .45881 .33597 .45527 .33368 Mtetra
.714 .857 .95 r
.45527 .33368 .45881 .33597 .46497 .33303 .46144 .33073 Mtetra
.703 .855 .955 r
.46144 .33073 .46497 .33303 .47113 .33024 .46761 .32793 Mtetra
.69 .852 .96 r
.46761 .32793 .47113 .33024 .4773 .32761 .4738 .3253 Mtetra
.677 .85 .965 r
.4738 .3253 .4773 .32761 .48348 .32513 .47999 .32282 Mtetra
.663 .846 .97 r
.47999 .32282 .48348 .32513 .48967 .32282 .4862 .3205 Mtetra
.648 .842 .975 r
.4862 .3205 .48967 .32282 .49588 .32067 .49241 .31834 Mtetra
.633 .838 .979 r
.49241 .31834 .49588 .32067 .5021 .31868 .49864 .31634 Mtetra
.617 .833 .983 r
.49864 .31634 .5021 .31868 .50833 .31685 .50488 .3145 Mtetra
.6 .827 .986 r
.50488 .3145 .50833 .31685 .51457 .31518 .51114 .31282 Mtetra
.582 .821 .989 r
.51114 .31282 .51457 .31518 .52083 .31367 .51741 .3113 Mtetra
.564 .814 .992 r
.51741 .3113 .52083 .31367 .52711 .31232 .52371 .30994 Mtetra
.545 .806 .994 r
.52371 .30994 .52711 .31232 .53341 .31113 .53001 .30874 Mtetra
.526 .798 .995 r
.53001 .30874 .53341 .31113 .53973 .3101 .53634 .3077 Mtetra
.506 .789 .996 r
.53634 .3077 .53973 .3101 .54606 .30923 .54269 .30681 Mtetra
.485 .779 .997 r
.54269 .30681 .54606 .30923 .55242 .30851 .54906 .30608 Mtetra
.464 .769 .996 r
.54906 .30608 .55242 .30851 .5588 .30795 .55545 .30551 Mtetra
.443 .758 .995 r
.55545 .30551 .5588 .30795 .5652 .30754 .56186 .30509 Mtetra
.421 .747 .994 r
.56186 .30509 .5652 .30754 .57163 .30729 .5683 .30482 Mtetra
.4 .736 .992 r
.5683 .30482 .57163 .30729 .57808 .30718 .57477 .30471 Mtetra
.378 .723 .989 r
.57477 .30471 .57808 .30718 .58456 .30723 .58126 .30474 Mtetra
.357 .711 .986 r
.58126 .30474 .58456 .30723 .59107 .30742 .58778 .30492 Mtetra
.335 .698 .982 r
.58778 .30492 .59107 .30742 .59761 .30776 .59432 .30524 Mtetra
.314 .686 .978 r
.59432 .30524 .59761 .30776 .60417 .30824 .6009 .3057 Mtetra
.294 .673 .974 r
.6009 .3057 .60417 .30824 .61077 .30886 .60751 .30631 Mtetra
.274 .66 .969 r
.60751 .30631 .61077 .30886 .6174 .30962 .61414 .30705 Mtetra
.254 .647 .964 r
.61414 .30705 .6174 .30962 .62406 .31051 .62081 .30792 Mtetra
.235 .634 .958 r
.62081 .30792 .62406 .31051 .63075 .31153 .62752 .30893 Mtetra
.217 .621 .953 r
.62752 .30893 .63075 .31153 .63748 .31268 .63426 .31006 Mtetra
.2 .609 .948 r
.63426 .31006 .63748 .31268 .64424 .31396 .64103 .31131 Mtetra
.184 .597 .942 r
.64103 .31131 .64424 .31396 .65104 .31535 .64784 .31269 Mtetra
.169 .586 .937 r
.64784 .31269 .65104 .31535 .65787 .31686 .65468 .31418 Mtetra
.154 .575 .932 r
.65468 .31418 .65787 .31686 .66475 .31848 .66156 .31578 Mtetra
.141 .565 .927 r
.66156 .31578 .66475 .31848 .67166 .32021 .66848 .31748 Mtetra
.129 .555 .922 r
.66848 .31748 .67166 .32021 .67861 .32204 .67544 .31929 Mtetra
.118 .546 .918 r
.67544 .31929 .67861 .32204 .6856 .32396 .68244 .32119 Mtetra
.108 .538 .914 r
.68244 .32119 .6856 .32396 .69262 .32598 .68948 .32319 Mtetra
.1 .531 .91 r
.68948 .32319 .69262 .32598 .69969 .32808 .69656 .32527 Mtetra
.092 .524 .907 r
.69656 .32527 .69969 .32808 .7068 .33027 .70368 .32743 Mtetra
.086 .518 .904 r
.70368 .32743 .7068 .33027 .71395 .33252 .71084 .32966 Mtetra
.082 .513 .902 r
.71084 .32966 .71395 .33252 .72115 .33485 .71804 .33195 Mtetra
.078 .509 .9 r
.71804 .33195 .72115 .33485 .72838 .33723 .72528 .33431 Mtetra
.076 .505 .899 r
.72528 .33431 .72838 .33723 .73566 .33967 .73257 .33672 Mtetra
.075 .503 .898 r
.73257 .33672 .73566 .33967 .74297 .34215 .7399 .33917 Mtetra
.076 .501 .898 r
.7399 .33917 .74297 .34215 .75033 .34467 .74726 .34166 Mtetra
.078 .501 .899 r
.74726 .34166 .75033 .34467 .75773 .34721 .75467 .34417 Mtetra
.081 .501 .899 r
.75467 .34417 .75773 .34721 .76518 .34978 .76213 .34671 Mtetra
.085 .502 .901 r
.76213 .34671 .76518 .34978 .77266 .35236 .76962 .34925 Mtetra
.091 .504 .903 r
.76962 .34925 .77266 .35236 .78019 .35494 .77715 .3518 Mtetra
.098 .507 .905 r
.77715 .3518 .78019 .35494 .78775 .35751 .78473 .35434 Mtetra
.107 .511 .908 r
.78473 .35434 .78775 .35751 .79535 .36006 .79234 .35686 Mtetra
.117 .516 .911 r
.79234 .35686 .79535 .36006 .803 .36259 .79999 .35934 Mtetra
.128 .522 .915 r
.79999 .35934 .803 .36259 .81068 .36507 .80768 .36179 Mtetra
.141 .528 .919 r
.80768 .36179 .81068 .36507 .8184 .36751 .81541 .36419 Mtetra
.155 .536 .923 r
.81541 .36419 .8184 .36751 .82615 .36988 .82317 .36652 Mtetra
.17 .544 .927 r
.82317 .36652 .82615 .36988 .83394 .37218 .83097 .36877 Mtetra
.837 .814 .828 r
.17823 .57284 .18241 .57531 .18867 .5691 .1845 .56665 Mtetra
.839 .816 .827 r
.1845 .56665 .18867 .5691 .19493 .56281 .19077 .56038 Mtetra
.841 .817 .826 r
.19077 .56038 .19493 .56281 .2012 .55644 .19705 .55404 Mtetra
.843 .818 .825 r
.19705 .55404 .2012 .55644 .20747 .55002 .20334 .54764 Mtetra
.845 .82 .824 r
.20334 .54764 .20747 .55002 .21374 .54354 .20962 .54119 Mtetra
.846 .821 .824 r
.20962 .54119 .21374 .54354 .22002 .53703 .21591 .5347 Mtetra
.848 .822 .823 r
.21591 .5347 .22002 .53703 .22629 .53049 .2222 .52817 Mtetra
.849 .824 .824 r
.2222 .52817 .22629 .53049 .23257 .52393 .22849 .52163 Mtetra
.85 .825 .824 r
.22849 .52163 .23257 .52393 .23884 .51737 .23477 .51508 Mtetra
.85 .827 .824 r
.23477 .51508 .23884 .51737 .24511 .5108 .24105 .50853 Mtetra
.851 .828 .825 r
.24105 .50853 .24511 .5108 .25137 .50424 .24733 .50199 Mtetra
.851 .83 .826 r
.24733 .50199 .25137 .50424 .25763 .4977 .25361 .49546 Mtetra
.851 .831 .827 r
.25361 .49546 .25763 .4977 .26389 .49118 .25988 .48896 Mtetra
.851 .833 .828 r
.25988 .48896 .26389 .49118 .27014 .48469 .26614 .48248 Mtetra
.851 .835 .83 r
.26614 .48248 .27014 .48469 .27638 .47825 .2724 .47605 Mtetra
.851 .836 .831 r
.2724 .47605 .27638 .47825 .28262 .47186 .27865 .46967 Mtetra
.85 .838 .833 r
.27865 .46967 .28262 .47186 .28885 .46551 .28489 .46334 Mtetra
.849 .84 .835 r
.28489 .46334 .28885 .46551 .29507 .45924 .29113 .45707 Mtetra
.848 .841 .838 r
.29113 .45707 .29507 .45924 .30129 .45302 .29737 .45086 Mtetra
.847 .843 .84 r
.29737 .45086 .30129 .45302 .3075 .44689 .30359 .44473 Mtetra
.846 .845 .843 r
.30359 .44473 .3075 .44689 .3137 .44083 .30981 .43868 Mtetra
.844 .847 .846 r
.30981 .43868 .3137 .44083 .3199 .43486 .31602 .43272 Mtetra
.843 .849 .849 r
.31602 .43272 .3199 .43486 .32609 .42898 .32223 .42684 Mtetra
.841 .85 .852 r
.32223 .42684 .32609 .42898 .33227 .42319 .32842 .42106 Mtetra
.838 .852 .855 r
.32842 .42106 .33227 .42319 .33845 .41751 .33462 .41539 Mtetra
.836 .854 .859 r
.33462 .41539 .33845 .41751 .34462 .41193 .3408 .40981 Mtetra
.833 .856 .863 r
.3408 .40981 .34462 .41193 .35079 .40646 .34698 .40435 Mtetra
.83 .857 .867 r
.34698 .40435 .35079 .40646 .35695 .40111 .35316 .399 Mtetra
.826 .859 .871 r
.35316 .399 .35695 .40111 .3631 .39588 .35933 .39377 Mtetra
.823 .861 .875 r
.35933 .39377 .3631 .39588 .36925 .39077 .36549 .38865 Mtetra
.819 .862 .88 r
.36549 .38865 .36925 .39077 .3754 .38578 .37166 .38367 Mtetra
.814 .864 .884 r
.37166 .38367 .3754 .38578 .38155 .38092 .37781 .37881 Mtetra
.809 .865 .889 r
.37781 .37881 .38155 .38092 .38769 .3762 .38397 .37409 Mtetra
.804 .866 .894 r
.38397 .37409 .38769 .3762 .39383 .37161 .39012 .3695 Mtetra
.799 .867 .899 r
.39012 .3695 .39383 .37161 .39997 .36716 .39628 .36504 Mtetra
.792 .869 .905 r
.39628 .36504 .39997 .36716 .4061 .36285 .40243 .36073 Mtetra
.786 .869 .91 r
.40243 .36073 .4061 .36285 .41224 .35868 .40858 .35656 Mtetra
.779 .87 .915 r
.40858 .35656 .41224 .35868 .41838 .35466 .41473 .35254 Mtetra
.771 .87 .921 r
.41473 .35254 .41838 .35466 .42452 .35078 .42088 .34866 Mtetra
.763 .871 .927 r
.42088 .34866 .42452 .35078 .43066 .34706 .42704 .34493 Mtetra
.754 .871 .932 r
.42704 .34493 .43066 .34706 .43681 .34348 .4332 .34135 Mtetra
.745 .87 .938 r
.4332 .34135 .43681 .34348 .44296 .34006 .43936 .33793 Mtetra
.735 .869 .944 r
.43936 .33793 .44296 .34006 .44911 .3368 .44553 .33466 Mtetra
.724 .868 .949 r
.44553 .33466 .44911 .3368 .45527 .33368 .45171 .33154 Mtetra
.712 .867 .955 r
.45171 .33154 .45527 .33368 .46144 .33073 .45789 .32858 Mtetra
.7 .865 .96 r
.45789 .32858 .46144 .33073 .46761 .32793 .46407 .32578 Mtetra
.687 .862 .965 r
.46407 .32578 .46761 .32793 .4738 .3253 .47027 .32313 Mtetra
.674 .859 .97 r
.47027 .32313 .4738 .3253 .47999 .32282 .47648 .32064 Mtetra
.659 .856 .975 r
.47648 .32064 .47999 .32282 .4862 .3205 .4827 .31832 Mtetra
.644 .852 .979 r
.4827 .31832 .4862 .3205 .49241 .31834 .48892 .31615 Mtetra
.628 .847 .983 r
.48892 .31615 .49241 .31834 .49864 .31634 .49517 .31414 Mtetra
.611 .842 .987 r
.49517 .31414 .49864 .31634 .50488 .3145 .50142 .31229 Mtetra
.594 .836 .99 r
.50142 .31229 .50488 .3145 .51114 .31282 .50769 .3106 Mtetra
.575 .829 .993 r
.50769 .3106 .51114 .31282 .51741 .3113 .51398 .30907 Mtetra
.556 .822 .995 r
.51398 .30907 .51741 .3113 .52371 .30994 .52028 .3077 Mtetra
.537 .814 .997 r
.52028 .3077 .52371 .30994 .53001 .30874 .5266 .30649 Mtetra
.516 .805 .998 r
.5266 .30649 .53001 .30874 .53634 .3077 .53294 .30544 Mtetra
.496 .796 .999 r
.53294 .30544 .53634 .3077 .54269 .30681 .5393 .30454 Mtetra
.474 .786 .998 r
.5393 .30454 .54269 .30681 .54906 .30608 .54568 .3038 Mtetra
.453 .775 .998 r
.54568 .3038 .54906 .30608 .55545 .30551 .55208 .30321 Mtetra
.431 .764 .996 r
.55208 .30321 .55545 .30551 .56186 .30509 .55851 .30278 Mtetra
.409 .752 .994 r
.55851 .30278 .56186 .30509 .5683 .30482 .56496 .3025 Mtetra
.387 .74 .992 r
.56496 .3025 .5683 .30482 .57477 .30471 .57144 .30237 Mtetra
.364 .727 .988 r
.57144 .30237 .57477 .30471 .58126 .30474 .57794 .30238 Mtetra
.342 .714 .985 r
.57794 .30238 .58126 .30474 .58778 .30492 .58447 .30255 Mtetra
.321 .701 .98 r
.58447 .30255 .58778 .30492 .59432 .30524 .59102 .30285 Mtetra
.299 .687 .976 r
.59102 .30285 .59432 .30524 .6009 .3057 .59761 .3033 Mtetra
.278 .674 .971 r
.59761 .3033 .6009 .3057 .60751 .30631 .60423 .30389 Mtetra
.258 .66 .966 r
.60423 .30389 .60751 .30631 .61414 .30705 .61088 .30461 Mtetra
.238 .647 .96 r
.61088 .30461 .61414 .30705 .62081 .30792 .61756 .30547 Mtetra
.219 .634 .954 r
.61756 .30547 .62081 .30792 .62752 .30893 .62427 .30645 Mtetra
.201 .621 .949 r
.62427 .30645 .62752 .30893 .63426 .31006 .63102 .30757 Mtetra
.184 .609 .943 r
.63102 .30757 .63426 .31006 .64103 .31131 .6378 .3088 Mtetra
.167 .597 .937 r
.6378 .3088 .64103 .31131 .64784 .31269 .64462 .31015 Mtetra
.152 .585 .932 r
.64462 .31015 .64784 .31269 .65468 .31418 .65148 .31162 Mtetra
.138 .574 .927 r
.65148 .31162 .65468 .31418 .66156 .31578 .65837 .3132 Mtetra
.125 .564 .922 r
.65837 .3132 .66156 .31578 .66848 .31748 .6653 .31488 Mtetra
.113 .554 .917 r
.6653 .31488 .66848 .31748 .67544 .31929 .67227 .31667 Mtetra
.102 .545 .912 r
.67227 .31667 .67544 .31929 .68244 .32119 .67928 .31855 Mtetra
.093 .537 .908 r
.67928 .31855 .68244 .32119 .68948 .32319 .68633 .32051 Mtetra
.085 .529 .905 r
.68633 .32051 .68948 .32319 .69656 .32527 .69341 .32257 Mtetra
.078 .522 .902 r
.69341 .32257 .69656 .32527 .70368 .32743 .70054 .3247 Mtetra
.072 .517 .899 r
.70054 .3247 .70368 .32743 .71084 .32966 .70771 .3269 Mtetra
.068 .512 .897 r
.70771 .3269 .71084 .32966 .71804 .33195 .71492 .32917 Mtetra
.065 .508 .896 r
.71492 .32917 .71804 .33195 .72528 .33431 .72218 .3315 Mtetra
.063 .504 .895 r
.72218 .3315 .72528 .33431 .73257 .33672 .72947 .33387 Mtetra
.063 .502 .894 r
.72947 .33387 .73257 .33672 .7399 .33917 .73681 .33629 Mtetra
.064 .501 .895 r
.73681 .33629 .7399 .33917 .74726 .34166 .74419 .33875 Mtetra
.066 .501 .895 r
.74419 .33875 .74726 .34166 .75467 .34417 .75161 .34123 Mtetra
.07 .501 .896 r
.75161 .34123 .75467 .34417 .76213 .34671 .75907 .34373 Mtetra
.075 .503 .898 r
.75907 .34373 .76213 .34671 .76962 .34925 .76657 .34624 Mtetra
.082 .505 .901 r
.76657 .34624 .76962 .34925 .77715 .3518 .77411 .34875 Mtetra
.089 .508 .903 r
.77411 .34875 .77715 .3518 .78473 .35434 .7817 .35125 Mtetra
.099 .513 .906 r
.7817 .35125 .78473 .35434 .79234 .35686 .78932 .35373 Mtetra
.109 .518 .91 r
.78932 .35373 .79234 .35686 .79999 .35934 .79698 .35618 Mtetra
.121 .524 .914 r
.79698 .35618 .79999 .35934 .80768 .36179 .80468 .35858 Mtetra
.135 .53 .918 r
.80468 .35858 .80768 .36179 .81541 .36419 .81241 .36094 Mtetra
.149 .538 .923 r
.81241 .36094 .81541 .36419 .82317 .36652 .82018 .36322 Mtetra
.165 .546 .927 r
.82018 .36322 .82317 .36652 .83097 .36877 .82799 .36543 Mtetra
.837 .818 .831 r
.17402 .57043 .17823 .57284 .1845 .56665 .1803 .56427 Mtetra
.84 .82 .829 r
.1803 .56427 .1845 .56665 .19077 .56038 .18659 .55803 Mtetra
.842 .821 .828 r
.18659 .55803 .19077 .56038 .19705 .55404 .19288 .55171 Mtetra
.844 .823 .827 r
.19288 .55171 .19705 .55404 .20334 .54764 .19918 .54534 Mtetra
.846 .824 .827 r
.19918 .54534 .20334 .54764 .20962 .54119 .20548 .53891 Mtetra
.847 .826 .826 r
.20548 .53891 .20962 .54119 .21591 .5347 .21178 .53244 Mtetra
.849 .827 .826 r
.21178 .53244 .21591 .5347 .2222 .52817 .21808 .52594 Mtetra
.85 .829 .826 r
.21808 .52594 .2222 .52817 .22849 .52163 .22438 .51942 Mtetra
.851 .83 .826 r
.22438 .51942 .22849 .52163 .23477 .51508 .23068 .51289 Mtetra
.852 .832 .827 r
.23068 .51289 .23477 .51508 .24105 .50853 .23697 .50636 Mtetra
.852 .834 .828 r
.23697 .50636 .24105 .50853 .24733 .50199 .24326 .49983 Mtetra
.853 .835 .829 r
.24326 .49983 .24733 .50199 .25361 .49546 .24955 .49332 Mtetra
.853 .837 .83 r
.24955 .49332 .25361 .49546 .25988 .48896 .25583 .48684 Mtetra
.853 .839 .831 r
.25583 .48684 .25988 .48896 .26614 .48248 .26211 .48038 Mtetra
.853 .841 .833 r
.26211 .48038 .26614 .48248 .2724 .47605 .26839 .47396 Mtetra
.852 .842 .834 r
.26839 .47396 .2724 .47605 .27865 .46967 .27465 .46759 Mtetra
.852 .844 .836 r
.27465 .46759 .27865 .46967 .28489 .46334 .28091 .46127 Mtetra
.851 .846 .838 r
.28091 .46127 .28489 .46334 .29113 .45707 .28717 .45501 Mtetra
.85 .848 .841 r
.28717 .45501 .29113 .45707 .29737 .45086 .29341 .44882 Mtetra
.849 .85 .843 r
.29341 .44882 .29737 .45086 .30359 .44473 .29965 .4427 Mtetra
.848 .852 .846 r
.29965 .4427 .30359 .44473 .30981 .43868 .30589 .43666 Mtetra
.846 .854 .849 r
.30589 .43666 .30981 .43868 .31602 .43272 .31211 .4307 Mtetra
.844 .856 .852 r
.31211 .4307 .31602 .43272 .32223 .42684 .31833 .42483 Mtetra
.842 .858 .855 r
.31833 .42483 .32223 .42684 .32842 .42106 .32455 .41906 Mtetra
.84 .86 .859 r
.32455 .41906 .32842 .42106 .33462 .41539 .33075 .41339 Mtetra
.837 .862 .862 r
.33075 .41339 .33462 .41539 .3408 .40981 .33695 .40782 Mtetra
.835 .864 .866 r
.33695 .40782 .3408 .40981 .34698 .40435 .34315 .40236 Mtetra
.831 .865 .87 r
.34315 .40236 .34698 .40435 .35316 .399 .34934 .39701 Mtetra
.828 .867 .874 r
.34934 .39701 .35316 .399 .35933 .39377 .35552 .39178 Mtetra
.824 .869 .879 r
.35552 .39178 .35933 .39377 .36549 .38865 .36171 .38668 Mtetra
.82 .871 .884 r
.36171 .38668 .36549 .38865 .37166 .38367 .36788 .38169 Mtetra
.815 .872 .888 r
.36788 .38169 .37166 .38367 .37781 .37881 .37406 .37684 Mtetra
.81 .874 .893 r
.37406 .37684 .37781 .37881 .38397 .37409 .38023 .37211 Mtetra
.805 .875 .898 r
.38023 .37211 .38397 .37409 .39012 .3695 .38639 .36752 Mtetra
.799 .877 .903 r
.38639 .36752 .39012 .3695 .39628 .36504 .39256 .36307 Mtetra
.793 .878 .909 r
.39256 .36307 .39628 .36504 .40243 .36073 .39873 .35876 Mtetra
.786 .879 .914 r
.39873 .35876 .40243 .36073 .40858 .35656 .40489 .35458 Mtetra
.779 .88 .92 r
.40489 .35458 .40858 .35656 .41473 .35254 .41106 .35056 Mtetra
.771 .88 .925 r
.41106 .35056 .41473 .35254 .42088 .34866 .41723 .34668 Mtetra
.762 .88 .931 r
.41723 .34668 .42088 .34866 .42704 .34493 .4234 .34295 Mtetra
.753 .88 .937 r
.4234 .34295 .42704 .34493 .4332 .34135 .42957 .33936 Mtetra
.744 .88 .942 r
.42957 .33936 .4332 .34135 .43936 .33793 .43575 .33593 Mtetra
.733 .879 .948 r
.43575 .33593 .43936 .33793 .44553 .33466 .44193 .33266 Mtetra
.722 .878 .954 r
.44193 .33266 .44553 .33466 .45171 .33154 .44812 .32954 Mtetra
.71 .877 .959 r
.44812 .32954 .45171 .33154 .45789 .32858 .45431 .32657 Mtetra
.697 .875 .964 r
.45431 .32657 .45789 .32858 .46407 .32578 .46051 .32376 Mtetra
.684 .872 .97 r
.46051 .32376 .46407 .32578 .47027 .32313 .46672 .32111 Mtetra
.67 .869 .974 r
.46672 .32111 .47027 .32313 .47648 .32064 .47294 .31861 Mtetra
.655 .865 .979 r
.47294 .31861 .47648 .32064 .4827 .31832 .47917 .31628 Mtetra
.639 .861 .983 r
.47917 .31628 .4827 .31832 .48892 .31615 .48542 .3141 Mtetra
.622 .856 .987 r
.48542 .3141 .48892 .31615 .49517 .31414 .49167 .31209 Mtetra
.605 .85 .991 r
.49167 .31209 .49517 .31414 .50142 .31229 .49794 .31023 Mtetra
.586 .844 .993 r
.49794 .31023 .50142 .31229 .50769 .3106 .50422 .30853 Mtetra
.567 .837 .996 r
.50422 .30853 .50769 .3106 .51398 .30907 .51052 .30699 Mtetra
.548 .829 .998 r
.51052 .30699 .51398 .30907 .52028 .3077 .51684 .30561 Mtetra
.527 .821 .999 r
.51684 .30561 .52028 .3077 .5266 .30649 .52317 .30439 Mtetra
.506 .811 1 r
.52317 .30439 .5266 .30649 .53294 .30544 .52952 .30332 Mtetra
.485 .802 1 r
.52952 .30332 .53294 .30544 .5393 .30454 .53589 .30241 Mtetra
.463 .791 .999 r
.53589 .30241 .5393 .30454 .54568 .3038 .54228 .30166 Mtetra
.441 .78 .998 r
.54228 .30166 .54568 .3038 .55208 .30321 .5487 .30106 Mtetra
.418 .768 .996 r
.5487 .30106 .55208 .30321 .55851 .30278 .55514 .30061 Mtetra
.395 .755 .993 r
.55514 .30061 .55851 .30278 .56496 .3025 .5616 .30031 Mtetra
.372 .743 .99 r
.5616 .30031 .56496 .3025 .57144 .30237 .56809 .30017 Mtetra
.35 .729 .986 r
.56809 .30017 .57144 .30237 .57794 .30238 .5746 .30017 Mtetra
.327 .716 .982 r
.5746 .30017 .57794 .30238 .58447 .30255 .58114 .30032 Mtetra
.305 .702 .977 r
.58114 .30032 .58447 .30255 .59102 .30285 .58771 .30061 Mtetra
.283 .688 .972 r
.58771 .30061 .59102 .30285 .59761 .3033 .59431 .30104 Mtetra
.262 .674 .967 r
.59431 .30104 .59761 .3033 .60423 .30389 .60094 .30161 Mtetra
.242 .661 .961 r
.60094 .30161 .60423 .30389 .61088 .30461 .6076 .30231 Mtetra
.222 .647 .955 r
.6076 .30231 .61088 .30461 .61756 .30547 .61429 .30315 Mtetra
.203 .633 .949 r
.61429 .30315 .61756 .30547 .62427 .30645 .62101 .30411 Mtetra
.184 .62 .943 r
.62101 .30411 .62427 .30645 .63102 .30757 .62777 .3052 Mtetra
.167 .608 .937 r
.62777 .3052 .63102 .30757 .6378 .3088 .63457 .30642 Mtetra
.151 .595 .931 r
.63457 .30642 .6378 .3088 .64462 .31015 .6414 .30775 Mtetra
.136 .583 .926 r
.6414 .30775 .64462 .31015 .65148 .31162 .64826 .30919 Mtetra
.122 .572 .92 r
.64826 .30919 .65148 .31162 .65837 .3132 .65516 .31075 Mtetra
.109 .562 .915 r
.65516 .31075 .65837 .3132 .6653 .31488 .66211 .3124 Mtetra
.097 .552 .911 r
.66211 .3124 .6653 .31488 .67227 .31667 .66909 .31416 Mtetra
.087 .543 .906 r
.66909 .31416 .67227 .31667 .67928 .31855 .6761 .31602 Mtetra
.078 .535 .902 r
.6761 .31602 .67928 .31855 .68633 .32051 .68316 .31796 Mtetra
.07 .527 .899 r
.68316 .31796 .68633 .32051 .69341 .32257 .69026 .31998 Mtetra
.063 .521 .896 r
.69026 .31998 .69341 .32257 .70054 .3247 .6974 .32208 Mtetra
.058 .515 .894 r
.6974 .32208 .70054 .3247 .70771 .3269 .70458 .32426 Mtetra
.054 .51 .892 r
.70458 .32426 .70771 .3269 .71492 .32917 .7118 .3265 Mtetra
.052 .506 .891 r
.7118 .3265 .71492 .32917 .72218 .3315 .71906 .32879 Mtetra
.051 .504 .89 r
.71906 .32879 .72218 .3315 .72947 .33387 .72637 .33113 Mtetra
.051 .502 .89 r
.72637 .33113 .72947 .33387 .73681 .33629 .73371 .33352 Mtetra
.053 .5 .89 r
.73371 .33352 .73681 .33629 .74419 .33875 .7411 .33594 Mtetra
.055 .5 .892 r
.7411 .33594 .74419 .33875 .75161 .34123 .74853 .33839 Mtetra
.06 .501 .893 r
.74853 .33839 .75161 .34123 .75907 .34373 .756 .34085 Mtetra
.066 .503 .895 r
.756 .34085 .75907 .34373 .76657 .34624 .76351 .34332 Mtetra
.073 .506 .898 r
.76351 .34332 .76657 .34624 .77411 .34875 .77106 .34579 Mtetra
.081 .509 .901 r
.77106 .34579 .77411 .34875 .7817 .35125 .77866 .34825 Mtetra
.091 .514 .905 r
.77866 .34825 .7817 .35125 .78932 .35373 .78629 .35069 Mtetra
.102 .519 .909 r
.78629 .35069 .78932 .35373 .79698 .35618 .79396 .35309 Mtetra
.115 .526 .913 r
.79396 .35309 .79698 .35618 .80468 .35858 .80167 .35545 Mtetra
.129 .533 .918 r
.80167 .35545 .80468 .35858 .81241 .36094 .80941 .35776 Mtetra
.145 .541 .923 r
.80941 .35776 .81241 .36094 .82018 .36322 .81719 .36 Mtetra
.161 .549 .928 r
.81719 .36 .82018 .36322 .82799 .36543 .825 .36216 Mtetra
.838 .822 .833 r
.16978 .56808 .17402 .57043 .1803 .56427 .17607 .56195 Mtetra
.84 .824 .832 r
.17607 .56195 .1803 .56427 .18659 .55803 .18237 .55574 Mtetra
.843 .825 .831 r
.18237 .55574 .18659 .55803 .19288 .55171 .18868 .54946 Mtetra
.845 .827 .83 r
.18868 .54946 .19288 .55171 .19918 .54534 .19499 .54311 Mtetra
.847 .828 .829 r
.19499 .54311 .19918 .54534 .20548 .53891 .2013 .53671 Mtetra
.848 .83 .829 r
.2013 .53671 .20548 .53891 .21178 .53244 .20761 .53027 Mtetra
.85 .832 .829 r
.20761 .53027 .21178 .53244 .21808 .52594 .21392 .5238 Mtetra
.851 .834 .829 r
.21392 .5238 .21808 .52594 .22438 .51942 .22024 .5173 Mtetra
.852 .835 .829 r
.22024 .5173 .22438 .51942 .23068 .51289 .22655 .5108 Mtetra
.853 .837 .83 r
.22655 .5108 .23068 .51289 .23697 .50636 .23286 .50428 Mtetra
.853 .839 .83 r
.23286 .50428 .23697 .50636 .24326 .49983 .23916 .49778 Mtetra
.854 .841 .831 r
.23916 .49778 .24326 .49983 .24955 .49332 .24547 .49129 Mtetra
.854 .843 .833 r
.24547 .49129 .24955 .49332 .25583 .48684 .25176 .48482 Mtetra
.854 .845 .834 r
.25176 .48482 .25583 .48684 .26211 .48038 .25806 .47838 Mtetra
.854 .846 .835 r
.25806 .47838 .26211 .48038 .26839 .47396 .26434 .47198 Mtetra
.854 .848 .837 r
.26434 .47198 .26839 .47396 .27465 .46759 .27063 .46562 Mtetra
.853 .85 .839 r
.27063 .46562 .27465 .46759 .28091 .46127 .2769 .45932 Mtetra
.853 .853 .841 r
.2769 .45932 .28091 .46127 .28717 .45501 .28317 .45307 Mtetra
.852 .855 .844 r
.28317 .45307 .28717 .45501 .29341 .44882 .28943 .44689 Mtetra
.851 .857 .846 r
.28943 .44689 .29341 .44882 .29965 .4427 .29569 .44078 Mtetra
.849 .859 .849 r
.29569 .44078 .29965 .4427 .30589 .43666 .30193 .43475 Mtetra
.848 .861 .852 r
.30193 .43475 .30589 .43666 .31211 .4307 .30818 .4288 Mtetra
.846 .863 .855 r
.30818 .4288 .31211 .4307 .31833 .42483 .31441 .42295 Mtetra
.844 .865 .858 r
.31441 .42295 .31833 .42483 .32455 .41906 .32064 .41718 Mtetra
.841 .867 .862 r
.32064 .41718 .32455 .41906 .33075 .41339 .32686 .41152 Mtetra
.839 .869 .866 r
.32686 .41152 .33075 .41339 .33695 .40782 .33308 .40595 Mtetra
.836 .871 .87 r
.33308 .40595 .33695 .40782 .34315 .40236 .33929 .4005 Mtetra
.833 .873 .874 r
.33929 .4005 .34315 .40236 .34934 .39701 .34549 .39516 Mtetra
.829 .875 .878 r
.34549 .39516 .34934 .39701 .35552 .39178 .35169 .38994 Mtetra
.825 .877 .883 r
.35169 .38994 .35552 .39178 .36171 .38668 .35789 .38483 Mtetra
.821 .879 .887 r
.35789 .38483 .36171 .38668 .36788 .38169 .36408 .37985 Mtetra
.816 .881 .892 r
.36408 .37985 .36788 .38169 .37406 .37684 .37027 .375 Mtetra
.811 .883 .897 r
.37027 .375 .37406 .37684 .38023 .37211 .37646 .37027 Mtetra
.806 .884 .902 r
.37646 .37027 .38023 .37211 .38639 .36752 .38264 .36568 Mtetra
.8 .886 .907 r
.38264 .36568 .38639 .36752 .39256 .36307 .38882 .36123 Mtetra
.793 .887 .913 r
.38882 .36123 .39256 .36307 .39873 .35876 .395 .35692 Mtetra
.786 .888 .918 r
.395 .35692 .39873 .35876 .40489 .35458 .40118 .35275 Mtetra
.779 .889 .924 r
.40118 .35275 .40489 .35458 .41106 .35056 .40736 .34872 Mtetra
.77 .889 .929 r
.40736 .34872 .41106 .35056 .41723 .34668 .41355 .34484 Mtetra
.762 .89 .935 r
.41355 .34484 .41723 .34668 .4234 .34295 .41973 .3411 Mtetra
.752 .89 .941 r
.41973 .3411 .4234 .34295 .42957 .33936 .42592 .33752 Mtetra
.742 .889 .946 r
.42592 .33752 .42957 .33936 .43575 .33593 .43211 .33408 Mtetra
.731 .889 .952 r
.43211 .33408 .43575 .33593 .44193 .33266 .4383 .3308 Mtetra
.72 .888 .958 r
.4383 .3308 .44193 .33266 .44812 .32954 .44451 .32768 Mtetra
.707 .886 .963 r
.44451 .32768 .44812 .32954 .45431 .32657 .45071 .3247 Mtetra
.694 .884 .968 r
.45071 .3247 .45431 .32657 .46051 .32376 .45693 .32189 Mtetra
.68 .881 .973 r
.45693 .32189 .46051 .32376 .46672 .32111 .46315 .31923 Mtetra
.665 .878 .978 r
.46315 .31923 .46672 .32111 .47294 .31861 .46939 .31673 Mtetra
.649 .874 .982 r
.46939 .31673 .47294 .31861 .47917 .31628 .47563 .31439 Mtetra
.633 .869 .986 r
.47563 .31439 .47917 .31628 .48542 .3141 .48189 .3122 Mtetra
.616 .864 .99 r
.48189 .3122 .48542 .3141 .49167 .31209 .48815 .31018 Mtetra
.597 .858 .993 r
.48815 .31018 .49167 .31209 .49794 .31023 .49444 .30831 Mtetra
.578 .852 .996 r
.49444 .30831 .49794 .31023 .50422 .30853 .50073 .3066 Mtetra
.559 .844 .998 r
.50073 .3066 .50422 .30853 .51052 .30699 .50704 .30505 Mtetra
.538 .836 .999 r
.50704 .30505 .51052 .30699 .51684 .30561 .51337 .30366 Mtetra
.517 .827 1 r
.51337 .30366 .51684 .30561 .52317 .30439 .51972 .30242 Mtetra
.495 .817 1 r
.51972 .30242 .52317 .30439 .52952 .30332 .52608 .30135 Mtetra
.473 .807 .999 r
.52608 .30135 .52952 .30332 .53589 .30241 .53247 .30042 Mtetra
.451 .795 .998 r
.53247 .30042 .53589 .30241 .54228 .30166 .53887 .29966 Mtetra
.428 .784 .996 r
.53887 .29966 .54228 .30166 .5487 .30106 .5453 .29904 Mtetra
.404 .771 .994 r
.5453 .29904 .5487 .30106 .55514 .30061 .55175 .29858 Mtetra
.381 .758 .991 r
.55175 .29858 .55514 .30061 .5616 .30031 .55822 .29827 Mtetra
.358 .745 .987 r
.55822 .29827 .5616 .30031 .56809 .30017 .56472 .29811 Mtetra
.335 .731 .983 r
.56472 .29811 .56809 .30017 .5746 .30017 .57125 .29809 Mtetra
.312 .717 .978 r
.57125 .29809 .5746 .30017 .58114 .30032 .5778 .29822 Mtetra
.289 .703 .973 r
.5778 .29822 .58114 .30032 .58771 .30061 .58438 .29849 Mtetra
.267 .688 .967 r
.58438 .29849 .58771 .30061 .59431 .30104 .59099 .2989 Mtetra
.246 .674 .961 r
.59099 .2989 .59431 .30104 .60094 .30161 .59763 .29945 Mtetra
.225 .66 .955 r
.59763 .29945 .60094 .30161 .6076 .30231 .6043 .30014 Mtetra
.205 .646 .949 r
.6043 .30014 .6076 .30231 .61429 .30315 .61101 .30096 Mtetra
.186 .632 .943 r
.61101 .30096 .61429 .30315 .62101 .30411 .61774 .3019 Mtetra
.168 .619 .936 r
.61774 .3019 .62101 .30411 .62777 .3052 .62451 .30297 Mtetra
.151 .606 .93 r
.62451 .30297 .62777 .3052 .63457 .30642 .63132 .30416 Mtetra
.134 .593 .924 r
.63132 .30416 .63457 .30642 .6414 .30775 .63816 .30547 Mtetra
.119 .581 .919 r
.63816 .30547 .6414 .30775 .64826 .30919 .64503 .30689 Mtetra
.106 .57 .913 r
.64503 .30689 .64826 .30919 .65516 .31075 .65195 .30841 Mtetra
.093 .56 .908 r
.65195 .30841 .65516 .31075 .66211 .3124 .6589 .31005 Mtetra
.082 .55 .903 r
.6589 .31005 .66211 .3124 .66909 .31416 .66589 .31178 Mtetra
.072 .541 .899 r
.66589 .31178 .66909 .31416 .6761 .31602 .67292 .3136 Mtetra
.063 .533 .895 r
.67292 .3136 .6761 .31602 .68316 .31796 .67999 .31552 Mtetra
.056 .525 .892 r
.67999 .31552 .68316 .31796 .69026 .31998 .68709 .31751 Mtetra
.05 .519 .89 r
.68709 .31751 .69026 .31998 .6974 .32208 .69424 .31958 Mtetra
.045 .514 .887 r
.69424 .31958 .6974 .32208 .70458 .32426 .70143 .32172 Mtetra
.041 .509 .886 r
.70143 .32172 .70458 .32426 .7118 .3265 .70866 .32393 Mtetra
.039 .505 .885 r
.70866 .32393 .7118 .3265 .71906 .32879 .71594 .32619 Mtetra
.039 .503 .885 r
.71594 .32619 .71906 .32879 .72637 .33113 .72325 .3285 Mtetra
.04 .501 .885 r
.72325 .3285 .72637 .33113 .73371 .33352 .73061 .33085 Mtetra
.042 .5 .886 r
.73061 .33085 .73371 .33352 .7411 .33594 .738 .33323 Mtetra
.045 .5 .888 r
.738 .33323 .7411 .33594 .74853 .33839 .74544 .33564 Mtetra
.05 .502 .89 r
.74544 .33564 .74853 .33839 .756 .34085 .75292 .33806 Mtetra
.057 .504 .892 r
.75292 .33806 .756 .34085 .76351 .34332 .76045 .34049 Mtetra
.065 .507 .895 r
.76045 .34049 .76351 .34332 .77106 .34579 .76801 .34292 Mtetra
.074 .511 .899 r
.76801 .34292 .77106 .34579 .77866 .34825 .77561 .34533 Mtetra
.084 .516 .903 r
.77561 .34533 .77866 .34825 .78629 .35069 .78325 .34772 Mtetra
.096 .521 .908 r
.78325 .34772 .78629 .35069 .79396 .35309 .79093 .35008 Mtetra
.11 .528 .913 r
.79093 .35008 .79396 .35309 .80167 .35545 .79864 .35239 Mtetra
.125 .536 .918 r
.79864 .35239 .80167 .35545 .80941 .35776 .8064 .35465 Mtetra
.141 .544 .923 r
.8064 .35465 .80941 .35776 .81719 .36 .81419 .35684 Mtetra
.158 .553 .928 r
.81419 .35684 .81719 .36 .825 .36216 .82201 .35894 Mtetra
.838 .826 .836 r
.16552 .56579 .16978 .56808 .17607 .56195 .17182 .5597 Mtetra
.841 .827 .835 r
.17182 .5597 .17607 .56195 .18237 .55574 .17813 .55353 Mtetra
.843 .829 .834 r
.17813 .55353 .18237 .55574 .18868 .54946 .18445 .54728 Mtetra
.845 .831 .833 r
.18445 .54728 .18868 .54946 .19499 .54311 .19077 .54096 Mtetra
.847 .833 .832 r
.19077 .54096 .19499 .54311 .2013 .53671 .19709 .53459 Mtetra
.849 .835 .832 r
.19709 .53459 .2013 .53671 .20761 .53027 .20342 .52818 Mtetra
.85 .836 .832 r
.20342 .52818 .20761 .53027 .21392 .5238 .20974 .52174 Mtetra
.852 .838 .832 r
.20974 .52174 .21392 .5238 .22024 .5173 .21607 .51527 Mtetra
.853 .84 .832 r
.21607 .51527 .22024 .5173 .22655 .5108 .22239 .50879 Mtetra
.854 .842 .833 r
.22239 .50879 .22655 .5108 .23286 .50428 .22872 .5023 Mtetra
.854 .844 .833 r
.22872 .5023 .23286 .50428 .23916 .49778 .23504 .49582 Mtetra
.855 .846 .834 r
.23504 .49582 .23916 .49778 .24547 .49129 .24135 .48935 Mtetra
.855 .848 .835 r
.24135 .48935 .24547 .49129 .25176 .48482 .24766 .4829 Mtetra
.855 .85 .837 r
.24766 .4829 .25176 .48482 .25806 .47838 .25397 .47648 Mtetra
.855 .852 .838 r
.25397 .47648 .25806 .47838 .26434 .47198 .26027 .4701 Mtetra
.855 .855 .84 r
.26027 .4701 .26434 .47198 .27063 .46562 .26657 .46376 Mtetra
.855 .857 .842 r
.26657 .46376 .27063 .46562 .2769 .45932 .27286 .45747 Mtetra
.854 .859 .844 r
.27286 .45747 .2769 .45932 .28317 .45307 .27914 .45124 Mtetra
.853 .861 .847 r
.27914 .45124 .28317 .45307 .28943 .44689 .28542 .44507 Mtetra
.852 .863 .849 r
.28542 .44507 .28943 .44689 .29569 .44078 .29169 .43898 Mtetra
.85 .866 .852 r
.29169 .43898 .29569 .44078 .30193 .43475 .29795 .43296 Mtetra
.849 .868 .855 r
.29795 .43296 .30193 .43475 .30818 .4288 .30421 .42703 Mtetra
.847 .87 .858 r
.30421 .42703 .30818 .4288 .31441 .42295 .31046 .42118 Mtetra
.845 .872 .862 r
.31046 .42118 .31441 .42295 .32064 .41718 .3167 .41542 Mtetra
.843 .875 .865 r
.3167 .41542 .32064 .41718 .32686 .41152 .32294 .40977 Mtetra
.84 .877 .869 r
.32294 .40977 .32686 .41152 .33308 .40595 .32917 .40421 Mtetra
.837 .879 .873 r
.32917 .40421 .33308 .40595 .33929 .4005 .3354 .39877 Mtetra
.834 .881 .877 r
.3354 .39877 .33929 .4005 .34549 .39516 .34162 .39343 Mtetra
.83 .883 .882 r
.34162 .39343 .34549 .39516 .35169 .38994 .34784 .38821 Mtetra
.826 .886 .886 r
.34784 .38821 .35169 .38994 .35789 .38483 .35405 .38311 Mtetra
.822 .888 .891 r
.35405 .38311 .35789 .38483 .36408 .37985 .36025 .37814 Mtetra
.817 .889 .896 r
.36025 .37814 .36408 .37985 .37027 .375 .36646 .37329 Mtetra
.812 .891 .901 r
.36646 .37329 .37027 .375 .37646 .37027 .37266 .36857 Mtetra
.806 .893 .906 r
.37266 .36857 .37646 .37027 .38264 .36568 .37886 .36398 Mtetra
.8 .895 .911 r
.37886 .36398 .38264 .36568 .38882 .36123 .38505 .35953 Mtetra
.793 .896 .916 r
.38505 .35953 .38882 .36123 .395 .35692 .39125 .35522 Mtetra
.786 .897 .922 r
.39125 .35522 .395 .35692 .40118 .35275 .39744 .35104 Mtetra
.778 .898 .928 r
.39744 .35104 .40118 .35275 .40736 .34872 .40364 .34702 Mtetra
.769 .899 .933 r
.40364 .34702 .40736 .34872 .41355 .34484 .40984 .34313 Mtetra
.76 .899 .939 r
.40984 .34313 .41355 .34484 .41973 .3411 .41604 .33939 Mtetra
.75 .899 .944 r
.41604 .33939 .41973 .3411 .42592 .33752 .42224 .33581 Mtetra
.74 .899 .95 r
.42224 .33581 .42592 .33752 .43211 .33408 .42844 .33237 Mtetra
.728 .898 .956 r
.42844 .33237 .43211 .33408 .4383 .3308 .43465 .32909 Mtetra
.716 .897 .961 r
.43465 .32909 .4383 .3308 .44451 .32768 .44087 .32595 Mtetra
.703 .895 .966 r
.44087 .32595 .44451 .32768 .45071 .3247 .44709 .32298 Mtetra
.69 .893 .971 r
.44709 .32298 .45071 .3247 .45693 .32189 .45332 .32016 Mtetra
.675 .89 .976 r
.45332 .32016 .45693 .32189 .46315 .31923 .45956 .31749 Mtetra
.66 .886 .98 r
.45956 .31749 .46315 .31923 .46939 .31673 .46581 .31498 Mtetra
.643 .882 .985 r
.46581 .31498 .46939 .31673 .47563 .31439 .47207 .31263 Mtetra
.626 .877 .988 r
.47207 .31263 .47563 .31439 .48189 .3122 .47834 .31044 Mtetra
.608 .872 .992 r
.47834 .31044 .48189 .3122 .48815 .31018 .48462 .30841 Mtetra
.589 .865 .994 r
.48462 .30841 .48815 .31018 .49444 .30831 .49091 .30653 Mtetra
.57 .858 .996 r
.49091 .30653 .49444 .30831 .50073 .3066 .49722 .30481 Mtetra
.549 .85 .998 r
.49722 .30481 .50073 .3066 .50704 .30505 .50355 .30325 Mtetra
.528 .842 .999 r
.50355 .30325 .50704 .30505 .51337 .30366 .50989 .30185 Mtetra
.506 .832 .999 r
.50989 .30185 .51337 .30366 .51972 .30242 .51625 .3006 Mtetra
.484 .822 .999 r
.51625 .3006 .51972 .30242 .52608 .30135 .52262 .29951 Mtetra
.461 .811 .998 r
.52262 .29951 .52608 .30135 .53247 .30042 .52902 .29857 Mtetra
.437 .799 .996 r
.52902 .29857 .53247 .30042 .53887 .29966 .53544 .29779 Mtetra
.414 .787 .994 r
.53544 .29779 .53887 .29966 .5453 .29904 .54188 .29716 Mtetra
.39 .774 .99 r
.54188 .29716 .5453 .29904 .55175 .29858 .54834 .29669 Mtetra
.366 .76 .987 r
.54834 .29669 .55175 .29858 .55822 .29827 .55483 .29636 Mtetra
.343 .746 .982 r
.55483 .29636 .55822 .29827 .56472 .29811 .56134 .29618 Mtetra
.319 .732 .977 r
.56134 .29618 .56472 .29811 .57125 .29809 .56788 .29615 Mtetra
.296 .717 .972 r
.56788 .29615 .57125 .29809 .5778 .29822 .57444 .29626 Mtetra
.273 .703 .966 r
.57444 .29626 .5778 .29822 .58438 .29849 .58103 .29651 Mtetra
.251 .688 .96 r
.58103 .29651 .58438 .29849 .59099 .2989 .58766 .29691 Mtetra
.229 .673 .954 r
.58766 .29691 .59099 .2989 .59763 .29945 .59431 .29744 Mtetra
.208 .659 .948 r
.59431 .29744 .59763 .29945 .6043 .30014 .60099 .2981 Mtetra
.188 .644 .941 r
.60099 .2981 .6043 .30014 .61101 .30096 .60771 .29889 Mtetra
.169 .63 .935 r
.60771 .29889 .61101 .30096 .61774 .3019 .61445 .29981 Mtetra
.151 .617 .928 r
.61445 .29981 .61774 .3019 .62451 .30297 .62124 .30086 Mtetra
.134 .603 .922 r
.62124 .30086 .62451 .30297 .63132 .30416 .62805 .30203 Mtetra
.118 .591 .916 r
.62805 .30203 .63132 .30416 .63816 .30547 .6349 .30331 Mtetra
.103 .579 .91 r
.6349 .30331 .63816 .30547 .64503 .30689 .64179 .3047 Mtetra
.09 .568 .905 r
.64179 .3047 .64503 .30689 .65195 .30841 .64872 .3062 Mtetra
.078 .557 .9 r
.64872 .3062 .65195 .30841 .6589 .31005 .65568 .30781 Mtetra
.067 .547 .895 r
.65568 .30781 .6589 .31005 .66589 .31178 .66268 .30951 Mtetra
.057 .539 .891 r
.66268 .30951 .66589 .31178 .67292 .3136 .66972 .31131 Mtetra
.049 .531 .888 r
.66972 .31131 .67292 .3136 .67999 .31552 .6768 .31319 Mtetra
.042 .523 .885 r
.6768 .31319 .67999 .31552 .68709 .31751 .68392 .31515 Mtetra
.036 .517 .882 r
.68392 .31515 .68709 .31751 .69424 .31958 .69108 .31719 Mtetra
.032 .512 .881 r
.69108 .31719 .69424 .31958 .70143 .32172 .69828 .31929 Mtetra
.029 .508 .88 r
.69828 .31929 .70143 .32172 .70866 .32393 .70552 .32146 Mtetra
.028 .504 .879 r
.70552 .32146 .70866 .32393 .71594 .32619 .7128 .32369 Mtetra
.028 .502 .879 r
.7128 .32369 .71594 .32619 .72325 .3285 .72013 .32596 Mtetra
.029 .5 .88 r
.72013 .32596 .72325 .3285 .73061 .33085 .72749 .32827 Mtetra
.032 .5 .881 r
.72749 .32827 .73061 .33085 .738 .33323 .7349 .33061 Mtetra
.036 .5 .883 r
.7349 .33061 .738 .33323 .74544 .33564 .74235 .33298 Mtetra
.042 .502 .886 r
.74235 .33298 .74544 .33564 .75292 .33806 .74984 .33536 Mtetra
.049 .504 .889 r
.74984 .33536 .75292 .33806 .76045 .34049 .75737 .33774 Mtetra
.057 .508 .893 r
.75737 .33774 .76045 .34049 .76801 .34292 .76494 .34012 Mtetra
.067 .512 .897 r
.76494 .34012 .76801 .34292 .77561 .34533 .77255 .34249 Mtetra
.078 .518 .902 r
.77255 .34249 .77561 .34533 .78325 .34772 .7802 .34483 Mtetra
.091 .524 .907 r
.7802 .34483 .78325 .34772 .79093 .35008 .78789 .34714 Mtetra
.105 .531 .912 r
.78789 .34714 .79093 .35008 .79864 .35239 .79561 .3494 Mtetra
.121 .539 .917 r
.79561 .3494 .79864 .35239 .8064 .35465 .80338 .3516 Mtetra
.138 .547 .923 r
.80338 .3516 .8064 .35465 .81419 .35684 .81117 .35374 Mtetra
.156 .557 .929 r
.81117 .35374 .81419 .35684 .82201 .35894 .819 .35579 Mtetra
.838 .829 .839 r
.16123 .56356 .16552 .56579 .17182 .5597 .16754 .55751 Mtetra
.841 .831 .838 r
.16754 .55751 .17182 .5597 .17813 .55353 .17386 .55138 Mtetra
.843 .833 .837 r
.17386 .55138 .17813 .55353 .18445 .54728 .18018 .54516 Mtetra
.846 .835 .836 r
.18018 .54516 .18445 .54728 .19077 .54096 .18652 .53888 Mtetra
.848 .837 .835 r
.18652 .53888 .19077 .54096 .19709 .53459 .19285 .53255 Mtetra
.85 .839 .835 r
.19285 .53255 .19709 .53459 .20342 .52818 .19919 .52617 Mtetra
.851 .841 .835 r
.19919 .52617 .20342 .52818 .20974 .52174 .20553 .51976 Mtetra
.852 .843 .835 r
.20553 .51976 .20974 .52174 .21607 .51527 .21187 .51332 Mtetra
.854 .845 .835 r
.21187 .51332 .21607 .51527 .22239 .50879 .21821 .50686 Mtetra
.855 .847 .835 r
.21821 .50686 .22239 .50879 .22872 .5023 .22454 .5004 Mtetra
.855 .849 .836 r
.22454 .5004 .22872 .5023 .23504 .49582 .23088 .49395 Mtetra
.856 .852 .837 r
.23088 .49395 .23504 .49582 .24135 .48935 .23721 .4875 Mtetra
.856 .854 .838 r
.23721 .4875 .24135 .48935 .24766 .4829 .24353 .48108 Mtetra
.856 .856 .84 r
.24353 .48108 .24766 .4829 .25397 .47648 .24985 .47468 Mtetra
.856 .858 .841 r
.24985 .47468 .25397 .47648 .26027 .4701 .25617 .46832 Mtetra
.856 .86 .843 r
.25617 .46832 .26027 .4701 .26657 .46376 .26248 .462 Mtetra
.856 .863 .845 r
.26248 .462 .26657 .46376 .27286 .45747 .26879 .45573 Mtetra
.855 .865 .847 r
.26879 .45573 .27286 .45747 .27914 .45124 .27508 .44952 Mtetra
.854 .867 .85 r
.27508 .44952 .27914 .45124 .28542 .44507 .28138 .44337 Mtetra
.853 .87 .852 r
.28138 .44337 .28542 .44507 .29169 .43898 .28766 .43729 Mtetra
.852 .872 .855 r
.28766 .43729 .29169 .43898 .29795 .43296 .29394 .43129 Mtetra
.85 .875 .858 r
.29394 .43129 .29795 .43296 .30421 .42703 .30021 .42536 Mtetra
.848 .877 .861 r
.30021 .42536 .30421 .42703 .31046 .42118 .30648 .41953 Mtetra
.846 .88 .865 r
.30648 .41953 .31046 .42118 .3167 .41542 .31274 .41379 Mtetra
.844 .882 .868 r
.31274 .41379 .3167 .41542 .32294 .40977 .31899 .40814 Mtetra
.841 .884 .872 r
.31899 .40814 .32294 .40977 .32917 .40421 .32524 .4026 Mtetra
.838 .887 .876 r
.32524 .4026 .32917 .40421 .3354 .39877 .33148 .39716 Mtetra
.834 .889 .88 r
.33148 .39716 .3354 .39877 .34162 .39343 .33772 .39183 Mtetra
.831 .891 .885 r
.33772 .39183 .34162 .39343 .34784 .38821 .34395 .38662 Mtetra
.826 .894 .889 r
.34395 .38662 .34784 .38821 .35405 .38311 .35017 .38153 Mtetra
.822 .896 .894 r
.35017 .38153 .35405 .38311 .36025 .37814 .3564 .37655 Mtetra
.817 .898 .899 r
.3564 .37655 .36025 .37814 .36646 .37329 .36262 .37171 Mtetra
.812 .9 .904 r
.36262 .37171 .36646 .37329 .37266 .36857 .36883 .36699 Mtetra
.806 .902 .909 r
.36883 .36699 .37266 .36857 .37886 .36398 .37505 .36241 Mtetra
.799 .903 .914 r
.37505 .36241 .37886 .36398 .38505 .35953 .38126 .35796 Mtetra
.792 .905 .92 r
.38126 .35796 .38505 .35953 .39125 .35522 .38747 .35365 Mtetra
.785 .906 .925 r
.38747 .35365 .39125 .35522 .39744 .35104 .39368 .34948 Mtetra
.776 .907 .931 r
.39368 .34948 .39744 .35104 .40364 .34702 .39989 .34545 Mtetra
.768 .907 .936 r
.39989 .34545 .40364 .34702 .40984 .34313 .4061 .34156 Mtetra
.758 .908 .942 r
.4061 .34156 .40984 .34313 .41604 .33939 .41232 .33782 Mtetra
.748 .908 .948 r
.41232 .33782 .41604 .33939 .42224 .33581 .41853 .33424 Mtetra
.737 .907 .953 r
.41853 .33424 .42224 .33581 .42844 .33237 .42475 .3308 Mtetra
.725 .907 .958 r
.42475 .3308 .42844 .33237 .43465 .32909 .43098 .32751 Mtetra
.713 .905 .964 r
.43098 .32751 .43465 .32909 .44087 .32595 .43721 .32437 Mtetra
.699 .903 .969 r
.43721 .32437 .44087 .32595 .44709 .32298 .44345 .32139 Mtetra
.685 .901 .973 r
.44345 .32139 .44709 .32298 .45332 .32016 .44969 .31856 Mtetra
.67 .898 .978 r
.44969 .31856 .45332 .32016 .45956 .31749 .45594 .31589 Mtetra
.654 .894 .982 r
.45594 .31589 .45956 .31749 .46581 .31498 .46221 .31338 Mtetra
.637 .89 .986 r
.46221 .31338 .46581 .31498 .47207 .31263 .46848 .31102 Mtetra
.619 .884 .989 r
.46848 .31102 .47207 .31263 .47834 .31044 .47476 .30882 Mtetra
.6 .878 .992 r
.47476 .30882 .47834 .31044 .48462 .30841 .48106 .30677 Mtetra
.58 .872 .994 r
.48106 .30677 .48462 .30841 .49091 .30653 .48737 .30489 Mtetra
.56 .864 .996 r
.48737 .30489 .49091 .30653 .49722 .30481 .49369 .30316 Mtetra
.539 .856 .997 r
.49369 .30316 .49722 .30481 .50355 .30325 .50003 .30159 Mtetra
.517 .846 .998 r
.50003 .30159 .50355 .30325 .50989 .30185 .50638 .30017 Mtetra
.494 .836 .997 r
.50638 .30017 .50989 .30185 .51625 .3006 .51275 .29891 Mtetra
.471 .825 .996 r
.51275 .29891 .51625 .3006 .52262 .29951 .51915 .29781 Mtetra
.448 .814 .995 r
.51915 .29781 .52262 .29951 .52902 .29857 .52556 .29686 Mtetra
.424 .801 .992 r
.52556 .29686 .52902 .29857 .53544 .29779 .53199 .29607 Mtetra
.4 .788 .989 r
.53199 .29607 .53544 .29779 .54188 .29716 .53844 .29542 Mtetra
.375 .775 .985 r
.53844 .29542 .54188 .29716 .54834 .29669 .54492 .29493 Mtetra
.351 .761 .981 r
.54492 .29493 .54834 .29669 .55483 .29636 .55141 .29459 Mtetra
.327 .746 .976 r
.55141 .29459 .55483 .29636 .56134 .29618 .55794 .29439 Mtetra
.303 .731 .971 r
.55794 .29439 .56134 .29618 .56788 .29615 .56449 .29434 Mtetra
.279 .716 .965 r
.56449 .29434 .56788 .29615 .57444 .29626 .57107 .29443 Mtetra
.256 .701 .959 r
.57107 .29443 .57444 .29626 .58103 .29651 .57767 .29466 Mtetra
.234 .686 .952 r
.57767 .29466 .58103 .29651 .58766 .29691 .58431 .29504 Mtetra
.212 .671 .946 r
.58431 .29504 .58766 .29691 .59431 .29744 .59097 .29555 Mtetra
.192 .656 .939 r
.59097 .29555 .59431 .29744 .60099 .2981 .59767 .29619 Mtetra
.172 .642 .932 r
.59767 .29619 .60099 .2981 .60771 .29889 .60439 .29696 Mtetra
.153 .628 .926 r
.60439 .29696 .60771 .29889 .61445 .29981 .61115 .29786 Mtetra
.135 .614 .919 r
.61115 .29786 .61445 .29981 .62124 .30086 .61794 .29888 Mtetra
.118 .601 .913 r
.61794 .29888 .62124 .30086 .62805 .30203 .62477 .30002 Mtetra
.102 .588 .907 r
.62477 .30002 .62805 .30203 .6349 .30331 .63164 .30127 Mtetra
.088 .576 .901 r
.63164 .30127 .6349 .30331 .64179 .3047 .63854 .30264 Mtetra
.075 .565 .896 r
.63854 .30264 .64179 .3047 .64872 .3062 .64547 .30411 Mtetra
.063 .554 .891 r
.64547 .30411 .64872 .3062 .65568 .30781 .65244 .30569 Mtetra
.052 .545 .887 r
.65244 .30569 .65568 .30781 .66268 .30951 .65946 .30736 Mtetra
.043 .536 .883 r
.65946 .30736 .66268 .30951 .66972 .31131 .66651 .30912 Mtetra
.035 .528 .879 r
.66651 .30912 .66972 .31131 .6768 .31319 .6736 .31097 Mtetra
.029 .521 .877 r
.6736 .31097 .6768 .31319 .68392 .31515 .68073 .3129 Mtetra
.024 .515 .875 r
.68073 .3129 .68392 .31515 .69108 .31719 .6879 .3149 Mtetra
.02 .51 .874 r
.6879 .3149 .69108 .31719 .69828 .31929 .69511 .31697 Mtetra
.018 .506 .873 r
.69511 .31697 .69828 .31929 .70552 .32146 .70236 .3191 Mtetra
.017 .503 .873 r
.70236 .3191 .70552 .32146 .7128 .32369 .70965 .32129 Mtetra
.017 .501 .873 r
.70965 .32129 .7128 .32369 .72013 .32596 .71699 .32352 Mtetra
.019 .5 .875 r
.71699 .32352 .72013 .32596 .72749 .32827 .72437 .32579 Mtetra
.022 .5 .877 r
.72437 .32579 .72749 .32827 .7349 .33061 .73178 .32809 Mtetra
.027 .501 .879 r
.73178 .32809 .7349 .33061 .74235 .33298 .73924 .33041 Mtetra
.034 .503 .882 r
.73924 .33041 .74235 .33298 .74984 .33536 .74674 .33274 Mtetra
.041 .506 .886 r
.74674 .33274 .74984 .33536 .75737 .33774 .75428 .33508 Mtetra
.05 .509 .89 r
.75428 .33508 .75737 .33774 .76494 .34012 .76186 .33741 Mtetra
.061 .514 .895 r
.76186 .33741 .76494 .34012 .77255 .34249 .76948 .33973 Mtetra
.073 .52 .9 r
.76948 .33973 .77255 .34249 .7802 .34483 .77714 .34202 Mtetra
.087 .526 .905 r
.77714 .34202 .7802 .34483 .78789 .34714 .78484 .34427 Mtetra
.102 .534 .911 r
.78484 .34427 .78789 .34714 .79561 .3494 .79257 .34648 Mtetra
.118 .542 .917 r
.79257 .34648 .79561 .3494 .80338 .3516 .80034 .34862 Mtetra
.136 .551 .923 r
.80034 .34862 .80338 .3516 .81117 .35374 .80815 .35069 Mtetra
.155 .561 .93 r
.80815 .35069 .81117 .35374 .819 .35579 .81599 .35268 Mtetra
.838 .833 .842 r
.1569 .56138 .16123 .56356 .16754 .55751 .16323 .55538 Mtetra
.841 .835 .841 r
.16323 .55538 .16754 .55751 .17386 .55138 .16956 .54928 Mtetra
.843 .837 .839 r
.16956 .54928 .17386 .55138 .18018 .54516 .17589 .54311 Mtetra
.846 .839 .839 r
.17589 .54311 .18018 .54516 .18652 .53888 .18224 .53687 Mtetra
.848 .841 .838 r
.18224 .53687 .18652 .53888 .19285 .53255 .18858 .53058 Mtetra
.85 .843 .838 r
.18858 .53058 .19285 .53255 .19919 .52617 .19493 .52423 Mtetra
.852 .846 .837 r
.19493 .52423 .19919 .52617 .20553 .51976 .20129 .51785 Mtetra
.853 .848 .837 r
.20129 .51785 .20553 .51976 .21187 .51332 .20764 .51145 Mtetra
.854 .85 .838 r
.20764 .51145 .21187 .51332 .21821 .50686 .21399 .50503 Mtetra
.855 .852 .838 r
.21399 .50503 .21821 .50686 .22454 .5004 .22034 .4986 Mtetra
.856 .855 .839 r
.22034 .4986 .22454 .5004 .23088 .49395 .22669 .49217 Mtetra
.857 .857 .84 r
.22669 .49217 .23088 .49395 .23721 .4875 .23303 .48575 Mtetra
.857 .859 .841 r
.23303 .48575 .23721 .4875 .24353 .48108 .23937 .47935 Mtetra
.857 .862 .843 r
.23937 .47935 .24353 .48108 .24985 .47468 .24571 .47298 Mtetra
.857 .864 .844 r
.24571 .47298 .24985 .47468 .25617 .46832 .25204 .46664 Mtetra
.857 .866 .846 r
.25204 .46664 .25617 .46832 .26248 .462 .25836 .46034 Mtetra
.857 .869 .848 r
.25836 .46034 .26248 .462 .26879 .45573 .26468 .45409 Mtetra
.856 .871 .85 r
.26468 .45409 .26879 .45573 .27508 .44952 .271 .4479 Mtetra
.855 .874 .853 r
.271 .4479 .27508 .44952 .28138 .44337 .2773 .44177 Mtetra
.854 .876 .855 r
.2773 .44177 .28138 .44337 .28766 .43729 .2836 .43571 Mtetra
.852 .879 .858 r
.2836 .43571 .28766 .43729 .29394 .43129 .2899 .42972 Mtetra
.851 .881 .861 r
.2899 .42972 .29394 .43129 .30021 .42536 .29619 .42382 Mtetra
.849 .884 .864 r
.29619 .42382 .30021 .42536 .30648 .41953 .30247 .418 Mtetra
.847 .887 .868 r
.30247 .418 .30648 .41953 .31274 .41379 .30874 .41227 Mtetra
.844 .889 .872 r
.30874 .41227 .31274 .41379 .31899 .40814 .31501 .40663 Mtetra
.841 .892 .875 r
.31501 .40663 .31899 .40814 .32524 .4026 .32127 .4011 Mtetra
.838 .894 .879 r
.32127 .4011 .32524 .4026 .33148 .39716 .32753 .39567 Mtetra
.835 .897 .884 r
.32753 .39567 .33148 .39716 .33772 .39183 .33378 .39035 Mtetra
.831 .899 .888 r
.33378 .39035 .33772 .39183 .34395 .38662 .34003 .38515 Mtetra
.827 .901 .893 r
.34003 .38515 .34395 .38662 .35017 .38153 .34627 .38006 Mtetra
.822 .904 .897 r
.34627 .38006 .35017 .38153 .3564 .37655 .35251 .3751 Mtetra
.817 .906 .902 r
.35251 .3751 .3564 .37655 .36262 .37171 .35874 .37026 Mtetra
.811 .908 .907 r
.35874 .37026 .36262 .37171 .36883 .36699 .36498 .36555 Mtetra
.805 .91 .912 r
.36498 .36555 .36883 .36699 .37505 .36241 .37121 .36097 Mtetra
.798 .911 .917 r
.37121 .36097 .37505 .36241 .38126 .35796 .37743 .35652 Mtetra
.791 .913 .923 r
.37743 .35652 .38126 .35796 .38747 .35365 .38366 .35221 Mtetra
.783 .914 .928 r
.38366 .35221 .38747 .35365 .39368 .34948 .38989 .34804 Mtetra
.775 .915 .934 r
.38989 .34804 .39368 .34948 .39989 .34545 .39611 .34401 Mtetra
.765 .916 .939 r
.39611 .34401 .39989 .34545 .4061 .34156 .40234 .34013 Mtetra
.756 .916 .945 r
.40234 .34013 .4061 .34156 .41232 .33782 .40857 .33639 Mtetra
.745 .916 .95 r
.40857 .33639 .41232 .33782 .41853 .33424 .4148 .3328 Mtetra
.733 .916 .955 r
.4148 .3328 .41853 .33424 .42475 .3308 .42104 .32936 Mtetra
.721 .915 .961 r
.42104 .32936 .42475 .3308 .43098 .32751 .42728 .32606 Mtetra
.708 .913 .966 r
.42728 .32606 .43098 .32751 .43721 .32437 .43352 .32292 Mtetra
.694 .911 .97 r
.43352 .32292 .43721 .32437 .44345 .32139 .43978 .31994 Mtetra
.679 .908 .975 r
.43978 .31994 .44345 .32139 .44969 .31856 .44604 .31711 Mtetra
.663 .905 .979 r
.44604 .31711 .44969 .31856 .45594 .31589 .4523 .31443 Mtetra
.647 .901 .983 r
.4523 .31443 .45594 .31589 .46221 .31338 .45858 .31191 Mtetra
.629 .896 .986 r
.45858 .31191 .46221 .31338 .46848 .31102 .46487 .30954 Mtetra
.61 .891 .989 r
.46487 .30954 .46848 .31102 .47476 .30882 .47116 .30733 Mtetra
.591 .884 .992 r
.47116 .30733 .47476 .30882 .48106 .30677 .47747 .30528 Mtetra
.571 .877 .993 r
.47747 .30528 .48106 .30677 .48737 .30489 .4838 .30338 Mtetra
.549 .869 .995 r
.4838 .30338 .48737 .30489 .49369 .30316 .49013 .30165 Mtetra
.528 .86 .995 r
.49013 .30165 .49369 .30316 .50003 .30159 .49649 .30006 Mtetra
.505 .85 .995 r
.49649 .30006 .50003 .30159 .50638 .30017 .50286 .29864 Mtetra
.482 .839 .994 r
.50286 .29864 .50638 .30017 .51275 .29891 .50924 .29736 Mtetra
.458 .828 .992 r
.50924 .29736 .51275 .29891 .51915 .29781 .51565 .29625 Mtetra
.434 .816 .99 r
.51565 .29625 .51915 .29781 .52556 .29686 .52207 .29528 Mtetra
.409 .803 .987 r
.52207 .29528 .52556 .29686 .53199 .29607 .52851 .29447 Mtetra
.385 .789 .983 r
.52851 .29447 .53199 .29607 .53844 .29542 .53498 .29381 Mtetra
.36 .775 .979 r
.53498 .29381 .53844 .29542 .54492 .29493 .54147 .2933 Mtetra
.335 .76 .974 r
.54147 .2933 .54492 .29493 .55141 .29459 .54798 .29294 Mtetra
.311 .745 .969 r
.54798 .29294 .55141 .29459 .55794 .29439 .55452 .29273 Mtetra
.287 .73 .963 r
.55452 .29273 .55794 .29439 .56449 .29434 .56108 .29266 Mtetra
.263 .715 .956 r
.56108 .29266 .56449 .29434 .57107 .29443 .56767 .29273 Mtetra
.24 .699 .95 r
.56767 .29273 .57107 .29443 .57767 .29466 .57429 .29295 Mtetra
.217 .684 .943 r
.57429 .29295 .57767 .29466 .58431 .29504 .58094 .2933 Mtetra
.196 .669 .936 r
.58094 .2933 .58431 .29504 .59097 .29555 .58761 .29378 Mtetra
.175 .653 .929 r
.58761 .29378 .59097 .29555 .59767 .29619 .59432 .2944 Mtetra
.155 .639 .922 r
.59432 .2944 .59767 .29619 .60439 .29696 .60106 .29515 Mtetra
.136 .624 .915 r
.60106 .29515 .60439 .29696 .61115 .29786 .60783 .29602 Mtetra
.119 .611 .909 r
.60783 .29602 .61115 .29786 .61794 .29888 .61464 .29701 Mtetra
.102 .597 .903 r
.61464 .29701 .61794 .29888 .62477 .30002 .62148 .29813 Mtetra
.087 .585 .897 r
.62148 .29813 .62477 .30002 .63164 .30127 .62835 .29935 Mtetra
.073 .573 .891 r
.62835 .29935 .63164 .30127 .63854 .30264 .63526 .30069 Mtetra
.06 .562 .886 r
.63526 .30069 .63854 .30264 .64547 .30411 .64221 .30213 Mtetra
.048 .551 .881 r
.64221 .30213 .64547 .30411 .65244 .30569 .6492 .30368 Mtetra
.038 .542 .877 r
.6492 .30368 .65244 .30569 .65946 .30736 .65622 .30532 Mtetra
.03 .533 .874 r
.65622 .30532 .65946 .30736 .66651 .30912 .66328 .30704 Mtetra
.022 .526 .871 r
.66328 .30704 .66651 .30912 .6736 .31097 .67038 .30886 Mtetra
.016 .519 .868 r
.67038 .30886 .6736 .31097 .68073 .3129 .67753 .31075 Mtetra
.012 .513 .867 r
.67753 .31075 .68073 .3129 .6879 .3149 .68471 .31272 Mtetra
.008 .509 .866 r
.68471 .31272 .6879 .3149 .69511 .31697 .69193 .31475 Mtetra
.007 .505 .866 r
.69193 .31475 .69511 .31697 .70236 .3191 .69919 .31684 Mtetra
.006 .502 .866 r
.69919 .31684 .70236 .3191 .70965 .32129 .7065 .31898 Mtetra
.007 .501 .867 r
.7065 .31898 .70965 .32129 .71699 .32352 .71384 .32117 Mtetra
.01 .5 .869 r
.71384 .32117 .71699 .32352 .72437 .32579 .72123 .32339 Mtetra
.014 .5 .872 r
.72123 .32339 .72437 .32579 .73178 .32809 .72865 .32565 Mtetra
.019 .501 .875 r
.72865 .32565 .73178 .32809 .73924 .33041 .73612 .32792 Mtetra
.026 .504 .878 r
.73612 .32792 .73924 .33041 .74674 .33274 .74363 .33021 Mtetra
.035 .507 .883 r
.74363 .33021 .74674 .33274 .75428 .33508 .75118 .33249 Mtetra
.045 .511 .887 r
.75118 .33249 .75428 .33508 .76186 .33741 .75877 .33477 Mtetra
.056 .516 .893 r
.75877 .33477 .76186 .33741 .76948 .33973 .7664 .33704 Mtetra
.069 .522 .898 r
.7664 .33704 .76948 .33973 .77714 .34202 .77407 .33927 Mtetra
.083 .529 .904 r
.77407 .33927 .77714 .34202 .78484 .34427 .78178 .34147 Mtetra
.099 .537 .911 r
.78178 .34147 .78484 .34427 .79257 .34648 .78952 .34361 Mtetra
.116 .546 .917 r
.78952 .34361 .79257 .34648 .80034 .34862 .7973 .3457 Mtetra
.134 .555 .924 r
.7973 .3457 .80034 .34862 .80815 .35069 .80512 .34771 Mtetra
.154 .565 .93 r
.80512 .34771 .80815 .35069 .81599 .35268 .81296 .34963 Mtetra
.837 .836 .845 r
.15255 .55925 .1569 .56138 .16323 .55538 .15889 .5533 Mtetra
.841 .839 .843 r
.15889 .5533 .16323 .55538 .16956 .54928 .16523 .54725 Mtetra
.843 .841 .842 r
.16523 .54725 .16956 .54928 .17589 .54311 .17157 .54112 Mtetra
.846 .843 .841 r
.17157 .54112 .17589 .54311 .18224 .53687 .17793 .53493 Mtetra
.848 .845 .841 r
.17793 .53493 .18224 .53687 .18858 .53058 .18429 .52867 Mtetra
.85 .848 .84 r
.18429 .52867 .18858 .53058 .19493 .52423 .19065 .52237 Mtetra
.852 .85 .84 r
.19065 .52237 .19493 .52423 .20129 .51785 .19701 .51602 Mtetra
.853 .852 .84 r
.19701 .51602 .20129 .51785 .20764 .51145 .20338 .50965 Mtetra
.855 .855 .841 r
.20338 .50965 .20764 .51145 .21399 .50503 .20974 .50327 Mtetra
.856 .857 .841 r
.20974 .50327 .21399 .50503 .22034 .4986 .21611 .49687 Mtetra
.857 .86 .842 r
.21611 .49687 .22034 .4986 .22669 .49217 .22247 .49047 Mtetra
.857 .862 .843 r
.22247 .49047 .22669 .49217 .23303 .48575 .22882 .48409 Mtetra
.858 .865 .844 r
.22882 .48409 .23303 .48575 .23937 .47935 .23518 .47772 Mtetra
.858 .867 .846 r
.23518 .47772 .23937 .47935 .24571 .47298 .24153 .47137 Mtetra
.858 .87 .847 r
.24153 .47137 .24571 .47298 .25204 .46664 .24787 .46506 Mtetra
.858 .872 .849 r
.24787 .46506 .25204 .46664 .25836 .46034 .25421 .45879 Mtetra
.857 .875 .851 r
.25421 .45879 .25836 .46034 .26468 .45409 .26055 .45256 Mtetra
.857 .877 .853 r
.26055 .45256 .26468 .45409 .271 .4479 .26688 .44639 Mtetra
.856 .88 .856 r
.26688 .44639 .271 .4479 .2773 .44177 .2732 .44028 Mtetra
.854 .883 .858 r
.2732 .44028 .2773 .44177 .2836 .43571 .27951 .43424 Mtetra
.853 .885 .861 r
.27951 .43424 .2836 .43571 .2899 .42972 .28582 .42827 Mtetra
.851 .888 .864 r
.28582 .42827 .2899 .42972 .29619 .42382 .29213 .42238 Mtetra
.849 .891 .867 r
.29213 .42238 .29619 .42382 .30247 .418 .29842 .41657 Mtetra
.847 .894 .871 r
.29842 .41657 .30247 .418 .30874 .41227 .30471 .41086 Mtetra
.845 .896 .875 r
.30471 .41086 .30874 .41227 .31501 .40663 .311 .40524 Mtetra
.842 .899 .878 r
.311 .40524 .31501 .40663 .32127 .4011 .31728 .39972 Mtetra
.838 .902 .882 r
.31728 .39972 .32127 .4011 .32753 .39567 .32355 .3943 Mtetra
.835 .904 .887 r
.32355 .3943 .32753 .39567 .33378 .39035 .32982 .389 Mtetra
.831 .907 .891 r
.32982 .389 .33378 .39035 .34003 .38515 .33608 .3838 Mtetra
.826 .909 .895 r
.33608 .3838 .34003 .38515 .34627 .38006 .34234 .37872 Mtetra
.821 .911 .9 r
.34234 .37872 .34627 .38006 .35251 .3751 .34859 .37377 Mtetra
.816 .914 .905 r
.34859 .37377 .35251 .3751 .35874 .37026 .35485 .36893 Mtetra
.81 .916 .91 r
.35485 .36893 .35874 .37026 .36498 .36555 .36109 .36423 Mtetra
.804 .918 .915 r
.36109 .36423 .36498 .36555 .37121 .36097 .36734 .35965 Mtetra
.797 .919 .92 r
.36734 .35965 .37121 .36097 .37743 .35652 .37358 .35521 Mtetra
.789 .921 .925 r
.37358 .35521 .37743 .35652 .38366 .35221 .37982 .3509 Mtetra
.781 .922 .931 r
.37982 .3509 .38366 .35221 .38989 .34804 .38607 .34674 Mtetra
.772 .923 .936 r
.38607 .34674 .38989 .34804 .39611 .34401 .39231 .34271 Mtetra
.763 .924 .941 r
.39231 .34271 .39611 .34401 .40234 .34013 .39855 .33882 Mtetra
.752 .924 .947 r
.39855 .33882 .40234 .34013 .40857 .33639 .4048 .33509 Mtetra
.741 .924 .952 r
.4048 .33509 .40857 .33639 .4148 .3328 .41104 .33149 Mtetra
.729 .923 .957 r
.41104 .33149 .4148 .3328 .42104 .32936 .4173 .32805 Mtetra
.716 .922 .962 r
.4173 .32805 .42104 .32936 .42728 .32606 .42355 .32475 Mtetra
.703 .92 .967 r
.42355 .32475 .42728 .32606 .43352 .32292 .42981 .32161 Mtetra
.688 .918 .971 r
.42981 .32161 .43352 .32292 .43978 .31994 .43608 .31862 Mtetra
.673 .915 .975 r
.43608 .31862 .43978 .31994 .44604 .31711 .44235 .31578 Mtetra
.656 .912 .979 r
.44235 .31578 .44604 .31711 .4523 .31443 .44864 .3131 Mtetra
.639 .907 .983 r
.44864 .3131 .4523 .31443 .45858 .31191 .45493 .31057 Mtetra
.621 .902 .986 r
.45493 .31057 .45858 .31191 .46487 .30954 .46123 .3082 Mtetra
.601 .896 .988 r
.46123 .3082 .46487 .30954 .47116 .30733 .46754 .30598 Mtetra
.581 .889 .99 r
.46754 .30598 .47116 .30733 .47747 .30528 .47387 .30392 Mtetra
.56 .881 .991 r
.47387 .30392 .47747 .30528 .4838 .30338 .4802 .30201 Mtetra
.538 .873 .992 r
.4802 .30201 .4838 .30338 .49013 .30165 .48656 .30026 Mtetra
.516 .863 .992 r
.48656 .30026 .49013 .30165 .49649 .30006 .49292 .29867 Mtetra
.492 .853 .991 r
.49292 .29867 .49649 .30006 .50286 .29864 .49931 .29723 Mtetra
.468 .841 .989 r
.49931 .29723 .50286 .29864 .50924 .29736 .50571 .29595 Mtetra
.444 .829 .987 r
.50571 .29595 .50924 .29736 .51565 .29625 .51213 .29482 Mtetra
.419 .816 .984 r
.51213 .29482 .51565 .29625 .52207 .29528 .51856 .29384 Mtetra
.394 .803 .98 r
.51856 .29384 .52207 .29528 .52851 .29447 .52502 .29301 Mtetra
.369 .789 .976 r
.52502 .29301 .52851 .29447 .53498 .29381 .5315 .29234 Mtetra
.344 .774 .971 r
.5315 .29234 .53498 .29381 .54147 .2933 .538 .29181 Mtetra
.319 .759 .966 r
.538 .29181 .54147 .2933 .54798 .29294 .54453 .29143 Mtetra
.295 .744 .96 r
.54453 .29143 .54798 .29294 .55452 .29273 .55108 .2912 Mtetra
.27 .728 .953 r
.55108 .2912 .55452 .29273 .56108 .29266 .55766 .29111 Mtetra
.246 .712 .947 r
.55766 .29111 .56108 .29266 .56767 .29273 .56426 .29116 Mtetra
.223 .696 .94 r
.56426 .29116 .56767 .29273 .57429 .29295 .57089 .29135 Mtetra
.201 .681 .933 r
.57089 .29135 .57429 .29295 .58094 .2933 .57755 .29168 Mtetra
.179 .665 .925 r
.57755 .29168 .58094 .2933 .58761 .29378 .58424 .29214 Mtetra
.159 .65 .918 r
.58424 .29214 .58761 .29378 .59432 .2944 .59096 .29274 Mtetra
.139 .635 .911 r
.59096 .29274 .59432 .2944 .60106 .29515 .59771 .29346 Mtetra
.12 .621 .904 r
.59771 .29346 .60106 .29515 .60783 .29602 .6045 .2943 Mtetra
.103 .607 .898 r
.6045 .2943 .60783 .29602 .61464 .29701 .61132 .29527 Mtetra
.087 .594 .891 r
.61132 .29527 .61464 .29701 .62148 .29813 .61817 .29636 Mtetra
.072 .581 .886 r
.61817 .29636 .62148 .29813 .62835 .29935 .62506 .29755 Mtetra
.058 .569 .88 r
.62506 .29755 .62835 .29935 .63526 .30069 .63198 .29886 Mtetra
.046 .558 .875 r
.63198 .29886 .63526 .30069 .64221 .30213 .63894 .30027 Mtetra
.035 .548 .871 r
.63894 .30027 .64221 .30213 .6492 .30368 .64594 .30178 Mtetra
.025 .539 .867 r
.64594 .30178 .6492 .30368 .65622 .30532 .65297 .30338 Mtetra
.017 .531 .864 r
.65297 .30338 .65622 .30532 .66328 .30704 .66004 .30508 Mtetra
.01 .523 .862 r
.66004 .30508 .66328 .30704 .67038 .30886 .66716 .30685 Mtetra
.005 .517 .86 r
.66716 .30685 .67038 .30886 .67753 .31075 .67431 .30871 Mtetra
0 .512 .859 r
.67431 .30871 .67753 .31075 .68471 .31272 .6815 .31063 Mtetra
0 .507 .858 r
.6815 .31063 .68471 .31272 .69193 .31475 .68874 .31262 Mtetra
0 .504 .859 r
.68874 .31262 .69193 .31475 .69919 .31684 .69601 .31467 Mtetra
0 .502 .86 r
.69601 .31467 .69919 .31684 .7065 .31898 .70332 .31677 Mtetra
0 .5 .861 r
.70332 .31677 .7065 .31898 .71384 .32117 .71068 .31891 Mtetra
.002 .5 .864 r
.71068 .31891 .71384 .32117 .72123 .32339 .71808 .32109 Mtetra
.006 .501 .867 r
.71808 .32109 .72123 .32339 .72865 .32565 .72552 .3233 Mtetra
.012 .502 .87 r
.72552 .3233 .72865 .32565 .73612 .32792 .73299 .32552 Mtetra
.02 .505 .875 r
.73299 .32552 .73612 .32792 .74363 .33021 .74051 .32775 Mtetra
.029 .509 .879 r
.74051 .32775 .74363 .33021 .75118 .33249 .74807 .32999 Mtetra
.04 .513 .885 r
.74807 .32999 .75118 .33249 .75877 .33477 .75567 .33221 Mtetra
.052 .519 .891 r
.75567 .33221 .75877 .33477 .7664 .33704 .76331 .33442 Mtetra
.065 .526 .897 r
.76331 .33442 .7664 .33704 .77407 .33927 .77099 .33659 Mtetra
.08 .533 .903 r
.77099 .33659 .77407 .33927 .78178 .34147 .77871 .33873 Mtetra
.097 .541 .91 r
.77871 .33873 .78178 .34147 .78952 .34361 .78646 .34081 Mtetra
.115 .55 .917 r
.78646 .34081 .78952 .34361 .7973 .3457 .79425 .34283 Mtetra
.134 .56 .924 r
.79425 .34283 .7973 .3457 .80512 .34771 .80207 .34477 Mtetra
.155 .57 .931 r
.80207 .34477 .80512 .34771 .81296 .34963 .80993 .34663 Mtetra
.837 .84 .848 r
.14818 .55717 .15255 .55925 .15889 .5533 .15452 .55127 Mtetra
.84 .842 .846 r
.15452 .55127 .15889 .5533 .16523 .54725 .16087 .54527 Mtetra
.843 .845 .845 r
.16087 .54527 .16523 .54725 .17157 .54112 .16722 .53919 Mtetra
.846 .847 .844 r
.16722 .53919 .17157 .54112 .17793 .53493 .17359 .53304 Mtetra
.848 .85 .844 r
.17359 .53304 .17793 .53493 .18429 .52867 .17996 .52683 Mtetra
.85 .852 .843 r
.17996 .52683 .18429 .52867 .19065 .52237 .18633 .52057 Mtetra
.852 .854 .843 r
.18633 .52057 .19065 .52237 .19701 .51602 .19271 .51427 Mtetra
.854 .857 .843 r
.19271 .51427 .19701 .51602 .20338 .50965 .19909 .50794 Mtetra
.855 .859 .844 r
.19909 .50794 .20338 .50965 .20974 .50327 .20546 .50159 Mtetra
.856 .862 .844 r
.20546 .50159 .20974 .50327 .21611 .49687 .21184 .49523 Mtetra
.857 .865 .845 r
.21184 .49523 .21611 .49687 .22247 .49047 .21821 .48886 Mtetra
.858 .867 .846 r
.21821 .48886 .22247 .49047 .22882 .48409 .22458 .48251 Mtetra
.858 .87 .847 r
.22458 .48251 .22882 .48409 .23518 .47772 .23095 .47617 Mtetra
.858 .872 .848 r
.23095 .47617 .23518 .47772 .24153 .47137 .23732 .46985 Mtetra
.858 .875 .85 r
.23732 .46985 .24153 .47137 .24787 .46506 .24368 .46357 Mtetra
.858 .878 .852 r
.24368 .46357 .24787 .46506 .25421 .45879 .25003 .45732 Mtetra
.858 .881 .854 r
.25003 .45732 .25421 .45879 .26055 .45256 .25638 .45112 Mtetra
.857 .883 .856 r
.25638 .45112 .26055 .45256 .26688 .44639 .26272 .44498 Mtetra
.856 .886 .859 r
.26272 .44498 .26688 .44639 .2732 .44028 .26906 .43889 Mtetra
.855 .889 .861 r
.26906 .43889 .2732 .44028 .27951 .43424 .27539 .43287 Mtetra
.853 .892 .864 r
.27539 .43287 .27951 .43424 .28582 .42827 .28172 .42692 Mtetra
.852 .895 .867 r
.28172 .42692 .28582 .42827 .29213 .42238 .28804 .42105 Mtetra
.85 .897 .87 r
.28804 .42105 .29213 .42238 .29842 .41657 .29435 .41526 Mtetra
.847 .9 .874 r
.29435 .41526 .29842 .41657 .30471 .41086 .30066 .40956 Mtetra
.845 .903 .877 r
.30066 .40956 .30471 .41086 .311 .40524 .30696 .40396 Mtetra
.842 .906 .881 r
.30696 .40396 .311 .40524 .31728 .39972 .31325 .39845 Mtetra
.838 .909 .885 r
.31325 .39845 .31728 .39972 .32355 .3943 .31954 .39305 Mtetra
.834 .911 .889 r
.31954 .39305 .32355 .3943 .32982 .389 .32582 .38776 Mtetra
.83 .914 .894 r
.32582 .38776 .32982 .389 .33608 .3838 .3321 .38257 Mtetra
.826 .917 .898 r
.3321 .38257 .33608 .3838 .34234 .37872 .33838 .3775 Mtetra
.821 .919 .903 r
.33838 .3775 .34234 .37872 .34859 .37377 .34465 .37256 Mtetra
.815 .921 .908 r
.34465 .37256 .34859 .37377 .35485 .36893 .35092 .36773 Mtetra
.809 .923 .912 r
.35092 .36773 .35485 .36893 .36109 .36423 .35718 .36303 Mtetra
.802 .925 .917 r
.35718 .36303 .36109 .36423 .36734 .35965 .36344 .35846 Mtetra
.795 .927 .922 r
.36344 .35846 .36734 .35965 .37358 .35521 .3697 .35402 Mtetra
.787 .929 .928 r
.3697 .35402 .37358 .35521 .37982 .3509 .37596 .34972 Mtetra
.779 .93 .933 r
.37596 .34972 .37982 .3509 .38607 .34674 .38222 .34556 Mtetra
.769 .931 .938 r
.38222 .34556 .38607 .34674 .39231 .34271 .38847 .34153 Mtetra
.759 .931 .943 r
.38847 .34153 .39231 .34271 .39855 .33882 .39473 .33765 Mtetra
.748 .931 .948 r
.39473 .33765 .39855 .33882 .4048 .33509 .401 .33391 Mtetra
.737 .931 .953 r
.401 .33391 .4048 .33509 .41104 .33149 .40726 .33032 Mtetra
.724 .93 .958 r
.40726 .33032 .41104 .33149 .4173 .32805 .41353 .32687 Mtetra
.711 .929 .963 r
.41353 .32687 .4173 .32805 .42355 .32475 .4198 .32358 Mtetra
.697 .927 .967 r
.4198 .32358 .42355 .32475 .42981 .32161 .42607 .32043 Mtetra
.682 .924 .971 r
.42607 .32043 .42981 .32161 .43608 .31862 .43236 .31743 Mtetra
.665 .921 .975 r
.43236 .31743 .43608 .31862 .44235 .31578 .43865 .31459 Mtetra
.648 .917 .978 r
.43865 .31459 .44235 .31578 .44864 .3131 .44494 .3119 Mtetra
.63 .912 .981 r
.44494 .3119 .44864 .3131 .45493 .31057 .45125 .30937 Mtetra
.611 .907 .984 r
.45125 .30937 .45493 .31057 .46123 .3082 .45757 .30699 Mtetra
.591 .9 .986 r
.45757 .30699 .46123 .3082 .46754 .30598 .4639 .30476 Mtetra
.57 .893 .987 r
.4639 .30476 .46754 .30598 .47387 .30392 .47024 .30269 Mtetra
.549 .884 .987 r
.47024 .30269 .47387 .30392 .4802 .30201 .47659 .30078 Mtetra
.526 .875 .987 r
.47659 .30078 .4802 .30201 .48656 .30026 .48295 .29902 Mtetra
.503 .865 .987 r
.48295 .29902 .48656 .30026 .49292 .29867 .48934 .29741 Mtetra
.479 .854 .985 r
.48934 .29741 .49292 .29867 .49931 .29723 .49573 .29596 Mtetra
.455 .842 .983 r
.49573 .29596 .49931 .29723 .50571 .29595 .50215 .29466 Mtetra
.43 .83 .98 r
.50215 .29466 .50571 .29595 .51213 .29482 .50858 .29352 Mtetra
.405 .816 .976 r
.50858 .29352 .51213 .29482 .51856 .29384 .51503 .29252 Mtetra
.379 .802 .972 r
.51503 .29252 .51856 .29384 .52502 .29301 .52151 .29168 Mtetra
.354 .787 .967 r
.52151 .29168 .52502 .29301 .5315 .29234 .528 .29099 Mtetra
.328 .772 .962 r
.528 .29099 .5315 .29234 .538 .29181 .53452 .29044 Mtetra
.303 .757 .956 r
.53452 .29044 .538 .29181 .54453 .29143 .54106 .29005 Mtetra
.278 .741 .949 r
.54106 .29005 .54453 .29143 .55108 .2912 .54762 .28979 Mtetra
.254 .725 .942 r
.54762 .28979 .55108 .2912 .55766 .29111 .55421 .28968 Mtetra
.23 .709 .935 r
.55421 .28968 .55766 .29111 .56426 .29116 .56083 .28971 Mtetra
.207 .693 .928 r
.56083 .28971 .56426 .29116 .57089 .29135 .56747 .28988 Mtetra
.185 .677 .921 r
.56747 .28988 .57089 .29135 .57755 .29168 .57415 .29019 Mtetra
.163 .661 .913 r
.57415 .29019 .57755 .29168 .58424 .29214 .58085 .29063 Mtetra
.143 .646 .906 r
.58085 .29063 .58424 .29214 .59096 .29274 .58758 .29119 Mtetra
.123 .631 .899 r
.58758 .29119 .59096 .29274 .59771 .29346 .59435 .29189 Mtetra
.105 .617 .892 r
.59435 .29189 .59771 .29346 .6045 .2943 .60115 .29271 Mtetra
.088 .603 .886 r
.60115 .29271 .6045 .2943 .61132 .29527 .60798 .29364 Mtetra
.072 .59 .88 r
.60798 .29364 .61132 .29527 .61817 .29636 .61484 .2947 Mtetra
.058 .577 .874 r
.61484 .2947 .61817 .29636 .62506 .29755 .62174 .29586 Mtetra
.044 .566 .869 r
.62174 .29586 .62506 .29755 .63198 .29886 .62868 .29714 Mtetra
.033 .555 .864 r
.62868 .29714 .63198 .29886 .63894 .30027 .63565 .29852 Mtetra
.022 .545 .86 r
.63565 .29852 .63894 .30027 .64594 .30178 .64266 .29999 Mtetra
.013 .536 .857 r
.64266 .29999 .64594 .30178 .65297 .30338 .64971 .30156 Mtetra
.005 .528 .854 r
.64971 .30156 .65297 .30338 .66004 .30508 .65679 .30321 Mtetra
0 .521 .852 r
.65679 .30321 .66004 .30508 .66716 .30685 .66392 .30495 Mtetra
0 .515 .851 r
.66392 .30495 .66716 .30685 .67431 .30871 .67108 .30677 Mtetra
0 .51 .85 r
.67108 .30677 .67431 .30871 .6815 .31063 .67828 .30865 Mtetra
0 .506 .85 r
.67828 .30865 .6815 .31063 .68874 .31262 .68553 .3106 Mtetra
0 .503 .851 r
.68553 .3106 .68874 .31262 .69601 .31467 .69281 .3126 Mtetra
0 .501 .853 r
.69281 .3126 .69601 .31467 .70332 .31677 .70014 .31465 Mtetra
0 .5 .855 r
.70014 .31465 .70332 .31677 .71068 .31891 .70751 .31675 Mtetra
0 .5 .858 r
.70751 .31675 .71068 .31891 .71808 .32109 .71491 .31887 Mtetra
0 .501 .862 r
.71491 .31887 .71808 .32109 .72552 .3233 .72236 .32103 Mtetra
.007 .504 .866 r
.72236 .32103 .72552 .3233 .73299 .32552 .72985 .3232 Mtetra
.015 .507 .871 r
.72985 .3232 .73299 .32552 .74051 .32775 .73738 .32538 Mtetra
.025 .511 .876 r
.73738 .32538 .74051 .32775 .74807 .32999 .74495 .32755 Mtetra
.036 .516 .882 r
.74495 .32755 .74807 .32999 .75567 .33221 .75256 .32972 Mtetra
.049 .522 .889 r
.75256 .32972 .75567 .33221 .76331 .33442 .76021 .33186 Mtetra
.063 .529 .896 r
.76021 .33186 .76331 .33442 .77099 .33659 .7679 .33398 Mtetra
.079 .537 .903 r
.7679 .33398 .77099 .33659 .77871 .33873 .77562 .33605 Mtetra
.096 .545 .91 r
.77562 .33605 .77871 .33873 .78646 .34081 .78339 .33806 Mtetra
.115 .555 .918 r
.78339 .33806 .78646 .34081 .79425 .34283 .79118 .34001 Mtetra
.135 .565 .925 r
.79118 .34001 .79425 .34283 .80207 .34477 .79901 .34189 Mtetra
.156 .576 .932 r
.79901 .34189 .80207 .34477 .80993 .34663 .80688 .34367 Mtetra
.836 .843 .851 r
.14377 .55514 .14818 .55717 .15452 .55127 .15012 .54929 Mtetra
.84 .846 .85 r
.15012 .54929 .15452 .55127 .16087 .54527 .15648 .54334 Mtetra
.843 .848 .848 r
.15648 .54334 .16087 .54527 .16722 .53919 .16285 .53732 Mtetra
.845 .851 .847 r
.16285 .53732 .16722 .53919 .17359 .53304 .16922 .53121 Mtetra
.848 .853 .847 r
.16922 .53121 .17359 .53304 .17996 .52683 .1756 .52505 Mtetra
.85 .856 .846 r
.1756 .52505 .17996 .52683 .18633 .52057 .18199 .51883 Mtetra
.852 .859 .846 r
.18199 .51883 .18633 .52057 .19271 .51427 .18837 .51258 Mtetra
.853 .861 .846 r
.18837 .51258 .19271 .51427 .19909 .50794 .19476 .50629 Mtetra
.855 .864 .847 r
.19476 .50629 .19909 .50794 .20546 .50159 .20115 .49998 Mtetra
.856 .867 .847 r
.20115 .49998 .20546 .50159 .21184 .49523 .20754 .49366 Mtetra
.857 .869 .848 r
.20754 .49366 .21184 .49523 .21821 .48886 .21393 .48733 Mtetra
.858 .872 .849 r
.21393 .48733 .21821 .48886 .22458 .48251 .22031 .48101 Mtetra
.858 .875 .85 r
.22031 .48101 .22458 .48251 .23095 .47617 .2267 .47471 Mtetra
.858 .878 .851 r
.2267 .47471 .23095 .47617 .23732 .46985 .23307 .46842 Mtetra
.859 .881 .853 r
.23307 .46842 .23732 .46985 .24368 .46357 .23945 .46217 Mtetra
.858 .883 .855 r
.23945 .46217 .24368 .46357 .25003 .45732 .24582 .45595 Mtetra
.858 .886 .857 r
.24582 .45595 .25003 .45732 .25638 .45112 .25218 .44978 Mtetra
.857 .889 .859 r
.25218 .44978 .25638 .45112 .26272 .44498 .25854 .44366 Mtetra
.856 .892 .861 r
.25854 .44366 .26272 .44498 .26906 .43889 .26489 .4376 Mtetra
.855 .895 .864 r
.26489 .4376 .26906 .43889 .27539 .43287 .27124 .4316 Mtetra
.853 .898 .867 r
.27124 .4316 .27539 .43287 .28172 .42692 .27758 .42568 Mtetra
.852 .901 .87 r
.27758 .42568 .28172 .42692 .28804 .42105 .28392 .41983 Mtetra
.85 .904 .873 r
.28392 .41983 .28804 .42105 .29435 .41526 .29024 .41406 Mtetra
.847 .907 .876 r
.29024 .41406 .29435 .41526 .30066 .40956 .29657 .40838 Mtetra
.844 .91 .88 r
.29657 .40838 .30066 .40956 .30696 .40396 .30288 .40279 Mtetra
.841 .913 .884 r
.30288 .40279 .30696 .40396 .31325 .39845 .30919 .3973 Mtetra
.838 .916 .888 r
.30919 .3973 .31325 .39845 .31954 .39305 .3155 .39191 Mtetra
.834 .918 .892 r
.3155 .39191 .31954 .39305 .32582 .38776 .3218 .38663 Mtetra
.829 .921 .896 r
.3218 .38663 .32582 .38776 .3321 .38257 .32809 .38146 Mtetra
.825 .924 .901 r
.32809 .38146 .3321 .38257 .33838 .3775 .33438 .3764 Mtetra
.819 .926 .905 r
.33438 .3764 .33838 .3775 .34465 .37256 .34067 .37146 Mtetra
.814 .928 .91 r
.34067 .37146 .34465 .37256 .35092 .36773 .34695 .36665 Mtetra
.807 .931 .915 r
.34695 .36665 .35092 .36773 .35718 .36303 .35323 .36196 Mtetra
.8 .933 .919 r
.35323 .36196 .35718 .36303 .36344 .35846 .35951 .35739 Mtetra
.793 .934 .924 r
.35951 .35739 .36344 .35846 .3697 .35402 .36579 .35296 Mtetra
.784 .936 .929 r
.36579 .35296 .3697 .35402 .37596 .34972 .37206 .34866 Mtetra
.775 .937 .934 r
.37206 .34866 .37596 .34972 .38222 .34556 .37834 .3445 Mtetra
.766 .938 .939 r
.37834 .3445 .38222 .34556 .38847 .34153 .38461 .34048 Mtetra
.755 .938 .944 r
.38461 .34048 .38847 .34153 .39473 .33765 .39089 .3366 Mtetra
.744 .938 .949 r
.39089 .3366 .39473 .33765 .401 .33391 .39717 .33286 Mtetra
.732 .938 .954 r
.39717 .33286 .401 .33391 .40726 .33032 .40344 .32927 Mtetra
.719 .937 .958 r
.40344 .32927 .40726 .33032 .41353 .32687 .40973 .32582 Mtetra
.705 .935 .963 r
.40973 .32582 .41353 .32687 .4198 .32358 .41602 .32252 Mtetra
.69 .933 .967 r
.41602 .32252 .4198 .32358 .42607 .32043 .42231 .31938 Mtetra
.674 .93 .97 r
.42231 .31938 .42607 .32043 .43236 .31743 .42861 .31638 Mtetra
.658 .926 .974 r
.42861 .31638 .43236 .31743 .43865 .31459 .43491 .31353 Mtetra
.64 .922 .976 r
.43491 .31353 .43865 .31459 .44494 .3119 .44123 .31084 Mtetra
.621 .917 .979 r
.44123 .31084 .44494 .3119 .45125 .30937 .44755 .30829 Mtetra
.601 .91 .981 r
.44755 .30829 .45125 .30937 .45757 .30699 .45388 .30591 Mtetra
.581 .903 .982 r
.45388 .30591 .45757 .30699 .4639 .30476 .46022 .30367 Mtetra
.559 .895 .983 r
.46022 .30367 .4639 .30476 .47024 .30269 .46658 .30159 Mtetra
.537 .886 .983 r
.46658 .30159 .47024 .30269 .47659 .30078 .47295 .29967 Mtetra
.514 .877 .982 r
.47295 .29967 .47659 .30078 .48295 .29902 .47933 .2979 Mtetra
.49 .866 .98 r
.47933 .2979 .48295 .29902 .48934 .29741 .48573 .29628 Mtetra
.465 .854 .978 r
.48573 .29628 .48934 .29741 .49573 .29596 .49214 .29481 Mtetra
.44 .842 .975 r
.49214 .29481 .49573 .29596 .50215 .29466 .49857 .2935 Mtetra
.415 .829 .972 r
.49857 .2935 .50215 .29466 .50858 .29352 .50502 .29234 Mtetra
.389 .815 .967 r
.50502 .29234 .50858 .29352 .51503 .29252 .51148 .29134 Mtetra
.364 .8 .962 r
.51148 .29134 .51503 .29252 .52151 .29168 .51797 .29048 Mtetra
.338 .785 .957 r
.51797 .29048 .52151 .29168 .528 .29099 .52448 .28977 Mtetra
.312 .769 .951 r
.52448 .28977 .528 .29099 .53452 .29044 .53101 .2892 Mtetra
.287 .753 .944 r
.53101 .2892 .53452 .29044 .54106 .29005 .53756 .28879 Mtetra
.262 .737 .938 r
.53756 .28879 .54106 .29005 .54762 .28979 .54414 .28851 Mtetra
.238 .721 .93 r
.54414 .28851 .54762 .28979 .55421 .28968 .55075 .28838 Mtetra
.214 .705 .923 r
.55075 .28838 .55421 .28968 .56083 .28971 .55738 .28839 Mtetra
.191 .688 .916 r
.55738 .28839 .56083 .28971 .56747 .28988 .56404 .28854 Mtetra
.169 .672 .908 r
.56404 .28854 .56747 .28988 .57415 .29019 .57072 .28882 Mtetra
.148 .657 .901 r
.57072 .28882 .57415 .29019 .58085 .29063 .57744 .28923 Mtetra
.127 .641 .893 r
.57744 .28923 .58085 .29063 .58758 .29119 .58419 .28977 Mtetra
.108 .626 .886 r
.58419 .28977 .58758 .29119 .59435 .29189 .59097 .29044 Mtetra
.091 .612 .88 r
.59097 .29044 .59435 .29189 .60115 .29271 .59778 .29122 Mtetra
.074 .598 .873 r
.59778 .29122 .60115 .29271 .60798 .29364 .60462 .29213 Mtetra
.058 .585 .867 r
.60462 .29213 .60798 .29364 .61484 .2947 .6115 .29315 Mtetra
.044 .573 .862 r
.6115 .29315 .61484 .2947 .62174 .29586 .61841 .29429 Mtetra
.032 .562 .857 r
.61841 .29429 .62174 .29586 .62868 .29714 .62536 .29553 Mtetra
.02 .552 .853 r
.62536 .29553 .62868 .29714 .63565 .29852 .63234 .29687 Mtetra
.01 .542 .849 r
.63234 .29687 .63565 .29852 .64266 .29999 .63936 .29831 Mtetra
.001 .533 .846 r
.63936 .29831 .64266 .29999 .64971 .30156 .64642 .29984 Mtetra
0 .526 .844 r
.64642 .29984 .64971 .30156 .65679 .30321 .65352 .30145 Mtetra
0 .519 .843 r
.65352 .30145 .65679 .30321 .66392 .30495 .66066 .30315 Mtetra
0 .513 .842 r
.66066 .30315 .66392 .30495 .67108 .30677 .66784 .30492 Mtetra
0 .509 .842 r
.66784 .30492 .67108 .30677 .67828 .30865 .67505 .30676 Mtetra
0 .505 .843 r
.67505 .30676 .67828 .30865 .68553 .3106 .68231 .30866 Mtetra
0 .502 .844 r
.68231 .30866 .68553 .3106 .69281 .3126 .6896 .31062 Mtetra
0 .501 .846 r
.6896 .31062 .69281 .3126 .70014 .31465 .69694 .31262 Mtetra
0 .5 .849 r
.69694 .31262 .70014 .31465 .70751 .31675 .70432 .31466 Mtetra
0 .501 .853 r
.70432 .31466 .70751 .31675 .71491 .31887 .71174 .31674 Mtetra
0 .503 .857 r
.71174 .31674 .71491 .31887 .72236 .32103 .7192 .31884 Mtetra
.002 .505 .862 r
.7192 .31884 .72236 .32103 .72985 .3232 .7267 .32095 Mtetra
.011 .509 .868 r
.7267 .32095 .72985 .3232 .73738 .32538 .73424 .32307 Mtetra
.021 .514 .874 r
.73424 .32307 .73738 .32538 .74495 .32755 .74182 .32519 Mtetra
.033 .519 .88 r
.74182 .32519 .74495 .32755 .75256 .32972 .74944 .32729 Mtetra
.047 .526 .887 r
.74944 .32729 .75256 .32972 .76021 .33186 .7571 .32937 Mtetra
.062 .533 .895 r
.7571 .32937 .76021 .33186 .7679 .33398 .76479 .33142 Mtetra
.078 .541 .902 r
.76479 .33142 .7679 .33398 .77562 .33605 .77253 .33342 Mtetra
.096 .55 .91 r
.77253 .33342 .77562 .33605 .78339 .33806 .7803 .33537 Mtetra
.116 .56 .918 r
.7803 .33537 .78339 .33806 .79118 .34001 .78811 .33725 Mtetra
.137 .57 .926 r
.78811 .33725 .79118 .34001 .79901 .34189 .79595 .33904 Mtetra
.159 .582 .934 r
.79595 .33904 .79901 .34189 .80688 .34367 .80382 .34075 Mtetra
.835 .846 .854 r
.13933 .55314 .14377 .55514 .15012 .54929 .14569 .54735 Mtetra
.839 .849 .853 r
.14569 .54735 .15012 .54929 .15648 .54334 .15206 .54146 Mtetra
.842 .852 .851 r
.15206 .54146 .15648 .54334 .16285 .53732 .15844 .53549 Mtetra
.845 .855 .851 r
.15844 .53549 .16285 .53732 .16922 .53121 .16482 .52944 Mtetra
.847 .857 .85 r
.16482 .52944 .16922 .53121 .1756 .52505 .17121 .52333 Mtetra
.85 .86 .85 r
.17121 .52333 .1756 .52505 .18199 .51883 .17761 .51716 Mtetra
.851 .863 .849 r
.17761 .51716 .18199 .51883 .18837 .51258 .18401 .51095 Mtetra
.853 .866 .849 r
.18401 .51095 .18837 .51258 .19476 .50629 .19041 .50471 Mtetra
.855 .868 .85 r
.19041 .50471 .19476 .50629 .20115 .49998 .19681 .49844 Mtetra
.856 .871 .85 r
.19681 .49844 .20115 .49998 .20754 .49366 .20321 .49216 Mtetra
.857 .874 .851 r
.20321 .49216 .20754 .49366 .21393 .48733 .20961 .48588 Mtetra
.858 .877 .852 r
.20961 .48588 .21393 .48733 .22031 .48101 .21601 .4796 Mtetra
.858 .88 .853 r
.21601 .4796 .22031 .48101 .2267 .47471 .22241 .47333 Mtetra
.858 .883 .854 r
.22241 .47333 .2267 .47471 .23307 .46842 .2288 .46708 Mtetra
.859 .886 .856 r
.2288 .46708 .23307 .46842 .23945 .46217 .23519 .46086 Mtetra
.858 .889 .858 r
.23519 .46086 .23945 .46217 .24582 .45595 .24157 .45467 Mtetra
.858 .892 .86 r
.24157 .45467 .24582 .45595 .25218 .44978 .24795 .44853 Mtetra
.857 .895 .862 r
.24795 .44853 .25218 .44978 .25854 .44366 .25432 .44244 Mtetra
.856 .898 .864 r
.25432 .44244 .25854 .44366 .26489 .4376 .26069 .43641 Mtetra
.855 .901 .867 r
.26069 .43641 .26489 .4376 .27124 .4316 .26705 .43043 Mtetra
.853 .904 .87 r
.26705 .43043 .27124 .4316 .27758 .42568 .27341 .42453 Mtetra
.851 .907 .873 r
.27341 .42453 .27758 .42568 .28392 .41983 .27976 .4187 Mtetra
.849 .91 .876 r
.27976 .4187 .28392 .41983 .29024 .41406 .28611 .41296 Mtetra
.847 .913 .879 r
.28611 .41296 .29024 .41406 .29657 .40838 .29244 .4073 Mtetra
.844 .916 .883 r
.29244 .4073 .29657 .40838 .30288 .40279 .29878 .40173 Mtetra
.841 .919 .886 r
.29878 .40173 .30288 .40279 .30919 .3973 .3051 .39626 Mtetra
.837 .922 .89 r
.3051 .39626 .30919 .3973 .3155 .39191 .31142 .39088 Mtetra
.833 .925 .894 r
.31142 .39088 .3155 .39191 .3218 .38663 .31774 .38562 Mtetra
.828 .928 .898 r
.31774 .38562 .3218 .38663 .32809 .38146 .32405 .38046 Mtetra
.823 .93 .903 r
.32405 .38046 .32809 .38146 .33438 .3764 .33036 .37541 Mtetra
.818 .933 .907 r
.33036 .37541 .33438 .3764 .34067 .37146 .33666 .37049 Mtetra
.812 .935 .912 r
.33666 .37049 .34067 .37146 .34695 .36665 .34296 .36568 Mtetra
.805 .937 .916 r
.34296 .36568 .34695 .36665 .35323 .36196 .34926 .361 Mtetra
.798 .939 .921 r
.34926 .361 .35323 .36196 .35951 .35739 .35555 .35644 Mtetra
.79 .941 .926 r
.35555 .35644 .35951 .35739 .36579 .35296 .36185 .35202 Mtetra
.781 .942 .931 r
.36185 .35202 .36579 .35296 .37206 .34866 .36814 .34773 Mtetra
.772 .944 .935 r
.36814 .34773 .37206 .34866 .37834 .3445 .37443 .34357 Mtetra
.762 .944 .94 r
.37443 .34357 .37834 .3445 .38461 .34048 .38072 .33955 Mtetra
.751 .944 .945 r
.38072 .33955 .38461 .34048 .39089 .3366 .38701 .33567 Mtetra
.739 .944 .949 r
.38701 .33567 .39089 .3366 .39717 .33286 .39331 .33194 Mtetra
.726 .944 .954 r
.39331 .33194 .39717 .33286 .40344 .32927 .3996 .32835 Mtetra
.713 .942 .958 r
.3996 .32835 .40344 .32927 .40973 .32582 .4059 .3249 Mtetra
.698 .94 .962 r
.4059 .3249 .40973 .32582 .41602 .32252 .41221 .3216 Mtetra
.683 .938 .965 r
.41221 .3216 .41602 .32252 .42231 .31938 .41851 .31845 Mtetra
.666 .934 .968 r
.41851 .31845 .42231 .31938 .42861 .31638 .42483 .31545 Mtetra
.649 .93 .971 r
.42483 .31545 .42861 .31638 .43491 .31353 .43115 .31259 Mtetra
.63 .925 .974 r
.43115 .31259 .43491 .31353 .44123 .31084 .43748 .3099 Mtetra
.611 .92 .975 r
.43748 .3099 .44123 .31084 .44755 .30829 .44382 .30735 Mtetra
.591 .913 .977 r
.44382 .30735 .44755 .30829 .45388 .30591 .45017 .30495 Mtetra
.569 .905 .977 r
.45017 .30495 .45388 .30591 .46022 .30367 .45653 .30271 Mtetra
.547 .897 .977 r
.45653 .30271 .46022 .30367 .46658 .30159 .4629 .30062 Mtetra
.524 .887 .976 r
.4629 .30062 .46658 .30159 .47295 .29967 .46928 .29869 Mtetra
.5 .877 .975 r
.46928 .29869 .47295 .29967 .47933 .2979 .47568 .2969 Mtetra
.476 .866 .973 r
.47568 .2969 .47933 .2979 .48573 .29628 .48209 .29527 Mtetra
.451 .854 .97 r
.48209 .29527 .48573 .29628 .49214 .29481 .48852 .2938 Mtetra
.426 .841 .966 r
.48852 .2938 .49214 .29481 .49857 .2935 .49496 .29247 Mtetra
.4 .827 .962 r
.49496 .29247 .49857 .2935 .50502 .29234 .50143 .2913 Mtetra
.374 .812 .957 r
.50143 .2913 .50502 .29234 .51148 .29134 .50791 .29027 Mtetra
.348 .797 .952 r
.50791 .29027 .51148 .29134 .51797 .29048 .51441 .2894 Mtetra
.322 .782 .946 r
.51441 .2894 .51797 .29048 .52448 .28977 .52093 .28867 Mtetra
.296 .766 .939 r
.52093 .28867 .52448 .28977 .53101 .2892 .52748 .28809 Mtetra
.271 .749 .932 r
.52748 .28809 .53101 .2892 .53756 .28879 .53405 .28765 Mtetra
.246 .733 .925 r
.53405 .28765 .53756 .28879 .54414 .28851 .54064 .28735 Mtetra
.222 .716 .918 r
.54064 .28735 .54414 .28851 .55075 .28838 .54726 .2872 Mtetra
.198 .7 .91 r
.54726 .2872 .55075 .28838 .55738 .28839 .55391 .28719 Mtetra
.175 .683 .902 r
.55391 .28719 .55738 .28839 .56404 .28854 .56058 .28731 Mtetra
.153 .667 .895 r
.56058 .28731 .56404 .28854 .57072 .28882 .56728 .28756 Mtetra
.133 .652 .887 r
.56728 .28756 .57072 .28882 .57744 .28923 .57401 .28794 Mtetra
.113 .636 .88 r
.57401 .28794 .57744 .28923 .58419 .28977 .58077 .28846 Mtetra
.094 .622 .873 r
.58077 .28846 .58419 .28977 .59097 .29044 .58756 .28909 Mtetra
.077 .607 .867 r
.58756 .28909 .59097 .29044 .59778 .29122 .59439 .28985 Mtetra
.06 .594 .86 r
.59439 .28985 .59778 .29122 .60462 .29213 .60124 .29073 Mtetra
.046 .581 .855 r
.60124 .29073 .60462 .29213 .6115 .29315 .60814 .29172 Mtetra
.032 .569 .85 r
.60814 .29172 .6115 .29315 .61841 .29429 .61506 .29282 Mtetra
.02 .558 .845 r
.61506 .29282 .61841 .29429 .62536 .29553 .62202 .29402 Mtetra
.009 .548 .841 r
.62202 .29402 .62536 .29553 .63234 .29687 .62902 .29532 Mtetra
0 .539 .838 r
.62902 .29532 .63234 .29687 .63936 .29831 .63606 .29672 Mtetra
0 .531 .836 r
.63606 .29672 .63936 .29831 .64642 .29984 .64313 .29821 Mtetra
0 .523 .834 r
.64313 .29821 .64642 .29984 .65352 .30145 .65024 .29979 Mtetra
0 .517 .833 r
.65024 .29979 .65352 .30145 .66066 .30315 .65739 .30144 Mtetra
0 .512 .833 r
.65739 .30144 .66066 .30315 .66784 .30492 .66457 .30317 Mtetra
0 .508 .834 r
.66457 .30317 .66784 .30492 .67505 .30676 .6718 .30496 Mtetra
0 .504 .835 r
.6718 .30496 .67505 .30676 .68231 .30866 .67907 .30681 Mtetra
0 .502 .837 r
.67907 .30681 .68231 .30866 .6896 .31062 .68638 .30872 Mtetra
0 .501 .84 r
.68638 .30872 .6896 .31062 .69694 .31262 .69373 .31067 Mtetra
0 .501 .843 r
.69373 .31067 .69694 .31262 .70432 .31466 .70112 .31266 Mtetra
0 .502 .848 r
.70112 .31266 .70432 .31466 .71174 .31674 .70855 .31468 Mtetra
0 .504 .853 r
.70855 .31468 .71174 .31674 .7192 .31884 .71602 .31672 Mtetra
0 .507 .858 r
.71602 .31672 .7192 .31884 .7267 .32095 .72353 .31878 Mtetra
.008 .512 .864 r
.72353 .31878 .7267 .32095 .73424 .32307 .73108 .32083 Mtetra
.019 .517 .871 r
.73108 .32083 .73424 .32307 .74182 .32519 .73867 .32289 Mtetra
.032 .523 .878 r
.73867 .32289 .74182 .32519 .74944 .32729 .7463 .32493 Mtetra
.046 .53 .886 r
.7463 .32493 .74944 .32729 .7571 .32937 .75397 .32694 Mtetra
.062 .537 .894 r
.75397 .32694 .7571 .32937 .76479 .33142 .76168 .32892 Mtetra
.079 .546 .902 r
.76168 .32892 .76479 .33142 .77253 .33342 .76942 .33085 Mtetra
.098 .556 .911 r
.76942 .33085 .77253 .33342 .7803 .33537 .7772 .33272 Mtetra
.118 .566 .919 r
.7772 .33272 .7803 .33537 .78811 .33725 .78501 .33452 Mtetra
.14 .577 .927 r
.78501 .33452 .78811 .33725 .79595 .33904 .79286 .33624 Mtetra
.163 .588 .935 r
.79286 .33624 .79595 .33904 .80382 .34075 .80074 .33787 Mtetra
.834 .849 .857 r
.13487 .55118 .13933 .55314 .14569 .54735 .14124 .54545 Mtetra
.838 .852 .856 r
.14124 .54545 .14569 .54735 .15206 .54146 .14761 .53962 Mtetra
.841 .855 .855 r
.14761 .53962 .15206 .54146 .15844 .53549 .154 .53371 Mtetra
.844 .858 .854 r
.154 .53371 .15844 .53549 .16482 .52944 .16039 .52772 Mtetra
.847 .861 .853 r
.16039 .52772 .16482 .52944 .17121 .52333 .16679 .52166 Mtetra
.849 .864 .853 r
.16679 .52166 .17121 .52333 .17761 .51716 .1732 .51555 Mtetra
.851 .867 .852 r
.1732 .51555 .17761 .51716 .18401 .51095 .17961 .50939 Mtetra
.853 .87 .852 r
.17961 .50939 .18401 .51095 .19041 .50471 .18602 .50319 Mtetra
.854 .873 .853 r
.18602 .50319 .19041 .50471 .19681 .49844 .19244 .49697 Mtetra
.856 .876 .853 r
.19244 .49697 .19681 .49844 .20321 .49216 .19885 .49074 Mtetra
.857 .879 .854 r
.19885 .49074 .20321 .49216 .20961 .48588 .20526 .4845 Mtetra
.857 .882 .855 r
.20526 .4845 .20961 .48588 .21601 .4796 .21168 .47826 Mtetra
.858 .885 .856 r
.21168 .47826 .21601 .4796 .22241 .47333 .21808 .47203 Mtetra
.858 .888 .857 r
.21808 .47203 .22241 .47333 .2288 .46708 .22449 .46582 Mtetra
.858 .891 .859 r
.22449 .46582 .2288 .46708 .23519 .46086 .23089 .45963 Mtetra
.858 .894 .861 r
.23089 .45963 .23519 .46086 .24157 .45467 .23729 .45348 Mtetra
.858 .897 .863 r
.23729 .45348 .24157 .45467 .24795 .44853 .24369 .44737 Mtetra
.857 .9 .865 r
.24369 .44737 .24795 .44853 .25432 .44244 .25007 .44131 Mtetra
.856 .904 .867 r
.25007 .44131 .25432 .44244 .26069 .43641 .25646 .4353 Mtetra
.854 .907 .87 r
.25646 .4353 .26069 .43641 .26705 .43043 .26284 .42936 Mtetra
.853 .91 .872 r
.26284 .42936 .26705 .43043 .27341 .42453 .26921 .42348 Mtetra
.851 .913 .875 r
.26921 .42348 .27341 .42453 .27976 .4187 .27557 .41768 Mtetra
.849 .916 .878 r
.27557 .41768 .27976 .4187 .28611 .41296 .28193 .41196 Mtetra
.846 .919 .882 r
.28193 .41196 .28611 .41296 .29244 .4073 .28829 .40632 Mtetra
.843 .922 .885 r
.28829 .40632 .29244 .4073 .29878 .40173 .29464 .40077 Mtetra
.839 .925 .889 r
.29464 .40077 .29878 .40173 .3051 .39626 .30098 .39532 Mtetra
.836 .928 .892 r
.30098 .39532 .3051 .39626 .31142 .39088 .30732 .38996 Mtetra
.831 .931 .896 r
.30732 .38996 .31142 .39088 .31774 .38562 .31365 .38471 Mtetra
.827 .934 .9 r
.31365 .38471 .31774 .38562 .32405 .38046 .31998 .37957 Mtetra
.821 .937 .905 r
.31998 .37957 .32405 .38046 .33036 .37541 .3263 .37454 Mtetra
.815 .939 .909 r
.3263 .37454 .33036 .37541 .33666 .37049 .33262 .36962 Mtetra
.809 .942 .913 r
.33262 .36962 .33666 .37049 .34296 .36568 .33894 .36483 Mtetra
.802 .944 .918 r
.33894 .36483 .34296 .36568 .34926 .361 .34525 .36016 Mtetra
.795 .946 .922 r
.34525 .36016 .34926 .361 .35555 .35644 .35156 .35561 Mtetra
.786 .947 .927 r
.35156 .35561 .35555 .35644 .36185 .35202 .35787 .35119 Mtetra
.777 .949 .931 r
.35787 .35119 .36185 .35202 .36814 .34773 .36418 .34691 Mtetra
.767 .95 .936 r
.36418 .34691 .36814 .34773 .37443 .34357 .37049 .34276 Mtetra
.757 .95 .94 r
.37049 .34276 .37443 .34357 .38072 .33955 .3768 .33874 Mtetra
.745 .95 .945 r
.3768 .33874 .38072 .33955 .38701 .33567 .38311 .33487 Mtetra
.733 .95 .949 r
.38311 .33487 .38701 .33567 .39331 .33194 .38942 .33113 Mtetra
.72 .949 .953 r
.38942 .33113 .39331 .33194 .3996 .32835 .39573 .32754 Mtetra
.706 .947 .956 r
.39573 .32754 .3996 .32835 .4059 .3249 .40205 .3241 Mtetra
.691 .945 .96 r
.40205 .3241 .4059 .3249 .41221 .3216 .40837 .3208 Mtetra
.675 .942 .963 r
.40837 .3208 .41221 .3216 .41851 .31845 .41469 .31764 Mtetra
.658 .938 .966 r
.41469 .31764 .41851 .31845 .42483 .31545 .42102 .31464 Mtetra
.64 .934 .968 r
.42102 .31464 .42483 .31545 .43115 .31259 .42736 .31178 Mtetra
.62 .928 .97 r
.42736 .31178 .43115 .31259 .43748 .3099 .43371 .30908 Mtetra
.6 .922 .971 r
.43371 .30908 .43748 .3099 .44382 .30735 .44006 .30652 Mtetra
.579 .915 .971 r
.44006 .30652 .44382 .30735 .45017 .30495 .44643 .30412 Mtetra
.557 .907 .971 r
.44643 .30412 .45017 .30495 .45653 .30271 .4528 .30187 Mtetra
.535 .897 .97 r
.4528 .30187 .45653 .30271 .4629 .30062 .45919 .29977 Mtetra
.511 .887 .969 r
.45919 .29977 .4629 .30062 .46928 .29869 .46559 .29783 Mtetra
.487 .876 .967 r
.46559 .29783 .46928 .29869 .47568 .2969 .472 .29603 Mtetra
.462 .864 .964 r
.472 .29603 .47568 .2969 .48209 .29527 .47843 .29439 Mtetra
.436 .852 .96 r
.47843 .29439 .48209 .29527 .48852 .2938 .48487 .2929 Mtetra
.411 .838 .956 r
.48487 .2929 .48852 .2938 .49496 .29247 .49133 .29156 Mtetra
.385 .824 .951 r
.49133 .29156 .49496 .29247 .50143 .2913 .49781 .29037 Mtetra
.358 .809 .946 r
.49781 .29037 .50143 .2913 .50791 .29027 .50431 .28933 Mtetra
.332 .793 .94 r
.50431 .28933 .50791 .29027 .51441 .2894 .51083 .28844 Mtetra
.306 .777 .933 r
.51083 .28844 .51441 .2894 .52093 .28867 .51737 .28769 Mtetra
.281 .761 .926 r
.51737 .28769 .52093 .28867 .52748 .28809 .52393 .28709 Mtetra
.255 .744 .919 r
.52393 .28709 .52748 .28809 .53405 .28765 .53051 .28663 Mtetra
.23 .728 .911 r
.53051 .28663 .53405 .28765 .54064 .28735 .53712 .28631 Mtetra
.206 .711 .904 r
.53712 .28631 .54064 .28735 .54726 .2872 .54375 .28614 Mtetra
.183 .694 .896 r
.54375 .28614 .54726 .2872 .55391 .28719 .55041 .2861 Mtetra
.16 .678 .888 r
.55041 .2861 .55391 .28719 .56058 .28731 .5571 .28619 Mtetra
.139 .662 .881 r
.5571 .28619 .56058 .28731 .56728 .28756 .56382 .28642 Mtetra
.118 .646 .873 r
.56382 .28642 .56728 .28756 .57401 .28794 .57056 .28677 Mtetra
.099 .631 .866 r
.57056 .28677 .57401 .28794 .58077 .28846 .57734 .28726 Mtetra
.081 .617 .86 r
.57734 .28726 .58077 .28846 .58756 .28909 .58414 .28786 Mtetra
.064 .603 .853 r
.58414 .28786 .58756 .28909 .59439 .28985 .59098 .28859 Mtetra
.048 .589 .847 r
.59098 .28859 .59439 .28985 .60124 .29073 .59785 .28943 Mtetra
.034 .577 .842 r
.59785 .28943 .60124 .29073 .60814 .29172 .60476 .29039 Mtetra
.02 .565 .837 r
.60476 .29039 .60814 .29172 .61506 .29282 .61169 .29145 Mtetra
.009 .555 .833 r
.61169 .29145 .61506 .29282 .62202 .29402 .61867 .29261 Mtetra
0 .545 .83 r
.61867 .29261 .62202 .29402 .62902 .29532 .62568 .29388 Mtetra
0 .536 .827 r
.62568 .29388 .62902 .29532 .63606 .29672 .63273 .29524 Mtetra
0 .528 .825 r
.63273 .29524 .63606 .29672 .64313 .29821 .63981 .29669 Mtetra
0 .521 .824 r
.63981 .29669 .64313 .29821 .65024 .29979 .64694 .29822 Mtetra
0 .515 .824 r
.64694 .29822 .65024 .29979 .65739 .30144 .6541 .29982 Mtetra
0 .511 .824 r
.6541 .29982 .65739 .30144 .66457 .30317 .6613 .3015 Mtetra
0 .507 .825 r
.6613 .3015 .66457 .30317 .6718 .30496 .66854 .30325 Mtetra
0 .504 .827 r
.66854 .30325 .6718 .30496 .67907 .30681 .67582 .30505 Mtetra
0 .502 .83 r
.67582 .30505 .67907 .30681 .68638 .30872 .68314 .3069 Mtetra
0 .502 .834 r
.68314 .3069 .68638 .30872 .69373 .31067 .6905 .3088 Mtetra
0 .502 .838 r
.6905 .3088 .69373 .31067 .70112 .31266 .6979 .31073 Mtetra
0 .504 .843 r
.6979 .31073 .70112 .31266 .70855 .31468 .70534 .31269 Mtetra
0 .506 .849 r
.70534 .31269 .70855 .31468 .71602 .31672 .71282 .31467 Mtetra
0 .51 .855 r
.71282 .31467 .71602 .31672 .72353 .31878 .72034 .31667 Mtetra
.006 .515 .862 r
.72034 .31667 .72353 .31878 .73108 .32083 .72791 .31866 Mtetra
.018 .52 .869 r
.72791 .31866 .73108 .32083 .73867 .32289 .73551 .32065 Mtetra
.031 .527 .877 r
.73551 .32065 .73867 .32289 .7463 .32493 .74315 .32262 Mtetra
.046 .534 .885 r
.74315 .32262 .7463 .32493 .75397 .32694 .75083 .32456 Mtetra
.063 .543 .894 r
.75083 .32456 .75397 .32694 .76168 .32892 .75854 .32646 Mtetra
.081 .552 .903 r
.75854 .32646 .76168 .32892 .76942 .33085 .7663 .32832 Mtetra
.1 .561 .911 r
.7663 .32832 .76942 .33085 .7772 .33272 .77409 .33011 Mtetra
.122 .572 .92 r
.77409 .33011 .7772 .33272 .78501 .33452 .78191 .33184 Mtetra
.144 .583 .929 r
.78191 .33184 .78501 .33452 .79286 .33624 .78977 .33347 Mtetra
.168 .595 .937 r
.78977 .33347 .79286 .33624 .80074 .33787 .79766 .33501 Mtetra
.833 .852 .861 r
.13038 .54924 .13487 .55118 .14124 .54545 .13675 .54358 Mtetra
.836 .855 .859 r
.13675 .54358 .14124 .54545 .14761 .53962 .14314 .53782 Mtetra
.84 .858 .858 r
.14314 .53782 .14761 .53962 .154 .53371 .14953 .53197 Mtetra
.843 .861 .857 r
.14953 .53197 .154 .53371 .16039 .52772 .15593 .52604 Mtetra
.846 .864 .856 r
.15593 .52604 .16039 .52772 .16679 .52166 .16234 .52004 Mtetra
.848 .867 .856 r
.16234 .52004 .16679 .52166 .1732 .51555 .16876 .51398 Mtetra
.85 .871 .856 r
.16876 .51398 .1732 .51555 .17961 .50939 .17518 .50788 Mtetra
.852 .874 .856 r
.17518 .50788 .17961 .50939 .18602 .50319 .18161 .50174 Mtetra
.854 .877 .856 r
.18161 .50174 .18602 .50319 .19244 .49697 .18803 .49557 Mtetra
.855 .88 .856 r
.18803 .49557 .19244 .49697 .19885 .49074 .19446 .48938 Mtetra
.856 .883 .857 r
.19446 .48938 .19885 .49074 .20526 .4845 .20088 .48318 Mtetra
.857 .886 .858 r
.20088 .48318 .20526 .4845 .21168 .47826 .20731 .47699 Mtetra
.857 .889 .859 r
.20731 .47699 .21168 .47826 .21808 .47203 .21373 .4708 Mtetra
.858 .893 .86 r
.21373 .4708 .21808 .47203 .22449 .46582 .22015 .46463 Mtetra
.858 .896 .862 r
.22015 .46463 .22449 .46582 .23089 .45963 .22657 .45848 Mtetra
.858 .899 .863 r
.22657 .45848 .23089 .45963 .23729 .45348 .23298 .45237 Mtetra
.857 .902 .865 r
.23298 .45237 .23729 .45348 .24369 .44737 .23939 .44629 Mtetra
.856 .906 .867 r
.23939 .44629 .24369 .44737 .25007 .44131 .24579 .44027 Mtetra
.855 .909 .87 r
.24579 .44027 .25007 .44131 .25646 .4353 .25219 .43429 Mtetra
.854 .912 .872 r
.25219 .43429 .25646 .4353 .26284 .42936 .25858 .42838 Mtetra
.852 .915 .875 r
.25858 .42838 .26284 .42936 .26921 .42348 .26497 .42253 Mtetra
.85 .919 .878 r
.26497 .42253 .26921 .42348 .27557 .41768 .27135 .41675 Mtetra
.848 .922 .881 r
.27135 .41675 .27557 .41768 .28193 .41196 .27773 .41105 Mtetra
.845 .925 .884 r
.27773 .41105 .28193 .41196 .28829 .40632 .2841 .40544 Mtetra
.842 .928 .887 r
.2841 .40544 .28829 .40632 .29464 .40077 .29047 .39991 Mtetra
.838 .931 .891 r
.29047 .39991 .29464 .40077 .30098 .39532 .29682 .39448 Mtetra
.834 .934 .895 r
.29682 .39448 .30098 .39532 .30732 .38996 .30318 .38914 Mtetra
.83 .937 .898 r
.30318 .38914 .30732 .38996 .31365 .38471 .30953 .38391 Mtetra
.825 .94 .902 r
.30953 .38391 .31365 .38471 .31998 .37957 .31587 .37879 Mtetra
.819 .943 .906 r
.31587 .37879 .31998 .37957 .3263 .37454 .32221 .37377 Mtetra
.813 .945 .91 r
.32221 .37377 .3263 .37454 .33262 .36962 .32855 .36887 Mtetra
.806 .948 .915 r
.32855 .36887 .33262 .36962 .33894 .36483 .33489 .36409 Mtetra
.799 .95 .919 r
.33489 .36409 .33894 .36483 .34525 .36016 .34122 .35943 Mtetra
.791 .952 .923 r
.34122 .35943 .34525 .36016 .35156 .35561 .34754 .35489 Mtetra
.782 .953 .927 r
.34754 .35489 .35156 .35561 .35787 .35119 .35387 .35048 Mtetra
.773 .954 .932 r
.35387 .35048 .35787 .35119 .36418 .34691 .3602 .3462 Mtetra
.763 .955 .936 r
.3602 .3462 .36418 .34691 .37049 .34276 .36652 .34206 Mtetra
.752 .955 .94 r
.36652 .34206 .37049 .34276 .3768 .33874 .37285 .33805 Mtetra
.74 .955 .944 r
.37285 .33805 .3768 .33874 .38311 .33487 .37917 .33418 Mtetra
.727 .954 .948 r
.37917 .33418 .38311 .33487 .38942 .33113 .3855 .33045 Mtetra
.713 .953 .951 r
.3855 .33045 .38942 .33113 .39573 .32754 .39183 .32686 Mtetra
.698 .951 .954 r
.39183 .32686 .39573 .32754 .40205 .3241 .39816 .32341 Mtetra
.683 .948 .957 r
.39816 .32341 .40205 .3241 .40837 .3208 .4045 .32011 Mtetra
.666 .945 .96 r
.4045 .32011 .40837 .3208 .41469 .31764 .41084 .31696 Mtetra
.648 .941 .962 r
.41084 .31696 .41469 .31764 .42102 .31464 .41719 .31395 Mtetra
.63 .936 .964 r
.41719 .31395 .42102 .31464 .42736 .31178 .42354 .31109 Mtetra
.61 .93 .965 r
.42354 .31109 .42736 .31178 .43371 .30908 .42991 .30838 Mtetra
.589 .923 .965 r
.42991 .30838 .43371 .30908 .44006 .30652 .43628 .30582 Mtetra
.568 .915 .965 r
.43628 .30582 .44006 .30652 .44643 .30412 .44266 .30341 Mtetra
.545 .906 .964 r
.44266 .30341 .44643 .30412 .4528 .30187 .44905 .30115 Mtetra
.522 .897 .963 r
.44905 .30115 .4528 .30187 .45919 .29977 .45545 .29904 Mtetra
.498 .886 .961 r
.45545 .29904 .45919 .29977 .46559 .29783 .46187 .29709 Mtetra
.473 .875 .958 r
.46187 .29709 .46559 .29783 .472 .29603 .4683 .29528 Mtetra
.448 .862 .954 r
.4683 .29528 .472 .29603 .47843 .29439 .47474 .29363 Mtetra
.422 .849 .95 r
.47474 .29363 .47843 .29439 .48487 .2929 .4812 .29212 Mtetra
.396 .835 .945 r
.4812 .29212 .48487 .2929 .49133 .29156 .48768 .29077 Mtetra
.369 .82 .94 r
.48768 .29077 .49133 .29156 .49781 .29037 .49418 .28956 Mtetra
.343 .805 .934 r
.49418 .28956 .49781 .29037 .50431 .28933 .50069 .2885 Mtetra
.317 .789 .927 r
.50069 .2885 .50431 .28933 .51083 .28844 .50722 .28759 Mtetra
.291 .772 .92 r
.50722 .28759 .51083 .28844 .51737 .28769 .51378 .28683 Mtetra
.265 .756 .913 r
.51378 .28683 .51737 .28769 .52393 .28709 .52035 .2862 Mtetra
.24 .739 .905 r
.52035 .2862 .52393 .28709 .53051 .28663 .52695 .28572 Mtetra
.215 .722 .897 r
.52695 .28572 .53051 .28663 .53712 .28631 .53358 .28538 Mtetra
.191 .705 .89 r
.53358 .28538 .53712 .28631 .54375 .28614 .54022 .28518 Mtetra
.168 .689 .882 r
.54022 .28518 .54375 .28614 .55041 .2861 .5469 .28512 Mtetra
.146 .672 .874 r
.5469 .28512 .55041 .2861 .5571 .28619 .5536 .28519 Mtetra
.125 .656 .867 r
.5536 .28519 .5571 .28619 .56382 .28642 .56033 .28539 Mtetra
.105 .641 .859 r
.56033 .28539 .56382 .28642 .57056 .28677 .56709 .28571 Mtetra
.086 .626 .852 r
.56709 .28571 .57056 .28677 .57734 .28726 .57388 .28617 Mtetra
.068 .612 .846 r
.57388 .28617 .57734 .28726 .58414 .28786 .5807 .28674 Mtetra
.052 .598 .84 r
.5807 .28674 .58414 .28786 .59098 .28859 .58755 .28743 Mtetra
.037 .585 .834 r
.58755 .28743 .59098 .28859 .59785 .28943 .59444 .28824 Mtetra
.023 .573 .829 r
.59444 .28824 .59785 .28943 .60476 .29039 .60136 .28916 Mtetra
.01 .562 .825 r
.60136 .28916 .60476 .29039 .61169 .29145 .60831 .29018 Mtetra
0 .551 .822 r
.60831 .29018 .61169 .29145 .61867 .29261 .6153 .29131 Mtetra
0 .542 .819 r
.6153 .29131 .61867 .29261 .62568 .29388 .62232 .29253 Mtetra
0 .533 .817 r
.62232 .29253 .62568 .29388 .63273 .29524 .62938 .29385 Mtetra
0 .526 .815 r
.62938 .29385 .63273 .29524 .63981 .29669 .63648 .29525 Mtetra
0 .52 .815 r
.63648 .29525 .63981 .29669 .64694 .29822 .64362 .29673 Mtetra
0 .514 .815 r
.64362 .29673 .64694 .29822 .6541 .29982 .65079 .29829 Mtetra
0 .51 .816 r
.65079 .29829 .6541 .29982 .6613 .3015 .65801 .29992 Mtetra
0 .507 .818 r
.65801 .29992 .6613 .3015 .66854 .30325 .66526 .30162 Mtetra
0 .504 .82 r
.66526 .30162 .66854 .30325 .67582 .30505 .67255 .30336 Mtetra
0 .503 .824 r
.67255 .30336 .67582 .30505 .68314 .3069 .67988 .30516 Mtetra
0 .503 .828 r
.67988 .30516 .68314 .3069 .6905 .3088 .68725 .307 Mtetra
0 .504 .833 r
.68725 .307 .6905 .3088 .6979 .31073 .69467 .30888 Mtetra
0 .506 .839 r
.69467 .30888 .6979 .31073 .70534 .31269 .70212 .31078 Mtetra
0 .509 .845 r
.70212 .31078 .70534 .31269 .71282 .31467 .70961 .3127 Mtetra
0 .513 .852 r
.70961 .3127 .71282 .31467 .72034 .31667 .71715 .31462 Mtetra
.005 .518 .859 r
.71715 .31462 .72034 .31667 .72791 .31866 .72472 .31655 Mtetra
.018 .524 .868 r
.72472 .31655 .72791 .31866 .73551 .32065 .73233 .31847 Mtetra
.032 .531 .876 r
.73233 .31847 .73551 .32065 .74315 .32262 .73998 .32036 Mtetra
.048 .539 .885 r
.73998 .32036 .74315 .32262 .75083 .32456 .74767 .32223 Mtetra
.065 .548 .894 r
.74767 .32223 .75083 .32456 .75854 .32646 .7554 .32406 Mtetra
.084 .558 .903 r
.7554 .32406 .75854 .32646 .7663 .32832 .76316 .32583 Mtetra
.104 .568 .913 r
.76316 .32583 .7663 .32832 .77409 .33011 .77096 .32755 Mtetra
.126 .579 .922 r
.77096 .32755 .77409 .33011 .78191 .33184 .77879 .32918 Mtetra
.149 .59 .931 r
.77879 .32918 .78191 .33184 .78977 .33347 .78666 .33073 Mtetra
.174 .602 .94 r
.78666 .33073 .78977 .33347 .79766 .33501 .79455 .33218 Mtetra
.831 .855 .864 r
.12586 .54734 .13038 .54924 .13675 .54358 .13224 .54175 Mtetra
.835 .858 .862 r
.13224 .54175 .13675 .54358 .14314 .53782 .13863 .53606 Mtetra
.838 .861 .861 r
.13863 .53606 .14314 .53782 .14953 .53197 .14503 .53027 Mtetra
.842 .864 .86 r
.14503 .53027 .14953 .53197 .15593 .52604 .15145 .5244 Mtetra
.844 .868 .859 r
.15145 .5244 .15593 .52604 .16234 .52004 .15787 .51846 Mtetra
.847 .871 .859 r
.15787 .51846 .16234 .52004 .16876 .51398 .16429 .51247 Mtetra
.849 .874 .859 r
.16429 .51247 .16876 .51398 .17518 .50788 .17072 .50642 Mtetra
.851 .877 .859 r
.17072 .50642 .17518 .50788 .18161 .50174 .17716 .50033 Mtetra
.853 .881 .859 r
.17716 .50033 .18161 .50174 .18803 .49557 .18359 .49422 Mtetra
.854 .884 .859 r
.18359 .49422 .18803 .49557 .19446 .48938 .19003 .48808 Mtetra
.855 .887 .86 r
.19003 .48808 .19446 .48938 .20088 .48318 .19647 .48193 Mtetra
.856 .891 .861 r
.19647 .48193 .20088 .48318 .20731 .47699 .20291 .47578 Mtetra
.857 .894 .862 r
.20291 .47578 .20731 .47699 .21373 .4708 .20934 .46964 Mtetra
.857 .897 .863 r
.20934 .46964 .21373 .4708 .22015 .46463 .21578 .46351 Mtetra
.857 .901 .865 r
.21578 .46351 .22015 .46463 .22657 .45848 .22221 .45741 Mtetra
.857 .904 .866 r
.22221 .45741 .22657 .45848 .23298 .45237 .22863 .45133 Mtetra
.856 .907 .868 r
.22863 .45133 .23298 .45237 .23939 .44629 .23506 .4453 Mtetra
.855 .911 .87 r
.23506 .4453 .23939 .44629 .24579 .44027 .24148 .4393 Mtetra
.854 .914 .872 r
.24148 .4393 .24579 .44027 .25219 .43429 .24789 .43336 Mtetra
.853 .917 .875 r
.24789 .43336 .25219 .43429 .25858 .42838 .2543 .42748 Mtetra
.851 .921 .877 r
.2543 .42748 .25858 .42838 .26497 .42253 .2607 .42166 Mtetra
.849 .924 .88 r
.2607 .42166 .26497 .42253 .27135 .41675 .2671 .41592 Mtetra
.846 .927 .883 r
.2671 .41592 .27135 .41675 .27773 .41105 .27349 .41024 Mtetra
.843 .931 .886 r
.27349 .41024 .27773 .41105 .2841 .40544 .27988 .40465 Mtetra
.84 .934 .889 r
.27988 .40465 .2841 .40544 .29047 .39991 .28626 .39915 Mtetra
.836 .937 .893 r
.28626 .39915 .29047 .39991 .29682 .39448 .29264 .39374 Mtetra
.832 .94 .896 r
.29264 .39374 .29682 .39448 .30318 .38914 .29901 .38843 Mtetra
.827 .943 .9 r
.29901 .38843 .30318 .38914 .30953 .38391 .30537 .38321 Mtetra
.822 .946 .904 r
.30537 .38321 .30953 .38391 .31587 .37879 .31174 .3781 Mtetra
.816 .949 .908 r
.31174 .3781 .31587 .37879 .32221 .37377 .31809 .37311 Mtetra
.81 .951 .912 r
.31809 .37311 .32221 .37377 .32855 .36887 .32445 .36822 Mtetra
.803 .953 .916 r
.32445 .36822 .32855 .36887 .33489 .36409 .3308 .36345 Mtetra
.795 .955 .92 r
.3308 .36345 .33489 .36409 .34122 .35943 .33715 .3588 Mtetra
.787 .957 .924 r
.33715 .3588 .34122 .35943 .34754 .35489 .34349 .35428 Mtetra
.778 .958 .928 r
.34349 .35428 .34754 .35489 .35387 .35048 .34983 .34988 Mtetra
.768 .959 .932 r
.34983 .34988 .35387 .35048 .3602 .3462 .35618 .34561 Mtetra
.757 .96 .935 r
.35618 .34561 .3602 .3462 .36652 .34206 .36252 .34147 Mtetra
.746 .96 .939 r
.36252 .34147 .36652 .34206 .37285 .33805 .36886 .33747 Mtetra
.733 .959 .943 r
.36886 .33747 .37285 .33805 .37917 .33418 .3752 .3336 Mtetra
.72 .958 .946 r
.3752 .3336 .37917 .33418 .3855 .33045 .38155 .32988 Mtetra
.706 .957 .949 r
.38155 .32988 .3855 .33045 .39183 .32686 .3879 .32629 Mtetra
.69 .954 .952 r
.3879 .32629 .39183 .32686 .39816 .32341 .39425 .32284 Mtetra
.674 .951 .954 r
.39425 .32284 .39816 .32341 .4045 .32011 .4006 .31954 Mtetra
.657 .947 .956 r
.4006 .31954 .4045 .32011 .41084 .31696 .40696 .31639 Mtetra
.638 .943 .958 r
.40696 .31639 .41084 .31696 .41719 .31395 .41333 .31338 Mtetra
.619 .937 .958 r
.41333 .31338 .41719 .31395 .42354 .31109 .4197 .31051 Mtetra
.599 .931 .959 r
.4197 .31051 .42354 .31109 .42991 .30838 .42608 .3078 Mtetra
.578 .923 .959 r
.42608 .3078 .42991 .30838 .43628 .30582 .43247 .30523 Mtetra
.555 .915 .958 r
.43247 .30523 .43628 .30582 .44266 .30341 .43886 .30282 Mtetra
.532 .905 .956 r
.43886 .30282 .44266 .30341 .44905 .30115 .44527 .30055 Mtetra
.508 .895 .954 r
.44527 .30055 .44905 .30115 .45545 .29904 .45169 .29843 Mtetra
.484 .884 .951 r
.45169 .29843 .45545 .29904 .46187 .29709 .45812 .29647 Mtetra
.459 .872 .948 r
.45812 .29647 .46187 .29709 .4683 .29528 .46457 .29465 Mtetra
.433 .859 .943 r
.46457 .29465 .4683 .29528 .47474 .29363 .47103 .29298 Mtetra
.407 .845 .939 r
.47103 .29298 .47474 .29363 .4812 .29212 .47751 .29146 Mtetra
.381 .83 .933 r
.47751 .29146 .4812 .29212 .48768 .29077 .484 .29009 Mtetra
.354 .815 .927 r
.484 .29009 .48768 .29077 .49418 .28956 .49051 .28887 Mtetra
.328 .799 .921 r
.49051 .28887 .49418 .28956 .50069 .2885 .49704 .28779 Mtetra
.302 .783 .914 r
.49704 .28779 .50069 .2885 .50722 .28759 .50359 .28686 Mtetra
.276 .767 .906 r
.50359 .28686 .50722 .28759 .51378 .28683 .51016 .28608 Mtetra
.25 .75 .899 r
.51016 .28608 .51378 .28683 .52035 .2862 .51675 .28543 Mtetra
.225 .733 .891 r
.51675 .28543 .52035 .2862 .52695 .28572 .52337 .28493 Mtetra
.201 .716 .883 r
.52337 .28493 .52695 .28572 .53358 .28538 .53001 .28457 Mtetra
.177 .699 .875 r
.53001 .28457 .53358 .28538 .54022 .28518 .53667 .28434 Mtetra
.155 .683 .867 r
.53667 .28434 .54022 .28518 .5469 .28512 .54336 .28425 Mtetra
.133 .667 .86 r
.54336 .28425 .5469 .28512 .5536 .28519 .55008 .28429 Mtetra
.112 .651 .852 r
.55008 .28429 .5536 .28519 .56033 .28539 .55682 .28446 Mtetra
.093 .635 .845 r
.55682 .28446 .56033 .28539 .56709 .28571 .5636 .28476 Mtetra
.074 .621 .838 r
.5636 .28476 .56709 .28571 .57388 .28617 .5704 .28518 Mtetra
.057 .607 .832 r
.5704 .28518 .57388 .28617 .5807 .28674 .57724 .28572 Mtetra
.041 .593 .826 r
.57724 .28572 .5807 .28674 .58755 .28743 .5841 .28637 Mtetra
.026 .581 .821 r
.5841 .28637 .58755 .28743 .59444 .28824 .591 .28715 Mtetra
.013 .569 .817 r
.591 .28715 .59444 .28824 .60136 .28916 .59794 .28803 Mtetra
.001 .558 .813 r
.59794 .28803 .60136 .28916 .60831 .29018 .6049 .28901 Mtetra
0 .548 .81 r
.6049 .28901 .60831 .29018 .6153 .29131 .61191 .29009 Mtetra
0 .539 .808 r
.61191 .29009 .6153 .29131 .62232 .29253 .61894 .29128 Mtetra
0 .531 .806 r
.61894 .29128 .62232 .29253 .62938 .29385 .62602 .29255 Mtetra
0 .524 .805 r
.62602 .29255 .62938 .29385 .63648 .29525 .63313 .2939 Mtetra
0 .518 .805 r
.63313 .2939 .63648 .29525 .64362 .29673 .64028 .29534 Mtetra
0 .513 .806 r
.64028 .29534 .64362 .29673 .65079 .29829 .64747 .29685 Mtetra
0 .51 .808 r
.64747 .29685 .65079 .29829 .65801 .29992 .65469 .29843 Mtetra
0 .507 .811 r
.65469 .29843 .65801 .29992 .66526 .30162 .66196 .30006 Mtetra
0 .505 .814 r
.66196 .30006 .66526 .30162 .67255 .30336 .66926 .30176 Mtetra
0 .504 .818 r
.66926 .30176 .67255 .30336 .67988 .30516 .67661 .3035 Mtetra
0 .505 .823 r
.67661 .3035 .67988 .30516 .68725 .307 .68399 .30528 Mtetra
0 .506 .829 r
.68399 .30528 .68725 .307 .69467 .30888 .69142 .30709 Mtetra
0 .509 .835 r
.69142 .30709 .69467 .30888 .70212 .31078 .69888 .30893 Mtetra
0 .512 .842 r
.69888 .30893 .70212 .31078 .70961 .3127 .70639 .31078 Mtetra
0 .517 .85 r
.70639 .31078 .70961 .3127 .71715 .31462 .71393 .31264 Mtetra
.005 .523 .858 r
.71393 .31264 .71715 .31462 .72472 .31655 .72151 .31449 Mtetra
.019 .529 .866 r
.72151 .31449 .72472 .31655 .73233 .31847 .72914 .31634 Mtetra
.034 .537 .876 r
.72914 .31634 .73233 .31847 .73998 .32036 .7368 .31816 Mtetra
.05 .545 .885 r
.7368 .31816 .73998 .32036 .74767 .32223 .7445 .31995 Mtetra
.069 .554 .895 r
.7445 .31995 .74767 .32223 .7554 .32406 .75223 .32169 Mtetra
.088 .564 .905 r
.75223 .32169 .7554 .32406 .76316 .32583 .76001 .32339 Mtetra
.109 .575 .914 r
.76001 .32339 .76316 .32583 .77096 .32755 .76781 .32501 Mtetra
.132 .586 .924 r
.76781 .32501 .77096 .32755 .77879 .32918 .77566 .32656 Mtetra
.156 .598 .933 r
.77566 .32656 .77879 .32918 .78666 .33073 .78353 .32802 Mtetra
.181 .61 .942 r
.78353 .32802 .78666 .33073 .79455 .33218 .79144 .32938 Mtetra
.829 .857 .867 r
.12131 .54545 .12586 .54734 .13224 .54175 .1277 .53994 Mtetra
.833 .86 .866 r
.1277 .53994 .13224 .54175 .13863 .53606 .1341 .53432 Mtetra
.837 .864 .864 r
.1341 .53432 .13863 .53606 .14503 .53027 .14051 .5286 Mtetra
.84 .867 .863 r
.14051 .5286 .14503 .53027 .15145 .5244 .14693 .5228 Mtetra
.843 .871 .863 r
.14693 .5228 .15145 .5244 .15787 .51846 .15336 .51693 Mtetra
.846 .874 .862 r
.15336 .51693 .15787 .51846 .16429 .51247 .15979 .51099 Mtetra
.848 .878 .862 r
.15979 .51099 .16429 .51247 .17072 .50642 .16623 .50501 Mtetra
.85 .881 .862 r
.16623 .50501 .17072 .50642 .17716 .50033 .17268 .49898 Mtetra
.852 .884 .862 r
.17268 .49898 .17716 .50033 .18359 .49422 .17912 .49292 Mtetra
.853 .888 .862 r
.17912 .49292 .18359 .49422 .19003 .48808 .18557 .48684 Mtetra
.854 .891 .863 r
.18557 .48684 .19003 .48808 .19647 .48193 .19202 .48074 Mtetra
.855 .895 .864 r
.19202 .48074 .19647 .48193 .20291 .47578 .19847 .47464 Mtetra
.856 .898 .865 r
.19847 .47464 .20291 .47578 .20934 .46964 .20492 .46855 Mtetra
.856 .902 .866 r
.20492 .46855 .20934 .46964 .21578 .46351 .21137 .46246 Mtetra
.856 .905 .867 r
.21137 .46246 .21578 .46351 .22221 .45741 .21782 .4564 Mtetra
.856 .909 .869 r
.21782 .4564 .22221 .45741 .22863 .45133 .22426 .45037 Mtetra
.855 .912 .871 r
.22426 .45037 .22863 .45133 .23506 .4453 .23069 .44437 Mtetra
.854 .916 .873 r
.23069 .44437 .23506 .4453 .24148 .4393 .23713 .43842 Mtetra
.853 .919 .875 r
.23713 .43842 .24148 .4393 .24789 .43336 .24356 .43251 Mtetra
.851 .922 .877 r
.24356 .43251 .24789 .43336 .2543 .42748 .24998 .42667 Mtetra
.85 .926 .88 r
.24998 .42667 .2543 .42748 .2607 .42166 .2564 .42088 Mtetra
.847 .929 .882 r
.2564 .42088 .2607 .42166 .2671 .41592 .26281 .41516 Mtetra
.845 .933 .885 r
.26281 .41516 .2671 .41592 .27349 .41024 .26922 .40952 Mtetra
.842 .936 .888 r
.26922 .40952 .27349 .41024 .27988 .40465 .27562 .40396 Mtetra
.838 .939 .891 r
.27562 .40396 .27988 .40465 .28626 .39915 .28202 .39848 Mtetra
.834 .942 .895 r
.28202 .39848 .28626 .39915 .29264 .39374 .28841 .3931 Mtetra
.83 .945 .898 r
.28841 .3931 .29264 .39374 .29901 .38843 .2948 .3878 Mtetra
.825 .948 .902 r
.2948 .3878 .29901 .38843 .30537 .38321 .30118 .38261 Mtetra
.819 .951 .905 r
.30118 .38261 .30537 .38321 .31174 .3781 .30756 .37752 Mtetra
.813 .954 .909 r
.30756 .37752 .31174 .3781 .31809 .37311 .31394 .37254 Mtetra
.806 .956 .913 r
.31394 .37254 .31809 .37311 .32445 .36822 .32031 .36767 Mtetra
.799 .958 .916 r
.32031 .36767 .32445 .36822 .3308 .36345 .32668 .36292 Mtetra
.791 .96 .92 r
.32668 .36292 .3308 .36345 .33715 .3588 .33304 .35828 Mtetra
.782 .962 .924 r
.33304 .35828 .33715 .3588 .34349 .35428 .3394 .35377 Mtetra
.773 .963 .927 r
.3394 .35377 .34349 .35428 .34983 .34988 .34577 .34938 Mtetra
.763 .963 .931 r
.34577 .34938 .34983 .34988 .35618 .34561 .35213 .34512 Mtetra
.751 .964 .934 r
.35213 .34512 .35618 .34561 .36252 .34147 .35849 .34099 Mtetra
.739 .964 .938 r
.35849 .34099 .36252 .34147 .36886 .33747 .36484 .337 Mtetra
.726 .963 .941 r
.36484 .337 .36886 .33747 .3752 .3336 .37121 .33314 Mtetra
.713 .961 .944 r
.37121 .33314 .3752 .3336 .38155 .32988 .37757 .32941 Mtetra
.698 .959 .946 r
.37757 .32941 .38155 .32988 .3879 .32629 .38393 .32583 Mtetra
.682 .957 .948 r
.38393 .32583 .3879 .32629 .39425 .32284 .3903 .32239 Mtetra
.665 .953 .95 r
.3903 .32239 .39425 .32284 .4006 .31954 .39667 .31908 Mtetra
.647 .949 .951 r
.39667 .31908 .4006 .31954 .40696 .31639 .40305 .31593 Mtetra
.628 .944 .952 r
.40305 .31593 .40696 .31639 .41333 .31338 .40943 .31291 Mtetra
.608 .937 .953 r
.40943 .31291 .41333 .31338 .4197 .31051 .41582 .31005 Mtetra
.587 .93 .952 r
.41582 .31005 .4197 .31051 .42608 .3078 .42222 .30733 Mtetra
.566 .922 .951 r
.42222 .30733 .42608 .3078 .43247 .30523 .42862 .30476 Mtetra
.543 .913 .95 r
.42862 .30476 .43247 .30523 .43886 .30282 .43504 .30233 Mtetra
.519 .904 .948 r
.43504 .30233 .43886 .30282 .44527 .30055 .44146 .30006 Mtetra
.495 .893 .945 r
.44146 .30006 .44527 .30055 .45169 .29843 .4479 .29793 Mtetra
.47 .881 .941 r
.4479 .29793 .45169 .29843 .45812 .29647 .45435 .29596 Mtetra
.445 .868 .937 r
.45435 .29596 .45812 .29647 .46457 .29465 .46081 .29413 Mtetra
.419 .855 .932 r
.46081 .29413 .46457 .29465 .47103 .29298 .46729 .29245 Mtetra
.393 .84 .927 r
.46729 .29245 .47103 .29298 .47751 .29146 .47378 .29091 Mtetra
.366 .825 .921 r
.47378 .29091 .47751 .29146 .484 .29009 .48029 .28953 Mtetra
.34 .81 .914 r
.48029 .28953 .484 .29009 .49051 .28887 .48682 .28829 Mtetra
.313 .794 .907 r
.48682 .28829 .49051 .28887 .49704 .28779 .49337 .28719 Mtetra
.287 .777 .9 r
.49337 .28719 .49704 .28779 .50359 .28686 .49993 .28624 Mtetra
.261 .761 .892 r
.49993 .28624 .50359 .28686 .51016 .28608 .50652 .28544 Mtetra
.236 .744 .884 r
.50652 .28544 .51016 .28608 .51675 .28543 .51313 .28477 Mtetra
.211 .727 .876 r
.51313 .28477 .51675 .28543 .52337 .28493 .51976 .28425 Mtetra
.187 .71 .868 r
.51976 .28425 .52337 .28493 .53001 .28457 .52641 .28386 Mtetra
.164 .693 .86 r
.52641 .28386 .53001 .28457 .53667 .28434 .53309 .2836 Mtetra
.142 .677 .853 r
.53309 .2836 .53667 .28434 .54336 .28425 .5398 .28348 Mtetra
.121 .661 .845 r
.5398 .28348 .54336 .28425 .55008 .28429 .54653 .2835 Mtetra
.1 .645 .838 r
.54653 .2835 .55008 .28429 .55682 .28446 .55329 .28364 Mtetra
.081 .63 .831 r
.55329 .28364 .55682 .28446 .5636 .28476 .56008 .2839 Mtetra
.063 .616 .825 r
.56008 .2839 .5636 .28476 .5704 .28518 .5669 .28429 Mtetra
.047 .602 .819 r
.5669 .28429 .5704 .28518 .57724 .28572 .57375 .28479 Mtetra
.031 .589 .813 r
.57375 .28479 .57724 .28572 .5841 .28637 .58063 .28541 Mtetra
.017 .577 .809 r
.58063 .28541 .5841 .28637 .591 .28715 .58755 .28615 Mtetra
.004 .565 .805 r
.58755 .28615 .591 .28715 .59794 .28803 .5945 .28699 Mtetra
0 .555 .802 r
.5945 .28699 .59794 .28803 .6049 .28901 .60148 .28793 Mtetra
0 .545 .799 r
.60148 .28793 .6049 .28901 .61191 .29009 .60849 .28897 Mtetra
0 .537 .797 r
.60849 .28897 .61191 .29009 .61894 .29128 .61555 .29011 Mtetra
0 .529 .796 r
.61555 .29011 .61894 .29128 .62602 .29255 .62264 .29133 Mtetra
0 .523 .796 r
.62264 .29133 .62602 .29255 .63313 .2939 .62976 .29264 Mtetra
0 .518 .797 r
.62976 .29264 .63313 .2939 .64028 .29534 .63692 .29402 Mtetra
0 .513 .798 r
.63692 .29402 .64028 .29534 .64747 .29685 .64413 .29548 Mtetra
0 .51 .801 r
.64413 .29548 .64747 .29685 .65469 .29843 .65137 .29701 Mtetra
0 .508 .804 r
.65137 .29701 .65469 .29843 .66196 .30006 .65864 .29859 Mtetra
0 .506 .808 r
.65864 .29859 .66196 .30006 .66926 .30176 .66596 .30022 Mtetra
0 .506 .813 r
.66596 .30022 .66926 .30176 .67661 .3035 .67332 .3019 Mtetra
0 .507 .818 r
.67332 .3019 .67661 .3035 .68399 .30528 .68072 .30362 Mtetra
0 .509 .825 r
.68072 .30362 .68399 .30528 .69142 .30709 .68815 .30537 Mtetra
0 .512 .832 r
.68815 .30537 .69142 .30709 .69888 .30893 .69563 .30714 Mtetra
0 .516 .839 r
.69563 .30714 .69888 .30893 .70639 .31078 .70314 .30892 Mtetra
0 .522 .848 r
.70314 .30892 .70639 .31078 .71393 .31264 .7107 .3107 Mtetra
.007 .528 .857 r
.7107 .3107 .71393 .31264 .72151 .31449 .71829 .31249 Mtetra
.021 .535 .866 r
.71829 .31249 .72151 .31449 .72914 .31634 .72593 .31425 Mtetra
.037 .543 .876 r
.72593 .31425 .72914 .31634 .7368 .31816 .7336 .316 Mtetra
.055 .552 .886 r
.7336 .316 .7368 .31816 .7445 .31995 .74131 .3177 Mtetra
.073 .561 .896 r
.74131 .3177 .7445 .31995 .75223 .32169 .74905 .31937 Mtetra
.094 .571 .906 r
.74905 .31937 .75223 .32169 .76001 .32339 .75684 .32097 Mtetra
.116 .582 .917 r
.75684 .32097 .76001 .32339 .76781 .32501 .76465 .32251 Mtetra
.139 .594 .926 r
.76465 .32251 .76781 .32501 .77566 .32656 .7725 .32396 Mtetra
.164 .606 .936 r
.7725 .32396 .77566 .32656 .78353 .32802 .78039 .32533 Mtetra
.19 .618 .945 r
.78039 .32533 .78353 .32802 .79144 .32938 .7883 .32658 Mtetra
.827 .859 .871 r
.11674 .54357 .12131 .54545 .1277 .53994 .12313 .53814 Mtetra
.831 .863 .869 r
.12313 .53814 .1277 .53994 .1341 .53432 .12953 .5326 Mtetra
.835 .866 .868 r
.12953 .5326 .1341 .53432 .14051 .5286 .13595 .52696 Mtetra
.838 .87 .867 r
.13595 .52696 .14051 .5286 .14693 .5228 .14238 .52123 Mtetra
.841 .874 .866 r
.14238 .52123 .14693 .5228 .15336 .51693 .14881 .51543 Mtetra
.844 .877 .865 r
.14881 .51543 .15336 .51693 .15979 .51099 .15526 .50956 Mtetra
.846 .881 .865 r
.15526 .50956 .15979 .51099 .16623 .50501 .16171 .50364 Mtetra
.848 .884 .865 r
.16171 .50364 .16623 .50501 .17268 .49898 .16817 .49767 Mtetra
.85 .888 .865 r
.16817 .49767 .17268 .49898 .17912 .49292 .17462 .49167 Mtetra
.852 .892 .866 r
.17462 .49167 .17912 .49292 .18557 .48684 .18109 .48564 Mtetra
.853 .895 .866 r
.18109 .48564 .18557 .48684 .19202 .48074 .18755 .4796 Mtetra
.854 .899 .867 r
.18755 .4796 .19202 .48074 .19847 .47464 .19401 .47356 Mtetra
.854 .902 .868 r
.19401 .47356 .19847 .47464 .20492 .46855 .20047 .46751 Mtetra
.855 .906 .869 r
.20047 .46751 .20492 .46855 .21137 .46246 .20693 .46148 Mtetra
.855 .909 .87 r
.20693 .46148 .21137 .46246 .21782 .4564 .21339 .45546 Mtetra
.854 .913 .872 r
.21339 .45546 .21782 .4564 .22426 .45037 .21984 .44948 Mtetra
.854 .917 .874 r
.21984 .44948 .22426 .45037 .23069 .44437 .2263 .44352 Mtetra
.853 .92 .875 r
.2263 .44352 .23069 .44437 .23713 .43842 .23274 .43761 Mtetra
.852 .924 .878 r
.23274 .43761 .23713 .43842 .24356 .43251 .23919 .43174 Mtetra
.85 .927 .88 r
.23919 .43174 .24356 .43251 .24998 .42667 .24563 .42593 Mtetra
.848 .931 .882 r
.24563 .42593 .24998 .42667 .2564 .42088 .25206 .42018 Mtetra
.846 .934 .885 r
.25206 .42018 .2564 .42088 .26281 .41516 .25849 .41449 Mtetra
.843 .938 .887 r
.25849 .41449 .26281 .41516 .26922 .40952 .26491 .40888 Mtetra
.839 .941 .89 r
.26491 .40888 .26922 .40952 .27562 .40396 .27133 .40335 Mtetra
.836 .944 .893 r
.27133 .40335 .27562 .40396 .28202 .39848 .27775 .3979 Mtetra
.832 .947 .896 r
.27775 .3979 .28202 .39848 .28841 .3931 .28416 .39254 Mtetra
.827 .95 .9 r
.28416 .39254 .28841 .3931 .2948 .3878 .29056 .38727 Mtetra
.822 .953 .903 r
.29056 .38727 .2948 .3878 .30118 .38261 .29696 .3821 Mtetra
.816 .956 .906 r
.29696 .3821 .30118 .38261 .30756 .37752 .30336 .37703 Mtetra
.81 .958 .91 r
.30336 .37703 .30756 .37752 .31394 .37254 .30975 .37207 Mtetra
.803 .961 .913 r
.30975 .37207 .31394 .37254 .32031 .36767 .31614 .36722 Mtetra
.795 .963 .917 r
.31614 .36722 .32031 .36767 .32668 .36292 .32252 .36248 Mtetra
.787 .964 .92 r
.32252 .36248 .32668 .36292 .33304 .35828 .32891 .35786 Mtetra
.777 .966 .923 r
.32891 .35786 .33304 .35828 .3394 .35377 .33529 .35336 Mtetra
.767 .967 .927 r
.33529 .35336 .3394 .35377 .34577 .34938 .34166 .34899 Mtetra
.757 .967 .93 r
.34166 .34899 .34577 .34938 .35213 .34512 .34804 .34474 Mtetra
.745 .967 .933 r
.34804 .34474 .35213 .34512 .35849 .34099 .35442 .34062 Mtetra
.733 .967 .936 r
.35442 .34062 .35849 .34099 .36484 .337 .3608 .33663 Mtetra
.719 .966 .938 r
.3608 .33663 .36484 .337 .37121 .33314 .36717 .33278 Mtetra
.705 .964 .941 r
.36717 .33278 .37121 .33314 .37757 .32941 .37355 .32906 Mtetra
.689 .961 .943 r
.37355 .32906 .37757 .32941 .38393 .32583 .37994 .32548 Mtetra
.673 .958 .944 r
.37994 .32548 .38393 .32583 .3903 .32239 .38632 .32203 Mtetra
.655 .954 .945 r
.38632 .32203 .3903 .32239 .39667 .31908 .39271 .31873 Mtetra
.637 .949 .946 r
.39271 .31873 .39667 .31908 .40305 .31593 .39911 .31558 Mtetra
.617 .944 .946 r
.39911 .31558 .40305 .31593 .40943 .31291 .40551 .31256 Mtetra
.597 .937 .946 r
.40551 .31256 .40943 .31291 .41582 .31005 .41191 .30969 Mtetra
.576 .929 .945 r
.41191 .30969 .41582 .31005 .42222 .30733 .41833 .30697 Mtetra
.553 .921 .943 r
.41833 .30697 .42222 .30733 .42862 .30476 .42475 .30439 Mtetra
.53 .911 .941 r
.42475 .30439 .42862 .30476 .43504 .30233 .43118 .30196 Mtetra
.506 .901 .938 r
.43118 .30196 .43504 .30233 .44146 .30006 .43763 .29968 Mtetra
.482 .889 .935 r
.43763 .29968 .44146 .30006 .4479 .29793 .44408 .29754 Mtetra
.456 .877 .93 r
.44408 .29754 .4479 .29793 .45435 .29596 .45055 .29555 Mtetra
.431 .864 .925 r
.45055 .29555 .45435 .29596 .46081 .29413 .45703 .29371 Mtetra
.405 .85 .92 r
.45703 .29371 .46081 .29413 .46729 .29245 .46352 .29202 Mtetra
.378 .835 .914 r
.46352 .29202 .46729 .29245 .47378 .29091 .47003 .29047 Mtetra
.352 .82 .908 r
.47003 .29047 .47378 .29091 .48029 .28953 .47656 .28907 Mtetra
.325 .804 .901 r
.47656 .28907 .48029 .28953 .48682 .28829 .48311 .28781 Mtetra
.299 .788 .893 r
.48311 .28781 .48682 .28829 .49337 .28719 .48967 .2867 Mtetra
.273 .771 .886 r
.48967 .2867 .49337 .28719 .49993 .28624 .49625 .28573 Mtetra
.248 .754 .878 r
.49625 .28573 .49993 .28624 .50652 .28544 .50285 .2849 Mtetra
.223 .737 .87 r
.50285 .2849 .50652 .28544 .51313 .28477 .50948 .28421 Mtetra
.198 .72 .862 r
.50948 .28421 .51313 .28477 .51976 .28425 .51613 .28366 Mtetra
.175 .704 .854 r
.51613 .28366 .51976 .28425 .52641 .28386 .5228 .28325 Mtetra
.152 .687 .846 r
.5228 .28325 .52641 .28386 .53309 .2836 .52949 .28297 Mtetra
.13 .671 .838 r
.52949 .28297 .53309 .2836 .5398 .28348 .53622 .28282 Mtetra
.109 .655 .831 r
.53622 .28282 .5398 .28348 .54653 .2835 .54296 .2828 Mtetra
.09 .64 .824 r
.54296 .2828 .54653 .2835 .55329 .28364 .54974 .28291 Mtetra
.071 .625 .817 r
.54974 .28291 .55329 .28364 .56008 .2839 .55655 .28314 Mtetra
.054 .611 .811 r
.55655 .28314 .56008 .2839 .5669 .28429 .56338 .28349 Mtetra
.037 .597 .806 r
.56338 .28349 .5669 .28429 .57375 .28479 .57025 .28396 Mtetra
.022 .585 .801 r
.57025 .28396 .57375 .28479 .58063 .28541 .57714 .28455 Mtetra
.009 .573 .797 r
.57714 .28455 .58063 .28541 .58755 .28615 .58407 .28524 Mtetra
0 .562 .793 r
.58407 .28524 .58755 .28615 .5945 .28699 .59103 .28604 Mtetra
0 .552 .791 r
.59103 .28604 .5945 .28699 .60148 .28793 .59803 .28694 Mtetra
0 .543 .789 r
.59803 .28694 .60148 .28793 .60849 .28897 .60506 .28793 Mtetra
0 .535 .787 r
.60506 .28793 .60849 .28897 .61555 .29011 .61213 .28902 Mtetra
0 .528 .787 r
.61213 .28902 .61555 .29011 .62264 .29133 .61923 .2902 Mtetra
0 .522 .788 r
.61923 .2902 .62264 .29133 .62976 .29264 .62637 .29145 Mtetra
0 .517 .789 r
.62637 .29145 .62976 .29264 .63692 .29402 .63355 .29279 Mtetra
0 .513 .791 r
.63355 .29279 .63692 .29402 .64413 .29548 .64076 .29419 Mtetra
0 .511 .794 r
.64076 .29419 .64413 .29548 .65137 .29701 .64802 .29566 Mtetra
0 .509 .798 r
.64802 .29566 .65137 .29701 .65864 .29859 .65531 .29718 Mtetra
0 .508 .803 r
.65531 .29718 .65864 .29859 .66596 .30022 .66264 .29875 Mtetra
0 .509 .808 r
.66264 .29875 .66596 .30022 .67332 .3019 .67001 .30037 Mtetra
0 .51 .815 r
.67001 .30037 .67332 .3019 .68072 .30362 .67742 .30202 Mtetra
0 .513 .822 r
.67742 .30202 .68072 .30362 .68815 .30537 .68487 .3037 Mtetra
0 .516 .829 r
.68487 .3037 .68815 .30537 .69563 .30714 .69236 .3054 Mtetra
0 .521 .838 r
.69236 .3054 .69563 .30714 .70314 .30892 .69988 .30711 Mtetra
0 .527 .847 r
.69988 .30711 .70314 .30892 .7107 .3107 .70745 .30882 Mtetra
.011 .533 .856 r
.70745 .30882 .7107 .3107 .71829 .31249 .71506 .31052 Mtetra
.025 .541 .866 r
.71506 .31052 .71829 .31249 .72593 .31425 .7227 .31221 Mtetra
.042 .549 .877 r
.7227 .31221 .72593 .31425 .7336 .316 .73038 .31387 Mtetra
.06 .559 .887 r
.73038 .31387 .7336 .316 .74131 .3177 .7381 .31549 Mtetra
.08 .569 .898 r
.7381 .31549 .74131 .3177 .74905 .31937 .74586 .31707 Mtetra
.101 .579 .909 r
.74586 .31707 .74905 .31937 .75684 .32097 .75365 .31858 Mtetra
.124 .591 .919 r
.75365 .31858 .75684 .32097 .76465 .32251 .76148 .32002 Mtetra
.148 .602 .929 r
.76148 .32002 .76465 .32251 .7725 .32396 .76934 .32138 Mtetra
.173 .614 .939 r
.76934 .32138 .7725 .32396 .78039 .32533 .77723 .32264 Mtetra
.2 .627 .948 r
.77723 .32264 .78039 .32533 .7883 .32658 .78515 .3238 Mtetra
.824 .861 .874 r
.11214 .54171 .11674 .54357 .12313 .53814 .11853 .53636 Mtetra
.828 .865 .873 r
.11853 .53636 .12313 .53814 .12953 .5326 .12494 .5309 Mtetra
.832 .869 .871 r
.12494 .5309 .12953 .5326 .13595 .52696 .13137 .52533 Mtetra
.836 .873 .87 r
.13137 .52533 .13595 .52696 .14238 .52123 .1378 .51968 Mtetra
.839 .876 .869 r
.1378 .51968 .14238 .52123 .14881 .51543 .14424 .51395 Mtetra
.842 .88 .869 r
.14424 .51395 .14881 .51543 .15526 .50956 .1507 .50815 Mtetra
.845 .884 .868 r
.1507 .50815 .15526 .50956 .16171 .50364 .15716 .5023 Mtetra
.847 .888 .868 r
.15716 .5023 .16171 .50364 .16817 .49767 .16362 .4964 Mtetra
.849 .891 .868 r
.16362 .4964 .16817 .49767 .17462 .49167 .17009 .49046 Mtetra
.85 .895 .869 r
.17009 .49046 .17462 .49167 .18109 .48564 .17656 .4845 Mtetra
.851 .899 .869 r
.17656 .4845 .18109 .48564 .18755 .4796 .18304 .47852 Mtetra
.852 .902 .87 r
.18304 .47852 .18755 .4796 .19401 .47356 .18951 .47252 Mtetra
.853 .906 .871 r
.18951 .47252 .19401 .47356 .20047 .46751 .19599 .46653 Mtetra
.853 .91 .872 r
.19599 .46653 .20047 .46751 .20693 .46148 .20246 .46055 Mtetra
.853 .913 .873 r
.20246 .46055 .20693 .46148 .21339 .45546 .20893 .45459 Mtetra
.853 .917 .875 r
.20893 .45459 .21339 .45546 .21984 .44948 .2154 .44864 Mtetra
.852 .921 .876 r
.2154 .44864 .21984 .44948 .2263 .44352 .22186 .44273 Mtetra
.851 .924 .878 r
.22186 .44273 .2263 .44352 .23274 .43761 .22833 .43686 Mtetra
.85 .928 .88 r
.22833 .43686 .23274 .43761 .23919 .43174 .23478 .43104 Mtetra
.848 .932 .882 r
.23478 .43104 .23919 .43174 .24563 .42593 .24124 .42527 Mtetra
.846 .935 .884 r
.24124 .42527 .24563 .42593 .25206 .42018 .24769 .41955 Mtetra
.843 .939 .887 r
.24769 .41955 .25206 .42018 .25849 .41449 .25413 .4139 Mtetra
.84 .942 .889 r
.25413 .4139 .25849 .41449 .26491 .40888 .26057 .40832 Mtetra
.837 .946 .892 r
.26057 .40832 .26491 .40888 .27133 .40335 .26701 .40282 Mtetra
.833 .949 .895 r
.26701 .40282 .27133 .40335 .27775 .3979 .27344 .3974 Mtetra
.829 .952 .898 r
.27344 .3974 .27775 .3979 .28416 .39254 .27987 .39207 Mtetra
.824 .955 .901 r
.27987 .39207 .28416 .39254 .29056 .38727 .28629 .38683 Mtetra
.818 .958 .904 r
.28629 .38683 .29056 .38727 .29696 .3821 .2927 .38168 Mtetra
.812 .96 .907 r
.2927 .38168 .29696 .3821 .30336 .37703 .29912 .37664 Mtetra
.806 .963 .91 r
.29912 .37664 .30336 .37703 .30975 .37207 .30553 .37169 Mtetra
.798 .965 .914 r
.30553 .37169 .30975 .37207 .31614 .36722 .31193 .36686 Mtetra
.79 .967 .917 r
.31193 .36686 .31614 .36722 .32252 .36248 .31834 .36214 Mtetra
.782 .968 .92 r
.31834 .36214 .32252 .36248 .32891 .35786 .32474 .35754 Mtetra
.772 .969 .923 r
.32474 .35754 .32891 .35786 .33529 .35336 .33113 .35305 Mtetra
.762 .97 .926 r
.33113 .35305 .33529 .35336 .34166 .34899 .33753 .34869 Mtetra
.75 .97 .929 r
.33753 .34869 .34166 .34899 .34804 .34474 .34393 .34445 Mtetra
.738 .97 .931 r
.34393 .34445 .34804 .34474 .35442 .34062 .35032 .34034 Mtetra
.725 .969 .933 r
.35032 .34034 .35442 .34062 .3608 .33663 .35672 .33636 Mtetra
.711 .968 .936 r
.35672 .33636 .3608 .33663 .36717 .33278 .36311 .33251 Mtetra
.696 .965 .937 r
.36311 .33251 .36717 .33278 .37355 .32906 .36951 .3288 Mtetra
.68 .963 .939 r
.36951 .3288 .37355 .32906 .37994 .32548 .37591 .32522 Mtetra
.663 .959 .94 r
.37591 .32522 .37994 .32548 .38632 .32203 .38231 .32179 Mtetra
.645 .954 .94 r
.38231 .32179 .38632 .32203 .39271 .31873 .38872 .31849 Mtetra
.627 .949 .94 r
.38872 .31849 .39271 .31873 .39911 .31558 .39513 .31533 Mtetra
.607 .943 .94 r
.39513 .31533 .39911 .31558 .40551 .31256 .40155 .31231 Mtetra
.586 .936 .939 r
.40155 .31231 .40551 .31256 .41191 .30969 .40798 .30944 Mtetra
.564 .927 .937 r
.40798 .30944 .41191 .30969 .41833 .30697 .41441 .30671 Mtetra
.541 .918 .935 r
.41441 .30671 .41833 .30697 .42475 .30439 .42085 .30413 Mtetra
.517 .908 .932 r
.42085 .30413 .42475 .30439 .43118 .30196 .4273 .30169 Mtetra
.493 .897 .928 r
.4273 .30169 .43118 .30196 .43763 .29968 .43376 .2994 Mtetra
.468 .885 .924 r
.43376 .2994 .43763 .29968 .44408 .29754 .44023 .29726 Mtetra
.443 .873 .919 r
.44023 .29726 .44408 .29754 .45055 .29555 .44672 .29526 Mtetra
.417 .859 .914 r
.44672 .29526 .45055 .29555 .45703 .29371 .45322 .2934 Mtetra
.391 .845 .908 r
.45322 .2934 .45703 .29371 .46352 .29202 .45973 .2917 Mtetra
.364 .83 .901 r
.45973 .2917 .46352 .29202 .47003 .29047 .46626 .29013 Mtetra
.338 .814 .894 r
.46626 .29013 .47003 .29047 .47656 .28907 .4728 .28871 Mtetra
.312 .798 .887 r
.4728 .28871 .47656 .28907 .48311 .28781 .47936 .28744 Mtetra
.286 .781 .879 r
.47936 .28744 .48311 .28781 .48967 .2867 .48594 .28631 Mtetra
.26 .765 .871 r
.48594 .28631 .48967 .2867 .49625 .28573 .49254 .28532 Mtetra
.235 .748 .863 r
.49254 .28532 .49625 .28573 .50285 .2849 .49916 .28447 Mtetra
.21 .731 .855 r
.49916 .28447 .50285 .2849 .50948 .28421 .5058 .28375 Mtetra
.186 .714 .847 r
.5058 .28375 .50948 .28421 .51613 .28366 .51247 .28318 Mtetra
.163 .697 .839 r
.51247 .28318 .51613 .28366 .5228 .28325 .51915 .28274 Mtetra
.141 .681 .832 r
.51915 .28274 .5228 .28325 .52949 .28297 .52587 .28243 Mtetra
.119 .665 .824 r
.52587 .28243 .52949 .28297 .53622 .28282 .53261 .28225 Mtetra
.099 .649 .817 r
.53261 .28225 .53622 .28282 .54296 .2828 .53937 .2822 Mtetra
.08 .634 .81 r
.53937 .2822 .54296 .2828 .54974 .28291 .54616 .28228 Mtetra
.062 .62 .804 r
.54616 .28228 .54974 .28291 .55655 .28314 .55298 .28247 Mtetra
.045 .606 .799 r
.55298 .28247 .55655 .28314 .56338 .28349 .55984 .28279 Mtetra
.029 .593 .793 r
.55984 .28279 .56338 .28349 .57025 .28396 .56672 .28322 Mtetra
.015 .581 .789 r
.56672 .28322 .57025 .28396 .57714 .28455 .57363 .28376 Mtetra
.002 .57 .785 r
.57363 .28376 .57714 .28455 .58407 .28524 .58057 .28442 Mtetra
0 .56 .782 r
.58057 .28442 .58407 .28524 .59103 .28604 .58755 .28517 Mtetra
0 .55 .78 r
.58755 .28517 .59103 .28604 .59803 .28694 .59456 .28603 Mtetra
0 .542 .779 r
.59456 .28603 .59803 .28694 .60506 .28793 .60161 .28698 Mtetra
0 .534 .778 r
.60161 .28698 .60506 .28793 .61213 .28902 .60869 .28801 Mtetra
0 .528 .779 r
.60869 .28801 .61213 .28902 .61923 .2902 .61581 .28914 Mtetra
0 .522 .78 r
.61581 .28914 .61923 .2902 .62637 .29145 .62296 .29034 Mtetra
0 .518 .782 r
.62296 .29034 .62637 .29145 .63355 .29279 .63015 .29162 Mtetra
0 .515 .785 r
.63015 .29162 .63355 .29279 .64076 .29419 .63738 .29297 Mtetra
0 .512 .788 r
.63738 .29297 .64076 .29419 .64802 .29566 .64465 .29437 Mtetra
0 .511 .793 r
.64465 .29437 .64802 .29566 .65531 .29718 .65195 .29584 Mtetra
0 .511 .798 r
.65195 .29584 .65531 .29718 .66264 .29875 .6593 .29734 Mtetra
0 .512 .805 r
.6593 .29734 .66264 .29875 .67001 .30037 .66668 .2989 Mtetra
0 .514 .812 r
.66668 .2989 .67001 .30037 .67742 .30202 .6741 .30048 Mtetra
0 .517 .819 r
.6741 .30048 .67742 .30202 .68487 .3037 .68157 .30209 Mtetra
0 .521 .828 r
.68157 .30209 .68487 .3037 .69236 .3054 .68907 .30371 Mtetra
0 .526 .837 r
.68907 .30371 .69236 .3054 .69988 .30711 .69661 .30535 Mtetra
.001 .533 .847 r
.69661 .30535 .69988 .30711 .70745 .30882 .70419 .30698 Mtetra
.015 .54 .857 r
.70419 .30698 .70745 .30882 .71506 .31052 .7118 .3086 Mtetra
.031 .548 .867 r
.7118 .3086 .71506 .31052 .7227 .31221 .71946 .3102 Mtetra
.048 .557 .878 r
.71946 .3102 .7227 .31221 .73038 .31387 .72715 .31178 Mtetra
.067 .566 .889 r
.72715 .31178 .73038 .31387 .7381 .31549 .73488 .31331 Mtetra
.087 .577 .9 r
.73488 .31331 .7381 .31549 .74586 .31707 .74265 .31479 Mtetra
.109 .588 .912 r
.74265 .31479 .74586 .31707 .75365 .31858 .75045 .31621 Mtetra
.133 .599 .922 r
.75045 .31621 .75365 .31858 .76148 .32002 .75828 .31755 Mtetra
.158 .611 .933 r
.75828 .31755 .76148 .32002 .76934 .32138 .76615 .31881 Mtetra
.184 .623 .943 r
.76615 .31881 .76934 .32138 .77723 .32264 .77405 .31997 Mtetra
.211 .636 .952 r
.77405 .31997 .77723 .32264 .78515 .3238 .78198 .32102 Mtetra
.821 .863 .878 r
.10751 .53985 .11214 .54171 .11853 .53636 .11391 .53458 Mtetra
.826 .867 .876 r
.11391 .53458 .11853 .53636 .12494 .5309 .12032 .52921 Mtetra
.83 .871 .875 r
.12032 .52921 .12494 .5309 .13137 .52533 .12675 .52373 Mtetra
.834 .875 .874 r
.12675 .52373 .13137 .52533 .1378 .51968 .13319 .51815 Mtetra
.837 .879 .873 r
.13319 .51815 .1378 .51968 .14424 .51395 .13965 .5125 Mtetra
.84 .883 .872 r
.13965 .5125 .14424 .51395 .1507 .50815 .14611 .50678 Mtetra
.843 .887 .872 r
.14611 .50678 .1507 .50815 .15716 .5023 .15257 .50099 Mtetra
.845 .891 .872 r
.15257 .50099 .15716 .5023 .16362 .4964 .15905 .49516 Mtetra
.847 .894 .872 r
.15905 .49516 .16362 .4964 .17009 .49046 .16553 .48929 Mtetra
.848 .898 .872 r
.16553 .48929 .17009 .49046 .17656 .4845 .17201 .48339 Mtetra
.85 .902 .872 r
.17201 .48339 .17656 .4845 .18304 .47852 .17849 .47747 Mtetra
.851 .906 .873 r
.17849 .47747 .18304 .47852 .18951 .47252 .18498 .47154 Mtetra
.851 .91 .874 r
.18498 .47154 .18951 .47252 .19599 .46653 .19147 .4656 Mtetra
.851 .913 .875 r
.19147 .4656 .19599 .46653 .20246 .46055 .19795 .45968 Mtetra
.851 .917 .876 r
.19795 .45968 .20246 .46055 .20893 .45459 .20444 .45376 Mtetra
.851 .921 .877 r
.20444 .45376 .20893 .45459 .2154 .44864 .21092 .44787 Mtetra
.85 .925 .879 r
.21092 .44787 .2154 .44864 .22186 .44273 .2174 .44201 Mtetra
.849 .929 .881 r
.2174 .44201 .22186 .44273 .22833 .43686 .22388 .43618 Mtetra
.848 .932 .883 r
.22388 .43618 .22833 .43686 .23478 .43104 .23035 .4304 Mtetra
.846 .936 .885 r
.23035 .4304 .23478 .43104 .24124 .42527 .23682 .42467 Mtetra
.844 .939 .887 r
.23682 .42467 .24124 .42527 .24769 .41955 .24328 .41899 Mtetra
.841 .943 .889 r
.24328 .41899 .24769 .41955 .25413 .4139 .24974 .41338 Mtetra
.838 .946 .891 r
.24974 .41338 .25413 .4139 .26057 .40832 .2562 .40784 Mtetra
.834 .95 .894 r
.2562 .40784 .26057 .40832 .26701 .40282 .26265 .40237 Mtetra
.83 .953 .897 r
.26265 .40237 .26701 .40282 .27344 .3974 .2691 .39698 Mtetra
.826 .956 .899 r
.2691 .39698 .27344 .3974 .27987 .39207 .27554 .39168 Mtetra
.821 .959 .902 r
.27554 .39168 .27987 .39207 .28629 .38683 .28198 .38646 Mtetra
.815 .962 .905 r
.28198 .38646 .28629 .38683 .2927 .38168 .28841 .38134 Mtetra
.808 .964 .908 r
.28841 .38134 .2927 .38168 .29912 .37664 .29484 .37632 Mtetra
.802 .967 .911 r
.29484 .37632 .29912 .37664 .30553 .37169 .30127 .3714 Mtetra
.794 .969 .914 r
.30127 .3714 .30553 .37169 .31193 .36686 .30769 .36659 Mtetra
.785 .97 .916 r
.30769 .36659 .31193 .36686 .31834 .36214 .31411 .36189 Mtetra
.776 .972 .919 r
.31411 .36189 .31834 .36214 .32474 .35754 .32053 .3573 Mtetra
.766 .972 .922 r
.32053 .3573 .32474 .35754 .33113 .35305 .32695 .35283 Mtetra
.756 .973 .924 r
.32695 .35283 .33113 .35305 .33753 .34869 .33336 .34849 Mtetra
.744 .973 .927 r
.33336 .34849 .33753 .34869 .34393 .34445 .33977 .34426 Mtetra
.731 .972 .929 r
.33977 .34426 .34393 .34445 .35032 .34034 .34619 .34016 Mtetra
.718 .971 .931 r
.34619 .34016 .35032 .34034 .35672 .33636 .3526 .33619 Mtetra
.703 .969 .932 r
.3526 .33619 .35672 .33636 .36311 .33251 .35902 .33235 Mtetra
.688 .966 .933 r
.35902 .33235 .36311 .33251 .36951 .3288 .36543 .32864 Mtetra
.671 .963 .934 r
.36543 .32864 .36951 .3288 .37591 .32522 .37185 .32507 Mtetra
.654 .959 .935 r
.37185 .32507 .37591 .32522 .38231 .32179 .37827 .32164 Mtetra
.635 .954 .935 r
.37827 .32164 .38231 .32179 .38872 .31849 .3847 .31834 Mtetra
.616 .948 .934 r
.3847 .31834 .38872 .31849 .39513 .31533 .39113 .31518 Mtetra
.595 .941 .933 r
.39113 .31518 .39513 .31533 .40155 .31231 .39757 .31216 Mtetra
.574 .934 .931 r
.39757 .31216 .40155 .31231 .40798 .30944 .40401 .30929 Mtetra
.552 .925 .929 r
.40401 .30929 .40798 .30944 .41441 .30671 .41046 .30656 Mtetra
.529 .915 .926 r
.41046 .30656 .41441 .30671 .42085 .30413 .41692 .30397 Mtetra
.505 .905 .922 r
.41692 .30397 .42085 .30413 .4273 .30169 .42339 .30153 Mtetra
.48 .893 .918 r
.42339 .30153 .4273 .30169 .43376 .2994 .42987 .29923 Mtetra
.455 .881 .913 r
.42987 .29923 .43376 .2994 .44023 .29726 .43636 .29707 Mtetra
.43 .868 .908 r
.43636 .29707 .44023 .29726 .44672 .29526 .44286 .29506 Mtetra
.404 .854 .902 r
.44286 .29506 .44672 .29526 .45322 .2934 .44937 .29319 Mtetra
.377 .839 .895 r
.44937 .29319 .45322 .2934 .45973 .2917 .4559 .29147 Mtetra
.351 .824 .888 r
.4559 .29147 .45973 .2917 .46626 .29013 .46245 .28989 Mtetra
.325 .808 .881 r
.46245 .28989 .46626 .29013 .4728 .28871 .46901 .28846 Mtetra
.299 .792 .873 r
.46901 .28846 .4728 .28871 .47936 .28744 .47559 .28717 Mtetra
.273 .775 .866 r
.47559 .28717 .47936 .28744 .48594 .28631 .48219 .28601 Mtetra
.248 .758 .858 r
.48219 .28601 .48594 .28631 .49254 .28532 .4888 .285 Mtetra
.223 .741 .849 r
.4888 .285 .49254 .28532 .49916 .28447 .49544 .28413 Mtetra
.199 .725 .841 r
.49544 .28413 .49916 .28447 .5058 .28375 .5021 .28339 Mtetra
.175 .708 .833 r
.5021 .28339 .5058 .28375 .51247 .28318 .50878 .28279 Mtetra
.152 .691 .825 r
.50878 .28279 .51247 .28318 .51915 .28274 .51549 .28232 Mtetra
.131 .675 .818 r
.51549 .28232 .51915 .28274 .52587 .28243 .52222 .28198 Mtetra
.11 .66 .811 r
.52222 .28198 .52587 .28243 .53261 .28225 .52897 .28177 Mtetra
.09 .644 .804 r
.52897 .28177 .53261 .28225 .53937 .2822 .53575 .28169 Mtetra
.071 .63 .798 r
.53575 .28169 .53937 .2822 .54616 .28228 .54256 .28173 Mtetra
.054 .616 .792 r
.54256 .28173 .54616 .28228 .55298 .28247 .5494 .28189 Mtetra
.038 .602 .786 r
.5494 .28189 .55298 .28247 .55984 .28279 .55627 .28217 Mtetra
.023 .59 .782 r
.55627 .28217 .55984 .28279 .56672 .28322 .56316 .28256 Mtetra
.009 .578 .778 r
.56316 .28256 .56672 .28322 .57363 .28376 .57009 .28307 Mtetra
0 .568 .775 r
.57009 .28307 .57363 .28376 .58057 .28442 .57705 .28367 Mtetra
0 .558 .772 r
.57705 .28367 .58057 .28442 .58755 .28517 .58405 .28438 Mtetra
0 .549 .771 r
.58405 .28438 .58755 .28517 .59456 .28603 .59107 .28519 Mtetra
0 .541 .77 r
.59107 .28519 .59456 .28603 .60161 .28698 .59813 .28609 Mtetra
0 .534 .77 r
.59813 .28609 .60161 .28698 .60869 .28801 .60523 .28708 Mtetra
0 .528 .771 r
.60523 .28708 .60869 .28801 .61581 .28914 .61236 .28815 Mtetra
0 .523 .773 r
.61236 .28815 .61581 .28914 .62296 .29034 .61953 .2893 Mtetra
0 .519 .776 r
.61953 .2893 .62296 .29034 .63015 .29162 .62674 .29052 Mtetra
0 .516 .779 r
.62674 .29052 .63015 .29162 .63738 .29297 .63398 .29181 Mtetra
0 .515 .784 r
.63398 .29181 .63738 .29297 .64465 .29437 .64126 .29315 Mtetra
0 .514 .789 r
.64126 .29315 .64465 .29437 .65195 .29584 .64858 .29455 Mtetra
0 .514 .795 r
.64858 .29455 .65195 .29584 .6593 .29734 .65594 .29599 Mtetra
0 .516 .802 r
.65594 .29599 .6593 .29734 .66668 .2989 .66334 .29747 Mtetra
0 .519 .81 r
.66334 .29747 .66668 .2989 .6741 .30048 .67077 .29899 Mtetra
0 .522 .818 r
.67077 .29899 .6741 .30048 .68157 .30209 .67824 .30052 Mtetra
0 .527 .827 r
.67824 .30052 .68157 .30209 .68907 .30371 .68576 .30207 Mtetra
0 .533 .837 r
.68576 .30207 .68907 .30371 .69661 .30535 .69331 .30362 Mtetra
.006 .539 .847 r
.69331 .30362 .69661 .30535 .70419 .30698 .7009 .30517 Mtetra
.021 .547 .858 r
.7009 .30517 .70419 .30698 .7118 .3086 .70853 .30671 Mtetra
.038 .555 .869 r
.70853 .30671 .7118 .3086 .71946 .3102 .7162 .30823 Mtetra
.056 .565 .881 r
.7162 .30823 .71946 .3102 .72715 .31178 .7239 .30971 Mtetra
.075 .575 .892 r
.7239 .30971 .72715 .31178 .73488 .31331 .73164 .31115 Mtetra
.097 .586 .904 r
.73164 .31115 .73488 .31331 .74265 .31479 .73942 .31253 Mtetra
.119 .597 .915 r
.73942 .31253 .74265 .31479 .75045 .31621 .74723 .31385 Mtetra
.143 .609 .926 r
.74723 .31385 .75045 .31621 .75828 .31755 .75507 .3151 Mtetra
.169 .621 .937 r
.75507 .3151 .75828 .31755 .76615 .31881 .76295 .31625 Mtetra
.196 .633 .947 r
.76295 .31625 .76615 .31881 .77405 .31997 .77086 .3173 Mtetra
.223 .645 .956 r
.77086 .3173 .77405 .31997 .78198 .32102 .77879 .31823 Mtetra
.818 .864 .881 r
.10286 .53798 .10751 .53985 .11391 .53458 .10926 .53281 Mtetra
.823 .868 .88 r
.10926 .53281 .11391 .53458 .12032 .52921 .11568 .52752 Mtetra
.827 .873 .878 r
.11568 .52752 .12032 .52921 .12675 .52373 .12211 .52213 Mtetra
.831 .877 .877 r
.12211 .52213 .12675 .52373 .13319 .51815 .12856 .51664 Mtetra
.834 .881 .876 r
.12856 .51664 .13319 .51815 .13965 .5125 .13502 .51106 Mtetra
.838 .885 .876 r
.13502 .51106 .13965 .5125 .14611 .50678 .14148 .50542 Mtetra
.84 .889 .875 r
.14148 .50542 .14611 .50678 .15257 .50099 .14796 .49971 Mtetra
.843 .893 .875 r
.14796 .49971 .15257 .50099 .15905 .49516 .15444 .49395 Mtetra
.845 .897 .875 r
.15444 .49395 .15905 .49516 .16553 .48929 .16093 .48815 Mtetra
.846 .901 .875 r
.16093 .48815 .16553 .48929 .17201 .48339 .16743 .48232 Mtetra
.848 .905 .875 r
.16743 .48232 .17201 .48339 .17849 .47747 .17392 .47646 Mtetra
.848 .909 .876 r
.17392 .47646 .17849 .47747 .18498 .47154 .18042 .47059 Mtetra
.849 .913 .877 r
.18042 .47059 .18498 .47154 .19147 .4656 .18692 .46472 Mtetra
.849 .917 .878 r
.18692 .46472 .19147 .4656 .19795 .45968 .19341 .45885 Mtetra
.849 .921 .879 r
.19341 .45885 .19795 .45968 .20444 .45376 .19991 .45299 Mtetra
.849 .925 .88 r
.19991 .45299 .20444 .45376 .21092 .44787 .20641 .44715 Mtetra
.848 .928 .882 r
.20641 .44715 .21092 .44787 .2174 .44201 .2129 .44134 Mtetra
.847 .932 .883 r
.2129 .44134 .2174 .44201 .22388 .43618 .21939 .43556 Mtetra
.845 .936 .885 r
.21939 .43556 .22388 .43618 .23035 .4304 .22588 .42982 Mtetra
.844 .94 .887 r
.22588 .42982 .23035 .4304 .23682 .42467 .23236 .42414 Mtetra
.841 .943 .889 r
.23236 .42414 .23682 .42467 .24328 .41899 .23884 .4185 Mtetra
.838 .947 .891 r
.23884 .4185 .24328 .41899 .24974 .41338 .24532 .41293 Mtetra
.835 .95 .893 r
.24532 .41293 .24974 .41338 .2562 .40784 .25179 .40742 Mtetra
.831 .954 .896 r
.25179 .40742 .2562 .40784 .26265 .40237 .25826 .40199 Mtetra
.827 .957 .898 r
.25826 .40199 .26265 .40237 .2691 .39698 .26472 .39663 Mtetra
.822 .96 .901 r
.26472 .39663 .2691 .39698 .27554 .39168 .27118 .39136 Mtetra
.817 .963 .903 r
.27118 .39136 .27554 .39168 .28198 .38646 .27764 .38618 Mtetra
.811 .965 .906 r
.27764 .38618 .28198 .38646 .28841 .38134 .28409 .38108 Mtetra
.804 .968 .908 r
.28409 .38108 .28841 .38134 .29484 .37632 .29053 .37609 Mtetra
.797 .97 .911 r
.29053 .37609 .29484 .37632 .30127 .3714 .29698 .37119 Mtetra
.789 .972 .914 r
.29698 .37119 .30127 .3714 .30769 .36659 .30342 .3664 Mtetra
.78 .973 .916 r
.30342 .3664 .30769 .36659 .31411 .36189 .30986 .36172 Mtetra
.771 .974 .918 r
.30986 .36172 .31411 .36189 .32053 .3573 .31629 .35715 Mtetra
.76 .975 .921 r
.31629 .35715 .32053 .3573 .32695 .35283 .32273 .3527 Mtetra
.749 .975 .923 r
.32273 .3527 .32695 .35283 .33336 .34849 .32916 .34837 Mtetra
.737 .975 .925 r
.32916 .34837 .33336 .34849 .33977 .34426 .33559 .34416 Mtetra
.724 .974 .926 r
.33559 .34416 .33977 .34426 .34619 .34016 .34202 .34007 Mtetra
.71 .972 .928 r
.34202 .34007 .34619 .34016 .3526 .33619 .34845 .33611 Mtetra
.695 .97 .929 r
.34845 .33611 .3526 .33619 .35902 .33235 .35489 .33228 Mtetra
.679 .967 .929 r
.35489 .33228 .35902 .33235 .36543 .32864 .36132 .32858 Mtetra
.662 .963 .93 r
.36132 .32858 .36543 .32864 .37185 .32507 .36776 .32501 Mtetra
.644 .958 .929 r
.36776 .32501 .37185 .32507 .37827 .32164 .3742 .32158 Mtetra
.625 .953 .929 r
.3742 .32158 .37827 .32164 .3847 .31834 .38064 .31828 Mtetra
.605 .946 .927 r
.38064 .31828 .3847 .31834 .39113 .31518 .38709 .31513 Mtetra
.584 .939 .925 r
.38709 .31513 .39113 .31518 .39757 .31216 .39355 .31211 Mtetra
.563 .931 .923 r
.39355 .31211 .39757 .31216 .40401 .30929 .40001 .30923 Mtetra
.54 .922 .92 r
.40001 .30923 .40401 .30929 .41046 .30656 .40648 .3065 Mtetra
.517 .912 .916 r
.40648 .3065 .41046 .30656 .41692 .30397 .41295 .3039 Mtetra
.492 .9 .912 r
.41295 .3039 .41692 .30397 .42339 .30153 .41944 .30145 Mtetra
.468 .889 .907 r
.41944 .30145 .42339 .30153 .42987 .29923 .42594 .29914 Mtetra
.443 .876 .902 r
.42594 .29914 .42987 .29923 .43636 .29707 .43245 .29698 Mtetra
.417 .862 .896 r
.43245 .29698 .43636 .29707 .44286 .29506 .43897 .29496 Mtetra
.391 .848 .89 r
.43897 .29496 .44286 .29506 .44937 .29319 .4455 .29308 Mtetra
.365 .833 .883 r
.4455 .29308 .44937 .29319 .4559 .29147 .45205 .29134 Mtetra
.339 .817 .876 r
.45205 .29134 .4559 .29147 .46245 .28989 .45861 .28975 Mtetra
.313 .801 .868 r
.45861 .28975 .46245 .28989 .46901 .28846 .46519 .2883 Mtetra
.287 .785 .86 r
.46519 .2883 .46901 .28846 .47559 .28717 .47179 .28698 Mtetra
.261 .769 .852 r
.47179 .28698 .47559 .28717 .48219 .28601 .47841 .28581 Mtetra
.236 .752 .844 r
.47841 .28581 .48219 .28601 .4888 .285 .48504 .28478 Mtetra
.212 .735 .836 r
.48504 .28478 .4888 .285 .49544 .28413 .49169 .28388 Mtetra
.188 .719 .828 r
.49169 .28388 .49544 .28413 .5021 .28339 .49837 .28312 Mtetra
.165 .702 .82 r
.49837 .28312 .5021 .28339 .50878 .28279 .50507 .28249 Mtetra
.143 .686 .812 r
.50507 .28249 .50878 .28279 .51549 .28232 .51179 .28199 Mtetra
.122 .67 .805 r
.51179 .28199 .51549 .28232 .52222 .28198 .51854 .28162 Mtetra
.101 .655 .798 r
.51854 .28162 .52222 .28198 .52897 .28177 .52531 .28138 Mtetra
.082 .64 .791 r
.52531 .28138 .52897 .28177 .53575 .28169 .53211 .28127 Mtetra
.064 .626 .786 r
.53211 .28127 .53575 .28169 .54256 .28173 .53894 .28127 Mtetra
.047 .612 .78 r
.53894 .28127 .54256 .28173 .5494 .28189 .54579 .2814 Mtetra
.032 .599 .775 r
.54579 .2814 .5494 .28189 .55627 .28217 .55267 .28163 Mtetra
.017 .587 .771 r
.55267 .28163 .55627 .28217 .56316 .28256 .55959 .28199 Mtetra
.004 .576 .768 r
.55959 .28199 .56316 .28256 .57009 .28307 .56653 .28244 Mtetra
0 .566 .765 r
.56653 .28244 .57009 .28307 .57705 .28367 .57351 .28301 Mtetra
0 .556 .763 r
.57351 .28301 .57705 .28367 .58405 .28438 .58052 .28367 Mtetra
0 .548 .762 r
.58052 .28367 .58405 .28438 .59107 .28519 .58756 .28443 Mtetra
0 .541 .762 r
.58756 .28443 .59107 .28519 .59813 .28609 .59464 .28528 Mtetra
0 .534 .763 r
.59464 .28528 .59813 .28609 .60523 .28708 .60175 .28621 Mtetra
0 .529 .765 r
.60175 .28621 .60523 .28708 .61236 .28815 .6089 .28723 Mtetra
0 .524 .767 r
.6089 .28723 .61236 .28815 .61953 .2893 .61608 .28832 Mtetra
0 .521 .77 r
.61608 .28832 .61953 .2893 .62674 .29052 .6233 .28948 Mtetra
0 .519 .775 r
.6233 .28948 .62674 .29052 .63398 .29181 .63056 .29071 Mtetra
0 .518 .78 r
.63056 .29071 .63398 .29181 .64126 .29315 .63785 .29199 Mtetra
0 .518 .786 r
.63785 .29199 .64126 .29315 .64858 .29455 .64519 .29332 Mtetra
0 .519 .793 r
.64519 .29332 .64858 .29455 .65594 .29599 .65256 .29469 Mtetra
0 .521 .8 r
.65256 .29469 .65594 .29599 .66334 .29747 .65997 .2961 Mtetra
0 .524 .809 r
.65997 .2961 .66334 .29747 .67077 .29899 .66742 .29754 Mtetra
0 .528 .818 r
.66742 .29754 .67077 .29899 .67824 .30052 .6749 .29899 Mtetra
0 .533 .827 r
.6749 .29899 .67824 .30052 .68576 .30207 .68243 .30046 Mtetra
0 .54 .838 r
.68243 .30046 .68576 .30207 .69331 .30362 .68999 .30193 Mtetra
.013 .547 .849 r
.68999 .30193 .69331 .30362 .7009 .30517 .6976 .3034 Mtetra
.029 .555 .86 r
.6976 .3034 .7009 .30517 .70853 .30671 .70524 .30485 Mtetra
.046 .564 .872 r
.70524 .30485 .70853 .30671 .7162 .30823 .71291 .30627 Mtetra
.065 .574 .884 r
.71291 .30627 .7162 .30823 .7239 .30971 .72063 .30766 Mtetra
.085 .584 .896 r
.72063 .30766 .7239 .30971 .73164 .31115 .72838 .309 Mtetra
.107 .595 .907 r
.72838 .309 .73164 .31115 .73942 .31253 .73617 .31029 Mtetra
.131 .607 .919 r
.73617 .31029 .73942 .31253 .74723 .31385 .74399 .3115 Mtetra
.155 .619 .93 r
.74399 .3115 .74723 .31385 .75507 .3151 .75184 .31264 Mtetra
.182 .631 .941 r
.75184 .31264 .75507 .3151 .76295 .31625 .75973 .31368 Mtetra
.209 .643 .951 r
.75973 .31368 .76295 .31625 .77086 .3173 .76764 .31462 Mtetra
.237 .655 .96 r
.76764 .31462 .77086 .3173 .77879 .31823 .77559 .31544 Mtetra
.814 .865 .885 r
.09818 .5361 .10286 .53798 .10926 .53281 .10458 .53103 Mtetra
.819 .869 .883 r
.10458 .53103 .10926 .53281 .11568 .52752 .111 .52583 Mtetra
.824 .874 .882 r
.111 .52583 .11568 .52752 .12211 .52213 .11744 .52053 Mtetra
.828 .878 .881 r
.11744 .52053 .12211 .52213 .12856 .51664 .12389 .51513 Mtetra
.832 .883 .88 r
.12389 .51513 .12856 .51664 .13502 .51106 .13036 .50964 Mtetra
.835 .887 .879 r
.13036 .50964 .13502 .51106 .14148 .50542 .13683 .50408 Mtetra
.838 .891 .879 r
.13683 .50408 .14148 .50542 .14796 .49971 .14332 .49845 Mtetra
.84 .896 .878 r
.14332 .49845 .14796 .49971 .15444 .49395 .14981 .49276 Mtetra
.842 .9 .878 r
.14981 .49276 .15444 .49395 .16093 .48815 .15631 .48704 Mtetra
.844 .904 .878 r
.15631 .48704 .16093 .48815 .16743 .48232 .16281 .48127 Mtetra
.845 .908 .879 r
.16281 .48127 .16743 .48232 .17392 .47646 .16931 .47549 Mtetra
.846 .912 .879 r
.16931 .47549 .17392 .47646 .18042 .47059 .17582 .46968 Mtetra
.847 .916 .88 r
.17582 .46968 .18042 .47059 .18692 .46472 .18233 .46387 Mtetra
.847 .92 .881 r
.18233 .46387 .18692 .46472 .19341 .45885 .18884 .45806 Mtetra
.847 .924 .882 r
.18884 .45806 .19341 .45885 .19991 .45299 .19535 .45226 Mtetra
.847 .928 .883 r
.19535 .45226 .19991 .45299 .20641 .44715 .20186 .44647 Mtetra
.846 .932 .884 r
.20186 .44647 .20641 .44715 .2129 .44134 .20837 .44072 Mtetra
.845 .936 .886 r
.20837 .44072 .2129 .44134 .21939 .43556 .21487 .43499 Mtetra
.843 .94 .887 r
.21487 .43499 .21939 .43556 .22588 .42982 .22137 .4293 Mtetra
.841 .943 .889 r
.22137 .4293 .22588 .42982 .23236 .42414 .22787 .42366 Mtetra
.838 .947 .891 r
.22787 .42366 .23236 .42414 .23884 .4185 .23437 .41807 Mtetra
.835 .95 .893 r
.23437 .41807 .23884 .4185 .24532 .41293 .24086 .41254 Mtetra
.832 .954 .895 r
.24086 .41254 .24532 .41293 .25179 .40742 .24735 .40707 Mtetra
.828 .957 .897 r
.24735 .40707 .25179 .40742 .25826 .40199 .25383 .40168 Mtetra
.824 .96 .9 r
.25383 .40168 .25826 .40199 .26472 .39663 .26031 .39635 Mtetra
.819 .963 .902 r
.26031 .39635 .26472 .39663 .27118 .39136 .26679 .39111 Mtetra
.813 .966 .904 r
.26679 .39111 .27118 .39136 .27764 .38618 .27326 .38596 Mtetra
.807 .969 .907 r
.27326 .38596 .27764 .38618 .28409 .38108 .27973 .3809 Mtetra
.8 .971 .909 r
.27973 .3809 .28409 .38108 .29053 .37609 .28619 .37593 Mtetra
.792 .973 .911 r
.28619 .37593 .29053 .37609 .29698 .37119 .29265 .37106 Mtetra
.784 .975 .913 r
.29265 .37106 .29698 .37119 .30342 .3664 .29911 .36629 Mtetra
.775 .976 .915 r
.29911 .36629 .30342 .3664 .30986 .36172 .30557 .36163 Mtetra
.765 .977 .917 r
.30557 .36163 .30986 .36172 .31629 .35715 .31202 .35709 Mtetra
.754 .977 .919 r
.31202 .35709 .31629 .35715 .32273 .3527 .31847 .35265 Mtetra
.742 .977 .921 r
.31847 .35265 .32273 .3527 .32916 .34837 .32492 .34833 Mtetra
.73 .976 .922 r
.32492 .34833 .32916 .34837 .33559 .34416 .33137 .34414 Mtetra
.716 .975 .924 r
.33137 .34414 .33559 .34416 .34202 .34007 .33782 .34006 Mtetra
.702 .973 .924 r
.33782 .34006 .34202 .34007 .34845 .33611 .34427 .33611 Mtetra
.686 .97 .925 r
.34427 .33611 .34845 .33611 .35489 .33228 .35072 .33229 Mtetra
.67 .967 .925 r
.35072 .33229 .35489 .33228 .36132 .32858 .35718 .3286 Mtetra
.653 .962 .924 r
.35718 .3286 .36132 .32858 .36776 .32501 .36363 .32504 Mtetra
.634 .957 .924 r
.36363 .32504 .36776 .32501 .3742 .32158 .37009 .32161 Mtetra
.615 .951 .922 r
.37009 .32161 .3742 .32158 .38064 .31828 .37655 .31832 Mtetra
.595 .944 .92 r
.37655 .31832 .38064 .31828 .38709 .31513 .38302 .31516 Mtetra
.573 .936 .918 r
.38302 .31516 .38709 .31513 .39355 .31211 .3895 .31214 Mtetra
.551 .928 .915 r
.3895 .31214 .39355 .31211 .40001 .30923 .39598 .30927 Mtetra
.528 .918 .911 r
.39598 .30927 .40001 .30923 .40648 .3065 .40246 .30653 Mtetra
.505 .907 .907 r
.40246 .30653 .40648 .3065 .41295 .3039 .40896 .30393 Mtetra
.48 .896 .902 r
.40896 .30393 .41295 .3039 .41944 .30145 .41547 .30147 Mtetra
.456 .884 .897 r
.41547 .30147 .41944 .30145 .42594 .29914 .42198 .29915 Mtetra
.43 .87 .891 r
.42198 .29915 .42594 .29914 .43245 .29698 .42851 .29698 Mtetra
.405 .857 .885 r
.42851 .29698 .43245 .29698 .43897 .29496 .43505 .29495 Mtetra
.379 .842 .878 r
.43505 .29495 .43897 .29496 .4455 .29308 .4416 .29305 Mtetra
.353 .827 .871 r
.4416 .29305 .4455 .29308 .45205 .29134 .44817 .2913 Mtetra
.327 .811 .863 r
.44817 .2913 .45205 .29134 .45861 .28975 .45475 .28969 Mtetra
.301 .795 .855 r
.45475 .28969 .45861 .28975 .46519 .2883 .46135 .28822 Mtetra
.276 .779 .847 r
.46135 .28822 .46519 .2883 .47179 .28698 .46796 .28689 Mtetra
.251 .762 .839 r
.46796 .28689 .47179 .28698 .47841 .28581 .47459 .2857 Mtetra
.226 .746 .831 r
.47459 .2857 .47841 .28581 .48504 .28478 .48125 .28464 Mtetra
.202 .729 .823 r
.48125 .28464 .48504 .28478 .49169 .28388 .48792 .28372 Mtetra
.179 .713 .815 r
.48792 .28372 .49169 .28388 .49837 .28312 .49461 .28293 Mtetra
.156 .697 .807 r
.49461 .28293 .49837 .28312 .50507 .28249 .50133 .28227 Mtetra
.135 .681 .8 r
.50133 .28227 .50507 .28249 .51179 .28199 .50807 .28175 Mtetra
.114 .665 .793 r
.50807 .28175 .51179 .28199 .51854 .28162 .51483 .28135 Mtetra
.094 .65 .786 r
.51483 .28135 .51854 .28162 .52531 .28138 .52162 .28107 Mtetra
.076 .636 .78 r
.52162 .28107 .52531 .28138 .53211 .28127 .52844 .28092 Mtetra
.058 .622 .774 r
.52844 .28092 .53211 .28127 .53894 .28127 .53528 .28089 Mtetra
.042 .609 .77 r
.53528 .28089 .53894 .28127 .54579 .2814 .54215 .28097 Mtetra
.027 .597 .765 r
.54215 .28097 .54579 .2814 .55267 .28163 .54905 .28117 Mtetra
.013 .585 .762 r
.54905 .28117 .55267 .28163 .55959 .28199 .55599 .28148 Mtetra
.001 .574 .759 r
.55599 .28148 .55959 .28199 .56653 .28244 .56295 .28189 Mtetra
0 .565 .757 r
.56295 .28189 .56653 .28244 .57351 .28301 .56994 .28241 Mtetra
0 .556 .756 r
.56994 .28241 .57351 .28301 .58052 .28367 .57696 .28303 Mtetra
0 .548 .755 r
.57696 .28303 .58052 .28367 .58756 .28443 .58402 .28373 Mtetra
0 .541 .756 r
.58402 .28373 .58756 .28443 .59464 .28528 .59112 .28453 Mtetra
0 .535 .757 r
.59112 .28453 .59464 .28528 .60175 .28621 .59824 .28541 Mtetra
0 .53 .759 r
.59824 .28541 .60175 .28621 .6089 .28723 .60541 .28637 Mtetra
0 .527 .762 r
.60541 .28637 .6089 .28723 .61608 .28832 .61261 .2874 Mtetra
0 .524 .766 r
.61261 .2874 .61608 .28832 .6233 .28948 .61984 .2885 Mtetra
0 .522 .771 r
.61984 .2885 .6233 .28948 .63056 .29071 .62711 .28966 Mtetra
0 .522 .777 r
.62711 .28966 .63056 .29071 .63785 .29199 .63442 .29087 Mtetra
0 .522 .784 r
.63442 .29087 .63785 .29199 .64519 .29332 .64177 .29213 Mtetra
0 .524 .791 r
.64177 .29213 .64519 .29332 .65256 .29469 .64916 .29343 Mtetra
0 .526 .799 r
.64916 .29343 .65256 .29469 .65997 .2961 .65658 .29477 Mtetra
0 .53 .809 r
.65658 .29477 .65997 .2961 .66742 .29754 .66404 .29613 Mtetra
0 .535 .818 r
.66404 .29613 .66742 .29754 .6749 .29899 .67154 .2975 Mtetra
0 .541 .829 r
.67154 .2975 .6749 .29899 .68243 .30046 .67908 .29889 Mtetra
.007 .547 .84 r
.67908 .29889 .68243 .30046 .68999 .30193 .68666 .30027 Mtetra
.021 .555 .851 r
.68666 .30027 .68999 .30193 .6976 .3034 .69427 .30165 Mtetra
.038 .564 .863 r
.69427 .30165 .6976 .3034 .70524 .30485 .70192 .30301 Mtetra
.056 .573 .875 r
.70192 .30301 .70524 .30485 .71291 .30627 .70961 .30434 Mtetra
.075 .583 .887 r
.70961 .30434 .71291 .30627 .72063 .30766 .71734 .30563 Mtetra
.096 .594 .9 r
.71734 .30563 .72063 .30766 .72838 .309 .7251 .30687 Mtetra
.119 .605 .912 r
.7251 .30687 .72838 .309 .73617 .31029 .7329 .30805 Mtetra
.143 .617 .924 r
.7329 .30805 .73617 .31029 .74399 .3115 .74073 .30916 Mtetra
.169 .629 .935 r
.74073 .30916 .74399 .3115 .75184 .31264 .74859 .31018 Mtetra
.196 .641 .946 r
.74859 .31018 .75184 .31264 .75973 .31368 .75648 .31111 Mtetra
.223 .653 .955 r
.75648 .31111 .75973 .31368 .76764 .31462 .76441 .31193 Mtetra
.252 .665 .964 r
.76441 .31193 .76764 .31462 .77559 .31544 .77236 .31263 Mtetra
.81 .865 .889 r
.09347 .53421 .09818 .5361 .10458 .53103 .09988 .52924 Mtetra
.816 .87 .887 r
.09988 .52924 .10458 .53103 .111 .52583 .1063 .52414 Mtetra
.82 .875 .885 r
.1063 .52414 .111 .52583 .11744 .52053 .11275 .51893 Mtetra
.825 .88 .884 r
.11275 .51893 .11744 .52053 .12389 .51513 .1192 .51362 Mtetra
.828 .884 .883 r
.1192 .51362 .12389 .51513 .13036 .50964 .12567 .50822 Mtetra
.832 .889 .883 r
.12567 .50822 .13036 .50964 .13683 .50408 .13215 .50274 Mtetra
.835 .893 .882 r
.13215 .50274 .13683 .50408 .14332 .49845 .13865 .49719 Mtetra
.837 .898 .882 r
.13865 .49719 .14332 .49845 .14981 .49276 .14514 .49159 Mtetra
.839 .902 .882 r
.14514 .49159 .14981 .49276 .15631 .48704 .15165 .48594 Mtetra
.841 .906 .882 r
.15165 .48594 .15631 .48704 .16281 .48127 .15816 .48025 Mtetra
.843 .91 .882 r
.15816 .48025 .16281 .48127 .16931 .47549 .16468 .47453 Mtetra
.844 .915 .882 r
.16468 .47453 .16931 .47549 .17582 .46968 .17119 .4688 Mtetra
.844 .919 .883 r
.17119 .4688 .17582 .46968 .18233 .46387 .17772 .46305 Mtetra
.845 .923 .884 r
.17772 .46305 .18233 .46387 .18884 .45806 .18424 .45731 Mtetra
.844 .927 .885 r
.18424 .45731 .18884 .45806 .19535 .45226 .19076 .45157 Mtetra
.844 .931 .886 r
.19076 .45157 .19535 .45226 .20186 .44647 .19728 .44584 Mtetra
.843 .935 .887 r
.19728 .44584 .20186 .44647 .20837 .44072 .2038 .44014 Mtetra
.842 .939 .888 r
.2038 .44014 .20837 .44072 .21487 .43499 .21032 .43446 Mtetra
.84 .943 .89 r
.21032 .43446 .21487 .43499 .22137 .4293 .21683 .42883 Mtetra
.838 .946 .891 r
.21683 .42883 .22137 .4293 .22787 .42366 .22335 .42323 Mtetra
.835 .95 .893 r
.22335 .42323 .22787 .42366 .23437 .41807 .22986 .41769 Mtetra
.832 .954 .895 r
.22986 .41769 .23437 .41807 .24086 .41254 .23636 .4122 Mtetra
.829 .957 .897 r
.23636 .4122 .24086 .41254 .24735 .40707 .24287 .40678 Mtetra
.824 .96 .899 r
.24287 .40678 .24735 .40707 .25383 .40168 .24937 .40142 Mtetra
.82 .963 .901 r
.24937 .40142 .25383 .40168 .26031 .39635 .25586 .39614 Mtetra
.815 .966 .903 r
.25586 .39614 .26031 .39635 .26679 .39111 .26236 .39093 Mtetra
.809 .969 .905 r
.26236 .39093 .26679 .39111 .27326 .38596 .26884 .38581 Mtetra
.802 .971 .907 r
.26884 .38581 .27326 .38596 .27973 .3809 .27533 .38078 Mtetra
.795 .974 .909 r
.27533 .38078 .27973 .3809 .28619 .37593 .28181 .37584 Mtetra
.787 .975 .911 r
.28181 .37584 .28619 .37593 .29265 .37106 .28829 .371 Mtetra
.778 .977 .913 r
.28829 .371 .29265 .37106 .29911 .36629 .29477 .36626 Mtetra
.769 .978 .915 r
.29477 .36626 .29911 .36629 .30557 .36163 .30124 .36162 Mtetra
.759 .978 .916 r
.30124 .36162 .30557 .36163 .31202 .35709 .30771 .35709 Mtetra
.747 .978 .918 r
.30771 .35709 .31202 .35709 .31847 .35265 .31418 .35268 Mtetra
.735 .978 .919 r
.31418 .35268 .31847 .35265 .32492 .34833 .32065 .34838 Mtetra
.722 .977 .92 r
.32065 .34838 .32492 .34833 .33137 .34414 .32712 .34419 Mtetra
.709 .975 .921 r
.32712 .34419 .33137 .34414 .33782 .34006 .33359 .34013 Mtetra
.694 .973 .921 r
.33359 .34013 .33782 .34006 .34427 .33611 .34006 .3362 Mtetra
.678 .97 .921 r
.34006 .3362 .34427 .33611 .35072 .33229 .34653 .33238 Mtetra
.661 .966 .92 r
.34653 .33238 .35072 .33229 .35718 .3286 .353 .3287 Mtetra
.643 .961 .919 r
.353 .3287 .35718 .3286 .36363 .32504 .35947 .32515 Mtetra
.625 .956 .918 r
.35947 .32515 .36363 .32504 .37009 .32161 .36595 .32172 Mtetra
.605 .949 .916 r
.36595 .32172 .37009 .32161 .37655 .31832 .37243 .31844 Mtetra
.584 .942 .913 r
.37243 .31844 .37655 .31832 .38302 .31516 .37892 .31528 Mtetra
.563 .933 .91 r
.37892 .31528 .38302 .31516 .3895 .31214 .38541 .31226 Mtetra
.54 .924 .907 r
.38541 .31226 .3895 .31214 .39598 .30927 .39191 .30938 Mtetra
.517 .914 .903 r
.39191 .30938 .39598 .30927 .40246 .30653 .39842 .30664 Mtetra
.493 .903 .898 r
.39842 .30664 .40246 .30653 .40896 .30393 .40493 .30404 Mtetra
.469 .891 .892 r
.40493 .30404 .40896 .30393 .41547 .30147 .41146 .30157 Mtetra
.444 .879 .887 r
.41146 .30157 .41547 .30147 .42198 .29915 .41799 .29925 Mtetra
.419 .865 .88 r
.41799 .29925 .42198 .29915 .42851 .29698 .42454 .29706 Mtetra
.393 .851 .874 r
.42454 .29706 .42851 .29698 .43505 .29495 .4311 .29502 Mtetra
.368 .836 .866 r
.4311 .29502 .43505 .29495 .4416 .29305 .43767 .29311 Mtetra
.342 .821 .859 r
.43767 .29311 .4416 .29305 .44817 .2913 .44425 .29135 Mtetra
.316 .805 .851 r
.44425 .29135 .44817 .2913 .45475 .28969 .45085 .28972 Mtetra
.291 .789 .843 r
.45085 .28972 .45475 .28969 .46135 .28822 .45747 .28823 Mtetra
.266 .773 .835 r
.45747 .28823 .46135 .28822 .46796 .28689 .4641 .28688 Mtetra
.241 .757 .827 r
.4641 .28688 .46796 .28689 .47459 .2857 .47075 .28566 Mtetra
.217 .74 .819 r
.47075 .28566 .47459 .2857 .48125 .28464 .47743 .28458 Mtetra
.193 .724 .811 r
.47743 .28458 .48125 .28464 .48792 .28372 .48412 .28364 Mtetra
.17 .708 .803 r
.48412 .28364 .48792 .28372 .49461 .28293 .49083 .28282 Mtetra
.149 .692 .796 r
.49083 .28282 .49461 .28293 .50133 .28227 .49756 .28214 Mtetra
.128 .676 .788 r
.49756 .28214 .50133 .28227 .50807 .28175 .50432 .28158 Mtetra
.107 .661 .782 r
.50432 .28158 .50807 .28175 .51483 .28135 .5111 .28115 Mtetra
.088 .646 .775 r
.5111 .28115 .51483 .28135 .52162 .28107 .51791 .28084 Mtetra
.071 .632 .77 r
.51791 .28084 .52162 .28107 .52844 .28092 .52474 .28065 Mtetra
.054 .619 .765 r
.52474 .28065 .52844 .28092 .53528 .28089 .5316 .28058 Mtetra
.038 .607 .76 r
.5316 .28058 .53528 .28089 .54215 .28097 .53849 .28062 Mtetra
.024 .595 .756 r
.53849 .28062 .54215 .28097 .54905 .28117 .54541 .28078 Mtetra
.011 .584 .753 r
.54541 .28078 .54905 .28117 .55599 .28148 .55236 .28104 Mtetra
0 .574 .751 r
.55236 .28104 .55599 .28148 .56295 .28189 .55934 .28141 Mtetra
0 .564 .749 r
.55934 .28141 .56295 .28189 .56994 .28241 .56635 .28188 Mtetra
0 .556 .749 r
.56635 .28188 .56994 .28241 .57696 .28303 .57339 .28244 Mtetra
0 .549 .749 r
.57339 .28244 .57696 .28303 .58402 .28373 .58046 .2831 Mtetra
0 .543 .75 r
.58046 .2831 .58402 .28373 .59112 .28453 .58757 .28384 Mtetra
0 .537 .752 r
.58757 .28384 .59112 .28453 .59824 .28541 .59472 .28466 Mtetra
0 .533 .755 r
.59472 .28466 .59824 .28541 .60541 .28637 .60189 .28556 Mtetra
0 .53 .759 r
.60189 .28556 .60541 .28637 .61261 .2874 .60911 .28653 Mtetra
0 .528 .763 r
.60911 .28653 .61261 .2874 .61984 .2885 .61636 .28756 Mtetra
0 .527 .769 r
.61636 .28756 .61984 .2885 .62711 .28966 .62365 .28865 Mtetra
0 .527 .775 r
.62365 .28865 .62711 .28966 .63442 .29087 .63097 .2898 Mtetra
0 .528 .783 r
.63097 .2898 .63442 .29087 .64177 .29213 .63833 .29098 Mtetra
0 .53 .791 r
.63833 .29098 .64177 .29213 .64916 .29343 .64573 .29221 Mtetra
0 .533 .8 r
.64573 .29221 .64916 .29343 .65658 .29477 .65317 .29347 Mtetra
0 .537 .81 r
.65317 .29347 .65658 .29477 .66404 .29613 .66065 .29475 Mtetra
0 .543 .82 r
.66065 .29475 .66404 .29613 .67154 .2975 .66816 .29604 Mtetra
.002 .549 .831 r
.66816 .29604 .67154 .2975 .67908 .29889 .67571 .29734 Mtetra
.016 .556 .843 r
.67571 .29734 .67908 .29889 .68666 .30027 .6833 .29863 Mtetra
.031 .564 .855 r
.6833 .29863 .68666 .30027 .69427 .30165 .69093 .29992 Mtetra
.048 .573 .867 r
.69093 .29992 .69427 .30165 .70192 .30301 .69859 .30118 Mtetra
.067 .583 .879 r
.69859 .30118 .70192 .30301 .70961 .30434 .70629 .30241 Mtetra
.087 .593 .892 r
.70629 .30241 .70961 .30434 .71734 .30563 .71403 .3036 Mtetra
.109 .604 .905 r
.71403 .3036 .71734 .30563 .7251 .30687 .7218 .30473 Mtetra
.133 .616 .917 r
.7218 .30473 .7251 .30687 .7329 .30805 .72961 .30581 Mtetra
.158 .628 .929 r
.72961 .30581 .7329 .30805 .74073 .30916 .73745 .3068 Mtetra
.184 .64 .94 r
.73745 .3068 .74073 .30916 .74859 .31018 .74532 .30771 Mtetra
.211 .652 .95 r
.74532 .30771 .74859 .31018 .75648 .31111 .75322 .30852 Mtetra
.239 .664 .96 r
.75322 .30852 .75648 .31111 .76441 .31193 .76116 .30922 Mtetra
.268 .676 .968 r
.76116 .30922 .76441 .31193 .77236 .31263 .76912 .30979 Mtetra
.806 .866 .892 r
.08875 .53229 .09347 .53421 .09988 .52924 .09515 .52742 Mtetra
.812 .871 .891 r
.09515 .52742 .09988 .52924 .1063 .52414 .10158 .52243 Mtetra
.817 .876 .889 r
.10158 .52243 .1063 .52414 .11275 .51893 .10802 .51732 Mtetra
.821 .881 .888 r
.10802 .51732 .11275 .51893 .1192 .51362 .11448 .5121 Mtetra
.825 .886 .887 r
.11448 .5121 .1192 .51362 .12567 .50822 .12096 .50679 Mtetra
.828 .89 .886 r
.12096 .50679 .12567 .50822 .13215 .50274 .12745 .5014 Mtetra
.832 .895 .886 r
.12745 .5014 .13215 .50274 .13865 .49719 .13394 .49594 Mtetra
.834 .899 .885 r
.13394 .49594 .13865 .49719 .14514 .49159 .14045 .49042 Mtetra
.836 .904 .885 r
.14045 .49042 .14514 .49159 .15165 .48594 .14696 .48485 Mtetra
.838 .908 .885 r
.14696 .48485 .15165 .48594 .15816 .48025 .15348 .47924 Mtetra
.84 .913 .885 r
.15348 .47924 .15816 .48025 .16468 .47453 .16001 .4736 Mtetra
.841 .917 .886 r
.16001 .4736 .16468 .47453 .17119 .4688 .16654 .46794 Mtetra
.841 .921 .886 r
.16654 .46794 .17119 .4688 .17772 .46305 .17307 .46226 Mtetra
.842 .925 .887 r
.17307 .46226 .17772 .46305 .18424 .45731 .1796 .45658 Mtetra
.842 .93 .888 r
.1796 .45658 .18424 .45731 .19076 .45157 .18613 .4509 Mtetra
.841 .934 .889 r
.18613 .4509 .19076 .45157 .19728 .44584 .19267 .44524 Mtetra
.84 .938 .89 r
.19267 .44524 .19728 .44584 .2038 .44014 .1992 .43959 Mtetra
.839 .942 .891 r
.1992 .43959 .2038 .44014 .21032 .43446 .20573 .43398 Mtetra
.837 .946 .892 r
.20573 .43398 .21032 .43446 .21683 .42883 .21226 .42839 Mtetra
.835 .949 .894 r
.21226 .42839 .21683 .42883 .22335 .42323 .21879 .42285 Mtetra
.832 .953 .895 r
.21879 .42285 .22335 .42323 .22986 .41769 .22531 .41736 Mtetra
.829 .957 .897 r
.22531 .41736 .22986 .41769 .23636 .4122 .23184 .41191 Mtetra
.825 .96 .899 r
.23184 .41191 .23636 .4122 .24287 .40678 .23835 .40653 Mtetra
.821 .963 .9 r
.23835 .40653 .24287 .40678 .24937 .40142 .24487 .40122 Mtetra
.816 .966 .902 r
.24487 .40122 .24937 .40142 .25586 .39614 .25138 .39597 Mtetra
.81 .969 .904 r
.25138 .39597 .25586 .39614 .26236 .39093 .25789 .39081 Mtetra
.804 .972 .906 r
.25789 .39081 .26236 .39093 .26884 .38581 .2644 .38572 Mtetra
.797 .974 .908 r
.2644 .38572 .26884 .38581 .27533 .38078 .2709 .38072 Mtetra
.79 .976 .909 r
.2709 .38072 .27533 .38078 .28181 .37584 .2774 .37581 Mtetra
.782 .977 .911 r
.2774 .37581 .28181 .37584 .28829 .371 .28389 .371 Mtetra
.773 .979 .913 r
.28389 .371 .28829 .371 .29477 .36626 .29039 .36628 Mtetra
.763 .979 .914 r
.29039 .36628 .29477 .36626 .30124 .36162 .29688 .36167 Mtetra
.752 .98 .915 r
.29688 .36167 .30124 .36162 .30771 .35709 .30337 .35717 Mtetra
.741 .979 .916 r
.30337 .35717 .30771 .35709 .31418 .35268 .30986 .35277 Mtetra
.728 .979 .917 r
.30986 .35277 .31418 .35268 .32065 .34838 .31634 .34849 Mtetra
.715 .977 .917 r
.31634 .34849 .32065 .34838 .32712 .34419 .32283 .34432 Mtetra
.701 .975 .917 r
.32283 .34432 .32712 .34419 .33359 .34013 .32932 .34028 Mtetra
.686 .972 .917 r
.32932 .34028 .33359 .34013 .34006 .3362 .33581 .33635 Mtetra
.669 .969 .917 r
.33581 .33635 .34006 .3362 .34653 .33238 .34229 .33255 Mtetra
.652 .965 .916 r
.34229 .33255 .34653 .33238 .353 .3287 .34879 .32888 Mtetra
.634 .959 .914 r
.34879 .32888 .353 .3287 .35947 .32515 .35528 .32533 Mtetra
.615 .953 .912 r
.35528 .32533 .35947 .32515 .36595 .32172 .36178 .32192 Mtetra
.595 .947 .909 r
.36178 .32192 .36595 .32172 .37243 .31844 .36828 .31863 Mtetra
.574 .939 .906 r
.36828 .31863 .37243 .31844 .37892 .31528 .37478 .31548 Mtetra
.552 .93 .903 r
.37478 .31548 .37892 .31528 .38541 .31226 .38129 .31246 Mtetra
.53 .92 .899 r
.38129 .31246 .38541 .31226 .39191 .30938 .38781 .30958 Mtetra
.506 .91 .894 r
.38781 .30958 .39191 .30938 .39842 .30664 .39434 .30683 Mtetra
.483 .899 .889 r
.39434 .30683 .39842 .30664 .40493 .30404 .40087 .30423 Mtetra
.458 .886 .883 r
.40087 .30423 .40493 .30404 .41146 .30157 .40742 .30176 Mtetra
.433 .873 .877 r
.40742 .30176 .41146 .30157 .41799 .29925 .41397 .29942 Mtetra
.408 .86 .87 r
.41397 .29942 .41799 .29925 .42454 .29706 .42054 .29723 Mtetra
.383 .845 .863 r
.42054 .29723 .42454 .29706 .4311 .29502 .42711 .29517 Mtetra
.357 .831 .856 r
.42711 .29517 .4311 .29502 .43767 .29311 .4337 .29325 Mtetra
.332 .815 .848 r
.4337 .29325 .43767 .29311 .44425 .29135 .44031 .29147 Mtetra
.306 .799 .84 r
.44031 .29147 .44425 .29135 .45085 .28972 .44693 .28983 Mtetra
.281 .784 .832 r
.44693 .28983 .45085 .28972 .45747 .28823 .45356 .28832 Mtetra
.257 .767 .824 r
.45356 .28832 .45747 .28823 .4641 .28688 .46021 .28695 Mtetra
.232 .751 .816 r
.46021 .28695 .4641 .28688 .47075 .28566 .46688 .28571 Mtetra
.209 .735 .808 r
.46688 .28571 .47075 .28566 .47743 .28458 .47357 .2846 Mtetra
.186 .719 .8 r
.47357 .2846 .47743 .28458 .48412 .28364 .48028 .28363 Mtetra
.164 .703 .792 r
.48028 .28363 .48412 .28364 .49083 .28282 .48702 .28279 Mtetra
.142 .687 .785 r
.48702 .28279 .49083 .28282 .49756 .28214 .49377 .28207 Mtetra
.122 .672 .778 r
.49377 .28207 .49756 .28214 .50432 .28158 .50054 .28148 Mtetra
.102 .657 .772 r
.50054 .28148 .50432 .28158 .5111 .28115 .50734 .28102 Mtetra
.084 .643 .766 r
.50734 .28102 .5111 .28115 .51791 .28084 .51417 .28067 Mtetra
.067 .63 .76 r
.51417 .28067 .51791 .28084 .52474 .28065 .52102 .28045 Mtetra
.05 .617 .756 r
.52102 .28045 .52474 .28065 .5316 .28058 .5279 .28034 Mtetra
.035 .605 .752 r
.5279 .28034 .5316 .28058 .53849 .28062 .53481 .28034 Mtetra
.022 .594 .749 r
.53481 .28034 .53849 .28062 .54541 .28078 .54174 .28045 Mtetra
.009 .583 .746 r
.54174 .28045 .54541 .28078 .55236 .28104 .54871 .28067 Mtetra
0 .574 .744 r
.54871 .28067 .55236 .28104 .55934 .28141 .5557 .28099 Mtetra
0 .565 .743 r
.5557 .28099 .55934 .28141 .56635 .28188 .56273 .28141 Mtetra
0 .557 .743 r
.56273 .28141 .56635 .28188 .57339 .28244 .56979 .28192 Mtetra
0 .551 .744 r
.56979 .28192 .57339 .28244 .58046 .2831 .57688 .28252 Mtetra
0 .545 .746 r
.57688 .28252 .58046 .2831 .58757 .28384 .584 .2832 Mtetra
0 .54 .748 r
.584 .2832 .58757 .28384 .59472 .28466 .59116 .28396 Mtetra
0 .536 .752 r
.59116 .28396 .59472 .28466 .60189 .28556 .59836 .2848 Mtetra
0 .534 .756 r
.59836 .2848 .60189 .28556 .60911 .28653 .60559 .2857 Mtetra
0 .532 .762 r
.60559 .2857 .60911 .28653 .61636 .28756 .61285 .28667 Mtetra
0 .532 .768 r
.61285 .28667 .61636 .28756 .62365 .28865 .62016 .28769 Mtetra
0 .532 .775 r
.62016 .28769 .62365 .28865 .63097 .2898 .6275 .28876 Mtetra
0 .534 .783 r
.6275 .28876 .63097 .2898 .63833 .29098 .63487 .28987 Mtetra
0 .537 .792 r
.63487 .28987 .63833 .29098 .64573 .29221 .64229 .29102 Mtetra
0 .541 .802 r
.64229 .29102 .64573 .29221 .65317 .29347 .64974 .2922 Mtetra
0 .545 .812 r
.64974 .2922 .65317 .29347 .66065 .29475 .65723 .29339 Mtetra
0 .551 .823 r
.65723 .29339 .66065 .29475 .66816 .29604 .66475 .2946 Mtetra
.012 .558 .834 r
.66475 .2946 .66816 .29604 .67571 .29734 .67232 .29581 Mtetra
.027 .566 .847 r
.67232 .29581 .67571 .29734 .6833 .29863 .67992 .29701 Mtetra
.043 .574 .859 r
.67992 .29701 .6833 .29863 .69093 .29992 .68756 .2982 Mtetra
.06 .584 .872 r
.68756 .2982 .69093 .29992 .69859 .30118 .69524 .29936 Mtetra
.08 .594 .885 r
.69524 .29936 .69859 .30118 .70629 .30241 .70295 .30049 Mtetra
.101 .604 .898 r
.70295 .30049 .70629 .30241 .71403 .3036 .7107 .30157 Mtetra
.124 .616 .91 r
.7107 .30157 .71403 .3036 .7218 .30473 .71848 .30259 Mtetra
.148 .627 .923 r
.71848 .30259 .7218 .30473 .72961 .30581 .7263 .30355 Mtetra
.173 .639 .934 r
.7263 .30355 .72961 .30581 .73745 .3068 .73415 .30443 Mtetra
.2 .651 .945 r
.73415 .30443 .73745 .3068 .74532 .30771 .74203 .30522 Mtetra
.228 .663 .956 r
.74203 .30522 .74532 .30771 .75322 .30852 .74994 .30591 Mtetra
.256 .675 .965 r
.74994 .30591 .75322 .30852 .76116 .30922 .75788 .30648 Mtetra
.286 .686 .973 r
.75788 .30648 .76116 .30922 .76912 .30979 .76585 .30692 Mtetra
.802 .866 .896 r
.084 .53034 .08875 .53229 .09515 .52742 .0904 .52558 Mtetra
.807 .871 .894 r
.0904 .52558 .09515 .52742 .10158 .52243 .09683 .52069 Mtetra
.812 .876 .893 r
.09683 .52069 .10158 .52243 .10802 .51732 .10328 .51568 Mtetra
.817 .881 .892 r
.10328 .51568 .10802 .51732 .11448 .5121 .10974 .51057 Mtetra
.821 .886 .891 r
.10974 .51057 .11448 .5121 .12096 .50679 .11622 .50536 Mtetra
.825 .891 .89 r
.11622 .50536 .12096 .50679 .12745 .5014 .12271 .50006 Mtetra
.828 .896 .889 r
.12271 .50006 .12745 .5014 .13394 .49594 .12921 .49469 Mtetra
.831 .901 .889 r
.12921 .49469 .13394 .49594 .14045 .49042 .13573 .48926 Mtetra
.833 .905 .888 r
.13573 .48926 .14045 .49042 .14696 .48485 .14225 .48377 Mtetra
.835 .91 .888 r
.14225 .48377 .14696 .48485 .15348 .47924 .14877 .47824 Mtetra
.837 .915 .888 r
.14877 .47824 .15348 .47924 .16001 .4736 .15531 .47268 Mtetra
.838 .919 .889 r
.15531 .47268 .16001 .4736 .16654 .46794 .16185 .46709 Mtetra
.838 .923 .889 r
.16185 .46709 .16654 .46794 .17307 .46226 .16839 .46149 Mtetra
.839 .928 .89 r
.16839 .46149 .17307 .46226 .1796 .45658 .17493 .45588 Mtetra
.839 .932 .891 r
.17493 .45588 .1796 .45658 .18613 .4509 .18148 .45027 Mtetra
.838 .936 .891 r
.18148 .45027 .18613 .4509 .19267 .44524 .18802 .44467 Mtetra
.837 .94 .892 r
.18802 .44467 .19267 .44524 .1992 .43959 .19457 .43908 Mtetra
.836 .944 .894 r
.19457 .43908 .1992 .43959 .20573 .43398 .20111 .43352 Mtetra
.834 .948 .895 r
.20111 .43352 .20573 .43398 .21226 .42839 .20765 .428 Mtetra
.831 .952 .896 r
.20765 .428 .21226 .42839 .21879 .42285 .2142 .42251 Mtetra
.828 .956 .897 r
.2142 .42251 .21879 .42285 .22531 .41736 .22074 .41706 Mtetra
.825 .959 .899 r
.22074 .41706 .22531 .41736 .23184 .41191 .22727 .41167 Mtetra
.821 .962 .9 r
.22727 .41167 .23184 .41191 .23835 .40653 .23381 .40633 Mtetra
.817 .966 .902 r
.23381 .40633 .23835 .40653 .24487 .40122 .24034 .40106 Mtetra
.812 .968 .904 r
.24034 .40106 .24487 .40122 .25138 .39597 .24687 .39586 Mtetra
.806 .971 .905 r
.24687 .39586 .25138 .39597 .25789 .39081 .25339 .39073 Mtetra
.8 .974 .907 r
.25339 .39073 .25789 .39081 .2644 .38572 .25991 .38568 Mtetra
.793 .976 .908 r
.25991 .38568 .2644 .38572 .2709 .38072 .26643 .38072 Mtetra
.785 .978 .91 r
.26643 .38072 .2709 .38072 .2774 .37581 .27295 .37584 Mtetra
.776 .979 .911 r
.27295 .37584 .2774 .37581 .28389 .371 .27946 .37106 Mtetra
.767 .98 .912 r
.27946 .37106 .28389 .371 .29039 .36628 .28597 .36637 Mtetra
.757 .981 .913 r
.28597 .36637 .29039 .36628 .29688 .36167 .29248 .36179 Mtetra
.746 .981 .914 r
.29248 .36179 .29688 .36167 .30337 .35717 .29899 .3573 Mtetra
.734 .98 .914 r
.29899 .3573 .30337 .35717 .30986 .35277 .3055 .35293 Mtetra
.721 .979 .915 r
.3055 .35293 .30986 .35277 .31634 .34849 .312 .34867 Mtetra
.708 .977 .915 r
.312 .34867 .31634 .34849 .32283 .34432 .31851 .34452 Mtetra
.693 .975 .914 r
.31851 .34452 .32283 .34432 .32932 .34028 .32501 .34049 Mtetra
.677 .972 .914 r
.32501 .34049 .32932 .34028 .33581 .33635 .33152 .33658 Mtetra
.661 .968 .912 r
.33152 .33658 .33581 .33635 .34229 .33255 .33803 .33279 Mtetra
.643 .963 .911 r
.33803 .33279 .34229 .33255 .34879 .32888 .34454 .32913 Mtetra
.625 .957 .909 r
.34454 .32913 .34879 .32888 .35528 .32533 .35105 .32559 Mtetra
.605 .951 .906 r
.35105 .32559 .35528 .32533 .36178 .32192 .35757 .32218 Mtetra
.585 .944 .903 r
.35757 .32218 .36178 .32192 .36828 .31863 .36409 .3189 Mtetra
.564 .935 .9 r
.36409 .3189 .36828 .31863 .37478 .31548 .37061 .31575 Mtetra
.542 .926 .896 r
.37061 .31575 .37478 .31548 .38129 .31246 .37714 .31273 Mtetra
.52 .916 .891 r
.37714 .31273 .38129 .31246 .38781 .30958 .38368 .30985 Mtetra
.496 .906 .886 r
.38368 .30985 .38781 .30958 .39434 .30683 .39023 .3071 Mtetra
.472 .894 .88 r
.39023 .3071 .39434 .30683 .40087 .30423 .39678 .30449 Mtetra
.448 .881 .874 r
.39678 .30449 .40087 .30423 .40742 .30176 .40334 .30201 Mtetra
.423 .868 .867 r
.40334 .30201 .40742 .30176 .41397 .29942 .40992 .29967 Mtetra
.398 .854 .86 r
.40992 .29967 .41397 .29942 .42054 .29723 .4165 .29746 Mtetra
.373 .84 .853 r
.4165 .29746 .42054 .29723 .42711 .29517 .4231 .2954 Mtetra
.348 .825 .845 r
.4231 .2954 .42711 .29517 .4337 .29325 .42971 .29346 Mtetra
.323 .81 .837 r
.42971 .29346 .4337 .29325 .44031 .29147 .43633 .29167 Mtetra
.298 .794 .829 r
.43633 .29167 .44031 .29147 .44693 .28983 .44297 .29 Mtetra
.273 .778 .821 r
.44297 .29 .44693 .28983 .45356 .28832 .44962 .28848 Mtetra
.249 .762 .813 r
.44962 .28848 .45356 .28832 .46021 .28695 .4563 .28708 Mtetra
.225 .746 .805 r
.4563 .28708 .46021 .28695 .46688 .28571 .46298 .28582 Mtetra
.202 .73 .797 r
.46298 .28582 .46688 .28571 .47357 .2846 .46969 .28469 Mtetra
.179 .715 .79 r
.46969 .28469 .47357 .2846 .48028 .28363 .47642 .28369 Mtetra
.158 .699 .782 r
.47642 .28369 .48028 .28363 .48702 .28279 .48317 .28282 Mtetra
.137 .684 .776 r
.48317 .28282 .48702 .28279 .49377 .28207 .48994 .28207 Mtetra
.117 .669 .769 r
.48994 .28207 .49377 .28207 .50054 .28148 .49674 .28145 Mtetra
.098 .655 .763 r
.49674 .28145 .50054 .28148 .50734 .28102 .50356 .28095 Mtetra
.081 .641 .757 r
.50356 .28095 .50734 .28102 .51417 .28067 .5104 .28057 Mtetra
.064 .628 .753 r
.5104 .28057 .51417 .28067 .52102 .28045 .51727 .2803 Mtetra
.048 .616 .748 r
.51727 .2803 .52102 .28045 .5279 .28034 .52417 .28015 Mtetra
.034 .604 .745 r
.52417 .28015 .5279 .28034 .53481 .28034 .53109 .28011 Mtetra
.021 .594 .742 r
.53109 .28011 .53481 .28034 .54174 .28045 .53804 .28018 Mtetra
.009 .584 .74 r
.53804 .28018 .54174 .28045 .54871 .28067 .54503 .28035 Mtetra
0 .575 .739 r
.54503 .28035 .54871 .28067 .5557 .28099 .55204 .28062 Mtetra
0 .567 .739 r
.55204 .28062 .5557 .28099 .56273 .28141 .55908 .28098 Mtetra
0 .559 .739 r
.55908 .28098 .56273 .28141 .56979 .28192 .56616 .28144 Mtetra
0 .553 .741 r
.56616 .28144 .56979 .28192 .57688 .28252 .57327 .28198 Mtetra
0 .548 .743 r
.57327 .28198 .57688 .28252 .584 .2832 .58041 .2826 Mtetra
0 .544 .746 r
.58041 .2826 .584 .2832 .59116 .28396 .58759 .28331 Mtetra
0 .541 .75 r
.58759 .28331 .59116 .28396 .59836 .2848 .5948 .28408 Mtetra
0 .539 .755 r
.5948 .28408 .59836 .2848 .60559 .2857 .60204 .28491 Mtetra
0 .538 .761 r
.60204 .28491 .60559 .2857 .61285 .28667 .60932 .28581 Mtetra
0 .538 .768 r
.60932 .28581 .61285 .28667 .62016 .28769 .61664 .28676 Mtetra
0 .539 .776 r
.61664 .28676 .62016 .28769 .6275 .28876 .624 .28775 Mtetra
0 .541 .785 r
.624 .28775 .6275 .28876 .63487 .28987 .63139 .28879 Mtetra
0 .545 .794 r
.63139 .28879 .63487 .28987 .64229 .29102 .63882 .28985 Mtetra
0 .549 .804 r
.63882 .28985 .64229 .29102 .64974 .2922 .64628 .29094 Mtetra
0 .554 .815 r
.64628 .29094 .64974 .2922 .65723 .29339 .65379 .29205 Mtetra
.01 .561 .827 r
.65379 .29205 .65723 .29339 .66475 .2946 .66133 .29317 Mtetra
.024 .568 .839 r
.66133 .29317 .66475 .2946 .67232 .29581 .66891 .29428 Mtetra
.039 .576 .852 r
.66891 .29428 .67232 .29581 .67992 .29701 .67652 .29539 Mtetra
.056 .585 .864 r
.67652 .29539 .67992 .29701 .68756 .2982 .68417 .29648 Mtetra
.074 .595 .877 r
.68417 .29648 .68756 .2982 .69524 .29936 .69186 .29754 Mtetra
.094 .605 .891 r
.69186 .29754 .69524 .29936 .70295 .30049 .69958 .29856 Mtetra
.116 .616 .904 r
.69958 .29856 .70295 .30049 .7107 .30157 .70734 .29953 Mtetra
.14 .627 .916 r
.70734 .29953 .7107 .30157 .71848 .30259 .71514 .30044 Mtetra
.164 .639 .929 r
.71514 .30044 .71848 .30259 .7263 .30355 .72296 .30128 Mtetra
.19 .651 .94 r
.72296 .30128 .7263 .30355 .73415 .30443 .73082 .30204 Mtetra
.217 .663 .951 r
.73082 .30204 .73415 .30443 .74203 .30522 .73871 .30271 Mtetra
.246 .674 .961 r
.73871 .30271 .74203 .30522 .74994 .30591 .74663 .30327 Mtetra
.275 .686 .97 r
.74663 .30327 .74994 .30591 .75788 .30648 .75458 .3037 Mtetra
.304 .697 .977 r
.75458 .3037 .75788 .30648 .76585 .30692 .76256 .30401 Mtetra
.797 .865 .899 r
.07922 .52835 .084 .53034 .0904 .52558 .08563 .52371 Mtetra
.803 .871 .898 r
.08563 .52371 .0904 .52558 .09683 .52069 .09206 .51893 Mtetra
.808 .876 .896 r
.09206 .51893 .09683 .52069 .10328 .51568 .0985 .51403 Mtetra
.813 .882 .895 r
.0985 .51403 .10328 .51568 .10974 .51057 .10497 .50901 Mtetra
.817 .887 .894 r
.10497 .50901 .10974 .51057 .11622 .50536 .11145 .5039 Mtetra
.821 .892 .893 r
.11145 .5039 .11622 .50536 .12271 .50006 .11795 .4987 Mtetra
.824 .897 .893 r
.11795 .4987 .12271 .50006 .12921 .49469 .12445 .49343 Mtetra
.827 .902 .892 r
.12445 .49343 .12921 .49469 .13573 .48926 .13097 .48809 Mtetra
.83 .907 .892 r
.13097 .48809 .13573 .48926 .14225 .48377 .1375 .48269 Mtetra
.832 .911 .892 r
.1375 .48269 .14225 .48377 .14877 .47824 .14404 .47724 Mtetra
.833 .916 .892 r
.14404 .47724 .14877 .47824 .15531 .47268 .15058 .47176 Mtetra
.834 .921 .892 r
.15058 .47176 .15531 .47268 .16185 .46709 .15712 .46625 Mtetra
.835 .925 .892 r
.15712 .46625 .16185 .46709 .16839 .46149 .16368 .46072 Mtetra
.835 .93 .893 r
.16368 .46072 .16839 .46149 .17493 .45588 .17023 .45519 Mtetra
.835 .934 .894 r
.17023 .45519 .17493 .45588 .18148 .45027 .17678 .44965 Mtetra
.835 .938 .894 r
.17678 .44965 .18148 .45027 .18802 .44467 .18334 .44411 Mtetra
.834 .942 .895 r
.18334 .44411 .18802 .44467 .19457 .43908 .1899 .43859 Mtetra
.832 .946 .896 r
.1899 .43859 .19457 .43908 .20111 .43352 .19646 .43309 Mtetra
.83 .95 .897 r
.19646 .43309 .20111 .43352 .20765 .428 .20301 .42763 Mtetra
.828 .954 .898 r
.20301 .42763 .20765 .428 .2142 .42251 .20957 .42219 Mtetra
.825 .958 .9 r
.20957 .42219 .2142 .42251 .22074 .41706 .21612 .4168 Mtetra
.821 .961 .901 r
.21612 .4168 .22074 .41706 .22727 .41167 .22267 .41146 Mtetra
.817 .964 .902 r
.22267 .41146 .22727 .41167 .23381 .40633 .22922 .40617 Mtetra
.813 .968 .904 r
.22922 .40617 .23381 .40633 .24034 .40106 .23577 .40095 Mtetra
.807 .97 .905 r
.23577 .40095 .24034 .40106 .24687 .39586 .24231 .39579 Mtetra
.801 .973 .906 r
.24231 .39579 .24687 .39586 .25339 .39073 .24886 .3907 Mtetra
.795 .975 .907 r
.24886 .3907 .25339 .39073 .25991 .38568 .25539 .38569 Mtetra
.788 .977 .909 r
.25539 .38569 .25991 .38568 .26643 .38072 .26193 .38076 Mtetra
.78 .979 .91 r
.26193 .38076 .26643 .38072 .27295 .37584 .26846 .37592 Mtetra
.771 .98 .911 r
.26846 .37592 .27295 .37584 .27946 .37106 .275 .37117 Mtetra
.761 .981 .912 r
.275 .37117 .27946 .37106 .28597 .36637 .28152 .36651 Mtetra
.751 .981 .912 r
.28152 .36651 .28597 .36637 .29248 .36179 .28805 .36195 Mtetra
.739 .981 .913 r
.28805 .36195 .29248 .36179 .29899 .3573 .29458 .3575 Mtetra
.727 .98 .913 r
.29458 .3575 .29899 .3573 .3055 .35293 .3011 .35315 Mtetra
.714 .979 .913 r
.3011 .35315 .3055 .35293 .312 .34867 .30763 .34891 Mtetra
.7 .977 .912 r
.30763 .34891 .312 .34867 .31851 .34452 .31415 .34478 Mtetra
.685 .974 .911 r
.31415 .34478 .31851 .34452 .32501 .34049 .32067 .34076 Mtetra
.669 .971 .91 r
.32067 .34076 .32501 .34049 .33152 .33658 .3272 .33687 Mtetra
.653 .966 .908 r
.3272 .33687 .33152 .33658 .33803 .33279 .33373 .33309 Mtetra
.635 .961 .906 r
.33373 .33309 .33803 .33279 .34454 .32913 .34026 .32944 Mtetra
.616 .955 .904 r
.34026 .32944 .34454 .32913 .35105 .32559 .34679 .32591 Mtetra
.596 .948 .901 r
.34679 .32591 .35105 .32559 .35757 .32218 .35332 .32251 Mtetra
.576 .941 .897 r
.35332 .32251 .35757 .32218 .36409 .3189 .35986 .31923 Mtetra
.555 .932 .893 r
.35986 .31923 .36409 .3189 .37061 .31575 .36641 .31609 Mtetra
.533 .923 .889 r
.36641 .31609 .37061 .31575 .37714 .31273 .37296 .31307 Mtetra
.51 .912 .884 r
.37296 .31307 .37714 .31273 .38368 .30985 .37952 .31019 Mtetra
.487 .901 .878 r
.37952 .31019 .38368 .30985 .39023 .3071 .38608 .30744 Mtetra
.463 .889 .872 r
.38608 .30744 .39023 .3071 .39678 .30449 .39265 .30482 Mtetra
.439 .877 .865 r
.39265 .30482 .39678 .30449 .40334 .30201 .39924 .30233 Mtetra
.414 .863 .858 r
.39924 .30233 .40334 .30201 .40992 .29967 .40583 .29998 Mtetra
.389 .85 .851 r
.40583 .29998 .40992 .29967 .4165 .29746 .41243 .29777 Mtetra
.364 .835 .844 r
.41243 .29777 .4165 .29746 .4231 .2954 .41905 .29569 Mtetra
.339 .82 .836 r
.41905 .29569 .4231 .2954 .42971 .29346 .42568 .29374 Mtetra
.315 .805 .828 r
.42568 .29374 .42971 .29346 .43633 .29167 .43232 .29193 Mtetra
.29 .789 .82 r
.43232 .29193 .43633 .29167 .44297 .29 .43898 .29025 Mtetra
.266 .774 .812 r
.43898 .29025 .44297 .29 .44962 .28848 .44565 .2887 Mtetra
.242 .758 .804 r
.44565 .2887 .44962 .28848 .4563 .28708 .45235 .28729 Mtetra
.219 .742 .796 r
.45235 .28729 .4563 .28708 .46298 .28582 .45905 .286 Mtetra
.196 .726 .788 r
.45905 .286 .46298 .28582 .46969 .28469 .46578 .28484 Mtetra
.175 .711 .781 r
.46578 .28484 .46969 .28469 .47642 .28369 .47253 .28382 Mtetra
.154 .696 .774 r
.47253 .28382 .47642 .28369 .48317 .28282 .4793 .28291 Mtetra
.133 .681 .767 r
.4793 .28291 .48317 .28282 .48994 .28207 .48609 .28214 Mtetra
.114 .667 .761 r
.48609 .28214 .48994 .28207 .49674 .28145 .4929 .28148 Mtetra
.096 .653 .755 r
.4929 .28148 .49674 .28145 .50356 .28095 .49974 .28094 Mtetra
.079 .64 .75 r
.49974 .28094 .50356 .28095 .5104 .28057 .5066 .28052 Mtetra
.063 .627 .746 r
.5066 .28052 .5104 .28057 .51727 .2803 .51349 .28022 Mtetra
.048 .616 .742 r
.51349 .28022 .51727 .2803 .52417 .28015 .52041 .28002 Mtetra
.034 .605 .739 r
.52041 .28002 .52417 .28015 .53109 .28011 .52735 .27994 Mtetra
.022 .594 .737 r
.52735 .27994 .53109 .28011 .53804 .28018 .53432 .27996 Mtetra
.01 .585 .736 r
.53432 .27996 .53804 .28018 .54503 .28035 .54132 .28008 Mtetra
0 .577 .735 r
.54132 .28008 .54503 .28035 .55204 .28062 .54835 .28029 Mtetra
0 .569 .735 r
.54835 .28029 .55204 .28062 .55908 .28098 .55541 .28061 Mtetra
0 .563 .736 r
.55541 .28061 .55908 .28098 .56616 .28144 .56251 .281 Mtetra
0 .557 .739 r
.56251 .281 .56616 .28144 .57327 .28198 .56963 .28149 Mtetra
0 .552 .741 r
.56963 .28149 .57327 .28198 .58041 .2826 .57679 .28205 Mtetra
0 .549 .745 r
.57679 .28205 .58041 .2826 .58759 .28331 .58398 .28268 Mtetra
0 .546 .75 r
.58398 .28268 .58759 .28331 .5948 .28408 .59121 .28339 Mtetra
0 .545 .756 r
.59121 .28339 .5948 .28408 .60204 .28491 .59847 .28416 Mtetra
0 .545 .763 r
.59847 .28416 .60204 .28491 .60932 .28581 .60577 .28498 Mtetra
0 .545 .77 r
.60577 .28498 .60932 .28581 .61664 .28676 .6131 .28585 Mtetra
0 .547 .778 r
.6131 .28585 .61664 .28676 .624 .28775 .62047 .28677 Mtetra
0 .55 .788 r
.62047 .28677 .624 .28775 .63139 .28879 .62788 .28772 Mtetra
0 .554 .798 r
.62788 .28772 .63139 .28879 .63882 .28985 .63532 .2887 Mtetra
0 .558 .809 r
.63532 .2887 .63882 .28985 .64628 .29094 .6428 .28971 Mtetra
.01 .564 .82 r
.6428 .28971 .64628 .29094 .65379 .29205 .65032 .29072 Mtetra
.022 .571 .832 r
.65032 .29072 .65379 .29205 .66133 .29317 .65788 .29175 Mtetra
.037 .579 .845 r
.65788 .29175 .66133 .29317 .66891 .29428 .66547 .29276 Mtetra
.053 .587 .858 r
.66547 .29276 .66891 .29428 .67652 .29539 .6731 .29377 Mtetra
.07 .597 .871 r
.6731 .29377 .67652 .29539 .68417 .29648 .68076 .29475 Mtetra
.09 .606 .884 r
.68076 .29475 .68417 .29648 .69186 .29754 .68846 .29571 Mtetra
.11 .617 .897 r
.68846 .29571 .69186 .29754 .69958 .29856 .6962 .29662 Mtetra
.133 .628 .91 r
.6962 .29662 .69958 .29856 .70734 .29953 .70397 .29747 Mtetra
.157 .64 .923 r
.70397 .29747 .70734 .29953 .71514 .30044 .71177 .29827 Mtetra
.182 .651 .935 r
.71177 .29827 .71514 .30044 .72296 .30128 .71961 .29899 Mtetra
.209 .663 .947 r
.71961 .29899 .72296 .30128 .73082 .30204 .72748 .29962 Mtetra
.236 .674 .957 r
.72748 .29962 .73082 .30204 .73871 .30271 .73538 .30016 Mtetra
.265 .686 .967 r
.73538 .30016 .73871 .30271 .74663 .30327 .74331 .30058 Mtetra
.294 .697 .975 r
.74331 .30058 .74663 .30327 .75458 .3037 .75126 .30089 Mtetra
.323 .707 .981 r
.75126 .30089 .75458 .3037 .76256 .30401 .75925 .30105 Mtetra
.791 .864 .903 r
.07443 .52631 .07922 .52835 .08563 .52371 .08083 .52179 Mtetra
.797 .87 .902 r
.08083 .52179 .08563 .52371 .09206 .51893 .08726 .51712 Mtetra
.803 .876 .9 r
.08726 .51712 .09206 .51893 .0985 .51403 .09371 .51233 Mtetra
.808 .881 .899 r
.09371 .51233 .0985 .51403 .10497 .50901 .10017 .50743 Mtetra
.813 .887 .898 r
.10017 .50743 .10497 .50901 .11145 .5039 .10666 .50242 Mtetra
.817 .892 .897 r
.10666 .50242 .11145 .5039 .11795 .4987 .11316 .49732 Mtetra
.82 .897 .896 r
.11316 .49732 .11795 .4987 .12445 .49343 .11967 .49215 Mtetra
.823 .903 .896 r
.11967 .49215 .12445 .49343 .13097 .48809 .12619 .4869 Mtetra
.826 .908 .895 r
.12619 .4869 .13097 .48809 .1375 .48269 .13273 .48159 Mtetra
.828 .912 .895 r
.13273 .48159 .1375 .48269 .14404 .47724 .13927 .47624 Mtetra
.829 .917 .895 r
.13927 .47624 .14404 .47724 .15058 .47176 .14582 .47084 Mtetra
.831 .922 .895 r
.14582 .47084 .15058 .47176 .15712 .46625 .15237 .46541 Mtetra
.831 .926 .896 r
.15237 .46541 .15712 .46625 .16368 .46072 .15893 .45996 Mtetra
.832 .931 .896 r
.15893 .45996 .16368 .46072 .17023 .45519 .1655 .4545 Mtetra
.832 .935 .897 r
.1655 .4545 .17023 .45519 .17678 .44965 .17206 .44903 Mtetra
.831 .94 .897 r
.17206 .44903 .17678 .44965 .18334 .44411 .17863 .44357 Mtetra
.83 .944 .898 r
.17863 .44357 .18334 .44411 .1899 .43859 .1852 .43812 Mtetra
.828 .948 .899 r
.1852 .43812 .1899 .43859 .19646 .43309 .19177 .43268 Mtetra
.826 .952 .9 r
.19177 .43268 .19646 .43309 .20301 .42763 .19834 .42728 Mtetra
.824 .956 .901 r
.19834 .42728 .20301 .42763 .20957 .42219 .20491 .4219 Mtetra
.821 .959 .902 r
.20491 .4219 .20957 .42219 .21612 .4168 .21148 .41657 Mtetra
.817 .963 .903 r
.21148 .41657 .21612 .4168 .22267 .41146 .21804 .41128 Mtetra
.813 .966 .904 r
.21804 .41128 .22267 .41146 .22922 .40617 .22461 .40605 Mtetra
.808 .969 .905 r
.22461 .40605 .22922 .40617 .23577 .40095 .23117 .40087 Mtetra
.803 .972 .906 r
.23117 .40087 .23577 .40095 .24231 .39579 .23773 .39576 Mtetra
.797 .975 .907 r
.23773 .39576 .24231 .39579 .24886 .3907 .24429 .39071 Mtetra
.79 .977 .908 r
.24429 .39071 .24886 .3907 .25539 .38569 .25084 .38574 Mtetra
.782 .979 .909 r
.25084 .38574 .25539 .38569 .26193 .38076 .25739 .38085 Mtetra
.774 .98 .91 r
.25739 .38085 .26193 .38076 .26846 .37592 .26394 .37604 Mtetra
.765 .981 .911 r
.26394 .37604 .26846 .37592 .275 .37117 .27049 .37133 Mtetra
.755 .982 .911 r
.27049 .37133 .275 .37117 .28152 .36651 .27704 .3667 Mtetra
.745 .982 .911 r
.27704 .3667 .28152 .36651 .28805 .36195 .28358 .36217 Mtetra
.733 .981 .911 r
.28358 .36217 .28805 .36195 .29458 .3575 .29013 .35774 Mtetra
.721 .98 .911 r
.29013 .35774 .29458 .3575 .3011 .35315 .29667 .35342 Mtetra
.707 .978 .911 r
.29667 .35342 .3011 .35315 .30763 .34891 .30321 .3492 Mtetra
.693 .976 .91 r
.30321 .3492 .30763 .34891 .31415 .34478 .30976 .34509 Mtetra
.678 .973 .908 r
.30976 .34509 .31415 .34478 .32067 .34076 .3163 .34109 Mtetra
.662 .969 .907 r
.3163 .34109 .32067 .34076 .3272 .33687 .32284 .33721 Mtetra
.645 .965 .905 r
.32284 .33721 .3272 .33687 .33373 .33309 .32939 .33345 Mtetra
.627 .959 .902 r
.32939 .33345 .33373 .33309 .34026 .32944 .33594 .32981 Mtetra
.608 .953 .899 r
.33594 .32981 .34026 .32944 .34679 .32591 .34249 .32629 Mtetra
.588 .946 .896 r
.34249 .32629 .34679 .32591 .35332 .32251 .34905 .32289 Mtetra
.567 .938 .892 r
.34905 .32289 .35332 .32251 .35986 .31923 .3556 .31962 Mtetra
.546 .929 .887 r
.3556 .31962 .35986 .31923 .36641 .31609 .36217 .31648 Mtetra
.524 .919 .882 r
.36217 .31648 .36641 .31609 .37296 .31307 .36874 .31347 Mtetra
.501 .909 .877 r
.36874 .31347 .37296 .31307 .37952 .31019 .37532 .31058 Mtetra
.478 .897 .871 r
.37532 .31058 .37952 .31019 .38608 .30744 .3819 .30783 Mtetra
.454 .885 .864 r
.3819 .30783 .38608 .30744 .39265 .30482 .38849 .30521 Mtetra
.43 .872 .858 r
.38849 .30521 .39265 .30482 .39924 .30233 .3951 .30272 Mtetra
.406 .859 .85 r
.3951 .30272 .39924 .30233 .40583 .29998 .40171 .30036 Mtetra
.381 .845 .843 r
.40171 .30036 .40583 .29998 .41243 .29777 .40833 .29813 Mtetra
.357 .831 .835 r
.40833 .29813 .41243 .29777 .41905 .29569 .41497 .29604 Mtetra
.332 .816 .828 r
.41497 .29604 .41905 .29569 .42568 .29374 .42162 .29408 Mtetra
.308 .801 .82 r
.42162 .29408 .42568 .29374 .43232 .29193 .42828 .29225 Mtetra
.284 .785 .812 r
.42828 .29225 .43232 .29193 .43898 .29025 .43496 .29055 Mtetra
.26 .77 .804 r
.43496 .29055 .43898 .29025 .44565 .2887 .44165 .28898 Mtetra
.237 .754 .796 r
.44165 .28898 .44565 .2887 .45235 .28729 .44836 .28755 Mtetra
.214 .739 .788 r
.44836 .28755 .45235 .28729 .45905 .286 .45509 .28624 Mtetra
.192 .723 .781 r
.45509 .28624 .45905 .286 .46578 .28484 .46184 .28505 Mtetra
.171 .708 .773 r
.46184 .28505 .46578 .28484 .47253 .28382 .46861 .284 Mtetra
.15 .694 .767 r
.46861 .284 .47253 .28382 .4793 .28291 .4754 .28306 Mtetra
.131 .679 .76 r
.4754 .28306 .4793 .28291 .48609 .28214 .48221 .28225 Mtetra
.112 .665 .755 r
.48221 .28225 .48609 .28214 .4929 .28148 .48904 .28156 Mtetra
.095 .652 .749 r
.48904 .28156 .4929 .28148 .49974 .28094 .4959 .28099 Mtetra
.078 .64 .745 r
.4959 .28099 .49974 .28094 .5066 .28052 .50278 .28053 Mtetra
.063 .628 .741 r
.50278 .28053 .5066 .28052 .51349 .28022 .50968 .28018 Mtetra
.049 .616 .738 r
.50968 .28018 .51349 .28022 .52041 .28002 .51662 .27994 Mtetra
.036 .606 .735 r
.51662 .27994 .52041 .28002 .52735 .27994 .52358 .27981 Mtetra
.024 .596 .733 r
.52358 .27981 .52735 .27994 .53432 .27996 .53057 .27978 Mtetra
.013 .588 .733 r
.53057 .27978 .53432 .27996 .54132 .28008 .53759 .27985 Mtetra
.004 .58 .733 r
.53759 .27985 .54132 .28008 .54835 .28029 .54463 .28001 Mtetra
0 .573 .733 r
.54463 .28001 .54835 .28029 .55541 .28061 .55171 .28027 Mtetra
0 .567 .735 r
.55171 .28027 .55541 .28061 .56251 .281 .55883 .2806 Mtetra
0 .562 .738 r
.55883 .2806 .56251 .281 .56963 .28149 .56597 .28103 Mtetra
0 .558 .741 r
.56597 .28103 .56963 .28149 .57679 .28205 .57314 .28152 Mtetra
0 .555 .746 r
.57314 .28152 .57679 .28205 .58398 .28268 .58035 .28209 Mtetra
0 .553 .751 r
.58035 .28209 .58398 .28268 .59121 .28339 .5876 .28273 Mtetra
0 .552 .758 r
.5876 .28273 .59121 .28339 .59847 .28416 .59488 .28342 Mtetra
0 .552 .765 r
.59488 .28342 .59847 .28416 .60577 .28498 .60219 .28417 Mtetra
0 .554 .773 r
.60219 .28417 .60577 .28498 .6131 .28585 .60954 .28496 Mtetra
0 .556 .782 r
.60954 .28496 .6131 .28585 .62047 .28677 .61693 .2858 Mtetra
0 .559 .792 r
.61693 .2858 .62047 .28677 .62788 .28772 .62435 .28667 Mtetra
.001 .563 .803 r
.62435 .28667 .62788 .28772 .63532 .2887 .63181 .28756 Mtetra
.011 .569 .814 r
.63181 .28756 .63532 .2887 .6428 .28971 .6393 .28847 Mtetra
.023 .575 .826 r
.6393 .28847 .6428 .28971 .65032 .29072 .64683 .2894 Mtetra
.036 .582 .838 r
.64683 .2894 .65032 .29072 .65788 .29175 .6544 .29032 Mtetra
.051 .59 .851 r
.6544 .29032 .65788 .29175 .66547 .29276 .66201 .29124 Mtetra
.068 .599 .865 r
.66201 .29124 .66547 .29276 .6731 .29377 .66965 .29214 Mtetra
.086 .609 .878 r
.66965 .29214 .6731 .29377 .68076 .29475 .67733 .29302 Mtetra
.106 .619 .892 r
.67733 .29302 .68076 .29475 .68846 .29571 .68504 .29386 Mtetra
.128 .63 .905 r
.68504 .29386 .68846 .29571 .6962 .29662 .69279 .29465 Mtetra
.151 .641 .918 r
.69279 .29465 .6962 .29662 .70397 .29747 .70057 .29539 Mtetra
.176 .652 .93 r
.70057 .29539 .70397 .29747 .71177 .29827 .70838 .29607 Mtetra
.202 .664 .942 r
.70838 .29607 .71177 .29827 .71961 .29899 .71623 .29666 Mtetra
.229 .675 .953 r
.71623 .29666 .71961 .29899 .72748 .29962 .72411 .29716 Mtetra
.256 .686 .963 r
.72411 .29716 .72748 .29962 .73538 .30016 .73202 .29757 Mtetra
.285 .697 .972 r
.73202 .29757 .73538 .30016 .74331 .30058 .73996 .29785 Mtetra
.314 .708 .979 r
.73996 .29785 .74331 .30058 .75126 .30089 .74792 .29801 Mtetra
.344 .718 .985 r
.74792 .29801 .75126 .30089 .75925 .30105 .75591 .29804 Mtetra
.785 .862 .907 r
.06962 .52422 .07443 .52631 .08083 .52179 .07602 .51981 Mtetra
.792 .869 .905 r
.07602 .51981 .08083 .52179 .08726 .51712 .08244 .51527 Mtetra
.798 .875 .904 r
.08244 .51527 .08726 .51712 .09371 .51233 .08889 .51059 Mtetra
.803 .881 .903 r
.08889 .51059 .09371 .51233 .10017 .50743 .09536 .5058 Mtetra
.808 .886 .901 r
.09536 .5058 .10017 .50743 .10666 .50242 .10184 .50091 Mtetra
.812 .892 .901 r
.10184 .50091 .10666 .50242 .11316 .49732 .10834 .49591 Mtetra
.816 .897 .9 r
.10834 .49591 .11316 .49732 .11967 .49215 .11486 .49084 Mtetra
.819 .903 .899 r
.11486 .49084 .11967 .49215 .12619 .4869 .12138 .48569 Mtetra
.821 .908 .899 r
.12138 .48569 .12619 .4869 .13273 .48159 .12792 .48048 Mtetra
.824 .913 .899 r
.12792 .48048 .13273 .48159 .13927 .47624 .13447 .47521 Mtetra
.825 .918 .899 r
.13447 .47521 .13927 .47624 .14582 .47084 .14103 .46991 Mtetra
.827 .923 .899 r
.14103 .46991 .14582 .47084 .15237 .46541 .14759 .46456 Mtetra
.828 .927 .899 r
.14759 .46456 .15237 .46541 .15893 .45996 .15416 .4592 Mtetra
.828 .932 .899 r
.15416 .4592 .15893 .45996 .1655 .4545 .16073 .45381 Mtetra
.828 .937 .9 r
.16073 .45381 .1655 .4545 .17206 .44903 .16731 .44842 Mtetra
.827 .941 .9 r
.16731 .44842 .17206 .44903 .17863 .44357 .17389 .44303 Mtetra
.826 .945 .901 r
.17389 .44303 .17863 .44357 .1852 .43812 .18047 .43765 Mtetra
.825 .949 .902 r
.18047 .43765 .1852 .43812 .19177 .43268 .18705 .43229 Mtetra
.823 .953 .902 r
.18705 .43229 .19177 .43268 .19834 .42728 .19363 .42694 Mtetra
.82 .957 .903 r
.19363 .42694 .19834 .42728 .20491 .4219 .20021 .42163 Mtetra
.817 .961 .904 r
.20021 .42163 .20491 .4219 .21148 .41657 .2068 .41636 Mtetra
.813 .964 .905 r
.2068 .41636 .21148 .41657 .21804 .41128 .21338 .41112 Mtetra
.809 .968 .906 r
.21338 .41112 .21804 .41128 .22461 .40605 .21995 .40594 Mtetra
.804 .971 .907 r
.21995 .40594 .22461 .40605 .23117 .40087 .22653 .40081 Mtetra
.798 .973 .908 r
.22653 .40081 .23117 .40087 .23773 .39576 .23311 .39575 Mtetra
.792 .976 .909 r
.23311 .39575 .23773 .39576 .24429 .39071 .23968 .39075 Mtetra
.785 .978 .909 r
.23968 .39075 .24429 .39071 .25084 .38574 .24625 .38582 Mtetra
.777 .979 .91 r
.24625 .38582 .25084 .38574 .25739 .38085 .25282 .38097 Mtetra
.769 .981 .91 r
.25282 .38097 .25739 .38085 .26394 .37604 .25939 .3762 Mtetra
.76 .982 .911 r
.25939 .3762 .26394 .37604 .27049 .37133 .26595 .37152 Mtetra
.749 .982 .911 r
.26595 .37152 .27049 .37133 .27704 .3667 .27252 .36693 Mtetra
.739 .982 .911 r
.27252 .36693 .27704 .3667 .28358 .36217 .27908 .36243 Mtetra
.727 .981 .91 r
.27908 .36243 .28358 .36217 .29013 .35774 .28564 .35803 Mtetra
.714 .98 .91 r
.28564 .35803 .29013 .35774 .29667 .35342 .29221 .35373 Mtetra
.7 .978 .909 r
.29221 .35373 .29667 .35342 .30321 .3492 .29877 .34953 Mtetra
.686 .975 .907 r
.29877 .34953 .30321 .3492 .30976 .34509 .30533 .34545 Mtetra
.671 .972 .906 r
.30533 .34545 .30976 .34509 .3163 .34109 .31189 .34147 Mtetra
.654 .968 .904 r
.31189 .34147 .3163 .34109 .32284 .33721 .31845 .33761 Mtetra
.637 .963 .901 r
.31845 .33761 .32284 .33721 .32939 .33345 .32502 .33386 Mtetra
.619 .957 .898 r
.32502 .33386 .32939 .33345 .33594 .32981 .33159 .33023 Mtetra
.6 .95 .895 r
.33159 .33023 .33594 .32981 .34249 .32629 .33816 .32672 Mtetra
.58 .943 .891 r
.33816 .32672 .34249 .32629 .34905 .32289 .34473 .32333 Mtetra
.559 .935 .886 r
.34473 .32333 .34905 .32289 .3556 .31962 .35131 .32007 Mtetra
.538 .925 .882 r
.35131 .32007 .3556 .31962 .36217 .31648 .3579 .31693 Mtetra
.516 .916 .876 r
.3579 .31693 .36217 .31648 .36874 .31347 .36449 .31392 Mtetra
.493 .905 .87 r
.36449 .31392 .36874 .31347 .37532 .31058 .37108 .31103 Mtetra
.47 .893 .864 r
.37108 .31103 .37532 .31058 .3819 .30783 .37769 .30828 Mtetra
.446 .881 .858 r
.37769 .30828 .3819 .30783 .38849 .30521 .3843 .30565 Mtetra
.423 .868 .851 r
.3843 .30565 .38849 .30521 .3951 .30272 .39092 .30315 Mtetra
.398 .855 .843 r
.39092 .30315 .3951 .30272 .40171 .30036 .39756 .30079 Mtetra
.374 .841 .836 r
.39756 .30079 .40171 .30036 .40833 .29813 .4042 .29855 Mtetra
.35 .827 .828 r
.4042 .29855 .40833 .29813 .41497 .29604 .41086 .29645 Mtetra
.326 .812 .82 r
.41086 .29645 .41497 .29604 .42162 .29408 .41753 .29447 Mtetra
.302 .797 .812 r
.41753 .29447 .42162 .29408 .42828 .29225 .42421 .29262 Mtetra
.278 .782 .804 r
.42421 .29262 .42828 .29225 .43496 .29055 .43091 .29091 Mtetra
.255 .766 .797 r
.43091 .29091 .43496 .29055 .44165 .28898 .43762 .28932 Mtetra
.233 .751 .789 r
.43762 .28932 .44165 .28898 .44836 .28755 .44435 .28786 Mtetra
.211 .736 .781 r
.44435 .28786 .44836 .28755 .45509 .28624 .4511 .28652 Mtetra
.189 .721 .774 r
.4511 .28652 .45509 .28624 .46184 .28505 .45787 .28531 Mtetra
.169 .707 .767 r
.45787 .28531 .46184 .28505 .46861 .284 .46466 .28422 Mtetra
.149 .692 .761 r
.46466 .28422 .46861 .284 .4754 .28306 .47146 .28326 Mtetra
.13 .678 .755 r
.47146 .28326 .4754 .28306 .48221 .28225 .47829 .28241 Mtetra
.112 .665 .75 r
.47829 .28241 .48221 .28225 .48904 .28156 .48514 .28169 Mtetra
.095 .652 .745 r
.48514 .28169 .48904 .28156 .4959 .28099 .49202 .28107 Mtetra
.079 .64 .741 r
.49202 .28107 .4959 .28099 .50278 .28053 .49892 .28057 Mtetra
.064 .629 .737 r
.49892 .28057 .50278 .28053 .50968 .28018 .50585 .28018 Mtetra
.051 .618 .735 r
.50585 .28018 .50968 .28018 .51662 .27994 .5128 .2799 Mtetra
.038 .608 .733 r
.5128 .2799 .51662 .27994 .52358 .27981 .51978 .27972 Mtetra
.027 .599 .731 r
.51978 .27972 .52358 .27981 .53057 .27978 .52679 .27964 Mtetra
.017 .591 .731 r
.52679 .27964 .53057 .27978 .53759 .27985 .53382 .27965 Mtetra
.009 .584 .732 r
.53382 .27965 .53759 .27985 .54463 .28001 .54089 .27976 Mtetra
.001 .577 .733 r
.54089 .27976 .54463 .28001 .55171 .28027 .54799 .27996 Mtetra
0 .572 .735 r
.54799 .27996 .55171 .28027 .55883 .2806 .55512 .28023 Mtetra
0 .568 .739 r
.55512 .28023 .55883 .2806 .56597 .28103 .56228 .28059 Mtetra
0 .564 .743 r
.56228 .28059 .56597 .28103 .57314 .28152 .56947 .28102 Mtetra
0 .562 .748 r
.56947 .28102 .57314 .28152 .58035 .28209 .5767 .28152 Mtetra
0 .561 .754 r
.5767 .28152 .58035 .28209 .5876 .28273 .58396 .28208 Mtetra
0 .56 .761 r
.58396 .28208 .5876 .28273 .59488 .28342 .59126 .2827 Mtetra
0 .561 .769 r
.59126 .2827 .59488 .28342 .60219 .28417 .59859 .28337 Mtetra
0 .563 .778 r
.59859 .28337 .60219 .28417 .60954 .28496 .60595 .28408 Mtetra
0 .566 .787 r
.60595 .28408 .60954 .28496 .61693 .2858 .61335 .28484 Mtetra
.006 .569 .798 r
.61335 .28484 .61693 .2858 .62435 .28667 .62079 .28562 Mtetra
.015 .574 .809 r
.62079 .28562 .62435 .28667 .63181 .28756 .62827 .28642 Mtetra
.025 .58 .821 r
.62827 .28642 .63181 .28756 .6393 .28847 .63578 .28724 Mtetra
.038 .587 .833 r
.63578 .28724 .6393 .28847 .64683 .2894 .64332 .28806 Mtetra
.052 .594 .846 r
.64332 .28806 .64683 .2894 .6544 .29032 .6509 .28889 Mtetra
.068 .603 .859 r
.6509 .28889 .6544 .29032 .66201 .29124 .65852 .2897 Mtetra
.085 .612 .873 r
.65852 .2897 .66201 .29124 .66965 .29214 .66618 .29049 Mtetra
.104 .622 .886 r
.66618 .29049 .66965 .29214 .67733 .29302 .67387 .29126 Mtetra
.125 .632 .9 r
.67387 .29126 .67733 .29302 .68504 .29386 .68159 .29198 Mtetra
.147 .643 .913 r
.68159 .29198 .68504 .29386 .69279 .29465 .68935 .29266 Mtetra
.171 .654 .926 r
.68935 .29266 .69279 .29465 .70057 .29539 .69714 .29328 Mtetra
.196 .665 .938 r
.69714 .29328 .70057 .29539 .70838 .29607 .70497 .29382 Mtetra
.222 .676 .95 r
.70497 .29382 .70838 .29607 .71623 .29666 .71283 .29429 Mtetra
.25 .688 .96 r
.71283 .29429 .71623 .29666 .72411 .29716 .72072 .29466 Mtetra
.278 .698 .969 r
.72072 .29466 .72411 .29716 .73202 .29757 .72863 .29492 Mtetra
.306 .709 .977 r
.72863 .29492 .73202 .29757 .73996 .29785 .73658 .29507 Mtetra
.335 .718 .984 r
.73658 .29507 .73996 .29785 .74792 .29801 .74455 .29508 Mtetra
.365 .728 .988 r
.74455 .29508 .74792 .29801 .75591 .29804 .75255 .29495 Mtetra
.779 .86 .91 r
.06478 .52206 .06962 .52422 .07602 .51981 .07118 .51778 Mtetra
.786 .867 .909 r
.07118 .51778 .07602 .51981 .08244 .51527 .0776 .51336 Mtetra
.792 .873 .907 r
.0776 .51336 .08244 .51527 .08889 .51059 .08405 .50881 Mtetra
.798 .88 .906 r
.08405 .50881 .08889 .51059 .09536 .5058 .09051 .50413 Mtetra
.803 .886 .905 r
.09051 .50413 .09536 .5058 .10184 .50091 .097 .49935 Mtetra
.807 .891 .904 r
.097 .49935 .10184 .50091 .10834 .49591 .1035 .49446 Mtetra
.811 .897 .904 r
.1035 .49446 .10834 .49591 .11486 .49084 .11002 .48949 Mtetra
.814 .903 .903 r
.11002 .48949 .11486 .49084 .12138 .48569 .11655 .48445 Mtetra
.817 .908 .903 r
.11655 .48445 .12138 .48569 .12792 .48048 .12309 .47934 Mtetra
.819 .913 .902 r
.12309 .47934 .12792 .48048 .13447 .47521 .12965 .47417 Mtetra
.821 .918 .902 r
.12965 .47417 .13447 .47521 .14103 .46991 .13621 .46895 Mtetra
.823 .923 .902 r
.13621 .46895 .14103 .46991 .14759 .46456 .14278 .4637 Mtetra
.823 .928 .902 r
.14278 .4637 .14759 .46456 .15416 .4592 .14936 .45842 Mtetra
.824 .933 .902 r
.14936 .45842 .15416 .4592 .16073 .45381 .15594 .45312 Mtetra
.824 .937 .903 r
.15594 .45312 .16073 .45381 .16731 .44842 .16253 .44781 Mtetra
.823 .942 .903 r
.16253 .44781 .16731 .44842 .17389 .44303 .16911 .44249 Mtetra
.822 .946 .904 r
.16911 .44249 .17389 .44303 .18047 .43765 .17571 .43718 Mtetra
.821 .95 .904 r
.17571 .43718 .18047 .43765 .18705 .43229 .1823 .43189 Mtetra
.818 .954 .905 r
.1823 .43189 .18705 .43229 .19363 .42694 .18889 .42661 Mtetra
.816 .958 .906 r
.18889 .42661 .19363 .42694 .20021 .42163 .19549 .42137 Mtetra
.813 .962 .906 r
.19549 .42137 .20021 .42163 .2068 .41636 .20208 .41615 Mtetra
.809 .965 .907 r
.20208 .41615 .2068 .41636 .21338 .41112 .20868 .41098 Mtetra
.804 .969 .908 r
.20868 .41098 .21338 .41112 .21995 .40594 .21527 .40585 Mtetra
.799 .972 .909 r
.21527 .40585 .21995 .40594 .22653 .40081 .22186 .40078 Mtetra
.793 .974 .909 r
.22186 .40078 .22653 .40081 .23311 .39575 .22845 .39576 Mtetra
.787 .976 .91 r
.22845 .39576 .23311 .39575 .23968 .39075 .23504 .39081 Mtetra
.78 .978 .91 r
.23504 .39081 .23968 .39075 .24625 .38582 .24163 .38593 Mtetra
.772 .98 .911 r
.24163 .38593 .24625 .38582 .25282 .38097 .24821 .38112 Mtetra
.763 .981 .911 r
.24821 .38112 .25282 .38097 .25939 .3762 .2548 .37639 Mtetra
.754 .982 .911 r
.2548 .37639 .25939 .3762 .26595 .37152 .26138 .37174 Mtetra
.744 .982 .911 r
.26138 .37174 .26595 .37152 .27252 .36693 .26796 .36719 Mtetra
.733 .982 .91 r
.26796 .36719 .27252 .36693 .27908 .36243 .27454 .36272 Mtetra
.721 .981 .91 r
.27454 .36272 .27908 .36243 .28564 .35803 .28112 .35835 Mtetra
.708 .979 .909 r
.28112 .35835 .28564 .35803 .29221 .35373 .2877 .35408 Mtetra
.694 .977 .907 r
.2877 .35408 .29221 .35373 .29877 .34953 .29428 .34991 Mtetra
.679 .974 .906 r
.29428 .34991 .29877 .34953 .30533 .34545 .30086 .34584 Mtetra
.664 .97 .903 r
.30086 .34584 .30533 .34545 .31189 .34147 .30745 .34188 Mtetra
.647 .966 .901 r
.30745 .34188 .31189 .34147 .31845 .33761 .31403 .33804 Mtetra
.63 .961 .898 r
.31403 .33804 .31845 .33761 .32502 .33386 .32061 .33431 Mtetra
.611 .955 .895 r
.32061 .33431 .32502 .33386 .33159 .33023 .3272 .33069 Mtetra
.592 .948 .891 r
.3272 .33069 .33159 .33023 .33816 .32672 .33379 .32719 Mtetra
.572 .94 .887 r
.33379 .32719 .33816 .32672 .34473 .32333 .34038 .32382 Mtetra
.552 .932 .882 r
.34038 .32382 .34473 .32333 .35131 .32007 .34698 .32056 Mtetra
.53 .922 .877 r
.34698 .32056 .35131 .32007 .3579 .31693 .35359 .31742 Mtetra
.508 .912 .871 r
.35359 .31742 .3579 .31693 .36449 .31392 .3602 .31441 Mtetra
.486 .901 .865 r
.3602 .31441 .36449 .31392 .37108 .31103 .36682 .31153 Mtetra
.463 .89 .859 r
.36682 .31153 .37108 .31103 .37769 .30828 .37344 .30877 Mtetra
.44 .878 .852 r
.37344 .30877 .37769 .30828 .3843 .30565 .38007 .30614 Mtetra
.416 .865 .845 r
.38007 .30614 .3843 .30565 .39092 .30315 .38672 .30364 Mtetra
.392 .851 .837 r
.38672 .30364 .39092 .30315 .39756 .30079 .39337 .30126 Mtetra
.368 .837 .83 r
.39337 .30126 .39756 .30079 .4042 .29855 .40003 .29902 Mtetra
.345 .823 .822 r
.40003 .29902 .4042 .29855 .41086 .29645 .40671 .2969 Mtetra
.321 .809 .814 r
.40671 .2969 .41086 .29645 .41753 .29447 .4134 .29491 Mtetra
.298 .794 .806 r
.4134 .29491 .41753 .29447 .42421 .29262 .4201 .29304 Mtetra
.275 .779 .798 r
.4201 .29304 .42421 .29262 .43091 .29091 .42682 .29131 Mtetra
.252 .764 .791 r
.42682 .29131 .43091 .29091 .43762 .28932 .43356 .2897 Mtetra
.23 .749 .783 r
.43356 .2897 .43762 .28932 .44435 .28786 .44031 .28821 Mtetra
.208 .734 .776 r
.44031 .28821 .44435 .28786 .4511 .28652 .44708 .28685 Mtetra
.188 .72 .769 r
.44708 .28685 .4511 .28652 .45787 .28531 .45386 .28561 Mtetra
.168 .706 .763 r
.45386 .28561 .45787 .28531 .46466 .28422 .46067 .28449 Mtetra
.149 .692 .757 r
.46067 .28449 .46466 .28422 .47146 .28326 .4675 .2835 Mtetra
.13 .679 .751 r
.4675 .2835 .47146 .28326 .47829 .28241 .47435 .28262 Mtetra
.113 .666 .746 r
.47435 .28262 .47829 .28241 .48514 .28169 .48122 .28185 Mtetra
.097 .654 .742 r
.48122 .28185 .48514 .28169 .49202 .28107 .48812 .2812 Mtetra
.082 .642 .738 r
.48812 .2812 .49202 .28107 .49892 .28057 .49504 .28065 Mtetra
.067 .631 .735 r
.49504 .28065 .49892 .28057 .50585 .28018 .50198 .28022 Mtetra
.054 .621 .733 r
.50198 .28022 .50585 .28018 .5128 .2799 .50895 .27989 Mtetra
.043 .612 .732 r
.50895 .27989 .5128 .2799 .51978 .27972 .51595 .27966 Mtetra
.032 .603 .731 r
.51595 .27966 .51978 .27972 .52679 .27964 .52298 .27952 Mtetra
.023 .596 .731 r
.52298 .27952 .52679 .27964 .53382 .27965 .53003 .27948 Mtetra
.015 .589 .732 r
.53003 .27948 .53382 .27965 .54089 .27976 .53712 .27953 Mtetra
.008 .583 .734 r
.53712 .27953 .54089 .27976 .54799 .27996 .54424 .27967 Mtetra
.003 .578 .737 r
.54424 .27967 .54799 .27996 .55512 .28023 .55138 .27988 Mtetra
0 .575 .741 r
.55138 .27988 .55512 .28023 .56228 .28059 .55856 .28017 Mtetra
0 .572 .746 r
.55856 .28017 .56228 .28059 .56947 .28102 .56577 .28054 Mtetra
0 .57 .752 r
.56577 .28054 .56947 .28102 .5767 .28152 .57302 .28096 Mtetra
0 .569 .758 r
.57302 .28096 .5767 .28152 .58396 .28208 .5803 .28145 Mtetra
0 .57 .766 r
.5803 .28145 .58396 .28208 .59126 .2827 .58761 .28199 Mtetra
0 .571 .774 r
.58761 .28199 .59126 .2827 .59859 .28337 .59496 .28258 Mtetra
.005 .573 .784 r
.59496 .28258 .59859 .28337 .60595 .28408 .60234 .28321 Mtetra
.011 .577 .794 r
.60234 .28321 .60595 .28408 .61335 .28484 .60976 .28387 Mtetra
.02 .581 .805 r
.60976 .28387 .61335 .28484 .62079 .28562 .61721 .28456 Mtetra
.029 .586 .816 r
.61721 .28456 .62079 .28562 .62827 .28642 .6247 .28527 Mtetra
.041 .592 .828 r
.6247 .28527 .62827 .28642 .63578 .28724 .63222 .28599 Mtetra
.054 .6 .841 r
.63222 .28599 .63578 .28724 .64332 .28806 .63978 .28672 Mtetra
.069 .608 .854 r
.63978 .28672 .64332 .28806 .6509 .28889 .64738 .28743 Mtetra
.086 .616 .868 r
.64738 .28743 .6509 .28889 .65852 .2897 .65501 .28814 Mtetra
.104 .626 .881 r
.65501 .28814 .65852 .2897 .66618 .29049 .66268 .28882 Mtetra
.124 .636 .895 r
.66268 .28882 .66618 .29049 .67387 .29126 .67038 .28947 Mtetra
.145 .646 .909 r
.67038 .28947 .67387 .29126 .68159 .29198 .67812 .29008 Mtetra
.168 .657 .922 r
.67812 .29008 .68159 .29198 .68935 .29266 .68589 .29063 Mtetra
.192 .668 .934 r
.68589 .29063 .68935 .29266 .69714 .29328 .6937 .29112 Mtetra
.218 .679 .946 r
.6937 .29112 .69714 .29328 .70497 .29382 .70153 .29153 Mtetra
.244 .689 .957 r
.70153 .29153 .70497 .29382 .71283 .29429 .7094 .29186 Mtetra
.272 .7 .967 r
.7094 .29186 .71283 .29429 .72072 .29466 .7173 .29209 Mtetra
.3 .71 .975 r
.7173 .29209 .72072 .29466 .72863 .29492 .72523 .29222 Mtetra
.328 .72 .982 r
.72523 .29222 .72863 .29492 .73658 .29507 .73318 .29221 Mtetra
.357 .729 .987 r
.73318 .29221 .73658 .29507 .74455 .29508 .74116 .29208 Mtetra
.386 .737 .991 r
.74116 .29208 .74455 .29508 .75255 .29495 .74917 .29179 Mtetra
.772 .858 .914 r
.05993 .51982 .06478 .52206 .07118 .51778 .06632 .51568 Mtetra
.779 .865 .912 r
.06632 .51568 .07118 .51778 .0776 .51336 .07274 .51138 Mtetra
.786 .871 .911 r
.07274 .51138 .0776 .51336 .08405 .50881 .07918 .50696 Mtetra
.792 .878 .91 r
.07918 .50696 .08405 .50881 .09051 .50413 .08565 .5024 Mtetra
.797 .884 .909 r
.08565 .5024 .09051 .50413 .097 .49935 .09213 .49773 Mtetra
.802 .89 .908 r
.09213 .49773 .097 .49935 .1035 .49446 .09864 .49297 Mtetra
.806 .896 .907 r
.09864 .49297 .1035 .49446 .11002 .48949 .10516 .48811 Mtetra
.809 .902 .907 r
.10516 .48811 .11002 .48949 .11655 .48445 .11169 .48317 Mtetra
.812 .907 .906 r
.11169 .48317 .11655 .48445 .12309 .47934 .11824 .47816 Mtetra
.815 .913 .906 r
.11824 .47816 .12309 .47934 .12965 .47417 .1248 .47309 Mtetra
.817 .918 .906 r
.1248 .47309 .12965 .47417 .13621 .46895 .13137 .46797 Mtetra
.818 .923 .906 r
.13137 .46797 .13621 .46895 .14278 .4637 .13794 .46281 Mtetra
.819 .928 .906 r
.13794 .46281 .14278 .4637 .14936 .45842 .14453 .45762 Mtetra
.82 .933 .906 r
.14453 .45762 .14936 .45842 .15594 .45312 .15112 .4524 Mtetra
.819 .938 .906 r
.15112 .4524 .15594 .45312 .16253 .44781 .15771 .44718 Mtetra
.819 .942 .906 r
.15771 .44718 .16253 .44781 .16911 .44249 .16431 .44194 Mtetra
.818 .947 .907 r
.16431 .44194 .16911 .44249 .17571 .43718 .17091 .43671 Mtetra
.816 .951 .907 r
.17091 .43671 .17571 .43718 .1823 .43189 .17752 .43149 Mtetra
.814 .955 .908 r
.17752 .43149 .1823 .43189 .18889 .42661 .18412 .42628 Mtetra
.811 .959 .908 r
.18412 .42628 .18889 .42661 .19549 .42137 .19073 .4211 Mtetra
.808 .963 .909 r
.19073 .4211 .19549 .42137 .20208 .41615 .19734 .41595 Mtetra
.804 .966 .909 r
.19734 .41595 .20208 .41615 .20868 .41098 .20394 .41084 Mtetra
.8 .969 .91 r
.20394 .41084 .20868 .41098 .21527 .40585 .21055 .40577 Mtetra
.795 .972 .911 r
.21055 .40577 .21527 .40585 .22186 .40078 .21716 .40075 Mtetra
.789 .975 .911 r
.21716 .40075 .22186 .40078 .22845 .39576 .22376 .39579 Mtetra
.782 .977 .911 r
.22376 .39579 .22845 .39576 .23504 .39081 .23037 .39089 Mtetra
.775 .979 .912 r
.23037 .39089 .23504 .39081 .24163 .38593 .23697 .38605 Mtetra
.767 .98 .912 r
.23697 .38605 .24163 .38593 .24821 .38112 .24357 .38129 Mtetra
.758 .981 .912 r
.24357 .38129 .24821 .38112 .2548 .37639 .25017 .3766 Mtetra
.749 .982 .911 r
.25017 .3766 .2548 .37639 .26138 .37174 .25677 .37199 Mtetra
.738 .982 .911 r
.25677 .37199 .26138 .37174 .26796 .36719 .26337 .36747 Mtetra
.727 .981 .91 r
.26337 .36747 .26796 .36719 .27454 .36272 .26997 .36304 Mtetra
.715 .98 .909 r
.26997 .36304 .27454 .36272 .28112 .35835 .27657 .3587 Mtetra
.702 .978 .908 r
.27657 .3587 .28112 .35835 .2877 .35408 .28317 .35445 Mtetra
.688 .976 .906 r
.28317 .35445 .2877 .35408 .29428 .34991 .28977 .35031 Mtetra
.673 .973 .904 r
.28977 .35031 .29428 .34991 .30086 .34584 .29636 .34627 Mtetra
.657 .969 .902 r
.29636 .34627 .30086 .34584 .30745 .34188 .30296 .34233 Mtetra
.641 .964 .899 r
.30296 .34233 .30745 .34188 .31403 .33804 .30957 .33851 Mtetra
.623 .959 .895 r
.30957 .33851 .31403 .33804 .32061 .33431 .31617 .33479 Mtetra
.605 .952 .892 r
.31617 .33479 .32061 .33431 .3272 .33069 .32278 .33119 Mtetra
.586 .945 .888 r
.32278 .33119 .3272 .33069 .33379 .32719 .32939 .3277 Mtetra
.566 .938 .883 r
.32939 .3277 .33379 .32719 .34038 .32382 .336 .32433 Mtetra
.545 .929 .878 r
.336 .32433 .34038 .32382 .34698 .32056 .34262 .32109 Mtetra
.524 .919 .873 r
.34262 .32109 .34698 .32056 .35359 .31742 .34924 .31796 Mtetra
.502 .909 .867 r
.34924 .31796 .35359 .31742 .3602 .31441 .35588 .31495 Mtetra
.48 .898 .86 r
.35588 .31495 .3602 .31441 .36682 .31153 .36251 .31207 Mtetra
.457 .887 .854 r
.36251 .31207 .36682 .31153 .37344 .30877 .36916 .30931 Mtetra
.434 .874 .847 r
.36916 .30931 .37344 .30877 .38007 .30614 .37581 .30667 Mtetra
.411 .862 .84 r
.37581 .30667 .38007 .30614 .38672 .30364 .38248 .30416 Mtetra
.387 .848 .832 r
.38248 .30416 .38672 .30364 .39337 .30126 .38915 .30178 Mtetra
.364 .835 .825 r
.38915 .30178 .39337 .30126 .40003 .29902 .39583 .29952 Mtetra
.341 .82 .817 r
.39583 .29952 .40003 .29902 .40671 .2969 .40253 .29739 Mtetra
.317 .806 .809 r
.40253 .29739 .40671 .2969 .4134 .29491 .40924 .29538 Mtetra
.294 .792 .801 r
.40924 .29538 .4134 .29491 .4201 .29304 .41597 .2935 Mtetra
.272 .777 .794 r
.41597 .2935 .4201 .29304 .42682 .29131 .4227 .29174 Mtetra
.25 .762 .786 r
.4227 .29174 .42682 .29131 .43356 .2897 .42946 .29011 Mtetra
.228 .748 .779 r
.42946 .29011 .43356 .2897 .44031 .28821 .43623 .2886 Mtetra
.208 .734 .772 r
.43623 .2886 .44031 .28821 .44708 .28685 .44302 .28721 Mtetra
.187 .72 .766 r
.44302 .28721 .44708 .28685 .45386 .28561 .44983 .28595 Mtetra
.168 .706 .759 r
.44983 .28595 .45386 .28561 .46067 .28449 .45665 .2848 Mtetra
.15 .693 .754 r
.45665 .2848 .46067 .28449 .4675 .2835 .4635 .28377 Mtetra
.132 .68 .749 r
.4635 .28377 .4675 .2835 .47435 .28262 .47037 .28285 Mtetra
.115 .667 .744 r
.47037 .28285 .47435 .28262 .48122 .28185 .47726 .28204 Mtetra
.1 .656 .74 r
.47726 .28204 .48122 .28185 .48812 .2812 .48418 .28135 Mtetra
.085 .645 .737 r
.48418 .28135 .48812 .2812 .49504 .28065 .49112 .28076 Mtetra
.072 .634 .735 r
.49112 .28076 .49504 .28065 .50198 .28022 .49809 .28028 Mtetra
.06 .625 .733 r
.49809 .28028 .50198 .28022 .50895 .27989 .50508 .2799 Mtetra
.048 .616 .732 r
.50508 .2799 .50895 .27989 .51595 .27966 .51209 .27962 Mtetra
.039 .608 .732 r
.51209 .27962 .51595 .27966 .52298 .27952 .51914 .27943 Mtetra
.03 .601 .733 r
.51914 .27943 .52298 .27952 .53003 .27948 .52622 .27933 Mtetra
.022 .595 .735 r
.52622 .27933 .53003 .27948 .53712 .27953 .53332 .27932 Mtetra
.016 .59 .737 r
.53332 .27932 .53712 .27953 .54424 .27967 .54045 .27939 Mtetra
.012 .586 .741 r
.54045 .27939 .54424 .27967 .55138 .27988 .54762 .27954 Mtetra
.008 .583 .745 r
.54762 .27954 .55138 .27988 .55856 .28017 .55482 .27977 Mtetra
.006 .58 .75 r
.55482 .27977 .55856 .28017 .56577 .28054 .56205 .28006 Mtetra
.006 .579 .757 r
.56205 .28006 .56577 .28054 .57302 .28096 .56931 .28041 Mtetra
.007 .579 .764 r
.56931 .28041 .57302 .28096 .5803 .28145 .5766 .28082 Mtetra
.009 .58 .772 r
.5766 .28082 .5803 .28145 .58761 .28199 .58393 .28128 Mtetra
.013 .582 .781 r
.58393 .28128 .58761 .28199 .59496 .28258 .5913 .28178 Mtetra
.019 .585 .791 r
.5913 .28178 .59496 .28258 .60234 .28321 .5987 .28232 Mtetra
.026 .588 .802 r
.5987 .28232 .60234 .28321 .60976 .28387 .60613 .2829 Mtetra
.035 .593 .813 r
.60613 .2829 .60976 .28387 .61721 .28456 .6136 .28349 Mtetra
.046 .599 .825 r
.6136 .28349 .61721 .28456 .6247 .28527 .62111 .2841 Mtetra
.058 .606 .837 r
.62111 .2841 .6247 .28527 .63222 .28599 .62865 .28472 Mtetra
.072 .613 .85 r
.62865 .28472 .63222 .28599 .63978 .28672 .63622 .28534 Mtetra
.088 .621 .864 r
.63622 .28534 .63978 .28672 .64738 .28743 .64383 .28595 Mtetra
.105 .63 .877 r
.64383 .28595 .64738 .28743 .65501 .28814 .65148 .28655 Mtetra
.124 .64 .891 r
.65148 .28655 .65501 .28814 .66268 .28882 .65916 .28711 Mtetra
.145 .65 .905 r
.65916 .28711 .66268 .28882 .67038 .28947 .66688 .28764 Mtetra
.167 .66 .918 r
.66688 .28764 .67038 .28947 .67812 .29008 .67463 .28813 Mtetra
.19 .671 .931 r
.67463 .28813 .67812 .29008 .68589 .29063 .68241 .28855 Mtetra
.215 .681 .943 r
.68241 .28855 .68589 .29063 .6937 .29112 .69022 .28891 Mtetra
.241 .692 .954 r
.69022 .28891 .6937 .29112 .70153 .29153 .69807 .28919 Mtetra
.268 .702 .964 r
.69807 .28919 .70153 .29153 .7094 .29186 .70595 .28938 Mtetra
.295 .712 .973 r
.70595 .28938 .7094 .29186 .7173 .29209 .71386 .28947 Mtetra
.323 .722 .981 r
.71386 .28947 .7173 .29209 .72523 .29222 .72179 .28944 Mtetra
.351 .731 .986 r
.72179 .28944 .72523 .29222 .73318 .29221 .72976 .28929 Mtetra
.38 .739 .991 r
.72976 .28929 .73318 .29221 .74116 .29208 .73774 .28899 Mtetra
.408 .746 .993 r
.73774 .28899 .74116 .29208 .74917 .29179 .74576 .28855 Mtetra
.765 .854 .917 r
.05507 .5175 .05993 .51982 .06632 .51568 .06145 .5135 Mtetra
.773 .862 .916 r
.06145 .5135 .06632 .51568 .07274 .51138 .06786 .50934 Mtetra
.779 .869 .914 r
.06786 .50934 .07274 .51138 .07918 .50696 .0743 .50503 Mtetra
.786 .876 .913 r
.0743 .50503 .07918 .50696 .08565 .5024 .08077 .50061 Mtetra
.791 .882 .912 r
.08077 .50061 .08565 .5024 .09213 .49773 .08725 .49606 Mtetra
.796 .889 .911 r
.08725 .49606 .09213 .49773 .09864 .49297 .09375 .49141 Mtetra
.8 .895 .911 r
.09375 .49141 .09864 .49297 .10516 .48811 .10027 .48667 Mtetra
.804 .901 .91 r
.10027 .48667 .10516 .48811 .11169 .48317 .10681 .48184 Mtetra
.807 .906 .91 r
.10681 .48184 .11169 .48317 .11824 .47816 .11336 .47693 Mtetra
.81 .912 .909 r
.11336 .47693 .11824 .47816 .1248 .47309 .11992 .47197 Mtetra
.812 .918 .909 r
.11992 .47197 .1248 .47309 .13137 .46797 .12649 .46695 Mtetra
.813 .923 .909 r
.12649 .46695 .13137 .46797 .13794 .46281 .13308 .46189 Mtetra
.814 .928 .909 r
.13308 .46189 .13794 .46281 .14453 .45762 .13967 .45679 Mtetra
.815 .933 .909 r
.13967 .45679 .14453 .45762 .15112 .4524 .14626 .45166 Mtetra
.815 .938 .909 r
.14626 .45166 .15112 .4524 .15771 .44718 .15287 .44652 Mtetra
.815 .943 .91 r
.15287 .44652 .15771 .44718 .16431 .44194 .15947 .44137 Mtetra
.813 .947 .91 r
.15947 .44137 .16431 .44194 .17091 .43671 .16609 .43622 Mtetra
.812 .951 .91 r
.16609 .43622 .17091 .43671 .17752 .43149 .1727 .43107 Mtetra
.81 .955 .911 r
.1727 .43107 .17752 .43149 .18412 .42628 .17932 .42594 Mtetra
.807 .959 .911 r
.17932 .42594 .18412 .42628 .19073 .4211 .18594 .42083 Mtetra
.804 .963 .911 r
.18594 .42083 .19073 .4211 .19734 .41595 .19256 .41574 Mtetra
.8 .966 .912 r
.19256 .41574 .19734 .41595 .20394 .41084 .19918 .41069 Mtetra
.795 .97 .912 r
.19918 .41069 .20394 .41084 .21055 .40577 .2058 .40569 Mtetra
.79 .972 .913 r
.2058 .40569 .21055 .40577 .21716 .40075 .21242 .40073 Mtetra
.784 .975 .913 r
.21242 .40073 .21716 .40075 .22376 .39579 .21904 .39582 Mtetra
.777 .977 .913 r
.21904 .39582 .22376 .39579 .23037 .39089 .22566 .39097 Mtetra
.77 .979 .913 r
.22566 .39097 .23037 .39089 .23697 .38605 .23228 .38618 Mtetra
.762 .98 .913 r
.23228 .38618 .23697 .38605 .24357 .38129 .2389 .38146 Mtetra
.753 .981 .912 r
.2389 .38146 .24357 .38129 .25017 .3766 .24551 .37682 Mtetra
.743 .981 .912 r
.24551 .37682 .25017 .3766 .25677 .37199 .25213 .37225 Mtetra
.733 .981 .911 r
.25213 .37225 .25677 .37199 .26337 .36747 .25875 .36777 Mtetra
.721 .981 .91 r
.25875 .36777 .26337 .36747 .26997 .36304 .26536 .36337 Mtetra
.709 .979 .909 r
.26536 .36337 .26997 .36304 .27657 .3587 .27198 .35906 Mtetra
.696 .977 .907 r
.27198 .35906 .27657 .3587 .28317 .35445 .2786 .35485 Mtetra
.682 .975 .905 r
.2786 .35485 .28317 .35445 .28977 .35031 .28521 .35073 Mtetra
.667 .971 .903 r
.28521 .35073 .28977 .35031 .29636 .34627 .29183 .34672 Mtetra
.651 .967 .9 r
.29183 .34672 .29636 .34627 .30296 .34233 .29845 .34281 Mtetra
.634 .962 .897 r
.29845 .34281 .30296 .34233 .30957 .33851 .30507 .339 Mtetra
.617 .957 .893 r
.30507 .339 .30957 .33851 .31617 .33479 .31169 .3353 Mtetra
.599 .95 .889 r
.31169 .3353 .31617 .33479 .32278 .33119 .31832 .33172 Mtetra
.58 .943 .885 r
.31832 .33172 .32278 .33119 .32939 .3277 .32495 .32824 Mtetra
.56 .935 .88 r
.32495 .32824 .32939 .3277 .336 .32433 .33158 .32488 Mtetra
.539 .926 .875 r
.33158 .32488 .336 .32433 .34262 .32109 .33822 .32164 Mtetra
.518 .917 .869 r
.33822 .32164 .34262 .32109 .34924 .31796 .34487 .31852 Mtetra
.497 .907 .863 r
.34487 .31852 .34924 .31796 .35588 .31495 .35152 .31552 Mtetra
.475 .896 .857 r
.35152 .31552 .35588 .31495 .36251 .31207 .35818 .31263 Mtetra
.452 .884 .85 r
.35818 .31263 .36251 .31207 .36916 .30931 .36484 .30987 Mtetra
.429 .872 .843 r
.36484 .30987 .36916 .30931 .37581 .30667 .37152 .30723 Mtetra
.406 .859 .836 r
.37152 .30723 .37581 .30667 .38248 .30416 .3782 .30472 Mtetra
.383 .846 .828 r
.3782 .30472 .38248 .30416 .38915 .30178 .38489 .30232 Mtetra
.36 .832 .821 r
.38489 .30232 .38915 .30178 .39583 .29952 .3916 .30006 Mtetra
.338 .819 .813 r
.3916 .30006 .39583 .29952 .40253 .29739 .39832 .29791 Mtetra
.315 .805 .805 r
.39832 .29791 .40253 .29739 .40924 .29538 .40505 .29589 Mtetra
.293 .79 .798 r
.40505 .29589 .40924 .29538 .41597 .2935 .41179 .29399 Mtetra
.271 .776 .791 r
.41179 .29399 .41597 .2935 .4227 .29174 .41855 .29221 Mtetra
.249 .762 .783 r
.41855 .29221 .4227 .29174 .42946 .29011 .42533 .29056 Mtetra
.228 .748 .776 r
.42533 .29056 .42946 .29011 .43623 .2886 .43212 .28902 Mtetra
.208 .734 .77 r
.43212 .28902 .43623 .2886 .44302 .28721 .43893 .28761 Mtetra
.189 .72 .764 r
.43893 .28761 .44302 .28721 .44983 .28595 .44576 .28631 Mtetra
.17 .707 .758 r
.44576 .28631 .44983 .28595 .45665 .2848 .45261 .28513 Mtetra
.152 .694 .753 r
.45261 .28513 .45665 .2848 .4635 .28377 .45948 .28406 Mtetra
.135 .682 .748 r
.45948 .28406 .4635 .28377 .47037 .28285 .46637 .2831 Mtetra
.119 .67 .744 r
.46637 .2831 .47037 .28285 .47726 .28204 .47328 .28226 Mtetra
.104 .659 .74 r
.47328 .28226 .47726 .28204 .48418 .28135 .48021 .28152 Mtetra
.09 .649 .738 r
.48021 .28152 .48418 .28135 .49112 .28076 .48717 .28089 Mtetra
.078 .639 .736 r
.48717 .28089 .49112 .28076 .49809 .28028 .49416 .28036 Mtetra
.066 .63 .735 r
.49416 .28036 .49809 .28028 .50508 .2799 .50117 .27993 Mtetra
.056 .622 .734 r
.50117 .27993 .50508 .2799 .51209 .27962 .50821 .27959 Mtetra
.046 .615 .735 r
.50821 .27959 .51209 .27962 .51914 .27943 .51527 .27935 Mtetra
.038 .608 .736 r
.51527 .27935 .51914 .27943 .52622 .27933 .52237 .27919 Mtetra
.032 .603 .738 r
.52237 .27919 .52622 .27933 .53332 .27932 .52949 .27912 Mtetra
.026 .598 .742 r
.52949 .27912 .53332 .27932 .54045 .27939 .53664 .27913 Mtetra
.022 .594 .746 r
.53664 .27913 .54045 .27939 .54762 .27954 .54383 .27921 Mtetra
.02 .592 .751 r
.54383 .27921 .54762 .27954 .55482 .27977 .55104 .27936 Mtetra
.018 .59 .757 r
.55104 .27936 .55482 .27977 .56205 .28006 .55829 .27958 Mtetra
.019 .59 .763 r
.55829 .27958 .56205 .28006 .56931 .28041 .56557 .27985 Mtetra
.02 .59 .771 r
.56557 .27985 .56931 .28041 .5766 .28082 .57289 .28018 Mtetra
.024 .591 .78 r
.57289 .28018 .5766 .28082 .58393 .28128 .58023 .28056 Mtetra
.029 .594 .789 r
.58023 .28056 .58393 .28128 .5913 .28178 .58761 .28097 Mtetra
.035 .597 .8 r
.58761 .28097 .5913 .28178 .5987 .28232 .59503 .28142 Mtetra
.043 .601 .811 r
.59503 .28142 .5987 .28232 .60613 .2829 .60248 .2819 Mtetra
.053 .607 .822 r
.60248 .2819 .60613 .2829 .6136 .28349 .60997 .2824 Mtetra
.064 .613 .835 r
.60997 .2824 .6136 .28349 .62111 .2841 .61749 .28291 Mtetra
.077 .62 .848 r
.61749 .28291 .62111 .2841 .62865 .28472 .62504 .28343 Mtetra
.092 .627 .861 r
.62504 .28343 .62865 .28472 .63622 .28534 .63263 .28394 Mtetra
.109 .636 .874 r
.63263 .28394 .63622 .28534 .64383 .28595 .64026 .28444 Mtetra
.127 .645 .888 r
.64026 .28444 .64383 .28595 .65148 .28655 .64792 .28491 Mtetra
.146 .654 .902 r
.64792 .28491 .65148 .28655 .65916 .28711 .65561 .28536 Mtetra
.167 .664 .915 r
.65561 .28536 .65916 .28711 .66688 .28764 .66334 .28577 Mtetra
.19 .675 .928 r
.66334 .28577 .66688 .28764 .67463 .28813 .6711 .28612 Mtetra
.214 .685 .94 r
.6711 .28612 .67463 .28813 .68241 .28855 .6789 .28642 Mtetra
.239 .695 .951 r
.6789 .28642 .68241 .28855 .69022 .28891 .68673 .28664 Mtetra
.265 .705 .962 r
.68673 .28664 .69022 .28891 .69807 .28919 .69458 .28678 Mtetra
.292 .715 .971 r
.69458 .28678 .69807 .28919 .70595 .28938 .70247 .28682 Mtetra
.319 .724 .979 r
.70247 .28682 .70595 .28938 .71386 .28947 .71039 .28676 Mtetra
.347 .733 .985 r
.71039 .28676 .71386 .28947 .72179 .28944 .71833 .28658 Mtetra
.375 .741 .99 r
.71833 .28658 .72179 .28944 .72976 .28929 .72631 .28627 Mtetra
.403 .748 .993 r
.72631 .28627 .72976 .28929 .73774 .28899 .7343 .28582 Mtetra
.43 .754 .995 r
.7343 .28582 .73774 .28899 .74576 .28855 .74232 .2852 Mtetra
.757 .85 .92 r
.05019 .51509 .05507 .5175 .06145 .5135 .05656 .51122 Mtetra
.765 .858 .919 r
.05656 .51122 .06145 .5135 .06786 .50934 .06297 .5072 Mtetra
.772 .866 .918 r
.06297 .5072 .06786 .50934 .0743 .50503 .0694 .50303 Mtetra
.779 .873 .917 r
.0694 .50303 .0743 .50503 .08077 .50061 .07586 .49874 Mtetra
.785 .88 .916 r
.07586 .49874 .08077 .50061 .08725 .49606 .08234 .49432 Mtetra
.79 .886 .915 r
.08234 .49432 .08725 .49606 .09375 .49141 .08884 .48979 Mtetra
.794 .893 .914 r
.08884 .48979 .09375 .49141 .10027 .48667 .09537 .48516 Mtetra
.798 .899 .914 r
.09537 .48516 .10027 .48667 .10681 .48184 .1019 .48045 Mtetra
.802 .905 .913 r
.1019 .48045 .10681 .48184 .11336 .47693 .10845 .47566 Mtetra
.804 .911 .913 r
.10845 .47566 .11336 .47693 .11992 .47197 .11502 .4708 Mtetra
.807 .916 .913 r
.11502 .4708 .11992 .47197 .12649 .46695 .1216 .46588 Mtetra
.808 .922 .913 r
.1216 .46588 .12649 .46695 .13308 .46189 .12818 .46092 Mtetra
.81 .927 .912 r
.12818 .46092 .13308 .46189 .13967 .45679 .13478 .45592 Mtetra
.81 .932 .913 r
.13478 .45592 .13967 .45679 .14626 .45166 .14138 .45088 Mtetra
.81 .937 .913 r
.14138 .45088 .14626 .45166 .15287 .44652 .14799 .44583 Mtetra
.81 .942 .913 r
.14799 .44583 .15287 .44652 .15947 .44137 .15461 .44077 Mtetra
.809 .947 .913 r
.15461 .44077 .15947 .44137 .16609 .43622 .16123 .4357 Mtetra
.807 .951 .913 r
.16123 .4357 .16609 .43622 .1727 .43107 .16786 .43063 Mtetra
.805 .955 .914 r
.16786 .43063 .1727 .43107 .17932 .42594 .17448 .42557 Mtetra
.802 .959 .914 r
.17448 .42557 .17932 .42594 .18594 .42083 .18111 .42054 Mtetra
.799 .963 .914 r
.18111 .42054 .18594 .42083 .19256 .41574 .18775 .41552 Mtetra
.795 .966 .914 r
.18775 .41552 .19256 .41574 .19918 .41069 .19438 .41054 Mtetra
.791 .97 .915 r
.19438 .41054 .19918 .41069 .2058 .40569 .20101 .4056 Mtetra
.785 .972 .915 r
.20101 .4056 .2058 .40569 .21242 .40073 .20765 .40069 Mtetra
.779 .975 .915 r
.20765 .40069 .21242 .40073 .21904 .39582 .21428 .39584 Mtetra
.773 .977 .915 r
.21428 .39584 .21904 .39582 .22566 .39097 .22092 .39105 Mtetra
.765 .979 .915 r
.22092 .39105 .22566 .39097 .23228 .38618 .22755 .38631 Mtetra
.757 .98 .914 r
.22755 .38631 .23228 .38618 .2389 .38146 .23419 .38164 Mtetra
.748 .981 .914 r
.23419 .38164 .2389 .38146 .24551 .37682 .24082 .37704 Mtetra
.738 .981 .913 r
.24082 .37704 .24551 .37682 .25213 .37225 .24745 .37252 Mtetra
.728 .981 .912 r
.24745 .37252 .25213 .37225 .25875 .36777 .25409 .36808 Mtetra
.716 .98 .911 r
.25409 .36808 .25875 .36777 .26536 .36337 .26072 .36372 Mtetra
.704 .978 .909 r
.26072 .36372 .26536 .36337 .27198 .35906 .26735 .35944 Mtetra
.69 .976 .907 r
.26735 .35944 .27198 .35906 .2786 .35485 .27399 .35526 Mtetra
.676 .973 .905 r
.27399 .35526 .2786 .35485 .28521 .35073 .28062 .35117 Mtetra
.661 .97 .902 r
.28062 .35117 .28521 .35073 .29183 .34672 .28726 .34718 Mtetra
.646 .966 .899 r
.28726 .34718 .29183 .34672 .29845 .34281 .2939 .3433 Mtetra
.629 .961 .896 r
.2939 .3433 .29845 .34281 .30507 .339 .30054 .33951 Mtetra
.612 .955 .892 r
.30054 .33951 .30507 .339 .31169 .3353 .30718 .33583 Mtetra
.593 .948 .888 r
.30718 .33583 .31169 .3353 .31832 .33172 .31383 .33226 Mtetra
.574 .941 .883 r
.31383 .33226 .31832 .33172 .32495 .32824 .32048 .3288 Mtetra
.555 .933 .878 r
.32048 .3288 .32495 .32824 .33158 .32488 .32713 .32545 Mtetra
.534 .924 .873 r
.32713 .32545 .33158 .32488 .33822 .32164 .33379 .32222 Mtetra
.513 .915 .867 r
.33379 .32222 .33822 .32164 .34487 .31852 .34045 .3191 Mtetra
.492 .904 .861 r
.34045 .3191 .34487 .31852 .35152 .31552 .34713 .3161 Mtetra
.47 .893 .854 r
.34713 .3161 .35152 .31552 .35818 .31263 .3538 .31322 Mtetra
.448 .882 .847 r
.3538 .31322 .35818 .31263 .36484 .30987 .36049 .31046 Mtetra
.426 .87 .84 r
.36049 .31046 .36484 .30987 .37152 .30723 .36719 .30782 Mtetra
.403 .857 .833 r
.36719 .30782 .37152 .30723 .3782 .30472 .37389 .30529 Mtetra
.381 .844 .826 r
.37389 .30529 .3782 .30472 .38489 .30232 .38061 .30289 Mtetra
.358 .831 .818 r
.38061 .30289 .38489 .30232 .3916 .30006 .38733 .30061 Mtetra
.336 .818 .811 r
.38733 .30061 .3916 .30006 .39832 .29791 .39407 .29845 Mtetra
.314 .804 .803 r
.39407 .29845 .39832 .29791 .40505 .29589 .40082 .29642 Mtetra
.292 .79 .796 r
.40082 .29642 .40505 .29589 .41179 .29399 .40759 .2945 Mtetra
.271 .776 .789 r
.40759 .2945 .41179 .29399 .41855 .29221 .41437 .2927 Mtetra
.25 .762 .782 r
.41437 .2927 .41855 .29221 .42533 .29056 .42117 .29102 Mtetra
.23 .749 .775 r
.42117 .29102 .42533 .29056 .43212 .28902 .42798 .28946 Mtetra
.21 .735 .769 r
.42798 .28946 .43212 .28902 .43893 .28761 .43481 .28802 Mtetra
.191 .722 .763 r
.43481 .28802 .43893 .28761 .44576 .28631 .44166 .28669 Mtetra
.173 .709 .758 r
.44166 .28669 .44576 .28631 .45261 .28513 .44853 .28547 Mtetra
.156 .697 .753 r
.44853 .28547 .45261 .28513 .45948 .28406 .45542 .28437 Mtetra
.14 .685 .749 r
.45542 .28437 .45948 .28406 .46637 .2831 .46233 .28338 Mtetra
.125 .674 .745 r
.46233 .28338 .46637 .2831 .47328 .28226 .46926 .28249 Mtetra
.11 .664 .742 r
.46926 .28249 .47328 .28226 .48021 .28152 .47622 .28171 Mtetra
.097 .654 .74 r
.47622 .28171 .48021 .28152 .48717 .28089 .4832 .28103 Mtetra
.085 .645 .739 r
.4832 .28103 .48717 .28089 .49416 .28036 .4902 .28045 Mtetra
.074 .636 .738 r
.4902 .28045 .49416 .28036 .50117 .27993 .49723 .27996 Mtetra
.064 .629 .738 r
.49723 .27996 .50117 .27993 .50821 .27959 .50429 .27957 Mtetra
.056 .622 .739 r
.50429 .27957 .50821 .27959 .51527 .27935 .51138 .27927 Mtetra
.049 .616 .741 r
.51138 .27927 .51527 .27935 .52237 .27919 .51849 .27905 Mtetra
.043 .611 .744 r
.51849 .27905 .52237 .27919 .52949 .27912 .52563 .27892 Mtetra
.038 .607 .748 r
.52563 .27892 .52949 .27912 .53664 .27913 .5328 .27886 Mtetra
.035 .604 .752 r
.5328 .27886 .53664 .27913 .54383 .27921 .54001 .27887 Mtetra
.033 .602 .758 r
.54001 .27887 .54383 .27921 .55104 .27936 .54724 .27895 Mtetra
.032 .601 .764 r
.54724 .27895 .55104 .27936 .55829 .27958 .55451 .27908 Mtetra
.033 .601 .772 r
.55451 .27908 .55829 .27958 .56557 .27985 .56181 .27928 Mtetra
.036 .602 .78 r
.56181 .27928 .56557 .27985 .57289 .28018 .56914 .27953 Mtetra
.04 .604 .789 r
.56914 .27953 .57289 .28018 .58023 .28056 .5765 .27981 Mtetra
.045 .607 .799 r
.5765 .27981 .58023 .28056 .58761 .28097 .5839 .28014 Mtetra
.053 .61 .81 r
.5839 .28014 .58761 .28097 .59503 .28142 .59133 .2805 Mtetra
.062 .615 .821 r
.59133 .2805 .59503 .28142 .60248 .2819 .5988 .28088 Mtetra
.072 .621 .833 r
.5988 .28088 .60248 .2819 .60997 .2824 .6063 .28128 Mtetra
.084 .627 .846 r
.6063 .28128 .60997 .2824 .61749 .28291 .61384 .28168 Mtetra
.098 .634 .859 r
.61384 .28168 .61749 .28291 .62504 .28343 .62141 .28209 Mtetra
.114 .642 .872 r
.62141 .28209 .62504 .28343 .63263 .28394 .62902 .28249 Mtetra
.131 .651 .886 r
.62902 .28249 .63263 .28394 .64026 .28444 .63666 .28287 Mtetra
.15 .66 .899 r
.63666 .28287 .64026 .28444 .64792 .28491 .64433 .28323 Mtetra
.17 .669 .912 r
.64433 .28323 .64792 .28491 .65561 .28536 .65204 .28355 Mtetra
.191 .679 .925 r
.65204 .28355 .65561 .28536 .66334 .28577 .65978 .28383 Mtetra
.215 .689 .938 r
.65978 .28383 .66334 .28577 .6711 .28612 .66756 .28405 Mtetra
.239 .699 .949 r
.66756 .28405 .6711 .28612 .6789 .28642 .67536 .28421 Mtetra
.264 .709 .96 r
.67536 .28421 .6789 .28642 .68673 .28664 .6832 .28429 Mtetra
.29 .718 .969 r
.6832 .28429 .68673 .28664 .69458 .28678 .69107 .28429 Mtetra
.317 .727 .978 r
.69107 .28429 .69458 .28678 .70247 .28682 .69897 .28418 Mtetra
.344 .736 .985 r
.69897 .28418 .70247 .28682 .71039 .28676 .7069 .28397 Mtetra
.371 .743 .99 r
.7069 .28397 .71039 .28676 .71833 .28658 .71485 .28363 Mtetra
.399 .75 .993 r
.71485 .28363 .71833 .28658 .72631 .28627 .72283 .28316 Mtetra
.426 .756 .995 r
.72283 .28316 .72631 .28627 .7343 .28582 .73083 .28254 Mtetra
.453 .761 .995 r
.73083 .28254 .7343 .28582 .74232 .2852 .73885 .28176 Mtetra
.749 .846 .923 r
.04529 .51258 .05019 .51509 .05656 .51122 .05166 .50885 Mtetra
.757 .854 .922 r
.05166 .50885 .05656 .51122 .06297 .5072 .05806 .50497 Mtetra
.765 .862 .921 r
.05806 .50497 .06297 .5072 .0694 .50303 .06449 .50094 Mtetra
.772 .869 .92 r
.06449 .50094 .0694 .50303 .07586 .49874 .07094 .49678 Mtetra
.778 .877 .919 r
.07094 .49678 .07586 .49874 .08234 .49432 .07742 .49249 Mtetra
.783 .884 .918 r
.07742 .49249 .08234 .49432 .08884 .48979 .08392 .48809 Mtetra
.788 .89 .918 r
.08392 .48809 .08884 .48979 .09537 .48516 .09044 .48358 Mtetra
.792 .897 .917 r
.09044 .48358 .09537 .48516 .1019 .48045 .09697 .47899 Mtetra
.796 .903 .917 r
.09697 .47899 .1019 .48045 .10845 .47566 .10353 .47431 Mtetra
.799 .909 .916 r
.10353 .47431 .10845 .47566 .11502 .4708 .11009 .46957 Mtetra
.801 .915 .916 r
.11009 .46957 .11502 .4708 .1216 .46588 .11667 .46476 Mtetra
.803 .921 .916 r
.11667 .46476 .1216 .46588 .12818 .46092 .12327 .4599 Mtetra
.804 .926 .916 r
.12327 .4599 .12818 .46092 .13478 .45592 .12987 .455 Mtetra
.805 .931 .916 r
.12987 .455 .13478 .45592 .14138 .45088 .13648 .45006 Mtetra
.805 .936 .916 r
.13648 .45006 .14138 .45088 .14799 .44583 .14309 .4451 Mtetra
.805 .941 .916 r
.14309 .4451 .14799 .44583 .15461 .44077 .14972 .44013 Mtetra
.804 .946 .916 r
.14972 .44013 .15461 .44077 .16123 .4357 .15635 .43514 Mtetra
.803 .95 .916 r
.15635 .43514 .16123 .4357 .16786 .43063 .16298 .43016 Mtetra
.801 .955 .917 r
.16298 .43016 .16786 .43063 .17448 .42557 .16962 .42518 Mtetra
.798 .959 .917 r
.16962 .42518 .17448 .42557 .18111 .42054 .17626 .42022 Mtetra
.795 .962 .917 r
.17626 .42022 .18111 .42054 .18775 .41552 .18291 .41528 Mtetra
.791 .966 .917 r
.18291 .41528 .18775 .41552 .19438 .41054 .18955 .41036 Mtetra
.786 .969 .917 r
.18955 .41036 .19438 .41054 .20101 .4056 .1962 .40548 Mtetra
.781 .972 .917 r
.1962 .40548 .20101 .4056 .20765 .40069 .20285 .40065 Mtetra
.775 .974 .917 r
.20285 .40065 .20765 .40069 .21428 .39584 .20949 .39585 Mtetra
.768 .976 .917 r
.20949 .39585 .21428 .39584 .22092 .39105 .21614 .39112 Mtetra
.76 .978 .916 r
.21614 .39112 .22092 .39105 .22755 .38631 .22279 .38643 Mtetra
.752 .979 .916 r
.22279 .38643 .22755 .38631 .23419 .38164 .22944 .38182 Mtetra
.743 .98 .915 r
.22944 .38182 .23419 .38164 .24082 .37704 .23609 .37726 Mtetra
.733 .98 .914 r
.23609 .37726 .24082 .37704 .24745 .37252 .24274 .37278 Mtetra
.723 .98 .913 r
.24274 .37278 .24745 .37252 .25409 .36808 .24939 .36838 Mtetra
.711 .979 .911 r
.24939 .36838 .25409 .36808 .26072 .36372 .25604 .36406 Mtetra
.699 .977 .91 r
.25604 .36406 .26072 .36372 .26735 .35944 .26269 .35982 Mtetra
.685 .975 .907 r
.26269 .35982 .26735 .35944 .27399 .35526 .26935 .35567 Mtetra
.671 .972 .905 r
.26935 .35567 .27399 .35526 .28062 .35117 .276 .35162 Mtetra
.656 .969 .902 r
.276 .35162 .28062 .35117 .28726 .34718 .28266 .34766 Mtetra
.641 .964 .899 r
.28266 .34766 .28726 .34718 .2939 .3433 .28931 .34379 Mtetra
.624 .959 .895 r
.28931 .34379 .2939 .3433 .30054 .33951 .29597 .34003 Mtetra
.607 .953 .891 r
.29597 .34003 .30054 .33951 .30718 .33583 .30263 .33637 Mtetra
.589 .947 .887 r
.30263 .33637 .30718 .33583 .31383 .33226 .3093 .33282 Mtetra
.57 .939 .882 r
.3093 .33282 .31383 .33226 .32048 .3288 .31597 .32937 Mtetra
.55 .931 .877 r
.31597 .32937 .32048 .3288 .32713 .32545 .32264 .32603 Mtetra
.53 .922 .871 r
.32264 .32603 .32713 .32545 .33379 .32222 .32932 .32281 Mtetra
.51 .913 .865 r
.32932 .32281 .33379 .32222 .34045 .3191 .33601 .3197 Mtetra
.489 .903 .859 r
.33601 .3197 .34045 .3191 .34713 .3161 .3427 .3167 Mtetra
.467 .892 .852 r
.3427 .3167 .34713 .3161 .3538 .31322 .3494 .31382 Mtetra
.446 .881 .846 r
.3494 .31382 .3538 .31322 .36049 .31046 .3561 .31106 Mtetra
.424 .869 .839 r
.3561 .31106 .36049 .31046 .36719 .30782 .36282 .30841 Mtetra
.402 .856 .831 r
.36282 .30841 .36719 .30782 .37389 .30529 .36955 .30589 Mtetra
.379 .844 .824 r
.36955 .30589 .37389 .30529 .38061 .30289 .37628 .30348 Mtetra
.358 .831 .817 r
.37628 .30348 .38061 .30289 .38733 .30061 .38303 .30118 Mtetra
.336 .817 .81 r
.38303 .30118 .38733 .30061 .39407 .29845 .38979 .29901 Mtetra
.314 .804 .802 r
.38979 .29901 .39407 .29845 .40082 .29642 .39656 .29696 Mtetra
.293 .79 .795 r
.39656 .29696 .40082 .29642 .40759 .2945 .40335 .29502 Mtetra
.272 .777 .788 r
.40335 .29502 .40759 .2945 .41437 .2927 .41015 .2932 Mtetra
.252 .764 .782 r
.41015 .2932 .41437 .2927 .42117 .29102 .41697 .2915 Mtetra
.232 .75 .775 r
.41697 .2915 .42117 .29102 .42798 .28946 .4238 .28991 Mtetra
.214 .738 .77 r
.4238 .28991 .42798 .28946 .43481 .28802 .43065 .28844 Mtetra
.195 .725 .764 r
.43065 .28844 .43481 .28802 .44166 .28669 .43752 .28708 Mtetra
.178 .713 .759 r
.43752 .28708 .44166 .28669 .44853 .28547 .44441 .28583 Mtetra
.162 .701 .755 r
.44441 .28583 .44853 .28547 .45542 .28437 .45132 .28469 Mtetra
.146 .69 .751 r
.45132 .28469 .45542 .28437 .46233 .28338 .45826 .28365 Mtetra
.131 .679 .748 r
.45826 .28365 .46233 .28338 .46926 .28249 .46521 .28272 Mtetra
.118 .669 .746 r
.46521 .28272 .46926 .28249 .47622 .28171 .47219 .2819 Mtetra
.105 .66 .744 r
.47219 .2819 .47622 .28171 .4832 .28103 .47919 .28117 Mtetra
.094 .651 .743 r
.47919 .28117 .4832 .28103 .4902 .28045 .48621 .28054 Mtetra
.084 .644 .743 r
.48621 .28054 .4902 .28045 .49723 .27996 .49326 .28 Mtetra
.075 .637 .744 r
.49326 .28 .49723 .27996 .50429 .27957 .50034 .27955 Mtetra
.067 .631 .745 r
.50034 .27955 .50429 .27957 .51138 .27927 .50745 .27919 Mtetra
.06 .625 .748 r
.50745 .27919 .51138 .27927 .51849 .27905 .51458 .27891 Mtetra
.055 .621 .751 r
.51458 .27891 .51849 .27905 .52563 .27892 .52174 .2787 Mtetra
.051 .618 .755 r
.52174 .2787 .52563 .27892 .5328 .27886 .52894 .27857 Mtetra
.048 .615 .76 r
.52894 .27857 .5328 .27886 .54001 .27887 .53616 .27851 Mtetra
.047 .614 .767 r
.53616 .27851 .54001 .27887 .54724 .27895 .54341 .27851 Mtetra
.048 .613 .774 r
.54341 .27851 .54724 .27895 .55451 .27908 .5507 .27857 Mtetra
.049 .613 .781 r
.5507 .27857 .55451 .27908 .56181 .27928 .55801 .27869 Mtetra
.053 .615 .79 r
.55801 .27869 .56181 .27928 .56914 .27953 .56536 .27884 Mtetra
.057 .617 .8 r
.56536 .27884 .56914 .27953 .5765 .27981 .57275 .27904 Mtetra
.064 .621 .81 r
.57275 .27904 .5765 .27981 .5839 .28014 .58016 .27928 Mtetra
.072 .625 .821 r
.58016 .27928 .5839 .28014 .59133 .2805 .58761 .27954 Mtetra
.082 .63 .833 r
.58761 .27954 .59133 .2805 .5988 .28088 .5951 .27982 Mtetra
.093 .636 .845 r
.5951 .27982 .5988 .28088 .6063 .28128 .60261 .28011 Mtetra
.106 .642 .858 r
.60261 .28011 .6063 .28128 .61384 .28168 .61017 .28041 Mtetra
.121 .65 .871 r
.61017 .28041 .61384 .28168 .62141 .28209 .61775 .28071 Mtetra
.137 .658 .884 r
.61775 .28071 .62141 .28209 .62902 .28249 .62537 .28099 Mtetra
.155 .666 .898 r
.62537 .28099 .62902 .28249 .63666 .28287 .63303 .28125 Mtetra
.174 .675 .911 r
.63303 .28125 .63666 .28287 .64433 .28323 .64072 .28148 Mtetra
.195 .685 .924 r
.64072 .28148 .64433 .28323 .65204 .28355 .64844 .28168 Mtetra
.217 .694 .936 r
.64844 .28168 .65204 .28355 .65978 .28383 .65619 .28183 Mtetra
.24 .704 .948 r
.65619 .28183 .65978 .28383 .66756 .28405 .66398 .28191 Mtetra
.265 .713 .958 r
.66398 .28191 .66756 .28405 .67536 .28421 .6718 .28193 Mtetra
.29 .722 .968 r
.6718 .28193 .67536 .28421 .6832 .28429 .67965 .28187 Mtetra
.316 .731 .977 r
.67965 .28187 .6832 .28429 .69107 .28429 .68753 .28171 Mtetra
.342 .739 .984 r
.68753 .28171 .69107 .28429 .69897 .28418 .69544 .28145 Mtetra
.369 .746 .989 r
.69544 .28145 .69897 .28418 .7069 .28397 .70337 .28108 Mtetra
.396 .753 .993 r
.70337 .28108 .7069 .28397 .71485 .28363 .71134 .28058 Mtetra
.423 .759 .995 r
.71134 .28058 .71485 .28363 .72283 .28316 .71932 .27994 Mtetra
.449 .764 .996 r
.71932 .27994 .72283 .28316 .73083 .28254 .72733 .27915 Mtetra
.475 .768 .995 r
.72733 .27915 .73083 .28254 .73885 .28176 .73536 .27819 Mtetra
.74 .84 .926 r
.04039 .50994 .04529 .51258 .05166 .50885 .04674 .50637 Mtetra
.749 .849 .925 r
.04674 .50637 .05166 .50885 .05806 .50497 .05313 .50264 Mtetra
.757 .857 .924 r
.05313 .50264 .05806 .50497 .06449 .50094 .05956 .49875 Mtetra
.764 .865 .923 r
.05956 .49875 .06449 .50094 .07094 .49678 .066 .49473 Mtetra
.771 .873 .922 r
.066 .49473 .07094 .49678 .07742 .49249 .07248 .49057 Mtetra
.776 .88 .922 r
.07248 .49057 .07742 .49249 .08392 .48809 .07897 .4863 Mtetra
.781 .887 .921 r
.07897 .4863 .08392 .48809 .09044 .48358 .08549 .48192 Mtetra
.786 .894 .921 r
.08549 .48192 .09044 .48358 .09697 .47899 .09202 .47745 Mtetra
.79 .9 .92 r
.09202 .47745 .09697 .47899 .10353 .47431 .09858 .47289 Mtetra
.793 .907 .92 r
.09858 .47289 .10353 .47431 .11009 .46957 .10515 .46826 Mtetra
.796 .913 .92 r
.10515 .46826 .11009 .46957 .11667 .46476 .11173 .46357 Mtetra
.798 .919 .92 r
.11173 .46357 .11667 .46476 .12327 .4599 .11832 .45881 Mtetra
.799 .924 .919 r
.11832 .45881 .12327 .4599 .12987 .455 .12493 .45402 Mtetra
.8 .93 .919 r
.12493 .45402 .12987 .455 .13648 .45006 .13154 .44918 Mtetra
.8 .935 .919 r
.13154 .44918 .13648 .45006 .14309 .4451 .13817 .44432 Mtetra
.8 .94 .919 r
.13817 .44432 .14309 .4451 .14972 .44013 .1448 .43943 Mtetra
.799 .945 .92 r
.1448 .43943 .14972 .44013 .15635 .43514 .15144 .43454 Mtetra
.798 .949 .92 r
.15144 .43454 .15635 .43514 .16298 .43016 .15808 .42964 Mtetra
.796 .954 .92 r
.15808 .42964 .16298 .43016 .16962 .42518 .16473 .42475 Mtetra
.793 .958 .92 r
.16473 .42475 .16962 .42518 .17626 .42022 .17138 .41986 Mtetra
.79 .962 .92 r
.17138 .41986 .17626 .42022 .18291 .41528 .17803 .415 Mtetra
.786 .965 .92 r
.17803 .415 .18291 .41528 .18955 .41036 .18469 .41016 Mtetra
.781 .968 .92 r
.18469 .41016 .18955 .41036 .1962 .40548 .19135 .40535 Mtetra
.776 .971 .92 r
.19135 .40535 .1962 .40548 .20285 .40065 .19801 .40057 Mtetra
.77 .974 .92 r
.19801 .40057 .20285 .40065 .20949 .39585 .20467 .39584 Mtetra
.763 .976 .919 r
.20467 .39584 .20949 .39585 .21614 .39112 .21134 .39116 Mtetra
.756 .977 .919 r
.21134 .39116 .21614 .39112 .22279 .38643 .218 .38654 Mtetra
.748 .978 .918 r
.218 .38654 .22279 .38643 .22944 .38182 .22467 .38197 Mtetra
.739 .979 .917 r
.22467 .38197 .22944 .38182 .23609 .37726 .23133 .37747 Mtetra
.729 .979 .916 r
.23133 .37747 .23609 .37726 .24274 .37278 .238 .37304 Mtetra
.718 .979 .914 r
.238 .37304 .24274 .37278 .24939 .36838 .24466 .36868 Mtetra
.707 .978 .913 r
.24466 .36868 .24939 .36838 .25604 .36406 .25133 .3644 Mtetra
.694 .976 .911 r
.25133 .3644 .25604 .36406 .26269 .35982 .258 .3602 Mtetra
.681 .974 .908 r
.258 .3602 .26269 .35982 .26935 .35567 .26467 .35608 Mtetra
.667 .971 .906 r
.26467 .35608 .26935 .35567 .276 .35162 .27134 .35206 Mtetra
.652 .967 .903 r
.27134 .35206 .276 .35162 .28266 .34766 .27802 .34812 Mtetra
.636 .963 .899 r
.27802 .34812 .28266 .34766 .28931 .34379 .28469 .34429 Mtetra
.62 .958 .895 r
.28469 .34429 .28931 .34379 .29597 .34003 .29137 .34055 Mtetra
.603 .952 .891 r
.29137 .34055 .29597 .34003 .30263 .33637 .29805 .33691 Mtetra
.585 .945 .887 r
.29805 .33691 .30263 .33637 .3093 .33282 .30474 .33337 Mtetra
.566 .938 .882 r
.30474 .33337 .3093 .33282 .31597 .32937 .31143 .32994 Mtetra
.547 .93 .876 r
.31143 .32994 .31597 .32937 .32264 .32603 .31812 .32662 Mtetra
.527 .921 .871 r
.31812 .32662 .32264 .32603 .32932 .32281 .32482 .3234 Mtetra
.507 .912 .865 r
.32482 .3234 .32932 .32281 .33601 .3197 .33152 .3203 Mtetra
.486 .902 .858 r
.33152 .3203 .33601 .3197 .3427 .3167 .33824 .31731 Mtetra
.465 .891 .852 r
.33824 .31731 .3427 .3167 .3494 .31382 .34496 .31443 Mtetra
.444 .88 .845 r
.34496 .31443 .3494 .31382 .3561 .31106 .35168 .31167 Mtetra
.422 .868 .838 r
.35168 .31167 .3561 .31106 .36282 .30841 .35842 .30902 Mtetra
.401 .856 .831 r
.35842 .30902 .36282 .30841 .36955 .30589 .36517 .30648 Mtetra
.379 .844 .824 r
.36517 .30648 .36955 .30589 .37628 .30348 .37193 .30406 Mtetra
.358 .831 .817 r
.37193 .30406 .37628 .30348 .38303 .30118 .37869 .30176 Mtetra
.337 .818 .81 r
.37869 .30176 .38303 .30118 .38979 .29901 .38547 .29957 Mtetra
.316 .805 .803 r
.38547 .29957 .38979 .29901 .39656 .29696 .39227 .2975 Mtetra
.295 .792 .796 r
.39227 .2975 .39656 .29696 .40335 .29502 .39908 .29555 Mtetra
.275 .779 .79 r
.39908 .29555 .40335 .29502 .41015 .2932 .4059 .29371 Mtetra
.256 .766 .783 r
.4059 .29371 .41015 .2932 .41697 .2915 .41274 .29198 Mtetra
.237 .753 .777 r
.41274 .29198 .41697 .2915 .4238 .28991 .41959 .29036 Mtetra
.218 .741 .772 r
.41959 .29036 .4238 .28991 .43065 .28844 .42647 .28886 Mtetra
.201 .729 .767 r
.42647 .28886 .43065 .28844 .43752 .28708 .43336 .28747 Mtetra
.184 .717 .762 r
.43336 .28747 .43752 .28708 .44441 .28583 .44027 .28618 Mtetra
.168 .706 .758 r
.44027 .28618 .44441 .28583 .45132 .28469 .4472 .285 Mtetra
.154 .695 .755 r
.4472 .285 .45132 .28469 .45826 .28365 .45415 .28393 Mtetra
.14 .685 .752 r
.45415 .28393 .45826 .28365 .46521 .28272 .46113 .28295 Mtetra
.127 .676 .751 r
.46113 .28295 .46521 .28272 .47219 .2819 .46813 .28208 Mtetra
.115 .667 .749 r
.46813 .28208 .47219 .2819 .47919 .28117 .47515 .2813 Mtetra
.104 .659 .749 r
.47515 .2813 .47919 .28117 .48621 .28054 .48219 .28061 Mtetra
.095 .652 .749 r
.48219 .28061 .48621 .28054 .49326 .28 .48927 .28002 Mtetra
.086 .646 .751 r
.48927 .28002 .49326 .28 .50034 .27955 .49636 .27951 Mtetra
.079 .64 .753 r
.49636 .27951 .50034 .27955 .50745 .27919 .50349 .27909 Mtetra
.073 .636 .756 r
.50349 .27909 .50745 .27919 .51458 .27891 .51064 .27874 Mtetra
.069 .632 .76 r
.51064 .27874 .51458 .27891 .52174 .2787 .51783 .27847 Mtetra
.066 .629 .765 r
.51783 .27847 .52174 .2787 .52894 .27857 .52504 .27827 Mtetra
.064 .627 .77 r
.52504 .27827 .52894 .27857 .53616 .27851 .53228 .27813 Mtetra
.064 .626 .777 r
.53228 .27813 .53616 .27851 .54341 .27851 .53955 .27805 Mtetra
.065 .626 .784 r
.53955 .27805 .54341 .27851 .5507 .27857 .54686 .27803 Mtetra
.067 .627 .793 r
.54686 .27803 .5507 .27857 .55801 .27869 .55419 .27806 Mtetra
.071 .629 .802 r
.55419 .27806 .55801 .27869 .56536 .27884 .56156 .27813 Mtetra
.077 .632 .812 r
.56156 .27813 .56536 .27884 .57275 .27904 .56896 .27823 Mtetra
.084 .635 .822 r
.56896 .27823 .57275 .27904 .58016 .27928 .57639 .27837 Mtetra
.093 .64 .834 r
.57639 .27837 .58016 .27928 .58761 .27954 .58386 .27853 Mtetra
.104 .645 .846 r
.58386 .27853 .58761 .27954 .5951 .27982 .59136 .27871 Mtetra
.116 .651 .858 r
.59136 .27871 .5951 .27982 .60261 .28011 .5989 .27889 Mtetra
.129 .658 .871 r
.5989 .27889 .60261 .28011 .61017 .28041 .60646 .27908 Mtetra
.145 .666 .884 r
.60646 .27908 .61017 .28041 .61775 .28071 .61407 .27926 Mtetra
.162 .674 .897 r
.61407 .27926 .61775 .28071 .62537 .28099 .6217 .27942 Mtetra
.18 .682 .91 r
.6217 .27942 .62537 .28099 .63303 .28125 .62937 .27956 Mtetra
.2 .691 .923 r
.62937 .27956 .63303 .28125 .64072 .28148 .63707 .27967 Mtetra
.221 .7 .935 r
.63707 .27967 .64072 .28148 .64844 .28168 .64481 .27973 Mtetra
.244 .709 .947 r
.64481 .27973 .64844 .28168 .65619 .28183 .65258 .27974 Mtetra
.267 .718 .957 r
.65258 .27974 .65619 .28183 .66398 .28191 .66038 .27969 Mtetra
.292 .727 .967 r
.66038 .27969 .66398 .28191 .6718 .28193 .66821 .27956 Mtetra
.317 .735 .976 r
.66821 .27956 .6718 .28193 .67965 .28187 .67607 .27935 Mtetra
.343 .743 .983 r
.67607 .27935 .67965 .28187 .68753 .28171 .68396 .27904 Mtetra
.369 .75 .989 r
.68396 .27904 .68753 .28171 .69544 .28145 .69188 .27862 Mtetra
.395 .756 .993 r
.69188 .27862 .69544 .28145 .70337 .28108 .69982 .27809 Mtetra
.421 .762 .996 r
.69982 .27809 .70337 .28108 .71134 .28058 .7078 .27742 Mtetra
.447 .766 .997 r
.7078 .27742 .71134 .28058 .71932 .27994 .71579 .27661 Mtetra
.472 .77 .996 r
.71579 .27661 .71932 .27994 .72733 .27915 .72381 .27564 Mtetra
.497 .773 .993 r
.72381 .27564 .72733 .27915 .73536 .27819 .73184 .2745 Mtetra
.731 .834 .928 r
.03547 .50719 .04039 .50994 .04674 .50637 .04182 .50377 Mtetra
.74 .843 .928 r
.04182 .50377 .04674 .50637 .05313 .50264 .0482 .50019 Mtetra
.748 .852 .927 r
.0482 .50019 .05313 .50264 .05956 .49875 .05461 .49645 Mtetra
.756 .86 .926 r
.05461 .49645 .05956 .49875 .066 .49473 .06105 .49257 Mtetra
.763 .868 .926 r
.06105 .49257 .066 .49473 .07248 .49057 .06752 .48855 Mtetra
.769 .876 .925 r
.06752 .48855 .07248 .49057 .07897 .4863 .07401 .48442 Mtetra
.774 .883 .924 r
.07401 .48442 .07897 .4863 .08549 .48192 .08052 .48017 Mtetra
.779 .89 .924 r
.08052 .48017 .08549 .48192 .09202 .47745 .08706 .47582 Mtetra
.783 .897 .924 r
.08706 .47582 .09202 .47745 .09858 .47289 .09361 .47139 Mtetra
.787 .904 .923 r
.09361 .47139 .09858 .47289 .10515 .46826 .10018 .46688 Mtetra
.789 .91 .923 r
.10018 .46688 .10515 .46826 .11173 .46357 .10676 .4623 Mtetra
.792 .916 .923 r
.10676 .4623 .11173 .46357 .11832 .45881 .11336 .45766 Mtetra
.793 .922 .923 r
.11336 .45766 .11832 .45881 .12493 .45402 .11997 .45297 Mtetra
.794 .928 .923 r
.11997 .45297 .12493 .45402 .13154 .44918 .12659 .44823 Mtetra
.795 .933 .923 r
.12659 .44823 .13154 .44918 .13817 .44432 .13322 .44347 Mtetra
.795 .938 .923 r
.13322 .44347 .13817 .44432 .1448 .43943 .13985 .43868 Mtetra
.794 .943 .923 r
.13985 .43868 .1448 .43943 .15144 .43454 .1465 .43388 Mtetra
.793 .948 .923 r
.1465 .43388 .15144 .43454 .15808 .42964 .15315 .42907 Mtetra
.791 .952 .923 r
.15315 .42907 .15808 .42964 .16473 .42475 .15981 .42426 Mtetra
.788 .956 .923 r
.15981 .42426 .16473 .42475 .17138 .41986 .16647 .41946 Mtetra
.785 .96 .923 r
.16647 .41946 .17138 .41986 .17803 .415 .17313 .41467 Mtetra
.781 .964 .923 r
.17313 .41467 .17803 .415 .18469 .41016 .1798 .40991 Mtetra
.777 .967 .923 r
.1798 .40991 .18469 .41016 .19135 .40535 .18647 .40517 Mtetra
.771 .97 .923 r
.18647 .40517 .19135 .40535 .19801 .40057 .19315 .40046 Mtetra
.766 .972 .922 r
.19315 .40046 .19801 .40057 .20467 .39584 .19982 .3958 Mtetra
.759 .974 .922 r
.19982 .3958 .20467 .39584 .21134 .39116 .2065 .39118 Mtetra
.751 .976 .921 r
.2065 .39118 .21134 .39116 .218 .38654 .21318 .38661 Mtetra
.743 .977 .92 r
.21318 .38661 .218 .38654 .22467 .38197 .21986 .3821 Mtetra
.734 .978 .919 r
.21986 .3821 .22467 .38197 .23133 .37747 .22654 .37765 Mtetra
.724 .978 .918 r
.22654 .37765 .23133 .37747 .238 .37304 .23322 .37327 Mtetra
.714 .978 .916 r
.23322 .37327 .238 .37304 .24466 .36868 .2399 .36895 Mtetra
.702 .977 .914 r
.2399 .36895 .24466 .36868 .25133 .3644 .24659 .36471 Mtetra
.69 .975 .912 r
.24659 .36471 .25133 .3644 .258 .3602 .25327 .36055 Mtetra
.677 .973 .91 r
.25327 .36055 .258 .3602 .26467 .35608 .25996 .35647 Mtetra
.663 .97 .907 r
.25996 .35647 .26467 .35608 .27134 .35206 .26665 .35248 Mtetra
.648 .966 .904 r
.26665 .35248 .27134 .35206 .27802 .34812 .27334 .34858 Mtetra
.633 .961 .9 r
.27334 .34858 .27802 .34812 .28469 .34429 .28004 .34477 Mtetra
.617 .956 .896 r
.28004 .34477 .28469 .34429 .29137 .34055 .28673 .34105 Mtetra
.6 .951 .892 r
.28673 .34105 .29137 .34055 .29805 .33691 .29343 .33744 Mtetra
.582 .944 .887 r
.29343 .33744 .29805 .33691 .30474 .33337 .30014 .33392 Mtetra
.564 .937 .882 r
.30014 .33392 .30474 .33337 .31143 .32994 .30685 .33051 Mtetra
.545 .929 .877 r
.30685 .33051 .31143 .32994 .31812 .32662 .31356 .3272 Mtetra
.525 .92 .871 r
.31356 .3272 .31812 .32662 .32482 .3234 .32028 .32399 Mtetra
.505 .911 .865 r
.32028 .32399 .32482 .3234 .33152 .3203 .32701 .3209 Mtetra
.485 .901 .859 r
.32701 .3209 .33152 .3203 .33824 .31731 .33374 .31791 Mtetra
.464 .89 .853 r
.33374 .31791 .33824 .31731 .34496 .31443 .34048 .31503 Mtetra
.444 .88 .846 r
.34048 .31503 .34496 .31443 .35168 .31167 .34723 .31227 Mtetra
.423 .868 .839 r
.34723 .31227 .35168 .31167 .35842 .30902 .35399 .30962 Mtetra
.402 .856 .832 r
.35399 .30962 .35842 .30902 .36517 .30648 .36076 .30708 Mtetra
.381 .844 .825 r
.36076 .30708 .36517 .30648 .37193 .30406 .36753 .30465 Mtetra
.36 .832 .818 r
.36753 .30465 .37193 .30406 .37869 .30176 .37432 .30233 Mtetra
.339 .819 .812 r
.37432 .30233 .37869 .30176 .38547 .29957 .38113 .30013 Mtetra
.319 .807 .805 r
.38113 .30013 .38547 .29957 .39227 .2975 .38794 .29804 Mtetra
.299 .794 .798 r
.38794 .29804 .39227 .2975 .39908 .29555 .39477 .29607 Mtetra
.28 .782 .792 r
.39477 .29607 .39908 .29555 .4059 .29371 .40162 .2942 Mtetra
.261 .769 .786 r
.40162 .2942 .4059 .29371 .41274 .29198 .40848 .29245 Mtetra
.242 .757 .781 r
.40848 .29245 .41274 .29198 .41959 .29036 .41535 .29081 Mtetra
.225 .745 .776 r
.41535 .29081 .41959 .29036 .42647 .28886 .42225 .28927 Mtetra
.208 .734 .771 r
.42225 .28927 .42647 .28886 .43336 .28747 .42916 .28785 Mtetra
.192 .723 .767 r
.42916 .28785 .43336 .28747 .44027 .28618 .43609 .28652 Mtetra
.177 .712 .764 r
.43609 .28652 .44027 .28618 .4472 .285 .44305 .2853 Mtetra
.163 .702 .761 r
.44305 .2853 .4472 .285 .45415 .28393 .45002 .28419 Mtetra
.149 .693 .759 r
.45002 .28419 .45415 .28393 .46113 .28295 .45702 .28317 Mtetra
.137 .684 .757 r
.45702 .28317 .46113 .28295 .46813 .28208 .46403 .28224 Mtetra
.126 .676 .757 r
.46403 .28224 .46813 .28208 .47515 .2813 .47108 .28141 Mtetra
.116 .668 .757 r
.47108 .28141 .47515 .2813 .48219 .28061 .47814 .28067 Mtetra
.107 .662 .758 r
.47814 .28067 .48219 .28061 .48927 .28002 .48524 .28002 Mtetra
.1 .656 .759 r
.48524 .28002 .48927 .28002 .49636 .27951 .49236 .27945 Mtetra
.093 .651 .762 r
.49236 .27945 .49636 .27951 .50349 .27909 .4995 .27896 Mtetra
.088 .647 .766 r
.4995 .27896 .50349 .27909 .51064 .27874 .50668 .27855 Mtetra
.085 .644 .77 r
.50668 .27855 .51064 .27874 .51783 .27847 .51388 .27821 Mtetra
.082 .641 .775 r
.51388 .27821 .51783 .27847 .52504 .27827 .52111 .27793 Mtetra
.081 .64 .782 r
.52111 .27793 .52504 .27827 .53228 .27813 .52837 .27771 Mtetra
.082 .64 .789 r
.52837 .27771 .53228 .27813 .53955 .27805 .53566 .27756 Mtetra
.083 .64 .796 r
.53566 .27756 .53955 .27805 .54686 .27803 .54298 .27745 Mtetra
.087 .641 .805 r
.54298 .27745 .54686 .27803 .55419 .27806 .55034 .27739 Mtetra
.092 .644 .815 r
.55034 .27739 .55419 .27806 .56156 .27813 .55773 .27736 Mtetra
.098 .647 .825 r
.55773 .27736 .56156 .27813 .56896 .27823 .56514 .27738 Mtetra
.106 .651 .836 r
.56514 .27738 .56896 .27823 .57639 .27837 .5726 .27741 Mtetra
.116 .656 .847 r
.5726 .27741 .57639 .27837 .58386 .27853 .58008 .27747 Mtetra
.127 .661 .859 r
.58008 .27747 .58386 .27853 .59136 .27871 .5876 .27754 Mtetra
.14 .668 .872 r
.5876 .27754 .59136 .27871 .5989 .27889 .59515 .27761 Mtetra
.154 .675 .885 r
.59515 .27761 .5989 .27889 .60646 .27908 .60273 .27769 Mtetra
.17 .682 .897 r
.60273 .27769 .60646 .27908 .61407 .27926 .61035 .27774 Mtetra
.188 .69 .91 r
.61035 .27774 .61407 .27926 .6217 .27942 .618 .27779 Mtetra
.207 .698 .923 r
.618 .27779 .6217 .27942 .62937 .27956 .62569 .2778 Mtetra
.227 .707 .935 r
.62569 .2778 .62937 .27956 .63707 .27967 .6334 .27777 Mtetra
.249 .715 .946 r
.6334 .27777 .63707 .27967 .64481 .27973 .64115 .2777 Mtetra
.271 .724 .957 r
.64115 .2777 .64481 .27973 .65258 .27974 .64894 .27756 Mtetra
.295 .732 .967 r
.64894 .27756 .65258 .27974 .66038 .27969 .65675 .27737 Mtetra
.319 .74 .975 r
.65675 .27737 .66038 .27969 .66821 .27956 .66459 .27709 Mtetra
.344 .747 .983 r
.66459 .27709 .66821 .27956 .67607 .27935 .67246 .27672 Mtetra
.37 .754 .989 r
.67246 .27672 .67607 .27935 .68396 .27904 .68036 .27625 Mtetra
.395 .76 .993 r
.68036 .27625 .68396 .27904 .69188 .27862 .68829 .27567 Mtetra
.42 .765 .996 r
.68829 .27567 .69188 .27862 .69982 .27809 .69625 .27497 Mtetra
.446 .769 .997 r
.69625 .27497 .69982 .27809 .7078 .27742 .70423 .27413 Mtetra
.471 .773 .997 r
.70423 .27413 .7078 .27742 .71579 .27661 .71223 .27314 Mtetra
.495 .776 .994 r
.71223 .27314 .71579 .27661 .72381 .27564 .72025 .27199 Mtetra
.518 .777 .991 r
.72025 .27199 .72381 .27564 .73184 .2745 .72829 .27066 Mtetra
.721 .827 .931 r
.03055 .5043 .03547 .50719 .04182 .50377 .03688 .50104 Mtetra
.731 .836 .93 r
.03688 .50104 .04182 .50377 .0482 .50019 .04325 .49761 Mtetra
.739 .846 .929 r
.04325 .49761 .0482 .50019 .05461 .49645 .04965 .49403 Mtetra
.747 .855 .929 r
.04965 .49403 .05461 .49645 .06105 .49257 .05609 .49029 Mtetra
.755 .863 .928 r
.05609 .49029 .06105 .49257 .06752 .48855 .06255 .48642 Mtetra
.761 .871 .928 r
.06255 .48642 .06752 .48855 .07401 .48442 .06903 .48242 Mtetra
.767 .879 .928 r
.06903 .48242 .07401 .48442 .08052 .48017 .07554 .47831 Mtetra
.772 .886 .927 r
.07554 .47831 .08052 .48017 .08706 .47582 .08207 .4741 Mtetra
.776 .893 .927 r
.08207 .4741 .08706 .47582 .09361 .47139 .08862 .46979 Mtetra
.78 .9 .927 r
.08862 .46979 .09361 .47139 .10018 .46688 .09519 .4654 Mtetra
.783 .907 .927 r
.09519 .4654 .10018 .46688 .10676 .4623 .10177 .46094 Mtetra
.786 .913 .926 r
.10177 .46094 .10676 .4623 .11336 .45766 .10837 .45641 Mtetra
.787 .919 .926 r
.10837 .45641 .11336 .45766 .11997 .45297 .11498 .45183 Mtetra
.789 .925 .926 r
.11498 .45183 .11997 .45297 .12659 .44823 .12161 .44721 Mtetra
.789 .93 .926 r
.12161 .44721 .12659 .44823 .13322 .44347 .12824 .44255 Mtetra
.789 .936 .926 r
.12824 .44255 .13322 .44347 .13985 .43868 .13488 .43786 Mtetra
.789 .941 .926 r
.13488 .43786 .13985 .43868 .1465 .43388 .14154 .43316 Mtetra
.788 .946 .926 r
.14154 .43316 .1465 .43388 .15315 .42907 .14819 .42844 Mtetra
.786 .95 .926 r
.14819 .42844 .15315 .42907 .15981 .42426 .15486 .42372 Mtetra
.783 .955 .926 r
.15486 .42372 .15981 .42426 .16647 .41946 .16153 .419 Mtetra
.78 .959 .926 r
.16153 .419 .16647 .41946 .17313 .41467 .1682 .41429 Mtetra
.777 .962 .926 r
.1682 .41429 .17313 .41467 .1798 .40991 .17488 .40961 Mtetra
.772 .965 .926 r
.17488 .40961 .1798 .40991 .18647 .40517 .18156 .40494 Mtetra
.767 .968 .926 r
.18156 .40494 .18647 .40517 .19315 .40046 .18825 .40031 Mtetra
.761 .971 .925 r
.18825 .40031 .19315 .40046 .19982 .3958 .19494 .39571 Mtetra
.754 .973 .924 r
.19494 .39571 .19982 .3958 .2065 .39118 .20163 .39115 Mtetra
.747 .975 .924 r
.20163 .39115 .2065 .39118 .21318 .38661 .20832 .38665 Mtetra
.739 .976 .923 r
.20832 .38665 .21318 .38661 .21986 .3821 .21502 .38219 Mtetra
.73 .977 .921 r
.21502 .38219 .21986 .3821 .22654 .37765 .22171 .3778 Mtetra
.72 .977 .92 r
.22171 .3778 .22654 .37765 .23322 .37327 .22841 .37346 Mtetra
.71 .976 .918 r
.22841 .37346 .23322 .37327 .2399 .36895 .23511 .3692 Mtetra
.699 .975 .916 r
.23511 .3692 .2399 .36895 .24659 .36471 .24181 .365 Mtetra
.686 .974 .914 r
.24181 .365 .24659 .36471 .25327 .36055 .24851 .36088 Mtetra
.674 .971 .912 r
.24851 .36088 .25327 .36055 .25996 .35647 .25522 .35684 Mtetra
.66 .968 .909 r
.25522 .35684 .25996 .35647 .26665 .35248 .26192 .35288 Mtetra
.645 .965 .905 r
.26192 .35288 .26665 .35248 .27334 .34858 .26863 .34901 Mtetra
.63 .96 .902 r
.26863 .34901 .27334 .34858 .28004 .34477 .27535 .34523 Mtetra
.614 .955 .898 r
.27535 .34523 .28004 .34477 .28673 .34105 .28206 .34154 Mtetra
.597 .949 .893 r
.28206 .34154 .28673 .34105 .29343 .33744 .28878 .33795 Mtetra
.58 .943 .889 r
.28878 .33795 .29343 .33744 .30014 .33392 .29551 .33445 Mtetra
.562 .936 .884 r
.29551 .33445 .30014 .33392 .30685 .33051 .30224 .33105 Mtetra
.543 .928 .878 r
.30224 .33105 .30685 .33051 .31356 .3272 .30897 .32776 Mtetra
.524 .92 .873 r
.30897 .32776 .31356 .3272 .32028 .32399 .31571 .32456 Mtetra
.505 .91 .867 r
.31571 .32456 .32028 .32399 .32701 .3209 .32246 .32148 Mtetra
.485 .901 .861 r
.32246 .32148 .32701 .3209 .33374 .31791 .32921 .3185 Mtetra
.465 .891 .854 r
.32921 .3185 .33374 .31791 .34048 .31503 .33597 .31562 Mtetra
.444 .88 .848 r
.33597 .31562 .34048 .31503 .34723 .31227 .34274 .31286 Mtetra
.424 .869 .841 r
.34274 .31286 .34723 .31227 .35399 .30962 .34952 .3102 Mtetra
.404 .858 .835 r
.34952 .3102 .35399 .30962 .36076 .30708 .35631 .30765 Mtetra
.383 .846 .828 r
.35631 .30765 .36076 .30708 .36753 .30465 .36311 .30522 Mtetra
.363 .834 .821 r
.36311 .30522 .36753 .30465 .37432 .30233 .36992 .30289 Mtetra
.343 .822 .815 r
.36992 .30289 .37432 .30233 .38113 .30013 .37674 .30068 Mtetra
.323 .81 .808 r
.37674 .30068 .38113 .30013 .38794 .29804 .38358 .29857 Mtetra
.304 .798 .802 r
.38358 .29857 .38794 .29804 .39477 .29607 .39043 .29657 Mtetra
.285 .786 .796 r
.39043 .29657 .39477 .29607 .40162 .2942 .3973 .29469 Mtetra
.267 .774 .791 r
.3973 .29469 .40162 .2942 .40848 .29245 .40418 .29291 Mtetra
.249 .762 .786 r
.40418 .29291 .40848 .29245 .41535 .29081 .41108 .29124 Mtetra
.233 .751 .781 r
.41108 .29124 .41535 .29081 .42225 .28927 .41799 .28967 Mtetra
.217 .74 .777 r
.41799 .28967 .42225 .28927 .42916 .28785 .42493 .28821 Mtetra
.201 .729 .773 r
.42493 .28821 .42916 .28785 .43609 .28652 .43188 .28684 Mtetra
.187 .719 .77 r
.43188 .28684 .43609 .28652 .44305 .2853 .43886 .28558 Mtetra
.173 .71 .768 r
.43886 .28558 .44305 .2853 .45002 .28419 .44585 .28442 Mtetra
.161 .701 .766 r
.44585 .28442 .45002 .28419 .45702 .28317 .45287 .28336 Mtetra
.149 .693 .766 r
.45287 .28336 .45702 .28317 .46403 .28224 .45991 .28238 Mtetra
.139 .685 .765 r
.45991 .28238 .46403 .28224 .47108 .28141 .46697 .2815 Mtetra
.13 .678 .766 r
.46697 .2815 .47108 .28141 .47814 .28067 .47406 .2807 Mtetra
.122 .672 .768 r
.47406 .2807 .47814 .28067 .48524 .28002 .48118 .27999 Mtetra
.115 .667 .77 r
.48118 .27999 .48524 .28002 .49236 .27945 .48832 .27936 Mtetra
.109 .663 .773 r
.48832 .27936 .49236 .27945 .4995 .27896 .49548 .2788 Mtetra
.105 .659 .777 r
.49548 .2788 .4995 .27896 .50668 .27855 .50268 .27832 Mtetra
.102 .657 .782 r
.50268 .27832 .50668 .27855 .51388 .27821 .5099 .2779 Mtetra
.1 .655 .788 r
.5099 .2779 .51388 .27821 .52111 .27793 .51715 .27755 Mtetra
.1 .654 .794 r
.51715 .27755 .52111 .27793 .52837 .27771 .52443 .27725 Mtetra
.101 .654 .802 r
.52443 .27725 .52837 .27771 .53566 .27756 .53174 .27701 Mtetra
.104 .655 .81 r
.53174 .27701 .53566 .27756 .54298 .27745 .53908 .27682 Mtetra
.108 .657 .819 r
.53908 .27682 .54298 .27745 .55034 .27739 .54646 .27666 Mtetra
.114 .659 .829 r
.54646 .27666 .55034 .27739 .55773 .27736 .55386 .27655 Mtetra
.121 .663 .839 r
.55386 .27655 .55773 .27736 .56514 .27738 .5613 .27646 Mtetra
.13 .667 .85 r
.5613 .27646 .56514 .27738 .5726 .27741 .56877 .27639 Mtetra
.14 .672 .862 r
.56877 .27639 .5726 .27741 .58008 .27747 .57627 .27634 Mtetra
.152 .678 .874 r
.57627 .27634 .58008 .27747 .5876 .27754 .58381 .2763 Mtetra
.166 .684 .886 r
.58381 .2763 .5876 .27754 .59515 .27761 .59137 .27626 Mtetra
.181 .691 .899 r
.59137 .27626 .59515 .27761 .60273 .27769 .59897 .27621 Mtetra
.198 .699 .911 r
.59897 .27621 .60273 .27769 .61035 .27774 .60661 .27615 Mtetra
.216 .706 .923 r
.60661 .27615 .61035 .27774 .618 .27779 .61428 .27606 Mtetra
.235 .714 .935 r
.61428 .27606 .618 .27779 .62569 .2778 .62197 .27594 Mtetra
.256 .722 .946 r
.62197 .27594 .62569 .2778 .6334 .27777 .62971 .27578 Mtetra
.277 .73 .957 r
.62971 .27578 .6334 .27777 .64115 .2777 .63747 .27556 Mtetra
.3 .737 .967 r
.63747 .27556 .64115 .2777 .64894 .27756 .64526 .27529 Mtetra
.323 .745 .975 r
.64526 .27529 .64894 .27756 .65675 .27737 .65309 .27494 Mtetra
.347 .752 .983 r
.65309 .27494 .65675 .27737 .66459 .27709 .66094 .27451 Mtetra
.372 .758 .989 r
.66094 .27451 .66459 .27709 .67246 .27672 .66883 .27398 Mtetra
.397 .764 .993 r
.66883 .27398 .67246 .27672 .68036 .27625 .67674 .27335 Mtetra
.421 .768 .996 r
.67674 .27335 .68036 .27625 .68829 .27567 .68468 .2726 Mtetra
.446 .773 .997 r
.68468 .2726 .68829 .27567 .69625 .27497 .69264 .27173 Mtetra
.47 .776 .997 r
.69264 .27173 .69625 .27497 .70423 .27413 .70063 .27071 Mtetra
.494 .778 .995 r
.70063 .27071 .70423 .27413 .71223 .27314 .70864 .26954 Mtetra
.517 .78 .992 r
.70864 .26954 .71223 .27314 .72025 .27199 .71667 .2682 Mtetra
.539 .78 .987 r
.71667 .2682 .72025 .27199 .72829 .27066 .72472 .26668 Mtetra
.71 .819 .932 r
.02562 .50126 .03055 .5043 .03688 .50104 .03194 .49817 Mtetra
.721 .829 .932 r
.03194 .49817 .03688 .50104 .04325 .49761 .0383 .4949 Mtetra
.73 .839 .932 r
.0383 .4949 .04325 .49761 .04965 .49403 .04469 .49147 Mtetra
.738 .848 .931 r
.04469 .49147 .04965 .49403 .05609 .49029 .05111 .48788 Mtetra
.746 .857 .931 r
.05111 .48788 .05609 .49029 .06255 .48642 .05756 .48416 Mtetra
.753 .865 .931 r
.05756 .48416 .06255 .48642 .06903 .48242 .06404 .48031 Mtetra
.759 .873 .93 r
.06404 .48031 .06903 .48242 .07554 .47831 .07054 .47634 Mtetra
.764 .881 .93 r
.07054 .47634 .07554 .47831 .08207 .4741 .07707 .47226 Mtetra
.769 .889 .93 r
.07707 .47226 .08207 .4741 .08862 .46979 .08362 .46808 Mtetra
.773 .896 .93 r
.08362 .46808 .08862 .46979 .09519 .4654 .09018 .46382 Mtetra
.776 .903 .93 r
.09018 .46382 .09519 .4654 .10177 .46094 .09677 .45948 Mtetra
.779 .909 .93 r
.09677 .45948 .10177 .46094 .10837 .45641 .10336 .45508 Mtetra
.781 .915 .93 r
.10336 .45508 .10837 .45641 .11498 .45183 .10998 .45061 Mtetra
.783 .922 .93 r
.10998 .45061 .11498 .45183 .12161 .44721 .1166 .4461 Mtetra
.784 .927 .93 r
.1166 .4461 .12161 .44721 .12824 .44255 .12324 .44155 Mtetra
.784 .933 .93 r
.12324 .44155 .12824 .44255 .13488 .43786 .12989 .43696 Mtetra
.783 .938 .93 r
.12989 .43696 .13488 .43786 .14154 .43316 .13655 .43236 Mtetra
.782 .943 .93 r
.13655 .43236 .14154 .43316 .14819 .42844 .14321 .42773 Mtetra
.781 .948 .93 r
.14321 .42773 .14819 .42844 .15486 .42372 .14988 .4231 Mtetra
.778 .952 .93 r
.14988 .4231 .15486 .42372 .16153 .419 .15656 .41847 Mtetra
.776 .956 .93 r
.15656 .41847 .16153 .419 .1682 .41429 .16325 .41385 Mtetra
.772 .96 .929 r
.16325 .41385 .1682 .41429 .17488 .40961 .16994 .40924 Mtetra
.768 .963 .929 r
.16994 .40924 .17488 .40961 .18156 .40494 .17663 .40466 Mtetra
.763 .966 .929 r
.17663 .40466 .18156 .40494 .18825 .40031 .18333 .40009 Mtetra
.757 .969 .928 r
.18333 .40009 .18825 .40031 .19494 .39571 .19003 .39557 Mtetra
.75 .971 .927 r
.19003 .39557 .19494 .39571 .20163 .39115 .19673 .39108 Mtetra
.743 .973 .927 r
.19673 .39108 .20163 .39115 .20832 .38665 .20344 .38663 Mtetra
.735 .974 .926 r
.20344 .38663 .20832 .38665 .21502 .38219 .21014 .38224 Mtetra
.726 .975 .924 r
.21014 .38224 .21502 .38219 .22171 .3778 .21685 .3779 Mtetra
.717 .975 .923 r
.21685 .3779 .22171 .3778 .22841 .37346 .22357 .37362 Mtetra
.706 .975 .921 r
.22357 .37362 .22841 .37346 .23511 .3692 .23028 .3694 Mtetra
.695 .974 .919 r
.23028 .3694 .23511 .3692 .24181 .365 .237 .36525 Mtetra
.683 .972 .917 r
.237 .36525 .24181 .365 .24851 .36088 .24372 .36117 Mtetra
.671 .97 .914 r
.24372 .36117 .24851 .36088 .25522 .35684 .25044 .35717 Mtetra
.657 .967 .911 r
.25044 .35717 .25522 .35684 .26192 .35288 .25717 .35325 Mtetra
.643 .963 .908 r
.25717 .35325 .26192 .35288 .26863 .34901 .26389 .34941 Mtetra
.628 .959 .904 r
.26389 .34941 .26863 .34901 .27535 .34523 .27063 .34566 Mtetra
.612 .954 .9 r
.27063 .34566 .27535 .34523 .28206 .34154 .27736 .342 Mtetra
.596 .949 .896 r
.27736 .342 .28206 .34154 .28878 .33795 .2841 .33843 Mtetra
.579 .942 .891 r
.2841 .33843 .28878 .33795 .29551 .33445 .29084 .33495 Mtetra
.561 .935 .886 r
.29084 .33495 .29551 .33445 .30224 .33105 .29759 .33157 Mtetra
.543 .928 .881 r
.29759 .33157 .30224 .33105 .30897 .32776 .30434 .32829 Mtetra
.524 .919 .875 r
.30434 .32829 .30897 .32776 .31571 .32456 .3111 .32511 Mtetra
.505 .911 .87 r
.3111 .32511 .31571 .32456 .32246 .32148 .31787 .32203 Mtetra
.486 .901 .864 r
.31787 .32203 .32246 .32148 .32921 .3185 .32464 .31906 Mtetra
.466 .891 .857 r
.32464 .31906 .32921 .3185 .33597 .31562 .33143 .31619 Mtetra
.446 .881 .851 r
.33143 .31619 .33597 .31562 .34274 .31286 .33822 .31342 Mtetra
.427 .87 .845 r
.33822 .31342 .34274 .31286 .34952 .3102 .34502 .31076 Mtetra
.407 .859 .838 r
.34502 .31076 .34952 .3102 .35631 .30765 .35183 .30821 Mtetra
.387 .848 .832 r
.35183 .30821 .35631 .30765 .36311 .30522 .35865 .30576 Mtetra
.367 .837 .826 r
.35865 .30576 .36311 .30522 .36992 .30289 .36548 .30343 Mtetra
.348 .825 .819 r
.36548 .30343 .36992 .30289 .37674 .30068 .37233 .30119 Mtetra
.329 .813 .813 r
.37233 .30119 .37674 .30068 .38358 .29857 .37919 .29907 Mtetra
.311 .802 .808 r
.37919 .29907 .38358 .29857 .39043 .29657 .38606 .29705 Mtetra
.292 .79 .802 r
.38606 .29705 .39043 .29657 .3973 .29469 .39295 .29514 Mtetra
.275 .779 .797 r
.39295 .29514 .3973 .29469 .40418 .29291 .39985 .29334 Mtetra
.258 .768 .792 r
.39985 .29334 .40418 .29291 .41108 .29124 .40677 .29163 Mtetra
.242 .757 .788 r
.40677 .29163 .41108 .29124 .41799 .28967 .41371 .29003 Mtetra
.227 .747 .785 r
.41371 .29003 .41799 .28967 .42493 .28821 .42066 .28854 Mtetra
.212 .737 .781 r
.42066 .28854 .42493 .28821 .43188 .28684 .42764 .28714 Mtetra
.198 .728 .779 r
.42764 .28714 .43188 .28684 .43886 .28558 .43464 .28583 Mtetra
.186 .719 .777 r
.43464 .28583 .43886 .28558 .44585 .28442 .44165 .28462 Mtetra
.174 .71 .776 r
.44165 .28462 .44585 .28442 .45287 .28336 .44869 .28351 Mtetra
.163 .703 .775 r
.44869 .28351 .45287 .28336 .45991 .28238 .45575 .28248 Mtetra
.154 .696 .776 r
.45575 .28248 .45991 .28238 .46697 .2815 .46284 .28155 Mtetra
.145 .69 .777 r
.46284 .28155 .46697 .2815 .47406 .2807 .46995 .28069 Mtetra
.138 .684 .779 r
.46995 .28069 .47406 .2807 .48118 .27999 .47708 .27992 Mtetra
.132 .68 .782 r
.47708 .27992 .48118 .27999 .48832 .27936 .48424 .27922 Mtetra
.127 .676 .785 r
.48424 .27922 .48832 .27936 .49548 .2788 .49143 .27859 Mtetra
.123 .673 .79 r
.49143 .27859 .49548 .2788 .50268 .27832 .49865 .27804 Mtetra
.121 .671 .795 r
.49865 .27804 .50268 .27832 .5099 .2779 .50589 .27755 Mtetra
.12 .669 .801 r
.50589 .27755 .5099 .2779 .51715 .27755 .51316 .27711 Mtetra
.121 .669 .808 r
.51316 .27711 .51715 .27755 .52443 .27725 .52046 .27673 Mtetra
.123 .669 .816 r
.52046 .27673 .52443 .27725 .53174 .27701 .52779 .27641 Mtetra
.126 .671 .825 r
.52779 .27641 .53174 .27701 .53908 .27682 .53515 .27612 Mtetra
.131 .673 .834 r
.53515 .27612 .53908 .27682 .54646 .27666 .54255 .27587 Mtetra
.138 .676 .844 r
.54255 .27587 .54646 .27666 .55386 .27655 .54997 .27566 Mtetra
.146 .68 .855 r
.54997 .27566 .55386 .27655 .5613 .27646 .55743 .27547 Mtetra
.155 .684 .866 r
.55743 .27547 .5613 .27646 .56877 .27639 .56491 .2753 Mtetra
.167 .689 .877 r
.56491 .2753 .56877 .27639 .57627 .27634 .57243 .27514 Mtetra
.179 .695 .889 r
.57243 .27514 .57627 .27634 .58381 .2763 .57999 .27498 Mtetra
.193 .701 .901 r
.57999 .27498 .58381 .2763 .59137 .27626 .58757 .27482 Mtetra
.209 .708 .913 r
.58757 .27482 .59137 .27626 .59897 .27621 .59519 .27465 Mtetra
.226 .715 .925 r
.59519 .27465 .59897 .27621 .60661 .27615 .60284 .27446 Mtetra
.245 .722 .936 r
.60284 .27446 .60661 .27615 .61428 .27606 .61052 .27424 Mtetra
.264 .729 .947 r
.61052 .27424 .61428 .27606 .62197 .27594 .61823 .27398 Mtetra
.285 .737 .958 r
.61823 .27398 .62197 .27594 .62971 .27578 .62598 .27368 Mtetra
.307 .744 .967 r
.62598 .27368 .62971 .27578 .63747 .27556 .63376 .27332 Mtetra
.329 .751 .976 r
.63376 .27332 .63747 .27556 .64526 .27529 .64156 .27289 Mtetra
.352 .757 .983 r
.64156 .27289 .64526 .27529 .65309 .27494 .6494 .27239 Mtetra
.376 .763 .989 r
.6494 .27239 .65309 .27494 .66094 .27451 .65727 .2718 Mtetra
.4 .768 .993 r
.65727 .2718 .66094 .27451 .66883 .27398 .66516 .27111 Mtetra
.424 .772 .996 r
.66516 .27111 .66883 .27398 .67674 .27335 .67309 .27031 Mtetra
.447 .776 .998 r
.67309 .27031 .67674 .27335 .68468 .2726 .68103 .26939 Mtetra
.471 .779 .998 r
.68103 .26939 .68468 .2726 .69264 .27173 .68901 .26834 Mtetra
.494 .781 .996 r
.68901 .26834 .69264 .27173 .70063 .27071 .697 .26714 Mtetra
.516 .782 .993 r
.697 .26714 .70063 .27071 .70864 .26954 .70502 .26578 Mtetra
.538 .782 .988 r
.70502 .26578 .70864 .26954 .71667 .2682 .71305 .26424 Mtetra
.559 .782 .982 r
.71305 .26424 .71667 .2682 .72472 .26668 .72111 .26253 Mtetra
.699 .81 .934 r
.02069 .49806 .02562 .50126 .03194 .49817 .02699 .49514 Mtetra
.71 .821 .934 r
.02699 .49514 .03194 .49817 .0383 .4949 .03334 .49203 Mtetra
.72 .831 .934 r
.03334 .49203 .0383 .4949 .04469 .49147 .03971 .48876 Mtetra
.729 .841 .934 r
.03971 .48876 .04469 .49147 .05111 .48788 .04612 .48534 Mtetra
.737 .85 .933 r
.04612 .48534 .05111 .48788 .05756 .48416 .05257 .48177 Mtetra
.744 .859 .933 r
.05257 .48177 .05756 .48416 .06404 .48031 .05904 .47806 Mtetra
.751 .867 .933 r
.05904 .47806 .06404 .48031 .07054 .47634 .06553 .47424 Mtetra
.756 .875 .933 r
.06553 .47424 .07054 .47634 .07707 .47226 .07205 .4703 Mtetra
.761 .883 .933 r
.07205 .4703 .07707 .47226 .08362 .46808 .0786 .46626 Mtetra
.766 .891 .933 r
.0786 .46626 .08362 .46808 .09018 .46382 .08516 .46213 Mtetra
.769 .898 .933 r
.08516 .46213 .09018 .46382 .09677 .45948 .09174 .45791 Mtetra
.772 .905 .933 r
.09174 .45791 .09677 .45948 .10336 .45508 .09834 .45363 Mtetra
.775 .911 .933 r
.09834 .45363 .10336 .45508 .10998 .45061 .10495 .44929 Mtetra
.776 .918 .933 r
.10495 .44929 .10998 .45061 .1166 .4461 .11158 .44489 Mtetra
.778 .924 .933 r
.11158 .44489 .1166 .4461 .12324 .44155 .11822 .44045 Mtetra
.778 .929 .933 r
.11822 .44045 .12324 .44155 .12989 .43696 .12487 .43597 Mtetra
.778 .935 .933 r
.12487 .43597 .12989 .43696 .13655 .43236 .13154 .43146 Mtetra
.777 .94 .933 r
.13154 .43146 .13655 .43236 .14321 .42773 .13821 .42694 Mtetra
.776 .945 .933 r
.13821 .42694 .14321 .42773 .14988 .4231 .14489 .42241 Mtetra
.773 .949 .933 r
.14489 .42241 .14988 .4231 .15656 .41847 .15157 .41787 Mtetra
.771 .954 .933 r
.15157 .41787 .15656 .41847 .16325 .41385 .15826 .41333 Mtetra
.767 .957 .933 r
.15826 .41333 .16325 .41385 .16994 .40924 .16496 .40881 Mtetra
.763 .961 .932 r
.16496 .40881 .16994 .40924 .17663 .40466 .17167 .4043 Mtetra
.758 .964 .932 r
.17167 .4043 .17663 .40466 .18333 .40009 .17837 .39981 Mtetra
.753 .967 .931 r
.17837 .39981 .18333 .40009 .19003 .39557 .18509 .39536 Mtetra
.746 .969 .931 r
.18509 .39536 .19003 .39557 .19673 .39108 .1918 .39094 Mtetra
.739 .971 .93 r
.1918 .39094 .19673 .39108 .20344 .38663 .19852 .38656 Mtetra
.731 .972 .929 r
.19852 .38656 .20344 .38663 .21014 .38224 .20524 .38222 Mtetra
.723 .973 .927 r
.20524 .38222 .21014 .38224 .21685 .3779 .21197 .37794 Mtetra
.713 .973 .926 r
.21197 .37794 .21685 .3779 .22357 .37362 .21869 .37372 Mtetra
.703 .973 .924 r
.21869 .37372 .22357 .37362 .23028 .3694 .22542 .36955 Mtetra
.692 .972 .922 r
.22542 .36955 .23028 .3694 .237 .36525 .23216 .36545 Mtetra
.681 .971 .92 r
.23216 .36545 .237 .36525 .24372 .36117 .23889 .36142 Mtetra
.668 .969 .917 r
.23889 .36142 .24372 .36117 .25044 .35717 .24563 .35746 Mtetra
.655 .966 .914 r
.24563 .35746 .25044 .35717 .25717 .35325 .25238 .35357 Mtetra
.641 .962 .911 r
.25238 .35357 .25717 .35325 .26389 .34941 .25912 .34977 Mtetra
.626 .958 .907 r
.25912 .34977 .26389 .34941 .27063 .34566 .26587 .34605 Mtetra
.611 .953 .903 r
.26587 .34605 .27063 .34566 .27736 .342 .27262 .34242 Mtetra
.595 .948 .899 r
.27262 .34242 .27736 .342 .2841 .33843 .27938 .33887 Mtetra
.578 .942 .894 r
.27938 .33887 .2841 .33843 .29084 .33495 .28614 .33542 Mtetra
.561 .935 .889 r
.28614 .33542 .29084 .33495 .29759 .33157 .29291 .33205 Mtetra
.543 .928 .884 r
.29291 .33205 .29759 .33157 .30434 .32829 .29969 .32879 Mtetra
.525 .92 .879 r
.29969 .32879 .30434 .32829 .3111 .32511 .30647 .32562 Mtetra
.507 .911 .873 r
.30647 .32562 .3111 .32511 .31787 .32203 .31325 .32255 Mtetra
.488 .902 .868 r
.31325 .32255 .31787 .32203 .32464 .31906 .32005 .31958 Mtetra
.469 .893 .862 r
.32005 .31958 .32464 .31906 .33143 .31619 .32685 .31671 Mtetra
.45 .883 .856 r
.32685 .31671 .33143 .31619 .33822 .31342 .33366 .31395 Mtetra
.431 .873 .849 r
.33366 .31395 .33822 .31342 .34502 .31076 .34048 .31129 Mtetra
.411 .862 .843 r
.34048 .31129 .34502 .31076 .35183 .30821 .34731 .30873 Mtetra
.392 .851 .837 r
.34731 .30873 .35183 .30821 .35865 .30576 .35416 .30627 Mtetra
.373 .84 .831 r
.35416 .30627 .35865 .30576 .36548 .30343 .36101 .30392 Mtetra
.355 .829 .825 r
.36101 .30392 .36548 .30343 .37233 .30119 .36788 .30168 Mtetra
.336 .818 .82 r
.36788 .30168 .37233 .30119 .37919 .29907 .37476 .29954 Mtetra
.318 .807 .814 r
.37476 .29954 .37919 .29907 .38606 .29705 .38165 .2975 Mtetra
.301 .796 .809 r
.38165 .2975 .38606 .29705 .39295 .29514 .38856 .29556 Mtetra
.284 .785 .805 r
.38856 .29556 .39295 .29514 .39985 .29334 .39549 .29373 Mtetra
.268 .775 .8 r
.39549 .29373 .39985 .29334 .40677 .29163 .40243 .29199 Mtetra
.253 .765 .797 r
.40243 .29199 .40677 .29163 .41371 .29003 .40939 .29036 Mtetra
.238 .755 .794 r
.40939 .29036 .41371 .29003 .42066 .28854 .41637 .28882 Mtetra
.224 .746 .791 r
.41637 .28882 .42066 .28854 .42764 .28714 .42337 .28738 Mtetra
.211 .737 .789 r
.42337 .28738 .42764 .28714 .43464 .28583 .43038 .28604 Mtetra
.199 .729 .788 r
.43038 .28604 .43464 .28583 .44165 .28462 .43742 .28478 Mtetra
.188 .721 .787 r
.43742 .28478 .44165 .28462 .44869 .28351 .44448 .28362 Mtetra
.179 .714 .787 r
.44448 .28362 .44869 .28351 .45575 .28248 .45157 .28254 Mtetra
.17 .707 .788 r
.45157 .28254 .45575 .28248 .46284 .28155 .45867 .28154 Mtetra
.162 .702 .789 r
.45867 .28154 .46284 .28155 .46995 .28069 .4658 .28063 Mtetra
.155 .697 .792 r
.4658 .28063 .46995 .28069 .47708 .27992 .47296 .27979 Mtetra
.15 .693 .795 r
.47296 .27979 .47708 .27992 .48424 .27922 .48014 .27902 Mtetra
.146 .69 .799 r
.48014 .27902 .48424 .27922 .49143 .27859 .48735 .27833 Mtetra
.143 .687 .804 r
.48735 .27833 .49143 .27859 .49865 .27804 .49459 .2777 Mtetra
.142 .685 .81 r
.49459 .2777 .49865 .27804 .50589 .27755 .50185 .27713 Mtetra
.142 .685 .816 r
.50185 .27713 .50589 .27755 .51316 .27711 .50914 .27661 Mtetra
.143 .685 .824 r
.50914 .27661 .51316 .27711 .52046 .27673 .51646 .27615 Mtetra
.146 .685 .832 r
.51646 .27615 .52046 .27673 .52779 .27641 .52381 .27573 Mtetra
.15 .687 .841 r
.52381 .27573 .52779 .27641 .53515 .27612 .53119 .27535 Mtetra
.156 .689 .85 r
.53119 .27535 .53515 .27612 .54255 .27587 .53861 .27501 Mtetra
.163 .693 .86 r
.53861 .27501 .54255 .27587 .54997 .27566 .54605 .27469 Mtetra
.172 .697 .871 r
.54605 .27469 .54997 .27566 .55743 .27547 .55352 .27439 Mtetra
.182 .701 .882 r
.55352 .27439 .55743 .27547 .56491 .2753 .56103 .27411 Mtetra
.194 .706 .893 r
.56103 .27411 .56491 .2753 .57243 .27514 .56857 .27384 Mtetra
.208 .712 .904 r
.56857 .27384 .57243 .27514 .57999 .27498 .57614 .27356 Mtetra
.222 .718 .916 r
.57614 .27356 .57999 .27498 .58757 .27482 .58374 .27328 Mtetra
.239 .724 .927 r
.58374 .27328 .58757 .27482 .59519 .27465 .59137 .27299 Mtetra
.256 .731 .938 r
.59137 .27299 .59519 .27465 .60284 .27446 .59904 .27266 Mtetra
.275 .738 .949 r
.59904 .27266 .60284 .27446 .61052 .27424 .60673 .27231 Mtetra
.294 .744 .959 r
.60673 .27231 .61052 .27424 .61823 .27398 .61446 .27191 Mtetra
.315 .751 .968 r
.61446 .27191 .61823 .27398 .62598 .27368 .62222 .27146 Mtetra
.337 .757 .976 r
.62222 .27146 .62598 .27368 .63376 .27332 .63001 .27096 Mtetra
.359 .763 .983 r
.63001 .27096 .63376 .27332 .64156 .27289 .63784 .27037 Mtetra
.381 .768 .989 r
.63784 .27037 .64156 .27289 .6494 .27239 .64569 .26971 Mtetra
.404 .773 .994 r
.64569 .26971 .6494 .27239 .65727 .2718 .65356 .26896 Mtetra
.427 .777 .997 r
.65356 .26896 .65727 .2718 .66516 .27111 .66147 .2681 Mtetra
.45 .78 .998 r
.66147 .2681 .66516 .27111 .67309 .27031 .6694 .26713 Mtetra
.473 .782 .998 r
.6694 .26713 .67309 .27031 .68103 .26939 .67736 .26603 Mtetra
.495 .784 .996 r
.67736 .26603 .68103 .26939 .68901 .26834 .68534 .26479 Mtetra
.517 .785 .993 r
.68534 .26479 .68901 .26834 .697 .26714 .69335 .2634 Mtetra
.538 .785 .989 r
.69335 .2634 .697 .26714 .70502 .26578 .70137 .26185 Mtetra
.559 .784 .983 r
.70137 .26185 .70502 .26578 .71305 .26424 .70941 .26012 Mtetra
.578 .783 .976 r
.70941 .26012 .71305 .26424 .72111 .26253 .71747 .2582 Mtetra
.687 .8 .935 r
.01576 .49469 .02069 .49806 .02699 .49514 .02204 .49194 Mtetra
.699 .811 .935 r
.02204 .49194 .02699 .49514 .03334 .49203 .02837 .48901 Mtetra
.709 .822 .935 r
.02837 .48901 .03334 .49203 .03971 .48876 .03473 .4859 Mtetra
.719 .832 .935 r
.03473 .4859 .03971 .48876 .04612 .48534 .04113 .48264 Mtetra
.727 .842 .935 r
.04113 .48264 .04612 .48534 .05257 .48177 .04756 .47922 Mtetra
.735 .851 .935 r
.04756 .47922 .05257 .48177 .05904 .47806 .05402 .47567 Mtetra
.742 .86 .935 r
.05402 .47567 .05904 .47806 .06553 .47424 .06051 .47199 Mtetra
.748 .869 .936 r
.06051 .47199 .06553 .47424 .07205 .4703 .06702 .4682 Mtetra
.753 .877 .936 r
.06702 .4682 .07205 .4703 .0786 .46626 .07356 .4643 Mtetra
.758 .885 .936 r
.07356 .4643 .0786 .46626 .08516 .46213 .08012 .4603 Mtetra
.762 .892 .936 r
.08012 .4603 .08516 .46213 .09174 .45791 .0867 .45622 Mtetra
.765 .899 .936 r
.0867 .45622 .09174 .45791 .09834 .45363 .0933 .45207 Mtetra
.768 .906 .936 r
.0933 .45207 .09834 .45363 .10495 .44929 .09991 .44784 Mtetra
.77 .913 .936 r
.09991 .44784 .10495 .44929 .11158 .44489 .10654 .44356 Mtetra
.771 .919 .936 r
.10654 .44356 .11158 .44489 .11822 .44045 .11318 .43924 Mtetra
.772 .925 .936 r
.11318 .43924 .11822 .44045 .12487 .43597 .11984 .43487 Mtetra
.772 .931 .936 r
.11984 .43487 .12487 .43597 .13154 .43146 .1265 .43047 Mtetra
.771 .936 .937 r
.1265 .43047 .13154 .43146 .13821 .42694 .13318 .42605 Mtetra
.77 .941 .937 r
.13318 .42605 .13821 .42694 .14489 .42241 .13986 .42161 Mtetra
.768 .946 .937 r
.13986 .42161 .14489 .42241 .15157 .41787 .14656 .41717 Mtetra
.766 .95 .936 r
.14656 .41717 .15157 .41787 .15826 .41333 .15326 .41272 Mtetra
.762 .954 .936 r
.15326 .41272 .15826 .41333 .16496 .40881 .15996 .40829 Mtetra
.759 .958 .936 r
.15996 .40829 .16496 .40881 .17167 .4043 .16668 .40386 Mtetra
.754 .961 .936 r
.16668 .40386 .17167 .4043 .17837 .39981 .17339 .39945 Mtetra
.748 .964 .935 r
.17339 .39945 .17837 .39981 .18509 .39536 .18012 .39507 Mtetra
.742 .967 .934 r
.18012 .39507 .18509 .39536 .1918 .39094 .18684 .39072 Mtetra
.736 .968 .933 r
.18684 .39072 .1918 .39094 .19852 .38656 .19358 .38641 Mtetra
.728 .97 .932 r
.19358 .38641 .19852 .38656 .20524 .38222 .20031 .38214 Mtetra
.72 .971 .931 r
.20031 .38214 .20524 .38222 .21197 .37794 .20705 .37792 Mtetra
.711 .971 .929 r
.20705 .37792 .21197 .37794 .21869 .37372 .21379 .37375 Mtetra
.701 .971 .928 r
.21379 .37375 .21869 .37372 .22542 .36955 .22054 .36964 Mtetra
.69 .97 .926 r
.22054 .36964 .22542 .36955 .23216 .36545 .22729 .36558 Mtetra
.679 .969 .923 r
.22729 .36558 .23216 .36545 .23889 .36142 .23404 .3616 Mtetra
.666 .967 .921 r
.23404 .3616 .23889 .36142 .24563 .35746 .24079 .35768 Mtetra
.653 .964 .918 r
.24079 .35768 .24563 .35746 .25238 .35357 .24755 .35384 Mtetra
.64 .961 .914 r
.24755 .35384 .25238 .35357 .25912 .34977 .25432 .35007 Mtetra
.626 .957 .911 r
.25432 .35007 .25912 .34977 .26587 .34605 .26108 .34638 Mtetra
.611 .953 .907 r
.26108 .34638 .26587 .34605 .27262 .34242 .26785 .34278 Mtetra
.595 .948 .903 r
.26785 .34278 .27262 .34242 .27938 .33887 .27463 .33926 Mtetra
.579 .942 .898 r
.27463 .33926 .27938 .33887 .28614 .33542 .28141 .33583 Mtetra
.562 .935 .894 r
.28141 .33583 .28614 .33542 .29291 .33205 .2882 .33249 Mtetra
.545 .928 .889 r
.2882 .33249 .29291 .33205 .29969 .32879 .29499 .32924 Mtetra
.527 .921 .883 r
.29499 .32924 .29969 .32879 .30647 .32562 .30179 .32608 Mtetra
.509 .912 .878 r
.30179 .32608 .30647 .32562 .31325 .32255 .3086 .32302 Mtetra
.491 .904 .873 r
.3086 .32302 .31325 .32255 .32005 .31958 .31542 .32006 Mtetra
.473 .895 .867 r
.31542 .32006 .32005 .31958 .32685 .31671 .32224 .3172 Mtetra
.454 .885 .861 r
.32224 .3172 .32685 .31671 .33366 .31395 .32907 .31443 Mtetra
.436 .875 .855 r
.32907 .31443 .33366 .31395 .34048 .31129 .33591 .31177 Mtetra
.417 .865 .849 r
.33591 .31177 .34048 .31129 .34731 .30873 .34277 .3092 Mtetra
.399 .855 .844 r
.34277 .3092 .34731 .30873 .35416 .30627 .34963 .30674 Mtetra
.38 .845 .838 r
.34963 .30674 .35416 .30627 .36101 .30392 .35651 .30437 Mtetra
.363 .834 .833 r
.35651 .30437 .36101 .30392 .36788 .30168 .36339 .30211 Mtetra
.345 .823 .827 r
.36339 .30211 .36788 .30168 .37476 .29954 .3703 .29995 Mtetra
.328 .813 .823 r
.3703 .29995 .37476 .29954 .38165 .2975 .37721 .29789 Mtetra
.311 .803 .818 r
.37721 .29789 .38165 .2975 .38856 .29556 .38414 .29593 Mtetra
.295 .793 .814 r
.38414 .29593 .38856 .29556 .39549 .29373 .39109 .29407 Mtetra
.28 .783 .81 r
.39109 .29407 .39549 .29373 .40243 .29199 .39806 .2923 Mtetra
.265 .773 .807 r
.39806 .2923 .40243 .29199 .40939 .29036 .40504 .29064 Mtetra
.251 .764 .804 r
.40504 .29064 .40939 .29036 .41637 .28882 .41204 .28906 Mtetra
.238 .755 .802 r
.41204 .28906 .41637 .28882 .42337 .28738 .41906 .28758 Mtetra
.226 .747 .8 r
.41906 .28758 .42337 .28738 .43038 .28604 .4261 .28619 Mtetra
.215 .739 .799 r
.4261 .28619 .43038 .28604 .43742 .28478 .43316 .28489 Mtetra
.205 .732 .799 r
.43316 .28489 .43742 .28478 .44448 .28362 .44024 .28367 Mtetra
.195 .726 .8 r
.44024 .28367 .44448 .28362 .45157 .28254 .44735 .28253 Mtetra
.187 .72 .801 r
.44735 .28253 .45157 .28254 .45867 .28154 .45447 .28148 Mtetra
.18 .715 .803 r
.45447 .28148 .45867 .28154 .4658 .28063 .46163 .2805 Mtetra
.175 .711 .806 r
.46163 .2805 .4658 .28063 .47296 .27979 .4688 .2796 Mtetra
.17 .707 .81 r
.4688 .2796 .47296 .27979 .48014 .27902 .47601 .27876 Mtetra
.167 .704 .814 r
.47601 .27876 .48014 .27902 .48735 .27833 .48324 .27799 Mtetra
.165 .702 .82 r
.48324 .27799 .48735 .27833 .49459 .2777 .49049 .27729 Mtetra
.164 .701 .826 r
.49049 .27729 .49459 .2777 .50185 .27713 .49778 .27663 Mtetra
.165 .7 .833 r
.49778 .27663 .50185 .27713 .50914 .27661 .50509 .27604 Mtetra
.167 .701 .84 r
.50509 .27604 .50914 .27661 .51646 .27615 .51243 .27548 Mtetra
.171 .702 .848 r
.51243 .27548 .51646 .27615 .52381 .27573 .5198 .27497 Mtetra
.176 .704 .857 r
.5198 .27497 .52381 .27573 .53119 .27535 .5272 .2745 Mtetra
.183 .706 .867 r
.5272 .2745 .53119 .27535 .53861 .27501 .53463 .27405 Mtetra
.191 .71 .877 r
.53463 .27405 .53861 .27501 .54605 .27469 .5421 .27363 Mtetra
.2 .714 .887 r
.5421 .27363 .54605 .27469 .55352 .27439 .54959 .27323 Mtetra
.211 .718 .898 r
.54959 .27323 .55352 .27439 .56103 .27411 .55711 .27283 Mtetra
.223 .723 .909 r
.55711 .27283 .56103 .27411 .56857 .27384 .56467 .27244 Mtetra
.237 .729 .92 r
.56467 .27244 .56857 .27384 .57614 .27356 .57226 .27204 Mtetra
.252 .734 .931 r
.57226 .27204 .57614 .27356 .58374 .27328 .57987 .27164 Mtetra
.269 .74 .941 r
.57987 .27164 .58374 .27328 .59137 .27299 .58752 .27121 Mtetra
.287 .746 .951 r
.58752 .27121 .59137 .27299 .59904 .27266 .59521 .27075 Mtetra
.305 .752 .961 r
.59521 .27075 .59904 .27266 .60673 .27231 .60292 .27026 Mtetra
.325 .758 .97 r
.60292 .27026 .60673 .27231 .61446 .27191 .61066 .26972 Mtetra
.346 .764 .978 r
.61066 .26972 .61446 .27191 .62222 .27146 .61844 .26912 Mtetra
.367 .769 .984 r
.61844 .26912 .62222 .27146 .63001 .27096 .62624 .26846 Mtetra
.388 .773 .99 r
.62624 .26846 .63001 .27096 .63784 .27037 .63408 .26772 Mtetra
.41 .778 .994 r
.63408 .26772 .63784 .27037 .64569 .26971 .64194 .26689 Mtetra
.432 .781 .997 r
.64194 .26689 .64569 .26971 .65356 .26896 .64983 .26597 Mtetra
.454 .784 .998 r
.64983 .26597 .65356 .26896 .66147 .2681 .65775 .26494 Mtetra
.476 .786 .998 r
.65775 .26494 .66147 .2681 .6694 .26713 .66569 .26379 Mtetra
.498 .787 .997 r
.66569 .26379 .6694 .26713 .67736 .26603 .67366 .26251 Mtetra
.519 .787 .994 r
.67366 .26251 .67736 .26603 .68534 .26479 .68165 .26108 Mtetra
.539 .787 .989 r
.68165 .26108 .68534 .26479 .69335 .2634 .68966 .2595 Mtetra
.559 .786 .984 r
.68966 .2595 .69335 .2634 .70137 .26185 .69769 .25775 Mtetra
.578 .784 .977 r
.69769 .25775 .70137 .26185 .70941 .26012 .70574 .25582 Mtetra
.596 .782 .969 r
.70574 .25582 .70941 .26012 .71747 .2582 .7138 .25369 Mtetra
.675 .789 .935 r
.01083 .49113 .01576 .49469 .02204 .49194 .0171 .48856 Mtetra
.687 .801 .936 r
.0171 .48856 .02204 .49194 .02837 .48901 .0234 .48581 Mtetra
.698 .812 .936 r
.0234 .48581 .02837 .48901 .03473 .4859 .02975 .48287 Mtetra
.708 .823 .937 r
.02975 .48287 .03473 .4859 .04113 .48264 .03614 .47977 Mtetra
.717 .833 .937 r
.03614 .47977 .04113 .48264 .04756 .47922 .04255 .47652 Mtetra
.725 .843 .937 r
.04255 .47652 .04756 .47922 .05402 .47567 .049 .47313 Mtetra
.732 .853 .937 r
.049 .47313 .05402 .47567 .06051 .47199 .05548 .4696 Mtetra
.739 .861 .938 r
.05548 .4696 .06051 .47199 .06702 .4682 .06199 .46595 Mtetra
.745 .87 .938 r
.06199 .46595 .06702 .4682 .07356 .4643 .06852 .4622 Mtetra
.75 .878 .938 r
.06852 .4622 .07356 .4643 .08012 .4603 .07507 .45834 Mtetra
.754 .886 .938 r
.07507 .45834 .08012 .4603 .0867 .45622 .08165 .4544 Mtetra
.758 .893 .939 r
.08165 .4544 .0867 .45622 .0933 .45207 .08824 .45037 Mtetra
.761 .901 .939 r
.08824 .45037 .0933 .45207 .09991 .44784 .09485 .44627 Mtetra
.763 .907 .939 r
.09485 .44627 .09991 .44784 .10654 .44356 .10148 .44212 Mtetra
.765 .914 .939 r
.10148 .44212 .10654 .44356 .11318 .43924 .10812 .43791 Mtetra
.766 .92 .94 r
.10812 .43791 .11318 .43924 .11984 .43487 .11478 .43365 Mtetra
.766 .926 .94 r
.11478 .43365 .11984 .43487 .1265 .43047 .12145 .42937 Mtetra
.766 .932 .94 r
.12145 .42937 .1265 .43047 .13318 .42605 .12813 .42505 Mtetra
.765 .937 .94 r
.12813 .42505 .13318 .42605 .13986 .42161 .13482 .42072 Mtetra
.763 .942 .94 r
.13482 .42072 .13986 .42161 .14656 .41717 .14152 .41637 Mtetra
.761 .946 .94 r
.14152 .41637 .14656 .41717 .15326 .41272 .14823 .41202 Mtetra
.758 .951 .94 r
.14823 .41202 .15326 .41272 .15996 .40829 .15494 .40767 Mtetra
.754 .955 .939 r
.15494 .40767 .15996 .40829 .16668 .40386 .16166 .40333 Mtetra
.75 .958 .939 r
.16166 .40333 .16668 .40386 .17339 .39945 .16839 .399 Mtetra
.744 .961 .939 r
.16839 .399 .17339 .39945 .18012 .39507 .17512 .3947 Mtetra
.739 .964 .938 r
.17512 .3947 .18012 .39507 .18684 .39072 .18186 .39042 Mtetra
.732 .966 .937 r
.18186 .39042 .18684 .39072 .19358 .38641 .1886 .38618 Mtetra
.725 .967 .936 r
.1886 .38618 .19358 .38641 .20031 .38214 .19535 .38198 Mtetra
.717 .968 .935 r
.19535 .38198 .20031 .38214 .20705 .37792 .2021 .37782 Mtetra
.708 .969 .933 r
.2021 .37782 .20705 .37792 .21379 .37375 .20886 .37371 Mtetra
.698 .969 .931 r
.20886 .37371 .21379 .37375 .22054 .36964 .21562 .36965 Mtetra
.688 .968 .929 r
.21562 .36965 .22054 .36964 .22729 .36558 .22238 .36565 Mtetra
.677 .967 .927 r
.22238 .36565 .22729 .36558 .23404 .3616 .22915 .36171 Mtetra
.665 .965 .925 r
.22915 .36171 .23404 .3616 .24079 .35768 .23592 .35784 Mtetra
.653 .963 .922 r
.23592 .35784 .24079 .35768 .24755 .35384 .2427 .35404 Mtetra
.639 .96 .919 r
.2427 .35404 .24755 .35384 .25432 .35007 .24948 .35031 Mtetra
.626 .956 .915 r
.24948 .35031 .25432 .35007 .26108 .34638 .25627 .34665 Mtetra
.611 .952 .912 r
.25627 .34665 .26108 .34638 .26785 .34278 .26305 .34308 Mtetra
.596 .947 .908 r
.26305 .34308 .26785 .34278 .27463 .33926 .26985 .33959 Mtetra
.58 .942 .903 r
.26985 .33959 .27463 .33926 .28141 .33583 .27665 .33618 Mtetra
.564 .936 .899 r
.27665 .33618 .28141 .33583 .2882 .33249 .28346 .33286 Mtetra
.547 .929 .894 r
.28346 .33286 .2882 .33249 .29499 .32924 .29027 .32963 Mtetra
.53 .922 .889 r
.29027 .32963 .29499 .32924 .30179 .32608 .29709 .32648 Mtetra
.513 .914 .884 r
.29709 .32648 .30179 .32608 .3086 .32302 .30392 .32343 Mtetra
.495 .906 .879 r
.30392 .32343 .3086 .32302 .31542 .32006 .31075 .32048 Mtetra
.478 .897 .873 r
.31075 .32048 .31542 .32006 .32224 .3172 .3176 .31762 Mtetra
.46 .888 .868 r
.3176 .31762 .32224 .3172 .32907 .31443 .32445 .31485 Mtetra
.442 .879 .862 r
.32445 .31485 .32907 .31443 .33591 .31177 .33131 .31219 Mtetra
.424 .869 .857 r
.33131 .31219 .33591 .31177 .34277 .3092 .33819 .30962 Mtetra
.406 .859 .851 r
.33819 .30962 .34277 .3092 .34963 .30674 .34507 .30714 Mtetra
.389 .849 .846 r
.34507 .30714 .34963 .30674 .35651 .30437 .35197 .30477 Mtetra
.372 .84 .841 r
.35197 .30477 .35651 .30437 .36339 .30211 .35888 .30249 Mtetra
.355 .83 .836 r
.35888 .30249 .36339 .30211 .3703 .29995 .3658 .30031 Mtetra
.339 .82 .832 r
.3658 .30031 .3703 .29995 .37721 .29789 .37274 .29823 Mtetra
.323 .81 .828 r
.37274 .29823 .37721 .29789 .38414 .29593 .37969 .29624 Mtetra
.307 .8 .824 r
.37969 .29624 .38414 .29593 .39109 .29407 .38666 .29435 Mtetra
.293 .791 .821 r
.38666 .29435 .39109 .29407 .39806 .2923 .39365 .29255 Mtetra
.279 .782 .818 r
.39365 .29255 .39806 .2923 .40504 .29064 .40065 .29085 Mtetra
.266 .774 .816 r
.40065 .29085 .40504 .29064 .41204 .28906 .40768 .28923 Mtetra
.254 .766 .814 r
.40768 .28923 .41204 .28906 .41906 .28758 .41472 .28771 Mtetra
.242 .758 .813 r
.41472 .28771 .41906 .28758 .4261 .28619 .42178 .28627 Mtetra
.232 .751 .813 r
.42178 .28627 .4261 .28619 .43316 .28489 .42886 .28492 Mtetra
.222 .744 .813 r
.42886 .28492 .43316 .28489 .44024 .28367 .43597 .28365 Mtetra
.214 .738 .814 r
.43597 .28365 .44024 .28367 .44735 .28253 .44309 .28246 Mtetra
.207 .733 .816 r
.44309 .28246 .44735 .28253 .45447 .28148 .45025 .28134 Mtetra
.201 .729 .818 r
.45025 .28134 .45447 .28148 .46163 .2805 .45742 .2803 Mtetra
.196 .725 .822 r
.45742 .2803 .46163 .2805 .4688 .2796 .46462 .27933 Mtetra
.192 .722 .826 r
.46462 .27933 .4688 .2796 .47601 .27876 .47184 .27842 Mtetra
.19 .719 .831 r
.47184 .27842 .47601 .27876 .48324 .27799 .47909 .27758 Mtetra
.188 .718 .836 r
.47909 .27758 .48324 .27799 .49049 .27729 .48637 .27679 Mtetra
.189 .717 .843 r
.48637 .27679 .49049 .27729 .49778 .27663 .49368 .27606 Mtetra
.19 .717 .85 r
.49368 .27606 .49778 .27663 .50509 .27604 .50101 .27537 Mtetra
.193 .717 .857 r
.50101 .27537 .50509 .27604 .51243 .27548 .50837 .27473 Mtetra
.197 .719 .866 r
.50837 .27473 .51243 .27548 .5198 .27497 .51576 .27412 Mtetra
.203 .721 .875 r
.51576 .27412 .5198 .27497 .5272 .2745 .52318 .27354 Mtetra
.211 .724 .884 r
.52318 .27354 .5272 .2745 .53463 .27405 .53063 .273 Mtetra
.219 .727 .894 r
.53063 .273 .53463 .27405 .5421 .27363 .53811 .27247 Mtetra
.229 .731 .904 r
.53811 .27247 .5421 .27363 .54959 .27323 .54563 .27195 Mtetra
.241 .735 .914 r
.54563 .27195 .54959 .27323 .55711 .27283 .55317 .27144 Mtetra
.254 .74 .925 r
.55317 .27144 .55711 .27283 .56467 .27244 .56074 .27093 Mtetra
.268 .745 .935 r
.56074 .27093 .56467 .27244 .57226 .27204 .56835 .27041 Mtetra
.283 .75 .945 r
.56835 .27041 .57226 .27204 .57987 .27164 .57598 .26987 Mtetra
.3 .755 .954 r
.57598 .26987 .57987 .27164 .58752 .27121 .58365 .2693 Mtetra
.318 .761 .963 r
.58365 .2693 .58752 .27121 .59521 .27075 .59135 .26871 Mtetra
.336 .766 .972 r
.59135 .26871 .59521 .27075 .60292 .27026 .59908 .26807 Mtetra
.356 .771 .979 r
.59908 .26807 .60292 .27026 .61066 .26972 .60684 .26738 Mtetra
.376 .775 .986 r
.60684 .26738 .61066 .26972 .61844 .26912 .61462 .26663 Mtetra
.397 .779 .991 r
.61462 .26663 .61844 .26912 .62624 .26846 .62244 .26581 Mtetra
.418 .783 .995 r
.62244 .26581 .62624 .26846 .63408 .26772 .63029 .26491 Mtetra
.439 .786 .998 r
.63029 .26491 .63408 .26772 .64194 .26689 .63817 .26391 Mtetra
.46 .788 .999 r
.63817 .26391 .64194 .26689 .64983 .26597 .64607 .26282 Mtetra
.481 .789 .999 r
.64607 .26282 .64983 .26597 .65775 .26494 .654 .26161 Mtetra
.502 .79 .997 r
.654 .26161 .65775 .26494 .66569 .26379 .66195 .26028 Mtetra
.522 .79 .994 r
.66195 .26028 .66569 .26379 .67366 .26251 .66992 .25881 Mtetra
.541 .789 .99 r
.66992 .25881 .67366 .26251 .68165 .26108 .67792 .25719 Mtetra
.561 .788 .984 r
.67792 .25719 .68165 .26108 .68966 .2595 .68594 .25541 Mtetra
.579 .786 .977 r
.68594 .25541 .68966 .2595 .69769 .25775 .69398 .25345 Mtetra
.596 .783 .97 r
.69398 .25345 .69769 .25775 .70574 .25582 .70203 .25131 Mtetra
.613 .78 .961 r
.70203 .25131 .70574 .25582 .7138 .25369 .7101 .24897 Mtetra
.662 .777 .935 r
.0059 .48738 .01083 .49113 .0171 .48856 .01215 .485 Mtetra
.674 .79 .936 r
.01215 .485 .0171 .48856 .0234 .48581 .01844 .48242 Mtetra
.686 .802 .937 r
.01844 .48242 .0234 .48581 .02975 .48287 .02477 .47966 Mtetra
.696 .813 .937 r
.02477 .47966 .02975 .48287 .03614 .47977 .03114 .47673 Mtetra
.706 .824 .938 r
.03114 .47673 .03614 .47977 .04255 .47652 .03754 .47364 Mtetra
.715 .834 .938 r
.03754 .47364 .04255 .47652 .049 .47313 .04398 .47041 Mtetra
.722 .844 .939 r
.04398 .47041 .049 .47313 .05548 .4696 .05044 .46704 Mtetra
.729 .853 .939 r
.05044 .46704 .05548 .4696 .06199 .46595 .05694 .46355 Mtetra
.736 .862 .94 r
.05694 .46355 .06199 .46595 .06852 .4622 .06346 .45994 Mtetra
.741 .871 .94 r
.06346 .45994 .06852 .4622 .07507 .45834 .07001 .45623 Mtetra
.746 .879 .941 r
.07001 .45623 .07507 .45834 .08165 .4544 .07658 .45242 Mtetra
.75 .887 .941 r
.07658 .45242 .08165 .4544 .08824 .45037 .08317 .44853 Mtetra
.753 .894 .942 r
.08317 .44853 .08824 .45037 .09485 .44627 .08978 .44456 Mtetra
.756 .901 .942 r
.08978 .44456 .09485 .44627 .10148 .44212 .09641 .44053 Mtetra
.758 .908 .942 r
.09641 .44053 .10148 .44212 .10812 .43791 .10305 .43645 Mtetra
.759 .915 .943 r
.10305 .43645 .10812 .43791 .11478 .43365 .10971 .43231 Mtetra
.76 .921 .943 r
.10971 .43231 .11478 .43365 .12145 .42937 .11638 .42813 Mtetra
.76 .927 .943 r
.11638 .42813 .12145 .42937 .12813 .42505 .12306 .42393 Mtetra
.759 .932 .943 r
.12306 .42393 .12813 .42505 .13482 .42072 .12976 .4197 Mtetra
.758 .937 .943 r
.12976 .4197 .13482 .42072 .14152 .41637 .13646 .41545 Mtetra
.756 .942 .943 r
.13646 .41545 .14152 .41637 .14823 .41202 .14317 .4112 Mtetra
.753 .946 .943 r
.14317 .4112 .14823 .41202 .15494 .40767 .14989 .40694 Mtetra
.749 .95 .943 r
.14989 .40694 .15494 .40767 .16166 .40333 .15662 .40269 Mtetra
.745 .954 .943 r
.15662 .40269 .16166 .40333 .16839 .399 .16336 .39845 Mtetra
.741 .957 .942 r
.16336 .39845 .16839 .399 .17512 .3947 .1701 .39422 Mtetra
.735 .96 .942 r
.1701 .39422 .17512 .3947 .18186 .39042 .17685 .39002 Mtetra
.729 .962 .941 r
.17685 .39002 .18186 .39042 .1886 .38618 .18361 .38585 Mtetra
.722 .964 .94 r
.18361 .38585 .1886 .38618 .19535 .38198 .19037 .38172 Mtetra
.714 .965 .939 r
.19037 .38172 .19535 .38198 .2021 .37782 .19713 .37762 Mtetra
.706 .966 .937 r
.19713 .37762 .2021 .37782 .20886 .37371 .2039 .37357 Mtetra
.696 .966 .936 r
.2039 .37357 .20886 .37371 .21562 .36965 .21068 .36957 Mtetra
.686 .966 .934 r
.21068 .36957 .21562 .36965 .22238 .36565 .21745 .36563 Mtetra
.676 .965 .932 r
.21745 .36563 .22238 .36565 .22915 .36171 .22424 .36174 Mtetra
.664 .964 .929 r
.22424 .36174 .22915 .36171 .23592 .35784 .23103 .35791 Mtetra
.652 .962 .926 r
.23103 .35791 .23592 .35784 .2427 .35404 .23782 .35415 Mtetra
.64 .959 .923 r
.23782 .35415 .2427 .35404 .24948 .35031 .24461 .35046 Mtetra
.626 .955 .92 r
.24461 .35046 .24948 .35031 .25627 .34665 .25142 .34684 Mtetra
.612 .952 .917 r
.25142 .34684 .25627 .34665 .26305 .34308 .25822 .3433 Mtetra
.598 .947 .913 r
.25822 .3433 .26305 .34308 .26985 .33959 .26504 .33984 Mtetra
.582 .942 .909 r
.26504 .33984 .26985 .33959 .27665 .33618 .27186 .33646 Mtetra
.567 .936 .905 r
.27186 .33646 .27665 .33618 .28346 .33286 .27868 .33316 Mtetra
.551 .93 .9 r
.27868 .33316 .28346 .33286 .29027 .32963 .28551 .32994 Mtetra
.534 .923 .895 r
.28551 .32994 .29027 .32963 .29709 .32648 .29235 .32681 Mtetra
.518 .916 .89 r
.29235 .32681 .29709 .32648 .30392 .32343 .2992 .32378 Mtetra
.501 .908 .886 r
.2992 .32378 .30392 .32343 .31075 .32048 .30606 .32083 Mtetra
.484 .9 .88 r
.30606 .32083 .31075 .32048 .3176 .31762 .31292 .31797 Mtetra
.467 .891 .875 r
.31292 .31797 .3176 .31762 .32445 .31485 .31979 .31521 Mtetra
.45 .882 .87 r
.31979 .31521 .32445 .31485 .33131 .31219 .32668 .31254 Mtetra
.432 .873 .865 r
.32668 .31254 .33131 .31219 .33819 .30962 .33357 .30996 Mtetra
.415 .864 .86 r
.33357 .30996 .33819 .30962 .34507 .30714 .34048 .30748 Mtetra
.399 .855 .856 r
.34048 .30748 .34507 .30714 .35197 .30477 .3474 .30509 Mtetra
.382 .846 .851 r
.3474 .30509 .35197 .30477 .35888 .30249 .35433 .3028 Mtetra
.366 .836 .847 r
.35433 .3028 .35888 .30249 .3658 .30031 .36128 .3006 Mtetra
.351 .827 .843 r
.36128 .3006 .3658 .30031 .37274 .29823 .36824 .29849 Mtetra
.336 .818 .839 r
.36824 .29849 .37274 .29823 .37969 .29624 .37521 .29648 Mtetra
.321 .809 .836 r
.37521 .29648 .37969 .29624 .38666 .29435 .3822 .29456 Mtetra
.307 .8 .833 r
.3822 .29456 .38666 .29435 .39365 .29255 .38921 .29273 Mtetra
.294 .792 .831 r
.38921 .29273 .39365 .29255 .40065 .29085 .39624 .29099 Mtetra
.282 .784 .829 r
.39624 .29099 .40065 .29085 .40768 .28923 .40328 .28933 Mtetra
.271 .777 .828 r
.40328 .28933 .40768 .28923 .41472 .28771 .41035 .28776 Mtetra
.26 .77 .827 r
.41035 .28776 .41472 .28771 .42178 .28627 .41743 .28628 Mtetra
.25 .763 .827 r
.41743 .28628 .42178 .28627 .42886 .28492 .42454 .28487 Mtetra
.242 .757 .828 r
.42454 .28487 .42886 .28492 .43597 .28365 .43166 .28355 Mtetra
.234 .752 .83 r
.43166 .28355 .43597 .28365 .44309 .28246 .43881 .2823 Mtetra
.228 .747 .832 r
.43881 .2823 .44309 .28246 .45025 .28134 .44598 .28112 Mtetra
.222 .743 .835 r
.44598 .28112 .45025 .28134 .45742 .2803 .45318 .28001 Mtetra
.218 .74 .838 r
.45318 .28001 .45742 .2803 .46462 .27933 .4604 .27897 Mtetra
.215 .737 .843 r
.4604 .27897 .46462 .27933 .47184 .27842 .46765 .27799 Mtetra
.214 .735 .848 r
.46765 .27799 .47184 .27842 .47909 .27758 .47492 .27707 Mtetra
.213 .734 .854 r
.47492 .27707 .47909 .27758 .48637 .27679 .48222 .2762 Mtetra
.214 .733 .86 r
.48222 .2762 .48637 .27679 .49368 .27606 .48954 .27538 Mtetra
.217 .733 .867 r
.48954 .27538 .49368 .27606 .50101 .27537 .4969 .2746 Mtetra
.22 .734 .875 r
.4969 .2746 .50101 .27537 .50837 .27473 .50428 .27386 Mtetra
.225 .736 .883 r
.50428 .27386 .50837 .27473 .51576 .27412 .51169 .27316 Mtetra
.232 .738 .892 r
.51169 .27316 .51576 .27412 .52318 .27354 .51913 .27248 Mtetra
.24 .741 .901 r
.51913 .27248 .52318 .27354 .53063 .273 .5266 .27183 Mtetra
.249 .744 .911 r
.5266 .27183 .53063 .273 .53811 .27247 .5341 .27119 Mtetra
.26 .747 .92 r
.5341 .27119 .53811 .27247 .54563 .27195 .54163 .27055 Mtetra
.272 .752 .93 r
.54163 .27055 .54563 .27195 .55317 .27144 .54919 .26992 Mtetra
.285 .756 .94 r
.54919 .26992 .55317 .27144 .56074 .27093 .55678 .26929 Mtetra
.3 .76 .949 r
.55678 .26929 .56074 .27093 .56835 .27041 .56441 .26864 Mtetra
.315 .765 .958 r
.56441 .26864 .56835 .27041 .57598 .26987 .57206 .26796 Mtetra
.332 .769 .967 r
.57206 .26796 .57598 .26987 .58365 .2693 .57974 .26726 Mtetra
.349 .774 .974 r
.57974 .26726 .58365 .2693 .59135 .26871 .58746 .26652 Mtetra
.368 .778 .981 r
.58746 .26652 .59135 .26871 .59908 .26807 .5952 .26574 Mtetra
.387 .782 .987 r
.5952 .26574 .59908 .26807 .60684 .26738 .60298 .26489 Mtetra
.406 .785 .992 r
.60298 .26489 .60684 .26738 .61462 .26663 .61078 .26399 Mtetra
.426 .788 .996 r
.61078 .26399 .61462 .26663 .62244 .26581 .61861 .263 Mtetra
.446 .79 .998 r
.61861 .263 .62244 .26581 .63029 .26491 .62647 .26193 Mtetra
.466 .792 .999 r
.62647 .26193 .63029 .26491 .63817 .26391 .63436 .26077 Mtetra
.486 .793 .999 r
.63436 .26077 .63817 .26391 .64607 .26282 .64227 .25949 Mtetra
.506 .793 .997 r
.64227 .25949 .64607 .26282 .654 .26161 .65021 .2581 Mtetra
.526 .793 .994 r
.65021 .2581 .654 .26161 .66195 .26028 .65818 .25658 Mtetra
.544 .792 .99 r
.65818 .25658 .66195 .26028 .66992 .25881 .66616 .25492 Mtetra
.563 .79 .984 r
.66616 .25492 .66992 .25881 .67792 .25719 .67417 .2531 Mtetra
.58 .787 .978 r
.67417 .2531 .67792 .25719 .68594 .25541 .68219 .25112 Mtetra
.597 .784 .97 r
.68219 .25112 .68594 .25541 .69398 .25345 .69024 .24895 Mtetra
.613 .781 .961 r
.69024 .24895 .69398 .25345 .70203 .25131 .6983 .2466 Mtetra
.629 .777 .952 r
.6983 .2466 .70203 .25131 .7101 .24897 .70637 .24404 Mtetra
.648 .764 .934 r
.00098 .48342 .0059 .48738 .01215 .485 .00721 .48122 Mtetra
.661 .777 .935 r
.00721 .48122 .01215 .485 .01844 .48242 .01348 .47883 Mtetra
.673 .79 .936 r
.01348 .47883 .01844 .48242 .02477 .47966 .01979 .47625 Mtetra
.684 .802 .938 r
.01979 .47625 .02477 .47966 .03114 .47673 .02614 .4735 Mtetra
.695 .813 .938 r
.02614 .4735 .03114 .47673 .03754 .47364 .03253 .47058 Mtetra
.704 .824 .939 r
.03253 .47058 .03754 .47364 .04398 .47041 .03895 .46751 Mtetra
.712 .834 .94 r
.03895 .46751 .04398 .47041 .05044 .46704 .0454 .4643 Mtetra
.719 .844 .941 r
.0454 .4643 .05044 .46704 .05694 .46355 .05189 .46097 Mtetra
.726 .853 .941 r
.05189 .46097 .05694 .46355 .06346 .45994 .0584 .45751 Mtetra
.732 .862 .942 r
.0584 .45751 .06346 .45994 .07001 .45623 .06494 .45395 Mtetra
.737 .871 .943 r
.06494 .45395 .07001 .45623 .07658 .45242 .0715 .45028 Mtetra
.741 .879 .943 r
.0715 .45028 .07658 .45242 .08317 .44853 .07809 .44653 Mtetra
.745 .887 .944 r
.07809 .44653 .08317 .44853 .08978 .44456 .0847 .4427 Mtetra
.748 .894 .944 r
.0847 .4427 .08978 .44456 .09641 .44053 .09132 .4388 Mtetra
.751 .901 .945 r
.09132 .4388 .09641 .44053 .10305 .43645 .09796 .43484 Mtetra
.752 .908 .945 r
.09796 .43484 .10305 .43645 .10971 .43231 .10462 .43082 Mtetra
.753 .915 .946 r
.10462 .43082 .10971 .43231 .11638 .42813 .11129 .42676 Mtetra
.753 .921 .946 r
.11129 .42676 .11638 .42813 .12306 .42393 .11798 .42267 Mtetra
.753 .926 .946 r
.11798 .42267 .12306 .42393 .12976 .4197 .12467 .41855 Mtetra
.752 .932 .946 r
.12467 .41855 .12976 .4197 .13646 .41545 .13138 .41441 Mtetra
.75 .937 .947 r
.13138 .41441 .13646 .41545 .14317 .4112 .1381 .41025 Mtetra
.748 .941 .947 r
.1381 .41025 .14317 .4112 .14989 .40694 .14483 .40609 Mtetra
.745 .946 .947 r
.14483 .40609 .14989 .40694 .15662 .40269 .15157 .40193 Mtetra
.741 .95 .946 r
.15157 .40193 .15662 .40269 .16336 .39845 .15831 .39777 Mtetra
.737 .953 .946 r
.15831 .39777 .16336 .39845 .1701 .39422 .16506 .39363 Mtetra
.731 .956 .945 r
.16506 .39363 .1701 .39422 .17685 .39002 .17182 .38951 Mtetra
.726 .959 .945 r
.17182 .38951 .17685 .39002 .18361 .38585 .17859 .38542 Mtetra
.719 .961 .944 r
.17859 .38542 .18361 .38585 .19037 .38172 .18536 .38135 Mtetra
.712 .962 .943 r
.18536 .38135 .19037 .38172 .19713 .37762 .19213 .37733 Mtetra
.703 .963 .942 r
.19213 .37733 .19713 .37762 .2039 .37357 .19892 .37334 Mtetra
.695 .964 .94 r
.19892 .37334 .2039 .37357 .21068 .36957 .2057 .3694 Mtetra
.685 .964 .938 r
.2057 .3694 .21068 .36957 .21745 .36563 .2125 .36551 Mtetra
.675 .963 .936 r
.2125 .36551 .21745 .36563 .22424 .36174 .2193 .36167 Mtetra
.664 .962 .934 r
.2193 .36167 .22424 .36174 .23103 .35791 .2261 .35789 Mtetra
.652 .96 .931 r
.2261 .35789 .23103 .35791 .23782 .35415 .23291 .35418 Mtetra
.64 .957 .929 r
.23291 .35418 .23782 .35415 .24461 .35046 .23972 .35053 Mtetra
.627 .954 .926 r
.23972 .35053 .24461 .35046 .25142 .34684 .24654 .34695 Mtetra
.614 .951 .922 r
.24654 .34695 .25142 .34684 .25822 .3433 .25336 .34344 Mtetra
.6 .947 .919 r
.25336 .34344 .25822 .3433 .26504 .33984 .26019 .34 Mtetra
.585 .942 .915 r
.26019 .34 .26504 .33984 .27186 .33646 .26703 .33665 Mtetra
.571 .937 .911 r
.26703 .33665 .27186 .33646 .27868 .33316 .27388 .33337 Mtetra
.555 .931 .907 r
.27388 .33337 .27868 .33316 .28551 .32994 .28073 .33017 Mtetra
.539 .924 .902 r
.28073 .33017 .28551 .32994 .29235 .32681 .28759 .32706 Mtetra
.523 .918 .898 r
.28759 .32706 .29235 .32681 .2992 .32378 .29445 .32403 Mtetra
.507 .91 .893 r
.29445 .32403 .2992 .32378 .30606 .32083 .30133 .32109 Mtetra
.491 .903 .889 r
.30133 .32109 .30606 .32083 .31292 .31797 .30821 .31824 Mtetra
.475 .895 .884 r
.30821 .31824 .31292 .31797 .31979 .31521 .31511 .31548 Mtetra
.458 .887 .879 r
.31511 .31548 .31979 .31521 .32668 .31254 .32201 .31281 Mtetra
.442 .878 .875 r
.32201 .31281 .32668 .31254 .33357 .30996 .32893 .31023 Mtetra
.426 .87 .87 r
.32893 .31023 .33357 .30996 .34048 .30748 .33586 .30773 Mtetra
.41 .861 .866 r
.33586 .30773 .34048 .30748 .3474 .30509 .3428 .30533 Mtetra
.394 .852 .862 r
.3428 .30533 .3474 .30509 .35433 .3028 .34975 .30302 Mtetra
.379 .843 .858 r
.34975 .30302 .35433 .3028 .36128 .3006 .35672 .3008 Mtetra
.364 .835 .855 r
.35672 .3008 .36128 .3006 .36824 .29849 .3637 .29867 Mtetra
.35 .826 .851 r
.3637 .29867 .36824 .29849 .37521 .29648 .3707 .29663 Mtetra
.336 .818 .849 r
.3707 .29663 .37521 .29648 .3822 .29456 .37771 .29468 Mtetra
.323 .81 .846 r
.37771 .29468 .3822 .29456 .38921 .29273 .38474 .29282 Mtetra
.311 .802 .844 r
.38474 .29282 .38921 .29273 .39624 .29099 .39179 .29104 Mtetra
.3 .795 .843 r
.39179 .29104 .39624 .29099 .40328 .28933 .39886 .28934 Mtetra
.289 .788 .842 r
.39886 .28934 .40328 .28933 .41035 .28776 .40595 .28773 Mtetra
.279 .782 .842 r
.40595 .28773 .41035 .28776 .41743 .28628 .41305 .28619 Mtetra
.27 .776 .843 r
.41305 .28619 .41743 .28628 .42454 .28487 .42018 .28473 Mtetra
.263 .77 .844 r
.42018 .28473 .42454 .28487 .43166 .28355 .42733 .28335 Mtetra
.256 .765 .846 r
.42733 .28335 .43166 .28355 .43881 .2823 .4345 .28204 Mtetra
.25 .761 .848 r
.4345 .28204 .43881 .2823 .44598 .28112 .44169 .2808 Mtetra
.246 .758 .852 r
.44169 .2808 .44598 .28112 .45318 .28001 .44891 .27962 Mtetra
.242 .755 .856 r
.44891 .27962 .45318 .28001 .4604 .27897 .45615 .27851 Mtetra
.24 .752 .86 r
.45615 .27851 .4604 .27897 .46765 .27799 .46342 .27745 Mtetra
.239 .751 .866 r
.46342 .27745 .46765 .27799 .47492 .27707 .47071 .27645 Mtetra
.24 .75 .872 r
.47071 .27645 .47492 .27707 .48222 .2762 .47803 .2755 Mtetra
.242 .75 .878 r
.47803 .2755 .48222 .2762 .48954 .27538 .48538 .27459 Mtetra
.245 .75 .885 r
.48538 .27459 .48954 .27538 .4969 .2746 .49276 .27372 Mtetra
.249 .751 .893 r
.49276 .27372 .4969 .2746 .50428 .27386 .50016 .27288 Mtetra
.255 .753 .901 r
.50016 .27288 .50428 .27386 .51169 .27316 .50759 .27208 Mtetra
.262 .755 .91 r
.50759 .27208 .51169 .27316 .51913 .27248 .51505 .27129 Mtetra
.27 .757 .918 r
.51505 .27129 .51913 .27248 .5266 .27183 .52254 .27053 Mtetra
.28 .76 .927 r
.52254 .27053 .5266 .27183 .5341 .27119 .53006 .26977 Mtetra
.291 .763 .936 r
.53006 .26977 .5341 .27119 .54163 .27055 .53761 .26902 Mtetra
.304 .767 .945 r
.53761 .26902 .54163 .27055 .54919 .26992 .54519 .26827 Mtetra
.317 .771 .954 r
.54519 .26827 .54919 .26992 .55678 .26929 .5528 .2675 Mtetra
.332 .774 .962 r
.5528 .2675 .55678 .26929 .56441 .26864 .56044 .26672 Mtetra
.347 .778 .97 r
.56044 .26672 .56441 .26864 .57206 .26796 .56811 .26591 Mtetra
.364 .782 .977 r
.56811 .26591 .57206 .26796 .57974 .26726 .57581 .26507 Mtetra
.381 .785 .984 r
.57581 .26507 .57974 .26726 .58746 .26652 .58354 .26418 Mtetra
.399 .788 .989 r
.58354 .26418 .58746 .26652 .5952 .26574 .5913 .26324 Mtetra
.417 .791 .993 r
.5913 .26324 .5952 .26574 .60298 .26489 .59909 .26224 Mtetra
.436 .793 .997 r
.59909 .26224 .60298 .26489 .61078 .26399 .60691 .26117 Mtetra
.455 .795 .999 r
.60691 .26117 .61078 .26399 .61861 .263 .61475 .26002 Mtetra
.474 .796 .999 r
.61475 .26002 .61861 .263 .62647 .26193 .62263 .25878 Mtetra
.493 .796 .999 r
.62263 .25878 .62647 .26193 .63436 .26077 .63052 .25743 Mtetra
.512 .796 .997 r
.63052 .25743 .63436 .26077 .64227 .25949 .63845 .25598 Mtetra
.53 .795 .994 r
.63845 .25598 .64227 .25949 .65021 .2581 .6464 .2544 Mtetra
.548 .794 .99 r
.6464 .2544 .65021 .2581 .65818 .25658 .65437 .25268 Mtetra
.566 .792 .984 r
.65437 .25268 .65818 .25658 .66616 .25492 .66237 .25082 Mtetra
.583 .789 .977 r
.66237 .25082 .66616 .25492 .67417 .2531 .67038 .2488 Mtetra
.599 .786 .97 r
.67038 .2488 .67417 .2531 .68219 .25112 .67841 .24661 Mtetra
.614 .782 .961 r
.67841 .24661 .68219 .25112 .69024 .24895 .68646 .24424 Mtetra
.629 .778 .952 r
.68646 .24424 .69024 .24895 .6983 .2466 .69453 .24166 Mtetra
.643 .773 .942 r
.69453 .24166 .6983 .2466 .70637 .24404 .7026 .23888 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.1578 .2079 m
.1624 .21257 L
s
[(-5)] .14858 .19855 .98554 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.54221 .05738 m
.54611 .06265 L
s
[(5)] .53441 .04682 .73893 1 Mshowa
.125 Mabswid
.19381 .1938 m
.19654 .19664 L
s
.23033 .1795 m
.23302 .18237 L
s
.26737 .16499 m
.27003 .1679 L
s
.30495 .15028 m
.30756 .15322 L
s
.38174 .12021 m
.38426 .12323 L
s
.42097 .10485 m
.42346 .1079 L
s
.46079 .08926 m
.46322 .09235 L
s
.5012 .07344 m
.50358 .07656 L
s
.12228 .22181 m
.12508 .22458 L
s
.08725 .23552 m
.09008 .23826 L
s
.0527 .24905 m
.05557 .25175 L
s
.58384 .04107 m
.58613 .04428 L
s
.62611 .02452 m
.62834 .02776 L
s
.66902 .00772 m
.6712 .011 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[80]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003obOooool2
o`0005Gooooo0036ooooo`?o000000?oooooo`000?ooool0E?ooool00<Cooooo0_l00004ooooo`;o
0000E?ooool00<7ooooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo000005?ooooo
002nooooo`?o00002Oooool3o`0005?ooooo002Kooooo`?o00007_ooool2o`0000cooooo00Co0000
oooooooooooo0000D_ooool009[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o00003_oo
ool01Ol0003ooooooooooooooooo0000057ooooo002Nooooo`03o`000?oooooooooo01Kooooo0ol0
000@ooooo`05o`000?ooooooooooooooool00000DOooool009kooooo00?o0000ooooooooool04ooo
ool3o`0001?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1>ooooo`00V_ooool4
o`0001Cooooo0_l0000Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool0
09[ooooo00?o0000ooooooooool04_ooool3o`0001Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1=ooooo`00V_ooool5o`0000gooooo0ol0000Kooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0C?ooool00:[ooooo0_l00002ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool00oooool2o`0004gooooo002Wooooo`?o00008Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo04_ooooo002Uooooo`;o00009?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04[ooooo002Rooooo`?o00009_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo04Wooooo002Pooooo`?o0000:?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo04Wooooo002Mooooo`?o00000oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0B?ooool009_ooooo0_l0000^ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0B?ooool009Sooooo0ol0000`ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Aoooool009Gooooo0ol0000cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0A_ooool009?ooooo0_l00002ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool02?ooool2o`0004Sooooo002@ooooo`?o0000>?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo0ol0000gooooo`00S_ooool2o`0003_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
=_ooool008_ooooo0ol0000mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00ooo
ool5o`0000Gooooo00?o0000ooooooooool0=?ooool008Wooooo0_l000000ooooooo0000ooooo`0m
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0d
ooooo`00I_ooool2o`0001kooooo0ol00012ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01oooool4o`0003Oooooo001Uooooo`04o`000?ooooooooooo`0001[ooooo0ol00015oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0hoooo
o`00IOooool01?l0003oooooooooool0000Hooooo`;o0000B?ooool00ol0003oooooooooo`0=oooo
o`;o00002?ooool5o`0003Kooooo001Uooooo`04o`000?ooooooooooo`0001Gooooo0ol000000ooo
oooo0000ooooo`17ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000@_ooool0
06Gooooo00Co0000oooooooooooo00004oooool2o`0004gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`10ooooo`00IOooool01?l0003oooooooooool0000@ooooo`?o0000Coooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03oooooo001Vooooo`;o00003oooool2o`00
05;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0nooooo`00M?ooool4o`0005?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0nooooo`00LOooool3o`0005Sooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0mooooo`00Koooool2o`0005_ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0looooo`00K?ooool3o`0005gooooo00?o0000
ooooooooool04Oooool2o`0003kooooo001Zooooo`?o0000Goooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo03_ooooo001Wooooo`?o00000oooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0>_ooool006Gooooo0_l0001Uooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0>_ooool006;ooooo0ol0001Wooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0>Oooool0063ooooo0_l0001Zooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0>?ooool005gooooo0ol00002ooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0hooooo`00F_ooool3o`0006oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0gooooo`00F?ooool2o`0007;ooooo
00?o0000ooooooooool05_ooool00ol0003oooooo`00000hooooo`00EOooool3o`0007Cooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0fooooo`00<_ooool3o`0001kooooo0_l00003
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0e
ooooo`00<Oooool01Ol0003ooooooooooooooooo000001[ooooo0ol0001iooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0=Oooool002_ooooo1Ol00005ooooo`03o`000?oooooooooo
01Kooooo0_l0001looooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0=?ooool003Go
oooo00?o0000ooooooooool04oooool4o`0007gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0cooooo`00<Oooool4o`0001?ooooo0ol00021ooooo`03o`000?oooooooooo01_ooooo
0_l0000dooooo`00<Oooool00ol0003oooooooooo`0Booooo`;o0000Q?ooool00ol0003ooooooooo
o`0Kooooo`;o0000=?ooool0037ooooo1Ol0000=ooooo`?o0000Q_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo037ooooo0011ooooo`Co0000Qoooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo037ooooo000nooooo`?o0000Roooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo033ooooo000looooo`;o0000S_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo02oooooo000iooooo`?o0000T?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02oooooo000fooooo`?o000000?oooooo`000?ooool0TOooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo02kooooo000dooooo`;o00001Oooool00ol0003oooooooooo`2?oooo
o`03o`000?oooooooooo01kooooo0ol0000_ooooo`00<Oooool3o`0009Wooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`06ooooo`;o00009Oooool002oooooo0_l0002Looooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Tooooo`00
;?ooool3o`0000;ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00009?ooool002[ooooo0_l0002Qooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000Tooooo`00
9oooool3o`000:?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0002Cooooo000Uooooo`;o0000Y_ooool00ol0003oooooooooo`0Sooooo`;o0000
0oooool01?l0003oooooooooool0000Tooooo`008_ooool3o`0000;ooooo00?o0000ooooooooool0
Xoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo000000Cooooo0_l0000Uooooo`007ooo
ool3o`000:[ooooo00?oY<Gao`000?ooool09_ooool00ol0003oooooooooo`0Xooooo`007Oooool2
o`000:Wooooo00CoWLSfoj77lonQao?oXLOc0_l0000Xooooo`03o`000?oooooooooo02Oooooo000J
ooooo`Go0000YOooool01OnEbO[oVLWhoiW9n?nIbOSoWLSf00?o000000?oW<Ofo`000?nQa_<09ooo
ool00ol0003oooooooooo`0Wooooo`006Oooool2o`000:Kooooo0on@b_/2oiG9nP?o00000_nHb?P0
1OnLaoKoV<ShoiS8n?l0003oW<Of02Oooooo00?o0000ooooooooool09_ooool001Wooooo0ol0002O
ooooo`;oPl_o0_n7boh2ohc;o@;oT<[k0ol000001?n@b__oU<Wjoho9non?bO/2oiC9nP05oiS8n?nC
b?[oV<Sho`000?nHb?P09oooool00ol0003oooooooooo`0Uooooo`006Oooool01?l0003ooooooooo
ool0002Jooooo`;oNL_o0_mnbol00on3boooO<_oogc;o`02oh7;o`?o000000?oRl[mohG:o_n5b_h0
0_n:bOd00on?bO_oRLWmohW9o@02oho9n`;oTlSj00?oV<Sho`000?nCb?T09Oooool2o`0002Oooooo
000Aooooo`;o00001_ooool01Ol0003ooooooooooooooooo0000093ooooo0_mVbOd2of[:oP;oKl_o
0_mdbol2ofg9oP;oL/[o0_mgb_l01Omlbooo0000o`000?l0003oNlWo00;oP<[o0_n5b_h2ogo9o`;o
Q<Wn00?oRLWmohC8o_n4b?h00_n9b?d2oho8n`03o`000?n?b?_oSlSk02Kooooo00?o0000oooooooo
ool09?ooool0013ooooo00Co0000oooooooooooo00001?ooool2o`0000Cooooo00?o0000oooooooo
ool0QOooool2oeC6mP;oF<Oh00?oGLSjoeC4momDa?L00_mIa_T2oek7n`;oHlSl0_mWb?d2of36o0;o
ILOm00GoJlSno`000?l0003o0000ofS7oP02ofk7o`;oM<So00?oNLWoog?7oomcaol00omib?l2ogk8
oP03ohC8o_mnaokoO/On00;oQ<Sn0_n9b?`00ol0003oRLOlohW7o00Vooooo`03o`000?oooooooooo
02?ooooo000@ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1jooooo`;oAL7[0_m7`^d00om:`noo@[o[od:oj`02odG0kP03odS1l?m1_Nco@Kg/
00;oA;k_0_m8_o42odc1m003oe72m_m9__?oBKkc00;oC/3f0_mC`_P2oeS3nP?o000000?oE/7ioe_3
nomK`o/00_mQa?d2ofO5oP;oKLKo00?oLlOoofc5o_m/aOh00omba_l2ogS7o`03ogk7o_mha_ooN<Ko
00;oO/On0_n4aod00ol0003oQ<KmohC6o@0Uooooo`03o`000?oooooooooo02?ooooo000@ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1^oooo
o`?o?KoP00?o?[oRocNkgOlg^md00_lh^ml01?li_>;o<[SMoc:hgOlc^=l2obfdf`;o;[CM00?o<;GP
obVag?lY/M`00_l//]h2objch@;o<KCT0_le]^L2ocRgjP03ocfikOle]NWo=KGY00;o>KO/0_ln^>l2
o`000003od>jl_m8_?GoB;ce00;oC[kg0_mD`?T2oe[1n`03of33oOmH`?_oF<3k00;oGl;m0_mU`oh3
of_4oP;oL/Go00?oN<Koog;4oomba?l00_mhaOl2ogk6oP03o`000?moaOkoOlGn02Gooooo00?o0000
ooooooooool08_ooool0013ooooo00Co0000oooooooooooo00001?ooool2o`0000Oooooo00?o0000
ooooooooool0Ioooool2ocg0g0;o=kcG00?o=[cIoc2he?lZ]=000_lU/<`01OlT[lgo7jc:oaZXa_lJ
Z<Ko6ZS800;o5JC500?o5:C6oa2Q`ol@XL<00_l@X<D2oa2PaP;o4:380_lAX</2oa:Qc@;o4j7?0_lE
X]800olGXmGo8:WKob2Yf`02ob>[g`04obN/h_l0003o0000o`0000;o<;3X0old/^`2ocZdk`;o?kOb
0_m5^O@2od^km`;oDKgi0_mH_o/2oek1o@;oIL;n0_m[`oh2ofG1oP;oJl?n0_mba?l00omhaOko0000
ogo5oP02ogW4oRCooooo00?o0000ooooooooool08_ooool0013ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0_m1`mP01Olo`]Wo>[oD
ocBkd?l_^<go:kC900;o9k;600?o8jo3ob2]`OlLZKd00_lLZ[h01olLZ[oo7:[1obB_b?lT[lSo7jc7
ob2]bOlR[/`00_lT[ll01?lOZlko8JcAoabXcolLZ<l2oaNTc@;o4Z7<0_l=WLX02?l9V/Wo19K5o`BF
aOl0T<7o08joo`2=__l0S;ko08o10_l0TL@3o`000005o`^Icol=Vm;o5J3HoaFPf?lIX]/00_lSZ>82
obNZi@?o;:cY0_la[n`2ocNak`;o?KCb0_m3]_D2odZhm`;oD;_j0_mG_O/3oejno@;oIL3n0_m/`_h0
0omb`oko0000ogW4oP02og?2oRCooooo00?o0000ooooooooool08Oooool0017ooooo0_l00005oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F_ooool00om5a]Oo?l?Coc_0d002ocNm
c00:oc:jbOl]]/?o:kC2obbe`_l[]<;o<;S6oc6iaolb^LWo>l3@ocg1d`;o@<?F00Ko>KkDocc0f?lo
`]_o@/?NodG5h_lo`N02od;2i004ocbnh_lo_nKo?koVocVki0;o?KgW00?o=kSUoc2dhol`]><00_l[
/>42obF/g`;o7jOM0_lJY=/2o`jKe0?o000000?o08c7o`2:aOl0R<<00_l0Ql801_l0RlGo08k8o`6A
c?l1TLco0i;?o`ZGd`;o4YcI00Co5YkMob2UholPYN?o8:GS0_lUYnH00olZZN[o=k3`ocN`l002ocfb
lP;o@kGe0_m:]oP2oe6jnP?oF;cl0_mN__d2ofJooP03ofg1o_l0003oLl;n00;oK/7n8_ooool3o`00
02;ooooo000Gooooo`;o00002oooool00ol0003oooooooooo`1Cooooo`0Eodc;eom8b=CoA<K@odC6
d?m0`lgo?<7;ocZob?li_/Ko=kg5ocJlaOlj_lOo@LC<od;5cOm4a/ooALOBodO8e?m:bMOoCL_Joe3=
g_mCc^7oE]3T00;oF]7X00KoDlgVoeO?jOmJd>goF]3]oe?<jomGc^l2oe_?lP05oeC;l?mIc??oD/Sb
oe;8l_m;a?000_m?a?<2odW0l@03od>ll?ll^>ko?;S^00;o=[C/0_l`/>X3o`000004ob2Ti?lHWmoo
69oOoa>Kg@;o39KH00_o29?Go`:?dol0S<oo08W<o`27bOl0QLOo08G5o`26a_l0R<So08_;o`2>c`02
o`FCd`03o`VDe_lAV]_o6Z3Q00;o6Z3Q00?o7j;UobZXjolZZ>/00_l`Znh2ocN^l@;o?K7d0_m4/oH0
0om;]_WoF;_loeRko002oe:hn`04oeVko?l0003oHKgmof6mo@;oJ;kn8oooool00ol0003ooooooooo
o`0Pooooo`005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04kooooo00WoD/oH
odk<eOm>c=GoBl[BodO8com4a/coA<K:od;4bOm1a<P00_m5a/X01_m=c<ooC/gAoe3>domBcmKoG]KM
of7Gh0;oI=WS00GoGMGRof3FiOmTf>SoImW[of_JkP02ofkKl@04ofSHl?m/fO?oKm[eofWFm0;oKMOg
00KoI]?fof[Dn?mZe?SoHm3gofO@nOmQcOP2ofC=nP;oG/Wi0_mHa_P01?mA`_OoEL;iodnnn?m?__P3
o`000003od>gm?lm/_?o=joa00;o;J[/0_lXY^/01OlSX^Wo6YgToaZMi?lFV^;o3YGM00;o297I00_o
1HkHo`2;e?l0R=7o08K>o`24c?l0Pl[o08C9o`26b_l0R<co08_?o`:?d`02o`VDf003o`fFfolFVn3o
5Y_P00;o6ikT0_lUY>T00ol[Yngo=jgbocN]lP02ocj`m0;oAK?g0_m<]OT2oe>hn`03o`000?mK^_co
Fk[l00;oH[cm8oooool00ol0003oooooooooo`0Oooooo`005oooool2o`0000gooooo00?o0000oooo
ooooool0BOooool2oeWCf@0FoeKAe_mBcm?oClgAodg;com=c<goC<_<od_:bom@cLgoD<k>oe7>comI
dm?oFmCEoegEf?mOem[oH]SLofCIgomWfn;oJ]cUofkNj?magn_oM>3^ogSQl0;oNn;c00KoMMobogWO
mOmlh?OoO>3gogKMm_migOT2oggMnP03ogOJn_mjf_coM=Ok00;oMmOm00GoLMClogGCoOmedogoKm3m
ofS=o002ofc=o@;oI/Wm00CoGlKlo`000?l0003o00000_mG__/2oe6knP;oBkOh00CoAK?god2`mOlf
Zo;o=Z_b0_laYo002?l/Y>ko8YoZob:Oj_lNW>So5YSToa:Dh_l;T=ko1HgJ0_l0RMH00ol0QmKo08GB
o`22c@03o`22c005o`24cOl0Q/oo08SAo`2<e?l6T=P00_l>UMd01OlBV>3o79gUoabMiOlLWNGo8Z3X
00;o;JK^0_lcZO400olj[??oAk;hodNbn002odjenP03o`000?mE]o_oEKOk00;oGK[l8oooool00ol0
003oooooooooo`0Nooooo`005oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Oo
oooo00GoGMGJoeSBdomHd]?oE]7AoeC@d003oeKAc`07oegEdomNe]CoG]KDofWLfom/g]goK]oPog7Q
h`02ogCRi@04ogOSj?mji>_oO^G]oh7Vl0;oQ>Ob00KoO^Caoh;Um?n5iOKoR>Ghoh;Sn?n6hoT2ohWR
n`07oh?Pnon6gocoRMomohWOoOn4g?goQmcnoh7IoP02ohCHo`;oO]Ko00?oN=?nog_Boomfcol00_mi
c_l3o`000003ofg8o_mWaOkoHL;m00;oIL7n0_mO__d2oeVjo004oe>gnom>/o[oA;3godB`m`;o?Zcf
0_liZ?@00oldYO;o:j7_obJMk@02oajIj@0:oaZFj?lBT^Co2hkOo`^>gol8S=ko0hWKo`26f?l0Q=Go
08;Bo`21d@;o087@0_l0P]02o`28d`03o`2:e_l5S]Wo39;M00;o59SR0_lIV^D2ob>PjP03obVSkOle
ZO;o=JWb00;o?:cd00Co@jogo`000?m@]O[oD;Gj0_mH]o`Rooooo`03o`000?oooooooooo01kooooo
000Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0@_ooool01_mTf]coHMSIoeoG
eomOemCoGMKCoecEdP;oHMSB00_oHMSCofWLeomZgMSoK=kIofkOfom`h=goL^7OogkWiOn1j>SoQ>WZ
ohOZk@02oh[[k`05ohCXk_n7jO3oRnWcohkZmOnAj_L00_nDj_P02?n>j?SoTNOjoiCWnonDio_oSnGk
oi7To?nDhogoSn7m0_nBh?h01_n<g_koSmgnohoMo_n9foooS=WoohOGo`;oRMKo0_n4dol3o`000005
ogc=oomfb_ooNLWoogW9oomca_l00_m^`oh2ofS0oP;oHkgm00?oGK[loeNfo?mG]_`00_mB/oX2odb_
n@;oAjch0_lhYO@2oc>RlP05obnNlOlVVnko9Y_^ob:Gk?lJU>P00_lCT>D02_l@SNCo2H[Po`B7gOl0
QM[o08?Go`22eOl0PM?o083Bo`21d_l0P]<2o`24e004o`26e_l1RMSo1hkLo`jBg`;o5YOT0_lKV^L2
obFPk005obbSkolgZO?o=jWco`000?ln[?H00_m6[oP3odfbnR7ooooo00?o0000ooooooooool07Ooo
ool001Oooooo0_l0000@ooooo`03o`000?oooooooooo03gooooo00OoKMkNof[Mg?mWfmWoIm_IofKJ
f?mTfMKoIm_E00;oI]_D00goKMkGofgOeom_gmSoL>3Jog[Ug_mli^3oO^ORoh7Xi?n4jNOoQn_Yoh[/
jon=k>goT>g_00;oTnga00GoU^kcoiW^mOnCk?GoU^cgoiW/n002oic[n@06oiOYn_nIj?_oW>SkoicX
nonGi_coVNGl0_nLi?d00onGh_goVN3moiCOoP02oiKMoP06oi7Ko_nCf_koTm[nohoHoonAe_koS=Co
0_l00002ohW@o`04ohC>oon6c?koPLWnoh79oP;oO<Oo00CoM/Cnog72o_md`?koM<3n0_m^_Od00omY
^ogoI;SlofBho002oejdo0;oFK7k00GoE:kjod^/nOm6Z?SoAZShod6UmP02ocRRm0;o<ikb00Go;i_a
obJHk_lVV>ko8YG]oa^Aj@02oa>>iP0:oa6<iOl;RN;o1HKNo`64g?l0P]Wo087Go`20e_l0P=Go087E
o`22e@;o08CF00?o08KHo`>:fol9S]h00_l@T^800olEUNGo7Y[YoajJj@02obRPk@03obnSl?l0003o
=ZKc00;o@Jcg0_m9[oTQooooo`;o00007_ooool001Kooooo0_l0000Booooo`;o0000>oooool01?ma
h=ooK]oMofkOgOm/g]/2ofgNf00<ofcNeom/g]KoL^7Hog;Qf?mch]WoO>KMogkWg_n0j>3oP^WRohGZ
i?n7jnKoR^cX0_n=kNX01_n@k^coT^o^oiK_l?nHko;oVnocoik_m@;oXNof00KoW>kgoik]n?nQk?Wo
XncioikZn_nQjO/2oj?Xn`07oikVo?nQiOcoXn?loj?So?nNh_goX>3loi_Oo@02oigMo@04oiSKo_nJ
fOgoV]WmoiKHoP?o000000GoU=;moi3@oOn@d?goRlknohg<o@02ohS:o@;oPlSn00CoO/Gnoh73oOmk
`OgoNl7m0_mg__d2og6lo@03ofbio?mW]_coIkKl00;oH[?k0_mL/O/01?mG[_[oDZ_iodVXn?m9Z?P2
odFUm`;o@:;f00So>ikdoc>Kl_lcVo;o;iSaobJEk_lOT^_o6hoZoaB<i`;o3XWT00_o38OSo`N5h?l3
Pmgo0h?Mo`21fol0P=Wo083Ho`20eol0PMOo08;Ho`24f@02o`67f`05o`J:gOl<S^3o4i?Toa>Ci?lH
U^L00olQVn/01?l0003o<ZCboc:Tl_liYo@2odB]mb7ooooo00?o0000ooooooooool07?ooool000ko
oooo0ol00005ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=_ooool00omgi=oo
MN?NogCRg002og?Rf`0;og;QfOmgi=[oMnCJogOTf_mhi=[oP>SMoh;Yg_n4j^3oQ^_QohS/hon:kND0
0_n=k^L02OnJl^goWO;_oigbkonHl>koVo7`oigal_nPlO?oXo7eojG`mP02ojS`m`03oj?_monVk_So
Z>gi00;oZ^_i00GoYN[jojOYn_nYio[oYNKkojOTn`02ojSRnP07ojCQo?nVgo_oY]okoj;No?nSg?_o
Wm_loj3Hn`03o`000003oigEnonIdocoVm7k00;oU/ol00CoT/kloi?;nonCbo_oSlWl0_n:b?`01?n5
a_goQlCkohO4non3`O`2ogjoo0;oNKgl0_md^_`00om_^?coJ[GkofZen`02ofFbn`;oH:oj00?oFjgj
oeJZnOmFZ_T00_mAYoP01_m<Y?OoA:7fodBQm_loW_Go=i_coc>IlP;o:iK_00Ko9i?^oan@k?lOT>co
78gZoaJ;iol@R>D2o`Z5hP03o`V4hOl5P]oo0H7M00;o083L00Go07oJo`20f_l0PM[o08;Jo`64f`02
o`B7g@09o`V;h?l?Sn?o5Y?VoaJCi_lKU^Wo99_]o`000?lTVngo:ik_00;o=JCc00?o?:Oeoooooooo
ool07oooool00ol0003oooooooooo`0Kooooo`003Oooool01Ol0003ooooooooooooooooo000000Co
oooo0_l0000Eooooo`03o`000?oooooooooo037ooooo0_mmin<01Omki^7oN^GOogWUgOmiiMgoN>CL
00?oO>KK00coONOKohCZg_n6jmooQncPohW/hOn;kN?oUO7WoiSbj?nJl^[oWO?/oiockOnRm>l2ojGd
l004ojOdlOnSl_;oYO;cojSbm0;oZ_7e00Go[?7fojk`monZkoOo[>khojk/n002ok3[n008ojcZnOn]
j?Wo[nKiojoVnOn[iO[o[>?iojSRn_nZh?X2oj_Nn@03ojOMn_nXfoWo000000;o000000?oX]Kjoj?C
nOnSdoT00_nOd_X00onKdO_oW<kioiS=nP02oiW;n@;oULWj00CoT<Ojohc5non>`oWoS/?i0_n9`OX0
1?n5_o[oP;gjoh2mn_mk^o/2ogfin@03ogVgnOmd]?WoM;Ci00;oKk;i0_m[[oT2oej/n@;oFJWh0_mD
Y_P01Om@XoOoB:7fodRQm_m3W_Go?i_d00;o=iWb00Go<iKaob^Ckol[Tnoo:93^ob6>k002oaZ;j@06
oaN9j?lAQ^Ko38CSo`R3hOl4PMoo0H3M0_l0Om`2o`1og@04o`20g?l0PMco0X?Mo`B5gP;o28OP00Go
38_Roa:?iOlIU>So0000oanGj`03obRLkP03obnOlOliYOCo>JGd023ooooo00?o0000ooooooooool0
6_ooool0017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02oooooo00GoPNSToh3Xh_mnin7oPNWOoh7YgP02oh7Xg@;oPNWM00WoR>cOohW]gon;kN3o
SNkQoho_h_nHl^KoV_?WoigcjOnOm>/00_nRm>`01?nTmNgoYoG_ojWel?n/mO42ojkdlP05oj[clon/
loCo[_;dok3amOnbl?H00_ndkoH01On`k_Oo/^ggok?[mon`joSo/NWh00;o/^Oh00Oo[nKiok3Tn?na
h_Oo/N;gojkQnOn_goSoZmki00?o00000_nYf?P00onUeoWoY]Ghoj?Cn@02ojCAm`05oj3@n?nQcOOo
WLchoig<n?nIboT00_nJb?L01?nFa_SoT/Gioi?3monC`oL2oho1n004oh^on?n6_OWoQ[gioh:kn@;o
Q;Wg00?oOkOhog^en?mk]OP00_mf/_P2og:`n004off^n?mYZoOoJJ_gofBYm`;oG:Oh0_mHYOL01OmC
X_KoCioeodNMmOm7WOGo@i_d00;o>iSc00Co=iKaobnCl?l_To3o;93_0_lUS^d02_lRS>co6hWYoaF7
iolEQnOo4hGVo`j3i?l:P^;o1h7Qo`B0gol2Omh2o`60g@04o`61gOl2P]ko18CNo`N6h0;o38WR0_l@
S>@01?l0003o7ICZoafDj_lSV>d2obbMl0;o=Z;c7oooool00ol0003oooooooooo`0Jooooo`004Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?oo
ool01?n5jnGoQ>[SohK[h_n6jn43ohK[g`06ohK[g_n<k^3oS^kPoho_hOn@l>;oT_3S0_nDlN@02OnO
m>SoX_GYojCfjonTm^_oYoK/ojWfk_n[m^oo[_K`ok3fl@02ok;elP05ojkdl_n`m??o/_?dokCbm?nf
lOD00_nhkoD00ondkoKo]^gfokO/mP02okSZmP04okGYmonfioKo]nGfok?Um`;o]>;f00?o/N;gok;O
m_l000000_l000001on`f_Go[MWgojkGmOn^eoGoZ]Kgoj_CmOnWd_H00_nXcoD2ojC>mP03oj7=monR
boGoW/Wf00;oW/Od0_nKaOD01?nGa?KoTl?goiC0mOnD`?D2oi2nmP04ohbmm_n8^oOoRKWeohVim@;o
QKOf00?oPKGfogfcm_mm/oH00_mh/OH2ogB_mP04og2/m_m[Z_KoJj[fofNWmP;oGjKg00CoFjCfoeNQ
mOmGXOGoDYod0_m;WO@2odNJl`04od>Hl_lkU_;o>iKbocNCl@;o<97_00So;Hk^obJ<kOlORN_o7hW[
oaf8j_lGQ^So4XCVo`f2i0;o2H7R00Co2H3Ro`MohOl5On3o183O0_l5PMl00ol6P^3o28CQo`^7hP02
oa2;i004o`000?lES^Oo6Y7Yob6Fk0;o:I__0_l`W_4Oooooo`03o`000?oooooooooo01Wooooo000=
ooooo`Co00001?ooool2o`0001Wooooo00?o0000ooooooooool0:?ooool01On>k^SoSNkVohc]i?n;
kN?oRngR00;oRngQ00KoRngPoi3`hOnAl>7oT_3RoiCah_nFlN<2oiObi00:oj;fionTm^WoY?KYojKg
j_nYmn_oZoO/ojggkOn`mnko/_O_okCfl0;o]_Ka00Go^?GbokCdl_nflo?o^?;cokWam002ok_`m003
okS_mOnik_Go^^cd00;o^n[d00Oo^>[fokWXmOnjiOCo^^GdokOUm_nhhoGo^>3d00?o000000Ko/mge
ok?Jm?ncf_Co/=[eok7Gm?n^eoD2ojkDm003oj_CmOn[d??oZ<oe00;oZ<gc00GoYLcdojG9l_nUbO;o
X/Scoik7m002oio4lP;oW<?c00GoV<;doiVol_nE__?oUKkcoi6lm002ohfjm004ohVimOn;]o?oRkOc
ohNel`;oPk?d0_mn/O@2ogZ_m003ogJ]m?mbZoCoLZ_d00;oKZSd0_mYY_@01OmUY?CoGZ?eoeZPm?mJ
X?CoEYkd00;oCYcd0_m:V_<01_m6Uo;o?iGbocnEl_lkTo7o=93`oc6>k`;o:Xc]00Go9h[/ob68jolK
Q^Wo6hKYoaJ4i`02oaB3iP05oa22iOl=PN?o2X3Ro`QohOl6P>400_l6PN002?l7P^7o2HCQo`V4hOl<
QN?o3hSUo`000?lDRnKo6HoY0_lPU>`00olVUnko;YcaobjLl@0Oooooo`03o`000?oooooooooo01So
oooo000=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Tooooo`05oi;_jOnAknOoTNoWoi3_i_n?kn@00_n?kn<2oho_hP03oiGahonFl^?oUo;S00;o
VO?S00WoV_?ToicdiOnWmnSoYoOXojWgjOn[n>[o[OS[ojohk?nan>d00_ncn>h02Onfmnoo^?O`okWf
l?nim_3o^oGaokSel_njm?;o^o?bokgalP02okk`lP06ok_`m?nlk_?o_NccokkZlonkj_Co_>Sc0_nm
i_<00onjiOCo^n?co`000002o`000003okWNl_nfgOCo]]_c00;o]mSa00?o]=ScokCElOnae?800_na
d_401On^dO;o[lk`ojo>l?n/c_;o[<_`00;oZL[a00GoYLWbojK6l?nSaO7oXlGaoio4lP02oj32l@04
oic1lOnI_o;oVKg`oiVml0;oU[_a00CoT[[bohnhl_n?^?;oRkOc0_n<]?400on8/_;oQ;7bohBalP02
oh2_lP;oO:gc00?oN:_cogBYlomdZO<00_m`Yo<01?m/YO?oJ:;bof6RlomQX_<2oefOl`;oFIgc00Ko
EI[bodjIl_m>VO;oBYOaod>ElOloT_02ocR@l005ocB>kol^S>ko;Xc^ob^:kOlUR>/00_lOQ^X01OlM
QNWo68?Woa>2i_lCP^Ko487U00;o3H3S00Co3GoSo`]ohol:P>;o2X7R0_l;P^<01Ol=Q>Co0000oa>:
i_lCR^Ko68cX00;o7Y3[0_lTUNd00ol[V>ooooooooooo`0Kooooo`;o00001oooool3o`00013ooooo
000=ooooo`Go00000oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo0_nE
lNX02_nDlNSoU?7WoiCaiOnDlNGoTo7ToiCai?nDlN?oV_?Toi_ci?nLm>@2oigdi007oioeiOnQm^Go
ZOSXoj_hj?n]n>Wo[oSZok7ij`02ok?ik004okGhkOngn>ko^OS^ok_gk`;o_OK`00Go^OK`ok_elOnm
m?7o__?aol3al@02ol7`l@03okk`l_nok_;o`>cb00;o`N[a00Go_^[cokoXl_noi_7o_NKcokgSlP02
o`000007ok_Ql_nlg_7o_=_`okcKl?nifo7o^MW`okOHl@02okOFl003okCElOndd_3o/M;a00;o//o_
00Go[lk`ojo<kon_c>oo[<_`ojc8kP02ojW7k`05ojK6l?nVa>ooXl?`oj?3l?nP`_400_nP_nl01?nM
__3oVKg`oiZjk_nJ^^h2oiNik`04oi>gl?n?]_7oSkKaohbdl@;oSK;_00?oRK3`ohF_l?n5[o000_n2
[O000omnZo7oNZWaogZYl@02ogJWl@;oLZGa00CoKZ?aofRRl_mTX?;oI:3b0_mOW_801OmLW?7oF9[a
oeRJlOmAV?7oCIKa00;oAYCa00Co@i;`ocb@kollT>oo>8k_0_lbS>h01_l_R^go:HS/obV8k?lVQn_o
8HGZoab3j0;o5h;W00So5X7Woa>0iOlCP>Go483Uo`ioi?l<P>?o387So`b2h`;o3XCT00Co0000oa65
iOlDR>Oo68_X0_lMSn/2ob>Ak@03obVFkooooooooooo01cooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000oooooo000Eooooo`;o00007?ooool00ol0003oooooooooo`0N
ooooo`;oVO;[00KoVO;YoiSbj?nHl^OoV?;WoiSbi_nHl^D2oiSbi006oioeiOnQm^GoXOKUoj;fiOnT
m^KoYOOV0_nWmnL01onanNWo/oWZokGijonenN_o]oW/okWikOnkn>d00_nln>h01onnmnko`?K_okgf
l?nnmO3o`?C`ol7cl?o3lO000_o4l?000oo1l?7o`^kaol?/l002ol?Zl004ol7ZlOo2j?7o`^K`ol;V
l0?o000000Go_^7aokkNl?nng>ko_]c^okcKl002okcIkP04okWIl?njdngo^]?]okOCkP;o]m3]00Oo
]=3^okC=k?nbcNko//g^ojo<kon_bNgo[<S^00;o[<K/0_nYaNh01?nVa>ooY/7]oj?0k_nT_^`3oj6m
k@05oifkk_nJ^^koVkS]oi^hkOnG]nd00_nD]Nh2oi2dk`04ohfbkon>/>goRZk^ohZ^kP;oQjg^0_n3
Znl00omoZNooNjO_og^Wk`02ogRVk`04ogBTkom`X^ooJZ7aofZQl@;oIYoa0_mRWO001OmNVo3oF9[a
oeBGl?mDUo3oD9G`00;oBIC`00CoAY7_ocn@koloT>oo?8k^0_lfS>h01OlcR^go;HS/obf8k?lZQn_o
9HGZ00;o7hCY00?o7X;XoaZ1iolFPNH00_lCP>D02Ol@P>Go3h3To`n0i?l@P>Go487Uoa63iOl0003o
4XGVoaF7i`02oaR:j003oaf<j_lRT>co8Y3/00;o:9C_7Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00gooooo000Eooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
7?ooool01onMlncoW??ZoiccjOnLlnWoW??XoiccionLm>H00_nMm>D2ojCfiP03ojGgi_nVmnKoZ?SV
00;oZOSW00KoZoSWojgij?nen^[o]o[ZokSjjonjnN`2okcik006okkikOnon>go_?S^okkgk_o0m^oo
`OG_0_o3m>l01Oo4lnooaO7_olK_koo4l?3oa>k`00;oaNc_00Coa^[_ol?Zl?o4j>ooa>K^0ol00002
ol?QkP04ol3Qkoo1g^ko`Mc]okkLkP;o_]W]00Co_=W^okcFkOnle>co^]?]0_nidN/01_ngd>go]lk[
okO>jondcNco]<_[ok;:k0;o/LOZ00Go[lK[ojc6k?n/`n_o[<?[ojW2k002ojW0jP05ojNojonT_^co
Y;k/oj6mkOnQ^^/00_nN^N`01?nK^>goVkK[oi^fjonH]>/2oiBck0;oTK7]00?oS[3]ohZ^k_n;[>`0
0on8Zn`00on4ZNgoPJO]oh6Wk@02ogfVk@04ogVTkOmfX^koL:;_og2Rk`;oK:3_0_mXW^l2ofFLk`05
of6JkomKVO3oEiO_oeNGkomCU>l00_m=Tnl01?m9TNoo@ho_od>?kom0SNh2ocV<kP05ocN:kOl`R>co
<8S/obj7jolXQN/00_lSQ>T00olRPnWo7H;XoaV1i`03oaJ0iP;o583V00Co4h3Uoa:1iOlBP^Ko0000
0olFQ^L00olJR>Wo7H_Zob:?k003obNCkQcooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0=ooooo`005Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo00Ko
X?C]oj3djonPm>[oX?CZoj3djOnPmNP2oj3ei`05oj7ei_nVmnOoYoSVojWhi_nZn>L00_n/nNL01?n]
nNOo[oWXok7ij?ncn^T2okGjjP06okcjjonmn^_o_oW/okcik?nnnNgo_oS]0_o1mnh01?o3m^koa?G^
olGdk_o6l^h2olOakP03olGakoo6knooank^00;oanc^00?ob>W]olKZkol000000_l000001Oo5hngo
aN7/olGQk?o3hNko`mk]00;o`mc/00Co`Mc]ol7Ik?o1en[o_]O/0_nne>X00onle>co_=7ZokWAj`02
okW>jP06okO>jongbnWo]l_YokC;jondb>Wo/LOZ0_naaNP01_n_a>Wo[<?[ojc1jOn/`NWoZL3ZojVm
j0;oYkcY0_nT^nX01_nQ^^_oXKSYoijgj_nN]n[oVkK[oi^cj0;oV;;Y0_nE/NX2oi:_j`06ohn^jon;
[>coRjc/ohR[k?n9ZN[oQJO[0_n2Y^/2ogjTj`;oNj;/00?oMZ;^og:Pk_mbX>h00_m^W^h2of^LkP04
ofNJkOmTVNgoGIS^oefHkP;oFYK^00CoEY?^oe2Bk_m@T^koCI3^0_m6Snh01Om3SNgo?Hc]ocf<kOlj
R^go=8S/00;o<XO[00Ko;8G[obN4j_lWQ>[o9H?Yob62j?lMPNP3oaV0i`08oaN0i_lEP>Ko5H3VoaB1
i_l0003o58;VoaN3iolHQNP2oaZ7j@04oaj:j_lRS^co8Xk/obN@kQgooooo00Co0000oooooooooooo
oooo1?l0000@ooooo`005Oooool2o`0001oooooo00?o0000ooooooooool05_ooool01_nSm>goXoG/
oj?ek?nSmN_oXoKYojCfj@;oY?KX00CoYOOWoj[hion[n>Oo[OWW0_n^nNL01?n`nNOo/O[Xok?jj?nd
n^T2okKjj@05okSjj_njn^[o_?[[okgjjononN`00_o1nN`01Oo3n>goa?O]olGfkOo7mNgob??]00;o
bO;]00Cob_3]olOak_o8kngobNg]0_o9jn`02_o7k>ko0000o`000?l0003obNG/olOUkOo7hncoan7[
olGQk?o5g^/2olGLjP04ol?Lk?o3fN[o`mOYol7GjP;o`=CY00Ko_]CZokkAjOnndNWo_=7Zok_>j?ni
c^X2okW;j003okO;jOnfb>So]<SY00;o]<GW00Go/LGXok72i_na`^Ko[l7Xojc1j@02ojbni`04ojVm
j?nW_>WoYk[WojNji`;oY;WX00CoXKSYoj6fionN]>SoW[CX0_nK/nP01OnH/^WoVK3WoiJ_j?nF[nSo
TZgY00;oSjcY0_n<ZnX2ohVYjP03ohFWjon2Y^_oPZK[00;oOZC[00?oNj;/ogNQk?mgXN`00_mdWn`2
og2Mk004offKk?mYVNcoI9W]ofBIk@;oH9O]00?oG9G]oeVCk?mITn`00_mCT^d01_m@T>goBHk]odN=
kOm7SNgo@8_]ocj9k0;o>8S/00Co=XO[oc25jol`QN_o:hCZ0_lYPnT01olTP^Wo887Xob21j?lPPNSo
7H3WoaZ0iolHP>L00_lGPNL01Ol0003o6H7WoaV3iolJQ>So78OY00?o7XWZ00?o8hc/obN?k_ooool0
6oooool2o`0000;ooooo00?o0000ooooooooool04Oooool001Gooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Cooooo`05ojKek_nVm^goY_K]ojOfk?nWm^/00_nWmnT01?nXmnWoZ?OX
ojWhj?nYn>P2ok3ij004ok;jj?ncn^So]O[XokKjj0;o^?[Y00Co^_[Yok_jjOnmn^[o_o[[0_o1n^/0
1_o2nN_oa?S/olGhk?o6mncob?K/olWdk0;ob_?/00Cobo;/olWbkOo:l>gobno/0_o;kN`02?o<jn_o
0000o`000?l0003ob^O[ol_Uj_o9iNcobN?[0_o9hNT01Oo7hN_oamkZolOLjOo5g>[oaMWY00;oa=OW
00?o`mOYol;Dioo0e>T00_o0dNL01_nndNWo_/oWokk?ionkc^So^lcWokW;j0;o^LWV00?o]/SXokK6
i_ndaNL00_nc`nD01Ona`^Ko/KoUojnoi_n__nKo[;kW00;o[;cU00CoZK_VojNjionW^>GoYkSU0_nT
]nH01onQ]^OoXK?Uoijbi_nN/^KoW;7WoiV`ionI[^D00onF[NH00onCZnOoT:[Woi2Zi`02ohfXj003
ohZWj?n6YNWoQZGY00;oPjCY0_n0X^T00omlXN[oNIoZogVOjP02ogJMjP;oLYcZ0_m[V>X2ofJGk0;o
HYK/00GoGiC[oeVCk?mITncoEY7/oe>?k002odf>k004odZ<k?m4RncoA8_/od69j`;o>hS[00Go>HK[
oc>5jol^Q>[o;XCZobf3jP02obR2j@05obB1j?lSPNSo8h7Xob20j?lMP>L00_lKP>L01OlLPNOo0000
oa^1j?lKP^So6hCX00;o7HKY00Co8HS[obB;k?lTRnco9hk]6_ooool00ol0003oooooo`000002oooo
o`Go00003oooool001Gooooo0_l0000Qooooo`03o`000?oooooooooo013ooooo0_nYm^l01onYm^go
Z_O/oj[gjonZmn_oZoSZoj_hjOn/n>T00_n]nNP01On^nNSo]?[XokCjj?ngn^So^?_X00;o^__X00Co
^o_YokgkjOnnnnWo`?[Z0_o2n^X01Oo3n^[oaOW[olKhjoo8mn_obOK[00;ob_G[00CoboC[olccjoo:
lncobo;/0_o<l>/00oo<k^_ocNcZo`000002o`0000;oc>OY00?ob^O[ol_Uj_o;hnT00_o;h>P02?o9
hNWobMkXolSLioo8g>OoamcYolKIioo6enKoa=OW0_o4e>H01?o2e>Oo`];Vol3AionocnH2oko<i005
okg<i_nmbNCo_LWTok_9iOnjan@00_nha^D00onfa^Ko]/?Tok?3i@02ok?0i005ok6oiOna_N?o[[cT
ojjli?n/_>D00_n/^N<01onY^NCoYkSUojJehonV]N?oY;CToj6ciOnQ/N<00onO/>@01_nL[nGoVJkU
oiV^iOnF[NKoUj_ToiBYi@?oTJSU0_n>YnH00on;YNKoQjCWohNTi`02ohBRi`03oh6Qj?mnWnSoOYoX
00;oNYgX00CoMicXogBJj?mdV^SoLIWX0_m[V>X2ofRFjP05ofFDj_mRTn[oHY?ZoebBjomIT>/00_mF
S^X2oe2=j`04odf<jom7Rn_oAh_[odB9j`;o?hS[00Ko?8KZocN5j_lbQ>[o<XCZoc23jOl/P^T2obN1
j@04obN1j?lSP>So8h3Xob20j0;o7X3X00Co0000oaf1j?lMP^So7H;X0_lMQ>T00olPQN[o8XO[obF:
k003obR=kA_ooooo00?o0000ooooooooool04oooool001Cooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0=ooooo`;o[?K_00Ko[OO^ojggkOn]n>co[OS/ojkhjon^n>X2ojoij@03ok3i
jOnanNWo/_[X00;o]?[X00Go^__Xok_kj?nmnnWo___Yol3kj@02ol7kj@04ol?jjOo4n^[oa_WZolOi
jP;ob?SZ00Cob_OZol_fj_o<mN[ob_G[0_o;m>/01?o<ln_ocO7[olk_j_o>k^X3o`000009olg[j_o>
j>Woc^KXolkVj?o<inWoc>GYolcRj?o<h>Oobn3X00;ob]kW00Sob]_VolSLioo8fNKob=WVolKIioo6
enKoa]CUolCDiP;oa=;U00Co`];Vol;?iOo1cN?o_lcT0_nob^<00onmbNCo_<OSok[7i002ok[4hP;o
^<CS00?o]/?TokG1honc`>@00_nc_^801_na_N?o[[[Rojjjh_n^^^;o[;WSojbghP;oZKKS00CoY[GS
ojJch_nT/^;oY;;R0_nQ/N<01?nO/>CoWjkRoib]honL[N<2oiV/i0;oUj_T00?oU:WUoi6XiOnAY^@0
0_n>YN@2oh^Ti@;oR:;U0_n5XND01?n2WnKoOikVogbLi_mlW>H2ogVKi`03ogBJj?maVNSoLIWX00;o
KIOX00?oJYGXofNCj?mWTnP00_mRTnX01OmNTNWoFhoYoeJ>j_mFS^[oDhgZ00;oD8_Z00CoBX[ZodR9
j_m8RN[o@XOZ0_m0Q^X01OljQN[o=HCZocF4j_ldPnWo;h;Y00;o:h7Y00Co:X7XobJ0j?lSP>So8h3X
0_lTP>P00ol0003o887Xoan2j002oan3j@;o8XGZ00Co98O[obJ9k?lYS>go:Hc]7?ooool00ol0003o
ooooooooo`0Booooo`001_ooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo
0_l0000<ooooo`06ojofl?n_mnoo/?O]ok3gkOn`n>go/OS/0_nanN/00onbnN[o/o[YokCjj@02okKj
j@03okOjjOnhnnSo^__X00;o^o_X00_o`O_Yol;kjOo4n^Woa?[YolGjjOo7n^Wob?WYolWhjOo;n>Wo
b?SZol[gjP02ol_fjP04olcej_o=ln[oc_;Zoloaj@;ocnoY0_l000001oo?k>Wocn[XoloXj?o?j>So
c^SYolkVj?o>i>L00_o>h^H01Oo<h^Soc>3WolcMi_o:g^Oob]_V00;ob]WU00Cob=WVolSGiOo7e>Co
a]CU0_o5d^@01oo4d^Go`loSol?=h_o3cN;o`LgSol7:h_nob^<00_nnan400onlan?o_<GQok[4hP02
okW2h@;o]l7R00?o]L7SokFnhOnc_^800_nb_>001On`^n7o[[[RojjhhOn^^>7o[;OR00?oZKCQ0_nV
/n801onT/^;oY;3Qoj6_hOnQ[n7oWjkRoib]honLZn400onJZ^800onGZN;oU:OSoiBWh`02oi6Vi003
ohjUi?n;Y>GoS:;S00;oRJ7S0_n6Wn@00on3W^CoP9cToh2Li002ogbLiP;oNI_W00CoMYWWog:Giomb
UnOoKiKW0_m/U>L2ofNCj004ofBBj?mQT>SoGXoXoej?j0;oF8kY00CoEXcYoe2;j_m@Rn[oCH[Y0_m8
RNX01?m5QnWo@8KZod26j_lnQNT2ocV4j@06ocN3jOlbP^Wo;X7Yobj1jOl]PNSo:X3X0_lVP>P2obN0
j005o`000?lSPNSo8X;Yob:2jOlTPnT00_lTQ>X01?lUQ^_o9hW/obN9k?l[RndKooooo`03o`000?oo
oooooooo01;ooooo0007ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo00Ko/OK`ok;gkonbn>ko/_S^
ok?hkOncnN`2okCij`07okGijonfn^[o]o[YokOjjOnin^Wo^__Yok_kj@02okckj@03okkkjOnonnWo
`O_Y00;o`__Y00Goa?[YolGjjOo7n^Wob?WYolWhj@02ol_hj@04olcgjOo=m^Woc_CYolocj@;od?7X
00God?3Xo`000?l0003o0000om3[j002om3Yi`03om7Wi_o?j>SocnKW00;ocnCV00?ocn;UolkRi_o>
gnD00_o=gN@01?o<gNKoc=_Uol_Ihoo:fND2olWGi004olWDh_o7e>Coam;RolGBi0;oaLoR00Ooa<gQ
ol?=h_o2b^7o`/[Qol7:h_o0b>3o_/OQ00;o_/GP00?o_<GQok_2goni`^400_ni_ml01Ong_n3o]KkQ
okBlgond_=oo/[cP00;o/[WO00Ko/;WPojjhhOn]]]oo[KKOoj^eh?nY]>42ojVbg`;oY[7P00GoY;3Q
oj6]h?nQ[N3oXJgPoin/h002oib[h@04oiZZh_nJZ>3oUjOQoiNWh@;oU:KQ0_nBY>800on?Xn;oS:;S
ohbRh`02ohVQh`03ohJOi?n3W^CoPikT00;oP9cT0_mmVnD01?mjVNGoMiSUogNHiOmdU^D2og6Ei@;o
K9CW00CoJI?WofJAiomSSnOoHhoW0_mNSnP00omKSNSoF8cXoeR<j002oe>;j004oe29j?m;R>WoBhSY
odR7j0;o@hKY00Go@HGYocb4jOljPnSo>X?XocJ2j@02oc61j@03oc61j?l]P>So:X3X00;o:X3X00?o
9h3Xo`000?lVPNT00_lTP^T01?lVPnWo9XCZobN6jolWQ^/2obR8k003obb:kOoooooooooo01Wooooo
00?o0000ooooooooool04Oooool000Oooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00004ooooo`;o00009oooool00ol0003oooooooooo`04ooooo`03ok?flOndmnoo]?O_00;o]OS^
00Go]_S]okKikOngnNco^?[[okWjj`02ok[jjP07ok_jjOnlnnWo___YokkkjOnonnWo`O_Yol;kj@02
ol?kj@04olGjjOo6n^Wob?[YolWij@;ob_WY00Coc?SYolggjOo>m^SocoGX0_o@m>P00oo@l^SodO7W
o`000002o`0000;odNgW00Cod^_Wom;Yi_o@jNOodNOV0_oAiNH00ooAhnGocnCVoloRi@02oloOi009
oloMhoo=gNCocM_SolgKhoo=fN;obmWSol_Gh_o9enCobMCR00;ob=;Q00Coam;RolK?hOo5cn;oa<gQ
0_o4bml01_o2b^7o`/SOol;8goo0b>3o_lGOokk5h0;o_L?N00Co^l;Ook_0g_ni_moo^;gM0_ng_Mh0
1Ond_=oo];[NokBjg_nb^Moo/[OM00;o/;ON00Ko[KKOojfcgOn]/mgoZk?NojVbgonX/=d2ojJ_gP;o
Y:kO00CoXJgPoj6[g_nOZ]ooWj[O0_nLZMl2oiZXh003oiNWhOnEY=ooUJCO00;oTZ?P0_n?X^42ohfP
h@;oRYoR00?oQigRohBLh_n4W>800_n1Vn<01?mnVN?oNiSSogRGhomhUn<2ogJEi0;oLIGU00CoKY?U
of^BiOmXT>GoJ93U0_mSSnL2of2>i`04oef=i_mHS>SoF8cXoeJ:i`;oDhWW00GoCXSXod^7j?m6Q^So
AXKXodB5j002ocn4j0;o>X?X00Go>H;XocF1j?ldPNSo=87Xoc21j003obf0j003o`000?lXPNWo:87Y
00;o9h;Y00?o:H?YobR4j_lYQN/00olZR>`00ol^RNgoooooooooo`0Iooooo`03o`000?oooooooooo
013ooooo0007ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0Wooooo`04o`000?ooooooooooooooo`;o]_Ka0_nfmo000ongmnoo]OS^okKhk@02
okKik@09ok[jjonkn^_o_O[Zokgjj_nnn^[o_o_Yol3kjOo2nnWo`o_Y00;oa?_X00Coa_[XolOjj?o8
n^Sob_WX0_o;nNP02?o<n>SocOOXolkfj?o>m^SocoGXom3diooAlnOod?CX0ol000002_oBknOod^kW
om?/i_oCk>Kodn[Uom;[iooBjNKod^OUom;Ui?oAiNH2om7Si@04om3Qi?o@gn?ocmoToloMh`;oc]_R
00SocM_SolgIh_o<e^7oc=KQol_Gh_o;e>7ob];PolSBh@;ob<oP00Coa/oQolK=goo5bmkoa<_O0_o3
b=h00oo2b=oo`LKNoko5g`02oko3g@05okg3g_nl`Mgo_<7Mok_0g_nj_]`00_nh_Md00ong_Mko][_M
okBjgP02ok>hg006ok:ggOn`]mko[kCLojndg?n]/mgo[K7L0_n[/M`2ojR`g@04ojJ_g_nV[McoY:cM
ojB/g@;oXJ_N00GoWj[OoibWg_nLYmkoW:ONoiZVgP02oiNUg`;oUJCO00?oTZ?Poi2Pgon@X=l00_n=
Wml2oh^Mh003ohRLh?n5Vn7oQI_Q00;oPYWQ00?oOiSQogbGh_mlUn800_mhUn<2ogJEi004og:Di?m`
T^CoKI7ToffAi0;oJ93U0_mUSnD01?mRSNGoH8cUof2<iOmKRnH2oeR:iP05oe>9iom@QnOoBhOXod^7
j?m9QNL00_m4QNP01?m3Q>So?X?Xocj3j?llP^P2ocR1j0;o=87X00Ko<h7Xoc20j?l]P>So;H3Xo`00
0?l[PNT2obZ2j@;o:h;Y00Co:hCZob^5jol/Qnco;8O/0_l_RN`Iooooo`;o00004_ooool000Oooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02So
oooo00Co0000oooooonhm_7o]_Ka0_nfmo001_ngmnoo^?S^okWikOninNgo^OW/ok[jj`;o^o[[00Ko
_O[Zokkjj_o1n^Wo`o[YolCjjOo5n^T2olKjj004olSjj?o9n^SoboWXolcij0;ocOSX00Koc_SXolog
ioo@m^Ooc_KXoloej?o@m>L3o`000008om?`i_oCknKodnoVom?]iOoDjnGodncVom?ZiOoCj>D2om?V
i003om?ThooBiNCod^?T00;od^7S00God>7Tom3Ohoo@gN;od=[QolkKhP02olkHh@08olkFh?o<e^7o
c=CPolcDh?o;d]oob];PolW?g_o8cn02olO=gP04olK=goo5bmkoaLSMol?8gP;o`lKM00?o`LKNol33
g?no`md00_nn`M`01?nl`Mgo_;kKokZng?nj_=/3okRkg004okJkgOnf^=_o/kSLok>ff`;o/KGL00Go
[kCLojnbfon_/]_o[K7Loj^ag002ojZ_f`;oZ:kL00GoYZgLojBZg?nTZ]coY:[Loj6Yg002oinXg@04
oibWg_nLY]coVZGMoiZUg@;oV:?M0_nEX]h00onBXMkoT:3Ooi2Pg`02ohfOg`03oh^Mh?n8W>3oR9cP
00;oQI_Q0_n2VN400omoV>7oO9ORogbGhP02ogZEhP;oMiCR0_maTN82offAi0;oJXoT00GoIhkTofB=
i?mTSNCoH8cUoef;i@02oeZ9i@03oeJ8i_mCQnKoDhOV00;oCXKW00GoC8GVodN4iom7Q>OoAH?Wod63
i`02ocn2i`03oc^1iolgPNSo=h7X00;o=h7X00Go<h3Xoc20j?l`P>So0000obj1j002obf2j@;o;X;Y
00Go;H?Zobf5jol^Qnco;XO/oc68k00Kooooo`03o`000?oooooooooo00oooooo0006ooooo`;o0000
1?ooool01?l0003oooooooooool00003ooooo`;o0000:oooool2okSfl@06okSfl?nimnoo^_S^ok[h
k_nkn>go_?W]0_nmnN`00onnn^_o_o[[ol3jjP02ol7jj@08ol?jjOo4n^WoaO[YolGjjOo6n^Sob?[X
olWjj?o;nNP2olcij005olghj?o>n>SocoOWom3fiooAmNL00ol00002om?aiP05omC_iOoDk^GodnoV
om?]iOoDjnD00_oDjN@01?oDj>Coe>KSom?Vi?oCi><2om?RhP03om?Ph_oBhN?odMkR00;odMcQ00Go
d=gRom3JhOo?f>3oc]SQolkFh002olgDg`04olcDh?o;d]oobloMolW?gP;obLgM00OoalgNolO;gOo7
bmgoa/SLolG8gOo4a]co`lKM00;o`/CK00?o`<?Lol31fonn`M`00_nm_]X01Onl_]_o^kcJokZlfonj
_=_o^;_L00;o]kWJ00So][SKokFff_nc]]_o/kKKok6eg?na/m[o[k;Kojj`f@;o[;3J00CoZZoKojZ]
fOnX[=[oZ:cJ0_nVZm/01?nTZ]coXjSJoj6XfonQZ=/2oinWf`;oW:KL00?oVZGMoiRRg?nHX]`00_nF
XM`2oi>Og@;oT9kM0_n>WMh00on;W=koR9_NohRKgP02ohJJg`03oh>Hgon1UmooPIOO00;oOYKP00Co
NiCPogRCh?mhTn3oMY;Q0_maTN82ofn@hP05ofb?h_mYSN?oJHgSofB=i?mRRn@00_mOR^@2oeZ9i@04
oeR8iOmCQnKoDhOVoe66iP;oChGU00CoBXCVodR3i_m8PnKoA8?W0_loP^L01?lnPNOo>X7WocZ1iolj
PNL2ocJ0i`;o<h3X00Go0000oc61j?l_PNWo;h7Yoc22j@02oc23jP04obn5jol`Q^_o<8K[oc>8k1[o
oooo00?o0000ooooooooool03oooool000Oooooo00?o0000ooooooooool00oooool2o`0000Cooooo
00?o0000ooooooooool0:?ooool2okWel@06ok[fl?nkmnoo_?O^okcgk_nmn>ko__W]0_nonN`01oo0
nN_o`O[[ol;jj_o2n^[o`o[ZolGjjOo6n^T00_o7n^P00oo8n^Sob_[Xol_ij002olcij005olghioo?
n>Ood?OWom7fiooBmNH00ol000001ooClnKoe?7UomC`iOoClNKoe>oUomC^iOoEk>@00_oEjn@01?oE
jN?oe>WTomCXi?oDi^<2omCThP03omCRhOoCh^;odn3R00;od]kQ00Wod]cOom7LhOoAf^3odM[Pom3H
goo?f>3ocmKOolkDgOo=e=l00_o<dMd01?o<cmcobloMol[=g?o9cMd2olS;g007olO;gOo6b=coaLKK
olG6foo4a]co`lCJol;4f`02ol71fP03ol31fono_m[o_KkJ00;o_KcI00So^kcJokVif_ni^M[o^KWJ
okNif_ng]mWo]KKJokBdf0?o/[CI00Ko/K?Jok2afOn^/=Wo[[3Iojb`f_n/[]T2ojZ]f@04ojR/f_nV
ZMWoYZWIojJYf@;oXjSJ00GoXJSKoinUf_nOYM[oWjGJoifTfP02oiZSf`;oV:;L00?oUZ7Loi>NfonC
W]/00_nAWM`2ohjLg0;oS9_L00CoRIWMohNHgOn7V=goQ9ON0_n1U]h2ognDgP;oO9?N00?oN9?PogJB
hOmfT^400_mcT>400om`Sn7oKXkQofj>h@02ofV=h`;oI8_S0_mOR^@00omMRNCoFhOToe^7i002oeJ7
i@04oeB6iOm?QNGoChGUodf4i@;oB8?V00GoAh?Vod>2i_m1PNKo@H7Vocf1i`02ocZ1i`07ocV0iolf
P>Oo=X3Wo`000?lfPNSo=87Xoc:1j002oc>2j@03oc:3jOlbQN[o<XGZ00;o<XK[00?o=HS/oooooooo
ool06?ooool00ol0003oooooooooo`0>ooooo`004oooool2o`0002Oooooo0_nkm?401OnlmO7o_OK`
okgfl?nmmnoo__S^00;o_oS]00Oo`OW/ol;ik?o3nN_o`oW[olCij_o5n^[oa_[Y00;ob?[Y00?obOWX
ol[ij?o<nNP00_o=nNL01Oo>n>OocoSWom3gioo@mnOodOKV00?o000000Ooe??UomCbiOoClnKoe?7U
omC`iOoEknGoe^gT00;oe^cS00Woe^[SomG[i?oEjN?oeNWSomGWhooEiN;oeN?QomCTh_oDh^400_oD
gn000ooCgMood]kQom;Lg`02om;JgP08om7Jh?o@f=ood=KMom3FgOo?e]ooc]CMolkAg?o<dMd2olc?
g004ol_=foo:cMcobL_KolS;g0;oalSK00CoalKJolG6foo5a=Wo`lCJ0_o3`]T01oo1`M[o`KoIol6o
fOno_m[o_[gHokflfOnl^]P00_nk^]T01Oni^M[o^;OHokRgf?ng]mWo][GH00;o];CH00Co/[CIok:b
f?n`/MWo/:oG0on^[]P01on/[]WoZZ_HojZ[f?nZZmSoZ:[IojJYfOnUZ=P00onSYmT01?nQY]WoWjGJ
oinSf?nMX]T3oiZQf@;oV:3J00?oUYoKoi>NfonCW]/00_nAWM`00on>W=coS9_LohbIf`02ohZHf`;o
QiSM00?oQ9ONoh6Fg_n1U]h00_moU=h01?mlTmkoNY;OogZBgomgTMl2ogB?g`;oLXkO0_m^S^401Om[
SN7oJ8_QofB;homTRn?oHXWS00;oGhSS0_mKQn@01?mHQ^CoEXGSoeJ5homBQN@2oe24i004od^3iOm:
P^GoBX;UodJ2iP?o@H7V0_lmPNL01?llPNOo>H3WocJ1j?l00002ocN1j005ocF1j?lcP^Wo<h;YocF3
jOldQ>X00oldQ^/00olgQncoooooooooo`0Hooooo`03o`000?oooooooooo00gooooo000Cooooo`03
o`000?oooooooooo02Gooooo00Go_??bokgdlOnnm_3o__K`okofk`02ol3gkP;o`OS]00Oo`_S/olCh
k?o5nN_oaOW[olKij_o7nN[ob?WY00;obOWY00?oboWXolcij?o=n>L00_o>n>L01?o?mnOod?OVom7f
i_o@mnL2o`000005om;ei_oCm>Koe??UomCbiOoElND00_oFkn@01ooFk^Coe^cSomO[h_oGjn;oe^cS
omKZhooFj>800_oFi^401?oFi>7oeNGRomGShOoEhN02omGOg`05omCOh?oCgMoodm_Nom?IgOoBf]h0
0_oAf=d02OoAeMcod=KMoloCg?o?dmcocm7KolkAg?o=cm_oc<oLol_=f`02ol_;fP03olW;foo8bM[o
alSK00;oalKJ00Coa/CHolG4fOo4`]So`l;I0_o2_mP01?o1_mWo`;gGokjmf?nn^mL3okbjf003ok^j
fOnj^=Oo^;OH00;o^;KG00Ko][GHokBbeond/]Oo];;Gok:bf?nb/=L2ok2_e`06ojj^f?n^[MOo[:cG
ojb/eonZZmSoZJWG0_nWZ=L2ojFXf004oj>WfOnSYMOoXJCHoj6Tf0;oWj?H00?oWJ;IoiZQfOnJX=P0
0_nHWmT2oiJNf@;oU9gJ0_nAW=X00on?Vm_oS9WKohbIf`02ohZHf`03ohNGg?n5U]coQIKL00;oPYGL
0_n0Tmd2og^Ag@;oN93M0_mdSml2og:>g`05ofn=gom]S>3oJ8_QofR;hOmVR^400_mTRN42oen8h`03
oef7h_mKQ^;oFhKR00;oEXGS00CoE8CSoe24i?m@Q>CoCX?T0_m:P^D01Om8P^GoA87VodB1i_m3PNGo
@87V00;o?h7V00Co?87WocV1iol0003o>X7W0_lhPNP2ocJ2j@04ocN3jOlgQ>[o=XK[ocJ6j`;o>HO[
6Oooool00ol0003oooooooooo`0=ooooo`004oooool00ol0003oooooooooo`0Sooooo`03okgcl_nn
m?7o__Ca00;o_oG`00?o`OK_ol;fk_o0mnh00_o1n>d01_o2n>coa?S/olGijoo5nN_oa_WZolOijP;o
b?WY00?obOWYol_ij?o<nNP00_o=n>L00oo>n>OocoOWom3giP03o`000003om?diOoDlnGoeO;U00;o
e_7T00Ooe_3TomO_hooGkn?oengSomK^i?oFk>?oen_R00;oenWR00CoenOQomOVh?oFi^7oe^CQ0_oF
hn000ooFhMooeN7PomGOg`02omCMgP06omCKgOoCfmkodmWMom;Gg?oAf=godMGL0_o@dm/02?o?dmco
cm7Kolk?f_o>cm[ocLoKolc=f_o<bmWobl_J0_o:bMT00oo8bM[ob<KIolO6fP02olK4f004olG2eoo4
`]So`l3Gol:of0;o`KgG00Go`;gGokjkeonn^mOo_[_Gokbjf002ok^he`04okZheoni]]Ko^;KGokNc
eP;o][?F00Co];;Gok>ae_nc/MKo/[3G0on_[MH01?n^[MOoZj[Foj^Ze_n[Z]H2ojVYe`07ojNXeonU
Y]OoYJKGojFVeonSYMOoXJCHoj6SeP03oinRe`03oifQf?nJX=SoVZ3H00;oV9oI00?oUYkIoiBKf?nD
VmP00_nBV]T00on?VMWoSISIohfHf@02oh^GfP03ohRFf_n6UM_oQYGK00;oPi?K0_n1T]/00omnTMco
Ni7Mog^Ag@02ogR@g@;oMXoN00GoLhgNog6<g_m]S>3oKHcPofZ;h002ofR9h0;oI8WQ00?oHHSQoen7
hOmOQn400_mKQ^801?mIQN;oEhCRoeN4h_mBQ><2oe63h`04odf2i?m;P^CoBh;TodN1i@;oAX7U00So
@h7Uocn1i_loPNKo?h7Vocb1iol0003o>X7WocZ1j0;o>H;X0_ljPnT01?liQ>Wo>HKZocV6j_lkQn/H
ooooo`03o`000?oooooo000000kooooo000Cooooo`03o`000?oooooooooo027ooooo00Oo__;bokoc
lOnolo7o_o?aol7dl?nomO3o`OK_00;o`_K^00Ko`oO]olCgkOo5n>coaOS/olKhjoo7n>X2olShjP03
ol[hjOo;n>Woc?SX00;ocOSX00?oc_SWom3giooAmnH00ol00002om?di@05omCdiOoElnCoe_;TomK`
hooFlN@00_oFl>@00ooGkn?oengSomO/hP02omSZhP04omSXhOoGjN;oenOQomOVh0;oenCO00?oen;O
omKSh?oFhMl00_oFg]h00ooEgMgoe=gNomCKg@02om?Ig005om?GfooBemcod]GKom7Cf_o@dm/00_o?
dMX02?o?cmWoc/oJolg=fOo=cMWoc<gJolc;fOo;bMSob/WI0_o9amP00oo8a]WoalCGolK4f002olG2
e`;o`l3G0oo1_ML2oknkeP06okjkeonm^MKo_KWFok^heonk]mGo^KKF0_ni]=D2okNceP04okJce_ne
/MGo/k7Fok>_e0;o/JkE00Ko[jgFojn/e?n]ZmGo[J_Eoj^Ze_n[Z=@2ojVXe@;oYjOF00CoYJKGojFU
eOnSY=KoXjCF0_nQXmH00onOX]OoWj3FoifOeP03oi^Ne`03oiRMeonFW=SoUYcH00;oU9_H00?oTY[I
ohnIfOn?VMT00_n=V=T2oh^GfP03ohRFf_n6UM_oQYGK00;oPi?K00?oPI;KogjAg?mnTM`00_mlT=`0
1?miSmcoMhkLogN>g?mdSMd2og6<gP03ofj;g_m/R]koK8[N00;oJ8WP0_mVR>001OmSQn3oGhOQoen7
hOmMQ^7oFhGQ00;oEhCR00CoEH?Roe63homAPn?oCh;S0_m;P^@2odZ1i003odJ1iOm5PNGoAH7U00?o
@X7V00Co0000ocb1iollPNOo?H;W0_lkP^P2ocZ3j@04oc^4jOlkQN[o?HO[ocf7ja[ooooo00?o0000
ooooooooool02oooool001;ooooo0_l0000Qooooo`;o_o3b0_o0l_400onolo7o`OC`ol;ek`02ol?f
kP06olCfkOo5mngoa_O/olKgk?o7mn_obOSZ0_o:n>X01?o;n>Woc?SXolghj?o=n>P2ologi`05om3g
iol0003o0000o`000?oCmNH00_oDm>D00ooCm>Goe?CUomGci002omKbi00:omK`hooGkn?oenkRomO^
h_oHk>;of>_QomSYhOoHj^;of>SQomSWh0;of>GO00?of>?OomOTgooGh]l00_oGh=h00ooFg]goe]kN
omGMg@02omGKg009omCIfooCfMcodmOKom?GfooBeM[od]GKom7Cf_o@dMWocm7J00;ocloI00Goc/gH
olg=fOo=bmSoc<_Iol_9f002ol[7e`06olW7f?o8aMOob<GGolO4eoo6`]KoaL;G0_o4`=H00oo3`=Oo
`[kFol6me`02ol2le@03oknke_nn^MGo_KWF00;o_;OD00Co^kOEokZde?ni]=Go^;;C0_ng/]@00one
/MGo]:oDokB_e002ok>_e006ok6^eOna[=Co[jcDojn/e?n]ZmGo[JWD0_n[Z=@01?nYZ=GoYjGDojNU
e?nWYM@2ojFUe@05oj>Te_nQXMGoXJ7Eoj6QeOnOX=H00_nMWmH00onKW]OoVigEoiVLeP02oiJKeP?o
U9[G00?oTYWGoi2Hf?n@V=P00_n=UmP00on;U]WoRIGIohVEf@02ohJDf@;oQ9?J0_moT=X2ogf?f`;o
NhkK00CoMhkLogB=gOmdSMgoLXcM0_m`Rmd2ofb:gP;oJXWN00GoIhSOofF7gomUQmooHHKPoen5h002
oe^5h@04oeV4hOmGPn7oEh?Qoe>3hP;oDX;R00CoCX;Sodf1hom=PN?oBH7T0_m8PN@2odF1i@;o@X7V
00Go0000ocn1i_m0P^Oo@8;Wocj2i`02ocb3j0;o?XCY00?o?HGYocf7jolmQn/06Oooool00ol0003o
ooooooooo`0;ooooo`004_ooool00ol0003oooooooooo`0Nooooo`?o_nob00?o_o3bol3blOo2lo00
0_o3m>l01?o4m>koaOG]olKfkOo6m^d2olOfk006olWgjoo:mn[oboOYol_gjOo<mnWocOOX0_o?mnP0
1?o=n>So0000o`000?l00002om;fiP04om?ei_oDm>Goe?CUomGci0;oe_;T00Woeo7SomO`hooGl>?o
f>kRomS]h_oGk^;of>cRomS[hOoHjN400_oHj>000ooHi]oof>CNomSUg`02omSSg`04omSQg_oGgmgo
en3NomKNg@;oe]cL00?oe][KomGKg?oDfM/00_oDemX02OoCem_od]GJom;CfOoBdmWodM7Hom3AfOo@
cmSocloIolk=f002olg;e`04olg;f?o<bMOoblOFol[7e`;obLGF00Kob<GGolO3e_o7`mKoa/;FolK0
eOo4`=H2olBne@03ol:ne_o2_=Co`;cE00;o`;[D00?o_[WEokjge?nl]m@00_nl]M<02?nj]=Co^;;C
okRbdonh/]?o]k;DokJ`dond[mCo]:kB0_nb[M<00ona[=Co/:_CojjZd`02ojjZd`07ojfYe?n[Ym?o
ZjOCoj^WdonYY]CoYjGDojNTd`02ojFSe0;oXj;D00?oXJ7Eoj6Pe?nOWm@00onMW]D2oi^Me@06oiVL
e_nFVmKoUY_FoiBJeonDVMGoTYSF0_n@UmH2ohjFe`03ohbEeon9U=SoRICH00;oQi?H0_n5T]P00on3
TMWoOi3Jogn@fP02ogf?f`;oNhkK0_mfS=/2ogB;f`;oL8_M00CoKXWMofb8gOm/R=goJHOM0_mUQml0
1?mSQ]ooGhGPoen5h?mMQN02oe^4h0;oEh?Q00CoEX?Qoe:2h_mBP^;oD8;R0_m=PN<01?m<PN?oB87T
odR1i?m8PN@3odF1i@06o`000?m2PNKo@8;Wod22iom1P^Oo?h?X0_m0Q>P2ocn5j@;o?hOZ6Oooool0
0ol0003oooooooooo`0:ooooo`004_ooool2o`0001kooooo0_o0k_800onoko;o`O7aol;bl002olCc
k`;oaOC^00Koa_C^olOekOo7mNgob?G/olOfk?o9mn/2ol[gjP04ol_gjOo<mnWocOOXolggj0?o0000
0_oBm^H00ooCmNKoe?CUomCdi@02omGci009omKbi?oGlN?oeo7SomO`hooHkn;oeo3SomS^h_oHkN;o
fNcQ00;ofN[P00KofNSPomWWgooIimoof>SPomSVgooHi=h2omSSgP04omSQgOoHhMkoemoMomOMg0;o
emcK00Goe]cLomKJfooEf=[oe=KJomCGfP02om?DfP09om?BfOoBdmWodM7Hom7Af?oAcmSod<oHolo=
eoo>bmKocL_G00;ocLWF00Coc<WGol_7e_o:aMGobLGF0_o8`m@00oo7`mKoal7DolK0e@02olFne006
olBneOo3_=Co`kcDol:le?o1^]?o`;[D0_no^=<01?nn]mCo_KKBokbedonk/m82okZcd`04okRbdong
/M;o]k7BokJ`d`?o]:kB00Ko/ZgCok:[d_n`Zm?o/:_CojjZdon^Z=82ojbXd`04oj^WdonZYM;oZ:GC
ojRUd`;oYjCC00CoYJ?Doj>QdonSXM?oXj7C0_nQX=@00onOWmCoWIkEoifMd`02oi^Le0;oVI_D0_nG
V]D00onDVMGoTYSFoi:HeP02oi2GeP;oSYKG00?oS9GGohVDf?n9U=P00_n7TmP00on5T]SoPi7Ioh>A
f@02oh2@f@04ogj>fOmlSMWoO8gIogV<fP;oMXcK0_mdRm/01?maR]coKhWLofn9g?m/R=d2ofV7g@04
ofN6g_mUQ]koIHKNof65g`;oGhCO0_mKQ>001?mJPn3oF8;PoeR2h?mDP^42oe>2hP04odn1h_m>PN?o
CX7Sod^1h`;oB87T00KoAh7TodF1iOm5PNGo0000odF1iOm2P^H2od>2iP03od:3iom0Q>So@8CX00;o
@XGY00?o@XOZooooooooool06?ooool00ol0003oooooooooo`09ooooo`004_ooool00ol0003ooooo
ooooo`0Mooooo`04ol3^l_o2ko7o`o7`ol?al0;oa?;_00KoaO;^olGdk_o6m>koa_C^olOekOo8mN`2
ol[fj`04ol_fj_o<m^WocOKYolkfj0?o00000_oBmNH2om?eiP03om?diOoDlnGoeO?T00;oe_;T00Ko
eO?TomKbi?oGlN?oeo3SomS_h_oHkN42omW/h@06omW[h?oIjMoofNWOomWZh?oIj>3ofNOO0_oIiMh0
1?oIi=gofN;MomSSg_oHhMd2omSOg003omSMfooGgMcoemcK00;oe][J00Koe]SJomGHf_oDe][oe=CI
om?Df_oCd]T2om;@f008om7Af?oAcmSod<gGom3=eoo?cMOoc/_Folk9eOo=bMH2olc7e@04ol_7e_o:
aMGobL?DolS3e0;ob<7C00?oal7DolJndoo5_]@00_o4_=<00oo3_=Co`[[Bol6jd`02ol2hdP04oknh
donn]];o_[KBokffdP?o^k?B00Co^[?CokVad_ng/M;o]joA0_ne[]801?nd[];o/jcAok>/dOnbZm83
ok2Yd@04ojjXd_n/Z=?o[:KAojbVd@;oZZGB00OoZ:GCojJSd_nVXm;oYZ?BojBRd_nSXM?oXioB00;o
XIkB0_nOW]<2oifMd`03oi^Le?nIVmCoVI[C00;oUiWD00?oUISDoi>Ge?nCUm@00_n@U]D2ohjEeP;o
S9CF00CoRY?FohRBeon8T]OoQY7G0_n3T=L2oh6?f0;oOhkH00CoO8gIogV<f_miS=[oMh_J0_meR]X2
og>9fP;oKhWL0_m[Qm`2ofV6g003ofF6g_mSQMkoHhGN00;oGhCO00CoGXCOoeb3gomLPmooF8;P0_mG
P^400omCP^;oDX7Roe:1hP03odj1h`?oBX7T00?oAh7Uo`000?m7PND00_m5P^H2od>2iP04odB3iom3
Q>SoA8GXodB5j0;oA8OY6?ooool2o`0000_ooooo0003ooooo`?o00000oooool3o`0000Kooooo00?o
0000ooooooooool06oooool00oo0kO;o`^kaol?_l002ol?_l003olG`koo4l^ooaO;^00;oao?^00Go
b?C]olWdk?o;mN_oboG[olcejP02olgej@?o000000Sod?GWom7diooBm>Kod_CVom;ei_oCmNKodoCU
omCci@;oeO?T00?oe_;TomOahooHl><00_oHkn802?oIk^7ofNgQomW[h?oIjn3ofNcQomW[h?oIjMoo
fNSO0_oJi]h01?oJiMgofNGNomWTgOoIh]d2omWPg003omSNfooHgmcof=gK00;oem_J00?oemWJomKJ
f_oFf=X00_oEe]T01OoDe][oe=CIom?Bf?oCd=Ood]3H00;odLkG00SodLgFom3=eoo?bmKocl_Folk;
e_o>bMGocLODolc7e@;oblGD00?ob/GEolW3e?o8`M<00_o8`M<01?o7_m;oa[kColFmd_o4_=<2ol>k
dP03ol:jd_o1^M7o`;SB00;o_kKA00Go_[KBokfddOnl]=7o_;CAok^cdP02okZbd@08okVad_nh[m3o
]joAokN_dOne[];o]JgAok>/dOncZm02ok6Zd@06ok2YdOn_Z=3o[ZOAojjWdOn/Y]7o[:G@0_nZY=42
ojRSd@04ojJSd_nVXM7oY:3AojBPd@;oXioB00?oXIkBoinNdonNW=800_nMW=82oi^Kd`;oVI[C0_nG
VM@00onEV=CoTiODoi>Ge002oi2Fe@03ohjEe_n=TmCoSI?D00;oRi;E00?oR9;GohJAeon6TML00_n3
T=L2oh6?f004ogn>f?mmSMSoNhcIog^<f@;oNH_I0_meR]X2og>9fP05og68fom_Qm_oJhOLof^7g?mY
Q]`00_mWQMd2of>5gP03of:4g_mPPmkoH8?N00;oG8?O00CoFX;OoeN2hOmGP^7oEX;Q0_mBPN801?mA
PN;oCX7Sodj1hom=PN<3odZ1i003o`000?m7PNGoB8;U00;oAX;V0_m6PnH01?m5Q>OoA8GXodB5j?m6
QnTJooooo`03o`000?oooooooooo00Sooooo0004ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o`>_bol;]lOo2kO400_o4
k_001_o3ko3oaO3_olKak_o6lNkoao;^olWck@;ob_?/0_o;m>/01oo=m>[o0000o`000?l0003oc_GY
oloej?o@mNL00_oAm>L00ooBm>KodoCUomCci@02omGbi007omKbi?oGlN?oeo7SomS`hooHkn;ofNkQ
omS_hP02omW^h@03omW]hOoIjn3of^[O00;of^SO00Cof^ONom[UgOoJi]kof^GM0_oIhmd01?oIhMco
fMoKomWPg?oHg]/2omSLfP03omSKf_oGfm[oemWJ00;oe]OI00Woe]GHomGFfOoDe=Soe=CHomCBeooC
d]Sodm3Gom;>e_oAc]L00_oAcMH02?o@bmGocl_Folk9e?o>bMCoc/WEolg7e?o<aM?oblGD0_o;`m<0
0oo9`mCobL7ColS1d`02olNodP04olJmdOo5_M;oa;_Aol>kdP;o`kWA00Co`KWAoknfdOno]]7o_kKA
0_nm]=401onl]=7o_;;@okbbd?nj/]7o^[3@okR_d?nh[/l00_nf[M000one[M7o]:_@ok>[d002ok>[
d005ok6ZdOnaZ=3o[jS@ojnXd?n^Ym400on/YM001?nZY=7oZ:;@ojRRd?nXX]02ojJQd@03ojBPdOnR
W]7oXYkA00;oXIgA0_nNW=82oifLdP03oi^KdonIVM;oVIWB00;oUiSB0_nEUm<2oi>Fd`03oi6Ee?n?
U=CoSiCD00;oSI?D0_n;T]D01?n8TMGoQY3FohJ@e_n4SmH2oh:>eP03oh2=eomnS=OoOXcG00;oNhcI
0_miRmT01?mfR]WoM8WIogB9fOmbR=X2ofn7f`03off7fom[Q]_oJhKK00;oIhGM00?oIHGMof>4gOmS
Q=d00_mPPmh01?mNPmkoGH;Noef2g_mIP]l2oeR2h003oeB1hOmCPN7oDh7Q00?oD87R00CoCH7Sodb1
hom<PN?o00000_m:P^@2odR2i@;oAX?V00CoB8CWodN5j?m8QnSoB8OX6?ooool3o`0000Wooooo0004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0001Wooooo00Oo`>[b
ol;[lOo2jo7o`^_aolC]l?o4k_3oaNo_00;oa_3^0_o8lNh01Oo9l^gobo;/ol_bk?o:lncoboC[00;o
000000Coc_CYolodjOo@m>SodOCW0_oBlnH01?oClnKoe??UomCciOoEl^D2omKbi005omOahooGl>?o
eo7SomS`hooHkn800_oIk^402OoIkN7ofNcPomW/h?oJj]oof^WOom[Xg_oJj=oof^ONom[Ug@02om[T
g@03om[Rg?oIhmgofN7L00;ofMoK00CofMkJomWLf_oHg=[of=_J0_oGfMT01ooGemSoe]OIomKEf?oF
eMSoeM?GomCDf?oDd]L00_oCd=H01?oCd=Ood/kFom7<eOoAcMH2om3;e@04olo9e?o>bMCoc/OColg7
e0;oc<GC00Oobl?Bol_3doo9`M;obL7BolW1doo8_m;oakoB00;oa[gA0_o4^m43ol>id@;o`KO@00Ko
_kKAokned?no]M3o_KCAokfbd?nl/]02ok^`c`06okZ`d?nh[/oo^:k?okR^conf[M3o]Zc?0_ndZm00
1?ncZm3o/ZW?ok6Xd?n`Yll3ojnVc`03ojfVd?n/YM3oZj??00;oZJ?@00CoZ:;@ojNQconVX=3oYZ3@
0_nTWm02oj:Nd@03oj6MdOnNVm7oWY_A00;oWI[A0_nKV]42oiVIdP03oiNHd_nEUm?oUIKB00;oTiGB
00?oTICBohnCdon?Tm<00_n=T]<2oh^Ae003ohV@e?n7SmCoQhoD00;oQHkE0_n2S]H01?n0SMOoOXcG
ogj<eomlRmL2ogZ:f0;oN8WH00CoM8WIog:8f_mbR=[oL8OJ0_m^Q]X2of^6f`03ofV5fomWQ=coIhCL
00;oHhCM00CoHX?Mof23gOmPPmgoGH;N0_mKP]l00omHP^3oEh7PoeN1h003oe>1h@;oD87R00GoCh7R
odb1hol0003oC8;TodZ2i002od^3i@;oBH?V0_m:Q>H00om9QNOoB8OXodR7j00Dooooo`?o00000_oo
ool00ol0003oooooooooo`07ooooo`001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05_ooool2ol3Xl@;o`^[a00Co`^_aolC]l?o5k^ooaNk_0_o7
knh00oo8l>kob?7^olWbk@02ol_bk0?o000000Goc_?Yolocj?o@lnSod??Xom;ci`03om?biP08omCb
iOoDlnGoeO;UomGbiOoFl^Coeo7SomO`hooHkn82omW^hP;ofNgQ00Kof^cPom[[gooIk>3of^[Oom[Y
gooJj=h2om[Vg@06om[UgOoJhmcof^?Lom[TgOoJh]cof^7K0_oJgmX01?oIgM[ofMkJomWLf_oHf]T2
omSHf005omOIfOoGemSoe]GGomKEf?oEdmL00_oDd]H02?oDd=Godm3Fom?>eOoCc]God/cDom7<eOoA
bmCod<_E0_o?bM@2olk7d`06olg5d_o<aM?obl?Bol_3d_o;`M7obL7B0_o9_m400oo8_m;oakgAolJm
d@02olFkd003olBkdOo4^M3o`kWA00;o`[O@00?o`KO@ol2econo]M000_nn/ll01?nm/]3o_;7?ok^`
conj[lh2okV^c`04okR^cong[<ko]jc>okJ/c`?o]:[?00Ko/ZW?ok2Wcon`Yloo/:O?ojnVcon^YLh2
ojfTc`;oZj??00OoZJ?@ojNQconWXLooYj7?ojJPd?nTWm3oY9k?00?oXYg@00CoX9c@oijKdOnNVm7o
WI[A0_nKVM03oiVHd@03oiNGdOnEU];oUIKB00;oTiGB00?oTICBohnCdon?Tm<00_n=T]<00on;TMCo
RI3DohV@e002ohN?e0;oQHkE00CoPhgEoh6<e_moS=KoOhcF0_mmRmH2ogZ:f004ogR9f?mfR=SoLhOH
og>7f0;oLXOI0_m^Q]X00om/QM[oJhGJof^5fP02ofN4g005ofF4g?mTPmcoH8?Mof23gOmOP]d00_mK
P]l00omJPMooFH7OoeV1g`02oeJ1h0;oEH7P00OoDX7Qoe:1h_mBPN;oCh7So`000?m?P^?oCH;T00;o
Bh?U00?oC8?UodZ4i_m:Q>H00_m;QNL2od^7j13ooooo0ol00005ooooo`03o`000?oooooooooo00Oo
oooo0004ooooo`04o`000?ooooooooooooooo`Co00001Oooool00ol0003oooooooooo`0Dooooo`?o
`>Ka00?o`^Saol;ZlOo4jo000_o5k>l2olO]kP04olO_k_o8l>kobO3]olW`k@?o000000KocO;Zolob
jOo?l^Wod?;Xom7bj?o@lnP2om;ci`;odo;V00Coe?;UomKai?oFlNCoe_7T0_oGl><02OoHkn;of>kR
omW]hOoIkN7ofNkRomW]hOoJk>3of^_Oom[Yg`02om[XgP06om_WgOoKiMgofnGMom[VgOoJiMgof^?L
0_oJh]/00ooJh=[of^7Kom[OfP02omWMfP03omWKfOoIf]Sof=[I00;of=SH00KoemOGomOGf?oFeMOo
e]?FomGAeOoDd]H2omC@e@09om?>e?oCc]God/cDom;<e?oAb]?odL_Dom38doo?bMCoc/OC00;oc/GB
00?ocLGBolc3d_o;`m800_o;`M401?o:_m3obKoAolRmd?o7_M42olJkd006olFkd?o5^LooaKW?olBi
d?o3^<oo`[O@0_o1]/l00oo0]Loo_k?>okjcc`02okfacP08okbaconj[lko^Zo>okZ_c_ni[/oo^:g>
okN/c_nfZld2okFZcP06okBZconcZ<ko/ZO>ok:Wc_n`Yloo/:K>0_n^YLh00on]Y<oo[:?>oj^RcP02
oj^RcP03ojVQconWXLooYio>00;oYYo?0_nTW/l00onRWM3oXYc?oj2Kc`03oijJc`06oifId?nKVM3o
ViW@oiVHdOnIUm3oUiK@0_nEUM42oi>Dd@03oi6CdOn@T];oT9;B00;oSY7B00?oS93CohZ?don:Sm<0
0_n8Sm<2ohJ>e003ohB=e?n2S=CoPXcD00;oOhcF0_mmRmH01?mkR]OoNHWGogN8eomgR=L2og>7f0;o
LXOI00?oL8KIofj5fOm^QMT00_m[QMX01OmYQ=_oIhCKofB3g?mTPmcoHX?L00;oHH;M00CoGH;Noeb2
g_mLP]koFH7O0_mHPMl2oeF1h003oeB1hOmBPN;oDX7R00;oDH7R00Co0000odn2hom?P^?oCH?T0_m>
Q>D00om=Q>KoCXKVodj6iP02odf7i`gooooo0ol00008ooooo`03o`000?oooooooooo00Oooooo0003
ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`;o00005?ooool2okoTl@04ol3VlOo2j?7o
`nW`ol?Yl0;oaN__00Coanc^olO]k_o8k^kobNo]0ol000001_o<l>_oc_3Zolk`j_o=l^[oco;Yom3b
j0;odO;X00?od_;Wom?ai_oDlND00_oElND2omK`i004omO`hooGkn?oeo3SomS_hP;of>kR00KofNgQ
omW/h?oJjmoof^_Oom[ZgooJjMh2om_Wg@03om[Xg_oKimgofnGM00;ofnCL00Cofn;Kom_QfooJh]_o
f^3J0_oJg]X00ooJg=WofMgJomWKf@02omWJf003omSHeooHf=SoemOG00;oemGF0_oFdmH00ooEdMGo
e<oDomC@e@02om?>e009om;<dooBc=CodL[Com7:doo@b=;od<SColo7d_o>aM7oc/GB00;ocL?A00?o
c<?Bol_1dOo;`M400_o:_m001?o9_/oob;g@olNlcoo6^m02olJjc`03olFicoo4^<oo`kS?00;o`[K>
00Co`KK?ol2dc_no/lko_[;>0onm/Lh2ok^_cP04okZ_c_nj[Lgo^Zg=okR]cP?o]Z_=00Ko]J[>ok>X
c_ncZ<ko/jS>ok:Wc_naY/d2ok2VcP06ojjUc_n/Xlko[:?>ojbSc_n[X/koZZ7=0_nYX<h2ojNOcP05
ojJOconTWLkoY9g>ojBMc_nRW<l00_nPVll00onNV/ooWYW>oifHc`03oi^Hc`03oiVGd?nGU]3oUiK@
00;oUIGA00?oTiCAoi6CdOnATm400_n@T]82ohjAdP03ohb@don:Sm?oRXoC00;oR8oC00?oQXkDohB=
e?n4SM@00_n2S=@01?n0RmGoOX[Eogj:eOmlRMH2ogV9e`;oMhSG00?oMHOGog>6f?mcQ]P00_maQ]P0
1?m^QMWoK8GIofb5fOm[Q=X2ofN4f`04ofJ3fomTPm_oI8?Kof62g@;oGh;M0_mLP]h01?mKPMkoF87O
oeR1gomGPMl2oeN1h005oeB1hOmDP^7oE8;Qoe62h_l000000_mAP^<01?m@PnCoCXCUodj4iOm?QND2
odj6iP;oChOW2?ooool4o`0000_ooooo00?o0000ooooooooool01oooool000Cooooo00Co0000oooo
oooooooooooo1Ol00004ooooo`03o`000?oooooooooo017ooooo0_nnho401?noi?7o`NKaol?Xl?o3
j?02olGYk`03olG[koo7k>kob>g^00?o000000Oobnk/ol_`k?o<l>_oc?3[olk`j_o?lNWod?7X00;o
dO7W0_oBlNL02?oCl>Koe?3UomG`i?oEl>CoeO7UomK`i?oGl>?oenoS0_oHk^82omW]h@05omW/hOoJ
jn3of^[Oom[[gooJj]l00_oJjMh01ooKimgofnKMom_VgOoKiMcofn?Kom_Tg?oKh]/00_oKhM/01?oJ
gm[of]gIom[Nf_oJg=T2omWKf003omWIeooIf]Sof=SG00;of=KF00[oemCFomOEe_oFdmKoe]?FomKA
e?oEdMGoe<oDomC>dooCc]Cod/cC0_oBb]802?oAb]?od<SBom38d_o@am7oclOBolk5dOo>`m3ocL?A
0_o<`M000oo;`M7obko@olZod002olVnc`;oakc?00Soa[[>olJjcoo5^<koaKS>olBhcoo3]/ko`[K>
ol6dc@;o`;C>0onn//h00onm/Lko_K3=ok^_cP02ok^^c@05okZ]cOni[<co^:_=okR[cOnfZld00_nf
ZLd01OndZLgo/jS>ok:WcOnbYlgo/JK=00?o[jC=00?o[ZC=ojbSc_n/X/d00_nZXLd01?nYX<koZ9o=
ojNNcOnWW/d2ojFMcP03ojBMc_nTW<goXY_>00?oX9[>0_nNVLh01?nMV<ooViS?oi^Gc_nIU/l2oiNE
c`;oUYC@00CoU9?@oi:Bd?nBT]3oTY;@0_n@TM401?n>T=7oS93Aohb@dOn:Sm82ohR>dP03ohJ=don4
S=?oQ8cC00;oPh_C0_n1Rm@01?mnR]GoO8WFogb9e_mjR=H2ogR8eP;oMXOF0_mcQ]P01?maQ]SoKhGH
ofj4f?m^Q=P2of^4fP04ofV3f_mWPm[oIh?JofB3f`;oHh;L0_mOP]d01?mNP]goGH7Moef1gOmJPMh2
oeZ1g`06oeN1h?mFPN3oEX7PoeB2hOmDP^;o00000_mAP^<2oe:3h`04oe24i?mAQNGoDHGUoe26iP;o
DHOV1Oooool3o`00013ooooo00?o0000ooooooooool01_ooool0017ooooo00?o0000ooooooooool0
3oooool2okgQl@03okkSlOo0i?7o`>Ca00;o`^K`00?oa>O_olGYkoo6jnh00ol000000oo9k>gobNk]
ol_^k002olc_j`04olk_j_o?knWocnoYom3`j0;odO3W00?od^oWom;aiooCl>H00_oDl>D01OoEl>Co
e^oTomO_hooGkn?of>kR00;of>gR00CofNcQomW]hOoIk>7of^_P0_oJj]l02?oJjMkofnSNom_Xg_oK
i]gofnGLom_VgOoKiMcofn?K0_oKh]/01?oKh=[ofn7Kom[Of_oJgMT2om[Lf003om[Jf?oIfmSofMWG
00;of=OG0_oHe]H2omODeP03omOBeOoFdmKoe]7D00;oeLoD0_oDc]<00ooCc=?od/[Bom;:dP02om78
dP06om38d_o@am7od<OAolo5d?o>aM7oc/?@0oo<`M001?o;_loobko@olZncoo9_/l2olRlc`03olNl
coo6^/koaKS>00;oaKS>0_o3]/h3ol6dc@03ol2dc_no//go_[;>00;o_[3=00Co_K3=okb^c?nk[/go
^Zg<0_ni[<`01OnhZlgo]j[<okNZc?nfZLgo]JS<00;o]:O<00Ko/ZO=ok:Vc?naYLco/JG<ojnTcOn_
Xl`2ojfRc0;o[:;=00GoZZ7=ojROcOnXWlgoZ9o=ojNNc@02ojFLc@?oY9c=00?oXY_>oj2Jc_nPVLd0
0_nNV<d01OnMUlkoViO>oi^Gc_nKUlkoVIK?00;oUiG?0_nFU=000onDTm3oTY;@oi:Ac`02oi2Ad003
ohn@d?n=Sm7oSHoA00;oRhkA0_n8S]800on6SM?oQ8cCohB<d`02oh>;d`;oPH_D0_mmRM@2og^8e@;o
N8SF0_mfQmH01OmdQ]OoLhGGofn5f?m_QMSoKXCH00;oK8CI0_m[PmT00omWPm[oIX;JofJ2fP02of>2
g004of:2g?mQP]coHH;Loef1g@;oG87N0_mJPMl01omIPMooEX7PoeJ1h?mFP^7oE8;Ro`000?mDPn80
0_mBPn<2oe:4i0;oDHGU00CoDXKUoe67i_mAQnKooooo0ol0000Cooooo`03o`000?oooooooooo00Ko
oooo000@ooooo`;o00003oooool2okcNl@03okgQlOnoho3o_n?`00;o`^C`00?o`^K`olCWkol00000
0_l000000oo7j^kob>c^olW/k@02ol_]k005olc^joo>k^[oc^kZolo^jOo?knT00_o@l>P01OoAl>Oo
d^oWom?_i_oCknKoe>oU00;oeNoT00?oe^kTomO^hooGkn<00_oHk^800ooHkN;ofNcQomW[h002om[Z
g`;of^WO00GofnSNom_WgOoKj=kofnKMom_Ug002om_Tg003om_RfooKhM[ofn;K00;ofn3J00WofmkI
om[Mf?oJfmSof]_Hom[Lf?oJf]SofMWGomWGe_oHemL00_oHe]H00ooGe=GoemCFomOBe@02omKAe009
omG?dooEcmCoe<kComC>dooCc=;odlcCom;:d_oBb=7odLSB00?od<OA00KoclG@olk3d?o>`m3oc/?@
olg2coo<`M02ol^oc`04ol^nc_o:_/oobKc>olRlc`;oak[>00?oa[[>olJhcOo5^<h00_o4]ld00oo3
]/ko`[C=ol6dc@02ol6cc003oknbcOno/Lco_[3=00;o_Jo<00So_:k<okZ]c?nj[Lco^Zg<okV/c?nh
Zlco]j[<okNYb`;o]JS<00Ko]:O<ok>VbonbY/co/ZK<ok6Uc?n`Y</3ojnSc007ojfRc?n/XLco[:7<
ojbQc?nZX<coZ9o=ojRNc002ojNMc0;oYIc=00?oY9c=oj>Kc?nRV/d00onPVLd01_nNV<goWIO>oifG
c_nKUlkoViK=oiVEcP;oV9C>0onFTll00onDT/ooTY7?oi:Ac`02oi2Ad003ohn@d?n=Sm7oSHoA00;o
RhkA00CoRHgAohN<d_n5S=;oQHcB0_n3Rm82oh::d`03oh29dommRMCoOHWD00;oNhSE00CoNHOEogN6
eOmgQ]GoMXKF0_mcQML00omaQMOoKhCHofn4f002ofb4f@03of^3fOmYPmWoJH?I00;oIX;J00?oIH;K
ofB2fomTP]/00_mQP]`01?mOPMcoG87Noeb1g_mLPMh2oe^1gP07oeV2gomHP^3oF8;PoeJ2hOl0003o
EX?QoeB3hP03oeF4h`05oe>5i?mDQ^GoE8KUoeB7i_l000005_ooool00ol0003oooooooooo`06oooo
o`004?ooool00ol0003oooooooooo`0=ooooo`;o^mca00Go_=kaokkQl?o1h_3o`N;`ol;Tl003o`00
0004olGWk_o7j>koan[^olW[k@;obnc/0_o<k>/01_o=kN[oc^kZolo^jOo?k^Wod>kXom7^i`;od^kV
0_oCk^H01?oDk^GoeNkTomG_i?oFk^@2omO^h`05omS]h_oHk>7ofN_QomW[hOoIj^000_oJjMl01?oJ
j]oof^WOom_Xg_oKimd2om_Vg003om_Tg?oKhm_ofnCL00;ofn;K00?ofn7Jom_OfOoKgmT00_oKg]T0
1ooJgMSof]_Hom[Kf?oJf]OofMSFomWIeooIemH00_oHeMD01OoHe]KoemCEomOBe?oFd=?oe]7D00;o
eLoC00WoeLgBomC>dooCc=;odlcBom?:dOoBb];od/SAom77d?o@am400_o@aM001?o?`looc/?@olg2
coo=`/l2olc0c`07ol^ocoo;_/kobkk>olZlcOo9_<kob;[=olNjcP02olNic@03olJhcOo5]lgoa;O=
00;o`kG<00?o`[C=ol:cc?o1/l`00_o0/L`01?no/Lco_Jo<okf_c?nm[l`2ok^]b`04okZ]c?niZl_o
^J_;okR[c0?o]jW;00Go]JS<ok>VboncY/_o/jK;ok:Vc003ok2Tb`06ojnSc?n^X/_o[J7;ojfQbon/
XLcoZio;0_nZW//2ojRNc005ojNMc?nUVlcoYI_<ojFKc?nSVl`00_nRV/d00onPVLgoX9S<oijGc@03
oifGc@;oViK=00KoVIG>oiRDc_nHU<koUY??oiJBc_nDT/h2oi:AcP;oTI3?00?oSho?ohf>d?n=S]00
0_n;S]000on9SM3oR8cAohR<d@02ohF<dP;oPh_B00CoPX[Coh29domnR=?oOXSC0_mlR=@2ogZ7e004
ogN6eOmfQ]KoM8GFogB5eP;oLXGF0_m_Q=P00om^Q=SoK8?Hofb3f002ofV3f@03ofR2f_mVP][oIX;J
00;oI8;K00?oHX;Kof:2g?mRP]`00omNPMd00omKPMkoFh;Ooe^2g`03oeR2h003o`000?mFPn7oEh?R
00;oEHCS0_mFQN<2oeB6i@03oeJ7iOoooooooooo01Cooooo00?o0000ooooooooool01_ooool0013o
oooo00?o0000ooooooooool02oooool2okWJl005ok_LlOnmg_3o_n3`okoPl?o1h_000_l00002olCU
kP04olGWk_o7j>kobNW]olWYk@;ob^[/00?oc>_[olc/joo=kNX00_o?kNT2om3]j007om7]iooBkNKo
d^gVom;^i_oCk^Koe>kUomG^i002omK]h`;oencS00Cof>cRomS[hOoIj^3ofN_Q0_oIj^001ooJjMoo
f^SNom_WgOoKimgofnKMom_Ug?oKi]`00_oKi=`01?oKhm_ofn;Jom_Rf_oKh=X2om_Of@06om_NfOoK
g=SofmcHom[KeooJfmSof][G0_oIf=H00ooIemGofMOFomSEe@02omSCe006omOBdooGd]Coe]3ComK?
d_oEcm?oeLgB0_oDc=402?oCc=;odl[Aom;8d?oBb=3od/SAom77d?o@aLood<G@0_o?`ll2olg2c`03
olg0c_o<`<oobkk>00;obkk>0_o:_<d2olRjc@07olNic?o7^Lgoa[O<olJgc?o5]lgoa;G<ol>ec002
ol>cb`04ol:cc?o0/Lco`;7<ol2ac0;o_Zo;00Oo_Jo<okb]bonl[L_o^jg;ok^/boniZl_o^J[:00;o
^:W;00Go]jW;okJWb_neYl_o]JO;ok>Vb`02ok>UbP07ok6Tbon`Y<_o/:?:ok2Sb_n^X/_o[J7;ojfP
b`02oj^Ob`04ojZNbonYWL_oZ9g;ojRMb`;oYYc;00?oYI_<ojFJbonSV//00onRVL`2oj2Hc003oijG
cOnMUlgoWIK<00;oViG=00GoVIC=oiRCcOnHTlgoV9?=oiJBcP02oiBBcP;oTY7>00?oTI3?ohn?con?
Sll00_n=S]02oh^>d004ohV=d?n8S=7oR8cAohJ;d@;oQ8[A00?oPXWBoh69d_n1RM800_mnR=<2ogb8
e004ogZ7e?miQ]CoMhKEogN6e@;oM8GF0_mbQMH00omaQ=OoKhCGofn4e`02ofb3f003of^3f?mYP]Wo
JH;I00;oIX;J00CoIH;JofB2fomTP]_oHX;L0_mQP]`2oej1g@07oef2g_mKP]ooFh;Ooe^2gomJPmoo
0000oeR3h@02oeV4h@03oeN4h_mHQN?oF8GS00;oEhKT0_mHR>DEooooo`03o`000?oooooooooo00Ko
oooo000@ooooo`;o00002_ooool2okSHl004okWJl?nlg?3o_=c`okkNl0?o00000_o4i>h00oo4iNko
a^O^olKWkP02olSXk@03olWXk?o:j^coc>_[00;ocN_Z0_o>k>T00oo@k>Sod>gXom7]i`02om;]iP04
om?]i_oDkNGoeNcTomG/i0;oe^cS00Coen_RomO/hooHk>;of>_Q0_oIj^02omWYg`05om[XgooJimko
fnKMom_WgOoKi]d00_oKiM`2om_Tf`04om_RfooKhM[ofn;Jom_PfP;ofmoI00CofmgHom_LeooKg=So
f]_G0_oJfMH00ooJf=KofMSFomWGe@02omWEe0;of=?D0_oGd]<01_oGd=?oe]3ComK?d_oEcM;oe<_A
omC<d@;odl[A00?odlS@om;8d?oAam000_oAam000oo@aLoocl??olo3c`02olk2cP04olg2coo=`<ko
c;k=ol^ncP;obkc=00?ob[c=olVkcOo8^/d00_o7^L`3olJgc0;oa;G<0oo3/l/2ol6bb`06ol2ac?no
/<_o_k3;okj_bonm[/[o_:g;0_nl[<X01Onk[<_o^J[:okVZb_niZ/[o^:W;00?o]ZO:00Co]JO;okBV
b_ncYL[o/ZC90_naXlX01?n`Xl[o[j79ojjQb_n^XLX2ojfPb`04oj^ObonYWL_oZIg;ojVMb`;oZ9g;
00OoYYc;ojFJbonUV/_oYI[;oj>JbonRVLcoXYS;00;oX9O;0_nNU/`2oifFc006oi^EcOnIU<goVIC=
oiRCcOnHT/coUY;=0_nDTLd2oi>@cP03oi6?c_n?SlkoSho>00;oSXk?0_n<SLl00on:S<ooR8_@ohR;
d002ohN;d003ohB:dOn2RM;oPXWB00;oPHWB00?oOhSBogf7dommQm<00_mkQm<01?miQ]CoMhKEogN6
eOmeQMD2ogB4eP;oLXCF0_m_Q=L01?m^PmOoKH?Hoff3f?mYP]T2ofR2f@04ofN2f_mTP]_oI8;Kof>2
f`;oHH;L0_mPP]`2oen2g@?oGH;N00CoFX?Oo`000?mKPn3oFHCQ0_mIQN82oeR5h`03oeV7i?mHR>Go
F8SU01Gooooo00?o0000ooooooooool01_ooool0013ooooo00?o0000ooooooooool01oooool2okKE
l003okSHl?njf_3o^][`00?o00000_o0h>l01?o2h^koa>C^olGUk_o5iNh2olOVk@04olSXkOo9j>co
bnW[ol_Yj`;ocN[Z00?oc^[Yolk/jOo@k>P00_oAk>L01?oBk>KodncVom?/i_oDk>D2omG[i004omG/
i?oFk>?oen_RomS[hP;of>[Q0_oIjN001?oIj=oofNWOom[XgooJimh2om_Vg@07om_Ug?oKi=cofnCL
om_SfooKi=_ofn;Kom_QfP02om_Of@03om_Nf?oKgmWofmgH00;ofmcG00Cof][Gom[Ie_oJfMKof]SF
0_oIe]D01ooIe=CofMGDomSCe?oHdmCof=7ComOBdooGd=<00_oFcm801OoEcM7oeLgBomC;dOoDb]3o
dl[A00;odlS@00Sod/K?om77d?oAaLoodLG?om35coo?`loocl;>olk2cP?ocL3>00?oc;k=ol^mc?o;
_<d00_o:^l`00oo9^lgob;W<olNic002olNgc003olJgc?o5]/_oa;G<00;o`kC;00?o`k?;ol:bboo1
///00_o0/<X01?no/<_o_Zk:okf^b_nm[LT3okb/bP;o^Z[:00Go^J[:okRXbOngZ<[o]jS:okJWbP02
okFVb@05okBVb_nbY<Wo/ZC9ok:TbOnaXlX00on_XLT01on^XL[o[9o9ojbObOn/WlWoZik:ojVMbonY
W<T00_nXW<X2ojJKb`03ojFJbonTVL[oXiW;00?oXYS;00?oX9O;oijFc?nNU//00_nMUL/00onKU<co
VI?<oiVCc003oiRBc003oiJBcOnDTLgoU97=00;oTi3>00?oTHo>ohn?c_n?Slh00_n>S/l00on<SLoo
RXc?ohZ<c`02ohR;d0;oQh_@0_n3RM42oh:8d@;oP8SB0_mmQm<01?mkQm?oNXKCogR5e?mhQM@2ogN5
e0;oM8CF00?oLXCFog64e_maQ=H00_m_PmL01Om]PmSoJh;HofZ2f?mZP]SoIh;J00;oIX;J0omSP]/2
of:2g0?oGh;M0_mMP]h2oef3g`03o`000?mKPn3oFhCQ00;oFHGR00CoFXKRoe^7homKQn?oFXST5Ooo
ool00ol0003oooooooooo`06ooooo`004?ooool00ol0003oooooooooo`06ooooo`;o]=;`00Go]]G`
o`000?l0003o0000okgLl002okoNk`03ol3Pkoo2h^ko`^;^00;oa>?^00?oa^C]olOVkOo9in`00oo;
j>/00oo<j>[ocN[ZolkZj@02olo[j0;odN_W00?od^_Vom?[i_oCk>H00_oDk>D01OoEjnCoe^_SomOZ
h_oGj^;of>[Q00;of>WQ00Cof>[QomWYh?oIj=oof^ON0_oJi]h2om_Ug@04om_Tg?oKiMcofnCLom_S
f`;ofn;J00Cofn3Iom_OfOoKgmWofmkH0_oKgMP00ooKfmOofmcGom[Je`02om[IeP03om[GeOoIe]Co
fMKE00;ofMCD00?of=?ComSCe?oHdM<00_oGd=802OoFc]7oe/oBomG=dOoEcM7oeL_@omC;dOoDb]3o
dlS?om?8d002om;6c`08om75c_oAaLood<?>om33c_o?`loocl;>olk0cOo=`<h2olfnc@03olbncOo;
_Lcob[_<00;ob[_<00CobKW;olRic?o7^<_oakO<0_o6]//00oo5]/_oa;C;ol>db`02ol>bbP03ol:b
boo1/L[o`;3:00;o_jo900So_Zk:okf]bOnm[LWo_Jg9okb/b_nkZlWo^Z[:okVYb@;o^:S900Go]jS:
okNWbOngYlWo]JK9okFUb@02ok>Tb@06ok:TbOnbXlWo/J;9ok6RbOn_XLWo[j390_n^WlT00on/WlWo
[9k9oj^Mb@03ojVLb@03ojRLb_nVV/WoYY[900?oY9W:00CoXiW;oj:HbonQUl[oX9K;0onNU//2oifE
b`03oi^Dc?nITlcoVI?<00;oV9;<00?oUY7<oiF@c?nET<`00_nCSld00onASlgoT8k=oi2>c@02ohj=
cP03ohb<c_n;S<ooRhc?00;oRH_?0_n7R/l00on6RM3oPhWAoh>9d@02oh:8d@;oP8SB00CoOXOBogb6
d_mkQ]?oNhKC0_mhQM@00omgQMCoMHCDogF4e002og>4e@04og64e_m_PmOoKh?Gofj3e`;oJh;H00?o
JX;HofV2fOmYP]T00_mVP]X01?mUP][oIH;KofF2fomRP]`2of62g0;oGh;M0omOPmh01OmMQ=oo0000
oef4h?mMQ>3oFhGQ00;oG8KR0_mKQn<00omLR>Coooooooooo`0Cooooo`03o`000?oooooooooo00Go
oooo000?ooooo`?o00000oooool2ojo=l003ok7@l?ndd_3o000000;o000000Go^MO_ok_Jkonmg>oo
_Mc_okoNk`02ol7OkP;o`n7^00Coa>?^olKTkOo8iNcob>G/0_o:i^/00oo;j>_oc>SZolgYj@03oloY
j004om3YiooAjnOod^_Vom?[iP;oe>[U0_oEj^@00ooFj^?oenWRomOZhP02omSZh@05omSYhOoIj>3o
fNSPomWWgooJi]h00_oJi]d00ooJi]kofnGMom_Tg002om_Sf`04om_RfooKhM[ofn;Jom_Pf@;ofmoI
00KofmgHom_LeooKg=OofmgHom_KeooJf]H2om[He@05om[Ie_oJemGofMKDomWDdooIe=@00_oHdm<0
0ooHdM;oem3BomO@dP02omK>d@07omK=dOoEcM7oeL_@omG;d?oDbM3oe<[@om?8c`02om;6c`;odLG>
0_o@`lh2olo2c@04olo2c_o>`<gocKk<olfnc@;oc;g<00?obkg<olZkc?o:^l`00_o9^L/2olNhb`08
olNfb_o6]/_oaKC:olFdb_o4]<_oa;?:ol>bb_o2/LT2ol6abP?o_jo90_nn[LT01?nm[LWo_:_9okb[
bOnkZlT3okVYb@04okRXbOnhYlSo]jO9okJVb0;o]JG900Ko/jC9ok>Sb?nbXlWo/Z?9ok6RbOn`XLP3
ojnPb@05ojjObOn/W/Wo[9k9ojbNbOn[WLT00_nYW<T2ojNKb@;oYY[900?oY9W:ojBIbOnSV<X00onQ
UlX00onPU/_oWYK;oijEbP02oifDb`05oi^CbonJT/_oVY;;oiZBbonHT/`00_nFTL`2oiF@c003oi>?
cOnASlgoTHo=00;oT8k=0_n>SLh00on<S<koRhc?oh^<c`02ohV;c`04ohN:con6RM3oQ8W@ohB9d0;o
PXS@0_n1Qm400omoQm7oO8KBogb6dP02og^6d`03ogV5domhQM?oN8GC00;oMHCD00CoLhCEog:3eOma
PmKoLH?F0_m^PmL00om]PmOoK8;Hofb2f002ofV2f@04ofR2fOmWP][oIh;JofF2f`;oI8;K0_mQP]`0
1_mQP]goHH?Mof63gOmOPmkoGhCOo`0000;oGHCP0_mMQN42oeb6hP03oef7h_mNRN?oGXWS01Cooooo
00?o0000ooooooooool01Oooool000Go00000oooool2o`0000Kooooo00?o0000ooooooooool00_n/
b^l01?n_cO3o0000o`000?l00003okOEk`05okWGkonlfNoo_=W_okgLkoo0gNh00_o2gnh00oo3hNko
aN;]olGRk@02olOSk003olSUk?o:i^_obnOZ00;ocNOY0_o>inP00oo?jNSod>WWom7YiP02om;YiP;o
dnWU00?oe>WTomGZi?oFj^<00_oGjN82omOXh@04omSXhOoIimoofNSPomWWg`;of^KN00Sof^KMom[U
gOoJiMgofnCLom_RfooKhm_ofn;Kom_QfP;ofmoI0_oKg]P02?oKgmWofmgHom_LeooKg=Oofm_Gom[I
e_oJf]Kof]SE0_oJemD00ooIeMCofMKDomWDd`02omSBd`;of=7B00?oem3BomO>dOoFc]400_oFcM42
omG;d007omC9d?oCb<oodlS?om?8cooBa/ood/G>om75cP02om33cP03om32cOo?`/goc/3=00;oc/3=
00?ocKk<olbmc?o<_L`00_o;^l/00oo:^lcobK[;olVib`02olRhb`03olNhboo7]/[oaKC:00;oaKC:
0_o4/lX3ol:ab@03ol6ab_o0[lWo_jo900;o_jk900Co_Zg9okf/b?nlZlWo^j[80_njZLP01?niZLWo
^JS8okVXb?nhYlP3okJVb005okFUbOncXlSo/j?8ok>Sb?nbXlT00on`XLP01_n_X<Wo[Yo8ojfNb?n]
W/So[9k9ojbMb0;oZYc80_nYW<T00onWVlWoYYW9ojJIb@02ojBIb@;oXiS:00?oXIO:oj6FbOnPU/X0
0onNULX00onMU<_oVi?;oi^Cb`02oiZBb`03oiRAbonGT<_oUi3;00;oUI3<00?oTho<oi:>c?nBS/`0
0_n@SLd2ohj=c@03ohf<cOn;RlkoRh_>00;oRH_>00?oR8[?ohJ9con6RLl00_n4RM02oh:8d004oh67
dOmoQm7oOHKAogf6d@;oO8KB0_mjQM82ogR5d`04ogJ4e?meQ=CoLhCDog>4e0;oLH?F00?oL8?Fofj3
eom^PmL00_m/P]P01?m[P]SoJX;HofZ2f?mWP]X2ofJ2fP;oI8;K00?oHh;Lof>3g?mSPm`00_mQPmd0
1?mQPmkoGhCOo`000?mOQMl2of26h0;oGXKQ0_mOR>82oej9ha?ooooo00?o0000ooooooooool01Ooo
ool00005ooooool0003oooooooooool000000_ooool01?l0003oooooooooool00004ooooo`04o`00
0?ooooooooooojW6k`?o000000Go[lg_ok;@koned^oo]M;_okOEk`02ok[Gk`05okcIkonnfnko`=g^
ol3Mk_o2gnh00_o4hNd2olKRk004olOSk?o9i>_ob^GZol[UjP;oc>KY00?ocNOYolkWj?o?j>L00_oA
j>L2om;XiP03om;Yi_oCjNGoe>WT00;oeNSS0_oFj>801?oGin7oenSQomSXhOoIiml2omWVg`;ofNKN
00Gof^GMom[Tg?oJiMgofnCLom_Rf`02om_QfP05om_Pf_oKgmWofmoIom_OfOoKg]P00_oKgMP00ooK
fmOofmcGom_Ke`02om[IeP04om[HeOoJe]Cof]OEomWEe0;ofMCC00[ofM;BomSBdooHdM;of=7BomO?
dOoGd=;oelkAomK=d?oFcM7oeL_@0_oDbLl02?oDb<oodlS?om?6c_oCa/kod/K?om;5c_oA`lgod<?>
0_o@`/d01?o?`<coc/3=oljoc?o=_/`2olbmc0?obk_;00Cob[[;olVjboo9^<[ob;S;0_o7]lX00oo7
]/[oa[G9olFdbP02olBcb@03olBcb_o3/LWo`[7900;o`K3900Co`:o9okn^b?no[/Wo_Zc80_nm[<P3
ok^Zb004okZYb?njZ<So^JS8okRWa`;o]jK800Go]ZK8okFTaondY<So]:C8ok>Sb002ok:Rb005ok6R
b?n`XLSo/:38ok2Pb?n^WlP00_n]W/P2ojbMb004ojZLb?nZVlSoZ9_8ojRKb0;oYi[80_nVVLT01OnT
VLWoXiO9oj>GbOnSUlWoXIK900;oX9K:00?oWYG:oijDbOnMTlX00_nKTlX3oiZBb`03oiRAbonGT<_o
Ui3;00;oUI3<00?oTho<oi:>c?nBS/`00_n@SLd00on>SLgoSHc=ohf<c@02oh^;cP;oRH_>00CoR8[?
ohJ9con6RLooQHS?0_n3R=000on2Qm3oP8O@oh27d002ogf6d@;oO8KB00CoNXGBogV5domiQM?oN8CC
0_meQ=@00omcQ=CoLX?Eog:3e@02og63e@03ofj3eom]P]OoKH;G00;oK8;G00?oJX;HofV2fOmYP]T0
0omVP]X2ofF3f`;oHh?L00OoHh?Mof>4gOmSQ=goHHCNo`000?mQQMooH8KP00?oH8OQ0_mOR>800omP
RN?oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo0002ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool4o`0000;o[<[_00Co[lg_ok;?konbcnoo]M;_0_nhe>l0
0onjenoo_=W^okcIkP02okkKkP06ol3Mk_o2g^go`]k]olCPk?o6h^coan?[0oo9hn/00oo:iN[oc>KY
olgVj002oloVj0;od>OW00?odNSWom;Xi_oCj>D00_oDj>@2omGWh`04omGXhooFj>;oenOQomSWh0;o
f>KO0_oIiMl01?oIiMkofNKNom[UgOoJi=`2om[Sg005om_RfooKhM[ofn7Jom_Qf_oKh=X00_oKgmT0
1?oKgMSofmcGom_Mf?oKfmL2om_JeP03om[IeOoJfMKof]SE00;of]KD00?ofMGComWCdooIe=<00_oI
d]82omSAdP08omO?dOoGc]7oelkAomK<d?oFcM3oeL_@omG9cooDbLl2omC8c`;odlK>0ooBaLh00ooA
`lgod<;<om32c@02olo0c0;oc[o<00GocKg;olbmc?o<^l_oc;_;ol^kb`02olZjb`;obKS:00Oob;O9
olNgb_o7]LWoakG9olJebOo5/lWoa;?900;oa;;800?o`k79ol:`b?o1/<T00_o1[/P01ono[/So_Zc8
okj/b?nn[<So_Jc8okb[b?nkZ/P00_nkZLL01OnjZ<So^:O7okRWaonhYlOo]jK800?o]JC700Co]:C8
okBSaonbX/So/Z770_naXLL00on`X<So[io7ojjNa`03ojfNb007ojbMb?nZVlSoZY_8ojZKb?nXVlSo
Yi[8ojNIb003ojFIb004ojBHb?nSUlWoXiK8oj6Fb0;oX9G90onNU<T01_nMTl[oVi?:oi^Cb_nJT/_o
VY7:oiRAbP;oUi3;0_nESl/00onCS/_oTXk<oi:>c002oi2=c003ohn<c?n=S<goSHc=00;oS8_=0_n:
R/d00on8RLkoQhW>ohN9cP02ohF8c`;oPhS@00CoPXO@oh27d?n0Qm3oOXKA0_mmQ]42og^5d@04ogV5
domhQ=?oMXCCogJ4d`;oMHCD0_mbPmD00omaPmGoL8?Fog23eP02off2e`03ofb2eom[P]SoJh;H00;o
JH;I00?oJ8;IofR3f_mXPmX00omUPm/2ofF4g003of>4gOmSQMko000000;oHHGO00?oHXKOof27hOmP
Qn400_mQR>42of:9hQ;ooooo00?o0000ooooooooool01Oooool000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo0_l000000oooooooZLK_ojc:k`02ojo=k`04
ok;?koned^oo]M;_okSDk`;o^]O_0_nlfNh01Onnfnko`Mc]ol7LkOo2g^goa>3/00;oa^7/0_o8h^/0
1?o9hn_obnCYolcUjOo<iNT2olkUj005oloVj?o@inOodNOVom7Wi_oBinD00_oCi^@00ooDj>CoeNOS
omKWhP02omKVh@06omOVh?oHiMoof>GOomSVgooIiMoofNGN0_oJi=d00ooJhmcof^;Kom[Sg002om_R
f`;ofn7J00CofmoIom_NfOoKgmWofmgH0_oKg=L01?oKfmOofm[Fom_Je_oJfMD2om[Ge@;of]KD00?o
fMGComWCdooIdm<00_oId]801OoHdM;oeloAomO?dOoGc]3oelkA00;oe/c@00Goe/_?omG;d?oEbLoo
e<S>omC8c`02om?6cP03om;5cOoBaLkodL?=00;odL?=00?od<;<olo0c?o?`<`00_o>_l`2olfmb`05
olblboo<^l_obk[:ol^jb_o:^//00_o9^<X2olRgb@?oakG90_o5/lT3olBbb0;o`[380oo1[/P2okn]
b004okj/b?nmZlOo_J_7okb[b0?o^jW70_niYlL01OnhYlOo^:K7okNUaongYLOo]JC700;o]J?700Go
]:?7ok:QaonbXLOo/Z77ok6Qa`03ojnOa`03ojjNaon]W/So[9g700;oZic700?oZY_8ojVKaonXV/L0
0onWVLP00onUVLSoYIS7ojBGb003oj>Fb006oj6Fb?nPULWoX9G9oijDbOnNTlSoWI?90_nKT/T2oiZA
bP;oV97:0_nGT</00onESl_oThk;oi>>b`02oi:>c003oi2=c?n?S<coShc<00;oSHc=0_n<Rld00on:
R/goR8W>ohR9cP02ohN9cP04ohF8con4R<ooQ8S?oh:7c`;oPHK@0_moQ]02ogf6d@04og^5dOmjQM;o
NHCBogV4dP;oMXCC0_meQ=@00omdPmCoLX?Eog:3e@02og23eP03ofn3e_m^PmOoKX?G00?oJh;H0_mZ
PmT2ofR3fP04ofN3f_mWPm_oIh?KofF4g0;oIHCM00?oHhGNo`000?mSQMh00_mTQ]l00omRQn3oHhSQ
of>8h@02of:9hQ;ooooo00?o0000ooooooooool01Oooool00005o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo[<W_00;o[lc_00Co//o_okGBkone
d^oo^=C_0_nje^h01?nlfNko_m[]okoJkOo1g>d2ol?Nk@;oaMo/00Koa^7/olSRjoo:h^[ob^;Zol_S
jOo<iNT2olkUj0;ocnGW00?od>GVom7Wi_oBinD00_oCi^@2omCVh`03omGVh_oFiN7oe^KQ00;oenKP
00Kof>GOomSTgooHi=oofNCNomWSgOoJi=d2om[Sg007om[RfooJhM_of^7Kom_Pf_oKhM[ofmoIom_N
f@02om_Mf0;ofmcG00Kofm_Gom_Je_oKf]Kof]SEom[Ge?oJemD2om[Fe003omWDdooIdm;ofM?C00;o
fM;B00?of=3AomS?dOoGcm400_oGc]02omK<d0;oe/_?00GoeLW>omG9cooDb<kodlK=om?6cP02om;5
c@03om;3c?oA`lgod<;<00;od<;<00?ocl3<olnoboo>_l`00oo=_L/00oo<_<_obk[:ol^jbP02olZi
b@03olVhb_o9]lWob;O900;oakK900?oakG9olJdb?o5/lT00oo4//P01oo3/<So`[38ol6_b?o1[lSo
`Jk8ol2]aono[LP00_nn[<L02?nmZlOo_J[7okbYaonlZLOo^jW7okZXaoniYlOo^JK60_nhY/L01Ong
YLOo]ZC6okJTa_neXlOo]:;600;o/j;700Ko/Z77ok:Pa_n`WlOo/9o7ojnOaon_W/H2ojjMa`;o[9g7
00OoZic7ojVKaonYVlOoZI_7ojRJaonWVLSoYiS700;oYIS70_nTUlP00onSU/SoXYK7oj6Eb002oinD
b0;oWY?80_nMTlT2oi^Bb@03oiZAb_nHT<WoV93900;oUho:00?oUHo:oiB>bonDS//00_nBSL/00onA
SL_oShc<ohn<c002ohj;c0;oS8_<00?oRh[=ohV9cOn9RLd00_n8RLd2ohJ8cP03ohB8con2QlooPXO?
00;oPHK@00CoOhK@ogj5d?mnQM3oOHGA0_mjQM82ogV4dP03ogN4domfQ=?oMXCC00;oMH?D0_mbPmD0
0omaPmGoL8?Fog23eP02ofj3e`04off3eom/PmSoK8?HofZ3f@;oJH?I0_mYPmX00omWPm_oIhCKofN4
f`02ofF4g@03ofF5gOl0003oIHKN00;oI8KO00CoI8OPof>8hOmSR>7oI8[R4_ooool00ol0003ooooo
ooooo`05ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000oooooon_c>l00_nbcnl01?ned^oo^=C^okSDk_nje^h3okgHk@06okoJkOo1g>go`mg/
ol?Mk?o5gncoan3[0_o8hNX01?o:h^[obn?Yol_SjOo=hnP2olkTi`04oloUioo@iNKodNGUom7Ui@;o
d^GT00?odnGSomCVhooEi^800_oFiN42omOUh004omOTgooHi=oof>COomWTgP;ofN?M0_oJh]`01?oJ
hM_of^3Kom[QfooKh=X2om_Nf@04om_Mf?oKg=SofmgHom_Le`;ofm[F00Gof]WFom_Je_oJf=Gof]SE
om[Ge002om[Ee0;ofMCC00?ofM?BomWAd_oId]800_oHd=400ooHcm7oelg@omO>d002omK<d0;oe/_?
0_oEbLh2omC8cP03om?6cOoCaLgod/G=00;od/?<00SodL;<om32c?o@`L_od<7;olo0c?o?_l_oc[g;
olfmb`;ocKc:00?oc;c;ol^jb_o:^LT00_o:^LT2olVgb@03olRfb?o7]/Woa[C800;oa[C800OoaK;8
olBbb?o4/LOoa;77ol>`b?o2[lOo`Jo800;o`Jk700Co`:g7okj/aonn[<Oo_Zc70_nmZ/L01?nlZLOo
^jS6ok^Xa_njZ<L3okVVaP04okRVaongYLKo]ZC6okFSaP;o]:;600Ko/j;7ok>Qa_nbX<Ko/Z36ok2O
aon`WlH2ojnNaP04ojjMaon]W<Ko[9c6ojbLaP;oZi_700CoZI_7ojVJa_nXVLOoZ9W70_nWV<L00onU
V<OoY9K7ojBFa`03oj:Fa`04oj6Eb?nOU<SoWiC8oijCb0;oWI;80_nKTLT2oiZAb@;oV9390_nGSlX0
0onESl[oU8k;oiB>b`02oi:=b`03oi6=bon?S<coShc<00;oSX_<00?oS8_<oh^:cOn;R/d00_n9RLd2
ohR9c@04ohJ8c_n5QlkoPhO?oh>7c`;oPXK?0_n0Q/l01?mnQM3oOHGAogf5dOmkQM42ogZ4dP;oNHCB
0_mfQ=<00omePmCoM8?DogB3e002og>3e004og23e_m_PmKoKh?Fofn3e`?oK8?H0_m[PmT2ofV3fP;o
JHCJ00?oIhCKofN5g?mWQM`00_mWQMd00ol0003oIHKNofJ7gP02ofJ8g`03ofF9hOmVR^7oIX[Q017o
oooo00?o0000ooooooooool01Oooool00004ooooool0003o0000o`0000Cooooo0_l00009ooooo`04
o`000?oooooooooook;?k`;o]M7^00Go^=C^ok_Fk_nke^ko_MS]okoJk@02ol7Kk003ol?Mk?o5g^_o
aMk[00;oamoZ00Kob>7Zol[QjOo<h^Soc>;XolgRioo>i>L2oloTiP;odNCU00?od^CTom;Ui?oCiN<0
0_oDiN82omGTh@04omKThOoGiN3oenCOomSTg`;of>?N0_oIh]d00ooIhMcof^;Lom[Qf`02om[Pf`04
om[Of_oJg]WofmkIom_Mf0;ofmcH00Gofm_Gom[Je_oJf]Kofm[Fom[IeP02om[He@03om[Fe?oJemCo
f]GD00;ofMCC00?ofM;BomWCd_oIdM800_oHd=401OoHcm3of<oAomO=d?oFc<ooe/c@00;oe/_?0_oE
bLh2omC8cP;odlK=00?odlG=om;3c?oB`l`00_oA`/`2om31b`?ocko;00?oc[g;olflb_o=_<X00_o<
^/T00oo;^/[obkW9olZib@02olVgb@;ob;K800GoakC8olJdb?o6/lOoa[?7olFbb002olBaa`;o`k37
00Co`Zo7ol6^aoo1[/Oo`Jk70_no[<L01onn[<Oo_Z[6okjZa_nmZ/Oo_:W6ok^Xa_nkYlH00_njYlH0
1?niY/Ko^:G6okRUa_ngYLH3okFSaP05okBRa_ncXLKo/j76ok>Qa_nbX<H00on`WlH01?n_W/Ko[Ic6
ojfLa_n]W<H2ojbLaP05oj^KaonYV/KoZI[6ojVJa_nXVLL00_nVV<H2ojFGa`;oY9K700?oXYK7oj:E
aonQU<L00onOTlP00onNTlSoWI;8oifBb002oi^Ab@03oiZAbOnIT<WoVI3900;oUho900?oUXk9oiB>
b_nDS/X00_nCSLX00onAS<_oT8c;oi2<b`02ohj;b`03ohf:c?n;R/coRh[<00;oRXW<0_n8R<d00on7
R<goQHO>ohF7cP02oh>7c`;oPXK?00CoP8K?ogn5d?mnQM3oOXG@0_mlQM42ogZ4dP03ogV4d_mhQ=;o
N8CB00;oMXCC0_mdPm@01OmcPmCoLX?Eofn3e_m_PmKoKh?G00;oKX?G0_m/PmP00om[PmWoJhCIof^4
f@02ofV4fP03ofR4fomXQMcoJ8GL00;oIhGM00Go0000ofN6gOmXQmkoJ8ONofJ8g`02ofN9h0;oIX[Q
4Oooool00ol0003oooooooooo`04ooooo`005?ooool2o`000006oooooonedNko^=?^okSCk_nke^ko
_MO]0_nofN`01_o1fnco`mc[ol?Ljoo3g>_oaMg[olOOjP;obN3Y00Cob^3XolcRj?o=h^OocN;W0_o>
h^H00oo@hnGodNCUom;Ti002om?Th`;odn?R00?oe>?RomGThOoFi>400ooGhml2omSRgP03omSSg_oI
h]gofN7L00;ofN3K00?of]oKom[PfooJgmX00_oJg]T01OoJgMSof]_Hom[Kf?oKg=Sofm_G00;of][F
00Cof]SEom[GeOoJf=Gof]KD0_oJeM<00ooIdm?ofMCComWBdP02omWAd@;of=3A0_oHcm02omO=d004
omK<cooFblooe/_?omG9cP?oe<S>00GodlK=om?5cOoCaLgodlG=om;3c002om72c0;od<7;0_o?_l/2
oljmbP03oljmboo=_<[oc;[900;oc;[90_o;^LT00oo:^<SobKO9olRfb002olRfb004olNdb?o6/lOo
a[?7olJca`;oa;770oo3/<L2ol:^a`07ol6^aoo0[<Ko`:c6okn/aonnZlKo_Z[6okfYaP02okbYaP?o
^jO600Co^ZO6okVVa_nhYLKo]jC50_ngY<H01_neXlKo]J;5okBQa_ndXLKo/j76ok:Pa@;o/Io600Ko
/9o6ok2NaOn^WLKo[Yg6ojfLa_n]W<D2ojbKaP;oZi[600CoZI[6ojVIa_nXV<KoZ9S60_nVV<H00onU
UlOoY9K7ojBFa`02oj:Ea`;oXIC700?oWi?8oinCaonNT/L00_nMT/P2oi^Ab0;oVY380_nIT<T00onG
SlWoUXk9oiJ>b@02oiB>bP03oi>=b_nAS<_oTHc;00;oT8c;0_n>Rl/00on=R/coRh[<oh^:c002ohZ9
c0;oR8S=00CoQhS=ohF7c_n4QlkoQ8O>0_n3Q/h2oh66c`04ogn5d?mnQM3oOXG@ogb5d@;oNhCA0_mj
Q=42ogR4dP04ogJ4domePm?oMH?CogB3e0;oLX?E00?oLH?Fog23e_m`PmH00_m^PmL00om]PmSoKHCH
off4f002of^4f@03of^4f_mZQM_oJXGK00;oJ8GL00?oJHKLofV7gOl000000_mXQmh2ofR8g`;oIhWP
00?oJ8_Qooooooooool03oooool00ol0003oooooooooo`04ooooo`005_ooool00ol0003ooooookSC
kP02ok_Ek@;o_MO]00Go_mW/ol7Jk?o1f^co`mc[olGMj`02olONj@03olWPjOo:h>Soc>7W00;oc>7W
00?ocN7WolkRi_o@hnD00_oAhn@2om;Ri003om?RhooChn;oe>?R00;oeN?Q00Goe^;PomORgooGh]oo
en?OomSRgP02omSQg@04omWPg?oIgm_ofN3Kom[Of`;of]kJ0_oJgMT00ooJg=Sof]gHom[Kf002om[J
e`03om[Ie_oJf]Kof]SE00;of]OE00?of]KDom[DdooJeM<00_oIdm<00ooId];ofM7AomWAd@02omS@
d@03omS>d?oHcm3oelg@00;oelc?00Goe/[>omK;cooEbLkoe<O=omC8cP02omC6c@03om?5c?oCaLgo
d/?<00;od/?<00?odL;<om31boo@`L/00_o?_l/01oo?_/[oc[g:oljlbOo>_<WocKc:olbkbOo<^/T0
0_o;^LT01?o;^<Sob[S8olVfb?o8]/P2olRea`03olNdb?o6/lOoa[?700;oaK;700?oa;77olB`aoo3
/<L00_o2[/H00oo2[/Oo`Jg6ol2/aP02okn[aP08okj[a_nmZLKo_JW6okfYa_nlZLKo^jS5ok^Wa_nj
Y/D2okVVaP?o]jC500Go]jC6okFRaOneX/Go]J;5okBQaP03ok:Pa@05ok6Oa_n`W/Go/9k5ok2NaOn^
WLH00on]W<D00on/VlKoZY[6ojZJaP02ojVIaP04ojRHa_nWV<KoYYO6ojJGaP;oYIK60_nTU/L00onR
ULOoXIC7oj6Da`02oinCa`;oWY;70_nMT/P00onKTLSoVY38oiZ@b002oiV?b003oiN?b?nFS/WoUXk9
00;oU8g900?oThg9oi6<b_nAS<X00_n@RlX2ohn;b`03ohf:bon<RLcoS8W<00;oRXW<0_n9R<`00on7
R<goQXO=ohJ7c@02ohB7cP;oPhK>00CoPHK?oh25comnQM3oOXG@0_mmQM02og^4d@;oNXCA00GoNHCB
ogR4d_mePm?oMH?CogB3e002og>3e0;oLX?E0_m`PmH00om`PmOoKhCGofn4e`02off4f003off4fOm/
QMWoK8GI00?oJXGK0_m[Q]`00omYQmgo0000ofV8gP02ofZ9gP;oJH[P0_mZS>4@ooooo`03o`000?oo
oooooooo00Cooooo000Gooooo`05o`000?oooooooooooooooonmend00_nof>`01Oo1f^co`m_[olGL
j_o5g>[oamkY00;obMkY0_o:gnP00oo<hNOocN7WolkQiP02om3Qi@04om7Si?oBh^Cod^;Tom?Rh`;o
dn;R00Goe>;QomGShOoFh^3oe^;PomORg`02omOQgP04omSPgOoHhMgofN3LomWOf`;ofMkK0_oIgMX0
1OoJg][of]gIom[Lf?oJg=Sof]_G00;of][G00Kof]WFom[HeOoJf=Gof]ODom[GeOoJe]@2om[Dd`03
omWCd_oIdm?ofM;B00;ofM7A00Gof<oAomS@dOoHc]3of<k@omO=c`02omO<c`;oe/[>0_oEbLh00ooD
algoe<K=omC6c@02om?5c0;od/?<0_oA`//01?oA`/cod<7;om2ob_o?_l/2olnnbP?oc[c900Coc;_9
olbib?o<^LSobkW90_o;^<P2olVfb0?ob;G700Coak?7olJcaoo6//OoaK;70_o4/<H01?o4/<Oo`jo6
ol:^a_o2[LH2ol6]aP?o_j_60_nnZ/D01?nmZLKo_:S5okbXaOnkZ<D3okZVa@04okVVa_nhYLGo]jC5
okNSa@;o]Z?500Ko]J;5okBQaOncXLGo/j75ok:PaOnbWlD2ok6Na@06ok2NaOn_WLGo[Yc5ojjLaOn]
W<Go[I_50_n[V/D2ojZJaP04ojVIa_nWV<KoYiS6ojNHaP;oYYO600?oYIK6oj>Ea_nSULH00_nRU<H2
oj6Da`03oinCaonNT/OoWY;700;oWI7700CoVi37oiZ@b?nJT<SoVY380_nISlP00onGSlSoUXk9oiJ>
b@02oiB=b@03oi>=bOnAS<[oTHc:00;oT8_:00?oSh_;ohf:bon=R//00_n<RL`2ohZ9c004ohV8c?n7
R<goQhS=ohJ7c@;oQHO=0_n3Q/h00on2Q/koPHK?oh66c`02ogj5d003ogf5d?mlQ=7oO8CA00;oNhCA
00CoNXCAogR4d_mhQ=;oMhCC0_mfQ=<2og>3e003og:3eOmbPmKoLX?F00;oLHCF0_m_Q=L00om_Q=So
KXCHofj4f002ofb5f@03ofb5f_m/Q]_oK8KK00;oJhKL00CoJhOMo`000?m[R=goJXWN0_m[Rml2ofZ<
hA3ooooo00?o0000ooooooooool01?ooool001Sooooo00Go0000oooooooooooooooookoHk002ol7I
j`;o`m[Z00KoaMcZolOMjOo9gNSobMgXol[Oj?o<gnL2olgPiP;oc^3U00Kod>7Uom7Qi?oBhN?od^7S
om?Qh_oCh^82omCRh@;oeN7P00Coe^7OomKPg_oGhMkof>3M0_oHgm`01OoHg]_ofMgKomWMfooIg]_o
fMgJ00;ofMcI00Cof]_Hom[Lf?oJfmOof][G0_oJfMH00ooJemGof]SEom[Ge002om[Ee007omWDdooJ
e=?ofM?BomWCd_oId];of=3AomWAd@02omS?d@;of<k@00?oelg?omO<cooGc<l00_oFb/h2omG9cP03
omG7cOoDalgoe<K=00;odlG<0_oB`l`02?oB`/_odL;;om71booA`L_od<7;om2ob_o?_/Wockk:0oo>
_<T00oo=^lWoc;[8olbib003ol^hb0;ob[O800?obKK8olReaoo8]LL00_o7/lL2olJba`?oa;360_o3
[lH3ol:]aP05ol6]a_o0[<Go_j_6oknZaOnnZ/D00_nmZLD02?nlZ<Go_:O5ok^WaOnkYlGo^ZK5okVU
aOnhYLGo^:C40_ngXlD00onfXlGo]J;4okBQa@02okBQa@05ok>QaOncX<Go/Yo5ok:OaOnaW/D00on_
WLD01On^W<Go[I_5ojfKaOn]VlGoZi[500;oZYW50_nYV<D01?nWV<KoYiO5ojJFaOnVU/D2ojFFaP;o
XiG600?oXYC6oj6Ca_nQTlH00_nOT/H2oijBa`;oWI7700?oVi37oiZ@b?nJSlL00_nISlP00onGS/So
UXk8oiJ>b002oiF=b@03oi><bOnBS<WoTXc900;oT8_:00?oSh_:ohj:bon>R//00_n<RL/2oh^9b`03
ohV8c?n8R<coR8S<00;oQhO=0_n5Qld01?n3Q/koPXK>oh:6c_n1Q/l2ogn5c`;oOXG@0_mlQ=401?mk
Q=7oNXCAogV4d_miQ=82ogR4dP;oMXCC00?oMHCDogB4e?mdQ=@00_mbPmH00omaQ=KoLHCGog64e`02
og24e`03ofj4f?m^QMWoKXGI00;oKXKJ00KoK8KKofb7fom/Qm_oKHSLo`000?m[R=d2ofb:gP;oJh_O
0_m/S>0?ooooo`03o`000?oooooooooo00Cooooo000Iooooo`;o00001?ooool01Oo3f^[oaM_YolGK
jOo7g>SobMgX00;ob]kW0_o<g^H01_o=h>Koc^3UoloPi?o?h>CodN3Som;Qh`;odn7R0_oCh>401?oD
h>3oeN7PomKQgooFh=h2omOOg@;oemkL00Gof=oLomSNfooIgM_ofMgKomWMfP02omWLf@06om[Kf?oJ
f]Oof][Gom[IeooJf=Kof]WF0_oJemD01OoJe]CofMGDomWEe?oJeMCofMCC00;ofM?B00GofM7BomWB
d_oHd=7of<o@omS?d@02omS>d003omO=cooGblooelc?00;oe/[>00Woe/W>omG9c_oEalgoeLO=omC6
c?oDa/godlG<om?3booB`l`00_oB`//00ooA`L[odL7;om2obP02om2obP03olnnbOo>_<Woc[c900?o
cK_900Soc;[8ol^hb?o;^<SobkS8olZgaoo:]lSobKG7olRea`;ob;C700?oak?7olJba_o6//L00_o5
/LH00oo4/<Koa:o6ol>_aP02ol:^aP03ol:]a_o1[<Go`:c500;o_j_500Co_j[5okfYaOnmZLGo_JW5
0_nlYlD01?nkYlGo^ZK4okZVa?niYLD3okRTa008okNSaOneX/Co]J;4okFRa?ndXLGo]:34ok>PaOnb
Wl@2ok6Na0;o/9k500Ko[ig5ojnLa?n^W<Go[Yc5ojfKaOn/V/@2oj^Ja@;oZYW500OoZIS5ojNGaOnW
UlGoYiO5ojJFaOnUU/KoYIG500;oXiC60_nRU<H2oj6CaP03oinBa_nNTLKoWY7600;oWI7700GoVi37
oiZ?aonJSlOoVXo7oiV?b002oiN>b0;oUXk800?oUHg9oi><bOnCS<T00_nBS<T2oi2;bP03ohn;b_n>
R/_oSX[;00;oS8W;00?oRhW;ohV8c?n9R<`00_n8R<`01?n7QlgoQXO=ohJ7cOn4Q/d2oh>6cP;oPXK>
0_moQLl2ogj5d004ogf5d?mlQ=3oNhCAog^4d@;oNHCB00?oN8CBogN4domgQ=<00_mfQ=<2ogB4e003
og>4eOmcQ=KoLhCF00;oLHCG00?oL8CGog25f?m`QMP00_m^QMT3ofj6fP;oK8OK00?oKHSLo`000?m]
RMd00_m/R]h00om]RmooKXgPofj=h00?ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`00
0?oooooooooo00;ooooo00?oaM_YolOLj?o7g>P00_o8g>P01_o:g^Ooc=kVolgNiOo=g^Goc]kToloP
i0;odN3S0_oAgn800ooBgn7odn3QomCPh002omGOg`05omKOg_oFg]goe]kMomOOgOoGg]`00_oHg]/0
1?oHgM_ofMgKomWMf_oIg=T2omWKf005omWJeooJf]Oof]WGom[IeooJf=H00_oIemD01?oJemGof]KD
omWEe?oIeM@2omWDd`03omWCd_oIdM;ofM7B00;of=3A00?of<o@omS>d?oHc]000_oGcLl00ooGbloo
e/[>omK:cP02omK9cP;oeLO=0_oDa/`2om?5c003om?3booB`/_od/;;00;odL7:0_o@_lX3olnnb@03
oljlbOo>^lSocK_900;ocK[800?oc;[8ol^hb?o;^<P00_o:]lL2olVea`07olRda_o8]<Ooak?6olNc
a_o6//Koa[76olFaaP02olB`aP03olB_a_o3[/Go`Zk600;o`Zg500Co`Jc5okn[aOnoZlGo_j_50_nn
ZLD01?nmZLGo_JS4okfXa?nlYlD3okZVa0;o^JC400Go^:C4okNSa?nfX/Co]Z;4okFRa002okFQa005
okBPa?nbWlCo/Yo4ok:Oa?naW/@00on`WL@00on_W<Co[Yc5ojfKa002ojbJa004oj^JaOn[VLCoZIS5
ojVHa@;oZ9S50_nWUlD01onVU/GoYIG5ojFEaOnUULGoXiC6oj:Da_nRTlD00_nQTlH2oinBaP;oWY76
00?oWI77oi^@aonKT<L00_nJSlL00onIS/OoV8k7oiR>a`02oiJ=b003oiF=b?nCS<SoThc800;oTX_9
0_nARlT00on@R/[oSX[:ohj:bP02ohf9bP03ohb9bon:R<_oRXS;00;oRHS<0_n7Ql`00on6QlgoQ8K=
ohB6c@02oh>6cP03oh:6c_n1QLooPHG?00;oOhG?00CoOXG@ogb4d?mlQ=3oNhCA0_mjQ=42ogV4dP;o
MhCC00?oMXCCogF4e?meQ=@00_meQ=D2og>4eP03og:4e_mbQMOoLXGG00;oL8GH0om`Q]T2ofj6fP06
ofj7fom_R=coKhSLo`000?m]RMgoKX[N0_m_S=l2ofj=h0kooooo00?o0000ooooooooool01?ooool0
01cooooo00?o0000ooooooooool01?ooool01Oo8g>Sob]gWolcMi_o<gNKocMkU00;oc]kT0_o?g^@0
0oo@g^?odMoRom;Oh@02om?Oh005omCNgooEgmooe]oNomKOg_oFg]d00ooGgM`01OoHg]_of=gKomSL
f_oHg=[of=_I00;ofM[H00OofM_HomWJeooIfMOofMWGomWGe_oJf=KofMOE00;ofMKD00?ofMCDomWE
e?oIe=<00_oId]800ooHdM;ofM7BomS@d@02omS?d004omO>d?oHc]3oelg?omO=c`;oel_?00?oe/[>
omK9cOoFbLh00_oEald2omC6c0;odlG<0_oC`l/00ooB`/_odL7:om71bP02om2obP?ockk900?ockg9
oljlbOo>^lP00oo=^/P01?o<^LOobkS8ol^gaoo:]lL2olVfa`03olVeaoo8]<Koak?600;oak?60_o6
/LH3olB`aP;o`jk50oo2[LD2ol2[a@04okn[aOnoZ/Co_j[4okjYa@;o_JS400Co_:O4ok^Va?nkY/Co
^ZK40_njYL@02?niY<Co]j?4okNSa?ngXlCo]Z;4okJQa?neXLCo]:340_ncWl@01onbWlCo/Yk4ok6M
a?naWLCo/9g4ojnLa?n^Vl@00on]Vl@01?n/V/CoZiW4oj^Ia?n[VL@2ojVHa@08ojRHaOnWUlGoYiO5
ojNGaOnVU/GoYIG5ojBDaOnSU<D3oj:Ca@;oXI?600CoWi;6oijAa_nNTLKoWI360_nLT<H3oiZ?a`03
oiV>aonHS/OoV8k700;oUXg800?oUHg8oi><b?nCS<P00_nBRlT00onARlWoT8[:oi2:bP02ohj:bP;o
SHW:00?oS8W;ohZ8bon:R</00_n9R<`01?n7QlcoQXO<ohF6cOn5Q/d2ohB6c@;oPhK>0_n1QLl01?mo
QLooOXG@ogf5d?mmQM02ogb5d@;oNXCA0_miQ=800omhQ=;oMhCCogN4d`02ogF4e003ogF4eOmdQMGo
M8GE00;oM8GF00?oLXGGog65f?maQMP00_maQ]P00om`Q]WoL8OJog27fP02og28f`;oKhSL00?o0000
og2;g_m`Rmh00_m_S=l2og2=g`gooooo00?o0000ooooooooool01?ooool001gooooo00?o0000oooo
ooooool01Oooool00oo<gNKocMgUolgMi@02olkMi006oloNi?o@g^?odMkRom7Nh_oBg^7odmoP0_oD
g]l2omCNgP04omGMg_oFgMgoemgLomOMg0;oemcK00Cof=_JomSLf_oHfmWof=_I0_oIf]P01?oIfMSo
fMSGomWIeooIemH2omWFe@03omWEe?oIe]CofMCD00;ofM?C0_oId]82omSAdP03omS@dOoHcm3of<o@
00;oelk@00Coelc?omO=cooGblooel_?0_oFb/h01?oFbLgoeLO=omG7cOoDa/`3om?5c0;odl?;0_oB
`//00ooA`L[odKo9om2obP02om2nb@03olnnbOo?_LWockg900;oc[_80_o=^/P2olbia`;obkO700Go
b[K7olVfaoo9]<KobKC6olRdaP02olNcaP?oa[7600GoaK35olB`a_o4[lGoa:o5ol>^a@02ol:]a@;o
`Jc500Co`:_5oknZa?noZ/Co_ZW40_nmZ<@3okbWa004ok^Va?nkYLCo^ZG4okVTa0;o^:?400Co]j?4
okNRa?ngX/Co]Z740ondX<@01OncWlCo/Yk4ok:Na?nbW/Co/Ig400?o[ic400?o[Y_4ojfKa?n]V/@0
0_n/V/@01?n[VLCoZiS4ojVHa?nYV<@2ojRGa003ojNGaOnWU/CoYYG400?oY9C500?oXiC5oj:CaOnR
TlD00_nQT/D01OnOT/KoWY76oijAa_nNTLKoWI3600;oW93600?oVXo7oiZ?a_nIS/L00_nHS/L2oiN=
a`03oiF<b?nDS<SoU8c800;oTh_800?oTH_9oi2:bOn@R/T00_n?RLT2ohf9bP03ohb8b_n;R<_oRhS;
00;oRHS;0_n8Ql`00on6QlcoQHK=ohF6c@02ohB6c@04oh>6c_n2QLkoPXG>oh25c`;oOhG?0_mmQM02
ogb5d@03og^4dOmjQ=;oNXCB00;oNXGB0_mgQ=<01?mgQ=CoMXGDogJ5e?mdQMD2ogB5eP03og>5eomc
Q]OoLhKG00;oLHKH00?oLHOIog68f_maR=X00_m`R=/2og29g005o`000?maRmcoL8_Nog2;g_maSMh0
0_mbS]l>ooooo`03o`000?oooooooooo00?ooooo000Nooooo`;o00002?ooool01Oo>gNCocmgSom3M
h_o@gN;odMkR00;od]kQ0_oCgN001?oCgMooe=kNomGMg_oFgMd2omKLg004omOKfooGg=_of=_JomSK
fP;of=[I00?of=WHomWJf?oIfMP00_oIf=L00ooIemKofMKEomWFe@02omWEe003omWDe?oHdm?ofM?C
00;ofM;B0_oHdM801OoHd=7of<o@omS?d?oGcM3oelk@00;oelc?00?oel_>omO;cooFb/h00_oFb<d2
omG7c@03omC6c?oDaLcodlG<00?odl?;0_oB`//2om71bP03om6obOo@_/Wod;k900?ockg90_o>^lP2
olfjb0;oc;W70oo;]lL02?o:]/OobKC6olVda_o9]<Kob;?6olNca_o7//Goa[760_o6/<D00oo5/<Go
a:o5olB_a@02ol>^a@04ol:]aOo2[<Co`Jc5ol2[a0;o_j[40onnZL@01?nmZ<Co_JO4okbWa?nkY/@2
ok^Ua0?o^JC400Co^:?4okNRa?ngX/Co]j;40_neXL<01_ndX<Co]9o3ok>O`oncWl?o/Yk4ok6M``;o
/9g300?o[ic4ojnK`on^Vl<00on]V/@01On/V/CoZiS4oj^Ha?n[V<CoZIS400;oZ9O40_nWU/@2ojJE
a003ojBDaOnTU<CoXi?500?oXY?500KoXI;5oinBa_nOT/KoWY76oijAaOnMT<H2oib?aP;oVXo60_nI
S/L2oiR>a`03oiN=aonES<SoUHc800;oU8c80_nCRlP00onARlWoT8[9oi2:b@02ohn9b@03ohf9b_n<
R<[oS8S:00;oRhS;0_n9R</01?n8QlcoQhO<ohJ6c?n6Q/`2ohF6c@;oQ8K=00CoPXG>oh25con0QLoo
OhG?0_mnQM02ogf5d0;oO8GA0_mjQ=801?mjQM;oNHGCogV5domhQM<2ogJ5e003ogJ5eOmeQMKoMHGF
00;oLhGG00?oLhKGog>7f?mcQmP00_mcQmT2og68fP05og:9fombR]_oLX[Kog6;g?l000000_mbS=d2
og:=gP;oLXkO3Oooool00ol0003oooooooooo`03ooooo`008?ooool00ol0003oooooooooo`08oooo
o`07om3Mh_oAgN7od]cPom;Lh?oCgN3odmgOomCLgP02omGLg@;oeM_L00Ooe]cLomOKfooGf][oem[J
omOJfOoHf]Wof=WH00;of=SH00?of=OGomWHeooIemH00_oIe]D00ooHeMCofMGDomWDe002omSCd`07
omSBd_oId];of=7BomSAd_oHd=7of<k@omS?d002omO=d0;oelc?00Goel_>omK:c_oFb/koeLS=omK8
c@02omG7c@;oe<K<00?oe<G<om?4booC`l/00ooB`//2om71bP;odKo900?od;k9olnmb?o?_LT00_o>
_<P00oo>^lSocK[8olfjb002olbia`07olbhaoo;]lOob[K6olZfa_o:]/OobKG6olVdaP02olRcaP;o
ak;50oo6/<D2olB_a@?o`jk50_o2[<@3ol2[a003oknZa?noZLCo_ZW400;o_JS400So_JO4ok^Va?nk
Y/Co^jK4ok^Ua?njY<?o^JC4okVS``;o^:?300Co]j;4okJQ`oneXL?o]J330ondWl<01OncWl?o/Ig3
ok6M`onaWL?o/9g300?o[i_300?o[Y_3ojfJa?n]V/<00_n/VL@00on[V<CoZYS3ojVGa003ojRGa003
ojNFa?nUULCoYIG400;oY9C40_nSTlD00onRTlGoXY;5oj6Ba@02oinAa@;oWY750_nMT<H2oib?aP03
oiZ?a_nIS/KoVHk600;oV8g700?oUhg7oiJ<aonFS<L00_nDS<P2oi>;b003oi:;b?n@R/WoT8[900;o
ShW900?oSXW9ohf8b_n=R<X00_n;R<X2ohZ8b`03ohV7bon7QlcoQhO<00;oQXK<0_n5Q/d01?n4Q/go
PXK>oh65c_n1QLh2oh25c`;oOXG@0_mmQM001?mlQM7oNhGAog^5dOmkQM82ogV5d`03ogR5domhQMCo
N8GD00;oMhKE0_meQMH00omeQ]KoM8OGogB7e`02og>7f003og>7fOmcR=[oLhSJ00;oLhWJ0_mbR]/0
0omcRmco0000og>=g@02og:=gP;oLhoO3Oooool00ol0003oooooooooo`03ooooo`008Oooool00ol0
003oooooooooo`09ooooo`04om;Lh?oBg=oodm_Nom?KgP;oe=_M00?oeMcMomGKg?oFf]/00_oFf]/0
1ooGf][oem[IomOIfOoGfMWoemSHomSHf?oHemL00_oHe]H01OoHeMKofMKEomSEe?oHeMCof=?D00;o
f=;C00Oof=?ComSBd_oHd=;of=3BomS?dOoHd=7of<k@00;oelg@0_oGc<l00ooFblkoe/W>omK:cP02
omG8c@;oeLO=0_oDa/`2omC5c003om?4booB`/_od/;;00;od/7:00?odL7:om6obOoA_lT00_o@_/T0
2?o?_LSoc[c8oljlb?o>_<Soc[[8olfjb?o=^LOoc;W70_o<^<L01oo;]lKob[K6olZea_o:]LKobKG6
olRda_o8/lH00oo7//D01oo6/LGoa[35olF_aOo5[lGoa:o5olB^a?o3[/D00_o2[L@00oo2[<Co`J_4
ol2[a002ol2Za004oknYa?nmZ<Co_JS4okfXa0;o_:K300Co^jK4ok^U`onjY<?o^JC30_niXl<01?nh
Xl?o]j;3okNR`onfXL<3okFP``04okBO`oncW/?o/Yk3ok:N``;o/Ig30_n`W<<2ojnK``;o[Y[30_n]
V/<01on/VLCoZYS3ojZH`onZV<?oZIO4ojRGa?nXU/@00_nWU/@2ojFEa003ojBDa?nSTlCoXi?400?o
XY;500CoXI;5oinAaOnOTLGoWY750_nMT<D2oib?aP;oVhk60_nIS/H2oiR=a`03oiN=aonFS<OoUXc7
00;oU8c800?oTh_8oi:;b?nBRlP00_n@R/T00on?RLWoSXW9ohj9b@02ohf8bP;oRhS:00CoRXS;ohV7
bon8QlcoR8O<0_n7Ql`2ohF6c@03ohB6cOn2Q/koPXK>00;oPHG>00?oP8G?ogn5comoQLl00_mnQM02
ogf5d004og^5dOmkQM;oNXGBogZ5dP;oNHGC0_mhQM@3ogN6e@;oMXOF0_mdQmL00omdQmSoM8SIogB8
f@02og>8fP;oLhWJ00GoM8_KogB<g?mdS=co0000og>=g@02ogB>gP03ogJ@gooooooooooo00_ooooo
00?o0000ooooooooool00oooool002;ooooo00?o0000ooooooooool02oooool01OoCfmkoe=_MomCK
gOoDf]goeM[L00?oe][K00?oe]WJomOHfOoGfMT00_oGf=P01OoGemOoemKFomOFe_oHe]Kof=GF00;o
f=CE0_oHdm@2omSBd`03omSAd_oHd=;of=3B00;of<oA00?oelk@omS>d?oGcM000_oGc<l2omK;cP03
omK9c_oEb<goeLS=00;oeLO=0_oDa/`2omC5c0;odlC;00?od/;;om;1b_oB`LX00_oA`<T00ooA_lWo
d;k9om2nb@02olnmb004olnlb?o>_<Soc[[8oljjb0;ocKW70_o<^<L2ol^gaP?ob[G60_o8]<H01?o8
//Goak;5olNaaOo6/LD2olF`a@03olF_aOo4[/Coa:k400;o`jg400?o`Zg4ol:/a?o1Zl@01?o0Z/@2
okjX``03okfXa?nmYl?o_:K300;o_:G300Go^jG3okVT`oniY<?o^JC3okVS``03okNR``;o]Z7300Ko
]J33okBO`oncW/?o/ik3ok:N`onbWL<2ok6M``06ok2L`on`Vl?o[i_3ojnK`on^V/?o[I[30_n/VL<2
oj^H``03ojZH`onZUl?oZIO300?oZ9K400?oYiK4ojFDa?nUU<@00_nTU<@2oj>Ca003oj:BaOnRT/Co
XI7400;oWi750_nNT<D2oif@a@;oW8o600?oVhk6oiV>a_nIS/H00_nHSLH00onGSLOoUXc7oiJ<a`02
oiB<a`03oi>;b?nBRlSoTX_800;oTH[800?oT8W9ohj9bOn>RLT00_n=RLT2ohb8bP03oh^8bon:Ql_o
RXO;00;oR8O<0_n7Ql`2ohF6c@;oPhK>0_n2Q/h2oh66c`;oOhG?0_mnQM001?mmQM3oOHGAogb5d_ml
QM82ogZ5dP;oNHGC00?oNHKDogR6e?mhQ]@00_mgQ]D2ogJ7eP03ogJ7eomfR=SoMXSH00;oM8SI00?o
MHWIogF:f_meR]X00_mfS=/00omdS=co0000ogF=g@02ogJ?gP;oMi7O3?ooool00ol0003ooooooooo
o`03ooooo`008oooool00ol0003oooooooooo`0;ooooo`07omCKgOoDf]goeM[LomGJg?oEfM_oe][K
omKIfP02omOHf@;oemOH00OoemKGomOGeooGe]KoemKFomOEe_oGe=Gof=CE00;of=?D0_oHd]<01OoH
dM;of=3BomS@d_oGcm7of<oA00;oelk@00?oelg@omK<cooGc<l00_oFblh2omK9cP03omG8cOoEalgo
eLO=00;oe<K<0_oDaL`2om?4b`;od/;;00?od/7:om70bOoA`<T00oo@_/T2olnmb0;ockc800Coc[_7
oljjb?o=^LOocKW70_o<^<L2ol^gaP?ob[G600CobKC6olRda_o8//Gob;;50_o7/LD3olF`a@;oa:k4
0oo3[L@2ol:/a0Co`:[400Go_jW3okjX`onnYl?o_ZO3okfW``03okbU``;o^ZC300Go^JC3okVS`onh
X/?o^:;3okNR``02okNQ``05okJQ`ondWl?o]9o3okBO`oncW/<00onbWL<01OnaWL?o/9_3ok2K`on`
Vl?o[i_300?o[I[300?o[9W3oj^H`on[V<<00_nZUl<2ojVG``04ojRFa?nWU/?oYYG3ojJE``;oYIC4
00?oY9C4oj>Ca?nSTl@00_nRT/@2oj6Aa0;oWi7500?oWY35oif?aOnMSlD00_nLSlD01OnKS/KoVHk6
oiV>a_nIS/KoV8g600;oUhg70_nFS<L2oiB<a`03oi>;b?nBRlSoTX_800;oTH[800?oT8W9ohj9bOn>
RLT00_n=RLT2ohb8bP04oh^8bon:Ql_oR8O;ohR7b`;oQhO<0_n6Ql`00on5Q/goPhK>oh>6cP02oh:6
cP;oPHK?00CoP8K?ogn6d?moQ]3oOhK@0_mmQM42ogb5dP03og^6d_mkQ]?oNhKC00;oNXKC0_mhQ]@0
0omhQmGoN8OFogR7eP02ogR8e`;oMXSH00?oMXWHogJ:fOmfR]T00_meR]X2ogJ<f`03ogJ=g?l0003o
MhkM00;oMXoN0_mgTMl;ooooo`03o`000?oooooooooo00?ooooo000Tooooo`;o00003Oooool01?oE
f]coeMWKomGIfooEf=X2omKGf@07omOHfOoGemSoemKGomOFeooGeMOoemKFomOEeP02omODe@03omOC
e?oHdmCof=;C00;oem7C00Coem3BomS@d_oGcm7oeloA0_oGc]001OoGcM3oe/c?omK<cooFblooe/_>
00;oe/W>0_oEb<d00ooEalgoe<K<omC6c002omC5c0;odlC;0_oB`//2om;1bP03om70bOo@_lWod;k9
00;od;g800?ockg8olnlb?o?_<P00_o>^lL01?o=^/OocKW7olbhaoo<^<L2ol^gaP07ol^fa_o:]LKo
bKC5olVdaOo9]<Kob;?5olRba@03olNaa@07olJ`a?o5/<GoaJo4olF_a?o4[/Coa:g4ol>]a003ol:/
a005ol6[`oo0Z/Co`:W3ol2Y`onoZL<00onnYl<2okbV``04okbU`onkYL?o^jG3okZT``?o^J?300Co
^:;3okRR`_ngXL?o]Z320_neX<801_ndWl?o]9k2ok>N`_ncW/;o/Yg3ok:M`P;o/Ic200Oo/9_3ojnK
`_n^V/?o[Y[3ojfJ`on]VL;o[9W300?oZiS300?oZYO3ojVF`onYU/<00onWU/<00onVUL?oYIC3ojFD
``02ojBCa0;oXi?400?oXY;4oj6Aa?nQTL@00_nOTL@2oij@a@;oWHo500KoW8o5oi^>a_nKS/KoVHk6
oiZ>a_nHSLH2oiN=aP;oUXc70_nERlL00onDRlOoTX_8oi:;b002oi6:b003oi29b?n?RLWoShW900;o
SXW90_n=R<X00on;R<[oRXS;ohZ8b`02ohR7b`;oQhO<00CoQXO<ohF6cOn5Q/goQ8K=0_n3Q/h2oh:6
cP;oPHK?0omoQ]000omnQ]7oOHKAogf6d@02ogf6dP;oNhKC00?oNXKCogZ7e?mjQm@00_mjQmD2ogR7
eP03ogR8eomhRMOoN8WG00;oN8[H0_mfR]T00omgRm[oMhcKogN<f`02ogR>g005o`000?mgS]goN93N
ogR@g_miT]l02oooool00ol0003oooooooooo`03ooooo`009_ooool00ol0003oooooooooo`0=oooo
o`07omGHf_oFemWoe]OIomKGfOoFe]SoemKGomOEe`02omODeP03omOCeOoGe=Goem?D00;oem;C0_oG
dM<2omO@dP;oeloA00?oelk@omO=d?oGcM000_oFc<l2omK;c`;oe/W>0_oEb<d2omG7c@05omC6c?oD
aLcoe<G<omC5c?oCa</00_oB`//2om;1bP;odL3900Cod;o9om2mb?o@_LSod;g80_o?_<P2oljka`;o
cK[700KocKS7olbhaoo<]lKoc;O6ol^ga_o;]/H3olVda@;ob;?500?ob;;5olNaaOo6/<@00_o6/<@2
olF_a0;oa:k400?oa:g4ol>/a?o2[<@00_o2Zl<01?o1Zl?o`:W3ol2Y`oo0ZL<2okjX``07okjW`onm
Y/?o_JK3okbV`onlYL;o^jG3okZT`P02okZS`P04okVS`onhX/;o^:;2okRR`P?o]Z3200Go]J32okBN
`_ndW/;o]9k2ok>N`P03ok:M`P05ok6L`_n_Vl;o[i_2ojnK`_n^V/<00on]VL800on/VL?oZiS3oj^G
``02ojZG``;oZIK300CoYiK3ojNE`onVU<?oYYC30_nUU<<01?nTTlCoXi;4oj>Ba?nRT/@3oj6Aa0;o
Wi7400CoWY35oif?aOnMSlGoW8o50_nKS/D3oiZ>aP03oiR=a_nGSLKoUhg600;oUXc700?oUH_7oiB;
aonDRlL00_nBRlP00onAR/SoT8W8oi29b002ohn9b@;oSXW900CoSHS:oh^8b_n;R<[oRXS;0_n9Ql/2
ohR7c003ohN7c?n6QlcoQXO<00;oQHK=0_n3Q/h2oh:6cP;oPHK?0_n0Q]02ogn6d0;oOHKA00?oOHKB
ogb6domlQ]<00_mlQm<2ogZ7e0;oNXOE00?oNHSFogV9eomiRML00_mhRML00omhR]SoN8_IogR;f@02
ogR<fP;oMhcK00?oN8kLo`000?miSmd00_mjTMh2og^Cg`_ooooo00?o0000ooooooooool00_ooool0
02Oooooo00?o0000ooooooooool03_ooool01ooFemWoe]KHomKEeooFeMOoe]CFomODe_oGdmD00_oG
d]@01?oGdMCoem;ComOAdooGdM<2omO@dP;oeloA00?oelkAomK=d?oGcM000_oFc<l2omK;c`;oe/W>
0_oEb<d2omG7c@;oe<K<0_oDaL`2om?4b`03om;2booB`L[od/7:00;odL3900CodKo9om2obOo@_LSo
d;g80_o?_<P2oljka`?ocK[700?ocKS7olbga_o<]lH00oo;]/H01_o:]LGobKC5olVcaOo9/lGob;?5
olRba@?oa[340_o5[l@3olB^a0;o`jc40oo2Zl<2ol2Z``07ol2Y`onoZ<?o_jS3okjX`onnYl?o_JK3
okbV`P02okbU`P?o^ZC200Co^Z?2okRR`_nhX/;o^:;20_ngXL801_nfX<;o]Yo2okFO`_neWl;o]9k2
ok>N`P;o/ig200Ko/Yg2ok6L`_n`Vl;o/9_2ojnK`_n_V/82ojjJ`P;o[IW200Go[9S2oj^G`on[Ul?o
ZiO3ojZG``02ojRF``;oYiG30_nVU<<01?nUU<?oYI?3ojBC`onTTl<2oj>Ba003oj:Ba?nQTLCoXI74
00;oWi340_nNT<@2oif?a@03oib?aOnKS/GoVhk500;oVXk600?oV8g6oiR<a_nHS<H00_nFS<H00onE
RlOoU8_7oiB;a`02oi>;a`03oi::b?n@RLSoT8W800;oShW90_n>RLT00on=R<WoS8S:ohb8bP02oh^8
bP;oRHO;00?oR8O<ohN7c?n7Ql`00_n6Ql`00on5Q/goQ8K>ohB6cP02oh>6cP03oh:6con1Q/ooPHK?
00;oP8K@00?oOhK@ogj6dOmnQ]400_mnQm82ogb6d`;oO8OC00CoNhODog^8eOmkR=GoNhWF1?miRML0
0omiRmSoNXcIogZ<f@02ogR<fP;oNHgK00?oNXoLogZ@gOl000000_mjTMh2og^Cg`_ooooo00?o0000
ooooooooool00_ooool002Sooooo00?o0000ooooooooool03oooool01?oFeMOoe]CFomKDe_oFdmH2
omKBe@06omOBe?oGdMCoe]3ComK@dooGdM?oem3B0_oFc]801OoFcM7oelkAomK=d?oFblooe/c?00;o
e/_?00?oeLW>omK9c_oEb<d00_oDald01_oEalgoe<K<om?5c?oCaLcoe<G<om?4b`?od/;;00?od/7:
om70bOoA`<T00_oA_lT01?o@_/Sod;g8olnlb?o?_<P2oljka`06oljjaoo=^/OocKW7olfiaoo=^<Oo
c;O60oo;]/H2olZea@03olVdaOo9/lGob;;500;ob;;500Ooak74olJ`a?o6/<Coa[34olF_a?o5[/Co
a:k400;o`jg300?o`jc4ol:/`oo2Zl<00_o1Z/<01?o0Z/?o`:W3oknX`onnYl82okjW``?o_:K200Co
_:G2ok^T`_njY<;o^Z?20_niXl801?nhX/;o^:72okNQ`_ngX<82okJO`P06okFO`_ndW/;o/ik2ok>N
`_ncWL;o/Yg20_naW<82ok2K`P?o[i[200Oo[Y[2ojfI`_n]VL;o[IW2ojbH`_n[Ul?oZiO200;oZIK2
0_nXU/<00onWUL?oYYC3ojJD``02ojFC``;oY9?300?oXi;4oj>B`onRTL@00onQTL@01_nOT<CoWY34
oij@a?nMSlGoWHo4oib?a@;oVhk50_nJSLD2oiV=aP;oV8c600?oUXc6oiF;aonERlL00_nDRlL2oi>;
a`03oi::b?n@RLSoT8W800;oShW900?oSXW9ohf8bOn=R<T00_n<R<X01?n;R<[oRXO;ohZ7bon9Ql/2
ohR7c0;oQhO<0_n6Qld2ohB6cP04oh>6c_n2Q/ooPXK?oh:6c`;oPHO@0_n0Qm02ogj6d@;oOXOB00Co
OHOBogf8dommR=?oO8SD0_mkR=D3og^9eP;oNh_G0_miRmP2ogZ<f@03ogZ=f_mkS]_oNhkK00;oNXoL
00GoNY3Mo`000?mkT]koNi;NogfDg`0;ooooo`03o`000?oooooooooo00;ooooo000Yooooo`;o0000
4Oooool01ooFe=Koe]?FomKBeOoFd]Goe]7DomOAe?oFd=<00_oFcm82omK>dP;oe/gA00?oe/c@omK=
d?oFbll00_oEb/l00ooFblooeLW>omG8cP02omC7c@;oe<K<0_oCaL`2om?4b`03om;3booB`/_od/7:
00;od/7:00?odL39om6obOoA_lT00_o@_/P01?o?_LSockc8olnkaoo>^lL2oljja`?ocKW700Coc;S6
olbga_o;]/KobkK60_o:]LD2olVda@?ob;;50_o7/L@2olJ`a0;oaJo400?oaJk4olB]`oo3[L<00_o3
[<<00oo2[<?o`Z_3ol6Z``03ol2Y``?o_ZO200Co_ZO3okfV`_nlY/;o_:G20_nkY<82okZS`P04okVS
`_niX/;o^J;2okRQ`P?o]j3200Go]Yo2okBN`_ndW/;o]9k2ok>N`P03ok:M`P04ok6L`_n`Vl;o/9_2
ok2K`P;o[i[20_n^VL800on]VL;o[IS2ojbH`P03oj^G`P03ojVF`_nXU/;oZ9K200;oYiG30_nVU<<0
0onUTl?oY9?3ojBC``02oj>B``;oXY740_nQTL@00onOT<CoWY34oij@a002oif?a0;oW8o50_nKS/D0
0onJSLGoVHg6oiV=a@02oiR<aP03oiN<a_nFRlKoUX_600;oU8_70_nCRlL00onBR/SoTH[8oi6:b002
oi29b003ohn9bOn>RLWoSXW900;oSHS:0_n<R<X00on:Ql_oRHO;ohV7b`02ohR7c0;oQhO<00CoQXO=
ohF7cOn5QlgoQ8O>0_n3Qlh2oh:6c`;oPHO@00?oP8O@ogn7dOmoQm400_moQm801?mnR=;oOHSCogf8
domlR=@2ogb9e@;oO8WF0_mkRMH2og^;e`03og^<f?mkSMWoNhgI00;oO8kJ0_mkS]/2og^@g003ogbA
gOl0003oOI?N00;oOYGO2_ooool00ol0003oooooooooo`02ooooo`00:oooool00ol0003ooooooooo
o`0@ooooo`06omKBeOoFdMCoe]3ComK@dooFcm?oe/oB0_oFc]82omK=d@;oe/c@00?oe/_@omK;cooE
b/l00_oEbLh01OoDb<koeLS>omC7cOoDa/goe<K<00;odlG<0_oCa</2om;3b`;od/7:0ooA`<T00ooA
_lWod;k8om2nb002olnmb0;ock_70_o>^/L3olfia`;oc;S600CobkK6ol^eaOo;]LGob[G50oo9]<D0
1?o8/lGob;;5olNaa?o7/L@2olJ`a0?oaJo40_o4[L<3ol>/``;o`Z_31?o0ZL<01OnoZ<;o_ZO2okjW
`_nmY/;o_JG200;o_:G20onkY<801?njXl;o^J;2okVR`_niX/82okNQ`P04okNP`_nfWl;o]Io2okFO
`P;o]9k20_ncWL801_nbWL;o/Yc2ok6K`_naVl;o/9_2ok2J`P;o[i[200Co[YW2ojfI`_n]V<;o[IS2
0_n/V<801?n[Ul;oZYO2ojVF`_nYU/82ojRF`P03ojNE`onVU<?oYYC300;oYI?30_nTTl<00onST/?o
XY73oj:A``03oj6Aa004oin@a?nNT<CoWY34oif?a0;oW8k50_nKS/D01?nJSLGoVHg5oiV=aOnISLD2
oiR<aP03oiN<a_nFRlKoUX_600;oU8_700?oTh_7oi::b?nBR/P00_nAR/P2oi29b003ohn9bOn>RLWo
SXW900;oSHS:00CoS8S:oh^8bon9R<_oRHS;0_n9Ql`2ohR7c0;oQhO=00?oQHO=ohB7c_n4Qlh00_n3
Qlh00on3QlooPXO@oh:7d002oh67d0;oOhOA00CoOhOBogj8d_mnR=?oOXSC0_mnRM@2ogb9e@;oO8WF
00?oO8[Fogb;eomlRmL00_mlS=P2og^=f@;oO8kJ00GoO8oKogfAg?mmTMcoOY?Mo`000002ogfCgP;o
OYGO2Oooool00ol0003oooooooooo`02ooooo`00;?ooool00ol0003oooooooooo`0Aooooo`05omK@
dooFcm?oe/oComG>d_oFc]800_oFcM400ooEc=7oe/c@omK;d002omG:c`04omC9cooEbLkoe<S>omC8
cP;oe<O=00Goe<K=om?5c?oCaLcodlG<om?4b`02om;3b`;od/7:00?odL3:om70bOoA_lT00_oA_lT0
0oo@_/Sockg8olnmb002olnkb004olnkaoo>^/OocKW7olfia`?oc;S600Soc;O6ol^eaOo;]LGobkG5
olZdaOo9]<GobK?5olRca@;ob;;400Koak74olN`a?o7/<Coa[34olJ_a?o5[l@2olB^``03olB]`oo3
[<?o`jc300;o`Z_30_o1Z/<00oo0ZL?o`:S2oknX`P03okjW`P?o_JG200Co_:G2ok^T`_nkY<;o^Z?2
0_niXl801?niX/;o^:72okRQ`_ngXL83okJO`P05okFO`_ndW/;o]9k2okBN`_ncWL800onbW<801Ona
Vl;o/9[2ok2J`_n`V/;o[i[200?o[IW200?o[IS2ojbH`_n[Ul800_nZUl82ojVF`P;oZ9G20_nWU<82
ojJD``03ojFC`onTT/?oY9;300;oXi;30_nRTL<00onQTLCoXI73oin@a002oij?a0;oWHo40_nLS/D2
oi^>a@03oiZ=aOnISLGoVHg500;oV8c600?oUhc6oiJ<a_nFS<H00_nERlL00onCRlOoTX[7oi::a`02
oi6:b0;oT8W800?oShW9ohj9bOn>RLT00_n=RLT2ohb8bP03oh^8bon9R<_oRHS;00;oRHO<0_n8Ql`0
1?n7QlgoQXO=ohF7c_n5Qlh2ohB7cP;oQ8S?0_n2Qm02oh67d004oh68dOn0R=;oP8SBoh28dP;oOXSC
0_mnRM@00omnRMGoOX_Fogj;eP02ogj;eP;oO8_G0_mlS=P00ommS]WoOHoJogf?fP02ogj@f`;oOI7L
00GoOY?Mo`000?moU=koOiCNoh2Gg`09ooooo`03o`000?oooooooooo00;ooooo000]ooooo`03o`00
0?oooooooooo017ooooo00Koe/oComG>d_oEcM;oeLgBomK=dOoEc=42omG;d004omC:cooEb/ooe<W?
omC9c`;oe<S>0_oDald02OoCa/goe<K=om?5c?oCaLcodlC<om?4booB`l_od/;:om;1bP02om70bP?o
dKo900God;k9om2nb?o?_LSockc8olnkb003oljja`03olfiaoo=^<Koc;S600?oc;O600CobkK5ol^e
aOo:]<Gob[C50_o9/lD3olRba004olNaa?o7/<CoaZo4olJ_a0;oaJk300?oa:k3olB]`oo3[<<00_o3
[<<01?o2Zl?o`J[3ol6Z`oo1Z/<2ol2X`PCo_ZO200?o_JK2okfU`_nlYL800_nkY<83okZS`P04okVS
`_niX/7o^:72okRQ`@;o]j3100Go]Yo2okJO`OneW/7o]Ik1okBN`P03ok>M`@06ok:L`_naW<7o/I_1
ok6K`On`V/;o[i[10_n^VL800on]VL;o[IS2ojbH`P03oj^G`P05ojZG`_nYU/;oZIK2ojVF`_nXUL80
0_nWU<82ojJD`P;oYI?30_nTT/<00onST/?oXY73oj:A``02oj6A``;oWi340_nNSl@00onMSlCoW8k5
oib>a002oi^>a@03oiZ=aOnISLGoVHg500;oV8c60_nGS<H2oiJ<aP;oUH_700?oTh_7oi::aonBR/L0
0_nAR/P00on@RLSoShW9ohn9b@02ohj9b@;oSHW900CoS8S:oh^8bon:R<_oRXS;0_n9R<`2ohR8c003
ohR8cOn6QlgoQXO=00;oQHO>0_n4Qlh00on4R<ooPhS@oh>8d002oh:8d003oh:8dOn0R=;oP8SB00;o
P8SB00?oOhWCogn:e?moR]@00_moRmD4ogj;eP03ogj<eomnSMSoOXgH00;oOXoI0_mmSmX2ogj@f`;o
Oi;L00?oP9CMo`000?n1U]h00_n2V=l8ooooo`03o`000?oooooooooo00;ooooo000^ooooo`;o0000
5?ooool01?oEcM;oeLcAomC;d?oEbm02omC:c`;oe<W?0_oDb<h01?oDalkoe<O=om?6cOoCa/d2om?5
c0;odlC<0_oB`l/00ooB`/[odL7:om70bP03om6ob@;od;k90_o?_LP00oo?_<Soc[_7oljja`03olfi
a`08olfha_o<]lKoc;O6olbga_o;]/KobkK5olZeaOo:]<D3olVca@;ob;;40_o7/L@2olJ_a0?oaJk3
0_o4[L<3ol>/``;o`Z[300Go`J[3ol2Y`_o0ZL;o`:S2oknX`P03okjW`P04okfV`_nlYL;o_:G2okbU
`P;o^jC200Co^Z?2okZR`OniX/7o^J;10onhXL401OngX<7o]Yo1okJO`OnfWl7o]Ik100Co/ig10ona
W<401OnaVl7o[i[1ojnJ`On_V/7o[YW200?o[IS200?o[9S2oj^G`_n[Ul800_nZU/82ojVF`P05ojRE
`_nWU<;oYiC2ojND`_nVU<800_nUTl<2ojBB``;oXi;30_nRTL<00onQTL?oWi34oin@a002oij?a005
oif?a?nLS/CoW8k4oib>a?nKS/D00_nJSLD2oiV=a@03oiR<a_nGS<KoUhc600;oUXc60_nERlL00onD
RlOoTh_7oi>;a`02oi::b003oi6:b?n@RLSoT8W800;oShW90_n>RLT00on=RL[oRhS;oh^8b`02ohZ8
b`;oRHS<00CoR8S<ohR8cOn7R<goQhS=0_n6R<h2ohF8cP;oQHS?0_n3R=001?n2R=3oPXSAoh:9d_n2
RM82oh69dP;oPH[C0_moR]@2ogn;e@03ogn;e_moS=OoOhcG00;oOhgG0_mnSMP2ogj?f@03ogn@f_mo
T]_oOi;K00;oPI?L00?oPIGMoh6Fg_l000000_n2V=l8ooooo`03o`000?oooooooooo00;ooooo000`
ooooo`03o`000?oooooooooo01;ooooo00KoeLcAomC;d?oDb]3oe<[@omC:cooDbLl2omC8cP;oe<O>
0_oCa/d2om?5c007om;4c?oCa<cod/?;om;3booB`/_od/;:om71bP02om6ob@?od;k90_o?_LP2olnl
b006oljkaoo=^LOocKW7olfiaoo=^LKocKS60_o<]lH2ol^faP;ob[G500?obKC5olVcaOo8//@00_o8
//@2olNaa0;oa[3400?oaZo4olF_`oo5[/<00oo4[L<2ol>/``;o`Z_300?o`Z[3ol6Y`_o0ZL800_o0
Z<801?noZ<;o_ZO2okjW`_nnYl82okfU`P04okbU`_nlY<7o_:C1ok^T`P?o^Z;100Co^J;1okRQ`Onh
XL7o]j310_ngWl401?nfWl7o]Ik1okBN`OndW/42ok>M`@;o/Yc100Co/Ic1ok6K`On`Vl7o/9_10_n_
V/42ojjI`@03ojfH`_n]V<7o[9O200?oZiO200?oZYK2ojVE`_nYUL800_nXUL82ojND`P04ojJC`_nU
Tl?oYI?3ojFC``;oY9;300CoXi;3oj:A`onRTL?oXI330onOT<@2oij?a004oif?a?nLS/CoW8k4oi^>
a@;oVXg50_nISLD01?nHS<GoUhc6oiN<a_nGS<H2oiJ<aP03oiF;aonDRlOoU8_700;oTh_70_nBR/P0
0onAR/SoT8W8oi29b002ohn9b@04ohj9bOn=RL[oS8S;ohb8b`;oRhS;0_n:R<`00on9R<coR8S=ohR8
c@02ohN8c@;oQXS>0_n5R<h01?n5R<ooQ8S@ohB8d?n4RM02oh>9d@;oPXWB0_n1RM82oh6:d`03oh6;
e?n1S=GoPHcE00;oPHcF0_moS=L00omoSMOoOhoHogn?f002oh2@f@03oh6Af_n1Tm_oPI?K00;oPI?L
0_n1UMd01?l0003oPiOOohBIh?n4VN08ooooo`03o`000?oooooooooo007ooooo000aooooo`03o`00
0?oooooooooo01;ooooo00?oe<_@omC:d?oDb]000_oDbLl01?oDb<kodlO>omC7c_oCa/d2om?5c@03
om?5c?oBa<cod/C<00;od/?;0_oB`//2om71bP03om6obOo@_/Wod;k900?ockg80_o?_<P01?o>^lOo
c[[7oljjaoo=^LL2olfiaP04olbha_o<]lKobkK6ol^faP?ob[G500CobKC5olRba?o8//Cob;;40_o7
/L@01_o7/<Coa[34olJ_`oo6[l?oaJo3olF^``?oa:g300Co`jc3ol>[`oo2Zl?o`Z[20_o1ZL83ol2X
`P?o_ZO20_nmY/801?nmYL;o_:C1okbT`OnlY<42okZS`@04okZR`OniX/7o^:71okRQ`@;o]j3100Ko
]io1okJO`OneW/7o]Ik1okBN`OndWL42ok>M`@;o/Yc10_naVl401?n`Vl7o/9[1ojnJ`On_V/42ojjI
`@;o[IS10_n/Ul82oj^G`P;oZYK20_nYUL801onXUL;oYiC2ojND`_nWU<;oYY?2ojFC`onUTl800_nT
T/<2oj>A``;oXY7300?oXI33oin@a?nOT<<00_nNSl@01OnMSlCoW8k4oib>a?nLS/CoVhk500;oVXg5
0_nISLD00onHS<GoUhc6oiN<aP02oiJ<aP03oiF;a_nDRlOoU8_700;oTh_70_nBR/P00onAR/SoT8[8
oi2:b002ohn9b@03ohj9bOn=RL[oSHW:00;oS8S;0_n;R</00on:R<coRHS<ohV8c003ohR8c@;oQhS>
0_n6RLh00on6RLooQ8S@ohB8d002ohB9d0;oPhWA00?oPh[Boh::d_n2R]800_n2Rm<2oh:<e0;oPHcE
00CoPHcFoh6=eon1SMOoPHkH0_n1T=T2oh2@f@;oPI7J0_n1Tm/2oh:Eg@03oh>Gg_n4VMoo000000;o
QY_P2?ooool00ol0003oooooooooo`01ooooo`00<_ooool00ol0003oooooooooo`0Booooo`04omC:
d?oDbLoodlS?om?8c`;odlO>00CodlK=om;5cOoBaLgodlG=0_oBa<`01?oB`l_odL;;om72booB`//2
om71bP05om6ob_oA_lWod;k9olnmbOo?_LP00oo?_<P00oo>^lOoc[[7oljja`02olfia`03olfia_o<
^<Koc;S600;obkK600OobkG5olZeaOo:]<Gob[C5olVdaOo9/lCob;;400;ob;7400?oak74olN`a?o6
[l<00_o6[l<2olF^``?oa:g30_o3Zl<3ol:Z`P03ol6Y`_o0ZL;o`:S200;o_jS200Co_ZO2okjV`_nm
Y/;o_JG10_nlYL401?nlY<7o^jC1okZS`OnjX/42okVR`@?o^:7100Go]j31okJO`OnfWl7o]Yo1okFN
`@03okBM`@05ok>M`OnbW<7o/Yc1ok:L`OnaVl400on`V/401On_V/7o[YW1ojjI`On^VL7o[IS100;o
[9O10_n[Ul82ojZF`P;oZIG20_nXU<82ojND`P05ojJC`_nUTl;oYI?2ojFC`_nTT/<00_nSTL<2oj:A
``05oj6@`onOT<?oWi33oin@`onNSl@00_nMSl@00onLS/CoWHk4oib>a002oi^=a@;oVXg500?oVHg5
oiR<a_nHS<H00onFS<H00onERlKoU8_7oiB;a`02oi>;a`03oi::b?nAR/SoTH[800;oT8[80_n?RLT2
ohj9bP;oSHW:0_n<RL/00on;RLcoRXW<ohZ9c004ohV9c@;oQhS>00?oQXW>ohJ9con6RLl00on5RM02
ohB:d@;oQ8_B0_n2R]82oh:;d`04oh:<e?n2S=GoPXcEoh:=eP;oPXkG0_n1S]P2oh6@f@;oPY7J00?o
PY?Koh>Dg?n3U=`00_n4U]d2ohFHgP04ohBIgol0003oQY_PohJKh0Oooooo00?o0000ooooooooool0
0Oooool003?ooooo0_l0000Dooooo`05om?8cooCalkodlO>om?6c_oCa/d00_oBaLd00ooBa<god/C<
om;3c002om72b`;odL7;00?odL7:om6ob_oA_lX00_o@_/T01oo?_LWockc8olnlb?o?_<Soc[_8oljk
aoo>^/L00oo=^LL2olbhaP;oc;O600?obkK6ol^eaOo:]<D00_o:]<D01?o9/lGobK?4olRba?o8/L@2
olNaa003olN`a?o6[lCoaZo300?oaJk30_o4[L<2ol>/``03ol>[`oo2Zl;o`Z[200;o`JW200Co`:W2
oknX`_noZ<;o_jS20_nnY/82okfU`@04okbU`OnlY<7o_:C1ok^T`@?o^Z;100Co^J;1okVQ`OnhXL7o
^:310_ngWl401_nfWl7o]Yk1okFN`OneW/7o]9g1ok>M`@;o/ic100Co/Yc1ok:K`OnaVl7o/I_10_n`
V/42ojnI`@04ojjI`On^V<7o[IS1ojfH`@;o[9O100CoZiO2ojZF`_nZU/;oZYK20_nYUL802?nXU<;o
YiC2ojND`_nWU<;oYY?2ojFC`_nUT/;oY9;30_nSTL<2oj:A``;oXI3300?oWi33oj2@`onOSl@00_nN
Sl@2oif>a0;oW8k40_nKSLD00onJSLGoVHg5oiV=a@02oiR<aP;oUXc600?oUH_6oiF;aonERlL00_nD
RlL00onCRlSoTX[8oi::b002oi6:b0;oT8[900?oSh[9ohj9b_n>RLX00_n=RLX2ohb9b`03oh^9c?n:
RLcoRXW<00?oRHW=0_n8RLh00on7RLkoQh[?ohN:c`02ohJ:d0;oQHW@0_n4R]42ohB;dP04ohB;don3
S=?oPhcCoh>=e0;oPhkE0_n2SMH2oh:>e`;oPY3H00?oPi7Ioh>Bf_n3T]X00_n4U=/2oh>Dg0;oQ9KM
0_n5V=h01?n6V]oo0000ohRMhOn8WN46ooooo`03o`000?oooooooooo007ooooo000eooooo`03o`00
0?oooooooooo01;ooooo00?odlO>om?6c_oCa/h00_oBaLd2om;4c@03om73c?oB`lcodL;;00;odL7;
0_o@`<X01OoA_l[od;k9om2nbOo?_/Wockg900;ockc80_o>^lP2oljja`;ocKW70_o<^<H2olbgaP;o
bkK500?obkG5olZdaOo:]<D00_o9/lD2olRba0?oak7400Coak34olJ_a?o6[l?oaJk30_o5[L<01?o4
[L?oa:c3ol>/`oo3Zl82ol:[`P?o`JW20_o0Z<800onoZ<;o_jO2okjV`P02okfV`@04okfU`OnlY<7o
_:C1okbT`@;o^j?100Co^Z;1okVR`OniXL7o^J710onhX<401OngWl7o]Yk1okJN`OnfW/7o]Ik100?o
/ig100Go/ic1ok:K`OnbVl7o/Y_1ok6K`@03ok2J`@05ojnI`On^V<7o[YS1ojjH`On]V<400_n/Ul42
oj^F`@04ojZF`_nYU/;oZ9G2ojRE`P;oZ9C20_nWU<801OnVTl;oYI;2ojFB`_nUT/;oY9;300;oXi73
00?oXY73oj6@`onQT<<00onPT<<01?nOSlCoWXo4oij?a?nMS/@2oib>a0;oVhk500?oVXg5oiV=aOnI
SLD00_nHS<H2oiN<aP;oUXc60_nERlL00onDRlOoTh_8oi>;b002oi::b0;oTH[800CoT8[9ohn:bOn>
RL[oSXW:1?n=RL/00on<RLcoRhW<oh^9c002ohZ9c@;oRH[=00?oR8W>ohN9c_n7RLh00_n7R/l3ohJ:
d0;oQH_A0_n5S=82ohF<d`03oh><don3SMCoPhgD00;oPhkE00?oPhoFoh>@eon3T=L00_n4TMP2ohBB
f@;oPi;J0_n4U=/2ohFFg0;oQYSM00?oQi[NohRLh?l000000_n:W^46ooooo`03o`000?oooooooooo
007ooooo000fooooo`03o`000?oooooooooo01;ooooo00?odlK>om;5cOoBaLd00_oBa<d2om73c005
om72c?oA`/_odL7;om30boo@`<X00_o@_lX01Oo@_/Wockk9olnnbOo?_LWockc800;oc[_80_o>^/L2
olfia`;oc;S60_o<]lH3ol^fa@04olZdaOo9/lGobK?5olVca@?ob;;40_o7/L@2olN`a0;oaZo30oo5
[L<2olB/``?o`j_200Go`Z_2ol6Z`_o1ZL;o`:W2ol2X`P03oknW`P?o_JK10_nlYL401?nlY<7o^jC1
ok^T`OnkXl43okVR`@04okVQ`OnhXL7o^:31okNP`@;o]Yo100Ko]Yk1okFN`OndWL7o]9g1ok>M`Onc
W<42ok:L`@03ok:K`OnaVl7o/9[100;o/9[100Go[iW1ojjI`On^VL7o[YS1ojfH`@02ojbH`@;o[9O1
00OoZiK1ojVF`_nYU/;oZIK2ojRE`_nXU<;oYiC200;oYYC20_nVTl82ojFB`P03ojBB`onSTL?oXi73
00;oXY730_nQT<<2oj2@``04oin?a?nNSlCoWXo4oif>a0?oW8k40_nKS/D00onJSLGoVHg5oiV=a@02
oiR<aP06oiN<a_nFS<KoUXc6oiF;aonES<OoU8_70_nCRlP2oi:;b0;oTH_800?oTH[9oi2:bOn@R/T0
0_n>RLX3ohf9b`;oS8W<0_n;RL`2ohZ9c@04ohV:cOn9R/koR8[?ohR:c`;oR8_?0_n7Rm02ohN;d@;o
QH_A00CoQHcBohF<don5S=?oQHgD0_n5S]@2ohF?eP;oQI3G0_n3T=L2ohBAf0;oQ9;I0_n5U=X00on5
U]_oQYOMohJGg@02ohNIgP05ohRKgon:W^7oRYkQo`000?n<X>801_ooool00ol0003oooooooooo`01
ooooo`00=oooool00ol0003oooooooooo`0Booooo`05om;5cOoBa<god/C=om73cOoA`l`00_oA`/`2
om71b`04om30boo@_l[od;o:om2obP;ockk90_o?_LT01?o>_<Soc[_8oljkb?o>^/L2olfia`;oc;S6
0_o<]lH2ol^faP03ol^faOo:]LGobK?500?obK?500?ob;;4olRaa?o7/L@00oo7/<@2olJ_``;oaJk3
00?oaJg3olB]`oo4[<<00_o3[<800oo3Zl;o`Z[2ol6Z`P02ol6Y`P04ol2Y`_noYl;o_jO2oknW`P;o
_ZK100Oo_JK1okfU`OnmYL7o_:G1okbT`OnkY<7o^j?100;o^Z;100Co^J;1okVQ`OniXL7o^:710ong
X<401OnfWl7o]Ik1okFN`OneW/7o]9g100?o/ic100Go/Yc1ok6K`OnaVl7o/I_1ok2J`@03ojnI`@07
ojjI`On]V<7o[IS1ojfH`On/V<7o[9O1oj^G`@02ojZF`@03ojVF`_nYUL7oZ9G200?oYiC200?oYYC2
ojJC`_nUTl800_nUT/82ojBB``;oXi7300?oXY73oj6@`onQT<<00_nPT<<2oin?a0;oWXo400?oWHk4
oib>a?nLS/@00_nKS/D00onJSLGoVHg5oiV=a@02oiR=aP03oiN<a_nFS<KoUXc600?oUHc700?oU8_7
oi>;b?nCRlP00_nBRlP01?nARlSoTH[9oi6:bOn@R/T2ohn:bP;oSX[;00?oSH[;ohf:c?n=R/`00_n<
R/`2oh^:c@03oh^;cOn:RlkoRX_>00;oR8[?0_n8Rll2ohN;d0;oQh_A00CoQXcAohJ=d_n6SM?oQXgC
0_n6S]@2ohF>e0;oQHoF0_n5T=L2ohFAf003ohFBfOn6U=[oQYCJ00;oQYGK00?oQiOLohJGgOn6Umd0
0_n7VMh2ohRKg`;oRYkQ00?o0000ohbPh_ooool01?ooool00ol0003oooooooooo`01ooooo`00>?oo
ool2o`0001?ooooo00?od/C=om73cOoA`ld00_oA`/`2om71b`;od<3;0_o@_lX2olnnb@;ockg90_o>
_<P2oljkb006olfjaoo=^LOoc;W7olbiaoo<^<Koc;O60_o;]/H3olZea@04olVdaOo9/lGobK?5olVc
a@;ob;740oo7/<@2olJ_``;oaJk30oo4[L<00oo3[<?o`jc2ol:[`P02ol:Z`P?o`JW20_o0Z<83oknW
`P04okjV`OnmY/7o_JG1okbU`@;o_:C10onkXl401?njX/7o^J71okVQ`OniXL42okRP`@04okNP`Ong
Wl7o]Yo1okJO`@;o]Ik10_ndWL42ok>L`@;o/Yc10_naVl42ok2J`@;o[iW10_n^VL42ojfH`@05ojbG
`On[Ul7oZiO1oj^G`OnZU/400onYUL401?nXUL;oYiC2ojND`_nVTl83ojFC`P03ojFB`_nTT/?oY9;3
00;oXi730_nRTL<2oj6@``03oj2@`onOSlCoWho400;oWXo400GoWHo4oib>a?nLS/CoW8k4oi^>a@02
oiZ=a@;oVHg50_nHSLH00onGS<KoUXc6oiJ<aP02oiF<a`03oiB;aonDRlSoU8_800;oTh_800?oTX_9
oi6;bOnARlT00_n@RlT2ohn:bP03ohj:bon=R/_oSH[;00;oSH[<0_n<R/`2oh^:c@03oh^;cOn:Rlko
RH_?00?oRH_?0_n8S=02ohR<d@03ohR=d_n6SM;oQXgB00;oQXgC0_n6S]@2ohJ?e@03ohJ@e_n6TMOo
QY7G00;oQY;H0_n7U=T00on6U=[oQYGKohJEf`02ohNGg0;oR9WM0_n9Vmh2oh^Mh0;oS:3Q00?o0000
ohjRh_ooool00oooool00ol0003oooooooooo`01ooooo`00>_ooool00ol0003oooooooooo`0Aoooo
o`05om73cOoA`/codL;<om31c?oA`L/00_o@`</01?o?_l_od;o:olnnb_o?_/T2olnmb@03oljlbOo>
_<Soc[_800;oc[_800?ocK[7olfiaoo<^LL00_o<^<H00oo<]lKobkK6olZea@02olZea@04olZdaOo9
]<GobK?5olVca@;ob;;400?ob;74olNaa?o7/<@00_o6/<@00oo6[l?oaJk3olB]``02olB]``;o`jc3
0oo2Zl800oo2Z/;o`J[2ol6Y`P03ol2X`P;o_jO200?o_ZK1okfV`OnmY/400onlYL401?nlY<7o^jC1
ok^S`OnjXl42okZR`@04okVQ`OnhXL7o^:31okNP`@;o]io100Co]Yo1okJN`OneW/7o]Ik10_ndWL42
ok>L`@04ok:L`OnbVl7o/I_1ok6K`@;o/9[10_n_VL401?n^VL7o[YS1ojfH`On]V<42ojbG`@;oZiO1
0_nZU/42ojVE`@05ojRE`_nWU<;oYiC2ojND`_nVTl800_nUTl801?nTT/;oY9;3ojBB`onTT/<2oj>A
``04oj:A`onQT<?oXI33oj2@``?oWho40_nNSl@01?nMSlCoW8k4oib>a?nKS/D2oiZ>a@;oVHg50_nH
SLH00onGSLKoUhc7oiN<a`02oiJ<a`;oUHc70_nDRlP2oi>;b004oi:;bOnARlWoTH_9oi2;b@;oT8_:
00?oSh_;ohj;bon>Rl/01?n=Rl`2ohb;c@03oh^;c_n;S<koRhc>00CoRH_?0_n8S=001?n8S=7oR8gB
ohR=d_n7S]82ohN>d`;oQhoD0_n7T=D2ohNAeP;oQY7G00?oQY;HohNDfOn7U=T00_n7UMX2ohRGf`;o
RIWL0_n:Vmh2oh^Mg`;oS9oP00?oSZ;Ro`000?n@YN<01Oooool1o`00007ooooo0Oooool003_ooooo
00?o0000ooooooooool04Oooool00ooA`/cod<7<om31c002om30b`;ocko;0_o?_/X2olnmb@;oc[c9
0_o>^lP2olfjb004olfjaoo=^LOoc;S7olbhaP;obkO60_o;]/H00oo:]LGob[C5olZda@02olVca@03
olRbaOo8//Coak7400;oak7400Coak34olJ`a?o6[l?oaZo30_o5[/<3olB]``03ol>/`oo3Zl;o`Z_2
00;o`Z[200Co`J[2ol6Y`_o0Z<;o`:S20_noYl83okjV`@04okfV`OnmYL7o_:G1okbT`@;o^jC10_nj
Xl401?njX/7o^J71okVQ`OnhXL43okNP`@05okNO`OnfW/7o]Yk1okJN`OneW/400ondWL401OncW<7o
/Y_1ok:K`OnbVl7o/I_100?o/9[100Go[iW1ojjH`On^V<7o[YS1ojfH`@02ojbG`@;oZiO10_nZU/42
ojVE`@;oZ9G20_nWU<801OnVTl;oYI?2ojFC`_nUTl;oY9;200;oY9;30_nSTL<2oj:A``;oXI3300?o
X933oin?a?nOT<@00_nNSl@00onMSlCoW8k5oib>a@02oi^>a@;oVXk50_nISLD00onHSLKoUhg6oiN=
aP02oiN<a`05oiJ<aonES<OoUHc7oiB;b?nDS<P00_nCS<P3oi:<b@;oTH_:00?oT8_:ohn;bon?Rl/0
0_n>Rl/4ohf;c003ohb;cOn;RlkoRh_>00;oRhc>00?oRXc?ohZ<d?n:S=000_n9SM000on9SM7oRHkB
ohV>dP02ohV?d`;oQhkC0_n7Sm@2ohN@e@04ohNAe_n8T]OoR9;GohRDf0;oR9GI0_n9Um/2ohZIg0;o
Ri_M0_n<WMh2ohfOh0;oSZ7Q0_n@Y><00ol0003oTZOTooooo`03ooooo`7o00000Oooool1ooooo`00
??ooool00ol0003oooooooooo`0Aooooo`03om31c?o@`<_od<3;00;ocko;0_o?_/X01?o>_L[ockg9
oljlbOo>_<T2oljkb0;ocK[80oo=^LL01?o<^<OobkO6ol^ga_o;]lH2ol^faP06olZea_o:]<GobKC5
olVdaOo9/lGob;;50oo7/L@2olN`a0?oaZo30_o5[/<2olB]``03ol>/`oo3Zl;o`j_200?o`Z[20_o1
ZL83ol2X`P;o_jO200Co_ZK1okfV`OnmYL7o_:G10_nlY<401?nkY<7o^j?1ok^S`OnjXl43okVQ`@;o
^:7100Ko]j31okNO`OnfWl7o]Yo1okJN`OneW/43okBM`@05ok>L`OnbW<7o/Yc1ok:K`OnaVl400_na
V/401?n`V/7o[i[1ojnI`On_VL42ojjH`@;o[IS10_n/Ul401on[Ul7oZYK1ojZF`OnZU/7oZIG1ojRE
`_nXU<800_nWU<82ojJC`P;oYI?200GoY9;2ojBB`onTT/?oY9;3oj>A``02oj:A``03oj6@`onQTL?o
X93400?oWi3400?oWXo4oif?a?nMSl@00_nLS/D00onKS/GoVXk5oiZ>a@02oiZ>aP03oiV=a_nHSLKo
V8g600;oUhg700?oUXc7oiF<aonES<L00onDS<P00onCS<SoTXc9oi:<b@02oi:<b@04oi6;b_n@Rl[o
Sh_;ohn;b`;oSh_<0_n>S<`3ohf<c@;oS8c>0_n<S<l2oh^=c`;oRXc@00?oRHg@ohV=dOn9SM400_n9
S]82ohV?d`;oR93D00CoR93EohRAe_n8TMKoRI?G0_n9U=P2ohVEf@;oR9GI0_n9Um/2ohZIg0;oRi_M
0_n<WMh2ohfOh005ohjQhOn@Y>?oT:CSoi:Wi?l000001?ooool1o`00007ooooo0Oooool003gooooo
0_l0000Booooo`05om30boo?_l_ocko;olnnboo?_/X00_o>_LX01?o>_LWoc[c9olfkbOo>^lP2olfj
b0?ocKW700Coc;S7ol^gaoo;]lOobkO60_o;]/H2olZeaP;obKC50_o8/lD00oo8//Gob;;4olNaa003
olN`a004olJ_a?o6[l?oaJk3olF^``;oa:g30oo3[<<00oo3Zl;o`Z_2ol:Z`P03ol6Y`P;o`:S20_no
Yl800onnY/7o_JK1okfV`@03okbU`@04okbT`OnkY<7o^j?1okZS`@;o^Z;10oniXL401OnhXL7o]io1
okNO`OngWl7o]Yo100?o]Ik100Go]9g1ok>L`OncW<7o/ic1ok:L`@03ok6K`@05ok6J`On_V/7o[i[1
ojnJ`On_VL400on^V<400on]V<7o[9O1ojbG`@02oj^F`@;oZYK100GoZIG2ojRD`_nXU<;oZ9C2ojND
`P02ojJC`P?oYI?200CoY9;2ojBB`onTT/?oXi730_nRTL<2oj6A``;oX9340_nOT<@00onNSlCoWHo4
oif?a002oib?a@;oVhk50_nJS/D00onJS/KoVHg6oiV=aP02oiR=aP;oUhg700?oUXc7oiF<aonES<L0
0_nDS<P00onCS<SoThc9oi><b@02oi:<b@;oTXc:00?oT8_:ohn;bon?Rl/00_n?Rl`2ohj<c0?oSHc=
0_n<S<h2ohb<c`;oRhg?00CoRhg@oh^>dOn:S];oRXkB0_n:Sm82ohZ@d`;oRY7D0_n:T]D00on8TMKo
RI?GohVCe`02ohVDf0;oRIGI0_n:UmX2oh^If`;oRi[L00?oS9cNohjOgon>Wml00_n?XN42oi2ThP;o
TZKS00?o0000oiBYiOooool00_ooool1o`00007ooooo0Oooool003oooooo00?o0000ooooooooool0
4?ooool01Oo?_l_ockk;olnnboo>_/_oc[g:00;oc[g90_o=^lT02?o=^lSocK[8olbjb?o<^/SocKW7
olbhaoo;^<OobkO70oo;]/H3olZeaP08olVdaOo8/lGob;?5olRcaOo8//Gob;;4olNaa?o7/<@2olJ`
a003olJ_a?o5[l?oaJk300;oa:k300?oa:g3olB/`oo3[<<00_o3Zl<01_o2Zl;o`Z[2ol6Y`_o1ZL;o
`:S2oknX`P;o_jO20onnY/401?nmY/7o_JG1okbU`OnlY<42ok^T`@?o^Z?100Co^Z;1okVQ`OniXL7o
^J710_nhX<42okNO`@;o]Yk10_neW/42okBM`@;o/ic10_nbW<42ok6K`@;o/9[100Go[i[1ojnI`On^
VL7o[YW1ojjH`@03ojfH`@;o[9O100GoZiK1ojZF`OnZU/7oZYK1ojVE`P02ojRD`P;oYiC20_nVTl82
ojFC`P05ojBB`_nTT/?oY9;3ojBB`onSTL<00_nRTL<00onQTL?oX934oj2@a002oin@a0;oWXo40_nM
Sl@01_nLSlGoVhk5oi^>aOnJS/GoVhk5oiZ>aP;oVHk60_nHSLH3oiN=a`;oUXg80_nES<P2oiB<b0;o
Thc90_nBS<T01?nBS<[oTHc;oi6<bon@S</4ohn<c003ohj=cOn>SLkoSXg>00;oSHg>0_n=SLl3ohb>
d0;oS8oA0_n:S]82ohZ?dP;oRY3C00?oRY7DohZBeOn:T]D00_n:TmH2ohZDe`03oh^FfOn;Um[oRiOJ
00;oS9WK0_n<V]`2ohfLg@04ohjNgon?XN3oSj7PohnQh0;oTJ?R0_nBY^<2oiBYi005o`000?nF[>Ko
ooooooooool000000_ooool0043ooooo00?o0000ooooooooool04?ooool01Oo?_/_oc[k;oljnboo>
_L[oc[g900;ocKc900CocK_9olfkb?o<^/Soc;[80_o<^LP00oo<^<OobkS7ol^faP02ol^faP07olZf
a_o:]LKobKC6olVda_o9]<GobK?5olRca@02olRba@;oak740oo6/<@2olF_``?oa:k30_o4[<<3ol>[
``;o`Z[20_o1ZL83oknX`P03oknW`_nnYl;o_ZK100;o_JK100So_JG1okbT`OnlY<7o_:C1ok^T`Onk
Xl7o^Z?1okZR`@;o^J;100Co^J71okRQ`OnhXL7o^:310ongWl401OnfW/7o]Ik1okFN`OneW/7o]9g1
00?o/ic100Go/Yc1ok6K`OnaVl7o/I_1ok2J`@03ojnI`@03ojjI`On]V<7o[IS100;o[IS10_n/Ul42
oj^F`@03ojZF`OnZU/;oZIG200?oZ9C200?oYiC2ojJC`_nVTl800_nUTl82ojBB`P;oY9;300?oXi73
oj:A`onRTL<00_nQTL<2oj2@a0;oWi3400CoWXo4oif?aOnMSlGoWHo50_nLSlD3oi^>a@03oiZ>a_nI
S/KoVHk600;oV8g60onGSLL2oiJ=b003oiF<b?nDS<SoU8g900;oU8g90_nCSLX00onBSL[oTHg;oi6=
b`02oi6=c0?oShc<0_n>SLd2ohj=cP;oSHg>0_n=SLl3ohb>d0;oS8oA0_n;T=801?n;T=?oRi7Doh^A
e?n;T]D2oh^CeP;oRiCG0_n<U]P2ohbGf@;oRiOJ0_n<VM/00on<V]coSIcMohfLg@02ohjNg`04ohnQ
h?nAXn7oTjKSoi>Vh`?oU:WT00?oUZcVoiR_iol000000_ooool1o`00007ooooo0Oooool0047ooooo
00?o0000ooooooooool04?ooool01Oo>_/_oc[g:oljmb_o=_<[ocKc900;ocK_900CocK_8olbjb?o<
^LSoc;W80oo;^<L01Oo;]lOobkK6olZfa_o:]/KobKG600;obKC600CobK?5olRcaOo8/lGob;;50_o7
/LD00oo7/LCoa[34olJ`a002olJ_a005olF_`oo5[/?oa:k3olB]`oo4[<<00_o3[<<00oo3Zl?o`Z_2
ol:Z`P03ol6Y`P05ol2X`_noZ<;o_jO2oknW`_nnYl800onmY/42okbU`@04okbT`OnkY<7o^jC1ok^S
`@?o^Z;100Co^J;1okVQ`OnhXL7o^:310_ngX<400ongWl7o]Yo1okFN`@02okFN`@?o]9g100Co/ic1
ok:L`OnbVl7o/Y_10_naVl42ok2J`@;o[iW10_n^VL42ojfH`@Co[9O100SoZiK1ojZF`_nZU/;oZYK2
ojVE`_nXU<;oZ9G2ojND`P?oYY?200?oYI?2ojBB`_nTTl<00_nTT/<2oj>B``;oXY7300?oXI73oj2A
a?nPTL@00_nOT<@2oij@a0?oWHo50_nLSlD00onKS/GoVho6oiZ>aP02oiV>aP;oVHk700?oV8k7oiN=
aonGSLL00_nFSLP00onESLSoU8g9oiB=b@03oiB=b@03oi>=b_nBSL[oTXg:00;oTHg;0_nASL`01?n@
SLcoT8g=ohn=cOn?SLd2ohn>cP;oSXk?0_n>Sll00on=Sm3oSI3Aohf@d@02ohf@dP;oSI7C0_n<T]@0
0on;TMCoRi;Eoh^Be@02oh^CeP;oRiCG0_n<U]P2ohbGf@03ohfIf_n=VmcoSI_L00;oSYcM0_n?W]h2
oi2Qg`;oTJ?Q0_nCY^<02?nDZNCoUjcUoiR_ionH[nOoV[;Xo`000?oooooo00000_ooool004;ooooo
0_l0000Aooooo`05oljmb_o=_<[ocKc:olfkb_o=^lT00_o<^/T00oo<^/Soc;W8ol^ha`02ol^ha`;o
bkO700Cob[K7olZfa_o9]LKobKG60_o9]<H3olRca@03olNbaOo7/LGoak7400?oa[3400?oaZo4olF_
a?o5[/<00oo4[L<2ol>/``;o`Z_300Co`Z_2ol6Z`_o1ZL;o`JW20_o0Z<83oknW`P;o_ZK200Co_JK1
okfU`OnmYL7o_:G10onkY<42okZS`@04okZR`OniX/7o^J71okVQ`@;o^:3100Co]j31okNO`OnfWl7o
]Yo10_neW/43okBM`@04ok>L`OnbW<7o/Yc1ok:K`@?o/I_10_n`V/42ojnI`@;o[YW10_n]V<43ojbG
`@06oj^G`On[U/7oZiK1ojZF`_nYU/;oZIG20onXUL801?nWU<;oYY?2ojJD`_nUTl83ojBC``03ojBB
`onST/?oXi;300;oXY730_nQTL@2oj2Aa003oin@a?nNT<CoWY3500;oWY3500?oWHo5oib?aOnLSlD0
0_nKSlH2oiZ>aP;oVHk600?oVHk7oiR>aonHS/L00_nGSLL2oiJ=b003oiF=b?nDSLWoUHk900;oU8k:
00?oThk:oi>>bonCS//00_nBS//2oi:>c003oi6>cOn@S/goT8k=00;oShg=0_n?S/h2ohj>c`03ohj?
con=Sm3oSHo@00;oSI3A0_n=T=82ohfAd`03ohbBe?n<TmCoS9?D00;oS9CF0_n=UML2ohfFf0;oSISI
00?oSYWJohjKfon>Vm/00_n?WM`2oi2OgP;oTJ7O0_nBXn400onCY^;oUJWToiFYi002oiN/i@07oiR_
ionK/^SoVk;Xo`000?nM]^[oooooo`000001ooooo`00A?ooool00ol0003oooooooooo`0?ooooo`04
olflb_o=^l[ocK_:olbkb@?oc;[900?oc;W8ol^hb?o;^<L00_o;]lL01?o:]lOob[K7olVeaoo9]LH3
olVdaP;ob;?50_o7//D2olNaa0?oa[340_o5[l@3olB]``;o`jc30oo2Zl<2ol6Z`P?o`JW200?o`:S2
oknX`_noYl800_nnYl801?nnY/;o_JG1okfU`OnmYL42okbT`@04ok^T`OnkXl7o^j?1okZS`@?o^J;1
00?o^J71okRQ`OnhX<400ongWl401OnfWl7o]Ik1okFN`OneW/7o]9g100?o/ic100?o/Yc1ok6K`Ona
Vl400_naVl43ok2J`@05ojnI`On^VL7o[YW1ojjI`On]V<400_n/Ul42oj^G`@04oj^F`OnZU/;oZIK2
ojVF`P;oZIG20_nXUL801OnWU<;oYYC2ojJD`_nVU<;oYI?200;oY9?300GoY9;3oj>B`onST/?oXi;3
oj:A``02oj6Aa0;oX97400?oWi34oij@aOnNT<D00_nNT<D2oif?a@;oW8o50onKSlH2oiZ?a`03oiV>
aonHS/OoV8k700CoUhk80_nFS/T2oiF>b@;oU8k:00?oThk:oi>>bonCS//00_nBS//00onBS/coTHk=
oi6>c@02oi2>c@;oT8k>0on?Sll00on?T=3oSY3Aohj@d@02ohjAdP;oSY;B0_n>T]<00on>TmCoSYCE
ohjDe@02ohjFeP;oSYOG0_n>V=T2ohnJfP03ohnKfon@WMcoT9gL00;oTIoM0_nAXMl2oi:Sh0;oU:KR
0_nEZN<2oiN/i@;oVJoV00KoVk;XoiffjOnO^^_o0000ooooool00001ooooo`00AOooool00ol0003o
ooooooooo`0?ooooo`03olfkb_o<^lWoc;_900?oc;[900CobkW8ol^hb?o;^<SobkO70_o:]lL2olVe
a`05olVea_o9]<Kob;?6olRca_o8/lD00_o7//D2olNaa@03olNaa?o6/<Coa[3400?oaJo400Coa:k4
olB]`oo4[L?oa:g30_o3[<<3ol:[``03ol6Z`_o1ZL;o`JW200;o`:S200Co_jS2oknW`_nnYl;o_ZK2
0_nmY/800onmYL7o_:G1okbU`@02okbT`@;o^j?10_njX/42okVR`@;o^:710_ngX<401?ngWl7o]Yo1
okJN`OnfW/42okFN`@;o]9g10oncW<400onbW<7o/I_1ok6K`@03ok2J`@03ojnJ`On_VL7o[iW100;o
[YW10_n]V<42ojbG`@05oj^G`OnZU/;oZYK2ojZF`_nYU/800_nYUL82ojRE`P;oYiC200?oYYC2ojJD
`onUTl<00onTTl<01?nTT/?oXi;3oj>B`onRT/@3oj6Aa0;oX97400CoWi34oij@aOnOT<GoWY350_nM
T<D2oib?aPCoVho60_nJSlL00onIS/OoV8k7oiR>a`03oiN>b0;oUXk90_nFS/X2oiF>bP03oiB>bonC
S/_oThk;00;oTho<00?oTXo<oi:?cOnBSld00_nASlh2oi6@cP;oT93?00?oT93@ohn@d?n?T=000_n>
T=42ohjAdP03ohjBd_n>T]?oSY;C00;oSY?D0_n>U=D2ohjFeP;oSYOG00?oSYSIohnJf_n?V]X00_n?
Vm/2oi2Mg0;oTIoM0_nAXMl00onBXn3oU:KRoiJYh`03oiN/i@;oVJoV0_nK/^P00onM]^WoWk[[oj:n
k@02o`00007ooooo0016ooooo`03o`000?oooooooooo00oooooo00Coc;_9ol^jbOo;^/Woc;[90_o;
^LP2ol^hb006olZgb?o:]lOobKK7olVfaoo9]LOobKG61?o8/lH2olNba@05olNaaOo6/LGoa[75olJ`
a?o5/<@00oo5[l@00oo4[/Coa:g4olB]``03ol>/``;o`Z_30_o1Z/<01?o1ZL;o`:S2ol2X`_o0Z<82
oknW`P?o_ZK20_nmY/801?nlYL7o_:G2okbT`OnlY<42ok^S`@;o^Z;10_niX/43okRQ`@05okNP`Onf
Wl7o]Yo1okJO`OnfW/400oneW/42okBM`@;o/ic10_nbW<42ok6K`@05ok2J`On_V/7o[i[1ojnJ`On_
VL400on^VL400on]V<7o[9O1ojbG`@02oj^G`P;oZYK200GoZIK2ojVE`_nYUL;oZIG2ojRE`P02ojND
`P;oYYC30_nUTl<3ojBC``?oXi;300?oXY;4oj6Aa?nQTL@00_nPTL@01OnOTLGoWi35oin@aOnOT<Go
WY3500;oWI350_nLSlH00onKSlKoVho7oi^?a`02oiZ?a`03oiV?aonISlSoVHo800;oV8o800CoUho9
oiJ>bOnFS/WoUXk90_nFS/X00onES/[oU8k;oiB>b`02oi>>b`;oTho<00?oTXo<oi:?cOnBSld00_nA
Slh2oi6@cP03oi2@con@T=3oT93@00;oT97A0_n?T]400on?T];oSi?CohnCd`02ohnDe0;oSiGE0_n?
U]H2ohnGe`03ohnIf?n@V]WoT9[I00;oT9cK0_nAWM`2oi6Og@;oTZ7O00?oTjCPoiBVh_nDY^800_nF
ZN<01?nG[>GoVJoVoiV_i_nK/^P2oiffj@03oinjjooooooo000000;o00000Oooool004Oooooo00?o
0000ooooooooool03oooool01?o;^/WobkW9ol^ibOo;^LP2ol^hb0;ob[O800KobKK8olVfaoo9]LOo
bKG7olVea_o8]<H3olRcaP;oak;50oo6/LD2olF`a0?oaJo40_o4[L@3ol>/``;o`Z_30oo1Z/<2ol2Y
`P06ol2X`_noZ<;o_jS2oknW`_nnYl;o_ZK20onmY/82okbU`P04okbT`OnkY<7o^jC1ok^S`@?o^Z;1
00Co^J;1okVQ`OnhXL7o^:310_ngX<42okJO`@?o]Ik10ondWL43ok>L`@03ok:L`OnaVl7o/I_100;o
/9[10_n_V/44ojjI`@;o[IS10_n/Ul401on[Ul;oZYK2ojZF`_nZU/;oZIK2ojVE`_nXU/800_nXUL82
ojND`P03ojJD`onUTl?oYI?300CoY9?300?oXi;3oj>Ba?nRT/@00_nQT/@2oj2Aa0;oWi750_nOT<D0
0onNT<GoWI36oif@aP04oib@aP;oVho700?oVXo7oiV?aonISlL00_nISlP2oiR?b003oiN?bOnFS/Wo
Uho:00;oUXo:00?oUXo;oiF?bonESl/00_nDSl`2oiB@c003oi>@cOnCT<koTi3>00;oTY3>0_nBTLl0
0onATM3oTI;@oi6Bd002oi6Bd@;oT9?B00?oT9CCoi2Ee?n@UM@00_n@U]D2oi2GeP;oT9SG0_n@VMP0
0onAVmWoTIcKoi6Lf`02oi:Ng0;oTZ3M0_nCX]h2oiBTh0;oUJKQ0_nGZN<2oiR/i003oiV_i_oooooo
oooo00Co00001?ooool004Sooooo0_l0000@ooooo`04ol^ibOo:^LWob[W9ol^hb0?ob[O800KobKK8
olVeaoo9]LOobKG7olRdaoo8]<H2olRcaP;oak;600?oak;5olJaaOo6/LD00_o6/<D00oo5/<CoaJo4
olF_a002olB^a003olB]a?o3[LCo`jc300;o`Zc30_o2Zl<3ol6Z``04ol2Y`_o0ZL?o_jS2oknX`P;o
_ZO20onmY/83okbU`P03okbT`_nkY<7o^j?200;o^Z?100Co^Z;1okVR`OniX/7o^J710onhX<401?ng
X<7o]Yo1okJO`OnfWl42okFN`@;o]9g10_ncWL401OncW<7o/Yc1ok:K`OnbVl7o/I_100;o/9[10_n_
V/44ojjI`@04ojfH`On]V<;o[9S2ojbH`P;oZiO200?oZYK2ojZG`_nYU/800onXU/800onXUL;oYiC3
ojND``02ojJD``;oYI?300?oY9?3ojBCa?nTTl@00onST/@01?nRT/CoXI;4oj6Ba?nPTL@2oj2Aa@;o
Wi750_nNTLD2oif@aP;oW93600CoW937oi^@aonKT<OoVY370_nJT<P2oiV?b0CoV8o90_nGSlX00onF
Sl[oUXo;oiJ?b`02oiF?b`;oU8o<00?oU93<oi>@cOnCT<d00_nCT<h2oi:@cP03oi:AconATM3oTI7@
00;oTI;@0_nAT]400on@Tm;oT9CCoi2Dd`02oi2Ee0;oT9KE0_n@UmH00on@V=OoT9WHoi2If002oi6K
f@;oTIcK0_nBW]`2oi:Pg@03oi>Rg_oooooooooo00Kooooo0ol00008ooooo`00B_ooool00ol0003o
ooooooooo`0>ooooo`04olZibOo:^<Wob[S9olZgb0;obKO800?obKK8olVfaoo9]LL00_o8]<L2olRc
aP04olNca_o7//Koa[;6olJbaP;oa[7500Goa[35olF`aOo5/<GoaJo4olB_a003olB^a003ol>]a?o3
[<Co`Zc300?o`Z_30_o1Z/<3ol2Y``;o_jS20onnYl82okfV`P;o_:G20_nlY<83ok^S`P04okZS`Oni
X/7o^J;1okVR`@;o^:7100Co^:31okNP`OngWl7o]io10_nfWl42okFN`@;o]9g10_ncWL42ok:L`@04
ok:K`OnaVl7o/I_1ok6K`@;o/9[100?o[i[1ojjI`On^VL400_n^VL43ojfH`P03ojbH`_n[Ul;oZiO2
00;oZYO20_nYU/82ojRF`P;oZ9G30_nWU<<00onVU<?oYIC3ojFD``02ojBC``;oY9?400?oXi;4oj>C
a?nRT/@00_nQT/@2oj6Ba@;oX97500?oWi75oijAaOnNTLH00onMTLH3oib@a`;oVi3700?oVY37oiZ@
b?nJT<P00_nISlP2oiR?bC7ooooo1?l0000;ooooo`00Boooool00ol0003oooooooooo`0=ooooo`?o
b[S900CobKO9olVgb?o9]/SobKK70_o8]LL3olRda`03olRca_o7/lKoa[;600;oa[;60_o6/LD3olF`
a@05olB_aOo4[lCoa:k4olB^a?o3[L@00_o3[<@3ol:[``;o`J[30oo0ZL<2oknX``03oknX`_nnYl;o
_ZO200?o_JK20onlYL801?nlY<;o^jC2ok^S`_njXl82okZS`@?o^J;100Co^:71okNP`OngX<7o]io1
0onfWl401?neW/7o]9k1okBN`OndWL43ok>M`@03ok:L`OnaVl7o/I_100;o/I_10_n`V/42ojnJ`@05
ojjI`On^VL;o[IW2ojfI`_n]V<800_n/V<83oj^G`P03ojZG`_nYU/;oZIK200;oZ9K20_nXUL<2ojNE
``;oYYC30_nUU<<00onTTl?oY9?4ojBCa002oj>Ca0;oXY;40_nQT/@01?nQT/GoX9;5oj2BaOnOTLH3
oijAaP?oWI7600?oW937ooooooooool0=Oooool4o`0000oooooo001<ooooo`03o`000?oooooooooo
00gooooo00?ob[S9olVgbOo9]lT00_o9]/P00oo8]/Sob;G7olRda`02olRda`03olNcaoo7/lKoa[;6
00;oa[;60_o6/LH00oo6/LGoaK35olF`a@02olB_a@;oa:k40_o3[L@01Oo3[<Co`Zc4ol:/a?o2Zl?o
`J_300?o`J[300Co`:W3oknY`onoZ<?o_jS30_nnYl84okfV`PCo_:G200So^jC2okZS`_njXl;o^Z?2
okZS`OniX/;o^J;1okRR`P;o^:7100?o]j31okJO`OnfWl400_nfWl400oneWl7o]9k1okBN`@03ok>M
`@05ok>M`_nbW<7o/Yc1ok6K`OnaVl800_n`Vl82ok2J`@05ojnJ`On^VL;o[YW2ojjI`_n]VL801?n/
V<82oj^G`P;oZYO20_nYU/801onXU/;oZ9G3ojRE`onXUL?oYiG3ojJD`onVUL<01?nUU<@2ojBCa003
oj>Ca?nRTlGoXY?500;oXY;50_nQT/D2oj2Ba@03oinAa_nNTLKooooo03Oooooo1?l0000Cooooo`00
COooool2o`0000kooooo00GobKO9olRgbOo8]lWobKK8olRfb003olRda`03olNdaoo7/lOoa[?700?o
a[;600?oa[76olFaa_o5/<D00_o5/<D2olB_a@05olB^a?o3[/Go`jk5ol>]a?o2[L@00oo2[<@01?o1
Zl?o`J_4ol6Z`oo0ZL<2oknY``?o_jS300?o_ZO2okjW`onmY/800_nmY/84okbU`P;o^jC20_njXl82
okVR`P;o^:;200Go^:71okNQ`_ngX<7o]j31okJO`@02okJO`P05okFO`OndW/7o]9k1okBN`OncWL40
0oncWL801OnbW<7o/I_2ok6K`_naVl;o/9_200Co[i[20_n^VL82ojfI`P?o[9S20on[Ul800onZUl;o
ZIK3ojVF``02ojRF``03ojRE`onXU/?oYiG300?oYYG30onUU<@2ojBDa0;oXi?40_nRTlD00onRT/Go
XI;5ooooo`0hooooo`Co00005oooool004oooooo00?o0000ooooooooool03?ooool01_o8]lWob;K9
olRfbOo8]/SoakG8olRda`;oakC70_o6/lL3olJbaP;oaK7600?oaK36olF`aOo4[lD00_o4[lD2ol>^
a@;o`jg500Co`Zg4ol:/a?o2[<Co`Zc40_o1Zl@3ol2Y``;o_jW300Co_jS3okjX`onnZ<?o_ZO30onm
Y/83okbU`P;o^jC200?o^ZC2okZS`_njXl800oniX/801OnhX/;o]j72okNQ`_ngXL;o]j3100?o]Yo2
0_neWl800ondW/7o]9k2ok>M`P02ok>M`P05ok:M`_nbW<;o/Yc2ok6K`_naW<800_n`Vl83ojnJ`P?o
[YW200?o[IW2ojbH`_n/V<800_n/V<801?n[Ul;oZiS3ojZG`onZUl<2ojVF``CoZ9K300CoYiG3ojJE
`onVULCoYIG40onUU<@2ojBDa003oj>Ca?oooooooooo03Sooooo0ol0000Kooooo`00D?ooool00ol0
003oooooooooo`0<ooooo`06olRfbOo7]/WoakK9olNeb?o7]<SoakC70_o6/lP00oo6/lOoa[;7olJb
aP02olFaaP;oaK360oo4[lD2ol>^a@?o`jg50oo2[<@3ol6[a003ol2Za?o0ZL?o_jW300;o_jW30_nn
Z<<01_nnYl?o_JO3okfW`onmY/;o_:K3okbU`P;o_:G300So^jC2okZT`_njY<;o^ZC2okZS`_niXl;o
^J;2okRR`P;o^:720_ngXL82okJP`P?o]Yo200Go]Io2okBN`_ndW/;o]9k2ok>M`P02ok:M`P04ok:L
`_naW<;o/Ic2ok6L`P;o/9_21?n_V/82ojjI`P;o[IW200?o[9S2ojbI`on[V<<00on[V<<00onZUl?o
ZIO3ojVG``03ojRF``03ojRFa?nWU/CoYYG400;oYYG400?oYIG4ojFDa?ooool0>Oooool4o`0001ko
oooo001Aooooo`03o`000?oooooooooo00cooooo00GoakK9olNebOo7]LWoakC8olJdb003olJcb003
olJbaoo5//OoaK7600;oaK7700?oaK36olB`a_o4[lD00_o3[lH2ol>^a@05ol>]aOo2[LGo`Zg5ol:/
a?o1[<@00oo1Zl@2ol2Za004oknY`onoZLCo_ZS3okjX``;o_ZO30onmYl<01?nlY/?o_:G3okbU`onl
YL<2ok^T`P04okZT`_njXl;o^Z?2okVS`P?o^:;200Co^:72okNQ`_ngXL;o]j720_nfX<801_nfWl;o
]Io2okBO`_ndWl;o]9k2ok>N`P;o/ig200?o/Yg2ok6L`_naW<800_naW<83ok2K`P03ojnJ`_n^V/;o
[Y[200;o[YW200Co[IW2ojfI`on/VL?o[9W31?n[V<<2ojZG``03ojVG`onXU/?oZ9O400?oZ9K400?o
YiK4ojJEa?ooool0>?ooool4o`0002;ooooo001Booooo`;o00003?ooool3olNeb@?oa[C800?oa[?8
olFcb?o5/lP00_o5//L00oo5/LOoa;77olBaa`02olB`aP?o`jo600?o`jk5ol:^aOo2[LD00_o2[LD0
1?o1[<Co`J_4ol6[a?o1Zl@2ol2Za0;o_jW400Co_ZS3okjXa?nnZ<Co_ZO30_nmYl<3okbV``04okbU
`onkYL?o^jG3ok^T`P?o^Z?20_niXl82okRR`PCo]j720_nfX<82okFO`P;o]9o20_ncW/82ok>M`P;o
/Yg20_naW<82ok2L`P04ok2K`_n`Vl?o[i_2ojnK`P;o[Y[200Go[YW2ojfI`on]VL?o[IW3ojbI``04
oj^H``03ojZG`onZV<CoZIO400?oZ9O400?oZ9K4ooooooooool0=_ooool4o`0002Kooooo001Doooo
o`03o`000?oooooooooo00[ooooo00?oakG9olJebOo6]LT00_o6]<P3olFcb0;oaK;70oo4/LL2olB`
aP?o`jo60_o2[/D3ol:]a@;o`Jc500?o`J_4ol2[a?o0Z/@00_noZ/@01?noZLCo_ZW4okjXa?nmZ<@2
okfW``Co_:K300?o^jK3ok^U`onkYL<00_njY<<01?njXl;o^J?3okVS`oniXl83okRR`P03okNQ`_ng
XL?o]j7200?o]Z3200Go]Io2okBO`_ndWl;o]9o2ok>N`P03ok>M`P05ok:M`_naW<;o/Ic2ok6L`_n`
W<800on`Vl<00on_Vl;o[Y[3ojjJ``02ojfJ``;o[IW30_n/VL<3oj^H``?oZYS400?oZIO4ojRGa?oo
ool0=Oooool4o`0002[ooooo001Eooooo`03o`000?oooooooooo00[ooooo00Koa[G9olJdbOo6]<Wo
a[C8olFcbOo5/lP2olFbb003olFbaoo4/LOoa;7700;oa;3700?oa;36ol>_a_o3[lH00_o2[/H00oo2
[/Go`Zg6ol:]a@02ol6/a@;o`:_500Co`:_4okn[aOnoZ/Co_jW40_nnZL@3okfXa004okfW`onmYlCo
_:K3okbVa0;o^jK30onkYL<2okZT``;o^J?30_nhXl<01?nhX/;o^:;3okNQ`ongXL<2okJQ``06okJP
`_neX<?o]Io3okFO`ondWl;o]9o30_ncW/<01_ncWL;o/Yk3ok:M`onbWL?o/Ic2ok6L``;o/9c300Co
/9_3ojnL`on_Vl?o[i_30_n^V/<01On]V/?o[IW3ojfI`on]VL?o[9W300;oZiW40_n[V<@00onZV<Co
ooooooooo`0dooooo`?o0000;_ooool005Kooooo00?o0000ooooooooool02_ooool00oo6]<WoaKC9
olFdb@02olFcb@06olFbb?o4//Soa;;8olBaaoo4/LSoa;370_o3/<L01Oo3[lKo`Zo7ol:^a_o2[/Ko
`Zg600;o`Jg600?o`Jc5ol2/a_o0ZlD00onoZlD3oknYa0;o_ZW40onmZ<@01OnmYlCo_:K4okbVa?nl
Y/Co^jK300;o^jG300?o^ZG3okZT`onjY<<00_niXl<2okRS``;o^:;30ongXL<01OnfXL?o]J33okFP
`oneX<?o]Io300?o]9o300Go/ik3ok:N`onbW/?o/Yk3ok:M``03ok6L``03ok2L`on_W<?o[ic300;o
[i_30_n^Vl<2ojfJ``04ojfI`on]V/Co[9W4ojbIa0;oZiW400?oZiS4ooooooooool0<Oooool4o`00
037ooooo001Gooooo`;o00002oooool00oo5]<Woa;C:olFcb@02olBcb@;oa;;800Goa;78ol>ab?o3
/LSo`k37ol:`a`03ol:_a`04ol:^a_o1[LKo`Jg6ol6]aP;o`:c61?noZlD01OnoZ/Go_jW4okjYaOnn
ZLGo_ZW400?o_JS40_nlYl@01?nlY/Co^jK4ok^U`onkYL@2okZU``04okZT`oniY<?o^JC3okVS``?o
^:?300?o^:;3okNR`ongXL<00onfXL<2okFP``?o]9o300?o/io3ok>N`oncW/<00_nbW/<2ok6M``05
ok6L`onaWL?o/9c3ok2L`on_W<<00on_Vl<00on^Vl?o[I[4ojfJa002ojfJa003ojbIa?oooooooooo
037ooooo1?l0000eooooo`00FOooool00ol0003oooooooooo`08ooooo`;oa;C:0oo4/lT2olBbb0?o
`k780_o2/<L3ol:_a`;o`Jk70oo1[LH2ol2/aP05okn[aOnoZlKo_j_6oknZaOnnZ/D00_nnZLD2okfX
a@03okfXa?nlZ<Co_:S400;o_:O400So^jK4ok^Ua?nkYLCo^jG4okZU`onjYLCo^JC3okVTa0;o^:?4
00Co^:?3okRSa?nhXlCo]j;31?nfXL<3okFP``03okBO`oncWl?o/io300;o/ik30_nbW/<01_naWL?o
/Ig4ok6M`onaWL?o/9c3ok2La0;o[ic400Co[i_3ojjLa?n^VlCo[Y_40on]V/@`ooooo`Co0000>Ooo
ool005[ooooo00?o0000ooooooooool02?ooool00oo4]<[oa;?:olBcb@02ol>bb@03olBbb?o3/LWo
`k7800;o`[3800?o`[37ol:_b?o2[lL00_o1[lL2ol6^a`07ol6]a_o0[LOo`:g7ol2/a_no[<Ko_j_6
okj[aP02okjZa@?o_ZW50_nmZ<D01?nlZ<Co_:S5okbWa?nkYlD2ok^Va004ok^Ua?njYLCo^ZG4okZU
a0?o^JC40onhXl@01OngXlCo]j;4okNRa?nfXL?o]Z;400;o]Z7400Ko]J33okBPa?ndX<?o]:33ok>O
`oncWl@2ok>N``05ok:N`onbW/Co/Ig4ok6Ma?naWL<00on`W<@01On_W<Co[Yc4ojjLa?n^W<Co[Y_4
02oooooo1?l0000mooooo`00Foooool00ol0003oooooooooo`08ooooo`03olBcb_o3/l_o`k;900;o
`k;:00?o`k79ol:abOo2/<P00_o2/<T00oo2[lSo`Jo8ol6_a`02ol6^b004ol6^aoo0[LOo`:g7okn]
a`;o_jc60onnZlH01_nnZ/Go_Z[6okjYaOnmZLKo_JS5okbXaP;o_:S50onkYlD01?nkY/Co^ZK5okZU
a?njY/D2okVUa004okVTa?nhY<Co^:C4okRSa0?o]j?400Go]j;4okJRa?nfX/Co]Z74okFQa002okBP
a004okBP`ondX<Co]:34ok>Oa0?o/Yo400Oo/Yk4ok6Na?naW/Co/Ik4ok2Ma?n`W<Co/9g400;o[ic4
00?o[Yc4ooooooooool0;?ooool3o`00047ooooo001Looooo`;o00002Oooool2ol>cb`06ol>bb_o2
//[o`[;:ol:abOo2/L[o`[390_o1/<T01?o1[lSo`Jo9ol6^b?o0[/P2ol2]a`?o_jg700Go_jc6okn/
aonnZlKo_Z_6okjZaP02okfZaP04okfYa_nlZ<Ko_:S6okbXaP;o_:S50_nkYlD5okZVa@04okVUa?nh
Y<Co^:C4okRTa0;o^:C500?o]j?4okNSaOnfX/@00onfX/@2okFQa004okBPa?ndXLCo]:34ok>Pa@;o
/io400?o/Yo4ok:OaOnaW/@00_naW/@00onaW/Go/9g5ok2Ma@02ok2Ma003ojnLa?oooooooooo02Wo
oooo1?l00014ooooo`00G_ooool00ol0003oooooooooo`07ooooo`04ol>cboo2/l_o`[;:ol:bb`;o
`[7:0oo1/<T2ol6_b@?o`:k800Go`:g7okn]b?no[LOo_jg7okn/a`02okj/a`04okj[a_nmZ/Ko_J[6
okfZaP;o_:W60onlZ<H01?nlZ<Go^jO5ok^WaOnkYlD3okZVa@04okVVaOniYLGo^JG5okRTa0;o^:C5
00Co]jC5okNSaOngXlGo]Z;40_nfXlD01OnfX/Co]J75okFQaOneXLGo]:7400?o/j3500Go/io4ok:O
aOnbWlGo/Yo5ok6Na002ok6Na@03ok2MaOoooooooooo02Wooooo1?l00018ooooo`00Goooool00ol0
003oooooooooo`06ooooo`;o`[?;0oo2///00oo2/L[o`K7:ol6`b@02ol6`b@04ol6_bOo0[lWo`:k8
okn^b@?o_jg800Co_jg7okj/aonn[<Oo_Zc70_nmZlL01onmZ/Ko_J[7okfZaonlZLKo_:W7okbXa_nk
ZLL00_nkZ<H01?nkYlGo^ZO6okZWa_njY/D2okVVa@04okVUaOnhYLGo^:G5okRTa@?o]jC50_ngXlD0
1_nfXlGo]Z?6okFRaOneX/Go]J75okBRa@;o]:7500Ko/j35ok>QaOncX<Go/j35ok:OaOnbX<D2ok6O
a@03ok6NaOoooooooooo02Kooooo1?l0001<ooooo`00H?ooool00ol0003oooooooooo`06ooooo`03
ol:cboo1/lco`[;;00;o`K;;00Go`K7:ol6aboo1/<Wo`;3:ol2_b@02okn_bP;o_jk900Go_jg8okj]
bOnn[LSo_Zg8okj/a`02okj/b003okf[aonmZlSo_J[700;o_:[700So_:W7ok^YaonkZLOo^jW7ok^X
a_nkZ<Oo^ZO6okZWa`;o^ZK600?o^JK5okVVa_nhYLD00onhYLH01?ngY<Go]jC6okNTa_ngXlD3okJS
aP05okFRaOndX/Go]:;5okBRaOndXLD00_ncXLD01OncX<Go/Z36ok:PaOnbX<Go/Io502Kooooo1?l0
001@ooooo`00HOooool2o`0000Oooooo0_o1/l`00oo1//_o`;;<ol6ab`02ol2ab`04ol2`b_no/<_o
_jo:okn_bP;o_jk90onn[LT00onn[LSo_Zg9okj/b002okf/b004okf[b?nlZ/Oo_:[7okbZa`Co^jW7
00Go^jS7okZXaonjYlOo^ZO7okZVaP02okVWa`03okVVa_nhYLKo^:G600;o^:G600?o]jG6okNTa_ng
Y<L00_nfY<H01_nfXlKo]J?6okFSa_neXlKo]:;5okBRaP;o/j7600Go/j75ok:Pa_nbX<Ko/Z36ok:P
a@0Tooooo`?o0000E?ooool006?ooooo00?o0000ooooooooool01?ooool01oo1/lco`;?=ol2ccOo0
//co_k;=ol2abono/L`00_no/</3okn_bP03okn^bOnn[/[o_Zg900;o_Zk:00Co_Zg9okf]bOnm[<So
_:c90_nlZlP01_nlZ/Oo_:_8okb[b?nkZLOo^j[8ok^Ya`?o^ZS700Co^ZO7okVXaoniYlOo^JO70_nh
Y/L01?nhYLKo^:K7okRVaongYLH2okNTa`03okJTa_nfY<Oo]J?600;o]J?600Co]:?7okBRa_ndX/Ko
/j760_ncX/L00oncXLKo/Z36ooooo`0Qooooo`Co0000Eoooool006Cooooo00?o0000ooooooooool0
1?ooool01?o0/lgo_k?>okncc_no//d3oknac003okn`bono/<co_jo:00;o_Zo;00?o_Zk:okj_bonn
[/X00_nm[//02_nm[LWo_:c9okb/bOnl[<Wo_:_8okb[bOnlZlSo^j_9ok^Zb?njZ/T2okZYb004okZX
aonjZ<So^ZS8okVXa`?o^JO700Co^:K7okRWb?nhY/Oo]jK80_ngYLL01_ngY<Oo]ZC7okJTaonfY<Oo
]J?6okFTa`;o]:?700?o]:;6okBSaoncX/L08Oooool4o`0005_ooooo001Uooooo`03o`000?oooooo
oooo00?ooooo0ono/lh2oknbc@06oknac?nn/Lgo_[7=okn`c?nn/<co_Zo;0_nm[l`01?nn[l_o_Jk;
okf^bonm[//2okb]bP03okb/bOnl[<[o_:_900;o^jc:00So^j_9okZZbOnjZ/Wo^Z[9okZYb?njZLWo
^ZS8okVYb@;o^JS800Co^JO7okRWb?nhYlSo]jO80_ngY/P01OngYLOo]ZK8okJUaonfYLOo]ZC700;o
]JG800Go]JC7okBTb?ndY<So]:C8okBSa`0Nooooo`Co0000Goooool006Kooooo0_l00004ooooo`06
okncc_nn/loo_[??oknbcOnn//ko_[7=0_nn/Lh01?nn/<co_K7=okf_c?nm/<d2okf_c003okf^bonl
[/_o_:g:00;o_:g;00Co_:c:ok^]bonk[<[o^jc;0_nkZlX01?njZ/Wo^Z_:okZ[b_njZLT3okVYb@03
okVXb?nhZ<Wo^:O800?o]jO800So]jK8okNWbOnfY/So]ZK8okJUaonfYLSo]JG8okFUb@?o]:C87Ooo
ool3o`0006?ooooo001Xooooo`03o`000?oooooooooo00;ooooo0onn/ll00onn//ko_K;?okjacP02
okfbcP09okfacOnm/<go_K3=okf`cOnm[lco_:o<okb^bonl[/co_:g;00;o^jk<00So^jg;ok^/bonk
[<_o^jc;ok^[b_njZl_o^Z_:okV[b`;o^J[:00Co^JW9okVYb_nhZ<Wo^:W:0_nhZ<T01?ngYlSo]jS9
okNXbOngYlT3okJVb@05okJUb?neYLWo]JG9okFUbOndY<P06_ooool4o`0006Kooooo001Yooooo`03
o`000?oooooooooo00;ooooo00Oo_[??okfdd?nm]=3o_K;?okfcd?nm//ko_;;?00;o_K7>00?o_K3=
okb`c_nl[l`00_nl[ld01?nl[/co^jo=ok^^c?nk[/d2ok^]c004ok^/bonj[Lco^Zg<okZ[b`;o^J_;
00Co^J[:okVZboniZ/_o^JW:0onhZLX01?nhZ<Wo]jS:okNXbOngZ</2okJWbP05okJVbOnfYl[o]JK9
okFVbOneYLT06?ooool4o`0006[ooooo001Zooooo`03o`000?oooooooooo00;ooooo00Co_KC@okbd
d_nm/m3o_;?A0_nl//l01_nm/Lko_;7?okbaconl/<ko^k7?okb_c@;o^k3?00So^jo=ok^^cOnk[/go
^jk=ok^]c?nj[/go^Zg<okV]c@;o^Jc<00Co^J_;okV/c?niZ/_o^:_<0_nhZ//01?nhZL[o]jW;okNY
bongZ<X3okNXb`04okJWb_nfZ<_o]ZO:okFVbAKooooo1?l0001^ooooo`00Joooool00ol0003ooooo
ooooo`02ooooo`07okbdd_nk]=?o_;?AokbcdOnl//oo_;;Aokbac`02ok^bd004ok^aconk/M3o^k3?
okZ`d0;o^jo>00Co^jk=okZ_c_nj[lko^Zk=0_ni[Ld01Oni[<co^Jg=okV]cOni[<co^:c=00;o^:_<
00Co^:[;okR[c?ngZL_o]j[=0_ngZL`00ongZ<_o]ZW<okJXb`0Eooooo`Co0000L_ooool006cooooo
0_l00003ooooo`07ok^ddonk]=;o^kCBok^dd_nl/]7o^k?Bok^bd002okZbd@08ok^ad?nj/=3o^[3@
okZ`d?nk[lko^[3@okZ_c_ni[m02okV^cP03okV]cOni[/ko^Jg=00;o^:g>1?nh[<d01onhZlco]jc>
okNZcOngZ/go]jW<okJZcOnfZL`04oooool3o`0007Kooooo001^ooooo`06o`000?oooooooooooooo
oonk]MCo^kCB0_nj]=@00onk/m;o^[CCokZbd@02okZcd`04okZbdOnj/=3o^[7AokZ`d0;o^K7A1?ni
[m001?ni[/ko^:k@okR]c_nh[]02okR]cP04okR/cOng[Loo]jc>okJ/c`;o]Z_>00?o]Z[=oooooooo
ool03oooool4o`0007Wooooo001_ooooo`03o`000?oooooooooo00;o^[KF00Oo^[CDokVeeOni]MGo
^[CCokVdeOnj/m?o^KCD00;o^K;C00Co^[7AokVbdoni/M7o^;7B0_ni/=401Oni[m3o^;3AokR`dOnh
[]3o]joA00;o^:k@00?o^:g>okN^d?ng[Ll00onf[<l00onfZlkoooooooooo`0<ooooo`Co0000OOoo
ool0073ooooo00Ko0000oooooooooooo^[KFokVgeoni]MD2okRfe`04okVdeOnh]]Oo^KCDokVbd`;o
^;?D00Oo^K;CokRce?nh/M;o^;7BokV`dOnh/M;o^;3A00;o]k7C0ong[m401Ong[]3o]ZoBokJ_d_nf
[]3o]Zc?00cooooo1?l00021ooooo`00LOooool2o`000007ooooooni]mOo]kSIokRfeong]mWo^;KG
okNgf002okReeP05okRce?ng]=Ko]kCFokRce?ng]=H00_ng/]@01?nh/M;o]k;DokNadonf/]@2okN`
d`03okN_dOnf/=?o]ZoB00_ooooo1?l00025ooooo`00Loooool01_l0003o]kSIokJifonf^M_o]kOI
okJhf`;o]kOH00?o^;GFokNff?ng]=H00_nf]]P3okNdeP04okNbe?nf/mKo][?FokJbe0?o][;E00?o
][3Cooooooooool01oooool3o`0008Wooooo001dooooo`06o`000?nf^M_o]K[MokFjgOnf^=_o];[M
0_nf^=/01?ng]]So]KOJokJff?ne]mX2okJef003okNde_ne]MSo][?F00;o]KGI00?o][?GokJbeOoo
ool01_ooool4o`0008cooooo001eooooo`06o`000?ne^]go/k_Pok>kh?nd^]go/k_O0_nd^Md01?ne
]m[o];WMokFgf_nd^Md2okBgfP03okFef?nd]m_o]KGI00Kooooo1?l0002@ooooo`00M_ooool2o`00
00;o/KgS00Co/k_Ook6mh_nc^moo];WM0_nb^]l01Ond^Mgo/[[Ook>hgOnc^=go];OK00?ooooo1?l0
002Dooooo`00N?ooool00ol0003o[koVok6mhP02ojnoi@05ok6lh_n__^Go/KcRok6lh_nb^]l00_oo
ool4o`0009Sooooo001iooooo`03o`000?n/`NWoZL?]00;o[<7Y00?o[kkUooooooooool00ol0002L
ooooo`00N_ooool00ol0003oZL?]ooooo`04o`0009oooooo001kooooo`;o0000Xoooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool002gooooo0ol0002:ooooo`03o`000?oooooooooo
02_ooooo0ol0000Eooooo`03o`000?oooooooooo01gooooo000^ooooo`03o`000?oooooooooo08So
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01co
oooo000Xooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000?ooooo
1?l000000ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co00000oooool2o`0000;ooooo
1_l00006ooooo`Co00000_ooool5o`000003ooooool0003o000000?o000000?oooooo`000?l00000
0ol00002ooooo`?o00000_ooool3o`0000Cooooo0ol00002ooooo`?o000000Coooooo`000?l0003o
oooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?o
oooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00000_ooool3o`0000;o
oooo0ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00002ooooo`[o00001Oooool00ol0
003oooooooooo`0Kooooo`009oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001_ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`009oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`03o`000?oo
oooooooo00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5o`0000So
oooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003oooo
o`03o`000?oooooo000000;ooooo1Ol00003ooooo`04o`000?ooooooooooooooo`Go00000_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00002ooooo`?o00001Oooool00ol0003oooooooooo`0Kooooo`009oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02?ooool3o`0000;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Gooooo00Ko
0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo01_ooooo000Wooooo`06o`00
0?ooooooooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol00003oooo
o`;o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003
ooooo`Co00000oooool3o`0000Wooooo00Go0000oooooooooooo0000ooooo`03o`0000Cooooo1?l0
0002ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_oo
ool4o`0000?ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`Ko000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00002ooooo`Co00000oooool9o`0000?ooooo0ol00003ooooo`Co00001?oo
ool00ol0003oooooooooo`0Kooooo`009oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool07?ooool002Sooooo0ol00009ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03Oooool3o`0000Wooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo
0_l0000:ooooo`Co00001?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool2o`0002kooooo
00?o0000ooooooooool06?ooool3o`0001Kooooo00?o0000ooooooooool00_ooool2o`0000_ooooo
00?o0000ooooooooool07Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0532854, 0.0647328, \
0.00350953, 0.00350953}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -93 0 ]
[.5 .82364 93 9 ]
[.13778 .20281 -23.9157 -9 ]
[.13778 .20281 .08425 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.54696 .04189 -15.5834 -9 ]
[.54696 .04189 2.41661 0 ]
[.76317 .09047 0 -6.16825 ]
[.76317 .09047 24 2.83175 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93807 .35831 0 -5.91508 ]
[.93807 .35831 18 3.08492 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -24 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Point Spread Intensity Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.14703 .21212 m
.15165 .21677 L
s
[(-0.1)] .13778 .20281 .99298 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.55471 .05248 m
.55858 .05778 L
s
[(0.1)] .54696 .04189 .73149 1 Mshowa
.125 Mabswid
.18507 .19722 m
.18781 .20005 L
s
.22368 .1821 m
.22638 .18497 L
s
.26288 .16675 m
.26553 .16966 L
s
.30267 .15117 m
.30528 .15412 L
s
.38409 .11929 m
.38661 .12231 L
s
.42575 .10298 m
.42822 .10604 L
s
.46806 .08641 m
.47049 .08951 L
s
.51104 .06958 m
.51342 .07272 L
s
.10954 .2268 m
.11235 .22955 L
s
.0726 .24126 m
.07544 .24398 L
s
.59907 .03511 m
.60134 .03833 L
s
.64416 .01746 m
.64637 .02071 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75086 .09503 m
.74471 .09732 L
s
[(-0.1)] .76317 .09047 -1 .37072 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92555 .36224 m
.91929 .36421 L
s
[(0.1)] .93807 .35831 -1 .31446 Mshowa
.125 Mabswid
.77057 .12517 m
.76687 .12652 L
s
.78971 .15446 m
.78601 .15579 L
s
.80833 .18294 m
.80462 .18425 L
s
.82645 .21065 m
.82273 .21194 L
s
.86123 .26386 m
.8575 .26511 L
s
.87794 .28942 m
.87421 .29065 L
s
.89422 .31432 m
.89048 .31554 L
s
.91009 .33859 m
.90634 .33979 L
s
.73059 .06402 m
.72691 .06541 L
s
.70971 .03208 m
.70604 .0335 L
s
.94063 .38531 m
.93687 .38648 L
s
.95534 .40781 m
.95158 .40896 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.25)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0.5)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.75)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.40204 .60085 .40512 .60371 .41029 .60216 .40722 .59929 Mtetra
.40722 .59929 .41029 .60216 .41547 .60061 .41241 .59773 Mtetra
.41241 .59773 .41547 .60061 .42066 .59905 .4176 .59617 Mtetra
.4176 .59617 .42066 .59905 .42586 .59749 .42281 .59461 Mtetra
.42281 .59461 .42586 .59749 .43107 .59593 .42802 .59304 Mtetra
.42802 .59304 .43107 .59593 .43629 .59436 .43325 .59147 Mtetra
.43325 .59147 .43629 .59436 .44151 .5928 .43848 .58989 Mtetra
.43848 .58989 .44151 .5928 .44675 .59122 .44373 .58831 Mtetra
.44373 .58831 .44675 .59122 .452 .58965 .44898 .58673 Mtetra
.44898 .58673 .452 .58965 .45726 .58807 .45425 .58515 Mtetra
.45425 .58515 .45726 .58807 .46253 .58649 .45952 .58356 Mtetra
.45952 .58356 .46253 .58649 .46781 .58491 .46481 .58197 Mtetra
.46481 .58197 .46781 .58491 .4731 .58332 .47011 .58038 Mtetra
.47011 .58038 .4731 .58332 .4784 .58173 .47541 .57879 Mtetra
.47541 .57879 .4784 .58173 .48371 .58014 .48073 .57719 Mtetra
.48073 .57719 .48371 .58014 .48903 .57854 .48606 .57558 Mtetra
.48606 .57558 .48903 .57854 .49437 .57694 .4914 .57398 Mtetra
.4914 .57398 .49437 .57694 .49971 .57534 .49675 .57237 Mtetra
.49675 .57237 .49971 .57534 .50506 .57373 .50211 .57076 Mtetra
.50211 .57076 .50506 .57373 .51042 .57212 .50748 .56915 Mtetra
.50748 .56915 .51042 .57212 .5158 .57051 .51286 .56753 Mtetra
.51286 .56753 .5158 .57051 .52118 .5689 .51825 .56591 Mtetra
.51825 .56591 .52118 .5689 .52657 .56728 .52365 .56428 Mtetra
.663 .741 .908 r
.52365 .56428 .52657 .56728 .53198 .56566 .52906 .56266 Mtetra
.664 .741 .908 r
.52906 .56266 .53198 .56566 .53739 .56403 .53448 .56103 Mtetra
.53448 .56103 .53739 .56403 .54282 .5624 .53992 .55939 Mtetra
.663 .741 .908 r
.53992 .55939 .54282 .5624 .54826 .56077 .54536 .55776 Mtetra
.54536 .55776 .54826 .56077 .55371 .55914 .55081 .55612 Mtetra
.664 .741 .908 r
.55081 .55612 .55371 .55914 .55916 .5575 .55628 .55447 Mtetra
.663 .741 .908 r
.55628 .55447 .55916 .5575 .56463 .55586 .56176 .55284 Mtetra
.661 .741 .909 r
.56176 .55284 .56463 .55586 .57011 .55423 .56724 .55122 Mtetra
.65 .74 .915 r
.56724 .55122 .57011 .55423 .57561 .55268 .57275 .54975 Mtetra
.622 .736 .929 r
.57275 .54975 .57561 .55268 .58111 .55144 .57826 .54864 Mtetra
.627 .748 .934 r
.57826 .54864 .58111 .55144 .58664 .55038 .58379 .54744 Mtetra
.674 .753 .91 r
.58379 .54744 .58664 .55038 .59217 .54901 .58932 .54561 Mtetra
.687 .728 .881 r
.58932 .54561 .59217 .54901 .5977 .54718 .59486 .54355 Mtetra
.664 .708 .88 r
.59486 .54355 .5977 .54718 .60324 .54498 .60041 .54187 Mtetra
.665 .74 .906 r
.60041 .54187 .60324 .54498 .60878 .54275 .60598 .54017 Mtetra
.681 .782 .926 r
.60598 .54017 .60878 .54275 .61435 .54108 .61155 .53821 Mtetra
.449 .671 .958 r
.61155 .53821 .61435 .54108 .61996 .54034 .61719 .53868 Mtetra
.508 .801 .998 r
.61719 .53868 .61996 .54034 .62555 .53869 .62282 .53799 Mtetra
.682 .933 .968 r
.62282 .53799 .62555 .53869 .63113 .53642 .62841 .53537 Mtetra
0 .386 .706 r
.62841 .53537 .63113 .53642 .6368 .53643 .63415 .53731 Mtetra
.38 .834 .74 r
.63415 .53731 .6368 .53643 .64241 .53415 .63976 .53477 Mtetra
.121 0 0 r
.63976 .53477 .64241 .53415 .64807 .53305 .64547 .53462 Mtetra
.23 0 0 r
.64547 .53462 .64807 .53305 .65375 .53201 .65118 .53409 Mtetra
.068 0 0 r
.65118 .53409 .65375 .53201 .65939 .52999 .65685 .53217 Mtetra
.325 0 0 r
.65685 .53217 .65939 .52999 .6651 .52902 .66259 .53174 Mtetra
.161 0 0 r
.66259 .53174 .6651 .52902 .67077 .52706 .66829 .52971 Mtetra
.213 0 0 r
.66829 .52971 .67077 .52706 .67647 .52542 .674 .52809 Mtetra
.225 0 0 r
.674 .52809 .67647 .52542 .68219 .52384 .67974 .52653 Mtetra
.017 0 0 r
.67974 .52653 .68219 .52384 .68788 .52147 .68542 .52362 Mtetra
.162 0 0 r
.68542 .52362 .68788 .52147 .69362 .52006 .69118 .52212 Mtetra
0 0 0 r
.69118 .52212 .69362 .52006 .69933 .51763 .69687 .51909 Mtetra
.69687 .51909 .69933 .51763 .70506 .51542 .70257 .51602 Mtetra
.70257 .51602 .70506 .51542 .71085 .51417 .70838 .51491 Mtetra
.778 .997 .804 r
.70838 .51491 .71085 .51417 .71653 .5108 .71398 .50967 Mtetra
.446 .822 .991 r
.71398 .50967 .71653 .5108 .72235 .50968 .71983 .50888 Mtetra
.693 .938 .964 r
.71983 .50888 .72235 .50968 .72815 .50788 .72558 .50605 Mtetra
.791 .871 .907 r
.72558 .50605 .72815 .50788 .7339 .50521 .73127 .5022 Mtetra
.64 .747 .927 r
.73127 .5022 .7339 .50521 .73972 .50348 .73712 .50076 Mtetra
.659 .776 .935 r
.73712 .50076 .73972 .50348 .74559 .50232 .74296 .49903 Mtetra
.662 .737 .906 r
.74296 .49903 .74559 .50232 .75148 .50111 .74881 .49729 Mtetra
.64 .698 .888 r
.74881 .49729 .75148 .50111 .75734 .49949 .75471 .49592 Mtetra
.655 .719 .895 r
.75471 .49592 .75734 .49949 .76319 .49742 .7606 .49429 Mtetra
.692 .76 .904 r
.7606 .49429 .76319 .49742 .76903 .49506 .76645 .49206 Mtetra
.697 .77 .908 r
.76645 .49206 .76903 .49506 .77489 .49289 .77231 .48974 Mtetra
.675 .753 .91 r
.77231 .48974 .77489 .49289 .78079 .49102 .77821 .48778 Mtetra
.665 .744 .909 r
.77821 .48778 .78079 .49102 .78671 .48924 .78414 .48597 Mtetra
.664 .742 .908 r
.78414 .48597 .78671 .48924 .79263 .48746 .79007 .48417 Mtetra
.663 .741 .908 r
.79007 .48417 .79263 .48746 .79857 .48568 .79602 .48238 Mtetra
.664 .741 .908 r
.79602 .48238 .79857 .48568 .80453 .48389 .80198 .48059 Mtetra
.664 .742 .908 r
.80198 .48059 .80453 .48389 .81049 .4821 .80796 .47879 Mtetra
.663 .741 .908 r
.80796 .47879 .81049 .4821 .81647 .48031 .81394 .47699 Mtetra
.664 .741 .908 r
.81394 .47699 .81647 .48031 .82246 .47851 .81994 .47519 Mtetra
.81994 .47519 .82246 .47851 .82846 .47671 .82595 .47338 Mtetra
.82595 .47338 .82846 .47671 .83448 .47491 .83198 .47157 Mtetra
.83198 .47157 .83448 .47491 .8405 .4731 .83801 .46975 Mtetra
.83801 .46975 .8405 .4731 .84654 .47129 .84406 .46793 Mtetra
.84406 .46793 .84654 .47129 .8526 .46947 .85012 .46611 Mtetra
.85012 .46611 .8526 .46947 .85866 .46765 .8562 .46428 Mtetra
.8562 .46428 .85866 .46765 .86474 .46583 .86228 .46245 Mtetra
.86228 .46245 .86474 .46583 .87083 .464 .86838 .46062 Mtetra
.86838 .46062 .87083 .464 .87693 .46217 .8745 .45878 Mtetra
.8745 .45878 .87693 .46217 .88305 .46034 .88062 .45694 Mtetra
.88062 .45694 .88305 .46034 .88918 .4585 .88676 .45509 Mtetra
.88676 .45509 .88918 .4585 .89532 .45666 .89291 .45324 Mtetra
.89291 .45324 .89532 .45666 .90147 .45481 .89907 .45139 Mtetra
.89907 .45139 .90147 .45481 .90764 .45296 .90525 .44953 Mtetra
.90525 .44953 .90764 .45296 .91382 .4511 .91144 .44767 Mtetra
.91144 .44767 .91382 .4511 .92001 .44925 .91764 .44581 Mtetra
.91764 .44581 .92001 .44925 .92622 .44738 .92386 .44394 Mtetra
.92386 .44394 .92622 .44738 .93244 .44552 .93009 .44206 Mtetra
.93009 .44206 .93244 .44552 .93867 .44365 .93633 .44019 Mtetra
.93633 .44019 .93867 .44365 .94492 .44178 .94258 .43831 Mtetra
.94258 .43831 .94492 .44178 .95118 .4399 .94885 .43642 Mtetra
.94885 .43642 .95118 .4399 .95745 .43802 .95514 .43453 Mtetra
.95514 .43453 .95745 .43802 .96373 .43613 .96143 .43264 Mtetra
.96143 .43264 .96373 .43613 .97003 .43424 .96774 .43074 Mtetra
.39896 .59797 .40204 .60085 .40722 .59929 .40414 .59641 Mtetra
.40414 .59641 .40722 .59929 .41241 .59773 .40933 .59485 Mtetra
.40933 .59485 .41241 .59773 .4176 .59617 .41453 .59328 Mtetra
.41453 .59328 .4176 .59617 .42281 .59461 .41974 .59171 Mtetra
.41974 .59171 .42281 .59461 .42802 .59304 .42496 .59013 Mtetra
.42496 .59013 .42802 .59304 .43325 .59147 .4302 .58856 Mtetra
.4302 .58856 .43325 .59147 .43848 .58989 .43544 .58698 Mtetra
.43544 .58698 .43848 .58989 .44373 .58831 .44069 .58539 Mtetra
.44069 .58539 .44373 .58831 .44898 .58673 .44595 .58381 Mtetra
.44595 .58381 .44898 .58673 .45425 .58515 .45122 .58222 Mtetra
.45122 .58222 .45425 .58515 .45952 .58356 .45651 .58063 Mtetra
.45651 .58063 .45952 .58356 .46481 .58197 .4618 .57903 Mtetra
.4618 .57903 .46481 .58197 .47011 .58038 .4671 .57743 Mtetra
.4671 .57743 .47011 .58038 .47541 .57879 .47242 .57583 Mtetra
.47242 .57583 .47541 .57879 .48073 .57719 .47774 .57423 Mtetra
.47774 .57423 .48073 .57719 .48606 .57558 .48308 .57262 Mtetra
.48308 .57262 .48606 .57558 .4914 .57398 .48842 .57101 Mtetra
.48842 .57101 .4914 .57398 .49675 .57237 .49378 .56939 Mtetra
.49378 .56939 .49675 .57237 .50211 .57076 .49914 .56778 Mtetra
.49914 .56778 .50211 .57076 .50748 .56915 .50452 .56616 Mtetra
.50452 .56616 .50748 .56915 .51286 .56753 .5099 .56453 Mtetra
.5099 .56453 .51286 .56753 .51825 .56591 .5153 .5629 Mtetra
.663 .741 .908 r
.5153 .5629 .51825 .56591 .52365 .56428 .52071 .56128 Mtetra
.52071 .56128 .52365 .56428 .52906 .56266 .52613 .55964 Mtetra
.664 .741 .908 r
.52613 .55964 .52906 .56266 .53448 .56103 .53156 .55801 Mtetra
.663 .741 .908 r
.53156 .55801 .53448 .56103 .53992 .55939 .537 .55637 Mtetra
.537 .55637 .53992 .55939 .54536 .55776 .54245 .55474 Mtetra
.664 .742 .908 r
.54245 .55474 .54536 .55776 .55081 .55612 .54791 .55309 Mtetra
.663 .741 .908 r
.54791 .55309 .55081 .55612 .55628 .55447 .55339 .55144 Mtetra
.659 .741 .911 r
.55339 .55144 .55628 .55447 .56176 .55284 .55887 .54986 Mtetra
.656 .744 .914 r
.55887 .54986 .56176 .55284 .56724 .55122 .56437 .5483 Mtetra
.636 .742 .925 r
.56437 .5483 .56724 .55122 .57275 .54975 .56988 .54701 Mtetra
.615 .748 .941 r
.56988 .54701 .57275 .54975 .57826 .54864 .5754 .54592 Mtetra
.671 .768 .923 r
.5754 .54592 .57826 .54864 .58379 .54744 .58093 .54413 Mtetra
.705 .739 .878 r
.58093 .54413 .58379 .54744 .58932 .54561 .58646 .54174 Mtetra
.651 .69 .874 r
.58646 .54174 .58932 .54561 .59486 .54355 .59201 .54028 Mtetra
.506 .668 .936 r
.59201 .54028 .59486 .54355 .60041 .54187 .59761 .54047 Mtetra
.5 .82 1 r
.59761 .54047 .60041 .54187 .60598 .54017 .60321 .53965 Mtetra
.553 .905 .971 r
.60321 .53965 .60598 .54017 .61155 .53821 .60879 .53782 Mtetra
.598 .027 0 r
.60879 .53782 .61155 .53821 .61719 .53868 .61453 .54153 Mtetra
.443 0 .041 r
.61453 .54153 .61719 .53868 .62282 .53799 .62021 .5417 Mtetra
.236 0 0 r
.62021 .5417 .62282 .53799 .62841 .53537 .62582 .53942 Mtetra
.709 .314 .297 r
.62582 .53942 .62841 .53537 .63415 .53731 .63169 .54467 Mtetra
.351 .022 .26 r
.63169 .54467 .63415 .53731 .63976 .53477 .6373 .54118 Mtetra
.606 .247 .334 r
.6373 .54118 .63976 .53477 .64547 .53462 .64311 .54345 Mtetra
.517 .195 .361 r
.64311 .54345 .64547 .53462 .65118 .53409 .64885 .54288 Mtetra
.498 .177 .353 r
.64885 .54288 .65118 .53409 .65685 .53217 .65458 .54179 Mtetra
.538 .223 .382 r
.65458 .54179 .65685 .53217 .66259 .53174 .66036 .54172 Mtetra
.482 .176 .371 r
.66036 .54172 .66259 .53174 .66829 .52971 .66609 .53984 Mtetra
.49 .185 .376 r
.66609 .53984 .66829 .52971 .674 .52809 .67184 .53817 Mtetra
.492 .186 .376 r
.67184 .53817 .674 .52809 .67974 .52653 .6776 .53655 Mtetra
.426 .128 .354 r
.6776 .53655 .67974 .52653 .68542 .52362 .68329 .53314 Mtetra
.467 .158 .358 r
.68329 .53314 .68542 .52362 .69118 .52212 .68905 .53098 Mtetra
.413 .103 .327 r
.68905 .53098 .69118 .52212 .69687 .51909 .69476 .52777 Mtetra
.303 .006 .284 r
.69476 .52777 .69687 .51909 .70257 .51602 .70038 .52248 Mtetra
.503 .145 .291 r
.70038 .52248 .70257 .51602 .70838 .51491 .70626 .52216 Mtetra
0 0 .11 r
.70626 .52216 .70838 .51491 .71398 .50967 .7117 .51362 Mtetra
.387 0 .104 r
.7117 .51362 .71398 .50967 .71983 .50888 .71755 .51254 Mtetra
.058 0 0 r
.71755 .51254 .71983 .50888 .72558 .50605 .72326 .50874 Mtetra
.617 .855 .489 r
.72326 .50874 .72558 .50605 .73127 .5022 .72878 .50164 Mtetra
.471 .874 .958 r
.72878 .50164 .73127 .5022 .73712 .50076 .73463 .50013 Mtetra
.66 .942 .962 r
.73463 .50013 .73712 .50076 .74296 .49903 .74043 .49743 Mtetra
.779 .892 .924 r
.74043 .49743 .74296 .49903 .74881 .49729 .74617 .49378 Mtetra
.673 .729 .892 r
.74617 .49378 .74881 .49729 .75471 .49592 .75203 .49186 Mtetra
.62 .678 .883 r
.75203 .49186 .75471 .49592 .7606 .49429 .75797 .49081 Mtetra
.657 .726 .9 r
.75797 .49081 .7606 .49429 .76645 .49206 .76387 .48915 Mtetra
.7 .778 .912 r
.76387 .48915 .76645 .49206 .77231 .48974 .76974 .48678 Mtetra
.687 .771 .915 r
.76974 .48678 .77231 .48974 .77821 .48778 .77564 .48462 Mtetra
.67 .752 .913 r
.77564 .48462 .77821 .48778 .78414 .48597 .78156 .48273 Mtetra
.667 .747 .91 r
.78156 .48273 .78414 .48597 .79007 .48417 .7875 .48088 Mtetra
.664 .743 .909 r
.7875 .48088 .79007 .48417 .79602 .48238 .79346 .47907 Mtetra
.663 .741 .908 r
.79346 .47907 .79602 .48238 .80198 .48059 .79943 .47728 Mtetra
.664 .742 .908 r
.79943 .47728 .80198 .48059 .80796 .47879 .80541 .47546 Mtetra
.664 .741 .908 r
.80541 .47546 .80796 .47879 .81394 .47699 .81141 .47366 Mtetra
.663 .741 .908 r
.81141 .47366 .81394 .47699 .81994 .47519 .81742 .47185 Mtetra
.664 .741 .908 r
.81742 .47185 .81994 .47519 .82595 .47338 .82344 .47003 Mtetra
.82344 .47003 .82595 .47338 .83198 .47157 .82947 .46821 Mtetra
.82947 .46821 .83198 .47157 .83801 .46975 .83551 .46639 Mtetra
.83551 .46639 .83801 .46975 .84406 .46793 .84157 .46456 Mtetra
.84157 .46456 .84406 .46793 .85012 .46611 .84764 .46273 Mtetra
.84764 .46273 .85012 .46611 .8562 .46428 .85372 .4609 Mtetra
.85372 .4609 .8562 .46428 .86228 .46245 .85982 .45906 Mtetra
.85982 .45906 .86228 .46245 .86838 .46062 .86593 .45722 Mtetra
.86593 .45722 .86838 .46062 .8745 .45878 .87205 .45538 Mtetra
.87205 .45538 .8745 .45878 .88062 .45694 .87819 .45353 Mtetra
.87819 .45353 .88062 .45694 .88676 .45509 .88433 .45168 Mtetra
.88433 .45168 .88676 .45509 .89291 .45324 .89049 .44982 Mtetra
.89049 .44982 .89291 .45324 .89907 .45139 .89667 .44796 Mtetra
.89667 .44796 .89907 .45139 .90525 .44953 .90285 .44609 Mtetra
.90285 .44609 .90525 .44953 .91144 .44767 .90905 .44423 Mtetra
.90905 .44423 .91144 .44767 .91764 .44581 .91526 .44235 Mtetra
.91526 .44235 .91764 .44581 .92386 .44394 .92149 .44048 Mtetra
.92149 .44048 .92386 .44394 .93009 .44206 .92773 .4386 Mtetra
.92773 .4386 .93009 .44206 .93633 .44019 .93398 .43671 Mtetra
.93398 .43671 .93633 .44019 .94258 .43831 .94024 .43482 Mtetra
.94024 .43482 .94258 .43831 .94885 .43642 .94652 .43293 Mtetra
.94652 .43293 .94885 .43642 .95514 .43453 .95281 .43103 Mtetra
.95281 .43103 .95514 .43453 .96143 .43264 .95912 .42913 Mtetra
.95912 .42913 .96143 .43264 .96774 .43074 .96544 .42723 Mtetra
.39586 .59509 .39896 .59797 .40414 .59641 .40105 .59352 Mtetra
.40105 .59352 .40414 .59641 .40933 .59485 .40624 .59195 Mtetra
.40624 .59195 .40933 .59485 .41453 .59328 .41145 .59038 Mtetra
.41145 .59038 .41453 .59328 .41974 .59171 .41667 .5888 Mtetra
.41667 .5888 .41974 .59171 .42496 .59013 .4219 .58722 Mtetra
.4219 .58722 .42496 .59013 .4302 .58856 .42713 .58564 Mtetra
.42713 .58564 .4302 .58856 .43544 .58698 .43238 .58405 Mtetra
.43238 .58405 .43544 .58698 .44069 .58539 .43764 .58246 Mtetra
.43764 .58246 .44069 .58539 .44595 .58381 .44291 .58087 Mtetra
.44291 .58087 .44595 .58381 .45122 .58222 .44819 .57928 Mtetra
.44819 .57928 .45122 .58222 .45651 .58063 .45348 .57768 Mtetra
.45348 .57768 .45651 .58063 .4618 .57903 .45878 .57608 Mtetra
.45878 .57608 .4618 .57903 .4671 .57743 .46409 .57447 Mtetra
.46409 .57447 .4671 .57743 .47242 .57583 .46941 .57287 Mtetra
.46941 .57287 .47242 .57583 .47774 .57423 .47474 .57126 Mtetra
.47474 .57126 .47774 .57423 .48308 .57262 .48008 .56964 Mtetra
.48008 .56964 .48308 .57262 .48842 .57101 .48543 .56803 Mtetra
.48543 .56803 .48842 .57101 .49378 .56939 .49079 .56641 Mtetra
.49079 .56641 .49378 .56939 .49914 .56778 .49617 .56478 Mtetra
.49617 .56478 .49914 .56778 .50452 .56616 .50155 .56316 Mtetra
.50155 .56316 .50452 .56616 .5099 .56453 .50694 .56153 Mtetra
.50694 .56153 .5099 .56453 .5153 .5629 .51235 .55989 Mtetra
.663 .741 .908 r
.51235 .55989 .5153 .5629 .52071 .56128 .51776 .55826 Mtetra
.51776 .55826 .52071 .56128 .52613 .55964 .52319 .55662 Mtetra
.664 .742 .908 r
.52319 .55662 .52613 .55964 .53156 .55801 .52863 .55498 Mtetra
.662 .741 .908 r
.52863 .55498 .53156 .55801 .537 .55637 .53407 .55335 Mtetra
.662 .742 .909 r
.53407 .55335 .537 .55637 .54245 .55474 .53953 .55172 Mtetra
.663 .743 .909 r
.53953 .55172 .54245 .55474 .54791 .55309 .545 .55007 Mtetra
.657 .742 .912 r
.545 .55007 .54791 .55309 .55339 .55144 .55048 .54851 Mtetra
.649 .745 .919 r
.55048 .54851 .55339 .55144 .55887 .54986 .55597 .54704 Mtetra
.642 .752 .929 r
.55597 .54704 .55887 .54986 .56437 .5483 .56148 .54566 Mtetra
.609 .754 .947 r
.56148 .54566 .56437 .5483 .56988 .54701 .567 .54461 Mtetra
.637 .782 .951 r
.567 .54461 .56988 .54701 .5754 .54592 .57253 .5432 Mtetra
.725 .78 .897 r
.57253 .5432 .5754 .54592 .58093 .54413 .57805 .54054 Mtetra
.673 .713 .879 r
.57805 .54054 .58093 .54413 .58646 .54174 .58359 .5387 Mtetra
.285 .573 .937 r
.58359 .5387 .58646 .54174 .59201 .54028 .58922 .54034 Mtetra
.665 .123 0 r
.58922 .54034 .59201 .54028 .59761 .54047 .59491 .54444 Mtetra
.478 .054 .157 r
.59491 .54444 .59761 .54047 .60321 .53965 .60054 .54452 Mtetra
.493 .098 .219 r
.60054 .54452 .60321 .53965 .60879 .53782 .60619 .5445 Mtetra
.756 .413 .404 r
.60619 .5445 .60879 .53782 .61453 .54153 .61211 .55397 Mtetra
.54 .249 .421 r
.61211 .55397 .61453 .54153 .62021 .5417 .6178 .55363 Mtetra
.549 .252 .417 r
.6178 .55363 .62021 .5417 .62582 .53942 .62351 .55368 Mtetra
.688 .393 .47 r
.62351 .55368 .62582 .53942 .63169 .54467 .62952 .56256 Mtetra
.455 .203 .441 r
.62952 .56256 .63169 .54467 .6373 .54118 .63512 .55728 Mtetra
.65 .365 .473 r
.63512 .55728 .6373 .54118 .64311 .54345 .64111 .56362 Mtetra
.527 .27 .469 r
.64111 .56362 .64311 .54345 .64885 .54288 .64684 .56153 Mtetra
.572 .304 .471 r
.64684 .56153 .64885 .54288 .65458 .54179 .65269 .56248 Mtetra
.552 .292 .476 r
.65269 .56248 .65458 .54179 .66036 .54172 .65851 .56192 Mtetra
.54 .282 .472 r
.65851 .56192 .66036 .54172 .66609 .53984 .66431 .56066 Mtetra
.533 .277 .473 r
.66431 .56066 .66609 .53984 .67184 .53817 .6701 .55881 Mtetra
.532 .276 .472 r
.6701 .55881 .67184 .53817 .6776 .53655 .6759 .55695 Mtetra
.509 .255 .466 r
.6759 .55695 .6776 .53655 .68329 .53314 .68165 .55365 Mtetra
.501 .249 .465 r
.68165 .55365 .68329 .53314 .68905 .53098 .68737 .54984 Mtetra
.525 .264 .463 r
.68737 .54984 .68905 .53098 .69476 .52777 .6932 .54778 Mtetra
.394 .162 .439 r
.6932 .54778 .69476 .52777 .70038 .52248 .69866 .53868 Mtetra
.578 .3 .458 r
.69866 .53868 .70038 .52248 .70626 .52216 .70468 .54004 Mtetra
.281 .064 .396 r
.70468 .54004 .70626 .52216 .7117 .51362 .70996 .52776 Mtetra
.479 .206 .421 r
.70996 .52776 .7117 .51362 .71755 .51254 .71573 .52452 Mtetra
.453 .17 .391 r
.71573 .52452 .71755 .51254 .72326 .50874 .7215 .52108 Mtetra
.067 0 .271 r
.7215 .52108 .72326 .50874 .72878 .50164 .7267 .50812 Mtetra
.346 .001 .23 r
.7267 .50812 .72878 .50164 .73463 .50013 .73247 .50492 Mtetra
.208 0 .082 r
.73247 .50492 .73463 .50013 .74043 .49743 .73823 .50126 Mtetra
0 0 0 r
.73823 .50126 .74043 .49743 .74617 .49378 .74373 .49354 Mtetra
.828 .984 .877 r
.74373 .49354 .74617 .49378 .75203 .49186 .7494 .48857 Mtetra
.647 .734 .913 r
.7494 .48857 .75203 .49186 .75797 .49081 .75531 .48704 Mtetra
.601 .686 .902 r
.75531 .48704 .75797 .49081 .76387 .48915 .76128 .48623 Mtetra
.681 .773 .921 r
.76128 .48623 .76387 .48915 .76974 .48678 .76718 .48417 Mtetra
.704 .802 .926 r
.76718 .48417 .76974 .48678 .77564 .48462 .77307 .48174 Mtetra
.68 .776 .923 r
.77307 .48174 .77564 .48462 .78156 .48273 .77899 .47967 Mtetra
.675 .762 .916 r
.77899 .47967 .78156 .48273 .7875 .48088 .78493 .47768 Mtetra
.669 .751 .912 r
.78493 .47768 .7875 .48088 .79346 .47907 .79089 .47578 Mtetra
.664 .743 .91 r
.79089 .47578 .79346 .47907 .79943 .47728 .79687 .47398 Mtetra
.665 .744 .909 r
.79687 .47398 .79943 .47728 .80541 .47546 .80286 .47214 Mtetra
.665 .743 .908 r
.80286 .47214 .80541 .47546 .81141 .47366 .80886 .47031 Mtetra
.663 .741 .908 r
.80886 .47031 .81141 .47366 .81742 .47185 .81488 .4685 Mtetra
.664 .741 .908 r
.81488 .4685 .81742 .47185 .82344 .47003 .82091 .46667 Mtetra
.664 .742 .908 r
.82091 .46667 .82344 .47003 .82947 .46821 .82695 .46485 Mtetra
.664 .741 .908 r
.82695 .46485 .82947 .46821 .83551 .46639 .833 .46302 Mtetra
.833 .46302 .83551 .46639 .84157 .46456 .83907 .46118 Mtetra
.83907 .46118 .84157 .46456 .84764 .46273 .84515 .45935 Mtetra
.84515 .45935 .84764 .46273 .85372 .4609 .85124 .45751 Mtetra
.85124 .45751 .85372 .4609 .85982 .45906 .85735 .45566 Mtetra
.85735 .45566 .85982 .45906 .86593 .45722 .86346 .45381 Mtetra
.86346 .45381 .86593 .45722 .87205 .45538 .8696 .45196 Mtetra
.8696 .45196 .87205 .45538 .87819 .45353 .87574 .4501 Mtetra
.87574 .4501 .87819 .45353 .88433 .45168 .8819 .44824 Mtetra
.8819 .44824 .88433 .45168 .89049 .44982 .88807 .44638 Mtetra
.88807 .44638 .89049 .44982 .89667 .44796 .89425 .44451 Mtetra
.89425 .44451 .89667 .44796 .90285 .44609 .90044 .44264 Mtetra
.90044 .44264 .90285 .44609 .90905 .44423 .90665 .44077 Mtetra
.90665 .44077 .90905 .44423 .91526 .44235 .91287 .43889 Mtetra
.91287 .43889 .91526 .44235 .92149 .44048 .91911 .437 Mtetra
.91911 .437 .92149 .44048 .92773 .4386 .92536 .43511 Mtetra
.92536 .43511 .92773 .4386 .93398 .43671 .93162 .43322 Mtetra
.93162 .43322 .93398 .43671 .94024 .43482 .93789 .43133 Mtetra
.93789 .43133 .94024 .43482 .94652 .43293 .94418 .42943 Mtetra
.94418 .42943 .94652 .43293 .95281 .43103 .95048 .42752 Mtetra
.95048 .42752 .95281 .43103 .95912 .42913 .9568 .42561 Mtetra
.9568 .42561 .95912 .42913 .96544 .42723 .96313 .4237 Mtetra
.39275 .59219 .39586 .59509 .40105 .59352 .39794 .59062 Mtetra
.39794 .59062 .40105 .59352 .40624 .59195 .40315 .58904 Mtetra
.40315 .58904 .40624 .59195 .41145 .59038 .40836 .58746 Mtetra
.40836 .58746 .41145 .59038 .41667 .5888 .41358 .58588 Mtetra
.41358 .58588 .41667 .5888 .4219 .58722 .41882 .5843 Mtetra
.41882 .5843 .4219 .58722 .42713 .58564 .42406 .58271 Mtetra
.42406 .58271 .42713 .58564 .43238 .58405 .42932 .58112 Mtetra
.42932 .58112 .43238 .58405 .43764 .58246 .43458 .57952 Mtetra
.43458 .57952 .43764 .58246 .44291 .58087 .43986 .57793 Mtetra
.43986 .57793 .44291 .58087 .44819 .57928 .44514 .57632 Mtetra
.44514 .57632 .44819 .57928 .45348 .57768 .45044 .57472 Mtetra
.45044 .57472 .45348 .57768 .45878 .57608 .45574 .57311 Mtetra
.45574 .57311 .45878 .57608 .46409 .57447 .46106 .5715 Mtetra
.46106 .5715 .46409 .57447 .46941 .57287 .46639 .56989 Mtetra
.46639 .56989 .46941 .57287 .47474 .57126 .47173 .56827 Mtetra
.47173 .56827 .47474 .57126 .48008 .56964 .47707 .56665 Mtetra
.47707 .56665 .48008 .56964 .48543 .56803 .48243 .56503 Mtetra
.48243 .56503 .48543 .56803 .49079 .56641 .4878 .56341 Mtetra
.663 .741 .908 r
.4878 .56341 .49079 .56641 .49617 .56478 .49318 .56178 Mtetra
.664 .741 .908 r
.49318 .56178 .49617 .56478 .50155 .56316 .49857 .56015 Mtetra
.49857 .56015 .50155 .56316 .50694 .56153 .50397 .55851 Mtetra
.663 .741 .908 r
.50397 .55851 .50694 .56153 .51235 .55989 .50938 .55687 Mtetra
.50938 .55687 .51235 .55989 .51776 .55826 .5148 .55524 Mtetra
.664 .742 .908 r
.5148 .55524 .51776 .55826 .52319 .55662 .52024 .5536 Mtetra
.663 .742 .909 r
.52024 .5536 .52319 .55662 .52863 .55498 .52568 .55196 Mtetra
.659 .741 .911 r
.52568 .55196 .52863 .55498 .53407 .55335 .53114 .55037 Mtetra
.66 .745 .913 r
.53114 .55037 .53407 .55335 .53953 .55172 .5366 .54877 Mtetra
.657 .746 .916 r
.5366 .54877 .53953 .55172 .545 .55007 .54208 .5472 Mtetra
.636 .746 .928 r
.54208 .5472 .545 .55007 .55048 .54851 .54757 .54589 Mtetra
.62 .76 .946 r
.54757 .54589 .55048 .54851 .55597 .54704 .55307 .54471 Mtetra
.593 .774 .966 r
.55307 .54471 .55597 .54704 .56148 .54566 .55859 .54372 Mtetra
.538 .788 .99 r
.55859 .54372 .56148 .54566 .567 .54461 .56412 .543 Mtetra
.667 .855 .972 r
.56412 .543 .567 .54461 .57253 .5432 .56965 .54103 Mtetra
.701 .817 .937 r
.56965 .54103 .57253 .5432 .57805 .54054 .57519 .53876 Mtetra
0 .371 .766 r
.57519 .53876 .57805 .54054 .58359 .5387 .58082 .54126 Mtetra
.805 .409 .304 r
.58082 .54126 .58359 .5387 .58922 .54034 .58658 .55019 Mtetra
.723 .406 .442 r
.58658 .55019 .58922 .54034 .59491 .54444 .59241 .55948 Mtetra
.557 .278 .447 r
.59241 .55948 .59491 .54444 .60054 .54452 .59808 .5597 Mtetra
.637 .35 .466 r
.59808 .5597 .60054 .54452 .60619 .5445 .60389 .56475 Mtetra
.717 .437 .501 r
.60389 .56475 .60619 .5445 .61211 .55397 .60999 .58052 Mtetra
.516 .274 .487 r
.60999 .58052 .61211 .55397 .6178 .55363 .61565 .57669 Mtetra
.623 .358 .497 r
.61565 .57669 .6178 .55363 .62351 .55368 .62157 .58216 Mtetra
.646 .387 .512 r
.62157 .58216 .62351 .55368 .62952 .56256 .62765 .59169 Mtetra
.481 .25 .486 r
.62765 .59169 .62952 .56256 .63512 .55728 .63325 .58461 Mtetra
.655 .392 .51 r
.63325 .58461 .63512 .55728 .64111 .56362 .63944 .59504 Mtetra
.506 .273 .496 r
.63944 .59504 .64111 .56362 .64684 .56153 .64511 .58942 Mtetra
.602 .347 .504 r
.64511 .58942 .64684 .56153 .65269 .56248 .65113 .59339 Mtetra
.538 .299 .5 r
.65113 .59339 .65269 .56248 .65851 .56192 .65694 .59081 Mtetra
.562 .316 .5 r
.65694 .59081 .65851 .56192 .66431 .56066 .66285 .59069 Mtetra
.542 .301 .499 r
.66285 .59069 .66431 .56066 .6701 .55881 .66869 .58852 Mtetra
.54 .299 .498 r
.66869 .58852 .6701 .55881 .6759 .55695 .67454 .58619 Mtetra
.544 .301 .498 r
.67454 .58619 .6759 .55695 .68165 .55365 .68042 .58431 Mtetra
.498 .266 .493 r
.68042 .58431 .68165 .55365 .68737 .54984 .6861 .57804 Mtetra
.574 .324 .5 r
.6861 .57804 .68737 .54984 .6932 .54778 .69214 .57915 Mtetra
.415 .202 .478 r
.69214 .57915 .6932 .54778 .69866 .53868 .69748 .56611 Mtetra
.595 .341 .501 r
.69748 .56611 .69866 .53868 .70468 .54004 .70366 .5694 Mtetra
.4 .187 .471 r
.70366 .5694 .70468 .54004 .70996 .52776 .70896 .55616 Mtetra
.465 .237 .483 r
.70896 .55616 .70996 .52776 .71573 .52452 .71451 .54776 Mtetra
.56 .304 .485 r
.71451 .54776 .71573 .52452 .7215 .52108 .72053 .54774 Mtetra
.262 .077 .431 r
.72053 .54774 .7215 .52108 .7267 .50812 .72541 .52823 Mtetra
.418 .181 .446 r
.72541 .52823 .7267 .50812 .73247 .50492 .73093 .52008 Mtetra
.474 .206 .428 r
.73093 .52008 .73247 .50492 .73823 .50126 .73673 .51632 Mtetra
.18 0 .345 r
.73673 .51632 .73823 .50126 .74373 .49354 .74191 .50312 Mtetra
0 0 .167 r
.74191 .50312 .74373 .49354 .7494 .48857 .74712 .49078 Mtetra
.529 .836 .519 r
.74712 .49078 .7494 .48857 .75531 .48704 .75276 .48503 Mtetra
.578 .809 .987 r
.75276 .48503 .75531 .48704 .76128 .48623 .75872 .48388 Mtetra
.63 .799 .964 r
.75872 .48388 .76128 .48623 .76718 .48417 .76467 .48236 Mtetra
.721 .871 .952 r
.76467 .48236 .76718 .48417 .77307 .48174 .77054 .47957 Mtetra
.704 .839 .947 r
.77054 .47957 .77307 .48174 .77899 .47967 .77645 .47708 Mtetra
.693 .803 .933 r
.77645 .47708 .77899 .47967 .78493 .47768 .78237 .4748 Mtetra
.685 .779 .922 r
.78237 .4748 .78493 .47768 .79089 .47578 .78832 .47263 Mtetra
.669 .756 .915 r
.78832 .47263 .79089 .47578 .79687 .47398 .7943 .47073 Mtetra
.667 .749 .912 r
.7943 .47073 .79687 .47398 .80286 .47214 .8003 .46886 Mtetra
.667 .747 .91 r
.8003 .46886 .80286 .47214 .80886 .47031 .80631 .46698 Mtetra
.664 .743 .909 r
.80631 .46698 .80886 .47031 .81488 .4685 .81233 .46514 Mtetra
.664 .742 .908 r
.81233 .46514 .81488 .4685 .82091 .46667 .81837 .46331 Mtetra
.81837 .46331 .82091 .46667 .82695 .46485 .82442 .46147 Mtetra
.82442 .46147 .82695 .46485 .833 .46302 .83048 .45963 Mtetra
.663 .741 .908 r
.83048 .45963 .833 .46302 .83907 .46118 .83656 .45779 Mtetra
.664 .741 .908 r
.83656 .45779 .83907 .46118 .84515 .45935 .84265 .45595 Mtetra
.84265 .45595 .84515 .45935 .85124 .45751 .84875 .4541 Mtetra
.84875 .4541 .85124 .45751 .85735 .45566 .85486 .45225 Mtetra
.85486 .45225 .85735 .45566 .86346 .45381 .86099 .45039 Mtetra
.86099 .45039 .86346 .45381 .8696 .45196 .86713 .44853 Mtetra
.86713 .44853 .8696 .45196 .87574 .4501 .87328 .44667 Mtetra
.87328 .44667 .87574 .4501 .8819 .44824 .87945 .4448 Mtetra
.87945 .4448 .8819 .44824 .88807 .44638 .88563 .44293 Mtetra
.88563 .44293 .88807 .44638 .89425 .44451 .89182 .44105 Mtetra
.89182 .44105 .89425 .44451 .90044 .44264 .89803 .43917 Mtetra
.89803 .43917 .90044 .44264 .90665 .44077 .90424 .43729 Mtetra
.90424 .43729 .90665 .44077 .91287 .43889 .91048 .4354 Mtetra
.91048 .4354 .91287 .43889 .91911 .437 .91672 .43351 Mtetra
.91672 .43351 .91911 .437 .92536 .43511 .92298 .43162 Mtetra
.92298 .43162 .92536 .43511 .93162 .43322 .92925 .42972 Mtetra
.92925 .42972 .93162 .43322 .93789 .43133 .93553 .42782 Mtetra
.93553 .42782 .93789 .43133 .94418 .42943 .94183 .42591 Mtetra
.94183 .42591 .94418 .42943 .95048 .42752 .94814 .424 Mtetra
.94814 .424 .95048 .42752 .9568 .42561 .95447 .42208 Mtetra
.95447 .42208 .9568 .42561 .96313 .4237 .96081 .42016 Mtetra
.38963 .58929 .39275 .59219 .39794 .59062 .39483 .58771 Mtetra
.39483 .58771 .39794 .59062 .40315 .58904 .40004 .58613 Mtetra
.40004 .58613 .40315 .58904 .40836 .58746 .40526 .58454 Mtetra
.40526 .58454 .40836 .58746 .41358 .58588 .41049 .58295 Mtetra
.41049 .58295 .41358 .58588 .41882 .5843 .41573 .58136 Mtetra
.41573 .58136 .41882 .5843 .42406 .58271 .42098 .57977 Mtetra
.42098 .57977 .42406 .58271 .42932 .58112 .42624 .57817 Mtetra
.42624 .57817 .42932 .58112 .43458 .57952 .43151 .57657 Mtetra
.43151 .57657 .43458 .57952 .43986 .57793 .43679 .57497 Mtetra
.43679 .57497 .43986 .57793 .44514 .57632 .44209 .57336 Mtetra
.44209 .57336 .44514 .57632 .45044 .57472 .44739 .57175 Mtetra
.44739 .57175 .45044 .57472 .45574 .57311 .4527 .57014 Mtetra
.4527 .57014 .45574 .57311 .46106 .5715 .45802 .56852 Mtetra
.45802 .56852 .46106 .5715 .46639 .56989 .46336 .5669 Mtetra
.46336 .5669 .46639 .56989 .47173 .56827 .4687 .56528 Mtetra
.4687 .56528 .47173 .56827 .47707 .56665 .47406 .56366 Mtetra
.47406 .56366 .47707 .56665 .48243 .56503 .47942 .56203 Mtetra
.663 .741 .908 r
.47942 .56203 .48243 .56503 .4878 .56341 .4848 .5604 Mtetra
.4848 .5604 .4878 .56341 .49318 .56178 .49018 .55876 Mtetra
.664 .741 .908 r
.49018 .55876 .49318 .56178 .49857 .56015 .49558 .55712 Mtetra
.49558 .55712 .49857 .56015 .50397 .55851 .50099 .55548 Mtetra
.662 .741 .908 r
.50099 .55548 .50397 .55851 .50938 .55687 .50641 .55385 Mtetra
.662 .742 .909 r
.50641 .55385 .50938 .55687 .5148 .55524 .51184 .55222 Mtetra
.663 .742 .909 r
.51184 .55222 .5148 .55524 .52024 .5536 .51728 .55058 Mtetra
.657 .742 .912 r
.51728 .55058 .52024 .5536 .52568 .55196 .52273 .54901 Mtetra
.651 .745 .918 r
.52273 .54901 .52568 .55196 .53114 .55037 .52819 .54753 Mtetra
.649 .752 .925 r
.52819 .54753 .53114 .55037 .5366 .54877 .53366 .54605 Mtetra
.623 .754 .94 r
.53366 .54605 .5366 .54877 .54208 .5472 .53915 .54487 Mtetra
.557 .762 .973 r
.53915 .54487 .54208 .5472 .54757 .54589 .54465 .5442 Mtetra
.484 .788 .998 r
.54465 .5442 .54757 .54589 .55307 .54471 .55017 .54368 Mtetra
.265 .729 .948 r
.55017 .54368 .55307 .54471 .55859 .54372 .5557 .5437 Mtetra
.01 0 0 r
.5557 .5437 .55859 .54372 .56412 .543 .56126 .54376 Mtetra
0 0 0 r
.56126 .54376 .56412 .543 .56965 .54103 .56681 .54257 Mtetra
.624 .125 .045 r
.56681 .54257 .56965 .54103 .57519 .53876 .57244 .54547 Mtetra
.796 .462 .424 r
.57244 .54547 .57519 .53876 .58082 .54126 .57825 .55871 Mtetra
.753 .466 .497 r
.57825 .55871 .58082 .54126 .58658 .55019 .58424 .57803 Mtetra
.665 .403 .514 r
.58424 .57803 .58658 .55019 .59241 .55948 .59016 .58995 Mtetra
.552 .31 .502 r
.59016 .58995 .59241 .55948 .59808 .5597 .59587 .58882 Mtetra
.67 .408 .516 r
.59587 .58882 .59808 .5597 .60389 .56475 .60191 .60213 Mtetra
.67 .415 .527 r
.60191 .60213 .60389 .56475 .60999 .58052 .6081 .61879 Mtetra
.471 .251 .498 r
.6081 .61879 .60999 .58052 .61565 .57669 .61367 .60841 Mtetra
.66 .401 .518 r
.61367 .60841 .61565 .57669 .62157 .58216 .61985 .62106 Mtetra
.586 .346 .519 r
.61985 .62106 .62157 .58216 .62765 .59169 .62581 .62392 Mtetra
.491 .261 .493 r
.62581 .62392 .62765 .59169 .63325 .58461 .63149 .61692 Mtetra
.645 .389 .517 r
.63149 .61692 .63325 .58461 .63944 .59504 .63773 .62747 Mtetra
.457 .234 .486 r
.63773 .62747 .63944 .59504 .64511 .58942 .64333 .61755 Mtetra
.619 .362 .506 r
.64333 .61755 .64511 .58942 .65113 .59339 .64949 .62364 Mtetra
.5 .266 .491 r
.64949 .62364 .65113 .59339 .65694 .59081 .65524 .61782 Mtetra
.572 .321 .496 r
.65524 .61782 .65694 .59081 .66285 .59069 .66125 .61883 Mtetra
.535 .292 .493 r
.66125 .61883 .66285 .59069 .66869 .58852 .66715 .61635 Mtetra
.531 .288 .491 r
.66715 .61635 .66869 .58852 .67454 .58619 .67304 .61354 Mtetra
.571 .32 .497 r
.67304 .61354 .67454 .58619 .68042 .58431 .6791 .61444 Mtetra
.474 .245 .486 r
.6791 .61444 .68042 .58431 .6861 .57804 .68477 .60638 Mtetra
.613 .356 .504 r
.68477 .60638 .6861 .57804 .69214 .57915 .69108 .61181 Mtetra
.417 .204 .48 r
.69108 .61181 .69214 .57915 .69748 .56611 .69648 .59841 Mtetra
.595 .346 .509 r
.69648 .59841 .69748 .56611 .70366 .5694 .70275 .60214 Mtetra
.495 .266 .496 r
.70275 .60214 .70366 .5694 .70896 .55616 .70847 .59511 Mtetra
.426 .219 .493 r
.70847 .59511 .70896 .55616 .71451 .54776 .71372 .57974 Mtetra
.618 .364 .511 r
.71372 .57974 .71451 .54776 .72053 .54774 .7202 .58649 Mtetra
.363 .171 .48 r
.7202 .58649 .72053 .54774 .72541 .52823 .7251 .56569 Mtetra
.409 .205 .488 r
.7251 .56569 .72541 .52823 .73093 .52008 .73021 .54929 Mtetra
.541 .298 .497 r
.73021 .54929 .73093 .52008 .73673 .51632 .73618 .54715 Mtetra
.37 .167 .469 r
.73618 .54715 .73673 .51632 .74191 .50312 .74125 .53096 Mtetra
.212 .042 .421 r
.74125 .53096 .74191 .50312 .74712 .49078 .74582 .50786 Mtetra
.132 0 .347 r
.74582 .50786 .74712 .49078 .75276 .48503 .75078 .49141 Mtetra
.116 0 .135 r
.75078 .49141 .75276 .48503 .75872 .48388 .75641 .48519 Mtetra
0 0 0 r
.75641 .48519 .75872 .48388 .76467 .48236 .76233 .48293 Mtetra
.577 .939 .81 r
.76233 .48293 .76467 .48236 .77054 .47957 .76815 .47934 Mtetra
.699 .975 .918 r
.76815 .47934 .77054 .47957 .77645 .47708 .77399 .4758 Mtetra
.72 .916 .961 r
.77399 .4758 .77645 .47708 .78237 .4748 .77988 .47283 Mtetra
.723 .862 .947 r
.77988 .47283 .78237 .4748 .78832 .47263 .78579 .47003 Mtetra
.693 .803 .933 r
.78579 .47003 .78832 .47263 .7943 .47073 .79175 .46772 Mtetra
.674 .769 .921 r
.79175 .46772 .7943 .47073 .8003 .46886 .79774 .46571 Mtetra
.674 .76 .915 r
.79774 .46571 .8003 .46886 .80631 .46698 .80375 .46371 Mtetra
.669 .75 .911 r
.80375 .46371 .80631 .46698 .81233 .46514 .80978 .46179 Mtetra
.664 .744 .909 r
.80978 .46179 .81233 .46514 .81837 .46331 .81582 .45995 Mtetra
.665 .743 .909 r
.81582 .45995 .81837 .46331 .82442 .46147 .82188 .45809 Mtetra
.664 .743 .908 r
.82188 .45809 .82442 .46147 .83048 .45963 .82795 .45623 Mtetra
.664 .741 .908 r
.82795 .45623 .83048 .45963 .83656 .45779 .83404 .45438 Mtetra
.663 .741 .908 r
.83404 .45438 .83656 .45779 .84265 .45595 .84014 .45253 Mtetra
.664 .741 .908 r
.84014 .45253 .84265 .45595 .84875 .4541 .84625 .45068 Mtetra
.84625 .45068 .84875 .4541 .85486 .45225 .85237 .44882 Mtetra
.85237 .44882 .85486 .45225 .86099 .45039 .85851 .44695 Mtetra
.85851 .44695 .86099 .45039 .86713 .44853 .86466 .44509 Mtetra
.86466 .44509 .86713 .44853 .87328 .44667 .87082 .44322 Mtetra
.87082 .44322 .87328 .44667 .87945 .4448 .87699 .44134 Mtetra
.87699 .44134 .87945 .4448 .88563 .44293 .88318 .43946 Mtetra
.88318 .43946 .88563 .44293 .89182 .44105 .88938 .43758 Mtetra
.88938 .43758 .89182 .44105 .89803 .43917 .8956 .4357 Mtetra
.8956 .4357 .89803 .43917 .90424 .43729 .90183 .4338 Mtetra
.90183 .4338 .90424 .43729 .91048 .4354 .90807 .43191 Mtetra
.90807 .43191 .91048 .4354 .91672 .43351 .91432 .43001 Mtetra
.91432 .43001 .91672 .43351 .92298 .43162 .92059 .42811 Mtetra
.92059 .42811 .92298 .43162 .92925 .42972 .92687 .4262 Mtetra
.92687 .4262 .92925 .42972 .93553 .42782 .93317 .42429 Mtetra
.93317 .42429 .93553 .42782 .94183 .42591 .93947 .42238 Mtetra
.93947 .42238 .94183 .42591 .94814 .424 .94579 .42046 Mtetra
.94579 .42046 .94814 .424 .95447 .42208 .95213 .41853 Mtetra
.95213 .41853 .95447 .42208 .96081 .42016 .95848 .41661 Mtetra
.38649 .58637 .38963 .58929 .39483 .58771 .3917 .58478 Mtetra
.3917 .58478 .39483 .58771 .40004 .58613 .39692 .5832 Mtetra
.39692 .5832 .40004 .58613 .40526 .58454 .40214 .58161 Mtetra
.40214 .58161 .40526 .58454 .41049 .58295 .40738 .58001 Mtetra
.40738 .58001 .41049 .58295 .41573 .58136 .41263 .57842 Mtetra
.41263 .57842 .41573 .58136 .42098 .57977 .41789 .57682 Mtetra
.41789 .57682 .42098 .57977 .42624 .57817 .42315 .57521 Mtetra
.42315 .57521 .42624 .57817 .43151 .57657 .42843 .57361 Mtetra
.42843 .57361 .43151 .57657 .43679 .57497 .43372 .572 Mtetra
.43372 .572 .43679 .57497 .44209 .57336 .43902 .57039 Mtetra
.43902 .57039 .44209 .57336 .44739 .57175 .44433 .56877 Mtetra
.44433 .56877 .44739 .57175 .4527 .57014 .44965 .56715 Mtetra
.44965 .56715 .4527 .57014 .45802 .56852 .45498 .56553 Mtetra
.45498 .56553 .45802 .56852 .46336 .5669 .46032 .56391 Mtetra
.46032 .56391 .46336 .5669 .4687 .56528 .46567 .56228 Mtetra
.46567 .56228 .4687 .56528 .47406 .56366 .47103 .56065 Mtetra
.47103 .56065 .47406 .56366 .47942 .56203 .4764 .55901 Mtetra
.663 .741 .908 r
.4764 .55901 .47942 .56203 .4848 .5604 .48178 .55738 Mtetra
.48178 .55738 .4848 .5604 .49018 .55876 .48718 .55574 Mtetra
.664 .741 .908 r
.48718 .55574 .49018 .55876 .49558 .55712 .49258 .55409 Mtetra
.662 .741 .908 r
.49258 .55409 .49558 .55712 .50099 .55548 .49799 .55246 Mtetra
.661 .742 .91 r
.49799 .55246 .50099 .55548 .50641 .55385 .50342 .55085 Mtetra
.661 .743 .911 r
.50342 .55085 .50641 .55385 .51184 .55222 .50886 .54924 Mtetra
.656 .744 .914 r
.50886 .54924 .51184 .55222 .51728 .55058 .5143 .54769 Mtetra
.639 .745 .925 r
.5143 .54769 .51728 .55058 .52273 .54901 .51976 .54634 Mtetra
.624 .757 .942 r
.51976 .54634 .52273 .54901 .52819 .54753 .52523 .54514 Mtetra
.592 .769 .964 r
.52523 .54514 .52819 .54753 .53366 .54605 .53071 .54418 Mtetra
.428 .748 .994 r
.53071 .54418 .53366 .54605 .53915 .54487 .53621 .54411 Mtetra
.01 .569 .809 r
.53621 .54411 .53915 .54487 .54465 .5442 .54173 .54483 Mtetra
.394 0 0 r
.54173 .54483 .54465 .5442 .55017 .54368 .54727 .54603 Mtetra
.617 .15 .123 r
.54727 .54603 .55017 .54368 .5557 .5437 .55284 .54863 Mtetra
.626 .24 .293 r
.55284 .54863 .5557 .5437 .56126 .54376 .55844 .55137 Mtetra
.66 .32 .387 r
.55844 .55137 .56126 .54376 .56681 .54257 .56409 .55576 Mtetra
.76 .461 .479 r
.56409 .55576 .56681 .54257 .57244 .54547 .56992 .57189 Mtetra
.754 .481 .519 r
.56992 .57189 .57244 .54547 .57825 .55871 .57601 .60032 Mtetra
.699 .443 .533 r
.57601 .60032 .57825 .55871 .58424 .57803 .58216 .62588 Mtetra
.6 .362 .528 r
.58216 .62588 .58424 .57803 .59016 .58995 .58805 .6317 Mtetra
.536 .306 .513 r
.58805 .6317 .59016 .58995 .59587 .58882 .59379 .62782 Mtetra
.682 .426 .529 r
.59379 .62782 .59587 .58882 .60191 .60213 .60004 .64778 Mtetra
.596 .358 .526 r
.60004 .64778 .60191 .60213 .6081 .61879 .60604 .65277 Mtetra
.371 .165 .466 r
.60604 .65277 .6081 .61879 .61367 .60841 .61153 .63625 Mtetra
.689 .422 .513 r
.61153 .63625 .61367 .60841 .61985 .62106 .61785 .65218 Mtetra
.427 .207 .475 r
.61785 .65218 .61985 .62106 .62581 .62392 .62346 .64067 Mtetra
.48 .215 .434 r
.62346 .64067 .62581 .62392 .63149 .61692 .62928 .63701 Mtetra
.598 .328 .478 r
.62928 .63701 .63149 .61692 .63773 .62747 .63533 .64004 Mtetra
.101 0 .264 r
.63533 .64004 .63773 .62747 .64333 .61755 .64091 .62841 Mtetra
.64 .325 .421 r
.64091 .62841 .64333 .61755 .64949 .62364 .64704 .63286 Mtetra
.125 0 .209 r
.64704 .63286 .64949 .62364 .65524 .61782 .65273 .62464 Mtetra
.556 .196 .313 r
.65273 .62464 .65524 .61782 .66125 .61883 .65877 .62563 Mtetra
.39 .039 .244 r
.65877 .62563 .66125 .61883 .66715 .61635 .66469 .62317 Mtetra
.37 .021 .236 r
.66469 .62317 .66715 .61635 .67304 .61354 .6706 .62035 Mtetra
.636 .276 .342 r
.6706 .62035 .67304 .61354 .6791 .61444 .67681 .62387 Mtetra
.237 0 .263 r
.67681 .62387 .6791 .61444 .68477 .60638 .68257 .61708 Mtetra
.694 .373 .428 r
.68257 .61708 .68477 .60638 .69108 .61181 .68902 .6249 Mtetra
.358 .093 .368 r
.68902 .6249 .69108 .61181 .69648 .59841 .69481 .61829 Mtetra
.573 .304 .471 r
.69481 .61829 .69648 .59841 .70275 .60214 .70099 .61944 Mtetra
.652 .364 .47 r
.70099 .61944 .70275 .60214 .70847 .59511 .70751 .62651 Mtetra
.328 .133 .456 r
.70751 .62651 .70847 .59511 .71372 .57974 .71265 .60774 Mtetra
.672 .403 .506 r
.71265 .60774 .71372 .57974 .7202 .58649 .71958 .62121 Mtetra
.475 .251 .495 r
.71958 .62121 .7202 .58649 .7251 .56569 .72523 .61183 Mtetra
.378 .187 .491 r
.72523 .61183 .7251 .56569 .73021 .54929 .73003 .58847 Mtetra
.573 .333 .515 r
.73003 .58847 .73021 .54929 .73618 .54715 .73629 .58961 Mtetra
.489 .27 .508 r
.73629 .58961 .73618 .54715 .74125 .53096 .74185 .5795 Mtetra
.326 .151 .483 r
.74185 .5795 .74125 .53096 .74582 .50786 .74608 .54943 Mtetra
.249 .088 .457 r
.74608 .54943 .74582 .50786 .75078 .49141 .7501 .51753 Mtetra
.261 .076 .43 r
.7501 .51753 .75078 .49141 .75641 .48519 .75489 .49813 Mtetra
.324 .07 .366 r
.75489 .49813 .75641 .48519 .76233 .48293 .76045 .49034 Mtetra
.191 0 .206 r
.76045 .49034 .76233 .48293 .76815 .47934 .76611 .4841 Mtetra
0 0 0 r
.76611 .4841 .76815 .47934 .77399 .4758 .77178 .47792 Mtetra
.77178 .47792 .77399 .4758 .77988 .47283 .77755 .4732 Mtetra
.688 .98 .842 r
.77755 .4732 .77988 .47283 .78579 .47003 .78337 .46899 Mtetra
.746 .941 .947 r
.78337 .46899 .78579 .47003 .79175 .46772 .78925 .46555 Mtetra
.705 .843 .948 r
.78925 .46555 .79175 .46772 .79774 .46571 .79521 .46301 Mtetra
.691 .797 .931 r
.79521 .46301 .79774 .46571 .80375 .46371 .80121 .46072 Mtetra
.683 .775 .92 r
.80121 .46072 .80375 .46371 .80978 .46179 .80723 .45856 Mtetra
.67 .754 .914 r
.80723 .45856 .80978 .46179 .81582 .45995 .81327 .45661 Mtetra
.666 .746 .91 r
.81327 .45661 .81582 .45995 .82188 .45809 .81934 .45473 Mtetra
.666 .745 .909 r
.81934 .45473 .82188 .45809 .82795 .45623 .82542 .45284 Mtetra
.665 .743 .908 r
.82542 .45284 .82795 .45623 .83404 .45438 .83151 .45096 Mtetra
.663 .741 .908 r
.83151 .45096 .83404 .45438 .84014 .45253 .83762 .44911 Mtetra
.664 .741 .908 r
.83762 .44911 .84014 .45253 .84625 .45068 .84374 .44724 Mtetra
.664 .742 .908 r
.84374 .44724 .84625 .45068 .85237 .44882 .84987 .44538 Mtetra
.664 .741 .908 r
.84987 .44538 .85237 .44882 .85851 .44695 .85601 .44351 Mtetra
.85601 .44351 .85851 .44695 .86466 .44509 .86217 .44163 Mtetra
.86217 .44163 .86466 .44509 .87082 .44322 .86834 .43975 Mtetra
.86834 .43975 .87082 .44322 .87699 .44134 .87453 .43787 Mtetra
.87453 .43787 .87699 .44134 .88318 .43946 .88073 .43599 Mtetra
.88073 .43599 .88318 .43946 .88938 .43758 .88694 .4341 Mtetra
.88694 .4341 .88938 .43758 .8956 .4357 .89316 .4322 Mtetra
.89316 .4322 .8956 .4357 .90183 .4338 .8994 .4303 Mtetra
.8994 .4303 .90183 .4338 .90807 .43191 .90565 .4284 Mtetra
.90565 .4284 .90807 .43191 .91432 .43001 .91191 .4265 Mtetra
.91191 .4265 .91432 .43001 .92059 .42811 .91819 .42459 Mtetra
.91819 .42459 .92059 .42811 .92687 .4262 .92448 .42267 Mtetra
.92448 .42267 .92687 .4262 .93317 .42429 .93079 .42075 Mtetra
.93079 .42075 .93317 .42429 .93947 .42238 .93711 .41883 Mtetra
.93711 .41883 .93947 .42238 .94579 .42046 .94344 .4169 Mtetra
.94344 .4169 .94579 .42046 .95213 .41853 .94978 .41497 Mtetra
.94978 .41497 .95213 .41853 .95848 .41661 .95614 .41304 Mtetra
.38335 .58344 .38649 .58637 .3917 .58478 .38856 .58185 Mtetra
.38856 .58185 .3917 .58478 .39692 .5832 .39379 .58026 Mtetra
.39379 .58026 .39692 .5832 .40214 .58161 .39902 .57866 Mtetra
.39902 .57866 .40214 .58161 .40738 .58001 .40426 .57706 Mtetra
.40426 .57706 .40738 .58001 .41263 .57842 .40952 .57546 Mtetra
.40952 .57546 .41263 .57842 .41789 .57682 .41478 .57386 Mtetra
.41478 .57386 .41789 .57682 .42315 .57521 .42005 .57225 Mtetra
.42005 .57225 .42315 .57521 .42843 .57361 .42534 .57064 Mtetra
.42534 .57064 .42843 .57361 .43372 .572 .43063 .56902 Mtetra
.43063 .56902 .43372 .572 .43902 .57039 .43594 .5674 Mtetra
.43594 .5674 .43902 .57039 .44433 .56877 .44125 .56578 Mtetra
.44125 .56578 .44433 .56877 .44965 .56715 .44658 .56416 Mtetra
.44658 .56416 .44965 .56715 .45498 .56553 .45192 .56253 Mtetra
.45192 .56253 .45498 .56553 .46032 .56391 .45726 .5609 Mtetra
.45726 .5609 .46032 .56391 .46567 .56228 .46262 .55926 Mtetra
.46262 .55926 .46567 .56228 .47103 .56065 .46799 .55763 Mtetra
.663 .741 .908 r
.46799 .55763 .47103 .56065 .4764 .55901 .47337 .55599 Mtetra
.47337 .55599 .4764 .55901 .48178 .55738 .47876 .55435 Mtetra
.664 .742 .908 r
.47876 .55435 .48178 .55738 .48718 .55574 .48416 .5527 Mtetra
.662 .741 .909 r
.48416 .5527 .48718 .55574 .49258 .55409 .48957 .55107 Mtetra
.659 .741 .911 r
.48957 .55107 .49258 .55409 .49799 .55246 .49499 .54948 Mtetra
.656 .744 .914 r
.49499 .54948 .49799 .55246 .50342 .55085 .50042 .54792 Mtetra
.652 .746 .919 r
.50042 .54792 .50342 .55085 .50886 .54924 .50586 .54642 Mtetra
.627 .747 .934 r
.50586 .54642 .50886 .54924 .5143 .54769 .51132 .54521 Mtetra
.575 .757 .964 r
.51132 .54521 .5143 .54769 .51976 .54634 .51678 .54444 Mtetra
.488 .772 .994 r
.51678 .54444 .51976 .54634 .52523 .54514 .52226 .54403 Mtetra
.117 .629 .894 r
.52226 .54403 .52523 .54514 .53071 .54418 .52775 .54468 Mtetra
.555 0 0 r
.52775 .54468 .53071 .54418 .53621 .54411 .53327 .54716 Mtetra
.668 .241 .222 r
.53327 .54716 .53621 .54411 .54173 .54483 .53881 .55079 Mtetra
.694 .337 .365 r
.53881 .55079 .54173 .54483 .54727 .54603 .5444 .55615 Mtetra
.707 .393 .442 r
.5444 .55615 .54727 .54603 .55284 .54863 .55004 .56438 Mtetra
.688 .4 .48 r
.55004 .56438 .55284 .54863 .55844 .55137 .55573 .57395 Mtetra
.718 .443 .509 r
.55573 .57395 .55844 .55137 .56409 .55576 .56156 .59144 Mtetra
.744 .479 .53 r
.56156 .59144 .56409 .55576 .56992 .57189 .56768 .62563 Mtetra
.709 .457 .541 r
.56768 .62563 .56992 .57189 .57601 .60032 .57395 .66205 Mtetra
.631 .393 .539 r
.57395 .66205 .57601 .60032 .58216 .62588 .58004 .67735 Mtetra
.485 .27 .511 r
.58004 .67735 .58216 .62588 .58805 .6317 .58571 .66537 Mtetra
.495 .264 .493 r
.58571 .66537 .58805 .6317 .59379 .62782 .59147 .6586 Mtetra
.68 .418 .518 r
.59147 .6586 .59379 .62782 .60004 .64778 .59768 .67446 Mtetra
.259 .063 .413 r
.59768 .67446 .60004 .64778 .60604 .65277 .60321 .65645 Mtetra
.975 .902 .556 r
.60321 .65645 .60604 .65277 .61153 .63625 .60874 .63998 Mtetra
.779 .391 .319 r
.60874 .63998 .61153 .63625 .61785 .65218 .61487 .64865 Mtetra
.936 .738 .61 r
.61487 .64865 .61785 .65218 .62346 .64067 .62014 .62402 Mtetra
.563 .437 .666 r
.62014 .62402 .62346 .64067 .62928 .63701 .62608 .62489 Mtetra
.741 .576 .67 r
.62608 .62489 .62928 .63701 .63533 .64004 .63173 .61561 Mtetra
.664 .482 .628 r
.63173 .61561 .63533 .64004 .64091 .62841 .63741 .6074 Mtetra
.599 .445 .644 r
.63741 .6074 .64091 .62841 .64704 .63286 .6433 .60593 Mtetra
.648 .466 .624 r
.6433 .60593 .64704 .63286 .65273 .62464 .649 .59869 Mtetra
.587 .425 .629 r
.649 .59869 .65273 .62464 .65877 .62563 .65494 .5979 Mtetra
.598 .43 .625 r
.65494 .5979 .65877 .62563 .66469 .62317 .66085 .5959 Mtetra
.599 .431 .626 r
.66085 .5959 .66469 .62317 .6706 .62035 .66676 .59388 Mtetra
.534 .387 .627 r
.66676 .59388 .6706 .62035 .67681 .62387 .67293 .59744 Mtetra
.599 .432 .628 r
.67293 .59744 .67681 .62387 .68257 .61708 .67889 .5955 Mtetra
.492 .37 .642 r
.67889 .5955 .68257 .61708 .68902 .6249 .6852 .60091 Mtetra
.508 .375 .634 r
.6852 .60091 .68902 .6249 .69481 .61829 .69152 .60587 Mtetra
.645 .517 .693 r
.69152 .60587 .69481 .61829 .70099 .61944 .69748 .60285 Mtetra
0 0 .531 r
.69748 .60285 .70099 .61944 .70751 .62651 .70468 .62337 Mtetra
.912 .783 .705 r
.70468 .62337 .70751 .62651 .71265 .60774 .71021 .61135 Mtetra
.841 .459 .327 r
.71021 .61135 .71265 .60774 .71958 .62121 .71717 .62538 Mtetra
.833 .455 .338 r
.71717 .62538 .71958 .62121 .72523 .61183 .7242 .63934 Mtetra
.264 .076 .429 r
.7242 .63934 .72523 .61183 .73003 .58847 .7293 .61952 Mtetra
.6 .347 .505 r
.7293 .61952 .73003 .58847 .73629 .58961 .73582 .62399 Mtetra
.625 .37 .512 r
.73582 .62399 .73629 .58961 .74185 .5795 .74263 .6324 Mtetra
.432 .232 .507 r
.74263 .6324 .74185 .5795 .74608 .54943 .74763 .61201 Mtetra
.312 .147 .489 r
.74763 .61201 .74608 .54943 .7501 .51753 .75122 .57139 Mtetra
.286 .124 .478 r
.75122 .57139 .7501 .51753 .75489 .49813 .75488 .53371 Mtetra
.341 .151 .471 r
.75488 .53371 .75489 .49813 .76045 .49034 .7596 .51278 Mtetra
.342 .128 .437 r
.7596 .51278 .76045 .49034 .76611 .4841 .76484 .49975 Mtetra
.251 .031 .372 r
.76484 .49975 .76611 .4841 .77178 .47792 .77013 .4879 Mtetra
.17 0 .27 r
.77013 .4879 .77178 .47792 .77755 .4732 .77562 .47894 Mtetra
0 0 .047 r
.77562 .47894 .77755 .4732 .78337 .46899 .78124 .47179 Mtetra
0 0 0 r
.78124 .47179 .78337 .46899 .78925 .46555 .78693 .46577 Mtetra
.701 .984 .858 r
.78693 .46577 .78925 .46555 .79521 .46301 .79278 .46159 Mtetra
.73 .911 .956 r
.79278 .46159 .79521 .46301 .80121 .46072 .79872 .45849 Mtetra
.718 .843 .941 r
.79872 .45849 .80121 .46072 .80723 .45856 .8047 .45576 Mtetra
.692 .792 .927 r
.8047 .45576 .80723 .45856 .81327 .45661 .81073 .45344 Mtetra
.673 .761 .917 r
.81073 .45344 .81327 .45661 .81934 .45473 .81679 .45143 Mtetra
.669 .752 .912 r
.81679 .45143 .81934 .45473 .82542 .45284 .82287 .44948 Mtetra
.668 .747 .91 r
.82287 .44948 .82542 .45284 .83151 .45096 .82897 .44755 Mtetra
.665 .743 .909 r
.82897 .44755 .83151 .45096 .83762 .44911 .83508 .44567 Mtetra
.664 .741 .908 r
.83508 .44567 .83762 .44911 .84374 .44724 .84121 .4438 Mtetra
.664 .742 .908 r
.84121 .4438 .84374 .44724 .84987 .44538 .84736 .44192 Mtetra
.84736 .44192 .84987 .44538 .85601 .44351 .85351 .44004 Mtetra
.664 .741 .908 r
.85351 .44004 .85601 .44351 .86217 .44163 .85968 .43816 Mtetra
.85968 .43816 .86217 .44163 .86834 .43975 .86586 .43628 Mtetra
.86586 .43628 .86834 .43975 .87453 .43787 .87205 .43439 Mtetra
.87205 .43439 .87453 .43787 .88073 .43599 .87826 .43249 Mtetra
.87826 .43249 .88073 .43599 .88694 .4341 .88448 .4306 Mtetra
.88448 .4306 .88694 .4341 .89316 .4322 .89072 .4287 Mtetra
.89072 .4287 .89316 .4322 .8994 .4303 .89696 .42679 Mtetra
.89696 .42679 .8994 .4303 .90565 .4284 .90322 .42488 Mtetra
.90322 .42488 .90565 .4284 .91191 .4265 .9095 .42297 Mtetra
.9095 .42297 .91191 .4265 .91819 .42459 .91579 .42105 Mtetra
.91579 .42105 .91819 .42459 .92448 .42267 .92209 .41913 Mtetra
.92209 .41913 .92448 .42267 .93079 .42075 .9284 .4172 Mtetra
.9284 .4172 .93079 .42075 .93711 .41883 .93473 .41527 Mtetra
.93473 .41527 .93711 .41883 .94344 .4169 .94107 .41334 Mtetra
.94107 .41334 .94344 .4169 .94978 .41497 .94742 .4114 Mtetra
.94742 .4114 .94978 .41497 .95614 .41304 .95379 .40946 Mtetra
.3802 .5805 .38335 .58344 .38856 .58185 .38541 .57891 Mtetra
.38541 .57891 .38856 .58185 .39379 .58026 .39064 .57731 Mtetra
.39064 .57731 .39379 .58026 .39902 .57866 .39588 .57571 Mtetra
.39588 .57571 .39902 .57866 .40426 .57706 .40113 .5741 Mtetra
.40113 .5741 .40426 .57706 .40952 .57546 .40639 .57249 Mtetra
.40639 .57249 .40952 .57546 .41478 .57386 .41166 .57088 Mtetra
.41166 .57088 .41478 .57386 .42005 .57225 .41694 .56927 Mtetra
.41694 .56927 .42005 .57225 .42534 .57064 .42223 .56765 Mtetra
.42223 .56765 .42534 .57064 .43063 .56902 .42754 .56603 Mtetra
.42754 .56603 .43063 .56902 .43594 .5674 .43285 .56441 Mtetra
.43285 .56441 .43594 .5674 .44125 .56578 .43817 .56278 Mtetra
.43817 .56278 .44125 .56578 .44658 .56416 .4435 .56115 Mtetra
.4435 .56115 .44658 .56416 .45192 .56253 .44885 .55952 Mtetra
.44885 .55952 .45192 .56253 .45726 .5609 .4542 .55788 Mtetra
.4542 .55788 .45726 .5609 .46262 .55926 .45956 .55624 Mtetra
.663 .741 .908 r
.45956 .55624 .46262 .55926 .46799 .55763 .46494 .5546 Mtetra
.46494 .5546 .46799 .55763 .47337 .55599 .47032 .55296 Mtetra
.663 .742 .908 r
.47032 .55296 .47337 .55599 .47876 .55435 .47572 .55131 Mtetra
.662 .741 .909 r
.47572 .55131 .47876 .55435 .48416 .5527 .48113 .54968 Mtetra
.657 .741 .912 r
.48113 .54968 .48416 .5527 .48957 .55107 .48654 .54811 Mtetra
.65 .744 .918 r
.48654 .54811 .48957 .55107 .49499 .54948 .49197 .54663 Mtetra
.642 .749 .927 r
.49197 .54663 .49499 .54948 .50042 .54792 .49741 .54524 Mtetra
.609 .752 .946 r
.49741 .54524 .50042 .54792 .50586 .54642 .50286 .54419 Mtetra
.494 .747 .985 r
.50286 .54419 .50586 .54642 .51132 .54521 .50831 .54393 Mtetra
.183 .662 .931 r
.50831 .54393 .51132 .54521 .51678 .54444 .51378 .54448 Mtetra
.412 0 0 r
.51378 .54448 .51678 .54444 .52226 .54403 .51926 .54625 Mtetra
.707 .264 .197 r
.51926 .54625 .52226 .54403 .52775 .54468 .52477 .55072 Mtetra
.732 .381 .386 r
.52477 .55072 .52775 .54468 .53327 .54716 .53031 .55803 Mtetra
.715 .405 .453 r
.53031 .55803 .53327 .54716 .53881 .55079 .5359 .56731 Mtetra
.718 .431 .49 r
.5359 .56731 .53881 .55079 .5444 .55615 .54156 .58068 Mtetra
.709 .438 .513 r
.54156 .58068 .5444 .55615 .55004 .56438 .54731 .598 Mtetra
.697 .436 .525 r
.54731 .598 .55004 .56438 .55573 .57395 .55315 .61846 Mtetra
.718 .461 .536 r
.55315 .61846 .55573 .57395 .56156 .59144 .55921 .65154 Mtetra
.71 .459 .543 r
.55921 .65154 .56156 .59144 .56768 .62563 .56548 .69261 Mtetra
.64 .401 .541 r
.56548 .69261 .56768 .62563 .57395 .66205 .57162 .71174 Mtetra
.444 .235 .5 r
.57162 .71174 .57395 .66205 .58004 .67735 .57732 .69551 Mtetra
0 0 0 r
.57732 .69551 .58004 .67735 .58571 .66537 .58271 .66321 Mtetra
.893 .817 .767 r
.58271 .66321 .58571 .66537 .59147 .6586 .58844 .6546 Mtetra
.696 .713 .861 r
.58844 .6546 .59147 .6586 .59768 .67446 .59429 .65215 Mtetra
.816 .592 .598 r
.59429 .65215 .59768 .67446 .60321 .65645 .59943 .61679 Mtetra
.638 .445 .605 r
.59943 .61679 .60321 .65645 .60874 .63998 .60508 .60769 Mtetra
.632 .448 .615 r
.60508 .60769 .60874 .63998 .61487 .64865 .61078 .60108 Mtetra
.694 .481 .595 r
.61078 .60108 .61487 .64865 .62014 .62402 .61602 .57728 Mtetra
.563 .385 .598 r
.61602 .57728 .62014 .62402 .62608 .62489 .62192 .57898 Mtetra
.663 .459 .598 r
.62192 .57898 .62608 .62489 .63173 .61561 .62732 .56322 Mtetra
.587 .4 .594 r
.62732 .56322 .63173 .61561 .63741 .6074 .63311 .56091 Mtetra
.617 .424 .599 r
.63311 .56091 .63741 .6074 .6433 .60593 .63876 .55399 Mtetra
.593 .404 .595 r
.63876 .55399 .6433 .60593 .649 .59869 .64452 .5506 Mtetra
.593 .406 .598 r
.64452 .5506 .649 .59869 .65494 .5979 .65031 .54763 Mtetra
.583 .397 .596 r
.65031 .54763 .65494 .5979 .66085 .5959 .65616 .54615 Mtetra
.58 .396 .596 r
.65616 .54615 .66085 .5959 .66676 .59388 .66204 .54517 Mtetra
.57 .389 .597 r
.66204 .54517 .66676 .59388 .67293 .59744 .66801 .54579 Mtetra
.558 .378 .594 r
.66801 .54579 .67293 .59744 .67889 .5955 .67409 .54846 Mtetra
.575 .394 .598 r
.67409 .54846 .67889 .5955 .6852 .60091 .68008 .54836 Mtetra
.5 .336 .59 r
.68008 .54836 .6852 .60091 .69152 .60587 .68663 .55979 Mtetra
.602 .414 .599 r
.68663 .55979 .69152 .60587 .69748 .60285 .69245 .55545 Mtetra
.412 .275 .584 r
.69245 .55545 .69748 .60285 .70468 .62337 .69956 .57589 Mtetra
.557 .38 .598 r
.69956 .57589 .70468 .62337 .71021 .61135 .70582 .57863 Mtetra
.508 .359 .614 r
.70582 .57863 .71021 .61135 .71717 .62538 .71232 .58532 Mtetra
.216 .143 .555 r
.71232 .58532 .71717 .62538 .7242 .63934 .72031 .6175 Mtetra
.602 .446 .642 r
.72031 .6175 .7242 .63934 .7293 .61952 .72645 .6157 Mtetra
0 .157 .686 r
.72645 .6157 .7293 .61952 .73582 .62399 .73308 .62185 Mtetra
.942 .577 .249 r
.73308 .62185 .73582 .62399 .74263 .6324 .74125 .6519 Mtetra
.686 .397 .478 r
.74125 .6519 .74263 .6324 .74763 .61201 .74836 .66352 Mtetra
.396 .204 .498 r
.74836 .66352 .74763 .61201 .75122 .57139 .75318 .63945 Mtetra
.304 .142 .49 r
.75318 .63945 .75122 .57139 .75488 .53371 .7565 .59429 Mtetra
.333 .162 .493 r
.7565 .59429 .75488 .53371 .7596 .51278 .76026 .55745 Mtetra
.366 .178 .488 r
.76026 .55745 .7596 .51278 .76484 .49975 .76481 .53343 Mtetra
.325 .136 .464 r
.76481 .53343 .76484 .49975 .77013 .4879 .76952 .51245 Mtetra
.286 .091 .432 r
.76952 .51245 .77013 .4879 .77562 .47894 .77447 .49535 Mtetra
.237 .025 .375 r
.77447 .49535 .77562 .47894 .78124 .47179 .77969 .48245 Mtetra
.105 0 .262 r
.77969 .48245 .78124 .47179 .78693 .46577 .78504 .47158 Mtetra
0 0 .022 r
.78504 .47158 .78693 .46577 .79278 .46159 .7906 .46352 Mtetra
.494 .828 .537 r
.7906 .46352 .79278 .46159 .79872 .45849 .79638 .45821 Mtetra
.745 .984 .905 r
.79638 .45821 .79872 .45849 .8047 .45576 .80227 .45414 Mtetra
.746 .9 .947 r
.80227 .45414 .8047 .45576 .81073 .45344 .80822 .45087 Mtetra
.702 .814 .935 r
.80822 .45087 .81073 .45344 .81679 .45143 .81426 .44838 Mtetra
.68 .772 .921 r
.81426 .44838 .81679 .45143 .82287 .44948 .82033 .44625 Mtetra
.674 .759 .914 r
.82033 .44625 .82287 .44948 .82897 .44755 .82643 .4442 Mtetra
.669 .749 .911 r
.82643 .4442 .82897 .44755 .83508 .44567 .83255 .44224 Mtetra
.665 .743 .909 r
.83255 .44224 .83508 .44567 .84121 .4438 .83868 .44035 Mtetra
.664 .742 .908 r
.83868 .44035 .84121 .4438 .84736 .44192 .84483 .43846 Mtetra
.84483 .43846 .84736 .44192 .85351 .44004 .851 .43657 Mtetra
.851 .43657 .85351 .44004 .85968 .43816 .85718 .43468 Mtetra
.664 .741 .908 r
.85718 .43468 .85968 .43816 .86586 .43628 .86337 .43279 Mtetra
.86337 .43279 .86586 .43628 .87205 .43439 .86957 .43089 Mtetra
.86957 .43089 .87205 .43439 .87826 .43249 .87579 .42899 Mtetra
.87579 .42899 .87826 .43249 .88448 .4306 .88202 .42708 Mtetra
.88202 .42708 .88448 .4306 .89072 .4287 .88826 .42517 Mtetra
.88826 .42517 .89072 .4287 .89696 .42679 .89452 .42326 Mtetra
.89452 .42326 .89696 .42679 .90322 .42488 .90079 .42134 Mtetra
.90079 .42134 .90322 .42488 .9095 .42297 .90707 .41942 Mtetra
.90707 .41942 .9095 .42297 .91579 .42105 .91337 .4175 Mtetra
.91337 .4175 .91579 .42105 .92209 .41913 .91968 .41557 Mtetra
.91968 .41557 .92209 .41913 .9284 .4172 .926 .41364 Mtetra
.926 .41364 .9284 .4172 .93473 .41527 .93234 .4117 Mtetra
.93234 .4117 .93473 .41527 .94107 .41334 .93869 .40976 Mtetra
.93869 .40976 .94107 .41334 .94742 .4114 .94506 .40781 Mtetra
.94506 .40781 .94742 .4114 .95379 .40946 .95144 .40586 Mtetra
.37703 .57756 .3802 .5805 .38541 .57891 .38225 .57595 Mtetra
.38225 .57595 .38541 .57891 .39064 .57731 .38749 .57435 Mtetra
.38749 .57435 .39064 .57731 .39588 .57571 .39274 .57274 Mtetra
.39274 .57274 .39588 .57571 .40113 .5741 .39799 .57113 Mtetra
.39799 .57113 .40113 .5741 .40639 .57249 .40326 .56952 Mtetra
.40326 .56952 .40639 .57249 .41166 .57088 .40854 .5679 Mtetra
.40854 .5679 .41166 .57088 .41694 .56927 .41382 .56628 Mtetra
.41382 .56628 .41694 .56927 .42223 .56765 .41912 .56466 Mtetra
.41912 .56466 .42223 .56765 .42754 .56603 .42443 .56303 Mtetra
.42443 .56303 .42754 .56603 .43285 .56441 .42975 .5614 Mtetra
.42975 .5614 .43285 .56441 .43817 .56278 .43507 .55977 Mtetra
.43507 .55977 .43817 .56278 .4435 .56115 .44041 .55813 Mtetra
.44041 .55813 .4435 .56115 .44885 .55952 .44576 .55649 Mtetra
.44576 .55649 .44885 .55952 .4542 .55788 .45112 .55485 Mtetra
.663 .741 .908 r
.45112 .55485 .4542 .55788 .45956 .55624 .4565 .55321 Mtetra
.4565 .55321 .45956 .55624 .46494 .5546 .46188 .55157 Mtetra
.663 .742 .909 r
.46188 .55157 .46494 .5546 .47032 .55296 .46727 .54993 Mtetra
.662 .742 .909 r
.46727 .54993 .47032 .55296 .47572 .55131 .47267 .54829 Mtetra
.656 .741 .912 r
.47267 .54829 .47572 .55131 .48113 .54968 .47808 .54674 Mtetra
.644 .743 .922 r
.47808 .54674 .48113 .54968 .48654 .54811 .48351 .54534 Mtetra
.626 .751 .937 r
.48351 .54534 .48654 .54811 .49197 .54663 .48894 .54413 Mtetra
.578 .756 .962 r
.48894 .54413 .49197 .54663 .49741 .54524 .49438 .54333 Mtetra
.363 .714 .987 r
.49438 .54333 .49741 .54524 .50286 .54419 .49982 .54361 Mtetra
.32 0 0 r
.49982 .54361 .50286 .54419 .50831 .54393 .50528 .54544 Mtetra
.667 .183 .093 r
.50528 .54544 .50831 .54393 .51378 .54448 .51074 .54897 Mtetra
.74 .367 .346 r
.51074 .54897 .51378 .54448 .51926 .54625 .51623 .55571 Mtetra
.751 .435 .45 r
.51623 .55571 .51926 .54625 .52477 .55072 .52176 .5672 Mtetra
.73 .442 .492 r
.52176 .5672 .52477 .55072 .53031 .55803 .52734 .58203 Mtetra
.716 .444 .512 r
.52734 .58203 .53031 .55803 .5359 .56731 .53299 .60019 Mtetra
.713 .45 .526 r
.53299 .60019 .5359 .56731 .54156 .58068 .53874 .62387 Mtetra
.695 .44 .534 r
.53874 .62387 .54156 .58068 .54731 .598 .5446 .64924 Mtetra
.687 .436 .538 r
.5446 .64924 .54731 .598 .55315 .61846 .55057 .67659 Mtetra
.693 .444 .541 r
.55057 .67659 .55315 .61846 .55921 .65154 .55671 .7098 Mtetra
.636 .395 .536 r
.55671 .7098 .55921 .65154 .56548 .69261 .56279 .72555 Mtetra
.196 .021 .403 r
.56279 .72555 .56548 .69261 .57162 .71174 .56843 .70079 Mtetra
.903 .67 .575 r
.56843 .70079 .57162 .71174 .57732 .69551 .57369 .65259 Mtetra
.748 .525 .593 r
.57369 .65259 .57732 .69551 .58271 .66321 .57898 .61569 Mtetra
.63 .434 .598 r
.57898 .61569 .58271 .66321 .58844 .6546 .58463 .60617 Mtetra
.681 .471 .596 r
.58463 .60617 .58844 .6546 .59429 .65215 .59006 .58533 Mtetra
.681 .465 .587 r
.59006 .58533 .59429 .65215 .59943 .61679 .59526 .55619 Mtetra
.582 .392 .589 r
.59526 .55619 .59943 .61679 .60508 .60769 .60099 .55433 Mtetra
.65 .445 .594 r
.60099 .55433 .60508 .60769 .61078 .60108 .60641 .53909 Mtetra
.615 .417 .589 r
.60641 .53909 .61078 .60108 .61602 .57728 .61195 .52992 Mtetra
.588 .402 .597 r
.61195 .52992 .61602 .57728 .62192 .57898 .61768 .5277 Mtetra
.625 .428 .595 r
.61768 .5277 .62192 .57898 .62732 .56322 .62319 .51827 Mtetra
.574 .393 .599 r
.62319 .51827 .62732 .56322 .63311 .56091 .62899 .51831 Mtetra
.615 .425 .601 r
.62899 .51831 .63311 .56091 .63876 .55399 .63461 .51227 Mtetra
.579 .399 .602 r
.63461 .51227 .63876 .55399 .64452 .5506 .64041 .51163 Mtetra
.599 .416 .605 r
.64041 .51163 .64452 .5506 .65031 .54763 .64614 .50842 Mtetra
.586 .406 .605 r
.64614 .50842 .65031 .54763 .65616 .54615 .65194 .50696 Mtetra
.581 .403 .605 r
.65194 .50696 .65616 .54615 .66204 .54517 .65777 .50608 Mtetra
.592 .411 .605 r
.65777 .50608 .66204 .54517 .66801 .54579 .66356 .50378 Mtetra
.559 .385 .601 r
.66356 .50378 .66801 .54579 .67409 .54846 .66955 .50582 Mtetra
.596 .411 .601 r
.66955 .50582 .67409 .54846 .68008 .54836 .67533 .50269 Mtetra
.533 .363 .597 r
.67533 .50269 .68008 .54836 .68663 .55979 .68154 .50849 Mtetra
.581 .395 .595 r
.68154 .50849 .68663 .55979 .69245 .55545 .68744 .50717 Mtetra
.532 .361 .595 r
.68744 .50717 .69245 .55545 .69956 .57589 .69374 .51339 Mtetra
.512 .34 .585 r
.69374 .51339 .69956 .57589 .70582 .57863 .70035 .52477 Mtetra
.58 .394 .593 r
.70035 .52477 .70582 .57863 .71232 .58532 .70633 .52355 Mtetra
.412 .268 .574 r
.70633 .52355 .71232 .58532 .72031 .6175 .71389 .55009 Mtetra
.486 .321 .581 r
.71389 .55009 .72031 .6175 .72645 .6157 .721 .56706 Mtetra
.532 .362 .596 r
.721 .56706 .72645 .6157 .73308 .62185 .72757 .57337 Mtetra
.262 .169 .557 r
.72757 .57337 .73308 .62185 .74125 .6519 .73596 .60873 Mtetra
.067 .037 .51 r
.73596 .60873 .74125 .6519 .74836 .66352 .74513 .65398 Mtetra
0 0 .335 r
.74513 .65398 .74836 .66352 .75318 .63945 .75285 .67418 Mtetra
.339 .145 .464 r
.75285 .67418 .75318 .63945 .7565 .59429 .75795 .65391 Mtetra
.321 .151 .488 r
.75795 .65391 .7565 .59429 .76026 .55745 .76182 .61643 Mtetra
.369 .188 .499 r
.76182 .61643 .76026 .55745 .76481 .53343 .766 .58518 Mtetra
.354 .173 .491 r
.766 .58518 .76481 .53343 .76952 .51245 .77025 .55604 Mtetra
.32 .142 .477 r
.77025 .55604 .76952 .51245 .77447 .49535 .77452 .52841 Mtetra
.304 .12 .458 r
.77452 .52841 .77447 .49535 .77969 .48245 .77913 .50642 Mtetra
.248 .061 .419 r
.77913 .50642 .77969 .48245 .78504 .47158 .78396 .48793 Mtetra
.162 0 .352 r
.78396 .48793 .78504 .47158 .7906 .46352 .789 .47277 Mtetra
.05 0 .211 r
.789 .47277 .7906 .46352 .79638 .45821 .7944 .4624 Mtetra
0 0 0 r
.7944 .4624 .79638 .45821 .80227 .45414 .80005 .45532 Mtetra
.66 .945 .696 r
.80005 .45532 .80227 .45414 .80822 .45087 .80585 .44995 Mtetra
.765 .956 .934 r
.80585 .44995 .80822 .45087 .81426 .44838 .81178 .4461 Mtetra
.716 .843 .942 r
.81178 .4461 .81426 .44838 .82033 .44625 .81781 .44336 Mtetra
.691 .789 .926 r
.81781 .44336 .82033 .44625 .82643 .4442 .8239 .44104 Mtetra
.68 .767 .917 r
.8239 .44104 .82643 .4442 .83255 .44224 .83001 .43889 Mtetra
.67 .751 .912 r
.83001 .43889 .83255 .44224 .83868 .44035 .83614 .4369 Mtetra
.665 .744 .909 r
.83614 .4369 .83868 .44035 .84483 .43846 .8423 .43499 Mtetra
.664 .742 .908 r
.8423 .43499 .84483 .43846 .851 .43657 .84848 .43309 Mtetra
.84848 .43309 .851 .43657 .85718 .43468 .85466 .43118 Mtetra
.85466 .43118 .85718 .43468 .86337 .43279 .86086 .42928 Mtetra
.664 .741 .908 r
.86086 .42928 .86337 .43279 .86957 .43089 .86708 .42738 Mtetra
.86708 .42738 .86957 .43089 .87579 .42899 .8733 .42547 Mtetra
.8733 .42547 .87579 .42899 .88202 .42708 .87954 .42356 Mtetra
.87954 .42356 .88202 .42708 .88826 .42517 .8858 .42164 Mtetra
.8858 .42164 .88826 .42517 .89452 .42326 .89206 .41972 Mtetra
.89206 .41972 .89452 .42326 .90079 .42134 .89834 .41779 Mtetra
.89834 .41779 .90079 .42134 .90707 .41942 .90464 .41587 Mtetra
.90464 .41587 .90707 .41942 .91337 .4175 .91094 .41393 Mtetra
.91094 .41393 .91337 .4175 .91968 .41557 .91726 .412 Mtetra
.91726 .412 .91968 .41557 .926 .41364 .9236 .41005 Mtetra
.9236 .41005 .926 .41364 .93234 .4117 .92994 .40811 Mtetra
.92994 .40811 .93234 .4117 .93869 .40976 .93631 .40616 Mtetra
.93631 .40616 .93869 .40976 .94506 .40781 .94268 .40421 Mtetra
.94268 .40421 .94506 .40781 .95144 .40586 .94907 .40225 Mtetra
.37385 .5746 .37703 .57756 .38225 .57595 .37908 .57299 Mtetra
.37908 .57299 .38225 .57595 .38749 .57435 .38433 .57138 Mtetra
.38433 .57138 .38749 .57435 .39274 .57274 .38958 .56977 Mtetra
.38958 .56977 .39274 .57274 .39799 .57113 .39484 .56815 Mtetra
.39484 .56815 .39799 .57113 .40326 .56952 .40011 .56653 Mtetra
.40011 .56653 .40326 .56952 .40854 .5679 .4054 .56491 Mtetra
.4054 .56491 .40854 .5679 .41382 .56628 .41069 .56328 Mtetra
.41069 .56328 .41382 .56628 .41912 .56466 .41599 .56165 Mtetra
.41599 .56165 .41912 .56466 .42443 .56303 .42131 .56002 Mtetra
.42131 .56002 .42443 .56303 .42975 .5614 .42663 .55838 Mtetra
.42663 .55838 .42975 .5614 .43507 .55977 .43197 .55674 Mtetra
.43197 .55674 .43507 .55977 .44041 .55813 .43731 .5551 Mtetra
.43731 .5551 .44041 .55813 .44576 .55649 .44267 .55346 Mtetra
.663 .741 .908 r
.44267 .55346 .44576 .55649 .45112 .55485 .44804 .55181 Mtetra
.44804 .55181 .45112 .55485 .4565 .55321 .45342 .55017 Mtetra
.662 .742 .909 r
.45342 .55017 .4565 .55321 .46188 .55157 .4588 .54853 Mtetra
.661 .742 .91 r
.4588 .54853 .46188 .55157 .46727 .54993 .4642 .54691 Mtetra
.655 .742 .913 r
.4642 .54691 .46727 .54993 .47267 .54829 .46961 .54536 Mtetra
.637 .743 .925 r
.46961 .54536 .47267 .54829 .47808 .54674 .47503 .54405 Mtetra
.604 .751 .948 r
.47503 .54405 .47808 .54674 .48351 .54534 .48045 .54306 Mtetra
.524 .754 .98 r
.48045 .54306 .48351 .54534 .48894 .54413 .48588 .5426 Mtetra
.144 .62 .923 r
.48588 .5426 .48894 .54413 .49438 .54333 .49131 .5435 Mtetra
.617 .066 0 r
.49131 .5435 .49438 .54333 .49982 .54361 .49674 .54674 Mtetra
.74 .338 .289 r
.49674 .54674 .49982 .54361 .50528 .54544 .50218 .55266 Mtetra
.751 .418 .42 r
.50218 .55266 .50528 .54544 .51074 .54897 .50764 .56223 Mtetra
.755 .458 .481 r
.50764 .56223 .51074 .54897 .51623 .55571 .51312 .57782 Mtetra
.739 .463 .511 r
.51312 .57782 .51623 .55571 .52176 .5672 .51867 .59886 Mtetra
.716 .452 .525 r
.51867 .59886 .52176 .5672 .52734 .58203 .5243 .62222 Mtetra
.706 .448 .532 r
.5243 .62222 .52734 .58203 .53299 .60019 .53002 .64877 Mtetra
.692 .44 .537 r
.53002 .64877 .53299 .60019 .53874 .62387 .53586 .67635 Mtetra
.66 .414 .536 r
.53586 .67635 .53874 .62387 .5446 .64924 .54177 .69678 Mtetra
.642 .395 .531 r
.54177 .69678 .5446 .64924 .55057 .67659 .54772 .71107 Mtetra
.572 .327 .507 r
.54772 .71107 .55057 .67659 .55671 .7098 .55364 .71234 Mtetra
.987 .789 .55 r
.55364 .71234 .55671 .7098 .56279 .72555 .55923 .67846 Mtetra
.787 .553 .583 r
.55923 .67846 .56279 .72555 .56843 .70079 .56445 .62039 Mtetra
.71 .485 .582 r
.56445 .62039 .56843 .70079 .57369 .65259 .56963 .57244 Mtetra
.643 .434 .584 r
.56963 .57244 .57369 .65259 .57898 .61569 .57506 .55164 Mtetra
.614 .415 .588 r
.57506 .55164 .57898 .61569 .58463 .60617 .58064 .54256 Mtetra
.652 .444 .589 r
.58064 .54256 .58463 .60617 .59006 .58533 .58602 .52362 Mtetra
.602 .406 .589 r
.58602 .52362 .59006 .58533 .59526 .55619 .59161 .51742 Mtetra
.587 .407 .605 r
.59161 .51742 .59526 .55619 .60099 .55433 .5973 .51579 Mtetra
.623 .434 .605 r
.5973 .51579 .60099 .55433 .60641 .53909 .60287 .50912 Mtetra
.545 .386 .617 r
.60287 .50912 .60641 .53909 .61195 .52992 .60868 .51185 Mtetra
.648 .485 .65 r
.60868 .51185 .61195 .52992 .61768 .5277 .61432 .50718 Mtetra
.542 .405 .644 r
.61432 .50718 .61768 .5277 .62319 .51827 .62016 .50934 Mtetra
.659 .559 .73 r
.62016 .50934 .62319 .51827 .62899 .51831 .62587 .50663 Mtetra
.573 .475 .705 r
.62587 .50663 .62899 .51831 .63461 .51227 .63169 .50683 Mtetra
.654 .634 .818 r
.63169 .50683 .63461 .51227 .64041 .51163 .63745 .50507 Mtetra
.623 .586 .791 r
.63745 .50507 .64041 .51163 .64614 .50842 .64326 .5039 Mtetra
.668 .677 .849 r
.64326 .5039 .64614 .50842 .65194 .50696 .64904 .50195 Mtetra
.668 .657 .83 r
.64904 .50195 .65194 .50696 .65777 .50608 .65484 .49993 Mtetra
.665 .618 .793 r
.65484 .49993 .65777 .50608 .66356 .50378 .66063 .49775 Mtetra
.704 .64 .782 r
.66063 .49775 .66356 .50378 .66955 .50582 .6664 .49443 Mtetra
.611 .502 .705 r
.6664 .49443 .66955 .50582 .67533 .50269 .67226 .49316 Mtetra
.71 .58 .708 r
.67226 .49316 .67533 .50269 .68154 .50849 .67794 .48785 Mtetra
.564 .421 .645 r
.67794 .48785 .68154 .50849 .68744 .50717 .68392 .4887 Mtetra
.663 .495 .646 r
.68392 .4887 .68744 .50717 .69374 .51339 .68958 .48258 Mtetra
.541 .383 .616 r
.68958 .48258 .69374 .51339 .70035 .52477 .69572 .48587 Mtetra
.59 .409 .605 r
.69572 .48587 .70035 .52477 .70633 .52355 .7016 .48377 Mtetra
.548 .379 .604 r
.7016 .48377 .70633 .52355 .71389 .55009 .70779 .487 Mtetra
.487 .322 .582 r
.70779 .487 .71389 .55009 .721 .56706 .71472 .50271 Mtetra
.546 .365 .586 r
.71472 .50271 .721 .56706 .72757 .57337 .72112 .50804 Mtetra
.474 .312 .58 r
.72112 .50804 .72757 .57337 .73596 .60873 .72835 .52658 Mtetra
.348 .217 .556 r
.72835 .52658 .73596 .60873 .74513 .65398 .73741 .57279 Mtetra
.29 .175 .545 r
.73741 .57279 .74513 .65398 .75285 .67418 .74723 .62782 Mtetra
.309 .205 .571 r
.74723 .62782 .75285 .67418 .75795 .65391 .75561 .65786 Mtetra
0 0 0 r
.75561 .65786 .75795 .65391 .76182 .61643 .76171 .65235 Mtetra
.371 .171 .474 r
.76171 .65235 .76182 .61643 .766 .58518 .76689 .63383 Mtetra
.381 .19 .493 r
.76689 .63383 .766 .58518 .77025 .55604 .7716 .60945 Mtetra
.339 .162 .489 r
.7716 .60945 .77025 .55604 .77452 .52841 .7757 .57773 Mtetra
.325 .15 .483 r
.7757 .57773 .77452 .52841 .77913 .50642 .77978 .547 Mtetra
.301 .126 .469 r
.77978 .547 .77913 .50642 .78396 .48793 .78403 .51972 Mtetra
.244 .073 .44 r
.78403 .51972 .78396 .48793 .789 .47277 .78839 .49486 Mtetra
.192 .014 .396 r
.78839 .49486 .789 .47277 .7944 .4624 .79312 .47549 Mtetra
.115 0 .303 r
.79312 .47549 .7944 .4624 .80005 .45532 .79831 .46225 Mtetra
0 0 .085 r
.79831 .46225 .80005 .45532 .80585 .44995 .80378 .45276 Mtetra
0 0 0 r
.80378 .45276 .80585 .44995 .81178 .4461 .80948 .44593 Mtetra
.763 .991 .884 r
.80948 .44593 .81178 .4461 .81781 .44336 .81537 .44146 Mtetra
.736 .879 .946 r
.81537 .44146 .81781 .44336 .8239 .44104 .8214 .43835 Mtetra
.705 .81 .931 r
.8214 .43835 .8239 .44104 .83001 .43889 .82748 .4358 Mtetra
.685 .775 .919 r
.82748 .4358 .83001 .43889 .83614 .4369 .83361 .43355 Mtetra
.671 .753 .912 r
.83361 .43355 .83614 .4369 .8423 .43499 .83977 .43154 Mtetra
.665 .745 .909 r
.83977 .43154 .8423 .43499 .84848 .43309 .84595 .42961 Mtetra
.665 .743 .908 r
.84595 .42961 .84848 .43309 .85466 .43118 .85214 .42768 Mtetra
.664 .742 .908 r
.85214 .42768 .85466 .43118 .86086 .42928 .85835 .42576 Mtetra
.85835 .42576 .86086 .42928 .86708 .42738 .86457 .42385 Mtetra
.663 .741 .908 r
.86457 .42385 .86708 .42738 .8733 .42547 .87081 .42193 Mtetra
.664 .741 .908 r
.87081 .42193 .8733 .42547 .87954 .42356 .87706 .42002 Mtetra
.87706 .42002 .87954 .42356 .8858 .42164 .88332 .41809 Mtetra
.88332 .41809 .8858 .42164 .89206 .41972 .8896 .41616 Mtetra
.8896 .41616 .89206 .41972 .89834 .41779 .89589 .41423 Mtetra
.89589 .41423 .89834 .41779 .90464 .41587 .90219 .41229 Mtetra
.90219 .41229 .90464 .41587 .91094 .41393 .90851 .41035 Mtetra
.90851 .41035 .91094 .41393 .91726 .412 .91484 .40841 Mtetra
.91484 .40841 .91726 .412 .9236 .41005 .92118 .40646 Mtetra
.92118 .40646 .9236 .41005 .92994 .40811 .92754 .40451 Mtetra
.92754 .40451 .92994 .40811 .93631 .40616 .93391 .40255 Mtetra
.93391 .40255 .93631 .40616 .94268 .40421 .9403 .40059 Mtetra
.9403 .40059 .94268 .40421 .94907 .40225 .94669 .39862 Mtetra
.37066 .57163 .37385 .5746 .37908 .57299 .3759 .57001 Mtetra
.3759 .57001 .37908 .57299 .38433 .57138 .38115 .5684 Mtetra
.38115 .5684 .38433 .57138 .38958 .56977 .38641 .56678 Mtetra
.38641 .56678 .38958 .56977 .39484 .56815 .39168 .56516 Mtetra
.39168 .56516 .39484 .56815 .40011 .56653 .39696 .56353 Mtetra
.39696 .56353 .40011 .56653 .4054 .56491 .40225 .5619 Mtetra
.40225 .5619 .4054 .56491 .41069 .56328 .40755 .56027 Mtetra
.40755 .56027 .41069 .56328 .41599 .56165 .41286 .55863 Mtetra
.41286 .55863 .41599 .56165 .42131 .56002 .41818 .557 Mtetra
.41818 .557 .42131 .56002 .42663 .55838 .42351 .55536 Mtetra
.42351 .55536 .42663 .55838 .43197 .55674 .42885 .55371 Mtetra
.42885 .55371 .43197 .55674 .43731 .5551 .4342 .55206 Mtetra
.663 .741 .908 r
.4342 .55206 .43731 .5551 .44267 .55346 .43957 .55041 Mtetra
.43957 .55041 .44267 .55346 .44804 .55181 .44494 .54877 Mtetra
.662 .742 .909 r
.44494 .54877 .44804 .55181 .45342 .55017 .45032 .54714 Mtetra
.661 .742 .91 r
.45032 .54714 .45342 .55017 .4588 .54853 .45572 .54552 Mtetra
.654 .742 .914 r
.45572 .54552 .4588 .54853 .4642 .54691 .46112 .54399 Mtetra
.63 .742 .928 r
.46112 .54399 .4642 .54691 .46961 .54536 .46653 .54275 Mtetra
.578 .748 .958 r
.46653 .54275 .46961 .54536 .47503 .54405 .47195 .54199 Mtetra
.436 .737 .991 r
.47195 .54199 .47503 .54405 .48045 .54306 .47736 .54197 Mtetra
0 .42 .726 r
.47736 .54197 .48045 .54306 .48588 .5426 .48278 .54357 Mtetra
.724 .245 .108 r
.48278 .54357 .48588 .5426 .49131 .5435 .48818 .54827 Mtetra
.769 .41 .375 r
.48818 .54827 .49131 .5435 .49674 .54674 .49358 .55691 Mtetra
.759 .449 .46 r
.49358 .55691 .49674 .54674 .50218 .55266 .49898 .56997 Mtetra
.755 .469 .5 r
.49898 .56997 .50218 .55266 .50764 .56223 .50441 .58948 Mtetra
.744 .473 .521 r
.50441 .58948 .50764 .56223 .51312 .57782 .50989 .616 Mtetra
.718 .458 .532 r
.50989 .616 .51312 .57782 .51867 .59886 .51547 .64448 Mtetra
.694 .44 .535 r
.51547 .64448 .51867 .59886 .5243 .62222 .52116 .67095 Mtetra
.677 .426 .535 r
.52116 .67095 .5243 .62222 .53002 .64877 .52695 .69424 Mtetra
.628 .383 .527 r
.52695 .69424 .53002 .64877 .53586 .67635 .53281 .70529 Mtetra
.466 .23 .472 r
.53281 .70529 .53586 .67635 .54177 .69678 .53865 .69791 Mtetra
.981 .82 .609 r
.53865 .69791 .54177 .69678 .54772 .71107 .54441 .67631 Mtetra
.784 .558 .592 r
.54441 .67631 .54772 .71107 .55364 .71234 .54997 .63455 Mtetra
.731 .503 .581 r
.54997 .63455 .55364 .71234 .55923 .67846 .55526 .57732 Mtetra
.68 .459 .58 r
.55526 .57732 .55923 .67846 .56445 .62039 .56053 .53407 Mtetra
.625 .418 .582 r
.56053 .53407 .56445 .62039 .56963 .57244 .56601 .51786 Mtetra
.583 .394 .591 r
.56601 .51786 .56963 .57244 .57506 .55164 .57164 .516 Mtetra
.611 .427 .608 r
.57164 .516 .57506 .55164 .58064 .54256 .57725 .51148 Mtetra
.552 .389 .614 r
.57725 .51148 .58064 .54256 .58602 .52362 .58297 .51357 Mtetra
.297 .317 .713 r
.58297 .51357 .58602 .52362 .59161 .51742 .5888 .5197 Mtetra
0 0 0 r
.5888 .5197 .59161 .51742 .5973 .51579 .59444 .51541 Mtetra
.83 .366 .102 r
.59444 .51541 .5973 .51579 .60287 .50912 .60039 .52413 Mtetra
.513 .234 .428 r
.60039 .52413 .60287 .50912 .60868 .51185 .60613 .5225 Mtetra
.539 .228 .388 r
.60613 .5225 .60868 .51185 .61432 .50718 .61192 .52256 Mtetra
.612 .323 .454 r
.61192 .52256 .61432 .50718 .62016 .50934 .61784 .52618 Mtetra
.453 .191 .425 r
.61784 .52618 .62016 .50934 .62587 .50663 .62354 .5215 Mtetra
.606 .315 .449 r
.62354 .5215 .62587 .50663 .63169 .50683 .62948 .52471 Mtetra
.472 .212 .437 r
.62948 .52471 .63169 .50683 .63745 .50507 .63522 .52055 Mtetra
.554 .271 .441 r
.63522 .52055 .63745 .50507 .64326 .5039 .64111 .52081 Mtetra
.509 .239 .44 r
.64111 .52081 .64326 .5039 .64904 .50195 .64693 .51861 Mtetra
.491 .223 .434 r
.64693 .51861 .64904 .50195 .65484 .49993 .65273 .51562 Mtetra
.547 .266 .441 r
.65273 .51562 .65484 .49993 .66063 .49775 .65866 .51553 Mtetra
.426 .173 .425 r
.65866 .51553 .66063 .49775 .6664 .49443 .66434 .50929 Mtetra
.565 .277 .438 r
.66434 .50929 .6664 .49443 .67226 .49316 .67034 .51017 Mtetra
.392 .143 .412 r
.67034 .51017 .67226 .49316 .67794 .48785 .67598 .5029 Mtetra
.477 .203 .419 r
.67598 .5029 .67794 .48785 .68392 .4887 .68181 .49965 Mtetra
.464 .163 .369 r
.68181 .49965 .68392 .4887 .68958 .48258 .68768 .49719 Mtetra
.186 0 .329 r
.68768 .49719 .68958 .48258 .69572 .48587 .69308 .48522 Mtetra
.002 .567 .795 r
.69308 .48522 .69572 .48587 .7016 .48377 .69913 .48593 Mtetra
.896 .956 .614 r
.69913 .48593 .7016 .48377 .70779 .487 .70461 .47596 Mtetra
.696 .557 .693 r
.70461 .47596 .70779 .487 .71472 .50271 .71034 .47065 Mtetra
.565 .398 .614 r
.71034 .47065 .71472 .50271 .72112 .50804 .71643 .47164 Mtetra
.587 .409 .608 r
.71643 .47164 .72112 .50804 .72835 .52658 .72239 .46998 Mtetra
.488 .325 .586 r
.72239 .46998 .72835 .52658 .73741 .57279 .72933 .48387 Mtetra
.395 .249 .562 r
.72933 .48387 .73741 .57279 .74723 .62782 .73807 .52504 Mtetra
.363 .223 .554 r
.73807 .52504 .74723 .62782 .75561 .65786 .74787 .5797 Mtetra
.383 .243 .564 r
.74787 .5797 .75561 .65786 .76171 .65235 .7568 .61827 Mtetra
.374 .264 .599 r
.7568 .61827 .76171 .65235 .76689 .63383 .76447 .63605 Mtetra
.626 .13 .055 r
.76447 .63605 .76689 .63383 .7716 .60945 .7712 .63958 Mtetra
.376 .167 .463 r
.7712 .63958 .7716 .60945 .7757 .57773 .77661 .62448 Mtetra
.338 .156 .482 r
.77661 .62448 .7757 .57773 .77978 .547 .78104 .59676 Mtetra
.327 .151 .483 r
.78104 .59676 .77978 .547 .78403 .51972 .78515 .56597 Mtetra
.285 .118 .471 r
.78515 .56597 .78403 .51972 .78839 .49486 .78902 .5334 Mtetra
.238 .078 .451 r
.78902 .5334 .78839 .49486 .79312 .47549 .79295 .50284 Mtetra
.204 .036 .419 r
.79295 .50284 .79312 .47549 .79831 .46225 .79738 .47943 Mtetra
.136 0 .35 r
.79738 .47943 .79831 .46225 .80378 .45276 .8023 .46266 Mtetra
0 0 .204 r
.8023 .46266 .80378 .45276 .80948 .44593 .80756 .45039 Mtetra
0 0 0 r
.80756 .45039 .80948 .44593 .81537 .44146 .81314 .44206 Mtetra
.73 .985 .785 r
.81314 .44206 .81537 .44146 .8214 .43835 .819 .43687 Mtetra
.759 .918 .943 r
.819 .43687 .8214 .43835 .82748 .4358 .825 .43332 Mtetra
.719 .831 .934 r
.825 .43332 .82748 .4358 .83361 .43355 .83109 .43052 Mtetra
.69 .782 .921 r
.83109 .43052 .83361 .43355 .83977 .43154 .83723 .42819 Mtetra
.672 .755 .913 r
.83723 .42819 .83977 .43154 .84595 .42961 .84341 .42614 Mtetra
.666 .745 .909 r
.84341 .42614 .84595 .42961 .85214 .42768 .84961 .42418 Mtetra
.665 .743 .909 r
.84961 .42418 .85214 .42768 .85835 .42576 .85583 .42225 Mtetra
.664 .742 .908 r
.85583 .42225 .85835 .42576 .86457 .42385 .86206 .42031 Mtetra
.86206 .42031 .86457 .42385 .87081 .42193 .8683 .41839 Mtetra
.663 .741 .908 r
.8683 .41839 .87081 .42193 .87706 .42002 .87456 .41646 Mtetra
.664 .741 .908 r
.87456 .41646 .87706 .42002 .88332 .41809 .88084 .41453 Mtetra
.88084 .41453 .88332 .41809 .8896 .41616 .88712 .41259 Mtetra
.88712 .41259 .8896 .41616 .89589 .41423 .89342 .41065 Mtetra
.89342 .41065 .89589 .41423 .90219 .41229 .89973 .40871 Mtetra
.89973 .40871 .90219 .41229 .90851 .41035 .90606 .40676 Mtetra
.90606 .40676 .90851 .41035 .91484 .40841 .9124 .40481 Mtetra
.9124 .40481 .91484 .40841 .92118 .40646 .91876 .40285 Mtetra
.91876 .40285 .92118 .40646 .92754 .40451 .92512 .40089 Mtetra
.92512 .40089 .92754 .40451 .93391 .40255 .9315 .39893 Mtetra
.9315 .39893 .93391 .40255 .9403 .40059 .9379 .39696 Mtetra
.9379 .39696 .9403 .40059 .94669 .39862 .94431 .39498 Mtetra
.36746 .56865 .37066 .57163 .3759 .57001 .37271 .56703 Mtetra
.37271 .56703 .3759 .57001 .38115 .5684 .37796 .56541 Mtetra
.37796 .56541 .38115 .5684 .38641 .56678 .38323 .56378 Mtetra
.38323 .56378 .38641 .56678 .39168 .56516 .3885 .56215 Mtetra
.3885 .56215 .39168 .56516 .39696 .56353 .39379 .56052 Mtetra
.39379 .56052 .39696 .56353 .40225 .5619 .39908 .55889 Mtetra
.39908 .55889 .40225 .5619 .40755 .56027 .40439 .55725 Mtetra
.40439 .55725 .40755 .56027 .41286 .55863 .40971 .55561 Mtetra
.40971 .55561 .41286 .55863 .41818 .557 .41503 .55396 Mtetra
.41503 .55396 .41818 .557 .42351 .55536 .42037 .55232 Mtetra
.42037 .55232 .42351 .55536 .42885 .55371 .42572 .55066 Mtetra
.663 .741 .908 r
.42572 .55066 .42885 .55371 .4342 .55206 .43108 .54901 Mtetra
.43108 .54901 .4342 .55206 .43957 .55041 .43645 .54737 Mtetra
.662 .742 .909 r
.43645 .54737 .43957 .55041 .44494 .54877 .44183 .54574 Mtetra
.66 .742 .911 r
.44183 .54574 .44494 .54877 .45032 .54714 .44722 .54412 Mtetra
.652 .742 .915 r
.44722 .54412 .45032 .54714 .45572 .54552 .45262 .54262 Mtetra
.625 .742 .931 r
.45262 .54262 .45572 .54552 .46112 .54399 .45802 .54144 Mtetra
.551 .743 .966 r
.45802 .54144 .46112 .54399 .46653 .54275 .46343 .54089 Mtetra
.316 .696 .979 r
.46343 .54089 .46653 .54275 .47195 .54199 .46883 .54133 Mtetra
.426 0 0 r
.46883 .54133 .47195 .54199 .47736 .54197 .47422 .54371 Mtetra
.765 .335 .229 r
.47422 .54371 .47736 .54197 .48278 .54357 .47959 .54985 Mtetra
.783 .447 .419 r
.47959 .54985 .48278 .54357 .48818 .54827 .48492 .56125 Mtetra
.766 .47 .483 r
.48492 .56125 .48818 .54827 .49358 .55691 .49026 .57821 Mtetra
.754 .477 .511 r
.49026 .57821 .49358 .55691 .49898 .56997 .49561 .60161 Mtetra
.744 .477 .527 r
.49561 .60161 .49898 .56997 .50441 .58948 .50101 .63211 Mtetra
.719 .461 .535 r
.50101 .63211 .50441 .58948 .50989 .616 .50651 .66414 Mtetra
.682 .43 .535 r
.50651 .66414 .50989 .616 .51547 .64448 .51217 .68845 Mtetra
.64 .392 .527 r
.51217 .68845 .51547 .64448 .52116 .67095 .51795 .70145 Mtetra
.525 .282 .489 r
.51795 .70145 .52116 .67095 .52695 .69424 .52379 .69839 Mtetra
.998 .836 .553 r
.52379 .69839 .52695 .69424 .53281 .70529 .52961 .67217 Mtetra
.79 .563 .593 r
.52961 .67217 .53281 .70529 .53865 .69791 .53531 .63014 Mtetra
.725 .499 .584 r
.53531 .63014 .53865 .69791 .54441 .67631 .54087 .58322 Mtetra
.69 .468 .58 r
.54087 .58322 .54441 .67631 .54997 .63455 .5463 .53833 Mtetra
.643 .431 .58 r
.5463 .53833 .54997 .63455 .55526 .57732 .55175 .51322 Mtetra
.567 .379 .585 r
.55175 .51322 .55526 .57732 .56053 .53407 .55739 .51399 Mtetra
.393 .301 .632 r
.55739 .51399 .56053 .53407 .56601 .51786 .56314 .52277 Mtetra
.557 .158 .242 r
.56314 .52277 .56601 .51786 .57164 .516 .56884 .52403 Mtetra
.656 .316 .385 r
.56884 .52403 .57164 .516 .57725 .51148 .57461 .52852 Mtetra
.725 .434 .486 r
.57461 .52852 .57725 .51148 .58297 .51357 .58058 .54318 Mtetra
.49 .253 .482 r
.58058 .54318 .58297 .51357 .5888 .5197 .58624 .53725 Mtetra
.536 .264 .45 r
.58624 .53725 .5888 .5197 .59444 .51541 .592 .5364 Mtetra
.651 .375 .488 r
.592 .5364 .59444 .51541 .60039 .52413 .59797 .54449 Mtetra
.29 .069 .396 r
.59797 .54449 .60039 .52413 .60613 .5225 .60351 .5321 Mtetra
.674 .347 .412 r
.60351 .5321 .60613 .5225 .61192 .52256 .60948 .53808 Mtetra
.375 .117 .39 r
.60948 .53808 .61192 .52256 .61784 .52618 .61515 .53118 Mtetra
.411 .011 .166 r
.61515 .53118 .61784 .52618 .62354 .5215 .62098 .53006 Mtetra
.443 .115 .313 r
.62098 .53006 .62354 .5215 .62948 .52471 .62679 .52798 Mtetra
.052 0 0 r
.62679 .52798 .62948 .52471 .63522 .52055 .63258 .52488 Mtetra
.36 0 .098 r
.63258 .52488 .63522 .52055 .64111 .52081 .63843 .52348 Mtetra
.178 0 0 r
.63843 .52348 .64111 .52081 .64693 .51861 .64429 .52175 Mtetra
.166 0 0 r
.64429 .52175 .64693 .51861 .65273 .51562 .65014 .51951 Mtetra
.442 .004 .108 r
.65014 .51951 .65273 .51562 .65866 .51553 .65608 .51933 Mtetra
.276 0 .011 r
.65608 .51933 .65866 .51553 .66434 .50929 .66197 .51741 Mtetra
.453 .118 .306 r
.66197 .51741 .66434 .50929 .67034 .51017 .66788 .51569 Mtetra
.606 .218 .282 r
.66788 .51569 .67034 .51017 .67598 .5029 .67399 .51822 Mtetra
.32 .074 .376 r
.67399 .51822 .67598 .5029 .68181 .49965 .67961 .50945 Mtetra
.709 .378 .415 r
.67961 .50945 .68181 .49965 .68768 .49719 .68604 .51793 Mtetra
.326 .104 .415 r
.68604 .51793 .68768 .49719 .69308 .48522 .69151 .50605 Mtetra
.521 .262 .462 r
.69151 .50605 .69308 .48522 .69913 .48593 .69745 .50387 Mtetra
.581 .303 .459 r
.69745 .50387 .69913 .48593 .70461 .47596 .70363 .50582 Mtetra
.306 .112 .444 r
.70363 .50582 .70461 .47596 .71034 .47065 .70869 .48717 Mtetra
.379 .13 .406 r
.70869 .48717 .71034 .47065 .71643 .47164 .71433 .47953 Mtetra
.276 0 .239 r
.71433 .47953 .71643 .47164 .72239 .46998 .72012 .4745 Mtetra
.755 .829 .366 r
.72012 .4745 .72239 .46998 .72933 .48387 .72544 .46182 Mtetra
.622 .456 .637 r
.72544 .46182 .72933 .48387 .73807 .52504 .73131 .4582 Mtetra
.449 .293 .576 r
.73131 .4582 .73807 .52504 .74787 .5797 .7389 .48106 Mtetra
.408 .257 .562 r
.7389 .48106 .74787 .5797 .7568 .61827 .74791 .52373 Mtetra
.393 .247 .561 r
.74791 .52373 .7568 .61827 .76447 .63605 .75721 .56791 Mtetra
.346 .22 .562 r
.75721 .56791 .76447 .63605 .7712 .63958 .76632 .60684 Mtetra
.285 .204 .587 r
.76632 .60684 .7712 .63958 .77661 .62448 .77444 .62969 Mtetra
.425 .023 .171 r
.77444 .62969 .77661 .62448 .78104 .59676 .78089 .62868 Mtetra
.355 .153 .462 r
.78089 .62868 .78104 .59676 .78515 .56597 .78611 .61117 Mtetra
.317 .14 .476 r
.78611 .61117 .78515 .56597 .78902 .5334 .79041 .58245 Mtetra
.265 .105 .468 r
.79041 .58245 .78902 .5334 .79295 .50284 .79401 .54608 Mtetra
.232 .077 .455 r
.79401 .54608 .79295 .50284 .79738 .47943 .79762 .51129 Mtetra
.202 .043 .429 r
.79762 .51129 .79738 .47943 .8023 .46266 .80173 .48388 Mtetra
.137 0 .375 r
.80173 .48388 .8023 .46266 .80756 .45039 .80633 .46315 Mtetra
.019 0 .266 r
.80633 .46315 .80756 .45039 .81314 .44206 .81137 .44804 Mtetra
0 0 0 r
.81137 .44804 .81314 .44206 .819 .43687 .81684 .43824 Mtetra
.674 .937 .655 r
.81684 .43824 .819 .43687 .825 .43332 .82265 .43225 Mtetra
.778 .952 .93 r
.82265 .43225 .825 .43332 .83109 .43052 .82863 .42822 Mtetra
.732 .851 .936 r
.82863 .42822 .83109 .43052 .83723 .42819 .83472 .42519 Mtetra
.694 .788 .923 r
.83472 .42519 .83723 .42819 .84341 .42614 .84087 .42278 Mtetra
.673 .756 .913 r
.84087 .42278 .84341 .42614 .84961 .42418 .84707 .4207 Mtetra
.667 .746 .91 r
.84707 .4207 .84961 .42418 .85583 .42225 .8533 .41873 Mtetra
.665 .744 .909 r
.8533 .41873 .85583 .42225 .86206 .42031 .85954 .41677 Mtetra
.664 .743 .908 r
.85954 .41677 .86206 .42031 .8683 .41839 .86579 .41483 Mtetra
.664 .742 .908 r
.86579 .41483 .8683 .41839 .87456 .41646 .87206 .41289 Mtetra
.664 .741 .908 r
.87206 .41289 .87456 .41646 .88084 .41453 .87834 .41095 Mtetra
.87834 .41095 .88084 .41453 .88712 .41259 .88464 .40901 Mtetra
.88464 .40901 .88712 .41259 .89342 .41065 .89095 .40706 Mtetra
.89095 .40706 .89342 .41065 .89973 .40871 .89727 .40511 Mtetra
.89727 .40511 .89973 .40871 .90606 .40676 .90361 .40315 Mtetra
.90361 .40315 .90606 .40676 .9124 .40481 .90996 .40119 Mtetra
.90996 .40119 .9124 .40481 .91876 .40285 .91632 .39923 Mtetra
.91632 .39923 .91876 .40285 .92512 .40089 .9227 .39726 Mtetra
.9227 .39726 .92512 .40089 .9315 .39893 .92909 .39529 Mtetra
.92909 .39529 .9315 .39893 .9379 .39696 .93549 .39331 Mtetra
.93549 .39331 .9379 .39696 .94431 .39498 .94191 .39133 Mtetra
.36425 .56566 .36746 .56865 .37271 .56703 .3695 .56403 Mtetra
.3695 .56403 .37271 .56703 .37796 .56541 .37476 .5624 Mtetra
.37476 .5624 .37796 .56541 .38323 .56378 .38003 .56077 Mtetra
.38003 .56077 .38323 .56378 .3885 .56215 .38531 .55914 Mtetra
.38531 .55914 .3885 .56215 .39379 .56052 .39061 .5575 Mtetra
.39061 .5575 .39379 .56052 .39908 .55889 .39591 .55586 Mtetra
.39591 .55586 .39908 .55889 .40439 .55725 .40122 .55422 Mtetra
.40122 .55422 .40439 .55725 .40971 .55561 .40655 .55257 Mtetra
.40655 .55257 .40971 .55561 .41503 .55396 .41188 .55092 Mtetra
.41188 .55092 .41503 .55396 .42037 .55232 .41723 .54926 Mtetra
.663 .741 .908 r
.41723 .54926 .42037 .55232 .42572 .55066 .42258 .54761 Mtetra
.42258 .54761 .42572 .55066 .43108 .54901 .42795 .54596 Mtetra
.661 .742 .909 r
.42795 .54596 .43108 .54901 .43645 .54737 .43332 .54433 Mtetra
.659 .742 .911 r
.43332 .54433 .43645 .54737 .44183 .54574 .43871 .54272 Mtetra
.651 .742 .916 r
.43871 .54272 .44183 .54574 .44722 .54412 .4441 .54123 Mtetra
.62 .741 .933 r
.4441 .54123 .44722 .54412 .45262 .54262 .4495 .5401 Mtetra
.526 .737 .971 r
.4495 .5401 .45262 .54262 .45802 .54144 .45489 .53972 Mtetra
.184 .632 .942 r
.45489 .53972 .45802 .54144 .46343 .54089 .46028 .5406 Mtetra
.585 .015 0 r
.46028 .5406 .46343 .54089 .46883 .54133 .46564 .54376 Mtetra
.785 .385 .296 r
.46564 .54376 .46883 .54133 .47422 .54371 .47096 .55128 Mtetra
.792 .47 .444 r
.47096 .55128 .47422 .54371 .47959 .54985 .47623 .56526 Mtetra
.773 .484 .496 r
.47623 .56526 .47959 .54985 .48492 .56125 .48148 .5861 Mtetra
.756 .482 .519 r
.48148 .5861 .48492 .56125 .49026 .57821 .48673 .61332 Mtetra
.742 .477 .531 r
.48673 .61332 .49026 .57821 .49561 .60161 .49204 .64636 Mtetra
.717 .46 .536 r
.49204 .64636 .49561 .60161 .50101 .63211 .49747 .67928 Mtetra
.667 .417 .533 r
.49747 .67928 .50101 .63211 .50651 .66414 .50311 .6994 Mtetra
.557 .314 .503 r
.50311 .6994 .50651 .66414 .51217 .68845 .50893 .69912 Mtetra
.733 .751 .24 r
.50893 .69912 .51217 .68845 .51795 .70145 .51482 .67856 Mtetra
.827 .6 .595 r
.51482 .67856 .51795 .70145 .52379 .69839 .52069 .63755 Mtetra
.747 .519 .584 r
.52069 .63755 .52379 .69839 .52961 .67217 .52643 .58545 Mtetra
.695 .473 .581 r
.52643 .58545 .52961 .67217 .53531 .63014 .53203 .54103 Mtetra
.649 .436 .581 r
.53203 .54103 .53531 .63014 .54087 .58322 .53757 .51534 Mtetra
.568 .378 .583 r
.53757 .51534 .54087 .58322 .5463 .53833 .54318 .51578 Mtetra
.025 .03 .524 r
.54318 .51578 .5463 .53833 .55175 .51322 .54897 .53725 Mtetra
.706 .432 .507 r
.54897 .53725 .55175 .51322 .55739 .51399 .5548 .55385 Mtetra
.542 .307 .508 r
.5548 .55385 .55739 .51399 .56314 .52277 .5605 .55154 Mtetra
.47 .235 .474 r
.5605 .55154 .56314 .52277 .56884 .52403 .56616 .54453 Mtetra
.659 .381 .488 r
.56616 .54453 .56884 .52403 .57461 .52852 .57203 .55325 Mtetra
.539 .285 .479 r
.57203 .55325 .57461 .52852 .58058 .54318 .57779 .55194 Mtetra
.732 .756 .248 r
.57779 .55194 .58058 .54318 .58624 .53725 .58327 .53351 Mtetra
0 .212 .728 r
.58327 .53351 .58624 .53725 .592 .5364 .58915 .53841 Mtetra
.899 .977 .686 r
.58915 .53841 .592 .5364 .59797 .54449 .59478 .52964 Mtetra
.713 .543 .656 r
.59478 .52964 .59797 .54449 .60351 .5321 .60039 .52093 Mtetra
.52 .448 .715 r
.60039 .52093 .60351 .5321 .60948 .53808 .60625 .52274 Mtetra
.73 .551 .649 r
.60625 .52274 .60948 .53808 .61515 .53118 .61181 .51211 Mtetra
.545 .412 .651 r
.61181 .51211 .61515 .53118 .62098 .53006 .6177 .51388 Mtetra
.682 .516 .655 r
.6177 .51388 .62098 .53006 .62679 .52798 .62336 .50714 Mtetra
.579 .43 .643 r
.62336 .50714 .62679 .52798 .63258 .52488 .62922 .50691 Mtetra
.63 .475 .653 r
.62922 .50691 .63258 .52488 .63843 .52348 .63499 .50347 Mtetra
.596 .444 .646 r
.63499 .50347 .63843 .52348 .64429 .52175 .64084 .50209 Mtetra
.59 .441 .648 r
.64084 .50209 .64429 .52175 .65014 .51951 .64671 .50117 Mtetra
.616 .463 .652 r
.64671 .50117 .65014 .51951 .65608 .51933 .65255 .49866 Mtetra
.537 .402 .644 r
.65255 .49866 .65608 .51933 .66197 .51741 .65859 .50107 Mtetra
.653 .497 .659 r
.65859 .50107 .66197 .51741 .66788 .51569 .66436 .49643 Mtetra
.446 .345 .647 r
.66436 .49643 .66788 .51569 .67399 .51822 .67063 .50312 Mtetra
.668 .513 .665 r
.67063 .50312 .67399 .51822 .67961 .50945 .6764 .49782 Mtetra
.382 .356 .705 r
.6764 .49782 .67961 .50945 .68604 .51793 .68268 .50342 Mtetra
.459 .38 .681 r
.68268 .50342 .68604 .51793 .69151 .50605 .68896 .50807 Mtetra
.821 .964 .641 r
.68896 .50807 .69151 .50605 .69745 .50387 .69462 .50001 Mtetra
.841 .42 0 r
.69462 .50001 .69745 .50387 .70363 .50582 .70151 .5153 Mtetra
.42 .107 .325 r
.70151 .5153 .70363 .50582 .70869 .48717 .70747 .51227 Mtetra
.372 .152 .446 r
.70747 .51227 .70869 .48717 .71433 .47953 .71292 .50001 Mtetra
.607 .331 .473 r
.71292 .50001 .71433 .47953 .72012 .4745 .7193 .50413 Mtetra
.538 .292 .491 r
.7193 .50413 .72012 .4745 .72544 .46182 .72535 .50219 Mtetra
.362 .168 .477 r
.72535 .50219 .72544 .46182 .73131 .4582 .73022 .48107 Mtetra
.031 0 .337 r
.73022 .48107 .73131 .4582 .7389 .48106 .73478 .45613 Mtetra
.61 .441 .629 r
.73478 .45613 .7389 .48106 .74791 .52373 .74072 .45309 Mtetra
.452 .294 .575 r
.74072 .45309 .74791 .52373 .75721 .56791 .74846 .47652 Mtetra
.396 .249 .561 r
.74846 .47652 .75721 .56791 .76632 .60684 .75761 .51864 Mtetra
.348 .216 .555 r
.75761 .51864 .76632 .60684 .77444 .62969 .76747 .56834 Mtetra
.322 .206 .562 r
.76747 .56834 .77444 .62969 .78089 .62868 .7767 .60642 Mtetra
.258 .211 .613 r
.7767 .60642 .78089 .62868 .78611 .61117 .78448 .62312 Mtetra
.424 .133 .364 r
.78448 .62312 .78611 .61117 .79041 .58245 .79074 .61905 Mtetra
.297 .116 .458 r
.79074 .61905 .79041 .58245 .79401 .54608 .79538 .59444 Mtetra
.245 .09 .462 r
.79538 .59444 .79401 .54608 .79762 .51129 .7989 .55687 Mtetra
.222 .071 .454 r
.7989 .55687 .79762 .51129 .80173 .48388 .8023 .51933 Mtetra
.189 .038 .432 r
.8023 .51933 .80173 .48388 .80633 .46315 .8061 .48799 Mtetra
.127 0 .388 r
.8061 .48799 .80633 .46315 .81137 .44804 .81038 .46328 Mtetra
.03 0 .299 r
.81038 .46328 .81137 .44804 .81684 .43824 .81519 .44551 Mtetra
0 0 .066 r
.81519 .44551 .81684 .43824 .82265 .43225 .82056 .4343 Mtetra
.619 .874 .533 r
.82056 .4343 .82265 .43225 .82863 .42822 .82631 .42751 Mtetra
.793 .975 .909 r
.82631 .42751 .82863 .42822 .83472 .42519 .83227 .42303 Mtetra
.743 .865 .937 r
.83227 .42303 .83472 .42519 .84087 .42278 .83836 .41981 Mtetra
.697 .792 .923 r
.83836 .41981 .84087 .42278 .84707 .4207 .84454 .41733 Mtetra
.674 .757 .913 r
.84454 .41733 .84707 .4207 .8533 .41873 .85076 .41523 Mtetra
.667 .746 .91 r
.85076 .41523 .8533 .41873 .85954 .41677 .857 .41323 Mtetra
.665 .744 .909 r
.857 .41323 .85954 .41677 .86579 .41483 .86327 .41127 Mtetra
.664 .743 .908 r
.86327 .41127 .86579 .41483 .87206 .41289 .86954 .40931 Mtetra
.664 .742 .908 r
.86954 .40931 .87206 .41289 .87834 .41095 .87584 .40736 Mtetra
.664 .741 .908 r
.87584 .40736 .87834 .41095 .88464 .40901 .88214 .40541 Mtetra
.88214 .40541 .88464 .40901 .89095 .40706 .88846 .40345 Mtetra
.88846 .40345 .89095 .40706 .89727 .40511 .89479 .40149 Mtetra
.89479 .40149 .89727 .40511 .90361 .40315 .90114 .39953 Mtetra
.90114 .39953 .90361 .40315 .90996 .40119 .9075 .39756 Mtetra
.9075 .39756 .90996 .40119 .91632 .39923 .91387 .39559 Mtetra
.91387 .39559 .91632 .39923 .9227 .39726 .92026 .39361 Mtetra
.92026 .39361 .9227 .39726 .92909 .39529 .92666 .39163 Mtetra
.92666 .39163 .92909 .39529 .93549 .39331 .93308 .38965 Mtetra
.93308 .38965 .93549 .39331 .94191 .39133 .93951 .38766 Mtetra
.36103 .56265 .36425 .56566 .3695 .56403 .36628 .56102 Mtetra
.36628 .56102 .3695 .56403 .37476 .5624 .37155 .55939 Mtetra
.37155 .55939 .37476 .5624 .38003 .56077 .37683 .55775 Mtetra
.37683 .55775 .38003 .56077 .38531 .55914 .38212 .55611 Mtetra
.38212 .55611 .38531 .55914 .39061 .5575 .38741 .55447 Mtetra
.38741 .55447 .39061 .5575 .39591 .55586 .39272 .55282 Mtetra
.39272 .55282 .39591 .55586 .40122 .55422 .39804 .55117 Mtetra
.39804 .55117 .40122 .55422 .40655 .55257 .40337 .54952 Mtetra
.40337 .54952 .40655 .55257 .41188 .55092 .40871 .54786 Mtetra
.663 .741 .908 r
.40871 .54786 .41188 .55092 .41723 .54926 .41407 .5462 Mtetra
.41407 .5462 .41723 .54926 .42258 .54761 .41943 .54455 Mtetra
.661 .742 .909 r
.41943 .54455 .42258 .54761 .42795 .54596 .4248 .54292 Mtetra
.659 .742 .911 r
.4248 .54292 .42795 .54596 .43332 .54433 .43018 .54131 Mtetra
.65 .742 .916 r
.43018 .54131 .43332 .54433 .43871 .54272 .43557 .53982 Mtetra
.617 .74 .934 r
.43557 .53982 .43871 .54272 .4441 .54123 .44096 .53872 Mtetra
.508 .732 .974 r
.44096 .53872 .4441 .54123 .4495 .5401 .44635 .53847 Mtetra
.071 .566 .893 r
.44635 .53847 .4495 .5401 .45489 .53972 .45171 .53969 Mtetra
.666 .127 0 r
.45171 .53969 .45489 .53972 .46028 .5406 .45705 .54355 Mtetra
.797 .416 .335 r
.45705 .54355 .46028 .5406 .46564 .54376 .46232 .55231 Mtetra
.798 .485 .459 r
.46232 .55231 .46564 .54376 .47096 .55128 .46751 .56854 Mtetra
.779 .494 .504 r
.46751 .56854 .47096 .55128 .47623 .56526 .47265 .59289 Mtetra
.758 .488 .524 r
.47265 .59289 .47623 .56526 .48148 .5861 .47779 .62366 Mtetra
.739 .477 .533 r
.47779 .62366 .48148 .5861 .48673 .61332 .48301 .65817 Mtetra
.712 .455 .536 r
.48301 .65817 .48673 .61332 .49204 .64636 .48839 .68946 Mtetra
.645 .395 .527 r
.48839 .68946 .49204 .64636 .49747 .67928 .49404 .70329 Mtetra
.284 .067 .397 r
.49404 .70329 .49747 .67928 .50311 .6994 .49995 .68938 Mtetra
.889 .668 .596 r
.49995 .68938 .50311 .6994 .50893 .69912 .50597 .65183 Mtetra
.772 .543 .587 r
.50597 .65183 .50893 .69912 .51482 .67856 .51192 .60058 Mtetra
.72 .493 .582 r
.51192 .60058 .51482 .67856 .52069 .63755 .51773 .54934 Mtetra
.666 .449 .581 r
.51773 .54934 .52069 .63755 .52643 .58545 .52337 .51736 Mtetra
.584 .39 .584 r
.52337 .51736 .52643 .58545 .53203 .54103 .52896 .51431 Mtetra
.076 .052 .524 r
.52896 .51431 .53203 .54103 .53757 .51534 .53464 .53784 Mtetra
.795 .513 .511 r
.53464 .53784 .53757 .51534 .54318 .51578 .54046 .57319 Mtetra
.631 .389 .533 r
.54046 .57319 .54318 .51578 .54897 .53725 .54629 .58776 Mtetra
.429 .221 .493 r
.54629 .58776 .54897 .53725 .5548 .55385 .55193 .57037 Mtetra
0 0 .051 r
.55193 .57037 .5548 .55385 .5605 .55154 .55747 .5461 Mtetra
.801 .69 .743 r
.55747 .5461 .5605 .55154 .56616 .54453 .56313 .53891 Mtetra
.584 .597 .831 r
.56313 .53891 .56616 .54453 .57203 .55325 .56888 .53854 Mtetra
.795 .595 .63 r
.56888 .53854 .57203 .55325 .57779 .55194 .57437 .51999 Mtetra
.634 .447 .613 r
.57437 .51999 .57779 .55194 .58327 .53351 .58001 .51309 Mtetra
.568 .423 .644 r
.58001 .51309 .58327 .53351 .58915 .53841 .58578 .51356 Mtetra
.691 .498 .622 r
.58578 .51356 .58915 .53841 .59478 .52964 .59133 .50178 Mtetra
.541 .386 .62 r
.59133 .50178 .59478 .52964 .60039 .52093 .59716 .50446 Mtetra
.675 .51 .654 r
.59716 .50446 .60039 .52093 .60625 .52274 .60281 .49816 Mtetra
.581 .421 .63 r
.60281 .49816 .60625 .52274 .61181 .51211 .60861 .49766 Mtetra
.622 .486 .675 r
.60861 .49766 .61181 .51211 .6177 .51388 .61437 .49538 Mtetra
.61 .458 .651 r
.61437 .49538 .6177 .51388 .62336 .50714 .62015 .49324 Mtetra
.604 .477 .681 r
.62015 .49324 .62336 .50714 .62922 .50691 .62596 .49199 Mtetra
.617 .48 .672 r
.62596 .49199 .62922 .50691 .63499 .50347 .63177 .48989 Mtetra
.616 .488 .683 r
.63177 .48989 .63499 .50347 .64084 .50209 .63759 .48807 Mtetra
.607 .479 .68 r
.63759 .48807 .64084 .50209 .64671 .50117 .64344 .48664 Mtetra
.625 .488 .674 r
.64344 .48664 .64671 .50117 .65255 .49866 .64926 .48416 Mtetra
.601 .472 .677 r
.64926 .48416 .65255 .49866 .65859 .50107 .65514 .48295 Mtetra
.603 .456 .654 r
.65514 .48295 .65859 .50107 .66436 .49643 .66102 .48129 Mtetra
.626 .485 .67 r
.66102 .48129 .66436 .49643 .67063 .50312 .66687 .47867 Mtetra
.544 .396 .631 r
.66687 .47867 .67063 .50312 .6764 .49782 .67295 .48094 Mtetra
.667 .503 .654 r
.67295 .48094 .6764 .49782 .68268 .50342 .67868 .47506 Mtetra
.469 .336 .616 r
.67868 .47506 .68268 .50342 .68896 .50807 .68509 .48327 Mtetra
.623 .451 .628 r
.68509 .48327 .68896 .50807 .69462 .50001 .69091 .47897 Mtetra
.51 .383 .643 r
.69091 .47897 .69462 .50001 .70151 .5153 .69718 .48295 Mtetra
.391 .275 .6 r
.69718 .48295 .70151 .5153 .70747 .51227 .70407 .49801 Mtetra
.649 .506 .675 r
.70407 .49801 .70747 .51227 .71292 .50001 .70999 .49422 Mtetra
.213 .381 .815 r
.70999 .49422 .71292 .50001 .7193 .50413 .71639 .49868 Mtetra
.865 .483 0 r
.71639 .49868 .7193 .50413 .72535 .50219 .72384 .52018 Mtetra
.704 .407 .47 r
.72384 .52018 .72535 .50219 .73022 .48107 .73086 .53315 Mtetra
.43 .227 .502 r
.73086 .53315 .73022 .48107 .73478 .45613 .73591 .51371 Mtetra
.28 .118 .474 r
.73591 .51371 .73478 .45613 .74072 .45309 .73959 .47409 Mtetra
0 0 .283 r
.73959 .47409 .74072 .45309 .74846 .47652 .74399 .44727 Mtetra
.568 .404 .62 r
.74399 .44727 .74846 .47652 .75761 .51864 .75021 .44783 Mtetra
.413 .266 .57 r
.75021 .44783 .75761 .51864 .76747 .56834 .75852 .47775 Mtetra
.357 .221 .555 r
.75852 .47775 .76747 .56834 .7767 .60642 .76838 .52706 Mtetra
.324 .201 .554 r
.76838 .52706 .7767 .60642 .78448 .62312 .7784 .5758 Mtetra
.271 .179 .563 r
.7784 .5758 .78448 .62312 .79074 .61905 .78751 .60994 Mtetra
.061 .193 .689 r
.78751 .60994 .79074 .61905 .79538 .59444 .79487 .6198 Mtetra
.266 .073 .422 r
.79487 .6198 .79538 .59444 .7989 .55687 .80002 .60139 Mtetra
.225 .071 .452 r
.80002 .60139 .7989 .55687 .8023 .51933 .80366 .5652 Mtetra
.204 .058 .45 r
.80366 .5652 .8023 .51933 .8061 .48799 .80693 .52601 Mtetra
.168 .026 .43 r
.80693 .52601 .8061 .48799 .81038 .46328 .81042 .49098 Mtetra
.112 0 .392 r
.81042 .49098 .81038 .46328 .81519 .44551 .81439 .46264 Mtetra
.026 0 .314 r
.81439 .46264 .81519 .44551 .82056 .4343 .81901 .44255 Mtetra
0 0 .106 r
.81901 .44255 .82056 .4343 .82631 .42751 .82427 .43006 Mtetra
.586 .827 .449 r
.82427 .43006 .82631 .42751 .83227 .42303 .82998 .42255 Mtetra
.802 .987 .888 r
.82998 .42255 .83227 .42303 .83836 .41981 .83593 .41772 Mtetra
.75 .874 .936 r
.83593 .41772 .83836 .41981 .84454 .41733 .84203 .41436 Mtetra
.699 .793 .923 r
.84203 .41436 .84454 .41733 .85076 .41523 .84822 .41184 Mtetra
.675 .757 .913 r
.84822 .41184 .85076 .41523 .857 .41323 .85447 .40971 Mtetra
.667 .746 .91 r
.85447 .40971 .857 .41323 .86327 .41127 .86073 .4077 Mtetra
.665 .744 .909 r
.86073 .4077 .86327 .41127 .86954 .40931 .86702 .40573 Mtetra
.664 .742 .908 r
.86702 .40573 .86954 .40931 .87584 .40736 .87332 .40376 Mtetra
.87332 .40376 .87584 .40736 .88214 .40541 .87964 .4018 Mtetra
.664 .741 .908 r
.87964 .4018 .88214 .40541 .88846 .40345 .88597 .39983 Mtetra
.88597 .39983 .88846 .40345 .89479 .40149 .89231 .39787 Mtetra
.89231 .39787 .89479 .40149 .90114 .39953 .89867 .39589 Mtetra
.89867 .39589 .90114 .39953 .9075 .39756 .90504 .39392 Mtetra
.90504 .39392 .9075 .39756 .91387 .39559 .91142 .39194 Mtetra
.91142 .39194 .91387 .39559 .92026 .39361 .91782 .38995 Mtetra
.91782 .38995 .92026 .39361 .92666 .39163 .92423 .38796 Mtetra
.92423 .38796 .92666 .39163 .93308 .38965 .93066 .38597 Mtetra
.93066 .38597 .93308 .38965 .93951 .38766 .9371 .38397 Mtetra
.35779 .55964 .36103 .56265 .36628 .56102 .36305 .55801 Mtetra
.36305 .55801 .36628 .56102 .37155 .55939 .36833 .55637 Mtetra
.36833 .55637 .37155 .55939 .37683 .55775 .37361 .55472 Mtetra
.37361 .55472 .37683 .55775 .38212 .55611 .37891 .55308 Mtetra
.37891 .55308 .38212 .55611 .38741 .55447 .38421 .55143 Mtetra
.38421 .55143 .38741 .55447 .39272 .55282 .38953 .54977 Mtetra
.38953 .54977 .39272 .55282 .39804 .55117 .39485 .54812 Mtetra
.39485 .54812 .39804 .55117 .40337 .54952 .40019 .54646 Mtetra
.663 .741 .908 r
.40019 .54646 .40337 .54952 .40871 .54786 .40554 .5448 Mtetra
.40554 .5448 .40871 .54786 .41407 .5462 .4109 .54314 Mtetra
.662 .742 .909 r
.4109 .54314 .41407 .5462 .41943 .54455 .41626 .5415 Mtetra
.659 .742 .911 r
.41626 .5415 .41943 .54455 .4248 .54292 .42164 .53989 Mtetra
.65 .741 .916 r
.42164 .53989 .4248 .54292 .43018 .54131 .42703 .53839 Mtetra
.616 .74 .934 r
.42703 .53839 .43018 .54131 .43557 .53982 .43241 .5373 Mtetra
.501 .728 .975 r
.43241 .5373 .43557 .53982 .44096 .53872 .43779 .5371 Mtetra
.008 .522 .86 r
.43779 .5371 .44096 .53872 .44635 .53847 .44314 .53853 Mtetra
.705 .187 0 r
.44314 .53853 .44635 .53847 .45171 .53969 .44844 .54292 Mtetra
.806 .436 .356 r
.44844 .54292 .45171 .53969 .45705 .54355 .45366 .55269 Mtetra
.804 .495 .467 r
.45366 .55269 .45705 .54355 .46232 .55231 .45877 .57076 Mtetra
.785 .503 .509 r
.45877 .57076 .46232 .55231 .46751 .56854 .46379 .59804 Mtetra
.762 .493 .526 r
.46379 .59804 .46751 .56854 .47265 .59289 .46881 .63188 Mtetra
.738 .476 .534 r
.46881 .63188 .47265 .59289 .47779 .62366 .47393 .6672 Mtetra
.704 .447 .534 r
.47393 .6672 .47779 .62366 .48301 .65817 .47928 .69524 Mtetra
.606 .357 .514 r
.47928 .69524 .48301 .65817 .48839 .68946 .48499 .70132 Mtetra
.864 .807 .321 r
.48499 .70132 .48839 .68946 .49404 .70329 .49105 .67493 Mtetra
.826 .594 .588 r
.49105 .67493 .49404 .70329 .49995 .68938 .49724 .62398 Mtetra
.747 .518 .583 r
.49724 .62398 .49995 .68938 .50597 .65183 .50331 .56782 Mtetra
.695 .473 .582 r
.50331 .56782 .50597 .65183 .51192 .60058 .50914 .52521 Mtetra
.619 .415 .583 r
.50914 .52521 .51192 .60058 .51773 .54934 .51476 .5125 Mtetra
.323 .212 .569 r
.51476 .5125 .51773 .54934 .52337 .51736 .52031 .5323 Mtetra
.838 .546 .495 r
.52031 .5323 .52337 .51736 .52896 .51431 .52596 .56968 Mtetra
.697 .444 .538 r
.52596 .56968 .52896 .51431 .53464 .53784 .53173 .60268 Mtetra
.564 .335 .527 r
.53173 .60268 .53464 .53784 .54046 .57319 .53751 .60293 Mtetra
0 0 .207 r
.53751 .60293 .54046 .57319 .54629 .58776 .54312 .56608 Mtetra
.825 .598 .595 r
.54312 .56608 .54629 .58776 .55193 .57037 .54861 .52862 Mtetra
.66 .458 .6 r
.54861 .52862 .55193 .57037 .55747 .5461 .5542 .51469 Mtetra
.578 .407 .613 r
.5542 .51469 .55747 .5461 .56313 .53891 .55989 .51412 Mtetra
.669 .483 .624 r
.55989 .51412 .56313 .53891 .56888 .53854 .5655 .50508 Mtetra
.616 .432 .61 r
.5655 .50508 .56888 .53854 .57437 .51999 .57116 .50011 Mtetra
.472 .358 .642 r
.57116 .50011 .57437 .51999 .58001 .51309 .57697 .50549 Mtetra
.763 .633 .716 r
.57697 .50549 .58001 .51309 .58578 .51356 .58261 .49846 Mtetra
.459 .373 .672 r
.58261 .49846 .58578 .51356 .59133 .50178 .58847 .50305 Mtetra
.042 0 0 r
.58847 .50305 .59133 .50178 .59716 .50446 .59423 .50196 Mtetra
.705 .807 .928 r
.59423 .50196 .59716 .50446 .60281 .49816 .59999 .49952 Mtetra
.628 .115 .006 r
.59999 .49952 .60281 .49816 .60861 .49766 .60589 .50282 Mtetra
.019 0 0 r
.60589 .50282 .60861 .49766 .61437 .49538 .6116 .49768 Mtetra
.595 .11 .072 r
.6116 .49768 .61437 .49538 .62015 .49324 .61753 .50022 Mtetra
.275 0 .192 r
.61753 .50022 .62015 .49324 .62596 .49199 .62329 .49615 Mtetra
.458 .029 .134 r
.62329 .49615 .62596 .49199 .63177 .48989 .62917 .4961 Mtetra
.376 .008 .206 r
.62917 .4961 .63177 .48989 .63759 .48807 .63501 .4939 Mtetra
.317 0 .162 r
.63501 .4939 .63759 .48807 .64344 .48664 .64084 .49111 Mtetra
.455 .035 .152 r
.64084 .49111 .64344 .48664 .64926 .48416 .64676 .49088 Mtetra
.141 0 .127 r
.64676 .49088 .64926 .48416 .65514 .48295 .6525 .48527 Mtetra
.492 0 0 r
.6525 .48527 .65514 .48295 .66102 .48129 .65852 .48648 Mtetra
0 0 0 r
.65852 .48648 .66102 .48129 .66687 .47867 .66421 .4796 Mtetra
.019 0 0 r
.66421 .4796 .66687 .47867 .67295 .48094 .67016 .47868 Mtetra
.734 .839 .929 r
.67016 .47868 .67295 .48094 .67868 .47506 .67604 .47572 Mtetra
.912 .98 .761 r
.67604 .47572 .67868 .47506 .68509 .48327 .68169 .46792 Mtetra
.5 .402 .674 r
.68169 .46792 .68509 .48327 .69091 .47897 .68788 .47122 Mtetra
.796 .649 .7 r
.68788 .47122 .69091 .47897 .69718 .48295 .69347 .46205 Mtetra
.544 .406 .644 r
.69347 .46205 .69718 .48295 .70407 .49801 .69963 .46398 Mtetra
.52 .363 .609 r
.69963 .46398 .70407 .49801 .70999 .49422 .706 .46928 Mtetra
.611 .442 .628 r
.706 .46928 .70999 .49422 .71639 .49868 .71193 .46609 Mtetra
.442 .311 .606 r
.71193 .46609 .71639 .49868 .72384 .52018 .71873 .47765 Mtetra
.198 .127 .545 r
.71873 .47765 .72384 .52018 .73086 .53315 .72701 .51257 Mtetra
0 0 .397 r
.72701 .51257 .73086 .53315 .73591 .51371 .73533 .54562 Mtetra
.506 .268 .488 r
.73533 .54562 .73591 .51371 .73959 .47409 .74133 .5405 Mtetra
.34 .165 .493 r
.74133 .5405 .73959 .47409 .74399 .44727 .74515 .50244 Mtetra
.245 .091 .464 r
.74515 .50244 .74399 .44727 .75021 .44783 .74862 .46095 Mtetra
0 0 .095 r
.74862 .46095 .75021 .44783 .75852 .47775 .75326 .43818 Mtetra
.479 .329 .6 r
.75326 .43818 .75852 .47775 .76838 .52706 .76024 .44879 Mtetra
.367 .231 .561 r
.76024 .44879 .76838 .52706 .7784 .5758 .76951 .48968 Mtetra
.316 .193 .55 r
.76951 .48968 .7784 .5758 .78751 .60994 .77996 .54376 Mtetra
.267 .165 .548 r
.77996 .54376 .78751 .60994 .79487 .6198 .79017 .59184 Mtetra
.224 .172 .586 r
.79017 .59184 .79487 .6198 .80002 .60139 .79857 .61453 Mtetra
.212 0 .32 r
.79857 .61453 .80002 .60139 .80366 .5652 .80435 .60383 Mtetra
.199 .047 .437 r
.80435 .60383 .80366 .5652 .80693 .52601 .80824 .5707 Mtetra
.179 .039 .441 r
.80824 .5707 .80693 .52601 .81042 .49098 .81143 .53053 Mtetra
.142 .008 .425 r
.81143 .53053 .81042 .49098 .81439 .46264 .81464 .49229 Mtetra
.091 0 .391 r
.81464 .49229 .81439 .46264 .81901 .44255 .81834 .4609 Mtetra
.012 0 .318 r
.81834 .4609 .81901 .44255 .82427 .43006 .8228 .4389 Mtetra
0 0 .12 r
.8228 .4389 .82427 .43006 .82998 .42255 .82798 .42537 Mtetra
.582 .807 .411 r
.82798 .42537 .82998 .42255 .83593 .41772 .83365 .41733 Mtetra
.81 .991 .876 r
.83365 .41733 .83593 .41772 .84203 .41436 .8396 .41226 Mtetra
.754 .876 .935 r
.8396 .41226 .84203 .41436 .84822 .41184 .84572 .40883 Mtetra
.7 .793 .923 r
.84572 .40883 .84822 .41184 .85447 .40971 .85193 .40629 Mtetra
.675 .757 .913 r
.85193 .40629 .85447 .40971 .86073 .4077 .8582 .40415 Mtetra
.667 .746 .909 r
.8582 .40415 .86073 .4077 .86702 .40573 .86449 .40214 Mtetra
.665 .743 .909 r
.86449 .40214 .86702 .40573 .87332 .40376 .8708 .40015 Mtetra
.664 .742 .908 r
.8708 .40015 .87332 .40376 .87964 .4018 .87712 .39817 Mtetra
.87712 .39817 .87964 .4018 .88597 .39983 .88346 .3962 Mtetra
.664 .741 .908 r
.88346 .3962 .88597 .39983 .89231 .39787 .88981 .39422 Mtetra
.88981 .39422 .89231 .39787 .89867 .39589 .89618 .39224 Mtetra
.89618 .39224 .89867 .39589 .90504 .39392 .90256 .39026 Mtetra
.90256 .39026 .90504 .39392 .91142 .39194 .90896 .38827 Mtetra
.90896 .38827 .91142 .39194 .91782 .38995 .91536 .38628 Mtetra
.91536 .38628 .91782 .38995 .92423 .38796 .92179 .38428 Mtetra
.92179 .38428 .92423 .38796 .93066 .38597 .92822 .38228 Mtetra
.92822 .38228 .93066 .38597 .9371 .38397 .93467 .38027 Mtetra
.35454 .55662 .35779 .55964 .36305 .55801 .35981 .55498 Mtetra
.35981 .55498 .36305 .55801 .36833 .55637 .36509 .55333 Mtetra
.36509 .55333 .36833 .55637 .37361 .55472 .37038 .55168 Mtetra
.37038 .55168 .37361 .55472 .37891 .55308 .37568 .55003 Mtetra
.37568 .55003 .37891 .55308 .38421 .55143 .381 .54837 Mtetra
.381 .54837 .38421 .55143 .38953 .54977 .38632 .54671 Mtetra
.38632 .54671 .38953 .54977 .39485 .54812 .39165 .54505 Mtetra
.663 .741 .908 r
.39165 .54505 .39485 .54812 .40019 .54646 .39699 .54339 Mtetra
.39699 .54339 .40019 .54646 .40554 .5448 .40235 .54173 Mtetra
.662 .742 .909 r
.40235 .54173 .40554 .5448 .4109 .54314 .40771 .54008 Mtetra
.66 .742 .91 r
.40771 .54008 .4109 .54314 .41626 .5415 .41309 .53845 Mtetra
.651 .741 .915 r
.41309 .53845 .41626 .5415 .42164 .53989 .41847 .53695 Mtetra
.618 .739 .933 r
.41847 .53695 .42164 .53989 .42703 .53839 .42385 .53583 Mtetra
.505 .728 .973 r
.42385 .53583 .42703 .53839 .43241 .5373 .42922 .53562 Mtetra
.005 .516 .86 r
.42922 .53562 .43241 .5373 .43779 .5371 .43455 .5371 Mtetra
.72 .208 .005 r
.43455 .5371 .43779 .5371 .44314 .53853 .43983 .54176 Mtetra
.814 .448 .364 r
.43983 .54176 .44314 .53853 .44844 .54292 .445 .55221 Mtetra
.81 .503 .471 r
.445 .55221 .44844 .54292 .45366 .55269 .45003 .57164 Mtetra
.791 .509 .511 r
.45003 .57164 .45366 .55269 .45877 .57076 .45492 .60117 Mtetra
.766 .498 .528 r
.45492 .60117 .45877 .57076 .46379 .59804 .45981 .63752 Mtetra
.738 .477 .534 r
.45981 .63752 .46379 .59804 .46881 .63188 .46483 .67337 Mtetra
.694 .438 .531 r
.46483 .67337 .46881 .63188 .47393 .6672 .47017 .69773 Mtetra
.535 .288 .488 r
.47017 .69773 .47393 .6672 .47928 .69524 .47597 .69576 Mtetra
.965 .756 .573 r
.47597 .69576 .47928 .69524 .48499 .70132 .48222 .65872 Mtetra
.8 .566 .584 r
.48222 .65872 .48499 .70132 .49105 .67493 .4886 .59889 Mtetra
.731 .503 .582 r
.4886 .59889 .49105 .67493 .49724 .62398 .49476 .54299 Mtetra
.667 .451 .583 r
.49476 .54299 .49724 .62398 .50331 .56782 .50057 .51337 Mtetra
.516 .342 .583 r
.50057 .51337 .50331 .56782 .50914 .52521 .50608 .52141 Mtetra
.959 .639 .373 r
.50608 .52141 .50914 .52521 .51476 .5125 .51151 .55964 Mtetra
.731 .471 .535 r
.51151 .55964 .51476 .5125 .52031 .5323 .51709 .59931 Mtetra
.621 .383 .536 r
.51709 .59931 .52031 .5323 .52596 .56968 .52284 .61363 Mtetra
.332 .137 .458 r
.52284 .61363 .52596 .56968 .53173 .60268 .52861 .59097 Mtetra
.898 .664 .576 r
.52861 .59097 .53173 .60268 .53751 .60293 .53425 .5424 Mtetra
.71 .488 .586 r
.53425 .5424 .53751 .60293 .54312 .56608 .53979 .5064 Mtetra
.596 .401 .587 r
.53979 .5064 .54312 .56608 .54861 .52862 .54543 .5013 Mtetra
.491 .35 .617 r
.54543 .5013 .54861 .52862 .5542 .51469 .55115 .50728 Mtetra
.667 .589 .758 r
.55115 .50728 .5542 .51469 .55989 .51412 .55683 .50469 Mtetra
.574 .502 .737 r
.55683 .50469 .55989 .51412 .5655 .50508 .56255 .50471 Mtetra
.874 .451 .201 r
.56255 .50471 .5655 .50508 .57116 .50011 .56843 .51644 Mtetra
.394 .134 .397 r
.56843 .51644 .57116 .50011 .57697 .50549 .57411 .51008 Mtetra
.435 .019 .149 r
.57411 .51008 .57697 .50549 .58261 .49846 .57988 .50954 Mtetra
.672 .355 .428 r
.57988 .50954 .58261 .49846 .58847 .50305 .5858 .51604 Mtetra
.121 0 .265 r
.5858 .51604 .58847 .50305 .59423 .50196 .59141 .50508 Mtetra
.736 .316 .25 r
.59141 .50508 .59423 .50196 .59999 .49952 .59737 .51118 Mtetra
.277 .004 .306 r
.59737 .51118 .59999 .49952 .60589 .50282 .60306 .50415 Mtetra
.29 0 0 r
.60306 .50415 .60589 .50282 .6116 .49768 .60892 .5043 Mtetra
.354 0 .21 r
.60892 .5043 .6116 .49768 .61753 .50022 .61473 .5016 Mtetra
0 0 0 r
.61473 .5016 .61753 .50022 .62329 .49615 .62056 .49942 Mtetra
.238 0 0 r
.62056 .49942 .62329 .49615 .62917 .4961 .62641 .49768 Mtetra
0 0 0 r
.62641 .49768 .62917 .4961 .63501 .4939 .63228 .496 Mtetra
.007 0 0 r
.63228 .496 .63501 .4939 .64084 .49111 .63815 .49384 Mtetra
.281 0 0 r
.63815 .49384 .64084 .49111 .64676 .49088 .64407 .49284 Mtetra
.107 0 0 r
.64407 .49284 .64676 .49088 .6525 .48527 .64999 .49136 Mtetra
.312 0 .171 r
.64999 .49136 .6525 .48527 .65852 .48648 .65585 .48833 Mtetra
.584 .074 .006 r
.65585 .48833 .65852 .48648 .66421 .4796 .66197 .49096 Mtetra
.179 0 .272 r
.66197 .49096 .66421 .4796 .67016 .47868 .6676 .48189 Mtetra
.754 .332 .247 r
.6676 .48189 .67016 .47868 .67604 .47572 .67395 .48899 Mtetra
.194 0 .308 r
.67395 .48899 .67604 .47572 .68169 .46792 .67952 .4786 Mtetra
.452 .146 .354 r
.67952 .4786 .68169 .46792 .68788 .47122 .68546 .47604 Mtetra
.595 .186 .237 r
.68546 .47604 .68788 .47122 .69347 .46205 .69166 .47841 Mtetra
.093 0 .309 r
.69166 .47841 .69347 .46205 .69963 .46398 .69694 .46274 Mtetra
.728 .921 .958 r
.69694 .46274 .69963 .46398 .706 .46928 .70286 .45961 Mtetra
.614 .526 .732 r
.70286 .45961 .706 .46928 .71193 .46609 .7089 .45832 Mtetra
.805 .654 .695 r
.7089 .45832 .71193 .46609 .71873 .47765 .71445 .44846 Mtetra
.544 .387 .619 r
.71445 .44846 .71873 .47765 .72701 .51257 .72072 .45098 Mtetra
.348 .221 .562 r
.72072 .45098 .72701 .51257 .73533 .54562 .72896 .48486 Mtetra
.239 .144 .54 r
.72896 .48486 .73533 .54562 .74133 .5405 .7381 .53057 Mtetra
0 0 .422 r
.7381 .53057 .74133 .5405 .74515 .50244 .74564 .5488 Mtetra
.406 .204 .491 r
.74564 .5488 .74515 .50244 .74862 .46095 .75071 .5291 Mtetra
.299 .136 .485 r
.75071 .5291 .74862 .46095 .75326 .43818 .754 .48457 Mtetra
.157 .021 .432 r
.754 .48457 .75326 .43818 .76024 .44879 .75733 .44264 Mtetra
.844 .699 .703 r
.75733 .44264 .76024 .44879 .76951 .48968 .76282 .43216 Mtetra
.385 .251 .573 r
.76282 .43216 .76951 .48968 .77996 .54376 .77117 .46011 Mtetra
.305 .186 .548 r
.77117 .46011 .77996 .54376 .79017 .59184 .78168 .51431 Mtetra
.258 .154 .541 r
.78168 .51431 .79017 .59184 .79857 .61453 .79267 .57183 Mtetra
.236 .158 .561 r
.79267 .57183 .79857 .61453 .80435 .60383 .80198 .60549 Mtetra
0 0 0 r
.80198 .60549 .80435 .60383 .80824 .5707 .80844 .60285 Mtetra
.163 .011 .414 r
.80844 .60285 .80824 .5707 .81143 .53053 .81263 .57326 Mtetra
.146 .013 .429 r
.81263 .57326 .81143 .53053 .81464 .49229 .81574 .5324 Mtetra
.112 0 .416 r
.81574 .5324 .81464 .49229 .81834 .4609 .81872 .49151 Mtetra
.066 0 .385 r
.81872 .49151 .81834 .4609 .8228 .4389 .8222 .45777 Mtetra
0 0 .313 r
.8222 .45777 .8228 .4389 .82798 .42537 .82653 .43437 Mtetra
0 0 .114 r
.82653 .43437 .82798 .42537 .83365 .41733 .83166 .42013 Mtetra
.607 .819 .418 r
.83166 .42013 .83365 .41733 .8396 .41226 .83732 .41179 Mtetra
.817 .989 .877 r
.83732 .41179 .8396 .41226 .84572 .40883 .84328 .40666 Mtetra
.753 .871 .933 r
.84328 .40666 .84572 .40883 .85193 .40629 .84942 .40323 Mtetra
.698 .79 .922 r
.84942 .40323 .85193 .40629 .8582 .40415 .85566 .40069 Mtetra
.674 .756 .912 r
.85566 .40069 .8582 .40415 .86449 .40214 .86195 .39855 Mtetra
.666 .745 .909 r
.86195 .39855 .86449 .40214 .8708 .40015 .86826 .39653 Mtetra
.665 .743 .908 r
.86826 .39653 .8708 .40015 .87712 .39817 .8746 .39454 Mtetra
.664 .742 .908 r
.8746 .39454 .87712 .39817 .88346 .3962 .88095 .39255 Mtetra
.88095 .39255 .88346 .3962 .88981 .39422 .88731 .39056 Mtetra
.664 .741 .908 r
.88731 .39056 .88981 .39422 .89618 .39224 .89369 .38858 Mtetra
.89369 .38858 .89618 .39224 .90256 .39026 .90008 .38658 Mtetra
.90008 .38658 .90256 .39026 .90896 .38827 .90648 .38459 Mtetra
.90648 .38459 .90896 .38827 .91536 .38628 .9129 .38259 Mtetra
.9129 .38259 .91536 .38628 .92179 .38428 .91933 .38058 Mtetra
.91933 .38058 .92179 .38428 .92822 .38228 .92578 .37857 Mtetra
.92578 .37857 .92822 .38228 .93467 .38027 .93224 .37656 Mtetra
.35128 .55358 .35454 .55662 .35981 .55498 .35656 .55193 Mtetra
.35656 .55193 .35981 .55498 .36509 .55333 .36185 .55028 Mtetra
.36185 .55028 .36509 .55333 .37038 .55168 .36714 .54863 Mtetra
.36714 .54863 .37038 .55168 .37568 .55003 .37245 .54697 Mtetra
.37245 .54697 .37568 .55003 .381 .54837 .37777 .54531 Mtetra
.37777 .54531 .381 .54837 .38632 .54671 .3831 .54364 Mtetra
.663 .741 .908 r
.3831 .54364 .38632 .54671 .39165 .54505 .38844 .54198 Mtetra
.38844 .54198 .39165 .54505 .39699 .54339 .39379 .54031 Mtetra
.663 .742 .909 r
.39379 .54031 .39699 .54339 .40235 .54173 .39915 .53865 Mtetra
.661 .741 .91 r
.39915 .53865 .40235 .54173 .40771 .54008 .40452 .53701 Mtetra
.652 .74 .914 r
.40452 .53701 .40771 .54008 .41309 .53845 .40989 .53549 Mtetra
.622 .739 .93 r
.40989 .53549 .41309 .53845 .41847 .53695 .41527 .53433 Mtetra
.52 .73 .969 r
.41527 .53433 .41847 .53695 .42385 .53583 .42063 .53402 Mtetra
.062 .548 .892 r
.42063 .53402 .42385 .53583 .42922 .53562 .42596 .5354 Mtetra
.717 .197 0 r
.42596 .5354 .42922 .53562 .43455 .5371 .43122 .54005 Mtetra
.821 .454 .362 r
.43122 .54005 .43455 .5371 .43983 .54176 .43635 .55078 Mtetra
.816 .51 .471 r
.43635 .55078 .43983 .54176 .445 .55221 .44129 .571 Mtetra
.797 .515 .511 r
.44129 .571 .445 .55221 .45003 .57164 .44607 .60207 Mtetra
.772 .503 .528 r
.44607 .60207 .45003 .57164 .45492 .60117 .45081 .64037 Mtetra
.741 .479 .534 r
.45081 .64037 .45492 .60117 .45981 .63752 .45573 .67682 Mtetra
.687 .429 .528 r
.45573 .67682 .45981 .63752 .46483 .67337 .46106 .69809 Mtetra
.4 .161 .433 r
.46106 .69809 .46483 .67337 .47017 .69773 .46698 .689 Mtetra
.906 .679 .584 r
.46698 .689 .47017 .69773 .47597 .69576 .47343 .64343 Mtetra
.787 .553 .582 r
.47343 .64343 .47597 .69576 .48222 .65872 .48 .5785 Mtetra
.718 .492 .582 r
.48 .5785 .48222 .65872 .4886 .59889 .48623 .52655 Mtetra
.63 .423 .584 r
.48623 .52655 .4886 .59889 .49476 .54299 .49193 .51142 Mtetra
.096 .053 .514 r
.49193 .51142 .49476 .54299 .50057 .51337 .49726 .53755 Mtetra
.82 .541 .517 r
.49726 .53755 .50057 .51337 .50608 .52141 .50256 .58599 Mtetra
.677 .43 .54 r
.50256 .58599 .50608 .52141 .51151 .55964 .50811 .61713 Mtetra
.485 .267 .507 r
.50811 .61713 .51151 .55964 .51709 .59931 .51392 .60517 Mtetra
.995 .787 .513 r
.51392 .60517 .51709 .59931 .52284 .61363 .51977 .56123 Mtetra
.751 .523 .585 r
.51977 .56123 .52284 .61363 .52861 .59097 .52548 .51492 Mtetra
.634 .425 .582 r
.52548 .51492 .52861 .59097 .53425 .5424 .5311 .4976 Mtetra
.446 .295 .582 r
.5311 .4976 .53425 .5424 .53979 .5064 .5368 .51153 Mtetra
.809 .457 .39 r
.5368 .51153 .53979 .5064 .54543 .5013 .54255 .5242 Mtetra
.471 .221 .453 r
.54255 .5242 .54543 .5013 .55115 .50728 .54824 .51908 Mtetra
.351 .065 .331 r
.54824 .51908 .55115 .50728 .55683 .50469 .55393 .51375 Mtetra
.739 .41 .425 r
.55393 .51375 .55683 .50469 .56255 .50471 .55978 .52394 Mtetra
.473 .212 .437 r
.55978 .52394 .56255 .50471 .56843 .51644 .56551 .51981 Mtetra
.958 .926 .583 r
.56551 .51981 .56843 .51644 .57411 .51008 .57111 .50608 Mtetra
0 0 .493 r
.57111 .50608 .57411 .51008 .57988 .50954 .57701 .51331 Mtetra
.837 .922 .532 r
.57701 .51331 .57988 .50954 .5858 .51604 .58264 .50265 Mtetra
.641 .505 .681 r
.58264 .50265 .5858 .51604 .59141 .50508 .58839 .49953 Mtetra
.573 .596 .838 r
.58839 .49953 .59141 .50508 .59737 .51118 .59422 .4993 Mtetra
.726 .568 .676 r
.59422 .4993 .59737 .51118 .60306 .50415 .59989 .4915 Mtetra
.524 .436 .698 r
.59989 .4915 .60306 .50415 .60892 .5043 .60578 .49334 Mtetra
.711 .567 .69 r
.60578 .49334 .60892 .5043 .61473 .5016 .61149 .48716 Mtetra
.567 .45 .68 r
.61149 .48716 .61473 .5016 .62056 .49942 .61738 .48751 Mtetra
.655 .525 .693 r
.61738 .48751 .62056 .49942 .62641 .49768 .62318 .48404 Mtetra
.607 .482 .684 r
.62318 .48404 .62641 .49768 .63228 .496 .62905 .4826 Mtetra
.595 .476 .687 r
.62905 .4826 .63228 .496 .63815 .49384 .63495 .48171 Mtetra
.65 .521 .692 r
.63495 .48171 .63815 .49384 .64407 .49284 .64078 .47842 Mtetra
.527 .425 .682 r
.64078 .47842 .64407 .49284 .64999 .49136 .64681 .48041 Mtetra
.692 .557 .696 r
.64681 .48041 .64999 .49136 .65585 .48833 .6526 .47534 Mtetra
.455 .389 .694 r
.6526 .47534 .65585 .48833 .66197 .49096 .65876 .47945 Mtetra
.661 .533 .697 r
.65876 .47945 .66197 .49096 .6676 .48189 .66462 .47581 Mtetra
.559 .573 .824 r
.66462 .47581 .6676 .48189 .67395 .48899 .67066 .47589 Mtetra
.369 .333 .687 r
.67066 .47589 .67395 .48899 .67952 .4786 .67701 .48242 Mtetra
.762 .874 .45 r
.67701 .48242 .67952 .4786 .68546 .47604 .68258 .47172 Mtetra
.641 .211 0 r
.68258 .47172 .68546 .47604 .69166 .47841 .68919 .48237 Mtetra
.438 0 .101 r
.68919 .48237 .69166 .47841 .69694 .46274 .69531 .48219 Mtetra
.242 .031 .38 r
.69531 .48219 .69694 .46274 .70286 .45961 .7007 .46822 Mtetra
.596 .252 .356 r
.7007 .46822 .70286 .45961 .7089 .45832 .70697 .47065 Mtetra
.56 .253 .404 r
.70697 .47065 .7089 .45832 .71445 .44846 .71319 .47163 Mtetra
.236 .04 .399 r
.71319 .47163 .71445 .44846 .72072 .45098 .71836 .45447 Mtetra
.954 .885 .488 r
.71836 .45447 .72072 .45098 .72896 .48486 .72349 .43738 Mtetra
.453 .303 .587 r
.72349 .43738 .72896 .48486 .7381 .53057 .73061 .4527 Mtetra
.338 .208 .553 r
.73061 .4527 .7381 .53057 .74564 .5488 .73968 .49692 Mtetra
.226 .14 .544 r
.73968 .49692 .74564 .5488 .75071 .5291 .74868 .53731 Mtetra
.693 .336 .366 r
.74868 .53731 .75071 .5291 .754 .48457 .75557 .54424 Mtetra
.319 .147 .484 r
.75557 .54424 .754 .48457 .75733 .44264 .75944 .50768 Mtetra
.211 .07 .461 r
.75944 .50768 .75733 .44264 .76282 .43216 .762 .45467 Mtetra
0 0 .294 r
.762 .45467 .76282 .43216 .77117 .46011 .76615 .42555 Mtetra
.429 .3 .602 r
.76615 .42555 .77117 .46011 .78168 .51431 .77345 .43896 Mtetra
.293 .179 .548 r
.77345 .43896 .78168 .51431 .79267 .57183 .78373 .48952 Mtetra
.244 .143 .536 r
.78373 .48952 .79267 .57183 .80198 .60549 .79522 .5526 Mtetra
.227 .144 .548 r
.79522 .5526 .80198 .60549 .80844 .60285 .8053 .59508 Mtetra
.337 .407 .787 r
.8053 .59508 .80844 .60285 .81263 .57326 .81238 .59959 Mtetra
.11 0 .381 r
.81238 .59959 .81263 .57326 .81574 .5324 .81682 .573 Mtetra
.106 0 .414 r
.81682 .573 .81574 .5324 .81872 .49151 .81985 .5314 Mtetra
.078 0 .405 r
.81985 .5314 .81872 .49151 .8222 .45777 .82263 .48843 Mtetra
.036 0 .376 r
.82263 .48843 .8222 .45777 .82653 .43437 .82595 .45306 Mtetra
0 0 .301 r
.82595 .45306 .82653 .43437 .83166 .42013 .8302 .42883 Mtetra
0 0 .089 r
.8302 .42883 .83166 .42013 .83732 .41179 .83531 .41429 Mtetra
.659 .858 .467 r
.83531 .41429 .83732 .41179 .84328 .40666 .84098 .40595 Mtetra
.821 .98 .888 r
.84098 .40595 .84328 .40666 .84942 .40323 .84698 .40091 Mtetra
.747 .86 .932 r
.84698 .40091 .84942 .40323 .85566 .40069 .85314 .39756 Mtetra
.696 .786 .92 r
.85314 .39756 .85566 .40069 .86195 .39855 .85941 .39505 Mtetra
.673 .754 .911 r
.85941 .39505 .86195 .39855 .86826 .39653 .86572 .39291 Mtetra
.666 .744 .909 r
.86572 .39291 .86826 .39653 .8746 .39454 .87206 .39089 Mtetra
.664 .742 .908 r
.87206 .39089 .8746 .39454 .88095 .39255 .87842 .38889 Mtetra
.87842 .38889 .88095 .39255 .88731 .39056 .88479 .38689 Mtetra
.88479 .38689 .88731 .39056 .89369 .38858 .89118 .3849 Mtetra
.664 .741 .908 r
.89118 .3849 .89369 .38858 .90008 .38658 .89758 .3829 Mtetra
.89758 .3829 .90008 .38658 .90648 .38459 .904 .38089 Mtetra
.904 .38089 .90648 .38459 .9129 .38259 .91042 .37888 Mtetra
.91042 .37888 .9129 .38259 .91933 .38058 .91687 .37687 Mtetra
.91687 .37687 .91933 .38058 .92578 .37857 .92332 .37485 Mtetra
.92332 .37485 .92578 .37857 .93224 .37656 .9298 .37283 Mtetra
.34801 .55054 .35128 .55358 .35656 .55193 .35329 .54888 Mtetra
.35329 .54888 .35656 .55193 .36185 .55028 .35859 .54722 Mtetra
.35859 .54722 .36185 .55028 .36714 .54863 .36389 .54556 Mtetra
.36389 .54556 .36714 .54863 .37245 .54697 .3692 .5439 Mtetra
.3692 .5439 .37245 .54697 .37777 .54531 .37453 .54223 Mtetra
.663 .741 .908 r
.37453 .54223 .37777 .54531 .3831 .54364 .37987 .54056 Mtetra
.37987 .54056 .3831 .54364 .38844 .54198 .38521 .53889 Mtetra
.38521 .53889 .38844 .54198 .39379 .54031 .39057 .53722 Mtetra
.661 .741 .909 r
.39057 .53722 .39379 .54031 .39915 .53865 .39593 .53557 Mtetra
.654 .74 .913 r
.39593 .53557 .39915 .53865 .40452 .53701 .40131 .53403 Mtetra
.628 .739 .928 r
.40131 .53403 .40452 .53701 .40989 .53549 .40668 .5328 Mtetra
.542 .733 .963 r
.40668 .5328 .40989 .53549 .41527 .53433 .41204 .53234 Mtetra
.167 .603 .937 r
.41204 .53234 .41527 .53433 .42063 .53402 .41736 .53346 Mtetra
.689 .149 0 r
.41736 .53346 .42063 .53402 .42596 .5354 .42261 .53782 Mtetra
.827 .454 .348 r
.42261 .53782 .42596 .5354 .43122 .54005 .4277 .54839 Mtetra
.823 .515 .468 r
.4277 .54839 .43122 .54005 .43635 .55078 .43258 .56878 Mtetra
.803 .521 .51 r
.43258 .56878 .43635 .55078 .44129 .571 .43725 .60065 Mtetra
.778 .508 .528 r
.43725 .60065 .44129 .571 .44607 .60207 .44185 .64038 Mtetra
.746 .483 .533 r
.44185 .64038 .44607 .60207 .45081 .64037 .44665 .67776 Mtetra
.683 .425 .525 r
.44665 .67776 .45081 .64037 .45573 .67682 .45196 .6973 Mtetra
.179 0 .332 r
.45196 .6973 .45573 .67682 .46106 .69809 .45799 .68296 Mtetra
.88 .648 .584 r
.45799 .68296 .46106 .69809 .46698 .689 .46465 .63102 Mtetra
.78 .546 .581 r
.46465 .63102 .46698 .689 .47343 .64343 .47141 .56336 Mtetra
.707 .483 .582 r
.47141 .56336 .47343 .64343 .48 .5785 .47766 .51689 Mtetra
.576 .384 .584 r
.47766 .51689 .48 .5785 .48623 .52655 .48321 .51539 Mtetra
.965 .658 .258 r
.48321 .51539 .48623 .52655 .49193 .51142 .48833 .55511 Mtetra
.764 .5 .535 r
.48833 .55511 .49193 .51142 .49726 .53755 .4935 .60507 Mtetra
.624 .385 .535 r
.4935 .60507 .49726 .53755 .50256 .58599 .49912 .62024 Mtetra
0 0 .273 r
.49912 .62024 .50256 .58599 .50811 .61713 .50511 .58418 Mtetra
.818 .583 .583 r
.50511 .58418 .50811 .61713 .51392 .60517 .51106 .53004 Mtetra
.676 .458 .583 r
.51106 .53004 .51392 .60517 .51977 .56123 .5168 .49911 Mtetra
.511 .334 .578 r
.5168 .49911 .51977 .56123 .52548 .51492 .52241 .50885 Mtetra
.962 .627 .28 r
.52241 .50885 .52548 .51492 .5311 .4976 .5281 .54025 Mtetra
.618 .37 .52 r
.5281 .54025 .5311 .4976 .5368 .51153 .53386 .54927 Mtetra
.318 .12 .446 r
.53386 .54927 .5368 .51153 .54255 .5242 .53953 .52907 Mtetra
.963 .897 .523 r
.53953 .52907 .54255 .5242 .54824 .51908 .54517 .51178 Mtetra
.473 .487 .791 r
.54517 .51178 .54824 .51908 .55393 .51375 .55092 .51356 Mtetra
.529 .911 .939 r
.55092 .51356 .55393 .51375 .55978 .52394 .55666 .51147 Mtetra
.8 .608 .642 r
.55666 .51147 .55978 .52394 .56551 .51981 .56224 .49526 Mtetra
.543 .393 .628 r
.56224 .49526 .56551 .51981 .57111 .50608 .56803 .49736 Mtetra
.674 .571 .732 r
.56803 .49736 .57111 .50608 .57701 .51331 .57376 .49408 Mtetra
.671 .497 .642 r
.57376 .49408 .57701 .51331 .58264 .50265 .57944 .487 Mtetra
.472 .378 .668 r
.57944 .487 .58264 .50265 .58839 .49953 .58532 .4912 Mtetra
.765 .624 .704 r
.58532 .4912 .58839 .49953 .59422 .4993 .59099 .48345 Mtetra
.503 .398 .669 r
.59099 .48345 .59422 .4993 .59989 .4915 .59689 .48656 Mtetra
.763 .698 .789 r
.59689 .48656 .59989 .4915 .60578 .49334 .60263 .48176 Mtetra
.563 .471 .708 r
.60263 .48176 .60578 .49334 .61149 .48716 .60851 .48215 Mtetra
.697 .672 .822 r
.60851 .48215 .61149 .48716 .61738 .48751 .61432 .4794 Mtetra
.615 .55 .759 r
.61432 .4794 .61738 .48751 .62318 .48404 .62018 .47825 Mtetra
.663 .632 .808 r
.62018 .47825 .62318 .48404 .62905 .4826 .62603 .47615 Mtetra
.652 .608 .792 r
.62603 .47615 .62905 .4826 .63495 .48171 .6319 .4742 Mtetra
.629 .571 .77 r
.6319 .4742 .63495 .48171 .64078 .47842 .63779 .47271 Mtetra
.711 .656 .794 r
.63779 .47271 .64078 .47842 .64681 .48041 .64363 .4693 Mtetra
.559 .474 .716 r
.64363 .4693 .64681 .48041 .6526 .47534 .64963 .46983 Mtetra
.786 .691 .759 r
.64963 .46983 .6526 .47534 .65876 .47945 .65538 .46362 Mtetra
.488 .39 .67 r
.65538 .46362 .65876 .47945 .66462 .47581 .66154 .46738 Mtetra
.766 .625 .705 r
.66154 .46738 .66462 .47581 .67066 .47589 .66723 .4596 Mtetra
.491 .39 .667 r
.66723 .4596 .67066 .47589 .67701 .48242 .67344 .46336 Mtetra
.586 .441 .651 r
.67344 .46336 .67701 .48242 .68258 .47172 .67946 .46256 Mtetra
.715 .59 .715 r
.67946 .46256 .68258 .47172 .68919 .48237 .68528 .45722 Mtetra
.36 .267 .612 r
.68528 .45722 .68919 .48237 .69531 .48219 .69203 .4702 Mtetra
.629 .51 .699 r
.69203 .4702 .69531 .48219 .7007 .46822 .69804 .46794 Mtetra
.824 .983 .881 r
.69804 .46794 .7007 .46822 .70697 .47065 .70392 .46286 Mtetra
0 0 .42 r
.70392 .46286 .70697 .47065 .71319 .47163 .71091 .47757 Mtetra
.829 .465 .368 r
.71091 .47757 .71319 .47163 .71836 .45447 .71805 .49362 Mtetra
.429 .215 .485 r
.71805 .49362 .71836 .45447 .72349 .43738 .72346 .47958 Mtetra
.181 .031 .429 r
.72346 .47958 .72349 .43738 .73061 .4527 .72751 .44407 Mtetra
.82 .65 .672 r
.72751 .44407 .73061 .4527 .73968 .49692 .73294 .43186 Mtetra
.395 .253 .568 r
.73294 .43186 .73968 .49692 .74868 .53731 .74107 .4611 Mtetra
.281 .168 .543 r
.74107 .4611 .74868 .53731 .75557 .54424 .75085 .51274 Mtetra
.086 .066 .535 r
.75085 .51274 .75557 .54424 .75944 .50768 .75946 .54457 Mtetra
.339 .144 .464 r
.75946 .54457 .75944 .50768 .762 .45467 .76445 .52371 Mtetra
.218 .077 .465 r
.76445 .52371 .762 .45467 .76615 .42555 .76685 .46835 Mtetra
.093 0 .409 r
.76685 .46835 .76615 .42555 .77345 .43896 .76996 .42506 Mtetra
.582 .466 .686 r
.76996 .42506 .77345 .43896 .78373 .48952 .77624 .42469 Mtetra
.278 .172 .55 r
.77624 .42469 .78373 .48952 .79522 .5526 .78617 .47002 Mtetra
.224 .129 .531 r
.78617 .47002 .79522 .5526 .8053 .59508 .798 .53619 Mtetra
.209 .128 .54 r
.798 .53619 .8053 .59508 .81238 .59959 .80868 .58528 Mtetra
.293 .281 .674 r
.80868 .58528 .81238 .59959 .81682 .573 .81623 .59507 Mtetra
.039 0 .339 r
.81623 .59507 .81682 .573 .81985 .5314 .82081 .5701 Mtetra
.06 0 .396 r
.82081 .5701 .81985 .5314 .82263 .48843 .82374 .52743 Mtetra
.04 0 .392 r
.82374 .52743 .82263 .48843 .82595 .45306 .82635 .48293 Mtetra
.001 0 .362 r
.82635 .48293 .82595 .45306 .8302 .42883 .82957 .44672 Mtetra
0 0 .281 r
.82957 .44672 .8302 .42883 .83531 .41429 .8338 .42229 Mtetra
0 0 .043 r
.8338 .42229 .83531 .41429 .84098 .40595 .83893 .4079 Mtetra
.727 .913 .551 r
.83893 .4079 .84098 .40595 .84698 .40091 .84464 .39983 Mtetra
.817 .96 .904 r
.84464 .39983 .84698 .40091 .85314 .39756 .85068 .39503 Mtetra
.738 .844 .929 r
.85068 .39503 .85314 .39756 .85941 .39505 .85689 .39183 Mtetra
.692 .78 .918 r
.85689 .39183 .85941 .39505 .86572 .39291 .86318 .38937 Mtetra
.672 .752 .911 r
.86318 .38937 .86572 .39291 .87206 .39089 .86952 .38724 Mtetra
.665 .743 .908 r
.86952 .38724 .87206 .39089 .87842 .38889 .87589 .38522 Mtetra
.664 .742 .908 r
.87589 .38522 .87842 .38889 .88479 .38689 .88227 .38321 Mtetra
.88227 .38321 .88479 .38689 .89118 .3849 .88867 .3812 Mtetra
.88867 .3812 .89118 .3849 .89758 .3829 .89508 .37919 Mtetra
.664 .741 .908 r
.89508 .37919 .89758 .3829 .904 .38089 .9015 .37718 Mtetra
.9015 .37718 .904 .38089 .91042 .37888 .90794 .37516 Mtetra
.90794 .37516 .91042 .37888 .91687 .37687 .91439 .37314 Mtetra
.91439 .37314 .91687 .37687 .92332 .37485 .92086 .37112 Mtetra
.92086 .37112 .92332 .37485 .9298 .37283 .92734 .36909 Mtetra
.34473 .54748 .34801 .55054 .35329 .54888 .35002 .54582 Mtetra
.35002 .54582 .35329 .54888 .35859 .54722 .35532 .54416 Mtetra
.35532 .54416 .35859 .54722 .36389 .54556 .36063 .54249 Mtetra
.36063 .54249 .36389 .54556 .3692 .5439 .36595 .54082 Mtetra
.663 .741 .908 r
.36595 .54082 .3692 .5439 .37453 .54223 .37128 .53915 Mtetra
.37128 .53915 .37453 .54223 .37987 .54056 .37662 .53747 Mtetra
.37662 .53747 .37987 .54056 .38521 .53889 .38197 .53579 Mtetra
.662 .741 .909 r
.38197 .53579 .38521 .53889 .39057 .53722 .38734 .53413 Mtetra
.655 .74 .912 r
.38734 .53413 .39057 .53722 .39593 .53557 .39271 .53256 Mtetra
.634 .74 .925 r
.39271 .53256 .39593 .53557 .40131 .53403 .39808 .53126 Mtetra
.569 .737 .955 r
.39808 .53126 .40131 .53403 .40668 .5328 .40344 .53059 Mtetra
.293 .658 .971 r
.40344 .53059 .40668 .5328 .41204 .53234 .40876 .53133 Mtetra
.615 .047 0 r
.40876 .53133 .41204 .53234 .41736 .53346 .414 .53517 Mtetra
.832 .446 .321 r
.414 .53517 .41736 .53346 .42261 .53782 .41908 .54514 Mtetra
.83 .517 .461 r
.41908 .54514 .42261 .53782 .4277 .54839 .42391 .56503 Mtetra
.81 .526 .508 r
.42391 .56503 .4277 .54839 .43258 .56878 .42848 .59689 Mtetra
.786 .515 .527 r
.42848 .59689 .43258 .56878 .43725 .60065 .43294 .63753 Mtetra
.754 .489 .533 r
.43294 .63753 .43725 .60065 .44185 .64038 .4376 .67635 Mtetra
.687 .427 .524 r
.4376 .67635 .44185 .64038 .44665 .67776 .44284 .69603 Mtetra
0 0 .222 r
.44284 .69603 .44665 .67776 .45196 .6973 .44896 .67893 Mtetra
.871 .637 .582 r
.44896 .67893 .45196 .6973 .45799 .68296 .45583 .62264 Mtetra
.779 .544 .581 r
.45583 .62264 .45799 .68296 .46465 .63102 .46278 .55324 Mtetra
.699 .477 .583 r
.46278 .55324 .46465 .63102 .47141 .56336 .46904 .51168 Mtetra
.497 .327 .581 r
.46904 .51168 .47141 .56336 .47766 .51689 .47442 .52136 Mtetra
.914 .615 .465 r
.47442 .52136 .47766 .51689 .48321 .51539 .47931 .57009 Mtetra
.73 .473 .539 r
.47931 .57009 .48321 .51539 .48833 .55511 .48443 .61549 Mtetra
.542 .314 .519 r
.48443 .61549 .48833 .55511 .4935 .60507 .49021 .61224 Mtetra
.993 .777 .507 r
.49021 .61224 .4935 .60507 .49912 .62024 .4964 .5596 Mtetra
.746 .517 .583 r
.4964 .5596 .49912 .62024 .50511 .58418 .50243 .50838 Mtetra
.598 .397 .58 r
.50243 .50838 .50511 .58418 .51106 .53004 .50809 .50085 Mtetra
0 0 .407 r
.50809 .50085 .51106 .53004 .5168 .49911 .5136 .53422 Mtetra
.748 .479 .525 r
.5136 .53422 .5168 .49911 .52241 .50885 .51923 .56914 Mtetra
.514 .291 .514 r
.51923 .56914 .52241 .50885 .5281 .54025 .52501 .56118 Mtetra
.727 .672 .123 r
.52501 .56118 .5281 .54025 .53386 .54927 .53071 .52141 Mtetra
.75 .536 .606 r
.53071 .52141 .53386 .54927 .53953 .52907 .53636 .4975 Mtetra
.56 .393 .611 r
.53636 .4975 .53953 .52907 .54517 .51178 .54207 .49842 Mtetra
.569 .458 .688 r
.54207 .49842 .54517 .51178 .55092 .51356 .54779 .4986 Mtetra
.727 .55 .652 r
.54779 .4986 .55092 .51356 .55666 .51147 .55345 .48854 Mtetra
.498 .365 .63 r
.55345 .48854 .55666 .51147 .56224 .49526 .55924 .49313 Mtetra
.041 .507 .886 r
.55924 .49313 .56224 .49526 .56803 .49736 .56503 .49504 Mtetra
.882 .818 .781 r
.56503 .49504 .56803 .49736 .57376 .49408 .57071 .48728 Mtetra
0 .042 .61 r
.57071 .48728 .57376 .49408 .57944 .487 .57664 .49596 Mtetra
.111 0 .175 r
.57664 .49596 .57944 .487 .58532 .4912 .58234 .48844 Mtetra
.136 .52 .915 r
.58234 .48844 .58532 .4912 .59099 .48345 .58821 .49051 Mtetra
.45 .091 .263 r
.58821 .49051 .59099 .48345 .59689 .48656 .59404 .48931 Mtetra
0 0 0 r
.59404 .48931 .59689 .48656 .60263 .48176 .59984 .4859 Mtetra
.516 .084 .159 r
.59984 .4859 .60263 .48176 .60851 .48215 .60575 .48677 Mtetra
.107 0 0 r
.60575 .48677 .60851 .48215 .61432 .4794 .61155 .48291 Mtetra
.39 0 .038 r
.61155 .48291 .61432 .4794 .62018 .47825 .61745 .48243 Mtetra
.277 0 .03 r
.61745 .48243 .62018 .47825 .62603 .47615 .62333 .48039 Mtetra
.2 0 0 r
.62333 .48039 .62603 .47615 .6319 .4742 .62919 .47759 Mtetra
.423 0 .046 r
.62919 .47759 .6319 .4742 .63779 .47271 .63516 .47754 Mtetra
.065 0 0 r
.63516 .47754 .63779 .47271 .64363 .4693 .64098 .47305 Mtetra
.44 0 .085 r
.64098 .47305 .64363 .4693 .64963 .46983 .64698 .47302 Mtetra
.062 0 0 r
.64698 .47302 .64963 .46983 .65538 .46362 .65288 .47007 Mtetra
.161 0 .118 r
.65288 .47007 .65538 .46362 .66154 .46738 .6587 .46497 Mtetra
0 .345 .786 r
.6587 .46497 .66154 .46738 .66723 .4596 .66488 .46827 Mtetra
0 0 .037 r
.66488 .46827 .66723 .4596 .67344 .46336 .6704 .45613 Mtetra
.303 .389 .785 r
.6704 .45613 .67344 .46336 .67946 .46256 .67667 .46047 Mtetra
.862 .859 .836 r
.67667 .46047 .67946 .46256 .68528 .45722 .68246 .45438 Mtetra
.88 .811 .777 r
.68246 .45438 .68528 .45722 .69203 .4702 .68817 .44649 Mtetra
.469 .346 .63 r
.68817 .44649 .69203 .4702 .69804 .46794 .69462 .45319 Mtetra
.656 .507 .669 r
.69462 .45319 .69804 .46794 .70392 .46286 .70052 .44873 Mtetra
.652 .508 .675 r
.70052 .44873 .70392 .46286 .71091 .47757 .70644 .44471 Mtetra
.284 .198 .579 r
.70644 .44471 .71091 .47757 .71805 .49362 .71385 .46639 Mtetra
0 0 .451 r
.71385 .46639 .71805 .49362 .72346 .47958 .72223 .50272 Mtetra
.586 .315 .473 r
.72223 .50272 .72346 .47958 .72751 .44407 .72872 .50562 Mtetra
.291 .125 .476 r
.72872 .50562 .72751 .44407 .73294 .43186 .73252 .46546 Mtetra
.019 0 .363 r
.73252 .46546 .73294 .43186 .74107 .4611 .73641 .42866 Mtetra
.509 .358 .611 r
.73641 .42866 .74107 .4611 .75085 .51274 .74303 .4345 Mtetra
.303 .183 .546 r
.74303 .4345 .75085 .51274 .75946 .54457 .75271 .48409 Mtetra
.205 .121 .533 r
.75271 .48409 .75946 .54457 .76445 .52371 .76259 .53342 Mtetra
.445 .123 .326 r
.76259 .53342 .76445 .52371 .76685 .46835 .76891 .53105 Mtetra
.206 .065 .458 r
.76891 .53105 .76685 .46835 .76996 .42506 .77158 .4796 Mtetra
.119 0 .429 r
.77158 .4796 .76996 .42506 .77624 .42469 .77396 .42672 Mtetra
.917 .936 .572 r
.77396 .42672 .77624 .42469 .78617 .47002 .7794 .41503 Mtetra
.257 .162 .551 r
.7794 .41503 .78617 .47002 .798 .53619 .78902 .45562 Mtetra
.199 .112 .525 r
.78902 .45562 .798 .53619 .80868 .58528 .80111 .52381 Mtetra
.187 .111 .533 r
.80111 .52381 .80868 .58528 .81623 .59507 .81225 .57741 Mtetra
.279 .249 .645 r
.81225 .57741 .81623 .59507 .82081 .5701 .82007 .58993 Mtetra
0 0 .297 r
.82007 .58993 .82081 .5701 .82374 .52743 .82462 .5647 Mtetra
.009 0 .377 r
.82462 .5647 .82374 .52743 .82635 .48293 .82738 .52048 Mtetra
0 0 .376 r
.82738 .52048 .82635 .48293 .82957 .44672 .82987 .475 Mtetra
0 0 .344 r
.82987 .475 .82957 .44672 .8338 .42229 .83307 .43879 Mtetra
0 0 .252 r
.83307 .43879 .8338 .42229 .83893 .4079 .83734 .41486 Mtetra
0 0 0 r
.83734 .41486 .83893 .4079 .84464 .39983 .84253 .40106 Mtetra
.796 .966 .656 r
.84253 .40106 .84464 .39983 .85068 .39503 .84831 .39349 Mtetra
.804 .93 .917 r
.84831 .39349 .85068 .39503 .85689 .39183 .8544 .38906 Mtetra
.726 .824 .926 r
.8544 .38906 .85689 .39183 .86318 .38937 .86065 .38605 Mtetra
.687 .773 .917 r
.86065 .38605 .86318 .38937 .86952 .38724 .86698 .38366 Mtetra
.671 .751 .911 r
.86698 .38366 .86952 .38724 .87589 .38522 .87334 .38154 Mtetra
.665 .743 .908 r
.87334 .38154 .87589 .38522 .88227 .38321 .87973 .37951 Mtetra
.664 .741 .908 r
.87973 .37951 .88227 .38321 .88867 .3812 .88614 .37749 Mtetra
.88614 .37749 .88867 .3812 .89508 .37919 .89256 .37548 Mtetra
.89256 .37548 .89508 .37919 .9015 .37718 .899 .37345 Mtetra
.899 .37345 .9015 .37718 .90794 .37516 .90545 .37143 Mtetra
.90545 .37143 .90794 .37516 .91439 .37314 .91191 .3694 Mtetra
.91191 .3694 .91439 .37314 .92086 .37112 .91839 .36737 Mtetra
.91839 .36737 .92086 .37112 .92734 .36909 .92488 .36533 Mtetra
.34143 .54441 .34473 .54748 .35002 .54582 .34673 .54274 Mtetra
.34673 .54274 .35002 .54582 .35532 .54416 .35203 .54107 Mtetra
.35203 .54107 .35532 .54416 .36063 .54249 .35735 .5394 Mtetra
.35735 .5394 .36063 .54249 .36595 .54082 .36268 .53773 Mtetra
.36268 .53773 .36595 .54082 .37128 .53915 .36802 .53605 Mtetra
.663 .741 .908 r
.36802 .53605 .37128 .53915 .37662 .53747 .37336 .53436 Mtetra
.662 .741 .908 r
.37336 .53436 .37662 .53747 .38197 .53579 .37872 .5327 Mtetra
.657 .741 .912 r
.37872 .5327 .38197 .53579 .38734 .53413 .38409 .5311 Mtetra
.641 .741 .921 r
.38409 .5311 .38734 .53413 .39271 .53256 .38946 .52971 Mtetra
.595 .739 .945 r
.38946 .52971 .39271 .53256 .39808 .53126 .39482 .5288 Mtetra
.409 .697 .98 r
.39482 .5288 .39808 .53126 .40344 .53059 .40015 .52911 Mtetra
.455 0 0 r
.40015 .52911 .40344 .53059 .40876 .53133 .4054 .53226 Mtetra
.833 .426 .274 r
.4054 .53226 .40876 .53133 .414 .53517 .41047 .54124 Mtetra
.836 .518 .449 r
.41047 .54124 .414 .53517 .41908 .54514 .41527 .55995 Mtetra
.817 .53 .503 r
.41527 .55995 .41908 .54514 .42391 .56503 .41978 .5909 Mtetra
.795 .522 .524 r
.41978 .5909 .42391 .56503 .42848 .59689 .42411 .63183 Mtetra
.764 .498 .532 r
.42411 .63183 .42848 .59689 .43294 .63753 .42859 .67258 Mtetra
.699 .437 .524 r
.42859 .67258 .43294 .63753 .4376 .67635 .43371 .6945 Mtetra
0 0 .215 r
.43371 .6945 .4376 .67635 .44284 .69603 .43987 .67751 Mtetra
.873 .638 .581 r
.43987 .67751 .44284 .69603 .44896 .67893 .44693 .61884 Mtetra
.782 .547 .58 r
.44693 .61884 .44896 .67893 .45583 .62264 .45408 .54763 Mtetra
.696 .475 .583 r
.45408 .54763 .45583 .62264 .46278 .55324 .46039 .50888 Mtetra
.394 .254 .57 r
.46039 .50888 .46278 .55324 .46904 .51168 .46559 .52631 Mtetra
.869 .583 .502 r
.46559 .52631 .46904 .51168 .47442 .52136 .47027 .58056 Mtetra
.705 .452 .54 r
.47027 .58056 .47442 .52136 .47931 .57009 .47537 .61915 Mtetra
.385 .179 .473 r
.47537 .61915 .47931 .57009 .48443 .61549 .48137 .59934 Mtetra
.889 .65 .572 r
.48137 .59934 .48443 .61549 .49021 .61224 .48777 .53811 Mtetra
.699 .476 .582 r
.48777 .53811 .49021 .61224 .4964 .5596 .49379 .49866 Mtetra
.454 .291 .569 r
.49379 .49866 .4964 .5596 .50243 .50838 .49925 .51571 Mtetra
.898 .597 .47 r
.49925 .51571 .50243 .50838 .50809 .50085 .50461 .5619 Mtetra
.649 .403 .534 r
.50461 .5619 .50809 .50085 .5136 .53422 .51026 .58269 Mtetra
.235 .061 .43 r
.51026 .58269 .5136 .53422 .51923 .56914 .51613 .55105 Mtetra
.867 .632 .581 r
.51613 .55105 .51923 .56914 .52501 .56118 .52193 .50248 Mtetra
.64 .434 .588 r
.52193 .50248 .52501 .56118 .53071 .52141 .5276 .48754 Mtetra
.435 .298 .594 r
.5276 .48754 .53071 .52141 .53636 .4975 .53331 .49868 Mtetra
.548 .008 0 r
.53331 .49868 .53636 .4975 .54207 .49842 .53904 .50094 Mtetra
.856 .973 .661 r
.53904 .50094 .54207 .49842 .54779 .4986 .54473 .49252 Mtetra
0 .148 .69 r
.54473 .49252 .54779 .4986 .55345 .48854 .55052 .49931 Mtetra
.668 .347 .421 r
.55052 .49931 .55345 .48854 .55924 .49313 .55635 .50547 Mtetra
0 0 .142 r
.55635 .50547 .55924 .49313 .56503 .49504 .562 .49164 Mtetra
0 0 .486 r
.562 .49164 .56503 .49504 .57071 .48728 .56788 .49811 Mtetra
.407 .102 .334 r
.56788 .49811 .57071 .48728 .57664 .49596 .57366 .49458 Mtetra
.902 .87 .797 r
.57366 .49458 .57664 .49596 .58234 .48844 .57937 .48699 Mtetra
.566 0 0 r
.57937 .48699 .58234 .48844 .58821 .49051 .5853 .49158 Mtetra
.95 .953 .722 r
.5853 .49158 .58821 .49051 .59404 .48931 .59097 .48192 Mtetra
.393 .439 .79 r
.59097 .48192 .59404 .48931 .59984 .4859 .59691 .48496 Mtetra
.881 .918 .846 r
.59691 .48496 .59984 .4859 .60575 .48677 .60266 .4788 Mtetra
.561 .524 .771 r
.60266 .4788 .60575 .48677 .61155 .48291 .60857 .47902 Mtetra
.734 .735 .852 r
.60857 .47902 .61155 .48291 .61745 .48243 .61441 .47572 Mtetra
.629 .59 .792 r
.61441 .47572 .61745 .48243 .62333 .48039 .6203 .47432 Mtetra
.624 .607 .812 r
.6203 .47432 .62333 .48039 .62919 .47759 .62622 .47308 Mtetra
.712 .701 .838 r
.62622 .47308 .62919 .47759 .63516 .47754 .63209 .47008 Mtetra
.487 .494 .79 r
.63209 .47008 .63516 .47754 .64098 .47305 .63813 .4717 Mtetra
.871 .902 .851 r
.63813 .4717 .64098 .47305 .64698 .47302 .64392 .46576 Mtetra
.2 .323 .766 r
.64392 .46576 .64698 .47302 .65288 .47007 .65015 .47125 Mtetra
.901 .985 .732 r
.65015 .47125 .65288 .47007 .6587 .46497 .65587 .46312 Mtetra
.418 0 0 r
.65587 .46312 .6587 .46497 .66488 .46827 .6621 .46739 Mtetra
.365 .804 .96 r
.6621 .46739 .66488 .46827 .6704 .45613 .66814 .46664 Mtetra
.096 0 .221 r
.66814 .46664 .6704 .45613 .67667 .46047 .6738 .45696 Mtetra
.711 .251 0 r
.6738 .45696 .67667 .46047 .68246 .45438 .68038 .46727 Mtetra
.166 0 .289 r
.68038 .46727 .68246 .45438 .68817 .44649 .686 .45667 Mtetra
.062 0 .204 r
.686 .45667 .68817 .44649 .69462 .45319 .69162 .44662 Mtetra
.2 .346 .787 r
.69162 .44662 .69462 .45319 .70052 .44873 .69803 .45172 Mtetra
0 0 0 r
.69803 .45172 .70052 .44873 .70644 .44471 .70383 .44492 Mtetra
.986 .877 .638 r
.70383 .44492 .70644 .44471 .71385 .46639 .70917 .43024 Mtetra
.435 .3 .597 r
.70917 .43024 .71385 .46639 .72223 .50272 .71609 .44315 Mtetra
.216 .126 .533 r
.71609 .44315 .72223 .50272 .72872 .50562 .7251 .48941 Mtetra
0 0 .396 r
.7251 .48941 .72872 .50562 .73252 .46546 .73312 .51657 Mtetra
.354 .166 .482 r
.73312 .51657 .73252 .46546 .73641 .42866 .73779 .48974 Mtetra
.189 .05 .449 r
.73779 .48974 .73641 .42866 .74303 .4345 .74079 .43897 Mtetra
.926 .855 .416 r
.74079 .43897 .74303 .4345 .75271 .48409 .74578 .41983 Mtetra
.322 .202 .556 r
.74578 .41983 .75271 .48409 .76259 .53342 .75474 .45822 Mtetra
.223 .128 .53 r
.75474 .45822 .76259 .53342 .76891 .53105 .76534 .51699 Mtetra
.078 .135 .62 r
.76534 .51699 .76891 .53105 .77158 .4796 .77291 .53144 Mtetra
.177 .038 .441 r
.77291 .53144 .77158 .4796 .77396 .42672 .77604 .48635 Mtetra
.109 0 .429 r
.77604 .48635 .77396 .42672 .7794 .41503 .77794 .42747 Mtetra
0 0 .145 r
.77794 .42747 .7794 .41503 .78902 .45562 .78277 .40791 Mtetra
.226 .145 .55 r
.78277 .40791 .78902 .45562 .80111 .52381 .79226 .44586 Mtetra
.168 .091 .518 r
.79226 .44586 .80111 .52381 .81225 .57741 .80461 .51606 Mtetra
.163 .095 .526 r
.80461 .51606 .81225 .57741 .82007 .58993 .81605 .5721 Mtetra
.289 .255 .646 r
.81605 .5721 .82007 .58993 .82462 .5647 .8239 .58441 Mtetra
0 0 .268 r
.8239 .58441 .82462 .5647 .82738 .52048 .82824 .55679 Mtetra
0 0 .357 r
.82824 .55679 .82738 .52048 .82987 .475 .83077 .51053 Mtetra
0 0 .356 r
.83077 .51053 .82987 .475 .83307 .43879 .83319 .46474 Mtetra
0 0 .32 r
.83319 .46474 .83307 .43879 .83734 .41486 .83646 .42945 Mtetra
0 0 .212 r
.83646 .42945 .83734 .41486 .84253 .40106 .84083 .40674 Mtetra
0 0 0 r
.84083 .40674 .84253 .40106 .84831 .39349 .84612 .39392 Mtetra
.843 .996 .759 r
.84612 .39392 .84831 .39349 .8544 .38906 .85199 .38703 Mtetra
.783 .893 .922 r
.85199 .38703 .8544 .38906 .86065 .38605 .85814 .38302 Mtetra
.712 .803 .922 r
.85814 .38302 .86065 .38605 .86698 .38366 .86444 .38023 Mtetra
.681 .765 .915 r
.86444 .38023 .86698 .38366 .87334 .38154 .8708 .37792 Mtetra
.669 .749 .91 r
.8708 .37792 .87334 .38154 .87973 .37951 .87719 .37581 Mtetra
.665 .743 .908 r
.87719 .37581 .87973 .37951 .88614 .37749 .8836 .37377 Mtetra
.664 .741 .908 r
.8836 .37377 .88614 .37749 .89256 .37548 .89004 .37174 Mtetra
.89004 .37174 .89256 .37548 .899 .37345 .89648 .36971 Mtetra
.89648 .36971 .899 .37345 .90545 .37143 .90294 .36768 Mtetra
.90294 .36768 .90545 .37143 .91191 .3694 .90942 .36564 Mtetra
.90942 .36564 .91191 .3694 .91839 .36737 .9159 .3636 Mtetra
.9159 .3636 .91839 .36737 .92488 .36533 .92241 .36155 Mtetra
.33812 .54133 .34143 .54441 .34673 .54274 .34343 .53966 Mtetra
.34343 .53966 .34673 .54274 .35203 .54107 .34874 .53798 Mtetra
.34874 .53798 .35203 .54107 .35735 .5394 .35406 .5363 Mtetra
.35406 .5363 .35735 .5394 .36268 .53773 .3594 .53462 Mtetra
.663 .741 .908 r
.3594 .53462 .36268 .53773 .36802 .53605 .36474 .53294 Mtetra
.662 .741 .908 r
.36474 .53294 .36802 .53605 .37336 .53436 .3701 .53126 Mtetra
.659 .741 .911 r
.3701 .53126 .37336 .53436 .37872 .5327 .37546 .52964 Mtetra
.648 .742 .917 r
.37546 .52964 .37872 .5327 .38409 .5311 .38083 .52815 Mtetra
.617 .74 .934 r
.38083 .52815 .38409 .5311 .38946 .52971 .38619 .52702 Mtetra
.496 .718 .97 r
.38619 .52702 .38946 .52971 .39482 .5288 .39153 .52689 Mtetra
0 .353 .744 r
.39153 .52689 .39482 .5288 .40015 .52911 .39679 .52925 Mtetra
.823 .385 .196 r
.39679 .52925 .40015 .52911 .4054 .53226 .40187 .53694 Mtetra
.842 .513 .431 r
.40187 .53694 .4054 .53226 .41047 .54124 .40668 .55379 Mtetra
.825 .534 .496 r
.40668 .55379 .41047 .54124 .41527 .55995 .41115 .58288 Mtetra
.805 .529 .521 r
.41115 .58288 .41527 .55995 .41978 .5909 .41537 .62334 Mtetra
.777 .509 .53 r
.41537 .62334 .41978 .5909 .42411 .63183 .41966 .66631 Mtetra
.719 .455 .526 r
.41966 .66631 .42411 .63183 .42859 .67258 .42458 .69248 Mtetra
.172 0 .319 r
.42458 .69248 .42859 .67258 .43371 .6945 .43069 .67873 Mtetra
.884 .65 .579 r
.43069 .67873 .43371 .6945 .43987 .67751 .43791 .61977 Mtetra
.79 .554 .58 r
.43791 .61977 .43987 .67751 .44693 .61884 .44529 .54617 Mtetra
.7 .478 .583 r
.44529 .54617 .44693 .61884 .45408 .54763 .4517 .50711 Mtetra
.309 .193 .555 r
.4517 .50711 .45408 .54763 .46039 .50888 .45676 .52845 Mtetra
.853 .572 .512 r
.45676 .52845 .46039 .50888 .46559 .52631 .46124 .5861 Mtetra
.689 .438 .538 r
.46124 .5861 .46559 .52631 .47027 .58056 .46634 .61901 Mtetra
.069 0 .349 r
.46634 .61901 .47027 .58056 .47537 .61915 .47257 .58684 Mtetra
.836 .598 .579 r
.47257 .58684 .47537 .61915 .48137 .59934 .47915 .52256 Mtetra
.657 .442 .582 r
.47915 .52256 .48137 .59934 .48777 .53811 .48506 .49764 Mtetra
.001 0 .461 r
.48506 .49764 .48777 .53811 .49379 .49866 .49026 .53489 Mtetra
.777 .507 .527 r
.49026 .53489 .49379 .49866 .49925 .51571 .49552 .58206 Mtetra
.54 .313 .52 r
.49552 .58206 .49925 .51571 .50461 .5619 .50131 .57828 Mtetra
.973 .801 .378 r
.50131 .57828 .50461 .5619 .51026 .58269 .50735 .52753 Mtetra
.729 .504 .586 r
.50735 .52753 .51026 .58269 .51613 .55105 .5132 .48797 Mtetra
.517 .338 .577 r
.5132 .48797 .51613 .55105 .52193 .50248 .51884 .49646 Mtetra
.936 .577 .169 r
.51884 .49646 .52193 .50248 .5276 .48754 .52453 .51914 Mtetra
.497 .257 .48 r
.52453 .51914 .5276 .48754 .53331 .49868 .53027 .51415 Mtetra
0 0 .178 r
.53027 .51415 .53331 .49868 .53904 .50094 .53597 .49725 Mtetra
.335 .572 .927 r
.53597 .49725 .53904 .50094 .54473 .49252 .54172 .49879 Mtetra
.702 .337 .354 r
.54172 .49879 .54473 .49252 .55052 .49931 .54753 .50489 Mtetra
.906 .888 .467 r
.54753 .50489 .55052 .49931 .55635 .50547 .55319 .48886 Mtetra
.604 .462 .661 r
.55319 .48886 .55635 .50547 .562 .49164 .55895 .48719 Mtetra
.337 .525 .893 r
.55895 .48719 .562 .49164 .56788 .49811 .56478 .48921 Mtetra
.806 .638 .674 r
.56478 .48921 .56788 .49811 .57366 .49458 .57044 .47735 Mtetra
.452 .356 .656 r
.57044 .47735 .57366 .49458 .57937 .48699 .57634 .48258 Mtetra
.835 .733 .752 r
.57634 .48258 .57937 .48699 .5853 .49158 .58205 .47478 Mtetra
.557 .43 .662 r
.58205 .47478 .5853 .49158 .59097 .48192 .58792 .47553 Mtetra
.69 .627 .781 r
.58792 .47553 .59097 .48192 .59691 .48496 .59373 .47251 Mtetra
.62 .499 .694 r
.59373 .47251 .59691 .48496 .60266 .4788 .59957 .47058 Mtetra
.625 .555 .755 r
.59957 .47058 .60266 .4788 .60857 .47902 .60544 .46909 Mtetra
.635 .535 .723 r
.60544 .46909 .60857 .47902 .61441 .47572 .6113 .46697 Mtetra
.636 .552 .743 r
.6113 .46697 .61441 .47572 .6203 .47432 .61718 .46505 Mtetra
.617 .534 .737 r
.61718 .46505 .6203 .47432 .62622 .47308 .62309 .46366 Mtetra
.647 .549 .729 r
.62309 .46366 .62622 .47308 .63209 .47008 .62898 .46119 Mtetra
.618 .54 .744 r
.62898 .46119 .63209 .47008 .63813 .4717 .63491 .45982 Mtetra
.604 .495 .703 r
.63491 .45982 .63813 .4717 .64392 .46576 .64087 .45863 Mtetra
.704 .619 .759 r
.64087 .45863 .64392 .46576 .65015 .47125 .64674 .45481 Mtetra
.494 .391 .666 r
.64674 .45481 .65015 .47125 .65587 .46312 .65291 .45835 Mtetra
.842 .73 .74 r
.65291 .45835 .65587 .46312 .6621 .46739 .65862 .44982 Mtetra
.378 .306 .649 r
.65862 .44982 .6621 .46739 .66814 .46664 .66503 .45808 Mtetra
.737 .611 .717 r
.66503 .45808 .66814 .46664 .6738 .45696 .67085 .45194 Mtetra
.631 .65 .851 r
.67085 .45194 .6738 .45696 .68038 .46727 .67689 .45057 Mtetra
.226 .208 .629 r
.67689 .45057 .68038 .46727 .686 .45667 .6836 .46295 Mtetra
0 0 0 r
.6836 .46295 .686 .45667 .69162 .44662 .68923 .45234 Mtetra
.169 0 .085 r
.68923 .45234 .69162 .44662 .69803 .45172 .69516 .44787 Mtetra
.799 .366 0 r
.69516 .44787 .69803 .45172 .70383 .44492 .70208 .46165 Mtetra
.544 .26 .435 r
.70208 .46165 .70383 .44492 .70917 .43024 .70831 .46173 Mtetra
.157 0 .399 r
.70831 .46173 .70917 .43024 .71609 .44315 .71299 .43461 Mtetra
.807 .646 .683 r
.71299 .43461 .71609 .44315 .7251 .48941 .71855 .42379 Mtetra
.325 .201 .554 r
.71855 .42379 .7251 .48941 .73312 .51657 .72711 .46191 Mtetra
.163 .092 .523 r
.72711 .46191 .73312 .51657 .73779 .48974 .73642 .50924 Mtetra
.508 .239 .442 r
.73642 .50924 .73779 .48974 .74079 .43897 .74269 .50689 Mtetra
.221 .076 .461 r
.74269 .50689 .74079 .43897 .74578 .41983 .74556 .45407 Mtetra
0 0 .349 r
.74556 .45407 .74578 .41983 .75474 .45822 .74914 .41406 Mtetra
.349 .232 .576 r
.74914 .41406 .75474 .45822 .76534 .51699 .75716 .43819 Mtetra
.216 .122 .527 r
.75716 .43819 .76534 .51699 .77291 .53144 .7681 .50069 Mtetra
.169 .126 .562 r
.7681 .50069 .77291 .53144 .77604 .48635 .77664 .52778 Mtetra
.123 0 .413 r
.77664 .52778 .77604 .48635 .77794 .42747 .78017 .48806 Mtetra
.08 0 .42 r
.78017 .48806 .77794 .42747 .78277 .40791 .78174 .42544 Mtetra
0 0 .258 r
.78174 .42544 .78277 .40791 .79226 .44586 .78627 .40197 Mtetra
.181 .116 .543 r
.78627 .40197 .79226 .44586 .80461 .51606 .79586 .44039 Mtetra
.133 .067 .51 r
.79586 .44039 .80461 .51606 .81605 .5721 .80854 .51311 Mtetra
.14 .08 .522 r
.80854 .51311 .81605 .5721 .8239 .58441 .82011 .56937 Mtetra
.338 .306 .676 r
.82011 .56937 .8239 .58441 .82824 .55679 .8277 .57825 Mtetra
0 0 .258 r
.8277 .57825 .82824 .55679 .83077 .51053 .83163 .54621 Mtetra
0 0 .337 r
.83163 .54621 .83077 .51053 .83319 .46474 .83391 .49767 Mtetra
0 0 .332 r
.83391 .49767 .83319 .46474 .83646 .42945 .83633 .45236 Mtetra
0 0 .288 r
.83633 .45236 .83646 .42945 .84083 .40674 .83975 .41899 Mtetra
0 0 .154 r
.83975 .41899 .84083 .40674 .84612 .39392 .8443 .39817 Mtetra
0 0 0 r
.8443 .39817 .84612 .39392 .85199 .38703 .84972 .38665 Mtetra
.856 .991 .837 r
.84972 .38665 .85199 .38703 .85814 .38302 .85568 .38054 Mtetra
.758 .855 .923 r
.85568 .38054 .85814 .38302 .86444 .38023 .86191 .37696 Mtetra
.698 .783 .917 r
.86191 .37696 .86444 .38023 .8708 .37792 .86825 .37437 Mtetra
.676 .757 .912 r
.86825 .37437 .8708 .37792 .87719 .37581 .87464 .37214 Mtetra
.668 .747 .91 r
.87464 .37214 .87719 .37581 .8836 .37377 .88106 .37004 Mtetra
.665 .743 .908 r
.88106 .37004 .8836 .37377 .89004 .37174 .8875 .36799 Mtetra
.664 .741 .908 r
.8875 .36799 .89004 .37174 .89648 .36971 .89396 .36595 Mtetra
.89396 .36595 .89648 .36971 .90294 .36768 .90043 .36391 Mtetra
.90043 .36391 .90294 .36768 .90942 .36564 .90691 .36187 Mtetra
.90691 .36187 .90942 .36564 .9159 .3636 .91341 .35982 Mtetra
.91341 .35982 .9159 .3636 .92241 .36155 .91992 .35776 Mtetra
.3348 .53824 .33812 .54133 .34343 .53966 .34011 .53656 Mtetra
.34011 .53656 .34343 .53966 .34874 .53798 .34543 .53488 Mtetra
.34543 .53488 .34874 .53798 .35406 .5363 .35076 .53319 Mtetra
.663 .741 .908 r
.35076 .53319 .35406 .5363 .3594 .53462 .3561 .53151 Mtetra
.3561 .53151 .3594 .53462 .36474 .53294 .36145 .52983 Mtetra
.66 .741 .91 r
.36145 .52983 .36474 .53294 .3701 .53126 .36681 .52818 Mtetra
.654 .742 .914 r
.36681 .52818 .3701 .53126 .37546 .52964 .37218 .5266 Mtetra
.635 .74 .924 r
.37218 .5266 .37546 .52964 .38083 .52815 .37755 .52528 Mtetra
.555 .726 .954 r
.37755 .52528 .38083 .52815 .38619 .52702 .38289 .52475 Mtetra
.1 .541 .911 r
.38289 .52475 .38619 .52702 .39153 .52689 .38817 .52631 Mtetra
.787 .301 .062 r
.38817 .52631 .39153 .52689 .39679 .52925 .39328 .53248 Mtetra
.846 .501 .401 r
.39328 .53248 .39679 .52925 .40187 .53694 .39812 .5469 Mtetra
.833 .535 .485 r
.39812 .5469 .40187 .53694 .40668 .55379 .4026 .5732 Mtetra
.816 .537 .516 r
.4026 .5732 .40668 .55379 .41115 .58288 .40674 .61225 Mtetra
.792 .522 .528 r
.40674 .61225 .41115 .58288 .41537 .62334 .41082 .6573 Mtetra
.741 .476 .528 r
.41082 .6573 .41537 .62334 .41966 .66631 .41548 .68931 Mtetra
.414 .165 .425 r
.41548 .68931 .41966 .66631 .42458 .69248 .42142 .68196 Mtetra
.904 .672 .577 r
.42142 .68196 .42458 .69248 .43069 .67873 .42872 .6253 Mtetra
.801 .564 .579 r
.42872 .6253 .43069 .67873 .43791 .61977 .43638 .54886 Mtetra
.711 .488 .583 r
.43638 .54886 .43791 .61977 .44529 .54617 .44298 .50592 Mtetra
.308 .192 .555 r
.44298 .50592 .44529 .54617 .4517 .50711 .44799 .52698 Mtetra
.854 .575 .513 r
.44799 .52698 .4517 .50711 .45676 .52845 .45226 .58693 Mtetra
.684 .434 .537 r
.45226 .58693 .45676 .52845 .46124 .5861 .45731 .61755 Mtetra
0 0 .132 r
.45731 .61755 .46124 .5861 .46634 .61901 .46375 .57787 Mtetra
.813 .576 .58 r
.46375 .57787 .46634 .61901 .47257 .58684 .47049 .51287 Mtetra
.617 .412 .581 r
.47049 .51287 .47257 .58684 .47915 .52256 .47626 .50047 Mtetra
.882 .63 .108 r
.47626 .50047 .47915 .52256 .48506 .49764 .48119 .5513 Mtetra
.719 .462 .536 r
.48119 .5513 .48506 .49764 .49026 .53489 .48642 .59153 Mtetra
.329 .138 .463 r
.48642 .59153 .49026 .53489 .49552 .58206 .49247 .56321 Mtetra
.876 .638 .574 r
.49247 .56321 .49552 .58206 .50131 .57828 .49867 .50498 Mtetra
.635 .426 .581 r
.49867 .50498 .50131 .57828 .50735 .52753 .50444 .48759 Mtetra
.071 .022 .489 r
.50444 .48759 .50735 .52753 .5132 .48797 .50994 .52168 Mtetra
.708 .441 .518 r
.50994 .52168 .5132 .48797 .51884 .49646 .5156 .54489 Mtetra
.32 .128 .456 r
.5156 .54489 .51884 .49646 .52453 .51914 .52141 .51969 Mtetra
.975 .778 .576 r
.52141 .51969 .52453 .51914 .53027 .51415 .52715 .49018 Mtetra
.587 .425 .629 r
.52715 .49018 .53027 .51415 .53597 .49725 .53287 .48894 Mtetra
.293 .353 .753 r
.53287 .48894 .53597 .49725 .54172 .49879 .53863 .49367 Mtetra
.868 .714 .689 r
.53863 .49367 .54172 .49879 .54753 .50489 .54433 .48114 Mtetra
.588 .426 .63 r
.54433 .48114 .54753 .50489 .55319 .48886 .55009 .47982 Mtetra
.267 .321 .733 r
.55009 .47982 .55319 .48886 .55895 .48719 .55592 .48538 Mtetra
.923 .822 .728 r
.55592 .48538 .55895 .48719 .56478 .48921 .56161 .47465 Mtetra
.361 .311 .667 r
.56161 .47465 .56478 .48921 .57044 .47735 .56751 .48157 Mtetra
0 0 0 r
.56751 .48157 .57044 .47735 .57634 .48258 .57328 .47669 Mtetra
.633 .616 .815 r
.57328 .47669 .57634 .48258 .58205 .47478 .5791 .47526 Mtetra
.384 0 0 r
.5791 .47526 .58205 .47478 .58792 .47553 .585 .47673 Mtetra
.75 .989 .784 r
.585 .47673 .58792 .47553 .59373 .47251 .59078 .47139 Mtetra
0 .372 .693 r
.59078 .47139 .59373 .47251 .59957 .47058 .59672 .47345 Mtetra
0 0 0 r
.59672 .47345 .59957 .47058 .60544 .46909 .60254 .46893 Mtetra
.073 .634 .772 r
.60254 .46893 .60544 .46909 .6113 .46697 .60846 .46879 Mtetra
0 0 0 r
.60846 .46879 .6113 .46697 .61718 .46505 .61435 .46658 Mtetra
.61435 .46658 .61718 .46505 .62309 .46366 .62024 .46369 Mtetra
.063 0 0 r
.62024 .46369 .62309 .46366 .62898 .46119 .62622 .46393 Mtetra
0 0 0 r
.62622 .46393 .62898 .46119 .63491 .45982 .63205 .45854 Mtetra
0 .499 .814 r
.63205 .45854 .63491 .45982 .64087 .45863 .63811 .46008 Mtetra
.692 .963 .727 r
.63811 .46008 .64087 .45863 .64674 .45481 .64394 .45467 Mtetra
.425 .865 .904 r
.64394 .45467 .64674 .45481 .65291 .45835 .64992 .4529 Mtetra
.517 .577 .854 r
.64992 .4529 .65291 .45835 .65862 .44982 .656 .45347 Mtetra
.763 .887 .477 r
.656 .45347 .65862 .44982 .66503 .45808 .66165 .44328 Mtetra
.374 .321 .67 r
.66165 .44328 .66503 .45808 .67085 .45194 .66804 .45033 Mtetra
.931 .859 .747 r
.66804 .45033 .67085 .45194 .67689 .45057 .67371 .4406 Mtetra
.623 .529 .727 r
.67371 .4406 .67689 .45057 .6836 .46295 .67974 .43889 Mtetra
.428 .316 .624 r
.67974 .43889 .6836 .46295 .68923 .45234 .68631 .44771 Mtetra
.857 .741 .734 r
.68631 .44771 .68923 .45234 .69516 .44787 .69201 .43854 Mtetra
.617 .535 .739 r
.69201 .43854 .69516 .44787 .70208 .46165 .69811 .43711 Mtetra
0 .012 .518 r
.69811 .43711 .70208 .46165 .70831 .46173 .70578 .46406 Mtetra
.894 .514 .305 r
.70578 .46406 .70831 .46173 .71299 .43461 .71321 .48453 Mtetra
.324 .141 .472 r
.71321 .48453 .71299 .43461 .71855 .42379 .71784 .45584 Mtetra
0 0 .331 r
.71784 .45584 .71855 .42379 .72711 .46191 .72185 .41841 Mtetra
.426 .286 .586 r
.72185 .41841 .72711 .46191 .73642 .50924 .72911 .43469 Mtetra
.231 .131 .529 r
.72911 .43469 .73642 .50924 .74269 .50689 .73902 .49069 Mtetra
0 0 .495 r
.73902 .49069 .74269 .50689 .74556 .45407 .74695 .51337 Mtetra
.214 .067 .454 r
.74695 .51337 .74556 .45407 .74914 .41406 .75023 .46668 Mtetra
.065 0 .405 r
.75023 .46668 .74914 .41406 .75716 .43819 .75282 .41237 Mtetra
.395 .291 .617 r
.75282 .41237 .75716 .43819 .7681 .50069 .76 .42407 Mtetra
.194 .106 .522 r
.76 .42407 .7681 .50069 .77664 .52778 .77111 .48778 Mtetra
.175 .116 .546 r
.77111 .48778 .77664 .52778 .78017 .48806 .78029 .52255 Mtetra
.04 0 .374 r
.78029 .52255 .78017 .48806 .78174 .42544 .78395 .48487 Mtetra
.041 0 .407 r
.78395 .48487 .78174 .42544 .78627 .40197 .78528 .41981 Mtetra
0 0 .271 r
.78528 .41981 .78627 .40197 .79586 .44039 .78984 .39675 Mtetra
.123 .077 .528 r
.78984 .39675 .79586 .44039 .80854 .51311 .79985 .43926 Mtetra
.097 .042 .5 r
.79985 .43926 .80854 .51311 .82011 .56937 .81291 .51482 Mtetra
.122 .07 .52 r
.81291 .51482 .82011 .56937 .8277 .57825 .82437 .56856 Mtetra
.491 .465 .756 r
.82437 .56856 .8277 .57825 .83163 .54621 .83141 .57077 Mtetra
0 0 .26 r
.83141 .57077 .83163 .54621 .83391 .49767 .83476 .53273 Mtetra
0 0 .318 r
.83476 .53273 .83391 .49767 .83633 .45236 .8368 .4821 Mtetra
0 0 .303 r
.8368 .4821 .83633 .45236 .83975 .41899 .83931 .43827 Mtetra
0 0 .241 r
.83931 .43827 .83975 .41899 .8443 .39817 .84298 .40775 Mtetra
0 0 .064 r
.84298 .40775 .8443 .39817 .84972 .38665 .84776 .38941 Mtetra
.717 .859 .437 r
.84776 .38941 .84972 .38665 .85568 .38054 .85335 .37943 Mtetra
.841 .962 .886 r
.85335 .37943 .85568 .38054 .86191 .37696 .85941 .3741 Mtetra
.734 .824 .92 r
.85941 .3741 .86191 .37696 .86825 .37437 .8657 .3709 Mtetra
.686 .767 .913 r
.8657 .3709 .86825 .37437 .87464 .37214 .87209 .36849 Mtetra
.671 .75 .91 r
.87209 .36849 .87464 .37214 .88106 .37004 .87851 .36633 Mtetra
.666 .745 .909 r
.87851 .36633 .88106 .37004 .8875 .36799 .88496 .36424 Mtetra
.664 .743 .908 r
.88496 .36424 .8875 .36799 .89396 .36595 .89142 .36219 Mtetra
.664 .742 .908 r
.89142 .36219 .89396 .36595 .90043 .36391 .8979 .36013 Mtetra
.664 .741 .908 r
.8979 .36013 .90043 .36391 .90691 .36187 .9044 .35808 Mtetra
.9044 .35808 .90691 .36187 .91341 .35982 .91091 .35602 Mtetra
.91091 .35602 .91341 .35982 .91992 .35776 .91743 .35396 Mtetra
.33147 .53514 .3348 .53824 .34011 .53656 .33679 .53345 Mtetra
.33679 .53345 .34011 .53656 .34543 .53488 .34211 .53176 Mtetra
.663 .741 .908 r
.34211 .53176 .34543 .53488 .35076 .53319 .34745 .53008 Mtetra
.34745 .53008 .35076 .53319 .3561 .53151 .3528 .52839 Mtetra
.662 .742 .909 r
.3528 .52839 .3561 .53151 .36145 .52983 .35815 .52671 Mtetra
.659 .741 .911 r
.35815 .52671 .36145 .52983 .36681 .52818 .36352 .52508 Mtetra
.646 .739 .917 r
.36352 .52508 .36681 .52818 .37218 .5266 .36889 .52362 Mtetra
.592 .731 .94 r
.36889 .52362 .37218 .5266 .37755 .52528 .37424 .52276 Mtetra
.318 .649 .969 r
.37424 .52276 .37755 .52528 .38289 .52475 .37953 .52355 Mtetra
.677 .127 0 r
.37953 .52355 .38289 .52475 .38817 .52631 .38469 .52808 Mtetra
.847 .475 .348 r
.38469 .52808 .38817 .52631 .39328 .53248 .38959 .53966 Mtetra
.843 .534 .467 r
.38959 .53966 .39328 .53248 .39812 .5469 .39412 .56241 Mtetra
.829 .545 .508 r
.39412 .56241 .39812 .5469 .4026 .5732 .39822 .59901 Mtetra
.807 .534 .525 r
.39822 .59901 .4026 .5732 .40674 .61225 .40211 .6454 Mtetra
.764 .496 .529 r
.40211 .6454 .40674 .61225 .41082 .6573 .40644 .68401 Mtetra
.574 .313 .483 r
.40644 .68401 .41082 .6573 .41548 .68931 .41208 .68594 Mtetra
.936 .711 .572 r
.41208 .68594 .41548 .68931 .42142 .68196 .41937 .63489 Mtetra
.817 .579 .578 r
.41937 .63489 .42142 .68196 .42872 .6253 .4273 .55609 Mtetra
.73 .503 .583 r
.4273 .55609 .42872 .6253 .43638 .54886 .43422 .50578 Mtetra
.398 .257 .57 r
.43422 .50578 .43638 .54886 .44298 .50592 .43929 .5219 Mtetra
.871 .589 .507 r
.43929 .5219 .44298 .50592 .44799 .52698 .44335 .58321 Mtetra
.695 .442 .537 r
.44335 .58321 .44799 .52698 .45226 .58693 .44827 .61611 Mtetra
0 0 .017 r
.44827 .61611 .45226 .58693 .45731 .61755 .45486 .57378 Mtetra
.808 .571 .58 r
.45486 .57378 .45731 .61755 .46375 .57787 .46177 .50777 Mtetra
.587 .388 .58 r
.46177 .50777 .46375 .57787 .47049 .51287 .46743 .50314 Mtetra
.977 .679 .376 r
.46743 .50314 .47049 .51287 .47626 .50047 .47209 .56179 Mtetra
.681 .431 .536 r
.47209 .56179 .47626 .50047 .48119 .5513 .47736 .59292 Mtetra
0 0 .239 r
.47736 .59292 .48119 .5513 .48642 .59153 .4837 .54638 Mtetra
.787 .553 .582 r
.4837 .54638 .48642 .59153 .49247 .56321 .48999 .4912 Mtetra
.522 .338 .573 r
.48999 .4912 .49247 .56321 .49867 .50498 .49555 .49957 Mtetra
.966 .657 .382 r
.49555 .49957 .49867 .50498 .50444 .48759 .50086 .54918 Mtetra
.597 .358 .526 r
.50086 .54918 .50444 .48759 .50994 .52168 .50658 .55724 Mtetra
0 0 .139 r
.50658 .55724 .50994 .52168 .5156 .54489 .51256 .50942 Mtetra
.753 .531 .595 r
.51256 .50942 .5156 .54489 .52141 .51969 .51835 .47798 Mtetra
.496 .334 .59 r
.51835 .47798 .52141 .51969 .52715 .49018 .52405 .48577 Mtetra
0 .114 .657 r
.52405 .48577 .52715 .49018 .53287 .48894 .52979 .49163 Mtetra
.946 .95 .642 r
.52979 .49163 .53287 .48894 .53863 .49367 .53551 .48024 Mtetra
.499 .412 .688 r
.53551 .48024 .53863 .49367 .54433 .48114 .54129 .48281 Mtetra
.823 .407 .254 r
.54129 .48281 .54433 .48114 .55009 .47982 .54713 .49239 Mtetra
0 0 .144 r
.54713 .49239 .55009 .47982 .55592 .48538 .55283 .4786 Mtetra
.194 .335 .779 r
.55283 .4786 .55592 .48538 .56161 .47465 .55869 .48343 Mtetra
.51 .171 .329 r
.55869 .48343 .56161 .47465 .56751 .48157 .56452 .4832 Mtetra
.934 .969 .707 r
.56452 .4832 .56751 .48157 .57328 .47669 .57025 .47379 Mtetra
.556 .048 0 r
.57025 .47379 .57328 .47669 .5791 .47526 .57621 .48005 Mtetra
.643 .813 .383 r
.57621 .48005 .5791 .47526 .585 .47673 .58192 .47019 Mtetra
.342 .436 .813 r
.58192 .47019 .585 .47673 .59078 .47139 .58787 .47338 Mtetra
.667 .939 .669 r
.58787 .47338 .59078 .47139 .59672 .47345 .59367 .46765 Mtetra
.557 .583 .836 r
.59367 .46765 .59672 .47345 .60254 .46893 .59959 .46765 Mtetra
.731 .912 .956 r
.59959 .46765 .60254 .46893 .60846 .46879 .60546 .46455 Mtetra
.636 .687 .881 r
.60546 .46455 .60846 .46879 .61435 .46658 .61137 .46312 Mtetra
.638 .732 .917 r
.61137 .46312 .61435 .46658 .62024 .46369 .6173 .46163 Mtetra
.721 .854 .945 r
.6173 .46163 .62024 .46369 .62622 .46393 .62321 .45882 Mtetra
.466 .565 .871 r
.62321 .45882 .62622 .46393 .63205 .45854 .62925 .45992 Mtetra
.767 .985 .744 r
.62925 .45992 .63205 .45854 .63811 .46008 .63507 .45389 Mtetra
.103 .298 .775 r
.63507 .45389 .63811 .46008 .64394 .45467 .6413 .45936 Mtetra
0 0 0 r
.6413 .45936 .64394 .45467 .64992 .4529 .647 .44969 Mtetra
0 .075 .59 r
.647 .44969 .64992 .4529 .656 .45347 .6533 .4556 Mtetra
0 0 0 r
.6533 .4556 .656 .45347 .66165 .44328 .65923 .45151 Mtetra
.056 0 .139 r
.65923 .45151 .66165 .44328 .66804 .45033 .665 .44357 Mtetra
0 0 .578 r
.665 .44357 .66804 .45033 .67371 .4406 .67156 .4536 Mtetra
0 0 .219 r
.67156 .4536 .67371 .4406 .67974 .43889 .67706 .43959 Mtetra
.788 .998 .809 r
.67706 .43959 .67974 .43889 .68631 .44771 .68294 .43402 Mtetra
.326 .3 .676 r
.68294 .43402 .68631 .44771 .69201 .43854 .68949 .4418 Mtetra
.808 .907 .504 r
.68949 .4418 .69201 .43854 .69811 .43711 .69513 .43121 Mtetra
.85 .707 .703 r
.69513 .43121 .69811 .43711 .70578 .46406 .70074 .4205 Mtetra
.264 .17 .557 r
.70074 .4205 .70578 .46406 .71321 .48453 .7086 .45016 Mtetra
0 0 .443 r
.7086 .45016 .71321 .48453 .71784 .45584 .71743 .49428 Mtetra
.418 .203 .477 r
.71743 .49428 .71784 .45584 .72185 .41841 .72295 .48003 Mtetra
.147 .017 .434 r
.72295 .48003 .72185 .41841 .72911 .43469 .72596 .42565 Mtetra
.787 .631 .688 r
.72596 .42565 .72911 .43469 .73902 .49069 .73163 .41598 Mtetra
.247 .142 .533 r
.73163 .41598 .73902 .49069 .74695 .51337 .74146 .46994 Mtetra
.107 .063 .52 r
.74146 .46994 .74695 .51337 .75023 .46668 .7507 .51157 Mtetra
.176 .029 .429 r
.7507 .51157 .75023 .46668 .75282 .41237 .75456 .47343 Mtetra
.068 0 .412 r
.75456 .47343 .75282 .41237 .76 .42407 .75653 .41068 Mtetra
.462 .394 .695 r
.75653 .41068 .76 .42407 .77111 .48778 .76319 .4147 Mtetra
.159 .083 .514 r
.76319 .4147 .77111 .48778 .78029 .52255 .7745 .47972 Mtetra
.173 .112 .542 r
.7745 .47972 .78029 .52255 .78395 .48487 .78394 .51708 Mtetra
0 0 .334 r
.78394 .51708 .78395 .48487 .78528 .41981 .78738 .47688 Mtetra
0 0 .391 r
.78738 .47688 .78528 .41981 .78984 .39675 .78856 .41056 Mtetra
0 0 .233 r
.78856 .41056 .78984 .39675 .79985 .43926 .79354 .39276 Mtetra
.062 .032 .507 r
.79354 .39276 .79985 .43926 .81291 .51482 .80429 .44282 Mtetra
.064 .02 .491 r
.80429 .44282 .81291 .51482 .82437 .56856 .81768 .5206 Mtetra
.116 .071 .525 r
.81768 .5206 .82437 .56856 .83141 .57077 .82872 .56834 Mtetra
.886 .871 .817 r
.82872 .56834 .83141 .57077 .83476 .53273 .83492 .56095 Mtetra
0 0 .265 r
.83492 .56095 .83476 .53273 .8368 .4821 .83763 .51624 Mtetra
0 0 .299 r
.83763 .51624 .8368 .4821 .83931 .43827 .83948 .46432 Mtetra
0 0 .268 r
.83948 .46432 .83931 .43827 .84298 .40775 .84218 .42302 Mtetra
0 0 .173 r
.84218 .42302 .84298 .40775 .84776 .38941 .84618 .39613 Mtetra
0 0 0 r
.84618 .39613 .84776 .38941 .85335 .37943 .85125 .38067 Mtetra
.827 .965 .641 r
.85125 .38067 .85335 .37943 .85941 .3741 .85702 .37234 Mtetra
.809 .92 .912 r
.85702 .37234 .85941 .3741 .8657 .3709 .86318 .36778 Mtetra
.715 .801 .918 r
.86318 .36778 .8657 .3709 .87209 .36849 .86953 .36488 Mtetra
.678 .757 .91 r
.86953 .36488 .87209 .36849 .87851 .36633 .87595 .3626 Mtetra
.667 .745 .908 r
.87595 .3626 .87851 .36633 .88496 .36424 .8824 .36048 Mtetra
.665 .743 .908 r
.8824 .36048 .88496 .36424 .89142 .36219 .88888 .35841 Mtetra
.664 .742 .908 r
.88888 .35841 .89142 .36219 .8979 .36013 .89537 .35634 Mtetra
.89537 .35634 .8979 .36013 .9044 .35808 .90187 .35427 Mtetra
.664 .741 .908 r
.90187 .35427 .9044 .35808 .91091 .35602 .90839 .35221 Mtetra
.90839 .35221 .91091 .35602 .91743 .35396 .91493 .35013 Mtetra
.663 .741 .908 r
.32813 .53202 .33147 .53514 .33679 .53345 .33345 .53033 Mtetra
.33345 .53033 .33679 .53345 .34211 .53176 .33878 .52864 Mtetra
.33878 .52864 .34211 .53176 .34745 .53008 .34412 .52694 Mtetra
.34412 .52694 .34745 .53008 .3528 .52839 .34948 .52525 Mtetra
.661 .741 .909 r
.34948 .52525 .3528 .52839 .35815 .52671 .35484 .52358 Mtetra
.652 .739 .913 r
.35484 .52358 .35815 .52671 .36352 .52508 .36021 .52203 Mtetra
.616 .735 .931 r
.36021 .52203 .36352 .52508 .36889 .52362 .36557 .52092 Mtetra
.461 .704 .973 r
.36557 .52092 .36889 .52362 .37424 .52276 .37088 .521 Mtetra
.364 0 0 r
.37088 .521 .37424 .52276 .37953 .52355 .37609 .52389 Mtetra
.836 .417 .242 r
.37609 .52389 .37953 .52355 .38469 .52808 .38108 .53251 Mtetra
.854 .529 .437 r
.38108 .53251 .38469 .52808 .38959 .53966 .38569 .55126 Mtetra
.842 .551 .497 r
.38569 .55126 .38959 .53966 .39412 .56241 .38981 .58439 Mtetra
.821 .545 .521 r
.38981 .58439 .39412 .56241 .39822 .59901 .39355 .6307 Mtetra
.784 .515 .529 r
.39355 .6307 .39822 .59901 .40211 .6454 .39752 .67538 Mtetra
.666 .401 .51 r
.39752 .67538 .40211 .6454 .40644 .68401 .40274 .68872 Mtetra
.983 .781 .554 r
.40274 .68872 .40644 .68401 .41208 .68594 .40984 .6474 Mtetra
.836 .597 .577 r
.40984 .6474 .41208 .68594 .41937 .63489 .418 .56837 Mtetra
.753 .522 .582 r
.418 .56837 .41937 .63489 .4273 .55609 .42537 .50805 Mtetra
.519 .344 .584 r
.42537 .50805 .4273 .55609 .43422 .50578 .43068 .514 Mtetra
.902 .615 .49 r
.43068 .514 .43422 .50578 .43929 .5219 .43457 .57478 Mtetra
.72 .463 .537 r
.43457 .57478 .43929 .5219 .44335 .58321 .4392 .61471 Mtetra
0 0 .114 r
.4392 .61471 .44335 .58321 .44827 .61611 .44584 .57494 Mtetra
.818 .58 .579 r
.44584 .57494 .44827 .61611 .45486 .57378 .45298 .50628 Mtetra
.579 .383 .58 r
.45298 .50628 .45486 .57378 .46177 .50777 .45861 .5033 Mtetra
.96 .664 .428 r
.45861 .5033 .46177 .50777 .46743 .50314 .46304 .56606 Mtetra
.659 .412 .534 r
.46304 .56606 .46743 .50314 .47209 .56179 .46833 .5908 Mtetra
.819 .716 .183 r
.46833 .5908 .47209 .56179 .47736 .59292 .47494 .53327 Mtetra
.74 .511 .583 r
.47494 .53327 .47736 .59292 .4837 .54638 .48125 .48568 Mtetra
.33 .195 .542 r
.48125 .48568 .4837 .54638 .48999 .4912 .48652 .51563 Mtetra
.827 .545 .512 r
.48652 .51563 .48999 .4912 .49555 .49957 .4917 .56742 Mtetra
.467 .253 .504 r
.4917 .56742 .49555 .49957 .50086 .54918 .49762 .55139 Mtetra
.973 .742 .526 r
.49762 .55139 .50086 .54918 .50658 .55724 .50378 .492 Mtetra
.631 .424 .583 r
.50378 .492 .50658 .55724 .51256 .50942 .50955 .47741 Mtetra
.138 .083 .527 r
.50955 .47741 .51256 .50942 .51835 .47798 .51517 .50213 Mtetra
.561 .297 .473 r
.51517 .50213 .51835 .47798 .52405 .48577 .52092 .50307 Mtetra
0 0 .164 r
.52092 .50307 .52405 .48577 .52979 .49163 .52668 .48329 Mtetra
.537 .502 .764 r
.52668 .48329 .52979 .49163 .53551 .48024 .53244 .484 Mtetra
.797 .413 .33 r
.53244 .484 .53551 .48024 .54129 .48281 .53826 .4939 Mtetra
0 0 0 r
.53826 .4939 .54129 .48281 .54713 .49239 .54398 .47792 Mtetra
.618 .483 .675 r
.54398 .47792 .54713 .49239 .55283 .4786 .54976 .47572 Mtetra
0 .215 .696 r
.54976 .47572 .55283 .4786 .55869 .48343 .55562 .47989 Mtetra
.904 .758 .689 r
.55562 .47989 .55869 .48343 .56452 .4832 .56132 .46667 Mtetra
.418 .336 .657 r
.56132 .46667 .56452 .4832 .57025 .47379 .56723 .47272 Mtetra
.913 .886 .793 r
.56723 .47272 .57025 .47379 .57621 .48005 .57299 .46482 Mtetra
.564 .443 .673 r
.57299 .46482 .57621 .48005 .58192 .47019 .57887 .46514 Mtetra
.687 .67 .828 r
.57887 .46514 .58192 .47019 .58787 .47338 .58471 .46259 Mtetra
.64 .528 .71 r
.58471 .46259 .58787 .47338 .59367 .46765 .59057 .46007 Mtetra
.614 .563 .773 r
.59057 .46007 .59367 .46765 .59959 .46765 .59647 .45892 Mtetra
.649 .561 .741 r
.59647 .45892 .59959 .46765 .60546 .46455 .60235 .45653 Mtetra
.638 .567 .758 r
.60235 .45653 .60546 .46455 .61137 .46312 .60825 .45463 Mtetra
.615 .546 .754 r
.60825 .45463 .61137 .46312 .6173 .46163 .61419 .45338 Mtetra
.664 .577 .748 r
.61419 .45338 .6173 .46163 .62321 .45882 .6201 .45059 Mtetra
.601 .544 .762 r
.6201 .45059 .62321 .45882 .62925 .45992 .62607 .44973 Mtetra
.622 .525 .723 r
.62607 .44973 .62925 .45992 .63507 .45389 .63204 .44802 Mtetra
.707 .654 .794 r
.63204 .44802 .63507 .45389 .6413 .45936 .63796 .44464 Mtetra
.482 .394 .679 r
.63796 .44464 .6413 .45936 .647 .44969 .64414 .44815 Mtetra
.926 .863 .758 r
.64414 .44815 .647 .44969 .6533 .4556 .64986 .43886 Mtetra
.319 .271 .646 r
.64986 .43886 .6533 .4556 .65923 .45151 .65632 .44836 Mtetra
.879 .797 .765 r
.65632 .44836 .65923 .45151 .665 .44357 .66208 .43998 Mtetra
.579 .705 .928 r
.66208 .43998 .665 .44357 .67156 .4536 .66817 .43923 Mtetra
.15 .174 .631 r
.66817 .43923 .67156 .4536 .67706 .43959 .67487 .45136 Mtetra
0 0 .155 r
.67487 .45136 .67706 .43959 .68294 .43402 .68036 .43685 Mtetra
0 0 0 r
.68036 .43685 .68294 .43402 .68949 .4418 .68637 .43343 Mtetra
0 0 .362 r
.68637 .43343 .68949 .4418 .69513 .43121 .69341 .44989 Mtetra
.421 .164 .417 r
.69341 .44989 .69513 .43121 .70074 .4205 .69931 .44361 Mtetra
0 0 .271 r
.69931 .44361 .70074 .4205 .7086 .45016 .70399 .41508 Mtetra
.421 .29 .596 r
.70399 .41508 .7086 .45016 .71743 .49428 .71097 .42839 Mtetra
.151 .076 .51 r
.71097 .42839 .71743 .49428 .72295 .48003 .72061 .48549 Mtetra
.767 .377 .316 r
.72061 .48549 .72295 .48003 .72596 .42565 .72761 .49528 Mtetra
.179 .043 .447 r
.72761 .49528 .72596 .42565 .73163 .41598 .73039 .43734 Mtetra
0 0 .208 r
.73039 .43734 .73163 .41598 .74146 .46994 .73468 .4056 Mtetra
.241 .142 .536 r
.73468 .4056 .74146 .46994 .7507 .51157 .74413 .45272 Mtetra
.141 .075 .515 r
.74413 .45272 .7507 .51157 .75456 .47343 .75422 .50593 Mtetra
.089 0 .381 r
.75422 .50593 .75456 .47343 .75653 .41068 .75849 .47379 Mtetra
.044 0 .406 r
.75849 .47379 .75653 .41068 .76319 .4147 .7601 .40659 Mtetra
.449 .461 .78 r
.7601 .40659 .76319 .4147 .7745 .47972 .76668 .40916 Mtetra
.117 .054 .503 r
.76668 .40916 .7745 .47972 .78394 .51708 .77831 .47691 Mtetra
.181 .12 .548 r
.77831 .47691 .78394 .51708 .78738 .47688 .7876 .51135 Mtetra
0 0 .309 r
.7876 .51135 .78738 .47688 .78856 .41056 .79044 .46394 Mtetra
0 0 .374 r
.79044 .46394 .78856 .41056 .79354 .39276 .79162 .39854 Mtetra
0 0 .024 r
.79162 .39854 .79354 .39276 .80429 .44282 .7975 .3914 Mtetra
.006 0 .484 r
.7975 .3914 .80429 .44282 .81768 .5206 .80922 .45159 Mtetra
.038 .003 .484 r
.80922 .45159 .81768 .5206 .82872 .56834 .82276 .52922 Mtetra
.138 .095 .542 r
.82276 .52922 .82872 .56834 .83492 .56095 .83298 .56667 Mtetra
.782 .775 .27 r
.83298 .56667 .83492 .56095 .83763 .51624 .83813 .54757 Mtetra
0 0 .266 r
.83813 .54757 .83763 .51624 .83948 .46432 .84021 .49682 Mtetra
0 0 .281 r
.84021 .49682 .83948 .46432 .84218 .42302 .84202 .44512 Mtetra
0 0 .227 r
.84202 .44512 .84218 .42302 .84618 .39613 .84502 .40741 Mtetra
0 0 .072 r
.84502 .40741 .84618 .39613 .85125 .38067 .8494 .38458 Mtetra
.691 .789 .316 r
.8494 .38458 .85125 .38067 .85702 .37234 .85478 .3721 Mtetra
.87 .993 .81 r
.85478 .3721 .85702 .37234 .86318 .36778 .86073 .36543 Mtetra
.771 .872 .922 r
.86073 .36543 .86318 .36778 .86953 .36488 .86699 .36157 Mtetra
.7 .785 .917 r
.86699 .36157 .86953 .36488 .87595 .3626 .87338 .35892 Mtetra
.673 .752 .91 r
.87338 .35892 .87595 .3626 .8824 .36048 .87984 .3567 Mtetra
.666 .743 .908 r
.87984 .3567 .8824 .36048 .88888 .35841 .88632 .3546 Mtetra
.664 .741 .908 r
.88632 .3546 .88888 .35841 .89537 .35634 .89282 .35253 Mtetra
.89282 .35253 .89537 .35634 .90187 .35427 .89934 .35046 Mtetra
.89934 .35046 .90187 .35427 .90839 .35221 .90587 .34838 Mtetra
.90587 .34838 .90839 .35221 .91493 .35013 .91241 .3463 Mtetra
.32477 .5289 .32813 .53202 .33345 .53033 .3301 .5272 Mtetra
.3301 .5272 .33345 .53033 .33878 .52864 .33544 .5255 Mtetra
.663 .741 .908 r
.33544 .5255 .33878 .52864 .34412 .52694 .34079 .5238 Mtetra
.662 .741 .908 r
.34079 .5238 .34412 .52694 .34948 .52525 .34615 .52211 Mtetra
.656 .74 .912 r
.34615 .52211 .34948 .52525 .35484 .52358 .35151 .52051 Mtetra
.634 .739 .924 r
.35151 .52051 .35484 .52358 .36021 .52203 .35687 .51919 Mtetra
.553 .729 .957 r
.35687 .51919 .36021 .52203 .36557 .52092 .36221 .51864 Mtetra
.128 .562 .923 r
.36221 .51864 .36557 .52092 .37088 .521 .36747 .52006 Mtetra
.773 .271 .003 r
.36747 .52006 .37088 .521 .37609 .52389 .37255 .52593 Mtetra
.863 .512 .385 r
.37255 .52593 .37609 .52389 .38108 .53251 .37727 .54061 Mtetra
.854 .555 .481 r
.37727 .54061 .38108 .53251 .38569 .55126 .38147 .56933 Mtetra
.833 .554 .515 r
.38147 .56933 .38569 .55126 .38981 .58439 .38514 .61353 Mtetra
.801 .53 .528 r
.38514 .61353 .38981 .58439 .39355 .6307 .3888 .66233 Mtetra
.725 .457 .522 r
.3888 .66233 .39355 .6307 .39752 .67538 .3935 .6879 Mtetra
.903 .837 .376 r
.3935 .6879 .39752 .67538 .40274 .68872 .40018 .66087 Mtetra
.859 .62 .577 r
.40018 .66087 .40274 .68872 .40984 .6474 .40843 .58597 Mtetra
.78 .545 .58 r
.40843 .58597 .40984 .6474 .418 .56837 .41633 .51481 Mtetra
.621 .42 .589 r
.41633 .51481 .418 .56837 .42537 .50805 .42212 .50507 Mtetra
.951 .656 .442 r
.42212 .50507 .42537 .50805 .43068 .514 .42596 .56142 Mtetra
.756 .494 .536 r
.42596 .56142 .43068 .514 .43457 .57478 .43016 .61204 Mtetra
.047 0 .33 r
.43016 .61204 .43457 .57478 .4392 .61471 .43666 .58103 Mtetra
.843 .603 .576 r
.43666 .58103 .4392 .61471 .44584 .57494 .44409 .50839 Mtetra
.604 .402 .582 r
.44409 .50839 .44584 .57494 .45298 .50628 .44983 .50019 Mtetra
.965 .67 .422 r
.44983 .50019 .45298 .50628 .45861 .5033 .45405 .56465 Mtetra
.659 .411 .533 r
.45405 .56465 .45861 .5033 .46304 .56606 .45928 .58872 Mtetra
.965 .792 .356 r
.45928 .58872 .46304 .56606 .46833 .5908 .46613 .52582 Mtetra
.717 .492 .583 r
.46613 .52582 .46833 .5908 .47494 .53327 .47245 .48421 Mtetra
.006 0 .449 r
.47245 .48421 .47494 .53327 .48125 .48568 .47743 .52832 Mtetra
.758 .491 .529 r
.47743 .52832 .48125 .48568 .48652 .51563 .48256 .5743 Mtetra
.221 .052 .428 r
.48256 .5743 .48652 .51563 .4917 .56742 .48877 .53606 Mtetra
.829 .591 .58 r
.48877 .53606 .4917 .56742 .49762 .55139 .49503 .47961 Mtetra
.489 .312 .568 r
.49503 .47961 .49762 .55139 .50378 .492 .5006 .49343 Mtetra
.927 .608 .418 r
.5006 .49343 .50378 .492 .50955 .47741 .50611 .53048 Mtetra
.417 .206 .483 r
.50611 .53048 .50955 .47741 .51517 .50213 .51197 .51258 Mtetra
.977 .827 .42 r
.51197 .51258 .51517 .50213 .52092 .50307 .51783 .47783 Mtetra
.57 .41 .625 r
.51783 .47783 .52092 .50307 .52668 .48329 .52357 .47765 Mtetra
0 0 .539 r
.52357 .47765 .52668 .48329 .53244 .484 .52934 .48586 Mtetra
.985 .896 .641 r
.52934 .48586 .53244 .484 .53826 .4939 .53509 .4712 Mtetra
.592 .431 .633 r
.53509 .4712 .53826 .4939 .54398 .47792 .54086 .46959 Mtetra
.118 .24 .715 r
.54086 .46959 .54398 .47792 .54976 .47572 .54671 .47633 Mtetra
.972 .891 .687 r
.54671 .47633 .54976 .47572 .55562 .47989 .55243 .46373 Mtetra
.363 .301 .653 r
.55243 .46373 .55562 .47989 .56132 .46667 .55834 .4712 Mtetra
0 0 0 r
.55834 .4712 .56132 .46667 .56723 .47272 .56413 .46583 Mtetra
.645 .595 .783 r
.56413 .46583 .56723 .47272 .57299 .46482 .56997 .46396 Mtetra
0 .401 .683 r
.56997 .46396 .57299 .46482 .57887 .46514 .57588 .46563 Mtetra
.849 .994 .836 r
.57588 .46563 .57887 .46514 .58471 .46259 .58169 .45976 Mtetra
.1 .496 .902 r
.58169 .45976 .58471 .46259 .59057 .46007 .58765 .46204 Mtetra
.543 .885 .64 r
.58765 .46204 .59057 .46007 .59647 .45892 .59349 .45722 Mtetra
.368 .748 .989 r
.59349 .45722 .59647 .45892 .60235 .45653 .59944 .45716 Mtetra
.366 .833 .784 r
.59944 .45716 .60235 .45653 .60825 .45463 .60535 .4549 Mtetra
.57 .939 .884 r
.60535 .4549 .60825 .45463 .61419 .45338 .61125 .45193 Mtetra
.221 .682 .946 r
.61125 .45193 .61419 .45338 .6201 .45059 .61727 .45239 Mtetra
.667 .944 .684 r
.61727 .45239 .6201 .45059 .62607 .44973 .62311 .44676 Mtetra
.182 .538 .925 r
.62311 .44676 .62607 .44973 .63204 .44802 .62921 .44877 Mtetra
.804 1 .814 r
.62921 .44877 .63204 .44802 .63796 .44464 .63507 .44311 Mtetra
.546 .846 .998 r
.63507 .44311 .63796 .44464 .64414 .44815 .64108 .44179 Mtetra
.506 .54 .825 r
.64108 .44179 .64414 .44815 .64986 .43886 .6472 .44272 Mtetra
.772 .884 .467 r
.6472 .44272 .64986 .43886 .65632 .44836 .65288 .43202 Mtetra
.333 .283 .651 r
.65288 .43202 .65632 .44836 .66208 .43998 .65934 .44089 Mtetra
.964 .94 .685 r
.65934 .44089 .66208 .43998 .66817 .43923 .665 .42985 Mtetra
.612 .532 .739 r
.665 .42985 .66817 .43923 .67487 .45136 .67108 .42855 Mtetra
.371 .28 .621 r
.67108 .42855 .67487 .45136 .68036 .43685 .67775 .43939 Mtetra
.942 .931 .576 r
.67775 .43939 .68036 .43685 .68637 .43343 .68331 .42648 Mtetra
.656 .603 .784 r
.68331 .42648 .68637 .43343 .69341 .44989 .68939 .42424 Mtetra
0 0 .465 r
.68939 .42424 .69341 .44989 .69931 .44361 .69729 .45638 Mtetra
.728 .403 .43 r
.69729 .45638 .69931 .44361 .70399 .41508 .70425 .46869 Mtetra
.196 .046 .439 r
.70425 .46869 .70399 .41508 .71097 .42839 .70821 .42641 Mtetra
.961 .816 .656 r
.70821 .42641 .71097 .42839 .72061 .48549 .71359 .41113 Mtetra
.225 .125 .526 r
.71359 .41113 .72061 .48549 .72761 .49528 .7232 .46659 Mtetra
0 0 .503 r
.7232 .46659 .72761 .49528 .73039 .43734 .73162 .4991 Mtetra
.16 .026 .437 r
.73162 .4991 .73039 .43734 .73468 .4056 .73469 .4459 Mtetra
0 0 .354 r
.73469 .4459 .73468 .4056 .74413 .45272 .73802 .39952 Mtetra
.211 .127 .537 r
.73802 .39952 .74413 .45272 .75422 .50593 .74719 .44116 Mtetra
.138 .07 .51 r
.74719 .44116 .75422 .50593 .75849 .47379 .75774 .49996 Mtetra
0 0 .311 r
.75774 .49996 .75849 .47379 .7601 .40659 .76202 .46813 Mtetra
.01 0 .393 r
.76202 .46813 .7601 .40659 .76668 .40916 .76346 .39934 Mtetra
.191 .263 .709 r
.76346 .39934 .76668 .40916 .77831 .47691 .77049 .40747 Mtetra
.075 .025 .491 r
.77049 .40747 .77831 .47691 .7876 .51135 .78253 .47897 Mtetra
.23 .166 .574 r
.78253 .47897 .7876 .51135 .79044 .46394 .79115 .50397 Mtetra
0 0 .3 r
.79115 .50397 .79044 .46394 .79162 .39854 .79308 .4459 Mtetra
0 0 .358 r
.79308 .4459 .79162 .39854 .7975 .3914 .79461 .38567 Mtetra
0 .083 .643 r
.79461 .38567 .7975 .3914 .80922 .45159 .8019 .39478 Mtetra
0 0 .463 r
.8019 .39478 .80922 .45159 .82276 .52922 .8147 .46577 Mtetra
.024 0 .483 r
.8147 .46577 .82276 .52922 .83298 .56667 .82798 .53866 Mtetra
.225 .175 .588 r
.82798 .53866 .83298 .56667 .83813 .54757 .83693 .5611 Mtetra
0 0 .015 r
.83693 .5611 .83813 .54757 .84021 .49682 .8409 .52954 Mtetra
0 0 .258 r
.8409 .52954 .84021 .49682 .84202 .44512 .84254 .47483 Mtetra
0 0 .259 r
.84254 .47483 .84202 .44512 .84502 .40741 .84451 .42548 Mtetra
0 0 .177 r
.84451 .42548 .84502 .40741 .8494 .38458 .84791 .39229 Mtetra
0 0 0 r
.84791 .39229 .8494 .38458 .85478 .3721 .85269 .37358 Mtetra
.859 .95 .595 r
.85269 .37358 .85478 .3721 .86073 .36543 .85836 .36387 Mtetra
.837 .937 .892 r
.85836 .36387 .86073 .36543 .86699 .36157 .86448 .35867 Mtetra
.734 .825 .921 r
.86448 .35867 .86699 .36157 .87338 .35892 .87083 .35544 Mtetra
.687 .771 .915 r
.87083 .35544 .87338 .35892 .87984 .3567 .87727 .35298 Mtetra
.67 .749 .91 r
.87727 .35298 .87984 .3567 .88632 .3546 .88375 .3508 Mtetra
.665 .743 .908 r
.88375 .3508 .88632 .3546 .89282 .35253 .89026 .3487 Mtetra
.664 .741 .908 r
.89026 .3487 .89282 .35253 .89934 .35046 .89679 .34662 Mtetra
.89679 .34662 .89934 .35046 .90587 .34838 .90333 .34453 Mtetra
.90333 .34453 .90587 .34838 .91241 .3463 .90989 .34245 Mtetra
.3214 .52576 .32477 .5289 .3301 .5272 .32674 .52406 Mtetra
.663 .741 .908 r
.32674 .52406 .3301 .5272 .33544 .5255 .33208 .52235 Mtetra
.662 .741 .908 r
.33208 .52235 .33544 .5255 .34079 .5238 .33744 .52066 Mtetra
.659 .741 .911 r
.33744 .52066 .34079 .5238 .34615 .52211 .3428 .51901 Mtetra
.647 .741 .918 r
.3428 .51901 .34615 .52211 .35151 .52051 .34817 .51751 Mtetra
.608 .737 .937 r
.34817 .51751 .35151 .52051 .35687 .51919 .35352 .51647 Mtetra
.433 .692 .973 r
.35352 .51647 .35687 .51919 .36221 .51864 .35882 .51672 Mtetra
.48 0 0 r
.35882 .51672 .36221 .51864 .36747 .52006 .36398 .52031 Mtetra
.864 .47 .293 r
.36398 .52031 .36747 .52006 .37255 .52593 .36883 .53117 Mtetra
.863 .55 .458 r
.36883 .53117 .37255 .52593 .37727 .54061 .37316 .55472 Mtetra
.843 .558 .507 r
.37316 .55472 .37727 .54061 .38147 .56933 .37688 .59444 Mtetra
.816 .543 .525 r
.37688 .59444 .38147 .56933 .38514 .61353 .38033 .64424 Mtetra
.767 .497 .526 r
.38033 .64424 .38514 .61353 .3888 .66233 .38447 .68118 Mtetra
.325 .07 .365 r
.38447 .68118 .3888 .66233 .3935 .6879 .3905 .67263 Mtetra
.889 .655 .577 r
.3905 .67263 .3935 .6879 .40018 .66087 .39857 .60837 Mtetra
.808 .57 .578 r
.39857 .60837 .40018 .66087 .40843 .58597 .407 .52841 Mtetra
.698 .479 .588 r
.407 .52841 .40843 .58597 .41633 .51481 .41351 .49812 Mtetra
.956 .674 .233 r
.41351 .49812 .41633 .51481 .42212 .50507 .41753 .5435 Mtetra
.799 .531 .533 r
.41753 .5435 .42212 .50507 .42596 .56142 .42122 .6056 Mtetra
.408 .19 .468 r
.42122 .6056 .42596 .56142 .43016 .61204 .42732 .59074 Mtetra
.881 .64 .569 r
.42732 .59074 .43016 .61204 .43666 .58103 .43503 .51512 Mtetra
.653 .441 .584 r
.43503 .51512 .43666 .58103 .44409 .50839 .44112 .49454 Mtetra
.982 .692 .357 r
.44112 .49454 .44409 .50839 .44983 .50019 .44518 .55753 Mtetra
.685 .432 .534 r
.44518 .55753 .44983 .50019 .45405 .56465 .45019 .58797 Mtetra
.964 .792 .356 r
.45019 .58797 .45405 .56465 .45928 .58872 .45721 .52431 Mtetra
.717 .491 .583 r
.45721 .52431 .45928 .58872 .46613 .52582 .46363 .48315 Mtetra
0 0 .319 r
.46363 .48315 .46613 .52582 .47245 .48421 .46837 .53426 Mtetra
.726 .465 .532 r
.46837 .53426 .47245 .48421 .47743 .52832 .47347 .57434 Mtetra
0 0 .224 r
.47347 .57434 .47743 .52832 .48256 .5743 .47997 .52148 Mtetra
.749 .52 .583 r
.47997 .52148 .48256 .5743 .48877 .53606 .48622 .47577 Mtetra
.203 .101 .508 r
.48622 .47577 .48877 .53606 .49503 .47961 .49147 .51622 Mtetra
.748 .477 .522 r
.49147 .51622 .49503 .47961 .5006 .49343 .49692 .5524 Mtetra
.151 0 .406 r
.49692 .5524 .5006 .49343 .50611 .53048 .50304 .5084 Mtetra
.834 .604 .589 r
.50304 .5084 .50611 .53048 .51197 .51258 .509 .46732 Mtetra
.475 .314 .582 r
.509 .46732 .51197 .51258 .51783 .47783 .51469 .4776 Mtetra
.804 .327 .082 r
.51469 .4776 .51783 .47783 .52357 .47765 .52043 .48517 Mtetra
.788 .822 .346 r
.52043 .48517 .52357 .47765 .52934 .48586 .52621 .46893 Mtetra
.497 .388 .659 r
.52621 .46893 .52934 .48586 .53509 .4712 .53199 .47212 Mtetra
.838 .413 .226 r
.53199 .47212 .53509 .4712 .54086 .46959 .53783 .48214 Mtetra
0 0 .052 r
.53783 .48214 .54086 .46959 .54671 .47633 .54357 .46587 Mtetra
.253 .286 .703 r
.54357 .46587 .54671 .47633 .55243 .46373 .54944 .47244 Mtetra
.446 .107 .297 r
.54944 .47244 .55243 .46373 .55834 .4712 .55528 .47078 Mtetra
.937 .903 .766 r
.55528 .47078 .55834 .4712 .56413 .46583 .56105 .46177 Mtetra
0 .035 .577 r
.56105 .46177 .56413 .46583 .56997 .46396 .56701 .46825 Mtetra
.766 .887 .476 r
.56701 .46825 .56997 .46396 .57588 .46563 .57276 .45777 Mtetra
.332 .392 .774 r
.57276 .45777 .57588 .46563 .58169 .45976 .57874 .46175 Mtetra
.743 .966 .688 r
.57874 .46175 .58169 .45976 .58765 .46204 .58455 .45533 Mtetra
.532 .542 .811 r
.58455 .45533 .58765 .46204 .59349 .45722 .5905 .45587 Mtetra
.754 .91 .945 r
.5905 .45587 .59349 .45722 .59944 .45716 .59639 .45246 Mtetra
.632 .665 .864 r
.59639 .45246 .59944 .45716 .60535 .4549 .60233 .45107 Mtetra
.629 .709 .904 r
.60233 .45107 .60535 .4549 .61125 .45193 .60828 .44972 Mtetra
.75 .848 .924 r
.60828 .44972 .61125 .45193 .61727 .45239 .6142 .44643 Mtetra
.444 .52 .841 r
.6142 .44643 .61727 .45239 .62311 .44676 .62027 .44809 Mtetra
.832 .994 .747 r
.62027 .44809 .62311 .44676 .62921 .44877 .6261 .44125 Mtetra
.149 .285 .749 r
.6261 .44125 .62921 .44877 .63507 .44311 .63235 .44733 Mtetra
.688 .842 .418 r
.63235 .44733 .63507 .44311 .64108 .44179 .63809 .4373 Mtetra
0 .212 .736 r
.63809 .4373 .64108 .44179 .6472 .44272 .64438 .4429 Mtetra
.546 .929 .885 r
.64438 .4429 .6472 .44272 .65288 .43202 .65038 .44007 Mtetra
0 0 .056 r
.65038 .44007 .65288 .43202 .65934 .44089 .65612 .43041 Mtetra
0 .039 .588 r
.65612 .43041 .65934 .44089 .665 .42985 .66279 .44297 Mtetra
0 0 .2 r
.66279 .44297 .665 .42985 .67108 .42855 .66832 .4283 Mtetra
.868 .977 .849 r
.66832 .4283 .67108 .42855 .67775 .43939 .67421 .42227 Mtetra
.218 .2 .624 r
.67421 .42227 .67775 .43939 .68331 .42648 .68099 .43494 Mtetra
0 0 0 r
.68099 .43494 .68331 .42648 .68939 .42424 .68658 .42222 Mtetra
.948 .826 .69 r
.68658 .42222 .68939 .42424 .69729 .45638 .69214 .4093 Mtetra
.158 .09 .524 r
.69214 .4093 .69729 .45638 .70425 .46869 .70048 .44893 Mtetra
0 0 .25 r
.70048 .44893 .70425 .46869 .70821 .42641 .70896 .48791 Mtetra
.25 .09 .459 r
.70896 .48791 .70821 .42641 .71359 .41113 .7129 .445 Mtetra
0 0 .302 r
.7129 .445 .71359 .41113 .7232 .46659 .71671 .40233 Mtetra
.245 .144 .536 r
.71671 .40233 .7232 .46659 .73162 .4991 .7258 .44799 Mtetra
.111 .057 .51 r
.7258 .44799 .73162 .4991 .73469 .4459 .73523 .49571 Mtetra
.094 0 .406 r
.73523 .49571 .73469 .4459 .73802 .39952 .7386 .44769 Mtetra
0 0 .374 r
.7386 .44769 .73802 .39952 .74719 .44116 .74144 .39415 Mtetra
.151 .089 .527 r
.74144 .39415 .74719 .44116 .75774 .49996 .75067 .43565 Mtetra
.13 .064 .508 r
.75067 .43565 .75774 .49996 .76202 .46813 .76135 .49488 Mtetra
0 0 .256 r
.76135 .49488 .76202 .46813 .76346 .39934 .76514 .45643 Mtetra
0 0 .378 r
.76514 .45643 .76346 .39934 .77049 .40747 .76666 .38973 Mtetra
0 .036 .553 r
.76666 .38973 .77049 .40747 .78253 .47897 .77471 .41061 Mtetra
.045 .005 .482 r
.77471 .41061 .78253 .47897 .79115 .50397 .78706 .48438 Mtetra
.414 .327 .649 r
.78706 .48438 .79115 .50397 .79308 .4459 .79438 .49239 Mtetra
0 0 .3 r
.79438 .49239 .79308 .4459 .79461 .38567 .79533 .4233 Mtetra
0 0 .343 r
.79533 .4233 .79461 .38567 .8019 .39478 .79781 .37507 Mtetra
0 0 .463 r
.79781 .37507 .8019 .39478 .8147 .46577 .80697 .40524 Mtetra
0 0 .448 r
.80697 .40524 .8147 .46577 .82798 .53866 .82068 .48475 Mtetra
.03 .007 .492 r
.82068 .48475 .82798 .53866 .83693 .5611 .83308 .54611 Mtetra
.496 .411 .689 r
.83308 .54611 .83693 .5611 .8409 .52954 .84032 .54934 Mtetra
0 0 .096 r
.84032 .54934 .8409 .52954 .84254 .47483 .84317 .50629 Mtetra
0 0 .236 r
.84317 .50629 .84254 .47483 .84451 .42548 .84466 .45086 Mtetra
0 0 .226 r
.84466 .45086 .84451 .42548 .84791 .39229 .84702 .40626 Mtetra
0 0 .112 r
.84702 .40626 .84791 .39229 .85269 .37358 .85093 .3784 Mtetra
.69 .751 .251 r
.85093 .3784 .85269 .37358 .85836 .36387 .8561 .36355 Mtetra
.899 .984 .788 r
.8561 .36355 .85836 .36387 .86448 .35867 .86201 .35612 Mtetra
.779 .862 .911 r
.86201 .35612 .86448 .35867 .87083 .35544 .86828 .35207 Mtetra
.704 .785 .914 r
.86828 .35207 .87083 .35544 .87727 .35298 .8747 .34932 Mtetra
.677 .757 .912 r
.8747 .34932 .87727 .35298 .88375 .3508 .88118 .34702 Mtetra
.668 .747 .91 r
.88118 .34702 .88375 .3508 .89026 .3487 .8877 .34487 Mtetra
.665 .743 .908 r
.8877 .34487 .89026 .3487 .89679 .34662 .89423 .34277 Mtetra
.664 .741 .908 r
.89423 .34277 .89679 .34662 .90333 .34453 .90079 .34067 Mtetra
.90079 .34067 .90333 .34453 .90989 .34245 .90735 .33858 Mtetra
.663 .741 .908 r
.31802 .52261 .3214 .52576 .32674 .52406 .32336 .52091 Mtetra
.32336 .52091 .32674 .52406 .33208 .52235 .32871 .5192 Mtetra
.661 .742 .909 r
.32871 .5192 .33208 .52235 .33744 .52066 .33407 .51751 Mtetra
.657 .741 .912 r
.33407 .51751 .33744 .52066 .3428 .51901 .33944 .51589 Mtetra
.637 .738 .921 r
.33944 .51589 .3428 .51901 .34817 .51751 .34481 .51452 Mtetra
.554 .72 .95 r
.34481 .51452 .34817 .51751 .35352 .51647 .35014 .51399 Mtetra
.048 .495 .888 r
.35014 .51399 .35352 .51647 .35882 .51672 .35537 .51585 Mtetra
.826 .365 .119 r
.35537 .51585 .35882 .51672 .36398 .52031 .36034 .52327 Mtetra
.866 .533 .419 r
.36034 .52327 .36398 .52031 .36883 .53117 .36486 .54116 Mtetra
.852 .559 .493 r
.36486 .54116 .36883 .53117 .37316 .55472 .36875 .57431 Mtetra
.833 .555 .518 r
.36875 .57431 .37316 .55472 .37688 .59444 .37214 .62159 Mtetra
.801 .529 .526 r
.37214 .62159 .37688 .59444 .38033 .64424 .37576 .66733 Mtetra
.68 .403 .497 r
.37576 .66733 .38033 .64424 .38447 .68118 .38092 .67967 Mtetra
.944 .725 .577 r
.38092 .67967 .38447 .68118 .3905 .67263 .38845 .63363 Mtetra
.839 .6 .576 r
.38845 .63363 .3905 .67263 .39857 .60837 .39724 .55052 Mtetra
.755 .525 .584 r
.39724 .55052 .39857 .60837 .407 .52841 .40471 .49715 Mtetra
.032 0 .482 r
.40471 .49715 .407 .52841 .41351 .49812 .40928 .52294 Mtetra
.849 .574 .522 r
.40928 .52294 .41351 .49812 .41753 .5435 .41251 .59238 Mtetra
.607 .361 .518 r
.41251 .59238 .41753 .5435 .42122 .6056 .41789 .60099 Mtetra
.937 .7 .553 r
.41789 .60099 .42122 .6056 .42732 .59074 .42574 .52781 Mtetra
.714 .49 .584 r
.42574 .52781 .42732 .59074 .43503 .51512 .43242 .48871 Mtetra
.869 .635 .104 r
.43242 .48871 .43503 .51512 .44112 .49454 .43649 .5442 Mtetra
.734 .474 .534 r
.43649 .5442 .44112 .49454 .44518 .55753 .44107 .58733 Mtetra
.835 .729 .203 r
.44107 .58733 .44518 .55753 .45019 .58797 .44815 .5288 Mtetra
.741 .512 .583 r
.44815 .5288 .45019 .58797 .45721 .52431 .45481 .48121 Mtetra
0 0 .31 r
.45481 .48121 .45721 .52431 .46363 .48315 .45939 .53289 Mtetra
.726 .465 .532 r
.45939 .53289 .46363 .48315 .46837 .53426 .46437 .57274 Mtetra
0 0 0 r
.46437 .57274 .46837 .53426 .47347 .57434 .47112 .51278 Mtetra
.709 .486 .583 r
.47112 .51278 .47347 .57434 .47997 .52148 .47735 .47627 Mtetra
0 0 .287 r
.47735 .47627 .47997 .52148 .48622 .47577 .48227 .53373 Mtetra
.666 .414 .53 r
.48227 .53373 .48622 .47577 .49147 .51622 .48776 .55884 Mtetra
0 0 .056 r
.48776 .55884 .49147 .51622 .49692 .5524 .49418 .49506 Mtetra
.692 .473 .585 r
.49418 .49506 .49692 .5524 .50304 .5084 .50014 .46654 Mtetra
.166 .088 .516 r
.50014 .46654 .50304 .5084 .509 .46732 .50567 .49688 Mtetra
.546 .291 .481 r
.50567 .49688 .509 .46732 .51469 .4776 .51145 .49658 Mtetra
0 0 .026 r
.51145 .49658 .51469 .4776 .52043 .48517 .51731 .46895 Mtetra
.473 .375 .663 r
.51731 .46895 .52043 .48517 .52621 .46893 .52308 .47286 Mtetra
.801 .421 .336 r
.52308 .47286 .52621 .46893 .53199 .47212 .52888 .48327 Mtetra
0 0 0 r
.52888 .48327 .53199 .47212 .53783 .48214 .53466 .4637 Mtetra
.527 .401 .651 r
.53466 .4637 .53783 .48214 .54357 .46587 .54048 .4658 Mtetra
.425 0 0 r
.54048 .4658 .54357 .46587 .54944 .47244 .54633 .46797 Mtetra
.885 .735 .69 r
.54633 .46797 .54944 .47244 .55528 .47078 .55209 .45506 Mtetra
.339 .288 .653 r
.55209 .45506 .55528 .47078 .56105 .46177 .55802 .46289 Mtetra
.953 .949 .718 r
.55802 .46289 .56105 .46177 .56701 .46825 .56379 .45289 Mtetra
.505 .403 .673 r
.56379 .45289 .56701 .46825 .57276 .45777 .56972 .45553 Mtetra
.799 .846 .886 r
.56972 .45553 .57276 .45777 .57874 .46175 .57556 .45123 Mtetra
.605 .51 .72 r
.57556 .45123 .57874 .46175 .58455 .45533 .58147 .45006 Mtetra
.66 .653 .832 r
.58147 .45006 .58455 .45533 .5905 .45587 .58738 .44806 Mtetra
.64 .573 .764 r
.58738 .44806 .5905 .45587 .59639 .45246 .59329 .44614 Mtetra
.656 .618 .799 r
.59329 .44614 .59639 .45246 .60233 .45107 .59922 .44406 Mtetra
.627 .585 .787 r
.59922 .44406 .60233 .45107 .60828 .44972 .60518 .44261 Mtetra
.657 .598 .777 r
.60518 .44261 .60828 .44972 .6142 .44643 .61112 .44031 Mtetra
.652 .622 .807 r
.61112 .44031 .6142 .44643 .62027 .44809 .61709 .43834 Mtetra
.578 .505 .737 r
.61709 .43834 .62027 .44809 .6261 .44125 .62312 .43808 Mtetra
.823 .797 .827 r
.62312 .43808 .6261 .44125 .63235 .44733 .62901 .4325 Mtetra
.417 .35 .674 r
.62901 .4325 .63235 .44733 .63809 .4373 .63526 .43802 Mtetra
.967 .93 .693 r
.63526 .43802 .63809 .4373 .64438 .4429 .64096 .42679 Mtetra
.305 .266 .648 r
.64096 .42679 .64438 .4429 .65038 .44007 .64741 .43616 Mtetra
.831 .765 .789 r
.64741 .43616 .65038 .44007 .65612 .43041 .65329 .42953 Mtetra
.837 .95 .892 r
.65329 .42953 .65612 .43041 .66279 .44297 .65922 .42447 Mtetra
.131 .132 .591 r
.65922 .42447 .66279 .44297 .66832 .4283 .66607 .44038 Mtetra
0 0 .137 r
.66607 .44038 .66832 .4283 .67421 .42227 .67158 .42499 Mtetra
.553 .84 .506 r
.67158 .42499 .67421 .42227 .68099 .43494 .67747 .41853 Mtetra
0 0 .421 r
.67747 .41853 .68099 .43494 .68658 .42222 .68489 .44319 Mtetra
.446 .19 .431 r
.68489 .44319 .68658 .42222 .69214 .4093 .69087 .4375 Mtetra
0 0 .291 r
.69087 .4375 .69214 .4093 .70048 .44893 .69536 .40354 Mtetra
.292 .187 .559 r
.69536 .40354 .70048 .44893 .70896 .48791 .70314 .43164 Mtetra
.011 0 .47 r
.70314 .43164 .70896 .48791 .7129 .445 .71286 .49159 Mtetra
.243 .075 .443 r
.71286 .49159 .7129 .445 .71671 .40233 .71738 .45862 Mtetra
.009 0 .381 r
.71738 .45862 .71671 .40233 .7258 .44799 .72012 .39808 Mtetra
.226 .138 .541 r
.72012 .39808 .7258 .44799 .73523 .49571 .72876 .43518 Mtetra
.127 .062 .507 r
.72876 .43518 .73523 .49571 .7386 .44769 .73872 .49016 Mtetra
0 0 .358 r
.73872 .49016 .7386 .44769 .74144 .39415 .74205 .44195 Mtetra
0 0 .371 r
.74205 .44195 .74144 .39415 .75067 .43565 .74484 .38821 Mtetra
.07 .032 .502 r
.74484 .38821 .75067 .43565 .76135 .49488 .7546 .43621 Mtetra
.139 .074 .515 r
.7546 .43621 .76135 .49488 .76514 .45643 .76496 .48936 Mtetra
0 0 .243 r
.76496 .48936 .76514 .45643 .76666 .38973 .76778 .43827 Mtetra
0 0 .364 r
.76778 .43827 .76666 .38973 .77471 .41061 .76989 .38022 Mtetra
0 0 .472 r
.76989 .38022 .77471 .41061 .78706 .48438 .77945 .41976 Mtetra
.042 .005 .484 r
.77945 .41976 .78706 .48438 .79438 .49239 .79165 .48982 Mtetra
.964 .813 .646 r
.79165 .48982 .79438 .49239 .79533 .4233 .79703 .47366 Mtetra
0 0 .302 r
.79703 .47366 .79533 .4233 .79781 .37507 .79737 .39827 Mtetra
0 0 .325 r
.79737 .39827 .79781 .37507 .80697 .40524 .80157 .37078 Mtetra
0 0 .413 r
.80157 .37078 .80697 .40524 .82068 .48475 .81287 .42434 Mtetra
0 0 .439 r
.81287 .42434 .82068 .48475 .83308 .54611 .827 .50641 Mtetra
.076 .051 .523 r
.827 .50641 .83308 .54611 .84032 .54934 .83778 .54853 Mtetra
.993 .85 .594 r
.83778 .54853 .84032 .54934 .84317 .50629 .84303 .53024 Mtetra
0 0 .119 r
.84303 .53024 .84317 .50629 .84466 .45086 .84497 .4784 Mtetra
0 0 .194 r
.84497 .4784 .84466 .45086 .84702 .40626 .84665 .4258 Mtetra
0 0 .164 r
.84665 .4258 .84702 .40626 .85093 .3784 .84964 .38807 Mtetra
0 0 0 r
.84964 .38807 .85093 .3784 .8561 .36355 .85411 .36602 Mtetra
.813 .893 .474 r
.85411 .36602 .8561 .36355 .86201 .35612 .85964 .35467 Mtetra
.857 .945 .875 r
.85964 .35467 .86201 .35612 .86828 .35207 .86575 .34895 Mtetra
.735 .813 .913 r
.86575 .34895 .86828 .35207 .8747 .34932 .87212 .34566 Mtetra
.684 .761 .909 r
.87212 .34566 .8747 .34932 .88118 .34702 .8786 .34322 Mtetra
.669 .747 .908 r
.8786 .34322 .88118 .34702 .8877 .34487 .88512 .34104 Mtetra
.665 .743 .908 r
.88512 .34104 .8877 .34487 .89423 .34277 .89167 .33891 Mtetra
.664 .742 .908 r
.89167 .33891 .89423 .34277 .90079 .34067 .89823 .3368 Mtetra
.89823 .3368 .90079 .34067 .90735 .33858 .90481 .33469 Mtetra
.663 .741 .908 r
.31463 .51946 .31802 .52261 .32336 .52091 .31997 .51774 Mtetra
.31997 .51774 .32336 .52091 .32871 .5192 .32533 .51602 Mtetra
.661 .74 .909 r
.32533 .51602 .32871 .5192 .33407 .51751 .3307 .51434 Mtetra
.65 .738 .914 r
.3307 .51434 .33407 .51751 .33944 .51589 .33607 .5128 Mtetra
.604 .73 .934 r
.33607 .5128 .33944 .51589 .34481 .51452 .34142 .51181 Mtetra
.37 .664 .971 r
.34142 .51181 .34481 .51452 .35014 .51399 .3467 .5124 Mtetra
.643 .086 0 r
.3467 .5124 .35014 .51399 .35537 .51585 .3518 .51681 Mtetra
.864 .49 .339 r
.3518 .51681 .35537 .51585 .36034 .52327 .35654 .52904 Mtetra
.863 .555 .465 r
.35654 .52904 .36034 .52327 .36486 .54116 .36069 .55448 Mtetra
.851 .566 .506 r
.36069 .55448 .36486 .54116 .36875 .57431 .36417 .59627 Mtetra
.829 .553 .521 r
.36417 .59627 .36875 .57431 .37214 .62159 .3674 .64684 Mtetra
.772 .497 .519 r
.3674 .64684 .37214 .62159 .37576 .66733 .37161 .67923 Mtetra
.798 .805 .317 r
.37161 .67923 .37576 .66733 .38092 .67967 .37821 .65784 Mtetra
.878 .639 .574 r
.37821 .65784 .38092 .67967 .38845 .63363 .38702 .58074 Mtetra
.8 .563 .58 r
.38702 .58074 .38845 .63363 .39724 .55052 .39549 .50616 Mtetra
.582 .394 .592 r
.39549 .50616 .39724 .55052 .40471 .49715 .40105 .50374 Mtetra
.911 .626 .49 r
.40105 .50374 .40471 .49715 .40928 .52294 .40416 .57041 Mtetra
.72 .461 .533 r
.40416 .57041 .40928 .52294 .41251 .59238 .40855 .60645 Mtetra
.999 .795 .479 r
.40855 .60645 .41251 .59238 .41789 .60099 .41616 .54664 Mtetra
.775 .541 .582 r
.41616 .54664 .41789 .60099 .42574 .52781 .4236 .48672 Mtetra
0 0 .426 r
.4236 .48672 .42574 .52781 .43242 .48871 .42802 .52488 Mtetra
.8 .529 .528 r
.42802 .52488 .43242 .48871 .43649 .5442 .43203 .58332 Mtetra
0 0 .192 r
.43203 .58332 .43649 .5442 .44107 .58733 .43888 .53911 Mtetra
.788 .552 .581 r
.43888 .53911 .44107 .58733 .44815 .5288 .44597 .47966 Mtetra
0 0 .433 r
.44597 .47966 .44815 .5288 .45481 .48121 .45056 .52419 Mtetra
.76 .493 .53 r
.45056 .52419 .45481 .48121 .45939 .53289 .45526 .57168 Mtetra
0 0 0 r
.45526 .57168 .45939 .53289 .46437 .57274 .46217 .51127 Mtetra
.706 .483 .583 r
.46217 .51127 .46437 .57274 .47112 .51278 .46846 .4761 Mtetra
.722 .545 0 r
.46846 .4761 .47112 .51278 .47735 .47627 .4731 .54138 Mtetra
.617 .374 .527 r
.4731 .54138 .47735 .47627 .48227 .53373 .47868 .5552 Mtetra
.986 .787 .39 r
.47868 .5552 .48227 .53373 .48776 .55884 .48537 .48266 Mtetra
.58 .38 .575 r
.48537 .48266 .48776 .55884 .49418 .49506 .49112 .47861 Mtetra
.942 .655 .196 r
.49112 .47861 .49418 .49506 .50014 .46654 .49643 .52719 Mtetra
.409 .201 .484 r
.49643 .52719 .50014 .46654 .50567 .49688 .5024 .50611 Mtetra
.999 .806 .469 r
.5024 .50611 .50567 .49688 .51145 .49658 .50843 .46231 Mtetra
.485 .332 .598 r
.50843 .46231 .51145 .49658 .51731 .46895 .51415 .46931 Mtetra
.818 .364 .154 r
.51415 .46931 .51731 .46895 .52308 .47286 .51992 .47766 Mtetra
.985 .882 .533 r
.51992 .47766 .52308 .47286 .52888 .48327 .52573 .45775 Mtetra
.491 .352 .619 r
.52573 .45775 .52888 .48327 .53466 .4637 .53154 .46271 Mtetra
.547 0 0 r
.53154 .46271 .53466 .4637 .54048 .4658 .53738 .46656 Mtetra
.977 .882 .669 r
.53738 .46656 .54048 .4658 .54633 .46797 .54315 .45278 Mtetra
.188 .188 .626 r
.54315 .45278 .54633 .46797 .55209 .45506 .54908 .46366 Mtetra
0 0 .03 r
.54908 .46366 .55209 .45506 .55802 .46289 .55487 .45385 Mtetra
.503 .471 .755 r
.55487 .45385 .55802 .46289 .56379 .45289 .56077 .45536 Mtetra
.22 0 0 r
.56077 .45536 .56379 .45289 .56972 .45553 .56667 .45429 Mtetra
.818 .916 .904 r
.56667 .45429 .56972 .45553 .57556 .45123 .57253 .44975 Mtetra
.017 .54 .858 r
.57253 .44975 .57556 .45123 .58147 .45006 .57849 .45112 Mtetra
.676 .973 .799 r
.57849 .45112 .58147 .45006 .58738 .44806 .58436 .44655 Mtetra
.378 .769 .988 r
.58436 .44655 .58738 .44806 .59329 .44614 .59032 .44626 Mtetra
.458 .886 .884 r
.59032 .44626 .59329 .44614 .59922 .44406 .59627 .44409 Mtetra
.615 .953 .914 r
.59627 .44409 .59922 .44406 .60518 .44261 .6022 .44107 Mtetra
.238 .688 .954 r
.6022 .44107 .60518 .44261 .61112 .44031 .60823 .4415 Mtetra
.702 .976 .773 r
.60823 .4415 .61112 .44031 .61709 .43834 .61413 .43642 Mtetra
.196 .632 .947 r
.61413 .43642 .61709 .43834 .62312 .43808 .62021 .4374 Mtetra
.713 .953 .951 r
.62021 .4374 .62312 .43808 .62901 .4325 .62618 .43409 Mtetra
.541 .897 .681 r
.62618 .43409 .62901 .4325 .63526 .43802 .63211 .42961 Mtetra
.27 .342 .753 r
.63211 .42961 .63526 .43802 .64096 .42679 .63839 .43486 Mtetra
0 0 0 r
.63839 .43486 .64096 .42679 .64741 .43616 .644 .42056 Mtetra
.255 .235 .643 r
.644 .42056 .64741 .43616 .65329 .42953 .65052 .4309 Mtetra
.896 .983 .71 r
.65052 .4309 .65329 .42953 .65922 .42447 .65634 .42241 Mtetra
.9 .855 .789 r
.65634 .42241 .65922 .42447 .66607 .44038 .66217 .41447 Mtetra
.275 .203 .592 r
.66217 .41447 .66607 .44038 .67158 .42499 .66907 .43097 Mtetra
.67 .765 .281 r
.66907 .43097 .67158 .42499 .67747 .41853 .67466 .4173 Mtetra
.936 .888 .759 r
.67466 .4173 .67747 .41853 .68489 .44319 .68043 .40799 Mtetra
0 0 .453 r
.68043 .40799 .68489 .44319 .69087 .4375 .68875 .44987 Mtetra
.752 .423 .427 r
.68875 .44987 .69087 .4375 .69536 .40354 .69583 .46438 Mtetra
.127 0 .421 r
.69583 .46438 .69536 .40354 .70314 .43164 .6993 .41059 Mtetra
.496 .373 .642 r
.6993 .41059 .70314 .43164 .71286 .49159 .70583 .41478 Mtetra
.114 .045 .492 r
.70583 .41478 .71286 .49159 .71738 .45862 .71619 .48468 Mtetra
.146 0 .372 r
.71619 .48468 .71738 .45862 .72012 .39808 .72133 .46221 Mtetra
.012 0 .388 r
.72133 .46221 .72012 .39808 .72876 .43518 .72354 .39347 Mtetra
.15 .092 .531 r
.72354 .39347 .72876 .43518 .73872 .49016 .73219 .42965 Mtetra
.128 .063 .508 r
.73219 .42965 .73872 .49016 .74205 .44195 .74223 .48448 Mtetra
0 0 .312 r
.74223 .48448 .74205 .44195 .74484 .38821 .74501 .42865 Mtetra
0 0 .361 r
.74501 .42865 .74484 .38821 .7546 .43621 .74832 .38306 Mtetra
.003 0 .475 r
.74832 .38306 .7546 .43621 .76496 .48936 .75898 .44243 Mtetra
.204 .127 .542 r
.75898 .44243 .76496 .48936 .76778 .43827 .76829 .47984 Mtetra
0 0 .251 r
.76829 .47984 .76778 .43827 .76989 .38022 .76997 .41421 Mtetra
0 0 .352 r
.76997 .41421 .76989 .38022 .77945 .41976 .77346 .37496 Mtetra
0 0 .44 r
.77346 .37496 .77945 .41976 .79165 .48982 .78472 .43481 Mtetra
.094 .046 .507 r
.78472 .43481 .79165 .48982 .79703 .47366 .79584 .48974 Mtetra
.72 .626 .062 r
.79584 .48974 .79703 .47366 .79737 .39827 .79894 .44606 Mtetra
0 0 .304 r
.79894 .44606 .79737 .39827 .80157 .37078 .79953 .37501 Mtetra
.544 .098 .141 r
.79953 .37501 .80157 .37078 .81287 .42434 .80626 .37677 Mtetra
0 0 .394 r
.80626 .37677 .81287 .42434 .827 .50641 .81958 .45145 Mtetra
0 0 .441 r
.81958 .45145 .827 .50641 .83778 .54853 .83328 .52661 Mtetra
.248 .209 .616 r
.83328 .52661 .83778 .54853 .84303 .53024 .84179 .54313 Mtetra
.74 .648 .089 r
.84179 .54313 .84303 .53024 .84497 .4784 .84509 .50443 Mtetra
0 0 .128 r
.84509 .50443 .84497 .4784 .84665 .4258 .84649 .44794 Mtetra
0 0 .133 r
.84649 .44794 .84665 .4258 .84964 .38807 .84866 .40111 Mtetra
0 0 .046 r
.84866 .40111 .84964 .38807 .85411 .36602 .85239 .37131 Mtetra
.694 .736 .226 r
.85239 .37131 .85411 .36602 .85964 .35467 .85745 .35505 Mtetra
.892 .985 .72 r
.85745 .35505 .85964 .35467 .86575 .34895 .8633 .34674 Mtetra
.8 .892 .91 r
.8633 .34674 .86575 .34895 .87212 .34566 .86957 .3423 Mtetra
.708 .79 .915 r
.86957 .3423 .87212 .34566 .8786 .34322 .87601 .33945 Mtetra
.675 .752 .909 r
.87601 .33945 .8786 .34322 .88512 .34104 .88254 .33716 Mtetra
.666 .742 .907 r
.88254 .33716 .88512 .34104 .89167 .33891 .88909 .33502 Mtetra
.664 .741 .908 r
.88909 .33502 .89167 .33891 .89823 .3368 .89566 .33291 Mtetra
.89566 .33291 .89823 .3368 .90481 .33469 .90225 .33079 Mtetra
.31122 .51628 .31463 .51946 .31997 .51774 .31657 .51456 Mtetra
.662 .741 .908 r
.31657 .51456 .31997 .51774 .32533 .51602 .32194 .51285 Mtetra
.655 .74 .912 r
.32194 .51285 .32533 .51602 .3307 .51434 .32731 .51123 Mtetra
.629 .738 .926 r
.32731 .51123 .3307 .51434 .33607 .5128 .33267 .50995 Mtetra
.526 .722 .963 r
.33267 .50995 .33607 .5128 .34142 .51181 .33799 .5096 Mtetra
0 .45 .84 r
.33799 .5096 .34142 .51181 .3467 .5124 .3432 .51157 Mtetra
.824 .362 .119 r
.3432 .51157 .3467 .5124 .3518 .51681 .34815 .51887 Mtetra
.877 .54 .409 r
.34815 .51887 .3518 .51681 .35654 .52904 .3526 .53677 Mtetra
.869 .574 .486 r
.3526 .53677 .35654 .52904 .36069 .55448 .3563 .57117 Mtetra
.85 .57 .514 r
.3563 .57117 .36069 .55448 .36417 .59627 .35936 .62158 Mtetra
.811 .537 .524 r
.35936 .62158 .36417 .59627 .3674 .64684 .36273 .66913 Mtetra
.623 .347 .479 r
.36273 .66913 .3674 .64684 .37161 .67923 .36814 .67513 Mtetra
.932 .703 .569 r
.36814 .67513 .37161 .67923 .37821 .65784 .37642 .61534 Mtetra
.836 .596 .575 r
.37642 .61534 .37821 .65784 .38702 .58074 .38569 .52767 Mtetra
.722 .5 .588 r
.38569 .52767 .38702 .58074 .39549 .50616 .39262 .49181 Mtetra
.979 .69 .318 r
.39262 .49181 .39549 .50616 .40105 .50374 .39619 .54097 Mtetra
.799 .53 .532 r
.39619 .54097 .40105 .50374 .40416 .57041 .39956 .60074 Mtetra
0 0 .188 r
.39956 .60074 .40416 .57041 .40855 .60645 .40634 .56882 Mtetra
.835 .596 .576 r
.40634 .56882 .40855 .60645 .41616 .54664 .41448 .49355 Mtetra
.494 .321 .575 r
.41448 .49355 .41616 .54664 .4236 .48672 .41972 .50261 Mtetra
.879 .597 .506 r
.41972 .50261 .4236 .48672 .42802 .52488 .42323 .57126 Mtetra
.378 .166 .46 r
.42323 .57126 .42802 .52488 .43203 .58332 .42942 .55342 Mtetra
.852 .612 .574 r
.42942 .55342 .43203 .58332 .43888 .53911 .437 .48218 Mtetra
.334 .198 .542 r
.437 .48218 .43888 .53911 .44597 .47966 .44192 .50863 Mtetra
.826 .549 .52 r
.44192 .50863 .44597 .47966 .45056 .52419 .44615 .56913 Mtetra
0 0 .195 r
.44615 .56913 .45056 .52419 .45526 .57168 .45304 .51708 Mtetra
.741 .513 .583 r
.45304 .51708 .45526 .57168 .46217 .51127 .45959 .47335 Mtetra
.723 .549 0 r
.45959 .47335 .46217 .51127 .46846 .4761 .46402 .54021 Mtetra
.607 .365 .525 r
.46402 .54021 .46846 .4761 .4731 .54138 .4696 .5516 Mtetra
.991 .761 .488 r
.4696 .5516 .4731 .54138 .47868 .5552 .47652 .47573 Mtetra
.476 .298 .561 r
.47652 .47573 .47868 .5552 .48537 .48266 .48199 .49255 Mtetra
.897 .601 .477 r
.48199 .49255 .48537 .48266 .49112 .47861 .48709 .54947 Mtetra
.22 .055 .433 r
.48709 .54947 .49112 .47861 .49643 .52719 .49339 .50359 Mtetra
.843 .607 .582 r
.49339 .50359 .49643 .52719 .5024 .50611 .49955 .45581 Mtetra
.368 .229 .558 r
.49955 .45581 .5024 .50611 .50843 .46231 .50516 .47725 Mtetra
.601 .301 .433 r
.50516 .47725 .50843 .46231 .51415 .46931 .51093 .48057 Mtetra
.841 .794 .298 r
.51093 .48057 .51415 .46931 .51992 .47766 .5168 .45538 Mtetra
.312 .234 .605 r
.5168 .45538 .51992 .47766 .52573 .45775 .52258 .46712 Mtetra
.648 .31 .386 r
.52258 .46712 .52573 .45775 .53154 .46271 .52841 .47192 Mtetra
.784 .79 .293 r
.52841 .47192 .53154 .46271 .53738 .46656 .53421 .45231 Mtetra
.055 .104 .596 r
.53421 .45231 .53738 .46656 .54315 .45278 .54011 .46479 Mtetra
.149 0 .239 r
.54011 .46479 .54315 .45278 .54908 .46366 .54593 .45582 Mtetra
.704 .605 .744 r
.54593 .45582 .54908 .46366 .55487 .45385 .55178 .45166 Mtetra
0 .216 .651 r
.55178 .45166 .55487 .45385 .56077 .45536 .55771 .45536 Mtetra
.951 .912 .743 r
.55771 .45536 .56077 .45536 .56667 .45429 .56351 .44545 Mtetra
.324 .365 .75 r
.56351 .44545 .56667 .45429 .57253 .44975 .5695 .44999 Mtetra
.914 .963 .799 r
.5695 .44999 .57253 .44975 .57849 .45112 .57533 .4425 Mtetra
.498 .478 .765 r
.57533 .4425 .57849 .45112 .58436 .44655 .58131 .44402 Mtetra
.783 .83 .888 r
.58131 .44402 .58436 .44655 .59032 .44626 .58721 .44 Mtetra
.626 .606 .811 r
.58721 .44 .59032 .44626 .59627 .44409 .59318 .43864 Mtetra
.602 .623 .844 r
.59318 .43864 .59627 .44409 .6022 .44107 .59916 .43777 Mtetra
.781 .785 .856 r
.59916 .43777 .6022 .44107 .60823 .4415 .60508 .43345 Mtetra
.419 .443 .779 r
.60508 .43345 .60823 .4415 .61413 .43642 .6112 .43625 Mtetra
.92 .949 .798 r
.6112 .43625 .61413 .43642 .62021 .4374 .61704 .42854 Mtetra
.242 .313 .737 r
.61704 .42854 .62021 .4374 .62618 .43409 .62329 .43441 Mtetra
.916 .971 .785 r
.62329 .43441 .62618 .43409 .63211 .42961 .62914 .42665 Mtetra
.323 .627 .96 r
.62914 .42665 .63211 .42961 .63839 .43486 .63528 .42775 Mtetra
.273 .38 .79 r
.63528 .42775 .63839 .43486 .644 .42056 .64157 .43209 Mtetra
0 0 .077 r
.64157 .43209 .644 .42056 .65052 .4309 .64712 .41619 Mtetra
0 .018 .551 r
.64712 .41619 .65052 .4309 .65634 .42241 .65393 .43269 Mtetra
.04 0 .179 r
.65393 .43269 .65634 .42241 .66217 .41447 .65971 .42267 Mtetra
0 0 0 r
.65971 .42267 .66217 .41447 .66907 .43097 .66528 .40804 Mtetra
.049 .055 .542 r
.66528 .40804 .66907 .43097 .67466 .4173 .67249 .43041 Mtetra
.215 0 .297 r
.67249 .43041 .67466 .4173 .68043 .40799 .67831 .42108 Mtetra
0 0 0 r
.67831 .42108 .68043 .40799 .68875 .44987 .68338 .39688 Mtetra
.116 .055 .505 r
.68338 .39688 .68875 .44987 .69583 .46438 .69203 .44411 Mtetra
0 0 .248 r
.69203 .44411 .69583 .46438 .6993 .41059 .70048 .48359 Mtetra
.133 .007 .429 r
.70048 .48359 .6993 .41059 .70583 .41478 .70341 .41974 Mtetra
.854 .85 .391 r
.70341 .41974 .70583 .41478 .71619 .48468 .70882 .4034 Mtetra
.116 .044 .491 r
.70882 .4034 .71619 .48468 .72133 .46221 .71951 .47715 Mtetra
0 0 .168 r
.71951 .47715 .72133 .46221 .72354 .39347 .72474 .4564 Mtetra
0 0 .378 r
.72474 .4564 .72354 .39347 .73219 .42965 .72684 .38666 Mtetra
.038 .012 .495 r
.72684 .38666 .73219 .42965 .74223 .48448 .73611 .43138 Mtetra
.163 .092 .524 r
.73611 .43138 .74223 .48448 .74501 .42865 .74561 .4765 Mtetra
0 0 .289 r
.74561 .4765 .74501 .42865 .74832 .38306 .74752 .40859 Mtetra
.055 0 .346 r
.74752 .40859 .74832 .38306 .75898 .44243 .75214 .38237 Mtetra
0 0 .46 r
.75214 .38237 .75898 .44243 .76829 .47984 .76367 .45208 Mtetra
.434 .314 .617 r
.76367 .45208 .76829 .47984 .76997 .41421 .77101 .46181 Mtetra
0 0 .266 r
.77101 .46181 .76997 .41421 .77346 .37496 .77196 .38777 Mtetra
.246 0 .315 r
.77196 .38777 .77346 .37496 .78472 .43481 .77778 .37881 Mtetra
0 0 .436 r
.77778 .37881 .78472 .43481 .79584 .48974 .79029 .45258 Mtetra
.276 .19 .574 r
.79029 .45258 .79584 .48974 .79894 .44606 .79909 .47788 Mtetra
0 0 .122 r
.79909 .47788 .79894 .44606 .79953 .37501 .8002 .41132 Mtetra
0 0 .305 r
.8002 .41132 .79953 .37501 .80626 .37677 .80236 .35958 Mtetra
0 0 .324 r
.80236 .35958 .80626 .37677 .81958 .45145 .81214 .39539 Mtetra
0 0 .393 r
.81214 .39539 .81958 .45145 .83328 .52661 .82678 .48254 Mtetra
0 0 .471 r
.82678 .48254 .83328 .52661 .84179 .54313 .83896 .53923 Mtetra
.915 .8 .718 r
.83896 .53923 .84179 .54313 .84509 .50443 .84488 .52765 Mtetra
0 0 .085 r
.84488 .52765 .84509 .50443 .84649 .44794 .84665 .47385 Mtetra
0 0 .133 r
.84665 .47385 .84649 .44794 .84866 .40111 .84801 .41784 Mtetra
0 0 .064 r
.84801 .41784 .84866 .40111 .85239 .37131 .85087 .37866 Mtetra
.703 .687 .149 r
.85087 .37866 .85239 .37131 .85745 .35505 .85535 .35654 Mtetra
.9 .939 .572 r
.85535 .35654 .85745 .35505 .8633 .34674 .86092 .34527 Mtetra
.861 .945 .871 r
.86092 .34527 .8633 .34674 .86957 .3423 .86705 .33942 Mtetra
.746 .835 .919 r
.86705 .33942 .86957 .3423 .87601 .33945 .87344 .33593 Mtetra
.691 .774 .915 r
.87344 .33593 .87601 .33945 .88254 .33716 .87995 .33337 Mtetra
.671 .75 .91 r
.87995 .33337 .88254 .33716 .88909 .33502 .8865 .33113 Mtetra
.665 .742 .908 r
.8865 .33113 .88909 .33502 .89566 .33291 .89309 .329 Mtetra
.663 .741 .908 r
.89309 .329 .89566 .33291 .90225 .33079 .89968 .32687 Mtetra
.3078 .5131 .31122 .51628 .31657 .51456 .31316 .51138 Mtetra
.659 .741 .911 r
.31316 .51138 .31657 .51456 .32194 .51285 .31853 .50972 Mtetra
.645 .741 .919 r
.31853 .50972 .32194 .51285 .32731 .51123 .32389 .50823 Mtetra
.602 .737 .94 r
.32389 .50823 .32731 .51123 .33267 .50995 .32924 .50723 Mtetra
.419 .688 .974 r
.32924 .50723 .33267 .50995 .33799 .5096 .33453 .50753 Mtetra
.482 0 0 r
.33453 .50753 .33799 .5096 .3432 .51157 .33965 .5112 Mtetra
.877 .484 .285 r
.33965 .5112 .3432 .51157 .34815 .51887 .34438 .52265 Mtetra
.882 .57 .454 r
.34438 .52265 .34815 .51887 .3526 .53677 .3484 .54861 Mtetra
.864 .579 .504 r
.3484 .54861 .3526 .53677 .3563 .57117 .35156 .59354 Mtetra
.835 .559 .522 r
.35156 .59354 .3563 .57117 .35936 .62158 .35441 .64816 Mtetra
.763 .489 .519 r
.35441 .64816 .35936 .62158 .36273 .66913 .35856 .67932 Mtetra
.993 .853 .501 r
.35856 .67932 .36273 .66913 .36814 .67513 .36572 .64769 Mtetra
.87 .629 .572 r
.36572 .64769 .36814 .67513 .37642 .61534 .3752 .56145 Mtetra
.788 .553 .581 r
.3752 .56145 .37642 .61534 .38569 .52767 .38363 .49381 Mtetra
.308 .197 .561 r
.38363 .49381 .38569 .52767 .39262 .49181 .3884 .51039 Mtetra
.869 .591 .515 r
.3884 .51039 .39262 .49181 .39619 .54097 .39116 .58006 Mtetra
.609 .355 .508 r
.39116 .58006 .39619 .54097 .39956 .60074 .39651 .58758 Mtetra
.906 .667 .565 r
.39651 .58758 .39956 .60074 .40634 .56882 .40486 .51261 Mtetra
.693 .475 .587 r
.40486 .51261 .40634 .56882 .41448 .49355 .41138 .48453 Mtetra
.972 .681 .411 r
.41138 .48453 .41448 .49355 .41972 .50261 .41482 .54826 Mtetra
.658 .402 .522 r
.41482 .54826 .41972 .50261 .42323 .57126 .41991 .56625 Mtetra
.937 .699 .551 r
.41991 .56625 .42323 .57126 .42942 .55342 .42775 .49315 Mtetra
.582 .386 .581 r
.42775 .49315 .42942 .55342 .437 .48218 .43344 .48946 Mtetra
.914 .626 .483 r
.43344 .48946 .437 .48218 .44192 .50863 .43722 .55981 Mtetra
.238 .056 .42 r
.43722 .55981 .44192 .50863 .44615 .56913 .4437 .52912 Mtetra
.808 .571 .58 r
.4437 .52912 .44615 .56913 .45304 .51708 .45074 .46982 Mtetra
0 0 .258 r
.45074 .46982 .45304 .51708 .45959 .47335 .45511 .53014 Mtetra
.659 .407 .528 r
.45511 .53014 .45959 .47335 .46402 .54021 .46042 .5528 Mtetra
.994 .766 .478 r
.46042 .5528 .46402 .54021 .4696 .5516 .46758 .47425 Mtetra
.429 .263 .553 r
.46758 .47425 .4696 .5516 .47652 .47573 .4729 .4977 Mtetra
.85 .565 .505 r
.4729 .4977 .47652 .47573 .48199 .49255 .47781 .55755 Mtetra
0 0 .319 r
.47781 .55755 .48199 .49255 .48709 .54947 .48444 .49442 Mtetra
.715 .49 .584 r
.48444 .49442 .48709 .54947 .49339 .50359 .49058 .46004 Mtetra
0 0 .417 r
.49058 .46004 .49339 .50359 .49955 .45581 .49593 .50395 Mtetra
.452 .229 .483 r
.49593 .50395 .49955 .45581 .50516 .47725 .50184 .49182 Mtetra
.937 .803 .343 r
.50184 .49182 .50516 .47725 .51093 .48057 .50787 .45245 Mtetra
.296 .205 .58 r
.50787 .45245 .51093 .48057 .5168 .45538 .51359 .46776 Mtetra
.619 .304 .414 r
.51359 .46776 .5168 .45538 .52258 .46712 .51941 .47177 Mtetra
.997 .853 .533 r
.51941 .47177 .52258 .46712 .52841 .47192 .52525 .44749 Mtetra
.319 .232 .598 r
.52525 .44749 .52841 .47192 .53421 .45231 .5311 .46009 Mtetra
0 0 .057 r
.5311 .46009 .53421 .45231 .54011 .46479 .53693 .45267 Mtetra
.713 .559 .679 r
.53693 .45267 .54011 .46479 .54593 .45582 .54277 .44572 Mtetra
.198 .258 .7 r
.54277 .44572 .54593 .45582 .55178 .45166 .54869 .45274 Mtetra
.972 .917 .687 r
.54869 .45274 .55178 .45166 .55771 .45536 .55449 .44074 Mtetra
.367 .316 .668 r
.55449 .44074 .55771 .45536 .56351 .44545 .56047 .44722 Mtetra
.88 .986 .716 r
.56047 .44722 .56351 .44545 .5695 .44999 .56631 .43913 Mtetra
.49 .436 .724 r
.56631 .43913 .5695 .44999 .57533 .4425 .57228 .44129 Mtetra
.807 .921 .914 r
.57228 .44129 .57533 .4425 .58131 .44402 .57818 .43696 Mtetra
.59 .566 .795 r
.57818 .43696 .58131 .44402 .58721 .44 .58415 .43635 Mtetra
.689 .743 .892 r
.58415 .43635 .58721 .44 .59318 .43864 .59009 .43399 Mtetra
.679 .69 .853 r
.59009 .43399 .59318 .43864 .59916 .43777 .59606 .43167 Mtetra
.579 .589 .827 r
.59606 .43167 .59916 .43777 .60508 .43345 .60207 .43124 Mtetra
.828 .855 .867 r
.60207 .43124 .60508 .43345 .6112 .43625 .60799 .42617 Mtetra
.425 .408 .736 r
.60799 .42617 .6112 .43625 .61704 .42854 .61415 .4296 Mtetra
.944 .961 .714 r
.61415 .4296 .61704 .42854 .62329 .43441 .61995 .4199 Mtetra
.314 .283 .664 r
.61995 .4199 .62329 .43441 .62914 .42665 .62628 .42792 Mtetra
.962 .944 .677 r
.62628 .42792 .62914 .42665 .63528 .42775 .63203 .41669 Mtetra
.413 .386 .72 r
.63203 .41669 .63528 .42775 .64157 .43209 .6383 .4208 Mtetra
.482 .428 .72 r
.6383 .4208 .64157 .43209 .64712 .41619 .64454 .42332 Mtetra
.688 .751 .252 r
.64454 .42332 .64712 .41619 .65393 .43269 .65011 .40749 Mtetra
.131 .104 .557 r
.65011 .40749 .65393 .43269 .65971 .42267 .65714 .42883 Mtetra
0 0 0 r
.65714 .42883 .65971 .42267 .66528 .40804 .66296 .41914 Mtetra
0 0 .01 r
.66296 .41914 .66528 .40804 .67249 .43041 .66839 .4012 Mtetra
0 0 .43 r
.66839 .4012 .67249 .43041 .67831 .42108 .67635 .43875 Mtetra
.62 .322 .444 r
.67635 .43875 .67831 .42108 .68338 .39688 .68292 .44406 Mtetra
.024 0 .371 r
.68292 .44406 .68338 .39688 .69203 .44411 .68684 .39596 Mtetra
.219 .132 .538 r
.68684 .39596 .69203 .44411 .70048 .48359 .69495 .43119 Mtetra
0 0 .463 r
.69495 .43119 .70048 .48359 .70341 .41974 .7044 .48807 Mtetra
.051 0 .4 r
.7044 .48807 .70341 .41974 .70882 .4034 .70708 .42009 Mtetra
0 0 .196 r
.70708 .42009 .70882 .4034 .71951 .47715 .71216 .39779 Mtetra
.086 .024 .483 r
.71216 .39779 .71951 .47715 .72474 .4564 .72307 .47342 Mtetra
0 0 .046 r
.72307 .47342 .72474 .4564 .72684 .38666 .7276 .44112 Mtetra
0 0 .366 r
.7276 .44112 .72684 .38666 .73611 .43138 .73015 .3796 Mtetra
0 0 .462 r
.73015 .3796 .73611 .43138 .74561 .4765 .74045 .43881 Mtetra
.312 .212 .577 r
.74045 .43881 .74561 .4765 .74752 .40859 .7485 .46106 Mtetra
0 0 .289 r
.7485 .46106 .74752 .40859 .75214 .38237 .7498 .38556 Mtetra
.664 .198 .136 r
.7498 .38556 .75214 .38237 .76367 .45208 .7566 .39015 Mtetra
.004 0 .469 r
.7566 .39015 .76367 .45208 .77101 .46181 .76823 .45929 Mtetra
.979 .775 .559 r
.76823 .45929 .77101 .46181 .77196 .38777 .77289 .43298 Mtetra
0 0 .288 r
.77289 .43298 .77196 .38777 .77778 .37881 .77432 .36639 Mtetra
0 0 .281 r
.77432 .36639 .77778 .37881 .79029 .45258 .78312 .39477 Mtetra
0 0 .455 r
.78312 .39477 .79029 .45258 .79909 .47788 .79559 .46603 Mtetra
.813 .623 .646 r
.79559 .46603 .79909 .47788 .8002 .41132 .80108 .45093 Mtetra
0 0 .189 r
.80108 .45093 .8002 .41132 .80236 .35958 .80139 .37626 Mtetra
.063 0 .306 r
.80139 .37626 .80236 .35958 .81214 .39539 .80647 .35865 Mtetra
0 0 .335 r
.80647 .35865 .81214 .39539 .82678 .48254 .81921 .42624 Mtetra
0 0 .408 r
.81921 .42624 .82678 .48254 .83896 .53923 .83384 .51081 Mtetra
.131 .109 .564 r
.83384 .51081 .83896 .53923 .84488 .52765 .84341 .53809 Mtetra
.82 .704 .168 r
.84341 .53809 .84488 .52765 .84665 .47385 .84688 .50097 Mtetra
0 0 .118 r
.84688 .50097 .84665 .47385 .84801 .41784 .84791 .44046 Mtetra
0 0 .115 r
.84791 .44046 .84801 .41784 .85087 .37866 .84975 .39038 Mtetra
0 0 0 r
.84975 .39038 .85087 .37866 .85535 .35654 .85344 .35989 Mtetra
.856 .851 .392 r
.85344 .35989 .85535 .35654 .86092 .34527 .85858 .3443 Mtetra
.914 .959 .802 r
.85858 .3443 .86092 .34527 .86705 .33942 .86455 .33669 Mtetra
.782 .855 .905 r
.86455 .33669 .86705 .33942 .87344 .33593 .87088 .33251 Mtetra
.708 .788 .914 r
.87088 .33251 .87344 .33593 .87995 .33337 .87736 .32965 Mtetra
.678 .759 .912 r
.87736 .32965 .87995 .33337 .8865 .33113 .88391 .32728 Mtetra
.668 .747 .91 r
.88391 .32728 .8865 .33113 .89309 .329 .8905 .32509 Mtetra
.664 .742 .908 r
.8905 .32509 .89309 .329 .89968 .32687 .89711 .32294 Mtetra
.661 .741 .909 r
.30437 .50991 .3078 .5131 .31316 .51138 .30973 .50821 Mtetra
.653 .741 .914 r
.30973 .50821 .31316 .51138 .31853 .50972 .3151 .50661 Mtetra
.631 .739 .926 r
.3151 .50661 .31853 .50972 .32389 .50823 .32046 .5053 Mtetra
.558 .728 .954 r
.32046 .5053 .32389 .50823 .32924 .50723 .3258 .50469 Mtetra
.192 .584 .942 r
.3258 .50469 .32924 .50723 .33453 .50753 .33103 .50598 Mtetra
.781 .278 0 r
.33103 .50598 .33453 .50753 .33965 .5112 .33601 .51219 Mtetra
.887 .542 .389 r
.33601 .51219 .33965 .5112 .34438 .52265 .34043 .52928 Mtetra
.878 .582 .483 r
.34043 .52928 .34438 .52265 .3484 .54861 .34395 .56447 Mtetra
.857 .578 .514 r
.34395 .56447 .3484 .54861 .35156 .59354 .34666 .61779 Mtetra
.82 .545 .523 r
.34666 .61779 .35156 .59354 .35441 .64816 .34973 .66785 Mtetra
.592 .311 .458 r
.34973 .66785 .35441 .64816 .35856 .67932 .35525 .67111 Mtetra
.917 .684 .57 r
.35525 .67111 .35856 .67932 .36572 .64769 .36409 .60411 Mtetra
.836 .595 .575 r
.36409 .60411 .36572 .64769 .3752 .56145 .37374 .51498 Mtetra
.703 .487 .593 r
.37374 .51498 .3752 .56145 .38363 .49381 .38034 .48919 Mtetra
.956 .664 .443 r
.38034 .48919 .38363 .49381 .3884 .51039 .38336 .54719 Mtetra
.774 .506 .53 r
.38336 .54719 .3884 .51039 .39116 .58006 .38705 .59372 Mtetra
1 .808 .48 r
.38705 .59372 .39116 .58006 .39651 .58758 .39473 .54165 Mtetra
.796 .561 .582 r
.39473 .54165 .39651 .58758 .40486 .51261 .40262 .47969 Mtetra
0 0 .32 r
.40262 .47969 .40486 .51261 .41138 .48453 .4068 .51728 Mtetra
.796 .524 .525 r
.4068 .51728 .41138 .48453 .41482 .54826 .41066 .56841 Mtetra
.974 .808 .39 r
.41066 .56841 .41482 .54826 .41991 .56625 .41812 .51332 Mtetra
.732 .507 .586 r
.41812 .51332 .41991 .56625 .42775 .49315 .42492 .47417 Mtetra
.978 .698 .308 r
.42492 .47417 .42775 .49315 .43344 .48946 .42864 .53881 Mtetra
.574 .331 .51 r
.42864 .53881 .43344 .48946 .43722 .55981 .43424 .54231 Mtetra
.893 .652 .565 r
.43424 .54231 .43722 .55981 .4437 .52912 .44177 .47063 Mtetra
.18 .081 .497 r
.44177 .47063 .4437 .52912 .45074 .46982 .44647 .50981 Mtetra
.761 .492 .526 r
.44647 .50981 .45074 .46982 .45511 .53014 .4512 .55434 Mtetra
.984 .789 .385 r
.4512 .55434 .45511 .53014 .46042 .5528 .45852 .4783 Mtetra
.496 .315 .564 r
.45852 .4783 .46042 .5528 .46758 .47425 .46399 .49026 Mtetra
.881 .593 .495 r
.46399 .49026 .46758 .47425 .4729 .4977 .4686 .55694 Mtetra
0 0 .231 r
.4686 .55694 .4729 .4977 .47781 .55755 .47546 .48936 Mtetra
.645 .432 .58 r
.47546 .48936 .47781 .55755 .48444 .49442 .48148 .46986 Mtetra
.927 .666 .182 r
.48148 .46986 .48444 .49442 .49058 .46004 .48647 .53542 Mtetra
.321 .135 .465 r
.48647 .53542 .49058 .46004 .49593 .50395 .49271 .49808 Mtetra
.936 .701 .559 r
.49271 .49808 .49593 .50395 .50184 .49182 .49894 .44707 Mtetra
.31 .19 .55 r
.49894 .44707 .50184 .49182 .50787 .45245 .50456 .47016 Mtetra
.489 .211 .418 r
.50456 .47016 .50787 .45245 .51359 .46776 .51039 .46784 Mtetra
.974 .793 .598 r
.51039 .46784 .51359 .46776 .51941 .47177 .51629 .44373 Mtetra
.219 .15 .561 r
.51629 .44373 .51941 .47177 .52525 .44749 .52208 .46211 Mtetra
.258 0 .313 r
.52208 .46211 .52525 .44749 .5311 .46009 .52793 .45367 Mtetra
.817 .68 .713 r
.52793 .45367 .5311 .46009 .53693 .45267 .53377 .44438 Mtetra
0 0 .412 r
.53377 .44438 .53693 .45267 .54277 .44572 .5397 .45718 Mtetra
0 0 0 r
.5397 .45718 .54277 .44572 .54869 .45274 .5455 .44014 Mtetra
.172 .203 .653 r
.5455 .44014 .54869 .45274 .55449 .44074 .55148 .44935 Mtetra
0 0 .067 r
.55148 .44935 .55449 .44074 .56047 .44722 .55732 .4405 Mtetra
.499 .526 .816 r
.55732 .4405 .56047 .44722 .56631 .43913 .56328 .44153 Mtetra
0 0 0 r
.56328 .44153 .56631 .43913 .57228 .44129 .5692 .43855 Mtetra
.665 .794 .943 r
.5692 .43855 .57228 .44129 .57818 .43696 .57514 .43655 Mtetra
.513 .899 .95 r
.57514 .43655 .57818 .43696 .58415 .43635 .5811 .43458 Mtetra
.586 .844 .994 r
.5811 .43458 .58415 .43635 .59009 .43399 .58708 .43308 Mtetra
.675 .93 .97 r
.58708 .43308 .59009 .43399 .59606 .43167 .59304 .43031 Mtetra
.445 .817 .993 r
.59304 .43031 .59606 .43167 .60207 .43124 .59906 .42949 Mtetra
.647 .866 .982 r
.59906 .42949 .60207 .43124 .60799 .42617 .60507 .4274 Mtetra
.455 .868 .72 r
.60507 .4274 .60799 .42617 .61415 .4296 .61105 .42394 Mtetra
.247 .42 .837 r
.61105 .42394 .61415 .4296 .61995 .4199 .61724 .42748 Mtetra
0 0 0 r
.61724 .42748 .61995 .4199 .62628 .42792 .623 .41566 Mtetra
0 .08 .6 r
.623 .41566 .62628 .42792 .63203 .41669 .62952 .42825 Mtetra
0 0 .036 r
.62952 .42825 .63203 .41669 .6383 .4208 .6351 .41129 Mtetra
.219 .286 .72 r
.6351 .41129 .6383 .4208 .64454 .42332 .64148 .41796 Mtetra
.264 .445 .852 r
.64148 .41796 .64454 .42332 .65011 .40749 .64779 .42119 Mtetra
0 0 .046 r
.64779 .42119 .65011 .40749 .65714 .42883 .65313 .39953 Mtetra
.205 .145 .564 r
.65313 .39953 .65714 .42883 .66296 .41914 .66022 .42108 Mtetra
0 0 0 r
.66022 .42108 .66296 .41914 .66839 .4012 .66632 .41773 Mtetra
0 0 .089 r
.66632 .41773 .66839 .4012 .67635 .43875 .67139 .3915 Mtetra
0 0 .46 r
.67139 .3915 .67635 .43875 .68292 .44406 .68006 .44265 Mtetra
.938 .569 .255 r
.68006 .44265 .68292 .44406 .68684 .39596 .68786 .47194 Mtetra
.079 0 .41 r
.68786 .47194 .68684 .39596 .69495 .43119 .69061 .40036 Mtetra
.24 .168 .571 r
.69061 .40036 .69495 .43119 .7044 .48807 .69808 .42189 Mtetra
.105 .041 .493 r
.69808 .42189 .7044 .48807 .70708 .42009 .7078 .48218 Mtetra
0 0 .343 r
.7078 .48218 .70708 .42009 .71216 .39779 .71006 .40791 Mtetra
.057 0 .189 r
.71006 .40791 .71216 .39779 .72307 .47342 .71587 .39794 Mtetra
.096 .032 .487 r
.71587 .39794 .72307 .47342 .7276 .44112 .7266 .46872 Mtetra
0 0 .093 r
.7266 .46872 .7276 .44112 .73015 .3796 .72982 .41582 Mtetra
.018 0 .359 r
.72982 .41582 .73015 .3796 .74045 .43881 .73378 .37729 Mtetra
0 0 .46 r
.73378 .37729 .74045 .43881 .7485 .46106 .74485 .44626 Mtetra
.754 .57 .647 r
.74485 .44626 .7485 .46106 .7498 .38556 .75059 .43405 Mtetra
0 0 .304 r
.75059 .43405 .7498 .38556 .7566 .39015 .75241 .36727 Mtetra
0 0 .366 r
.75241 .36727 .7566 .39015 .76823 .45929 .76175 .40637 Mtetra
.129 .07 .516 r
.76175 .40637 .76823 .45929 .77289 .43298 .77198 .4549 Mtetra
.724 .611 .041 r
.77198 .4549 .77289 .43298 .77432 .36639 .7742 .39714 Mtetra
0 0 .322 r
.7742 .39714 .77432 .36639 .78312 .39477 .77776 .35885 Mtetra
0 0 .354 r
.77776 .35885 .78312 .39477 .79559 .46603 .78929 .41989 Mtetra
.091 .051 .514 r
.78929 .41989 .79559 .46603 .80108 .45093 .79983 .46597 Mtetra
.851 .693 .16 r
.79983 .46597 .80108 .45093 .80139 .37626 .80206 .41242 Mtetra
0 0 .238 r
.80206 .41242 .80139 .37626 .80647 .35865 .80344 .35157 Mtetra
.782 .426 0 r
.80344 .35157 .80647 .35865 .81921 .42624 .81237 .37723 Mtetra
0 0 .334 r
.81237 .37723 .81921 .42624 .83384 .51081 .82721 .46572 Mtetra
0 0 .439 r
.82721 .46572 .83384 .51081 .84341 .53809 .84013 .52962 Mtetra
.787 .653 .714 r
.84013 .52962 .84341 .53809 .84688 .50097 .84636 .52091 Mtetra
0 0 0 r
.84636 .52091 .84688 .50097 .84791 .44046 .84792 .46482 Mtetra
0 0 .079 r
.84792 .46482 .84791 .44046 .84975 .39038 .84901 .40607 Mtetra
0 0 .022 r
.84901 .40607 .84975 .39038 .85344 .35989 .8518 .36616 Mtetra
.766 .736 .212 r
.8518 .36616 .85344 .35989 .85858 .3443 .85638 .34478 Mtetra
.934 .962 .665 r
.85638 .34478 .85858 .3443 .86455 .33669 .86209 .33452 Mtetra
.833 .902 .887 r
.86209 .33452 .86455 .33669 .87088 .33251 .86832 .32929 Mtetra
.732 .81 .913 r
.86832 .32929 .87088 .33251 .87736 .32965 .87477 .32601 Mtetra
.689 .769 .912 r
.87477 .32601 .87736 .32965 .88391 .32728 .88132 .32345 Mtetra
.672 .751 .91 r
.88132 .32345 .88391 .32728 .8905 .32509 .8879 .32118 Mtetra
.666 .744 .909 r
.8879 .32118 .8905 .32509 .89711 .32294 .89452 .319 Mtetra
.655 .746 .917 r
.30091 .50681 .30437 .50991 .30973 .50821 .30628 .50519 Mtetra
.638 .747 .927 r
.30628 .50519 .30973 .50821 .3151 .50661 .31164 .50377 Mtetra
.604 .75 .947 r
.31164 .50377 .3151 .50661 .32046 .5053 .317 .5027 Mtetra
.503 .734 .977 r
.317 .5027 .32046 .5053 .3258 .50469 .32232 .50239 Mtetra
0 .443 .838 r
.32232 .50239 .3258 .50469 .33103 .50598 .32752 .50442 Mtetra
.86 .417 .144 r
.32752 .50442 .33103 .50598 .33601 .51219 .33234 .51327 Mtetra
.903 .581 .426 r
.33234 .51327 .33601 .51219 .34043 .52928 .33637 .53727 Mtetra
.885 .598 .496 r
.33637 .53727 .34043 .52928 .34395 .56447 .33926 .5837 Mtetra
.854 .578 .52 r
.33926 .5837 .34395 .56447 .34666 .61779 .34156 .64449 Mtetra
.782 .508 .521 r
.34156 .64449 .34666 .61779 .34973 .66785 .34528 .68175 Mtetra
.96 .848 .43 r
.34528 .68175 .34973 .66785 .35525 .67111 .35265 .64846 Mtetra
.886 .645 .568 r
.35265 .64846 .35525 .67111 .36409 .60411 .3628 .55518 Mtetra
.798 .563 .581 r
.3628 .55518 .36409 .60411 .37374 .51498 .37148 .48731 Mtetra
0 0 .452 r
.37148 .48731 .37374 .51498 .38034 .48919 .37583 .51184 Mtetra
.853 .578 .52 r
.37583 .51184 .38034 .48919 .38336 .54719 .3784 .57997 Mtetra
.404 .17 .442 r
.3784 .57997 .38336 .54719 .38705 .59372 .38446 .5695 Mtetra
.872 .632 .572 r
.38446 .5695 .38705 .59372 .39473 .54165 .39314 .49286 Mtetra
.593 .399 .588 r
.39314 .49286 .39473 .54165 .40262 .47969 .39884 .48826 Mtetra
.903 .616 .491 r
.39884 .48826 .40262 .47969 .4068 .51728 .40205 .55201 Mtetra
.299 .087 .413 r
.40205 .55201 .4068 .51728 .41066 .56841 .40831 .53485 Mtetra
.831 .594 .579 r
.40831 .53485 .41066 .56841 .41812 .51332 .41605 .47139 Mtetra
0 0 .443 r
.41605 .47139 .41812 .51332 .42492 .47417 .42047 .50781 Mtetra
.762 .49 .522 r
.42047 .50781 .42492 .47417 .42864 .53881 .42497 .54601 Mtetra
.984 .758 .516 r
.42497 .54601 .42864 .53881 .43424 .54231 .43253 .48033 Mtetra
.541 .353 .575 r
.43253 .48033 .43424 .54231 .44177 .47063 .43807 .48352 Mtetra
.887 .598 .493 r
.43807 .48352 .44177 .47063 .44647 .50981 .44219 .54566 Mtetra
0 0 0 r
.44219 .54566 .44647 .50981 .4512 .55434 .44928 .48819 Mtetra
.63 .421 .58 r
.44928 .48819 .4512 .55434 .45852 .4783 .45529 .47322 Mtetra
.962 .668 .428 r
.45529 .47322 .45852 .4783 .46399 .49026 .45954 .54714 Mtetra
0 0 .304 r
.45954 .54714 .46399 .49026 .4686 .55694 .46635 .49216 Mtetra
.663 .447 .581 r
.46635 .49216 .4686 .55694 .47546 .48936 .47248 .46882 Mtetra
.98 .699 .319 r
.47248 .46882 .47546 .48936 .48148 .46986 .47705 .55063 Mtetra
.234 .067 .44 r
.47705 .55063 .48148 .46986 .48647 .53542 .48357 .50068 Mtetra
.807 .571 .581 r
.48357 .50068 .48647 .53542 .49271 .49808 .48993 .45088 Mtetra
0 0 .443 r
.48993 .45088 .49271 .49808 .49894 .44707 .4953 .49438 Mtetra
.324 .124 .447 r
.4953 .49438 .49894 .44707 .50456 .47016 .50132 .47145 Mtetra
.982 .791 .571 r
.50132 .47145 .50456 .47016 .51039 .46784 .50731 .44244 Mtetra
0 0 .468 r
.50731 .44244 .51039 .46784 .51629 .44373 .51301 .46791 Mtetra
.307 .078 .394 r
.51301 .46791 .51629 .44373 .52208 .46211 .5189 .45562 Mtetra
.862 .692 .67 r
.5189 .45562 .52208 .46211 .52793 .45367 .52477 .44118 Mtetra
0 0 .447 r
.52477 .44118 .52793 .45367 .53377 .44438 .53065 .45735 Mtetra
0 0 0 r
.53065 .45735 .53377 .44438 .5397 .45718 .53649 .43819 Mtetra
.419 .324 .641 r
.53649 .43819 .5397 .45718 .5455 .44014 .54241 .44466 Mtetra
0 0 0 r
.54241 .44466 .5455 .44014 .55148 .44935 .54829 .43969 Mtetra
.689 .571 .717 r
.54829 .43969 .55148 .44935 .55732 .4405 .55419 .43532 Mtetra
.399 .531 .873 r
.55419 .43532 .55732 .4405 .56328 .44153 .56015 .43703 Mtetra
.81 .734 .78 r
.56015 .43703 .56328 .44153 .5692 .43855 .56603 .43065 Mtetra
.498 .495 .783 r
.56603 .43065 .5692 .43855 .57514 .43655 .57202 .43194 Mtetra
.746 .715 .823 r
.57202 .43194 .57514 .43655 .5811 .43458 .57795 .42796 Mtetra
.634 .601 .799 r
.57795 .42796 .5811 .43458 .58708 .43308 .58393 .42634 Mtetra
.582 .572 .807 r
.58393 .42634 .58708 .43308 .59304 .43031 .58995 .42587 Mtetra
.774 .731 .813 r
.58995 .42587 .59304 .43031 .59906 .42949 .59589 .42107 Mtetra
.442 .45 .772 r
.59589 .42107 .59906 .42949 .60507 .4274 .602 .42355 Mtetra
.819 .766 .803 r
.602 .42355 .60507 .4274 .61105 .42394 .60793 .41752 Mtetra
.463 .518 .829 r
.60793 .41752 .61105 .42394 .61724 .42748 .61406 .419 Mtetra
.577 .529 .764 r
.61406 .419 .61724 .42748 .623 .41566 .62016 .41867 Mtetra
.76 .923 .558 r
.62016 .41867 .623 .41566 .62952 .42825 .62603 .40995 Mtetra
.171 .159 .602 r
.62603 .40995 .62952 .42825 .6351 .41129 .63263 .42407 Mtetra
0 0 .033 r
.63263 .42407 .6351 .41129 .64148 .41796 .63813 .40441 Mtetra
.123 .164 .632 r
.63813 .40441 .64148 .41796 .64779 .42119 .64472 .41586 Mtetra
0 .066 .627 r
.64472 .41586 .64779 .42119 .65313 .39953 .65123 .42363 Mtetra
0 0 .237 r
.65123 .42363 .65313 .39953 .66022 .42108 .65626 .39375 Mtetra
0 0 .502 r
.65626 .39375 .66022 .42108 .66632 .41773 .66369 .42228 Mtetra
.846 .467 .333 r
.66369 .42228 .66632 .41773 .67139 .3915 .67071 .43856 Mtetra
.01 0 .362 r
.67071 .43856 .67139 .3915 .68006 .44265 .6748 .39035 Mtetra
.042 .002 .48 r
.6748 .39035 .68006 .44265 .68786 .47194 .68358 .44187 Mtetra
0 0 .425 r
.68358 .44187 .68786 .47194 .69061 .40036 .69197 .4814 Mtetra
0 0 .379 r
.69197 .4814 .69061 .40036 .69808 .42189 .69388 .39431 Mtetra
.091 .072 .54 r
.69388 .39431 .69808 .42189 .7078 .48218 .70162 .41991 Mtetra
.216 .122 .527 r
.70162 .41991 .7078 .48218 .71006 .40791 .71062 .46567 Mtetra
0 0 .293 r
.71062 .46567 .71006 .40791 .71587 .39794 .71256 .38718 Mtetra
0 0 .501 r
.71256 .38718 .71587 .39794 .7266 .46872 .71993 .40348 Mtetra
.207 .115 .524 r
.71993 .40348 .7266 .46872 .72982 .41582 .72948 .45306 Mtetra
0 0 .148 r
.72948 .45306 .72982 .41582 .73378 .37729 .73172 .38589 Mtetra
.41 .069 .273 r
.73172 .38589 .73378 .37729 .74485 .44626 .73802 .38348 Mtetra
.096 .039 .496 r
.73802 .38348 .74485 .44626 .75059 .43405 .74858 .44315 Mtetra
.955 .769 .315 r
.74858 .44315 .75059 .43405 .75241 .36727 .75204 .39833 Mtetra
0 0 .328 r
.75204 .39833 .75241 .36727 .76175 .40637 .75594 .36183 Mtetra
0 0 .423 r
.75594 .36183 .76175 .40637 .77198 .4549 .76697 .42248 Mtetra
.455 .319 .606 r
.76697 .42248 .77198 .4549 .7742 .39714 .77434 .43196 Mtetra
0 0 .147 r
.77434 .43196 .7742 .39714 .77776 .35885 .77572 .36457 Mtetra
.649 .239 .254 r
.77572 .36457 .77776 .35885 .78929 .41989 .78266 .36909 Mtetra
0 0 .408 r
.78266 .36909 .78929 .41989 .79983 .46597 .79534 .44238 Mtetra
.517 .382 .636 r
.79534 .44238 .79983 .46597 .80206 .41242 .8024 .44567 Mtetra
0 0 .102 r
.8024 .44567 .80206 .41242 .80344 .35157 .80285 .37248 Mtetra
0 0 .3 r
.80285 .37248 .80344 .35157 .81237 .37723 .80725 .34685 Mtetra
0 0 .245 r
.80725 .34685 .81237 .37723 .82721 .46572 .82009 .41466 Mtetra
0 0 .338 r
.82009 .41466 .82721 .46572 .84013 .52962 .83546 .5063 Mtetra
0 .011 .529 r
.83546 .5063 .84013 .52962 .84636 .52091 .84526 .53521 Mtetra
.741 .638 .077 r
.84526 .53521 .84636 .52091 .84792 .46482 .84816 .49192 Mtetra
0 0 .074 r
.84816 .49192 .84792 .46482 .84901 .40607 .84857 .42525 Mtetra
0 0 .016 r
.84857 .42525 .84901 .40607 .8518 .36616 .85027 .37374 Mtetra
.819 .728 .2 r
.85027 .37374 .8518 .36616 .85638 .34478 .85417 .34529 Mtetra
.969 .926 .609 r
.85417 .34529 .85638 .34478 .86209 .33452 .85961 .33231 Mtetra
.861 .9 .861 r
.85961 .33231 .86209 .33452 .86832 .32929 .86578 .32632 Mtetra
.75 .833 .915 r
.86578 .32632 .86832 .32929 .87477 .32601 .87221 .32272 Mtetra
.705 .798 .923 r
.87221 .32272 .87477 .32601 .88132 .32345 .87874 .31989 Mtetra
.683 .773 .919 r
.87874 .31989 .88132 .32345 .8879 .32118 .88532 .31742 Mtetra
.671 .757 .915 r
.88532 .31742 .8879 .32118 .89452 .319 .89193 .31515 Mtetra
.641 .763 .937 r
.29743 .50401 .30091 .50681 .30628 .50519 .30279 .50253 Mtetra
.631 .771 .947 r
.30279 .50253 .30628 .50519 .31164 .50377 .30816 .50114 Mtetra
.632 .774 .948 r
.30816 .50114 .31164 .50377 .317 .5027 .31354 .49972 Mtetra
.59 .738 .946 r
.31354 .49972 .317 .5027 .32232 .50239 .3189 .49881 Mtetra
.024 .402 .855 r
.3189 .49881 .32232 .50239 .32752 .50442 .32406 .50156 Mtetra
.923 .541 .256 r
.32406 .50156 .32752 .50442 .33234 .51327 .32855 .51603 Mtetra
.906 .608 .469 r
.32855 .51603 .33234 .51327 .33637 .53727 .33179 .55344 Mtetra
.867 .59 .517 r
.33179 .55344 .33637 .53727 .33926 .5837 .33377 .61614 Mtetra
.813 .544 .531 r
.33377 .61614 .33926 .5837 .34156 .64449 .33603 .67764 Mtetra
.594 .335 .494 r
.33603 .67764 .34156 .64449 .34528 .68175 .34147 .68256 Mtetra
.951 .719 .551 r
.34147 .68256 .34528 .68175 .35265 .64846 .35113 .6049 Mtetra
.843 .601 .573 r
.35113 .6049 .35265 .64846 .3628 .55518 .3615 .50789 Mtetra
.685 .472 .592 r
.3615 .50789 .3628 .55518 .37148 .48731 .368 .48626 Mtetra
.94 .651 .465 r
.368 .48626 .37148 .48731 .37583 .51184 .37068 .54693 Mtetra
.739 .471 .524 r
.37068 .54693 .37583 .51184 .3784 .57997 .37482 .57927 Mtetra
.95 .721 .557 r
.37482 .57927 .3784 .57997 .38446 .5695 .38305 .51825 Mtetra
.75 .522 .585 r
.38305 .51825 .38446 .5695 .39314 .49286 .39044 .47346 Mtetra
.933 .666 .189 r
.39044 .47346 .39314 .49286 .39884 .48826 .39415 .51932 Mtetra
.717 .446 .515 r
.39415 .51932 .39884 .48826 .40205 .55201 .39886 .54275 Mtetra
.914 .679 .57 r
.39886 .54275 .40205 .55201 .40831 .53485 .40664 .48328 Mtetra
.591 .396 .585 r
.40664 .48328 .40831 .53485 .41605 .47139 .41238 .47852 Mtetra
.902 .608 .479 r
.41238 .47852 .41605 .47139 .42047 .50781 .41627 .53066 Mtetra
0 0 0 r
.41627 .53066 .42047 .50781 .42497 .54601 .42304 .49549 Mtetra
.716 .494 .587 r
.42304 .49549 .42497 .54601 .43253 .48033 .4296 .46364 Mtetra
.975 .689 .294 r
.4296 .46364 .43253 .48033 .43807 .48352 .43366 .52044 Mtetra
.25 .051 .403 r
.43366 .52044 .43807 .48352 .44219 .54566 .43993 .49934 Mtetra
.755 .526 .585 r
.43993 .49934 .44219 .54566 .44928 .48819 .44663 .45747 Mtetra
.855 .631 .093 r
.44663 .45747 .44928 .48819 .45529 .47322 .45086 .5219 Mtetra
.326 .124 .445 r
.45086 .5219 .45529 .47322 .45954 .54714 .45711 .49911 Mtetra
.754 .524 .583 r
.45711 .49911 .45954 .54714 .46635 .49216 .46367 .45598 Mtetra
.864 .643 .109 r
.46367 .45598 .46635 .49216 .47248 .46882 .46804 .5351 Mtetra
.297 .111 .451 r
.46804 .5351 .47248 .46882 .47705 .55063 .47443 .50055 Mtetra
.747 .517 .582 r
.47443 .50055 .47705 .55063 .48357 .50068 .48081 .45838 Mtetra
.725 .552 0 r
.48081 .45838 .48357 .50068 .48993 .45088 .48568 .53522 Mtetra
.275 .1 .454 r
.48568 .53522 .48993 .45088 .4953 .49438 .49207 .48789 Mtetra
.931 .698 .564 r
.49207 .48789 .4953 .49438 .50132 .47145 .49832 .44015 Mtetra
0 0 .377 r
.49832 .44015 .50132 .47145 .50731 .44244 .50387 .47642 Mtetra
.105 0 .351 r
.50387 .47642 .50731 .44244 .51301 .46791 .50987 .44964 Mtetra
.71 .526 .638 r
.50987 .44964 .51301 .46791 .5189 .45562 .51574 .43916 Mtetra
0 .045 .554 r
.51574 .43916 .5189 .45562 .52477 .44118 .52158 .4543 Mtetra
0 0 0 r
.52158 .4543 .52477 .44118 .53065 .45735 .52745 .43502 Mtetra
.434 .321 .625 r
.52745 .43502 .53065 .45735 .53649 .43819 .53335 .44187 Mtetra
.148 0 0 r
.53335 .44187 .53649 .43819 .54241 .44466 .53924 .43944 Mtetra
.81 .709 .754 r
.53924 .43944 .54241 .44466 .54829 .43969 .54512 .43225 Mtetra
.113 .267 .744 r
.54512 .43225 .54829 .43969 .55419 .43532 .5511 .43817 Mtetra
.879 .961 .625 r
.5511 .43817 .55419 .43532 .56015 .43703 .55696 .42829 Mtetra
.296 .351 .75 r
.55696 .42829 .56015 .43703 .56603 .43065 .56298 .43306 Mtetra
.729 .948 .643 r
.56298 .43306 .56603 .43065 .57202 .43194 .56888 .42615 Mtetra
.471 .545 .851 r
.56888 .42615 .57202 .43194 .57795 .42796 .5749 .42728 Mtetra
.702 .949 .956 r
.5749 .42728 .57795 .42796 .58393 .42634 .58086 .4241 Mtetra
.704 .843 .949 r
.58086 .4241 .58393 .42634 .58995 .42587 .58685 .42148 Mtetra
.465 .609 .909 r
.58685 .42148 .58995 .42587 .59589 .42107 .59291 .42218 Mtetra
.836 .998 .777 r
.59291 .42218 .59589 .42107 .602 .42355 .59883 .41559 Mtetra
.308 .379 .773 r
.59883 .41559 .602 .42355 .60793 .41752 .60502 .41986 Mtetra
.836 .966 .643 r
.60502 .41986 .60793 .41752 .61406 .419 .6109 .41127 Mtetra
.409 .448 .789 r
.6109 .41127 .61406 .419 .62016 .41867 .61709 .41402 Mtetra
.623 .672 .876 r
.61709 .41402 .62016 .41867 .62603 .40995 .62319 .41271 Mtetra
.881 .949 .594 r
.62319 .41271 .62603 .40995 .63263 .42407 .62901 .40215 Mtetra
.198 .161 .588 r
.62901 .40215 .63263 .42407 .63813 .40441 .63571 .41816 Mtetra
0 0 .07 r
.63571 .41816 .63813 .40441 .64472 .41586 .64119 .39795 Mtetra
.339 .278 .641 r
.64119 .39795 .64472 .41586 .65123 .42363 .64773 .40705 Mtetra
0 0 .468 r
.64773 .40705 .65123 .42363 .65626 .39375 .65483 .42885 Mtetra
0 0 .286 r
.65483 .42885 .65626 .39375 .66369 .42228 .65937 .38697 Mtetra
0 0 .361 r
.65937 .38697 .66369 .42228 .67071 .43856 .66781 .4373 Mtetra
.946 .592 .292 r
.66781 .4373 .67071 .43856 .6748 .39035 .67582 .47342 Mtetra
.041 0 .398 r
.67582 .47342 .6748 .39035 .68358 .44187 .67837 .39191 Mtetra
.115 .056 .506 r
.67837 .39191 .68358 .44187 .69197 .4814 .68686 .43577 Mtetra
.342 .221 .567 r
.68686 .43577 .69197 .4814 .69388 .39431 .69448 .459 Mtetra
0 0 .322 r
.69448 .459 .69388 .39431 .70162 .41991 .69664 .37837 Mtetra
.022 0 .488 r
.69664 .37837 .70162 .41991 .71062 .46567 .70537 .42111 Mtetra
.447 .297 .584 r
.70537 .42111 .71062 .46567 .71256 .38718 .71259 .4344 Mtetra
0 0 .277 r
.71259 .4344 .71256 .38718 .71993 .40348 .7152 .36912 Mtetra
0 0 .472 r
.7152 .36912 .71993 .40348 .72948 .45306 .72406 .40911 Mtetra
.45 .301 .586 r
.72406 .40911 .72948 .45306 .73172 .38589 .73137 .42198 Mtetra
0 0 .205 r
.73137 .42198 .73172 .38589 .73802 .38348 .7341 .36376 Mtetra
0 0 .425 r
.7341 .36376 .73802 .38348 .74858 .44315 .74259 .39384 Mtetra
.325 .208 .563 r
.74259 .39384 .74858 .44315 .75204 .39833 .75104 .42139 Mtetra
0 0 0 r
.75104 .42139 .75204 .39833 .75594 .36183 .75369 .36615 Mtetra
.644 .203 .188 r
.75369 .36615 .75594 .36183 .76697 .42248 .76053 .37031 Mtetra
.058 .021 .495 r
.76053 .37031 .76697 .42248 .77434 .43196 .77114 .42384 Mtetra
.929 .701 .573 r
.77114 .42384 .77434 .43196 .77572 .36457 .77552 .39415 Mtetra
0 0 .23 r
.77552 .39415 .77572 .36457 .78266 .36909 .77841 .34715 Mtetra
0 0 .311 r
.77841 .34715 .78266 .36909 .79534 .44238 .78854 .39041 Mtetra
.051 .018 .495 r
.78854 .39041 .79534 .44238 .8024 .44567 .79987 .44553 Mtetra
.996 .769 .466 r
.79987 .44553 .8024 .44567 .80285 .37248 .80336 .40671 Mtetra
0 0 .192 r
.80336 .40671 .80285 .37248 .80725 .34685 .80453 .34337 Mtetra
.859 .449 0 r
.80453 .34337 .80725 .34685 .82009 .41466 .81312 .36461 Mtetra
0 0 .303 r
.81312 .36461 .82009 .41466 .83546 .5063 .82875 .46078 Mtetra
0 0 .383 r
.82875 .46078 .83546 .5063 .84526 .53521 .8428 .53558 Mtetra
.928 .971 .701 r
.8428 .53558 .84526 .53521 .84816 .49192 .84897 .52554 Mtetra
0 0 .178 r
.84897 .52554 .84816 .49192 .84857 .42525 .84945 .4581 Mtetra
0 0 .167 r
.84945 .4581 .84857 .42525 .85027 .37374 .84959 .3899 Mtetra
0 0 .016 r
.84959 .3899 .85027 .37374 .85417 .34529 .85213 .34765 Mtetra
.955 .864 .451 r
.85213 .34765 .85417 .34529 .85961 .33231 .85699 .32882 Mtetra
.857 .822 .813 r
.85699 .32882 .85961 .33231 .86578 .32632 .86309 .32201 Mtetra
.708 .74 .876 r
.86309 .32201 .86578 .32632 .87221 .32272 .86959 .31899 Mtetra
.683 .763 .912 r
.86959 .31899 .87221 .32272 .87874 .31989 .87617 .31652 Mtetra
.684 .786 .928 r
.87617 .31652 .87874 .31989 .88532 .31742 .88276 .31401 Mtetra
.679 .783 .929 r
.88276 .31401 .88532 .31742 .89193 .31515 .88937 .31159 Mtetra
.65 .78 .943 r
.29391 .50141 .29743 .50401 .30279 .50253 .29929 .49979 Mtetra
.679 .777 .924 r
.29929 .49979 .30279 .50253 .30816 .50114 .30471 .4978 Mtetra
.698 .744 .887 r
.30471 .4978 .30816 .50114 .31354 .49972 .31015 .49547 Mtetra
.581 .657 .89 r
.31015 .49547 .31354 .49972 .3189 .49881 .3155 .49488 Mtetra
.766 .298 0 r
.3155 .49488 .3189 .49881 .32406 .50156 .32034 .50279 Mtetra
.907 .595 .442 r
.32034 .50279 .32406 .50156 .32855 .51603 .32402 .53076 Mtetra
.865 .587 .514 r
.32402 .53076 .32855 .51603 .33179 .55344 .32616 .58688 Mtetra
.823 .555 .533 r
.32616 .58688 .33179 .55344 .33377 .61614 .3277 .65721 Mtetra
.735 .471 .53 r
.3277 .65721 .33377 .61614 .33603 .67764 .33137 .69334 Mtetra
.994 .83 .467 r
.33137 .69334 .33603 .67764 .34147 .68256 .33956 .64723 Mtetra
.863 .621 .57 r
.33956 .64723 .34147 .68256 .35113 .6049 .35053 .54499 Mtetra
.772 .538 .581 r
.35053 .54499 .35113 .6049 .3615 .50789 .35929 .48051 Mtetra
0 0 .406 r
.35929 .48051 .3615 .50789 .368 .48626 .36345 .5069 Mtetra
.842 .563 .516 r
.36345 .5069 .368 .48626 .37068 .54693 .36642 .56094 Mtetra
0 0 0 r
.36642 .56094 .37068 .54693 .37482 .57927 .37297 .53997 Mtetra
.81 .575 .582 r
.37297 .53997 .37482 .57927 .38305 .51825 .3812 .47929 Mtetra
.486 .324 .586 r
.3812 .47929 .38305 .51825 .39044 .47346 .38641 .48624 Mtetra
.856 .565 .495 r
.38641 .48624 .39044 .47346 .39415 .51932 .39028 .52757 Mtetra
.992 .859 .511 r
.39028 .52757 .39415 .51932 .39886 .54275 .39696 .50004 Mtetra
.741 .518 .591 r
.39696 .50004 .39886 .54275 .40664 .48328 .40382 .46579 Mtetra
.854 .595 .057 r
.40382 .46579 .40664 .48328 .41238 .47852 .40814 .50067 Mtetra
.58 .304 .463 r
.40814 .50067 .41238 .47852 .41627 .53066 .41368 .50337 Mtetra
.814 .584 .591 r
.41368 .50337 .41627 .53066 .42304 .49549 .42068 .46085 Mtetra
.078 .027 .492 r
.42068 .46085 .42304 .49549 .4296 .46364 .42548 .4876 Mtetra
.682 .403 .492 r
.42548 .4876 .4296 .46364 .43366 .52044 .43076 .50091 Mtetra
.855 .623 .586 r
.43076 .50091 .43366 .52044 .43993 .49934 .43769 .45488 Mtetra
.127 .051 .493 r
.43769 .45488 .43993 .49934 .44663 .45747 .44253 .48712 Mtetra
.655 .385 .498 r
.44253 .48712 .44663 .45747 .45086 .5219 .44796 .49914 Mtetra
.851 .615 .581 r
.44796 .49914 .45086 .5219 .45711 .49911 .45481 .4481 Mtetra
0 0 .383 r
.45481 .4481 .45711 .49911 .46367 .45598 .45948 .49987 Mtetra
.516 .276 .49 r
.45948 .49987 .46367 .45598 .46804 .5351 .46534 .49607 Mtetra
.789 .555 .582 r
.46534 .49607 .46804 .5351 .47443 .50055 .47192 .44834 Mtetra
0 0 .072 r
.47192 .44834 .47443 .50055 .48081 .45838 .4764 .53563 Mtetra
.367 .17 .476 r
.4764 .53563 .48081 .45838 .48568 .53522 .48271 .50403 Mtetra
.833 .593 .576 r
.48271 .50403 .48568 .53522 .49207 .48789 .48921 .4472 Mtetra
0 0 .232 r
.48921 .4472 .49207 .48789 .49832 .44015 .49449 .50423 Mtetra
.093 0 .383 r
.49449 .50423 .49832 .44015 .50387 .47642 .50078 .45309 Mtetra
.674 .487 .625 r
.50078 .45309 .50387 .47642 .50987 .44964 .50667 .44388 Mtetra
.938 .577 .181 r
.50667 .44388 .50987 .44964 .51574 .43916 .51243 .46738 Mtetra
0 0 .143 r
.51243 .46738 .51574 .43916 .52158 .4543 .51841 .43127 Mtetra
.197 .149 .575 r
.51841 .43127 .52158 .4543 .52745 .43502 .52427 .44691 Mtetra
.204 0 .251 r
.52427 .44691 .52745 .43502 .53335 .44187 .53017 .43921 Mtetra
.872 .813 .788 r
.53017 .43921 .53335 .44187 .53924 .43944 .53606 .43167 Mtetra
.103 .251 .732 r
.53606 .43167 .53924 .43944 .54512 .43225 .54202 .4379 Mtetra
.633 .791 .347 r
.54202 .4379 .54512 .43225 .5511 .43817 .54789 .42706 Mtetra
.387 .368 .716 r
.54789 .42706 .5511 .43817 .55696 .42829 .55389 .43145 Mtetra
.566 .849 .516 r
.55389 .43145 .55696 .42829 .56298 .43306 .5598 .42493 Mtetra
.543 .516 .775 r
.5598 .42493 .56298 .43306 .56888 .42615 .56579 .42534 Mtetra
.698 .941 .961 r
.56579 .42534 .56888 .42615 .5749 .42728 .57176 .42229 Mtetra
.663 .671 .848 r
.57176 .42229 .5749 .42728 .58086 .4241 .57775 .42024 Mtetra
.57 .69 .922 r
.57775 .42024 .58086 .4241 .58685 .42148 .58378 .41958 Mtetra
.807 .879 .899 r
.58378 .41958 .58685 .42148 .59291 .42218 .58975 .41516 Mtetra
.385 .454 .809 r
.58975 .41516 .59291 .42218 .59883 .41559 .59588 .4179 Mtetra
.829 .968 .651 r
.59588 .4179 .59883 .41559 .60502 .41986 .60178 .40955 Mtetra
.202 .261 .701 r
.60178 .40955 .60502 .41986 .6109 .41127 .60807 .41682 Mtetra
0 0 0 r
.60807 .41682 .6109 .41127 .61709 .41402 .61392 .40623 Mtetra
.269 .36 .773 r
.61392 .40623 .61709 .41402 .62319 .41271 .62019 .41091 Mtetra
0 .308 .704 r
.62019 .41091 .62319 .41271 .62901 .40215 .62646 .41396 Mtetra
0 0 0 r
.62646 .41396 .62901 .40215 .63571 .41816 .63201 .39465 Mtetra
0 0 .361 r
.63201 .39465 .63571 .41816 .64119 .39795 .6394 .42905 Mtetra
0 0 .317 r
.6394 .42905 .64119 .39795 .64773 .40705 .64448 .39699 Mtetra
0 .061 .606 r
.64448 .39699 .64773 .40705 .65483 .42885 .65115 .40853 Mtetra
0 0 .166 r
.65115 .40853 .65483 .42885 .65937 .38697 .65916 .45075 Mtetra
.039 0 .385 r
.65916 .45075 .65937 .38697 .66781 .4373 .66287 .38891 Mtetra
0 0 .417 r
.66287 .38891 .66781 .4373 .67582 .47342 .67177 .44723 Mtetra
.222 .166 .58 r
.67177 .44723 .67582 .47342 .67837 .39191 .67905 .46584 Mtetra
0 0 .337 r
.67905 .46584 .67837 .39191 .68686 .43577 .68124 .37831 Mtetra
.163 .084 .513 r
.68124 .37831 .68686 .43577 .69448 .459 .68992 .42462 Mtetra
.608 .422 .604 r
.68992 .42462 .69448 .459 .69664 .37837 .69608 .41946 Mtetra
0 0 .301 r
.69608 .41946 .69664 .37837 .70537 .42111 .69972 .36837 Mtetra
.122 .06 .507 r
.69972 .36837 .70537 .42111 .71259 .4344 .70872 .41476 Mtetra
.768 .559 .615 r
.70872 .41476 .71259 .4344 .7152 .36912 .71412 .39638 Mtetra
0 0 .295 r
.71412 .39638 .7152 .36912 .72406 .40911 .71863 .36411 Mtetra
.118 .064 .516 r
.71863 .36411 .72406 .40911 .73137 .42198 .72759 .40457 Mtetra
.787 .577 .618 r
.72759 .40457 .73137 .42198 .7341 .36376 .73291 .38585 Mtetra
0 0 .269 r
.73291 .38585 .7341 .36376 .74259 .39384 .73759 .35854 Mtetra
.025 .013 .503 r
.73759 .35854 .74259 .39384 .75104 .42139 .74665 .39585 Mtetra
.659 .471 .619 r
.74665 .39585 .75104 .42139 .75369 .36615 .75261 .38715 Mtetra
0 0 .149 r
.75261 .38715 .75369 .36615 .76053 .37031 .75658 .3513 Mtetra
0 0 .412 r
.75658 .3513 .76053 .37031 .77114 .42384 .76543 .38216 Mtetra
.361 .241 .579 r
.76543 .38216 .77114 .42384 .77552 .39415 .77363 .40264 Mtetra
.952 .763 .306 r
.77363 .40264 .77552 .39415 .77841 .34715 .77678 .35798 Mtetra
.229 0 .27 r
.77678 .35798 .77841 .34715 .78854 .39041 .78277 .35025 Mtetra
0 0 .428 r
.78277 .35025 .78854 .39041 .79987 .44553 .7941 .40667 Mtetra
.425 .29 .593 r
.7941 .40667 .79987 .44553 .80336 .40671 .80206 .42067 Mtetra
.896 .711 .201 r
.80206 .42067 .80336 .40671 .80453 .34337 .80377 .3623 Mtetra
0 0 .236 r
.80377 .3623 .80453 .34337 .81312 .36461 .80803 .33484 Mtetra
0 0 .27 r
.80803 .33484 .81312 .36461 .82875 .46078 .82056 .39848 Mtetra
0 0 .377 r
.82056 .39848 .82875 .46078 .8428 .53558 .8368 .49847 Mtetra
.026 .02 .512 r
.8368 .49847 .8428 .53558 .84897 .52554 .84792 .5405 Mtetra
0 0 0 r
.84792 .5405 .84897 .52554 .84945 .4581 .85105 .49907 Mtetra
0 0 .228 r
.85105 .49907 .84945 .4581 .84959 .3899 .85059 .42335 Mtetra
0 0 .227 r
.85059 .42335 .84959 .3899 .85213 .34765 .85133 .36224 Mtetra
0 0 .072 r
.85133 .36224 .85213 .34765 .85699 .32882 .85482 .32968 Mtetra
.948 .938 .602 r
.85482 .32968 .85699 .32882 .86309 .32201 .86036 .31748 Mtetra
.726 .736 .86 r
.86036 .31748 .86309 .32201 .86959 .31899 .86683 .314 Mtetra
.632 .674 .872 r
.86683 .314 .86959 .31899 .87617 .31652 .87351 .31239 Mtetra
.648 .727 .906 r
.87351 .31239 .87617 .31652 .88276 .31401 .88018 .31048 Mtetra
.67 .772 .927 r
.88018 .31048 .88276 .31401 .88937 .31159 .88682 .3082 Mtetra
.686 .767 .913 r
.2904 .4985 .29391 .50141 .29929 .49979 .29582 .49641 Mtetra
.712 .744 .877 r
.29582 .49641 .29929 .49979 .30471 .4978 .30128 .49381 Mtetra
.666 .701 .873 r
.30128 .49381 .30471 .4978 .31015 .49547 .3067 .49197 Mtetra
0 .223 .718 r
.3067 .49197 .31015 .49547 .3155 .49488 .31178 .4957 Mtetra
.894 .557 .401 r
.31178 .4957 .3155 .49488 .32034 .50279 .31593 .51455 Mtetra
.861 .577 .505 r
.31593 .51455 .32034 .50279 .32402 .53076 .31865 .55827 Mtetra
.832 .561 .529 r
.31865 .55827 .32402 .53076 .32616 .58688 .32027 .62316 Mtetra
.789 .521 .532 r
.32027 .62316 .32616 .58688 .3277 .65721 .32278 .67644 Mtetra
.293 .035 .34 r
.32278 .67644 .3277 .65721 .33137 .69334 .32898 .66749 Mtetra
.869 .63 .575 r
.32898 .66749 .33137 .69334 .33956 .64723 .3391 .58639 Mtetra
.803 .564 .577 r
.3391 .58639 .33956 .64723 .35053 .54499 .34932 .49873 Mtetra
.676 .465 .592 r
.34932 .49873 .35053 .54499 .35929 .48051 .35576 .47959 Mtetra
.936 .636 .447 r
.35576 .47959 .35929 .48051 .36345 .5069 .35906 .52285 Mtetra
.759 .465 .487 r
.35906 .52285 .36345 .5069 .36642 .56094 .3637 .54168 Mtetra
.845 .618 .595 r
.3637 .54168 .36642 .56094 .37297 .53997 .37124 .49921 Mtetra
.722 .504 .594 r
.37124 .49921 .37297 .53997 .3812 .47929 .37799 .47202 Mtetra
.961 .628 .266 r
.37799 .47202 .3812 .47929 .38641 .48624 .38237 .49813 Mtetra
.674 .358 .432 r
.38237 .49813 .38641 .48624 .39028 .52757 .38765 .50513 Mtetra
.806 .585 .603 r
.38765 .50513 .39028 .52757 .39696 .50004 .39451 .47288 Mtetra
.523 .368 .613 r
.39451 .47288 .39696 .50004 .40382 .46579 .39997 .4756 Mtetra
.803 .489 .458 r
.39997 .4756 .40382 .46579 .40814 .50067 .40487 .49439 Mtetra
.893 .695 .627 r
.40487 .49439 .40814 .50067 .41368 .50337 .41132 .4705 Mtetra
.599 .416 .606 r
.41132 .4705 .41368 .50337 .42068 .46085 .41705 .46676 Mtetra
.85 .523 .433 r
.41705 .46676 .42068 .46085 .42548 .4876 .42202 .48757 Mtetra
.963 .781 .609 r
.42202 .48757 .42548 .4876 .43076 .50091 .42842 .46275 Mtetra
.556 .378 .595 r
.42842 .46275 .43076 .50091 .43769 .45488 .43406 .46317 Mtetra
.837 .518 .45 r
.43406 .46317 .43769 .45488 .44253 .48712 .43914 .48583 Mtetra
.954 .745 .582 r
.43914 .48583 .44253 .48712 .44796 .49914 .44569 .45161 Mtetra
.401 .253 .563 r
.44569 .45161 .44796 .49914 .45481 .4481 .45101 .46799 Mtetra
.733 .442 .486 r
.45101 .46799 .45481 .4481 .45948 .49987 .45637 .48613 Mtetra
.885 .652 .581 r
.45637 .48613 .45948 .49987 .46534 .49607 .46301 .44078 Mtetra
0 0 .421 r
.46301 .44078 .46534 .49607 .47192 .44834 .46785 .49164 Mtetra
.517 .276 .489 r
.46785 .49164 .47192 .44834 .4764 .53563 .47374 .48804 Mtetra
.754 .523 .582 r
.47374 .48804 .4764 .53563 .48271 .50403 .48016 .44572 Mtetra
0 0 .189 r
.48016 .44572 .48271 .50403 .48921 .4472 .48495 .52932 Mtetra
.193 .035 .426 r
.48495 .52932 .48921 .4472 .49449 .50423 .49146 .47437 Mtetra
.772 .548 .595 r
.49146 .47437 .49449 .50423 .50078 .45309 .49759 .44351 Mtetra
.972 .66 .305 r
.49759 .44351 .50078 .45309 .50667 .44388 .50312 .49136 Mtetra
0 0 .164 r
.50312 .49136 .50667 .44388 .51243 .46738 .50936 .42975 Mtetra
.267 .166 .55 r
.50936 .42975 .51243 .46738 .51841 .43127 .51515 .45138 Mtetra
.303 .06 .369 r
.51515 .45138 .51841 .43127 .52427 .44691 .52107 .44128 Mtetra
.876 .711 .675 r
.52107 .44128 .52427 .44691 .53017 .43921 .52697 .42704 Mtetra
0 .038 .575 r
.52697 .42704 .53017 .43921 .53606 .43167 .53291 .43933 Mtetra
.829 .833 .361 r
.53291 .43933 .53606 .43167 .54202 .4379 .53878 .42136 Mtetra
.271 .236 .634 r
.53878 .42136 .54202 .4379 .54789 .42706 .54478 .43098 Mtetra
.819 .921 .533 r
.54478 .43098 .54789 .42706 .55389 .43145 .55067 .42042 Mtetra
.443 .405 .721 r
.55067 .42042 .55389 .43145 .5598 .42493 .55667 .4236 Mtetra
.832 .913 .891 r
.55667 .4236 .5598 .42493 .56579 .42534 .56262 .41867 Mtetra
.589 .579 .809 r
.56262 .41867 .56579 .42534 .57176 .42229 .56862 .41801 Mtetra
.662 .704 .879 r
.56862 .41801 .57176 .42229 .57775 .42024 .57462 .41605 Mtetra
.722 .729 .856 r
.57462 .41605 .57775 .42024 .58378 .41958 .58061 .41288 Mtetra
.492 .526 .82 r
.58061 .41288 .58378 .41958 .58975 .41516 .5867 .41396 Mtetra
.899 .903 .819 r
.5867 .41396 .58975 .41516 .59588 .4179 .59263 .40677 Mtetra
.242 .274 .695 r
.59263 .40677 .59588 .4179 .60178 .40955 .59888 .41391 Mtetra
.901 .904 .496 r
.59888 .41391 .60178 .40955 .60807 .41682 .60465 .39945 Mtetra
.046 .077 .57 r
.60465 .39945 .60807 .41682 .61392 .40623 .6112 .41544 Mtetra
.689 .723 .206 r
.6112 .41544 .61392 .40623 .62019 .41091 .61682 .39616 Mtetra
0 .057 .573 r
.61682 .39616 .62019 .41091 .62646 .41396 .62342 .411 Mtetra
.375 .662 .969 r
.62342 .411 .62646 .41396 .63201 .39465 .62965 .41168 Mtetra
0 0 .181 r
.62965 .41168 .63201 .39465 .6394 .42905 .63516 .39091 Mtetra
0 0 .329 r
.63516 .39091 .6394 .42905 .64448 .39699 .64338 .44625 Mtetra
0 0 .322 r
.64338 .44625 .64448 .39699 .65115 .40853 .64761 .39119 Mtetra
0 0 .219 r
.64761 .39119 .65115 .40853 .65916 .45075 .65522 .42512 Mtetra
0 0 .298 r
.65522 .42512 .65916 .45075 .66287 .38891 .66334 .46747 Mtetra
0 0 .362 r
.66334 .46747 .66287 .38891 .67177 .44723 .66605 .38259 Mtetra
.262 .15 .533 r
.66605 .38259 .67177 .44723 .67905 .46584 .67424 .4237 Mtetra
.594 .404 .594 r
.67424 .4237 .67905 .46584 .68124 .37831 .68042 .41917 Mtetra
0 0 .294 r
.68042 .41917 .68124 .37831 .68992 .42462 .68432 .3687 Mtetra
.218 .124 .529 r
.68432 .3687 .68992 .42462 .69608 .41946 .69274 .40883 Mtetra
.871 .659 .612 r
.69274 .40883 .69608 .41946 .69972 .36837 .69795 .38609 Mtetra
.035 0 .281 r
.69795 .38609 .69972 .36837 .70872 .41476 .70338 .36833 Mtetra
.29 .183 .556 r
.70338 .36833 .70872 .41476 .71412 .39638 .71141 .39642 Mtetra
.995 .809 .541 r
.71141 .39642 .71412 .39638 .71863 .36411 .71636 .37089 Mtetra
.312 0 .173 r
.71636 .37089 .71863 .36411 .72759 .40457 .72262 .36772 Mtetra
.346 .234 .581 r
.72262 .36772 .72759 .40457 .73291 .38585 .73029 .38644 Mtetra
.999 .829 .539 r
.73029 .38644 .73291 .38585 .73759 .35854 .73528 .36317 Mtetra
.494 .056 .135 r
.73528 .36317 .73759 .35854 .74665 .39585 .74184 .36397 Mtetra
.327 .229 .589 r
.74184 .36397 .74665 .39585 .75261 .38715 .74961 .38158 Mtetra
.936 .735 .607 r
.74961 .38158 .75261 .38715 .75658 .3513 .75462 .35979 Mtetra
.294 0 .229 r
.75462 .35979 .75658 .3513 .76543 .38216 .76085 .35513 Mtetra
.088 .076 .547 r
.76085 .35513 .76543 .38216 .77363 .40264 .76944 .38143 Mtetra
.711 .516 .624 r
.76944 .38143 .77363 .40264 .77678 .35798 .77513 .36916 Mtetra
0 0 0 r
.77513 .36916 .77678 .35798 .78277 .35025 .77958 .34165 Mtetra
.7 .373 0 r
.77958 .34165 .78277 .35025 .7941 .40667 .78823 .36616 Mtetra
.149 .096 .537 r
.78823 .36616 .7941 .40667 .80206 .42067 .79798 .40222 Mtetra
.817 .592 .597 r
.79798 .40222 .80206 .42067 .80377 .3623 .80264 .37758 Mtetra
.757 .645 .085 r
.80264 .37758 .80377 .3623 .80803 .33484 .80538 .33218 Mtetra
.85 .419 0 r
.80538 .33218 .80803 .33484 .82056 .39848 .81375 .35048 Mtetra
0 0 .34 r
.81375 .35048 .82056 .39848 .8368 .49847 .82848 .43604 Mtetra
0 0 .462 r
.82848 .43604 .8368 .49847 .84792 .5405 .84282 .51335 Mtetra
.511 .371 .627 r
.84282 .51335 .84792 .5405 .85105 .49907 .85038 .5174 Mtetra
.764 .628 .065 r
.85038 .5174 .85105 .49907 .85059 .42335 .85176 .45902 Mtetra
0 0 .199 r
.85176 .45902 .85059 .42335 .85133 .36224 .85176 .38931 Mtetra
0 0 .224 r
.85176 .38931 .85133 .36224 .85482 .32968 .85372 .34105 Mtetra
0 0 .069 r
.85372 .34105 .85482 .32968 .86036 .31748 .85814 .31782 Mtetra
.872 .99 .731 r
.85814 .31782 .86036 .31748 .86683 .314 .86415 .30988 Mtetra
.666 .735 .901 r
.86415 .30988 .86683 .314 .87351 .31239 .87078 .30767 Mtetra
.617 .681 .888 r
.87078 .30767 .87351 .31239 .88018 .31048 .87752 .30631 Mtetra
.643 .723 .907 r
.87752 .30631 .88018 .31048 .88682 .3082 .88423 .30448 Mtetra
.698 .74 .884 r
.28691 .49509 .2904 .4985 .29582 .49641 .29236 .49274 Mtetra
.679 .722 .882 r
.29236 .49274 .29582 .49641 .30128 .49381 .29779 .49069 Mtetra
.273 .589 .947 r
.29779 .49069 .30128 .49381 .3067 .49197 .30301 .49194 Mtetra
.87 .479 .298 r
.30301 .49194 .3067 .49197 .31178 .4957 .3076 .50312 Mtetra
.86 .562 .482 r
.3076 .50312 .31178 .4957 .31593 .51455 .31107 .53281 Mtetra
.843 .566 .518 r
.31107 .53281 .31593 .51455 .31865 .55827 .31334 .58343 Mtetra
.825 .552 .525 r
.31334 .58343 .31865 .55827 .32027 .62316 .31554 .63834 Mtetra
.774 .48 .489 r
.31554 .63834 .32027 .62316 .32278 .67644 .31995 .65919 Mtetra
.853 .629 .598 r
.31995 .65919 .32278 .67644 .32898 .66749 .32807 .61655 Mtetra
.813 .575 .578 r
.32807 .61655 .32898 .66749 .3391 .58639 .33823 .53496 Mtetra
.771 .54 .584 r
.33823 .53496 .3391 .58639 .34932 .49873 .34671 .48002 Mtetra
.369 .283 .627 r
.34671 .48002 .34932 .49873 .35576 .47959 .35177 .48722 Mtetra
.867 .565 .476 r
.35177 .48722 .35576 .47959 .35906 .52285 .35562 .51913 Mtetra
.781 .747 .821 r
.35562 .51913 .35906 .52285 .3637 .54168 .36139 .51445 Mtetra
.783 .563 .601 r
.36139 .51445 .3637 .54168 .37124 .49921 .36845 .48245 Mtetra
.664 .501 .653 r
.36845 .48245 .37124 .49921 .37799 .47202 .37423 .47671 Mtetra
.83 .487 .407 r
.37423 .47671 .37799 .47202 .38237 .49813 .3791 .4915 Mtetra
.771 .656 .735 r
.3791 .4915 .38237 .49813 .38765 .50513 .38494 .48487 Mtetra
.722 .529 .629 r
.38494 .48487 .38765 .50513 .39451 .47288 .39105 .47168 Mtetra
.701 .161 0 r
.39105 .47168 .39451 .47288 .39997 .4756 .39642 .47682 Mtetra
0 0 0 r
.39642 .47682 .39997 .4756 .40487 .49439 .40208 .47496 Mtetra
.681 .503 .638 r
.40208 .47496 .40487 .49439 .41132 .4705 .40798 .46671 Mtetra
0 .116 .636 r
.40798 .46671 .41132 .4705 .41705 .46676 .41342 .47163 Mtetra
0 0 0 r
.41342 .47163 .41705 .46676 .42202 .48757 .41926 .46537 Mtetra
.639 .465 .631 r
.41926 .46537 .42202 .48757 .42842 .46275 .42507 .45989 Mtetra
.847 .389 .006 r
.42507 .45989 .42842 .46275 .43406 .46317 .43044 .46981 Mtetra
.841 .883 .45 r
.43044 .46981 .43406 .46317 .43914 .48583 .43652 .45541 Mtetra
.553 .385 .608 r
.43652 .45541 .43914 .48583 .44569 .45161 .44219 .45604 Mtetra
.831 .475 .382 r
.44219 .45604 .44569 .45161 .45101 .46799 .44756 .47032 Mtetra
.986 .808 .579 r
.44756 .47032 .45101 .46799 .45637 .48613 .4539 .44317 Mtetra
.344 .214 .556 r
.4539 .44317 .45637 .48613 .46301 .44078 .45924 .46207 Mtetra
.607 .325 .463 r
.45924 .46207 .46301 .44078 .46785 .49164 .46492 .46692 Mtetra
.797 .573 .597 r
.46492 .46692 .46785 .49164 .47374 .48804 .47124 .43495 Mtetra
0 0 .277 r
.47124 .43495 .47374 .48804 .48016 .44572 .47603 .50127 Mtetra
.311 .116 .446 r
.47603 .50127 .48016 .44572 .48495 .52932 .48228 .47391 Mtetra
.711 .486 .581 r
.48228 .47391 .48495 .52932 .49146 .47437 .48852 .44046 Mtetra
0 0 .085 r
.48852 .44046 .49146 .47437 .49759 .44351 .4938 .49917 Mtetra
0 0 .225 r
.4938 .49917 .49759 .44351 .50312 .49136 .50024 .43417 Mtetra
.39 .24 .554 r
.50024 .43417 .50312 .49136 .50936 .42975 .50597 .45539 Mtetra
.542 .275 .461 r
.50597 .45539 .50936 .42975 .51515 .45138 .51188 .45549 Mtetra
.997 .808 .527 r
.51188 .45549 .51515 .45138 .52107 .44128 .51789 .42216 Mtetra
0 0 .226 r
.51789 .42216 .52107 .44128 .52697 .42704 .52377 .45276 Mtetra
0 0 .098 r
.52377 .45276 .52697 .42704 .53291 .43933 .52968 .41745 Mtetra
.017 .027 .524 r
.52968 .41745 .53291 .43933 .53878 .42136 .53567 .43719 Mtetra
0 0 .148 r
.53567 .43719 .53878 .42136 .54478 .43098 .54156 .41948 Mtetra
.32 .319 .702 r
.54156 .41948 .54478 .43098 .55067 .42042 .54757 .42527 Mtetra
0 0 0 r
.54757 .42527 .55067 .42042 .55667 .4236 .5535 .41837 Mtetra
.516 .595 .871 r
.5535 .41837 .55667 .4236 .56262 .41867 .55951 .4187 Mtetra
.73 .983 .907 r
.55951 .4187 .56262 .41867 .56862 .41801 .56548 .41468 Mtetra
.485 .689 .957 r
.56548 .41468 .56862 .41801 .57462 .41605 .57152 .4147 Mtetra
.782 .918 .93 r
.57152 .4147 .57462 .41605 .58061 .41288 .57752 .41075 Mtetra
.402 .74 .993 r
.57752 .41075 .58061 .41288 .5867 .41396 .58359 .41069 Mtetra
.629 .754 .937 r
.58359 .41069 .5867 .41396 .59263 .40677 .58965 .40917 Mtetra
.487 .837 .566 r
.58965 .40917 .59263 .40677 .59888 .41391 .59565 .40405 Mtetra
.033 .156 .661 r
.59565 .40405 .59888 .41391 .60465 .39945 .60198 .41319 Mtetra
0 0 .047 r
.60198 .41319 .60465 .39945 .6112 .41544 .60763 .39332 Mtetra
0 0 .412 r
.60763 .39332 .6112 .41544 .61682 .39616 .61457 .42215 Mtetra
0 0 .182 r
.61457 .42215 .61682 .39616 .62342 .411 .61976 .38732 Mtetra
0 0 .389 r
.61976 .38732 .62342 .411 .62965 .41168 .62695 .41965 Mtetra
0 0 0 r
.62695 .41965 .62965 .41168 .63516 .39091 .63287 .40944 Mtetra
0 0 .257 r
.63287 .40944 .63516 .39091 .64338 .44625 .63846 .39062 Mtetra
0 0 .456 r
.63846 .39062 .64338 .44625 .64761 .39119 .64679 .44672 Mtetra
0 0 .329 r
.64679 .44672 .64761 .39119 .65522 .42512 .65073 .38464 Mtetra
.141 .081 .522 r
.65073 .38464 .65522 .42512 .66334 .46747 .65837 .41768 Mtetra
.396 .255 .569 r
.65837 .41768 .66334 .46747 .66605 .38259 .66557 .43712 Mtetra
0 0 .3 r
.66557 .43712 .66605 .38259 .67424 .4237 .66895 .3698 Mtetra
.327 .202 .554 r
.66895 .3698 .67424 .4237 .68042 .41917 .6766 .39805 Mtetra
.682 .497 .63 r
.6766 .39805 .68042 .41917 .68432 .3687 .68253 .38886 Mtetra
0 0 .271 r
.68253 .38886 .68432 .3687 .69274 .40883 .68781 .367 Mtetra
.323 .21 .567 r
.68781 .367 .69274 .40883 .69795 .38609 .69538 .3895 Mtetra
.955 .889 .497 r
.69538 .3895 .69795 .38609 .70338 .36833 .70086 .37214 Mtetra
0 0 0 r
.70086 .37214 .70338 .36833 .71141 .39642 .707 .36714 Mtetra
.42 .298 .606 r
.707 .36714 .71141 .39642 .71636 .37089 .71405 .37751 Mtetra
0 0 0 r
.71405 .37751 .71636 .37089 .72262 .36772 .71975 .36466 Mtetra
.419 .681 .971 r
.71975 .36466 .72262 .36772 .73029 .38644 .72626 .36506 Mtetra
.52 .388 .641 r
.72626 .36506 .73029 .38644 .73528 .36317 .73293 .36764 Mtetra
0 0 0 r
.73293 .36764 .73528 .36317 .74184 .36397 .73895 .36003 Mtetra
.188 .482 .896 r
.73895 .36003 .74184 .36397 .74961 .38158 .74569 .36289 Mtetra
.603 .454 .652 r
.74569 .36289 .74961 .38158 .75462 .35979 .75209 .36057 Mtetra
.836 .994 .748 r
.75209 .36057 .75462 .35979 .76085 .35513 .75815 .35342 Mtetra
.694 .174 0 r
.75815 .35342 .76085 .35513 .76944 .38143 .76539 .36191 Mtetra
.55 .416 .651 r
.76539 .36191 .76944 .38143 .77513 .36916 .77209 .36268 Mtetra
.906 .72 .64 r
.77209 .36268 .77513 .36916 .77958 .34165 .77737 .34535 Mtetra
.625 .16 .129 r
.77737 .34535 .77958 .34165 .78823 .36616 .78433 .34915 Mtetra
0 0 .457 r
.78433 .34915 .78823 .36616 .79798 .40222 .79325 .3758 Mtetra
.583 .418 .623 r
.79325 .3758 .79798 .40222 .80264 .37758 .79986 .37403 Mtetra
.981 .748 .512 r
.79986 .37403 .80264 .37758 .80538 .33218 .80353 .33875 Mtetra
0 0 .041 r
.80353 .33875 .80538 .33218 .81375 .35048 .80952 .33047 Mtetra
0 0 .181 r
.80952 .33047 .81375 .35048 .82848 .43604 .82116 .38358 Mtetra
0 0 .412 r
.82116 .38358 .82848 .43604 .84282 .51335 .8354 .46146 Mtetra
.249 .158 .552 r
.8354 .46146 .84282 .51335 .85038 .5174 .84612 .49917 Mtetra
.828 .601 .594 r
.84612 .49917 .85038 .5174 .85176 .45902 .85074 .47326 Mtetra
.867 .688 .161 r
.85074 .47326 .85176 .45902 .85176 .38931 .85186 .41368 Mtetra
0 0 .113 r
.85186 .41368 .85176 .38931 .85372 .34105 .85323 .35868 Mtetra
0 0 .153 r
.85323 .35868 .85372 .34105 .85814 .31782 .8566 .3247 Mtetra
0 0 0 r
.8566 .3247 .85814 .31782 .86415 .30988 .86184 .30928 Mtetra
.807 .993 .872 r
.86184 .30928 .86415 .30988 .87078 .30767 .86814 .30389 Mtetra
.651 .75 .922 r
.86814 .30389 .87078 .30767 .87752 .30631 .87482 .3019 Mtetra
.63 .705 .9 r
.87482 .3019 .87752 .30631 .88423 .30448 .88156 .30028 Mtetra
.667 .71 .88 r
.28344 .49124 .28691 .49509 .29236 .49274 .28886 .48939 Mtetra
.516 .688 .946 r
.28886 .48939 .29236 .49274 .29779 .49069 .29416 .48922 Mtetra
.735 .209 0 r
.29416 .48922 .29779 .49069 .30301 .49194 .29911 .4945 Mtetra
.864 .527 .411 r
.29911 .4945 .30301 .49194 .3076 .50312 .30334 .51115 Mtetra
.863 .568 .487 r
.30334 .51115 .3076 .50312 .31107 .53281 .3066 .54385 Mtetra
.867 .581 .503 r
.3066 .54385 .31107 .53281 .31334 .58343 .30923 .58846 Mtetra
.89 .592 .476 r
.30923 .58846 .31334 .58343 .31554 .63834 .31253 .62496 Mtetra
.584 .47 .69 r
.31253 .62496 .31554 .63834 .31995 .65919 .31819 .62422 Mtetra
.798 .569 .591 r
.31819 .62422 .31995 .65919 .32807 .61655 .32662 .5762 Mtetra
.813 .578 .583 r
.32662 .5762 .32807 .61655 .33823 .53496 .33588 .51129 Mtetra
.806 .584 .602 r
.33588 .51129 .33823 .53496 .34671 .48002 .34327 .47649 Mtetra
.876 .442 .059 r
.34327 .47649 .34671 .48002 .35177 .48722 .34815 .48717 Mtetra
.914 .58 .395 r
.34815 .48717 .35177 .48722 .35562 .51913 .35245 .5099 Mtetra
.713 .587 .714 r
.35245 .5099 .35562 .51913 .36139 .51445 .35825 .5046 Mtetra
.858 .655 .626 r
.35825 .5046 .36139 .51445 .36845 .48245 .36498 .48015 Mtetra
.866 .808 .791 r
.36498 .48015 .36845 .48245 .37423 .47671 .37084 .47285 Mtetra
.872 .44 .035 r
.37084 .47285 .37423 .47671 .3791 .4915 .37586 .48405 Mtetra
.535 .524 .79 r
.37586 .48405 .3791 .4915 .38494 .48487 .3814 .48448 Mtetra
.948 .828 .692 r
.3814 .48448 .38494 .48487 .39105 .47168 .38756 .47058 Mtetra
.788 .91 .924 r
.38756 .47058 .39105 .47168 .39642 .47682 .39329 .46671 Mtetra
.08 .176 .665 r
.39329 .46671 .39642 .47682 .40208 .47496 .39859 .47428 Mtetra
.8 .938 .92 r
.39859 .47428 .40208 .47496 .40798 .46671 .40436 .47012 Mtetra
.941 .955 .649 r
.40436 .47012 .40798 .46671 .41342 .47163 .41039 .45865 Mtetra
.366 .327 .682 r
.41039 .45865 .41342 .47163 .41926 .46537 .41584 .46383 Mtetra
.4 0 0 r
.41584 .46383 .41926 .46537 .42507 .45989 .4214 .46689 Mtetra
.846 .879 .443 r
.4214 .46689 .42507 .45989 .43044 .46981 .42752 .45185 Mtetra
.434 .336 .645 r
.42752 .45185 .43044 .46981 .43652 .45541 .43305 .45702 Mtetra
.761 .312 .185 r
.43305 .45702 .43652 .45541 .44219 .45604 .43858 .46341 Mtetra
.95 .882 .479 r
.43858 .46341 .44219 .45604 .44756 .47032 .44481 .44289 Mtetra
.31 .214 .58 r
.44481 .44289 .44756 .47032 .4539 .44317 .45022 .45631 Mtetra
.577 .264 .402 r
.45022 .45631 .4539 .44317 .45924 .46207 .45592 .45847 Mtetra
.93 .735 .619 r
.45592 .45847 .45924 .46207 .46492 .46692 .46217 .43429 Mtetra
0 0 .373 r
.46217 .43429 .46492 .46692 .47124 .43495 .46729 .47037 Mtetra
.243 .043 .397 r
.46729 .47037 .47124 .43495 .47603 .50127 .47345 .44974 Mtetra
.624 .42 .585 r
.47345 .44974 .47603 .50127 .48228 .47391 .47942 .43885 Mtetra
0 0 .12 r
.47942 .43885 .48228 .47391 .48852 .44046 .48454 .49592 Mtetra
0 0 .246 r
.48454 .49592 .48852 .44046 .4938 .49917 .49111 .43456 Mtetra
.444 .277 .559 r
.49111 .43456 .4938 .49917 .50024 .43417 .49682 .45161 Mtetra
.722 .421 .468 r
.49682 .45161 .50024 .43417 .50597 .45539 .50261 .4665 Mtetra
.997 .801 .443 r
.50261 .4665 .50597 .45539 .51188 .45549 .5088 .41719 Mtetra
0 0 .414 r
.5088 .41719 .51188 .45549 .51789 .42216 .51456 .45699 Mtetra
0 0 .234 r
.51456 .45699 .51789 .42216 .52377 .45276 .52057 .41842 Mtetra
.361 .24 .577 r
.52057 .41842 .52377 .45276 .52968 .41745 .5265 .4331 Mtetra
.193 0 .293 r
.5265 .4331 .52968 .41745 .53567 .43719 .53244 .42272 Mtetra
.654 .507 .672 r
.53244 .42272 .53567 .43719 .54156 .41948 .53839 .41837 Mtetra
0 .364 .676 r
.53839 .41837 .54156 .41948 .54757 .42527 .54437 .42041 Mtetra
.836 .729 .746 r
.54437 .42041 .54757 .42527 .5535 .41837 .55031 .41215 Mtetra
.384 .482 .837 r
.55031 .41215 .5535 .41837 .55951 .4187 .55634 .41443 Mtetra
.775 .74 .821 r
.55634 .41443 .55951 .4187 .56548 .41468 .56232 .40972 Mtetra
.663 .675 .851 r
.56232 .40972 .56548 .41468 .57152 .4147 .56833 .40765 Mtetra
.504 .523 .81 r
.56833 .40765 .57152 .4147 .57752 .41075 .5744 .40857 Mtetra
.876 .851 .814 r
.5744 .40857 .57752 .41075 .58359 .41069 .58036 .40159 Mtetra
.254 .319 .738 r
.58036 .40159 .58359 .41069 .58965 .40917 .58656 .40714 Mtetra
.904 .851 .781 r
.58656 .40714 .58965 .40917 .59565 .40405 .5925 .39875 Mtetra
.189 .405 .842 r
.5925 .39875 .59565 .40405 .60198 .41319 .59871 .40239 Mtetra
.496 .444 .729 r
.59871 .40239 .60198 .41319 .60763 .39332 .60491 .40427 Mtetra
0 0 .066 r
.60491 .40427 .60763 .39332 .61457 .42215 .61072 .39047 Mtetra
.029 .012 .5 r
.61072 .39047 .61457 .42215 .61976 .38732 .61775 .4203 Mtetra
0 0 .239 r
.61775 .4203 .61976 .38732 .62695 .41965 .62275 .3794 Mtetra
0 0 .432 r
.62275 .3794 .62695 .41965 .63287 .40944 .63041 .42472 Mtetra
0 0 .09 r
.63041 .42472 .63287 .40944 .63846 .39062 .63596 .40286 Mtetra
0 0 .083 r
.63596 .40286 .63846 .39062 .64679 .44672 .64165 .38641 Mtetra
.069 .012 .478 r
.64165 .38641 .64679 .44672 .65073 .38464 .65002 .44127 Mtetra
0 0 .342 r
.65002 .44127 .65073 .38464 .65837 .41768 .65397 .38029 Mtetra
.461 .312 .592 r
.65397 .38029 .65837 .41768 .66557 .43712 .66067 .38974 Mtetra
.425 .277 .575 r
.66067 .38974 .66557 .43712 .66895 .3698 .6677 .40532 Mtetra
0 0 .307 r
.6677 .40532 .66895 .3698 .6766 .39805 .67225 .36527 Mtetra
.257 .175 .568 r
.67225 .36527 .6766 .39805 .68253 .38886 .67961 .38644 Mtetra
.873 .858 .824 r
.67961 .38644 .68253 .38886 .68781 .367 .68567 .37964 Mtetra
0 0 .113 r
.68567 .37964 .68781 .367 .69538 .3895 .69117 .36221 Mtetra
.264 .193 .586 r
.69117 .36221 .69538 .3895 .70086 .37214 .69852 .37972 Mtetra
0 0 0 r
.69852 .37972 .70086 .37214 .707 .36714 .70435 .3685 Mtetra
.893 .977 .681 r
.70435 .3685 .707 .36714 .71405 .37751 .71028 .35937 Mtetra
.252 .22 .628 r
.71028 .35937 .71405 .37751 .71975 .36466 .71748 .37157 Mtetra
0 0 .03 r
.71748 .37157 .71975 .36466 .72626 .36506 .72348 .36346 Mtetra
.934 .891 .764 r
.72348 .36346 .72626 .36506 .73293 .36764 .7294 .35421 Mtetra
.258 .261 .672 r
.7294 .35421 .73293 .36764 .73895 .36003 .73652 .36319 Mtetra
.311 0 0 r
.73652 .36319 .73895 .36003 .74569 .36289 .74303 .36239 Mtetra
.975 .902 .68 r
.74303 .36239 .74569 .36289 .75209 .36057 .74874 .34998 Mtetra
.504 .456 .737 r
.74874 .34998 .75209 .36057 .75815 .35342 .75544 .35168 Mtetra
.754 .255 0 r
.75544 .35168 .75815 .35342 .76539 .36191 .76281 .36181 Mtetra
.855 .995 .824 r
.76281 .36181 .76539 .36191 .77209 .36268 .76897 .35535 Mtetra
.875 .699 .66 r
.76897 .35535 .77209 .36268 .77737 .34535 .77447 .34061 Mtetra
0 .271 .777 r
.77447 .34061 .77737 .34535 .78433 .34915 .78159 .34633 Mtetra
.872 .453 .02 r
.78159 .34633 .78433 .34915 .79325 .3758 .78997 .36656 Mtetra
.607 .541 .754 r
.78997 .36656 .79325 .3758 .79986 .37403 .79661 .36524 Mtetra
.92 .694 .579 r
.79661 .36524 .79986 .37403 .80353 .33875 .80102 .338 Mtetra
.974 .908 .682 r
.80102 .338 .80353 .33875 .80952 .33047 .80668 .32592 Mtetra
.905 .531 .084 r
.80668 .32592 .80952 .33047 .82116 .38358 .8165 .35945 Mtetra
0 0 .194 r
.8165 .35945 .82116 .38358 .8354 .46146 .82912 .42099 Mtetra
.063 .04 .517 r
.82912 .42099 .8354 .46146 .84612 .49917 .84023 .46378 Mtetra
.602 .417 .604 r
.84023 .46378 .84612 .49917 .85074 .47326 .84688 .45895 Mtetra
.913 .66 .541 r
.84688 .45895 .85074 .47326 .85186 .41368 .84986 .41756 Mtetra
.984 .756 .355 r
.84986 .41756 .85186 .41368 .85323 .35868 .85192 .36869 Mtetra
.811 .693 .152 r
.85192 .36869 .85323 .35868 .8566 .3247 .85506 .33192 Mtetra
0 0 0 r
.85506 .33192 .8566 .3247 .86184 .30928 .85978 .31117 Mtetra
.777 .919 .541 r
.85978 .31117 .86184 .30928 .86814 .30389 .86567 .30176 Mtetra
.764 .903 .937 r
.86567 .30176 .86814 .30389 .87482 .3019 .87215 .29784 Mtetra
.662 .74 .908 r
.87215 .29784 .87482 .3019 .88156 .30028 .87885 .29567 Mtetra
.631 .696 .892 r
.27996 .48733 .28344 .49124 .28886 .48939 .28534 .48602 Mtetra
.384 .63 .951 r
.28534 .48602 .28886 .48939 .29416 .48922 .29059 .48678 Mtetra
.759 .25 0 r
.29059 .48678 .29416 .48922 .29911 .4945 .29547 .49305 Mtetra
.916 .56 .344 r
.29547 .49305 .29911 .4945 .30334 .51115 .29967 .50994 Mtetra
.93 .619 .432 r
.29967 .50994 .30334 .51115 .3066 .54385 .30299 .54129 Mtetra
.941 .643 .445 r
.30299 .54129 .3066 .54385 .30923 .58846 .30577 .58291 Mtetra
.96 .647 .387 r
.30577 .58291 .30923 .58846 .31253 .62496 .30923 .61606 Mtetra
.662 .568 .739 r
.30923 .61606 .31253 .62496 .31819 .62422 .31503 .61314 Mtetra
.891 .666 .59 r
.31503 .61314 .31819 .62422 .32662 .5762 .32355 .56439 Mtetra
.901 .668 .576 r
.32355 .56439 .32662 .5762 .33588 .51129 .33281 .50046 Mtetra
.864 .652 .614 r
.33281 .50046 .33588 .51129 .34327 .47649 .33996 .47059 Mtetra
.948 .592 .227 r
.33996 .47059 .34327 .47649 .34815 .48717 .34434 .49018 Mtetra
.892 .575 .44 r
.34434 .49018 .34815 .48717 .35245 .5099 .34842 .51694 Mtetra
.857 .899 .481 r
.34842 .51694 .35245 .5099 .35825 .5046 .35471 .50264 Mtetra
.939 .734 .599 r
.35471 .50264 .35825 .5046 .36498 .48015 .36189 .4697 Mtetra
.492 .44 .727 r
.36189 .4697 .36498 .48015 .37084 .47285 .36732 .47142 Mtetra
.927 .58 .355 r
.36732 .47142 .37084 .47285 .37586 .48405 .37187 .49278 Mtetra
0 0 0 r
.37187 .49278 .37586 .48405 .3814 .48448 .37798 .48099 Mtetra
.918 .733 .636 r
.37798 .48099 .3814 .48448 .38756 .47058 .3845 .45901 Mtetra
0 0 .459 r
.3845 .45901 .38756 .47058 .39329 .46671 .38954 .47201 Mtetra
.731 .358 .343 r
.38954 .47201 .39329 .46671 .39859 .47428 .39486 .47911 Mtetra
.996 .859 .574 r
.39486 .47911 .39859 .47428 .40436 .47012 .40137 .45608 Mtetra
.45 .373 .679 r
.40137 .45608 .40436 .47012 .41039 .45865 .40685 .45963 Mtetra
.867 .481 .308 r
.40685 .45963 .41039 .45865 .41584 .46383 .41205 .47259 Mtetra
.935 .872 .45 r
.41205 .47259 .41584 .46383 .4214 .46689 .41844 .4507 Mtetra
.494 .388 .663 r
.41844 .4507 .4214 .46689 .42752 .45185 .42402 .45338 Mtetra
.86 .477 .318 r
.42402 .45338 .42752 .45185 .43305 .45702 .42933 .46646 Mtetra
.945 .86 .436 r
.42933 .46646 .43305 .45702 .43858 .46341 .43573 .44181 Mtetra
.287 .215 .599 r
.43573 .44181 .43858 .46341 .44481 .44289 .44114 .45304 Mtetra
.674 .34 .402 r
.44114 .45304 .44481 .44289 .45022 .45631 .44673 .4595 Mtetra
.992 .82 .57 r
.44673 .4595 .45022 .45631 .45592 .45847 .45309 .43245 Mtetra
0 0 .427 r
.45309 .43245 .45592 .45847 .46217 .43429 .4583 .45907 Mtetra
.168 0 .336 r
.4583 .45907 .46217 .43429 .46729 .47037 .46441 .44238 Mtetra
.624 .441 .615 r
.46441 .44238 .46729 .47037 .47345 .44974 .47031 .43675 Mtetra
.969 .667 .272 r
.47031 .43675 .47345 .44974 .47942 .43885 .47537 .48608 Mtetra
0 0 .2 r
.47537 .48608 .47942 .43885 .48454 .49592 .48202 .4308 Mtetra
.428 .264 .555 r
.48202 .4308 .48454 .49592 .49111 .43456 .48763 .44986 Mtetra
.727 .419 .457 r
.48763 .44986 .49111 .43456 .49682 .45161 .49339 .46377 Mtetra
.993 .805 .43 r
.49339 .46377 .49682 .45161 .50261 .4665 .4997 .41566 Mtetra
.059 0 .467 r
.4997 .41566 .50261 .4665 .5088 .41719 .50531 .45776 Mtetra
0 0 .295 r
.50531 .45776 .5088 .41719 .51456 .45699 .51144 .41841 Mtetra
.411 .27 .578 r
.51144 .41841 .51456 .45699 .52057 .41842 .51732 .43129 Mtetra
.353 .058 .318 r
.51732 .43129 .52057 .41842 .5265 .4331 .52327 .42627 Mtetra
.841 .684 .687 r
.52327 .42627 .5265 .4331 .53244 .42272 .52922 .41425 Mtetra
0 0 .564 r
.52922 .41425 .53244 .42272 .53839 .41837 .53522 .42454 Mtetra
.871 .874 .433 r
.53522 .42454 .53839 .41837 .54437 .42041 .54114 .40825 Mtetra
.144 .192 .654 r
.54114 .40825 .54437 .42041 .55031 .41215 .54719 .41734 Mtetra
.676 .827 .394 r
.54719 .41734 .55031 .41215 .55634 .41443 .55313 .40663 Mtetra
.405 .445 .789 r
.55313 .40663 .55634 .41443 .56232 .40972 .55918 .4093 Mtetra
.67 .955 .948 r
.55918 .4093 .56232 .40972 .56833 .40765 .5652 .40619 Mtetra
.816 .91 .904 r
.5652 .40619 .56833 .40765 .5744 .40857 .5712 .40158 Mtetra
.185 .333 .781 r
.5712 .40158 .5744 .40857 .58036 .40159 .57737 .40645 Mtetra
.769 .869 .437 r
.57737 .40645 .58036 .40159 .58656 .40714 .58326 .39455 Mtetra
.01 .096 .607 r
.58326 .39455 .58656 .40714 .5925 .39875 .58961 .40643 Mtetra
0 0 0 r
.58961 .40643 .5925 .39875 .59871 .40239 .59543 .39129 Mtetra
.04 .139 .641 r
.59543 .39129 .59871 .40239 .60491 .40427 .60182 .40144 Mtetra
.691 .806 .936 r
.60182 .40144 .60491 .40427 .61072 .39047 .60794 .39898 Mtetra
0 0 0 r
.60794 .39898 .61072 .39047 .61775 .4203 .61379 .38618 Mtetra
.038 .014 .498 r
.61379 .38618 .61775 .4203 .62275 .3794 .62093 .41788 Mtetra
0 0 .282 r
.62093 .41788 .62275 .3794 .63041 .42472 .62582 .37363 Mtetra
.077 .022 .486 r
.62582 .37363 .63041 .42472 .63596 .40286 .63355 .41887 Mtetra
0 0 .132 r
.63355 .41887 .63596 .40286 .64165 .38641 .63913 .39763 Mtetra
0 0 0 r
.63913 .39763 .64165 .38641 .65002 .44127 .64473 .37871 Mtetra
.15 .069 .501 r
.64473 .37871 .65002 .44127 .65397 .38029 .65298 .42833 Mtetra
0 0 .318 r
.65298 .42833 .65397 .38029 .66067 .38974 .65715 .37412 Mtetra
.459 .374 .673 r
.65715 .37412 .66067 .38974 .6677 .40532 .66365 .37821 Mtetra
.39 .28 .607 r
.66365 .37821 .6677 .40532 .67225 .36527 .67051 .38915 Mtetra
0 0 .237 r
.67051 .38915 .67225 .36527 .67961 .38644 .6755 .35947 Mtetra
.108 .084 .545 r
.6755 .35947 .67961 .38644 .68567 .37964 .68303 .38306 Mtetra
.836 .908 .501 r
.68303 .38306 .68567 .37964 .69117 .36221 .68886 .37124 Mtetra
0 0 0 r
.68886 .37124 .69117 .36221 .69852 .37972 .69456 .35746 Mtetra
.089 .088 .56 r
.69456 .35746 .69852 .37972 .70435 .3685 .70212 .37784 Mtetra
0 0 0 r
.70212 .37784 .70435 .3685 .71028 .35937 .70758 .3599 Mtetra
.74 .992 .819 r
.70758 .3599 .71028 .35937 .71748 .37157 .71376 .35468 Mtetra
.021 .07 .573 r
.71376 .35468 .71748 .37157 .72348 .36346 .72132 .37208 Mtetra
0 0 0 r
.72132 .37208 .72348 .36346 .7294 .35421 .72674 .35429 Mtetra
.833 .998 .831 r
.72674 .35429 .7294 .35421 .73652 .36319 .73288 .34821 Mtetra
0 0 .536 r
.73288 .34821 .73652 .36319 .74303 .36239 .7407 .3671 Mtetra
.676 .791 .327 r
.7407 .3671 .74303 .36239 .74874 .34998 .74645 .35468 Mtetra
.819 .836 .367 r
.74645 .35468 .74874 .34998 .75544 .35168 .75192 .33887 Mtetra
0 0 .502 r
.75192 .33887 .75544 .35168 .76281 .36181 .75993 .35788 Mtetra
0 .178 .702 r
.75993 .35788 .76281 .36181 .76897 .35535 .76706 .3641 Mtetra
.775 .724 .193 r
.76706 .3641 .76897 .35535 .77447 .34061 .77174 .3382 Mtetra
.756 .87 .931 r
.77174 .3382 .77447 .34061 .78159 .34633 .77812 .33452 Mtetra
0 0 .233 r
.77812 .33452 .78159 .34633 .78997 .36656 .78726 .36437 Mtetra
.626 .111 0 r
.78726 .36437 .78997 .36656 .79661 .36524 .79474 .37272 Mtetra
.9 .768 .275 r
.79474 .37272 .79661 .36524 .80102 .338 .79877 .34051 Mtetra
.978 .85 .458 r
.79877 .34051 .80102 .338 .80668 .32592 .80359 .31856 Mtetra
.807 .453 0 r
.80359 .31856 .80668 .32592 .8165 .35945 .81298 .34753 Mtetra
.89 .57 .07 r
.81298 .34753 .8165 .35945 .82912 .42099 .82556 .40932 Mtetra
.805 .491 0 r
.82556 .40932 .82912 .42099 .84023 .46378 .83677 .45359 Mtetra
.649 .556 .737 r
.83677 .45359 .84023 .46378 .84688 .45895 .8436 .45061 Mtetra
.953 .706 .525 r
.8436 .45061 .84688 .45895 .84986 .41756 .84687 .41176 Mtetra
.976 .721 .481 r
.84687 .41176 .84986 .41756 .85192 .36869 .84922 .3653 Mtetra
.987 .752 .493 r
.84922 .3653 .85192 .36869 .85506 .33192 .85252 .32971 Mtetra
.99 .811 .569 r
.85252 .32971 .85506 .33192 .85978 .31117 .85725 .30879 Mtetra
.944 .874 .738 r
.85725 .30879 .85978 .31117 .86567 .30176 .86307 .2985 Mtetra
.799 .834 .878 r
.86307 .2985 .86567 .30176 .87215 .29784 .86947 .29371 Mtetra
.691 .749 .896 r
.86947 .29371 .87215 .29784 .87885 .29567 .87611 .29101 Mtetra
.65 .739 .915 r
.27642 .48406 .27996 .48733 .28534 .48602 .28183 .48246 Mtetra
.376 .613 .943 r
.28183 .48246 .28534 .48602 .29059 .48678 .28707 .48335 Mtetra
.815 .346 0 r
.28707 .48335 .29059 .48678 .29547 .49305 .29182 .49144 Mtetra
.926 .593 .387 r
.29182 .49144 .29547 .49305 .29967 .50994 .29566 .51348 Mtetra
.902 .608 .477 r
.29566 .51348 .29967 .50994 .30299 .54129 .29839 .55324 Mtetra
.868 .584 .505 r
.29839 .55324 .30299 .54129 .30577 .58291 .3007 .60173 Mtetra
.79 .505 .505 r
.3007 .60173 .30577 .58291 .30923 .61606 .30443 .63085 Mtetra
0 0 0 r
.30443 .63085 .30923 .61606 .31503 .61314 .31141 .60937 Mtetra
.933 .702 .566 r
.31141 .60937 .31503 .61314 .32355 .56439 .32113 .54187 Mtetra
.861 .626 .582 r
.32113 .54187 .32355 .56439 .33281 .50046 .33032 .47979 Mtetra
.678 .497 .633 r
.33032 .47979 .33281 .50046 .33996 .47059 .33626 .47131 Mtetra
.919 .608 .439 r
.33626 .47131 .33996 .47059 .34434 .49018 .33991 .50383 Mtetra
.707 .401 .456 r
.33991 .50383 .34434 .49018 .34842 .51694 .34487 .51432 Mtetra
.933 .729 .603 r
.34487 .51432 .34842 .51694 .35471 .50264 .35211 .48223 Mtetra
.761 .557 .621 r
.35211 .48223 .35471 .50264 .36189 .4697 .35861 .46304 Mtetra
.934 .575 .163 r
.35861 .46304 .36189 .4697 .36732 .47142 .36319 .48203 Mtetra
.65 .323 .405 r
.36319 .48203 .36732 .47142 .37187 .49278 .36851 .48726 Mtetra
.901 .703 .627 r
.36851 .48726 .37187 .49278 .37798 .48099 .37521 .4628 Mtetra
.576 .433 .65 r
.37521 .4628 .37798 .48099 .3845 .45901 .38081 .46207 Mtetra
.852 .496 .379 r
.38081 .46207 .3845 .45901 .38954 .47201 .38576 .47706 Mtetra
.967 .919 .582 r
.38576 .47706 .38954 .47201 .39486 .47911 .39202 .4612 Mtetra
.689 .513 .644 r
.39202 .4612 .39486 .47911 .40137 .45608 .39796 .45295 Mtetra
.92 .525 .201 r
.39796 .45295 .40137 .45608 .40685 .45963 .40302 .46814 Mtetra
0 0 0 r
.40302 .46814 .40685 .45963 .41205 .47259 .40916 .45481 Mtetra
.683 .509 .645 r
.40916 .45481 .41205 .47259 .41844 .4507 .41507 .44719 Mtetra
.917 .519 .171 r
.41507 .44719 .41844 .4507 .42402 .45338 .42026 .46239 Mtetra
.799 .829 .356 r
.42026 .46239 .42402 .45338 .42933 .46646 .42649 .44495 Mtetra
.56 .41 .635 r
.42649 .44495 .42933 .46646 .43573 .44181 .43219 .44498 Mtetra
.827 .45 .34 r
.43219 .44498 .43573 .44181 .44114 .45304 .43759 .45695 Mtetra
.996 .846 .572 r
.43759 .45695 .44114 .45304 .44673 .4595 .44395 .43304 Mtetra
.213 .145 .559 r
.44395 .43304 .44673 .4595 .45309 .43245 .44931 .44935 Mtetra
.422 .141 .38 r
.44931 .44935 .45309 .43245 .4583 .45907 .45518 .44501 Mtetra
.787 .593 .639 r
.45518 .44501 .4583 .45907 .46441 .44238 .46129 .42907 Mtetra
.89 .594 .086 r
.46129 .42907 .46441 .44238 .47031 .43675 .4665 .46123 Mtetra
0 0 0 r
.4665 .46123 .47031 .43675 .47537 .48608 .47296 .42424 Mtetra
.363 .216 .543 r
.47296 .42424 .47537 .48608 .48202 .4308 .47842 .44917 Mtetra
.712 .413 .469 r
.47842 .44917 .48202 .4308 .48763 .44986 .48412 .46337 Mtetra
.989 .806 .418 r
.48412 .46337 .48763 .44986 .49339 .46377 .49057 .41404 Mtetra
0 0 .399 r
.49057 .41404 .49339 .46377 .4997 .41566 .49599 .46422 Mtetra
.01 0 .333 r
.49599 .46422 .4997 .41566 .50531 .45776 .50225 .42135 Mtetra
.458 .307 .588 r
.50225 .42135 .50531 .45776 .51144 .41841 .50812 .43003 Mtetra
.6 .272 .387 r
.50812 .43003 .51144 .41841 .51732 .43129 .51405 .43323 Mtetra
.992 .826 .576 r
.51405 .43323 .51732 .43129 .52327 .42627 .52006 .40913 Mtetra
0 0 .443 r
.52006 .40913 .52327 .42627 .52922 .41425 .52601 .42935 Mtetra
0 0 0 r
.52601 .42935 .52922 .41425 .53522 .42454 .53196 .40345 Mtetra
.149 .124 .572 r
.53196 .40345 .53522 .42454 .54114 .40825 .538 .41898 Mtetra
0 0 0 r
.538 .41898 .54114 .40825 .54719 .41734 .54392 .40237 Mtetra
.336 .293 .662 r
.54392 .40237 .54719 .41734 .55313 .40663 .54999 .40944 Mtetra
.761 .945 .614 r
.54999 .40944 .55313 .40663 .55918 .4093 .55596 .40154 Mtetra
.553 .533 .787 r
.55596 .40154 .55918 .4093 .5652 .40619 .56202 .40163 Mtetra
.556 .65 .897 r
.56202 .40163 .5652 .40619 .5712 .40158 .56809 .40125 Mtetra
.903 .951 .823 r
.56809 .40125 .5712 .40158 .57737 .40645 .57408 .39415 Mtetra
.178 .216 .663 r
.57408 .39415 .57737 .40645 .58326 .39455 .58033 .40296 Mtetra
0 0 0 r
.58033 .40296 .58326 .39455 .58961 .40643 .58615 .38638 Mtetra
0 .009 .524 r
.58615 .38638 .58961 .40643 .59543 .39129 .5927 .40622 Mtetra
0 0 0 r
.5927 .40622 .59543 .39129 .60182 .40144 .59834 .3822 Mtetra
0 0 .487 r
.59834 .3822 .60182 .40144 .60794 .39898 .60504 .40393 Mtetra
.692 .829 .39 r
.60504 .40393 .60794 .39898 .61379 .38618 .61097 .3927 Mtetra
0 0 0 r
.61097 .3927 .61379 .38618 .62093 .41788 .61698 .38522 Mtetra
0 0 .474 r
.61698 .38522 .62093 .41788 .62582 .37363 .62424 .41877 Mtetra
0 0 .3 r
.62424 .41877 .62582 .37363 .63355 .41887 .62891 .36782 Mtetra
.073 .02 .485 r
.62891 .36782 .63355 .41887 .63913 .39763 .63672 .41326 Mtetra
0 0 .133 r
.63672 .41326 .63913 .39763 .64473 .37871 .64232 .39269 Mtetra
0 0 0 r
.64232 .39269 .64473 .37871 .65298 .42833 .64768 .36714 Mtetra
.324 .195 .545 r
.64768 .36714 .65298 .42833 .65715 .37412 .65525 .39855 Mtetra
0 0 .168 r
.65525 .39855 .65715 .37412 .66365 .37821 .66016 .36357 Mtetra
.143 .169 .629 r
.66016 .36357 .66365 .37821 .67051 .38915 .66704 .37546 Mtetra
.571 .463 .691 r
.66704 .37546 .67051 .38915 .6755 .35947 .67341 .37512 Mtetra
0 0 .19 r
.67341 .37512 .6755 .35947 .68303 .38306 .67891 .3562 Mtetra
.223 .165 .577 r
.67891 .3562 .68303 .38306 .68886 .37124 .68625 .37497 Mtetra
.913 .896 .483 r
.68625 .37497 .68886 .37124 .69456 .35746 .6919 .35959 Mtetra
0 0 0 r
.6919 .35959 .69456 .35746 .70212 .37784 .69816 .35611 Mtetra
.307 .241 .617 r
.69816 .35611 .70212 .37784 .70758 .3599 .70532 .3684 Mtetra
0 0 0 r
.70532 .3684 .70758 .3599 .71376 .35468 .71078 .35026 Mtetra
.121 .41 .859 r
.71078 .35026 .71376 .35468 .72132 .37208 .7175 .35398 Mtetra
.37 .301 .648 r
.7175 .35398 .72132 .37208 .72674 .35429 .72455 .36222 Mtetra
0 0 0 r
.72455 .36222 .72674 .35429 .73288 .34821 .72995 .34417 Mtetra
0 .332 .815 r
.72995 .34417 .73288 .34821 .7407 .3671 .73681 .34868 Mtetra
.311 .261 .639 r
.73681 .34868 .7407 .3671 .74645 .35468 .74413 .3592 Mtetra
.891 .852 .398 r
.74413 .3592 .74645 .35468 .75192 .33887 .74947 .34097 Mtetra
.02 0 0 r
.74947 .34097 .75192 .33887 .75993 .35788 .75593 .33881 Mtetra
.056 .084 .573 r
.75593 .33881 .75993 .35788 .76706 .3641 .76402 .35804 Mtetra
.851 .72 .719 r
.76402 .35804 .76706 .3641 .77174 .3382 .76995 .34804 Mtetra
0 0 0 r
.76995 .34804 .77174 .3382 .77812 .33452 .77496 .32663 Mtetra
0 0 .428 r
.77496 .32663 .77812 .33452 .78726 .36437 .78296 .34276 Mtetra
0 0 .516 r
.78296 .34276 .78726 .36437 .79474 .37272 .79194 .36944 Mtetra
.958 .804 .648 r
.79194 .36944 .79474 .37272 .79877 .34051 .7974 .3535 Mtetra
.709 .638 .077 r
.7974 .3535 .79877 .34051 .80359 .31856 .80109 .31792 Mtetra
.661 .111 0 r
.80109 .31792 .80359 .31856 .81298 .34753 .80848 .32479 Mtetra
0 0 .175 r
.80848 .32479 .81298 .34753 .82556 .40932 .82082 .38478 Mtetra
0 0 .183 r
.82082 .38478 .82556 .40932 .83677 .45359 .83383 .44882 Mtetra
.703 .29 0 r
.83383 .44882 .83677 .45359 .8436 .45061 .84257 .4655 Mtetra
0 0 .034 r
.84257 .4655 .8436 .45061 .84687 .41176 .84635 .43105 Mtetra
0 0 0 r
.84635 .43105 .84687 .41176 .84922 .3653 .84808 .37747 Mtetra
.813 .677 .131 r
.84808 .37747 .84922 .3653 .85252 .32971 .85054 .33304 Mtetra
.961 .815 .381 r
.85054 .33304 .85252 .32971 .85725 .30879 .85474 .30664 Mtetra
.965 .869 .692 r
.85474 .30664 .85725 .30879 .86307 .2985 .86036 .29436 Mtetra
.79 .783 .846 r
.86036 .29436 .86307 .2985 .86947 .29371 .86675 .28938 Mtetra
.675 .732 .893 r
.86675 .28938 .86947 .29371 .87611 .29101 .87344 .28695 Mtetra
.493 .755 .988 r
.2728 .48171 .27642 .48406 .28183 .48246 .27812 .4813 Mtetra
.659 .105 0 r
.27812 .4813 .28183 .48246 .28707 .48335 .28313 .48546 Mtetra
.856 .504 .385 r
.28313 .48546 .28707 .48335 .29182 .49144 .28746 .49946 Mtetra
.853 .554 .482 r
.28746 .49946 .29182 .49144 .29566 .51348 .29084 .52807 Mtetra
.843 .559 .508 r
.29084 .52807 .29566 .51348 .29839 .55324 .29348 .56905 Mtetra
.828 .543 .506 r
.29348 .56905 .29839 .55324 .3007 .60173 .29655 .60591 Mtetra
.71 .314 .296 r
.29655 .60591 .3007 .60173 .30443 .63085 .30179 .61145 Mtetra
.837 .614 .601 r
.30179 .61145 .30443 .63085 .31141 .60937 .30993 .57174 Mtetra
.815 .581 .584 r
.30993 .57174 .31141 .60937 .32113 .54187 .31931 .51012 Mtetra
.786 .561 .595 r
.31931 .51012 .32113 .54187 .33032 .47979 .32712 .47151 Mtetra
.224 .314 .746 r
.32712 .47151 .33032 .47979 .33626 .47131 .3323 .4761 Mtetra
.857 .532 .436 r
.3323 .4761 .33626 .47131 .33991 .50383 .33662 .49644 Mtetra
.674 .599 .763 r
.33662 .49644 .33991 .50383 .34487 .51432 .3423 .49354 Mtetra
.767 .56 .618 r
.3423 .49354 .34487 .51432 .35211 .48223 .34894 .47295 Mtetra
.726 .594 .708 r
.34894 .47295 .35211 .48223 .35861 .46304 .35478 .46692 Mtetra
.754 .365 .317 r
.35478 .46692 .35861 .46304 .36319 .48203 .35994 .4742 Mtetra
.673 .59 .753 r
.35994 .4742 .36319 .48203 .36851 .48726 .36565 .47118 Mtetra
.702 .529 .651 r
.36565 .47118 .36851 .48726 .37521 .4628 .37161 .4628 Mtetra
.035 .605 .729 r
.37161 .4628 .37521 .4628 .38081 .46207 .37719 .46267 Mtetra
.241 .755 .765 r
.37719 .46267 .38081 .46207 .38576 .47706 .38285 .46126 Mtetra
.642 .491 .662 r
.38285 .46126 .38576 .47706 .39202 .4612 .38863 .45723 Mtetra
.524 .661 .922 r
.38863 .45723 .39202 .4612 .39796 .45295 .39425 .45712 Mtetra
0 0 0 r
.39425 .45712 .39796 .45295 .40302 .46814 .40007 .45254 Mtetra
.612 .471 .666 r
.40007 .45254 .40302 .46814 .40916 .45481 .4058 .45024 Mtetra
.251 .485 .887 r
.4058 .45024 .40916 .45481 .41507 .44719 .41138 .45256 Mtetra
0 0 0 r
.41138 .45256 .41507 .44719 .42026 .46239 .41735 .44421 Mtetra
.55 .416 .651 r
.41735 .44421 .42026 .46239 .42649 .44495 .42302 .44473 Mtetra
.522 0 0 r
.42302 .44473 .42649 .44495 .43219 .44498 .42865 .44759 Mtetra
.969 .934 .664 r
.42865 .44759 .43219 .44498 .43759 .45695 .43473 .43498 Mtetra
.372 .274 .613 r
.43473 .43498 .43759 .45695 .44395 .43304 .44024 .44351 Mtetra
.347 .025 .269 r
.44024 .44351 .44395 .43304 .44931 .44935 .4461 .43967 Mtetra
.794 .627 .674 r
.4461 .43967 .44931 .44935 .45518 .44501 .45214 .4282 Mtetra
0 .013 .533 r
.45214 .4282 .45518 .44501 .46129 .42907 .4576 .44333 Mtetra
0 0 0 r
.4576 .44333 .46129 .42907 .4665 .46123 .46383 .42187 Mtetra
.303 .188 .552 r
.46383 .42187 .4665 .46123 .47296 .42424 .4693 .44138 Mtetra
.654 .353 .45 r
.4693 .44138 .47296 .42424 .47842 .44917 .47504 .44918 Mtetra
.971 .758 .56 r
.47504 .44918 .47842 .44917 .48412 .46337 .48144 .41212 Mtetra
.051 0 .461 r
.48144 .41212 .48412 .46337 .49057 .41404 .48679 .45424 Mtetra
.035 0 .329 r
.48679 .45424 .49057 .41404 .49599 .46422 .49307 .42025 Mtetra
.521 .346 .584 r
.49307 .42025 .49599 .46422 .50225 .42135 .49893 .42433 Mtetra
.804 .4 .286 r
.49893 .42433 .50225 .42135 .50812 .43003 .5048 .43421 Mtetra
.999 .824 .532 r
.5048 .43421 .50812 .43003 .51405 .43323 .51089 .4047 Mtetra
0 0 .483 r
.51089 .4047 .51405 .43323 .52006 .40913 .51676 .43079 Mtetra
0 0 .06 r
.51676 .43079 .52006 .40913 .52601 .42935 .52278 .40063 Mtetra
.215 .145 .558 r
.52278 .40063 .52601 .42935 .53196 .40345 .52876 .41906 Mtetra
0 0 .113 r
.52876 .41906 .53196 .40345 .538 .41898 .53473 .40073 Mtetra
.355 .283 .637 r
.53473 .40073 .538 .41898 .54392 .40237 .54077 .40872 Mtetra
0 0 0 r
.54077 .40872 .54392 .40237 .54999 .40944 .54675 .39944 Mtetra
.474 .442 .742 r
.54675 .39944 .54999 .40944 .55596 .40154 .55281 .40153 Mtetra
.77 .987 .899 r
.55281 .40153 .55596 .40154 .56202 .40163 .55883 .39705 Mtetra
.624 .679 .882 r
.55883 .39705 .56202 .40163 .56809 .40125 .56489 .39568 Mtetra
.535 .594 .86 r
.56489 .39568 .56809 .40125 .57408 .39415 .57099 .39578 Mtetra
.813 .989 .732 r
.57099 .39578 .57408 .39415 .58033 .40296 .577 .38882 Mtetra
.237 .235 .654 r
.577 .38882 .58033 .40296 .58615 .38638 .58329 .39775 Mtetra
0 0 0 r
.58329 .39775 .58615 .38638 .5927 .40622 .5891 .38011 Mtetra
.092 .069 .536 r
.5891 .38011 .5927 .40622 .59834 .3822 .59573 .40197 Mtetra
0 0 .114 r
.59573 .40197 .59834 .3822 .60504 .40393 .60129 .37452 Mtetra
.097 .064 .528 r
.60129 .37452 .60504 .40393 .61097 .3927 .60812 .39917 Mtetra
.748 .808 .33 r
.60812 .39917 .61097 .3927 .61698 .38522 .61395 .384 Mtetra
.837 .933 .892 r
.61395 .384 .61698 .38522 .62424 .41877 .62004 .37884 Mtetra
.217 .133 .541 r
.62004 .37884 .62424 .41877 .62891 .36782 .62716 .40591 Mtetra
0 0 .283 r
.62716 .40591 .62891 .36782 .63672 .41326 .63202 .3622 Mtetra
.241 .14 .533 r
.63202 .3622 .63672 .41326 .64232 .39269 .63946 .39514 Mtetra
.921 .947 .604 r
.63946 .39514 .64232 .39269 .64768 .36714 .64538 .38338 Mtetra
0 0 .107 r
.64538 .38338 .64768 .36714 .65525 .39855 .65081 .36009 Mtetra
.356 .235 .575 r
.65081 .36009 .65525 .39855 .66016 .36357 .65788 .37773 Mtetra
0 0 .124 r
.65788 .37773 .66016 .36357 .66704 .37546 .66344 .35885 Mtetra
.384 .318 .659 r
.66344 .35885 .66704 .37546 .67341 .37512 .67013 .3657 Mtetra
.531 .49 .756 r
.67013 .3657 .67341 .37512 .67891 .3562 .67657 .36645 Mtetra
0 0 .083 r
.67657 .36645 .67891 .3562 .68625 .37497 .68236 .35329 Mtetra
.393 .299 .629 r
.68236 .35329 .68625 .37497 .6919 .35959 .68923 .36193 Mtetra
.545 .856 .555 r
.68923 .36193 .6919 .35959 .69816 .35611 .69538 .35591 Mtetra
.829 .992 .862 r
.69538 .35591 .69816 .35611 .70532 .3684 .70155 .35026 Mtetra
.454 .357 .656 r
.70155 .35026 .70532 .3684 .71078 .35026 .70833 .35521 Mtetra
0 0 0 r
.70833 .35521 .71078 .35026 .7175 .35398 .71452 .34954 Mtetra
.708 .729 .867 r
.71452 .34954 .7175 .35398 .72455 .36222 .72087 .3465 Mtetra
.532 .423 .676 r
.72087 .3465 .72455 .36222 .72995 .34417 .72751 .34781 Mtetra
.109 0 0 r
.72751 .34781 .72995 .34417 .73681 .34868 .73389 .34482 Mtetra
.622 .729 .923 r
.73389 .34482 .73681 .34868 .74413 .3592 .74039 .34332 Mtetra
.61 .473 .67 r
.74039 .34332 .74413 .3592 .74947 .34097 .74684 .34089 Mtetra
.423 .868 .876 r
.74684 .34089 .74947 .34097 .75593 .33881 .75332 .33871 Mtetra
.478 0 0 r
.75332 .33871 .75593 .33881 .76402 .35804 .76023 .34214 Mtetra
.611 .474 .67 r
.76023 .34214 .76402 .35804 .76995 .34804 .76673 .33964 Mtetra
.806 .658 .698 r
.76673 .33964 .76995 .34804 .77496 .32663 .77267 .3298 Mtetra
.612 .126 .076 r
.77267 .3298 .77496 .32663 .78296 .34276 .77967 .33345 Mtetra
0 0 .526 r
.77967 .33345 .78296 .34276 .79194 .36944 .78768 .34865 Mtetra
.609 .45 .642 r
.78768 .34865 .79194 .36944 .7974 .3535 .79421 .34545 Mtetra
.918 .703 .595 r
.79421 .34545 .7974 .3535 .80109 .31792 .79896 .32178 Mtetra
0 0 0 r
.79896 .32178 .80109 .31792 .80848 .32479 .80522 .31577 Mtetra
.822 .487 0 r
.80522 .31577 .80848 .32479 .82082 .38478 .81535 .35209 Mtetra
0 0 .363 r
.81535 .35209 .82082 .38478 .83383 .44882 .82764 .40955 Mtetra
.159 .107 .545 r
.82764 .40955 .83383 .44882 .84257 .4655 .83801 .44408 Mtetra
.694 .506 .629 r
.83801 .44408 .84257 .4655 .84635 .43105 .84413 .43347 Mtetra
.991 .773 .393 r
.84413 .43347 .84635 .43105 .84808 .37747 .84715 .39208 Mtetra
.738 .629 .065 r
.84715 .39208 .84808 .37747 .85054 .33304 .84962 .34688 Mtetra
0 0 .034 r
.84962 .34688 .85054 .33304 .85474 .30664 .85321 .3141 Mtetra
0 0 0 r
.85321 .3141 .85474 .30664 .86036 .29436 .85825 .2959 Mtetra
.76 .937 .593 r
.85825 .2959 .86036 .29436 .86675 .28938 .8643 .28755 Mtetra
.742 .922 .951 r
.8643 .28755 .86675 .28938 .87344 .28695 .87086 .28384 Mtetra
.406 .644 .954 r
.26923 .47836 .2728 .48171 .27812 .4813 .27449 .47894 Mtetra
.673 .135 0 r
.27449 .47894 .27812 .4813 .28313 .48546 .27943 .48406 Mtetra
.903 .525 .3 r
.27943 .48406 .28313 .48546 .28746 .49946 .28378 .49769 Mtetra
.93 .606 .404 r
.28378 .49769 .28746 .49946 .29084 .52807 .28736 .52295 Mtetra
.957 .648 .404 r
.28736 .52295 .29084 .52807 .29348 .56905 .29042 .55727 Mtetra
.963 .658 .247 r
.29042 .55727 .29348 .56905 .29655 .60591 .29388 .58752 Mtetra
.431 .331 .641 r
.29388 .58752 .29655 .60591 .30179 .61145 .29914 .59247 Mtetra
.822 .604 .608 r
.29914 .59247 .30179 .61145 .30993 .57174 .30684 .5599 Mtetra
.893 .664 .585 r
.30684 .5599 .30993 .57174 .31931 .51012 .3158 .506 Mtetra
.923 .709 .597 r
.3158 .506 .31931 .51012 .32712 .47151 .3236 .46834 Mtetra
.106 .492 .902 r
.3236 .46834 .32712 .47151 .3323 .4761 .32893 .47037 Mtetra
.958 .616 .293 r
.32893 .47037 .3323 .4761 .33662 .49644 .33306 .49361 Mtetra
0 .368 .804 r
.33306 .49361 .33662 .49644 .3423 .49354 .33844 .4963 Mtetra
.981 .817 .607 r
.33844 .4963 .3423 .49354 .34894 .47295 .34533 .47183 Mtetra
.932 .808 .701 r
.34533 .47183 .34894 .47295 .35478 .46692 .35156 .45852 Mtetra
.697 .364 0 r
.35156 .45852 .35478 .46692 .35994 .4742 .35641 .47179 Mtetra
.57 .022 0 r
.35641 .47179 .35994 .4742 .36565 .47118 .36174 .47652 Mtetra
.984 .9 .581 r
.36174 .47652 .36565 .47118 .37161 .4628 .36821 .45816 Mtetra
.769 .711 .798 r
.36821 .45816 .37161 .4628 .37719 .46267 .37401 .45332 Mtetra
0 0 .364 r
.37401 .45332 .37719 .46267 .38285 .46126 .37905 .4658 Mtetra
.653 .873 .504 r
.37905 .4658 .38285 .46126 .38863 .45723 .38502 .45781 Mtetra
.961 .87 .701 r
.38502 .45781 .38863 .45723 .39425 .45712 .39118 .4449 Mtetra
0 .056 .583 r
.39118 .4449 .39425 .45712 .40007 .45254 .3964 .45543 Mtetra
0 0 0 r
.3964 .45543 .40007 .45254 .4058 .45024 .40216 .453 Mtetra
.981 .908 .649 r
.40216 .453 .4058 .45024 .41138 .45256 .40836 .43844 Mtetra
.093 .128 .606 r
.40836 .43844 .41138 .45256 .41735 .44421 .41368 .44882 Mtetra
.096 0 0 r
.41368 .44882 .41735 .44421 .42302 .44473 .41949 .44562 Mtetra
.97 .878 .687 r
.41949 .44562 .42302 .44473 .42865 .44759 .42563 .43209 Mtetra
0 .026 .546 r
.42563 .43209 .42865 .44759 .43473 .43498 .43096 .44566 Mtetra
0 0 .049 r
.43096 .44566 .43473 .43498 .44024 .44351 .43701 .43506 Mtetra
.749 .619 .715 r
.43701 .43506 .44024 .44351 .4461 .43967 .44294 .42829 Mtetra
0 0 .427 r
.44294 .42829 .4461 .43967 .45214 .4282 .44838 .44255 Mtetra
0 0 0 r
.44838 .44255 .45214 .4282 .4576 .44333 .45464 .42183 Mtetra
.187 .145 .575 r
.45464 .42183 .4576 .44333 .46383 .42187 .46016 .43578 Mtetra
.429 .129 .352 r
.46016 .43578 .46383 .42187 .4693 .44138 .46606 .43262 Mtetra
.859 .665 .639 r
.46606 .43262 .4693 .44138 .47504 .44918 .47223 .41344 Mtetra
0 0 .418 r
.47223 .41344 .47504 .44918 .48144 .41212 .47756 .44887 Mtetra
0 0 .275 r
.47756 .44887 .48144 .41212 .48679 .45424 .48393 .41371 Mtetra
.427 .278 .576 r
.48393 .41371 .48679 .45424 .49307 .42025 .48968 .42558 Mtetra
.704 .311 .302 r
.48968 .42558 .49307 .42025 .49893 .42433 .49555 .43167 Mtetra
.987 .849 .475 r
.49555 .43167 .49893 .42433 .5048 .43421 .5017 .40344 Mtetra
.007 0 .483 r
.5017 .40344 .5048 .43421 .51089 .4047 .50748 .43061 Mtetra
0 0 .163 r
.50748 .43061 .51089 .4047 .51676 .43079 .51358 .39992 Mtetra
.267 .177 .564 r
.51358 .39992 .51676 .43079 .52278 .40063 .51951 .41732 Mtetra
0 0 .2 r
.51951 .41732 .52278 .40063 .52876 .41906 .52551 .40132 Mtetra
.453 .353 .652 r
.52551 .40132 .52876 .41906 .53473 .40073 .53152 .40583 Mtetra
0 0 0 r
.53152 .40583 .53473 .40073 .54077 .40872 .53752 .3999 Mtetra
.595 .534 .757 r
.53752 .3999 .54077 .40872 .54675 .39944 .54355 .39899 Mtetra
.658 .95 .952 r
.54355 .39899 .54675 .39944 .55281 .40153 .54959 .39599 Mtetra
.614 .633 .846 r
.54959 .39599 .55281 .40153 .55883 .39705 .55565 .39479 Mtetra
.72 .85 .944 r
.55565 .39479 .55883 .39705 .56489 .39568 .5617 .39189 Mtetra
.6 .713 .924 r
.5617 .39189 .56489 .39568 .57099 .39578 .56779 .39078 Mtetra
.579 .641 .876 r
.56779 .39078 .57099 .39578 .577 .38882 .57391 .39012 Mtetra
.741 .985 .77 r
.57391 .39012 .577 .38882 .58329 .39775 .57996 .38447 Mtetra
.224 .235 .662 r
.57996 .38447 .58329 .39775 .5891 .38011 .58628 .3931 Mtetra
0 0 .034 r
.58628 .3931 .5891 .38011 .59573 .40197 .59209 .37492 Mtetra
.055 .04 .521 r
.59209 .37492 .59573 .40197 .60129 .37452 .59881 .39888 Mtetra
0 0 .201 r
.59881 .39888 .60129 .37452 .60812 .39917 .60432 .36918 Mtetra
.113 .074 .531 r
.60432 .36918 .60812 .39917 .61395 .384 .61119 .39368 Mtetra
0 0 .047 r
.61119 .39368 .61395 .384 .62004 .37884 .61713 .38194 Mtetra
.933 .929 .565 r
.61713 .38194 .62004 .37884 .62716 .40591 .623 .3685 Mtetra
.136 .078 .523 r
.623 .3685 .62716 .40591 .63202 .3622 .63025 .39826 Mtetra
0 0 .297 r
.63025 .39826 .63202 .3622 .63946 .39514 .63524 .35897 Mtetra
.355 .236 .577 r
.63524 .35897 .63946 .39514 .64538 .38338 .64214 .37541 Mtetra
.632 .576 .773 r
.64214 .37541 .64538 .38338 .65081 .36009 .64843 .37352 Mtetra
0 0 .118 r
.64843 .37352 .65081 .36009 .65788 .37773 .65409 .3561 Mtetra
.163 .139 .582 r
.65409 .3561 .65788 .37773 .66344 .35885 .66117 .37285 Mtetra
0 0 .12 r
.66117 .37285 .66344 .35885 .67013 .3657 .66675 .35405 Mtetra
.433 .396 .718 r
.66675 .35405 .67013 .3657 .67657 .36645 .67332 .35767 Mtetra
.217 .308 .743 r
.67332 .35767 .67657 .36645 .68236 .35329 .68005 .36375 Mtetra
0 0 0 r
.68005 .36375 .68236 .35329 .68923 .36193 .68562 .34603 Mtetra
.253 .235 .645 r
.68562 .34603 .68923 .36193 .69538 .35591 .69261 .35635 Mtetra
.223 .742 .746 r
.69261 .35635 .69538 .35591 .70155 .35026 .69903 .35476 Mtetra
.817 .859 .408 r
.69903 .35476 .70155 .35026 .70833 .35521 .70473 .3405 Mtetra
.182 .198 .641 r
.70473 .3405 .70833 .35521 .71452 .34954 .71192 .35185 Mtetra
0 0 0 r
.71192 .35185 .71452 .34954 .72087 .3465 .71832 .34934 Mtetra
.927 .911 .521 r
.71832 .34934 .72087 .3465 .72751 .34781 .72399 .33488 Mtetra
.189 .222 .665 r
.72399 .33488 .72751 .34781 .73389 .34482 .73121 .34483 Mtetra
.464 0 0 r
.73121 .34483 .73389 .34482 .74039 .34332 .73804 .34795 Mtetra
.861 .849 .388 r
.73804 .34795 .74039 .34332 .74684 .34089 .74351 .33095 Mtetra
.475 .45 .75 r
.74351 .33095 .74684 .34089 .75332 .33871 .7503 .33315 Mtetra
.63 .239 0 r
.7503 .33315 .75332 .33871 .76023 .34214 .75802 .34753 Mtetra
0 0 0 r
.75802 .34753 .76023 .34214 .76673 .33964 .76396 .33725 Mtetra
.972 .819 .632 r
.76396 .33725 .76673 .33964 .77267 .3298 .76937 .3204 Mtetra
0 .113 .645 r
.76937 .3204 .77267 .3298 .77967 .33345 .77697 .33157 Mtetra
.885 .462 .065 r
.77697 .33157 .77967 .33345 .78768 .34865 .7854 .35184 Mtetra
.598 .816 .417 r
.7854 .35184 .78768 .34865 .79421 .34545 .79148 .34302 Mtetra
.987 .778 .535 r
.79148 .34302 .79421 .34545 .79896 .32178 .79592 .31532 Mtetra
.709 .658 .798 r
.79592 .31532 .79896 .32178 .80522 .31577 .80238 .31155 Mtetra
.916 .544 .112 r
.80238 .31155 .80522 .31577 .81535 .35209 .8125 .34789 Mtetra
.938 .582 .175 r
.8125 .34789 .81535 .35209 .82764 .40955 .82413 .39862 Mtetra
0 0 .293 r
.82413 .39862 .82764 .40955 .83801 .44408 .83378 .4259 Mtetra
.717 .532 .639 r
.83378 .4259 .83801 .44408 .84413 .43347 .83986 .41496 Mtetra
.869 .622 .563 r
.83986 .41496 .84413 .43347 .84715 .39208 .84346 .37932 Mtetra
.922 .67 .54 r
.84346 .37932 .84715 .39208 .84962 .34688 .84659 .34045 Mtetra
.959 .729 .548 r
.84659 .34045 .84962 .34688 .85321 .3141 .85058 .3111 Mtetra
.976 .813 .615 r
.85058 .3111 .85321 .3141 .85825 .2959 .8557 .29347 Mtetra
.928 .883 .768 r
.8557 .29347 .85825 .2959 .8643 .28755 .86168 .28431 Mtetra
.793 .838 .886 r
.86168 .28431 .8643 .28755 .87086 .28384 .86816 .27966 Mtetra
.48 .642 .928 r
.2657 .47447 .26923 .47836 .27449 .47894 .27098 .47473 Mtetra
0 0 .512 r
.27098 .47473 .27449 .47894 .27943 .48406 .27589 .48021 Mtetra
.935 .565 .263 r
.27589 .48021 .27943 .48406 .28378 .49769 .28005 .49618 Mtetra
.931 .62 .429 r
.28005 .49618 .28378 .49769 .28736 .52295 .28323 .52681 Mtetra
.902 .608 .479 r
.28323 .52681 .28736 .52295 .29042 .55727 .28576 .56827 Mtetra
.846 .553 .492 r
.28576 .56827 .29042 .55727 .29388 .58752 .28899 .60177 Mtetra
.453 .148 .358 r
.28899 .60177 .29388 .58752 .29914 .59247 .29476 .59949 Mtetra
.983 .78 .553 r
.29476 .59949 .29914 .59247 .30684 .5599 .30352 .55173 Mtetra
.914 .683 .575 r
.30352 .55173 .30684 .5599 .3158 .506 .31308 .48929 Mtetra
.824 .61 .612 r
.31308 .48929 .3158 .506 .3236 .46834 .32037 .46019 Mtetra
.894 .545 .064 r
.32037 .46019 .3236 .46834 .32893 .47037 .32477 .47763 Mtetra
.842 .529 .458 r
.32477 .47763 .32893 .47037 .33306 .49361 .32893 .50031 Mtetra
.884 .915 .516 r
.32893 .50031 .33306 .49361 .33844 .4963 .33529 .4861 Mtetra
.865 .656 .618 r
.33529 .4861 .33844 .4963 .34533 .47183 .34238 .45846 Mtetra
.456 .382 .685 r
.34238 .45846 .34533 .47183 .35156 .45852 .34773 .46151 Mtetra
.854 .503 .386 r
.34773 .46151 .35156 .45852 .35641 .47179 .35247 .47691 Mtetra
.905 .941 .579 r
.35247 .47691 .35641 .47179 .36174 .47652 .35869 .46441 Mtetra
.795 .608 .649 r
.35869 .46441 .36174 .47652 .36821 .45816 .365 .44935 Mtetra
0 0 .419 r
.365 .44935 .36821 .45816 .37401 .45332 .37006 .46045 Mtetra
.51 .134 .263 r
.37006 .46045 .37401 .45332 .37905 .4658 .37565 .46093 Mtetra
.889 .717 .664 r
.37565 .46093 .37905 .4658 .38502 .45781 .38201 .44425 Mtetra
.332 .298 .67 r
.38201 .44425 .38502 .45781 .39118 .4449 .38738 .45012 Mtetra
.645 .248 .277 r
.38738 .45012 .39118 .4449 .3964 .45543 .39288 .4539 Mtetra
.937 .791 .674 r
.39288 .4539 .3964 .45543 .40216 .453 .39917 .4381 Mtetra
.353 .3 .659 r
.39917 .4381 .40216 .453 .40836 .43844 .40461 .44417 Mtetra
.562 .162 .242 r
.40461 .44417 .40836 .43844 .41368 .44882 .41024 .44592 Mtetra
.915 .764 .679 r
.41024 .44592 .41368 .44882 .41949 .44562 .41646 .43093 Mtetra
.119 .141 .608 r
.41646 .43093 .41949 .44562 .42563 .43209 .42184 .44133 Mtetra
.16 0 .15 r
.42184 .44133 .42563 .43209 .43096 .44566 .42777 .43544 Mtetra
.765 .607 .682 r
.42777 .43544 .43096 .44566 .43701 .43506 .43379 .42601 Mtetra
0 0 .318 r
.43379 .42601 .43701 .43506 .44294 .42829 .43919 .43972 Mtetra
0 0 0 r
.43919 .43972 .44294 .42829 .44838 .44255 .44542 .42222 Mtetra
.446 .334 .633 r
.44542 .42222 .44838 .44255 .45464 .42183 .45109 .42741 Mtetra
.444 .033 .164 r
.45109 .42741 .45464 .42183 .46016 .43578 .45692 .42713 Mtetra
.819 .65 .673 r
.45692 .42713 .46016 .43578 .46606 .43262 .463 .41449 Mtetra
0 0 .21 r
.463 .41449 .46606 .43262 .47223 .41344 .46835 .44235 Mtetra
0 0 .186 r
.46835 .44235 .47223 .41344 .47756 .44887 .47475 .41067 Mtetra
.392 .255 .573 r
.47475 .41067 .47756 .44887 .48393 .41371 .48043 .42412 Mtetra
.629 .29 .379 r
.48043 .42412 .48393 .41371 .48968 .42558 .48629 .42852 Mtetra
.995 .822 .559 r
.48629 .42852 .48968 .42558 .49555 .43167 .4925 .40143 Mtetra
0 0 .466 r
.4925 .40143 .49555 .43167 .5017 .40344 .49818 .42937 Mtetra
0 0 .136 r
.49818 .42937 .5017 .40344 .50748 .43061 .50437 .39756 Mtetra
.272 .176 .559 r
.50437 .39756 .50748 .43061 .51358 .39992 .51023 .41574 Mtetra
0 0 .171 r
.51023 .41574 .51358 .39992 .51951 .41732 .51627 .4 Mtetra
.487 .379 .657 r
.51627 .4 .51951 .41732 .52551 .40132 .52226 .40312 Mtetra
.442 .846 .658 r
.52226 .40312 .52551 .40132 .53152 .40583 .52827 .39926 Mtetra
.698 .637 .785 r
.52827 .39926 .53152 .40583 .53752 .3999 .53429 .39584 Mtetra
.583 .69 .915 r
.53429 .39584 .53752 .3999 .54355 .39899 .54033 .39499 Mtetra
.71 .74 .874 r
.54033 .39499 .54355 .39899 .54959 .39599 .54637 .39209 Mtetra
.701 .742 .884 r
.54637 .39209 .54959 .39599 .55565 .39479 .55242 .38941 Mtetra
.527 .599 .869 r
.55242 .38941 .55565 .39479 .5617 .39189 .55852 .38955 Mtetra
.82 .855 .873 r
.55852 .38955 .5617 .39189 .56779 .39078 .56457 .38458 Mtetra
.439 .519 .843 r
.56457 .38458 .56779 .39078 .57391 .39012 .57072 .38611 Mtetra
.722 .745 .87 r
.57072 .38611 .57391 .39012 .57996 .38447 .57682 .38295 Mtetra
.762 .911 .94 r
.57682 .38295 .57996 .38447 .58628 .3931 .58292 .37926 Mtetra
.289 .274 .669 r
.58292 .37926 .58628 .3931 .59209 .37492 .58925 .38689 Mtetra
0 0 0 r
.58925 .38689 .59209 .37492 .59881 .39888 .59507 .36859 Mtetra
.114 .074 .53 r
.59507 .36859 .59881 .39888 .60432 .36918 .60186 .39304 Mtetra
0 0 .184 r
.60186 .39304 .60432 .36918 .61119 .39368 .60735 .36293 Mtetra
.159 .106 .543 r
.60735 .36293 .61119 .39368 .61713 .38194 .61423 .38604 Mtetra
.701 .862 .451 r
.61423 .38604 .61713 .38194 .623 .3685 .62023 .37607 Mtetra
0 0 0 r
.62023 .37607 .623 .3685 .63025 .39826 .62606 .36108 Mtetra
.203 .127 .542 r
.62606 .36108 .63025 .39826 .63524 .35897 .63323 .38697 Mtetra
0 0 .274 r
.63323 .38697 .63524 .35897 .64214 .37541 .63851 .35636 Mtetra
.368 .292 .638 r
.63851 .35636 .64214 .37541 .64843 .37352 .64515 .3646 Mtetra
.679 .583 .741 r
.64515 .3646 .64843 .37352 .65409 .3561 .65138 .3609 Mtetra
0 0 0 r
.65138 .3609 .65409 .3561 .66117 .37285 .65741 .35237 Mtetra
.272 .22 .615 r
.65741 .35237 .66117 .37285 .66675 .35405 .66434 .36473 Mtetra
0 0 .003 r
.66434 .36473 .66675 .35405 .67332 .35767 .67002 .34807 Mtetra
.318 .356 .743 r
.67002 .34807 .67332 .35767 .68005 .36375 .67669 .35309 Mtetra
.508 .457 .735 r
.67669 .35309 .68005 .36375 .68562 .34603 .68322 .35455 Mtetra
0 0 0 r
.68322 .35455 .68562 .34603 .69261 .35635 .68902 .34118 Mtetra
.243 .235 .65 r
.68902 .34118 .69261 .35635 .69903 .35476 .69605 .35124 Mtetra
.821 .806 .836 r
.69605 .35124 .69903 .35476 .70473 .3405 .70226 .34557 Mtetra
0 0 0 r
.70226 .34557 .70473 .3405 .71192 .35185 .70826 .33636 Mtetra
.229 .224 .645 r
.70826 .33636 .71192 .35185 .71832 .34934 .71545 .34712 Mtetra
.897 .877 .807 r
.71545 .34712 .71832 .34934 .72399 .33488 .72157 .33945 Mtetra
0 0 0 r
.72157 .33945 .72399 .33488 .73121 .34483 .7276 .33057 Mtetra
.156 .186 .641 r
.7276 .33057 .73121 .34483 .73804 .34795 .73498 .3423 Mtetra
.756 .702 .8 r
.73498 .3423 .73804 .34795 .74351 .33095 .74129 .3374 Mtetra
0 0 0 r
.74129 .3374 .74351 .33095 .7503 .33315 .74698 .32356 Mtetra
0 .121 .648 r
.74698 .32356 .7503 .33315 .75802 .34753 .75444 .33446 Mtetra
.323 .311 .691 r
.75444 .33446 .75802 .34753 .76396 .33725 .76168 .34159 Mtetra
.901 .849 .396 r
.76168 .34159 .76396 .33725 .76937 .3204 .76697 .32263 Mtetra
0 0 0 r
.76697 .32263 .76937 .3204 .77697 .33157 .77326 .31705 Mtetra
0 0 .457 r
.77326 .31705 .77697 .33157 .7854 .35184 .78191 .34041 Mtetra
.217 .264 .697 r
.78191 .34041 .7854 .35184 .79148 .34302 .78944 .34893 Mtetra
.911 .797 .32 r
.78944 .34893 .79148 .34302 .79592 .31532 .79398 .32184 Mtetra
.748 .746 .229 r
.79398 .32184 .79592 .31532 .80238 .31155 .79907 .30201 Mtetra
.682 .368 0 r
.79907 .30201 .80238 .31155 .8125 .34789 .80833 .32916 Mtetra
.751 .484 0 r
.80833 .32916 .8125 .34789 .82413 .39862 .82071 .3887 Mtetra
.843 .512 0 r
.82071 .3887 .82413 .39862 .83378 .4259 .83187 .43227 Mtetra
.318 0 .136 r
.83187 .43227 .83378 .4259 .83986 .41496 .83878 .42948 Mtetra
0 0 0 r
.83878 .42948 .83986 .41496 .84346 .37932 .84216 .39078 Mtetra
.854 .7 .17 r
.84216 .39078 .84346 .37932 .84659 .34045 .84462 .34446 Mtetra
.97 .784 .353 r
.84462 .34446 .84659 .34045 .85058 .3111 .84805 .3093 Mtetra
.993 .824 .568 r
.84805 .3093 .85058 .3111 .8557 .29347 .85292 .28903 Mtetra
.891 .79 .743 r
.85292 .28903 .8557 .29347 .86168 .28431 .85887 .27936 Mtetra
.753 .736 .837 r
.85887 .27936 .86168 .28431 .86816 .27966 .86538 .27499 Mtetra
0 .32 .673 r
.26197 .4728 .2657 .47447 .27098 .47473 .26711 .47497 Mtetra
.838 .424 .252 r
.26711 .47497 .27098 .47473 .27589 .48021 .27176 .48379 Mtetra
.865 .54 .435 r
.27176 .48379 .27589 .48021 .28005 .49618 .27565 .50351 Mtetra
.865 .567 .482 r
.27565 .50351 .28005 .49618 .28323 .52681 .27875 .53504 Mtetra
.866 .571 .487 r
.27875 .53504 .28323 .52681 .28576 .56827 .28171 .57006 Mtetra
.882 .545 .406 r
.28171 .57006 .28576 .56827 .28899 .60177 .28593 .58914 Mtetra
.794 .607 .648 r
.28593 .58914 .28899 .60177 .29476 .59949 .29262 .57328 Mtetra
.826 .597 .592 r
.29262 .57328 .29476 .59949 .30352 .55173 .30138 .52582 Mtetra
.828 .598 .591 r
.30138 .52582 .30352 .55173 .31308 .48929 .31003 .47791 Mtetra
.811 .622 .647 r
.31003 .47791 .31308 .48929 .32037 .46019 .31657 .46117 Mtetra
.87 .499 .341 r
.31657 .46117 .32037 .46019 .32477 .47763 .3212 .47467 Mtetra
.895 .474 .144 r
.3212 .47467 .32477 .47763 .32893 .50031 .326 .48624 Mtetra
.745 .567 .654 r
.326 .48624 .32893 .50031 .33529 .4861 .33219 .47514 Mtetra
.811 .625 .65 r
.33219 .47514 .33529 .4861 .34238 .45846 .33864 .45913 Mtetra
.106 0 0 r
.33864 .45913 .34238 .45846 .34773 .46151 .34417 .45903 Mtetra
.628 .088 0 r
.34417 .45903 .34773 .46151 .35247 .47691 .34944 .46425 Mtetra
.681 .536 .682 r
.34944 .46425 .35247 .47691 .35869 .46441 .35529 .45903 Mtetra
.803 .697 .748 r
.35529 .45903 .35869 .46441 .365 .44935 .36123 .45179 Mtetra
.307 0 0 r
.36123 .45179 .365 .44935 .37006 .46045 .36684 .45154 Mtetra
.57 .515 .754 r
.36684 .45154 .37006 .46045 .37565 .46093 .37246 .45125 Mtetra
.676 .563 .72 r
.37246 .45125 .37565 .46093 .38201 .44425 .37825 .44747 Mtetra
0 0 0 r
.37825 .44747 .38201 .44425 .38738 .45012 .38405 .44389 Mtetra
.624 .608 .814 r
.38405 .44389 .38738 .45012 .39288 .4539 .38975 .44251 Mtetra
.574 .482 .712 r
.38975 .44251 .39288 .4539 .39917 .4381 .39544 .44208 Mtetra
0 0 0 r
.39544 .44208 .39917 .4381 .40461 .44417 .4013 .43748 Mtetra
.672 .617 .786 r
.4013 .43748 .40461 .44417 .41024 .44592 .40709 .43483 Mtetra
.484 .429 .72 r
.40709 .43483 .41024 .44592 .41646 .43093 .41273 .43678 Mtetra
0 0 0 r
.41273 .43678 .41646 .43093 .42184 .44133 .41868 .43017 Mtetra
.598 .5 .714 r
.41868 .43017 .42184 .44133 .42777 .43544 .42446 .42898 Mtetra
.347 .454 .827 r
.42446 .42898 .42777 .43544 .43379 .42601 .43014 .43153 Mtetra
.703 .858 .442 r
.43014 .43153 .43379 .42601 .43919 .43972 .4362 .4212 Mtetra
.44 .338 .643 r
.4362 .4212 .43919 .43972 .44542 .42222 .44186 .42609 Mtetra
.025 0 0 r
.44186 .42609 .44542 .42222 .45109 .42741 .44774 .42297 Mtetra
.807 .734 .784 r
.44774 .42297 .45109 .42741 .45692 .42713 .45371 .41673 Mtetra
0 .058 .6 r
.45371 .41673 .45692 .42713 .463 .41449 .45934 .42662 Mtetra
0 0 0 r
.45934 .42662 .463 .41449 .46835 .44235 .46557 .4068 Mtetra
.355 .231 .569 r
.46557 .4068 .46835 .44235 .47475 .41067 .47118 .42139 Mtetra
.39 .065 .289 r
.47118 .42139 .47475 .41067 .48043 .42412 .47713 .41836 Mtetra
.886 .711 .66 r
.47713 .41836 .48043 .42412 .48629 .42852 .48326 .4019 Mtetra
.019 .008 .5 r
.48326 .4019 .48629 .42852 .4925 .40143 .48891 .42459 Mtetra
0 0 .127 r
.48891 .42459 .4925 .40143 .49818 .42937 .49513 .3968 Mtetra
.298 .195 .565 r
.49513 .3968 .49818 .42937 .50437 .39756 .50095 .41331 Mtetra
.06 0 .229 r
.50095 .41331 .50437 .39756 .51023 .41574 .507 .40049 Mtetra
.568 .446 .674 r
.507 .40049 .51023 .41574 .51627 .4 .51299 .40015 Mtetra
.155 0 0 r
.51299 .40015 .51627 .4 .52226 .40312 .51899 .40072 Mtetra
.889 .83 .782 r
.51899 .40072 .52226 .40312 .52827 .39926 .52501 .39254 Mtetra
.253 .389 .807 r
.52501 .39254 .52827 .39926 .53429 .39584 .53105 .39633 Mtetra
.902 .978 .801 r
.53105 .39633 .53429 .39584 .54033 .39499 .53708 .38893 Mtetra
.467 .54 .848 r
.53708 .38893 .54033 .39499 .54637 .39209 .54315 .39003 Mtetra
.727 .866 .947 r
.54315 .39003 .54637 .39209 .55242 .38941 .54921 .38699 Mtetra
.748 .845 .924 r
.54921 .38699 .55242 .38941 .55852 .38955 .55528 .38361 Mtetra
.413 .515 .853 r
.55528 .38361 .55852 .38955 .56457 .38458 .56142 .38534 Mtetra
.869 .995 .799 r
.56142 .38534 .56457 .38458 .57072 .38611 .56747 .37844 Mtetra
.312 .395 .788 r
.56747 .37844 .57072 .38611 .57682 .38295 .57368 .38223 Mtetra
.839 .957 .889 r
.57368 .38223 .57682 .38295 .58292 .37926 .57977 .37695 Mtetra
.664 .839 .967 r
.57977 .37695 .58292 .37926 .58925 .38689 .58592 .37473 Mtetra
.297 .299 .693 r
.58592 .37473 .58925 .38689 .59507 .36859 .59226 .38125 Mtetra
0 0 .023 r
.59226 .38125 .59507 .36859 .60186 .39304 .59809 .36324 Mtetra
.172 .116 .548 r
.59809 .36324 .60186 .39304 .60735 .36293 .60486 .3849 Mtetra
0 0 .212 r
.60486 .3849 .60735 .36293 .61423 .38604 .61047 .35959 Mtetra
.346 .248 .599 r
.61047 .35959 .61423 .38604 .62023 .37607 .61709 .37182 Mtetra
.592 .69 .91 r
.61709 .37182 .62023 .37607 .62606 .36108 .62337 .37083 Mtetra
0 0 0 r
.62337 .37083 .62606 .36108 .63323 .38697 .6291 .35238 Mtetra
.344 .231 .578 r
.6291 .35238 .63323 .38697 .63851 .35636 .63598 .36854 Mtetra
0 0 .132 r
.63598 .36854 .63851 .35636 .64515 .3646 .64184 .35455 Mtetra
.494 .458 .746 r
.64184 .35455 .64515 .3646 .65138 .3609 .64827 .35621 Mtetra
.528 .638 .902 r
.64827 .35621 .65138 .3609 .65741 .35237 .65466 .35614 Mtetra
.692 .861 .455 r
.65466 .35614 .65741 .35237 .66434 .36473 .66066 .34644 Mtetra
.402 .32 .649 r
.66066 .34644 .66434 .36473 .67002 .34807 .66738 .35321 Mtetra
0 0 0 r
.66738 .35321 .67002 .34807 .67669 .35309 .67354 .34683 Mtetra
.709 .659 .799 r
.67354 .34683 .67669 .35309 .68322 .35455 .67982 .34315 Mtetra
.428 .398 .723 r
.67982 .34315 .68322 .35455 .68902 .34118 .68649 .34676 Mtetra
0 0 0 r
.68649 .34676 .68902 .34118 .69605 .35124 .69266 .34033 Mtetra
.617 .521 .722 r
.69266 .34033 .69605 .35124 .70226 .34557 .69908 .33839 Mtetra
.452 .498 .816 r
.69908 .33839 .70226 .34557 .70826 .33636 .70572 .34016 Mtetra
0 0 0 r
.70572 .34016 .70826 .33636 .71545 .34712 .71203 .33583 Mtetra
.647 .534 .712 r
.71203 .33583 .71545 .34712 .72157 .33945 .71842 .33263 Mtetra
.498 .537 .827 r
.71842 .33263 .72157 .33945 .7276 .33057 .72508 .33354 Mtetra
.289 0 0 r
.72508 .33354 .7276 .33057 .73498 .3423 .73166 .33276 Mtetra
.7 .587 .727 r
.73166 .33276 .73498 .3423 .74129 .3374 .73798 .32791 Mtetra
.639 .555 .744 r
.73798 .32791 .74129 .3374 .74698 .32356 .74447 .32546 Mtetra
.603 .074 0 r
.74447 .32546 .74698 .32356 .75444 .33446 .75143 .32924 Mtetra
.565 .635 .88 r
.75143 .32924 .75444 .33446 .76168 .34159 .7581 .32872 Mtetra
.742 .575 .668 r
.7581 .32872 .76168 .34159 .76697 .32263 .76413 .31933 Mtetra
.645 .779 .945 r
.76413 .31933 .76697 .32263 .77326 .31705 .77072 .31737 Mtetra
.83 .358 .054 r
.77072 .31737 .77326 .31705 .78191 .34041 .77847 .3296 Mtetra
.367 .371 .732 r
.77847 .3296 .78191 .34041 .78944 .34893 .78569 .33455 Mtetra
.802 .6 .628 r
.78569 .33455 .78944 .34893 .79398 .32184 .79114 .31799 Mtetra
.949 .791 .651 r
.79114 .31799 .79398 .32184 .79907 .30201 .79661 .30227 Mtetra
.858 .404 .083 r
.79661 .30227 .79907 .30201 .80833 .32916 .8048 .31743 Mtetra
.813 .5 0 r
.8048 .31743 .80833 .32916 .82071 .3887 .81577 .36214 Mtetra
0 0 .417 r
.81577 .36214 .82071 .3887 .83187 .43227 .82676 .40463 Mtetra
.412 .3 .616 r
.82676 .40463 .83187 .43227 .83878 .42948 .83488 .41496 Mtetra
.854 .63 .598 r
.83488 .41496 .83878 .42948 .84216 .39078 .8397 .39082 Mtetra
.997 .77 .435 r
.8397 .39082 .84216 .39078 .84462 .34446 .84291 .35137 Mtetra
.91 .756 .264 r
.84291 .35137 .84462 .34446 .84805 .3093 .84635 .31571 Mtetra
.803 .747 .226 r
.84635 .31571 .84805 .3093 .85292 .28903 .8509 .29187 Mtetra
.816 .872 .433 r
.8509 .29187 .85292 .28903 .85887 .27936 .85653 .27889 Mtetra
.843 .996 .834 r
.85653 .27889 .85887 .27936 .86538 .27499 .86285 .27255 Mtetra
.203 .499 .905 r
.25841 .46887 .26197 .4728 .26711 .47497 .26356 .47085 Mtetra
.778 .313 0 r
.26356 .47085 .26711 .47497 .27176 .48379 .26827 .47884 Mtetra
.947 .589 .268 r
.26827 .47884 .27176 .48379 .27565 .50351 .27226 .49691 Mtetra
.965 .649 .363 r
.27226 .49691 .27565 .50351 .27875 .53504 .27546 .52664 Mtetra
.972 .665 .366 r
.27546 .52664 .27875 .53504 .28171 .57006 .27839 .56145 Mtetra
.948 .612 .2 r
.27839 .56145 .28171 .57006 .28593 .58914 .28239 .58334 Mtetra
.841 .695 .7 r
.28239 .58334 .28593 .58914 .29262 .57328 .2888 .57161 Mtetra
.939 .722 .582 r
.2888 .57161 .29262 .57328 .30138 .52582 .29756 .52516 Mtetra
.945 .725 .573 r
.29756 .52516 .30138 .52582 .31003 .47791 .30649 .47397 Mtetra
.901 .726 .655 r
.30649 .47397 .31003 .47791 .31657 .46117 .31319 .45514 Mtetra
.939 .575 .192 r
.31319 .45514 .31657 .46117 .3212 .47467 .31752 .47303 Mtetra
.918 .553 .32 r
.31752 .47303 .3212 .47467 .326 .48624 .32199 .49012 Mtetra
.979 .916 .642 r
.32199 .49012 .326 .48624 .33219 .47514 .32844 .47515 Mtetra
.955 .78 .625 r
.32844 .47515 .33219 .47514 .33864 .45913 .33535 .4515 Mtetra
.297 .382 .781 r
.33535 .4515 .33864 .45913 .34417 .45903 .34069 .45498 Mtetra
.908 .501 .131 r
.34069 .45498 .34417 .45903 .34944 .46425 .34551 .46836 Mtetra
.914 .96 .635 r
.34551 .46836 .34944 .46425 .35529 .45903 .35169 .45724 Mtetra
.926 .787 .688 r
.35169 .45724 .35529 .45903 .36123 .45179 .35802 .4427 Mtetra
0 0 .571 r
.35802 .4427 .36123 .45179 .36684 .45154 .36316 .45173 Mtetra
.499 0 0 r
.36316 .45173 .36684 .45154 .37246 .45125 .36867 .45407 Mtetra
.984 .893 .646 r
.36867 .45407 .37246 .45125 .37825 .44747 .37503 .43839 Mtetra
.44 .434 .756 r
.37503 .43839 .37825 .44747 .38405 .44389 .38057 .44066 Mtetra
.636 .127 0 r
.38057 .44066 .38405 .44389 .38975 .44251 .38596 .44694 Mtetra
.955 .935 .604 r
.38596 .44694 .38975 .44251 .39544 .44208 .39221 .43293 Mtetra
.52 .482 .755 r
.39221 .43293 .39544 .44208 .4013 .43748 .39786 .43377 Mtetra
0 0 .498 r
.39786 .43377 .4013 .43748 .40709 .43483 .40335 .43955 Mtetra
.941 .933 .583 r
.40335 .43955 .40709 .43483 .41273 .43678 .40957 .42557 Mtetra
.375 .358 .712 r
.40957 .42557 .41273 .43678 .41868 .43017 .41516 .4297 Mtetra
.258 0 0 r
.41516 .4297 .41868 .43017 .42446 .42898 .42086 .43118 Mtetra
.975 .919 .67 r
.42086 .43118 .42446 .42898 .43014 .43153 .42703 .41804 Mtetra
.084 .131 .613 r
.42703 .41804 .43014 .43153 .4362 .4212 .43252 .42813 Mtetra
0 0 0 r
.43252 .42813 .4362 .4212 .44186 .42609 .43853 .42015 Mtetra
.764 .677 .767 r
.43853 .42015 .44186 .42609 .44774 .42297 .44448 .41462 Mtetra
0 .143 .67 r
.44448 .41462 .44774 .42297 .45371 .41673 .45013 .42204 Mtetra
.939 .914 .535 r
.45013 .42204 .45371 .41673 .45934 .42662 .45632 .40622 Mtetra
.045 .049 .538 r
.45632 .40622 .45934 .42662 .46557 .4068 .46185 .42267 Mtetra
.12 0 .249 r
.46185 .42267 .46557 .4068 .47118 .42139 .46794 .41131 Mtetra
.739 .595 .696 r
.46794 .41131 .47118 .42139 .47713 .41836 .47395 .40398 Mtetra
0 0 .468 r
.47395 .40398 .47713 .41836 .48326 .4019 .47963 .42015 Mtetra
0 0 0 r
.47963 .42015 .48326 .4019 .48891 .42459 .48589 .39442 Mtetra
.245 .161 .558 r
.48589 .39442 .48891 .42459 .49513 .3968 .49164 .41183 Mtetra
0 0 .147 r
.49164 .41183 .49513 .3968 .50095 .41331 .49774 .39681 Mtetra
.515 .403 .664 r
.49774 .39681 .50095 .41331 .507 .40049 .5037 .39864 Mtetra
.468 .797 .999 r
.5037 .39864 .507 .40049 .51299 .40015 .50969 .39794 Mtetra
.885 .841 .796 r
.50969 .39794 .51299 .40015 .51899 .40072 .51573 .39026 Mtetra
.367 .367 .728 r
.51573 .39026 .51899 .40072 .52501 .39254 .52174 .39444 Mtetra
.877 .986 .715 r
.52174 .39444 .52501 .39254 .53105 .39633 .52778 .38613 Mtetra
.453 .426 .739 r
.52778 .38613 .53105 .39633 .53708 .38893 .53384 .38862 Mtetra
.809 .976 .899 r
.53384 .38862 .53708 .38893 .54315 .39003 .53989 .38378 Mtetra
.625 .615 .821 r
.53989 .38378 .54315 .39003 .54921 .38699 .54597 .3823 Mtetra
.548 .644 .897 r
.54597 .3823 .54921 .38699 .55528 .38361 .55208 .382 Mtetra
.855 .897 .865 r
.55208 .382 .55528 .38361 .56142 .38534 .55815 .37627 Mtetra
.363 .392 .758 r
.55815 .37627 .56142 .38534 .56747 .37844 .56433 .38 Mtetra
.883 .987 .725 r
.56433 .38 .56747 .37844 .57368 .38223 .57038 .37173 Mtetra
.371 .371 .73 r
.57038 .37173 .57368 .38223 .57977 .37695 .57662 .37598 Mtetra
.811 .948 .912 r
.57662 .37598 .57977 .37695 .58592 .37473 .58274 .3713 Mtetra
.767 .79 .872 r
.58274 .3713 .58592 .37473 .59226 .38125 .58888 .36727 Mtetra
.23 .233 .656 r
.58888 .36727 .59226 .38125 .59809 .36324 .5953 .37619 Mtetra
0 0 0 r
.5953 .37619 .59809 .36324 .60486 .3849 .6011 .35645 Mtetra
.165 .115 .551 r
.6011 .35645 .60486 .3849 .61047 .35959 .60789 .37737 Mtetra
0 0 .182 r
.60789 .37737 .61047 .35959 .61709 .37182 .61364 .35687 Mtetra
.432 .361 .677 r
.61364 .35687 .61709 .37182 .62337 .37083 .62007 .36135 Mtetra
.23 .301 .73 r
.62007 .36135 .62337 .37083 .6291 .35238 .62659 .36745 Mtetra
0 0 .117 r
.62659 .36745 .6291 .35238 .63598 .36854 .63229 .34776 Mtetra
.293 .232 .615 r
.63229 .34776 .63598 .36854 .64184 .35455 .63905 .35931 Mtetra
.706 .833 .392 r
.63905 .35931 .64184 .35455 .64827 .35621 .645 .34773 Mtetra
.456 .465 .78 r
.645 .34773 .64827 .35621 .65466 .35614 .65148 .34978 Mtetra
.315 .444 .833 r
.65148 .34978 .65466 .35614 .66066 .34644 .65803 .35293 Mtetra
0 0 0 r
.65803 .35293 .66066 .34644 .66738 .35321 .66388 .33935 Mtetra
.235 .241 .662 r
.66388 .33935 .66738 .35321 .67354 .34683 .67074 .34849 Mtetra
.679 .947 .682 r
.67074 .34849 .67354 .34683 .67982 .34315 .67694 .34237 Mtetra
.906 .95 .818 r
.67694 .34237 .67982 .34315 .68649 .34676 .68306 .33497 Mtetra
.14 .203 .668 r
.68306 .33497 .68649 .34676 .69266 .34033 .69007 .34456 Mtetra
.634 .808 .379 r
.69007 .34456 .69266 .34033 .69908 .33839 .69606 .33434 Mtetra
.756 .767 .862 r
.69606 .33434 .69908 .33839 .70572 .34016 .70238 .33029 Mtetra
.047 .172 .673 r
.70238 .33029 .70572 .34016 .71203 .33583 .7095 .33981 Mtetra
.691 .837 .407 r
.7095 .33981 .71203 .33583 .71842 .33263 .71546 .32904 Mtetra
.812 .805 .844 r
.71546 .32904 .71842 .33263 .72508 .33354 .72174 .32363 Mtetra
0 .094 .63 r
.72174 .32363 .72508 .33354 .73166 .33276 .7291 .33506 Mtetra
.647 .896 .564 r
.7291 .33506 .73166 .33276 .73798 .32791 .73529 .32781 Mtetra
.974 .92 .675 r
.73529 .32781 .73798 .32791 .74447 .32546 .74112 .31553 Mtetra
0 .118 .644 r
.74112 .31553 .74447 .32546 .75143 .32924 .74859 .32664 Mtetra
0 .095 .578 r
.74859 .32664 .75143 .32924 .7581 .32872 .75576 .33261 Mtetra
.909 .865 .425 r
.75576 .33261 .7581 .32872 .76413 .31933 .76118 .31477 Mtetra
.813 .765 .807 r
.76118 .31477 .76413 .31933 .77072 .31737 .76745 .30863 Mtetra
0 0 .326 r
.76745 .30863 .77072 .31737 .77847 .3296 .77583 .3289 Mtetra
.758 .245 0 r
.77583 .3289 .77847 .3296 .78569 .33455 .78344 .33843 Mtetra
.945 .842 .407 r
.78344 .33843 .78569 .33455 .79114 .31799 .78845 .31609 Mtetra
.989 .814 .577 r
.78845 .31609 .79114 .31799 .79661 .30227 .7935 .2952 Mtetra
0 0 .361 r
.7935 .2952 .79661 .30227 .8048 .31743 .80186 .31237 Mtetra
.931 .576 .152 r
.80186 .31237 .8048 .31743 .81577 .36214 .81318 .36122 Mtetra
.938 .566 .208 r
.81318 .36122 .81577 .36214 .82676 .40463 .82414 .40356 Mtetra
.57 .006 0 r
.82414 .40356 .82676 .40463 .83488 .41496 .83189 .40983 Mtetra
.968 .75 .556 r
.83189 .40983 .83488 .41496 .8397 .39082 .8364 .3823 Mtetra
.956 .706 .518 r
.8364 .3823 .8397 .39082 .84291 .35137 .8396 .34242 Mtetra
.944 .701 .539 r
.8396 .34242 .84291 .35137 .84635 .31571 .84321 .3082 Mtetra
.928 .716 .596 r
.84321 .3082 .84635 .31571 .8509 .29187 .84795 .28593 Mtetra
.888 .742 .695 r
.84795 .28593 .8509 .29187 .85653 .27889 .85368 .27382 Mtetra
.804 .751 .803 r
.85368 .27382 .85653 .27889 .86285 .27255 .86004 .26774 Mtetra
0 .287 .73 r
.25474 .4661 .25841 .46887 .26356 .47085 .25982 .46901 Mtetra
.884 .465 .201 r
.25982 .46901 .26356 .47085 .26827 .47884 .26434 .47935 Mtetra
.904 .576 .415 r
.26434 .47935 .26827 .47884 .27226 .49691 .26801 .50141 Mtetra
.889 .589 .473 r
.26801 .50141 .27226 .49691 .27546 .52664 .27088 .53518 Mtetra
.864 .569 .487 r
.27088 .53518 .27546 .52664 .27839 .56145 .27379 .57022 Mtetra
.783 .461 .444 r
.27379 .57022 .27839 .56145 .28239 .58334 .2783 .58484 Mtetra
.965 .799 .627 r
.2783 .58484 .28239 .58334 .2888 .57161 .2856 .56102 Mtetra
.898 .67 .585 r
.2856 .56102 .2888 .57161 .29756 .52516 .29485 .50807 Mtetra
.859 .632 .594 r
.29485 .50807 .29756 .52516 .30649 .47397 .30342 .46294 Mtetra
.729 .578 .685 r
.30342 .46294 .30649 .47397 .31319 .45514 .30938 .45555 Mtetra
.902 .558 .385 r
.30938 .45555 .31319 .45514 .31752 .47303 .31359 .47512 Mtetra
.768 .345 .246 r
.31359 .47512 .31752 .47303 .32199 .49012 .3187 .48191 Mtetra
.855 .666 .647 r
.3187 .48191 .32199 .49012 .32844 .47515 .3254 .46294 Mtetra
.785 .602 .653 r
.3254 .46294 .32844 .47515 .33535 .4515 .33176 .44909 Mtetra
.801 .311 0 r
.33176 .44909 .33535 .4515 .34069 .45498 .33686 .45664 Mtetra
.64 .146 .061 r
.33686 .45664 .34069 .45498 .34551 .46836 .34224 .46 Mtetra
.815 .649 .678 r
.34224 .46 .34551 .46836 .35169 .45724 .34849 .44771 Mtetra
.679 .567 .722 r
.34849 .44771 .35169 .45724 .35802 .4427 .35428 .44386 Mtetra
.731 .256 .121 r
.35428 .44386 .35802 .4427 .36316 .45173 .35961 .4491 Mtetra
.842 .807 .817 r
.35961 .4491 .36316 .45173 .36867 .45407 .36554 .44291 Mtetra
.703 .562 .693 r
.36554 .44291 .36867 .45407 .37503 .43839 .37145 .4371 Mtetra
.517 0 0 r
.37145 .4371 .37503 .43839 .38057 .44066 .37693 .44059 Mtetra
.826 .967 .894 r
.37693 .44059 .38057 .44066 .38596 .44694 .38281 .43567 Mtetra
.678 .547 .698 r
.38281 .43567 .38596 .44694 .39221 .43293 .38868 .43118 Mtetra
0 .271 .643 r
.38868 .43118 .39221 .43293 .39786 .43377 .39426 .43389 Mtetra
.879 .96 .849 r
.39426 .43389 .39786 .43377 .40335 .43955 .40021 .42765 Mtetra
.606 .496 .703 r
.40021 .42765 .40335 .43955 .40957 .42557 .40599 .42606 Mtetra
.337 0 0 r
.40599 .42606 .40957 .42557 .41516 .4297 .41169 .42724 Mtetra
.873 .815 .789 r
.41169 .42724 .41516 .4297 .42086 .43118 .4177 .41961 Mtetra
.443 .397 .712 r
.4177 .41961 .42086 .43118 .42703 .41804 .42337 .42253 Mtetra
0 0 0 r
.42337 .42253 .42703 .41804 .43252 .42813 .42928 .41838 Mtetra
.696 .575 .716 r
.42928 .41838 .43252 .42813 .43853 .42015 .43521 .41365 Mtetra
.124 .316 .785 r
.43521 .41365 .43853 .42015 .44448 .41462 .44091 .41817 Mtetra
.837 .957 .617 r
.44091 .41817 .44448 .41462 .45013 .42204 .44697 .4088 Mtetra
.34 .31 .679 r
.44697 .4088 .45013 .42204 .45632 .40622 .45269 .41448 Mtetra
0 0 0 r
.45269 .41448 .45632 .40622 .46185 .42267 .45874 .40607 Mtetra
.602 .46 .661 r
.45874 .40607 .46185 .42267 .46794 .41131 .46465 .40398 Mtetra
0 0 .56 r
.46465 .40398 .46794 .41131 .47395 .40398 .4704 .41288 Mtetra
.827 .83 .356 r
.4704 .41288 .47395 .40398 .47963 .42015 .47661 .39374 Mtetra
.233 .162 .567 r
.47661 .39374 .47963 .42015 .48589 .39442 .48232 .40927 Mtetra
0 0 .152 r
.48232 .40927 .48589 .39442 .49164 .41183 .48845 .39497 Mtetra
.502 .392 .661 r
.48845 .39497 .49164 .41183 .49774 .39681 .49439 .39729 Mtetra
.073 0 0 r
.49439 .39729 .49774 .39681 .5037 .39864 .50037 .3972 Mtetra
.917 .866 .774 r
.50037 .3972 .5037 .39864 .50969 .39794 .50642 .38828 Mtetra
.196 .271 .715 r
.50642 .38828 .50969 .39794 .51573 .39026 .51241 .39451 Mtetra
.808 .916 .525 r
.51241 .39451 .51573 .39026 .52174 .39444 .51847 .38374 Mtetra
.319 .333 .718 r
.51847 .38374 .52174 .39444 .52778 .38613 .52451 .38884 Mtetra
.764 .954 .638 r
.52451 .38884 .52778 .38613 .53384 .38862 .53057 .38116 Mtetra
.474 .499 .803 r
.53057 .38116 .53384 .38862 .53989 .38378 .53665 .38252 Mtetra
.738 .924 .953 r
.53665 .38252 .53989 .38378 .54597 .3823 .54273 .37911 Mtetra
.712 .79 .912 r
.54273 .37911 .54597 .3823 .55208 .382 .54882 .37628 Mtetra
.458 .552 .863 r
.54882 .37628 .55208 .382 .55815 .37627 .55497 .37735 Mtetra
.857 .997 .779 r
.55497 .37735 .55815 .37627 .56433 .38 .56104 .37032 Mtetra
.301 .341 .737 r
.56104 .37032 .56433 .38 .57038 .37173 .56727 .37529 Mtetra
.756 .913 .537 r
.56727 .37529 .57038 .37173 .57662 .37598 .57332 .36596 Mtetra
.334 .356 .735 r
.57332 .36596 .57662 .37598 .58274 .3713 .5796 .37061 Mtetra
.805 .964 .91 r
.5796 .37061 .58274 .3713 .58888 .36727 .58574 .36591 Mtetra
.825 .925 .9 r
.58574 .36591 .58888 .36727 .5953 .37619 .59188 .36098 Mtetra
.285 .26 .654 r
.59188 .36098 .5953 .37619 .6011 .35645 .59833 .36939 Mtetra
0 0 .045 r
.59833 .36939 .6011 .35645 .60789 .37737 .60418 .35162 Mtetra
.297 .215 .592 r
.60418 .35162 .60789 .37737 .61364 .35687 .61083 .36546 Mtetra
0 0 0 r
.61083 .36546 .61364 .35687 .62007 .36135 .61681 .35335 Mtetra
.646 .583 .77 r
.61681 .35335 .62007 .36135 .62659 .36745 .62306 .35103 Mtetra
.44 .356 .665 r
.62306 .35103 .62659 .36745 .63229 .34776 .62956 .35568 Mtetra
0 0 0 r
.62956 .35568 .63229 .34776 .63905 .35931 .63561 .34614 Mtetra
.412 .365 .696 r
.63561 .34614 .63905 .35931 .645 .34773 .64216 .35062 Mtetra
.641 .882 .536 r
.64216 .35062 .645 .34773 .65148 .34978 .64828 .34312 Mtetra
.557 .574 .826 r
.64828 .34312 .65148 .34978 .65803 .35293 .65469 .34293 Mtetra
.542 .489 .746 r
.65469 .34293 .65803 .35293 .66388 .33935 .66115 .34334 Mtetra
0 0 0 r
.66115 .34334 .66388 .33935 .67074 .34849 .66733 .33681 Mtetra
.471 .421 .72 r
.66733 .33681 .67074 .34849 .67694 .34237 .67392 .33936 Mtetra
.781 .83 .891 r
.67392 .33936 .67694 .34237 .68306 .33497 .68022 .33511 Mtetra
.483 .9 .866 r
.68022 .33511 .68306 .33497 .69007 .34456 .68661 .33241 Mtetra
.514 .443 .714 r
.68661 .33241 .69007 .34456 .69606 .33434 .69322 .33384 Mtetra
.835 .984 .873 r
.69322 .33384 .69606 .33434 .70238 .33029 .69948 .32821 Mtetra
.37 .738 .99 r
.69948 .32821 .70238 .33029 .7095 .33981 .70605 .32818 Mtetra
.555 .475 .72 r
.70605 .32818 .7095 .33981 .71546 .32904 .71266 .32829 Mtetra
.87 .971 .854 r
.71266 .32829 .71546 .32904 .72174 .32363 .7189 .32196 Mtetra
.041 .55 .875 r
.7189 .32196 .72174 .32363 .7291 .33506 .72563 .32348 Mtetra
.528 .46 .723 r
.72563 .32348 .7291 .33506 .73529 .32781 .73236 .32445 Mtetra
.886 .823 .781 r
.73236 .32445 .73529 .32781 .74112 .31553 .73849 .31614 Mtetra
.2 0 0 r
.73849 .31614 .74112 .31553 .74859 .32664 .74523 .31669 Mtetra
.235 .299 .726 r
.74523 .31669 .74859 .32664 .75576 .33261 .75244 .32352 Mtetra
.766 .63 .71 r
.75244 .32352 .75576 .33261 .76118 .31477 .75862 .31564 Mtetra
.92 .97 .678 r
.75862 .31564 .76118 .31477 .76745 .30863 .76463 .30566 Mtetra
.664 .183 0 r
.76463 .30566 .76745 .30863 .77583 .3289 .77222 .31602 Mtetra
.04 .125 .626 r
.77222 .31602 .77583 .3289 .78344 .33843 .78012 .32928 Mtetra
.824 .658 .677 r
.78012 .32928 .78344 .33843 .78845 .31609 .786 .31725 Mtetra
.996 .845 .502 r
.786 .31725 .78845 .31609 .7935 .2952 .79096 .2948 Mtetra
.596 .024 0 r
.79096 .2948 .7935 .2952 .80186 .31237 .79829 .30032 Mtetra
.788 .48 0 r
.79829 .30032 .80186 .31237 .81318 .36122 .80898 .34259 Mtetra
0 0 .196 r
.80898 .34259 .81318 .36122 .82414 .40356 .82046 .39123 Mtetra
0 0 .532 r
.82046 .39123 .82414 .40356 .83189 .40983 .82937 .40992 Mtetra
.996 .861 .548 r
.82937 .40992 .83189 .40983 .8364 .3823 .83468 .3902 Mtetra
.911 .748 .255 r
.83468 .3902 .8364 .3823 .8396 .34242 .83796 .35046 Mtetra
.895 .742 .238 r
.83796 .35046 .8396 .34242 .84321 .3082 .84124 .31228 Mtetra
.94 .809 .353 r
.84124 .31228 .84321 .3082 .84795 .28593 .8456 .28594 Mtetra
.983 .906 .6 r
.8456 .28594 .84795 .28593 .85368 .27382 .8511 .27135 Mtetra
.887 .895 .83 r
.8511 .27135 .85368 .27382 .86004 .26774 .85737 .26423 Mtetra
0 .171 .62 r
.25105 .46335 .25474 .4661 .25982 .46901 .25609 .46681 Mtetra
.887 .467 .186 r
.25609 .46681 .25982 .46901 .26434 .47935 .26059 .47726 Mtetra
.929 .589 .371 r
.26059 .47726 .26434 .47935 .26801 .50141 .26434 .49804 Mtetra
.945 .63 .41 r
.26434 .49804 .26801 .50141 .27088 .53518 .26743 .52854 Mtetra
.965 .649 .366 r
.26743 .52854 .27088 .53518 .27379 .57022 .27062 .55927 Mtetra
0 0 .388 r
.27062 .55927 .27379 .57022 .2783 .58484 .27527 .57172 Mtetra
.818 .619 .633 r
.27527 .57172 .2783 .58484 .2856 .56102 .28239 .55063 Mtetra
.894 .669 .591 r
.28239 .55063 .2856 .56102 .29485 .50807 .2913 .50328 Mtetra
.921 .703 .591 r
.2913 .50328 .29485 .50807 .30342 .46294 .29973 .46094 Mtetra
.894 .804 .753 r
.29973 .46094 .30342 .46294 .30938 .45555 .30584 .45141 Mtetra
.939 .571 .258 r
.30584 .45141 .30938 .45555 .31359 .47512 .31018 .46894 Mtetra
.685 .286 0 r
.31018 .46894 .31359 .47512 .3187 .48191 .31509 .47862 Mtetra
.905 .745 .674 r
.31509 .47862 .3187 .48191 .3254 .46294 .32164 .4625 Mtetra
.948 .801 .665 r
.32164 .4625 .3254 .46294 .33176 .44909 .32823 .44532 Mtetra
0 .096 .609 r
.32823 .44532 .33176 .44909 .33686 .45664 .33349 .45006 Mtetra
0 0 .505 r
.33349 .45006 .33686 .45664 .34224 .46 .3386 .45801 Mtetra
.904 .805 .739 r
.3386 .45801 .34224 .46 .34849 .44771 .34477 .44754 Mtetra
.934 .88 .758 r
.34477 .44754 .34849 .44771 .35428 .44386 .35089 .43776 Mtetra
0 .098 .655 r
.35089 .43776 .35428 .44386 .35961 .4491 .35617 .44392 Mtetra
.547 .613 .87 r
.35617 .44392 .35961 .4491 .36554 .44291 .36181 .44374 Mtetra
.956 .902 .73 r
.36181 .44374 .36554 .44291 .37145 .4371 .36799 .43268 Mtetra
.412 .587 .913 r
.36799 .43268 .37145 .4371 .37693 .44059 .37359 .43366 Mtetra
.316 .419 .809 r
.37359 .43366 .37693 .44059 .38281 .43567 .37913 .43662 Mtetra
.943 .936 .758 r
.37913 .43662 .38281 .43567 .38868 .43118 .38522 .42721 Mtetra
.578 .69 .917 r
.38522 .42721 .38868 .43118 .39426 .43389 .39095 .42644 Mtetra
.345 .42 .795 r
.39095 .42644 .39426 .43389 .40021 .42765 .39654 .42937 Mtetra
.927 .972 .748 r
.39654 .42937 .40021 .42765 .40599 .42606 .40261 .4205 Mtetra
.507 .579 .862 r
.40261 .4205 .40599 .42606 .41169 .42724 .40834 .42091 Mtetra
.463 .526 .837 r
.40834 .42091 .41169 .42724 .4177 .41961 .41406 .42205 Mtetra
.897 .983 .711 r
.41406 .42205 .4177 .41961 .42337 .42253 .42012 .41323 Mtetra
.356 .38 .748 r
.42012 .41323 .42337 .42253 .42928 .41838 .4258 .41686 Mtetra
.734 .894 .952 r
.4258 .41686 .42928 .41838 .43521 .41365 .4317 .41374 Mtetra
.874 .967 .852 r
.4317 .41374 .43521 .41365 .44091 .41817 .43769 .40756 Mtetra
.35 .353 .722 r
.43769 .40756 .44091 .41817 .44697 .4088 .44341 .41187 Mtetra
.883 .97 .655 r
.44341 .41187 .44697 .4088 .45269 .41448 .4495 .40225 Mtetra
.348 .328 .695 r
.4495 .40225 .45269 .41448 .45874 .40607 .45525 .40732 Mtetra
.252 .748 .671 r
.45525 .40732 .45874 .40607 .46465 .40398 .46119 .40513 Mtetra
.949 .948 .735 r
.46119 .40513 .46465 .40398 .4704 .41288 .46727 .39519 Mtetra
.224 .193 .612 r
.46727 .39519 .4704 .41288 .47661 .39374 .47301 .40573 Mtetra
0 0 .008 r
.47301 .40573 .47661 .39374 .48232 .40927 .47917 .39152 Mtetra
.424 .333 .648 r
.47917 .39152 .48232 .40927 .48845 .39497 .48505 .39671 Mtetra
.504 .886 .7 r
.48505 .39671 .48845 .39497 .49439 .39729 .49106 .39266 Mtetra
.775 .728 .809 r
.49106 .39266 .49439 .39729 .50037 .3972 .49709 .38769 Mtetra
.399 .405 .75 r
.49709 .38769 .50037 .3972 .50642 .38828 .50307 .39088 Mtetra
.834 .973 .665 r
.50307 .39088 .50642 .38828 .51241 .39451 .50914 .38247 Mtetra
.418 .378 .707 r
.50914 .38247 .51241 .39451 .51847 .38374 .51516 .38617 Mtetra
.737 .958 .666 r
.51516 .38617 .51847 .38374 .52451 .38884 .52122 .37928 Mtetra
.5 .467 .752 r
.52122 .37928 .52451 .38884 .53057 .38116 .52729 .3806 Mtetra
.764 .965 .93 r
.52729 .3806 .53057 .38116 .53665 .38252 .53337 .37654 Mtetra
.625 .625 .831 r
.53337 .37654 .53665 .38252 .54273 .37911 .53947 .37506 Mtetra
.602 .703 .915 r
.53947 .37506 .54273 .37911 .54882 .37628 .54558 .37391 Mtetra
.794 .855 .896 r
.54558 .37391 .54882 .37628 .55497 .37735 .55169 .36957 Mtetra
.449 .477 .796 r
.55169 .36957 .55497 .37735 .56104 .37032 .55786 .37141 Mtetra
.854 .997 .778 r
.55786 .37141 .56104 .37032 .56727 .37529 .56396 .3644 Mtetra
.396 .382 .726 r
.56396 .3644 .56727 .37529 .57332 .36596 .5702 .36825 Mtetra
.742 .956 .658 r
.5702 .36825 .57332 .36596 .5796 .37061 .5763 .36112 Mtetra
.509 .475 .755 r
.5763 .36112 .5796 .37061 .58574 .36591 .58255 .36225 Mtetra
.539 .703 .946 r
.58255 .36225 .58574 .36591 .59188 .36098 .58878 .36175 Mtetra
.922 .975 .752 r
.58878 .36175 .59188 .36098 .59833 .36939 .59486 .35304 Mtetra
.25 .227 .637 r
.59486 .35304 .59833 .36939 .60418 .35162 .60138 .36293 Mtetra
0 0 .039 r
.60138 .36293 .60418 .35162 .61083 .36546 .60731 .34813 Mtetra
.391 .316 .652 r
.60731 .34813 .61083 .36546 .61681 .35335 .6138 .35461 Mtetra
0 0 0 r
.6138 .35461 .61681 .35335 .62306 .35103 .62007 .3521 Mtetra
.913 .98 .728 r
.62007 .3521 .62306 .35103 .62956 .35568 .62615 .3432 Mtetra
.345 .329 .698 r
.62615 .3432 .62956 .35568 .63561 .34614 .63271 .34893 Mtetra
.769 .932 .577 r
.63271 .34893 .63561 .34614 .64216 .35062 .6388 .34009 Mtetra
.449 .423 .738 r
.6388 .34009 .64216 .35062 .64828 .34312 .64531 .34281 Mtetra
.362 .829 .898 r
.64531 .34281 .64828 .34312 .65469 .34293 .65169 .34132 Mtetra
.903 .903 .814 r
.65169 .34132 .65469 .34293 .66115 .34334 .65783 .33373 Mtetra
.301 .346 .742 r
.65783 .33373 .66115 .34334 .66733 .33681 .66452 .33891 Mtetra
.592 .895 .611 r
.66452 .33891 .66733 .33681 .67392 .33936 .67074 .33293 Mtetra
.713 .658 .794 r
.67074 .33293 .67392 .33936 .68022 .33511 .67706 .32904 Mtetra
.133 .343 .805 r
.67706 .32904 .68022 .33511 .68661 .33241 .68383 .33389 Mtetra
.815 .98 .695 r
.68383 .33389 .68661 .33241 .69322 .33384 .68999 .32616 Mtetra
.653 .598 .78 r
.68999 .32616 .69322 .33384 .69948 .32821 .69642 .32366 Mtetra
0 .273 .778 r
.69642 .32366 .69948 .32821 .70605 .32818 .7033 .32891 Mtetra
.873 .992 .749 r
.7033 .32891 .70605 .32818 .71266 .32829 .70946 .32107 Mtetra
.711 .639 .774 r
.70946 .32107 .71266 .32829 .7189 .32196 .71584 .31688 Mtetra
0 .143 .687 r
.71584 .31688 .7189 .32196 .72563 .32348 .72293 .32404 Mtetra
.693 .979 .81 r
.72293 .32404 .72563 .32348 .73236 .32445 .72929 .31905 Mtetra
.861 .743 .731 r
.72929 .31905 .73236 .32445 .73849 .31614 .73534 .30934 Mtetra
.045 .254 .751 r
.73534 .30934 .73849 .31614 .74523 .31669 .7425 .31603 Mtetra
.588 .017 0 r
.7425 .31603 .74523 .31669 .75244 .32352 .74963 .32144 Mtetra
.961 .856 .691 r
.74963 .32144 .75244 .32352 .75862 .31564 .75546 .30859 Mtetra
.793 .681 .741 r
.75546 .30859 .75862 .31564 .76463 .30566 .76167 .30107 Mtetra
.686 .264 0 r
.76167 .30107 .76463 .30566 .77222 .31602 .76956 .31522 Mtetra
.786 .288 0 r
.76956 .31522 .77222 .31602 .78012 .32928 .77726 .32601 Mtetra
.957 .81 .657 r
.77726 .32601 .78012 .32928 .786 .31725 .78289 .31071 Mtetra
.93 .728 .609 r
.78289 .31071 .786 .31725 .79096 .2948 .78801 .28985 Mtetra
0 .124 .671 r
.78801 .28985 .79096 .2948 .79829 .30032 .79555 .29768 Mtetra
.932 .561 .169 r
.79555 .29768 .79829 .30032 .80898 .34259 .80602 .33772 Mtetra
.921 .558 .124 r
.80602 .33772 .80898 .34259 .82046 .39123 .81698 .38094 Mtetra
0 0 .561 r
.81698 .38094 .82046 .39123 .82937 .40992 .82558 .39653 Mtetra
.828 .623 .626 r
.82558 .39653 .82937 .40992 .83468 .3902 .83105 .37845 Mtetra
.924 .677 .547 r
.83105 .37845 .83468 .3902 .83796 .35046 .83474 .3427 Mtetra
.956 .714 .53 r
.83474 .3427 .83796 .35046 .84124 .31228 .83838 .30776 Mtetra
.973 .763 .56 r
.83838 .30776 .84124 .31228 .8456 .28594 .84291 .2828 Mtetra
.964 .827 .66 r
.84291 .2828 .8456 .28594 .8511 .27135 .84844 .26821 Mtetra
.886 .857 .808 r
.84844 .26821 .8511 .27135 .85737 .26423 .85467 .2606 Mtetra
0 .237 .729 r
.24742 .45969 .25105 .46335 .25609 .46681 .25245 .46327 Mtetra
.899 .482 .138 r
.25245 .46327 .25609 .46681 .26059 .47726 .25688 .4745 Mtetra
.937 .603 .375 r
.25688 .4745 .26059 .47726 .26434 .49804 .26046 .49715 Mtetra
.927 .62 .441 r
.26046 .49715 .26434 .49804 .26743 .52854 .26331 .53039 Mtetra
.907 .6 .454 r
.26331 .53039 .26743 .52854 .27062 .55927 .26633 .56301 Mtetra
.806 .441 .366 r
.26633 .56301 .27062 .55927 .27527 .57172 .2711 .57389 Mtetra
.969 .797 .614 r
.2711 .57389 .27527 .57172 .28239 .55063 .27865 .54735 Mtetra
.932 .709 .578 r
.27865 .54735 .28239 .55063 .2913 .50328 .28798 .49503 Mtetra
.9 .68 .595 r
.28798 .49503 .2913 .50328 .29973 .46094 .2964 .45354 Mtetra
.698 .611 .756 r
.2964 .45354 .29973 .46094 .30584 .45141 .30213 .44983 Mtetra
.925 .578 .358 r
.30213 .44983 .30584 .45141 .31018 .46894 .30626 .47022 Mtetra
.716 .241 .121 r
.30626 .47022 .31018 .46894 .31509 .47862 .31148 .47504 Mtetra
.912 .732 .646 r
.31148 .47504 .31509 .47862 .32164 .4625 .31834 .45448 Mtetra
.824 .657 .675 r
.31834 .45448 .32164 .4625 .32823 .44532 .32469 .44144 Mtetra
.818 .36 0 r
.32469 .44144 .32823 .44532 .33349 .45006 .32968 .45065 Mtetra
.614 .074 0 r
.32968 .45065 .33349 .45006 .3386 .45801 .33507 .45388 Mtetra
.886 .734 .688 r
.33507 .45388 .3386 .45801 .34477 .44754 .34145 .43999 Mtetra
.699 .61 .754 r
.34145 .43999 .34477 .44754 .35089 .43776 .34725 .43617 Mtetra
.785 .284 0 r
.34725 .43617 .35089 .43776 .35617 .44392 .3525 .44305 Mtetra
.885 .895 .832 r
.3525 .44305 .35617 .44392 .36181 .44374 .35848 .43635 Mtetra
.775 .648 .722 r
.35848 .43635 .36181 .44374 .36799 .43268 .36449 .4289 Mtetra
0 .094 .608 r
.36449 .4289 .36799 .43268 .37359 .43366 .36991 .43381 Mtetra
.763 .98 .913 r
.36991 .43381 .37359 .43366 .37913 .43662 .37578 .42967 Mtetra
.772 .655 .734 r
.37578 .42967 .37913 .43662 .38522 .42721 .38177 .42285 Mtetra
0 .289 .786 r
.38177 .42285 .38522 .42721 .39095 .42644 .3873 .42679 Mtetra
.814 .986 .883 r
.3873 .42679 .39095 .42644 .39654 .42937 .39322 .42179 Mtetra
.714 .619 .749 r
.39322 .42179 .39654 .42937 .40261 .4205 .39913 .41733 Mtetra
0 .334 .793 r
.39913 .41733 .40261 .4205 .40834 .42091 .40476 .4205 Mtetra
.901 .923 .824 r
.40476 .4205 .40834 .42091 .41406 .42205 .41078 .41335 Mtetra
.561 .516 .763 r
.41078 .41335 .41406 .42205 .42012 .41323 .41656 .41322 Mtetra
.083 .643 .758 r
.41656 .41322 .42012 .41323 .4258 .41686 .42237 .41289 Mtetra
.831 .756 .78 r
.42237 .41289 .4258 .41686 .4317 .41374 .42839 .40588 Mtetra
.303 .384 .78 r
.42839 .40588 .4317 .41374 .43769 .40756 .43411 .40952 Mtetra
.781 .989 .751 r
.43411 .40952 .43769 .40756 .44341 .41187 .44013 .40321 Mtetra
.539 .506 .767 r
.44013 .40321 .44341 .41187 .4495 .40225 .44598 .40353 Mtetra
0 0 0 r
.44598 .40353 .4495 .40225 .45525 .40732 .4519 .40152 Mtetra
.787 .691 .758 r
.4519 .40152 .45525 .40732 .46119 .40513 .45793 .39503 Mtetra
.151 .232 .694 r
.45793 .39503 .46119 .40513 .46727 .39519 .4637 .40186 Mtetra
.672 .807 .357 r
.4637 .40186 .46727 .39519 .47301 .40573 .46985 .38978 Mtetra
.382 .315 .657 r
.46985 .38978 .47301 .40573 .47917 .39152 .47569 .39557 Mtetra
0 0 0 r
.47569 .39557 .47917 .39152 .48505 .39671 .48173 .39001 Mtetra
.687 .63 .787 r
.48173 .39001 .48505 .39671 .49106 .39266 .48774 .38687 Mtetra
.356 .492 .858 r
.48774 .38687 .49106 .39266 .49709 .38769 .49371 .38901 Mtetra
.9 .987 .761 r
.49371 .38901 .49709 .38769 .50307 .39088 .49979 .38098 Mtetra
.357 .372 .739 r
.49979 .38098 .50307 .39088 .50914 .38247 .50579 .38499 Mtetra
.789 .969 .668 r
.50579 .38499 .50914 .38247 .51516 .38617 .51187 .37735 Mtetra
.435 .443 .769 r
.51187 .37735 .51516 .38617 .52122 .37928 .51792 .37969 Mtetra
.806 .996 .86 r
.51792 .37969 .52122 .37928 .52729 .3806 .524 .37435 Mtetra
.543 .576 .838 r
.524 .37435 .52729 .3806 .53337 .37654 .53009 .37434 Mtetra
.72 .859 .947 r
.53009 .37434 .53337 .37654 .53947 .37506 .53619 .37138 Mtetra
.679 .753 .907 r
.53619 .37138 .53947 .37506 .54558 .37391 .54231 .36907 Mtetra
.561 .645 .89 r
.54231 .36907 .54558 .37391 .55169 .36957 .54845 .36859 Mtetra
.821 .945 .905 r
.54845 .36859 .55169 .36957 .55786 .37141 .55458 .36371 Mtetra
.424 .465 .799 r
.55458 .36371 .55786 .37141 .56396 .3644 .56078 .3659 Mtetra
.829 .993 .745 r
.56078 .3659 .56396 .3644 .5702 .36825 .56689 .35876 Mtetra
.388 .402 .753 r
.56689 .35876 .5702 .36825 .5763 .36112 .57316 .3622 Mtetra
.809 .998 .786 r
.57316 .3622 .5763 .36112 .58255 .36225 .57929 .35587 Mtetra
.56 .583 .833 r
.57929 .35587 .58255 .36225 .58878 .36175 .58554 .35558 Mtetra
.519 .569 .846 r
.58554 .35558 .58878 .36175 .59486 .35304 .59182 .35592 Mtetra
.765 .936 .589 r
.59182 .35592 .59486 .35304 .60138 .36293 .59792 .34735 Mtetra
.353 .303 .662 r
.59792 .34735 .60138 .36293 .60731 .34813 .60439 .35417 Mtetra
0 0 0 r
.60439 .35417 .60731 .34813 .6138 .35461 .61046 .34415 Mtetra
.482 .445 .739 r
.61046 .34415 .6138 .35461 .62007 .3521 .61685 .34606 Mtetra
.642 .636 .83 r
.61685 .34606 .62007 .3521 .62615 .3432 .62316 .34416 Mtetra
.577 .935 .782 r
.62316 .34416 .62615 .3432 .63271 .34893 .62941 .34004 Mtetra
.489 .478 .771 r
.62941 .34004 .63271 .34893 .6388 .34009 .63586 .34148 Mtetra
.783 .985 .731 r
.63586 .34148 .6388 .34009 .64531 .34281 .64204 .33472 Mtetra
.437 .466 .791 r
.64204 .33472 .64531 .34281 .65169 .34132 .64856 .3369 Mtetra
.732 .741 .858 r
.64856 .3369 .65169 .34132 .65783 .33373 .65488 .3333 Mtetra
.664 .962 .934 r
.65488 .3333 .65783 .33373 .66452 .33891 .66121 .32988 Mtetra
.458 .457 .769 r
.66121 .32988 .66452 .33891 .67074 .33293 .6678 .33198 Mtetra
.879 .953 .851 r
.6678 .33198 .67074 .33293 .67706 .32904 .67402 .32549 Mtetra
.439 .667 .958 r
.67402 .32549 .67706 .32904 .68383 .33389 .68057 .32585 Mtetra
.547 .532 .79 r
.68057 .32585 .68383 .33389 .68999 .32616 .68713 .32595 Mtetra
.886 .983 .818 r
.68713 .32595 .68999 .32616 .69642 .32366 .69334 .31888 Mtetra
.278 .499 .891 r
.69334 .31888 .69642 .32366 .7033 .32891 .70007 .32141 Mtetra
.585 .568 .801 r
.70007 .32141 .7033 .32891 .70946 .32107 .70665 .32063 Mtetra
.916 .965 .793 r
.70665 .32063 .70946 .32107 .71584 .31688 .71282 .31262 Mtetra
.127 .432 .872 r
.71282 .31262 .71584 .31688 .72293 .32404 .71968 .31604 Mtetra
.478 .495 .797 r
.71968 .31604 .72293 .32404 .72929 .31905 .72646 .31752 Mtetra
.948 .895 .742 r
.72646 .31752 .72929 .31905 .73534 .30934 .73249 .3072 Mtetra
.267 .675 .968 r
.73249 .3072 .73534 .30934 .7425 .31603 .73925 .30784 Mtetra
0 .179 .695 r
.73925 .30784 .7425 .31603 .74963 .32144 .74661 .31655 Mtetra
.847 .761 .767 r
.74661 .31655 .74963 .32144 .75546 .30859 .75281 .30852 Mtetra
.97 .929 .676 r
.75281 .30852 .75546 .30859 .76167 .30107 .7587 .29653 Mtetra
0 0 .502 r
.7587 .29653 .76167 .30107 .76956 .31522 .76625 .30635 Mtetra
0 0 .501 r
.76625 .30635 .76956 .31522 .77726 .32601 .7743 .32155 Mtetra
.893 .785 .734 r
.7743 .32155 .77726 .32601 .78289 .31071 .78036 .31126 Mtetra
.999 .833 .51 r
.78036 .31126 .78289 .31071 .78801 .28985 .78527 .28752 Mtetra
.129 .567 .923 r
.78527 .28752 .78801 .28985 .79555 .29768 .7923 .28925 Mtetra
.858 .514 .001 r
.7923 .28925 .79555 .29768 .80602 .33772 .80263 .32818 Mtetra
.878 .543 .039 r
.80263 .32818 .80602 .33772 .81698 .38094 .81402 .37651 Mtetra
.812 .404 0 r
.81402 .37651 .81698 .38094 .82558 .39653 .82316 .39796 Mtetra
.965 .904 .54 r
.82316 .39796 .82558 .39653 .83105 .37845 .82885 .38177 Mtetra
.983 .784 .379 r
.82885 .38177 .83105 .37845 .83474 .3427 .83242 .3442 Mtetra
.994 .779 .411 r
.83242 .3442 .83474 .3427 .83838 .30776 .83583 .30642 Mtetra
.998 .799 .506 r
.83583 .30642 .83838 .30776 .84291 .2828 .84019 .27943 Mtetra
.964 .816 .647 r
.84019 .27943 .84291 .2828 .84844 .26821 .84565 .26395 Mtetra
.864 .8 .786 r
.84565 .26395 .84844 .26821 .85467 .2606 .85188 .25615 Mtetra
.498 0 0 r
.2437 .45695 .24742 .45969 .25245 .46327 .24868 .46105 Mtetra
.899 .495 .226 r
.24868 .46105 .25245 .46327 .25688 .4745 .25307 .47272 Mtetra
.927 .594 .388 r
.25307 .47272 .25688 .4745 .26046 .49715 .25665 .49512 Mtetra
.935 .624 .426 r
.25665 .49512 .26046 .49715 .26331 .53039 .2596 .5267 Mtetra
.947 .629 .399 r
.2596 .5267 .26331 .53039 .26633 .56301 .26281 .55638 Mtetra
0 0 .421 r
.26281 .55638 .26633 .56301 .2711 .57389 .26776 .56475 Mtetra
.868 .665 .626 r
.26776 .56475 .2711 .57389 .27865 .54735 .27531 .53857 Mtetra
.903 .678 .588 r
.27531 .53857 .27865 .54735 .28798 .49503 .28446 .48949 Mtetra
.914 .699 .597 r
.28446 .48949 .28798 .49503 .2964 .45354 .29273 .4508 Mtetra
.786 .801 .865 r
.29273 .4508 .2964 .45354 .30213 .44983 .2985 .44657 Mtetra
.936 .574 .297 r
.2985 .44657 .30213 .44983 .30626 .47022 .30276 .46479 Mtetra
0 .137 .682 r
.30276 .46479 .30626 .47022 .31148 .47504 .30795 .47008 Mtetra
.889 .713 .658 r
.30795 .47008 .31148 .47504 .31834 .45448 .31468 .452 Mtetra
.909 .772 .698 r
.31468 .452 .31834 .45448 .32469 .44144 .32107 .43851 Mtetra
.738 .232 0 r
.32107 .43851 .32469 .44144 .32968 .45065 .32621 .4453 Mtetra
0 .251 .764 r
.32621 .4453 .32968 .45065 .33507 .45388 .33152 .44975 Mtetra
.872 .737 .71 r
.33152 .44975 .33507 .45388 .34145 .43999 .33779 .43816 Mtetra
.856 .848 .834 r
.33779 .43816 .34145 .43999 .34725 .43617 .34374 .43202 Mtetra
0 .009 .538 r
.34374 .43202 .34725 .43617 .3525 .44305 .34905 .43766 Mtetra
.712 .674 .811 r
.34905 .43766 .3525 .44305 .35848 .43635 .35486 .4343 Mtetra
.889 .821 .774 r
.35486 .4343 .35848 .43635 .36449 .4289 .36094 .42579 Mtetra
.066 .477 .89 r
.36094 .42579 .36449 .4289 .36991 .43381 .3665 .42794 Mtetra
.575 .6 .841 r
.3665 .42794 .36991 .43381 .37578 .42967 .3722 .42742 Mtetra
.872 .823 .797 r
.3722 .42742 .37578 .42967 .38177 .42285 .37823 .42004 Mtetra
.343 .663 .973 r
.37823 .42004 .38177 .42285 .3873 .42679 .38391 .42064 Mtetra
.582 .595 .831 r
.38391 .42064 .3873 .42679 .39322 .42179 .38966 .42 Mtetra
.859 .859 .839 r
.38966 .42 .39322 .42179 .39913 .41733 .39565 .41385 Mtetra
.402 .645 .956 r
.39565 .41385 .39913 .41733 .40476 .4205 .40137 .41445 Mtetra
.647 .629 .818 r
.40137 .41445 .40476 .4205 .41078 .41335 .40722 .41253 Mtetra
.828 .933 .9 r
.40722 .41253 .41078 .41335 .41656 .41322 .41317 .40769 Mtetra
.462 .56 .869 r
.41317 .40769 .41656 .41322 .42237 .41289 .41894 .40857 Mtetra
.734 .727 .844 r
.41894 .40857 .42237 .41289 .42839 .40588 .42487 .40503 Mtetra
.682 .93 .969 r
.42487 .40503 .42839 .40588 .43411 .40952 .43079 .4022 Mtetra
.546 .542 .801 r
.43079 .4022 .43411 .40952 .44013 .40321 .43663 .40227 Mtetra
.838 .928 .891 r
.43663 .40227 .44013 .40321 .44598 .40353 .44263 .39717 Mtetra
.52 .558 .835 r
.44263 .39717 .44598 .40353 .4519 .40152 .4485 .39753 Mtetra
.665 .725 .894 r
.4485 .39753 .4519 .40152 .45793 .39503 .45445 .39549 Mtetra
.781 .994 .876 r
.45445 .39549 .45793 .39503 .4637 .40186 .46046 .39065 Mtetra
.482 .429 .722 r
.46046 .39065 .4637 .40186 .46985 .38978 .46635 .39258 Mtetra
.545 .87 .592 r
.46635 .39258 .46985 .38978 .47569 .39557 .47239 .38709 Mtetra
.575 .532 .769 r
.47239 .38709 .47569 .39557 .48173 .39001 .47836 .38659 Mtetra
.642 .753 .93 r
.47836 .38659 .48173 .39001 .48774 .38687 .48437 .38486 Mtetra
.776 .872 .919 r
.48437 .38486 .48774 .38687 .49371 .38901 .49041 .381 Mtetra
.534 .519 .786 r
.49041 .381 .49371 .38901 .49979 .38098 .49642 .38136 Mtetra
.751 .991 .881 r
.49642 .38136 .49979 .38098 .50579 .38499 .50248 .3768 Mtetra
.549 .524 .78 r
.50248 .3768 .50579 .38499 .51187 .37735 .50853 .37686 Mtetra
.73 .964 .939 r
.50853 .37686 .51187 .37735 .51792 .37969 .51461 .37316 Mtetra
.598 .595 .82 r
.51461 .37316 .51792 .37969 .524 .37435 .52069 .37219 Mtetra
.696 .857 .959 r
.52069 .37219 .524 .37435 .53009 .37434 .52679 .36954 Mtetra
.653 .686 .869 r
.52679 .36954 .53009 .37434 .53619 .37138 .53291 .36761 Mtetra
.64 .735 .918 r
.53291 .36761 .53619 .37138 .54231 .36907 .53904 .3659 Mtetra
.713 .795 .915 r
.53904 .3659 .54231 .36907 .54845 .36859 .54517 .36303 Mtetra
.58 .623 .859 r
.54517 .36303 .54845 .36859 .55458 .36371 .55134 .36233 Mtetra
.768 .923 .938 r
.55134 .36233 .55458 .36371 .56078 .3659 .55749 .35846 Mtetra
.541 .54 .803 r
.55749 .35846 .56078 .3659 .56689 .35876 .5637 .35862 Mtetra
.74 .982 .911 r
.5637 .35862 .56689 .35876 .57316 .3622 .56986 .35443 Mtetra
.573 .55 .79 r
.56986 .35443 .57316 .3622 .57929 .35587 .5761 .35396 Mtetra
.64 .865 .984 r
.5761 .35396 .57929 .35587 .58554 .35558 .58232 .3518 Mtetra
.753 .773 .869 r
.58232 .3518 .58554 .35558 .59182 .35592 .58853 .34794 Mtetra
.456 .479 .793 r
.58853 .34794 .59182 .35592 .59792 .34735 .59486 .34971 Mtetra
.66 .923 .626 r
.59486 .34971 .59792 .34735 .60439 .35417 .60102 .34316 Mtetra
.51 .453 .73 r
.60102 .34316 .60439 .35417 .61046 .34415 .60739 .34446 Mtetra
.44 .878 .848 r
.60739 .34446 .61046 .34415 .61685 .34606 .61368 .34197 Mtetra
.769 .764 .849 r
.61368 .34197 .61685 .34606 .62316 .34416 .61992 .33755 Mtetra
.458 .522 .836 r
.61992 .33755 .62316 .34416 .62941 .34004 .62635 .3389 Mtetra
.814 .948 .91 r
.62635 .3389 .62941 .34004 .63586 .34148 .6326 .33407 Mtetra
.575 .563 .803 r
.6326 .33407 .63586 .34148 .64204 .33472 .63901 .33352 Mtetra
.426 .827 .98 r
.63901 .33352 .64204 .33472 .64856 .3369 .64542 .33246 Mtetra
.782 .754 .828 r
.64542 .33246 .64856 .3369 .65488 .3333 .65169 .32744 Mtetra
.442 .543 .864 r
.65169 .32744 .65488 .3333 .66121 .32988 .65823 .32876 Mtetra
.674 .934 .968 r
.65823 .32876 .66121 .32988 .6678 .33198 .6646 .32573 Mtetra
.724 .67 .796 r
.6646 .32573 .6678 .33198 .67402 .32549 .67094 .32157 Mtetra
.235 .526 .917 r
.67094 .32157 .67402 .32549 .68057 .32585 .67759 .32379 Mtetra
.788 .897 .92 r
.67759 .32379 .68057 .32585 .68713 .32595 .68395 .3195 Mtetra
.713 .66 .796 r
.68395 .3195 .68713 .32595 .69334 .31888 .69033 .31558 Mtetra
.009 .414 .857 r
.69033 .31558 .69334 .31888 .70007 .32141 .69711 .31887 Mtetra
.794 .869 .903 r
.69711 .31887 .70007 .32141 .70665 .32063 .70349 .31439 Mtetra
.761 .687 .781 r
.70349 .31439 .70665 .32063 .71282 .31262 .70982 .30896 Mtetra
0 .287 .778 r
.70982 .30896 .71282 .31262 .71968 .31604 .71677 .31366 Mtetra
.616 .836 .984 r
.71677 .31366 .71968 .31604 .72646 .31752 .72335 .31176 Mtetra
.849 .731 .734 r
.72335 .31176 .72646 .31752 .73249 .3072 .72945 .30244 Mtetra
.218 .463 .879 r
.72945 .30244 .73249 .3072 .73925 .30784 .73639 .30554 Mtetra
.516 0 0 r
.73639 .30554 .73925 .30784 .74661 .31655 .7436 .31211 Mtetra
.881 .781 .747 r
.7436 .31211 .74661 .31655 .75281 .30852 .74971 .30261 Mtetra
.853 .73 .728 r
.74971 .30261 .75281 .30852 .7587 .29653 .75579 .29293 Mtetra
.618 .156 0 r
.75579 .29293 .7587 .29653 .76625 .30635 .7634 .30343 Mtetra
.75 .284 0 r
.7634 .30343 .76625 .30635 .7743 .32155 .77126 .31626 Mtetra
.884 .757 .717 r
.77126 .31626 .7743 .32155 .78036 .31126 .77728 .30527 Mtetra
.941 .738 .601 r
.77728 .30527 .78036 .31126 .78527 .28752 .78238 .28351 Mtetra
.244 .525 .915 r
.78238 .28351 .78527 .28752 .7923 .28925 .78947 .28588 Mtetra
.922 .546 .132 r
.78947 .28588 .7923 .28925 .80263 .32818 .79956 .32221 Mtetra
.915 .559 .108 r
.79956 .32221 .80263 .32818 .81402 .37651 .81062 .36724 Mtetra
0 0 .372 r
.81062 .36724 .81402 .37651 .82316 .39796 .81968 .38808 Mtetra
.837 .66 .663 r
.81968 .38808 .82316 .39796 .82885 .38177 .8256 .37417 Mtetra
.957 .716 .532 r
.8256 .37417 .82885 .38177 .83242 .3442 .82948 .33947 Mtetra
.981 .742 .503 r
.82948 .33947 .83242 .3442 .83583 .30642 .83309 .30338 Mtetra
.989 .78 .533 r
.83309 .30338 .83583 .30642 .84019 .27943 .83752 .27673 Mtetra
.976 .833 .637 r
.83752 .27673 .84019 .27943 .84565 .26395 .84297 .26087 Mtetra
.901 .86 .791 r
.84297 .26087 .84565 .26395 .85188 .25615 .84916 .25256 Mtetra
0 .135 .632 r
.24003 .45337 .2437 .45695 .24868 .46105 .24502 .45745 Mtetra
.906 .496 .16 r
.24502 .45745 .24868 .46105 .25307 .47272 .24939 .46926 Mtetra
.943 .609 .366 r
.24939 .46926 .25307 .47272 .25665 .49512 .25291 .4921 Mtetra
.942 .632 .42 r
.25291 .4921 .25665 .49512 .2596 .5267 .25575 .52447 Mtetra
.936 .621 .417 r
.25575 .52447 .2596 .5267 .26281 .55638 .25888 .55487 Mtetra
.838 .378 .106 r
.25888 .55487 .26281 .55638 .26776 .56475 .26383 .56311 Mtetra
.935 .746 .622 r
.26383 .56311 .26776 .56475 .27531 .53857 .27153 .5356 Mtetra
.933 .712 .58 r
.27153 .5356 .27531 .53857 .28446 .48949 .28086 .485 Mtetra
.921 .707 .596 r
.28086 .485 .28446 .48949 .29273 .4508 .28918 .44623 Mtetra
.697 .697 .846 r
.28918 .44623 .29273 .4508 .2985 .44657 .29485 .44356 Mtetra
.936 .58 .318 r
.29485 .44356 .2985 .44657 .30276 .46479 .29902 .46287 Mtetra
.558 0 0 r
.29902 .46287 .30276 .46479 .30795 .47008 .30429 .46693 Mtetra
.915 .741 .652 r
.30429 .46693 .30795 .47008 .31468 .452 .31114 .44729 Mtetra
.868 .721 .697 r
.31114 .44729 .31468 .452 .32107 .43851 .3175 .43473 Mtetra
.784 .313 0 r
.3175 .43473 .32107 .43851 .32621 .4453 .32253 .44309 Mtetra
.374 0 0 r
.32253 .44309 .32621 .4453 .33152 .44975 .32792 .44638 Mtetra
.894 .755 .7 r
.32792 .44638 .33152 .44975 .33779 .43816 .33429 .43342 Mtetra
.759 .71 .806 r
.33429 .43342 .33779 .43816 .34374 .43202 .34015 .4289 Mtetra
.669 .156 0 r
.34015 .4289 .34374 .43202 .34905 .43766 .34542 .43518 Mtetra
.827 .82 .843 r
.34542 .43518 .34905 .43766 .35486 .4343 .35136 .42976 Mtetra
.83 .73 .754 r
.35136 .42976 .35486 .4343 .36094 .42579 .35742 .42192 Mtetra
0 .278 .77 r
.35742 .42192 .36094 .42579 .3665 .42794 .36289 .42566 Mtetra
.705 .834 .944 r
.36289 .42566 .3665 .42794 .3722 .42742 .36871 .42307 Mtetra
.823 .737 .769 r
.36871 .42307 .3722 .42742 .37823 .42004 .37474 .41595 Mtetra
.152 .464 .889 r
.37474 .41595 .37823 .42004 .38391 .42064 .38034 .4184 Mtetra
.73 .842 .934 r
.38034 .4184 .38391 .42064 .38966 .42 .38619 .41542 Mtetra
.784 .726 .798 r
.38619 .41542 .38966 .42 .39565 .41385 .39216 .41006 Mtetra
.196 .511 .913 r
.39216 .41006 .39565 .41385 .40137 .41445 .39784 .41209 Mtetra
.808 .838 .873 r
.39784 .41209 .40137 .41445 .40722 .41253 .40379 .40741 Mtetra
.683 .677 .839 r
.40379 .40741 .40722 .41253 .41317 .40769 .40967 .40487 Mtetra
.363 .675 .976 r
.40967 .40487 .41317 .40769 .41894 .40857 .41546 .40535 Mtetra
.815 .791 .83 r
.41546 .40535 .41894 .40857 .42487 .40503 .42146 .39991 Mtetra
.5 .599 .884 r
.42146 .39991 .42487 .40503 .43079 .4022 .42729 .40024 Mtetra
.74 .868 .939 r
.42729 .40024 .43079 .4022 .43663 .40227 .43324 .39704 Mtetra
.683 .675 .836 r
.43324 .39704 .43663 .40227 .44263 .39717 .43918 .39444 Mtetra
.453 .726 .984 r
.43918 .39444 .44263 .39717 .4485 .39753 .44507 .3943 Mtetra
.796 .794 .85 r
.44507 .3943 .4485 .39753 .45445 .39549 .45108 .38953 Mtetra
.492 .56 .853 r
.45108 .38953 .45445 .39549 .46046 .39065 .45699 .39018 Mtetra
.79 .964 .919 r
.45699 .39018 .46046 .39065 .46635 .39258 .46301 .38581 Mtetra
.586 .581 .813 r
.46301 .38581 .46635 .39258 .47239 .38709 .46898 .38507 Mtetra
.684 .859 .966 r
.46898 .38507 .47239 .38709 .47836 .38659 .47499 .38259 Mtetra
.695 .738 .884 r
.47499 .38259 .47836 .38659 .48437 .38486 .48101 .37998 Mtetra
.596 .658 .88 r
.48101 .37998 .48437 .38486 .49041 .381 .48703 .379 Mtetra
.755 .873 .933 r
.48703 .379 .49041 .381 .49642 .38136 .49308 .3755 Mtetra
.577 .608 .847 r
.49308 .3755 .49642 .38136 .50248 .3768 .49913 .37487 Mtetra
.748 .879 .939 r
.49913 .37487 .50248 .3768 .50853 .37686 .5052 .37146 Mtetra
.595 .636 .861 r
.5052 .37146 .50853 .37686 .51461 .37316 .51128 .37051 Mtetra
.72 .827 .932 r
.51128 .37051 .51461 .37316 .52069 .37219 .51738 .36757 Mtetra
.625 .684 .885 r
.51738 .36757 .52069 .37219 .52679 .36954 .52348 .36611 Mtetra
.684 .77 .917 r
.52348 .36611 .52679 .36954 .53291 .36761 .52961 .36371 Mtetra
.659 .736 .906 r
.52961 .36371 .53291 .36761 .53904 .3659 .53574 .3617 Mtetra
.646 .715 .898 r
.53574 .3617 .53904 .3659 .54517 .36303 .54189 .3599 Mtetra
.698 .794 .925 r
.54189 .3599 .54517 .36303 .55134 .36233 .54805 .35727 Mtetra
.606 .657 .874 r
.54805 .35727 .55134 .36233 .55749 .35846 .55424 .35612 Mtetra
.734 .856 .938 r
.55424 .35612 .55749 .35846 .5637 .35862 .56042 .35291 Mtetra
.581 .618 .855 r
.56042 .35291 .5637 .35862 .56986 .35443 .56664 .35219 Mtetra
.738 .865 .94 r
.56664 .35219 .56986 .35443 .5761 .35396 .57284 .3489 Mtetra
.602 .657 .876 r
.57284 .3489 .5761 .35396 .58232 .3518 .57909 .34779 Mtetra
.674 .739 .899 r
.57909 .34779 .58232 .3518 .58853 .34794 .58534 .3455 Mtetra
.688 .843 .958 r
.58534 .3455 .58853 .34794 .59486 .34971 .59159 .34293 Mtetra
.577 .581 .82 r
.59159 .34293 .59486 .34971 .60102 .34316 .5979 .34232 Mtetra
.757 .96 .935 r
.5979 .34232 .60102 .34316 .60739 .34446 .60414 .33829 Mtetra
.528 .577 .848 r
.60414 .33829 .60739 .34446 .61368 .34197 .61051 .33847 Mtetra
.759 .794 .881 r
.61051 .33847 .61368 .34197 .61992 .33755 .61678 .33454 Mtetra
.574 .767 .97 r
.61678 .33454 .61992 .33755 .62635 .3389 .62314 .3334 Mtetra
.631 .654 .854 r
.62314 .3334 .62635 .3389 .6326 .33407 .6295 .33175 Mtetra
.754 .87 .932 r
.6295 .33175 .6326 .33407 .63901 .33352 .63581 .32812 Mtetra
.473 .581 .882 r
.63581 .32812 .63901 .33352 .64542 .33246 .6423 .32887 Mtetra
.784 .797 .863 r
.6423 .32887 .64542 .33246 .65169 .32744 .6486 .32428 Mtetra
.562 .753 .967 r
.6486 .32428 .65169 .32744 .65823 .32876 .65505 .32328 Mtetra
.553 .619 .873 r
.65505 .32328 .65823 .32876 .6646 .32573 .66155 .32295 Mtetra
.832 .851 .861 r
.66155 .32295 .6646 .32573 .67094 .32157 .66784 .3174 Mtetra
.358 .584 .929 r
.66784 .3174 .67094 .32157 .67759 .32379 .67446 .31878 Mtetra
.649 .686 .871 r
.67446 .31878 .67759 .32379 .68395 .3195 .68094 .3168 Mtetra
.839 .859 .859 r
.68094 .3168 .68395 .3195 .69033 .31558 .68724 .31105 Mtetra
.201 .467 .885 r
.68724 .31105 .69033 .31558 .69711 .31887 .69401 .31402 Mtetra
.672 .704 .872 r
.69401 .31402 .69711 .31887 .70349 .31439 .70052 .3116 Mtetra
.872 .855 .823 r
.70052 .3116 .70349 .31439 .70982 .30896 .70677 .3046 Mtetra
.064 .385 .847 r
.70677 .3046 .70982 .30896 .71677 .31366 .71368 .30856 Mtetra
.511 .618 .895 r
.71368 .30856 .71677 .31366 .72335 .31176 .72039 .30872 Mtetra
.917 .835 .75 r
.72039 .30872 .72335 .31176 .72945 .30244 .72648 .29878 Mtetra
.319 .595 .944 r
.72648 .29878 .72945 .30244 .73639 .30554 .73331 .3002 Mtetra
0 .11 .662 r
.73331 .3002 .73639 .30554 .7436 .31211 .74062 .30811 Mtetra
.873 .801 .776 r
.74062 .30811 .7436 .31211 .74971 .30261 .74683 .29981 Mtetra
.938 .843 .723 r
.74683 .29981 .74971 .30261 .75579 .29293 .75281 .28852 Mtetra
0 0 .508 r
.75281 .28852 .75579 .29293 .7634 .30343 .76034 .298 Mtetra
.627 .23 0 r
.76034 .298 .7634 .30343 .77126 .31626 .76832 .3124 Mtetra
.9 .811 .751 r
.76832 .3124 .77126 .31626 .77728 .30527 .77446 .30269 Mtetra
.985 .795 .569 r
.77446 .30269 .77728 .30527 .78238 .28351 .7795 .27982 Mtetra
.408 .646 .954 r
.7795 .27982 .78238 .28351 .78947 .28588 .78646 .28051 Mtetra
.901 .533 .075 r
.78646 .28051 .78947 .28588 .79956 .32221 .79653 .31684 Mtetra
.924 .566 .131 r
.79653 .31684 .79956 .32221 .81062 .36724 .8077 .36346 Mtetra
.843 .43 0 r
.8077 .36346 .81062 .36724 .81968 .38808 .81689 .38576 Mtetra
.968 .86 .679 r
.81689 .38576 .81968 .38808 .8256 .37417 .82285 .37205 Mtetra
.994 .767 .481 r
.82285 .37205 .8256 .37417 .82948 .33947 .82671 .33661 Mtetra
.991 .757 .48 r
.82671 .33661 .82948 .33947 .83309 .30338 .83028 .29968 Mtetra
.984 .77 .537 r
.83028 .29968 .83309 .30338 .83752 .27673 .83469 .27251 Mtetra
.953 .792 .645 r
.83469 .27251 .83752 .27673 .84297 .26087 .84014 .25646 Mtetra
.871 .797 .774 r
.84014 .25646 .84297 .26087 .84916 .25256 .84635 .24814 Mtetra
0 .126 .617 r
.23634 .4499 .24003 .45337 .24502 .45745 .24132 .45397 Mtetra
.906 .496 .167 r
.24132 .45397 .24502 .45745 .24939 .46926 .24569 .46575 Mtetra
.943 .609 .365 r
.24569 .46575 .24939 .46926 .25291 .4921 .24918 .48862 Mtetra
.945 .635 .416 r
.24918 .48862 .25291 .4921 .25575 .52447 .25199 .52107 Mtetra
.945 .629 .406 r
.25199 .52107 .25575 .52447 .25888 .55487 .25507 .5516 Mtetra
.822 .348 0 r
.25507 .5516 .25888 .55487 .26383 .56311 .26001 .55995 Mtetra
.922 .728 .624 r
.26001 .55995 .26383 .56311 .27153 .5356 .26775 .5324 Mtetra
.932 .711 .58 r
.26775 .5324 .27153 .5356 .28086 .485 .27715 .48161 Mtetra
.928 .715 .595 r
.27715 .48161 .28086 .485 .28918 .44623 .28554 .44269 Mtetra
.706 .75 .886 r
.28554 .44269 .28918 .44623 .29485 .44356 .29121 .44005 Mtetra
.94 .584 .308 r
.29121 .44005 .29485 .44356 .29902 .46287 .29535 .4595 Mtetra
0 .158 .644 r
.29535 .4595 .29902 .46287 .30429 .46693 .30063 .46355 Mtetra
.913 .737 .651 r
.30063 .46355 .30429 .46693 .31114 .44729 .30752 .44373 Mtetra
.887 .749 .703 r
.30752 .44373 .31114 .44729 .3175 .43473 .3139 .43115 Mtetra
.803 .331 0 r
.3139 .43115 .3175 .43473 .32253 .44309 .31892 .43966 Mtetra
0 .309 .779 r
.31892 .43966 .32253 .44309 .32792 .44638 .32431 .44292 Mtetra
.893 .752 .698 r
.32431 .44292 .32792 .44638 .33429 .43342 .3307 .42979 Mtetra
.777 .76 .838 r
.3307 .42979 .33429 .43342 .34015 .4289 .33657 .42534 Mtetra
.639 .138 0 r
.33657 .42534 .34015 .4289 .34542 .43518 .34183 .43174 Mtetra
.812 .773 .817 r
.34183 .43174 .34542 .43518 .35136 .42976 .34779 .42615 Mtetra
.849 .763 .767 r
.34779 .42615 .35136 .42976 .35742 .42192 .35387 .41828 Mtetra
0 .232 .725 r
.35387 .41828 .35742 .42192 .36289 .42566 .35933 .4222 Mtetra
.71 .762 .893 r
.35933 .4222 .36289 .42566 .36871 .42307 .36516 .41945 Mtetra
.84 .766 .781 r
.36516 .41945 .36871 .42307 .37474 .41595 .37121 .41226 Mtetra
.051 .428 .869 r
.37121 .41226 .37474 .41595 .38034 .4184 .3768 .41493 Mtetra
.73 .767 .882 r
.3768 .41493 .38034 .4184 .38619 .41542 .38268 .41176 Mtetra
.803 .766 .819 r
.38268 .41176 .38619 .41542 .39216 .41006 .38866 .40637 Mtetra
.141 .486 .901 r
.38866 .40637 .39216 .41006 .39784 .41209 .39433 .40861 Mtetra
.795 .776 .836 r
.39433 .40861 .39784 .41209 .40379 .40741 .4003 .40367 Mtetra
.688 .744 .894 r
.4003 .40367 .40379 .40741 .40967 .40487 .40619 .40127 Mtetra
.43 .653 .953 r
.40619 .40127 .40967 .40487 .41546 .40535 .41198 .40171 Mtetra
.814 .771 .813 r
.41198 .40171 .41546 .40535 .42146 .39991 .41801 .39594 Mtetra
.395 .611 .937 r
.41801 .39594 .42146 .39991 .42729 .40024 .42382 .39681 Mtetra
.726 .773 .889 r
.42382 .39681 .42729 .40024 .43324 .39704 .42977 .39371 Mtetra
.704 .774 .907 r
.42977 .39371 .43324 .39704 .43918 .39444 .43573 .39106 Mtetra
.573 .731 .949 r
.43573 .39106 .43918 .39444 .44507 .3943 .44164 .39015 Mtetra
.78 .748 .824 r
.44164 .39015 .44507 .3943 .45108 .38953 .44767 .38531 Mtetra
.293 .542 .917 r
.44767 .38531 .45108 .38953 .45699 .39018 .45355 .38706 Mtetra
.825 .802 .83 r
.45355 .38706 .45699 .39018 .46301 .38581 .45962 .38133 Mtetra
.486 .628 .914 r
.45962 .38133 .46301 .38581 .46898 .38507 .46557 .38161 Mtetra
.694 .768 .908 r
.46557 .38161 .46898 .38507 .47499 .38259 .47159 .37908 Mtetra
.729 .773 .888 r
.47159 .37908 .47499 .38259 .48101 .37998 .47763 .37588 Mtetra
.496 .655 .931 r
.47763 .37588 .48101 .37998 .48703 .379 .48364 .37593 Mtetra
.792 .809 .866 r
.48364 .37593 .48703 .379 .49308 .3755 .48972 .37137 Mtetra
.471 .642 .932 r
.48972 .37137 .49308 .3755 .49913 .37487 .49576 .37167 Mtetra
.773 .801 .875 r
.49576 .37167 .49913 .37487 .5052 .37146 .50186 .36755 Mtetra
.542 .689 .935 r
.50186 .36755 .5052 .37146 .51128 .37051 .50794 .36707 Mtetra
.732 .782 .893 r
.50794 .36707 .51128 .37051 .51738 .36757 .51405 .36382 Mtetra
.608 .726 .929 r
.51405 .36382 .51738 .36757 .52348 .36611 .52016 .36252 Mtetra
.688 .763 .909 r
.52016 .36252 .52348 .36611 .52961 .36371 .52629 .36005 Mtetra
.661 .751 .917 r
.52629 .36005 .52961 .36371 .53574 .3617 .53244 .358 Mtetra
.634 .74 .924 r
.53244 .358 .53574 .3617 .54189 .3599 .5386 .35634 Mtetra
.715 .774 .899 r
.5386 .35634 .54189 .3599 .54805 .35727 .54477 .35338 Mtetra
.551 .696 .936 r
.54477 .35338 .54805 .35727 .55424 .35612 .55096 .35277 Mtetra
.767 .798 .878 r
.55096 .35277 .55424 .35612 .56042 .35291 .55715 .34873 Mtetra
.477 .645 .931 r
.55715 .34873 .56042 .35291 .56664 .35219 .56339 .34899 Mtetra
.781 .81 .876 r
.56339 .34899 .56664 .35219 .57284 .3489 .56959 .34465 Mtetra
.548 .675 .922 r
.56959 .34465 .57284 .3489 .57909 .34779 .57585 .34416 Mtetra
.677 .762 .915 r
.57585 .34416 .57909 .34779 .58534 .3455 .58211 .34183 Mtetra
.741 .778 .883 r
.58211 .34183 .58534 .3455 .59159 .34293 .58835 .33827 Mtetra
.449 .604 .912 r
.58835 .33827 .59159 .34293 .5979 .34232 .5947 .339 Mtetra
.809 .81 .852 r
.5947 .339 .5979 .34232 .60414 .33829 .60093 .33381 Mtetra
.485 .633 .919 r
.60093 .33381 .60414 .33829 .61051 .33847 .6073 .33409 Mtetra
.713 .736 .869 r
.6073 .33409 .61051 .33847 .61678 .33454 .6136 .33095 Mtetra
.588 .735 .945 r
.6136 .33095 .61678 .33454 .62314 .3334 .61997 .3298 Mtetra
.637 .754 .933 r
.61997 .3298 .62314 .3334 .6295 .33175 .62634 .32802 Mtetra
.766 .785 .869 r
.62634 .32802 .6295 .33175 .63581 .32812 .63265 .32384 Mtetra
.398 .6 .928 r
.63265 .32384 .63581 .32812 .6423 .32887 .63915 .3249 Mtetra
.776 .777 .854 r
.63915 .3249 .6423 .32887 .6486 .32428 .64546 .32034 Mtetra
.593 .718 .931 r
.64546 .32034 .6486 .32428 .65505 .32328 .65192 .31919 Mtetra
.505 .668 .936 r
.65192 .31919 .65505 .32328 .66155 .32295 .65844 .3191 Mtetra
.817 .792 .829 r
.65844 .3191 .66155 .32295 .66784 .3174 .66473 .31333 Mtetra
.35 .587 .933 r
.66473 .31333 .66784 .3174 .67446 .31878 .67135 .31471 Mtetra
.638 .73 .915 r
.67135 .31471 .67446 .31878 .68094 .3168 .67785 .3129 Mtetra
.822 .793 .825 r
.67785 .3129 .68094 .3168 .68724 .31105 .68416 .30693 Mtetra
.15 .46 .887 r
.68416 .30693 .68724 .31105 .69401 .31402 .69094 .30995 Mtetra
.667 .743 .907 r
.69094 .30995 .69401 .31402 .70052 .3116 .69746 .30767 Mtetra
.851 .797 .798 r
.69746 .30767 .70052 .3116 .70677 .3046 .70372 .30047 Mtetra
.032 .377 .843 r
.70372 .30047 .70677 .3046 .71368 .30856 .71064 .30444 Mtetra
.466 .649 .938 r
.71064 .30444 .71368 .30856 .72039 .30872 .71737 .30477 Mtetra
.898 .798 .741 r
.71737 .30477 .72039 .30872 .72648 .29878 .72347 .29468 Mtetra
.361 .593 .934 r
.72347 .29468 .72648 .29878 .73331 .3002 .7303 .296 Mtetra
0 .025 .571 r
.7303 .296 .73331 .3002 .74062 .30811 .73762 .30407 Mtetra
.872 .8 .777 r
.73762 .30407 .74062 .30811 .74683 .29981 .74385 .29579 Mtetra
.915 .798 .717 r
.74385 .29579 .74683 .29981 .75281 .28852 .74984 .28433 Mtetra
0 0 .487 r
.74984 .28433 .75281 .28852 .76034 .298 .75737 .29381 Mtetra
.725 .292 0 r
.75737 .29381 .76034 .298 .76832 .3124 .76536 .30837 Mtetra
.896 .804 .75 r
.76536 .30837 .76832 .3124 .77446 .30269 .77152 .29866 Mtetra
.969 .771 .581 r
.77152 .29866 .77446 .30269 .7795 .27982 .77658 .27563 Mtetra
.439 .633 .937 r
.77658 .27563 .7795 .27982 .78646 .28051 .78354 .27626 Mtetra
.915 .542 .109 r
.78354 .27626 .78646 .28051 .79653 .31684 .7936 .31273 Mtetra
.932 .572 .159 r
.7936 .31273 .79653 .31684 .8077 .36346 .80476 .35954 Mtetra
.84 .428 0 r
.80476 .35954 .8077 .36346 .81689 .38576 .81395 .38187 Mtetra
.943 .81 .684 r
.81395 .38187 .81689 .38576 .82285 .37205 .81992 .36804 Mtetra
.985 .751 .501 r
.81992 .36804 .82285 .37205 .82671 .33661 .8238 .33244 Mtetra
.985 .746 .493 r
.8238 .33244 .82671 .33661 .83028 .29968 .8274 .2954 Mtetra
.979 .763 .542 r
.8274 .2954 .83028 .29968 .83469 .27251 .83184 .2682 Mtetra
.952 .79 .645 r
.83184 .2682 .83469 .27251 .84014 .25646 .83731 .25215 Mtetra
.873 .802 .776 r
.83731 .25215 .84014 .25646 .84635 .24814 .84354 .24383 Mtetra
0 .09 .567 r
.23261 .44668 .23634 .4499 .24132 .45397 .23759 .4508 Mtetra
.905 .495 .181 r
.23759 .4508 .24132 .45397 .24569 .46575 .24195 .4625 Mtetra
.94 .605 .366 r
.24195 .4625 .24569 .46575 .24918 .48862 .24546 .48493 Mtetra
.946 .634 .411 r
.24546 .48493 .24918 .48862 .25199 .52107 .2483 .51654 Mtetra
.952 .634 .389 r
.2483 .51654 .25199 .52107 .25507 .5516 .25142 .54617 Mtetra
.677 .242 0 r
.25142 .54617 .25507 .5516 .26001 .55995 .25635 .55445 Mtetra
.899 .703 .628 r
.25635 .55445 .26001 .55995 .26775 .5324 .26403 .52819 Mtetra
.927 .705 .583 r
.26403 .52819 .26775 .5324 .27715 .48161 .27337 .4791 Mtetra
.934 .723 .594 r
.27337 .4791 .27715 .48161 .28554 .44269 .28179 .44039 Mtetra
.796 .829 .877 r
.28179 .44039 .28554 .44269 .29121 .44005 .2876 .43608 Mtetra
.94 .576 .276 r
.2876 .43608 .29121 .44005 .29535 .4595 .29181 .45421 Mtetra
0 .118 .665 r
.29181 .45421 .29535 .4595 .30063 .46355 .29699 .45952 Mtetra
.901 .73 .66 r
.29699 .45952 .30063 .46355 .30752 .44373 .30379 .44152 Mtetra
.914 .78 .699 r
.30379 .44152 .30752 .44373 .3139 .43115 .31025 .42797 Mtetra
.712 .205 0 r
.31025 .42797 .3139 .43115 .31892 .43966 .31539 .43461 Mtetra
0 .227 .747 r
.31539 .43461 .31892 .43966 .32431 .44292 .3207 .43909 Mtetra
.877 .747 .714 r
.3207 .43909 .32431 .44292 .3307 .42979 .32702 .42761 Mtetra
.852 .831 .825 r
.32702 .42761 .3307 .42979 .33657 .42534 .33301 .42134 Mtetra
0 .007 .527 r
.33301 .42134 .33657 .42534 .34183 .43174 .33831 .42687 Mtetra
.714 .695 .831 r
.33831 .42687 .34183 .43174 .34779 .42615 .34415 .42365 Mtetra
.88 .804 .77 r
.34415 .42365 .34779 .42615 .35387 .41828 .35028 .4151 Mtetra
.111 .504 .906 r
.35028 .4151 .35387 .41828 .35933 .4222 .35585 .41706 Mtetra
.558 .625 .875 r
.35585 .41706 .35933 .4222 .36516 .41945 .36156 .41667 Mtetra
.86 .801 .791 r
.36156 .41667 .36516 .41945 .37121 .41226 .36763 .4093 Mtetra
.389 .678 .974 r
.36763 .4093 .37121 .41226 .3768 .41493 .37333 .40968 Mtetra
.565 .624 .87 r
.37333 .40968 .3768 .41493 .38268 .41176 .3791 .40921 Mtetra
.845 .82 .825 r
.3791 .40921 .38268 .41176 .38866 .40637 .38512 .40302 Mtetra
.419 .665 .963 r
.38512 .40302 .38866 .40637 .39433 .40861 .39087 .40341 Mtetra
.641 .659 .852 r
.39087 .40341 .39433 .40861 .4003 .40367 .39673 .4017 Mtetra
.825 .862 .874 r
.39673 .4017 .4003 .40367 .40619 .40127 .40272 .39668 Mtetra
.418 .587 .911 r
.40272 .39668 .40619 .40127 .41198 .40171 .4085 .39761 Mtetra
.726 .738 .861 r
.4085 .39761 .41198 .40171 .41801 .39594 .41445 .39435 Mtetra
.75 .894 .943 r
.41445 .39435 .41801 .39594 .42382 .39681 .42041 .39094 Mtetra
.543 .59 .851 r
.42041 .39094 .42382 .39681 .42977 .39371 .42628 .39084 Mtetra
.812 .814 .852 r
.42628 .39084 .42977 .39371 .43573 .39106 .43231 .38577 Mtetra
.417 .551 .882 r
.43231 .38577 .43573 .39106 .44164 .39015 .43818 .387 Mtetra
.663 .777 .934 r
.43818 .387 .44164 .39015 .44767 .38531 .44415 .38497 Mtetra
.867 .955 .864 r
.44415 .38497 .44767 .38531 .45355 .38706 .45022 .379 Mtetra
.333 .4 .782 r
.45022 .379 .45355 .38706 .45962 .38133 .45609 .38234 Mtetra
.858 .996 .811 r
.45609 .38234 .45962 .38133 .46557 .38161 .4622 .37572 Mtetra
.567 .602 .848 r
.4622 .37572 .46557 .38161 .47159 .37908 .46818 .37525 Mtetra
.603 .718 .925 r
.46818 .37525 .47159 .37908 .47763 .37588 .4742 .37404 Mtetra
.824 .883 .887 r
.4742 .37404 .47763 .37588 .48364 .37593 .48029 .3691 Mtetra
.455 .511 .827 r
.48029 .3691 .48364 .37593 .48972 .37137 .48631 .37045 Mtetra
.85 .937 .881 r
.48631 .37045 .48972 .37137 .49576 .37167 .49242 .36494 Mtetra
.499 .539 .829 r
.49242 .36494 .49576 .37167 .50186 .36755 .49848 .36564 Mtetra
.791 .884 .913 r
.49848 .36564 .50186 .36755 .50794 .36707 .50459 .36144 Mtetra
.579 .621 .857 r
.50459 .36144 .50794 .36707 .51405 .36382 .5107 .36074 Mtetra
.712 .8 .92 r
.5107 .36074 .51405 .36382 .52016 .36252 .51683 .35789 Mtetra
.649 .695 .879 r
.51683 .35789 .52016 .36252 .52629 .36005 .52297 .356 Mtetra
.638 .722 .908 r
.52297 .356 .52629 .36005 .53244 .358 .52912 .3543 Mtetra
.718 .767 .891 r
.52912 .3543 .53244 .358 .5386 .35634 .53528 .35125 Mtetra
.553 .633 .884 r
.53528 .35125 .5386 .35634 .54477 .35338 .54147 .35086 Mtetra
.795 .851 .893 r
.54147 .35086 .54477 .35338 .55096 .35277 .54765 .34643 Mtetra
.475 .542 .845 r
.54765 .34643 .55096 .35277 .55715 .34873 .55389 .34738 Mtetra
.833 .925 .894 r
.55389 .34738 .55715 .34873 .56339 .34899 .56008 .34222 Mtetra
.51 .546 .829 r
.56008 .34222 .56339 .34899 .56959 .34465 .56635 .34276 Mtetra
.693 .882 .968 r
.56635 .34276 .56959 .34465 .57585 .34416 .57259 .33999 Mtetra
.747 .754 .858 r
.57259 .33999 .57585 .34416 .58211 .34183 .57883 .33613 Mtetra
.29 .462 .858 r
.57883 .33613 .58211 .34183 .58835 .33827 .5852 .33891 Mtetra
.903 .984 .775 r
.5852 .33891 .58835 .33827 .5947 .339 .59138 .33091 Mtetra
.414 .453 .792 r
.59138 .33091 .5947 .339 .60093 .33381 .59779 .33334 Mtetra
.572 .927 .947 r
.59779 .33334 .60093 .33381 .6073 .33409 .60411 .33075 Mtetra
.815 .812 .848 r
.60411 .33075 .6073 .33409 .6136 .33095 .61036 .32538 Mtetra
.428 .549 .876 r
.61036 .32538 .6136 .33095 .61997 .3298 .61681 .32669 Mtetra
.796 .825 .874 r
.61681 .32669 .61997 .3298 .62634 .32802 .6231 .32198 Mtetra
.538 .589 .854 r
.6231 .32198 .62634 .32802 .63265 .32384 .62955 .32195 Mtetra
.541 .837 .999 r
.62955 .32195 .63265 .32384 .63915 .3249 .63598 .32055 Mtetra
.787 .762 .83 r
.63598 .32055 .63915 .3249 .64546 .32034 .64228 .31543 Mtetra
.388 .56 .902 r
.64228 .31543 .64546 .32034 .65192 .31919 .64885 .31689 Mtetra
.73 .872 .947 r
.64885 .31689 .65192 .31919 .65844 .3191 .65525 .31359 Mtetra
.73 .699 .821 r
.65525 .31359 .65844 .3191 .66473 .31333 .66162 .30959 Mtetra
.21 .525 .919 r
.66162 .30959 .66473 .31333 .67135 .31471 .66829 .3118 Mtetra
.791 .845 .892 r
.66829 .3118 .67135 .31471 .67785 .3129 .67468 .30728 Mtetra
.719 .692 .823 r
.67468 .30728 .67785 .3129 .68416 .30693 .6811 .30353 Mtetra
.022 .42 .862 r
.6811 .30353 .68416 .30693 .69094 .30995 .6879 .30678 Mtetra
.793 .831 .881 r
.6879 .30678 .69094 .30995 .69746 .30767 .69431 .3021 Mtetra
.769 .714 .8 r
.69431 .3021 .69746 .30767 .70372 .30047 .70069 .29681 Mtetra
0 .285 .775 r
.70069 .29681 .70372 .30047 .71064 .30444 .70765 .3015 Mtetra
.645 .809 .962 r
.70765 .3015 .71064 .30444 .71737 .30477 .71425 .29941 Mtetra
.857 .747 .741 r
.71425 .29941 .71737 .30477 .72347 .29468 .72041 .29015 Mtetra
.18 .455 .88 r
.72041 .29015 .72347 .29468 .7303 .296 .72737 .29334 Mtetra
0 .054 .539 r
.72737 .29334 .7303 .296 .73762 .30407 .73459 .29974 Mtetra
.885 .788 .748 r
.73459 .29974 .73762 .30407 .74385 .29579 .74074 .29016 Mtetra
.857 .741 .734 r
.74074 .29016 .74385 .29579 .74984 .28433 .74689 .28058 Mtetra
.609 .151 0 r
.74689 .28058 .74984 .28433 .75737 .29381 .75449 .29109 Mtetra
.758 .287 0 r
.75449 .29109 .75737 .29381 .76536 .30837 .76234 .30378 Mtetra
.9 .782 .722 r
.76234 .30378 .76536 .30837 .77152 .29866 .76841 .29271 Mtetra
.942 .74 .602 r
.76841 .29271 .77152 .29866 .77658 .27563 .7736 .271 Mtetra
.285 .516 .901 r
.7736 .271 .77658 .27563 .78354 .27626 .78072 .27341 Mtetra
.925 .548 .146 r
.78072 .27341 .78354 .27626 .7936 .31273 .79074 .3097 Mtetra
.935 .57 .174 r
.79074 .3097 .7936 .31273 .80476 .35954 .80172 .35468 Mtetra
.79 .385 0 r
.80172 .35468 .80476 .35954 .81395 .38187 .81077 .37552 Mtetra
.897 .74 .679 r
.81077 .37552 .81395 .38187 .81992 .36804 .81675 .36164 Mtetra
.967 .729 .525 r
.81675 .36164 .81992 .36804 .8238 .33244 .82075 .32693 Mtetra
.976 .736 .509 r
.82075 .32693 .8238 .33244 .8274 .2954 .82448 .2908 Mtetra
.975 .76 .549 r
.82448 .2908 .8274 .2954 .83184 .2682 .82899 .26407 Mtetra
.955 .796 .646 r
.82899 .26407 .83184 .2682 .83731 .25215 .8345 .24812 Mtetra
.881 .816 .78 r
.8345 .24812 .83731 .25215 .84354 .24383 .84074 .23975 Mtetra
0 .272 .77 r
.22895 .44249 .23261 .44668 .23759 .4508 .23398 .44605 Mtetra
.886 .47 .06 r
.23398 .44605 .23759 .4508 .24195 .4625 .23837 .45729 Mtetra
.955 .619 .333 r
.23837 .45729 .24195 .4625 .24546 .48493 .24182 .48004 Mtetra
.954 .645 .407 r
.24182 .48004 .24546 .48493 .2483 .51654 .24447 .51347 Mtetra
.942 .631 .419 r
.24447 .51347 .2483 .51654 .25142 .54617 .24729 .54633 Mtetra
.858 .458 .28 r
.24729 .54633 .25142 .54617 .25635 .55445 .25201 .55732 Mtetra
.974 .806 .612 r
.25201 .55732 .25635 .55445 .26403 .52819 .25977 .53058 Mtetra
.959 .743 .567 r
.25977 .53058 .26403 .52819 .27337 .4791 .26947 .47783 Mtetra
.942 .73 .587 r
.26947 .47783 .27337 .4791 .28179 .44039 .27818 .43603 Mtetra
.74 .719 .832 r
.27818 .43603 .28179 .44039 .2876 .43608 .28395 .43233 Mtetra
.943 .592 .316 r
.28395 .43233 .2876 .43608 .29181 .45421 .28797 .4529 Mtetra
.681 .133 0 r
.28797 .4529 .29181 .45421 .29699 .45952 .29319 .45768 Mtetra
.933 .761 .645 r
.29319 .45768 .29699 .45952 .30379 .44152 .30021 .43686 Mtetra
.873 .723 .693 r
.30021 .43686 .30379 .44152 .31025 .42797 .30666 .42375 Mtetra
.813 .359 0 r
.30666 .42375 .31025 .42797 .31539 .43461 .31161 .43311 Mtetra
.459 0 0 r
.31161 .43311 .31539 .43461 .3207 .43909 .31701 .43627 Mtetra
.908 .766 .692 r
.31701 .43627 .3207 .43909 .32702 .42761 .32351 .42216 Mtetra
.725 .678 .804 r
.32351 .42216 .32702 .42761 .33301 .42134 .32936 .41839 Mtetra
.739 .234 0 r
.32936 .41839 .33301 .42134 .33831 .42687 .33458 .42536 Mtetra
.878 .861 .82 r
.33458 .42536 .33831 .42687 .34415 .42365 .34064 .41844 Mtetra
.812 .709 .751 r
.34064 .41844 .34415 .42365 .35028 .4151 .34672 .41094 Mtetra
0 .095 .621 r
.34672 .41094 .35028 .4151 .35585 .41706 .35213 .41601 Mtetra
.805 .918 .914 r
.35213 .41601 .35585 .41706 .36156 .41667 .35806 .41166 Mtetra
.807 .715 .764 r
.35806 .41166 .36156 .41667 .36763 .4093 .36412 .40476 Mtetra
0 .267 .772 r
.36412 .40476 .36763 .4093 .37333 .40968 .36964 .40887 Mtetra
.843 .927 .886 r
.36964 .40887 .37333 .40968 .3791 .40921 .37564 .40363 Mtetra
.744 .683 .792 r
.37564 .40363 .3791 .40921 .38512 .40302 .3816 .39915 Mtetra
0 .347 .819 r
.3816 .39915 .38512 .40302 .39087 .40341 .38723 .40247 Mtetra
.899 .894 .815 r
.38723 .40247 .39087 .40341 .39673 .4017 .39333 .39503 Mtetra
.543 .561 .823 r
.39333 .39503 .39673 .4017 .40272 .39668 .39913 .39502 Mtetra
.398 .779 .991 r
.39913 .39502 .40272 .39668 .4085 .39761 .40497 .39458 Mtetra
.857 .798 .792 r
.40497 .39458 .4085 .39761 .41445 .39435 .41108 .38728 Mtetra
.192 .343 .788 r
.41108 .38728 .41445 .39435 .42041 .39094 .41679 .39143 Mtetra
.868 .983 .842 r
.41679 .39143 .42041 .39094 .42628 .39084 .42287 .38512 Mtetra
.516 .583 .861 r
.42287 .38512 .42628 .39084 .43231 .38577 .42875 .38535 Mtetra
.641 .943 .957 r
.42875 .38535 .43231 .38577 .43818 .387 .43473 .38254 Mtetra
.811 .742 .787 r
.43473 .38254 .43818 .387 .44415 .38497 .44082 .37618 Mtetra
0 .125 .658 r
.44082 .37618 .44415 .38497 .45022 .379 .44656 .38395 Mtetra
.896 .926 .541 r
.44656 .38395 .45022 .379 .45609 .38234 .45284 .37048 Mtetra
.211 .244 .678 r
.45284 .37048 .45609 .38234 .4622 .37572 .45865 .37748 Mtetra
.752 .985 .759 r
.45865 .37748 .4622 .37572 .46818 .37525 .46476 .37151 Mtetra
.741 .765 .873 r
.46476 .37151 .46818 .37525 .4742 .37404 .47083 .36799 Mtetra
.27 .433 .84 r
.47083 .36799 .4742 .37404 .48029 .3691 .47681 .37097 Mtetra
.912 .98 .72 r
.47681 .37097 .48029 .3691 .48631 .37045 .48297 .36184 Mtetra
.229 .321 .751 r
.48297 .36184 .48631 .37045 .49242 .36494 .48897 .36677 Mtetra
.889 .987 .728 r
.48897 .36677 .49242 .36494 .49848 .36564 .49513 .3583 Mtetra
.351 .434 .807 r
.49513 .3583 .49848 .36564 .50459 .36144 .5012 .36114 Mtetra
.853 .97 .871 r
.5012 .36114 .50459 .36144 .5107 .36074 .50735 .35537 Mtetra
.515 .602 .878 r
.50735 .35537 .5107 .36074 .51683 .35789 .51347 .35553 Mtetra
.726 .852 .941 r
.51347 .35553 .51683 .35789 .52297 .356 .51962 .35245 Mtetra
.683 .766 .914 r
.51962 .35245 .52297 .356 .52912 .3543 .52579 .35004 Mtetra
.532 .667 .924 r
.52579 .35004 .52912 .3543 .53528 .35125 .53197 .34973 Mtetra
.839 .912 .886 r
.53197 .34973 .53528 .35125 .54147 .35086 .53815 .34443 Mtetra
.323 .451 .835 r
.53815 .34443 .54147 .35086 .54765 .34643 .54438 .34721 Mtetra
.905 .983 .775 r
.54438 .34721 .54765 .34643 .55389 .34738 .55056 .33918 Mtetra
.269 .359 .772 r
.55056 .33918 .55389 .34738 .56008 .34222 .55685 .34357 Mtetra
.843 .995 .755 r
.55685 .34357 .56008 .34222 .56635 .34276 .56304 .33629 Mtetra
.535 .57 .838 r
.56304 .33629 .56635 .34276 .57259 .33999 .56933 .33637 Mtetra
.41 .65 .956 r
.56933 .33637 .57259 .33999 .57883 .33613 .57565 .33695 Mtetra
.941 .962 .729 r
.57565 .33695 .57883 .33613 .5852 .33891 .58181 .32716 Mtetra
.175 .226 .677 r
.58181 .32716 .5852 .33891 .59138 .33091 .58831 .33527 Mtetra
.754 .88 .466 r
.58831 .33527 .59138 .33091 .59779 .33334 .59444 .32419 Mtetra
.471 .463 .768 r
.59444 .32419 .59779 .33334 .60411 .33075 .60086 .32593 Mtetra
.6 .672 .891 r
.60086 .32593 .60411 .33075 .61036 .32538 .60724 .32479 Mtetra
.749 .972 .926 r
.60724 .32479 .61036 .32538 .61681 .32669 .61355 .32063 Mtetra
.44 .536 .859 r
.61355 .32063 .61681 .32669 .6231 .32198 .62003 .32197 Mtetra
.894 .98 .811 r
.62003 .32197 .6231 .32198 .62955 .32195 .62626 .31462 Mtetra
.398 .467 .815 r
.62626 .31462 .62955 .32195 .63598 .32055 .63282 .31701 Mtetra
.741 .794 .895 r
.63282 .31701 .63598 .32055 .64228 .31543 .63919 .31346 Mtetra
.75 .897 .944 r
.63919 .31346 .64228 .31543 .64885 .31689 .64557 .3098 Mtetra
.397 .475 .823 r
.64557 .3098 .64885 .31689 .65525 .31359 .65221 .31212 Mtetra
.883 .926 .846 r
.65221 .31212 .65525 .31359 .66162 .30959 .65849 .3054 Mtetra
.47 .647 .935 r
.65849 .3054 .66162 .30959 .66829 .3118 .66508 .30568 Mtetra
.518 .579 .855 r
.66508 .30568 .66829 .3118 .67468 .30728 .67169 .30595 Mtetra
.9 .931 .827 r
.67169 .30595 .67468 .30728 .6811 .30353 .67796 .29862 Mtetra
.279 .497 .889 r
.67796 .29862 .6811 .30353 .6879 .30678 .68472 .30114 Mtetra
.571 .626 .868 r
.68472 .30114 .6879 .30678 .69431 .3021 .69136 .30048 Mtetra
.917 .911 .799 r
.69136 .30048 .69431 .3021 .70069 .29681 .69759 .29223 Mtetra
.154 .436 .872 r
.69759 .29223 .70069 .29681 .70765 .3015 .70448 .29561 Mtetra
.416 .532 .867 r
.70448 .29561 .70765 .3015 .71425 .29941 .71131 .29723 Mtetra
.94 .87 .742 r
.71131 .29723 .71425 .29941 .72041 .29015 .71742 .28674 Mtetra
.406 .666 .966 r
.71742 .28674 .72041 .29015 .72737 .29334 .72421 .28723 Mtetra
0 .079 .639 r
.72421 .28723 .72737 .29334 .73459 .29974 .73159 .29608 Mtetra
.876 .819 .788 r
.73159 .29608 .73459 .29974 .74074 .29016 .73787 .28803 Mtetra
.957 .863 .704 r
.73787 .28803 .74074 .29016 .74689 .28058 .74385 .27582 Mtetra
0 0 .513 r
.74385 .27582 .74689 .28058 .75449 .29109 .7514 .2856 Mtetra
.664 .266 0 r
.7514 .2856 .75449 .29109 .76234 .30378 .75944 .30097 Mtetra
.93 .855 .746 r
.75944 .30097 .76234 .30378 .76841 .29271 .7656 .29065 Mtetra
.99 .8 .554 r
.7656 .29065 .76841 .29271 .7736 .271 .77064 .26665 Mtetra
.346 .571 .923 r
.77064 .26665 .7736 .271 .78072 .27341 .7777 .26828 Mtetra
.913 .548 .103 r
.7777 .26828 .78072 .27341 .79074 .3097 .78794 .30742 Mtetra
.941 .579 .2 r
.78794 .30742 .79074 .3097 .80172 .35468 .79921 .35607 Mtetra
.889 .466 .169 r
.79921 .35607 .80172 .35468 .81077 .37552 .80833 .37764 Mtetra
.943 .9 .508 r
.80833 .37764 .81077 .37552 .81675 .36164 .81413 .36127 Mtetra
.998 .774 .449 r
.81413 .36127 .81675 .36164 .82075 .32693 .81788 .32337 Mtetra
.988 .75 .483 r
.81788 .32337 .82075 .32693 .82448 .2908 .82146 .28532 Mtetra
.967 .747 .553 r
.82146 .28532 .82448 .2908 .82899 .26407 .82596 .25816 Mtetra
.921 .751 .654 r
.82596 .25816 .82899 .26407 .8345 .24812 .83153 .24258 Mtetra
.836 .749 .767 r
.83153 .24258 .8345 .24812 .84074 .23975 .83784 .23473 Mtetra
0 .205 .674 r
.22518 .43933 .22895 .44249 .23398 .44605 .23022 .44279 Mtetra
.889 .462 .126 r
.23022 .44279 .23398 .44605 .23837 .45729 .23467 .45327 Mtetra
.945 .602 .337 r
.23467 .45327 .23837 .45729 .24182 .48004 .23826 .47413 Mtetra
.961 .646 .381 r
.23826 .47413 .24182 .48004 .24447 .51347 .24111 .50472 Mtetra
.972 .659 .336 r
.24111 .50472 .24447 .51347 .24729 .54633 .24406 .53553 Mtetra
0 0 .356 r
.24406 .53553 .24729 .54633 .25201 .55732 .24864 .54798 Mtetra
.852 .658 .64 r
.24864 .54798 .25201 .55732 .25977 .53058 .25598 .52677 Mtetra
.928 .709 .585 r
.25598 .52677 .25977 .53058 .26947 .47783 .26534 .47919 Mtetra
.957 .749 .58 r
.26534 .47919 .26947 .47783 .27818 .43603 .27418 .4366 Mtetra
.939 .903 .762 r
.27418 .4366 .27818 .43603 .28395 .43233 .28041 .4269 Mtetra
.94 .573 .214 r
.28041 .4269 .28395 .43233 .28797 .4529 .28463 .4444 Mtetra
0 0 .442 r
.28463 .4444 .28797 .4529 .29319 .45768 .28949 .45416 Mtetra
.902 .743 .674 r
.28949 .45416 .29319 .45768 .30021 .43686 .29621 .43801 Mtetra
.968 .836 .66 r
.29621 .43801 .30021 .43686 .30666 .42375 .30298 .42064 Mtetra
.482 0 0 r
.30298 .42064 .30666 .42375 .31161 .43311 .30825 .42525 Mtetra
0 0 .562 r
.30825 .42525 .31161 .43311 .31701 .43627 .31332 .43327 Mtetra
.886 .775 .734 r
.31332 .43327 .31701 .43627 .32351 .42216 .31961 .42281 Mtetra
.945 .91 .754 r
.31961 .42281 .32351 .42216 .32936 .41839 .32586 .41281 Mtetra
0 .054 .614 r
.32586 .41281 .32936 .41839 .33458 .42536 .33113 .41891 Mtetra
.544 .568 .829 r
.33113 .41891 .33458 .42536 .34064 .41844 .3368 .41885 Mtetra
.951 .887 .733 r
.3368 .41885 .34064 .41844 .34672 .41094 .34311 .40763 Mtetra
.345 .632 .96 r
.34311 .40763 .34672 .41094 .35213 .41601 .34875 .40844 Mtetra
.316 .403 .793 r
.34875 .40844 .35213 .41601 .35806 .41166 .35429 .41155 Mtetra
.934 .895 .766 r
.35429 .41155 .35806 .41166 .36412 .40476 .3605 .40202 Mtetra
.562 .769 .975 r
.3605 .40202 .36412 .40476 .36964 .40887 .36628 .40104 Mtetra
.33 .404 .787 r
.36628 .40104 .36964 .40887 .37564 .40363 .37188 .40415 Mtetra
.936 .931 .773 r
.37188 .40415 .37564 .40363 .3816 .39915 .37806 .39511 Mtetra
.472 .647 .934 r
.37806 .39511 .3816 .39915 .38723 .40247 .38383 .39535 Mtetra
.457 .501 .816 r
.38383 .39535 .38723 .40247 .39333 .39503 .38957 .39668 Mtetra
.93 .97 .748 r
.38957 .39668 .39333 .39503 .39913 .39502 .39576 .38757 Mtetra
.252 .368 .788 r
.39576 .38757 .39913 .39502 .40497 .39458 .40143 .39135 Mtetra
.722 .785 .902 r
.40143 .39135 .40497 .39458 .41108 .38728 .40739 .38836 Mtetra
.871 .993 .811 r
.40739 .38836 .41108 .38728 .41679 .39143 .41349 .38155 Mtetra
.327 .353 .736 r
.41349 .38155 .41679 .39143 .42287 .38512 .41923 .38569 Mtetra
.944 .934 .758 r
.41923 .38569 .42287 .38512 .42875 .38535 .42543 .37612 Mtetra
.131 .24 .711 r
.42543 .37612 .42875 .38535 .43473 .38254 .43115 .38231 Mtetra
.584 .932 .946 r
.43115 .38231 .43473 .38254 .44082 .37618 .43716 .37975 Mtetra
.897 .959 .624 r
.43716 .37975 .44082 .37618 .44656 .38395 .44339 .36881 Mtetra
.03 .079 .579 r
.44339 .36881 .44656 .38395 .45284 .37048 .44905 .38083 Mtetra
0 0 0 r
.44905 .38083 .45284 .37048 .45865 .37748 .45539 .36514 Mtetra
.316 .308 .691 r
.45539 .36514 .45865 .37748 .46476 .37151 .46127 .37066 Mtetra
.762 .946 .939 r
.46127 .37066 .46476 .37151 .47083 .36799 .46736 .36677 Mtetra
.861 .914 .865 r
.46736 .36677 .47083 .36799 .47681 .37097 .47348 .36088 Mtetra
.348 .365 .736 r
.47348 .36088 .47681 .37097 .48297 .36184 .47947 .36491 Mtetra
.849 .965 .637 r
.47947 .36491 .48297 .36184 .48897 .36677 .48566 .35552 Mtetra
.361 .354 .716 r
.48566 .35552 .48897 .36677 .49513 .3583 .49169 .35985 Mtetra
.859 .995 .757 r
.49169 .35985 .49513 .3583 .5012 .36114 .49786 .35237 Mtetra
.47 .468 .774 r
.49786 .35237 .5012 .36114 .50735 .35537 .50396 .35396 Mtetra
.795 .919 .921 r
.50396 .35396 .50735 .35537 .51347 .35553 .51011 .34964 Mtetra
.621 .632 .84 r
.51011 .34964 .51347 .35553 .51962 .35245 .51627 .34817 Mtetra
.599 .696 .911 r
.51627 .34817 .51962 .35245 .52579 .35004 .52244 .34702 Mtetra
.794 .82 .873 r
.52244 .34702 .52579 .35004 .53197 .34973 .52862 .34242 Mtetra
.405 .469 .814 r
.52862 .34242 .53197 .34973 .53815 .34443 .53483 .3446 Mtetra
.907 .97 .804 r
.53483 .3446 .53815 .34443 .54438 .34721 .54102 .33696 Mtetra
.326 .35 .733 r
.54102 .33696 .54438 .34721 .55056 .33918 .54729 .34157 Mtetra
.8 .969 .663 r
.54729 .34157 .55056 .33918 .55685 .34357 .55349 .33353 Mtetra
.468 .444 .748 r
.55349 .33353 .55685 .34357 .56304 .33629 .55978 .33549 Mtetra
.334 .796 .938 r
.55978 .33549 .56304 .33629 .56933 .33637 .56607 .33462 Mtetra
.919 .873 .775 r
.56607 .33462 .56933 .33637 .57565 .33695 .57226 .32557 Mtetra
0 .072 .606 r
.57226 .32557 .57565 .33695 .58181 .32716 .57878 .33676 Mtetra
0 0 0 r
.57878 .33676 .58181 .32716 .58831 .33527 .58484 .32036 Mtetra
.305 .277 .662 r
.58484 .32036 .58831 .33527 .59444 .32419 .59136 .32779 Mtetra
.136 0 0 r
.59136 .32779 .59444 .32419 .60086 .32593 .59771 .32548 Mtetra
.951 .921 .744 r
.59771 .32548 .60086 .32593 .60724 .32479 .60387 .31531 Mtetra
.246 .315 .738 r
.60387 .31531 .60724 .32479 .61355 .32063 .61045 .3209 Mtetra
.927 .968 .764 r
.61045 .3209 .61355 .32063 .62003 .32197 .61665 .31213 Mtetra
.403 .409 .752 r
.61665 .31213 .62003 .32197 .62626 .31462 .62321 .31536 Mtetra
.205 .725 .705 r
.62321 .31536 .62626 .31462 .63282 .31701 .62965 .3136 Mtetra
.872 .815 .79 r
.62965 .3136 .63282 .31701 .63919 .31346 .63589 .30575 Mtetra
.181 .32 .77 r
.63589 .30575 .63919 .31346 .64557 .3098 .64261 .3111 Mtetra
.743 .98 .74 r
.64261 .3111 .64557 .3098 .65221 .31212 .64892 .30482 Mtetra
.7 .633 .779 r
.64892 .30482 .65221 .31212 .65849 .3054 .65532 .30097 Mtetra
0 .285 .784 r
.65532 .30097 .65849 .3054 .66508 .30568 .66212 .30587 Mtetra
.904 .983 .78 r
.66212 .30587 .66508 .30568 .67169 .30595 .66838 .29785 Mtetra
.645 .588 .776 r
.66838 .29785 .67169 .30595 .67796 .29862 .67489 .29543 Mtetra
0 .182 .677 r
.67489 .29543 .67796 .29862 .68472 .30114 .6818 .30068 Mtetra
.916 .964 .794 r
.6818 .30068 .68472 .30114 .69136 .30048 .68806 .29257 Mtetra
.701 .621 .765 r
.68806 .29257 .69136 .30048 .69759 .29223 .69452 .28843 Mtetra
0 .048 .578 r
.69452 .28843 .69759 .29223 .70448 .29561 .70164 .29564 Mtetra
.765 .996 .859 r
.70164 .29564 .70448 .29561 .71131 .29723 .70808 .2904 Mtetra
.835 .703 .718 r
.70808 .2904 .71131 .29723 .71742 .28674 .71425 .28063 Mtetra
0 .215 .737 r
.71425 .28063 .71742 .28674 .72421 .28723 .72144 .28744 Mtetra
.625 .062 0 r
.72144 .28744 .72421 .28723 .73159 .29608 .7286 .29271 Mtetra
.941 .816 .693 r
.7286 .29271 .73159 .29608 .73787 .28803 .73456 .27965 Mtetra
.771 .648 .726 r
.73456 .27965 .73787 .28803 .74385 .27582 .74088 .27216 Mtetra
.755 .309 0 r
.74088 .27216 .74385 .27582 .7514 .2856 .74875 .28639 Mtetra
.801 .315 .038 r
.74875 .28639 .7514 .2856 .75944 .30097 .75645 .29706 Mtetra
.948 .796 .658 r
.75645 .29706 .75944 .30097 .7656 .29065 .76223 .28155 Mtetra
.898 .689 .612 r
.76223 .28155 .7656 .29065 .77064 .26665 .76753 .26061 Mtetra
0 .161 .7 r
.76753 .26061 .77064 .26665 .7777 .26828 .7751 .26852 Mtetra
.937 .563 .228 r
.7751 .26852 .7777 .26828 .78794 .30742 .78542 .30867 Mtetra
.938 .566 .247 r
.78542 .30867 .78794 .30742 .79921 .35607 .79621 .35197 Mtetra
.726 .291 0 r
.79621 .35197 .79921 .35607 .80833 .37764 .8048 .36753 Mtetra
.871 .673 .632 r
.8048 .36753 .80833 .37764 .81413 .36127 .81044 .34932 Mtetra
.925 .677 .545 r
.81044 .34932 .81413 .36127 .81788 .32337 .81439 .31338 Mtetra
.94 .694 .539 r
.81439 .31338 .81788 .32337 .82146 .28532 .81829 .27825 Mtetra
.946 .727 .575 r
.81829 .27825 .82146 .28532 .82596 .25816 .82301 .25311 Mtetra
.932 .775 .665 r
.82301 .25311 .82596 .25816 .83153 .24258 .82868 .23839 Mtetra
.865 .808 .793 r
.82868 .23839 .83153 .24258 .83784 .23473 .83502 .23066 Mtetra
.012 .375 .841 r
.22149 .43518 .22518 .43933 .23022 .44279 .22658 .43805 Mtetra
.865 .438 .01 r
.22658 .43805 .23022 .44279 .23467 .45327 .23102 .44844 Mtetra
.952 .614 .335 r
.23102 .44844 .23467 .45327 .23826 .47413 .23447 .47066 Mtetra
.945 .637 .423 r
.23447 .47066 .23826 .47413 .24111 .50472 .23699 .50475 Mtetra
.922 .617 .448 r
.23699 .50475 .24111 .50472 .24406 .53553 .23952 .54012 Mtetra
.827 .483 .404 r
.23952 .54012 .24406 .53553 .24864 .54798 .24392 .55485 Mtetra
.994 .871 .583 r
.24392 .55485 .24864 .54798 .25598 .52677 .25155 .53067 Mtetra
.966 .751 .563 r
.25155 .53067 .25598 .52677 .26534 .47919 .26146 .47707 Mtetra
.938 .721 .583 r
.26146 .47707 .26534 .47919 .27418 .4366 .27059 .43147 Mtetra
.81 .707 .751 r
.27059 .43147 .27418 .4366 .28041 .4269 .27667 .42406 Mtetra
.935 .581 .327 r
.27667 .42406 .28041 .4269 .28463 .4444 .2807 .44382 Mtetra
.792 .31 .077 r
.2807 .44382 .28463 .4444 .28949 .45416 .28578 .45053 Mtetra
.909 .736 .654 r
.28578 .45053 .28949 .45416 .29621 .43801 .29275 .43125 Mtetra
.848 .683 .677 r
.29275 .43125 .29621 .43801 .30298 .42064 .2993 .41731 Mtetra
.773 .285 0 r
.2993 .41731 .30298 .42064 .30825 .42525 .30436 .42496 Mtetra
.578 .006 0 r
.30436 .42496 .30825 .42525 .31332 .43327 .30975 .42821 Mtetra
.865 .717 .697 r
.30975 .42821 .31332 .43327 .31961 .42281 .31619 .41568 Mtetra
.703 .624 .766 r
.31619 .41568 .31961 .42281 .32586 .41281 .32206 .41187 Mtetra
.715 .183 0 r
.32206 .41187 .32586 .41281 .33113 .41891 .32738 .41713 Mtetra
.864 .854 .83 r
.32738 .41713 .33113 .41891 .3368 .41885 .33343 .41069 Mtetra
.737 .62 .729 r
.33343 .41069 .3368 .41885 .34311 .40763 .33945 .40486 Mtetra
0 .21 .659 r
.33945 .40486 .34311 .40763 .34875 .40844 .34494 .40841 Mtetra
.834 .967 .888 r
.34494 .40841 .34875 .40844 .35429 .41155 .35093 .40324 Mtetra
.707 .604 .739 r
.35093 .40324 .35429 .41155 .3605 .40202 .35689 .39871 Mtetra
0 .387 .834 r
.35689 .39871 .3605 .40202 .36628 .40104 .36249 .40151 Mtetra
.881 .972 .839 r
.36249 .40151 .36628 .40104 .37188 .40415 .36856 .39497 Mtetra
.612 .539 .748 r
.36856 .39497 .37188 .40415 .37806 .39511 .3744 .39343 Mtetra
.03 .551 .864 r
.3744 .39343 .37806 .39511 .38383 .39535 .38014 .39463 Mtetra
.909 .898 .804 r
.38014 .39463 .38383 .39535 .38957 .39668 .38629 .38669 Mtetra
.395 .395 .741 r
.38629 .38669 .38957 .39668 .39576 .38757 .39197 .38976 Mtetra
.527 .892 .683 r
.39197 .38976 .39576 .38757 .40143 .39135 .39799 .38535 Mtetra
.748 .675 .78 r
.39799 .38535 .40143 .39135 .40739 .38836 .40402 .38047 Mtetra
.154 .292 .753 r
.40402 .38047 .40739 .38836 .41349 .38155 .40971 .38544 Mtetra
.822 .951 .605 r
.40971 .38544 .41349 .38155 .41923 .38569 .41592 .37593 Mtetra
.214 .283 .719 r
.41592 .37593 .41923 .38569 .42543 .37612 .42164 .38146 Mtetra
.635 .836 .435 r
.42164 .38146 .42543 .37612 .43115 .38231 .42785 .37216 Mtetra
.605 .521 .733 r
.42785 .37216 .43115 .38231 .43716 .37975 .43382 .37068 Mtetra
0 .01 .58 r
.43382 .37068 .43716 .37975 .44339 .36881 .43952 .38011 Mtetra
.741 .771 .27 r
.43952 .38011 .44339 .36881 .44905 .38083 .44601 .35965 Mtetra
.018 .027 .523 r
.44601 .35965 .44905 .38083 .45539 .36514 .45159 .37672 Mtetra
0 0 0 r
.45159 .37672 .45539 .36514 .46127 .37066 .45793 .36134 Mtetra
.426 .429 .76 r
.45793 .36134 .46127 .37066 .46736 .36677 .4639 .36379 Mtetra
.399 .688 .977 r
.4639 .36379 .46736 .36677 .47348 .36088 .46993 .36408 Mtetra
.867 .964 .633 r
.46993 .36408 .47348 .36088 .47947 .36491 .47615 .35419 Mtetra
.159 .229 .688 r
.47615 .35419 .47947 .36491 .48566 .35552 .48212 .36125 Mtetra
.729 .855 .425 r
.48212 .36125 .48566 .35552 .49169 .35985 .48835 .34953 Mtetra
.248 .297 .717 r
.48835 .34953 .49169 .35985 .49786 .35237 .4944 .35517 Mtetra
.798 .963 .648 r
.4944 .35517 .49786 .35237 .50396 .35396 .50059 .34694 Mtetra
.441 .5 .824 r
.50059 .34694 .50396 .35396 .51011 .34964 .50672 .34849 Mtetra
.741 .934 .951 r
.50672 .34849 .51011 .34964 .51627 .34817 .5129 .3449 Mtetra
.717 .794 .912 r
.5129 .3449 .51627 .34817 .52244 .34702 .51908 .34192 Mtetra
.402 .558 .895 r
.51908 .34192 .52244 .34702 .52862 .34242 .52527 .34321 Mtetra
.891 .988 .788 r
.52527 .34321 .52862 .34242 .53483 .3446 .53148 .33563 Mtetra
.198 .295 .738 r
.53148 .33563 .53483 .3446 .54102 .33696 .53773 .34126 Mtetra
.744 .891 .494 r
.53773 .34126 .54102 .33696 .54729 .34157 .54393 .33102 Mtetra
.281 .316 .721 r
.54393 .33102 .54729 .34157 .55349 .33353 .55023 .33647 Mtetra
0 0 0 r
.55023 .33647 .55349 .33353 .55978 .33549 .55647 .33117 Mtetra
.786 .758 .828 r
.55647 .33117 .55978 .33549 .56607 .33462 .56272 .32607 Mtetra
0 .076 .63 r
.56272 .32607 .56607 .33462 .57226 .32557 .56917 .33528 Mtetra
.689 .733 .222 r
.56917 .33528 .57226 .32557 .57878 .33676 .57522 .31589 Mtetra
.148 .128 .577 r
.57522 .31589 .57878 .33676 .58484 .32036 .58184 .33092 Mtetra
0 0 .026 r
.58184 .33092 .58484 .32036 .59136 .32779 .58798 .3181 Mtetra
.652 .56 .738 r
.58798 .3181 .59136 .32779 .59771 .32548 .59431 .31506 Mtetra
.288 .325 .726 r
.59431 .31506 .59771 .32548 .60387 .31531 .60086 .32049 Mtetra
0 0 0 r
.60086 .32049 .60387 .31531 .61045 .3209 .60706 .3109 Mtetra
.337 .364 .742 r
.60706 .3109 .61045 .3209 .61665 .31213 .61364 .31533 Mtetra
.659 .884 .526 r
.61364 .31533 .61665 .31213 .62321 .31536 .61988 .30725 Mtetra
.556 .538 .79 r
.61988 .30725 .62321 .31536 .62965 .3136 .62637 .30706 Mtetra
.504 .556 .842 r
.62637 .30706 .62965 .3136 .63589 .30575 .6329 .3076 Mtetra
.726 .959 .678 r
.6329 .3076 .63589 .30575 .64261 .3111 .63919 .30075 Mtetra
.439 .423 .745 r
.63919 .30075 .64261 .3111 .64892 .30482 .64585 .30345 Mtetra
.786 .942 .928 r
.64585 .30345 .64892 .30482 .65532 .30097 .65225 .29903 Mtetra
.691 .89 .97 r
.65225 .29903 .65532 .30097 .66212 .30587 .65873 .29612 Mtetra
.485 .463 .758 r
.65873 .29612 .66212 .30587 .66838 .29785 .66541 .29769 Mtetra
.825 .994 .857 r
.66541 .29769 .66838 .29785 .67489 .29543 .67178 .29184 Mtetra
.487 .697 .962 r
.67178 .29184 .67489 .29543 .6818 .30068 .67843 .29167 Mtetra
.54 .511 .772 r
.67843 .29167 .6818 .30068 .68806 .29257 .68513 .29188 Mtetra
.871 .974 .849 r
.68513 .29188 .68806 .29257 .69452 .28843 .69148 .28535 Mtetra
.255 .603 .953 r
.69148 .28535 .69452 .28843 .70164 .29564 .69828 .28673 Mtetra
.502 .492 .778 r
.69828 .28673 .70164 .29564 .70808 .2904 .70509 .28779 Mtetra
.905 .866 .79 r
.70509 .28779 .70808 .2904 .71425 .28063 .71135 .27933 Mtetra
.173 .672 .914 r
.71135 .27933 .71425 .28063 .72144 .28744 .71816 .27968 Mtetra
.083 .256 .742 r
.71816 .27968 .72144 .28744 .7286 .29271 .72541 .28657 Mtetra
.82 .718 .753 r
.72541 .28657 .7286 .29271 .73456 .27965 .73173 .27866 Mtetra
.952 .926 .74 r
.73173 .27866 .73456 .27965 .74088 .27216 .73789 .26843 Mtetra
.604 .142 0 r
.73789 .26843 .74088 .27216 .74875 .28639 .74548 .27872 Mtetra
0 0 .507 r
.74548 .27872 .74875 .28639 .75645 .29706 .75338 .29211 Mtetra
.904 .772 .705 r
.75338 .29211 .75645 .29706 .76223 .28155 .75943 .28 Mtetra
.993 .814 .558 r
.75943 .28 .76223 .28155 .76753 .26061 .76462 .25725 Mtetra
0 .224 .721 r
.76462 .25725 .76753 .26061 .7751 .26852 .772 .26263 Mtetra
.914 .556 .106 r
.772 .26263 .7751 .26852 .78542 .30867 .78249 .30519 Mtetra
.938 .578 .18 r
.78249 .30519 .78542 .30867 .79621 .35197 .79375 .35428 Mtetra
.871 .441 .18 r
.79375 .35428 .79621 .35197 .8048 .36753 .80263 .37316 Mtetra
.806 .793 .296 r
.80263 .37316 .8048 .36753 .81044 .34932 .80817 .35319 Mtetra
.981 .779 .368 r
.80817 .35319 .81044 .34932 .81439 .31338 .81179 .31298 Mtetra
.997 .771 .443 r
.81179 .31298 .81439 .31338 .81829 .27825 .8154 .27436 Mtetra
.982 .771 .543 r
.8154 .27436 .81829 .27825 .82301 .25311 .82001 .24772 Mtetra
.926 .766 .664 r
.82001 .24772 .82301 .25311 .82868 .23839 .8257 .23294 Mtetra
.825 .75 .781 r
.8257 .23294 .82868 .23839 .83502 .23066 .8321 .2257 Mtetra
.2 .497 .904 r
.21778 .43108 .22149 .43518 .22658 .43805 .22296 .43302 Mtetra
.724 .277 0 r
.22296 .43302 .22658 .43805 .23102 .44844 .22761 .44102 Mtetra
.942 .59 .187 r
.22761 .44102 .23102 .44844 .23447 .47066 .23139 .45917 Mtetra
.97 .665 .279 r
.23139 .45917 .23447 .47066 .23699 .50475 .23422 .48909 Mtetra
.96 .678 .245 r
.23422 .48909 .23699 .50475 .23952 .54012 .23672 .52418 Mtetra
.722 .488 0 r
.23672 .52418 .23952 .54012 .24392 .55485 .24045 .54628 Mtetra
.807 .648 .684 r
.24045 .54628 .24392 .55485 .25155 .53067 .24709 .53445 Mtetra
.968 .76 .57 r
.24709 .53445 .25155 .53067 .26146 .47707 .25655 .48753 Mtetra
.992 .793 .536 r
.25655 .48753 .26146 .47707 .27059 .43147 .26625 .43574 Mtetra
.989 .876 .625 r
.26625 .43574 .27059 .43147 .27667 .42406 .27326 .41657 Mtetra
.928 .571 .141 r
.27326 .41657 .27667 .42406 .2807 .44382 .27741 .43454 Mtetra
.864 .526 .014 r
.27741 .43454 .2807 .44382 .28578 .45053 .28169 .45182 Mtetra
.967 .86 .682 r
.28169 .45182 .28578 .45053 .29275 .43125 .28839 .4367 Mtetra
.994 .857 .588 r
.28839 .4367 .29275 .43125 .2993 .41731 .2957 .41267 Mtetra
.011 .345 .823 r
.2957 .41267 .2993 .41731 .30436 .42496 .30104 .41604 Mtetra
.715 .384 0 r
.30104 .41604 .30436 .42496 .30975 .42821 .30573 .4296 Mtetra
.958 .915 .728 r
.30573 .4296 .30975 .42821 .31619 .41568 .31212 .41834 Mtetra
.979 .898 .666 r
.31212 .41834 .31619 .41568 .32206 .41187 .31871 .40347 Mtetra
0 0 .513 r
.31871 .40347 .32206 .41187 .32738 .41713 .32379 .41254 Mtetra
.19 .462 .884 r
.32379 .41254 .32738 .41713 .33343 .41069 .32932 .41496 Mtetra
.98 .915 .622 r
.32932 .41496 .33343 .41069 .33945 .40486 .33595 .39896 Mtetra
.328 .474 .854 r
.33595 .39896 .33945 .40486 .34494 .40841 .34152 .40113 Mtetra
0 .127 .672 r
.34152 .40113 .34494 .40841 .35093 .40324 .34688 .40755 Mtetra
.963 .934 .621 r
.34688 .40755 .35093 .40324 .35689 .39871 .35338 .39325 Mtetra
.466 .57 .876 r
.35338 .39325 .35689 .39871 .36249 .40151 .35908 .39397 Mtetra
0 .191 .71 r
.35908 .39397 .36249 .40151 .36856 .39497 .36455 .39991 Mtetra
.944 .935 .589 r
.36455 .39991 .36856 .39497 .3744 .39343 .37102 .38559 Mtetra
.232 .344 .773 r
.37102 .38559 .3744 .39343 .38014 .39463 .37662 .38968 Mtetra
.353 .536 .896 r
.37662 .38968 .38014 .39463 .38629 .38669 .38236 .39124 Mtetra
.936 .941 .597 r
.38236 .39124 .38629 .38669 .39197 .38976 .38877 .37774 Mtetra
0 .043 .58 r
.38877 .37774 .39197 .38976 .39799 .38535 .39417 .38811 Mtetra
.84 .983 .697 r
.39417 .38811 .39799 .38535 .40402 .38047 .40036 .38 Mtetra
.873 .942 .859 r
.40036 .38 .40402 .38047 .40971 .38544 .40646 .37385 Mtetra
.162 .214 .67 r
.40646 .37385 .40971 .38544 .41592 .37593 .41209 .38109 Mtetra
.945 .922 .558 r
.41209 .38109 .41592 .37593 .42164 .38146 .41853 .36549 Mtetra
0 0 .414 r
.41853 .36549 .42164 .38146 .42785 .37216 .42387 .38333 Mtetra
0 0 0 r
.42387 .38333 .42785 .37216 .43382 .37068 .43021 .37089 Mtetra
.915 .952 .805 r
.43021 .37089 .43382 .37068 .43952 .38011 .43638 .36307 Mtetra
0 0 .46 r
.43638 .36307 .43952 .38011 .44601 .35965 .4419 .38058 Mtetra
0 0 .005 r
.4419 .38058 .44601 .35965 .45159 .37672 .44858 .35294 Mtetra
.052 .039 .521 r
.44858 .35294 .45159 .37672 .45793 .36134 .45417 .3712 Mtetra
0 0 0 r
.45417 .3712 .45793 .36134 .4639 .36379 .46053 .35569 Mtetra
.471 .485 .791 r
.46053 .35569 .4639 .36379 .46993 .36408 .46654 .35705 Mtetra
.556 .562 .815 r
.46654 .35705 .46993 .36408 .47615 .35419 .47261 .35679 Mtetra
.842 .977 .677 r
.47261 .35679 .47615 .35419 .48212 .36125 .47882 .34828 Mtetra
.371 .338 .692 r
.47882 .34828 .48212 .36125 .48835 .34953 .48485 .35299 Mtetra
.783 .942 .594 r
.48485 .35299 .48835 .34953 .4944 .35517 .49106 .34405 Mtetra
.437 .406 .726 r
.49106 .34405 .4944 .35517 .50059 .34694 .49716 .3468 Mtetra
.814 .982 .889 r
.49716 .3468 .50059 .34694 .50672 .34849 .50335 .34165 Mtetra
.619 .602 .811 r
.50335 .34165 .50672 .34849 .5129 .3449 .50952 .34013 Mtetra
.538 .645 .903 r
.50952 .34013 .5129 .3449 .51908 .34192 .5157 .33983 Mtetra
.856 .873 .852 r
.5157 .33983 .51908 .34192 .52527 .34321 .52191 .33376 Mtetra
.33 .369 .751 r
.52191 .33376 .52527 .34321 .53148 .33563 .52813 .33783 Mtetra
.868 .98 .684 r
.52813 .33783 .53148 .33563 .53773 .34126 .53435 .32892 Mtetra
.359 .339 .701 r
.53435 .32892 .53773 .34126 .54393 .33102 .54062 .33377 Mtetra
.471 .824 .55 r
.54062 .33377 .54393 .33102 .55023 .33647 .54687 .32844 Mtetra
.687 .607 .761 r
.54687 .32844 .55023 .33647 .55647 .33117 .55313 .32476 Mtetra
0 0 .544 r
.55313 .32476 .55647 .33117 .56272 .32607 .55954 .33389 Mtetra
.861 .834 .364 r
.55954 .33389 .56272 .32607 .56917 .33528 .56563 .31322 Mtetra
0 0 .482 r
.56563 .31322 .56917 .33528 .57522 .31589 .5723 .33581 Mtetra
0 0 .176 r
.5723 .33581 .57522 .31589 .58184 .33092 .57832 .31375 Mtetra
.425 .34 .657 r
.57832 .31375 .58184 .33092 .58798 .3181 .5848 .31863 Mtetra
.742 .232 0 r
.5848 .31863 .58798 .3181 .59431 .31506 .59136 .32559 Mtetra
.683 .713 .192 r
.59136 .32559 .59431 .31506 .60086 .32049 .59732 .30428 Mtetra
.176 .179 .622 r
.59732 .30428 .60086 .32049 .60706 .3109 .60403 .31545 Mtetra
.747 .867 .442 r
.60403 .31545 .60706 .3109 .61364 .31533 .6102 .30388 Mtetra
.459 .419 .726 r
.6102 .30388 .61364 .31533 .61988 .30725 .61675 .30635 Mtetra
.38 0 0 r
.61675 .30635 .61988 .30725 .62637 .30706 .62335 .30944 Mtetra
.956 .929 .59 r
.62335 .30944 .62637 .30706 .6329 .3076 .62942 .29539 Mtetra
.134 .195 .662 r
.62942 .29539 .6329 .3076 .63919 .30075 .63629 .30471 Mtetra
0 0 0 r
.63629 .30471 .63919 .30075 .64585 .30345 .64263 .29832 Mtetra
.83 .745 .77 r
.64263 .29832 .64585 .30345 .65225 .29903 .64891 .29077 Mtetra
0 .076 .632 r
.64891 .29077 .65225 .29903 .65873 .29612 .65592 .30052 Mtetra
.659 .826 .4 r
.65592 .30052 .65873 .29612 .66541 .29769 .6621 .28995 Mtetra
.702 .626 .769 r
.6621 .28995 .66541 .29769 .67178 .29184 .66855 .28583 Mtetra
0 0 .56 r
.66855 .28583 .67178 .29184 .67843 .29167 .67568 .29546 Mtetra
.749 .877 .461 r
.67568 .29546 .67843 .29167 .68513 .29188 .68183 .28435 Mtetra
.741 .65 .759 r
.68183 .28435 .68513 .29188 .69148 .28535 .68825 .27886 Mtetra
0 0 .493 r
.68825 .27886 .69148 .28535 .69828 .28673 .6956 .29041 Mtetra
0 0 0 r
.6956 .29041 .69828 .28673 .70509 .28779 .70195 .2829 Mtetra
.905 .767 .698 r
.70195 .2829 .70509 .28779 .71135 .27933 .70799 .27039 Mtetra
0 .053 .612 r
.70799 .27039 .71135 .27933 .71816 .27968 .71546 .28165 Mtetra
.687 .175 .015 r
.71546 .28165 .71816 .27968 .72541 .28657 .72267 .28755 Mtetra
.992 .88 .562 r
.72267 .28755 .72541 .28657 .73173 .27866 .72835 .26936 Mtetra
.733 .614 .726 r
.72835 .26936 .73173 .27866 .73789 .26843 .73478 .26314 Mtetra
.804 .407 0 r
.73478 .26314 .73789 .26843 .74548 .27872 .74309 .2836 Mtetra
.754 .32 .22 r
.74309 .2836 .74548 .27872 .75338 .29211 .75071 .29308 Mtetra
.998 .846 .514 r
.75071 .29308 .75338 .29211 .75943 .28 .75601 .27035 Mtetra
.892 .682 .611 r
.75601 .27035 .75943 .28 .76462 .25725 .76134 .24921 Mtetra
0 0 .386 r
.76134 .24921 .76462 .25725 .772 .26263 .76966 .26656 Mtetra
.937 .575 .295 r
.76966 .26656 .772 .26263 .78249 .30519 .78069 .31579 Mtetra
.896 .537 .354 r
.78069 .31579 .78249 .30519 .79375 .35428 .79141 .35838 Mtetra
.677 .206 .127 r
.79141 .35838 .79375 .35428 .80263 .37316 .79921 .36451 Mtetra
.935 .708 .571 r
.79921 .36451 .80263 .37316 .80817 .35319 .80406 .33658 Mtetra
.901 .645 .542 r
.80406 .33658 .80817 .35319 .81179 .31298 .80769 .29625 Mtetra
.884 .635 .558 r
.80769 .29625 .81179 .31298 .8154 .27436 .81169 .26168 Mtetra
.869 .648 .6 r
.81169 .26168 .8154 .27436 .82001 .24772 .81671 .23916 Mtetra
.844 .681 .679 r
.81671 .23916 .82001 .24772 .8257 .23294 .82265 .22688 Mtetra
.788 .718 .786 r
.82265 .22688 .8257 .23294 .8321 .2257 .82917 .22064 Mtetra
0 .438 .854 r
.21395 .42816 .21778 .43108 .22296 .43302 .21911 .43028 Mtetra
.86 .408 .077 r
.21911 .43028 .22296 .43302 .22761 .44102 .22367 .43915 Mtetra
.924 .581 .367 r
.22367 .43915 .22761 .44102 .23139 .45917 .22727 .45907 Mtetra
.92 .611 .441 r
.22727 .45907 .23139 .45917 .23422 .48909 .2299 .49096 Mtetra
.909 .605 .458 r
.2299 .49096 .23422 .48909 .23672 .52418 .23234 .52637 Mtetra
.877 .539 .405 r
.23234 .52637 .23672 .52418 .24045 .54628 .23631 .54559 Mtetra
.938 .801 .683 r
.23631 .54559 .24045 .54628 .24709 .53445 .24334 .52934 Mtetra
.922 .701 .586 r
.24334 .52934 .24709 .53445 .25655 .48753 .25296 .48112 Mtetra
.916 .693 .585 r
.25296 .48112 .25655 .48753 .26625 .43574 .26247 .4326 Mtetra
.908 .747 .67 r
.26247 .4326 .26625 .43574 .27326 .41657 .26934 .41567 Mtetra
.894 .508 .29 r
.26934 .41567 .27326 .41657 .27741 .43454 .27381 .42925 Mtetra
.859 .442 0 r
.27381 .42925 .27741 .43454 .28169 .45182 .2785 .4408 Mtetra
.777 .607 .67 r
.2785 .4408 .28169 .45182 .28839 .4367 .28493 .42947 Mtetra
.855 .679 .663 r
.28493 .42947 .28839 .4367 .2957 .41267 .2917 .41329 Mtetra
.075 0 0 r
.2917 .41329 .2957 .41267 .30104 .41604 .2973 .41313 Mtetra
.582 .047 0 r
.2973 .41313 .30104 .41604 .30573 .4296 .30256 .41824 Mtetra
.693 .556 .695 r
.30256 .41824 .30573 .4296 .31212 .41834 .30856 .41289 Mtetra
.805 .702 .751 r
.30856 .41289 .31212 .41834 .31871 .40347 .31468 .40559 Mtetra
.234 0 0 r
.31468 .40559 .31871 .40347 .32379 .41254 .32036 .40521 Mtetra
.569 .555 .8 r
.32036 .40521 .32379 .41254 .32932 .41496 .32606 .40475 Mtetra
.67 .556 .717 r
.32606 .40475 .32932 .41496 .33595 .39896 .33197 .40097 Mtetra
.467 .868 .696 r
.33197 .40097 .33595 .39896 .34152 .40113 .33789 .39727 Mtetra
.635 .724 .912 r
.33789 .39727 .34152 .40113 .34688 .40755 .3437 .39568 Mtetra
.565 .473 .709 r
.3437 .39568 .34688 .40755 .35338 .39325 .34945 .39528 Mtetra
.626 .946 .745 r
.34945 .39528 .35338 .39325 .35908 .39397 .35546 .39055 Mtetra
.715 .771 .897 r
.35546 .39055 .35908 .39397 .36455 .39991 .36137 .38767 Mtetra
.474 .411 .706 r
.36137 .38767 .36455 .39991 .37102 .38559 .36705 .38971 Mtetra
.575 .854 .52 r
.36705 .38971 .37102 .38559 .37662 .38968 .37317 .3829 Mtetra
.615 .596 .809 r
.37317 .3829 .37662 .38968 .38236 .39124 .37905 .38153 Mtetra
.414 .412 .749 r
.37905 .38153 .38236 .39124 .38877 .37774 .38476 .38416 Mtetra
.661 .828 .404 r
.38476 .38416 .38877 .37774 .39417 .38811 .39106 .37342 Mtetra
.375 .32 .668 r
.39106 .37342 .39417 .38811 .40036 .38 .39672 .37842 Mtetra
.712 .894 .962 r
.39672 .37842 .40036 .38 .40646 .37385 .40271 .37549 Mtetra
.816 .998 .786 r
.40271 .37549 .40646 .37385 .41209 .38109 .40884 .36907 Mtetra
0 .097 .611 r
.40884 .36907 .41209 .38109 .41853 .36549 .41442 .37867 Mtetra
0 0 0 r
.41442 .37867 .41853 .36549 .42387 .38333 .42104 .35807 Mtetra
.162 .11 .547 r
.42104 .35807 .42387 .38333 .43021 .37089 .42648 .37396 Mtetra
0 0 0 r
.42648 .37396 .43021 .37089 .43638 .36307 .43256 .3705 Mtetra
.872 .878 .441 r
.43256 .3705 .43638 .36307 .4419 .38058 .43902 .35328 Mtetra
0 0 .458 r
.43902 .35328 .4419 .38058 .44858 .35294 .44439 .37755 Mtetra
0 0 .08 r
.44439 .37755 .44858 .35294 .45417 .3712 .45113 .34793 Mtetra
.067 .052 .529 r
.45113 .34793 .45417 .3712 .46053 .35569 .45677 .36539 Mtetra
0 0 0 r
.45677 .36539 .46053 .35569 .46654 .35705 .4631 .35205 Mtetra
.578 .651 .886 r
.4631 .35205 .46654 .35705 .47261 .35679 .46918 .35126 Mtetra
.443 .56 .878 r
.46918 .35126 .47261 .35679 .47882 .34828 .47525 .35226 Mtetra
.737 .913 .547 r
.47525 .35226 .47882 .34828 .48485 .35299 .48149 .34323 Mtetra
.32 .356 .742 r
.48149 .34323 .48485 .35299 .49106 .34405 .48755 .34748 Mtetra
.711 .92 .579 r
.48755 .34748 .49106 .34405 .49716 .3468 .49378 .33948 Mtetra
.466 .506 .815 r
.49378 .33948 .49716 .3468 .50335 .34165 .49992 .34072 Mtetra
.7 .94 .961 r
.49992 .34072 .50335 .34165 .50952 .34013 .50611 .33749 Mtetra
.754 .841 .917 r
.50611 .33749 .50952 .34013 .5157 .33983 .51232 .33388 Mtetra
.368 .501 .861 r
.51232 .33388 .5157 .33983 .52191 .33376 .51852 .33586 Mtetra
.803 .981 .703 r
.51852 .33586 .52191 .33376 .52813 .33783 .52476 .32837 Mtetra
.31 .357 .749 r
.52476 .32837 .52813 .33783 .53435 .32892 .53101 .33272 Mtetra
0 0 0 r
.53101 .33272 .53435 .32892 .54062 .33377 .53726 .32678 Mtetra
.635 .607 .805 r
.53726 .32678 .54062 .33377 .54687 .32844 .54353 .32487 Mtetra
0 0 .495 r
.54353 .32487 .54687 .32844 .55313 .32476 .54988 .33154 Mtetra
.883 .86 .41 r
.54988 .33154 .55313 .32476 .55954 .33389 .55604 .31251 Mtetra
0 0 .46 r
.55604 .31251 .55954 .33389 .56563 .31322 .56264 .33567 Mtetra
0 0 .15 r
.56264 .33567 .56563 .31322 .5723 .33581 .56865 .3086 Mtetra
.314 .22 .587 r
.56865 .3086 .5723 .33581 .57832 .31375 .57522 .32143 Mtetra
.431 .047 .208 r
.57522 .32143 .57832 .31375 .5848 .31863 .58162 .3206 Mtetra
.995 .868 .571 r
.58162 .3206 .5848 .31863 .59136 .32559 .58765 .30066 Mtetra
.182 .136 .567 r
.58765 .30066 .59136 .32559 .59732 .30428 .59444 .31744 Mtetra
0 0 .127 r
.59444 .31744 .59732 .30428 .60403 .31545 .60058 .30348 Mtetra
.497 .436 .718 r
.60058 .30348 .60403 .31545 .6102 .30388 .60709 .30505 Mtetra
.111 0 0 r
.60709 .30505 .6102 .30388 .61675 .30635 .61358 .30459 Mtetra
.935 .876 .754 r
.61358 .30459 .61675 .30635 .62335 .30944 .61979 .29456 Mtetra
.324 .292 .668 r
.61979 .29456 .62335 .30944 .62942 .29539 .62654 .30153 Mtetra
0 0 0 r
.62654 .30153 .62942 .29539 .63629 .30471 .63288 .29485 Mtetra
.669 .569 .733 r
.63288 .29485 .63629 .30471 .64263 .29832 .63931 .29111 Mtetra
.296 .412 .811 r
.63931 .29111 .64263 .29832 .64891 .29077 .64604 .29471 Mtetra
0 0 0 r
.64604 .29471 .64891 .29077 .65592 .30052 .65239 .28796 Mtetra
.605 .497 .705 r
.65239 .28796 .65592 .30052 .6621 .28995 .65894 .28603 Mtetra
.289 .567 .933 r
.65894 .28603 .6621 .28995 .66855 .28583 .66567 .28772 Mtetra
.438 .829 .607 r
.66567 .28772 .66855 .28583 .67568 .29546 .67214 .28313 Mtetra
.637 .52 .703 r
.67214 .28313 .67568 .29546 .68183 .28435 .67868 .27991 Mtetra
.421 .612 .928 r
.67868 .27991 .68183 .28435 .68825 .27886 .68544 .28074 Mtetra
.127 0 0 r
.68544 .28074 .68825 .27886 .6956 .29041 .69213 .27973 Mtetra
.689 .57 .716 r
.69213 .27973 .6956 .29041 .70195 .2829 .69862 .27481 Mtetra
.647 .593 .78 r
.69862 .27481 .70195 .2829 .70799 .27039 .70526 .27229 Mtetra
.579 .041 0 r
.70526 .27229 .70799 .27039 .71546 .28165 .71228 .2759 Mtetra
.566 .625 .87 r
.71228 .2759 .71546 .28165 .72267 .28755 .71908 .27527 Mtetra
.752 .588 .673 r
.71908 .27527 .72267 .28755 .72835 .26936 .72533 .26578 Mtetra
.648 .775 .941 r
.72533 .26578 .72835 .26936 .73478 .26314 .73205 .26367 Mtetra
.825 .35 .056 r
.73205 .26367 .73478 .26314 .74309 .2836 .73979 .27583 Mtetra
.239 .361 .787 r
.73979 .27583 .74309 .2836 .75071 .29308 .74708 .28076 Mtetra
.83 .631 .633 r
.74708 .28076 .75071 .29308 .75601 .27035 .75283 .264 Mtetra
.911 .736 .653 r
.75283 .264 .75601 .27035 .76134 .24921 .75858 .24801 Mtetra
.84 .378 0 r
.75858 .24801 .76134 .24921 .76966 .26656 .76673 .26314 Mtetra
.936 .572 .173 r
.76673 .26314 .76966 .26656 .78069 .31579 .77738 .30819 Mtetra
.892 .541 .059 r
.77738 .30819 .78069 .31579 .79141 .35838 .7881 .35115 Mtetra
0 .073 .635 r
.7881 .35115 .79141 .35838 .79921 .36451 .79627 .36162 Mtetra
.987 .794 .558 r
.79627 .36162 .79921 .36451 .80406 .33658 .80146 .33713 Mtetra
.997 .773 .429 r
.80146 .33713 .80406 .33658 .80769 .29625 .80517 .2971 Mtetra
.997 .784 .431 r
.80517 .2971 .80769 .29625 .81169 .26168 .80907 .2609 Mtetra
1 .821 .517 r
.80907 .2609 .81169 .26168 .81671 .23916 .81397 .23666 Mtetra
.967 .86 .681 r
.81397 .23666 .81671 .23916 .82265 .22688 .81984 .22342 Mtetra
.851 .848 .839 r
.81984 .22342 .82265 .22688 .82917 .22064 .82635 .21691 Mtetra
.509 .596 .876 r
.21032 .42291 .21395 .42816 .21911 .43028 .21566 .42309 Mtetra
0 .162 .695 r
.21566 .42309 .21911 .43028 .22367 .43915 .22053 .42854 Mtetra
.797 .489 0 r
.22053 .42854 .22367 .43915 .22727 .45907 .22445 .44462 Mtetra
.953 .666 .224 r
.22445 .44462 .22727 .45907 .2299 .49096 .22711 .47559 Mtetra
.98 .697 .323 r
.22711 .47559 .2299 .49096 .23234 .52637 .22891 .5176 Mtetra
.972 .664 .358 r
.22891 .5176 .23234 .52637 .23631 .54559 .23156 .55161 Mtetra
.246 0 .025 r
.23156 .55161 .23631 .54559 .24334 .52934 .23744 .54928 Mtetra
.986 .837 .454 r
.23744 .54928 .24334 .52934 .25296 .48112 .2472 .50071 Mtetra
1 .81 .488 r
.2472 .50071 .25296 .48112 .26247 .4326 .25804 .43722 Mtetra
.986 .814 .589 r
.25804 .43722 .26247 .4326 .26934 .41567 .26596 .40757 Mtetra
.913 .56 .103 r
.26596 .40757 .26934 .41567 .27381 .42925 .2701 .42518 Mtetra
.948 .605 .333 r
.2701 .42518 .27381 .42925 .2785 .4408 .2739 .44817 Mtetra
.874 .915 .514 r
.2739 .44817 .2785 .4408 .28493 .42947 .28061 .43366 Mtetra
.986 .818 .59 r
.28061 .43366 .28493 .42947 .2917 .41329 .28829 .40547 Mtetra
.32 .398 .786 r
.28829 .40547 .2917 .41329 .2973 .41313 .29367 .40848 Mtetra
.926 .54 .181 r
.29367 .40848 .2973 .41313 .30256 .41824 .29819 .42408 Mtetra
.887 .937 .566 r
.29819 .42408 .30256 .41824 .30856 .41289 .30472 .41129 Mtetra
.932 .791 .682 r
.30472 .41129 .30856 .41289 .31468 .40559 .3114 .39586 Mtetra
0 0 .419 r
.3114 .39586 .31468 .40559 .32036 .40521 .31632 .4071 Mtetra
.34 0 0 r
.31632 .4071 .32036 .40521 .32606 .40475 .32198 .40752 Mtetra
.984 .879 .644 r
.32198 .40752 .32606 .40475 .33197 .40097 .32873 .39042 Mtetra
.19 .249 .694 r
.32873 .39042 .33197 .40097 .33789 .39727 .33408 .39632 Mtetra
.584 .008 0 r
.33408 .39632 .33789 .39727 .3437 .39568 .33959 .40014 Mtetra
.978 .916 .612 r
.33959 .40014 .3437 .39568 .34945 .39528 .34624 .38391 Mtetra
.215 .252 .685 r
.34624 .38391 .34945 .39528 .35546 .39055 .35166 .39002 Mtetra
.308 0 0 r
.35166 .39002 .35546 .39055 .36137 .38767 .35734 .39177 Mtetra
.975 .922 .619 r
.35734 .39177 .36137 .38767 .36705 .38971 .36392 .37636 Mtetra
0 .062 .581 r
.36392 .37636 .36705 .38971 .37317 .3829 .3692 .38689 Mtetra
0 0 0 r
.3692 .38689 .37317 .3829 .37905 .38153 .37531 .38084 Mtetra
.93 .878 .763 r
.37531 .38084 .37905 .38153 .38476 .38416 .38158 .37113 Mtetra
0 0 .45 r
.38158 .37113 .38476 .38416 .39106 .37342 .38682 .38517 Mtetra
0 0 0 r
.38682 .38517 .39106 .37342 .39672 .37842 .39345 .36717 Mtetra
.317 .324 .709 r
.39345 .36717 .39672 .37842 .40271 .37549 .39914 .37191 Mtetra
.532 .708 .952 r
.39914 .37191 .40271 .37549 .40884 .36907 .40506 .37139 Mtetra
.961 .945 .684 r
.40506 .37139 .40884 .36907 .41442 .37867 .41141 .35948 Mtetra
0 0 .16 r
.41141 .35948 .41442 .37867 .42104 .35807 .41635 .38863 Mtetra
0 0 .131 r
.41635 .38863 .42104 .35807 .42648 .37396 .42343 .355 Mtetra
.061 .069 .553 r
.42343 .355 .42648 .37396 .43256 .3705 .42896 .36904 Mtetra
.614 .049 0 r
.42896 .36904 .43256 .3705 .43902 .35328 .43483 .37391 Mtetra
0 0 0 r
.43483 .37391 .43902 .35328 .44439 .37755 .44162 .34501 Mtetra
0 0 .437 r
.44162 .34501 .44439 .37755 .45113 .34793 .44691 .3742 Mtetra
0 0 .061 r
.44691 .3742 .45113 .34793 .45677 .36539 .45374 .34106 Mtetra
.057 .04 .52 r
.45374 .34106 .45677 .36539 .4631 .35205 .45939 .35957 Mtetra
.809 .852 .396 r
.45939 .35957 .4631 .35205 .46918 .35126 .46579 .34351 Mtetra
.358 .429 .798 r
.46579 .34351 .46918 .35126 .47525 .35226 .47183 .34631 Mtetra
.716 .672 .806 r
.47183 .34631 .47525 .35226 .48149 .34323 .478 .34256 Mtetra
.745 .959 .94 r
.478 .34256 .48149 .34323 .48755 .34748 .48417 .33872 Mtetra
.58 .534 .768 r
.48417 .33872 .48755 .34748 .49378 .33948 .49032 .33796 Mtetra
.717 .909 .962 r
.49032 .33796 .49378 .33948 .49992 .34072 .49651 .33479 Mtetra
.681 .66 .823 r
.49651 .33479 .49992 .34072 .50611 .33749 .50271 .33199 Mtetra
.514 .6 .878 r
.50271 .33199 .50611 .33749 .51232 .33388 .50891 .33212 Mtetra
.836 .899 .883 r
.50891 .33212 .51232 .33388 .51852 .33586 .51514 .3268 Mtetra
.462 .46 .77 r
.51514 .3268 .51852 .33586 .52476 .32837 .52137 .32852 Mtetra
.643 .965 .901 r
.52137 .32852 .52476 .32837 .53101 .33272 .52762 .32494 Mtetra
.686 .612 .768 r
.52762 .32494 .53101 .33272 .53726 .32678 .53389 .32138 Mtetra
0 .02 .582 r
.53389 .32138 .53726 .32678 .54353 .32487 .54021 .32896 Mtetra
.975 .894 .535 r
.54021 .32896 .54353 .32487 .54988 .33154 .54641 .31018 Mtetra
0 0 .412 r
.54641 .31018 .54988 .33154 .55604 .31251 .55295 .33559 Mtetra
0 0 .086 r
.55295 .33559 .55604 .31251 .56264 .33567 .55899 .30404 Mtetra
.089 .049 .513 r
.55899 .30404 .56264 .33567 .56865 .3086 .56565 .32873 Mtetra
.256 .006 .33 r
.56565 .32873 .56865 .3086 .57522 .32143 .57191 .31795 Mtetra
.936 .783 .666 r
.57191 .31795 .57522 .32143 .58162 .3206 .57807 .30224 Mtetra
0 0 .323 r
.57807 .30224 .58162 .3206 .58765 .30066 .585 .3298 Mtetra
0 0 .227 r
.585 .3298 .58765 .30066 .59444 .31744 .59082 .29763 Mtetra
.378 .294 .634 r
.59082 .29763 .59444 .31744 .60058 .30348 .59744 .30489 Mtetra
.43 .849 .693 r
.59744 .30489 .60058 .30348 .60709 .30505 .60383 .30119 Mtetra
.87 .795 .774 r
.60383 .30119 .60709 .30505 .61358 .30459 .61011 .29286 Mtetra
0 .034 .581 r
.61011 .29286 .61358 .30459 .61979 .29456 .617 .30544 Mtetra
0 0 0 r
.617 .30544 .61979 .29456 .62654 .30153 .62302 .28821 Mtetra
.375 .342 .694 r
.62302 .28821 .62654 .30153 .63288 .29485 .62974 .29325 Mtetra
.028 .551 .862 r
.62974 .29325 .63288 .29485 .63931 .29111 .63638 .29461 Mtetra
.895 .917 .522 r
.63638 .29461 .63931 .29111 .64604 .29471 .64247 .28087 Mtetra
.153 .189 .646 r
.64247 .28087 .64604 .29471 .65239 .28796 .64949 .29108 Mtetra
0 0 0 r
.64949 .29108 .65239 .28796 .65894 .28603 .6559 .28516 Mtetra
.941 .929 .763 r
.6559 .28516 .65894 .28603 .66567 .28772 .66215 .27567 Mtetra
.044 .138 .639 r
.66215 .27567 .66567 .28772 .67214 .28313 .66933 .28657 Mtetra
.565 .82 .452 r
.66933 .28657 .67214 .28313 .67868 .27991 .67567 .27862 Mtetra
.934 .919 .775 r
.67567 .27862 .67868 .27991 .68544 .28074 .68194 .26946 Mtetra
0 .087 .618 r
.68194 .26946 .68544 .28074 .69213 .27973 .6893 .28133 Mtetra
.541 .892 .663 r
.6893 .28133 .69213 .27973 .69862 .27481 .69581 .27622 Mtetra
.968 .924 .601 r
.69581 .27622 .69862 .27481 .70526 .27229 .7018 .26201 Mtetra
0 .106 .637 r
.7018 .26201 .70526 .27229 .71228 .2759 .70926 .27302 Mtetra
.505 0 0 r
.70926 .27302 .71228 .2759 .71908 .27527 .71655 .28016 Mtetra
.89 .848 .391 r
.71655 .28016 .71908 .27527 .72533 .26578 .7222 .26076 Mtetra
.795 .752 .813 r
.7222 .26076 .72533 .26578 .73205 .26367 .72869 .25497 Mtetra
.707 .372 0 r
.72869 .25497 .73205 .26367 .73979 .27583 .7372 .2786 Mtetra
.753 .277 .114 r
.7372 .2786 .73979 .27583 .74708 .28076 .74477 .28714 Mtetra
.911 .802 .326 r
.74477 .28714 .74708 .28076 .75283 .264 .74977 .25951 Mtetra
.959 .772 .608 r
.74977 .25951 .75283 .264 .75858 .24801 .75523 .23929 Mtetra
.753 .414 0 r
.75523 .23929 .75858 .24801 .76673 .26314 .76432 .26672 Mtetra
.946 .592 .298 r
.76432 .26672 .76673 .26314 .77738 .30819 .77618 .327 Mtetra
.854 .511 .403 r
.77618 .327 .77738 .30819 .7881 .35115 .78702 .37108 Mtetra
.46 .171 .386 r
.78702 .37108 .7881 .35115 .79627 .36162 .79411 .36805 Mtetra
.95 .774 .317 r
.79411 .36805 .79627 .36162 .80146 .33713 .79806 .3286 Mtetra
.965 .706 .493 r
.79806 .3286 .80146 .33713 .80517 .2971 .80117 .2815 Mtetra
.897 .646 .551 r
.80117 .2815 .80517 .2971 .80907 .2609 .80513 .24579 Mtetra
.832 .613 .606 r
.80513 .24579 .80907 .2609 .81397 .23666 .81037 .22517 Mtetra
.769 .607 .678 r
.81037 .22517 .81397 .23666 .81984 .22342 .81658 .21528 Mtetra
.708 .628 .765 r
.81658 .21528 .81984 .22342 .82635 .21691 .82328 .21074 Mtetra
.356 .663 .972 r
.20645 .41995 .21032 .42291 .21566 .42309 .21177 .42045 Mtetra
.66 .122 0 r
.21177 .42045 .21566 .42309 .22053 .42854 .21667 .42556 Mtetra
.918 .53 .25 r
.21667 .42556 .22053 .42854 .22445 .44462 .22079 .43932 Mtetra
.956 .629 .357 r
.22079 .43932 .22445 .44462 .22711 .47559 .2239 .46488 Mtetra
.977 .675 .34 r
.2239 .46488 .22711 .47559 .22891 .5176 .22629 .49965 Mtetra
.88 .624 .102 r
.22629 .49965 .22891 .5176 .23156 .55161 .22918 .53026 Mtetra
.43 .315 .621 r
.22918 .53026 .23156 .55161 .23744 .54928 .23442 .53517 Mtetra
.853 .637 .609 r
.23442 .53517 .23744 .54928 .2472 .50071 .24292 .50196 Mtetra
.954 .735 .568 r
.24292 .50196 .2472 .50071 .25804 .43722 .25313 .44714 Mtetra
.998 .827 .539 r
.25313 .44714 .25804 .43722 .26596 .40757 .26182 .40882 Mtetra
.505 0 0 r
.26182 .40882 .26596 .40757 .2701 .42518 .2672 .41074 Mtetra
.823 .553 .001 r
.2672 .41074 .2701 .42518 .2739 .44817 .27092 .43421 Mtetra
.455 .379 .682 r
.27092 .43421 .2739 .44817 .28061 .43366 .27633 .43688 Mtetra
.983 .823 .608 r
.27633 .43688 .28061 .43366 .28829 .40547 .28382 .41198 Mtetra
.887 .928 .545 r
.28382 .41198 .28829 .40547 .29367 .40848 .29042 .39832 Mtetra
0 0 .282 r
.29042 .39832 .29367 .40848 .29819 .42408 .29508 .41165 Mtetra
.33 .312 .688 r
.29508 .41165 .29819 .42408 .30472 .41129 .3004 .41642 Mtetra
.987 .898 .602 r
.3004 .41642 .30472 .41129 .3114 .39586 .30734 .3977 Mtetra
.713 .982 .793 r
.30734 .3977 .3114 .39586 .31632 .4071 .31333 .39261 Mtetra
0 0 .509 r
.31333 .39261 .31632 .4071 .32198 .40752 .3182 .40519 Mtetra
.879 .817 .783 r
.3182 .40519 .32198 .40752 .32873 .39042 .32442 .39705 Mtetra
.844 .91 .505 r
.32442 .39705 .32873 .39042 .33408 .39632 .33095 .38377 Mtetra
0 .015 .558 r
.33095 .38377 .33408 .39632 .33959 .40014 .33604 .39434 Mtetra
.672 .653 .823 r
.33604 .39434 .33959 .40014 .34624 .38391 .34194 .39186 Mtetra
.816 .874 .437 r
.34194 .39186 .34624 .38391 .35166 .39002 .34853 .37691 Mtetra
0 .052 .577 r
.34853 .37691 .35166 .39002 .35734 .39177 .35374 .38733 Mtetra
.72 .723 .852 r
.35374 .38733 .35734 .39177 .36392 .37636 .35971 .38406 Mtetra
.771 .857 .415 r
.35971 .38406 .36392 .37636 .3692 .38689 .36622 .37013 Mtetra
0 .004 .527 r
.36622 .37013 .3692 .38689 .37531 .38084 .37137 .38382 Mtetra
.933 .965 .68 r
.37137 .38382 .37531 .38084 .38158 .37113 .37773 .37298 Mtetra
.848 .997 .772 r
.37773 .37298 .38158 .37113 .38682 .38517 .3839 .36589 Mtetra
.024 .038 .534 r
.3839 .36589 .38682 .38517 .39345 .36717 .38915 .38046 Mtetra
.679 .731 .222 r
.38915 .38046 .39345 .36717 .39914 .37191 .39591 .35944 Mtetra
0 0 .444 r
.39591 .35944 .39914 .37191 .40506 .37139 .40127 .37339 Mtetra
.441 .85 .673 r
.40127 .37339 .40506 .37139 .41141 .35948 .40735 .36961 Mtetra
.79 .817 .338 r
.40735 .36961 .41141 .35948 .41635 .38863 .41397 .3505 Mtetra
0 0 .377 r
.41397 .3505 .41635 .38863 .42343 .355 .41869 .38753 Mtetra
0 0 .119 r
.41869 .38753 .42343 .355 .42896 .36904 .42588 .3505 Mtetra
.116 .111 .575 r
.42588 .3505 .42896 .36904 .43483 .37391 .43149 .36309 Mtetra
.177 .241 .692 r
.43149 .36309 .43483 .37391 .44162 .34501 .43734 .36969 Mtetra
0 0 .063 r
.43734 .36969 .44162 .34501 .44691 .3742 .44417 .33951 Mtetra
0 0 .457 r
.44417 .33951 .44691 .3742 .45374 .34106 .44952 .36823 Mtetra
0 0 .099 r
.44952 .36823 .45374 .34106 .45939 .35957 .45632 .33593 Mtetra
.061 .047 .526 r
.45632 .33593 .45939 .35957 .46579 .34351 .46203 .35378 Mtetra
0 0 0 r
.46203 .35378 .46579 .34351 .47183 .34631 .46844 .33735 Mtetra
.291 .355 .757 r
.46844 .33735 .47183 .34631 .478 .34256 .47449 .34154 Mtetra
.861 .932 .871 r
.47449 .34154 .478 .34256 .48417 .33872 .48071 .33564 Mtetra
.59 .77 .965 r
.48071 .33564 .48417 .33872 .49032 .33796 .48687 .33433 Mtetra
.716 .775 .899 r
.48687 .33433 .49032 .33796 .49651 .33479 .49307 .3313 Mtetra
.602 .748 .947 r
.49307 .3313 .49651 .33479 .50271 .33199 .49927 .32995 Mtetra
.724 .878 .952 r
.49927 .32995 .50271 .33199 .50891 .33212 .5055 .32679 Mtetra
.591 .646 .873 r
.5055 .32679 .50891 .33212 .51514 .3268 .51172 .32579 Mtetra
.395 .821 .965 r
.51172 .32579 .51514 .3268 .52137 .32852 .51797 .32476 Mtetra
.81 .788 .832 r
.51797 .32476 .52137 .32852 .52762 .32494 .52423 .31922 Mtetra
0 0 .512 r
.52423 .31922 .52762 .32494 .53389 .32138 .53053 .32787 Mtetra
.901 .873 .437 r
.53053 .32787 .53389 .32138 .54021 .32896 .53677 .30909 Mtetra
0 0 .383 r
.53677 .30909 .54021 .32896 .54641 .31018 .54322 .33422 Mtetra
0 0 .104 r
.54322 .33422 .54641 .31018 .55295 .33559 .54935 .30278 Mtetra
.069 .031 .502 r
.54935 .30278 .55295 .33559 .55899 .30404 .55594 .32894 Mtetra
.272 .035 .36 r
.55594 .32894 .55899 .30404 .56565 .32873 .5622 .3163 Mtetra
.8 .612 .648 r
.5622 .3163 .56565 .32873 .57191 .31795 .56841 .302 Mtetra
0 0 .156 r
.56841 .302 .57191 .31795 .57807 .30224 .57532 .33328 Mtetra
0 0 .146 r
.57532 .33328 .57807 .30224 .585 .3298 .58107 .29209 Mtetra
.337 .216 .564 r
.58107 .29209 .585 .3298 .59082 .29763 .58782 .30824 Mtetra
.434 .088 .279 r
.58782 .30824 .59082 .29763 .59744 .30489 .59428 .30667 Mtetra
.991 .887 .587 r
.59428 .30667 .59744 .30489 .60383 .30119 .60036 .28893 Mtetra
0 0 .458 r
.60036 .28893 .60383 .30119 .61011 .29286 .6073 .30569 Mtetra
0 0 0 r
.6073 .30569 .61011 .29286 .617 .30544 .6133 .28629 Mtetra
.468 .36 .648 r
.6133 .28629 .617 .30544 .62302 .28821 .61995 .28995 Mtetra
.703 .199 .037 r
.61995 .28995 .62302 .28821 .62974 .29325 .62672 .29597 Mtetra
.98 .893 .544 r
.62672 .29597 .62974 .29325 .63638 .29461 .6327 .27784 Mtetra
.226 .211 .632 r
.6327 .27784 .63638 .29461 .64247 .28087 .63969 .28829 Mtetra
.37 0 .17 r
.63969 .28829 .64247 .28087 .64949 .29108 .64626 .28645 Mtetra
.921 .767 .674 r
.64626 .28645 .64949 .29108 .6559 .28516 .65233 .27186 Mtetra
.067 .137 .628 r
.65233 .27186 .6559 .28516 .66215 .27567 .65948 .28333 Mtetra
.325 0 .161 r
.65948 .28333 .66215 .27567 .66933 .28657 .66607 .28057 Mtetra
.9 .736 .669 r
.66607 .28057 .66933 .28657 .67567 .27862 .67209 .26578 Mtetra
.131 .188 .655 r
.67209 .26578 .67567 .27862 .68194 .26946 .67931 .27582 Mtetra
.579 .159 .21 r
.67931 .27582 .68194 .26946 .6893 .28133 .68624 .27878 Mtetra
.97 .816 .634 r
.68624 .27878 .6893 .28133 .69581 .27622 .6921 .26139 Mtetra
.491 .405 .687 r
.6921 .26139 .69581 .27622 .7018 .26201 .69901 .26357 Mtetra
.851 .408 .158 r
.69901 .26357 .7018 .26201 .70926 .27302 .70668 .27799 Mtetra
0 0 0 r
.70668 .27799 .70926 .27302 .71655 .28016 .71291 .26737 Mtetra
.827 .625 .63 r
.71291 .26737 .71655 .28016 .7222 .26076 .71871 .2502 Mtetra
0 .11 .637 r
.71871 .2502 .7222 .26076 .72869 .25497 .72632 .26144 Mtetra
.849 .459 .306 r
.72632 .26144 .72869 .25497 .7372 .2786 .73462 .28181 Mtetra
.643 .851 .462 r
.73462 .28181 .7372 .2786 .74477 .28714 .74098 .27268 Mtetra
.875 .64 .581 r
.74098 .27268 .74477 .28714 .74977 .25951 .74595 .2445 Mtetra
.635 .497 .676 r
.74595 .2445 .74977 .25951 .75523 .23929 .75263 .24059 Mtetra
.931 .552 .242 r
.75263 .24059 .75523 .23929 .76432 .26672 .76242 .27728 Mtetra
.912 .558 .354 r
.76242 .27728 .76432 .26672 .77618 .327 .77357 .32857 Mtetra
.909 .507 .205 r
.77357 .32857 .77618 .327 .78702 .37108 .78305 .35613 Mtetra
.748 .57 .654 r
.78305 .35613 .78702 .37108 .79411 .36805 .78944 .34491 Mtetra
.846 .596 .561 r
.78944 .34491 .79411 .36805 .79806 .3286 .79366 .30863 Mtetra
.877 .622 .549 r
.79366 .30863 .79806 .3286 .80117 .2815 .79746 .26907 Mtetra
.905 .666 .566 r
.79746 .26907 .80117 .2815 .80513 .24579 .80197 .23918 Mtetra
.925 .738 .63 r
.80197 .23918 .80513 .24579 .81037 .22517 .80747 .22116 Mtetra
.9 .821 .76 r
.80747 .22116 .81037 .22517 .81658 .21528 .81374 .21172 Mtetra
.793 .834 .884 r
.81374 .21172 .81658 .21528 .82328 .21074 .82043 .20687 Mtetra
.54 .705 .947 r
.20262 .41642 .20645 .41995 .21177 .42045 .20804 .41589 Mtetra
0 .194 .714 r
.20804 .41589 .21177 .42045 .21667 .42556 .21303 .42001 Mtetra
.922 .537 .149 r
.21303 .42001 .21667 .42556 .22079 .43932 .21711 .43415 Mtetra
.956 .638 .383 r
.21711 .43415 .22079 .43932 .2239 .46488 .21986 .46318 Mtetra
.935 .636 .451 r
.21986 .46318 .2239 .46488 .22629 .49965 .22159 .50486 Mtetra
.89 .59 .473 r
.22159 .50486 .22629 .49965 .22918 .53026 .22384 .54238 Mtetra
.641 .311 .397 r
.22384 .54238 .22918 .53026 .23442 .53517 .22904 .54792 Mtetra
.999 .837 .521 r
.22904 .54792 .23442 .53517 .24292 .50196 .23826 .50726 Mtetra
.968 .749 .553 r
.23826 .50726 .24292 .50196 .25313 .44714 .24924 .44432 Mtetra
.933 .721 .593 r
.24924 .44432 .25313 .44714 .26182 .40882 .25808 .40493 Mtetra
0 .091 .599 r
.25808 .40493 .26182 .40882 .2672 .41074 .26324 .40954 Mtetra
.92 .573 .362 r
.26324 .40954 .2672 .41074 .27092 .43421 .26717 .43013 Mtetra
.719 .735 .864 r
.26717 .43013 .27092 .43421 .27633 .43688 .27302 .42702 Mtetra
.85 .654 .636 r
.27302 .42702 .27633 .43688 .28382 .41198 .28025 .40593 Mtetra
.775 .679 .758 r
.28025 .40593 .28382 .41198 .29042 .39832 .28632 .39974 Mtetra
.784 .346 .211 r
.28632 .39974 .29042 .39832 .29508 .41165 .29141 .40705 Mtetra
.717 .712 .844 r
.29141 .40705 .29508 .41165 .3004 .41642 .29729 .40381 Mtetra
.732 .57 .671 r
.29729 .40381 .3004 .41642 .30734 .3977 .30354 .39518 Mtetra
.433 .737 .991 r
.30354 .39518 .30734 .3977 .31333 .39261 .30923 .39499 Mtetra
.033 0 0 r
.30923 .39499 .31333 .39261 .3182 .40519 .31502 .39339 Mtetra
.667 .537 .697 r
.31502 .39339 .3182 .40519 .32442 .39705 .32099 .38915 Mtetra
.552 .534 .788 r
.32099 .38915 .32442 .39705 .33095 .38377 .32672 .38899 Mtetra
0 0 0 r
.32672 .38899 .33095 .38377 .33604 .39434 .33274 .3842 Mtetra
.636 .539 .727 r
.33274 .3842 .33604 .39434 .34194 .39186 .33864 .38169 Mtetra
.434 .417 .74 r
.33864 .38169 .34194 .39186 .34853 .37691 .34427 .38401 Mtetra
0 0 0 r
.34427 .38401 .34853 .37691 .35374 .38733 .35053 .37537 Mtetra
.536 .455 .711 r
.35053 .37537 .35374 .38733 .35971 .38406 .3563 .37573 Mtetra
.356 .41 .78 r
.3563 .37573 .35971 .38406 .36622 .37013 .36197 .37861 Mtetra
.637 .778 .319 r
.36197 .37861 .36622 .37013 .37137 .38382 .36845 .36561 Mtetra
.272 .22 .615 r
.36845 .36561 .37137 .38382 .37773 .37298 .37388 .37422 Mtetra
.605 .951 .817 r
.37388 .37422 .37773 .37298 .3839 .36589 .37993 .3703 Mtetra
.904 .95 .602 r
.37993 .3703 .3839 .36589 .38915 .38046 .38634 .35823 Mtetra
.106 .08 .543 r
.38634 .35823 .38915 .38046 .39591 .35944 .3916 .37312 Mtetra
.677 .726 .214 r
.3916 .37312 .39591 .35944 .40127 .37339 .3984 .3515 Mtetra
0 0 .428 r
.3984 .3515 .40127 .37339 .40735 .36961 .4035 .37273 Mtetra
.76 .335 .242 r
.4035 .37273 .40735 .36961 .41397 .3505 .4092 .38041 Mtetra
0 0 .02 r
.4092 .38041 .41397 .3505 .41869 .38753 .41655 .34138 Mtetra
0 0 .373 r
.41655 .34138 .41869 .38753 .42588 .3505 .42109 .3852 Mtetra
0 0 .183 r
.42109 .3852 .42588 .3505 .43149 .36309 .42822 .34994 Mtetra
.417 .366 .694 r
.42822 .34994 .43149 .36309 .43734 .36969 .43414 .3535 Mtetra
.144 .15 .606 r
.43414 .3535 .43734 .36969 .44417 .33951 .4399 .364 Mtetra
0 0 .043 r
.4399 .364 .44417 .33951 .44952 .36823 .44675 .33305 Mtetra
.043 0 .477 r
.44675 .33305 .44952 .36823 .45632 .33593 .45219 .36003 Mtetra
0 0 .036 r
.45219 .36003 .45632 .33593 .46203 .35378 .45896 .32873 Mtetra
.061 .041 .519 r
.45896 .32873 .46203 .35378 .46844 .33735 .46469 .34761 Mtetra
.724 .771 .275 r
.46469 .34761 .46844 .33735 .47449 .34154 .47116 .32869 Mtetra
.175 .209 .657 r
.47116 .32869 .47449 .34154 .48071 .33564 .47716 .33673 Mtetra
.937 .964 .742 r
.47716 .33673 .48071 .33564 .48687 .33433 .48346 .32716 Mtetra
.402 .476 .822 r
.48346 .32716 .48687 .33433 .49307 .3313 .4896 .32916 Mtetra
.808 .877 .897 r
.4896 .32916 .49307 .3313 .49927 .32995 .49584 .32446 Mtetra
.62 .652 .86 r
.49584 .32446 .49927 .32995 .5055 .32679 .50206 .32297 Mtetra
.486 .68 .951 r
.50206 .32297 .5055 .32679 .51172 .32579 .50829 .32289 Mtetra
.866 .829 .809 r
.50829 .32289 .51172 .32579 .51797 .32476 .51457 .3157 Mtetra
0 .079 .629 r
.51457 .3157 .51797 .32476 .52423 .31922 .52082 .32474 Mtetra
.935 .892 .487 r
.52082 .32474 .52423 .31922 .53053 .32787 .52711 .30646 Mtetra
0 0 .456 r
.52711 .30646 .53053 .32787 .53677 .30909 .53346 .329 Mtetra
0 0 .023 r
.53346 .329 .53677 .30909 .54322 .33422 .53968 .3004 Mtetra
.091 .044 .506 r
.53968 .3004 .54322 .33422 .54935 .30278 .54618 .32615 Mtetra
.143 0 .307 r
.54618 .32615 .54935 .30278 .55594 .32894 .55243 .30998 Mtetra
.634 .472 .645 r
.55243 .30998 .55594 .32894 .5622 .3163 .55877 .30513 Mtetra
.818 .502 0 r
.55877 .30513 .5622 .3163 .56841 .302 .56553 .33303 Mtetra
0 0 .085 r
.56553 .33303 .56841 .302 .57532 .33328 .57133 .28738 Mtetra
.108 .041 .492 r
.57133 .28738 .57532 .33328 .58107 .29209 .57834 .32205 Mtetra
.34 .101 .399 r
.57834 .32205 .58107 .29209 .58782 .30824 .58462 .31005 Mtetra
.999 .833 .541 r
.58462 .31005 .58782 .30824 .59428 .30667 .59059 .28471 Mtetra
.087 .082 .554 r
.59059 .28471 .59428 .30667 .60036 .28893 .59748 .30218 Mtetra
0 0 .009 r
.59748 .30218 .60036 .28893 .6073 .30569 .60354 .28324 Mtetra
.404 .3 .622 r
.60354 .28324 .6073 .30569 .6133 .28629 .61026 .29034 Mtetra
.432 0 .021 r
.61026 .29034 .6133 .28629 .61995 .28995 .61684 .29085 Mtetra
.977 .921 .65 r
.61684 .29085 .61995 .28995 .62672 .29597 .62301 .27729 Mtetra
.322 .263 .635 r
.62301 .27729 .62672 .29597 .6327 .27784 .62989 .28598 Mtetra
.098 0 .087 r
.62989 .28598 .6327 .27784 .63969 .28829 .63629 .27964 Mtetra
.733 .624 .737 r
.63629 .27964 .63969 .28829 .64626 .28645 .64271 .27381 Mtetra
.367 .347 .704 r
.64271 .27381 .64626 .28645 .65233 .27186 .64957 .27873 Mtetra
.047 0 .017 r
.64957 .27873 .65233 .27186 .65948 .28333 .65601 .27274 Mtetra
.647 .548 .728 r
.65601 .27274 .65948 .28333 .66607 .28057 .66257 .26956 Mtetra
.504 .456 .737 r
.66257 .26956 .66607 .28057 .67209 .26578 .66935 .27078 Mtetra
.159 0 0 r
.66935 .27078 .67209 .26578 .67931 .27582 .67594 .26752 Mtetra
.612 .571 .783 r
.67594 .26752 .67931 .27582 .68624 .27878 .68263 .26589 Mtetra
.618 .503 .701 r
.68263 .26589 .68624 .27878 .6921 .26139 .68929 .26332 Mtetra
0 0 0 r
.68929 .26332 .6921 .26139 .69901 .26357 .69597 .26089 Mtetra
0 .379 .809 r
.69597 .26089 .69901 .26357 .70668 .27799 .70299 .26422 Mtetra
.615 .494 .692 r
.70299 .26422 .70668 .27799 .71291 .26737 .7097 .26159 Mtetra
.864 .743 .727 r
.7097 .26159 .71291 .26737 .71871 .2502 .71596 .25144 Mtetra
.546 0 0 r
.71596 .25144 .71871 .2502 .72632 .26144 .72308 .25494 Mtetra
0 0 .345 r
.72308 .25494 .72632 .26144 .73462 .28181 .73103 .27026 Mtetra
.643 .536 .717 r
.73103 .27026 .73462 .28181 .74098 .27268 .73779 .26692 Mtetra
.952 .744 .584 r
.73779 .26692 .74098 .27268 .74595 .2445 .74308 .24271 Mtetra
.865 .935 .867 r
.74308 .24271 .74595 .2445 .75263 .24059 .74959 .2364 Mtetra
.919 .546 .121 r
.74959 .2364 .75263 .24059 .76242 .27728 .75937 .27313 Mtetra
.945 .595 .201 r
.75937 .27313 .76242 .27728 .77357 .32857 .77103 .33149 Mtetra
.921 .537 .254 r
.77103 .33149 .77357 .32857 .78305 .35613 .78112 .36656 Mtetra
.001 0 .137 r
.78112 .36656 .78305 .35613 .78944 .34491 .78759 .35562 Mtetra
.871 .729 .212 r
.78759 .35562 .78944 .34491 .79366 .30863 .79138 .31329 Mtetra
.979 .766 .351 r
.79138 .31329 .79366 .30863 .79746 .26907 .79466 .26713 Mtetra
.996 .774 .484 r
.79466 .26713 .79746 .26907 .80197 .23918 .7989 .23365 Mtetra
.945 .761 .622 r
.7989 .23365 .80197 .23918 .80747 .22116 .80437 .21501 Mtetra
.839 .735 .749 r
.80437 .21501 .80747 .22116 .81374 .21172 .81072 .20638 Mtetra
.727 .725 .848 r
.81072 .20638 .81374 .21172 .82043 .20687 .81752 .20246 Mtetra
.648 .686 .872 r
.19888 .41187 .20262 .41642 .20804 .41589 .20443 .41011 Mtetra
.459 .55 .862 r
.20443 .41011 .20804 .41589 .21303 .42001 .20974 .4109 Mtetra
0 0 .551 r
.20974 .4109 .21303 .42001 .21711 .43415 .21436 .41902 Mtetra
.802 .546 0 r
.21436 .41902 .21711 .43415 .21986 .46318 .2177 .44136 Mtetra
.925 .678 .191 r
.2177 .44136 .21986 .46318 .22159 .50486 .21945 .48179 Mtetra
.961 .706 .264 r
.21945 .48179 .22159 .50486 .22384 .54238 .22055 .5312 Mtetra
.968 .658 .273 r
.22055 .5312 .22384 .54238 .22904 .54792 .22359 .56088 Mtetra
.857 .857 .403 r
.22359 .56088 .22904 .54792 .23826 .50726 .23127 .53884 Mtetra
.972 .819 .402 r
.23127 .53884 .23826 .50726 .24924 .44432 .24291 .46979 Mtetra
.989 .822 .439 r
.24291 .46979 .24924 .44432 .25808 .40493 .25387 .40634 Mtetra
.931 .951 .777 r
.25387 .40634 .25808 .40493 .26324 .40954 .26014 .39754 Mtetra
.971 .668 .279 r
.26014 .39754 .26324 .40954 .26717 .43013 .26303 .43057 Mtetra
.85 .442 .264 r
.26303 .43057 .26717 .43013 .27302 .42702 .26782 .44119 Mtetra
.968 .858 .456 r
.26782 .44119 .27302 .42702 .28025 .40593 .27602 .40833 Mtetra
.979 .844 .638 r
.27602 .40833 .28025 .40593 .28632 .39974 .28313 .38862 Mtetra
.835 .525 0 r
.28313 .38862 .28632 .39974 .29141 .40705 .28732 .40786 Mtetra
.725 .237 .081 r
.28732 .40786 .29141 .40705 .29729 .40381 .29261 .41311 Mtetra
.979 .88 .514 r
.29261 .41311 .29729 .40381 .30354 .39518 .30006 .38801 Mtetra
.589 .573 .803 r
.30006 .38801 .30354 .39518 .30923 .39499 .30579 .38712 Mtetra
.845 .481 0 r
.30579 .38712 .30923 .39499 .31502 .39339 .31046 .40231 Mtetra
.827 .871 .429 r
.31046 .40231 .31502 .39339 .32099 .38915 .31725 .38603 Mtetra
.869 .785 .765 r
.31725 .38603 .32099 .38915 .32672 .38899 .32351 .37744 Mtetra
0 0 .27 r
.32351 .37744 .32672 .38899 .33274 .3842 .3283 .39283 Mtetra
.701 .816 .362 r
.3283 .39283 .33274 .3842 .33864 .38169 .33489 .37913 Mtetra
.874 .813 .786 r
.33489 .37913 .33864 .38169 .34427 .38401 .34112 .37118 Mtetra
0 0 .348 r
.34112 .37118 .34427 .38401 .35053 .37537 .34603 .38659 Mtetra
.715 .782 .296 r
.34603 .38659 .35053 .37537 .3563 .37573 .35282 .3687 Mtetra
.548 .557 .816 r
.35282 .3687 .3563 .37573 .36197 .37861 .35864 .36854 Mtetra
0 0 .416 r
.35864 .36854 .36197 .37861 .36845 .36561 .36387 .38065 Mtetra
.737 .753 .243 r
.36387 .38065 .36845 .36561 .37388 .37422 .37093 .35612 Mtetra
0 0 .471 r
.37093 .35612 .37388 .37422 .37993 .3703 .37602 .37261 Mtetra
.506 .878 .669 r
.37602 .37261 .37993 .3703 .38634 .35823 .38212 .36821 Mtetra
.699 .782 .301 r
.38212 .36821 .38634 .35823 .3916 .37312 .38873 .35183 Mtetra
0 0 .127 r
.38873 .35183 .3916 .37312 .3984 .3515 .39332 .38404 Mtetra
0 0 .085 r
.39332 .38404 .3984 .3515 .4035 .37273 .40078 .34626 Mtetra
0 0 .38 r
.40078 .34626 .4035 .37273 .4092 .38041 .40572 .3732 Mtetra
.778 .4 0 r
.40572 .3732 .4092 .38041 .41655 .34138 .41122 .38746 Mtetra
0 0 .147 r
.41122 .38746 .41655 .34138 .42109 .3852 .41901 .33581 Mtetra
0 0 .313 r
.41901 .33581 .42109 .3852 .42822 .34994 .42333 .38839 Mtetra
0 0 .12 r
.42333 .38839 .42822 .34994 .43414 .3535 .43076 .34356 Mtetra
0 .127 .649 r
.43076 .34356 .43414 .3535 .4399 .364 .43658 .35172 Mtetra
.382 .355 .704 r
.43658 .35172 .4399 .364 .44675 .33305 .44255 .35573 Mtetra
0 0 .089 r
.44255 .35573 .44675 .33305 .45219 .36003 .44928 .32976 Mtetra
.101 .053 .511 r
.44928 .32976 .45219 .36003 .45896 .32873 .45489 .35099 Mtetra
0 0 .062 r
.45489 .35099 .45896 .32873 .46469 .34761 .46158 .32385 Mtetra
.135 .099 .549 r
.46158 .32385 .46469 .34761 .47116 .32869 .4674 .33973 Mtetra
0 0 0 r
.4674 .33973 .47116 .32869 .47716 .33673 .47384 .32254 Mtetra
.273 .26 .662 r
.47384 .32254 .47716 .33673 .48346 .32716 .47989 .32959 Mtetra
.829 .98 .688 r
.47989 .32959 .48346 .32716 .4896 .32916 .48618 .32139 Mtetra
.542 .538 .8 r
.48618 .32139 .4896 .32916 .49584 .32446 .49238 .32136 Mtetra
.509 .739 .977 r
.49238 .32136 .49584 .32446 .50206 .32297 .4986 .32079 Mtetra
.881 .863 .817 r
.4986 .32079 .50206 .32297 .50829 .32289 .50489 .31349 Mtetra
0 .097 .637 r
.50489 .31349 .50829 .32289 .51457 .3157 .5111 .32236 Mtetra
.862 .87 .426 r
.5111 .32236 .51457 .3157 .52082 .32474 .51743 .30523 Mtetra
0 0 .463 r
.51743 .30523 .52082 .32474 .52711 .30646 .5237 .32579 Mtetra
0 0 .058 r
.5237 .32579 .52711 .30646 .53346 .329 .53 .30052 Mtetra
.041 .021 .504 r
.53 .30052 .53346 .329 .53968 .3004 .5364 .32372 Mtetra
.246 .007 .34 r
.5364 .32372 .53968 .3004 .54618 .32615 .54271 .31123 Mtetra
.692 .531 .664 r
.54271 .31123 .54618 .32615 .55243 .30998 .54904 .30411 Mtetra
.949 .599 .22 r
.54904 .30411 .55243 .30998 .55877 .30513 .55578 .339 Mtetra
0 0 .043 r
.55578 .339 .55877 .30513 .56553 .33303 .56163 .28543 Mtetra
0 0 .416 r
.56163 .28543 .56553 .33303 .57133 .28738 .56869 .33289 Mtetra
.304 .093 .419 r
.56869 .33289 .57133 .28738 .57834 .32205 .57488 .31175 Mtetra
.897 .675 .594 r
.57488 .31175 .57834 .32205 .58462 .31005 .58088 .28395 Mtetra
0 0 .394 r
.58088 .28395 .58462 .31005 .59059 .28471 .588 .31584 Mtetra
0 0 .219 r
.588 .31584 .59059 .28471 .59748 .30218 .59377 .28046 Mtetra
.262 .205 .602 r
.59377 .28046 .59748 .30218 .60354 .28324 .60058 .29239 Mtetra
.452 .085 .249 r
.60058 .29239 .60354 .28324 .61026 .29034 .60712 .29174 Mtetra
.995 .869 .576 r
.60712 .29174 .61026 .29034 .61684 .29085 .61315 .27232 Mtetra
0 0 .519 r
.61315 .27232 .61684 .29085 .62301 .27729 .62031 .29131 Mtetra
0 0 .124 r
.62031 .29131 .62301 .27729 .62989 .28598 .62642 .27545 Mtetra
.66 .555 .726 r
.62642 .27545 .62989 .28598 .63629 .27964 .63292 .27182 Mtetra
0 0 .487 r
.63292 .27182 .63629 .27964 .64271 .27381 .64002 .28416 Mtetra
0 0 0 r
.64002 .28416 .64271 .27381 .64957 .27873 .64599 .26549 Mtetra
.425 .378 .702 r
.64599 .26549 .64957 .27873 .65601 .27274 .65282 .26918 Mtetra
.552 .07 0 r
.65282 .26918 .65601 .27274 .66257 .26956 .65989 .2774 Mtetra
.714 .753 .248 r
.65989 .2774 .66257 .26956 .66935 .27078 .6658 .25882 Mtetra
.376 .362 .717 r
.6658 .25882 .66935 .27078 .67594 .26752 .67276 .2633 Mtetra
.618 .168 0 r
.67276 .2633 .67594 .26752 .68263 .26589 .68007 .27385 Mtetra
.692 .735 .224 r
.68007 .27385 .68263 .26589 .68929 .26332 .68592 .25509 Mtetra
.638 .587 .781 r
.68592 .25509 .68929 .26332 .69597 .26089 .6926 .25276 Mtetra
.662 .32 0 r
.6926 .25276 .69597 .26089 .70299 .26422 .70054 .2722 Mtetra
0 0 0 r
.70054 .2722 .70299 .26422 .7097 .26159 .70684 .26181 Mtetra
.998 .842 .547 r
.70684 .26181 .7097 .26159 .71596 .25144 .7124 .23985 Mtetra
0 0 .516 r
.7124 .23985 .71596 .25144 .72308 .25494 .72032 .25615 Mtetra
.914 .517 .221 r
.72032 .25615 .72308 .25494 .73103 .27026 .72905 .28315 Mtetra
0 0 .126 r
.72905 .28315 .73103 .27026 .73779 .26692 .73497 .26672 Mtetra
.998 .779 .47 r
.73497 .26672 .73779 .26692 .74308 .24271 .73944 .23034 Mtetra
.287 .301 .701 r
.73944 .23034 .74308 .24271 .74959 .2364 .74691 .23719 Mtetra
.951 .598 .273 r
.74691 .23719 .74959 .2364 .75937 .27313 .75849 .29813 Mtetra
.871 .538 .417 r
.75849 .29813 .75937 .27313 .77103 .33149 .7707 .36326 Mtetra
.667 .363 .45 r
.7707 .36326 .77103 .33149 .78112 .36656 .7794 .38009 Mtetra
0 0 0 r
.7794 .38009 .78112 .36656 .78759 .35562 .78394 .34472 Mtetra
.958 .691 .488 r
.78394 .34472 .78759 .35562 .79138 .31329 .78671 .28991 Mtetra
.874 .612 .539 r
.78671 .28991 .79138 .31329 .79466 .26713 .79007 .24452 Mtetra
.81 .572 .579 r
.79007 .24452 .79466 .26713 .7989 .23365 .79487 .21751 Mtetra
.754 .562 .637 r
.79487 .21751 .7989 .23365 .80437 .21501 .80088 .20486 Mtetra
.701 .588 .726 r
.80088 .20486 .80437 .21501 .81072 .20638 .80756 .19963 Mtetra
.659 .642 .822 r
.80756 .19963 .81072 .20638 .81752 .20246 .81449 .19699 Mtetra
.629 .731 .921 r
.19503 .40826 .19888 .41187 .20443 .41011 .20055 .40679 Mtetra
.355 .64 .962 r
.20055 .40679 .20443 .41011 .20974 .4109 .20588 .40744 Mtetra
.71 .204 0 r
.20588 .40744 .20974 .4109 .21436 .41902 .21068 .41371 Mtetra
.943 .579 .244 r
.21068 .41371 .21436 .41902 .2177 .44136 .21448 .43084 Mtetra
.975 .669 .323 r
.21448 .43084 .2177 .44136 .21945 .48179 .21698 .46275 Mtetra
.966 .697 .268 r
.21698 .46275 .21945 .48179 .22055 .5312 .21863 .50518 Mtetra
0 0 .068 r
.21863 .50518 .22055 .5312 .22359 .56088 .22122 .53898 Mtetra
.601 .438 .633 r
.22122 .53898 .22359 .56088 .23127 .53884 .22723 .53584 Mtetra
.934 .714 .581 r
.22723 .53584 .23127 .53884 .24291 .46979 .23732 .4858 Mtetra
.997 .795 .512 r
.23732 .4858 .24291 .46979 .25387 .40634 .24857 .42034 Mtetra
.96 .864 .457 r
.24857 .42034 .25387 .40634 .26014 .39754 .2567 .38972 Mtetra
.942 .594 .184 r
.2567 .38972 .26014 .39754 .26303 .43057 .26063 .40957 Mtetra
0 0 .129 r
.26063 .40957 .26303 .43057 .26782 .44119 .26405 .43675 Mtetra
.886 .731 .684 r
.26405 .43675 .26782 .44119 .27602 .40833 .27087 .42203 Mtetra
.978 .857 .469 r
.27087 .42203 .27602 .40833 .28313 .38862 .27912 .38828 Mtetra
.319 0 0 r
.27912 .38828 .28313 .38862 .28732 .40786 .28462 .38987 Mtetra
0 0 .235 r
.28462 .38987 .28732 .40786 .29261 .41311 .28868 .41153 Mtetra
.922 .814 .722 r
.28868 .41153 .29261 .41311 .30006 .38801 .29524 .39939 Mtetra
.9 .867 .427 r
.29524 .39939 .30006 .38801 .30579 .38712 .30251 .37681 Mtetra
0 0 .317 r
.30251 .37681 .30579 .38712 .31046 .40231 .3073 .38991 Mtetra
.162 .201 .654 r
.3073 .38991 .31046 .40231 .31725 .38603 .31256 .39704 Mtetra
.922 .871 .441 r
.31256 .39704 .31725 .38603 .32351 .37744 .31983 .3734 Mtetra
0 .314 .796 r
.31983 .3734 .32351 .37744 .3283 .39283 .32534 .37686 Mtetra
0 0 .518 r
.32534 .37686 .3283 .39283 .33489 .37913 .33031 .38996 Mtetra
.899 .864 .421 r
.33031 .38996 .33489 .37913 .34112 .37118 .33743 .3675 Mtetra
.042 .433 .87 r
.33743 .3675 .34112 .37118 .34603 .38659 .34307 .37005 Mtetra
0 .003 .528 r
.34307 .37005 .34603 .38659 .35282 .3687 .34814 .38328 Mtetra
.797 .791 .294 r
.34814 .38328 .35282 .3687 .35864 .36854 .35534 .35799 Mtetra
0 0 .483 r
.35534 .35799 .35864 .36854 .36387 .38065 .36059 .36928 Mtetra
.179 .231 .68 r
.36059 .36928 .36387 .38065 .37093 .35612 .36613 .37581 Mtetra
0 0 0 r
.36613 .37581 .37093 .35612 .37602 .37261 .37336 .34799 Mtetra
0 0 .337 r
.37336 .34799 .37602 .37261 .38212 .36821 .37801 .3746 Mtetra
.939 .911 .528 r
.37801 .3746 .38212 .36821 .38873 .35183 .38471 .35729 Mtetra
0 0 0 r
.38471 .35729 .38873 .35183 .39332 .38404 .39083 .35273 Mtetra
.734 .55 0 r
.39083 .35273 .39332 .38404 .40078 .34626 .3947 .40413 Mtetra
0 0 .209 r
.3947 .40413 .40078 .34626 .40572 .3732 .40299 .34621 Mtetra
.074 .04 .51 r
.40299 .34621 .40572 .3732 .41122 .38746 .40826 .36529 Mtetra
.118 .092 .55 r
.40826 .36529 .41122 .38746 .41901 .33581 .41378 .37996 Mtetra
0 0 .136 r
.41378 .37996 .41901 .33581 .42333 .38839 .42151 .32974 Mtetra
.051 0 .442 r
.42151 .32974 .42333 .38839 .43076 .34356 .42617 .37299 Mtetra
0 0 0 r
.42617 .37299 .43076 .34356 .43658 .35172 .43346 .33237 Mtetra
.125 .113 .572 r
.43346 .33237 .43658 .35172 .44255 .35573 .43917 .34523 Mtetra
.692 .57 .713 r
.43917 .34523 .44255 .35573 .44928 .32976 .44539 .34028 Mtetra
0 0 0 r
.44539 .34028 .44928 .32976 .45489 .35099 .4518 .32738 Mtetra
.295 .213 .591 r
.4518 .32738 .45489 .35099 .46158 .32385 .45768 .3382 Mtetra
0 0 .002 r
.45768 .3382 .46158 .32385 .4674 .33973 .46417 .32102 Mtetra
.265 .217 .615 r
.46417 .32102 .4674 .33973 .47384 .32254 .47014 .33044 Mtetra
0 0 0 r
.47014 .33044 .47384 .32254 .47989 .32959 .4765 .31917 Mtetra
.423 .411 .741 r
.4765 .31917 .47989 .32959 .48618 .32139 .48265 .32184 Mtetra
.583 .945 .874 r
.48265 .32184 .48618 .32139 .49238 .32136 .4889 .31848 Mtetra
.805 .834 .873 r
.4889 .31848 .49238 .32136 .4986 .32079 .49517 .31358 Mtetra
.124 .303 .774 r
.49517 .31358 .4986 .32079 .50489 .31349 .50137 .31852 Mtetra
.818 .901 .489 r
.50137 .31852 .50489 .31349 .5111 .32236 .50772 .30598 Mtetra
.081 .109 .589 r
.50772 .30598 .5111 .32236 .51743 .30523 .51395 .31829 Mtetra
0 0 .01 r
.51395 .31829 .51743 .30523 .5237 .32579 .52029 .30224 Mtetra
.31 .227 .598 r
.52029 .30224 .5237 .32579 .53 .30052 .5266 .31292 Mtetra
.391 .066 .289 r
.5266 .31292 .53 .30052 .5364 .32372 .53295 .30988 Mtetra
.774 .588 .648 r
.53295 .30988 .5364 .32372 .54271 .31123 .53926 .29685 Mtetra
.794 .51 0 r
.53926 .29685 .54271 .31123 .54904 .30411 .54585 .32929 Mtetra
0 0 0 r
.54585 .32929 .54904 .30411 .55578 .339 .55191 .28358 Mtetra
.022 0 .449 r
.55191 .28358 .55578 .339 .56163 .28543 .55881 .33055 Mtetra
.279 .072 .41 r
.55881 .33055 .56163 .28543 .56869 .33289 .56503 .30804 Mtetra
.744 .528 .602 r
.56503 .30804 .56869 .33289 .57488 .31175 .57123 .28889 Mtetra
.78 .538 0 r
.57123 .28889 .57488 .31175 .58088 .28395 .57859 .34069 Mtetra
0 0 .302 r
.57859 .34069 .58088 .28395 .588 .31584 .58411 .28395 Mtetra
.509 .348 .598 r
.58411 .28395 .588 .31584 .59377 .28046 .59068 .28667 Mtetra
.77 .373 .302 r
.59068 .28667 .59377 .28046 .60058 .29239 .59748 .29781 Mtetra
.988 .833 .451 r
.59748 .29781 .60058 .29239 .60712 .29174 .60331 .26778 Mtetra
0 0 .49 r
.60331 .26778 .60712 .29174 .61315 .27232 .61052 .29172 Mtetra
.196 0 .305 r
.61052 .29172 .61315 .27232 .62031 .29131 .61679 .27943 Mtetra
.808 .622 .65 r
.61679 .27943 .62031 .29131 .62642 .27545 .62296 .26523 Mtetra
0 0 .263 r
.62296 .26523 .62642 .27545 .63292 .27182 .63028 .28582 Mtetra
0 0 .073 r
.63028 .28582 .63292 .27182 .64002 .28416 .63631 .26734 Mtetra
.652 .495 .657 r
.63631 .26734 .64002 .28416 .64599 .26549 .64278 .26189 Mtetra
.858 .433 0 r
.64278 .26189 .64599 .26549 .65282 .26918 .65018 .27944 Mtetra
0 0 0 r
.65018 .27944 .65282 .26918 .65989 .2774 .65615 .2611 Mtetra
.67 .509 .658 r
.65615 .2611 .65989 .2774 .6658 .25882 .66261 .25477 Mtetra
.857 .441 0 r
.66261 .25477 .6658 .25882 .67276 .2633 .67026 .27384 Mtetra
0 0 .061 r
.67026 .27384 .67276 .2633 .68007 .27385 .67645 .26098 Mtetra
.818 .62 .635 r
.67645 .26098 .68007 .27385 .68592 .25509 .68243 .24472 Mtetra
0 0 .367 r
.68243 .24472 .68592 .25509 .6926 .25276 .69027 .26392 Mtetra
.639 .275 .336 r
.69027 .26392 .6926 .25276 .70054 .2722 .69749 .27005 Mtetra
.987 .788 .55 r
.69749 .27005 .70054 .2722 .70684 .26181 .70287 .24349 Mtetra
.619 .466 .652 r
.70287 .24349 .70684 .26181 .7124 .23985 .70952 .23958 Mtetra
.925 .537 .207 r
.70952 .23958 .7124 .23985 .72032 .25615 .71832 .26981 Mtetra
.661 .31 .368 r
.71832 .26981 .72032 .25615 .72905 .28315 .72586 .27812 Mtetra
.972 .743 .533 r
.72586 .27812 .72905 .28315 .73497 .26672 .73069 .24512 Mtetra
.789 .563 .594 r
.73069 .24512 .73497 .26672 .73944 .23034 .73613 .22259 Mtetra
.822 .466 0 r
.73613 .22259 .73944 .23034 .74691 .23719 .74521 .25191 Mtetra
.909 .565 .378 r
.74521 .25191 .74691 .23719 .75849 .29813 .75692 .31475 Mtetra
.868 .521 .39 r
.75692 .31475 .75849 .29813 .7707 .36326 .76761 .35982 Mtetra
.704 .823 .939 r
.76761 .35982 .7707 .36326 .7794 .38009 .77473 .35661 Mtetra
.857 .602 .553 r
.77473 .35661 .7794 .38009 .78394 .34472 .7789 .31674 Mtetra
.856 .593 .54 r
.7789 .31674 .78394 .34472 .78671 .28991 .78228 .26913 Mtetra
.863 .611 .556 r
.78228 .26913 .78671 .28991 .79007 .24452 .78641 .23266 Mtetra
.874 .657 .605 r
.78641 .23266 .79007 .24452 .79487 .21751 .79171 .21115 Mtetra
.867 .736 .717 r
.79171 .21115 .79487 .21751 .80088 .20486 .79792 .20048 Mtetra
.787 .79 .856 r
.79792 .20048 .80088 .20486 .80756 .19963 .80463 .19541 Mtetra
.693 .768 .909 r
.80463 .19541 .80756 .19963 .81449 .19699 .81154 .19246 Mtetra
.669 .781 .933 r
.19109 .4053 .19503 .40826 .20055 .40679 .19668 .40326 Mtetra
.51 .697 .953 r
.19668 .40326 .20055 .40679 .20588 .40744 .20211 .40295 Mtetra
0 .003 .534 r
.20211 .40295 .20588 .40744 .21068 .41371 .207 .4082 Mtetra
.943 .577 .232 r
.207 .4082 .21068 .41371 .21448 .43084 .21081 .42509 Mtetra
.959 .649 .398 r
.21081 .42509 .21448 .43084 .21698 .46275 .21312 .45843 Mtetra
.949 .653 .443 r
.21312 .45843 .21698 .46275 .21863 .50518 .21443 .50403 Mtetra
.931 .625 .44 r
.21443 .50403 .21863 .50518 .22122 .53898 .21666 .54136 Mtetra
.152 0 0 r
.21666 .54136 .22122 .53898 .22723 .53584 .22248 .54047 Mtetra
.971 .763 .566 r
.22248 .54047 .22723 .53584 .23732 .4858 .2326 .49103 Mtetra
.967 .745 .551 r
.2326 .49103 .23732 .4858 .24857 .42034 .24406 .42436 Mtetra
.977 .787 .581 r
.24406 .42436 .24857 .42034 .2567 .38972 .25269 .38862 Mtetra
.873 .454 .216 r
.25269 .38862 .2567 .38972 .26063 .40957 .25735 .39942 Mtetra
.938 .613 .17 r
.25735 .39942 .26063 .40957 .26405 .43675 .26106 .42253 Mtetra
.674 .522 .671 r
.26106 .42253 .26405 .43675 .27087 .42203 .26716 .41694 Mtetra
.907 .712 .627 r
.26716 .41694 .27087 .42203 .27912 .38828 .27478 .39177 Mtetra
.789 .972 .68 r
.27478 .39177 .27912 .38828 .28462 .38987 .281 .38418 Mtetra
.826 .41 0 r
.281 .38418 .28462 .38987 .28868 .41153 .2858 .39548 Mtetra
.54 .42 .665 r
.2858 .39548 .28868 .41153 .29524 .39939 .29146 .39575 Mtetra
.899 .751 .689 r
.29146 .39575 .29524 .39939 .30251 .37681 .29818 .38139 Mtetra
0 0 0 r
.29818 .38139 .30251 .37681 .3073 .38991 .30416 .3773 Mtetra
.134 .178 .643 r
.30416 .3773 .3073 .38991 .31256 .39704 .30937 .38487 Mtetra
.667 .534 .693 r
.30937 .38487 .31256 .39704 .31983 .3734 .3154 .38046 Mtetra
.733 .864 .442 r
.3154 .38046 .31983 .3734 .32534 .37686 .32191 .3686 Mtetra
.117 .26 .736 r
.32191 .3686 .32534 .37686 .33031 .38996 .32735 .37373 Mtetra
.458 .363 .66 r
.32735 .37373 .33031 .38996 .33743 .3675 .33295 .37669 Mtetra
.755 .833 .373 r
.33295 .37669 .33743 .3675 .34307 .37005 .33967 .36119 Mtetra
.166 .276 .733 r
.33967 .36119 .34307 .37005 .34814 .38328 .34518 .36629 Mtetra
.336 .274 .638 r
.34518 .36629 .34814 .38328 .35534 .35799 .35067 .37267 Mtetra
0 0 0 r
.35067 .37267 .35534 .35799 .36059 .36928 .35764 .35155 Mtetra
0 .026 .535 r
.35764 .35155 .36059 .36928 .36613 .37581 .3628 .36506 Mtetra
.452 .421 .733 r
.3628 .36506 .36613 .37581 .37336 .34799 .3686 .36714 Mtetra
0 0 0 r
.3686 .36714 .37336 .34799 .37801 .3746 .37568 .34242 Mtetra
0 0 .278 r
.37568 .34242 .37801 .3746 .38471 .35729 .37992 .37893 Mtetra
0 0 .107 r
.37992 .37893 .38471 .35729 .39083 .35273 .38684 .35734 Mtetra
.78 .926 .557 r
.38684 .35734 .39083 .35273 .3947 .40413 .39321 .34749 Mtetra
0 0 .294 r
.39321 .34749 .3947 .40413 .40299 .34621 .39681 .40709 Mtetra
0 0 .18 r
.39681 .40709 .40299 .34621 .40826 .36529 .40536 .3423 Mtetra
.027 .022 .513 r
.40536 .3423 .40826 .36529 .41378 .37996 .41073 .35966 Mtetra
0 .013 .519 r
.41073 .35966 .41378 .37996 .42151 .32974 .41624 .37577 Mtetra
0 0 .139 r
.41624 .37577 .42151 .32974 .42617 .37299 .42402 .3234 Mtetra
0 0 .419 r
.42402 .3234 .42617 .37299 .43346 .33237 .42881 .36451 Mtetra
0 0 .071 r
.42881 .36451 .43346 .33237 .43917 .34523 .43606 .32476 Mtetra
.098 .087 .556 r
.43606 .32476 .43917 .34523 .44539 .34028 .44176 .33898 Mtetra
.931 .867 .754 r
.44176 .33898 .44539 .34028 .4518 .32738 .44814 .32877 Mtetra
.711 .982 .796 r
.44814 .32877 .4518 .32738 .45768 .3382 .45438 .32353 Mtetra
.475 .391 .681 r
.45438 .32353 .45768 .3382 .46417 .32102 .46047 .32585 Mtetra
.627 .844 .456 r
.46047 .32585 .46417 .32102 .47014 .33044 .4668 .31694 Mtetra
.469 .398 .695 r
.4668 .31694 .47014 .33044 .4765 .31917 .47293 .31926 Mtetra
.795 .99 .886 r
.47293 .31926 .4765 .31917 .48265 .32184 .4792 .31418 Mtetra
.642 .595 .786 r
.4792 .31418 .48265 .32184 .4889 .31848 .48544 .31193 Mtetra
.476 .542 .845 r
.48544 .31193 .4889 .31848 .49517 .31358 .49166 .31273 Mtetra
.901 .93 .826 r
.49166 .31273 .49517 .31358 .50137 .31852 .49798 .30533 Mtetra
.317 .302 .685 r
.49798 .30533 .50137 .31852 .50772 .30598 .50421 .31106 Mtetra
0 0 0 r
.50421 .31106 .50772 .30598 .51395 .31829 .51054 .30199 Mtetra
.428 .348 .664 r
.51054 .30199 .51395 .31829 .52029 .30224 .51683 .30611 Mtetra
.477 0 .037 r
.51683 .30611 .52029 .30224 .5266 .31292 .52317 .3073 Mtetra
.886 .732 .685 r
.52317 .3073 .5266 .31292 .53295 .30988 .52951 .29368 Mtetra
0 0 .147 r
.52951 .29368 .53295 .30988 .53926 .29685 .53597 .32405 Mtetra
0 0 .013 r
.53597 .32405 .53926 .29685 .54585 .32929 .54217 .28159 Mtetra
0 0 .403 r
.54217 .28159 .54585 .32929 .55191 .28358 .54892 .32947 Mtetra
.266 .061 .405 r
.54892 .32947 .55191 .28358 .55881 .33055 .55519 .30584 Mtetra
.73 .519 .605 r
.55519 .30584 .55881 .33055 .56503 .30804 .56147 .28889 Mtetra
.896 .613 .106 r
.56147 .28889 .56503 .30804 .57123 .28889 .56873 .34661 Mtetra
0 0 .259 r
.56873 .34661 .57123 .28889 .57859 .34069 .57432 .28266 Mtetra
.48 .301 .559 r
.57432 .28266 .57859 .34069 .58411 .28395 .58097 .29078 Mtetra
.815 .436 .338 r
.58097 .29078 .58411 .28395 .59068 .28667 .58784 .30686 Mtetra
.709 .657 .104 r
.58784 .30686 .59068 .28667 .59748 .29781 .59353 .26594 Mtetra
.176 .112 .54 r
.59353 .26594 .59748 .29781 .60331 .26778 .60059 .28723 Mtetra
.348 .074 .349 r
.60059 .28723 .60331 .26778 .61052 .29172 .60701 .28008 Mtetra
.841 .641 .632 r
.60701 .28008 .61052 .29172 .61679 .27943 .61312 .26215 Mtetra
0 0 .529 r
.61312 .26215 .61679 .27943 .62296 .26523 .62027 .27983 Mtetra
.085 0 .218 r
.62027 .27983 .62296 .26523 .63028 .28582 .62655 .26817 Mtetra
.704 .523 .642 r
.62655 .26817 .63028 .28582 .63631 .26734 .63289 .2587 Mtetra
0 0 .527 r
.63289 .2587 .63631 .26734 .64278 .26189 .64003 .27094 Mtetra
0 0 .075 r
.64003 .27094 .64278 .26189 .65018 .27944 .64642 .26248 Mtetra
.71 .531 .645 r
.64642 .26248 .65018 .27944 .65615 .2611 .65276 .25286 Mtetra
0 .121 .663 r
.65276 .25286 .65615 .2611 .66261 .25477 .65989 .26182 Mtetra
.402 .001 .159 r
.65989 .26182 .66261 .25477 .67026 .27384 .66663 .26081 Mtetra
.784 .601 .652 r
.66663 .26081 .67026 .27384 .67645 .26098 .67283 .24797 Mtetra
.499 .429 .709 r
.67283 .24797 .67645 .26098 .68243 .24472 .67971 .2495 Mtetra
.767 .336 .228 r
.67971 .2495 .68243 .24472 .69027 .26392 .68708 .25965 Mtetra
.836 .794 .812 r
.68708 .25965 .69027 .26392 .69749 .27005 .6936 .25287 Mtetra
.768 .566 .625 r
.6936 .25287 .69749 .27005 .70287 .24349 .69963 .23763 Mtetra
.013 .284 .782 r
.69963 .23763 .70287 .24349 .70952 .23958 .70686 .24325 Mtetra
.874 .468 .252 r
.70686 .24325 .70952 .23958 .71832 .26981 .71505 .26372 Mtetra
.612 .642 .857 r
.71505 .26372 .71832 .26981 .72586 .27812 .72196 .2622 Mtetra
.862 .627 .582 r
.72196 .2622 .72586 .27812 .73069 .24512 .72714 .23419 Mtetra
.809 .634 .664 r
.72714 .23419 .73069 .24512 .73613 .22259 .73328 .22164 Mtetra
.929 .545 .191 r
.73328 .22164 .73613 .22259 .74521 .25191 .74268 .25567 Mtetra
.946 .594 .302 r
.74268 .25567 .74521 .25191 .75692 .31475 .75436 .31841 Mtetra
.931 .56 .28 r
.75436 .31841 .75692 .31475 .76761 .35982 .76493 .36207 Mtetra
0 0 0 r
.76493 .36207 .76761 .35982 .77473 .35661 .77193 .35693 Mtetra
.997 .769 .435 r
.77193 .35693 .77473 .35661 .7789 .31674 .77594 .31432 Mtetra
.991 .741 .443 r
.77594 .31432 .7789 .31674 .78228 .26913 .77916 .26411 Mtetra
.98 .74 .499 r
.77916 .26411 .78228 .26913 .78641 .23266 .78322 .22635 Mtetra
.945 .744 .6 r
.78322 .22635 .78641 .23266 .79171 .21115 .78856 .20497 Mtetra
.858 .74 .732 r
.78856 .20497 .79171 .21115 .79792 .20048 .79486 .19518 Mtetra
.738 .733 .846 r
.79486 .19518 .79792 .20048 .80463 .19541 .80167 .19098 Mtetra
.662 .745 .911 r
.80167 .19098 .80463 .19541 .81154 .19246 .80864 .18856 Mtetra
.704 .784 .914 r
.18715 .40228 .19109 .4053 .19668 .40326 .19279 .39971 Mtetra
.682 .75 .903 r
.19279 .39971 .19668 .40326 .20211 .40295 .19842 .39746 Mtetra
.408 .54 .877 r
.19842 .39746 .20211 .40295 .207 .4082 .20372 .39859 Mtetra
0 0 .313 r
.20372 .39859 .207 .4082 .21081 .42509 .20804 .40989 Mtetra
.942 .66 .199 r
.20804 .40989 .21081 .42509 .21312 .45843 .2106 .44018 Mtetra
.985 .711 .351 r
.2106 .44018 .21312 .45843 .21443 .50403 .21123 .49199 Mtetra
.976 .692 .417 r
.21123 .49199 .21443 .50403 .21666 .54136 .21165 .54831 Mtetra
.838 .515 .442 r
.21165 .54831 .21666 .54136 .22248 .54047 .21546 .56964 Mtetra
.809 .766 .254 r
.21546 .56964 .22248 .54047 .2326 .49103 .22522 .5256 Mtetra
.988 .813 .425 r
.22522 .5256 .2326 .49103 .24406 .42436 .23836 .44161 Mtetra
1 .815 .496 r
.23836 .44161 .24406 .42436 .25269 .38862 .24886 .38512 Mtetra
.753 .259 0 r
.24886 .38512 .25269 .38862 .25735 .39942 .25381 .39235 Mtetra
.967 .65 .357 r
.25381 .39235 .25735 .39942 .26106 .42253 .25671 .4249 Mtetra
.642 .951 .744 r
.25671 .4249 .26106 .42253 .26716 .41694 .26278 .41995 Mtetra
.976 .788 .587 r
.26278 .41995 .26716 .41694 .27478 .39177 .27107 .38698 Mtetra
.795 .723 .784 r
.27107 .38698 .27478 .39177 .281 .38418 .27717 .38094 Mtetra
.92 .528 .222 r
.27717 .38094 .281 .38418 .2858 .39548 .28169 .39594 Mtetra
.893 .958 .833 r
.28169 .39594 .2858 .39548 .29146 .39575 .2879 .38897 Mtetra
.85 .688 .68 r
.2879 .38897 .29146 .39575 .29818 .38139 .29459 .37529 Mtetra
0 .187 .72 r
.29459 .37529 .29818 .38139 .30416 .3773 .29993 .38039 Mtetra
.034 0 0 r
.29993 .38039 .30416 .3773 .30937 .38487 .3058 .37833 Mtetra
.807 .682 .726 r
.3058 .37833 .30937 .38487 .3154 .38046 .31211 .36971 Mtetra
.266 .299 .71 r
.31211 .36971 .3154 .38046 .32191 .3686 .31755 .37458 Mtetra
0 0 0 r
.31755 .37458 .32191 .3686 .32735 .37373 .32374 .36801 Mtetra
.774 .694 .774 r
.32374 .36801 .32735 .37373 .33295 .37669 .32988 .36222 Mtetra
.051 .097 .591 r
.32988 .36222 .33295 .37669 .33967 .36119 .33508 .37222 Mtetra
0 0 0 r
.33508 .37222 .33967 .36119 .34518 .36629 .34178 .35731 Mtetra
.52 .494 .768 r
.34178 .35731 .34518 .36629 .35067 .37267 .34758 .35777 Mtetra
0 0 .462 r
.34758 .35777 .35067 .37267 .35764 .35155 .35265 .37224 Mtetra
0 0 0 r
.35265 .37224 .35764 .35155 .3628 .36506 .36 .34429 Mtetra
0 0 .442 r
.36 .34429 .3628 .36506 .3686 .36714 .36492 .36324 Mtetra
0 .185 .688 r
.36492 .36324 .3686 .36714 .37568 .34242 .37063 .36766 Mtetra
0 0 0 r
.37063 .36766 .37568 .34242 .37992 .37893 .37807 .33555 Mtetra
.726 .565 0 r
.37807 .33555 .37992 .37893 .38684 .35734 .38089 .40496 Mtetra
.158 0 .355 r
.38089 .40496 .38684 .35734 .39321 .34749 .38817 .37635 Mtetra
0 0 .032 r
.38817 .37635 .39321 .34749 .39681 .40709 .39565 .34097 Mtetra
0 0 .353 r
.39565 .34097 .39681 .40709 .40536 .3423 .39929 .40142 Mtetra
0 0 .139 r
.39929 .40142 .40536 .3423 .41073 .35966 .40791 .33407 Mtetra
0 0 .467 r
.40791 .33407 .41073 .35966 .41624 .37577 .41317 .35557 Mtetra
.541 .401 .64 r
.41317 .35557 .41624 .37577 .42402 .3234 .41924 .35578 Mtetra
0 0 .138 r
.41924 .35578 .42402 .3234 .42881 .36451 .42644 .32075 Mtetra
.061 0 .464 r
.42644 .32075 .42881 .36451 .43606 .32476 .43157 .35253 Mtetra
0 0 .018 r
.43157 .35253 .43606 .32476 .44176 .33898 .43872 .31579 Mtetra
0 0 .48 r
.43872 .31579 .44176 .33898 .44814 .32877 .4443 .33588 Mtetra
.9 .885 .459 r
.4443 .33588 .44814 .32877 .45438 .32353 .45088 .31769 Mtetra
0 .2 .729 r
.45088 .31769 .45438 .32353 .46047 .32585 .4569 .3232 Mtetra
.865 .839 .818 r
.4569 .3232 .46047 .32585 .4668 .31694 .46321 .31618 Mtetra
.142 .674 .86 r
.46321 .31618 .4668 .31694 .47293 .31926 .4694 .31616 Mtetra
.775 .82 .888 r
.4694 .31616 .47293 .31926 .4792 .31418 .47567 .31196 Mtetra
.386 .744 .992 r
.47567 .31196 .4792 .31418 .48544 .31193 .48189 .31178 Mtetra
.744 .981 .913 r
.48189 .31178 .48544 .31193 .49166 .31273 .48819 .30748 Mtetra
.519 .62 .892 r
.48819 .30748 .49166 .31273 .49798 .30533 .49444 .30741 Mtetra
0 0 0 r
.49444 .30741 .49798 .30533 .50421 .31106 .50074 .30544 Mtetra
.763 .707 .798 r
.50074 .30544 .50421 .31106 .51054 .30199 .50707 .30028 Mtetra
.787 .289 0 r
.50707 .30028 .51054 .30199 .51683 .30611 .51335 .30928 Mtetra
.993 .876 .561 r
.51335 .30928 .51683 .30611 .52317 .3073 .51974 .28874 Mtetra
0 0 .229 r
.51974 .28874 .52317 .3073 .52951 .29368 .52609 .31843 Mtetra
0 0 .025 r
.52609 .31843 .52951 .29368 .53597 .32405 .53242 .28198 Mtetra
.047 0 .473 r
.53242 .28198 .53597 .32405 .54217 .28159 .53894 .31563 Mtetra
.373 .131 .412 r
.53894 .31563 .54217 .28159 .54892 .32947 .54533 .30462 Mtetra
.746 .529 .601 r
.54533 .30462 .54892 .32947 .55519 .30584 .55163 .28527 Mtetra
.882 .608 .089 r
.55163 .28527 .55519 .30584 .56147 .28889 .5587 .34307 Mtetra
0 0 .22 r
.5587 .34307 .56147 .28889 .56873 .34661 .56448 .27882 Mtetra
.271 .142 .514 r
.56448 .27882 .56873 .34661 .57432 .28266 .57148 .31345 Mtetra
.694 .395 .464 r
.57148 .31345 .57432 .28266 .58097 .29078 .5784 .33353 Mtetra
0 0 .051 r
.5784 .33353 .58097 .29078 .58784 .30686 .5837 .2628 Mtetra
.194 .104 .519 r
.5837 .2628 .58784 .30686 .59353 .26594 .59082 .29072 Mtetra
.347 .092 .377 r
.59082 .29072 .59353 .26594 .60059 .28723 .59721 .28149 Mtetra
.933 .735 .612 r
.59721 .28149 .60059 .28723 .60701 .28008 .60326 .25917 Mtetra
0 0 .476 r
.60326 .25917 .60701 .28008 .61312 .26215 .61048 .28195 Mtetra
.003 0 .238 r
.61048 .28195 .61312 .26215 .62027 .27983 .61661 .26399 Mtetra
.656 .503 .664 r
.61661 .26399 .62027 .27983 .62655 .26817 .6231 .25869 Mtetra
0 .068 .62 r
.6231 .25869 .62655 .26817 .63289 .2587 .63012 .26908 Mtetra
0 0 .013 r
.63012 .26908 .63289 .2587 .64003 .27094 .63636 .25573 Mtetra
.541 .434 .682 r
.63636 .25573 .64003 .27094 .64642 .26248 .64308 .25595 Mtetra
.352 .478 .847 r
.64308 .25595 .64642 .26248 .65276 .25286 .64992 .25837 Mtetra
0 0 0 r
.64992 .25837 .65276 .25286 .65989 .26182 .65635 .25039 Mtetra
.441 .412 .731 r
.65635 .25039 .65989 .26182 .66663 .26081 .66325 .25312 Mtetra
.651 .608 .793 r
.66325 .25312 .66663 .26081 .67283 .24797 .66994 .25052 Mtetra
.649 .899 .569 r
.66994 .25052 .67283 .24797 .67971 .2495 .6764 .24301 Mtetra
0 .094 .652 r
.6764 .24301 .67971 .2495 .68708 .25965 .68368 .25149 Mtetra
.51 .52 .803 r
.68368 .25149 .68708 .25965 .6936 .25287 .6906 .25206 Mtetra
.991 .855 .607 r
.6906 .25206 .6936 .25287 .69963 .23763 .69652 .23413 Mtetra
0 .381 .836 r
.69652 .23413 .69963 .23763 .70686 .24325 .70363 .2378 Mtetra
.876 .493 .021 r
.70363 .2378 .70686 .24325 .71505 .26372 .71222 .26486 Mtetra
0 0 0 r
.71222 .26486 .71505 .26372 .72196 .2622 .71912 .26284 Mtetra
.999 .785 .463 r
.71912 .26284 .72196 .2622 .72714 .23419 .7238 .22653 Mtetra
.808 .683 .727 r
.7238 .22653 .72714 .23419 .73328 .22164 .73021 .21786 Mtetra
.946 .593 .207 r
.73021 .21786 .73328 .22164 .74268 .25567 .741 .27198 Mtetra
.92 .581 .38 r
.741 .27198 .74268 .25567 .75436 .31841 .7539 .35162 Mtetra
.769 .451 .447 r
.7539 .35162 .75436 .31841 .76493 .36207 .76414 .39016 Mtetra
.04 0 .315 r
.76414 .39016 .76493 .36207 .77193 .35693 .76957 .36331 Mtetra
.979 .748 .336 r
.76957 .36331 .77193 .35693 .77594 .31432 .77217 .30193 Mtetra
.953 .683 .489 r
.77217 .30193 .77594 .31432 .77916 .26411 .77491 .2454 Mtetra
.872 .622 .557 r
.77491 .2454 .77916 .26411 .78322 .22635 .77922 .21043 Mtetra
.789 .585 .624 r
.77922 .21043 .78322 .22635 .78856 .20497 .78503 .19445 Mtetra
.708 .587 .719 r
.78503 .19445 .78856 .20497 .79486 .19518 .7917 .18873 Mtetra
.644 .647 .839 r
.7917 .18873 .79486 .19518 .80167 .19098 .79868 .18647 Mtetra
.628 .727 .918 r
.79868 .18647 .80167 .19098 .80864 .18856 .80573 .1846 Mtetra
.686 .755 .904 r
.18323 .3988 .18715 .40228 .19279 .39971 .18886 .3965 Mtetra
.717 .776 .898 r
.18886 .3965 .19279 .39971 .19842 .39746 .19455 .39367 Mtetra
.668 .734 .899 r
.19455 .39367 .19842 .39746 .20372 .39859 .20017 .3916 Mtetra
.16 .33 .787 r
.20017 .3916 .20372 .39859 .20804 .40989 .20524 .39527 Mtetra
.712 .471 0 r
.20524 .39527 .20804 .40989 .2106 .44018 .20882 .41446 Mtetra
.907 .678 .174 r
.20882 .41446 .2106 .44018 .21123 .49199 .21003 .45923 Mtetra
.956 .722 .268 r
.21003 .45923 .21123 .49199 .21165 .54831 .20935 .5259 Mtetra
.978 .714 .312 r
.20935 .5259 .21165 .54831 .21546 .56964 .21001 .58072 Mtetra
0 0 0 r
.21001 .58072 .21546 .56964 .22522 .5256 .21672 .57131 Mtetra
.926 .796 .326 r
.21672 .57131 .22522 .5256 .23836 .44161 .23003 .4875 Mtetra
.949 .801 .35 r
.23003 .4875 .23836 .44161 .24886 .38512 .24365 .3972 Mtetra
.825 .848 .387 r
.24365 .3972 .24886 .38512 .25381 .39235 .25094 .37739 Mtetra
.98 .693 .325 r
.25094 .37739 .25381 .39235 .25671 .4249 .2528 .42164 Mtetra
.935 .573 .301 r
.2528 .42164 .25671 .4249 .26278 .41995 .2569 .44083 Mtetra
.951 .834 .4 r
.2569 .44083 .26278 .41995 .27107 .38698 .26615 .397 Mtetra
.988 .871 .519 r
.26615 .397 .27107 .38698 .27717 .38094 .27402 .36893 Mtetra
.935 .626 .168 r
.27402 .36893 .27717 .38094 .28169 .39594 .27762 .39557 Mtetra
.79 .31 .084 r
.27762 .39557 .28169 .39594 .2879 .38897 .2828 .40257 Mtetra
.973 .856 .46 r
.2828 .40257 .2879 .38897 .29459 .37529 .29097 .36929 Mtetra
.255 .434 .847 r
.29097 .36929 .29459 .37529 .29993 .38039 .29648 .37191 Mtetra
.908 .558 .094 r
.29648 .37191 .29993 .38039 .3058 .37833 .30088 .39102 Mtetra
.891 .853 .4 r
.30088 .39102 .3058 .37833 .31211 .36971 .30833 .36632 Mtetra
.765 .784 .869 r
.30833 .36632 .31211 .36971 .31755 .37458 .31435 .3623 Mtetra
.814 .518 0 r
.31435 .3623 .31755 .37458 .32374 .36801 .31876 .38349 Mtetra
.789 .788 .29 r
.31876 .38349 .32374 .36801 .32988 .36222 .32619 .35783 Mtetra
.467 .634 .927 r
.32619 .35783 .32988 .36222 .33508 .37222 .33197 .35808 Mtetra
.769 .501 0 r
.33197 .35808 .33508 .37222 .34178 .35731 .33643 .38116 Mtetra
.692 .691 .156 r
.33643 .38116 .34178 .35731 .34758 .35777 .34433 .34586 Mtetra
0 0 .246 r
.34433 .34586 .34758 .35777 .35265 .37224 .34926 .36245 Mtetra
.819 .487 0 r
.34926 .36245 .35265 .37224 .36 .34429 .35417 .38082 Mtetra
0 0 0 r
.35417 .38082 .36 .34429 .36492 .36324 .36251 .33419 Mtetra
.819 .607 .052 r
.36251 .33419 .36492 .36324 .37063 .36766 .36582 .38615 Mtetra
.401 .108 .348 r
.36582 .38615 .37063 .36766 .37807 .33555 .37202 .38197 Mtetra
0 0 .222 r
.37202 .38197 .37807 .33555 .38089 .40496 .37997 .33968 Mtetra
0 0 .118 r
.37997 .33968 .38089 .40496 .38817 .37635 .38206 .42764 Mtetra
0 0 .12 r
.38206 .42764 .38817 .37635 .39565 .34097 .39065 .36949 Mtetra
0 0 .053 r
.39065 .36949 .39565 .34097 .39929 .40142 .39806 .33578 Mtetra
.006 0 .416 r
.39806 .33578 .39929 .40142 .40791 .33407 .40215 .38599 Mtetra
0 0 .084 r
.40215 .38599 .40791 .33407 .41317 .35557 .41061 .32183 Mtetra
.144 .073 .511 r
.41061 .32183 .41317 .35557 .41924 .35578 .41591 .34291 Mtetra
.745 .578 .667 r
.41591 .34291 .41924 .35578 .42644 .32075 .42232 .33318 Mtetra
0 0 0 r
.42232 .33318 .42644 .32075 .43157 .35253 .42889 .31763 Mtetra
.349 .222 .562 r
.42889 .31763 .43157 .35253 .43872 .31579 .43462 .33034 Mtetra
0 0 0 r
.43462 .33034 .43872 .31579 .4443 .33588 .44125 .31167 Mtetra
.331 .236 .595 r
.44125 .31167 .4443 .33588 .45088 .31769 .44714 .32126 Mtetra
.879 .958 .617 r
.44714 .32126 .45088 .31769 .4569 .3232 .45354 .3104 Mtetra
.435 .384 .702 r
.45354 .3104 .4569 .3232 .46321 .31618 .45965 .31334 Mtetra
.813 .836 .867 r
.45965 .31334 .46321 .31618 .4694 .31616 .46594 .3082 Mtetra
.584 .559 .792 r
.46594 .3082 .4694 .31616 .47567 .31196 .47216 .30728 Mtetra
.661 .708 .883 r
.47216 .30728 .47567 .31196 .48189 .31178 .47842 .30508 Mtetra
.693 .646 .798 r
.47842 .30508 .48189 .31178 .48819 .30748 .4847 .30167 Mtetra
.458 .564 .875 r
.4847 .30167 .48819 .30748 .49444 .30741 .49096 .30246 Mtetra
.827 .744 .772 r
.49096 .30246 .49444 .30741 .50074 .30544 .49731 .29502 Mtetra
.139 .228 .695 r
.49731 .29502 .50074 .30544 .50707 .30028 .50355 .30197 Mtetra
.982 .91 .64 r
.50355 .30197 .50707 .30028 .51335 .30928 .50996 .28707 Mtetra
.095 .081 .55 r
.50996 .28707 .51335 .30928 .51974 .28874 .51624 .30325 Mtetra
0 0 0 r
.51624 .30325 .51974 .28874 .52609 .31843 .52264 .28306 Mtetra
.309 .196 .558 r
.52264 .28306 .52609 .31843 .53242 .28198 .52902 .29877 Mtetra
.497 .185 .368 r
.52902 .29877 .53242 .28198 .53894 .31563 .53544 .29844 Mtetra
.803 .589 .613 r
.53544 .29844 .53894 .31563 .54533 .30462 .54177 .27796 Mtetra
.775 .548 0 r
.54177 .27796 .54533 .30462 .55163 .28527 .54863 .33513 Mtetra
0 0 .217 r
.54863 .33513 .55163 .28527 .5587 .34307 .55464 .27721 Mtetra
.238 .117 .506 r
.55464 .27721 .5587 .34307 .56448 .27882 .56154 .31374 Mtetra
.782 .479 .475 r
.56154 .31374 .56448 .27882 .57148 .31345 .56873 .35833 Mtetra
.728 .624 .059 r
.56873 .35833 .57148 .31345 .5784 .33353 .574 .2687 Mtetra
.191 .086 .496 r
.574 .2687 .5784 .33353 .5837 .2628 .58127 .30942 Mtetra
.485 .234 .458 r
.58127 .30942 .5837 .2628 .59082 .29072 .58782 .30491 Mtetra
.951 .776 .32 r
.58782 .30491 .59082 .29072 .59721 .28149 .59332 .25299 Mtetra
0 0 .309 r
.59332 .25299 .59721 .28149 .60326 .25917 .60089 .2938 Mtetra
.164 0 .356 r
.60089 .2938 .60326 .25917 .61048 .28195 .60695 .27036 Mtetra
.846 .644 .63 r
.60695 .27036 .61048 .28195 .61661 .26399 .61308 .25198 Mtetra
.752 .451 0 r
.61308 .25198 .61661 .26399 .6231 .25869 .62061 .28053 Mtetra
0 0 .167 r
.62061 .28053 .6231 .25869 .63012 .26908 .62647 .25416 Mtetra
.626 .491 .677 r
.62647 .25416 .63012 .26908 .63636 .25573 .63305 .2507 Mtetra
.84 .434 0 r
.63305 .2507 .63636 .25573 .64308 .25595 .64048 .26966 Mtetra
0 0 0 r
.64048 .26966 .64308 .25595 .64992 .25837 .64632 .2456 Mtetra
.527 .449 .711 r
.64632 .2456 .64992 .25837 .65635 .25039 .6531 .24619 Mtetra
.838 .417 0 r
.6531 .24619 .65635 .25039 .66325 .25312 .66068 .26402 Mtetra
0 0 0 r
.66068 .26402 .66325 .25312 .66994 .25052 .66649 .24148 Mtetra
.709 .609 .743 r
.66649 .24148 .66994 .25052 .6764 .24301 .67308 .23647 Mtetra
.864 .491 0 r
.67308 .23647 .6764 .24301 .68368 .25149 .68128 .26319 Mtetra
0 0 .116 r
.68128 .26319 .68368 .25149 .6906 .25206 .68754 .2504 Mtetra
.991 .789 .534 r
.68754 .2504 .6906 .25206 .69652 .23413 .69291 .222 Mtetra
0 0 .288 r
.69291 .222 .69652 .23413 .70363 .2378 .70123 .24687 Mtetra
.891 .53 .352 r
.70123 .24687 .70363 .2378 .71222 .26486 .71041 .28362 Mtetra
0 0 .154 r
.71041 .28362 .71222 .26486 .71912 .26284 .71592 .25813 Mtetra
.98 .73 .484 r
.71592 .25813 .71912 .26284 .7238 .22653 .71998 .2114 Mtetra
0 0 .529 r
.71998 .2114 .7238 .22653 .73021 .21786 .72819 .22989 Mtetra
.938 .599 .362 r
.72819 .22989 .73021 .21786 .741 .27198 .74128 .31744 Mtetra
.828 .511 .453 r
.74128 .31744 .741 .27198 .7539 .35162 .75421 .3968 Mtetra
.552 .283 .461 r
.75421 .3968 .7539 .35162 .76414 .39016 .762 .40076 Mtetra
.949 .743 .28 r
.762 .40076 .76414 .39016 .76957 .36331 .76496 .3404 Mtetra
.922 .643 .495 r
.76496 .3404 .76957 .36331 .77217 .30193 .76676 .26855 Mtetra
.838 .573 .539 r
.76676 .26855 .77217 .30193 .77491 .2454 .77004 .21884 Mtetra
.769 .537 .582 r
.77004 .21884 .77491 .2454 .77922 .21043 .77525 .19482 Mtetra
.704 .536 .657 r
.77525 .19482 .77922 .21043 .78503 .19445 .78171 .18646 Mtetra
.642 .601 .792 r
.78171 .18646 .78503 .19445 .7917 .18873 .78867 .18396 Mtetra
.613 .706 .911 r
.78867 .18396 .7917 .18873 .79868 .18647 .79572 .18233 Mtetra
.641 .754 .931 r
.79572 .18233 .79868 .18647 .80573 .1846 .80276 .18021 Mtetra
.653 .72 .898 r
.17935 .39482 .18323 .3988 .18886 .3965 .18493 .39298 Mtetra
.679 .753 .906 r
.18493 .39298 .18886 .3965 .19455 .39367 .19057 .39076 Mtetra
.704 .793 .92 r
.19057 .39076 .19455 .39367 .20017 .3916 .19625 .38818 Mtetra
.558 .724 .952 r
.19625 .38818 .20017 .3916 .20524 .39527 .20177 .3874 Mtetra
0 0 .496 r
.20177 .3874 .20524 .39527 .20882 .41446 .20643 .39535 Mtetra
.823 .591 .037 r
.20643 .39535 .20882 .41446 .21003 .45923 .20913 .42394 Mtetra
.878 .678 .154 r
.20913 .42394 .21003 .45923 .20935 .5259 .20918 .4816 Mtetra
.875 .686 .162 r
.20918 .4816 .20935 .5259 .21001 .58072 .20804 .5541 Mtetra
.761 .573 0 r
.20804 .5541 .21001 .58072 .21672 .57131 .21043 .59135 Mtetra
.985 .841 .457 r
.21043 .59135 .21672 .57131 .23003 .4875 .22065 .54345 Mtetra
.938 .792 .33 r
.22065 .54345 .23003 .4875 .24365 .3972 .23586 .43772 Mtetra
.866 .772 .269 r
.23586 .43772 .24365 .3972 .25094 .37739 .24732 .37119 Mtetra
.961 .632 .331 r
.24732 .37119 .25094 .37739 .2528 .42164 .2506 .39815 Mtetra
.968 .708 .281 r
.2506 .39815 .2528 .42164 .2569 .44083 .25161 .45363 Mtetra
.843 .848 .386 r
.25161 .45363 .2569 .44083 .26615 .397 .25915 .43183 Mtetra
.899 .789 .303 r
.25915 .43183 .26615 .397 .27402 .36893 .2699 .36919 Mtetra
.787 .32 .129 r
.2699 .36919 .27402 .36893 .27762 .39557 .275 .37616 Mtetra
.944 .676 .213 r
.275 .37616 .27762 .39557 .2828 .40257 .27745 .41851 Mtetra
.869 .829 .356 r
.27745 .41851 .2828 .40257 .29097 .36929 .28536 .38997 Mtetra
.847 .795 .3 r
.28536 .38997 .29097 .36929 .29648 .37191 .29368 .35456 Mtetra
.918 .646 .156 r
.29368 .35456 .29648 .37191 .30088 .39102 .29685 .39026 Mtetra
.434 0 0 r
.29685 .39026 .30088 .39102 .30833 .36632 .30246 .39284 Mtetra
.817 .759 .244 r
.30246 .39284 .30833 .36632 .31435 .3623 .31124 .34891 Mtetra
.898 .602 .1 r
.31124 .34891 .31435 .3623 .31876 .38349 .3152 .37623 Mtetra
.806 .425 0 r
.3152 .37623 .31876 .38349 .32619 .35783 .32016 .38974 Mtetra
.72 .689 .148 r
.32016 .38974 .32619 .35783 .33197 .35808 .32898 .3422 Mtetra
.901 .621 .117 r
.32898 .3422 .33197 .35808 .33643 .38116 .3328 .37516 Mtetra
.809 .398 0 r
.3328 .37516 .33643 .38116 .34433 .34586 .33798 .38732 Mtetra
0 0 0 r
.33798 .38732 .34433 .34586 .34926 .36245 .34688 .33466 Mtetra
.864 .637 .103 r
.34688 .33466 .34926 .36245 .35417 .38082 .34985 .38753 Mtetra
.066 0 0 r
.34985 .38753 .35417 .38082 .36251 .33419 .35605 .38308 Mtetra
0 0 .172 r
.35605 .38308 .36251 .33419 .36582 .38615 .3645 .33452 Mtetra
.81 .631 .076 r
.3645 .33452 .36582 .38615 .37202 .38197 .36595 .42593 Mtetra
.014 0 .288 r
.36595 .42593 .37202 .38197 .37997 .33968 .3736 .39318 Mtetra
0 0 .122 r
.3736 .39318 .37997 .33968 .38206 .42764 .38237 .33328 Mtetra
.13 .016 .444 r
.38237 .33328 .38206 .42764 .39065 .36949 .38582 .39184 Mtetra
.937 .799 .337 r
.38582 .39184 .39065 .36949 .39806 .33578 .39413 .33867 Mtetra
.908 .974 .681 r
.39413 .33867 .39806 .33578 .40215 .38599 .40056 .32849 Mtetra
.294 .155 .516 r
.40056 .32849 .40215 .38599 .41061 .32183 .40566 .35327 Mtetra
0 0 .062 r
.40566 .35327 .41061 .32183 .41591 .34291 .41312 .31538 Mtetra
.19 .122 .545 r
.41312 .31538 .41591 .34291 .42232 .33318 .41864 .33111 Mtetra
.885 .858 .81 r
.41864 .33111 .42232 .33318 .42889 .31763 .42499 .32351 Mtetra
0 0 0 r
.42499 .32351 .42889 .31763 .43462 .33034 .43136 .31488 Mtetra
.305 .269 .653 r
.43136 .31488 .43462 .33034 .44125 .31167 .43729 .32152 Mtetra
0 0 0 r
.43729 .32152 .44125 .31167 .44714 .32126 .44375 .30987 Mtetra
.337 .34 .715 r
.44375 .30987 .44714 .32126 .45354 .3104 .44979 .31424 Mtetra
.562 .847 .515 r
.44979 .31424 .45354 .3104 .45965 .31334 .45613 .3073 Mtetra
.511 .583 .863 r
.45613 .3073 .45965 .31334 .46594 .3082 .46232 .30746 Mtetra
.692 .949 .956 r
.46232 .30746 .46594 .3082 .47216 .30728 .4686 .30414 Mtetra
.669 .799 .944 r
.4686 .30414 .47216 .30728 .47842 .30508 .47487 .30182 Mtetra
.546 .749 .97 r
.47487 .30182 .47842 .30508 .4847 .30167 .48114 .30091 Mtetra
.796 .961 .917 r
.48114 .30091 .4847 .30167 .49096 .30246 .48747 .29622 Mtetra
.301 .457 .85 r
.48747 .29622 .49096 .30246 .49731 .29502 .49373 .29882 Mtetra
.719 .911 .551 r
.49373 .29882 .49731 .29502 .50355 .30197 .50012 .29 Mtetra
.169 .222 .674 r
.50012 .29 .50355 .30197 .50996 .28707 .5064 .29752 Mtetra
0 0 0 r
.5064 .29752 .50996 .28707 .51624 .30325 .5128 .28601 Mtetra
.395 .319 .652 r
.5128 .28601 .51624 .30325 .52264 .28306 .51916 .29127 Mtetra
.559 .171 .263 r
.51916 .29127 .52264 .28306 .52902 .29877 .52555 .29365 Mtetra
.926 .742 .633 r
.52555 .29365 .52902 .29877 .53544 .29844 .53194 .27379 Mtetra
0 0 .271 r
.53194 .27379 .53544 .29844 .54177 .27796 .5385 .30945 Mtetra
0 0 .205 r
.5385 .30945 .54177 .27796 .54863 .33513 .54479 .27547 Mtetra
.445 .272 .551 r
.54479 .27547 .54863 .33513 .55464 .27721 .55136 .28766 Mtetra
.891 .558 .41 r
.55136 .28766 .55464 .27721 .56154 .31374 .55833 .33118 Mtetra
.961 .771 .326 r
.55833 .33118 .56154 .31374 .56873 .35833 .56415 .26731 Mtetra
.155 .048 .471 r
.56415 .26731 .56873 .35833 .574 .2687 .57157 .32824 Mtetra
.625 .354 .488 r
.57157 .32824 .574 .2687 .58127 .30942 .57856 .34708 Mtetra
.837 .688 .151 r
.57856 .34708 .58127 .30942 .58782 .30491 .58355 .25514 Mtetra
0 0 .435 r
.58355 .25514 .58782 .30491 .59332 .25299 .5911 .30181 Mtetra
.481 .232 .459 r
.5911 .30181 .59332 .25299 .60089 .2938 .59768 .29664 Mtetra
.996 .764 .458 r
.59768 .29664 .60089 .2938 .60695 .27036 .60305 .24411 Mtetra
0 0 .19 r
.60305 .24411 .60695 .27036 .61308 .25198 .61098 .29149 Mtetra
.29 .074 .403 r
.61098 .29149 .61308 .25198 .62061 .28053 .61716 .27239 Mtetra
.936 .705 .563 r
.61716 .27239 .62061 .28053 .62647 .25416 .62282 .23904 Mtetra
.816 .527 0 r
.62282 .23904 .62647 .25416 .63305 .2507 .63092 .28036 Mtetra
.183 0 .35 r
.63092 .28036 .63305 .2507 .64048 .26966 .63702 .26089 Mtetra
.922 .698 .581 r
.63702 .26089 .64048 .26966 .64632 .2456 .64271 .23263 Mtetra
.824 .518 0 r
.64271 .23263 .64632 .2456 .6531 .24619 .65102 .27069 Mtetra
.349 .092 .377 r
.65102 .27069 .6531 .24619 .66068 .26402 .65749 .26153 Mtetra
.985 .758 .513 r
.65749 .26153 .66068 .26402 .66649 .24148 .66268 .22448 Mtetra
0 0 .274 r
.66268 .22448 .66649 .24148 .67308 .23647 .67099 .25592 Mtetra
.749 .415 .419 r
.67099 .25592 .67308 .23647 .68128 .26319 .67893 .27673 Mtetra
.889 .743 .237 r
.67893 .27673 .68128 .26319 .68754 .2504 .68352 .23063 Mtetra
.674 .494 .635 r
.68352 .23063 .68754 .2504 .69291 .222 .68998 .22244 Mtetra
.951 .602 .288 r
.68998 .22244 .69291 .222 .70123 .24687 .70016 .28015 Mtetra
.644 .346 .452 r
.70016 .28015 .70123 .24687 .71041 .28362 .70807 .29431 Mtetra
.962 .752 .307 r
.70807 .29431 .71041 .28362 .71592 .25813 .71153 .2341 Mtetra
.806 .568 .577 r
.71153 .2341 .71592 .25813 .71998 .2114 .71676 .20567 Mtetra
.95 .609 .212 r
.71676 .20567 .71998 .2114 .72819 .22989 .72802 .27075 Mtetra
.871 .549 .439 r
.72802 .27075 .72819 .22989 .74128 .31744 .74217 .37352 Mtetra
.718 .421 .475 r
.74217 .37352 .74128 .31744 .75421 .3968 .75265 .41672 Mtetra
0 0 .001 r
.75265 .41672 .75421 .3968 .762 .40076 .75708 .37364 Mtetra
.914 .633 .496 r
.75708 .37364 .762 .40076 .76496 .3404 .75871 .29533 Mtetra
.828 .557 .53 r
.75871 .29533 .76496 .3404 .76676 .26855 .76117 .23227 Mtetra
.77 .523 .561 r
.76117 .23227 .76676 .26855 .77004 .21884 .76571 .19862 Mtetra
.723 .524 .621 r
.76571 .19862 .77004 .21884 .77525 .19482 .77184 .18587 Mtetra
.677 .598 .76 r
.77184 .18587 .77525 .19482 .78171 .18646 .77868 .18205 Mtetra
.628 .734 .923 r
.77868 .18205 .78171 .18646 .78867 .18396 .78571 .18015 Mtetra
.645 .776 .943 r
.78571 .18015 .78867 .18396 .79572 .18233 .79273 .17793 Mtetra
.671 .753 .913 r
.79273 .17793 .79572 .18233 .80276 .18021 .79973 .17533 Mtetra
.643 .702 .889 r
.17549 .39051 .17935 .39482 .18493 .39298 .18106 .3888 Mtetra
.638 .707 .897 r
.18106 .3888 .18493 .39298 .19057 .39076 .18664 .38718 Mtetra
.638 .74 .922 r
.18664 .38718 .19057 .39076 .19625 .38818 .19223 .38553 Mtetra
.573 .781 .977 r
.19223 .38553 .19625 .38818 .20177 .3874 .19779 .3844 Mtetra
0 .341 .775 r
.19779 .3844 .20177 .3874 .20643 .39535 .20298 .38704 Mtetra
.869 .512 .013 r
.20298 .38704 .20643 .39535 .20913 .42394 .20701 .40176 Mtetra
.903 .663 .156 r
.20701 .40176 .20913 .42394 .20918 .4816 .20881 .44014 Mtetra
.849 .668 .13 r
.20881 .44014 .20918 .4816 .20804 .5541 .20828 .50475 Mtetra
0 0 .011 r
.20828 .50475 .20804 .5541 .21043 .59135 .20808 .56829 Mtetra
.428 .308 .614 r
.20808 .56829 .21043 .59135 .22065 .54345 .2135 .57323 Mtetra
.996 .812 .453 r
.2135 .57323 .22065 .54345 .23586 .43772 .22665 .49259 Mtetra
.925 .787 .314 r
.22665 .49259 .23586 .43772 .24732 .37119 .24128 .39223 Mtetra
0 0 0 r
.24128 .39223 .24732 .37119 .2506 .39815 .24885 .36974 Mtetra
.959 .713 .266 r
.24885 .36974 .2506 .39815 .25161 .45363 .24917 .43211 Mtetra
.807 .585 .025 r
.24917 .43211 .25161 .45363 .25915 .43183 .25215 .46533 Mtetra
.921 .801 .33 r
.25215 .46533 .25915 .43183 .2699 .36919 .26309 .40212 Mtetra
.722 .7 .164 r
.26309 .40212 .2699 .36919 .275 .37616 .27249 .35577 Mtetra
.957 .69 .245 r
.27249 .35577 .275 .37616 .27745 .41851 .2745 .40283 Mtetra
.774 .521 0 r
.2745 .40283 .27745 .41851 .28536 .38997 .27844 .42683 Mtetra
.844 .758 .245 r
.27844 .42683 .28536 .38997 .29368 .35456 .28882 .36529 Mtetra
.205 0 .156 r
.28882 .36529 .29368 .35456 .29685 .39026 .29492 .36018 Mtetra
.866 .65 .118 r
.29492 .36018 .29685 .39026 .30246 .39284 .2969 .41375 Mtetra
.848 .793 .297 r
.2969 .41375 .30246 .39284 .31124 .34891 .30526 .37727 Mtetra
0 0 0 r
.30526 .37727 .31124 .34891 .3152 .37623 .31329 .34425 Mtetra
.866 .652 .12 r
.31329 .34425 .3152 .37623 .32016 .38974 .31527 .40259 Mtetra
.801 .817 .335 r
.31527 .40259 .32016 .38974 .32898 .3422 .32257 .38062 Mtetra
0 0 .053 r
.32257 .38062 .32898 .3422 .3328 .37516 .33111 .33728 Mtetra
.829 .634 .085 r
.33111 .33728 .3328 .37516 .33798 .38732 .33301 .40343 Mtetra
.676 .722 .209 r
.33301 .40343 .33798 .38732 .34688 .33466 .34035 .37964 Mtetra
0 0 .157 r
.34035 .37964 .34688 .33466 .34985 .38753 .34878 .33513 Mtetra
.731 .582 .006 r
.34878 .33513 .34985 .38753 .35605 .38308 .35027 .41667 Mtetra
0 0 .094 r
.35027 .41667 .35605 .38308 .3645 .33452 .3582 .38067 Mtetra
0 0 .203 r
.3582 .38067 .3645 .33452 .36595 .42593 .36636 .33796 Mtetra
0 0 .318 r
.36636 .33796 .36595 .42593 .3736 .39318 .3684 .4191 Mtetra
.859 .767 .26 r
.3684 .4191 .3736 .39318 .38237 .33328 .37684 .36922 Mtetra
0 0 0 r
.37684 .36922 .38237 .33328 .38582 .39184 .38521 .31732 Mtetra
.232 .099 .485 r
.38521 .31732 .38582 .39184 .39413 .33867 .3896 .35472 Mtetra
.75 .75 .235 r
.3896 .35472 .39413 .33867 .40056 .32849 .39679 .32738 Mtetra
.942 .853 .724 r
.39679 .32738 .40056 .32849 .40566 .35327 .4033 .31544 Mtetra
.304 .183 .544 r
.4033 .31544 .40566 .35327 .41312 .31538 .40876 .33124 Mtetra
0 0 0 r
.40876 .33124 .41312 .31538 .41864 .33111 .41556 .31113 Mtetra
.365 .278 .623 r
.41556 .31113 .41864 .33111 .42499 .32351 .42142 .31785 Mtetra
.666 .668 .842 r
.42142 .31785 .42499 .32351 .43136 .31488 .42761 .31543 Mtetra
.907 .972 .801 r
.42761 .31543 .43136 .31488 .43729 .32152 .43397 .30756 Mtetra
.295 .278 .669 r
.43397 .30756 .43729 .32152 .44375 .30987 .43994 .31372 Mtetra
.85 .951 .6 r
.43994 .31372 .44375 .30987 .44979 .31424 .44639 .30315 Mtetra
.298 .32 .716 r
.44639 .30315 .44979 .31424 .45613 .3073 .45245 .308 Mtetra
.887 .987 .806 r
.45245 .308 .45613 .3073 .46232 .30746 .45882 .30059 Mtetra
.462 .526 .837 r
.45882 .30059 .46232 .30746 .4686 .30414 .46502 .30158 Mtetra
.745 .852 .93 r
.46502 .30158 .4686 .30414 .47487 .30182 .47132 .29806 Mtetra
.706 .774 .904 r
.47132 .29806 .47487 .30182 .48114 .30091 .47763 .29512 Mtetra
.477 .577 .877 r
.47763 .29512 .48114 .30091 .48747 .29622 .4839 .29565 Mtetra
.893 .95 .835 r
.4839 .29565 .48747 .29622 .49373 .29882 .49028 .28852 Mtetra
.316 .348 .737 r
.49028 .28852 .49373 .29882 .50012 .29 .49655 .29284 Mtetra
.841 .967 .646 r
.49655 .29284 .50012 .29 .5064 .29752 .50296 .28349 Mtetra
.449 .382 .69 r
.50296 .28349 .5064 .29752 .5128 .28601 .5093 .28634 Mtetra
.331 .815 .822 r
.5093 .28634 .5128 .28601 .51916 .29127 .51568 .28444 Mtetra
.843 .701 .706 r
.51568 .28444 .51916 .29127 .52555 .29365 .52209 .2735 Mtetra
.032 .049 .543 r
.52209 .2735 .52555 .29365 .53194 .27379 .52851 .28973 Mtetra
0 0 .009 r
.52851 .28973 .53194 .27379 .5385 .30945 .5349 .26833 Mtetra
.424 .271 .568 r
.5349 .26833 .5385 .30945 .54479 .27547 .54139 .27841 Mtetra
.888 .507 .307 r
.54139 .27841 .54479 .27547 .55136 .28766 .54804 .30007 Mtetra
.956 .798 .353 r
.54804 .30007 .55136 .28766 .55833 .33118 .55418 .25662 Mtetra
.107 .018 .462 r
.55418 .25662 .55833 .33118 .56415 .26731 .56129 .31075 Mtetra
.733 .439 .482 r
.56129 .31075 .56415 .26731 .57157 .32824 .56844 .34841 Mtetra
.974 .758 .333 r
.56844 .34841 .57157 .32824 .57856 .34708 .5738 .26204 Mtetra
.262 .128 .502 r
.5738 .26204 .57856 .34708 .58355 .25514 .58117 .30605 Mtetra
.66 .379 .483 r
.58117 .30605 .58355 .25514 .5911 .30181 .58834 .32992 Mtetra
.903 .727 .224 r
.58834 .32992 .5911 .30181 .59768 .29664 .59326 .2465 Mtetra
.016 0 .456 r
.59326 .2465 .59768 .29664 .60305 .24411 .60094 .29008 Mtetra
.616 .338 .474 r
.60094 .29008 .60305 .24411 .61098 .29149 .60804 .30361 Mtetra
.984 .765 .362 r
.60804 .30361 .61098 .29149 .61716 .27239 .61289 .23625 Mtetra
0 0 .407 r
.61289 .23625 .61716 .27239 .62282 .23904 .62083 .27713 Mtetra
.626 .34 .463 r
.62083 .27713 .62282 .23904 .63092 .28036 .62805 .29013 Mtetra
.986 .768 .37 r
.62805 .29013 .63092 .28036 .63702 .26089 .63277 .22999 Mtetra
0 0 .471 r
.63277 .22999 .63702 .26089 .64271 .23263 .64066 .26068 Mtetra
.747 .432 .45 r
.64066 .26068 .64271 .23263 .65102 .27069 .64861 .2888 Mtetra
.885 .729 .218 r
.64861 .2888 .65102 .27069 .65749 .26153 .65313 .23169 Mtetra
.484 .335 .602 r
.65313 .23169 .65749 .26153 .66268 .22448 .66013 .23572 Mtetra
.911 .569 .381 r
.66013 .23572 .66268 .22448 .67099 .25592 .66953 .29057 Mtetra
.038 0 .322 r
.66953 .29057 .67099 .25592 .67893 .27673 .67504 .25973 Mtetra
.91 .651 .533 r
.67504 .25973 .67893 .27673 .68352 .23063 .67953 .21115 Mtetra
0 0 .156 r
.67953 .21115 .68352 .23063 .68998 .22244 .68877 .25537 Mtetra
.823 .502 .447 r
.68877 .25537 .68998 .22244 .70016 .28015 .69892 .31191 Mtetra
0 0 .229 r
.69892 .31191 .70016 .28015 .70807 .29431 .70376 .27163 Mtetra
.911 .638 .511 r
.70376 .27163 .70807 .29431 .71153 .2341 .70693 .20623 Mtetra
.134 .1 .551 r
.70693 .20623 .71153 .2341 .71676 .20567 .71526 .2278 Mtetra
.917 .586 .399 r
.71526 .2278 .71676 .20567 .72802 .27075 .72872 .32661 Mtetra
.797 .488 .466 r
.72872 .32661 .72802 .27075 .74217 .37352 .7412 .4037 Mtetra
.368 .119 .4 r
.7412 .4037 .74217 .37352 .75265 .41672 .74799 .39303 Mtetra
.916 .64 .502 r
.74799 .39303 .75265 .41672 .75708 .37364 .7505 .32302 Mtetra
.827 .554 .527 r
.7505 .32302 .75708 .37364 .75871 .29533 .75268 .25246 Mtetra
.783 .527 .549 r
.75268 .25246 .75871 .29533 .76117 .23227 .7566 .20876 Mtetra
.759 .537 .595 r
.7566 .20876 .76117 .23227 .76571 .19862 .76224 .18917 Mtetra
.754 .629 .721 r
.76224 .18917 .76571 .19862 .77184 .18587 .76882 .18191 Mtetra
.716 .794 .913 r
.76882 .18191 .77184 .18587 .77868 .18205 .77573 .17854 Mtetra
.683 .81 .943 r
.77573 .17854 .77868 .18205 .78571 .18015 .78269 .17572 Mtetra
.684 .758 .907 r
.78269 .17572 .78571 .18015 .79273 .17793 .78966 .17288 Mtetra
.676 .723 .885 r
.78966 .17288 .79273 .17793 .79973 .17533 .79666 .17012 Mtetra
.654 .715 .893 r
.17159 .3864 .17549 .39051 .18106 .3888 .17718 .38453 Mtetra
.64 .703 .892 r
.17718 .38453 .18106 .3888 .18664 .38718 .18277 .38286 Mtetra
.614 .693 .9 r
.18277 .38286 .18664 .38718 .19223 .38553 .18833 .38156 Mtetra
.54 .686 .933 r
.18833 .38156 .19223 .38553 .19779 .3844 .19383 .38104 Mtetra
.084 .489 .897 r
.19383 .38104 .19779 .3844 .20298 .38704 .1991 .38293 Mtetra
.833 .377 0 r
.1991 .38293 .20298 .38704 .20701 .40176 .20369 .39187 Mtetra
.96 .639 .243 r
.20369 .39187 .20701 .40176 .20881 .44014 .20679 .41644 Mtetra
.952 .702 .245 r
.20679 .41644 .20881 .44014 .20828 .50475 .20776 .46427 Mtetra
.845 .663 .123 r
.20776 .46427 .20828 .50475 .20808 .56829 .20748 .52709 Mtetra
0 0 .27 r
.20748 .52709 .20808 .56829 .2135 .57323 .20971 .56561 Mtetra
.9 .689 .608 r
.20971 .56561 .2135 .57323 .22665 .49259 .21878 .53082 Mtetra
.992 .807 .429 r
.21878 .53082 .22665 .49259 .24128 .39223 .23331 .43395 Mtetra
.882 .779 .283 r
.23331 .43395 .24128 .39223 .24885 .36974 .24519 .36364 Mtetra
.959 .624 .313 r
.24519 .36364 .24885 .36974 .24917 .43211 .24864 .38874 Mtetra
.845 .662 .123 r
.24864 .38874 .24917 .43211 .25215 .46533 .24838 .45899 Mtetra
.836 .695 .708 r
.24838 .45899 .25215 .46533 .26309 .40212 .25511 .44795 Mtetra
.883 .771 .272 r
.25511 .44795 .26309 .40212 .27249 .35577 .26733 .36853 Mtetra
.271 0 .223 r
.26733 .36853 .27249 .35577 .2745 .40283 .27341 .36357 Mtetra
.847 .655 .115 r
.27341 .36357 .2745 .40283 .27844 .42683 .27405 .42922 Mtetra
.981 .866 .65 r
.27405 .42922 .27844 .42683 .28882 .36529 .28124 .41128 Mtetra
.724 .68 .134 r
.28124 .41128 .28882 .36529 .29492 .36018 .29191 .34554 Mtetra
.959 .667 .239 r
.29191 .34554 .29492 .36018 .2969 .41375 .29496 .3829 Mtetra
0 0 .13 r
.29496 .3829 .2969 .41375 .30526 .37727 .29803 .42219 Mtetra
.759 .698 .157 r
.29803 .42219 .30526 .37727 .31329 .34425 .30858 .35411 Mtetra
.586 .226 .326 r
.30858 .35411 .31329 .34425 .31527 .40259 .31419 .35716 Mtetra
0 0 .04 r
.31419 .35716 .31527 .40259 .32257 .38062 .3159 .42114 Mtetra
.714 .673 .126 r
.3159 .42114 .32257 .38062 .33111 .33728 .3256 .36154 Mtetra
.084 0 .251 r
.3256 .36154 .33111 .33728 .33301 .40343 .33244 .3459 Mtetra
0 0 .091 r
.33244 .3459 .33301 .40343 .34035 .37964 .33383 .42196 Mtetra
0 0 0 r
.33383 .42196 .34035 .37964 .34878 .33513 .34314 .36476 Mtetra
0 0 .215 r
.34314 .36476 .34878 .33513 .35027 .41667 .35039 .34114 Mtetra
0 0 .2 r
.35039 .34114 .35027 .41667 .3582 .38067 .35176 .42682 Mtetra
0 0 .089 r
.35176 .42682 .3582 .38067 .36636 .33796 .36055 .37472 Mtetra
0 0 0 r
.36055 .37472 .36636 .33796 .3684 .4191 .3692 .32208 Mtetra
.254 .107 .48 r
.3692 .32208 .3684 .4191 .37684 .36922 .37301 .36723 Mtetra
.952 .77 .619 r
.37301 .36723 .37684 .36922 .38521 .31732 .38017 .34332 Mtetra
0 0 .02 r
.38017 .34332 .38521 .31732 .3896 .35472 .38759 .31204 Mtetra
.128 .044 .484 r
.38759 .31204 .3896 .35472 .39679 .32738 .39247 .33873 Mtetra
0 0 0 r
.39247 .33873 .39679 .32738 .4033 .31544 .39906 .3261 Mtetra
.39906 .3261 .4033 .31544 .40876 .33124 .40575 .30997 Mtetra
0 0 .504 r
.40575 .30997 .40876 .33124 .41556 .31113 .41121 .32694 Mtetra
0 0 0 r
.41121 .32694 .41556 .31113 .42142 .31785 .41802 .30672 Mtetra
.203 .256 .695 r
.41802 .30672 .42142 .31785 .42761 .31543 .42393 .31285 Mtetra
.814 .85 .876 r
.42393 .31285 .42761 .31543 .43397 .30756 .43023 .3078 Mtetra
.792 .991 .883 r
.43023 .3078 .43397 .30756 .43994 .31372 .43653 .30269 Mtetra
.468 .43 .733 r
.43653 .30269 .43994 .31372 .44639 .30315 .44265 .30443 Mtetra
.846 .998 .791 r
.44265 .30443 .44639 .30315 .45245 .308 .44902 .29744 Mtetra
.491 .453 .742 r
.44902 .29744 .45245 .308 .45882 .30059 .45519 .29863 Mtetra
.792 .892 .916 r
.45519 .29863 .45882 .30059 .46502 .30158 .46151 .29423 Mtetra
.628 .599 .802 r
.46151 .29423 .46502 .30158 .47132 .29806 .46779 .29234 Mtetra
.567 .625 .869 r
.46779 .29234 .47132 .29806 .47763 .29512 .47407 .29163 Mtetra
.805 .806 .852 r
.47407 .29163 .47763 .29512 .4839 .29565 .48043 .28639 Mtetra
.408 .428 .769 r
.48043 .28639 .4839 .29565 .49028 .28852 .4867 .28885 Mtetra
.862 .99 .835 r
.4867 .28885 .49028 .28852 .49655 .29284 .49309 .2822 Mtetra
.471 .441 .742 r
.49309 .2822 .49655 .29284 .50296 .28349 .49942 .28383 Mtetra
.125 .674 .733 r
.49942 .28383 .50296 .28349 .5093 .28634 .50579 .28294 Mtetra
.884 .81 .771 r
.50579 .28294 .5093 .28634 .51568 .28444 .51221 .27405 Mtetra
0 0 .417 r
.51221 .27405 .51568 .28444 .52209 .2735 .51857 .28853 Mtetra
0 0 0 r
.51857 .28853 .52209 .2735 .52851 .28973 .52502 .26753 Mtetra
.221 .17 .586 r
.52502 .26753 .52851 .28973 .5349 .26833 .53148 .28011 Mtetra
.662 .307 .36 r
.53148 .28011 .5349 .26833 .54139 .27841 .53799 .28753 Mtetra
.954 .828 .393 r
.53799 .28753 .54139 .27841 .54804 .30007 .54431 .2559 Mtetra
.134 .058 .498 r
.54431 .2559 .54804 .30007 .55418 .25662 .55104 .28621 Mtetra
.674 .374 .456 r
.55104 .28621 .55418 .25662 .56129 .31075 .55778 .30272 Mtetra
.949 .702 .529 r
.55778 .30272 .56129 .31075 .56844 .34841 .56377 .25232 Mtetra
.228 .099 .488 r
.56377 .25232 .56844 .34841 .5738 .26204 .57111 .30621 Mtetra
.741 .445 .48 r
.57111 .30621 .5738 .26204 .58117 .30605 .57849 .34693 Mtetra
.792 .661 .109 r
.57849 .34693 .58117 .30605 .58834 .32992 .58354 .25542 Mtetra
.37 .21 .53 r
.58354 .25542 .58834 .32992 .59326 .2465 .59071 .2809 Mtetra
.791 .483 .466 r
.59071 .2809 .59326 .2465 .60094 .29008 .59852 .32804 Mtetra
.745 .635 .072 r
.59852 .32804 .60094 .29008 .60804 .30361 .60329 .24692 Mtetra
.401 .243 .548 r
.60329 .24692 .60804 .30361 .61289 .23625 .61043 .26342 Mtetra
.829 .511 .45 r
.61043 .26342 .61289 .23625 .62083 .27713 .61871 .31431 Mtetra
0 0 .011 r
.61871 .31431 .62083 .27713 .62805 .29013 .62336 .24479 Mtetra
.56 .366 .575 r
.62336 .24479 .62805 .29013 .63277 .22999 .63003 .24206 Mtetra
.913 .578 .394 r
.63003 .24206 .63277 .22999 .64066 .26068 .63905 .30333 Mtetra
0 0 .273 r
.63905 .30333 .64066 .26068 .64861 .2888 .64419 .25682 Mtetra
.802 .554 .563 r
.64419 .25682 .64861 .2888 .65313 .23169 .64951 .21898 Mtetra
.931 .613 .154 r
.64951 .21898 .65313 .23169 .66013 .23572 .65901 .2812 Mtetra
.59 .314 .466 r
.65901 .2812 .66013 .23572 .66953 .29057 .66642 .29071 Mtetra
.99 .733 .432 r
.66642 .29071 .66953 .29057 .67504 .25973 .67012 .22097 Mtetra
.492 .325 .583 r
.67012 .22097 .67504 .25973 .67953 .21115 .67724 .22536 Mtetra
.921 .586 .387 r
.67724 .22536 .67953 .21115 .68877 .25537 .68811 .30066 Mtetra
.544 .277 .46 r
.68811 .30066 .68877 .25537 .69892 .31191 .69541 .30378 Mtetra
.972 .701 .458 r
.69541 .30378 .69892 .31191 .70376 .27163 .69828 .22802 Mtetra
.713 .477 .567 r
.69828 .22802 .70376 .27163 .70693 .20623 .70373 .20137 Mtetra
.955 .616 .236 r
.70373 .20137 .70693 .20623 .71526 .2278 .71499 .27094 Mtetra
.856 .536 .445 r
.71499 .27094 .71526 .2278 .72872 .32661 .7282 .36543 Mtetra
.714 .406 .456 r
.7282 .36543 .72872 .32661 .7412 .4037 .7376 .39514 Mtetra
.962 .71 .509 r
.7376 .39514 .7412 .4037 .74799 .39303 .74203 .34997 Mtetra
.846 .573 .525 r
.74203 .34997 .74799 .39303 .7505 .32302 .74459 .28076 Mtetra
.814 .549 .539 r
.74459 .28076 .7505 .32302 .75268 .25246 .748 .22735 Mtetra
.808 .565 .572 r
.748 .22735 .75268 .25246 .7566 .20876 .75299 .19778 Mtetra
.824 .643 .657 r
.75299 .19778 .7566 .20876 .76224 .18917 .75912 .18416 Mtetra
.816 .773 .812 r
.75912 .18416 .76224 .18917 .76882 .18191 .76578 .17771 Mtetra
.744 .792 .891 r
.76578 .17771 .76882 .18191 .77573 .17854 .77264 .17372 Mtetra
.7 .744 .886 r
.77264 .17372 .77573 .17854 .78269 .17572 .77959 .17053 Mtetra
.678 .718 .879 r
.77959 .17053 .78269 .17572 .78966 .17288 .78657 .1677 Mtetra
.668 .714 .883 r
.78657 .1677 .78966 .17288 .79666 .17012 .7936 .16506 Mtetra
.661 .735 .904 r
.16763 .3826 .17159 .3864 .17718 .38453 .17325 .38063 Mtetra
.653 .728 .904 r
.17325 .38063 .17718 .38453 .18277 .38286 .17886 .37877 Mtetra
.633 .712 .904 r
.17886 .37877 .18277 .38286 .18833 .38156 .18446 .3772 Mtetra
.576 .678 .91 r
.18446 .3772 .18833 .38156 .19383 .38104 .18999 .37636 Mtetra
.362 .564 .914 r
.18999 .37636 .19383 .38104 .1991 .38293 .19534 .37747 Mtetra
0 0 .499 r
.19534 .37747 .1991 .38293 .20369 .39187 .2002 .38368 Mtetra
.925 .573 .133 r
.2002 .38368 .20369 .39187 .20679 .41644 .20397 .40114 Mtetra
.97 .684 .275 r
.20397 .40114 .20679 .41644 .20776 .46427 .20599 .43736 Mtetra
.955 .711 .258 r
.20599 .43736 .20776 .46427 .20748 .52709 .20634 .49249 Mtetra
.821 .636 .084 r
.20634 .49249 .20748 .52709 .20971 .56561 .2072 .54436 Mtetra
.465 .342 .628 r
.2072 .54436 .20971 .56561 .21878 .53082 .21278 .54755 Mtetra
.996 .792 .512 r
.21278 .54755 .21878 .53082 .23331 .43395 .22503 .47765 Mtetra
.967 .806 .377 r
.22503 .47765 .23331 .43395 .24519 .36364 .23907 .38505 Mtetra
0 0 0 r
.23907 .38505 .24519 .36364 .24864 .38874 .24707 .35817 Mtetra
.931 .7 .216 r
.24707 .35817 .24864 .38874 .24838 .45899 .24758 .41797 Mtetra
0 0 .129 r
.24758 .41797 .24838 .45899 .25511 .44795 .2493 .466 Mtetra
.998 .823 .476 r
.2493 .466 .25511 .44795 .26733 .36853 .25961 .41177 Mtetra
.778 .718 .184 r
.25961 .41177 .26733 .36853 .27341 .36357 .27055 .34746 Mtetra
.958 .674 .239 r
.27055 .34746 .27341 .36357 .27405 .42922 .2732 .3861 Mtetra
0 0 .112 r
.2732 .3861 .27405 .42922 .28124 .41128 .27493 .43885 Mtetra
.942 .812 .36 r
.27493 .43885 .28124 .41128 .29191 .34554 .28511 .38155 Mtetra
0 0 .013 r
.28511 .38155 .29191 .34554 .29496 .3829 .29389 .34085 Mtetra
.796 .623 .063 r
.29389 .34085 .29496 .3829 .29803 .42219 .2949 .40748 Mtetra
.42 .353 .676 r
.2949 .40748 .29803 .42219 .30858 .35411 .30056 .41089 Mtetra
0 0 0 r
.30056 .41089 .30858 .35411 .31419 .35716 .31151 .33651 Mtetra
.892 .638 .123 r
.31151 .33651 .31419 .35716 .3159 .42114 .31468 .37676 Mtetra
0 0 .263 r
.31468 .37676 .3159 .42114 .3256 .36154 .31765 .4226 Mtetra
0 0 0 r
.31765 .4226 .3256 .36154 .33244 .3459 .32856 .34367 Mtetra
.885 .457 .148 r
.32856 .34367 .33244 .3459 .33383 .42196 .3337 .35599 Mtetra
0 0 .244 r
.3337 .35599 .33383 .42196 .34314 .36476 .33561 .42496 Mtetra
0 0 .069 r
.33561 .42496 .34314 .36476 .35039 .34114 .34566 .35459 Mtetra
0 0 0 r
.34566 .35459 .35039 .34114 .35176 .42682 .3527 .33495 Mtetra
0 0 .384 r
.3527 .33495 .35176 .42682 .36055 .37472 .355 .40442 Mtetra
0 0 0 r
.355 .40442 .36055 .37472 .3692 .32208 .3631 .36517 Mtetra
0 0 .01 r
.3631 .36517 .3692 .32208 .37301 .36723 .37186 .30988 Mtetra
.303 .16 .515 r
.37186 .30988 .37301 .36723 .38017 .34332 .37674 .33309 Mtetra
.616 .532 .736 r
.37674 .33309 .38017 .34332 .38759 .31204 .38287 .33107 Mtetra
0 0 0 r
.38287 .33107 .38759 .31204 .39247 .33873 .39003 .30545 Mtetra
.175 .095 .519 r
.39003 .30545 .39247 .33873 .39906 .3261 .39528 .32448 Mtetra
.909 .867 .786 r
.39528 .32448 .39906 .3261 .40575 .30997 .40171 .31569 Mtetra
.67 .852 .447 r
.40171 .31569 .40575 .30997 .41121 .32694 .40818 .30554 Mtetra
.132 .105 .559 r
.40818 .30554 .41121 .32694 .41802 .30672 .4138 .319 Mtetra
0 0 0 r
.4138 .319 .41802 .30672 .42393 .31285 .42056 .30085 Mtetra
0 .099 .616 r
.42056 .30085 .42393 .31285 .43023 .3078 .42639 .31025 Mtetra
.889 .982 .7 r
.42639 .31025 .43023 .3078 .43653 .30269 .43284 .3009 Mtetra
.155 .638 .923 r
.43284 .3009 .43653 .30269 .44265 .30443 .439 .30158 Mtetra
.726 .83 .93 r
.439 .30158 .44265 .30443 .44902 .29744 .44529 .29838 Mtetra
.347 .819 .762 r
.44529 .29838 .44902 .29744 .45519 .29863 .45157 .29595 Mtetra
.654 .827 .966 r
.45157 .29595 .45519 .29863 .46151 .29423 .45785 .29373 Mtetra
.457 .874 .942 r
.45785 .29373 .46151 .29423 .46779 .29234 .46415 .29191 Mtetra
.643 .951 .947 r
.46415 .29191 .46779 .29234 .47407 .29163 .47048 .28876 Mtetra
.537 .774 .985 r
.47048 .28876 .47407 .29163 .48043 .28639 .47679 .28776 Mtetra
.279 .764 .674 r
.47679 .28776 .48043 .28639 .4867 .28885 .48314 .28521 Mtetra
.743 .793 .893 r
.48314 .28521 .4867 .28885 .49309 .2822 .48952 .28153 Mtetra
.469 0 0 r
.48952 .28153 .49309 .2822 .49942 .28383 .49584 .28486 Mtetra
.969 .928 .687 r
.49584 .28486 .49942 .28383 .50579 .28294 .50231 .2723 Mtetra
0 0 .486 r
.50231 .2723 .50579 .28294 .51221 .27405 .50862 .28532 Mtetra
0 0 0 r
.50862 .28532 .51221 .27405 .51857 .28853 .51511 .26707 Mtetra
.379 .284 .621 r
.51511 .26707 .51857 .28853 .52502 .26753 .52153 .27403 Mtetra
.573 .155 .211 r
.52153 .27403 .52502 .26753 .53148 .28011 .52799 .27688 Mtetra
.958 .77 .608 r
.52799 .27688 .53148 .28011 .53799 .28753 .53441 .25401 Mtetra
.142 .08 .521 r
.53441 .25401 .53799 .28753 .54431 .2559 .54099 .27645 Mtetra
.414 .126 .365 r
.54099 .27645 .54431 .2559 .55104 .28621 .54749 .27208 Mtetra
.862 .637 .596 r
.54749 .27208 .55104 .28621 .55778 .30272 .55379 .24526 Mtetra
0 0 .407 r
.55379 .24526 .55778 .30272 .56377 .25232 .56095 .30016 Mtetra
.694 .405 .482 r
.56095 .30016 .56377 .25232 .57111 .30621 .56803 .33041 Mtetra
.927 .746 .264 r
.56803 .33041 .57111 .30621 .57849 .34693 .57358 .25426 Mtetra
.428 .247 .532 r
.57358 .25426 .57849 .34693 .58354 .25542 .58058 .27551 Mtetra
.879 .557 .435 r
.58058 .27551 .58354 .25542 .59071 .2809 .58852 .33776 Mtetra
0 0 .171 r
.58852 .33776 .59071 .2809 .59852 .32804 .59365 .26054 Mtetra
.592 .377 .558 r
.59365 .26054 .59852 .32804 .60329 .24692 .6001 .24978 Mtetra
.952 .621 .358 r
.6001 .24978 .60329 .24692 .61043 .26342 .60875 .32266 Mtetra
0 0 .326 r
.60875 .32266 .61043 .26342 .61871 .31431 .61406 .26774 Mtetra
.757 .509 .559 r
.61406 .26774 .61871 .31431 .62336 .24479 .61963 .22773 Mtetra
.926 .625 .152 r
.61963 .22773 .62336 .24479 .63003 .24206 .62873 .29866 Mtetra
.425 .191 .453 r
.62873 .29866 .63003 .24206 .63905 .30333 .6352 .28575 Mtetra
.93 .661 .508 r
.6352 .28575 .63905 .30333 .64419 .25682 .63951 .21655 Mtetra
0 0 .45 r
.63951 .21655 .64419 .25682 .64951 .21898 .64791 .25661 Mtetra
.789 .477 .461 r
.64791 .25661 .64951 .21898 .65901 .2812 .65693 .30649 Mtetra
.753 .648 .089 r
.65693 .30649 .65901 .2812 .66642 .29071 .66132 .2465 Mtetra
.764 .514 .557 r
.66132 .2465 .66642 .29071 .67012 .22097 .66641 .20674 Mtetra
.912 .6 .116 r
.66641 .20674 .67012 .22097 .67724 .22536 .67636 .26943 Mtetra
.762 .455 .466 r
.67636 .26943 .67724 .22536 .68811 .30066 .68585 .31682 Mtetra
.888 .729 .219 r
.68585 .31682 .68811 .30066 .69541 .30378 .69006 .26114 Mtetra
.833 .565 .533 r
.69006 .26114 .69541 .30378 .69828 .22802 .69363 .19807 Mtetra
.058 .041 .52 r
.69363 .19807 .69828 .22802 .70373 .20137 .70212 .22423 Mtetra
.909 .577 .404 r
.70212 .22423 .70373 .20137 .71499 .27094 .7147 .31542 Mtetra
.806 .491 .456 r
.7147 .31542 .71499 .27094 .7282 .36543 .72616 .38145 Mtetra
.233 0 .276 r
.72616 .38145 .7282 .36543 .7376 .39514 .73304 .37211 Mtetra
.903 .633 .519 r
.73304 .37211 .7376 .39514 .74203 .34997 .73659 .3136 Mtetra
.853 .582 .528 r
.73659 .3136 .74203 .34997 .74459 .28076 .73971 .25251 Mtetra
.837 .58 .549 r
.73971 .25251 .74459 .28076 .748 .22735 .74399 .21102 Mtetra
.833 .609 .598 r
.74399 .21102 .748 .22735 .75299 .19778 .74953 .18869 Mtetra
.82 .666 .692 r
.74953 .18869 .75299 .19778 .75912 .18416 .75588 .17782 Mtetra
.769 .71 .797 r
.75588 .17782 .75912 .18416 .76578 .17771 .76261 .17214 Mtetra
.713 .716 .851 r
.76261 .17214 .76578 .17771 .77264 .17372 .76951 .16846 Mtetra
.683 .717 .875 r
.76951 .16846 .77264 .17372 .77959 .17053 .77649 .16552 Mtetra
.67 .724 .89 r
.77649 .16552 .77959 .17053 .78657 .1677 .78351 .16286 Mtetra
.665 .731 .899 r
.78351 .16286 .78657 .1677 .7936 .16506 .79055 .16031 Mtetra
.663 .741 .908 r
.16366 .37889 .16763 .3826 .17325 .38063 .16928 .37688 Mtetra
.659 .738 .909 r
.16928 .37688 .17325 .38063 .17886 .37877 .17491 .37494 Mtetra
.645 .731 .911 r
.17491 .37494 .17886 .37877 .18446 .3772 .18053 .37318 Mtetra
.607 .709 .916 r
.18053 .37318 .18446 .3772 .18999 .37636 .18611 .37192 Mtetra
.483 .638 .923 r
.18611 .37192 .18999 .37636 .19534 .37747 .19157 .37201 Mtetra
.007 .309 .8 r
.19157 .37201 .19534 .37747 .2002 .38368 .19669 .37558 Mtetra
.748 .388 0 r
.19669 .37558 .2002 .38368 .20397 .40114 .20102 .3872 Mtetra
.928 .637 .163 r
.20102 .3872 .20397 .40114 .20599 .43736 .20393 .41388 Mtetra
.947 .697 .233 r
.20393 .41388 .20599 .43736 .20634 .49249 .20502 .46032 Mtetra
.91 .691 .189 r
.20502 .46032 .20634 .49249 .2072 .54436 .20531 .51697 Mtetra
0 0 .134 r
.20531 .51697 .2072 .54436 .21278 .54755 .20811 .54927 Mtetra
.965 .777 .599 r
.20811 .54927 .21278 .54755 .22503 .47765 .21708 .51606 Mtetra
.984 .811 .412 r
.21708 .51606 .22503 .47765 .23907 .38505 .23109 .4261 Mtetra
.891 .784 .293 r
.23109 .4261 .23907 .38505 .24707 .35817 .24307 .35573 Mtetra
.922 .549 .29 r
.24307 .35573 .24707 .35817 .24758 .41797 .24723 .37267 Mtetra
.835 .658 .114 r
.24723 .37267 .24758 .41797 .2493 .466 .24677 .44475 Mtetra
.325 .24 .603 r
.24677 .44475 .2493 .466 .25961 .41177 .25197 .45234 Mtetra
.929 .795 .327 r
.25197 .45234 .25961 .41177 .27055 .34746 .2642 .37426 Mtetra
0 0 0 r
.2642 .37426 .27055 .34746 .2732 .3861 .27228 .34495 Mtetra
.82 .64 .089 r
.27228 .34495 .2732 .3861 .27493 .43885 .27286 .41077 Mtetra
.046 .009 .486 r
.27286 .41077 .27493 .43885 .28511 .38155 .27731 .42922 Mtetra
.816 .732 .205 r
.27731 .42922 .28511 .38155 .29389 .34085 .28887 .35315 Mtetra
.31 0 .232 r
.28887 .35315 .29389 .34085 .2949 .40748 .29495 .34909 Mtetra
0 0 .098 r
.29495 .34909 .2949 .40748 .30056 .41089 .29562 .42179 Mtetra
.988 .858 .496 r
.29562 .42179 .30056 .41089 .31151 .33651 .30379 .38967 Mtetra
0 0 .039 r
.30379 .38967 .31151 .33651 .31468 .37676 .31383 .32803 Mtetra
0 0 .105 r
.31383 .32803 .31468 .37676 .31765 .4226 .3156 .39029 Mtetra
.002 0 .458 r
.3156 .39029 .31765 .4226 .32856 .34367 .3201 .41348 Mtetra
0 0 .061 r
.3201 .41348 .32856 .34367 .3337 .35599 .33114 .33181 Mtetra
0 0 .34 r
.33114 .33181 .3337 .35599 .33561 .42496 .33557 .35647 Mtetra
0 0 .313 r
.33557 .35647 .33561 .42496 .34566 .35459 .33792 .41917 Mtetra
0 0 .154 r
.33792 .41917 .34566 .35459 .3527 .33495 .34772 .35302 Mtetra
.888 .809 .328 r
.34772 .35302 .3527 .33495 .355 .40442 .35567 .31673 Mtetra
.195 .064 .464 r
.35567 .31673 .355 .40442 .3631 .36517 .35922 .36308 Mtetra
.927 .816 .716 r
.35922 .36308 .3631 .36517 .37186 .30988 .36591 .35048 Mtetra
0 0 .127 r
.36591 .35048 .37186 .30988 .37674 .33309 .37404 .30775 Mtetra
.137 .089 .535 r
.37404 .30775 .37674 .33309 .38287 .33107 .37933 .32312 Mtetra
.156 .304 .764 r
.37933 .32312 .38287 .33107 .39003 .30545 .38518 .32774 Mtetra
0 0 .016 r
.38518 .32774 .39003 .30545 .39528 .32448 .39237 .30158 Mtetra
.193 .14 .566 r
.39237 .30158 .39528 .32448 .40171 .31569 .39792 .31419 Mtetra
.894 .886 .816 r
.39792 .31419 .40171 .31569 .40818 .30554 .40432 .30655 Mtetra
.896 .985 .793 r
.40432 .30655 .40818 .30554 .4138 .319 .41072 .29873 Mtetra
.346 .263 .618 r
.41072 .29873 .4138 .319 .42056 .30085 .41659 .30595 Mtetra
.862 .927 .541 r
.41659 .30595 .42056 .30085 .42639 .31025 .42316 .2932 Mtetra
.332 .274 .641 r
.42316 .2932 .42639 .31025 .43284 .3009 .42912 .29967 Mtetra
.915 .894 .794 r
.42912 .29967 .43284 .3009 .439 .30158 .43556 .29108 Mtetra
.45 .429 .744 r
.43556 .29108 .439 .30158 .44529 .29838 .4417 .29303 Mtetra
.755 .715 .815 r
.4417 .29303 .44529 .29838 .45157 .29595 .44804 .28833 Mtetra
.58 .569 .805 r
.44804 .28833 .45157 .29595 .45785 .29373 .4543 .28743 Mtetra
.67 .652 .823 r
.4543 .28743 .45785 .29373 .46415 .29191 .46062 .28472 Mtetra
.659 .62 .799 r
.46062 .28472 .46415 .29191 .47048 .28876 .46694 .28206 Mtetra
.572 .593 .836 r
.46694 .28206 .47048 .28876 .47679 .28776 .47325 .2813 Mtetra
.758 .683 .779 r
.47325 .2813 .47679 .28776 .48314 .28521 .47965 .27581 Mtetra
.358 .395 .763 r
.47965 .27581 .48314 .28521 .48952 .28153 .48594 .27904 Mtetra
.917 .837 .75 r
.48594 .27904 .48952 .28153 .49584 .28486 .49241 .26871 Mtetra
.258 .234 .64 r
.49241 .26871 .49584 .28486 .50231 .2723 .49871 .27679 Mtetra
.834 .92 .528 r
.49871 .27679 .50231 .2723 .50862 .28532 .50519 .2647 Mtetra
.441 .331 .633 r
.50519 .2647 .50862 .28532 .51511 .26707 .51158 .26905 Mtetra
.478 0 0 r
.51158 .26905 .51511 .26707 .52153 .27403 .51801 .27105 Mtetra
.947 .796 .661 r
.51801 .27105 .52153 .27403 .52799 .27688 .52448 .25462 Mtetra
0 0 .457 r
.52448 .25462 .52799 .27688 .53441 .25401 .53099 .27718 Mtetra
.266 .014 .333 r
.53099 .27718 .53441 .25401 .54099 .27645 .53747 .26611 Mtetra
.858 .66 .634 r
.53747 .26611 .54099 .27645 .54749 .27208 .54389 .24759 Mtetra
0 0 .199 r
.54389 .24759 .54749 .27208 .55379 .24526 .55074 .28787 Mtetra
.559 .288 .46 r
.55074 .28787 .55379 .24526 .56095 .30016 .55742 .29277 Mtetra
.954 .707 .524 r
.55742 .29277 .56095 .30016 .56803 .33041 .56345 .24164 Mtetra
.322 .169 .512 r
.56345 .24164 .56803 .33041 .57358 .25426 .57057 .27826 Mtetra
.858 .539 .446 r
.57057 .27826 .57358 .25426 .58058 .27551 .57825 .33729 Mtetra
0 0 .239 r
.57825 .33729 .58058 .27551 .58852 .33776 .58373 .2657 Mtetra
.645 .415 .555 r
.58373 .2657 .58852 .33776 .59365 .26054 .58993 .24175 Mtetra
.938 .641 .181 r
.58993 .24175 .59365 .26054 .6001 .24978 .59844 .31975 Mtetra
.286 .089 .429 r
.59844 .31975 .6001 .24978 .60875 .32266 .60446 .28608 Mtetra
.85 .586 .538 r
.60446 .28608 .60875 .32266 .61406 .26774 .60952 .22217 Mtetra
0 0 .316 r
.60952 .22217 .61406 .26774 .61963 .22773 .61807 .28307 Mtetra
.646 .365 .48 r
.61807 .28307 .61963 .22773 .62873 .29866 .62569 .30584 Mtetra
.993 .747 .396 r
.62569 .30584 .62873 .29866 .6352 .28575 .62995 .22744 Mtetra
.502 .315 .559 r
.62995 .22744 .6352 .28575 .63951 .21655 .63693 .23188 Mtetra
.912 .58 .402 r
.63693 .23188 .63951 .21655 .64791 .25661 .64655 .30314 Mtetra
.224 .03 .394 r
.64655 .30314 .64791 .25661 .65693 .30649 .65246 .2756 Mtetra
.882 .611 .523 r
.65246 .2756 .65693 .30649 .66132 .2465 .65646 .20645 Mtetra
.142 .077 .517 r
.65646 .20645 .66132 .2465 .66641 .20674 .66466 .23546 Mtetra
.869 .544 .433 r
.66466 .23546 .66641 .20674 .67636 .26943 .67516 .30896 Mtetra
.336 .108 .412 r
.67516 .30896 .67636 .26943 .68585 .31682 .68152 .293 Mtetra
.92 .643 .5 r
.68152 .293 .68585 .31682 .69006 .26114 .6846 .21542 Mtetra
.664 .44 .57 r
.6846 .21542 .69006 .26114 .69363 .19807 .69059 .19693 Mtetra
.957 .614 .278 r
.69059 .19693 .69363 .19807 .70212 .22423 .70156 .2665 Mtetra
.849 .529 .446 r
.70156 .2665 .70212 .22423 .7147 .31542 .71395 .35398 Mtetra
.707 .4 .455 r
.71395 .35398 .7147 .31542 .72616 .38145 .72311 .38206 Mtetra
.998 .784 .458 r
.72311 .38206 .72616 .38145 .73304 .37211 .72812 .34311 Mtetra
.885 .612 .519 r
.72812 .34311 .73304 .37211 .73659 .3136 .73137 .27997 Mtetra
.843 .577 .537 r
.73137 .27997 .73659 .3136 .73971 .25251 .73511 .22781 Mtetra
.821 .575 .567 r
.73511 .22781 .73971 .25251 .74399 .21102 .74008 .19601 Mtetra
.803 .599 .625 r
.74008 .19601 .74399 .21102 .74953 .18869 .74606 .17961 Mtetra
.777 .648 .719 r
.74606 .17961 .74953 .18869 .75588 .17782 .75263 .17144 Mtetra
.736 .696 .813 r
.75263 .17144 .75588 .17782 .76261 .17214 .75946 .16682 Mtetra
.698 .721 .868 r
.75946 .16682 .76261 .17214 .76951 .16846 .7664 .16354 Mtetra
.676 .732 .892 r
.7664 .16354 .76951 .16846 .77649 .16552 .77341 .16077 Mtetra
.667 .737 .902 r
.77341 .16077 .77649 .16552 .78351 .16286 .78044 .15818 Mtetra
.664 .74 .906 r
.78044 .15818 .78351 .16286 .79055 .16031 .7875 .15565 Mtetra
.664 .741 .908 r
.15966 .37517 .16366 .37889 .16928 .37688 .16529 .37314 Mtetra
.662 .74 .908 r
.16529 .37314 .16928 .37688 .17491 .37494 .17094 .37113 Mtetra
.655 .735 .909 r
.17094 .37113 .17491 .37494 .18053 .37318 .17658 .36923 Mtetra
.63 .721 .912 r
.17658 .36923 .18053 .37318 .18611 .37192 .1822 .36766 Mtetra
.551 .677 .921 r
.1822 .36766 .18611 .37192 .19157 .37201 .18773 .36705 Mtetra
.269 .5 .894 r
.18773 .36705 .19157 .37201 .19669 .37558 .19303 .36886 Mtetra
0 0 .471 r
.19303 .36886 .19669 .37558 .20102 .3872 .19779 .3762 Mtetra
.866 .55 .03 r
.19779 .3762 .20102 .3872 .20393 .41388 .20148 .39454 Mtetra
.924 .665 .178 r
.20148 .39454 .20393 .41388 .20502 .46032 .20357 .43006 Mtetra
.903 .684 .177 r
.20357 .43006 .20502 .46032 .20531 .51697 .20417 .48233 Mtetra
.786 .613 .049 r
.20417 .48233 .20531 .51697 .20811 .54927 .20524 .53175 Mtetra
.329 .267 .635 r
.20524 .53175 .20811 .54927 .21708 .51606 .21057 .5378 Mtetra
.998 .82 .475 r
.21057 .5378 .21708 .51606 .23109 .4261 .22224 .47513 Mtetra
.932 .794 .327 r
.22224 .47513 .23109 .4261 .24307 .35573 .23631 .38364 Mtetra
.7 .705 .175 r
.23631 .38364 .24307 .35573 .24723 .37267 .24531 .34618 Mtetra
.923 .686 .196 r
.24531 .34618 .24723 .37267 .24677 .44475 .24656 .39697 Mtetra
0 0 .035 r
.24656 .39697 .24677 .44475 .25197 .45234 .24707 .45895 Mtetra
.994 .825 .565 r
.24707 .45895 .25197 .45234 .2642 .37426 .25573 .42546 Mtetra
.805 .727 .197 r
.25573 .42546 .2642 .37426 .27228 .34495 .26794 .347 Mtetra
.804 .39 .261 r
.26794 .347 .27228 .34495 .27286 .41077 .27294 .35615 Mtetra
0 0 .047 r
.27294 .35615 .27286 .41077 .27731 .42922 .2732 .42726 Mtetra
.937 .778 .659 r
.2732 .42726 .27731 .42922 .28887 .35315 .28054 .40843 Mtetra
0 0 0 r
.28054 .40843 .28887 .35315 .29495 .34909 .29192 .33419 Mtetra
.866 .586 .057 r
.29192 .33419 .29495 .34909 .29562 .42179 .29575 .36138 Mtetra
0 0 .224 r
.29575 .36138 .29562 .42179 .30379 .38967 .29722 .42399 Mtetra
.79 .73 .202 r
.29722 .42399 .30379 .38967 .31383 .32803 .30692 .36958 Mtetra
0 0 .06 r
.30692 .36958 .31383 .32803 .3156 .39029 .31587 .32403 Mtetra
0 0 .226 r
.31587 .32403 .3156 .39029 .3201 .41348 .31724 .39335 Mtetra
.148 .121 .569 r
.31724 .39335 .3201 .41348 .33114 .33181 .32252 .40491 Mtetra
0 0 .115 r
.32252 .40491 .33114 .33181 .33557 .35647 .33338 .32578 Mtetra
.138 .07 .511 r
.33338 .32578 .33557 .35647 .33792 .41917 .33824 .34382 Mtetra
0 0 .364 r
.33824 .34382 .33792 .41917 .34772 .35302 .34076 .40425 Mtetra
0 0 .184 r
.34076 .40425 .34772 .35302 .35567 .31673 .34954 .35585 Mtetra
0 0 0 r
.34954 .35585 .35567 .31673 .35922 .36308 .35834 .30417 Mtetra
.322 .172 .517 r
.35834 .30417 .35922 .36308 .36591 .35048 .36319 .32594 Mtetra
.464 .328 .61 r
.36319 .32594 .36591 .35048 .37404 .30775 .36903 .32969 Mtetra
0 0 0 r
.36903 .32969 .37404 .30775 .37933 .32312 .37637 .30275 Mtetra
.145 .118 .567 r
.37637 .30275 .37933 .32312 .38518 .32774 .38184 .31491 Mtetra
.303 .297 .686 r
.38184 .31491 .38518 .32774 .39237 .30158 .38769 .32016 Mtetra
0 0 .002 r
.38769 .32016 .39237 .30158 .39792 .31419 .39469 .29888 Mtetra
0 0 .536 r
.39469 .29888 .39792 .31419 .40432 .30655 .40026 .31175 Mtetra
.673 .869 .482 r
.40026 .31175 .40432 .30655 .41072 .29873 .40676 .30228 Mtetra
0 0 0 r
.40676 .30228 .41072 .29873 .41659 .30595 .41308 .29726 Mtetra
.275 .359 .769 r
.41308 .29726 .41659 .30595 .42316 .2932 .4191 .30112 Mtetra
0 0 0 r
.4191 .30112 .42316 .2932 .42912 .29967 .42563 .29027 Mtetra
.251 .326 .747 r
.42563 .29027 .42912 .29967 .43556 .29108 .43168 .2948 Mtetra
.706 .921 .584 r
.43168 .2948 .43556 .29108 .4417 .29303 .43813 .28668 Mtetra
.42 .525 .859 r
.43813 .28668 .4417 .29303 .44804 .28833 .44432 .28796 Mtetra
.766 .975 .919 r
.44432 .28796 .44804 .28833 .4543 .28743 .45068 .28351 Mtetra
.624 .742 .932 r
.45068 .28351 .4543 .28743 .46062 .28472 .45698 .28182 Mtetra
.557 .782 .983 r
.45698 .28182 .46062 .28472 .46694 .28206 .46329 .28064 Mtetra
.805 .928 .916 r
.46329 .28064 .46694 .28206 .47325 .2813 .46969 .27591 Mtetra
.225 .456 .873 r
.46969 .27591 .47325 .2813 .47965 .27581 .47597 .27858 Mtetra
.796 .967 .659 r
.47597 .27858 .47965 .27581 .48594 .27904 .48243 .27023 Mtetra
.099 .244 .726 r
.48243 .27023 .48594 .27904 .49241 .26871 .48872 .27631 Mtetra
0 0 0 r
.48872 .27631 .49241 .26871 .49871 .27679 .4952 .26769 Mtetra
.47 .472 .778 r
.4952 .26769 .49871 .27679 .50519 .2647 .50159 .26899 Mtetra
.625 .167 .145 r
.50159 .26899 .50519 .2647 .51158 .26905 .508 .27307 Mtetra
.96 .912 .552 r
.508 .27307 .51158 .26905 .51801 .27105 .51452 .25614 Mtetra
0 0 .449 r
.51452 .25614 .51801 .27105 .52448 .25462 .52095 .27361 Mtetra
.181 0 .274 r
.52095 .27361 .52448 .25462 .53099 .27718 .52746 .26236 Mtetra
.79 .593 .633 r
.52746 .26236 .53099 .27718 .53747 .26611 .53393 .2467 Mtetra
0 0 .402 r
.53393 .2467 .53747 .26611 .54389 .24759 .54056 .27011 Mtetra
.27 .015 .33 r
.54056 .27011 .54389 .24759 .55074 .28787 .54706 .25954 Mtetra
.762 .533 .586 r
.54706 .25954 .55074 .28787 .55742 .29277 .55342 .23447 Mtetra
0 0 .431 r
.55342 .23447 .55742 .29277 .56345 .24164 .56055 .28498 Mtetra
.744 .446 .477 r
.56055 .28498 .56345 .24164 .57057 .27826 .5678 .32603 Mtetra
0 0 .12 r
.5678 .32603 .57057 .27826 .57825 .33729 .57354 .25791 Mtetra
.613 .388 .552 r
.57354 .25791 .57825 .33729 .58373 .2657 .5799 .23986 Mtetra
.878 .613 .09 r
.5799 .23986 .58373 .2657 .58993 .24175 .58811 .31611 Mtetra
.39 .169 .454 r
.58811 .31611 .58993 .24175 .59844 .31975 .59449 .29429 Mtetra
.902 .633 .522 r
.59449 .29429 .59844 .31975 .60446 .28608 .59955 .22157 Mtetra
.127 .04 .478 r
.59955 .22157 .60446 .28608 .60952 .22217 .60749 .26748 Mtetra
.755 .454 .474 r
.60749 .26748 .60952 .22217 .61807 .28307 .61568 .31404 Mtetra
.767 .654 .097 r
.61568 .31404 .61807 .28307 .62569 .30584 .62044 .24332 Mtetra
.672 .438 .557 r
.62044 .24332 .62569 .30584 .62995 .22744 .62637 .21587 Mtetra
.953 .634 .215 r
.62637 .21587 .62995 .22744 .63693 .23188 .63574 .28779 Mtetra
.579 .31 .473 r
.63574 .28779 .63693 .23188 .64655 .30314 .6431 .29759 Mtetra
.976 .71 .459 r
.6431 .29759 .64655 .30314 .65246 .2756 .64706 .22052 Mtetra
.596 .385 .564 r
.64706 .22052 .65246 .2756 .65646 .20645 .65355 .21093 Mtetra
.95 .613 .342 r
.65355 .21093 .65646 .20645 .66466 .23546 .66386 .28707 Mtetra
.665 .377 .473 r
.66386 .28707 .66466 .23546 .67516 .30896 .67218 .31304 Mtetra
.993 .746 .399 r
.67218 .31304 .67516 .30896 .68152 .293 .67596 .24362 Mtetra
.791 .53 .543 r
.67596 .24362 .68152 .293 .6846 .21542 .68024 .18976 Mtetra
0 0 .374 r
.68024 .18976 .6846 .21542 .69059 .19693 .68919 .22649 Mtetra
.888 .56 .422 r
.68919 .22649 .69059 .19693 .70156 .2665 .70134 .31662 Mtetra
.775 .465 .464 r
.70134 .31662 .70156 .2665 .71395 .35398 .7121 .37537 Mtetra
.233 0 .319 r
.7121 .37537 .71395 .35398 .72311 .38206 .71883 .36295 Mtetra
.918 .65 .516 r
.71883 .36295 .72311 .38206 .72812 .34311 .72276 .30658 Mtetra
.847 .578 .531 r
.72276 .30658 .72812 .34311 .73137 .27997 .72631 .2481 Mtetra
.818 .562 .551 r
.72631 .2481 .73137 .27997 .73511 .22781 .73081 .20719 Mtetra
.804 .574 .59 r
.73081 .20719 .73511 .22781 .74008 .19601 .73639 .18399 Mtetra
.792 .616 .663 r
.73639 .18399 .74008 .19601 .74606 .17961 .7427 .172 Mtetra
.764 .673 .762 r
.7427 .172 .74606 .17961 .75263 .17144 .74941 .16563 Mtetra
.72 .711 .841 r
.74941 .16563 .75263 .17144 .75946 .16682 .7563 .16169 Mtetra
.686 .726 .881 r
.7563 .16169 .75946 .16682 .7664 .16354 .76328 .1587 Mtetra
.67 .734 .898 r
.76328 .1587 .7664 .16354 .77341 .16077 .77031 .15605 Mtetra
.664 .738 .905 r
.77031 .15605 .77341 .16077 .78044 .15818 .77736 .1535 Mtetra
.663 .74 .907 r
.77736 .1535 .78044 .15818 .7875 .15565 .78443 .15097 Mtetra
.663 .741 .908 r
.15565 .37143 .15966 .37517 .16529 .37314 .16129 .3694 Mtetra
.663 .742 .908 r
.16129 .3694 .16529 .37314 .17094 .37113 .16694 .36738 Mtetra
.661 .74 .909 r
.16694 .36738 .17094 .37113 .17658 .36923 .1726 .36537 Mtetra
.65 .733 .91 r
.1726 .36537 .17658 .36923 .1822 .36766 .17826 .36353 Mtetra
.608 .705 .913 r
.17826 .36353 .1822 .36766 .18773 .36705 .18386 .36225 Mtetra
.46 .609 .911 r
.18386 .36225 .18773 .36705 .19303 .36886 .18931 .36261 Mtetra
0 .237 .752 r
.18931 .36261 .19303 .36886 .19779 .3762 .19437 .36694 Mtetra
.715 .385 0 r
.19437 .36694 .19779 .3762 .20148 .39454 .19864 .37941 Mtetra
.897 .619 .112 r
.19864 .37941 .20148 .39454 .20357 .43006 .20158 .40563 Mtetra
.914 .677 .178 r
.20158 .40563 .20357 .43006 .20417 .48233 .20296 .44895 Mtetra
.856 .658 .122 r
.20296 .44895 .20417 .48233 .20524 .53175 .20362 .50155 Mtetra
0 0 .165 r
.20362 .50155 .20524 .53175 .21057 .5378 .20627 .53523 Mtetra
.929 .754 .644 r
.20627 .53523 .21057 .5378 .22224 .47513 .21431 .51257 Mtetra
.971 .813 .392 r
.21431 .51257 .22224 .47513 .23631 .38364 .2276 .43174 Mtetra
.862 .765 .258 r
.2276 .43174 .23631 .38364 .24531 .34618 .24037 .35384 Mtetra
.254 0 .083 r
.24037 .35384 .24531 .34618 .24656 .39697 .24628 .35107 Mtetra
.8 .636 .079 r
.24628 .35107 .24656 .39697 .24707 .45895 .24602 .4202 Mtetra
0 0 .27 r
.24602 .4202 .24707 .45895 .25573 .42546 .24871 .45757 Mtetra
.932 .807 .345 r
.24871 .45757 .25573 .42546 .26794 .347 .25978 .39492 Mtetra
0 0 0 r
.25978 .39492 .26794 .347 .27294 .35615 .27065 .33234 Mtetra
.84 .616 .07 r
.27065 .33234 .27294 .35615 .2732 .42726 .27328 .37174 Mtetra
0 0 .177 r
.27328 .37174 .2732 .42726 .28054 .40843 .27444 .43239 Mtetra
.914 .813 .344 r
.27444 .43239 .28054 .40843 .29192 .33419 .28388 .38601 Mtetra
0 0 0 r
.28388 .38601 .29192 .33419 .29575 .36138 .29432 .32394 Mtetra
0 0 .133 r
.29432 .32394 .29575 .36138 .29722 .42399 .29684 .36998 Mtetra
0 0 .306 r
.29684 .36998 .29722 .42399 .30692 .36958 .29932 .41916 Mtetra
0 0 0 r
.29932 .41916 .30692 .36958 .31587 .32403 .30963 .3559 Mtetra
0 0 .006 r
.30963 .3559 .31587 .32403 .31724 .39335 .31796 .31926 Mtetra
0 0 .293 r
.31796 .31926 .31724 .39335 .32252 .40491 .31948 .38739 Mtetra
0 0 .497 r
.31948 .38739 .32252 .40491 .33338 .32578 .32461 .40178 Mtetra
0 0 .163 r
.32461 .40178 .33338 .32578 .33824 .34382 .33527 .3256 Mtetra
.625 .467 .648 r
.33527 .3256 .33824 .34382 .34076 .40425 .34147 .32143 Mtetra
.097 0 .431 r
.34147 .32143 .34076 .40425 .34954 .35585 .34451 .37327 Mtetra
0 0 0 r
.34451 .37327 .34954 .35585 .35834 .30417 .35181 .3511 Mtetra
0 0 .142 r
.35181 .3511 .35834 .30417 .36319 .32594 .3604 .30321 Mtetra
.393 .283 .609 r
.3604 .30321 .36319 .32594 .36903 .32969 .36608 .3094 Mtetra
.272 .209 .601 r
.36608 .3094 .36903 .32969 .37637 .30275 .37168 .31839 Mtetra
0 0 0 r
.37168 .31839 .37637 .30275 .38184 .31491 .37875 .29717 Mtetra
.398 .313 .643 r
.37875 .29717 .38184 .31491 .38769 .32016 .38459 .30193 Mtetra
.428 .331 .644 r
.38459 .30193 .38769 .32016 .39469 .29888 .3905 .30594 Mtetra
.825 .885 .456 r
.3905 .30594 .39469 .29888 .40026 .31175 .39722 .29119 Mtetra
.193 .153 .581 r
.39722 .29119 .40026 .31175 .40676 .30228 .40289 .30245 Mtetra
.948 .92 .748 r
.40289 .30245 .40676 .30228 .41308 .29726 .40944 .29197 Mtetra
.379 .551 .898 r
.40944 .29197 .41308 .29726 .4191 .30112 .41555 .29325 Mtetra
.596 .57 .796 r
.41555 .29325 .4191 .30112 .42563 .29027 .42177 .29199 Mtetra
.654 .959 .763 r
.42177 .29199 .42563 .29027 .43168 .2948 .42814 .28688 Mtetra
.454 .491 .808 r
.42814 .28688 .43168 .2948 .43813 .28668 .43432 .28814 Mtetra
.679 .972 .788 r
.43432 .28814 .43813 .28668 .44432 .28796 .4407 .28302 Mtetra
.544 .654 .907 r
.4407 .28302 .44432 .28796 .45068 .28351 .44697 .28248 Mtetra
.617 .918 .977 r
.44697 .28248 .45068 .28351 .45698 .28182 .45331 .27993 Mtetra
.735 .897 .952 r
.45331 .27993 .45698 .28182 .46329 .28064 .45968 .27646 Mtetra
.45 .653 .946 r
.45968 .27646 .46329 .28064 .46969 .27591 .46599 .27667 Mtetra
.785 .998 .838 r
.46599 .27667 .46969 .27591 .47597 .27858 .47243 .27098 Mtetra
.479 .516 .818 r
.47243 .27098 .47597 .27858 .48243 .27023 .47877 .27181 Mtetra
.475 .878 .721 r
.47877 .27181 .48243 .27023 .48872 .27631 .48519 .26792 Mtetra
.715 .621 .751 r
.48519 .26792 .48872 .27631 .4952 .26769 .49164 .26298 Mtetra
0 .205 .725 r
.49164 .26298 .4952 .26769 .50159 .26899 .49801 .26811 Mtetra
.97 .852 .668 r
.49801 .26811 .50159 .26899 .508 .27307 .50455 .25274 Mtetra
.242 .194 .602 r
.50455 .25274 .508 .27307 .51452 .25614 .51094 .26332 Mtetra
0 0 0 r
.51094 .26332 .51452 .25614 .52095 .27361 .51745 .25389 Mtetra
.677 .496 .634 r
.51745 .25389 .52095 .27361 .52746 .26236 .52394 .24549 Mtetra
0 0 .498 r
.52394 .24549 .52746 .26236 .53393 .2467 .53047 .26252 Mtetra
0 0 .135 r
.53047 .26252 .53393 .2467 .54056 .27011 .53697 .24743 Mtetra
.669 .48 .621 r
.53697 .24743 .54056 .27011 .54706 .25954 .54346 .23836 Mtetra
.766 .522 0 r
.54346 .23836 .54706 .25954 .55342 .23447 .55039 .28359 Mtetra
.616 .338 .473 r
.55039 .28359 .55342 .23447 .56055 .28498 .55723 .29822 Mtetra
.977 .781 .363 r
.55723 .29822 .56055 .28498 .5678 .32603 .56324 .24046 Mtetra
.512 .31 .543 r
.56324 .24046 .5678 .32603 .57354 .25791 .56994 .24423 Mtetra
.959 .648 .234 r
.56994 .24423 .57354 .25791 .5799 .23986 .57784 .31696 Mtetra
.379 .161 .452 r
.57784 .31696 .5799 .23986 .58811 .31611 .58424 .29298 Mtetra
.909 .641 .52 r
.58424 .29298 .58811 .31611 .59449 .29429 .58954 .22079 Mtetra
.266 .134 .507 r
.58954 .22079 .59449 .29429 .59955 .22157 .59711 .25782 Mtetra
.81 .498 .462 r
.59711 .25782 .59955 .22157 .60749 .26748 .60538 .31458 Mtetra
0 0 .209 r
.60538 .31458 .60749 .26748 .61568 .31404 .61071 .25624 Mtetra
.751 .498 .55 r
.61071 .25624 .61568 .31404 .62044 .24332 .61614 .20863 Mtetra
0 0 .192 r
.61614 .20863 .62044 .24332 .62637 .21587 .6249 .26987 Mtetra
.708 .415 .478 r
.6249 .26987 .62637 .21587 .63574 .28779 .63319 .30849 Mtetra
.905 .731 .231 r
.63319 .30849 .63574 .28779 .6431 .29759 .63772 .23993 Mtetra
.731 .483 .552 r
.63772 .23993 .6431 .29759 .64706 .22052 .64305 .19892 Mtetra
.822 .555 .002 r
.64305 .19892 .64706 .22052 .65355 .21093 .65248 .26066 Mtetra
.771 .465 .47 r
.65248 .26066 .65355 .21093 .66386 .28707 .662 .31749 Mtetra
0 0 .128 r
.662 .31749 .66386 .28707 .67218 .31304 .66709 .27167 Mtetra
.858 .584 .523 r
.66709 .27167 .67218 .31304 .67596 .24362 .67063 .19763 Mtetra
.521 .336 .572 r
.67063 .19763 .67596 .24362 .68024 .18976 .67769 .19911 Mtetra
.939 .598 .357 r
.67769 .19911 .68024 .18976 .68919 .22649 .68878 .27627 Mtetra
.814 .501 .459 r
.68878 .27627 .68919 .22649 .70134 .31662 .70031 .3543 Mtetra
.648 .349 .45 r
.70031 .3543 .70134 .31662 .7121 .37537 .70871 .37123 Mtetra
.983 .747 .5 r
.70871 .37123 .7121 .37537 .71883 .36295 .71377 .33047 Mtetra
.864 .594 .528 r
.71377 .33047 .71883 .36295 .72276 .30658 .71752 .27127 Mtetra
.828 .565 .541 r
.71752 .27127 .72276 .30658 .72631 .2481 .72168 .22228 Mtetra
.812 .566 .568 r
.72168 .22228 .72631 .2481 .73081 .20719 .72682 .19104 Mtetra
.799 .59 .619 r
.72682 .19104 .73081 .20719 .73639 .18399 .73282 .17385 Mtetra
.775 .63 .701 r
.73282 .17385 .73639 .18399 .7427 .172 .73936 .16491 Mtetra
.735 .674 .791 r
.73936 .16491 .7427 .172 .74941 .16563 .74619 .15996 Mtetra
.695 .707 .857 r
.74619 .15996 .74941 .16563 .7563 .16169 .75314 .15666 Mtetra
.673 .727 .89 r
.75314 .15666 .7563 .16169 .76328 .1587 .76016 .15394 Mtetra
.665 .737 .903 r
.76016 .15394 .76328 .1587 .77031 .15605 .7672 .15136 Mtetra
.664 .741 .907 r
.7672 .15136 .77031 .15605 .77736 .1535 .77427 .14882 Mtetra
.664 .742 .908 r
.77427 .14882 .77736 .1535 .78443 .15097 .78135 .14627 Mtetra
.663 .741 .908 r
.15162 .36768 .15565 .37143 .16129 .3694 .15727 .36564 Mtetra
.15727 .36564 .16129 .3694 .16694 .36738 .16293 .36361 Mtetra
.662 .741 .909 r
.16293 .36361 .16694 .36738 .1726 .36537 .16859 .3616 Mtetra
.657 .739 .911 r
.16859 .3616 .1726 .36537 .17826 .36353 .17427 .35965 Mtetra
.638 .729 .914 r
.17427 .35965 .17826 .36353 .18386 .36225 .17992 .35796 Mtetra
.568 .684 .918 r
.17992 .35796 .18386 .36225 .18931 .36261 .1855 .35715 Mtetra
.32 .503 .881 r
.1855 .35715 .18931 .36261 .19437 .36694 .19083 .35882 Mtetra
0 0 .548 r
.19083 .35882 .19437 .36694 .19864 .37941 .19559 .36627 Mtetra
.77 .496 0 r
.19559 .36627 .19864 .37941 .20158 .40563 .19929 .38465 Mtetra
.878 .639 .114 r
.19929 .38465 .20158 .40563 .20296 .44895 .20148 .41897 Mtetra
.88 .668 .145 r
.20148 .41897 .20296 .44895 .20362 .50155 .20236 .46816 Mtetra
.789 .612 .049 r
.20236 .46816 .20362 .50155 .20627 .53523 .20357 .51587 Mtetra
.012 .027 .527 r
.20357 .51587 .20627 .53523 .21431 .51257 .20827 .52856 Mtetra
.999 .832 .499 r
.20827 .52856 .21431 .51257 .2276 .43174 .21873 .47998 Mtetra
.919 .791 .315 r
.21873 .47998 .2276 .43174 .24037 .35384 .23254 .39282 Mtetra
.769 .724 .194 r
.23254 .39282 .24037 .35384 .24628 .35107 .24327 .33694 Mtetra
.903 .614 .115 r
.24327 .33694 .24628 .35107 .24602 .4202 .24662 .36352 Mtetra
0 0 .036 r
.24662 .36352 .24602 .4202 .24871 .45757 .24618 .43573 Mtetra
.284 .207 .591 r
.24618 .43573 .24871 .45757 .25978 .39492 .25134 .44448 Mtetra
.813 .733 .207 r
.25134 .44448 .25978 .39492 .27065 .33234 .26355 .36778 Mtetra
0 0 0 r
.26355 .36778 .27065 .33234 .27328 .37174 .27264 .32679 Mtetra
0 0 .068 r
.27264 .32679 .27328 .37174 .27444 .43239 .27389 .38432 Mtetra
0 0 .288 r
.27389 .38432 .27444 .43239 .28388 .38601 .27635 .4291 Mtetra
.723 .684 .14 r
.27635 .4291 .28388 .38601 .29432 .32394 .28692 .36768 Mtetra
0 0 .019 r
.28692 .36768 .29432 .32394 .29684 .36998 .29643 .31787 Mtetra
0 0 .233 r
.29643 .31787 .29684 .36998 .29932 .41916 .29845 .37151 Mtetra
0 0 .339 r
.29845 .37151 .29932 .41916 .30963 .3559 .30154 .41285 Mtetra
0 0 .07 r
.30154 .41285 .30963 .3559 .31796 .31926 .31182 .34988 Mtetra
0 0 0 r
.31182 .34988 .31796 .31926 .31948 .38739 .32025 .31179 Mtetra
0 0 .353 r
.32025 .31179 .31948 .38739 .32461 .40178 .32231 .37228 Mtetra
0 0 .376 r
.32231 .37228 .32461 .40178 .33527 .3256 .3267 .39903 Mtetra
0 0 .206 r
.3267 .39903 .33527 .3256 .34147 .32143 .33683 .33145 Mtetra
.986 .857 .486 r
.33683 .33145 .34147 .32143 .34451 .37327 .34462 .30053 Mtetra
.262 .118 .489 r
.34462 .30053 .34451 .37327 .35181 .3511 .34879 .3325 Mtetra
.539 .407 .648 r
.34879 .3325 .35181 .3511 .3604 .30321 .35484 .33246 Mtetra
0 0 .094 r
.35484 .33246 .3604 .30321 .36608 .3094 .36248 .30232 Mtetra
.219 .377 .809 r
.36248 .30232 .36608 .3094 .37168 .31839 .36834 .30578 Mtetra
0 0 .544 r
.36834 .30578 .37168 .31839 .37875 .29717 .37386 .31697 Mtetra
0 0 .035 r
.37386 .31697 .37875 .29717 .38459 .30193 .38094 .29578 Mtetra
.389 .516 .865 r
.38094 .29578 .38459 .30193 .3905 .30594 .38697 .29727 Mtetra
.394 .435 .784 r
.38697 .29727 .3905 .30594 .39722 .29119 .39298 .29953 Mtetra
.69 .807 .349 r
.39298 .29953 .39722 .29119 .40289 .30245 .39969 .28548 Mtetra
.261 .225 .628 r
.39969 .28548 .40289 .30245 .40944 .29197 .40552 .29334 Mtetra
.949 .953 .727 r
.40552 .29334 .40944 .29197 .41555 .29325 .41209 .28268 Mtetra
.425 .413 .742 r
.41209 .28268 .41555 .29325 .42177 .29199 .41818 .28501 Mtetra
.728 .657 .779 r
.41818 .28501 .42177 .29199 .42814 .28688 .42454 .28035 Mtetra
.617 .621 .833 r
.42454 .28035 .42814 .28688 .43432 .28814 .43081 .27874 Mtetra
.629 .556 .754 r
.43081 .27874 .43432 .28814 .4407 .28302 .43711 .27642 Mtetra
.65 .635 .822 r
.43711 .27642 .4407 .28302 .44697 .28248 .44343 .27409 Mtetra
.641 .583 .774 r
.44343 .27409 .44697 .28248 .45331 .27993 .44977 .27162 Mtetra
.616 .573 .782 r
.44977 .27162 .45331 .27993 .45968 .27646 .4561 .26982 Mtetra
.667 .643 .816 r
.4561 .26982 .45968 .27646 .46599 .27667 .46248 .26706 Mtetra
.626 .551 .751 r
.46248 .26706 .46599 .27667 .47243 .27098 .46885 .26478 Mtetra
.563 .61 .858 r
.46885 .26478 .47243 .27098 .47877 .27181 .47522 .26409 Mtetra
.75 .651 .752 r
.47522 .26409 .47877 .27181 .48519 .26792 .48168 .25809 Mtetra
.211 .294 .731 r
.48168 .25809 .48519 .26792 .49164 .26298 .48801 .26345 Mtetra
.965 .924 .708 r
.48801 .26345 .49164 .26298 .49801 .26811 .49455 .25147 Mtetra
.189 .183 .62 r
.49455 .25147 .49801 .26811 .50455 .25274 .5009 .2612 Mtetra
0 0 0 r
.5009 .2612 .50455 .25274 .51094 .26332 .50741 .25367 Mtetra
.704 .595 .731 r
.50741 .25367 .51094 .26332 .51745 .25389 .51391 .24854 Mtetra
.847 .438 0 r
.51391 .24854 .51745 .25389 .52394 .24549 .52038 .26524 Mtetra
0 0 .199 r
.52038 .26524 .52394 .24549 .53047 .26252 .52693 .24825 Mtetra
.689 .535 .672 r
.52693 .24825 .53047 .26252 .53697 .24743 .53345 .2416 Mtetra
.92 .548 .126 r
.53345 .2416 .53697 .24743 .54346 .23836 .54014 .26797 Mtetra
.406 .142 .397 r
.54014 .26797 .54346 .23836 .55039 .28359 .54673 .2611 Mtetra
.841 .598 .571 r
.54673 .2611 .55039 .28359 .55723 .29822 .55304 .22484 Mtetra
.32 .171 .517 r
.55304 .22484 .55723 .29822 .56324 .24046 .55998 .25471 Mtetra
.903 .576 .416 r
.55998 .25471 .56324 .24046 .56994 .24423 .56752 .31755 Mtetra
.273 .078 .422 r
.56752 .31755 .56994 .24423 .57784 .31696 .57381 .28198 Mtetra
.855 .592 .539 r
.57381 .28198 .57784 .31696 .58424 .29298 .57946 .2178 Mtetra
.26 .128 .504 r
.57946 .2178 .58424 .29298 .58954 .22079 .58692 .25582 Mtetra
.815 .502 .46 r
.58692 .25582 .58954 .22079 .59711 .25782 .59499 .31287 Mtetra
0 0 .313 r
.59499 .31287 .59711 .25782 .60538 .31458 .6007 .26228 Mtetra
.787 .529 .546 r
.6007 .26228 .60538 .31458 .61071 .25624 .60605 .20603 Mtetra
0 0 .421 r
.60605 .20603 .61071 .25624 .61614 .20863 .61426 .25552 Mtetra
.774 .469 .471 r
.61426 .25552 .61614 .20863 .6249 .26987 .62289 .31059 Mtetra
0 0 .182 r
.62289 .31059 .6249 .26987 .63319 .30849 .62815 .257 Mtetra
.801 .538 .54 r
.62815 .257 .63319 .30849 .63772 .23993 .63294 .19636 Mtetra
0 0 .454 r
.63294 .19636 .63772 .23993 .64305 .19892 .64135 .23706 Mtetra
.837 .519 .452 r
.64135 .23706 .64305 .19892 .65248 .26066 .65125 .30969 Mtetra
.358 .131 .427 r
.65125 .30969 .65248 .26066 .662 .31749 .65769 .29248 Mtetra
.916 .64 .502 r
.65769 .29248 .662 .31749 .66709 .27167 .66131 .21368 Mtetra
.686 .448 .556 r
.66131 .21368 .66709 .27167 .67063 .19763 .66695 .18482 Mtetra
.902 .584 .094 r
.66695 .18482 .67063 .19763 .67769 .19911 .67666 .24007 Mtetra
.849 .529 .446 r
.67666 .24007 .67769 .19911 .68878 .27627 .6882 .32529 Mtetra
.736 .432 .465 r
.6882 .32529 .68878 .27627 .70031 .3543 .69793 .36905 Mtetra
0 0 .089 r
.69793 .36905 .70031 .3543 .70871 .37123 .70431 .34954 Mtetra
.902 .635 .524 r
.70431 .34954 .70871 .37123 .71377 .33047 .70857 .29498 Mtetra
.843 .576 .534 r
.70857 .29498 .71377 .33047 .71752 .27127 .71256 .2398 Mtetra
.815 .56 .553 r
.71256 .2398 .71752 .27127 .72168 .22228 .71731 .20022 Mtetra
.794 .563 .588 r
.71731 .20022 .72168 .22228 .72682 .19104 .72299 .17699 Mtetra
.77 .587 .65 r
.72299 .17699 .72682 .19104 .73282 .17385 .72934 .16485 Mtetra
.74 .633 .74 r
.72934 .16485 .73282 .17385 .73936 .16491 .73608 .15857 Mtetra
.706 .686 .829 r
.73608 .15857 .73936 .16491 .74619 .15996 .743 .15478 Mtetra
.68 .723 .882 r
.743 .15478 .74619 .15996 .75314 .15666 .74999 .15189 Mtetra
.669 .738 .902 r
.74999 .15189 .75314 .15666 .76016 .15394 .75703 .14925 Mtetra
.665 .742 .907 r
.75703 .14925 .76016 .15394 .7672 .15136 .76409 .14667 Mtetra
.664 .742 .908 r
.76409 .14667 .7672 .15136 .77427 .14882 .77116 .14411 Mtetra
.664 .741 .908 r
.77116 .14411 .77427 .14882 .78135 .14627 .77826 .14154 Mtetra
.14758 .36391 .15162 .36768 .15727 .36564 .15323 .36187 Mtetra
.663 .741 .908 r
.15323 .36187 .15727 .36564 .16293 .36361 .1589 .35982 Mtetra
.662 .74 .908 r
.1589 .35982 .16293 .36361 .16859 .3616 .16457 .35778 Mtetra
.659 .739 .909 r
.16457 .35778 .16859 .3616 .17427 .35965 .17026 .35579 Mtetra
.648 .734 .912 r
.17026 .35579 .17427 .35965 .17992 .35796 .17594 .35396 Mtetra
.612 .716 .919 r
.17594 .35396 .17992 .35796 .1855 .35715 .18158 .3526 Mtetra
.492 .639 .921 r
.18158 .3526 .1855 .35715 .19083 .35882 .18709 .35259 Mtetra
.1 .334 .806 r
.18709 .35259 .19083 .35882 .19559 .36627 .19226 .35605 Mtetra
0 0 .361 r
.19226 .35605 .19559 .36627 .19929 .38465 .19667 .36709 Mtetra
.772 .54 0 r
.19667 .36709 .19929 .38465 .20148 .41897 .19981 .39141 Mtetra
.83 .628 .078 r
.19981 .39141 .20148 .41897 .20236 .46816 .20136 .43269 Mtetra
.811 .632 .077 r
.20136 .43269 .20236 .46816 .20357 .51587 .20204 .48467 Mtetra
0 0 .074 r
.20204 .48467 .20357 .51587 .20827 .52856 .20421 .52325 Mtetra
.834 .724 .742 r
.20421 .52325 .20827 .52856 .21873 .47998 .21103 .51398 Mtetra
.951 .815 .373 r
.21103 .51398 .21873 .47998 .23254 .39282 .22324 .44619 Mtetra
.846 .753 .238 r
.22324 .44619 .23254 .39282 .24327 .33694 .2367 .36226 Mtetra
0 0 0 r
.2367 .36226 .24327 .33694 .24662 .36352 .24525 .33039 Mtetra
.757 .588 .016 r
.24525 .33039 .24662 .36352 .24618 .43573 .24685 .37745 Mtetra
0 0 .139 r
.24685 .37745 .24618 .43573 .25134 .44448 .24714 .44216 Mtetra
.925 .783 .685 r
.24714 .44216 .25134 .44448 .26355 .36778 .2544 .4263 Mtetra
.702 .661 .111 r
.2544 .4263 .26355 .36778 .27264 .32679 .26679 .34695 Mtetra
0 0 0 r
.26679 .34695 .27264 .32679 .27389 .38432 .27432 .32521 Mtetra
0 0 .159 r
.27432 .32521 .27389 .38432 .27635 .4291 .27501 .39069 Mtetra
0 0 .37 r
.27501 .39069 .27635 .4291 .28692 .36768 .27854 .42226 Mtetra
0 0 0 r
.27854 .42226 .28692 .36768 .29643 .31787 .2895 .35536 Mtetra
0 0 .001 r
.2895 .35536 .29643 .31787 .29845 .37151 .29852 .3122 Mtetra
0 0 .303 r
.29852 .3122 .29845 .37151 .30154 .41285 .30062 .36545 Mtetra
0 0 .331 r
.30062 .36545 .30154 .41285 .31182 .34988 .30372 .4073 Mtetra
0 0 .149 r
.30372 .4073 .31182 .34988 .32025 .31179 .3135 .35154 Mtetra
0 0 0 r
.3135 .35154 .32025 .31179 .32231 .37228 .3226 .30353 Mtetra
.087 0 .432 r
.3226 .30353 .32231 .37228 .3267 .39903 .32582 .34643 Mtetra
0 0 .404 r
.32582 .34643 .3267 .39903 .33683 .33145 .32946 .38535 Mtetra
0 0 .214 r
.32946 .38535 .33683 .33145 .34462 .30053 .33835 .33841 Mtetra
0 0 .021 r
.33835 .33841 .34462 .30053 .34879 .3325 .34697 .29331 Mtetra
.397 .246 .557 r
.34697 .29331 .34879 .3325 .35484 .33246 .35241 .30326 Mtetra
.384 .255 .579 r
.35241 .30326 .35484 .33246 .36248 .30232 .358 .3114 Mtetra
.821 .858 .406 r
.358 .3114 .36248 .30232 .36834 .30578 .36496 .29396 Mtetra
.392 .37 .715 r
.36496 .29396 .36834 .30578 .37386 .31697 .37085 .29714 Mtetra
.19 .154 .585 r
.37085 .29714 .37386 .31697 .38094 .29578 .37643 .30779 Mtetra
0 0 0 r
.37643 .30779 .38094 .29578 .38697 .29727 .38336 .29013 Mtetra
0 .113 .665 r
.38336 .29013 .38697 .29727 .39298 .29953 .38918 .29675 Mtetra
.622 .811 .973 r
.38918 .29675 .39298 .29953 .39969 .28548 .39541 .2949 Mtetra
0 0 0 r
.39541 .2949 .39969 .28548 .40552 .29334 .40197 .28482 Mtetra
0 .167 .69 r
.40197 .28482 .40552 .29334 .41209 .28268 .4079 .29149 Mtetra
0 0 0 r
.4079 .29149 .41209 .28268 .41818 .28501 .41451 .28006 Mtetra
0 .33 .814 r
.41451 .28006 .41818 .28501 .42454 .28035 .42059 .2839 Mtetra
.626 .895 .58 r
.42059 .2839 .42454 .28035 .43081 .27874 .42705 .27687 Mtetra
.258 .702 .96 r
.42705 .27687 .43081 .27874 .43711 .27642 .4333 .27706 Mtetra
.623 .96 .864 r
.4333 .27706 .43711 .27642 .44343 .27409 .43968 .2732 Mtetra
.49 .876 .97 r
.43968 .2732 .44343 .27409 .44977 .27162 .44601 .27143 Mtetra
.394 .848 .9 r
.44601 .27143 .44977 .27162 .4561 .26982 .45237 .26968 Mtetra
.673 .968 .924 r
.45237 .26968 .4561 .26982 .46248 .26706 .45878 .26599 Mtetra
0 .466 .737 r
.45878 .26599 .46248 .26706 .46885 .26478 .4651 .2674 Mtetra
.748 .962 .672 r
.4651 .2674 .46885 .26478 .47522 .26409 .4716 .25995 Mtetra
0 .045 .567 r
.4716 .25995 .47522 .26409 .48168 .25809 .47789 .26614 Mtetra
0 0 0 r
.47789 .26614 .48168 .25809 .48801 .26345 .48446 .25514 Mtetra
.077 .246 .735 r
.48446 .25514 .48801 .26345 .49455 .25147 .49082 .26103 Mtetra
.291 0 .168 r
.49082 .26103 .49455 .25147 .5009 .2612 .49731 .25752 Mtetra
.899 .801 .742 r
.49731 .25752 .5009 .2612 .50741 .25367 .50386 .24707 Mtetra
.684 .292 0 r
.50386 .24707 .50741 .25367 .51391 .24854 .51028 .26019 Mtetra
0 0 0 r
.51028 .26019 .51391 .24854 .52038 .26524 .51686 .24405 Mtetra
.648 .471 .63 r
.51686 .24405 .52038 .26524 .52693 .24825 .52339 .23729 Mtetra
0 0 .505 r
.52339 .23729 .52693 .24825 .53345 .2416 .52995 .25033 Mtetra
0 0 0 r
.52995 .25033 .53345 .2416 .54014 .26797 .53649 .23619 Mtetra
.671 .461 .592 r
.53649 .23619 .54014 .26797 .54673 .2611 .543 .22293 Mtetra
0 0 .364 r
.543 .22293 .54673 .2611 .55304 .22484 .54993 .26584 Mtetra
.751 .449 .472 r
.54993 .26584 .55304 .22484 .55998 .25471 .55705 .30675 Mtetra
0 0 .301 r
.55705 .30675 .55998 .25471 .56752 .31755 .56329 .26017 Mtetra
.746 .496 .553 r
.56329 .26017 .56752 .31755 .57381 .28198 .56937 .21443 Mtetra
.119 .029 .469 r
.56937 .21443 .57381 .28198 .57946 .2178 .57683 .26167 Mtetra
.768 .464 .472 r
.57683 .26167 .57946 .2178 .58692 .25582 .58458 .31129 Mtetra
0 0 .309 r
.58458 .31129 .58692 .25582 .59499 .31287 .59044 .26061 Mtetra
.788 .529 .546 r
.59044 .26061 .59499 .31287 .6007 .26228 .59597 .2043 Mtetra
.101 .024 .474 r
.59597 .2043 .6007 .26228 .60605 .20603 .60382 .24707 Mtetra
.806 .495 .463 r
.60382 .24707 .60605 .20603 .61426 .25552 .61242 .30855 Mtetra
.089 0 .354 r
.61242 .30855 .61426 .25552 .62289 .31059 .61824 .26804 Mtetra
.845 .576 .532 r
.61824 .26804 .62289 .31059 .62815 .257 .62296 .19825 Mtetra
.354 .206 .537 r
.62296 .19825 .62815 .257 .63294 .19636 .63055 .21959 Mtetra
.891 .563 .421 r
.63055 .21959 .63294 .19636 .64135 .23706 .64031 .29615 Mtetra
.565 .298 .47 r
.64031 .29615 .64135 .23706 .65125 .30969 .64775 .30416 Mtetra
.977 .712 .46 r
.64775 .30416 .65125 .30969 .65769 .29248 .65192 .2317 Mtetra
.753 .496 .544 r
.65192 .2317 .65769 .29248 .66131 .21368 .65674 .18119 Mtetra
0 0 .479 r
.65674 .18119 .66131 .21368 .66695 .18482 .66512 .21217 Mtetra
.886 .557 .421 r
.66512 .21217 .66695 .18482 .67666 .24007 .67618 .29473 Mtetra
.775 .467 .467 r
.67618 .29473 .67666 .24007 .6882 .32529 .68671 .35868 Mtetra
.542 .255 .429 r
.68671 .35868 .6882 .32529 .69793 .36905 .69432 .36171 Mtetra
.968 .718 .506 r
.69432 .36171 .69793 .36905 .70431 .34954 .69928 .31617 Mtetra
.859 .589 .53 r
.69928 .31617 .70431 .34954 .70857 .29498 .70332 .25783 Mtetra
.815 .554 .544 r
.70332 .25783 .70857 .29498 .71256 .2398 .7078 .21098 Mtetra
.786 .544 .57 r
.7078 .21098 .71256 .2398 .71731 .20022 .71319 .18163 Mtetra
.765 .557 .617 r
.71319 .18163 .71731 .20022 .72299 .17699 .71934 .16584 Mtetra
.747 .603 .697 r
.71934 .16584 .72299 .17699 .72934 .16485 .72597 .15774 Mtetra
.723 .67 .797 r
.72597 .15774 .72934 .16485 .73608 .15857 .73284 .15315 Mtetra
.694 .719 .868 r
.73284 .15315 .73608 .15857 .743 .15478 .73981 .14991 Mtetra
.675 .737 .897 r
.73981 .14991 .743 .15478 .74999 .15189 .74683 .14714 Mtetra
.667 .74 .905 r
.74683 .14714 .74999 .15189 .75703 .14925 .75388 .14452 Mtetra
.665 .741 .907 r
.75388 .14452 .75703 .14925 .76409 .14667 .76095 .14194 Mtetra
.664 .741 .907 r
.76095 .14194 .76409 .14667 .77116 .14411 .76804 .13937 Mtetra
.664 .741 .908 r
.76804 .13937 .77116 .14411 .77826 .14154 .77515 .1368 Mtetra
.14352 .36013 .14758 .36391 .15323 .36187 .14918 .35808 Mtetra
.14918 .35808 .15323 .36187 .1589 .35982 .15485 .35602 Mtetra
.663 .741 .908 r
.15485 .35602 .1589 .35982 .16457 .35778 .16054 .35396 Mtetra
.662 .74 .908 r
.16054 .35396 .16457 .35778 .17026 .35579 .16623 .35191 Mtetra
.656 .736 .908 r
.16623 .35191 .17026 .35579 .17594 .35396 .17193 .34995 Mtetra
.635 .724 .912 r
.17193 .34995 .17594 .35396 .18158 .3526 .17761 .34829 Mtetra
.57 .686 .918 r
.17761 .34829 .18158 .3526 .18709 .35259 .18322 .34743 Mtetra
.366 .546 .899 r
.18322 .34743 .18709 .35259 .19226 .35605 .18862 .34862 Mtetra
0 .104 .658 r
.18862 .34862 .19226 .35605 .19667 .36709 .19356 .35446 Mtetra
0 0 .224 r
.19356 .35446 .19667 .36709 .19981 .39141 .1976 .36952 Mtetra
.76 .557 0 r
.1976 .36952 .19981 .39141 .20136 .43269 .20023 .39929 Mtetra
.769 .6 .032 r
.20023 .39929 .20136 .43269 .20204 .48467 .20137 .44537 Mtetra
.712 .571 0 r
.20137 .44537 .20204 .48467 .20421 .52325 .20221 .49644 Mtetra
0 0 .263 r
.20221 .49644 .20421 .52325 .21103 .51398 .20558 .52313 Mtetra
.995 .869 .553 r
.20558 .52313 .21103 .51398 .22324 .44619 .21426 .49435 Mtetra
.873 .772 .27 r
.21426 .49435 .22324 .44619 .2367 .36226 .22748 .4153 Mtetra
.762 .707 .169 r
.22748 .4153 .2367 .36226 .24525 .33039 .24005 .3405 Mtetra
0 0 0 r
.24005 .3405 .24525 .33039 .24685 .37745 .24669 .33003 Mtetra
0 0 .066 r
.24669 .33003 .24685 .37745 .24714 .44216 .24735 .38866 Mtetra
0 0 .226 r
.24735 .38866 .24714 .44216 .2544 .4263 .24873 .44148 Mtetra
.95 .858 .437 r
.24873 .44148 .2544 .4263 .26679 .34695 .25741 .40861 Mtetra
0 0 0 r
.25741 .40861 .26679 .34695 .27432 .32521 .26952 .33228 Mtetra
.26952 .33228 .27432 .32521 .27501 .39069 .27603 .32342 Mtetra
0 0 .221 r
.27603 .32342 .27501 .39069 .27854 .42226 .27666 .39059 Mtetra
0 0 .408 r
.27666 .39059 .27854 .42226 .2895 .35536 .28073 .41556 Mtetra
0 0 .057 r
.28073 .41556 .2895 .35536 .29852 .3122 .29164 .34928 Mtetra
0 0 0 r
.29164 .34928 .29852 .3122 .30062 .36545 .3007 .30556 Mtetra
0 0 .369 r
.3007 .30556 .30062 .36545 .30372 .4073 .30334 .35177 Mtetra
0 0 .325 r
.30334 .35177 .30372 .4073 .3135 .35154 .30602 .40021 Mtetra
0 0 .213 r
.30602 .40021 .3135 .35154 .3226 .30353 .31479 .35971 Mtetra
0 0 .098 r
.31479 .35971 .3226 .30353 .32582 .34643 .32466 .29982 Mtetra
.354 .204 .534 r
.32466 .29982 .32582 .34643 .32946 .38535 .3297 .31434 Mtetra
.148 .031 .453 r
.3297 .31434 .32946 .38535 .33835 .33841 .33329 .35423 Mtetra
0 0 0 r
.33329 .35423 .33835 .33841 .34697 .29331 .34049 .33516 Mtetra
0 0 .174 r
.34049 .33516 .34697 .29331 .35241 .30326 .34874 .29672 Mtetra
.602 .612 .834 r
.34874 .29672 .35241 .30326 .358 .3114 .35484 .29541 Mtetra
.18 .176 .617 r
.35484 .29541 .358 .3114 .36496 .29396 .36043 .30405 Mtetra
.673 .778 .304 r
.36043 .30405 .36496 .29396 .37085 .29714 .36731 .28828 Mtetra
.628 .565 .764 r
.36731 .28828 .37085 .29714 .37643 .30779 .3735 .28608 Mtetra
.359 .264 .609 r
.3735 .28608 .37643 .30779 .38336 .29013 .37927 .293 Mtetra
.965 .939 .656 r
.37927 .293 .38336 .29013 .38918 .29675 .38601 .27949 Mtetra
.272 .23 .627 r
.38601 .27949 .38918 .29675 .39541 .2949 .39181 .2871 Mtetra
.745 .645 .749 r
.39181 .2871 .39541 .2949 .40197 .28482 .39822 .28124 Mtetra
.664 .775 .932 r
.39822 .28124 .40197 .28482 .4079 .29149 .40448 .27896 Mtetra
.478 .417 .711 r
.40448 .27896 .4079 .29149 .41451 .28006 .41063 .2805 Mtetra
.857 .99 .842 r
.41063 .2805 .41451 .28006 .42059 .2839 .41708 .27399 Mtetra
.424 .426 .758 r
.41708 .27399 .42059 .2839 .42705 .27687 .42324 .27613 Mtetra
.83 .958 .895 r
.42324 .27613 .42705 .27687 .4333 .27706 .42967 .27073 Mtetra
.542 .595 .856 r
.42967 .27073 .4333 .27706 .43968 .2732 .43596 .27037 Mtetra
.688 .831 .952 r
.43596 .27037 .43968 .2732 .44601 .27143 .44233 .26767 Mtetra
.73 .786 .897 r
.44233 .26767 .44601 .27143 .45237 .26968 .44873 .26421 Mtetra
.49 .606 .895 r
.44873 .26421 .45237 .26968 .45878 .26599 .45507 .26437 Mtetra
.863 .91 .862 r
.45507 .26437 .45878 .26599 .4651 .2674 .46156 .25806 Mtetra
.437 .449 .773 r
.46156 .25806 .4651 .2674 .4716 .25995 .46789 .25987 Mtetra
.857 .982 .855 r
.46789 .25987 .4716 .25995 .47789 .26614 .4744 .25348 Mtetra
.591 .489 .707 r
.4744 .25348 .47789 .26614 .48446 .25514 .48084 .25176 Mtetra
.353 .659 .971 r
.48084 .25176 .48446 .25514 .49082 .26103 .48726 .25231 Mtetra
.824 .666 .687 r
.48726 .25231 .49082 .26103 .49731 .25752 .49384 .24067 Mtetra
.226 .207 .627 r
.49384 .24067 .49731 .25752 .50386 .24707 .50023 .2496 Mtetra
.933 .957 .644 r
.50023 .2496 .50386 .24707 .51028 .26019 .5068 .23753 Mtetra
.562 .406 .627 r
.5068 .23753 .51028 .26019 .51686 .24405 .51331 .23603 Mtetra
0 0 .483 r
.51331 .23603 .51686 .24405 .52339 .23729 .51982 .2471 Mtetra
0 0 0 r
.51982 .2471 .52339 .23729 .52995 .25033 .52639 .23289 Mtetra
.578 .442 .659 r
.52639 .23289 .52995 .25033 .53649 .23619 .53296 .23109 Mtetra
.947 .591 .22 r
.53296 .23109 .53649 .23619 .543 .22293 .53972 .26608 Mtetra
.61 .327 .463 r
.53972 .26608 .543 .22293 .54993 .26584 .5465 .27851 Mtetra
.957 .794 .35 r
.5465 .27851 .54993 .26584 .55705 .30675 .55283 .23255 Mtetra
.611 .386 .552 r
.55283 .23255 .55705 .30675 .56329 .26017 .55931 .21591 Mtetra
0 0 .29 r
.55931 .21591 .56329 .26017 .56937 .21443 .56676 .274 Mtetra
.68 .395 .482 r
.56676 .274 .56937 .21443 .57683 .26167 .57411 .30772 Mtetra
0 0 .187 r
.57411 .30772 .57683 .26167 .58458 .31129 .58002 .25114 Mtetra
.75 .497 .549 r
.58002 .25114 .58458 .31129 .59044 .26061 .58585 .20202 Mtetra
.098 .02 .471 r
.58585 .20202 .59044 .26061 .59597 .2043 .59356 .24499 Mtetra
.806 .495 .463 r
.59356 .24499 .59597 .2043 .60382 .24707 .60193 .30615 Mtetra
.219 .03 .398 r
.60193 .30615 .60382 .24707 .61242 .30855 .60805 .27246 Mtetra
.868 .598 .527 r
.60805 .27246 .61242 .30855 .61824 .26804 .61293 .20029 Mtetra
.477 .289 .547 r
.61293 .20029 .61824 .26804 .62296 .19825 .62003 .20837 Mtetra
.932 .598 .378 r
.62003 .20837 .62296 .19825 .63055 .21959 .62942 .28262 Mtetra
.643 .362 .478 r
.62942 .28262 .63055 .21959 .64031 .29615 .63744 .30844 Mtetra
.967 .763 .326 r
.63744 .30844 .64031 .29615 .64775 .30416 .64228 .24731 Mtetra
.794 .529 .537 r
.64228 .24731 .64775 .30416 .65192 .2317 .64679 .18416 Mtetra
.446 .28 .562 r
.64679 .18416 .65192 .2317 .65674 .18119 .65413 .19325 Mtetra
.927 .588 .374 r
.65413 .19325 .65674 .18119 .66512 .21217 .66446 .26695 Mtetra
.798 .488 .464 r
.66446 .26695 .66512 .21217 .67618 .29473 .67527 .343 Mtetra
.658 .364 .463 r
.67527 .343 .67618 .29473 .68671 .35868 .68384 .36624 Mtetra
.937 .805 .346 r
.68384 .36624 .68671 .35868 .69432 .36171 .68958 .33264 Mtetra
.875 .606 .528 r
.68958 .33264 .69432 .36171 .69928 .31617 .69387 .27487 Mtetra
.814 .55 .54 r
.69387 .27487 .69928 .31617 .70332 .25783 .69825 .2229 Mtetra
.782 .533 .559 r
.69825 .2229 .70332 .25783 .7078 .21098 .70342 .18792 Mtetra
.765 .542 .595 r
.70342 .18792 .7078 .21098 .71319 .18163 .70938 .16806 Mtetra
.755 .582 .662 r
.70938 .16806 .71319 .18163 .71934 .16584 .71589 .15756 Mtetra
.74 .648 .758 r
.71589 .15756 .71934 .16584 .72597 .15774 .72268 .15175 Mtetra
.71 .702 .841 r
.72268 .15175 .72597 .15774 .73284 .15315 .72961 .14799 Mtetra
.683 .726 .883 r
.72961 .14799 .73284 .15315 .73981 .14991 .73662 .14503 Mtetra
.669 .735 .899 r
.73662 .14503 .73981 .14991 .74683 .14714 .74366 .14236 Mtetra
.665 .738 .905 r
.74366 .14236 .74683 .14714 .75388 .14452 .75072 .13977 Mtetra
.664 .74 .907 r
.75072 .13977 .75388 .14452 .76095 .14194 .75781 .1372 Mtetra
.664 .741 .908 r
.75781 .1372 .76095 .14194 .76804 .13937 .76491 .13462 Mtetra
.76491 .13462 .76804 .13937 .77515 .1368 .77203 .13204 Mtetra
.663 .741 .908 r
.13944 .35634 .14352 .36013 .14918 .35808 .14511 .35427 Mtetra
.14511 .35427 .14918 .35808 .15485 .35602 .15079 .35221 Mtetra
.15079 .35221 .15485 .35602 .16054 .35396 .15648 .35014 Mtetra
.15648 .35014 .16054 .35396 .16623 .35191 .16219 .34807 Mtetra
.661 .74 .908 r
.16219 .34807 .16623 .35191 .17193 .34995 .1679 .34603 Mtetra
.652 .733 .909 r
.1679 .34603 .17193 .34995 .17761 .34829 .17361 .34411 Mtetra
.619 .711 .911 r
.17361 .34411 .17761 .34829 .18322 .34743 .17929 .34264 Mtetra
.516 .639 .909 r
.17929 .34264 .18322 .34743 .18862 .34862 .18484 .34243 Mtetra
.209 .406 .837 r
.18484 .34243 .18862 .34862 .19356 .35446 .19011 .34515 Mtetra
0 0 .495 r
.19011 .34515 .19356 .35446 .1976 .36952 .19478 .35388 Mtetra
0 0 .148 r
.19478 .35388 .1976 .36952 .20023 .39929 .19842 .37322 Mtetra
.736 .557 0 r
.19842 .37322 .20023 .39929 .20137 .44537 .20062 .40768 Mtetra
0 0 .015 r
.20062 .40768 .20137 .44537 .20221 .49644 .2016 .4561 Mtetra
0 0 .097 r
.2016 .4561 .20221 .49644 .20558 .52313 .20292 .50295 Mtetra
0 0 .504 r
.20292 .50295 .20558 .52313 .21426 .49435 .20756 .51676 Mtetra
.941 .838 .397 r
.20756 .51676 .21426 .49435 .22748 .4153 .21767 .47282 Mtetra
.79 .721 .189 r
.21767 .47282 .22748 .4153 .24005 .3405 .23125 .38934 Mtetra
0 0 0 r
.23125 .38934 .24005 .3405 .24669 .33003 .24276 .32581 Mtetra
.558 .067 0 r
.24276 .32581 .24669 .33003 .24735 .38866 .24797 .33173 Mtetra
0 0 .133 r
.24797 .33173 .24735 .38866 .24873 .44148 .24827 .39514 Mtetra
0 0 .292 r
.24827 .39514 .24873 .44148 .25741 .40861 .25066 .43683 Mtetra
.776 .746 .225 r
.25066 .43683 .25741 .40861 .26952 .33228 .26012 .39467 Mtetra
0 0 .004 r
.26012 .39467 .26952 .33228 .27603 .32342 .27187 .32237 Mtetra
.729 .928 .957 r
.27187 .32237 .27603 .32342 .27666 .39059 .27797 .31897 Mtetra
0 0 .268 r
.27797 .31897 .27666 .39059 .28073 .41556 .27877 .38454 Mtetra
0 0 .387 r
.27877 .38454 .28073 .41556 .29164 .34928 .28283 .41031 Mtetra
0 0 .12 r
.28283 .41031 .29164 .34928 .3007 .30556 .29332 .34949 Mtetra
0 0 .019 r
.29332 .34949 .3007 .30556 .30334 .35177 .30285 .29933 Mtetra
.098 .004 .449 r
.30285 .29933 .30334 .35177 .30602 .40021 .30655 .33087 Mtetra
0 0 .352 r
.30655 .33087 .30602 .40021 .31479 .35971 .30882 .38591 Mtetra
.061 0 .237 r
.30882 .38591 .31479 .35971 .32466 .29982 .31602 .36903 Mtetra
0 0 .191 r
.31602 .36903 .32466 .29982 .3297 .31434 .32615 .30536 Mtetra
.848 .666 .655 r
.32615 .30536 .3297 .31434 .33329 .35423 .33315 .289 Mtetra
.284 .137 .498 r
.33315 .289 .33329 .35423 .34049 .33516 .33756 .31525 Mtetra
.509 .378 .638 r
.33756 .31525 .34049 .33516 .34874 .29672 .34355 .3164 Mtetra
0 0 0 r
.34355 .3164 .34874 .29672 .35484 .29541 .35084 .29454 Mtetra
.103 .645 .847 r
.35084 .29454 .35484 .29541 .36043 .30405 .35689 .29472 Mtetra
0 0 .476 r
.35689 .29472 .36043 .30405 .36731 .28828 .36243 .30524 Mtetra
0 0 .014 r
.36243 .30524 .36731 .28828 .3735 .28608 .36942 .28778 Mtetra
.365 .816 .693 r
.36942 .28778 .3735 .28608 .37927 .293 .37568 .2847 Mtetra
.201 .327 .769 r
.37568 .2847 .37927 .293 .38601 .27949 .38162 .28895 Mtetra
0 0 0 r
.38162 .28895 .38601 .27949 .39181 .2871 .38842 .27453 Mtetra
.246 .264 .682 r
.38842 .27453 .39181 .2871 .39822 .28124 .39432 .28043 Mtetra
.917 .913 .799 r
.39432 .28043 .39822 .28124 .40448 .27896 .40086 .27191 Mtetra
.532 .564 .833 r
.40086 .27191 .40448 .27896 .41063 .2805 .40706 .27176 Mtetra
.653 .582 .763 r
.40706 .27176 .41063 .2805 .41708 .27399 .41339 .26884 Mtetra
.696 .709 .858 r
.41339 .26884 .41708 .27399 .42324 .27613 .41973 .26578 Mtetra
.594 .521 .742 r
.41973 .26578 .42324 .27613 .42967 .27073 .42604 .26428 Mtetra
.674 .653 .821 r
.42604 .26428 .42967 .27073 .43596 .27037 .4324 .26141 Mtetra
.631 .567 .765 r
.4324 .26141 .43596 .27037 .44233 .26767 .43876 .25908 Mtetra
.607 .563 .779 r
.43876 .25908 .44233 .26767 .44873 .26421 .44512 .25743 Mtetra
.686 .649 .807 r
.44512 .25743 .44873 .26421 .45507 .26437 .45154 .25413 Mtetra
.582 .517 .747 r
.45154 .25413 .45507 .26437 .46156 .25806 .45792 .25293 Mtetra
.654 .697 .878 r
.45792 .25293 .46156 .25806 .46789 .25987 .46434 .2507 Mtetra
.674 .587 .75 r
.46434 .2507 .46789 .25987 .4744 .25348 .4708 .24695 Mtetra
.228 .41 .835 r
.4708 .24695 .4744 .25348 .48084 .25176 .47716 .25017 Mtetra
.93 .88 .764 r
.47716 .25017 .48084 .25176 .48726 .25231 .48374 .2402 Mtetra
0 .099 .619 r
.48374 .2402 .48726 .25231 .49384 .24067 .49008 .25001 Mtetra
0 0 0 r
.49008 .25001 .49384 .24067 .50023 .2496 .49667 .24066 Mtetra
.563 .533 .78 r
.49667 .24066 .50023 .2496 .5068 .23753 .50317 .23998 Mtetra
.831 .403 .221 r
.50317 .23998 .5068 .23753 .51331 .23603 .50963 .25267 Mtetra
0 0 .122 r
.50963 .25267 .51331 .23603 .51982 .2471 .51626 .23662 Mtetra
.658 .559 .732 r
.51626 .23662 .51982 .2471 .52639 .23289 .52283 .23297 Mtetra
.89 .475 .2 r
.52283 .23297 .52639 .23289 .53296 .23109 .52945 .2506 Mtetra
.309 .028 .314 r
.52945 .2506 .53296 .23109 .53972 .26608 .53607 .24312 Mtetra
.82 .582 .58 r
.53607 .24312 .53972 .26608 .5465 .27851 .54255 .21226 Mtetra
.425 .25 .538 r
.54255 .21226 .5465 .27851 .55283 .23255 .54929 .22661 Mtetra
.964 .634 .29 r
.54929 .22661 .55283 .23255 .55931 .21591 .55659 .28706 Mtetra
.565 .303 .477 r
.55659 .28706 .55931 .21591 .56676 .274 .56354 .29662 Mtetra
.885 .738 .229 r
.56354 .29662 .56676 .274 .57411 .30772 .56952 .23452 Mtetra
.678 .437 .55 r
.56952 .23452 .57411 .30772 .58002 .25114 .57573 .20051 Mtetra
0 0 .412 r
.57573 .20051 .58002 .25114 .58585 .20202 .58339 .24937 Mtetra
.774 .469 .471 r
.58339 .24937 .58585 .20202 .59356 .24499 .59143 .30482 Mtetra
.214 .026 .395 r
.59143 .30482 .59356 .24499 .60193 .30615 .59765 .27064 Mtetra
.868 .598 .528 r
.59765 .27064 .60193 .30615 .60805 .27246 .60279 .19993 Mtetra
.515 .314 .547 r
.60279 .19993 .60805 .27246 .61293 .20029 .60969 .20219 Mtetra
.954 .617 .334 r
.60969 .20219 .61293 .20029 .62003 .20837 .6187 .27262 Mtetra
.677 .39 .48 r
.6187 .27262 .62003 .20837 .62942 .28262 .62692 .30838 Mtetra
0 0 0 r
.62692 .30838 .62942 .28262 .63744 .30844 .63235 .25827 Mtetra
.823 .554 .532 r
.63235 .25827 .63744 .30844 .64228 .24731 .63687 .18955 Mtetra
.58 .369 .559 r
.63687 .18955 .64228 .24731 .64679 .18416 .64352 .1817 Mtetra
.957 .613 .272 r
.64352 .1817 .64679 .18416 .65413 .19325 .65309 .24416 Mtetra
.816 .503 .46 r
.65309 .24416 .65413 .19325 .66446 .26695 .66381 .32524 Mtetra
.699 .404 .472 r
.66381 .32524 .66446 .26695 .67527 .343 .67298 .3643 Mtetra
0 0 .223 r
.67298 .3643 .67527 .343 .68384 .36624 .67946 .34375 Mtetra
.896 .631 .528 r
.67946 .34375 .68384 .36624 .68958 .33264 .68417 .28996 Mtetra
.816 .551 .538 r
.68417 .28996 .68958 .33264 .69387 .27487 .68861 .23537 Mtetra
.783 .529 .552 r
.68861 .23537 .69387 .27487 .69825 .2229 .69365 .19555 Mtetra
.767 .533 .58 r
.69365 .19555 .69825 .2229 .70342 .18792 .69944 .17133 Mtetra
.759 .564 .633 r
.69944 .17133 .70342 .18792 .70938 .16806 .70579 .15792 Mtetra
.747 .617 .715 r
.70579 .15792 .70938 .16806 .71589 .15756 .7125 .15056 Mtetra
.72 .672 .803 r
.7125 .15056 .71589 .15756 .72268 .15175 .71939 .14612 Mtetra
.689 .709 .863 r
.71939 .14612 .72268 .15175 .72961 .14799 .72638 .14294 Mtetra
.671 .728 .892 r
.72638 .14294 .72961 .14799 .73662 .14503 .73341 .14021 Mtetra
.665 .737 .904 r
.73341 .14021 .73662 .14503 .74366 .14236 .74047 .1376 Mtetra
.664 .741 .907 r
.74047 .1376 .74366 .14236 .75072 .13977 .74755 .13502 Mtetra
.664 .742 .908 r
.74755 .13502 .75072 .13977 .75781 .1372 .75465 .13244 Mtetra
.664 .741 .908 r
.75465 .13244 .75781 .1372 .76491 .13462 .76176 .12984 Mtetra
.76176 .12984 .76491 .13462 .77203 .13204 .76889 .12725 Mtetra
.13535 .35252 .13944 .35634 .14511 .35427 .14102 .35045 Mtetra
.14102 .35045 .14511 .35427 .15079 .35221 .14671 .34838 Mtetra
.663 .741 .908 r
.14671 .34838 .15079 .35221 .15648 .35014 .15241 .3463 Mtetra
.15241 .3463 .15648 .35014 .16219 .34807 .15812 .34422 Mtetra
.662 .741 .909 r
.15812 .34422 .16219 .34807 .1679 .34603 .16384 .34216 Mtetra
.659 .739 .909 r
.16384 .34216 .1679 .34603 .17361 .34411 .16957 .34013 Mtetra
.646 .731 .911 r
.16957 .34013 .17361 .34411 .17929 .34264 .1753 .33829 Mtetra
.599 .696 .911 r
.1753 .33829 .17929 .34264 .18484 .34243 .18096 .33708 Mtetra
.451 .582 .893 r
.18096 .33708 .18484 .34243 .19011 .34515 .18646 .3376 Mtetra
.063 .257 .749 r
.18646 .3376 .19011 .34515 .19478 .35388 .19157 .34203 Mtetra
0 0 .386 r
.19157 .34203 .19478 .35388 .19842 .37322 .19595 .35386 Mtetra
0 0 .126 r
.19595 .35386 .19842 .37322 .20062 .40768 .19919 .37743 Mtetra
0 0 .044 r
.19919 .37743 .20062 .40768 .2016 .4561 .20108 .41563 Mtetra
0 0 .064 r
.20108 .41563 .2016 .4561 .20292 .50295 .20209 .46426 Mtetra
0 0 .18 r
.20209 .46426 .20292 .50295 .20756 .51676 .20409 .50479 Mtetra
.457 .416 .723 r
.20409 .50479 .20756 .51676 .21767 .47282 .20992 .50653 Mtetra
.858 .783 .283 r
.20992 .50653 .21767 .47282 .23125 .38934 .22098 .45222 Mtetra
.71 .67 .123 r
.22098 .45222 .23125 .38934 .24276 .32581 .23451 .36888 Mtetra
0 0 0 r
.23451 .36888 .24276 .32581 .24797 .33173 .24506 .31578 Mtetra
0 0 .329 r
.24506 .31578 .24797 .33173 .24827 .39514 .24935 .33235 Mtetra
0 0 .189 r
.24935 .33235 .24827 .39514 .25066 .43683 .24966 .39645 Mtetra
0 0 .334 r
.24966 .39645 .25066 .43683 .26012 .39467 .25272 .43081 Mtetra
0 0 0 r
.25272 .43081 .26012 .39467 .27187 .32237 .26241 .38585 Mtetra
0 0 .043 r
.26241 .38585 .27187 .32237 .27797 .31897 .27393 .31621 Mtetra
.812 .828 .863 r
.27393 .31621 .27797 .31897 .27877 .38454 .28018 .31108 Mtetra
0 0 .312 r
.28018 .31108 .27877 .38454 .28283 .41031 .28136 .37251 Mtetra
0 0 .347 r
.28136 .37251 .28283 .41031 .29332 .34949 .28492 .40519 Mtetra
0 0 .178 r
.28492 .40519 .29332 .34949 .30285 .29933 .29458 .3558 Mtetra
0 0 .098 r
.29458 .3558 .30285 .29933 .30655 .33087 .30471 .29734 Mtetra
.385 .244 .564 r
.30471 .29734 .30655 .33087 .30882 .38591 .31003 .30613 Mtetra
.032 0 .402 r
.31003 .30613 .30882 .38591 .31602 .36903 .31244 .3592 Mtetra
0 0 .567 r
.31244 .3592 .31602 .36903 .32615 .30536 .31794 .36822 Mtetra
0 0 .236 r
.31794 .36822 .32615 .30536 .33315 .289 .32732 .31648 Mtetra
0 0 0 r
.32732 .31648 .33315 .289 .33756 .31525 .3355 .28145 Mtetra
.412 .265 .57 r
.3355 .28145 .33756 .31525 .34355 .3164 .34106 .28899 Mtetra
.412 .279 .589 r
.34106 .28899 .34355 .3164 .35084 .29454 .34674 .29523 Mtetra
.963 .904 .715 r
.34674 .29523 .35084 .29454 .35689 .29472 .35349 .28284 Mtetra
.419 .387 .717 r
.35349 .28284 .35689 .29472 .36243 .30524 .35943 .28544 Mtetra
.203 .163 .588 r
.35943 .28544 .36243 .30524 .36942 .28778 .36501 .29557 Mtetra
.803 .872 .435 r
.36501 .29557 .36942 .28778 .37568 .2847 .37189 .28047 Mtetra
0 .162 .673 r
.37189 .28047 .37568 .2847 .38162 .28895 .3778 .28526 Mtetra
.497 .708 .965 r
.3778 .28526 .38162 .28895 .38842 .27453 .38399 .28484 Mtetra
0 0 0 r
.38399 .28484 .38842 .27453 .39432 .28043 .39064 .27429 Mtetra
0 .094 .649 r
.39064 .27429 .39432 .28043 .40086 .27191 .39657 .28067 Mtetra
0 0 0 r
.39657 .28067 .40086 .27191 .40706 .27176 .40322 .26982 Mtetra
0 .273 .647 r
.40322 .26982 .40706 .27176 .41339 .26884 .40934 .2728 Mtetra
.5 .819 .508 r
.40934 .2728 .41339 .26884 .41973 .26578 .41583 .26641 Mtetra
.012 0 0 r
.41583 .26641 .41973 .26578 .42604 .26428 .42212 .266 Mtetra
.426 .85 .704 r
.42212 .266 .42604 .26428 .4324 .26141 .42853 .26241 Mtetra
.221 .735 .706 r
.42853 .26241 .4324 .26141 .43876 .25908 .4349 .26054 Mtetra
0 0 0 r
.4349 .26054 .43876 .25908 .44512 .25743 .44128 .2586 Mtetra
.447 .874 .77 r
.44128 .2586 .44512 .25743 .45154 .25413 .44772 .25535 Mtetra
.291 0 0 r
.44772 .25535 .45154 .25413 .45792 .25293 .45407 .25613 Mtetra
.607 .894 .595 r
.45407 .25613 .45792 .25293 .46434 .2507 .46061 .24947 Mtetra
.633 .072 0 r
.46061 .24947 .46434 .2507 .4708 .24695 .46692 .25497 Mtetra
0 0 0 r
.46692 .25497 .4708 .24695 .47716 .25017 .47354 .24431 Mtetra
0 .147 .69 r
.47354 .24431 .47716 .25017 .48374 .2402 .4799 .25045 Mtetra
.224 0 .15 r
.4799 .25045 .48374 .2402 .49008 .25001 .48645 .24559 Mtetra
.864 .779 .766 r
.48645 .24559 .49008 .25001 .49667 .24066 .49305 .23685 Mtetra
.747 .274 0 r
.49305 .23685 .49667 .24066 .50317 .23998 .49947 .24726 Mtetra
.759 .833 .373 r
.49947 .24726 .50317 .23998 .50963 .25267 .50612 .23175 Mtetra
.644 .469 .632 r
.50612 .23175 .50963 .25267 .51626 .23662 .5127 .22531 Mtetra
.098 .191 .673 r
.5127 .22531 .51626 .23662 .52283 .23297 .51925 .23315 Mtetra
.964 .925 .71 r
.51925 .23315 .52283 .23297 .52945 .2506 .52585 .22123 Mtetra
.662 .458 .598 r
.52585 .22123 .52945 .2506 .53607 .24312 .53243 .20998 Mtetra
0 0 .422 r
.53243 .20998 .53607 .24312 .54255 .21226 .53919 .24241 Mtetra
.807 .492 .456 r
.53919 .24241 .54255 .21226 .54929 .22661 .54621 .2894 Mtetra
.395 .163 .44 r
.54621 .2894 .54929 .22661 .55659 .28706 .5529 .27309 Mtetra
.932 .673 .524 r
.5529 .27309 .55659 .28706 .56354 .29662 .55907 .21442 Mtetra
.578 .358 .546 r
.55907 .21442 .56354 .29662 .56952 .23452 .56564 .20358 Mtetra
0 0 .137 r
.56564 .20358 .56952 .23452 .57573 .20051 .57326 .25992 Mtetra
.711 .419 .48 r
.57326 .25992 .57573 .20051 .58339 .24937 .58091 .3033 Mtetra
.077 0 .344 r
.58091 .3033 .58339 .24937 .59143 .30482 .5871 .2626 Mtetra
.839 .572 .535 r
.5871 .2626 .59143 .30482 .59765 .27064 .59255 .19632 Mtetra
.505 .306 .544 r
.59255 .19632 .59765 .27064 .60279 .19993 .59947 .20006 Mtetra
.957 .62 .322 r
.59947 .20006 .60279 .19993 .60969 .20219 .60815 .26774 Mtetra
.685 .397 .48 r
.60815 .26774 .60969 .20219 .6187 .27262 .61632 .30663 Mtetra
0 0 .176 r
.61632 .30663 .6187 .27262 .62692 .30838 .62213 .26397 Mtetra
.841 .571 .53 r
.62213 .26397 .62692 .30838 .63235 .25827 .62686 .1941 Mtetra
.631 .404 .554 r
.62686 .1941 .63235 .25827 .63687 .18955 .63313 .17511 Mtetra
.883 .575 .065 r
.63313 .17511 .63687 .18955 .64352 .1817 .64206 .22702 Mtetra
.831 .515 .454 r
.64206 .22702 .64352 .1817 .65309 .24416 .65246 .3083 Mtetra
.719 .423 .475 r
.65246 .3083 .65309 .24416 .66381 .32524 .66192 .35826 Mtetra
.399 .138 .398 r
.66192 .35826 .66381 .32524 .67298 .3643 .66901 .35004 Mtetra
.929 .672 .527 r
.66901 .35004 .67298 .3643 .67946 .34375 .6742 .30247 Mtetra
.822 .556 .538 r
.6742 .30247 .67946 .34375 .68417 .28996 .67883 .24747 Mtetra
.785 .528 .548 r
.67883 .24747 .68417 .28996 .68861 .23537 .68382 .20378 Mtetra
.769 .527 .569 r
.68382 .20378 .68861 .23537 .69365 .19555 .68946 .17524 Mtetra
.759 .546 .61 r
.68946 .17524 .69365 .19555 .69944 .17133 .69569 .15867 Mtetra
.745 .585 .677 r
.69569 .15867 .69944 .17133 .70579 .15792 .70231 .14956 Mtetra
.722 .639 .764 r
.70231 .14956 .70579 .15792 .7125 .15056 .70916 .14437 Mtetra
.694 .689 .841 r
.70916 .14437 .7125 .15056 .71939 .14612 .71612 .14091 Mtetra
.675 .722 .885 r
.71612 .14091 .71939 .14612 .72638 .14294 .72315 .13809 Mtetra
.667 .737 .902 r
.72315 .13809 .72638 .14294 .73341 .14021 .7302 .13545 Mtetra
.665 .741 .907 r
.7302 .13545 .73341 .14021 .74047 .1376 .73727 .13284 Mtetra
.664 .742 .908 r
.73727 .13284 .74047 .1376 .74755 .13502 .74436 .13025 Mtetra
.664 .741 .908 r
.74436 .13025 .74755 .13502 .75465 .13244 .75147 .12765 Mtetra
.75147 .12765 .75465 .13244 .76176 .12984 .7586 .12505 Mtetra
.7586 .12505 .76176 .12984 .76889 .12725 .76574 .12244 Mtetra
.13124 .3487 .13535 .35252 .14102 .35045 .13692 .34662 Mtetra
.13692 .34662 .14102 .35045 .14671 .34838 .14261 .34453 Mtetra
.14261 .34453 .14671 .34838 .15241 .3463 .14832 .34244 Mtetra
.663 .741 .908 r
.14832 .34244 .15241 .3463 .15812 .34422 .15404 .34035 Mtetra
.15404 .34035 .15812 .34422 .16384 .34216 .15977 .33827 Mtetra
.66 .74 .909 r
.15977 .33827 .16384 .34216 .16957 .34013 .16551 .33621 Mtetra
.655 .737 .91 r
.16551 .33621 .16957 .34013 .1753 .33829 .17125 .33424 Mtetra
.636 .725 .912 r
.17125 .33424 .1753 .33829 .18096 .33708 .17698 .33253 Mtetra
.573 .677 .911 r
.17698 .33253 .18096 .33708 .18646 .3376 .18263 .33164 Mtetra
.38 .518 .87 r
.18263 .33164 .18646 .3376 .19157 .34203 .18807 .33295 Mtetra
0 .134 .664 r
.18807 .33295 .19157 .34203 .19595 .35386 .19302 .3391 Mtetra
0 0 .331 r
.19302 .3391 .19595 .35386 .19919 .37743 .19712 .35392 Mtetra
0 0 .136 r
.19712 .35392 .19919 .37743 .20108 .41563 .20002 .38128 Mtetra
0 0 .081 r
.20002 .38128 .20108 .41563 .20209 .46426 .20169 .42215 Mtetra
0 0 .114 r
.20169 .42215 .20209 .46426 .20409 .50479 .2029 .46948 Mtetra
0 0 .257 r
.2029 .46948 .20409 .50479 .20992 .50653 .20562 .50312 Mtetra
.855 .79 .787 r
.20562 .50312 .20992 .50653 .22098 .45222 .21241 .49499 Mtetra
.765 .721 .19 r
.21241 .49499 .22098 .45222 .23451 .36888 .22402 .43463 Mtetra
0 0 0 r
.22402 .43463 .23451 .36888 .24506 .31578 .2373 .35366 Mtetra
.2373 .35366 .24506 .31578 .24935 .33235 .24715 .30821 Mtetra
0 0 .351 r
.24715 .30821 .24935 .33235 .24966 .39645 .25101 .32999 Mtetra
0 0 .235 r
.25101 .32999 .24966 .39645 .25272 .43081 .25149 .39279 Mtetra
0 0 .344 r
.25149 .39279 .25272 .43081 .26241 .38585 .25479 .42481 Mtetra
0 0 .012 r
.25479 .42481 .26241 .38585 .27393 .31621 .26426 .38255 Mtetra
0 0 .083 r
.26426 .38255 .27393 .31621 .28018 .31108 .27571 .3138 Mtetra
.969 .929 .685 r
.27571 .3138 .28018 .31108 .28136 .37251 .28261 .3005 Mtetra
0 0 .362 r
.28261 .3005 .28136 .37251 .28492 .40519 .28444 .3539 Mtetra
0 0 .341 r
.28444 .3539 .28492 .40519 .29458 .3558 .2873 .39647 Mtetra
0 0 .229 r
.2873 .39647 .29458 .3558 .30471 .29734 .29556 .36632 Mtetra
0 0 .187 r
.29556 .36632 .30471 .29734 .31003 .30613 .30597 .30422 Mtetra
.944 .786 .654 r
.30597 .30422 .31003 .30613 .31244 .3592 .31322 .28545 Mtetra
.197 .065 .464 r
.31322 .28545 .31244 .3592 .31794 .36822 .31676 .32193 Mtetra
.153 .053 .478 r
.31676 .32193 .31794 .36822 .32732 .31648 .32118 .34726 Mtetra
0 0 .141 r
.32118 .34726 .32732 .31648 .3355 .28145 .32901 .3198 Mtetra
0 0 .182 r
.32901 .3198 .3355 .28145 .34106 .28899 .33709 .28669 Mtetra
.655 .851 .975 r
.33709 .28669 .34106 .28899 .34674 .29523 .34328 .28438 Mtetra
.25 .296 .715 r
.34328 .28438 .34674 .29523 .35349 .28284 .34907 .28922 Mtetra
.845 .913 .511 r
.34907 .28922 .35349 .28284 .35943 .28544 .35591 .27559 Mtetra
.607 .536 .748 r
.35591 .27559 .35943 .28544 .36501 .29557 .3621 .27376 Mtetra
.394 .288 .614 r
.3621 .27376 .36501 .29557 .37189 .28047 .36792 .27938 Mtetra
.941 .863 .734 r
.36792 .27938 .37189 .28047 .3778 .28526 .37464 .26778 Mtetra
.293 .243 .629 r
.37464 .26778 .3778 .28526 .38399 .28484 .38045 .27484 Mtetra
.707 .59 .722 r
.38045 .27484 .38399 .28484 .39064 .27429 .38688 .26939 Mtetra
.632 .697 .892 r
.38688 .26939 .39064 .27429 .39657 .28067 .39316 .26757 Mtetra
.487 .417 .704 r
.39316 .26757 .39657 .28067 .40322 .26982 .39932 .26886 Mtetra
.857 .94 .875 r
.39932 .26886 .40322 .26982 .40934 .2728 .4058 .26283 Mtetra
.435 .434 .759 r
.4058 .26283 .40934 .2728 .41583 .26641 .41199 .26472 Mtetra
.822 .911 .899 r
.41199 .26472 .41583 .26641 .42212 .266 .41845 .25956 Mtetra
.548 .597 .855 r
.41845 .25956 .42212 .266 .42853 .26241 .42477 .25907 Mtetra
.688 .803 .936 r
.42477 .25907 .42853 .26241 .4349 .26054 .43117 .25637 Mtetra
.724 .766 .887 r
.43117 .25637 .4349 .26054 .44128 .2586 .43761 .25293 Mtetra
.512 .611 .888 r
.43761 .25293 .44128 .2586 .44772 .25535 .44397 .25283 Mtetra
.847 .866 .856 r
.44397 .25283 .44772 .25535 .45407 .25613 .4505 .2467 Mtetra
.465 .465 .773 r
.4505 .2467 .45407 .25613 .46061 .24947 .45687 .24797 Mtetra
.859 .921 .87 r
.45687 .24797 .46061 .24947 .46692 .25497 .46341 .24178 Mtetra
.603 .492 .699 r
.46341 .24178 .46692 .25497 .47354 .24431 .46989 .2395 Mtetra
.47 .635 .926 r
.46989 .2395 .47354 .24431 .4799 .25045 .47634 .23964 Mtetra
.791 .626 .676 r
.47634 .23964 .4799 .25045 .48645 .24559 .48298 .22841 Mtetra
.308 .261 .641 r
.48298 .22841 .48645 .24559 .49305 .23685 .48938 .23538 Mtetra
.94 .882 .748 r
.48938 .23538 .49305 .23685 .49947 .24726 .49601 .22463 Mtetra
.571 .412 .627 r
.49601 .22463 .49947 .24726 .50612 .23175 .50255 .22255 Mtetra
0 .072 .627 r
.50255 .22255 .50612 .23175 .5127 .22531 .50905 .23148 Mtetra
0 0 0 r
.50905 .23148 .5127 .22531 .51925 .23315 .51567 .22124 Mtetra
.575 .491 .722 r
.51567 .22124 .51925 .23315 .52585 .22123 .52227 .22006 Mtetra
.934 .562 .262 r
.52227 .22006 .52585 .22123 .53243 .20998 .52893 .24968 Mtetra
.672 .376 .463 r
.52893 .24968 .53243 .20998 .53919 .24241 .53572 .27131 Mtetra
0 0 .164 r
.53572 .27131 .53919 .24241 .54621 .2894 .54232 .23946 Mtetra
.75 .501 .556 r
.54232 .23946 .54621 .2894 .5529 .27309 .54874 .19883 Mtetra
.417 .24 .531 r
.54874 .19883 .5529 .27309 .55907 .21442 .55559 .21567 Mtetra
.95 .613 .341 r
.55559 .21567 .55907 .21442 .56564 .20358 .56306 .27453 Mtetra
.623 .349 .481 r
.56306 .27453 .56564 .20358 .57326 .25992 .57031 .29791 Mtetra
0 0 .135 r
.57031 .29791 .57326 .25992 .58091 .3033 .57645 .24787 Mtetra
.784 .523 .543 r
.57645 .24787 .58091 .3033 .5871 .2626 .58225 .19022 Mtetra
.452 .267 .538 r
.58225 .19022 .5871 .2626 .59255 .19632 .5893 .20198 Mtetra
.941 .604 .36 r
.5893 .20198 .59255 .19632 .59947 .20006 .59772 .26843 Mtetra
.671 .386 .481 r
.59772 .26843 .59947 .20006 .60815 .26774 .60569 .30465 Mtetra
0 0 .228 r
.60569 .30465 .60815 .26774 .61632 .30663 .6117 .26453 Mtetra
.846 .576 .53 r
.6117 .26453 .61632 .30663 .62213 .26397 .61669 .19582 Mtetra
.65 .415 .551 r
.61669 .19582 .62213 .26397 .62686 .1941 .62284 .17127 Mtetra
0 0 .182 r
.62284 .17127 .62686 .1941 .63313 .17511 .6313 .21533 Mtetra
.842 .522 .448 r
.6313 .21533 .63313 .17511 .64206 .22702 .64131 .29436 Mtetra
.729 .432 .476 r
.64131 .29436 .64206 .22702 .65246 .3083 .65081 .35073 Mtetra
.526 .25 .44 r
.65081 .35073 .65246 .3083 .66192 .35826 .65832 .35265 Mtetra
.973 .735 .517 r
.65832 .35265 .66192 .35826 .66901 .35004 .66398 .31199 Mtetra
.83 .565 .538 r
.66398 .31199 .66901 .35004 .6742 .30247 .66886 .25818 Mtetra
.788 .529 .545 r
.66886 .25818 .6742 .30247 .67883 .24747 .67388 .21169 Mtetra
.768 .522 .561 r
.67388 .21169 .67883 .24747 .68382 .20378 .67944 .17928 Mtetra
.754 .531 .593 r
.67944 .17928 .68382 .20378 .68946 .17524 .68555 .15965 Mtetra
.739 .558 .648 r
.68555 .15965 .68946 .17524 .69569 .15867 .6921 .14877 Mtetra
.722 .609 .73 r
.6921 .14877 .69569 .15867 .70231 .14956 .69891 .14277 Mtetra
.7 .671 .819 r
.69891 .14277 .70231 .14956 .70916 .14437 .70585 .13897 Mtetra
.681 .717 .876 r
.70585 .13897 .70916 .14437 .71612 .14091 .71286 .136 Mtetra
.67 .736 .899 r
.71286 .136 .71612 .14091 .72315 .13809 .71991 .13329 Mtetra
.666 .74 .906 r
.71991 .13329 .72315 .13809 .7302 .13545 .72697 .13066 Mtetra
.664 .741 .907 r
.72697 .13066 .7302 .13545 .73727 .13284 .73406 .12805 Mtetra
.73406 .12805 .73727 .13284 .74436 .13025 .74116 .12545 Mtetra
.664 .741 .908 r
.74116 .12545 .74436 .13025 .75147 .12765 .74828 .12284 Mtetra
.74828 .12284 .75147 .12765 .7586 .12505 .75542 .12023 Mtetra
.75542 .12023 .7586 .12505 .76574 .12244 .76258 .11761 Mtetra
.12711 .34485 .13124 .3487 .13692 .34662 .1328 .34277 Mtetra
.1328 .34277 .13692 .34662 .14261 .34453 .1385 .34067 Mtetra
.1385 .34067 .14261 .34453 .14832 .34244 .14421 .33858 Mtetra
.14421 .33858 .14832 .34244 .15404 .34035 .14994 .33647 Mtetra
.663 .741 .908 r
.14994 .33647 .15404 .34035 .15977 .33827 .15568 .33437 Mtetra
.662 .74 .908 r
.15568 .33437 .15977 .33827 .16551 .33621 .16143 .33228 Mtetra
.659 .738 .908 r
.16143 .33228 .16551 .33621 .17125 .33424 .16719 .33023 Mtetra
.649 .732 .91 r
.16719 .33023 .17125 .33424 .17698 .33253 .17294 .32833 Mtetra
.621 .714 .912 r
.17294 .32833 .17698 .33253 .18263 .33164 .17867 .32681 Mtetra
.539 .65 .907 r
.17867 .32681 .18263 .33164 .18807 .33295 .1843 .32632 Mtetra
.308 .449 .84 r
.1843 .32632 .18807 .33295 .19302 .3391 .18967 .32846 Mtetra
0 .048 .596 r
.18967 .32846 .19302 .3391 .19712 .35392 .19447 .33621 Mtetra
0 0 .312 r
.19447 .33621 .19712 .35392 .20002 .38128 .19834 .35361 Mtetra
0 0 .164 r
.19834 .35361 .20002 .38128 .20169 .42215 .20098 .38396 Mtetra
0 0 .126 r
.20098 .38396 .20169 .42215 .2029 .46948 .20255 .42642 Mtetra
0 0 .164 r
.20255 .42642 .2029 .46948 .20562 .50312 .20402 .47166 Mtetra
0 0 .324 r
.20402 .47166 .20562 .50312 .21241 .49499 .20737 .49914 Mtetra
.97 .933 .664 r
.20737 .49914 .21241 .49499 .22402 .43463 .21483 .48418 Mtetra
0 0 0 r
.21483 .48418 .22402 .43463 .2373 .35366 .22666 .42126 Mtetra
.22666 .42126 .2373 .35366 .24715 .30821 .23966 .34316 Mtetra
.23966 .34316 .24715 .30821 .25101 .32999 .24915 .30171 Mtetra
0 0 .403 r
.24915 .30171 .25101 .32999 .25149 .39279 .25302 .32381 Mtetra
0 0 .275 r
.25302 .32381 .25149 .39279 .25479 .42481 .25375 .3843 Mtetra
0 0 .332 r
.25375 .3843 .25479 .42481 .26426 .38255 .25687 .41883 Mtetra
0 0 .087 r
.25687 .41883 .26426 .38255 .27571 .3138 .26571 .38444 Mtetra
0 0 .13 r
.26571 .38444 .27571 .3138 .28261 .3005 .27711 .31624 Mtetra
.829 .817 .333 r
.27711 .31624 .28261 .3005 .28444 .3539 .28507 .28969 Mtetra
.073 0 .424 r
.28507 .28969 .28444 .3539 .2873 .39647 .28801 .32891 Mtetra
0 0 .366 r
.28801 .32891 .2873 .39647 .29556 .36632 .29031 .37915 Mtetra
.312 0 .221 r
.29031 .37915 .29556 .36632 .30597 .30422 .29669 .37526 Mtetra
0 0 .258 r
.29669 .37526 .30597 .30422 .31322 .28545 .30659 .32076 Mtetra
0 0 0 r
.30659 .32076 .31322 .28545 .31676 .32193 .31552 .27785 Mtetra
.423 .258 .55 r
.31552 .27785 .31676 .32193 .32118 .34726 .32093 .28649 Mtetra
.276 .132 .497 r
.32093 .28649 .32118 .34726 .32901 .3198 .32538 .31096 Mtetra
.724 .616 .737 r
.32538 .31096 .32901 .3198 .33709 .28669 .33181 .30543 Mtetra
0 0 .012 r
.33181 .30543 .33709 .28669 .34328 .28438 .33904 .2864 Mtetra
.392 0 0 r
.33904 .2864 .34328 .28438 .34907 .28922 .34506 .28746 Mtetra
.709 .173 0 r
.34506 .28746 .34907 .28922 .35591 .27559 .35082 .2938 Mtetra
0 0 .042 r
.35082 .2938 .35591 .27559 .3621 .27376 .35791 .27612 Mtetra
0 0 0 r
.35791 .27612 .3621 .27376 .36792 .27938 .36417 .2736 Mtetra
.315 .498 .879 r
.36417 .2736 .36792 .27938 .37464 .26778 .37023 .27549 Mtetra
.7 .831 .39 r
.37023 .27549 .37464 .26778 .38045 .27484 .37703 .26243 Mtetra
.288 .295 .694 r
.37703 .26243 .38045 .27484 .38688 .26939 .38298 .26747 Mtetra
.901 .867 .795 r
.38298 .26747 .38688 .26939 .39316 .26757 .38956 .25896 Mtetra
.512 .51 .791 r
.38956 .25896 .39316 .26757 .39932 .26886 .39576 .25926 Mtetra
.662 .573 .744 r
.39576 .25926 .39932 .26886 .4058 .26283 .40214 .25577 Mtetra
.65 .625 .811 r
.40214 .25577 .4058 .26283 .41199 .26472 .40849 .25331 Mtetra
.601 .511 .724 r
.40849 .25331 .41199 .26472 .41845 .25956 .41483 .25139 Mtetra
.647 .594 .781 r
.41483 .25139 .41845 .25956 .42477 .25907 .42122 .24876 Mtetra
.623 .54 .74 r
.42122 .24876 .42477 .25907 .43117 .25637 .42761 .24635 Mtetra
.606 .535 .749 r
.42761 .24635 .43117 .25637 .43761 .25293 .434 .24449 Mtetra
.658 .595 .773 r
.434 .24449 .43761 .25293 .44397 .25283 .44044 .24147 Mtetra
.597 .51 .726 r
.44044 .24147 .44397 .25283 .4505 .2467 .44686 .23967 Mtetra
.616 .612 .824 r
.44686 .23967 .4505 .2467 .45687 .24797 .4533 .23794 Mtetra
.68 .577 .733 r
.4533 .23794 .45687 .24797 .46341 .24178 .45981 .23363 Mtetra
.297 .397 .796 r
.45981 .23363 .46341 .24178 .46989 .2395 .46618 .23688 Mtetra
.905 .847 .776 r
.46618 .23688 .46989 .2395 .47634 .23964 .4728 .2276 Mtetra
.068 .157 .649 r
.4728 .2276 .47634 .23964 .48298 .22841 .47915 .23607 Mtetra
0 0 0 r
.47915 .23607 .48298 .22841 .48938 .23538 .48575 .22906 Mtetra
.601 .631 .853 r
.48575 .22906 .48938 .23538 .49601 .22463 .4923 .22763 Mtetra
.827 .405 .237 r
.4923 .22763 .49601 .22463 .50255 .22255 .49873 .24064 Mtetra
.111 0 .225 r
.49873 .24064 .50255 .22255 .50905 .23148 .50541 .22877 Mtetra
.801 .869 .898 r
.50541 .22877 .50905 .23148 .51567 .22124 .51204 .22388 Mtetra
.849 .431 .239 r
.51204 .22388 .51567 .22124 .52227 .22006 .51863 .23883 Mtetra
.481 .166 .355 r
.51863 .23883 .52227 .22006 .52893 .24968 .52531 .23835 Mtetra
.9 .672 .585 r
.52531 .23835 .52893 .24968 .53572 .27131 .53194 .20846 Mtetra
.597 .379 .555 r
.53194 .20846 .53572 .27131 .54232 .23946 .53855 .19665 Mtetra
0 0 .411 r
.53855 .19665 .54232 .23946 .54874 .19883 .54549 .23719 Mtetra
.786 .476 .464 r
.54549 .23719 .54874 .19883 .55559 .21567 .55272 .28717 Mtetra
.494 .243 .463 r
.55272 .28717 .55559 .21567 .56306 .27453 .55961 .28376 Mtetra
.992 .78 .401 r
.55961 .28376 .56306 .27453 .57031 .29791 .56579 .22691 Mtetra
.709 .461 .547 r
.56579 .22691 .57031 .29791 .57645 .24787 .57196 .18413 Mtetra
.323 .177 .522 r
.57196 .18413 .57645 .24787 .58225 .19022 .57918 .20897 Mtetra
.891 .561 .416 r
.57918 .20897 .58225 .19022 .5893 .20198 .58736 .27434 Mtetra
.638 .36 .48 r
.58736 .27434 .5893 .20198 .59772 .26843 .59502 .30249 Mtetra
0 0 .163 r
.59502 .30249 .59772 .26843 .60569 .30465 .6011 .26009 Mtetra
.834 .565 .533 r
.6011 .26009 .60569 .30465 .6117 .26453 .60637 .1938 Mtetra
.648 .413 .549 r
.60637 .1938 .6117 .26453 .61669 .19582 .61258 .16875 Mtetra
0 0 .306 r
.61258 .16875 .61669 .19582 .62284 .17127 .62074 .20859 Mtetra
.846 .525 .445 r
.62074 .20859 .62284 .17127 .6313 .21533 .63035 .28472 Mtetra
.731 .434 .477 r
.63035 .28472 .6313 .21533 .64131 .29436 .63973 .34383 Mtetra
.574 .294 .454 r
.63973 .34383 .64131 .29436 .65081 .35073 .64748 .35282 Mtetra
.999 .809 .473 r
.64748 .35282 .65081 .35073 .65832 .35265 .65353 .31841 Mtetra
.84 .576 .54 r
.65353 .31841 .65832 .35265 .66398 .31199 .65869 .26665 Mtetra
.79 .53 .544 r
.65869 .26665 .66398 .31199 .66886 .25818 .6638 .21847 Mtetra
.766 .516 .556 r
.6638 .21847 .66886 .25818 .67388 .21169 .66933 .18297 Mtetra
.748 .517 .581 r
.66933 .18297 .67388 .21169 .67944 .17928 .67538 .16069 Mtetra
.733 .537 .628 r
.67538 .16069 .67944 .17928 .68555 .15965 .68187 .14818 Mtetra
.72 .585 .703 r
.68187 .14818 .68555 .15965 .6921 .14877 .68864 .14132 Mtetra
.706 .654 .796 r
.68864 .14132 .6921 .14877 .69891 .14277 .69556 .13711 Mtetra
.688 .709 .864 r
.69556 .13711 .69891 .14277 .70585 .13897 .70256 .13393 Mtetra
.674 .732 .893 r
.70256 .13393 .70585 .13897 .71286 .136 .70959 .13113 Mtetra
.667 .738 .903 r
.70959 .13113 .71286 .136 .71991 .13329 .71665 .12847 Mtetra
.665 .74 .906 r
.71665 .12847 .71991 .13329 .72697 .13066 .72373 .12585 Mtetra
.664 .74 .907 r
.72373 .12585 .72697 .13066 .73406 .12805 .73083 .12324 Mtetra
.663 .741 .908 r
.73083 .12324 .73406 .12805 .74116 .12545 .73794 .12063 Mtetra
.664 .741 .908 r
.73794 .12063 .74116 .12545 .74828 .12284 .74507 .11801 Mtetra
.74507 .11801 .74828 .12284 .75542 .12023 .75223 .11539 Mtetra
.75223 .11539 .75542 .12023 .76258 .11761 .7594 .11275 Mtetra
.12297 .341 .12711 .34485 .1328 .34277 .12866 .3389 Mtetra
.12866 .3389 .1328 .34277 .1385 .34067 .13437 .3368 Mtetra
.13437 .3368 .1385 .34067 .14421 .33858 .14009 .33469 Mtetra
.14009 .33469 .14421 .33858 .14994 .33647 .14583 .33258 Mtetra
.14583 .33258 .14994 .33647 .15568 .33437 .15157 .33046 Mtetra
.663 .741 .908 r
.15157 .33046 .15568 .33437 .16143 .33228 .15733 .32835 Mtetra
.662 .74 .908 r
.15733 .32835 .16143 .33228 .16719 .33023 .1631 .32624 Mtetra
.657 .736 .908 r
.1631 .32624 .16719 .33023 .17294 .32833 .16888 .32421 Mtetra
.642 .725 .909 r
.16888 .32421 .17294 .32833 .17867 .32681 .17464 .32239 Mtetra
.604 .698 .91 r
.17464 .32239 .17867 .32681 .1843 .32632 .18036 .32109 Mtetra
.501 .615 .897 r
.18036 .32109 .1843 .32632 .18967 .32846 .18596 .32106 Mtetra
.245 .382 .803 r
.18596 .32106 .18967 .32846 .19447 .33621 .19127 .32402 Mtetra
0 0 .551 r
.19127 .32402 .19447 .33621 .19834 .35361 .19596 .33313 Mtetra
0 0 .313 r
.19596 .33313 .19834 .35361 .20098 .38396 .19965 .35251 Mtetra
0 0 .198 r
.19965 .35251 .20098 .38396 .20255 .42642 .20213 .38488 Mtetra
0 0 .172 r
.20213 .38488 .20255 .42642 .20402 .47166 .20369 .42793 Mtetra
0 0 .211 r
.20369 .42793 .20402 .47166 .20737 .49914 .20544 .47092 Mtetra
0 0 .375 r
.20544 .47092 .20737 .49914 .21483 .48418 .20926 .49392 Mtetra
.889 .904 .493 r
.20926 .49392 .21483 .48418 .22666 .42126 .21706 .47546 Mtetra
0 0 0 r
.21706 .47546 .22666 .42126 .23966 .34316 .22887 .41271 Mtetra
0 0 .023 r
.22887 .41271 .23966 .34316 .24915 .30171 .24164 .33699 Mtetra
0 0 0 r
.24164 .33699 .24915 .30171 .25302 .32381 .25111 .29577 Mtetra
.023 0 .472 r
.25111 .29577 .25302 .32381 .25375 .3843 .25536 .31379 Mtetra
0 0 .313 r
.25536 .31379 .25375 .3843 .25687 .41883 .25643 .3708 Mtetra
0 0 .321 r
.25643 .3708 .25687 .41883 .26571 .38444 .25907 .41146 Mtetra
0 0 .143 r
.25907 .41146 .26571 .38444 .27711 .31624 .26686 .39016 Mtetra
0 0 .181 r
.26686 .39016 .27711 .31624 .28507 .28969 .27804 .32495 Mtetra
0 0 0 r
.27804 .32495 .28507 .28969 .28801 .32891 .28723 .28289 Mtetra
.281 .146 .513 r
.28723 .28289 .28801 .32891 .29031 .37915 .2918 .30078 Mtetra
.052 0 .408 r
.2918 .30078 .29031 .37915 .29669 .37526 .29417 .35018 Mtetra
0 0 .376 r
.29417 .35018 .29669 .37526 .30659 .32076 .29865 .37285 Mtetra
.04 0 .289 r
.29865 .37285 .30659 .32076 .31552 .27785 .30715 .33869 Mtetra
0 0 .197 r
.30715 .33869 .31552 .27785 .32093 .28649 .31681 .28554 Mtetra
.956 .817 .666 r
.31681 .28554 .32093 .28649 .32538 .31096 .32395 .26841 Mtetra
.374 .221 .543 r
.32395 .26841 .32538 .31096 .33181 .30543 .32923 .27999 Mtetra
.486 .339 .606 r
.32923 .27999 .33181 .30543 .33904 .2864 .33515 .28229 Mtetra
.868 .772 .754 r
.33515 .28229 .33904 .2864 .34506 .28746 .34179 .27295 Mtetra
.208 .212 .644 r
.34179 .27295 .34506 .28746 .35082 .2938 .34747 .2801 Mtetra
.231 .239 .662 r
.34747 .2801 .35082 .2938 .35791 .27612 .35325 .28652 Mtetra
0 0 0 r
.35325 .28652 .35791 .27612 .36417 .2736 .36023 .27117 Mtetra
.683 .149 0 r
.36023 .27117 .36417 .2736 .37023 .27549 .36606 .27769 Mtetra
.45 .854 .675 r
.36606 .27769 .37023 .27549 .37703 .26243 .37245 .27364 Mtetra
0 0 .032 r
.37245 .27364 .37703 .26243 .38298 .26747 .37908 .2649 Mtetra
.474 0 0 r
.37908 .2649 .38298 .26747 .38956 .25896 .38509 .26949 Mtetra
0 0 0 r
.38509 .26949 .38956 .25896 .39576 .25926 .3918 .25872 Mtetra
.429 0 0 r
.3918 .25872 .39576 .25926 .40214 .25577 .39794 .2615 Mtetra
0 0 0 r
.39794 .2615 .40214 .25577 .40849 .25331 .4045 .25459 Mtetra
.134 0 0 r
.4045 .25459 .40849 .25331 .41483 .25139 .4108 .25436 Mtetra
0 0 0 r
.4108 .25436 .41483 .25139 .42122 .24876 .41725 .25048 Mtetra
.41725 .25048 .42122 .24876 .42761 .24635 .42365 .2486 Mtetra
.42365 .2486 .42761 .24635 .434 .24449 .43006 .24688 Mtetra
.43006 .24688 .434 .24449 .44044 .24147 .43653 .24336 Mtetra
.4 0 0 r
.43653 .24336 .44044 .24147 .44686 .23967 .44289 .24469 Mtetra
0 0 0 r
.44289 .24469 .44686 .23967 .4533 .23794 .44948 .23804 Mtetra
.675 .132 0 r
.44948 .23804 .4533 .23794 .45981 .23363 .45579 .24358 Mtetra
0 0 0 r
.45579 .24358 .45981 .23363 .46618 .23688 .46244 .23448 Mtetra
.423 0 0 r
.46244 .23448 .46618 .23688 .4728 .2276 .46884 .23889 Mtetra
.418 .058 .245 r
.46884 .23889 .4728 .2276 .47915 .23607 .47537 .2376 Mtetra
.936 .968 .709 r
.47537 .2376 .47915 .23607 .48575 .22906 .48206 .22691 Mtetra
.814 .333 0 r
.48206 .22691 .48575 .22906 .4923 .22763 .48847 .23772 Mtetra
0 0 0 r
.48847 .23772 .4923 .22763 .49873 .24064 .49517 .2258 Mtetra
.75 .569 .65 r
.49517 .2258 .49873 .24064 .50541 .22877 .50185 .21442 Mtetra
.344 .313 .68 r
.50185 .21442 .50541 .22877 .51204 .22388 .50841 .21944 Mtetra
.852 .785 .786 r
.50841 .21944 .51204 .22388 .51863 .23883 .51506 .21153 Mtetra
.711 .497 .597 r
.51506 .21153 .51863 .23883 .52531 .23835 .52171 .19546 Mtetra
.355 .214 .548 r
.52171 .19546 .52531 .23835 .53194 .20846 .52836 .20966 Mtetra
.945 .603 .339 r
.52836 .20966 .53194 .20846 .53855 .19665 .53521 .25946 Mtetra
.654 .371 .479 r
.53521 .25946 .53855 .19665 .54549 .23719 .54219 .28795 Mtetra
.181 0 .366 r
.54219 .28795 .54549 .23719 .55272 .28717 .54888 .2581 Mtetra
.862 .601 .543 r
.54888 .2581 .55272 .28717 .55961 .28376 .5552 .20318 Mtetra
.619 .388 .546 r
.5552 .20318 .55961 .28376 .56579 .22691 .56173 .18236 Mtetra
0 0 .432 r
.56173 .18236 .56579 .22691 .57196 .18413 .56907 .22236 Mtetra
.815 .5 .457 r
.56907 .22236 .57196 .18413 .57918 .20897 .57698 .28399 Mtetra
.583 .315 .476 r
.57698 .28399 .57918 .20897 .58736 .27434 .58431 .29875 Mtetra
0 0 0 r
.58431 .29875 .58736 .27434 .59502 .30249 .59039 .25052 Mtetra
.805 .54 .538 r
.59039 .25052 .59502 .30249 .6011 .26009 .59595 .18802 Mtetra
.629 .398 .548 r
.59595 .18802 .6011 .26009 .60637 .1938 .60232 .16702 Mtetra
0 0 .299 r
.60232 .16702 .60637 .1938 .61258 .16875 .61032 .20641 Mtetra
.84 .52 .447 r
.61032 .20641 .61258 .16875 .62074 .20859 .61958 .28001 Mtetra
.727 .431 .478 r
.61958 .28001 .62074 .20859 .63035 .28472 .62873 .33898 Mtetra
.591 .31 .46 r
.62873 .33898 .63035 .28472 .63973 .34383 .63656 .35163 Mtetra
.923 .82 .359 r
.63656 .35163 .63973 .34383 .64748 .35282 .64288 .32182 Mtetra
.847 .585 .542 r
.64288 .32182 .64748 .35282 .65353 .31841 .64831 .27233 Mtetra
.789 .529 .544 r
.64831 .27233 .65353 .31841 .65869 .26665 .65357 .2235 Mtetra
.762 .51 .553 r
.65357 .2235 .65869 .26665 .6638 .21847 .65912 .1859 Mtetra
.742 .507 .574 r
.65912 .1859 .6638 .21847 .66933 .18297 .66515 .16158 Mtetra
.727 .522 .613 r
.66515 .16158 .66933 .18297 .67538 .16069 .67161 .14766 Mtetra
.718 .567 .682 r
.67161 .14766 .67538 .16069 .68187 .14818 .67835 .13997 Mtetra
.71 .637 .774 r
.67835 .13997 .68187 .14818 .68864 .14132 .68525 .13529 Mtetra
.694 .697 .848 r
.68525 .13529 .68864 .14132 .69556 .13711 .69223 .13187 Mtetra
.678 .724 .885 r
.69223 .13187 .69556 .13711 .70256 .13393 .69925 .12897 Mtetra
.668 .734 .899 r
.69925 .12897 .70256 .13393 .70959 .13113 .7063 .12627 Mtetra
.665 .738 .905 r
.7063 .12627 .70959 .13113 .71665 .12847 .71338 .12365 Mtetra
.664 .74 .907 r
.71338 .12365 .71665 .12847 .72373 .12585 .72047 .12103 Mtetra
.664 .741 .908 r
.72047 .12103 .72373 .12585 .73083 .12324 .72758 .11842 Mtetra
.72758 .11842 .73083 .12324 .73794 .12063 .73471 .11579 Mtetra
.73471 .11579 .73794 .12063 .74507 .11801 .74186 .11316 Mtetra
.74186 .11316 .74507 .11801 .75223 .11539 .74902 .11052 Mtetra
.74902 .11052 .75223 .11539 .7594 .11275 .7562 .10788 Mtetra
.1188 .33712 .12297 .341 .12866 .3389 .12451 .33502 Mtetra
.12451 .33502 .12866 .3389 .13437 .3368 .13022 .3329 Mtetra
.13022 .3329 .13437 .3368 .14009 .33469 .13595 .33079 Mtetra
.663 .741 .908 r
.13595 .33079 .14009 .33469 .14583 .33258 .14169 .32867 Mtetra
.14169 .32867 .14583 .33258 .15157 .33046 .14745 .32655 Mtetra
.14745 .32655 .15157 .33046 .15733 .32835 .15321 .32442 Mtetra
.15321 .32442 .15733 .32835 .1631 .32624 .15899 .32229 Mtetra
.662 .74 .908 r
.15899 .32229 .1631 .32624 .16888 .32421 .16479 .32018 Mtetra
.655 .734 .908 r
.16479 .32018 .16888 .32421 .17464 .32239 .17058 .31816 Mtetra
.635 .718 .907 r
.17058 .31816 .17464 .32239 .18036 .32109 .17635 .31642 Mtetra
.586 .679 .905 r
.17635 .31642 .18036 .32109 .18596 .32106 .18207 .31534 Mtetra
.465 .576 .882 r
.18207 .31534 .18596 .32106 .19127 .32402 .18764 .31576 Mtetra
.203 .327 .768 r
.18764 .31576 .19127 .32402 .19596 .33313 .19289 .31945 Mtetra
0 0 .527 r
.19289 .31945 .19596 .33313 .19965 .35251 .1975 .3296 Mtetra
0 0 .327 r
.1975 .3296 .19965 .35251 .20213 .38488 .2011 .35026 Mtetra
0 0 .235 r
.2011 .35026 .20213 .38488 .20369 .42793 .20351 .38364 Mtetra
0 0 .215 r
.20351 .38364 .20369 .42793 .20544 .47092 .20515 .42646 Mtetra
0 0 .251 r
.20515 .42646 .20544 .47092 .20926 .49392 .20713 .46748 Mtetra
0 0 .405 r
.20713 .46748 .20926 .49392 .21706 .47546 .21121 .48814 Mtetra
.748 .822 .356 r
.21121 .48814 .21706 .47546 .22887 .41271 .21905 .4695 Mtetra
0 0 .023 r
.21905 .4695 .22887 .41271 .24164 .33699 .23063 .40916 Mtetra
0 0 .066 r
.23063 .40916 .24164 .33699 .25111 .29577 .24323 .33518 Mtetra
0 0 0 r
.24323 .33518 .25111 .29577 .25536 .31379 .25299 .2909 Mtetra
.241 .167 .569 r
.25299 .2909 .25536 .31379 .25643 .3708 .25797 .30075 Mtetra
0 0 .354 r
.25797 .30075 .25643 .3708 .25907 .41146 .25955 .35201 Mtetra
0 0 .327 r
.25955 .35201 .25907 .41146 .26686 .39016 .26161 .40005 Mtetra
.252 0 .124 r
.26161 .40005 .26686 .39016 .27804 .32495 .268 .39645 Mtetra
0 0 .232 r
.268 .39645 .27804 .32495 .28723 .28289 .27849 .34018 Mtetra
0 0 .127 r
.27849 .34018 .28723 .28289 .2918 .30078 .28869 .28535 Mtetra
.706 .536 .657 r
.28869 .28535 .2918 .30078 .29417 .35018 .29525 .277 Mtetra
.191 .058 .459 r
.29525 .277 .29417 .35018 .29865 .37285 .29863 .31274 Mtetra
.053 0 .423 r
.29863 .31274 .29865 .37285 .30715 .33869 .30201 .35072 Mtetra
0 0 .044 r
.30201 .35072 .30715 .33869 .31681 .28554 .30873 .34216 Mtetra
0 0 .241 r
.30873 .34216 .31681 .28554 .32395 .26841 .3178 .2982 Mtetra
0 0 .118 r
.3178 .2982 .32395 .26841 .32923 .27999 .32563 .271 Mtetra
.514 .501 .78 r
.32563 .271 .32923 .27999 .33515 .28229 .33167 .27126 Mtetra
.534 .474 .735 r
.33167 .27126 .33515 .28229 .34179 .27295 .33776 .27119 Mtetra
.926 .844 .744 r
.33776 .27119 .34179 .27295 .34747 .2801 .3445 .26019 Mtetra
.405 .304 .627 r
.3445 .26019 .34747 .2801 .35325 .28652 .35035 .26482 Mtetra
.492 .358 .626 r
.35035 .26482 .35325 .28652 .36023 .27117 .35639 .26655 Mtetra
.85 .76 .763 r
.35639 .26655 .36023 .27117 .36606 .27769 .363 .25803 Mtetra
.241 .191 .599 r
.363 .25803 .36606 .27769 .37245 .27364 .36871 .26704 Mtetra
.812 .699 .74 r
.36871 .26704 .37245 .27364 .37908 .2649 .37533 .25865 Mtetra
.337 .492 .866 r
.37533 .25865 .37908 .2649 .38509 .26949 .38147 .26052 Mtetra
.601 .553 .773 r
.38147 .26052 .38509 .26949 .3918 .25872 .38778 .25892 Mtetra
.69 .977 .906 r
.38778 .25892 .3918 .25872 .39794 .2615 .39423 .25486 Mtetra
.469 .55 .856 r
.39423 .25486 .39794 .2615 .4045 .25459 .40049 .25545 Mtetra
.677 .978 .851 r
.40049 .25545 .4045 .25459 .4108 .25436 .40697 .25091 Mtetra
.532 .745 .973 r
.40697 .25091 .4108 .25436 .41725 .25048 .41333 .25001 Mtetra
.56 .921 .949 r
.41333 .25001 .41725 .25048 .42365 .2486 .41977 .24743 Mtetra
.701 .936 .963 r
.41977 .24743 .42365 .2486 .43006 .24688 .42624 .24403 Mtetra
.445 .747 .992 r
.42624 .24403 .43006 .24688 .43653 .24336 .43264 .24359 Mtetra
.779 .993 .879 r
.43264 .24359 .43653 .24336 .44289 .24469 .4392 .23835 Mtetra
.538 .6 .863 r
.4392 .23835 .44289 .24469 .44948 .23804 .44563 .23793 Mtetra
.65 .963 .921 r
.44563 .23793 .44948 .23804 .45579 .24358 .45217 .23431 Mtetra
.727 .615 .733 r
.45217 .23431 .45579 .24358 .46244 .23448 .45877 .22841 Mtetra
.202 .421 .851 r
.45877 .22841 .46244 .23448 .46884 .23889 .46519 .23147 Mtetra
.862 .702 .681 r
.46519 .23147 .46884 .23889 .47537 .2376 .47193 .21798 Mtetra
.427 .326 .637 r
.47193 .21798 .47537 .2376 .48206 .22691 .47838 .22205 Mtetra
.825 .764 .795 r
.47838 .22205 .48206 .22691 .48847 .23772 .48502 .21506 Mtetra
.667 .478 .62 r
.48502 .21506 .48847 .23772 .49517 .2258 .49167 .20613 Mtetra
.351 .274 .628 r
.49167 .20613 .49517 .2258 .50185 .21442 .49817 .21272 Mtetra
.822 .927 .903 r
.49817 .21272 .50185 .21442 .50841 .21944 .50481 .20742 Mtetra
.66 .541 .708 r
.50481 .20742 .50841 .21944 .51506 .21153 .51145 .20311 Mtetra
.86 .502 0 r
.51145 .20311 .51506 .21153 .52171 .19546 .51803 .22709 Mtetra
.778 .464 .455 r
.51803 .22709 .52171 .19546 .52836 .20966 .52474 .26649 Mtetra
.525 .261 .456 r
.52474 .26649 .52836 .20966 .53521 .25946 .53158 .26877 Mtetra
.985 .804 .406 r
.53158 .26877 .53521 .25946 .54219 .28795 .53825 .22446 Mtetra
.715 .468 .55 r
.53825 .22446 .54219 .28795 .54888 .2581 .54477 .18438 Mtetra
.488 .291 .539 r
.54477 .18438 .54888 .2581 .5552 .20318 .55155 .19009 Mtetra
.931 .615 .155 r
.55155 .19009 .5552 .20318 .56173 .18236 .5589 .24222 Mtetra
.733 .436 .477 r
.5589 .24222 .56173 .18236 .56907 .22236 .56651 .294 Mtetra
.493 .241 .46 r
.56651 .294 .56907 .22236 .57698 .28399 .57352 .29079 Mtetra
.995 .777 .417 r
.57352 .29079 .57698 .28399 .58431 .29875 .57961 .23564 Mtetra
.763 .503 .541 r
.57961 .23564 .58431 .29875 .59039 .25052 .58546 .17934 Mtetra
.592 .37 .548 r
.58546 .17934 .59039 .25052 .59595 .18802 .59206 .16656 Mtetra
0 0 .15 r
.59206 .16656 .59595 .18802 .60232 .16702 .59999 .20881 Mtetra
.824 .508 .453 r
.59999 .20881 .60232 .16702 .61032 .20641 .60894 .28042 Mtetra
.717 .423 .479 r
.60894 .28042 .61032 .20641 .61958 .28001 .61781 .3369 Mtetra
.589 .31 .461 r
.61781 .3369 .61958 .28001 .62873 .33898 .62559 .34979 Mtetra
.79 .761 .248 r
.62559 .34979 .62873 .33898 .63656 .35163 .63208 .32245 Mtetra
.85 .59 .545 r
.63208 .32245 .63656 .35163 .64288 .32182 .63775 .27499 Mtetra
.786 .526 .544 r
.63775 .27499 .64288 .32182 .64831 .27233 .64318 .22637 Mtetra
.756 .504 .551 r
.64318 .22637 .64831 .27233 .65357 .2235 .64882 .1877 Mtetra
.735 .498 .569 r
.64882 .1877 .65357 .2235 .65912 .1859 .65487 .16204 Mtetra
.721 .51 .604 r
.65487 .16204 .65912 .1859 .66515 .16158 .66131 .14705 Mtetra
.715 .552 .666 r
.66131 .14705 .66515 .16158 .67161 .14766 .66804 .13862 Mtetra
.712 .62 .753 r
.66804 .13862 .67161 .14766 .67835 .13997 .67492 .13347 Mtetra
.698 .682 .831 r
.67492 .13347 .67835 .13997 .68525 .13529 .68188 .12981 Mtetra
.681 .715 .875 r
.68188 .12981 .68525 .13529 .69223 .13187 .68889 .12681 Mtetra
.669 .73 .895 r
.68889 .12681 .69223 .13187 .69925 .12897 .69594 .12408 Mtetra
.665 .737 .904 r
.69594 .12408 .69925 .12897 .7063 .12627 .70301 .12144 Mtetra
.664 .74 .907 r
.70301 .12144 .7063 .12627 .71338 .12365 .71009 .11882 Mtetra
.664 .741 .908 r
.71009 .11882 .71338 .12365 .72047 .12103 .7172 .1162 Mtetra
.7172 .1162 .72047 .12103 .72758 .11842 .72432 .11357 Mtetra
.72432 .11357 .72758 .11842 .73471 .11579 .73146 .11093 Mtetra
.73146 .11093 .73471 .11579 .74186 .11316 .73862 .10829 Mtetra
.73862 .10829 .74186 .11316 .74902 .11052 .7458 .10564 Mtetra
.7458 .10564 .74902 .11052 .7562 .10788 .75299 .10298 Mtetra
.11463 .33323 .1188 .33712 .12451 .33502 .12034 .33112 Mtetra
.12034 .33112 .12451 .33502 .13022 .3329 .12606 .329 Mtetra
.12606 .329 .13022 .3329 .13595 .33079 .13179 .32687 Mtetra
.13179 .32687 .13595 .33079 .14169 .32867 .13754 .32474 Mtetra
.663 .741 .908 r
.13754 .32474 .14169 .32867 .14745 .32655 .1433 .32261 Mtetra
.1433 .32261 .14745 .32655 .15321 .32442 .14908 .32048 Mtetra
.14908 .32048 .15321 .32442 .15899 .32229 .15487 .31834 Mtetra
.15487 .31834 .15899 .32229 .16479 .32018 .16067 .3162 Mtetra
.661 .74 .908 r
.16067 .3162 .16479 .32018 .17058 .31816 .16648 .31408 Mtetra
.654 .733 .908 r
.16648 .31408 .17058 .31816 .17635 .31642 .17229 .31207 Mtetra
.63 .712 .906 r
.17229 .31207 .17635 .31642 .18207 .31534 .17807 .31039 Mtetra
.57 .661 .899 r
.17807 .31039 .18207 .31534 .18764 .31576 .18379 .30952 Mtetra
.438 .54 .864 r
.18379 .30952 .18764 .31576 .19289 .31945 .18934 .31033 Mtetra
.186 .29 .739 r
.18934 .31033 .19289 .31945 .1975 .3296 .19455 .31456 Mtetra
0 0 .521 r
.19455 .31456 .1975 .3296 .2011 .35026 .19913 .32535 Mtetra
0 0 .35 r
.19913 .32535 .2011 .35026 .20351 .38364 .2027 .34656 Mtetra
0 0 .271 r
.2027 .34656 .20351 .38364 .20515 .42646 .20515 .38001 Mtetra
0 0 .256 r
.20515 .38001 .20515 .42646 .20713 .46748 .20691 .42194 Mtetra
0 0 .285 r
.20691 .42194 .20713 .46748 .21121 .48814 .20908 .46149 Mtetra
0 0 .409 r
.20908 .46149 .21121 .48814 .21905 .4695 .21321 .48205 Mtetra
0 0 0 r
.21321 .48205 .21905 .4695 .23063 .40916 .22079 .46631 Mtetra
0 0 .078 r
.22079 .46631 .23063 .40916 .24323 .33518 .23197 .41046 Mtetra
0 0 .109 r
.23197 .41046 .24323 .33518 .25299 .2909 .24442 .33815 Mtetra
0 0 .031 r
.24442 .33815 .25299 .2909 .25797 .30075 .25466 .28854 Mtetra
.599 .496 .708 r
.25466 .28854 .25797 .30075 .25955 .35201 .26068 .28658 Mtetra
.025 0 .401 r
.26068 .28658 .25955 .35201 .26161 .40005 .26308 .32835 Mtetra
0 0 .351 r
.26308 .32835 .26161 .40005 .268 .39645 .26475 .38139 Mtetra
0 0 .338 r
.26475 .38139 .268 .39645 .27849 .34018 .26956 .39764 Mtetra
.005 0 .274 r
.26956 .39764 .27849 .34018 .28869 .28535 .2787 .359 Mtetra
0 0 .233 r
.2787 .359 .28869 .28535 .29525 .277 .2892 .30071 Mtetra
.7 .711 .184 r
.2892 .30071 .29525 .277 .29863 .31274 .29768 .26713 Mtetra
.4 .237 .541 r
.29768 .26713 .29863 .31274 .30201 .35072 .30292 .27734 Mtetra
.213 .075 .467 r
.30292 .27734 .30201 .35072 .30873 .34216 .30656 .31135 Mtetra
.338 .215 .562 r
.30656 .31135 .30873 .34216 .3178 .2982 .312 .32117 Mtetra
0 0 .039 r
.312 .32117 .3178 .2982 .32563 .271 .31963 .29849 Mtetra
0 0 .2 r
.31963 .29849 .32563 .271 .33167 .27126 .32702 .27865 Mtetra
.502 .091 .193 r
.32702 .27865 .33167 .27126 .33776 .27119 .33305 .27993 Mtetra
.295 0 .123 r
.33305 .27993 .33776 .27119 .3445 .26019 .33934 .27733 Mtetra
0 0 0 r
.33934 .27733 .3445 .26019 .35035 .26482 .34653 .25935 Mtetra
.332 .526 .895 r
.34653 .25935 .35035 .26482 .35639 .26655 .35258 .2609 Mtetra
.719 .699 .83 r
.35258 .2609 .35639 .26655 .363 .25803 .35895 .25712 Mtetra
.905 .915 .816 r
.35895 .25712 .363 .25803 .36871 .26704 .36555 .24913 Mtetra
.41 .321 .645 r
.36555 .24913 .36871 .26704 .37533 .25865 .37154 .25314 Mtetra
.834 .733 .753 r
.37154 .25314 .37533 .25865 .38147 .26052 .37817 .24461 Mtetra
.438 .357 .667 r
.37817 .24461 .38147 .26052 .38778 .25892 .38427 .24747 Mtetra
.692 .564 .706 r
.38427 .24747 .38778 .25892 .39423 .25486 .39077 .24203 Mtetra
.532 .45 .709 r
.39077 .24203 .39423 .25486 .40049 .25545 .39704 .24202 Mtetra
.627 .504 .693 r
.39704 .24202 .40049 .25545 .40697 .25091 .40347 .23871 Mtetra
.588 .493 .714 r
.40347 .23871 .40697 .25091 .41333 .25001 .40985 .23707 Mtetra
.613 .5 .701 r
.40985 .23707 .41333 .25001 .41977 .24743 .41628 .23442 Mtetra
.609 .497 .701 r
.41628 .23442 .41977 .24743 .42624 .24403 .42272 .23191 Mtetra
.6 .502 .715 r
.42272 .23191 .42624 .24403 .43264 .24359 .42916 .22987 Mtetra
.643 .511 .688 r
.42916 .22987 .43264 .24359 .4392 .23835 .43568 .2258 Mtetra
.529 .453 .714 r
.43568 .2258 .4392 .23835 .44563 .23793 .44209 .22585 Mtetra
.716 .571 .691 r
.44209 .22585 .44563 .23793 .45217 .23431 .4487 .21884 Mtetra
.416 .348 .673 r
.4487 .21884 .45217 .23431 .45877 .22841 .45508 .22229 Mtetra
.83 .723 .747 r
.45508 .22229 .45877 .22841 .46519 .23147 .46174 .21363 Mtetra
.429 .338 .651 r
.46174 .21363 .46519 .23147 .47193 .21798 .46816 .21722 Mtetra
.389 .833 .939 r
.46816 .21722 .47193 .21798 .47838 .22205 .47471 .21582 Mtetra
.772 .706 .79 r
.47471 .21582 .47838 .22205 .48502 .21506 .48134 .20999 Mtetra
.798 .367 0 r
.48134 .20999 .48502 .21506 .49167 .20613 .48774 .22366 Mtetra
.411 .097 .319 r
.48774 .22366 .49167 .20613 .49817 .21272 .49438 .22076 Mtetra
.063 0 .002 r
.49438 .22076 .49817 .21272 .50481 .20742 .50106 .21518 Mtetra
.804 .423 .333 r
.50106 .21518 .50481 .20742 .51145 .20311 .50762 .23142 Mtetra
.681 .368 .438 r
.50762 .23142 .51145 .20311 .51803 .22709 .51428 .24876 Mtetra
.047 0 .226 r
.51428 .24876 .51803 .22709 .52474 .26649 .52108 .23272 Mtetra
.8 .551 .562 r
.52108 .23272 .52474 .26649 .53158 .26877 .52782 .19358 Mtetra
.593 .369 .546 r
.52782 .19358 .53158 .26877 .53825 .22446 .53448 .17994 Mtetra
.094 .025 .48 r
.53448 .17994 .53825 .22446 .54477 .18438 .54136 .2108 Mtetra
.842 .518 .441 r
.54136 .2108 .54477 .18438 .55155 .19009 .54859 .2654 Mtetra
.651 .37 .481 r
.54859 .2654 .55155 .19009 .5589 .24222 .55588 .29857 Mtetra
.299 .081 .405 r
.55588 .29857 .5589 .24222 .56651 .294 .56265 .27545 Mtetra
.916 .653 .525 r
.56265 .27545 .56651 .294 .57352 .29079 .56883 .21598 Mtetra
.713 .46 .542 r
.56883 .21598 .57352 .29079 .57961 .23564 .57499 .16971 Mtetra
.528 .324 .547 r
.57499 .16971 .57961 .23564 .58546 .17934 .58183 .16883 Mtetra
.928 .598 .145 r
.58183 .16883 .58546 .17934 .59206 .16656 .58972 .21616 Mtetra
.799 .488 .463 r
.58972 .21616 .59206 .16656 .59999 .20881 .59838 .28581 Mtetra
.7 .409 .48 r
.59838 .28581 .59999 .20881 .60894 .28042 .60694 .3376 Mtetra
.571 .295 .459 r
.60694 .3376 .60894 .28042 .61781 .3369 .61458 .34758 Mtetra
.799 .769 .26 r
.61458 .34758 .61781 .3369 .62559 .34979 .62116 .32044 Mtetra
.845 .586 .548 r
.62116 .32044 .62559 .34979 .63208 .32245 .62703 .27453 Mtetra
.78 .521 .545 r
.62703 .27453 .63208 .32245 .63775 .27499 .63264 .22683 Mtetra
.75 .498 .55 r
.63264 .22683 .63775 .27499 .64318 .22637 .6384 .18806 Mtetra
.729 .49 .566 r
.6384 .18806 .64318 .22637 .64882 .1877 .64451 .16181 Mtetra
.715 .501 .597 r
.64451 .16181 .64882 .1877 .65487 .16204 .65097 .14617 Mtetra
.712 .539 .654 r
.65097 .14617 .65487 .16204 .66131 .14705 .65769 .13716 Mtetra
.711 .605 .736 r
.65769 .13716 .66131 .14705 .66804 .13862 .66456 .13162 Mtetra
.7 .667 .814 r
.66456 .13162 .66804 .13862 .67492 .13347 .67151 .12773 Mtetra
.682 .705 .865 r
.67151 .12773 .67492 .13347 .68188 .12981 .67851 .12464 Mtetra
.67 .726 .891 r
.67851 .12464 .68188 .12981 .68889 .12681 .68555 .12188 Mtetra
.665 .736 .903 r
.68555 .12188 .68889 .12681 .69594 .12408 .69261 .11924 Mtetra
.664 .741 .907 r
.69261 .11924 .69594 .12408 .70301 .12144 .6997 .11661 Mtetra
.664 .741 .908 r
.6997 .11661 .70301 .12144 .71009 .11882 .7068 .11397 Mtetra
.7068 .11397 .71009 .11882 .7172 .1162 .71391 .11134 Mtetra
.71391 .11134 .7172 .1162 .72432 .11357 .72105 .10869 Mtetra
.72105 .10869 .72432 .11357 .73146 .11093 .7282 .10604 Mtetra
.7282 .10604 .73146 .11093 .73862 .10829 .73537 .10339 Mtetra
.73537 .10339 .73862 .10829 .7458 .10564 .74256 .10073 Mtetra
.74256 .10073 .7458 .10564 .75299 .10298 .74977 .09806 Mtetra
.11043 .32932 .11463 .33323 .12034 .33112 .11615 .3272 Mtetra
.11615 .3272 .12034 .33112 .12606 .329 .12188 .32507 Mtetra
.12188 .32507 .12606 .329 .13179 .32687 .12762 .32294 Mtetra
.12762 .32294 .13179 .32687 .13754 .32474 .13338 .3208 Mtetra
.13338 .3208 .13754 .32474 .1433 .32261 .13914 .31866 Mtetra
.13914 .31866 .1433 .32261 .14908 .32048 .14493 .31651 Mtetra
.663 .741 .908 r
.14493 .31651 .14908 .32048 .15487 .31834 .15072 .31436 Mtetra
.15072 .31436 .15487 .31834 .16067 .3162 .15653 .31221 Mtetra
.15653 .31221 .16067 .3162 .16648 .31408 .16235 .31007 Mtetra
.661 .739 .908 r
.16235 .31007 .16648 .31408 .17229 .31207 .16818 .30794 Mtetra
.652 .731 .907 r
.16818 .30794 .17229 .31207 .17807 .31039 .17401 .30594 Mtetra
.625 .706 .904 r
.17401 .30594 .17807 .31039 .18379 .30952 .17981 .30432 Mtetra
.559 .645 .892 r
.17981 .30432 .18379 .30952 .18934 .31033 .18553 .3036 Mtetra
.422 .514 .847 r
.18553 .3036 .18934 .31033 .19455 .31456 .19107 .30466 Mtetra
.192 .275 .721 r
.19107 .30466 .19455 .31456 .19913 .32535 .19628 .30919 Mtetra
0 0 .526 r
.19628 .30919 .19913 .32535 .2027 .34656 .20086 .32016 Mtetra
0 0 .377 r
.20086 .32016 .2027 .34656 .20515 .38001 .20448 .34122 Mtetra
0 0 .307 r
.20448 .34122 .20515 .38001 .20691 .42194 .20704 .37387 Mtetra
0 0 .293 r
.20704 .37387 .20691 .42194 .20908 .46149 .20899 .41434 Mtetra
0 0 .313 r
.20899 .41434 .20908 .46149 .21321 .48205 .21128 .45295 Mtetra
0 0 .397 r
.21128 .45295 .21321 .48205 .22079 .46631 .21526 .47539 Mtetra
0 0 0 r
.21526 .47539 .22079 .46631 .23197 .41046 .22234 .46526 Mtetra
0 0 .124 r
.22234 .46526 .23197 .41046 .24442 .33815 .23293 .4161 Mtetra
0 0 .153 r
.23293 .4161 .24442 .33815 .25466 .28854 .24516 .34647 Mtetra
0 0 .1 r
.24516 .34647 .25466 .28854 .26068 .28658 .25593 .2909 Mtetra
.979 .917 .633 r
.25593 .2909 .26068 .28658 .26308 .32835 .26322 .27444 Mtetra
.16 .045 .462 r
.26322 .27444 .26308 .32835 .26475 .38139 .26684 .30183 Mtetra
.015 0 .388 r
.26684 .30183 .26475 .38139 .26956 .39764 .26864 .35335 Mtetra
0 0 .378 r
.26864 .35335 .26956 .39764 .2787 .359 .27208 .38691 Mtetra
.209 0 .293 r
.27208 .38691 .2787 .359 .2892 .30071 .27922 .37423 Mtetra
.035 0 .302 r
.27922 .37423 .2892 .30071 .29768 .26713 .28895 .32667 Mtetra
0 0 .194 r
.28895 .32667 .29768 .26713 .30292 .27734 .29873 .27619 Mtetra
.956 .801 .649 r
.29873 .27619 .30292 .27734 .30656 .31135 .30612 .25688 Mtetra
.367 .203 .523 r
.30612 .25688 .30656 .31135 .312 .32117 .31112 .27161 Mtetra
.365 .207 .529 r
.31112 .27161 .312 .32117 .31963 .29849 .31626 .2852 Mtetra
.686 .541 .683 r
.31626 .2852 .31963 .29849 .32702 .27865 .32277 .27918 Mtetra
.848 .989 .853 r
.32277 .27918 .32702 .27865 .33305 .27993 .32929 .27287 Mtetra
.654 .265 0 r
.32929 .27287 .33305 .27993 .33934 .27733 .33476 .2836 Mtetra
0 0 0 r
.33476 .2836 .33934 .27733 .34653 .25935 .34123 .27874 Mtetra
0 0 .118 r
.34123 .27874 .34653 .25935 .35258 .2609 .34831 .2632 Mtetra
.748 .288 .157 r
.34831 .2632 .35258 .2609 .35895 .25712 .3541 .27045 Mtetra
0 0 .01 r
.3541 .27045 .35895 .25712 .36555 .24913 .36095 .25862 Mtetra
.215 0 .104 r
.36095 .25862 .36555 .24913 .37154 .25314 .36738 .25453 Mtetra
.077 0 0 r
.36738 .25453 .37154 .25314 .37817 .24461 .37365 .25395 Mtetra
0 0 0 r
.37365 .25395 .37817 .24461 .38427 .24747 .38033 .24504 Mtetra
.05 .537 .887 r
.38033 .24504 .38427 .24747 .39077 .24203 .38653 .24654 Mtetra
.517 .817 .484 r
.38653 .24654 .39077 .24203 .39704 .24202 .39314 .2395 Mtetra
.367 .729 .989 r
.39314 .2395 .39704 .24202 .40347 .23871 .39945 .2394 Mtetra
.645 .968 .865 r
.39945 .2394 .40347 .23871 .40985 .23707 .40594 .23527 Mtetra
.581 .87 .995 r
.40594 .23527 .40985 .23707 .41628 .23442 .41236 .23329 Mtetra
.441 .845 .972 r
.41236 .23329 .41628 .23442 .42272 .23191 .41878 .2319 Mtetra
.677 .971 .915 r
.41878 .2319 .42272 .23191 .42916 .22987 .4253 .228 Mtetra
0 .483 .813 r
.4253 .228 .42916 .22987 .43568 .2258 .43165 .2297 Mtetra
0 0 0 r
.43165 .2297 .43568 .2258 .44209 .22585 .43826 .22387 Mtetra
.437 0 0 r
.43826 .22387 .44209 .22585 .4487 .21884 .4446 .22796 Mtetra
.193 0 .09 r
.4446 .22796 .4487 .21884 .45508 .22229 .45119 .22355 Mtetra
.161 0 0 r
.45119 .22355 .45508 .22229 .46174 .21363 .4577 .22352 Mtetra
.651 .27 .309 r
.4577 .22352 .46174 .21363 .46816 .21722 .4641 .23006 Mtetra
0 0 .044 r
.4641 .23006 .46816 .21722 .47471 .21582 .47087 .21825 Mtetra
.813 .373 .196 r
.47087 .21825 .47471 .21582 .48134 .20999 .47727 .22962 Mtetra
.475 .161 .353 r
.47727 .22962 .48134 .20999 .48774 .22366 .4839 .22899 Mtetra
.889 .909 .503 r
.4839 .22899 .48774 .22366 .49438 .22076 .49072 .21337 Mtetra
.341 .455 .832 r
.49072 .21337 .49438 .22076 .50106 .21518 .49733 .21573 Mtetra
.195 0 0 r
.49733 .21573 .50106 .21518 .50762 .23142 .504 .21643 Mtetra
.82 .61 .619 r
.504 .21643 .50762 .23142 .51428 .24876 .51079 .19718 Mtetra
.652 .425 .562 r
.51079 .19718 .51428 .24876 .52108 .23272 .51752 .17828 Mtetra
.367 .211 .533 r
.51752 .17828 .52108 .23272 .52782 .19358 .52419 .19455 Mtetra
.944 .598 .329 r
.52419 .19455 .52782 .19358 .53448 .17994 .53101 .24181 Mtetra
.704 .411 .478 r
.53101 .24181 .53448 .17994 .54136 .2108 .53806 .28456 Mtetra
.543 .28 .467 r
.53806 .28456 .54136 .2108 .54859 .2654 .54509 .29093 Mtetra
0 0 0 r
.54509 .29093 .54859 .2654 .55588 .29857 .55178 .25079 Mtetra
.804 .542 .542 r
.55178 .25079 .55588 .29857 .56265 .27545 .55812 .19369 Mtetra
.655 .414 .543 r
.55812 .19369 .56265 .27545 .56883 .21598 .56458 .16235 Mtetra
.397 .235 .541 r
.56458 .16235 .56883 .21598 .57499 .16971 .57162 .17602 Mtetra
.929 .582 .355 r
.57162 .17602 .57499 .16971 .58183 .16883 .57945 .22903 Mtetra
.767 .463 .472 r
.57945 .22903 .58183 .16883 .58972 .21616 .58783 .29558 Mtetra
.678 .391 .48 r
.58783 .29558 .58972 .21616 .59838 .28581 .59606 .34042 Mtetra
.537 .265 .451 r
.59606 .34042 .59838 .28581 .60694 .3376 .60353 .34474 Mtetra
.943 .836 .396 r
.60353 .34474 .60694 .3376 .61458 .34758 .61014 .31579 Mtetra
.831 .573 .55 r
.61014 .31579 .61458 .34758 .62116 .32044 .61617 .27092 Mtetra
.771 .513 .546 r
.61617 .27092 .62116 .32044 .62703 .27453 .62199 .22475 Mtetra
.742 .491 .55 r
.62199 .22475 .62703 .27453 .63264 .22683 .6279 .18679 Mtetra
.722 .483 .565 r
.6279 .18679 .63264 .22683 .6384 .18806 .63409 .16068 Mtetra
.709 .493 .594 r
.63409 .16068 .6384 .18806 .64451 .16181 .64059 .14484 Mtetra
.707 .529 .646 r
.64059 .14484 .64451 .16181 .65097 .14617 .64731 .13552 Mtetra
.708 .591 .722 r
.64731 .13552 .65097 .14617 .65769 .13716 .65417 .12969 Mtetra
.7 .653 .8 r
.65417 .12969 .65769 .13716 .66456 .13162 .66111 .12564 Mtetra
.683 .696 .856 r
.66111 .12564 .66456 .13162 .67151 .12773 .66811 .12247 Mtetra
.671 .722 .888 r
.66811 .12247 .67151 .12773 .67851 .12464 .67514 .11969 Mtetra
.665 .736 .902 r
.67514 .11969 .67851 .12464 .68555 .12188 .6822 .11703 Mtetra
.664 .74 .907 r
.6822 .11703 .68555 .12188 .69261 .11924 .68928 .11439 Mtetra
.664 .741 .908 r
.68928 .11439 .69261 .11924 .6997 .11661 .69637 .11174 Mtetra
.69637 .11174 .6997 .11661 .7068 .11397 .70348 .1091 Mtetra
.70348 .1091 .7068 .11397 .71391 .11134 .71061 .10645 Mtetra
.71061 .10645 .71391 .11134 .72105 .10869 .71776 .1038 Mtetra
.71776 .1038 .72105 .10869 .7282 .10604 .72492 .10114 Mtetra
.72492 .10114 .7282 .10604 .73537 .10339 .73211 .09847 Mtetra
.73211 .09847 .73537 .10339 .74256 .10073 .73931 .0958 Mtetra
.73931 .0958 .74256 .10073 .74977 .09806 .74653 .09311 Mtetra
.10622 .3254 .11043 .32932 .11615 .3272 .11194 .32327 Mtetra
.11194 .32327 .11615 .3272 .12188 .32507 .11768 .32113 Mtetra
.11768 .32113 .12188 .32507 .12762 .32294 .12343 .31899 Mtetra
.12343 .31899 .12762 .32294 .13338 .3208 .12919 .31684 Mtetra
.12919 .31684 .13338 .3208 .13914 .31866 .13497 .31469 Mtetra
.13497 .31469 .13914 .31866 .14493 .31651 .14076 .31254 Mtetra
.14076 .31254 .14493 .31651 .15072 .31436 .14656 .31037 Mtetra
.663 .741 .908 r
.14656 .31037 .15072 .31436 .15653 .31221 .15238 .30821 Mtetra
.15238 .30821 .15653 .31221 .16235 .31007 .1582 .30605 Mtetra
.662 .74 .908 r
.1582 .30605 .16235 .31007 .16818 .30794 .16404 .3039 Mtetra
.66 .739 .908 r
.16404 .3039 .16818 .30794 .17401 .30594 .16989 .30177 Mtetra
.651 .73 .907 r
.16989 .30177 .17401 .30594 .17981 .30432 .17574 .29977 Mtetra
.622 .702 .902 r
.17574 .29977 .17981 .30432 .18553 .3036 .18156 .29818 Mtetra
.553 .634 .886 r
.18156 .29818 .18553 .3036 .19107 .30466 .18729 .29754 Mtetra
.421 .499 .834 r
.18729 .29754 .19107 .30466 .19628 .30919 .19284 .29871 Mtetra
.216 .278 .713 r
.19284 .29871 .19628 .30919 .20086 .32016 .19807 .30324 Mtetra
.001 .034 .54 r
.19807 .30324 .20086 .32016 .20448 .34122 .20271 .31392 Mtetra
0 0 .406 r
.20271 .31392 .20448 .34122 .20704 .37387 .20644 .33416 Mtetra
0 0 .342 r
.20644 .33416 .20704 .37387 .20899 .41434 .20919 .36521 Mtetra
0 0 .327 r
.20919 .36521 .20899 .41434 .21128 .45295 .21137 .40364 Mtetra
0 0 .337 r
.21137 .40364 .21128 .45295 .21526 .47539 .21375 .44167 Mtetra
0 0 .382 r
.21375 .44167 .21526 .47539 .22234 .46526 .21744 .46746 Mtetra
0 0 0 r
.21744 .46746 .22234 .46526 .23293 .4161 .22384 .46498 Mtetra
0 0 .161 r
.22384 .46498 .23293 .4161 .24516 .34647 .23363 .42485 Mtetra
0 0 .195 r
.23363 .42485 .24516 .34647 .25593 .2909 .24542 .36047 Mtetra
0 0 .169 r
.24542 .36047 .25593 .2909 .26322 .27444 .2566 .3005 Mtetra
0 0 0 r
.2566 .3005 .26322 .27444 .26684 .30183 .26523 .26858 Mtetra
.383 .24 .56 r
.26523 .26858 .26684 .30183 .26864 .35335 .27047 .27671 Mtetra
.137 .013 .435 r
.27047 .27671 .26864 .35335 .27208 .38691 .27316 .31733 Mtetra
.051 0 .41 r
.27316 .31733 .27208 .38691 .27922 .37423 .27586 .36016 Mtetra
0 0 .327 r
.27586 .36016 .27922 .37423 .28895 .32667 .2808 .37602 Mtetra
.176 0 .333 r
.2808 .37602 .28895 .32667 .29873 .27619 .28883 .35143 Mtetra
0 0 .276 r
.28883 .35143 .29873 .27619 .30612 .25688 .29888 .2981 Mtetra
0 0 .101 r
.29888 .2981 .30612 .25688 .31112 .27161 .3078 .25806 Mtetra
.689 .54 .678 r
.3078 .25806 .31112 .27161 .31626 .2852 .31428 .25175 Mtetra
.426 .274 .57 r
.31428 .25175 .31626 .2852 .32277 .27918 .31993 .25785 Mtetra
.589 .427 .63 r
.31993 .25785 .32277 .27918 .32929 .27287 .32622 .25479 Mtetra
.532 .404 .651 r
.32622 .25479 .32929 .27287 .33476 .2836 .33234 .25468 Mtetra
.25 .156 .548 r
.33234 .25468 .33476 .2836 .34123 .27874 .33772 .26713 Mtetra
.725 .581 .693 r
.33772 .26713 .34123 .27874 .34831 .2632 .34433 .25985 Mtetra
.537 .754 .976 r
.34433 .25985 .34831 .2632 .3541 .27045 .35058 .25888 Mtetra
.122 .201 .674 r
.35058 .25888 .3541 .27045 .36095 .25862 .35643 .26557 Mtetra
.727 .863 .442 r
.35643 .26557 .36095 .25862 .36738 .25453 .36333 .25324 Mtetra
.696 .154 0 r
.36333 .25324 .36738 .25453 .37365 .25395 .36927 .25937 Mtetra
0 0 0 r
.36927 .25937 .37365 .25395 .38033 .24504 .37595 .25139 Mtetra
.389 0 .082 r
.37595 .25139 .38033 .24504 .38653 .24654 .38226 .25101 Mtetra
0 0 0 r
.38226 .25101 .38653 .24654 .39314 .2395 .38873 .24772 Mtetra
.262 0 .087 r
.38873 .24772 .39314 .2395 .39945 .2394 .39519 .24486 Mtetra
.192 0 0 r
.39519 .24486 .39945 .2394 .40594 .23527 .40164 .24257 Mtetra
.279 0 .063 r
.40164 .24257 .40594 .23527 .41236 .23329 .4081 .24033 Mtetra
.226 0 .025 r
.4081 .24033 .41236 .23329 .41878 .2319 .4146 .23755 Mtetra
.283 0 0 r
.4146 .23755 .41878 .2319 .4253 .228 .42107 .2361 Mtetra
.315 0 .11 r
.42107 .2361 .4253 .228 .43165 .2297 .42758 .23402 Mtetra
0 0 0 r
.42758 .23402 .43165 .2297 .43826 .22387 .43415 .23042 Mtetra
.54 .109 .171 r
.43415 .23042 .43826 .22387 .4446 .22796 .44057 .23279 Mtetra
.723 .896 .513 r
.44057 .23279 .4446 .22796 .45119 .22355 .44734 .2226 Mtetra
.731 .203 0 r
.44734 .2226 .45119 .22355 .4577 .22352 .45368 .22988 Mtetra
.669 .83 .404 r
.45368 .22988 .4577 .22352 .4641 .23006 .46049 .21813 Mtetra
.633 .527 .716 r
.46049 .21813 .4641 .23006 .47087 .21825 .46711 .2149 Mtetra
.081 .503 .9 r
.46711 .2149 .47087 .21825 .47727 .22962 .47366 .21699 Mtetra
.83 .631 .634 r
.47366 .21699 .47727 .22962 .4839 .22899 .48052 .19944 Mtetra
.582 .399 .599 r
.48052 .19944 .4839 .22899 .49072 .21337 .48717 .19534 Mtetra
.575 .436 .655 r
.48717 .19534 .49072 .21337 .49733 .21573 .49381 .19335 Mtetra
.692 .496 .617 r
.49381 .19335 .49733 .21573 .504 .21643 .50054 .18222 Mtetra
.489 .322 .582 r
.50054 .18222 .504 .21643 .51079 .19718 .50717 .18489 Mtetra
.894 .575 .078 r
.50717 .18489 .51079 .19718 .51752 .17828 .51371 .22169 Mtetra
.769 .461 .467 r
.51371 .22169 .51752 .17828 .52419 .19455 .52042 .27094 Mtetra
.597 .325 .475 r
.52042 .27094 .52419 .19455 .53101 .24181 .52736 .28978 Mtetra
.252 .035 .377 r
.52736 .28978 .53101 .24181 .53806 .28456 .53428 .26727 Mtetra
.905 .651 .542 r
.53428 .26727 .53806 .28456 .54509 .29093 .54099 .21846 Mtetra
.714 .462 .543 r
.54099 .21846 .54509 .29093 .55178 .25079 .54754 .17313 Mtetra
.58 .357 .543 r
.54754 .17313 .55178 .25079 .55812 .19369 .55424 .16152 Mtetra
0 0 .451 r
.55424 .16152 .55812 .19369 .56458 .16235 .56141 .19063 Mtetra
.841 .515 .437 r
.56141 .19063 .56458 .16235 .57162 .17602 .56914 .24766 Mtetra
.731 .435 .478 r
.56914 .24766 .57162 .17602 .57945 .22903 .57723 .30847 Mtetra
.651 .368 .478 r
.57723 .30847 .57945 .22903 .58783 .29558 .58515 .34396 Mtetra
.475 .21 .432 r
.58515 .34396 .58783 .29558 .59606 .34042 .59243 .34057 Mtetra
.997 .803 .519 r
.59243 .34057 .59606 .34042 .60353 .34474 .59905 .30835 Mtetra
.809 .553 .551 r
.59905 .30835 .60353 .34474 .61014 .31579 .60523 .26418 Mtetra
.758 .502 .547 r
.60523 .26418 .61014 .31579 .61617 .27092 .61124 .22013 Mtetra
.733 .484 .551 r
.61124 .22013 .61617 .27092 .62199 .22475 .61731 .18381 Mtetra
.714 .477 .564 r
.61731 .18381 .62199 .22475 .6279 .18679 .6236 .15853 Mtetra
.702 .486 .592 r
.6236 .15853 .6279 .18679 .63409 .16068 .63015 .14296 Mtetra
.701 .522 .642 r
.63015 .14296 .63409 .16068 .64059 .14484 .63689 .13363 Mtetra
.704 .581 .714 r
.63689 .13363 .64059 .14484 .64731 .13552 .64375 .12767 Mtetra
.698 .642 .79 r
.64375 .12767 .64731 .13552 .65417 .12969 .65069 .12351 Mtetra
.683 .689 .849 r
.65069 .12351 .65417 .12969 .66111 .12564 .65769 .1203 Mtetra
.671 .719 .885 r
.65769 .1203 .66111 .12564 .66811 .12247 .66471 .11749 Mtetra
.666 .735 .901 r
.66471 .11749 .66811 .12247 .67514 .11969 .67176 .11481 Mtetra
.665 .74 .906 r
.67176 .11481 .67514 .11969 .6822 .11703 .67883 .11216 Mtetra
.664 .741 .907 r
.67883 .11216 .6822 .11703 .68928 .11439 .68592 .10951 Mtetra
.664 .741 .908 r
.68592 .10951 .68928 .11439 .69637 .11174 .69303 .10686 Mtetra
.69303 .10686 .69637 .11174 .70348 .1091 .70015 .10421 Mtetra
.70015 .10421 .70348 .1091 .71061 .10645 .70729 .10155 Mtetra
.70729 .10155 .71061 .10645 .71776 .1038 .71445 .09888 Mtetra
.71445 .09888 .71776 .1038 .72492 .10114 .72163 .09621 Mtetra
.72163 .09621 .72492 .10114 .73211 .09847 .72883 .09353 Mtetra
.72883 .09353 .73211 .09847 .73931 .0958 .73604 .09084 Mtetra
.73604 .09084 .73931 .0958 .74653 .09311 .74327 .08815 Mtetra
.10198 .32146 .10622 .3254 .11194 .32327 .10772 .31932 Mtetra
.10772 .31932 .11194 .32327 .11768 .32113 .11346 .31717 Mtetra
.11346 .31717 .11768 .32113 .12343 .31899 .11922 .31502 Mtetra
.11922 .31502 .12343 .31899 .12919 .31684 .12499 .31287 Mtetra
.12499 .31287 .12919 .31684 .13497 .31469 .13077 .31071 Mtetra
.13077 .31071 .13497 .31469 .14076 .31254 .13657 .30854 Mtetra
.13657 .30854 .14076 .31254 .14656 .31037 .14238 .30637 Mtetra
.14238 .30637 .14656 .31037 .15238 .30821 .1482 .3042 Mtetra
.663 .741 .908 r
.1482 .3042 .15238 .30821 .1582 .30605 .15404 .30202 Mtetra
.663 .74 .908 r
.15404 .30202 .1582 .30605 .16404 .3039 .15989 .29985 Mtetra
.662 .74 .908 r
.15989 .29985 .16404 .3039 .16989 .30177 .16575 .29769 Mtetra
.659 .738 .908 r
.16575 .29769 .16989 .30177 .17574 .29977 .17162 .29555 Mtetra
.65 .729 .906 r
.17162 .29555 .17574 .29977 .18156 .29818 .17749 .29355 Mtetra
.62 .699 .901 r
.17749 .29355 .18156 .29818 .18729 .29754 .18332 .29196 Mtetra
.552 .628 .881 r
.18332 .29196 .18729 .29754 .19284 .29871 .18907 .29133 Mtetra
.431 .497 .826 r
.18907 .29133 .19284 .29871 .19807 .30324 .19465 .29243 Mtetra
.254 .296 .714 r
.19465 .29243 .19807 .30324 .20271 .31392 .19994 .29666 Mtetra
.063 .075 .559 r
.19994 .29666 .20271 .31392 .20644 .33416 .20467 .30662 Mtetra
0 0 .436 r
.20467 .30662 .20644 .33416 .20919 .36521 .20857 .32544 Mtetra
0 0 .377 r
.20857 .32544 .20919 .36521 .21137 .40364 .21159 .35412 Mtetra
0 0 .36 r
.21159 .35412 .21137 .40364 .21375 .44167 .21406 .38991 Mtetra
0 0 .359 r
.21406 .38991 .21375 .44167 .21744 .46746 .21651 .4274 Mtetra
0 0 .375 r
.21651 .4274 .21744 .46746 .22384 .46498 .21985 .45719 Mtetra
0 .118 .669 r
.21985 .45719 .22384 .46498 .23363 .42485 .22547 .4634 Mtetra
0 0 .181 r
.22547 .4634 .23363 .42485 .24542 .36047 .23426 .43466 Mtetra
0 0 .236 r
.23426 .43466 .24542 .36047 .2566 .3005 .24525 .37963 Mtetra
0 0 .231 r
.24525 .37963 .2566 .3005 .26523 .26858 .25653 .31917 Mtetra
0 0 .126 r
.25653 .31917 .26523 .26858 .27047 .27671 .26638 .27327 Mtetra
.91 .773 .697 r
.26638 .27327 .27047 .27671 .27316 .31733 .27348 .25922 Mtetra
.292 .141 .498 r
.27348 .25922 .27316 .31733 .27586 .36016 .27776 .28007 Mtetra
.162 .031 .443 r
.27776 .28007 .27586 .36016 .2808 .37602 .28064 .32039 Mtetra
.017 0 .411 r
.28064 .32039 .2808 .37602 .28883 .35143 .28401 .35656 Mtetra
.416 0 .036 r
.28401 .35656 .28883 .35143 .29888 .2981 .29019 .35695 Mtetra
0 0 .267 r
.29019 .35695 .29888 .2981 .3078 .25806 .29936 .31606 Mtetra
0 0 .255 r
.29936 .31606 .3078 .25806 .31428 .25175 .30847 .27401 Mtetra
0 0 .158 r
.30847 .27401 .31428 .25175 .31993 .25785 .31568 .25788 Mtetra
.25 .762 .836 r
.31568 .25788 .31993 .25785 .32622 .25479 .32186 .25674 Mtetra
.93 .971 .737 r
.32186 .25674 .32622 .25479 .33234 .25468 .32863 .2467 Mtetra
.74 .642 .752 r
.32863 .2467 .33234 .25468 .33772 .26713 .33512 .24098 Mtetra
.415 .284 .593 r
.33512 .24098 .33772 .26713 .34433 .25985 .34094 .2463 Mtetra
.714 .556 .673 r
.34094 .2463 .34433 .25985 .35058 .25888 .34758 .2385 Mtetra
.402 .3 .624 r
.34758 .2385 .35058 .25888 .35643 .26557 .3535 .24312 Mtetra
.558 .401 .625 r
.3535 .24312 .35643 .26557 .36333 .25324 .35981 .24155 Mtetra
.628 .524 .717 r
.35981 .24155 .36333 .25324 .36927 .25937 .36621 .2386 Mtetra
.449 .332 .628 r
.36621 .2386 .36927 .25937 .37595 .25139 .37231 .24174 Mtetra
.722 .606 .727 r
.37231 .24174 .37595 .25139 .38226 .25101 .37889 .23582 Mtetra
.45 .372 .677 r
.37889 .23582 .38226 .25101 .38873 .24772 .38508 .23814 Mtetra
.697 .595 .738 r
.38508 .23814 .38873 .24772 .39519 .24486 .39163 .23332 Mtetra
.547 .479 .73 r
.39163 .23332 .39519 .24486 .40164 .24257 .398 .23283 Mtetra
.638 .561 .752 r
.398 .23283 .40164 .24257 .4081 .24033 .40449 .23 Mtetra
.653 .56 .737 r
.40449 .23 .4081 .24033 .4146 .23755 .41101 .22653 Mtetra
.557 .493 .74 r
.41101 .22653 .4146 .23755 .42107 .2361 .41745 .22581 Mtetra
.727 .601 .715 r
.41745 .22581 .42107 .2361 .42758 .23402 .4241 .21928 Mtetra
.503 .413 .686 r
.4241 .21928 .42758 .23402 .43415 .23042 .43052 .22006 Mtetra
.752 .613 .704 r
.43052 .22006 .43415 .23042 .44057 .23279 .43722 .21215 Mtetra
.56 .412 .636 r
.43722 .21215 .44057 .23279 .44734 .2226 .44375 .21058 Mtetra
.645 .532 .711 r
.44375 .21058 .44734 .2226 .45368 .22988 .45035 .20687 Mtetra
.665 .475 .618 r
.45035 .20687 .45368 .22988 .46049 .21813 .45708 .19789 Mtetra
.458 .343 .635 r
.45708 .19789 .46049 .21813 .46711 .2149 .46355 .20075 Mtetra
.744 .571 .659 r
.46355 .20075 .46711 .2149 .47366 .21699 .4703 .19046 Mtetra
.499 .347 .606 r
.4703 .19046 .47366 .21699 .48052 .19944 .47685 .19198 Mtetra
.07 .28 .768 r
.47685 .19198 .48052 .19944 .48717 .19534 .48338 .19707 Mtetra
.416 .841 .687 r
.48338 .19707 .48717 .19534 .49381 .19335 .49006 .19327 Mtetra
.846 .39 .111 r
.49006 .19327 .49381 .19335 .50054 .18222 .4966 .20595 Mtetra
.809 .483 .438 r
.4966 .20595 .50054 .18222 .50717 .18489 .50304 .24429 Mtetra
.686 .395 .475 r
.50304 .24429 .50717 .18489 .51371 .22169 .50968 .28004 Mtetra
.455 .201 .439 r
.50968 .28004 .51371 .22169 .52042 .27094 .51663 .27344 Mtetra
.998 .786 .489 r
.51663 .27344 .52042 .27094 .52736 .28978 .5236 .23099 Mtetra
.743 .49 .547 r
.5236 .23099 .52736 .28978 .53428 .26727 .5304 .18547 Mtetra
.631 .395 .542 r
.5304 .18547 .53428 .26727 .54099 .21846 .5371 .1606 Mtetra
.429 .254 .54 r
.5371 .1606 .54099 .21846 .54754 .17313 .54394 .17142 Mtetra
.948 .594 .278 r
.54394 .17142 .54754 .17313 .55424 .16152 .55114 .21438 Mtetra
.763 .457 .468 r
.55114 .21438 .55424 .16152 .56141 .19063 .55873 .27147 Mtetra
.692 .403 .481 r
.55873 .27147 .56141 .19063 .56914 .24766 .56652 .32235 Mtetra
.616 .338 .473 r
.56652 .32235 .56914 .24766 .57723 .30847 .57415 .34609 Mtetra
.344 .093 .383 r
.57415 .34609 .57723 .30847 .58515 .34396 .58128 .33399 Mtetra
.935 .699 .557 r
.58128 .33399 .58515 .34396 .59243 .34057 .5879 .29788 Mtetra
.784 .528 .55 r
.5879 .29788 .59243 .34057 .59905 .30835 .59422 .25437 Mtetra
.742 .489 .547 r
.59422 .25437 .59905 .30835 .60523 .26418 .60042 .21308 Mtetra
.723 .476 .552 r
.60042 .21308 .60523 .26418 .61124 .22013 .60666 .1792 Mtetra
.707 .471 .565 r
.60666 .1792 .61124 .22013 .61731 .18381 .61306 .15535 Mtetra
.695 .481 .593 r
.61306 .15535 .61731 .18381 .6236 .15853 .61967 .14049 Mtetra
.695 .516 .641 r
.61967 .14049 .6236 .15853 .63015 .14296 .62644 .13143 Mtetra
.7 .574 .711 r
.62644 .13143 .63015 .14296 .63689 .13363 .63331 .12553 Mtetra
.696 .635 .784 r
.63331 .12553 .63689 .13363 .64375 .12767 .64025 .12135 Mtetra
.683 .684 .845 r
.64025 .12135 .64375 .12767 .65069 .12351 .64724 .11811 Mtetra
.671 .717 .883 r
.64724 .11811 .65069 .12351 .65769 .1203 .65426 .11528 Mtetra
.666 .734 .9 r
.65426 .11528 .65769 .1203 .66471 .11749 .6613 .11259 Mtetra
.665 .74 .906 r
.6613 .11259 .66471 .11749 .67176 .11481 .66837 .10993 Mtetra
.664 .741 .907 r
.66837 .10993 .67176 .11481 .67883 .11216 .67545 .10727 Mtetra
.67545 .10727 .67883 .11216 .68592 .10951 .68255 .10461 Mtetra
.664 .741 .908 r
.68255 .10461 .68592 .10951 .69303 .10686 .68967 .10196 Mtetra
.68967 .10196 .69303 .10686 .70015 .10421 .6968 .09929 Mtetra
.6968 .09929 .70015 .10421 .70729 .10155 .70396 .09662 Mtetra
.70396 .09662 .70729 .10155 .71445 .09888 .71113 .09394 Mtetra
.71113 .09394 .71445 .09888 .72163 .09621 .71832 .09125 Mtetra
.71832 .09125 .72163 .09621 .72883 .09353 .72553 .08856 Mtetra
.72553 .08856 .72883 .09353 .73604 .09084 .73276 .08586 Mtetra
.73276 .08586 .73604 .09084 .74327 .08815 .74 .08316 Mtetra
.09774 .3175 .10198 .32146 .10772 .31932 .10347 .31535 Mtetra
.10347 .31535 .10772 .31932 .11346 .31717 .10923 .3132 Mtetra
.10923 .3132 .11346 .31717 .11922 .31502 .11499 .31104 Mtetra
.11499 .31104 .11922 .31502 .12499 .31287 .12077 .30888 Mtetra
.12077 .30888 .12499 .31287 .13077 .31071 .12656 .30671 Mtetra
.12656 .30671 .13077 .31071 .13657 .30854 .13236 .30453 Mtetra
.13236 .30453 .13657 .30854 .14238 .30637 .13818 .30235 Mtetra
.13818 .30235 .14238 .30637 .1482 .3042 .14401 .30017 Mtetra
.14401 .30017 .1482 .3042 .15404 .30202 .14986 .29798 Mtetra
.663 .741 .908 r
.14986 .29798 .15404 .30202 .15989 .29985 .15571 .29579 Mtetra
.663 .74 .908 r
.15571 .29579 .15989 .29985 .16575 .29769 .16158 .2936 Mtetra
.661 .739 .908 r
.16158 .2936 .16575 .29769 .17162 .29555 .16746 .29143 Mtetra
.659 .737 .907 r
.16746 .29143 .17162 .29555 .17749 .29355 .17335 .28929 Mtetra
.65 .728 .906 r
.17335 .28929 .17749 .29355 .18332 .29196 .17924 .28727 Mtetra
.621 .697 .899 r
.17924 .28727 .18332 .29196 .18907 .29133 .1851 .28566 Mtetra
.557 .627 .877 r
.1851 .28566 .18907 .29133 .19465 .29243 .19088 .28495 Mtetra
.451 .506 .824 r
.19088 .28495 .19465 .29243 .19994 .29666 .19651 .28581 Mtetra
.299 .326 .722 r
.19651 .28581 .19994 .29666 .20467 .30662 .20187 .28949 Mtetra
.127 .122 .582 r
.20187 .28949 .20467 .30662 .20857 .32544 .20674 .29837 Mtetra
.009 0 .468 r
.20674 .29837 .20857 .32544 .21159 .35412 .21086 .31524 Mtetra
0 0 .412 r
.21086 .31524 .21159 .35412 .21406 .38991 .21422 .34081 Mtetra
0 0 .392 r
.21422 .34081 .21406 .38991 .21651 .4274 .21702 .37333 Mtetra
0 0 .38 r
.21702 .37333 .21651 .4274 .21985 .45719 .21957 .40997 Mtetra
0 0 .379 r
.21957 .40997 .21985 .45719 .22547 .4634 .2226 .44329 Mtetra
0 0 .481 r
.2226 .44329 .22547 .4634 .23426 .43466 .22747 .45791 Mtetra
0 0 .161 r
.22747 .45791 .23426 .43466 .24525 .37963 .23507 .44264 Mtetra
.01 0 .273 r
.23507 .44264 .24525 .37963 .25653 .31917 .24485 .40193 Mtetra
0 0 .281 r
.24485 .40193 .25653 .31917 .26638 .27327 .25574 .34656 Mtetra
0 0 .234 r
.25574 .34656 .26638 .27327 .27348 .25922 .26644 .29124 Mtetra
0 0 0 r
.26644 .29124 .27348 .25922 .27776 .28007 .27528 .25645 Mtetra
.593 .421 .618 r
.27528 .25645 .27776 .28007 .28064 .32039 .28156 .2527 Mtetra
.279 .125 .486 r
.28156 .2527 .28064 .32039 .28401 .35656 .2856 .27794 Mtetra
.175 .042 .448 r
.2856 .27794 .28401 .35656 .29019 .35695 .28877 .3165 Mtetra
.267 .142 .519 r
.28877 .3165 .29019 .35695 .29936 .31606 .29377 .33244 Mtetra
0 0 0 r
.29377 .33244 .29936 .31606 .30847 .27401 .30139 .31273 Mtetra
0 0 .226 r
.30139 .31273 .30847 .27401 .31568 .25788 .30951 .28509 Mtetra
.312 .04 .331 r
.30951 .28509 .31568 .25788 .32186 .25674 .31627 .27641 Mtetra
.464 .15 .347 r
.31627 .27641 .32186 .25674 .32863 .2467 .32251 .27551 Mtetra
0 0 .201 r
.32251 .27551 .32863 .2467 .33512 .24098 .33002 .25487 Mtetra
.083 0 .127 r
.33002 .25487 .33512 .24098 .34094 .2463 .33672 .24657 Mtetra
.051 0 0 r
.33672 .24657 .34094 .2463 .34758 .2385 .34291 .24662 Mtetra
.685 .825 .385 r
.34291 .24662 .34758 .2385 .3535 .24312 .34987 .23354 Mtetra
.392 .419 .769 r
.34987 .23354 .3535 .24312 .35981 .24155 .35597 .23578 Mtetra
.806 .723 .773 r
.35597 .23578 .35981 .24155 .36621 .2386 .36259 .2287 Mtetra
.573 .521 .758 r
.36259 .2287 .36621 .2386 .37231 .24174 .3689 .22762 Mtetra
.611 .487 .687 r
.3689 .22762 .37231 .24174 .37889 .23582 .37532 .22477 Mtetra
.626 .533 .728 r
.37532 .22477 .37889 .23582 .38508 .23814 .38174 .22202 Mtetra
.576 .448 .669 r
.38174 .22202 .38508 .23814 .39163 .23332 .38814 .22021 Mtetra
.612 .498 .7 r
.38814 .22021 .39163 .23332 .398 .23283 .3946 .21749 Mtetra
.594 .467 .676 r
.3946 .21749 .398 .23283 .40449 .23 .40105 .21506 Mtetra
.586 .464 .681 r
.40105 .21506 .40449 .23 .41101 .22653 .40751 .21303 Mtetra
.621 .5 .694 r
.40751 .21303 .41101 .22653 .41745 .22581 .41402 .20988 Mtetra
.576 .45 .672 r
.41402 .20988 .41745 .22581 .4241 .21928 .4205 .20808 Mtetra
.611 .523 .73 r
.4205 .20808 .4241 .21928 .43052 .22006 .42702 .20575 Mtetra
.618 .491 .685 r
.42702 .20575 .43052 .22006 .43722 .21215 .43358 .2025 Mtetra
.425 .441 .773 r
.43358 .2025 .43722 .21215 .44375 .21058 .44001 .20431 Mtetra
.79 .712 .778 r
.44001 .20431 .44375 .21058 .45035 .20687 .44669 .19768 Mtetra
0 .081 .634 r
.44669 .19768 .45035 .20687 .45708 .19789 .45301 .20597 Mtetra
.084 0 0 r
.45301 .20597 .45708 .19789 .46355 .20075 .45969 .20085 Mtetra
.576 .002 0 r
.45969 .20085 .46355 .20075 .4703 .19046 .46619 .20506 Mtetra
.741 .391 .388 r
.46619 .20506 .4703 .19046 .47685 .19198 .47253 .22095 Mtetra
.422 .14 .379 r
.47253 .22095 .47685 .19198 .48338 .19707 .47928 .21641 Mtetra
.576 .247 .375 r
.47928 .21641 .48338 .19707 .49006 .19327 .48592 .22124 Mtetra
.723 .404 .439 r
.48592 .22124 .49006 .19327 .4966 .20595 .4924 .2449 Mtetra
.623 .326 .446 r
.4924 .2449 .4966 .20595 .50304 .24429 .4991 .25883 Mtetra
0 0 0 r
.4991 .25883 .50304 .24429 .50968 .28004 .50611 .23669 Mtetra
.781 .528 .553 r
.50611 .23669 .50968 .28004 .51663 .27344 .51314 .1927 Mtetra
.65 .41 .542 r
.51314 .1927 .51663 .27344 .5236 .23099 .51997 .16306 Mtetra
.518 .313 .542 r
.51997 .16306 .5236 .23099 .5304 .18547 .52672 .16318 Mtetra
0 0 .283 r
.52672 .16318 .5304 .18547 .5371 .1606 .53358 .19468 Mtetra
.807 .488 .45 r
.53358 .19468 .5371 .1606 .54394 .17142 .54072 .24679 Mtetra
.702 .411 .479 r
.54072 .24679 .54394 .17142 .55114 .21438 .54813 .29833 Mtetra
.646 .365 .479 r
.54813 .29833 .55114 .21438 .55873 .27147 .55564 .33429 Mtetra
.564 .29 .459 r
.55564 .33429 .55873 .27147 .56652 .32235 .56305 .34419 Mtetra
0 0 .17 r
.56305 .34419 .56652 .32235 .57415 .34609 .57009 .32371 Mtetra
.861 .611 .559 r
.57009 .32371 .57415 .34609 .58128 .33399 .57675 .28425 Mtetra
.758 .504 .549 r
.57675 .28425 .58128 .33399 .5879 .29788 .58319 .24174 Mtetra
.725 .475 .548 r
.58319 .24174 .5879 .29788 .59422 .25437 .58957 .20383 Mtetra
.711 .467 .554 r
.58957 .20383 .59422 .25437 .60042 .21308 .59597 .17313 Mtetra
.699 .466 .568 r
.59597 .17313 .60042 .21308 .60666 .1792 .60249 .15126 Mtetra
.689 .477 .595 r
.60249 .15126 .60666 .1792 .61306 .15535 .60916 .13746 Mtetra
.688 .512 .644 r
.60916 .13746 .61306 .15535 .61967 .14049 .61596 .12895 Mtetra
.695 .571 .712 r
.61596 .12895 .61967 .14049 .62644 .13143 .62284 .12326 Mtetra
.693 .632 .784 r
.62284 .12326 .62644 .13143 .63331 .12553 .62978 .11913 Mtetra
.682 .681 .843 r
.62978 .11913 .63331 .12553 .64025 .12135 .63677 .11589 Mtetra
.671 .715 .882 r
.63677 .11589 .64025 .12135 .64724 .11811 .64378 .11307 Mtetra
.666 .733 .9 r
.64378 .11307 .64724 .11811 .65426 .11528 .65082 .11037 Mtetra
.665 .739 .905 r
.65082 .11037 .65426 .11528 .6613 .11259 .65788 .10769 Mtetra
.664 .74 .907 r
.65788 .10769 .6613 .11259 .66837 .10993 .66496 .10503 Mtetra
.664 .741 .907 r
.66496 .10503 .66837 .10993 .67545 .10727 .67205 .10237 Mtetra
.664 .741 .908 r
.67205 .10237 .67545 .10727 .68255 .10461 .67916 .0997 Mtetra
.67916 .0997 .68255 .10461 .68967 .10196 .6863 .09703 Mtetra
.6863 .09703 .68967 .10196 .6968 .09929 .69344 .09435 Mtetra
.69344 .09435 .6968 .09929 .70396 .09662 .70061 .09167 Mtetra
.70061 .09167 .70396 .09662 .71113 .09394 .7078 .08898 Mtetra
.7078 .08898 .71113 .09394 .71832 .09125 .715 .08628 Mtetra
.715 .08628 .71832 .09125 .72553 .08856 .72222 .08357 Mtetra
.72222 .08357 .72553 .08856 .73276 .08586 .72946 .08086 Mtetra
.72946 .08086 .73276 .08586 .74 .08316 .73672 .07814 Mtetra
.09347 .31353 .09774 .3175 .10347 .31535 .09922 .31137 Mtetra
.09922 .31137 .10347 .31535 .10923 .3132 .10497 .30921 Mtetra
.10497 .30921 .10923 .3132 .11499 .31104 .11075 .30704 Mtetra
.11075 .30704 .11499 .31104 .12077 .30888 .11653 .30487 Mtetra
.11653 .30487 .12077 .30888 .12656 .30671 .12233 .30269 Mtetra
.12233 .30269 .12656 .30671 .13236 .30453 .12814 .3005 Mtetra
.12814 .3005 .13236 .30453 .13818 .30235 .13397 .29832 Mtetra
.13397 .29832 .13818 .30235 .14401 .30017 .1398 .29612 Mtetra
.1398 .29612 .14401 .30017 .14986 .29798 .14566 .29392 Mtetra
.14566 .29392 .14986 .29798 .15571 .29579 .15152 .29172 Mtetra
.663 .741 .908 r
.15152 .29172 .15571 .29579 .16158 .2936 .1574 .28952 Mtetra
.663 .74 .908 r
.1574 .28952 .16158 .2936 .16746 .29143 .16329 .28732 Mtetra
.661 .739 .908 r
.16329 .28732 .16746 .29143 .17335 .28929 .16919 .28513 Mtetra
.659 .737 .907 r
.16919 .28513 .17335 .28929 .17924 .28727 .1751 .28297 Mtetra
.651 .728 .905 r
.1751 .28297 .17924 .28727 .1851 .28566 .18102 .28093 Mtetra
.624 .698 .898 r
.18102 .28093 .1851 .28566 .19088 .28495 .1869 .27927 Mtetra
.567 .632 .876 r
.1869 .27927 .19088 .28495 .19651 .28581 .19271 .27842 Mtetra
.479 .525 .827 r
.19271 .27842 .19651 .28581 .20187 .28949 .1984 .2789 Mtetra
.349 .365 .735 r
.1984 .2789 .20187 .28949 .20674 .29837 .20387 .28182 Mtetra
.19 .173 .607 r
.20387 .28182 .20674 .29837 .21086 .31524 .20889 .28938 Mtetra
.081 .036 .501 r
.20889 .28938 .21086 .31524 .21422 .34081 .21328 .30385 Mtetra
.047 0 .447 r
.21328 .30385 .21422 .34081 .21702 .37333 .21702 .32568 Mtetra
.035 0 .421 r
.21702 .32568 .21702 .37333 .21957 .40997 .2202 .35439 Mtetra
.005 0 .399 r
.2202 .35439 .21957 .40997 .2226 .44329 .22293 .38946 Mtetra
0 0 .394 r
.22293 .38946 .2226 .44329 .22747 .45791 .2258 .42457 Mtetra
0 0 .447 r
.2258 .42457 .22747 .45791 .23507 .44264 .23006 .44602 Mtetra
.255 0 0 r
.23006 .44602 .23507 .44264 .24485 .40193 .23637 .44554 Mtetra
.144 0 .302 r
.23637 .44554 .24485 .40193 .25574 .34656 .24458 .42321 Mtetra
.084 0 .315 r
.24458 .42321 .25574 .34656 .26644 .29124 .25459 .37881 Mtetra
.019 0 .296 r
.25459 .37881 .26644 .29124 .27528 .25645 .26545 .32237 Mtetra
0 0 .241 r
.26545 .32237 .27528 .25645 .28156 .2527 .27547 .27401 Mtetra
0 0 0 r
.27547 .27401 .28156 .2527 .2856 .27794 .28374 .24575 Mtetra
.521 .346 .585 r
.28374 .24575 .2856 .27794 .28877 .3165 .28975 .24583 Mtetra
.314 .151 .494 r
.28975 .24583 .28877 .3165 .29377 .33244 .29406 .26897 Mtetra
.35 .183 .509 r
.29406 .26897 .29377 .33244 .30139 .31273 .29887 .28686 Mtetra
.577 .404 .61 r
.29887 .28686 .30139 .31273 .30951 .28509 .30526 .28372 Mtetra
.903 .889 .808 r
.30526 .28372 .30951 .28509 .31627 .27641 .31202 .27536 Mtetra
.815 .335 .053 r
.31202 .27536 .31627 .27641 .32251 .27551 .31761 .28442 Mtetra
.335 0 .135 r
.31761 .28442 .32251 .27551 .33002 .25487 .32396 .28254 Mtetra
0 0 .177 r
.32396 .28254 .33002 .25487 .33672 .24657 .33152 .26171 Mtetra
.588 .245 .356 r
.33152 .26171 .33672 .24657 .34291 .24662 .33748 .26633 Mtetra
.168 0 .23 r
.33748 .26633 .34291 .24662 .34987 .23354 .34434 .25642 Mtetra
.217 0 .273 r
.34434 .25642 .34987 .23354 .35597 .23578 .35119 .24618 Mtetra
.512 .133 .259 r
.35119 .24618 .35597 .23578 .36259 .2287 .35739 .24767 Mtetra
.06 0 .181 r
.35739 .24767 .36259 .2287 .3689 .22762 .36433 .23562 Mtetra
.498 .089 .195 r
.36433 .23562 .3689 .22762 .37532 .22477 .37058 .23694 Mtetra
.062 0 .089 r
.37058 .23694 .37532 .22477 .38174 .22202 .37729 .22922 Mtetra
.371 0 .1 r
.37729 .22922 .38174 .22202 .38814 .22021 .38367 .2284 Mtetra
.15 0 .025 r
.38367 .2284 .38814 .22021 .3946 .21749 .39023 .22422 Mtetra
.273 0 .029 r
.39023 .22422 .3946 .21749 .40105 .21506 .3967 .22225 Mtetra
.324 0 .075 r
.3967 .22225 .40105 .21506 .40751 .21303 .40316 .22075 Mtetra
.22 0 .043 r
.40316 .22075 .40751 .21303 .41402 .20988 .40971 .21763 Mtetra
.528 .113 .199 r
.40971 .21763 .41402 .20988 .4205 .20808 .41609 .21971 Mtetra
.203 0 .146 r
.41609 .21971 .4205 .20808 .42702 .20575 .42275 .21432 Mtetra
.666 .271 .287 r
.42275 .21432 .42702 .20575 .43358 .2025 .42903 .22113 Mtetra
.305 .006 .282 r
.42903 .22113 .43358 .2025 .44001 .20431 .43575 .21491 Mtetra
.631 .252 .307 r
.43575 .21491 .44001 .20431 .44669 .19768 .44214 .22081 Mtetra
.563 .248 .392 r
.44214 .22081 .44669 .19768 .45301 .20597 .44862 .22528 Mtetra
.221 0 .258 r
.44862 .22528 .45301 .20597 .45969 .20085 .45545 .21629 Mtetra
.74 .393 .393 r
.45545 .21629 .45969 .20085 .46619 .20506 .46174 .23274 Mtetra
.428 .142 .374 r
.46174 .23274 .46619 .20506 .47253 .22095 .46851 .22893 Mtetra
.635 .777 .32 r
.46851 .22893 .47253 .22095 .47928 .21641 .47545 .21511 Mtetra
.492 0 0 r
.47545 .21511 .47928 .21641 .48592 .22124 .4821 .21937 Mtetra
.614 .888 .989 r
.4821 .21937 .48592 .22124 .4924 .2449 .48888 .21692 Mtetra
.759 .529 .584 r
.48888 .21692 .4924 .2449 .4991 .25883 .49588 .19321 Mtetra
.666 .427 .549 r
.49588 .19321 .4991 .25883 .50611 .23669 .50283 .16543 Mtetra
.541 .329 .541 r
.50283 .16543 .50611 .23669 .51314 .1927 .50956 .16158 Mtetra
0 0 .472 r
.50956 .16158 .51314 .1927 .51997 .16306 .51622 .18635 Mtetra
.831 .502 .431 r
.51622 .18635 .51997 .16306 .52672 .16318 .52301 .23109 Mtetra
.719 .424 .477 r
.52301 .23109 .52672 .16318 .53358 .19468 .53004 .28379 Mtetra
.652 .371 .481 r
.53004 .28379 .53358 .19468 .54072 .24679 .5373 .32391 Mtetra
.586 .313 .469 r
.5373 .32391 .54072 .24679 .54813 .29833 .54462 .34102 Mtetra
.445 .177 .413 r
.54462 .34102 .54813 .29833 .55564 .33429 .55186 .33581 Mtetra
.999 .837 .537 r
.55186 .33581 .55564 .33429 .56305 .34419 .55887 .30857 Mtetra
.802 .549 .555 r
.55887 .30857 .56305 .34419 .57009 .32371 .5656 .26758 Mtetra
.735 .483 .547 r
.5656 .26758 .57009 .32371 .57675 .28425 .57218 .2268 Mtetra
.707 .461 .549 r
.57218 .2268 .57675 .28425 .58319 .24174 .57871 .19278 Mtetra
.698 .458 .557 r
.57871 .19278 .58319 .24174 .58957 .20383 .58526 .1659 Mtetra
.691 .462 .572 r
.58526 .1659 .58957 .20383 .59597 .17313 .59188 .14646 Mtetra
.682 .476 .6 r
.59188 .14646 .59597 .17313 .60249 .15126 .59862 .13398 Mtetra
.682 .512 .65 r
.59862 .13398 .60249 .15126 .60916 .13746 .60545 .1262 Mtetra
.69 .573 .718 r
.60545 .1262 .60916 .13746 .61596 .12895 .61235 .12087 Mtetra
.69 .634 .788 r
.61235 .12087 .61596 .12895 .62284 .12326 .61929 .11687 Mtetra
.68 .681 .844 r
.61929 .11687 .62284 .12326 .62978 .11913 .62627 .11366 Mtetra
.67 .715 .882 r
.62627 .11366 .62978 .11913 .63677 .11589 .63329 .11084 Mtetra
.666 .733 .899 r
.63329 .11084 .63677 .11589 .64378 .11307 .64032 .10813 Mtetra
.665 .739 .905 r
.64032 .10813 .64378 .11307 .65082 .11037 .64737 .10545 Mtetra
.664 .74 .906 r
.64737 .10545 .65082 .11037 .65788 .10769 .65444 .10278 Mtetra
.664 .741 .907 r
.65444 .10278 .65788 .10769 .66496 .10503 .66153 .10011 Mtetra
.663 .741 .908 r
.66153 .10011 .66496 .10503 .67205 .10237 .66864 .09744 Mtetra
.664 .741 .908 r
.66864 .09744 .67205 .10237 .67916 .0997 .67576 .09477 Mtetra
.67576 .09477 .67916 .0997 .6863 .09703 .68291 .09208 Mtetra
.68291 .09208 .6863 .09703 .69344 .09435 .69007 .08939 Mtetra
.69007 .08939 .69344 .09435 .70061 .09167 .69725 .08669 Mtetra
.69725 .08669 .70061 .09167 .7078 .08898 .70444 .08399 Mtetra
.70444 .08399 .7078 .08898 .715 .08628 .71166 .08128 Mtetra
.71166 .08128 .715 .08628 .72222 .08357 .71889 .07856 Mtetra
.71889 .07856 .72222 .08357 .72946 .08086 .72615 .07584 Mtetra
.72615 .07584 .72946 .08086 .73672 .07814 .73342 .0731 Mtetra
.08919 .30954 .09347 .31353 .09922 .31137 .09494 .30737 Mtetra
.09494 .30737 .09922 .31137 .10497 .30921 .1007 .3052 Mtetra
.1007 .3052 .10497 .30921 .11075 .30704 .10648 .30302 Mtetra
.10648 .30302 .11075 .30704 .11653 .30487 .11228 .30084 Mtetra
.11228 .30084 .11653 .30487 .12233 .30269 .11808 .29865 Mtetra
.11808 .29865 .12233 .30269 .12814 .3005 .1239 .29646 Mtetra
.1239 .29646 .12814 .3005 .13397 .29832 .12973 .29426 Mtetra
.12973 .29426 .13397 .29832 .1398 .29612 .13558 .29206 Mtetra
.13558 .29206 .1398 .29612 .14566 .29392 .14144 .28985 Mtetra
.14144 .28985 .14566 .29392 .15152 .29172 .14731 .28764 Mtetra
.14731 .28764 .15152 .29172 .1574 .28952 .1532 .28542 Mtetra
.663 .741 .908 r
.1532 .28542 .1574 .28952 .16329 .28732 .1591 .2832 Mtetra
.663 .74 .908 r
.1591 .2832 .16329 .28732 .16919 .28513 .16501 .28099 Mtetra
.661 .739 .907 r
.16501 .28099 .16919 .28513 .1751 .28297 .17093 .27879 Mtetra
.66 .737 .907 r
.17093 .27879 .1751 .28297 .18102 .28093 .17687 .2766 Mtetra
.652 .728 .905 r
.17687 .2766 .18102 .28093 .1869 .27927 .1828 .27453 Mtetra
.627 .7 .897 r
.1828 .27453 .1869 .27927 .19271 .27842 .18871 .27281 Mtetra
.581 .642 .876 r
.18871 .27281 .19271 .27842 .1984 .2789 .19457 .27175 Mtetra
.511 .551 .833 r
.19457 .27175 .1984 .2789 .20387 .28182 .20033 .27176 Mtetra
.399 .408 .753 r
.20033 .27176 .20387 .28182 .20889 .28938 .2059 .27383 Mtetra
.252 .227 .635 r
.2059 .27383 .20889 .28938 .21328 .30385 .2111 .27991 Mtetra
.156 .099 .536 r
.2111 .27991 .21328 .30385 .21702 .32568 .21578 .29162 Mtetra
.125 .043 .484 r
.21578 .29162 .21702 .32568 .2202 .35439 .21994 .3093 Mtetra
.097 .003 .449 r
.21994 .3093 .2202 .35439 .22293 .38946 .22354 .33391 Mtetra
.058 0 .42 r
.22354 .33391 .22293 .38946 .2258 .42457 .22653 .36624 Mtetra
.057 0 .418 r
.22653 .36624 .2258 .42457 .23006 .44602 .2295 .40036 Mtetra
.078 0 .445 r
.2295 .40036 .23006 .44602 .23637 .44554 .23335 .42636 Mtetra
0 0 .491 r
.23335 .42636 .23637 .44554 .24458 .42321 .23839 .44034 Mtetra
.375 .05 .28 r
.23839 .44034 .24458 .42321 .25459 .37881 .24498 .4371 Mtetra
.172 0 .334 r
.24498 .4371 .25459 .37881 .26545 .32237 .25368 .40882 Mtetra
.137 0 .342 r
.25368 .40882 .26545 .32237 .27547 .27401 .26372 .3632 Mtetra
.092 0 .327 r
.26372 .3632 .27547 .27401 .28374 .24575 .27406 .31192 Mtetra
0 0 .237 r
.27406 .31192 .28374 .24575 .28975 .24583 .28407 .26257 Mtetra
.817 .805 .316 r
.28407 .26257 .28975 .24583 .29406 .26897 .29228 .23463 Mtetra
.517 .339 .579 r
.29228 .23463 .29406 .26897 .29887 .28686 .29832 .2349 Mtetra
.421 .245 .535 r
.29832 .2349 .29887 .28686 .30526 .28372 .30374 .24403 Mtetra
.508 .325 .567 r
.30374 .24403 .30526 .28372 .31202 .27536 .30979 .24496 Mtetra
.44 .29 .58 r
.30979 .24496 .31202 .27536 .31761 .28442 .31562 .24958 Mtetra
.22 .117 .519 r
.31562 .24958 .31761 .28442 .32396 .28254 .32077 .26527 Mtetra
.672 .505 .651 r
.32077 .26527 .32396 .28254 .33152 .26171 .32745 .25829 Mtetra
.585 .772 .969 r
.32745 .25829 .33152 .26171 .33748 .26633 .33379 .25682 Mtetra
0 .027 .595 r
.33379 .25682 .33748 .26633 .34434 .25642 .33955 .26522 Mtetra
.689 .817 .369 r
.33955 .26522 .34434 .25642 .35119 .24618 .34668 .25115 Mtetra
.679 .242 .205 r
.34668 .25115 .35119 .24618 .35739 .24767 .35265 .25708 Mtetra
0 0 0 r
.35265 .25708 .35739 .24767 .36433 .23562 .35942 .24913 Mtetra
.4 .054 .258 r
.35942 .24913 .36433 .23562 .37058 .23694 .36587 .24727 Mtetra
.318 0 .163 r
.36587 .24727 .37058 .23694 .37729 .22922 .37238 .24458 Mtetra
.339 .013 .257 r
.37238 .24458 .37729 .22922 .38367 .2284 .37896 .24063 Mtetra
.383 .026 .23 r
.37896 .24063 .38367 .2284 .39023 .22422 .38546 .23864 Mtetra
.389 .051 .266 r
.38546 .23864 .39023 .22422 .3967 .22225 .392 .23625 Mtetra
.364 .025 .25 r
.392 .23625 .3967 .22225 .40316 .22075 .39857 .23332 Mtetra
.441 .083 .26 r
.39857 .23332 .40316 .22075 .40971 .21763 .40507 .2327 Mtetra
.387 .054 .273 r
.40507 .2327 .40971 .21763 .41609 .21971 .41166 .23008 Mtetra
.347 0 .178 r
.41166 .23008 .41609 .21971 .42275 .21432 .41826 .22786 Mtetra
.531 .175 .308 r
.41826 .22786 .42275 .21432 .42903 .22113 .42473 .23008 Mtetra
0 0 0 r
.42473 .23008 .42903 .22113 .43575 .21491 .4316 .22014 Mtetra
.738 .311 .237 r
.4316 .22014 .43575 .21491 .44214 .22081 .43793 .22895 Mtetra
0 0 0 r
.43793 .22895 .44214 .22081 .44862 .22528 .44491 .21545 Mtetra
.635 .563 .756 r
.44491 .21545 .44862 .22528 .45545 .21629 .4516 .21266 Mtetra
.176 .553 .931 r
.4516 .21266 .45545 .21629 .46174 .23274 .4582 .21431 Mtetra
.802 .584 .607 r
.4582 .21431 .46174 .23274 .46851 .22893 .46529 .19332 Mtetra
.619 .414 .582 r
.46529 .19332 .46851 .22893 .47545 .21511 .4721 .18431 Mtetra
.6 .408 .594 r
.4721 .18431 .47545 .21511 .4821 .21937 .47886 .17831 Mtetra
.647 .428 .572 r
.47886 .17831 .4821 .21937 .48888 .21692 .48572 .164 Mtetra
.553 .347 .555 r
.48572 .164 .48888 .21692 .49588 .19321 .49244 .15965 Mtetra
.033 0 .479 r
.49244 .15965 .49588 .19321 .50283 .16543 .49892 .1841 Mtetra
.855 .522 .421 r
.49892 .1841 .50283 .16543 .50956 .16158 .5054 .2299 Mtetra
.703 .41 .477 r
.5054 .2299 .50956 .16158 .51622 .18635 .51211 .27706 Mtetra
.652 .372 .481 r
.51211 .27706 .51622 .18635 .52301 .23109 .51907 .31818 Mtetra
.602 .328 .475 r
.51907 .31818 .52301 .23109 .53004 .28379 .52624 .34173 Mtetra
.485 .222 .439 r
.52624 .34173 .53004 .28379 .5373 .32391 .53348 .33952 Mtetra
0 0 0 r
.53348 .33952 .5373 .32391 .54462 .34102 .54066 .31967 Mtetra
.839 .6 .577 r
.54066 .31967 .54462 .34102 .55186 .33581 .54768 .28795 Mtetra
.754 .503 .552 r
.54768 .28795 .55186 .33581 .55887 .30857 .55451 .24823 Mtetra
.715 .465 .547 r
.55451 .24823 .55887 .30857 .5656 .26758 .56121 .21039 Mtetra
.691 .448 .551 r
.56121 .21039 .5656 .26758 .57218 .2268 .56788 .18055 Mtetra
.684 .449 .561 r
.56788 .18055 .57218 .2268 .57871 .19278 .57456 .15788 Mtetra
.683 .46 .578 r
.57456 .15788 .57871 .19278 .58526 .1659 .58127 .14122 Mtetra
.677 .478 .608 r
.58127 .14122 .58526 .1659 .59188 .14646 .58806 .13021 Mtetra
.677 .515 .66 r
.58806 .13021 .59188 .14646 .59862 .13398 .59492 .12326 Mtetra
.684 .578 .73 r
.59492 .12326 .59862 .13398 .60545 .1262 .60183 .11839 Mtetra
.687 .639 .796 r
.60183 .11839 .60545 .1262 .61235 .12087 .60878 .11456 Mtetra
.679 .684 .848 r
.60878 .11456 .61235 .12087 .61929 .11687 .61576 .1114 Mtetra
.67 .715 .883 r
.61576 .1114 .61929 .11687 .62627 .11366 .62276 .10859 Mtetra
.666 .733 .9 r
.62276 .10859 .62627 .11366 .63329 .11084 .62979 .10589 Mtetra
.665 .739 .905 r
.62979 .10589 .63329 .11084 .64032 .10813 .63684 .1032 Mtetra
.664 .74 .906 r
.63684 .1032 .64032 .10813 .64737 .10545 .6439 .10052 Mtetra
.664 .741 .907 r
.6439 .10052 .64737 .10545 .65444 .10278 .65099 .09785 Mtetra
.663 .741 .908 r
.65099 .09785 .65444 .10278 .66153 .10011 .65809 .09518 Mtetra
.664 .741 .908 r
.65809 .09518 .66153 .10011 .66864 .09744 .66521 .0925 Mtetra
.66521 .0925 .66864 .09744 .67576 .09477 .67235 .08981 Mtetra
.67235 .08981 .67576 .09477 .68291 .09208 .6795 .08711 Mtetra
.6795 .08711 .68291 .09208 .69007 .08939 .68667 .08441 Mtetra
.68667 .08441 .69007 .08939 .69725 .08669 .69387 .0817 Mtetra
.69387 .0817 .69725 .08669 .70444 .08399 .70108 .07898 Mtetra
.70108 .07898 .70444 .08399 .71166 .08128 .7083 .07626 Mtetra
.7083 .07626 .71166 .08128 .71889 .07856 .71555 .07353 Mtetra
.71555 .07353 .71889 .07856 .72615 .07584 .72282 .07079 Mtetra
.72282 .07079 .72615 .07584 .73342 .0731 .7301 .06804 Mtetra
.08488 .30554 .08919 .30954 .09494 .30737 .09064 .30336 Mtetra
.09064 .30336 .09494 .30737 .1007 .3052 .09642 .30118 Mtetra
.09642 .30118 .1007 .3052 .10648 .30302 .1022 .29899 Mtetra
.1022 .29899 .10648 .30302 .11228 .30084 .108 .2968 Mtetra
.108 .2968 .11228 .30084 .11808 .29865 .11382 .2946 Mtetra
.11382 .2946 .11808 .29865 .1239 .29646 .11964 .2924 Mtetra
.11964 .2924 .1239 .29646 .12973 .29426 .12548 .29019 Mtetra
.12548 .29019 .12973 .29426 .13558 .29206 .13134 .28798 Mtetra
.13134 .28798 .13558 .29206 .14144 .28985 .1372 .28576 Mtetra
.1372 .28576 .14144 .28985 .14731 .28764 .14308 .28354 Mtetra
.14308 .28354 .14731 .28764 .1532 .28542 .14898 .28131 Mtetra
.14898 .28131 .1532 .28542 .1591 .2832 .15488 .27908 Mtetra
.663 .741 .908 r
.15488 .27908 .1591 .2832 .16501 .28099 .1608 .27685 Mtetra
.663 .74 .908 r
.1608 .27685 .16501 .28099 .17093 .27879 .16674 .27462 Mtetra
.662 .739 .907 r
.16674 .27462 .17093 .27879 .17687 .2766 .17268 .2724 Mtetra
.66 .737 .907 r
.17268 .2724 .17687 .2766 .1828 .27453 .17864 .27019 Mtetra
.653 .729 .905 r
.17864 .27019 .1828 .27453 .18871 .27281 .1846 .26808 Mtetra
.632 .704 .897 r
.1846 .26808 .18871 .27281 .19457 .27175 .19054 .26627 Mtetra
.597 .656 .879 r
.19054 .26627 .19457 .27175 .20033 .27176 .19644 .26497 Mtetra
.544 .581 .842 r
.19644 .26497 .20033 .27176 .2059 .27383 .20228 .26447 Mtetra
.446 .453 .773 r
.20228 .26447 .2059 .27383 .2111 .27991 .20796 .26569 Mtetra
.314 .285 .666 r
.20796 .26569 .2111 .27991 .21578 .29162 .21333 .27023 Mtetra
.234 .169 .576 r
.21333 .27023 .21578 .29162 .21994 .3093 .21832 .27898 Mtetra
.199 .108 .52 r
.21832 .27898 .21994 .3093 .22354 .33391 .22291 .29248 Mtetra
.151 .049 .475 r
.22291 .29248 .22354 .33391 .22653 .36624 .22692 .31289 Mtetra
.118 .01 .444 r
.22692 .31289 .22653 .36624 .2295 .40036 .23032 .3409 Mtetra
.136 .02 .445 r
.23032 .3409 .2295 .40036 .23335 .42636 .23365 .37118 Mtetra
.135 .023 .451 r
.23365 .37118 .23335 .42636 .23839 .44034 .23729 .39947 Mtetra
.028 0 .437 r
.23729 .39947 .23839 .44034 .24498 .4371 .24134 .42464 Mtetra
0 0 .435 r
.24134 .42464 .24498 .4371 .25368 .40882 .24661 .43691 Mtetra
.335 .055 .331 r
.24661 .43691 .25368 .40882 .26372 .3632 .25361 .42935 Mtetra
.287 .059 .383 r
.25361 .42935 .26372 .3632 .27406 .31192 .26188 .40611 Mtetra
.176 0 .36 r
.26188 .40611 .27406 .31192 .28407 .26257 .27188 .36026 Mtetra
.018 0 .301 r
.27188 .36026 .28407 .26257 .29228 .23463 .28308 .29695 Mtetra
0 0 .22 r
.28308 .29695 .29228 .23463 .29832 .2349 .29292 .24873 Mtetra
0 0 0 r
.29292 .24873 .29832 .2349 .30374 .24403 .30039 .23027 Mtetra
.604 .485 .691 r
.30039 .23027 .30374 .24403 .30979 .24496 .30668 .22772 Mtetra
.642 .484 .653 r
.30668 .22772 .30979 .24496 .31562 .24958 .31317 .22252 Mtetra
.483 .33 .597 r
.31317 .22252 .31562 .24958 .32077 .26527 .31917 .22455 Mtetra
.437 .269 .554 r
.31917 .22455 .32077 .26527 .32745 .25829 .32493 .23071 Mtetra
.598 .413 .603 r
.32493 .23071 .32745 .25829 .33379 .25682 .33146 .2257 Mtetra
.346 .219 .561 r
.33146 .2257 .33379 .25682 .33955 .26522 .33711 .23485 Mtetra
.554 .375 .593 r
.33711 .23485 .33955 .26522 .34668 .25115 .34351 .23261 Mtetra
.533 .403 .649 r
.34351 .23261 .34668 .25115 .35265 .25708 .34981 .23225 Mtetra
.448 .314 .605 r
.34981 .23225 .35265 .25708 .35942 .24913 .35593 .23574 Mtetra
.676 .536 .687 r
.35593 .23574 .35942 .24913 .36587 .24727 .36256 .23015 Mtetra
.429 .342 .656 r
.36256 .23015 .36587 .24727 .37238 .24458 .36876 .23317 Mtetra
.683 .562 .713 r
.36876 .23317 .37238 .24458 .37896 .24063 .37539 .22813 Mtetra
.533 .458 .718 r
.37539 .22813 .37896 .24063 .38546 .23864 .3818 .22792 Mtetra
.632 .544 .737 r
.3818 .22792 .38546 .23864 .392 .23625 .38836 .22502 Mtetra
.653 .548 .724 r
.38836 .22502 .392 .23625 .39857 .23332 .39496 .22125 Mtetra
.548 .474 .724 r
.39496 .22125 .39857 .23332 .40507 .2327 .40145 .22063 Mtetra
.721 .577 .692 r
.40145 .22063 .40507 .2327 .41166 .23008 .40822 .21331 Mtetra
.512 .403 .666 r
.40822 .21331 .41166 .23008 .41826 .22786 .41471 .21374 Mtetra
.719 .557 .669 r
.41471 .21374 .41826 .22786 .42473 .23008 .42152 .20526 Mtetra
.592 .417 .614 r
.42152 .20526 .42473 .23008 .4316 .22014 .42819 .20115 Mtetra
.595 .444 .646 r
.42819 .20115 .4316 .22014 .43793 .22895 .43484 .19792 Mtetra
.675 .463 .59 r
.43484 .19792 .43793 .22895 .44491 .21545 .44179 .18424 Mtetra
.519 .348 .589 r
.44179 .18424 .44491 .21545 .4516 .21266 .44835 .18433 Mtetra
.665 .46 .598 r
.44835 .18433 .4516 .21266 .4582 .21431 .45522 .17299 Mtetra
.584 .38 .571 r
.45522 .17299 .4582 .21431 .46529 .19332 .46195 .16645 Mtetra
.516 .357 .604 r
.46195 .16645 .46529 .19332 .4721 .18431 .46856 .16678 Mtetra
.58 .442 .658 r
.46856 .16678 .4721 .18431 .47886 .17831 .47523 .16452 Mtetra
0 0 .473 r
.47523 .16452 .47886 .17831 .48572 .164 .48168 .1794 Mtetra
.869 .533 .413 r
.48168 .1794 .48572 .164 .49244 .15965 .48786 .22423 Mtetra
.742 .443 .477 r
.48786 .22423 .49244 .15965 .49892 .1841 .49413 .28358 Mtetra
.643 .365 .483 r
.49413 .28358 .49892 .1841 .5054 .2299 .50083 .32479 Mtetra
.576 .308 .474 r
.50083 .32479 .5054 .2299 .51211 .27706 .50787 .34275 Mtetra
.516 .25 .45 r
.50787 .34275 .51211 .27706 .51907 .31818 .51507 .34506 Mtetra
.096 0 .259 r
.51507 .34506 .51907 .31818 .52624 .34173 .52233 .32737 Mtetra
.886 .654 .582 r
.52233 .32737 .52624 .34173 .53348 .33952 .52952 .2964 Mtetra
.747 .501 .559 r
.52952 .2964 .53348 .33952 .54066 .31967 .53658 .26247 Mtetra
.714 .466 .549 r
.53658 .26247 .54066 .31967 .54768 .28795 .54351 .22684 Mtetra
.696 .45 .548 r
.54351 .22684 .54768 .28795 .55451 .24823 .55032 .19353 Mtetra
.677 .439 .553 r
.55032 .19353 .55451 .24823 .56121 .21039 .55709 .16795 Mtetra
.67 .442 .567 r
.55709 .16795 .56121 .21039 .56788 .18055 .56386 .14948 Mtetra
.674 .46 .588 r
.56386 .14948 .56788 .18055 .57456 .15788 .57065 .13581 Mtetra
.674 .484 .62 r
.57065 .13581 .57456 .15788 .58127 .14122 .57748 .12635 Mtetra
.673 .523 .674 r
.57748 .12635 .58127 .14122 .58806 .13021 .58436 .12021 Mtetra
.679 .587 .745 r
.58436 .12021 .58806 .13021 .59492 .12326 .59129 .11583 Mtetra
.684 .649 .809 r
.59129 .11583 .59492 .12326 .60183 .11839 .59824 .11223 Mtetra
.677 .69 .854 r
.59824 .11223 .60183 .11839 .60878 .11456 .60522 .10913 Mtetra
.669 .717 .885 r
.60522 .10913 .60878 .11456 .61576 .1114 .61222 .10633 Mtetra
.665 .733 .9 r
.61222 .10633 .61576 .1114 .62276 .10859 .61924 .10364 Mtetra
.665 .739 .905 r
.61924 .10364 .62276 .10859 .62979 .10589 .62629 .10095 Mtetra
.664 .74 .906 r
.62629 .10095 .62979 .10589 .63684 .1032 .63334 .09827 Mtetra
.664 .741 .907 r
.63334 .09827 .63684 .1032 .6439 .10052 .64042 .09559 Mtetra
.663 .741 .908 r
.64042 .09559 .6439 .10052 .65099 .09785 .64752 .09291 Mtetra
.664 .741 .908 r
.64752 .09291 .65099 .09785 .65809 .09518 .65463 .09022 Mtetra
.65463 .09022 .65809 .09518 .66521 .0925 .66176 .08752 Mtetra
.66176 .08752 .66521 .0925 .67235 .08981 .66891 .08482 Mtetra
.66891 .08482 .67235 .08981 .6795 .08711 .67608 .08211 Mtetra
.67608 .08211 .6795 .08711 .68667 .08441 .68327 .0794 Mtetra
.68327 .0794 .68667 .08441 .69387 .0817 .69047 .07668 Mtetra
.69047 .07668 .69387 .0817 .70108 .07898 .69769 .07395 Mtetra
.69769 .07395 .70108 .07898 .7083 .07626 .70493 .07121 Mtetra
.70493 .07121 .7083 .07626 .71555 .07353 .71219 .06847 Mtetra
.71219 .06847 .71555 .07353 .72282 .07079 .71947 .06571 Mtetra
.71947 .06571 .72282 .07079 .7301 .06804 .72677 .06296 Mtetra
.08056 .30151 .08488 .30554 .09064 .30336 .08633 .29933 Mtetra
.08633 .29933 .09064 .30336 .09642 .30118 .09211 .29714 Mtetra
.09211 .29714 .09642 .30118 .1022 .29899 .0979 .29494 Mtetra
.0979 .29494 .1022 .29899 .108 .2968 .10371 .29274 Mtetra
.10371 .29274 .108 .2968 .11382 .2946 .10953 .29053 Mtetra
.10953 .29053 .11382 .2946 .11964 .2924 .11537 .28832 Mtetra
.11537 .28832 .11964 .2924 .12548 .29019 .12121 .28611 Mtetra
.12121 .28611 .12548 .29019 .13134 .28798 .12707 .28388 Mtetra
.12707 .28388 .13134 .28798 .1372 .28576 .13295 .28166 Mtetra
.13295 .28166 .1372 .28576 .14308 .28354 .13884 .27943 Mtetra
.13884 .27943 .14308 .28354 .14898 .28131 .14474 .27719 Mtetra
.14474 .27719 .14898 .28131 .15488 .27908 .15065 .27495 Mtetra
.15065 .27495 .15488 .27908 .1608 .27685 .15658 .2727 Mtetra
.663 .741 .908 r
.15658 .2727 .1608 .27685 .16674 .27462 .16252 .27045 Mtetra
.663 .74 .908 r
.16252 .27045 .16674 .27462 .17268 .2724 .16848 .26821 Mtetra
.662 .739 .907 r
.16848 .26821 .17268 .2724 .17864 .27019 .17445 .26596 Mtetra
.661 .738 .907 r
.17445 .26596 .17864 .27019 .1846 .26808 .18043 .26373 Mtetra
.655 .73 .905 r
.18043 .26373 .1846 .26808 .19054 .26627 .18641 .26158 Mtetra
.638 .709 .898 r
.18641 .26158 .19054 .26627 .19644 .26497 .19238 .25968 Mtetra
.613 .672 .882 r
.19238 .25968 .19644 .26497 .20228 .26447 .19833 .25812 Mtetra
.574 .613 .853 r
.19833 .25812 .20228 .26447 .20796 .26569 .20424 .25714 Mtetra
.488 .499 .794 r
.20424 .25714 .20796 .26569 .21333 .27023 .21002 .25759 Mtetra
.379 .35 .701 r
.21002 .25759 .21333 .27023 .21832 .27898 .21557 .26056 Mtetra
.316 .247 .619 r
.21557 .26056 .21832 .27898 .22291 .29248 .22087 .26639 Mtetra
.266 .171 .557 r
.22087 .26639 .22291 .29248 .22692 .31289 .22584 .27613 Mtetra
.203 .096 .502 r
.22584 .27613 .22692 .31289 .23032 .3409 .23026 .29231 Mtetra
.189 .068 .475 r
.23026 .29231 .23032 .3409 .23365 .37118 .23422 .31439 Mtetra
.208 .076 .471 r
.23422 .31439 .23365 .37118 .23729 .39947 .23805 .33907 Mtetra
.177 .05 .458 r
.23805 .33907 .23729 .39947 .24134 .42464 .24168 .36736 Mtetra
.127 .016 .446 r
.24168 .36736 .24134 .42464 .24661 .43691 .24531 .39717 Mtetra
.082 .005 .461 r
.24531 .39717 .24661 .43691 .25361 .42935 .2497 .41974 Mtetra
.807 .454 0 r
.2497 .41974 .25361 .42935 .26188 .40611 .25472 .43614 Mtetra
.522 .224 .403 r
.25472 .43614 .26188 .40611 .27188 .36026 .26098 .43824 Mtetra
.179 0 .352 r
.26098 .43824 .27188 .36026 .28308 .29695 .27039 .40086 Mtetra
.042 0 .312 r
.27039 .40086 .28308 .29695 .29292 .24873 .28179 .33596 Mtetra
.051 0 .31 r
.28179 .33596 .29292 .24873 .30039 .23027 .29214 .28215 Mtetra
.203 0 .341 r
.29214 .28215 .30039 .23027 .30668 .22772 .30008 .25857 Mtetra
.291 .028 .331 r
.30008 .25857 .30668 .22772 .31317 .22252 .30702 .24816 Mtetra
0 0 .12 r
.30702 .24816 .31317 .22252 .31917 .22455 .31467 .22715 Mtetra
.795 .987 .733 r
.31467 .22715 .31917 .22455 .32493 .23071 .32136 .21972 Mtetra
.609 .524 .733 r
.32136 .21972 .32493 .23071 .33146 .2257 .3277 .21749 Mtetra
.774 .655 .732 r
.3277 .21749 .33146 .2257 .33711 .23485 .33439 .20995 Mtetra
.472 .33 .606 r
.33439 .20995 .33711 .23485 .34351 .23261 .34047 .21231 Mtetra
.629 .46 .634 r
.34047 .21231 .34351 .23261 .34981 .23225 .34704 .2069 Mtetra
.484 .337 .605 r
.34704 .2069 .34981 .23225 .35593 .23574 .35321 .20876 Mtetra
.576 .399 .605 r
.35321 .20876 .35593 .23574 .36256 .23015 .35969 .20534 Mtetra
.526 .369 .611 r
.35969 .20534 .36256 .23015 .36876 .23317 .36602 .2051 Mtetra
.559 .384 .6 r
.36602 .2051 .36876 .23317 .37539 .22813 .37248 .20267 Mtetra
.553 .386 .61 r
.37248 .20267 .37539 .22813 .3818 .22792 .37893 .2009 Mtetra
.564 .39 .604 r
.37893 .2009 .3818 .22792 .38836 .22502 .38544 .19825 Mtetra
.566 .392 .605 r
.38544 .19825 .38836 .22502 .39496 .22125 .39196 .19551 Mtetra
.57 .399 .61 r
.39196 .19551 .39496 .22125 .40145 .22063 .39851 .19259 Mtetra
.584 .402 .601 r
.39851 .19259 .40145 .22063 .40822 .21331 .40512 .18839 Mtetra
.556 .391 .613 r
.40512 .18839 .40822 .21331 .41471 .21374 .41166 .18643 Mtetra
.614 .426 .604 r
.41166 .18643 .41471 .21374 .42152 .20526 .41836 .18009 Mtetra
.517 .363 .61 r
.41836 .18009 .42152 .20526 .42819 .20115 .42485 .1803 Mtetra
.651 .473 .63 r
.42485 .1803 .42819 .20115 .43484 .19792 .4316 .17321 Mtetra
.465 .327 .609 r
.4316 .17321 .43484 .19792 .44179 .18424 .43805 .176 Mtetra
.649 .604 .79 r
.43805 .176 .44179 .18424 .44835 .18433 .4447 .17315 Mtetra
.364 .374 .737 r
.4447 .17315 .44835 .18433 .45522 .17299 .45121 .17628 Mtetra
.852 .444 .265 r
.45121 .17628 .45522 .17299 .46195 .16645 .45747 .19266 Mtetra
.566 .255 .4 r
.45747 .19266 .46195 .16645 .46856 .16678 .46405 .19794 Mtetra
.687 .373 .438 r
.46405 .19794 .46856 .16678 .47523 .16452 .47042 .21799 Mtetra
.745 .443 .471 r
.47042 .21799 .47523 .16452 .48168 .1794 .47642 .26876 Mtetra
.701 .413 .484 r
.47642 .26876 .48168 .1794 .48786 .22423 .48255 .32915 Mtetra
.612 .34 .48 r
.48255 .32915 .48786 .22423 .49413 .28358 .4893 .36117 Mtetra
.456 .205 .444 r
.4893 .36117 .49413 .28358 .50083 .32479 .49658 .35332 Mtetra
0 0 .226 r
.49658 .35332 .50083 .32479 .50787 .34275 .50395 .33126 Mtetra
.898 .677 .594 r
.50395 .33126 .50787 .34275 .51507 .34506 .51127 .30337 Mtetra
.757 .51 .559 r
.51127 .30337 .51507 .34506 .52233 .32737 .51851 .26809 Mtetra
.702 .456 .549 r
.51851 .26809 .52233 .32737 .52952 .2964 .52562 .23427 Mtetra
.68 .438 .548 r
.52562 .23427 .52952 .2964 .53658 .26247 .53261 .20437 Mtetra
.677 .437 .551 r
.53261 .20437 .53658 .26247 .54351 .22684 .53951 .17718 Mtetra
.667 .434 .558 r
.53951 .17718 .54351 .22684 .55032 .19353 .54636 .1559 Mtetra
.659 .439 .575 r
.54636 .1559 .55032 .19353 .55709 .16795 .55319 .14118 Mtetra
.664 .463 .602 r
.55319 .14118 .55709 .16795 .56386 .14948 .56004 .13044 Mtetra
.671 .495 .638 r
.56004 .13044 .56386 .14948 .57065 .13581 .5669 .12255 Mtetra
.671 .538 .693 r
.5669 .12255 .57065 .13581 .57748 .12635 .5738 .11716 Mtetra
.675 .601 .765 r
.5738 .11716 .57748 .12635 .58436 .12021 .58073 .11323 Mtetra
.679 .661 .825 r
.58073 .11323 .58436 .12021 .59129 .11583 .58768 .10987 Mtetra
.676 .697 .863 r
.58768 .10987 .59129 .11583 .59824 .11223 .59466 .10685 Mtetra
.668 .72 .887 r
.59466 .10685 .59824 .11223 .60522 .10913 .60165 .10407 Mtetra
.665 .733 .901 r
.60165 .10407 .60522 .10913 .61222 .10633 .60867 .10138 Mtetra
.664 .739 .906 r
.60867 .10138 .61222 .10633 .61924 .10364 .61571 .09869 Mtetra
.664 .74 .907 r
.61571 .09869 .61924 .10364 .62629 .10095 .62276 .096 Mtetra
.664 .741 .907 r
.62276 .096 .62629 .10095 .63334 .09827 .62983 .09332 Mtetra
.663 .741 .908 r
.62983 .09332 .63334 .09827 .64042 .09559 .63692 .09063 Mtetra
.664 .741 .908 r
.63692 .09063 .64042 .09559 .64752 .09291 .64403 .08794 Mtetra
.64403 .08794 .64752 .09291 .65463 .09022 .65116 .08524 Mtetra
.65116 .08524 .65463 .09022 .66176 .08752 .6583 .08253 Mtetra
.6583 .08253 .66176 .08752 .66891 .08482 .66546 .07982 Mtetra
.66546 .07982 .66891 .08482 .67608 .08211 .67264 .07709 Mtetra
.67264 .07709 .67608 .08211 .68327 .0794 .67984 .07437 Mtetra
.67984 .07437 .68327 .0794 .69047 .07668 .68706 .07163 Mtetra
.68706 .07163 .69047 .07668 .69769 .07395 .69429 .06889 Mtetra
.69429 .06889 .69769 .07395 .70493 .07121 .70155 .06614 Mtetra
.70155 .06614 .70493 .07121 .71219 .06847 .70882 .06338 Mtetra
.70882 .06338 .71219 .06847 .71947 .06571 .71611 .06062 Mtetra
.71611 .06062 .71947 .06571 .72677 .06296 .72342 .05785 Mtetra
.07622 .29747 .08056 .30151 .08633 .29933 .082 .29528 Mtetra
.082 .29528 .08633 .29933 .09211 .29714 .08779 .29308 Mtetra
.08779 .29308 .09211 .29714 .0979 .29494 .09359 .29087 Mtetra
.09359 .29087 .0979 .29494 .10371 .29274 .0994 .28866 Mtetra
.0994 .28866 .10371 .29274 .10953 .29053 .10523 .28645 Mtetra
.10523 .28645 .10953 .29053 .11537 .28832 .11107 .28423 Mtetra
.11107 .28423 .11537 .28832 .12121 .28611 .11693 .282 Mtetra
.11693 .282 .12121 .28611 .12707 .28388 .12279 .27977 Mtetra
.12279 .27977 .12707 .28388 .13295 .28166 .12868 .27753 Mtetra
.12868 .27753 .13295 .28166 .13884 .27943 .13457 .27529 Mtetra
.13457 .27529 .13884 .27943 .14474 .27719 .14048 .27305 Mtetra
.14048 .27305 .14474 .27719 .15065 .27495 .1464 .27079 Mtetra
.1464 .27079 .15065 .27495 .15658 .2727 .15234 .26854 Mtetra
.15234 .26854 .15658 .2727 .16252 .27045 .15829 .26627 Mtetra
.663 .741 .908 r
.15829 .26627 .16252 .27045 .16848 .26821 .16425 .26401 Mtetra
.663 .74 .908 r
.16425 .26401 .16848 .26821 .17445 .26596 .17023 .26175 Mtetra
.663 .74 .907 r
.17023 .26175 .17445 .26596 .18043 .26373 .17622 .25948 Mtetra
.662 .739 .907 r
.17622 .25948 .18043 .26373 .18641 .26158 .18222 .25722 Mtetra
.656 .732 .905 r
.18222 .25722 .18641 .26158 .19238 .25968 .18823 .25505 Mtetra
.644 .715 .899 r
.18823 .25505 .19238 .25968 .19833 .25812 .19424 .25304 Mtetra
.629 .689 .887 r
.19424 .25304 .19833 .25812 .20424 .25714 .20023 .25122 Mtetra
.599 .642 .865 r
.20023 .25122 .20424 .25714 .21002 .25759 .2062 .24985 Mtetra
.526 .543 .816 r
.2062 .24985 .21002 .25759 .21557 .26056 .21207 .24964 Mtetra
.447 .423 .739 r
.21207 .24964 .21557 .26056 .22087 .26639 .21779 .25107 Mtetra
.394 .329 .665 r
.21779 .25107 .22087 .26639 .22584 .27613 .22336 .25433 Mtetra
.322 .231 .595 r
.22336 .25433 .22584 .27613 .23026 .29231 .22864 .26101 Mtetra
.261 .152 .535 r
.22864 .26101 .23026 .29231 .23422 .31439 .23349 .27279 Mtetra
.267 .136 .51 r
.23349 .27279 .23422 .31439 .23805 .33907 .23808 .28815 Mtetra
.264 .123 .494 r
.23808 .28815 .23805 .33907 .24168 .36736 .24242 .30712 Mtetra
.224 .086 .473 r
.24242 .30712 .24168 .36736 .24531 .39717 .24632 .33221 Mtetra
.222 .081 .468 r
.24632 .33221 .24531 .39717 .2497 .41974 .25016 .35951 Mtetra
.147 .029 .45 r
.25016 .35951 .2497 .41974 .25472 .43614 .25388 .38966 Mtetra
0 0 .337 r
.25388 .38966 .25472 .43614 .26098 .43824 .25716 .42697 Mtetra
.785 .46 0 r
.25716 .42697 .26098 .43824 .27039 .40086 .26215 .44516 Mtetra
.034 0 .255 r
.26215 .44516 .27039 .40086 .28179 .33596 .27083 .41756 Mtetra
0 0 .28 r
.27083 .41756 .28179 .33596 .29214 .28215 .28147 .36315 Mtetra
.149 0 .343 r
.28147 .36315 .29214 .28215 .30008 .25857 .29098 .32142 Mtetra
.406 .156 .419 r
.29098 .32142 .30008 .25857 .30702 .24816 .29812 .31032 Mtetra
.269 .043 .375 r
.29812 .31032 .30702 .24816 .31467 .22715 .30611 .28695 Mtetra
.123 0 .32 r
.30611 .28695 .31467 .22715 .32136 .21972 .31467 .25425 Mtetra
.452 .171 .395 r
.31467 .25425 .32136 .21972 .3277 .21749 .32113 .25144 Mtetra
.164 0 .293 r
.32113 .25144 .3277 .21749 .33439 .20995 .32852 .23448 Mtetra
.213 0 .274 r
.32852 .23448 .33439 .20995 .34047 .21231 .33548 .22372 Mtetra
.319 0 .181 r
.33548 .22372 .34047 .21231 .34704 .2069 .34195 .22082 Mtetra
0 0 .044 r
.34195 .22082 .34704 .2069 .35321 .20876 .34889 .21005 Mtetra
.059 0 0 r
.34889 .21005 .35321 .20876 .35969 .20534 .35524 .20948 Mtetra
.577 .868 .553 r
.35524 .20948 .35969 .20534 .36602 .2051 .36195 .20247 Mtetra
.533 .806 .996 r
.36195 .20247 .36602 .2051 .37248 .20267 .36837 .20117 Mtetra
.75 .929 .948 r
.36837 .20117 .37248 .20267 .37893 .2009 .37494 .19719 Mtetra
.64 .779 .948 r
.37494 .19719 .37893 .2009 .38544 .19825 .38144 .19504 Mtetra
.578 .789 .979 r
.38144 .19504 .38544 .19825 .39196 .19551 .38792 .19351 Mtetra
.683 .893 .974 r
.38792 .19351 .39196 .19551 .39851 .19259 .39449 .19051 Mtetra
0 .508 .841 r
.39449 .19051 .39851 .19259 .40512 .18839 .40088 .19208 Mtetra
0 0 0 r
.40088 .19208 .40512 .18839 .41166 .18643 .40751 .1882 Mtetra
.684 .176 .023 r
.40751 .1882 .41166 .18643 .41836 .18009 .41381 .19392 Mtetra
.393 .047 .254 r
.41381 .19392 .41836 .18009 .42485 .1803 .42042 .19189 Mtetra
.634 .26 .316 r
.42042 .19189 .42485 .1803 .4316 .17321 .42678 .19832 Mtetra
.643 .323 .415 r
.42678 .19832 .4316 .17321 .43805 .176 .43303 .20998 Mtetra
.47 .185 .399 r
.43303 .20998 .43805 .176 .4447 .17315 .43974 .20836 Mtetra
.721 .41 .452 r
.43974 .20836 .4447 .17315 .45121 .17628 .44568 .23709 Mtetra
.608 .325 .463 r
.44568 .23709 .45121 .17628 .45747 .19266 .45203 .25508 Mtetra
.542 .27 .452 r
.45203 .25508 .45747 .19266 .46405 .19794 .45873 .26161 Mtetra
.687 .395 .473 r
.45873 .26161 .46405 .19794 .47042 .21799 .46487 .30052 Mtetra
.687 .399 .481 r
.46487 .30052 .47042 .21799 .47642 .26876 .47102 .35054 Mtetra
.598 .322 .47 r
.47102 .35054 .47642 .26876 .48255 .32915 .47785 .37195 Mtetra
.154 0 .322 r
.47785 .37195 .48255 .32915 .4893 .36117 .48538 .3477 Mtetra
.917 .673 .553 r
.48538 .3477 .4893 .36117 .49658 .35332 .49301 .30469 Mtetra
.736 .489 .555 r
.49301 .30469 .49658 .35332 .50395 .33126 .50042 .26927 Mtetra
.691 .447 .548 r
.50042 .26927 .50395 .33126 .51127 .30337 .50769 .23687 Mtetra
.674 .431 .546 r
.50769 .23687 .51127 .30337 .51851 .26809 .51482 .20649 Mtetra
.656 .419 .549 r
.51482 .20649 .51851 .26809 .52562 .23427 .52184 .18233 Mtetra
.657 .425 .556 r
.52184 .18233 .52562 .23427 .53261 .20437 .52878 .16196 Mtetra
.659 .434 .567 r
.52878 .16196 .53261 .20437 .53951 .17718 .53567 .14517 Mtetra
.652 .443 .587 r
.53567 .14517 .53951 .17718 .54636 .1559 .54255 .13349 Mtetra
.656 .47 .621 r
.54255 .13349 .54636 .1559 .55319 .14118 .54942 .1253 Mtetra
.669 .513 .664 r
.54942 .1253 .55319 .14118 .56004 .13044 .55631 .11894 Mtetra
.673 .56 .719 r
.55631 .11894 .56004 .13044 .5669 .12255 .56321 .1142 Mtetra
.672 .619 .787 r
.56321 .1142 .5669 .12255 .5738 .11716 .57015 .11063 Mtetra
.674 .675 .843 r
.57015 .11063 .5738 .11716 .58073 .11323 .5771 .10751 Mtetra
.673 .706 .872 r
.5771 .10751 .58073 .11323 .58768 .10987 .58407 .10457 Mtetra
.668 .723 .891 r
.58407 .10457 .58768 .10987 .59466 .10685 .59107 .1018 Mtetra
.664 .734 .902 r
.59107 .1018 .59466 .10685 .60165 .10407 .59808 .09911 Mtetra
.664 .739 .906 r
.59808 .09911 .60165 .10407 .60867 .10138 .60511 .09643 Mtetra
.664 .74 .907 r
.60511 .09643 .60867 .10138 .61571 .09869 .61216 .09374 Mtetra
.664 .741 .907 r
.61216 .09374 .61571 .09869 .62276 .096 .61922 .09105 Mtetra
.663 .741 .908 r
.61922 .09105 .62276 .096 .62983 .09332 .62631 .08835 Mtetra
.664 .741 .908 r
.62631 .08835 .62983 .09332 .63692 .09063 .63341 .08566 Mtetra
.63341 .08566 .63692 .09063 .64403 .08794 .64053 .08295 Mtetra
.64053 .08295 .64403 .08794 .65116 .08524 .64767 .08023 Mtetra
.64767 .08023 .65116 .08524 .6583 .08253 .65482 .07751 Mtetra
.65482 .07751 .6583 .08253 .66546 .07982 .662 .07479 Mtetra
.662 .07479 .66546 .07982 .67264 .07709 .66919 .07205 Mtetra
.66919 .07205 .67264 .07709 .67984 .07437 .6764 .06931 Mtetra
.6764 .06931 .67984 .07437 .68706 .07163 .68363 .06656 Mtetra
.68363 .06656 .68706 .07163 .69429 .06889 .69088 .06381 Mtetra
.69088 .06381 .69429 .06889 .70155 .06614 .69815 .06104 Mtetra
.69815 .06104 .70155 .06614 .70882 .06338 .70543 .05827 Mtetra
.70543 .05827 .70882 .06338 .71611 .06062 .71273 .0555 Mtetra
.71273 .0555 .71611 .06062 .72342 .05785 .72006 .05271 Mtetra
.07187 .29342 .07622 .29747 .082 .29528 .07765 .29121 Mtetra
.07765 .29121 .082 .29528 .08779 .29308 .08344 .289 Mtetra
.08344 .289 .08779 .29308 .09359 .29087 .08925 .28679 Mtetra
.08925 .28679 .09359 .29087 .0994 .28866 .09507 .28457 Mtetra
.09507 .28457 .0994 .28866 .10523 .28645 .10091 .28234 Mtetra
.10091 .28234 .10523 .28645 .11107 .28423 .10676 .28011 Mtetra
.10676 .28011 .11107 .28423 .11693 .282 .11262 .27788 Mtetra
.11262 .27788 .11693 .282 .12279 .27977 .1185 .27564 Mtetra
.1185 .27564 .12279 .27977 .12868 .27753 .12439 .27339 Mtetra
.12439 .27339 .12868 .27753 .13457 .27529 .13029 .27114 Mtetra
.13029 .27114 .13457 .27529 .14048 .27305 .13621 .26888 Mtetra
.13621 .26888 .14048 .27305 .1464 .27079 .14214 .26662 Mtetra
.14214 .26662 .1464 .27079 .15234 .26854 .14808 .26436 Mtetra
.14808 .26436 .15234 .26854 .15829 .26627 .15404 .26209 Mtetra
.15404 .26209 .15829 .26627 .16425 .26401 .16001 .25981 Mtetra
.663 .741 .908 r
.16001 .25981 .16425 .26401 .17023 .26175 .166 .25753 Mtetra
.166 .25753 .17023 .26175 .17622 .25948 .17199 .25525 Mtetra
.663 .74 .907 r
.17199 .25525 .17622 .25948 .18222 .25722 .17801 .25296 Mtetra
.662 .739 .907 r
.17801 .25296 .18222 .25722 .18823 .25505 .18403 .25068 Mtetra
.657 .733 .906 r
.18403 .25068 .18823 .25505 .19424 .25304 .19007 .24847 Mtetra
.65 .721 .901 r
.19007 .24847 .19424 .25304 .20023 .25122 .1961 .24635 Mtetra
.643 .705 .892 r
.1961 .24635 .20023 .25122 .2062 .24985 .20214 .24433 Mtetra
.617 .667 .875 r
.20214 .24433 .2062 .24985 .21207 .24964 .20816 .24268 Mtetra
.562 .588 .837 r
.20816 .24268 .21207 .24964 .21779 .25107 .21411 .24186 Mtetra
.514 .499 .777 r
.21411 .24186 .21779 .25107 .22336 .25433 .21999 .24192 Mtetra
.461 .409 .713 r
.21999 .24192 .22336 .25433 .22864 .26101 .22577 .24327 Mtetra
.374 .294 .637 r
.22577 .24327 .22864 .26101 .23349 .27279 .2313 .2475 Mtetra
.336 .226 .578 r
.2313 .2475 .23349 .27279 .23808 .28815 .23658 .25477 Mtetra
.34 .206 .548 r
.23658 .25477 .23808 .28815 .24242 .30712 .24173 .26412 Mtetra
.308 .165 .518 r
.24173 .26412 .24242 .30712 .24632 .33221 .24654 .27785 Mtetra
.296 .145 .499 r
.24654 .27785 .24632 .33221 .25016 .35951 .25105 .29595 Mtetra
.287 .131 .488 r
.25105 .29595 .25016 .35951 .25388 .38966 .25533 .31782 Mtetra
.139 .014 .436 r
.25533 .31782 .25388 .38966 .25716 .42697 .25851 .35417 Mtetra
.01 0 .389 r
.25851 .35417 .25716 .42697 .26215 .44516 .26107 .40006 Mtetra
.17 .063 .481 r
.26107 .40006 .26215 .44516 .27083 .41756 .26578 .42174 Mtetra
.983 .91 .625 r
.26578 .42174 .27083 .41756 .28147 .36315 .27372 .40327 Mtetra
0 0 .101 r
.27372 .40327 .28147 .36315 .29098 .32142 .283 .36656 Mtetra
.37 .111 .386 r
.283 .36656 .29098 .32142 .29812 .31032 .2902 .35644 Mtetra
.461 .19 .416 r
.2902 .35644 .29812 .31032 .30611 .28695 .29687 .35329 Mtetra
.069 0 .303 r
.29687 .35329 .30611 .28695 .31467 .25425 .30612 .31354 Mtetra
.4 .148 .413 r
.30612 .31354 .31467 .25425 .32113 .25144 .31328 .30261 Mtetra
.418 .158 .411 r
.31328 .30261 .32113 .25144 .32852 .23448 .3202 .2949 Mtetra
.215 0 .355 r
.3202 .2949 .32852 .23448 .33548 .22372 .32834 .26803 Mtetra
.506 .229 .427 r
.32834 .26803 .33548 .22372 .34195 .22082 .33467 .26919 Mtetra
.276 .04 .363 r
.33467 .26919 .34195 .22082 .34889 .21005 .34215 .25145 Mtetra
.455 .181 .409 r
.34215 .25145 .34889 .21005 .35524 .20948 .34876 .24815 Mtetra
.383 .117 .382 r
.34876 .24815 .35524 .20948 .36195 .20247 .35564 .24014 Mtetra
.435 .16 .396 r
.35564 .24014 .36195 .20247 .36837 .20117 .36232 .23576 Mtetra
.437 .158 .39 r
.36232 .23576 .36837 .20117 .37494 .19719 .36897 .232 Mtetra
.461 .178 .397 r
.36897 .232 .37494 .19719 .38144 .19504 .37556 .22981 Mtetra
.469 .185 .399 r
.37556 .22981 .38144 .19504 .38792 .19351 .38214 .22816 Mtetra
.494 .206 .406 r
.38214 .22816 .38792 .19351 .39449 .19051 .38865 .22838 Mtetra
.519 .232 .419 r
.38865 .22838 .39449 .19051 .40088 .19208 .39511 .23066 Mtetra
.487 .205 .412 r
.39511 .23066 .40088 .19208 .40751 .1882 .40171 .23019 Mtetra
.6 .308 .444 r
.40171 .23019 .40751 .1882 .41381 .19392 .40787 .24206 Mtetra
.444 .179 .416 r
.40787 .24206 .41381 .19392 .42042 .19189 .41472 .23691 Mtetra
.658 .361 .457 r
.41472 .23691 .42042 .19189 .42678 .19832 .42066 .25896 Mtetra
.515 .246 .445 r
.42066 .25896 .42678 .19832 .43303 .20998 .42734 .26131 Mtetra
.553 .273 .444 r
.42734 .26131 .43303 .20998 .43974 .20836 .43392 .26849 Mtetra
.681 .388 .471 r
.43392 .26849 .43974 .20836 .44568 .23709 .4398 .30359 Mtetra
.48 .219 .441 r
.4398 .30359 .44568 .23709 .45203 .25508 .4468 .30093 Mtetra
.551 .265 .435 r
.4468 .30093 .45203 .25508 .45873 .26161 .45362 .30725 Mtetra
.707 .403 .459 r
.45362 .30725 .45873 .26161 .46487 .30052 .45995 .34034 Mtetra
.605 .306 .435 r
.45995 .34034 .46487 .30052 .47102 .35054 .46684 .35256 Mtetra
.998 .835 .549 r
.46684 .35256 .47102 .35054 .47785 .37195 .47446 .32433 Mtetra
.79 .532 .547 r
.47446 .32433 .47785 .37195 .48538 .3477 .4823 .27292 Mtetra
.698 .448 .541 r
.4823 .27292 .48538 .3477 .49301 .30469 .48982 .23146 Mtetra
.648 .409 .543 r
.48982 .23146 .49301 .30469 .50042 .26927 .49705 .20467 Mtetra
.646 .41 .547 r
.49705 .20467 .50042 .26927 .50769 .23687 .50416 .18154 Mtetra
.642 .411 .553 r
.50416 .18154 .50769 .23687 .51482 .20649 .51118 .16267 Mtetra
.639 .417 .566 r
.51118 .16267 .51482 .20649 .52184 .18233 .51812 .14831 Mtetra
.65 .438 .582 r
.51812 .14831 .52184 .18233 .52878 .16196 .52503 .13608 Mtetra
.652 .456 .606 r
.52503 .13608 .52878 .16196 .53567 .14517 .53192 .12685 Mtetra
.651 .486 .647 r
.53192 .12685 .53567 .14517 .54255 .13349 .53881 .12054 Mtetra
.665 .538 .699 r
.53881 .12054 .54255 .13349 .54942 .1253 .5457 .11554 Mtetra
.675 .59 .752 r
.5457 .11554 .54942 .1253 .55631 .11894 .55262 .11139 Mtetra
.672 .641 .811 r
.55262 .11139 .55631 .11894 .56321 .1142 .55955 .10808 Mtetra
.67 .689 .859 r
.55955 .10808 .56321 .1142 .57015 .11063 .5665 .10514 Mtetra
.67 .716 .882 r
.5665 .10514 .57015 .11063 .5771 .10751 .57347 .10229 Mtetra
.667 .727 .894 r
.57347 .10229 .5771 .10751 .58407 .10457 .58046 .09953 Mtetra
.664 .735 .903 r
.58046 .09953 .58407 .10457 .59107 .1018 .58746 .09684 Mtetra
.664 .74 .907 r
.58746 .09684 .59107 .1018 .59808 .09911 .59449 .09416 Mtetra
.664 .741 .907 r
.59449 .09416 .59808 .09911 .60511 .09643 .60153 .09146 Mtetra
.60153 .09146 .60511 .09643 .61216 .09374 .60859 .08877 Mtetra
.664 .741 .908 r
.60859 .08877 .61216 .09374 .61922 .09105 .61567 .08607 Mtetra
.61567 .08607 .61922 .09105 .62631 .08835 .62276 .08337 Mtetra
.62276 .08337 .62631 .08835 .63341 .08566 .62988 .08065 Mtetra
.62988 .08065 .63341 .08566 .64053 .08295 .63701 .07793 Mtetra
.63701 .07793 .64053 .08295 .64767 .08023 .64416 .07521 Mtetra
.64416 .07521 .64767 .08023 .65482 .07751 .65133 .07247 Mtetra
.65133 .07247 .65482 .07751 .662 .07479 .65852 .06973 Mtetra
.65852 .06973 .662 .07479 .66919 .07205 .66572 .06699 Mtetra
.66572 .06699 .66919 .07205 .6764 .06931 .67294 .06423 Mtetra
.67294 .06423 .6764 .06931 .68363 .06656 .68019 .06147 Mtetra
.68019 .06147 .68363 .06656 .69088 .06381 .68745 .0587 Mtetra
.68745 .0587 .69088 .06381 .69815 .06104 .69473 .05593 Mtetra
.69473 .05593 .69815 .06104 .70543 .05827 .70202 .05314 Mtetra
.70202 .05314 .70543 .05827 .71273 .0555 .70934 .05035 Mtetra
.70934 .05035 .71273 .0555 .72006 .05271 .71668 .04756 Mtetra
.06749 .28934 .07187 .29342 .07765 .29121 .07328 .28713 Mtetra
.07328 .28713 .07765 .29121 .08344 .289 .07908 .28491 Mtetra
.07908 .28491 .08344 .289 .08925 .28679 .0849 .28269 Mtetra
.0849 .28269 .08925 .28679 .09507 .28457 .09073 .28046 Mtetra
.09073 .28046 .09507 .28457 .10091 .28234 .09657 .27822 Mtetra
.09657 .27822 .10091 .28234 .10676 .28011 .10243 .27598 Mtetra
.10243 .27598 .10676 .28011 .11262 .27788 .1083 .27374 Mtetra
.1083 .27374 .11262 .27788 .1185 .27564 .11418 .27149 Mtetra
.11418 .27149 .1185 .27564 .12439 .27339 .12008 .26923 Mtetra
.12008 .26923 .12439 .27339 .13029 .27114 .12599 .26697 Mtetra
.12599 .26697 .13029 .27114 .13621 .26888 .13191 .26471 Mtetra
.13191 .26471 .13621 .26888 .14214 .26662 .13785 .26244 Mtetra
.13785 .26244 .14214 .26662 .14808 .26436 .1438 .26016 Mtetra
.1438 .26016 .14808 .26436 .15404 .26209 .14977 .25788 Mtetra
.14977 .25788 .15404 .26209 .16001 .25981 .15575 .25559 Mtetra
.15575 .25559 .16001 .25981 .166 .25753 .16174 .2533 Mtetra
.663 .741 .908 r
.16174 .2533 .166 .25753 .17199 .25525 .16775 .251 Mtetra
.16775 .251 .17199 .25525 .17801 .25296 .17377 .24871 Mtetra
.664 .741 .908 r
.17377 .24871 .17801 .25296 .18403 .25068 .17981 .2464 Mtetra
.662 .74 .907 r
.17981 .2464 .18403 .25068 .19007 .24847 .18585 .2441 Mtetra
.659 .735 .906 r
.18585 .2441 .19007 .24847 .1961 .24635 .19191 .24185 Mtetra
.656 .728 .902 r
.19191 .24185 .1961 .24635 .20214 .24433 .19798 .23963 Mtetra
.651 .717 .897 r
.19798 .23963 .20214 .24433 .20816 .24268 .20405 .23747 Mtetra
.629 .686 .885 r
.20405 .23747 .20816 .24268 .21411 .24186 .21011 .23563 Mtetra
.597 .631 .856 r
.21011 .23563 .21411 .24186 .21999 .24192 .21614 .23425 Mtetra
.571 .571 .814 r
.21614 .23425 .21999 .24192 .22577 .24327 .22214 .23326 Mtetra
.511 .481 .76 r
.22214 .23326 .22577 .24327 .2313 .2475 .22806 .23339 Mtetra
.436 .371 .686 r
.22806 .23339 .2313 .2475 .23658 .25477 .23381 .23548 Mtetra
.421 .317 .63 r
.23381 .23548 .23658 .25477 .24173 .26412 .23948 .23877 Mtetra
.399 .272 .59 r
.23948 .23877 .24173 .26412 .24654 .27785 .24503 .24387 Mtetra
.37 .227 .553 r
.24503 .24387 .24654 .27785 .25105 .29595 .25034 .25201 Mtetra
.383 .221 .534 r
.25034 .25201 .25105 .29595 .25533 .31782 .25559 .26166 Mtetra
.296 .143 .497 r
.25559 .26166 .25533 .31782 .25851 .35417 .26012 .28026 Mtetra
.136 .01 .432 r
.26012 .28026 .25851 .35417 .26107 .40006 .26319 .31771 Mtetra
.152 .02 .434 r
.26319 .31771 .26107 .40006 .26578 .42174 .26619 .35817 Mtetra
.349 .181 .506 r
.26619 .35817 .26578 .42174 .27372 .40327 .27124 .37506 Mtetra
.69 .483 .602 r
.27124 .37506 .27372 .40327 .283 .36656 .27877 .36117 Mtetra
.827 .747 .776 r
.27877 .36117 .283 .36656 .2902 .35644 .28582 .35319 Mtetra
.911 .507 .181 r
.28582 .35319 .2902 .35644 .29687 .35329 .29101 .37048 Mtetra
0 0 0 r
.29101 .37048 .29687 .35329 .30612 .31354 .299 .34998 Mtetra
.136 0 .281 r
.299 .34998 .30612 .31354 .31328 .30261 .30682 .33097 Mtetra
.607 .298 .419 r
.30682 .33097 .31328 .30261 .3202 .2949 .3127 .34007 Mtetra
.053 0 .27 r
.3127 .34007 .3202 .2949 .32834 .26803 .32105 .31224 Mtetra
.495 .217 .422 r
.32105 .31224 .32834 .26803 .33467 .26919 .32754 .31242 Mtetra
.356 .098 .379 r
.32754 .31242 .33467 .26919 .34215 .25145 .33472 .30174 Mtetra
.391 .134 .4 r
.33472 .30174 .34215 .25145 .34876 .24815 .34184 .29192 Mtetra
.47 .195 .414 r
.34184 .29192 .34876 .24815 .35564 .24014 .3485 .2898 Mtetra
.404 .145 .404 r
.3485 .2898 .35564 .24014 .36232 .23576 .35554 .28117 Mtetra
.479 .204 .419 r
.35554 .28117 .36232 .23576 .36897 .232 .36219 .27974 Mtetra
.466 .196 .419 r
.36219 .27974 .36897 .232 .37556 .22981 .36893 .27697 Mtetra
.466 .195 .418 r
.36893 .27697 .37556 .22981 .38214 .22816 .37568 .27419 Mtetra
.526 .245 .432 r
.37568 .27419 .38214 .22816 .38865 .22838 .38216 .2776 Mtetra
.468 .198 .421 r
.38216 .2776 .38865 .22838 .39511 .23066 .38896 .27486 Mtetra
.546 .261 .433 r
.38896 .27486 .39511 .23066 .40171 .23019 .39542 .28044 Mtetra
.535 .256 .438 r
.39542 .28044 .40171 .23019 .40787 .24206 .40197 .28524 Mtetra
.452 .179 .408 r
.40197 .28524 .40787 .24206 .41472 .23691 .40888 .28157 Mtetra
.659 .36 .455 r
.40888 .28157 .41472 .23691 .42066 .25896 .4149 .3037 Mtetra
.323 .074 .374 r
.4149 .3037 .42066 .25896 .42734 .26131 .42223 .28979 Mtetra
.66 .342 .423 r
.42223 .28979 .42734 .26131 .43392 .26849 .42863 .30497 Mtetra
.633 .328 .436 r
.42863 .30497 .43392 .26849 .4398 .30359 .43514 .31983 Mtetra
0 0 0 r
.43514 .31983 .4398 .30359 .4468 .30093 .44274 .29706 Mtetra
0 .256 .729 r
.44274 .29706 .4468 .30093 .45362 .30725 .44961 .30137 Mtetra
0 0 .484 r
.44961 .30137 .45362 .30725 .45995 .34034 .45643 .31016 Mtetra
.749 .519 .583 r
.45643 .31016 .45995 .34034 .46684 .35256 .46395 .28652 Mtetra
.729 .475 .543 r
.46395 .28652 .46684 .35256 .47446 .32433 .47179 .24039 Mtetra
.686 .435 .537 r
.47179 .24039 .47446 .32433 .4823 .27292 .47939 .19809 Mtetra
.632 .395 .541 r
.47939 .19809 .4823 .27292 .48982 .23146 .48658 .17466 Mtetra
.614 .389 .552 r
.48658 .17466 .48982 .23146 .49705 .20467 .49361 .16013 Mtetra
.629 .409 .565 r
.49361 .16013 .49705 .20467 .50416 .18154 .50058 .14693 Mtetra
.63 .422 .582 r
.50058 .14693 .50416 .18154 .51118 .16267 .50751 .13678 Mtetra
.64 .448 .607 r
.50751 .13678 .51118 .16267 .51812 .14831 .51441 .12852 Mtetra
.654 .48 .636 r
.51441 .12852 .51812 .14831 .52503 .13608 .5213 .12144 Mtetra
.654 .514 .68 r
.5213 .12144 .52503 .13608 .53192 .12685 .52819 .11632 Mtetra
.662 .569 .74 r
.52819 .11632 .53192 .12685 .53881 .12054 .53509 .11234 Mtetra
.674 .624 .791 r
.53509 .11234 .53881 .12054 .5457 .11554 .542 .10874 Mtetra
.672 .665 .835 r
.542 .10874 .5457 .11554 .55262 .11139 .54893 .1056 Mtetra
.667 .701 .872 r
.54893 .1056 .55262 .11139 .55955 .10808 .55588 .10277 Mtetra
.667 .723 .891 r
.55588 .10277 .55955 .10808 .5665 .10514 .56284 .1 Mtetra
.667 .732 .898 r
.56284 .1 .5665 .10514 .57347 .10229 .56982 .09726 Mtetra
.664 .737 .904 r
.56982 .09726 .57347 .10229 .58046 .09953 .57682 .09457 Mtetra
.663 .74 .907 r
.57682 .09457 .58046 .09953 .58746 .09684 .58384 .09188 Mtetra
.664 .741 .908 r
.58384 .09188 .58746 .09684 .59449 .09416 .59088 .08919 Mtetra
.59088 .08919 .59449 .09416 .60153 .09146 .59793 .08649 Mtetra
.59793 .08649 .60153 .09146 .60859 .08877 .605 .08378 Mtetra
.605 .08378 .60859 .08877 .61567 .08607 .61209 .08107 Mtetra
.61209 .08107 .61567 .08607 .62276 .08337 .6192 .07835 Mtetra
.6192 .07835 .62276 .08337 .62988 .08065 .62633 .07563 Mtetra
.62633 .07563 .62988 .08065 .63701 .07793 .63347 .07289 Mtetra
.63347 .07289 .63701 .07793 .64416 .07521 .64064 .07015 Mtetra
.64064 .07015 .64416 .07521 .65133 .07247 .64782 .06741 Mtetra
.64782 .06741 .65133 .07247 .65852 .06973 .65502 .06466 Mtetra
.65502 .06466 .65852 .06973 .66572 .06699 .66223 .06189 Mtetra
.66223 .06189 .66572 .06699 .67294 .06423 .66947 .05913 Mtetra
.66947 .05913 .67294 .06423 .68019 .06147 .67673 .05635 Mtetra
.67673 .05635 .68019 .06147 .68745 .0587 .684 .05357 Mtetra
.684 .05357 .68745 .0587 .69473 .05593 .69129 .05078 Mtetra
.69129 .05078 .69473 .05593 .70202 .05314 .6986 .04799 Mtetra
.6986 .04799 .70202 .05314 .70934 .05035 .70593 .04518 Mtetra
.70593 .04518 .70934 .05035 .71668 .04756 .71328 .04237 Mtetra
.0631 .28525 .06749 .28934 .07328 .28713 .06889 .28303 Mtetra
.06889 .28303 .07328 .28713 .07908 .28491 .0747 .2808 Mtetra
.0747 .2808 .07908 .28491 .0849 .28269 .08053 .27857 Mtetra
.08053 .27857 .0849 .28269 .09073 .28046 .08636 .27633 Mtetra
.08636 .27633 .09073 .28046 .09657 .27822 .09221 .27408 Mtetra
.09221 .27408 .09657 .27822 .10243 .27598 .09808 .27183 Mtetra
.09808 .27183 .10243 .27598 .1083 .27374 .10395 .26958 Mtetra
.10395 .26958 .1083 .27374 .11418 .27149 .10985 .26732 Mtetra
.10985 .26732 .11418 .27149 .12008 .26923 .11575 .26506 Mtetra
.11575 .26506 .12008 .26923 .12599 .26697 .12167 .26278 Mtetra
.12167 .26278 .12599 .26697 .13191 .26471 .1276 .26051 Mtetra
.1276 .26051 .13191 .26471 .13785 .26244 .13355 .25823 Mtetra
.13355 .25823 .13785 .26244 .1438 .26016 .13951 .25594 Mtetra
.13951 .25594 .1438 .26016 .14977 .25788 .14548 .25365 Mtetra
.14548 .25365 .14977 .25788 .15575 .25559 .15147 .25136 Mtetra
.15147 .25136 .15575 .25559 .16174 .2533 .15747 .24905 Mtetra
.15747 .24905 .16174 .2533 .16775 .251 .16348 .24675 Mtetra
.663 .741 .908 r
.16348 .24675 .16775 .251 .17377 .24871 .16951 .24444 Mtetra
.16951 .24444 .17377 .24871 .17981 .2464 .17556 .24212 Mtetra
.664 .741 .908 r
.17556 .24212 .17981 .2464 .18585 .2441 .18162 .23979 Mtetra
.662 .74 .908 r
.18162 .23979 .18585 .2441 .19191 .24185 .18769 .23748 Mtetra
.66 .737 .906 r
.18769 .23748 .19191 .24185 .19798 .23963 .19377 .23519 Mtetra
.66 .733 .904 r
.19377 .23519 .19798 .23963 .20405 .23747 .19987 .23289 Mtetra
.655 .726 .901 r
.19987 .23289 .20405 .23747 .21011 .23563 .20597 .23066 Mtetra
.639 .702 .892 r
.20597 .23066 .21011 .23563 .21614 .23425 .21207 .22865 Mtetra
.628 .671 .872 r
.21207 .22865 .21614 .23425 .22214 .23326 .21816 .22679 Mtetra
.608 .629 .846 r
.21816 .22679 .22214 .23326 .22806 .23339 .22425 .22519 Mtetra
.55 .547 .803 r
.22425 .22519 .22806 .23339 .23381 .23548 .23026 .22454 Mtetra
.51 .464 .741 r
.23026 .22454 .23381 .23548 .23948 .23877 .23621 .22472 Mtetra
.495 .411 .691 r
.23621 .22472 .23948 .23877 .24503 .24387 .24214 .22539 Mtetra
.456 .347 .641 r
.24214 .22539 .24503 .24387 .25034 .25201 .24797 .22749 Mtetra
.469 .326 .604 r
.24797 .22749 .25034 .25201 .25559 .26166 .25383 .22969 Mtetra
.445 .287 .572 r
.25383 .22969 .25559 .26166 .26012 .28026 .25955 .23374 Mtetra
.265 .128 .501 r
.25955 .23374 .26012 .28026 .26319 .31771 .26421 .25085 Mtetra
.177 .045 .451 r
.26421 .25085 .26319 .31771 .26619 .35817 .26781 .28185 Mtetra
.264 .107 .472 r
.26781 .28185 .26619 .35817 .27124 .37506 .2718 .30986 Mtetra
.461 .266 .529 r
.2718 .30986 .27124 .37506 .27877 .36117 .27767 .3158 Mtetra
.561 .358 .563 r
.27767 .3158 .27877 .36117 .28582 .35319 .2844 .31106 Mtetra
.134 .04 .474 r
.2844 .31106 .28582 .35319 .29101 .37048 .28916 .33289 Mtetra
.439 .276 .562 r
.28916 .33289 .29101 .37048 .299 .34998 .29525 .33801 Mtetra
.84 .645 .638 r
.29525 .33801 .299 .34998 .30682 .33097 .30308 .31911 Mtetra
.687 .387 0 r
.30308 .31911 .30682 .33097 .3127 .34007 .30839 .33628 Mtetra
.911 .79 .715 r
.30839 .33628 .3127 .34007 .32105 .31224 .31581 .32304 Mtetra
.183 0 .087 r
.31581 .32304 .32105 .31224 .32754 .31242 .32266 .31831 Mtetra
.552 .102 .135 r
.32266 .31831 .32754 .31242 .33472 .30174 .32904 .3212 Mtetra
0 0 .129 r
.32904 .3212 .33472 .30174 .34184 .29192 .33645 .30766 Mtetra
.573 .223 .337 r
.33645 .30766 .34184 .29192 .3485 .2898 .34279 .31203 Mtetra
.21 0 .251 r
.34279 .31203 .3485 .2898 .35554 .28117 .34996 .30235 Mtetra
.487 .165 .347 r
.34996 .30235 .35554 .28117 .36219 .27974 .35657 .30285 Mtetra
.406 .1 .33 r
.35657 .30285 .36219 .27974 .36893 .27697 .3634 .29955 Mtetra
.395 .088 .323 r
.3634 .29955 .36893 .27697 .37568 .27419 .37027 .29587 Mtetra
.54 .216 .367 r
.37027 .29587 .37568 .27419 .38216 .2776 .37681 .2992 Mtetra
.26 0 .268 r
.37681 .2992 .38216 .2776 .38896 .27486 .38392 .29109 Mtetra
.636 .285 .36 r
.38392 .29109 .38896 .27486 .39542 .28044 .39032 .29924 Mtetra
.223 0 .232 r
.39032 .29924 .39542 .28044 .40197 .28524 .39744 .29124 Mtetra
.436 0 .059 r
.39744 .29124 .40197 .28524 .40888 .28157 .40421 .29205 Mtetra
.651 .263 .296 r
.40421 .29205 .40888 .28157 .4149 .3037 .41079 .2992 Mtetra
.943 .765 .632 r
.41079 .2992 .4149 .3037 .42223 .28979 .4184 .27776 Mtetra
0 0 .424 r
.4184 .27776 .42223 .28979 .42863 .30497 .4248 .29211 Mtetra
.77 .603 .672 r
.4248 .29211 .42863 .30497 .43514 .31983 .43206 .28097 Mtetra
.729 .492 .569 r
.43206 .28097 .43514 .31983 .44274 .29706 .43972 .25426 Mtetra
.507 .321 .563 r
.43972 .25426 .44274 .29706 .44961 .30137 .44661 .25481 Mtetra
.615 .398 .564 r
.44661 .25481 .44961 .30137 .45643 .31016 .45381 .24298 Mtetra
.687 .441 .545 r
.45381 .24298 .45643 .31016 .46395 .28652 .46145 .2089 Mtetra
.675 .428 .54 r
.46145 .2089 .46395 .28652 .47179 .24039 .469 .17302 Mtetra
.635 .4 .544 r
.469 .17302 .47179 .24039 .47939 .19809 .47618 .15124 Mtetra
.592 .379 .561 r
.47618 .15124 .47939 .19809 .48658 .17466 .48312 .14232 Mtetra
.606 .408 .587 r
.48312 .14232 .48658 .17466 .49361 .16013 .49002 .13513 Mtetra
.63 .443 .611 r
.49002 .13513 .49361 .16013 .50058 .14693 .49691 .12795 Mtetra
.637 .472 .643 r
.49691 .12795 .50058 .14693 .50751 .13678 .50379 .12226 Mtetra
.656 .516 .681 r
.50379 .12226 .50751 .13678 .51441 .12852 .51068 .1171 Mtetra
.664 .556 .723 r
.51068 .1171 .51441 .12852 .5213 .12144 .51756 .11274 Mtetra
.662 .606 .781 r
.51756 .11274 .5213 .12144 .52819 .11632 .52446 .10933 Mtetra
.67 .658 .829 r
.52446 .10933 .52819 .11632 .53509 .11234 .53136 .1062 Mtetra
.672 .69 .858 r
.53136 .1062 .53509 .11234 .542 .10874 .53829 .1032 Mtetra
.666 .712 .883 r
.53829 .1032 .542 .10874 .54893 .1056 .54523 .10042 Mtetra
.665 .729 .898 r
.54523 .10042 .54893 .1056 .55588 .10277 .55219 .09771 Mtetra
.665 .736 .902 r
.55219 .09771 .55588 .10277 .56284 .1 .55917 .09499 Mtetra
.664 .738 .905 r
.55917 .09499 .56284 .1 .56982 .09726 .56616 .09229 Mtetra
.663 .74 .907 r
.56616 .09229 .56982 .09726 .57682 .09457 .57317 .0896 Mtetra
.664 .741 .908 r
.57317 .0896 .57682 .09457 .58384 .09188 .58021 .0869 Mtetra
.58021 .0869 .58384 .09188 .59088 .08919 .58725 .0842 Mtetra
.58725 .0842 .59088 .08919 .59793 .08649 .59432 .08149 Mtetra
.59432 .08149 .59793 .08649 .605 .08378 .6014 .07877 Mtetra
.6014 .07877 .605 .08378 .61209 .08107 .60851 .07605 Mtetra
.60851 .07605 .61209 .08107 .6192 .07835 .61563 .07331 Mtetra
.61563 .07331 .6192 .07835 .62633 .07563 .62276 .07058 Mtetra
.62276 .07058 .62633 .07563 .63347 .07289 .62992 .06783 Mtetra
.62992 .06783 .63347 .07289 .64064 .07015 .6371 .06508 Mtetra
.6371 .06508 .64064 .07015 .64782 .06741 .64429 .06232 Mtetra
.64429 .06232 .64782 .06741 .65502 .06466 .6515 .05955 Mtetra
.6515 .05955 .65502 .06466 .66223 .06189 .65873 .05678 Mtetra
.65873 .05678 .66223 .06189 .66947 .05913 .66598 .054 Mtetra
.66598 .054 .66947 .05913 .67673 .05635 .67325 .05121 Mtetra
.67325 .05121 .67673 .05635 .684 .05357 .68054 .04842 Mtetra
.68054 .04842 .684 .05357 .69129 .05078 .68784 .04561 Mtetra
.68784 .04561 .69129 .05078 .6986 .04799 .69516 .04281 Mtetra
.69516 .04281 .6986 .04799 .70593 .04518 .70251 .03999 Mtetra
.70251 .03999 .70593 .04518 .71328 .04237 .70987 .03716 Mtetra
.05868 .28114 .0631 .28525 .06889 .28303 .06449 .27891 Mtetra
.06449 .27891 .06889 .28303 .0747 .2808 .07031 .27667 Mtetra
.07031 .27667 .0747 .2808 .08053 .27857 .07614 .27443 Mtetra
.07614 .27443 .08053 .27857 .08636 .27633 .08198 .27218 Mtetra
.08198 .27218 .08636 .27633 .09221 .27408 .08784 .26993 Mtetra
.08784 .26993 .09221 .27408 .09808 .27183 .09371 .26767 Mtetra
.09371 .26767 .09808 .27183 .10395 .26958 .09959 .2654 Mtetra
.09959 .2654 .10395 .26958 .10985 .26732 .10549 .26313 Mtetra
.10549 .26313 .10985 .26732 .11575 .26506 .1114 .26086 Mtetra
.1114 .26086 .11575 .26506 .12167 .26278 .11733 .25858 Mtetra
.11733 .25858 .12167 .26278 .1276 .26051 .12327 .25629 Mtetra
.12327 .25629 .1276 .26051 .13355 .25823 .12922 .254 Mtetra
.12922 .254 .13355 .25823 .13951 .25594 .13519 .25171 Mtetra
.13519 .25171 .13951 .25594 .14548 .25365 .14117 .24941 Mtetra
.14117 .24941 .14548 .25365 .15147 .25136 .14717 .2471 Mtetra
.14717 .2471 .15147 .25136 .15747 .24905 .15318 .24479 Mtetra
.15318 .24479 .15747 .24905 .16348 .24675 .1592 .24247 Mtetra
.663 .741 .908 r
.1592 .24247 .16348 .24675 .16951 .24444 .16524 .24015 Mtetra
.16524 .24015 .16951 .24444 .17556 .24212 .17129 .23782 Mtetra
.664 .741 .908 r
.17129 .23782 .17556 .24212 .18162 .23979 .17736 .23549 Mtetra
.663 .741 .908 r
.17736 .23549 .18162 .23979 .18769 .23748 .18344 .23315 Mtetra
.662 .74 .908 r
.18344 .23315 .18769 .23748 .19377 .23519 .18953 .23082 Mtetra
.662 .738 .907 r
.18953 .23082 .19377 .23519 .19987 .23289 .19564 .22849 Mtetra
.662 .737 .906 r
.19564 .22849 .19987 .23289 .20597 .23066 .20176 .22614 Mtetra
.657 .731 .904 r
.20176 .22614 .20597 .23066 .21207 .22865 .20789 .22388 Mtetra
.65 .716 .897 r
.20789 .22388 .21207 .22865 .21816 .22679 .21403 .2217 Mtetra
.648 .701 .885 r
.21403 .2217 .21816 .22679 .22425 .22519 .22017 .21952 Mtetra
.626 .669 .871 r
.22017 .21952 .22425 .22519 .23026 .22454 .22631 .21766 Mtetra
.589 .608 .838 r
.22631 .21766 .23026 .22454 .23621 .22472 .2324 .21635 Mtetra
.576 .557 .796 r
.2324 .21635 .23621 .22472 .24214 .22539 .2385 .2152 Mtetra
.546 .5 .755 r
.2385 .2152 .24214 .22539 .24797 .22749 .24457 .21458 Mtetra
.543 .457 .707 r
.24457 .21458 .24797 .22749 .25383 .22969 .25066 .21394 Mtetra
.578 .451 .671 r
.25066 .21394 .25383 .22969 .25955 .23374 .2569 .21192 Mtetra
.454 .327 .617 r
.2569 .21192 .25955 .23374 .26421 .25085 .26276 .21439 Mtetra
.252 .133 .517 r
.26276 .21439 .26421 .25085 .26781 .28185 .2677 .22835 Mtetra
.245 .106 .485 r
.2677 .22835 .26781 .28185 .2718 .30986 .27214 .24914 Mtetra
.387 .21 .515 r
.27214 .24914 .2718 .30986 .27767 .3158 .27736 .26171 Mtetra
.526 .323 .548 r
.27736 .26171 .27767 .3158 .2844 .31106 .28378 .25994 Mtetra
.337 .179 .515 r
.28378 .25994 .2844 .31106 .28916 .33289 .28899 .27428 Mtetra
.317 .158 .502 r
.28899 .27428 .28916 .33289 .29525 .33801 .29401 .29223 Mtetra
.62 .403 .566 r
.29401 .29223 .29525 .33801 .30308 .31911 .30129 .28023 Mtetra
.289 .16 .526 r
.30129 .28023 .30308 .31911 .30839 .33628 .30676 .29375 Mtetra
.479 .299 .557 r
.30676 .29375 .30839 .33628 .31581 .32304 .31305 .29643 Mtetra
.64 .448 .607 r
.31305 .29643 .31581 .32304 .32266 .31831 .3201 .28811 Mtetra
.275 .172 .551 r
.3201 .28811 .32266 .31831 .32904 .3212 .32591 .29928 Mtetra
.7 .505 .622 r
.32591 .29928 .32904 .3212 .33645 .30766 .33318 .28772 Mtetra
.327 .255 .621 r
.33318 .28772 .33645 .30766 .34279 .31203 .33938 .29389 Mtetra
.665 .499 .649 r
.33938 .29389 .34279 .31203 .34996 .30235 .34639 .28688 Mtetra
.502 .411 .684 r
.34639 .28688 .34996 .30235 .35657 .30285 .35298 .2874 Mtetra
.611 .482 .68 r
.35298 .2874 .35657 .30285 .3634 .29955 .3598 .28406 Mtetra
.619 .487 .679 r
.3598 .28406 .3634 .29955 .37027 .29587 .36666 .28036 Mtetra
.507 .414 .685 r
.36666 .28036 .37027 .29587 .37681 .2992 .37333 .28073 Mtetra
.699 .519 .642 r
.37333 .28073 .37681 .2992 .38392 .29109 .38049 .27121 Mtetra
.36 .28 .629 r
.38049 .27121 .38392 .29109 .39032 .29924 .38697 .27659 Mtetra
.733 .525 .611 r
.38697 .27659 .39032 .29924 .39744 .29124 .39439 .26109 Mtetra
.454 .304 .587 r
.39439 .26109 .39744 .29124 .40421 .29205 .401 .2646 Mtetra
.638 .444 .604 r
.401 .2646 .40421 .29205 .41079 .2992 .40812 .25611 Mtetra
.664 .438 .568 r
.40812 .25611 .41079 .2992 .4184 .27776 .41555 .23842 Mtetra
.421 .261 .557 r
.41555 .23842 .4184 .27776 .4248 .29211 .42212 .2452 Mtetra
.688 .453 .562 r
.42212 .2452 .4248 .29211 .43206 .28097 .42969 .22151 Mtetra
.634 .403 .55 r
.42969 .22151 .43206 .28097 .43972 .25426 .43705 .2026 Mtetra
.538 .334 .552 r
.43705 .2026 .43972 .25426 .44661 .25481 .44393 .19958 Mtetra
.639 .409 .553 r
.44393 .19958 .44661 .25481 .45381 .24298 .4512 .18115 Mtetra
.665 .425 .548 r
.4512 .18115 .45381 .24298 .46145 .2089 .45859 .15506 Mtetra
.643 .412 .553 r
.45859 .15506 .46145 .2089 .469 .17302 .46574 .13644 Mtetra
.596 .394 .577 r
.46574 .13644 .469 .17302 .47618 .15124 .47263 .12915 Mtetra
.576 .416 .627 r
.47263 .12915 .47618 .15124 .48312 .14232 .47945 .12618 Mtetra
.63 .486 .668 r
.47945 .12618 .48312 .14232 .49002 .13513 .48631 .12175 Mtetra
.649 .523 .696 r
.48631 .12175 .49002 .13513 .49691 .12795 .49317 .11731 Mtetra
.658 .565 .739 r
.49317 .11731 .49691 .12795 .50379 .12226 .50004 .11344 Mtetra
.671 .608 .776 r
.50004 .11344 .50379 .12226 .51068 .1171 .50692 .10974 Mtetra
.667 .645 .818 r
.50692 .10974 .51068 .1171 .51756 .11274 .51381 .10657 Mtetra
.665 .685 .859 r
.51381 .10657 .51756 .11274 .52446 .10933 .52071 .10372 Mtetra
.669 .71 .879 r
.52071 .10372 .52446 .10933 .53136 .1062 .52763 .10087 Mtetra
.667 .723 .891 r
.52763 .10087 .53136 .1062 .53829 .1032 .53456 .09811 Mtetra
.664 .733 .901 r
.53456 .09811 .53829 .1032 .54523 .10042 .54152 .09542 Mtetra
.664 .738 .905 r
.54152 .09542 .54523 .10042 .55219 .09771 .54849 .09272 Mtetra
.664 .739 .906 r
.54849 .09272 .55219 .09771 .55917 .09499 .55548 .09001 Mtetra
.664 .74 .907 r
.55548 .09001 .55917 .09499 .56616 .09229 .56248 .08732 Mtetra
.663 .741 .908 r
.56248 .08732 .56616 .09229 .57317 .0896 .56951 .08462 Mtetra
.664 .741 .908 r
.56951 .08462 .57317 .0896 .58021 .0869 .57655 .08191 Mtetra
.57655 .08191 .58021 .0869 .58725 .0842 .58361 .07919 Mtetra
.58361 .07919 .58725 .0842 .59432 .08149 .59069 .07647 Mtetra
.59069 .07647 .59432 .08149 .6014 .07877 .59779 .07374 Mtetra
.59779 .07374 .6014 .07877 .60851 .07605 .6049 .071 Mtetra
.6049 .071 .60851 .07605 .61563 .07331 .61203 .06825 Mtetra
.61203 .06825 .61563 .07331 .62276 .07058 .61918 .0655 Mtetra
.61918 .0655 .62276 .07058 .62992 .06783 .62635 .06275 Mtetra
.62635 .06275 .62992 .06783 .6371 .06508 .63354 .05998 Mtetra
.63354 .05998 .6371 .06508 .64429 .06232 .64075 .05721 Mtetra
.64075 .05721 .64429 .06232 .6515 .05955 .64797 .05443 Mtetra
.64797 .05443 .6515 .05955 .65873 .05678 .65521 .05164 Mtetra
.65521 .05164 .65873 .05678 .66598 .054 .66247 .04885 Mtetra
.66247 .04885 .66598 .054 .67325 .05121 .66976 .04605 Mtetra
.66976 .04605 .67325 .05121 .68054 .04842 .67705 .04324 Mtetra
.67705 .04324 .68054 .04842 .68784 .04561 .68437 .04042 Mtetra
.68437 .04042 .68784 .04561 .69516 .04281 .69171 .0376 Mtetra
.69171 .0376 .69516 .04281 .70251 .03999 .69907 .03477 Mtetra
.69907 .03477 .70251 .03999 .70987 .03716 .70644 .03193 Mtetra
.05425 .27702 .05868 .28114 .06449 .27891 .06006 .27477 Mtetra
.06006 .27477 .06449 .27891 .07031 .27667 .06589 .27253 Mtetra
.06589 .27253 .07031 .27667 .07614 .27443 .07173 .27027 Mtetra
.07173 .27027 .07614 .27443 .08198 .27218 .07758 .26802 Mtetra
.07758 .26802 .08198 .27218 .08784 .26993 .08344 .26575 Mtetra
.08344 .26575 .08784 .26993 .09371 .26767 .08932 .26348 Mtetra
.08932 .26348 .09371 .26767 .09959 .2654 .09521 .26121 Mtetra
.09521 .26121 .09959 .2654 .10549 .26313 .10112 .25893 Mtetra
.10112 .25893 .10549 .26313 .1114 .26086 .10704 .25665 Mtetra
.10704 .25665 .1114 .26086 .11733 .25858 .11297 .25436 Mtetra
.11297 .25436 .11733 .25858 .12327 .25629 .11892 .25206 Mtetra
.11892 .25206 .12327 .25629 .12922 .254 .12488 .24976 Mtetra
.12488 .24976 .12922 .254 .13519 .25171 .13086 .24746 Mtetra
.13086 .24746 .13519 .25171 .14117 .24941 .13685 .24514 Mtetra
.13685 .24514 .14117 .24941 .14717 .2471 .14285 .24283 Mtetra
.14285 .24283 .14717 .2471 .15318 .24479 .14887 .24051 Mtetra
.14887 .24051 .15318 .24479 .1592 .24247 .1549 .23818 Mtetra
.1549 .23818 .1592 .24247 .16524 .24015 .16095 .23585 Mtetra
.663 .741 .908 r
.16095 .23585 .16524 .24015 .17129 .23782 .16701 .23351 Mtetra
.664 .741 .908 r
.16701 .23351 .17129 .23782 .17736 .23549 .17308 .23116 Mtetra
.17308 .23116 .17736 .23549 .18344 .23315 .17917 .22881 Mtetra
.663 .741 .908 r
.17917 .22881 .18344 .23315 .18953 .23082 .18527 .22646 Mtetra
.663 .74 .908 r
.18527 .22646 .18953 .23082 .19564 .22849 .19139 .22411 Mtetra
.663 .74 .907 r
.19139 .22411 .19564 .22849 .20176 .22614 .19752 .22174 Mtetra
.663 .739 .907 r
.19752 .22174 .20176 .22614 .20789 .22388 .20367 .21938 Mtetra
.659 .734 .905 r
.20367 .21938 .20789 .22388 .21403 .2217 .20982 .21707 Mtetra
.659 .728 .9 r
.20982 .21707 .21403 .2217 .22017 .21952 .21599 .21475 Mtetra
.656 .72 .896 r
.21599 .21475 .22017 .21952 .22631 .21766 .22217 .21246 Mtetra
.636 .694 .887 r
.22217 .21246 .22631 .21766 .2324 .21635 .22834 .21045 Mtetra
.624 .66 .865 r
.22834 .21045 .2324 .21635 .2385 .2152 .23451 .20858 Mtetra
.61 .628 .844 r
.23451 .20858 .2385 .2152 .24457 .21458 .24068 .2069 Mtetra
.591 .585 .814 r
.24068 .2069 .24457 .21458 .25066 .21394 .24685 .20548 Mtetra
.647 .593 .779 r
.24685 .20548 .25066 .21394 .2569 .21192 .25315 .20268 Mtetra
.652 .579 .76 r
.25315 .20268 .2569 .21192 .26276 .21439 .2595 .19952 Mtetra
.438 .366 .678 r
.2595 .19952 .26276 .21439 .2677 .22835 .26541 .2016 Mtetra
.286 .184 .56 r
.26541 .2016 .2677 .22835 .27214 .24914 .27076 .21079 Mtetra
.359 .21 .539 r
.27076 .21079 .27214 .24914 .27736 .26171 .27615 .22034 Mtetra
.516 .326 .561 r
.27615 .22034 .27736 .26171 .28378 .25994 .28238 .21996 Mtetra
.44 .27 .553 r
.28238 .21996 .28378 .25994 .28899 .27428 .28822 .22508 Mtetra
.287 .143 .504 r
.28822 .22508 .28899 .27428 .29401 .29223 .29321 .24189 Mtetra
.554 .347 .554 r
.29321 .24189 .29401 .29223 .30129 .28023 .29989 .23709 Mtetra
.44 .266 .548 r
.29989 .23709 .30129 .28023 .30676 .29375 .30584 .24264 Mtetra
.397 .226 .529 r
.30584 .24264 .30676 .29375 .31305 .29643 .31153 .2526 Mtetra
.594 .384 .566 r
.31153 .2526 .31305 .29643 .3201 .28811 .31852 .24424 Mtetra
.362 .207 .533 r
.31852 .24424 .3201 .28811 .32591 .29928 .32424 .2552 Mtetra
.579 .372 .565 r
.32424 .2552 .32591 .29928 .33318 .28772 .33116 .24843 Mtetra
.461 .288 .56 r
.33116 .24843 .33318 .28772 .33938 .29389 .33742 .25222 Mtetra
.55 .353 .566 r
.33742 .25222 .33938 .29389 .34639 .28688 .34416 .24878 Mtetra
.521 .336 .571 r
.34416 .24878 .34639 .28688 .35298 .2874 .35075 .24804 Mtetra
.547 .354 .57 r
.35075 .24804 .35298 .2874 .3598 .28406 .3575 .24503 Mtetra
.55 .356 .571 r
.3575 .24503 .3598 .28406 .36666 .28036 .36426 .24185 Mtetra
.545 .353 .572 r
.36426 .24185 .36666 .28036 .37333 .28073 .37102 .23912 Mtetra
.59 .383 .569 r
.37102 .23912 .37333 .28073 .38049 .27121 .37803 .23157 Mtetra
.505 .322 .566 r
.37803 .23157 .38049 .27121 .38697 .27659 .38465 .23212 Mtetra
.643 .42 .566 r
.38465 .23212 .38697 .27659 .39439 .26109 .39199 .21707 Mtetra
.477 .295 .555 r
.39199 .21707 .39439 .26109 .401 .2646 .39855 .22001 Mtetra
.643 .421 .565 r
.39855 .22001 .401 .2646 .40812 .25611 .40586 .20474 Mtetra
.593 .376 .556 r
.40586 .20474 .40812 .25611 .41555 .23842 .41294 .19474 Mtetra
.518 .327 .56 r
.41294 .19474 .41555 .23842 .42212 .2452 .41967 .19406 Mtetra
.668 .434 .557 r
.41967 .19406 .42212 .2452 .42969 .22151 .42713 .17193 Mtetra
.593 .377 .557 r
.42713 .17193 .42969 .22151 .43705 .2026 .43415 .16219 Mtetra
.564 .364 .569 r
.43415 .16219 .43705 .2026 .44393 .19958 .44101 .15745 Mtetra
.648 .425 .567 r
.44101 .15745 .44393 .19958 .4512 .18115 .44814 .1424 Mtetra
.65 .431 .572 r
.44814 .1424 .4512 .18115 .45859 .15506 .45521 .12826 Mtetra
.619 .429 .603 r
.45521 .12826 .45859 .15506 .46574 .13644 .46209 .12139 Mtetra
.573 .458 .685 r
.46209 .12139 .46574 .13644 .47263 .12915 .46887 .11956 Mtetra
.613 .56 .771 r
.46887 .11956 .47263 .12915 .47945 .12618 .47568 .11729 Mtetra
.669 .605 .774 r
.47568 .11729 .47945 .12618 .48631 .12175 .48253 .11363 Mtetra
.667 .623 .795 r
.48253 .11363 .48631 .12175 .49317 .11731 .48938 .11025 Mtetra
.671 .656 .827 r
.48938 .11025 .49317 .11731 .50004 .11344 .49625 .10708 Mtetra
.672 .681 .85 r
.49625 .10708 .50004 .11344 .50692 .10974 .50313 .10405 Mtetra
.664 .705 .877 r
.50313 .10405 .50692 .10974 .51381 .10657 .51003 .10129 Mtetra
.665 .724 .893 r
.51003 .10129 .51381 .10657 .52071 .10372 .51694 .09856 Mtetra
.666 .731 .898 r
.51694 .09856 .52071 .10372 .52763 .10087 .52387 .09582 Mtetra
.664 .736 .903 r
.52387 .09582 .52763 .10087 .53456 .09811 .53082 .09313 Mtetra
.663 .739 .907 r
.53082 .09313 .53456 .09811 .54152 .09542 .53779 .09044 Mtetra
.664 .74 .907 r
.53779 .09044 .54152 .09542 .54849 .09272 .54477 .08773 Mtetra
.664 .741 .907 r
.54477 .08773 .54849 .09272 .55548 .09001 .55177 .08503 Mtetra
.663 .741 .908 r
.55177 .08503 .55548 .09001 .56248 .08732 .55879 .08232 Mtetra
.664 .741 .908 r
.55879 .08232 .56248 .08732 .56951 .08462 .56583 .07961 Mtetra
.56583 .07961 .56951 .08462 .57655 .08191 .57288 .07688 Mtetra
.57288 .07688 .57655 .08191 .58361 .07919 .57995 .07416 Mtetra
.57995 .07416 .58361 .07919 .59069 .07647 .58704 .07142 Mtetra
.58704 .07142 .59069 .07647 .59779 .07374 .59415 .06868 Mtetra
.59415 .06868 .59779 .07374 .6049 .071 .60128 .06593 Mtetra
.60128 .06593 .6049 .071 .61203 .06825 .60842 .06317 Mtetra
.60842 .06317 .61203 .06825 .61918 .0655 .61558 .06041 Mtetra
.61558 .06041 .61918 .0655 .62635 .06275 .62277 .05763 Mtetra
.62277 .05763 .62635 .06275 .63354 .05998 .62997 .05486 Mtetra
.62997 .05486 .63354 .05998 .64075 .05721 .63718 .05207 Mtetra
.63718 .05207 .64075 .05721 .64797 .05443 .64442 .04928 Mtetra
.64442 .04928 .64797 .05443 .65521 .05164 .65168 .04648 Mtetra
.65168 .04648 .65521 .05164 .66247 .04885 .65895 .04367 Mtetra
.65895 .04367 .66247 .04885 .66976 .04605 .66624 .04086 Mtetra
.66624 .04086 .66976 .04605 .67705 .04324 .67356 .03803 Mtetra
.67356 .03803 .67705 .04324 .68437 .04042 .68089 .03521 Mtetra
.68089 .03521 .68437 .04042 .69171 .0376 .68824 .03237 Mtetra
.68824 .03237 .69171 .0376 .69907 .03477 .69561 .02953 Mtetra
.69561 .02953 .69907 .03477 .70644 .03193 .703 .02667 Mtetra
.0498 .27287 .05425 .27702 .06006 .27477 .05562 .27062 Mtetra
.05562 .27062 .06006 .27477 .06589 .27253 .06145 .26836 Mtetra
.06145 .26836 .06589 .27253 .07173 .27027 .0673 .2661 Mtetra
.0673 .2661 .07173 .27027 .07758 .26802 .07316 .26383 Mtetra
.07316 .26383 .07758 .26802 .08344 .26575 .07903 .26156 Mtetra
.07903 .26156 .08344 .26575 .08932 .26348 .08492 .25928 Mtetra
.08492 .25928 .08932 .26348 .09521 .26121 .09082 .257 Mtetra
.09082 .257 .09521 .26121 .10112 .25893 .09673 .25471 Mtetra
.09673 .25471 .10112 .25893 .10704 .25665 .10266 .25242 Mtetra
.10266 .25242 .10704 .25665 .11297 .25436 .1086 .25012 Mtetra
.1086 .25012 .11297 .25436 .11892 .25206 .11455 .24781 Mtetra
.11455 .24781 .11892 .25206 .12488 .24976 .12052 .2455 Mtetra
.12052 .2455 .12488 .24976 .13086 .24746 .12651 .24318 Mtetra
.12651 .24318 .13086 .24746 .13685 .24514 .1325 .24086 Mtetra
.1325 .24086 .13685 .24514 .14285 .24283 .13851 .23854 Mtetra
.13851 .23854 .14285 .24283 .14887 .24051 .14454 .2362 Mtetra
.14454 .2362 .14887 .24051 .1549 .23818 .15058 .23387 Mtetra
.15058 .23387 .1549 .23818 .16095 .23585 .15663 .23152 Mtetra
.15663 .23152 .16095 .23585 .16701 .23351 .1627 .22917 Mtetra
.1627 .22917 .16701 .23351 .17308 .23116 .16878 .22682 Mtetra
.16878 .22682 .17308 .23116 .17917 .22881 .17488 .22446 Mtetra
.17488 .22446 .17917 .22881 .18527 .22646 .18099 .22209 Mtetra
.663 .741 .908 r
.18099 .22209 .18527 .22646 .19139 .22411 .18712 .21973 Mtetra
.18712 .21973 .19139 .22411 .19752 .22174 .19326 .21735 Mtetra
.664 .741 .908 r
.19326 .21735 .19752 .22174 .20367 .21938 .19942 .21497 Mtetra
.662 .74 .907 r
.19942 .21497 .20367 .21938 .20982 .21707 .20558 .2126 Mtetra
.662 .737 .906 r
.20558 .2126 .20982 .21707 .21599 .21475 .21177 .21023 Mtetra
.663 .736 .904 r
.21177 .21023 .21599 .21475 .22217 .21246 .21797 .20783 Mtetra
.657 .729 .903 r
.21797 .20783 .22217 .21246 .22834 .21045 .22417 .20552 Mtetra
.648 .713 .895 r
.22417 .20552 .22834 .21045 .23451 .20858 .23038 .20333 Mtetra
.641 .696 .885 r
.23038 .20333 .23451 .20858 .24068 .2069 .23659 .20122 Mtetra
.616 .668 .877 r
.23659 .20122 .24068 .2069 .24685 .20548 .24279 .19947 Mtetra
.639 .664 .859 r
.24279 .19947 .24685 .20548 .25315 .20268 .24904 .19732 Mtetra
.711 .716 .853 r
.24904 .19732 .25315 .20268 .2595 .19952 .25543 .19379 Mtetra
.667 .687 .859 r
.25543 .19379 .2595 .19952 .26541 .2016 .26176 .19112 Mtetra
.453 .441 .755 r
.26176 .19112 .26541 .2016 .27076 .21079 .26777 .19226 Mtetra
.393 .303 .635 r
.26777 .19226 .27076 .21079 .27615 .22034 .2736 .19607 Mtetra
.527 .37 .611 r
.2736 .19607 .27615 .22034 .28238 .21996 .27982 .19546 Mtetra
.525 .368 .61 r
.27982 .19546 .28238 .21996 .28822 .22508 .28606 .19491 Mtetra
.301 .186 .551 r
.28606 .19491 .28822 .22508 .29321 .24189 .29152 .20472 Mtetra
.525 .338 .57 r
.29152 .20472 .29321 .24189 .29989 .23709 .29786 .20368 Mtetra
.519 .34 .579 r
.29786 .20368 .29989 .23709 .30584 .24264 .30418 .20323 Mtetra
.372 .219 .541 r
.30418 .20323 .30584 .24264 .31153 .2526 .30985 .21237 Mtetra
.581 .377 .57 r
.30985 .21237 .31153 .2526 .31852 .24424 .31665 .20598 Mtetra
.416 .255 .553 r
.31665 .20598 .31852 .24424 .32424 .2552 .32259 .21237 Mtetra
.542 .345 .562 r
.32259 .21237 .32424 .2552 .33116 .24843 .32919 .20945 Mtetra
.505 .321 .565 r
.32919 .20945 .33116 .24843 .33742 .25222 .3356 .2099 Mtetra
.524 .332 .561 r
.3356 .2099 .33742 .25222 .34416 .24878 .34213 .20866 Mtetra
.534 .342 .566 r
.34213 .20866 .34416 .24878 .35075 .24804 .34873 .20665 Mtetra
.541 .345 .565 r
.34873 .20665 .35075 .24804 .3575 .24503 .35539 .20397 Mtetra
.541 .346 .565 r
.35539 .20397 .3575 .24503 .36426 .24185 .36206 .20128 Mtetra
.559 .36 .568 r
.36206 .20128 .36426 .24185 .37102 .23912 .36883 .197 Mtetra
.562 .361 .565 r
.36883 .197 .37102 .23912 .37803 .23157 .37563 .19214 Mtetra
.545 .351 .569 r
.37563 .19214 .37803 .23157 .38465 .23212 .38236 .18922 Mtetra
.613 .399 .567 r
.38236 .18922 .38465 .23212 .39199 .21707 .38944 .17852 Mtetra
.5 .319 .566 r
.38944 .17852 .39199 .21707 .39855 .22001 .39602 .17933 Mtetra
.645 .425 .57 r
.39602 .17933 .39855 .22001 .40586 .20474 .40323 .16519 Mtetra
.56 .362 .569 r
.40323 .16519 .40586 .20474 .41294 .19474 .41003 .16087 Mtetra
.569 .378 .582 r
.41003 .16087 .41294 .19474 .41967 .19406 .41685 .15648 Mtetra
.66 .439 .574 r
.41685 .15648 .41967 .19406 .42713 .17193 .42403 .1416 Mtetra
.575 .389 .592 r
.42403 .1416 .42713 .17193 .43415 .16219 .43083 .13733 Mtetra
.594 .417 .612 r
.43083 .13733 .43415 .16219 .44101 .15745 .43765 .13274 Mtetra
.654 .46 .609 r
.43765 .13274 .44101 .15745 .44814 .1424 .4446 .12372 Mtetra
.644 .479 .644 r
.4446 .12372 .44814 .1424 .45521 .12826 .45146 .11766 Mtetra
.608 .537 .749 r
.45146 .11766 .45521 .12826 .46209 .12139 .45824 .11535 Mtetra
.595 .658 .882 r
.45824 .11535 .46209 .12139 .46887 .11956 .46503 .1138 Mtetra
.674 .704 .87 r
.46503 .1138 .46887 .11956 .47568 .11729 .47185 .11086 Mtetra
.685 .683 .842 r
.47185 .11086 .47568 .11729 .48253 .11363 .47871 .10752 Mtetra
.671 .69 .859 r
.47871 .10752 .48253 .11363 .48938 .11025 .48557 .10456 Mtetra
.67 .707 .876 r
.48557 .10456 .48938 .11025 .49625 .10708 .49244 .10169 Mtetra
.666 .719 .888 r
.49244 .10169 .49625 .10708 .50313 .10405 .49933 .09893 Mtetra
.663 .731 .9 r
.49933 .09893 .50313 .10405 .51003 .10129 .50624 .09625 Mtetra
.665 .737 .904 r
.50624 .09625 .51003 .10129 .51694 .09856 .51316 .09355 Mtetra
.664 .738 .905 r
.51316 .09355 .51694 .09856 .52387 .09582 .5201 .09084 Mtetra
.663 .74 .907 r
.5201 .09084 .52387 .09582 .53082 .09313 .52706 .08815 Mtetra
.664 .741 .908 r
.52706 .08815 .53082 .09313 .53779 .09044 .53404 .08545 Mtetra
.664 .741 .907 r
.53404 .08545 .53779 .09044 .54477 .08773 .54103 .08274 Mtetra
.664 .741 .908 r
.54103 .08274 .54477 .08773 .55177 .08503 .54805 .08003 Mtetra
.54805 .08003 .55177 .08503 .55879 .08232 .55508 .07731 Mtetra
.55508 .07731 .55879 .08232 .56583 .07961 .56212 .07458 Mtetra
.56212 .07458 .56583 .07961 .57288 .07688 .56919 .07184 Mtetra
.56919 .07184 .57288 .07688 .57995 .07416 .57627 .0691 Mtetra
.57627 .0691 .57995 .07416 .58704 .07142 .58338 .06635 Mtetra
.58338 .06635 .58704 .07142 .59415 .06868 .5905 .06359 Mtetra
.5905 .06359 .59415 .06868 .60128 .06593 .59764 .06083 Mtetra
.59764 .06083 .60128 .06593 .60842 .06317 .60479 .05806 Mtetra
.60479 .05806 .60842 .06317 .61558 .06041 .61197 .05528 Mtetra
.61197 .05528 .61558 .06041 .62277 .05763 .61916 .0525 Mtetra
.61916 .0525 .62277 .05763 .62997 .05486 .62637 .04971 Mtetra
.62637 .04971 .62997 .05486 .63718 .05207 .63361 .04691 Mtetra
.63361 .04691 .63718 .05207 .64442 .04928 .64086 .0441 Mtetra
.64086 .0441 .64442 .04928 .65168 .04648 .64812 .04129 Mtetra
.64812 .04129 .65168 .04648 .65895 .04367 .65541 .03847 Mtetra
.65541 .03847 .65895 .04367 .66624 .04086 .66272 .03564 Mtetra
.66272 .03564 .66624 .04086 .67356 .03803 .67004 .03281 Mtetra
.67004 .03281 .67356 .03803 .68089 .03521 .67739 .02996 Mtetra
.67739 .02996 .68089 .03521 .68824 .03237 .68475 .02711 Mtetra
.68475 .02711 .68824 .03237 .69561 .02953 .69213 .02426 Mtetra
.69213 .02426 .69561 .02953 .703 .02667 .69954 .02139 Mtetra
.04533 .26871 .0498 .27287 .05562 .27062 .05116 .26645 Mtetra
.05116 .26645 .05562 .27062 .06145 .26836 .057 .26418 Mtetra
.057 .26418 .06145 .26836 .0673 .2661 .06285 .26191 Mtetra
.06285 .26191 .0673 .2661 .07316 .26383 .06872 .25963 Mtetra
.06872 .25963 .07316 .26383 .07903 .26156 .0746 .25735 Mtetra
.0746 .25735 .07903 .26156 .08492 .25928 .08049 .25506 Mtetra
.08049 .25506 .08492 .25928 .09082 .257 .0864 .25277 Mtetra
.0864 .25277 .09082 .257 .09673 .25471 .09232 .25047 Mtetra
.09232 .25047 .09673 .25471 .10266 .25242 .09825 .24817 Mtetra
.09825 .24817 .10266 .25242 .1086 .25012 .1042 .24586 Mtetra
.1042 .24586 .1086 .25012 .11455 .24781 .11017 .24354 Mtetra
.11017 .24354 .11455 .24781 .12052 .2455 .11614 .24122 Mtetra
.11614 .24122 .12052 .2455 .12651 .24318 .12213 .23889 Mtetra
.12213 .23889 .12651 .24318 .1325 .24086 .12814 .23656 Mtetra
.12814 .23656 .1325 .24086 .13851 .23854 .13416 .23423 Mtetra
.13416 .23423 .13851 .23854 .14454 .2362 .14019 .23188 Mtetra
.14019 .23188 .14454 .2362 .15058 .23387 .14624 .22954 Mtetra
.14624 .22954 .15058 .23387 .15663 .23152 .1523 .22718 Mtetra
.1523 .22718 .15663 .23152 .1627 .22917 .15838 .22482 Mtetra
.15838 .22482 .1627 .22917 .16878 .22682 .16447 .22246 Mtetra
.16447 .22246 .16878 .22682 .17488 .22446 .17058 .22009 Mtetra
.17058 .22009 .17488 .22446 .18099 .22209 .1767 .21771 Mtetra
.663 .741 .908 r
.1767 .21771 .18099 .22209 .18712 .21973 .18283 .21533 Mtetra
.18283 .21533 .18712 .21973 .19326 .21735 .18898 .21295 Mtetra
.664 .741 .908 r
.18898 .21295 .19326 .21735 .19942 .21497 .19514 .21055 Mtetra
.663 .741 .908 r
.19514 .21055 .19942 .21497 .20558 .2126 .20132 .20815 Mtetra
.663 .74 .908 r
.20132 .20815 .20558 .2126 .21177 .21023 .20751 .20576 Mtetra
.664 .74 .907 r
.20751 .20576 .21177 .21023 .21797 .20783 .21372 .20335 Mtetra
.663 .739 .907 r
.21372 .20335 .21797 .20783 .22417 .20552 .21994 .20094 Mtetra
.658 .733 .905 r
.21994 .20094 .22417 .20552 .23038 .20333 .22618 .19859 Mtetra
.655 .725 .901 r
.22618 .19859 .23038 .20333 .23659 .20122 .23242 .19628 Mtetra
.636 .71 .9 r
.23242 .19628 .23659 .20122 .24279 .19947 .23865 .19426 Mtetra
.619 .691 .895 r
.23865 .19426 .24279 .19947 .24904 .19732 .24487 .19248 Mtetra
.668 .726 .893 r
.24487 .19248 .24904 .19732 .25543 .19379 .25118 .18993 Mtetra
.713 .787 .91 r
.25118 .18993 .25543 .19379 .26176 .19112 .25757 .18668 Mtetra
.652 .742 .915 r
.25757 .18668 .26176 .19112 .26777 .19226 .26388 .18441 Mtetra
.536 .555 .821 r
.26388 .18441 .26777 .19226 .2736 .19607 .27006 .18391 Mtetra
.578 .49 .719 r
.27006 .18391 .2736 .19607 .27982 .19546 .27635 .18229 Mtetra
.604 .493 .701 r
.27635 .18229 .27982 .19546 .28606 .19491 .28274 .17971 Mtetra
.377 .322 .67 r
.28274 .17971 .28606 .19491 .29152 .20472 .28867 .18316 Mtetra
.527 .381 .626 r
.28867 .18316 .29152 .20472 .29786 .20368 .29495 .18263 Mtetra
.581 .422 .63 r
.29495 .18263 .29786 .20368 .30418 .20323 .30144 .17957 Mtetra
.385 .27 .598 r
.30144 .17957 .30418 .20323 .30985 .21237 .30735 .18467 Mtetra
.585 .402 .6 r
.30735 .18467 .30985 .21237 .31665 .20598 .31398 .18019 Mtetra
.474 .326 .6 r
.31398 .18019 .31665 .20598 .32259 .21237 .32018 .18209 Mtetra
.532 .357 .589 r
.32018 .18209 .32259 .21237 .32919 .20945 .32663 .18079 Mtetra
.542 .368 .595 r
.32663 .18079 .32919 .20945 .3356 .2099 .33313 .17898 Mtetra
.523 .349 .586 r
.33313 .17898 .3356 .2099 .34213 .20866 .33958 .17824 Mtetra
.553 .372 .59 r
.33958 .17824 .34213 .20866 .34873 .20665 .34618 .17554 Mtetra
.549 .368 .588 r
.34618 .17554 .34873 .20665 .35539 .20397 .35278 .17304 Mtetra
.35278 .17304 .35539 .20397 .36206 .20128 .35939 .1706 Mtetra
.576 .388 .59 r
.35939 .1706 .36206 .20128 .36883 .197 .36612 .16621 Mtetra
.558 .375 .589 r
.36612 .16621 .36883 .197 .37563 .19214 .37279 .16314 Mtetra
.576 .393 .596 r
.37279 .16314 .37563 .19214 .38236 .18922 .37953 .15897 Mtetra
.604 .41 .592 r
.37953 .15897 .38236 .18922 .38944 .17852 .38639 .15244 Mtetra
.531 .368 .605 r
.38639 .15244 .38944 .17852 .39602 .17933 .393 .15144 Mtetra
.652 .45 .598 r
.393 .15144 .39602 .17933 .40323 .16519 .40002 .14141 Mtetra
.552 .391 .617 r
.40002 .14141 .40323 .16519 .41003 .16087 .4067 .13947 Mtetra
.609 .441 .629 r
.4067 .13947 .41003 .16087 .41685 .15648 .4135 .13472 Mtetra
.663 .476 .622 r
.4135 .13472 .41685 .15648 .42403 .1416 .42044 .12625 Mtetra
.586 .463 .68 r
.42044 .12625 .42403 .1416 .43083 .13733 .42717 .12385 Mtetra
.626 .507 .698 r
.42717 .12385 .43083 .13733 .43765 .13274 .43395 .12031 Mtetra
.66 .54 .707 r
.43395 .12031 .43765 .13274 .4446 .12372 .44078 .11571 Mtetra
.645 .614 .805 r
.44078 .11571 .4446 .12372 .45146 .11766 .44756 .11296 Mtetra
.612 .729 .929 r
.44756 .11296 .45146 .11766 .45824 .11535 .45434 .11111 Mtetra
.659 .772 .933 r
.45434 .11111 .45824 .11535 .46503 .1138 .46115 .10855 Mtetra
.697 .735 .881 r
.46115 .10855 .46503 .1138 .47185 .11086 .468 .10523 Mtetra
.681 .714 .874 r
.468 .10523 .47185 .11086 .47871 .10752 .47486 .10216 Mtetra
.667 .721 .889 r
.47486 .10216 .47871 .10752 .48557 .10456 .48173 .09938 Mtetra
.666 .729 .897 r
.48173 .09938 .48557 .10456 .49244 .10169 .48861 .09664 Mtetra
.663 .735 .903 r
.48861 .09664 .49244 .10169 .49933 .09893 .49551 .09395 Mtetra
.663 .739 .907 r
.49551 .09395 .49933 .09893 .50624 .09625 .50243 .09127 Mtetra
.664 .74 .907 r
.50243 .09127 .50624 .09625 .51316 .09355 .50936 .08856 Mtetra
.50936 .08856 .51316 .09355 .5201 .09084 .51632 .08586 Mtetra
.663 .741 .908 r
.51632 .08586 .5201 .09084 .52706 .08815 .52329 .08316 Mtetra
.664 .741 .908 r
.52329 .08316 .52706 .08815 .53404 .08545 .53028 .08044 Mtetra
.53028 .08044 .53404 .08545 .54103 .08274 .53728 .07772 Mtetra
.53728 .07772 .54103 .08274 .54805 .08003 .54431 .075 Mtetra
.54431 .075 .54805 .08003 .55508 .07731 .55135 .07226 Mtetra
.55135 .07226 .55508 .07731 .56212 .07458 .55841 .06952 Mtetra
.55841 .06952 .56212 .07458 .56919 .07184 .56548 .06677 Mtetra
.56548 .06677 .56919 .07184 .57627 .0691 .57258 .06402 Mtetra
.57258 .06402 .57627 .0691 .58338 .06635 .5797 .06126 Mtetra
.5797 .06126 .58338 .06635 .5905 .06359 .58683 .05849 Mtetra
.58683 .05849 .5905 .06359 .59764 .06083 .59398 .05571 Mtetra
.59398 .05571 .59764 .06083 .60479 .05806 .60115 .05293 Mtetra
.60115 .05293 .60479 .05806 .61197 .05528 .60834 .05014 Mtetra
.60834 .05014 .61197 .05528 .61916 .0525 .61554 .04734 Mtetra
.61554 .04734 .61916 .0525 .62637 .04971 .62277 .04454 Mtetra
.62277 .04454 .62637 .04971 .63361 .04691 .63001 .04172 Mtetra
.63001 .04172 .63361 .04691 .64086 .0441 .63727 .0389 Mtetra
.63727 .0389 .64086 .0441 .64812 .04129 .64455 .03608 Mtetra
.64455 .03608 .64812 .04129 .65541 .03847 .65185 .03324 Mtetra
.65185 .03324 .65541 .03847 .66272 .03564 .65917 .0304 Mtetra
.65917 .0304 .66272 .03564 .67004 .03281 .66651 .02755 Mtetra
.66651 .02755 .67004 .03281 .67739 .02996 .67387 .0247 Mtetra
.67387 .0247 .67739 .02996 .68475 .02711 .68125 .02183 Mtetra
.68125 .02183 .68475 .02711 .69213 .02426 .68864 .01896 Mtetra
.68864 .01896 .69213 .02426 .69954 .02139 .69606 .01608 Mtetra
.04084 .26453 .04533 .26871 .05116 .26645 .04668 .26226 Mtetra
.04668 .26226 .05116 .26645 .057 .26418 .05252 .25998 Mtetra
.05252 .25998 .057 .26418 .06285 .26191 .05838 .2577 Mtetra
.05838 .2577 .06285 .26191 .06872 .25963 .06426 .25541 Mtetra
.06426 .25541 .06872 .25963 .0746 .25735 .07014 .25312 Mtetra
.07014 .25312 .0746 .25735 .08049 .25506 .07605 .25082 Mtetra
.07605 .25082 .08049 .25506 .0864 .25277 .08196 .24852 Mtetra
.08196 .24852 .0864 .25277 .09232 .25047 .08789 .24621 Mtetra
.08789 .24621 .09232 .25047 .09825 .24817 .09383 .2439 Mtetra
.09383 .2439 .09825 .24817 .1042 .24586 .09979 .24158 Mtetra
.09979 .24158 .1042 .24586 .11017 .24354 .10576 .23925 Mtetra
.10576 .23925 .11017 .24354 .11614 .24122 .11174 .23692 Mtetra
.11174 .23692 .11614 .24122 .12213 .23889 .11774 .23459 Mtetra
.11774 .23459 .12213 .23889 .12814 .23656 .12376 .23224 Mtetra
.12376 .23224 .12814 .23656 .13416 .23423 .12978 .2299 Mtetra
.12978 .2299 .13416 .23423 .14019 .23188 .13583 .22755 Mtetra
.13583 .22755 .14019 .23188 .14624 .22954 .14188 .22519 Mtetra
.14188 .22519 .14624 .22954 .1523 .22718 .14795 .22282 Mtetra
.14795 .22282 .1523 .22718 .15838 .22482 .15404 .22045 Mtetra
.15404 .22045 .15838 .22482 .16447 .22246 .16014 .21808 Mtetra
.16014 .21808 .16447 .22246 .17058 .22009 .16625 .2157 Mtetra
.16625 .2157 .17058 .22009 .1767 .21771 .17238 .21331 Mtetra
.17238 .21331 .1767 .21771 .18283 .21533 .17852 .21092 Mtetra
.663 .741 .908 r
.17852 .21092 .18283 .21533 .18898 .21295 .18468 .20852 Mtetra
.664 .741 .908 r
.18468 .20852 .18898 .21295 .19514 .21055 .19085 .20612 Mtetra
.19085 .20612 .19514 .21055 .20132 .20815 .19704 .20371 Mtetra
.663 .741 .908 r
.19704 .20371 .20132 .20815 .20751 .20576 .20324 .2013 Mtetra
.20324 .2013 .20751 .20576 .21372 .20335 .20946 .19888 Mtetra
.664 .741 .908 r
.20946 .19888 .21372 .20335 .21994 .20094 .21569 .19645 Mtetra
.663 .74 .908 r
.21569 .19645 .21994 .20094 .22618 .19859 .22193 .19403 Mtetra
.661 .737 .906 r
.22193 .19403 .22618 .19859 .23242 .19628 .22819 .19163 Mtetra
.649 .729 .907 r
.22819 .19163 .23242 .19628 .23865 .19426 .23445 .1894 Mtetra
.621 .71 .909 r
.23445 .1894 .23865 .19426 .24487 .19248 .24068 .18757 Mtetra
.627 .71 .906 r
.24068 .18757 .24487 .19248 .25118 .18993 .24694 .18566 Mtetra
.674 .758 .914 r
.24694 .18566 .25118 .18993 .25757 .18668 .25328 .18305 Mtetra
.695 .797 .929 r
.25328 .18305 .25757 .18668 .26388 .18441 .25966 .18014 Mtetra
.67 .757 .916 r
.25966 .18014 .26388 .18441 .27006 .18391 .26602 .17758 Mtetra
.656 .663 .845 r
.26602 .17758 .27006 .18391 .27635 .18229 .2724 .17499 Mtetra
.655 .631 .814 r
.2724 .17499 .27635 .18229 .28274 .17971 .27881 .17224 Mtetra
.508 .554 .838 r
.27881 .17224 .28274 .17971 .28867 .18316 .28502 .17212 Mtetra
.578 .508 .74 r
.28502 .17212 .28867 .18316 .29495 .18263 .29136 .17061 Mtetra
.636 .528 .714 r
.29136 .17061 .29495 .18263 .30144 .17957 .29787 .16714 Mtetra
.448 .406 .719 r
.29787 .16714 .30144 .17957 .30735 .18467 .30403 .1686 Mtetra
.61 .471 .668 r
.30403 .1686 .30735 .18467 .31398 .18019 .31058 .16512 Mtetra
.54 .434 .682 r
.31058 .16512 .31398 .18019 .32018 .18209 .31695 .16434 Mtetra
.55 .419 .655 r
.31695 .16434 .32018 .18209 .32663 .18079 .32338 .16305 Mtetra
.585 .443 .655 r
.32338 .16305 .32663 .18079 .33313 .17898 .32992 .16032 Mtetra
.545 .41 .648 r
.32992 .16032 .33313 .17898 .33958 .17824 .33638 .15915 Mtetra
.583 .434 .644 r
.33638 .15915 .33958 .17824 .34618 .17554 .34296 .15627 Mtetra
.573 .426 .643 r
.34296 .15627 .34618 .17554 .35278 .17304 .34953 .15381 Mtetra
.572 .425 .644 r
.34953 .15381 .35278 .17304 .35939 .1706 .35612 .15141 Mtetra
.602 .446 .643 r
.35612 .15141 .35939 .1706 .36612 .16621 .3628 .14756 Mtetra
.572 .429 .648 r
.3628 .14756 .36612 .16621 .37279 .16314 .36942 .1452 Mtetra
.61 .459 .652 r
.36942 .1452 .37279 .16314 .37953 .15897 .37613 .14124 Mtetra
.614 .463 .654 r
.37613 .14124 .37953 .15897 .38639 .15244 .38286 .13713 Mtetra
.571 .454 .681 r
.38286 .13713 .38639 .15244 .393 .15144 .3895 .13526 Mtetra
.668 .509 .661 r
.3895 .13526 .393 .15144 .40002 .14141 .39635 .12883 Mtetra
.574 .486 .717 r
.39635 .12883 .40002 .14141 .4067 .13947 .40301 .12721 Mtetra
.638 .529 .714 r
.40301 .12721 .4067 .13947 .4135 .13472 .40976 .12352 Mtetra
.681 .569 .722 r
.40976 .12352 .4135 .13472 .42044 .12625 .41658 .11858 Mtetra
.628 .616 .819 r
.41658 .11858 .42044 .12625 .42717 .12385 .42331 .11626 Mtetra
.638 .623 .819 r
.42331 .11626 .42717 .12385 .43395 .12031 .43006 .11374 Mtetra
.647 .662 .85 r
.43006 .11374 .43395 .12031 .44078 .11571 .43684 .11119 Mtetra
.636 .749 .93 r
.43684 .11119 .44078 .11571 .44756 .11296 .44362 .10899 Mtetra
.657 .787 .944 r
.44362 .10899 .44756 .11296 .45434 .11111 .45042 .10645 Mtetra
.696 .764 .904 r
.45042 .10645 .45434 .11111 .46115 .10855 .45727 .10325 Mtetra
.694 .734 .881 r
.45727 .10325 .46115 .10855 .468 .10523 .46412 .09996 Mtetra
.673 .728 .891 r
.46412 .09996 .468 .10523 .47486 .10216 .47099 .09708 Mtetra
.665 .734 .902 r
.47099 .09708 .47486 .10216 .48173 .09938 .47786 .09437 Mtetra
.664 .738 .905 r
.47786 .09437 .48173 .09938 .48861 .09664 .48476 .09167 Mtetra
.663 .74 .907 r
.48476 .09167 .48861 .09664 .49551 .09395 .49167 .08898 Mtetra
.664 .741 .908 r
.49167 .08898 .49551 .09395 .50243 .09127 .4986 .08628 Mtetra
.664 .741 .907 r
.4986 .08628 .50243 .09127 .50936 .08856 .50555 .08357 Mtetra
.663 .741 .908 r
.50555 .08357 .50936 .08856 .51632 .08586 .51251 .08086 Mtetra
.664 .741 .908 r
.51251 .08086 .51632 .08586 .52329 .08316 .51949 .07814 Mtetra
.51949 .07814 .52329 .08316 .53028 .08044 .52649 .07542 Mtetra
.52649 .07542 .53028 .08044 .53728 .07772 .53351 .07268 Mtetra
.53351 .07268 .53728 .07772 .54431 .075 .54055 .06994 Mtetra
.54055 .06994 .54431 .075 .55135 .07226 .5476 .0672 Mtetra
.5476 .0672 .55135 .07226 .55841 .06952 .55467 .06444 Mtetra
.55467 .06444 .55841 .06952 .56548 .06677 .56176 .06168 Mtetra
.56176 .06168 .56548 .06677 .57258 .06402 .56887 .05891 Mtetra
.56887 .05891 .57258 .06402 .5797 .06126 .576 .05614 Mtetra
.576 .05614 .5797 .06126 .58683 .05849 .58314 .05336 Mtetra
.58314 .05336 .58683 .05849 .59398 .05571 .5903 .05057 Mtetra
.5903 .05057 .59398 .05571 .60115 .05293 .59749 .04777 Mtetra
.59749 .04777 .60115 .05293 .60834 .05014 .60469 .04497 Mtetra
.60469 .04497 .60834 .05014 .61554 .04734 .6119 .04216 Mtetra
.6119 .04216 .61554 .04734 .62277 .04454 .61914 .03934 Mtetra
.61914 .03934 .62277 .04454 .63001 .04172 .6264 .03651 Mtetra
.6264 .03651 .63001 .04172 .63727 .0389 .63367 .03368 Mtetra
.63367 .03368 .63727 .0389 .64455 .03608 .64097 .03084 Mtetra
.64097 .03084 .64455 .03608 .65185 .03324 .64828 .02799 Mtetra
.64828 .02799 .65185 .03324 .65917 .0304 .65561 .02514 Mtetra
.65561 .02514 .65917 .0304 .66651 .02755 .66296 .02227 Mtetra
.66296 .02227 .66651 .02755 .67387 .0247 .67033 .0194 Mtetra
.67033 .0194 .67387 .0247 .68125 .02183 .67772 .01653 Mtetra
.67772 .01653 .68125 .02183 .68864 .01896 .68513 .01364 Mtetra
.68513 .01364 .68864 .01896 .69606 .01608 .69256 .01075 Mtetra
.03634 .26033 .04084 .26453 .04668 .26226 .04218 .25805 Mtetra
.04218 .25805 .04668 .26226 .05252 .25998 .04803 .25577 Mtetra
.04803 .25577 .05252 .25998 .05838 .2577 .0539 .25347 Mtetra
.0539 .25347 .05838 .2577 .06426 .25541 .05978 .25118 Mtetra
.05978 .25118 .06426 .25541 .07014 .25312 .06567 .24888 Mtetra
.06567 .24888 .07014 .25312 .07605 .25082 .07158 .24657 Mtetra
.07158 .24657 .07605 .25082 .08196 .24852 .0775 .24425 Mtetra
.0775 .24425 .08196 .24852 .08789 .24621 .08344 .24194 Mtetra
.08344 .24194 .08789 .24621 .09383 .2439 .08939 .23961 Mtetra
.08939 .23961 .09383 .2439 .09979 .24158 .09536 .23728 Mtetra
.09536 .23728 .09979 .24158 .10576 .23925 .10133 .23495 Mtetra
.10133 .23495 .10576 .23925 .11174 .23692 .10733 .23261 Mtetra
.10733 .23261 .11174 .23692 .11774 .23459 .11333 .23026 Mtetra
.11333 .23026 .11774 .23459 .12376 .23224 .11936 .22791 Mtetra
.11936 .22791 .12376 .23224 .12978 .2299 .12539 .22555 Mtetra
.12539 .22555 .12978 .2299 .13583 .22755 .13144 .22319 Mtetra
.13144 .22319 .13583 .22755 .14188 .22519 .1375 .22082 Mtetra
.1375 .22082 .14188 .22519 .14795 .22282 .14358 .21844 Mtetra
.14358 .21844 .14795 .22282 .15404 .22045 .14968 .21606 Mtetra
.14968 .21606 .15404 .22045 .16014 .21808 .15578 .21368 Mtetra
.15578 .21368 .16014 .21808 .16625 .2157 .1619 .21129 Mtetra
.1619 .21129 .16625 .2157 .17238 .21331 .16804 .20889 Mtetra
.16804 .20889 .17238 .21331 .17852 .21092 .17419 .20649 Mtetra
.17419 .20649 .17852 .21092 .18468 .20852 .18036 .20408 Mtetra
.18036 .20408 .18468 .20852 .19085 .20612 .18654 .20167 Mtetra
.18654 .20167 .19085 .20612 .19704 .20371 .19274 .19925 Mtetra
.19274 .19925 .19704 .20371 .20324 .2013 .19895 .19682 Mtetra
.663 .741 .908 r
.19895 .19682 .20324 .2013 .20946 .19888 .20517 .19439 Mtetra
.664 .741 .908 r
.20517 .19439 .20946 .19888 .21569 .19645 .21141 .19195 Mtetra
.21141 .19195 .21569 .19645 .22193 .19403 .21767 .18951 Mtetra
.663 .74 .908 r
.21767 .18951 .22193 .19403 .22819 .19163 .22394 .18707 Mtetra
.656 .737 .909 r
.22394 .18707 .22819 .19163 .23445 .1894 .23021 .18473 Mtetra
.633 .725 .914 r
.23021 .18473 .23445 .1894 .24068 .18757 .23647 .18274 Mtetra
.617 .711 .913 r
.23647 .18274 .24068 .18757 .24694 .18566 .24272 .18097 Mtetra
.64 .727 .911 r
.24272 .18097 .24694 .18566 .25328 .18305 .24902 .17886 Mtetra
.676 .764 .917 r
.24902 .17886 .25328 .18305 .25966 .18014 .25539 .17619 Mtetra
.705 .784 .913 r
.25539 .17619 .25966 .18014 .26602 .17758 .26181 .17307 Mtetra
.703 .756 .893 r
.26181 .17307 .26602 .17758 .2724 .17499 .26825 .1699 Mtetra
.659 .716 .891 r
.26825 .1699 .2724 .17499 .27881 .17224 .27464 .16744 Mtetra
.59 .705 .923 r
.27464 .16744 .27881 .17224 .28502 .17212 .28096 .16599 Mtetra
.656 .673 .854 r
.28096 .16599 .28502 .17212 .29136 .17061 .28739 .16342 Mtetra
.671 .643 .814 r
.28739 .16342 .29136 .17061 .29787 .16714 .29388 .16029 Mtetra
.54 .594 .857 r
.29388 .16029 .29787 .16714 .30403 .1686 .3002 .15964 Mtetra
.655 .591 .771 r
.3002 .15964 .30403 .1686 .31058 .16512 .30673 .15641 Mtetra
.602 .57 .79 r
.30673 .15641 .31058 .16512 .31695 .16434 .31317 .15457 Mtetra
.597 .544 .765 r
.31317 .15457 .31695 .16434 .32338 .16305 .31963 .1527 Mtetra
.63 .551 .747 r
.31963 .1527 .32338 .16305 .32992 .16032 .32618 .14983 Mtetra
.589 .526 .752 r
.32618 .14983 .32992 .16032 .33638 .15915 .33267 .14806 Mtetra
.623 .535 .735 r
.33267 .14806 .33638 .15915 .34296 .15627 .33925 .14523 Mtetra
.612 .53 .738 r
.33925 .14523 .34296 .15627 .34953 .15381 .34582 .14273 Mtetra
.609 .528 .738 r
.34582 .14273 .34953 .15381 .35612 .15141 .35241 .1403 Mtetra
.637 .544 .732 r
.35241 .1403 .35612 .15141 .3628 .14756 .35905 .13702 Mtetra
.607 .536 .749 r
.35905 .13702 .3628 .14756 .36942 .1452 .36566 .13474 Mtetra
.643 .558 .744 r
.36566 .13474 .36942 .1452 .37613 .14124 .37234 .13142 Mtetra
.644 .571 .758 r
.37234 .13142 .37613 .14124 .38286 .13713 .37902 .12824 Mtetra
.607 .572 .788 r
.37902 .12824 .38286 .13713 .3895 .13526 .38567 .12621 Mtetra
.691 .611 .762 r
.38567 .12621 .3895 .13526 .39635 .12883 .39244 .1218 Mtetra
.616 .63 .842 r
.39244 .1218 .39635 .12883 .40301 .12721 .39911 .11982 Mtetra
.643 .631 .823 r
.39911 .11982 .40301 .12721 .40976 .12352 .40583 .11722 Mtetra
.701 .693 .839 r
.40583 .11722 .40976 .12352 .41658 .11858 .41261 .11354 Mtetra
.664 .732 .901 r
.41261 .11354 .41658 .11858 .42331 .11626 .41936 .11089 Mtetra
.618 .699 .903 r
.41936 .11089 .42331 .11626 .43006 .11374 .4261 .10896 Mtetra
.622 .731 .925 r
.4261 .10896 .43006 .11374 .43684 .11119 .43287 .10695 Mtetra
.656 .772 .935 r
.43287 .10695 .43684 .11119 .44362 .10899 .43967 .10443 Mtetra
.688 .767 .912 r
.43967 .10443 .44362 .10899 .45042 .10645 .4465 .10138 Mtetra
.7 .746 .888 r
.4465 .10138 .45042 .10645 .45727 .10325 .45336 .09803 Mtetra
.687 .736 .888 r
.45336 .09803 .45727 .10325 .46412 .09996 .46022 .09489 Mtetra
.669 .737 .901 r
.46022 .09489 .46412 .09996 .47099 .09708 .4671 .09209 Mtetra
.664 .74 .906 r
.4671 .09209 .47099 .09708 .47786 .09437 .47398 .08939 Mtetra
.664 .741 .907 r
.47398 .08939 .47786 .09437 .48476 .09167 .48089 .0867 Mtetra
.663 .741 .908 r
.48089 .0867 .48476 .09167 .49167 .08898 .48781 .08399 Mtetra
.664 .741 .908 r
.48781 .08399 .49167 .08898 .4986 .08628 .49475 .08128 Mtetra
.49475 .08128 .4986 .08628 .50555 .08357 .50171 .07856 Mtetra
.663 .741 .908 r
.50171 .07856 .50555 .08357 .51251 .08086 .50869 .07584 Mtetra
.664 .741 .908 r
.50869 .07584 .51251 .08086 .51949 .07814 .51568 .07311 Mtetra
.51568 .07311 .51949 .07814 .52649 .07542 .52269 .07037 Mtetra
.52269 .07037 .52649 .07542 .53351 .07268 .52972 .06762 Mtetra
.52972 .06762 .53351 .07268 .54055 .06994 .53677 .06487 Mtetra
.53677 .06487 .54055 .06994 .5476 .0672 .54383 .06211 Mtetra
.54383 .06211 .5476 .0672 .55467 .06444 .55092 .05934 Mtetra
.55092 .05934 .55467 .06444 .56176 .06168 .55802 .05657 Mtetra
.55802 .05657 .56176 .06168 .56887 .05891 .56514 .05379 Mtetra
.56514 .05379 .56887 .05891 .576 .05614 .57228 .051 Mtetra
.57228 .051 .576 .05614 .58314 .05336 .57944 .0482 Mtetra
.57944 .0482 .58314 .05336 .5903 .05057 .58661 .0454 Mtetra
.58661 .0454 .5903 .05057 .59749 .04777 .59381 .04259 Mtetra
.59381 .04259 .59749 .04777 .60469 .04497 .60102 .03977 Mtetra
.60102 .03977 .60469 .04497 .6119 .04216 .60825 .03695 Mtetra
.60825 .03695 .6119 .04216 .61914 .03934 .6155 .03412 Mtetra
.6155 .03412 .61914 .03934 .6264 .03651 .62277 .03128 Mtetra
.62277 .03128 .6264 .03651 .63367 .03368 .63006 .02843 Mtetra
.63006 .02843 .63367 .03368 .64097 .03084 .63736 .02558 Mtetra
.63736 .02558 .64097 .03084 .64828 .02799 .64469 .02271 Mtetra
.64469 .02271 .64828 .02799 .65561 .02514 .65203 .01985 Mtetra
.65203 .01985 .65561 .02514 .66296 .02227 .6594 .01697 Mtetra
.6594 .01697 .66296 .02227 .67033 .0194 .66678 .01408 Mtetra
.66678 .01408 .67033 .0194 .67772 .01653 .67418 .01119 Mtetra
.67418 .01119 .67772 .01653 .68513 .01364 .68161 .00829 Mtetra
.68161 .00829 .68513 .01364 .69256 .01075 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14703 .21212 m
.15165 .21677 L
s
[(-0.1)] .13778 .20281 .99298 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.55471 .05248 m
.55858 .05778 L
s
[(0.1)] .54696 .04189 .73149 1 Mshowa
.125 Mabswid
.18507 .19722 m
.18781 .20005 L
s
.22368 .1821 m
.22638 .18497 L
s
.26288 .16675 m
.26553 .16966 L
s
.30267 .15117 m
.30528 .15412 L
s
.38409 .11929 m
.38661 .12231 L
s
.42575 .10298 m
.42822 .10604 L
s
.46806 .08641 m
.47049 .08951 L
s
.51104 .06958 m
.51342 .07272 L
s
.10954 .2268 m
.11235 .22955 L
s
.0726 .24126 m
.07544 .24398 L
s
.59907 .03511 m
.60134 .03833 L
s
.64416 .01746 m
.64637 .02071 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[80]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00boooool2o`0005?ooooo0038
ooooo`?o000000?oooooo`000?ooool0D_ooool00<Kooooo0_l00004ooooo`;o0000D_ooool009Wo
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Looooo`?o00001Oooool01?nY_NSo
0000ooooool0001Aooooo`00V?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
01Wooooo0_l00004ooooo`GoZKgX00?o0000ooooool00000DOooool009Sooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`0Fooooo`?o00001?ooool7ojVmj004o`000?oooooooooo
o`00053ooooo002Hooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool05?ooool2
o`0000;ooooo00?o0000ooooooooool02OnY_NP01Ol0003oZKgXoooooooooooo000004oooooo002H
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool04Oooool3o`0000?ooooo3OnY
_NP01Ol0003oZKgXojVmj?oooooo000004oooooo002Hooooo`04o`000?ooooooooooo`0000Sooooo
0_l0000@ooooo`?o00001?ooool?ojVmj003o`000?nY_NSoZKgX00;ooooo00?o0000ooooooooool0
C?ooool009Wooooo0_l0000:ooooo`03o`000?oooooooooo00cooooo0_l00005oooooa7oZKgX00Co
0000ojVmj?nY_NSoZKgX0ol0001=ooooo`00/Oooool5o`0000;ooooo5?nY_NP00ol0003oZKgXojVm
j002ojVmj003ooooool0003ooooo04cooooo002_ooooo`;o00001OoooolFojVmj003o`000?nY_NSo
ZKgX00?oZKgX00?oooooo`000?ooool0Boooool00:cooooo0ol00003oooooa_oZKgX00?o0000ojVm
j?nY_NP00_nY_NP00ooooooo0000ooooo`1;ooooo`00Z_ooool2o`0000Cooooo7OnY_NP00ol0003o
ZKgXojVmj003ojVmj003ooooool0003ooooo04[ooooo002Wooooo`?o00001?oooolOojVmj003o`00
0?nY_NSoZKgX00CoZKgX00?oooooo`000?ooool0BOooool00:Gooooo0_l00003ooooo`03o`000?nY
_NSoZKgX023oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oooooooooo`18ooooo`00X_ooool3
o`0000Cooooo9?nY_NP00ol0003oZKgXojVmj005ojVmj003ooooool0003ooooo04Sooooo002Poooo
o`;o00001OoooolVojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00018ooooo`00WOooool3o`0000?o
oooo:_nY_NP00ol0003oZKgXojVmj006ojVmj003ooooool0003ooooo04Oooooo002Kooooo`Co0000
0_ooool/ojVmj003o`000?nY_NSoZKgX00OoZKgX00?oooooo`000?ooool03Oooool2o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0002_ooooo002Hooooo`?o00000oooool_ojVmj003o`000?nY
_NSoZKgX00OoZKgX0_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool0:_ooool009Gooooo0ol00004oooooc7oZKgX00?o0000ojVmj?nY_NP02?nY
_NP00ooooooo0000ooooo`04ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo02[ooooo002Cooooo`;o00001OoooolcojVmj003o`000?nY_NSoZKgX00WoZKgX00?o
ooooo`000?ooool02_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo02[ooooo
002@ooooo`?o00000ooooolgojVmj003o`000?nY_NSoZKgX00[oZKgX00?oooooo`000?ooool02Ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo02[ooooo002>ooooo`;o00000ooo
ool00ol0003oooooojVmj00gojVmj003o`000?nY_NSoZKgX00[oZKgX00?oooooo`000?ooool02Ooo
ool01?l0003oooooooooool00008ooooo`;o0000;?ooool006cooooo0_l0000Mooooo`?o00000ooo
ool01?n[_>KoZKgWojVmionY_NL:ojVmj0;oZKcW1onY_NP2ojVmi`03ojVmj?nY_>OoZKgX023oZKgX
00?o0000ojVmj?nY_NP02onY_NP2o`0000[ooooo0_l0000:ooooo`03o`000?oooooooooo02[ooooo
001[ooooo`04o`000?ooooooooooo`0001[ooooo0_l00004ooooo`;o[kcS0_n[_>H01OnY_NOoZ[_V
ojZki_nY_>OoZKgX00;oZKcW00?oZKgXojVki_nZ_>L00_nZ_>L01_nY_>OoZ[_UojVlionY_>OoZKgX
ojVkiP?oZKcW00?oZKgWojZli_nZ_>H00_nY_>L00onY_NSoZKcWojVmj00MojVmj003o`000?nY_NSo
ZKgX00_oZKgX0_ooool00ol0003oooooooooo`10ooooo`00Joooool01?l0003oooooooooool0000G
ooooo`?o00001?ooool2ok>nh`03ojnlhona^n7o[;[T00;o[;[T00KoZ[_VojZhhonZ^^GoZ[[UojVl
ionZ^><3ojVkiP03ojZlionZ^NCoZ[WT00;oZ[_U00GoZKcWojZii?nY^nKoZK_VojVli`02ojZji@06
ojZli_nZ^NCoZ[_UojZkiOnY_>OoZ[[T0onY_>L00onY_NSoZK_VojVmi`02ojVmi`03ojVmj?nY_NOo
ZKgX00;oZKgX0_nY_NL?ojVmj003o`000?nY_NSoZKgX00coZKgX00?oooooo`000?ooool0@Oooool0
06_ooooo00Co0000oooooooooooo00005Oooool2o`0000;ooooo00Oo0000oooooooooooooooook34
jOnc_^?o//?W00?o/K_Q00?o[;[Tojjfgon^]]l00_nZ^><01OnZ^^GoZkCPojZhhonZ^>?oZK_V00;o
ZKCP00?oZ[WTojZ_fon[]N400_n[]N401_nZ^NCoZ[KRojZfh_nZ]^;oZ[[UojZcg`?oZ[WT00GoZ[_U
oj^ghOnZ^^CoZ[[TojVli`02oj^ii0;oZK_V00CoZKgWojZki_nZ^nKoZKgW0onZ_NL00onY_NOoZ[gW
ojVmi`02ojVmi`03ojVmj?nY_NOoZKgX00WoZKgX00?o0000ojVmj?nY_NP03?nY_NP2ooooo`03o`00
0?oooooooooo03oooooo001[ooooo`04o`000?ooooooooooo`0001;ooooo0ol00004ooooo`;oWk_/
0_nWaNl01On`a>WoZ<Waok;3ionb`nOo/K_Q00;o/[cQ00?o[[KOojn^eon[/=/00_n[/=/01_n[]>3o
[:kIojb^fOn/[]WoZKCPojZUd@?oZZoK00GoZkGQoj^Xe?n//=_o[;3KojZfhP02ojbZe@;oZ[?O00Co
Z[WToj^`fon[/=_oZkOQ0on/]=l00on[^NCo[K;Loj^hh`02oj^hh`05ojZki_n[]n;oZkORojZki_nZ
_NL00_nZ^nH2ojZmi`04ojVmionZ_NOoZ[gWojVmi`[oZKgX00?o0000ojVmj?nY_NP03OnY_NP2oooo
o`03o`000?oooooooooo03kooooo001[ooooo`04o`000?ooooooooooo`00013ooooo0_l00004oooo
o`?oW[;W00?oWk_/ojFYfOnR_nh00_nR_nh01_nXbO7oW;[]ojS5k_nXaNko/[cQojbdgP?o[jkG00Ko
Zk3KojZObon[Ym?oZjOCojb^fOn[VlH3ojZUd@06ojZ_fonYVlOoZjSDoj^Xe?n//=_o[9o:0on/Z]D3
ojbTc`06oj^`fon/W/Wo[:cGojb/eon/]=oo[JWC0on]/]`01On[^>?o[K3Jojf`f_n[]n;o[JoI00;o
ZkOR00?oZ[_Voj^ghOnZ^nH00_nZ^nH01OnZ_NOoZ[_VojZki_nZ_NOoZKgX00;oZ[gW1_nY_NP00ol0
003oZKgXojVmj00>ojVmj003ooooool0003ooooo03oooooo001/ooooo`;o00003_ooool3o`0000Co
oooo0_nc/MH00onY^nKoW[;Woj>Od@03ojFYf@04oj:ok_nUWLkoYIg>oibjk@;oV:SQ0on/]=h00on_
[]OoZi[6ojZOb`02ojZOb`06oj^Wdon[VlKoZi_6oj^Ka_nZYM7oZHji0onYVlL01On[Z=Co[9o:ojbO
b_n/Wl[o[:[E00;o[9O000?o[:C?ojb?^?n/W/T00_n/W/T01On/[=Oo[JWCojfYdon]ZM?o[K;L00;o
[jK?00Go[K3JojnSbon][mWo[JoIoj^ghP02ojj^f0;oZkOQ00GoZ[_Voj^ghOn[]n7oZ[_Voj^ghP02
ojZkiP03ojZmionZ_>KoZ[gW00;oZ[gW0onY_NP00ol0003oZKgXojVmj00?ojVmj003ooooool0003o
oooo03kooooo001jooooo`;o000000?oooooo`000?ooool00_ooool01OnTXM;o/k7Fok>ae_nc/MKo
X9gA00?oXioA00?oYJWIojR:]?nUWLh00_nUWLh2oi^9_`;oV:SQ00?o[;CNoib?aOn[V/H00_n[V/H0
1_nZWl_oYXFbojR@_OnXT;goZi_6ojN4[P?oZHji00KoZI_7ojN3[_nYTKgoZI6mojbOb_nZRK83ojbG
`0?o[8nh00Ko[9k9oj^9/On/VL?o[9W3ojfYdon]U[h3ojnVc`?o[j?;00Co[JoIojj^f?n^[]So[ZkH
0on^[]L01On[]n7o[ZoHoj^gh_n[]n;oZ[_V00;oZkSR0_nZ_>H01_nZ_NOoZ[cVojZli_nY_NSoZ[cW
o`0001;oZKgX00?oooooo`000?ooool0?Oooool007Oooooo0ol00004ooooo`;oWJ7G0onTXM801_nc
/MKo[Y6hojjA^?nPWM7oXioAoj21/P?oZ8Zd00CoYIg>ojAjY?nTNZCoVhVo0_nBMJl3oib?a@03oj^J
a_nQO:_oYXFb00;oYXFb00CoZ92mojN4[_nWQ:koYhB^0_nYS[T3ojN3[P05ojVA_OnZRK;oZXVbojZ9
/_n/Ul000_n[PjT2ojb?^0?oZhVa00Go[9W3ojfF__n]U[ko[IJnojnVc`02ojnC^P05ojnSbon`T[Oo
/:;9ok2RbOn^[]P00_naXLP00on^[]Oo/Z;8ojj_f002ojj_f004oj^gh_n^/=WoZkSRojjbf`?oZkSS
00OoZ[cVoj^ii?n[^NCoZ[cWojVmj?l0003oZ[cW013oZKgX0_l0000nooooo`00M?ooool3o`0000Go
oooo00?oVi;9ok2L`on`W<<00_nMXML00onTXM;oXhNfojjA^002ojjA^004oiIf[_nPPK;oX86boj21
/P;oZ8Zd0onTNZ@01_nKRKooTWF_oi9e[onBMJooW8o5oi=ZX0;oXGb[0onVQK801_nXT;goYhB^ojN4
[_nWQ:koZHjiojMjXP?oYh>^0_nVO:D2ojZ9/P?oZh>Y00?o[8nhoj]nXon[RK400_n[RK42ojb5[003
ojfF__n]PjSo[i>j00;o[i>j0on`T[L01?n`X/Wo/J78ok6Qb?naXLP3ok:Rb004ojj_f?nbY<[o/ZC:
ojj`f@?o[[;K00GoZkSSojjdgOn^]=goZkWTojjgg`02oj^ji@03o`000?n[^nKoZ[cW00;oZ[cW00?o
ZKgXojZmionY_NP02_nY_NP2ooooo`03o`000?oooooooooo03_ooooo001booooo`;o00001_ooool0
1OnTT/;oVi;9oi^BbOnKT/Wo/9c300;oTWbg0onSQkH2ojjA^0;oUWJ^0_nPPK800onXR[CoYgFKojAj
Y002ojAjY0;oWVfJ0_nBMJl2oi=ZX0?oXGb[0_nVQK82oj=hY0;oYhB^0onWNZ82ojN3[P;oYWbU00?o
ZXVbojMhW_n[PjT00_n[PjT3oj]nX`;oZhVa0_n/QJ`3ojf3Z003ojnC^_n^PjKo[X>V00;o/9:g0_na
T[H01OnaXLSo/i:fok>B]_nbX/So]9Bf00?o/ZC:0_ncYl`01On^/]_o/j[@ok>Zd?n^]=go/ZkD00;o
[[OO00?oZk[Uojfih_l000000_n[^nH3ojZli`03ojZmionY_NSoZKgX00[oZKgX00?oooooo`000?oo
ool0??ooool006oooooo1?l00005ooooo`04ojB>__nTT/;oY9;2ojBB`P;oVi;900Co/9c3oj^2ZOnB
O;OoTWbg0_nSQkH01_n^TKSoZGVOojUiWonFMZkoX86boiQZW0?oYgFK0_nTNZ@2oii]VP03oi9e[onH
I9?oTfZP00;oTfZP0_nQO:/01_nVQK;oXG6Loj=hY?nSN:CoYhB^oj=bV`?oYgZR00CoYh>^ojIdVonV
M9_oYWbU0onWN9h2oj^3Z@?oZgjS00CoZhVaojakW_n/Niko[8F/0on]PjP3ojj3YP04ok2B]on`PjCo
/8>Tok6B]P?o/i:f0ondU;H01?nbY<[o]INhok>Wc?nfV[`3ok>Zd0?o/ZkD00Co[[OOok6bfOn]^N;o
00000on/^n@01OnZ_>OoZkcVojZmionZ_NOoZKgX00;oZ[gX2OnY_NP00ooooooo0000ooooo`0koooo
o`00KOooool2o`0000Cooooo00Co0000oooooonSRk_oVhVo0onTS[h01?nTT/;oWGJWoi9d[_nBM:h2
oj^2Z@;oTWbg00?oXhNfoi]`XOnYNIl00_nYNIl00onFMZkoV6ZLoiQZW003ojMeV`04ojAjY?nVKY;o
WVfJoii]VP;oV6BC0onCJZ001?nQO:_oVfRFoj5aW?nQLI`2oj=hY0?oXg:K0_nWNZ83ojIdV`05ojIl
YOnWN9koYgRNojMhW_n[PjT00_nYMYX2oj]nX`?o[7^N0_n]NY/2ojf3Z0?o[X>V0on`Pj@01OnaT[Ko
/HBTok>B]_ncT[Ko/hFT00;o]9Bf0_neUkP3okJJ_004ok>Zd?nfW/3o]Yk0ok:^e0;o]J?600Go/K;I
ok2egOl0003o/;GMojbki002ojjgh005oj^li_nZ_>KoZ[cVojZli_nZ_NP00_nZ_>L9ojVmj003oooo
ool0003ooooo03[ooooo001Zooooo`?o00001_ooool01onKQkcoXh^koj>;^onSRk_oVhVoojB>__nL
MJH00_nMMZL2oi9d[P;oZh:Y0_n=I9d2oi]`X@?oZGVO00?oTf>GoiQZW?nHJY`00onWMI/01?nTNZCo
YVjBojI^T_nNKIX3oiQTT`;oTfZP0_nKJ9H2oj5aW0;oXgRT0onSLY/2ojMjXP?oYWBK00CoYW6FojMh
W_nWN9koYgRN0onYMYX2oj]nX`?o[7^N0_n]NY/00on]PjSo[WVIojiiV@02ojj3YP?o/8>T0_naQ:@0
1?ncT[Ko/hFTok>5Y?ndU;H2okB7Y@04okFG^?nfRJOo]YZlokJJ_0?o]Yk00oneXlH2okBWb`04o`00
0?ncZm7o/j_Aojjgh0;o/K3G00Ko[;SRojZli_n[^^CoZk[TojZlion[_>H3ojZli`KoZKgX00?ooooo
o`000?ooool0>_ooool006Sooooo0_l00006ooooo`;oW8Nl0onKQk`2oj>;^`03oi^9_onLMJKoW7FV
00?oWGJW00?oTWB^oj^2ZOn[PZT00_n=I9d3oi]`X@;oZGVO00CoTf>GoiQZW?nHJYcoV6ZL0_nWMI/3
ojI^TP04oii]V_nHI9?oV6BCoiQTT`;oTfZP0_nKJ9H2oj5aW003oj=hY?nQK9CoXg:K00;oXg:K00?o
YgZRojI`U?nVM9/00_nVM9/2ojIaUP;oYgRN0onYMYX00on[OZ?o[7FFojakWP02ojakWP;o[GZK00Co
[H>XojiiVOn^NIWo[X>V0_n`NYP2ok23Y0;o/HBT0oncQJ@3okB7Y@;o]XVW00Co]YZlokN=Z_ngSJ[o
]Yk00_ngTJh01oneXlKo^9FcokBWbonhVk[o0000ok>[dOnhXl<00ona/=L2ok2eg003oj^ji?n^^N;o
[[WR00;oZkcV00CoZ[cWojZmionZ_NSoZ[gX1OnY_NP00ooooooo0000ooooo`0iooooo`00IOooool3
o`0000Cooooo00?oXHfooiJ6`?nFQ/000_nOR;`2oib7_0;oVhNl00?oXh^koiYbY?nBKJD00onLMJH2
oiefY`03oi9d[_n[PZWoYW>I00?oSFBM0_nKL:401?nYNIooZ72Boi=SUonCHiL2oiQZW0;oYgFK0onV
KY801_nTJHgoV6BCoiQTTonHI9?oTfZPoiMQS`?oVfRF00CoXG6Loj5/U?nQK9CoXFbD0_nSLY/3ojI`
U0;oYWBK0_nVLIH00onWN9koZ72CojUfVP02ojUfVP?o[7FF00Co[7^NojieTon]NY_o[GZK0on^NIT0
1?n^PjKo/7ZHok1jV?n`Pj@2ok5kU`04ok64Y?ncQJCo/hFTok>5Y0?o]8NU0_nfRJL3okN=ZP?o]i6^
0_nhUK<2okRK^P07o`000?nhXl?o^:?3okRS`ona/=Oo^:c=ok2eg002okFce`06ojjih_na^=ko[;cU
ojbliOnZ_NOoZkcV0onZ_NP4ojVmj0;ooooo00?o0000ooooooooool0=oooool006?ooooo0_l00003
ooooo`03o`000?oooooooooo00?oXHfo0_nFQ/000onOR;coW8Nloi9]Y002oi9/Y0;oVW:T0_nBKJD2
oiaeYP;oWGJW00CoQejJojIcVOnVLiWoYW>I0_n=I9d2oi]`X@04ojUiWonXL9;oTf>Goi=SU`;oV6ZL
00?oYgFKojE/TOnVKY800_nVKY82ojAYS@;oV6BC0_nGHHl3oi]XUP04oj5aW?nQK9CoXFbDoj5/U0;o
Xg:K0onVL9@01OnVM9_oZ6nAojIaU_nVLIKoYgRN00;oZ72C0_nYMYX3ojaeUP04ojakW_n^MI?o[WFC
ojejV`?o[WVI0on`NYP01_n`PjCo/G^Gok5kUonaQ:Co/gbGok>5Y0;o]GjH00Co]8NUokN0V?ngP9So
]XVW0ongSJX02OnjQIco]i6^okNA[_nkRJ3o^9Fcokf>YOnhVk[o0000okjE[@02okRS``03oknM]onh
[<go]K?G00;o]K?G0ona^=h01On/_>Go[[WQoj^li_n[_>KoZ[gX00;oZ[cW00CoZKgXojVlionY_NSo
ZKgX0_l0000iooooo`00H?ooool3o`0000Cooooo00?oYiO5oiZAb_nJTLX00_nHRl<2oj6=_`;oUXK0
00?oWhRloi9]Y?nBKJ@00_nBK:@2oiYbY0;oTVfU0_nLMJH00onMMZOoVVRGohMNVP03ojIcV@;oSFBM
00CoVg2Qoi5PU?nXL9;oZ72B0_nCHiL2oiQZW0;oYFbA0onVKY82ojAYS@;oV6BC0onGHHl2oi]XUP06
oj5XT?nQK9CoXFbDoj5/U?nSLY_oXfZ@0onVL9@01?nVM9_oZ6nAojIaU_nVLIH3ojQ`T`03ojUfV_n[
LI7o[7FF00;o[7FF00Co[7^NojieTon^MI?o[GZK0on^NIT3ok1jV0?o/G^G0_ncO9L01?ncQJCo]GjH
okEnV?ndQjD2okN0V003okJ9YonhPY[o]hfZ00;o^XFL00?o]i6^ok^9X?nkRJ000_nmSZD01?nhVk[o
0000okjE[OnhXl<2oknM]`;o_JG200Oo]K?GokV[c?niZlco/KSNokB_e?n^^N7o/KCK00?o[;[S00Go
Z[cWoj^kiOn[^nGoZKcWojVmj002ojVmi`03ooooool0003ooooo03Oooooo001Nooooo`;o00001?oo
ool00on[Y=3oRYSKojNGa@02ojNGa@;oVY7:00?oV8_3oj6=_onELJL00_n;J:D01?nEKjCoTVfToi9]
Y?nBKJ@2oi9/Y005oiYbY?nBKJGoTVfUoiaeY_nCI9P00_nJJ9L01_n7GY[oYW>IojIcVOnVLiWoSFBM
ohmLT@;oTF2D0_nXL982oi=SU`04oiQZW?n@GI7oYFbAojE/T@?oYVjB0_nTJHd00onHI9?oXVJ;oiMQ
S`02oiMQS`;oVfRF00KoXFR@oj5/U?nQK9CoXFbDoj=bVonSJY03ojI`U004ojIdVonXKi7oZ6nAojIa
UP?oZ72C00?oZGJJoj]aTOn/MIH00_n/MIH3ojieT`;o/7JB00?o[WVIok9gTOn`NYP00_n`NYP3ok5k
U`;o/gbG0oneOYP00ondQjGo]h2HokN0V002okR2VP03okN=Z_njQIco^XFL00?o^hVP0_nmSZD00onn
UJgo0000okjE[@03oknM]`04ol6DZOnmYL;o_iZbokV[c0;o_J:m00Go]:oDok6dfona]=_o/KCKojbj
h`02ojnih@05oj^kiOn]^nCoZ[cVojZli_nY_NL00_nZ^nH00ooooooo0000ooooo`0fooooo`00Fooo
ool3o`0000Cooooo00OoYjcJoj^Td?n[Y=3oZjC@ohZHfonWUlGoW7R[00;oRVn^00?oS6^WoiEaYonE
LJL00_n;J:D2oiE_Y0;oTVfT0_nBK:@00onJLZCoTVfUohiOUP02oi=TV0?oVVRG00?oQejJojIcVOnV
LiT00_n?G942oi5PU0;oZ72B0_nCHiL2oi1MT@?oYFbA0_nVKY82ojAYS@03oiQTTonRIX_oUf6?00;o
Uf6?0_nKJ9H2oj5XT0;oXFbD0onSJY02ojI`U0?oZ6nA00GoYW6FojQ`TonXL9?oZ72CojUfVP02oj]a
T@;o[7FF0on^MI<2ok1fTP05ojiiVOnbMi7o/WNAok1jV?ndN9000onaNiL2ok=lU`?o]GjH0ongP9P2
okR2VP?o^XFL0onkRJ02okf>Y@05ol:;W?l0003o_YF]ol:@X_noWKL00_o1U:T00onmYL;o_iZbokfR
_@02okfR_@;o_:c:00Co/KCKokRfeonh]]Oo[kWQ0_nb^=h02?n]^nCoZ[cVoj^ihon[^N?oZ[_Voj^f
h_oooooo0000=oooool002cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Ooooo
o`;o00000_ooool01Ol0003oooooojRgi?nX]nCoUkC/00;oYjcJ00?oZjC@oj:7]_mbIkP00_nLN:/2
ohY_[P04oha[YonELJOoUG6WoiEaY`;oRfRU00?oUFnToi9]Y?nBKJ@00_nBK:@00onJLZCoSUnFohiO
UP02oi=TV0?oVVRG00?oQejJojIcVOnVLiT00_n?G942oi5PU0;oZ72B00CoTf>GoiMPS_n@GI7oT5fA
0onUK9401_nVKY;oZVb<ojAYSOnTJHgoV6BCoj9VR`?oUf6?00CoVfRFoieSSOnQJ93oXFR@0_nQK9@3
oj=ZT0;oYW2D0onXKi401?nVLIKoZ72CojQ`TonXL9<3oj]aT@03ojaeU_n_LXoo[WFC00;o[WFC0_n`
MY801?n^NIWo/WNAok9gTOn`NYP2okAhT004ok5kUonfNY3o/gbGok=lU`?o]GjH0ongP9P2okR2VP;o
^XFL0_noQ9@01_nkRJ3o`HNGol67UonmSZGo`X^Lo`0000;o`Y2R0oo1U:T2oknJ/P07olFFY_nmX[go
_J:molJQ/onl[<[o`jc3okRfe`02okbbd005ok:hg_nf]mWo[[OOojjggon[^N<00_n]]n42oj^fhP03
ooooool0003ooooo03Gooooo000[ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool06oooool3o`0000?ooooo0onc`N@00onX]nCoYj7@oh:=eP02oi>2_@?oXXNf0onLN:/00on:Kjko
S6^Woha[Y`02oiEaY`;oRfRU00?oUFnToi9]Y?n<GYH00_n<GYH00onCHiOoSUnFohiOUP02oi=TV0?o
VVRG00?oQejJojIcVOnUK9400_n?G942oi5PU0;oZ72B0_nGH8h2oi1MT@?oYFbA00CoYVjBojY/S?nT
JHgoY6V=0_nRIX/3oiMQS`06oi]XU_nMHhgoXFR@oj5XT?nQK9CoY6V=0onSJY000onVL9CoZ6b>ojQ_
T@02ojQ_T@04ojY_S_nXL9?oZ72CojQ`T`?oZg6A00?o[7FFojmbSon^MI<00_n^MI<2ok1fTP?o/WNA
00Co/7ZHokAhT?ndN93o/G^G0_nfNY001?ncO9Oo^7^@okEnV?njOI02okN0V005okaoTOnhPY[o^8:J
okf1T_njQI`00_noQ9@00onkRJ3o`HNGol67U`02ol:;W003o`000?o2T:;o`Y2R00?o`IBY00Co_iZb
olFFY_o5UZKo_J:m0_o6XK<2ol>/``?o_;;@0_nf]mT01On^]moo/kkRok>nh_n]]n7o[l;X00;o[KWR
0_ooool00ol0003oooooooooo`0cooooo`009?ooool5o`0000;ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`0Hooooo`?o00001?ooool2ojg3jP03okC8jOnc`NCoYjWH00?oYj7@
00?oPXgFoi>2_OnCP[d00_nRQkH01?mbIkSoW7R[oiahZon:Kjh2oha[Y`;oUG6W0_n;J:D00onEKjCo
S5jFohaNUP02ohaNUP04oi=SUon>GiKoSUnFohiOUP;oTfBH0_nJJ9L00on7GY[oYW>IojE/T@03ohmL
T@03oi5PU?nXL9;oZ72B00;oUf2>0on@GI42ojE/T@04ojI^T_nZK8coY6V=ojAYS@?oXVJ;0_nGHHl2
oieSS@;oXFR@00?oXFbDojAYSOnSJY000_nSJY000onVL9CoZ6b>ojQ_T@02ojQ_T@;oZVn>0_nXL9<3
oj]aT@03ojaeU_n_LXoo[g:?00;o[WFC0_n`MY83ok9gT@?o]7R@00?o/G^GokIjT?nfNY000_nhNi00
1?neOYSo^Wf@okYmT?ngP9P2okaoT@03okR2V_nmPI;o^XFL00;o_hBD00?o^hVPol67Uoo1QiL00_o2
Ri`01ol0003o`Y2Rol>:V?o3RYSo`IBYol>>WOnoV[800_o5UZH3olJQ/`04ol>/`oo6YKSoaZFhokbb
d0;oa;G<00?o][OIokk:i?nc_^800_n^co42ojo2j004ojfih_n[`>Woooooo`0003Gooooo000[oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool05_ooool2o`0000Gooooo0_nS^^T0
1?n]`n[o/Lc]ok7<kOn[`NX2ojNYf003ojNQd?nJO[?oH5:[00;oTh:m00?oXXNfoiA/XOmbIkP00_nL
N:/01OmiDiWoS6^Woha[YonELJOoRUjH00;oQEVF00?oSEnGohaNU_n<GYH00_n<GYH01?nCHiOoSUnF
ohiOU_n>GiH2oi=TV0;oVVRG00?oOe6@ojE/TOnUK9400on?G9400onAH9CoZ72Boj]_SP02oiMPSP?o
T5fA0_nUK942ojY/S0;oY6V=0onRIX/2oiMQS`;oWF>=0_nQJ9000onQK9CoY6V=oj=ZT002oj=ZT003
ojI`U?nXK8koZ6nA00;oZ6nA0_nZKhh00onXL9?o[G2=oj]aT@02oj]aT@?o[g:?00Co[WFCok9eS_n`
MY;o/7JB0onbMi43okAhT0?o]WZ@0_nhNi001?neOYSo^Wf@okYmT?ngP9P2okaoT@;o_H6B0onoQ9@3
ol67U`;o`X^L00Ko0000ol:@X_o3RYSo`hZHol6DZOo3SYd3olFFYP03olbGW_o6XK?obYfY00?oaZFh
00CodJZaolBec?o@aLoo_/[T0_ngbnT01on^co7oX;_/oj2kk?nUa_7oZl3YojC1k_ooool00_l0000d
ooooo`00:oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo01?ooooo0ol00002
ooooo`06o`000?ooooooX[WYoj:ijOnM]^WoXk[Y0_n/`^T00onac>goY[gZohV>dP02oi=m^0;oVWjc
00?oH5:[ohIQX?n6HJ000_nDK:401?mRAIWoW7R[oiEVVOmiDiT2ohQKUP;oRUjH0_n5FIH00on=GiOo
S5jFohaNUP02ohaNUP;oTf>G0_n>GiH2oi=TV0;oVVRG00CoOe6@ojE/TOnUK97oYFbA0_n?G9400onA
H9CoZ72Boj]_SP03oiMPSP;oT5fA0_nUK942ojY/S003ojAYSOn/KH[oXVJ;00;oXVJ;00?oUf6?oj5U
R_nMHhd00_nMHhd01?nQJ93oY6V=ojAYSOnTJHd2oj=ZT0?oZ6b>0_nXKi42ojY_SP03ojQ`Ton]L8go
Zg6A00;oZg6A0on_LXl01On^MI?o/WF>ok1fT_n`MY;o]WN=00;o/WNA0ondN903okIjT0;o^7^@0onj
OI03okaoT@;o_H6B0onoQ9@3ol67U`04olB6TOo2Rico0000ol:@XP;o`hZH0_o3SYd01?o;T9KoaIJV
olbGW_o<Uih2olZMZ@04olfIWoo6YKSoaZFhom6Z/@;od<G?00Ko`J6hokO;jOn]VL;o[IW2oj2kk?nT
VLX2oibdj@;oY<7^0_ooool00ol0003oooooooooo`0aooooo`00:oooool01?l0003oooooooooool0
0008ooooo`;o00004oooool2o`0000Cooooo0_nY_NP00onW_>SoX[WYoijej003oj2ei`05ojc2jOnf
bNSoY[gZojJmj_n9S]800_nCOKP2oiYn/`;oQV6P0_nDK:401?mRAIWoUFJIoiEVVOmiDiT2ohQKUP;o
RUjH0_n5FIH00on=GiOoS5jFohaNUP02ohaNUP;oTf>G0_n>GiH2oi=TV003oiYXUonLIY7oOe6@00?o
YFbA0_n?G9400onAH9CoZ72Boj]_SP03oiMPSP;oT5fA0_nUK942ojY/S003ojAYSOn/KH[oXVJ;00;o
XVJ;00?oUf6?oj5UR_nMHhd00_nMHhd01?nQJ93oY6V=ojAYSOnTJHd2oj=ZT0?oZ6b>0_nXKi42ojY_
SP03ojQ`Ton]L8go[G2=00;oZg6A0on_LXl01On^MI?o/WF>ok9eS_n`MY;o]WN=00;o/WNA0ondN903
okIjT0;o^7^@0onjOI03okaoT@;o_H6B0onoQ9@2ol67U`;oa8JA00?oa8RDo`000?o3RYP00_o3RYP2
ol>>W@08ol^@U_o5UZKoc9NNolbGW_o=TYOobYfYolfIWoo6YKP2om6Z/@03om:TZ?o@aLoo`J6h00?o
[IW20_nTVLX00onL]>WoY:GFojBUeP02oj2jj`03ooooool0003ooooo03;ooooo000/ooooo`;o0000
2_ooool00ol0003oooooooooo`0>ooooo`?o00000oooool4ojVmj003ojVlionV^^SoY[[X00;oW[GX
00CoX;GWoj^ii?n[^NCo]/WX0_mcL<400on9S];oTgfhoi=m^002oiYn/`?oQV6P00?oU6bQof95VOnE
IYT00_nEIYT2ohQKUP;oRUjH0_n5FIH2oheOU`?oS5jF0_nCHiL2ohiOUP;oReVA0_nLIY401?moDI3o
YFbAojE/TOnUK942ohmLT@03oi5PU?n[KhkoZfn>00?oUf2>0_n@GI401_nUK97oXfR=ojY/S?nZK8co
Y6V=oja]RP?oXVJ;00?oUf6?oj5UR_nMHhd00_nMHhd01_nQJ93oY6V=ojAYSOnTJHgoXfZ@ojM[S0?o
Z6b>00CoZ6nAoje_SOnZKhkoZVn>0on]L8d00on[LI7o/7:=ojmbS`02ojmbS`?o/WF>00Co/7JBokIg
SOnbMi7o/WNA0ondN903okIjT0;o^7^@0onjOI03okaoT@;o_H6B00Goa8B>okn4U?noQ9Coa8F?ol67
U`02olB6T@03olB8U?l0003o`hZH00;o`hZH00?obH^Aol>>WOo;T9H00_o<Uih2olfBU`;ocIVO0_oA
Z[42om:TZ0;o`J6h00Oo^HJNojfI`_ndRJSo]8VXojBIb_neU[SoY:GF00;o_;_H0_nY_^T00ooooooo
0000ooooo`0aooooo`00Aoooool2o`0000Cooooo1_nY_NP2ojVli`05ojJjj?nR]NKoW[3Uoij`iOn[
^N@00_nf]mX00onZ[m_oLg31ofA=XP04ohINW005of1BZon6HJ3oQV6PoiA/XOmRAIT00onEIYT3ohQK
UP;oRUjH00?oQEVFoheOUon=GiL00on<GYH2oi=SU`04ohiOU_n?G93oReVAoh]IT@;oW6JA00CoOe6@
ojE/TOnUK97oYFbA0_n?G9401?n4DhooZfn>oj]_S_n[Khh2oiMPSP;oT5fA00KoYFbAoj=XSOnZK8co
ZVb<ojAYSOn/KHX3oj9VR`;oXFF:0onMHhd01_nQJ93oY6V=ojAYSOnTJHgoXfZ@ojM[S0?oZ6b>00Co
Z6nAoje_SOnZKhkoZVn>0on]L8d00on[LI7o/7:=ojmbS`02ojmbS`?o/WF>0_nfMhd2ok9gT@;o]7R@
00Co^g^=okIjT?nfNY3o]WZ@0_nhNi000onoOhco^Wf@okYmT003okaoT@;o_H6B00Goa8B>okn4U?no
Q9Coa8F?ol67U`02olB6T@04olB8U?l0003o`hZHol>:V0;obH^A0_o;T9H2olbGWP;ocI:G0_o=VIl0
1OoEViWodJZaom:TZ?oBY:So`XVH00;o^HJN0ondRJP2okFF^0?o_;_H0_naa>P2ooooo`03o`000?oo
oooooooo02oooooo0014ooooo`?o00000_ooool00ol0003oZKgXojVmj006ojVmj0;oZ;_W0_nW^NH0
2OnR]NKoXjWKoj>YfonSZM_o][OJojJD`_m`GJgoLg31ofA=XP04ohINW004odd_SOn6HJ3oQV6PoiA/
X@;oHTFI0_nEIYT00omiDiWoR5^FohQKUP02ohYNV003ohEIU_n=GiOoSEnG00?oS5jF00CoTf>GohmL
TOn?G93oSeb@0_n;FI42oiaVT@;oOe6@0_nUK942ohmLT@04ohACSon[KhkoZfn>oj]_SP;oUf2>00Co
T5fAohUESOnSJ8goXfR=0_nZK8`00onTJHgo[6f:oj9VR`02oj9VR`;oXFF:0onMHhd01_nUJ8coY6V=
ojAYSOnTJHgoXfZ@ojM[S0?oZ6b>00CoZ6nAoje_SOnZKhkoZVn>0on]L8d00on[LI7o/7:=ojmbS`02
ojmbS`?o/WF>0_nfMhd01OnbMi7o^GV=okUiSOndN93o^g^=00;o]WZ@00Co_Gf<okQkT?nhNi3o_gn<
0_njOI02okaoT@05ol>2SOnmPI;o_H6BolB4S_noQ9@00_o4QHl01oo1QiOoa8JAolB6TOo4R9Co0000
olR8Soo3RYP00_o9Ri42ol^@UP04oln@TOo<UikocI:GolfBU`;ocIVO00?oeI^Iom:TZ?oBY:P00_o2
RIP2okV6WP?o]8VX00GobIFOokFF^?oK_K_o_;_HolW:f`03ojRTdP03ooooool0003ooooo033ooooo
0012ooooo`;o00001?ooool:ojVmj003ojRkionU]^GoY;;R00;oY;;R00?oWJ_Poj>YfonUUlL00_nV
U<800om`GJgoBBn?og=``@04ohINW004odd_SOn6HJ3oQUJAohAGU0;oHTFI0_nEIYT00omiDiWoR5^F
ohQKUP02ohYNV003ohEIU_n=GiOoSEnG00?oS5jF0_n?G942ohmLT0;oReVA0_nLIY42ogmAT0;oYFbA
00?oSebAoiMPS_n4Dhl00on[Khh2oiMPSP;oREF=0_nSJ8d2ojY/S0;o[6f:0onRIX/3oj5URP;oWF>=
00CoYFR<ojAYSOnTJHgoY6V=0_nWJh`3ojQ/SP?o[Fn=00GoZVn>oje`SOn]L8go[G2=oj]aT@02ok1b
S@;o[g:?0onbMHh3okIgS@;o^GV=00Go]7R@ok]kSOnkNhgo]WZ@okemS002okQkT003okmoS?njOI3o
^Wf@00;o_7nA0_o3PXd2olB4SP03okn4U?o4QHooa8F?00?oa8JA0_o4R9@01?l0003o`hZHolV;TOo9
Ri42ol^@UP05oln@TOo=TYOocI:GolfBUooBTi400_oEViT01?o>T9;odZBXol:9V?o2RIP2okV6WP04
olB9U?ndRJSobIFOolVEW`;ofkfk00CogKbgolW:foncU[WoZ:CB0_nj^MT00ooooooo0000ooooo`0_
ooooo`00?oooool3o`0000?ooooo3OnY_NP2ojRji`04ojFfiOnT/^;oW:3HoiNEd0?oYIO70_nVU<82
odT_S`05ofA=X_n6GYcoQUjLohINW?m=;hd00_n6EY400on4EiCoGcR:of95V@02oiEVV@03ogUCVOn8
FiKoR5^F00;oRUjH00?oQEVFoheOUon8Ei000on:F902ohmLT@;oSeb@0_n;FI42oiaVT@;oOe6@0_nU
K942oiMPSP04ohACSon[KhkoZfn>oj]_SP;oUf2>0_n9EHd2oj=XS@;oZVb<0on/KHX2oj9VR`?oXFF:
0_nMHhd01?nUJ8coY6V=ojAYSOnTJHd3ojM[S0;oZ6b>0on]Khd01?nZKhko/W><oje`SOn]L8d3ok1b
S@03ojmbSondMXco/WF>00;o/WF>0onfMhd2okUiS@04okAhT?nkNhgo^g^=okIjT0;o_Gf<00Ko^7^@
okmoS?njOI3o^Wf@ol61SOnlOi42ol>2S@?oa8B>0_o4QHl3olB6T@03olR7SOo8R8oo000000?obH^A
0_o;T9H01Oo?T97ocI:GolfBUoo=TYOodY>A00;oeI^I00SocY2Bom:TZ?o2RISo`XVHolF5SoniQYko
a8VDokB9Z0;obIFO00?ofkfkomfl]ooM_;L00_ncU[T3okZif@03ol_Eh_l0003o000002oooooo000m
ooooo`?o00000_ooool=ojVmj0?oZKcW00CoZ;[Woj:ahonOZ=goWjSM0_nLX=P00onGUM3oYIO7ojFG
a`02ojJD`P;oBBn?00GoI4fRohINW?n6GYcoQUjLodd_S@02ohIFT@08ohAGU?mO>8[oGcR:oiEVVOnD
H97oJT6=ohQKU_n:F8l2oh5BT003ohIDSon8Ei3oR5N@00?oRUR@0_n?G943ohmLT003oh]ITOnLIY7o
W6JA00;oOe6@0_nUK942oiMPSP06ohACSon[KhkoZfn>oj]_S_nGH8koXVN<0_n9EHd2oj=XS@;oZVb<
0on/KHX2oj9VR`?oXFF:0_nMHhd2ojEXS0;oY6V=0onWJh`2ojQ/SP?o[Fn=00CoZVn>ok9cS?n]L8go
[G2=0on`LXd00on_LXoo]7J<ok9eSP02ok9eSP?o]WN=0_niNHd01?ndN93o^g^=ok]kSOnfNY02okem
S0;o_gn<00Co^Wf@ol61SOo1PHgo_7nA0_o3PXd3olB4SP;oa8F?0_o4QY42olR7S@03olR8Sol0003o
bH^A00;obH^A00Cod8n=oln@TOo?T97odHn=0_o=TYL01?oBTi7oeI^IomFKVOo>T982ol:9V0;oaHF?
0_o4RI@3olVEW`?ogKbg00So`HnSok>F^OoF_;oo^[WIol_Eh_neX<?oooooo`0002oooooo000joooo
o`?o00000oooool00ol0003oZKgXojVmj00<ojVmj004ojVlionW^>GoYkSUojNhi@;oX[7S00CoWjSM
oh]o`On;Ol7oRgBd0_nCLj/2ogACW@03og1M[Om9;hooFcF900?oQUjL00CoCBn=ohIFTOn6EY7oQ5ND
0_mO>8X2oiAPT@03ofY1SOn:F8ooRUR?00;oPE:@00?oQUB?ohQGT?n8Ei000on:F902ohmLT@?oSeb@
00?oReVAoiaVTOnLIY400_moDI001OnUK97oY6^@oiMPS_nGH8koQ5>?00?oZfn>00CoUf2>oj9WS?n9
EHgoREF=0_nSJ8d2ojY/S0?o[6f:00?oXVJ;ojm_ROnQIHX00_nQIHX2oieSS@;oYFR<0_nTJHd3ojM[
S0;oZ6b>0on]Khd2ok9cS0;o[G2=0on`LXd00on_LXoo]7J<ok9eSP02ok9eSP?o]WN=0_niNHd3ok]k
S@03okIjT?nmOHco_Gf<00?o_gn<0_o1PHd00onlOi7o`h:=ol>2S@03olB4SP;oa8F?0_o4QY42olR7
S@03olR8Sol0003obH^A00;obH^A00God8n=oln@TOo?T97odHn=olfBU`02om:CT@;oeI^I00?ocY2B
ol:9V?o2RIP00_o5QHl2olB9U0;obIFO00?olKjIomnXV_oM_;L00_o1Sj<2omJl_`03onKB`_neX<?o
]J3300;ooooo00?o0000ooooooooool01Oooool2o`0002Gooooo000hooooo`;o00000ooooolAojVm
j0;oZ;_W00?oZ;[VojNhiOnPZmh00_nFVmH2oi>>b`04oh]o`On;M;CoTg>[oi=cZ`;oM5>M00?oL5f]
odT_SomK=HT00on6GY`01?m=;hgoQUJAohIFTOn4Ei@2oelhRP;oU62A00?oJT6=ohYHSon:F8l00_n1
DY000on6E8ooR5N@ohQGT003ohYHT0?oSebA0_n?G9000on;FI7oW6JAoiaVT@02ogY;SP04ojE/TOnT
Ji3oUf2>oiMPSP;oQ5>?0_n[Khh01?nGH8koXVN<ohUESOn9EHd2oj=XS@;oZVb<0on/KHX00onRIX_o
[fn9oj5URP02oj5URP06oieSSOnUJ8_oYFR<ojEXS?nTJHgo[6j;0onWJh`00onXK8ko[W2<oje_S@02
oje_S@;o/W><0_n]L8d3ok1bS@05ojmbSondMXco]7J<ok9eS_niNH`00onfMhd2okUiS@?o^g^=0onm
OH`3okmoS0;o`H6=0oo3PXd3olB4SP;oa8F?0_o4QY42olR7S@03olR8Sol0003od8f;00;obH^A00Go
d8n=oln@TOo?T97odHn=olfBU`02om:CT@03omJDS?o>T9;ocY2B00;o`XVH0_o5QHl2olB9U004omnO
S_o9UIoolKjIomnXVP?o`HnS00Soe[boonKB`_oVd/;oa9^]okFP`ooIfMKoooooo`0000Kooooo00Co
0000oooooooooooo00009?ooool003Gooooo0ol00003oooooa?oZKgX00CoZ;_WojJgiOnV]nGoYK?R
0_nPZmh2oiJKeP04oi>>bon;Ol7oRgo1oh]d]0;oTg>[00CoM5>Mod0RQ?m9;hooFcF90_n4Dhl01?m`
AHgoCBn=ohIFTOn6EY42ohAGU004oelhR_nDH97oU62AofY1S@;oRUR?0_n1DY000on6E8ooR5N@ohQG
T004ohYHT0;oSebA0_n?G9000on;FI7oW6JAoiaVT@02ogY;SP;oY6^@0_nGH8h2ohACS`;oZfn>0_nR
Ih`2ohUES@;oXfR=00?oZVb<ojm`Ron/KHX00_n/KHX00onRIX_o[fn9oj5URP02oj5URP06oieSSOnU
J8_oYFR<ojEXS?nTJHgo[6j;0onWJh`00onXK8ko[W2<oje_S@02oje_S@;o/W><0_n]L8d3ok1bS@05
ojmbSondMXco]7J<ok9eS_niNH`00onfMhd2okUiS@?o^g^=0onmOH`3okmoS0;o`H6=0oo3PXd3olB4
SP;oa8F?00Oob8N<olB6TOo8Qhgob8N=olR8Sol0003od8f;00;obH^A00?od8n=oln@TOo?T9400_oA
Shd2om:CT@05omJDS?o>T9;ocY2BolR6S?o2RIP00_o5QHl2olB9U004omnOS_o9UIoolKjIomnXVP;o
`HnS00?olL:OonblXOoVd/800_o4Vjd01OneX<?ofMWFolVgbOoooooo000000Gooooo00Co0000oooo
oooooooo00009?ooool003;ooooo1?l00002oooooaCoZKgX00KoZKcWojRkionX^nOoY[OUoj2[gonK
XMP2ohb<c@;oPWJm00CoOVV`ogAHY?mdF:CoRgBd0_nCLj/01?mdDigo@2:4odT_SomK=HT2ohACS`04
og15SOm=;hgoQUJAohIFT@;oQ5ND00CoGcR:oiAPTOnDH97oJT6=0_n:F8l2oh5BT003ohIDSon8Ei3o
R5N@00CoRUR@0_n?G942ohmLT003oh]ITOnLIY7oY6^@00;oNT^>0_nTJi02oiMPSP;oQ5>?0_n[Khh2
oj9WS0;oREF=0_nSJ8d00onZK8co[g2;oja]RP02oja]RP03oj9VRon_KhWoXFF:00;oXFF:00KoWF>=
ojEXRonUJ8coYFR<ojAYSOn/KX/3ojM[S003ojQ/S_n^L8co[Fn=00;o[Fn=0_nbLh`2oje`S@?o/7:=
0ondMX`00onbMHko^GV<okIgS@02okIgS@;o^GV=0onkNhd3okemS0?o_gn<0_o1PHd3ol>2S@?oa8B>
0_o4QHl02?o8Qhcoa8JAolR7SOo8Qhgob8R?o`000?o@SH_obH^A0_o@Shd2oln@T@;odHn=0_oBTi40
1OoFU8cocY2Bolj@T_o8QXco`XVH00;oaHF?0_o4RI@02?oOWhkolKjIomnXV_oOZ9[oci:Dol6?Xooa
`Yook;bQ0oo4Vjd00ooIfMKobKO9olVgb@02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00009?ooool0033ooooo0_l00003oooooaGoZKgX0_nY_>P2ojVli`05ojRkionS/nCoX:_O
oj2[gonKXMP00_n<S<d01On2M[goOVV`ogAHY?mdF:CoN5>J00;oLDVB00CoM5>Mod0RQ?m9;hooFcF9
0_n4Dhl01?m`AHgoCBn=ohIFTOn6EY42ohAGU004oelhR_nDH97oU62AofY1S@;oRUR?0_n1DY02ohID
S`03ohQGT?n:F93oRUR@00;oRUR@0_n?G942ohmLT003oh]ITOnLIY7oY6^@00;oNT^>0_nTJi02oiMP
SP;oQ5>?00?oZfn>ok1cSonRIh`00_nRIh`01On9EHgoXfR=oj=XSOnZK8co[g2;00?o[6f:00?oXVJ;
ojm_ROnQIHX00_nQIHX2ojEXR`;oYFR<00?oY6V=oja^RonWJh`00_nWJh`2oji`S0?o[Fn=0_nbLh`2
oje`S@?o/7:=0ondMX`01OnbMHko^GV<okUiS?nfMhgo_Gf<00;o^GV=0onkNhd3okemS0?o_gn<0_o1
PHd3ol>2S@;oa8B>0_o9Qh/2olR7S0?ob8N=00Cob8R?o`000?o@SH_obH^A0_o@Shd01?o?T97odHn=
om6?SOoAShd2om:CT@04omJDS?o>T9;ocY2BolR6S0?oaHF?00CoeY:9omnOS_oOWhkon[eo0_oOZ9X0
1Oo?TYCo`HnSoo72Woo/_:7oe9bK00;oa9^]00Kof:j]olVgbOoC_lOodko7ooooool00004ooooo`04
o`000?ooooooooooo`0002Cooooo000]ooooo`?o00000ooooolHojVmj005ojVlj?nX^nOoYkWVojNi
i_nS/n@00_nBT]001?n2Nl;oKej_ofmN[on2M[d2ogiY/008ogAHY?mhDi[oLDVBog59T_mdDigo@2:4
odT_SomK=HT2ohACS`04og15SOm9987oQUJAohIFT@;oQ5ND00?oGcR:oiAPTOnDH9400_mZ@Hd00on:
F8ooPE:@oh5BT002ohIDS`03ohQGT?n:F93oRUR@00;oRUR@0_n?G942ohmLT003oh5BT?nTJi3oY6^@
00;oNT^>0_nTJi02oiMPSP;oQ5>?00?oZfn>ok1cSonRIh`00_nRIh`01On9EHgoXfR=oj=XSOnZK8co
[g2;00?o[6f:0_n_KhT3oj5URP;oYFR;0_nUJ8`2oja^R`?oYf^<0on^L8`2oje_S@?o/W><00Co]gN<
ok1bSOn`LXgo/7:=0ondMX`01OnbMHko^GV<okUiS?nfMhgo_Gf<00;o^GV=00?o`X2<ok]kSOnkNhd0
0onmOH`3okmoS0;o`H6=0oo3PXd2olB4SP;obHN;0_o8Qh`3olR7S@04olR8Sol0003od8f;om2=R`;o
d8n=00Godi2:om6?SOoAShgodHn=om:CT@02omJDS003olj@T_o8QXcob8J<00?oaHF?00GoeY:9omnO
S_oOWhkon[eoomnXVP02olnBU007oo72Woo/_:7ok;bQomBLVoo4Vjgommb^omR^[@03om>oa`03oooo
ool0003o000000?ooooo00Co0000oooooooooooo00009?ooool002_ooooo0_l00003oooooa[oZKgX
0_nX_>L01OnX^nOoXJoRoj6_h_nQ[n;oV:7K00;oTY;@0_m_GZl01Om[DJ7oOVV`ogiY/?mdF:CoN5>J
00;oLDVB00CoM5>Mod0RQ?ln6gcoFcF90_n4Dhl01om`AHgoBBB1ohIFTOn=F8goL4B<ohAGU?mO>8X0
0_nDH942ofY1S@03ohYHSon1DY3oPE:@00;oQUB?00?oR5N@ohYHT?n:F9000_n:F902ohmLT@03ohmL
T?nGHY7oPE:@00?oY6^@00?oNT^>ojA[T?nTJi000_nGH8h2ohACS`03oj]_S_n`LhooXVN<00;oXVN<
00GoREF=oj=XSOnSJ8goZVb<ojm`R`03oja]RP?o[fn90_nQIHX2ojEXR`;oYFR<0on/KX/2ojM[S0?o
[W2<0_n]Khd3ok9cS0;o]gN<0_n`LXd3okAfS0?o^GV<00Go]WN=okemS?nmOHco^GV=ol:0S002ok]k
S@?o_Gf<0onoOh`2ol61S@05olV7Roo3PXgo`h:=olZ7Roo4Q8h00_o9Qh/2olR7S0?ob8N=00Cob8R?
o`000?o@SH_od8f;0_o@Shd01OoCT8[odHn=om6?SOoAShgodY>A00;oeYB<00?ocY2BolR6S?o8QX`0
0oo5QHl01OoFTXWogin>omnOS_oj_Goog9b>00;oci:D00Goo/IkonblXOoDW9_oe9bKoooBQ002omR^
[@04ong4ZOoC_lOogLk;omJoa0;ooooo00Co0000oooooooooooooooo0_l0000Uooooo`00:?ooool3
o`000003ooooool0003oZKgX01_oZKgX00SoZ;cWojNji_nW^^KoYk[VojJgiOnQ[n;oSiKFoh=oaP;o
MVRf00?oPW_2ofmN[om[DJ400_mVAIL02?mdF:CoN5>Jog59T_maBI;o@b20od0RQ?ln6gcoFcF90_n4
Dhl01?m`AHgoBBB1oheHSOn=F8d2og14S003oelhR_nDH97oU62A00;oJT6=00?oRUR?oh5BT?n1DY00
0_n6E8l01On8Ei3oRUR@ohYHT?n:F93oS5^B00;oReZB0_nGHY401?n1DY3oY6^@ojA[T?nTJi02ogY;
SP03ojA[T?nGH8koUf2>00;oJd:>0_n`Lhl3oj9WS003ohUESOnSJ8goXfR=00;o[g2;0on/KHX3ojm_
R@;oXFF:0_nUJ8/2ojEXS0?o[6j;0_nWJh`3oji`S003oje_SOnfMhco/W><00;o/W><0_ngMh`00on`
LXgo_7^<okAfS002okAfS0?o^GV<00Go]WN=okemS?nmOHco^GV=ol:0S002ok]kS@?o_Gf<0_noOh`0
1?o9QX_o`H6=ol61SOo9Qh/2ol>2S@04olZ7Roo4Q8kobHN;olV7R`;ob8N<0oo8Qhd2o`0000;od8f;
0_o@Shd01OoCT8[odHn=om6?SOoAShgoei>900;oeYB<00Cod8b9olR6S?o8QXcodhj70_o5QHl01OoF
TXWogin>omnOS_oj_Goog9b>00;oci:D00Goo/IkonNZT?oDW9_oe9bKoooBQ002omR^[@07ong4ZOo^
aZ[ogLk;omJoa?oQd<Ooooooo`00000Zooooo`009_ooool2o`0000Cooooo7_nY_NP00onX_>OoYk[V
ojBdi002oifZg`;oSiKF0_mfJ;H00omOBj?oKej_ofmN[`02ofI5U`08ogAHY?mhDi[oN5>Jog59T_m3
883o@2:4ochKO?mK=HT2ohACS`04og15SOm9987oSER=oheHS@;oL4B<00?oGcR:oiAPTOnDH9400_mZ
@Hd00on:F8ooPE:@oh5BT002ohIDS`03ohQGT?n:F93oS5ZA00;oS5^B0_n;FY82oiMRT@04oh5BT?nT
Ji3oY6^@ojA[T0;oNT^>00?oY6^@oiMPS_nGH8h00_m[@Xh2ok1cS`?oXVN<00?oREF=oj=XSOnSJ8d0
0_n_L8/3oja]RP?o[fn90_nQIHX2ojEXR`;oYFR<0on/KX/00onWJhco/gB<oji`S002oji`S003oje_
SOnfMhco/W><00;o/W><0_ngMh`00on`LXgo_7^<okAfS002okAfS0?o^GV<00?o]WN=okemS?nmOH`0
0_o2P8`2ok]kS@;o_Gf<00CoahF;okmoS?noOhcobHJ;0_o1PHd01Oo9Qh_o`h:=olZ7Roo:Qh_oa8B>
00;obHN;0_o8Qh`3o`000004om2<R_l0003od8f;om2=R`;od8n=00Godi2:om6?SOoAShgodHn=omNC
R@02omJDS005om2<ROo8QXcob8J<om>>Qoo5QHl00_oFTXT2omnOSP06ooZmOooLW8koci:DolnBU?on
aW_oijZ@0_oDW9/02ooodXCogZFIong4ZOo]a:Wok/JZon_0YooF_lCohM37omo=a_oooooo000002Wo
oooo000Sooooo`?o00000ooooolPojVmj0;oZ;_W00CoY[SVojBdi?nT]>CoWJ[O0_mbK;d01On3OlKo
MVRfoem;XomF>I?oKej_00;oITFG00SoGSZ=ogQCV_mhDi[oLDVBod<PP?m08XCo?Q]loe/eR@;oQ5>?
00CoL4F=odTTPOn=F8goSER=0_m`A8`01_mU>HOoU62AoiQRT?mL=8SoJT6=ohYHS`;oMTV?00?oQUB?
ohaJT?n5EY800_n<FY42ohaKTP;oReZB0_nGHY401?n1DY3oY6^@ojA[T?nTJi02ogY;SP03ojA[T?nG
H8koZG2A00;oJd:>0_n`Lhl3oj9WS003ohUESOnSJ8goXfR=00?o[g2;0_n/KHX3ojm_R@06oj5UR_nb
LX[oYFR;ojEXRonUJ8co/7:<0on/KX/00onWJhco/gB<oji`S002oji`S003oje_SOnfMhco/W><00;o
/W><0_ngMh`00on`LXgo_7^<okAfS002okAfS0?o^GV<0onmOH`2ol:0S0;o^g^=00?oaH>;okemS?o7
QH/00_noOh`2olV6R`03ol61SOo9Qh_o`h:=00;obXN;00?oa8B>olV7Rol000000_l000002?o@SHWo
b8N=olR7SOo@S8[od8f;o`000?o@SH_od8n=0_oCT8X3om6?S@04omNCROoFU8coeYB<om2<R@;ob8J<
00Godhj7olF5SooFTXWoeY:9omnOSP02ooZmO`05ombLS_o?TYCoci:Dook6NooWZY000_oDW9/00ooo
dXCogZFIoo_5R`02onk6ZP04on_0YooQd<Ooglg6omo=aP;ooooo00?o0000ooooooooool09_ooool0
02;ooooo0_l00002ooooob?oZKgX00GoZ;_WojBgi_nQ/>?oXK3SoiVTg@02ohJ;d004og9/_OmTE:[o
MVRfogIX]P;oESVC00?oJe6QofI5UomN>Xd00_mhDiX01OmaBI;o@b20od0RQ?ln6gcoFcF900;oQ5>?
00CoL4F=odTTPOn=F8goSER=0_m`A8`00omU>HOoV6:@oiQRT002oe`dR003ohYHSomfBHooMTV?00;o
S5Z@00?oQEJBohaJTOn<FY400_n<Fi82oh]JTP;oUf:A0_n1DY02ojA[T0;oNT^>00?oY6^@oiMPS_nY
L9400_m[@Xh3ok1cS`;oXVN<00?oREF=oj=XSOnMII000on_L8/2oja]RP?o[fn900KoXFF:ok9bR_nU
J8_oYFR;ojEXS?n`LX`3oja^R`03ojM[S?ncM8co[W2<00;o[W2<00?o[Fn=okIgS?nbLh`00_nbLh`2
okMgS003ok1bSOnlNhco]7J<00;o]7J<0oniNH`3okemS0;o`X2<00Co^g^=olF3Roo5Ph_o_Gf<0_o7
QH/00onoOhcobHJ;olV6R`02olV7R`03ol>2SOo:Qh_o000000;o000000GobHN;olR7S?o8Qhcod8f9
olR7S@02om2<RP;od8f;00Co0000om2?SOoCT8[odi2:0ooAShd01?oGThWoeYB<omJDS?o@S8T2olR6
S005om>>Qoo5QHooeY:9omJBROoc[Wd00_oj_Gl01_oLW8koci:Dook6NoonaW_oijZ@onFUS@;oom:4
00?ogZFIoo_5Roo^aZX00_o[`:L01_ocbZGoglg6omk<a_oVg<[oooooo`0002Sooooo000Rooooo`;o
00009?nY_NP2ojNki`;oY;OV00KoXK3SogaobomlOl_oQX_@og9/_OmTE:X2oe8kV0;oESVC00[oJe6Q
ofI5UomN>XgoHSR8ogQCV_maBI;o@b20od0RQ?ln6gcoHcF30_n4Dhl00om`AHgoBBB1oheHS@02oheH
S@04og14S?mU>HOoV6:@oiQRT0;oG3B800?oU5n@ogI9SomfBHl00_n<FY000on5EY;oS5ZAohaJT@02
ohaKTP;oReZB0_nGHY42oh5BT0;oY6^@0_mjBhh00onTJi3oZG2AojU`T@02of]2SP?o/7>?0_nRIh`0
0on1DY3oWFF@oieUT003ojm`R`03oja]R_njNH_o[fn900;o[fn900KoXFF:ok9bR_nUJ8_oYFR;ojEX
S?n`LX`3oja^R`03ojM[S?ncM8co[W2<00;o[W2<00?o[Fn=okIgS?nfMh`00_nbLh`2okMgS005ok1b
SOnlNhco_7^<okAfS?o2PH`00oniNH`3okemS0;o`X2<00Co^g^=olF3Roo5Ph_o_Gf<0_o7QH/01?no
OhcobHJ;olV6Roo9Qh/3o`000004olZ7Roo9Qh_obHN;olV7R`;ob8N<00Cod8f9olR7SOo@S8[od8b:
0oo@SH/01Ol0003odi2:om>@R_oHThOodHn=00;oei>90_oFU8`01Oo@S8Wob8J<olR6S?oCSXOoaHF?
00;oeY:900GoljimooZmOooLW8kog9b>omnLR@02ook6N`03onNZT?oUYHgoom:400;ogZFI00ConlF;
onk6Z_o[`:Oom<^U0_ocbZD01OoNc<Koi]c:omg<bOoooooo000002Oooooo000Jooooo`;o00001_oo
ool00ol0003oZKgXojVmj00TojVmj009ojNkionS]NGoW:cQoib/hOnBW=[oO7o;of5I/om@?ikoLVbm
00;oDS^H00GoGd^SoeHiTomG=8coITFGoehjS@02of8hR009og59T_m3883o@2:4ochKO?mS=H?oQ5>?
ohIBS?m`AHgoBBB100?oSER=00CoL4B<ofDiQonHHY3oV6:@0_mL=8P00onDGi3oMTV?ogI9S`02ohaJ
T003ohEFT_n<FY7oS5ZA00?oS5^B00?oReZBoiMRTOnGHY400_n1DY02ojA[T0;oM4fF00GoY6^@ojU`
TOnYL97oZG2Aof]2SP03ok1cS`;oXVN<00?oPE:@oieUT?nMII000on_L8/00on/KH[o^WV;ojm_R@02
ojm_R@06oj5UR_nbLX[oYFR;ojEXRonUJ8co/7:<0on/KX/00onWJhco/gB<oji`S002oji`S0?o]WN<
00Co/W><ol60SOngMhco]gN<0onlNh`00ondMXco`X6<okUiS002okUiS0?o_Gf<0oo2P8`2olF3R`04
okemS?o7QH_oahF;okmoS0?o00000_o9Qh/2olZ7R`?obHN;0_o8Qh`01?o@SHWob8N=om2<R_o@S8X3
om2=R`05o`000?oCT8[odi2:omRCQooAShd00_oGThT00ooFU8cod8b9om2<R@02olR6S0;odhj70_oF
TXT01_oc[Wgon[eoombLS_oLW8kogib9ook6N`;oijZ@00SoiJF=ooo8K_oNYIWogZFIoo_5Roog_hgo
jl2WooC;Y@;ollZU00Coi]c:omg<bOoMc<Wooooo0_l0000Vooooo`006Oooool01?l0003ooooooooo
ool00005ooooo`03o`000?ooooooZKgX02;oZKgX00CoZKcXojNjionW^^OoXkGU0_n;U=L00ombLlGo
O7o;ogaob`02oe0oWP07ofADZ_mB>iSo@RJ8oeHiTomG=8coITFGoehjS@02of8hR005og59T_m3883o
@2:4ochKO?mS=H<00_n6DX`00om`AHgoBBB1oheHS@02oheHS@04og14S?mU>HOoV6:@oiQRT0;oG3B8
00?oU5n@ogI9SomfBHl00_n<FY001?n5EY;oS5ZAohaJTOn<FY42ohaKTP03oh]JT_nGHY7oUf:A00;o
PE:@0_nTJi02ogA=UP05oj=aV_nYL97oZG2AojU`TOm[@Xh00on`Lhl2oj9WS003oh5BT?nMII3oWFF@
00?o[g2;00?o[6f:okYiRon_KhT00_n_KhT01_nQIH[o/W::ojEXRonUJ8_oYFR<ok1bS0?o[6j;0onc
M8`2oji`S0?o]WN<00Co/W><ol60SOngMhco]gN<0onlNh`00ondMXco`X6<okUiS002okUiS0?o_Gf<
0oo2P8`2olF3R`04okemS?l0003o0000o`0000;obHJ;0oo9Qh/2olZ7R`?obHN;0_o8Qh`2om2=R@;o
d8b:0oo@SH/01OoGThSo0000om>@R_oHThOodHn=00;oei>900GoeYB<om2<ROo@S8Wodhf6olR6S002
om>>Q`;oeY:900KoljimooZmOooLW8kog9b>omnLROonaW/2onNZT007onFUSOoob6kogZFIoo_5Roob
^Y?omkn=ooW2S003oo?:Y@06ooK@YOoMc<Woh]_>on?Ue?oooooo00009_ooool001Wooooo00Co0000
oooooooooooo00001?ooool2o`000003oooooonY_NSoZKgX027oZKgX00GoZKcXojNjionQ]>GoXKCU
oiRWh@02oh^De`;oD4RZ00WoHEVcoe0oW_mTE:[oDS^Hod8VR?mF>I?oEcB<ofI5UomN>Xd00_mR>8P0
1OmaBI;o@b20obd;Loln6gcoHcF300;oQU:<00?oERf3odTTPOm998400_n=F8d01?m`A8coICV7oiQR
T?nHHY02oe`dR0;oU5n@00?oMTV?ohaJT?n<FY000_n5EY82ohaJT@;oS5^B00?oReZBoiMRTOnGHY40
0_n1DY001OnTJi3o^hJLogA=U_mdCIKoXg6J00?oZG2A0_m[@Xh2ok1cS`03oj9WS?njOI7oPE:@00;o
WFF@0on_L8/00on/KH[o^WV;ojm_R@02ojm_R@?o/W::00CoYFR;ok1bS?n`LXco/7:<0_n/KX/3ok=d
S0;o[W2<0onfMh`01?nbLhco`H2=okMgS?ngMh`3okakS003okAfS?o2PHco`X6<00;o^GV<0onmOH`3
ol:0S003olF3Rol0003o000000;oahF;0oo9QX/3olV7R`;obXN;0oo9Qh/01?oBSXWod8f9om2=ROo@
SHT2om2<RP08om^FQoo@SH_od8f;omNCR?oCT8[o0000omRCQooAShd2omNCR@05omZDQoo@S8Wod8b9
om>=Q_o8QX`00_oCSXL2omJBR@07oo>^OOom_G7og9b>ombLS_oOW8Won/AIonNZT002onFUS@0@ooo8
K_oRXXkonlF;oo:jToog_hgonL:<oo[3R_ocbZGonMFSooK@YOofdjSoh]_>on?Ue?o=`<goooooo`00
02Gooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo8OnY_NP2
ojRlj004ojNjionDY>3oU:CPoh:=e@;oIVS000_oLW?5oe18Z_mQFK?oD3nNod@[S_mB>iSo@RJ8oeHi
TomG=8coCRZ4oehjS@02of8hR005od/TOom3883o;@]cochKO?mS=H<00_n6DX`00omF;H?oBBB1odTT
P@02oheHS@04og14S?mU>HOoV6:@oiQRT0;oG3B80_nDGi000omfBHooS5Z@ohaJT002ohEFTP;oS5ZA
0_n<Fi800on;FY;oUf:AoiMRT@02oea7X@05ojA[T?nkQYcoM4fFogA=U_nSLIX00onYL942of]2SP;o
/7>?00?oXVN<okYmTOn1DY000_nMII03ojm`R`03oja]R_njNH_o[fn900;o[fn90onbLXX01?nUJ8_o
/7:<ok1bS?n`LX`2oja^R`?o/gB<0_n^L8`3okIgS004ok9cS?o1P8go]gN<okMgS0?o_7^<00Go]7J<
ol:1S?o2PHco^GV<olR7S003okemS005ol:0S?l0003o0000o`000?o5Ph/00oo7QH/3olV6R`?obHN;
0_o:Qh/01?oDT8WobHN;olV7RooBSXT3om2=R@;od8b:00KofiJ7om2=RooGThSoei>8om>@R_l00002
omRCQ`;oei>900GofYB7om2<ROo@S8Wodhf6olR6S002om>>Q`;oeY:900?oljimoofmLOoLW8h00_oO
W8T05Ooja5WoijZ@onFUSOoUYHgoolQ^on:RS_okaH_ol[ZCooNoSOoi`Xcon/>:oo?:YOoieJ?om]2U
ooKCZ?okiiWohnGDolg0cOoGo]Goooooo`00000Tooooo`006Oooool01?l0003oooooooooool00004
ooooo`;o00000ooooolPojVmj0?oY[[W013oX;?UoiBTh?nDY>3oPXgEofIX`?m0>Z;oD4RZoc/[Tom@
?ikoA2^>oe8kV?m29XSoESVCoeLdS?m>:XCoGSZ=0_mR>8P01Om;97oo@b20obd;Loln6gcoHcF300;o
QU:<00?oERf3odTTPOm998400_n=F8d01?m`A8coICV7ofDiQonHHY02oe`dR0;oU5n@00?oMTV?ohaJ
T?n<FY000_n5EY82ohaJT@;oS5^B00?oReZBoiMRTOnGHY400_mLAj43ok^6W003ogA=U_nSLI[oXg6J
00;oZG2A0_m[@Xh2ok1cS`03oj9WS?njOI7oPE:@00?oWFF@0_n_L8/00on/KH[o^WV;ojm_R@02ojm_
R@?o/W::00CoYFR;ok1bS?n`LXco/7:<0_n/KX/3ok=dS003oji`S?noP8oo]WN<00;o]WN<00Co/W><
ol60SOngMhco]gN<0onlNh`3ol:1S003okUiS?o8Qhco_Gf<00?o00000_o2P8`2olF3R`?oahF;0oo9
QX/3olV7R`;obXN;00Coe929olV7Roo9Qh_odXj90oo@SHT2om2<RP04om^FQoo@SH_oei>8omNCR0;o
di2:00Go0000omRCQooGThWoei>9omZDQ`02om2<R@05om>=Q_o8QXcodhj7om>>QooFTXT00_oc[Wd0
1_om_G7og9b>omnLROoOW8Won/AIon2OS0;oiJF=00?oolQ^on:RS_ob^Y<00_og_hd00ooi`Xcon/>:
oo?:Y@02ooK@Y@07ooKCZ?okiiWocL3=omOneOo0_=Koooooo`00000Tooooo`006Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00?ooooo7onY_NP01?nX_>SoY[[WoinbiOnAXN02
ogZ6d`0=oeUM_?mVJ<3o@3ZRoe18Z_lk:i?oD3nNod@[S_mB>iSo@RJ8od@RP_mG=8coCRZ4oehjS@02
of8hR005od/TOom3883o;@]cochKO?mS=H<00_n6DX`00omF;H?oDBR0odTTP@02oheHS@04og14S?mU
>HOoICV7oiQRT0;oG3B80_nDGi000omfBHooS5Z@ohaJT002ohEFTP;oS5ZA00CoS5^Boiil[On1JJoo
Uf:A0_nbQ:@01OmLAj7o^hJLok^6W?nkQYcoM4fF00;oXg6J0_nYL942of]2SP;o/7>?0_njOI42oh5B
T0;oWFF@0_n_L8/2okYiR`?o[fn90onbLXX01_nUJ8_o/7:<ok1bS?n`LXco[6j;ol62S`?o/gB<00?o
[W2<okn0SonfMh`00_nfMh`3ol60S@04okMgS?nlNhco_7^<okakS0?o`X6<0ol000000onmOHcochf=
ol:0S002ol:0S0;oaH>;0oo7QH/3olV6R`?obHN;0_o:Qh/01?oDT8WobHN;om:>ROoBSXT3om2=R@;o
d8b:00GofiJ7om2=RooGThSoei>8om>@RP02omRCQ`04o`000?oGThWoei>9omZDQ`;od8b900Godhf6
olR6S?oCSXOodhj7omJBR@02oo>^O@06oofmLOoKUh[ogib9omnLROoja5Woh9n<0_oUYHd01?oob6ko
hZ:>oo:jToog_hd2ooW2S004oo[3R_omahSoolb1ooKCZ0;onnNI00Kod=m^onC:__o0_=KobmKRoooo
ool0000Sooooo`006_ooool2o`0000Gooooo00?o0000ooooooooool01?oooolMojVmj0;oZ;cX00Co
Y[[WoinbiOnO/^GoTJ7P0_mjQ]<03?mVJ<3o@3ZRobLIROlk:i?oD3nNod@[S_lc683o@RJ8od@RP_mG
=8coCRZ4oehjS@;oHSR800GoBbAood<PP?l]2g?o?Q]lof<eP`02ohIBS003oeH]PomA:83oBBB100;o
SER=00CoL4B<ofDiQomU>HOoV6:@0_mL=8P2oiAOT003ogI9Son<FY3oS5Z@00;oQEJB00GoS5ZAoiak
[_nNO:goWWb]oh5Y[`03ok:4Y005oea7XOnkQYco^hJLok^6W?mdCIH00_nSLIX2ojU`T@04oo73XOm[
@Xko/7>?ok1cS`;o^WfA0_n1DY02oieUT0;o[g2;0onjNH/2ojm_R@?o/W::00KoYFR;ok1bS?n`LXco
/7:<oja^Roo1PXl3ok=dS003oji`S?noP8oo]WN<00;o]WN<0oo1P8d01?ngMhcocHb>okakS?nlNh`3
o`000005okUiS?o8Qhcob8N<okemS?o?SHd00oo2P8`2olF3R`?oahF;0oo9QX/2olV7R`05omNCR_o:
Qh_obXN;omB@ROo9Qh/00_oBSXT3om2=R@;od8b:00GofiJ7om2=RooGThSoei>8om>@RP03omRCQ`03
o`000?oGThWofYB700;od8b90_oCSHH2om>>Q`05onbTO_oc[WgoljimoofmLOoKUhX00_oOW8T01?oj
a5Woh9n<onFUSOoob6h2on:RSP0=oo2aROog_hgonL:<oo[3R_okaHWooLN8ooo<POofdjSonnNIon>m
/Oo@gfkoi<Znol_FhP02okg/l`03ooooool0003ooooo027ooooo000Pooooo`;o00002?oooolKojVm
j006ojRlj?nV^^OoY[[Woijbi_n>X>3oLh7B0_m<DkP03?l`;9_o@3ZRobLIROlk:i?o<Q^5od@[S_lc
683o@RJ8od@RP_mG=8coCRZ4od/UO`;oHSR800GoBbAood<PP?l]2g?o?Q]lof<eP`02ohIBS006oeH]
PomA:83oBBB1oheHSOnNIi3oBBR60_mU>HL00onHHY3oG3B8oe`dR002oiAOT003ogI9Son<FY3oS5Z@
00;oP6V_0_nLNjh3oiil[@?o/XBT0_mLAj42ok^6W004ogA=U_nSLI[oXg6JojU`T@;olL>Q00?oJd:>
ok1cSon`Lhl00_njOI42oh5BT0;oWFF@0_n_L8/3okYiR`;o[fn90onbLXX01_nUJ8_o/7:<ok1bS?n`
LXco[6j;ol62S`?o/gB<00?o[W2<okn0SonfMh`00_nfMh`3ol60S@04okMgS?l0003o0000o`0000?o
`X6<00Go^GV<olR7S?o8Qhco_Gf<oln=S@02ol:0S004omBBS?o5Ph_oaH>;omRFS0;oahF;00?ofIN;
olV6Roo9QX/00_o9Qh/01OoGTh[obXN;olZ7RooDT8WobHN;00;odXj90oo@SHT2om2<RP;ofiJ70_oG
ThP01OoMV8Oof9>7omRCQooHThOo000000;ofYB70_o@S8T2om>=QP;odhj700Gok:Anoo>^OOoc[Wgo
oKeaom^GRP02omnLR@04oo[4FOoPWhcoiJF=ooo8KP;ohZ:>00[ol;69ooboNooi`Xcon/>:oo_5ROom
ahSoolb1oo3?F_o]]iSod=m^0_oTb[h00oo2kiOo_Nccojbki002o`0002;ooooo000Pooooo`03o`00
0?oooooooooo00Sooooo6_nY_NP01?nX_>SoY[[Woijbi_n=X>42ofiod`03og>1d_m<DkSoFEfl00;o
@3ZR00Wo>b^Coc8KQOm4:hko<aR0od8VR?m48X;oEcB<odhZQ?m;9Gl00_mR>8P01Om;97oo@b20obd;
Loln6gcoHcF300;oQU:<00KoERf3oe4XP?mA:83oSER=oiiWT?m9:8H2ofDiQ`03oiQRT?m6;8goG3B8
00;oU5n@00?oDd6NohaJT?nZOjH00_n0JJl3oiak[P;oWWb]00GoPFV_ok:4Y?nbQ:Como2Woea7X@02
ok^6W004od8iX?nSLI[oXg6JojU`T@;olL>Q00?o001/ok1cSoo5VZ`00_njOI42oh5BT0;oWFF@0_n_
L8/3okYiR`03ojm_ROo:R8co/W::00;o/W::00Ko_7f>ok1bS?n`LXco/7:<oja^Roo1PXl3ok=dS003
oji`S?noP8oo_h2?00;o]WN<00Go`H2=o`000?l0003o0000olf<SP02okakS0?o`X6<0oo8Qh`01Onm
OHcochf=oln=SOo2P8coe9:<00;oaH>;00Cof9J<olN5Roo7QH_ofIN;0_o9QX/2olV7R`;oei>:0ooD
T8T2om:>R@?od8f900Cod8b:om^FQooKUXOofiJ70_oGThP01ooMV8Oof9>7omRCQooHThOoei>9o`00
0?oJU8L00_o@S8T2om>=QP;odhj700Gok:Anoo>^OOom_G7ooKeaom^GRP02omnLR@04oo[4FOoPWhco
mkAnooo8KP;ohZ:>00col;69ooboNooi_8;on/>:oo_5ROomahSoolb1oo3?F_o]]iSoo]:AonC:__o]
h/@2ol[8f004ojbki?n`_nGoooooo`00027ooooo000Pooooo`03o`000?oooooooooo00Wooooo6?nY
_NP00onX_>SoY[[WojJji`02oijbiP0@ohfPhOm^Om?o@D^fodaC^?lP7iCo50V0od0jX_lk:i?o<Q^5
od@[S_lc683o@RJ8od@RP_m37gkoCRZ4od/UO`;oHSR800GoBbAood<PP?l]2g?o@a]hof<eP`02ohIB
S003oeH]PomA:83oDBR000;oWVN@00CoBBR6ogY<S_mjC8koXg:K0_m6;8d00onDGi3o/h6Ooe=1WP03
ojYoYP;oP6V_0_nLNjh2oiil[@08oh5Y[onbQ:CoFd>Kof>4gOm5>Z3o^hJLofA_b?la9i@2od8iX004
ojU`TOoa`j7olL>QoiRAb`;oaIZ/0_njOI42oh5BT0;oWFF@00?o[g2;okn4UOnjNH/00_njNH/00on_
KhWobXR<ok9bRP02ok9bRP06okamS_n`LXco/7:<ok1bS?n/KX_o`H:?0oncM8`3okn0S`03okIgS?l0
003o000000;o`H2=0_o=S8h2okakS003ombLSoo2PHco`X6<00?ob8N<00Co_Gf<oln=SOo?SHgo`X2<
0_oDTX`01Oo5Ph_of9J<olN5Roo7QH_ofIN;00;obHJ;00Cof9F:olV7RooGTh[oei>:0ooDT8T2om:>
R@?od8f900Cogi^7om^FQooKUXOofiJ70_oGThP02OoMV8Oof9>7omRCQooHThOohYb4omZDQol0003o
f9:6om2<R@02om>=QP;odhj700Ook:Anoo>^OOom_G7ooKeaom^GR_oOW8Won/AI00;oh9n<00WomkAn
ooo8K_oRXXkohZ:>oo2aROol_g_onKb2oo_5ROomahP00_ooc8402Oo`ce[okKNHookBTOoid9gommja
ol[8f?o<eN3o/;oUojVmj002ooooo`03o`000?oooooooooo01kooooo000Pooooo`;o00002ooooolG
ojVmj0;oZ;cX00CoY[[WohfRh_n=X^;oJgoE0_lgAkH03Om<DkSo81nDoa@9P?m0>Z;o7`]koc8KQOm4
:hko<aR0od8VR?m48X;o@amnodhZQ?m;9Gl00_mR>8P01Om;97oo8P9^obd;Lom36gSoHcF300;oQU:<
00?oERf3oe4XP?mA:8000_nNIi001?m9:8KoNTb>ogY<S_nSLY/2odH/S@?o/h6O0onZOjH2oh1Y[`08
oiak[_lc:IKod]]WofAN]onPT<?oFd>KofE@Y?mSQ=d2ofA_b004om?RM?la9iCo@SVPoo;[_`;olL>Q
00CoV97;oeA6Y?l006coaIZ/0_njOI401_l0003o046joieUT?nMII3o[g2;okn4U@?o^WV;00?o[fn9
olZ8S?nbLXX00_nbLXX01?nlOHko/7:<ok1bS?n`LX`3ol62S`;o/gB<00Go_h2?o`000?l0003o0000
omJIT`03ol60S@;ocHb>0_nlNh`00ooLW8oo`X6<ol:1S003olR7S004okemS?o?SHgochf=ol:0S0;o
e9:<00KoaH>;omRFS?o7QH_oahF;omVGRoo9QX/2omRERP03olV7RooGTh[oei>:00?oe9290_oBSXT3
om2=R@04omnKQooKUXOofiJ7om^FQ`;oei>800GogIR7omRCQooHThOof9>7on:LQ002omZDQ`04o`00
0?o@S8Wodhf6om>=QP;odhj700?ok:Anoo>^OOom_G400_oKUhX01ooOW8Won/AIon2OS?oPWhcomkAn
ooo5KOoRXXh00_o`/HT03_ol_g_onKb2oog1N_omahSoolb1ooW3Soo`ce[okKNHookBTOoid9gommja
oo7O_?o<eN3o`nO_0_nY_NP00ooooooo0000ooooo`0Oooooo`008?ooool00ol0003oooooooooo`0;
oooooaKoZKgX00CoZ;gXojJjj?nV^^SoWk?V0_n=X^805_m[OmGo=dNfoa0CSolP7iCo<2bKoa@9P?lO
2g_o<Q^5obH<NOlc683o<15iod@RP_m37gkoCRZ4od/UOom98GcoHSR8od/TOolR0Vko;@]cod<KN?mS
=H<2ohIBS003oeH]PomA:83oDBR000;oWVN@00?oBBR6ogY<S_mjC8h00_nSLY/01Om6;8go/h6Ook>1
WoncPIooDd6N00;oZWnV00WoICj>oiZLeOl^;Igo<bVFocQPcomTG[Oo<2NEoe]3VomUD:@00_m]E:@0
1omTKlSodn9doc4WU?la9iCoiOc;oeQ3W_oa`j400_oLkHX02_mDAZCoaIZ/okYmTOnjOI7o0000odaA
]ooHol[oWFF@ojm`RonoQ9D3okYiR`03ojm_ROo:R8co/W::00;o/W::0_nlOHh2ok1bS0?o`H:?0ol0
0002okn0S`03okIgS?oFVI?o`H2=00;o`H2=0_o=S8h2okakS003ombLSoo2PHco`X6<00?ob8N<0oo?
SHd00oo2P8coe9:<omBBS002omRFS004olN5RooIUh_ofIN;olV6R`;of9F:00?obHN;omNCR_oGThX0
0ooDT8T2om:>R@04onFQQoo@SHWod8f9omnKQ`?ofiJ70_oGThP01OoMV8Oof9>7omRCQooHThOohYb4
00;ofYB700Co0000om2<ROoCSHKodhf60_oCSXL00oo/Y7koljimoofmL@02om^GRP07ooF`O?oja5Wo
h9n<on2OS?og]7koolE]on:RSP02oo2aR@06ooboNooi_8;ooL5joo^mP?ooc87ol<mJ0_o]]iP01Oon
dY7onM2MooON/Ooagkco`nO_00;oY[o/00CoXKCVoooooooooooo00007oooool0023ooooo0_l0000=
oooooaGoZKgX01coZ;gXojJkj?nO]>OoWkCWohnUi?m/PmSo<DJhocM7]_l028[o81nDo`80MolD2H3o
9aV9oc8KQOlV37Wo<aR0oc0ANOm48X;o@amnodhZQ?m;9GooBB5lof8hR?m;97oo8P9^obd;Lom36gSo
HcF30_n6DX`00omF;H?oDBR0oe4XP002oiiWT003odTXQ_mjC8koNTb>00;oXg:K00GoARb=ok>1Wonc
PIoo/h6Ooe=1WP02ojYoYP09ofDnS_mR@ICo;RfMom;KIolhH<ooI5jgoc0WUOmK@i_o000000;oKEBT
00Go<B>@o`000?la9iCo<BNDonGlb`03oeQ3WP09o`000?mDAZCoaIZ/okYmTOl0003oMfjkomWcVOm<
DKOo001k00;o_hBE0onjNH/00on_KhWobXR<ok9bRP02ok9bRP;o_7f>0_n`LX`3o`0000;o/gB<0ono
P8l00onfMhcoeYVCol60S@02ol60S@;ocHb>00?o_7^<ombLSooLW8l00_o2PH`3olR7S0?ochf=00?o
`X2<omBBS?oDTX`00_oHUX`01?o7QH_ofIN;omVGRoo9QX/2omRERP03olV7RooGTh[oei>:00?oe929
0_oBSXT01?oUXHOod8f9omnKQooOVhL3om^FQ`03omNCR?oMV8OogIR700?of9>700GohYb4omZDQooJ
U8Oof9:6o`000002om>=QP05om>>Qoo/Y7kok:AnooZoE_om_G400_oKUhX01ooe/7con/AIon2OS?oP
WhcomkAnooo5KOoVYHX00_o`/HT03ool_g_onKb2oog1N_ok_H3oo/MYoo3?F_o]]iSoo]:AooW@WOog
g[7olMnlolK[R_o>o]ooY[o/oif^h`02ojBij003ooooool0003ooooo01kooooo000Oooooo`;o0000
3ooooolEojVmj004ojJkj?nAZNKoTJWVog2:g@;o;dZm01Go=dNfo`08R_lP7iCo0P1goa@9P?lW6HWo
<Q^5obH<NOlc683o<15iod@RP_m37gkoCRZ4od/UOom98GcoHSR8od/TOolR0Vko;@]cod<KN?mS=H<0
0_n6DX`00omF;H?oDBR0oe4XP002oiiWT003odTXQ_mjC8koNTb>00;oXg:K0_m6;8d2ok>1W`0:ofU3
TOnZOjKoICj>ofDnS_mR@ICo;RfMof91U?m5=IWo>63?oc0WU@;o9AjA01?oIE2TofeDY?la8i3o<B>@
oc4WU?oTh]3o8AZ?onGlbomH@iko0000oc=1/Ol06IgoaIZ/okYmTOl0003ofO>IoeIG]om<DKOo001k
00;o_hBE0onjNH/00on_KhWobXR<olZ8S002ok9bRP04okamS_l0003o0000o`0000?o`H:?00?o/gB<
on:WU?noP8l00_noP8l00onfMhcoeYVComJIT`02ol60S@?ocHb>0_oLW8l2ol:1S0?ob8N<0oo?SHd3
omBBS0?of9J<0ooIUh/2omRERP?oei>:0ooDT8T2om:>R@04onFQQoo@SHWogi^7omnKQ`?ofiJ700?o
ei>8omfHQooMV8L00ooHThL02?oRW8CofYB7omZDQooHTXKod8b9o`000?oCSHKodhj70_o/Y7h01ooj
_eKooKeaom^GR_oKUh[omK1loo[4FOoPWh`00_og]7h00oooaFgoiZF:oo2aR@02ooboN`0;ooVlP_om
`G[onkf0ook7JOo`ce[okKNHooS8F_oid9gooLnAo`000?oOoK/00_nZ_>H01_nM[^?oYK[Woj_5kOn[
aNgoooooo`0001kooooo0006ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000;ooooo
0ol00005ooooo`03o`000?oooooooooo013ooooo4_nY_NP2ojNkj00Coj6fionAZNKoTJWVog2:gOl_
B[go0026o`08R_l006oo0P1goa@9P?l<07;o<Q^5obH<NOlc683o<15iod@RP_m37gkoCRZ4od/UO`02
odTQO008od/TOolR0Vko;@]cod<KN?mfA8OoQU:<ohmKT?mF;H<2oe4XP0;oWVN@00?oBBR6ogY<S_mj
C8h00_nSLY/2odH/S@;o/h6O0_mY@i401Ol000GoICj>of91U?mR@ICo000T00;oACFI00Ko0008o`00
0?lU7Y7oIE2TofeDY?l/68@2oc4ST009oj_JL_lQ6XooiOc;oeQ3W_mMAioo<d6aom3Ih?m>A:Oo^WfA
00;oBdN[00?o0000oeIG]om_H[<00_noQ9D3okYiR`03ojm_ROo:R8cobXR<00?o000000?o_7f>ok1b
S?oU[IP00oo1PXl00oncM8cohZNDokn0S`02okn0S`03okIgS?oFVI?oeYVC00;o`H2=0oo=S8h2ombL
S`;o`X6<0oo8Qh`3oln=S@?oe9:<0ooHUX`3omVGR`;of9F:0ooGThX3omB@R@;odXj900CoiJ67om2=
ROoOVhOogi^70ooKUXL01OoVXXKogIR7omfHQoo[YXCof9>700;ohYb40_oJU8L2omRBQP03o`000?oC
SHKodhj700;ok:An00Oon[mFooo4KooKUh[ofiN:ooF`O?oN^SKoh9n<00;omkAn00CoolE]onJUR_o`
/HWoo;mk0_oi_8802_om`G[onkf0ook7JOoU_CcolK>9ooS8F_l000SooLnAo`000?ni_=`2oj6/g`07
ojFjion_bNgo[lW]ojg8kOl0003oooooo`00000Mooooo`001Oooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`;o0000
4_oooolAojVmj0;oYk_X01?oX[OXoiJ]ionF[NOo<e?4obm:_Ol008Go00R:oa0CSol207Oo50V0o``0
L_lb6hGo9Paioc<HP?l`4GWoA2:2od<OO_li5WWoBbEo00;oBB5l00GoBbAoob82K_l]2g?o@a]hogI4
Q`02ohmKT003oeH]PomA:83oDBR000;oWVN@00?oBBR6ogY<S_mjC8h00_nSLY/2odHQO`05ok>1Wom8
8gooPV2Soh9PXom37Wd00_mU?Xh02_mR@ICo000TofA8Vom5=IWoMU>Lob<FR?lU7Y7oCDb_o`000?l/
68@2oc4ST005o`000?l0087o8AZ?oeQ3W_mMAil00_nZZmL00om>A:Oo0000od]7Z`02oe@lV0;ohOFM
0onoQ9D2okYiR`?o00000_nbLXX2okamSP03ok1bS?oU[ISo`H:?00;o`H:?00?o/gB<on:WU?oRYi@0
0_noP8l3omJIT`;o`H2=0oo=S8h2ombLS`03ol:1S?o_/Xkokk:>00;ob8N<0oo?SHd3omBBS0?of9J<
0ooIUh/2omRERP?oei>:0_oDT8T01Oo][8KodXj9om:>ROoUXHOod8f900;ogi^70ooKUXL01OoVXXKo
gIR7omfHQoo[YXCof9>700;ohYb40_oJU8L2omRBQP03om>=Q_l0003ojJ9n00;ok:An00Oon[mFooo4
KooKUh[ofiN:ooF`O?oN^SKof9R?00;omkAn00ooolE]onJUR_o/[H_oo;mkooVlP_ol_WkooL5joo^m
P?onafWoiKdloo6cROohb5[o0008oog?TOobl9X00_ni_=`01?nQ[=oo[/?Yojo9kOn^aN/2oj_1jP03
ooooool0003ooooo01cooooo0005ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo4?nY_NP05OnW^nSo
Y;WXoiZbj?nJ/^SoP9gUociQcOl008Ko;dZmo`08R_l006Oo0P1goa@9P?l<07;o601bobH<NOlc683o
<15iod@RP_m37gko>AIiod/UO`02odTQO0;o8P9^00?o;@]cod<KN?mfA8L00_n?Fi000olR2WWoDBR0
oe4XP002oiiWT005odTXQ_mjC8koNTb>oj=bVooYb[L00_m68Gl01OoIZZOoB2=ooh9PXon2H:?o@aim
00;oICj>013oHT6Doe8/Q?mTB9_oACFIoddXPolS5XSo9AjAode<[ol0003o;1R4oc4ST?oXgLWoCBj;
o`000?lQ6Xoo00000_mMAil01?l0003oFCR?odi4Yol007X3oe@lV004o`0c^_noQ9Go_hBEokn4U@;o
00000oo:R8`01OnbLX[ojZb=okamS_nlOHko/7:<00;oiJfH0_o1PXl00oncM8cohZNDon:WU002okn0
S`?oeYVC00?o`H2=oooFROo=S8h00_o=S8h3ombLS`;okk:>00?ob8N<ooo=Q?o?SHd00_o?SHd3omBB
S0?of9J<0ooIUh/2omRERP?oei>:0_oDT8T2onf/QP?oiJ670_oOVhL3om^FQ`05onJRQ_oMV8OogIR7
on^VQ?oHThL00_oRW8@01?oJU8Oof9:6omRBQ_oHTXH2om>=QP06o`000?o/Y7kok:AnooZoE_ooa6oo
fiN:0_oe/7`01?oN^SKof9R?ooNdO_ooaFd2onJURP03onb]Rool_g_onKb200;ooL5j00Gonkf0ook7
JOoU_CcolK>9ooS8FP02oog?T@04oo;`V_oKd]3o]KgPokoEjP;o]<c/00Ko[/G[ojc0j?nZ_^SoZ[kX
ooooool0000Looooo`001Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`ooZKgX01GoZ;cXojBij?nT
^NSoV[;XodibeolnHLgo<e?4o`00Q_l028[o001Wo`80MolD2H3o301boaP0L_lV37Wo7P9aoc0ANOle
4gSo@amnocTFNOm;9Gl00_m98G`2ob82KP;o@a]h00CoMTB7ohmKT?n?Fi3o8PYi0_mA:802oiiWT005
odTXQ_mjC8koNTb>onW:]om/@X`00_m68Gl01OoIZZOoB2=oodPSOon2H:?o@aim00;oICj>00KoHT6D
oe8/Q?mfDico0000oddXPolS5XP2obM=``05ob0;Nol/68Co;1R4oo7J^Om=;X/00_l000002ol`7h_o
GDNOoee7Wol0003oFCR?odi4Yol007[o0000oe@lV?oVhWGoNFB^00?o00000_njNH/3olZ8S005ok9b
R_oZ[8go_7f>okamS_n`LX`00_oU[IP2ol62S`?ohZND0_noP8l3omJIT`03ol60SOooeXWoomJ900;o
cHb>0ooLW8l2onnbSP03olR7S?oocHCoolf400;ochf=0ooDTX`3omRFS0?ofIN;0_oHUHX00ooocgWo
ei>:omNCRP02omB@R@;okJb60ooUXHL2omnKQ`04ooNgPOoKUXOoiZ:6onJRQP;ogIR700GojjJ4omRC
QooRW8CohYb4omZDQ`03omRBQP;odhf600KojJ9no`000?o/Y7kon[mFooo4KooKUhX2ooF`O004omjj
=_oHV8oomkAnooo5K@;oiZF:00Cok:f;ooo6L_oi_8;ooL5j0_ok_H001_onafWoiKdloo6cROohb5[o
oLnAo`009`;ofm;@00Go_mGZok_?jOnkcnWo/<CYojc0j002oj^oj004ojVmj?ooooooooooo`0001_o
oooo0005ooooo`04o`000?ooooooooooo`0000Oooooo00Ko0000ooooooooooooooooo`000?ooool4
o`0000Gooooo00?o0000ooooooooool05?ooool=ojVmj0;oZ;cX01CoY[_XoijfjOnN]^WoRJKXo`0<
V?lnHLgo0026o`00H?l006Oo0P1go`00JOl<07;o601bobH<NOlN0W7o<15iocDCN?m37gko>AIiod/U
O`;oBB5l0_lR0Vh2od<KN004ogI4Qon?Fi3oSe^@ohmKT0;oDBR000?oWVN@omNUXooGYJ<00_mjC8h0
1OoYb[OoK4:<odHQOom68GoofJZW00;oB2=o00Coo=]lod<NOOmU?XkoICj>0_mB;8@2ogICW005oddX
PolS5XSo8aJ8oc/IO?lP2g/00_l/68@02?oaf[WoCBj;odd^Rol000oo<1n;oee7WooRfloo3`1f0_mI
>8l00ol000Co0000o`000002o`000003o`00NonoQ9Go_hBE00;o^WV;0oo:R8`01?nbLX[ojZb=okam
S_nlOHh3onF]V0;o`H:?0ooRYi@00onoP8ooFeJco`000002omJIT`03ol60SOooeXWoomJ900;ocHb>
0ooLW8l2onnbSP05olR7S?oocHCoolf4oln=SOoaeVD00ooDTX`3omRFS0?ofIN;0_oHUHX00ooocgWo
ei>:omNCRP02omB@R@;okJb60ooUXHL2omnKQ`04ooNgPOoKUXOoiZ:6onJRQP;ogIR700GojjJ4omRC
QooRW8CohYb4omZDQ`03omRBQP;odhf600KojJ9no`000?o/Y7kon[mFooo4KooKVXd2ooF`O0;of9R?
00_omkAnooo5KOoVYH[oiZF:onb]RoooaW;omkZ6oog1N_ok_H3oo/MYooBfQ`02oo6cR@08ooFjS?ol
`7ko000Wom_Bd?oLi]coeNKSok_?jOnebNT2ojg2j@06oj^oj?nZ_NSoZKgXojVmj?oooooo00006ooo
ool000Gooooo00Co0000oooooooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool0
00001oooool2o`0001Oooooo3?nY_NP01?nX_>SoYkcXoj:ijOnR^NT2oi:]j@0@odibeol039So0026
o`00Q_l006Oo0P1go`00JOl<07;o601bobH<NOlN0W7o<15iocDCN?m37gko>AIiod/UO`;oBB5l0_lR
0Vh2od<KN004ogI4Qon?Fi3oSe^@ohmKT0;oL4J?00CoWVN@omNUXooGYJ?oNTb>0_oYb[L01?lW3G[o
AR5ooeXdR?lU1g<2odPSO`09oocKO?m37WgoRFRUohUXYOl0003oDRb4ogICW?l000;oCBR300;oWHRl
00So>aUlo`001Ol/68Co_kllod/WQ?oaf[WoCBj;ob@BPP;o<1n;00?o000So`l0M_l000000ol00000
1?mD?9Sok]g1od/fUomiI:h2okn4U@;o^WV;0oo:R8`01?nbLX[ojZb=okamS_nlOHh3onF]V0;o`H:?
00KoE5k0on:WU?oRYiCo_h2?oe]F/ol00002omJIT`?oomJ900?ocHb>ooW2EOoLW8l00_oLW8l2onnb
SP04olR7S?oocHCoolf4oln=S@;olMIU00Goe9:<olc4@_oHUXcof9J<ol[2?`02omVGR`04oncAFooH
UH[of9F:ooo?N@;oei>:00ConKb4omB@ROo][8KokJb60ooUXHL2omnKQ`04ooNgPOoKUXOoiZ:6onJR
QP;ogIR70_o[YX@2on:LQ004onNRQ?oHTXKof9:6omRBQP;odhf600KojJ9nonbTO_l0003on[mFooo4
KooKVXd2ooF`O0;of9R?00_ollIAooo5KOoVYH[oiZF:onb]RoooaW;omkZ6oog1N_ok_H3oo/MYooBf
Q`02oo6cR@05o`002?ol`7kom=ecooS]VooLi]`00_o8f^L01OnebNWo/<KZoj^oj?n[_nSoZ[gX00?o
ZKgX00?oooooo`000?ooool06Oooool000Kooooo0_l00009ooooo`?o00000_ooool5o`0000?ooooo
00?o0000ooooooooool05oooool;ojVmj004ojRmj?nW_>SoYkcXoj:ij@;oLiCT013oHHCNo`0<V?l0
08Ko001Io`00Iol207Oo001Yo``0L_lH07;o9Paioah2LOl`4GWo=A=hod<OO_li5WWoBbEo0_m98G`2
ob82KP;o@a]h00CoMTB7ohmKT?n?Fi3oSe^@0_m`AXl3omNUX`07oeHgSolb47Ko<Q1fobL=N_m68Goo
FSB8obD7L`02odPSO`08oocKO?m37WgoRFRUohUXYOl0003oDRb4ogICW?l00082oddXP`09oif8_?lk
6Gco0005ob`HQ?oXnJkoBbN4oo7J^Om=;X_o000E00;o<1n;0ol000001ol000Co6AJ>o`00N_o^gL7o
6@f2od/fUomiI:h00_noQ9D00onjNH_oomF<olZ8S002olZ8S005ok9bR_oZ[8go_7f>okamS_ncl?H0
0_oU[IP00oo1PXoofmoJom_OfP02on:WU00;okn0SomKE[?oDeVkomJITom7D;Soc?RYogMa_oooeXWo
cHb>ooW2EOl002/00_oLW8l00om:M]_okk:>ooo=Q002ooo=Q004oln=SOoaeVGolMIUomBBS0;oc<A2
00Cof9J<ol[2?oo:`SoofIN;0_o/dE/2ooo?N@04omNCR_oi_8ConKb4omB@R@;okJb60ooUXHL2omnK
Q`05ooNgPOoKUXOoiZ:6onJRQ_oMV8L00oo[YX@2on:LQ005onNRQ?oHTXKof9:6omRBQ_oCSHH00_oY
XWh2onbTOP05o`000?ooa6oofiZ=ooF`O?oN^SH00_oHV8l00oocaU7oo<^>onJURP02onb]R`0@ooo6
L_og^XKoo/Akoo^mP?onafWoiKdloo6cROohb5[o0008ooc0O_odgG?on>fKonWecOo8f^Oo_]G[ok36
jP;o[<3X00?oZ[gXojVmj?nY_NP00_nY_NP3o`0001Wooooo000Nooooo`;o00006Oooool:ojVmj0;o
Z;gX0_nU^nT04_nI/^WoLiCTog>Di?l039So001@o`00FOl006Oo001Po`00JOl<07;o601bobH<NOlN
0W7o<15iocDCN?m37gko>AIiod/UO`;oBB5l0_lR0Vh2od<KN0;oMTB70_n?Fi02og16S`;oejFS00So
=Q=gof8nT?lb47Ko<Q1fobL=N_m68GooFSB8obD7L`;oB2=o00Soo=]lod<NOOm37WgoRFRUoc4@M_mB
;8CoMU>Lo`000P;oCBR300So0000oc/IO?l000Go80]kono<E_m;9hColMZiodd^R`?o00000_l002<2
o`000006oaTFS_naTKKo2`1joaT=P_l0003o000?0_noQ9D00onjNH_oomF<olZ8S002olZ8S0;ojZb=
00?o_7f>ogN1d?nNV/l00_oU[IP01_o1PXoofmoJom_Of_mDG/3oi?c9oc9;_0;oj?S=0_mCFK/01om4
FlGoMg6oomOn`Oo=S8koR97Fok7QmooLW8l00_n]`nX02oo_/XkoLY[Yog:JjOo?cm[olMIUohNCfOoa
eVGoe9:<olC3fOo<a4;of9J<00;ob/8o00?ofIN;oncAFoo/dE/00_oocgT01?oGTh[onKb4ooVlQ?oD
T8T2onf/QP?oiJ670_oOVhL2ooNgP@;oiZ:600CogIR7on^VQ?o[YXCojjJ40_oRW8@01OoWXXCof9:6
omRBQ_oHTXKodhf600;ojJ9n0_o/Y7h01Oooa6oo0000om^JSOoe/7cog[Xf00;of9R?00?ollIAooc;
S_oVYHX00_o/[H/03?ooaW;omkZ6ook4Nood]hSoo/MYonFm??oa/hWon<QJo`002?ol`7kon>fKonof
ZP;og?7N00Co_]G[okG:j_n/`>SoZkoX0_nZ_^P4ojVmj003ooooool0003ooooo00Oooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`007_ooool00ol0003oooooooooo`0Ioooo
o`[oZKgX01GoZ;gXojJkj?nN]^WoW[KYohBSj?leImKo00bHo`00Col005Wo001Wo`00Kol006Wo301b
oaP0L_lV37Wo7P9aoc0ANOle4gSo@amnocTFNOlh57L00_m98G`2ob82KP;o@a]h0_mfA8L2ohmKT0?o
L4J?00?oejFSocHCMomR?Y000_lb47H01olW3G[o5P1^oeXdR?lU1g?oB2=ooimgYOolfg`00_m37Wd0
1OoSce?o<A1foe8/Q?mfDico@A]j00;oCBR300GoflA2oc/IO?lk6Gco_kllono<EP03o`000007o`00
5OnnTj[o_Y>Zo`008ol006_o3`1fo`000002ok6A]P08o`/0N_l001Ko6@f2o`l<Q_l?2XCo_hBEokYi
RoooeH`3olZ8S0;ojZb=00Co_7f>ogN1d?o@nn?oWY[?0_nmko<00ongbnWoIXkUol_Ag`02ofMhd0;o
DW?E00?oDeVkonOka_m4FlD00_oEk>@01oofaE?oaloPohb/k?oLW8oo[L?Zojbmi_n`eoD00onCU=42
oh9c^P;oNg6m00Soa<?Iolc4@_oHUXcoF5Bbol[2?ooIUh_oLVbloncAF`?oolmi0_oi_8@3onf/QP;o
iJ6700?okliHomnKQoog]h400_og]h42onJRQP05omfHQoo[YXCojjJ4on^VQ?oRW8@00_oWXX@3omRB
QP0:om>=Q_oYXWkojJ9noo:nAoo/Y7koolA_o`000?oKVXgomK1lomjj=P;of9R?00?ollIAooc;S_o_
]I800_o/[H/03oooaW;omkZ6ook4Nood]hSonlQQonFm??oa/hWof[<[okbQ4?ol`7koa;`fonK`T_oL
lMkoc>CXokc@j@02ojo2j0;oZkoX0_nZ_^P4ojVmj003ooooool0003ooooo00Gooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0Joooo
o`[oZKgX01CoY[_Xoj:ijOnA[n_oTJo[ocEWe_l007ko001?o`00FOl006Oo001Go`00JOl<07;o601b
o`h0JolN0W7o<15iocDCN?m37gko>AIiocPDM`;oBB5l0_lR0Vh2od<KN0;oMTB70_n?Fi03og16S`03
omNUXolf4gOoHSj@00;o<Q1f00Oo9`ejoaH0K_mJ=8So9@McodPSOonOMjGo601^00;o@aim00GohlmC
oc4@M_mB;8CokM2god4KNP02oddXP`03o`007olk6Gco>aUl00;o00000_m;9h@04?l002?o001gob@B
P_nnTj[o000So`00Jol?07Ko022VoalLT_naTKKo000;o`005_lI3H;o000Io`l:Q?o?fVD3oooES0;o
bXR<0_oZ[8d01_nlOHkoL7oBog1od_m`Om;o_NocoijQe`;oVK;Y0_o;dMl00omWN=3oe^WRoe9ce@02
ol_Ii005ogV:f?o4c>3oNZG^ogZUk_o7cn000onJZ>002?n/_NKoM7[;ogAjbonCU=7oFTfYojS/X?n2
Lk[o00000_mkLKd01onTX]CojOZjoeQD/_mHE;;ok=5Kog9/_?mdMlL00ooocgT2ooVlQ0?okJb60_oU
XHL2ono>F0?omkN10_oVXXH01Ook_goojjJ4on^VQ?o[YXCohYb400;oij:40ooHTXH01ooZXh3ojJ9n
onVRO_ob_TOok:Anooo4KooKVXd00_l000001?oN^SKof9R?omRHSoocaU42onneTP0@onb]RoooaW;o
mkZ6ooNjQ_ona7_om;N8oo_8HOoU_Ccom;B4omZc:onlXA3oo<1nolBl=_oVl9;oi?bhokc@j@;o]<SY
00Co[L7Yoj^oj?nZ_^SoZ[kX1OnY_NP2ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0Kooooo`So
ZKgX0_nW_>P04onR^NWoW;O[ogfSjolIELko001no`00Col005Wo001Wo`00Eol006Wo301boaP0L_l>
06_o7P9aoc0ANOle4gSo;@aeocTFNOlh57L00_m98G`2ob82KP;o@a]h0_mfA8L2ohmKT006ob8:NOm`
AXooL4J?o`d0K?lI0G;oHSj@0_lb47H01olW3G[o5P1^oeXdR?lU1g?oB2=ooimgYOlH06h00_m37Wd0
1ooSce?o<A1foe8/Q?o]d;Oo@A]joddXPoocaIh00ol000005Olk6Gco000=od/WQ?m;9hCo1PF3o`00
MolT4X;oRVJSo`d0LOl006_o3`1fo`0PY_mQF[Co000;o`00M?l;07[o6@f2o`006Ol?2XCo0000oi>V
hP02oooES0;obXR<0_oZ[8d00om_IkWoN7O6og1odP02ol_[j`08oijQeonif_3o[/CYojk4jOn8Z^co
]lCTohfRh_nga^H2ohfbk`03olC<h?nkfo3oU9kJ00;oU9kJ00Oo_=g`oiZXh?nSgO_oXmgkol35g_md
N/_o`nnF00;oFTfY0_mTD:H02OmkLKgoYIG5og1KZ_m`Fj[oF5Bbod/kWOl0003oJEfbokCEI002ogAg
a`03oe1aeOoi_8ConKb400;okJb600?oPWBlonFQQooUXHL00_o_cUP3ooNgP@;oiZ:600Gonkmoon^V
Q?o[YXCojjJ4on:LQ002onNRQ0?of9:600KojZ>0onVRO_oYXWkol[i7onbTO_ooa6l2om^JS@05o`00
0?noTJOof9R?oo?6DOolbhh00_o_]I804_o/[H_oolIbooNjQ_ol`83oo/AkooBgR?okb67ojKm1ooBd
Q?oJ/b_o_:4@o`007?oVl9;oi?bhom_agoo7g>Wo]<SYojo5jP;oZkoX00?oZ[kXojVmj?nY_NP01OnY
_NP00ooooooo0000ooooo`04ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
0_ooool001kooooo00?o0000ooooooooool07?ooool7ojVmj004ojRmj?nU^nWoYK_Yoibgj`;oDH3Q
017o001no`00Col005Wo001>o`00Eol006Wo001ToaP0L_l>06_o7P9aob85LOle4gSo;@aeocTFNOlh
57OoBB5lob<3K`02ob82KP;o@a]h0_mfA8L2ohmKT006ob8:NOm`AXooL4J?o`d0K?lI0G;oHSj@0_lb
47H01olW3G[o5P1^oeXdR?lU1g?o8a62oimgYOlH06h00_m37Wd01?oSce?o<A1foe8/Q?l003<3o`00
0009o`007ol0003o>aUlono<E_l000goj?V^od/WQ?l61H?o001g00;oRVJS00co3@1ao`00JomZGK7o
92JKo`0PY_l006oo000@o`/0N_lA3HOo3PZ5oloJIOmhO<X2ohj?d005oooES?o:R8coGUJaoeaJ]ooZ
[8d00_oKo/401_mhMlKof_SNoh>Jh?n3V^3o^M[`ojJah@;oXkSX00Ko]lCToj:mk?nga^Ko]lKVohfb
konKZ=l2ok_Kl004oiBNf_nmnnWoTXc:oi:<bP;oSiGE0_n4TMP01?lo>Z?o`nnFoeY=ZOl000T2ofA@
YP06o`000?m`Fj[oL5^ZoePkTol001goBc^M0omnMKh02On7XnKoACRMok7LM?oi_8CoKVFgonf/Q_mA
Fkko000ionFQQ`02ono>F0;omkN100Co000FonJRQ_ok_goonkmo0_o[YX@2ooo8M@;oij:40ooHTXH0
0ooZXh3ojJ9nonVROP02oo:nA`03okCBl?oKVXgofiZ=00;o000000?o_i6Woo?6DOolbhh00_o_]I80
0ooN[:7oolIbooNjQP02ook4N`0:ooBgR?okb67ojKm1ooBdQ?oJ/b_o_:4@o`007?na_3Wod>AiolOL
j@;o^m?[00Co[lGZojc0j?nZ_^SoZ[kX2?nY_NP00ooooooo0000ooooo`03ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool00_ooool001gooooo00?o0000ooooooooool07oooool5
ojVmj00GojRmj?nX_NWoXk[Yoj>jjOnA[n_oDH3QoaUEc_l004oo001Io`00H?l005Oo001Yo`00I?lH
07;o3P1[oah2LOlR1G7o=A=hobd<MOli5WWo>1AgodTQO?lS0fl00_lR0Vh2od<KN0;oMTB701CoSe^@
om>oa_oC_lKoL4J?oc0>MOl=06co6@5bo`00F_l0097o<Q1fo`00F_lF06koFSB8obD7LolS4H;oWgNU
oaP0K_m37Wgo0000on??D`?o000000co@A]joddXPol0003o000Oo`000?lk6GcoklaFo`003Ol106[o
BbN4o`H5Pol007L2ohYVX`03o`d0LOl006_oJUfa00;o92JK00Ko0000o`004?l;07[o4@f7o`h:QOl0
0002ogQlbP04ohj?d?ooeHcobXR<ok[JK0;oG5Zg0_mIKlh00omhMlKof_SNoiBNf`02okK<j`06ojJa
hOn``nSoZL3ZojW0j_nR_NcoYKOU0_nbbn`01_nKZ=ooRX[=ohZ:cOn:R/goHfK0oi:<bP;ocoo900So
SiGEohBAf?o/nL3ok?W0ocljXom<=iOo0009ofA@YP;oKUb]00WoYIG5og1KZ_mH>i?o000Mod/kWOmN
BZ?oOWFnojfE_OlY8i@00_m5>9d02?mVDJKo000Nonf/Q_lgC[koPWBlonFQQomTC:7o@3bU0_og]h40
1?oDoMco000Foo^oOook_gl2on^VQ0;oolQe0_oWXX@3omRBQP03onZSP?oYXWkojJ9n00;ol[i700?o
]=;`om^JSOoKVXd00_l000001?noTJOollIAonneT_o_]I82omj/X@03ooo6L_og^XKoo/Ak00;om;N8
00conlQQonVo@Ood]8Cof[<[ooc0O_l001co/K`ionKkbOoFknCo^m?[ok?8j_n/`>P3ojZnj0SoZKgX
0ol00003ooooo`04o`000?ooooooooooo`0000Sooooo0_l00004ooooo`007Oooool3o`00023ooooo
1OnY_NP01?nX_NWoY[_XojJkj?nK]>T2o`0l`00Do`00Col005Wo0015o`00Eol006Wo001ToaP0L_l>
06_o7P9aob85LOle4gSo;@aeocTFNOlh57OoBB5lob<3KolR0Vko9PE_oeT^POm36gP2ogI4Q`0Aok1k
V_oC_lKo001Mog16Sol0063o3@1/oaT1L_l005[o201Vo`00>Ol005[o5P1^oeXdR?lU1g?o8a62oimg
YOlH06h00ol00002oc4@MP0Io`00<om16g[ollFNom_4@_l001oo8@Aaoc/IO?o_c5Ko000=o`40J_m;
9hCo1PF3o`03Q?l007OoRVJSo`d0LOl006_o;CfaofYM/OlT9Y_o0000o`004?l0007o4@f7o`h:Q@02
ofe]`P06ofJ`n_oLjMgoomF<olZ8S?ljD/3oG5Zg0_oSo;X00omIKlkob^;YoiBNf`02ok_8i004oi^i
kOn``nSo[lGZojo5jP;oZ;cW00KoYKOUokK;j_nDWm_od_7Wofagc?n:R/d2ofEQ^@07of=V`?n2NL7o
PWW1oh9i`On9/o;oB4:Wonci`002o`002`06od`gUomTD:Ko000^ofiL[OljCK[oL5^Z0_mH>i<01ol0
04KoGTZSojfE_On]UKgo:B>Do`000?m5>9d00_mRDJP01_m^IKOo=djnocTZToo_cUSoI4bQonWUN`;o
mkN100CoCSfMo`005_ok_goonkmo0_o[YX@2ooo8M@;oij:400Com[F2omRBQ_oZXh3ojZ>00_oYXWh2
oo:nA`07okCBl?oKVXgo0000ocX0AOnoTJOo0000oo?6D@02onneTP;ogZbQ00?olNJ2onFm[Oona7/0
0_od]hP02_o/[HcojKm1ooBdQ?o/Zh[oo<1no`007?n``43oe^oTolGOk?ngcN/2ojg1j0;oZ[kX0_nY
_^P8ojVmj003ooooool0003ooooo00?ooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo000:
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0Q
ooooo`GoZKgX01WoY[_Xoj6hjOnQ^>WoSJg[o`0l`?l003Wo000bo`00AOl005Oo001Yo`00I?lH07;o
3P1[oah2LOlR1G7o=A=hobd<MOli5WWo>1AgodTQO?lS0foo8P9^obH5KomI;X7o@a]h00;oMTB700ko
/7^Joa80K?l005goL4J?o`00H?l=06co6@5bo`00F_l806Ko000io`00F_lF06ko001WobD7L`?o0000
00?o@aimo`000?oSce<00_la47H02ol003?o@A]jod4KN_l005Ko000Oob44LOlk6Gcoanf>o`003Ol1
06[oBbN400;o1PF3017o001go`00Gol=077o3a6=oadLTol]?K7ogn1`o`000?l006oo0001oa4=Qom@
C[3oKFg2ol?bl?nm`mooAFkGoeUM_002onWj^003ocYB`?oIkn7oOhWD00;oaLgO00KoR[3_ok_8i?nh
dnko^=?^oin_h_n_aNX2ojN_gP06oj>ljonfbn[oSjGSohnUhooBlNOoK7O<0_oJolL02omUHKWoEE^l
oeEK_?n2NL7oc_KXolC:gooCk>KoB4:Wob`MS?lZ7HgoC3NG00;oF3nI00KoKUb]ocY=^_lc88[o0000
oePkTomJ?9<2oei:X`0<o`007_mK?9?o0000odDhWOl001ooHU6XohMm`OlK5H_o000`o`005OmTC:7o
@c6F0_l000001?m>?Igoi?Z^oo^oOook_gl2on^VQ0;oolQe0_oWXX@01?of]H;of9:6onZSP?oZXh02
onVROP;ol[i700WoS6ZVokCBl?l0003o001?oknAYonKLjCo0000ojdd8?o_]I800_oN[:401_oaiX;o
iKf]ook4Nood]hSonlQQonb]S0;om;B400Cok:^:ooVhNol0003o/<100_o?jnT01?ngcN_o[lCYoj^o
j?n[_nP2ojZnj0[oZKgX00?oooooo`000?ooool04oooool000Wooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool08_ooool4ojVmj00G
ojNlj?nQ^>WoVkGZoi^ej_l1Clco000io`00<_l004Go001Go`00G?l006Co0@1Vo`h0JolN0W7o8PEa
ocDCN?l]37Go>AIiocPDMom98Gco8`=_ob82K_lV1Fl00_mI;X403OmfA8Oo/7^Jok1kV_lB06co001M
o`d0J?l003_o001NoaT1L_l005[o201Vo`00>Ol005X00ol000001_lS4H;oWgNUoaP0K_mFAZ?o0000
o`00HP;o<A1f01_o000cod4KN_m16g[oV_?Ao`007olQ177o>aUlolO]S_l005[o0@1Zod/WQ?lN5hco
1PF3ol[AE_l005oo3@1ao`lASOnJQK_o00:Don[cc_l007Go001_o`000Ol=2HGo0000oe1>/?o0o<80
0_nm`ml00om5K]Ood^;SogB2d`02ol[?g@03ogRTk_o5cMoo_n7`00;oV:;L00Go^=?^oiVHdOnIV=7o
/]_eojN_gP02okSKlP03ojg0j?n?YN?obm[U00;oLW[;0_m=Ek`00omUHKWoGUjjoeEK_002olobj@07
olC:golj>jOoB4:Wob`MS?l0003oC3NGo`00=P02oePoV@05o`000?lc88[o0000oePkTomJ?9<00_mN
BZ<01Ol001_oFcbCobTSU?m5>9go92^Q00;oHU6X00Go000lo`00<?li:Y?ojNEkod<aUP03o`000005
of]<VooTnZko@3RPoc/0DOo[YX@00_oob7D2onNRQ004ooJeP_oHTXKojZ>0onZSP0;ojJ9n0_ob_TL0
2on<JZKo]=;`o`000?l004oo9QR9o`00M?l0003onkn3olk;BoniBP3ogZbQ00;oiKf]00Commb]ooBg
R?okb67ok:f<0_od]8@01oo/Zh[onKQko`002ooCmjCocn_Yok_Bjon_a>T00_n]`NT00on[_nSoZ[kX
ojVmj00:ojVmj0;ooooo00?o0000ooooooooool04Oooool000Wooooo00Co0000oooooooooooo0000
2oooool00ol0003oooooooooo`02ooooo`;o00009?ooool2ojVmj0;oZ;cX01KoYK_Yoi^ej_nC[NSo
G93Yo`00>Ol003;o0015o`00Eol005co001To`40I_l>06_o7P9aob85LOle4gSo;@aeocTFNOlh57Oo
9@Mcob<3KolR0Vko9PE_0_mI;X42ok1kVP08o`00G?l005Oo001Mo`d0J?l003_o001No`00Dol005X3
o`000009oaH0K_l006Oo9@Mcob<AP_l005go601^obY6^ol0003o001R00;o<A1f017o000cod4KN_m1
6g[ok_N^o`007olQ177o>aUlolO]S_l005[o0@1ZomoafolB2X;o7QN<ol[AE_l005oo3@1aobTLS002
oiZ5^`07o`02U?l007Go1aBDo`@6QOoUkH[o=Sj]oe1>/002oi6Jf@06oiZgk?njaN?oOZO^ogjWk_o:
cmgo`Mo^0_nCVmP2okoQl004oiRRg?njm_3oVISAolkng0;oRi?F00Co^=_boinOe?nJ/n[o]/[Y0_me
SM`00ombN/_oG6C2odeG_002on;l^@0:oeiN^_o?l^WoZMKgolC:golj>jOo7A:7ob`MS?l0003o:1^;
o`00=P;oF3nI00Go8Q>5oc<PR_l0003o?B>8o`00C002oj6Ca@05oe8aRomK?9?o:B>DogEO[?lT:j40
0_nBM[002?l003co6aF;ocTZToli:Y?o000Lod<aU_lF5XooBRj>0_m[C9/00om0>:3o001;ooo8M@02
ooo8M@04onNRQ?of]H;om[F2omRBQP;ojZ>00_oYXWh03?ob_TOo/B`0ohaZY_l002Go001Bo`00Conc
G`3o001doiE[Wol0003odINHo`00DP;oiKf]00[olLn_ooOL[Ood]hSonlQQonb]S?od]8CoolE_onb[
R_oi^7_o00000_oGm^801?nkd^_o//SZojg1jOn[_nP2ojZnj0coZKgX00?oooooo`000?ooool04_oo
ool000Wooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02Cooooo00GoZKgXojRlj?nW^^OoYk[Woj:fi`02oi>]j00Boeb@jOl003;o0015o`00Eol0
05co001To`40I_l>06_o7P9aob85LOle4gSo;@aeocTFNOlh57Oo9@Mcob<3Kol206?o9PE_0_mI;X42
ok1kVP06o`00G?l005Oo001MooWKMOl003_o001N0_l000003ol806Ko000io`00F_lF06ko001WogEL
Z?lS4H;o001MoaP0K_l008Oo0000o`00H_la47KoaM]Zo`00<`02od4KNP07onkP`ol001oo8@Aaoc/I
O?mODJ_o001Jo`40JP02omoaf`07o`0HW?o:dEKo001Oo`d0LOoakl;oVXFkoiG^lP02olnmb@06o`LD
U?l41XGoEFK8ocHn[OoKo/ooTI[I0_naa>P01onjaN?oV:SQoiRXhOnHZ>7o`Mo^oi>Kf?o0oN400_n<
Q/L3ofmaa006ogmg`?n;TmKo`oO^ol?gk_nOWmCo_>cc0_nfb^T01?meSMcof^GMoeaT`_mLI<82odmU
b@0:oeiN^_o3jO3oBDJ[ojWFmolj>jOo7A:7o`001Ol/7Hco000_obPKR`;oF3nI01Ko8Q>5o`000?lc
88[o?B>8o`00C?mJ?9?o0000oe8aRol001_oFcbCogEO[?lT:j7oTWJ`od4/TOl003co6aF;ocTZTol0
04Go000Lod<aU_l004go20170om[C9/01Ol004_oolQeooo8MOn5HjCoij:400;om[F200?of9:6onZS
P?oZXh000_oYXWh02?ob_TOo5Q><okJ4Wol002Go001Bo`00Colj04Go001d0_nEJil04Ol0003o001B
olQ]0?oU_JgolLn_ooOL[OoFZ:WonlQQonb]S?od]8CoolE_onb[R_oi^7_o]m]_omOfh_o2f^co]/g/
00;o[/?Z00?oZkoXojZnj?nY_NP03OnY_NP00ooooooo0000ooooo`0Aooooo`002Oooool01?l0003o
ooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`0Uooooo`05ojVlionW^^OoXk?T
oj>ci?nM/NH00_n:[nh01_l003;o0015o`00Eol005co001To`40IP;o3P1[00Wo8PEaob85Lol]37Go
80AbocPDMolU1g?o8`=_o`80HolV1Fl00_mI;X42ok1kVP03o`00G?l005Oo001M00?o0000017o001C
o`00F_o>[[Wo000io`00F_l0063o001WogELZ?lS4H;o001MoaP0K_l008Oo000co`00H_la47KonNbN
o`00D@02od4KNP07oifHcol001ko8@Aaono<E_nYdfOo001Jo`40JP02obM:`003om;cV_mCF[co=TRh
00;olNo200Oo8CffojCam?o?_LWockg9o`0OZ?oMm=goEFK800;odlgD00OoO:3Yok74j?n_foOo[m_g
ok6lh_nHZ>7oa]o[00;oR8C90_mKGkd01_n<Q/OoJf2dofmaa?mAEKOo_?FZogmg`0?oNGo=0_nOWM80
1?n<Y>Go_mS/ofV3f_mLI<82omknc003odmUbOnh_]ko`nW`00;oBDJ[02Ko3PZ5o`000?l000Go000_
o`00<olX6h_oF3nIomK^i?lR4hGo0000oc<PR_lm8hSo001<oeXlTol0003oDS6;o`006ol0057oMEn/
of=7VolT:j7o001>od4/TOlK5H_o001;o`00AOmB=I7o@c6Fo`00COl804Oo0000of]<Vol004Ko001;
oah@Q?mH>iCoomB9oc/0AP?om[F20_oZXh002_l0003ojJ9noo:nAolF4hco]XBOoch0D?l005;oYSe1
o`00ColV68T2oiE[W`04om6GV?l0003o001Eom]b00;ommb]00[oeZRYooOWR_oCWj3om;B4ooo5Koo/
Zh[onKQkom_me_o8i>co]/g/0_n_aNX00on[`>WoZ[kXojVmj00?ojVmj0;o00004Oooool000Wooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`;o0000:?ooool03?nW]nCo
Xk?Toj>diOnS]>GoXkg/oi;7n_l003;o0015o`00Eol005co001To`40IP;o3P1[00Wo8PEaob85Lol]
37Go80AbocPDMolU1g?o8`=_o`80HolV1Fl00_mI;X400on`Ni[o0014o`000002o`000007omV`[_l0
03_o001Do`00Dol005[oZXRao`00>@02o`00FP0?o`00Iol008Co001@o`00GOlH06kon^ZLo`00<ol0
06;o<A1fogUY]?l0057o@A]joc]HaOnMV<oo000N00;o8@Aa00Go00^Do`00F_l002?o_jc7obM:`002
oc5Gb@03oe=J_?oNnmOoQ9GL00;ocm3J00OoJXgQojW6koo7_m;oakoBod^:j_oCcMCob_K[00;oUYC@
0onCR<@01_nT`>koFggKoe]mfon8Q<WoIVNooe]O_@;oeOVZ00KoJf2dolkZQ_mAEKOoOgO0og=]_Omi
Old2oloiiP06oinMd_njgO;o_mS/okoHk?mYPm[odM[O0_m`Q=L00onh_]ko>CbYol?Yl002o`002004
o`000?lM4XOo6127o`00<`;o:1^;00coe^kTonk]T?l0003o<b2:o`00B?lm8hSoFSbCo`000?mB<H_o
000KogI?UomeGj`2of=7V`0>o`00C_m1;97o@BbAo`00Bolg7hOoDSFAod<aU_l004go2017o`000?m[
C9_o0016o`00BolN48@2oePkU004ofPAAOof]H;om[F2ooJePP;ojZ>0017o0000onVRO_l006WoG3fD
okJ4Wol0073o0017ojHm@Ol004oo9QR9o`00M?nEJioodINHo`000?l005;ofg80o`00A@02omJXZ@;o
dinP00Womkn>ooo5KooNWi3onKQkomOn`_o8i>co^M;]ojo5j_n/`>T00_nZ_^PAojVmj003o`000?oo
oooooooo00oooooo000:ooooo`;o00002?ooool5o`0000?ooooo00?o0000ooooooooool0:?ooool0
2onT/n?oXkCUojg0ion]`>Oo]<_[o`00<_l004Go001Go`00G?l006Co0@1V00;o3P1[00[o8PEaob85
Lol]37Go80AbocPDMolU1g?o8`=_o`80HolV1FooFBj10ol000007ol004oo001Go`00GOoI/:ko000k
o`00E_l005?o001JojZ8/Ol003Wo001oo`00F_n=R<Wo/m1Lo`00?_l005go601^oo[ZW?l003?o001R
oc4@M_miJKCo001Aod4KN_oakiKo>eS5o`007_lQ177oj>G=ofEU_Ol005X00_m0G/T01?nhb>Koflc:
oc5GbOnoi?42oh^Gf@08olo@f_nda^SoT[_boi:kl_o7_m;obl_Iogf?f_o7o^02og]]^004oiJDd?mQ
D:SoThS4o`0000;o[j7900CoFggKolJjcomVIkooIVNo0_lbAKL2oeeM^P07oe5E]ooPo;OoLffmog=]
_OoVn/goMh[Iok[MlP02ok>mhP03ohJIg_oAf]ooVKK/00;oU:CP01?o?3bWokglaOli?:Wo0000oaLA
ROl>2XGo7A:7o`007OlH48Oo:1^;o`000?oFk^Co=b::ob8CQOlB1Gco0018ocdSR?l0003o9Q6000;o
DS6;00GoMTnGogEO[?meGjco001<oe<cS@02od4/T@0;obTEPolg7hOoDSFAoe8eTOl507co7`n1odX^
S_m[C9_o001;o`00N?lN48@00_mH>i@01?l007Gom[F2ooJeP_of]H82onZSP00Ao`000?oYXWko001Y
oe`mU?lF4hco001`o`00Kol005[o001?obHHROl007CoUF^Oom6GV?n;6BCo0000olQ]0?l004D00_oF
Z:T2om>OX006ooNoS_oJXIWogYn@ooVhNoo=k^[o^M;]0_naan/00on/`>WoZ[kXojVmj00AojVmj003
ooooool0003ooooo00oooooo000Looooo`03o`000?oooooooooo02Wooooo00[oYkSUojg0ionga^Go
]lKUo`00<_l004Go001;o`00G?l006Co0@1V0_l>06/01olR1G7o8PEcobd<MOlP17;o>1AgobD7LolS
0fl00ol000006omI;X7o/7^Jo`00A?l004oo001GohY[Z_oI/:ko001>o`00E_l005?oK[cmoncNL?l0
03Wo001;o`00F_oHj87onn6To`00?_l005go601^oo[ZW?l003?o001Roc4@M_ngaNGo001Aod4KNP02
oib9_`08o`007_lQ177oM83@onkh_ol005[oRhoBofG7oOoKc<X2okVlg006okoTlOn;UmWo^LGSokW5
honda^So[ZcF0_mc^O/01Oo;bmWoZ[WTobHk/Oo7o^3oNffh00?oHE2X00KoK5FUojnQbOn0I:WoP6BY
olJjcomVIkl2on[MaP07oc95]ooRel_oGEfjoeeM^_oSe<SoLffmonKjc@02oiF`jP05okFmgonc_N;o
WJ;HoifRf?nhfO400_nI]^`05?nDY>3od?fkoc`lYoli?:Wo0000oaLAROl>2XGo0000o`007OlH48Oo
0000o`T3Ool007Wo=b::ob8CQOl004co0018ocdSR?l0003o9Q600_mB<H/02OmfCiOoK4JCogEO[?m3
9XSoDc>=od4/TOn^Oj7o:AF3ocLOQ`02oe8eT@0:o`D0O?lO3h7oBRj>ook?R_l004_o001hoah@Q?m?
02coF3^Do`@0F`?om[F20_oZXh02o`00000Ao`00JOmL?ICo5Q><o`00L?ln053o001Jo`00ConcG`3o
9QR9om6GV?l005?oRaTTo`00D_l0003o0015o`00R?ogihX00_oCWj001Oog_hkofZ6IomjOT?oi^7_o
_=S]00;o//W[00Co[<7YojZnj?nZ_^SoZ[kX4_nY_NP00ol0003oooooooooo`0>ooooo`007?ooool2
o`0002_ooooo00Wo[l7WokO6iOn^_nOo000bo`00AOl004_o001Lo`00I?l106H00_l>06/01?lR1G7o
8PEcobd<MOlP1783o`000008o`80HolV1FooFBj1oeT^POokj9oo0014o`00Hol005L2ohY[ZP08o`00
C_l005Ko001CoocUV_lY<jOo000iobDNTOnZRK82oo_QY00:o`00?_l005gon^ZLoi1i]Ol003?o001R
okBJ_Ol0HmGo001Aod4KNP;oW8Vo00Go000Nob44LOmdP=3oi^C@oh^?dP02om?Lg`06of^FjOni_=co
d<G@om35d?mUW>oo^LGS0_nmg_003On^[=KoQHkEohF>eOn5S]GoZ[WTolV``_lV>k7o[<iKocTaW?mQ
D:So>bVAo`000_m/EJD00on0I:T2oh=WZ@;oMlco00Coh]O;oeeM^_oSe<SoLMRX0_nbXlP01OnE/>[o
V8S1oiR8`OmiLKgoWJ;H00;oaOcV02GoWjgQohRHg?oWlm;oio?Boc`lYoo4gVoo0000oaLAROl`ImOo
2R>To`00O?lH48Oo1`=oo`T3Ool007Woe^kTo`00B?l004co0018ocdSR?lA0g[o9Q60o`000?mB<H_o
MTnGofa6TomeGjco@bJ8oe<cSOn^Oj7o001;obTEPolg7hOo0015oe8eTOl005;o7`n100;oBRj>00Oo
001;o`00A_l004_o7Q24olVCW_l405_oJ15500;om[F200GojZ>0o`000?l005go001Mo`h5OP02oe`m
U00=o`00F_ln053o001Jo`00Col006go9QR9om6GV?l007Ko001Yo`00D_o8K@3o0000o`00;P02om>O
X0;omkn>00KofZ6IomjOT?oi^7_o_mc^ok;9jon/`NT3ojZnj1?oZKgX00?oooooo`000?ooool03_oo
ool001cooooo00?o0000ooooooooool0:oooool02?ndb>WoZlO^o`00<_l004Go001;o`00G?l006Co
0@1V0_l>06/02OlR1G7o0000o`000?l0003o>1AgobD7LolS0foo0P1SobH5K`02oeT^P@04oo_XWol0
06So001SolJ]`P;oRV^Z01co001>o`00E_nkTJ_oo>FJonk:[_l007Go000?on7Ab?okhJCoZhjgo`00
?_l005goX[WYoi1i]Ol003?o001RokBJ_Oo_iLCo001Aod4KN_nLRKooknk5okj^b_lQ177oJj[fonKT
d?nTZ=[odmcO0_n`_^@01Om^Yo?od<G@om3:e?o@b]CoOiWR00?oRh[=00?oRH74ohF>eOmIDk400_o9
/<802?lV>k7ol_:loo;b_?mQD:So>bVAo`000_m/EJGo?RV>0_n0I:T2oh=WZ@?oTG:/0_mlHJP2og=J
YP04ok:Sb?nHR<7oV8S1oiR8`@;oNG6m0_n=R<T01?n>Y^God>SWobmEaol_ELL2od5A_003o`8HVooW
fLOo<6OG00;oOW6j00ko001Yo`L3Ool0003o0000omK^i?l004So001<oa85O?lm8hSo000EobHAP?l0
003oDS6;ogI?U`;oK4JC00Go@bJ8oe<cSOn^Oj7oV6NHobTEP`02ocLOQ`0Toi]/V_l005;o7`n1o`P0
Aom:;Xko001;o`00P?l007So7Q24olVCW_l405_oJ155ooJeP_mC=I3ojZ>0o`000?l107So001Mo`h5
O_l006WoG3fDo`00F_ln053o001Jo`00Col006go9QR9om6GV?l007Ko001Yo`00D_l005Go0000o`00
;_l008oodinP0_og_hh00ooJXIWogYn@ooVhN`02ok;:k004ojc1jOnZ_^SoZ[kXojZnj1CoZKgX00?o
ooooo`000?ooool03Oooool001cooooo00?o0000ooooooooool0;?ooool02?n[anko000Do`00=ol0
04_o001Lo`00HOl106Ko001T0_l000002?lR1G?o;@aeob04L_lh57Oo9@Mcob<3Kol206?o9PE_0_mI
;X402Ol004Wo001No`00Hoo6[L;oRV^Zonc@^?l004ko001FoocUVP02onk:[P03o`00@ol007GohM78
00;oZhjg00[o000no`00GOl0=JSoT7Veo`00<ol006;o]9ZmonoUa?l0057o@A]j0_oGkN801onn[/[o
8@Aaolg4dOlTO>KoY:SJol_6e_n`_^@00_n^[MH01_mL[?Wod<[Dok^jf?nk^]SoCF;7oh^:c@;oaog0
00OoRH74on;hYomIDk7obK32oiYeZOl008ool_:l00;odmAK00Oo>bVAo`000?ln:HkoP6BYod`aT?l0
02GoPfNY00?oTG:/0_mlHJP2og=JYP;oFTRS00?oV8S1oeI;ZOmiLKd00_mWLLT01_n=R<WoZoCbom3X
ioo@j>Oo;eG7on3Id0;o@E6l00KoimW7o`PWZOl`ImOo000<onKWO_l00102o`00000AomK^i?l004So
001<oa85O?l002;o000EobHAP?l0003o001DogI?Uom/AY?o001<od<VR?mC<hgo[WnQoiQWV?l005H0
0_lg7hL09OnKK9[o001Bo`00COlO3h7oBRj>o`h0<?l0083o001hoah@Q?o9Tiko101KofPAAOl006co
DcF@oehNI_l0003oZC8Ro`00GOl>1Gko001Yoe`mU?l005[o001`o`00M?l006So3@AnobHHROoAUiSo
001fo`00JOl006Co001Eo`00?_l0003oJDbMom>OX?og_hh00_oJXIT01?oNWi3onKQkok?;k?n/`NT3
ojZnj1KoZKgX00?o0000ooooooooool03?ooool001_ooooo0_l0000_ooooo`04o`005?l003Oo001;
o`00G0?o000001Wo3P1[ob85LOlR1G?o1`1_ob04L_lD0GKo9@Mco`00E_l206?o:a1koeT^POokj9oo
000]o`00G_okgJKoaZg2ohY[Z_ojhH?o001>o`00E_oliI[ok/Z^oljc`?l004?o001e00;oTHk<00_o
Zhjgo`000?l005goln>ko`0HW_l003?o001RonoUa?o>]l?o001Aod4KNP03oi2OgP07ob44LOo=a=7o
b;W<oc:2jOo;a]Koc]KOojj]eP02om?^iP05ogJ?g_nk^]Soe<77omC1aom=H/L00_mIF[P01?oRn:Oo
Edn]oeUC/Ol00002oiYeZ@07o`00SooCe5_odmAKoc/YTOl0003o?RV>oh1TZ@02od`aT00@odD]Sol?
03[oTG:/od@]T?mlHJSo=bF>o`00<omcFZKo000LoeY8XolT<JOo0000oeI;ZOn]dfCoIg79olJmdP;o
ZJcI01?oPHG?olS[k_mV_OkoI[gnoj71kooVim7o?DJao`PWZOlc@[?oi^Mno`004?l0003oA5c5omK^
i?l004So4`Eloa85O?l002ko000E00;o0000033o001Dob@DQOm/AY?o001<od<VR?l004coDc>=oiQW
V?l005Ko001;ocLOQonKK9[o001Bo`D0O?lO3h7oa8nMo`h0<?l0083o001hoah@Q?o9Tiko001fofPA
AOl006coDcF@o`H3P?l>05SoZC8Ro`00GOl006co001Yoe`mU?l007So001`o`00Aol005[o3@Anofa:
UolV68Wo01FTo`00JOl006Co001Bo`00?_l0063o0000ofU<WOog_hh2omZQV@03omjOT?oi^7_o[<7Y
00?oZ[kX00?oZKkXojVmj?nY_NP05?nY_NP00ooooooo0000ooooo`0<ooooo`006oooool00ol0003o
ooooooooo`0^ooooo`0Oo`005?l0003o0000o`000?l0067o0@1Vo`00I?l>06_o4`1aob85Lol706oo
80Aboa@1M_lU1g?o001Fo`80Hol[47_oFBj1oo_XWol002go001Noo_MY_okdY_oo=6GomZ]ZOl004ko
^i6[on?_T?naS[7oc[?0oo[UZP02ok>Oa00Doc1fh_n[S[OogM[DokbN^_ochk_ockG0o`0HW_l006;o
c^_Yoljg`ol0057og<g:omO4aon@Wmko^/CQob44LOo=a=7ob;W<om_Ke_mVYO@2ojFQd@?oShC300?o
Ff6oomC1aonki?<00_lOD<P01OmIF[Soe_BMoeM?[Oo`jHSo2`b900;oVWFY0_nmV;805Ol007Oo>bVA
on:fZ?ln:Hko001go`008?m<<I3o000RodD]SonALZcoA2f@ogaQZ?l000oo000co`007?l0003oFTRS
omkOK_lT<JOoe[Znof9keP02olJmdP04ok[kj?ml/?CoO;3dolS[kP?oOHKA00Ooi^OAoce6/OoDmjKo
e?NVoc=2/ol006Wo1`=o00;oWjcP00Go001^oa<5O?lB1Gco000^o`005@02o`00000Ho`00E?lT58Go
MTnGofE1TOl005co@bJ8oe<cSOnHIiSo001FobTEPolg7hOoVfbJoaLBR_l507co7`n1olB?WOl>033o
0020o`00N?mcCIKo7Q24o`00M_l007Go60Un0_mC=I005?l007WoZC8Ro`00GOl006co001YonfcT_l0
07So001`o`00Kol005[o3@Anofa:UolV68Wo01FTo`00JOn;6BCo001BolQ]0?l004Go00000_mYC9d0
1OoJXIWogYn@omjOT?oc]8Ko[<7Y00?oZ[kX00?oZKkXojVmj?nY_NP05OnY_NP00ooooooo0000oooo
o`0;ooooo`006oooool00ol0003oooooooooo`0/ooooo`?o000001Go000go`00Bol005co001Qo`40
I_l006Co3P1[oa<0LOlR1G?o1`1_ob04L_lD0GKo9@Mco`00E_l206?o:a1koeT^POl[47_o000]o`00
G_oIYj800_oldIL00ooJ[JWo001>oeA?/002ok6>/@05ooGZ^_ncWlCo/io4ok>Oa?ni[Ld00_oMf]@0
2?ochk_ockG0olne`?oQcLGofL?4o`0k^On>Wmoo001A0_oGa<L03?oB_<Co9WKSok[Gkonjenoob;W<
om_Ke_nfW[oo05G;ojFQdOoVk=;oShC3onGk]P;oFf6o0_nbTkL01?lOD<So`jg4ol>]a?mGCjd2oo3Y
R0;oVWFY00?oFS^AokfH/_oR]ZP00_oR]ZP04Oln:Hkoo]:?o`008?l002;o0@1kodD]SooodXSo000Y
od@]T?l0077o=bF>omN_[ol0003oFTRSo`1M[OlT<JOoe[Zn00;oQ9SN00?oa[gBok[kj?nFU<l00_nY
]>401Onh^]_oOHKAolkQi_o>hNKoHWC?00;oCV7501oo<d:cogJ4e?mXL/WoJ7;9ol;/S_l006ko4`El
o`002?l002ko001do`000?lA0g[o000hob@DQOmfCiOoID6Ao`00G?m39XSoDc>=oiQWV?l005Ko:AF3
ocLOQonKK9[o5a::o`D0O?lO3h7oa8nMo`00<_lH27co=1f600;oLdfF013o001Mo`00MOlH2Gko001/
oe<eT?l007Wo001eo`00GOlQ4HCo3PEnonfcT_l007So001`o`00Kol005[o001?0_m/BYL03Ol05JCo
001bo`00JOl005;o001Eo`00AOl006Wo0000ofU<WOoJXIWogYn@oog5I?oc]8H00onZ_^P00onY_^So
ZKgXojVmj00FojVmj003ooooool0003ooooo00_ooooo000Kooooo`;o0000:_ooool3o`0000;ooooo
013o000Do`00=ol004_o001Fo`00HOl106Ko001To`h0JolC077o8PEco`L0KolP17;o505fobD7Lol0
05Ko0P1S0ol[47/01Ol002go0019oo_BVooldIOofZfY00;oo]^F00Kohnn@oi@<0?naS[7omNZjomfg
/_ncWl@3okV]c@0:oh^Ae?oPg=7oh=cAolne`?oQcLGofL?4omBj`Ol0AlGo]L?TomO4a`;od[c400Co
gm;<oiBHe?nDV=CoU9SD0_nfW[l02_o]n;ooMXKFogJ6e_mfQ]KoLFFfoe]Q_olE8Ico0000ok:C]om`
EZ@2ol>]a004o`0TZoo>^lSol>V8oiYeZ@;oFS^A00Co000_ofA1T_oR]ZSoh[JX0_ondXl03?l007Oo
o=UioocINOm5;Hooom:8o`00:Ol000oo001aocLUS_oG[joo002@ojN1[0;oDE6c00Koe[Znog5W^?n4
V=koe>WToiJDconbl?H2ojV[f@04oi6`k?ndeo;o]=ObogNKj0;oLG?500?oCV75om74cOmfQ=@00_nC
Ql<0;Ol0003o`^b>ob/XV_oflJgoNffho`00M?l0003o/<10o`002olT58GoMTnGofE1TOl005co@bJ8
oe<cSOnHIiSo001FobTEPolg7hOo?B^BoaLBR_l507co7`n1olB?WOl003;o60Qloc@MQ_mcCIKo9QN7
o`00GOl007Go60Uno`00K?mC=I3o001Lo`00MOl005go8A64o`h5O_o]/i;o2`5ko`00L?ln053o001J
o`00C`02ofa:U`0=o`40Nol007Ko001Yo`00D_l005Go0015o`00;_mYC9go0000ofU<WOoNWi3ooLET
oo>dQP02ojZnj1_oZKgX00?oooooo`000?ooool02_ooool000;ooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool09_oo
ool3o`0000Gooooo00Co000Do`00=ol004_o001F0_l006402_l006Co3P1[oa<0LOlR1G?o1`1_ob04
L_lD0GKo9@Mco`00E_l206<2ob/@N`07ojb5Zol002go2`9loo_BVooldIOofZfYookKUP02omV^[@0:
ooOFZ?oej[[ogKNbomfg/_oRa[_oj<BaokV]cOoJe=?oa/;Fon3Ld@;o][7D00koclGAomW3a?oD^/7o
hm;6oa1jhondeO7od[c4omoBc?o5Yk_o04W9oiBHe?o@o>;o]Yjoongh_`;oVgjc00OoMXKFomo@bOoO
d<WoLFFfooW[ZolE8Ico/Y>g00;oL5JT0_mbEJ802Oo>^lSo00jIom6V[?l0003oFS^Ao`00;omT@I;o
n<:?ofe7T`02ookBS`07o`00MoolfGWoo=UiodD]SooodXSo001koogCT`03omN_[`;oYh6/00?o000U
oe5A/omADK<00_maIkP2oh^4aP;oN8_I00CoZJ_Iok?bm?ndeo;oU9;>0_o6^m02og5ca@0>om74cOm/
J;co?f_Fo`000?m@B:Wo01BIob/XV_oflJgoJF:ho`00M?lA0g[o000Cob4JS_lT58D2ofE1T@0Mo`00
G?m39XSoV6NHo`X0IOlM3X7o:AF3oi]/V_lm:i;o5a::o`D0O?mbC9Go7`n1o`00<_lH27co=1f6og==
U_lV5hOo2@=no`@0FolH2Gko001/ooC4D?l005co001eo`40N?lQ4HCoM56KonfcT_l02Hd00_l00700
4_l005[o001?o`00KOm/BYOo0@1ko`00M_l006Wo001To`00EOl003ko001GobPKRomYC9go0000okN8
XoomaFColkB6ojZnj1goZKgX0_l0000:ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02?ooooo0ol00008ooooo`04o`005?l003Oo001;o`00EP;o001Q00Co001To`h0JolC077o8PEc0_l7
06l2oa@1MP05o`00E_l206?o:a1kob/@NooR^jl00_oIYj801OoldIOofZfYomZ]ZOonfiKofJj]00;o
mmJX00[ogkVao`00SooM]k;oh/JkonS4/OoP_kKoi<2bolK2e_o2]Lko][7D0_o?aM42omBj`@04on?B
a_o6YKSoTiWGol?jj@;oaJNk00ColNo2oi>`j_nC/>[oF6_;0onKO[<02Oo`kYGoGe^foiUo]_oijj_o
F7CCoaDQW?ncfg7oL5JTo`000002og9EXP08o`000?oAYZcodJJ/o`00=OmJ>i7ofjZSofA1T_oh`Xl3
ofe7T`05oocINOn5F9Goo=UiogE>U_mYAI<00_omdi<02OmL?I?oejn_o`006Ola04_oYh6/odDlX_mA
DK?oHejgog5W^002od]I_`04oh^4a_njlZCoN8_IokjgdP;oXYW<0_nDT/h01?o6^m3oLM7nojGMnooC
f]d2ofaX_00Zoo7f]_m@B:WoD4RYon[hb?mBX?GoAF7:o`00M?lA0g[o@CbTob4JS_lT58GoID6AonKJ
bOl005co@bJ8oiQWV?l:07[o7@j1obTEPonKK9[o?B^BoaLBR_l507coLTbEoal?POl003;o60Qloc@M
Q_l007So9QN7o`T3O_l007Ko60Uno`00K?oda53o4@R0o`h0F?l107So8A64ogAAVol`@kGo00V=0_l0
07004_l007Co001?o`00KOona7Oo0006o`00M_l006Wo001To`00EOl003ko001Go`00G?mYC9go0000
okN8XoomaFColkB6ojZnj1goZKgX00?oooooo`000?ooool02Oooool00005ooooool0003ooooooooo
ool000002_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`;o00008oooool2
o`0000_ooooo00Co000Do`00=ol004_o001F0_l006401?l006Co3P1[oa<0LOl007d2o`L0K`0<oa@1
M_l004[o001Fo`80Hol[47_o[8F[on:k[onh_=gonm:KomoZPoo6Vj_oo]^F0_oI[Zd01OogeZSogkVa
omni/OoYak;oM@0000;oj<Ba00?oh;nfonC0/_o2]Lh00_o2]Lh01?o?aM7odm7Gom?AeooSd/H2olJU
^006ooCV^_m@JlooD6_?olFW^ooakl;o[Hbb0_n5Nl401_oQmMWoVgjcoo3^UOo`kYGoGe^fo`0000;o
VGnf0_o3Vjh03om`EZCo_ijgo`000?mbEJ;o0000oblUTooAYZcofjZSoeXkTOoKZZ?oI46BooS2Sol=
07KoKDNCo`P0E002ohEHU@;oMDjF0_mYAI<01?oocXKo000koe`mTol001T2omCEG0;oACbR00GoX/YH
of=N]ooQmYooBeVoolnka`02ogmnb004okjgd_nRVLcoU]Snok2ni0;o[K3J00CoU9KColO8fom[LLOo
K6Rl0_o[l/`0<om@B:Woj_S8ofYI[?n:iJkoAF7:odi4YOl001Go@CbTomC3bOlT58GoID6AonKJbOl0
06[o@bJ8oiQWV?l:07[o7@j1obTEPonKK9[o?B^BoaLBR_lg7hKoLTbEom[II?l003;o60Qloc@MQ_l0
07So9QN7o`T3O_l007KoJ155oaP9O_oda53o4@R0o`00NOl107So001MogAAVol`@kGo00V=o`X1Nol0
073o001doaL=Pol=17koo/Ago`001_l007Ko001Yo`00I002o`00E@07o`00Eol005co001;okN8Xol0
003o/H6Qoo>dQP0OojVmj003o`000?oooooooooo00Sooooo00001Ooooooo0000oooooooooooo0000
00[ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000027ooooo0ol0000=
ooooo`04o`005?l003Oo001;o`00EP;o001Q00_o001To`00L_lC077o4`1ao`L0Koold6co000ionc8
[oondi3oh/E5ob/@N`02oog;R@;oM66^0_o6Vj/01Oogg:koj;bWomV^[Oo^`ZGogkVa00;ojLNb00Wo
hknco`0j_ooP_kKoh;nfonC0/_oT`K?o`[G>om_IeOnbW<400_nf[<l3olJU^004ooCV^_ncSk7oD6_?
om?gi0;o[Hbb00Com>nJohEk`On5Nl7oVgjc0omkKKP00olN99_oVGnfobP09P02ol>K[P0Aog1FY?no
W[Oo0000og9EX_o;X:co;bFColVGXom=<8goFS^Aom^ZXomT@I;on<:?o`d0M_m]Ai?ooLi[ohEHUOl?
07L00_meCYH03?l006WoJDFCooo>Q_l003_oh;J/o`09TooDeEcogm39odDlX_o?]L7o74Bnok2B]`;o
IXOO00Cock_7ogmnb?nZbo7oc^_Y0_nGT</2ok2ni009ojf`f_nJWmSoalSKolO8fom[LLOo/oW5oc:Q
l_nflo?od/cC00;oJUV/00oo03JlooO^/Om>A:GoCTBUomC3bOl003SoID6Aob4QUol006[o@bJ8oiQW
V?l:07[o7@j1obTEPonKK9X00_lm:i808olg7hKoLTbEom[II?l003;o3P0`o`00P?l007So9QN7o`T3
O_l007Ko001eoaP9O_oda53o4@R0o`00NOnY<R;o001Mo`00K?l`@kGo00V=o`00N?l0073o0017oaL=
Pol=17koo/Ago`l8POl05JCo001bo`00L?l005;o001Eo`00H?l006Wo:1^;00;o]hRS00?o0000oo>d
Q_nY_NP07?nY_NP2ooooo`03o`000?oooooooooo00Sooooo00001Ooooooo0000oooooooooooo0000
00_ooooo00?o0000ooooool000000ol00004ooooo`03o`000?oooooooooo01cooooo0ol0000Aoooo
o`03o`00=ol004So001F00;o001Q00_o001To`00L_lC077o4`1ao`00OOog_Xgo000ionc8[oondi3o
jleDob/@N`02oog;R@0:ogAQ[_oOjX?oaY^[olJKZoogg:koj;bWonJn[?o^`ZGoi[ZXonW7/P;ohknc
00?og[Rbo`1?aooT`;800_oT`K<02?oO_;Go/Yc1ok:L`Oo_hL;o]Zc?on;Ue?o6YKSom>Jj0_ncSk42
og1_`@05om?gi?n]S;;om>nJohEk`OmJC:P00_n/WLT00omkKKSoj/>]oahTV`02ooSP[`;o`i^^00?o
GdJLoknN]oo;X:`00_o;X:`2olVGX`0Fo`000?m=<8gofjZSofA1T_oh`Xoo3@1fofe7ToomcV_oQERE
ook>K_l205Gooleao`00JOmYAI?oolj6o`00>ooP]ZcoKe:Oomo@bOm[DZCockG1ob`cY`;o/9:g0omo
Q]02oge_^@;oc^_Y00CoUi3;oj2KconPVlooVYoH0_nMlnT00oll/?CoYYo>ojJOcP02oi>1_00hobI8
_ooBc=?oJUV/ok3GJol0=[coCTBUoe55YOo5hWOoEDRVob@DQOnD]>go001Zod<VR?nHIiSo2P1joad>
POmG>97o:AF3o`00M_lm:i;o=an6og9<UOoJfFCo7@]mo`h0<?l0083o=1f6obHGQol90gko001fo`00
MOlH2Gkom<A@oa48P?l007Wo001eo`00GOl006co<4>eo`09SOl007So001`o`00KolG3H?o3@Anook4
Mol?287o0@1ko`00L_l006Wo001Bo`00J?l0063o001YobPKRongR:<2ok61X@03o`000?nY_NSoZKgX
01OoZKgX1_ooool00ol0003oooooooooo`08ooooo`0000Goooooo`000?ooooooooooo`000007oooo
o`07o`000?ooooooooooooooool0003oooooo`000007ooooo`;o00006_ooool3o`0001Cooooo00Oo
000go`00B?l005Ko001Oo`00HOl006Co001b00;o4`1a00goo=1/ooNnSOm8=9OoB3BGoooBNOoocgco
j[6Eoog;ROo`^9GoM66^ooBoU?o6Vj_ommb^00;oj;bW0_o^`ZD00ooV^ZSojKbVon>o/`02omjh/P06
onS5/_oT`;;oi<6conC1/ooO_;Goh[^`0_o_hL800on]TKSo002BohbLgP03ok>?/@04oo_TYOm`Kl7o
Wi_@ooC_VP;oTW^f00ooklZ/oeY<Z?okj:KoNffhon[3[OlN99_oS6ZVohmXX_o3Vjkon>nYoem6W?on
f9;o=RF?ol^P[?omdI400_o9Uj<00ol0003oCC2=oe`gR`02ooS2S`0<o`d0M_m]Ai?ooLi[ohEHUOon
cVko0P1Eooo=LOl006WoJDFCooo>Q_lb9Y?oh;J/0_m_DYl2of]BY006o`000?l/<jOo/9:goee@Zomo
Q]3ohObg0_mmKkT2ogmj``;ob=CS00CoX9_?ogGRh_nPULWoX9G90_nXVLH2ojJOcP04oi>1_?oDo[oo
9TRook3GJ`;oNfB]00OoPH[Coe55YOmAAJGoEDRVob@DQOnD]>go9RbQ00;o@bJ802Wo2P1joad>POmG
>97o:AF3ocPQROlm:i;o=an6o`D0O?oJfFCo7@]mo`h0<?l0083o=1f6ob0?POlV5hOo:AN6odlfTolH
2Gko9QJ6oa48P?l007Wo001eo`00GOlQ4HCo7@f0oa<6OOl007So001`o`00Kol005[oQ66Rook4Mol?
287o0@1ko`00L_l006Wo001To`00J?l004Go001fobPKR`03ok61X@03o`000?nY_NSoZKgX01;oZKgX
3?ooool00ol0003oooooooooo`07ooooo`000_ooool2o`0000Sooooo1Ol000000ooooooo0000o`00
0003o`0000?ooooo00?o0000ooooooooool05_ooool3o`0001Oooooo00Ko000fo`00B?l005Ko001K
o`00HOl006@2o`00LP06ook?Loold6comkj=o`00AOm8=9Ooom9i0_oZ/ID02OombhWol;REooBoU?oa
^YKoaY^[ooOL[_oX_:Ooi[j/onk2Y@02onJjZ004onVlY_oZ_JKog[RbonS5/P;odZR/00Goi<6comnl
]OoR^k3oh[^`onO>_@02ojfA^005ong9/?l009;oelkAok>?/Ooki:D00_n]T;P00omDC:_oWi_@oi9k
]P02ono:[0;onnRV00Co5b2Ko`000?n<JZKoS6ZV0on?J:800omOAYcoo]RBocHUS`02oogAT@;obINS
0_l00002oe`gR`0DooS2Sol=07KoKDNCoog>Jon5F9Goo/i^o`l0MooocG7o001Yooo>Q_l002Co0000
ombaZom_DYoodJjfo`000?m[DZCo<T:cob`cYoohjZl2oee@Z`06oo?Y__mmKkWojOK<onWfc?moN/?o
[OW<0_nST/<2ojNNc0;oX9G900OoZ9W6okoIk?maQMOoZ_6_obj9k?nOQ[Wo]:O;00?oNfB]00KokMc2
oe55YOmAAJGo91B5oemBZonD]>d2od<VR008o`X0N_lM3X7oEcRAobTEPolh8HWo?B^BocLOQ_l507`2
oad;O@0No`h0<?l0083o000Gob0?POlV5hOo:AN6odlfToo1TJGo9QJ6oa48P?lS4X?o001eo`40N?oj
aXoo7@f0oa<6OOl;0G_o001`oaP;POl005[oQ66RomVa:?l?287o0@1ko`00L_l006Wo001To`00J?l0
05Ko001f0_lX6h/2ok61X@03onVXR_l0003oZKgX00ooZKgX3oooool00ol0003oooooooooo`07oooo
o`006_ooool00ol0003oooooooooo`0Cooooo`?o00006_ooool00ol003Ko0018o`00EP03o`00H@09
o`00L_omcVgol<YDooc@K?og_Xgo0015onk>F?oodWWoj[6E00;ooL^90_od_i@2onniV005onfgV?oX
_:Ooi[j/onk2YOoV^ZP00_oY_:H01ooZ_JKohkJXonS5/_oBZ:col/fZolRJYooO_;D00_oR^k001ooW
c[god:J]ojfA^?o]bK3ocK:ool^KY_ncSk400_n]T;P01OoS]jWoE4b[ooKN/onBNkKoklZ/00?oW7RZ
00Co@7cSojj2YOl0003oS6ZV0_n?J:801?oag6ooo]RBookHT_lf9Hl2oogAT@04olVGXoo^_9ko0000
oim`W@;oG3N;00_on<:?o`d0M_omcV_ooLi[ohEHUOoncVko3`1gooo=LOoocXKo]HJSo`0;S@02omba
Z`05ofmBWooA[[Ko0000okJ?[Olb@[<00_ndV[h01OmMD:_olnVnoo?Y__mBGKoodN[W00;oVX:h0_nX
Ym@02OnST/?oXJ[Moj6ZgOnQZ]goXKGWoi7`h_lh[_;oZI>ooiV;``03oin6^@07okBWbomkI:goNfB]
ohBCf_mAAJGo`n=job@DQ@02oemBZ`0:ocPZU?m39XSoWhNjo`00K?mG>97o7@j1ocPQROlm:i;o5a::
o`D0O0;o7@]m02Go3P0`oaP8O?l001Oo>B>:obHGQolY5hKoCcJCol6AYOlS4H;o9QJ6ob<BPold88[o
0@1hoo[6SolM3H3o4`Imo`/1Nol0073o60^1o`00F_n4HJ;ofK4Xo`l8POl107_o001fo`00JOl006Co
001Eo`00?_l005Oo001YobPKRonaPJ7olkB6onVXR_nY_NSo000000coZKgX4_ooool00ol0003ooooo
ooooo`07ooooo`006Oooool2o`0001;ooooo0ol0000Mooooo`03o`00=_l004So001F00?o001Q00Wo
001boog>KOo]be?oo=1/ooo;Poondi3oDcfJomJa]OoZ/ID00_ombhT2ooBoU004onniV?o]]iSokKNH
on^dV0;ok/:U00Goi[ZXonVlY_oZ_JKoj[fVon>fZ002om:X[005oo;=Z_o8VZOom<NOon:k/?oWc[d0
0_o@YZd2ong9/007olfb_oo;VjKoTH?1oi63`On]T;SohkNYoeA<Z`02ooKN/`04o`0>UOnLN:[oW7RZ
oiahZP;o[X:U01Co0000olcDFoo<e5_oSfRRoo7LKom9=iWoln5joogATOm?=YCoF3J>olVGXoo^_9ko
:`1Foim`WOl0003oG3N;o`00<oomcV_o]WbDoog>J`;oo/i^00Co3`1gojalWol002Wo]HJS0ooL/J/0
1?m_DYoo3QZHokJ?[OnfSjd3okBJ_P;oP7S10_n1Ij`2olcHhP06oiZ2^?n8R/ooR8[?ohR:coo1j?7o
XJ[M0_nSTL800onMRl7oZI>oojVC_`02oiV;``0Eoin6^Oo4o;ko6Tc6og]T[OndW/;oOVBZohBCf_oG
^[goH4jVoemBZonlW;Oo>2ZDod<VR?nOQk[o2P1joeLhTOmhF:7o>269ocd[T_lG4X[oOUnT00;o7@]m
00Oo5PIkoaP8O?l001Oo>B>:obHGQolY5hKoCcJC00;o=R2901;o9QJ6ob<BPold88[oKe2Moo[6SolM
3H3o4`Imo`/1Nol:0G_o60^1o`00M?lG3H?ofK4Xo`l8POl@1Ggo001fo`00L_l00702o`00E@08o`00
Eol006WoYXjlok61XOnVS[cojJR:ojVmj?l00009ojVmj1Gooooo00?o0000ooooooooool01oooool0
01Wooooo00?o0000ooooooooool03oooool2o`00023ooooo00Co000fo`00B?l005Ko001Q0_l07Z/0
3ookcfWok<U@ooc@K?og_Xgool^3ooNoSOmC?I[ojleDonZaUOombhWol;REooBoU?oa^YKokkVHonfg
V002on^dV005onVbV?oV[YSoi[ZXonVlY_oZ_JH00_oS]ZP01_oY^jGodZR/olRJYoo8VZOom<NOolnO
YP?od:J]0_n^RJh2ol^KYP07oo_VU?o4]/co[I2hon>gZOnWgh7oY7fYohJYk002ok23Y0;oW7RZ00_o
[X:UonoOLoo_gg?oc=AKomSQLOn?J:;oKeJUodTgVOn=HY_oln5jooc>U002oePfSP08onjlW_l[05Ko
Wg2Moim[UOmL=h_o000cofe3S_nfO9@2og56S`0@of<mSOoocG7o[7bOo`00MoneQZ?o>2J?ombaZooo
fXSoDC^IolS:Bol000ko]Xn]oc0`X?ndV[koETVWoh1h`@;olo:g00OoPFN/oeATa_mDI<KoVX:hoaUn
i_n8R/ooWI3500?oYXnm00OoXi72oif;`OnMRl7oZI>ookSJlOmgT=ko000000;oVWjc0_ndW/82ogiT
ZP;oekZm0_nlW;L02_l006[o@bJ8ocTeXOl:07[o7@j1ogQHXOlh8HWo001foaLBR_mnGj@2oad;O@0K
o`00<_lH27co?RB9ocTSR_lV5hOo2@=no`00M_lT4h?o=R29obHFQ_lS4X?o=22:ofm@WOlX5H?oLWK7
oc13]Ol02Hgo2P5koaP;POm6<9;o5`f3omVa:?l?287o40Emo`00M_l007;o001`00;o001E00Ko001P
o`00JOl@2XCo:1^;oiYZV_oYZ8X2ojVmj003o`000?nY_NSoZKgX00?oZKgX6?ooool00ol0003ooooo
ooooo`07ooooo`006Oooool00ol0003oooooooooo`0<ooooo`?o00008_ooool05_l003Ko0018o`00
IOl0067o001OooS@I?okcfWok<U@ooc@K?og_XgooM9`ooNoSOoodWWoolmlonZaUOombhWol;REooBo
U?oa^YKokkVHonfgV?o[]9P2onVbV005onJ^V?o[/iOojKbVonZmY_oS]ZP00_oY^jD01ooW_Zcob9ZW
olRJYoodaioocinVomfWW_o@YZd00on^RJh2ol^KYP04oo_VU?ncQjKoTfjVon>gZ@;oY7fY0_n`Pj@0
3Oonfi;oW7RZo`000?n^PZGoGE>^ofH00?oHhG7oXgNQofmFYOoGhW?oSF:KooBnU?ochGX00_olcY@0
2OmH=XkohZJDolbBV?o<TYSoWf^Eoe`gRol003?oKD>>okIlU002og56S`03o`00>OmS?HgonlZB00;o
nL^I00So>2J?oooJR?oofXSob<Y;ohIVY_l>6YSon^6[oc0`X0;oh[b`00OoETVWonoWa?l029?oPFN/
o`1V[_mDI<KofOkF00?oXhNe00?oWI35ojJ?_OnkjO@00_nR[n401?nS^n[o0000ojF<^_nUS;X2oij:
_P;oVWjc00co]9k2ogiTZ_mnI:[oi_bkof/00?mPCZKo_9bgogeSZ_nFL:Ko>CFQokNG]olM3X42ogQH
X@03o`00M_lG4X[o0P1h00;o7@]m01Ko000boaP8O?ln98Wo>B>:ob0?POl90gko001fob@CPolf88Wo
9QJ6oa48P?ld88[o001eobPEPombM/Oo<4>eo`09SOl:0G_o001`odH`T_lG3H?o7a>70_l?28400ol9
07_o001bo`00L002o`00E@03o`00H?l007Ko40Z400;oVVZJ00GojJR:ojVmj?nY_NSoZKgXo`00000L
ooooo`03o`000?oooooooooo00Oooooo000Iooooo`;o00002_ooool3o`0002Gooooo00?o000fo`00
B?l005000_l006404_oodGWomliPook?Loold6comkj=ooSAI_og_hgom;bAooo?O?oZ/IGooL^9oo2h
UOod_iColKZFonniV?o]]iSojkBHonVbV0;oiZjH00Cojk>Gom^QV?oZ_JKohkJX0_oY^jD01ooW_Zco
fZZUooC7WoodaioocinVomfWW_mdHJl00on^RJh01?o;VjKonnJDok>7Y_ncQjH2oi=^YP;oY7fY0_n`
Pj@01Oonfi;oLen]ojj0Xon^PZGoGE>^00?oXgNQ00GoKeJUomORLon=HY_om;jDofI0T002ooc>U00D
oePfS_oRYYCoc9:HolbBV?nOJiGoG3N;oim[UOm]@hko]WbDo`00?_maAXook[:@of<mSOokbY;oBcBD
omO;C?oofXSoCc^JogeJW_o8bT/3ohIVYP?oh[b`00CoETVWonoWa?nUV<SoYIS80on@LJ`00on_Zm?o
XhNeoj>7]@02ohjEeP;o^nWd00CoXZoQoj:=__nMR;coWHRl0_nUS;X01onNR[koVWjcomkVfOlcD/Co
OVBZonKl^omlHj/00oo4Wk@04_mmHj[oUW2VoiI`Y_ngUkOo7@j1ogQHXOnQP[;o001foaX:O_l207So
7@]mom[II?lM2ggo60QlochTROli8h[o80n1o`T3OP;o?BB900Go=R29obHFQ_lA283o001io`00M@02
obPEP`0Aoad=P?lC1Wgo2P5ko`00L?m6<9;od9nUob8AP_lH2Woo3`R1o`40Nol007;o001`o`00I?l0
06So001Ro`00M_lo:8d00onJJYX01OnY_NSooooooooooooooooo000001_ooooo00?o0000oooooooo
ool01oooool001Wooooo00?o0000ooooooooool01_ooool3o`0002Sooooo00co000fo`00B?l006So
001Qo`00IOoodGWoo/Z3ook?Loold6comkj=ooSAI_og_hd2ooo?O004onZaUOombhWom;nDooBoU0;o
kkVH00?okKNHon^dV?oY/YP00_oV[YP01_o[/iOofj6HokZC[ooS]ZSojK^UonNn[0;ofZZU00Wom<NO
olnOY_oMYikogJNNoo_AVoo^c[?o[XV^onO`U?o;VjH00_ncQjH2onJcX008oi=^Y_lm`L?oY7fYooO[
U?n`PjCoo]^Bolc`jon^P:<2oiUZV`;oXgNQ00Gom/NKohiPV?oGhW?oSF:KooBnU002ofI0T003ooc>
U?mH=XkohZJD00;oc9:H00goWf^Eoe`gRonOJiGoKD>>okIlU?l003ko000ionjbT?mS?HgokleGod/d
U?mlE9Woel]<00;oo>6800SoOEZNo`000?n6IZKoQVJVo`003OoR_;3on>B_oea=Y`;oJeJX00[oYIS8
onWRbon@LJcoT76/oeM_d?nSQkGo_og8o`1O/On>UMKoWhk10_nRR;T2oj:=_P03oif8_?nUS;[o][?F
00;oO7k:0_oNi]T01?lcD/CobK32olV``_mlHj/2olBO]003ogeSZ_nFL:KoUW2V00;o]iNg0_nQP[80
2olh8HWo?B^Bo`80N?lM2ggof]UToad;OOli7hKo?RB9oa`>P_lP3h7o812200;o?BB901Wo=R29ob<A
P_lA283o001ioc4KQOmfI;7o:1F3oad=P?lC1Wgo001ho`00L?l006oo^:0?ob8AP_lH2Woo3`R1o`40
Nol007;o001Yo`00I?l006So001Fo`00M_lo:8go40Z400;oVVZJ1?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00Kooooo000Iooooo`03o`000?oooooooooo00?ooooo0ol0000[oooo
o`0=o`00=_l004So001Xo`00IOohd6ConlmYoog>KOoncg?oo=1/ooNnSOohdFKomkn=ooo?O002onZa
U@04oo2hUOod_iColKZFonniV0;okKNH00[ojkBHonVbV?oV[YSoiZjHon^cUooKXISolKVBonJiYooY
^jGoikj/0_oJZZD02OojjZCocinVomfWW_oMYikonm6KokVH]On^RJko`XjNol^KYP02ok>7YP;oi[>P
0_o[^j801?ogjiCo^8NQookKT_l00002ojj0X`;oVFZK00Kod9FGoj=gXOofai_oSV2HomZOU_n=HY/2
ooBnU004ofI0T?oIWICoF3J>on:VU0;oc9:H00co0016oim[UOnOJiGoKD>>okIlU?l003koaHbHonjb
T?mS?HgokleGod/dU?mlE9T2ogUOZ@08oocQR?l0003oUfjRohIVY_nGKZ;o7Sfgoiik[?l0=k82onO2
/0;oJeJX00CoSP`0oi1a[?nRWM3oEfo@0_n`X<L2oiio/@;oWhk100?oXXRioj6Gb_nQUlX00_nOVll2
okJceP04oganb_nfYl_o]ZO;ohmi]`;oM6>a00CoO6>[ohnBd_n?T];oOF>Z0_nFL:H02?oYn/;o]iNg
oea4W?nQP[;oRfNTocd[T_m:;hooOUnT0_lM2gd01Oli7hKo0020oa`>P_lP3h7o9QN700;o?BB901Wo
=R29ob<AP_lA283o8a:3oc4KQOmfI;7o:1F3oad=P?lC1Wgo2`5ko`00L?lH2h7o^:0?ob8AP_lO4hOo
3`R1o`40Nol607_o001bo`00L?l006So001Fo`00M_l006Wo40Z400;oVVZJ1Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Kooooo000Hooooo`?o000000Coooooo`000?l0003o0000
;_ooool05?l003Ko0010o`00J?l006Gon=1Too_?JOomcVgokL]Cooc@K?oobh?omkn=ooBlTOoocgco
j[6Eoog;ROog`93okKFEooFnTOo]]9GokKNH0_o[]9P00ooY/YSoiZjHon^cU`02om^QV004oo6iT_o?
WjGocinUonNn[0;ofZZU00Kon^ZTolnOY_oMYikogJNNoo_AVoo4Sih2ol:>WP03oo2kVOn/Ul3o/hNV
00;oi[>P00Kojk^Roo;C/OnhQj7o^8NQohENW?nmQ9L2ojj0X`;oVFZK00Kod9FGoj=gXOofai_oSV2H
omZOU_n=HY/2ooBnU007ofI0T?oIWICohZJDon:VU?l006_oc9:Ho`00AP02oim[U@07ofe3S_nfO9Co
000nolF<V?o_/hookleGooo>N002ogaDV@07o`001_miGjWobM9HogmSZ?nGKZ;oQVJVoiM^XP02oiik
[0;o<EG700Koil:`of]FZ?o_n;CoLe^Woj:Md?oE^l02ohi^Z@;o/:3700?oWWnaohn6aOn?Q/D00_nk
_=X00onQUl[oWi_?ojVQcP02ojJKbP04oj6BaOn6K:koQVb^ohmi]`;oM6>a0_nYR;800on?T];oGUF_
oiI`YP02ogQFW@09ogmV[?mLA9coXH:boh]WY?n5G9_oW76PogiOY?m[BYSo9Q>200;o>An600Wo70j2
ob0?POlV5hOo6a25ocdTROlT4h?o8a62ob4@P_l004400_la6hD04olX5H?o7@f0oa<6OOl;0G_o2P5k
oaP;POnhX0oo;Qf;oalCQol?287o0@1ko`H0Nol007;o001`o`00J?l0073o001fo`00JOlo:8d00_nJ
JYX6ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool0013ooooo0ol00005
ooooo`Co0000<Oooool05Ol005;o001Oo`00J?oKb4Son=1Too_?JOomcVgokL]CooNnSOo_]YComkn=
ooBlTOoocgcok;>Foog;ROog`93okKFEooFnTOo]]9Gok[JDon^dV002onVbV007onJ^V?o[/iOofj6H
om^QV?oa^I;odiVGolnOY@02omZZY@05oo[ZY?nnTJOogJNNomfWW_okdI/00_o4Sih01?o2SYkol;^I
oo2kVOoKYj03onJcX008on^kX_obdk7o^8NQokR7XOn5GYco_HBGo`000?n^P:<2oiUZV`05om2EUoof
ai_om/NKohiPV?oJWiH00ood_Y@01omV@93ofIfDon:VU?oRYYCo001[olbBV?o1QI@00_nOJiD02Om]
@hko]WbDolF<V?o5S9Sokk>?ono=EooocWSoO5BIogU@U002oi5XW`03ohV0`ooliJCoo>FT00;oUfjR
0_nNNj`00om4D[_ok=:joncB^P02oea?ZP;oLe^W0_oE^l001_n>KZWoI73:ofA`b_nNOk7ohN_Hohn6
a@;o/ZcB00?oWHc2ojVQc_nKNjl00_nHNJl00onVQK7oQVb^ohI/[P02ok6>/P;oM6>a00CoZHRboh]U
XOn?T];oGUF_0_mhEYd01?nOLj3oPV:Toh9RY?n;Ij@2ohELV`03oiaaX?m8<YCo9Q>200;o>An600Oo
70j2ocTSR_lk8HOo?bB8ocdTROlT4h?o8a6200;o8A2201GoIDZMoc4KQOlX5H?o7@f0oa<6OOl;0G_o
2P5koaP;POnhX0oo:aN4oalCQol?287o40Emo`00M_l007;o001`o`00J?l0073o001Go`00M_lo:8d0
0_nJJYX7ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool0017ooooo00?o
0000ooooooooool01?ooool2o`0003?ooooo01?o0011o`00Gol006Solm1Oong1Y?okcfWoo/mcooc@
K?og_Xgon=5VooNoSOod_97oolmlonbcU_og`Y7oml2@onfeUOoe_Y7okKBE00;ok[JD00CojK:HonJ^
V?oV[YSojk>G0_oKXIP01Ooa^I;odiVGom:LW?o/]ISofZZU00;o_Y6W0_oMYih01?okdI_oa8nNolB?
W_o2SYh2oo2kV@05om^WX?oV/j3oi[>PonJcX?n8Q/X00_nhQj401?o>UI[oQEjLokf4Uol00002onBa
X005oiUZVoo@UIOo4`ImooK7Von>H9P00_oJWiH2ooBnU009ofI0T?oIWICohZJDon:VU?l006_oc9:H
ol65U?nOJiGo`HFD00;o]WbD0_o5S9P01Oo_/hookleGooo>N?mlE9WoNE2D00;oTFRO00_o000YohV0
`ooliJCoUfjRogmY/?l0003oWW^/odAB^onJMZWoEXKToea?ZP02oljS[006og=KYooVg/coeK_0ohi^
ZOoclkSoI73:0_o3//T01?n@N;GoTG>^oi5c[_nWQ[42oi]k[`;oV7V_0_nVQK400on6K:ko/Hjbok6>
/P02ogAS/@04ojV8/_n;IJ7oZX2WojZ0Y`;oN5JM00CoWg>Poh9RY?n2HZCoI4JI0_n5G9/08onLLJ3o
B3:DobHCP_lg88So>An6ochTROli8h[o>b67oclTR?lm98Wo91>3ob<AP_lV5XKo=an6ofE:WOla6hGo
:1F3ob`LR_l^7Xco>RZBofUCY_lH2h7o>BF<ob/GQ?lR4H;o60Yooa05OOl007Ko001bo`00L?l006So
001`o`00H_l007Ko?bR=00;oVVZJ1oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Kooooo000Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool04ol0047o
001Oo`00Ioooe7ooom5iook:Pooncg?oo=1/ooS3T?ohdFKomkn=ooBlTOoleWCok;>FooO2TOog`93o
kKFEooFnTOo]]9D00_o^]Y@01OoW[IKoiZjHonJ^V?o[/iOofj6H00;olKVB00CodiVGom:LW?o/]ISo
bHnH0_nnTJL00ooRjXCogJNNoo_AV`02olB?WP08ol:>W_o`^iWofjNPom^WX?o8T9Woi[>PokR1V?o5
Yk`2okR7X@04oljEV_n5GYco_HBGokf4U`;oi;6P00GoVFZKom2EUolC1Wgom/NKohiPV002omZOUP04
ol66UOod_YCofIfDomVMU0;ohZJD00gobHjDolbBV?o1QICoWf^Eol65U?nfO9CoeINConncSoo5S9So
kk>?oehjS_oocWSoO5BI00;on]=[00KoTFROoiI/XOn9P<?oBe[0oiM^X_oN][02oiI]X@;oVWJY00Oo
EXKToljS[?o>XjcocZ>/og=KYooVg/coN62[00;o`ind00CoP6F[ohI_/_n6Kk;oT7Re0_nALjh2ojN6
/@;oVg^_00GoV7V_ojJ5/OnVQK7oQVb^oiml[002oiUh[@04oiYdYonPO:_oX7b[oh]UX@;oZX2W00Oo
N5JMoimcX?nOLj3oPV:TofA6VOn;IjCoQEbK00;oW76P00_oKdbHocLPR?mC<hgoDc>=ofe9U_lk8HOo
?bB8oa/@QOlT4h?o=R29ob<APP02ocLOQP0Coc4KQOlX5H?o;1b:obhNS?lj:Y;oJE>Vod4YSOlb78Ko
:aN4ob8AP_lH2Woo40Emo`T0Nol007;o001`o`00N?l005Go001Ro`00MP02oclXS@03om>IV?oooooo
oooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`004Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo00co0011o`00GooJb/WoomAooooANOon
bX?oo/mcooc@K?oh`i3on=5VooNoSOoocg`2onbcUP03ooO0T?o]]IGomKjA00;okKBE0_o^]Y@01_oW
[IKoiZjHonJ^V?o[/iOofj6Hoo6iTP;odiVG00OodYbLonbeV?o9SiSobHnHokjAYon]Oj;onm6K00;o
a8nN00Cok[ZJol:>W_o`^iWofjNP0_o8T9T2okR1V005ogaBU_o5Ykco^8NQoljEV_n5GY`00_nmQ9L2
onBaX004oiUZVoo@UIOo]gjFokMnUP?ofYnF0_o1QYD2omVMU009ol66UOoRYYCobHjDolV>U?o1QICo
Wf^Eol65U?nfO9CoeINC00?okk>?00?oGSZ>ooo>N?miD9@00_ojdf/01Ol002WoUVbQoiI/XOnFK:7o
Be[000;og[J`00[oUVfQoiYfZOnJMZWoOefQoh]TX?o>Xjco[9:konKNc?n[OjCoN62[0_o3Wk@00on0
IJ_oQVnbohI_/P02okJA/0;oTG>^00GoYhJaoi]k[onKNjooV7V_oiel[P02oi]j[P04oiml[?nIN:go
VGR]oiYdY`;oX7b[00?oRfFQojZ0YonZP:L00_mhEYd01OnOLj3oPV:TofA6VOmTAYWoQEbK00;o=V7@
00_oLDnKocLPR?mC<hgoDc>=ofe9U_lk8HOo001noa/@QOlT4h?o=R29oe8cSP02ocLOQP0>oc4KQOlX
5H?o;1b:obhNS?lC1Wgo2`5kod4YSOlb78Ko:aN4ob8AP_lH2Woo40Emo`T0Nol607/2o`00L003o`00
EOl005Ko001f00;o?bR=00?odiVHooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Kooooo000Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_oo
ool04_l0047o001Bom[:bOooe7ooom5ioog>KOoncg?oo=1/onnfU?ohdFKom;bAooo?O?o//iKoml:A
ooO0T?o]]IGomKjAonfdU@?ok[JD00KoijfFonjeToo[/iOojk>Gom^QV?oa^I82om>IU`;ok;FH00Go
bHnHombPU?oRjXCogJJMojbI``02olB?WP04onjjV_o`^iWol;^Iom^WX0;ob92I00Ko^86HolnCU?o?
TiCoaJNlokR7XOo>UIX3okf4U`;oi;6P0_o@UIL2okMnUP?ofYnF0_o1QYD2omVMU004ol66UOoRYYCo
bHjDolV>U0?o`HFD00?o]WbDomFGToo_/hl00_o_/hl00ooocWSoeIZFogU@U002oo[CJ`0<ogiEUonF
K:7oUVbQoiI/XOn?I9coEI;]omjf/?nFKJ7oin=goiYfZOmoGJ7oRfBP0_n/T[/2oj]oY003ogQPZoo3
WkCo`ind00;o^I6]0_n6Kk801OnfTK3oTG>^oi5c[_nWQ[7oVWZ^00;oWGZ/00CoWGb^oi]j[_nKNZko
Wgb/0_n9IZ@01_nJM:OoLURUoj1lZon;IJ7oHE^dojZ0Y`;oN5JM00CoWg>Poh9RY?n2HZCoI4JI0_nV
PJ`01_lfHM3oLDnKocLPR?lg88SoDc>=obTGQ@;o>b6701Wo6a25ocdTROld7XSoDS>>oeTkTolg7hKo
<A^5ob`MRol/78[o7@f0oa<6OOm7;8co@BV=oc8LQ_l[5hCo8Q62oaP:Ool?287o2@1ko`H0Nol007;o
001`o`00J?l0073o001f00;o?bR=00?odiVHooooooooool01oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Gooooo000@ooooo`;o00002oooool2o`0002kooooo01;o0011om[:bOl0
087on=1ToooANOomcVgoo/mcooS3T?o_]YComkn=omZSVooleWCok;>FooO2TOog`93okKFEooFnTOo]
]9D3onjfU003onN]U_o^]I?ojk>G00;ofj6H00ColKVBom>IUooCVIOok;FH0_o9SiP2ombPU006omfV
WOo>UI[o[9W3olB?W_o^^Y[ofnIk0_oKYj02olR@V@04okR1V?o?TiCoci>DogaBUP;ocYFJ0_nmQ9L0
0ooY[I7oUfFEomBHU002om2EU`;o]gjF0ooJWiH2ol66U@;ofIfD0_o1QYD2olV>U0?o`HFD00So]WbD
omFGTongOIGokk>?omNKU?oocWSoeIZFogU@U0;o`8NH00GoOUFGooW7TonFK:7oUVbQohmTW002oi5e
/004onOSMonjS:KoOefQolbKY0;oRfBP00?o[9:koj]oY?n[Oj@00_nTPJh00onBV=Ko^I6]okVA[@02
ohI_/P03okJA/?nOO:coW7FV00;oVWZ^0_nMNZ`01?nMO:koUg2UoiM`YOnMMZH2ohUVY006ojMoZ?mb
F:GoLURUoh]UXOn[Pj[oHE^d0_mhEYd01?nOLj3oPV:Toh9RY?mTAYT2ojJ1[006oh]MU_oMN`3oRf>N
oeThSomC<hgo:AN50_lk8HL06?lo98So?BB9odd^RomB<hko>B27ocLOQ_la6hGo;1f;obPEPolM3H3o
4`ImodL/S?li8HOo<Qb6ob/GQ?lR4H;o7a>7o`l8POl107_o1P1ko`00L_l0073o001Xo`00L0;o001f
00?o?bR=om>IV?ooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo
000Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:oooool2ogAZ^@0@oo?@Goo]
`JConlmYonJ`Voo]be?on<>@onnfU?og_hgofZ>KoocFM?o//iKoml:AooO0T?o]]IGomKjAonfdU@;o
k[JD0_oW[IH02?o^]I?oi:^Gom^QV?oKXISolKVBom>IUooY[Y?oi:VE0_o9SiP2ombPU006onJ[Too>
UI[o[9W3olB?W_o^^Y[ofnIk0_oKYj02olR@V@04okR1V?o?TiCoci>DogaBUP;ocYFJ0_nmQ9L00ooY
[I7oUfFEomBHU002om2EU`;o]gjF0ooJWiH2ol66U@;ofIfD0_o1QYD2olV>U0?o`HFD00?o]WbDomFG
TongOID00_oGVi@2omFJUP07ogU@U?o0QiSo`8NHogiEUooiai?oUVbQokn9V`02ohmTW0;oTGF`00?o
^XbVogmMXOo<Vj@00_n;I:000on/T[_oZgnToj]oY002ojB1[P03ohYRW_nBV=Ko^I6]00;oU6^Q0_nO
O:`00onLMJKoVWZ^oiA^Y002oj5iY`04oiQaYOnGL:GoUg2UoiefYP;oRFJT0_nWOjP01?mbF:GoZh>Z
oj^3Z_mQFk@2ogEQ[P04oimcX?n:HYgoPV:TofA6V@;oYX6/0_n;GIH01_lb88_oFCR?oe<cSOmF=Hgo
>b67ocTSR`;oAb^;01SoCBj;oe8cS_li88Oo=an6oc4KQOl/7H_o:1F3ob`LR_m;;HcoAbb<ocTQQolb
78Ko>BF<ob/GQ?lR4H;o60Yoo`40Nol607_o001bo`00L?l007So001`o`00H_l007H2oclXS@_ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`008?ooool00ol0003ooooooooo
o`0Zooooo`0;o`00POmdJ[WoomAooooANOonbX?oo/mcong;Dooh`i3on=5VoooFQOoJXi/00_o//iH0
1Oog`Y7oml2@onfeUOoe_Y7okKBE00;ok[JD00CoijfFonjeToo^]I?oi:^G0_oKXIP01?oa^I;odiVG
onV^TooTZID2olV?V0;og:2D00?oiZ^ColjEV_o5RYD00_o^^YX2okJF]P?ob92I00Co^86HolnCU?o?
TiCo_hFE0_o>UIX2okf4U`03onV]TOnGIIGoe9RD00;od9FG0_ngOYH01ook`XCofYnFocl=Ioo1QYGo
0000oj5[U?oIWI@00_o1QYD2olV>U0?o`HFD00?o]WbDomFGTongOID00_oGVi@2omFJUP03oj5/UOo0
QiSo`8NH00;onLNC00CoUVbQokn9Von?I9coSfBL0_nAMK000onjS:KoOefQolbKY002oh]TX005ooG]
UOn[OjCo`j:gomK/R?nTPJh00_n:HYh00oniTJgo[8:WoiA[X@02oiml[003oiaeY_nDKZCoU6jT00;o
XGVW0_nHLJD00onGL:GoWGJVoiefYP02ohUVY00=ojMoZ?mbF:GoLURUoj^3Z_n8G9SoHE^dogEQ[_n8
G9SoRV:Moh9RY?mTAYWoYX6/ogaBU002oh]MUP03og5?VomI>8ooFCR?00;oESF=01_o>B>;odL[Rom7
:h_oCBj;oc@NR?li88Oo=an6ob/PSola6hGo:1F3odh_S?m;;HcoAbb<ocTQQolb78Ko>BF<ob/GQ?lR
4H;o60Yooa05OOl607_o001bo`00L?l007So001`o`00H_l007H00_lo:8d<ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0:Oooool02Ol0
04?o0021oooDOooodGWoo/Z3ook?Loold6cokkJDooSAIP02omZSV`07onbcU_og`Y7oml:AooO0T?o]
]IGomKjAonfdU@02onjfU004onN]U_o^]I?ok[FConB[U`;ofj6H00ColKVBom>IUooY[Y?oi:VE0_o9
SiP2ombPU007onJ[Too>UI[oaHZEolF:UOoKiW_o[GNGokJF]P02olR@V@05omRNV?nhPISoci>DolnC
U?noQID00_o>UIX2okf4U`03onV]TOnGIIGoe9RD00;od9FG0_ngOYH01Ook`XCofYnFonBVT?o1QYGo
000000;oXF^D0_o1QYD2olV>U008oog2O?o1QICo`HFDokIlU?oEUi?o]gfEomNKU?naNID2omFJUP03
oj5/UOo0QiSo`8NH00;onLNC00CoKdbHokn9VonoRI_oSfBL0_miO<X01on7jO3oc9^TolbKY?n;I:3o
mNfEoie^W?mhFj@00_nAK:@2ok1oW`;oRV:N00Go[8:WoiA[XOn;JJKoRfVVojj4Y`03oiA^Y004oj5i
YonHLJGoV76UoiM`Y@;oWGJV0_n9IZ@01_nWOjSoLURUog9HYOn[Pj[oR5bHoiAUV0;oR5bH0_n:HYd0
0omTAYWoS66JogaBU002oh]MUP06ogU?U?mI>8ooFCR?og==U_mF=Hgo>B>;0_m7:h/02om=;X_o=1j8
oe8cS_lg7hKo:b2?oc4KQOlX5H?oCRn<od/]S?m7;8co>B6700;o<Qb600_o:aN4ob8AP_lH2Woo40Em
o`00M_l607_o001`o`00N?l0073o00:7o`00MP02oh9NX0cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`05ooooo`008_ooool2o`0002Wooooo00co0013o`00POooe7ooom5iook:Poon
cg?oo=1/onnfU?ohdFKofZ>KoocFM?o//iH2ooO2T@04ooO0T?o]]IGomKjAonfdU@;ok[JD00KoijfF
onjeToo^]I?oi:^GonF[UOoa^I82om>IU`05onV^TooTZIGobHnHolV?V?oLX9@00_oVZi<01_o>UI[o
aHZEolf@Ton]MiOoaHVDokJF]P;ob92I00Oof9jHokR1V?o?TiCoci>Dokn5UOoOXI;ooM^200;o_HBG
00GojJfAoiMUUOoDV9Coe9RDo`000002okMnUP05oo_2Q?oJWiKoi:J@ol66UOl000000_nQJi@2ol66
U@0:o`00COo9SYCooL9lol65U?nUKYCoeINColjBU?ngOIGoei^Dok5iU@;oeIZF00?oXFbEol27V?o0
QiP00_oiai<3okn9V`07ohmTW?ofiHGoNGc:oi=XW?n7jO3oc9^Toh]TX002oie^W003ogQKY?nAK:Co
TFbT00;o/7nO0_n:HYh01?n/PZOoU6^Qoh]YY_n;JJH2ojj4Y`;oU6jT00CoXGVWoiQaYOnHLJGoUg2U
0_nMMZH01On9IZCoUfVJohmRVOn?HYWoV6VI00;oR5bH00OoU6FHohQLV?n8G9SoPeNEohYRWOnGJ9[o
S66J00;oO5:D00coRefFogU?U?lb88_oFCR?og==U_mF=Hgo>B>;ofE0TOm7:h_oCBj;oc@NR?mB<hh2
ocLOQP0Coc4KQOm>;hcoCRn<od/]S?m7;8co>B67od4YSOlb78Ko:aN4ob8AP_lH2Woo40Emo`T0Nol6
07_o1`5moa<=QOlQ6i3o001`o`H5P`02oh9NX0gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`05ooooo`009?ooool00ol0003oooooooooo`0Vooooo`0@o`00@ooE^KgokL6ToooANOon
bX?oo/mcooS3T?o_]YCoomJ5omZSVooleWCok;>FooO2TOog`93okKFEooFnT@;okKBE0_o^]Y@00ooW
[IKok[FConB[U`02onF[U@03oo6iT_oCVIOodiVG00;oi:VE0_o9SiP01ooLX9CoiZ^ConJ[Too>UI[o
aHZEolf@Ton]MiL00_o5RI@2olR@V@06omRNV?nhPISoci>DolnCU?noQIGogj6B0_omfh800onmQ9Oo
jJfAoiMUU@02omBHU0;o000001Oo]gjFoo_2Q?n:FY?oi:J@ol66UOo>TYCo0000oj5[U?okbF;o`HJE
o`00COo9SYCooL9lol65U?nUKYCoo<USokMmUOl000koei^Dok5iUOnQK9GoeIZFoj5/U@02ol27V0;o
XfnF0onoRI/00on?I9coV6JFogeIW@02oi=XW004olbKY?n[NiooWFjLoie^W0;oXW:L00?oTFbTok1o
Won`Oil00_n:HYh00on5L[Oo^XfVokZ=YP02oh]YYP05ojj4YonDKZCoU6jToj5iYonHLJD00_nIJYX0
1?nFIi[oU6NJoiAWV_nGJIX2ohmRV@04oiQYVOn8G9SoR5bHoiAUV0;oR5bH0_n3EiD02OnGJ9[oS66J
ogaBU?mlDYCoRefFogU?U?lb88_oFCR?ocdTRP02oeHeS@0KofE0TOm7:h_o5Q28oc@NR?mB<hko4b:N
ocLOQ_mM>hooHT2Bodh_S?m29h[o?RB9ocTQQom1:Hgo<Qb6ob/GQ?lR4H;o8aB5oa05OOl907_o1P1k
o`L1OOlC3HGo001ho`00L?l61H?oPUjP00oooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`05ooooo`009Oooool00ol0003oooooooooo`0Vooooo`09oooDOoo]`JCoo/Z3onJ`Vooncg?o
n<>@onnfU?ooeXGofZ>K00;ok;>F00Goml:AooO0T?o]]IGomKjAonfdU@03onjfU003onN]U_o^]I?o
i:^G00;oiJ^E00?ol;RDom>IUooY[Y<00_oTZID00oo@U9GobHnHombPU002onJ[T`;oaHZE00CocI2C
ojegUoo5RICoaHVD0_o8T9T01_oHWYSo^86HolnCU?o?TiCo_hFEomnQTP;ooM^200?o_HBGonV]TOoD
V9@00_oDV9@06OnkPIKo0000okMnU_ok`XCoRUZConBVT?o1QYGocY:Do`000?nQJiConlURol66UOon
a7[obHjDoog2O?o1QICoYFjDooc9HongOIGoe9NDo`003_naNIGonKf6oj5/UOl002<00_o0QiP2oj=_
UP?o_hVK0_nHIYH01OnXMIWoTfRLoi=XW?nCJ9coZg^O00;oWFjL0_nRLY`2oi5/Y004ok1oWon:HYko
]X^WohEb]`;o^XfV0_n;JJH01On^Q:OoU6jToie/VOnMK9WoU6JJ00;oVFZJ00?oUVNJoiAWV_nDIiX0
0_nGJIX2ohmRV@03oiQYVOn8G9SoU6FH00;oR5bH0_n3EiD01?nDI9OoS66JogaBU?mlDY@2oh]MUP03
ogU?U?mI>8oo?BB:00;oESF=00?o>B>;odL[RolF48P00_ld7XP01oli88Oo=an6oedkSomR@9;oCRn<
od8WR_ln98T00_li8HL03Olb78Ko:aN4obTHQ_lS58Go7a65o`T0Nol607_o001bo`00L?l007So8A^@
o`00H_l007H04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo000Voooo
o`03o`000?oooooooooo02Gooooo00Wo0`J6ong1Y?onbX?oi[2Kook?Looh`i3okkJDoooFQOoJXi/0
0_o//iH01Oog`Y7oml2@omZXXooe_Y7oi[>P00?ok[JD00?oijfFonjeTooTZiL00_oUZiD01?o`^9Co
diVGonV^TooTZID2om2DU@04olV?V?oLX9CoiZ^Com2CU@;oaHZE00OocI2CojegUoo5RICoaHVDolNo
d_o8T9Wof9jH00?oci>D00Ko_hFEomnQT_oOXI;ooM^2okf4UooY[I43omBHU0;o^h6F01Wo]gjFoo_2
Q?oTYY3oi:J@ol66UOo>TYCo0000oj5[U?okbF;o`HJEook4N_o9SYCooL9lol65U?miC8ooo<USokMm
UOoDUiCo000>ok5iUOoi_HKoXFbEo`008oo0QiSogJ6D00;oXfnF0onoRI/2oiQVUP07ojQeVOnCJ9co
TfRLoi=XW?n[NiooWFjLol^HX@02oj9bW0;oTFbT00Co/7nOokJ;YonfRjOoQG:g0_njSJH2oh]YYP05
ojj4YonBI9WoWFbIoie/VOnDIYX00_nIJYX2oiIWVP03oiAWV_nGJI[oUfVJ00;oSf:I00?oV6VIohQL
V?nDIIP00_n8G9P2oh=GU@04oiATUon<HI[oO5:DogaBU0;oRefF00?oNDnDogaCU_lm98X00_mF=Hd0
1_li8h_oAb^;odL[Rom=;X_o=1j8ocTPQ`;oGC^?00CoD36<odh_S?m29h[oBbf<0_li8HL03Olb78Ko
:aN4obTHQ_lR4H;o60YooadBQ_l607_o001bo`00L?l007So8A^@olVW]_l007H04?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo000Wooooo`03o`000?oooooooooo02Cooooo
00OokL6ToooANOonbX?oi[2Kong;Doo_]YCon=5V00;ofZ>K00Wol<f^ooO2TOo>YJooo]jEomZXXooi
cYcoi[>PonbjWoo^]Y@00_oW[IH02?o^]I?oi:^GonF[UOoUZiGol;RDom>IUooY[Y?oi:VE0_o@U9D2
ombPU006onJ[Too@TiGoaHZEolF:UOo=T9?o[GNG0_o5RI@00ooGVI;ob92IomRNV003olnCU004okn5
UOoOXI;ogj6Bol^?U0;ojJfA0_oDV9@01OoicV?o^h6FonnbSOngOYKonl:400;oi:J@00oo`HJEoljB
U?l0003oXF^Doo_9H_o1QYGoo/AjojUbU?om`Wco_hBDogU<SoolbF?o]gfEomBGU?l000h00_oi_HH0
0onQK9Go^X6Fol27V002omfQU004oj=_U_noRI_o_hVKokn9V`;oV6JF0_nXMIT2oi=XW003oj]kWonM
KYcobiRQ00;oXW:L00?o^l4ooi5/Y?n`Oil00_nfRjL01?nOKi[oQG:gokZ=Y_nFIYP2oim]V003oi9T
VOnMK9WoWFbI00;oU6JJ00?oVFZJoiIWV_nFIiX00_nDIiX01?nGJI[oSf:IohmRVOnHJIT2ohQLV006
oiAUV?n8G9SoPeNEoh=GUOnDI9OoJDBB0_mlDY@2oh]MUP03ogU?U?mlDiKoFCR?00;oESF=00Ko>B>;
odL[Rom7:h_oCBj;oc@NR?mK>8h2oedkS`0<oe0aS?m>;hcoCRn<od/]S?m7;8co>B67oc8LQ_l_78So
:aN4ob8AP_lH2Woo40Em0_l607/01?l0073o?cFMo`00N?l0070Booooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool01?ooool002Sooooo0_l0000Tooooo`07oeA4X_ogaYWoo/Z3ook?Loo]
be?oVG2Rom_KI`02omZSV`03oo3=[_o>YJoocZF_00;ofZRS00GonLjLonJcX?o/^YookkjOonN]UP02
onjeT`07onB[UooUZiGol;RDom>HUooCVIOojJjConBYU@02om2DU@04ombPU?oVZi?oiZ^Com2CU@;o
aHZE00?ocI2ColF9U?o5RI@00_oGVI82omRNV0;oci>D00GolkR>okn5UOoOXI;ogj6Bol^?U002onV]
T@;oe9RD00?onLiSok^1U_o_/Xd00_ok`X@3onBVT004oljBU?l0003oXF^Doo_9HP;oo/Aj00SoZG:D
oog2O?noQ9CoNDb?ooc9HongOIGoe9NDo`003P;onKf600?oXFbEokZ1U_o0QiP00_oMXI@00onSKiKo
^Z`Ookn9V`02okElUP03oiQVU_nXMIWoZ7FI00;oTfRL00KoZg^Ooie^W?o;V:7obiRQoj9bW?nk`Cl2
oiYWUP06onKj[onfRjOoWfnJoh]RWOnjSJKoUVJH0_nOKIP00onBI9WoWFbIoie/V@02oiAVVP;oVFZJ
00CoUVNJoiAWV_nDIi[oUfVJ0_n?HYT01OnHJIWoR5bHohQLV?nDIISoR5bH00;oPeNE00CoU6BGofU4
T_n<HI[oO5:D0_n;GIH03_miCiCoO5>FoeThSolm98[oESF=ocTSRomT?hooAb^;ofDoSomYA97oFcR>
oe8cSOmM>hooD36<0_m>;h`03om;;HcoAbb<ocTQQolb78Ko;ab8ob/GQ?lR4H;o60Yooa05OOlS68[o
1P1ko`L1OOlC3HGo001hokfU5P0Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1?ooool002[ooooo00?o0000ooooooooool08Oooool01?mDA:;omlJIogMGX?oncg<2oiU`XP06oooF
QOoJXi_ofZ>Koo3=[_o>YJooo]jE0_oJZ:<2onJcX003onbjWoo__YooijfF00;ok[FC0_oUZiD01Oo`
^9CodiRGom>IUooY[Y?oi:VE00;od9BE00Cog:2DonJ[TooVZi?od9>E0_o5RYD00oo=T9?oaHVDolF9
U002omNITP;of9jH0_o?Ti@01Ooc^8ko_hFEomnQT_oOXI;obhnD00;ojJfA0_oDV9@01OoicV?o^h6F
onnbSOok`XCofYbB00;oi:J@00GobHfDoljBU?l0003onlURokf3U@02ook4NP03ojUbU?om`Wco_hBD
00;oo<US00?o]gfEomBGU?l000h00_oi_HH00onQK9Go^X6FokZ1UP02omfQU003oj=_U_nj[1oo_hVK
00;o]GbF00?oV6JFojQeVOnXMIT00_nCJ9`01_o=/;kobiRQol^HXOo;V:7oXW:LojIaUP;oVVNF0_nF
J9X01?nOKi[oWFZFoieZU_nFIYP2oim]V0;oTVBI00?oWFbIoiAVV_nDIYX00_nIJYX01?nFIi[oU6NJ
oiAWV_nGJIX2ohmRV@05oiQYVOn8G9SoR5bHoiAUV?n8G9P00_n3EiD2oiATU`0;ohaQV_mlDYCoRefF
oh]MU_miCiCoFCN>ofDoSolm98[oESF=ocTSRomT?hl00_mU?hl01OmYA97oFcR>oe8cSOmM>hooD36<
00;oCRn<00?o@RN:ochTROli8HL00_lb78H02Ol[5hCo8Q62ob<DQOl@1Ggo2@1ko`H0Nol70Ggo4`f5
ocleW@0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool002_ooooo00?o
0000ooooooooool08?ooool01?mDA:;oo/Z3onJ`Vooncg<2oiU`XP;oKU2N00Ool<f^oljU[oo>YJoo
o]jEomZXXooicYcoi[>P00;ok;ZO00CokkjOomjZX?o^]I?oi:^G0_oUZiD01Oo`^9CodiRGonV^TooY
[Y?oi:VE00;od9BE00Gog:2DonJ[TooVZi?od9>EolF:U@02olf@T`;oaHVD0_oGVI82omRNV0;oci>D
00GolkR>okn5UOoOXI;ogj6Bol^?U002onV]T@;oe9RD00GonLiSok^1U_o_/Xgonl:4omZLTP02onBV
T00=olV=U?o>TYCo_H>Eoo_9H_l0003oo/AjokAkUOom`Wco]GbEoog2O?olbF?o_hFEoiAQT`02omBG
U0;onKf600?oXFbEokZ1U_njPIH00_oMXI@00onj[1ooXVbDokn9V`02okElUP04oiQVU_nXMIWoZ7FI
oi=XW0;ocK2n0oo;V:42ojIaUP;oVVNF0_nFJ9X01?nOKi[oWFZFoieZU_nFIYP2oim]V0;oTVBI0_nM
K9T01onDIY[oVFZJoiUZV_nFIi[oU6NJoiAUV?nAHiP00_n?HYT01?nHJIWoR5bHohQLV?nDIIP2ohQL
V005oh=GUOnDI9OoU6BGofU4T_mlDY@00_n;GIH03_miCiCoFCN>ofDoSolm98[oLT^CocTSRomT?hoo
Ld^CofDoSomI=hkoFcR>oe8cSOmM>hooD36<0_m>;h`03_m29h[o?RB9ocTQQole88[o<Qb6ob/GQ?lY
68Ko8aB5oalAQOlM4XKo1P1kocT/U_lC3HGo?cFM5Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Cooooo000/ooooo`03o`000?oooooooooo01oooooo00KomlJIogMGX?oV/9_oo/mc
oiU`X_oKffL2ofi@WP03ooooooo>YJoocZF_00;ofZRS00?onLjLonJcX?o/^Yl00_o__Yl00ooNZZ3o
n<bMonB[U`02onF[U@03oo2hU?oCV9OojJjC00;oi:VE0_o@U9D01OoLX9CoiZ^Com2CUOo@TiGoaHZE
00;ocI2C0_o5RI@2omNITP;of9jH0_o?Ti@01?oc^8ko_hFEomnQT_oOXI82ol^?U005onNZT?oDV9Co
e9RDooW>HonkPIH00_o_/Xd01ooJW9;oi:J@onBVT?o9SICocY:Dokf3UOl003400_l000001_ndNiGo
0000okElUOom`Wco000iokn5U@?oe9ND0_oi_HH00onQK9Go^X6FokZ1UP02omfQU003okZ/7onRK9Co
]GbF00;o]GbF00OoV6JFom>IV?nXMIWo000=olf`__nOJiCoUFBG00;obiRQ0_nVLIH2oiYWUP;oUVRJ
00CoWfnJoieZU_nMJYKoUVJH0_nOKIP2oi9TV@;oWFbI00CoU6JJoiUZV_nGIiWoUFFH0_nDIIP01?nA
HiSoSV2HohiPV?nCI9T2ohQLV004oiAUV?n8G9SoR5bHoh=GU@;oU6BG00CoJDBBogaBU?n;GIKoRefF
0_miCi@2ofDoS`0:og9;TomX@HooJ46?og=;TomU?hooFCN>ofU4TOmK>8koGC^?oe0aS0;oCRn<00go
@RN:ochTROli8HOo=B2:oc8LQ_l[5hCo:AR6ob<DQOlO4HGo7A:6ob<HR_li;9KoOVV`01Oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`00;Oooool2o`0001oooooo0_mgEj00
1?oV/9_oo/mcoiU`X_oKffL4ooooo`03ookNUOl005_ofZRS00;oi[>P00Sok;ZOonnnWooNZZ3ogZZP
ooS<WOoTZiOoiJ^Eoo2hU0;odiRG00?ojJjConBYUOoTZID00_o@U9D01OoLX9CoiZ^Com2CUOo@TiGo
aHZE00;ocI2C0_o5RI@2omNITP06olb@U?oHWYSoci>DolnCU?oc^8ko_hFE0_oOXI82ol^?U005onNZ
T?naNIKoe9RDooW>HonkPIH00_o_/Xd2omZLTP0>onBVT?o9SICocY:Dokf3UOl0037o0000okMmUOnd
NiGo0000okElUOnmPYGo000iokn5UOo9SI@2omBGU003on2ST_oi_HKo^X6F00;o^X6F0_oMXI@00onj
[1ooXVbDokElUP02okElUP;odiVH00OoZ7FIo`003OnOJiCoWf^DoiETUoo;V:7oWFZF00;oYW6F0_nJ
IiH2oiIXVP05ojIaV?nMJYKoWFZFoieZU_nFIYP00_nOKIP01?nBI9WoWFbIoie/VOnDIYX2oiMWV@04
oiEUV?nDIISoU6FHoi5SV0;oSV2H00CoTfBIogmFUon8G9SoU6FH0_n8G9P2oh=GU@05oiATUomYA9;o
O5:DogaBU?n;GIH00_miCi@00omlDiKoICn?oe`iS@02ofQ1S`0;og=;TomU?hooFCN>ofU4TOmK>8ko
DS>=oedkSom4:XcoCRn<od8WR_ln98T00_li8HL02Olb78Ko;ab8obTHQ_lS58Go7a65oadBQ_lS68[o
1P1kogiY/00Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool002oooooo
00?o0000ooooooooool07?ooool01Ol004GoMeNPonJ`VoolegCoVG2R00Oooooo00GonLjLooooooo/
^Yook;ZOonnnW`02omjZX004ooS<WOoTZiOoiJ^Eoo2hU0;odiRG00?onlN=onBYUOoTZID00_o@U9D2
onJ[T`;od9>E00?oaHZEolf@Too=T9<00_o5RI@2omNITP05olb@U?l0003oci>DolnCU?oc^8h00ooO
XI801oo;SiCoijZ@onNZT?oEV9?oe9RDolJ:U?nkPIH00_o_/Xd2omZLTP;obHfD00cocY:Dokf3UOl0
037om/YKokMmUOndNiGo]gfEokElUOnmPYGo000iokn5UOo9SI@2omBGU003on2ST_oicF3onLeP00;o
^X6F0_oMXI@00oo0QIGoXVbDokElUP02okElUP;odiVH00CoZ7FIoi5QUOnOJiCoWf^D0_nEI9L01OnM
JYKoYW6FojIaU_nVLIKoVVNF00;oU6BF00GoYW6HoieZU_nMJYKoWFZFoiIVV002oim]V004oi9TVOnM
K9WoWFbIoiMWV0;oUfNI00CoUFFHoiAUV?nDIISoTF>H0_n>H9P01?nCI9WoOeJGogmFUonDIIP2ohQL
V0;oPeNE00GoU6BGofU4T_mlDYCoO5:Doh]MUP02ogU?U00@ogaCU_mU?hooG3V=og9;TomX@HooI3n?
ofDoSomI=hkoJDBAoe/hS_mB<hgoGC^?od@ZS?m>;hco@RN:od/]S0;o>B6700Wo<Qb6oblLR?lY68Ko
8Q62oaP:OolM4XKo8aR:o`H0Noli;9H06?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00?ooooo000`ooooo`03o`000?oooooooooo01_ooooo00Go0015ogMGX?oV/9_okL]Com_KI`0:
ooooo`;okkjO00?ogZZPooS<WOoAWZ800_oUZiD01Oo`^9CodiRGom>HUookahgoi:VE00;od9BE00Ko
k[>@onJ[TooVZi?od9>Eom2CToo5RYD2olf@T`;oaHVD0_oGVI801Oo<T9CoeYRCo`000?o?TiColkR>
00;ogj6B00Ooolijol^?U?oWZY3oijZ@omFHTooicV?oaXZD00?okk:=0_oJW982olV=U00:omFj<onm
PiGom/YKooK:FongOIGo]7^EokMmUOneO9Go_H:Eo`00>@;obHfD00?oe9NDon2ST_oPXi800_oicF02
okZ1UP;ogJ6D00?o`8FEoj9/U?neO9H00_neO9H2om>IV007ojQeVOn^MICoWf^Doim[U?nEI9OoY6nE
oieZUP03ojIaUP04oiYWU_nDI9KoU6BFojIaV0?oWFZF00CoUVJHoim]V?nOKISoTVBI0_nMK9T01?nG
IiSoUfNIoiMWVOnEIIP2oiAUV003oi5SV?n>H9SoSV2H00;oTfBI00CoOeJGoiYYVOmYAYGoR5bH0_n3
EiD01?nDI9OoJDBBogaBU?mlDY@2oh]MUP0?ogU?U?mlDiKoICn?oe`iSOmbBi?oJ46?of@oSomU?hoo
FCN>ofU4TOmK>8koDS>=oedkSom@<HcoCRn<00;o@RN:00_o>RB<ocTQQole88[o;ab8obTHQ_lR4H;o
8aB5oa05OOl907_o8aR:olS6A@0Iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
0oooool0037ooooo00?o0000ooooooooool06_ooool00ol004Goi[2Kook?L`0<ooooo`05o`00JooN
ZZ3ogZZPooS<WOoAWZ800_oUZiD01Oo`^9CodiRGom>HUookahgodYZK00;od9BE00Kok[>@onJ[TooV
Zi?od9>Eom2CToo5RYD2olf@T`;oaHVD0_oGVI801Oo<T9CoeYRComJHToo?TiColkR>00;ogj6B00Co
olijol^?U?oWZY3oijZ@0_oEV9<02_o6RYCokk:=onnbSOnfOIGofYbBo`00<OnWL9GobHfDomFj<onm
PiD2ooK:F`06okMmUOogbU_o]gfEom6g;_nmPYGoZ76D0_o9SI@00ooDUiCoh:>Bon2STP02ooW=H006
okZ1U_n]MIGogJ6DomfQU?o0QIGoXVbD0oneO9H2om>IV007o`003On^MICoWf^Doim[U?nEI9OoY6nE
oieZUP03ojIaUP04oiYWU_nDI9KoU6BFojIaV0?oWFZF00CoUVJHoim]V?nOKISoUVJH0_nMK9T01?nG
IiSoUfNIoiMWVOnEIIP2oiAUV003oi5SV?n>H9SoSV2H00;oTfBI00CoOeJGoiYYVOmYAYGoR5bH0_n3
EiD01?nDI9OoJDBBogaBU?mlDY@2oh]MUP07ogU?U?mI=hkoICn?oe`iSOmbBi?oJ46?of@oS`02ofDo
S`06oeTgS_mK>8koDS>=oedkSom@<HcoCRn<0_m29hX02oln98Wo>B67ocDPR_l_78So:aN4obTHQ_lS
58Go7a65oadBQ_lS68[ob<I501[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03
ooooo`00<_ooool2o`0001[ooooo00?oKDjMonJ`Vooncg<03Oooool2omjZX003ooS<WOoAWZ;omlbP
00;ol;RD00CodiRGoo_7SOokahgodYZK0_o@U9D01_o^/i3oiZ^ConJ[Too@TiGod9>ColF:U@;ocI2C
0_o5RI@2omNITP03olb@U?oFV9?oeYRC00;olkR>0_oOXI801?oocW[obhnDonNZT?oWZY02omFHT`;o
aXZD00Sokk:=okImUOoQXi7ohJ>AomNJToo9SICoeKXcokf3U@;om/YK00Ko]gfEooO:FongOIGodKL^
okf2UOnXLI@2olV=U0?oh:>B0_oicF000onjPIKo[GFEomfQU002ol25U@04oj9/U?neO9Ko]GbFokEl
UP;odiVH00OoY6jDojieU?nOJiCoWf^DoiETUonTKiGoWFZF00?oYW6F00CoVVNFoiATU_nDI9KoYW6H
0onMJYH01?nFIYSoWffHoim]V?nFIYP2oie/V@04oiMWV?nGIiWoUfNIoiEUV0?oU6FH0_n>H9P2oi=T
V@04ogmFUonJJIWoVVVIohQLV0;oPeNE00goU6BGofU4T_mYA9;oO5:DohQLV?n;GIKoNDnDoeTgS_mU
?hooG3V=og9;TomX@HooI3n?00;oICn?00KoFCN>oe/hS_mB<hgoDS>=oe0aS?m4:X`2od8WRP0:ochT
ROli8HOo=B2:oblLR?l[5hCo:AR6ob<DQOlO4HGo7A:6ob<HRQcooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`03ooooo`00=?ooool00ol0003oooooooooo`0Gooooo`;oKDjM00?oo=Md
ooooooooool03?ooool01Oohc9godIjRom6NX_ogc:3oek6c00;odiRG00?onlN=om:JVooBVY/00_o@
U9D01_o^/i3oi:ZGom2CUOo@TiGod9>ColF:U@;ocI2C0_o5RI@2omNITP03olb@U?oFV9?oeYRC00;o
lkR>0_oOXI801?oocW[obhnDonNZT?oWZY02omFHT`;oaXZD01?okk>=okImUOoQXi7ohJ>AomNJToo9
SICoeKXcokf3UOoAU9Com/YKokMmUOogbU_o]gfEom6g;_nmPYGoZ76Do`00?Oo9SICo/WVD00;oh:>B
00ConLePom6EUOnjPIKo[GFE0oo0QID01?oUZI?o]GbFokElU_neO9H2om>IV004ojA^U?n^MICoWf^D
oim[U0;oY6nE00GoWFZFojIaU_nVLIKoYW6FoiYWUP02oiATUP;oYW6H0_nMJYH01?nFIYSoWffHojUe
VOnFIYP2oie/V@05oiMWV?nGIiWoUfNIoiMWVOnEIIP00_nDIIP01OnAHiSoSV2HohiPV?nCI9WoOeJG
00;oVVVI00?oJDJEoh=GUOn3EiD00_nDI9L01omYA9;oO5:DohQLV?n8G9SoNDnDoeTgS_mU?hl00_mL
>Hd01_mX@HooI3n?ofDoSomU?hooFCN>oe/hSP;oDS>=00goD36<od@ZS?m29h[o@RN:ochTROlj98co
=B2:oc8LQ_l_78So:AR6ob<DQOmFCZgoOGO101gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`00=Oooool00ol0003oooooooooo`0Fooooo`;oKDjM00?oo=Mdooooooooool0
3Oooool2om6NXP05ooO<X?oG/K?odiRGom>HUookahd00_oBVY/2om2DU@05onjcT?oTZYOod9>Eom2C
UOo@Ti<00_o=T9<2ombNT@04olF9U?oGVI;ohZFAolb@U0;oeYRC0_oc^8h2omnQTP04ooo>N_o;SiCo
ijZ@onNZT0;oeIRC00?ool]jolJ:U?o_/hd00ooQXi42omNJT`0=om6DU?nmPiGodIBDooK:FongOIGo
mlYKokMmUOoA]bko_H:EojQaU?l003gobHfDok9iU002on2STP04okj4UOoAUIGo^X6FojeeU@?o`8FE
0_oUZI<2okElUP;odiVH00CoY6jDojieU?nOJiCoWf^D0_nTKiD2oieZUP;oYW6F00?o[WNFoiATU_nD
I9H00_nVLIP2oieZUP04oiIVV?nOKISoZGFIoiIVV0;oWFbI0_nGIiP2oiMWV@04oiEUV?nDIISoU6FH
oi5SV0;oSV2H00GoTfBIogmFUonJJIWoVVVIofU6U@02ohiQV@;oU6BG00KoJDBBogaBU?n8G9SoR5bH
ogU?U?mI=hh2ofDoS`07oe`iSOmX@HooI3n?oePhSomU?hooFCN>oe/hSP02oe8cS@0<oe0aS?m4:Xco
CRn<od8WR_ln98Wo>RB<ocDPR_lb78Ko;ab8obTHQ_m9@JGoETj]7oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00?ooooo000fooooo`03o`000?oooooooooo01Kooooo00?oKDjMoooo
ooooool03_ooool01?l006?omlbPomNa/ooG/K<2om>HU`05oo_7SOoBVY_odYZKom2DUOo^/i000_oT
ZYL2om2CU@03om2CToo=T9?ocI2C00;og9jA00CoaHVDomNIT_oRYI7oc92D0_oFV9<01_o9SICoeYRC
omnQT_oOXI;oolijol^?U0;oijZ@00GoeIRCooo;N_oobg[oaXZDonncS@03on6ST@;oeiZC00GodIBD
ooK:FooAU9Com/YKooO:F`02om2CU007omJIU?nmPYGoZ76Do`00?Oo9SICo/WVDon2STP02okj4U@;o
dIFE00Co[GFEol25UOo0QIGo`8FE0_oUZI<00oneO9Ko000dom>IV002ojA^U0;o[WFD00?oWf^DojA_
UOnTKiD00_nMJYH2ojIaUP03ojigU_nDI9KoU6BF00;oYW6H0_nMJYH01?n@HYWoZGFIojUeVOnFIYP3
oie/V@04oiMWV?nGIiWoUfNIoiEUV0;oU6FH00GoTF>HohiPV?n>H9SoTfBIogmFU`02oiYYV@07ofU6
UOn>HIWoSV6Ioh9KWOnDI9OoJDBBogaBU002ohQLV00;ogU?U?mI=hkoICn?ofDoSomL>HgoJ46?of@o
SomH>8ooICn?oeTgS_mB=8l00_mB<hd02Om@<HcoA2Z<odh_S?m29h[o?2R?ocXTS?li8HOo=B2:oblL
R002obTHQP03ob<DQOoooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`03ooooo`00=oooool2o`0001Kooooo00?oKDjMooooooooool03oooool00oogc:3oek6comNa/`02
om>HU`05oo_7SOoBVY_odYZKom2DUOo^/i000_oTZYL2om2CU@03om2CToo=T9?ocI2C00;og9jA00Oo
aHVDomNIT_oRYI7oc92DomJHTooNXI;obHfD00;oeYRC00Kogj6Booo>N_oWZY3oijZ@oljATooEV9<2
ooo;NP03olJ:U?o_/hgohJ>A00;ohJ>A0_oGVY<3om6DU0;ocY:D0_o@Ti@00ooFVICo_H:EojQaU002
on>VTP04ok9iU?nnQ9Go_XBEokj4U@;odIFE00Co[GFEol25UOo0QIGo`8FE0_oUZI<00oneO9Ko/7ND
om>IV002ojA^U0;o[WFD00GoWf^DojA_UOnTKiGoY6nEoieZUP02ojIaUP05ojigU_nDI9KoU6BFoiAT
U_nVLIP00_nMJYH01?n@HYWoZGFIojUeVOnFIYP3oie/V@04oiMWV?nGIiWoUfNIoiEUV0;oU6FH00Co
TF>HohiPV?n>H9SoTfBI0_moEYL01?nJJIWoJDJEohiQVOn>HIT2oh9KW@0:ofU4T_mlDYCoR5bHohQL
V?m3:hkoFCN>odX/RomU?hooG3V=ofQ1S`;oI3n?00?oICn?oeTgS_mB=8l00_mB<hd02om5;I3oA2Z<
odh_S?m29h[o?2R?ocXTS?li8HOo=B2:oblLR?m7?jGo:AR602;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`00>Oooool00ol0003oooooooooo`0Cooooo`03ofe>WOoooooo
oooo017ooooo0_o;VjD01_oCV9OonlN=om:JVooFWIWod9BEonjcT0;oi:ZG0_o@TiD00oo@Ti?ocI2C
olf@T`02ombNT@;oeiVB00GohZFAomJHTooFV9?ogZ6BolV=U002omJHT`06ooo>N_o<T9CoijZ@onNZ
T?o>TI?o000`0_oobgX2onncS@?ohJ>A0_oGVY<3om6DU0;ocY:D0_o@Ti@2omJIU004ojQaU?oSYY;o
hjJBok9iU0?o_XBE0_oAUID2ook9P`;o`8FE0_oUZI<00oneO9Ko/7NDom>IV002ojA^U0;o[WFD00Go
Wf^DojA_UOnTKiGoY6nEoieZUP02ojIaUP;o[WNF0_nDI9H01?nVLISoWFZFok5kV?n@HYT2ojUeV@;o
UVJH0_nMK9T01?nGIiSoUfNIoiMWVOnEIIP2oiAUV003oi5SV?n>H9SoSV2H00;oTfBI00GoOeJGoiYY
VOmYAYGoJDJEohiQV@02oh9KW@0:ofU4T_mlDYCoR5bHohQLV?m3:hkoFCN>odX/RomU?hooG3V=ofQ1
S`;oI3n?00KoF3R?oeTgS_mI=hkoFcR>oe8cSOm5;I02od@ZS007od8WR_ll:8oo>RB<ocXTS?le88[o
BdN/oblLR00Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool003[ooooo
00?o0000ooooooooool09_ooool2ol^KY@06om>HUooBVY_odYZKomJMVOo@U9Gok[>@0_oTZYL2om2C
U@03om2CToo=T9?ocI2C00;og9jA0_oGVI801OoRYI7oeYRComJHTooNXI;obHfD00;oeYRC0_o<T9@2
onNZT004oljATol0033ool]jooo;NP;okk>=0ooQXi401ooGVY?o000Mom6DU?oAU9Co0004oljBU?l0
02400_o@Ti@2omJIU0?ohjJB0_onaX42okj4U@;odIFE0_onbH<2ol25U@;oiJVC00?o]GbFok1gU?n`
Mi@00_nTKY@2ojieU005oim[U?nTKiGoY6nEojA_UOnMJYH00_nVLIH2ojigUP;oU6BF00CoYW6HoieZ
U_naNiSoT6:I0onYMIT01?nFIYSoWFbIoie/VOnGIiP2oiMWV@04oiEUV?nDIISoU6FHoi5SV0;oSV2H
0_nCI9T01OmoEYOoVVVIoiYYVOmYAYGoSV6I00;oPU^M00[oJDBBogaBU?mlDYCoR5bHod<[S_miCiCo
BRb;ofDoSomL>HgoHSj@0_mT?hl01_mH>8ooFCN>oeTgS_mK>8koDS>=odD]T0;oA2Z<00Ko@RN:oc`X
Soln98Wo>RB<ocDPR_m;Aj`Uooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool003_ooooo00?o0000ooooooooool09Oooool2ol^KY@08oo_7SOoBVY_odYZKomJMVOo@U9Gok[>@
onBZUoo<TIL2om2CU@03om2CToo=T9?ocI2C00;og9jA0_oGVI801OoRYI7oeYRComJHTooNXI;obHfD
00;oeYRC0_o<T9@01?oFVI?oijZ@oljATol00302ooo;NP;okk>=0_oQXi402?o=T9CoeiZColZ=U?l0
01godIBDo`001?o>TYCoah^D0_o@Ti@2omJIU0?ohjJB0_onaX42okj4U@;odIFE0_onbH<2ol25U@03
ok5iU?oUZI?o]GbF00;o/7ND0_nTKY@2ojieU007oim[U?neO9CoY6nEojA_UOnMJYKoYW6FojihV002
ojigUP;oU6BF00CoYW6HoieZU_naNiSoT6:I0onYMIT01?nFIYSoWFbIoie/VOnGIiP2oiMWV@04oiEU
V?nDIISoVFjPohQSX0;oSV2H0_nCI9T01?moEYOoVVVIoiYYVOmYAYD2ohiQV@0;oh9KWOlg98koO5:D
ogaBU?n8G9So@b^>ogU?U?mI=hkoICn?oe`iSOmR?Y000_mT?hl02?mH>8ooICn?oeTgS_mK>8koDS>=
odD]T?m@<HcoA2Z<0_m29hX01?ln98Wo>RB<oeIXbOle88XVooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool003cooooo0_l0000Uooooo`;obi^U00OonlN=om:JVooBVY_oeYfI
om2DUOo^/i3oi:ZG00;oc96G00Cod9>Eom2CToo=T9?ocI2C0_oLWY42omNITP05on:UTOoFV9?oeYRC
omjQT_o9SI@00_oFV9<00oo<T9CoeYVComJIT`02oljAT`03olN;U?oobg[oeYRC00;okk>=0_oQXi40
2_o=T9CoeiZColZ=U?o:SICodIBDo`001?o>TYCoah^Do`008Oo@Ti@2omJIU0?ohjJB0_onaX401?nn
Q9Go0015om6EUOoAUID2ook9P`05ol25UOnaNICo/GVDonFYTonVKi@00_n`Mi@01_nTKYCo^h2Dojie
U?n^MICoWf^DokElU0;oY6nE00?oWFZFojIaU_n^N9P00_n^MiH2oiATUP04ojIaV?naNiSo/G^Hoi1R
V@?oZGFI00CoUVJHoie/VOnMK9WoUfNH0_nFK:401?nIKYooVFjPoiU^X?n8Hj02oiU^X0;oOEjT00Co
OeJGoiYYVOnJJIWoJDJE0_n>HIT01?n2Figo=bB>ogaBU?mlDY@2ohQLV003ogU?U?mI=hkoICn?00;o
G3V=00KoJ46?of@oSomH>8ooICn?oeTgS_mB=8l2oe8cS@05oe0aS?m4:Xco>BbFod8WR_ll:8l00_lj
98`Wooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool003kooooo00?o0000
ooooooooool09?ooool2ofiDY005om:JVooFWIWok[>@onjcT?oTZYL00_o<TIL2om2CT`;ocI2C0_oL
WY42omNITP05on:UTOoFV9?oeYRComjQT_o9SI@00_oFV9<00oo<T9CoeYVComJIT`02oljAT`;oah^D
00OoeYRCol25U?oAU9?odIBCon6STOo=T9CoeiZC00;obXfD00SodIBDolR<U?o>TYCoah^Do`008Oo@
TiCo]7^DomJIU0?ohjJB0_onaX401?nnQ9Go/GVDom6EUOoAUID2ook9P`05ol25UOnaNICo/GVDok5i
U?nVKi@00_n`Mi@01?nTKYCo^h2DojieU?n^MI@2okElU0;oY6nE00?oWFZFojIaU_n^N9P00_n^MiH2
oiATUP05ojIaV?naNiSo/G^Hok5kV?n@HYT00_nYMIT01?nFIYSoWFbIoie/VOnGIiP2oiI/X@04oiU^
WonIKZ3oVFjPohQSX0;oVFjP0_mmGZ@01?n2Gj;oVVVIojF4/OmYAYD2ohiQV@04oh9KWOlg98koJDBB
ogaBU0;oR5bH00?o@b^>oeTgS_m:;8/00_mL>Hd01_mX@HooI3n?oePhSomH>8ooFCN>oe8dS`;oDS>=
00KoABf@od@ZS?li;9Ko@RN:oc`XSolj98`Yooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool003oooooo00?o0000ooooooooool09?ooool01?m^E:CoeYfIomJMVOo^/i02onBZ
U`;oc96G0_o@Ti<2olf@T`;og9jA00?oeiVBon:UTOoRYI400_oFV9<01OoNXI;oeYRComJHTooPXi;o
c92D00;oeYVC0_o>TI<2olN;U007omJHToo0QICodIBCom6DTooQXi7ocI2DomNJT`02olZ=U008om6D
U?o8S9CocY:DolN;U?l0027oah^DokAkU?oFVI@3on>VTP;oo/J100Co_XBEok5iU?oAUIGodIFE0_nh
OY@01Oo0QIGo/GVDok5iU?naNICoYVnD00;o/7ND00CoY6jDok^0U?n^MICo[WFD0_neO9@2ojA_U@03
oieZU_n^N9So[WRH00;o[WNF0_nDI9H01OnVLISo/G^Hok5kV?naNiSoT6:I00;oZGFI00CoUVJHoie/
VOnILJCoYGNO0_nFK:400onIKYooVFjPoiU^X004oiU^X005ogeNY?n2Gj;oYHBaojF4/Ol008L00_n>
HIT2oh9KW@07ofU4T_mlDYCoR5bHohQLV?m3:hkoFCN>odX/R`02oe`iS@06ofQ1SomT?hooF3R?oePh
SomI=hkoDSB?0_mB<hd01?m5;I3oA2Z<od@ZS?m29hX2oc`XSb[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`00@?ooool00ol0003oooooooooo`0Sooooo`04okE@BooFWIWo
eYfIo`0000;oi:ZG0_o<TIL01?o@Ti?ogZ6Colf@Too=T9<2ombNT@04omNIT_oRYI7ohZFAomJHT`;o
gZ6B0_oFV9<01_oPXi;oc92DomJITooFVI?ocY6Com^NT`;oah^D00CoeYRCol25U?oAU9?odIBC0_o=
T9@00ol001gobXfDolZ=U002olR<U0;oah^D00Go000QolN;U?ndNiCoeYVDokMmU002on>VTP;oo/J1
00Co_XBEokn4UOoAUIGodIFE0_nhOY@01OnZLYCo/GVDok5iU?naNICo^GnE00;o/7ND00CoY6jDok^0
U?n^MICo[WFD0_neO9@2ojA_U@03oieZU_n^N9So[WRH00;o[WNF0_nDI9H01OnQLYgo/G^Hok5kV?na
NiSoT6:I00;oZGFI00?oUVJHoiUaY?nILJ@00_nUMil2oiI/X@04oiU^WonIKZ3oVFjPohQSX0;oVFjP
00?oOEjToh9OX_nUQ;400_nUQ;42ohiQV@;oPU^M00_o=bB>ogaBU?n8G9SoR5bHod<[S_mI=hkoBRb;
ofDoSomL>HgoHSj@of@oS`02oePhS`05oeTgS_mB=8ooDSB?oe8cSOm5;I000_m4:X`00oli;9Ko?2R?
oc`XS`0[ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0047ooooo00?o
0000ooooooooool08_ooool01?neD4_oeYfIomJMVOl00002onBZU`;oc96G00Cod9>ComjQToo=T9?o
cI2C0_oLWY401?oGVI;ohZFAon:UTOoFV9<2omjQTP;oeYRC00Koh:>Bolb@U?oFVI?oeYVColjATooK
WY<2olN;U004omJHToo0QICodIBCom6DT`;ocI2D0oo:SI@2olR<U0;oah^D00Ko/WZEolN;U?ndNiCo
bHfDokMmU?oSYY83ok^0U003okj4UOnoQ9GodIFE00?o^7jD00GoZW:Dok5iU?naNICo/GVDokUoU@02
ok1gU004ojA^U?nkP9Co[WFDojieU0;o]GbD0_nTKiD00onQKiWo[WRHojihV002ojigUP03oiATU_nS
LI[oXG:M00?o/G^H00CoT6:IojUeVOnYMIWoUVJH0_nILJ@2ojEgW`;oUVbQ00CoVFjOoiU^X?nIKZ3o
R6>P0_nIKZ02ogeNY005oh9OX_nUQ;7oYHBaofU6UOn>HIT00_n2Fid02olg98koO5:DohQLV?n8G9So
@b^>oeTgS_m:;8_oICn?oe`iSOmR?Y3oI3n?00;oF3R?00CoB3BFoeTgS_mB=8ooDS>=0_m5;I000om4
:Xco>BbFoc`XS`0/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool004;o
oooo0_l0000Sooooo`04omJMVOl0003oZI6mojVA_@?oc96G00Cod9>ComjQTooNXI?ocI2C0_oLWY40
1?oGVI;ohZFAon:UTOoFV9<2omjQTP;oeYRC00Goh:>Bolb@U?oFVI?oeYVColjAT`02om^NT`03olN;
U?oFV9?o`8FD00;odIBC0_o=T9@3olZ=U0;ob8bD1?o7Ri@01?ndNiCobHfDolV=U?ngOI@3ok^0U0;o
_hBE00Go/GVDokQnU?nhOYCo^7jDokn4U@03ok5iU005okUoUOn`MiCo/7NDojA^U?nkP9@00_n^MI@2
okElU0;oY6nE00GoXFnIojihV?n^N9So[WRHojigUP02oj=aVP05oj5bWOnaNiSo/G^Hok5kV?n@HYT0
0_nYMIT2ojUkX0;oVG6T00CoYGNOoiI/XOnFK:7oVFjO0_nIKZ001_n8Hj3oVFjPoiU^X?ooooooOEjT
oh9OXP;oYHBa00Go0027ohiQVOooooooPU^MocLTSP02oiYbY007o`0X[om3:hkoFCN>odX/RomU?hoo
G3V=of8nT002of@oS`05oePhSom8=9KoFCN>oe8dSomB<hd00_m5;I000ooooooo>BbFooooo`0]oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00Oooool004Cooooo00?o0000oooooooo
ool08?ooool01?oFWIWo0000ojVA_OnYTKd3olbAU`07om2CTooNXI?ogZ6Colf@TooLWY7olkR=omNI
TP02on:UT@03omJHTooNXI;ogZ6B00;oeYRC00Goh:>Bolb@U?oFVI?oeYVColjAT`02om^NT`03olN;
U?oFV9?odIBC00;odIBC0_o=T9@3olZ=U0;ob8bD1?o7Ri@01?ndNiCobHfDolV=U?ngOI@3ok^0U0;o
_hBE00Go/GVDokQnU?nhOYCo^7jDokn4U@03ok5iU005okUoUOn`MiCo/7NDojA^U?nkP9@00_n^MI@2
okElU0;oY6nE00GoXFnIojihV?n^N9So[WRHojigUP02oj=aVP07oj5bWOnaNiSo/G^Hok5kV?n@HYWo
ZGFIokfCZ`02ojUkX0;oVG6T00GoYGNOoiI/XOnFK:7oVFjOoiU^X002ooooo`05oiU^X?oooooooooo
oooooon2Gj800_ooool01Ol008OojLRdoooooooooooo=bB>00;oVW:T00?ooooood<[S_lA2H800_m:
;8/01omL>HgoHSj@of@oSomT?hooF3R?odPdU_mI=hh00_mB=8l00om5;I3oooooooooo`0`ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00Oooool004Gooooo00?o0000ooooooooool0
7oooool01?oFWIWooooooiEh/?nEN;03olbAU`03om2CTooNXI?ogZ6C00;og9jA00GolkR=omNIT_oR
YI7ojZnAomJHT`02omjQTP;oeYRC00Goh:>BomJITooFVI?oeYVColjAT`02om^NT`03olN;U?oFV9?o
dIBC00;odIBC0_o=T9@3olZ=U0;ob8bD1?o7Ri@01?ndNiCobHfDolV=U?ngOI@3ok^0U0;o_hBE00Go
/GVDokQnU?nhOYCo^7jDokn4U@03ok5iU003okUoUOn`MiCo/7ND00;o^h2D0_n^MI@2okElU0;oY6nE
00GoXFnIojihV?n^N9So[WRHojigUP03oj=aVP04oj5bWOnaNiSo/G^Hoi1_ZP;o_I>[0_nYNj02oiUa
Y003ojEgWooooooooooo00cooooo00CojLRdoooooooooooo=bB>0_nJLZ@00ooooooo@b^>oa49PP02
odX/R`04oe`iSOmR?Y3oGd>Iof@oS`;oF3R?00?oB3BFoe8dSomB=8l0=?ooool01Ol0003ooooooooo
oooooooo000000?ooooo0016ooooo`03o`000?oooooooooo01kooooo00Co0000oooooonEN;3oUGR`
0_o<TIL01?oJXIWod9>ComjQTooNXI<2ombNT@05oo>hSOoGVI;ohZFAonZ_TOoFV9<00_oNXI82omJH
T`05on2ST_oFVI?oeYVCon>WToo>TI<00_oKWY<00oo7RiCoeYRCom6DT`02om6DT`;ocI2D0oo:SI@2
olR<U0Coah^D00Co]7^DolV=U?o9SICo]gfD0onkP9@2okn4U@04olF;U_nhOYCo^7jDokQnU0;o_hBE
0_naNI@2okUoU@05ok1gU?nkP9Co^h2Dok^0U?n^MI@00_neO9@2ojA_U@;oXFnI0_n^N9P01On^MiKo
Xg6Joj=aV_nSLI[oXG:M00;o/G^H0_n@KjX2okfCZ`04ojUkX?ooooooooooojEgWa;ooooo00Go=bB>
oiYbY?oooooooooood<[SP02odX/R`04oe`iSOmR?Y3oHSj@of@oS`;oF3R?00?oB3BFooooooooool0
=?ooool01Ol0003ooooooooooooooooo000000?ooooo0017ooooo`;o00008Oooool01OnEN;3oc96G
olbAUooJXIWod9>C00;ogZ6C0_oLWY401Ooc^8goeiVBon:UTOoZ[i7oeYRC00;ogZ6B0_oFV9<01OoP
Xi;oeYVComJITooSYi?ocY6C00;ofijC0_oFV9<3om6DT`;ocI2D0oo:SI@2olR<U0Coah^D0oo9SI@0
1?o<T9Go^h2Dok^0U?nkP9@2okn4U@04olF;U_nhOYCo^7jDokQnU0;o_hBE0_naNI@2okUoU@05ok1g
U?nkP9Co^h2Dok^0U?n^MI@00oneO9@00onTKiGoXFnIoj5_V@02ojihV006ojigU_nSLI[oXg6Joj=a
V_nQLYgo/G^H0_o__9`01?n@Kj[o_I>[okfCZonYNj0Eooooo`05ocLTS_oooooooooooooooom3:hh0
0_m:;8/01?mL>HgoHSj@of8nT?mO@iT2oePhS`03odPdU_oooooooooo03Gooooo00Co0000oooooooo
oooo00000oooool004Wooooo00?o0000ooooooooool07_ooool01OnEN;3oc96GolbAUooJXIWod9>C
00;ogZ6C0_oLWY401?oc^8gohZFAon:UTOoZ[i42omjQTP;ok[>A00KoeYRCon2ST_oFVI?oeYVCon>W
Too>TI<2om^NT`;oeYRC0ooAU9<2olf@U0?obXfD0_o8S9@4olN;U0?obHfD0_o<T9D2ok^0U0;o_hBE
00CoaH^FokQnU?nhOYCo^7jD0_noQ9D2ok5iU0;o^GnE00Go/7NDok^0U?nkP9Co^h2DojieU003okEl
U003okn6UonQKiWoXFnI00;o[WRH0_o@UiT2oj=aVP05oj5bWOnaNiSokkbLonnlW?n@KjX07?ooool0
1?m3:hkoFCN>odX/Rom?=982of8nT0;oGd>I>_ooool00ol0003oooooo`000003ooooo`00B_ooool0
0ol0003oooooooooo`0Mooooo`05oiEh/?o<TIOofZ6IomZQVOo@Ti<00_oNXI<2ombNT@04oo>hSOoR
YI7ohZFAonZ_T@;ogZ6B0_o^/i401_oFV9?oh:>BomJITooFVI?ohjNColjAT`;ofijC0_oFV9<3om6D
T`07olf@U?oRYYCobXfDolZ=U?oOXiCob8bDomjSU004olN;U0?obHfD0_o<T9D01?nkP9CodiRFokn4
UOnoQ9D2olF;UP;o^7jD0_noQ9D2ok5iU0;o^GnE00Go/7NDok^0U?nkP9Co^h2DojieU003okElU0;o
_hJG00?oXFnIojihV?n^N9P00_o@UiT2oj=aVP04oj5bWOnaNiSokkbLonnlW1gooooo00Ko@b^>oeTg
S_m:;8_oCcBBoe`iSOmR?Y02oem3VC[ooooo00Co0000oooooooooooo00000_ooool004_ooooo00?o
0000ooooooooool07?ooool01OnEN;3oc96GomZQVOoJXIWod9>C00;ogZ6C0_oLWY401?oc^8gohZFA
on:UTOoZ[i42omjQTP;ok[>A0_oPXi82omJIT`04on>WToo>TI?ofijCom^NT`;oeYRC0_oAU9<00ooW
[9?ocI2Don:VU002olZ=U003omnSU?o8S9CogZ>D00Coah^D0oo9SI@2olb@U@04ok^0U?oCV9Ko_hBE
okn4U@;oaH^F0_nhOY@2okn4U@;o/GVD0_niOiD01On`MiCo^h2Dok^0U?nkP9Co[WFD00?o]GbD0_no
QYL00onQKiWo[WRHojihV002om2GV@;oXg6J00CoooooonnlW?o__9cokkbL7_ooool01?lA2H;oBRb;
odldT_mL>Hd2of8nT003oem3VOoooooooooo03Wooooo00?o0000ooooool000000_ooool004cooooo
0_l0000Mooooo`04olbAUooJXIWofZ6Iom2CT`;ogZ6C00?og9jAoo>hSOoc^8d00_oRYI400ooZ[i7o
gZ6BomjQTP02onjcT@;oh:>B0_oFVI<01?oSYi?ofijCom^NTooKWY<2omJHT`;odIBC00[oijbColf@
U?oRYYCohZJDolZ=U?oOXiCob8bDomjSU?o7RiCohJFE0_o7Ri@3olV=U0;oc92E00Co^h2Dom>HU_no
Q9Go_hBE0_o5RiH2okQnU0;o_hBE00Go/GVDolZ@UoniOiGo^GnEok1gU003ok^0U004ojieU?neO9Co
]GbDokElU0;o_hJG00?oXFnIojihV?n^N9P00_o@UiT01OnSLI[oooooooooooooooookkbL01oooooo
00Co4@V2odX/Rom?=9;oG3V=0_mR?Y0mooooo`;o00000_ooool004kooooo00?o0000ooooooooool0
6_ooool00oo<TIOofZ6IomZQV@03omjQT`03ombNTOoc^8golkR=00;ohZFA00?ojZnAomjQT_oNXI80
0_o^/i401OoPXi;olKVComJITooFVI?ohjNC00?ofijC00KoeYRConnfT_oAU9?odIBConN/Too=T9@2
on:VU006olZ=U?oOXiCob8bDomjSU?o7RiCohJFE0_o7Ri@3olV=U0;oc92E00Co^h2Dom>HU_noQ9Go
_hBE0_o5RiH01_nhOYCodiVHokn4UOnoQ9Go/GVDolZ@U`;o^GnE00Go/7NDok^0U?nkP9Co^h2DolV=
U@03okElU0;o_hJG00?oXFnIojihV?nb]]`00_o@UiT00onSLI[oooooooooo`0Qooooo`04oa49P_m:
;8_oBRb;odldTP;oHSj@??ooool3o`0000;ooooo001?ooooo`03o`000?oooooooooo01Wooooo0ooJ
XIT3omjQT`03ombNTOoc^8golkR=00;ohZFA00?ojZnAomjQT_oNXI800_o^/i401OoPXi;olKVCoo6i
TooFVI?ohjNC00?ofijC00KoeYRConnfT_oAU9?odIBConN/Too=T9@2on:VU006olZ=U?oOXiCob8bD
omjSU?o7RiCohJFE0_o7Ri@3olV=U0;oc92E00Co^h2Dom>HU_noQ9Go_hBE0_o5RiH01_nhOYCodiVH
okn4UOnoQ9Go/GVDolZ@U`;o^GnE00Go/7NDok^0U?nkP9Co^h2DolV=U@03okElU0;o_hJG00?oXFnI
onCAa?nb]]`00_o@UiTUooooo`;oBRb;00?oCcBBof8nT?ooool0>?ooool4o`0000Gooooo001@oooo
o`03o`000?oooooooooo01Sooooo0ooJXIT2omjQT`03ookDMooLWY7olkR=00;omMU^00CojZnAookJ
P?onfX3ogZ6B0_o^/i401OoPXi;olKVCoo6iTooFVI?ohjNC00?ofijC00KoeYRConnfT_o_]Y;odIBC
onN/Too=T9@2on:VU005olZ=U?oOXiCob8bDomjSU?o7Ri@00_oQYID01?o7RiCobHfDolV=U?o9SI@2
olb@U@04ok^0U?oCV9Ko_hBEokn4U@;oaH^F00Ko^7jDom>IV?noQ9Go_hBEok5iU?o:T9L2okUoU@04
olR>UonkP9Co^h2Dok^0U0;obHfE0_neO9@2okn6U`03oj5_VOoTdLCo/[KL00;od9NI9_ooool00om:
;8_oCcBBodldTP0eooooo`Co00002Oooool0057ooooo0_l0000Hooooo`?ofZ6I0_oNXI<00oone7Oo
g9jAoo>hS@02ooGIKP03onZ_TOonfX3oo]Z000?ok[>A00?oh:>Boo6iTooa^I<00_oSYi<2om^NT`07
oo_7SOoFV9?okkJBonnfT_oAU9?oijbColf@U002on:VU005olZ=U?oOXiCob8bDomjSU?o7Ri@00_oQ
YID01?o7RiCobHfDolV=U?o9SI@2olb@U@04ok^0U?oCV9Ko_hBEon>[V0;oaH^F00Ko^7jDom>IV?no
Q9Go_hBEok5iU?o:T9L2okUoU@04olR>UonkP9Co^h2Dok^0U0;obHfE0_neO9@2okn6U`05o`000?oT
dLCooooook:fg?o@UiT09_ooool00om:;8_oCcBBooooo`0booooo`?o00003Oooool005?ooooo00?o
0000ooooooooool05_ooool2omZQV@;ogZ6C00?oo]AgombNTOoc^8d00_ooool00ooZ[i7oo]Z0ookJ
P002onjcT@04olc>DOoPXi;olKVCoo6iT`;ohjNC0_oKWY<01_okahgoeYRConnfT_o_]Y;odIBConN/
T`?ohZJD0_oOXi@2omjSU004olN;U?oQYIGohJFEolN;U0?obHfD0_o<T9D2om>HUP05okn4UOoSZiSo
aH^FolF;U_nhOY@00_oCVIP00onoQ9GobY2GolZ@U`02okUoU@04olR>UonkP9Co^h2Dok^0U0;obHfE
00Go]GbDonN[TonoQYOo_hJGo`000002ooooo`03ok:fg?oooooooooo02Gooooo00?oBRb;odldT_oo
ool0;_ooool4o`00013ooooo001Dooooo`03o`000?oooooooooo01Gooooo0_oJXIT2omjQT`03ookD
MooLWY7olkR=00;ooooo00?ojZnAookJP?ooool00_o^/i401?o<cU7oh:>Boo6iTooa^I<2on>WT`;o
fijC00ConlN=omJHToo_]Y;okkJB0_oW[9<3on:VU0;ogj>D0_oNXi@00oo7RiCohJFEon6UU@02onN]
U@04olV=U?og`I;oc92Eolb@U@;odiRF00Co_hBEon>[V?o5RiKoaH^F0ooCVIP00onoQ9GobY2GolZ@
U`02okUoU@04olR>UonkP9Co^h2Dok^0U0;obHfE00Go]GbDonN[TonoQYOo_hJGo`00000[ooooo`03
odldT_oooooooooo02Wooooo1?l0000Dooooo`00EOooool00ol0003oooooooooo`0Dooooo`03omZQ
VOoooooogZ6C00;oo]Ag0_oc^8d2ooooo`06ookJP?ooooooooooooooooo^/i7ooooo0ooa^I<2on>W
T`04onOFH?oKWY?onlN=omJHT`;okkJB0_oW[9<3on:VU0;ogj>D0_oNXi@3on6UU@;oijfE00CobHfD
ooO1T_o<T9Goc92E0_oCV9H01?noQ9Gohj^Hon>[V?o5RiH3om>IV003okn4UOo:T9OobY2G00;o^GnE
0_o8SYL2ok^0U0;obHfE00Co]GbDonN[TonoQYOo0000E?ooool4o`0001Sooooo001Fooooo`;o0000
5_ooool01?oNXI?oo]Agoooooooc^8d9ooooo`;olKVC00Koooooon>WTooWeV3oimIPom^NTookahd3
onnfTP;oijbC0ooRYY@2omnSU0;ogZ>D0ooQYID2onN]U@04olV=U?og`I;oc92Eolb@U@;odiRF00Co
_hBEon>[V?oSZiSoaH^F0ooCVIP00onoQ9GobY2GolZ@U`02okUoU@;ob8jG0_nkP9@2olV=U@03okEl
U?oWZi?o_hJG057ooooo1?l0000Looooo`00F?ooool00ol0003oooooooooo`0Cooooo`03omjQToon
e7Oooooo00kooooo00CoimIPoooooookahgonlN=0oo_]Y82onN/T`?ohZJD0_oOXi@2omjSU0?ohJFE
0_oW[ID01?o9SIComl6Bolb@UOo<T9D2om>HUP?ohj^H00GoaH^Fom>IV?oCVISodiVHokn4U@02olZ@
U`;o^GnE0_o8SYL2ok^0U0;obHfE00?o]GbDonN[TonoQYL0COooool4o`00023ooooo001Iooooo`03
o`000?oooooooooo01;ooooo00?ogZ6Cooooooooool04?ooool01?okahgoooooooooooo_]Y82oooo
o`08onN/TooooooohZJDoooooooOXiCoooooo`00>?oNXi@3on6UU@;oijfE00CobHfDooO1T_o<T9Go
gLiB0_oCV9H3on>[V005olF;U_oCVISodiVHom>IV?noQ9D00_o:T9L01?niOiGonm6KolR>Uoo8SYL2
ok^0U0;obHfE00?o]GbDonN[TonoQYL0B_ooool3o`0002Cooooo001Jooooo`03o`000?oooooooooo
017ooooo00?oo]Agooooooooool04?ooool00ol0003oooooooooo`05ooooo`07on:VU?oooooogj>D
ooooool003SogZ>Dooooo`02on6UU@;oijfE0_og`I801?o<T9GogLiBomg>D_oCV9H3on>[V004olF;
U_nk`3godiVHom>IV0;oomJ=00?obY2GokUoUOokdI/00_o8SYL01onkP9Coo<V<olV=UOo9SIGo]GbD
onN[TonoQYL0A_ooool4o`0002Oooooo001Kooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01oooool00ooOXiCoooooooooo`02ooooo`04on6UUOooooooooooonN]U@;oml6B00Goc92E
oooooooMcU;odiRFooooo`02on>[V004ok_0?OoooooodiVHom>IV0;oomJ=00OobY2GokUoUOokdI_o
nm6KolR>UonkP9Coo<V<00;obHfE0_oWZi=3ooooo`Co0000:oooool005cooooo0_l0000Sooooo`03
o`000?oooooooooo01Cooooo00?ogLiBom>HU_ooool00_oSZiP2ooooo`06om>IV?oooooooooooooF
SOo:T9Oooooo0_okdI/00oo8SYOo^h2Dooc9S002olV=U@;oij^C?oooool4o`0002oooooo001Noooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool01_o:T9OooooooooooookdI_o
b8jGok^0U0;oo<V<00?obHfEonN[TooWZi<0>oooool4o`0003?ooooo001Oooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool08_ooool00ookdI_ob8jGok^0U002ooc9S003olV=UOlb1FOo
ij^C03Oooooo1?l0000gooooo`00H?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02?ooooo00Gob8jGooc9S?olbHcoo<V<olV=U@0fooooo`?o0000>oooool0067ooooo0_l0000Noooo
o`03o`000?oooooooooo02Kooooo00?oo<V<olV=UOooool0<Oooool4o`0003kooooo001Sooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool09_ooool00oolbHcoooooooooo`0]ooooo`Co
0000@_ooool006Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Booooo`Co0000
A_ooool006Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`Co0000B_oo
ool006Kooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001>ooooo`00J?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo0ol0001Booooo`00JOooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo1?l0001Eooooo`00J_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l0001Iooooo`00Joooool2o`0001Cooooo00?o
0000ooooooooool0>oooool4o`0005gooooo001]ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0=oooool4o`00067ooooo001^ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0=?ooool3o`0006Gooooo001_ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0<?ooool4o`0006Sooooo001`ooooo`;o00003_ooool00ol0003oooooooooo`0]ooooo`Co0000
K?ooool007;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`Co0000L?oo
ool007?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`Co0000M?ooool0
07Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000N?ooool007Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`?o0000O?ooool007Kooooo
0_l00008ooooo`03o`000?oooooooooo01[ooooo1?l0001oooooo`00N?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Kooooo1?l00023ooooo`00NOooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01;ooooo1?l00027ooooo`00N_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00kooooo1?l0002;ooooo`00Noooool2o`0000?ooooo00?o0000oooooooo
ool02_ooool4o`0008oooooo001mooooo`04o`000?ooooooooooo`0000Wooooo0ol0002Cooooo`00
O_ooool00ol0003oooooo`000005ooooo`Co0000U_ooool007oooooo0_l000000ooooooo0000o`00
0002o`0009[ooooo0020ooooo`;o0000W_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool006Oooooo0ol0001Aooooo`?o0000H_ooool006Sooooo00?o0000ooooooooool0DOooool0
0ol0003oooooooooo`1Qooooo`00?Oooool3o`0000Cooooo0ol00002ooooo`Go000000Goooooo`00
0?l0003o0000ooooo`02o`0000;ooooo0_l00009ooooo`?o00000oooool3o`0000;ooooo0ol00004
ooooo`?o00000oooool4o`0000;ooooo1?l00007ooooo`Go000000Goooooo`000?l0003o0000oooo
o`02o`0000;ooooo0_l00003ooooo`?o00000_ooool3o`000003ooooool0003o000000Co00000_oo
ool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo00Oooooo0ol00005ooooo`;o000000?o
ooooo`000?l000000_l000001?oooooo0000o`000?ooool3o`0000Cooooo0_l00002ooooo`Go0000
0_ooool3o`0000;ooooo0ol000000ooooooo0000o`00000Yooooo`00?_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0006ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool0000Zooooo`00?_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo1Ol00002ooooo`?o00000_ooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000002Oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool0:?ooool003kooooo0ol00002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool02_ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`00
00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01_l0
003oooooooooool0003oooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Wooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
:?ooool003kooooo00Co0000oooooooooooo00000_ooool3o`0000;ooooo0ol00003ooooo`Co0000
0_ooool4o`0000Wooooo00?o0000ooooooooool00_ooool4o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`?o00000oooool2o`0000Cooooo0ol0000:ooooo`04o`000?ooooooooooooooo`Co
00000_ooool4o`0000?ooooo0ol00002ooooo`Co00000oooool4o`000004ooooool0003o0000o`00
00?ooooo1?l00002ooooo`;o000000?oooooo`000?l000002?ooool00ol0003oooooooooo`02oooo
o`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`?o00000_ooool4o`0000;ooooo0ol00004
ooooo`?o00000_ooool4o`0002_ooooo000nooooo`04o`000?ooooooooooo`0001Cooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooo00005?ooool00ol0003oooooooooo`0mooooo`00?Oooool4o`0000[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`?o00006oooool2o`0000Sooooo1Ol0
0008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0>ooooo`Go00005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0897167, 0.0484211, \
0.00365545, 0.00365545}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -117 0 ]
[.5 .82364 117 9 ]
[.13778 .20281 -23.9157 -9 ]
[.13778 .20281 .08425 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.54696 .04189 -15.5834 -9 ]
[.54696 .04189 2.41661 0 ]
[.76317 .09047 0 -6.16825 ]
[.76317 .09047 24 2.83175 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93807 .35831 0 -5.91508 ]
[.93807 .35831 18 3.08492 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01415 .32758 -24 -2.79515 ]
[.01415 .32758 0 6.20485 ]
[.00377 .39263 -18 -2.85039 ]
[.00377 .39263 0 6.14961 ]
[-0.00705 .46043 -24 -2.90822 ]
[-0.00705 .46043 0 6.09178 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Perfect Point Spread Intensity Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.14703 .21212 m
.15165 .21677 L
s
[(-0.1)] .13778 .20281 .99298 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.55471 .05248 m
.55858 .05778 L
s
[(0.1)] .54696 .04189 .73149 1 Mshowa
.125 Mabswid
.18507 .19722 m
.18781 .20005 L
s
.22368 .1821 m
.22638 .18497 L
s
.26288 .16675 m
.26553 .16966 L
s
.30267 .15117 m
.30528 .15412 L
s
.38409 .11929 m
.38661 .12231 L
s
.42575 .10298 m
.42822 .10604 L
s
.46806 .08641 m
.47049 .08951 L
s
.51104 .06958 m
.51342 .07272 L
s
.10954 .2268 m
.11235 .22955 L
s
.0726 .24126 m
.07544 .24398 L
s
.59907 .03511 m
.60134 .03833 L
s
.64416 .01746 m
.64637 .02071 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75086 .09503 m
.74471 .09732 L
s
[(-0.1)] .76317 .09047 -1 .37072 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92555 .36224 m
.91929 .36421 L
s
[(0.1)] .93807 .35831 -1 .31446 Mshowa
.125 Mabswid
.77057 .12517 m
.76687 .12652 L
s
.78971 .15446 m
.78601 .15579 L
s
.80833 .18294 m
.80462 .18425 L
s
.82645 .21065 m
.82273 .21194 L
s
.86123 .26386 m
.8575 .26511 L
s
.87794 .28942 m
.87421 .29065 L
s
.89422 .31432 m
.89048 .31554 L
s
.91009 .33859 m
.90634 .33979 L
s
.73059 .06402 m
.72691 .06541 L
s
.70971 .03208 m
.70604 .0335 L
s
.94063 .38531 m
.93687 .38648 L
s
.95534 .40781 m
.95158 .40896 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02642 .32293 m
.03255 .3206 L
s
[(0.05)] .01415 .32758 1 -0.37886 Mshowa
.01609 .38811 m
.02225 .38585 L
s
[(0.1)] .00377 .39263 1 -0.36658 Mshowa
.00532 .45606 m
.01151 .45387 L
s
[(0.15)] -0.00705 .46043 1 -0.35373 Mshowa
.125 Mabswid
.03438 .27265 m
.03805 .27123 L
s
.03242 .28507 m
.03609 .28365 L
s
.03043 .29759 m
.03411 .29618 L
s
.02843 .31021 m
.03211 .3088 L
s
.02439 .33575 m
.02807 .33436 L
s
.02234 .34868 m
.02602 .3473 L
s
.02027 .36172 m
.02396 .36035 L
s
.01819 .37486 m
.02188 .3735 L
s
.01397 .40148 m
.01767 .40013 L
s
.01183 .41495 m
.01554 .41361 L
s
.00968 .42854 m
.01339 .42721 L
s
.00751 .44224 m
.01122 .44092 L
s
.00311 .46999 m
.00683 .46869 L
s
.00088 .48405 m
.0046 .48275 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.40204 .60085 .40512 .60371 .41029 .60216 .40722 .59929 Mtetra
.40722 .59929 .41029 .60216 .41547 .60061 .41241 .59773 Mtetra
.41241 .59773 .41547 .60061 .42066 .59905 .4176 .59617 Mtetra
.4176 .59617 .42066 .59905 .42586 .59749 .42281 .5946 Mtetra
.42281 .5946 .42586 .59749 .43107 .59593 .42802 .59304 Mtetra
.42802 .59304 .43107 .59593 .43629 .59436 .43325 .59147 Mtetra
.43325 .59147 .43629 .59436 .44151 .5928 .43848 .58989 Mtetra
.43848 .58989 .44151 .5928 .44675 .59122 .44373 .58831 Mtetra
.44373 .58831 .44675 .59122 .452 .58965 .44898 .58673 Mtetra
.44898 .58673 .452 .58965 .45726 .58807 .45425 .58515 Mtetra
.45425 .58515 .45726 .58807 .46253 .58649 .45952 .58356 Mtetra
.45952 .58356 .46253 .58649 .46781 .58491 .46481 .58197 Mtetra
.46481 .58197 .46781 .58491 .4731 .58332 .47011 .58038 Mtetra
.47011 .58038 .4731 .58332 .4784 .58173 .47541 .57879 Mtetra
.47541 .57879 .4784 .58173 .48371 .58014 .48073 .57719 Mtetra
.48073 .57719 .48371 .58014 .48903 .57854 .48606 .57558 Mtetra
.48606 .57558 .48903 .57854 .49437 .57694 .4914 .57398 Mtetra
.4914 .57398 .49437 .57694 .49971 .57534 .49675 .57237 Mtetra
.49675 .57237 .49971 .57534 .50506 .57373 .50211 .57076 Mtetra
.50211 .57076 .50506 .57373 .51042 .57212 .50748 .56914 Mtetra
.50748 .56914 .51042 .57212 .5158 .57051 .51286 .56753 Mtetra
.51286 .56753 .5158 .57051 .52118 .5689 .51825 .56591 Mtetra
.51825 .56591 .52118 .5689 .52657 .56728 .52365 .56428 Mtetra
.52365 .56428 .52657 .56728 .53198 .56566 .52906 .56265 Mtetra
.52906 .56265 .53198 .56566 .53739 .56403 .53448 .56102 Mtetra
.53448 .56102 .53739 .56403 .54282 .5624 .53992 .55939 Mtetra
.53992 .55939 .54282 .5624 .54826 .56077 .54536 .55775 Mtetra
.54536 .55775 .54826 .56077 .55371 .55914 .55081 .55611 Mtetra
.55081 .55611 .55371 .55914 .55916 .5575 .55628 .55447 Mtetra
.55628 .55447 .55916 .5575 .56463 .55586 .56176 .55282 Mtetra
.56176 .55282 .56463 .55586 .57011 .55422 .56724 .55117 Mtetra
.56724 .55117 .57011 .55422 .5756 .55257 .57274 .54952 Mtetra
.57274 .54952 .5756 .55257 .58111 .55092 .57825 .54786 Mtetra
.57825 .54786 .58111 .55092 .58662 .54926 .58377 .5462 Mtetra
.58377 .5462 .58662 .54926 .59214 .54761 .5893 .54454 Mtetra
.5893 .54454 .59214 .54761 .59768 .54595 .59484 .54287 Mtetra
.59484 .54287 .59768 .54595 .60322 .54428 .6004 .5412 Mtetra
.6004 .5412 .60322 .54428 .60878 .54262 .60596 .53953 Mtetra
.60596 .53953 .60878 .54262 .61435 .54095 .61154 .53785 Mtetra
.61154 .53785 .61435 .54095 .61993 .53927 .61712 .53617 Mtetra
.61712 .53617 .61993 .53927 .62552 .53759 .62272 .53449 Mtetra
.62272 .53449 .62552 .53759 .63112 .53591 .62833 .5328 Mtetra
.62833 .5328 .63112 .53591 .63673 .53423 .63395 .53111 Mtetra
.63395 .53111 .63673 .53423 .64235 .53254 .63958 .52942 Mtetra
.63958 .52942 .64235 .53254 .64799 .53085 .64522 .52772 Mtetra
.64522 .52772 .64799 .53085 .65364 .52916 .65088 .52602 Mtetra
.65088 .52602 .65364 .52916 .65929 .52746 .65654 .52432 Mtetra
.663 .741 .908 r
.65654 .52432 .65929 .52746 .66496 .52576 .66222 .52261 Mtetra
.66222 .52261 .66496 .52576 .67064 .52407 .66791 .52092 Mtetra
.664 .741 .908 r
.66791 .52092 .67064 .52407 .67634 .52236 .67361 .5192 Mtetra
.664 .742 .908 r
.67361 .5192 .67634 .52236 .68204 .52064 .67932 .51747 Mtetra
.664 .741 .908 r
.67932 .51747 .68204 .52064 .68775 .51892 .68504 .51575 Mtetra
.68504 .51575 .68775 .51892 .69348 .51721 .69078 .51403 Mtetra
.69078 .51403 .69348 .51721 .69922 .51548 .69652 .5123 Mtetra
.69652 .5123 .69922 .51548 .70497 .51376 .70228 .51057 Mtetra
.70228 .51057 .70497 .51376 .71073 .51203 .70805 .50883 Mtetra
.70805 .50883 .71073 .51203 .7165 .5103 .71383 .50709 Mtetra
.71383 .50709 .7165 .5103 .72229 .50856 .71962 .50535 Mtetra
.71962 .50535 .72229 .50856 .72808 .50682 .72543 .50361 Mtetra
.72543 .50361 .72808 .50682 .73389 .50508 .73125 .50186 Mtetra
.73125 .50186 .73389 .50508 .73971 .50334 .73707 .5001 Mtetra
.73707 .5001 .73971 .50334 .74554 .50159 .74292 .49835 Mtetra
.74292 .49835 .74554 .50159 .75139 .49983 .74877 .49659 Mtetra
.74877 .49659 .75139 .49983 .75724 .49808 .75463 .49482 Mtetra
.75463 .49482 .75724 .49808 .76311 .49632 .76051 .49306 Mtetra
.76051 .49306 .76311 .49632 .76899 .49455 .7664 .49129 Mtetra
.7664 .49129 .76899 .49455 .77488 .49278 .7723 .48951 Mtetra
.7723 .48951 .77488 .49278 .78079 .49101 .77821 .48773 Mtetra
.77821 .48773 .78079 .49101 .78671 .48924 .78414 .48595 Mtetra
.78414 .48595 .78671 .48924 .79263 .48746 .79007 .48417 Mtetra
.79007 .48417 .79263 .48746 .79857 .48568 .79602 .48238 Mtetra
.79602 .48238 .79857 .48568 .80453 .48389 .80198 .48059 Mtetra
.80198 .48059 .80453 .48389 .81049 .4821 .80796 .47879 Mtetra
.80796 .47879 .81049 .4821 .81647 .48031 .81394 .47699 Mtetra
.81394 .47699 .81647 .48031 .82246 .47851 .81994 .47518 Mtetra
.81994 .47518 .82246 .47851 .82846 .47671 .82595 .47338 Mtetra
.82595 .47338 .82846 .47671 .83448 .47491 .83198 .47157 Mtetra
.83198 .47157 .83448 .47491 .8405 .4731 .83801 .46975 Mtetra
.83801 .46975 .8405 .4731 .84654 .47129 .84406 .46793 Mtetra
.84406 .46793 .84654 .47129 .8526 .46947 .85012 .46611 Mtetra
.85012 .46611 .8526 .46947 .85866 .46765 .8562 .46428 Mtetra
.8562 .46428 .85866 .46765 .86474 .46583 .86228 .46245 Mtetra
.86228 .46245 .86474 .46583 .87083 .464 .86838 .46062 Mtetra
.86838 .46062 .87083 .464 .87693 .46217 .8745 .45878 Mtetra
.8745 .45878 .87693 .46217 .88305 .46034 .88062 .45694 Mtetra
.88062 .45694 .88305 .46034 .88918 .4585 .88676 .45509 Mtetra
.88676 .45509 .88918 .4585 .89532 .45665 .89291 .45324 Mtetra
.89291 .45324 .89532 .45665 .90147 .45481 .89907 .45139 Mtetra
.89907 .45139 .90147 .45481 .90764 .45296 .90525 .44953 Mtetra
.90525 .44953 .90764 .45296 .91382 .4511 .91144 .44767 Mtetra
.91144 .44767 .91382 .4511 .92001 .44925 .91764 .44581 Mtetra
.91764 .44581 .92001 .44925 .92622 .44738 .92386 .44394 Mtetra
.92386 .44394 .92622 .44738 .93244 .44552 .93009 .44206 Mtetra
.93009 .44206 .93244 .44552 .93867 .44365 .93633 .44019 Mtetra
.93633 .44019 .93867 .44365 .94492 .44178 .94258 .43831 Mtetra
.94258 .43831 .94492 .44178 .95118 .4399 .94885 .43642 Mtetra
.94885 .43642 .95118 .4399 .95745 .43802 .95514 .43453 Mtetra
.95514 .43453 .95745 .43802 .96373 .43613 .96143 .43264 Mtetra
.96143 .43264 .96373 .43613 .97003 .43424 .96774 .43074 Mtetra
.39896 .59797 .40204 .60085 .40722 .59929 .40414 .59641 Mtetra
.40414 .59641 .40722 .59929 .41241 .59773 .40933 .59485 Mtetra
.40933 .59485 .41241 .59773 .4176 .59617 .41453 .59328 Mtetra
.41453 .59328 .4176 .59617 .42281 .5946 .41974 .59171 Mtetra
.41974 .59171 .42281 .5946 .42802 .59304 .42496 .59013 Mtetra
.42496 .59013 .42802 .59304 .43325 .59147 .4302 .58856 Mtetra
.4302 .58856 .43325 .59147 .43848 .58989 .43544 .58698 Mtetra
.43544 .58698 .43848 .58989 .44373 .58831 .44069 .58539 Mtetra
.44069 .58539 .44373 .58831 .44898 .58673 .44595 .58381 Mtetra
.44595 .58381 .44898 .58673 .45425 .58515 .45122 .58222 Mtetra
.45122 .58222 .45425 .58515 .45952 .58356 .45651 .58063 Mtetra
.45651 .58063 .45952 .58356 .46481 .58197 .4618 .57903 Mtetra
.4618 .57903 .46481 .58197 .47011 .58038 .4671 .57743 Mtetra
.4671 .57743 .47011 .58038 .47541 .57879 .47242 .57583 Mtetra
.47242 .57583 .47541 .57879 .48073 .57719 .47774 .57423 Mtetra
.47774 .57423 .48073 .57719 .48606 .57558 .48308 .57262 Mtetra
.48308 .57262 .48606 .57558 .4914 .57398 .48842 .57101 Mtetra
.48842 .57101 .4914 .57398 .49675 .57237 .49378 .56939 Mtetra
.49378 .56939 .49675 .57237 .50211 .57076 .49914 .56778 Mtetra
.49914 .56778 .50211 .57076 .50748 .56914 .50452 .56616 Mtetra
.50452 .56616 .50748 .56914 .51286 .56753 .5099 .56453 Mtetra
.5099 .56453 .51286 .56753 .51825 .56591 .5153 .5629 Mtetra
.5153 .5629 .51825 .56591 .52365 .56428 .52071 .56127 Mtetra
.52071 .56127 .52365 .56428 .52906 .56265 .52613 .55964 Mtetra
.52613 .55964 .52906 .56265 .53448 .56102 .53156 .558 Mtetra
.53156 .558 .53448 .56102 .53992 .55939 .537 .55636 Mtetra
.537 .55636 .53992 .55939 .54536 .55775 .54245 .55472 Mtetra
.54245 .55472 .54536 .55775 .55081 .55611 .54791 .55308 Mtetra
.54791 .55308 .55081 .55611 .55628 .55447 .55339 .55143 Mtetra
.55339 .55143 .55628 .55447 .56176 .55282 .55887 .54977 Mtetra
.55887 .54977 .56176 .55282 .56724 .55117 .56436 .54812 Mtetra
.56436 .54812 .56724 .55117 .57274 .54952 .56987 .54646 Mtetra
.56987 .54646 .57274 .54952 .57825 .54786 .57539 .54479 Mtetra
.57539 .54479 .57825 .54786 .58377 .5462 .58091 .54313 Mtetra
.58091 .54313 .58377 .5462 .5893 .54454 .58645 .54146 Mtetra
.58645 .54146 .5893 .54454 .59484 .54287 .592 .53979 Mtetra
.592 .53979 .59484 .54287 .6004 .5412 .59756 .53811 Mtetra
.59756 .53811 .6004 .5412 .60596 .53953 .60313 .53643 Mtetra
.60313 .53643 .60596 .53953 .61154 .53785 .60872 .53475 Mtetra
.60872 .53475 .61154 .53785 .61712 .53617 .61431 .53306 Mtetra
.61431 .53306 .61712 .53617 .62272 .53449 .61991 .53137 Mtetra
.61991 .53137 .62272 .53449 .62833 .5328 .62553 .52968 Mtetra
.62553 .52968 .62833 .5328 .63395 .53111 .63116 .52798 Mtetra
.63116 .52798 .63395 .53111 .63958 .52942 .6368 .52628 Mtetra
.6368 .52628 .63958 .52942 .64522 .52772 .64245 .52458 Mtetra
.64245 .52458 .64522 .52772 .65088 .52602 .64811 .52288 Mtetra
.64811 .52288 .65088 .52602 .65654 .52432 .65378 .52117 Mtetra
.663 .741 .908 r
.65378 .52117 .65654 .52432 .66222 .52261 .65947 .51945 Mtetra
.65947 .51945 .66222 .52261 .66791 .52092 .66516 .51775 Mtetra
.664 .741 .908 r
.66516 .51775 .66791 .52092 .67361 .5192 .67087 .51603 Mtetra
.665 .742 .908 r
.67087 .51603 .67361 .5192 .67932 .51747 .67659 .51429 Mtetra
.664 .741 .908 r
.67659 .51429 .67932 .51747 .68504 .51575 .68232 .51256 Mtetra
.68232 .51256 .68504 .51575 .69078 .51403 .68806 .51083 Mtetra
.68806 .51083 .69078 .51403 .69652 .5123 .69382 .5091 Mtetra
.69382 .5091 .69652 .5123 .70228 .51057 .69958 .50736 Mtetra
.69958 .50736 .70228 .51057 .70805 .50883 .70536 .50562 Mtetra
.70536 .50562 .70805 .50883 .71383 .50709 .71115 .50387 Mtetra
.71115 .50387 .71383 .50709 .71962 .50535 .71695 .50213 Mtetra
.71695 .50213 .71962 .50535 .72543 .50361 .72276 .50037 Mtetra
.72276 .50037 .72543 .50361 .73125 .50186 .72859 .49862 Mtetra
.72859 .49862 .73125 .50186 .73707 .5001 .73443 .49686 Mtetra
.73443 .49686 .73707 .5001 .74292 .49835 .74028 .4951 Mtetra
.74028 .4951 .74292 .49835 .74877 .49659 .74614 .49333 Mtetra
.74614 .49333 .74877 .49659 .75463 .49482 .75201 .49156 Mtetra
.75201 .49156 .75463 .49482 .76051 .49306 .75789 .48978 Mtetra
.75789 .48978 .76051 .49306 .7664 .49129 .76379 .48801 Mtetra
.76379 .48801 .7664 .49129 .7723 .48951 .7697 .48623 Mtetra
.7697 .48623 .7723 .48951 .77821 .48773 .77562 .48444 Mtetra
.77562 .48444 .77821 .48773 .78414 .48595 .78156 .48265 Mtetra
.78156 .48265 .78414 .48595 .79007 .48417 .7875 .48086 Mtetra
.7875 .48086 .79007 .48417 .79602 .48238 .79346 .47907 Mtetra
.79346 .47907 .79602 .48238 .80198 .48059 .79943 .47727 Mtetra
.79943 .47727 .80198 .48059 .80796 .47879 .80541 .47546 Mtetra
.80541 .47546 .80796 .47879 .81394 .47699 .81141 .47366 Mtetra
.81141 .47366 .81394 .47699 .81994 .47518 .81742 .47184 Mtetra
.81742 .47184 .81994 .47518 .82595 .47338 .82344 .47003 Mtetra
.82344 .47003 .82595 .47338 .83198 .47157 .82947 .46821 Mtetra
.82947 .46821 .83198 .47157 .83801 .46975 .83551 .46639 Mtetra
.83551 .46639 .83801 .46975 .84406 .46793 .84157 .46456 Mtetra
.84157 .46456 .84406 .46793 .85012 .46611 .84764 .46273 Mtetra
.84764 .46273 .85012 .46611 .8562 .46428 .85372 .4609 Mtetra
.85372 .4609 .8562 .46428 .86228 .46245 .85982 .45906 Mtetra
.85982 .45906 .86228 .46245 .86838 .46062 .86593 .45722 Mtetra
.86593 .45722 .86838 .46062 .8745 .45878 .87205 .45538 Mtetra
.87205 .45538 .8745 .45878 .88062 .45694 .87819 .45353 Mtetra
.87819 .45353 .88062 .45694 .88676 .45509 .88433 .45168 Mtetra
.88433 .45168 .88676 .45509 .89291 .45324 .89049 .44982 Mtetra
.89049 .44982 .89291 .45324 .89907 .45139 .89667 .44796 Mtetra
.89667 .44796 .89907 .45139 .90525 .44953 .90285 .44609 Mtetra
.90285 .44609 .90525 .44953 .91144 .44767 .90905 .44422 Mtetra
.90905 .44422 .91144 .44767 .91764 .44581 .91526 .44235 Mtetra
.91526 .44235 .91764 .44581 .92386 .44394 .92149 .44048 Mtetra
.92149 .44048 .92386 .44394 .93009 .44206 .92773 .4386 Mtetra
.92773 .4386 .93009 .44206 .93633 .44019 .93398 .43671 Mtetra
.93398 .43671 .93633 .44019 .94258 .43831 .94024 .43482 Mtetra
.94024 .43482 .94258 .43831 .94885 .43642 .94652 .43293 Mtetra
.94652 .43293 .94885 .43642 .95514 .43453 .95281 .43103 Mtetra
.95281 .43103 .95514 .43453 .96143 .43264 .95912 .42913 Mtetra
.95912 .42913 .96143 .43264 .96774 .43074 .96544 .42723 Mtetra
.39586 .59509 .39896 .59797 .40414 .59641 .40105 .59352 Mtetra
.40105 .59352 .40414 .59641 .40933 .59485 .40624 .59195 Mtetra
.40624 .59195 .40933 .59485 .41453 .59328 .41145 .59038 Mtetra
.41145 .59038 .41453 .59328 .41974 .59171 .41667 .5888 Mtetra
.41667 .5888 .41974 .59171 .42496 .59013 .4219 .58722 Mtetra
.4219 .58722 .42496 .59013 .4302 .58856 .42713 .58564 Mtetra
.42713 .58564 .4302 .58856 .43544 .58698 .43238 .58405 Mtetra
.43238 .58405 .43544 .58698 .44069 .58539 .43764 .58246 Mtetra
.43764 .58246 .44069 .58539 .44595 .58381 .44291 .58087 Mtetra
.44291 .58087 .44595 .58381 .45122 .58222 .44819 .57928 Mtetra
.44819 .57928 .45122 .58222 .45651 .58063 .45348 .57768 Mtetra
.45348 .57768 .45651 .58063 .4618 .57903 .45878 .57608 Mtetra
.45878 .57608 .4618 .57903 .4671 .57743 .46409 .57447 Mtetra
.46409 .57447 .4671 .57743 .47242 .57583 .46941 .57287 Mtetra
.46941 .57287 .47242 .57583 .47774 .57423 .47474 .57126 Mtetra
.47474 .57126 .47774 .57423 .48308 .57262 .48008 .56964 Mtetra
.48008 .56964 .48308 .57262 .48842 .57101 .48543 .56802 Mtetra
.48543 .56802 .48842 .57101 .49378 .56939 .49079 .5664 Mtetra
.49079 .5664 .49378 .56939 .49914 .56778 .49617 .56478 Mtetra
.49617 .56478 .49914 .56778 .50452 .56616 .50155 .56316 Mtetra
.50155 .56316 .50452 .56616 .5099 .56453 .50694 .56153 Mtetra
.50694 .56153 .5099 .56453 .5153 .5629 .51235 .55989 Mtetra
.51235 .55989 .5153 .5629 .52071 .56127 .51776 .55826 Mtetra
.51776 .55826 .52071 .56127 .52613 .55964 .52319 .55662 Mtetra
.52319 .55662 .52613 .55964 .53156 .558 .52863 .55497 Mtetra
.52863 .55497 .53156 .558 .537 .55636 .53407 .55333 Mtetra
.53407 .55333 .537 .55636 .54245 .55472 .53953 .55168 Mtetra
.53953 .55168 .54245 .55472 .54791 .55308 .545 .55003 Mtetra
.545 .55003 .54791 .55308 .55339 .55143 .55048 .54837 Mtetra
.55048 .54837 .55339 .55143 .55887 .54977 .55597 .54671 Mtetra
.55597 .54671 .55887 .54977 .56436 .54812 .56147 .54505 Mtetra
.56147 .54505 .56436 .54812 .56987 .54646 .56699 .54339 Mtetra
.56699 .54339 .56987 .54646 .57539 .54479 .57251 .54172 Mtetra
.57251 .54172 .57539 .54479 .58091 .54313 .57804 .54004 Mtetra
.57804 .54004 .58091 .54313 .58645 .54146 .58359 .53837 Mtetra
.58359 .53837 .58645 .54146 .592 .53979 .58915 .53669 Mtetra
.58915 .53669 .592 .53979 .59756 .53811 .59471 .53501 Mtetra
.59471 .53501 .59756 .53811 .60313 .53643 .60029 .53332 Mtetra
.60029 .53332 .60313 .53643 .60872 .53475 .60588 .53163 Mtetra
.60588 .53163 .60872 .53475 .61431 .53306 .61148 .52994 Mtetra
.61148 .52994 .61431 .53306 .61991 .53137 .6171 .52825 Mtetra
.6171 .52825 .61991 .53137 .62553 .52968 .62272 .52655 Mtetra
.62272 .52655 .62553 .52968 .63116 .52798 .62836 .52484 Mtetra
.62836 .52484 .63116 .52798 .6368 .52628 .634 .52314 Mtetra
.634 .52314 .6368 .52628 .64245 .52458 .63966 .52143 Mtetra
.63966 .52143 .64245 .52458 .64811 .52288 .64533 .51972 Mtetra
.64533 .51972 .64811 .52288 .65378 .52117 .65101 .518 Mtetra
.663 .741 .908 r
.65101 .518 .65378 .52117 .65947 .51945 .6567 .51628 Mtetra
.6567 .51628 .65947 .51945 .66516 .51775 .66241 .51457 Mtetra
.664 .741 .908 r
.66241 .51457 .66516 .51775 .67087 .51603 .66812 .51285 Mtetra
.665 .742 .908 r
.66812 .51285 .67087 .51603 .67659 .51429 .67385 .5111 Mtetra
.664 .741 .908 r
.67385 .5111 .67659 .51429 .68232 .51256 .67959 .50937 Mtetra
.67959 .50937 .68232 .51256 .68806 .51083 .68534 .50763 Mtetra
.68534 .50763 .68806 .51083 .69382 .5091 .6911 .50589 Mtetra
.6911 .50589 .69382 .5091 .69958 .50736 .69688 .50414 Mtetra
.69688 .50414 .69958 .50736 .70536 .50562 .70266 .50239 Mtetra
.70266 .50239 .70536 .50562 .71115 .50387 .70846 .50064 Mtetra
.70846 .50064 .71115 .50387 .71695 .50213 .71427 .49889 Mtetra
.71427 .49889 .71695 .50213 .72276 .50037 .72009 .49713 Mtetra
.72009 .49713 .72276 .50037 .72859 .49862 .72592 .49537 Mtetra
.72592 .49537 .72859 .49862 .73443 .49686 .73177 .4936 Mtetra
.73177 .4936 .73443 .49686 .74028 .4951 .73763 .49183 Mtetra
.73763 .49183 .74028 .4951 .74614 .49333 .7435 .49006 Mtetra
.7435 .49006 .74614 .49333 .75201 .49156 .74938 .48828 Mtetra
.74938 .48828 .75201 .49156 .75789 .48978 .75527 .4865 Mtetra
.75527 .4865 .75789 .48978 .76379 .48801 .76118 .48472 Mtetra
.76118 .48472 .76379 .48801 .7697 .48623 .76709 .48293 Mtetra
.76709 .48293 .7697 .48623 .77562 .48444 .77302 .48114 Mtetra
.77302 .48114 .77562 .48444 .78156 .48265 .77897 .47934 Mtetra
.77897 .47934 .78156 .48265 .7875 .48086 .78492 .47754 Mtetra
.78492 .47754 .7875 .48086 .79346 .47907 .79089 .47574 Mtetra
.79089 .47574 .79346 .47907 .79943 .47727 .79687 .47393 Mtetra
.79687 .47393 .79943 .47727 .80541 .47546 .80286 .47212 Mtetra
.80286 .47212 .80541 .47546 .81141 .47366 .80886 .47031 Mtetra
.80886 .47031 .81141 .47366 .81742 .47184 .81488 .46849 Mtetra
.81488 .46849 .81742 .47184 .82344 .47003 .82091 .46667 Mtetra
.82091 .46667 .82344 .47003 .82947 .46821 .82695 .46484 Mtetra
.82695 .46484 .82947 .46821 .83551 .46639 .833 .46302 Mtetra
.833 .46302 .83551 .46639 .84157 .46456 .83907 .46118 Mtetra
.83907 .46118 .84157 .46456 .84764 .46273 .84515 .45935 Mtetra
.84515 .45935 .84764 .46273 .85372 .4609 .85124 .45751 Mtetra
.85124 .45751 .85372 .4609 .85982 .45906 .85735 .45566 Mtetra
.85735 .45566 .85982 .45906 .86593 .45722 .86346 .45381 Mtetra
.86346 .45381 .86593 .45722 .87205 .45538 .8696 .45196 Mtetra
.8696 .45196 .87205 .45538 .87819 .45353 .87574 .4501 Mtetra
.87574 .4501 .87819 .45353 .88433 .45168 .8819 .44824 Mtetra
.8819 .44824 .88433 .45168 .89049 .44982 .88807 .44638 Mtetra
.88807 .44638 .89049 .44982 .89667 .44796 .89425 .44451 Mtetra
.89425 .44451 .89667 .44796 .90285 .44609 .90044 .44264 Mtetra
.90044 .44264 .90285 .44609 .90905 .44422 .90665 .44076 Mtetra
.90665 .44076 .90905 .44422 .91526 .44235 .91287 .43888 Mtetra
.91287 .43888 .91526 .44235 .92149 .44048 .91911 .437 Mtetra
.91911 .437 .92149 .44048 .92773 .4386 .92536 .43511 Mtetra
.92536 .43511 .92773 .4386 .93398 .43671 .93162 .43322 Mtetra
.93162 .43322 .93398 .43671 .94024 .43482 .93789 .43133 Mtetra
.93789 .43133 .94024 .43482 .94652 .43293 .94418 .42943 Mtetra
.94418 .42943 .94652 .43293 .95281 .43103 .95048 .42752 Mtetra
.95048 .42752 .95281 .43103 .95912 .42913 .9568 .42561 Mtetra
.9568 .42561 .95912 .42913 .96544 .42723 .96313 .4237 Mtetra
.39275 .59219 .39586 .59509 .40105 .59352 .39794 .59062 Mtetra
.39794 .59062 .40105 .59352 .40624 .59195 .40315 .58904 Mtetra
.40315 .58904 .40624 .59195 .41145 .59038 .40836 .58746 Mtetra
.40836 .58746 .41145 .59038 .41667 .5888 .41358 .58588 Mtetra
.41358 .58588 .41667 .5888 .4219 .58722 .41882 .5843 Mtetra
.41882 .5843 .4219 .58722 .42713 .58564 .42406 .58271 Mtetra
.42406 .58271 .42713 .58564 .43238 .58405 .42932 .58112 Mtetra
.42932 .58112 .43238 .58405 .43764 .58246 .43458 .57952 Mtetra
.43458 .57952 .43764 .58246 .44291 .58087 .43986 .57792 Mtetra
.43986 .57792 .44291 .58087 .44819 .57928 .44514 .57632 Mtetra
.44514 .57632 .44819 .57928 .45348 .57768 .45044 .57472 Mtetra
.45044 .57472 .45348 .57768 .45878 .57608 .45574 .57311 Mtetra
.45574 .57311 .45878 .57608 .46409 .57447 .46106 .5715 Mtetra
.46106 .5715 .46409 .57447 .46941 .57287 .46639 .56989 Mtetra
.46639 .56989 .46941 .57287 .47474 .57126 .47173 .56827 Mtetra
.47173 .56827 .47474 .57126 .48008 .56964 .47707 .56665 Mtetra
.47707 .56665 .48008 .56964 .48543 .56802 .48243 .56503 Mtetra
.48243 .56503 .48543 .56802 .49079 .5664 .4878 .56341 Mtetra
.4878 .56341 .49079 .5664 .49617 .56478 .49318 .56178 Mtetra
.49318 .56178 .49617 .56478 .50155 .56316 .49857 .56014 Mtetra
.49857 .56014 .50155 .56316 .50694 .56153 .50397 .55851 Mtetra
.50397 .55851 .50694 .56153 .51235 .55989 .50938 .55687 Mtetra
.50938 .55687 .51235 .55989 .51776 .55826 .5148 .55523 Mtetra
.5148 .55523 .51776 .55826 .52319 .55662 .52024 .55358 Mtetra
.52024 .55358 .52319 .55662 .52863 .55497 .52568 .55193 Mtetra
.52568 .55193 .52863 .55497 .53407 .55333 .53114 .55028 Mtetra
.53114 .55028 .53407 .55333 .53953 .55168 .5366 .54863 Mtetra
.5366 .54863 .53953 .55168 .545 .55003 .54208 .54697 Mtetra
.54208 .54697 .545 .55003 .55048 .54837 .54756 .54531 Mtetra
.54756 .54531 .55048 .54837 .55597 .54671 .55306 .54364 Mtetra
.55306 .54364 .55597 .54671 .56147 .54505 .55857 .54197 Mtetra
.55857 .54197 .56147 .54505 .56699 .54339 .56409 .5403 Mtetra
.56409 .5403 .56699 .54339 .57251 .54172 .56962 .53863 Mtetra
.56962 .53863 .57251 .54172 .57804 .54004 .57516 .53695 Mtetra
.57516 .53695 .57804 .54004 .58359 .53837 .58072 .53527 Mtetra
.58072 .53527 .58359 .53837 .58915 .53669 .58628 .53358 Mtetra
.58628 .53358 .58915 .53669 .59471 .53501 .59186 .53189 Mtetra
.59186 .53189 .59471 .53501 .60029 .53332 .59744 .5302 Mtetra
.59744 .5302 .60029 .53332 .60588 .53163 .60304 .52851 Mtetra
.60304 .52851 .60588 .53163 .61148 .52994 .60865 .52681 Mtetra
.60865 .52681 .61148 .52994 .6171 .52825 .61427 .52511 Mtetra
.61427 .52511 .6171 .52825 .62272 .52655 .6199 .5234 Mtetra
.6199 .5234 .62272 .52655 .62836 .52484 .62554 .52169 Mtetra
.62554 .52169 .62836 .52484 .634 .52314 .6312 .51998 Mtetra
.6312 .51998 .634 .52314 .63966 .52143 .63686 .51826 Mtetra
.63686 .51826 .63966 .52143 .64533 .51972 .64254 .51654 Mtetra
.64254 .51654 .64533 .51972 .65101 .518 .64823 .51482 Mtetra
.663 .741 .908 r
.64823 .51482 .65101 .518 .6567 .51628 .65393 .5131 Mtetra
.65393 .5131 .6567 .51628 .66241 .51457 .65964 .51138 Mtetra
.664 .741 .908 r
.65964 .51138 .66241 .51457 .66812 .51285 .66537 .50965 Mtetra
.665 .742 .908 r
.66537 .50965 .66812 .51285 .67385 .5111 .6711 .5079 Mtetra
.664 .741 .908 r
.6711 .5079 .67385 .5111 .67959 .50937 .67685 .50616 Mtetra
.67685 .50616 .67959 .50937 .68534 .50763 .68261 .50441 Mtetra
.68261 .50441 .68534 .50763 .6911 .50589 .68838 .50266 Mtetra
.68838 .50266 .6911 .50589 .69688 .50414 .69416 .50091 Mtetra
.69416 .50091 .69688 .50414 .70266 .50239 .69995 .49916 Mtetra
.69995 .49916 .70266 .50239 .70846 .50064 .70576 .4974 Mtetra
.70576 .4974 .70846 .50064 .71427 .49889 .71158 .49564 Mtetra
.71158 .49564 .71427 .49889 .72009 .49713 .71741 .49387 Mtetra
.71741 .49387 .72009 .49713 .72592 .49537 .72325 .4921 Mtetra
.72325 .4921 .72592 .49537 .73177 .4936 .7291 .49033 Mtetra
.7291 .49033 .73177 .4936 .73763 .49183 .73497 .48855 Mtetra
.73497 .48855 .73763 .49183 .7435 .49006 .74084 .48677 Mtetra
.74084 .48677 .7435 .49006 .74938 .48828 .74673 .48499 Mtetra
.74673 .48499 .74938 .48828 .75527 .4865 .75264 .4832 Mtetra
.75264 .4832 .75527 .4865 .76118 .48472 .75855 .48141 Mtetra
.75855 .48141 .76118 .48472 .76709 .48293 .76448 .47962 Mtetra
.76448 .47962 .76709 .48293 .77302 .48114 .77041 .47782 Mtetra
.77041 .47782 .77302 .48114 .77897 .47934 .77637 .47602 Mtetra
.77637 .47602 .77897 .47934 .78492 .47754 .78233 .47421 Mtetra
.78233 .47421 .78492 .47754 .79089 .47574 .7883 .4724 Mtetra
.7883 .4724 .79089 .47574 .79687 .47393 .79429 .47059 Mtetra
.79429 .47059 .79687 .47393 .80286 .47212 .80029 .46877 Mtetra
.80029 .46877 .80286 .47212 .80886 .47031 .80631 .46695 Mtetra
.80631 .46695 .80886 .47031 .81488 .46849 .81233 .46513 Mtetra
.81233 .46513 .81488 .46849 .82091 .46667 .81837 .4633 Mtetra
.81837 .4633 .82091 .46667 .82695 .46484 .82442 .46147 Mtetra
.82442 .46147 .82695 .46484 .833 .46302 .83048 .45963 Mtetra
.83048 .45963 .833 .46302 .83907 .46118 .83656 .45779 Mtetra
.83656 .45779 .83907 .46118 .84515 .45935 .84265 .45594 Mtetra
.84265 .45594 .84515 .45935 .85124 .45751 .84875 .4541 Mtetra
.84875 .4541 .85124 .45751 .85735 .45566 .85486 .45225 Mtetra
.85486 .45225 .85735 .45566 .86346 .45381 .86099 .45039 Mtetra
.86099 .45039 .86346 .45381 .8696 .45196 .86713 .44853 Mtetra
.86713 .44853 .8696 .45196 .87574 .4501 .87328 .44667 Mtetra
.87328 .44667 .87574 .4501 .8819 .44824 .87945 .4448 Mtetra
.87945 .4448 .8819 .44824 .88807 .44638 .88563 .44293 Mtetra
.88563 .44293 .88807 .44638 .89425 .44451 .89182 .44105 Mtetra
.89182 .44105 .89425 .44451 .90044 .44264 .89803 .43917 Mtetra
.89803 .43917 .90044 .44264 .90665 .44076 .90424 .43729 Mtetra
.90424 .43729 .90665 .44076 .91287 .43888 .91048 .4354 Mtetra
.91048 .4354 .91287 .43888 .91911 .437 .91672 .43351 Mtetra
.91672 .43351 .91911 .437 .92536 .43511 .92298 .43162 Mtetra
.92298 .43162 .92536 .43511 .93162 .43322 .92925 .42972 Mtetra
.92925 .42972 .93162 .43322 .93789 .43133 .93553 .42782 Mtetra
.93553 .42782 .93789 .43133 .94418 .42943 .94183 .42591 Mtetra
.94183 .42591 .94418 .42943 .95048 .42752 .94814 .424 Mtetra
.94814 .424 .95048 .42752 .9568 .42561 .95447 .42208 Mtetra
.95447 .42208 .9568 .42561 .96313 .4237 .96081 .42016 Mtetra
.38963 .58928 .39275 .59219 .39794 .59062 .39483 .58771 Mtetra
.39483 .58771 .39794 .59062 .40315 .58904 .40004 .58612 Mtetra
.40004 .58612 .40315 .58904 .40836 .58746 .40526 .58454 Mtetra
.40526 .58454 .40836 .58746 .41358 .58588 .41049 .58295 Mtetra
.41049 .58295 .41358 .58588 .41882 .5843 .41573 .58136 Mtetra
.41573 .58136 .41882 .5843 .42406 .58271 .42098 .57977 Mtetra
.42098 .57977 .42406 .58271 .42932 .58112 .42624 .57817 Mtetra
.42624 .57817 .42932 .58112 .43458 .57952 .43151 .57657 Mtetra
.43151 .57657 .43458 .57952 .43986 .57792 .43679 .57497 Mtetra
.43679 .57497 .43986 .57792 .44514 .57632 .44209 .57336 Mtetra
.44209 .57336 .44514 .57632 .45044 .57472 .44739 .57175 Mtetra
.44739 .57175 .45044 .57472 .45574 .57311 .4527 .57014 Mtetra
.4527 .57014 .45574 .57311 .46106 .5715 .45802 .56852 Mtetra
.45802 .56852 .46106 .5715 .46639 .56989 .46336 .5669 Mtetra
.46336 .5669 .46639 .56989 .47173 .56827 .4687 .56528 Mtetra
.4687 .56528 .47173 .56827 .47707 .56665 .47406 .56366 Mtetra
.47406 .56366 .47707 .56665 .48243 .56503 .47942 .56203 Mtetra
.47942 .56203 .48243 .56503 .4878 .56341 .4848 .5604 Mtetra
.4848 .5604 .4878 .56341 .49318 .56178 .49018 .55876 Mtetra
.49018 .55876 .49318 .56178 .49857 .56014 .49558 .55712 Mtetra
.49558 .55712 .49857 .56014 .50397 .55851 .50099 .55548 Mtetra
.50099 .55548 .50397 .55851 .50938 .55687 .50641 .55384 Mtetra
.50641 .55384 .50938 .55687 .5148 .55523 .51184 .55219 Mtetra
.51184 .55219 .5148 .55523 .52024 .55358 .51728 .55054 Mtetra
.51728 .55054 .52024 .55358 .52568 .55193 .52273 .54888 Mtetra
.52273 .54888 .52568 .55193 .53114 .55028 .52819 .54722 Mtetra
.52819 .54722 .53114 .55028 .5366 .54863 .53366 .54556 Mtetra
.53366 .54556 .5366 .54863 .54208 .54697 .53914 .5439 Mtetra
.53914 .5439 .54208 .54697 .54756 .54531 .54464 .54223 Mtetra
.54464 .54223 .54756 .54531 .55306 .54364 .55014 .54056 Mtetra
.55014 .54056 .55306 .54364 .55857 .54197 .55566 .53888 Mtetra
.55566 .53888 .55857 .54197 .56409 .5403 .56119 .53721 Mtetra
.56119 .53721 .56409 .5403 .56962 .53863 .56672 .53553 Mtetra
.56672 .53553 .56962 .53863 .57516 .53695 .57227 .53384 Mtetra
.57227 .53384 .57516 .53695 .58072 .53527 .57783 .53215 Mtetra
.57783 .53215 .58072 .53527 .58628 .53358 .58341 .53046 Mtetra
.58341 .53046 .58628 .53358 .59186 .53189 .58899 .52877 Mtetra
.58899 .52877 .59186 .53189 .59744 .5302 .59458 .52707 Mtetra
.59458 .52707 .59744 .5302 .60304 .52851 .60019 .52537 Mtetra
.60019 .52537 .60304 .52851 .60865 .52681 .6058 .52366 Mtetra
.6058 .52366 .60865 .52681 .61427 .52511 .61143 .52195 Mtetra
.61143 .52195 .61427 .52511 .6199 .5234 .61707 .52024 Mtetra
.61707 .52024 .6199 .5234 .62554 .52169 .62272 .51853 Mtetra
.62272 .51853 .62554 .52169 .6312 .51998 .62838 .51681 Mtetra
.62838 .51681 .6312 .51998 .63686 .51826 .63406 .51509 Mtetra
.63406 .51509 .63686 .51826 .64254 .51654 .63974 .51336 Mtetra
.63974 .51336 .64254 .51654 .64823 .51482 .64544 .51163 Mtetra
.663 .741 .908 r
.64544 .51163 .64823 .51482 .65393 .5131 .65115 .5099 Mtetra
.662 .741 .908 r
.65115 .5099 .65393 .5131 .65964 .51138 .65687 .50818 Mtetra
.664 .741 .908 r
.65687 .50818 .65964 .51138 .66537 .50965 .6626 .50644 Mtetra
.665 .742 .908 r
.6626 .50644 .66537 .50965 .6711 .5079 .66834 .50468 Mtetra
.664 .741 .908 r
.66834 .50468 .6711 .5079 .67685 .50616 .6741 .50293 Mtetra
.6741 .50293 .67685 .50616 .68261 .50441 .67986 .50118 Mtetra
.67986 .50118 .68261 .50441 .68838 .50266 .68564 .49943 Mtetra
.68564 .49943 .68838 .50266 .69416 .50091 .69143 .49767 Mtetra
.69143 .49767 .69416 .50091 .69995 .49916 .69723 .49591 Mtetra
.69723 .49591 .69995 .49916 .70576 .4974 .70305 .49414 Mtetra
.70305 .49414 .70576 .4974 .71158 .49564 .70887 .49238 Mtetra
.70887 .49238 .71158 .49564 .71741 .49387 .71471 .4906 Mtetra
.71471 .4906 .71741 .49387 .72325 .4921 .72056 .48883 Mtetra
.72056 .48883 .72325 .4921 .7291 .49033 .72642 .48705 Mtetra
.72642 .48705 .7291 .49033 .73497 .48855 .7323 .48527 Mtetra
.7323 .48527 .73497 .48855 .74084 .48677 .73818 .48348 Mtetra
.73818 .48348 .74084 .48677 .74673 .48499 .74408 .48169 Mtetra
.74408 .48169 .74673 .48499 .75264 .4832 .74999 .47989 Mtetra
.74999 .47989 .75264 .4832 .75855 .48141 .75591 .4781 Mtetra
.75591 .4781 .75855 .48141 .76448 .47962 .76185 .4763 Mtetra
.76185 .4763 .76448 .47962 .77041 .47782 .7678 .47449 Mtetra
.7678 .47449 .77041 .47782 .77637 .47602 .77376 .47268 Mtetra
.77376 .47268 .77637 .47602 .78233 .47421 .77973 .47087 Mtetra
.77973 .47087 .78233 .47421 .7883 .4724 .78571 .46905 Mtetra
.78571 .46905 .7883 .4724 .79429 .47059 .79171 .46723 Mtetra
.79171 .46723 .79429 .47059 .80029 .46877 .79772 .46541 Mtetra
.79772 .46541 .80029 .46877 .80631 .46695 .80374 .46358 Mtetra
.80374 .46358 .80631 .46695 .81233 .46513 .80977 .46175 Mtetra
.80977 .46175 .81233 .46513 .81837 .4633 .81582 .45991 Mtetra
.81582 .45991 .81837 .4633 .82442 .46147 .82188 .45807 Mtetra
.82188 .45807 .82442 .46147 .83048 .45963 .82795 .45623 Mtetra
.82795 .45623 .83048 .45963 .83656 .45779 .83404 .45438 Mtetra
.83404 .45438 .83656 .45779 .84265 .45594 .84014 .45253 Mtetra
.84014 .45253 .84265 .45594 .84875 .4541 .84625 .45068 Mtetra
.84625 .45068 .84875 .4541 .85486 .45225 .85237 .44882 Mtetra
.85237 .44882 .85486 .45225 .86099 .45039 .85851 .44695 Mtetra
.85851 .44695 .86099 .45039 .86713 .44853 .86466 .44509 Mtetra
.86466 .44509 .86713 .44853 .87328 .44667 .87082 .44322 Mtetra
.87082 .44322 .87328 .44667 .87945 .4448 .87699 .44134 Mtetra
.87699 .44134 .87945 .4448 .88563 .44293 .88318 .43946 Mtetra
.88318 .43946 .88563 .44293 .89182 .44105 .88938 .43758 Mtetra
.88938 .43758 .89182 .44105 .89803 .43917 .8956 .43569 Mtetra
.8956 .43569 .89803 .43917 .90424 .43729 .90183 .4338 Mtetra
.90183 .4338 .90424 .43729 .91048 .4354 .90807 .43191 Mtetra
.90807 .43191 .91048 .4354 .91672 .43351 .91432 .43001 Mtetra
.91432 .43001 .91672 .43351 .92298 .43162 .92059 .42811 Mtetra
.92059 .42811 .92298 .43162 .92925 .42972 .92687 .4262 Mtetra
.92687 .4262 .92925 .42972 .93553 .42782 .93317 .42429 Mtetra
.93317 .42429 .93553 .42782 .94183 .42591 .93947 .42238 Mtetra
.93947 .42238 .94183 .42591 .94814 .424 .94579 .42046 Mtetra
.94579 .42046 .94814 .424 .95447 .42208 .95213 .41853 Mtetra
.95213 .41853 .95447 .42208 .96081 .42016 .95848 .41661 Mtetra
.38649 .58637 .38963 .58928 .39483 .58771 .3917 .58478 Mtetra
.3917 .58478 .39483 .58771 .40004 .58612 .39692 .5832 Mtetra
.39692 .5832 .40004 .58612 .40526 .58454 .40214 .58161 Mtetra
.40214 .58161 .40526 .58454 .41049 .58295 .40738 .58001 Mtetra
.40738 .58001 .41049 .58295 .41573 .58136 .41263 .57842 Mtetra
.41263 .57842 .41573 .58136 .42098 .57977 .41789 .57682 Mtetra
.41789 .57682 .42098 .57977 .42624 .57817 .42315 .57521 Mtetra
.42315 .57521 .42624 .57817 .43151 .57657 .42843 .57361 Mtetra
.42843 .57361 .43151 .57657 .43679 .57497 .43372 .572 Mtetra
.43372 .572 .43679 .57497 .44209 .57336 .43902 .57039 Mtetra
.43902 .57039 .44209 .57336 .44739 .57175 .44433 .56877 Mtetra
.44433 .56877 .44739 .57175 .4527 .57014 .44965 .56715 Mtetra
.44965 .56715 .4527 .57014 .45802 .56852 .45498 .56553 Mtetra
.45498 .56553 .45802 .56852 .46336 .5669 .46032 .56391 Mtetra
.46032 .56391 .46336 .5669 .4687 .56528 .46567 .56228 Mtetra
.46567 .56228 .4687 .56528 .47406 .56366 .47103 .56065 Mtetra
.47103 .56065 .47406 .56366 .47942 .56203 .4764 .55901 Mtetra
.4764 .55901 .47942 .56203 .4848 .5604 .48178 .55737 Mtetra
.48178 .55737 .4848 .5604 .49018 .55876 .48718 .55573 Mtetra
.48718 .55573 .49018 .55876 .49558 .55712 .49258 .55409 Mtetra
.49258 .55409 .49558 .55712 .50099 .55548 .49799 .55244 Mtetra
.49799 .55244 .50099 .55548 .50641 .55384 .50342 .55079 Mtetra
.50342 .55079 .50641 .55384 .51184 .55219 .50886 .54914 Mtetra
.50886 .54914 .51184 .55219 .51728 .55054 .5143 .54748 Mtetra
.5143 .54748 .51728 .55054 .52273 .54888 .51976 .54582 Mtetra
.51976 .54582 .52273 .54888 .52819 .54722 .52523 .54415 Mtetra
.52523 .54415 .52819 .54722 .53366 .54556 .53071 .54249 Mtetra
.53071 .54249 .53366 .54556 .53914 .5439 .5362 .54082 Mtetra
.5362 .54082 .53914 .5439 .54464 .54223 .5417 .53914 Mtetra
.5417 .53914 .54464 .54223 .55014 .54056 .54721 .53747 Mtetra
.54721 .53747 .55014 .54056 .55566 .53888 .55274 .53578 Mtetra
.55274 .53578 .55566 .53888 .56119 .53721 .55827 .5341 Mtetra
.55827 .5341 .56119 .53721 .56672 .53553 .56382 .53241 Mtetra
.56382 .53241 .56672 .53553 .57227 .53384 .56937 .53072 Mtetra
.56937 .53072 .57227 .53384 .57783 .53215 .57494 .52903 Mtetra
.57494 .52903 .57783 .53215 .58341 .53046 .58052 .52733 Mtetra
.58052 .52733 .58341 .53046 .58899 .52877 .58611 .52563 Mtetra
.58611 .52563 .58899 .52877 .59458 .52707 .59171 .52393 Mtetra
.59171 .52393 .59458 .52707 .60019 .52537 .59732 .52222 Mtetra
.59732 .52222 .60019 .52537 .6058 .52366 .60295 .52051 Mtetra
.60295 .52051 .6058 .52366 .61143 .52195 .60858 .51879 Mtetra
.60858 .51879 .61143 .52195 .61707 .52024 .61423 .51707 Mtetra
.61423 .51707 .61707 .52024 .62272 .51853 .61989 .51535 Mtetra
.61989 .51535 .62272 .51853 .62838 .51681 .62556 .51363 Mtetra
.62556 .51363 .62838 .51681 .63406 .51509 .63124 .5119 Mtetra
.63124 .5119 .63406 .51509 .63974 .51336 .63693 .51017 Mtetra
.63693 .51017 .63974 .51336 .64544 .51163 .64264 .50843 Mtetra
.663 .741 .908 r
.64264 .50843 .64544 .51163 .65115 .5099 .64835 .50669 Mtetra
.662 .741 .908 r
.64835 .50669 .65115 .5099 .65687 .50818 .65408 .50497 Mtetra
.664 .741 .908 r
.65408 .50497 .65687 .50818 .6626 .50644 .65982 .50322 Mtetra
.665 .742 .908 r
.65982 .50322 .6626 .50644 .66834 .50468 .66557 .50145 Mtetra
.664 .741 .908 r
.66557 .50145 .66834 .50468 .6741 .50293 .67133 .4997 Mtetra
.67133 .4997 .6741 .50293 .67986 .50118 .67711 .49794 Mtetra
.67711 .49794 .67986 .50118 .68564 .49943 .6829 .49618 Mtetra
.6829 .49618 .68564 .49943 .69143 .49767 .68869 .49442 Mtetra
.68869 .49442 .69143 .49767 .69723 .49591 .6945 .49265 Mtetra
.6945 .49265 .69723 .49591 .70305 .49414 .70033 .49088 Mtetra
.70033 .49088 .70305 .49414 .70887 .49238 .70616 .4891 Mtetra
.70616 .4891 .70887 .49238 .71471 .4906 .71201 .48732 Mtetra
.71201 .48732 .71471 .4906 .72056 .48883 .71786 .48554 Mtetra
.71786 .48554 .72056 .48883 .72642 .48705 .72373 .48375 Mtetra
.72373 .48375 .72642 .48705 .7323 .48527 .72962 .48196 Mtetra
.72962 .48196 .7323 .48527 .73818 .48348 .73551 .48017 Mtetra
.73551 .48017 .73818 .48348 .74408 .48169 .74142 .47837 Mtetra
.74142 .47837 .74408 .48169 .74999 .47989 .74734 .47657 Mtetra
.74734 .47657 .74999 .47989 .75591 .4781 .75327 .47477 Mtetra
.75327 .47477 .75591 .4781 .76185 .4763 .75921 .47296 Mtetra
.75921 .47296 .76185 .4763 .7678 .47449 .76517 .47115 Mtetra
.76517 .47115 .7678 .47449 .77376 .47268 .77114 .46933 Mtetra
.77114 .46933 .77376 .47268 .77973 .47087 .77712 .46751 Mtetra
.77712 .46751 .77973 .47087 .78571 .46905 .78311 .46569 Mtetra
.78311 .46569 .78571 .46905 .79171 .46723 .78912 .46386 Mtetra
.78912 .46386 .79171 .46723 .79772 .46541 .79513 .46203 Mtetra
.79513 .46203 .79772 .46541 .80374 .46358 .80116 .46019 Mtetra
.80116 .46019 .80374 .46358 .80977 .46175 .80721 .45836 Mtetra
.80721 .45836 .80977 .46175 .81582 .45991 .81326 .45651 Mtetra
.81326 .45651 .81582 .45991 .82188 .45807 .81933 .45467 Mtetra
.81933 .45467 .82188 .45807 .82795 .45623 .82541 .45282 Mtetra
.82541 .45282 .82795 .45623 .83404 .45438 .83151 .45096 Mtetra
.83151 .45096 .83404 .45438 .84014 .45253 .83762 .4491 Mtetra
.83762 .4491 .84014 .45253 .84625 .45068 .84374 .44724 Mtetra
.84374 .44724 .84625 .45068 .85237 .44882 .84987 .44537 Mtetra
.84987 .44537 .85237 .44882 .85851 .44695 .85601 .4435 Mtetra
.85601 .4435 .85851 .44695 .86466 .44509 .86217 .44163 Mtetra
.86217 .44163 .86466 .44509 .87082 .44322 .86834 .43975 Mtetra
.86834 .43975 .87082 .44322 .87699 .44134 .87453 .43787 Mtetra
.87453 .43787 .87699 .44134 .88318 .43946 .88073 .43599 Mtetra
.88073 .43599 .88318 .43946 .88938 .43758 .88694 .4341 Mtetra
.88694 .4341 .88938 .43758 .8956 .43569 .89316 .4322 Mtetra
.89316 .4322 .8956 .43569 .90183 .4338 .8994 .4303 Mtetra
.8994 .4303 .90183 .4338 .90807 .43191 .90565 .4284 Mtetra
.90565 .4284 .90807 .43191 .91432 .43001 .91191 .4265 Mtetra
.91191 .4265 .91432 .43001 .92059 .42811 .91819 .42459 Mtetra
.91819 .42459 .92059 .42811 .92687 .4262 .92448 .42267 Mtetra
.92448 .42267 .92687 .4262 .93317 .42429 .93079 .42075 Mtetra
.93079 .42075 .93317 .42429 .93947 .42238 .93711 .41883 Mtetra
.93711 .41883 .93947 .42238 .94579 .42046 .94344 .4169 Mtetra
.94344 .4169 .94579 .42046 .95213 .41853 .94978 .41497 Mtetra
.94978 .41497 .95213 .41853 .95848 .41661 .95614 .41304 Mtetra
.38335 .58344 .38649 .58637 .3917 .58478 .38856 .58185 Mtetra
.38856 .58185 .3917 .58478 .39692 .5832 .39379 .58026 Mtetra
.39379 .58026 .39692 .5832 .40214 .58161 .39902 .57866 Mtetra
.39902 .57866 .40214 .58161 .40738 .58001 .40426 .57706 Mtetra
.40426 .57706 .40738 .58001 .41263 .57842 .40952 .57546 Mtetra
.40952 .57546 .41263 .57842 .41789 .57682 .41478 .57386 Mtetra
.41478 .57386 .41789 .57682 .42315 .57521 .42005 .57225 Mtetra
.42005 .57225 .42315 .57521 .42843 .57361 .42534 .57063 Mtetra
.42534 .57063 .42843 .57361 .43372 .572 .43063 .56902 Mtetra
.43063 .56902 .43372 .572 .43902 .57039 .43594 .5674 Mtetra
.43594 .5674 .43902 .57039 .44433 .56877 .44125 .56578 Mtetra
.44125 .56578 .44433 .56877 .44965 .56715 .44658 .56416 Mtetra
.44658 .56416 .44965 .56715 .45498 .56553 .45192 .56253 Mtetra
.45192 .56253 .45498 .56553 .46032 .56391 .45726 .5609 Mtetra
.45726 .5609 .46032 .56391 .46567 .56228 .46262 .55926 Mtetra
.46262 .55926 .46567 .56228 .47103 .56065 .46799 .55763 Mtetra
.46799 .55763 .47103 .56065 .4764 .55901 .47337 .55599 Mtetra
.47337 .55599 .4764 .55901 .48178 .55737 .47876 .55434 Mtetra
.47876 .55434 .48178 .55737 .48718 .55573 .48416 .5527 Mtetra
.48416 .5527 .48718 .55573 .49258 .55409 .48957 .55104 Mtetra
.48957 .55104 .49258 .55409 .49799 .55244 .49499 .54939 Mtetra
.49499 .54939 .49799 .55244 .50342 .55079 .50042 .54773 Mtetra
.50042 .54773 .50342 .55079 .50886 .54914 .50586 .54607 Mtetra
.50586 .54607 .50886 .54914 .5143 .54748 .51132 .54441 Mtetra
.51132 .54441 .5143 .54748 .51976 .54582 .51678 .54274 Mtetra
.51678 .54274 .51976 .54582 .52523 .54415 .52226 .54107 Mtetra
.52226 .54107 .52523 .54415 .53071 .54249 .52775 .5394 Mtetra
.52775 .5394 .53071 .54249 .5362 .54082 .53324 .53772 Mtetra
.53324 .53772 .5362 .54082 .5417 .53914 .53875 .53604 Mtetra
.53875 .53604 .5417 .53914 .54721 .53747 .54427 .53436 Mtetra
.54427 .53436 .54721 .53747 .55274 .53578 .5498 .53267 Mtetra
.5498 .53267 .55274 .53578 .55827 .5341 .55534 .53098 Mtetra
.55534 .53098 .55827 .5341 .56382 .53241 .5609 .52929 Mtetra
.5609 .52929 .56382 .53241 .56937 .53072 .56646 .52759 Mtetra
.56646 .52759 .56937 .53072 .57494 .52903 .57204 .52589 Mtetra
.57204 .52589 .57494 .52903 .58052 .52733 .57762 .52419 Mtetra
.57762 .52419 .58052 .52733 .58611 .52563 .58322 .52248 Mtetra
.58322 .52248 .58611 .52563 .59171 .52393 .58883 .52077 Mtetra
.58883 .52077 .59171 .52393 .59732 .52222 .59445 .51906 Mtetra
.59445 .51906 .59732 .52222 .60295 .52051 .60008 .51734 Mtetra
.60008 .51734 .60295 .52051 .60858 .51879 .60572 .51562 Mtetra
.60572 .51562 .60858 .51879 .61423 .51707 .61138 .51389 Mtetra
.61138 .51389 .61423 .51707 .61989 .51535 .61705 .51216 Mtetra
.61705 .51216 .61989 .51535 .62556 .51363 .62272 .51043 Mtetra
.62272 .51043 .62556 .51363 .63124 .5119 .62841 .5087 Mtetra
.62841 .5087 .63124 .5119 .63693 .51017 .63411 .50696 Mtetra
.63411 .50696 .63693 .51017 .64264 .50843 .63982 .50522 Mtetra
.663 .741 .908 r
.63982 .50522 .64264 .50843 .64835 .50669 .64555 .50347 Mtetra
.662 .741 .908 r
.64555 .50347 .64835 .50669 .65408 .50497 .65129 .50174 Mtetra
.664 .741 .908 r
.65129 .50174 .65408 .50497 .65982 .50322 .65703 .49999 Mtetra
.665 .742 .907 r
.65703 .49999 .65982 .50322 .66557 .50145 .66279 .49821 Mtetra
.664 .741 .908 r
.66279 .49821 .66557 .50145 .67133 .4997 .66856 .49645 Mtetra
.66856 .49645 .67133 .4997 .67711 .49794 .67434 .49469 Mtetra
.67434 .49469 .67711 .49794 .6829 .49618 .68014 .49292 Mtetra
.68014 .49292 .6829 .49618 .68869 .49442 .68595 .49115 Mtetra
.68595 .49115 .68869 .49442 .6945 .49265 .69176 .48938 Mtetra
.69176 .48938 .6945 .49265 .70033 .49088 .69759 .4876 Mtetra
.69759 .4876 .70033 .49088 .70616 .4891 .70344 .48581 Mtetra
.70344 .48581 .70616 .4891 .71201 .48732 .70929 .48403 Mtetra
.70929 .48403 .71201 .48732 .71786 .48554 .71516 .48224 Mtetra
.71516 .48224 .71786 .48554 .72373 .48375 .72104 .48045 Mtetra
.72104 .48045 .72373 .48375 .72962 .48196 .72693 .47865 Mtetra
.72693 .47865 .72962 .48196 .73551 .48017 .73283 .47685 Mtetra
.73283 .47685 .73551 .48017 .74142 .47837 .73875 .47505 Mtetra
.73875 .47505 .74142 .47837 .74734 .47657 .74467 .47324 Mtetra
.74467 .47324 .74734 .47657 .75327 .47477 .75061 .47143 Mtetra
.75061 .47143 .75327 .47477 .75921 .47296 .75656 .46961 Mtetra
.75656 .46961 .75921 .47296 .76517 .47115 .76253 .46779 Mtetra
.76253 .46779 .76517 .47115 .77114 .46933 .76851 .46597 Mtetra
.76851 .46597 .77114 .46933 .77712 .46751 .7745 .46414 Mtetra
.7745 .46414 .77712 .46751 .78311 .46569 .7805 .46231 Mtetra
.7805 .46231 .78311 .46569 .78912 .46386 .78651 .46048 Mtetra
.78651 .46048 .78912 .46386 .79513 .46203 .79254 .45864 Mtetra
.79254 .45864 .79513 .46203 .80116 .46019 .79858 .4568 Mtetra
.79858 .4568 .80116 .46019 .80721 .45836 .80463 .45495 Mtetra
.80463 .45495 .80721 .45836 .81326 .45651 .8107 .4531 Mtetra
.8107 .4531 .81326 .45651 .81933 .45467 .81677 .45125 Mtetra
.81677 .45125 .81933 .45467 .82541 .45282 .82286 .44939 Mtetra
.82286 .44939 .82541 .45282 .83151 .45096 .82897 .44753 Mtetra
.82897 .44753 .83151 .45096 .83762 .4491 .83508 .44566 Mtetra
.83508 .44566 .83762 .4491 .84374 .44724 .84121 .44379 Mtetra
.84121 .44379 .84374 .44724 .84987 .44537 .84736 .44192 Mtetra
.84736 .44192 .84987 .44537 .85601 .4435 .85351 .44004 Mtetra
.85351 .44004 .85601 .4435 .86217 .44163 .85968 .43816 Mtetra
.85968 .43816 .86217 .44163 .86834 .43975 .86586 .43628 Mtetra
.86586 .43628 .86834 .43975 .87453 .43787 .87205 .43439 Mtetra
.87205 .43439 .87453 .43787 .88073 .43599 .87826 .43249 Mtetra
.87826 .43249 .88073 .43599 .88694 .4341 .88448 .4306 Mtetra
.88448 .4306 .88694 .4341 .89316 .4322 .89072 .42869 Mtetra
.89072 .42869 .89316 .4322 .8994 .4303 .89696 .42679 Mtetra
.89696 .42679 .8994 .4303 .90565 .4284 .90322 .42488 Mtetra
.90322 .42488 .90565 .4284 .91191 .4265 .9095 .42297 Mtetra
.9095 .42297 .91191 .4265 .91819 .42459 .91579 .42105 Mtetra
.91579 .42105 .91819 .42459 .92448 .42267 .92209 .41913 Mtetra
.92209 .41913 .92448 .42267 .93079 .42075 .9284 .4172 Mtetra
.9284 .4172 .93079 .42075 .93711 .41883 .93473 .41527 Mtetra
.93473 .41527 .93711 .41883 .94344 .4169 .94107 .41334 Mtetra
.94107 .41334 .94344 .4169 .94978 .41497 .94742 .4114 Mtetra
.94742 .4114 .94978 .41497 .95614 .41304 .95379 .40946 Mtetra
.3802 .5805 .38335 .58344 .38856 .58185 .38541 .57891 Mtetra
.38541 .57891 .38856 .58185 .39379 .58026 .39064 .57731 Mtetra
.39064 .57731 .39379 .58026 .39902 .57866 .39588 .57571 Mtetra
.39588 .57571 .39902 .57866 .40426 .57706 .40113 .5741 Mtetra
.40113 .5741 .40426 .57706 .40952 .57546 .40639 .57249 Mtetra
.40639 .57249 .40952 .57546 .41478 .57386 .41166 .57088 Mtetra
.41166 .57088 .41478 .57386 .42005 .57225 .41694 .56927 Mtetra
.41694 .56927 .42005 .57225 .42534 .57063 .42223 .56765 Mtetra
.42223 .56765 .42534 .57063 .43063 .56902 .42754 .56603 Mtetra
.42754 .56603 .43063 .56902 .43594 .5674 .43285 .56441 Mtetra
.43285 .56441 .43594 .5674 .44125 .56578 .43817 .56278 Mtetra
.43817 .56278 .44125 .56578 .44658 .56416 .4435 .56115 Mtetra
.4435 .56115 .44658 .56416 .45192 .56253 .44885 .55952 Mtetra
.44885 .55952 .45192 .56253 .45726 .5609 .4542 .55788 Mtetra
.4542 .55788 .45726 .5609 .46262 .55926 .45956 .55624 Mtetra
.45956 .55624 .46262 .55926 .46799 .55763 .46494 .5546 Mtetra
.46494 .5546 .46799 .55763 .47337 .55599 .47032 .55295 Mtetra
.47032 .55295 .47337 .55599 .47876 .55434 .47572 .5513 Mtetra
.47572 .5513 .47876 .55434 .48416 .5527 .48113 .54965 Mtetra
.48113 .54965 .48416 .5527 .48957 .55104 .48655 .54799 Mtetra
.48655 .54799 .48957 .55104 .49499 .54939 .49197 .54633 Mtetra
.49197 .54633 .49499 .54939 .50042 .54773 .49741 .54467 Mtetra
.49741 .54467 .50042 .54773 .50586 .54607 .50286 .543 Mtetra
.50286 .543 .50586 .54607 .51132 .54441 .50832 .54133 Mtetra
.50832 .54133 .51132 .54441 .51678 .54274 .5138 .53966 Mtetra
.5138 .53966 .51678 .54274 .52226 .54107 .51928 .53798 Mtetra
.51928 .53798 .52226 .54107 .52775 .5394 .52477 .5363 Mtetra
.52477 .5363 .52775 .5394 .53324 .53772 .53028 .53462 Mtetra
.53028 .53462 .53324 .53772 .53875 .53604 .53579 .53293 Mtetra
.53579 .53293 .53875 .53604 .54427 .53436 .54132 .53124 Mtetra
.54132 .53124 .54427 .53436 .5498 .53267 .54686 .52955 Mtetra
.54686 .52955 .5498 .53267 .55534 .53098 .55241 .52785 Mtetra
.55241 .52785 .55534 .53098 .5609 .52929 .55797 .52615 Mtetra
.55797 .52615 .5609 .52929 .56646 .52759 .56354 .52445 Mtetra
.56354 .52445 .56646 .52759 .57204 .52589 .56912 .52274 Mtetra
.56912 .52274 .57204 .52589 .57762 .52419 .57472 .52103 Mtetra
.57472 .52103 .57762 .52419 .58322 .52248 .58032 .51932 Mtetra
.58032 .51932 .58322 .52248 .58883 .52077 .58594 .5176 Mtetra
.58594 .5176 .58883 .52077 .59445 .51906 .59156 .51588 Mtetra
.59156 .51588 .59445 .51906 .60008 .51734 .5972 .51416 Mtetra
.5972 .51416 .60008 .51734 .60572 .51562 .60285 .51243 Mtetra
.60285 .51243 .60572 .51562 .61138 .51389 .60852 .5107 Mtetra
.60852 .5107 .61138 .51389 .61705 .51216 .61419 .50896 Mtetra
.61419 .50896 .61705 .51216 .62272 .51043 .61988 .50723 Mtetra
.61988 .50723 .62272 .51043 .62841 .5087 .62557 .50548 Mtetra
.62557 .50548 .62841 .5087 .63411 .50696 .63128 .50374 Mtetra
.63128 .50374 .63411 .50696 .63982 .50522 .637 .50199 Mtetra
.663 .741 .908 r
.637 .50199 .63982 .50522 .64555 .50347 .64273 .50024 Mtetra
.662 .741 .908 r
.64273 .50024 .64555 .50347 .65129 .50174 .64848 .4985 Mtetra
.664 .741 .908 r
.64848 .4985 .65129 .50174 .65703 .49999 .65423 .49674 Mtetra
.665 .742 .907 r
.65423 .49674 .65703 .49999 .66279 .49821 .66 .49496 Mtetra
.664 .741 .908 r
.66 .49496 .66279 .49821 .66856 .49645 .66578 .49319 Mtetra
.66578 .49319 .66856 .49645 .67434 .49469 .67157 .49142 Mtetra
.67157 .49142 .67434 .49469 .68014 .49292 .67737 .48965 Mtetra
.67737 .48965 .68014 .49292 .68595 .49115 .68319 .48787 Mtetra
.68319 .48787 .68595 .49115 .69176 .48938 .68901 .48609 Mtetra
.68901 .48609 .69176 .48938 .69759 .4876 .69485 .4843 Mtetra
.69485 .4843 .69759 .4876 .70344 .48581 .7007 .48252 Mtetra
.7007 .48252 .70344 .48581 .70929 .48403 .70657 .48072 Mtetra
.70657 .48072 .70929 .48403 .71516 .48224 .71244 .47893 Mtetra
.71244 .47893 .71516 .48224 .72104 .48045 .71833 .47713 Mtetra
.71833 .47713 .72104 .48045 .72693 .47865 .72423 .47532 Mtetra
.72423 .47532 .72693 .47865 .73283 .47685 .73014 .47352 Mtetra
.73014 .47352 .73283 .47685 .73875 .47505 .73606 .47171 Mtetra
.73606 .47171 .73875 .47505 .74467 .47324 .742 .46989 Mtetra
.742 .46989 .74467 .47324 .75061 .47143 .74795 .46807 Mtetra
.74795 .46807 .75061 .47143 .75656 .46961 .75391 .46625 Mtetra
.75391 .46625 .75656 .46961 .76253 .46779 .75988 .46442 Mtetra
.75988 .46442 .76253 .46779 .76851 .46597 .76587 .46259 Mtetra
.76587 .46259 .76851 .46597 .7745 .46414 .77186 .46076 Mtetra
.77186 .46076 .7745 .46414 .7805 .46231 .77788 .45892 Mtetra
.77788 .45892 .7805 .46231 .78651 .46048 .7839 .45708 Mtetra
.7839 .45708 .78651 .46048 .79254 .45864 .78993 .45523 Mtetra
.78993 .45523 .79254 .45864 .79858 .4568 .79598 .45339 Mtetra
.79598 .45339 .79858 .4568 .80463 .45495 .80204 .45153 Mtetra
.80204 .45153 .80463 .45495 .8107 .4531 .80812 .44968 Mtetra
.80812 .44968 .8107 .4531 .81677 .45125 .81421 .44781 Mtetra
.81421 .44781 .81677 .45125 .82286 .44939 .82031 .44595 Mtetra
.82031 .44595 .82286 .44939 .82897 .44753 .82642 .44408 Mtetra
.82642 .44408 .82897 .44753 .83508 .44566 .83254 .44221 Mtetra
.83254 .44221 .83508 .44566 .84121 .44379 .83868 .44033 Mtetra
.83868 .44033 .84121 .44379 .84736 .44192 .84483 .43845 Mtetra
.84483 .43845 .84736 .44192 .85351 .44004 .851 .43657 Mtetra
.851 .43657 .85351 .44004 .85968 .43816 .85718 .43468 Mtetra
.85718 .43468 .85968 .43816 .86586 .43628 .86337 .43278 Mtetra
.86337 .43278 .86586 .43628 .87205 .43439 .86957 .43089 Mtetra
.86957 .43089 .87205 .43439 .87826 .43249 .87579 .42899 Mtetra
.87579 .42899 .87826 .43249 .88448 .4306 .88202 .42708 Mtetra
.88202 .42708 .88448 .4306 .89072 .42869 .88826 .42517 Mtetra
.88826 .42517 .89072 .42869 .89696 .42679 .89452 .42326 Mtetra
.89452 .42326 .89696 .42679 .90322 .42488 .90079 .42134 Mtetra
.90079 .42134 .90322 .42488 .9095 .42297 .90707 .41942 Mtetra
.90707 .41942 .9095 .42297 .91579 .42105 .91337 .4175 Mtetra
.91337 .4175 .91579 .42105 .92209 .41913 .91968 .41557 Mtetra
.91968 .41557 .92209 .41913 .9284 .4172 .926 .41363 Mtetra
.926 .41363 .9284 .4172 .93473 .41527 .93234 .4117 Mtetra
.93234 .4117 .93473 .41527 .94107 .41334 .93869 .40976 Mtetra
.93869 .40976 .94107 .41334 .94742 .4114 .94506 .40781 Mtetra
.94506 .40781 .94742 .4114 .95379 .40946 .95144 .40586 Mtetra
.37703 .57756 .3802 .5805 .38541 .57891 .38225 .57595 Mtetra
.38225 .57595 .38541 .57891 .39064 .57731 .38749 .57435 Mtetra
.38749 .57435 .39064 .57731 .39588 .57571 .39274 .57274 Mtetra
.39274 .57274 .39588 .57571 .40113 .5741 .39799 .57113 Mtetra
.39799 .57113 .40113 .5741 .40639 .57249 .40326 .56952 Mtetra
.40326 .56952 .40639 .57249 .41166 .57088 .40854 .5679 Mtetra
.40854 .5679 .41166 .57088 .41694 .56927 .41382 .56628 Mtetra
.41382 .56628 .41694 .56927 .42223 .56765 .41912 .56466 Mtetra
.41912 .56466 .42223 .56765 .42754 .56603 .42443 .56303 Mtetra
.42443 .56303 .42754 .56603 .43285 .56441 .42975 .5614 Mtetra
.42975 .5614 .43285 .56441 .43817 .56278 .43507 .55977 Mtetra
.43507 .55977 .43817 .56278 .4435 .56115 .44041 .55813 Mtetra
.44041 .55813 .4435 .56115 .44885 .55952 .44576 .55649 Mtetra
.44576 .55649 .44885 .55952 .4542 .55788 .45112 .55485 Mtetra
.45112 .55485 .4542 .55788 .45956 .55624 .4565 .5532 Mtetra
.4565 .5532 .45956 .55624 .46494 .5546 .46188 .55155 Mtetra
.46188 .55155 .46494 .5546 .47032 .55295 .46727 .5499 Mtetra
.46727 .5499 .47032 .55295 .47572 .5513 .47267 .54824 Mtetra
.47267 .54824 .47572 .5513 .48113 .54965 .47809 .54659 Mtetra
.47809 .54659 .48113 .54965 .48655 .54799 .48351 .54492 Mtetra
.48351 .54492 .48655 .54799 .49197 .54633 .48895 .54326 Mtetra
.48895 .54326 .49197 .54633 .49741 .54467 .49439 .54159 Mtetra
.49439 .54159 .49741 .54467 .50286 .543 .49985 .53992 Mtetra
.49985 .53992 .50286 .543 .50832 .54133 .50532 .53824 Mtetra
.50532 .53824 .50832 .54133 .5138 .53966 .5108 .53656 Mtetra
.5108 .53656 .5138 .53966 .51928 .53798 .51629 .53488 Mtetra
.51629 .53488 .51928 .53798 .52477 .5363 .52179 .53319 Mtetra
.52179 .53319 .52477 .5363 .53028 .53462 .5273 .5315 Mtetra
.5273 .5315 .53028 .53462 .53579 .53293 .53282 .52981 Mtetra
.53282 .52981 .53579 .53293 .54132 .53124 .53836 .52811 Mtetra
.53836 .52811 .54132 .53124 .54686 .52955 .5439 .52642 Mtetra
.5439 .52642 .54686 .52955 .55241 .52785 .54946 .52471 Mtetra
.54946 .52471 .55241 .52785 .55797 .52615 .55503 .52301 Mtetra
.55503 .52301 .55797 .52615 .56354 .52445 .56061 .5213 Mtetra
.56061 .5213 .56354 .52445 .56912 .52274 .5662 .51958 Mtetra
.5662 .51958 .56912 .52274 .57472 .52103 .5718 .51787 Mtetra
.5718 .51787 .57472 .52103 .58032 .51932 .57741 .51615 Mtetra
.57741 .51615 .58032 .51932 .58594 .5176 .58303 .51442 Mtetra
.58303 .51442 .58594 .5176 .59156 .51588 .58867 .5127 Mtetra
.58867 .5127 .59156 .51588 .5972 .51416 .59432 .51097 Mtetra
.59432 .51097 .5972 .51416 .60285 .51243 .59997 .50923 Mtetra
.59997 .50923 .60285 .51243 .60852 .5107 .60564 .50749 Mtetra
.60564 .50749 .60852 .5107 .61419 .50896 .61133 .50575 Mtetra
.61133 .50575 .61419 .50896 .61988 .50723 .61702 .50401 Mtetra
.61702 .50401 .61988 .50723 .62557 .50548 .62272 .50226 Mtetra
.62272 .50226 .62557 .50548 .63128 .50374 .62844 .50051 Mtetra
.62844 .50051 .63128 .50374 .637 .50199 .63417 .49875 Mtetra
.663 .741 .908 r
.63417 .49875 .637 .50199 .64273 .50024 .63991 .497 Mtetra
.662 .741 .908 r
.63991 .497 .64273 .50024 .64848 .4985 .64566 .49525 Mtetra
.664 .741 .908 r
.64566 .49525 .64848 .4985 .65423 .49674 .65142 .49349 Mtetra
.665 .742 .907 r
.65142 .49349 .65423 .49674 .66 .49496 .6572 .4917 Mtetra
.664 .741 .908 r
.6572 .4917 .66 .49496 .66578 .49319 .66298 .48992 Mtetra
.66298 .48992 .66578 .49319 .67157 .49142 .66878 .48814 Mtetra
.66878 .48814 .67157 .49142 .67737 .48965 .67459 .48636 Mtetra
.67459 .48636 .67737 .48965 .68319 .48787 .68042 .48458 Mtetra
.68042 .48458 .68319 .48787 .68901 .48609 .68625 .48279 Mtetra
.68625 .48279 .68901 .48609 .69485 .4843 .6921 .481 Mtetra
.6921 .481 .69485 .4843 .7007 .48252 .69796 .4792 Mtetra
.69796 .4792 .7007 .48252 .70657 .48072 .70383 .4774 Mtetra
.70383 .4774 .70657 .48072 .71244 .47893 .70971 .4756 Mtetra
.70971 .4756 .71244 .47893 .71833 .47713 .71561 .47379 Mtetra
.71561 .47379 .71833 .47713 .72423 .47532 .72152 .47198 Mtetra
.72152 .47198 .72423 .47532 .73014 .47352 .72744 .47017 Mtetra
.72744 .47017 .73014 .47352 .73606 .47171 .73337 .46835 Mtetra
.73337 .46835 .73606 .47171 .742 .46989 .73931 .46653 Mtetra
.73931 .46653 .742 .46989 .74795 .46807 .74527 .4647 Mtetra
.74527 .4647 .74795 .46807 .75391 .46625 .75124 .46287 Mtetra
.75124 .46287 .75391 .46625 .75988 .46442 .75722 .46104 Mtetra
.75722 .46104 .75988 .46442 .76587 .46259 .76322 .4592 Mtetra
.76322 .4592 .76587 .46259 .77186 .46076 .76922 .45736 Mtetra
.76922 .45736 .77186 .46076 .77788 .45892 .77524 .45552 Mtetra
.77524 .45552 .77788 .45892 .7839 .45708 .78127 .45367 Mtetra
.78127 .45367 .7839 .45708 .78993 .45523 .78732 .45182 Mtetra
.78732 .45182 .78993 .45523 .79598 .45339 .79338 .44996 Mtetra
.79338 .44996 .79598 .45339 .80204 .45153 .79945 .4481 Mtetra
.79945 .4481 .80204 .45153 .80812 .44968 .80553 .44624 Mtetra
.80553 .44624 .80812 .44968 .81421 .44781 .81163 .44437 Mtetra
.81163 .44437 .81421 .44781 .82031 .44595 .81774 .4425 Mtetra
.81774 .4425 .82031 .44595 .82642 .44408 .82386 .44062 Mtetra
.82386 .44062 .82642 .44408 .83254 .44221 .82999 .43874 Mtetra
.82999 .43874 .83254 .44221 .83868 .44033 .83614 .43686 Mtetra
.83614 .43686 .83868 .44033 .84483 .43845 .8423 .43497 Mtetra
.8423 .43497 .84483 .43845 .851 .43657 .84847 .43308 Mtetra
.84847 .43308 .851 .43657 .85718 .43468 .85466 .43118 Mtetra
.85466 .43118 .85718 .43468 .86337 .43278 .86086 .42928 Mtetra
.86086 .42928 .86337 .43278 .86957 .43089 .86708 .42738 Mtetra
.86708 .42738 .86957 .43089 .87579 .42899 .8733 .42547 Mtetra
.8733 .42547 .87579 .42899 .88202 .42708 .87954 .42356 Mtetra
.87954 .42356 .88202 .42708 .88826 .42517 .8858 .42164 Mtetra
.8858 .42164 .88826 .42517 .89452 .42326 .89206 .41972 Mtetra
.89206 .41972 .89452 .42326 .90079 .42134 .89834 .41779 Mtetra
.89834 .41779 .90079 .42134 .90707 .41942 .90464 .41587 Mtetra
.90464 .41587 .90707 .41942 .91337 .4175 .91094 .41393 Mtetra
.91094 .41393 .91337 .4175 .91968 .41557 .91726 .412 Mtetra
.91726 .412 .91968 .41557 .926 .41363 .9236 .41005 Mtetra
.9236 .41005 .926 .41363 .93234 .4117 .92994 .40811 Mtetra
.92994 .40811 .93234 .4117 .93869 .40976 .93631 .40616 Mtetra
.93631 .40616 .93869 .40976 .94506 .40781 .94268 .40421 Mtetra
.94268 .40421 .94506 .40781 .95144 .40586 .94907 .40225 Mtetra
.37385 .5746 .37703 .57756 .38225 .57595 .37908 .57299 Mtetra
.37908 .57299 .38225 .57595 .38749 .57435 .38433 .57138 Mtetra
.38433 .57138 .38749 .57435 .39274 .57274 .38958 .56977 Mtetra
.38958 .56977 .39274 .57274 .39799 .57113 .39484 .56815 Mtetra
.39484 .56815 .39799 .57113 .40326 .56952 .40011 .56653 Mtetra
.40011 .56653 .40326 .56952 .40854 .5679 .4054 .56491 Mtetra
.4054 .56491 .40854 .5679 .41382 .56628 .41069 .56328 Mtetra
.41069 .56328 .41382 .56628 .41912 .56466 .41599 .56165 Mtetra
.41599 .56165 .41912 .56466 .42443 .56303 .42131 .56002 Mtetra
.42131 .56002 .42443 .56303 .42975 .5614 .42663 .55838 Mtetra
.42663 .55838 .42975 .5614 .43507 .55977 .43197 .55674 Mtetra
.43197 .55674 .43507 .55977 .44041 .55813 .43731 .5551 Mtetra
.43731 .5551 .44041 .55813 .44576 .55649 .44267 .55346 Mtetra
.44267 .55346 .44576 .55649 .45112 .55485 .44804 .55181 Mtetra
.44804 .55181 .45112 .55485 .4565 .5532 .45342 .55015 Mtetra
.45342 .55015 .4565 .5532 .46188 .55155 .4588 .5485 Mtetra
.4588 .5485 .46188 .55155 .46727 .5499 .4642 .54684 Mtetra
.4642 .54684 .46727 .5499 .47267 .54824 .46961 .54518 Mtetra
.46961 .54518 .47267 .54824 .47809 .54659 .47503 .54351 Mtetra
.47503 .54351 .47809 .54659 .48351 .54492 .48047 .54185 Mtetra
.48047 .54185 .48351 .54492 .48895 .54326 .48591 .54017 Mtetra
.48591 .54017 .48895 .54326 .49439 .54159 .49136 .5385 Mtetra
.49136 .5385 .49439 .54159 .49985 .53992 .49683 .53682 Mtetra
.49683 .53682 .49985 .53992 .50532 .53824 .5023 .53514 Mtetra
.5023 .53514 .50532 .53824 .5108 .53656 .50779 .53345 Mtetra
.50779 .53345 .5108 .53656 .51629 .53488 .51328 .53176 Mtetra
.51328 .53176 .51629 .53488 .52179 .53319 .51879 .53007 Mtetra
.51879 .53007 .52179 .53319 .5273 .5315 .52431 .52838 Mtetra
.52431 .52838 .5273 .5315 .53282 .52981 .52984 .52668 Mtetra
.52984 .52668 .53282 .52981 .53836 .52811 .53538 .52497 Mtetra
.53538 .52497 .53836 .52811 .5439 .52642 .54094 .52327 Mtetra
.54094 .52327 .5439 .52642 .54946 .52471 .5465 .52156 Mtetra
.5465 .52156 .54946 .52471 .55503 .52301 .55207 .51985 Mtetra
.55207 .51985 .55503 .52301 .56061 .5213 .55766 .51813 Mtetra
.55766 .51813 .56061 .5213 .5662 .51958 .56326 .51641 Mtetra
.56326 .51641 .5662 .51958 .5718 .51787 .56887 .51469 Mtetra
.56887 .51469 .5718 .51787 .57741 .51615 .57449 .51296 Mtetra
.57449 .51296 .57741 .51615 .58303 .51442 .58012 .51123 Mtetra
.58012 .51123 .58303 .51442 .58867 .5127 .58576 .5095 Mtetra
.58576 .5095 .58867 .5127 .59432 .51097 .59142 .50776 Mtetra
.59142 .50776 .59432 .51097 .59997 .50923 .59708 .50602 Mtetra
.59708 .50602 .59997 .50923 .60564 .50749 .60276 .50428 Mtetra
.60276 .50428 .60564 .50749 .61133 .50575 .60845 .50253 Mtetra
.60845 .50253 .61133 .50575 .61702 .50401 .61415 .50078 Mtetra
.61415 .50078 .61702 .50401 .62272 .50226 .61986 .49902 Mtetra
.61986 .49902 .62272 .50226 .62844 .50051 .62559 .49726 Mtetra
.62559 .49726 .62844 .50051 .63417 .49875 .63132 .4955 Mtetra
.663 .741 .908 r
.63132 .4955 .63417 .49875 .63991 .497 .63707 .49374 Mtetra
.662 .741 .908 r
.63707 .49374 .63991 .497 .64566 .49525 .64283 .49199 Mtetra
.664 .741 .908 r
.64283 .49199 .64566 .49525 .65142 .49349 .6486 .49022 Mtetra
.665 .742 .907 r
.6486 .49022 .65142 .49349 .6572 .4917 .65439 .48842 Mtetra
.664 .741 .908 r
.65439 .48842 .6572 .4917 .66298 .48992 .66018 .48664 Mtetra
.66018 .48664 .66298 .48992 .66878 .48814 .66599 .48485 Mtetra
.66599 .48485 .66878 .48814 .67459 .48636 .67181 .48307 Mtetra
.67181 .48307 .67459 .48636 .68042 .48458 .67764 .48128 Mtetra
.67764 .48128 .68042 .48458 .68625 .48279 .68348 .47948 Mtetra
.68348 .47948 .68625 .48279 .6921 .481 .68934 .47768 Mtetra
.68934 .47768 .6921 .481 .69796 .4792 .6952 .47588 Mtetra
.6952 .47588 .69796 .4792 .70383 .4774 .70108 .47407 Mtetra
.70108 .47407 .70383 .4774 .70971 .4756 .70697 .47226 Mtetra
.70697 .47226 .70971 .4756 .71561 .47379 .71288 .47045 Mtetra
.71288 .47045 .71561 .47379 .72152 .47198 .71879 .46863 Mtetra
.71879 .46863 .72152 .47198 .72744 .47017 .72472 .46681 Mtetra
.72472 .46681 .72744 .47017 .73337 .46835 .73066 .46499 Mtetra
.73066 .46499 .73337 .46835 .73931 .46653 .73662 .46316 Mtetra
.73662 .46316 .73931 .46653 .74527 .4647 .74258 .46132 Mtetra
.74258 .46132 .74527 .4647 .75124 .46287 .74856 .45949 Mtetra
.74856 .45949 .75124 .46287 .75722 .46104 .75455 .45765 Mtetra
.75455 .45765 .75722 .46104 .76322 .4592 .76056 .4558 Mtetra
.76056 .4558 .76322 .4592 .76922 .45736 .76657 .45395 Mtetra
.76657 .45395 .76922 .45736 .77524 .45552 .7726 .4521 Mtetra
.7726 .4521 .77524 .45552 .78127 .45367 .77864 .45025 Mtetra
.77864 .45025 .78127 .45367 .78732 .45182 .7847 .44839 Mtetra
.7847 .44839 .78732 .45182 .79338 .44996 .79076 .44652 Mtetra
.79076 .44652 .79338 .44996 .79945 .4481 .79684 .44466 Mtetra
.79684 .44466 .79945 .4481 .80553 .44624 .80293 .44278 Mtetra
.80293 .44278 .80553 .44624 .81163 .44437 .80904 .44091 Mtetra
.80904 .44091 .81163 .44437 .81774 .4425 .81516 .43903 Mtetra
.81516 .43903 .81774 .4425 .82386 .44062 .82129 .43715 Mtetra
.82129 .43715 .82386 .44062 .82999 .43874 .82743 .43526 Mtetra
.82743 .43526 .82999 .43874 .83614 .43686 .83359 .43337 Mtetra
.83359 .43337 .83614 .43686 .8423 .43497 .83976 .43147 Mtetra
.83976 .43147 .8423 .43497 .84847 .43308 .84594 .42957 Mtetra
.84594 .42957 .84847 .43308 .85466 .43118 .85214 .42767 Mtetra
.85214 .42767 .85466 .43118 .86086 .42928 .85835 .42576 Mtetra
.85835 .42576 .86086 .42928 .86708 .42738 .86457 .42385 Mtetra
.86457 .42385 .86708 .42738 .8733 .42547 .87081 .42193 Mtetra
.87081 .42193 .8733 .42547 .87954 .42356 .87706 .42001 Mtetra
.87706 .42001 .87954 .42356 .8858 .42164 .88332 .41809 Mtetra
.88332 .41809 .8858 .42164 .89206 .41972 .8896 .41616 Mtetra
.8896 .41616 .89206 .41972 .89834 .41779 .89589 .41423 Mtetra
.89589 .41423 .89834 .41779 .90464 .41587 .90219 .41229 Mtetra
.90219 .41229 .90464 .41587 .91094 .41393 .90851 .41035 Mtetra
.90851 .41035 .91094 .41393 .91726 .412 .91484 .40841 Mtetra
.91484 .40841 .91726 .412 .9236 .41005 .92118 .40646 Mtetra
.92118 .40646 .9236 .41005 .92994 .40811 .92754 .40451 Mtetra
.92754 .40451 .92994 .40811 .93631 .40616 .93391 .40255 Mtetra
.93391 .40255 .93631 .40616 .94268 .40421 .9403 .40059 Mtetra
.9403 .40059 .94268 .40421 .94907 .40225 .94669 .39862 Mtetra
.37066 .57163 .37385 .5746 .37908 .57299 .3759 .57001 Mtetra
.3759 .57001 .37908 .57299 .38433 .57138 .38115 .5684 Mtetra
.38115 .5684 .38433 .57138 .38958 .56977 .38641 .56678 Mtetra
.38641 .56678 .38958 .56977 .39484 .56815 .39168 .56516 Mtetra
.39168 .56516 .39484 .56815 .40011 .56653 .39696 .56353 Mtetra
.39696 .56353 .40011 .56653 .4054 .56491 .40225 .5619 Mtetra
.40225 .5619 .4054 .56491 .41069 .56328 .40755 .56027 Mtetra
.40755 .56027 .41069 .56328 .41599 .56165 .41286 .55863 Mtetra
.41286 .55863 .41599 .56165 .42131 .56002 .41818 .557 Mtetra
.41818 .557 .42131 .56002 .42663 .55838 .42351 .55535 Mtetra
.42351 .55535 .42663 .55838 .43197 .55674 .42885 .55371 Mtetra
.42885 .55371 .43197 .55674 .43731 .5551 .4342 .55206 Mtetra
.4342 .55206 .43731 .5551 .44267 .55346 .43957 .55041 Mtetra
.43957 .55041 .44267 .55346 .44804 .55181 .44494 .54875 Mtetra
.44494 .54875 .44804 .55181 .45342 .55015 .45033 .5471 Mtetra
.45033 .5471 .45342 .55015 .4588 .5485 .45572 .54543 Mtetra
.45572 .54543 .4588 .5485 .4642 .54684 .46113 .54377 Mtetra
.46113 .54377 .4642 .54684 .46961 .54518 .46654 .5421 Mtetra
.46654 .5421 .46961 .54518 .47503 .54351 .47197 .54043 Mtetra
.47197 .54043 .47503 .54351 .48047 .54185 .47741 .53876 Mtetra
.47741 .53876 .48047 .54185 .48591 .54017 .48286 .53708 Mtetra
.48286 .53708 .48591 .54017 .49136 .5385 .48832 .5354 Mtetra
.48832 .5354 .49136 .5385 .49683 .53682 .49379 .53371 Mtetra
.49379 .53371 .49683 .53682 .5023 .53514 .49927 .53202 Mtetra
.49927 .53202 .5023 .53514 .50779 .53345 .50477 .53033 Mtetra
.50477 .53033 .50779 .53345 .51328 .53176 .51027 .52864 Mtetra
.51027 .52864 .51328 .53176 .51879 .53007 .51579 .52694 Mtetra
.51579 .52694 .51879 .53007 .52431 .52838 .52131 .52524 Mtetra
.52131 .52524 .52431 .52838 .52984 .52668 .52685 .52353 Mtetra
.52685 .52353 .52984 .52668 .53538 .52497 .5324 .52182 Mtetra
.5324 .52182 .53538 .52497 .54094 .52327 .53796 .52011 Mtetra
.53796 .52011 .54094 .52327 .5465 .52156 .54353 .5184 Mtetra
.54353 .5184 .5465 .52156 .55207 .51985 .54911 .51668 Mtetra
.54911 .51668 .55207 .51985 .55766 .51813 .55471 .51495 Mtetra
.55471 .51495 .55766 .51813 .56326 .51641 .56031 .51323 Mtetra
.56031 .51323 .56326 .51641 .56887 .51469 .56593 .5115 Mtetra
.56593 .5115 .56887 .51469 .57449 .51296 .57155 .50977 Mtetra
.57155 .50977 .57449 .51296 .58012 .51123 .57719 .50803 Mtetra
.57719 .50803 .58012 .51123 .58576 .5095 .58284 .50629 Mtetra
.58284 .50629 .58576 .5095 .59142 .50776 .58851 .50455 Mtetra
.58851 .50455 .59142 .50776 .59708 .50602 .59418 .5028 Mtetra
.59418 .5028 .59708 .50602 .60276 .50428 .59987 .50105 Mtetra
.59987 .50105 .60276 .50428 .60845 .50253 .60556 .49929 Mtetra
.60556 .49929 .60845 .50253 .61415 .50078 .61127 .49754 Mtetra
.61127 .49754 .61415 .50078 .61986 .49902 .61699 .49577 Mtetra
.61699 .49577 .61986 .49902 .62559 .49726 .62272 .49401 Mtetra
.62272 .49401 .62559 .49726 .63132 .4955 .62847 .49224 Mtetra
.663 .741 .908 r
.62847 .49224 .63132 .4955 .63707 .49374 .63422 .49047 Mtetra
.662 .741 .908 r
.63422 .49047 .63707 .49374 .64283 .49199 .63999 .48872 Mtetra
.664 .741 .908 r
.63999 .48872 .64283 .49199 .6486 .49022 .64577 .48694 Mtetra
.665 .742 .907 r
.64577 .48694 .6486 .49022 .65439 .48842 .65156 .48513 Mtetra
.664 .741 .908 r
.65156 .48513 .65439 .48842 .66018 .48664 .65737 .48334 Mtetra
.65737 .48334 .66018 .48664 .66599 .48485 .66318 .48155 Mtetra
.66318 .48155 .66599 .48485 .67181 .48307 .66901 .47976 Mtetra
.66901 .47976 .67181 .48307 .67764 .48128 .67485 .47796 Mtetra
.67485 .47796 .67764 .48128 .68348 .47948 .6807 .47616 Mtetra
.6807 .47616 .68348 .47948 .68934 .47768 .68656 .47435 Mtetra
.68656 .47435 .68934 .47768 .6952 .47588 .69244 .47254 Mtetra
.69244 .47254 .6952 .47588 .70108 .47407 .69833 .47073 Mtetra
.69833 .47073 .70108 .47407 .70697 .47226 .70423 .46891 Mtetra
.70423 .46891 .70697 .47226 .71288 .47045 .71014 .46709 Mtetra
.71014 .46709 .71288 .47045 .71879 .46863 .71606 .46527 Mtetra
.71606 .46527 .71879 .46863 .72472 .46681 .722 .46344 Mtetra
.722 .46344 .72472 .46681 .73066 .46499 .72795 .46161 Mtetra
.72795 .46161 .73066 .46499 .73662 .46316 .73391 .45977 Mtetra
.73391 .45977 .73662 .46316 .74258 .46132 .73989 .45793 Mtetra
.73989 .45793 .74258 .46132 .74856 .45949 .74587 .45609 Mtetra
.74587 .45609 .74856 .45949 .75455 .45765 .75187 .45424 Mtetra
.75187 .45424 .75455 .45765 .76056 .4558 .75788 .45239 Mtetra
.75788 .45239 .76056 .4558 .76657 .45395 .76391 .45053 Mtetra
.76391 .45053 .76657 .45395 .7726 .4521 .76995 .44867 Mtetra
.76995 .44867 .7726 .4521 .77864 .45025 .776 .44681 Mtetra
.776 .44681 .77864 .45025 .7847 .44839 .78206 .44494 Mtetra
.78206 .44494 .7847 .44839 .79076 .44652 .78814 .44307 Mtetra
.78814 .44307 .79076 .44652 .79684 .44466 .79422 .4412 Mtetra
.79422 .4412 .79684 .44466 .80293 .44278 .80033 .43932 Mtetra
.80033 .43932 .80293 .44278 .80904 .44091 .80644 .43744 Mtetra
.80644 .43744 .80904 .44091 .81516 .43903 .81257 .43555 Mtetra
.81257 .43555 .81516 .43903 .82129 .43715 .81871 .43366 Mtetra
.81871 .43366 .82129 .43715 .82743 .43526 .82486 .43176 Mtetra
.82486 .43176 .82743 .43526 .83359 .43337 .83103 .42986 Mtetra
.83103 .42986 .83359 .43337 .83976 .43147 .83721 .42796 Mtetra
.83721 .42796 .83976 .43147 .84594 .42957 .8434 .42606 Mtetra
.8434 .42606 .84594 .42957 .85214 .42767 .84961 .42414 Mtetra
.84961 .42414 .85214 .42767 .85835 .42576 .85582 .42223 Mtetra
.85582 .42223 .85835 .42576 .86457 .42385 .86206 .42031 Mtetra
.86206 .42031 .86457 .42385 .87081 .42193 .8683 .41839 Mtetra
.8683 .41839 .87081 .42193 .87706 .42001 .87456 .41646 Mtetra
.87456 .41646 .87706 .42001 .88332 .41809 .88083 .41453 Mtetra
.88083 .41453 .88332 .41809 .8896 .41616 .88712 .41259 Mtetra
.88712 .41259 .8896 .41616 .89589 .41423 .89342 .41065 Mtetra
.89342 .41065 .89589 .41423 .90219 .41229 .89973 .40871 Mtetra
.89973 .40871 .90219 .41229 .90851 .41035 .90606 .40676 Mtetra
.90606 .40676 .90851 .41035 .91484 .40841 .9124 .40481 Mtetra
.9124 .40481 .91484 .40841 .92118 .40646 .91875 .40285 Mtetra
.91875 .40285 .92118 .40646 .92754 .40451 .92512 .40089 Mtetra
.92512 .40089 .92754 .40451 .93391 .40255 .9315 .39892 Mtetra
.9315 .39892 .93391 .40255 .9403 .40059 .9379 .39696 Mtetra
.9379 .39696 .9403 .40059 .94669 .39862 .94431 .39498 Mtetra
.36746 .56865 .37066 .57163 .3759 .57001 .37271 .56703 Mtetra
.37271 .56703 .3759 .57001 .38115 .5684 .37796 .56541 Mtetra
.37796 .56541 .38115 .5684 .38641 .56678 .38323 .56378 Mtetra
.38323 .56378 .38641 .56678 .39168 .56516 .3885 .56215 Mtetra
.3885 .56215 .39168 .56516 .39696 .56353 .39379 .56052 Mtetra
.39379 .56052 .39696 .56353 .40225 .5619 .39908 .55889 Mtetra
.39908 .55889 .40225 .5619 .40755 .56027 .40439 .55725 Mtetra
.40439 .55725 .40755 .56027 .41286 .55863 .40971 .55561 Mtetra
.40971 .55561 .41286 .55863 .41818 .557 .41503 .55396 Mtetra
.41503 .55396 .41818 .557 .42351 .55535 .42037 .55231 Mtetra
.42037 .55231 .42351 .55535 .42885 .55371 .42572 .55066 Mtetra
.42572 .55066 .42885 .55371 .4342 .55206 .43108 .54901 Mtetra
.43108 .54901 .4342 .55206 .43957 .55041 .43645 .54735 Mtetra
.43645 .54735 .43957 .55041 .44494 .54875 .44183 .54569 Mtetra
.44183 .54569 .44494 .54875 .45033 .5471 .44722 .54403 Mtetra
.44722 .54403 .45033 .5471 .45572 .54543 .45263 .54236 Mtetra
.45263 .54236 .45572 .54543 .46113 .54377 .45804 .54069 Mtetra
.45804 .54069 .46113 .54377 .46654 .5421 .46346 .53901 Mtetra
.46346 .53901 .46654 .5421 .47197 .54043 .4689 .53734 Mtetra
.4689 .53734 .47197 .54043 .47741 .53876 .47434 .53566 Mtetra
.47434 .53566 .47741 .53876 .48286 .53708 .4798 .53397 Mtetra
.4798 .53397 .48286 .53708 .48832 .5354 .48527 .53228 Mtetra
.48527 .53228 .48832 .5354 .49379 .53371 .49074 .53059 Mtetra
.49074 .53059 .49379 .53371 .49927 .53202 .49623 .5289 Mtetra
.49623 .5289 .49927 .53202 .50477 .53033 .50173 .5272 Mtetra
.50173 .5272 .50477 .53033 .51027 .52864 .50725 .5255 Mtetra
.50725 .5255 .51027 .52864 .51579 .52694 .51277 .52379 Mtetra
.51277 .52379 .51579 .52694 .52131 .52524 .5183 .52209 Mtetra
.5183 .52209 .52131 .52524 .52685 .52353 .52385 .52037 Mtetra
.52385 .52037 .52685 .52353 .5324 .52182 .5294 .51866 Mtetra
.5294 .51866 .5324 .52182 .53796 .52011 .53497 .51694 Mtetra
.53497 .51694 .53796 .52011 .54353 .5184 .54055 .51522 Mtetra
.54055 .51522 .54353 .5184 .54911 .51668 .54614 .51349 Mtetra
.54614 .51349 .54911 .51668 .55471 .51495 .55174 .51176 Mtetra
.55174 .51176 .55471 .51495 .56031 .51323 .55735 .51003 Mtetra
.55735 .51003 .56031 .51323 .56593 .5115 .56298 .5083 Mtetra
.56298 .5083 .56593 .5115 .57155 .50977 .56861 .50656 Mtetra
.56861 .50656 .57155 .50977 .57719 .50803 .57426 .50481 Mtetra
.57426 .50481 .57719 .50803 .58284 .50629 .57992 .50307 Mtetra
.57992 .50307 .58284 .50629 .58851 .50455 .58559 .50132 Mtetra
.58559 .50132 .58851 .50455 .59418 .5028 .59127 .49956 Mtetra
.59127 .49956 .59418 .5028 .59987 .50105 .59696 .49781 Mtetra
.59696 .49781 .59987 .50105 .60556 .49929 .60267 .49605 Mtetra
.60267 .49605 .60556 .49929 .61127 .49754 .60838 .49428 Mtetra
.60838 .49428 .61127 .49754 .61699 .49577 .61411 .49251 Mtetra
.61411 .49251 .61699 .49577 .62272 .49401 .61985 .49074 Mtetra
.61985 .49074 .62272 .49401 .62847 .49224 .6256 .48897 Mtetra
.663 .741 .908 r
.6256 .48897 .62847 .49224 .63422 .49047 .63137 .48719 Mtetra
.662 .741 .908 r
.63137 .48719 .63422 .49047 .63999 .48872 .63714 .48543 Mtetra
.664 .741 .908 r
.63714 .48543 .63999 .48872 .64577 .48694 .64293 .48364 Mtetra
.665 .742 .907 r
.64293 .48364 .64577 .48694 .65156 .48513 .64873 .48183 Mtetra
.664 .741 .908 r
.64873 .48183 .65156 .48513 .65737 .48334 .65454 .48003 Mtetra
.65454 .48003 .65737 .48334 .66318 .48155 .66036 .47824 Mtetra
.66036 .47824 .66318 .48155 .66901 .47976 .6662 .47643 Mtetra
.6662 .47643 .66901 .47976 .67485 .47796 .67205 .47463 Mtetra
.67205 .47463 .67485 .47796 .6807 .47616 .67791 .47282 Mtetra
.67791 .47282 .6807 .47616 .68656 .47435 .68378 .47101 Mtetra
.68378 .47101 .68656 .47435 .69244 .47254 .68966 .46919 Mtetra
.68966 .46919 .69244 .47254 .69833 .47073 .69556 .46737 Mtetra
.69556 .46737 .69833 .47073 .70423 .46891 .70147 .46555 Mtetra
.70147 .46555 .70423 .46891 .71014 .46709 .70739 .46372 Mtetra
.70739 .46372 .71014 .46709 .71606 .46527 .71332 .46189 Mtetra
.71332 .46189 .71606 .46527 .722 .46344 .71927 .46005 Mtetra
.71927 .46005 .722 .46344 .72795 .46161 .72522 .45821 Mtetra
.72522 .45821 .72795 .46161 .73391 .45977 .7312 .45637 Mtetra
.7312 .45637 .73391 .45977 .73989 .45793 .73718 .45452 Mtetra
.73718 .45452 .73989 .45793 .74587 .45609 .74317 .45267 Mtetra
.74317 .45267 .74587 .45609 .75187 .45424 .74918 .45082 Mtetra
.74918 .45082 .75187 .45424 .75788 .45239 .7552 .44896 Mtetra
.7552 .44896 .75788 .45239 .76391 .45053 .76124 .4471 Mtetra
.76124 .4471 .76391 .45053 .76995 .44867 .76728 .44523 Mtetra
.76728 .44523 .76995 .44867 .776 .44681 .77334 .44336 Mtetra
.77334 .44336 .776 .44681 .78206 .44494 .77941 .44149 Mtetra
.77941 .44149 .78206 .44494 .78814 .44307 .7855 .43961 Mtetra
.7855 .43961 .78814 .44307 .79422 .4412 .7916 .43773 Mtetra
.7916 .43773 .79422 .4412 .80033 .43932 .79771 .43584 Mtetra
.79771 .43584 .80033 .43932 .80644 .43744 .80383 .43395 Mtetra
.80383 .43395 .80644 .43744 .81257 .43555 .80997 .43206 Mtetra
.80997 .43206 .81257 .43555 .81871 .43366 .81612 .43016 Mtetra
.81612 .43016 .81871 .43366 .82486 .43176 .82228 .42826 Mtetra
.82228 .42826 .82486 .43176 .83103 .42986 .82846 .42635 Mtetra
.82846 .42635 .83103 .42986 .83721 .42796 .83464 .42444 Mtetra
.83464 .42444 .83721 .42796 .8434 .42606 .84085 .42252 Mtetra
.84085 .42252 .8434 .42606 .84961 .42414 .84706 .42061 Mtetra
.84706 .42061 .84961 .42414 .85582 .42223 .85329 .41868 Mtetra
.85329 .41868 .85582 .42223 .86206 .42031 .85953 .41676 Mtetra
.85953 .41676 .86206 .42031 .8683 .41839 .86579 .41482 Mtetra
.86579 .41482 .8683 .41839 .87456 .41646 .87206 .41289 Mtetra
.87206 .41289 .87456 .41646 .88083 .41453 .87834 .41095 Mtetra
.87834 .41095 .88083 .41453 .88712 .41259 .88464 .40901 Mtetra
.88464 .40901 .88712 .41259 .89342 .41065 .89095 .40706 Mtetra
.89095 .40706 .89342 .41065 .89973 .40871 .89727 .40511 Mtetra
.89727 .40511 .89973 .40871 .90606 .40676 .90361 .40315 Mtetra
.90361 .40315 .90606 .40676 .9124 .40481 .90996 .40119 Mtetra
.90996 .40119 .9124 .40481 .91875 .40285 .91632 .39923 Mtetra
.91632 .39923 .91875 .40285 .92512 .40089 .9227 .39726 Mtetra
.9227 .39726 .92512 .40089 .9315 .39892 .92909 .39529 Mtetra
.92909 .39529 .9315 .39892 .9379 .39696 .93549 .39331 Mtetra
.93549 .39331 .9379 .39696 .94431 .39498 .94191 .39133 Mtetra
.36425 .56566 .36746 .56865 .37271 .56703 .3695 .56403 Mtetra
.3695 .56403 .37271 .56703 .37796 .56541 .37476 .5624 Mtetra
.37476 .5624 .37796 .56541 .38323 .56378 .38003 .56077 Mtetra
.38003 .56077 .38323 .56378 .3885 .56215 .38531 .55914 Mtetra
.38531 .55914 .3885 .56215 .39379 .56052 .39061 .5575 Mtetra
.39061 .5575 .39379 .56052 .39908 .55889 .39591 .55586 Mtetra
.39591 .55586 .39908 .55889 .40439 .55725 .40122 .55422 Mtetra
.40122 .55422 .40439 .55725 .40971 .55561 .40655 .55257 Mtetra
.40655 .55257 .40971 .55561 .41503 .55396 .41188 .55092 Mtetra
.41188 .55092 .41503 .55396 .42037 .55231 .41723 .54926 Mtetra
.41723 .54926 .42037 .55231 .42572 .55066 .42258 .54761 Mtetra
.42258 .54761 .42572 .55066 .43108 .54901 .42795 .54595 Mtetra
.42795 .54595 .43108 .54901 .43645 .54735 .43332 .54428 Mtetra
.43332 .54428 .43645 .54735 .44183 .54569 .43871 .54262 Mtetra
.43871 .54262 .44183 .54569 .44722 .54403 .44411 .54095 Mtetra
.44411 .54095 .44722 .54403 .45263 .54236 .44952 .53927 Mtetra
.44952 .53927 .45263 .54236 .45804 .54069 .45494 .53759 Mtetra
.45494 .53759 .45804 .54069 .46346 .53901 .46037 .53591 Mtetra
.46037 .53591 .46346 .53901 .4689 .53734 .46581 .53423 Mtetra
.46581 .53423 .4689 .53734 .47434 .53566 .47126 .53254 Mtetra
.47126 .53254 .47434 .53566 .4798 .53397 .47673 .53085 Mtetra
.47673 .53085 .4798 .53397 .48527 .53228 .4822 .52916 Mtetra
.4822 .52916 .48527 .53228 .49074 .53059 .48769 .52746 Mtetra
.48769 .52746 .49074 .53059 .49623 .5289 .49318 .52576 Mtetra
.49318 .52576 .49623 .5289 .50173 .5272 .49869 .52406 Mtetra
.49869 .52406 .50173 .5272 .50725 .5255 .50421 .52235 Mtetra
.50421 .52235 .50725 .5255 .51277 .52379 .50974 .52064 Mtetra
.50974 .52064 .51277 .52379 .5183 .52209 .51528 .51892 Mtetra
.51528 .51892 .5183 .52209 .52385 .52037 .52083 .51721 Mtetra
.52083 .51721 .52385 .52037 .5294 .51866 .52639 .51548 Mtetra
.52639 .51548 .5294 .51866 .53497 .51694 .53197 .51376 Mtetra
.53197 .51376 .53497 .51694 .54055 .51522 .53756 .51203 Mtetra
.53756 .51203 .54055 .51522 .54614 .51349 .54315 .5103 Mtetra
.54315 .5103 .54614 .51349 .55174 .51176 .54876 .50856 Mtetra
.54876 .50856 .55174 .51176 .55735 .51003 .55438 .50682 Mtetra
.55438 .50682 .55735 .51003 .56298 .5083 .56001 .50508 Mtetra
.56001 .50508 .56298 .5083 .56861 .50656 .56566 .50334 Mtetra
.56566 .50334 .56861 .50656 .57426 .50481 .57131 .50159 Mtetra
.57131 .50159 .57426 .50481 .57992 .50307 .57698 .49983 Mtetra
.57698 .49983 .57992 .50307 .58559 .50132 .58265 .49808 Mtetra
.58265 .49808 .58559 .50132 .59127 .49956 .58834 .49632 Mtetra
.58834 .49632 .59127 .49956 .59696 .49781 .59404 .49455 Mtetra
.59404 .49455 .59696 .49781 .60267 .49605 .59976 .49278 Mtetra
.59976 .49278 .60267 .49605 .60838 .49428 .60548 .49101 Mtetra
.60548 .49101 .60838 .49428 .61411 .49251 .61122 .48924 Mtetra
.61122 .48924 .61411 .49251 .61985 .49074 .61697 .48746 Mtetra
.61697 .48746 .61985 .49074 .6256 .48897 .62273 .48568 Mtetra
.663 .741 .908 r
.62273 .48568 .6256 .48897 .63137 .48719 .6285 .48389 Mtetra
.662 .741 .908 r
.6285 .48389 .63137 .48719 .63714 .48543 .63428 .48213 Mtetra
.664 .741 .908 r
.63428 .48213 .63714 .48543 .64293 .48364 .64008 .48034 Mtetra
.665 .742 .907 r
.64008 .48034 .64293 .48364 .64873 .48183 .64588 .47851 Mtetra
.664 .741 .908 r
.64588 .47851 .64873 .48183 .65454 .48003 .6517 .47671 Mtetra
.6517 .47671 .65454 .48003 .66036 .47824 .65753 .47491 Mtetra
.65753 .47491 .66036 .47824 .6662 .47643 .66338 .4731 Mtetra
.66338 .4731 .6662 .47643 .67205 .47463 .66923 .47129 Mtetra
.66923 .47129 .67205 .47463 .67791 .47282 .6751 .46947 Mtetra
.6751 .46947 .67791 .47282 .68378 .47101 .68098 .46765 Mtetra
.68098 .46765 .68378 .47101 .68966 .46919 .68688 .46583 Mtetra
.68688 .46583 .68966 .46919 .69556 .46737 .69278 .464 Mtetra
.69278 .464 .69556 .46737 .70147 .46555 .6987 .46217 Mtetra
.6987 .46217 .70147 .46555 .70739 .46372 .70463 .46034 Mtetra
.70463 .46034 .70739 .46372 .71332 .46189 .71057 .4585 Mtetra
.71057 .4585 .71332 .46189 .71927 .46005 .71652 .45665 Mtetra
.71652 .45665 .71927 .46005 .72522 .45821 .72249 .45481 Mtetra
.72249 .45481 .72522 .45821 .7312 .45637 .72847 .45296 Mtetra
.72847 .45296 .7312 .45637 .73718 .45452 .73446 .4511 Mtetra
.73446 .4511 .73718 .45452 .74317 .45267 .74047 .44925 Mtetra
.74047 .44925 .74317 .45267 .74918 .45082 .74648 .44738 Mtetra
.74648 .44738 .74918 .45082 .7552 .44896 .75251 .44552 Mtetra
.75251 .44552 .7552 .44896 .76124 .4471 .75855 .44365 Mtetra
.75855 .44365 .76124 .4471 .76728 .44523 .76461 .44178 Mtetra
.76461 .44178 .76728 .44523 .77334 .44336 .77068 .4399 Mtetra
.77068 .4399 .77334 .44336 .77941 .44149 .77676 .43802 Mtetra
.77676 .43802 .77941 .44149 .7855 .43961 .78285 .43613 Mtetra
.78285 .43613 .7855 .43961 .7916 .43773 .78896 .43424 Mtetra
.78896 .43424 .7916 .43773 .79771 .43584 .79508 .43235 Mtetra
.79508 .43235 .79771 .43584 .80383 .43395 .80121 .43045 Mtetra
.80121 .43045 .80383 .43395 .80997 .43206 .80736 .42855 Mtetra
.80736 .42855 .80997 .43206 .81612 .43016 .81352 .42664 Mtetra
.81352 .42664 .81612 .43016 .82228 .42826 .81969 .42473 Mtetra
.81969 .42473 .82228 .42826 .82846 .42635 .82587 .42282 Mtetra
.82587 .42282 .82846 .42635 .83464 .42444 .83207 .4209 Mtetra
.83207 .4209 .83464 .42444 .84085 .42252 .83828 .41898 Mtetra
.83828 .41898 .84085 .42252 .84706 .42061 .84451 .41705 Mtetra
.84451 .41705 .84706 .42061 .85329 .41868 .85075 .41512 Mtetra
.85075 .41512 .85329 .41868 .85953 .41676 .857 .41319 Mtetra
.857 .41319 .85953 .41676 .86579 .41482 .86326 .41125 Mtetra
.86326 .41125 .86579 .41482 .87206 .41289 .86954 .40931 Mtetra
.86954 .40931 .87206 .41289 .87834 .41095 .87584 .40736 Mtetra
.87584 .40736 .87834 .41095 .88464 .40901 .88214 .40541 Mtetra
.88214 .40541 .88464 .40901 .89095 .40706 .88846 .40345 Mtetra
.88846 .40345 .89095 .40706 .89727 .40511 .89479 .40149 Mtetra
.89479 .40149 .89727 .40511 .90361 .40315 .90114 .39953 Mtetra
.90114 .39953 .90361 .40315 .90996 .40119 .9075 .39756 Mtetra
.9075 .39756 .90996 .40119 .91632 .39923 .91387 .39559 Mtetra
.91387 .39559 .91632 .39923 .9227 .39726 .92026 .39361 Mtetra
.92026 .39361 .9227 .39726 .92909 .39529 .92666 .39163 Mtetra
.92666 .39163 .92909 .39529 .93549 .39331 .93308 .38965 Mtetra
.93308 .38965 .93549 .39331 .94191 .39133 .93951 .38766 Mtetra
.36103 .56265 .36425 .56566 .3695 .56403 .36628 .56102 Mtetra
.36628 .56102 .3695 .56403 .37476 .5624 .37155 .55939 Mtetra
.37155 .55939 .37476 .5624 .38003 .56077 .37683 .55775 Mtetra
.37683 .55775 .38003 .56077 .38531 .55914 .38212 .55611 Mtetra
.38212 .55611 .38531 .55914 .39061 .5575 .38741 .55447 Mtetra
.38741 .55447 .39061 .5575 .39591 .55586 .39272 .55282 Mtetra
.39272 .55282 .39591 .55586 .40122 .55422 .39804 .55117 Mtetra
.39804 .55117 .40122 .55422 .40655 .55257 .40337 .54952 Mtetra
.40337 .54952 .40655 .55257 .41188 .55092 .40871 .54786 Mtetra
.40871 .54786 .41188 .55092 .41723 .54926 .41407 .5462 Mtetra
.41407 .5462 .41723 .54926 .42258 .54761 .41943 .54454 Mtetra
.41943 .54454 .42258 .54761 .42795 .54595 .4248 .54287 Mtetra
.4248 .54287 .42795 .54595 .43332 .54428 .43018 .5412 Mtetra
.43018 .5412 .43332 .54428 .43871 .54262 .43558 .53953 Mtetra
.43558 .53953 .43871 .54262 .44411 .54095 .44098 .53785 Mtetra
.44098 .53785 .44411 .54095 .44952 .53927 .4464 .53617 Mtetra
.4464 .53617 .44952 .53927 .45494 .53759 .45183 .53449 Mtetra
.45183 .53449 .45494 .53759 .46037 .53591 .45726 .5328 Mtetra
.45726 .5328 .46037 .53591 .46581 .53423 .46271 .53111 Mtetra
.46271 .53111 .46581 .53423 .47126 .53254 .46817 .52942 Mtetra
.46817 .52942 .47126 .53254 .47673 .53085 .47364 .52772 Mtetra
.47364 .52772 .47673 .53085 .4822 .52916 .47912 .52602 Mtetra
.47912 .52602 .4822 .52916 .48769 .52746 .48462 .52432 Mtetra
.48462 .52432 .48769 .52746 .49318 .52576 .49012 .52261 Mtetra
.49012 .52261 .49318 .52576 .49869 .52406 .49564 .5209 Mtetra
.49564 .5209 .49869 .52406 .50421 .52235 .50116 .51919 Mtetra
.50116 .51919 .50421 .52235 .50974 .52064 .5067 .51747 Mtetra
.5067 .51747 .50974 .52064 .51528 .51892 .51225 .51575 Mtetra
.51225 .51575 .51528 .51892 .52083 .51721 .51781 .51403 Mtetra
.51781 .51403 .52083 .51721 .52639 .51548 .52338 .5123 Mtetra
.52338 .5123 .52639 .51548 .53197 .51376 .52896 .51057 Mtetra
.52896 .51057 .53197 .51376 .53756 .51203 .53455 .50883 Mtetra
.53455 .50883 .53756 .51203 .54315 .5103 .54016 .50709 Mtetra
.54016 .50709 .54315 .5103 .54876 .50856 .54577 .50535 Mtetra
.54577 .50535 .54876 .50856 .55438 .50682 .5514 .50361 Mtetra
.5514 .50361 .55438 .50682 .56001 .50508 .55704 .50186 Mtetra
.55704 .50186 .56001 .50508 .56566 .50334 .56269 .5001 Mtetra
.56269 .5001 .56566 .50334 .57131 .50159 .56835 .49835 Mtetra
.56835 .49835 .57131 .50159 .57698 .49983 .57403 .49659 Mtetra
.57403 .49659 .57698 .49983 .58265 .49808 .57971 .49482 Mtetra
.57971 .49482 .58265 .49808 .58834 .49632 .58541 .49306 Mtetra
.58541 .49306 .58834 .49632 .59404 .49455 .59112 .49129 Mtetra
.59112 .49129 .59404 .49455 .59976 .49278 .59684 .48951 Mtetra
.59684 .48951 .59976 .49278 .60548 .49101 .60257 .48773 Mtetra
.60257 .48773 .60548 .49101 .61122 .48924 .60831 .48595 Mtetra
.60831 .48595 .61122 .48924 .61697 .48746 .61407 .48417 Mtetra
.61407 .48417 .61697 .48746 .62273 .48568 .61984 .48238 Mtetra
.663 .741 .908 r
.61984 .48238 .62273 .48568 .6285 .48389 .62562 .48059 Mtetra
.662 .741 .909 r
.62562 .48059 .6285 .48389 .63428 .48213 .63141 .47882 Mtetra
.664 .741 .908 r
.63141 .47882 .63428 .48213 .64008 .48034 .63721 .47702 Mtetra
.665 .742 .907 r
.63721 .47702 .64008 .48034 .64588 .47851 .64303 .47519 Mtetra
.664 .741 .908 r
.64303 .47519 .64588 .47851 .6517 .47671 .64886 .47338 Mtetra
.64886 .47338 .6517 .47671 .65753 .47491 .6547 .47157 Mtetra
.6547 .47157 .65753 .47491 .66338 .4731 .66055 .46975 Mtetra
.66055 .46975 .66338 .4731 .66923 .47129 .66641 .46793 Mtetra
.66641 .46793 .66923 .47129 .6751 .46947 .67229 .46611 Mtetra
.67229 .46611 .6751 .46947 .68098 .46765 .67818 .46428 Mtetra
.67818 .46428 .68098 .46765 .68688 .46583 .68408 .46245 Mtetra
.68408 .46245 .68688 .46583 .69278 .464 .68999 .46062 Mtetra
.68999 .46062 .69278 .464 .6987 .46217 .69592 .45878 Mtetra
.69592 .45878 .6987 .46217 .70463 .46034 .70185 .45694 Mtetra
.70185 .45694 .70463 .46034 .71057 .4585 .7078 .45509 Mtetra
.7078 .45509 .71057 .4585 .71652 .45665 .71377 .45324 Mtetra
.71377 .45324 .71652 .45665 .72249 .45481 .71974 .45139 Mtetra
.71974 .45139 .72249 .45481 .72847 .45296 .72573 .44953 Mtetra
.72573 .44953 .72847 .45296 .73446 .4511 .73173 .44767 Mtetra
.73173 .44767 .73446 .4511 .74047 .44925 .73775 .44581 Mtetra
.73775 .44581 .74047 .44925 .74648 .44738 .74377 .44394 Mtetra
.74377 .44394 .74648 .44738 .75251 .44552 .74981 .44206 Mtetra
.74981 .44206 .75251 .44552 .75855 .44365 .75586 .44019 Mtetra
.75586 .44019 .75855 .44365 .76461 .44178 .76193 .43831 Mtetra
.76193 .43831 .76461 .44178 .77068 .4399 .768 .43642 Mtetra
.768 .43642 .77068 .4399 .77676 .43802 .77409 .43453 Mtetra
.77409 .43453 .77676 .43802 .78285 .43613 .7802 .43264 Mtetra
.7802 .43264 .78285 .43613 .78896 .43424 .78631 .43074 Mtetra
.78631 .43074 .78896 .43424 .79508 .43235 .79244 .42884 Mtetra
.79244 .42884 .79508 .43235 .80121 .43045 .79858 .42694 Mtetra
.79858 .42694 .80121 .43045 .80736 .42855 .80474 .42503 Mtetra
.80474 .42503 .80736 .42855 .81352 .42664 .81091 .42311 Mtetra
.81091 .42311 .81352 .42664 .81969 .42473 .81709 .4212 Mtetra
.81709 .4212 .81969 .42473 .82587 .42282 .82328 .41927 Mtetra
.82328 .41927 .82587 .42282 .83207 .4209 .82949 .41735 Mtetra
.82949 .41735 .83207 .4209 .83828 .41898 .83571 .41542 Mtetra
.83571 .41542 .83828 .41898 .84451 .41705 .84195 .41349 Mtetra
.84195 .41349 .84451 .41705 .85075 .41512 .84819 .41155 Mtetra
.84819 .41155 .85075 .41512 .857 .41319 .85446 .40961 Mtetra
.85446 .40961 .857 .41319 .86326 .41125 .86073 .40766 Mtetra
.86073 .40766 .86326 .41125 .86954 .40931 .86702 .40571 Mtetra
.86702 .40571 .86954 .40931 .87584 .40736 .87332 .40375 Mtetra
.87332 .40375 .87584 .40736 .88214 .40541 .87964 .4018 Mtetra
.87964 .4018 .88214 .40541 .88846 .40345 .88597 .39983 Mtetra
.88597 .39983 .88846 .40345 .89479 .40149 .89231 .39786 Mtetra
.89231 .39786 .89479 .40149 .90114 .39953 .89866 .39589 Mtetra
.89866 .39589 .90114 .39953 .9075 .39756 .90504 .39392 Mtetra
.90504 .39392 .9075 .39756 .91387 .39559 .91142 .39194 Mtetra
.91142 .39194 .91387 .39559 .92026 .39361 .91782 .38995 Mtetra
.91782 .38995 .92026 .39361 .92666 .39163 .92423 .38796 Mtetra
.92423 .38796 .92666 .39163 .93308 .38965 .93066 .38597 Mtetra
.93066 .38597 .93308 .38965 .93951 .38766 .9371 .38397 Mtetra
.35779 .55964 .36103 .56265 .36628 .56102 .36305 .558 Mtetra
.36305 .558 .36628 .56102 .37155 .55939 .36833 .55636 Mtetra
.36833 .55636 .37155 .55939 .37683 .55775 .37361 .55472 Mtetra
.37361 .55472 .37683 .55775 .38212 .55611 .37891 .55308 Mtetra
.37891 .55308 .38212 .55611 .38741 .55447 .38421 .55143 Mtetra
.38421 .55143 .38741 .55447 .39272 .55282 .38953 .54977 Mtetra
.38953 .54977 .39272 .55282 .39804 .55117 .39485 .54812 Mtetra
.39485 .54812 .39804 .55117 .40337 .54952 .40019 .54646 Mtetra
.40019 .54646 .40337 .54952 .40871 .54786 .40554 .54479 Mtetra
.40554 .54479 .40871 .54786 .41407 .5462 .4109 .54313 Mtetra
.4109 .54313 .41407 .5462 .41943 .54454 .41626 .54146 Mtetra
.41626 .54146 .41943 .54454 .4248 .54287 .42164 .53979 Mtetra
.42164 .53979 .4248 .54287 .43018 .5412 .42703 .53811 Mtetra
.42703 .53811 .43018 .5412 .43558 .53953 .43244 .53643 Mtetra
.43244 .53643 .43558 .53953 .44098 .53785 .43785 .53475 Mtetra
.43785 .53475 .44098 .53785 .4464 .53617 .44327 .53306 Mtetra
.44327 .53306 .4464 .53617 .45183 .53449 .4487 .53137 Mtetra
.4487 .53137 .45183 .53449 .45726 .5328 .45415 .52968 Mtetra
.45415 .52968 .45726 .5328 .46271 .53111 .4596 .52798 Mtetra
.4596 .52798 .46271 .53111 .46817 .52942 .46507 .52628 Mtetra
.46507 .52628 .46817 .52942 .47364 .52772 .47055 .52458 Mtetra
.47055 .52458 .47364 .52772 .47912 .52602 .47604 .52288 Mtetra
.47604 .52288 .47912 .52602 .48462 .52432 .48154 .52117 Mtetra
.48154 .52117 .48462 .52432 .49012 .52261 .48705 .51945 Mtetra
.48705 .51945 .49012 .52261 .49564 .5209 .49257 .51773 Mtetra
.49257 .51773 .49564 .5209 .50116 .51919 .4981 .51601 Mtetra
.4981 .51601 .50116 .51919 .5067 .51747 .50365 .51429 Mtetra
.50365 .51429 .5067 .51747 .51225 .51575 .5092 .51256 Mtetra
.5092 .51256 .51225 .51575 .51781 .51403 .51477 .51083 Mtetra
.51477 .51083 .51781 .51403 .52338 .5123 .52035 .5091 Mtetra
.52035 .5091 .52338 .5123 .52896 .51057 .52594 .50736 Mtetra
.52594 .50736 .52896 .51057 .53455 .50883 .53154 .50562 Mtetra
.53154 .50562 .53455 .50883 .54016 .50709 .53715 .50387 Mtetra
.53715 .50387 .54016 .50709 .54577 .50535 .54277 .50213 Mtetra
.54277 .50213 .54577 .50535 .5514 .50361 .54841 .50037 Mtetra
.54841 .50037 .5514 .50361 .55704 .50186 .55405 .49862 Mtetra
.55405 .49862 .55704 .50186 .56269 .5001 .55971 .49686 Mtetra
.55971 .49686 .56269 .5001 .56835 .49835 .56538 .4951 Mtetra
.56538 .4951 .56835 .49835 .57403 .49659 .57106 .49333 Mtetra
.57106 .49333 .57403 .49659 .57971 .49482 .57676 .49156 Mtetra
.57676 .49156 .57971 .49482 .58541 .49306 .58246 .48978 Mtetra
.58246 .48978 .58541 .49306 .59112 .49129 .58818 .48801 Mtetra
.58818 .48801 .59112 .49129 .59684 .48951 .59391 .48623 Mtetra
.59391 .48623 .59684 .48951 .60257 .48773 .59965 .48444 Mtetra
.59965 .48444 .60257 .48773 .60831 .48595 .6054 .48265 Mtetra
.6054 .48265 .60831 .48595 .61407 .48417 .61116 .48086 Mtetra
.61116 .48086 .61407 .48417 .61984 .48238 .61694 .47907 Mtetra
.663 .741 .908 r
.61694 .47907 .61984 .48238 .62562 .48059 .62273 .47727 Mtetra
.662 .741 .909 r
.62273 .47727 .62562 .48059 .63141 .47882 .62853 .47549 Mtetra
.664 .741 .908 r
.62853 .47549 .63141 .47882 .63721 .47702 .63434 .47369 Mtetra
.665 .742 .907 r
.63434 .47369 .63721 .47702 .64303 .47519 .64016 .47185 Mtetra
.664 .741 .908 r
.64016 .47185 .64303 .47519 .64886 .47338 .646 .47003 Mtetra
.646 .47003 .64886 .47338 .6547 .47157 .65185 .46821 Mtetra
.65185 .46821 .6547 .47157 .66055 .46975 .65771 .46639 Mtetra
.65771 .46639 .66055 .46975 .66641 .46793 .66358 .46456 Mtetra
.66358 .46456 .66641 .46793 .67229 .46611 .66946 .46273 Mtetra
.66946 .46273 .67229 .46611 .67818 .46428 .67536 .4609 Mtetra
.67536 .4609 .67818 .46428 .68408 .46245 .68127 .45906 Mtetra
.68127 .45906 .68408 .46245 .68999 .46062 .68719 .45722 Mtetra
.68719 .45722 .68999 .46062 .69592 .45878 .69313 .45538 Mtetra
.69313 .45538 .69592 .45878 .70185 .45694 .69907 .45353 Mtetra
.69907 .45353 .70185 .45694 .7078 .45509 .70503 .45168 Mtetra
.70503 .45168 .7078 .45509 .71377 .45324 .711 .44982 Mtetra
.711 .44982 .71377 .45324 .71974 .45139 .71699 .44796 Mtetra
.71699 .44796 .71974 .45139 .72573 .44953 .72298 .44609 Mtetra
.72298 .44609 .72573 .44953 .73173 .44767 .72899 .44422 Mtetra
.72899 .44422 .73173 .44767 .73775 .44581 .73502 .44235 Mtetra
.73502 .44235 .73775 .44581 .74377 .44394 .74105 .44048 Mtetra
.74105 .44048 .74377 .44394 .74981 .44206 .7471 .4386 Mtetra
.7471 .4386 .74981 .44206 .75586 .44019 .75316 .43671 Mtetra
.75316 .43671 .75586 .44019 .76193 .43831 .75923 .43482 Mtetra
.75923 .43482 .76193 .43831 .768 .43642 .76532 .43293 Mtetra
.76532 .43293 .768 .43642 .77409 .43453 .77142 .43103 Mtetra
.77142 .43103 .77409 .43453 .7802 .43264 .77753 .42913 Mtetra
.77753 .42913 .7802 .43264 .78631 .43074 .78365 .42723 Mtetra
.78365 .42723 .78631 .43074 .79244 .42884 .78979 .42532 Mtetra
.78979 .42532 .79244 .42884 .79858 .42694 .79594 .42341 Mtetra
.79594 .42341 .79858 .42694 .80474 .42503 .80211 .42149 Mtetra
.80211 .42149 .80474 .42503 .81091 .42311 .80829 .41957 Mtetra
.80829 .41957 .81091 .42311 .81709 .4212 .81448 .41765 Mtetra
.81448 .41765 .81709 .4212 .82328 .41927 .82068 .41572 Mtetra
.82068 .41572 .82328 .41927 .82949 .41735 .8269 .41378 Mtetra
.8269 .41378 .82949 .41735 .83571 .41542 .83313 .41185 Mtetra
.83313 .41185 .83571 .41542 .84195 .41349 .83937 .4099 Mtetra
.83937 .4099 .84195 .41349 .84819 .41155 .84563 .40796 Mtetra
.84563 .40796 .84819 .41155 .85446 .40961 .8519 .40601 Mtetra
.8519 .40601 .85446 .40961 .86073 .40766 .85819 .40406 Mtetra
.85819 .40406 .86073 .40766 .86702 .40571 .86448 .4021 Mtetra
.86448 .4021 .86702 .40571 .87332 .40375 .8708 .40013 Mtetra
.8708 .40013 .87332 .40375 .87964 .4018 .87712 .39817 Mtetra
.87712 .39817 .87964 .4018 .88597 .39983 .88346 .3962 Mtetra
.88346 .3962 .88597 .39983 .89231 .39786 .88981 .39422 Mtetra
.88981 .39422 .89231 .39786 .89866 .39589 .89618 .39224 Mtetra
.89618 .39224 .89866 .39589 .90504 .39392 .90256 .39026 Mtetra
.90256 .39026 .90504 .39392 .91142 .39194 .90895 .38827 Mtetra
.90895 .38827 .91142 .39194 .91782 .38995 .91536 .38628 Mtetra
.91536 .38628 .91782 .38995 .92423 .38796 .92179 .38428 Mtetra
.92179 .38428 .92423 .38796 .93066 .38597 .92822 .38228 Mtetra
.92822 .38228 .93066 .38597 .9371 .38397 .93467 .38027 Mtetra
.35454 .55662 .35779 .55964 .36305 .558 .35981 .55497 Mtetra
.35981 .55497 .36305 .558 .36833 .55636 .36509 .55333 Mtetra
.36509 .55333 .36833 .55636 .37361 .55472 .37038 .55168 Mtetra
.37038 .55168 .37361 .55472 .37891 .55308 .37568 .55003 Mtetra
.37568 .55003 .37891 .55308 .38421 .55143 .381 .54837 Mtetra
.381 .54837 .38421 .55143 .38953 .54977 .38632 .54671 Mtetra
.38632 .54671 .38953 .54977 .39485 .54812 .39165 .54505 Mtetra
.39165 .54505 .39485 .54812 .40019 .54646 .39699 .54339 Mtetra
.39699 .54339 .40019 .54646 .40554 .54479 .40235 .54172 Mtetra
.40235 .54172 .40554 .54479 .4109 .54313 .40771 .54004 Mtetra
.40771 .54004 .4109 .54313 .41626 .54146 .41309 .53837 Mtetra
.41309 .53837 .41626 .54146 .42164 .53979 .41848 .53669 Mtetra
.41848 .53669 .42164 .53979 .42703 .53811 .42387 .53501 Mtetra
.42387 .53501 .42703 .53811 .43244 .53643 .42928 .53332 Mtetra
.42928 .53332 .43244 .53643 .43785 .53475 .4347 .53163 Mtetra
.4347 .53163 .43785 .53475 .44327 .53306 .44013 .52994 Mtetra
.44013 .52994 .44327 .53306 .4487 .53137 .44557 .52825 Mtetra
.44557 .52825 .4487 .53137 .45415 .52968 .45102 .52655 Mtetra
.45102 .52655 .45415 .52968 .4596 .52798 .45648 .52484 Mtetra
.45648 .52484 .4596 .52798 .46507 .52628 .46196 .52314 Mtetra
.46196 .52314 .46507 .52628 .47055 .52458 .46744 .52143 Mtetra
.46744 .52143 .47055 .52458 .47604 .52288 .47294 .51972 Mtetra
.47294 .51972 .47604 .52288 .48154 .52117 .47844 .518 Mtetra
.47844 .518 .48154 .52117 .48705 .51945 .48396 .51628 Mtetra
.48396 .51628 .48705 .51945 .49257 .51773 .48949 .51456 Mtetra
.48949 .51456 .49257 .51773 .4981 .51601 .49503 .51283 Mtetra
.49503 .51283 .4981 .51601 .50365 .51429 .50058 .5111 Mtetra
.50058 .5111 .50365 .51429 .5092 .51256 .50615 .50937 Mtetra
.50615 .50937 .5092 .51256 .51477 .51083 .51172 .50763 Mtetra
.51172 .50763 .51477 .51083 .52035 .5091 .51731 .50589 Mtetra
.51731 .50589 .52035 .5091 .52594 .50736 .5229 .50414 Mtetra
.5229 .50414 .52594 .50736 .53154 .50562 .52851 .50239 Mtetra
.52851 .50239 .53154 .50562 .53715 .50387 .53413 .50064 Mtetra
.53413 .50064 .53715 .50387 .54277 .50213 .53976 .49889 Mtetra
.53976 .49889 .54277 .50213 .54841 .50037 .5454 .49713 Mtetra
.5454 .49713 .54841 .50037 .55405 .49862 .55106 .49537 Mtetra
.55106 .49537 .55405 .49862 .55971 .49686 .55672 .4936 Mtetra
.55672 .4936 .55971 .49686 .56538 .4951 .5624 .49183 Mtetra
.5624 .49183 .56538 .4951 .57106 .49333 .56809 .49006 Mtetra
.56809 .49006 .57106 .49333 .57676 .49156 .57379 .48828 Mtetra
.57379 .48828 .57676 .49156 .58246 .48978 .5795 .4865 Mtetra
.5795 .4865 .58246 .48978 .58818 .48801 .58523 .48472 Mtetra
.58523 .48472 .58818 .48801 .59391 .48623 .59096 .48293 Mtetra
.59096 .48293 .59391 .48623 .59965 .48444 .59671 .48114 Mtetra
.59671 .48114 .59965 .48444 .6054 .48265 .60247 .47934 Mtetra
.60247 .47934 .6054 .48265 .61116 .48086 .60824 .47754 Mtetra
.60824 .47754 .61116 .48086 .61694 .47907 .61403 .47574 Mtetra
.663 .741 .908 r
.61403 .47574 .61694 .47907 .62273 .47727 .61982 .47394 Mtetra
.662 .741 .909 r
.61982 .47394 .62273 .47727 .62853 .47549 .62563 .47216 Mtetra
.664 .741 .908 r
.62563 .47216 .62853 .47549 .63434 .47369 .63145 .47034 Mtetra
.665 .742 .907 r
.63145 .47034 .63434 .47369 .64016 .47185 .63728 .4685 Mtetra
.664 .741 .908 r
.63728 .4685 .64016 .47185 .646 .47003 .64313 .46667 Mtetra
.64313 .46667 .646 .47003 .65185 .46821 .64898 .46485 Mtetra
.64898 .46485 .65185 .46821 .65771 .46639 .65485 .46302 Mtetra
.65485 .46302 .65771 .46639 .66358 .46456 .66073 .46118 Mtetra
.66073 .46118 .66358 .46456 .66946 .46273 .66663 .45935 Mtetra
.66663 .45935 .66946 .46273 .67536 .4609 .67253 .45751 Mtetra
.67253 .45751 .67536 .4609 .68127 .45906 .67845 .45566 Mtetra
.67845 .45566 .68127 .45906 .68719 .45722 .68438 .45381 Mtetra
.68438 .45381 .68719 .45722 .69313 .45538 .69032 .45196 Mtetra
.69032 .45196 .69313 .45538 .69907 .45353 .69628 .4501 Mtetra
.69628 .4501 .69907 .45353 .70503 .45168 .70225 .44824 Mtetra
.70225 .44824 .70503 .45168 .711 .44982 .70823 .44638 Mtetra
.70823 .44638 .711 .44982 .71699 .44796 .71422 .44451 Mtetra
.71422 .44451 .71699 .44796 .72298 .44609 .72022 .44264 Mtetra
.72022 .44264 .72298 .44609 .72899 .44422 .72624 .44076 Mtetra
.72624 .44076 .72899 .44422 .73502 .44235 .73227 .43888 Mtetra
.73227 .43888 .73502 .44235 .74105 .44048 .73832 .437 Mtetra
.73832 .437 .74105 .44048 .7471 .4386 .74437 .43511 Mtetra
.74437 .43511 .7471 .4386 .75316 .43671 .75044 .43322 Mtetra
.75044 .43322 .75316 .43671 .75923 .43482 .75653 .43133 Mtetra
.75653 .43133 .75923 .43482 .76532 .43293 .76262 .42943 Mtetra
.76262 .42943 .76532 .43293 .77142 .43103 .76873 .42752 Mtetra
.76873 .42752 .77142 .43103 .77753 .42913 .77485 .42561 Mtetra
.77485 .42561 .77753 .42913 .78365 .42723 .78099 .4237 Mtetra
.78099 .4237 .78365 .42723 .78979 .42532 .78713 .42179 Mtetra
.78713 .42179 .78979 .42532 .79594 .42341 .79329 .41987 Mtetra
.79329 .41987 .79594 .42341 .80211 .42149 .79947 .41794 Mtetra
.79947 .41794 .80211 .42149 .80829 .41957 .80565 .41601 Mtetra
.80565 .41601 .80829 .41957 .81448 .41765 .81185 .41408 Mtetra
.81185 .41408 .81448 .41765 .82068 .41572 .81807 .41214 Mtetra
.81807 .41214 .82068 .41572 .8269 .41378 .82429 .4102 Mtetra
.82429 .4102 .8269 .41378 .83313 .41185 .83054 .40826 Mtetra
.83054 .40826 .83313 .41185 .83937 .4099 .83679 .40631 Mtetra
.83679 .40631 .83937 .4099 .84563 .40796 .84306 .40436 Mtetra
.84306 .40436 .84563 .40796 .8519 .40601 .84934 .4024 Mtetra
.84934 .4024 .8519 .40601 .85819 .40406 .85563 .40044 Mtetra
.85563 .40044 .85819 .40406 .86448 .4021 .86194 .39847 Mtetra
.86194 .39847 .86448 .4021 .8708 .40013 .86826 .3965 Mtetra
.86826 .3965 .8708 .40013 .87712 .39817 .8746 .39453 Mtetra
.8746 .39453 .87712 .39817 .88346 .3962 .88095 .39255 Mtetra
.88095 .39255 .88346 .3962 .88981 .39422 .88731 .39056 Mtetra
.88731 .39056 .88981 .39422 .89618 .39224 .89369 .38858 Mtetra
.89369 .38858 .89618 .39224 .90256 .39026 .90008 .38658 Mtetra
.90008 .38658 .90256 .39026 .90895 .38827 .90648 .38459 Mtetra
.90648 .38459 .90895 .38827 .91536 .38628 .9129 .38259 Mtetra
.9129 .38259 .91536 .38628 .92179 .38428 .91933 .38058 Mtetra
.91933 .38058 .92179 .38428 .92822 .38228 .92578 .37857 Mtetra
.92578 .37857 .92822 .38228 .93467 .38027 .93224 .37656 Mtetra
.35128 .55358 .35454 .55662 .35981 .55497 .35656 .55193 Mtetra
.35656 .55193 .35981 .55497 .36509 .55333 .36185 .55028 Mtetra
.36185 .55028 .36509 .55333 .37038 .55168 .36714 .54863 Mtetra
.36714 .54863 .37038 .55168 .37568 .55003 .37245 .54697 Mtetra
.37245 .54697 .37568 .55003 .381 .54837 .37777 .54531 Mtetra
.37777 .54531 .381 .54837 .38632 .54671 .3831 .54364 Mtetra
.3831 .54364 .38632 .54671 .39165 .54505 .38844 .54197 Mtetra
.38844 .54197 .39165 .54505 .39699 .54339 .39379 .5403 Mtetra
.39379 .5403 .39699 .54339 .40235 .54172 .39915 .53863 Mtetra
.39915 .53863 .40235 .54172 .40771 .54004 .40452 .53695 Mtetra
.40452 .53695 .40771 .54004 .41309 .53837 .4099 .53527 Mtetra
.4099 .53527 .41309 .53837 .41848 .53669 .4153 .53358 Mtetra
.4153 .53358 .41848 .53669 .42387 .53501 .4207 .53189 Mtetra
.4207 .53189 .42387 .53501 .42928 .53332 .42611 .5302 Mtetra
.42611 .5302 .42928 .53332 .4347 .53163 .43154 .52851 Mtetra
.43154 .52851 .4347 .53163 .44013 .52994 .43698 .52681 Mtetra
.43698 .52681 .44013 .52994 .44557 .52825 .44242 .52511 Mtetra
.44242 .52511 .44557 .52825 .45102 .52655 .44788 .5234 Mtetra
.44788 .5234 .45102 .52655 .45648 .52484 .45335 .52169 Mtetra
.45335 .52169 .45648 .52484 .46196 .52314 .45883 .51998 Mtetra
.45883 .51998 .46196 .52314 .46744 .52143 .46432 .51826 Mtetra
.46432 .51826 .46744 .52143 .47294 .51972 .46983 .51654 Mtetra
.46983 .51654 .47294 .51972 .47844 .518 .47534 .51482 Mtetra
.47534 .51482 .47844 .518 .48396 .51628 .48087 .5131 Mtetra
.48087 .5131 .48396 .51628 .48949 .51456 .4864 .51137 Mtetra
.4864 .51137 .48949 .51456 .49503 .51283 .49195 .50963 Mtetra
.49195 .50963 .49503 .51283 .50058 .5111 .49751 .5079 Mtetra
.49751 .5079 .50058 .5111 .50615 .50937 .50308 .50615 Mtetra
.50308 .50615 .50615 .50937 .51172 .50763 .50866 .50441 Mtetra
.50866 .50441 .51172 .50763 .51731 .50589 .51425 .50266 Mtetra
.51425 .50266 .51731 .50589 .5229 .50414 .51986 .50091 Mtetra
.51986 .50091 .5229 .50414 .52851 .50239 .52547 .49916 Mtetra
.52547 .49916 .52851 .50239 .53413 .50064 .5311 .4974 Mtetra
.5311 .4974 .53413 .50064 .53976 .49889 .53674 .49564 Mtetra
.53674 .49564 .53976 .49889 .5454 .49713 .54239 .49387 Mtetra
.54239 .49387 .5454 .49713 .55106 .49537 .54805 .4921 Mtetra
.54805 .4921 .55106 .49537 .55672 .4936 .55372 .49033 Mtetra
.55372 .49033 .55672 .4936 .5624 .49183 .55941 .48855 Mtetra
.55941 .48855 .5624 .49183 .56809 .49006 .56511 .48677 Mtetra
.56511 .48677 .56809 .49006 .57379 .48828 .57081 .48499 Mtetra
.57081 .48499 .57379 .48828 .5795 .4865 .57654 .4832 Mtetra
.57654 .4832 .5795 .4865 .58523 .48472 .58227 .48141 Mtetra
.58227 .48141 .58523 .48472 .59096 .48293 .58801 .47962 Mtetra
.58801 .47962 .59096 .48293 .59671 .48114 .59377 .47782 Mtetra
.59377 .47782 .59671 .48114 .60247 .47934 .59954 .47602 Mtetra
.59954 .47602 .60247 .47934 .60824 .47754 .60532 .47421 Mtetra
.60532 .47421 .60824 .47754 .61403 .47574 .61111 .4724 Mtetra
.663 .741 .908 r
.61111 .4724 .61403 .47574 .61982 .47394 .61691 .47059 Mtetra
.662 .741 .909 r
.61691 .47059 .61982 .47394 .62563 .47216 .62273 .46881 Mtetra
.664 .741 .908 r
.62273 .46881 .62563 .47216 .63145 .47034 .62856 .46698 Mtetra
.665 .742 .907 r
.62856 .46698 .63145 .47034 .63728 .4685 .6344 .46513 Mtetra
.664 .741 .908 r
.6344 .46513 .63728 .4685 .64313 .46667 .64025 .4633 Mtetra
.64025 .4633 .64313 .46667 .64898 .46485 .64611 .46147 Mtetra
.64611 .46147 .64898 .46485 .65485 .46302 .65199 .45963 Mtetra
.65199 .45963 .65485 .46302 .66073 .46118 .65788 .45779 Mtetra
.65788 .45779 .66073 .46118 .66663 .45935 .66378 .45595 Mtetra
.66378 .45595 .66663 .45935 .67253 .45751 .66969 .4541 Mtetra
.66969 .4541 .67253 .45751 .67845 .45566 .67562 .45225 Mtetra
.67562 .45225 .67845 .45566 .68438 .45381 .68156 .45039 Mtetra
.68156 .45039 .68438 .45381 .69032 .45196 .68751 .44853 Mtetra
.68751 .44853 .69032 .45196 .69628 .4501 .69347 .44667 Mtetra
.69347 .44667 .69628 .4501 .70225 .44824 .69945 .4448 Mtetra
.69945 .4448 .70225 .44824 .70823 .44638 .70544 .44293 Mtetra
.70544 .44293 .70823 .44638 .71422 .44451 .71144 .44105 Mtetra
.71144 .44105 .71422 .44451 .72022 .44264 .71746 .43917 Mtetra
.71746 .43917 .72022 .44264 .72624 .44076 .72348 .43729 Mtetra
.72348 .43729 .72624 .44076 .73227 .43888 .72952 .4354 Mtetra
.72952 .4354 .73227 .43888 .73832 .437 .73557 .43351 Mtetra
.73557 .43351 .73832 .437 .74437 .43511 .74164 .43162 Mtetra
.74164 .43162 .74437 .43511 .75044 .43322 .74772 .42972 Mtetra
.74772 .42972 .75044 .43322 .75653 .43133 .75381 .42782 Mtetra
.75381 .42782 .75653 .43133 .76262 .42943 .75991 .42591 Mtetra
.75991 .42591 .76262 .42943 .76873 .42752 .76603 .424 Mtetra
.76603 .424 .76873 .42752 .77485 .42561 .77216 .42208 Mtetra
.77216 .42208 .77485 .42561 .78099 .4237 .77831 .42016 Mtetra
.77831 .42016 .78099 .4237 .78713 .42179 .78446 .41824 Mtetra
.78446 .41824 .78713 .42179 .79329 .41987 .79063 .41631 Mtetra
.79063 .41631 .79329 .41987 .79947 .41794 .79682 .41438 Mtetra
.79682 .41438 .79947 .41794 .80565 .41601 .80301 .41244 Mtetra
.80301 .41244 .80565 .41601 .81185 .41408 .80922 .4105 Mtetra
.80922 .4105 .81185 .41408 .81807 .41214 .81544 .40856 Mtetra
.81544 .40856 .81807 .41214 .82429 .4102 .82168 .40661 Mtetra
.82168 .40661 .82429 .4102 .83054 .40826 .82793 .40466 Mtetra
.82793 .40466 .83054 .40826 .83679 .40631 .83419 .4027 Mtetra
.83419 .4027 .83679 .40631 .84306 .40436 .84047 .40074 Mtetra
.84047 .40074 .84306 .40436 .84934 .4024 .84676 .39877 Mtetra
.84676 .39877 .84934 .4024 .85563 .40044 .85307 .3968 Mtetra
.85307 .3968 .85563 .40044 .86194 .39847 .85938 .39483 Mtetra
.85938 .39483 .86194 .39847 .86826 .3965 .86572 .39285 Mtetra
.86572 .39285 .86826 .3965 .8746 .39453 .87206 .39087 Mtetra
.87206 .39087 .8746 .39453 .88095 .39255 .87842 .38888 Mtetra
.87842 .38888 .88095 .39255 .88731 .39056 .88479 .38689 Mtetra
.88479 .38689 .88731 .39056 .89369 .38858 .89118 .3849 Mtetra
.89118 .3849 .89369 .38858 .90008 .38658 .89758 .3829 Mtetra
.89758 .3829 .90008 .38658 .90648 .38459 .904 .38089 Mtetra
.904 .38089 .90648 .38459 .9129 .38259 .91042 .37888 Mtetra
.91042 .37888 .9129 .38259 .91933 .38058 .91687 .37687 Mtetra
.91687 .37687 .91933 .38058 .92578 .37857 .92332 .37485 Mtetra
.92332 .37485 .92578 .37857 .93224 .37656 .9298 .37283 Mtetra
.34801 .55054 .35128 .55358 .35656 .55193 .35329 .54888 Mtetra
.35329 .54888 .35656 .55193 .36185 .55028 .35859 .54722 Mtetra
.35859 .54722 .36185 .55028 .36714 .54863 .36389 .54556 Mtetra
.36389 .54556 .36714 .54863 .37245 .54697 .36921 .5439 Mtetra
.36921 .5439 .37245 .54697 .37777 .54531 .37453 .54223 Mtetra
.37453 .54223 .37777 .54531 .3831 .54364 .37987 .54056 Mtetra
.37987 .54056 .3831 .54364 .38844 .54197 .38521 .53888 Mtetra
.38521 .53888 .38844 .54197 .39379 .5403 .39057 .53721 Mtetra
.39057 .53721 .39379 .5403 .39915 .53863 .39594 .53553 Mtetra
.39594 .53553 .39915 .53863 .40452 .53695 .40131 .53384 Mtetra
.40131 .53384 .40452 .53695 .4099 .53527 .4067 .53215 Mtetra
.4067 .53215 .4099 .53527 .4153 .53358 .4121 .53046 Mtetra
.4121 .53046 .4153 .53358 .4207 .53189 .41751 .52877 Mtetra
.41751 .52877 .4207 .53189 .42611 .5302 .42294 .52707 Mtetra
.42294 .52707 .42611 .5302 .43154 .52851 .42837 .52537 Mtetra
.42837 .52537 .43154 .52851 .43698 .52681 .43381 .52366 Mtetra
.43381 .52366 .43698 .52681 .44242 .52511 .43927 .52195 Mtetra
.43927 .52195 .44242 .52511 .44788 .5234 .44473 .52024 Mtetra
.44473 .52024 .44788 .5234 .45335 .52169 .45021 .51853 Mtetra
.45021 .51853 .45335 .52169 .45883 .51998 .4557 .51681 Mtetra
.4557 .51681 .45883 .51998 .46432 .51826 .46119 .51509 Mtetra
.46119 .51509 .46432 .51826 .46983 .51654 .4667 .51336 Mtetra
.4667 .51336 .46983 .51654 .47534 .51482 .47223 .51163 Mtetra
.47223 .51163 .47534 .51482 .48087 .5131 .47776 .5099 Mtetra
.47776 .5099 .48087 .5131 .4864 .51137 .4833 .50816 Mtetra
.4833 .50816 .4864 .51137 .49195 .50963 .48886 .50642 Mtetra
.48886 .50642 .49195 .50963 .49751 .5079 .49442 .50468 Mtetra
.49442 .50468 .49751 .5079 .50308 .50615 .5 .50293 Mtetra
.5 .50293 .50308 .50615 .50866 .50441 .50559 .50118 Mtetra
.50559 .50118 .50866 .50441 .51425 .50266 .51119 .49943 Mtetra
.51119 .49943 .51425 .50266 .51986 .50091 .5168 .49767 Mtetra
.5168 .49767 .51986 .50091 .52547 .49916 .52242 .49591 Mtetra
.52242 .49591 .52547 .49916 .5311 .4974 .52806 .49414 Mtetra
.52806 .49414 .5311 .4974 .53674 .49564 .5337 .49238 Mtetra
.5337 .49238 .53674 .49564 .54239 .49387 .53936 .4906 Mtetra
.53936 .4906 .54239 .49387 .54805 .4921 .54503 .48883 Mtetra
.54503 .48883 .54805 .4921 .55372 .49033 .55071 .48705 Mtetra
.55071 .48705 .55372 .49033 .55941 .48855 .55641 .48527 Mtetra
.55641 .48527 .55941 .48855 .56511 .48677 .56211 .48348 Mtetra
.56211 .48348 .56511 .48677 .57081 .48499 .56783 .48169 Mtetra
.56783 .48169 .57081 .48499 .57654 .4832 .57355 .47989 Mtetra
.57355 .47989 .57654 .4832 .58227 .48141 .5793 .4781 Mtetra
.5793 .4781 .58227 .48141 .58801 .47962 .58505 .4763 Mtetra
.58505 .4763 .58801 .47962 .59377 .47782 .59081 .47449 Mtetra
.59081 .47449 .59377 .47782 .59954 .47602 .59659 .47268 Mtetra
.59659 .47268 .59954 .47602 .60532 .47421 .60237 .47087 Mtetra
.60237 .47087 .60532 .47421 .61111 .4724 .60817 .46905 Mtetra
.663 .741 .908 r
.60817 .46905 .61111 .4724 .61691 .47059 .61399 .46723 Mtetra
.661 .741 .909 r
.61399 .46723 .61691 .47059 .62273 .46881 .61981 .46544 Mtetra
.664 .741 .908 r
.61981 .46544 .62273 .46881 .62856 .46698 .62565 .46361 Mtetra
.666 .742 .907 r
.62565 .46361 .62856 .46698 .6344 .46513 .6315 .46175 Mtetra
.664 .741 .908 r
.6315 .46175 .6344 .46513 .64025 .4633 .63736 .45991 Mtetra
.63736 .45991 .64025 .4633 .64611 .46147 .64323 .45807 Mtetra
.64323 .45807 .64611 .46147 .65199 .45963 .64911 .45623 Mtetra
.64911 .45623 .65199 .45963 .65788 .45779 .65501 .45438 Mtetra
.65501 .45438 .65788 .45779 .66378 .45595 .66092 .45253 Mtetra
.66092 .45253 .66378 .45595 .66969 .4541 .66684 .45068 Mtetra
.66684 .45068 .66969 .4541 .67562 .45225 .67278 .44882 Mtetra
.67278 .44882 .67562 .45225 .68156 .45039 .67873 .44695 Mtetra
.67873 .44695 .68156 .45039 .68751 .44853 .68469 .44509 Mtetra
.68469 .44509 .68751 .44853 .69347 .44667 .69066 .44322 Mtetra
.69066 .44322 .69347 .44667 .69945 .4448 .69664 .44134 Mtetra
.69664 .44134 .69945 .4448 .70544 .44293 .70264 .43946 Mtetra
.70264 .43946 .70544 .44293 .71144 .44105 .70865 .43758 Mtetra
.70865 .43758 .71144 .44105 .71746 .43917 .71467 .43569 Mtetra
.71467 .43569 .71746 .43917 .72348 .43729 .72071 .4338 Mtetra
.72071 .4338 .72348 .43729 .72952 .4354 .72676 .43191 Mtetra
.72676 .43191 .72952 .4354 .73557 .43351 .73282 .43001 Mtetra
.73282 .43001 .73557 .43351 .74164 .43162 .7389 .42811 Mtetra
.7389 .42811 .74164 .43162 .74772 .42972 .74498 .4262 Mtetra
.74498 .4262 .74772 .42972 .75381 .42782 .75108 .42429 Mtetra
.75108 .42429 .75381 .42782 .75991 .42591 .7572 .42238 Mtetra
.7572 .42238 .75991 .42591 .76603 .424 .76332 .42046 Mtetra
.76332 .42046 .76603 .424 .77216 .42208 .76946 .41853 Mtetra
.76946 .41853 .77216 .42208 .77831 .42016 .77562 .41661 Mtetra
.77562 .41661 .77831 .42016 .78446 .41824 .78178 .41468 Mtetra
.78178 .41468 .78446 .41824 .79063 .41631 .78796 .41274 Mtetra
.78796 .41274 .79063 .41631 .79682 .41438 .79415 .4108 Mtetra
.79415 .4108 .79682 .41438 .80301 .41244 .80036 .40886 Mtetra
.80036 .40886 .80301 .41244 .80922 .4105 .80658 .40691 Mtetra
.80658 .40691 .80922 .4105 .81544 .40856 .81281 .40496 Mtetra
.81281 .40496 .81544 .40856 .82168 .40661 .81906 .403 Mtetra
.81906 .403 .82168 .40661 .82793 .40466 .82532 .40104 Mtetra
.82532 .40104 .82793 .40466 .83419 .4027 .83159 .39908 Mtetra
.83159 .39908 .83419 .4027 .84047 .40074 .83788 .39711 Mtetra
.83788 .39711 .84047 .40074 .84676 .39877 .84418 .39513 Mtetra
.84418 .39513 .84676 .39877 .85307 .3968 .85049 .39316 Mtetra
.85049 .39316 .85307 .3968 .85938 .39483 .85682 .39117 Mtetra
.85682 .39117 .85938 .39483 .86572 .39285 .86316 .38919 Mtetra
.86316 .38919 .86572 .39285 .87206 .39087 .86952 .3872 Mtetra
.86952 .3872 .87206 .39087 .87842 .38888 .87589 .3852 Mtetra
.87589 .3852 .87842 .38888 .88479 .38689 .88227 .3832 Mtetra
.88227 .3832 .88479 .38689 .89118 .3849 .88867 .3812 Mtetra
.88867 .3812 .89118 .3849 .89758 .3829 .89508 .37919 Mtetra
.89508 .37919 .89758 .3829 .904 .38089 .9015 .37718 Mtetra
.9015 .37718 .904 .38089 .91042 .37888 .90794 .37516 Mtetra
.90794 .37516 .91042 .37888 .91687 .37687 .91439 .37314 Mtetra
.91439 .37314 .91687 .37687 .92332 .37485 .92086 .37112 Mtetra
.92086 .37112 .92332 .37485 .9298 .37283 .92734 .36909 Mtetra
.34473 .54748 .34801 .55054 .35329 .54888 .35002 .54582 Mtetra
.35002 .54582 .35329 .54888 .35859 .54722 .35532 .54415 Mtetra
.35532 .54415 .35859 .54722 .36389 .54556 .36063 .54249 Mtetra
.36063 .54249 .36389 .54556 .36921 .5439 .36595 .54082 Mtetra
.36595 .54082 .36921 .5439 .37453 .54223 .37128 .53914 Mtetra
.37128 .53914 .37453 .54223 .37987 .54056 .37662 .53747 Mtetra
.37662 .53747 .37987 .54056 .38521 .53888 .38197 .53578 Mtetra
.38197 .53578 .38521 .53888 .39057 .53721 .38734 .5341 Mtetra
.38734 .5341 .39057 .53721 .39594 .53553 .39271 .53241 Mtetra
.39271 .53241 .39594 .53553 .40131 .53384 .3981 .53072 Mtetra
.3981 .53072 .40131 .53384 .4067 .53215 .40349 .52903 Mtetra
.40349 .52903 .4067 .53215 .4121 .53046 .4089 .52733 Mtetra
.4089 .52733 .4121 .53046 .41751 .52877 .41432 .52563 Mtetra
.41432 .52563 .41751 .52877 .42294 .52707 .41975 .52393 Mtetra
.41975 .52393 .42294 .52707 .42837 .52537 .42518 .52222 Mtetra
.42518 .52222 .42837 .52537 .43381 .52366 .43063 .52051 Mtetra
.43063 .52051 .43381 .52366 .43927 .52195 .4361 .51879 Mtetra
.4361 .51879 .43927 .52195 .44473 .52024 .44157 .51707 Mtetra
.44157 .51707 .44473 .52024 .45021 .51853 .44705 .51535 Mtetra
.44705 .51535 .45021 .51853 .4557 .51681 .45255 .51363 Mtetra
.45255 .51363 .4557 .51681 .46119 .51509 .45805 .5119 Mtetra
.45805 .5119 .46119 .51509 .4667 .51336 .46357 .51017 Mtetra
.46357 .51017 .4667 .51336 .47223 .51163 .4691 .50843 Mtetra
.4691 .50843 .47223 .51163 .47776 .5099 .47464 .50669 Mtetra
.47464 .50669 .47776 .5099 .4833 .50816 .48019 .50495 Mtetra
.48019 .50495 .4833 .50816 .48886 .50642 .48575 .5032 Mtetra
.48575 .5032 .48886 .50642 .49442 .50468 .49132 .50145 Mtetra
.49132 .50145 .49442 .50468 .5 .50293 .49691 .4997 Mtetra
.49691 .4997 .5 .50293 .50559 .50118 .5025 .49794 Mtetra
.5025 .49794 .50559 .50118 .51119 .49943 .50811 .49618 Mtetra
.50811 .49618 .51119 .49943 .5168 .49767 .51373 .49442 Mtetra
.51373 .49442 .5168 .49767 .52242 .49591 .51936 .49265 Mtetra
.51936 .49265 .52242 .49591 .52806 .49414 .525 .49088 Mtetra
.525 .49088 .52806 .49414 .5337 .49238 .53066 .4891 Mtetra
.53066 .4891 .5337 .49238 .53936 .4906 .53632 .48732 Mtetra
.53632 .48732 .53936 .4906 .54503 .48883 .542 .48554 Mtetra
.542 .48554 .54503 .48883 .55071 .48705 .54769 .48375 Mtetra
.54769 .48375 .55071 .48705 .55641 .48527 .55339 .48196 Mtetra
.55339 .48196 .55641 .48527 .56211 .48348 .5591 .48017 Mtetra
.5591 .48017 .56211 .48348 .56783 .48169 .56483 .47837 Mtetra
.56483 .47837 .56783 .48169 .57355 .47989 .57056 .47657 Mtetra
.57056 .47657 .57355 .47989 .5793 .4781 .57631 .47477 Mtetra
.57631 .47477 .5793 .4781 .58505 .4763 .58207 .47296 Mtetra
.58207 .47296 .58505 .4763 .59081 .47449 .58784 .47115 Mtetra
.58784 .47115 .59081 .47449 .59659 .47268 .59363 .46933 Mtetra
.59363 .46933 .59659 .47268 .60237 .47087 .59942 .46751 Mtetra
.663 .741 .908 r
.59942 .46751 .60237 .47087 .60817 .46905 .60523 .46569 Mtetra
.60523 .46569 .60817 .46905 .61399 .46723 .61105 .46386 Mtetra
.661 .741 .909 r
.61105 .46386 .61399 .46723 .61981 .46544 .61688 .46207 Mtetra
.664 .741 .908 r
.61688 .46207 .61981 .46544 .62565 .46361 .62273 .46023 Mtetra
.666 .742 .907 r
.62273 .46023 .62565 .46361 .6315 .46175 .62858 .45836 Mtetra
.664 .741 .908 r
.62858 .45836 .6315 .46175 .63736 .45991 .63445 .45651 Mtetra
.63445 .45651 .63736 .45991 .64323 .45807 .64033 .45467 Mtetra
.64033 .45467 .64323 .45807 .64911 .45623 .64623 .45282 Mtetra
.64623 .45282 .64911 .45623 .65501 .45438 .65213 .45096 Mtetra
.65213 .45096 .65501 .45438 .66092 .45253 .65805 .4491 Mtetra
.65805 .4491 .66092 .45253 .66684 .45068 .66398 .44724 Mtetra
.66398 .44724 .66684 .45068 .67278 .44882 .66993 .44537 Mtetra
.66993 .44537 .67278 .44882 .67873 .44695 .67588 .4435 Mtetra
.67588 .4435 .67873 .44695 .68469 .44509 .68185 .44163 Mtetra
.68185 .44163 .68469 .44509 .69066 .44322 .68783 .43975 Mtetra
.68783 .43975 .69066 .44322 .69664 .44134 .69383 .43787 Mtetra
.69383 .43787 .69664 .44134 .70264 .43946 .69983 .43599 Mtetra
.69983 .43599 .70264 .43946 .70865 .43758 .70585 .4341 Mtetra
.70585 .4341 .70865 .43758 .71467 .43569 .71188 .4322 Mtetra
.71188 .4322 .71467 .43569 .72071 .4338 .71793 .4303 Mtetra
.71793 .4303 .72071 .4338 .72676 .43191 .72399 .4284 Mtetra
.72399 .4284 .72676 .43191 .73282 .43001 .73006 .4265 Mtetra
.73006 .4265 .73282 .43001 .7389 .42811 .73614 .42459 Mtetra
.73614 .42459 .7389 .42811 .74498 .4262 .74224 .42267 Mtetra
.74224 .42267 .74498 .4262 .75108 .42429 .74835 .42075 Mtetra
.74835 .42075 .75108 .42429 .7572 .42238 .75447 .41883 Mtetra
.75447 .41883 .7572 .42238 .76332 .42046 .7606 .4169 Mtetra
.7606 .4169 .76332 .42046 .76946 .41853 .76675 .41497 Mtetra
.76675 .41497 .76946 .41853 .77562 .41661 .77292 .41304 Mtetra
.77292 .41304 .77562 .41661 .78178 .41468 .77909 .4111 Mtetra
.77909 .4111 .78178 .41468 .78796 .41274 .78528 .40916 Mtetra
.78528 .40916 .78796 .41274 .79415 .4108 .79148 .40721 Mtetra
.79148 .40721 .79415 .4108 .80036 .40886 .7977 .40526 Mtetra
.7977 .40526 .80036 .40886 .80658 .40691 .80393 .4033 Mtetra
.80393 .4033 .80658 .40691 .81281 .40496 .81017 .40134 Mtetra
.81017 .40134 .81281 .40496 .81906 .403 .81642 .39938 Mtetra
.81642 .39938 .81906 .403 .82532 .40104 .82269 .39741 Mtetra
.82269 .39741 .82532 .40104 .83159 .39908 .82898 .39544 Mtetra
.82898 .39544 .83159 .39908 .83788 .39711 .83527 .39346 Mtetra
.83527 .39346 .83788 .39711 .84418 .39513 .84158 .39148 Mtetra
.84158 .39148 .84418 .39513 .85049 .39316 .84791 .38949 Mtetra
.84791 .38949 .85049 .39316 .85682 .39117 .85424 .3875 Mtetra
.85424 .3875 .85682 .39117 .86316 .38919 .8606 .38551 Mtetra
.8606 .38551 .86316 .38919 .86952 .3872 .86696 .38351 Mtetra
.86696 .38351 .86952 .3872 .87589 .3852 .87334 .38151 Mtetra
.87334 .38151 .87589 .3852 .88227 .3832 .87973 .3795 Mtetra
.87973 .3795 .88227 .3832 .88867 .3812 .88614 .37749 Mtetra
.88614 .37749 .88867 .3812 .89508 .37919 .89256 .37547 Mtetra
.89256 .37547 .89508 .37919 .9015 .37718 .899 .37345 Mtetra
.899 .37345 .9015 .37718 .90794 .37516 .90545 .37143 Mtetra
.90545 .37143 .90794 .37516 .91439 .37314 .91191 .3694 Mtetra
.91191 .3694 .91439 .37314 .92086 .37112 .91839 .36736 Mtetra
.91839 .36736 .92086 .37112 .92734 .36909 .92488 .36533 Mtetra
.34143 .54441 .34473 .54748 .35002 .54582 .34673 .54274 Mtetra
.34673 .54274 .35002 .54582 .35532 .54415 .35203 .54107 Mtetra
.35203 .54107 .35532 .54415 .36063 .54249 .35735 .5394 Mtetra
.35735 .5394 .36063 .54249 .36595 .54082 .36268 .53772 Mtetra
.36268 .53772 .36595 .54082 .37128 .53914 .36802 .53604 Mtetra
.36802 .53604 .37128 .53914 .37662 .53747 .37336 .53436 Mtetra
.37336 .53436 .37662 .53747 .38197 .53578 .37872 .53267 Mtetra
.37872 .53267 .38197 .53578 .38734 .5341 .38409 .53098 Mtetra
.38409 .53098 .38734 .5341 .39271 .53241 .38948 .52929 Mtetra
.38948 .52929 .39271 .53241 .3981 .53072 .39487 .52759 Mtetra
.39487 .52759 .3981 .53072 .40349 .52903 .40027 .52589 Mtetra
.40027 .52589 .40349 .52903 .4089 .52733 .40568 .52419 Mtetra
.40568 .52419 .4089 .52733 .41432 .52563 .41111 .52248 Mtetra
.41111 .52248 .41432 .52563 .41975 .52393 .41654 .52077 Mtetra
.41654 .52077 .41975 .52393 .42518 .52222 .42199 .51906 Mtetra
.42199 .51906 .42518 .52222 .43063 .52051 .42745 .51734 Mtetra
.42745 .51734 .43063 .52051 .4361 .51879 .43291 .51562 Mtetra
.43291 .51562 .4361 .51879 .44157 .51707 .43839 .51389 Mtetra
.43839 .51389 .44157 .51707 .44705 .51535 .44389 .51216 Mtetra
.44389 .51216 .44705 .51535 .45255 .51363 .44939 .51043 Mtetra
.44939 .51043 .45255 .51363 .45805 .5119 .4549 .5087 Mtetra
.4549 .5087 .45805 .5119 .46357 .51017 .46042 .50696 Mtetra
.46042 .50696 .46357 .51017 .4691 .50843 .46596 .50522 Mtetra
.46596 .50522 .4691 .50843 .47464 .50669 .47151 .50347 Mtetra
.47151 .50347 .47464 .50669 .48019 .50495 .47706 .50172 Mtetra
.47706 .50172 .48019 .50495 .48575 .5032 .48263 .49997 Mtetra
.48263 .49997 .48575 .5032 .49132 .50145 .48821 .49821 Mtetra
.48821 .49821 .49132 .50145 .49691 .4997 .49381 .49645 Mtetra
.49381 .49645 .49691 .4997 .5025 .49794 .49941 .49469 Mtetra
.49941 .49469 .5025 .49794 .50811 .49618 .50502 .49292 Mtetra
.50502 .49292 .50811 .49618 .51373 .49442 .51065 .49115 Mtetra
.51065 .49115 .51373 .49442 .51936 .49265 .51629 .48938 Mtetra
.51629 .48938 .51936 .49265 .525 .49088 .52194 .4876 Mtetra
.52194 .4876 .525 .49088 .53066 .4891 .5276 .48581 Mtetra
.5276 .48581 .53066 .4891 .53632 .48732 .53327 .48403 Mtetra
.53327 .48403 .53632 .48732 .542 .48554 .53896 .48224 Mtetra
.53896 .48224 .542 .48554 .54769 .48375 .54466 .48045 Mtetra
.54466 .48045 .54769 .48375 .55339 .48196 .55036 .47865 Mtetra
.55036 .47865 .55339 .48196 .5591 .48017 .55608 .47685 Mtetra
.55608 .47685 .5591 .48017 .56483 .47837 .56182 .47505 Mtetra
.56182 .47505 .56483 .47837 .57056 .47657 .56756 .47324 Mtetra
.56756 .47324 .57056 .47657 .57631 .47477 .57332 .47143 Mtetra
.57332 .47143 .57631 .47477 .58207 .47296 .57908 .46961 Mtetra
.57908 .46961 .58207 .47296 .58784 .47115 .58486 .46779 Mtetra
.58486 .46779 .58784 .47115 .59363 .46933 .59066 .46597 Mtetra
.59066 .46597 .59363 .46933 .59942 .46751 .59646 .46414 Mtetra
.663 .741 .908 r
.59646 .46414 .59942 .46751 .60523 .46569 .60228 .46231 Mtetra
.60228 .46231 .60523 .46569 .61105 .46386 .6081 .46048 Mtetra
.661 .741 .909 r
.6081 .46048 .61105 .46386 .61688 .46207 .61395 .45868 Mtetra
.664 .741 .908 r
.61395 .45868 .61688 .46207 .62273 .46023 .6198 .45684 Mtetra
.666 .742 .907 r
.6198 .45684 .62273 .46023 .62858 .45836 .62566 .45495 Mtetra
.664 .741 .908 r
.62566 .45495 .62858 .45836 .63445 .45651 .63154 .4531 Mtetra
.63154 .4531 .63445 .45651 .64033 .45467 .63743 .45125 Mtetra
.63743 .45125 .64033 .45467 .64623 .45282 .64333 .44939 Mtetra
.64333 .44939 .64623 .45282 .65213 .45096 .64925 .44753 Mtetra
.64925 .44753 .65213 .45096 .65805 .4491 .65517 .44566 Mtetra
.65517 .44566 .65805 .4491 .66398 .44724 .66111 .44379 Mtetra
.66111 .44379 .66398 .44724 .66993 .44537 .66706 .44192 Mtetra
.66706 .44192 .66993 .44537 .67588 .4435 .67303 .44004 Mtetra
.67303 .44004 .67588 .4435 .68185 .44163 .67901 .43816 Mtetra
.67901 .43816 .68185 .44163 .68783 .43975 .68499 .43628 Mtetra
.68499 .43628 .68783 .43975 .69383 .43787 .691 .43439 Mtetra
.691 .43439 .69383 .43787 .69983 .43599 .69701 .43249 Mtetra
.69701 .43249 .69983 .43599 .70585 .4341 .70304 .4306 Mtetra
.70304 .4306 .70585 .4341 .71188 .4322 .70908 .42869 Mtetra
.70908 .42869 .71188 .4322 .71793 .4303 .71514 .42679 Mtetra
.71514 .42679 .71793 .4303 .72399 .4284 .7212 .42488 Mtetra
.7212 .42488 .72399 .4284 .73006 .4265 .72728 .42297 Mtetra
.72728 .42297 .73006 .4265 .73614 .42459 .73337 .42105 Mtetra
.73337 .42105 .73614 .42459 .74224 .42267 .73948 .41913 Mtetra
.73948 .41913 .74224 .42267 .74835 .42075 .7456 .4172 Mtetra
.7456 .4172 .74835 .42075 .75447 .41883 .75173 .41527 Mtetra
.75173 .41527 .75447 .41883 .7606 .4169 .75788 .41334 Mtetra
.75788 .41334 .7606 .4169 .76675 .41497 .76403 .4114 Mtetra
.76403 .4114 .76675 .41497 .77292 .41304 .7702 .40946 Mtetra
.7702 .40946 .77292 .41304 .77909 .4111 .77639 .40751 Mtetra
.77639 .40751 .77909 .4111 .78528 .40916 .78259 .40556 Mtetra
.78259 .40556 .78528 .40916 .79148 .40721 .7888 .4036 Mtetra
.7888 .4036 .79148 .40721 .7977 .40526 .79502 .40164 Mtetra
.79502 .40164 .7977 .40526 .80393 .4033 .80126 .39968 Mtetra
.80126 .39968 .80393 .4033 .81017 .40134 .80751 .39771 Mtetra
.80751 .39771 .81017 .40134 .81642 .39938 .81378 .39574 Mtetra
.81378 .39574 .81642 .39938 .82269 .39741 .82006 .39377 Mtetra
.82006 .39377 .82269 .39741 .82898 .39544 .82635 .39178 Mtetra
.82635 .39178 .82898 .39544 .83527 .39346 .83266 .3898 Mtetra
.83266 .3898 .83527 .39346 .84158 .39148 .83898 .38781 Mtetra
.83898 .38781 .84158 .39148 .84791 .38949 .84531 .38582 Mtetra
.84531 .38582 .84791 .38949 .85424 .3875 .85166 .38382 Mtetra
.85166 .38382 .85424 .3875 .8606 .38551 .85802 .38182 Mtetra
.85802 .38182 .8606 .38551 .86696 .38351 .86439 .37981 Mtetra
.86439 .37981 .86696 .38351 .87334 .38151 .87078 .3778 Mtetra
.87078 .3778 .87334 .38151 .87973 .3795 .87719 .37578 Mtetra
.87719 .37578 .87973 .3795 .88614 .37749 .8836 .37376 Mtetra
.8836 .37376 .88614 .37749 .89256 .37547 .89004 .37174 Mtetra
.89004 .37174 .89256 .37547 .899 .37345 .89648 .36971 Mtetra
.89648 .36971 .899 .37345 .90545 .37143 .90294 .36768 Mtetra
.90294 .36768 .90545 .37143 .91191 .3694 .90941 .36564 Mtetra
.90941 .36564 .91191 .3694 .91839 .36736 .9159 .3636 Mtetra
.9159 .3636 .91839 .36736 .92488 .36533 .92241 .36155 Mtetra
.33812 .54133 .34143 .54441 .34673 .54274 .34343 .53966 Mtetra
.34343 .53966 .34673 .54274 .35203 .54107 .34874 .53798 Mtetra
.34874 .53798 .35203 .54107 .35735 .5394 .35406 .5363 Mtetra
.35406 .5363 .35735 .5394 .36268 .53772 .3594 .53462 Mtetra
.3594 .53462 .36268 .53772 .36802 .53604 .36474 .53293 Mtetra
.36474 .53293 .36802 .53604 .37336 .53436 .3701 .53124 Mtetra
.3701 .53124 .37336 .53436 .37872 .53267 .37546 .52955 Mtetra
.37546 .52955 .37872 .53267 .38409 .53098 .38084 .52785 Mtetra
.38084 .52785 .38409 .53098 .38948 .52929 .38623 .52615 Mtetra
.38623 .52615 .38948 .52929 .39487 .52759 .39163 .52445 Mtetra
.39163 .52445 .39487 .52759 .40027 .52589 .39703 .52274 Mtetra
.39703 .52274 .40027 .52589 .40568 .52419 .40246 .52103 Mtetra
.40246 .52103 .40568 .52419 .41111 .52248 .40789 .51932 Mtetra
.40789 .51932 .41111 .52248 .41654 .52077 .41333 .5176 Mtetra
.41333 .5176 .41654 .52077 .42199 .51906 .41878 .51588 Mtetra
.41878 .51588 .42199 .51906 .42745 .51734 .42425 .51416 Mtetra
.42425 .51416 .42745 .51734 .43291 .51562 .42972 .51243 Mtetra
.42972 .51243 .43291 .51562 .43839 .51389 .43521 .5107 Mtetra
.43521 .5107 .43839 .51389 .44389 .51216 .44071 .50896 Mtetra
.44071 .50896 .44389 .51216 .44939 .51043 .44621 .50723 Mtetra
.44621 .50723 .44939 .51043 .4549 .5087 .45173 .50548 Mtetra
.45173 .50548 .4549 .5087 .46042 .50696 .45727 .50374 Mtetra
.45727 .50374 .46042 .50696 .46596 .50522 .46281 .50199 Mtetra
.46281 .50199 .46596 .50522 .47151 .50347 .46836 .50024 Mtetra
.46836 .50024 .47151 .50347 .47706 .50172 .47393 .49848 Mtetra
.47393 .49848 .47706 .50172 .48263 .49997 .4795 .49672 Mtetra
.4795 .49672 .48263 .49997 .48821 .49821 .48509 .49496 Mtetra
.48509 .49496 .48821 .49821 .49381 .49645 .49069 .49319 Mtetra
.49069 .49319 .49381 .49645 .49941 .49469 .4963 .49142 Mtetra
.4963 .49142 .49941 .49469 .50502 .49292 .50193 .48965 Mtetra
.50193 .48965 .50502 .49292 .51065 .49115 .50756 .48787 Mtetra
.50756 .48787 .51065 .49115 .51629 .48938 .51321 .48609 Mtetra
.51321 .48609 .51629 .48938 .52194 .4876 .51886 .4843 Mtetra
.51886 .4843 .52194 .4876 .5276 .48581 .52453 .48252 Mtetra
.52453 .48252 .5276 .48581 .53327 .48403 .53021 .48072 Mtetra
.53021 .48072 .53327 .48403 .53896 .48224 .53591 .47893 Mtetra
.53591 .47893 .53896 .48224 .54466 .48045 .54161 .47713 Mtetra
.54161 .47713 .54466 .48045 .55036 .47865 .54733 .47532 Mtetra
.54733 .47532 .55036 .47865 .55608 .47685 .55305 .47352 Mtetra
.55305 .47352 .55608 .47685 .56182 .47505 .55879 .47171 Mtetra
.55879 .47171 .56182 .47505 .56756 .47324 .56455 .46989 Mtetra
.56455 .46989 .56756 .47324 .57332 .47143 .57031 .46807 Mtetra
.57031 .46807 .57332 .47143 .57908 .46961 .57609 .46625 Mtetra
.57609 .46625 .57908 .46961 .58486 .46779 .58187 .46442 Mtetra
.58187 .46442 .58486 .46779 .59066 .46597 .58767 .46259 Mtetra
.58767 .46259 .59066 .46597 .59646 .46414 .59349 .46076 Mtetra
.663 .741 .908 r
.59349 .46076 .59646 .46414 .60228 .46231 .59931 .45892 Mtetra
.59931 .45892 .60228 .46231 .6081 .46048 .60515 .45708 Mtetra
.661 .74 .909 r
.60515 .45708 .6081 .46048 .61395 .45868 .611 .45528 Mtetra
.664 .741 .908 r
.611 .45528 .61395 .45868 .6198 .45684 .61686 .45343 Mtetra
.666 .742 .907 r
.61686 .45343 .6198 .45684 .62566 .45495 .62273 .45154 Mtetra
.664 .741 .908 r
.62273 .45154 .62566 .45495 .63154 .4531 .62861 .44968 Mtetra
.62861 .44968 .63154 .4531 .63743 .45125 .63451 .44782 Mtetra
.63451 .44782 .63743 .45125 .64333 .44939 .64042 .44595 Mtetra
.64042 .44595 .64333 .44939 .64925 .44753 .64635 .44408 Mtetra
.64635 .44408 .64925 .44753 .65517 .44566 .65228 .44221 Mtetra
.65228 .44221 .65517 .44566 .66111 .44379 .65823 .44033 Mtetra
.65823 .44033 .66111 .44379 .66706 .44192 .66419 .43845 Mtetra
.66419 .43845 .66706 .44192 .67303 .44004 .67016 .43657 Mtetra
.67016 .43657 .67303 .44004 .67901 .43816 .67615 .43468 Mtetra
.67615 .43468 .67901 .43816 .68499 .43628 .68215 .43278 Mtetra
.68215 .43278 .68499 .43628 .691 .43439 .68816 .43089 Mtetra
.68816 .43089 .691 .43439 .69701 .43249 .69418 .42899 Mtetra
.69418 .42899 .69701 .43249 .70304 .4306 .70022 .42708 Mtetra
.70022 .42708 .70304 .4306 .70908 .42869 .70627 .42517 Mtetra
.70627 .42517 .70908 .42869 .71514 .42679 .71233 .42326 Mtetra
.71233 .42326 .71514 .42679 .7212 .42488 .71841 .42134 Mtetra
.71841 .42134 .7212 .42488 .72728 .42297 .7245 .41942 Mtetra
.7245 .41942 .72728 .42297 .73337 .42105 .7306 .4175 Mtetra
.7306 .4175 .73337 .42105 .73948 .41913 .73671 .41557 Mtetra
.73671 .41557 .73948 .41913 .7456 .4172 .74284 .41363 Mtetra
.74284 .41363 .7456 .4172 .75173 .41527 .74898 .4117 Mtetra
.74898 .4117 .75173 .41527 .75788 .41334 .75513 .40976 Mtetra
.75513 .40976 .75788 .41334 .76403 .4114 .7613 .40781 Mtetra
.7613 .40781 .76403 .4114 .7702 .40946 .76748 .40586 Mtetra
.76748 .40586 .7702 .40946 .77639 .40751 .77368 .4039 Mtetra
.77368 .4039 .77639 .40751 .78259 .40556 .77988 .40195 Mtetra
.77988 .40195 .78259 .40556 .7888 .4036 .78611 .39998 Mtetra
.78611 .39998 .7888 .4036 .79502 .40164 .79234 .39802 Mtetra
.79234 .39802 .79502 .40164 .80126 .39968 .79859 .39604 Mtetra
.79859 .39604 .80126 .39968 .80751 .39771 .80485 .39407 Mtetra
.80485 .39407 .80751 .39771 .81378 .39574 .81112 .39209 Mtetra
.81112 .39209 .81378 .39574 .82006 .39377 .81741 .39011 Mtetra
.81741 .39011 .82006 .39377 .82635 .39178 .82371 .38812 Mtetra
.82371 .38812 .82635 .39178 .83266 .3898 .83003 .38612 Mtetra
.83003 .38612 .83266 .3898 .83898 .38781 .83636 .38413 Mtetra
.83636 .38413 .83898 .38781 .84531 .38582 .8427 .38213 Mtetra
.8427 .38213 .84531 .38582 .85166 .38382 .84906 .38012 Mtetra
.84906 .38012 .85166 .38382 .85802 .38182 .85543 .37811 Mtetra
.85543 .37811 .85802 .38182 .86439 .37981 .86182 .37609 Mtetra
.86182 .37609 .86439 .37981 .87078 .3778 .86822 .37407 Mtetra
.86822 .37407 .87078 .3778 .87719 .37578 .87463 .37205 Mtetra
.87463 .37205 .87719 .37578 .8836 .37376 .88106 .37002 Mtetra
.88106 .37002 .8836 .37376 .89004 .37174 .8875 .36799 Mtetra
.8875 .36799 .89004 .37174 .89648 .36971 .89396 .36595 Mtetra
.89396 .36595 .89648 .36971 .90294 .36768 .90043 .36391 Mtetra
.90043 .36391 .90294 .36768 .90941 .36564 .90691 .36187 Mtetra
.90691 .36187 .90941 .36564 .9159 .3636 .91341 .35982 Mtetra
.91341 .35982 .9159 .3636 .92241 .36155 .91992 .35776 Mtetra
.33481 .53824 .33812 .54133 .34343 .53966 .34011 .53656 Mtetra
.34011 .53656 .34343 .53966 .34874 .53798 .34543 .53488 Mtetra
.34543 .53488 .34874 .53798 .35406 .5363 .35076 .53319 Mtetra
.35076 .53319 .35406 .5363 .3594 .53462 .3561 .5315 Mtetra
.3561 .5315 .3594 .53462 .36474 .53293 .36145 .52981 Mtetra
.36145 .52981 .36474 .53293 .3701 .53124 .36682 .52811 Mtetra
.36682 .52811 .3701 .53124 .37546 .52955 .37219 .52642 Mtetra
.37219 .52642 .37546 .52955 .38084 .52785 .37757 .52471 Mtetra
.37757 .52471 .38084 .52785 .38623 .52615 .38297 .52301 Mtetra
.38297 .52301 .38623 .52615 .39163 .52445 .38837 .5213 Mtetra
.38837 .5213 .39163 .52445 .39703 .52274 .39379 .51958 Mtetra
.39379 .51958 .39703 .52274 .40246 .52103 .39922 .51787 Mtetra
.39922 .51787 .40246 .52103 .40789 .51932 .40465 .51615 Mtetra
.40465 .51615 .40789 .51932 .41333 .5176 .4101 .51442 Mtetra
.4101 .51442 .41333 .5176 .41878 .51588 .41556 .5127 Mtetra
.41556 .5127 .41878 .51588 .42425 .51416 .42103 .51097 Mtetra
.42103 .51097 .42425 .51416 .42972 .51243 .42652 .50923 Mtetra
.42652 .50923 .42972 .51243 .43521 .5107 .43201 .50749 Mtetra
.43201 .50749 .43521 .5107 .44071 .50896 .43751 .50575 Mtetra
.43751 .50575 .44071 .50896 .44621 .50723 .44303 .50401 Mtetra
.44303 .50401 .44621 .50723 .45173 .50548 .44856 .50226 Mtetra
.44856 .50226 .45173 .50548 .45727 .50374 .4541 .50051 Mtetra
.4541 .50051 .45727 .50374 .46281 .50199 .45965 .49875 Mtetra
.45965 .49875 .46281 .50199 .46836 .50024 .46521 .49699 Mtetra
.46521 .49699 .46836 .50024 .47393 .49848 .47078 .49523 Mtetra
.47078 .49523 .47393 .49848 .4795 .49672 .47636 .49346 Mtetra
.47636 .49346 .4795 .49672 .48509 .49496 .48196 .49169 Mtetra
.48196 .49169 .48509 .49496 .49069 .49319 .48757 .48992 Mtetra
.48757 .48992 .49069 .49319 .4963 .49142 .49318 .48814 Mtetra
.49318 .48814 .4963 .49142 .50193 .48965 .49881 .48636 Mtetra
.49881 .48636 .50193 .48965 .50756 .48787 .50446 .48458 Mtetra
.50446 .48458 .50756 .48787 .51321 .48609 .51011 .48279 Mtetra
.51011 .48279 .51321 .48609 .51886 .4843 .51577 .481 Mtetra
.51577 .481 .51886 .4843 .52453 .48252 .52145 .4792 Mtetra
.52145 .4792 .52453 .48252 .53021 .48072 .52714 .4774 Mtetra
.52714 .4774 .53021 .48072 .53591 .47893 .53284 .4756 Mtetra
.53284 .4756 .53591 .47893 .54161 .47713 .53855 .47379 Mtetra
.53855 .47379 .54161 .47713 .54733 .47532 .54428 .47198 Mtetra
.54428 .47198 .54733 .47532 .55305 .47352 .55001 .47017 Mtetra
.55001 .47017 .55305 .47352 .55879 .47171 .55576 .46835 Mtetra
.55576 .46835 .55879 .47171 .56455 .46989 .56152 .46653 Mtetra
.56152 .46653 .56455 .46989 .57031 .46807 .56729 .4647 Mtetra
.56729 .4647 .57031 .46807 .57609 .46625 .57307 .46288 Mtetra
.57307 .46288 .57609 .46625 .58187 .46442 .57887 .46104 Mtetra
.57887 .46104 .58187 .46442 .58767 .46259 .58468 .45921 Mtetra
.58468 .45921 .58767 .46259 .59349 .46076 .5905 .45736 Mtetra
.663 .741 .908 r
.5905 .45736 .59349 .46076 .59931 .45892 .59633 .45552 Mtetra
.59633 .45552 .59931 .45892 .60515 .45708 .60218 .45368 Mtetra
.661 .74 .909 r
.60218 .45368 .60515 .45708 .611 .45528 .60803 .45186 Mtetra
.664 .741 .908 r
.60803 .45186 .611 .45528 .61686 .45343 .6139 .45001 Mtetra
.666 .742 .907 r
.6139 .45001 .61686 .45343 .62273 .45154 .61978 .44811 Mtetra
.664 .741 .908 r
.61978 .44811 .62273 .45154 .62861 .44968 .62568 .44624 Mtetra
.62568 .44624 .62861 .44968 .63451 .44782 .63158 .44437 Mtetra
.63158 .44437 .63451 .44782 .64042 .44595 .6375 .4425 Mtetra
.6375 .4425 .64042 .44595 .64635 .44408 .64343 .44062 Mtetra
.64343 .44062 .64635 .44408 .65228 .44221 .64938 .43874 Mtetra
.64938 .43874 .65228 .44221 .65823 .44033 .65533 .43686 Mtetra
.65533 .43686 .65823 .44033 .66419 .43845 .6613 .43497 Mtetra
.6613 .43497 .66419 .43845 .67016 .43657 .66729 .43308 Mtetra
.66729 .43308 .67016 .43657 .67615 .43468 .67328 .43118 Mtetra
.67328 .43118 .67615 .43468 .68215 .43278 .67929 .42928 Mtetra
.67929 .42928 .68215 .43278 .68816 .43089 .68531 .42738 Mtetra
.68531 .42738 .68816 .43089 .69418 .42899 .69134 .42547 Mtetra
.69134 .42547 .69418 .42899 .70022 .42708 .69739 .42356 Mtetra
.69739 .42356 .70022 .42708 .70627 .42517 .70344 .42164 Mtetra
.70344 .42164 .70627 .42517 .71233 .42326 .70952 .41972 Mtetra
.70952 .41972 .71233 .42326 .71841 .42134 .7156 .41779 Mtetra
.7156 .41779 .71841 .42134 .7245 .41942 .7217 .41587 Mtetra
.7217 .41587 .7245 .41942 .7306 .4175 .72781 .41393 Mtetra
.72781 .41393 .7306 .4175 .73671 .41557 .73393 .412 Mtetra
.73393 .412 .73671 .41557 .74284 .41363 .74007 .41005 Mtetra
.74007 .41005 .74284 .41363 .74898 .4117 .74622 .40811 Mtetra
.74622 .40811 .74898 .4117 .75513 .40976 .75238 .40616 Mtetra
.75238 .40616 .75513 .40976 .7613 .40781 .75856 .40421 Mtetra
.75856 .40421 .7613 .40781 .76748 .40586 .76475 .40225 Mtetra
.76475 .40225 .76748 .40586 .77368 .4039 .77095 .40029 Mtetra
.77095 .40029 .77368 .4039 .77988 .40195 .77717 .39832 Mtetra
.77717 .39832 .77988 .40195 .78611 .39998 .7834 .39635 Mtetra
.7834 .39635 .78611 .39998 .79234 .39802 .78964 .39437 Mtetra
.78964 .39437 .79234 .39802 .79859 .39604 .7959 .39239 Mtetra
.7959 .39239 .79859 .39604 .80485 .39407 .80217 .39041 Mtetra
.80217 .39041 .80485 .39407 .81112 .39209 .80846 .38842 Mtetra
.80846 .38842 .81112 .39209 .81741 .39011 .81476 .38643 Mtetra
.81476 .38643 .81741 .39011 .82371 .38812 .82107 .38443 Mtetra
.82107 .38443 .82371 .38812 .83003 .38612 .82739 .38243 Mtetra
.82739 .38243 .83003 .38612 .83636 .38413 .83373 .38043 Mtetra
.83373 .38043 .83636 .38413 .8427 .38213 .84009 .37842 Mtetra
.84009 .37842 .8427 .38213 .84906 .38012 .84645 .3764 Mtetra
.84645 .3764 .84906 .38012 .85543 .37811 .85284 .37439 Mtetra
.85284 .37439 .85543 .37811 .86182 .37609 .85923 .37236 Mtetra
.85923 .37236 .86182 .37609 .86822 .37407 .86564 .37034 Mtetra
.86564 .37034 .86822 .37407 .87463 .37205 .87206 .3683 Mtetra
.87206 .3683 .87463 .37205 .88106 .37002 .8785 .36627 Mtetra
.8785 .36627 .88106 .37002 .8875 .36799 .88495 .36423 Mtetra
.88495 .36423 .8875 .36799 .89396 .36595 .89142 .36218 Mtetra
.89142 .36218 .89396 .36595 .90043 .36391 .8979 .36013 Mtetra
.8979 .36013 .90043 .36391 .90691 .36187 .9044 .35808 Mtetra
.9044 .35808 .90691 .36187 .91341 .35982 .91091 .35602 Mtetra
.91091 .35602 .91341 .35982 .91992 .35776 .91743 .35396 Mtetra
.33147 .53514 .33481 .53824 .34011 .53656 .33679 .53345 Mtetra
.33679 .53345 .34011 .53656 .34543 .53488 .34211 .53176 Mtetra
.34211 .53176 .34543 .53488 .35076 .53319 .34745 .53007 Mtetra
.34745 .53007 .35076 .53319 .3561 .5315 .3528 .52838 Mtetra
.3528 .52838 .3561 .5315 .36145 .52981 .35815 .52668 Mtetra
.35815 .52668 .36145 .52981 .36682 .52811 .36352 .52497 Mtetra
.36352 .52497 .36682 .52811 .37219 .52642 .3689 .52327 Mtetra
.3689 .52327 .37219 .52642 .37757 .52471 .37429 .52156 Mtetra
.37429 .52156 .37757 .52471 .38297 .52301 .37969 .51985 Mtetra
.37969 .51985 .38297 .52301 .38837 .5213 .38511 .51813 Mtetra
.38511 .51813 .38837 .5213 .39379 .51958 .39053 .51641 Mtetra
.39053 .51641 .39379 .51958 .39922 .51787 .39596 .51469 Mtetra
.39596 .51469 .39922 .51787 .40465 .51615 .40141 .51296 Mtetra
.40141 .51296 .40465 .51615 .4101 .51442 .40686 .51123 Mtetra
.40686 .51123 .4101 .51442 .41556 .5127 .41233 .5095 Mtetra
.41233 .5095 .41556 .5127 .42103 .51097 .41781 .50776 Mtetra
.41781 .50776 .42103 .51097 .42652 .50923 .4233 .50602 Mtetra
.4233 .50602 .42652 .50923 .43201 .50749 .4288 .50428 Mtetra
.4288 .50428 .43201 .50749 .43751 .50575 .43431 .50253 Mtetra
.43431 .50253 .43751 .50575 .44303 .50401 .43983 .50078 Mtetra
.43983 .50078 .44303 .50401 .44856 .50226 .44537 .49902 Mtetra
.44537 .49902 .44856 .50226 .4541 .50051 .45091 .49726 Mtetra
.45091 .49726 .4541 .50051 .45965 .49875 .45647 .4955 Mtetra
.45647 .4955 .45965 .49875 .46521 .49699 .46204 .49374 Mtetra
.46204 .49374 .46521 .49699 .47078 .49523 .46762 .49197 Mtetra
.46762 .49197 .47078 .49523 .47636 .49346 .47321 .49019 Mtetra
.47321 .49019 .47636 .49346 .48196 .49169 .47881 .48842 Mtetra
.47881 .48842 .48196 .49169 .48757 .48992 .48443 .48664 Mtetra
.48443 .48664 .48757 .48992 .49318 .48814 .49005 .48485 Mtetra
.49005 .48485 .49318 .48814 .49881 .48636 .49569 .48307 Mtetra
.49569 .48307 .49881 .48636 .50446 .48458 .50134 .48127 Mtetra
.50134 .48127 .50446 .48458 .51011 .48279 .507 .47948 Mtetra
.507 .47948 .51011 .48279 .51577 .481 .51267 .47768 Mtetra
.51267 .47768 .51577 .481 .52145 .4792 .51836 .47588 Mtetra
.51836 .47588 .52145 .4792 .52714 .4774 .52406 .47407 Mtetra
.52406 .47407 .52714 .4774 .53284 .4756 .52976 .47226 Mtetra
.52976 .47226 .53284 .4756 .53855 .47379 .53548 .47045 Mtetra
.53548 .47045 .53855 .47379 .54428 .47198 .54121 .46863 Mtetra
.54121 .46863 .54428 .47198 .55001 .47017 .54696 .46681 Mtetra
.54696 .46681 .55001 .47017 .55576 .46835 .55271 .46499 Mtetra
.55271 .46499 .55576 .46835 .56152 .46653 .55848 .46316 Mtetra
.55848 .46316 .56152 .46653 .56729 .4647 .56426 .46132 Mtetra
.56426 .46132 .56729 .4647 .57307 .46288 .57005 .45949 Mtetra
.57005 .45949 .57307 .46288 .57887 .46104 .57586 .45765 Mtetra
.57586 .45765 .57887 .46104 .58468 .45921 .58167 .4558 Mtetra
.58167 .4558 .58468 .45921 .5905 .45736 .5875 .45396 Mtetra
.663 .741 .908 r
.5875 .45396 .5905 .45736 .59633 .45552 .59334 .4521 Mtetra
.59334 .4521 .59633 .45552 .60218 .45368 .59919 .45025 Mtetra
.661 .74 .909 r
.59919 .45025 .60218 .45368 .60803 .45186 .60506 .44844 Mtetra
.664 .742 .908 r
.60506 .44844 .60803 .45186 .6139 .45001 .61094 .44657 Mtetra
.666 .742 .907 r
.61094 .44657 .6139 .45001 .61978 .44811 .61683 .44466 Mtetra
.664 .741 .908 r
.61683 .44466 .61978 .44811 .62568 .44624 .62273 .44279 Mtetra
.62273 .44279 .62568 .44624 .63158 .44437 .62864 .44091 Mtetra
.62864 .44091 .63158 .44437 .6375 .4425 .63457 .43903 Mtetra
.63457 .43903 .6375 .4425 .64343 .44062 .64051 .43715 Mtetra
.64051 .43715 .64343 .44062 .64938 .43874 .64646 .43526 Mtetra
.64646 .43526 .64938 .43874 .65533 .43686 .65243 .43337 Mtetra
.65243 .43337 .65533 .43686 .6613 .43497 .65841 .43147 Mtetra
.65841 .43147 .6613 .43497 .66729 .43308 .6644 .42957 Mtetra
.6644 .42957 .66729 .43308 .67328 .43118 .6704 .42767 Mtetra
.6704 .42767 .67328 .43118 .67929 .42928 .67642 .42576 Mtetra
.67642 .42576 .67929 .42928 .68531 .42738 .68244 .42385 Mtetra
.68244 .42385 .68531 .42738 .69134 .42547 .68849 .42193 Mtetra
.68849 .42193 .69134 .42547 .69739 .42356 .69454 .42001 Mtetra
.69454 .42001 .69739 .42356 .70344 .42164 .70061 .41809 Mtetra
.70061 .41809 .70344 .42164 .70952 .41972 .70669 .41616 Mtetra
.70669 .41616 .70952 .41972 .7156 .41779 .71278 .41423 Mtetra
.71278 .41423 .7156 .41779 .7217 .41587 .71889 .41229 Mtetra
.71889 .41229 .7217 .41587 .72781 .41393 .72501 .41035 Mtetra
.72501 .41035 .72781 .41393 .73393 .412 .73114 .40841 Mtetra
.73114 .40841 .73393 .412 .74007 .41005 .73729 .40646 Mtetra
.73729 .40646 .74007 .41005 .74622 .40811 .74345 .40451 Mtetra
.74345 .40451 .74622 .40811 .75238 .40616 .74962 .40255 Mtetra
.74962 .40255 .75238 .40616 .75856 .40421 .75581 .40059 Mtetra
.75581 .40059 .75856 .40421 .76475 .40225 .76201 .39862 Mtetra
.76201 .39862 .76475 .40225 .77095 .40029 .76822 .39665 Mtetra
.76822 .39665 .77095 .40029 .77717 .39832 .77445 .39468 Mtetra
.77445 .39468 .77717 .39832 .7834 .39635 .78069 .3927 Mtetra
.78069 .3927 .7834 .39635 .78964 .39437 .78694 .39072 Mtetra
.78694 .39072 .78964 .39437 .7959 .39239 .79321 .38873 Mtetra
.79321 .38873 .7959 .39239 .80217 .39041 .79949 .38674 Mtetra
.79949 .38674 .80217 .39041 .80846 .38842 .80578 .38474 Mtetra
.80578 .38474 .80846 .38842 .81476 .38643 .81209 .38274 Mtetra
.81209 .38274 .81476 .38643 .82107 .38443 .81841 .38074 Mtetra
.81841 .38074 .82107 .38443 .82739 .38243 .82475 .37873 Mtetra
.82475 .37873 .82739 .38243 .83373 .38043 .8311 .37671 Mtetra
.8311 .37671 .83373 .38043 .84009 .37842 .83746 .3747 Mtetra
.83746 .3747 .84009 .37842 .84645 .3764 .84384 .37267 Mtetra
.84384 .37267 .84645 .3764 .85284 .37439 .85023 .37065 Mtetra
.85023 .37065 .85284 .37439 .85923 .37236 .85663 .36862 Mtetra
.85663 .36862 .85923 .37236 .86564 .37034 .86305 .36658 Mtetra
.86305 .36658 .86564 .37034 .87206 .3683 .86949 .36454 Mtetra
.86949 .36454 .87206 .3683 .8785 .36627 .87594 .3625 Mtetra
.87594 .3625 .8785 .36627 .88495 .36423 .8824 .36045 Mtetra
.8824 .36045 .88495 .36423 .89142 .36218 .88887 .35839 Mtetra
.88887 .35839 .89142 .36218 .8979 .36013 .89537 .35634 Mtetra
.89537 .35634 .8979 .36013 .9044 .35808 .90187 .35427 Mtetra
.90187 .35427 .9044 .35808 .91091 .35602 .90839 .35221 Mtetra
.90839 .35221 .91091 .35602 .91743 .35396 .91492 .35013 Mtetra
.32813 .53202 .33147 .53514 .33679 .53345 .33345 .53033 Mtetra
.33345 .53033 .33679 .53345 .34211 .53176 .33878 .52864 Mtetra
.33878 .52864 .34211 .53176 .34745 .53007 .34413 .52694 Mtetra
.34413 .52694 .34745 .53007 .3528 .52838 .34948 .52524 Mtetra
.34948 .52524 .3528 .52838 .35815 .52668 .35484 .52353 Mtetra
.35484 .52353 .35815 .52668 .36352 .52497 .36022 .52182 Mtetra
.36022 .52182 .36352 .52497 .3689 .52327 .3656 .52011 Mtetra
.3656 .52011 .3689 .52327 .37429 .52156 .371 .5184 Mtetra
.371 .5184 .37429 .52156 .37969 .51985 .37641 .51668 Mtetra
.37641 .51668 .37969 .51985 .38511 .51813 .38183 .51495 Mtetra
.38183 .51495 .38511 .51813 .39053 .51641 .38726 .51323 Mtetra
.38726 .51323 .39053 .51641 .39596 .51469 .3927 .5115 Mtetra
.3927 .5115 .39596 .51469 .40141 .51296 .39815 .50977 Mtetra
.39815 .50977 .40141 .51296 .40686 .51123 .40361 .50803 Mtetra
.40361 .50803 .40686 .51123 .41233 .5095 .40909 .50629 Mtetra
.40909 .50629 .41233 .5095 .41781 .50776 .41457 .50455 Mtetra
.41457 .50455 .41781 .50776 .4233 .50602 .42007 .5028 Mtetra
.42007 .5028 .4233 .50602 .4288 .50428 .42558 .50105 Mtetra
.42558 .50105 .4288 .50428 .43431 .50253 .4311 .49929 Mtetra
.4311 .49929 .43431 .50253 .43983 .50078 .43663 .49754 Mtetra
.43663 .49754 .43983 .50078 .44537 .49902 .44217 .49577 Mtetra
.44217 .49577 .44537 .49902 .45091 .49726 .44772 .49401 Mtetra
.44772 .49401 .45091 .49726 .45647 .4955 .45329 .49224 Mtetra
.45329 .49224 .45647 .4955 .46204 .49374 .45886 .49047 Mtetra
.45886 .49047 .46204 .49374 .46762 .49197 .46445 .48869 Mtetra
.46445 .48869 .46762 .49197 .47321 .49019 .47005 .48691 Mtetra
.47005 .48691 .47321 .49019 .47881 .48842 .47566 .48513 Mtetra
.47566 .48513 .47881 .48842 .48443 .48664 .48128 .48334 Mtetra
.48128 .48334 .48443 .48664 .49005 .48485 .48691 .48155 Mtetra
.48691 .48155 .49005 .48485 .49569 .48307 .49256 .47976 Mtetra
.49256 .47976 .49569 .48307 .50134 .48127 .49821 .47796 Mtetra
.49821 .47796 .50134 .48127 .507 .47948 .50388 .47616 Mtetra
.50388 .47616 .507 .47948 .51267 .47768 .50956 .47435 Mtetra
.50956 .47435 .51267 .47768 .51836 .47588 .51525 .47254 Mtetra
.51525 .47254 .51836 .47588 .52406 .47407 .52096 .47073 Mtetra
.52096 .47073 .52406 .47407 .52976 .47226 .52667 .46891 Mtetra
.52667 .46891 .52976 .47226 .53548 .47045 .5324 .46709 Mtetra
.5324 .46709 .53548 .47045 .54121 .46863 .53814 .46527 Mtetra
.53814 .46527 .54121 .46863 .54696 .46681 .54389 .46344 Mtetra
.54389 .46344 .54696 .46681 .55271 .46499 .54966 .46161 Mtetra
.54966 .46161 .55271 .46499 .55848 .46316 .55543 .45977 Mtetra
.55543 .45977 .55848 .46316 .56426 .46132 .56122 .45793 Mtetra
.56122 .45793 .56426 .46132 .57005 .45949 .56702 .45609 Mtetra
.56702 .45609 .57005 .45949 .57586 .45765 .57283 .45424 Mtetra
.57283 .45424 .57586 .45765 .58167 .4558 .57866 .45239 Mtetra
.57866 .45239 .58167 .4558 .5875 .45396 .58449 .45053 Mtetra
.663 .741 .908 r
.58449 .45053 .5875 .45396 .59334 .4521 .59034 .44868 Mtetra
.59034 .44868 .59334 .4521 .59919 .45025 .5962 .44682 Mtetra
.66 .74 .909 r
.5962 .44682 .59919 .45025 .60506 .44844 .60208 .445 Mtetra
.664 .742 .908 r
.60208 .445 .60506 .44844 .61094 .44657 .60796 .44313 Mtetra
.667 .743 .907 r
.60796 .44313 .61094 .44657 .61683 .44466 .61386 .4412 Mtetra
.664 .741 .908 r
.61386 .4412 .61683 .44466 .62273 .44279 .61977 .43932 Mtetra
.61977 .43932 .62273 .44279 .62864 .44091 .62569 .43744 Mtetra
.62569 .43744 .62864 .44091 .63457 .43903 .63163 .43555 Mtetra
.63163 .43555 .63457 .43903 .64051 .43715 .63758 .43366 Mtetra
.63758 .43366 .64051 .43715 .64646 .43526 .64354 .43176 Mtetra
.64354 .43176 .64646 .43526 .65243 .43337 .64951 .42987 Mtetra
.64951 .42987 .65243 .43337 .65841 .43147 .6555 .42796 Mtetra
.6555 .42796 .65841 .43147 .6644 .42957 .6615 .42606 Mtetra
.6615 .42606 .6644 .42957 .6704 .42767 .66751 .42414 Mtetra
.66751 .42414 .6704 .42767 .67642 .42576 .67353 .42223 Mtetra
.67353 .42223 .67642 .42576 .68244 .42385 .67957 .42031 Mtetra
.67957 .42031 .68244 .42385 .68849 .42193 .68562 .41839 Mtetra
.68562 .41839 .68849 .42193 .69454 .42001 .69169 .41646 Mtetra
.69169 .41646 .69454 .42001 .70061 .41809 .69776 .41453 Mtetra
.69776 .41453 .70061 .41809 .70669 .41616 .70385 .41259 Mtetra
.70385 .41259 .70669 .41616 .71278 .41423 .70995 .41065 Mtetra
.70995 .41065 .71278 .41423 .71889 .41229 .71607 .40871 Mtetra
.71607 .40871 .71889 .41229 .72501 .41035 .7222 .40676 Mtetra
.7222 .40676 .72501 .41035 .73114 .40841 .72834 .40481 Mtetra
.72834 .40481 .73114 .40841 .73729 .40646 .7345 .40285 Mtetra
.7345 .40285 .73729 .40646 .74345 .40451 .74067 .40089 Mtetra
.74067 .40089 .74345 .40451 .74962 .40255 .74685 .39892 Mtetra
.74685 .39892 .74962 .40255 .75581 .40059 .75304 .39696 Mtetra
.75304 .39696 .75581 .40059 .76201 .39862 .75925 .39498 Mtetra
.75925 .39498 .76201 .39862 .76822 .39665 .76547 .393 Mtetra
.76547 .393 .76822 .39665 .77445 .39468 .77171 .39102 Mtetra
.77171 .39102 .77445 .39468 .78069 .3927 .77796 .38904 Mtetra
.77796 .38904 .78069 .3927 .78694 .39072 .78422 .38704 Mtetra
.78422 .38704 .78694 .39072 .79321 .38873 .7905 .38505 Mtetra
.7905 .38505 .79321 .38873 .79949 .38674 .79679 .38305 Mtetra
.79679 .38305 .79949 .38674 .80578 .38474 .80309 .38105 Mtetra
.80309 .38105 .80578 .38474 .81209 .38274 .80941 .37904 Mtetra
.80941 .37904 .81209 .38274 .81841 .38074 .81574 .37702 Mtetra
.81574 .37702 .81841 .38074 .82475 .37873 .82209 .37501 Mtetra
.82209 .37501 .82475 .37873 .8311 .37671 .82845 .37299 Mtetra
.82845 .37299 .8311 .37671 .83746 .3747 .83482 .37096 Mtetra
.83482 .37096 .83746 .3747 .84384 .37267 .84121 .36893 Mtetra
.84121 .36893 .84384 .37267 .85023 .37065 .84761 .36689 Mtetra
.84761 .36689 .85023 .37065 .85663 .36862 .85403 .36486 Mtetra
.85403 .36486 .85663 .36862 .86305 .36658 .86046 .36281 Mtetra
.86046 .36281 .86305 .36658 .86949 .36454 .8669 .36076 Mtetra
.8669 .36076 .86949 .36454 .87594 .3625 .87336 .35871 Mtetra
.87336 .35871 .87594 .3625 .8824 .36045 .87983 .35665 Mtetra
.87983 .35665 .8824 .36045 .88887 .35839 .88632 .35459 Mtetra
.88632 .35459 .88887 .35839 .89537 .35634 .89282 .35252 Mtetra
.89282 .35252 .89537 .35634 .90187 .35427 .89934 .35045 Mtetra
.89934 .35045 .90187 .35427 .90839 .35221 .90587 .34838 Mtetra
.90587 .34838 .90839 .35221 .91492 .35013 .91241 .3463 Mtetra
.32477 .5289 .32813 .53202 .33345 .53033 .3301 .5272 Mtetra
.3301 .5272 .33345 .53033 .33878 .52864 .33544 .5255 Mtetra
.33544 .5255 .33878 .52864 .34413 .52694 .34079 .52379 Mtetra
.34079 .52379 .34413 .52694 .34948 .52524 .34615 .52209 Mtetra
.34615 .52209 .34948 .52524 .35484 .52353 .35152 .52037 Mtetra
.35152 .52037 .35484 .52353 .36022 .52182 .3569 .51866 Mtetra
.3569 .51866 .36022 .52182 .3656 .52011 .36229 .51694 Mtetra
.36229 .51694 .3656 .52011 .371 .5184 .3677 .51522 Mtetra
.3677 .51522 .371 .5184 .37641 .51668 .37311 .51349 Mtetra
.37311 .51349 .37641 .51668 .38183 .51495 .37854 .51176 Mtetra
.37854 .51176 .38183 .51495 .38726 .51323 .38397 .51003 Mtetra
.38397 .51003 .38726 .51323 .3927 .5115 .38942 .5083 Mtetra
.38942 .5083 .3927 .5115 .39815 .50977 .39488 .50656 Mtetra
.39488 .50656 .39815 .50977 .40361 .50803 .40035 .50481 Mtetra
.40035 .50481 .40361 .50803 .40909 .50629 .40583 .50307 Mtetra
.40583 .50307 .40909 .50629 .41457 .50455 .41132 .50132 Mtetra
.41132 .50132 .41457 .50455 .42007 .5028 .41683 .49956 Mtetra
.41683 .49956 .42007 .5028 .42558 .50105 .42234 .49781 Mtetra
.42234 .49781 .42558 .50105 .4311 .49929 .42787 .49604 Mtetra
.42787 .49604 .4311 .49929 .43663 .49754 .43341 .49428 Mtetra
.43341 .49428 .43663 .49754 .44217 .49577 .43895 .49251 Mtetra
.43895 .49251 .44217 .49577 .44772 .49401 .44452 .49074 Mtetra
.44452 .49074 .44772 .49401 .45329 .49224 .45009 .48896 Mtetra
.45009 .48896 .45329 .49224 .45886 .49047 .45567 .48719 Mtetra
.45567 .48719 .45886 .49047 .46445 .48869 .46126 .4854 Mtetra
.46126 .4854 .46445 .48869 .47005 .48691 .46687 .48362 Mtetra
.46687 .48362 .47005 .48691 .47566 .48513 .47249 .48183 Mtetra
.47249 .48183 .47566 .48513 .48128 .48334 .47812 .48003 Mtetra
.47812 .48003 .48128 .48334 .48691 .48155 .48376 .47824 Mtetra
.48376 .47824 .48691 .48155 .49256 .47976 .48941 .47643 Mtetra
.48941 .47643 .49256 .47976 .49821 .47796 .49507 .47463 Mtetra
.49507 .47463 .49821 .47796 .50388 .47616 .50075 .47282 Mtetra
.50075 .47282 .50388 .47616 .50956 .47435 .50644 .47101 Mtetra
.50644 .47101 .50956 .47435 .51525 .47254 .51214 .46919 Mtetra
.51214 .46919 .51525 .47254 .52096 .47073 .51785 .46737 Mtetra
.51785 .46737 .52096 .47073 .52667 .46891 .52357 .46555 Mtetra
.52357 .46555 .52667 .46891 .5324 .46709 .52931 .46372 Mtetra
.52931 .46372 .5324 .46709 .53814 .46527 .53506 .46189 Mtetra
.53506 .46189 .53814 .46527 .54389 .46344 .54082 .46005 Mtetra
.54082 .46005 .54389 .46344 .54966 .46161 .54659 .45821 Mtetra
.54659 .45821 .54966 .46161 .55543 .45977 .55237 .45637 Mtetra
.55237 .45637 .55543 .45977 .56122 .45793 .55817 .45452 Mtetra
.55817 .45452 .56122 .45793 .56702 .45609 .56397 .45267 Mtetra
.56397 .45267 .56702 .45609 .57283 .45424 .56979 .45082 Mtetra
.56979 .45082 .57283 .45424 .57866 .45239 .57563 .44896 Mtetra
.57563 .44896 .57866 .45239 .58449 .45053 .58147 .4471 Mtetra
.663 .741 .908 r
.58147 .4471 .58449 .45053 .59034 .44868 .58733 .44523 Mtetra
.58733 .44523 .59034 .44868 .5962 .44682 .5932 .44337 Mtetra
.66 .74 .909 r
.5932 .44337 .5962 .44682 .60208 .445 .59908 .44154 Mtetra
.664 .742 .908 r
.59908 .44154 .60208 .445 .60796 .44313 .60497 .43967 Mtetra
.667 .743 .907 r
.60497 .43967 .60796 .44313 .61386 .4412 .61088 .43773 Mtetra
.664 .741 .908 r
.61088 .43773 .61386 .4412 .61977 .43932 .6168 .43584 Mtetra
.6168 .43584 .61977 .43932 .62569 .43744 .62273 .43395 Mtetra
.62273 .43395 .62569 .43744 .63163 .43555 .62867 .43206 Mtetra
.62867 .43206 .63163 .43555 .63758 .43366 .63463 .43016 Mtetra
.63463 .43016 .63758 .43366 .64354 .43176 .6406 .42826 Mtetra
.6406 .42826 .64354 .43176 .64951 .42987 .64658 .42635 Mtetra
.64658 .42635 .64951 .42987 .6555 .42796 .65258 .42444 Mtetra
.65258 .42444 .6555 .42796 .6615 .42606 .65859 .42252 Mtetra
.65859 .42252 .6615 .42606 .66751 .42414 .66461 .42061 Mtetra
.66461 .42061 .66751 .42414 .67353 .42223 .67064 .41868 Mtetra
.67064 .41868 .67353 .42223 .67957 .42031 .67669 .41676 Mtetra
.67669 .41676 .67957 .42031 .68562 .41839 .68275 .41483 Mtetra
.68275 .41483 .68562 .41839 .69169 .41646 .68882 .41289 Mtetra
.68882 .41289 .69169 .41646 .69776 .41453 .6949 .41095 Mtetra
.6949 .41095 .69776 .41453 .70385 .41259 .701 .40901 Mtetra
.701 .40901 .70385 .41259 .70995 .41065 .70711 .40706 Mtetra
.70711 .40706 .70995 .41065 .71607 .40871 .71324 .40511 Mtetra
.71324 .40511 .71607 .40871 .7222 .40676 .71938 .40315 Mtetra
.71938 .40315 .7222 .40676 .72834 .40481 .72553 .40119 Mtetra
.72553 .40119 .72834 .40481 .7345 .40285 .73169 .39923 Mtetra
.73169 .39923 .7345 .40285 .74067 .40089 .73787 .39726 Mtetra
.73787 .39726 .74067 .40089 .74685 .39892 .74406 .39529 Mtetra
.74406 .39529 .74685 .39892 .75304 .39696 .75027 .39331 Mtetra
.75027 .39331 .75304 .39696 .75925 .39498 .75649 .39133 Mtetra
.75649 .39133 .75925 .39498 .76547 .393 .76272 .38934 Mtetra
.76272 .38934 .76547 .393 .77171 .39102 .76896 .38735 Mtetra
.76896 .38735 .77171 .39102 .77796 .38904 .77522 .38536 Mtetra
.77522 .38536 .77796 .38904 .78422 .38704 .78149 .38336 Mtetra
.78149 .38336 .78422 .38704 .7905 .38505 .78778 .38135 Mtetra
.78778 .38135 .7905 .38505 .79679 .38305 .79408 .37935 Mtetra
.79408 .37935 .79679 .38305 .80309 .38105 .8004 .37733 Mtetra
.8004 .37733 .80309 .38105 .80941 .37904 .80672 .37532 Mtetra
.80672 .37532 .80941 .37904 .81574 .37702 .81306 .3733 Mtetra
.81306 .3733 .81574 .37702 .82209 .37501 .81942 .37127 Mtetra
.81942 .37127 .82209 .37501 .82845 .37299 .82579 .36924 Mtetra
.82579 .36924 .82845 .37299 .83482 .37096 .83217 .36721 Mtetra
.83217 .36721 .83482 .37096 .84121 .36893 .83857 .36517 Mtetra
.83857 .36517 .84121 .36893 .84761 .36689 .84498 .36313 Mtetra
.84498 .36313 .84761 .36689 .85403 .36486 .85141 .36108 Mtetra
.85141 .36108 .85403 .36486 .86046 .36281 .85785 .35903 Mtetra
.85785 .35903 .86046 .36281 .8669 .36076 .8643 .35697 Mtetra
.8643 .35697 .8669 .36076 .87336 .35871 .87077 .35491 Mtetra
.87077 .35491 .87336 .35871 .87983 .35665 .87725 .35284 Mtetra
.87725 .35284 .87983 .35665 .88632 .35459 .88375 .35077 Mtetra
.88375 .35077 .88632 .35459 .89282 .35252 .89026 .3487 Mtetra
.89026 .3487 .89282 .35252 .89934 .35045 .89679 .34662 Mtetra
.89679 .34662 .89934 .35045 .90587 .34838 .90333 .34453 Mtetra
.90333 .34453 .90587 .34838 .91241 .3463 .90989 .34244 Mtetra
.3214 .52576 .32477 .5289 .3301 .5272 .32674 .52406 Mtetra
.32674 .52406 .3301 .5272 .33544 .5255 .33208 .52235 Mtetra
.33208 .52235 .33544 .5255 .34079 .52379 .33744 .52064 Mtetra
.33744 .52064 .34079 .52379 .34615 .52209 .34281 .51892 Mtetra
.34281 .51892 .34615 .52209 .35152 .52037 .34818 .51721 Mtetra
.34818 .51721 .35152 .52037 .3569 .51866 .35357 .51548 Mtetra
.35357 .51548 .3569 .51866 .36229 .51694 .35897 .51376 Mtetra
.35897 .51376 .36229 .51694 .3677 .51522 .36438 .51203 Mtetra
.36438 .51203 .3677 .51522 .37311 .51349 .3698 .5103 Mtetra
.3698 .5103 .37311 .51349 .37854 .51176 .37524 .50856 Mtetra
.37524 .50856 .37854 .51176 .38397 .51003 .38068 .50682 Mtetra
.38068 .50682 .38397 .51003 .38942 .5083 .38613 .50508 Mtetra
.38613 .50508 .38942 .5083 .39488 .50656 .3916 .50334 Mtetra
.3916 .50334 .39488 .50656 .40035 .50481 .39708 .50159 Mtetra
.39708 .50159 .40035 .50481 .40583 .50307 .40256 .49983 Mtetra
.40256 .49983 .40583 .50307 .41132 .50132 .40806 .49808 Mtetra
.40806 .49808 .41132 .50132 .41683 .49956 .41357 .49632 Mtetra
.41357 .49632 .41683 .49956 .42234 .49781 .4191 .49455 Mtetra
.4191 .49455 .42234 .49781 .42787 .49604 .42463 .49278 Mtetra
.42463 .49278 .42787 .49604 .43341 .49428 .43017 .49101 Mtetra
.43017 .49101 .43341 .49428 .43895 .49251 .43573 .48924 Mtetra
.43573 .48924 .43895 .49251 .44452 .49074 .4413 .48746 Mtetra
.4413 .48746 .44452 .49074 .45009 .48896 .44688 .48568 Mtetra
.44688 .48568 .45009 .48896 .45567 .48719 .45247 .48389 Mtetra
.45247 .48389 .45567 .48719 .46126 .4854 .45807 .4821 Mtetra
.45807 .4821 .46126 .4854 .46687 .48362 .46368 .48031 Mtetra
.46368 .48031 .46687 .48362 .47249 .48183 .46931 .47851 Mtetra
.46931 .47851 .47249 .48183 .47812 .48003 .47494 .47671 Mtetra
.47494 .47671 .47812 .48003 .48376 .47824 .48059 .47491 Mtetra
.48059 .47491 .48376 .47824 .48941 .47643 .48625 .4731 Mtetra
.48625 .4731 .48941 .47643 .49507 .47463 .49192 .47129 Mtetra
.49192 .47129 .49507 .47463 .50075 .47282 .49761 .46947 Mtetra
.49761 .46947 .50075 .47282 .50644 .47101 .5033 .46765 Mtetra
.5033 .46765 .50644 .47101 .51214 .46919 .50901 .46583 Mtetra
.50901 .46583 .51214 .46919 .51785 .46737 .51473 .464 Mtetra
.51473 .464 .51785 .46737 .52357 .46555 .52046 .46217 Mtetra
.52046 .46217 .52357 .46555 .52931 .46372 .5262 .46034 Mtetra
.5262 .46034 .52931 .46372 .53506 .46189 .53196 .4585 Mtetra
.53196 .4585 .53506 .46189 .54082 .46005 .53773 .45665 Mtetra
.53773 .45665 .54082 .46005 .54659 .45821 .54351 .45481 Mtetra
.54351 .45481 .54659 .45821 .55237 .45637 .5493 .45296 Mtetra
.5493 .45296 .55237 .45637 .55817 .45452 .5551 .4511 Mtetra
.5551 .4511 .55817 .45452 .56397 .45267 .56092 .44925 Mtetra
.56092 .44925 .56397 .45267 .56979 .45082 .56675 .44738 Mtetra
.56675 .44738 .56979 .45082 .57563 .44896 .57259 .44552 Mtetra
.57259 .44552 .57563 .44896 .58147 .4471 .57844 .44365 Mtetra
.663 .741 .908 r
.57844 .44365 .58147 .4471 .58733 .44523 .5843 .44178 Mtetra
.5843 .44178 .58733 .44523 .5932 .44337 .59018 .4399 Mtetra
.66 .74 .909 r
.59018 .4399 .5932 .44337 .59908 .44154 .59607 .43808 Mtetra
.664 .742 .908 r
.59607 .43808 .59908 .44154 .60497 .43967 .60197 .43619 Mtetra
.667 .743 .907 r
.60197 .43619 .60497 .43967 .61088 .43773 .60789 .43425 Mtetra
.664 .741 .908 r
.60789 .43425 .61088 .43773 .6168 .43584 .61382 .43235 Mtetra
.61382 .43235 .6168 .43584 .62273 .43395 .61976 .43045 Mtetra
.61976 .43045 .62273 .43395 .62867 .43206 .62571 .42855 Mtetra
.62571 .42855 .62867 .43206 .63463 .43016 .63167 .42664 Mtetra
.63167 .42664 .63463 .43016 .6406 .42826 .63765 .42473 Mtetra
.63765 .42473 .6406 .42826 .64658 .42635 .64364 .42282 Mtetra
.64364 .42282 .64658 .42635 .65258 .42444 .64965 .4209 Mtetra
.64965 .4209 .65258 .42444 .65859 .42252 .65566 .41898 Mtetra
.65566 .41898 .65859 .42252 .66461 .42061 .66169 .41705 Mtetra
.66169 .41705 .66461 .42061 .67064 .41868 .66773 .41512 Mtetra
.66773 .41512 .67064 .41868 .67669 .41676 .67379 .41319 Mtetra
.67379 .41319 .67669 .41676 .68275 .41483 .67986 .41125 Mtetra
.67986 .41125 .68275 .41483 .68882 .41289 .68594 .40931 Mtetra
.68594 .40931 .68882 .41289 .6949 .41095 .69203 .40736 Mtetra
.69203 .40736 .6949 .41095 .701 .40901 .69814 .40541 Mtetra
.69814 .40541 .701 .40901 .70711 .40706 .70426 .40345 Mtetra
.70426 .40345 .70711 .40706 .71324 .40511 .7104 .40149 Mtetra
.7104 .40149 .71324 .40511 .71938 .40315 .71654 .39953 Mtetra
.71654 .39953 .71938 .40315 .72553 .40119 .7227 .39756 Mtetra
.7227 .39756 .72553 .40119 .73169 .39923 .72888 .39559 Mtetra
.72888 .39559 .73169 .39923 .73787 .39726 .73507 .39361 Mtetra
.73507 .39361 .73787 .39726 .74406 .39529 .74127 .39163 Mtetra
.74127 .39163 .74406 .39529 .75027 .39331 .74748 .38965 Mtetra
.74748 .38965 .75027 .39331 .75649 .39133 .75371 .38766 Mtetra
.75371 .38766 .75649 .39133 .76272 .38934 .75995 .38566 Mtetra
.75995 .38566 .76272 .38934 .76896 .38735 .76621 .38367 Mtetra
.76621 .38367 .76896 .38735 .77522 .38536 .77247 .38166 Mtetra
.77247 .38166 .77522 .38536 .78149 .38336 .77876 .37966 Mtetra
.77876 .37966 .78149 .38336 .78778 .38135 .78505 .37764 Mtetra
.78505 .37764 .78778 .38135 .79408 .37935 .79136 .37563 Mtetra
.79136 .37563 .79408 .37935 .8004 .37733 .79769 .37361 Mtetra
.79769 .37361 .8004 .37733 .80672 .37532 .80402 .37158 Mtetra
.80402 .37158 .80672 .37532 .81306 .3733 .81038 .36955 Mtetra
.81038 .36955 .81306 .3733 .81942 .37127 .81674 .36752 Mtetra
.81674 .36752 .81942 .37127 .82579 .36924 .82312 .36548 Mtetra
.82312 .36548 .82579 .36924 .83217 .36721 .82951 .36344 Mtetra
.82951 .36344 .83217 .36721 .83857 .36517 .83592 .36139 Mtetra
.83592 .36139 .83857 .36517 .84498 .36313 .84234 .35934 Mtetra
.84234 .35934 .84498 .36313 .85141 .36108 .84878 .35729 Mtetra
.84878 .35729 .85141 .36108 .85785 .35903 .85523 .35523 Mtetra
.85523 .35523 .85785 .35903 .8643 .35697 .86169 .35316 Mtetra
.86169 .35316 .8643 .35697 .87077 .35491 .86817 .35109 Mtetra
.86817 .35109 .87077 .35491 .87725 .35284 .87467 .34902 Mtetra
.87467 .34902 .87725 .35284 .88375 .35077 .88117 .34694 Mtetra
.88117 .34694 .88375 .35077 .89026 .3487 .8877 .34485 Mtetra
.8877 .34485 .89026 .3487 .89679 .34662 .89423 .34277 Mtetra
.89423 .34277 .89679 .34662 .90333 .34453 .90079 .34067 Mtetra
.90079 .34067 .90333 .34453 .90989 .34244 .90735 .33857 Mtetra
.31802 .52261 .3214 .52576 .32674 .52406 .32336 .5209 Mtetra
.32336 .5209 .32674 .52406 .33208 .52235 .32871 .51919 Mtetra
.32871 .51919 .33208 .52235 .33744 .52064 .33408 .51747 Mtetra
.33408 .51747 .33744 .52064 .34281 .51892 .33945 .51575 Mtetra
.33945 .51575 .34281 .51892 .34818 .51721 .34483 .51403 Mtetra
.34483 .51403 .34818 .51721 .35357 .51548 .35023 .5123 Mtetra
.35023 .5123 .35357 .51548 .35897 .51376 .35564 .51057 Mtetra
.35564 .51057 .35897 .51376 .36438 .51203 .36105 .50883 Mtetra
.36105 .50883 .36438 .51203 .3698 .5103 .36648 .50709 Mtetra
.36648 .50709 .3698 .5103 .37524 .50856 .37192 .50535 Mtetra
.37192 .50535 .37524 .50856 .38068 .50682 .37737 .50361 Mtetra
.37737 .50361 .38068 .50682 .38613 .50508 .38283 .50186 Mtetra
.38283 .50186 .38613 .50508 .3916 .50334 .3883 .5001 Mtetra
.3883 .5001 .3916 .50334 .39708 .50159 .39379 .49835 Mtetra
.39379 .49835 .39708 .50159 .40256 .49983 .39928 .49659 Mtetra
.39928 .49659 .40256 .49983 .40806 .49808 .40479 .49482 Mtetra
.40479 .49482 .40806 .49808 .41357 .49632 .41031 .49306 Mtetra
.41031 .49306 .41357 .49632 .4191 .49455 .41584 .49129 Mtetra
.41584 .49129 .4191 .49455 .42463 .49278 .42138 .48951 Mtetra
.42138 .48951 .42463 .49278 .43017 .49101 .42693 .48773 Mtetra
.42693 .48773 .43017 .49101 .43573 .48924 .43249 .48595 Mtetra
.43249 .48595 .43573 .48924 .4413 .48746 .43807 .48417 Mtetra
.43807 .48417 .4413 .48746 .44688 .48568 .44365 .48238 Mtetra
.44365 .48238 .44688 .48568 .45247 .48389 .44925 .48059 Mtetra
.44925 .48059 .45247 .48389 .45807 .4821 .45486 .47879 Mtetra
.45486 .47879 .45807 .4821 .46368 .48031 .46048 .47699 Mtetra
.46048 .47699 .46368 .48031 .46931 .47851 .46611 .47518 Mtetra
.46611 .47518 .46931 .47851 .47494 .47671 .47176 .47338 Mtetra
.47176 .47338 .47494 .47671 .48059 .47491 .47741 .47157 Mtetra
.47741 .47157 .48059 .47491 .48625 .4731 .48308 .46975 Mtetra
.48308 .46975 .48625 .4731 .49192 .47129 .48876 .46793 Mtetra
.48876 .46793 .49192 .47129 .49761 .46947 .49445 .46611 Mtetra
.49445 .46611 .49761 .46947 .5033 .46765 .50016 .46428 Mtetra
.50016 .46428 .5033 .46765 .50901 .46583 .50587 .46245 Mtetra
.50587 .46245 .50901 .46583 .51473 .464 .5116 .46062 Mtetra
.5116 .46062 .51473 .464 .52046 .46217 .51734 .45878 Mtetra
.51734 .45878 .52046 .46217 .5262 .46034 .52309 .45694 Mtetra
.52309 .45694 .5262 .46034 .53196 .4585 .52885 .45509 Mtetra
.52885 .45509 .53196 .4585 .53773 .45665 .53463 .45324 Mtetra
.53463 .45324 .53773 .45665 .54351 .45481 .54041 .45139 Mtetra
.54041 .45139 .54351 .45481 .5493 .45296 .54621 .44953 Mtetra
.54621 .44953 .5493 .45296 .5551 .4511 .55202 .44767 Mtetra
.55202 .44767 .5551 .4511 .56092 .44925 .55785 .44581 Mtetra
.55785 .44581 .56092 .44925 .56675 .44738 .56368 .44394 Mtetra
.56368 .44394 .56675 .44738 .57259 .44552 .56953 .44206 Mtetra
.56953 .44206 .57259 .44552 .57844 .44365 .57539 .44019 Mtetra
.663 .741 .908 r
.57539 .44019 .57844 .44365 .5843 .44178 .58127 .43831 Mtetra
.58127 .43831 .5843 .44178 .59018 .4399 .58715 .43643 Mtetra
.66 .74 .909 r
.58715 .43643 .59018 .4399 .59607 .43808 .59305 .4346 Mtetra
.664 .742 .908 r
.59305 .4346 .59607 .43808 .60197 .43619 .59896 .43271 Mtetra
.667 .743 .907 r
.59896 .43271 .60197 .43619 .60789 .43425 .60489 .43075 Mtetra
.664 .741 .908 r
.60489 .43075 .60789 .43425 .61382 .43235 .61082 .42884 Mtetra
.61082 .42884 .61382 .43235 .61976 .43045 .61677 .42694 Mtetra
.61677 .42694 .61976 .43045 .62571 .42855 .62273 .42503 Mtetra
.62273 .42503 .62571 .42855 .63167 .42664 .6287 .42311 Mtetra
.6287 .42311 .63167 .42664 .63765 .42473 .63469 .4212 Mtetra
.63469 .4212 .63765 .42473 .64364 .42282 .64069 .41927 Mtetra
.64069 .41927 .64364 .42282 .64965 .4209 .6467 .41735 Mtetra
.6467 .41735 .64965 .4209 .65566 .41898 .65273 .41542 Mtetra
.65273 .41542 .65566 .41898 .66169 .41705 .65877 .41349 Mtetra
.65877 .41349 .66169 .41705 .66773 .41512 .66482 .41155 Mtetra
.66482 .41155 .66773 .41512 .67379 .41319 .67088 .40961 Mtetra
.67088 .40961 .67379 .41319 .67986 .41125 .67696 .40766 Mtetra
.67696 .40766 .67986 .41125 .68594 .40931 .68305 .40571 Mtetra
.68305 .40571 .68594 .40931 .69203 .40736 .68915 .40375 Mtetra
.68915 .40375 .69203 .40736 .69814 .40541 .69527 .4018 Mtetra
.69527 .4018 .69814 .40541 .70426 .40345 .7014 .39983 Mtetra
.7014 .39983 .70426 .40345 .7104 .40149 .70754 .39786 Mtetra
.70754 .39786 .7104 .40149 .71654 .39953 .7137 .39589 Mtetra
.7137 .39589 .71654 .39953 .7227 .39756 .71987 .39392 Mtetra
.71987 .39392 .7227 .39756 .72888 .39559 .72605 .39194 Mtetra
.72605 .39194 .72888 .39559 .73507 .39361 .73225 .38995 Mtetra
.73225 .38995 .73507 .39361 .74127 .39163 .73846 .38796 Mtetra
.73846 .38796 .74127 .39163 .74748 .38965 .74468 .38597 Mtetra
.74468 .38597 .74748 .38965 .75371 .38766 .75092 .38397 Mtetra
.75092 .38397 .75371 .38766 .75995 .38566 .75717 .38197 Mtetra
.75717 .38197 .75995 .38566 .76621 .38367 .76344 .37996 Mtetra
.76344 .37996 .76621 .38367 .77247 .38166 .76971 .37795 Mtetra
.76971 .37795 .77247 .38166 .77876 .37966 .77601 .37594 Mtetra
.77601 .37594 .77876 .37966 .78505 .37764 .78231 .37392 Mtetra
.78231 .37392 .78505 .37764 .79136 .37563 .78863 .3719 Mtetra
.78863 .3719 .79136 .37563 .79769 .37361 .79497 .36987 Mtetra
.79497 .36987 .79769 .37361 .80402 .37158 .80131 .36783 Mtetra
.80131 .36783 .80402 .37158 .81038 .36955 .80767 .3658 Mtetra
.80767 .3658 .81038 .36955 .81674 .36752 .81405 .36376 Mtetra
.81405 .36376 .81674 .36752 .82312 .36548 .82044 .36171 Mtetra
.82044 .36171 .82312 .36548 .82951 .36344 .82684 .35966 Mtetra
.82684 .35966 .82951 .36344 .83592 .36139 .83326 .3576 Mtetra
.83326 .3576 .83592 .36139 .84234 .35934 .83969 .35554 Mtetra
.83969 .35554 .84234 .35934 .84878 .35729 .84614 .35348 Mtetra
.84614 .35348 .84878 .35729 .85523 .35523 .8526 .35141 Mtetra
.8526 .35141 .85523 .35523 .86169 .35316 .85908 .34934 Mtetra
.85908 .34934 .86169 .35316 .86817 .35109 .86556 .34726 Mtetra
.86556 .34726 .86817 .35109 .87467 .34902 .87207 .34517 Mtetra
.87207 .34517 .87467 .34902 .88117 .34694 .87859 .34309 Mtetra
.87859 .34309 .88117 .34694 .8877 .34485 .88512 .34099 Mtetra
.88512 .34099 .8877 .34485 .89423 .34277 .89167 .3389 Mtetra
.89167 .3389 .89423 .34277 .90079 .34067 .89823 .3368 Mtetra
.89823 .3368 .90079 .34067 .90735 .33857 .90481 .33469 Mtetra
.31463 .51945 .31802 .52261 .32336 .5209 .31997 .51773 Mtetra
.31997 .51773 .32336 .5209 .32871 .51919 .32533 .51601 Mtetra
.32533 .51601 .32871 .51919 .33408 .51747 .3307 .51429 Mtetra
.3307 .51429 .33408 .51747 .33945 .51575 .33608 .51256 Mtetra
.33608 .51256 .33945 .51575 .34483 .51403 .34147 .51083 Mtetra
.34147 .51083 .34483 .51403 .35023 .5123 .34687 .5091 Mtetra
.34687 .5091 .35023 .5123 .35564 .51057 .35229 .50736 Mtetra
.35229 .50736 .35564 .51057 .36105 .50883 .35771 .50562 Mtetra
.35771 .50562 .36105 .50883 .36648 .50709 .36315 .50387 Mtetra
.36315 .50387 .36648 .50709 .37192 .50535 .36859 .50213 Mtetra
.36859 .50213 .37192 .50535 .37737 .50361 .37405 .50037 Mtetra
.37405 .50037 .37737 .50361 .38283 .50186 .37952 .49862 Mtetra
.37952 .49862 .38283 .50186 .3883 .5001 .385 .49686 Mtetra
.385 .49686 .3883 .5001 .39379 .49835 .39049 .4951 Mtetra
.39049 .4951 .39379 .49835 .39928 .49659 .39599 .49333 Mtetra
.39599 .49333 .39928 .49659 .40479 .49482 .4015 .49156 Mtetra
.4015 .49156 .40479 .49482 .41031 .49306 .40703 .48978 Mtetra
.40703 .48978 .41031 .49306 .41584 .49129 .41257 .48801 Mtetra
.41257 .48801 .41584 .49129 .42138 .48951 .41811 .48623 Mtetra
.41811 .48623 .42138 .48951 .42693 .48773 .42367 .48444 Mtetra
.42367 .48444 .42693 .48773 .43249 .48595 .42924 .48265 Mtetra
.42924 .48265 .43249 .48595 .43807 .48417 .43482 .48086 Mtetra
.43482 .48086 .43807 .48417 .44365 .48238 .44042 .47907 Mtetra
.44042 .47907 .44365 .48238 .44925 .48059 .44602 .47727 Mtetra
.44602 .47727 .44925 .48059 .45486 .47879 .45164 .47546 Mtetra
.45164 .47546 .45486 .47879 .46048 .47699 .45727 .47366 Mtetra
.45727 .47366 .46048 .47699 .46611 .47518 .46291 .47184 Mtetra
.46291 .47184 .46611 .47518 .47176 .47338 .46856 .47003 Mtetra
.46856 .47003 .47176 .47338 .47741 .47157 .47422 .46821 Mtetra
.47422 .46821 .47741 .47157 .48308 .46975 .4799 .46639 Mtetra
.4799 .46639 .48308 .46975 .48876 .46793 .48559 .46456 Mtetra
.48559 .46456 .48876 .46793 .49445 .46611 .49128 .46273 Mtetra
.49128 .46273 .49445 .46611 .50016 .46428 .49699 .4609 Mtetra
.49699 .4609 .50016 .46428 .50587 .46245 .50272 .45906 Mtetra
.50272 .45906 .50587 .46245 .5116 .46062 .50845 .45722 Mtetra
.50845 .45722 .5116 .46062 .51734 .45878 .5142 .45538 Mtetra
.5142 .45538 .51734 .45878 .52309 .45694 .51996 .45353 Mtetra
.51996 .45353 .52309 .45694 .52885 .45509 .52573 .45168 Mtetra
.52573 .45168 .52885 .45509 .53463 .45324 .53151 .44982 Mtetra
.53151 .44982 .53463 .45324 .54041 .45139 .53731 .44796 Mtetra
.53731 .44796 .54041 .45139 .54621 .44953 .54312 .44609 Mtetra
.54312 .44609 .54621 .44953 .55202 .44767 .54893 .44422 Mtetra
.54893 .44422 .55202 .44767 .55785 .44581 .55477 .44235 Mtetra
.55477 .44235 .55785 .44581 .56368 .44394 .56061 .44048 Mtetra
.56061 .44048 .56368 .44394 .56953 .44206 .56647 .4386 Mtetra
.56647 .4386 .56953 .44206 .57539 .44019 .57234 .43671 Mtetra
.663 .741 .908 r
.57234 .43671 .57539 .44019 .58127 .43831 .57822 .43483 Mtetra
.57822 .43483 .58127 .43831 .58715 .43643 .58411 .43294 Mtetra
.659 .74 .91 r
.58411 .43294 .58715 .43643 .59305 .4346 .59002 .43111 Mtetra
.664 .742 .908 r
.59002 .43111 .59305 .4346 .59896 .43271 .59594 .42921 Mtetra
.668 .743 .907 r
.59594 .42921 .59896 .43271 .60489 .43075 .60187 .42724 Mtetra
.664 .741 .908 r
.60187 .42724 .60489 .43075 .61082 .42884 .60781 .42532 Mtetra
.60781 .42532 .61082 .42884 .61677 .42694 .61377 .42341 Mtetra
.61377 .42341 .61677 .42694 .62273 .42503 .61974 .42149 Mtetra
.61974 .42149 .62273 .42503 .6287 .42311 .62572 .41957 Mtetra
.62572 .41957 .6287 .42311 .63469 .4212 .63172 .41765 Mtetra
.63172 .41765 .63469 .4212 .64069 .41927 .63773 .41572 Mtetra
.63773 .41572 .64069 .41927 .6467 .41735 .64375 .41378 Mtetra
.64375 .41378 .6467 .41735 .65273 .41542 .64978 .41185 Mtetra
.64978 .41185 .65273 .41542 .65877 .41349 .65583 .4099 Mtetra
.65583 .4099 .65877 .41349 .66482 .41155 .66189 .40796 Mtetra
.66189 .40796 .66482 .41155 .67088 .40961 .66796 .40601 Mtetra
.66796 .40601 .67088 .40961 .67696 .40766 .67405 .40406 Mtetra
.67405 .40406 .67696 .40766 .68305 .40571 .68015 .4021 Mtetra
.68015 .4021 .68305 .40571 .68915 .40375 .68626 .40013 Mtetra
.68626 .40013 .68915 .40375 .69527 .4018 .69239 .39817 Mtetra
.69239 .39817 .69527 .4018 .7014 .39983 .69853 .3962 Mtetra
.69853 .3962 .7014 .39983 .70754 .39786 .70468 .39422 Mtetra
.70468 .39422 .70754 .39786 .7137 .39589 .71084 .39224 Mtetra
.71084 .39224 .7137 .39589 .71987 .39392 .71702 .39026 Mtetra
.71702 .39026 .71987 .39392 .72605 .39194 .72322 .38827 Mtetra
.72322 .38827 .72605 .39194 .73225 .38995 .72942 .38628 Mtetra
.72942 .38628 .73225 .38995 .73846 .38796 .73564 .38428 Mtetra
.73564 .38428 .73846 .38796 .74468 .38597 .74187 .38228 Mtetra
.74187 .38228 .74468 .38597 .75092 .38397 .74812 .38027 Mtetra
.74812 .38027 .75092 .38397 .75717 .38197 .75438 .37826 Mtetra
.75438 .37826 .75717 .38197 .76344 .37996 .76066 .37625 Mtetra
.76066 .37625 .76344 .37996 .76971 .37795 .76694 .37423 Mtetra
.76694 .37423 .76971 .37795 .77601 .37594 .77325 .37221 Mtetra
.77325 .37221 .77601 .37594 .78231 .37392 .77956 .37018 Mtetra
.77956 .37018 .78231 .37392 .78863 .3719 .78589 .36815 Mtetra
.78589 .36815 .78863 .3719 .79497 .36987 .79223 .36611 Mtetra
.79223 .36611 .79497 .36987 .80131 .36783 .79859 .36407 Mtetra
.79859 .36407 .80131 .36783 .80767 .3658 .80496 .36202 Mtetra
.80496 .36202 .80767 .3658 .81405 .36376 .81135 .35997 Mtetra
.81135 .35997 .81405 .36376 .82044 .36171 .81775 .35792 Mtetra
.81775 .35792 .82044 .36171 .82684 .35966 .82416 .35586 Mtetra
.82416 .35586 .82684 .35966 .83326 .3576 .83059 .3538 Mtetra
.83059 .3538 .83326 .3576 .83969 .35554 .83703 .35173 Mtetra
.83703 .35173 .83969 .35554 .84614 .35348 .84349 .34965 Mtetra
.84349 .34965 .84614 .35348 .8526 .35141 .84996 .34758 Mtetra
.84996 .34758 .8526 .35141 .85908 .34934 .85645 .3455 Mtetra
.85645 .3455 .85908 .34934 .86556 .34726 .86295 .34341 Mtetra
.86295 .34341 .86556 .34726 .87207 .34517 .86946 .34132 Mtetra
.86946 .34132 .87207 .34517 .87859 .34309 .87599 .33922 Mtetra
.87599 .33922 .87859 .34309 .88512 .34099 .88253 .33712 Mtetra
.88253 .33712 .88512 .34099 .89167 .3389 .88909 .33501 Mtetra
.88909 .33501 .89167 .3389 .89823 .3368 .89566 .3329 Mtetra
.89566 .3329 .89823 .3368 .90481 .33469 .90225 .33079 Mtetra
.31122 .51628 .31463 .51945 .31997 .51773 .31657 .51456 Mtetra
.31657 .51456 .31997 .51773 .32533 .51601 .32194 .51283 Mtetra
.32194 .51283 .32533 .51601 .3307 .51429 .32731 .5111 Mtetra
.32731 .5111 .3307 .51429 .33608 .51256 .3327 .50937 Mtetra
.3327 .50937 .33608 .51256 .34147 .51083 .3381 .50763 Mtetra
.3381 .50763 .34147 .51083 .34687 .5091 .34351 .50589 Mtetra
.34351 .50589 .34687 .5091 .35229 .50736 .34893 .50414 Mtetra
.34893 .50414 .35229 .50736 .35771 .50562 .35436 .50239 Mtetra
.35436 .50239 .35771 .50562 .36315 .50387 .3598 .50064 Mtetra
.3598 .50064 .36315 .50387 .36859 .50213 .36525 .49889 Mtetra
.36525 .49889 .36859 .50213 .37405 .50037 .37072 .49713 Mtetra
.37072 .49713 .37405 .50037 .37952 .49862 .37619 .49537 Mtetra
.37619 .49537 .37952 .49862 .385 .49686 .38168 .4936 Mtetra
.38168 .4936 .385 .49686 .39049 .4951 .38718 .49183 Mtetra
.38718 .49183 .39049 .4951 .39599 .49333 .39269 .49006 Mtetra
.39269 .49006 .39599 .49333 .4015 .49156 .39821 .48828 Mtetra
.39821 .48828 .4015 .49156 .40703 .48978 .40374 .4865 Mtetra
.40374 .4865 .40703 .48978 .41257 .48801 .40928 .48472 Mtetra
.40928 .48472 .41257 .48801 .41811 .48623 .41484 .48293 Mtetra
.41484 .48293 .41811 .48623 .42367 .48444 .4204 .48114 Mtetra
.4204 .48114 .42367 .48444 .42924 .48265 .42598 .47934 Mtetra
.42598 .47934 .42924 .48265 .43482 .48086 .43157 .47754 Mtetra
.43157 .47754 .43482 .48086 .44042 .47907 .43717 .47574 Mtetra
.43717 .47574 .44042 .47907 .44602 .47727 .44278 .47393 Mtetra
.44278 .47393 .44602 .47727 .45164 .47546 .44841 .47212 Mtetra
.44841 .47212 .45164 .47546 .45727 .47366 .45404 .47031 Mtetra
.45404 .47031 .45727 .47366 .46291 .47184 .45969 .46849 Mtetra
.45969 .46849 .46291 .47184 .46856 .47003 .46535 .46667 Mtetra
.46535 .46667 .46856 .47003 .47422 .46821 .47102 .46484 Mtetra
.47102 .46484 .47422 .46821 .4799 .46639 .4767 .46302 Mtetra
.4767 .46302 .4799 .46639 .48559 .46456 .4824 .46118 Mtetra
.4824 .46118 .48559 .46456 .49128 .46273 .4881 .45935 Mtetra
.4881 .45935 .49128 .46273 .49699 .4609 .49382 .45751 Mtetra
.49382 .45751 .49699 .4609 .50272 .45906 .49955 .45566 Mtetra
.49955 .45566 .50272 .45906 .50845 .45722 .5053 .45381 Mtetra
.5053 .45381 .50845 .45722 .5142 .45538 .51105 .45196 Mtetra
.51105 .45196 .5142 .45538 .51996 .45353 .51682 .4501 Mtetra
.51682 .4501 .51996 .45353 .52573 .45168 .5226 .44824 Mtetra
.5226 .44824 .52573 .45168 .53151 .44982 .52839 .44638 Mtetra
.52839 .44638 .53151 .44982 .53731 .44796 .53419 .44451 Mtetra
.53419 .44451 .53731 .44796 .54312 .44609 .54001 .44264 Mtetra
.54001 .44264 .54312 .44609 .54893 .44422 .54583 .44076 Mtetra
.54583 .44076 .54893 .44422 .55477 .44235 .55167 .43889 Mtetra
.55167 .43889 .55477 .44235 .56061 .44048 .55753 .437 Mtetra
.55753 .437 .56061 .44048 .56647 .4386 .56339 .43511 Mtetra
.56339 .43511 .56647 .4386 .57234 .43671 .56927 .43322 Mtetra
.663 .741 .908 r
.56927 .43322 .57234 .43671 .57822 .43483 .57516 .43133 Mtetra
.57516 .43133 .57822 .43483 .58411 .43294 .58106 .42944 Mtetra
.659 .74 .91 r
.58106 .42944 .58411 .43294 .59002 .43111 .58698 .42761 Mtetra
.664 .742 .908 r
.58698 .42761 .59002 .43111 .59594 .42921 .59291 .4257 Mtetra
.668 .743 .906 r
.59291 .4257 .59594 .42921 .60187 .42724 .59884 .42371 Mtetra
.664 .741 .908 r
.59884 .42371 .60187 .42724 .60781 .42532 .6048 .42179 Mtetra
.6048 .42179 .60781 .42532 .61377 .42341 .61076 .41987 Mtetra
.61076 .41987 .61377 .42341 .61974 .42149 .61674 .41794 Mtetra
.61674 .41794 .61974 .42149 .62572 .41957 .62273 .41601 Mtetra
.62273 .41601 .62572 .41957 .63172 .41765 .62874 .41408 Mtetra
.62874 .41408 .63172 .41765 .63773 .41572 .63475 .41214 Mtetra
.63475 .41214 .63773 .41572 .64375 .41378 .64078 .4102 Mtetra
.64078 .4102 .64375 .41378 .64978 .41185 .64683 .40826 Mtetra
.64683 .40826 .64978 .41185 .65583 .4099 .65288 .40631 Mtetra
.65288 .40631 .65583 .4099 .66189 .40796 .65895 .40436 Mtetra
.65895 .40436 .66189 .40796 .66796 .40601 .66503 .4024 Mtetra
.66503 .4024 .66796 .40601 .67405 .40406 .67113 .40044 Mtetra
.67113 .40044 .67405 .40406 .68015 .4021 .67724 .39847 Mtetra
.67724 .39847 .68015 .4021 .68626 .40013 .68336 .3965 Mtetra
.68336 .3965 .68626 .40013 .69239 .39817 .68949 .39453 Mtetra
.68949 .39453 .69239 .39817 .69853 .3962 .69564 .39255 Mtetra
.69564 .39255 .69853 .3962 .70468 .39422 .7018 .39056 Mtetra
.7018 .39056 .70468 .39422 .71084 .39224 .70798 .38858 Mtetra
.70798 .38858 .71084 .39224 .71702 .39026 .71417 .38658 Mtetra
.71417 .38658 .71702 .39026 .72322 .38827 .72037 .38459 Mtetra
.72037 .38459 .72322 .38827 .72942 .38628 .72658 .38259 Mtetra
.72658 .38259 .72942 .38628 .73564 .38428 .73281 .38058 Mtetra
.73281 .38058 .73564 .38428 .74187 .38228 .73905 .37857 Mtetra
.73905 .37857 .74187 .38228 .74812 .38027 .74531 .37656 Mtetra
.74531 .37656 .74812 .38027 .75438 .37826 .75158 .37454 Mtetra
.75158 .37454 .75438 .37826 .76066 .37625 .75786 .37252 Mtetra
.75786 .37252 .76066 .37625 .76694 .37423 .76416 .37049 Mtetra
.76416 .37049 .76694 .37423 .77325 .37221 .77047 .36846 Mtetra
.77047 .36846 .77325 .37221 .77956 .37018 .7768 .36642 Mtetra
.7768 .36642 .77956 .37018 .78589 .36815 .78314 .36438 Mtetra
.78314 .36438 .78589 .36815 .79223 .36611 .78949 .36234 Mtetra
.78949 .36234 .79223 .36611 .79859 .36407 .79586 .36029 Mtetra
.79586 .36029 .79859 .36407 .80496 .36202 .80224 .35824 Mtetra
.80224 .35824 .80496 .36202 .81135 .35997 .80864 .35618 Mtetra
.80864 .35618 .81135 .35997 .81775 .35792 .81505 .35411 Mtetra
.81505 .35411 .81775 .35792 .82416 .35586 .82147 .35205 Mtetra
.82147 .35205 .82416 .35586 .83059 .3538 .82791 .34997 Mtetra
.82791 .34997 .83059 .3538 .83703 .35173 .83436 .3479 Mtetra
.83436 .3479 .83703 .35173 .84349 .34965 .84083 .34582 Mtetra
.84083 .34582 .84349 .34965 .84996 .34758 .84731 .34373 Mtetra
.84731 .34373 .84996 .34758 .85645 .3455 .8538 .34164 Mtetra
.8538 .34164 .85645 .3455 .86295 .34341 .86031 .33954 Mtetra
.86031 .33954 .86295 .34341 .86946 .34132 .86684 .33744 Mtetra
.86684 .33744 .86946 .34132 .87599 .33922 .87338 .33534 Mtetra
.87338 .33534 .87599 .33922 .88253 .33712 .87993 .33323 Mtetra
.87993 .33323 .88253 .33712 .88909 .33501 .8865 .33111 Mtetra
.8865 .33111 .88909 .33501 .89566 .3329 .89309 .329 Mtetra
.89309 .329 .89566 .3329 .90225 .33079 .89968 .32687 Mtetra
.3078 .5131 .31122 .51628 .31657 .51456 .31316 .51137 Mtetra
.31316 .51137 .31657 .51456 .32194 .51283 .31853 .50963 Mtetra
.31853 .50963 .32194 .51283 .32731 .5111 .32391 .5079 Mtetra
.32391 .5079 .32731 .5111 .3327 .50937 .32931 .50615 Mtetra
.32931 .50615 .3327 .50937 .3381 .50763 .33471 .50441 Mtetra
.33471 .50441 .3381 .50763 .34351 .50589 .34013 .50266 Mtetra
.34013 .50266 .34351 .50589 .34893 .50414 .34555 .50091 Mtetra
.34555 .50091 .34893 .50414 .35436 .50239 .35099 .49916 Mtetra
.35099 .49916 .35436 .50239 .3598 .50064 .35644 .4974 Mtetra
.35644 .4974 .3598 .50064 .36525 .49889 .3619 .49564 Mtetra
.3619 .49564 .36525 .49889 .37072 .49713 .36737 .49387 Mtetra
.36737 .49387 .37072 .49713 .37619 .49537 .37285 .4921 Mtetra
.37285 .4921 .37619 .49537 .38168 .4936 .37835 .49033 Mtetra
.37835 .49033 .38168 .4936 .38718 .49183 .38385 .48855 Mtetra
.38385 .48855 .38718 .49183 .39269 .49006 .38937 .48677 Mtetra
.38937 .48677 .39269 .49006 .39821 .48828 .3949 .48499 Mtetra
.3949 .48499 .39821 .48828 .40374 .4865 .40043 .4832 Mtetra
.40043 .4832 .40374 .4865 .40928 .48472 .40599 .48141 Mtetra
.40599 .48141 .40928 .48472 .41484 .48293 .41155 .47962 Mtetra
.41155 .47962 .41484 .48293 .4204 .48114 .41712 .47782 Mtetra
.41712 .47782 .4204 .48114 .42598 .47934 .42271 .47602 Mtetra
.42271 .47602 .42598 .47934 .43157 .47754 .4283 .47421 Mtetra
.4283 .47421 .43157 .47754 .43717 .47574 .43391 .4724 Mtetra
.43391 .4724 .43717 .47574 .44278 .47393 .43953 .47059 Mtetra
.43953 .47059 .44278 .47393 .44841 .47212 .44516 .46877 Mtetra
.44516 .46877 .44841 .47212 .45404 .47031 .4508 .46695 Mtetra
.4508 .46695 .45404 .47031 .45969 .46849 .45646 .46513 Mtetra
.45646 .46513 .45969 .46849 .46535 .46667 .46213 .4633 Mtetra
.46213 .4633 .46535 .46667 .47102 .46484 .4678 .46147 Mtetra
.4678 .46147 .47102 .46484 .4767 .46302 .47349 .45963 Mtetra
.47349 .45963 .4767 .46302 .4824 .46118 .4792 .45779 Mtetra
.4792 .45779 .4824 .46118 .4881 .45935 .48491 .45594 Mtetra
.48491 .45594 .4881 .45935 .49382 .45751 .49064 .4541 Mtetra
.49064 .4541 .49382 .45751 .49955 .45566 .49638 .45225 Mtetra
.49638 .45225 .49955 .45566 .5053 .45381 .50213 .45039 Mtetra
.50213 .45039 .5053 .45381 .51105 .45196 .50789 .44853 Mtetra
.50789 .44853 .51105 .45196 .51682 .4501 .51366 .44667 Mtetra
.51366 .44667 .51682 .4501 .5226 .44824 .51945 .4448 Mtetra
.51945 .4448 .5226 .44824 .52839 .44638 .52525 .44293 Mtetra
.52525 .44293 .52839 .44638 .53419 .44451 .53106 .44105 Mtetra
.53106 .44105 .53419 .44451 .54001 .44264 .53688 .43917 Mtetra
.53688 .43917 .54001 .44264 .54583 .44076 .54272 .43729 Mtetra
.54272 .43729 .54583 .44076 .55167 .43889 .54857 .4354 Mtetra
.54857 .4354 .55167 .43889 .55753 .437 .55443 .43351 Mtetra
.55443 .43351 .55753 .437 .56339 .43511 .5603 .43162 Mtetra
.663 .741 .908 r
.5603 .43162 .56339 .43511 .56927 .43322 .56619 .42972 Mtetra
.56619 .42972 .56927 .43322 .57516 .43133 .57209 .42782 Mtetra
.57209 .42782 .57516 .43133 .58106 .42944 .578 .42592 Mtetra
.658 .74 .91 r
.578 .42592 .58106 .42944 .58698 .42761 .58392 .42409 Mtetra
.664 .742 .908 r
.58392 .42409 .58698 .42761 .59291 .4257 .58986 .42217 Mtetra
.669 .744 .906 r
.58986 .42217 .59291 .4257 .59884 .42371 .59581 .42017 Mtetra
.664 .741 .908 r
.59581 .42017 .59884 .42371 .6048 .42179 .60177 .41824 Mtetra
.60177 .41824 .6048 .42179 .61076 .41987 .60774 .41631 Mtetra
.60774 .41631 .61076 .41987 .61674 .41794 .61373 .41438 Mtetra
.61373 .41438 .61674 .41794 .62273 .41601 .61973 .41244 Mtetra
.61973 .41244 .62273 .41601 .62874 .41408 .62574 .4105 Mtetra
.62574 .4105 .62874 .41408 .63475 .41214 .63177 .40856 Mtetra
.63177 .40856 .63475 .41214 .64078 .4102 .6378 .40661 Mtetra
.6378 .40661 .64078 .4102 .64683 .40826 .64386 .40466 Mtetra
.64386 .40466 .64683 .40826 .65288 .40631 .64992 .4027 Mtetra
.64992 .4027 .65288 .40631 .65895 .40436 .656 .40074 Mtetra
.656 .40074 .65895 .40436 .66503 .4024 .66209 .39877 Mtetra
.66209 .39877 .66503 .4024 .67113 .40044 .66819 .3968 Mtetra
.66819 .3968 .67113 .40044 .67724 .39847 .67431 .39483 Mtetra
.67431 .39483 .67724 .39847 .68336 .3965 .68044 .39285 Mtetra
.68044 .39285 .68336 .3965 .68949 .39453 .68659 .39087 Mtetra
.68659 .39087 .68949 .39453 .69564 .39255 .69274 .38888 Mtetra
.69274 .38888 .69564 .39255 .7018 .39056 .69891 .38689 Mtetra
.69891 .38689 .7018 .39056 .70798 .38858 .7051 .3849 Mtetra
.7051 .3849 .70798 .38858 .71417 .38658 .7113 .3829 Mtetra
.7113 .3829 .71417 .38658 .72037 .38459 .71751 .38089 Mtetra
.71751 .38089 .72037 .38459 .72658 .38259 .72373 .37888 Mtetra
.72373 .37888 .72658 .38259 .73281 .38058 .72997 .37687 Mtetra
.72997 .37687 .73281 .38058 .73905 .37857 .73622 .37485 Mtetra
.73622 .37485 .73905 .37857 .74531 .37656 .74249 .37283 Mtetra
.74249 .37283 .74531 .37656 .75158 .37454 .74877 .3708 Mtetra
.74877 .3708 .75158 .37454 .75786 .37252 .75506 .36877 Mtetra
.75506 .36877 .75786 .37252 .76416 .37049 .76137 .36674 Mtetra
.76137 .36674 .76416 .37049 .77047 .36846 .76769 .3647 Mtetra
.76769 .3647 .77047 .36846 .7768 .36642 .77403 .36265 Mtetra
.77403 .36265 .7768 .36642 .78314 .36438 .78038 .36061 Mtetra
.78038 .36061 .78314 .36438 .78949 .36234 .78674 .35855 Mtetra
.78674 .35855 .78949 .36234 .79586 .36029 .79312 .35649 Mtetra
.79312 .35649 .79586 .36029 .80224 .35824 .79951 .35443 Mtetra
.79951 .35443 .80224 .35824 .80864 .35618 .80591 .35236 Mtetra
.80591 .35236 .80864 .35618 .81505 .35411 .81233 .35029 Mtetra
.81233 .35029 .81505 .35411 .82147 .35205 .81877 .34822 Mtetra
.81877 .34822 .82147 .35205 .82791 .34997 .82522 .34614 Mtetra
.82522 .34614 .82791 .34997 .83436 .3479 .83168 .34405 Mtetra
.83168 .34405 .83436 .3479 .84083 .34582 .83816 .34196 Mtetra
.83816 .34196 .84083 .34582 .84731 .34373 .84465 .33987 Mtetra
.84465 .33987 .84731 .34373 .8538 .34164 .85115 .33777 Mtetra
.85115 .33777 .8538 .34164 .86031 .33954 .85767 .33566 Mtetra
.85767 .33566 .86031 .33954 .86684 .33744 .86421 .33355 Mtetra
.86421 .33355 .86684 .33744 .87338 .33534 .87076 .33144 Mtetra
.87076 .33144 .87338 .33534 .87993 .33323 .87732 .32932 Mtetra
.87732 .32932 .87993 .33323 .8865 .33111 .8839 .3272 Mtetra
.8839 .3272 .8865 .33111 .89309 .329 .8905 .32507 Mtetra
.8905 .32507 .89309 .329 .89968 .32687 .89711 .32294 Mtetra
.30437 .5099 .3078 .5131 .31316 .51137 .30973 .50816 Mtetra
.30973 .50816 .31316 .51137 .31853 .50963 .31511 .50642 Mtetra
.31511 .50642 .31853 .50963 .32391 .5079 .3205 .50468 Mtetra
.3205 .50468 .32391 .5079 .32931 .50615 .3259 .50293 Mtetra
.3259 .50293 .32931 .50615 .33471 .50441 .33131 .50118 Mtetra
.33131 .50118 .33471 .50441 .34013 .50266 .33673 .49943 Mtetra
.33673 .49943 .34013 .50266 .34555 .50091 .34217 .49767 Mtetra
.34217 .49767 .34555 .50091 .35099 .49916 .34761 .49591 Mtetra
.34761 .49591 .35099 .49916 .35644 .4974 .35307 .49414 Mtetra
.35307 .49414 .35644 .4974 .3619 .49564 .35853 .49238 Mtetra
.35853 .49238 .3619 .49564 .36737 .49387 .36401 .4906 Mtetra
.36401 .4906 .36737 .49387 .37285 .4921 .3695 .48883 Mtetra
.3695 .48883 .37285 .4921 .37835 .49033 .375 .48705 Mtetra
.375 .48705 .37835 .49033 .38385 .48855 .38051 .48527 Mtetra
.38051 .48527 .38385 .48855 .38937 .48677 .38604 .48348 Mtetra
.38604 .48348 .38937 .48677 .3949 .48499 .39157 .48169 Mtetra
.39157 .48169 .3949 .48499 .40043 .4832 .39712 .47989 Mtetra
.39712 .47989 .40043 .4832 .40599 .48141 .40268 .4781 Mtetra
.40268 .4781 .40599 .48141 .41155 .47962 .40825 .4763 Mtetra
.40825 .4763 .41155 .47962 .41712 .47782 .41383 .47449 Mtetra
.41383 .47449 .41712 .47782 .42271 .47602 .41942 .47268 Mtetra
.41942 .47268 .42271 .47602 .4283 .47421 .42502 .47087 Mtetra
.42502 .47087 .4283 .47421 .43391 .4724 .43064 .46905 Mtetra
.43064 .46905 .43391 .4724 .43953 .47059 .43626 .46723 Mtetra
.43626 .46723 .43953 .47059 .44516 .46877 .4419 .46541 Mtetra
.4419 .46541 .44516 .46877 .4508 .46695 .44755 .46358 Mtetra
.44755 .46358 .4508 .46695 .45646 .46513 .45322 .46175 Mtetra
.45322 .46175 .45646 .46513 .46213 .4633 .45889 .45991 Mtetra
.45889 .45991 .46213 .4633 .4678 .46147 .46458 .45807 Mtetra
.46458 .45807 .4678 .46147 .47349 .45963 .47027 .45623 Mtetra
.47027 .45623 .47349 .45963 .4792 .45779 .47598 .45438 Mtetra
.47598 .45438 .4792 .45779 .48491 .45594 .48171 .45253 Mtetra
.48171 .45253 .48491 .45594 .49064 .4541 .48744 .45068 Mtetra
.48744 .45068 .49064 .4541 .49638 .45225 .49319 .44882 Mtetra
.49319 .44882 .49638 .45225 .50213 .45039 .49895 .44695 Mtetra
.49895 .44695 .50213 .45039 .50789 .44853 .50472 .44509 Mtetra
.50472 .44509 .50789 .44853 .51366 .44667 .5105 .44322 Mtetra
.5105 .44322 .51366 .44667 .51945 .4448 .51629 .44134 Mtetra
.51629 .44134 .51945 .4448 .52525 .44293 .5221 .43946 Mtetra
.5221 .43946 .52525 .44293 .53106 .44105 .52792 .43758 Mtetra
.52792 .43758 .53106 .44105 .53688 .43917 .53375 .4357 Mtetra
.53375 .4357 .53688 .43917 .54272 .43729 .53959 .4338 Mtetra
.53959 .4338 .54272 .43729 .54857 .4354 .54545 .43191 Mtetra
.54545 .43191 .54857 .4354 .55443 .43351 .55132 .43001 Mtetra
.55132 .43001 .55443 .43351 .5603 .43162 .5572 .42811 Mtetra
.663 .741 .908 r
.5572 .42811 .5603 .43162 .56619 .42972 .5631 .4262 Mtetra
.5631 .4262 .56619 .42972 .57209 .42782 .569 .4243 Mtetra
.569 .4243 .57209 .42782 .578 .42592 .57492 .42239 Mtetra
.658 .739 .91 r
.57492 .42239 .578 .42592 .58392 .42409 .58085 .42056 Mtetra
.664 .742 .908 r
.58085 .42056 .58392 .42409 .58986 .42217 .5868 .41864 Mtetra
.669 .744 .906 r
.5868 .41864 .58986 .42217 .59581 .42017 .59275 .41662 Mtetra
.664 .742 .908 r
.59275 .41662 .59581 .42017 .60177 .41824 .59872 .41468 Mtetra
.664 .741 .908 r
.59872 .41468 .60177 .41824 .60774 .41631 .60471 .41274 Mtetra
.60471 .41274 .60774 .41631 .61373 .41438 .6107 .4108 Mtetra
.6107 .4108 .61373 .41438 .61973 .41244 .61671 .40886 Mtetra
.61671 .40886 .61973 .41244 .62574 .4105 .62273 .40691 Mtetra
.62273 .40691 .62574 .4105 .63177 .40856 .62877 .40496 Mtetra
.62877 .40496 .63177 .40856 .6378 .40661 .63481 .403 Mtetra
.63481 .403 .6378 .40661 .64386 .40466 .64088 .40104 Mtetra
.64088 .40104 .64386 .40466 .64992 .4027 .64695 .39908 Mtetra
.64695 .39908 .64992 .4027 .656 .40074 .65304 .39711 Mtetra
.65304 .39711 .656 .40074 .66209 .39877 .65914 .39513 Mtetra
.65914 .39513 .66209 .39877 .66819 .3968 .66525 .39316 Mtetra
.66525 .39316 .66819 .3968 .67431 .39483 .67138 .39117 Mtetra
.67138 .39117 .67431 .39483 .68044 .39285 .67752 .38919 Mtetra
.67752 .38919 .68044 .39285 .68659 .39087 .68367 .3872 Mtetra
.68367 .3872 .68659 .39087 .69274 .38888 .68983 .3852 Mtetra
.68983 .3852 .69274 .38888 .69891 .38689 .69601 .3832 Mtetra
.69601 .3832 .69891 .38689 .7051 .3849 .70221 .3812 Mtetra
.70221 .3812 .7051 .3849 .7113 .3829 .70842 .37919 Mtetra
.70842 .37919 .7113 .3829 .71751 .38089 .71464 .37718 Mtetra
.71464 .37718 .71751 .38089 .72373 .37888 .72087 .37516 Mtetra
.72087 .37516 .72373 .37888 .72997 .37687 .72712 .37314 Mtetra
.72712 .37314 .72997 .37687 .73622 .37485 .73338 .37112 Mtetra
.73338 .37112 .73622 .37485 .74249 .37283 .73966 .36909 Mtetra
.73966 .36909 .74249 .37283 .74877 .3708 .74595 .36705 Mtetra
.74595 .36705 .74877 .3708 .75506 .36877 .75225 .36501 Mtetra
.75225 .36501 .75506 .36877 .76137 .36674 .75857 .36297 Mtetra
.75857 .36297 .76137 .36674 .76769 .3647 .7649 .36092 Mtetra
.7649 .36092 .76769 .3647 .77403 .36265 .77124 .35887 Mtetra
.77124 .35887 .77403 .36265 .78038 .36061 .7776 .35681 Mtetra
.7776 .35681 .78038 .36061 .78674 .35855 .78397 .35475 Mtetra
.78397 .35475 .78674 .35855 .79312 .35649 .79036 .35268 Mtetra
.79036 .35268 .79312 .35649 .79951 .35443 .79676 .35061 Mtetra
.79676 .35061 .79951 .35443 .80591 .35236 .80318 .34854 Mtetra
.80318 .34854 .80591 .35236 .81233 .35029 .80961 .34646 Mtetra
.80961 .34646 .81233 .35029 .81877 .34822 .81605 .34437 Mtetra
.81605 .34437 .81877 .34822 .82522 .34614 .82251 .34228 Mtetra
.82251 .34228 .82522 .34614 .83168 .34405 .82898 .34019 Mtetra
.82898 .34019 .83168 .34405 .83816 .34196 .83547 .33809 Mtetra
.83547 .33809 .83816 .34196 .84465 .33987 .84197 .33599 Mtetra
.84197 .33599 .84465 .33987 .85115 .33777 .84849 .33388 Mtetra
.84849 .33388 .85115 .33777 .85767 .33566 .85502 .33177 Mtetra
.85502 .33177 .85767 .33566 .86421 .33355 .86157 .32965 Mtetra
.86157 .32965 .86421 .33355 .87076 .33144 .86813 .32753 Mtetra
.86813 .32753 .87076 .33144 .87732 .32932 .8747 .3254 Mtetra
.8747 .3254 .87732 .32932 .8839 .3272 .88129 .32327 Mtetra
.88129 .32327 .8839 .3272 .8905 .32507 .8879 .32113 Mtetra
.8879 .32113 .8905 .32507 .89711 .32294 .89452 .31899 Mtetra
.30092 .50669 .30437 .5099 .30973 .50816 .3063 .50495 Mtetra
.3063 .50495 .30973 .50816 .31511 .50642 .31168 .5032 Mtetra
.31168 .5032 .31511 .50642 .3205 .50468 .31708 .50145 Mtetra
.31708 .50145 .3205 .50468 .3259 .50293 .32248 .4997 Mtetra
.32248 .4997 .3259 .50293 .33131 .50118 .3279 .49794 Mtetra
.3279 .49794 .33131 .50118 .33673 .49943 .33333 .49618 Mtetra
.33333 .49618 .33673 .49943 .34217 .49767 .33877 .49442 Mtetra
.33877 .49442 .34217 .49767 .34761 .49591 .34422 .49265 Mtetra
.34422 .49265 .34761 .49591 .35307 .49414 .34968 .49088 Mtetra
.34968 .49088 .35307 .49414 .35853 .49238 .35516 .4891 Mtetra
.35516 .4891 .35853 .49238 .36401 .4906 .36064 .48732 Mtetra
.36064 .48732 .36401 .4906 .3695 .48883 .36614 .48554 Mtetra
.36614 .48554 .3695 .48883 .375 .48705 .37165 .48375 Mtetra
.37165 .48375 .375 .48705 .38051 .48527 .37716 .48196 Mtetra
.37716 .48196 .38051 .48527 .38604 .48348 .38269 .48017 Mtetra
.38269 .48017 .38604 .48348 .39157 .48169 .38824 .47837 Mtetra
.38824 .47837 .39157 .48169 .39712 .47989 .39379 .47657 Mtetra
.39379 .47657 .39712 .47989 .40268 .4781 .39935 .47477 Mtetra
.39935 .47477 .40268 .4781 .40825 .4763 .40493 .47296 Mtetra
.40493 .47296 .40825 .4763 .41383 .47449 .41052 .47115 Mtetra
.41052 .47115 .41383 .47449 .41942 .47268 .41612 .46933 Mtetra
.41612 .46933 .41942 .47268 .42502 .47087 .42173 .46751 Mtetra
.42173 .46751 .42502 .47087 .43064 .46905 .42735 .46569 Mtetra
.42735 .46569 .43064 .46905 .43626 .46723 .43299 .46386 Mtetra
.43299 .46386 .43626 .46723 .4419 .46541 .43863 .46203 Mtetra
.43863 .46203 .4419 .46541 .44755 .46358 .44429 .46019 Mtetra
.44429 .46019 .44755 .46358 .45322 .46175 .44996 .45836 Mtetra
.44996 .45836 .45322 .46175 .45889 .45991 .45564 .45651 Mtetra
.45564 .45651 .45889 .45991 .46458 .45807 .46134 .45467 Mtetra
.46134 .45467 .46458 .45807 .47027 .45623 .46704 .45282 Mtetra
.46704 .45282 .47027 .45623 .47598 .45438 .47276 .45096 Mtetra
.47276 .45096 .47598 .45438 .48171 .45253 .47849 .4491 Mtetra
.47849 .4491 .48171 .45253 .48744 .45068 .48423 .44724 Mtetra
.48423 .44724 .48744 .45068 .49319 .44882 .48999 .44537 Mtetra
.48999 .44537 .49319 .44882 .49895 .44695 .49575 .4435 Mtetra
.49575 .4435 .49895 .44695 .50472 .44509 .50153 .44163 Mtetra
.50153 .44163 .50472 .44509 .5105 .44322 .50732 .43975 Mtetra
.50732 .43975 .5105 .44322 .51629 .44134 .51312 .43787 Mtetra
.51312 .43787 .51629 .44134 .5221 .43946 .51894 .43599 Mtetra
.51894 .43599 .5221 .43946 .52792 .43758 .52477 .4341 Mtetra
.52477 .4341 .52792 .43758 .53375 .4357 .53061 .4322 Mtetra
.53061 .4322 .53375 .4357 .53959 .4338 .53646 .4303 Mtetra
.53646 .4303 .53959 .4338 .54545 .43191 .54232 .4284 Mtetra
.54232 .4284 .54545 .43191 .55132 .43001 .5482 .4265 Mtetra
.5482 .4265 .55132 .43001 .5572 .42811 .55409 .42459 Mtetra
.663 .741 .908 r
.55409 .42459 .5572 .42811 .5631 .4262 .55999 .42267 Mtetra
.55999 .42267 .5631 .4262 .569 .4243 .56591 .42076 Mtetra
.56591 .42076 .569 .4243 .57492 .42239 .57183 .41884 Mtetra
.657 .739 .91 r
.57183 .41884 .57492 .42239 .58085 .42056 .57777 .41702 Mtetra
.664 .742 .908 r
.57777 .41702 .58085 .42056 .5868 .41864 .58373 .41509 Mtetra
.67 .744 .906 r
.58373 .41509 .5868 .41864 .59275 .41662 .58969 .41305 Mtetra
.664 .742 .908 r
.58969 .41305 .59275 .41662 .59872 .41468 .59567 .4111 Mtetra
.664 .741 .908 r
.59567 .4111 .59872 .41468 .60471 .41274 .60166 .40916 Mtetra
.60166 .40916 .60471 .41274 .6107 .4108 .60767 .40721 Mtetra
.60767 .40721 .6107 .4108 .61671 .40886 .61368 .40526 Mtetra
.61368 .40526 .61671 .40886 .62273 .40691 .61971 .4033 Mtetra
.61971 .4033 .62273 .40691 .62877 .40496 .62576 .40134 Mtetra
.62576 .40134 .62877 .40496 .63481 .403 .63181 .39938 Mtetra
.63181 .39938 .63481 .403 .64088 .40104 .63788 .39741 Mtetra
.63788 .39741 .64088 .40104 .64695 .39908 .64396 .39544 Mtetra
.64396 .39544 .64695 .39908 .65304 .39711 .65006 .39346 Mtetra
.65006 .39346 .65304 .39711 .65914 .39513 .65617 .39148 Mtetra
.65617 .39148 .65914 .39513 .66525 .39316 .66229 .38949 Mtetra
.66229 .38949 .66525 .39316 .67138 .39117 .66843 .3875 Mtetra
.66843 .3875 .67138 .39117 .67752 .38919 .67458 .38551 Mtetra
.67458 .38551 .67752 .38919 .68367 .3872 .68074 .38351 Mtetra
.68074 .38351 .68367 .3872 .68983 .3852 .68691 .38151 Mtetra
.68691 .38151 .68983 .3852 .69601 .3832 .6931 .3795 Mtetra
.6931 .3795 .69601 .3832 .70221 .3812 .69931 .37749 Mtetra
.69931 .37749 .70221 .3812 .70842 .37919 .70552 .37547 Mtetra
.70552 .37547 .70842 .37919 .71464 .37718 .71175 .37345 Mtetra
.71175 .37345 .71464 .37718 .72087 .37516 .718 .37143 Mtetra
.718 .37143 .72087 .37516 .72712 .37314 .72425 .3694 Mtetra
.72425 .3694 .72712 .37314 .73338 .37112 .73053 .36736 Mtetra
.73053 .36736 .73338 .37112 .73966 .36909 .73681 .36533 Mtetra
.73681 .36533 .73966 .36909 .74595 .36705 .74311 .36328 Mtetra
.74311 .36328 .74595 .36705 .75225 .36501 .74942 .36124 Mtetra
.74942 .36124 .75225 .36501 .75857 .36297 .75575 .35918 Mtetra
.75575 .35918 .75857 .36297 .7649 .36092 .76209 .35713 Mtetra
.76209 .35713 .7649 .36092 .77124 .35887 .76845 .35507 Mtetra
.76845 .35507 .77124 .35887 .7776 .35681 .77481 .353 Mtetra
.77481 .353 .7776 .35681 .78397 .35475 .7812 .35093 Mtetra
.7812 .35093 .78397 .35475 .79036 .35268 .78759 .34886 Mtetra
.78759 .34886 .79036 .35268 .79676 .35061 .79401 .34678 Mtetra
.79401 .34678 .79676 .35061 .80318 .34854 .80043 .34469 Mtetra
.80043 .34469 .80318 .34854 .80961 .34646 .80687 .3426 Mtetra
.80687 .3426 .80961 .34646 .81605 .34437 .81333 .34051 Mtetra
.81333 .34051 .81605 .34437 .82251 .34228 .8198 .33841 Mtetra
.8198 .33841 .82251 .34228 .82898 .34019 .82628 .33631 Mtetra
.82628 .33631 .82898 .34019 .83547 .33809 .83278 .3342 Mtetra
.83278 .3342 .83547 .33809 .84197 .33599 .83929 .33209 Mtetra
.83929 .33209 .84197 .33599 .84849 .33388 .84582 .32997 Mtetra
.84582 .32997 .84849 .33388 .85502 .33177 .85236 .32785 Mtetra
.85236 .32785 .85502 .33177 .86157 .32965 .85891 .32573 Mtetra
.85891 .32573 .86157 .32965 .86813 .32753 .86549 .3236 Mtetra
.86549 .3236 .86813 .32753 .8747 .3254 .87207 .32146 Mtetra
.87207 .32146 .8747 .3254 .88129 .32327 .87867 .31932 Mtetra
.87867 .31932 .88129 .32327 .8879 .32113 .88529 .31717 Mtetra
.88529 .31717 .8879 .32113 .89452 .31899 .89192 .31502 Mtetra
.29746 .50347 .30092 .50669 .3063 .50495 .30284 .50172 Mtetra
.30284 .50172 .3063 .50495 .31168 .5032 .30823 .49997 Mtetra
.30823 .49997 .31168 .5032 .31708 .50145 .31364 .49821 Mtetra
.31364 .49821 .31708 .50145 .32248 .4997 .31905 .49645 Mtetra
.31905 .49645 .32248 .4997 .3279 .49794 .32448 .49469 Mtetra
.32448 .49469 .3279 .49794 .33333 .49618 .32991 .49292 Mtetra
.32991 .49292 .33333 .49618 .33877 .49442 .33536 .49115 Mtetra
.33536 .49115 .33877 .49442 .34422 .49265 .34082 .48938 Mtetra
.34082 .48938 .34422 .49265 .34968 .49088 .34629 .4876 Mtetra
.34629 .4876 .34968 .49088 .35516 .4891 .35177 .48581 Mtetra
.35177 .48581 .35516 .4891 .36064 .48732 .35726 .48403 Mtetra
.35726 .48403 .36064 .48732 .36614 .48554 .36276 .48224 Mtetra
.36276 .48224 .36614 .48554 .37165 .48375 .36828 .48045 Mtetra
.36828 .48045 .37165 .48375 .37716 .48196 .3738 .47865 Mtetra
.3738 .47865 .37716 .48196 .38269 .48017 .37934 .47685 Mtetra
.37934 .47685 .38269 .48017 .38824 .47837 .38489 .47505 Mtetra
.38489 .47505 .38824 .47837 .39379 .47657 .39045 .47324 Mtetra
.39045 .47324 .39379 .47657 .39935 .47477 .39602 .47143 Mtetra
.39602 .47143 .39935 .47477 .40493 .47296 .4016 .46961 Mtetra
.4016 .46961 .40493 .47296 .41052 .47115 .4072 .46779 Mtetra
.4072 .46779 .41052 .47115 .41612 .46933 .41281 .46597 Mtetra
.41281 .46597 .41612 .46933 .42173 .46751 .41842 .46414 Mtetra
.41842 .46414 .42173 .46751 .42735 .46569 .42405 .46231 Mtetra
.42405 .46231 .42735 .46569 .43299 .46386 .4297 .46048 Mtetra
.4297 .46048 .43299 .46386 .43863 .46203 .43535 .45864 Mtetra
.43535 .45864 .43863 .46203 .44429 .46019 .44102 .4568 Mtetra
.44102 .4568 .44429 .46019 .44996 .45836 .44669 .45495 Mtetra
.44669 .45495 .44996 .45836 .45564 .45651 .45238 .4531 Mtetra
.45238 .4531 .45564 .45651 .46134 .45467 .45808 .45125 Mtetra
.45808 .45125 .46134 .45467 .46704 .45282 .4638 .44939 Mtetra
.4638 .44939 .46704 .45282 .47276 .45096 .46952 .44753 Mtetra
.46952 .44753 .47276 .45096 .47849 .4491 .47526 .44566 Mtetra
.47526 .44566 .47849 .4491 .48423 .44724 .48101 .44379 Mtetra
.48101 .44379 .48423 .44724 .48999 .44537 .48677 .44192 Mtetra
.48677 .44192 .48999 .44537 .49575 .4435 .49255 .44004 Mtetra
.49255 .44004 .49575 .4435 .50153 .44163 .49833 .43816 Mtetra
.49833 .43816 .50153 .44163 .50732 .43975 .50413 .43628 Mtetra
.50413 .43628 .50732 .43975 .51312 .43787 .50994 .43439 Mtetra
.50994 .43439 .51312 .43787 .51894 .43599 .51576 .43249 Mtetra
.51576 .43249 .51894 .43599 .52477 .4341 .5216 .4306 Mtetra
.5216 .4306 .52477 .4341 .53061 .4322 .52745 .42869 Mtetra
.52745 .42869 .53061 .4322 .53646 .4303 .53331 .42679 Mtetra
.53331 .42679 .53646 .4303 .54232 .4284 .53918 .42488 Mtetra
.53918 .42488 .54232 .4284 .5482 .4265 .54507 .42297 Mtetra
.54507 .42297 .5482 .4265 .55409 .42459 .55096 .42105 Mtetra
.663 .741 .908 r
.55096 .42105 .55409 .42459 .55999 .42267 .55687 .41913 Mtetra
.55687 .41913 .55999 .42267 .56591 .42076 .5628 .41721 Mtetra
.5628 .41721 .56591 .42076 .57183 .41884 .56873 .41529 Mtetra
.656 .739 .911 r
.56873 .41529 .57183 .41884 .57777 .41702 .57468 .41347 Mtetra
.664 .742 .909 r
.57468 .41347 .57777 .41702 .58373 .41509 .58064 .41153 Mtetra
.671 .745 .906 r
.58064 .41153 .58373 .41509 .58969 .41305 .58662 .40947 Mtetra
.664 .742 .908 r
.58662 .40947 .58969 .41305 .59567 .4111 .5926 .40751 Mtetra
.664 .741 .908 r
.5926 .40751 .59567 .4111 .60166 .40916 .5986 .40556 Mtetra
.5986 .40556 .60166 .40916 .60767 .40721 .60462 .40361 Mtetra
.60462 .40361 .60767 .40721 .61368 .40526 .61064 .40165 Mtetra
.61064 .40165 .61368 .40526 .61971 .4033 .61668 .39968 Mtetra
.61668 .39968 .61971 .4033 .62576 .40134 .62273 .39771 Mtetra
.62273 .39771 .62576 .40134 .63181 .39938 .6288 .39574 Mtetra
.6288 .39574 .63181 .39938 .63788 .39741 .63488 .39377 Mtetra
.63488 .39377 .63788 .39741 .64396 .39544 .64097 .39178 Mtetra
.64097 .39178 .64396 .39544 .65006 .39346 .64707 .3898 Mtetra
.64707 .3898 .65006 .39346 .65617 .39148 .65319 .38781 Mtetra
.65319 .38781 .65617 .39148 .66229 .38949 .65932 .38582 Mtetra
.65932 .38582 .66229 .38949 .66843 .3875 .66547 .38382 Mtetra
.66547 .38382 .66843 .3875 .67458 .38551 .67163 .38182 Mtetra
.67163 .38182 .67458 .38551 .68074 .38351 .6778 .37981 Mtetra
.6778 .37981 .68074 .38351 .68691 .38151 .68398 .3778 Mtetra
.68398 .3778 .68691 .38151 .6931 .3795 .69018 .37578 Mtetra
.69018 .37578 .6931 .3795 .69931 .37749 .69639 .37376 Mtetra
.69639 .37376 .69931 .37749 .70552 .37547 .70262 .37174 Mtetra
.70262 .37174 .70552 .37547 .71175 .37345 .70886 .36971 Mtetra
.70886 .36971 .71175 .37345 .718 .37143 .71511 .36768 Mtetra
.71511 .36768 .718 .37143 .72425 .3694 .72138 .36564 Mtetra
.72138 .36564 .72425 .3694 .73053 .36736 .72766 .3636 Mtetra
.72766 .3636 .73053 .36736 .73681 .36533 .73395 .36155 Mtetra
.73395 .36155 .73681 .36533 .74311 .36328 .74026 .3595 Mtetra
.74026 .3595 .74311 .36328 .74942 .36124 .74659 .35744 Mtetra
.74659 .35744 .74942 .36124 .75575 .35918 .75292 .35538 Mtetra
.75292 .35538 .75575 .35918 .76209 .35713 .75927 .35332 Mtetra
.75927 .35332 .76209 .35713 .76845 .35507 .76564 .35125 Mtetra
.76564 .35125 .76845 .35507 .77481 .353 .77202 .34918 Mtetra
.77202 .34918 .77481 .353 .7812 .35093 .77841 .3471 Mtetra
.77841 .3471 .7812 .35093 .78759 .34886 .78482 .34501 Mtetra
.78482 .34501 .78759 .34886 .79401 .34678 .79124 .34293 Mtetra
.79124 .34293 .79401 .34678 .80043 .34469 .79767 .34083 Mtetra
.79767 .34083 .80043 .34469 .80687 .3426 .80412 .33874 Mtetra
.80412 .33874 .80687 .3426 .81333 .34051 .81059 .33663 Mtetra
.81059 .33663 .81333 .34051 .8198 .33841 .81707 .33453 Mtetra
.81707 .33453 .8198 .33841 .82628 .33631 .82356 .33242 Mtetra
.82356 .33242 .82628 .33631 .83278 .3342 .83007 .3303 Mtetra
.83007 .3303 .83278 .3342 .83929 .33209 .83659 .32818 Mtetra
.83659 .32818 .83929 .33209 .84582 .32997 .84313 .32605 Mtetra
.84313 .32605 .84582 .32997 .85236 .32785 .84968 .32392 Mtetra
.84968 .32392 .85236 .32785 .85891 .32573 .85625 .32179 Mtetra
.85625 .32179 .85891 .32573 .86549 .3236 .86283 .31965 Mtetra
.86283 .31965 .86549 .3236 .87207 .32146 .86943 .3175 Mtetra
.86943 .3175 .87207 .32146 .87867 .31932 .87604 .31535 Mtetra
.87604 .31535 .87867 .31932 .88529 .31717 .88267 .3132 Mtetra
.88267 .3132 .88529 .31717 .89192 .31502 .88931 .31104 Mtetra
.29399 .50024 .29746 .50347 .30284 .50172 .29938 .49848 Mtetra
.29938 .49848 .30284 .50172 .30823 .49997 .30478 .49672 Mtetra
.30478 .49672 .30823 .49997 .31364 .49821 .31019 .49496 Mtetra
.31019 .49496 .31364 .49821 .31905 .49645 .31561 .49319 Mtetra
.31561 .49319 .31905 .49645 .32448 .49469 .32104 .49142 Mtetra
.32104 .49142 .32448 .49469 .32991 .49292 .32648 .48965 Mtetra
.32648 .48965 .32991 .49292 .33536 .49115 .33193 .48787 Mtetra
.33193 .48787 .33536 .49115 .34082 .48938 .3374 .48609 Mtetra
.3374 .48609 .34082 .48938 .34629 .4876 .34287 .4843 Mtetra
.34287 .4843 .34629 .4876 .35177 .48581 .34836 .48252 Mtetra
.34836 .48252 .35177 .48581 .35726 .48403 .35386 .48072 Mtetra
.35386 .48072 .35726 .48403 .36276 .48224 .35937 .47893 Mtetra
.35937 .47893 .36276 .48224 .36828 .48045 .36489 .47713 Mtetra
.36489 .47713 .36828 .48045 .3738 .47865 .37043 .47532 Mtetra
.37043 .47532 .3738 .47865 .37934 .47685 .37597 .47352 Mtetra
.37597 .47352 .37934 .47685 .38489 .47505 .38153 .47171 Mtetra
.38153 .47171 .38489 .47505 .39045 .47324 .38709 .46989 Mtetra
.38709 .46989 .39045 .47324 .39602 .47143 .39267 .46807 Mtetra
.39267 .46807 .39602 .47143 .4016 .46961 .39826 .46625 Mtetra
.39826 .46625 .4016 .46961 .4072 .46779 .40387 .46442 Mtetra
.40387 .46442 .4072 .46779 .41281 .46597 .40948 .46259 Mtetra
.40948 .46259 .41281 .46597 .41842 .46414 .41511 .46076 Mtetra
.41511 .46076 .41842 .46414 .42405 .46231 .42074 .45892 Mtetra
.42074 .45892 .42405 .46231 .4297 .46048 .42639 .45708 Mtetra
.42639 .45708 .4297 .46048 .43535 .45864 .43205 .45523 Mtetra
.43205 .45523 .43535 .45864 .44102 .4568 .43773 .45339 Mtetra
.43773 .45339 .44102 .4568 .44669 .45495 .44341 .45153 Mtetra
.44341 .45153 .44669 .45495 .45238 .4531 .44911 .44968 Mtetra
.44911 .44968 .45238 .4531 .45808 .45125 .45482 .44781 Mtetra
.45482 .44781 .45808 .45125 .4638 .44939 .46054 .44595 Mtetra
.46054 .44595 .4638 .44939 .46952 .44753 .46627 .44408 Mtetra
.46627 .44408 .46952 .44753 .47526 .44566 .47202 .44221 Mtetra
.47202 .44221 .47526 .44566 .48101 .44379 .47778 .44033 Mtetra
.47778 .44033 .48101 .44379 .48677 .44192 .48354 .43845 Mtetra
.48354 .43845 .48677 .44192 .49255 .44004 .48933 .43657 Mtetra
.48933 .43657 .49255 .44004 .49833 .43816 .49512 .43468 Mtetra
.49512 .43468 .49833 .43816 .50413 .43628 .50093 .43278 Mtetra
.50093 .43278 .50413 .43628 .50994 .43439 .50675 .43089 Mtetra
.50675 .43089 .50994 .43439 .51576 .43249 .51258 .42899 Mtetra
.51258 .42899 .51576 .43249 .5216 .4306 .51842 .42708 Mtetra
.51842 .42708 .5216 .4306 .52745 .42869 .52428 .42517 Mtetra
.52428 .42517 .52745 .42869 .53331 .42679 .53014 .42326 Mtetra
.53014 .42326 .53331 .42679 .53918 .42488 .53603 .42134 Mtetra
.53603 .42134 .53918 .42488 .54507 .42297 .54192 .41942 Mtetra
.54192 .41942 .54507 .42297 .55096 .42105 .54783 .4175 Mtetra
.663 .741 .908 r
.54783 .4175 .55096 .42105 .55687 .41913 .55374 .41557 Mtetra
.55374 .41557 .55687 .41913 .5628 .41721 .55968 .41364 Mtetra
.55968 .41364 .5628 .41721 .56873 .41529 .56562 .41171 Mtetra
.655 .739 .911 r
.56562 .41171 .56873 .41529 .57468 .41347 .57158 .4099 Mtetra
.664 .742 .909 r
.57158 .4099 .57468 .41347 .58064 .41153 .57755 .40796 Mtetra
.672 .745 .906 r
.57755 .40796 .58064 .41153 .58662 .40947 .58353 .40588 Mtetra
.664 .742 .908 r
.58353 .40588 .58662 .40947 .5926 .40751 .58953 .40391 Mtetra
.664 .741 .908 r
.58953 .40391 .5926 .40751 .5986 .40556 .59553 .40195 Mtetra
.59553 .40195 .5986 .40556 .60462 .40361 .60156 .39998 Mtetra
.60156 .39998 .60462 .40361 .61064 .40165 .60759 .39802 Mtetra
.60759 .39802 .61064 .40165 .61668 .39968 .61364 .39605 Mtetra
.61364 .39605 .61668 .39968 .62273 .39771 .6197 .39407 Mtetra
.6197 .39407 .62273 .39771 .6288 .39574 .62577 .39209 Mtetra
.62577 .39209 .6288 .39574 .63488 .39377 .63186 .39011 Mtetra
.63186 .39011 .63488 .39377 .64097 .39178 .63796 .38812 Mtetra
.63796 .38812 .64097 .39178 .64707 .3898 .64407 .38612 Mtetra
.64407 .38612 .64707 .3898 .65319 .38781 .6502 .38413 Mtetra
.6502 .38413 .65319 .38781 .65932 .38582 .65634 .38213 Mtetra
.65634 .38213 .65932 .38582 .66547 .38382 .6625 .38012 Mtetra
.6625 .38012 .66547 .38382 .67163 .38182 .66866 .37811 Mtetra
.66866 .37811 .67163 .38182 .6778 .37981 .67484 .37609 Mtetra
.67484 .37609 .6778 .37981 .68398 .3778 .68104 .37408 Mtetra
.68104 .37408 .68398 .3778 .69018 .37578 .68725 .37205 Mtetra
.68725 .37205 .69018 .37578 .69639 .37376 .69347 .37002 Mtetra
.69347 .37002 .69639 .37376 .70262 .37174 .6997 .36799 Mtetra
.6997 .36799 .70262 .37174 .70886 .36971 .70595 .36595 Mtetra
.70595 .36595 .70886 .36971 .71511 .36768 .71221 .36391 Mtetra
.71221 .36391 .71511 .36768 .72138 .36564 .71849 .36187 Mtetra
.71849 .36187 .72138 .36564 .72766 .3636 .72478 .35982 Mtetra
.72478 .35982 .72766 .3636 .73395 .36155 .73109 .35776 Mtetra
.73109 .35776 .73395 .36155 .74026 .3595 .7374 .3557 Mtetra
.7374 .3557 .74026 .3595 .74659 .35744 .74374 .35364 Mtetra
.74374 .35364 .74659 .35744 .75292 .35538 .75008 .35157 Mtetra
.75008 .35157 .75292 .35538 .75927 .35332 .75644 .3495 Mtetra
.75644 .3495 .75927 .35332 .76564 .35125 .76282 .34742 Mtetra
.76282 .34742 .76564 .35125 .77202 .34918 .76921 .34533 Mtetra
.76921 .34533 .77202 .34918 .77841 .3471 .77561 .34325 Mtetra
.77561 .34325 .77841 .3471 .78482 .34501 .78203 .34116 Mtetra
.78203 .34116 .78482 .34501 .79124 .34293 .78846 .33906 Mtetra
.78846 .33906 .79124 .34293 .79767 .34083 .79491 .33696 Mtetra
.79491 .33696 .79767 .34083 .80412 .33874 .80137 .33485 Mtetra
.80137 .33485 .80412 .33874 .81059 .33663 .80784 .33274 Mtetra
.80784 .33274 .81059 .33663 .81707 .33453 .81433 .33063 Mtetra
.81433 .33063 .81707 .33453 .82356 .33242 .82084 .32851 Mtetra
.82084 .32851 .82356 .33242 .83007 .3303 .82735 .32638 Mtetra
.82735 .32638 .83007 .3303 .83659 .32818 .83389 .32425 Mtetra
.83389 .32425 .83659 .32818 .84313 .32605 .84044 .32212 Mtetra
.84044 .32212 .84313 .32605 .84968 .32392 .847 .31998 Mtetra
.847 .31998 .84968 .32392 .85625 .32179 .85358 .31783 Mtetra
.85358 .31783 .85625 .32179 .86283 .31965 .86017 .31568 Mtetra
.86017 .31568 .86283 .31965 .86943 .3175 .86678 .31353 Mtetra
.86678 .31353 .86943 .3175 .87604 .31535 .8734 .31137 Mtetra
.8734 .31137 .87604 .31535 .88267 .3132 .88004 .30921 Mtetra
.88004 .30921 .88267 .3132 .88931 .31104 .88669 .30704 Mtetra
.29051 .49699 .29399 .50024 .29938 .49848 .2959 .49523 Mtetra
.2959 .49523 .29938 .49848 .30478 .49672 .30131 .49346 Mtetra
.30131 .49346 .30478 .49672 .31019 .49496 .30672 .49169 Mtetra
.30672 .49169 .31019 .49496 .31561 .49319 .31215 .48992 Mtetra
.31215 .48992 .31561 .49319 .32104 .49142 .31759 .48814 Mtetra
.31759 .48814 .32104 .49142 .32648 .48965 .32304 .48636 Mtetra
.32304 .48636 .32648 .48965 .33193 .48787 .3285 .48458 Mtetra
.3285 .48458 .33193 .48787 .3374 .48609 .33397 .48279 Mtetra
.33397 .48279 .3374 .48609 .34287 .4843 .33945 .481 Mtetra
.33945 .481 .34287 .4843 .34836 .48252 .34494 .4792 Mtetra
.34494 .4792 .34836 .48252 .35386 .48072 .35045 .4774 Mtetra
.35045 .4774 .35386 .48072 .35937 .47893 .35597 .4756 Mtetra
.35597 .4756 .35937 .47893 .36489 .47713 .3615 .47379 Mtetra
.3615 .47379 .36489 .47713 .37043 .47532 .36704 .47198 Mtetra
.36704 .47198 .37043 .47532 .37597 .47352 .37259 .47017 Mtetra
.37259 .47017 .37597 .47352 .38153 .47171 .37815 .46835 Mtetra
.37815 .46835 .38153 .47171 .38709 .46989 .38373 .46653 Mtetra
.38373 .46653 .38709 .46989 .39267 .46807 .38931 .4647 Mtetra
.38931 .4647 .39267 .46807 .39826 .46625 .39491 .46287 Mtetra
.39491 .46287 .39826 .46625 .40387 .46442 .40052 .46104 Mtetra
.40052 .46104 .40387 .46442 .40948 .46259 .40614 .4592 Mtetra
.40614 .4592 .40948 .46259 .41511 .46076 .41177 .45736 Mtetra
.41177 .45736 .41511 .46076 .42074 .45892 .41742 .45552 Mtetra
.41742 .45552 .42074 .45892 .42639 .45708 .42308 .45367 Mtetra
.42308 .45367 .42639 .45708 .43205 .45523 .42875 .45182 Mtetra
.42875 .45182 .43205 .45523 .43773 .45339 .43443 .44996 Mtetra
.43443 .44996 .43773 .45339 .44341 .45153 .44012 .4481 Mtetra
.44012 .4481 .44341 .45153 .44911 .44968 .44582 .44624 Mtetra
.44582 .44624 .44911 .44968 .45482 .44781 .45154 .44437 Mtetra
.45154 .44437 .45482 .44781 .46054 .44595 .45727 .4425 Mtetra
.45727 .4425 .46054 .44595 .46627 .44408 .46301 .44062 Mtetra
.46301 .44062 .46627 .44408 .47202 .44221 .46876 .43874 Mtetra
.46876 .43874 .47202 .44221 .47778 .44033 .47453 .43686 Mtetra
.47453 .43686 .47778 .44033 .48354 .43845 .48031 .43497 Mtetra
.48031 .43497 .48354 .43845 .48933 .43657 .4861 .43308 Mtetra
.4861 .43308 .48933 .43657 .49512 .43468 .4919 .43118 Mtetra
.4919 .43118 .49512 .43468 .50093 .43278 .49771 .42928 Mtetra
.49771 .42928 .50093 .43278 .50675 .43089 .50354 .42738 Mtetra
.50354 .42738 .50675 .43089 .51258 .42899 .50938 .42547 Mtetra
.50938 .42547 .51258 .42899 .51842 .42708 .51523 .42356 Mtetra
.51523 .42356 .51842 .42708 .52428 .42517 .52109 .42164 Mtetra
.52109 .42164 .52428 .42517 .53014 .42326 .52697 .41972 Mtetra
.52697 .41972 .53014 .42326 .53603 .42134 .53286 .41779 Mtetra
.53286 .41779 .53603 .42134 .54192 .41942 .53876 .41587 Mtetra
.53876 .41587 .54192 .41942 .54783 .4175 .54468 .41393 Mtetra
.663 .741 .908 r
.54468 .41393 .54783 .4175 .55374 .41557 .5506 .412 Mtetra
.5506 .412 .55374 .41557 .55968 .41364 .55654 .41006 Mtetra
.55654 .41006 .55968 .41364 .56562 .41171 .5625 .40813 Mtetra
.654 .738 .912 r
.5625 .40813 .56562 .41171 .57158 .4099 .56846 .40633 Mtetra
.664 .743 .909 r
.56846 .40633 .57158 .4099 .57755 .40796 .57444 .40437 Mtetra
.673 .746 .905 r
.57444 .40437 .57755 .40796 .58353 .40588 .58043 .40227 Mtetra
.664 .742 .908 r
.58043 .40227 .58353 .40588 .58953 .40391 .58643 .40029 Mtetra
.664 .741 .908 r
.58643 .40029 .58953 .40391 .59553 .40195 .59245 .39832 Mtetra
.59245 .39832 .59553 .40195 .60156 .39998 .59848 .39635 Mtetra
.59848 .39635 .60156 .39998 .60759 .39802 .60453 .39437 Mtetra
.60453 .39437 .60759 .39802 .61364 .39605 .61058 .3924 Mtetra
.61058 .3924 .61364 .39605 .6197 .39407 .61665 .39041 Mtetra
.61665 .39041 .6197 .39407 .62577 .39209 .62273 .38842 Mtetra
.62273 .38842 .62577 .39209 .63186 .39011 .62883 .38643 Mtetra
.62883 .38643 .63186 .39011 .63796 .38812 .63494 .38443 Mtetra
.63494 .38443 .63796 .38812 .64407 .38612 .64106 .38243 Mtetra
.64106 .38243 .64407 .38612 .6502 .38413 .6472 .38043 Mtetra
.6472 .38043 .6502 .38413 .65634 .38213 .65335 .37842 Mtetra
.65335 .37842 .65634 .38213 .6625 .38012 .65951 .3764 Mtetra
.65951 .3764 .6625 .38012 .66866 .37811 .66569 .37439 Mtetra
.66569 .37439 .66866 .37811 .67484 .37609 .67188 .37236 Mtetra
.67188 .37236 .67484 .37609 .68104 .37408 .67808 .37034 Mtetra
.67808 .37034 .68104 .37408 .68725 .37205 .6843 .3683 Mtetra
.6843 .3683 .68725 .37205 .69347 .37002 .69053 .36627 Mtetra
.69053 .36627 .69347 .37002 .6997 .36799 .69677 .36423 Mtetra
.69677 .36423 .6997 .36799 .70595 .36595 .70303 .36218 Mtetra
.70303 .36218 .70595 .36595 .71221 .36391 .70931 .36013 Mtetra
.70931 .36013 .71221 .36391 .71849 .36187 .71559 .35808 Mtetra
.71559 .35808 .71849 .36187 .72478 .35982 .72189 .35602 Mtetra
.72189 .35602 .72478 .35982 .73109 .35776 .72821 .35396 Mtetra
.72821 .35396 .73109 .35776 .7374 .3557 .73453 .35189 Mtetra
.73453 .35189 .7374 .3557 .74374 .35364 .74088 .34981 Mtetra
.74088 .34981 .74374 .35364 .75008 .35157 .74723 .34774 Mtetra
.74723 .34774 .75008 .35157 .75644 .3495 .7536 .34566 Mtetra
.7536 .34566 .75644 .3495 .76282 .34742 .75999 .34357 Mtetra
.75999 .34357 .76282 .34742 .76921 .34533 .76639 .34148 Mtetra
.76639 .34148 .76921 .34533 .77561 .34325 .7728 .33938 Mtetra
.7728 .33938 .77561 .34325 .78203 .34116 .77923 .33728 Mtetra
.77923 .33728 .78203 .34116 .78846 .33906 .78567 .33518 Mtetra
.78567 .33518 .78846 .33906 .79491 .33696 .79213 .33307 Mtetra
.79213 .33307 .79491 .33696 .80137 .33485 .7986 .33095 Mtetra
.7986 .33095 .80137 .33485 .80784 .33274 .80508 .32883 Mtetra
.80508 .32883 .80784 .33274 .81433 .33063 .81158 .32671 Mtetra
.81158 .32671 .81433 .33063 .82084 .32851 .8181 .32458 Mtetra
.8181 .32458 .82084 .32851 .82735 .32638 .82463 .32245 Mtetra
.82463 .32245 .82735 .32638 .83389 .32425 .83117 .32031 Mtetra
.83117 .32031 .83389 .32425 .84044 .32212 .83773 .31816 Mtetra
.83773 .31816 .84044 .32212 .847 .31998 .8443 .31602 Mtetra
.8443 .31602 .847 .31998 .85358 .31783 .85089 .31386 Mtetra
.85089 .31386 .85358 .31783 .86017 .31568 .85749 .3117 Mtetra
.85749 .3117 .86017 .31568 .86678 .31353 .86411 .30954 Mtetra
.86411 .30954 .86678 .31353 .8734 .31137 .87075 .30737 Mtetra
.87075 .30737 .8734 .31137 .88004 .30921 .87739 .3052 Mtetra
.87739 .3052 .88004 .30921 .88669 .30704 .88406 .30302 Mtetra
.28701 .49374 .29051 .49699 .2959 .49523 .29241 .49197 Mtetra
.29241 .49197 .2959 .49523 .30131 .49346 .29782 .49019 Mtetra
.29782 .49019 .30131 .49346 .30672 .49169 .30324 .48842 Mtetra
.30324 .48842 .30672 .49169 .31215 .48992 .30868 .48664 Mtetra
.30868 .48664 .31215 .48992 .31759 .48814 .31412 .48485 Mtetra
.31412 .48485 .31759 .48814 .32304 .48636 .31958 .48307 Mtetra
.31958 .48307 .32304 .48636 .3285 .48458 .32504 .48127 Mtetra
.32504 .48127 .3285 .48458 .33397 .48279 .33052 .47948 Mtetra
.33052 .47948 .33397 .48279 .33945 .481 .33601 .47768 Mtetra
.33601 .47768 .33945 .481 .34494 .4792 .34151 .47588 Mtetra
.34151 .47588 .34494 .4792 .35045 .4774 .34703 .47407 Mtetra
.34703 .47407 .35045 .4774 .35597 .4756 .35255 .47226 Mtetra
.35255 .47226 .35597 .4756 .3615 .47379 .35809 .47045 Mtetra
.35809 .47045 .3615 .47379 .36704 .47198 .36363 .46863 Mtetra
.36363 .46863 .36704 .47198 .37259 .47017 .36919 .46681 Mtetra
.36919 .46681 .37259 .47017 .37815 .46835 .37476 .46499 Mtetra
.37476 .46499 .37815 .46835 .38373 .46653 .38035 .46316 Mtetra
.38035 .46316 .38373 .46653 .38931 .4647 .38594 .46132 Mtetra
.38594 .46132 .38931 .4647 .39491 .46287 .39154 .45949 Mtetra
.39154 .45949 .39491 .46287 .40052 .46104 .39716 .45765 Mtetra
.39716 .45765 .40052 .46104 .40614 .4592 .40279 .4558 Mtetra
.40279 .4558 .40614 .4592 .41177 .45736 .40843 .45395 Mtetra
.40843 .45395 .41177 .45736 .41742 .45552 .41408 .4521 Mtetra
.41408 .4521 .41742 .45552 .42308 .45367 .41975 .45025 Mtetra
.41975 .45025 .42308 .45367 .42875 .45182 .42542 .44839 Mtetra
.42542 .44839 .42875 .45182 .43443 .44996 .43111 .44652 Mtetra
.43111 .44652 .43443 .44996 .44012 .4481 .43681 .44466 Mtetra
.43681 .44466 .44012 .4481 .44582 .44624 .44253 .44278 Mtetra
.44253 .44278 .44582 .44624 .45154 .44437 .44825 .44091 Mtetra
.44825 .44091 .45154 .44437 .45727 .4425 .45399 .43903 Mtetra
.45399 .43903 .45727 .4425 .46301 .44062 .45973 .43715 Mtetra
.45973 .43715 .46301 .44062 .46876 .43874 .4655 .43526 Mtetra
.4655 .43526 .46876 .43874 .47453 .43686 .47127 .43337 Mtetra
.47127 .43337 .47453 .43686 .48031 .43497 .47705 .43147 Mtetra
.47705 .43147 .48031 .43497 .4861 .43308 .48285 .42957 Mtetra
.48285 .42957 .4861 .43308 .4919 .43118 .48866 .42767 Mtetra
.48866 .42767 .4919 .43118 .49771 .42928 .49448 .42576 Mtetra
.49448 .42576 .49771 .42928 .50354 .42738 .50032 .42385 Mtetra
.50032 .42385 .50354 .42738 .50938 .42547 .50617 .42193 Mtetra
.50617 .42193 .50938 .42547 .51523 .42356 .51203 .42001 Mtetra
.51203 .42001 .51523 .42356 .52109 .42164 .5179 .41809 Mtetra
.5179 .41809 .52109 .42164 .52697 .41972 .52378 .41616 Mtetra
.52378 .41616 .52697 .41972 .53286 .41779 .52968 .41423 Mtetra
.52968 .41423 .53286 .41779 .53876 .41587 .53559 .41229 Mtetra
.663 .741 .908 r
.53559 .41229 .53876 .41587 .54468 .41393 .54151 .41036 Mtetra
.54151 .41036 .54468 .41393 .5506 .412 .54745 .40841 Mtetra
.54745 .40841 .5506 .412 .55654 .41006 .5534 .40647 Mtetra
.5534 .40647 .55654 .41006 .5625 .40813 .55936 .40453 Mtetra
.652 .738 .912 r
.55936 .40453 .5625 .40813 .56846 .40633 .56533 .40274 Mtetra
.664 .743 .909 r
.56533 .40274 .56846 .40633 .57444 .40437 .57132 .40078 Mtetra
.674 .746 .905 r
.57132 .40078 .57444 .40437 .58043 .40227 .57732 .39864 Mtetra
.664 .742 .908 r
.57732 .39864 .58043 .40227 .58643 .40029 .58333 .39666 Mtetra
.664 .741 .908 r
.58333 .39666 .58643 .40029 .59245 .39832 .58936 .39468 Mtetra
.58936 .39468 .59245 .39832 .59848 .39635 .5954 .3927 Mtetra
.5954 .3927 .59848 .39635 .60453 .39437 .60145 .39072 Mtetra
.60145 .39072 .60453 .39437 .61058 .3924 .60751 .38873 Mtetra
.60751 .38873 .61058 .3924 .61665 .39041 .61359 .38674 Mtetra
.61359 .38674 .61665 .39041 .62273 .38842 .61968 .38474 Mtetra
.61968 .38474 .62273 .38842 .62883 .38643 .62579 .38274 Mtetra
.62579 .38274 .62883 .38643 .63494 .38443 .63191 .38074 Mtetra
.63191 .38074 .63494 .38443 .64106 .38243 .63804 .37873 Mtetra
.63804 .37873 .64106 .38243 .6472 .38043 .64418 .37671 Mtetra
.64418 .37671 .6472 .38043 .65335 .37842 .65034 .3747 Mtetra
.65034 .3747 .65335 .37842 .65951 .3764 .65652 .37267 Mtetra
.65652 .37267 .65951 .3764 .66569 .37439 .6627 .37065 Mtetra
.6627 .37065 .66569 .37439 .67188 .37236 .6689 .36862 Mtetra
.6689 .36862 .67188 .37236 .67808 .37034 .67511 .36658 Mtetra
.67511 .36658 .67808 .37034 .6843 .3683 .68134 .36454 Mtetra
.68134 .36454 .6843 .3683 .69053 .36627 .68758 .3625 Mtetra
.68758 .3625 .69053 .36627 .69677 .36423 .69383 .36045 Mtetra
.69383 .36045 .69677 .36423 .70303 .36218 .7001 .35839 Mtetra
.7001 .35839 .70303 .36218 .70931 .36013 .70638 .35634 Mtetra
.70638 .35634 .70931 .36013 .71559 .35808 .71268 .35427 Mtetra
.71268 .35427 .71559 .35808 .72189 .35602 .71899 .35221 Mtetra
.71899 .35221 .72189 .35602 .72821 .35396 .72531 .35013 Mtetra
.72531 .35013 .72821 .35396 .73453 .35189 .73165 .34806 Mtetra
.73165 .34806 .73453 .35189 .74088 .34981 .738 .34598 Mtetra
.738 .34598 .74088 .34981 .74723 .34774 .74437 .34389 Mtetra
.74437 .34389 .74723 .34774 .7536 .34566 .75075 .3418 Mtetra
.75075 .3418 .7536 .34566 .75999 .34357 .75715 .3397 Mtetra
.75715 .3397 .75999 .34357 .76639 .34148 .76355 .33761 Mtetra
.76355 .33761 .76639 .34148 .7728 .33938 .76998 .3355 Mtetra
.76998 .3355 .7728 .33938 .77923 .33728 .77642 .33339 Mtetra
.77642 .33339 .77923 .33728 .78567 .33518 .78287 .33128 Mtetra
.78287 .33128 .78567 .33518 .79213 .33307 .78933 .32916 Mtetra
.78933 .32916 .79213 .33307 .7986 .33095 .79582 .32704 Mtetra
.79582 .32704 .7986 .33095 .80508 .32883 .80231 .32491 Mtetra
.80231 .32491 .80508 .32883 .81158 .32671 .80882 .32277 Mtetra
.80882 .32277 .81158 .32671 .8181 .32458 .81535 .32064 Mtetra
.81535 .32064 .8181 .32458 .82463 .32245 .82189 .31849 Mtetra
.82189 .31849 .82463 .32245 .83117 .32031 .82844 .31635 Mtetra
.82844 .31635 .83117 .32031 .83773 .31816 .83501 .31419 Mtetra
.83501 .31419 .83773 .31816 .8443 .31602 .84159 .31204 Mtetra
.84159 .31204 .8443 .31602 .85089 .31386 .84819 .30987 Mtetra
.84819 .30987 .85089 .31386 .85749 .3117 .85481 .30771 Mtetra
.85481 .30771 .85749 .3117 .86411 .30954 .86144 .30554 Mtetra
.86144 .30554 .86411 .30954 .87075 .30737 .86808 .30336 Mtetra
.86808 .30336 .87075 .30737 .87739 .3052 .87474 .30118 Mtetra
.87474 .30118 .87739 .3052 .88406 .30302 .88142 .29899 Mtetra
.2835 .49047 .28701 .49374 .29241 .49197 .2889 .48869 Mtetra
.2889 .48869 .29241 .49197 .29782 .49019 .29432 .48691 Mtetra
.29432 .48691 .29782 .49019 .30324 .48842 .29975 .48513 Mtetra
.29975 .48513 .30324 .48842 .30868 .48664 .30519 .48334 Mtetra
.30519 .48334 .30868 .48664 .31412 .48485 .31064 .48155 Mtetra
.31064 .48155 .31412 .48485 .31958 .48307 .31611 .47976 Mtetra
.31611 .47976 .31958 .48307 .32504 .48127 .32158 .47796 Mtetra
.32158 .47796 .32504 .48127 .33052 .47948 .32707 .47616 Mtetra
.32707 .47616 .33052 .47948 .33601 .47768 .33256 .47435 Mtetra
.33256 .47435 .33601 .47768 .34151 .47588 .33807 .47254 Mtetra
.33807 .47254 .34151 .47588 .34703 .47407 .34359 .47073 Mtetra
.34359 .47073 .34703 .47407 .35255 .47226 .34912 .46891 Mtetra
.34912 .46891 .35255 .47226 .35809 .47045 .35467 .46709 Mtetra
.35467 .46709 .35809 .47045 .36363 .46863 .36022 .46527 Mtetra
.36022 .46527 .36363 .46863 .36919 .46681 .36579 .46344 Mtetra
.36579 .46344 .36919 .46681 .37476 .46499 .37136 .46161 Mtetra
.37136 .46161 .37476 .46499 .38035 .46316 .37695 .45977 Mtetra
.37695 .45977 .38035 .46316 .38594 .46132 .38255 .45793 Mtetra
.38255 .45793 .38594 .46132 .39154 .45949 .38817 .45609 Mtetra
.38817 .45609 .39154 .45949 .39716 .45765 .39379 .45424 Mtetra
.39379 .45424 .39716 .45765 .40279 .4558 .39943 .45239 Mtetra
.39943 .45239 .40279 .4558 .40843 .45395 .40507 .45053 Mtetra
.40507 .45053 .40843 .45395 .41408 .4521 .41073 .44867 Mtetra
.41073 .44867 .41408 .4521 .41975 .45025 .41641 .44681 Mtetra
.41641 .44681 .41975 .45025 .42542 .44839 .42209 .44494 Mtetra
.42209 .44494 .42542 .44839 .43111 .44652 .42779 .44307 Mtetra
.42779 .44307 .43111 .44652 .43681 .44466 .43349 .4412 Mtetra
.43349 .4412 .43681 .44466 .44253 .44278 .43921 .43932 Mtetra
.43921 .43932 .44253 .44278 .44825 .44091 .44495 .43744 Mtetra
.44495 .43744 .44825 .44091 .45399 .43903 .45069 .43555 Mtetra
.45069 .43555 .45399 .43903 .45973 .43715 .45645 .43366 Mtetra
.45645 .43366 .45973 .43715 .4655 .43526 .46221 .43176 Mtetra
.46221 .43176 .4655 .43526 .47127 .43337 .468 .42987 Mtetra
.468 .42987 .47127 .43337 .47705 .43147 .47379 .42796 Mtetra
.47379 .42796 .47705 .43147 .48285 .42957 .47959 .42606 Mtetra
.47959 .42606 .48285 .42957 .48866 .42767 .48541 .42414 Mtetra
.48541 .42414 .48866 .42767 .49448 .42576 .49124 .42223 Mtetra
.49124 .42223 .49448 .42576 .50032 .42385 .49709 .42031 Mtetra
.49709 .42031 .50032 .42385 .50617 .42193 .50294 .41839 Mtetra
.50294 .41839 .50617 .42193 .51203 .42001 .50881 .41646 Mtetra
.50881 .41646 .51203 .42001 .5179 .41809 .51469 .41453 Mtetra
.51469 .41453 .5179 .41809 .52378 .41616 .52058 .41259 Mtetra
.52058 .41259 .52378 .41616 .52968 .41423 .52649 .41065 Mtetra
.52649 .41065 .52968 .41423 .53559 .41229 .53241 .40871 Mtetra
.663 .741 .908 r
.53241 .40871 .53559 .41229 .54151 .41036 .53834 .40676 Mtetra
.53834 .40676 .54151 .41036 .54745 .40841 .54428 .40481 Mtetra
.54428 .40481 .54745 .40841 .5534 .40647 .55024 .40286 Mtetra
.662 .741 .908 r
.55024 .40286 .5534 .40647 .55936 .40453 .55621 .40091 Mtetra
.65 .737 .913 r
.55621 .40091 .55936 .40453 .56533 .40274 .56219 .39915 Mtetra
.664 .743 .909 r
.56219 .39915 .56533 .40274 .57132 .40078 .56819 .39719 Mtetra
.676 .747 .905 r
.56819 .39719 .57132 .40078 .57732 .39864 .57419 .39501 Mtetra
.665 .742 .908 r
.57419 .39501 .57732 .39864 .58333 .39666 .58022 .39301 Mtetra
.664 .741 .908 r
.58022 .39301 .58333 .39666 .58936 .39468 .58625 .39103 Mtetra
.58625 .39103 .58936 .39468 .5954 .3927 .5923 .38904 Mtetra
.5923 .38904 .5954 .3927 .60145 .39072 .59836 .38705 Mtetra
.59836 .38705 .60145 .39072 .60751 .38873 .60443 .38505 Mtetra
.60443 .38505 .60751 .38873 .61359 .38674 .61052 .38305 Mtetra
.61052 .38305 .61359 .38674 .61968 .38474 .61662 .38105 Mtetra
.61662 .38105 .61968 .38474 .62579 .38274 .62274 .37904 Mtetra
.62274 .37904 .62579 .38274 .63191 .38074 .62886 .37702 Mtetra
.62886 .37702 .63191 .38074 .63804 .37873 .635 .37501 Mtetra
.635 .37501 .63804 .37873 .64418 .37671 .64116 .37299 Mtetra
.64116 .37299 .64418 .37671 .65034 .3747 .64733 .37096 Mtetra
.64733 .37096 .65034 .3747 .65652 .37267 .65351 .36893 Mtetra
.65351 .36893 .65652 .37267 .6627 .37065 .6597 .36689 Mtetra
.6597 .36689 .6627 .37065 .6689 .36862 .66591 .36486 Mtetra
.66591 .36486 .6689 .36862 .67511 .36658 .67213 .36281 Mtetra
.67213 .36281 .67511 .36658 .68134 .36454 .67837 .36076 Mtetra
.67837 .36076 .68134 .36454 .68758 .3625 .68462 .35871 Mtetra
.68462 .35871 .68758 .3625 .69383 .36045 .69088 .35665 Mtetra
.69088 .35665 .69383 .36045 .7001 .35839 .69716 .35459 Mtetra
.69716 .35459 .7001 .35839 .70638 .35634 .70345 .35252 Mtetra
.70345 .35252 .70638 .35634 .71268 .35427 .70976 .35045 Mtetra
.70976 .35045 .71268 .35427 .71899 .35221 .71608 .34838 Mtetra
.71608 .34838 .71899 .35221 .72531 .35013 .72241 .3463 Mtetra
.72241 .3463 .72531 .35013 .73165 .34806 .72876 .34421 Mtetra
.72876 .34421 .73165 .34806 .738 .34598 .73512 .34212 Mtetra
.73512 .34212 .738 .34598 .74437 .34389 .7415 .34003 Mtetra
.7415 .34003 .74437 .34389 .75075 .3418 .74789 .33793 Mtetra
.74789 .33793 .75075 .3418 .75715 .3397 .75429 .33582 Mtetra
.75429 .33582 .75715 .3397 .76355 .33761 .76071 .33372 Mtetra
.76071 .33372 .76355 .33761 .76998 .3355 .76714 .3316 Mtetra
.76714 .3316 .76998 .3355 .77642 .33339 .77359 .32949 Mtetra
.77359 .32949 .77642 .33339 .78287 .33128 .78005 .32736 Mtetra
.78005 .32736 .78287 .33128 .78933 .32916 .78653 .32523 Mtetra
.78653 .32523 .78933 .32916 .79582 .32704 .79302 .3231 Mtetra
.79302 .3231 .79582 .32704 .80231 .32491 .79953 .32097 Mtetra
.79953 .32097 .80231 .32491 .80882 .32277 .80605 .31882 Mtetra
.80605 .31882 .80882 .32277 .81535 .32064 .81258 .31668 Mtetra
.81258 .31668 .81535 .32064 .82189 .31849 .81913 .31453 Mtetra
.81913 .31453 .82189 .31849 .82844 .31635 .8257 .31237 Mtetra
.8257 .31237 .82844 .31635 .83501 .31419 .83228 .31021 Mtetra
.83228 .31021 .83501 .31419 .84159 .31204 .83888 .30804 Mtetra
.83888 .30804 .84159 .31204 .84819 .30987 .84549 .30587 Mtetra
.84549 .30587 .84819 .30987 .85481 .30771 .85211 .30369 Mtetra
.85211 .30369 .85481 .30771 .86144 .30554 .85875 .30151 Mtetra
.85875 .30151 .86144 .30554 .86808 .30336 .86541 .29933 Mtetra
.86541 .29933 .86808 .30336 .87474 .30118 .87208 .29714 Mtetra
.87208 .29714 .87474 .30118 .88142 .29899 .87876 .29494 Mtetra
.27997 .48719 .2835 .49047 .2889 .48869 .28539 .4854 Mtetra
.28539 .4854 .2889 .48869 .29432 .48691 .29081 .48362 Mtetra
.29081 .48362 .29432 .48691 .29975 .48513 .29625 .48183 Mtetra
.29625 .48183 .29975 .48513 .30519 .48334 .30169 .48003 Mtetra
.30169 .48003 .30519 .48334 .31064 .48155 .30715 .47824 Mtetra
.30715 .47824 .31064 .48155 .31611 .47976 .31262 .47643 Mtetra
.31262 .47643 .31611 .47976 .32158 .47796 .3181 .47463 Mtetra
.3181 .47463 .32158 .47796 .32707 .47616 .3236 .47282 Mtetra
.3236 .47282 .32707 .47616 .33256 .47435 .3291 .47101 Mtetra
.3291 .47101 .33256 .47435 .33807 .47254 .33462 .46919 Mtetra
.33462 .46919 .33807 .47254 .34359 .47073 .34014 .46737 Mtetra
.34014 .46737 .34359 .47073 .34912 .46891 .34568 .46555 Mtetra
.34568 .46555 .34912 .46891 .35467 .46709 .35123 .46372 Mtetra
.35123 .46372 .35467 .46709 .36022 .46527 .35679 .46189 Mtetra
.35679 .46189 .36022 .46527 .36579 .46344 .36236 .46005 Mtetra
.36236 .46005 .36579 .46344 .37136 .46161 .36795 .45821 Mtetra
.36795 .45821 .37136 .46161 .37695 .45977 .37355 .45637 Mtetra
.37355 .45637 .37695 .45977 .38255 .45793 .37915 .45452 Mtetra
.37915 .45452 .38255 .45793 .38817 .45609 .38477 .45267 Mtetra
.38477 .45267 .38817 .45609 .39379 .45424 .39041 .45082 Mtetra
.39041 .45082 .39379 .45424 .39943 .45239 .39605 .44896 Mtetra
.39605 .44896 .39943 .45239 .40507 .45053 .4017 .4471 Mtetra
.4017 .4471 .40507 .45053 .41073 .44867 .40737 .44523 Mtetra
.40737 .44523 .41073 .44867 .41641 .44681 .41305 .44336 Mtetra
.41305 .44336 .41641 .44681 .42209 .44494 .41874 .44149 Mtetra
.41874 .44149 .42209 .44494 .42779 .44307 .42445 .43961 Mtetra
.42445 .43961 .42779 .44307 .43349 .4412 .43016 .43773 Mtetra
.43016 .43773 .43349 .4412 .43921 .43932 .43589 .43584 Mtetra
.43589 .43584 .43921 .43932 .44495 .43744 .44163 .43395 Mtetra
.44163 .43395 .44495 .43744 .45069 .43555 .44738 .43206 Mtetra
.44738 .43206 .45069 .43555 .45645 .43366 .45315 .43016 Mtetra
.45315 .43016 .45645 .43366 .46221 .43176 .45892 .42826 Mtetra
.45892 .42826 .46221 .43176 .468 .42987 .46471 .42635 Mtetra
.46471 .42635 .468 .42987 .47379 .42796 .47051 .42444 Mtetra
.47051 .42444 .47379 .42796 .47959 .42606 .47632 .42252 Mtetra
.47632 .42252 .47959 .42606 .48541 .42414 .48215 .42061 Mtetra
.48215 .42061 .48541 .42414 .49124 .42223 .48799 .41868 Mtetra
.48799 .41868 .49124 .42223 .49709 .42031 .49384 .41676 Mtetra
.49384 .41676 .49709 .42031 .50294 .41839 .4997 .41483 Mtetra
.4997 .41483 .50294 .41839 .50881 .41646 .50558 .41289 Mtetra
.50558 .41289 .50881 .41646 .51469 .41453 .51147 .41095 Mtetra
.51147 .41095 .51469 .41453 .52058 .41259 .51737 .40901 Mtetra
.51737 .40901 .52058 .41259 .52649 .41065 .52328 .40706 Mtetra
.52328 .40706 .52649 .41065 .53241 .40871 .52921 .40511 Mtetra
.663 .741 .908 r
.52921 .40511 .53241 .40871 .53834 .40676 .53515 .40315 Mtetra
.53515 .40315 .53834 .40676 .54428 .40481 .5411 .4012 Mtetra
.5411 .4012 .54428 .40481 .55024 .40286 .54707 .39924 Mtetra
.662 .741 .908 r
.54707 .39924 .55024 .40286 .55621 .40091 .55305 .39729 Mtetra
.647 .736 .914 r
.55305 .39729 .55621 .40091 .56219 .39915 .55904 .39556 Mtetra
.664 .744 .91 r
.55904 .39556 .56219 .39915 .56819 .39719 .56504 .39358 Mtetra
.679 .749 .904 r
.56504 .39358 .56819 .39719 .57419 .39501 .57106 .39136 Mtetra
.665 .742 .908 r
.57106 .39136 .57419 .39501 .58022 .39301 .57709 .38935 Mtetra
.664 .742 .908 r
.57709 .38935 .58022 .39301 .58625 .39103 .58313 .38736 Mtetra
.664 .741 .908 r
.58313 .38736 .58625 .39103 .5923 .38904 .58919 .38536 Mtetra
.58919 .38536 .5923 .38904 .59836 .38705 .59526 .38336 Mtetra
.59526 .38336 .59836 .38705 .60443 .38505 .60134 .38136 Mtetra
.60134 .38136 .60443 .38505 .61052 .38305 .60744 .37935 Mtetra
.60744 .37935 .61052 .38305 .61662 .38105 .61355 .37734 Mtetra
.61355 .37734 .61662 .38105 .62274 .37904 .61967 .37532 Mtetra
.61967 .37532 .62274 .37904 .62886 .37702 .62581 .3733 Mtetra
.62581 .3733 .62886 .37702 .635 .37501 .63196 .37127 Mtetra
.63196 .37127 .635 .37501 .64116 .37299 .63812 .36924 Mtetra
.63812 .36924 .64116 .37299 .64733 .37096 .6443 .36721 Mtetra
.6443 .36721 .64733 .37096 .65351 .36893 .65049 .36517 Mtetra
.65049 .36517 .65351 .36893 .6597 .36689 .65669 .36313 Mtetra
.65669 .36313 .6597 .36689 .66591 .36486 .66291 .36108 Mtetra
.66291 .36108 .66591 .36486 .67213 .36281 .66914 .35903 Mtetra
.66914 .35903 .67213 .36281 .67837 .36076 .67539 .35697 Mtetra
.67539 .35697 .67837 .36076 .68462 .35871 .68165 .35491 Mtetra
.68165 .35491 .68462 .35871 .69088 .35665 .68792 .35284 Mtetra
.68792 .35284 .69088 .35665 .69716 .35459 .69421 .35077 Mtetra
.69421 .35077 .69716 .35459 .70345 .35252 .70051 .3487 Mtetra
.70051 .3487 .70345 .35252 .70976 .35045 .70682 .34662 Mtetra
.70682 .34662 .70976 .35045 .71608 .34838 .71315 .34453 Mtetra
.71315 .34453 .71608 .34838 .72241 .3463 .7195 .34244 Mtetra
.7195 .34244 .72241 .3463 .72876 .34421 .72585 .34035 Mtetra
.72585 .34035 .72876 .34421 .73512 .34212 .73222 .33825 Mtetra
.73222 .33825 .73512 .34212 .7415 .34003 .73861 .33615 Mtetra
.73861 .33615 .7415 .34003 .74789 .33793 .74501 .33404 Mtetra
.74501 .33404 .74789 .33793 .75429 .33582 .75143 .33193 Mtetra
.75143 .33193 .75429 .33582 .76071 .33372 .75785 .32981 Mtetra
.75785 .32981 .76071 .33372 .76714 .3316 .7643 .32769 Mtetra
.7643 .32769 .76714 .3316 .77359 .32949 .77076 .32556 Mtetra
.77076 .32556 .77359 .32949 .78005 .32736 .77723 .32343 Mtetra
.77723 .32343 .78005 .32736 .78653 .32523 .78372 .32129 Mtetra
.78372 .32129 .78653 .32523 .79302 .3231 .79022 .31915 Mtetra
.79022 .31915 .79302 .3231 .79953 .32097 .79673 .31701 Mtetra
.79673 .31701 .79953 .32097 .80605 .31882 .80327 .31486 Mtetra
.80327 .31486 .80605 .31882 .81258 .31668 .80981 .3127 Mtetra
.80981 .3127 .81258 .31668 .81913 .31453 .81637 .31054 Mtetra
.81637 .31054 .81913 .31453 .8257 .31237 .82295 .30837 Mtetra
.82295 .30837 .8257 .31237 .83228 .31021 .82954 .3062 Mtetra
.82954 .3062 .83228 .31021 .83888 .30804 .83614 .30403 Mtetra
.83614 .30403 .83888 .30804 .84549 .30587 .84277 .30185 Mtetra
.84277 .30185 .84549 .30587 .85211 .30369 .8494 .29966 Mtetra
.8494 .29966 .85211 .30369 .85875 .30151 .85605 .29747 Mtetra
.85605 .29747 .85875 .30151 .86541 .29933 .86272 .29528 Mtetra
.86272 .29528 .86541 .29933 .87208 .29714 .8694 .29308 Mtetra
.8694 .29308 .87208 .29714 .87876 .29494 .8761 .29087 Mtetra
.27644 .48389 .27997 .48719 .28539 .4854 .28186 .4821 Mtetra
.28186 .4821 .28539 .4854 .29081 .48362 .28729 .48031 Mtetra
.28729 .48031 .29081 .48362 .29625 .48183 .29273 .47851 Mtetra
.29273 .47851 .29625 .48183 .30169 .48003 .29818 .47671 Mtetra
.29818 .47671 .30169 .48003 .30715 .47824 .30365 .47491 Mtetra
.30365 .47491 .30715 .47824 .31262 .47643 .30913 .4731 Mtetra
.30913 .4731 .31262 .47643 .3181 .47463 .31461 .47129 Mtetra
.31461 .47129 .3181 .47463 .3236 .47282 .32011 .46947 Mtetra
.32011 .46947 .3236 .47282 .3291 .47101 .32562 .46765 Mtetra
.32562 .46765 .3291 .47101 .33462 .46919 .33115 .46583 Mtetra
.33115 .46583 .33462 .46919 .34014 .46737 .33668 .464 Mtetra
.33668 .464 .34014 .46737 .34568 .46555 .34222 .46217 Mtetra
.34222 .46217 .34568 .46555 .35123 .46372 .34778 .46034 Mtetra
.34778 .46034 .35123 .46372 .35679 .46189 .35335 .4585 Mtetra
.35335 .4585 .35679 .46189 .36236 .46005 .35893 .45665 Mtetra
.35893 .45665 .36236 .46005 .36795 .45821 .36452 .45481 Mtetra
.36452 .45481 .36795 .45821 .37355 .45637 .37013 .45296 Mtetra
.37013 .45296 .37355 .45637 .37915 .45452 .37574 .4511 Mtetra
.37574 .4511 .37915 .45452 .38477 .45267 .38137 .44925 Mtetra
.38137 .44925 .38477 .45267 .39041 .45082 .38701 .44738 Mtetra
.38701 .44738 .39041 .45082 .39605 .44896 .39266 .44552 Mtetra
.39266 .44552 .39605 .44896 .4017 .4471 .39832 .44365 Mtetra
.39832 .44365 .4017 .4471 .40737 .44523 .404 .44178 Mtetra
.404 .44178 .40737 .44523 .41305 .44336 .40968 .4399 Mtetra
.40968 .4399 .41305 .44336 .41874 .44149 .41538 .43802 Mtetra
.41538 .43802 .41874 .44149 .42445 .43961 .42109 .43613 Mtetra
.42109 .43613 .42445 .43961 .43016 .43773 .42682 .43424 Mtetra
.42682 .43424 .43016 .43773 .43589 .43584 .43255 .43235 Mtetra
.43255 .43235 .43589 .43584 .44163 .43395 .4383 .43045 Mtetra
.4383 .43045 .44163 .43395 .44738 .43206 .44406 .42855 Mtetra
.44406 .42855 .44738 .43206 .45315 .43016 .44983 .42664 Mtetra
.44983 .42664 .45315 .43016 .45892 .42826 .45562 .42473 Mtetra
.45562 .42473 .45892 .42826 .46471 .42635 .46141 .42282 Mtetra
.46141 .42282 .46471 .42635 .47051 .42444 .46722 .4209 Mtetra
.46722 .4209 .47051 .42444 .47632 .42252 .47304 .41898 Mtetra
.47304 .41898 .47632 .42252 .48215 .42061 .47888 .41705 Mtetra
.47888 .41705 .48215 .42061 .48799 .41868 .48472 .41512 Mtetra
.48472 .41512 .48799 .41868 .49384 .41676 .49058 .41319 Mtetra
.49058 .41319 .49384 .41676 .4997 .41483 .49645 .41125 Mtetra
.49645 .41125 .4997 .41483 .50558 .41289 .50234 .40931 Mtetra
.50234 .40931 .50558 .41289 .51147 .41095 .50823 .40736 Mtetra
.50823 .40736 .51147 .41095 .51737 .40901 .51414 .40541 Mtetra
.51414 .40541 .51737 .40901 .52328 .40706 .52007 .40345 Mtetra
.52007 .40345 .52328 .40706 .52921 .40511 .526 .4015 Mtetra
.663 .741 .908 r
.526 .4015 .52921 .40511 .53515 .40315 .53195 .39953 Mtetra
.53195 .39953 .53515 .40315 .5411 .4012 .53791 .39757 Mtetra
.53791 .39757 .5411 .4012 .54707 .39924 .54388 .3956 Mtetra
.662 .741 .909 r
.54388 .3956 .54707 .39924 .55305 .39729 .54987 .39365 Mtetra
.644 .735 .915 r
.54987 .39365 .55305 .39729 .55904 .39556 .55587 .39197 Mtetra
.664 .745 .911 r
.55587 .39197 .55904 .39556 .56504 .39358 .56189 .38998 Mtetra
.682 .751 .903 r
.56189 .38998 .56504 .39358 .57106 .39136 .56791 .38769 Mtetra
.665 .742 .908 r
.56791 .38769 .57106 .39136 .57709 .38935 .57395 .38568 Mtetra
.664 .742 .908 r
.57395 .38568 .57709 .38935 .58313 .38736 .58 .38367 Mtetra
.664 .741 .908 r
.58 .38367 .58313 .38736 .58919 .38536 .58606 .38167 Mtetra
.58606 .38167 .58919 .38536 .59526 .38336 .59214 .37966 Mtetra
.59214 .37966 .59526 .38336 .60134 .38136 .59823 .37765 Mtetra
.59823 .37765 .60134 .38136 .60744 .37935 .60434 .37563 Mtetra
.60434 .37563 .60744 .37935 .61355 .37734 .61046 .37361 Mtetra
.61046 .37361 .61355 .37734 .61967 .37532 .61659 .37158 Mtetra
.61659 .37158 .61967 .37532 .62581 .3733 .62274 .36956 Mtetra
.62274 .36956 .62581 .3733 .63196 .37127 .6289 .36752 Mtetra
.6289 .36752 .63196 .37127 .63812 .36924 .63507 .36548 Mtetra
.63507 .36548 .63812 .36924 .6443 .36721 .64125 .36344 Mtetra
.64125 .36344 .6443 .36721 .65049 .36517 .64745 .36139 Mtetra
.64745 .36139 .65049 .36517 .65669 .36313 .65367 .35934 Mtetra
.65367 .35934 .65669 .36313 .66291 .36108 .65989 .35729 Mtetra
.65989 .35729 .66291 .36108 .66914 .35903 .66614 .35523 Mtetra
.66614 .35523 .66914 .35903 .67539 .35697 .67239 .35316 Mtetra
.67239 .35316 .67539 .35697 .68165 .35491 .67866 .35109 Mtetra
.67866 .35109 .68165 .35491 .68792 .35284 .68494 .34902 Mtetra
.68494 .34902 .68792 .35284 .69421 .35077 .69124 .34694 Mtetra
.69124 .34694 .69421 .35077 .70051 .3487 .69755 .34485 Mtetra
.69755 .34485 .70051 .3487 .70682 .34662 .70388 .34277 Mtetra
.70388 .34277 .70682 .34662 .71315 .34453 .71021 .34067 Mtetra
.71021 .34067 .71315 .34453 .7195 .34244 .71657 .33857 Mtetra
.71657 .33857 .7195 .34244 .72585 .34035 .72293 .33647 Mtetra
.72293 .33647 .72585 .34035 .73222 .33825 .72932 .33437 Mtetra
.72932 .33437 .73222 .33825 .73861 .33615 .73571 .33225 Mtetra
.73571 .33225 .73861 .33615 .74501 .33404 .74212 .33014 Mtetra
.74212 .33014 .74501 .33404 .75143 .33193 .74855 .32802 Mtetra
.74855 .32802 .75143 .33193 .75785 .32981 .75499 .32589 Mtetra
.75499 .32589 .75785 .32981 .7643 .32769 .76144 .32376 Mtetra
.76144 .32376 .7643 .32769 .77076 .32556 .76791 .32162 Mtetra
.76791 .32162 .77076 .32556 .77723 .32343 .77439 .31948 Mtetra
.77439 .31948 .77723 .32343 .78372 .32129 .78089 .31734 Mtetra
.78089 .31734 .78372 .32129 .79022 .31915 .7874 .31519 Mtetra
.7874 .31519 .79022 .31915 .79673 .31701 .79393 .31303 Mtetra
.79393 .31303 .79673 .31701 .80327 .31486 .80047 .31087 Mtetra
.80047 .31087 .80327 .31486 .80981 .3127 .80703 .30871 Mtetra
.80703 .30871 .80981 .3127 .81637 .31054 .8136 .30654 Mtetra
.8136 .30654 .81637 .31054 .82295 .30837 .82018 .30436 Mtetra
.82018 .30436 .82295 .30837 .82954 .3062 .82679 .30218 Mtetra
.82679 .30218 .82954 .3062 .83614 .30403 .8334 .3 Mtetra
.8334 .3 .83614 .30403 .84277 .30185 .84003 .29781 Mtetra
.84003 .29781 .84277 .30185 .8494 .29966 .84668 .29562 Mtetra
.84668 .29562 .8494 .29966 .85605 .29747 .85334 .29342 Mtetra
.85334 .29342 .85605 .29747 .86272 .29528 .86002 .29121 Mtetra
.86002 .29121 .86272 .29528 .8694 .29308 .86671 .289 Mtetra
.86671 .289 .8694 .29308 .8761 .29087 .87342 .28679 Mtetra
.27288 .48059 .27644 .48389 .28186 .4821 .27831 .47879 Mtetra
.27831 .47879 .28186 .4821 .28729 .48031 .28375 .47699 Mtetra
.28375 .47699 .28729 .48031 .29273 .47851 .2892 .47518 Mtetra
.2892 .47518 .29273 .47851 .29818 .47671 .29466 .47338 Mtetra
.29466 .47338 .29818 .47671 .30365 .47491 .30013 .47157 Mtetra
.30013 .47157 .30365 .47491 .30913 .4731 .30561 .46975 Mtetra
.30561 .46975 .30913 .4731 .31461 .47129 .31111 .46793 Mtetra
.31111 .46793 .31461 .47129 .32011 .46947 .31662 .46611 Mtetra
.31662 .46611 .32011 .46947 .32562 .46765 .32213 .46428 Mtetra
.32213 .46428 .32562 .46765 .33115 .46583 .32766 .46245 Mtetra
.32766 .46245 .33115 .46583 .33668 .464 .3332 .46062 Mtetra
.3332 .46062 .33668 .464 .34222 .46217 .33876 .45878 Mtetra
.33876 .45878 .34222 .46217 .34778 .46034 .34432 .45694 Mtetra
.34432 .45694 .34778 .46034 .35335 .4585 .3499 .45509 Mtetra
.3499 .45509 .35335 .4585 .35893 .45665 .35548 .45324 Mtetra
.35548 .45324 .35893 .45665 .36452 .45481 .36108 .45139 Mtetra
.36108 .45139 .36452 .45481 .37013 .45296 .36669 .44953 Mtetra
.36669 .44953 .37013 .45296 .37574 .4511 .37232 .44767 Mtetra
.37232 .44767 .37574 .4511 .38137 .44925 .37795 .44581 Mtetra
.37795 .44581 .38137 .44925 .38701 .44738 .3836 .44394 Mtetra
.3836 .44394 .38701 .44738 .39266 .44552 .38926 .44206 Mtetra
.38926 .44206 .39266 .44552 .39832 .44365 .39493 .44019 Mtetra
.39493 .44019 .39832 .44365 .404 .44178 .40061 .43831 Mtetra
.40061 .43831 .404 .44178 .40968 .4399 .4063 .43642 Mtetra
.4063 .43642 .40968 .4399 .41538 .43802 .41201 .43453 Mtetra
.41201 .43453 .41538 .43802 .42109 .43613 .41773 .43264 Mtetra
.41773 .43264 .42109 .43613 .42682 .43424 .42346 .43074 Mtetra
.42346 .43074 .42682 .43424 .43255 .43235 .4292 .42884 Mtetra
.4292 .42884 .43255 .43235 .4383 .43045 .43496 .42694 Mtetra
.43496 .42694 .4383 .43045 .44406 .42855 .44072 .42503 Mtetra
.44072 .42503 .44406 .42855 .44983 .42664 .4465 .42311 Mtetra
.4465 .42311 .44983 .42664 .45562 .42473 .4523 .4212 Mtetra
.4523 .4212 .45562 .42473 .46141 .42282 .4581 .41927 Mtetra
.4581 .41927 .46141 .42282 .46722 .4209 .46392 .41735 Mtetra
.46392 .41735 .46722 .4209 .47304 .41898 .46975 .41542 Mtetra
.46975 .41542 .47304 .41898 .47888 .41705 .47559 .41349 Mtetra
.47559 .41349 .47888 .41705 .48472 .41512 .48144 .41155 Mtetra
.48144 .41155 .48472 .41512 .49058 .41319 .48731 .40961 Mtetra
.48731 .40961 .49058 .41319 .49645 .41125 .49319 .40766 Mtetra
.49319 .40766 .49645 .41125 .50234 .40931 .49908 .40571 Mtetra
.49908 .40571 .50234 .40931 .50823 .40736 .50499 .40376 Mtetra
.50499 .40376 .50823 .40736 .51414 .40541 .5109 .4018 Mtetra
.5109 .4018 .51414 .40541 .52007 .40345 .51684 .39983 Mtetra
.663 .741 .908 r
.51684 .39983 .52007 .40345 .526 .4015 .52278 .39787 Mtetra
.52278 .39787 .526 .4015 .53195 .39953 .52874 .3959 Mtetra
.52874 .3959 .53195 .39953 .53791 .39757 .5347 .39392 Mtetra
.5347 .39392 .53791 .39757 .54388 .3956 .54069 .39195 Mtetra
.662 .741 .909 r
.54069 .39195 .54388 .3956 .54987 .39365 .54668 .39 Mtetra
.639 .733 .917 r
.54668 .39 .54987 .39365 .55587 .39197 .55269 .38838 Mtetra
.664 .746 .912 r
.55269 .38838 .55587 .39197 .56189 .38998 .55872 .38639 Mtetra
.686 .753 .902 r
.55872 .38639 .56189 .38998 .56791 .38769 .56475 .38402 Mtetra
.665 .742 .908 r
.56475 .38402 .56791 .38769 .57395 .38568 .57079 .38199 Mtetra
.664 .742 .908 r
.57079 .38199 .57395 .38568 .58 .38367 .57685 .37997 Mtetra
.664 .741 .908 r
.57685 .37997 .58 .38367 .58606 .38167 .58293 .37796 Mtetra
.58293 .37796 .58606 .38167 .59214 .37966 .58902 .37594 Mtetra
.58902 .37594 .59214 .37966 .59823 .37765 .59512 .37392 Mtetra
.59512 .37392 .59823 .37765 .60434 .37563 .60123 .3719 Mtetra
.60123 .3719 .60434 .37563 .61046 .37361 .60736 .36987 Mtetra
.60736 .36987 .61046 .37361 .61659 .37158 .6135 .36784 Mtetra
.6135 .36784 .61659 .37158 .62274 .36956 .61965 .3658 Mtetra
.61965 .3658 .62274 .36956 .6289 .36752 .62582 .36376 Mtetra
.62582 .36376 .6289 .36752 .63507 .36548 .632 .36171 Mtetra
.632 .36171 .63507 .36548 .64125 .36344 .6382 .35966 Mtetra
.6382 .35966 .64125 .36344 .64745 .36139 .64441 .3576 Mtetra
.64441 .3576 .64745 .36139 .65367 .35934 .65063 .35554 Mtetra
.65063 .35554 .65367 .35934 .65989 .35729 .65687 .35348 Mtetra
.65687 .35348 .65989 .35729 .66614 .35523 .66312 .35141 Mtetra
.66312 .35141 .66614 .35523 .67239 .35316 .66938 .34934 Mtetra
.66938 .34934 .67239 .35316 .67866 .35109 .67566 .34726 Mtetra
.67566 .34726 .67866 .35109 .68494 .34902 .68195 .34517 Mtetra
.68195 .34517 .68494 .34902 .69124 .34694 .68826 .34309 Mtetra
.68826 .34309 .69124 .34694 .69755 .34485 .69458 .34099 Mtetra
.69458 .34099 .69755 .34485 .70388 .34277 .70092 .3389 Mtetra
.70092 .3389 .70388 .34277 .71021 .34067 .70726 .3368 Mtetra
.70726 .3368 .71021 .34067 .71657 .33857 .71363 .33469 Mtetra
.71363 .33469 .71657 .33857 .72293 .33647 .72 .33258 Mtetra
.72 .33258 .72293 .33647 .72932 .33437 .7264 .33046 Mtetra
.7264 .33046 .72932 .33437 .73571 .33225 .7328 .32834 Mtetra
.7328 .32834 .73571 .33225 .74212 .33014 .73922 .32622 Mtetra
.73922 .32622 .74212 .33014 .74855 .32802 .74566 .32409 Mtetra
.74566 .32409 .74855 .32802 .75499 .32589 .75211 .32195 Mtetra
.75211 .32195 .75499 .32589 .76144 .32376 .75857 .31981 Mtetra
.75857 .31981 .76144 .32376 .76791 .32162 .76505 .31767 Mtetra
.76505 .31767 .76791 .32162 .77439 .31948 .77154 .31552 Mtetra
.77154 .31552 .77439 .31948 .78089 .31734 .77805 .31336 Mtetra
.77805 .31336 .78089 .31734 .7874 .31519 .78457 .31121 Mtetra
.78457 .31121 .7874 .31519 .79393 .31303 .79111 .30904 Mtetra
.79111 .30904 .79393 .31303 .80047 .31087 .79766 .30687 Mtetra
.79766 .30687 .80047 .31087 .80703 .30871 .80423 .3047 Mtetra
.80423 .3047 .80703 .30871 .8136 .30654 .81081 .30252 Mtetra
.81081 .30252 .8136 .30654 .82018 .30436 .81741 .30034 Mtetra
.81741 .30034 .82018 .30436 .82679 .30218 .82402 .29815 Mtetra
.82402 .29815 .82679 .30218 .8334 .3 .83065 .29595 Mtetra
.83065 .29595 .8334 .3 .84003 .29781 .83729 .29375 Mtetra
.83729 .29375 .84003 .29781 .84668 .29562 .84395 .29155 Mtetra
.84395 .29155 .84668 .29562 .85334 .29342 .85062 .28934 Mtetra
.85062 .28934 .85334 .29342 .86002 .29121 .85731 .28713 Mtetra
.85731 .28713 .86002 .29121 .86671 .289 .86401 .28491 Mtetra
.86401 .28491 .86671 .289 .87342 .28679 .87073 .28268 Mtetra
.26932 .47727 .27288 .48059 .27831 .47879 .27475 .47546 Mtetra
.27475 .47546 .27831 .47879 .28375 .47699 .2802 .47366 Mtetra
.2802 .47366 .28375 .47699 .2892 .47518 .28565 .47184 Mtetra
.28565 .47184 .2892 .47518 .29466 .47338 .29112 .47003 Mtetra
.29112 .47003 .29466 .47338 .30013 .47157 .2966 .46821 Mtetra
.2966 .46821 .30013 .47157 .30561 .46975 .30209 .46639 Mtetra
.30209 .46639 .30561 .46975 .31111 .46793 .30759 .46456 Mtetra
.30759 .46456 .31111 .46793 .31662 .46611 .31311 .46273 Mtetra
.31311 .46273 .31662 .46611 .32213 .46428 .31863 .4609 Mtetra
.31863 .4609 .32213 .46428 .32766 .46245 .32417 .45906 Mtetra
.32417 .45906 .32766 .46245 .3332 .46062 .32971 .45722 Mtetra
.32971 .45722 .3332 .46062 .33876 .45878 .33527 .45538 Mtetra
.33527 .45538 .33876 .45878 .34432 .45694 .34084 .45353 Mtetra
.34084 .45353 .34432 .45694 .3499 .45509 .34643 .45168 Mtetra
.34643 .45168 .3499 .45509 .35548 .45324 .35202 .44982 Mtetra
.35202 .44982 .35548 .45324 .36108 .45139 .35763 .44796 Mtetra
.35763 .44796 .36108 .45139 .36669 .44953 .36325 .44609 Mtetra
.36325 .44609 .36669 .44953 .37232 .44767 .36888 .44422 Mtetra
.36888 .44422 .37232 .44767 .37795 .44581 .37452 .44235 Mtetra
.37452 .44235 .37795 .44581 .3836 .44394 .38017 .44048 Mtetra
.38017 .44048 .3836 .44394 .38926 .44206 .38584 .4386 Mtetra
.38584 .4386 .38926 .44206 .39493 .44019 .39152 .43671 Mtetra
.39152 .43671 .39493 .44019 .40061 .43831 .39721 .43482 Mtetra
.39721 .43482 .40061 .43831 .4063 .43642 .40291 .43293 Mtetra
.40291 .43293 .4063 .43642 .41201 .43453 .40862 .43103 Mtetra
.40862 .43103 .41201 .43453 .41773 .43264 .41435 .42913 Mtetra
.41435 .42913 .41773 .43264 .42346 .43074 .42009 .42723 Mtetra
.42009 .42723 .42346 .43074 .4292 .42884 .42584 .42532 Mtetra
.42584 .42532 .4292 .42884 .43496 .42694 .4316 .42341 Mtetra
.4316 .42341 .43496 .42694 .44072 .42503 .43738 .42149 Mtetra
.43738 .42149 .44072 .42503 .4465 .42311 .44316 .41957 Mtetra
.44316 .41957 .4465 .42311 .4523 .4212 .44896 .41765 Mtetra
.44896 .41765 .4523 .4212 .4581 .41927 .45478 .41572 Mtetra
.45478 .41572 .4581 .41927 .46392 .41735 .4606 .41378 Mtetra
.4606 .41378 .46392 .41735 .46975 .41542 .46644 .41185 Mtetra
.46644 .41185 .46975 .41542 .47559 .41349 .47229 .40991 Mtetra
.47229 .40991 .47559 .41349 .48144 .41155 .47815 .40796 Mtetra
.47815 .40796 .48144 .41155 .48731 .40961 .48403 .40601 Mtetra
.48403 .40601 .48731 .40961 .49319 .40766 .48991 .40406 Mtetra
.48991 .40406 .49319 .40766 .49908 .40571 .49581 .4021 Mtetra
.49581 .4021 .49908 .40571 .50499 .40376 .50173 .40014 Mtetra
.50173 .40014 .50499 .40376 .5109 .4018 .50765 .39817 Mtetra
.50765 .39817 .5109 .4018 .51684 .39983 .51359 .3962 Mtetra
.663 .741 .908 r
.51359 .3962 .51684 .39983 .52278 .39787 .51954 .39423 Mtetra
.51954 .39423 .52278 .39787 .52874 .3959 .52551 .39225 Mtetra
.52551 .39225 .52874 .3959 .5347 .39392 .53149 .39027 Mtetra
.53149 .39027 .5347 .39392 .54069 .39195 .53748 .38829 Mtetra
.661 .741 .909 r
.53748 .38829 .54069 .39195 .54668 .39 .54348 .38634 Mtetra
.631 .731 .919 r
.54348 .38634 .54668 .39 .55269 .38838 .5495 .38481 Mtetra
.664 .748 .913 r
.5495 .38481 .55269 .38838 .55872 .38639 .55553 .38281 Mtetra
.692 .757 .901 r
.55553 .38281 .55872 .38639 .56475 .38402 .56157 .38033 Mtetra
.666 .743 .908 r
.56157 .38033 .56475 .38402 .57079 .38199 .56763 .37828 Mtetra
.664 .742 .908 r
.56763 .37828 .57079 .38199 .57685 .37997 .5737 .37626 Mtetra
.5737 .37626 .57685 .37997 .58293 .37796 .57978 .37424 Mtetra
.664 .741 .908 r
.57978 .37424 .58293 .37796 .58902 .37594 .58588 .37221 Mtetra
.58588 .37221 .58902 .37594 .59512 .37392 .59199 .37018 Mtetra
.59199 .37018 .59512 .37392 .60123 .3719 .59811 .36815 Mtetra
.59811 .36815 .60123 .3719 .60736 .36987 .60425 .36611 Mtetra
.60425 .36611 .60736 .36987 .6135 .36784 .6104 .36407 Mtetra
.6104 .36407 .6135 .36784 .61965 .3658 .61656 .36202 Mtetra
.61656 .36202 .61965 .3658 .62582 .36376 .62274 .35997 Mtetra
.62274 .35997 .62582 .36376 .632 .36171 .62893 .35792 Mtetra
.62893 .35792 .632 .36171 .6382 .35966 .63513 .35586 Mtetra
.63513 .35586 .6382 .35966 .64441 .3576 .64135 .3538 Mtetra
.64135 .3538 .64441 .3576 .65063 .35554 .64758 .35173 Mtetra
.64758 .35173 .65063 .35554 .65687 .35348 .65383 .34966 Mtetra
.65383 .34966 .65687 .35348 .66312 .35141 .66009 .34758 Mtetra
.66009 .34758 .66312 .35141 .66938 .34934 .66636 .3455 Mtetra
.66636 .3455 .66938 .34934 .67566 .34726 .67265 .34341 Mtetra
.67265 .34341 .67566 .34726 .68195 .34517 .67895 .34132 Mtetra
.67895 .34132 .68195 .34517 .68826 .34309 .68527 .33922 Mtetra
.68527 .33922 .68826 .34309 .69458 .34099 .6916 .33712 Mtetra
.6916 .33712 .69458 .34099 .70092 .3389 .69794 .33501 Mtetra
.69794 .33501 .70092 .3389 .70726 .3368 .7043 .3329 Mtetra
.7043 .3329 .70726 .3368 .71363 .33469 .71068 .33079 Mtetra
.71068 .33079 .71363 .33469 .72 .33258 .71706 .32867 Mtetra
.71706 .32867 .72 .33258 .7264 .33046 .72346 .32654 Mtetra
.72346 .32654 .7264 .33046 .7328 .32834 .72988 .32442 Mtetra
.72988 .32442 .7328 .32834 .73922 .32622 .73631 .32228 Mtetra
.73631 .32228 .73922 .32622 .74566 .32409 .74276 .32014 Mtetra
.74276 .32014 .74566 .32409 .75211 .32195 .74922 .318 Mtetra
.74922 .318 .75211 .32195 .75857 .31981 .75569 .31585 Mtetra
.75569 .31585 .75857 .31981 .76505 .31767 .76218 .3137 Mtetra
.76218 .3137 .76505 .31767 .77154 .31552 .76868 .31154 Mtetra
.76868 .31154 .77154 .31552 .77805 .31336 .7752 .30937 Mtetra
.7752 .30937 .77805 .31336 .78457 .31121 .78173 .30721 Mtetra
.78173 .30721 .78457 .31121 .79111 .30904 .78828 .30503 Mtetra
.78828 .30503 .79111 .30904 .79766 .30687 .79484 .30286 Mtetra
.79484 .30286 .79766 .30687 .80423 .3047 .80142 .30067 Mtetra
.80142 .30067 .80423 .3047 .81081 .30252 .80801 .29848 Mtetra
.80801 .29848 .81081 .30252 .81741 .30034 .81462 .29629 Mtetra
.81462 .29629 .81741 .30034 .82402 .29815 .82125 .29409 Mtetra
.82125 .29409 .82402 .29815 .83065 .29595 .82788 .29189 Mtetra
.82788 .29189 .83065 .29595 .83729 .29375 .83454 .28968 Mtetra
.83454 .28968 .83729 .29375 .84395 .29155 .84121 .28747 Mtetra
.84121 .28747 .84395 .29155 .85062 .28934 .84789 .28525 Mtetra
.84789 .28525 .85062 .28934 .85731 .28713 .85459 .28303 Mtetra
.85459 .28303 .85731 .28713 .86401 .28491 .8613 .2808 Mtetra
.8613 .2808 .86401 .28491 .87073 .28268 .86803 .27857 Mtetra
.26574 .47393 .26932 .47727 .27475 .47546 .27118 .47212 Mtetra
.27118 .47212 .27475 .47546 .2802 .47366 .27663 .47031 Mtetra
.27663 .47031 .2802 .47366 .28565 .47184 .2821 .46849 Mtetra
.2821 .46849 .28565 .47184 .29112 .47003 .28757 .46667 Mtetra
.28757 .46667 .29112 .47003 .2966 .46821 .29306 .46484 Mtetra
.29306 .46484 .2966 .46821 .30209 .46639 .29855 .46302 Mtetra
.29855 .46302 .30209 .46639 .30759 .46456 .30406 .46118 Mtetra
.30406 .46118 .30759 .46456 .31311 .46273 .30958 .45935 Mtetra
.30958 .45935 .31311 .46273 .31863 .4609 .31511 .45751 Mtetra
.31511 .45751 .31863 .4609 .32417 .45906 .32066 .45566 Mtetra
.32066 .45566 .32417 .45906 .32971 .45722 .32621 .45381 Mtetra
.32621 .45381 .32971 .45722 .33527 .45538 .33178 .45196 Mtetra
.33178 .45196 .33527 .45538 .34084 .45353 .33736 .4501 Mtetra
.33736 .4501 .34084 .45353 .34643 .45168 .34295 .44824 Mtetra
.34295 .44824 .34643 .45168 .35202 .44982 .34855 .44638 Mtetra
.34855 .44638 .35202 .44982 .35763 .44796 .35416 .44451 Mtetra
.35416 .44451 .35763 .44796 .36325 .44609 .35979 .44264 Mtetra
.35979 .44264 .36325 .44609 .36888 .44422 .36542 .44076 Mtetra
.36542 .44076 .36888 .44422 .37452 .44235 .37107 .43889 Mtetra
.37107 .43889 .37452 .44235 .38017 .44048 .37674 .437 Mtetra
.37674 .437 .38017 .44048 .38584 .4386 .38241 .43511 Mtetra
.38241 .43511 .38584 .4386 .39152 .43671 .38809 .43322 Mtetra
.38809 .43322 .39152 .43671 .39721 .43482 .39379 .43133 Mtetra
.39379 .43133 .39721 .43482 .40291 .43293 .3995 .42943 Mtetra
.3995 .42943 .40291 .43293 .40862 .43103 .40522 .42752 Mtetra
.40522 .42752 .40862 .43103 .41435 .42913 .41096 .42561 Mtetra
.41096 .42561 .41435 .42913 .42009 .42723 .4167 .4237 Mtetra
.4167 .4237 .42009 .42723 .42584 .42532 .42246 .42179 Mtetra
.42246 .42179 .42584 .42532 .4316 .42341 .42823 .41987 Mtetra
.42823 .41987 .4316 .42341 .43738 .42149 .43401 .41794 Mtetra
.43401 .41794 .43738 .42149 .44316 .41957 .43981 .41601 Mtetra
.43981 .41601 .44316 .41957 .44896 .41765 .44562 .41408 Mtetra
.44562 .41408 .44896 .41765 .45478 .41572 .45144 .41214 Mtetra
.45144 .41214 .45478 .41572 .4606 .41378 .45727 .4102 Mtetra
.45727 .4102 .4606 .41378 .46644 .41185 .46312 .40826 Mtetra
.46312 .40826 .46644 .41185 .47229 .40991 .46897 .40631 Mtetra
.46897 .40631 .47229 .40991 .47815 .40796 .47484 .40436 Mtetra
.47484 .40436 .47815 .40796 .48403 .40601 .48073 .4024 Mtetra
.48073 .4024 .48403 .40601 .48991 .40406 .48662 .40044 Mtetra
.48662 .40044 .48991 .40406 .49581 .4021 .49253 .39847 Mtetra
.49253 .39847 .49581 .4021 .50173 .40014 .49845 .3965 Mtetra
.49845 .3965 .50173 .40014 .50765 .39817 .50439 .39453 Mtetra
.663 .741 .908 r
.50439 .39453 .50765 .39817 .51359 .3962 .51034 .39255 Mtetra
.51034 .39255 .51359 .3962 .51954 .39423 .5163 .39057 Mtetra
.5163 .39057 .51954 .39423 .52551 .39225 .52227 .38858 Mtetra
.52227 .38858 .52551 .39225 .53149 .39027 .52826 .3866 Mtetra
.52826 .3866 .53149 .39027 .53748 .38829 .53426 .38461 Mtetra
.66 .741 .909 r
.53426 .38461 .53748 .38829 .54348 .38634 .54027 .38266 Mtetra
.62 .727 .923 r
.54027 .38266 .54348 .38634 .5495 .38481 .5463 .38129 Mtetra
.663 .752 .916 r
.5463 .38129 .5495 .38481 .55553 .38281 .55234 .37928 Mtetra
.702 .763 .9 r
.55234 .37928 .55553 .38281 .56157 .38033 .55838 .37664 Mtetra
.667 .743 .908 r
.55838 .37664 .56157 .38033 .56763 .37828 .56445 .37457 Mtetra
.664 .742 .908 r
.56445 .37457 .56763 .37828 .5737 .37626 .57053 .37253 Mtetra
.57053 .37253 .5737 .37626 .57978 .37424 .57662 .3705 Mtetra
.664 .741 .908 r
.57662 .3705 .57978 .37424 .58588 .37221 .58272 .36847 Mtetra
.58272 .36847 .58588 .37221 .59199 .37018 .58884 .36643 Mtetra
.58884 .36643 .59199 .37018 .59811 .36815 .59497 .36439 Mtetra
.59497 .36439 .59811 .36815 .60425 .36611 .60112 .36234 Mtetra
.60112 .36234 .60425 .36611 .6104 .36407 .60728 .36029 Mtetra
.60728 .36029 .6104 .36407 .61656 .36202 .61345 .35824 Mtetra
.61345 .35824 .61656 .36202 .62274 .35997 .61964 .35618 Mtetra
.61964 .35618 .62274 .35997 .62893 .35792 .62584 .35411 Mtetra
.62584 .35411 .62893 .35792 .63513 .35586 .63205 .35205 Mtetra
.63205 .35205 .63513 .35586 .64135 .3538 .63828 .34997 Mtetra
.63828 .34997 .64135 .3538 .64758 .35173 .64452 .3479 Mtetra
.64452 .3479 .64758 .35173 .65383 .34966 .65078 .34582 Mtetra
.65078 .34582 .65383 .34966 .66009 .34758 .65705 .34373 Mtetra
.65705 .34373 .66009 .34758 .66636 .3455 .66333 .34164 Mtetra
.66333 .34164 .66636 .3455 .67265 .34341 .66963 .33954 Mtetra
.66963 .33954 .67265 .34341 .67895 .34132 .67594 .33744 Mtetra
.67594 .33744 .67895 .34132 .68527 .33922 .68227 .33534 Mtetra
.68227 .33534 .68527 .33922 .6916 .33712 .68861 .33323 Mtetra
.68861 .33323 .6916 .33712 .69794 .33501 .69496 .33111 Mtetra
.69496 .33111 .69794 .33501 .7043 .3329 .70133 .329 Mtetra
.70133 .329 .7043 .3329 .71068 .33079 .70771 .32687 Mtetra
.70771 .32687 .71068 .33079 .71706 .32867 .71411 .32474 Mtetra
.71411 .32474 .71706 .32867 .72346 .32654 .72052 .32261 Mtetra
.72052 .32261 .72346 .32654 .72988 .32442 .72695 .32047 Mtetra
.72695 .32047 .72988 .32442 .73631 .32228 .73339 .31833 Mtetra
.73339 .31833 .73631 .32228 .74276 .32014 .73984 .31618 Mtetra
.73984 .31618 .74276 .32014 .74922 .318 .74631 .31403 Mtetra
.74631 .31403 .74922 .318 .75569 .31585 .7528 .31187 Mtetra
.7528 .31187 .75569 .31585 .76218 .3137 .7593 .30971 Mtetra
.7593 .30971 .76218 .3137 .76868 .31154 .76581 .30754 Mtetra
.76581 .30754 .76868 .31154 .7752 .30937 .77234 .30537 Mtetra
.77234 .30537 .7752 .30937 .78173 .30721 .77888 .30319 Mtetra
.77888 .30319 .78173 .30721 .78828 .30503 .78544 .30101 Mtetra
.78544 .30101 .78828 .30503 .79484 .30286 .79201 .29882 Mtetra
.79201 .29882 .79484 .30286 .80142 .30067 .7986 .29663 Mtetra
.7986 .29663 .80142 .30067 .80801 .29848 .8052 .29443 Mtetra
.8052 .29443 .80801 .29848 .81462 .29629 .81182 .29223 Mtetra
.81182 .29223 .81462 .29629 .82125 .29409 .81846 .29002 Mtetra
.81846 .29002 .82125 .29409 .82788 .29189 .82511 .28781 Mtetra
.82511 .28781 .82788 .29189 .83454 .28968 .83177 .28559 Mtetra
.83177 .28559 .83454 .28968 .84121 .28747 .83845 .28337 Mtetra
.83845 .28337 .84121 .28747 .84789 .28525 .84515 .28114 Mtetra
.84515 .28114 .84789 .28525 .85459 .28303 .85186 .27891 Mtetra
.85186 .27891 .85459 .28303 .8613 .2808 .85858 .27667 Mtetra
.85858 .27667 .8613 .2808 .86803 .27857 .86532 .27443 Mtetra
.26215 .47059 .26574 .47393 .27118 .47212 .2676 .46877 Mtetra
.2676 .46877 .27118 .47212 .27663 .47031 .27305 .46695 Mtetra
.27305 .46695 .27663 .47031 .2821 .46849 .27852 .46513 Mtetra
.27852 .46513 .2821 .46849 .28757 .46667 .284 .4633 Mtetra
.284 .4633 .28757 .46667 .29306 .46484 .2895 .46147 Mtetra
.2895 .46147 .29306 .46484 .29855 .46302 .295 .45963 Mtetra
.295 .45963 .29855 .46302 .30406 .46118 .30052 .45779 Mtetra
.30052 .45779 .30406 .46118 .30958 .45935 .30604 .45595 Mtetra
.30604 .45595 .30958 .45935 .31511 .45751 .31158 .4541 Mtetra
.31158 .4541 .31511 .45751 .32066 .45566 .31713 .45225 Mtetra
.31713 .45225 .32066 .45566 .32621 .45381 .32269 .45039 Mtetra
.32269 .45039 .32621 .45381 .33178 .45196 .32827 .44853 Mtetra
.32827 .44853 .33178 .45196 .33736 .4501 .33385 .44667 Mtetra
.33385 .44667 .33736 .4501 .34295 .44824 .33945 .4448 Mtetra
.33945 .4448 .34295 .44824 .34855 .44638 .34506 .44293 Mtetra
.34506 .44293 .34855 .44638 .35416 .44451 .35068 .44105 Mtetra
.35068 .44105 .35416 .44451 .35979 .44264 .35631 .43917 Mtetra
.35631 .43917 .35979 .44264 .36542 .44076 .36196 .43729 Mtetra
.36196 .43729 .36542 .44076 .37107 .43889 .36762 .4354 Mtetra
.36762 .4354 .37107 .43889 .37674 .437 .37328 .43351 Mtetra
.37328 .43351 .37674 .437 .38241 .43511 .37896 .43162 Mtetra
.37896 .43162 .38241 .43511 .38809 .43322 .38466 .42972 Mtetra
.38466 .42972 .38809 .43322 .39379 .43133 .39036 .42782 Mtetra
.39036 .42782 .39379 .43133 .3995 .42943 .39608 .42591 Mtetra
.39608 .42591 .3995 .42943 .40522 .42752 .40181 .424 Mtetra
.40181 .424 .40522 .42752 .41096 .42561 .40755 .42208 Mtetra
.40755 .42208 .41096 .42561 .4167 .4237 .4133 .42016 Mtetra
.4133 .42016 .4167 .4237 .42246 .42179 .41907 .41824 Mtetra
.41907 .41824 .42246 .42179 .42823 .41987 .42485 .41631 Mtetra
.42485 .41631 .42823 .41987 .43401 .41794 .43064 .41438 Mtetra
.43064 .41438 .43401 .41794 .43981 .41601 .43644 .41244 Mtetra
.43644 .41244 .43981 .41601 .44562 .41408 .44226 .4105 Mtetra
.44226 .4105 .44562 .41408 .45144 .41214 .44809 .40856 Mtetra
.44809 .40856 .45144 .41214 .45727 .4102 .45393 .40661 Mtetra
.45393 .40661 .45727 .4102 .46312 .40826 .45978 .40466 Mtetra
.45978 .40466 .46312 .40826 .46897 .40631 .46565 .4027 Mtetra
.46565 .4027 .46897 .40631 .47484 .40436 .47153 .40074 Mtetra
.47153 .40074 .47484 .40436 .48073 .4024 .47742 .39877 Mtetra
.47742 .39877 .48073 .4024 .48662 .40044 .48332 .39681 Mtetra
.48332 .39681 .48662 .40044 .49253 .39847 .48924 .39483 Mtetra
.48924 .39483 .49253 .39847 .49845 .3965 .49517 .39285 Mtetra
.663 .741 .908 r
.49517 .39285 .49845 .3965 .50439 .39453 .50111 .39087 Mtetra
.50111 .39087 .50439 .39453 .51034 .39255 .50707 .38889 Mtetra
.50707 .38889 .51034 .39255 .5163 .39057 .51304 .3869 Mtetra
.51304 .3869 .5163 .39057 .52227 .38858 .51902 .38491 Mtetra
.51902 .38491 .52227 .38858 .52826 .3866 .52501 .38291 Mtetra
.662 .741 .909 r
.52501 .38291 .52826 .3866 .53426 .38461 .53102 .38093 Mtetra
.659 .74 .91 r
.53102 .38093 .53426 .38461 .54027 .38266 .53704 .37899 Mtetra
.601 .721 .929 r
.53704 .37899 .54027 .38266 .5463 .38129 .54308 .37785 Mtetra
.663 .758 .92 r
.54308 .37785 .5463 .38129 .55234 .37928 .54913 .37583 Mtetra
.715 .772 .897 r
.54913 .37583 .55234 .37928 .55838 .37664 .55518 .37294 Mtetra
.668 .744 .908 r
.55518 .37294 .55838 .37664 .56445 .37457 .56126 .37084 Mtetra
.665 .742 .908 r
.56126 .37084 .56445 .37457 .57053 .37253 .56734 .36879 Mtetra
.664 .742 .908 r
.56734 .36879 .57053 .37253 .57662 .3705 .57344 .36675 Mtetra
.57344 .36675 .57662 .3705 .58272 .36847 .57956 .3647 Mtetra
.664 .741 .908 r
.57956 .3647 .58272 .36847 .58884 .36643 .58569 .36266 Mtetra
.58569 .36266 .58884 .36643 .59497 .36439 .59183 .36061 Mtetra
.59183 .36061 .59497 .36439 .60112 .36234 .59798 .35855 Mtetra
.59798 .35855 .60112 .36234 .60728 .36029 .60415 .3565 Mtetra
.60415 .3565 .60728 .36029 .61345 .35824 .61033 .35443 Mtetra
.61033 .35443 .61345 .35824 .61964 .35618 .61653 .35237 Mtetra
.61653 .35237 .61964 .35618 .62584 .35411 .62274 .35029 Mtetra
.62274 .35029 .62584 .35411 .63205 .35205 .62896 .34822 Mtetra
.62896 .34822 .63205 .35205 .63828 .34997 .6352 .34614 Mtetra
.6352 .34614 .63828 .34997 .64452 .3479 .64145 .34405 Mtetra
.64145 .34405 .64452 .3479 .65078 .34582 .64771 .34196 Mtetra
.64771 .34196 .65078 .34582 .65705 .34373 .65399 .33987 Mtetra
.65399 .33987 .65705 .34373 .66333 .34164 .66029 .33777 Mtetra
.66029 .33777 .66333 .34164 .66963 .33954 .66659 .33566 Mtetra
.66659 .33566 .66963 .33954 .67594 .33744 .67292 .33355 Mtetra
.67292 .33355 .67594 .33744 .68227 .33534 .67925 .33144 Mtetra
.67925 .33144 .68227 .33534 .68861 .33323 .6856 .32932 Mtetra
.6856 .32932 .68861 .33323 .69496 .33111 .69196 .3272 Mtetra
.69196 .3272 .69496 .33111 .70133 .329 .69834 .32507 Mtetra
.69834 .32507 .70133 .329 .70771 .32687 .70474 .32294 Mtetra
.70474 .32294 .70771 .32687 .71411 .32474 .71114 .3208 Mtetra
.71114 .3208 .71411 .32474 .72052 .32261 .71756 .31866 Mtetra
.71756 .31866 .72052 .32261 .72695 .32047 .724 .31651 Mtetra
.724 .31651 .72695 .32047 .73339 .31833 .73045 .31436 Mtetra
.73045 .31436 .73339 .31833 .73984 .31618 .73692 .3122 Mtetra
.73692 .3122 .73984 .31618 .74631 .31403 .7434 .31004 Mtetra
.7434 .31004 .74631 .31403 .7528 .31187 .74989 .30787 Mtetra
.74989 .30787 .7528 .31187 .7593 .30971 .7564 .3057 Mtetra
.7564 .3057 .7593 .30971 .76581 .30754 .76292 .30353 Mtetra
.76292 .30353 .76581 .30754 .77234 .30537 .76946 .30134 Mtetra
.76946 .30134 .77234 .30537 .77888 .30319 .77602 .29916 Mtetra
.77602 .29916 .77888 .30319 .78544 .30101 .78259 .29697 Mtetra
.78259 .29697 .78544 .30101 .79201 .29882 .78917 .29477 Mtetra
.78917 .29477 .79201 .29882 .7986 .29663 .79577 .29257 Mtetra
.79577 .29257 .7986 .29663 .8052 .29443 .80238 .29036 Mtetra
.80238 .29036 .8052 .29443 .81182 .29223 .80901 .28815 Mtetra
.80901 .28815 .81182 .29223 .81846 .29002 .81566 .28593 Mtetra
.81566 .28593 .81846 .29002 .82511 .28781 .82232 .28371 Mtetra
.82232 .28371 .82511 .28781 .83177 .28559 .82899 .28149 Mtetra
.82899 .28149 .83177 .28559 .83845 .28337 .83568 .27925 Mtetra
.83568 .27925 .83845 .28337 .84515 .28114 .84239 .27702 Mtetra
.84239 .27702 .84515 .28114 .85186 .27891 .84911 .27477 Mtetra
.84911 .27477 .85186 .27891 .85858 .27667 .85585 .27253 Mtetra
.85585 .27253 .85858 .27667 .86532 .27443 .8626 .27027 Mtetra
.25854 .46723 .26215 .47059 .2676 .46877 .264 .46541 Mtetra
.264 .46541 .2676 .46877 .27305 .46695 .26946 .46358 Mtetra
.26946 .46358 .27305 .46695 .27852 .46513 .27494 .46175 Mtetra
.27494 .46175 .27852 .46513 .284 .4633 .28043 .45991 Mtetra
.28043 .45991 .284 .4633 .2895 .46147 .28592 .45807 Mtetra
.28592 .45807 .2895 .46147 .295 .45963 .29144 .45623 Mtetra
.29144 .45623 .295 .45963 .30052 .45779 .29696 .45438 Mtetra
.29696 .45438 .30052 .45779 .30604 .45595 .30249 .45253 Mtetra
.30249 .45253 .30604 .45595 .31158 .4541 .30804 .45068 Mtetra
.30804 .45068 .31158 .4541 .31713 .45225 .3136 .44882 Mtetra
.3136 .44882 .31713 .45225 .32269 .45039 .31916 .44695 Mtetra
.31916 .44695 .32269 .45039 .32827 .44853 .32475 .44509 Mtetra
.32475 .44509 .32827 .44853 .33385 .44667 .33034 .44322 Mtetra
.33034 .44322 .33385 .44667 .33945 .4448 .33594 .44134 Mtetra
.33594 .44134 .33945 .4448 .34506 .44293 .34156 .43946 Mtetra
.34156 .43946 .34506 .44293 .35068 .44105 .34719 .43758 Mtetra
.34719 .43758 .35068 .44105 .35631 .43917 .35283 .43569 Mtetra
.35283 .43569 .35631 .43917 .36196 .43729 .35848 .4338 Mtetra
.35848 .4338 .36196 .43729 .36762 .4354 .36414 .43191 Mtetra
.36414 .43191 .36762 .4354 .37328 .43351 .36982 .43001 Mtetra
.36982 .43001 .37328 .43351 .37896 .43162 .37551 .42811 Mtetra
.37551 .42811 .37896 .43162 .38466 .42972 .38121 .4262 Mtetra
.38121 .4262 .38466 .42972 .39036 .42782 .38692 .42429 Mtetra
.38692 .42429 .39036 .42782 .39608 .42591 .39264 .42238 Mtetra
.39264 .42238 .39608 .42591 .40181 .424 .39838 .42046 Mtetra
.39838 .42046 .40181 .424 .40755 .42208 .40413 .41854 Mtetra
.40413 .41854 .40755 .42208 .4133 .42016 .40989 .41661 Mtetra
.40989 .41661 .4133 .42016 .41907 .41824 .41567 .41468 Mtetra
.41567 .41468 .41907 .41824 .42485 .41631 .42145 .41274 Mtetra
.42145 .41274 .42485 .41631 .43064 .41438 .42725 .4108 Mtetra
.42725 .4108 .43064 .41438 .43644 .41244 .43306 .40886 Mtetra
.43306 .40886 .43644 .41244 .44226 .4105 .43889 .40691 Mtetra
.43889 .40691 .44226 .4105 .44809 .40856 .44472 .40496 Mtetra
.44472 .40496 .44809 .40856 .45393 .40661 .45057 .403 Mtetra
.45057 .403 .45393 .40661 .45978 .40466 .45643 .40104 Mtetra
.45643 .40104 .45978 .40466 .46565 .4027 .46231 .39908 Mtetra
.46231 .39908 .46565 .4027 .47153 .40074 .46819 .39711 Mtetra
.46819 .39711 .47153 .40074 .47742 .39877 .47409 .39514 Mtetra
.47409 .39514 .47742 .39877 .48332 .39681 .48001 .39316 Mtetra
.48001 .39316 .48332 .39681 .48924 .39483 .48593 .39118 Mtetra
.663 .741 .908 r
.48593 .39118 .48924 .39483 .49517 .39285 .49187 .38919 Mtetra
.49187 .38919 .49517 .39285 .50111 .39087 .49782 .3872 Mtetra
.49782 .3872 .50111 .39087 .50707 .38889 .50378 .38521 Mtetra
.50378 .38521 .50707 .38889 .51304 .3869 .50976 .38321 Mtetra
.50976 .38321 .51304 .3869 .51902 .38491 .51575 .38122 Mtetra
.51575 .38122 .51902 .38491 .52501 .38291 .52175 .37922 Mtetra
.662 .741 .909 r
.52175 .37922 .52501 .38291 .53102 .38093 .52777 .37723 Mtetra
.657 .74 .911 r
.52777 .37723 .53102 .38093 .53704 .37899 .5338 .37532 Mtetra
.567 .708 .937 r
.5338 .37532 .53704 .37899 .54308 .37785 .53985 .37457 Mtetra
.663 .769 .928 r
.53985 .37457 .54308 .37785 .54913 .37583 .54591 .37254 Mtetra
.737 .788 .893 r
.54591 .37254 .54913 .37583 .55518 .37294 .55197 .36924 Mtetra
.67 .746 .908 r
.55197 .36924 .55518 .37294 .56126 .37084 .55805 .36711 Mtetra
.665 .743 .908 r
.55805 .36711 .56126 .37084 .56734 .36879 .56415 .36504 Mtetra
.664 .742 .908 r
.56415 .36504 .56734 .36879 .57344 .36675 .57026 .36298 Mtetra
.57026 .36298 .57344 .36675 .57956 .3647 .57638 .36093 Mtetra
.57638 .36093 .57956 .3647 .58569 .36266 .58252 .35887 Mtetra
.664 .741 .908 r
.58252 .35887 .58569 .36266 .59183 .36061 .58867 .35682 Mtetra
.58867 .35682 .59183 .36061 .59798 .35855 .59483 .35475 Mtetra
.59483 .35475 .59798 .35855 .60415 .3565 .60101 .35269 Mtetra
.60101 .35269 .60415 .3565 .61033 .35443 .6072 .35061 Mtetra
.6072 .35061 .61033 .35443 .61653 .35237 .61341 .34854 Mtetra
.61341 .34854 .61653 .35237 .62274 .35029 .61962 .34646 Mtetra
.61962 .34646 .62274 .35029 .62896 .34822 .62586 .34437 Mtetra
.62586 .34437 .62896 .34822 .6352 .34614 .6321 .34228 Mtetra
.6321 .34228 .6352 .34614 .64145 .34405 .63836 .34019 Mtetra
.63836 .34019 .64145 .34405 .64771 .34196 .64464 .33809 Mtetra
.64464 .33809 .64771 .34196 .65399 .33987 .65093 .33599 Mtetra
.65093 .33599 .65399 .33987 .66029 .33777 .65723 .33388 Mtetra
.65723 .33388 .66029 .33777 .66659 .33566 .66355 .33177 Mtetra
.66355 .33177 .66659 .33566 .67292 .33355 .66988 .32965 Mtetra
.66988 .32965 .67292 .33355 .67925 .33144 .67622 .32753 Mtetra
.67622 .32753 .67925 .33144 .6856 .32932 .68258 .3254 Mtetra
.68258 .3254 .6856 .32932 .69196 .3272 .68896 .32327 Mtetra
.68896 .32327 .69196 .3272 .69834 .32507 .69534 .32113 Mtetra
.69534 .32113 .69834 .32507 .70474 .32294 .70175 .31899 Mtetra
.70175 .31899 .70474 .32294 .71114 .3208 .70816 .31684 Mtetra
.70816 .31684 .71114 .3208 .71756 .31866 .71459 .31469 Mtetra
.71459 .31469 .71756 .31866 .724 .31651 .72104 .31254 Mtetra
.72104 .31254 .724 .31651 .73045 .31436 .7275 .31037 Mtetra
.7275 .31037 .73045 .31436 .73692 .3122 .73398 .30821 Mtetra
.73398 .30821 .73692 .3122 .7434 .31004 .74047 .30604 Mtetra
.74047 .30604 .7434 .31004 .74989 .30787 .74697 .30386 Mtetra
.74697 .30386 .74989 .30787 .7564 .3057 .75349 .30168 Mtetra
.75349 .30168 .7564 .3057 .76292 .30353 .76003 .2995 Mtetra
.76003 .2995 .76292 .30353 .76946 .30134 .76658 .2973 Mtetra
.76658 .2973 .76946 .30134 .77602 .29916 .77314 .29511 Mtetra
.77314 .29511 .77602 .29916 .78259 .29697 .77972 .29291 Mtetra
.77972 .29291 .78259 .29697 .78917 .29477 .78632 .2907 Mtetra
.78632 .2907 .78917 .29477 .79577 .29257 .79293 .28849 Mtetra
.79293 .28849 .79577 .29257 .80238 .29036 .79955 .28628 Mtetra
.79955 .28628 .80238 .29036 .80901 .28815 .80619 .28405 Mtetra
.80619 .28405 .80901 .28815 .81566 .28593 .81285 .28183 Mtetra
.81285 .28183 .81566 .28593 .82232 .28371 .81952 .2796 Mtetra
.81952 .2796 .82232 .28371 .82899 .28149 .8262 .27736 Mtetra
.8262 .27736 .82899 .28149 .83568 .27925 .8329 .27512 Mtetra
.8329 .27512 .83568 .27925 .84239 .27702 .83962 .27287 Mtetra
.83962 .27287 .84239 .27702 .84911 .27477 .84635 .27062 Mtetra
.84635 .27062 .84911 .27477 .85585 .27253 .8531 .26836 Mtetra
.8531 .26836 .85585 .27253 .8626 .27027 .85987 .2661 Mtetra
.25492 .46386 .25854 .46723 .264 .46541 .26038 .46203 Mtetra
.26038 .46203 .264 .46541 .26946 .46358 .26585 .46019 Mtetra
.26585 .46019 .26946 .46358 .27494 .46175 .27134 .45836 Mtetra
.27134 .45836 .27494 .46175 .28043 .45991 .27683 .45651 Mtetra
.27683 .45651 .28043 .45991 .28592 .45807 .28234 .45467 Mtetra
.28234 .45467 .28592 .45807 .29144 .45623 .28786 .45282 Mtetra
.28786 .45282 .29144 .45623 .29696 .45438 .29339 .45096 Mtetra
.29339 .45096 .29696 .45438 .30249 .45253 .29893 .4491 Mtetra
.29893 .4491 .30249 .45253 .30804 .45068 .30448 .44724 Mtetra
.30448 .44724 .30804 .45068 .3136 .44882 .31004 .44538 Mtetra
.31004 .44538 .3136 .44882 .31916 .44695 .31562 .44351 Mtetra
.31562 .44351 .31916 .44695 .32475 .44509 .32121 .44163 Mtetra
.32121 .44163 .32475 .44509 .33034 .44322 .32681 .43975 Mtetra
.32681 .43975 .33034 .44322 .33594 .44134 .33242 .43787 Mtetra
.33242 .43787 .33594 .44134 .34156 .43946 .33804 .43599 Mtetra
.33804 .43599 .34156 .43946 .34719 .43758 .34368 .4341 Mtetra
.34368 .4341 .34719 .43758 .35283 .43569 .34933 .4322 Mtetra
.34933 .4322 .35283 .43569 .35848 .4338 .35499 .4303 Mtetra
.35499 .4303 .35848 .4338 .36414 .43191 .36066 .4284 Mtetra
.36066 .4284 .36414 .43191 .36982 .43001 .36634 .4265 Mtetra
.36634 .4265 .36982 .43001 .37551 .42811 .37204 .42459 Mtetra
.37204 .42459 .37551 .42811 .38121 .4262 .37774 .42267 Mtetra
.37774 .42267 .38121 .4262 .38692 .42429 .38346 .42075 Mtetra
.38346 .42075 .38692 .42429 .39264 .42238 .3892 .41883 Mtetra
.3892 .41883 .39264 .42238 .39838 .42046 .39494 .4169 Mtetra
.39494 .4169 .39838 .42046 .40413 .41854 .4007 .41497 Mtetra
.4007 .41497 .40413 .41854 .40989 .41661 .40647 .41304 Mtetra
.40647 .41304 .40989 .41661 .41567 .41468 .41225 .4111 Mtetra
.41225 .4111 .41567 .41468 .42145 .41274 .41804 .40916 Mtetra
.41804 .40916 .42145 .41274 .42725 .4108 .42385 .40721 Mtetra
.42385 .40721 .42725 .4108 .43306 .40886 .42967 .40526 Mtetra
.42967 .40526 .43306 .40886 .43889 .40691 .4355 .4033 Mtetra
.4355 .4033 .43889 .40691 .44472 .40496 .44134 .40134 Mtetra
.44134 .40134 .44472 .40496 .45057 .403 .4472 .39938 Mtetra
.4472 .39938 .45057 .403 .45643 .40104 .45307 .39741 Mtetra
.45307 .39741 .45643 .40104 .46231 .39908 .45895 .39544 Mtetra
.45895 .39544 .46231 .39908 .46819 .39711 .46485 .39346 Mtetra
.46485 .39346 .46819 .39711 .47409 .39514 .47076 .39148 Mtetra
.47076 .39148 .47409 .39514 .48001 .39316 .47668 .3895 Mtetra
.663 .741 .908 r
.47668 .3895 .48001 .39316 .48593 .39118 .48261 .38751 Mtetra
.48261 .38751 .48593 .39118 .49187 .38919 .48856 .38552 Mtetra
.48856 .38552 .49187 .38919 .49782 .3872 .49452 .38352 Mtetra
.49452 .38352 .49782 .3872 .50378 .38521 .50049 .38152 Mtetra
.50049 .38152 .50378 .38521 .50976 .38321 .50647 .37952 Mtetra
.50647 .37952 .50976 .38321 .51575 .38122 .51247 .37751 Mtetra
.662 .741 .909 r
.51247 .37751 .51575 .38122 .52175 .37922 .51848 .37551 Mtetra
.661 .741 .91 r
.51848 .37551 .52175 .37922 .52777 .37723 .52451 .37354 Mtetra
.653 .74 .913 r
.52451 .37354 .52777 .37723 .5338 .37532 .53055 .37167 Mtetra
.495 .679 .948 r
.53055 .37167 .5338 .37532 .53985 .37457 .53661 .37163 Mtetra
.661 .791 .944 r
.53661 .37163 .53985 .37457 .54591 .37254 .54268 .3696 Mtetra
.774 .815 .885 r
.54268 .3696 .54591 .37254 .55197 .36924 .54874 .36557 Mtetra
.674 .75 .908 r
.54874 .36557 .55197 .36924 .55805 .36711 .55483 .36337 Mtetra
.666 .744 .908 r
.55483 .36337 .55805 .36711 .56415 .36504 .56094 .36128 Mtetra
.665 .743 .908 r
.56094 .36128 .56415 .36504 .57026 .36298 .56706 .35921 Mtetra
.664 .742 .908 r
.56706 .35921 .57026 .36298 .57638 .36093 .57319 .35714 Mtetra
.57319 .35714 .57638 .36093 .58252 .35887 .57934 .35508 Mtetra
.57934 .35508 .58252 .35887 .58867 .35682 .58549 .35301 Mtetra
.664 .741 .908 r
.58549 .35301 .58867 .35682 .59483 .35475 .59167 .35094 Mtetra
.59167 .35094 .59483 .35475 .60101 .35269 .59785 .34886 Mtetra
.59785 .34886 .60101 .35269 .6072 .35061 .60405 .34678 Mtetra
.60405 .34678 .6072 .35061 .61341 .34854 .61027 .3447 Mtetra
.61027 .3447 .61341 .34854 .61962 .34646 .6165 .34261 Mtetra
.6165 .34261 .61962 .34646 .62586 .34437 .62274 .34051 Mtetra
.62274 .34051 .62586 .34437 .6321 .34228 .62899 .33842 Mtetra
.62899 .33842 .6321 .34228 .63836 .34019 .63526 .33631 Mtetra
.63526 .33631 .63836 .34019 .64464 .33809 .64155 .3342 Mtetra
.64155 .3342 .64464 .33809 .65093 .33599 .64785 .33209 Mtetra
.64785 .33209 .65093 .33599 .65723 .33388 .65416 .32998 Mtetra
.65416 .32998 .65723 .33388 .66355 .33177 .66049 .32785 Mtetra
.66049 .32785 .66355 .33177 .66988 .32965 .66683 .32573 Mtetra
.66683 .32573 .66988 .32965 .67622 .32753 .67318 .3236 Mtetra
.67318 .3236 .67622 .32753 .68258 .3254 .67955 .32146 Mtetra
.67955 .32146 .68258 .3254 .68896 .32327 .68593 .31932 Mtetra
.68593 .31932 .68896 .32327 .69534 .32113 .69233 .31717 Mtetra
.69233 .31717 .69534 .32113 .70175 .31899 .69874 .31502 Mtetra
.69874 .31502 .70175 .31899 .70816 .31684 .70517 .31287 Mtetra
.70517 .31287 .70816 .31684 .71459 .31469 .71161 .31071 Mtetra
.71161 .31071 .71459 .31469 .72104 .31254 .71807 .30854 Mtetra
.71807 .30854 .72104 .31254 .7275 .31037 .72454 .30637 Mtetra
.72454 .30637 .7275 .31037 .73398 .30821 .73103 .3042 Mtetra
.73103 .3042 .73398 .30821 .74047 .30604 .73753 .30202 Mtetra
.73753 .30202 .74047 .30604 .74697 .30386 .74404 .29983 Mtetra
.74404 .29983 .74697 .30386 .75349 .30168 .75057 .29764 Mtetra
.75057 .29764 .75349 .30168 .76003 .2995 .75712 .29545 Mtetra
.75712 .29545 .76003 .2995 .76658 .2973 .76368 .29325 Mtetra
.76368 .29325 .76658 .2973 .77314 .29511 .77025 .29104 Mtetra
.77025 .29104 .77314 .29511 .77972 .29291 .77684 .28883 Mtetra
.77684 .28883 .77972 .29291 .78632 .2907 .78345 .28662 Mtetra
.78345 .28662 .78632 .2907 .79293 .28849 .79007 .2844 Mtetra
.79007 .2844 .79293 .28849 .79955 .28628 .7967 .28217 Mtetra
.7967 .28217 .79955 .28628 .80619 .28405 .80336 .27994 Mtetra
.80336 .27994 .80619 .28405 .81285 .28183 .81002 .27771 Mtetra
.81002 .27771 .81285 .28183 .81952 .2796 .8167 .27546 Mtetra
.8167 .27546 .81952 .2796 .8262 .27736 .8234 .27322 Mtetra
.8234 .27322 .8262 .27736 .8329 .27512 .83011 .27097 Mtetra
.83011 .27097 .8329 .27512 .83962 .27287 .83684 .26871 Mtetra
.83684 .26871 .83962 .27287 .84635 .27062 .84359 .26645 Mtetra
.84359 .26645 .84635 .27062 .8531 .26836 .85035 .26418 Mtetra
.85035 .26418 .8531 .26836 .85987 .2661 .85712 .26191 Mtetra
.25129 .46048 .25492 .46386 .26038 .46203 .25676 .45864 Mtetra
.25676 .45864 .26038 .46203 .26585 .46019 .26223 .4568 Mtetra
.26223 .4568 .26585 .46019 .27134 .45836 .26772 .45495 Mtetra
.26772 .45495 .27134 .45836 .27683 .45651 .27323 .4531 Mtetra
.27323 .4531 .27683 .45651 .28234 .45467 .27874 .45125 Mtetra
.27874 .45125 .28234 .45467 .28786 .45282 .28426 .44939 Mtetra
.28426 .44939 .28786 .45282 .29339 .45096 .2898 .44753 Mtetra
.2898 .44753 .29339 .45096 .29893 .4491 .29535 .44566 Mtetra
.29535 .44566 .29893 .4491 .30448 .44724 .30091 .44379 Mtetra
.30091 .44379 .30448 .44724 .31004 .44538 .30648 .44192 Mtetra
.30648 .44192 .31004 .44538 .31562 .44351 .31206 .44004 Mtetra
.31206 .44004 .31562 .44351 .32121 .44163 .31766 .43816 Mtetra
.31766 .43816 .32121 .44163 .32681 .43975 .32326 .43628 Mtetra
.32326 .43628 .32681 .43975 .33242 .43787 .32888 .43439 Mtetra
.32888 .43439 .33242 .43787 .33804 .43599 .33451 .43249 Mtetra
.33451 .43249 .33804 .43599 .34368 .4341 .34016 .4306 Mtetra
.34016 .4306 .34368 .4341 .34933 .4322 .34581 .4287 Mtetra
.34581 .4287 .34933 .4322 .35499 .4303 .35148 .42679 Mtetra
.35148 .42679 .35499 .4303 .36066 .4284 .35716 .42488 Mtetra
.35716 .42488 .36066 .4284 .36634 .4265 .36285 .42297 Mtetra
.36285 .42297 .36634 .4265 .37204 .42459 .36855 .42105 Mtetra
.36855 .42105 .37204 .42459 .37774 .42267 .37427 .41913 Mtetra
.37427 .41913 .37774 .42267 .38346 .42075 .38 .4172 Mtetra
.38 .4172 .38346 .42075 .3892 .41883 .38574 .41527 Mtetra
.38574 .41527 .3892 .41883 .39494 .4169 .39149 .41334 Mtetra
.39149 .41334 .39494 .4169 .4007 .41497 .39725 .4114 Mtetra
.39725 .4114 .4007 .41497 .40647 .41304 .40303 .40946 Mtetra
.40303 .40946 .40647 .41304 .41225 .4111 .40882 .40751 Mtetra
.40882 .40751 .41225 .4111 .41804 .40916 .41462 .40556 Mtetra
.41462 .40556 .41804 .40916 .42385 .40721 .42043 .40361 Mtetra
.42043 .40361 .42385 .40721 .42967 .40526 .42626 .40165 Mtetra
.42626 .40165 .42967 .40526 .4355 .4033 .4321 .39968 Mtetra
.4321 .39968 .4355 .4033 .44134 .40134 .43795 .39772 Mtetra
.43795 .39772 .44134 .40134 .4472 .39938 .44382 .39574 Mtetra
.44382 .39574 .4472 .39938 .45307 .39741 .4497 .39377 Mtetra
.4497 .39377 .45307 .39741 .45895 .39544 .45559 .39179 Mtetra
.45559 .39179 .45895 .39544 .46485 .39346 .46149 .3898 Mtetra
.663 .741 .908 r
.46149 .3898 .46485 .39346 .47076 .39148 .46741 .38782 Mtetra
.46741 .38782 .47076 .39148 .47668 .3895 .47333 .38582 Mtetra
.47333 .38582 .47668 .3895 .48261 .38751 .47928 .38383 Mtetra
.47928 .38383 .48261 .38751 .48856 .38552 .48523 .38183 Mtetra
.48523 .38183 .48856 .38552 .49452 .38352 .4912 .37982 Mtetra
.663 .742 .908 r
.4912 .37982 .49452 .38352 .50049 .38152 .49718 .37782 Mtetra
.49718 .37782 .50049 .38152 .50647 .37952 .50317 .37581 Mtetra
.663 .742 .909 r
.50317 .37581 .50647 .37952 .51247 .37751 .50918 .37381 Mtetra
.662 .742 .909 r
.50918 .37381 .51247 .37751 .51848 .37551 .5152 .37181 Mtetra
.659 .741 .911 r
.5152 .37181 .51848 .37551 .52451 .37354 .52123 .36986 Mtetra
.645 .739 .917 r
.52123 .36986 .52451 .37354 .53055 .37167 .52728 .3681 Mtetra
.301 .585 .941 r
.52728 .3681 .53055 .37167 .53661 .37163 .53335 .36951 Mtetra
.645 .845 .977 r
.53335 .36951 .53661 .37163 .54268 .3696 .53943 .36746 Mtetra
.84 .866 .863 r
.53943 .36746 .54268 .3696 .54874 .36557 .54551 .36197 Mtetra
.681 .757 .909 r
.54551 .36197 .54874 .36557 .55483 .36337 .5516 .35965 Mtetra
.668 .746 .909 r
.5516 .35965 .55483 .36337 .56094 .36128 .55772 .35752 Mtetra
.665 .744 .909 r
.55772 .35752 .56094 .36128 .56706 .35921 .56384 .35543 Mtetra
.665 .743 .908 r
.56384 .35543 .56706 .35921 .57319 .35714 .56999 .35335 Mtetra
.664 .742 .908 r
.56999 .35335 .57319 .35714 .57934 .35508 .57614 .35127 Mtetra
.57614 .35127 .57934 .35508 .58549 .35301 .58231 .34919 Mtetra
.58231 .34919 .58549 .35301 .59167 .35094 .58849 .34711 Mtetra
.58849 .34711 .59167 .35094 .59785 .34886 .59469 .34502 Mtetra
.59469 .34502 .59785 .34886 .60405 .34678 .6009 .34293 Mtetra
.664 .741 .908 r
.6009 .34293 .60405 .34678 .61027 .3447 .60712 .34084 Mtetra
.60712 .34084 .61027 .3447 .6165 .34261 .61336 .33874 Mtetra
.61336 .33874 .6165 .34261 .62274 .34051 .61961 .33664 Mtetra
.61961 .33664 .62274 .34051 .62899 .33842 .62587 .33453 Mtetra
.62587 .33453 .62899 .33842 .63526 .33631 .63215 .33242 Mtetra
.63215 .33242 .63526 .33631 .64155 .3342 .63845 .3303 Mtetra
.63845 .3303 .64155 .3342 .64785 .33209 .64475 .32818 Mtetra
.64475 .32818 .64785 .33209 .65416 .32998 .65108 .32606 Mtetra
.65108 .32606 .65416 .32998 .66049 .32785 .65741 .32393 Mtetra
.65741 .32393 .66049 .32785 .66683 .32573 .66376 .32179 Mtetra
.66376 .32179 .66683 .32573 .67318 .3236 .67013 .31965 Mtetra
.67013 .31965 .67318 .3236 .67955 .32146 .67651 .3175 Mtetra
.67651 .3175 .67955 .32146 .68593 .31932 .6829 .31535 Mtetra
.6829 .31535 .68593 .31932 .69233 .31717 .68931 .3132 Mtetra
.68931 .3132 .69233 .31717 .69874 .31502 .69573 .31104 Mtetra
.69573 .31104 .69874 .31502 .70517 .31287 .70217 .30888 Mtetra
.70217 .30888 .70517 .31287 .71161 .31071 .70862 .30671 Mtetra
.70862 .30671 .71161 .31071 .71807 .30854 .71509 .30453 Mtetra
.71509 .30453 .71807 .30854 .72454 .30637 .72157 .30235 Mtetra
.72157 .30235 .72454 .30637 .73103 .3042 .72806 .30017 Mtetra
.72806 .30017 .73103 .3042 .73753 .30202 .73457 .29798 Mtetra
.73457 .29798 .73753 .30202 .74404 .29983 .7411 .29579 Mtetra
.7411 .29579 .74404 .29983 .75057 .29764 .74764 .29359 Mtetra
.74764 .29359 .75057 .29764 .75712 .29545 .7542 .29138 Mtetra
.7542 .29138 .75712 .29545 .76368 .29325 .76077 .28917 Mtetra
.76077 .28917 .76368 .29325 .77025 .29104 .76735 .28696 Mtetra
.76735 .28696 .77025 .29104 .77684 .28883 .77395 .28474 Mtetra
.77395 .28474 .77684 .28883 .78345 .28662 .78057 .28251 Mtetra
.78057 .28251 .78345 .28662 .79007 .2844 .7872 .28028 Mtetra
.7872 .28028 .79007 .2844 .7967 .28217 .79385 .27805 Mtetra
.79385 .27805 .7967 .28217 .80336 .27994 .80051 .27581 Mtetra
.80051 .27581 .80336 .27994 .81002 .27771 .80719 .27356 Mtetra
.80719 .27356 .81002 .27771 .8167 .27546 .81388 .27131 Mtetra
.81388 .27131 .8167 .27546 .8234 .27322 .82059 .26906 Mtetra
.82059 .26906 .8234 .27322 .83011 .27097 .82731 .2668 Mtetra
.82731 .2668 .83011 .27097 .83684 .26871 .83405 .26453 Mtetra
.83405 .26453 .83684 .26871 .84359 .26645 .84081 .26226 Mtetra
.84081 .26226 .84359 .26645 .85035 .26418 .84758 .25998 Mtetra
.84758 .25998 .85035 .26418 .85712 .26191 .85436 .2577 Mtetra
.24764 .45708 .25129 .46048 .25676 .45864 .25311 .45524 Mtetra
.25311 .45524 .25676 .45864 .26223 .4568 .2586 .45339 Mtetra
.2586 .45339 .26223 .4568 .26772 .45495 .2641 .45153 Mtetra
.2641 .45153 .26772 .45495 .27323 .4531 .2696 .44968 Mtetra
.2696 .44968 .27323 .4531 .27874 .45125 .27512 .44782 Mtetra
.27512 .44782 .27874 .45125 .28426 .44939 .28066 .44595 Mtetra
.28066 .44595 .28426 .44939 .2898 .44753 .2862 .44408 Mtetra
.2862 .44408 .2898 .44753 .29535 .44566 .29176 .44221 Mtetra
.29176 .44221 .29535 .44566 .30091 .44379 .29732 .44033 Mtetra
.29732 .44033 .30091 .44379 .30648 .44192 .3029 .43845 Mtetra
.3029 .43845 .30648 .44192 .31206 .44004 .30849 .43657 Mtetra
.30849 .43657 .31206 .44004 .31766 .43816 .31409 .43468 Mtetra
.31409 .43468 .31766 .43816 .32326 .43628 .31971 .43279 Mtetra
.31971 .43279 .32326 .43628 .32888 .43439 .32533 .43089 Mtetra
.32533 .43089 .32888 .43439 .33451 .43249 .33097 .42899 Mtetra
.33097 .42899 .33451 .43249 .34016 .4306 .33662 .42708 Mtetra
.33662 .42708 .34016 .4306 .34581 .4287 .34228 .42517 Mtetra
.34228 .42517 .34581 .4287 .35148 .42679 .34796 .42326 Mtetra
.34796 .42326 .35148 .42679 .35716 .42488 .35364 .42135 Mtetra
.35364 .42135 .35716 .42488 .36285 .42297 .35934 .41942 Mtetra
.35934 .41942 .36285 .42297 .36855 .42105 .36505 .4175 Mtetra
.36505 .4175 .36855 .42105 .37427 .41913 .37078 .41557 Mtetra
.37078 .41557 .37427 .41913 .38 .4172 .37651 .41364 Mtetra
.37651 .41364 .38 .4172 .38574 .41527 .38226 .4117 Mtetra
.38226 .4117 .38574 .41527 .39149 .41334 .38802 .40976 Mtetra
.38802 .40976 .39149 .41334 .39725 .4114 .39379 .40781 Mtetra
.39379 .40781 .39725 .4114 .40303 .40946 .39958 .40586 Mtetra
.39958 .40586 .40303 .40946 .40882 .40751 .40537 .40391 Mtetra
.40537 .40391 .40882 .40751 .41462 .40556 .41118 .40195 Mtetra
.41118 .40195 .41462 .40556 .42043 .40361 .41701 .39999 Mtetra
.41701 .39999 .42043 .40361 .42626 .40165 .42284 .39802 Mtetra
.42284 .39802 .42626 .40165 .4321 .39968 .42869 .39605 Mtetra
.42869 .39605 .4321 .39968 .43795 .39772 .43455 .39407 Mtetra
.43455 .39407 .43795 .39772 .44382 .39574 .44042 .39209 Mtetra
.663 .741 .908 r
.44042 .39209 .44382 .39574 .4497 .39377 .44631 .39011 Mtetra
.44631 .39011 .4497 .39377 .45559 .39179 .45221 .38812 Mtetra
.45221 .38812 .45559 .39179 .46149 .3898 .45812 .38613 Mtetra
.663 .742 .908 r
.45812 .38613 .46149 .3898 .46741 .38782 .46404 .38414 Mtetra
.46404 .38414 .46741 .38782 .47333 .38582 .46998 .38214 Mtetra
.46998 .38214 .47333 .38582 .47928 .38383 .47593 .38013 Mtetra
.47593 .38013 .47928 .38383 .48523 .38183 .48189 .37813 Mtetra
.48189 .37813 .48523 .38183 .4912 .37982 .48787 .37612 Mtetra
.663 .742 .909 r
.48787 .37612 .4912 .37982 .49718 .37782 .49386 .37411 Mtetra
.662 .742 .909 r
.49386 .37411 .49718 .37782 .50317 .37581 .49986 .3721 Mtetra
.662 .742 .91 r
.49986 .3721 .50317 .37581 .50918 .37381 .50588 .37011 Mtetra
.66 .742 .911 r
.50588 .37011 .50918 .37381 .5152 .37181 .5119 .36814 Mtetra
.654 .742 .915 r
.5119 .36814 .5152 .37181 .52123 .36986 .51795 .36625 Mtetra
.624 .737 .928 r
.51795 .36625 .52123 .36986 .52728 .3681 .524 .36477 Mtetra
0 .139 .638 r
.524 .36477 .52728 .3681 .53335 .36951 .53008 .36975 Mtetra
.399 .855 .855 r
.53008 .36975 .53335 .36951 .53943 .36746 .53618 .36771 Mtetra
.939 .945 .763 r
.53618 .36771 .53943 .36746 .54551 .36197 .54225 .35862 Mtetra
.699 .778 .913 r
.54225 .35862 .54551 .36197 .5516 .35965 .54836 .356 Mtetra
.673 .753 .911 r
.54836 .356 .5516 .35965 .55772 .35752 .55448 .35378 Mtetra
.668 .747 .91 r
.55448 .35378 .55772 .35752 .56384 .35543 .56062 .35165 Mtetra
.666 .744 .909 r
.56062 .35165 .56384 .35543 .56999 .35335 .56677 .34955 Mtetra
.665 .743 .909 r
.56677 .34955 .56999 .35335 .57614 .35127 .57293 .34745 Mtetra
.664 .743 .908 r
.57293 .34745 .57614 .35127 .58231 .34919 .57911 .34536 Mtetra
.664 .742 .908 r
.57911 .34536 .58231 .34919 .58849 .34711 .5853 .34327 Mtetra
.5853 .34327 .58849 .34711 .59469 .34502 .59151 .34117 Mtetra
.59151 .34117 .59469 .34502 .6009 .34293 .59772 .33907 Mtetra
.59772 .33907 .6009 .34293 .60712 .34084 .60396 .33697 Mtetra
.60396 .33697 .60712 .34084 .61336 .33874 .6102 .33486 Mtetra
.6102 .33486 .61336 .33874 .61961 .33664 .61647 .33275 Mtetra
.61647 .33275 .61961 .33664 .62587 .33453 .62274 .33063 Mtetra
.664 .741 .908 r
.62274 .33063 .62587 .33453 .63215 .33242 .62903 .32851 Mtetra
.62903 .32851 .63215 .33242 .63845 .3303 .63533 .32639 Mtetra
.63533 .32639 .63845 .3303 .64475 .32818 .64165 .32426 Mtetra
.64165 .32426 .64475 .32818 .65108 .32606 .64798 .32212 Mtetra
.64798 .32212 .65108 .32606 .65741 .32393 .65433 .31998 Mtetra
.65433 .31998 .65741 .32393 .66376 .32179 .66069 .31784 Mtetra
.66069 .31784 .66376 .32179 .67013 .31965 .66706 .31569 Mtetra
.66706 .31569 .67013 .31965 .67651 .3175 .67345 .31353 Mtetra
.67345 .31353 .67651 .3175 .6829 .31535 .67985 .31137 Mtetra
.67985 .31137 .6829 .31535 .68931 .3132 .68627 .30921 Mtetra
.68627 .30921 .68931 .3132 .69573 .31104 .6927 .30704 Mtetra
.6927 .30704 .69573 .31104 .70217 .30888 .69915 .30487 Mtetra
.69915 .30487 .70217 .30888 .70862 .30671 .70561 .30269 Mtetra
.70561 .30269 .70862 .30671 .71509 .30453 .71209 .30051 Mtetra
.71209 .30051 .71509 .30453 .72157 .30235 .71858 .29832 Mtetra
.71858 .29832 .72157 .30235 .72806 .30017 .72509 .29612 Mtetra
.72509 .29612 .72806 .30017 .73457 .29798 .73161 .29393 Mtetra
.73161 .29393 .73457 .29798 .7411 .29579 .73814 .29172 Mtetra
.73814 .29172 .7411 .29579 .74764 .29359 .7447 .28951 Mtetra
.7447 .28951 .74764 .29359 .7542 .29138 .75126 .2873 Mtetra
.75126 .2873 .7542 .29138 .76077 .28917 .75784 .28508 Mtetra
.75784 .28508 .76077 .28917 .76735 .28696 .76444 .28286 Mtetra
.76444 .28286 .76735 .28696 .77395 .28474 .77105 .28063 Mtetra
.77105 .28063 .77395 .28474 .78057 .28251 .77768 .27839 Mtetra
.77768 .27839 .78057 .28251 .7872 .28028 .78432 .27615 Mtetra
.78432 .27615 .7872 .28028 .79385 .27805 .79098 .27391 Mtetra
.79098 .27391 .79385 .27805 .80051 .27581 .79765 .27166 Mtetra
.79765 .27166 .80051 .27581 .80719 .27356 .80434 .26941 Mtetra
.80434 .26941 .80719 .27356 .81388 .27131 .81104 .26715 Mtetra
.81104 .26715 .81388 .27131 .82059 .26906 .81776 .26488 Mtetra
.81776 .26488 .82059 .26906 .82731 .2668 .8245 .26261 Mtetra
.8245 .26261 .82731 .2668 .83405 .26453 .83125 .26033 Mtetra
.83125 .26033 .83405 .26453 .84081 .26226 .83801 .25805 Mtetra
.83801 .25805 .84081 .26226 .84758 .25998 .8448 .25577 Mtetra
.8448 .25577 .84758 .25998 .85436 .2577 .85159 .25347 Mtetra
.24398 .45367 .24764 .45708 .25311 .45524 .24946 .45182 Mtetra
.24946 .45182 .25311 .45524 .2586 .45339 .25495 .44996 Mtetra
.25495 .44996 .2586 .45339 .2641 .45153 .26045 .4481 Mtetra
.26045 .4481 .2641 .45153 .2696 .44968 .26597 .44624 Mtetra
.26597 .44624 .2696 .44968 .27512 .44782 .2715 .44437 Mtetra
.2715 .44437 .27512 .44782 .28066 .44595 .27704 .4425 Mtetra
.27704 .4425 .28066 .44595 .2862 .44408 .28259 .44062 Mtetra
.28259 .44062 .2862 .44408 .29176 .44221 .28815 .43874 Mtetra
.28815 .43874 .29176 .44221 .29732 .44033 .29372 .43686 Mtetra
.29372 .43686 .29732 .44033 .3029 .43845 .29931 .43497 Mtetra
.29931 .43497 .3029 .43845 .30849 .43657 .30491 .43308 Mtetra
.30491 .43308 .30849 .43657 .31409 .43468 .31051 .43118 Mtetra
.31051 .43118 .31409 .43468 .31971 .43279 .31614 .42928 Mtetra
.31614 .42928 .31971 .43279 .32533 .43089 .32177 .42738 Mtetra
.32177 .42738 .32533 .43089 .33097 .42899 .32741 .42547 Mtetra
.32741 .42547 .33097 .42899 .33662 .42708 .33307 .42356 Mtetra
.33307 .42356 .33662 .42708 .34228 .42517 .33874 .42164 Mtetra
.33874 .42164 .34228 .42517 .34796 .42326 .34442 .41972 Mtetra
.34442 .41972 .34796 .42326 .35364 .42135 .35012 .4178 Mtetra
.35012 .4178 .35364 .42135 .35934 .41942 .35582 .41587 Mtetra
.35582 .41587 .35934 .41942 .36505 .4175 .36154 .41394 Mtetra
.36154 .41394 .36505 .4175 .37078 .41557 .36727 .412 Mtetra
.36727 .412 .37078 .41557 .37651 .41364 .37301 .41006 Mtetra
.37301 .41006 .37651 .41364 .38226 .4117 .37877 .40811 Mtetra
.664 .742 .908 r
.37877 .40811 .38226 .4117 .38802 .40976 .38454 .40617 Mtetra
.38454 .40617 .38802 .40976 .39379 .40781 .39032 .40421 Mtetra
.39032 .40421 .39379 .40781 .39958 .40586 .39611 .40226 Mtetra
.39611 .40226 .39958 .40586 .40537 .40391 .40192 .40029 Mtetra
.40192 .40029 .40537 .40391 .41118 .40195 .40773 .39833 Mtetra
.663 .742 .908 r
.40773 .39833 .41118 .40195 .41701 .39999 .41356 .39636 Mtetra
.41356 .39636 .41701 .39999 .42284 .39802 .41941 .39438 Mtetra
.41941 .39438 .42284 .39802 .42869 .39605 .42526 .39241 Mtetra
.42526 .39241 .42869 .39605 .43455 .39407 .43113 .39042 Mtetra
.43113 .39042 .43455 .39407 .44042 .39209 .43701 .38844 Mtetra
.43701 .38844 .44042 .39209 .44631 .39011 .4429 .38645 Mtetra
.4429 .38645 .44631 .39011 .45221 .38812 .44881 .38445 Mtetra
.663 .742 .909 r
.44881 .38445 .45221 .38812 .45812 .38613 .45473 .38246 Mtetra
.45473 .38246 .45812 .38613 .46404 .38414 .46066 .38046 Mtetra
.46066 .38046 .46404 .38414 .46998 .38214 .46661 .37845 Mtetra
.46661 .37845 .46998 .38214 .47593 .38013 .47257 .37645 Mtetra
.663 .743 .909 r
.47257 .37645 .47593 .38013 .48189 .37813 .47854 .37444 Mtetra
.662 .743 .91 r
.47854 .37444 .48189 .37813 .48787 .37612 .48452 .37244 Mtetra
.662 .744 .911 r
.48452 .37244 .48787 .37612 .49386 .37411 .49052 .37044 Mtetra
.66 .744 .912 r
.49052 .37044 .49386 .37411 .49986 .3721 .49653 .36846 Mtetra
.658 .745 .914 r
.49653 .36846 .49986 .3721 .50588 .37011 .50256 .36651 Mtetra
.652 .747 .919 r
.50256 .36651 .50588 .37011 .5119 .36814 .50859 .36464 Mtetra
.632 .747 .931 r
.50859 .36464 .5119 .36814 .51795 .36625 .51464 .36304 Mtetra
.518 .721 .965 r
.51464 .36304 .51795 .36625 .524 .36477 .52071 .36259 Mtetra
.916 .518 .196 r
.52071 .36259 .524 .36477 .53008 .36975 .5268 .38072 Mtetra
.431 .1 .302 r
.5268 .38072 .53008 .36975 .53618 .36771 .53294 .37868 Mtetra
.745 .752 .238 r
.53294 .37868 .53618 .36771 .54225 .35862 .53899 .35642 Mtetra
.763 .865 .924 r
.53899 .35642 .54225 .35862 .54836 .356 .54511 .35275 Mtetra
.692 .783 .921 r
.54511 .35275 .54836 .356 .55448 .35378 .55124 .35023 Mtetra
.675 .761 .916 r
.55124 .35023 .55448 .35378 .56062 .35165 .55738 .34798 Mtetra
.669 .752 .913 r
.55738 .34798 .56062 .35165 .56677 .34955 .56354 .34581 Mtetra
.667 .748 .911 r
.56354 .34581 .56677 .34955 .57293 .34745 .56971 .34367 Mtetra
.665 .746 .91 r
.56971 .34367 .57293 .34745 .57911 .34536 .5759 .34155 Mtetra
.665 .745 .91 r
.5759 .34155 .57911 .34536 .5853 .34327 .5821 .33944 Mtetra
.664 .744 .909 r
.5821 .33944 .5853 .34327 .59151 .34117 .58831 .33733 Mtetra
.664 .743 .909 r
.58831 .33733 .59151 .34117 .59772 .33907 .59454 .33521 Mtetra
.59454 .33521 .59772 .33907 .60396 .33697 .60078 .3331 Mtetra
.664 .742 .909 r
.60078 .3331 .60396 .33697 .6102 .33486 .60704 .33098 Mtetra
.60704 .33098 .6102 .33486 .61647 .33275 .61331 .32885 Mtetra
.664 .742 .908 r
.61331 .32885 .61647 .33275 .62274 .33063 .61959 .32673 Mtetra
.61959 .32673 .62274 .33063 .62903 .32851 .62589 .3246 Mtetra
.62589 .3246 .62903 .32851 .63533 .32639 .6322 .32246 Mtetra
.6322 .32246 .63533 .32639 .64165 .32426 .63853 .32032 Mtetra
.63853 .32032 .64165 .32426 .64798 .32212 .64487 .31817 Mtetra
.64487 .31817 .64798 .32212 .65433 .31998 .65123 .31603 Mtetra
.65123 .31603 .65433 .31998 .66069 .31784 .6576 .31387 Mtetra
.6576 .31387 .66069 .31784 .66706 .31569 .66398 .31171 Mtetra
.66398 .31171 .66706 .31569 .67345 .31353 .67038 .30955 Mtetra
.67038 .30955 .67345 .31353 .67985 .31137 .67679 .30738 Mtetra
.67679 .30738 .67985 .31137 .68627 .30921 .68322 .30521 Mtetra
.68322 .30521 .68627 .30921 .6927 .30704 .68967 .30303 Mtetra
.68967 .30303 .6927 .30704 .69915 .30487 .69612 .30085 Mtetra
.69612 .30085 .69915 .30487 .70561 .30269 .70259 .29866 Mtetra
.664 .741 .908 r
.70259 .29866 .70561 .30269 .71209 .30051 .70908 .29647 Mtetra
.70908 .29647 .71209 .30051 .71858 .29832 .71558 .29427 Mtetra
.71558 .29427 .71858 .29832 .72509 .29612 .7221 .29206 Mtetra
.7221 .29206 .72509 .29612 .73161 .29393 .72863 .28986 Mtetra
.72863 .28986 .73161 .29393 .73814 .29172 .73518 .28764 Mtetra
.73518 .28764 .73814 .29172 .7447 .28951 .74174 .28543 Mtetra
.74174 .28543 .7447 .28951 .75126 .2873 .74832 .2832 Mtetra
.74832 .2832 .75126 .2873 .75784 .28508 .75491 .28097 Mtetra
.75491 .28097 .75784 .28508 .76444 .28286 .76151 .27874 Mtetra
.76151 .27874 .76444 .28286 .77105 .28063 .76814 .2765 Mtetra
.76814 .2765 .77105 .28063 .77768 .27839 .77477 .27426 Mtetra
.77477 .27426 .77768 .27839 .78432 .27615 .78143 .27201 Mtetra
.78143 .27201 .78432 .27615 .79098 .27391 .7881 .26975 Mtetra
.7881 .26975 .79098 .27391 .79765 .27166 .79478 .2675 Mtetra
.79478 .2675 .79765 .27166 .80434 .26941 .80148 .26523 Mtetra
.80148 .26523 .80434 .26941 .81104 .26715 .80819 .26296 Mtetra
.80819 .26296 .81104 .26715 .81776 .26488 .81492 .26069 Mtetra
.81492 .26069 .81776 .26488 .8245 .26261 .82167 .25841 Mtetra
.82167 .25841 .8245 .26261 .83125 .26033 .82843 .25612 Mtetra
.82843 .25612 .83125 .26033 .83801 .25805 .83521 .25383 Mtetra
.83521 .25383 .83801 .25805 .8448 .25577 .842 .25153 Mtetra
.842 .25153 .8448 .25577 .85159 .25347 .84881 .24923 Mtetra
.664 .742 .909 r
.2403 .45026 .24398 .45367 .24946 .45182 .24579 .4484 Mtetra
.24579 .4484 .24946 .45182 .25495 .44996 .25129 .44654 Mtetra
.25129 .44654 .25495 .44996 .26045 .4481 .2568 .44467 Mtetra
.2568 .44467 .26045 .4481 .26597 .44624 .26232 .4428 Mtetra
.26232 .4428 .26597 .44624 .2715 .44437 .26785 .44093 Mtetra
.26785 .44093 .2715 .44437 .27704 .4425 .2734 .43905 Mtetra
.2734 .43905 .27704 .4425 .28259 .44062 .27896 .43717 Mtetra
.27896 .43717 .28259 .44062 .28815 .43874 .28453 .43528 Mtetra
.28453 .43528 .28815 .43874 .29372 .43686 .29011 .43339 Mtetra
.663 .742 .909 r
.29011 .43339 .29372 .43686 .29931 .43497 .2957 .4315 Mtetra
.2957 .4315 .29931 .43497 .30491 .43308 .3013 .4296 Mtetra
.663 .743 .909 r
.3013 .4296 .30491 .43308 .31051 .43118 .30692 .42769 Mtetra
.30692 .42769 .31051 .43118 .31614 .42928 .31255 .42579 Mtetra
.31255 .42579 .31614 .42928 .32177 .42738 .31819 .42388 Mtetra
.31819 .42388 .32177 .42738 .32741 .42547 .32384 .42196 Mtetra
.32384 .42196 .32741 .42547 .33307 .42356 .32951 .42005 Mtetra
.32951 .42005 .33307 .42356 .33874 .42164 .33518 .41812 Mtetra
.33518 .41812 .33874 .42164 .34442 .41972 .34087 .4162 Mtetra
.34087 .4162 .34442 .41972 .35012 .4178 .34657 .41427 Mtetra
.34657 .41427 .35012 .4178 .35582 .41587 .35229 .41233 Mtetra
.663 .743 .91 r
.35229 .41233 .35582 .41587 .36154 .41394 .35801 .4104 Mtetra
.35801 .4104 .36154 .41394 .36727 .412 .36375 .40845 Mtetra
.663 .744 .91 r
.36375 .40845 .36727 .412 .37301 .41006 .3695 .40651 Mtetra
.3695 .40651 .37301 .41006 .37877 .40811 .37526 .40456 Mtetra
.37526 .40456 .37877 .40811 .38454 .40617 .38104 .40261 Mtetra
.38104 .40261 .38454 .40617 .39032 .40421 .38683 .40065 Mtetra
.663 .744 .911 r
.38683 .40065 .39032 .40421 .39611 .40226 .39263 .39869 Mtetra
.663 .745 .911 r
.39263 .39869 .39611 .40226 .40192 .40029 .39844 .39673 Mtetra
.39844 .39673 .40192 .40029 .40773 .39833 .40427 .39476 Mtetra
.40427 .39476 .40773 .39833 .41356 .39636 .4101 .39279 Mtetra
.663 .746 .912 r
.4101 .39279 .41356 .39636 .41941 .39438 .41595 .39082 Mtetra
.41595 .39082 .41941 .39438 .42526 .39241 .42182 .38884 Mtetra
.663 .747 .913 r
.42182 .38884 .42526 .39241 .43113 .39042 .42769 .38687 Mtetra
.662 .748 .913 r
.42769 .38687 .43113 .39042 .43701 .38844 .43358 .38489 Mtetra
.662 .749 .914 r
.43358 .38489 .43701 .38844 .4429 .38645 .43948 .38291 Mtetra
.662 .75 .915 r
.43948 .38291 .4429 .38645 .44881 .38445 .4454 .38093 Mtetra
.661 .751 .916 r
.4454 .38093 .44881 .38445 .45473 .38246 .45133 .37896 Mtetra
.661 .752 .918 r
.45133 .37896 .45473 .38246 .46066 .38046 .45727 .37699 Mtetra
.66 .754 .92 r
.45727 .37699 .46066 .38046 .46661 .37845 .46322 .37503 Mtetra
.658 .757 .923 r
.46322 .37503 .46661 .37845 .47257 .37645 .46919 .37309 Mtetra
.655 .761 .927 r
.46919 .37309 .47257 .37645 .47854 .37444 .47516 .37118 Mtetra
.651 .766 .933 r
.47516 .37118 .47854 .37444 .48452 .37244 .48116 .36932 Mtetra
.642 .773 .943 r
.48116 .36932 .48452 .37244 .49052 .37044 .48716 .36755 Mtetra
.624 .784 .958 r
.48716 .36755 .49052 .37044 .49653 .36846 .49318 .36596 Mtetra
.577 .796 .982 r
.49318 .36596 .49653 .36846 .50256 .36651 .49921 .36471 Mtetra
.409 .775 .994 r
.49921 .36471 .50256 .36651 .50859 .36464 .50525 .36429 Mtetra
.331 0 0 r
.50525 .36429 .50859 .36464 .51464 .36304 .5113 .36623 Mtetra
.831 .435 .3 r
.5113 .36623 .51464 .36304 .52071 .36259 .51735 .37886 Mtetra
.939 .648 .462 r
.51735 .37886 .52071 .36259 .5268 .38072 .52339 .57257 Mtetra
.539 .312 .52 r
.52339 .57257 .5268 .38072 .53294 .37868 .52991 .57062 Mtetra
0 0 .323 r
.52991 .57062 .53294 .37868 .53899 .35642 .53578 .37269 Mtetra
0 0 .162 r
.53578 .37269 .53899 .35642 .54511 .35275 .54187 .35591 Mtetra
.506 .823 .509 r
.54187 .35591 .54511 .35275 .55124 .35023 .548 .34983 Mtetra
.717 .969 .934 r
.548 .34983 .55124 .35023 .55738 .34798 .55415 .34612 Mtetra
.707 .884 .963 r
.55415 .34612 .55738 .34798 .56354 .34581 .56031 .34322 Mtetra
.69 .83 .95 r
.56031 .34322 .56354 .34581 .56971 .34367 .56649 .34068 Mtetra
.68 .8 .939 r
.56649 .34068 .56971 .34367 .5759 .34155 .57268 .33831 Mtetra
.674 .783 .931 r
.57268 .33831 .5759 .34155 .5821 .33944 .57889 .33603 Mtetra
.671 .772 .926 r
.57889 .33603 .5821 .33944 .58831 .33733 .58511 .33381 Mtetra
.669 .765 .922 r
.58511 .33381 .58831 .33733 .59454 .33521 .59135 .33161 Mtetra
.667 .76 .92 r
.59135 .33161 .59454 .33521 .60078 .3331 .5976 .32943 Mtetra
.666 .757 .918 r
.5976 .32943 .60078 .3331 .60704 .33098 .60387 .32727 Mtetra
.666 .754 .916 r
.60387 .32727 .60704 .33098 .61331 .32885 .61014 .3251 Mtetra
.665 .752 .915 r
.61014 .3251 .61331 .32885 .61959 .32673 .61644 .32294 Mtetra
.665 .751 .914 r
.61644 .32294 .61959 .32673 .62589 .3246 .62275 .32078 Mtetra
.665 .749 .913 r
.62275 .32078 .62589 .3246 .6322 .32246 .62907 .31862 Mtetra
.665 .748 .913 r
.62907 .31862 .6322 .32246 .63853 .32032 .6354 .31646 Mtetra
.664 .748 .912 r
.6354 .31646 .63853 .32032 .64487 .31817 .64175 .3143 Mtetra
.664 .747 .912 r
.64175 .3143 .64487 .31817 .65123 .31603 .64812 .31213 Mtetra
.664 .746 .911 r
.64812 .31213 .65123 .31603 .6576 .31387 .6545 .30996 Mtetra
.6545 .30996 .6576 .31387 .66398 .31171 .66089 .30778 Mtetra
.664 .745 .911 r
.66089 .30778 .66398 .31171 .67038 .30955 .6673 .30561 Mtetra
.6673 .30561 .67038 .30955 .67679 .30738 .67373 .30342 Mtetra
.664 .745 .91 r
.67373 .30342 .67679 .30738 .68322 .30521 .68016 .30124 Mtetra
.664 .744 .91 r
.68016 .30124 .68322 .30521 .68967 .30303 .68662 .29904 Mtetra
.68662 .29904 .68967 .30303 .69612 .30085 .69308 .29685 Mtetra
.69308 .29685 .69612 .30085 .70259 .29866 .69957 .29465 Mtetra
.69957 .29465 .70259 .29866 .70908 .29647 .70606 .29244 Mtetra
.70606 .29244 .70908 .29647 .71558 .29427 .71257 .29023 Mtetra
.664 .743 .909 r
.71257 .29023 .71558 .29427 .7221 .29206 .7191 .28802 Mtetra
.7191 .28802 .7221 .29206 .72863 .28986 .72564 .2858 Mtetra
.72564 .2858 .72863 .28986 .73518 .28764 .7322 .28358 Mtetra
.7322 .28358 .73518 .28764 .74174 .28543 .73877 .28135 Mtetra
.73877 .28135 .74174 .28543 .74832 .2832 .74536 .27911 Mtetra
.74536 .27911 .74832 .2832 .75491 .28097 .75196 .27687 Mtetra
.75196 .27687 .75491 .28097 .76151 .27874 .75858 .27463 Mtetra
.75858 .27463 .76151 .27874 .76814 .2765 .76521 .27238 Mtetra
.76521 .27238 .76814 .2765 .77477 .27426 .77186 .27012 Mtetra
.77186 .27012 .77477 .27426 .78143 .27201 .77852 .26787 Mtetra
.77852 .26787 .78143 .27201 .7881 .26975 .7852 .2656 Mtetra
.664 .742 .909 r
.7852 .2656 .7881 .26975 .79478 .2675 .7919 .26333 Mtetra
.7919 .26333 .79478 .2675 .80148 .26523 .79861 .26106 Mtetra
.79861 .26106 .80148 .26523 .80819 .26296 .80533 .25878 Mtetra
.80533 .25878 .80819 .26296 .81492 .26069 .81208 .25649 Mtetra
.81208 .25649 .81492 .26069 .82167 .25841 .81883 .2542 Mtetra
.81883 .2542 .82167 .25841 .82843 .25612 .82561 .2519 Mtetra
.82561 .2519 .82843 .25612 .83521 .25383 .8324 .2496 Mtetra
.8324 .2496 .83521 .25383 .842 .25153 .8392 .24729 Mtetra
.8392 .24729 .842 .25153 .84881 .24923 .84602 .24498 Mtetra
.664 .741 .908 r
.23661 .44683 .2403 .45026 .24579 .4484 .2421 .44496 Mtetra
.2421 .44496 .24579 .4484 .25129 .44654 .24761 .44309 Mtetra
.24761 .44309 .25129 .44654 .2568 .44467 .25313 .44122 Mtetra
.663 .741 .908 r
.25313 .44122 .2568 .44467 .26232 .4428 .25866 .43934 Mtetra
.25866 .43934 .26232 .4428 .26785 .44093 .2642 .43745 Mtetra
.2642 .43745 .26785 .44093 .2734 .43905 .26975 .43557 Mtetra
.26975 .43557 .2734 .43905 .27896 .43717 .27531 .43368 Mtetra
.27531 .43368 .27896 .43717 .28453 .43528 .28089 .43179 Mtetra
.28089 .43179 .28453 .43528 .29011 .43339 .28648 .42989 Mtetra
.28648 .42989 .29011 .43339 .2957 .4315 .29208 .42799 Mtetra
.29208 .42799 .2957 .4315 .3013 .4296 .29769 .42608 Mtetra
.29769 .42608 .3013 .4296 .30692 .42769 .30331 .42417 Mtetra
.30331 .42417 .30692 .42769 .31255 .42579 .30895 .42226 Mtetra
.30895 .42226 .31255 .42579 .31819 .42388 .3146 .42034 Mtetra
.3146 .42034 .31819 .42388 .32384 .42196 .32026 .41842 Mtetra
.32026 .41842 .32384 .42196 .32951 .42005 .32593 .41649 Mtetra
.32593 .41649 .32951 .42005 .33518 .41812 .33161 .41456 Mtetra
.33161 .41456 .33518 .41812 .34087 .4162 .33731 .41263 Mtetra
.33731 .41263 .34087 .4162 .34657 .41427 .34302 .41069 Mtetra
.34302 .41069 .34657 .41427 .35229 .41233 .34874 .40875 Mtetra
.34874 .40875 .35229 .41233 .35801 .4104 .35447 .4068 Mtetra
.35447 .4068 .35801 .4104 .36375 .40845 .36022 .40485 Mtetra
.36022 .40485 .36375 .40845 .3695 .40651 .36598 .4029 Mtetra
.36598 .4029 .3695 .40651 .37526 .40456 .37175 .40094 Mtetra
.37175 .40094 .37526 .40456 .38104 .40261 .37753 .39898 Mtetra
.37753 .39898 .38104 .40261 .38683 .40065 .38333 .39702 Mtetra
.38333 .39702 .38683 .40065 .39263 .39869 .38913 .39505 Mtetra
.38913 .39505 .39263 .39869 .39844 .39673 .39495 .39308 Mtetra
.39495 .39308 .39844 .39673 .40427 .39476 .40079 .3911 Mtetra
.40079 .3911 .40427 .39476 .4101 .39279 .40663 .38913 Mtetra
.40663 .38913 .4101 .39279 .41595 .39082 .41249 .38715 Mtetra
.41249 .38715 .41595 .39082 .42182 .38884 .41836 .38516 Mtetra
.41836 .38516 .42182 .38884 .42769 .38687 .42425 .38318 Mtetra
.662 .741 .908 r
.42425 .38318 .42769 .38687 .43358 .38489 .43014 .38119 Mtetra
.43014 .38119 .43358 .38489 .43948 .38291 .43605 .3792 Mtetra
.662 .741 .909 r
.43605 .3792 .43948 .38291 .4454 .38093 .44198 .37722 Mtetra
.661 .741 .909 r
.44198 .37722 .4454 .38093 .45133 .37896 .44791 .37524 Mtetra
.661 .74 .909 r
.44791 .37524 .45133 .37896 .45727 .37699 .45386 .37326 Mtetra
.66 .74 .909 r
.45386 .37326 .45727 .37699 .46322 .37503 .45982 .37129 Mtetra
.658 .74 .91 r
.45982 .37129 .46322 .37503 .46919 .37309 .4658 .36934 Mtetra
.656 .739 .911 r
.4658 .36934 .46919 .37309 .47516 .37118 .47178 .36742 Mtetra
.652 .738 .912 r
.47178 .36742 .47516 .37118 .48116 .36932 .47778 .36556 Mtetra
.646 .736 .914 r
.47778 .36556 .48116 .36932 .48716 .36755 .4838 .36378 Mtetra
.633 .731 .919 r
.4838 .36378 .48716 .36755 .49318 .36596 .48982 .36218 Mtetra
.607 .722 .926 r
.48982 .36218 .49318 .36596 .49921 .36471 .49586 .36093 Mtetra
.535 .692 .94 r
.49586 .36093 .49921 .36471 .50525 .36429 .50191 .3605 Mtetra
.23 .532 .921 r
.50191 .3605 .50525 .36429 .5113 .36623 .50796 .36244 Mtetra
.84 .4 0 r
.50796 .36244 .5113 .36623 .51735 .37886 .51401 .37507 Mtetra
.966 .676 .429 r
.51401 .37507 .51735 .37886 .52339 .57257 .51986 .56897 Mtetra
.646 .763 .934 r
.51986 .56897 .52339 .57257 .52991 .57062 .52638 .56701 Mtetra
.966 .698 .473 r
.52638 .56701 .52991 .57062 .53578 .37269 .53246 .36888 Mtetra
.926 .761 .657 r
.53246 .36888 .53578 .37269 .54187 .35591 .53858 .35208 Mtetra
.822 .778 .811 r
.53858 .35208 .54187 .35591 .548 .34983 .54472 .34598 Mtetra
.747 .766 .868 r
.54472 .34598 .548 .34983 .55415 .34612 .55088 .34226 Mtetra
.709 .756 .889 r
.55088 .34226 .55415 .34612 .56031 .34322 .55705 .33935 Mtetra
.69 .75 .897 r
.55705 .33935 .56031 .34322 .56649 .34068 .56324 .3368 Mtetra
.68 .747 .902 r
.56324 .3368 .56649 .34068 .57268 .33831 .56944 .33442 Mtetra
.674 .745 .904 r
.56944 .33442 .57268 .33831 .57889 .33603 .57566 .33214 Mtetra
.671 .744 .905 r
.57566 .33214 .57889 .33603 .58511 .33381 .58189 .3299 Mtetra
.669 .743 .906 r
.58189 .3299 .58511 .33381 .59135 .33161 .58814 .3277 Mtetra
.667 .743 .907 r
.58814 .3277 .59135 .33161 .5976 .32943 .5944 .32551 Mtetra
.666 .742 .907 r
.5944 .32551 .5976 .32943 .60387 .32727 .60067 .32333 Mtetra
.60067 .32333 .60387 .32727 .61014 .3251 .60696 .32116 Mtetra
.665 .742 .907 r
.60696 .32116 .61014 .3251 .61644 .32294 .61326 .31899 Mtetra
.61326 .31899 .61644 .32294 .62275 .32078 .61958 .31682 Mtetra
.665 .742 .908 r
.61958 .31682 .62275 .32078 .62907 .31862 .62591 .31466 Mtetra
.664 .742 .908 r
.62591 .31466 .62907 .31862 .6354 .31646 .63226 .31248 Mtetra
.63226 .31248 .6354 .31646 .64175 .3143 .63862 .31031 Mtetra
.63862 .31031 .64175 .3143 .64812 .31213 .64499 .30813 Mtetra
.664 .741 .908 r
.64499 .30813 .64812 .31213 .6545 .30996 .65138 .30595 Mtetra
.65138 .30595 .6545 .30996 .66089 .30778 .65779 .30377 Mtetra
.65779 .30377 .66089 .30778 .6673 .30561 .66421 .30158 Mtetra
.66421 .30158 .6673 .30561 .67373 .30342 .67064 .29939 Mtetra
.67064 .29939 .67373 .30342 .68016 .30124 .67709 .29719 Mtetra
.67709 .29719 .68016 .30124 .68662 .29904 .68355 .29499 Mtetra
.68355 .29499 .68662 .29904 .69308 .29685 .69003 .29279 Mtetra
.69003 .29279 .69308 .29685 .69957 .29465 .69652 .29058 Mtetra
.69652 .29058 .69957 .29465 .70606 .29244 .70303 .28837 Mtetra
.70303 .28837 .70606 .29244 .71257 .29023 .70955 .28615 Mtetra
.70955 .28615 .71257 .29023 .7191 .28802 .71609 .28392 Mtetra
.71609 .28392 .7191 .28802 .72564 .2858 .72264 .28169 Mtetra
.72264 .28169 .72564 .2858 .7322 .28358 .72921 .27946 Mtetra
.72921 .27946 .7322 .28358 .73877 .28135 .73579 .27722 Mtetra
.73579 .27722 .73877 .28135 .74536 .27911 .74239 .27498 Mtetra
.74239 .27498 .74536 .27911 .75196 .27687 .749 .27273 Mtetra
.749 .27273 .75196 .27687 .75858 .27463 .75563 .27047 Mtetra
.75563 .27047 .75858 .27463 .76521 .27238 .76227 .26822 Mtetra
.76227 .26822 .76521 .27238 .77186 .27012 .76893 .26595 Mtetra
.76893 .26595 .77186 .27012 .77852 .26787 .77561 .26368 Mtetra
.77561 .26368 .77852 .26787 .7852 .2656 .7823 .26141 Mtetra
.7823 .26141 .7852 .2656 .7919 .26333 .789 .25913 Mtetra
.789 .25913 .7919 .26333 .79861 .26106 .79572 .25684 Mtetra
.79572 .25684 .79861 .26106 .80533 .25878 .80246 .25455 Mtetra
.80246 .25455 .80533 .25878 .81208 .25649 .80921 .25226 Mtetra
.80921 .25226 .81208 .25649 .81883 .2542 .81598 .24996 Mtetra
.81598 .24996 .81883 .2542 .82561 .2519 .82277 .24765 Mtetra
.82277 .24765 .82561 .2519 .8324 .2496 .82957 .24534 Mtetra
.82957 .24534 .8324 .2496 .8392 .24729 .83638 .24302 Mtetra
.83638 .24302 .8392 .24729 .84602 .24498 .84322 .2407 Mtetra
.664 .74 .907 r
.23291 .44336 .23661 .44683 .2421 .44496 .23841 .44149 Mtetra
.23841 .44149 .2421 .44496 .24761 .44309 .24392 .43961 Mtetra
.24392 .43961 .24761 .44309 .25313 .44122 .24944 .43773 Mtetra
.24944 .43773 .25313 .44122 .25866 .43934 .25498 .43584 Mtetra
.25498 .43584 .25866 .43934 .2642 .43745 .26053 .43395 Mtetra
.26053 .43395 .2642 .43745 .26975 .43557 .26609 .43206 Mtetra
.26609 .43206 .26975 .43557 .27531 .43368 .27166 .43016 Mtetra
.27166 .43016 .27531 .43368 .28089 .43179 .27724 .42826 Mtetra
.27724 .42826 .28089 .43179 .28648 .42989 .28284 .42635 Mtetra
.28284 .42635 .28648 .42989 .29208 .42799 .28844 .42444 Mtetra
.28844 .42444 .29208 .42799 .29769 .42608 .29406 .42253 Mtetra
.29406 .42253 .29769 .42608 .30331 .42417 .29969 .42061 Mtetra
.29969 .42061 .30331 .42417 .30895 .42226 .30534 .41869 Mtetra
.30534 .41869 .30895 .42226 .3146 .42034 .31099 .41676 Mtetra
.663 .74 .907 r
.31099 .41676 .3146 .42034 .32026 .41842 .31666 .41483 Mtetra
.31666 .41483 .32026 .41842 .32593 .41649 .32234 .41289 Mtetra
.32234 .41289 .32593 .41649 .33161 .41456 .32803 .41095 Mtetra
.32803 .41095 .33161 .41456 .33731 .41263 .33374 .40901 Mtetra
.663 .739 .906 r
.33374 .40901 .33731 .41263 .34302 .41069 .33945 .40706 Mtetra
.33945 .40706 .34302 .41069 .34874 .40875 .34518 .40511 Mtetra
.34518 .40511 .34874 .40875 .35447 .4068 .35092 .40316 Mtetra
.35092 .40316 .35447 .4068 .36022 .40485 .35667 .4012 Mtetra
.35667 .4012 .36022 .40485 .36598 .4029 .36244 .39923 Mtetra
.36244 .39923 .36598 .4029 .37175 .40094 .36822 .39726 Mtetra
.36822 .39726 .37175 .40094 .37753 .39898 .37401 .39529 Mtetra
.663 .738 .906 r
.37401 .39529 .37753 .39898 .38333 .39702 .37981 .39332 Mtetra
.663 .738 .905 r
.37981 .39332 .38333 .39702 .38913 .39505 .38563 .39133 Mtetra
.38563 .39133 .38913 .39505 .39495 .39308 .39146 .38935 Mtetra
.663 .737 .905 r
.39146 .38935 .39495 .39308 .40079 .3911 .3973 .38736 Mtetra
.3973 .38736 .40079 .3911 .40663 .38913 .40315 .38537 Mtetra
.663 .737 .904 r
.40315 .38537 .40663 .38913 .41249 .38715 .40902 .38337 Mtetra
.663 .736 .904 r
.40902 .38337 .41249 .38715 .41836 .38516 .4149 .38137 Mtetra
.663 .735 .903 r
.4149 .38137 .41836 .38516 .42425 .38318 .42079 .37936 Mtetra
.42079 .37936 .42425 .38318 .43014 .38119 .4267 .37735 Mtetra
.663 .734 .902 r
.4267 .37735 .43014 .38119 .43605 .3792 .43261 .37534 Mtetra
.663 .733 .901 r
.43261 .37534 .43605 .3792 .44198 .37722 .43855 .37332 Mtetra
.663 .731 .9 r
.43855 .37332 .44198 .37722 .44791 .37524 .44449 .3713 Mtetra
.663 .73 .899 r
.44449 .3713 .44791 .37524 .45386 .37326 .45045 .36927 Mtetra
.663 .727 .898 r
.45045 .36927 .45386 .37326 .45982 .37129 .45642 .36724 Mtetra
.662 .725 .895 r
.45642 .36724 .45982 .37129 .4658 .36934 .4624 .36521 Mtetra
.662 .721 .892 r
.4624 .36521 .4658 .36934 .47178 .36742 .4684 .36318 Mtetra
.661 .715 .888 r
.4684 .36318 .47178 .36742 .47778 .36556 .47441 .36115 Mtetra
.66 .707 .882 r
.47441 .36115 .47778 .36556 .4838 .36378 .48043 .35913 Mtetra
.658 .694 .873 r
.48043 .35913 .4838 .36378 .48982 .36218 .48647 .35712 Mtetra
.653 .675 .858 r
.48647 .35712 .48982 .36218 .49586 .36093 .49252 .35515 Mtetra
.644 .643 .834 r
.49252 .35515 .49586 .36093 .50191 .3605 .49858 .35326 Mtetra
.624 .589 .794 r
.49858 .35326 .50191 .3605 .50796 .36244 .50465 .35163 Mtetra
.57 .492 .727 r
.50465 .35163 .50796 .36244 .51401 .37507 .51074 .35116 Mtetra
.097 .075 .541 r
.51074 .35116 .51401 .37507 .51986 .56897 .5168 .36932 Mtetra
.548 .335 .543 r
.5168 .36932 .51986 .56897 .52638 .56701 .52296 .36725 Mtetra
.586 .364 .547 r
.52296 .36725 .52638 .56701 .53246 .36888 .52911 .34491 Mtetra
.606 .435 .624 r
.52911 .34491 .53246 .36888 .53858 .35208 .53525 .34121 Mtetra
.632 .529 .718 r
.53525 .34121 .53858 .35208 .54472 .34598 .54141 .33867 Mtetra
.649 .602 .788 r
.54141 .33867 .54472 .34598 .55088 .34226 .54758 .33639 Mtetra
.657 .649 .83 r
.54758 .33639 .55088 .34226 .55705 .33935 .55377 .33419 Mtetra
.66 .678 .856 r
.55377 .33419 .55705 .33935 .56324 .3368 .55997 .33203 Mtetra
.662 .696 .871 r
.55997 .33203 .56324 .3368 .56944 .33442 .56618 .32989 Mtetra
.663 .708 .881 r
.56618 .32989 .56944 .33442 .57566 .33214 .57241 .32775 Mtetra
.663 .716 .887 r
.57241 .32775 .57566 .33214 .58189 .3299 .57865 .32561 Mtetra
.663 .721 .892 r
.57865 .32561 .58189 .3299 .58814 .3277 .58491 .32347 Mtetra
.663 .725 .895 r
.58491 .32347 .58814 .3277 .5944 .32551 .59118 .32132 Mtetra
.663 .728 .897 r
.59118 .32132 .5944 .32551 .60067 .32333 .59746 .31918 Mtetra
.663 .73 .899 r
.59746 .31918 .60067 .32333 .60696 .32116 .60376 .31703 Mtetra
.663 .732 .9 r
.60376 .31703 .60696 .32116 .61326 .31899 .61007 .31487 Mtetra
.663 .733 .901 r
.61007 .31487 .61326 .31899 .61958 .31682 .6164 .31272 Mtetra
.663 .734 .902 r
.6164 .31272 .61958 .31682 .62591 .31466 .62274 .31055 Mtetra
.663 .735 .903 r
.62274 .31055 .62591 .31466 .63226 .31248 .6291 .30839 Mtetra
.6291 .30839 .63226 .31248 .63862 .31031 .63547 .30622 Mtetra
.663 .736 .904 r
.63547 .30622 .63862 .31031 .64499 .30813 .64185 .30404 Mtetra
.663 .737 .904 r
.64185 .30404 .64499 .30813 .65138 .30595 .64825 .30186 Mtetra
.663 .737 .905 r
.64825 .30186 .65138 .30595 .65779 .30377 .65467 .29967 Mtetra
.65467 .29967 .65779 .30377 .66421 .30158 .6611 .29748 Mtetra
.663 .738 .905 r
.6611 .29748 .66421 .30158 .67064 .29939 .66754 .29528 Mtetra
.66754 .29528 .67064 .29939 .67709 .29719 .674 .29308 Mtetra
.663 .738 .906 r
.674 .29308 .67709 .29719 .68355 .29499 .68047 .29088 Mtetra
.664 .739 .906 r
.68047 .29088 .68355 .29499 .69003 .29279 .68696 .28867 Mtetra
.68696 .28867 .69003 .29279 .69652 .29058 .69346 .28645 Mtetra
.69346 .28645 .69652 .29058 .70303 .28837 .69998 .28423 Mtetra
.69998 .28423 .70303 .28837 .70955 .28615 .70651 .282 Mtetra
.70651 .282 .70955 .28615 .71609 .28392 .71306 .27977 Mtetra
.71306 .27977 .71609 .28392 .72264 .28169 .71962 .27754 Mtetra
.71962 .27754 .72264 .28169 .72921 .27946 .7262 .2753 Mtetra
.664 .74 .907 r
.7262 .2753 .72921 .27946 .73579 .27722 .73279 .27305 Mtetra
.73279 .27305 .73579 .27722 .74239 .27498 .7394 .2708 Mtetra
.7394 .2708 .74239 .27498 .749 .27273 .74602 .26854 Mtetra
.74602 .26854 .749 .27273 .75563 .27047 .75266 .26628 Mtetra
.75266 .26628 .75563 .27047 .76227 .26822 .75932 .26401 Mtetra
.75932 .26401 .76227 .26822 .76893 .26595 .76599 .26174 Mtetra
.76599 .26174 .76893 .26595 .77561 .26368 .77267 .25946 Mtetra
.77267 .25946 .77561 .26368 .7823 .26141 .77938 .25718 Mtetra
.77938 .25718 .7823 .26141 .789 .25913 .78609 .25489 Mtetra
.78609 .25489 .789 .25913 .79572 .25684 .79282 .25259 Mtetra
.79282 .25259 .79572 .25684 .80246 .25455 .79957 .25029 Mtetra
.79957 .25029 .80246 .25455 .80921 .25226 .80634 .24799 Mtetra
.80634 .24799 .80921 .25226 .81598 .24996 .81312 .24568 Mtetra
.81312 .24568 .81598 .24996 .82277 .24765 .81991 .24336 Mtetra
.81991 .24336 .82277 .24765 .82957 .24534 .82672 .24104 Mtetra
.82672 .24104 .82957 .24534 .83638 .24302 .83355 .23872 Mtetra
.83355 .23872 .83638 .24302 .84322 .2407 .8404 .23639 Mtetra
.664 .741 .908 r
.22919 .4399 .23291 .44336 .23841 .44149 .23469 .43802 Mtetra
.23469 .43802 .23841 .44149 .24392 .43961 .24021 .43613 Mtetra
.24021 .43613 .24392 .43961 .24944 .43773 .24574 .43424 Mtetra
.24574 .43424 .24944 .43773 .25498 .43584 .25129 .43235 Mtetra
.25129 .43235 .25498 .43584 .26053 .43395 .25684 .43045 Mtetra
.25684 .43045 .26053 .43395 .26609 .43206 .26241 .42855 Mtetra
.26241 .42855 .26609 .43206 .27166 .43016 .26799 .42664 Mtetra
.26799 .42664 .27166 .43016 .27724 .42826 .27358 .42473 Mtetra
.27358 .42473 .27724 .42826 .28284 .42635 .27918 .42282 Mtetra
.27918 .42282 .28284 .42635 .28844 .42444 .28479 .4209 Mtetra
.28479 .4209 .28844 .42444 .29406 .42253 .29042 .41898 Mtetra
.29042 .41898 .29406 .42253 .29969 .42061 .29606 .41705 Mtetra
.29606 .41705 .29969 .42061 .30534 .41869 .30171 .41512 Mtetra
.30171 .41512 .30534 .41869 .31099 .41676 .30737 .41319 Mtetra
.30737 .41319 .31099 .41676 .31666 .41483 .31305 .41125 Mtetra
.31305 .41125 .31666 .41483 .32234 .41289 .31873 .40931 Mtetra
.31873 .40931 .32234 .41289 .32803 .41095 .32443 .40736 Mtetra
.32443 .40736 .32803 .41095 .33374 .40901 .33014 .40541 Mtetra
.33014 .40541 .33374 .40901 .33945 .40706 .33587 .40345 Mtetra
.33587 .40345 .33945 .40706 .34518 .40511 .3416 .4015 Mtetra
.3416 .4015 .34518 .40511 .35092 .40316 .34735 .39953 Mtetra
.34735 .39953 .35092 .40316 .35667 .4012 .35311 .39756 Mtetra
.35311 .39756 .35667 .4012 .36244 .39923 .35889 .39559 Mtetra
.35889 .39559 .36244 .39923 .36822 .39726 .36467 .39361 Mtetra
.36467 .39361 .36822 .39726 .37401 .39529 .37047 .39163 Mtetra
.37047 .39163 .37401 .39529 .37981 .39332 .37628 .38965 Mtetra
.37628 .38965 .37981 .39332 .38563 .39133 .38211 .38766 Mtetra
.38211 .38766 .38563 .39133 .39146 .38935 .38794 .38567 Mtetra
.38794 .38567 .39146 .38935 .3973 .38736 .39379 .38367 Mtetra
.39379 .38367 .3973 .38736 .40315 .38537 .39965 .38167 Mtetra
.39965 .38167 .40315 .38537 .40902 .38337 .40553 .37966 Mtetra
.40553 .37966 .40902 .38337 .4149 .38137 .41142 .37765 Mtetra
.41142 .37765 .4149 .38137 .42079 .37936 .41732 .37563 Mtetra
.663 .741 .908 r
.41732 .37563 .42079 .37936 .4267 .37735 .42323 .37361 Mtetra
.663 .741 .907 r
.42323 .37361 .4267 .37735 .43261 .37534 .42916 .37159 Mtetra
.42916 .37159 .43261 .37534 .43855 .37332 .4351 .36956 Mtetra
.663 .74 .907 r
.4351 .36956 .43855 .37332 .44449 .3713 .44105 .36753 Mtetra
.44105 .36753 .44449 .3713 .45045 .36927 .44702 .36549 Mtetra
.44702 .36549 .45045 .36927 .45642 .36724 .45299 .36345 Mtetra
.45299 .36345 .45642 .36724 .4624 .36521 .45899 .36141 Mtetra
.45899 .36141 .4624 .36521 .4684 .36318 .46499 .35936 Mtetra
.663 .739 .906 r
.46499 .35936 .4684 .36318 .47441 .36115 .47101 .35731 Mtetra
.663 .738 .906 r
.47101 .35731 .47441 .36115 .48043 .35913 .47704 .35526 Mtetra
.662 .737 .905 r
.47704 .35526 .48043 .35913 .48647 .35712 .48309 .35321 Mtetra
.661 .735 .904 r
.48309 .35321 .48647 .35712 .49252 .35515 .48915 .35117 Mtetra
.659 .731 .903 r
.48915 .35117 .49252 .35515 .49858 .35326 .49522 .34916 Mtetra
.653 .723 .9 r
.49522 .34916 .49858 .35326 .50465 .35163 .5013 .34724 Mtetra
.627 .698 .896 r
.5013 .34724 .50465 .35163 .51074 .35116 .5074 .34572 Mtetra
0 .264 .771 r
.5074 .34572 .51074 .35116 .5168 .36932 .51349 .35069 Mtetra
.593 .445 .649 r
.51349 .35069 .5168 .36932 .52296 .36725 .51963 .3486 Mtetra
.694 .513 .638 r
.51963 .3486 .52296 .36725 .52911 .34491 .52578 .33944 Mtetra
.681 .673 .835 r
.52578 .33944 .52911 .34491 .53525 .34121 .53194 .33677 Mtetra
.67 .714 .881 r
.53194 .33677 .53525 .34121 .54141 .33867 .53811 .33451 Mtetra
.667 .727 .895 r
.53811 .33451 .54141 .33867 .54758 .33639 .54429 .33234 Mtetra
.665 .733 .9 r
.54429 .33234 .54758 .33639 .55377 .33419 .55048 .33019 Mtetra
.664 .736 .903 r
.55048 .33019 .55377 .33419 .55997 .33203 .55669 .32805 Mtetra
.664 .738 .905 r
.55669 .32805 .55997 .33203 .56618 .32989 .56291 .32592 Mtetra
.664 .739 .906 r
.56291 .32592 .56618 .32989 .57241 .32775 .56915 .32378 Mtetra
.56915 .32378 .57241 .32775 .57865 .32561 .5754 .32164 Mtetra
.664 .74 .907 r
.5754 .32164 .57865 .32561 .58491 .32347 .58167 .3195 Mtetra
.58167 .3195 .58491 .32347 .59118 .32132 .58795 .31735 Mtetra
.58795 .31735 .59118 .32132 .59746 .31918 .59424 .3152 Mtetra
.59424 .3152 .59746 .31918 .60376 .31703 .60055 .31304 Mtetra
.664 .741 .907 r
.60055 .31304 .60376 .31703 .61007 .31487 .60687 .31088 Mtetra
.60687 .31088 .61007 .31487 .6164 .31272 .61321 .30871 Mtetra
.61321 .30871 .6164 .31272 .62274 .31055 .61956 .30654 Mtetra
.61956 .30654 .62274 .31055 .6291 .30839 .62593 .30437 Mtetra
.664 .741 .908 r
.62593 .30437 .6291 .30839 .63547 .30622 .63231 .30219 Mtetra
.63231 .30219 .63547 .30622 .64185 .30404 .6387 .3 Mtetra
.6387 .3 .64185 .30404 .64825 .30186 .64511 .29781 Mtetra
.64511 .29781 .64825 .30186 .65467 .29967 .65154 .29562 Mtetra
.65154 .29562 .65467 .29967 .6611 .29748 .65797 .29342 Mtetra
.65797 .29342 .6611 .29748 .66754 .29528 .66443 .29121 Mtetra
.66443 .29121 .66754 .29528 .674 .29308 .6709 .289 Mtetra
.6709 .289 .674 .29308 .68047 .29088 .67738 .28679 Mtetra
.67738 .28679 .68047 .29088 .68696 .28867 .68388 .28457 Mtetra
.68388 .28457 .68696 .28867 .69346 .28645 .69039 .28234 Mtetra
.69039 .28234 .69346 .28645 .69998 .28423 .69692 .28011 Mtetra
.69692 .28011 .69998 .28423 .70651 .282 .70346 .27788 Mtetra
.70346 .27788 .70651 .282 .71306 .27977 .71002 .27564 Mtetra
.71002 .27564 .71306 .27977 .71962 .27754 .71659 .27339 Mtetra
.71659 .27339 .71962 .27754 .7262 .2753 .72318 .27114 Mtetra
.72318 .27114 .7262 .2753 .73279 .27305 .72978 .26889 Mtetra
.72978 .26889 .73279 .27305 .7394 .2708 .7364 .26662 Mtetra
.7364 .26662 .7394 .2708 .74602 .26854 .74304 .26436 Mtetra
.74304 .26436 .74602 .26854 .75266 .26628 .74969 .26209 Mtetra
.74969 .26209 .75266 .26628 .75932 .26401 .75635 .25981 Mtetra
.75635 .25981 .75932 .26401 .76599 .26174 .76303 .25753 Mtetra
.76303 .25753 .76599 .26174 .77267 .25946 .76973 .25524 Mtetra
.76973 .25524 .77267 .25946 .77938 .25718 .77644 .25295 Mtetra
.77644 .25295 .77938 .25718 .78609 .25489 .78317 .25065 Mtetra
.78317 .25065 .78609 .25489 .79282 .25259 .78991 .24834 Mtetra
.78991 .24834 .79282 .25259 .79957 .25029 .79667 .24603 Mtetra
.79667 .24603 .79957 .25029 .80634 .24799 .80345 .24372 Mtetra
.80345 .24372 .80634 .24799 .81312 .24568 .81024 .2414 Mtetra
.81024 .2414 .81312 .24568 .81991 .24336 .81705 .23907 Mtetra
.81705 .23907 .81991 .24336 .82672 .24104 .82387 .23674 Mtetra
.82387 .23674 .82672 .24104 .83355 .23872 .83071 .23441 Mtetra
.83071 .23441 .83355 .23872 .8404 .23639 .83757 .23206 Mtetra
.22545 .43642 .22919 .4399 .23469 .43802 .23097 .43453 Mtetra
.23097 .43453 .23469 .43802 .24021 .43613 .23649 .43264 Mtetra
.23649 .43264 .24021 .43613 .24574 .43424 .24203 .43074 Mtetra
.24203 .43074 .24574 .43424 .25129 .43235 .24758 .42884 Mtetra
.24758 .42884 .25129 .43235 .25684 .43045 .25314 .42694 Mtetra
.25314 .42694 .25684 .43045 .26241 .42855 .25872 .42503 Mtetra
.25872 .42503 .26241 .42855 .26799 .42664 .2643 .42311 Mtetra
.2643 .42311 .26799 .42664 .27358 .42473 .2699 .4212 Mtetra
.2699 .4212 .27358 .42473 .27918 .42282 .27551 .41928 Mtetra
.27551 .41928 .27918 .42282 .28479 .4209 .28113 .41735 Mtetra
.28113 .41735 .28479 .4209 .29042 .41898 .28676 .41542 Mtetra
.28676 .41542 .29042 .41898 .29606 .41705 .29241 .41349 Mtetra
.29241 .41349 .29606 .41705 .30171 .41512 .29807 .41155 Mtetra
.29807 .41155 .30171 .41512 .30737 .41319 .30374 .40961 Mtetra
.30374 .40961 .30737 .41319 .31305 .41125 .30942 .40766 Mtetra
.30942 .40766 .31305 .41125 .31873 .40931 .31511 .40571 Mtetra
.31511 .40571 .31873 .40931 .32443 .40736 .32082 .40375 Mtetra
.32082 .40375 .32443 .40736 .33014 .40541 .32654 .4018 Mtetra
.32654 .4018 .33014 .40541 .33587 .40345 .33227 .39983 Mtetra
.33227 .39983 .33587 .40345 .3416 .4015 .33801 .39787 Mtetra
.33801 .39787 .3416 .4015 .34735 .39953 .34377 .39589 Mtetra
.34377 .39589 .34735 .39953 .35311 .39756 .34954 .39392 Mtetra
.34954 .39392 .35311 .39756 .35889 .39559 .35532 .39194 Mtetra
.35532 .39194 .35889 .39559 .36467 .39361 .36111 .38995 Mtetra
.36111 .38995 .36467 .39361 .37047 .39163 .36692 .38796 Mtetra
.36692 .38796 .37047 .39163 .37628 .38965 .37274 .38597 Mtetra
.37274 .38597 .37628 .38965 .38211 .38766 .37857 .38397 Mtetra
.37857 .38397 .38211 .38766 .38794 .38567 .38442 .38197 Mtetra
.38442 .38197 .38794 .38567 .39379 .38367 .39027 .37997 Mtetra
.39027 .37997 .39379 .38367 .39965 .38167 .39614 .37796 Mtetra
.39614 .37796 .39965 .38167 .40553 .37966 .40203 .37594 Mtetra
.40203 .37594 .40553 .37966 .41142 .37765 .40792 .37392 Mtetra
.40792 .37392 .41142 .37765 .41732 .37563 .41383 .3719 Mtetra
.41383 .3719 .41732 .37563 .42323 .37361 .41975 .36987 Mtetra
.41975 .36987 .42323 .37361 .42916 .37159 .42569 .36784 Mtetra
.42569 .36784 .42916 .37159 .4351 .36956 .43163 .3658 Mtetra
.43163 .3658 .4351 .36956 .44105 .36753 .43759 .36376 Mtetra
.663 .741 .908 r
.43759 .36376 .44105 .36753 .44702 .36549 .44357 .36171 Mtetra
.44357 .36171 .44702 .36549 .45299 .36345 .44956 .35966 Mtetra
.44956 .35966 .45299 .36345 .45899 .36141 .45556 .35761 Mtetra
.45556 .35761 .45899 .36141 .46499 .35936 .46157 .35555 Mtetra
.46157 .35555 .46499 .35936 .47101 .35731 .4676 .35349 Mtetra
.663 .74 .907 r
.4676 .35349 .47101 .35731 .47704 .35526 .47364 .35143 Mtetra
.47364 .35143 .47704 .35526 .48309 .35321 .47969 .34936 Mtetra
.663 .739 .907 r
.47969 .34936 .48309 .35321 .48915 .35117 .48576 .3473 Mtetra
.662 .738 .907 r
.48576 .3473 .48915 .35117 .49522 .34916 .49184 .34525 Mtetra
.659 .735 .906 r
.49184 .34525 .49522 .34916 .5013 .34724 .49793 .34323 Mtetra
.646 .727 .908 r
.49793 .34323 .5013 .34724 .5074 .34572 .50404 .34142 Mtetra
.351 .572 .923 r
.50404 .34142 .5074 .34572 .51349 .35069 .51015 .34279 Mtetra
.638 .582 .775 r
.51015 .34279 .51349 .35069 .51963 .3486 .51629 .34069 Mtetra
.736 .63 .742 r
.51629 .34069 .51963 .3486 .52578 .33944 .52245 .33512 Mtetra
.678 .723 .883 r
.52245 .33512 .52578 .33944 .53194 .33677 .52861 .33273 Mtetra
.668 .734 .9 r
.52861 .33273 .53194 .33677 .53811 .33451 .53479 .33054 Mtetra
.665 .738 .904 r
.53479 .33054 .53811 .33451 .54429 .33234 .54098 .32838 Mtetra
.664 .739 .906 r
.54098 .32838 .54429 .33234 .55048 .33019 .54718 .32624 Mtetra
.664 .74 .907 r
.54718 .32624 .55048 .33019 .55669 .32805 .5534 .32411 Mtetra
.5534 .32411 .55669 .32805 .56291 .32592 .55964 .32197 Mtetra
.664 .741 .907 r
.55964 .32197 .56291 .32592 .56915 .32378 .56588 .31982 Mtetra
.56588 .31982 .56915 .32378 .5754 .32164 .57214 .31768 Mtetra
.664 .741 .908 r
.57214 .31768 .5754 .32164 .58167 .3195 .57842 .31553 Mtetra
.57842 .31553 .58167 .3195 .58795 .31735 .58471 .31337 Mtetra
.58471 .31337 .58795 .31735 .59424 .3152 .59101 .31121 Mtetra
.59101 .31121 .59424 .3152 .60055 .31304 .59733 .30905 Mtetra
.59733 .30905 .60055 .31304 .60687 .31088 .60366 .30688 Mtetra
.60366 .30688 .60687 .31088 .61321 .30871 .61001 .3047 Mtetra
.61001 .3047 .61321 .30871 .61956 .30654 .61637 .30252 Mtetra
.61637 .30252 .61956 .30654 .62593 .30437 .62274 .30034 Mtetra
.62274 .30034 .62593 .30437 .63231 .30219 .62913 .29815 Mtetra
.62913 .29815 .63231 .30219 .6387 .3 .63554 .29596 Mtetra
.63554 .29596 .6387 .3 .64511 .29781 .64196 .29376 Mtetra
.64196 .29376 .64511 .29781 .65154 .29562 .64839 .29155 Mtetra
.64839 .29155 .65154 .29562 .65797 .29342 .65484 .28934 Mtetra
.65484 .28934 .65797 .29342 .66443 .29121 .6613 .28713 Mtetra
.6613 .28713 .66443 .29121 .6709 .289 .66778 .28491 Mtetra
.66778 .28491 .6709 .289 .67738 .28679 .67427 .28269 Mtetra
.67427 .28269 .67738 .28679 .68388 .28457 .68078 .28046 Mtetra
.68078 .28046 .68388 .28457 .69039 .28234 .68731 .27822 Mtetra
.68731 .27822 .69039 .28234 .69692 .28011 .69384 .27598 Mtetra
.69384 .27598 .69692 .28011 .70346 .27788 .7004 .27374 Mtetra
.7004 .27374 .70346 .27788 .71002 .27564 .70697 .27149 Mtetra
.70697 .27149 .71002 .27564 .71659 .27339 .71355 .26923 Mtetra
.71355 .26923 .71659 .27339 .72318 .27114 .72015 .26697 Mtetra
.72015 .26697 .72318 .27114 .72978 .26889 .72676 .26471 Mtetra
.72676 .26471 .72978 .26889 .7364 .26662 .73339 .26244 Mtetra
.73339 .26244 .7364 .26662 .74304 .26436 .74004 .26016 Mtetra
.74004 .26016 .74304 .26436 .74969 .26209 .7467 .25788 Mtetra
.7467 .25788 .74969 .26209 .75635 .25981 .75338 .25559 Mtetra
.75338 .25559 .75635 .25981 .76303 .25753 .76007 .2533 Mtetra
.76007 .2533 .76303 .25753 .76973 .25524 .76678 .251 Mtetra
.76678 .251 .76973 .25524 .77644 .25295 .7735 .2487 Mtetra
.7735 .2487 .77644 .25295 .78317 .25065 .78024 .24639 Mtetra
.78024 .24639 .78317 .25065 .78991 .24834 .78699 .24408 Mtetra
.78699 .24408 .78991 .24834 .79667 .24603 .79376 .24176 Mtetra
.79376 .24176 .79667 .24603 .80345 .24372 .80055 .23943 Mtetra
.80055 .23943 .80345 .24372 .81024 .2414 .80735 .2371 Mtetra
.80735 .2371 .81024 .2414 .81705 .23907 .81417 .23477 Mtetra
.81417 .23477 .81705 .23907 .82387 .23674 .82101 .23242 Mtetra
.82101 .23242 .82387 .23674 .83071 .23441 .82786 .23008 Mtetra
.82786 .23008 .83071 .23441 .83757 .23206 .83472 .22773 Mtetra
.2217 .43293 .22545 .43642 .23097 .43453 .22723 .43103 Mtetra
.22723 .43103 .23097 .43453 .23649 .43264 .23276 .42913 Mtetra
.23276 .42913 .23649 .43264 .24203 .43074 .2383 .42723 Mtetra
.2383 .42723 .24203 .43074 .24758 .42884 .24386 .42532 Mtetra
.24386 .42532 .24758 .42884 .25314 .42694 .24943 .42341 Mtetra
.24943 .42341 .25314 .42694 .25872 .42503 .25501 .42149 Mtetra
.25501 .42149 .25872 .42503 .2643 .42311 .2606 .41957 Mtetra
.2606 .41957 .2643 .42311 .2699 .4212 .26621 .41765 Mtetra
.26621 .41765 .2699 .4212 .27551 .41928 .27182 .41572 Mtetra
.27182 .41572 .27551 .41928 .28113 .41735 .27745 .41378 Mtetra
.27745 .41378 .28113 .41735 .28676 .41542 .28309 .41185 Mtetra
.28309 .41185 .28676 .41542 .29241 .41349 .28875 .40991 Mtetra
.28875 .40991 .29241 .41349 .29807 .41155 .29441 .40796 Mtetra
.29441 .40796 .29807 .41155 .30374 .40961 .30009 .40601 Mtetra
.30009 .40601 .30374 .40961 .30942 .40766 .30578 .40406 Mtetra
.30578 .40406 .30942 .40766 .31511 .40571 .31148 .4021 Mtetra
.31148 .4021 .31511 .40571 .32082 .40375 .31719 .40013 Mtetra
.31719 .40013 .32082 .40375 .32654 .4018 .32292 .39817 Mtetra
.32292 .39817 .32654 .4018 .33227 .39983 .32866 .3962 Mtetra
.32866 .3962 .33227 .39983 .33801 .39787 .33441 .39422 Mtetra
.33441 .39422 .33801 .39787 .34377 .39589 .34017 .39224 Mtetra
.34017 .39224 .34377 .39589 .34954 .39392 .34595 .39026 Mtetra
.34595 .39026 .34954 .39392 .35532 .39194 .35174 .38827 Mtetra
.35174 .38827 .35532 .39194 .36111 .38995 .35754 .38628 Mtetra
.35754 .38628 .36111 .38995 .36692 .38796 .36335 .38428 Mtetra
.36335 .38428 .36692 .38796 .37274 .38597 .36918 .38228 Mtetra
.36918 .38228 .37274 .38597 .37857 .38397 .37502 .38027 Mtetra
.37502 .38027 .37857 .38397 .38442 .38197 .38087 .37826 Mtetra
.38087 .37826 .38442 .38197 .39027 .37997 .38674 .37625 Mtetra
.38674 .37625 .39027 .37997 .39614 .37796 .39262 .37423 Mtetra
.39262 .37423 .39614 .37796 .40203 .37594 .39851 .37221 Mtetra
.39851 .37221 .40203 .37594 .40792 .37392 .40441 .37018 Mtetra
.40441 .37018 .40792 .37392 .41383 .3719 .41033 .36815 Mtetra
.41033 .36815 .41383 .3719 .41975 .36987 .41626 .36611 Mtetra
.41626 .36611 .41975 .36987 .42569 .36784 .4222 .36407 Mtetra
.4222 .36407 .42569 .36784 .43163 .3658 .42816 .36203 Mtetra
.42816 .36203 .43163 .3658 .43759 .36376 .43413 .35998 Mtetra
.43413 .35998 .43759 .36376 .44357 .36171 .44011 .35792 Mtetra
.44011 .35792 .44357 .36171 .44956 .35966 .4461 .35586 Mtetra
.663 .741 .908 r
.4461 .35586 .44956 .35966 .45556 .35761 .45211 .3538 Mtetra
.45211 .3538 .45556 .35761 .46157 .35555 .45813 .35173 Mtetra
.45813 .35173 .46157 .35555 .4676 .35349 .46417 .34966 Mtetra
.46417 .34966 .4676 .35349 .47364 .35143 .47022 .34759 Mtetra
.47022 .34759 .47364 .35143 .47969 .34936 .47628 .34551 Mtetra
.663 .74 .908 r
.47628 .34551 .47969 .34936 .48576 .3473 .48236 .34343 Mtetra
.662 .74 .908 r
.48236 .34343 .48576 .3473 .49184 .34525 .48845 .34136 Mtetra
.661 .739 .908 r
.48845 .34136 .49184 .34525 .49793 .34323 .49455 .33931 Mtetra
.653 .734 .909 r
.49455 .33931 .49793 .34323 .50404 .34142 .50067 .33737 Mtetra
.505 .667 .935 r
.50067 .33737 .50404 .34142 .51015 .34279 .50679 .33727 Mtetra
.655 .661 .844 r
.50679 .33727 .51015 .34279 .51629 .34069 .51293 .33516 Mtetra
.734 .692 .81 r
.51293 .33516 .51629 .34069 .52245 .33512 .5191 .33104 Mtetra
.673 .735 .897 r
.5191 .33104 .52245 .33512 .52861 .33273 .52527 .32876 Mtetra
.666 .739 .904 r
.52527 .32876 .52861 .33273 .53479 .33054 .53146 .32659 Mtetra
.665 .74 .906 r
.53146 .32659 .53479 .33054 .54098 .32838 .53766 .32444 Mtetra
.664 .74 .907 r
.53766 .32444 .54098 .32838 .54718 .32624 .54387 .3223 Mtetra
.664 .741 .907 r
.54387 .3223 .54718 .32624 .5534 .32411 .5501 .32015 Mtetra
.664 .741 .908 r
.5501 .32015 .5534 .32411 .55964 .32197 .55634 .31801 Mtetra
.55634 .31801 .55964 .32197 .56588 .31982 .5626 .31586 Mtetra
.5626 .31586 .56588 .31982 .57214 .31768 .56887 .3137 Mtetra
.56887 .3137 .57214 .31768 .57842 .31553 .57515 .31154 Mtetra
.57515 .31154 .57842 .31553 .58471 .31337 .58145 .30938 Mtetra
.58145 .30938 .58471 .31337 .59101 .31121 .58776 .30721 Mtetra
.58776 .30721 .59101 .31121 .59733 .30905 .59409 .30504 Mtetra
.59409 .30504 .59733 .30905 .60366 .30688 .60043 .30286 Mtetra
.60043 .30286 .60366 .30688 .61001 .3047 .60679 .30067 Mtetra
.60679 .30067 .61001 .3047 .61637 .30252 .61316 .29849 Mtetra
.61316 .29849 .61637 .30252 .62274 .30034 .61955 .29629 Mtetra
.61955 .29629 .62274 .30034 .62913 .29815 .62594 .29409 Mtetra
.62594 .29409 .62913 .29815 .63554 .29596 .63236 .29189 Mtetra
.63236 .29189 .63554 .29596 .64196 .29376 .63879 .28968 Mtetra
.63879 .28968 .64196 .29376 .64839 .29155 .64523 .28747 Mtetra
.64523 .28747 .64839 .29155 .65484 .28934 .65169 .28525 Mtetra
.65169 .28525 .65484 .28934 .6613 .28713 .65817 .28303 Mtetra
.65817 .28303 .6613 .28713 .66778 .28491 .66465 .2808 Mtetra
.66465 .2808 .66778 .28491 .67427 .28269 .67116 .27857 Mtetra
.67116 .27857 .67427 .28269 .68078 .28046 .67768 .27633 Mtetra
.67768 .27633 .68078 .28046 .68731 .27822 .68421 .27408 Mtetra
.68421 .27408 .68731 .27822 .69384 .27598 .69076 .27183 Mtetra
.69076 .27183 .69384 .27598 .7004 .27374 .69732 .26958 Mtetra
.69732 .26958 .7004 .27374 .70697 .27149 .7039 .26732 Mtetra
.7039 .26732 .70697 .27149 .71355 .26923 .7105 .26505 Mtetra
.7105 .26505 .71355 .26923 .72015 .26697 .71711 .26278 Mtetra
.71711 .26278 .72015 .26697 .72676 .26471 .72373 .26051 Mtetra
.72373 .26051 .72676 .26471 .73339 .26244 .73037 .25823 Mtetra
.73037 .25823 .73339 .26244 .74004 .26016 .73703 .25594 Mtetra
.73703 .25594 .74004 .26016 .7467 .25788 .7437 .25365 Mtetra
.7437 .25365 .7467 .25788 .75338 .25559 .75039 .25135 Mtetra
.75039 .25135 .75338 .25559 .76007 .2533 .75709 .24905 Mtetra
.75709 .24905 .76007 .2533 .76678 .251 .76381 .24674 Mtetra
.76381 .24674 .76678 .251 .7735 .2487 .77054 .24443 Mtetra
.77054 .24443 .7735 .2487 .78024 .24639 .77729 .24211 Mtetra
.77729 .24211 .78024 .24639 .78699 .24408 .78406 .23979 Mtetra
.78406 .23979 .78699 .24408 .79376 .24176 .79084 .23746 Mtetra
.79084 .23746 .79376 .24176 .80055 .23943 .79764 .23513 Mtetra
.79764 .23513 .80055 .23943 .80735 .2371 .80445 .23279 Mtetra
.80445 .23279 .80735 .2371 .81417 .23477 .81128 .23044 Mtetra
.81128 .23044 .81417 .23477 .82101 .23242 .81813 .22809 Mtetra
.81813 .22809 .82101 .23242 .82786 .23008 .82499 .22573 Mtetra
.82499 .22573 .82786 .23008 .83472 .22773 .83187 .22337 Mtetra
.21794 .42943 .2217 .43293 .22723 .43103 .22347 .42752 Mtetra
.22347 .42752 .22723 .43103 .23276 .42913 .22901 .42561 Mtetra
.22901 .42561 .23276 .42913 .2383 .42723 .23456 .4237 Mtetra
.23456 .4237 .2383 .42723 .24386 .42532 .24012 .42179 Mtetra
.24012 .42179 .24386 .42532 .24943 .42341 .2457 .41987 Mtetra
.2457 .41987 .24943 .42341 .25501 .42149 .25129 .41794 Mtetra
.25129 .41794 .25501 .42149 .2606 .41957 .25689 .41601 Mtetra
.25689 .41601 .2606 .41957 .26621 .41765 .2625 .41408 Mtetra
.2625 .41408 .26621 .41765 .27182 .41572 .26812 .41214 Mtetra
.26812 .41214 .27182 .41572 .27745 .41378 .27376 .4102 Mtetra
.27376 .4102 .27745 .41378 .28309 .41185 .27941 .40826 Mtetra
.27941 .40826 .28309 .41185 .28875 .40991 .28507 .40631 Mtetra
.28507 .40631 .28875 .40991 .29441 .40796 .29074 .40436 Mtetra
.29074 .40436 .29441 .40796 .30009 .40601 .29642 .4024 Mtetra
.29642 .4024 .30009 .40601 .30578 .40406 .30212 .40044 Mtetra
.30212 .40044 .30578 .40406 .31148 .4021 .30783 .39847 Mtetra
.30783 .39847 .31148 .4021 .31719 .40013 .31355 .3965 Mtetra
.31355 .3965 .31719 .40013 .32292 .39817 .31929 .39453 Mtetra
.31929 .39453 .32292 .39817 .32866 .3962 .32503 .39255 Mtetra
.32503 .39255 .32866 .3962 .33441 .39422 .33079 .39056 Mtetra
.33079 .39056 .33441 .39422 .34017 .39224 .33656 .38858 Mtetra
.33656 .38858 .34017 .39224 .34595 .39026 .34235 .38658 Mtetra
.34235 .38658 .34595 .39026 .35174 .38827 .34814 .38459 Mtetra
.34814 .38459 .35174 .38827 .35754 .38628 .35395 .38259 Mtetra
.35395 .38259 .35754 .38628 .36335 .38428 .35977 .38058 Mtetra
.35977 .38058 .36335 .38428 .36918 .38228 .36561 .37857 Mtetra
.36561 .37857 .36918 .38228 .37502 .38027 .37146 .37656 Mtetra
.37146 .37656 .37502 .38027 .38087 .37826 .37732 .37454 Mtetra
.37732 .37454 .38087 .37826 .38674 .37625 .38319 .37252 Mtetra
.38319 .37252 .38674 .37625 .39262 .37423 .38907 .37049 Mtetra
.38907 .37049 .39262 .37423 .39851 .37221 .39497 .36846 Mtetra
.39497 .36846 .39851 .37221 .40441 .37018 .40089 .36643 Mtetra
.40089 .36643 .40441 .37018 .41033 .36815 .40681 .36438 Mtetra
.40681 .36438 .41033 .36815 .41626 .36611 .41275 .36234 Mtetra
.41275 .36234 .41626 .36611 .4222 .36407 .4187 .36029 Mtetra
.4187 .36029 .4222 .36407 .42816 .36203 .42466 .35824 Mtetra
.42466 .35824 .42816 .36203 .43413 .35998 .43064 .35618 Mtetra
.43064 .35618 .43413 .35998 .44011 .35792 .43663 .35412 Mtetra
.43663 .35412 .44011 .35792 .4461 .35586 .44264 .35205 Mtetra
.44264 .35205 .4461 .35586 .45211 .3538 .44865 .34998 Mtetra
.663 .741 .908 r
.44865 .34998 .45211 .3538 .45813 .35173 .45469 .3479 Mtetra
.45469 .3479 .45813 .35173 .46417 .34966 .46073 .34582 Mtetra
.46073 .34582 .46417 .34966 .47022 .34759 .46679 .34374 Mtetra
.46679 .34374 .47022 .34759 .47628 .34551 .47286 .34165 Mtetra
.47286 .34165 .47628 .34551 .48236 .34343 .47894 .33956 Mtetra
.47894 .33956 .48236 .34343 .48845 .34136 .48504 .33747 Mtetra
.662 .74 .908 r
.48504 .33747 .48845 .34136 .49455 .33931 .49115 .33539 Mtetra
.657 .737 .909 r
.49115 .33539 .49455 .33931 .50067 .33737 .49728 .33339 Mtetra
.569 .701 .93 r
.49728 .33339 .50067 .33737 .50679 .33727 .50341 .33256 Mtetra
.66 .699 .875 r
.50341 .33256 .50679 .33727 .51293 .33516 .50957 .33044 Mtetra
.721 .72 .848 r
.50957 .33044 .51293 .33516 .5191 .33104 .51574 .32703 Mtetra
.67 .738 .902 r
.51574 .32703 .5191 .33104 .52527 .32876 .52192 .3248 Mtetra
.665 .74 .906 r
.52192 .3248 .52527 .32876 .53146 .32659 .52812 .32264 Mtetra
.664 .741 .907 r
.52812 .32264 .53146 .32659 .53766 .32444 .53432 .32049 Mtetra
.53432 .32049 .53766 .32444 .54387 .3223 .54055 .31834 Mtetra
.664 .741 .908 r
.54055 .31834 .54387 .3223 .5501 .32015 .54678 .31619 Mtetra
.54678 .31619 .5501 .32015 .55634 .31801 .55304 .31403 Mtetra
.55304 .31403 .55634 .31801 .5626 .31586 .5593 .31187 Mtetra
.5593 .31187 .5626 .31586 .56887 .3137 .56558 .30971 Mtetra
.56558 .30971 .56887 .3137 .57515 .31154 .57187 .30754 Mtetra
.57187 .30754 .57515 .31154 .58145 .30938 .57818 .30537 Mtetra
.57818 .30537 .58145 .30938 .58776 .30721 .5845 .30319 Mtetra
.5845 .30319 .58776 .30721 .59409 .30504 .59084 .30101 Mtetra
.59084 .30101 .59409 .30504 .60043 .30286 .59719 .29882 Mtetra
.59719 .29882 .60043 .30286 .60679 .30067 .60356 .29663 Mtetra
.60356 .29663 .60679 .30067 .61316 .29849 .60994 .29443 Mtetra
.60994 .29443 .61316 .29849 .61955 .29629 .61633 .29223 Mtetra
.61633 .29223 .61955 .29629 .62594 .29409 .62274 .29002 Mtetra
.62274 .29002 .62594 .29409 .63236 .29189 .62917 .28781 Mtetra
.62917 .28781 .63236 .29189 .63879 .28968 .63561 .28559 Mtetra
.63561 .28559 .63879 .28968 .64523 .28747 .64206 .28337 Mtetra
.64206 .28337 .64523 .28747 .65169 .28525 .64853 .28114 Mtetra
.64853 .28114 .65169 .28525 .65817 .28303 .65501 .27891 Mtetra
.65501 .27891 .65817 .28303 .66465 .2808 .66151 .27667 Mtetra
.66151 .27667 .66465 .2808 .67116 .27857 .66803 .27443 Mtetra
.66803 .27443 .67116 .27857 .67768 .27633 .67456 .27218 Mtetra
.67456 .27218 .67768 .27633 .68421 .27408 .6811 .26993 Mtetra
.6811 .26993 .68421 .27408 .69076 .27183 .68766 .26767 Mtetra
.68766 .26767 .69076 .27183 .69732 .26958 .69423 .2654 Mtetra
.69423 .2654 .69732 .26958 .7039 .26732 .70082 .26313 Mtetra
.70082 .26313 .7039 .26732 .7105 .26505 .70743 .26086 Mtetra
.70743 .26086 .7105 .26505 .71711 .26278 .71405 .25858 Mtetra
.71405 .25858 .71711 .26278 .72373 .26051 .72068 .25629 Mtetra
.72068 .25629 .72373 .26051 .73037 .25823 .72733 .254 Mtetra
.72733 .254 .73037 .25823 .73703 .25594 .734 .25171 Mtetra
.734 .25171 .73703 .25594 .7437 .25365 .74068 .24941 Mtetra
.74068 .24941 .7437 .25365 .75039 .25135 .74738 .2471 Mtetra
.74738 .2471 .75039 .25135 .75709 .24905 .7541 .24479 Mtetra
.7541 .24479 .75709 .24905 .76381 .24674 .76083 .24247 Mtetra
.76083 .24247 .76381 .24674 .77054 .24443 .76757 .24015 Mtetra
.76757 .24015 .77054 .24443 .77729 .24211 .77433 .23782 Mtetra
.77433 .23782 .77729 .24211 .78406 .23979 .78111 .23549 Mtetra
.78111 .23549 .78406 .23979 .79084 .23746 .7879 .23315 Mtetra
.7879 .23315 .79084 .23746 .79764 .23513 .79471 .2308 Mtetra
.79471 .2308 .79764 .23513 .80445 .23279 .80154 .22845 Mtetra
.80154 .22845 .80445 .23279 .81128 .23044 .80838 .22609 Mtetra
.80838 .22609 .81128 .23044 .81813 .22809 .81524 .22373 Mtetra
.81524 .22373 .81813 .22809 .82499 .22573 .82211 .22137 Mtetra
.82211 .22137 .82499 .22573 .83187 .22337 .829 .21899 Mtetra
.21416 .42591 .21794 .42943 .22347 .42752 .2197 .424 Mtetra
.2197 .424 .22347 .42752 .22901 .42561 .22524 .42208 Mtetra
.22524 .42208 .22901 .42561 .23456 .4237 .2308 .42016 Mtetra
.2308 .42016 .23456 .4237 .24012 .42179 .23637 .41824 Mtetra
.23637 .41824 .24012 .42179 .2457 .41987 .24196 .41631 Mtetra
.24196 .41631 .2457 .41987 .25129 .41794 .24755 .41438 Mtetra
.24755 .41438 .25129 .41794 .25689 .41601 .25316 .41244 Mtetra
.25316 .41244 .25689 .41601 .2625 .41408 .25878 .4105 Mtetra
.25878 .4105 .2625 .41408 .26812 .41214 .26441 .40856 Mtetra
.26441 .40856 .26812 .41214 .27376 .4102 .27005 .40661 Mtetra
.27005 .40661 .27376 .4102 .27941 .40826 .27571 .40466 Mtetra
.27571 .40466 .27941 .40826 .28507 .40631 .28137 .4027 Mtetra
.28137 .4027 .28507 .40631 .29074 .40436 .28705 .40074 Mtetra
.28705 .40074 .29074 .40436 .29642 .4024 .29274 .39877 Mtetra
.29274 .39877 .29642 .4024 .30212 .40044 .29845 .3968 Mtetra
.29845 .3968 .30212 .40044 .30783 .39847 .30417 .39483 Mtetra
.30417 .39483 .30783 .39847 .31355 .3965 .30989 .39285 Mtetra
.30989 .39285 .31355 .3965 .31929 .39453 .31564 .39087 Mtetra
.31564 .39087 .31929 .39453 .32503 .39255 .32139 .38888 Mtetra
.32139 .38888 .32503 .39255 .33079 .39056 .32716 .38689 Mtetra
.32716 .38689 .33079 .39056 .33656 .38858 .33294 .3849 Mtetra
.33294 .3849 .33656 .38858 .34235 .38658 .33873 .3829 Mtetra
.33873 .3829 .34235 .38658 .34814 .38459 .34453 .38089 Mtetra
.34453 .38089 .34814 .38459 .35395 .38259 .35035 .37888 Mtetra
.35035 .37888 .35395 .38259 .35977 .38058 .35618 .37687 Mtetra
.35618 .37687 .35977 .38058 .36561 .37857 .36202 .37485 Mtetra
.36202 .37485 .36561 .37857 .37146 .37656 .36788 .37283 Mtetra
.36788 .37283 .37146 .37656 .37732 .37454 .37374 .3708 Mtetra
.37374 .3708 .37732 .37454 .38319 .37252 .37963 .36877 Mtetra
.37963 .36877 .38319 .37252 .38907 .37049 .38552 .36674 Mtetra
.38552 .36674 .38907 .37049 .39497 .36846 .39143 .3647 Mtetra
.39143 .3647 .39497 .36846 .40089 .36643 .39735 .36265 Mtetra
.39735 .36265 .40089 .36643 .40681 .36438 .40328 .36061 Mtetra
.40328 .36061 .40681 .36438 .41275 .36234 .40923 .35855 Mtetra
.40923 .35855 .41275 .36234 .4187 .36029 .41519 .35649 Mtetra
.41519 .35649 .4187 .36029 .42466 .35824 .42116 .35443 Mtetra
.42116 .35443 .42466 .35824 .43064 .35618 .42714 .35237 Mtetra
.42714 .35237 .43064 .35618 .43663 .35412 .43314 .35029 Mtetra
.43314 .35029 .43663 .35412 .44264 .35205 .43916 .34822 Mtetra
.43916 .34822 .44264 .35205 .44865 .34998 .44518 .34614 Mtetra
.44518 .34614 .44865 .34998 .45469 .3479 .45122 .34405 Mtetra
.663 .741 .908 r
.45122 .34405 .45469 .3479 .46073 .34582 .45727 .34196 Mtetra
.45727 .34196 .46073 .34582 .46679 .34374 .46334 .33987 Mtetra
.46334 .33987 .46679 .34374 .47286 .34165 .46942 .33777 Mtetra
.46942 .33777 .47286 .34165 .47894 .33956 .47551 .33567 Mtetra
.47551 .33567 .47894 .33956 .48504 .33747 .48162 .33357 Mtetra
.662 .74 .908 r
.48162 .33357 .48504 .33747 .49115 .33539 .48774 .33148 Mtetra
.659 .739 .909 r
.48774 .33148 .49115 .33539 .49728 .33339 .49388 .32943 Mtetra
.602 .716 .925 r
.49388 .32943 .49728 .33339 .50341 .33256 .50002 .32819 Mtetra
.662 .717 .889 r
.50002 .32819 .50341 .33256 .50957 .33044 .50618 .32606 Mtetra
.708 .732 .87 r
.50618 .32606 .50957 .33044 .51574 .32703 .51236 .32305 Mtetra
.668 .74 .904 r
.51236 .32305 .51574 .32703 .52192 .3248 .51855 .32084 Mtetra
.665 .741 .907 r
.51855 .32084 .52192 .3248 .52812 .32264 .52476 .31868 Mtetra
.664 .741 .907 r
.52476 .31868 .52812 .32264 .53432 .32049 .53098 .31652 Mtetra
.664 .741 .908 r
.53098 .31652 .53432 .32049 .54055 .31834 .53721 .31437 Mtetra
.53721 .31437 .54055 .31834 .54678 .31619 .54345 .31221 Mtetra
.54345 .31221 .54678 .31619 .55304 .31403 .54971 .31004 Mtetra
.54971 .31004 .55304 .31403 .5593 .31187 .55599 .30788 Mtetra
.55599 .30788 .5593 .31187 .56558 .30971 .56228 .3057 Mtetra
.56228 .3057 .56558 .30971 .57187 .30754 .56858 .30353 Mtetra
.56858 .30353 .57187 .30754 .57818 .30537 .5749 .30135 Mtetra
.5749 .30135 .57818 .30537 .5845 .30319 .58123 .29916 Mtetra
.58123 .29916 .5845 .30319 .59084 .30101 .58758 .29697 Mtetra
.58758 .29697 .59084 .30101 .59719 .29882 .59394 .29477 Mtetra
.59394 .29477 .59719 .29882 .60356 .29663 .60031 .29257 Mtetra
.60031 .29257 .60356 .29663 .60994 .29443 .6067 .29036 Mtetra
.6067 .29036 .60994 .29443 .61633 .29223 .61311 .28815 Mtetra
.61311 .28815 .61633 .29223 .62274 .29002 .61953 .28593 Mtetra
.61953 .28593 .62274 .29002 .62917 .28781 .62596 .28371 Mtetra
.62596 .28371 .62917 .28781 .63561 .28559 .63241 .28149 Mtetra
.63241 .28149 .63561 .28559 .64206 .28337 .63888 .27925 Mtetra
.63888 .27925 .64206 .28337 .64853 .28114 .64536 .27702 Mtetra
.64536 .27702 .64853 .28114 .65501 .27891 .65185 .27477 Mtetra
.65185 .27477 .65501 .27891 .66151 .27667 .65836 .27253 Mtetra
.65836 .27253 .66151 .27667 .66803 .27443 .66488 .27027 Mtetra
.66488 .27027 .66803 .27443 .67456 .27218 .67142 .26802 Mtetra
.67142 .26802 .67456 .27218 .6811 .26993 .67798 .26575 Mtetra
.67798 .26575 .6811 .26993 .68766 .26767 .68455 .26348 Mtetra
.68455 .26348 .68766 .26767 .69423 .2654 .69113 .26121 Mtetra
.69113 .26121 .69423 .2654 .70082 .26313 .69773 .25893 Mtetra
.69773 .25893 .70082 .26313 .70743 .26086 .70435 .25665 Mtetra
.70435 .25665 .70743 .26086 .71405 .25858 .71098 .25436 Mtetra
.71098 .25436 .71405 .25858 .72068 .25629 .71762 .25206 Mtetra
.71762 .25206 .72068 .25629 .72733 .254 .72429 .24976 Mtetra
.72429 .24976 .72733 .254 .734 .25171 .73096 .24746 Mtetra
.73096 .24746 .734 .25171 .74068 .24941 .73766 .24514 Mtetra
.73766 .24514 .74068 .24941 .74738 .2471 .74437 .24283 Mtetra
.74437 .24283 .74738 .2471 .7541 .24479 .75109 .24051 Mtetra
.75109 .24051 .7541 .24479 .76083 .24247 .75783 .23818 Mtetra
.75783 .23818 .76083 .24247 .76757 .24015 .76459 .23584 Mtetra
.76459 .23584 .76757 .24015 .77433 .23782 .77136 .23351 Mtetra
.77136 .23351 .77433 .23782 .78111 .23549 .77815 .23116 Mtetra
.77815 .23116 .78111 .23549 .7879 .23315 .78495 .22881 Mtetra
.78495 .22881 .7879 .23315 .79471 .2308 .79177 .22646 Mtetra
.79177 .22646 .79471 .2308 .80154 .22845 .79861 .2241 Mtetra
.79861 .2241 .80154 .22845 .80838 .22609 .80546 .22173 Mtetra
.80546 .22173 .80838 .22609 .81524 .22373 .81233 .21936 Mtetra
.81233 .21936 .81524 .22373 .82211 .22137 .81922 .21698 Mtetra
.81922 .21698 .82211 .22137 .829 .21899 .82612 .2146 Mtetra
.21037 .42238 .21416 .42591 .2197 .424 .21591 .42046 Mtetra
.21591 .42046 .2197 .424 .22524 .42208 .22146 .41853 Mtetra
.22146 .41853 .22524 .42208 .2308 .42016 .22703 .41661 Mtetra
.22703 .41661 .2308 .42016 .23637 .41824 .23261 .41468 Mtetra
.23261 .41468 .23637 .41824 .24196 .41631 .2382 .41274 Mtetra
.2382 .41274 .24196 .41631 .24755 .41438 .2438 .4108 Mtetra
.2438 .4108 .24755 .41438 .25316 .41244 .24941 .40886 Mtetra
.24941 .40886 .25316 .41244 .25878 .4105 .25504 .40691 Mtetra
.25504 .40691 .25878 .4105 .26441 .40856 .26068 .40496 Mtetra
.26068 .40496 .26441 .40856 .27005 .40661 .26633 .403 Mtetra
.26633 .403 .27005 .40661 .27571 .40466 .27199 .40104 Mtetra
.27199 .40104 .27571 .40466 .28137 .4027 .27767 .39908 Mtetra
.27767 .39908 .28137 .4027 .28705 .40074 .28335 .39711 Mtetra
.28335 .39711 .28705 .40074 .29274 .39877 .28905 .39513 Mtetra
.28905 .39513 .29274 .39877 .29845 .3968 .29476 .39316 Mtetra
.29476 .39316 .29845 .3968 .30417 .39483 .30049 .39117 Mtetra
.30049 .39117 .30417 .39483 .30989 .39285 .30622 .38919 Mtetra
.30622 .38919 .30989 .39285 .31564 .39087 .31197 .3872 Mtetra
.31197 .3872 .31564 .39087 .32139 .38888 .31773 .3852 Mtetra
.31773 .3852 .32139 .38888 .32716 .38689 .32351 .3832 Mtetra
.32351 .3832 .32716 .38689 .33294 .3849 .3293 .3812 Mtetra
.3293 .3812 .33294 .3849 .33873 .3829 .33509 .37919 Mtetra
.33509 .37919 .33873 .3829 .34453 .38089 .34091 .37718 Mtetra
.34091 .37718 .34453 .38089 .35035 .37888 .34673 .37516 Mtetra
.34673 .37516 .35035 .37888 .35618 .37687 .35257 .37314 Mtetra
.35257 .37314 .35618 .37687 .36202 .37485 .35842 .37112 Mtetra
.35842 .37112 .36202 .37485 .36788 .37283 .36428 .36909 Mtetra
.36428 .36909 .36788 .37283 .37374 .3708 .37016 .36705 Mtetra
.37016 .36705 .37374 .3708 .37963 .36877 .37605 .36501 Mtetra
.37605 .36501 .37963 .36877 .38552 .36674 .38195 .36297 Mtetra
.38195 .36297 .38552 .36674 .39143 .3647 .38787 .36092 Mtetra
.38787 .36092 .39143 .3647 .39735 .36265 .39379 .35887 Mtetra
.39379 .35887 .39735 .36265 .40328 .36061 .39973 .35681 Mtetra
.39973 .35681 .40328 .36061 .40923 .35855 .40569 .35475 Mtetra
.40569 .35475 .40923 .35855 .41519 .35649 .41166 .35268 Mtetra
.41166 .35268 .41519 .35649 .42116 .35443 .41764 .35061 Mtetra
.41764 .35061 .42116 .35443 .42714 .35237 .42363 .34854 Mtetra
.42363 .34854 .42714 .35237 .43314 .35029 .42964 .34646 Mtetra
.42964 .34646 .43314 .35029 .43916 .34822 .43566 .34437 Mtetra
.43566 .34437 .43916 .34822 .44518 .34614 .4417 .34228 Mtetra
.4417 .34228 .44518 .34614 .45122 .34405 .44774 .34019 Mtetra
.44774 .34019 .45122 .34405 .45727 .34196 .4538 .33809 Mtetra
.663 .741 .908 r
.4538 .33809 .45727 .34196 .46334 .33987 .45988 .33599 Mtetra
.45988 .33599 .46334 .33987 .46942 .33777 .46597 .33388 Mtetra
.46597 .33388 .46942 .33777 .47551 .33567 .47207 .33177 Mtetra
.47207 .33177 .47551 .33567 .48162 .33357 .47819 .32966 Mtetra
.47819 .32966 .48162 .33357 .48774 .33148 .48432 .32755 Mtetra
.66 .74 .909 r
.48432 .32755 .48774 .33148 .49388 .32943 .49046 .32548 Mtetra
.62 .724 .921 r
.49046 .32548 .49388 .32943 .50002 .32819 .49661 .32398 Mtetra
.663 .726 .896 r
.49661 .32398 .50002 .32819 .50618 .32606 .50278 .32185 Mtetra
.698 .738 .882 r
.50278 .32185 .50618 .32606 .51236 .32305 .50897 .31907 Mtetra
.667 .741 .905 r
.50897 .31907 .51236 .32305 .51855 .32084 .51517 .31687 Mtetra
.664 .741 .907 r
.51517 .31687 .51855 .32084 .52476 .31868 .52139 .3147 Mtetra
.664 .741 .908 r
.52139 .3147 .52476 .31868 .53098 .31652 .52761 .31254 Mtetra
.52761 .31254 .53098 .31652 .53721 .31437 .53385 .31038 Mtetra
.53385 .31038 .53721 .31437 .54345 .31221 .54011 .30821 Mtetra
.54011 .30821 .54345 .31221 .54971 .31004 .54638 .30604 Mtetra
.54638 .30604 .54971 .31004 .55599 .30788 .55266 .30386 Mtetra
.55266 .30386 .55599 .30788 .56228 .3057 .55896 .30168 Mtetra
.55896 .30168 .56228 .3057 .56858 .30353 .56528 .2995 Mtetra
.56528 .2995 .56858 .30353 .5749 .30135 .5716 .29731 Mtetra
.5716 .29731 .5749 .30135 .58123 .29916 .57794 .29511 Mtetra
.57794 .29511 .58123 .29916 .58758 .29697 .5843 .29291 Mtetra
.5843 .29291 .58758 .29697 .59394 .29477 .59067 .2907 Mtetra
.59067 .2907 .59394 .29477 .60031 .29257 .59706 .28849 Mtetra
.59706 .28849 .60031 .29257 .6067 .29036 .60346 .28628 Mtetra
.60346 .28628 .6067 .29036 .61311 .28815 .60987 .28405 Mtetra
.60987 .28405 .61311 .28815 .61953 .28593 .6163 .28183 Mtetra
.6163 .28183 .61953 .28593 .62596 .28371 .62274 .2796 Mtetra
.62274 .2796 .62596 .28371 .63241 .28149 .6292 .27736 Mtetra
.6292 .27736 .63241 .28149 .63888 .27925 .63568 .27512 Mtetra
.63568 .27512 .63888 .27925 .64536 .27702 .64217 .27287 Mtetra
.64217 .27287 .64536 .27702 .65185 .27477 .64867 .27062 Mtetra
.64867 .27062 .65185 .27477 .65836 .27253 .65519 .26836 Mtetra
.65519 .26836 .65836 .27253 .66488 .27027 .66172 .2661 Mtetra
.66172 .2661 .66488 .27027 .67142 .26802 .66827 .26383 Mtetra
.66827 .26383 .67142 .26802 .67798 .26575 .67484 .26156 Mtetra
.67484 .26156 .67798 .26575 .68455 .26348 .68142 .25928 Mtetra
.68142 .25928 .68455 .26348 .69113 .26121 .68801 .257 Mtetra
.68801 .257 .69113 .26121 .69773 .25893 .69463 .25471 Mtetra
.69463 .25471 .69773 .25893 .70435 .25665 .70125 .25241 Mtetra
.70125 .25241 .70435 .25665 .71098 .25436 .70789 .25012 Mtetra
.70789 .25012 .71098 .25436 .71762 .25206 .71455 .24781 Mtetra
.71455 .24781 .71762 .25206 .72429 .24976 .72122 .2455 Mtetra
.72122 .2455 .72429 .24976 .73096 .24746 .72791 .24318 Mtetra
.72791 .24318 .73096 .24746 .73766 .24514 .73462 .24086 Mtetra
.73462 .24086 .73766 .24514 .74437 .24283 .74134 .23854 Mtetra
.74134 .23854 .74437 .24283 .75109 .24051 .74807 .2362 Mtetra
.74807 .2362 .75109 .24051 .75783 .23818 .75482 .23387 Mtetra
.75482 .23387 .75783 .23818 .76459 .23584 .76159 .23152 Mtetra
.76159 .23152 .76459 .23584 .77136 .23351 .76838 .22917 Mtetra
.76838 .22917 .77136 .23351 .77815 .23116 .77518 .22682 Mtetra
.77518 .22682 .77815 .23116 .78495 .22881 .78199 .22446 Mtetra
.78199 .22446 .78495 .22881 .79177 .22646 .78882 .22209 Mtetra
.78882 .22209 .79177 .22646 .79861 .2241 .79567 .21972 Mtetra
.79567 .21972 .79861 .2241 .80546 .22173 .80254 .21735 Mtetra
.80254 .21735 .80546 .22173 .81233 .21936 .80942 .21496 Mtetra
.80942 .21496 .81233 .21936 .81922 .21698 .81632 .21258 Mtetra
.81632 .21258 .81922 .21698 .82612 .2146 .82323 .21018 Mtetra
.20656 .41883 .21037 .42238 .21591 .42046 .21211 .4169 Mtetra
.21211 .4169 .21591 .42046 .22146 .41853 .21767 .41497 Mtetra
.21767 .41497 .22146 .41853 .22703 .41661 .22324 .41304 Mtetra
.22324 .41304 .22703 .41661 .23261 .41468 .22883 .4111 Mtetra
.22883 .4111 .23261 .41468 .2382 .41274 .23442 .40916 Mtetra
.23442 .40916 .2382 .41274 .2438 .4108 .24003 .40721 Mtetra
.24003 .40721 .2438 .4108 .24941 .40886 .24565 .40526 Mtetra
.24565 .40526 .24941 .40886 .25504 .40691 .25129 .4033 Mtetra
.25129 .4033 .25504 .40691 .26068 .40496 .25693 .40134 Mtetra
.25693 .40134 .26068 .40496 .26633 .403 .26259 .39938 Mtetra
.26259 .39938 .26633 .403 .27199 .40104 .26826 .39741 Mtetra
.26826 .39741 .27199 .40104 .27767 .39908 .27394 .39544 Mtetra
.27394 .39544 .27767 .39908 .28335 .39711 .27964 .39346 Mtetra
.27964 .39346 .28335 .39711 .28905 .39513 .28534 .39148 Mtetra
.28534 .39148 .28905 .39513 .29476 .39316 .29106 .38949 Mtetra
.29106 .38949 .29476 .39316 .30049 .39117 .29679 .3875 Mtetra
.29679 .3875 .30049 .39117 .30622 .38919 .30254 .38551 Mtetra
.30254 .38551 .30622 .38919 .31197 .3872 .30829 .38351 Mtetra
.30829 .38351 .31197 .3872 .31773 .3852 .31406 .38151 Mtetra
.31406 .38151 .31773 .3852 .32351 .3832 .31985 .3795 Mtetra
.31985 .3795 .32351 .3832 .3293 .3812 .32564 .37749 Mtetra
.32564 .37749 .3293 .3812 .33509 .37919 .33145 .37547 Mtetra
.33145 .37547 .33509 .37919 .34091 .37718 .33727 .37345 Mtetra
.33727 .37345 .34091 .37718 .34673 .37516 .3431 .37143 Mtetra
.3431 .37143 .34673 .37516 .35257 .37314 .34894 .3694 Mtetra
.34894 .3694 .35257 .37314 .35842 .37112 .3548 .36736 Mtetra
.3548 .36736 .35842 .37112 .36428 .36909 .36067 .36533 Mtetra
.36067 .36533 .36428 .36909 .37016 .36705 .36656 .36328 Mtetra
.36656 .36328 .37016 .36705 .37605 .36501 .37246 .36124 Mtetra
.37246 .36124 .37605 .36501 .38195 .36297 .37837 .35918 Mtetra
.37837 .35918 .38195 .36297 .38787 .36092 .38429 .35713 Mtetra
.38429 .35713 .38787 .36092 .39379 .35887 .39023 .35507 Mtetra
.39023 .35507 .39379 .35887 .39973 .35681 .39617 .353 Mtetra
.39617 .353 .39973 .35681 .40569 .35475 .40214 .35093 Mtetra
.40214 .35093 .40569 .35475 .41166 .35268 .40811 .34886 Mtetra
.40811 .34886 .41166 .35268 .41764 .35061 .4141 .34678 Mtetra
.4141 .34678 .41764 .35061 .42363 .34854 .42011 .34469 Mtetra
.42011 .34469 .42363 .34854 .42964 .34646 .42612 .34261 Mtetra
.42612 .34261 .42964 .34646 .43566 .34437 .43215 .34051 Mtetra
.43215 .34051 .43566 .34437 .4417 .34228 .43819 .33841 Mtetra
.43819 .33841 .4417 .34228 .44774 .34019 .44425 .33631 Mtetra
.44425 .33631 .44774 .34019 .4538 .33809 .45032 .33421 Mtetra
.45032 .33421 .4538 .33809 .45988 .33599 .4564 .33209 Mtetra
.663 .741 .908 r
.4564 .33209 .45988 .33599 .46597 .33388 .4625 .32998 Mtetra
.4625 .32998 .46597 .33388 .47207 .33177 .46861 .32786 Mtetra
.46861 .32786 .47207 .33177 .47819 .32966 .47474 .32574 Mtetra
.47474 .32574 .47819 .32966 .48432 .32755 .48088 .32362 Mtetra
.661 .74 .909 r
.48088 .32362 .48432 .32755 .49046 .32548 .48703 .32152 Mtetra
.631 .729 .918 r
.48703 .32152 .49046 .32548 .49661 .32398 .49319 .31986 Mtetra
.663 .732 .901 r
.49319 .31986 .49661 .32398 .50278 .32185 .49937 .31771 Mtetra
.691 .741 .889 r
.49937 .31771 .50278 .32185 .50897 .31907 .50557 .31508 Mtetra
.666 .741 .906 r
.50557 .31508 .50897 .31907 .51517 .31687 .51178 .31289 Mtetra
.664 .741 .907 r
.51178 .31289 .51517 .31687 .52139 .3147 .518 .31072 Mtetra
.664 .741 .908 r
.518 .31072 .52139 .3147 .52761 .31254 .52424 .30855 Mtetra
.52424 .30855 .52761 .31254 .53385 .31038 .53049 .30638 Mtetra
.53049 .30638 .53385 .31038 .54011 .30821 .53675 .3042 Mtetra
.53675 .3042 .54011 .30821 .54638 .30604 .54303 .30202 Mtetra
.54303 .30202 .54638 .30604 .55266 .30386 .54932 .29983 Mtetra
.54932 .29983 .55266 .30386 .55896 .30168 .55563 .29764 Mtetra
.55563 .29764 .55896 .30168 .56528 .2995 .56195 .29545 Mtetra
.56195 .29545 .56528 .2995 .5716 .29731 .56829 .29325 Mtetra
.56829 .29325 .5716 .29731 .57794 .29511 .57464 .29104 Mtetra
.57464 .29104 .57794 .29511 .5843 .29291 .58101 .28883 Mtetra
.58101 .28883 .5843 .29291 .59067 .2907 .58739 .28662 Mtetra
.58739 .28662 .59067 .2907 .59706 .28849 .59378 .2844 Mtetra
.59378 .2844 .59706 .28849 .60346 .28628 .60019 .28217 Mtetra
.60019 .28217 .60346 .28628 .60987 .28405 .60662 .27994 Mtetra
.60662 .27994 .60987 .28405 .6163 .28183 .61306 .27771 Mtetra
.61306 .27771 .6163 .28183 .62274 .2796 .61951 .27546 Mtetra
.61951 .27546 .62274 .2796 .6292 .27736 .62598 .27322 Mtetra
.62598 .27322 .6292 .27736 .63568 .27512 .63247 .27097 Mtetra
.63247 .27097 .63568 .27512 .64217 .27287 .63897 .26871 Mtetra
.63897 .26871 .64217 .27287 .64867 .27062 .64548 .26645 Mtetra
.64548 .26645 .64867 .27062 .65519 .26836 .65201 .26418 Mtetra
.65201 .26418 .65519 .26836 .66172 .2661 .65855 .26191 Mtetra
.65855 .26191 .66172 .2661 .66827 .26383 .66511 .25963 Mtetra
.66511 .25963 .66827 .26383 .67484 .26156 .67169 .25735 Mtetra
.67169 .25735 .67484 .26156 .68142 .25928 .67828 .25506 Mtetra
.67828 .25506 .68142 .25928 .68801 .257 .68489 .25277 Mtetra
.68489 .25277 .68801 .257 .69463 .25471 .69151 .25047 Mtetra
.69151 .25047 .69463 .25471 .70125 .25241 .69814 .24817 Mtetra
.69814 .24817 .70125 .25241 .70789 .25012 .7048 .24586 Mtetra
.7048 .24586 .70789 .25012 .71455 .24781 .71146 .24354 Mtetra
.71146 .24354 .71455 .24781 .72122 .2455 .71815 .24122 Mtetra
.71815 .24122 .72122 .2455 .72791 .24318 .72485 .23889 Mtetra
.72485 .23889 .72791 .24318 .73462 .24086 .73156 .23656 Mtetra
.73156 .23656 .73462 .24086 .74134 .23854 .73829 .23423 Mtetra
.73829 .23423 .74134 .23854 .74807 .2362 .74504 .23188 Mtetra
.74504 .23188 .74807 .2362 .75482 .23387 .7518 .22954 Mtetra
.7518 .22954 .75482 .23387 .76159 .23152 .75858 .22718 Mtetra
.75858 .22718 .76159 .23152 .76838 .22917 .76538 .22482 Mtetra
.76538 .22482 .76838 .22917 .77518 .22682 .77219 .22246 Mtetra
.77219 .22246 .77518 .22682 .78199 .22446 .77902 .22009 Mtetra
.77902 .22009 .78199 .22446 .78882 .22209 .78586 .21771 Mtetra
.78586 .21771 .78882 .22209 .79567 .21972 .79272 .21533 Mtetra
.79272 .21533 .79567 .21972 .80254 .21735 .7996 .21294 Mtetra
.7996 .21294 .80254 .21735 .80942 .21496 .80649 .21055 Mtetra
.80649 .21055 .80942 .21496 .81632 .21258 .8134 .20815 Mtetra
.8134 .20815 .81632 .21258 .82323 .21018 .82032 .20575 Mtetra
.20274 .41527 .20656 .41883 .21211 .4169 .20829 .41334 Mtetra
.20829 .41334 .21211 .4169 .21767 .41497 .21386 .4114 Mtetra
.21386 .4114 .21767 .41497 .22324 .41304 .21944 .40946 Mtetra
.21944 .40946 .22324 .41304 .22883 .4111 .22503 .40751 Mtetra
.22503 .40751 .22883 .4111 .23442 .40916 .23064 .40556 Mtetra
.23064 .40556 .23442 .40916 .24003 .40721 .23625 .4036 Mtetra
.23625 .4036 .24003 .40721 .24565 .40526 .24188 .40164 Mtetra
.24188 .40164 .24565 .40526 .25129 .4033 .24752 .39968 Mtetra
.24752 .39968 .25129 .4033 .25693 .40134 .25317 .39771 Mtetra
.25317 .39771 .25693 .40134 .26259 .39938 .25884 .39574 Mtetra
.25884 .39574 .26259 .39938 .26826 .39741 .26451 .39377 Mtetra
.26451 .39377 .26826 .39741 .27394 .39544 .2702 .39178 Mtetra
.2702 .39178 .27394 .39544 .27964 .39346 .27591 .3898 Mtetra
.27591 .3898 .27964 .39346 .28534 .39148 .28162 .38781 Mtetra
.28162 .38781 .28534 .39148 .29106 .38949 .28735 .38582 Mtetra
.28735 .38582 .29106 .38949 .29679 .3875 .29309 .38382 Mtetra
.29309 .38382 .29679 .3875 .30254 .38551 .29884 .38182 Mtetra
.29884 .38182 .30254 .38551 .30829 .38351 .3046 .37981 Mtetra
.3046 .37981 .30829 .38351 .31406 .38151 .31038 .3778 Mtetra
.31038 .3778 .31406 .38151 .31985 .3795 .31617 .37578 Mtetra
.31617 .37578 .31985 .3795 .32564 .37749 .32197 .37376 Mtetra
.32197 .37376 .32564 .37749 .33145 .37547 .32778 .37174 Mtetra
.32778 .37174 .33145 .37547 .33727 .37345 .33361 .36971 Mtetra
.33361 .36971 .33727 .37345 .3431 .37143 .33945 .36768 Mtetra
.33945 .36768 .3431 .37143 .34894 .3694 .34531 .36564 Mtetra
.34531 .36564 .34894 .3694 .3548 .36736 .35117 .3636 Mtetra
.35117 .3636 .3548 .36736 .36067 .36533 .35705 .36155 Mtetra
.35705 .36155 .36067 .36533 .36656 .36328 .36294 .3595 Mtetra
.36294 .3595 .36656 .36328 .37246 .36124 .36885 .35744 Mtetra
.36885 .35744 .37246 .36124 .37837 .35918 .37477 .35538 Mtetra
.37477 .35538 .37837 .35918 .38429 .35713 .3807 .35332 Mtetra
.3807 .35332 .38429 .35713 .39023 .35507 .38664 .35125 Mtetra
.38664 .35125 .39023 .35507 .39617 .353 .3926 .34918 Mtetra
.3926 .34918 .39617 .353 .40214 .35093 .39857 .3471 Mtetra
.39857 .3471 .40214 .35093 .40811 .34886 .40456 .34501 Mtetra
.40456 .34501 .40811 .34886 .4141 .34678 .41055 .34293 Mtetra
.41055 .34293 .4141 .34678 .42011 .34469 .41656 .34083 Mtetra
.41656 .34083 .42011 .34469 .42612 .34261 .42259 .33874 Mtetra
.42259 .33874 .42612 .34261 .43215 .34051 .42863 .33664 Mtetra
.42863 .33664 .43215 .34051 .43819 .33841 .43468 .33453 Mtetra
.43468 .33453 .43819 .33841 .44425 .33631 .44074 .33242 Mtetra
.44074 .33242 .44425 .33631 .45032 .33421 .44682 .3303 Mtetra
.44682 .3303 .45032 .33421 .4564 .33209 .45291 .32818 Mtetra
.663 .741 .908 r
.45291 .32818 .4564 .33209 .4625 .32998 .45902 .32606 Mtetra
.45902 .32606 .4625 .32998 .46861 .32786 .46514 .32393 Mtetra
.46514 .32393 .46861 .32786 .47474 .32574 .47127 .3218 Mtetra
.47127 .3218 .47474 .32574 .48088 .32362 .47742 .31966 Mtetra
.662 .74 .908 r
.47742 .31966 .48088 .32362 .48703 .32152 .48358 .31755 Mtetra
.639 .732 .916 r
.48358 .31755 .48703 .32152 .49319 .31986 .48975 .31578 Mtetra
.663 .735 .903 r
.48975 .31578 .49319 .31986 .49937 .31771 .49594 .31362 Mtetra
.685 .742 .894 r
.49594 .31362 .49937 .31771 .50557 .31508 .50215 .31109 Mtetra
.665 .741 .907 r
.50215 .31109 .50557 .31508 .51178 .31289 .50837 .30889 Mtetra
.664 .741 .908 r
.50837 .30889 .51178 .31289 .518 .31072 .5146 .30671 Mtetra
.5146 .30671 .518 .31072 .52424 .30855 .52085 .30454 Mtetra
.52085 .30454 .52424 .30855 .53049 .30638 .52711 .30236 Mtetra
.52711 .30236 .53049 .30638 .53675 .3042 .53338 .30017 Mtetra
.53338 .30017 .53675 .3042 .54303 .30202 .53967 .29798 Mtetra
.53967 .29798 .54303 .30202 .54932 .29983 .54597 .29579 Mtetra
.54597 .29579 .54932 .29983 .55563 .29764 .55229 .29359 Mtetra
.55229 .29359 .55563 .29764 .56195 .29545 .55862 .29138 Mtetra
.55862 .29138 .56195 .29545 .56829 .29325 .56497 .28917 Mtetra
.56497 .28917 .56829 .29325 .57464 .29104 .57133 .28696 Mtetra
.57133 .28696 .57464 .29104 .58101 .28883 .5777 .28474 Mtetra
.5777 .28474 .58101 .28883 .58739 .28662 .58409 .28251 Mtetra
.58409 .28251 .58739 .28662 .59378 .2844 .5905 .28028 Mtetra
.5905 .28028 .59378 .2844 .60019 .28217 .59692 .27805 Mtetra
.59692 .27805 .60019 .28217 .60662 .27994 .60335 .27581 Mtetra
.60335 .27581 .60662 .27994 .61306 .27771 .6098 .27356 Mtetra
.6098 .27356 .61306 .27771 .61951 .27546 .61627 .27131 Mtetra
.61627 .27131 .61951 .27546 .62598 .27322 .62275 .26906 Mtetra
.62275 .26906 .62598 .27322 .63247 .27097 .62924 .2668 Mtetra
.62924 .2668 .63247 .27097 .63897 .26871 .63575 .26453 Mtetra
.63575 .26453 .63897 .26871 .64548 .26645 .64227 .26226 Mtetra
.64227 .26226 .64548 .26645 .65201 .26418 .64881 .25998 Mtetra
.64881 .25998 .65201 .26418 .65855 .26191 .65537 .2577 Mtetra
.65537 .2577 .65855 .26191 .66511 .25963 .66194 .25541 Mtetra
.66194 .25541 .66511 .25963 .67169 .25735 .66852 .25312 Mtetra
.66852 .25312 .67169 .25735 .67828 .25506 .67513 .25082 Mtetra
.67513 .25082 .67828 .25506 .68489 .25277 .68174 .24852 Mtetra
.68174 .24852 .68489 .25277 .69151 .25047 .68837 .24621 Mtetra
.68837 .24621 .69151 .25047 .69814 .24817 .69502 .2439 Mtetra
.69502 .2439 .69814 .24817 .7048 .24586 .70169 .24158 Mtetra
.70169 .24158 .7048 .24586 .71146 .24354 .70836 .23925 Mtetra
.70836 .23925 .71146 .24354 .71815 .24122 .71506 .23692 Mtetra
.71506 .23692 .71815 .24122 .72485 .23889 .72177 .23459 Mtetra
.72177 .23459 .72485 .23889 .73156 .23656 .7285 .23224 Mtetra
.7285 .23224 .73156 .23656 .73829 .23423 .73524 .2299 Mtetra
.73524 .2299 .73829 .23423 .74504 .23188 .742 .22754 Mtetra
.742 .22754 .74504 .23188 .7518 .22954 .74877 .22519 Mtetra
.74877 .22519 .7518 .22954 .75858 .22718 .75556 .22282 Mtetra
.75556 .22282 .75858 .22718 .76538 .22482 .76237 .22045 Mtetra
.76237 .22045 .76538 .22482 .77219 .22246 .76919 .21808 Mtetra
.76919 .21808 .77219 .22246 .77902 .22009 .77603 .2157 Mtetra
.77603 .2157 .77902 .22009 .78586 .21771 .78288 .21331 Mtetra
.78288 .21331 .78586 .21771 .79272 .21533 .78976 .21092 Mtetra
.78976 .21092 .79272 .21533 .7996 .21294 .79664 .20852 Mtetra
.79664 .20852 .7996 .21294 .80649 .21055 .80355 .20612 Mtetra
.80355 .20612 .80649 .21055 .8134 .20815 .81047 .20371 Mtetra
.81047 .20371 .8134 .20815 .82032 .20575 .81741 .20129 Mtetra
.1989 .4117 .20274 .41527 .20829 .41334 .20446 .40976 Mtetra
.20446 .40976 .20829 .41334 .21386 .4114 .21004 .40781 Mtetra
.21004 .40781 .21386 .4114 .21944 .40946 .21562 .40586 Mtetra
.21562 .40586 .21944 .40946 .22503 .40751 .22122 .4039 Mtetra
.22122 .4039 .22503 .40751 .23064 .40556 .22683 .40195 Mtetra
.22683 .40195 .23064 .40556 .23625 .4036 .23246 .39998 Mtetra
.23246 .39998 .23625 .4036 .24188 .40164 .23809 .39802 Mtetra
.23809 .39802 .24188 .40164 .24752 .39968 .24374 .39604 Mtetra
.24374 .39604 .24752 .39968 .25317 .39771 .2494 .39407 Mtetra
.2494 .39407 .25317 .39771 .25884 .39574 .25507 .39209 Mtetra
.25507 .39209 .25884 .39574 .26451 .39377 .26075 .39011 Mtetra
.26075 .39011 .26451 .39377 .2702 .39178 .26645 .38812 Mtetra
.26645 .38812 .2702 .39178 .27591 .3898 .27216 .38612 Mtetra
.27216 .38612 .27591 .3898 .28162 .38781 .27788 .38413 Mtetra
.27788 .38413 .28162 .38781 .28735 .38582 .28362 .38213 Mtetra
.28362 .38213 .28735 .38582 .29309 .38382 .28936 .38012 Mtetra
.28936 .38012 .29309 .38382 .29884 .38182 .29512 .37811 Mtetra
.29512 .37811 .29884 .38182 .3046 .37981 .30089 .37609 Mtetra
.30089 .37609 .3046 .37981 .31038 .3778 .30668 .37408 Mtetra
.30668 .37408 .31038 .3778 .31617 .37578 .31247 .37205 Mtetra
.31247 .37205 .31617 .37578 .32197 .37376 .31828 .37002 Mtetra
.31828 .37002 .32197 .37376 .32778 .37174 .32411 .36799 Mtetra
.32411 .36799 .32778 .37174 .33361 .36971 .32994 .36595 Mtetra
.32994 .36595 .33361 .36971 .33945 .36768 .33579 .36391 Mtetra
.33579 .36391 .33945 .36768 .34531 .36564 .34165 .36187 Mtetra
.34165 .36187 .34531 .36564 .35117 .3636 .34753 .35982 Mtetra
.34753 .35982 .35117 .3636 .35705 .36155 .35341 .35776 Mtetra
.35341 .35776 .35705 .36155 .36294 .3595 .35931 .3557 Mtetra
.35931 .3557 .36294 .3595 .36885 .35744 .36523 .35364 Mtetra
.36523 .35364 .36885 .35744 .37477 .35538 .37115 .35157 Mtetra
.37115 .35157 .37477 .35538 .3807 .35332 .37709 .3495 Mtetra
.37709 .3495 .3807 .35332 .38664 .35125 .38305 .34742 Mtetra
.38305 .34742 .38664 .35125 .3926 .34918 .38901 .34534 Mtetra
.38901 .34534 .3926 .34918 .39857 .3471 .39499 .34325 Mtetra
.39499 .34325 .39857 .3471 .40456 .34501 .40098 .34116 Mtetra
.40098 .34116 .40456 .34501 .41055 .34293 .40699 .33906 Mtetra
.40699 .33906 .41055 .34293 .41656 .34083 .41301 .33696 Mtetra
.41301 .33696 .41656 .34083 .42259 .33874 .41904 .33485 Mtetra
.41904 .33485 .42259 .33874 .42863 .33664 .42509 .33274 Mtetra
.42509 .33274 .42863 .33664 .43468 .33453 .43115 .33063 Mtetra
.43115 .33063 .43468 .33453 .44074 .33242 .43722 .32851 Mtetra
.43722 .32851 .44074 .33242 .44682 .3303 .44331 .32638 Mtetra
.44331 .32638 .44682 .3303 .45291 .32818 .44941 .32425 Mtetra
.663 .741 .908 r
.44941 .32425 .45291 .32818 .45902 .32606 .45553 .32212 Mtetra
.45553 .32212 .45902 .32606 .46514 .32393 .46165 .31998 Mtetra
.46165 .31998 .46514 .32393 .47127 .3218 .4678 .31784 Mtetra
.4678 .31784 .47127 .3218 .47742 .31966 .47395 .3157 Mtetra
.662 .741 .908 r
.47395 .3157 .47742 .31966 .48358 .31755 .48012 .31357 Mtetra
.644 .734 .914 r
.48012 .31357 .48358 .31755 .48975 .31578 .4863 .31171 Mtetra
.663 .737 .904 r
.4863 .31171 .48975 .31578 .49594 .31362 .4925 .30955 Mtetra
.681 .743 .897 r
.4925 .30955 .49594 .31362 .50215 .31109 .49872 .30708 Mtetra
.665 .741 .907 r
.49872 .30708 .50215 .31109 .50837 .30889 .50494 .30488 Mtetra
.664 .741 .908 r
.50494 .30488 .50837 .30889 .5146 .30671 .51119 .30269 Mtetra
.51119 .30269 .5146 .30671 .52085 .30454 .51744 .30051 Mtetra
.51744 .30051 .52085 .30454 .52711 .30236 .52371 .29832 Mtetra
.52371 .29832 .52711 .30236 .53338 .30017 .52999 .29612 Mtetra
.52999 .29612 .53338 .30017 .53967 .29798 .53629 .29393 Mtetra
.53629 .29393 .53967 .29798 .54597 .29579 .5426 .29172 Mtetra
.5426 .29172 .54597 .29579 .55229 .29359 .54893 .28951 Mtetra
.54893 .28951 .55229 .29359 .55862 .29138 .55527 .2873 Mtetra
.55527 .2873 .55862 .29138 .56497 .28917 .56163 .28508 Mtetra
.56163 .28508 .56497 .28917 .57133 .28696 .568 .28286 Mtetra
.568 .28286 .57133 .28696 .5777 .28474 .57438 .28063 Mtetra
.57438 .28063 .5777 .28474 .58409 .28251 .58078 .27839 Mtetra
.58078 .27839 .58409 .28251 .5905 .28028 .5872 .27615 Mtetra
.5872 .27615 .5905 .28028 .59692 .27805 .59363 .27391 Mtetra
.59363 .27391 .59692 .27805 .60335 .27581 .60007 .27166 Mtetra
.60007 .27166 .60335 .27581 .6098 .27356 .60653 .26941 Mtetra
.60653 .26941 .6098 .27356 .61627 .27131 .61301 .26715 Mtetra
.61301 .26715 .61627 .27131 .62275 .26906 .6195 .26488 Mtetra
.6195 .26488 .62275 .26906 .62924 .2668 .626 .26261 Mtetra
.626 .26261 .62924 .2668 .63575 .26453 .63252 .26033 Mtetra
.63252 .26033 .63575 .26453 .64227 .26226 .63905 .25805 Mtetra
.63905 .25805 .64227 .26226 .64881 .25998 .6456 .25577 Mtetra
.6456 .25577 .64881 .25998 .65537 .2577 .65217 .25347 Mtetra
.65217 .25347 .65537 .2577 .66194 .25541 .65875 .25118 Mtetra
.65875 .25118 .66194 .25541 .66852 .25312 .66535 .24887 Mtetra
.66535 .24887 .66852 .25312 .67513 .25082 .67196 .24657 Mtetra
.67196 .24657 .67513 .25082 .68174 .24852 .67859 .24425 Mtetra
.67859 .24425 .68174 .24852 .68837 .24621 .68523 .24193 Mtetra
.68523 .24193 .68837 .24621 .69502 .2439 .69189 .23961 Mtetra
.69189 .23961 .69502 .2439 .70169 .24158 .69856 .23728 Mtetra
.69856 .23728 .70169 .24158 .70836 .23925 .70525 .23495 Mtetra
.70525 .23495 .70836 .23925 .71506 .23692 .71196 .2326 Mtetra
.71196 .2326 .71506 .23692 .72177 .23459 .71868 .23026 Mtetra
.71868 .23026 .72177 .23459 .7285 .23224 .72542 .22791 Mtetra
.72542 .22791 .7285 .23224 .73524 .2299 .73217 .22555 Mtetra
.73217 .22555 .73524 .2299 .742 .22754 .73894 .22319 Mtetra
.73894 .22319 .742 .22754 .74877 .22519 .74572 .22082 Mtetra
.74572 .22082 .74877 .22519 .75556 .22282 .75253 .21844 Mtetra
.75253 .21844 .75556 .22282 .76237 .22045 .75934 .21606 Mtetra
.75934 .21606 .76237 .22045 .76919 .21808 .76618 .21368 Mtetra
.76618 .21368 .76919 .21808 .77603 .2157 .77303 .21129 Mtetra
.77303 .21129 .77603 .2157 .78288 .21331 .77989 .20889 Mtetra
.77989 .20889 .78288 .21331 .78976 .21092 .78678 .20649 Mtetra
.78678 .20649 .78976 .21092 .79664 .20852 .79368 .20408 Mtetra
.79368 .20408 .79664 .20852 .80355 .20612 .80059 .20166 Mtetra
.80059 .20166 .80355 .20612 .81047 .20371 .80753 .19924 Mtetra
.80753 .19924 .81047 .20371 .81741 .20129 .81447 .19682 Mtetra
.19505 .40811 .1989 .4117 .20446 .40976 .20062 .40616 Mtetra
.20062 .40616 .20446 .40976 .21004 .40781 .2062 .40421 Mtetra
.2062 .40421 .21004 .40781 .21562 .40586 .21179 .40225 Mtetra
.21179 .40225 .21562 .40586 .22122 .4039 .2174 .40029 Mtetra
.2174 .40029 .22122 .4039 .22683 .40195 .22301 .39832 Mtetra
.22301 .39832 .22683 .40195 .23246 .39998 .22864 .39635 Mtetra
.22864 .39635 .23246 .39998 .23809 .39802 .23429 .39437 Mtetra
.23429 .39437 .23809 .39802 .24374 .39604 .23994 .39239 Mtetra
.23994 .39239 .24374 .39604 .2494 .39407 .24561 .39041 Mtetra
.24561 .39041 .2494 .39407 .25507 .39209 .25129 .38842 Mtetra
.25129 .38842 .25507 .39209 .26075 .39011 .25698 .38643 Mtetra
.25698 .38643 .26075 .39011 .26645 .38812 .26268 .38443 Mtetra
.26268 .38443 .26645 .38812 .27216 .38612 .2684 .38243 Mtetra
.2684 .38243 .27216 .38612 .27788 .38413 .27413 .38043 Mtetra
.27413 .38043 .27788 .38413 .28362 .38213 .27987 .37842 Mtetra
.27987 .37842 .28362 .38213 .28936 .38012 .28562 .3764 Mtetra
.28562 .3764 .28936 .38012 .29512 .37811 .29139 .37439 Mtetra
.29139 .37439 .29512 .37811 .30089 .37609 .29717 .37236 Mtetra
.29717 .37236 .30089 .37609 .30668 .37408 .30296 .37034 Mtetra
.30296 .37034 .30668 .37408 .31247 .37205 .30877 .3683 Mtetra
.30877 .3683 .31247 .37205 .31828 .37002 .31458 .36627 Mtetra
.31458 .36627 .31828 .37002 .32411 .36799 .32041 .36423 Mtetra
.32041 .36423 .32411 .36799 .32994 .36595 .32626 .36218 Mtetra
.32626 .36218 .32994 .36595 .33579 .36391 .33211 .36013 Mtetra
.33211 .36013 .33579 .36391 .34165 .36187 .33798 .35808 Mtetra
.33798 .35808 .34165 .36187 .34753 .35982 .34387 .35602 Mtetra
.34387 .35602 .34753 .35982 .35341 .35776 .34976 .35396 Mtetra
.34976 .35396 .35341 .35776 .35931 .3557 .35567 .35189 Mtetra
.35567 .35189 .35931 .3557 .36523 .35364 .36159 .34981 Mtetra
.36159 .34981 .36523 .35364 .37115 .35157 .36752 .34774 Mtetra
.36752 .34774 .37115 .35157 .37709 .3495 .37347 .34566 Mtetra
.37347 .34566 .37709 .3495 .38305 .34742 .37943 .34357 Mtetra
.37943 .34357 .38305 .34742 .38901 .34534 .38541 .34148 Mtetra
.38541 .34148 .38901 .34534 .39499 .34325 .3914 .33938 Mtetra
.3914 .33938 .39499 .34325 .40098 .34116 .3974 .33728 Mtetra
.3974 .33728 .40098 .34116 .40699 .33906 .40341 .33518 Mtetra
.40341 .33518 .40699 .33906 .41301 .33696 .40944 .33307 Mtetra
.40944 .33307 .41301 .33696 .41904 .33485 .41548 .33095 Mtetra
.41548 .33095 .41904 .33485 .42509 .33274 .42154 .32883 Mtetra
.42154 .32883 .42509 .33274 .43115 .33063 .4276 .32671 Mtetra
.4276 .32671 .43115 .33063 .43722 .32851 .43369 .32458 Mtetra
.43369 .32458 .43722 .32851 .44331 .32638 .43978 .32245 Mtetra
.43978 .32245 .44331 .32638 .44941 .32425 .44589 .32031 Mtetra
.44589 .32031 .44941 .32425 .45553 .32212 .45202 .31817 Mtetra
.663 .741 .908 r
.45202 .31817 .45553 .32212 .46165 .31998 .45815 .31602 Mtetra
.45815 .31602 .46165 .31998 .4678 .31784 .4643 .31387 Mtetra
.4643 .31387 .4678 .31784 .47395 .3157 .47047 .31171 Mtetra
.662 .741 .908 r
.47047 .31171 .47395 .3157 .48012 .31357 .47665 .30957 Mtetra
.647 .736 .913 r
.47665 .30957 .48012 .31357 .4863 .31171 .48284 .30765 Mtetra
.663 .738 .905 r
.48284 .30765 .4863 .31171 .4925 .30955 .48905 .30548 Mtetra
.678 .743 .9 r
.48905 .30548 .4925 .30955 .49872 .30708 .49527 .30305 Mtetra
.665 .741 .907 r
.49527 .30305 .49872 .30708 .50494 .30488 .50151 .30085 Mtetra
.664 .741 .908 r
.50151 .30085 .50494 .30488 .51119 .30269 .50776 .29866 Mtetra
.50776 .29866 .51119 .30269 .51744 .30051 .51402 .29646 Mtetra
.51402 .29646 .51744 .30051 .52371 .29832 .5203 .29426 Mtetra
.5203 .29426 .52371 .29832 .52999 .29612 .52659 .29206 Mtetra
.52659 .29206 .52999 .29612 .53629 .29393 .5329 .28985 Mtetra
.5329 .28985 .53629 .29393 .5426 .29172 .53922 .28764 Mtetra
.53922 .28764 .5426 .29172 .54893 .28951 .54556 .28542 Mtetra
.54556 .28542 .54893 .28951 .55527 .2873 .55191 .2832 Mtetra
.55191 .2832 .55527 .2873 .56163 .28508 .55827 .28097 Mtetra
.55827 .28097 .56163 .28508 .568 .28286 .56466 .27874 Mtetra
.56466 .27874 .568 .28286 .57438 .28063 .57105 .2765 Mtetra
.57105 .2765 .57438 .28063 .58078 .27839 .57746 .27426 Mtetra
.57746 .27426 .58078 .27839 .5872 .27615 .58388 .27201 Mtetra
.58388 .27201 .5872 .27615 .59363 .27391 .59032 .26975 Mtetra
.59032 .26975 .59363 .27391 .60007 .27166 .59678 .26749 Mtetra
.59678 .26749 .60007 .27166 .60653 .26941 .60325 .26523 Mtetra
.60325 .26523 .60653 .26941 .61301 .26715 .60973 .26296 Mtetra
.60973 .26296 .61301 .26715 .6195 .26488 .61623 .26068 Mtetra
.61623 .26068 .6195 .26488 .626 .26261 .62275 .2584 Mtetra
.62275 .2584 .626 .26261 .63252 .26033 .62928 .25612 Mtetra
.62928 .25612 .63252 .26033 .63905 .25805 .63582 .25383 Mtetra
.63582 .25383 .63905 .25805 .6456 .25577 .64238 .25153 Mtetra
.64238 .25153 .6456 .25577 .65217 .25347 .64896 .24923 Mtetra
.64896 .24923 .65217 .25347 .65875 .25118 .65555 .24692 Mtetra
.65555 .24692 .65875 .25118 .66535 .24887 .66216 .24461 Mtetra
.66216 .24461 .66535 .24887 .67196 .24657 .66878 .24229 Mtetra
.66878 .24229 .67196 .24657 .67859 .24425 .67542 .23997 Mtetra
.67542 .23997 .67859 .24425 .68523 .24193 .68207 .23764 Mtetra
.68207 .23764 .68523 .24193 .69189 .23961 .68874 .23531 Mtetra
.68874 .23531 .69189 .23961 .69856 .23728 .69542 .23297 Mtetra
.69542 .23297 .69856 .23728 .70525 .23495 .70212 .23062 Mtetra
.70212 .23062 .70525 .23495 .71196 .2326 .70884 .22827 Mtetra
.70884 .22827 .71196 .2326 .71868 .23026 .71557 .22591 Mtetra
.71557 .22591 .71868 .23026 .72542 .22791 .72232 .22355 Mtetra
.72232 .22355 .72542 .22791 .73217 .22555 .72909 .22118 Mtetra
.72909 .22118 .73217 .22555 .73894 .22319 .73587 .21881 Mtetra
.73587 .21881 .73894 .22319 .74572 .22082 .74266 .21643 Mtetra
.74266 .21643 .74572 .22082 .75253 .21844 .74948 .21405 Mtetra
.74948 .21405 .75253 .21844 .75934 .21606 .75631 .21166 Mtetra
.75631 .21166 .75934 .21606 .76618 .21368 .76315 .20926 Mtetra
.76315 .20926 .76618 .21368 .77303 .21129 .77001 .20686 Mtetra
.77001 .20686 .77303 .21129 .77989 .20889 .77689 .20445 Mtetra
.77689 .20445 .77989 .20889 .78678 .20649 .78379 .20204 Mtetra
.78379 .20204 .78678 .20649 .79368 .20408 .7907 .19962 Mtetra
.7907 .19962 .79368 .20408 .80059 .20166 .79762 .19719 Mtetra
.79762 .19719 .80059 .20166 .80753 .19924 .80457 .19476 Mtetra
.80457 .19476 .80753 .19924 .81447 .19682 .81153 .19233 Mtetra
.19118 .40451 .19505 .40811 .20062 .40616 .19675 .40255 Mtetra
.19675 .40255 .20062 .40616 .2062 .40421 .20234 .40059 Mtetra
.20234 .40059 .2062 .40421 .21179 .40225 .20794 .39862 Mtetra
.20794 .39862 .21179 .40225 .2174 .40029 .21356 .39665 Mtetra
.21356 .39665 .2174 .40029 .22301 .39832 .21918 .39468 Mtetra
.21918 .39468 .22301 .39832 .22864 .39635 .22482 .3927 Mtetra
.22482 .3927 .22864 .39635 .23429 .39437 .23047 .39072 Mtetra
.23047 .39072 .23429 .39437 .23994 .39239 .23613 .38873 Mtetra
.23613 .38873 .23994 .39239 .24561 .39041 .2418 .38674 Mtetra
.2418 .38674 .24561 .39041 .25129 .38842 .24749 .38474 Mtetra
.24749 .38474 .25129 .38842 .25698 .38643 .25319 .38274 Mtetra
.25319 .38274 .25698 .38643 .26268 .38443 .2589 .38074 Mtetra
.2589 .38074 .26268 .38443 .2684 .38243 .26462 .37873 Mtetra
.26462 .37873 .2684 .38243 .27413 .38043 .27036 .37671 Mtetra
.27036 .37671 .27413 .38043 .27987 .37842 .27611 .3747 Mtetra
.27611 .3747 .27987 .37842 .28562 .3764 .28187 .37267 Mtetra
.28187 .37267 .28562 .3764 .29139 .37439 .28765 .37065 Mtetra
.28765 .37065 .29139 .37439 .29717 .37236 .29343 .36862 Mtetra
.29343 .36862 .29717 .37236 .30296 .37034 .29923 .36658 Mtetra
.29923 .36658 .30296 .37034 .30877 .3683 .30504 .36454 Mtetra
.30504 .36454 .30877 .3683 .31458 .36627 .31087 .3625 Mtetra
.31087 .3625 .31458 .36627 .32041 .36423 .31671 .36045 Mtetra
.31671 .36045 .32041 .36423 .32626 .36218 .32256 .35839 Mtetra
.32256 .35839 .32626 .36218 .33211 .36013 .32842 .35634 Mtetra
.32842 .35634 .33211 .36013 .33798 .35808 .3343 .35427 Mtetra
.3343 .35427 .33798 .35808 .34387 .35602 .34019 .35221 Mtetra
.34019 .35221 .34387 .35602 .34976 .35396 .34609 .35013 Mtetra
.34609 .35013 .34976 .35396 .35567 .35189 .35201 .34806 Mtetra
.35201 .34806 .35567 .35189 .36159 .34981 .35794 .34598 Mtetra
.35794 .34598 .36159 .34981 .36752 .34774 .36388 .34389 Mtetra
.36388 .34389 .36752 .34774 .37347 .34566 .36984 .3418 Mtetra
.36984 .3418 .37347 .34566 .37943 .34357 .37581 .3397 Mtetra
.37581 .3397 .37943 .34357 .38541 .34148 .38179 .33761 Mtetra
.38179 .33761 .38541 .34148 .3914 .33938 .38778 .3355 Mtetra
.38778 .3355 .3914 .33938 .3974 .33728 .39379 .33339 Mtetra
.39379 .33339 .3974 .33728 .40341 .33518 .39982 .33128 Mtetra
.39982 .33128 .40341 .33518 .40944 .33307 .40585 .32916 Mtetra
.40585 .32916 .40944 .33307 .41548 .33095 .4119 .32704 Mtetra
.4119 .32704 .41548 .33095 .42154 .32883 .41797 .32491 Mtetra
.41797 .32491 .42154 .32883 .4276 .32671 .42404 .32277 Mtetra
.42404 .32277 .4276 .32671 .43369 .32458 .43014 .32064 Mtetra
.43014 .32064 .43369 .32458 .43978 .32245 .43624 .31849 Mtetra
.43624 .31849 .43978 .32245 .44589 .32031 .44236 .31635 Mtetra
.44236 .31635 .44589 .32031 .45202 .31817 .44849 .3142 Mtetra
.663 .741 .908 r
.44849 .3142 .45202 .31817 .45815 .31602 .45464 .31204 Mtetra
.45464 .31204 .45815 .31602 .4643 .31387 .4608 .30988 Mtetra
.4608 .30988 .4643 .31387 .47047 .31171 .46697 .30772 Mtetra
.662 .741 .908 r
.46697 .30772 .47047 .31171 .47665 .30957 .47316 .30556 Mtetra
.65 .737 .913 r
.47316 .30556 .47665 .30957 .48284 .30765 .47936 .30359 Mtetra
.663 .739 .906 r
.47936 .30359 .48284 .30765 .48905 .30548 .48558 .30141 Mtetra
.676 .743 .901 r
.48558 .30141 .48905 .30548 .49527 .30305 .49181 .29902 Mtetra
.665 .741 .907 r
.49181 .29902 .49527 .30305 .50151 .30085 .49805 .29681 Mtetra
.664 .741 .908 r
.49805 .29681 .50151 .30085 .50776 .29866 .50431 .29461 Mtetra
.50431 .29461 .50776 .29866 .51402 .29646 .51059 .2924 Mtetra
.51059 .2924 .51402 .29646 .5203 .29426 .51688 .29019 Mtetra
.51688 .29019 .5203 .29426 .52659 .29206 .52318 .28798 Mtetra
.52318 .28798 .52659 .29206 .5329 .28985 .52949 .28576 Mtetra
.52949 .28576 .5329 .28985 .53922 .28764 .53583 .28354 Mtetra
.53583 .28354 .53922 .28764 .54556 .28542 .54217 .28131 Mtetra
.54217 .28131 .54556 .28542 .55191 .2832 .54853 .27908 Mtetra
.54853 .27908 .55191 .2832 .55827 .28097 .55491 .27684 Mtetra
.55491 .27684 .55827 .28097 .56466 .27874 .5613 .2746 Mtetra
.5613 .2746 .56466 .27874 .57105 .2765 .5677 .27235 Mtetra
.5677 .27235 .57105 .2765 .57746 .27426 .57412 .2701 Mtetra
.57412 .2701 .57746 .27426 .58388 .27201 .58056 .26784 Mtetra
.58056 .26784 .58388 .27201 .59032 .26975 .58701 .26558 Mtetra
.58701 .26558 .59032 .26975 .59678 .26749 .59347 .26331 Mtetra
.59347 .26331 .59678 .26749 .60325 .26523 .59995 .26103 Mtetra
.59995 .26103 .60325 .26523 .60973 .26296 .60644 .25876 Mtetra
.60644 .25876 .60973 .26296 .61623 .26068 .61295 .25647 Mtetra
.61295 .25647 .61623 .26068 .62275 .2584 .61948 .25418 Mtetra
.61948 .25418 .62275 .2584 .62928 .25612 .62602 .25188 Mtetra
.62602 .25188 .62928 .25612 .63582 .25383 .63257 .24958 Mtetra
.63257 .24958 .63582 .25383 .64238 .25153 .63915 .24728 Mtetra
.63915 .24728 .64238 .25153 .64896 .24923 .64573 .24497 Mtetra
.64573 .24497 .64896 .24923 .65555 .24692 .65233 .24265 Mtetra
.65233 .24265 .65555 .24692 .66216 .24461 .65895 .24033 Mtetra
.65895 .24033 .66216 .24461 .66878 .24229 .66558 .238 Mtetra
.66558 .238 .66878 .24229 .67542 .23997 .67223 .23566 Mtetra
.67223 .23566 .67542 .23997 .68207 .23764 .6789 .23333 Mtetra
.6789 .23333 .68207 .23764 .68874 .23531 .68558 .23098 Mtetra
.68558 .23098 .68874 .23531 .69542 .23297 .69227 .22863 Mtetra
.69227 .22863 .69542 .23297 .70212 .23062 .69898 .22628 Mtetra
.69898 .22628 .70212 .23062 .70884 .22827 .70571 .22391 Mtetra
.70571 .22391 .70884 .22827 .71557 .22591 .71245 .22155 Mtetra
.71245 .22155 .71557 .22591 .72232 .22355 .71921 .21917 Mtetra
.71921 .21917 .72232 .22355 .72909 .22118 .72599 .2168 Mtetra
.72599 .2168 .72909 .22118 .73587 .21881 .73278 .21441 Mtetra
.73278 .21441 .73587 .21881 .74266 .21643 .73959 .21202 Mtetra
.73959 .21202 .74266 .21643 .74948 .21405 .74641 .20963 Mtetra
.74641 .20963 .74948 .21405 .75631 .21166 .75325 .20723 Mtetra
.75325 .20723 .75631 .21166 .76315 .20926 .76011 .20482 Mtetra
.76011 .20482 .76315 .20926 .77001 .20686 .76698 .20241 Mtetra
.76698 .20241 .77001 .20686 .77689 .20445 .77387 .19999 Mtetra
.77387 .19999 .77689 .20445 .78379 .20204 .78078 .19757 Mtetra
.78078 .19757 .78379 .20204 .7907 .19962 .7877 .19514 Mtetra
.7877 .19514 .7907 .19962 .79762 .19719 .79464 .1927 Mtetra
.79464 .1927 .79762 .19719 .80457 .19476 .8016 .19026 Mtetra
.8016 .19026 .80457 .19476 .81153 .19233 .80857 .18781 Mtetra
.18729 .40089 .19118 .40451 .19675 .40255 .19288 .39892 Mtetra
.19288 .39892 .19675 .40255 .20234 .40059 .19847 .39696 Mtetra
.19847 .39696 .20234 .40059 .20794 .39862 .20408 .39498 Mtetra
.20408 .39498 .20794 .39862 .21356 .39665 .2097 .393 Mtetra
.2097 .393 .21356 .39665 .21918 .39468 .21533 .39102 Mtetra
.21533 .39102 .21918 .39468 .22482 .3927 .22098 .38904 Mtetra
.22098 .38904 .22482 .3927 .23047 .39072 .22663 .38704 Mtetra
.22663 .38704 .23047 .39072 .23613 .38873 .2323 .38505 Mtetra
.2323 .38505 .23613 .38873 .2418 .38674 .23798 .38305 Mtetra
.23798 .38305 .2418 .38674 .24749 .38474 .24368 .38105 Mtetra
.24368 .38105 .24749 .38474 .25319 .38274 .24938 .37904 Mtetra
.24938 .37904 .25319 .38274 .2589 .38074 .2551 .37702 Mtetra
.2551 .37702 .2589 .38074 .26462 .37873 .26083 .37501 Mtetra
.26083 .37501 .26462 .37873 .27036 .37671 .26658 .37299 Mtetra
.26658 .37299 .27036 .37671 .27611 .3747 .27233 .37096 Mtetra
.27233 .37096 .27611 .3747 .28187 .37267 .2781 .36893 Mtetra
.2781 .36893 .28187 .37267 .28765 .37065 .28388 .36689 Mtetra
.28388 .36689 .28765 .37065 .29343 .36862 .28968 .36486 Mtetra
.28968 .36486 .29343 .36862 .29923 .36658 .29549 .36281 Mtetra
.29549 .36281 .29923 .36658 .30504 .36454 .30131 .36076 Mtetra
.30131 .36076 .30504 .36454 .31087 .3625 .30714 .35871 Mtetra
.30714 .35871 .31087 .3625 .31671 .36045 .31299 .35665 Mtetra
.31299 .35665 .31671 .36045 .32256 .35839 .31884 .35459 Mtetra
.31884 .35459 .32256 .35839 .32842 .35634 .32472 .35252 Mtetra
.32472 .35252 .32842 .35634 .3343 .35427 .3306 .35045 Mtetra
.3306 .35045 .3343 .35427 .34019 .35221 .3365 .34838 Mtetra
.3365 .34838 .34019 .35221 .34609 .35013 .34241 .3463 Mtetra
.34241 .3463 .34609 .35013 .35201 .34806 .34833 .34421 Mtetra
.34833 .34421 .35201 .34806 .35794 .34598 .35427 .34212 Mtetra
.35427 .34212 .35794 .34598 .36388 .34389 .36022 .34003 Mtetra
.36022 .34003 .36388 .34389 .36984 .3418 .36619 .33793 Mtetra
.36619 .33793 .36984 .3418 .37581 .3397 .37216 .33582 Mtetra
.37216 .33582 .37581 .3397 .38179 .33761 .37816 .33372 Mtetra
.37816 .33372 .38179 .33761 .38778 .3355 .38416 .3316 Mtetra
.38416 .3316 .38778 .3355 .39379 .33339 .39018 .32949 Mtetra
.39018 .32949 .39379 .33339 .39982 .33128 .39621 .32736 Mtetra
.39621 .32736 .39982 .33128 .40585 .32916 .40225 .32524 Mtetra
.40225 .32524 .40585 .32916 .4119 .32704 .40831 .3231 Mtetra
.40831 .3231 .4119 .32704 .41797 .32491 .41438 .32097 Mtetra
.41438 .32097 .41797 .32491 .42404 .32277 .42047 .31882 Mtetra
.42047 .31882 .42404 .32277 .43014 .32064 .42657 .31668 Mtetra
.42657 .31668 .43014 .32064 .43624 .31849 .43268 .31453 Mtetra
.43268 .31453 .43624 .31849 .44236 .31635 .43881 .31237 Mtetra
.43881 .31237 .44236 .31635 .44849 .3142 .44495 .31021 Mtetra
.663 .741 .908 r
.44495 .31021 .44849 .3142 .45464 .31204 .45111 .30804 Mtetra
.45111 .30804 .45464 .31204 .4608 .30988 .45728 .30587 Mtetra
.45728 .30587 .4608 .30988 .46697 .30772 .46346 .3037 Mtetra
.46346 .3037 .46697 .30772 .47316 .30556 .46966 .30153 Mtetra
.652 .737 .912 r
.46966 .30153 .47316 .30556 .47936 .30359 .47586 .29953 Mtetra
.663 .739 .906 r
.47586 .29953 .47936 .30359 .48558 .30141 .48209 .29734 Mtetra
.674 .743 .902 r
.48209 .29734 .48558 .30141 .49181 .29902 .48833 .29496 Mtetra
.664 .741 .907 r
.48833 .29496 .49181 .29902 .49805 .29681 .49459 .29275 Mtetra
.664 .741 .908 r
.49459 .29275 .49805 .29681 .50431 .29461 .50086 .29054 Mtetra
.50086 .29054 .50431 .29461 .51059 .2924 .50714 .28832 Mtetra
.50714 .28832 .51059 .2924 .51688 .29019 .51344 .28611 Mtetra
.51344 .28611 .51688 .29019 .52318 .28798 .51975 .28388 Mtetra
.51975 .28388 .52318 .28798 .52949 .28576 .52607 .28166 Mtetra
.52607 .28166 .52949 .28576 .53583 .28354 .53242 .27943 Mtetra
.53242 .27943 .53583 .28354 .54217 .28131 .53877 .27719 Mtetra
.53877 .27719 .54217 .28131 .54853 .27908 .54514 .27495 Mtetra
.54514 .27495 .54853 .27908 .55491 .27684 .55153 .2727 Mtetra
.55153 .2727 .55491 .27684 .5613 .2746 .55793 .27045 Mtetra
.55793 .27045 .5613 .2746 .5677 .27235 .56434 .26819 Mtetra
.56434 .26819 .5677 .27235 .57412 .2701 .57077 .26593 Mtetra
.57077 .26593 .57412 .2701 .58056 .26784 .57721 .26366 Mtetra
.57721 .26366 .58056 .26784 .58701 .26558 .58367 .26138 Mtetra
.58367 .26138 .58701 .26558 .59347 .26331 .59015 .25911 Mtetra
.59015 .25911 .59347 .26331 .59995 .26103 .59664 .25682 Mtetra
.59664 .25682 .59995 .26103 .60644 .25876 .60314 .25453 Mtetra
.60314 .25453 .60644 .25876 .61295 .25647 .60966 .25224 Mtetra
.60966 .25224 .61295 .25647 .61948 .25418 .6162 .24994 Mtetra
.6162 .24994 .61948 .25418 .62602 .25188 .62275 .24763 Mtetra
.62275 .24763 .62602 .25188 .63257 .24958 .62931 .24532 Mtetra
.62931 .24532 .63257 .24958 .63915 .24728 .63589 .24301 Mtetra
.63589 .24301 .63915 .24728 .64573 .24497 .64249 .24068 Mtetra
.64249 .24068 .64573 .24497 .65233 .24265 .6491 .23836 Mtetra
.6491 .23836 .65233 .24265 .65895 .24033 .65573 .23602 Mtetra
.65573 .23602 .65895 .24033 .66558 .238 .66238 .23369 Mtetra
.66238 .23369 .66558 .238 .67223 .23566 .66903 .23134 Mtetra
.66903 .23134 .67223 .23566 .6789 .23333 .67571 .22899 Mtetra
.67571 .22899 .6789 .23333 .68558 .23098 .6824 .22664 Mtetra
.6824 .22664 .68558 .23098 .69227 .22863 .68911 .22428 Mtetra
.68911 .22428 .69227 .22863 .69898 .22628 .69583 .22191 Mtetra
.69583 .22191 .69898 .22628 .70571 .22391 .70257 .21954 Mtetra
.70257 .21954 .70571 .22391 .71245 .22155 .70932 .21716 Mtetra
.70932 .21716 .71245 .22155 .71921 .21917 .71609 .21478 Mtetra
.71609 .21478 .71921 .21917 .72599 .2168 .72288 .21239 Mtetra
.72288 .21239 .72599 .2168 .73278 .21441 .72968 .21 Mtetra
.72968 .21 .73278 .21441 .73959 .21202 .7365 .2076 Mtetra
.7365 .2076 .73959 .21202 .74641 .20963 .74334 .20519 Mtetra
.74334 .20519 .74641 .20963 .75325 .20723 .75019 .20278 Mtetra
.75019 .20278 .75325 .20723 .76011 .20482 .75706 .20036 Mtetra
.75706 .20036 .76011 .20482 .76698 .20241 .76394 .19794 Mtetra
.76394 .19794 .76698 .20241 .77387 .19999 .77084 .19551 Mtetra
.77084 .19551 .77387 .19999 .78078 .19757 .77776 .19308 Mtetra
.77776 .19308 .78078 .19757 .7877 .19514 .7847 .19064 Mtetra
.7847 .19064 .7877 .19514 .79464 .1927 .79165 .18819 Mtetra
.79165 .18819 .79464 .1927 .8016 .19026 .79862 .18574 Mtetra
.79862 .18574 .8016 .19026 .80857 .18781 .8056 .18328 Mtetra
.18339 .39726 .18729 .40089 .19288 .39892 .18898 .39529 Mtetra
.18898 .39529 .19288 .39892 .19847 .39696 .19459 .39331 Mtetra
.19459 .39331 .19847 .39696 .20408 .39498 .2002 .39133 Mtetra
.2002 .39133 .20408 .39498 .2097 .393 .20583 .38934 Mtetra
.20583 .38934 .2097 .393 .21533 .39102 .21147 .38735 Mtetra
.21147 .38735 .21533 .39102 .22098 .38904 .21712 .38536 Mtetra
.21712 .38536 .22098 .38904 .22663 .38704 .22278 .38336 Mtetra
.22278 .38336 .22663 .38704 .2323 .38505 .22846 .38135 Mtetra
.22846 .38135 .2323 .38505 .23798 .38305 .23415 .37935 Mtetra
.23415 .37935 .23798 .38305 .24368 .38105 .23985 .37733 Mtetra
.23985 .37733 .24368 .38105 .24938 .37904 .24556 .37532 Mtetra
.24556 .37532 .24938 .37904 .2551 .37702 .25129 .3733 Mtetra
.25129 .3733 .2551 .37702 .26083 .37501 .25703 .37127 Mtetra
.25703 .37127 .26083 .37501 .26658 .37299 .26278 .36924 Mtetra
.26278 .36924 .26658 .37299 .27233 .37096 .26854 .36721 Mtetra
.26854 .36721 .27233 .37096 .2781 .36893 .27432 .36517 Mtetra
.27432 .36517 .2781 .36893 .28388 .36689 .28011 .36313 Mtetra
.28011 .36313 .28388 .36689 .28968 .36486 .28591 .36108 Mtetra
.28591 .36108 .28968 .36486 .29549 .36281 .29172 .35903 Mtetra
.29172 .35903 .29549 .36281 .30131 .36076 .29755 .35697 Mtetra
.29755 .35697 .30131 .36076 .30714 .35871 .30339 .35491 Mtetra
.30339 .35491 .30714 .35871 .31299 .35665 .30925 .35284 Mtetra
.30925 .35284 .31299 .35665 .31884 .35459 .31511 .35077 Mtetra
.31511 .35077 .31884 .35459 .32472 .35252 .32099 .3487 Mtetra
.32099 .3487 .32472 .35252 .3306 .35045 .32689 .34662 Mtetra
.32689 .34662 .3306 .35045 .3365 .34838 .33279 .34453 Mtetra
.33279 .34453 .3365 .34838 .34241 .3463 .33871 .34244 Mtetra
.33871 .34244 .34241 .3463 .34833 .34421 .34464 .34035 Mtetra
.34464 .34035 .34833 .34421 .35427 .34212 .35059 .33825 Mtetra
.35059 .33825 .35427 .34212 .36022 .34003 .35655 .33615 Mtetra
.35655 .33615 .36022 .34003 .36619 .33793 .36252 .33404 Mtetra
.36252 .33404 .36619 .33793 .37216 .33582 .36851 .33193 Mtetra
.36851 .33193 .37216 .33582 .37816 .33372 .37451 .32981 Mtetra
.37451 .32981 .37816 .33372 .38416 .3316 .38052 .32769 Mtetra
.38052 .32769 .38416 .3316 .39018 .32949 .38655 .32556 Mtetra
.38655 .32556 .39018 .32949 .39621 .32736 .39259 .32343 Mtetra
.39259 .32343 .39621 .32736 .40225 .32524 .39864 .32129 Mtetra
.39864 .32129 .40225 .32524 .40831 .3231 .40471 .31915 Mtetra
.40471 .31915 .40831 .3231 .41438 .32097 .41079 .31701 Mtetra
.41079 .31701 .41438 .32097 .42047 .31882 .41688 .31486 Mtetra
.41688 .31486 .42047 .31882 .42657 .31668 .42299 .3127 Mtetra
.42299 .3127 .42657 .31668 .43268 .31453 .42911 .31054 Mtetra
.42911 .31054 .43268 .31453 .43881 .31237 .43525 .30838 Mtetra
.43525 .30838 .43881 .31237 .44495 .31021 .4414 .30621 Mtetra
.4414 .30621 .44495 .31021 .45111 .30804 .44756 .30403 Mtetra
.663 .741 .908 r
.44756 .30403 .45111 .30804 .45728 .30587 .45374 .30185 Mtetra
.45374 .30185 .45728 .30587 .46346 .3037 .45993 .29967 Mtetra
.45993 .29967 .46346 .3037 .46966 .30153 .46614 .29749 Mtetra
.654 .738 .911 r
.46614 .29749 .46966 .30153 .47586 .29953 .47236 .29545 Mtetra
.663 .74 .907 r
.47236 .29545 .47586 .29953 .48209 .29734 .47859 .29325 Mtetra
.673 .743 .903 r
.47859 .29325 .48209 .29734 .48833 .29496 .48484 .29089 Mtetra
.664 .741 .907 r
.48484 .29089 .48833 .29496 .49459 .29275 .49111 .28867 Mtetra
.664 .741 .908 r
.49111 .28867 .49459 .29275 .50086 .29054 .49738 .28645 Mtetra
.49738 .28645 .50086 .29054 .50714 .28832 .50368 .28423 Mtetra
.50368 .28423 .50714 .28832 .51344 .28611 .50998 .282 Mtetra
.50998 .282 .51344 .28611 .51975 .28388 .5163 .27977 Mtetra
.5163 .27977 .51975 .28388 .52607 .28166 .52264 .27753 Mtetra
.52264 .27753 .52607 .28166 .53242 .27943 .52899 .27529 Mtetra
.52899 .27529 .53242 .27943 .53877 .27719 .53536 .27305 Mtetra
.53536 .27305 .53877 .27719 .54514 .27495 .54173 .27079 Mtetra
.54173 .27079 .54514 .27495 .55153 .2727 .54813 .26854 Mtetra
.54813 .26854 .55153 .2727 .55793 .27045 .55454 .26627 Mtetra
.55454 .26627 .55793 .27045 .56434 .26819 .56096 .26401 Mtetra
.56096 .26401 .56434 .26819 .57077 .26593 .5674 .26173 Mtetra
.5674 .26173 .57077 .26593 .57721 .26366 .57386 .25946 Mtetra
.57386 .25946 .57721 .26366 .58367 .26138 .58033 .25717 Mtetra
.58033 .25717 .58367 .26138 .59015 .25911 .58681 .25489 Mtetra
.58681 .25489 .59015 .25911 .59664 .25682 .59331 .25259 Mtetra
.59331 .25259 .59664 .25682 .60314 .25453 .59983 .25029 Mtetra
.59983 .25029 .60314 .25453 .60966 .25224 .60636 .24799 Mtetra
.60636 .24799 .60966 .25224 .6162 .24994 .6129 .24568 Mtetra
.6129 .24568 .6162 .24994 .62275 .24763 .61946 .24336 Mtetra
.61946 .24336 .62275 .24763 .62931 .24532 .62604 .24104 Mtetra
.62604 .24104 .62931 .24532 .63589 .24301 .63263 .23872 Mtetra
.63263 .23872 .63589 .24301 .64249 .24068 .63924 .23638 Mtetra
.63924 .23638 .64249 .24068 .6491 .23836 .64586 .23405 Mtetra
.64586 .23405 .6491 .23836 .65573 .23602 .6525 .2317 Mtetra
.6525 .2317 .65573 .23602 .66238 .23369 .65915 .22935 Mtetra
.65915 .22935 .66238 .23369 .66903 .23134 .66582 .227 Mtetra
.66582 .227 .66903 .23134 .67571 .22899 .67251 .22464 Mtetra
.67251 .22464 .67571 .22899 .6824 .22664 .67921 .22228 Mtetra
.67921 .22228 .6824 .22664 .68911 .22428 .68593 .21991 Mtetra
.68593 .21991 .68911 .22428 .69583 .22191 .69266 .21753 Mtetra
.69266 .21753 .69583 .22191 .70257 .21954 .69941 .21515 Mtetra
.69941 .21515 .70257 .21954 .70932 .21716 .70618 .21276 Mtetra
.70618 .21276 .70932 .21716 .71609 .21478 .71296 .21037 Mtetra
.71296 .21037 .71609 .21478 .72288 .21239 .71976 .20797 Mtetra
.71976 .20797 .72288 .21239 .72968 .21 .72657 .20556 Mtetra
.72657 .20556 .72968 .21 .7365 .2076 .7334 .20315 Mtetra
.7334 .20315 .7365 .2076 .74334 .20519 .74025 .20073 Mtetra
.74025 .20073 .74334 .20519 .75019 .20278 .74711 .19831 Mtetra
.74711 .19831 .75019 .20278 .75706 .20036 .75399 .19588 Mtetra
.75399 .19588 .75706 .20036 .76394 .19794 .76089 .19345 Mtetra
.76089 .19345 .76394 .19794 .77084 .19551 .7678 .19101 Mtetra
.7678 .19101 .77084 .19551 .77776 .19308 .77473 .18857 Mtetra
.77473 .18857 .77776 .19308 .7847 .19064 .78168 .18611 Mtetra
.78168 .18611 .7847 .19064 .79165 .18819 .78864 .18366 Mtetra
.78864 .18366 .79165 .18819 .79862 .18574 .79562 .18119 Mtetra
.79562 .18119 .79862 .18574 .8056 .18328 .80262 .17872 Mtetra
.17948 .39361 .18339 .39726 .18898 .39529 .18507 .39163 Mtetra
.18507 .39163 .18898 .39529 .19459 .39331 .19068 .38965 Mtetra
.19068 .38965 .19459 .39331 .2002 .39133 .19631 .38766 Mtetra
.19631 .38766 .2002 .39133 .20583 .38934 .20194 .38566 Mtetra
.20194 .38566 .20583 .38934 .21147 .38735 .20759 .38367 Mtetra
.20759 .38367 .21147 .38735 .21712 .38536 .21324 .38166 Mtetra
.21324 .38166 .21712 .38536 .22278 .38336 .21892 .37966 Mtetra
.21892 .37966 .22278 .38336 .22846 .38135 .2246 .37764 Mtetra
.2246 .37764 .22846 .38135 .23415 .37935 .2303 .37563 Mtetra
.2303 .37563 .23415 .37935 .23985 .37733 .236 .37361 Mtetra
.236 .37361 .23985 .37733 .24556 .37532 .24172 .37158 Mtetra
.24172 .37158 .24556 .37532 .25129 .3733 .24746 .36955 Mtetra
.24746 .36955 .25129 .3733 .25703 .37127 .2532 .36752 Mtetra
.2532 .36752 .25703 .37127 .26278 .36924 .25896 .36548 Mtetra
.25896 .36548 .26278 .36924 .26854 .36721 .26473 .36344 Mtetra
.26473 .36344 .26854 .36721 .27432 .36517 .27052 .36139 Mtetra
.27052 .36139 .27432 .36517 .28011 .36313 .27632 .35934 Mtetra
.27632 .35934 .28011 .36313 .28591 .36108 .28213 .35729 Mtetra
.28213 .35729 .28591 .36108 .29172 .35903 .28795 .35523 Mtetra
.28795 .35523 .29172 .35903 .29755 .35697 .29378 .35316 Mtetra
.29378 .35316 .29755 .35697 .30339 .35491 .29963 .35109 Mtetra
.29963 .35109 .30339 .35491 .30925 .35284 .30549 .34902 Mtetra
.30549 .34902 .30925 .35284 .31511 .35077 .31137 .34694 Mtetra
.31137 .34694 .31511 .35077 .32099 .3487 .31726 .34485 Mtetra
.31726 .34485 .32099 .3487 .32689 .34662 .32316 .34277 Mtetra
.32316 .34277 .32689 .34662 .33279 .34453 .32907 .34067 Mtetra
.32907 .34067 .33279 .34453 .33871 .34244 .335 .33857 Mtetra
.335 .33857 .33871 .34244 .34464 .34035 .34094 .33647 Mtetra
.34094 .33647 .34464 .34035 .35059 .33825 .34689 .33437 Mtetra
.34689 .33437 .35059 .33825 .35655 .33615 .35286 .33225 Mtetra
.35286 .33225 .35655 .33615 .36252 .33404 .35884 .33014 Mtetra
.35884 .33014 .36252 .33404 .36851 .33193 .36483 .32802 Mtetra
.36483 .32802 .36851 .33193 .37451 .32981 .37084 .32589 Mtetra
.37084 .32589 .37451 .32981 .38052 .32769 .37686 .32376 Mtetra
.37686 .32376 .38052 .32769 .38655 .32556 .3829 .32162 Mtetra
.3829 .32162 .38655 .32556 .39259 .32343 .38895 .31948 Mtetra
.38895 .31948 .39259 .32343 .39864 .32129 .39501 .31734 Mtetra
.39501 .31734 .39864 .32129 .40471 .31915 .40108 .31519 Mtetra
.40108 .31519 .40471 .31915 .41079 .31701 .40717 .31303 Mtetra
.40717 .31303 .41079 .31701 .41688 .31486 .41328 .31087 Mtetra
.41328 .31087 .41688 .31486 .42299 .3127 .41939 .30871 Mtetra
.41939 .30871 .42299 .3127 .42911 .31054 .42552 .30654 Mtetra
.42552 .30654 .42911 .31054 .43525 .30838 .43167 .30436 Mtetra
.43167 .30436 .43525 .30838 .4414 .30621 .43783 .30219 Mtetra
.43783 .30219 .4414 .30621 .44756 .30403 .444 .3 Mtetra
.663 .741 .908 r
.444 .3 .44756 .30403 .45374 .30185 .45019 .29781 Mtetra
.45019 .29781 .45374 .30185 .45993 .29967 .45639 .29562 Mtetra
.45639 .29562 .45993 .29967 .46614 .29749 .4626 .29343 Mtetra
.655 .738 .911 r
.4626 .29343 .46614 .29749 .47236 .29545 .46883 .29136 Mtetra
.663 .74 .907 r
.46883 .29136 .47236 .29545 .47859 .29325 .47508 .28915 Mtetra
.672 .743 .904 r
.47508 .28915 .47859 .29325 .48484 .29089 .48134 .2868 Mtetra
.664 .741 .908 r
.48134 .2868 .48484 .29089 .49111 .28867 .48761 .28457 Mtetra
.48761 .28457 .49111 .28867 .49738 .28645 .4939 .28235 Mtetra
.4939 .28235 .49738 .28645 .50368 .28423 .5002 .28011 Mtetra
.5002 .28011 .50368 .28423 .50998 .282 .50651 .27788 Mtetra
.50651 .27788 .50998 .282 .5163 .27977 .51284 .27564 Mtetra
.51284 .27564 .5163 .27977 .52264 .27753 .51919 .27339 Mtetra
.51919 .27339 .52264 .27753 .52899 .27529 .52555 .27114 Mtetra
.52555 .27114 .52899 .27529 .53536 .27305 .53192 .26888 Mtetra
.53192 .26888 .53536 .27305 .54173 .27079 .53831 .26662 Mtetra
.53831 .26662 .54173 .27079 .54813 .26854 .54472 .26436 Mtetra
.54472 .26436 .54813 .26854 .55454 .26627 .55114 .26208 Mtetra
.55114 .26208 .55454 .26627 .56096 .26401 .55757 .25981 Mtetra
.55757 .25981 .56096 .26401 .5674 .26173 .56402 .25753 Mtetra
.56402 .25753 .5674 .26173 .57386 .25946 .57049 .25524 Mtetra
.57049 .25524 .57386 .25946 .58033 .25717 .57697 .25294 Mtetra
.57697 .25294 .58033 .25717 .58681 .25489 .58346 .25065 Mtetra
.58346 .25065 .58681 .25489 .59331 .25259 .58997 .24834 Mtetra
.58997 .24834 .59331 .25259 .59983 .25029 .59649 .24603 Mtetra
.59649 .24603 .59983 .25029 .60636 .24799 .60304 .24372 Mtetra
.60304 .24372 .60636 .24799 .6129 .24568 .60959 .2414 Mtetra
.60959 .2414 .6129 .24568 .61946 .24336 .61616 .23907 Mtetra
.61616 .23907 .61946 .24336 .62604 .24104 .62275 .23674 Mtetra
.62275 .23674 .62604 .24104 .63263 .23872 .62935 .23441 Mtetra
.62935 .23441 .63263 .23872 .63924 .23638 .63597 .23206 Mtetra
.63597 .23206 .63924 .23638 .64586 .23405 .6426 .22972 Mtetra
.6426 .22972 .64586 .23405 .6525 .2317 .64925 .22736 Mtetra
.64925 .22736 .6525 .2317 .65915 .22935 .65592 .225 Mtetra
.65592 .225 .65915 .22935 .66582 .227 .6626 .22264 Mtetra
.6626 .22264 .66582 .227 .67251 .22464 .66929 .22027 Mtetra
.66929 .22027 .67251 .22464 .67921 .22228 .67601 .2179 Mtetra
.67601 .2179 .67921 .22228 .68593 .21991 .68273 .21551 Mtetra
.68273 .21551 .68593 .21991 .69266 .21753 .68948 .21313 Mtetra
.68948 .21313 .69266 .21753 .69941 .21515 .69624 .21073 Mtetra
.69624 .21073 .69941 .21515 .70618 .21276 .70302 .20834 Mtetra
.70302 .20834 .70618 .21276 .71296 .21037 .70981 .20593 Mtetra
.70981 .20593 .71296 .21037 .71976 .20797 .71662 .20352 Mtetra
.71662 .20352 .71976 .20797 .72657 .20556 .72344 .20111 Mtetra
.72344 .20111 .72657 .20556 .7334 .20315 .73029 .19869 Mtetra
.73029 .19869 .7334 .20315 .74025 .20073 .73714 .19626 Mtetra
.73714 .19626 .74025 .20073 .74711 .19831 .74402 .19383 Mtetra
.74402 .19383 .74711 .19831 .75399 .19588 .75091 .19139 Mtetra
.75091 .19139 .75399 .19588 .76089 .19345 .75782 .18894 Mtetra
.75782 .18894 .76089 .19345 .7678 .19101 .76474 .18649 Mtetra
.76474 .18649 .7678 .19101 .77473 .18857 .77169 .18403 Mtetra
.77169 .18403 .77473 .18857 .78168 .18611 .77864 .18157 Mtetra
.77864 .18157 .78168 .18611 .78864 .18366 .78562 .1791 Mtetra
.78562 .1791 .78864 .18366 .79562 .18119 .79261 .17663 Mtetra
.79261 .17663 .79562 .18119 .80262 .17872 .79962 .17415 Mtetra
.17555 .38995 .17948 .39361 .18507 .39163 .18115 .38796 Mtetra
.18115 .38796 .18507 .39163 .19068 .38965 .18677 .38597 Mtetra
.18677 .38597 .19068 .38965 .19631 .38766 .1924 .38397 Mtetra
.1924 .38397 .19631 .38766 .20194 .38566 .19804 .38197 Mtetra
.19804 .38197 .20194 .38566 .20759 .38367 .20369 .37996 Mtetra
.20369 .37996 .20759 .38367 .21324 .38166 .20936 .37795 Mtetra
.20936 .37795 .21324 .38166 .21892 .37966 .21503 .37594 Mtetra
.21503 .37594 .21892 .37966 .2246 .37764 .22073 .37392 Mtetra
.22073 .37392 .2246 .37764 .2303 .37563 .22643 .3719 Mtetra
.22643 .3719 .2303 .37563 .236 .37361 .23214 .36987 Mtetra
.23214 .36987 .236 .37361 .24172 .37158 .23787 .36783 Mtetra
.23787 .36783 .24172 .37158 .24746 .36955 .24361 .3658 Mtetra
.24361 .3658 .24746 .36955 .2532 .36752 .24937 .36376 Mtetra
.24937 .36376 .2532 .36752 .25896 .36548 .25513 .36171 Mtetra
.25513 .36171 .25896 .36548 .26473 .36344 .26091 .35966 Mtetra
.26091 .35966 .26473 .36344 .27052 .36139 .2667 .3576 Mtetra
.2667 .3576 .27052 .36139 .27632 .35934 .27251 .35554 Mtetra
.27251 .35554 .27632 .35934 .28213 .35729 .27833 .35348 Mtetra
.27833 .35348 .28213 .35729 .28795 .35523 .28416 .35141 Mtetra
.28416 .35141 .28795 .35523 .29378 .35316 .29 .34934 Mtetra
.29 .34934 .29378 .35316 .29963 .35109 .29586 .34726 Mtetra
.29586 .34726 .29963 .35109 .30549 .34902 .30173 .34517 Mtetra
.30173 .34517 .30549 .34902 .31137 .34694 .30761 .34309 Mtetra
.30761 .34309 .31137 .34694 .31726 .34485 .3135 .34099 Mtetra
.3135 .34099 .31726 .34485 .32316 .34277 .31941 .3389 Mtetra
.31941 .3389 .32316 .34277 .32907 .34067 .32534 .3368 Mtetra
.32534 .3368 .32907 .34067 .335 .33857 .33127 .33469 Mtetra
.33127 .33469 .335 .33857 .34094 .33647 .33722 .33258 Mtetra
.33722 .33258 .34094 .33647 .34689 .33437 .34318 .33046 Mtetra
.34318 .33046 .34689 .33437 .35286 .33225 .34916 .32834 Mtetra
.34916 .32834 .35286 .33225 .35884 .33014 .35515 .32622 Mtetra
.35515 .32622 .35884 .33014 .36483 .32802 .36115 .32409 Mtetra
.36115 .32409 .36483 .32802 .37084 .32589 .36716 .32195 Mtetra
.36716 .32195 .37084 .32589 .37686 .32376 .37319 .31981 Mtetra
.37319 .31981 .37686 .32376 .3829 .32162 .37924 .31767 Mtetra
.37924 .31767 .3829 .32162 .38895 .31948 .38529 .31552 Mtetra
.38529 .31552 .38895 .31948 .39501 .31734 .39136 .31336 Mtetra
.39136 .31336 .39501 .31734 .40108 .31519 .39745 .31121 Mtetra
.39745 .31121 .40108 .31519 .40717 .31303 .40355 .30904 Mtetra
.40355 .30904 .40717 .31303 .41328 .31087 .40966 .30687 Mtetra
.40966 .30687 .41328 .31087 .41939 .30871 .41578 .3047 Mtetra
.41578 .3047 .41939 .30871 .42552 .30654 .42192 .30252 Mtetra
.42192 .30252 .42552 .30654 .43167 .30436 .42808 .30034 Mtetra
.42808 .30034 .43167 .30436 .43783 .30219 .43424 .29815 Mtetra
.43424 .29815 .43783 .30219 .444 .3 .44043 .29596 Mtetra
.663 .741 .908 r
.44043 .29596 .444 .3 .45019 .29781 .44662 .29376 Mtetra
.44662 .29376 .45019 .29781 .45639 .29562 .45283 .29156 Mtetra
.45283 .29156 .45639 .29562 .4626 .29343 .45906 .28936 Mtetra
.656 .739 .911 r
.45906 .28936 .4626 .29343 .46883 .29136 .46529 .28726 Mtetra
.663 .74 .907 r
.46529 .28726 .46883 .29136 .47508 .28915 .47155 .28504 Mtetra
.671 .743 .904 r
.47155 .28504 .47508 .28915 .48134 .2868 .47782 .2827 Mtetra
.664 .741 .908 r
.47782 .2827 .48134 .2868 .48761 .28457 .4841 .28046 Mtetra
.4841 .28046 .48761 .28457 .4939 .28235 .49039 .27822 Mtetra
.49039 .27822 .4939 .28235 .5002 .28011 .49671 .27598 Mtetra
.49671 .27598 .5002 .28011 .50651 .27788 .50303 .27374 Mtetra
.50303 .27374 .50651 .27788 .51284 .27564 .50937 .27149 Mtetra
.50937 .27149 .51284 .27564 .51919 .27339 .51573 .26923 Mtetra
.51573 .26923 .51919 .27339 .52555 .27114 .5221 .26697 Mtetra
.5221 .26697 .52555 .27114 .53192 .26888 .52848 .26471 Mtetra
.52848 .26471 .53192 .26888 .53831 .26662 .53488 .26243 Mtetra
.53488 .26243 .53831 .26662 .54472 .26436 .54129 .26016 Mtetra
.54129 .26016 .54472 .26436 .55114 .26208 .54772 .25788 Mtetra
.54772 .25788 .55114 .26208 .55757 .25981 .55417 .25559 Mtetra
.55417 .25559 .55757 .25981 .56402 .25753 .56063 .2533 Mtetra
.56063 .2533 .56402 .25753 .57049 .25524 .5671 .251 Mtetra
.5671 .251 .57049 .25524 .57697 .25294 .57359 .2487 Mtetra
.57359 .2487 .57697 .25294 .58346 .25065 .58009 .24639 Mtetra
.58009 .24639 .58346 .25065 .58997 .24834 .58661 .24408 Mtetra
.58661 .24408 .58997 .24834 .59649 .24603 .59315 .24176 Mtetra
.59315 .24176 .59649 .24603 .60304 .24372 .5997 .23943 Mtetra
.5997 .23943 .60304 .24372 .60959 .2414 .60627 .2371 Mtetra
.60627 .2371 .60959 .2414 .61616 .23907 .61285 .23477 Mtetra
.61285 .23477 .61616 .23907 .62275 .23674 .61944 .23242 Mtetra
.61944 .23242 .62275 .23674 .62935 .23441 .62606 .23008 Mtetra
.62606 .23008 .62935 .23441 .63597 .23206 .63269 .22773 Mtetra
.63269 .22773 .63597 .23206 .6426 .22972 .63933 .22537 Mtetra
.63933 .22537 .6426 .22972 .64925 .22736 .64599 .223 Mtetra
.64599 .223 .64925 .22736 .65592 .225 .65267 .22064 Mtetra
.65267 .22064 .65592 .225 .6626 .22264 .65936 .21826 Mtetra
.65936 .21826 .6626 .22264 .66929 .22027 .66606 .21588 Mtetra
.66606 .21588 .66929 .22027 .67601 .2179 .67279 .21349 Mtetra
.67279 .21349 .67601 .2179 .68273 .21551 .67953 .2111 Mtetra
.67953 .2111 .68273 .21551 .68948 .21313 .68628 .20871 Mtetra
.68628 .20871 .68948 .21313 .69624 .21073 .69305 .2063 Mtetra
.69305 .2063 .69624 .21073 .70302 .20834 .69984 .20389 Mtetra
.69984 .20389 .70302 .20834 .70981 .20593 .70665 .20148 Mtetra
.70665 .20148 .70981 .20593 .71662 .20352 .71347 .19906 Mtetra
.71347 .19906 .71662 .20352 .72344 .20111 .7203 .19663 Mtetra
.7203 .19663 .72344 .20111 .73029 .19869 .72716 .1942 Mtetra
.72716 .1942 .73029 .19869 .73714 .19626 .73403 .19176 Mtetra
.73403 .19176 .73714 .19626 .74402 .19383 .74091 .18932 Mtetra
.74091 .18932 .74402 .19383 .75091 .19139 .74782 .18687 Mtetra
.74782 .18687 .75091 .19139 .75782 .18894 .75474 .18441 Mtetra
.75474 .18441 .75782 .18894 .76474 .18649 .76167 .18195 Mtetra
.76167 .18195 .76474 .18649 .77169 .18403 .76863 .17948 Mtetra
.76863 .17948 .77169 .18403 .77864 .18157 .7756 .17701 Mtetra
.7756 .17701 .77864 .18157 .78562 .1791 .78258 .17453 Mtetra
.78258 .17453 .78562 .1791 .79261 .17663 .78959 .17205 Mtetra
.78959 .17205 .79261 .17663 .79962 .17415 .79661 .16955 Mtetra
.1716 .38628 .17555 .38995 .18115 .38796 .17721 .38428 Mtetra
.17721 .38428 .18115 .38796 .18677 .38597 .18283 .38228 Mtetra
.18283 .38228 .18677 .38597 .1924 .38397 .18847 .38027 Mtetra
.18847 .38027 .1924 .38397 .19804 .38197 .19412 .37826 Mtetra
.19412 .37826 .19804 .38197 .20369 .37996 .19978 .37625 Mtetra
.19978 .37625 .20369 .37996 .20936 .37795 .20545 .37423 Mtetra
.20545 .37423 .20936 .37795 .21503 .37594 .21114 .37221 Mtetra
.21114 .37221 .21503 .37594 .22073 .37392 .21684 .37018 Mtetra
.21684 .37018 .22073 .37392 .22643 .3719 .22255 .36815 Mtetra
.22255 .36815 .22643 .3719 .23214 .36987 .22827 .36611 Mtetra
.22827 .36611 .23214 .36987 .23787 .36783 .234 .36407 Mtetra
.234 .36407 .23787 .36783 .24361 .3658 .23975 .36202 Mtetra
.23975 .36202 .24361 .3658 .24937 .36376 .24551 .35997 Mtetra
.24551 .35997 .24937 .36376 .25513 .36171 .25129 .35792 Mtetra
.25129 .35792 .25513 .36171 .26091 .35966 .25707 .35586 Mtetra
.25707 .35586 .26091 .35966 .2667 .3576 .26287 .3538 Mtetra
.26287 .3538 .2667 .3576 .27251 .35554 .26869 .35173 Mtetra
.26869 .35173 .27251 .35554 .27833 .35348 .27451 .34965 Mtetra
.27451 .34965 .27833 .35348 .28416 .35141 .28035 .34758 Mtetra
.28035 .34758 .28416 .35141 .29 .34934 .2862 .3455 Mtetra
.2862 .3455 .29 .34934 .29586 .34726 .29206 .34341 Mtetra
.29206 .34341 .29586 .34726 .30173 .34517 .29794 .34132 Mtetra
.29794 .34132 .30173 .34517 .30761 .34309 .30383 .33922 Mtetra
.30383 .33922 .30761 .34309 .3135 .34099 .30974 .33712 Mtetra
.30974 .33712 .3135 .34099 .31941 .3389 .31565 .33501 Mtetra
.31565 .33501 .31941 .3389 .32534 .3368 .32158 .3329 Mtetra
.32158 .3329 .32534 .3368 .33127 .33469 .32753 .33079 Mtetra
.32753 .33079 .33127 .33469 .33722 .33258 .33348 .32867 Mtetra
.33348 .32867 .33722 .33258 .34318 .33046 .33945 .32654 Mtetra
.33945 .32654 .34318 .33046 .34916 .32834 .34544 .32442 Mtetra
.34544 .32442 .34916 .32834 .35515 .32622 .35143 .32228 Mtetra
.35143 .32228 .35515 .32622 .36115 .32409 .35744 .32014 Mtetra
.35744 .32014 .36115 .32409 .36716 .32195 .36347 .318 Mtetra
.36347 .318 .36716 .32195 .37319 .31981 .36951 .31585 Mtetra
.36951 .31585 .37319 .31981 .37924 .31767 .37556 .3137 Mtetra
.37556 .3137 .37924 .31767 .38529 .31552 .38162 .31154 Mtetra
.38162 .31154 .38529 .31552 .39136 .31336 .3877 .30937 Mtetra
.3877 .30937 .39136 .31336 .39745 .31121 .3938 .30721 Mtetra
.3938 .30721 .39745 .31121 .40355 .30904 .3999 .30503 Mtetra
.3999 .30503 .40355 .30904 .40966 .30687 .40602 .30286 Mtetra
.40602 .30286 .40966 .30687 .41578 .3047 .41216 .30067 Mtetra
.41216 .30067 .41578 .3047 .42192 .30252 .41831 .29848 Mtetra
.41831 .29848 .42192 .30252 .42808 .30034 .42447 .29629 Mtetra
.42447 .29629 .42808 .30034 .43424 .29815 .43064 .29409 Mtetra
.43064 .29409 .43424 .29815 .44043 .29596 .43684 .29189 Mtetra
.663 .741 .908 r
.43684 .29189 .44043 .29596 .44662 .29376 .44304 .28968 Mtetra
.44304 .28968 .44662 .29376 .45283 .29156 .44926 .28747 Mtetra
.44926 .28747 .45283 .29156 .45906 .28936 .45549 .28526 Mtetra
.657 .739 .91 r
.45549 .28526 .45906 .28936 .46529 .28726 .46174 .28315 Mtetra
.664 .74 .907 r
.46174 .28315 .46529 .28726 .47155 .28504 .468 .28092 Mtetra
.67 .743 .905 r
.468 .28092 .47155 .28504 .47782 .2827 .47428 .27858 Mtetra
.664 .741 .908 r
.47428 .27858 .47782 .2827 .4841 .28046 .48057 .27633 Mtetra
.48057 .27633 .4841 .28046 .49039 .27822 .48688 .27408 Mtetra
.48688 .27408 .49039 .27822 .49671 .27598 .4932 .27183 Mtetra
.4932 .27183 .49671 .27598 .50303 .27374 .49953 .26958 Mtetra
.49953 .26958 .50303 .27374 .50937 .27149 .50588 .26732 Mtetra
.50588 .26732 .50937 .27149 .51573 .26923 .51225 .26505 Mtetra
.51225 .26505 .51573 .26923 .5221 .26697 .51863 .26278 Mtetra
.51863 .26278 .5221 .26697 .52848 .26471 .52502 .26051 Mtetra
.52502 .26051 .52848 .26471 .53488 .26243 .53143 .25823 Mtetra
.53143 .25823 .53488 .26243 .54129 .26016 .53785 .25594 Mtetra
.53785 .25594 .54129 .26016 .54772 .25788 .54429 .25365 Mtetra
.54429 .25365 .54772 .25788 .55417 .25559 .55075 .25135 Mtetra
.55075 .25135 .55417 .25559 .56063 .2533 .55722 .24905 Mtetra
.55722 .24905 .56063 .2533 .5671 .251 .5637 .24674 Mtetra
.5637 .24674 .5671 .251 .57359 .2487 .5702 .24443 Mtetra
.5702 .24443 .57359 .2487 .58009 .24639 .57671 .24211 Mtetra
.57671 .24211 .58009 .24639 .58661 .24408 .58324 .23979 Mtetra
.58324 .23979 .58661 .24408 .59315 .24176 .58979 .23746 Mtetra
.58979 .23746 .59315 .24176 .5997 .23943 .59635 .23513 Mtetra
.59635 .23513 .5997 .23943 .60627 .2371 .60293 .23279 Mtetra
.60293 .23279 .60627 .2371 .61285 .23477 .60952 .23044 Mtetra
.60952 .23044 .61285 .23477 .61944 .23242 .61613 .22809 Mtetra
.61613 .22809 .61944 .23242 .62606 .23008 .62275 .22573 Mtetra
.62275 .22573 .62606 .23008 .63269 .22773 .62939 .22337 Mtetra
.62939 .22337 .63269 .22773 .63933 .22537 .63604 .221 Mtetra
.63604 .221 .63933 .22537 .64599 .223 .64271 .21863 Mtetra
.64271 .21863 .64599 .223 .65267 .22064 .6494 .21625 Mtetra
.6494 .21625 .65267 .22064 .65936 .21826 .6561 .21386 Mtetra
.6561 .21386 .65936 .21826 .66606 .21588 .66282 .21147 Mtetra
.66282 .21147 .66606 .21588 .67279 .21349 .66956 .20907 Mtetra
.66956 .20907 .67279 .21349 .67953 .2111 .67631 .20667 Mtetra
.67631 .20667 .67953 .2111 .68628 .20871 .68307 .20426 Mtetra
.68307 .20426 .68628 .20871 .69305 .2063 .68986 .20185 Mtetra
.68986 .20185 .69305 .2063 .69984 .20389 .69665 .19943 Mtetra
.69665 .19943 .69984 .20389 .70665 .20148 .70347 .19701 Mtetra
.70347 .19701 .70665 .20148 .71347 .19906 .7103 .19457 Mtetra
.7103 .19457 .71347 .19906 .7203 .19663 .71715 .19214 Mtetra
.71715 .19214 .7203 .19663 .72716 .1942 .72402 .18969 Mtetra
.72402 .18969 .72716 .1942 .73403 .19176 .7309 .18725 Mtetra
.7309 .18725 .73403 .19176 .74091 .18932 .73779 .18479 Mtetra
.73779 .18479 .74091 .18932 .74782 .18687 .74471 .18233 Mtetra
.74471 .18233 .74782 .18687 .75474 .18441 .75164 .17986 Mtetra
.75164 .17986 .75474 .18441 .76167 .18195 .75859 .17739 Mtetra
.75859 .17739 .76167 .18195 .76863 .17948 .76555 .17491 Mtetra
.76555 .17491 .76863 .17948 .7756 .17701 .77254 .17243 Mtetra
.77254 .17243 .7756 .17701 .78258 .17453 .77954 .16994 Mtetra
.77954 .16994 .78258 .17453 .78959 .17205 .78655 .16744 Mtetra
.78655 .16744 .78959 .17205 .79661 .16955 .79359 .16494 Mtetra
.16764 .38259 .1716 .38628 .17721 .38428 .17325 .38058 Mtetra
.17325 .38058 .17721 .38428 .18283 .38228 .17888 .37857 Mtetra
.17888 .37857 .18283 .38228 .18847 .38027 .18453 .37656 Mtetra
.18453 .37656 .18847 .38027 .19412 .37826 .19018 .37454 Mtetra
.19018 .37454 .19412 .37826 .19978 .37625 .19585 .37252 Mtetra
.19585 .37252 .19978 .37625 .20545 .37423 .20153 .37049 Mtetra
.20153 .37049 .20545 .37423 .21114 .37221 .20722 .36846 Mtetra
.20722 .36846 .21114 .37221 .21684 .37018 .21293 .36642 Mtetra
.21293 .36642 .21684 .37018 .22255 .36815 .21865 .36438 Mtetra
.21865 .36438 .22255 .36815 .22827 .36611 .22438 .36234 Mtetra
.22438 .36234 .22827 .36611 .234 .36407 .23012 .36029 Mtetra
.23012 .36029 .234 .36407 .23975 .36202 .23588 .35824 Mtetra
.23588 .35824 .23975 .36202 .24551 .35997 .24164 .35618 Mtetra
.24164 .35618 .24551 .35997 .25129 .35792 .24743 .35411 Mtetra
.24743 .35411 .25129 .35792 .25707 .35586 .25322 .35205 Mtetra
.25322 .35205 .25707 .35586 .26287 .3538 .25903 .34997 Mtetra
.25903 .34997 .26287 .3538 .26869 .35173 .26485 .3479 Mtetra
.26485 .3479 .26869 .35173 .27451 .34965 .27068 .34582 Mtetra
.27068 .34582 .27451 .34965 .28035 .34758 .27653 .34373 Mtetra
.27653 .34373 .28035 .34758 .2862 .3455 .28239 .34164 Mtetra
.28239 .34164 .2862 .3455 .29206 .34341 .28826 .33954 Mtetra
.28826 .33954 .29206 .34341 .29794 .34132 .29414 .33744 Mtetra
.29414 .33744 .29794 .34132 .30383 .33922 .30004 .33534 Mtetra
.30004 .33534 .30383 .33922 .30974 .33712 .30595 .33323 Mtetra
.30595 .33323 .30974 .33712 .31565 .33501 .31188 .33111 Mtetra
.31188 .33111 .31565 .33501 .32158 .3329 .31782 .329 Mtetra
.31782 .329 .32158 .3329 .32753 .33079 .32377 .32687 Mtetra
.32377 .32687 .32753 .33079 .33348 .32867 .32973 .32474 Mtetra
.32973 .32474 .33348 .32867 .33945 .32654 .33571 .32261 Mtetra
.33571 .32261 .33945 .32654 .34544 .32442 .3417 .32047 Mtetra
.3417 .32047 .34544 .32442 .35143 .32228 .34771 .31833 Mtetra
.34771 .31833 .35143 .32228 .35744 .32014 .35373 .31618 Mtetra
.35373 .31618 .35744 .32014 .36347 .318 .35976 .31403 Mtetra
.35976 .31403 .36347 .318 .36951 .31585 .36581 .31187 Mtetra
.36581 .31187 .36951 .31585 .37556 .3137 .37187 .30971 Mtetra
.37187 .30971 .37556 .3137 .38162 .31154 .37794 .30754 Mtetra
.37794 .30754 .38162 .31154 .3877 .30937 .38403 .30537 Mtetra
.38403 .30537 .3877 .30937 .3938 .30721 .39013 .30319 Mtetra
.39013 .30319 .3938 .30721 .3999 .30503 .39624 .30101 Mtetra
.39624 .30101 .3999 .30503 .40602 .30286 .40237 .29882 Mtetra
.40237 .29882 .40602 .30286 .41216 .30067 .40852 .29663 Mtetra
.40852 .29663 .41216 .30067 .41831 .29848 .41467 .29443 Mtetra
.41467 .29443 .41831 .29848 .42447 .29629 .42084 .29223 Mtetra
.42084 .29223 .42447 .29629 .43064 .29409 .42703 .29002 Mtetra
.42703 .29002 .43064 .29409 .43684 .29189 .43323 .28781 Mtetra
.663 .741 .908 r
.43323 .28781 .43684 .29189 .44304 .28968 .43944 .28559 Mtetra
.43944 .28559 .44304 .28968 .44926 .28747 .44567 .28337 Mtetra
.44567 .28337 .44926 .28747 .45549 .28526 .45191 .28115 Mtetra
.658 .739 .91 r
.45191 .28115 .45549 .28526 .46174 .28315 .45817 .27901 Mtetra
.664 .741 .907 r
.45817 .27901 .46174 .28315 .468 .28092 .46444 .27678 Mtetra
.669 .743 .905 r
.46444 .27678 .468 .28092 .47428 .27858 .47073 .27444 Mtetra
.664 .741 .908 r
.47073 .27444 .47428 .27858 .48057 .27633 .47703 .27218 Mtetra
.47703 .27218 .48057 .27633 .48688 .27408 .48335 .26993 Mtetra
.48335 .26993 .48688 .27408 .4932 .27183 .48968 .26767 Mtetra
.48968 .26767 .4932 .27183 .49953 .26958 .49602 .2654 Mtetra
.49602 .2654 .49953 .26958 .50588 .26732 .50238 .26313 Mtetra
.50238 .26313 .50588 .26732 .51225 .26505 .50875 .26086 Mtetra
.50875 .26086 .51225 .26505 .51863 .26278 .51514 .25858 Mtetra
.51514 .25858 .51863 .26278 .52502 .26051 .52155 .25629 Mtetra
.52155 .25629 .52502 .26051 .53143 .25823 .52796 .254 Mtetra
.52796 .254 .53143 .25823 .53785 .25594 .5344 .25171 Mtetra
.5344 .25171 .53785 .25594 .54429 .25365 .54085 .24941 Mtetra
.54085 .24941 .54429 .25365 .55075 .25135 .54731 .2471 Mtetra
.54731 .2471 .55075 .25135 .55722 .24905 .55379 .24479 Mtetra
.55379 .24479 .55722 .24905 .5637 .24674 .56028 .24247 Mtetra
.56028 .24247 .5637 .24674 .5702 .24443 .56679 .24015 Mtetra
.56679 .24015 .5702 .24443 .57671 .24211 .57332 .23782 Mtetra
.57332 .23782 .57671 .24211 .58324 .23979 .57986 .23549 Mtetra
.57986 .23549 .58324 .23979 .58979 .23746 .58642 .23315 Mtetra
.58642 .23315 .58979 .23746 .59635 .23513 .59299 .2308 Mtetra
.59299 .2308 .59635 .23513 .60293 .23279 .59957 .22845 Mtetra
.59957 .22845 .60293 .23279 .60952 .23044 .60618 .22609 Mtetra
.60618 .22609 .60952 .23044 .61613 .22809 .61279 .22373 Mtetra
.61279 .22373 .61613 .22809 .62275 .22573 .61943 .22137 Mtetra
.61943 .22137 .62275 .22573 .62939 .22337 .62608 .21899 Mtetra
.62608 .21899 .62939 .22337 .63604 .221 .63274 .21661 Mtetra
.63274 .21661 .63604 .221 .64271 .21863 .63942 .21423 Mtetra
.63942 .21423 .64271 .21863 .6494 .21625 .64612 .21184 Mtetra
.64612 .21184 .6494 .21625 .6561 .21386 .65283 .20944 Mtetra
.65283 .20944 .6561 .21386 .66282 .21147 .65956 .20704 Mtetra
.65956 .20704 .66282 .21147 .66956 .20907 .66631 .20464 Mtetra
.66631 .20464 .66956 .20907 .67631 .20667 .67307 .20222 Mtetra
.67307 .20222 .67631 .20667 .68307 .20426 .67985 .1998 Mtetra
.67985 .1998 .68307 .20426 .68986 .20185 .68664 .19738 Mtetra
.68664 .19738 .68986 .20185 .69665 .19943 .69345 .19495 Mtetra
.69345 .19495 .69665 .19943 .70347 .19701 .70028 .19251 Mtetra
.70028 .19251 .70347 .19701 .7103 .19457 .70712 .19007 Mtetra
.70712 .19007 .7103 .19457 .71715 .19214 .71398 .18762 Mtetra
.71398 .18762 .71715 .19214 .72402 .18969 .72086 .18517 Mtetra
.72086 .18517 .72402 .18969 .7309 .18725 .72775 .18271 Mtetra
.72775 .18271 .7309 .18725 .73779 .18479 .73466 .18024 Mtetra
.73466 .18024 .73779 .18479 .74471 .18233 .74159 .17777 Mtetra
.74159 .17777 .74471 .18233 .75164 .17986 .74853 .17529 Mtetra
.74853 .17529 .75164 .17986 .75859 .17739 .75549 .17281 Mtetra
.75549 .17281 .75859 .17739 .76555 .17491 .76247 .17032 Mtetra
.76247 .17032 .76555 .17491 .77254 .17243 .76946 .16782 Mtetra
.76946 .16782 .77254 .17243 .77954 .16994 .77647 .16532 Mtetra
.77647 .16532 .77954 .16994 .78655 .16744 .7835 .16281 Mtetra
.7835 .16281 .78655 .16744 .79359 .16494 .79055 .1603 Mtetra
.16366 .37888 .16764 .38259 .17325 .38058 .16928 .37687 Mtetra
.16928 .37687 .17325 .38058 .17888 .37857 .17492 .37485 Mtetra
.17492 .37485 .17888 .37857 .18453 .37656 .18057 .37283 Mtetra
.18057 .37283 .18453 .37656 .19018 .37454 .18623 .3708 Mtetra
.18623 .3708 .19018 .37454 .19585 .37252 .19191 .36877 Mtetra
.19191 .36877 .19585 .37252 .20153 .37049 .19759 .36674 Mtetra
.19759 .36674 .20153 .37049 .20722 .36846 .20329 .3647 Mtetra
.20329 .3647 .20722 .36846 .21293 .36642 .20901 .36265 Mtetra
.20901 .36265 .21293 .36642 .21865 .36438 .21473 .36061 Mtetra
.21473 .36061 .21865 .36438 .22438 .36234 .22047 .35855 Mtetra
.22047 .35855 .22438 .36234 .23012 .36029 .22622 .35649 Mtetra
.22622 .35649 .23012 .36029 .23588 .35824 .23198 .35443 Mtetra
.23198 .35443 .23588 .35824 .24164 .35618 .23776 .35236 Mtetra
.23776 .35236 .24164 .35618 .24743 .35411 .24355 .35029 Mtetra
.24355 .35029 .24743 .35411 .25322 .35205 .24935 .34822 Mtetra
.24935 .34822 .25322 .35205 .25903 .34997 .25517 .34614 Mtetra
.25517 .34614 .25903 .34997 .26485 .3479 .26099 .34405 Mtetra
.26099 .34405 .26485 .3479 .27068 .34582 .26683 .34196 Mtetra
.26683 .34196 .27068 .34582 .27653 .34373 .27269 .33987 Mtetra
.27269 .33987 .27653 .34373 .28239 .34164 .27855 .33777 Mtetra
.27855 .33777 .28239 .34164 .28826 .33954 .28443 .33566 Mtetra
.28443 .33566 .28826 .33954 .29414 .33744 .29033 .33355 Mtetra
.29033 .33355 .29414 .33744 .30004 .33534 .29623 .33144 Mtetra
.29623 .33144 .30004 .33534 .30595 .33323 .30215 .32932 Mtetra
.30215 .32932 .30595 .33323 .31188 .33111 .30809 .3272 Mtetra
.30809 .3272 .31188 .33111 .31782 .329 .31403 .32507 Mtetra
.31403 .32507 .31782 .329 .32377 .32687 .31999 .32294 Mtetra
.31999 .32294 .32377 .32687 .32973 .32474 .32596 .3208 Mtetra
.32596 .3208 .32973 .32474 .33571 .32261 .33195 .31866 Mtetra
.33195 .31866 .33571 .32261 .3417 .32047 .33795 .31651 Mtetra
.33795 .31651 .3417 .32047 .34771 .31833 .34396 .31436 Mtetra
.34396 .31436 .34771 .31833 .35373 .31618 .34999 .3122 Mtetra
.34999 .3122 .35373 .31618 .35976 .31403 .35603 .31004 Mtetra
.35603 .31004 .35976 .31403 .36581 .31187 .36209 .30787 Mtetra
.36209 .30787 .36581 .31187 .37187 .30971 .36816 .3057 Mtetra
.36816 .3057 .37187 .30971 .37794 .30754 .37424 .30353 Mtetra
.37424 .30353 .37794 .30754 .38403 .30537 .38033 .30134 Mtetra
.38033 .30134 .38403 .30537 .39013 .30319 .38644 .29916 Mtetra
.38644 .29916 .39013 .30319 .39624 .30101 .39257 .29697 Mtetra
.39257 .29697 .39624 .30101 .40237 .29882 .39871 .29477 Mtetra
.39871 .29477 .40237 .29882 .40852 .29663 .40486 .29257 Mtetra
.40486 .29257 .40852 .29663 .41467 .29443 .41103 .29036 Mtetra
.41103 .29036 .41467 .29443 .42084 .29223 .41721 .28815 Mtetra
.41721 .28815 .42084 .29223 .42703 .29002 .4234 .28593 Mtetra
.4234 .28593 .42703 .29002 .43323 .28781 .42961 .28371 Mtetra
.663 .741 .908 r
.42961 .28371 .43323 .28781 .43944 .28559 .43583 .28149 Mtetra
.43583 .28149 .43944 .28559 .44567 .28337 .44207 .27926 Mtetra
.44207 .27926 .44567 .28337 .45191 .28115 .44832 .27703 Mtetra
.658 .739 .91 r
.44832 .27703 .45191 .28115 .45817 .27901 .45459 .27487 Mtetra
.664 .741 .907 r
.45459 .27487 .45817 .27901 .46444 .27678 .46087 .27262 Mtetra
.669 .742 .906 r
.46087 .27262 .46444 .27678 .47073 .27444 .46716 .27028 Mtetra
.664 .741 .908 r
.46716 .27028 .47073 .27444 .47703 .27218 .47347 .26802 Mtetra
.47347 .26802 .47703 .27218 .48335 .26993 .4798 .26575 Mtetra
.4798 .26575 .48335 .26993 .48968 .26767 .48614 .26348 Mtetra
.48614 .26348 .48968 .26767 .49602 .2654 .49249 .26121 Mtetra
.49249 .26121 .49602 .2654 .50238 .26313 .49886 .25893 Mtetra
.49886 .25893 .50238 .26313 .50875 .26086 .50524 .25665 Mtetra
.50524 .25665 .50875 .26086 .51514 .25858 .51164 .25436 Mtetra
.51164 .25436 .51514 .25858 .52155 .25629 .51806 .25206 Mtetra
.51806 .25206 .52155 .25629 .52796 .254 .52448 .24976 Mtetra
.52448 .24976 .52796 .254 .5344 .25171 .53093 .24746 Mtetra
.53093 .24746 .5344 .25171 .54085 .24941 .53739 .24514 Mtetra
.53739 .24514 .54085 .24941 .54731 .2471 .54386 .24283 Mtetra
.54386 .24283 .54731 .2471 .55379 .24479 .55035 .24051 Mtetra
.55035 .24051 .55379 .24479 .56028 .24247 .55685 .23818 Mtetra
.55685 .23818 .56028 .24247 .56679 .24015 .56337 .23584 Mtetra
.56337 .23584 .56679 .24015 .57332 .23782 .56991 .23351 Mtetra
.56991 .23351 .57332 .23782 .57986 .23549 .57646 .23116 Mtetra
.57646 .23116 .57986 .23549 .58642 .23315 .58303 .22881 Mtetra
.58303 .22881 .58642 .23315 .59299 .2308 .58961 .22646 Mtetra
.58961 .22646 .59299 .2308 .59957 .22845 .5962 .2241 Mtetra
.5962 .2241 .59957 .22845 .60618 .22609 .60282 .22173 Mtetra
.60282 .22173 .60618 .22609 .61279 .22373 .60945 .21936 Mtetra
.60945 .21936 .61279 .22373 .61943 .22137 .61609 .21698 Mtetra
.61609 .21698 .61943 .22137 .62608 .21899 .62275 .2146 Mtetra
.62275 .2146 .62608 .21899 .63274 .21661 .62943 .21221 Mtetra
.62943 .21221 .63274 .21661 .63942 .21423 .63612 .20981 Mtetra
.63612 .20981 .63942 .21423 .64612 .21184 .64283 .20741 Mtetra
.64283 .20741 .64612 .21184 .65283 .20944 .64955 .20501 Mtetra
.64955 .20501 .65283 .20944 .65956 .20704 .65629 .20259 Mtetra
.65629 .20259 .65956 .20704 .66631 .20464 .66305 .20018 Mtetra
.66305 .20018 .66631 .20464 .67307 .20222 .66982 .19775 Mtetra
.66982 .19775 .67307 .20222 .67985 .1998 .67661 .19532 Mtetra
.67661 .19532 .67985 .1998 .68664 .19738 .68341 .19289 Mtetra
.68341 .19289 .68664 .19738 .69345 .19495 .69024 .19045 Mtetra
.69024 .19045 .69345 .19495 .70028 .19251 .69707 .188 Mtetra
.69707 .188 .70028 .19251 .70712 .19007 .70393 .18555 Mtetra
.70393 .18555 .70712 .19007 .71398 .18762 .7108 .18309 Mtetra
.7108 .18309 .71398 .18762 .72086 .18517 .71769 .18062 Mtetra
.71769 .18062 .72086 .18517 .72775 .18271 .72459 .17815 Mtetra
.72459 .17815 .72775 .18271 .73466 .18024 .73151 .17568 Mtetra
.73151 .17568 .73466 .18024 .74159 .17777 .73845 .17319 Mtetra
.73845 .17319 .74159 .17777 .74853 .17529 .74541 .1707 Mtetra
.74541 .1707 .74853 .17529 .75549 .17281 .75238 .16821 Mtetra
.75238 .16821 .75549 .17281 .76247 .17032 .75937 .16571 Mtetra
.75937 .16571 .76247 .17032 .76946 .16782 .76637 .1632 Mtetra
.76637 .1632 .76946 .16782 .77647 .16532 .7734 .16069 Mtetra
.7734 .16069 .77647 .16532 .7835 .16281 .78044 .15817 Mtetra
.78044 .15817 .7835 .16281 .79055 .1603 .7875 .15564 Mtetra
.15966 .37516 .16366 .37888 .16928 .37687 .16529 .37314 Mtetra
.16529 .37314 .16928 .37687 .17492 .37485 .17094 .37112 Mtetra
.17094 .37112 .17492 .37485 .18057 .37283 .1766 .36909 Mtetra
.1766 .36909 .18057 .37283 .18623 .3708 .18227 .36705 Mtetra
.18227 .36705 .18623 .3708 .19191 .36877 .18795 .36501 Mtetra
.18795 .36501 .19191 .36877 .19759 .36674 .19364 .36297 Mtetra
.19364 .36297 .19759 .36674 .20329 .3647 .19935 .36092 Mtetra
.19935 .36092 .20329 .3647 .20901 .36265 .20507 .35887 Mtetra
.20507 .35887 .20901 .36265 .21473 .36061 .2108 .35681 Mtetra
.2108 .35681 .21473 .36061 .22047 .35855 .21655 .35475 Mtetra
.21655 .35475 .22047 .35855 .22622 .35649 .22231 .35268 Mtetra
.22231 .35268 .22622 .35649 .23198 .35443 .22808 .35061 Mtetra
.22808 .35061 .23198 .35443 .23776 .35236 .23386 .34854 Mtetra
.23386 .34854 .23776 .35236 .24355 .35029 .23966 .34646 Mtetra
.23966 .34646 .24355 .35029 .24935 .34822 .24547 .34437 Mtetra
.24547 .34437 .24935 .34822 .25517 .34614 .25129 .34228 Mtetra
.25129 .34228 .25517 .34614 .26099 .34405 .25712 .34019 Mtetra
.25712 .34019 .26099 .34405 .26683 .34196 .26297 .33809 Mtetra
.26297 .33809 .26683 .34196 .27269 .33987 .26883 .33599 Mtetra
.26883 .33599 .27269 .33987 .27855 .33777 .27471 .33388 Mtetra
.27471 .33388 .27855 .33777 .28443 .33566 .28059 .33177 Mtetra
.28059 .33177 .28443 .33566 .29033 .33355 .2865 .32965 Mtetra
.2865 .32965 .29033 .33355 .29623 .33144 .29241 .32753 Mtetra
.29241 .32753 .29623 .33144 .30215 .32932 .29834 .3254 Mtetra
.29834 .3254 .30215 .32932 .30809 .3272 .30428 .32327 Mtetra
.30428 .32327 .30809 .3272 .31403 .32507 .31023 .32113 Mtetra
.31023 .32113 .31403 .32507 .31999 .32294 .3162 .31899 Mtetra
.3162 .31899 .31999 .32294 .32596 .3208 .32218 .31684 Mtetra
.32218 .31684 .32596 .3208 .33195 .31866 .32818 .31469 Mtetra
.32818 .31469 .33195 .31866 .33795 .31651 .33419 .31253 Mtetra
.33419 .31253 .33795 .31651 .34396 .31436 .34021 .31037 Mtetra
.34021 .31037 .34396 .31436 .34999 .3122 .34624 .30821 Mtetra
.34624 .30821 .34999 .3122 .35603 .31004 .35229 .30604 Mtetra
.35229 .30604 .35603 .31004 .36209 .30787 .35836 .30386 Mtetra
.35836 .30386 .36209 .30787 .36816 .3057 .36443 .30168 Mtetra
.36443 .30168 .36816 .3057 .37424 .30353 .37052 .29949 Mtetra
.37052 .29949 .37424 .30353 .38033 .30134 .37663 .2973 Mtetra
.37663 .2973 .38033 .30134 .38644 .29916 .38275 .29511 Mtetra
.38275 .29511 .38644 .29916 .39257 .29697 .38888 .29291 Mtetra
.38888 .29291 .39257 .29697 .39871 .29477 .39503 .2907 Mtetra
.39503 .2907 .39871 .29477 .40486 .29257 .40119 .28849 Mtetra
.40119 .28849 .40486 .29257 .41103 .29036 .40736 .28628 Mtetra
.40736 .28628 .41103 .29036 .41721 .28815 .41355 .28405 Mtetra
.41355 .28405 .41721 .28815 .4234 .28593 .41975 .28183 Mtetra
.41975 .28183 .4234 .28593 .42961 .28371 .42597 .2796 Mtetra
.42597 .2796 .42961 .28371 .43583 .28149 .4322 .27736 Mtetra
.663 .741 .908 r
.4322 .27736 .43583 .28149 .44207 .27926 .43845 .27512 Mtetra
.43845 .27512 .44207 .27926 .44832 .27703 .44471 .27288 Mtetra
.659 .74 .91 r
.44471 .27288 .44832 .27703 .45459 .27487 .45099 .27071 Mtetra
.664 .741 .908 r
.45099 .27071 .45459 .27487 .46087 .27262 .45728 .26845 Mtetra
.668 .742 .906 r
.45728 .26845 .46087 .27262 .46716 .27028 .46358 .26611 Mtetra
.664 .741 .908 r
.46358 .26611 .46716 .27028 .47347 .26802 .4699 .26384 Mtetra
.4699 .26384 .47347 .26802 .4798 .26575 .47624 .26156 Mtetra
.47624 .26156 .4798 .26575 .48614 .26348 .48258 .25928 Mtetra
.48258 .25928 .48614 .26348 .49249 .26121 .48895 .257 Mtetra
.48895 .257 .49249 .26121 .49886 .25893 .49533 .25471 Mtetra
.49533 .25471 .49886 .25893 .50524 .25665 .50172 .25242 Mtetra
.50172 .25242 .50524 .25665 .51164 .25436 .50813 .25012 Mtetra
.50813 .25012 .51164 .25436 .51806 .25206 .51455 .24781 Mtetra
.51455 .24781 .51806 .25206 .52448 .24976 .52099 .2455 Mtetra
.52099 .2455 .52448 .24976 .53093 .24746 .52744 .24318 Mtetra
.52744 .24318 .53093 .24746 .53739 .24514 .53391 .24086 Mtetra
.53391 .24086 .53739 .24514 .54386 .24283 .5404 .23854 Mtetra
.5404 .23854 .54386 .24283 .55035 .24051 .54689 .2362 Mtetra
.54689 .2362 .55035 .24051 .55685 .23818 .55341 .23387 Mtetra
.55341 .23387 .55685 .23818 .56337 .23584 .55994 .23152 Mtetra
.55994 .23152 .56337 .23584 .56991 .23351 .56648 .22917 Mtetra
.56648 .22917 .56991 .23351 .57646 .23116 .57305 .22682 Mtetra
.57305 .22682 .57646 .23116 .58303 .22881 .57962 .22446 Mtetra
.57962 .22446 .58303 .22881 .58961 .22646 .58621 .22209 Mtetra
.58621 .22209 .58961 .22646 .5962 .2241 .59282 .21972 Mtetra
.59282 .21972 .5962 .2241 .60282 .22173 .59944 .21735 Mtetra
.59944 .21735 .60282 .22173 .60945 .21936 .60608 .21496 Mtetra
.60608 .21496 .60945 .21936 .61609 .21698 .61274 .21258 Mtetra
.61274 .21258 .61609 .21698 .62275 .2146 .61941 .21018 Mtetra
.61941 .21018 .62275 .2146 .62943 .21221 .6261 .20778 Mtetra
.6261 .20778 .62943 .21221 .63612 .20981 .6328 .20538 Mtetra
.6328 .20538 .63612 .20981 .64283 .20741 .63952 .20297 Mtetra
.63952 .20297 .64283 .20741 .64955 .20501 .64625 .20055 Mtetra
.64625 .20055 .64955 .20501 .65629 .20259 .653 .19813 Mtetra
.653 .19813 .65629 .20259 .66305 .20018 .65977 .1957 Mtetra
.65977 .1957 .66305 .20018 .66982 .19775 .66656 .19326 Mtetra
.66656 .19326 .66982 .19775 .67661 .19532 .67336 .19082 Mtetra
.67336 .19082 .67661 .19532 .68341 .19289 .68017 .18838 Mtetra
.68017 .18838 .68341 .19289 .69024 .19045 .68701 .18592 Mtetra
.68701 .18592 .69024 .19045 .69707 .188 .69385 .18347 Mtetra
.69385 .18347 .69707 .188 .70393 .18555 .70072 .181 Mtetra
.70072 .181 .70393 .18555 .7108 .18309 .7076 .17853 Mtetra
.7076 .17853 .7108 .18309 .71769 .18062 .7145 .17606 Mtetra
.7145 .17606 .71769 .18062 .72459 .17815 .72142 .17358 Mtetra
.72142 .17358 .72459 .17815 .73151 .17568 .72835 .17109 Mtetra
.72835 .17109 .73151 .17568 .73845 .17319 .7353 .16859 Mtetra
.7353 .16859 .73845 .17319 .74541 .1707 .74227 .16609 Mtetra
.74227 .16609 .74541 .1707 .75238 .16821 .74925 .16359 Mtetra
.74925 .16359 .75238 .16821 .75937 .16571 .75625 .16107 Mtetra
.75625 .16107 .75937 .16571 .76637 .1632 .76327 .15856 Mtetra
.76327 .15856 .76637 .1632 .7734 .16069 .77031 .15603 Mtetra
.77031 .15603 .7734 .16069 .78044 .15817 .77736 .1535 Mtetra
.77736 .1535 .78044 .15817 .7875 .15564 .78443 .15096 Mtetra
.15565 .37143 .15966 .37516 .16529 .37314 .16129 .3694 Mtetra
.16129 .3694 .16529 .37314 .17094 .37112 .16694 .36736 Mtetra
.16694 .36736 .17094 .37112 .1766 .36909 .17261 .36533 Mtetra
.17261 .36533 .1766 .36909 .18227 .36705 .17828 .36328 Mtetra
.17828 .36328 .18227 .36705 .18795 .36501 .18397 .36124 Mtetra
.18397 .36124 .18795 .36501 .19364 .36297 .18967 .35918 Mtetra
.18967 .35918 .19364 .36297 .19935 .36092 .19539 .35713 Mtetra
.19539 .35713 .19935 .36092 .20507 .35887 .20112 .35507 Mtetra
.20112 .35507 .20507 .35887 .2108 .35681 .20686 .353 Mtetra
.20686 .353 .2108 .35681 .21655 .35475 .21261 .35093 Mtetra
.21261 .35093 .21655 .35475 .22231 .35268 .21837 .34886 Mtetra
.21837 .34886 .22231 .35268 .22808 .35061 .22415 .34678 Mtetra
.22415 .34678 .22808 .35061 .23386 .34854 .22994 .34469 Mtetra
.22994 .34469 .23386 .34854 .23966 .34646 .23575 .3426 Mtetra
.23575 .3426 .23966 .34646 .24547 .34437 .24156 .34051 Mtetra
.24156 .34051 .24547 .34437 .25129 .34228 .24739 .33841 Mtetra
.24739 .33841 .25129 .34228 .25712 .34019 .25324 .33631 Mtetra
.25324 .33631 .25712 .34019 .26297 .33809 .25909 .3342 Mtetra
.25909 .3342 .26297 .33809 .26883 .33599 .26496 .33209 Mtetra
.26496 .33209 .26883 .33599 .27471 .33388 .27084 .32997 Mtetra
.27084 .32997 .27471 .33388 .28059 .33177 .27674 .32785 Mtetra
.27674 .32785 .28059 .33177 .2865 .32965 .28265 .32573 Mtetra
.28265 .32573 .2865 .32965 .29241 .32753 .28857 .3236 Mtetra
.28857 .3236 .29241 .32753 .29834 .3254 .29451 .32146 Mtetra
.29451 .32146 .29834 .3254 .30428 .32327 .30046 .31932 Mtetra
.30046 .31932 .30428 .32327 .31023 .32113 .30642 .31717 Mtetra
.30642 .31717 .31023 .32113 .3162 .31899 .31239 .31502 Mtetra
.31239 .31502 .3162 .31899 .32218 .31684 .31838 .31287 Mtetra
.31838 .31287 .32218 .31684 .32818 .31469 .32439 .31071 Mtetra
.32439 .31071 .32818 .31469 .33419 .31253 .3304 .30854 Mtetra
.3304 .30854 .33419 .31253 .34021 .31037 .33643 .30637 Mtetra
.33643 .30637 .34021 .31037 .34624 .30821 .34248 .3042 Mtetra
.34248 .3042 .34624 .30821 .35229 .30604 .34854 .30202 Mtetra
.34854 .30202 .35229 .30604 .35836 .30386 .35461 .29983 Mtetra
.35461 .29983 .35836 .30386 .36443 .30168 .36069 .29764 Mtetra
.36069 .29764 .36443 .30168 .37052 .29949 .36679 .29545 Mtetra
.36679 .29545 .37052 .29949 .37663 .2973 .37291 .29325 Mtetra
.37291 .29325 .37663 .2973 .38275 .29511 .37903 .29104 Mtetra
.37903 .29104 .38275 .29511 .38888 .29291 .38517 .28883 Mtetra
.38517 .28883 .38888 .29291 .39503 .2907 .39133 .28662 Mtetra
.39133 .28662 .39503 .2907 .40119 .28849 .3975 .2844 Mtetra
.3975 .2844 .40119 .28849 .40736 .28628 .40368 .28217 Mtetra
.40368 .28217 .40736 .28628 .41355 .28405 .40988 .27994 Mtetra
.40988 .27994 .41355 .28405 .41975 .28183 .41609 .27771 Mtetra
.41609 .27771 .41975 .28183 .42597 .2796 .42232 .27546 Mtetra
.42232 .27546 .42597 .2796 .4322 .27736 .42856 .27322 Mtetra
.663 .741 .908 r
.42856 .27322 .4322 .27736 .43845 .27512 .43482 .27097 Mtetra
.43482 .27097 .43845 .27512 .44471 .27288 .44109 .26872 Mtetra
.659 .74 .909 r
.44109 .26872 .44471 .27288 .45099 .27071 .44737 .26653 Mtetra
.664 .741 .908 r
.44737 .26653 .45099 .27071 .45728 .26845 .45367 .26426 Mtetra
.668 .742 .906 r
.45367 .26426 .45728 .26845 .46358 .26611 .45999 .26192 Mtetra
.664 .741 .908 r
.45999 .26192 .46358 .26611 .4699 .26384 .46631 .25964 Mtetra
.46631 .25964 .4699 .26384 .47624 .26156 .47266 .25735 Mtetra
.47266 .25735 .47624 .26156 .48258 .25928 .47902 .25506 Mtetra
.47902 .25506 .48258 .25928 .48895 .257 .48539 .25277 Mtetra
.48539 .25277 .48895 .257 .49533 .25471 .49178 .25047 Mtetra
.49178 .25047 .49533 .25471 .50172 .25242 .49818 .24817 Mtetra
.49818 .24817 .50172 .25242 .50813 .25012 .5046 .24586 Mtetra
.5046 .24586 .50813 .25012 .51455 .24781 .51103 .24354 Mtetra
.51103 .24354 .51455 .24781 .52099 .2455 .51748 .24122 Mtetra
.51748 .24122 .52099 .2455 .52744 .24318 .52394 .23889 Mtetra
.52394 .23889 .52744 .24318 .53391 .24086 .53042 .23656 Mtetra
.53042 .23656 .53391 .24086 .5404 .23854 .53692 .23423 Mtetra
.53692 .23423 .5404 .23854 .54689 .2362 .54342 .23188 Mtetra
.54342 .23188 .54689 .2362 .55341 .23387 .54995 .22954 Mtetra
.54995 .22954 .55341 .23387 .55994 .23152 .55649 .22718 Mtetra
.55649 .22718 .55994 .23152 .56648 .22917 .56304 .22482 Mtetra
.56304 .22482 .56648 .22917 .57305 .22682 .56962 .22246 Mtetra
.56962 .22246 .57305 .22682 .57962 .22446 .5762 .22009 Mtetra
.5762 .22009 .57962 .22446 .58621 .22209 .58281 .21771 Mtetra
.58281 .21771 .58621 .22209 .59282 .21972 .58942 .21533 Mtetra
.58942 .21533 .59282 .21972 .59944 .21735 .59606 .21294 Mtetra
.59606 .21294 .59944 .21735 .60608 .21496 .60271 .21055 Mtetra
.60271 .21055 .60608 .21496 .61274 .21258 .60937 .20815 Mtetra
.60937 .20815 .61274 .21258 .61941 .21018 .61605 .20575 Mtetra
.61605 .20575 .61941 .21018 .6261 .20778 .62275 .20334 Mtetra
.62275 .20334 .6261 .20778 .6328 .20538 .62947 .20092 Mtetra
.62947 .20092 .6328 .20538 .63952 .20297 .6362 .1985 Mtetra
.6362 .1985 .63952 .20297 .64625 .20055 .64294 .19607 Mtetra
.64294 .19607 .64625 .20055 .653 .19813 .6497 .19364 Mtetra
.6497 .19364 .653 .19813 .65977 .1957 .65648 .1912 Mtetra
.65648 .1912 .65977 .1957 .66656 .19326 .66328 .18875 Mtetra
.66328 .18875 .66656 .19326 .67336 .19082 .67009 .1863 Mtetra
.67009 .1863 .67336 .19082 .68017 .18838 .67692 .18385 Mtetra
.67692 .18385 .68017 .18838 .68701 .18592 .68376 .18138 Mtetra
.68376 .18138 .68701 .18592 .69385 .18347 .69062 .17891 Mtetra
.69062 .17891 .69385 .18347 .70072 .181 .6975 .17644 Mtetra
.6975 .17644 .70072 .181 .7076 .17853 .70439 .17396 Mtetra
.70439 .17396 .7076 .17853 .7145 .17606 .7113 .17147 Mtetra
.7113 .17147 .7145 .17606 .72142 .17358 .71823 .16898 Mtetra
.71823 .16898 .72142 .17358 .72835 .17109 .72518 .16648 Mtetra
.72518 .16648 .72835 .17109 .7353 .16859 .73214 .16397 Mtetra
.73214 .16397 .7353 .16859 .74227 .16609 .73912 .16146 Mtetra
.73912 .16146 .74227 .16609 .74925 .16359 .74611 .15894 Mtetra
.74611 .15894 .74925 .16359 .75625 .16107 .75313 .15642 Mtetra
.75313 .15642 .75625 .16107 .76327 .15856 .76016 .15389 Mtetra
.76016 .15389 .76327 .15856 .77031 .15603 .7672 .15135 Mtetra
.7672 .15135 .77031 .15603 .77736 .1535 .77427 .14881 Mtetra
.77427 .14881 .77736 .1535 .78443 .15096 .78135 .14626 Mtetra
.15162 .36768 .15565 .37143 .16129 .3694 .15727 .36564 Mtetra
.15727 .36564 .16129 .3694 .16694 .36736 .16293 .3636 Mtetra
.16293 .3636 .16694 .36736 .17261 .36533 .1686 .36155 Mtetra
.1686 .36155 .17261 .36533 .17828 .36328 .17428 .3595 Mtetra
.17428 .3595 .17828 .36328 .18397 .36124 .17998 .35744 Mtetra
.17998 .35744 .18397 .36124 .18967 .35918 .18569 .35538 Mtetra
.18569 .35538 .18967 .35918 .19539 .35713 .19141 .35332 Mtetra
.19141 .35332 .19539 .35713 .20112 .35507 .19715 .35125 Mtetra
.19715 .35125 .20112 .35507 .20686 .353 .20289 .34918 Mtetra
.20289 .34918 .20686 .353 .21261 .35093 .20865 .3471 Mtetra
.20865 .3471 .21261 .35093 .21837 .34886 .21443 .34501 Mtetra
.21443 .34501 .21837 .34886 .22415 .34678 .22021 .34293 Mtetra
.22021 .34293 .22415 .34678 .22994 .34469 .22601 .34083 Mtetra
.22601 .34083 .22994 .34469 .23575 .3426 .23182 .33874 Mtetra
.23182 .33874 .23575 .3426 .24156 .34051 .23765 .33663 Mtetra
.23765 .33663 .24156 .34051 .24739 .33841 .24348 .33453 Mtetra
.24348 .33453 .24739 .33841 .25324 .33631 .24933 .33242 Mtetra
.24933 .33242 .25324 .33631 .25909 .3342 .2552 .3303 Mtetra
.2552 .3303 .25909 .3342 .26496 .33209 .26108 .32818 Mtetra
.26108 .32818 .26496 .33209 .27084 .32997 .26697 .32605 Mtetra
.26697 .32605 .27084 .32997 .27674 .32785 .27287 .32392 Mtetra
.27287 .32392 .27674 .32785 .28265 .32573 .27879 .32179 Mtetra
.27879 .32179 .28265 .32573 .28857 .3236 .28472 .31965 Mtetra
.28472 .31965 .28857 .3236 .29451 .32146 .29066 .3175 Mtetra
.29066 .3175 .29451 .32146 .30046 .31932 .29662 .31535 Mtetra
.29662 .31535 .30046 .31932 .30642 .31717 .30259 .3132 Mtetra
.30259 .3132 .30642 .31717 .31239 .31502 .30857 .31104 Mtetra
.30857 .31104 .31239 .31502 .31838 .31287 .31457 .30887 Mtetra
.31457 .30887 .31838 .31287 .32439 .31071 .32058 .30671 Mtetra
.32058 .30671 .32439 .31071 .3304 .30854 .32661 .30453 Mtetra
.32661 .30453 .3304 .30854 .33643 .30637 .33264 .30235 Mtetra
.33264 .30235 .33643 .30637 .34248 .3042 .3387 .30017 Mtetra
.3387 .30017 .34248 .3042 .34854 .30202 .34476 .29798 Mtetra
.34476 .29798 .34854 .30202 .35461 .29983 .35084 .29578 Mtetra
.35084 .29578 .35461 .29983 .36069 .29764 .35694 .29359 Mtetra
.35694 .29359 .36069 .29764 .36679 .29545 .36304 .29138 Mtetra
.36304 .29138 .36679 .29545 .37291 .29325 .36917 .28917 Mtetra
.36917 .28917 .37291 .29325 .37903 .29104 .3753 .28696 Mtetra
.3753 .28696 .37903 .29104 .38517 .28883 .38145 .28474 Mtetra
.38145 .28474 .38517 .28883 .39133 .28662 .38762 .28251 Mtetra
.38762 .28251 .39133 .28662 .3975 .2844 .3938 .28028 Mtetra
.3938 .28028 .3975 .2844 .40368 .28217 .39999 .27805 Mtetra
.39999 .27805 .40368 .28217 .40988 .27994 .4062 .27581 Mtetra
.4062 .27581 .40988 .27994 .41609 .27771 .41242 .27356 Mtetra
.41242 .27356 .41609 .27771 .42232 .27546 .41865 .27131 Mtetra
.41865 .27131 .42232 .27546 .42856 .27322 .4249 .26906 Mtetra
.663 .741 .908 r
.4249 .26906 .42856 .27322 .43482 .27097 .43117 .2668 Mtetra
.43117 .2668 .43482 .27097 .44109 .26872 .43745 .26454 Mtetra
.66 .74 .909 r
.43745 .26454 .44109 .26872 .44737 .26653 .44374 .26233 Mtetra
.664 .741 .908 r
.44374 .26233 .44737 .26653 .45367 .26426 .45005 .26005 Mtetra
.667 .742 .906 r
.45005 .26005 .45367 .26426 .45999 .26192 .45637 .25771 Mtetra
.664 .741 .908 r
.45637 .25771 .45999 .26192 .46631 .25964 .46271 .25542 Mtetra
.46271 .25542 .46631 .25964 .47266 .25735 .46906 .25312 Mtetra
.46906 .25312 .47266 .25735 .47902 .25506 .47543 .25082 Mtetra
.47543 .25082 .47902 .25506 .48539 .25277 .48182 .24852 Mtetra
.48182 .24852 .48539 .25277 .49178 .25047 .48821 .24621 Mtetra
.48821 .24621 .49178 .25047 .49818 .24817 .49463 .2439 Mtetra
.49463 .2439 .49818 .24817 .5046 .24586 .50105 .24158 Mtetra
.50105 .24158 .5046 .24586 .51103 .24354 .5075 .23925 Mtetra
.5075 .23925 .51103 .24354 .51748 .24122 .51395 .23692 Mtetra
.51395 .23692 .51748 .24122 .52394 .23889 .52043 .23459 Mtetra
.52043 .23459 .52394 .23889 .53042 .23656 .52692 .23224 Mtetra
.52692 .23224 .53042 .23656 .53692 .23423 .53342 .2299 Mtetra
.53342 .2299 .53692 .23423 .54342 .23188 .53994 .22754 Mtetra
.53994 .22754 .54342 .23188 .54995 .22954 .54647 .22519 Mtetra
.54647 .22519 .54995 .22954 .55649 .22718 .55302 .22282 Mtetra
.55302 .22282 .55649 .22718 .56304 .22482 .55959 .22045 Mtetra
.55959 .22045 .56304 .22482 .56962 .22246 .56617 .21808 Mtetra
.56617 .21808 .56962 .22246 .5762 .22009 .57277 .2157 Mtetra
.57277 .2157 .5762 .22009 .58281 .21771 .57938 .21331 Mtetra
.57938 .21331 .58281 .21771 .58942 .21533 .58601 .21092 Mtetra
.58601 .21092 .58942 .21533 .59606 .21294 .59265 .20852 Mtetra
.59265 .20852 .59606 .21294 .60271 .21055 .59932 .20612 Mtetra
.59932 .20612 .60271 .21055 .60937 .20815 .60599 .20371 Mtetra
.60599 .20371 .60937 .20815 .61605 .20575 .61268 .20129 Mtetra
.61268 .20129 .61605 .20575 .62275 .20334 .61939 .19887 Mtetra
.61939 .19887 .62275 .20334 .62947 .20092 .62612 .19645 Mtetra
.62612 .19645 .62947 .20092 .6362 .1985 .63286 .19401 Mtetra
.63286 .19401 .6362 .1985 .64294 .19607 .63961 .19157 Mtetra
.63961 .19157 .64294 .19607 .6497 .19364 .64639 .18913 Mtetra
.64639 .18913 .6497 .19364 .65648 .1912 .65318 .18668 Mtetra
.65318 .18668 .65648 .1912 .66328 .18875 .65998 .18422 Mtetra
.65998 .18422 .66328 .18875 .67009 .1863 .66681 .18176 Mtetra
.66681 .18176 .67009 .1863 .67692 .18385 .67364 .17929 Mtetra
.67364 .17929 .67692 .18385 .68376 .18138 .6805 .17682 Mtetra
.6805 .17682 .68376 .18138 .69062 .17891 .68737 .17434 Mtetra
.68737 .17434 .69062 .17891 .6975 .17644 .69426 .17185 Mtetra
.69426 .17185 .6975 .17644 .70439 .17396 .70117 .16936 Mtetra
.70117 .16936 .70439 .17396 .7113 .17147 .70809 .16686 Mtetra
.70809 .16686 .7113 .17147 .71823 .16898 .71503 .16436 Mtetra
.71503 .16436 .71823 .16898 .72518 .16648 .72199 .16185 Mtetra
.72199 .16185 .72518 .16648 .73214 .16397 .72896 .15933 Mtetra
.72896 .15933 .73214 .16397 .73912 .16146 .73595 .15681 Mtetra
.73595 .15681 .73912 .16146 .74611 .15894 .74296 .15428 Mtetra
.74296 .15428 .74611 .15894 .75313 .15642 .74998 .15175 Mtetra
.74998 .15175 .75313 .15642 .76016 .15389 .75703 .1492 Mtetra
.75703 .1492 .76016 .15389 .7672 .15135 .76409 .14666 Mtetra
.76409 .14666 .7672 .15135 .77427 .14881 .77116 .1441 Mtetra
.77116 .1441 .77427 .14881 .78135 .14626 .77826 .14154 Mtetra
.14758 .36391 .15162 .36768 .15727 .36564 .15323 .36187 Mtetra
.15323 .36187 .15727 .36564 .16293 .3636 .1589 .35982 Mtetra
.1589 .35982 .16293 .3636 .1686 .36155 .16458 .35776 Mtetra
.16458 .35776 .1686 .36155 .17428 .3595 .17027 .3557 Mtetra
.17027 .3557 .17428 .3595 .17998 .35744 .17597 .35364 Mtetra
.17597 .35364 .17998 .35744 .18569 .35538 .18169 .35157 Mtetra
.18169 .35157 .18569 .35538 .19141 .35332 .18742 .3495 Mtetra
.18742 .3495 .19141 .35332 .19715 .35125 .19316 .34742 Mtetra
.19316 .34742 .19715 .35125 .20289 .34918 .19891 .34533 Mtetra
.19891 .34533 .20289 .34918 .20865 .3471 .20468 .34325 Mtetra
.20468 .34325 .20865 .3471 .21443 .34501 .21046 .34116 Mtetra
.21046 .34116 .21443 .34501 .22021 .34293 .21625 .33906 Mtetra
.21625 .33906 .22021 .34293 .22601 .34083 .22206 .33696 Mtetra
.22206 .33696 .22601 .34083 .23182 .33874 .22788 .33485 Mtetra
.22788 .33485 .23182 .33874 .23765 .33663 .23371 .33274 Mtetra
.23371 .33274 .23765 .33663 .24348 .33453 .23956 .33063 Mtetra
.23956 .33063 .24348 .33453 .24933 .33242 .24542 .32851 Mtetra
.24542 .32851 .24933 .33242 .2552 .3303 .25129 .32638 Mtetra
.25129 .32638 .2552 .3303 .26108 .32818 .25717 .32425 Mtetra
.25717 .32425 .26108 .32818 .26697 .32605 .26307 .32212 Mtetra
.26307 .32212 .26697 .32605 .27287 .32392 .26898 .31998 Mtetra
.26898 .31998 .27287 .32392 .27879 .32179 .27491 .31783 Mtetra
.27491 .31783 .27879 .32179 .28472 .31965 .28084 .31568 Mtetra
.28084 .31568 .28472 .31965 .29066 .3175 .2868 .31353 Mtetra
.2868 .31353 .29066 .3175 .29662 .31535 .29276 .31137 Mtetra
.29276 .31137 .29662 .31535 .30259 .3132 .29874 .30921 Mtetra
.29874 .30921 .30259 .3132 .30857 .31104 .30473 .30704 Mtetra
.30473 .30704 .30857 .31104 .31457 .30887 .31074 .30487 Mtetra
.31074 .30487 .31457 .30887 .32058 .30671 .31676 .30269 Mtetra
.31676 .30269 .32058 .30671 .32661 .30453 .32279 .3005 Mtetra
.32279 .3005 .32661 .30453 .33264 .30235 .32884 .29832 Mtetra
.32884 .29832 .33264 .30235 .3387 .30017 .3349 .29612 Mtetra
.3349 .29612 .3387 .30017 .34476 .29798 .34097 .29392 Mtetra
.34097 .29392 .34476 .29798 .35084 .29578 .34706 .29172 Mtetra
.34706 .29172 .35084 .29578 .35694 .29359 .35317 .28951 Mtetra
.35317 .28951 .35694 .29359 .36304 .29138 .35928 .2873 Mtetra
.35928 .2873 .36304 .29138 .36917 .28917 .36541 .28508 Mtetra
.36541 .28508 .36917 .28917 .3753 .28696 .37156 .28286 Mtetra
.37156 .28286 .3753 .28696 .38145 .28474 .37772 .28063 Mtetra
.37772 .28063 .38145 .28474 .38762 .28251 .38389 .27839 Mtetra
.38389 .27839 .38762 .28251 .3938 .28028 .39008 .27615 Mtetra
.39008 .27615 .3938 .28028 .39999 .27805 .39628 .27391 Mtetra
.39628 .27391 .39999 .27805 .4062 .27581 .40249 .27166 Mtetra
.40249 .27166 .4062 .27581 .41242 .27356 .40873 .26941 Mtetra
.40873 .26941 .41242 .27356 .41865 .27131 .41497 .26715 Mtetra
.41497 .26715 .41865 .27131 .4249 .26906 .42123 .26488 Mtetra
.663 .741 .908 r
.42123 .26488 .4249 .26906 .43117 .2668 .4275 .26261 Mtetra
.4275 .26261 .43117 .2668 .43745 .26454 .43379 .26034 Mtetra
.66 .74 .909 r
.43379 .26034 .43745 .26454 .44374 .26233 .44009 .25812 Mtetra
.664 .741 .908 r
.44009 .25812 .44374 .26233 .45005 .26005 .44641 .25583 Mtetra
.667 .742 .906 r
.44641 .25583 .45005 .26005 .45637 .25771 .45275 .25348 Mtetra
.664 .741 .908 r
.45275 .25348 .45637 .25771 .46271 .25542 .45909 .25118 Mtetra
.45909 .25118 .46271 .25542 .46906 .25312 .46546 .24888 Mtetra
.46546 .24888 .46906 .25312 .47543 .25082 .47183 .24657 Mtetra
.47183 .24657 .47543 .25082 .48182 .24852 .47823 .24425 Mtetra
.47823 .24425 .48182 .24852 .48821 .24621 .48463 .24194 Mtetra
.48463 .24194 .48821 .24621 .49463 .2439 .49106 .23961 Mtetra
.49106 .23961 .49463 .2439 .50105 .24158 .49749 .23728 Mtetra
.49749 .23728 .50105 .24158 .5075 .23925 .50395 .23495 Mtetra
.50395 .23495 .5075 .23925 .51395 .23692 .51041 .23261 Mtetra
.51041 .23261 .51395 .23692 .52043 .23459 .5169 .23026 Mtetra
.5169 .23026 .52043 .23459 .52692 .23224 .5234 .22791 Mtetra
.5234 .22791 .52692 .23224 .53342 .2299 .52991 .22555 Mtetra
.52991 .22555 .53342 .2299 .53994 .22754 .53644 .22319 Mtetra
.53644 .22319 .53994 .22754 .54647 .22519 .54298 .22082 Mtetra
.54298 .22082 .54647 .22519 .55302 .22282 .54954 .21844 Mtetra
.54954 .21844 .55302 .22282 .55959 .22045 .55612 .21606 Mtetra
.55612 .21606 .55959 .22045 .56617 .21808 .56271 .21368 Mtetra
.56271 .21368 .56617 .21808 .57277 .2157 .56932 .21129 Mtetra
.56932 .21129 .57277 .2157 .57938 .21331 .57594 .20889 Mtetra
.57594 .20889 .57938 .21331 .58601 .21092 .58258 .20649 Mtetra
.58258 .20649 .58601 .21092 .59265 .20852 .58924 .20408 Mtetra
.58924 .20408 .59265 .20852 .59932 .20612 .59591 .20166 Mtetra
.59591 .20166 .59932 .20612 .60599 .20371 .6026 .19924 Mtetra
.6026 .19924 .60599 .20371 .61268 .20129 .6093 .19682 Mtetra
.6093 .19682 .61268 .20129 .61939 .19887 .61602 .19439 Mtetra
.61602 .19439 .61939 .19887 .62612 .19645 .62275 .19195 Mtetra
.62275 .19195 .62612 .19645 .63286 .19401 .6295 .18951 Mtetra
.6295 .18951 .63286 .19401 .63961 .19157 .63627 .18706 Mtetra
.63627 .18706 .63961 .19157 .64639 .18913 .64306 .1846 Mtetra
.64306 .1846 .64639 .18913 .65318 .18668 .64986 .18214 Mtetra
.64986 .18214 .65318 .18668 .65998 .18422 .65667 .17967 Mtetra
.65667 .17967 .65998 .18422 .66681 .18176 .66351 .1772 Mtetra
.66351 .1772 .66681 .18176 .67364 .17929 .67036 .17472 Mtetra
.67036 .17472 .67364 .17929 .6805 .17682 .67723 .17224 Mtetra
.67723 .17224 .6805 .17682 .68737 .17434 .68411 .16975 Mtetra
.68411 .16975 .68737 .17434 .69426 .17185 .69101 .16725 Mtetra
.69101 .16725 .69426 .17185 .70117 .16936 .69793 .16474 Mtetra
.69793 .16474 .70117 .16936 .70809 .16686 .70486 .16224 Mtetra
.70486 .16224 .70809 .16686 .71503 .16436 .71181 .15972 Mtetra
.71181 .15972 .71503 .16436 .72199 .16185 .71878 .1572 Mtetra
.71878 .1572 .72199 .16185 .72896 .15933 .72577 .15467 Mtetra
.72577 .15467 .72896 .15933 .73595 .15681 .73277 .15214 Mtetra
.73277 .15214 .73595 .15681 .74296 .15428 .73979 .1496 Mtetra
.73979 .1496 .74296 .15428 .74998 .15175 .74683 .14705 Mtetra
.74683 .14705 .74998 .15175 .75703 .1492 .75388 .1445 Mtetra
.75388 .1445 .75703 .1492 .76409 .14666 .76095 .14194 Mtetra
.76095 .14194 .76409 .14666 .77116 .1441 .76804 .13937 Mtetra
.76804 .13937 .77116 .1441 .77826 .14154 .77515 .1368 Mtetra
.14352 .36013 .14758 .36391 .15323 .36187 .14918 .35808 Mtetra
.14918 .35808 .15323 .36187 .1589 .35982 .15485 .35602 Mtetra
.15485 .35602 .1589 .35982 .16458 .35776 .16054 .35396 Mtetra
.16054 .35396 .16458 .35776 .17027 .3557 .16624 .35189 Mtetra
.16624 .35189 .17027 .3557 .17597 .35364 .17195 .34981 Mtetra
.17195 .34981 .17597 .35364 .18169 .35157 .17767 .34774 Mtetra
.17767 .34774 .18169 .35157 .18742 .3495 .18341 .34566 Mtetra
.18341 .34566 .18742 .3495 .19316 .34742 .18916 .34357 Mtetra
.18916 .34357 .19316 .34742 .19891 .34533 .19492 .34148 Mtetra
.19492 .34148 .19891 .34533 .20468 .34325 .20069 .33938 Mtetra
.20069 .33938 .20468 .34325 .21046 .34116 .20648 .33728 Mtetra
.20648 .33728 .21046 .34116 .21625 .33906 .21228 .33518 Mtetra
.21228 .33518 .21625 .33906 .22206 .33696 .2181 .33307 Mtetra
.2181 .33307 .22206 .33696 .22788 .33485 .22392 .33095 Mtetra
.22392 .33095 .22788 .33485 .23371 .33274 .22976 .32883 Mtetra
.22976 .32883 .23371 .33274 .23956 .33063 .23561 .32671 Mtetra
.23561 .32671 .23956 .33063 .24542 .32851 .24148 .32458 Mtetra
.24148 .32458 .24542 .32851 .25129 .32638 .24736 .32245 Mtetra
.24736 .32245 .25129 .32638 .25717 .32425 .25325 .32031 Mtetra
.25325 .32031 .25717 .32425 .26307 .32212 .25916 .31816 Mtetra
.25916 .31816 .26307 .32212 .26898 .31998 .26508 .31602 Mtetra
.26508 .31602 .26898 .31998 .27491 .31783 .27101 .31386 Mtetra
.27101 .31386 .27491 .31783 .28084 .31568 .27696 .3117 Mtetra
.27696 .3117 .28084 .31568 .2868 .31353 .28292 .30954 Mtetra
.28292 .30954 .2868 .31353 .29276 .31137 .28889 .30737 Mtetra
.28889 .30737 .29276 .31137 .29874 .30921 .29488 .3052 Mtetra
.29488 .3052 .29874 .30921 .30473 .30704 .30088 .30302 Mtetra
.30088 .30302 .30473 .30704 .31074 .30487 .30689 .30084 Mtetra
.30689 .30084 .31074 .30487 .31676 .30269 .31292 .29865 Mtetra
.31292 .29865 .31676 .30269 .32279 .3005 .31896 .29646 Mtetra
.31896 .29646 .32279 .3005 .32884 .29832 .32502 .29426 Mtetra
.32502 .29426 .32884 .29832 .3349 .29612 .33109 .29206 Mtetra
.33109 .29206 .3349 .29612 .34097 .29392 .33717 .28985 Mtetra
.33717 .28985 .34097 .29392 .34706 .29172 .34327 .28764 Mtetra
.34327 .28764 .34706 .29172 .35317 .28951 .34938 .28542 Mtetra
.34938 .28542 .35317 .28951 .35928 .2873 .3555 .2832 Mtetra
.3555 .2832 .35928 .2873 .36541 .28508 .36164 .28097 Mtetra
.36164 .28097 .36541 .28508 .37156 .28286 .3678 .27874 Mtetra
.3678 .27874 .37156 .28286 .37772 .28063 .37396 .2765 Mtetra
.37396 .2765 .37772 .28063 .38389 .27839 .38015 .27426 Mtetra
.38015 .27426 .38389 .27839 .39008 .27615 .38634 .27201 Mtetra
.38634 .27201 .39008 .27615 .39628 .27391 .39255 .26975 Mtetra
.39255 .26975 .39628 .27391 .40249 .27166 .39878 .26749 Mtetra
.39878 .26749 .40249 .27166 .40873 .26941 .40502 .26523 Mtetra
.40502 .26523 .40873 .26941 .41497 .26715 .41127 .26296 Mtetra
.41127 .26296 .41497 .26715 .42123 .26488 .41754 .26069 Mtetra
.663 .741 .908 r
.41754 .26069 .42123 .26488 .4275 .26261 .42382 .25841 Mtetra
.42382 .25841 .4275 .26261 .43379 .26034 .43012 .25612 Mtetra
.66 .74 .909 r
.43012 .25612 .43379 .26034 .44009 .25812 .43643 .25389 Mtetra
.664 .741 .908 r
.43643 .25389 .44009 .25812 .44641 .25583 .44276 .25159 Mtetra
.667 .742 .906 r
.44276 .25159 .44641 .25583 .45275 .25348 .4491 .24924 Mtetra
.664 .741 .908 r
.4491 .24924 .45275 .25348 .45909 .25118 .45546 .24692 Mtetra
.45546 .24692 .45909 .25118 .46546 .24888 .46183 .24461 Mtetra
.46183 .24461 .46546 .24888 .47183 .24657 .46822 .24229 Mtetra
.46822 .24229 .47183 .24657 .47823 .24425 .47462 .23997 Mtetra
.47462 .23997 .47823 .24425 .48463 .24194 .48104 .23764 Mtetra
.48104 .23764 .48463 .24194 .49106 .23961 .48747 .23531 Mtetra
.48747 .23531 .49106 .23961 .49749 .23728 .49392 .23297 Mtetra
.49392 .23297 .49749 .23728 .50395 .23495 .50038 .23062 Mtetra
.50038 .23062 .50395 .23495 .51041 .23261 .50686 .22827 Mtetra
.50686 .22827 .51041 .23261 .5169 .23026 .51335 .22591 Mtetra
.51335 .22591 .5169 .23026 .5234 .22791 .51986 .22355 Mtetra
.51986 .22355 .5234 .22791 .52991 .22555 .52638 .22118 Mtetra
.52638 .22118 .52991 .22555 .53644 .22319 .53292 .21881 Mtetra
.53292 .21881 .53644 .22319 .54298 .22082 .53948 .21643 Mtetra
.53948 .21643 .54298 .22082 .54954 .21844 .54605 .21405 Mtetra
.54605 .21405 .54954 .21844 .55612 .21606 .55264 .21166 Mtetra
.55264 .21166 .55612 .21606 .56271 .21368 .55924 .20926 Mtetra
.55924 .20926 .56271 .21368 .56932 .21129 .56586 .20686 Mtetra
.56586 .20686 .56932 .21129 .57594 .20889 .57249 .20445 Mtetra
.57249 .20445 .57594 .20889 .58258 .20649 .57914 .20204 Mtetra
.57914 .20204 .58258 .20649 .58924 .20408 .5858 .19962 Mtetra
.5858 .19962 .58924 .20408 .59591 .20166 .59249 .19719 Mtetra
.59249 .19719 .59591 .20166 .6026 .19924 .59918 .19476 Mtetra
.59918 .19476 .6026 .19924 .6093 .19682 .6059 .19233 Mtetra
.6059 .19233 .6093 .19682 .61602 .19439 .61263 .18988 Mtetra
.61263 .18988 .61602 .19439 .62275 .19195 .61937 .18743 Mtetra
.61937 .18743 .62275 .19195 .6295 .18951 .62614 .18498 Mtetra
.62614 .18498 .6295 .18951 .63627 .18706 .63292 .18252 Mtetra
.63292 .18252 .63627 .18706 .64306 .1846 .63971 .18005 Mtetra
.63971 .18005 .64306 .1846 .64986 .18214 .64652 .17758 Mtetra
.64652 .17758 .64986 .18214 .65667 .17967 .65335 .1751 Mtetra
.65335 .1751 .65667 .17967 .66351 .1772 .6602 .17262 Mtetra
.6602 .17262 .66351 .1772 .67036 .17472 .66706 .17013 Mtetra
.66706 .17013 .67036 .17472 .67723 .17224 .67394 .16763 Mtetra
.67394 .16763 .67723 .17224 .68411 .16975 .68083 .16513 Mtetra
.68083 .16513 .68411 .16975 .69101 .16725 .68774 .16262 Mtetra
.68774 .16262 .69101 .16725 .69793 .16474 .69467 .16011 Mtetra
.69467 .16011 .69793 .16474 .70486 .16224 .70162 .15759 Mtetra
.70162 .15759 .70486 .16224 .71181 .15972 .70858 .15506 Mtetra
.70858 .15506 .71181 .15972 .71878 .1572 .71556 .15253 Mtetra
.71556 .15253 .71878 .1572 .72577 .15467 .72256 .14999 Mtetra
.72256 .14999 .72577 .15467 .73277 .15214 .72957 .14744 Mtetra
.72957 .14744 .73277 .15214 .73979 .1496 .73661 .14489 Mtetra
.73661 .14489 .73979 .1496 .74683 .14705 .74366 .14233 Mtetra
.74366 .14233 .74683 .14705 .75388 .1445 .75072 .13977 Mtetra
.75072 .13977 .75388 .1445 .76095 .14194 .75781 .13719 Mtetra
.75781 .13719 .76095 .14194 .76804 .13937 .76491 .13462 Mtetra
.76491 .13462 .76804 .13937 .77515 .1368 .77203 .13203 Mtetra
.13944 .35634 .14352 .36013 .14918 .35808 .14511 .35427 Mtetra
.14511 .35427 .14918 .35808 .15485 .35602 .15079 .35221 Mtetra
.15079 .35221 .15485 .35602 .16054 .35396 .15648 .35013 Mtetra
.15648 .35013 .16054 .35396 .16624 .35189 .16219 .34806 Mtetra
.16219 .34806 .16624 .35189 .17195 .34981 .16791 .34598 Mtetra
.16791 .34598 .17195 .34981 .17767 .34774 .17364 .34389 Mtetra
.17364 .34389 .17767 .34774 .18341 .34566 .17938 .3418 Mtetra
.17938 .3418 .18341 .34566 .18916 .34357 .18514 .3397 Mtetra
.18514 .3397 .18916 .34357 .19492 .34148 .19091 .33761 Mtetra
.19091 .33761 .19492 .34148 .20069 .33938 .19669 .3355 Mtetra
.19669 .3355 .20069 .33938 .20648 .33728 .20248 .33339 Mtetra
.20248 .33339 .20648 .33728 .21228 .33518 .20829 .33128 Mtetra
.20829 .33128 .21228 .33518 .2181 .33307 .21411 .32916 Mtetra
.21411 .32916 .2181 .33307 .22392 .33095 .21995 .32704 Mtetra
.21995 .32704 .22392 .33095 .22976 .32883 .2258 .32491 Mtetra
.2258 .32491 .22976 .32883 .23561 .32671 .23166 .32277 Mtetra
.23166 .32277 .23561 .32671 .24148 .32458 .23753 .32064 Mtetra
.23753 .32064 .24148 .32458 .24736 .32245 .24342 .31849 Mtetra
.24342 .31849 .24736 .32245 .25325 .32031 .24932 .31635 Mtetra
.24932 .31635 .25325 .32031 .25916 .31816 .25523 .31419 Mtetra
.25523 .31419 .25916 .31816 .26508 .31602 .26116 .31204 Mtetra
.26116 .31204 .26508 .31602 .27101 .31386 .2671 .30987 Mtetra
.2671 .30987 .27101 .31386 .27696 .3117 .27305 .30771 Mtetra
.27305 .30771 .27696 .3117 .28292 .30954 .27902 .30554 Mtetra
.27902 .30554 .28292 .30954 .28889 .30737 .285 .30336 Mtetra
.285 .30336 .28889 .30737 .29488 .3052 .291 .30118 Mtetra
.291 .30118 .29488 .3052 .30088 .30302 .29701 .29899 Mtetra
.29701 .29899 .30088 .30302 .30689 .30084 .30303 .2968 Mtetra
.30303 .2968 .30689 .30084 .31292 .29865 .30906 .2946 Mtetra
.30906 .2946 .31292 .29865 .31896 .29646 .31511 .2924 Mtetra
.31511 .2924 .31896 .29646 .32502 .29426 .32118 .29019 Mtetra
.32118 .29019 .32502 .29426 .33109 .29206 .32726 .28798 Mtetra
.32726 .28798 .33109 .29206 .33717 .28985 .33335 .28576 Mtetra
.33335 .28576 .33717 .28985 .34327 .28764 .33945 .28354 Mtetra
.33945 .28354 .34327 .28764 .34938 .28542 .34557 .28131 Mtetra
.34557 .28131 .34938 .28542 .3555 .2832 .35171 .27908 Mtetra
.35171 .27908 .3555 .2832 .36164 .28097 .35786 .27684 Mtetra
.35786 .27684 .36164 .28097 .3678 .27874 .36402 .2746 Mtetra
.36402 .2746 .3678 .27874 .37396 .2765 .37019 .27235 Mtetra
.37019 .27235 .37396 .2765 .38015 .27426 .37639 .2701 Mtetra
.37639 .2701 .38015 .27426 .38634 .27201 .38259 .26784 Mtetra
.38259 .26784 .38634 .27201 .39255 .26975 .38881 .26558 Mtetra
.38881 .26558 .39255 .26975 .39878 .26749 .39504 .26331 Mtetra
.39504 .26331 .39878 .26749 .40502 .26523 .40129 .26103 Mtetra
.40129 .26103 .40502 .26523 .41127 .26296 .40756 .25876 Mtetra
.40756 .25876 .41127 .26296 .41754 .26069 .41383 .25647 Mtetra
.663 .741 .908 r
.41383 .25647 .41754 .26069 .42382 .25841 .42013 .25418 Mtetra
.42013 .25418 .42382 .25841 .43012 .25612 .42643 .25189 Mtetra
.66 .74 .909 r
.42643 .25189 .43012 .25612 .43643 .25389 .43275 .24964 Mtetra
.664 .741 .908 r
.43275 .24964 .43643 .25389 .44276 .25159 .43909 .24733 Mtetra
.667 .742 .907 r
.43909 .24733 .44276 .25159 .4491 .24924 .44544 .24497 Mtetra
.664 .741 .908 r
.44544 .24497 .4491 .24924 .45546 .24692 .45181 .24265 Mtetra
.45181 .24265 .45546 .24692 .46183 .24461 .45819 .24033 Mtetra
.45819 .24033 .46183 .24461 .46822 .24229 .46459 .238 Mtetra
.46459 .238 .46822 .24229 .47462 .23997 .471 .23567 Mtetra
.471 .23567 .47462 .23997 .48104 .23764 .47743 .23333 Mtetra
.47743 .23333 .48104 .23764 .48747 .23531 .48387 .23098 Mtetra
.48387 .23098 .48747 .23531 .49392 .23297 .49033 .22863 Mtetra
.49033 .22863 .49392 .23297 .50038 .23062 .4968 .22628 Mtetra
.4968 .22628 .50038 .23062 .50686 .22827 .50329 .22391 Mtetra
.50329 .22391 .50686 .22827 .51335 .22591 .50979 .22155 Mtetra
.50979 .22155 .51335 .22591 .51986 .22355 .51631 .21917 Mtetra
.51631 .21917 .51986 .22355 .52638 .22118 .52284 .2168 Mtetra
.52284 .2168 .52638 .22118 .53292 .21881 .52939 .21441 Mtetra
.52939 .21441 .53292 .21881 .53948 .21643 .53596 .21202 Mtetra
.53596 .21202 .53948 .21643 .54605 .21405 .54254 .20963 Mtetra
.54254 .20963 .54605 .21405 .55264 .21166 .54913 .20723 Mtetra
.54913 .20723 .55264 .21166 .55924 .20926 .55575 .20482 Mtetra
.55575 .20482 .55924 .20926 .56586 .20686 .56238 .20241 Mtetra
.56238 .20241 .56586 .20686 .57249 .20445 .56902 .19999 Mtetra
.56902 .19999 .57249 .20445 .57914 .20204 .57568 .19757 Mtetra
.57568 .19757 .57914 .20204 .5858 .19962 .58236 .19514 Mtetra
.58236 .19514 .5858 .19962 .59249 .19719 .58905 .1927 Mtetra
.58905 .1927 .59249 .19719 .59918 .19476 .59576 .19026 Mtetra
.59576 .19026 .59918 .19476 .6059 .19233 .60248 .18781 Mtetra
.60248 .18781 .6059 .19233 .61263 .18988 .60922 .18536 Mtetra
.60922 .18536 .61263 .18988 .61937 .18743 .61598 .1829 Mtetra
.61598 .1829 .61937 .18743 .62614 .18498 .62275 .18043 Mtetra
.62275 .18043 .62614 .18498 .63292 .18252 .62954 .17796 Mtetra
.62954 .17796 .63292 .18252 .63971 .18005 .63635 .17549 Mtetra
.63635 .17549 .63971 .18005 .64652 .17758 .64317 .173 Mtetra
.64317 .173 .64652 .17758 .65335 .1751 .65001 .17051 Mtetra
.65001 .17051 .65335 .1751 .6602 .17262 .65687 .16802 Mtetra
.65687 .16802 .6602 .17262 .66706 .17013 .66374 .16552 Mtetra
.66374 .16552 .66706 .17013 .67394 .16763 .67063 .16301 Mtetra
.67063 .16301 .67394 .16763 .68083 .16513 .67754 .16049 Mtetra
.67754 .16049 .68083 .16513 .68774 .16262 .68446 .15797 Mtetra
.68446 .15797 .68774 .16262 .69467 .16011 .6914 .15545 Mtetra
.6914 .15545 .69467 .16011 .70162 .15759 .69836 .15292 Mtetra
.69836 .15292 .70162 .15759 .70858 .15506 .70534 .15038 Mtetra
.70534 .15038 .70858 .15506 .71556 .15253 .71233 .14783 Mtetra
.71233 .14783 .71556 .15253 .72256 .14999 .71934 .14528 Mtetra
.71934 .14528 .72256 .14999 .72957 .14744 .72636 .14272 Mtetra
.72636 .14272 .72957 .14744 .73661 .14489 .73341 .14016 Mtetra
.73341 .14016 .73661 .14489 .74366 .14233 .74047 .13759 Mtetra
.74047 .13759 .74366 .14233 .75072 .13977 .74755 .13501 Mtetra
.74755 .13501 .75072 .13977 .75781 .13719 .75465 .13243 Mtetra
.75465 .13243 .75781 .13719 .76491 .13462 .76176 .12984 Mtetra
.76176 .12984 .76491 .13462 .77203 .13203 .76889 .12725 Mtetra
.13535 .35252 .13944 .35634 .14511 .35427 .14102 .35045 Mtetra
.14102 .35045 .14511 .35427 .15079 .35221 .14671 .34838 Mtetra
.14671 .34838 .15079 .35221 .15648 .35013 .15241 .3463 Mtetra
.15241 .3463 .15648 .35013 .16219 .34806 .15812 .34421 Mtetra
.15812 .34421 .16219 .34806 .16791 .34598 .16385 .34212 Mtetra
.16385 .34212 .16791 .34598 .17364 .34389 .16959 .34003 Mtetra
.16959 .34003 .17364 .34389 .17938 .3418 .17534 .33793 Mtetra
.17534 .33793 .17938 .3418 .18514 .3397 .1811 .33582 Mtetra
.1811 .33582 .18514 .3397 .19091 .33761 .18688 .33372 Mtetra
.18688 .33372 .19091 .33761 .19669 .3355 .19267 .3316 Mtetra
.19267 .3316 .19669 .3355 .20248 .33339 .19847 .32949 Mtetra
.19847 .32949 .20248 .33339 .20829 .33128 .20429 .32736 Mtetra
.20429 .32736 .20829 .33128 .21411 .32916 .21011 .32523 Mtetra
.21011 .32523 .21411 .32916 .21995 .32704 .21596 .3231 Mtetra
.21596 .3231 .21995 .32704 .2258 .32491 .22181 .32097 Mtetra
.22181 .32097 .2258 .32491 .23166 .32277 .22768 .31882 Mtetra
.22768 .31882 .23166 .32277 .23753 .32064 .23356 .31668 Mtetra
.23356 .31668 .23753 .32064 .24342 .31849 .23946 .31453 Mtetra
.23946 .31453 .24342 .31849 .24932 .31635 .24537 .31237 Mtetra
.24537 .31237 .24932 .31635 .25523 .31419 .25129 .31021 Mtetra
.25129 .31021 .25523 .31419 .26116 .31204 .25722 .30804 Mtetra
.25722 .30804 .26116 .31204 .2671 .30987 .26317 .30587 Mtetra
.26317 .30587 .2671 .30987 .27305 .30771 .26913 .30369 Mtetra
.26913 .30369 .27305 .30771 .27902 .30554 .27511 .30151 Mtetra
.27511 .30151 .27902 .30554 .285 .30336 .2811 .29933 Mtetra
.2811 .29933 .285 .30336 .291 .30118 .2871 .29714 Mtetra
.2871 .29714 .291 .30118 .29701 .29899 .29312 .29494 Mtetra
.29312 .29494 .29701 .29899 .30303 .2968 .29915 .29274 Mtetra
.29915 .29274 .30303 .2968 .30906 .2946 .30519 .29053 Mtetra
.30519 .29053 .30906 .2946 .31511 .2924 .31125 .28832 Mtetra
.31125 .28832 .31511 .2924 .32118 .29019 .31732 .2861 Mtetra
.31732 .2861 .32118 .29019 .32726 .28798 .32341 .28388 Mtetra
.32341 .28388 .32726 .28798 .33335 .28576 .32951 .28166 Mtetra
.32951 .28166 .33335 .28576 .33945 .28354 .33563 .27942 Mtetra
.33563 .27942 .33945 .28354 .34557 .28131 .34175 .27719 Mtetra
.34175 .27719 .34557 .28131 .35171 .27908 .3479 .27495 Mtetra
.3479 .27495 .35171 .27908 .35786 .27684 .35405 .2727 Mtetra
.35405 .2727 .35786 .27684 .36402 .2746 .36022 .27045 Mtetra
.36022 .27045 .36402 .2746 .37019 .27235 .36641 .26819 Mtetra
.36641 .26819 .37019 .27235 .37639 .2701 .37261 .26593 Mtetra
.37261 .26593 .37639 .2701 .38259 .26784 .37882 .26366 Mtetra
.37882 .26366 .38259 .26784 .38881 .26558 .38505 .26138 Mtetra
.38505 .26138 .38881 .26558 .39504 .26331 .3913 .25911 Mtetra
.3913 .25911 .39504 .26331 .40129 .26103 .39755 .25682 Mtetra
.39755 .25682 .40129 .26103 .40756 .25876 .40383 .25453 Mtetra
.40383 .25453 .40756 .25876 .41383 .25647 .41011 .25224 Mtetra
.663 .741 .908 r
.41011 .25224 .41383 .25647 .42013 .25418 .41641 .24994 Mtetra
.41641 .24994 .42013 .25418 .42643 .25189 .42273 .24764 Mtetra
.661 .74 .909 r
.42273 .24764 .42643 .25189 .43275 .24964 .42906 .24537 Mtetra
.664 .741 .908 r
.42906 .24537 .43275 .24964 .43909 .24733 .43541 .24306 Mtetra
.666 .742 .907 r
.43541 .24306 .43909 .24733 .44544 .24497 .44177 .24069 Mtetra
.664 .741 .908 r
.44177 .24069 .44544 .24497 .45181 .24265 .44814 .23836 Mtetra
.44814 .23836 .45181 .24265 .45819 .24033 .45454 .23603 Mtetra
.45454 .23603 .45819 .24033 .46459 .238 .46094 .23369 Mtetra
.46094 .23369 .46459 .238 .471 .23567 .46736 .23134 Mtetra
.46736 .23134 .471 .23567 .47743 .23333 .4738 .22899 Mtetra
.4738 .22899 .47743 .23333 .48387 .23098 .48025 .22664 Mtetra
.48025 .22664 .48387 .23098 .49033 .22863 .48672 .22428 Mtetra
.48672 .22428 .49033 .22863 .4968 .22628 .4932 .22191 Mtetra
.4932 .22191 .4968 .22628 .50329 .22391 .4997 .21954 Mtetra
.4997 .21954 .50329 .22391 .50979 .22155 .50621 .21716 Mtetra
.50621 .21716 .50979 .22155 .51631 .21917 .51274 .21478 Mtetra
.51274 .21478 .51631 .21917 .52284 .2168 .51928 .21239 Mtetra
.51928 .21239 .52284 .2168 .52939 .21441 .52584 .21 Mtetra
.52584 .21 .52939 .21441 .53596 .21202 .53242 .2076 Mtetra
.53242 .2076 .53596 .21202 .54254 .20963 .53901 .20519 Mtetra
.53901 .20519 .54254 .20963 .54913 .20723 .54562 .20278 Mtetra
.54562 .20278 .54913 .20723 .55575 .20482 .55224 .20036 Mtetra
.55224 .20036 .55575 .20482 .56238 .20241 .55888 .19794 Mtetra
.55888 .19794 .56238 .20241 .56902 .19999 .56554 .19551 Mtetra
.56554 .19551 .56902 .19999 .57568 .19757 .57221 .19308 Mtetra
.57221 .19308 .57568 .19757 .58236 .19514 .57889 .19064 Mtetra
.57889 .19064 .58236 .19514 .58905 .1927 .5856 .18819 Mtetra
.5856 .18819 .58905 .1927 .59576 .19026 .59232 .18574 Mtetra
.59232 .18574 .59576 .19026 .60248 .18781 .59905 .18328 Mtetra
.59905 .18328 .60248 .18781 .60922 .18536 .6058 .18081 Mtetra
.6058 .18081 .60922 .18536 .61598 .1829 .61257 .17834 Mtetra
.61257 .17834 .61598 .1829 .62275 .18043 .61936 .17587 Mtetra
.61936 .17587 .62275 .18043 .62954 .17796 .62616 .17338 Mtetra
.62616 .17338 .62954 .17796 .63635 .17549 .63297 .1709 Mtetra
.63297 .1709 .63635 .17549 .64317 .173 .63981 .1684 Mtetra
.63981 .1684 .64317 .173 .65001 .17051 .64666 .1659 Mtetra
.64666 .1659 .65001 .17051 .65687 .16802 .65353 .16339 Mtetra
.65353 .16339 .65687 .16802 .66374 .16552 .66041 .16088 Mtetra
.66041 .16088 .66374 .16552 .67063 .16301 .66731 .15836 Mtetra
.66731 .15836 .67063 .16301 .67754 .16049 .67423 .15584 Mtetra
.67423 .15584 .67754 .16049 .68446 .15797 .68117 .15331 Mtetra
.68117 .15331 .68446 .15797 .6914 .15545 .68812 .15077 Mtetra
.68812 .15077 .6914 .15545 .69836 .15292 .69509 .14822 Mtetra
.69509 .14822 .69836 .15292 .70534 .15038 .70208 .14567 Mtetra
.70208 .14567 .70534 .15038 .71233 .14783 .70908 .14312 Mtetra
.70908 .14312 .71233 .14783 .71934 .14528 .7161 .14056 Mtetra
.7161 .14056 .71934 .14528 .72636 .14272 .72314 .13799 Mtetra
.72314 .13799 .72636 .14272 .73341 .14016 .7302 .13541 Mtetra
.7302 .13541 .73341 .14016 .74047 .13759 .73727 .13283 Mtetra
.73727 .13283 .74047 .13759 .74755 .13501 .74436 .13024 Mtetra
.74436 .13024 .74755 .13501 .75465 .13243 .75147 .12765 Mtetra
.75147 .12765 .75465 .13243 .76176 .12984 .7586 .12505 Mtetra
.7586 .12505 .76176 .12984 .76889 .12725 .76574 .12244 Mtetra
.13124 .3487 .13535 .35252 .14102 .35045 .13692 .34662 Mtetra
.13692 .34662 .14102 .35045 .14671 .34838 .14261 .34453 Mtetra
.14261 .34453 .14671 .34838 .15241 .3463 .14832 .34244 Mtetra
.14832 .34244 .15241 .3463 .15812 .34421 .15404 .34035 Mtetra
.15404 .34035 .15812 .34421 .16385 .34212 .15977 .33825 Mtetra
.15977 .33825 .16385 .34212 .16959 .34003 .16552 .33615 Mtetra
.16552 .33615 .16959 .34003 .17534 .33793 .17128 .33404 Mtetra
.17128 .33404 .17534 .33793 .1811 .33582 .17705 .33193 Mtetra
.17705 .33193 .1811 .33582 .18688 .33372 .18283 .32981 Mtetra
.18283 .32981 .18688 .33372 .19267 .3316 .18863 .32769 Mtetra
.18863 .32769 .19267 .3316 .19847 .32949 .19444 .32556 Mtetra
.19444 .32556 .19847 .32949 .20429 .32736 .20026 .32343 Mtetra
.20026 .32343 .20429 .32736 .21011 .32523 .2061 .32129 Mtetra
.2061 .32129 .21011 .32523 .21596 .3231 .21195 .31915 Mtetra
.21195 .31915 .21596 .3231 .22181 .32097 .21781 .31701 Mtetra
.21781 .31701 .22181 .32097 .22768 .31882 .22369 .31486 Mtetra
.22369 .31486 .22768 .31882 .23356 .31668 .22958 .3127 Mtetra
.22958 .3127 .23356 .31668 .23946 .31453 .23548 .31054 Mtetra
.23548 .31054 .23946 .31453 .24537 .31237 .2414 .30837 Mtetra
.2414 .30837 .24537 .31237 .25129 .31021 .24733 .3062 Mtetra
.24733 .3062 .25129 .31021 .25722 .30804 .25327 .30403 Mtetra
.25327 .30403 .25722 .30804 .26317 .30587 .25923 .30185 Mtetra
.25923 .30185 .26317 .30587 .26913 .30369 .2652 .29966 Mtetra
.2652 .29966 .26913 .30369 .27511 .30151 .27118 .29747 Mtetra
.27118 .29747 .27511 .30151 .2811 .29933 .27718 .29528 Mtetra
.27718 .29528 .2811 .29933 .2871 .29714 .28319 .29308 Mtetra
.28319 .29308 .2871 .29714 .29312 .29494 .28921 .29087 Mtetra
.28921 .29087 .29312 .29494 .29915 .29274 .29525 .28866 Mtetra
.29525 .28866 .29915 .29274 .30519 .29053 .30131 .28645 Mtetra
.30131 .28645 .30519 .29053 .31125 .28832 .30737 .28423 Mtetra
.30737 .28423 .31125 .28832 .31732 .2861 .31345 .282 Mtetra
.31345 .282 .31732 .2861 .32341 .28388 .31955 .27977 Mtetra
.31955 .27977 .32341 .28388 .32951 .28166 .32566 .27753 Mtetra
.32566 .27753 .32951 .28166 .33563 .27942 .33178 .27529 Mtetra
.33178 .27529 .33563 .27942 .34175 .27719 .33792 .27305 Mtetra
.33792 .27305 .34175 .27719 .3479 .27495 .34407 .27079 Mtetra
.34407 .27079 .3479 .27495 .35405 .2727 .35023 .26854 Mtetra
.35023 .26854 .35405 .2727 .36022 .27045 .35641 .26627 Mtetra
.35641 .26627 .36022 .27045 .36641 .26819 .36261 .26401 Mtetra
.36261 .26401 .36641 .26819 .37261 .26593 .36882 .26173 Mtetra
.36882 .26173 .37261 .26593 .37882 .26366 .37504 .25946 Mtetra
.37504 .25946 .37882 .26366 .38505 .26138 .38128 .25717 Mtetra
.38128 .25717 .38505 .26138 .3913 .25911 .38753 .25489 Mtetra
.38753 .25489 .3913 .25911 .39755 .25682 .3938 .25259 Mtetra
.3938 .25259 .39755 .25682 .40383 .25453 .40008 .25029 Mtetra
.40008 .25029 .40383 .25453 .41011 .25224 .40637 .24799 Mtetra
.663 .741 .908 r
.40637 .24799 .41011 .25224 .41641 .24994 .41269 .24568 Mtetra
.41269 .24568 .41641 .24994 .42273 .24764 .41901 .24337 Mtetra
.661 .74 .909 r
.41901 .24337 .42273 .24764 .42906 .24537 .42535 .24109 Mtetra
.664 .741 .908 r
.42535 .24109 .42906 .24537 .43541 .24306 .43171 .23876 Mtetra
.666 .742 .907 r
.43171 .23876 .43541 .24306 .44177 .24069 .43808 .23639 Mtetra
.664 .741 .908 r
.43808 .23639 .44177 .24069 .44814 .23836 .44446 .23405 Mtetra
.44446 .23405 .44814 .23836 .45454 .23603 .45086 .2317 Mtetra
.45086 .2317 .45454 .23603 .46094 .23369 .45728 .22936 Mtetra
.45728 .22936 .46094 .23369 .46736 .23134 .46371 .227 Mtetra
.46371 .227 .46736 .23134 .4738 .22899 .47016 .22464 Mtetra
.47016 .22464 .4738 .22899 .48025 .22664 .47662 .22228 Mtetra
.47662 .22228 .48025 .22664 .48672 .22428 .4831 .21991 Mtetra
.4831 .21991 .48672 .22428 .4932 .22191 .48959 .21753 Mtetra
.48959 .21753 .4932 .22191 .4997 .21954 .4961 .21515 Mtetra
.4961 .21515 .4997 .21954 .50621 .21716 .50262 .21276 Mtetra
.50262 .21276 .50621 .21716 .51274 .21478 .50916 .21037 Mtetra
.50916 .21037 .51274 .21478 .51928 .21239 .51571 .20797 Mtetra
.51571 .20797 .51928 .21239 .52584 .21 .52228 .20556 Mtetra
.52228 .20556 .52584 .21 .53242 .2076 .52887 .20315 Mtetra
.52887 .20315 .53242 .2076 .53901 .20519 .53547 .20073 Mtetra
.53547 .20073 .53901 .20519 .54562 .20278 .54209 .19831 Mtetra
.54209 .19831 .54562 .20278 .55224 .20036 .54872 .19588 Mtetra
.54872 .19588 .55224 .20036 .55888 .19794 .55537 .19345 Mtetra
.55537 .19345 .55888 .19794 .56554 .19551 .56204 .19101 Mtetra
.56204 .19101 .56554 .19551 .57221 .19308 .56872 .18857 Mtetra
.56872 .18857 .57221 .19308 .57889 .19064 .57541 .18611 Mtetra
.57541 .18611 .57889 .19064 .5856 .18819 .58213 .18366 Mtetra
.58213 .18366 .5856 .18819 .59232 .18574 .58886 .18119 Mtetra
.58886 .18119 .59232 .18574 .59905 .18328 .5956 .17872 Mtetra
.5956 .17872 .59905 .18328 .6058 .18081 .60237 .17625 Mtetra
.60237 .17625 .6058 .18081 .61257 .17834 .60915 .17377 Mtetra
.60915 .17377 .61257 .17834 .61936 .17587 .61594 .17128 Mtetra
.61594 .17128 .61936 .17587 .62616 .17338 .62276 .16879 Mtetra
.62276 .16879 .62616 .17338 .63297 .1709 .62958 .16629 Mtetra
.62958 .16629 .63297 .1709 .63981 .1684 .63643 .16378 Mtetra
.63643 .16378 .63981 .1684 .64666 .1659 .64329 .16127 Mtetra
.64329 .16127 .64666 .1659 .65353 .16339 .65017 .15875 Mtetra
.65017 .15875 .65353 .16339 .66041 .16088 .65707 .15623 Mtetra
.65707 .15623 .66041 .16088 .66731 .15836 .66398 .1537 Mtetra
.66398 .1537 .66731 .15836 .67423 .15584 .67091 .15116 Mtetra
.67091 .15116 .67423 .15584 .68117 .15331 .67786 .14862 Mtetra
.67786 .14862 .68117 .15331 .68812 .15077 .68482 .14607 Mtetra
.68482 .14607 .68812 .15077 .69509 .14822 .6918 .14351 Mtetra
.6918 .14351 .69509 .14822 .70208 .14567 .6988 .14095 Mtetra
.6988 .14095 .70208 .14567 .70908 .14312 .70582 .13838 Mtetra
.70582 .13838 .70908 .14312 .7161 .14056 .71285 .13581 Mtetra
.71285 .13581 .7161 .14056 .72314 .13799 .7199 .13323 Mtetra
.7199 .13323 .72314 .13799 .7302 .13541 .72697 .13064 Mtetra
.72697 .13064 .7302 .13541 .73727 .13283 .73406 .12805 Mtetra
.73406 .12805 .73727 .13283 .74436 .13024 .74116 .12545 Mtetra
.74116 .12545 .74436 .13024 .75147 .12765 .74828 .12284 Mtetra
.74828 .12284 .75147 .12765 .7586 .12505 .75542 .12023 Mtetra
.75542 .12023 .7586 .12505 .76574 .12244 .76258 .11761 Mtetra
.12711 .34485 .13124 .3487 .13692 .34662 .1328 .34277 Mtetra
.1328 .34277 .13692 .34662 .14261 .34453 .1385 .34067 Mtetra
.1385 .34067 .14261 .34453 .14832 .34244 .14421 .33857 Mtetra
.14421 .33857 .14832 .34244 .15404 .34035 .14994 .33647 Mtetra
.14994 .33647 .15404 .34035 .15977 .33825 .15568 .33437 Mtetra
.15568 .33437 .15977 .33825 .16552 .33615 .16143 .33225 Mtetra
.16143 .33225 .16552 .33615 .17128 .33404 .1672 .33014 Mtetra
.1672 .33014 .17128 .33404 .17705 .33193 .17298 .32802 Mtetra
.17298 .32802 .17705 .33193 .18283 .32981 .17877 .32589 Mtetra
.17877 .32589 .18283 .32981 .18863 .32769 .18458 .32376 Mtetra
.18458 .32376 .18863 .32769 .19444 .32556 .19039 .32162 Mtetra
.19039 .32162 .19444 .32556 .20026 .32343 .19622 .31948 Mtetra
.19622 .31948 .20026 .32343 .2061 .32129 .20207 .31734 Mtetra
.20207 .31734 .2061 .32129 .21195 .31915 .20793 .31519 Mtetra
.20793 .31519 .21195 .31915 .21781 .31701 .2138 .31303 Mtetra
.2138 .31303 .21781 .31701 .22369 .31486 .21968 .31087 Mtetra
.21968 .31087 .22369 .31486 .22958 .3127 .22558 .30871 Mtetra
.22558 .30871 .22958 .3127 .23548 .31054 .23149 .30654 Mtetra
.23149 .30654 .23548 .31054 .2414 .30837 .23741 .30436 Mtetra
.23741 .30436 .2414 .30837 .24733 .3062 .24335 .30218 Mtetra
.24335 .30218 .24733 .3062 .25327 .30403 .2493 .3 Mtetra
.2493 .3 .25327 .30403 .25923 .30185 .25527 .29781 Mtetra
.25527 .29781 .25923 .30185 .2652 .29966 .26124 .29562 Mtetra
.26124 .29562 .2652 .29966 .27118 .29747 .26724 .29342 Mtetra
.26724 .29342 .27118 .29747 .27718 .29528 .27324 .29121 Mtetra
.27324 .29121 .27718 .29528 .28319 .29308 .27926 .289 Mtetra
.27926 .289 .28319 .29308 .28921 .29087 .28529 .28679 Mtetra
.28529 .28679 .28921 .29087 .29525 .28866 .29134 .28457 Mtetra
.29134 .28457 .29525 .28866 .30131 .28645 .2974 .28234 Mtetra
.2974 .28234 .30131 .28645 .30737 .28423 .30348 .28011 Mtetra
.30348 .28011 .30737 .28423 .31345 .282 .30957 .27788 Mtetra
.30957 .27788 .31345 .282 .31955 .27977 .31567 .27564 Mtetra
.31567 .27564 .31955 .27977 .32566 .27753 .32179 .27339 Mtetra
.32179 .27339 .32566 .27753 .33178 .27529 .32792 .27114 Mtetra
.32792 .27114 .33178 .27529 .33792 .27305 .33407 .26888 Mtetra
.33407 .26888 .33792 .27305 .34407 .27079 .34023 .26662 Mtetra
.34023 .26662 .34407 .27079 .35023 .26854 .3464 .26436 Mtetra
.3464 .26436 .35023 .26854 .35641 .26627 .35259 .26208 Mtetra
.35259 .26208 .35641 .26627 .36261 .26401 .35879 .25981 Mtetra
.35879 .25981 .36261 .26401 .36882 .26173 .36501 .25753 Mtetra
.36501 .25753 .36882 .26173 .37504 .25946 .37124 .25524 Mtetra
.37124 .25524 .37504 .25946 .38128 .25717 .37749 .25294 Mtetra
.37749 .25294 .38128 .25717 .38753 .25489 .38375 .25065 Mtetra
.38375 .25065 .38753 .25489 .3938 .25259 .39002 .24834 Mtetra
.39002 .24834 .3938 .25259 .40008 .25029 .39632 .24603 Mtetra
.39632 .24603 .40008 .25029 .40637 .24799 .40262 .24372 Mtetra
.663 .741 .908 r
.40262 .24372 .40637 .24799 .41269 .24568 .40894 .2414 Mtetra
.40894 .2414 .41269 .24568 .41901 .24337 .41528 .23908 Mtetra
.661 .74 .909 r
.41528 .23908 .41901 .24337 .42535 .24109 .42162 .23679 Mtetra
.664 .741 .908 r
.42162 .23679 .42535 .24109 .43171 .23876 .42799 .23445 Mtetra
.666 .742 .907 r
.42799 .23445 .43171 .23876 .43808 .23639 .43437 .23207 Mtetra
.664 .741 .908 r
.43437 .23207 .43808 .23639 .44446 .23405 .44077 .22972 Mtetra
.44077 .22972 .44446 .23405 .45086 .2317 .44718 .22736 Mtetra
.44718 .22736 .45086 .2317 .45728 .22936 .4536 .22501 Mtetra
.4536 .22501 .45728 .22936 .46371 .227 .46004 .22264 Mtetra
.46004 .22264 .46371 .227 .47016 .22464 .4665 .22027 Mtetra
.4665 .22027 .47016 .22464 .47662 .22228 .47297 .2179 Mtetra
.47297 .2179 .47662 .22228 .4831 .21991 .47946 .21551 Mtetra
.47946 .21551 .4831 .21991 .48959 .21753 .48596 .21313 Mtetra
.48596 .21313 .48959 .21753 .4961 .21515 .49248 .21073 Mtetra
.49248 .21073 .4961 .21515 .50262 .21276 .49901 .20834 Mtetra
.49901 .20834 .50262 .21276 .50916 .21037 .50556 .20593 Mtetra
.50556 .20593 .50916 .21037 .51571 .20797 .51212 .20352 Mtetra
.51212 .20352 .51571 .20797 .52228 .20556 .5187 .20111 Mtetra
.5187 .20111 .52228 .20556 .52887 .20315 .5253 .19869 Mtetra
.5253 .19869 .52887 .20315 .53547 .20073 .53191 .19626 Mtetra
.53191 .19626 .53547 .20073 .54209 .19831 .53854 .19383 Mtetra
.53854 .19383 .54209 .19831 .54872 .19588 .54518 .19139 Mtetra
.54518 .19139 .54872 .19588 .55537 .19345 .55184 .18894 Mtetra
.55184 .18894 .55537 .19345 .56204 .19101 .55852 .18649 Mtetra
.55852 .18649 .56204 .19101 .56872 .18857 .56521 .18403 Mtetra
.56521 .18403 .56872 .18857 .57541 .18611 .57192 .18157 Mtetra
.57192 .18157 .57541 .18611 .58213 .18366 .57864 .1791 Mtetra
.57864 .1791 .58213 .18366 .58886 .18119 .58539 .17663 Mtetra
.58539 .17663 .58886 .18119 .5956 .17872 .59214 .17415 Mtetra
.59214 .17415 .5956 .17872 .60237 .17625 .59892 .17166 Mtetra
.59892 .17166 .60237 .17625 .60915 .17377 .60571 .16917 Mtetra
.60571 .16917 .60915 .17377 .61594 .17128 .61251 .16667 Mtetra
.61251 .16667 .61594 .17128 .62276 .16879 .61934 .16417 Mtetra
.61934 .16417 .62276 .16879 .62958 .16629 .62618 .16166 Mtetra
.62618 .16166 .62958 .16629 .63643 .16378 .63303 .15914 Mtetra
.63303 .15914 .63643 .16378 .64329 .16127 .63991 .15661 Mtetra
.63991 .15661 .64329 .16127 .65017 .15875 .6468 .15409 Mtetra
.6468 .15409 .65017 .15875 .65707 .15623 .65371 .15155 Mtetra
.65371 .15155 .65707 .15623 .66398 .1537 .66063 .14901 Mtetra
.66063 .14901 .66398 .1537 .67091 .15116 .66757 .14646 Mtetra
.66757 .14646 .67091 .15116 .67786 .14862 .67453 .14391 Mtetra
.67453 .14391 .67786 .14862 .68482 .14607 .68151 .14134 Mtetra
.68151 .14134 .68482 .14607 .6918 .14351 .6885 .13878 Mtetra
.6885 .13878 .6918 .14351 .6988 .14095 .69551 .1362 Mtetra
.69551 .1362 .6988 .14095 .70582 .13838 .70254 .13362 Mtetra
.70254 .13362 .70582 .13838 .71285 .13581 .70958 .13104 Mtetra
.70958 .13104 .71285 .13581 .7199 .13323 .71665 .12845 Mtetra
.71665 .12845 .7199 .13323 .72697 .13064 .72373 .12585 Mtetra
.72373 .12585 .72697 .13064 .73406 .12805 .73083 .12324 Mtetra
.73083 .12324 .73406 .12805 .74116 .12545 .73794 .12063 Mtetra
.73794 .12063 .74116 .12545 .74828 .12284 .74507 .11801 Mtetra
.74507 .11801 .74828 .12284 .75542 .12023 .75223 .11539 Mtetra
.75223 .11539 .75542 .12023 .76258 .11761 .7594 .11275 Mtetra
.12297 .34099 .12711 .34485 .1328 .34277 .12866 .3389 Mtetra
.12866 .3389 .1328 .34277 .1385 .34067 .13437 .3368 Mtetra
.13437 .3368 .1385 .34067 .14421 .33857 .14009 .33469 Mtetra
.14009 .33469 .14421 .33857 .14994 .33647 .14583 .33258 Mtetra
.14583 .33258 .14994 .33647 .15568 .33437 .15157 .33046 Mtetra
.15157 .33046 .15568 .33437 .16143 .33225 .15733 .32834 Mtetra
.15733 .32834 .16143 .33225 .1672 .33014 .16311 .32622 Mtetra
.16311 .32622 .1672 .33014 .17298 .32802 .16889 .32409 Mtetra
.16889 .32409 .17298 .32802 .17877 .32589 .17469 .32195 Mtetra
.17469 .32195 .17877 .32589 .18458 .32376 .1805 .31981 Mtetra
.1805 .31981 .18458 .32376 .19039 .32162 .18633 .31767 Mtetra
.18633 .31767 .19039 .32162 .19622 .31948 .19217 .31552 Mtetra
.19217 .31552 .19622 .31948 .20207 .31734 .19802 .31336 Mtetra
.19802 .31336 .20207 .31734 .20793 .31519 .20388 .31121 Mtetra
.20388 .31121 .20793 .31519 .2138 .31303 .20976 .30904 Mtetra
.20976 .30904 .2138 .31303 .21968 .31087 .21565 .30687 Mtetra
.21565 .30687 .21968 .31087 .22558 .30871 .22156 .3047 Mtetra
.22156 .3047 .22558 .30871 .23149 .30654 .22748 .30252 Mtetra
.22748 .30252 .23149 .30654 .23741 .30436 .23341 .30034 Mtetra
.23341 .30034 .23741 .30436 .24335 .30218 .23936 .29815 Mtetra
.23936 .29815 .24335 .30218 .2493 .3 .24531 .29595 Mtetra
.24531 .29595 .2493 .3 .25527 .29781 .25129 .29375 Mtetra
.25129 .29375 .25527 .29781 .26124 .29562 .25727 .29155 Mtetra
.25727 .29155 .26124 .29562 .26724 .29342 .26327 .28934 Mtetra
.26327 .28934 .26724 .29342 .27324 .29121 .26929 .28713 Mtetra
.26929 .28713 .27324 .29121 .27926 .289 .27532 .28491 Mtetra
.27532 .28491 .27926 .289 .28529 .28679 .28136 .28268 Mtetra
.28136 .28268 .28529 .28679 .29134 .28457 .28741 .28046 Mtetra
.28741 .28046 .29134 .28457 .2974 .28234 .29348 .27822 Mtetra
.29348 .27822 .2974 .28234 .30348 .28011 .29957 .27598 Mtetra
.29957 .27598 .30348 .28011 .30957 .27788 .30566 .27374 Mtetra
.30566 .27374 .30957 .27788 .31567 .27564 .31178 .27149 Mtetra
.31178 .27149 .31567 .27564 .32179 .27339 .3179 .26923 Mtetra
.3179 .26923 .32179 .27339 .32792 .27114 .32404 .26697 Mtetra
.32404 .26697 .32792 .27114 .33407 .26888 .3302 .26471 Mtetra
.3302 .26471 .33407 .26888 .34023 .26662 .33636 .26243 Mtetra
.33636 .26243 .34023 .26662 .3464 .26436 .34255 .26016 Mtetra
.34255 .26016 .3464 .26436 .35259 .26208 .34875 .25788 Mtetra
.34875 .25788 .35259 .26208 .35879 .25981 .35496 .25559 Mtetra
.35496 .25559 .35879 .25981 .36501 .25753 .36118 .2533 Mtetra
.36118 .2533 .36501 .25753 .37124 .25524 .36742 .251 Mtetra
.36742 .251 .37124 .25524 .37749 .25294 .37368 .2487 Mtetra
.37368 .2487 .37749 .25294 .38375 .25065 .37995 .24639 Mtetra
.37995 .24639 .38375 .25065 .39002 .24834 .38624 .24408 Mtetra
.38624 .24408 .39002 .24834 .39632 .24603 .39254 .24176 Mtetra
.39254 .24176 .39632 .24603 .40262 .24372 .39885 .23943 Mtetra
.663 .741 .908 r
.39885 .23943 .40262 .24372 .40894 .2414 .40518 .2371 Mtetra
.40518 .2371 .40894 .2414 .41528 .23908 .41152 .23477 Mtetra
.661 .741 .909 r
.41152 .23477 .41528 .23908 .42162 .23679 .41788 .23247 Mtetra
.664 .741 .908 r
.41788 .23247 .42162 .23679 .42799 .23445 .42426 .23012 Mtetra
.666 .742 .907 r
.42426 .23012 .42799 .23445 .43437 .23207 .43065 .22773 Mtetra
.664 .741 .908 r
.43065 .22773 .43437 .23207 .44077 .22972 .43705 .22537 Mtetra
.43705 .22537 .44077 .22972 .44718 .22736 .44347 .22301 Mtetra
.44347 .22301 .44718 .22736 .4536 .22501 .44991 .22064 Mtetra
.44991 .22064 .4536 .22501 .46004 .22264 .45636 .21826 Mtetra
.45636 .21826 .46004 .22264 .4665 .22027 .46282 .21588 Mtetra
.46282 .21588 .4665 .22027 .47297 .2179 .4693 .21349 Mtetra
.4693 .21349 .47297 .2179 .47946 .21551 .4758 .2111 Mtetra
.4758 .2111 .47946 .21551 .48596 .21313 .48231 .20871 Mtetra
.48231 .20871 .48596 .21313 .49248 .21073 .48884 .2063 Mtetra
.48884 .2063 .49248 .21073 .49901 .20834 .49538 .20389 Mtetra
.49538 .20389 .49901 .20834 .50556 .20593 .50194 .20148 Mtetra
.50194 .20148 .50556 .20593 .51212 .20352 .50852 .19906 Mtetra
.50852 .19906 .51212 .20352 .5187 .20111 .51511 .19663 Mtetra
.51511 .19663 .5187 .20111 .5253 .19869 .52172 .1942 Mtetra
.52172 .1942 .5253 .19869 .53191 .19626 .52834 .19176 Mtetra
.52834 .19176 .53191 .19626 .53854 .19383 .53498 .18932 Mtetra
.53498 .18932 .53854 .19383 .54518 .19139 .54163 .18687 Mtetra
.54163 .18687 .54518 .19139 .55184 .18894 .5483 .18441 Mtetra
.5483 .18441 .55184 .18894 .55852 .18649 .55499 .18195 Mtetra
.55499 .18195 .55852 .18649 .56521 .18403 .56169 .17948 Mtetra
.56169 .17948 .56521 .18403 .57192 .18157 .56841 .17701 Mtetra
.56841 .17701 .57192 .18157 .57864 .1791 .57515 .17453 Mtetra
.57515 .17453 .57864 .1791 .58539 .17663 .5819 .17205 Mtetra
.5819 .17205 .58539 .17663 .59214 .17415 .58867 .16955 Mtetra
.58867 .16955 .59214 .17415 .59892 .17166 .59545 .16706 Mtetra
.59545 .16706 .59892 .17166 .60571 .16917 .60225 .16455 Mtetra
.60225 .16455 .60571 .16917 .61251 .16667 .60907 .16204 Mtetra
.60907 .16204 .61251 .16667 .61934 .16417 .6159 .15953 Mtetra
.6159 .15953 .61934 .16417 .62618 .16166 .62276 .157 Mtetra
.62276 .157 .62618 .16166 .63303 .15914 .62962 .15448 Mtetra
.62962 .15448 .63303 .15914 .63991 .15661 .63651 .15194 Mtetra
.63651 .15194 .63991 .15661 .6468 .15409 .64341 .1494 Mtetra
.64341 .1494 .6468 .15409 .65371 .15155 .65033 .14685 Mtetra
.65033 .14685 .65371 .15155 .66063 .14901 .65727 .1443 Mtetra
.65727 .1443 .66063 .14901 .66757 .14646 .66422 .14174 Mtetra
.66422 .14174 .66757 .14646 .67453 .14391 .67119 .13917 Mtetra
.67119 .13917 .67453 .14391 .68151 .14134 .67818 .1366 Mtetra
.67818 .1366 .68151 .14134 .6885 .13878 .68518 .13402 Mtetra
.68518 .13402 .6885 .13878 .69551 .1362 .69221 .13144 Mtetra
.69221 .13144 .69551 .1362 .70254 .13362 .69925 .12884 Mtetra
.69925 .12884 .70254 .13362 .70958 .13104 .7063 .12625 Mtetra
.7063 .12625 .70958 .13104 .71665 .12845 .71338 .12364 Mtetra
.71338 .12364 .71665 .12845 .72373 .12585 .72047 .12103 Mtetra
.72047 .12103 .72373 .12585 .73083 .12324 .72758 .11841 Mtetra
.72758 .11841 .73083 .12324 .73794 .12063 .73471 .11579 Mtetra
.73471 .11579 .73794 .12063 .74507 .11801 .74186 .11316 Mtetra
.74186 .11316 .74507 .11801 .75223 .11539 .74902 .11052 Mtetra
.74902 .11052 .75223 .11539 .7594 .11275 .7562 .10788 Mtetra
.1188 .33712 .12297 .34099 .12866 .3389 .12451 .33501 Mtetra
.12451 .33501 .12866 .3389 .13437 .3368 .13022 .3329 Mtetra
.13022 .3329 .13437 .3368 .14009 .33469 .13595 .33079 Mtetra
.13595 .33079 .14009 .33469 .14583 .33258 .14169 .32867 Mtetra
.14169 .32867 .14583 .33258 .15157 .33046 .14745 .32654 Mtetra
.14745 .32654 .15157 .33046 .15733 .32834 .15322 .32442 Mtetra
.15322 .32442 .15733 .32834 .16311 .32622 .159 .32228 Mtetra
.159 .32228 .16311 .32622 .16889 .32409 .16479 .32014 Mtetra
.16479 .32014 .16889 .32409 .17469 .32195 .1706 .318 Mtetra
.1706 .318 .17469 .32195 .1805 .31981 .17642 .31585 Mtetra
.17642 .31585 .1805 .31981 .18633 .31767 .18225 .3137 Mtetra
.18225 .3137 .18633 .31767 .19217 .31552 .18809 .31154 Mtetra
.18809 .31154 .19217 .31552 .19802 .31336 .19395 .30937 Mtetra
.19395 .30937 .19802 .31336 .20388 .31121 .19983 .30721 Mtetra
.19983 .30721 .20388 .31121 .20976 .30904 .20571 .30503 Mtetra
.20571 .30503 .20976 .30904 .21565 .30687 .21161 .30286 Mtetra
.21161 .30286 .21565 .30687 .22156 .3047 .21752 .30067 Mtetra
.21752 .30067 .22156 .3047 .22748 .30252 .22345 .29848 Mtetra
.22345 .29848 .22748 .30252 .23341 .30034 .22939 .29629 Mtetra
.22939 .29629 .23341 .30034 .23936 .29815 .23534 .29409 Mtetra
.23534 .29409 .23936 .29815 .24531 .29595 .24131 .29189 Mtetra
.24131 .29189 .24531 .29595 .25129 .29375 .24729 .28968 Mtetra
.24729 .28968 .25129 .29375 .25727 .29155 .25329 .28747 Mtetra
.25329 .28747 .25727 .29155 .26327 .28934 .2593 .28525 Mtetra
.2593 .28525 .26327 .28934 .26929 .28713 .26532 .28303 Mtetra
.26532 .28303 .26929 .28713 .27532 .28491 .27135 .2808 Mtetra
.27135 .2808 .27532 .28491 .28136 .28268 .2774 .27857 Mtetra
.2774 .27857 .28136 .28268 .28741 .28046 .28347 .27633 Mtetra
.28347 .27633 .28741 .28046 .29348 .27822 .28955 .27408 Mtetra
.28955 .27408 .29348 .27822 .29957 .27598 .29564 .27183 Mtetra
.29564 .27183 .29957 .27598 .30566 .27374 .30174 .26958 Mtetra
.30174 .26958 .30566 .27374 .31178 .27149 .30786 .26732 Mtetra
.30786 .26732 .31178 .27149 .3179 .26923 .314 .26505 Mtetra
.314 .26505 .3179 .26923 .32404 .26697 .32015 .26278 Mtetra
.32015 .26278 .32404 .26697 .3302 .26471 .32631 .26051 Mtetra
.32631 .26051 .3302 .26471 .33636 .26243 .33249 .25823 Mtetra
.33249 .25823 .33636 .26243 .34255 .26016 .33868 .25594 Mtetra
.33868 .25594 .34255 .26016 .34875 .25788 .34489 .25365 Mtetra
.34489 .25365 .34875 .25788 .35496 .25559 .35111 .25135 Mtetra
.35111 .25135 .35496 .25559 .36118 .2533 .35734 .24905 Mtetra
.35734 .24905 .36118 .2533 .36742 .251 .36359 .24674 Mtetra
.36359 .24674 .36742 .251 .37368 .2487 .36986 .24443 Mtetra
.36986 .24443 .37368 .2487 .37995 .24639 .37614 .24211 Mtetra
.37614 .24211 .37995 .24639 .38624 .24408 .38243 .23979 Mtetra
.38243 .23979 .38624 .24408 .39254 .24176 .38874 .23746 Mtetra
.38874 .23746 .39254 .24176 .39885 .23943 .39506 .23513 Mtetra
.663 .741 .908 r
.39506 .23513 .39885 .23943 .40518 .2371 .4014 .23279 Mtetra
.4014 .23279 .40518 .2371 .41152 .23477 .40776 .23044 Mtetra
.661 .741 .909 r
.40776 .23044 .41152 .23477 .41788 .23247 .41412 .22813 Mtetra
.664 .741 .908 r
.41412 .22813 .41788 .23247 .42426 .23012 .42051 .22577 Mtetra
.666 .742 .907 r
.42051 .22577 .42426 .23012 .43065 .22773 .42691 .22337 Mtetra
.664 .741 .908 r
.42691 .22337 .43065 .22773 .43705 .22537 .43332 .221 Mtetra
.43332 .221 .43705 .22537 .44347 .22301 .43975 .21863 Mtetra
.43975 .21863 .44347 .22301 .44991 .22064 .4462 .21625 Mtetra
.4462 .21625 .44991 .22064 .45636 .21826 .45266 .21386 Mtetra
.45266 .21386 .45636 .21826 .46282 .21588 .45913 .21147 Mtetra
.45913 .21147 .46282 .21588 .4693 .21349 .46562 .20907 Mtetra
.46562 .20907 .4693 .21349 .4758 .2111 .47213 .20667 Mtetra
.47213 .20667 .4758 .2111 .48231 .20871 .47865 .20426 Mtetra
.47865 .20426 .48231 .20871 .48884 .2063 .48519 .20185 Mtetra
.48519 .20185 .48884 .2063 .49538 .20389 .49174 .19943 Mtetra
.49174 .19943 .49538 .20389 .50194 .20148 .49831 .19701 Mtetra
.49831 .19701 .50194 .20148 .50852 .19906 .5049 .19457 Mtetra
.5049 .19457 .50852 .19906 .51511 .19663 .5115 .19214 Mtetra
.5115 .19214 .51511 .19663 .52172 .1942 .51812 .18969 Mtetra
.51812 .18969 .52172 .1942 .52834 .19176 .52475 .18725 Mtetra
.52475 .18725 .52834 .19176 .53498 .18932 .5314 .18479 Mtetra
.5314 .18479 .53498 .18932 .54163 .18687 .53806 .18233 Mtetra
.53806 .18233 .54163 .18687 .5483 .18441 .54474 .17986 Mtetra
.54474 .17986 .5483 .18441 .55499 .18195 .55144 .17739 Mtetra
.55144 .17739 .55499 .18195 .56169 .17948 .55815 .17491 Mtetra
.55815 .17491 .56169 .17948 .56841 .17701 .56488 .17243 Mtetra
.56488 .17243 .56841 .17701 .57515 .17453 .57163 .16994 Mtetra
.57163 .16994 .57515 .17453 .5819 .17205 .57839 .16744 Mtetra
.57839 .16744 .5819 .17205 .58867 .16955 .58517 .16494 Mtetra
.58517 .16494 .58867 .16955 .59545 .16706 .59197 .16243 Mtetra
.59197 .16243 .59545 .16706 .60225 .16455 .59878 .15991 Mtetra
.59878 .15991 .60225 .16455 .60907 .16204 .60561 .15739 Mtetra
.60561 .15739 .60907 .16204 .6159 .15953 .61246 .15486 Mtetra
.61246 .15486 .6159 .15953 .62276 .157 .61932 .15233 Mtetra
.61932 .15233 .62276 .157 .62962 .15448 .6262 .14979 Mtetra
.6262 .14979 .62962 .15448 .63651 .15194 .6331 .14724 Mtetra
.6331 .14724 .63651 .15194 .64341 .1494 .64001 .14469 Mtetra
.64001 .14469 .64341 .1494 .65033 .14685 .64694 .14213 Mtetra
.64694 .14213 .65033 .14685 .65727 .1443 .65389 .13957 Mtetra
.65389 .13957 .65727 .1443 .66422 .14174 .66085 .137 Mtetra
.66085 .137 .66422 .14174 .67119 .13917 .66783 .13442 Mtetra
.66783 .13442 .67119 .13917 .67818 .1366 .67483 .13183 Mtetra
.67483 .13183 .67818 .1366 .68518 .13402 .68185 .12924 Mtetra
.68185 .12924 .68518 .13402 .69221 .13144 .68889 .12665 Mtetra
.68889 .12665 .69221 .13144 .69925 .12884 .69594 .12404 Mtetra
.69594 .12404 .69925 .12884 .7063 .12625 .70301 .12143 Mtetra
.70301 .12143 .7063 .12625 .71338 .12364 .71009 .11882 Mtetra
.71009 .11882 .71338 .12364 .72047 .12103 .7172 .11619 Mtetra
.7172 .11619 .72047 .12103 .72758 .11841 .72432 .11356 Mtetra
.72432 .11356 .72758 .11841 .73471 .11579 .73146 .11093 Mtetra
.73146 .11093 .73471 .11579 .74186 .11316 .73862 .10828 Mtetra
.73862 .10828 .74186 .11316 .74902 .11052 .7458 .10564 Mtetra
.7458 .10564 .74902 .11052 .7562 .10788 .75299 .10298 Mtetra
.11463 .33323 .1188 .33712 .12451 .33501 .12034 .33111 Mtetra
.12034 .33111 .12451 .33501 .13022 .3329 .12606 .329 Mtetra
.12606 .329 .13022 .3329 .13595 .33079 .13179 .32687 Mtetra
.13179 .32687 .13595 .33079 .14169 .32867 .13754 .32474 Mtetra
.13754 .32474 .14169 .32867 .14745 .32654 .1433 .32261 Mtetra
.1433 .32261 .14745 .32654 .15322 .32442 .14908 .32047 Mtetra
.14908 .32047 .15322 .32442 .159 .32228 .15487 .31833 Mtetra
.15487 .31833 .159 .32228 .16479 .32014 .16067 .31618 Mtetra
.16067 .31618 .16479 .32014 .1706 .318 .16648 .31403 Mtetra
.16648 .31403 .1706 .318 .17642 .31585 .17231 .31187 Mtetra
.17231 .31187 .17642 .31585 .18225 .3137 .17815 .30971 Mtetra
.17815 .30971 .18225 .3137 .18809 .31154 .184 .30754 Mtetra
.184 .30754 .18809 .31154 .19395 .30937 .18987 .30537 Mtetra
.18987 .30537 .19395 .30937 .19983 .30721 .19575 .30319 Mtetra
.19575 .30319 .19983 .30721 .20571 .30503 .20164 .30101 Mtetra
.20164 .30101 .20571 .30503 .21161 .30286 .20755 .29882 Mtetra
.20755 .29882 .21161 .30286 .21752 .30067 .21347 .29663 Mtetra
.21347 .29663 .21752 .30067 .22345 .29848 .21941 .29443 Mtetra
.21941 .29443 .22345 .29848 .22939 .29629 .22535 .29223 Mtetra
.22535 .29223 .22939 .29629 .23534 .29409 .23132 .29002 Mtetra
.23132 .29002 .23534 .29409 .24131 .29189 .23729 .28781 Mtetra
.23729 .28781 .24131 .29189 .24729 .28968 .24328 .28559 Mtetra
.24328 .28559 .24729 .28968 .25329 .28747 .24928 .28337 Mtetra
.24928 .28337 .25329 .28747 .2593 .28525 .2553 .28114 Mtetra
.2553 .28114 .2593 .28525 .26532 .28303 .26133 .27891 Mtetra
.26133 .27891 .26532 .28303 .27135 .2808 .26737 .27667 Mtetra
.26737 .27667 .27135 .2808 .2774 .27857 .27343 .27443 Mtetra
.27343 .27443 .2774 .27857 .28347 .27633 .27951 .27218 Mtetra
.27951 .27218 .28347 .27633 .28955 .27408 .28559 .26993 Mtetra
.28559 .26993 .28955 .27408 .29564 .27183 .29169 .26767 Mtetra
.29169 .26767 .29564 .27183 .30174 .26958 .29781 .2654 Mtetra
.29781 .2654 .30174 .26958 .30786 .26732 .30394 .26313 Mtetra
.30394 .26313 .30786 .26732 .314 .26505 .31008 .26086 Mtetra
.31008 .26086 .314 .26505 .32015 .26278 .31624 .25858 Mtetra
.31624 .25858 .32015 .26278 .32631 .26051 .32241 .25629 Mtetra
.32241 .25629 .32631 .26051 .33249 .25823 .32859 .254 Mtetra
.32859 .254 .33249 .25823 .33868 .25594 .33479 .25171 Mtetra
.33479 .25171 .33868 .25594 .34489 .25365 .34101 .24941 Mtetra
.34101 .24941 .34489 .25365 .35111 .25135 .34724 .2471 Mtetra
.34724 .2471 .35111 .25135 .35734 .24905 .35348 .24479 Mtetra
.35348 .24479 .35734 .24905 .36359 .24674 .35974 .24247 Mtetra
.35974 .24247 .36359 .24674 .36986 .24443 .36602 .24015 Mtetra
.36602 .24015 .36986 .24443 .37614 .24211 .37231 .23782 Mtetra
.37231 .23782 .37614 .24211 .38243 .23979 .37861 .23549 Mtetra
.37861 .23549 .38243 .23979 .38874 .23746 .38493 .23315 Mtetra
.38493 .23315 .38874 .23746 .39506 .23513 .39126 .2308 Mtetra
.39126 .2308 .39506 .23513 .4014 .23279 .39761 .22845 Mtetra
.663 .741 .908 r
.39761 .22845 .4014 .23279 .40776 .23044 .40397 .2261 Mtetra
.661 .741 .909 r
.40397 .2261 .40776 .23044 .41412 .22813 .41035 .22377 Mtetra
.664 .741 .908 r
.41035 .22377 .41412 .22813 .42051 .22577 .41674 .2214 Mtetra
.666 .742 .907 r
.41674 .2214 .42051 .22577 .42691 .22337 .42315 .219 Mtetra
.664 .741 .908 r
.42315 .219 .42691 .22337 .43332 .221 .42958 .21662 Mtetra
.42958 .21662 .43332 .221 .43975 .21863 .43602 .21423 Mtetra
.43602 .21423 .43975 .21863 .4462 .21625 .44247 .21184 Mtetra
.44247 .21184 .4462 .21625 .45266 .21386 .44894 .20944 Mtetra
.44894 .20944 .45266 .21386 .45913 .21147 .45543 .20704 Mtetra
.45543 .20704 .45913 .21147 .46562 .20907 .46193 .20464 Mtetra
.46193 .20464 .46562 .20907 .47213 .20667 .46844 .20222 Mtetra
.46844 .20222 .47213 .20667 .47865 .20426 .47497 .1998 Mtetra
.47497 .1998 .47865 .20426 .48519 .20185 .48152 .19738 Mtetra
.48152 .19738 .48519 .20185 .49174 .19943 .48809 .19495 Mtetra
.48809 .19495 .49174 .19943 .49831 .19701 .49467 .19251 Mtetra
.49467 .19251 .49831 .19701 .5049 .19457 .50126 .19007 Mtetra
.50126 .19007 .5049 .19457 .5115 .19214 .50787 .18762 Mtetra
.50787 .18762 .5115 .19214 .51812 .18969 .5145 .18517 Mtetra
.5145 .18517 .51812 .18969 .52475 .18725 .52114 .18271 Mtetra
.52114 .18271 .52475 .18725 .5314 .18479 .5278 .18024 Mtetra
.5278 .18024 .5314 .18479 .53806 .18233 .53448 .17777 Mtetra
.53448 .17777 .53806 .18233 .54474 .17986 .54117 .17529 Mtetra
.54117 .17529 .54474 .17986 .55144 .17739 .54788 .17281 Mtetra
.54788 .17281 .55144 .17739 .55815 .17491 .5546 .17032 Mtetra
.5546 .17032 .55815 .17491 .56488 .17243 .56134 .16782 Mtetra
.56134 .16782 .56488 .17243 .57163 .16994 .5681 .16532 Mtetra
.5681 .16532 .57163 .16994 .57839 .16744 .57487 .16281 Mtetra
.57487 .16281 .57839 .16744 .58517 .16494 .58166 .1603 Mtetra
.58166 .1603 .58517 .16494 .59197 .16243 .58847 .15778 Mtetra
.58847 .15778 .59197 .16243 .59878 .15991 .59529 .15525 Mtetra
.59529 .15525 .59878 .15991 .60561 .15739 .60213 .15272 Mtetra
.60213 .15272 .60561 .15739 .61246 .15486 .60899 .15018 Mtetra
.60899 .15018 .61246 .15486 .61932 .15233 .61587 .14764 Mtetra
.61587 .14764 .61932 .15233 .6262 .14979 .62276 .14509 Mtetra
.62276 .14509 .6262 .14979 .6331 .14724 .62967 .14253 Mtetra
.62967 .14253 .6331 .14724 .64001 .14469 .63659 .13996 Mtetra
.63659 .13996 .64001 .14469 .64694 .14213 .64353 .13739 Mtetra
.64353 .13739 .64694 .14213 .65389 .13957 .65049 .13482 Mtetra
.65049 .13482 .65389 .13957 .66085 .137 .65747 .13223 Mtetra
.65747 .13223 .66085 .137 .66783 .13442 .66446 .12964 Mtetra
.66446 .12964 .66783 .13442 .67483 .13183 .67147 .12705 Mtetra
.67147 .12705 .67483 .13183 .68185 .12924 .6785 .12444 Mtetra
.6785 .12444 .68185 .12924 .68889 .12665 .68555 .12184 Mtetra
.68555 .12184 .68889 .12665 .69594 .12404 .69261 .11922 Mtetra
.69261 .11922 .69594 .12404 .70301 .12143 .6997 .1166 Mtetra
.6997 .1166 .70301 .12143 .71009 .11882 .70679 .11397 Mtetra
.70679 .11397 .71009 .11882 .7172 .11619 .71391 .11133 Mtetra
.71391 .11133 .7172 .11619 .72432 .11356 .72105 .10869 Mtetra
.72105 .10869 .72432 .11356 .73146 .11093 .7282 .10604 Mtetra
.7282 .10604 .73146 .11093 .73862 .10828 .73537 .10339 Mtetra
.73537 .10339 .73862 .10828 .7458 .10564 .74256 .10073 Mtetra
.74256 .10073 .7458 .10564 .75299 .10298 .74977 .09806 Mtetra
.11043 .32932 .11463 .33323 .12034 .33111 .11615 .3272 Mtetra
.11615 .3272 .12034 .33111 .12606 .329 .12188 .32507 Mtetra
.12188 .32507 .12606 .329 .13179 .32687 .12762 .32294 Mtetra
.12762 .32294 .13179 .32687 .13754 .32474 .13338 .3208 Mtetra
.13338 .3208 .13754 .32474 .1433 .32261 .13914 .31866 Mtetra
.13914 .31866 .1433 .32261 .14908 .32047 .14493 .31651 Mtetra
.14493 .31651 .14908 .32047 .15487 .31833 .15072 .31436 Mtetra
.15072 .31436 .15487 .31833 .16067 .31618 .15653 .3122 Mtetra
.15653 .3122 .16067 .31618 .16648 .31403 .16235 .31004 Mtetra
.16235 .31004 .16648 .31403 .17231 .31187 .16819 .30787 Mtetra
.16819 .30787 .17231 .31187 .17815 .30971 .17403 .3057 Mtetra
.17403 .3057 .17815 .30971 .184 .30754 .1799 .30353 Mtetra
.1799 .30353 .184 .30754 .18987 .30537 .18577 .30134 Mtetra
.18577 .30134 .18987 .30537 .19575 .30319 .19166 .29916 Mtetra
.19166 .29916 .19575 .30319 .20164 .30101 .19756 .29697 Mtetra
.19756 .29697 .20164 .30101 .20755 .29882 .20348 .29477 Mtetra
.20348 .29477 .20755 .29882 .21347 .29663 .2094 .29257 Mtetra
.2094 .29257 .21347 .29663 .21941 .29443 .21535 .29036 Mtetra
.21535 .29036 .21941 .29443 .22535 .29223 .2213 .28815 Mtetra
.2213 .28815 .22535 .29223 .23132 .29002 .22727 .28593 Mtetra
.22727 .28593 .23132 .29002 .23729 .28781 .23325 .28371 Mtetra
.23325 .28371 .23729 .28781 .24328 .28559 .23925 .28149 Mtetra
.23925 .28149 .24328 .28559 .24928 .28337 .24526 .27925 Mtetra
.24526 .27925 .24928 .28337 .2553 .28114 .25129 .27702 Mtetra
.25129 .27702 .2553 .28114 .26133 .27891 .25733 .27477 Mtetra
.25733 .27477 .26133 .27891 .26737 .27667 .26338 .27253 Mtetra
.26338 .27253 .26737 .27667 .27343 .27443 .26944 .27027 Mtetra
.26944 .27027 .27343 .27443 .27951 .27218 .27553 .26802 Mtetra
.27553 .26802 .27951 .27218 .28559 .26993 .28162 .26575 Mtetra
.28162 .26575 .28559 .26993 .29169 .26767 .28773 .26348 Mtetra
.28773 .26348 .29169 .26767 .29781 .2654 .29385 .26121 Mtetra
.29385 .26121 .29781 .2654 .30394 .26313 .29999 .25893 Mtetra
.29999 .25893 .30394 .26313 .31008 .26086 .30614 .25665 Mtetra
.30614 .25665 .31008 .26086 .31624 .25858 .31231 .25436 Mtetra
.31231 .25436 .31624 .25858 .32241 .25629 .31849 .25206 Mtetra
.31849 .25206 .32241 .25629 .32859 .254 .32468 .24976 Mtetra
.32468 .24976 .32859 .254 .33479 .25171 .33089 .24746 Mtetra
.33089 .24746 .33479 .25171 .34101 .24941 .33712 .24514 Mtetra
.33712 .24514 .34101 .24941 .34724 .2471 .34336 .24283 Mtetra
.34336 .24283 .34724 .2471 .35348 .24479 .34961 .24051 Mtetra
.34961 .24051 .35348 .24479 .35974 .24247 .35588 .23818 Mtetra
.35588 .23818 .35974 .24247 .36602 .24015 .36216 .23584 Mtetra
.36216 .23584 .36602 .24015 .37231 .23782 .36846 .23351 Mtetra
.36846 .23351 .37231 .23782 .37861 .23549 .37477 .23116 Mtetra
.37477 .23116 .37861 .23549 .38493 .23315 .3811 .22881 Mtetra
.3811 .22881 .38493 .23315 .39126 .2308 .38744 .22646 Mtetra
.38744 .22646 .39126 .2308 .39761 .22845 .3938 .2241 Mtetra
.663 .741 .908 r
.3938 .2241 .39761 .22845 .40397 .2261 .40017 .22173 Mtetra
.662 .741 .909 r
.40017 .22173 .40397 .2261 .41035 .22377 .40656 .21939 Mtetra
.664 .741 .908 r
.40656 .21939 .41035 .22377 .41674 .2214 .41296 .21702 Mtetra
.665 .742 .907 r
.41296 .21702 .41674 .2214 .42315 .219 .41938 .2146 Mtetra
.664 .741 .908 r
.41938 .2146 .42315 .219 .42958 .21662 .42581 .21221 Mtetra
.42581 .21221 .42958 .21662 .43602 .21423 .43226 .20981 Mtetra
.43226 .20981 .43602 .21423 .44247 .21184 .43873 .20741 Mtetra
.43873 .20741 .44247 .21184 .44894 .20944 .44521 .20501 Mtetra
.44521 .20501 .44894 .20944 .45543 .20704 .4517 .20259 Mtetra
.4517 .20259 .45543 .20704 .46193 .20464 .45821 .20018 Mtetra
.45821 .20018 .46193 .20464 .46844 .20222 .46474 .19775 Mtetra
.46474 .19775 .46844 .20222 .47497 .1998 .47128 .19532 Mtetra
.47128 .19532 .47497 .1998 .48152 .19738 .47784 .19289 Mtetra
.47784 .19289 .48152 .19738 .48809 .19495 .48441 .19045 Mtetra
.48441 .19045 .48809 .19495 .49467 .19251 .491 .188 Mtetra
.491 .188 .49467 .19251 .50126 .19007 .49761 .18555 Mtetra
.49761 .18555 .50126 .19007 .50787 .18762 .50423 .18309 Mtetra
.50423 .18309 .50787 .18762 .5145 .18517 .51087 .18062 Mtetra
.51087 .18062 .5145 .18517 .52114 .18271 .51752 .17815 Mtetra
.51752 .17815 .52114 .18271 .5278 .18024 .52419 .17568 Mtetra
.52419 .17568 .5278 .18024 .53448 .17777 .53088 .17319 Mtetra
.53088 .17319 .53448 .17777 .54117 .17529 .53758 .1707 Mtetra
.53758 .1707 .54117 .17529 .54788 .17281 .5443 .16821 Mtetra
.5443 .16821 .54788 .17281 .5546 .17032 .55103 .16571 Mtetra
.55103 .16571 .5546 .17032 .56134 .16782 .55779 .1632 Mtetra
.55779 .1632 .56134 .16782 .5681 .16532 .56455 .16069 Mtetra
.56455 .16069 .5681 .16532 .57487 .16281 .57134 .15817 Mtetra
.57134 .15817 .57487 .16281 .58166 .1603 .57814 .15564 Mtetra
.57814 .15564 .58166 .1603 .58847 .15778 .58496 .15311 Mtetra
.58496 .15311 .58847 .15778 .59529 .15525 .59179 .15057 Mtetra
.59179 .15057 .59529 .15525 .60213 .15272 .59864 .14803 Mtetra
.59864 .14803 .60213 .15272 .60899 .15018 .60551 .14548 Mtetra
.60551 .14548 .60899 .15018 .61587 .14764 .6124 .14292 Mtetra
.6124 .14292 .61587 .14764 .62276 .14509 .6193 .14036 Mtetra
.6193 .14036 .62276 .14509 .62967 .14253 .62622 .13779 Mtetra
.62622 .13779 .62967 .14253 .63659 .13996 .63316 .13521 Mtetra
.63316 .13521 .63659 .13996 .64353 .13739 .64011 .13263 Mtetra
.64011 .13263 .64353 .13739 .65049 .13482 .64708 .13004 Mtetra
.64708 .13004 .65049 .13482 .65747 .13223 .65407 .12745 Mtetra
.65407 .12745 .65747 .13223 .66446 .12964 .66108 .12485 Mtetra
.66108 .12485 .66446 .12964 .67147 .12705 .6681 .12224 Mtetra
.6681 .12224 .67147 .12705 .6785 .12444 .67514 .11962 Mtetra
.67514 .11962 .6785 .12444 .68555 .12184 .6822 .117 Mtetra
.6822 .117 .68555 .12184 .69261 .11922 .68927 .11437 Mtetra
.68927 .11437 .69261 .11922 .6997 .1166 .69637 .11174 Mtetra
.69637 .11174 .6997 .1166 .70679 .11397 .70348 .1091 Mtetra
.70348 .1091 .70679 .11397 .71391 .11133 .71061 .10645 Mtetra
.71061 .10645 .71391 .11133 .72105 .10869 .71776 .1038 Mtetra
.71776 .1038 .72105 .10869 .7282 .10604 .72492 .10114 Mtetra
.72492 .10114 .7282 .10604 .73537 .10339 .73211 .09847 Mtetra
.73211 .09847 .73537 .10339 .74256 .10073 .73931 .09579 Mtetra
.73931 .09579 .74256 .10073 .74977 .09806 .74653 .09311 Mtetra
.10622 .3254 .11043 .32932 .11615 .3272 .11194 .32327 Mtetra
.11194 .32327 .11615 .3272 .12188 .32507 .11768 .32113 Mtetra
.11768 .32113 .12188 .32507 .12762 .32294 .12343 .31899 Mtetra
.12343 .31899 .12762 .32294 .13338 .3208 .12919 .31684 Mtetra
.12919 .31684 .13338 .3208 .13914 .31866 .13497 .31469 Mtetra
.13497 .31469 .13914 .31866 .14493 .31651 .14076 .31253 Mtetra
.14076 .31253 .14493 .31651 .15072 .31436 .14656 .31037 Mtetra
.14656 .31037 .15072 .31436 .15653 .3122 .15238 .30821 Mtetra
.15238 .30821 .15653 .3122 .16235 .31004 .1582 .30604 Mtetra
.1582 .30604 .16235 .31004 .16819 .30787 .16405 .30386 Mtetra
.16405 .30386 .16819 .30787 .17403 .3057 .1699 .30168 Mtetra
.1699 .30168 .17403 .3057 .1799 .30353 .17577 .29949 Mtetra
.17577 .29949 .1799 .30353 .18577 .30134 .18165 .2973 Mtetra
.18165 .2973 .18577 .30134 .19166 .29916 .18755 .29511 Mtetra
.18755 .29511 .19166 .29916 .19756 .29697 .19346 .29291 Mtetra
.19346 .29291 .19756 .29697 .20348 .29477 .19938 .2907 Mtetra
.19938 .2907 .20348 .29477 .2094 .29257 .20532 .28849 Mtetra
.20532 .28849 .2094 .29257 .21535 .29036 .21127 .28628 Mtetra
.21127 .28628 .21535 .29036 .2213 .28815 .21723 .28405 Mtetra
.21723 .28405 .2213 .28815 .22727 .28593 .22321 .28183 Mtetra
.22321 .28183 .22727 .28593 .23325 .28371 .2292 .2796 Mtetra
.2292 .2796 .23325 .28371 .23925 .28149 .23521 .27736 Mtetra
.23521 .27736 .23925 .28149 .24526 .27925 .24122 .27512 Mtetra
.24122 .27512 .24526 .27925 .25129 .27702 .24726 .27287 Mtetra
.24726 .27287 .25129 .27702 .25733 .27477 .2533 .27062 Mtetra
.2533 .27062 .25733 .27477 .26338 .27253 .25937 .26836 Mtetra
.25937 .26836 .26338 .27253 .26944 .27027 .26544 .2661 Mtetra
.26544 .2661 .26944 .27027 .27553 .26802 .27153 .26383 Mtetra
.27153 .26383 .27553 .26802 .28162 .26575 .27763 .26156 Mtetra
.27763 .26156 .28162 .26575 .28773 .26348 .28375 .25928 Mtetra
.28375 .25928 .28773 .26348 .29385 .26121 .28988 .257 Mtetra
.28988 .257 .29385 .26121 .29999 .25893 .29603 .25471 Mtetra
.29603 .25471 .29999 .25893 .30614 .25665 .30219 .25241 Mtetra
.30219 .25241 .30614 .25665 .31231 .25436 .30836 .25012 Mtetra
.30836 .25012 .31231 .25436 .31849 .25206 .31455 .24781 Mtetra
.31455 .24781 .31849 .25206 .32468 .24976 .32076 .2455 Mtetra
.32076 .2455 .32468 .24976 .33089 .24746 .32697 .24318 Mtetra
.32697 .24318 .33089 .24746 .33712 .24514 .33321 .24086 Mtetra
.33321 .24086 .33712 .24514 .34336 .24283 .33945 .23854 Mtetra
.33945 .23854 .34336 .24283 .34961 .24051 .34572 .2362 Mtetra
.34572 .2362 .34961 .24051 .35588 .23818 .35199 .23387 Mtetra
.35199 .23387 .35588 .23818 .36216 .23584 .35829 .23152 Mtetra
.35829 .23152 .36216 .23584 .36846 .23351 .36459 .22917 Mtetra
.36459 .22917 .36846 .23351 .37477 .23116 .37092 .22682 Mtetra
.37092 .22682 .37477 .23116 .3811 .22881 .37725 .22446 Mtetra
.37725 .22446 .3811 .22881 .38744 .22646 .3836 .22209 Mtetra
.3836 .22209 .38744 .22646 .3938 .2241 .38997 .21972 Mtetra
.663 .741 .908 r
.38997 .21972 .3938 .2241 .40017 .22173 .39635 .21735 Mtetra
.662 .741 .909 r
.39635 .21735 .40017 .22173 .40656 .21939 .40275 .215 Mtetra
.664 .741 .908 r
.40275 .215 .40656 .21939 .41296 .21702 .40916 .21261 Mtetra
.665 .742 .907 r
.40916 .21261 .41296 .21702 .41938 .2146 .41559 .21019 Mtetra
.664 .741 .908 r
.41559 .21019 .41938 .2146 .42581 .21221 .42203 .20778 Mtetra
.42203 .20778 .42581 .21221 .43226 .20981 .42849 .20538 Mtetra
.42849 .20538 .43226 .20981 .43873 .20741 .43497 .20297 Mtetra
.43497 .20297 .43873 .20741 .44521 .20501 .44146 .20055 Mtetra
.44146 .20055 .44521 .20501 .4517 .20259 .44796 .19813 Mtetra
.44796 .19813 .4517 .20259 .45821 .20018 .45448 .1957 Mtetra
.45448 .1957 .45821 .20018 .46474 .19775 .46102 .19326 Mtetra
.46102 .19326 .46474 .19775 .47128 .19532 .46757 .19082 Mtetra
.46757 .19082 .47128 .19532 .47784 .19289 .47414 .18838 Mtetra
.47414 .18838 .47784 .19289 .48441 .19045 .48072 .18592 Mtetra
.48072 .18592 .48441 .19045 .491 .188 .48732 .18347 Mtetra
.48732 .18347 .491 .188 .49761 .18555 .49394 .181 Mtetra
.49394 .181 .49761 .18555 .50423 .18309 .50057 .17853 Mtetra
.50057 .17853 .50423 .18309 .51087 .18062 .50722 .17606 Mtetra
.50722 .17606 .51087 .18062 .51752 .17815 .51388 .17358 Mtetra
.51388 .17358 .51752 .17815 .52419 .17568 .52056 .17109 Mtetra
.52056 .17109 .52419 .17568 .53088 .17319 .52726 .16859 Mtetra
.52726 .16859 .53088 .17319 .53758 .1707 .53397 .16609 Mtetra
.53397 .16609 .53758 .1707 .5443 .16821 .5407 .16359 Mtetra
.5407 .16359 .5443 .16821 .55103 .16571 .54745 .16107 Mtetra
.54745 .16107 .55103 .16571 .55779 .1632 .55421 .15856 Mtetra
.55421 .15856 .55779 .1632 .56455 .16069 .56099 .15603 Mtetra
.56099 .15603 .56455 .16069 .57134 .15817 .56779 .1535 Mtetra
.56779 .1535 .57134 .15817 .57814 .15564 .5746 .15096 Mtetra
.5746 .15096 .57814 .15564 .58496 .15311 .58143 .14842 Mtetra
.58143 .14842 .58496 .15311 .59179 .15057 .58827 .14587 Mtetra
.58827 .14587 .59179 .15057 .59864 .14803 .59514 .14332 Mtetra
.59514 .14332 .59864 .14803 .60551 .14548 .60202 .14075 Mtetra
.60202 .14075 .60551 .14548 .6124 .14292 .60891 .13818 Mtetra
.60891 .13818 .6124 .14292 .6193 .14036 .61583 .13561 Mtetra
.61583 .13561 .6193 .14036 .62622 .13779 .62276 .13303 Mtetra
.62276 .13303 .62622 .13779 .63316 .13521 .62971 .13044 Mtetra
.62971 .13044 .63316 .13521 .64011 .13263 .63667 .12785 Mtetra
.63667 .12785 .64011 .13263 .64708 .13004 .64366 .12525 Mtetra
.64366 .12525 .64708 .13004 .65407 .12745 .65066 .12264 Mtetra
.65066 .12264 .65407 .12745 .66108 .12485 .65767 .12003 Mtetra
.65767 .12003 .66108 .12485 .6681 .12224 .66471 .11741 Mtetra
.66471 .11741 .6681 .12224 .67514 .11962 .67176 .11478 Mtetra
.67176 .11478 .67514 .11962 .6822 .117 .67883 .11215 Mtetra
.67883 .11215 .6822 .117 .68927 .11437 .68592 .10951 Mtetra
.68592 .10951 .68927 .11437 .69637 .11174 .69303 .10686 Mtetra
.69303 .10686 .69637 .11174 .70348 .1091 .70015 .10421 Mtetra
.70015 .10421 .70348 .1091 .71061 .10645 .70729 .10155 Mtetra
.70729 .10155 .71061 .10645 .71776 .1038 .71445 .09888 Mtetra
.71445 .09888 .71776 .1038 .72492 .10114 .72163 .09621 Mtetra
.72163 .09621 .72492 .10114 .73211 .09847 .72883 .09353 Mtetra
.72883 .09353 .73211 .09847 .73931 .09579 .73604 .09084 Mtetra
.73604 .09084 .73931 .09579 .74653 .09311 .74327 .08815 Mtetra
.10198 .32146 .10622 .3254 .11194 .32327 .10772 .31932 Mtetra
.10772 .31932 .11194 .32327 .11768 .32113 .11346 .31717 Mtetra
.11346 .31717 .11768 .32113 .12343 .31899 .11922 .31502 Mtetra
.11922 .31502 .12343 .31899 .12919 .31684 .12499 .31287 Mtetra
.12499 .31287 .12919 .31684 .13497 .31469 .13077 .31071 Mtetra
.13077 .31071 .13497 .31469 .14076 .31253 .13657 .30854 Mtetra
.13657 .30854 .14076 .31253 .14656 .31037 .14238 .30637 Mtetra
.14238 .30637 .14656 .31037 .15238 .30821 .1482 .3042 Mtetra
.1482 .3042 .15238 .30821 .1582 .30604 .15404 .30202 Mtetra
.15404 .30202 .1582 .30604 .16405 .30386 .15989 .29983 Mtetra
.15989 .29983 .16405 .30386 .1699 .30168 .16575 .29764 Mtetra
.16575 .29764 .1699 .30168 .17577 .29949 .17163 .29545 Mtetra
.17163 .29545 .17577 .29949 .18165 .2973 .17752 .29325 Mtetra
.17752 .29325 .18165 .2973 .18755 .29511 .18342 .29104 Mtetra
.18342 .29104 .18755 .29511 .19346 .29291 .18934 .28883 Mtetra
.18934 .28883 .19346 .29291 .19938 .2907 .19527 .28662 Mtetra
.19527 .28662 .19938 .2907 .20532 .28849 .20121 .2844 Mtetra
.20121 .2844 .20532 .28849 .21127 .28628 .20717 .28217 Mtetra
.20717 .28217 .21127 .28628 .21723 .28405 .21314 .27994 Mtetra
.21314 .27994 .21723 .28405 .22321 .28183 .21913 .2777 Mtetra
.21913 .2777 .22321 .28183 .2292 .2796 .22513 .27546 Mtetra
.22513 .27546 .2292 .2796 .23521 .27736 .23114 .27322 Mtetra
.23114 .27322 .23521 .27736 .24122 .27512 .23717 .27097 Mtetra
.23717 .27097 .24122 .27512 .24726 .27287 .24321 .26871 Mtetra
.24321 .26871 .24726 .27287 .2533 .27062 .24927 .26645 Mtetra
.24927 .26645 .2533 .27062 .25937 .26836 .25533 .26418 Mtetra
.25533 .26418 .25937 .26836 .26544 .2661 .26142 .26191 Mtetra
.26142 .26191 .26544 .2661 .27153 .26383 .26752 .25963 Mtetra
.26752 .25963 .27153 .26383 .27763 .26156 .27363 .25735 Mtetra
.27363 .25735 .27763 .26156 .28375 .25928 .27975 .25506 Mtetra
.27975 .25506 .28375 .25928 .28988 .257 .28589 .25277 Mtetra
.28589 .25277 .28988 .257 .29603 .25471 .29205 .25047 Mtetra
.29205 .25047 .29603 .25471 .30219 .25241 .29822 .24817 Mtetra
.29822 .24817 .30219 .25241 .30836 .25012 .3044 .24586 Mtetra
.3044 .24586 .30836 .25012 .31455 .24781 .3106 .24354 Mtetra
.3106 .24354 .31455 .24781 .32076 .2455 .31681 .24122 Mtetra
.31681 .24122 .32076 .2455 .32697 .24318 .32304 .23889 Mtetra
.32304 .23889 .32697 .24318 .33321 .24086 .32928 .23656 Mtetra
.32928 .23656 .33321 .24086 .33945 .23854 .33554 .23423 Mtetra
.33554 .23423 .33945 .23854 .34572 .2362 .34181 .23188 Mtetra
.34181 .23188 .34572 .2362 .35199 .23387 .34809 .22954 Mtetra
.34809 .22954 .35199 .23387 .35829 .23152 .3544 .22718 Mtetra
.3544 .22718 .35829 .23152 .36459 .22917 .36071 .22482 Mtetra
.36071 .22482 .36459 .22917 .37092 .22682 .36704 .22246 Mtetra
.36704 .22246 .37092 .22682 .37725 .22446 .37339 .22009 Mtetra
.37339 .22009 .37725 .22446 .3836 .22209 .37975 .21771 Mtetra
.37975 .21771 .3836 .22209 .38997 .21972 .38613 .21533 Mtetra
.663 .741 .908 r
.38613 .21533 .38997 .21972 .39635 .21735 .39252 .21295 Mtetra
.662 .741 .909 r
.39252 .21295 .39635 .21735 .40275 .215 .39892 .21058 Mtetra
.664 .741 .908 r
.39892 .21058 .40275 .215 .40916 .21261 .40535 .20818 Mtetra
.665 .742 .907 r
.40535 .20818 .40916 .21261 .41559 .21019 .41178 .20575 Mtetra
.664 .741 .908 r
.41178 .20575 .41559 .21019 .42203 .20778 .41824 .20334 Mtetra
.41824 .20334 .42203 .20778 .42849 .20538 .42471 .20092 Mtetra
.42471 .20092 .42849 .20538 .43497 .20297 .43119 .1985 Mtetra
.43119 .1985 .43497 .20297 .44146 .20055 .43769 .19607 Mtetra
.43769 .19607 .44146 .20055 .44796 .19813 .4442 .19364 Mtetra
.4442 .19364 .44796 .19813 .45448 .1957 .45074 .1912 Mtetra
.45074 .1912 .45448 .1957 .46102 .19326 .45728 .18875 Mtetra
.45728 .18875 .46102 .19326 .46757 .19082 .46384 .1863 Mtetra
.46384 .1863 .46757 .19082 .47414 .18838 .47042 .18385 Mtetra
.47042 .18385 .47414 .18838 .48072 .18592 .47702 .18138 Mtetra
.47702 .18138 .48072 .18592 .48732 .18347 .48363 .17891 Mtetra
.48363 .17891 .48732 .18347 .49394 .181 .49025 .17644 Mtetra
.49025 .17644 .49394 .181 .50057 .17853 .4969 .17396 Mtetra
.4969 .17396 .50057 .17853 .50722 .17606 .50355 .17147 Mtetra
.50355 .17147 .50722 .17606 .51388 .17358 .51023 .16898 Mtetra
.51023 .16898 .51388 .17358 .52056 .17109 .51692 .16648 Mtetra
.51692 .16648 .52056 .17109 .52726 .16859 .52363 .16397 Mtetra
.52363 .16397 .52726 .16859 .53397 .16609 .53035 .16146 Mtetra
.53035 .16146 .53397 .16609 .5407 .16359 .53709 .15894 Mtetra
.53709 .15894 .5407 .16359 .54745 .16107 .54385 .15642 Mtetra
.54385 .15642 .54745 .16107 .55421 .15856 .55062 .15389 Mtetra
.55062 .15389 .55421 .15856 .56099 .15603 .55741 .15135 Mtetra
.55741 .15135 .56099 .15603 .56779 .1535 .56422 .14881 Mtetra
.56422 .14881 .56779 .1535 .5746 .15096 .57104 .14626 Mtetra
.57104 .14626 .5746 .15096 .58143 .14842 .57788 .14371 Mtetra
.57788 .14371 .58143 .14842 .58827 .14587 .58474 .14115 Mtetra
.58474 .14115 .58827 .14587 .59514 .14332 .59161 .13858 Mtetra
.59161 .13858 .59514 .14332 .60202 .14075 .5985 .13601 Mtetra
.5985 .13601 .60202 .14075 .60891 .13818 .60541 .13343 Mtetra
.60541 .13343 .60891 .13818 .61583 .13561 .61234 .13084 Mtetra
.61234 .13084 .61583 .13561 .62276 .13303 .61928 .12825 Mtetra
.61928 .12825 .62276 .13303 .62971 .13044 .62624 .12565 Mtetra
.62624 .12565 .62971 .13044 .63667 .12785 .63322 .12304 Mtetra
.63322 .12304 .63667 .12785 .64366 .12525 .64021 .12043 Mtetra
.64021 .12043 .64366 .12525 .65066 .12264 .64723 .11781 Mtetra
.64723 .11781 .65066 .12264 .65767 .12003 .65425 .11518 Mtetra
.65425 .11518 .65767 .12003 .66471 .11741 .6613 .11255 Mtetra
.6613 .11255 .66471 .11741 .67176 .11478 .66837 .10991 Mtetra
.66837 .10991 .67176 .11478 .67883 .11215 .67545 .10727 Mtetra
.67545 .10727 .67883 .11215 .68592 .10951 .68255 .10461 Mtetra
.68255 .10461 .68592 .10951 .69303 .10686 .68967 .10196 Mtetra
.68967 .10196 .69303 .10686 .70015 .10421 .6968 .09929 Mtetra
.6968 .09929 .70015 .10421 .70729 .10155 .70396 .09662 Mtetra
.70396 .09662 .70729 .10155 .71445 .09888 .71113 .09394 Mtetra
.71113 .09394 .71445 .09888 .72163 .09621 .71832 .09125 Mtetra
.71832 .09125 .72163 .09621 .72883 .09353 .72553 .08856 Mtetra
.72553 .08856 .72883 .09353 .73604 .09084 .73276 .08586 Mtetra
.73276 .08586 .73604 .09084 .74327 .08815 .74 .08316 Mtetra
.09774 .3175 .10198 .32146 .10772 .31932 .10347 .31535 Mtetra
.10347 .31535 .10772 .31932 .11346 .31717 .10923 .3132 Mtetra
.10923 .3132 .11346 .31717 .11922 .31502 .11499 .31104 Mtetra
.11499 .31104 .11922 .31502 .12499 .31287 .12077 .30887 Mtetra
.12077 .30887 .12499 .31287 .13077 .31071 .12656 .30671 Mtetra
.12656 .30671 .13077 .31071 .13657 .30854 .13236 .30453 Mtetra
.13236 .30453 .13657 .30854 .14238 .30637 .13818 .30235 Mtetra
.13818 .30235 .14238 .30637 .1482 .3042 .14401 .30017 Mtetra
.14401 .30017 .1482 .3042 .15404 .30202 .14986 .29798 Mtetra
.14986 .29798 .15404 .30202 .15989 .29983 .15571 .29578 Mtetra
.15571 .29578 .15989 .29983 .16575 .29764 .16158 .29359 Mtetra
.16158 .29359 .16575 .29764 .17163 .29545 .16747 .29138 Mtetra
.16747 .29138 .17163 .29545 .17752 .29325 .17337 .28917 Mtetra
.17337 .28917 .17752 .29325 .18342 .29104 .17928 .28696 Mtetra
.17928 .28696 .18342 .29104 .18934 .28883 .1852 .28474 Mtetra
.1852 .28474 .18934 .28883 .19527 .28662 .19114 .28251 Mtetra
.19114 .28251 .19527 .28662 .20121 .2844 .19709 .28028 Mtetra
.19709 .28028 .20121 .2844 .20717 .28217 .20306 .27805 Mtetra
.20306 .27805 .20717 .28217 .21314 .27994 .20904 .27581 Mtetra
.20904 .27581 .21314 .27994 .21913 .2777 .21503 .27356 Mtetra
.21503 .27356 .21913 .2777 .22513 .27546 .22104 .27131 Mtetra
.22104 .27131 .22513 .27546 .23114 .27322 .22706 .26906 Mtetra
.22706 .26906 .23114 .27322 .23717 .27097 .2331 .2668 Mtetra
.2331 .2668 .23717 .27097 .24321 .26871 .23915 .26453 Mtetra
.23915 .26453 .24321 .26871 .24927 .26645 .24521 .26226 Mtetra
.24521 .26226 .24927 .26645 .25533 .26418 .25129 .25998 Mtetra
.25129 .25998 .25533 .26418 .26142 .26191 .25738 .2577 Mtetra
.25738 .2577 .26142 .26191 .26752 .25963 .26348 .25541 Mtetra
.26348 .25541 .26752 .25963 .27363 .25735 .2696 .25312 Mtetra
.2696 .25312 .27363 .25735 .27975 .25506 .27574 .25082 Mtetra
.27574 .25082 .27975 .25506 .28589 .25277 .28189 .24852 Mtetra
.28189 .24852 .28589 .25277 .29205 .25047 .28805 .24621 Mtetra
.28805 .24621 .29205 .25047 .29822 .24817 .29423 .2439 Mtetra
.29423 .2439 .29822 .24817 .3044 .24586 .30042 .24158 Mtetra
.30042 .24158 .3044 .24586 .3106 .24354 .30663 .23925 Mtetra
.30663 .23925 .3106 .24354 .31681 .24122 .31285 .23692 Mtetra
.31285 .23692 .31681 .24122 .32304 .23889 .31909 .23459 Mtetra
.31909 .23459 .32304 .23889 .32928 .23656 .32534 .23224 Mtetra
.32534 .23224 .32928 .23656 .33554 .23423 .3316 .2299 Mtetra
.3316 .2299 .33554 .23423 .34181 .23188 .33788 .22754 Mtetra
.33788 .22754 .34181 .23188 .34809 .22954 .34418 .22519 Mtetra
.34418 .22519 .34809 .22954 .3544 .22718 .35049 .22282 Mtetra
.35049 .22282 .3544 .22718 .36071 .22482 .35681 .22045 Mtetra
.35681 .22045 .36071 .22482 .36704 .22246 .36315 .21808 Mtetra
.36315 .21808 .36704 .22246 .37339 .22009 .36951 .2157 Mtetra
.36951 .2157 .37339 .22009 .37975 .21771 .37588 .21331 Mtetra
.37588 .21331 .37975 .21771 .38613 .21533 .38227 .21092 Mtetra
.663 .741 .908 r
.38227 .21092 .38613 .21533 .39252 .21295 .38867 .20852 Mtetra
.662 .741 .909 r
.38867 .20852 .39252 .21295 .39892 .21058 .39508 .20615 Mtetra
.664 .741 .908 r
.39508 .20615 .39892 .21058 .40535 .20818 .40151 .20374 Mtetra
.665 .742 .907 r
.40151 .20374 .40535 .20818 .41178 .20575 .40796 .2013 Mtetra
.664 .741 .908 r
.40796 .2013 .41178 .20575 .41824 .20334 .41442 .19887 Mtetra
.41442 .19887 .41824 .20334 .42471 .20092 .4209 .19645 Mtetra
.4209 .19645 .42471 .20092 .43119 .1985 .4274 .19401 Mtetra
.4274 .19401 .43119 .1985 .43769 .19607 .43391 .19157 Mtetra
.43391 .19157 .43769 .19607 .4442 .19364 .44043 .18913 Mtetra
.44043 .18913 .4442 .19364 .45074 .1912 .44697 .18668 Mtetra
.44697 .18668 .45074 .1912 .45728 .18875 .45353 .18422 Mtetra
.45353 .18422 .45728 .18875 .46384 .1863 .4601 .18176 Mtetra
.4601 .18176 .46384 .1863 .47042 .18385 .46669 .17929 Mtetra
.46669 .17929 .47042 .18385 .47702 .18138 .47329 .17682 Mtetra
.47329 .17682 .47702 .18138 .48363 .17891 .47991 .17434 Mtetra
.47991 .17434 .48363 .17891 .49025 .17644 .48655 .17185 Mtetra
.48655 .17185 .49025 .17644 .4969 .17396 .4932 .16936 Mtetra
.4932 .16936 .4969 .17396 .50355 .17147 .49987 .16686 Mtetra
.49987 .16686 .50355 .17147 .51023 .16898 .50656 .16436 Mtetra
.50656 .16436 .51023 .16898 .51692 .16648 .51326 .16185 Mtetra
.51326 .16185 .51692 .16648 .52363 .16397 .51998 .15933 Mtetra
.51998 .15933 .52363 .16397 .53035 .16146 .52671 .15681 Mtetra
.52671 .15681 .53035 .16146 .53709 .15894 .53346 .15428 Mtetra
.53346 .15428 .53709 .15894 .54385 .15642 .54023 .15175 Mtetra
.54023 .15175 .54385 .15642 .55062 .15389 .54702 .1492 Mtetra
.54702 .1492 .55062 .15389 .55741 .15135 .55382 .14666 Mtetra
.55382 .14666 .55741 .15135 .56422 .14881 .56063 .1441 Mtetra
.56063 .1441 .56422 .14881 .57104 .14626 .56747 .14154 Mtetra
.56747 .14154 .57104 .14626 .57788 .14371 .57432 .13898 Mtetra
.57432 .13898 .57788 .14371 .58474 .14115 .58119 .1364 Mtetra
.58119 .1364 .58474 .14115 .59161 .13858 .58807 .13382 Mtetra
.58807 .13382 .59161 .13858 .5985 .13601 .59498 .13124 Mtetra
.59498 .13124 .5985 .13601 .60541 .13343 .6019 .12865 Mtetra
.6019 .12865 .60541 .13343 .61234 .13084 .60883 .12605 Mtetra
.60883 .12605 .61234 .13084 .61928 .12825 .61579 .12344 Mtetra
.61579 .12344 .61928 .12825 .62624 .12565 .62276 .12083 Mtetra
.62276 .12083 .62624 .12565 .63322 .12304 .62975 .11821 Mtetra
.62975 .11821 .63322 .12304 .64021 .12043 .63676 .11559 Mtetra
.63676 .11559 .64021 .12043 .64723 .11781 .64378 .11296 Mtetra
.64378 .11296 .64723 .11781 .65425 .11518 .65082 .11032 Mtetra
.65082 .11032 .65425 .11518 .6613 .11255 .65788 .10767 Mtetra
.65788 .10767 .6613 .11255 .66837 .10991 .66496 .10502 Mtetra
.66496 .10502 .66837 .10991 .67545 .10727 .67205 .10237 Mtetra
.67205 .10237 .67545 .10727 .68255 .10461 .67916 .0997 Mtetra
.67916 .0997 .68255 .10461 .68967 .10196 .6863 .09703 Mtetra
.6863 .09703 .68967 .10196 .6968 .09929 .69344 .09435 Mtetra
.69344 .09435 .6968 .09929 .70396 .09662 .70061 .09167 Mtetra
.70061 .09167 .70396 .09662 .71113 .09394 .7078 .08898 Mtetra
.7078 .08898 .71113 .09394 .71832 .09125 .715 .08628 Mtetra
.715 .08628 .71832 .09125 .72553 .08856 .72222 .08357 Mtetra
.72222 .08357 .72553 .08856 .73276 .08586 .72946 .08086 Mtetra
.72946 .08086 .73276 .08586 .74 .08316 .73672 .07814 Mtetra
.09347 .31353 .09774 .3175 .10347 .31535 .09922 .31137 Mtetra
.09922 .31137 .10347 .31535 .10923 .3132 .10497 .30921 Mtetra
.10497 .30921 .10923 .3132 .11499 .31104 .11075 .30704 Mtetra
.11075 .30704 .11499 .31104 .12077 .30887 .11653 .30487 Mtetra
.11653 .30487 .12077 .30887 .12656 .30671 .12233 .30269 Mtetra
.12233 .30269 .12656 .30671 .13236 .30453 .12814 .3005 Mtetra
.12814 .3005 .13236 .30453 .13818 .30235 .13397 .29832 Mtetra
.13397 .29832 .13818 .30235 .14401 .30017 .1398 .29612 Mtetra
.1398 .29612 .14401 .30017 .14986 .29798 .14566 .29392 Mtetra
.14566 .29392 .14986 .29798 .15571 .29578 .15152 .29172 Mtetra
.15152 .29172 .15571 .29578 .16158 .29359 .1574 .28951 Mtetra
.1574 .28951 .16158 .29359 .16747 .29138 .16329 .2873 Mtetra
.16329 .2873 .16747 .29138 .17337 .28917 .1692 .28508 Mtetra
.1692 .28508 .17337 .28917 .17928 .28696 .17512 .28286 Mtetra
.17512 .28286 .17928 .28696 .1852 .28474 .18105 .28063 Mtetra
.18105 .28063 .1852 .28474 .19114 .28251 .187 .27839 Mtetra
.187 .27839 .19114 .28251 .19709 .28028 .19296 .27615 Mtetra
.19296 .27615 .19709 .28028 .20306 .27805 .19893 .27391 Mtetra
.19893 .27391 .20306 .27805 .20904 .27581 .20492 .27166 Mtetra
.20492 .27166 .20904 .27581 .21503 .27356 .21092 .26941 Mtetra
.21092 .26941 .21503 .27356 .22104 .27131 .21693 .26715 Mtetra
.21693 .26715 .22104 .27131 .22706 .26906 .22296 .26488 Mtetra
.22296 .26488 .22706 .26906 .2331 .2668 .22901 .26261 Mtetra
.22901 .26261 .2331 .2668 .23915 .26453 .23506 .26033 Mtetra
.23506 .26033 .23915 .26453 .24521 .26226 .24114 .25805 Mtetra
.24114 .25805 .24521 .26226 .25129 .25998 .24722 .25577 Mtetra
.24722 .25577 .25129 .25998 .25738 .2577 .25332 .25347 Mtetra
.25332 .25347 .25738 .2577 .26348 .25541 .25944 .25118 Mtetra
.25944 .25118 .26348 .25541 .2696 .25312 .26556 .24887 Mtetra
.26556 .24887 .2696 .25312 .27574 .25082 .27171 .24657 Mtetra
.27171 .24657 .27574 .25082 .28189 .24852 .27787 .24425 Mtetra
.27787 .24425 .28189 .24852 .28805 .24621 .28404 .24193 Mtetra
.28404 .24193 .28805 .24621 .29423 .2439 .29022 .23961 Mtetra
.29022 .23961 .29423 .2439 .30042 .24158 .29642 .23728 Mtetra
.29642 .23728 .30042 .24158 .30663 .23925 .30264 .23495 Mtetra
.30264 .23495 .30663 .23925 .31285 .23692 .30887 .2326 Mtetra
.30887 .2326 .31285 .23692 .31909 .23459 .31512 .23026 Mtetra
.31512 .23026 .31909 .23459 .32534 .23224 .32138 .22791 Mtetra
.32138 .22791 .32534 .23224 .3316 .2299 .32765 .22555 Mtetra
.32765 .22555 .3316 .2299 .33788 .22754 .33394 .22319 Mtetra
.33394 .22319 .33788 .22754 .34418 .22519 .34024 .22082 Mtetra
.34024 .22082 .34418 .22519 .35049 .22282 .34656 .21844 Mtetra
.34656 .21844 .35049 .22282 .35681 .22045 .3529 .21606 Mtetra
.3529 .21606 .35681 .22045 .36315 .21808 .35925 .21368 Mtetra
.35925 .21368 .36315 .21808 .36951 .2157 .36561 .21129 Mtetra
.36561 .21129 .36951 .2157 .37588 .21331 .37199 .20889 Mtetra
.37199 .20889 .37588 .21331 .38227 .21092 .37839 .20649 Mtetra
.663 .741 .908 r
.37839 .20649 .38227 .21092 .38867 .20852 .3848 .20408 Mtetra
.662 .741 .908 r
.3848 .20408 .38867 .20852 .39508 .20615 .39122 .20169 Mtetra
.664 .741 .908 r
.39122 .20169 .39508 .20615 .40151 .20374 .39766 .19927 Mtetra
.665 .742 .907 r
.39766 .19927 .40151 .20374 .40796 .2013 .40412 .19682 Mtetra
.664 .741 .908 r
.40412 .19682 .40796 .2013 .41442 .19887 .41059 .19439 Mtetra
.41059 .19439 .41442 .19887 .4209 .19645 .41708 .19195 Mtetra
.41708 .19195 .4209 .19645 .4274 .19401 .42359 .18951 Mtetra
.42359 .18951 .4274 .19401 .43391 .19157 .43011 .18706 Mtetra
.43011 .18706 .43391 .19157 .44043 .18913 .43664 .1846 Mtetra
.43664 .1846 .44043 .18913 .44697 .18668 .44319 .18214 Mtetra
.44319 .18214 .44697 .18668 .45353 .18422 .44976 .17967 Mtetra
.44976 .17967 .45353 .18422 .4601 .18176 .45634 .1772 Mtetra
.45634 .1772 .4601 .18176 .46669 .17929 .46294 .17472 Mtetra
.46294 .17472 .46669 .17929 .47329 .17682 .46955 .17224 Mtetra
.46955 .17224 .47329 .17682 .47991 .17434 .47618 .16975 Mtetra
.47618 .16975 .47991 .17434 .48655 .17185 .48283 .16725 Mtetra
.48283 .16725 .48655 .17185 .4932 .16936 .4895 .16474 Mtetra
.4895 .16474 .4932 .16936 .49987 .16686 .49617 .16224 Mtetra
.49617 .16224 .49987 .16686 .50656 .16436 .50287 .15972 Mtetra
.50287 .15972 .50656 .16436 .51326 .16185 .50958 .1572 Mtetra
.50958 .1572 .51326 .16185 .51998 .15933 .51631 .15467 Mtetra
.51631 .15467 .51998 .15933 .52671 .15681 .52306 .15214 Mtetra
.52306 .15214 .52671 .15681 .53346 .15428 .52982 .1496 Mtetra
.52982 .1496 .53346 .15428 .54023 .15175 .5366 .14705 Mtetra
.5366 .14705 .54023 .15175 .54702 .1492 .54339 .1445 Mtetra
.54339 .1445 .54702 .1492 .55382 .14666 .5502 .14194 Mtetra
.5502 .14194 .55382 .14666 .56063 .1441 .55703 .13937 Mtetra
.55703 .13937 .56063 .1441 .56747 .14154 .56388 .1368 Mtetra
.56388 .1368 .56747 .14154 .57432 .13898 .57074 .13422 Mtetra
.57074 .13422 .57432 .13898 .58119 .1364 .57762 .13164 Mtetra
.57762 .13164 .58119 .1364 .58807 .13382 .58452 .12904 Mtetra
.58452 .12904 .58807 .13382 .59498 .13124 .59143 .12645 Mtetra
.59143 .12645 .59498 .13124 .6019 .12865 .59836 .12384 Mtetra
.59836 .12384 .6019 .12865 .60883 .12605 .60531 .12123 Mtetra
.60531 .12123 .60883 .12605 .61579 .12344 .61228 .11862 Mtetra
.61228 .11862 .61579 .12344 .62276 .12083 .61926 .11599 Mtetra
.61926 .11599 .62276 .12083 .62975 .11821 .62626 .11336 Mtetra
.62626 .11336 .62975 .11821 .63676 .11559 .63328 .11072 Mtetra
.63328 .11072 .63676 .11559 .64378 .11296 .64032 .10808 Mtetra
.64032 .10808 .64378 .11296 .65082 .11032 .64737 .10543 Mtetra
.64737 .10543 .65082 .11032 .65788 .10767 .65444 .10277 Mtetra
.65444 .10277 .65788 .10767 .66496 .10502 .66153 .10011 Mtetra
.66153 .10011 .66496 .10502 .67205 .10237 .66864 .09744 Mtetra
.66864 .09744 .67205 .10237 .67916 .0997 .67576 .09476 Mtetra
.67576 .09476 .67916 .0997 .6863 .09703 .68291 .09208 Mtetra
.68291 .09208 .6863 .09703 .69344 .09435 .69007 .08939 Mtetra
.69007 .08939 .69344 .09435 .70061 .09167 .69725 .08669 Mtetra
.69725 .08669 .70061 .09167 .7078 .08898 .70444 .08399 Mtetra
.70444 .08399 .7078 .08898 .715 .08628 .71166 .08128 Mtetra
.71166 .08128 .715 .08628 .72222 .08357 .71889 .07856 Mtetra
.71889 .07856 .72222 .08357 .72946 .08086 .72615 .07584 Mtetra
.72615 .07584 .72946 .08086 .73672 .07814 .73342 .0731 Mtetra
.08919 .30954 .09347 .31353 .09922 .31137 .09494 .30737 Mtetra
.09494 .30737 .09922 .31137 .10497 .30921 .1007 .3052 Mtetra
.1007 .3052 .10497 .30921 .11075 .30704 .10648 .30302 Mtetra
.10648 .30302 .11075 .30704 .11653 .30487 .11228 .30084 Mtetra
.11228 .30084 .11653 .30487 .12233 .30269 .11808 .29865 Mtetra
.11808 .29865 .12233 .30269 .12814 .3005 .1239 .29646 Mtetra
.1239 .29646 .12814 .3005 .13397 .29832 .12973 .29426 Mtetra
.12973 .29426 .13397 .29832 .1398 .29612 .13558 .29206 Mtetra
.13558 .29206 .1398 .29612 .14566 .29392 .14144 .28985 Mtetra
.14144 .28985 .14566 .29392 .15152 .29172 .14731 .28764 Mtetra
.14731 .28764 .15152 .29172 .1574 .28951 .1532 .28542 Mtetra
.1532 .28542 .1574 .28951 .16329 .2873 .1591 .2832 Mtetra
.1591 .2832 .16329 .2873 .1692 .28508 .16501 .28097 Mtetra
.16501 .28097 .1692 .28508 .17512 .28286 .17094 .27874 Mtetra
.17094 .27874 .17512 .28286 .18105 .28063 .17688 .2765 Mtetra
.17688 .2765 .18105 .28063 .187 .27839 .18283 .27426 Mtetra
.18283 .27426 .187 .27839 .19296 .27615 .1888 .27201 Mtetra
.1888 .27201 .19296 .27615 .19893 .27391 .19478 .26975 Mtetra
.19478 .26975 .19893 .27391 .20492 .27166 .20078 .26749 Mtetra
.20078 .26749 .20492 .27166 .21092 .26941 .20679 .26523 Mtetra
.20679 .26523 .21092 .26941 .21693 .26715 .21281 .26296 Mtetra
.21281 .26296 .21693 .26715 .22296 .26488 .21885 .26068 Mtetra
.21885 .26068 .22296 .26488 .22901 .26261 .2249 .2584 Mtetra
.2249 .2584 .22901 .26261 .23506 .26033 .23097 .25612 Mtetra
.23097 .25612 .23506 .26033 .24114 .25805 .23705 .25383 Mtetra
.23705 .25383 .24114 .25805 .24722 .25577 .24314 .25153 Mtetra
.24314 .25153 .24722 .25577 .25332 .25347 .24925 .24923 Mtetra
.24925 .24923 .25332 .25347 .25944 .25118 .25537 .24692 Mtetra
.25537 .24692 .25944 .25118 .26556 .24887 .26151 .24461 Mtetra
.26151 .24461 .26556 .24887 .27171 .24657 .26766 .24229 Mtetra
.26766 .24229 .27171 .24657 .27787 .24425 .27383 .23997 Mtetra
.27383 .23997 .27787 .24425 .28404 .24193 .28001 .23764 Mtetra
.28001 .23764 .28404 .24193 .29022 .23961 .2862 .23531 Mtetra
.2862 .23531 .29022 .23961 .29642 .23728 .29241 .23297 Mtetra
.29241 .23297 .29642 .23728 .30264 .23495 .29864 .23062 Mtetra
.29864 .23062 .30264 .23495 .30887 .2326 .30487 .22827 Mtetra
.30487 .22827 .30887 .2326 .31512 .23026 .31113 .22591 Mtetra
.31113 .22591 .31512 .23026 .32138 .22791 .3174 .22355 Mtetra
.3174 .22355 .32138 .22791 .32765 .22555 .32368 .22118 Mtetra
.32368 .22118 .32765 .22555 .33394 .22319 .32998 .21881 Mtetra
.32998 .21881 .33394 .22319 .34024 .22082 .33629 .21643 Mtetra
.33629 .21643 .34024 .22082 .34656 .21844 .34262 .21405 Mtetra
.34262 .21405 .34656 .21844 .3529 .21606 .34897 .21166 Mtetra
.34897 .21166 .3529 .21606 .35925 .21368 .35532 .20926 Mtetra
.35532 .20926 .35925 .21368 .36561 .21129 .3617 .20686 Mtetra
.3617 .20686 .36561 .21129 .37199 .20889 .36809 .20445 Mtetra
.36809 .20445 .37199 .20889 .37839 .20649 .37449 .20204 Mtetra
.663 .741 .908 r
.37449 .20204 .37839 .20649 .3848 .20408 .38091 .19962 Mtetra
.662 .741 .908 r
.38091 .19962 .3848 .20408 .39122 .20169 .38735 .19722 Mtetra
.664 .741 .908 r
.38735 .19722 .39122 .20169 .39766 .19927 .3938 .19479 Mtetra
.665 .742 .907 r
.3938 .19479 .39766 .19927 .40412 .19682 .40027 .19233 Mtetra
.664 .741 .908 r
.40027 .19233 .40412 .19682 .41059 .19439 .40675 .18988 Mtetra
.40675 .18988 .41059 .19439 .41708 .19195 .41325 .18744 Mtetra
.41325 .18744 .41708 .19195 .42359 .18951 .41976 .18498 Mtetra
.41976 .18498 .42359 .18951 .43011 .18706 .42629 .18252 Mtetra
.42629 .18252 .43011 .18706 .43664 .1846 .43283 .18005 Mtetra
.43283 .18005 .43664 .1846 .44319 .18214 .43939 .17758 Mtetra
.43939 .17758 .44319 .18214 .44976 .17967 .44597 .1751 Mtetra
.44597 .1751 .44976 .17967 .45634 .1772 .45256 .17262 Mtetra
.45256 .17262 .45634 .1772 .46294 .17472 .45917 .17013 Mtetra
.45917 .17013 .46294 .17472 .46955 .17224 .4658 .16763 Mtetra
.4658 .16763 .46955 .17224 .47618 .16975 .47244 .16513 Mtetra
.47244 .16513 .47618 .16975 .48283 .16725 .4791 .16262 Mtetra
.4791 .16262 .48283 .16725 .4895 .16474 .48577 .16011 Mtetra
.48577 .16011 .4895 .16474 .49617 .16224 .49246 .15759 Mtetra
.49246 .15759 .49617 .16224 .50287 .15972 .49917 .15506 Mtetra
.49917 .15506 .50287 .15972 .50958 .1572 .50589 .15253 Mtetra
.50589 .15253 .50958 .1572 .51631 .15467 .51263 .14999 Mtetra
.51263 .14999 .51631 .15467 .52306 .15214 .51939 .14744 Mtetra
.51939 .14744 .52306 .15214 .52982 .1496 .52616 .14489 Mtetra
.52616 .14489 .52982 .1496 .5366 .14705 .53295 .14233 Mtetra
.53295 .14233 .5366 .14705 .54339 .1445 .53975 .13977 Mtetra
.53975 .13977 .54339 .1445 .5502 .14194 .54658 .13719 Mtetra
.54658 .13719 .5502 .14194 .55703 .13937 .55342 .13462 Mtetra
.55342 .13462 .55703 .13937 .56388 .1368 .56027 .13203 Mtetra
.56027 .13203 .56388 .1368 .57074 .13422 .56715 .12944 Mtetra
.56715 .12944 .57074 .13422 .57762 .13164 .57404 .12685 Mtetra
.57404 .12685 .57762 .13164 .58452 .12904 .58095 .12424 Mtetra
.58095 .12424 .58452 .12904 .59143 .12645 .58787 .12163 Mtetra
.58787 .12163 .59143 .12645 .59836 .12384 .59482 .11902 Mtetra
.59482 .11902 .59836 .12384 .60531 .12123 .60178 .1164 Mtetra
.60178 .1164 .60531 .12123 .61228 .11862 .60875 .11377 Mtetra
.60875 .11377 .61228 .11862 .61926 .11599 .61575 .11113 Mtetra
.61575 .11113 .61926 .11599 .62626 .11336 .62276 .10849 Mtetra
.62276 .10849 .62626 .11336 .63328 .11072 .62979 .10584 Mtetra
.62979 .10584 .63328 .11072 .64032 .10808 .63684 .10318 Mtetra
.63684 .10318 .64032 .10808 .64737 .10543 .6439 .10052 Mtetra
.6439 .10052 .64737 .10543 .65444 .10277 .65099 .09785 Mtetra
.65099 .09785 .65444 .10277 .66153 .10011 .65809 .09518 Mtetra
.65809 .09518 .66153 .10011 .66864 .09744 .66521 .09249 Mtetra
.66521 .09249 .66864 .09744 .67576 .09476 .67235 .0898 Mtetra
.67235 .0898 .67576 .09476 .68291 .09208 .6795 .08711 Mtetra
.6795 .08711 .68291 .09208 .69007 .08939 .68667 .08441 Mtetra
.68667 .08441 .69007 .08939 .69725 .08669 .69387 .0817 Mtetra
.69387 .0817 .69725 .08669 .70444 .08399 .70108 .07898 Mtetra
.70108 .07898 .70444 .08399 .71166 .08128 .7083 .07626 Mtetra
.7083 .07626 .71166 .08128 .71889 .07856 .71555 .07352 Mtetra
.71555 .07352 .71889 .07856 .72615 .07584 .72282 .07079 Mtetra
.72282 .07079 .72615 .07584 .73342 .0731 .7301 .06804 Mtetra
.08488 .30554 .08919 .30954 .09494 .30737 .09064 .30336 Mtetra
.09064 .30336 .09494 .30737 .1007 .3052 .09642 .30118 Mtetra
.09642 .30118 .1007 .3052 .10648 .30302 .1022 .29899 Mtetra
.1022 .29899 .10648 .30302 .11228 .30084 .108 .2968 Mtetra
.108 .2968 .11228 .30084 .11808 .29865 .11382 .2946 Mtetra
.11382 .2946 .11808 .29865 .1239 .29646 .11964 .2924 Mtetra
.11964 .2924 .1239 .29646 .12973 .29426 .12548 .29019 Mtetra
.12548 .29019 .12973 .29426 .13558 .29206 .13134 .28798 Mtetra
.13134 .28798 .13558 .29206 .14144 .28985 .1372 .28576 Mtetra
.1372 .28576 .14144 .28985 .14731 .28764 .14308 .28354 Mtetra
.14308 .28354 .14731 .28764 .1532 .28542 .14898 .28131 Mtetra
.14898 .28131 .1532 .28542 .1591 .2832 .15488 .27908 Mtetra
.15488 .27908 .1591 .2832 .16501 .28097 .1608 .27684 Mtetra
.1608 .27684 .16501 .28097 .17094 .27874 .16674 .2746 Mtetra
.16674 .2746 .17094 .27874 .17688 .2765 .17269 .27235 Mtetra
.17269 .27235 .17688 .2765 .18283 .27426 .17865 .2701 Mtetra
.17865 .2701 .18283 .27426 .1888 .27201 .18463 .26784 Mtetra
.18463 .26784 .1888 .27201 .19478 .26975 .19062 .26558 Mtetra
.19062 .26558 .19478 .26975 .20078 .26749 .19662 .26331 Mtetra
.19662 .26331 .20078 .26749 .20679 .26523 .20264 .26103 Mtetra
.20264 .26103 .20679 .26523 .21281 .26296 .20867 .25876 Mtetra
.20867 .25876 .21281 .26296 .21885 .26068 .21471 .25647 Mtetra
.21471 .25647 .21885 .26068 .2249 .2584 .22077 .25418 Mtetra
.22077 .25418 .2249 .2584 .23097 .25612 .22685 .25188 Mtetra
.22685 .25188 .23097 .25612 .23705 .25383 .23294 .24958 Mtetra
.23294 .24958 .23705 .25383 .24314 .25153 .23904 .24728 Mtetra
.23904 .24728 .24314 .25153 .24925 .24923 .24516 .24497 Mtetra
.24516 .24497 .24925 .24923 .25537 .24692 .25129 .24265 Mtetra
.25129 .24265 .25537 .24692 .26151 .24461 .25743 .24033 Mtetra
.25743 .24033 .26151 .24461 .26766 .24229 .26359 .238 Mtetra
.26359 .238 .26766 .24229 .27383 .23997 .26977 .23566 Mtetra
.26977 .23566 .27383 .23997 .28001 .23764 .27596 .23333 Mtetra
.27596 .23333 .28001 .23764 .2862 .23531 .28216 .23098 Mtetra
.28216 .23098 .2862 .23531 .29241 .23297 .28838 .22863 Mtetra
.28838 .22863 .29241 .23297 .29864 .23062 .29461 .22628 Mtetra
.29461 .22628 .29864 .23062 .30487 .22827 .30086 .22391 Mtetra
.30086 .22391 .30487 .22827 .31113 .22591 .30712 .22155 Mtetra
.30712 .22155 .31113 .22591 .3174 .22355 .3134 .21917 Mtetra
.3134 .21917 .3174 .22355 .32368 .22118 .31969 .2168 Mtetra
.31969 .2168 .32368 .22118 .32998 .21881 .326 .21441 Mtetra
.326 .21441 .32998 .21881 .33629 .21643 .33232 .21202 Mtetra
.33232 .21202 .33629 .21643 .34262 .21405 .33866 .20963 Mtetra
.33866 .20963 .34262 .21405 .34897 .21166 .34502 .20723 Mtetra
.34502 .20723 .34897 .21166 .35532 .20926 .35138 .20482 Mtetra
.35138 .20482 .35532 .20926 .3617 .20686 .35777 .20241 Mtetra
.35777 .20241 .3617 .20686 .36809 .20445 .36417 .19999 Mtetra
.36417 .19999 .36809 .20445 .37449 .20204 .37058 .19757 Mtetra
.663 .741 .908 r
.37058 .19757 .37449 .20204 .38091 .19962 .37701 .19514 Mtetra
.662 .741 .908 r
.37701 .19514 .38091 .19962 .38735 .19722 .38345 .19273 Mtetra
.664 .741 .908 r
.38345 .19273 .38735 .19722 .3938 .19479 .38991 .19028 Mtetra
.665 .742 .907 r
.38991 .19028 .3938 .19479 .40027 .19233 .39639 .18781 Mtetra
.664 .741 .908 r
.39639 .18781 .40027 .19233 .40675 .18988 .40288 .18536 Mtetra
.40288 .18536 .40675 .18988 .41325 .18744 .40939 .1829 Mtetra
.40939 .1829 .41325 .18744 .41976 .18498 .41591 .18043 Mtetra
.41591 .18043 .41976 .18498 .42629 .18252 .42245 .17796 Mtetra
.42245 .17796 .42629 .18252 .43283 .18005 .42901 .17549 Mtetra
.42901 .17549 .43283 .18005 .43939 .17758 .43558 .173 Mtetra
.43558 .173 .43939 .17758 .44597 .1751 .44217 .17051 Mtetra
.44217 .17051 .44597 .1751 .45256 .17262 .44877 .16802 Mtetra
.44877 .16802 .45256 .17262 .45917 .17013 .45539 .16552 Mtetra
.45539 .16552 .45917 .17013 .4658 .16763 .46202 .16301 Mtetra
.46202 .16301 .4658 .16763 .47244 .16513 .46868 .16049 Mtetra
.46868 .16049 .47244 .16513 .4791 .16262 .47534 .15797 Mtetra
.47534 .15797 .4791 .16262 .48577 .16011 .48203 .15545 Mtetra
.48203 .15545 .48577 .16011 .49246 .15759 .48873 .15292 Mtetra
.48873 .15292 .49246 .15759 .49917 .15506 .49545 .15038 Mtetra
.49545 .15038 .49917 .15506 .50589 .15253 .50218 .14783 Mtetra
.50218 .14783 .50589 .15253 .51263 .14999 .50893 .14528 Mtetra
.50893 .14528 .51263 .14999 .51939 .14744 .5157 .14272 Mtetra
.5157 .14272 .51939 .14744 .52616 .14489 .52248 .14016 Mtetra
.52248 .14016 .52616 .14489 .53295 .14233 .52928 .13759 Mtetra
.52928 .13759 .53295 .14233 .53975 .13977 .5361 .13501 Mtetra
.5361 .13501 .53975 .13977 .54658 .13719 .54293 .13243 Mtetra
.54293 .13243 .54658 .13719 .55342 .13462 .54978 .12984 Mtetra
.54978 .12984 .55342 .13462 .56027 .13203 .55665 .12725 Mtetra
.55665 .12725 .56027 .13203 .56715 .12944 .56354 .12464 Mtetra
.56354 .12464 .56715 .12944 .57404 .12685 .57044 .12204 Mtetra
.57044 .12204 .57404 .12685 .58095 .12424 .57736 .11942 Mtetra
.57736 .11942 .58095 .12424 .58787 .12163 .5843 .1168 Mtetra
.5843 .1168 .58787 .12163 .59482 .11902 .59125 .11417 Mtetra
.59125 .11417 .59482 .11902 .60178 .1164 .59822 .11154 Mtetra
.59822 .11154 .60178 .1164 .60875 .11377 .60521 .1089 Mtetra
.60521 .1089 .60875 .11377 .61575 .11113 .61222 .10625 Mtetra
.61222 .10625 .61575 .11113 .62276 .10849 .61924 .10359 Mtetra
.61924 .10359 .62276 .10849 .62979 .10584 .62628 .10093 Mtetra
.62628 .10093 .62979 .10584 .63684 .10318 .63334 .09826 Mtetra
.63334 .09826 .63684 .10318 .6439 .10052 .64042 .09559 Mtetra
.64042 .09559 .6439 .10052 .65099 .09785 .64752 .09291 Mtetra
.64752 .09291 .65099 .09785 .65809 .09518 .65463 .09022 Mtetra
.65463 .09022 .65809 .09518 .66521 .09249 .66176 .08752 Mtetra
.66176 .08752 .66521 .09249 .67235 .0898 .66891 .08482 Mtetra
.66891 .08482 .67235 .0898 .6795 .08711 .67608 .08211 Mtetra
.67608 .08211 .6795 .08711 .68667 .08441 .68327 .0794 Mtetra
.68327 .0794 .68667 .08441 .69387 .0817 .69047 .07667 Mtetra
.69047 .07667 .69387 .0817 .70108 .07898 .69769 .07395 Mtetra
.69769 .07395 .70108 .07898 .7083 .07626 .70493 .07121 Mtetra
.70493 .07121 .7083 .07626 .71555 .07352 .71219 .06846 Mtetra
.71219 .06846 .71555 .07352 .72282 .07079 .71947 .06571 Mtetra
.71947 .06571 .72282 .07079 .7301 .06804 .72677 .06296 Mtetra
.08056 .30151 .08488 .30554 .09064 .30336 .08633 .29933 Mtetra
.08633 .29933 .09064 .30336 .09642 .30118 .09211 .29714 Mtetra
.09211 .29714 .09642 .30118 .1022 .29899 .0979 .29494 Mtetra
.0979 .29494 .1022 .29899 .108 .2968 .10371 .29274 Mtetra
.10371 .29274 .108 .2968 .11382 .2946 .10953 .29053 Mtetra
.10953 .29053 .11382 .2946 .11964 .2924 .11537 .28832 Mtetra
.11537 .28832 .11964 .2924 .12548 .29019 .12121 .2861 Mtetra
.12121 .2861 .12548 .29019 .13134 .28798 .12707 .28388 Mtetra
.12707 .28388 .13134 .28798 .1372 .28576 .13295 .28166 Mtetra
.13295 .28166 .1372 .28576 .14308 .28354 .13884 .27942 Mtetra
.13884 .27942 .14308 .28354 .14898 .28131 .14474 .27719 Mtetra
.14474 .27719 .14898 .28131 .15488 .27908 .15065 .27495 Mtetra
.15065 .27495 .15488 .27908 .1608 .27684 .15658 .2727 Mtetra
.15658 .2727 .1608 .27684 .16674 .2746 .16252 .27045 Mtetra
.16252 .27045 .16674 .2746 .17269 .27235 .16848 .26819 Mtetra
.16848 .26819 .17269 .27235 .17865 .2701 .17445 .26593 Mtetra
.17445 .26593 .17865 .2701 .18463 .26784 .18043 .26366 Mtetra
.18043 .26366 .18463 .26784 .19062 .26558 .18643 .26138 Mtetra
.18643 .26138 .19062 .26558 .19662 .26331 .19244 .25911 Mtetra
.19244 .25911 .19662 .26331 .20264 .26103 .19847 .25682 Mtetra
.19847 .25682 .20264 .26103 .20867 .25876 .20451 .25453 Mtetra
.20451 .25453 .20867 .25876 .21471 .25647 .21056 .25224 Mtetra
.21056 .25224 .21471 .25647 .22077 .25418 .21663 .24994 Mtetra
.21663 .24994 .22077 .25418 .22685 .25188 .22271 .24763 Mtetra
.22271 .24763 .22685 .25188 .23294 .24958 .22881 .24532 Mtetra
.22881 .24532 .23294 .24958 .23904 .24728 .23492 .24301 Mtetra
.23492 .24301 .23904 .24728 .24516 .24497 .24105 .24068 Mtetra
.24105 .24068 .24516 .24497 .25129 .24265 .24719 .23836 Mtetra
.24719 .23836 .25129 .24265 .25743 .24033 .25334 .23602 Mtetra
.25334 .23602 .25743 .24033 .26359 .238 .25951 .23369 Mtetra
.25951 .23369 .26359 .238 .26977 .23566 .26569 .23134 Mtetra
.26569 .23134 .26977 .23566 .27596 .23333 .27189 .22899 Mtetra
.27189 .22899 .27596 .23333 .28216 .23098 .2781 .22664 Mtetra
.2781 .22664 .28216 .23098 .28838 .22863 .28433 .22428 Mtetra
.28433 .22428 .28838 .22863 .29461 .22628 .29057 .22191 Mtetra
.29057 .22191 .29461 .22628 .30086 .22391 .29683 .21954 Mtetra
.29683 .21954 .30086 .22391 .30712 .22155 .3031 .21716 Mtetra
.3031 .21716 .30712 .22155 .3134 .21917 .30939 .21478 Mtetra
.30939 .21478 .3134 .21917 .31969 .2168 .31569 .21239 Mtetra
.31569 .21239 .31969 .2168 .326 .21441 .32201 .21 Mtetra
.32201 .21 .326 .21441 .33232 .21202 .32834 .2076 Mtetra
.32834 .2076 .33232 .21202 .33866 .20963 .33469 .20519 Mtetra
.33469 .20519 .33866 .20963 .34502 .20723 .34105 .20278 Mtetra
.34105 .20278 .34502 .20723 .35138 .20482 .34743 .20036 Mtetra
.34743 .20036 .35138 .20482 .35777 .20241 .35382 .19794 Mtetra
.35382 .19794 .35777 .20241 .36417 .19999 .36023 .19551 Mtetra
.36023 .19551 .36417 .19999 .37058 .19757 .36665 .19308 Mtetra
.663 .741 .908 r
.36665 .19308 .37058 .19757 .37701 .19514 .37309 .19064 Mtetra
.662 .741 .908 r
.37309 .19064 .37701 .19514 .38345 .19273 .37954 .18821 Mtetra
.664 .741 .908 r
.37954 .18821 .38345 .19273 .38991 .19028 .38601 .18576 Mtetra
.665 .742 .907 r
.38601 .18576 .38991 .19028 .39639 .18781 .3925 .18328 Mtetra
.664 .741 .908 r
.3925 .18328 .39639 .18781 .40288 .18536 .399 .18081 Mtetra
.399 .18081 .40288 .18536 .40939 .1829 .40552 .17834 Mtetra
.40552 .17834 .40939 .1829 .41591 .18043 .41205 .17587 Mtetra
.41205 .17587 .41591 .18043 .42245 .17796 .4186 .17338 Mtetra
.4186 .17338 .42245 .17796 .42901 .17549 .42517 .1709 Mtetra
.42517 .1709 .42901 .17549 .43558 .173 .43175 .1684 Mtetra
.43175 .1684 .43558 .173 .44217 .17051 .43835 .1659 Mtetra
.43835 .1659 .44217 .17051 .44877 .16802 .44496 .16339 Mtetra
.44496 .16339 .44877 .16802 .45539 .16552 .45159 .16088 Mtetra
.45159 .16088 .45539 .16552 .46202 .16301 .45823 .15836 Mtetra
.45823 .15836 .46202 .16301 .46868 .16049 .4649 .15584 Mtetra
.4649 .15584 .46868 .16049 .47534 .15797 .47157 .15331 Mtetra
.47157 .15331 .47534 .15797 .48203 .15545 .47827 .15077 Mtetra
.47827 .15077 .48203 .15545 .48873 .15292 .48498 .14822 Mtetra
.48498 .14822 .48873 .15292 .49545 .15038 .49171 .14567 Mtetra
.49171 .14567 .49545 .15038 .50218 .14783 .49845 .14312 Mtetra
.49845 .14312 .50218 .14783 .50893 .14528 .50521 .14056 Mtetra
.50521 .14056 .50893 .14528 .5157 .14272 .51199 .13799 Mtetra
.51199 .13799 .5157 .14272 .52248 .14016 .51879 .13541 Mtetra
.51879 .13541 .52248 .14016 .52928 .13759 .5256 .13283 Mtetra
.5256 .13283 .52928 .13759 .5361 .13501 .53243 .13024 Mtetra
.53243 .13024 .5361 .13501 .54293 .13243 .53927 .12765 Mtetra
.53927 .12765 .54293 .13243 .54978 .12984 .54613 .12505 Mtetra
.54613 .12505 .54978 .12984 .55665 .12725 .55301 .12244 Mtetra
.55301 .12244 .55665 .12725 .56354 .12464 .55991 .11982 Mtetra
.55991 .11982 .56354 .12464 .57044 .12204 .56682 .1172 Mtetra
.56682 .1172 .57044 .12204 .57736 .11942 .57375 .11458 Mtetra
.57375 .11458 .57736 .11942 .5843 .1168 .5807 .11194 Mtetra
.5807 .11194 .5843 .1168 .59125 .11417 .58767 .1093 Mtetra
.58767 .1093 .59125 .11417 .59822 .11154 .59465 .10666 Mtetra
.59465 .10666 .59822 .11154 .60521 .1089 .60165 .104 Mtetra
.60165 .104 .60521 .1089 .61222 .10625 .60867 .10134 Mtetra
.60867 .10134 .61222 .10625 .61924 .10359 .61571 .09867 Mtetra
.61571 .09867 .61924 .10359 .62628 .10093 .62276 .096 Mtetra
.62276 .096 .62628 .10093 .63334 .09826 .62983 .09332 Mtetra
.62983 .09332 .63334 .09826 .64042 .09559 .63692 .09063 Mtetra
.63692 .09063 .64042 .09559 .64752 .09291 .64403 .08794 Mtetra
.64403 .08794 .64752 .09291 .65463 .09022 .65116 .08524 Mtetra
.65116 .08524 .65463 .09022 .66176 .08752 .6583 .08253 Mtetra
.6583 .08253 .66176 .08752 .66891 .08482 .66546 .07982 Mtetra
.66546 .07982 .66891 .08482 .67608 .08211 .67264 .07709 Mtetra
.67264 .07709 .67608 .08211 .68327 .0794 .67984 .07437 Mtetra
.67984 .07437 .68327 .0794 .69047 .07667 .68706 .07163 Mtetra
.68706 .07163 .69047 .07667 .69769 .07395 .69429 .06889 Mtetra
.69429 .06889 .69769 .07395 .70493 .07121 .70155 .06614 Mtetra
.70155 .06614 .70493 .07121 .71219 .06846 .70882 .06338 Mtetra
.70882 .06338 .71219 .06846 .71947 .06571 .71611 .06062 Mtetra
.71611 .06062 .71947 .06571 .72677 .06296 .72342 .05785 Mtetra
.07622 .29747 .08056 .30151 .08633 .29933 .082 .29528 Mtetra
.082 .29528 .08633 .29933 .09211 .29714 .08779 .29308 Mtetra
.08779 .29308 .09211 .29714 .0979 .29494 .09359 .29087 Mtetra
.09359 .29087 .0979 .29494 .10371 .29274 .0994 .28866 Mtetra
.0994 .28866 .10371 .29274 .10953 .29053 .10523 .28645 Mtetra
.10523 .28645 .10953 .29053 .11537 .28832 .11107 .28423 Mtetra
.11107 .28423 .11537 .28832 .12121 .2861 .11693 .282 Mtetra
.11693 .282 .12121 .2861 .12707 .28388 .12279 .27977 Mtetra
.12279 .27977 .12707 .28388 .13295 .28166 .12868 .27753 Mtetra
.12868 .27753 .13295 .28166 .13884 .27942 .13457 .27529 Mtetra
.13457 .27529 .13884 .27942 .14474 .27719 .14048 .27305 Mtetra
.14048 .27305 .14474 .27719 .15065 .27495 .1464 .27079 Mtetra
.1464 .27079 .15065 .27495 .15658 .2727 .15234 .26854 Mtetra
.15234 .26854 .15658 .2727 .16252 .27045 .15829 .26627 Mtetra
.15829 .26627 .16252 .27045 .16848 .26819 .16425 .26401 Mtetra
.16425 .26401 .16848 .26819 .17445 .26593 .17023 .26173 Mtetra
.17023 .26173 .17445 .26593 .18043 .26366 .17622 .25946 Mtetra
.17622 .25946 .18043 .26366 .18643 .26138 .18223 .25717 Mtetra
.18223 .25717 .18643 .26138 .19244 .25911 .18825 .25489 Mtetra
.18825 .25489 .19244 .25911 .19847 .25682 .19428 .25259 Mtetra
.19428 .25259 .19847 .25682 .20451 .25453 .20033 .25029 Mtetra
.20033 .25029 .20451 .25453 .21056 .25224 .20639 .24799 Mtetra
.20639 .24799 .21056 .25224 .21663 .24994 .21247 .24568 Mtetra
.21247 .24568 .21663 .24994 .22271 .24763 .21856 .24336 Mtetra
.21856 .24336 .22271 .24763 .22881 .24532 .22467 .24104 Mtetra
.22467 .24104 .22881 .24532 .23492 .24301 .23078 .23872 Mtetra
.23078 .23872 .23492 .24301 .24105 .24068 .23692 .23638 Mtetra
.23692 .23638 .24105 .24068 .24719 .23836 .24307 .23405 Mtetra
.24307 .23405 .24719 .23836 .25334 .23602 .24923 .2317 Mtetra
.24923 .2317 .25334 .23602 .25951 .23369 .25541 .22935 Mtetra
.25541 .22935 .25951 .23369 .26569 .23134 .2616 .227 Mtetra
.2616 .227 .26569 .23134 .27189 .22899 .26781 .22464 Mtetra
.26781 .22464 .27189 .22899 .2781 .22664 .27403 .22228 Mtetra
.27403 .22228 .2781 .22664 .28433 .22428 .28026 .21991 Mtetra
.28026 .21991 .28433 .22428 .29057 .22191 .28651 .21753 Mtetra
.28651 .21753 .29057 .22191 .29683 .21954 .29278 .21515 Mtetra
.29278 .21515 .29683 .21954 .3031 .21716 .29906 .21276 Mtetra
.29906 .21276 .3031 .21716 .30939 .21478 .30536 .21037 Mtetra
.30536 .21037 .30939 .21478 .31569 .21239 .31167 .20797 Mtetra
.31167 .20797 .31569 .21239 .32201 .21 .31799 .20556 Mtetra
.31799 .20556 .32201 .21 .32834 .2076 .32433 .20315 Mtetra
.32433 .20315 .32834 .2076 .33469 .20519 .33069 .20073 Mtetra
.33069 .20073 .33469 .20519 .34105 .20278 .33706 .19831 Mtetra
.33706 .19831 .34105 .20278 .34743 .20036 .34345 .19588 Mtetra
.34345 .19588 .34743 .20036 .35382 .19794 .34985 .19345 Mtetra
.34985 .19345 .35382 .19794 .36023 .19551 .35627 .19101 Mtetra
.35627 .19101 .36023 .19551 .36665 .19308 .3627 .18857 Mtetra
.663 .741 .908 r
.3627 .18857 .36665 .19308 .37309 .19064 .36915 .18612 Mtetra
.662 .741 .908 r
.36915 .18612 .37309 .19064 .37954 .18821 .37561 .18368 Mtetra
.664 .741 .908 r
.37561 .18368 .37954 .18821 .38601 .18576 .38209 .18122 Mtetra
.665 .742 .907 r
.38209 .18122 .38601 .18576 .3925 .18328 .38859 .17873 Mtetra
.664 .741 .908 r
.38859 .17873 .3925 .18328 .399 .18081 .3951 .17625 Mtetra
.3951 .17625 .399 .18081 .40552 .17834 .40163 .17377 Mtetra
.40163 .17377 .40552 .17834 .41205 .17587 .40817 .17128 Mtetra
.40817 .17128 .41205 .17587 .4186 .17338 .41473 .16879 Mtetra
.41473 .16879 .4186 .17338 .42517 .1709 .42131 .16629 Mtetra
.42131 .16629 .42517 .1709 .43175 .1684 .4279 .16378 Mtetra
.4279 .16378 .43175 .1684 .43835 .1659 .43451 .16127 Mtetra
.43451 .16127 .43835 .1659 .44496 .16339 .44113 .15875 Mtetra
.44113 .15875 .44496 .16339 .45159 .16088 .44777 .15623 Mtetra
.44777 .15623 .45159 .16088 .45823 .15836 .45443 .1537 Mtetra
.45443 .1537 .45823 .15836 .4649 .15584 .4611 .15116 Mtetra
.4611 .15116 .4649 .15584 .47157 .15331 .46779 .14862 Mtetra
.46779 .14862 .47157 .15331 .47827 .15077 .47449 .14607 Mtetra
.47449 .14607 .47827 .15077 .48498 .14822 .48121 .14351 Mtetra
.48121 .14351 .48498 .14822 .49171 .14567 .48795 .14095 Mtetra
.48795 .14095 .49171 .14567 .49845 .14312 .49471 .13838 Mtetra
.49471 .13838 .49845 .14312 .50521 .14056 .50148 .13581 Mtetra
.50148 .13581 .50521 .14056 .51199 .13799 .50827 .13323 Mtetra
.50827 .13323 .51199 .13799 .51879 .13541 .51507 .13064 Mtetra
.51507 .13064 .51879 .13541 .5256 .13283 .5219 .12805 Mtetra
.5219 .12805 .5256 .13283 .53243 .13024 .52874 .12545 Mtetra
.52874 .12545 .53243 .13024 .53927 .12765 .53559 .12284 Mtetra
.53559 .12284 .53927 .12765 .54613 .12505 .54247 .12023 Mtetra
.54247 .12023 .54613 .12505 .55301 .12244 .54936 .11761 Mtetra
.54936 .11761 .55301 .12244 .55991 .11982 .55626 .11498 Mtetra
.55626 .11498 .55991 .11982 .56682 .1172 .56319 .11235 Mtetra
.56319 .11235 .56682 .1172 .57375 .11458 .57013 .10971 Mtetra
.57013 .10971 .57375 .11458 .5807 .11194 .57709 .10706 Mtetra
.57709 .10706 .5807 .11194 .58767 .1093 .58407 .10441 Mtetra
.58407 .10441 .58767 .1093 .59465 .10666 .59107 .10175 Mtetra
.59107 .10175 .59465 .10666 .60165 .104 .59808 .09909 Mtetra
.59808 .09909 .60165 .104 .60867 .10134 .60511 .09641 Mtetra
.60511 .09641 .60867 .10134 .61571 .09867 .61216 .09373 Mtetra
.61216 .09373 .61571 .09867 .62276 .096 .61922 .09105 Mtetra
.61922 .09105 .62276 .096 .62983 .09332 .62631 .08835 Mtetra
.62631 .08835 .62983 .09332 .63692 .09063 .63341 .08565 Mtetra
.63341 .08565 .63692 .09063 .64403 .08794 .64053 .08295 Mtetra
.64053 .08295 .64403 .08794 .65116 .08524 .64767 .08023 Mtetra
.64767 .08023 .65116 .08524 .6583 .08253 .65482 .07751 Mtetra
.65482 .07751 .6583 .08253 .66546 .07982 .662 .07479 Mtetra
.662 .07479 .66546 .07982 .67264 .07709 .66919 .07205 Mtetra
.66919 .07205 .67264 .07709 .67984 .07437 .6764 .06931 Mtetra
.6764 .06931 .67984 .07437 .68706 .07163 .68363 .06656 Mtetra
.68363 .06656 .68706 .07163 .69429 .06889 .69088 .06381 Mtetra
.69088 .06381 .69429 .06889 .70155 .06614 .69815 .06104 Mtetra
.69815 .06104 .70155 .06614 .70882 .06338 .70543 .05827 Mtetra
.70543 .05827 .70882 .06338 .71611 .06062 .71273 .0555 Mtetra
.71273 .0555 .71611 .06062 .72342 .05785 .72006 .05271 Mtetra
.07187 .29342 .07622 .29747 .082 .29528 .07765 .29121 Mtetra
.07765 .29121 .082 .29528 .08779 .29308 .08344 .289 Mtetra
.08344 .289 .08779 .29308 .09359 .29087 .08925 .28679 Mtetra
.08925 .28679 .09359 .29087 .0994 .28866 .09507 .28457 Mtetra
.09507 .28457 .0994 .28866 .10523 .28645 .10091 .28234 Mtetra
.10091 .28234 .10523 .28645 .11107 .28423 .10676 .28011 Mtetra
.10676 .28011 .11107 .28423 .11693 .282 .11262 .27788 Mtetra
.11262 .27788 .11693 .282 .12279 .27977 .1185 .27564 Mtetra
.1185 .27564 .12279 .27977 .12868 .27753 .12439 .27339 Mtetra
.12439 .27339 .12868 .27753 .13457 .27529 .13029 .27114 Mtetra
.13029 .27114 .13457 .27529 .14048 .27305 .13621 .26888 Mtetra
.13621 .26888 .14048 .27305 .1464 .27079 .14214 .26662 Mtetra
.14214 .26662 .1464 .27079 .15234 .26854 .14808 .26436 Mtetra
.14808 .26436 .15234 .26854 .15829 .26627 .15404 .26208 Mtetra
.15404 .26208 .15829 .26627 .16425 .26401 .16001 .25981 Mtetra
.16001 .25981 .16425 .26401 .17023 .26173 .166 .25753 Mtetra
.166 .25753 .17023 .26173 .17622 .25946 .172 .25524 Mtetra
.172 .25524 .17622 .25946 .18223 .25717 .17801 .25294 Mtetra
.17801 .25294 .18223 .25717 .18825 .25489 .18404 .25065 Mtetra
.18404 .25065 .18825 .25489 .19428 .25259 .19008 .24834 Mtetra
.19008 .24834 .19428 .25259 .20033 .25029 .19614 .24603 Mtetra
.19614 .24603 .20033 .25029 .20639 .24799 .20221 .24372 Mtetra
.20221 .24372 .20639 .24799 .21247 .24568 .20829 .2414 Mtetra
.20829 .2414 .21247 .24568 .21856 .24336 .21439 .23907 Mtetra
.21439 .23907 .21856 .24336 .22467 .24104 .2205 .23674 Mtetra
.2205 .23674 .22467 .24104 .23078 .23872 .22663 .23441 Mtetra
.22663 .23441 .23078 .23872 .23692 .23638 .23277 .23206 Mtetra
.23277 .23206 .23692 .23638 .24307 .23405 .23893 .22972 Mtetra
.23893 .22972 .24307 .23405 .24923 .2317 .2451 .22736 Mtetra
.2451 .22736 .24923 .2317 .25541 .22935 .25129 .225 Mtetra
.25129 .225 .25541 .22935 .2616 .227 .25749 .22264 Mtetra
.25749 .22264 .2616 .227 .26781 .22464 .2637 .22027 Mtetra
.2637 .22027 .26781 .22464 .27403 .22228 .26993 .2179 Mtetra
.26993 .2179 .27403 .22228 .28026 .21991 .27618 .21551 Mtetra
.27618 .21551 .28026 .21991 .28651 .21753 .28244 .21313 Mtetra
.28244 .21313 .28651 .21753 .29278 .21515 .28871 .21073 Mtetra
.28871 .21073 .29278 .21515 .29906 .21276 .295 .20834 Mtetra
.295 .20834 .29906 .21276 .30536 .21037 .30131 .20593 Mtetra
.30131 .20593 .30536 .21037 .31167 .20797 .30763 .20352 Mtetra
.30763 .20352 .31167 .20797 .31799 .20556 .31396 .20111 Mtetra
.31396 .20111 .31799 .20556 .32433 .20315 .32031 .19869 Mtetra
.32031 .19869 .32433 .20315 .33069 .20073 .32668 .19626 Mtetra
.32668 .19626 .33069 .20073 .33706 .19831 .33306 .19383 Mtetra
.33306 .19383 .33706 .19831 .34345 .19588 .33946 .19139 Mtetra
.33946 .19139 .34345 .19588 .34985 .19345 .34587 .18894 Mtetra
.34587 .18894 .34985 .19345 .35627 .19101 .35229 .18649 Mtetra
.35229 .18649 .35627 .19101 .3627 .18857 .35874 .18404 Mtetra
.663 .741 .908 r
.35874 .18404 .3627 .18857 .36915 .18612 .3652 .18157 Mtetra
.662 .741 .908 r
.3652 .18157 .36915 .18612 .37561 .18368 .37167 .17913 Mtetra
.664 .741 .908 r
.37167 .17913 .37561 .18368 .38209 .18122 .37816 .17665 Mtetra
.665 .742 .907 r
.37816 .17665 .38209 .18122 .38859 .17873 .38467 .17415 Mtetra
.664 .741 .908 r
.38467 .17415 .38859 .17873 .3951 .17625 .39119 .17166 Mtetra
.39119 .17166 .3951 .17625 .40163 .17377 .39772 .16917 Mtetra
.39772 .16917 .40163 .17377 .40817 .17128 .40428 .16667 Mtetra
.40428 .16667 .40817 .17128 .41473 .16879 .41085 .16417 Mtetra
.41085 .16417 .41473 .16879 .42131 .16629 .41743 .16166 Mtetra
.41743 .16166 .42131 .16629 .4279 .16378 .42403 .15914 Mtetra
.42403 .15914 .4279 .16378 .43451 .16127 .43065 .15661 Mtetra
.43065 .15661 .43451 .16127 .44113 .15875 .43728 .15409 Mtetra
.43728 .15409 .44113 .15875 .44777 .15623 .44393 .15155 Mtetra
.44393 .15155 .44777 .15623 .45443 .1537 .4506 .14901 Mtetra
.4506 .14901 .45443 .1537 .4611 .15116 .45728 .14646 Mtetra
.45728 .14646 .4611 .15116 .46779 .14862 .46398 .14391 Mtetra
.46398 .14391 .46779 .14862 .47449 .14607 .4707 .14134 Mtetra
.4707 .14134 .47449 .14607 .48121 .14351 .47743 .13878 Mtetra
.47743 .13878 .48121 .14351 .48795 .14095 .48418 .1362 Mtetra
.48418 .1362 .48795 .14095 .49471 .13838 .49095 .13362 Mtetra
.49095 .13362 .49471 .13838 .50148 .13581 .49773 .13104 Mtetra
.49773 .13104 .50148 .13581 .50827 .13323 .50453 .12845 Mtetra
.50453 .12845 .50827 .13323 .51507 .13064 .51135 .12585 Mtetra
.51135 .12585 .51507 .13064 .5219 .12805 .51818 .12324 Mtetra
.51818 .12324 .5219 .12805 .52874 .12545 .52503 .12063 Mtetra
.52503 .12063 .52874 .12545 .53559 .12284 .5319 .11801 Mtetra
.5319 .11801 .53559 .12284 .54247 .12023 .53878 .11539 Mtetra
.53878 .11539 .54247 .12023 .54936 .11761 .54568 .11275 Mtetra
.54568 .11275 .54936 .11761 .55626 .11498 .5526 .11012 Mtetra
.5526 .11012 .55626 .11498 .56319 .11235 .55954 .10747 Mtetra
.55954 .10747 .56319 .11235 .57013 .10971 .56649 .10482 Mtetra
.56649 .10482 .57013 .10971 .57709 .10706 .57347 .10216 Mtetra
.57347 .10216 .57709 .10706 .58407 .10441 .58046 .0995 Mtetra
.58046 .0995 .58407 .10441 .59107 .10175 .58746 .09682 Mtetra
.58746 .09682 .59107 .10175 .59808 .09909 .59449 .09415 Mtetra
.59449 .09415 .59808 .09909 .60511 .09641 .60153 .09146 Mtetra
.60153 .09146 .60511 .09641 .61216 .09373 .60859 .08877 Mtetra
.60859 .08877 .61216 .09373 .61922 .09105 .61567 .08607 Mtetra
.61567 .08607 .61922 .09105 .62631 .08835 .62276 .08336 Mtetra
.62276 .08336 .62631 .08835 .63341 .08565 .62988 .08065 Mtetra
.62988 .08065 .63341 .08565 .64053 .08295 .63701 .07793 Mtetra
.63701 .07793 .64053 .08295 .64767 .08023 .64416 .07521 Mtetra
.64416 .07521 .64767 .08023 .65482 .07751 .65133 .07247 Mtetra
.65133 .07247 .65482 .07751 .662 .07479 .65852 .06973 Mtetra
.65852 .06973 .662 .07479 .66919 .07205 .66572 .06698 Mtetra
.66572 .06698 .66919 .07205 .6764 .06931 .67294 .06423 Mtetra
.67294 .06423 .6764 .06931 .68363 .06656 .68019 .06147 Mtetra
.68019 .06147 .68363 .06656 .69088 .06381 .68745 .0587 Mtetra
.68745 .0587 .69088 .06381 .69815 .06104 .69473 .05592 Mtetra
.69473 .05592 .69815 .06104 .70543 .05827 .70202 .05314 Mtetra
.70202 .05314 .70543 .05827 .71273 .0555 .70934 .05035 Mtetra
.70934 .05035 .71273 .0555 .72006 .05271 .71668 .04756 Mtetra
.06749 .28934 .07187 .29342 .07765 .29121 .07328 .28713 Mtetra
.07328 .28713 .07765 .29121 .08344 .289 .07908 .28491 Mtetra
.07908 .28491 .08344 .289 .08925 .28679 .0849 .28268 Mtetra
.0849 .28268 .08925 .28679 .09507 .28457 .09073 .28046 Mtetra
.09073 .28046 .09507 .28457 .10091 .28234 .09657 .27822 Mtetra
.09657 .27822 .10091 .28234 .10676 .28011 .10243 .27598 Mtetra
.10243 .27598 .10676 .28011 .11262 .27788 .1083 .27374 Mtetra
.1083 .27374 .11262 .27788 .1185 .27564 .11418 .27149 Mtetra
.11418 .27149 .1185 .27564 .12439 .27339 .12008 .26923 Mtetra
.12008 .26923 .12439 .27339 .13029 .27114 .12599 .26697 Mtetra
.12599 .26697 .13029 .27114 .13621 .26888 .13191 .26471 Mtetra
.13191 .26471 .13621 .26888 .14214 .26662 .13785 .26243 Mtetra
.13785 .26243 .14214 .26662 .14808 .26436 .1438 .26016 Mtetra
.1438 .26016 .14808 .26436 .15404 .26208 .14977 .25788 Mtetra
.14977 .25788 .15404 .26208 .16001 .25981 .15575 .25559 Mtetra
.15575 .25559 .16001 .25981 .166 .25753 .16174 .2533 Mtetra
.16174 .2533 .166 .25753 .172 .25524 .16775 .251 Mtetra
.16775 .251 .172 .25524 .17801 .25294 .17377 .2487 Mtetra
.17377 .2487 .17801 .25294 .18404 .25065 .17981 .24639 Mtetra
.17981 .24639 .18404 .25065 .19008 .24834 .18586 .24408 Mtetra
.18586 .24408 .19008 .24834 .19614 .24603 .19192 .24176 Mtetra
.19192 .24176 .19614 .24603 .20221 .24372 .198 .23943 Mtetra
.198 .23943 .20221 .24372 .20829 .2414 .20409 .2371 Mtetra
.20409 .2371 .20829 .2414 .21439 .23907 .2102 .23477 Mtetra
.2102 .23477 .21439 .23907 .2205 .23674 .21632 .23242 Mtetra
.21632 .23242 .2205 .23674 .22663 .23441 .22246 .23008 Mtetra
.22246 .23008 .22663 .23441 .23277 .23206 .22861 .22773 Mtetra
.22861 .22773 .23277 .23206 .23893 .22972 .23477 .22537 Mtetra
.23477 .22537 .23893 .22972 .2451 .22736 .24095 .223 Mtetra
.24095 .223 .2451 .22736 .25129 .225 .24715 .22064 Mtetra
.24715 .22064 .25129 .225 .25749 .22264 .25336 .21826 Mtetra
.25336 .21826 .25749 .22264 .2637 .22027 .25958 .21588 Mtetra
.25958 .21588 .2637 .22027 .26993 .2179 .26582 .21349 Mtetra
.26582 .21349 .26993 .2179 .27618 .21551 .27208 .2111 Mtetra
.27208 .2111 .27618 .21551 .28244 .21313 .27834 .20871 Mtetra
.27834 .20871 .28244 .21313 .28871 .21073 .28463 .2063 Mtetra
.28463 .2063 .28871 .21073 .295 .20834 .29093 .20389 Mtetra
.29093 .20389 .295 .20834 .30131 .20593 .29724 .20148 Mtetra
.29724 .20148 .30131 .20593 .30763 .20352 .30357 .19906 Mtetra
.30357 .19906 .30763 .20352 .31396 .20111 .30991 .19663 Mtetra
.30991 .19663 .31396 .20111 .32031 .19869 .31627 .1942 Mtetra
.31627 .1942 .32031 .19869 .32668 .19626 .32265 .19176 Mtetra
.32265 .19176 .32668 .19626 .33306 .19383 .32904 .18932 Mtetra
.32904 .18932 .33306 .19383 .33946 .19139 .33544 .18687 Mtetra
.33544 .18687 .33946 .19139 .34587 .18894 .34187 .18441 Mtetra
.34187 .18441 .34587 .18894 .35229 .18649 .3483 .18195 Mtetra
.3483 .18195 .35229 .18649 .35874 .18404 .35475 .17948 Mtetra
.663 .741 .908 r
.35475 .17948 .35874 .18404 .3652 .18157 .36122 .17701 Mtetra
.662 .741 .908 r
.36122 .17701 .3652 .18157 .37167 .17913 .36771 .17455 Mtetra
.664 .741 .908 r
.36771 .17455 .37167 .17913 .37816 .17665 .3742 .17207 Mtetra
.665 .742 .907 r
.3742 .17207 .37816 .17665 .38467 .17415 .38072 .16956 Mtetra
.664 .741 .908 r
.38072 .16956 .38467 .17415 .39119 .17166 .38725 .16706 Mtetra
.38725 .16706 .39119 .17166 .39772 .16917 .3938 .16455 Mtetra
.3938 .16455 .39772 .16917 .40428 .16667 .40036 .16204 Mtetra
.40036 .16204 .40428 .16667 .41085 .16417 .40694 .15953 Mtetra
.40694 .15953 .41085 .16417 .41743 .16166 .41354 .157 Mtetra
.41354 .157 .41743 .16166 .42403 .15914 .42015 .15448 Mtetra
.42015 .15448 .42403 .15914 .43065 .15661 .42678 .15194 Mtetra
.42678 .15194 .43065 .15661 .43728 .15409 .43342 .1494 Mtetra
.43342 .1494 .43728 .15409 .44393 .15155 .44008 .14685 Mtetra
.44008 .14685 .44393 .15155 .4506 .14901 .44676 .1443 Mtetra
.44676 .1443 .4506 .14901 .45728 .14646 .45345 .14174 Mtetra
.45345 .14174 .45728 .14646 .46398 .14391 .46016 .13917 Mtetra
.46016 .13917 .46398 .14391 .4707 .14134 .46689 .1366 Mtetra
.46689 .1366 .4707 .14134 .47743 .13878 .47363 .13402 Mtetra
.47363 .13402 .47743 .13878 .48418 .1362 .48039 .13144 Mtetra
.48039 .13144 .48418 .1362 .49095 .13362 .48717 .12884 Mtetra
.48717 .12884 .49095 .13362 .49773 .13104 .49396 .12625 Mtetra
.49396 .12625 .49773 .13104 .50453 .12845 .50077 .12364 Mtetra
.50077 .12364 .50453 .12845 .51135 .12585 .5076 .12103 Mtetra
.5076 .12103 .51135 .12585 .51818 .12324 .51444 .11841 Mtetra
.51444 .11841 .51818 .12324 .52503 .12063 .52131 .11579 Mtetra
.52131 .11579 .52503 .12063 .5319 .11801 .52819 .11316 Mtetra
.52819 .11316 .5319 .11801 .53878 .11539 .53508 .11052 Mtetra
.53508 .11052 .53878 .11539 .54568 .11275 .54199 .10788 Mtetra
.54199 .10788 .54568 .11275 .5526 .11012 .54893 .10523 Mtetra
.54893 .10523 .5526 .11012 .55954 .10747 .55587 .10257 Mtetra
.55587 .10257 .55954 .10747 .56649 .10482 .56284 .09991 Mtetra
.56284 .09991 .56649 .10482 .57347 .10216 .56982 .09724 Mtetra
.56982 .09724 .57347 .10216 .58046 .0995 .57682 .09456 Mtetra
.57682 .09456 .58046 .0995 .58746 .09682 .58384 .09187 Mtetra
.58384 .09187 .58746 .09682 .59449 .09415 .59088 .08918 Mtetra
.59088 .08918 .59449 .09415 .60153 .09146 .59793 .08649 Mtetra
.59793 .08649 .60153 .09146 .60859 .08877 .605 .08378 Mtetra
.605 .08378 .60859 .08877 .61567 .08607 .61209 .08107 Mtetra
.61209 .08107 .61567 .08607 .62276 .08336 .6192 .07835 Mtetra
.6192 .07835 .62276 .08336 .62988 .08065 .62633 .07563 Mtetra
.62633 .07563 .62988 .08065 .63701 .07793 .63347 .07289 Mtetra
.63347 .07289 .63701 .07793 .64416 .07521 .64064 .07015 Mtetra
.64064 .07015 .64416 .07521 .65133 .07247 .64782 .06741 Mtetra
.64782 .06741 .65133 .07247 .65852 .06973 .65502 .06465 Mtetra
.65502 .06465 .65852 .06973 .66572 .06698 .66223 .06189 Mtetra
.66223 .06189 .66572 .06698 .67294 .06423 .66947 .05913 Mtetra
.66947 .05913 .67294 .06423 .68019 .06147 .67673 .05635 Mtetra
.67673 .05635 .68019 .06147 .68745 .0587 .684 .05357 Mtetra
.684 .05357 .68745 .0587 .69473 .05592 .69129 .05078 Mtetra
.69129 .05078 .69473 .05592 .70202 .05314 .6986 .04799 Mtetra
.6986 .04799 .70202 .05314 .70934 .05035 .70593 .04518 Mtetra
.70593 .04518 .70934 .05035 .71668 .04756 .71328 .04237 Mtetra
.0631 .28525 .06749 .28934 .07328 .28713 .06889 .28303 Mtetra
.06889 .28303 .07328 .28713 .07908 .28491 .0747 .2808 Mtetra
.0747 .2808 .07908 .28491 .0849 .28268 .08053 .27857 Mtetra
.08053 .27857 .0849 .28268 .09073 .28046 .08636 .27633 Mtetra
.08636 .27633 .09073 .28046 .09657 .27822 .09221 .27408 Mtetra
.09221 .27408 .09657 .27822 .10243 .27598 .09808 .27183 Mtetra
.09808 .27183 .10243 .27598 .1083 .27374 .10395 .26958 Mtetra
.10395 .26958 .1083 .27374 .11418 .27149 .10985 .26732 Mtetra
.10985 .26732 .11418 .27149 .12008 .26923 .11575 .26505 Mtetra
.11575 .26505 .12008 .26923 .12599 .26697 .12167 .26278 Mtetra
.12167 .26278 .12599 .26697 .13191 .26471 .1276 .26051 Mtetra
.1276 .26051 .13191 .26471 .13785 .26243 .13355 .25823 Mtetra
.13355 .25823 .13785 .26243 .1438 .26016 .13951 .25594 Mtetra
.13951 .25594 .1438 .26016 .14977 .25788 .14548 .25365 Mtetra
.14548 .25365 .14977 .25788 .15575 .25559 .15147 .25135 Mtetra
.15147 .25135 .15575 .25559 .16174 .2533 .15747 .24905 Mtetra
.15747 .24905 .16174 .2533 .16775 .251 .16348 .24674 Mtetra
.16348 .24674 .16775 .251 .17377 .2487 .16951 .24443 Mtetra
.16951 .24443 .17377 .2487 .17981 .24639 .17556 .24211 Mtetra
.17556 .24211 .17981 .24639 .18586 .24408 .18162 .23979 Mtetra
.18162 .23979 .18586 .24408 .19192 .24176 .18769 .23746 Mtetra
.18769 .23746 .19192 .24176 .198 .23943 .19378 .23513 Mtetra
.19378 .23513 .198 .23943 .20409 .2371 .19988 .23279 Mtetra
.19988 .23279 .20409 .2371 .2102 .23477 .20599 .23044 Mtetra
.20599 .23044 .2102 .23477 .21632 .23242 .21212 .22809 Mtetra
.21212 .22809 .21632 .23242 .22246 .23008 .21827 .22573 Mtetra
.21827 .22573 .22246 .23008 .22861 .22773 .22443 .22337 Mtetra
.22443 .22337 .22861 .22773 .23477 .22537 .2306 .221 Mtetra
.2306 .221 .23477 .22537 .24095 .223 .23679 .21863 Mtetra
.23679 .21863 .24095 .223 .24715 .22064 .24299 .21625 Mtetra
.24299 .21625 .24715 .22064 .25336 .21826 .24921 .21386 Mtetra
.24921 .21386 .25336 .21826 .25958 .21588 .25544 .21147 Mtetra
.25544 .21147 .25958 .21588 .26582 .21349 .26169 .20907 Mtetra
.26169 .20907 .26582 .21349 .27208 .2111 .26795 .20667 Mtetra
.26795 .20667 .27208 .2111 .27834 .20871 .27423 .20426 Mtetra
.27423 .20426 .27834 .20871 .28463 .2063 .28052 .20185 Mtetra
.28052 .20185 .28463 .2063 .29093 .20389 .28683 .19943 Mtetra
.28683 .19943 .29093 .20389 .29724 .20148 .29316 .19701 Mtetra
.29316 .19701 .29724 .20148 .30357 .19906 .29949 .19457 Mtetra
.29949 .19457 .30357 .19906 .30991 .19663 .30585 .19214 Mtetra
.30585 .19214 .30991 .19663 .31627 .1942 .31222 .18969 Mtetra
.31222 .18969 .31627 .1942 .32265 .19176 .3186 .18725 Mtetra
.3186 .18725 .32265 .19176 .32904 .18932 .325 .18479 Mtetra
.325 .18479 .32904 .18932 .33544 .18687 .33142 .18233 Mtetra
.33142 .18233 .33544 .18687 .34187 .18441 .33785 .17986 Mtetra
.33785 .17986 .34187 .18441 .3483 .18195 .34429 .17739 Mtetra
.34429 .17739 .3483 .18195 .35475 .17948 .35075 .17491 Mtetra
.663 .741 .908 r
.35075 .17491 .35475 .17948 .36122 .17701 .35723 .17243 Mtetra
.662 .741 .908 r
.35723 .17243 .36122 .17701 .36771 .17455 .36372 .16996 Mtetra
.664 .741 .908 r
.36372 .16996 .36771 .17455 .3742 .17207 .37023 .16746 Mtetra
.665 .742 .907 r
.37023 .16746 .3742 .17207 .38072 .16956 .37676 .16494 Mtetra
.664 .741 .908 r
.37676 .16494 .38072 .16956 .38725 .16706 .3833 .16243 Mtetra
.3833 .16243 .38725 .16706 .3938 .16455 .38986 .15991 Mtetra
.38986 .15991 .3938 .16455 .40036 .16204 .39643 .15739 Mtetra
.39643 .15739 .40036 .16204 .40694 .15953 .40302 .15486 Mtetra
.40302 .15486 .40694 .15953 .41354 .157 .40963 .15233 Mtetra
.40963 .15233 .41354 .157 .42015 .15448 .41625 .14979 Mtetra
.41625 .14979 .42015 .15448 .42678 .15194 .42289 .14724 Mtetra
.42289 .14724 .42678 .15194 .43342 .1494 .42954 .14469 Mtetra
.42954 .14469 .43342 .1494 .44008 .14685 .43621 .14213 Mtetra
.43621 .14213 .44008 .14685 .44676 .1443 .4429 .13957 Mtetra
.4429 .13957 .44676 .1443 .45345 .14174 .4496 .137 Mtetra
.4496 .137 .45345 .14174 .46016 .13917 .45632 .13442 Mtetra
.45632 .13442 .46016 .13917 .46689 .1366 .46306 .13183 Mtetra
.46306 .13183 .46689 .1366 .47363 .13402 .46981 .12924 Mtetra
.46981 .12924 .47363 .13402 .48039 .13144 .47658 .12665 Mtetra
.47658 .12665 .48039 .13144 .48717 .12884 .48337 .12404 Mtetra
.48337 .12404 .48717 .12884 .49396 .12625 .49018 .12143 Mtetra
.49018 .12143 .49396 .12625 .50077 .12364 .497 .11882 Mtetra
.497 .11882 .50077 .12364 .5076 .12103 .50384 .11619 Mtetra
.50384 .11619 .5076 .12103 .51444 .11841 .51069 .11356 Mtetra
.51069 .11356 .51444 .11841 .52131 .11579 .51757 .11093 Mtetra
.51757 .11093 .52131 .11579 .52819 .11316 .52446 .10828 Mtetra
.52446 .10828 .52819 .11316 .53508 .11052 .53136 .10564 Mtetra
.53136 .10564 .53508 .11052 .54199 .10788 .53829 .10298 Mtetra
.53829 .10298 .54199 .10788 .54893 .10523 .54523 .10032 Mtetra
.54523 .10032 .54893 .10523 .55587 .10257 .55219 .09765 Mtetra
.55219 .09765 .55587 .10257 .56284 .09991 .55917 .09497 Mtetra
.55917 .09497 .56284 .09991 .56982 .09724 .56616 .09229 Mtetra
.56616 .09229 .56982 .09724 .57682 .09456 .57317 .0896 Mtetra
.57317 .0896 .57682 .09456 .58384 .09187 .5802 .0869 Mtetra
.5802 .0869 .58384 .09187 .59088 .08918 .58725 .0842 Mtetra
.58725 .0842 .59088 .08918 .59793 .08649 .59432 .08149 Mtetra
.59432 .08149 .59793 .08649 .605 .08378 .6014 .07877 Mtetra
.6014 .07877 .605 .08378 .61209 .08107 .60851 .07605 Mtetra
.60851 .07605 .61209 .08107 .6192 .07835 .61563 .07331 Mtetra
.61563 .07331 .6192 .07835 .62633 .07563 .62276 .07058 Mtetra
.62276 .07058 .62633 .07563 .63347 .07289 .62992 .06783 Mtetra
.62992 .06783 .63347 .07289 .64064 .07015 .6371 .06508 Mtetra
.6371 .06508 .64064 .07015 .64782 .06741 .64429 .06232 Mtetra
.64429 .06232 .64782 .06741 .65502 .06465 .6515 .05955 Mtetra
.6515 .05955 .65502 .06465 .66223 .06189 .65873 .05678 Mtetra
.65873 .05678 .66223 .06189 .66947 .05913 .66598 .054 Mtetra
.66598 .054 .66947 .05913 .67673 .05635 .67325 .05121 Mtetra
.67325 .05121 .67673 .05635 .684 .05357 .68054 .04842 Mtetra
.68054 .04842 .684 .05357 .69129 .05078 .68784 .04561 Mtetra
.68784 .04561 .69129 .05078 .6986 .04799 .69516 .04281 Mtetra
.69516 .04281 .6986 .04799 .70593 .04518 .70251 .03999 Mtetra
.70251 .03999 .70593 .04518 .71328 .04237 .70987 .03716 Mtetra
.05868 .28114 .0631 .28525 .06889 .28303 .06449 .27891 Mtetra
.06449 .27891 .06889 .28303 .0747 .2808 .07031 .27667 Mtetra
.07031 .27667 .0747 .2808 .08053 .27857 .07614 .27443 Mtetra
.07614 .27443 .08053 .27857 .08636 .27633 .08198 .27218 Mtetra
.08198 .27218 .08636 .27633 .09221 .27408 .08784 .26993 Mtetra
.08784 .26993 .09221 .27408 .09808 .27183 .09371 .26767 Mtetra
.09371 .26767 .09808 .27183 .10395 .26958 .09959 .2654 Mtetra
.09959 .2654 .10395 .26958 .10985 .26732 .10549 .26313 Mtetra
.10549 .26313 .10985 .26732 .11575 .26505 .1114 .26086 Mtetra
.1114 .26086 .11575 .26505 .12167 .26278 .11733 .25858 Mtetra
.11733 .25858 .12167 .26278 .1276 .26051 .12327 .25629 Mtetra
.12327 .25629 .1276 .26051 .13355 .25823 .12922 .254 Mtetra
.12922 .254 .13355 .25823 .13951 .25594 .13519 .25171 Mtetra
.13519 .25171 .13951 .25594 .14548 .25365 .14117 .24941 Mtetra
.14117 .24941 .14548 .25365 .15147 .25135 .14717 .2471 Mtetra
.14717 .2471 .15147 .25135 .15747 .24905 .15318 .24479 Mtetra
.15318 .24479 .15747 .24905 .16348 .24674 .1592 .24247 Mtetra
.1592 .24247 .16348 .24674 .16951 .24443 .16524 .24015 Mtetra
.16524 .24015 .16951 .24443 .17556 .24211 .17129 .23782 Mtetra
.17129 .23782 .17556 .24211 .18162 .23979 .17736 .23548 Mtetra
.17736 .23548 .18162 .23979 .18769 .23746 .18344 .23315 Mtetra
.18344 .23315 .18769 .23746 .19378 .23513 .18953 .2308 Mtetra
.18953 .2308 .19378 .23513 .19988 .23279 .19564 .22845 Mtetra
.19564 .22845 .19988 .23279 .20599 .23044 .20177 .22609 Mtetra
.20177 .22609 .20599 .23044 .21212 .22809 .20791 .22373 Mtetra
.20791 .22373 .21212 .22809 .21827 .22573 .21406 .22137 Mtetra
.21406 .22137 .21827 .22573 .22443 .22337 .22023 .21899 Mtetra
.22023 .21899 .22443 .22337 .2306 .221 .22641 .21661 Mtetra
.22641 .21661 .2306 .221 .23679 .21863 .23261 .21423 Mtetra
.23261 .21423 .23679 .21863 .24299 .21625 .23882 .21184 Mtetra
.23882 .21184 .24299 .21625 .24921 .21386 .24505 .20944 Mtetra
.24505 .20944 .24921 .21386 .25544 .21147 .25129 .20704 Mtetra
.25129 .20704 .25544 .21147 .26169 .20907 .25754 .20464 Mtetra
.25754 .20464 .26169 .20907 .26795 .20667 .26382 .20222 Mtetra
.26382 .20222 .26795 .20667 .27423 .20426 .2701 .1998 Mtetra
.2701 .1998 .27423 .20426 .28052 .20185 .2764 .19738 Mtetra
.2764 .19738 .28052 .20185 .28683 .19943 .28272 .19495 Mtetra
.28272 .19495 .28683 .19943 .29316 .19701 .28905 .19251 Mtetra
.28905 .19251 .29316 .19701 .29949 .19457 .2954 .19007 Mtetra
.2954 .19007 .29949 .19457 .30585 .19214 .30176 .18762 Mtetra
.30176 .18762 .30585 .19214 .31222 .18969 .30814 .18517 Mtetra
.30814 .18517 .31222 .18969 .3186 .18725 .31453 .18271 Mtetra
.31453 .18271 .3186 .18725 .325 .18479 .32094 .18024 Mtetra
.32094 .18024 .325 .18479 .33142 .18233 .32737 .17777 Mtetra
.32737 .17777 .33142 .18233 .33785 .17986 .33381 .17529 Mtetra
.33381 .17529 .33785 .17986 .34429 .17739 .34026 .17281 Mtetra
.34026 .17281 .34429 .17739 .35075 .17491 .34674 .17032 Mtetra
.663 .741 .908 r
.34674 .17032 .35075 .17491 .35723 .17243 .35322 .16783 Mtetra
.662 .741 .908 r
.35322 .16783 .35723 .17243 .36372 .16996 .35972 .16534 Mtetra
.664 .741 .908 r
.35972 .16534 .36372 .16996 .37023 .16746 .36624 .16283 Mtetra
.665 .742 .907 r
.36624 .16283 .37023 .16746 .37676 .16494 .37278 .1603 Mtetra
.664 .741 .908 r
.37278 .1603 .37676 .16494 .3833 .16243 .37933 .15778 Mtetra
.37933 .15778 .3833 .16243 .38986 .15991 .3859 .15525 Mtetra
.3859 .15525 .38986 .15991 .39643 .15739 .39248 .15272 Mtetra
.39248 .15272 .39643 .15739 .40302 .15486 .39908 .15018 Mtetra
.39908 .15018 .40302 .15486 .40963 .15233 .4057 .14764 Mtetra
.4057 .14764 .40963 .15233 .41625 .14979 .41233 .14509 Mtetra
.41233 .14509 .41625 .14979 .42289 .14724 .41898 .14253 Mtetra
.41898 .14253 .42289 .14724 .42954 .14469 .42564 .13996 Mtetra
.42564 .13996 .42954 .14469 .43621 .14213 .43232 .13739 Mtetra
.43232 .13739 .43621 .14213 .4429 .13957 .43902 .13482 Mtetra
.43902 .13482 .4429 .13957 .4496 .137 .44574 .13223 Mtetra
.44574 .13223 .4496 .137 .45632 .13442 .45247 .12964 Mtetra
.45247 .12964 .45632 .13442 .46306 .13183 .45921 .12705 Mtetra
.45921 .12705 .46306 .13183 .46981 .12924 .46598 .12444 Mtetra
.46598 .12444 .46981 .12924 .47658 .12665 .47276 .12184 Mtetra
.47276 .12184 .47658 .12665 .48337 .12404 .47956 .11922 Mtetra
.47956 .11922 .48337 .12404 .49018 .12143 .48637 .1166 Mtetra
.48637 .1166 .49018 .12143 .497 .11882 .49321 .11397 Mtetra
.49321 .11397 .497 .11882 .50384 .11619 .50006 .11133 Mtetra
.50006 .11133 .50384 .11619 .51069 .11356 .50692 .10869 Mtetra
.50692 .10869 .51069 .11356 .51757 .11093 .51381 .10604 Mtetra
.51381 .10604 .51757 .11093 .52446 .10828 .52071 .10339 Mtetra
.52071 .10339 .52446 .10828 .53136 .10564 .52763 .10073 Mtetra
.52763 .10073 .53136 .10564 .53829 .10298 .53456 .09806 Mtetra
.53456 .09806 .53829 .10298 .54523 .10032 .54152 .09538 Mtetra
.54152 .09538 .54523 .10032 .55219 .09765 .54849 .0927 Mtetra
.54849 .0927 .55219 .09765 .55917 .09497 .55548 .09001 Mtetra
.55548 .09001 .55917 .09497 .56616 .09229 .56248 .08732 Mtetra
.56248 .08732 .56616 .09229 .57317 .0896 .56951 .08461 Mtetra
.56951 .08461 .57317 .0896 .5802 .0869 .57655 .0819 Mtetra
.57655 .0819 .5802 .0869 .58725 .0842 .58361 .07919 Mtetra
.58361 .07919 .58725 .0842 .59432 .08149 .59069 .07646 Mtetra
.59069 .07646 .59432 .08149 .6014 .07877 .59779 .07373 Mtetra
.59779 .07373 .6014 .07877 .60851 .07605 .6049 .071 Mtetra
.6049 .071 .60851 .07605 .61563 .07331 .61203 .06825 Mtetra
.61203 .06825 .61563 .07331 .62276 .07058 .61918 .0655 Mtetra
.61918 .0655 .62276 .07058 .62992 .06783 .62635 .06274 Mtetra
.62635 .06274 .62992 .06783 .6371 .06508 .63354 .05998 Mtetra
.63354 .05998 .6371 .06508 .64429 .06232 .64075 .05721 Mtetra
.64075 .05721 .64429 .06232 .6515 .05955 .64797 .05443 Mtetra
.64797 .05443 .6515 .05955 .65873 .05678 .65521 .05164 Mtetra
.65521 .05164 .65873 .05678 .66598 .054 .66247 .04885 Mtetra
.66247 .04885 .66598 .054 .67325 .05121 .66976 .04605 Mtetra
.66976 .04605 .67325 .05121 .68054 .04842 .67705 .04324 Mtetra
.67705 .04324 .68054 .04842 .68784 .04561 .68437 .04042 Mtetra
.68437 .04042 .68784 .04561 .69516 .04281 .69171 .0376 Mtetra
.69171 .0376 .69516 .04281 .70251 .03999 .69907 .03477 Mtetra
.69907 .03477 .70251 .03999 .70987 .03716 .70644 .03193 Mtetra
.05425 .27702 .05868 .28114 .06449 .27891 .06006 .27477 Mtetra
.06006 .27477 .06449 .27891 .07031 .27667 .06589 .27253 Mtetra
.06589 .27253 .07031 .27667 .07614 .27443 .07173 .27027 Mtetra
.07173 .27027 .07614 .27443 .08198 .27218 .07758 .26802 Mtetra
.07758 .26802 .08198 .27218 .08784 .26993 .08344 .26575 Mtetra
.08344 .26575 .08784 .26993 .09371 .26767 .08932 .26348 Mtetra
.08932 .26348 .09371 .26767 .09959 .2654 .09521 .26121 Mtetra
.09521 .26121 .09959 .2654 .10549 .26313 .10112 .25893 Mtetra
.10112 .25893 .10549 .26313 .1114 .26086 .10704 .25665 Mtetra
.10704 .25665 .1114 .26086 .11733 .25858 .11297 .25436 Mtetra
.11297 .25436 .11733 .25858 .12327 .25629 .11892 .25206 Mtetra
.11892 .25206 .12327 .25629 .12922 .254 .12488 .24976 Mtetra
.12488 .24976 .12922 .254 .13519 .25171 .13086 .24746 Mtetra
.13086 .24746 .13519 .25171 .14117 .24941 .13685 .24514 Mtetra
.13685 .24514 .14117 .24941 .14717 .2471 .14285 .24283 Mtetra
.14285 .24283 .14717 .2471 .15318 .24479 .14887 .24051 Mtetra
.14887 .24051 .15318 .24479 .1592 .24247 .1549 .23818 Mtetra
.1549 .23818 .1592 .24247 .16524 .24015 .16095 .23584 Mtetra
.16095 .23584 .16524 .24015 .17129 .23782 .16701 .23351 Mtetra
.16701 .23351 .17129 .23782 .17736 .23548 .17308 .23116 Mtetra
.17308 .23116 .17736 .23548 .18344 .23315 .17917 .22881 Mtetra
.17917 .22881 .18344 .23315 .18953 .2308 .18527 .22646 Mtetra
.18527 .22646 .18953 .2308 .19564 .22845 .19139 .2241 Mtetra
.19139 .2241 .19564 .22845 .20177 .22609 .19752 .22173 Mtetra
.19752 .22173 .20177 .22609 .20791 .22373 .20367 .21936 Mtetra
.20367 .21936 .20791 .22373 .21406 .22137 .20983 .21698 Mtetra
.20983 .21698 .21406 .22137 .22023 .21899 .21601 .2146 Mtetra
.21601 .2146 .22023 .21899 .22641 .21661 .2222 .21221 Mtetra
.2222 .21221 .22641 .21661 .23261 .21423 .2284 .20981 Mtetra
.2284 .20981 .23261 .21423 .23882 .21184 .23463 .20741 Mtetra
.23463 .20741 .23882 .21184 .24505 .20944 .24086 .20501 Mtetra
.24086 .20501 .24505 .20944 .25129 .20704 .24711 .20259 Mtetra
.24711 .20259 .25129 .20704 .25754 .20464 .25338 .20018 Mtetra
.25338 .20018 .25754 .20464 .26382 .20222 .25966 .19775 Mtetra
.25966 .19775 .26382 .20222 .2701 .1998 .26595 .19532 Mtetra
.26595 .19532 .2701 .1998 .2764 .19738 .27226 .19289 Mtetra
.27226 .19289 .2764 .19738 .28272 .19495 .27859 .19045 Mtetra
.27859 .19045 .28272 .19495 .28905 .19251 .28493 .188 Mtetra
.28493 .188 .28905 .19251 .2954 .19007 .29129 .18555 Mtetra
.29129 .18555 .2954 .19007 .30176 .18762 .29766 .18309 Mtetra
.29766 .18309 .30176 .18762 .30814 .18517 .30405 .18062 Mtetra
.30405 .18062 .30814 .18517 .31453 .18271 .31045 .17815 Mtetra
.31045 .17815 .31453 .18271 .32094 .18024 .31687 .17568 Mtetra
.31687 .17568 .32094 .18024 .32737 .17777 .3233 .17319 Mtetra
.3233 .17319 .32737 .17777 .33381 .17529 .32975 .1707 Mtetra
.32975 .1707 .33381 .17529 .34026 .17281 .33622 .16821 Mtetra
.33622 .16821 .34026 .17281 .34674 .17032 .3427 .16571 Mtetra
.663 .741 .908 r
.3427 .16571 .34674 .17032 .35322 .16783 .3492 .1632 Mtetra
.3492 .1632 .35322 .16783 .35972 .16534 .35571 .16071 Mtetra
.664 .741 .908 r
.35571 .16071 .35972 .16534 .36624 .16283 .36224 .15819 Mtetra
.665 .742 .907 r
.36224 .15819 .36624 .16283 .37278 .1603 .36878 .15564 Mtetra
.664 .741 .908 r
.36878 .15564 .37278 .1603 .37933 .15778 .37534 .15311 Mtetra
.37534 .15311 .37933 .15778 .3859 .15525 .38192 .15057 Mtetra
.38192 .15057 .3859 .15525 .39248 .15272 .38851 .14803 Mtetra
.38851 .14803 .39248 .15272 .39908 .15018 .39512 .14548 Mtetra
.39512 .14548 .39908 .15018 .4057 .14764 .40175 .14292 Mtetra
.40175 .14292 .4057 .14764 .41233 .14509 .40839 .14036 Mtetra
.40839 .14036 .41233 .14509 .41898 .14253 .41505 .13779 Mtetra
.41505 .13779 .41898 .14253 .42564 .13996 .42173 .13521 Mtetra
.42173 .13521 .42564 .13996 .43232 .13739 .42842 .13263 Mtetra
.42842 .13263 .43232 .13739 .43902 .13482 .43513 .13004 Mtetra
.43513 .13004 .43902 .13482 .44574 .13223 .44185 .12745 Mtetra
.44185 .12745 .44574 .13223 .45247 .12964 .44859 .12485 Mtetra
.44859 .12485 .45247 .12964 .45921 .12705 .45535 .12224 Mtetra
.45535 .12224 .45921 .12705 .46598 .12444 .46213 .11962 Mtetra
.46213 .11962 .46598 .12444 .47276 .12184 .46892 .117 Mtetra
.46892 .117 .47276 .12184 .47956 .11922 .47573 .11437 Mtetra
.47573 .11437 .47956 .11922 .48637 .1166 .48255 .11174 Mtetra
.48255 .11174 .48637 .1166 .49321 .11397 .4894 .1091 Mtetra
.4894 .1091 .49321 .11397 .50006 .11133 .49626 .10645 Mtetra
.49626 .10645 .50006 .11133 .50692 .10869 .50314 .1038 Mtetra
.50314 .1038 .50692 .10869 .51381 .10604 .51003 .10114 Mtetra
.51003 .10114 .51381 .10604 .52071 .10339 .51694 .09847 Mtetra
.51694 .09847 .52071 .10339 .52763 .10073 .52387 .09579 Mtetra
.52387 .09579 .52763 .10073 .53456 .09806 .53082 .09311 Mtetra
.53082 .09311 .53456 .09806 .54152 .09538 .53779 .09043 Mtetra
.53779 .09043 .54152 .09538 .54849 .0927 .54477 .08773 Mtetra
.54477 .08773 .54849 .0927 .55548 .09001 .55177 .08503 Mtetra
.55177 .08503 .55548 .09001 .56248 .08732 .55879 .08232 Mtetra
.55879 .08232 .56248 .08732 .56951 .08461 .56583 .07961 Mtetra
.56583 .07961 .56951 .08461 .57655 .0819 .57288 .07688 Mtetra
.57288 .07688 .57655 .0819 .58361 .07919 .57995 .07416 Mtetra
.57995 .07416 .58361 .07919 .59069 .07646 .58704 .07142 Mtetra
.58704 .07142 .59069 .07646 .59779 .07373 .59415 .06868 Mtetra
.59415 .06868 .59779 .07373 .6049 .071 .60128 .06593 Mtetra
.60128 .06593 .6049 .071 .61203 .06825 .60842 .06317 Mtetra
.60842 .06317 .61203 .06825 .61918 .0655 .61558 .06041 Mtetra
.61558 .06041 .61918 .0655 .62635 .06274 .62277 .05763 Mtetra
.62277 .05763 .62635 .06274 .63354 .05998 .62997 .05486 Mtetra
.62997 .05486 .63354 .05998 .64075 .05721 .63718 .05207 Mtetra
.63718 .05207 .64075 .05721 .64797 .05443 .64442 .04928 Mtetra
.64442 .04928 .64797 .05443 .65521 .05164 .65168 .04648 Mtetra
.65168 .04648 .65521 .05164 .66247 .04885 .65895 .04367 Mtetra
.65895 .04367 .66247 .04885 .66976 .04605 .66624 .04086 Mtetra
.66624 .04086 .66976 .04605 .67705 .04324 .67356 .03803 Mtetra
.67356 .03803 .67705 .04324 .68437 .04042 .68089 .03521 Mtetra
.68089 .03521 .68437 .04042 .69171 .0376 .68824 .03237 Mtetra
.68824 .03237 .69171 .0376 .69907 .03477 .69561 .02952 Mtetra
.69561 .02952 .69907 .03477 .70644 .03193 .703 .02667 Mtetra
.0498 .27287 .05425 .27702 .06006 .27477 .05562 .27062 Mtetra
.05562 .27062 .06006 .27477 .06589 .27253 .06145 .26836 Mtetra
.06145 .26836 .06589 .27253 .07173 .27027 .0673 .2661 Mtetra
.0673 .2661 .07173 .27027 .07758 .26802 .07316 .26383 Mtetra
.07316 .26383 .07758 .26802 .08344 .26575 .07903 .26156 Mtetra
.07903 .26156 .08344 .26575 .08932 .26348 .08492 .25928 Mtetra
.08492 .25928 .08932 .26348 .09521 .26121 .09082 .257 Mtetra
.09082 .257 .09521 .26121 .10112 .25893 .09673 .25471 Mtetra
.09673 .25471 .10112 .25893 .10704 .25665 .10266 .25241 Mtetra
.10266 .25241 .10704 .25665 .11297 .25436 .1086 .25012 Mtetra
.1086 .25012 .11297 .25436 .11892 .25206 .11455 .24781 Mtetra
.11455 .24781 .11892 .25206 .12488 .24976 .12052 .2455 Mtetra
.12052 .2455 .12488 .24976 .13086 .24746 .12651 .24318 Mtetra
.12651 .24318 .13086 .24746 .13685 .24514 .1325 .24086 Mtetra
.1325 .24086 .13685 .24514 .14285 .24283 .13851 .23854 Mtetra
.13851 .23854 .14285 .24283 .14887 .24051 .14454 .2362 Mtetra
.14454 .2362 .14887 .24051 .1549 .23818 .15058 .23387 Mtetra
.15058 .23387 .1549 .23818 .16095 .23584 .15663 .23152 Mtetra
.15663 .23152 .16095 .23584 .16701 .23351 .1627 .22917 Mtetra
.1627 .22917 .16701 .23351 .17308 .23116 .16878 .22682 Mtetra
.16878 .22682 .17308 .23116 .17917 .22881 .17488 .22446 Mtetra
.17488 .22446 .17917 .22881 .18527 .22646 .18099 .22209 Mtetra
.18099 .22209 .18527 .22646 .19139 .2241 .18712 .21972 Mtetra
.18712 .21972 .19139 .2241 .19752 .22173 .19326 .21735 Mtetra
.19326 .21735 .19752 .22173 .20367 .21936 .19942 .21496 Mtetra
.19942 .21496 .20367 .21936 .20983 .21698 .20559 .21258 Mtetra
.20559 .21258 .20983 .21698 .21601 .2146 .21177 .21018 Mtetra
.21177 .21018 .21601 .2146 .2222 .21221 .21797 .20778 Mtetra
.21797 .20778 .2222 .21221 .2284 .20981 .22418 .20538 Mtetra
.22418 .20538 .2284 .20981 .23463 .20741 .23041 .20297 Mtetra
.23041 .20297 .23463 .20741 .24086 .20501 .23666 .20055 Mtetra
.23666 .20055 .24086 .20501 .24711 .20259 .24292 .19813 Mtetra
.24292 .19813 .24711 .20259 .25338 .20018 .24919 .1957 Mtetra
.24919 .1957 .25338 .20018 .25966 .19775 .25548 .19326 Mtetra
.25548 .19326 .25966 .19775 .26595 .19532 .26179 .19082 Mtetra
.26179 .19082 .26595 .19532 .27226 .19289 .26811 .18838 Mtetra
.26811 .18838 .27226 .19289 .27859 .19045 .27444 .18592 Mtetra
.27444 .18592 .27859 .19045 .28493 .188 .28079 .18347 Mtetra
.28079 .18347 .28493 .188 .29129 .18555 .28716 .181 Mtetra
.28716 .181 .29129 .18555 .29766 .18309 .29354 .17853 Mtetra
.29354 .17853 .29766 .18309 .30405 .18062 .29993 .17606 Mtetra
.29993 .17606 .30405 .18062 .31045 .17815 .30635 .17358 Mtetra
.30635 .17358 .31045 .17815 .31687 .17568 .31278 .17109 Mtetra
.31278 .17109 .31687 .17568 .3233 .17319 .31922 .16859 Mtetra
.31922 .16859 .3233 .17319 .32975 .1707 .32568 .16609 Mtetra
.32568 .16609 .32975 .1707 .33622 .16821 .33215 .16359 Mtetra
.33215 .16359 .33622 .16821 .3427 .16571 .33864 .16108 Mtetra
.663 .741 .908 r
.33864 .16108 .3427 .16571 .3492 .1632 .34515 .15856 Mtetra
.34515 .15856 .3492 .1632 .35571 .16071 .35167 .15605 Mtetra
.664 .741 .908 r
.35167 .15605 .35571 .16071 .36224 .15819 .35821 .15352 Mtetra
.665 .742 .907 r
.35821 .15352 .36224 .15819 .36878 .15564 .36477 .15097 Mtetra
.664 .741 .908 r
.36477 .15097 .36878 .15564 .37534 .15311 .37134 .14842 Mtetra
.37134 .14842 .37534 .15311 .38192 .15057 .37793 .14587 Mtetra
.37793 .14587 .38192 .15057 .38851 .14803 .38453 .14332 Mtetra
.38453 .14332 .38851 .14803 .39512 .14548 .39115 .14075 Mtetra
.39115 .14075 .39512 .14548 .40175 .14292 .39778 .13818 Mtetra
.39778 .13818 .40175 .14292 .40839 .14036 .40444 .13561 Mtetra
.40444 .13561 .40839 .14036 .41505 .13779 .41111 .13303 Mtetra
.41111 .13303 .41505 .13779 .42173 .13521 .41779 .13044 Mtetra
.41779 .13044 .42173 .13521 .42842 .13263 .42449 .12785 Mtetra
.42449 .12785 .42842 .13263 .43513 .13004 .43121 .12525 Mtetra
.43121 .12525 .43513 .13004 .44185 .12745 .43795 .12264 Mtetra
.43795 .12264 .44185 .12745 .44859 .12485 .4447 .12003 Mtetra
.4447 .12003 .44859 .12485 .45535 .12224 .45147 .11741 Mtetra
.45147 .11741 .45535 .12224 .46213 .11962 .45826 .11478 Mtetra
.45826 .11478 .46213 .11962 .46892 .117 .46506 .11215 Mtetra
.46506 .11215 .46892 .117 .47573 .11437 .47188 .10951 Mtetra
.47188 .10951 .47573 .11437 .48255 .11174 .47872 .10686 Mtetra
.47872 .10686 .48255 .11174 .4894 .1091 .48557 .10421 Mtetra
.48557 .10421 .4894 .1091 .49626 .10645 .49244 .10155 Mtetra
.49244 .10155 .49626 .10645 .50314 .1038 .49933 .09888 Mtetra
.49933 .09888 .50314 .1038 .51003 .10114 .50624 .09621 Mtetra
.50624 .09621 .51003 .10114 .51694 .09847 .51316 .09353 Mtetra
.51316 .09353 .51694 .09847 .52387 .09579 .5201 .09084 Mtetra
.5201 .09084 .52387 .09579 .53082 .09311 .52706 .08815 Mtetra
.52706 .08815 .53082 .09311 .53779 .09043 .53404 .08545 Mtetra
.53404 .08545 .53779 .09043 .54477 .08773 .54103 .08274 Mtetra
.54103 .08274 .54477 .08773 .55177 .08503 .54805 .08002 Mtetra
.54805 .08002 .55177 .08503 .55879 .08232 .55508 .0773 Mtetra
.55508 .0773 .55879 .08232 .56583 .07961 .56212 .07458 Mtetra
.56212 .07458 .56583 .07961 .57288 .07688 .56919 .07184 Mtetra
.56919 .07184 .57288 .07688 .57995 .07416 .57627 .0691 Mtetra
.57627 .0691 .57995 .07416 .58704 .07142 .58338 .06635 Mtetra
.58338 .06635 .58704 .07142 .59415 .06868 .5905 .06359 Mtetra
.5905 .06359 .59415 .06868 .60128 .06593 .59764 .06083 Mtetra
.59764 .06083 .60128 .06593 .60842 .06317 .60479 .05806 Mtetra
.60479 .05806 .60842 .06317 .61558 .06041 .61197 .05528 Mtetra
.61197 .05528 .61558 .06041 .62277 .05763 .61916 .0525 Mtetra
.61916 .0525 .62277 .05763 .62997 .05486 .62637 .04971 Mtetra
.62637 .04971 .62997 .05486 .63718 .05207 .63361 .04691 Mtetra
.63361 .04691 .63718 .05207 .64442 .04928 .64086 .0441 Mtetra
.64086 .0441 .64442 .04928 .65168 .04648 .64812 .04129 Mtetra
.64812 .04129 .65168 .04648 .65895 .04367 .65541 .03847 Mtetra
.65541 .03847 .65895 .04367 .66624 .04086 .66272 .03564 Mtetra
.66272 .03564 .66624 .04086 .67356 .03803 .67004 .03281 Mtetra
.67004 .03281 .67356 .03803 .68089 .03521 .67739 .02996 Mtetra
.67739 .02996 .68089 .03521 .68824 .03237 .68475 .02711 Mtetra
.68475 .02711 .68824 .03237 .69561 .02952 .69213 .02426 Mtetra
.69213 .02426 .69561 .02952 .703 .02667 .69953 .02139 Mtetra
.04533 .26871 .0498 .27287 .05562 .27062 .05116 .26645 Mtetra
.05116 .26645 .05562 .27062 .06145 .26836 .057 .26418 Mtetra
.057 .26418 .06145 .26836 .0673 .2661 .06285 .26191 Mtetra
.06285 .26191 .0673 .2661 .07316 .26383 .06872 .25963 Mtetra
.06872 .25963 .07316 .26383 .07903 .26156 .0746 .25735 Mtetra
.0746 .25735 .07903 .26156 .08492 .25928 .08049 .25506 Mtetra
.08049 .25506 .08492 .25928 .09082 .257 .0864 .25277 Mtetra
.0864 .25277 .09082 .257 .09673 .25471 .09232 .25047 Mtetra
.09232 .25047 .09673 .25471 .10266 .25241 .09825 .24817 Mtetra
.09825 .24817 .10266 .25241 .1086 .25012 .1042 .24586 Mtetra
.1042 .24586 .1086 .25012 .11455 .24781 .11017 .24354 Mtetra
.11017 .24354 .11455 .24781 .12052 .2455 .11614 .24122 Mtetra
.11614 .24122 .12052 .2455 .12651 .24318 .12213 .23889 Mtetra
.12213 .23889 .12651 .24318 .1325 .24086 .12814 .23656 Mtetra
.12814 .23656 .1325 .24086 .13851 .23854 .13416 .23423 Mtetra
.13416 .23423 .13851 .23854 .14454 .2362 .14019 .23188 Mtetra
.14019 .23188 .14454 .2362 .15058 .23387 .14624 .22954 Mtetra
.14624 .22954 .15058 .23387 .15663 .23152 .1523 .22718 Mtetra
.1523 .22718 .15663 .23152 .1627 .22917 .15838 .22482 Mtetra
.15838 .22482 .1627 .22917 .16878 .22682 .16447 .22246 Mtetra
.16447 .22246 .16878 .22682 .17488 .22446 .17058 .22009 Mtetra
.17058 .22009 .17488 .22446 .18099 .22209 .1767 .21771 Mtetra
.1767 .21771 .18099 .22209 .18712 .21972 .18283 .21533 Mtetra
.18283 .21533 .18712 .21972 .19326 .21735 .18898 .21294 Mtetra
.18898 .21294 .19326 .21735 .19942 .21496 .19514 .21055 Mtetra
.19514 .21055 .19942 .21496 .20559 .21258 .20132 .20815 Mtetra
.20132 .20815 .20559 .21258 .21177 .21018 .20751 .20575 Mtetra
.20751 .20575 .21177 .21018 .21797 .20778 .21372 .20334 Mtetra
.21372 .20334 .21797 .20778 .22418 .20538 .21995 .20092 Mtetra
.21995 .20092 .22418 .20538 .23041 .20297 .22618 .1985 Mtetra
.22618 .1985 .23041 .20297 .23666 .20055 .23244 .19607 Mtetra
.23244 .19607 .23666 .20055 .24292 .19813 .23871 .19364 Mtetra
.23871 .19364 .24292 .19813 .24919 .1957 .24499 .1912 Mtetra
.24499 .1912 .24919 .1957 .25548 .19326 .25129 .18875 Mtetra
.25129 .18875 .25548 .19326 .26179 .19082 .2576 .1863 Mtetra
.2576 .1863 .26179 .19082 .26811 .18838 .26393 .18385 Mtetra
.26393 .18385 .26811 .18838 .27444 .18592 .27027 .18138 Mtetra
.27027 .18138 .27444 .18592 .28079 .18347 .27663 .17891 Mtetra
.27663 .17891 .28079 .18347 .28716 .181 .28301 .17644 Mtetra
.28301 .17644 .28716 .181 .29354 .17853 .2894 .17396 Mtetra
.2894 .17396 .29354 .17853 .29993 .17606 .2958 .17147 Mtetra
.2958 .17147 .29993 .17606 .30635 .17358 .30223 .16898 Mtetra
.30223 .16898 .30635 .17358 .31278 .17109 .30866 .16648 Mtetra
.30866 .16648 .31278 .17109 .31922 .16859 .31512 .16397 Mtetra
.31512 .16397 .31922 .16859 .32568 .16609 .32159 .16146 Mtetra
.32159 .16146 .32568 .16609 .33215 .16359 .32807 .15894 Mtetra
.32807 .15894 .33215 .16359 .33864 .16108 .33457 .15642 Mtetra
.663 .741 .908 r
.33457 .15642 .33864 .16108 .34515 .15856 .34109 .15389 Mtetra
.34109 .15389 .34515 .15856 .35167 .15605 .34762 .15137 Mtetra
.664 .741 .908 r
.34762 .15137 .35167 .15605 .35821 .15352 .35417 .14883 Mtetra
.665 .742 .908 r
.35417 .14883 .35821 .15352 .36477 .15097 .36073 .14627 Mtetra
.664 .741 .908 r
.36073 .14627 .36477 .15097 .37134 .14842 .36731 .14371 Mtetra
.36731 .14371 .37134 .14842 .37793 .14587 .37391 .14115 Mtetra
.37391 .14115 .37793 .14587 .38453 .14332 .38052 .13858 Mtetra
.38052 .13858 .38453 .14332 .39115 .14075 .38715 .13601 Mtetra
.38715 .13601 .39115 .14075 .39778 .13818 .3938 .13343 Mtetra
.3938 .13343 .39778 .13818 .40444 .13561 .40046 .13084 Mtetra
.40046 .13084 .40444 .13561 .41111 .13303 .40714 .12825 Mtetra
.40714 .12825 .41111 .13303 .41779 .13044 .41384 .12565 Mtetra
.41384 .12565 .41779 .13044 .42449 .12785 .42055 .12304 Mtetra
.42055 .12304 .42449 .12785 .43121 .12525 .42728 .12043 Mtetra
.42728 .12043 .43121 .12525 .43795 .12264 .43403 .11781 Mtetra
.43403 .11781 .43795 .12264 .4447 .12003 .44079 .11518 Mtetra
.44079 .11518 .4447 .12003 .45147 .11741 .44757 .11255 Mtetra
.44757 .11255 .45147 .11741 .45826 .11478 .45437 .10991 Mtetra
.45437 .10991 .45826 .11478 .46506 .11215 .46118 .10727 Mtetra
.46118 .10727 .46506 .11215 .47188 .10951 .46801 .10461 Mtetra
.46801 .10461 .47188 .10951 .47872 .10686 .47486 .10196 Mtetra
.47486 .10196 .47872 .10686 .48557 .10421 .48173 .09929 Mtetra
.48173 .09929 .48557 .10421 .49244 .10155 .48861 .09662 Mtetra
.48861 .09662 .49244 .10155 .49933 .09888 .49551 .09394 Mtetra
.49551 .09394 .49933 .09888 .50624 .09621 .50243 .09125 Mtetra
.50243 .09125 .50624 .09621 .51316 .09353 .50936 .08856 Mtetra
.50936 .08856 .51316 .09353 .5201 .09084 .51632 .08586 Mtetra
.51632 .08586 .5201 .09084 .52706 .08815 .52329 .08316 Mtetra
.52329 .08316 .52706 .08815 .53404 .08545 .53028 .08044 Mtetra
.53028 .08044 .53404 .08545 .54103 .08274 .53728 .07772 Mtetra
.53728 .07772 .54103 .08274 .54805 .08002 .54431 .075 Mtetra
.54431 .075 .54805 .08002 .55508 .0773 .55135 .07226 Mtetra
.55135 .07226 .55508 .0773 .56212 .07458 .55841 .06952 Mtetra
.55841 .06952 .56212 .07458 .56919 .07184 .56548 .06677 Mtetra
.56548 .06677 .56919 .07184 .57627 .0691 .57258 .06402 Mtetra
.57258 .06402 .57627 .0691 .58338 .06635 .5797 .06126 Mtetra
.5797 .06126 .58338 .06635 .5905 .06359 .58683 .05849 Mtetra
.58683 .05849 .5905 .06359 .59764 .06083 .59398 .05571 Mtetra
.59398 .05571 .59764 .06083 .60479 .05806 .60115 .05293 Mtetra
.60115 .05293 .60479 .05806 .61197 .05528 .60834 .05014 Mtetra
.60834 .05014 .61197 .05528 .61916 .0525 .61554 .04734 Mtetra
.61554 .04734 .61916 .0525 .62637 .04971 .62277 .04453 Mtetra
.62277 .04453 .62637 .04971 .63361 .04691 .63001 .04172 Mtetra
.63001 .04172 .63361 .04691 .64086 .0441 .63727 .0389 Mtetra
.63727 .0389 .64086 .0441 .64812 .04129 .64455 .03608 Mtetra
.64455 .03608 .64812 .04129 .65541 .03847 .65185 .03324 Mtetra
.65185 .03324 .65541 .03847 .66272 .03564 .65917 .0304 Mtetra
.65917 .0304 .66272 .03564 .67004 .03281 .66651 .02755 Mtetra
.66651 .02755 .67004 .03281 .67739 .02996 .67387 .0247 Mtetra
.67387 .0247 .67739 .02996 .68475 .02711 .68125 .02183 Mtetra
.68125 .02183 .68475 .02711 .69213 .02426 .68864 .01896 Mtetra
.68864 .01896 .69213 .02426 .69953 .02139 .69606 .01608 Mtetra
.04084 .26453 .04533 .26871 .05116 .26645 .04668 .26226 Mtetra
.04668 .26226 .05116 .26645 .057 .26418 .05252 .25998 Mtetra
.05252 .25998 .057 .26418 .06285 .26191 .05838 .2577 Mtetra
.05838 .2577 .06285 .26191 .06872 .25963 .06426 .25541 Mtetra
.06426 .25541 .06872 .25963 .0746 .25735 .07014 .25312 Mtetra
.07014 .25312 .0746 .25735 .08049 .25506 .07605 .25082 Mtetra
.07605 .25082 .08049 .25506 .0864 .25277 .08196 .24852 Mtetra
.08196 .24852 .0864 .25277 .09232 .25047 .08789 .24621 Mtetra
.08789 .24621 .09232 .25047 .09825 .24817 .09383 .2439 Mtetra
.09383 .2439 .09825 .24817 .1042 .24586 .09979 .24158 Mtetra
.09979 .24158 .1042 .24586 .11017 .24354 .10576 .23925 Mtetra
.10576 .23925 .11017 .24354 .11614 .24122 .11174 .23692 Mtetra
.11174 .23692 .11614 .24122 .12213 .23889 .11774 .23459 Mtetra
.11774 .23459 .12213 .23889 .12814 .23656 .12376 .23224 Mtetra
.12376 .23224 .12814 .23656 .13416 .23423 .12978 .2299 Mtetra
.12978 .2299 .13416 .23423 .14019 .23188 .13583 .22754 Mtetra
.13583 .22754 .14019 .23188 .14624 .22954 .14188 .22519 Mtetra
.14188 .22519 .14624 .22954 .1523 .22718 .14795 .22282 Mtetra
.14795 .22282 .1523 .22718 .15838 .22482 .15404 .22045 Mtetra
.15404 .22045 .15838 .22482 .16447 .22246 .16014 .21808 Mtetra
.16014 .21808 .16447 .22246 .17058 .22009 .16625 .2157 Mtetra
.16625 .2157 .17058 .22009 .1767 .21771 .17238 .21331 Mtetra
.17238 .21331 .1767 .21771 .18283 .21533 .17852 .21092 Mtetra
.17852 .21092 .18283 .21533 .18898 .21294 .18468 .20852 Mtetra
.18468 .20852 .18898 .21294 .19514 .21055 .19085 .20612 Mtetra
.19085 .20612 .19514 .21055 .20132 .20815 .19704 .20371 Mtetra
.19704 .20371 .20132 .20815 .20751 .20575 .20324 .20129 Mtetra
.20324 .20129 .20751 .20575 .21372 .20334 .20946 .19887 Mtetra
.20946 .19887 .21372 .20334 .21995 .20092 .21569 .19645 Mtetra
.21569 .19645 .21995 .20092 .22618 .1985 .22194 .19401 Mtetra
.22194 .19401 .22618 .1985 .23244 .19607 .2282 .19157 Mtetra
.2282 .19157 .23244 .19607 .23871 .19364 .23447 .18913 Mtetra
.23447 .18913 .23871 .19364 .24499 .1912 .24077 .18668 Mtetra
.24077 .18668 .24499 .1912 .25129 .18875 .24707 .18422 Mtetra
.24707 .18422 .25129 .18875 .2576 .1863 .2534 .18176 Mtetra
.2534 .18176 .2576 .1863 .26393 .18385 .25973 .17929 Mtetra
.25973 .17929 .26393 .18385 .27027 .18138 .26609 .17682 Mtetra
.26609 .17682 .27027 .18138 .27663 .17891 .27246 .17434 Mtetra
.27246 .17434 .27663 .17891 .28301 .17644 .27884 .17185 Mtetra
.27884 .17185 .28301 .17644 .2894 .17396 .28524 .16936 Mtetra
.28524 .16936 .2894 .17396 .2958 .17147 .29166 .16686 Mtetra
.29166 .16686 .2958 .17147 .30223 .16898 .29809 .16436 Mtetra
.29809 .16436 .30223 .16898 .30866 .16648 .30453 .16185 Mtetra
.30453 .16185 .30866 .16648 .31512 .16397 .311 .15933 Mtetra
.311 .15933 .31512 .16397 .32159 .16146 .31747 .15681 Mtetra
.31747 .15681 .32159 .16146 .32807 .15894 .32397 .15428 Mtetra
.32397 .15428 .32807 .15894 .33457 .15642 .33048 .15175 Mtetra
.663 .741 .908 r
.33048 .15175 .33457 .15642 .34109 .15389 .337 .14921 Mtetra
.337 .14921 .34109 .15389 .34762 .15137 .34355 .14667 Mtetra
.664 .741 .908 r
.34355 .14667 .34762 .15137 .35417 .14883 .3501 .14412 Mtetra
.664 .742 .908 r
.3501 .14412 .35417 .14883 .36073 .14627 .35668 .14154 Mtetra
.664 .741 .908 r
.35668 .14154 .36073 .14627 .36731 .14371 .36327 .13898 Mtetra
.36327 .13898 .36731 .14371 .37391 .14115 .36988 .1364 Mtetra
.36988 .1364 .37391 .14115 .38052 .13858 .3765 .13382 Mtetra
.3765 .13382 .38052 .13858 .38715 .13601 .38314 .13124 Mtetra
.38314 .13124 .38715 .13601 .3938 .13343 .3898 .12865 Mtetra
.3898 .12865 .3938 .13343 .40046 .13084 .39647 .12605 Mtetra
.39647 .12605 .40046 .13084 .40714 .12825 .40316 .12344 Mtetra
.40316 .12344 .40714 .12825 .41384 .12565 .40987 .12083 Mtetra
.40987 .12083 .41384 .12565 .42055 .12304 .41659 .11821 Mtetra
.41659 .11821 .42055 .12304 .42728 .12043 .42333 .11559 Mtetra
.42333 .11559 .42728 .12043 .43403 .11781 .43009 .11296 Mtetra
.43009 .11296 .43403 .11781 .44079 .11518 .43686 .11032 Mtetra
.43686 .11032 .44079 .11518 .44757 .11255 .44365 .10767 Mtetra
.44365 .10767 .44757 .11255 .45437 .10991 .45046 .10502 Mtetra
.45046 .10502 .45437 .10991 .46118 .10727 .45729 .10237 Mtetra
.45729 .10237 .46118 .10727 .46801 .10461 .46413 .0997 Mtetra
.46413 .0997 .46801 .10461 .47486 .10196 .47099 .09703 Mtetra
.47099 .09703 .47486 .10196 .48173 .09929 .47786 .09435 Mtetra
.47786 .09435 .48173 .09929 .48861 .09662 .48476 .09167 Mtetra
.48476 .09167 .48861 .09662 .49551 .09394 .49167 .08898 Mtetra
.49167 .08898 .49551 .09394 .50243 .09125 .4986 .08628 Mtetra
.4986 .08628 .50243 .09125 .50936 .08856 .50555 .08357 Mtetra
.50555 .08357 .50936 .08856 .51632 .08586 .51251 .08086 Mtetra
.51251 .08086 .51632 .08586 .52329 .08316 .51949 .07814 Mtetra
.51949 .07814 .52329 .08316 .53028 .08044 .52649 .07542 Mtetra
.52649 .07542 .53028 .08044 .53728 .07772 .53351 .07268 Mtetra
.53351 .07268 .53728 .07772 .54431 .075 .54055 .06994 Mtetra
.54055 .06994 .54431 .075 .55135 .07226 .5476 .0672 Mtetra
.5476 .0672 .55135 .07226 .55841 .06952 .55467 .06444 Mtetra
.55467 .06444 .55841 .06952 .56548 .06677 .56176 .06168 Mtetra
.56176 .06168 .56548 .06677 .57258 .06402 .56887 .05891 Mtetra
.56887 .05891 .57258 .06402 .5797 .06126 .576 .05614 Mtetra
.576 .05614 .5797 .06126 .58683 .05849 .58314 .05336 Mtetra
.58314 .05336 .58683 .05849 .59398 .05571 .5903 .05057 Mtetra
.5903 .05057 .59398 .05571 .60115 .05293 .59749 .04777 Mtetra
.59749 .04777 .60115 .05293 .60834 .05014 .60469 .04497 Mtetra
.60469 .04497 .60834 .05014 .61554 .04734 .6119 .04216 Mtetra
.6119 .04216 .61554 .04734 .62277 .04453 .61914 .03934 Mtetra
.61914 .03934 .62277 .04453 .63001 .04172 .6264 .03651 Mtetra
.6264 .03651 .63001 .04172 .63727 .0389 .63367 .03368 Mtetra
.63367 .03368 .63727 .0389 .64455 .03608 .64097 .03084 Mtetra
.64097 .03084 .64455 .03608 .65185 .03324 .64828 .02799 Mtetra
.64828 .02799 .65185 .03324 .65917 .0304 .65561 .02514 Mtetra
.65561 .02514 .65917 .0304 .66651 .02755 .66296 .02227 Mtetra
.66296 .02227 .66651 .02755 .67387 .0247 .67033 .0194 Mtetra
.67033 .0194 .67387 .0247 .68125 .02183 .67772 .01652 Mtetra
.67772 .01652 .68125 .02183 .68864 .01896 .68513 .01364 Mtetra
.68513 .01364 .68864 .01896 .69606 .01608 .69256 .01075 Mtetra
.03634 .26033 .04084 .26453 .04668 .26226 .04218 .25805 Mtetra
.04218 .25805 .04668 .26226 .05252 .25998 .04803 .25577 Mtetra
.04803 .25577 .05252 .25998 .05838 .2577 .0539 .25347 Mtetra
.0539 .25347 .05838 .2577 .06426 .25541 .05978 .25118 Mtetra
.05978 .25118 .06426 .25541 .07014 .25312 .06567 .24887 Mtetra
.06567 .24887 .07014 .25312 .07605 .25082 .07158 .24657 Mtetra
.07158 .24657 .07605 .25082 .08196 .24852 .07751 .24425 Mtetra
.07751 .24425 .08196 .24852 .08789 .24621 .08344 .24193 Mtetra
.08344 .24193 .08789 .24621 .09383 .2439 .08939 .23961 Mtetra
.08939 .23961 .09383 .2439 .09979 .24158 .09536 .23728 Mtetra
.09536 .23728 .09979 .24158 .10576 .23925 .10134 .23495 Mtetra
.10134 .23495 .10576 .23925 .11174 .23692 .10733 .2326 Mtetra
.10733 .2326 .11174 .23692 .11774 .23459 .11333 .23026 Mtetra
.11333 .23026 .11774 .23459 .12376 .23224 .11936 .22791 Mtetra
.11936 .22791 .12376 .23224 .12978 .2299 .12539 .22555 Mtetra
.12539 .22555 .12978 .2299 .13583 .22754 .13144 .22319 Mtetra
.13144 .22319 .13583 .22754 .14188 .22519 .1375 .22082 Mtetra
.1375 .22082 .14188 .22519 .14795 .22282 .14358 .21844 Mtetra
.14358 .21844 .14795 .22282 .15404 .22045 .14968 .21606 Mtetra
.14968 .21606 .15404 .22045 .16014 .21808 .15578 .21368 Mtetra
.15578 .21368 .16014 .21808 .16625 .2157 .16191 .21129 Mtetra
.16191 .21129 .16625 .2157 .17238 .21331 .16804 .20889 Mtetra
.16804 .20889 .17238 .21331 .17852 .21092 .17419 .20649 Mtetra
.17419 .20649 .17852 .21092 .18468 .20852 .18036 .20408 Mtetra
.18036 .20408 .18468 .20852 .19085 .20612 .18654 .20166 Mtetra
.18654 .20166 .19085 .20612 .19704 .20371 .19274 .19924 Mtetra
.19274 .19924 .19704 .20371 .20324 .20129 .19895 .19682 Mtetra
.19895 .19682 .20324 .20129 .20946 .19887 .20517 .19439 Mtetra
.20517 .19439 .20946 .19887 .21569 .19645 .21141 .19195 Mtetra
.21141 .19195 .21569 .19645 .22194 .19401 .21767 .18951 Mtetra
.21767 .18951 .22194 .19401 .2282 .19157 .22394 .18706 Mtetra
.22394 .18706 .2282 .19157 .23447 .18913 .23022 .1846 Mtetra
.23022 .1846 .23447 .18913 .24077 .18668 .23652 .18214 Mtetra
.23652 .18214 .24077 .18668 .24707 .18422 .24284 .17967 Mtetra
.24284 .17967 .24707 .18422 .2534 .18176 .24917 .1772 Mtetra
.24917 .1772 .2534 .18176 .25973 .17929 .25552 .17472 Mtetra
.25552 .17472 .25973 .17929 .26609 .17682 .26188 .17224 Mtetra
.26188 .17224 .26609 .17682 .27246 .17434 .26826 .16975 Mtetra
.26826 .16975 .27246 .17434 .27884 .17185 .27465 .16725 Mtetra
.27465 .16725 .27884 .17185 .28524 .16936 .28106 .16474 Mtetra
.28106 .16474 .28524 .16936 .29166 .16686 .28749 .16224 Mtetra
.28749 .16224 .29166 .16686 .29809 .16436 .29393 .15972 Mtetra
.29393 .15972 .29809 .16436 .30453 .16185 .30038 .1572 Mtetra
.30038 .1572 .30453 .16185 .311 .15933 .30686 .15467 Mtetra
.30686 .15467 .311 .15933 .31747 .15681 .31334 .15214 Mtetra
.31334 .15214 .31747 .15681 .32397 .15428 .31985 .1496 Mtetra
.31985 .1496 .32397 .15428 .33048 .15175 .32637 .14705 Mtetra
.663 .741 .908 r
.32637 .14705 .33048 .15175 .337 .14921 .3329 .1445 Mtetra
.3329 .1445 .337 .14921 .34355 .14667 .33946 .14195 Mtetra
.664 .741 .908 r
.33946 .14195 .34355 .14667 .3501 .14412 .34602 .13939 Mtetra
.664 .742 .908 r
.34602 .13939 .3501 .14412 .35668 .14154 .35261 .1368 Mtetra
.664 .741 .908 r
.35261 .1368 .35668 .14154 .36327 .13898 .35921 .13422 Mtetra
.35921 .13422 .36327 .13898 .36988 .1364 .36583 .13164 Mtetra
.36583 .13164 .36988 .1364 .3765 .13382 .37246 .12904 Mtetra
.37246 .12904 .3765 .13382 .38314 .13124 .37911 .12645 Mtetra
.37911 .12645 .38314 .13124 .3898 .12865 .38578 .12384 Mtetra
.38578 .12384 .3898 .12865 .39647 .12605 .39246 .12123 Mtetra
.39246 .12123 .39647 .12605 .40316 .12344 .39916 .11862 Mtetra
.39916 .11862 .40316 .12344 .40987 .12083 .40588 .11599 Mtetra
.40588 .11599 .40987 .12083 .41659 .11821 .41261 .11336 Mtetra
.41261 .11336 .41659 .11821 .42333 .11559 .41936 .11072 Mtetra
.41936 .11072 .42333 .11559 .43009 .11296 .42613 .10808 Mtetra
.42613 .10808 .43009 .11296 .43686 .11032 .43292 .10543 Mtetra
.43292 .10543 .43686 .11032 .44365 .10767 .43972 .10277 Mtetra
.43972 .10277 .44365 .10767 .45046 .10502 .44654 .10011 Mtetra
.44654 .10011 .45046 .10502 .45729 .10237 .45337 .09744 Mtetra
.45337 .09744 .45729 .10237 .46413 .0997 .46023 .09476 Mtetra
.46023 .09476 .46413 .0997 .47099 .09703 .4671 .09208 Mtetra
.4671 .09208 .47099 .09703 .47786 .09435 .47398 .08939 Mtetra
.47398 .08939 .47786 .09435 .48476 .09167 .48089 .08669 Mtetra
.48089 .08669 .48476 .09167 .49167 .08898 .48781 .08399 Mtetra
.48781 .08399 .49167 .08898 .4986 .08628 .49475 .08128 Mtetra
.49475 .08128 .4986 .08628 .50555 .08357 .50171 .07856 Mtetra
.50171 .07856 .50555 .08357 .51251 .08086 .50869 .07584 Mtetra
.50869 .07584 .51251 .08086 .51949 .07814 .51568 .0731 Mtetra
.51568 .0731 .51949 .07814 .52649 .07542 .52269 .07037 Mtetra
.52269 .07037 .52649 .07542 .53351 .07268 .52972 .06762 Mtetra
.52972 .06762 .53351 .07268 .54055 .06994 .53677 .06487 Mtetra
.53677 .06487 .54055 .06994 .5476 .0672 .54383 .06211 Mtetra
.54383 .06211 .5476 .0672 .55467 .06444 .55092 .05934 Mtetra
.55092 .05934 .55467 .06444 .56176 .06168 .55802 .05657 Mtetra
.55802 .05657 .56176 .06168 .56887 .05891 .56514 .05379 Mtetra
.56514 .05379 .56887 .05891 .576 .05614 .57228 .051 Mtetra
.57228 .051 .576 .05614 .58314 .05336 .57944 .0482 Mtetra
.57944 .0482 .58314 .05336 .5903 .05057 .58661 .0454 Mtetra
.58661 .0454 .5903 .05057 .59749 .04777 .59381 .04259 Mtetra
.59381 .04259 .59749 .04777 .60469 .04497 .60102 .03977 Mtetra
.60102 .03977 .60469 .04497 .6119 .04216 .60825 .03695 Mtetra
.60825 .03695 .6119 .04216 .61914 .03934 .6155 .03412 Mtetra
.6155 .03412 .61914 .03934 .6264 .03651 .62277 .03128 Mtetra
.62277 .03128 .6264 .03651 .63367 .03368 .63006 .02843 Mtetra
.63006 .02843 .63367 .03368 .64097 .03084 .63736 .02558 Mtetra
.63736 .02558 .64097 .03084 .64828 .02799 .64469 .02271 Mtetra
.64469 .02271 .64828 .02799 .65561 .02514 .65203 .01984 Mtetra
.65203 .01984 .65561 .02514 .66296 .02227 .6594 .01697 Mtetra
.6594 .01697 .66296 .02227 .67033 .0194 .66678 .01408 Mtetra
.66678 .01408 .67033 .0194 .67772 .01652 .67418 .01119 Mtetra
.67418 .01119 .67772 .01652 .68513 .01364 .68161 .00829 Mtetra
.68161 .00829 .68513 .01364 .69256 .01075 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14703 .21212 m
.15165 .21677 L
s
[(-0.1)] .13778 .20281 .99298 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.55471 .05248 m
.55858 .05778 L
s
[(0.1)] .54696 .04189 .73149 1 Mshowa
.125 Mabswid
.18507 .19722 m
.18781 .20005 L
s
.22368 .1821 m
.22638 .18497 L
s
.26288 .16675 m
.26553 .16966 L
s
.30267 .15117 m
.30528 .15412 L
s
.38409 .11929 m
.38661 .12231 L
s
.42575 .10298 m
.42822 .10604 L
s
.46806 .08641 m
.47049 .08951 L
s
.51104 .06958 m
.51342 .07272 L
s
.10954 .2268 m
.11235 .22955 L
s
.0726 .24126 m
.07544 .24398 L
s
.59907 .03511 m
.60134 .03833 L
s
.64416 .01746 m
.64637 .02071 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[80]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00boooool2
o`0005?ooooo0038ooooo`?o000000?oooooo`000?ooool0D_ooool00<Kooooo0_l00003ooooo`03
ojVmj?l0003o000005;ooooo002Iooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
7?ooool3o`0000?ooooo0onY_NP00ol0003oooooo`00001Aooooo`00V?ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo01Sooooo0ol00004ooooo`GoZKgX00?o0000ojVmj?l00000
DOooool009Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Fooooo`;o0000
00?oooooo`000?ooool02OnY_NP01?l0003oZKgXooooool0001@ooooo`00V?ooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo01?ooooo0ol00003ooooo`_oZKgX00Go0000ojVmj?nY
_NSoooooo`00001?ooooo`00V?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
017ooooo0_l00005ooooo`coZKgX00Go0000ojVmj?nY_NSoZKgXo`00001?ooooo`00V?ooool01?l0
003oooooooooool00008ooooo`;o00004?ooool3o`0000?ooooo4?nY_NP01_l0003oZKgXojVmj?nY
_NSoooooo`0004kooooo002Iooooo`;o00002_ooool00ol0003oooooooooo`0<ooooo`;o00001?oo
oolCojVmj006o`000?nY_NSoZKgXo`000?oooooo0000COooool00;7ooooo0ol000001?oooooo0000
oooooooooolEojVmj006o`000?nY_NSoZKgXojVmj?oooooo0000COooool00:oooooo0_l00003oooo
oaWoZKgX00?o0000ojVmj?nY_NP00_nY_NP00ooooooo0000ooooo`1;ooooo`00[?ooool3o`0000?o
oooo6onY_NP00ol0003oZKgXojVmj003ojVmj003ooooool0003ooooo04[ooooo002Yooooo`?o0000
0ooooolNojVmj003o`000?nY_NSoZKgX00?oZKgX00?oooooo`000?ooool0B_ooool00:Oooooo0ol0
0003ooooob3oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ooooooo0000ooooo`19ooooo`00Y?ooool3
o`0000?ooooo00?o0000ojVmj?nY_NP08?nY_NP00ol0003oZKgXojVmj005ojVmj003ooooool0003o
oooo04Sooooo002Rooooo`;o00000ooooolVojVmj003o`000?nY_NSoZKgX00KoZKgX00?o0000oooo
ooooool0Aoooool009oooooo0ol00003ooooobSoZKgX00?o0000ojVmj?nY_NP01_nY_NP2o`0004So
oooo002Mooooo`;o00000oooool[ojVmj003o`000?nY_NSoZKgX00OoZKgX00?oooooo`000?ooool0
A_ooool009[ooooo0ol000000ooooooo0000ooooo`0]ojVmj003o`000?nY_NSoZKgX00OoZKgX00?o
ooooo`000?ooool03Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0002_ooooo002H
ooooo`;o00001?ooool_ojVmj003o`000?nY_NSoZKgX00SoZKgX00?oooooo`000?ooool02oooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo02[ooooo002Eooooo`?o00000ooooolb
ojVmj003o`000?nY_NSoZKgX00SoZKgX00?oooooo`000?ooool01?ooool5o`0000;ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`0Zooooo`00T_ooool3o`0000Cooooo=?nY_NP0
0ol0003oZKgXojVmj009ojVmj003ooooool0003ooooo00[ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`0Zooooo`00T?ooool2o`000003ooooool0003ooooo03SoZKgX00?o0000
ojVmj?nY_NP02_nY_NP00ooooooo0000ooooo`09ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0:_ooool006cooooo0_l0000Oooooo`?o00000oooooljojVmj003o`000?nY_NSo
ZKgX00_oZKgX00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`;o0000;?oo
ool006_ooooo00Co0000oooooooooooo00007?ooool2o`0000Gooooo??nY_NP00ol0003oZKgXojVm
j00;ojVmj003o`000?oooooooooo00Sooooo0_l0000:ooooo`03o`000?oooooooooo02[ooooo001[
ooooo`04o`000?ooooooooooo`0001Wooooo0ol00003oooood3oZKgX00?o0000ojVmj?nY_NP02onY
_NP00ooooooo0000ooooo`11ooooo`00Joooool01?l0003oooooooooool0000Gooooo`?o00000ooo
oom2ojVmj003o`000?nY_NSoZKgX00coZKgX00?o0000ooooooooool0@?ooool006_ooooo00Co0000
oooooooooooo00005?ooool3o`0000?oooooAOnY_NP00ol0003oZKgXojVmj00<ojVmj003ooooool0
003ooooo043ooooo001[ooooo`04o`000?ooooooooooo`00017ooooo0ol00004ooooodOoZKgX00?o
0000ojVmj?nY_NP03OnY_NP00ooooooo0000ooooo`0oooooo`00K?ooool2o`00013ooooo0_l00004
oooood[oZKgX00?o0000ojVmj?nY_NP03_nY_NP00ol0003oooooooooo`0nooooo`00Noooool3o`00
00CoooooC?nY_NP00ol0003oZKgXojVmj00>ojVmj003ooooool0003ooooo03kooooo001iooooo`;o
00000oooool00ol0003oZKgXojVmj01=ojVmj003o`000?nY_NSoZKgX00ooZKgX00?oooooo`000?oo
ool0?Oooool007Kooooo0ol00004oooooe7oZKgX00?o0000ojVmj?nY_NP04?nY_NP00ol0003ooooo
ooooo`0looooo`00M?ooool2o`0000?oooooEOnY_NP00ol0003oZKgXojVmj00@ojVmj003ooooool0
003ooooo03cooooo001aooooo`?o00000ooooomGojVmj003o`000?nY_NSoZKgX017oZKgX00?ooooo
o`000?ooool0>oooool006oooooo0_l00002ooooo`03o`000?nY_NSoZKgX05SoZKgX00?o0000ojVm
j?nY_NP04OnY_NP00ooooooo0000ooooo`0kooooo`00K?ooool3o`0000?oooooG?nY_NP00ol0003o
ZKgXojVmj00BojVmj003ooooool0003ooooo03[ooooo001Yooooo`?o00000ooooomOojVmj003o`00
0?nY_NSoZKgX01?oZKgX00?oooooo`000?ooool0>Oooool006Oooooo0_l00004ooooo`WoZKgX0_nZ
_NQFojVmj003o`000?nY_NSoZKgX01CoZKgX00?o0000ooooooooool0>?ooool006Cooooo0ol00000
0ooooooo0000ooooo`0<ojVmj0?oZ[gXEOnY_NP00ol0003oZKgXojVmj00DojVmj0;o0000>Oooool0
06;ooooo0_l00004ooooo`ooZKgX0_nZ_NQFojVmj003o`000?nY_NSoZKgX01?oZKgX0_ooool00ol0
003oooooooooo`0fooooo`00Goooool3o`0000?ooooo4onY_NP2ojZmj5GoZKgX00?o0000ojVmj?nY
_NP05?nY_NP00ooooooo0000ooooo`0gooooo`00GOooool2o`0000Cooooo5_nY_NP2ojZmj5CoZKgX
00?o0000ojVmj?nY_NP05OnY_NP00ooooooo0000ooooo`0fooooo`00F_ooool3o`000003ooooool0
003ooooo01WoZKgX0onZ_NQCojVmj003o`000?nY_NSoZKgX01KoZKgX00?oooooo`000?ooool0=Ooo
ool002gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Looooo`?o00001?oooolL
ojVmj0?oZ[gXD_nY_NP00ol0003oZKgXojVmj00GojVmj003o`000?oooooooooo03Cooooo000/oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool06Oooool2o`0000Cooooo8?nY_NP3
ojZmj57oZKgX00?o0000ojVmj?nY_NP05onY_NP00ooooooo0000ooooo`0dooooo`009Oooool5o`00
00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Fooooo`?o00001?oooolS
ojVmj0?oZ[gXD?nY_NP00ol0003oZKgXojVmj00HojVmj003ooooool0003ooooo03?ooooo000/oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool05?ooool2o`0000;ooooo00?o0000
oooooonY_NP09_nY_NP2ojZmj53oZKgX00?o0000ojVmj?nY_NP06?nY_NP2o`0003Cooooo000/oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool04Oooool3o`0000?ooooo:onY_NP2
ojZmj4ooZKgX00?o0000ojVmj?nY_NP06OnY_NP00ooooooo0000ooooo`0booooo`00;?ooool01?l0
003oooooooooool00008ooooo`;o00004Oooool2o`0000Cooooo;_nY_NP2ojZmj4koZKgX00?o0000
ojVmj?nY_NP06_nY_NP00ooooooo0000ooooo`0aooooo`00;Oooool2o`0000[ooooo00?o0000oooo
ooooool03?ooool3o`0000?ooooo<OnY_NP3ojZmj4goZKgX00?o0000ojVmj?nY_NP06_nY_NP00ooo
oooo0000ooooo`0aooooo`00A_ooool2o`0000;ooooo00?o0000oooooonY_NP0<onY_NP3ojZmj4co
ZKgX00?o0000ojVmj?nY_NP06onY_NP00ooooooo0000ooooo`0`ooooo`00@oooool3o`0000?ooooo
>?nY_NP3ojZmj4_oZKgX00?o0000ojVmj?nY_NP07?nY_NP00ooooooo0000ooooo`0_ooooo`00@?oo
ool3o`0000?ooooo??nY_NP3ojZmj4[oZKgX00?o0000ojVmj?nY_NP07OnY_NP00ol0003ooooooooo
o`0^ooooo`00?_ooool3o`0000?ooooo?onY_NP2ojZmj4[oZKgX00?o0000ojVmj?nY_NP07OnY_NP2
o`0002oooooo000kooooo`?o00000oooool00ol0003oZKgXojVmj010ojVmj0;oZ[gXBOnY_NP00ol0
003oZKgXojVmj00MojVmj0;ooooo00?o0000ooooooooool01Oooool2o`0002Gooooo000iooooo`;o
00001Ooooom5ojVmj0;oZ[gXBOnY_NP00ol0003oZKgXojVmj00MojVmj003ooooool0003ooooo00Go
oooo00Co0000oooooooooooo00009?ooool003Kooooo0ol00003oooood[oZKgX0_nZ_NQ8ojVmj003
o`000?nY_NSoZKgX01koZKgX00?oooooo`000?ooool01?ooool01?l0003oooooooooool0000Toooo
o`00=?ooool3o`0000;oooooCOnY_NP3ojZmj4OoZKgX00?o0000ojVmj?nY_NP07onY_NP00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0002Cooooo000aooooo`?o00001?oooom?ojVmj0?o
Z[gXA_nY_NP00ol0003oZKgXojVmj00OojVmj003ooooool0003ooooo00?ooooo00Co0000oooooooo
oooo00009?ooool002oooooo0_l00004oooooe?oZKgX0onZ_NQ5ojVmj003o`000?nY_NSoZKgX023o
ZKgX00?oooooo`000?ooool00_ooool01?l0003oooooooooool0000Tooooo`00;?ooool3o`0000?o
ooooEonY_NP3ojZmj4CoZKgX00?o0000ojVmj?nY_NP08OnY_NP00ol0003oooooooooo`02ooooo`;o
00009Oooool002Wooooo1Ol00002oooooe[oZKgX0onZ_NQ3ojVmj003o`000?nY_NSoZKgX02;oZKgX
00?o0000ooooooooool0:?ooool002Oooooo0_l00004oooooekoZKgX0_nZ_NQ2ojVmj0;o00009?nY
_NP00ooooooo0000ooooo`0Xooooo`009?ooool3o`0000?oooooH_nY_NP2ojZmj3koZKgX0ol00000
0onY_NSo0000ojVmj00SojVmj003ooooool0003ooooo02Sooooo000Sooooo`;o00000ooooomQojVm
j004ojRmj?nY_NSoZKgXojVmj0;oZ[gW>_nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP08_nY_NP0
0ooooooo0000ooooo`0Wooooo`008oooool2o`0006GoZKgX00CoZ;gXojVmj?nY_NSoZKgX0_nZ_NLf
ojVmj0?o00002OnY_NP00ol0003oZKgXojVmj00RojVmj003ooooool0003ooooo02Kooooo000Loooo
o`;o00001Oooool00ol0003oZKgXojVmj01TojVmj0;oZ;gX0onY_NP2ojZmic;oZKgX0ol0000=ojVm
j003o`000?nY_NSoZKgX02;oZKgX0_l0000Vooooo`006oooool01?l0003oooooooooool00004oooo
o`03o`000?nY_NSoZKgX06GoZKgX0_nX_NP2ojVmj0?oZkgW;_nY_NP3o`00013oZKgX00?o0000ojVm
j?nY_NP08_nY_NP2o`0002Kooooo000Kooooo`04o`000?ooooooooooo`0000?ooooo0_l000000ooo
ooooZKgXojVmj01UojVmj0;oZ;gX0_nY_NP2oj^mib_oZKgX0ol0000DojVmj003o`000?nY_NSoZKgX
00_oZKgX1?nY_^PCojVmj003ooooool0003ooooo02Cooooo000Kooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000ooooooooooooooooIonY_NP2ojRmj0;oZKgX0_n[_NLWojVmj0?o00006?nY_NP0
0ol0003oZKgXojVmj009ojVmj0;oZKkX5onY_NP00ol0003oooooooooo`0Sooooo`006oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00;oooooIonY_NP2ojRmj0;oZKgX00?oZkgW
oj^nionY_NP08_nY_NP3o`0001_oZKgX00?oZKgWo`000?nY_NP01OnY_NP4ojVnj1WoZKgX00?ooooo
o`000?ooool08oooool001_ooooo00Co0000oooooooooooo00000oooool2o`0000GoooooIOnY_NP3
ojRmj0;oZKgX0_n[_^LOojVmj0?o00006_nY_NP5ojVmi`04o`000?nY_NSoZKgXojVmj0CoZKkX7OnY
_NP00ooooooo0000ooooo`0Rooooo`007?ooool2o`0000Cooooo00?o0000ooooooooool01OoooomU
ojVmj0?oZ;gX0_nY_NP2oj^nia_oZKgX0ol0000LojVmj0CoZKgW0_nY_NP00onY_^So0000ojVnj002
ojVnj27oZKgX00?o0000ooooooooool08Oooool002;ooooo00?o0000ooooooooool01_oooomUojVm
j005ojRmj?nW_NWoYkgYojVmj?n[_^L00_n/_^LHojVmj0;o00006onY_NP5ojVmi`CoZKgX0onY_^P0
0ol0003oZKgXojVmj00QojVmj0;o00008_ooool0027ooooo00?o0000ooooooooool02?oooomUojVm
j004ojNmjOnW_>WoZKgXojVmj0?o[;kW5?nY_NP3o`0001[oZKgX0_nY_>L2ojVmi`CoZKgX1OnY_^P2
ojVmj003o`000?nY_NSoZKgX02;oZKgX00?oooooo`000?ooool08?ooool0027ooooo0_l0000:oooo
ofGoZKgX0_nW_>T2ojVmj003ojbnion/_^Ko[;kV013oZKgX0ol0000KojVmj0?oZKcW1?nY_NP4ojVn
j0OoZKgX00?o0000ojVmj?nY_NP08_nY_NP00ol0003oooooooooo`0Oooooo`008Oooool00ol0003o
ooooooooo`0:ooooofGoZKgX0_nW_>T01?nY_NSoZKgWojbni_n]_^H2ojZmj0_oZKgX0ol0000KojVm
j0CoZKcW0onY_NP4ojVnj0_oZKgX00?o0000ojVmj?nY_NP08OnY_NP00ooooooo0000ooooo`0Ooooo
o`008Oooool00ol0003oooooooooo`0;ooooofGoZKgX0_nV_>T2ojVmi`;o[KkV0_nZ_NP7ojVmj0?o
00006onY_NP4ojVli`CoZKgX1?nY_^P>ojVmj003o`000?nY_NSoZKgX027oZKgX00?oooooo`000?oo
ool07_ooool0027ooooo0_l0000=ooooofGoZKgX00CoY[cYojVmionY_>OoZKcW0_n]_^H2ojZmj0?o
ZKgX0ol0000JojVmj0GoZKcW1?nY_NP3ojVnj@03ojVnj?nY_NSoZKgX00ooZKgX00?o0000ojVmj?nY
_NP08OnY_NP00ooooooo0000ooooo`0Nooooo`008Oooool00ol0003oooooooooo`0>ooooofCoZKgX
00GoYKcYojVlionY_>OoZKcWojjni@02ojZmj0?o00006_nY_NP01?nY^nKoZKcWojVlionY_>L4ojVm
j0CoZKkY5_nY_NP00ol0003oZKgXojVmj00QojVmj003ooooool0003ooooo01gooooo000Pooooo`03
o`000?oooooooooo013oooooI?nY_NP00onT^nWoZKcWojVli`03o`0000;oZ[gW6OnY_NP4ojVkiP03
ojVlionY_NSoZKgX00?oZKoY00?oZKkYojVmj?nY_NP06?nY_NP00ol0003oZKgXojVmj00QojVmj003
ooooool0003ooooo01cooooo000Pooooo`?o00004OoooomSojVmj0?o00000_nY^nH01?n`_N?oZ[gW
ojZmionZ_NLEojVmj0;oZK[V0_nY^nH3ojZmj004ojVmj?nZ_nWoZ[oYojVojAkoZKgX00?o0000ojVm
j?nY_NP08?nY_NP00ooooooo0000ooooo`0Looooo`008?ooool00ol0003oooooooooo`0Boooooeoo
ZKgX0ol000001?nY_NSoXK[[oj6jjonY^nH2ojVii@05ok:lhOnZ_NOoZkgWoj^mionZ_NP03?nY_NP0
1OnY_NOoZKgXojVmj?nY_NSoZKWU00;oZK[U00?oZK[VojZmj?nZ_NP00_nZ_NP2oj[0j@;oZ[oY8?nY
_NP00ol0003oZKgXojVmj00QojVmj003ooooool0003ooooo01_ooooo0007ooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool04ooooomL
ojVmj0;o00001?nY_NP01OnX_NSoW[W[oijijonY^NGoZKOS00;o]K_N00GoZkgWoj^li_nZ_NOoZ[gW
ojVmj002ojZmi`GoZKgX00GoZKcWojVmionY_NOoZKgWojVgh`02ojVhi003ojViiOnZ_^SoZ[gX00;o
Z[gX00CoZ/7Zoj[0j_nZ`>[oZ/3Y9?nY_NP00ol0003oZKgXojVmj00QojVmj003ooooool0003ooooo
01[ooooo0006ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?oooomHojVmj0?o00001_nY
_NP2ojRmj0;oV[O/00KoZKOSokFkg_nh^=Wo^;SIoj^li_n/_>D3ojZmi`04ojZlionY_NOoZKgWojVm
j0;oZKcW00GoZK;NojVehOnY]N7oZKGQojVgh`03oj^ni`05ojZnj?nZ`^_oZ/7[oj[1jonZ`NX0:?nY
_NP00ol0003oZKgXojVmj00PojVmj003ooooool0003ooooo01[ooooo0006ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`;o0000
5_oooomDojVmj0?o00002_nY_NP01_nX_NSoZ;cXoi6ck_nA/nkoZ;;OokRhf@;o^k7?00Ko[;cUojfi
h_n[^nKoZk_VojZlionZ^^D2ojZkiP07ojVlionX[M_oZK;NojVbg_nY]N7o[;kWoj^ni`02oj_5k@04
oj_3k?nZ`^_oZKkXojVnj2_oZKgX00?o0000ojVmj?nY_NP08?nY_NP00ooooooo0000ooooo`0Ioooo
o`001_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000
ooooooooooooooooo`00000Ioooooe3oZKgX0ol0000>ojVmj003ojRlj?nW^nSoPJ[_00;oYjWH00Go
^k7?okbQ_OnlXKgo[KWRojj/e@02oj^fh@06ojZjiOnXY]CoZ:KDojRVe?nX[M_o/;oU0_n^_nH00on/
_^Oo[<S^oj_5k@04ojVnj2coZKgX00?o0000ojVmj?nY_NP08OnY_NP2o`0001Wooooo0006ooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Cooooo00?o0000
ooooooooool06?oooom<ojVmj0?o00004OnY_NP01OnW^nSoYK[XoeVBk?mIT^coYjWH00?o_:6m00Co
[ZcEoi]_WonQQkOoXHNg0_nVV/T01OnXY]Co]L7SokG1hon`_nGo/=Cc00;o[/c`00?o[<S^ojZnj?nY
_^P0<?nY_NP00ol0003oZKgXojVmj00PojVmj003ooooool0003ooooo00Oooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00003ooooo`001_ooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00001oooool2o`0001[oooooB?nY_NP3o`0001;oZKgX0_nY_>P0
1?nX_>OoYK[XojFjj?mIT^`2oj>DaP03okbQ_OnaPj?oVfnO00;oVfnO0_nQQkL01OnVV/Wo_lCNokG1
hondh_Ko/=Cc00;oZ[oY00?oZ[kXojVnj?nY_NP0<_nY_NP00ol0003oZKgXojVmj00PojVmj003oooo
ool0003ooooo00Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`00
1oooool2o`0000[ooooo0_l00002ooooo`Go00000oooool00ol0003oooooooooo`0JooooodCoZKgX
0ol0000EojVmj004ojVlj?nX^nOoYkWVojNiiP;oX;;U00CoXiC6oiMaY_naPj?o/H>S0onKKil01?nQ
QkOod/O?oko4g_ngn>l2ojc2jP05oj_0jOnZ_nWoZ[kXojZnj?nY_^P0<onY_NP00ol0003oZKgXojVm
j00PojVmj0;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00;ooooo000Oooooo`03o`000?oooooooooo01_ooooo@?nY_NP3o`0001SoZKgX00Co
ZKcWojRkionX^nOoYkWV0_nAOKX2oiMaYP;o/H>S0onKKil01_o]`ZSod/O?ok78jonab>_o[<;Zoj^o
j0?oZ[kX=_nY_NP00ol0003oZKgXojVmj00PojVmj003ooooool0003ooooo00Cooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`02ooooo`007oooool2o`0001kooooo>onY_NP3o`00
01OoZKgX1?nY_>L00onW[=_oY:CEojBTe@02oinFb`06oi5m^_nGLJKoUg6VoiMaY_naPj?oUUf<0_nK
Kil00oo]`ZSo`mg/ok;7j@02ojc0j@04oj^oj?nZ_^SoZ[kXojZnj3OoZKgX00?o0000ojVmj?nY_NP0
8?nY_NP00ooooooo0000ooooo`03ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool00_ooool001kooooo0_l0000PooooocOoZKgX0ol0000IojVmj005ojVmionY_>OoZ;CQojRdhOnX
/Ml00_nW[=/01OnTY=GoR;7`ocZ8jonAOK[o61>:00;oUg6V0_nFGH`01_nKKiookL:Xong2Z?o`lL?o
//OYojk1j0;oZkkX0_nZ_^PiojVmj003o`000?nY_NSoZKgX01ooZKgX0_l00004ooooo`04o`000?oo
ooooooooo`0000Sooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Poooooc?oZKgX0ol0
000KojVmj0;oZKST00GoZKOSojRdhOnU_>WoYKcYoj:kj`02oi^hk@04ohRal?mXa_koTGfjoi5m^P;o
Ug6V0_nFGH`00onKKiookL:Xoo3a``02omOMg003ojk1j?n/_nSoZ[kX00;oZ[kX>OnY_NP00ol0003o
ZKgXojVmj00PojVmj003ooooool0003ooooo00?ooooo0_l0000:ooooo`03o`000?oooooooooo00;o
oooo000Nooooo`03o`000?oooooooooo027ooooo<?nY_NP2o`0001_oZKgX0_nY^^D02?nY^NGoZKST
ojNmjOnW_NWoY[cYojFljOnTaO7oWlSe0onX_^T01OnV_n_oZ;gYoi5m^_nGLJKoS5F;00;oUUf<00Ko
VfnOong2Z?nUf?[oemgLolK@h_n/_nP2oj^nj003ojZnj?nY_NSoZKgX03WoZKgX00?o0000ojVmj?nY
_NP08?nY_NP00ooooooo0000ooooo`0Cooooo`007_ooool2o`0002?ooooo;?nY_NP3o`0001[oZKgX
00CoZK_VojVji_nY^^KoZK[U0onX_NP01onW_NWoYl;]ojK4k_nVa>koY<GaojVnjOnX_^T00onY_NP0
1?nX_NWoZKgXohaERon<EH/2oiIMS006ooNbNOo]`ZSoZL[aojW:lOo6d>;o_<WT0on[_^P00onZ_NSo
ZKgXojVmj00iojVmj003o`000?nY_NSoZKgX01ooZKgX00?oooooo`000?ooool04oooool001kooooo
00?o0000ooooooooool08ooooolXojVmj0?o00006_nY_NP4ojVkiP?oZKgX00GoZ;gXojS1jonX`Nco
Z<7/ojO2k@02ojVnj0SoZKgX0_n<EH/2oiIMS004ooNbNOnX_NWoTKG_ojW4k@;oZL;[00?o]lGUoj^n
j?nZ_^P0?OnY_NP00ol0003oZKgXojVmj00OojVmj003ooooool0003ooooo01;ooooo000Nooooo`03
o`000?oooooooooo02Cooooo9?nY_NP3o`0001[oZKgX0onY_>L00onY^nKoZKgXojVmj002ojVmj004
ojW0j_nY`>_oZL3[ojS1j`?oZKgX00?oZKkXojVmj?nY_NP01onY_NP2ohaER`;oUUf<00Komk9iojRm
j?nI^>goVKS]ojW2jonY`>X2ok?3iP;oZ[kX??nY_NP00ol0003oZKgXojVmj00PojVmj003ooooool0
003ooooo017ooooo000Nooooo`;o00009_oooolPojVmj0?o00006_nY_NP4ojVli`CoZKgX00CoZKoY
ojVoj_nY_n[oZL3Z4?nY_NP2ohaER`;oUUf<00?omk9iojRmj?nX_NP00_nN^^`01_nY`>[oZKoYok71
i_na`NKoZ[kXojZmj3coZKgX00?o0000ojVmj?nY_NP08?nY_NP00ol0003oooooooooo`0@ooooo`00
2_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo0_l0000XoooooacoZKgX
0ol0000JojVmj0CoZKcW1?nY_NP4ojVojA?oZKgX0_n<EH/2oiIMS004ooNbNOnY_NSoZ;gXojVmj0;o
XK_[00CoZKoYojVnjOn_`>Ko[/3W0_nZ_NPlojVmj003o`000?nY_NSoZKgX01ooZKgX00?oooooo`00
0?ooool04?ooool000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Sooooo6?nY_NP3o`0001[oZKgX1?nY_>L4ojVmj0?oZKkY00?oZKoYojVm
j?nY_NP05?nY_NP2ohaER`;oUUf<00?omk9iojVmj?nY_NP00_nY_NP01_nS^n[oZKkYojVnjOnY_^Wo
[/3Wojfoi`;oZ[gX??nY_NP00ol0003oZKgXojVmj00OojVmj003ooooool0003ooooo00oooooo0009
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0YoooooaCoZKgX0ol0000JojVmj004ojVmionY_>OoZKcWojVli`CoZKgX1?nY_^TIojVmj0;oS5F;
0_nFGH`00oog/WWoZKgXojVmj003ojVmj004ojBlj_nY_^WoZKkXojVnj0;o[KoW0_nZ_NPkojVmj003
o`000?nY_NSoZKgX023oZKgX00?o0000ooooooooool03_ooool000Wooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`04ooooo`;o0000:oooool@ojVmj0?o00006_nY_NP4ojVmi`Co
ZKgX1?nY_^TLojVmj0;oS5F;0_nFGH`00oog/WWoZKgXojVmj004ojVmj004ojFljOnV_>WoZKkXojfo
i`;o[;kW?OnY_NP00ol0003oZKgXojVmj00OojVmj003ooooool0003ooooo00kooooo0009ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[oooo
o`coZKgX0ol0000JojVmj0CoZKgW1?nY_NP3ojVnj003ojVnjOnY_NSoZKgX01goZKgX0_n<EH/2oiIM
S003ooNbNOnY_NSoZKgX00CoZKgX0onV_>T01?nY_^So[;kWojbnion/_^LmojVmj003o`000?nY_NSo
ZKgX01ooZKgX00?oooooo`000?ooool03Oooool000Wooooo00Co0000oooooooooooo00002?ooool2
o`0000Kooooo00?o0000ooooooooool0;?ooool9ojVmj0;o00006_nY_NP4ojVmi`CoZKgX1?nY_^PR
ojVmj0;oS5F;0_nFGH`00oog/WWoZKgXojVmj005ojVmj004ojJljOnW_>WoZKkXojVnj0;o[;kW?OnY
_NP00ol0003oZKgXojVmj00PojVmj003o`000?oooooooooo00cooooo000:ooooo`;o00002_ooool0
0ol0003oooooooooo`03ooooo`;o0000;oooool5ojVmj0?o00007?nY_NP00onY_NOoZKgXojVmj002
ojVmj0CoZKkX9OnY_NP2ohaER`;oUUf<00?omk9iojVmj?nY_NP01_nY_NP01_nW_>WoYkgYojVmj?nY
_NSo[;kWoj^nicgoZKgX00?o0000ojVmj?nY_NP07onY_NP00ooooooo0000ooooo`0<ooooo`007?oo
ool00ol0003oooooooooo`0_ooooo`04ojVmj?l0003o0000o`00027oZKgX1?nY_^PXojVmj0;oS5F;
0_nFGH`00oog/WWoZKgXojVmj007ojVmj0;oYkgY0_nY_NP2oj^nicgoZKgX00?o0000ojVmj?nY_NP0
7onY_NP00ooooooo0000ooooo`0;ooooo`007?ooool00ol0003oooooooooo`0]ooooo`?o00008OnY
_NP4ojVnj2_oZKgX0_n<EH/2oiIMS003ooNbNOnY_NSoZKgX00SoZKgX00CoYkgYojRmj?nY_NSoZKgX
0_n[_^LmojVmj003o`000?nY_NSoZKgX01koZKgX00?oooooo`000?ooool02oooool001cooooo00?o
0000ooooooooool0:_ooool3o`0000Gooooo7?nY_NP4ojVnj2koZKgX0_n<EH/2oiIMS003ooNbNOnY
_NSoZKgX00WoZKgX0_nX_NP2ojVmj0;oZkkW??nY_NP00ol0003oZKgXojVmj00OojVmj003ooooool0
003ooooo00[ooooo000Looooo`;o0000:?ooool3o`0000Wooooo6?nY_NP4ojVnj37oZKgX0_n<EH/2
oiIMS003ooNbNOnY_NSoZKgX00[oZKgX00GoZ;gXojVmj?nY_NSoZKgXoj^ni`0mojVmj003o`000?nY
_NSoZKgX01ooZKgX0_l0000:ooooo`007?ooool00ol0003oooooooooo`0Tooooo`?o00003OoooolE
ojVmj0?oZKkX=?nY_NP2ohaER`;oUUf<00?omk9iojVmj?nY_NP02onY_NP01OnX_NSoZKgXojVmj?nY
_NSoZkkX03goZKgX00?o0000ojVmj?nY_NP07_nY_NP00ooooooo0000ooooo`09ooooo`006oooool0
0ol0003oooooooooo`0Rooooo`?o00004Ooooom;ojVmj0;oS5F;0_nFGH`00oog/WWoZKgXojVmj00<
ojVmj003ojRmj?nY_NSoZKgX00;oZ[kX?OnY_NP00ol0003oZKgXojVmj00NojVmj003o`000?oooooo
oooo00Sooooo000Kooooo`;o00008?ooool3o`0001GoooooB_nY_NP2ohaER`;oUUf<00?omk9iojVm
j?nY_NP03?nY_NP2ojRmj0;oZKgX0_nZ_^PlojVmj003o`000?nY_NSoZKgX01coZKgX0_ooool00ol0
003oooooooooo`08ooooo`006oooool00ol0003oooooooooo`0Looooo`?o00006Ooooom9ojVmj0;o
S5F;0_nFGH`00oog/WWoZKgXojVmj00=ojVmj0;oZ;gX0_nY_NP2ojZnj3coZKgX00?o0000ojVmj?nY
_NP05_nY_NP7ooooo`03o`000?oooooooooo00Sooooo000Kooooo`03o`000?oooooooooo01Wooooo
0ol0000MooooodSoZKgX0_n<EH/2oiIMS003ooNbNOnY_NSoZKgX00koZKgX0_nX_NP2ojVmj003ojZn
j?nZ_NSoZKgX03_oZKgX00?o0000ojVmj?nY_NP04OnY_NP<ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo01Oooooo0_l0000QooooodOoZKgX0_n<EH/2oiIMS003ooNbNOnY
_NSoZKgX00ooZKgX00?oZ;gXojVmj?nY_NP00onZ_NPlojVmj003o`000?nY_NSoZKgX00goZKgX3ooo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0001Gooooo0ol0000TooooodKoZKgX0_n<EH/2
oiIMS003ooNbNOnY_NSoZKgX01?oZKgX0onZ_NPkojVmj003o`000?nY_NSoZKgX00[oZKgX4_ooool0
0ol0003oooooooooo`07ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00?ooooo0ol00004ooooo`03o`000?oooooooooo01;ooooo0ol0000XooooodGoZKgX0_n<EH/2oiIM
S003ooNbNOnY_NSoZKgX01GoZKgX00?oZ[gXojVmj?nY_NP0>_nY_NP00ol0003oZKgXojVmj006ojVm
j1Gooooo00?o0000ooooooooool01oooool00005ooooool0003oooooooooool000002Oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Aooooo`?o0000;?oo
oom4ojVmj0;oS5F;0_nFGH`00oog/WWoZKgXojVmj00FojVmj003ojZmj?nY_NSoZKgX03[oZKgX00?o
0000ojVmj?nY_NP00_nY_NPHooooo`03o`000?oooooooooo00Oooooo00001Ooooooo0000oooooooo
oooo000000Wooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool2o`0000gooooo
0ol0000`oooood?oZKgX0_n<EH/2oiIMS003ooNbNOnY_NSoZKgX01KoZKgX0_nZ_NPkojVmj003o`00
0?oooooooooo01[ooooo00?o0000ooooooooool01oooool00005ooooool0003oooooooooool00000
2Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000002oooool3o`0003Co
oooo@_nY_NP01OlH4h[oS5F;ohaERonFGHcomk9i01WoZKgX0_nZ_NPhojVmj0?ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`07ooooo`0000Goooooo`000?ooooooooooo`000009oooo
o`04o`000?ooooooooooooooo`Co00001?ooool00ol0003oooooooooo`06ooooo`?o0000>?oooom2
ojVmj0;oS5F;0_og/WTJojVmj0;oZ[gX=?nY_NP7ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01_ooool00005ooooool0003oooooooooool000002?ooool2o`0000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o0000??oooom1ojVmj0;oS5F;00?omk9i
ojVmj?nY_NP06_nY_NP2ojZmj33oZKgX2oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00Kooooo0002ooooo`;o00002_ooool01?l0003oooooooooooooool5o`0000;ooooo0ol00000
1?oooooo0000o`000?l00010oooood3oZKgX0_n<EH/00oog/WWoZKgXojVmj00KojVmj003ojZmj?nY
_NSoZKgX02WoZKgX4?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo000I
ooooo`Co0000AOoooolnojVmj0;oS5F;00?omk9iojVmj?nY_NP07?nY_NP00onZ_NSoZKgXojVmj00U
ojVmj1Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`006Oooool2o`00
04Sooooo?OnY_NP2ohaER`03ooNbNOnY_NSoZKgX01coZKgX0_nZ_NPSojVmj1Sooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`06ooooo`006oooool00ol0003oooooooooo`16ooooocco
ZKgX0_n<EH/00oog/WWoZKgXojVmj00MojVmj0;oZ[gX7onY_NPLooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01_ooool001cooooo00?o0000ooooooooool0A_oooolkojVmj0;oS5F;
00?omk9iojVmj?nY_NP07_nY_NP2ojZmj1_oZKgX7oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Kooooo000Mooooo`03o`000?oooooooooo04Kooooo>_nY_NP2ohaER`03ooNbNOnY
_NSoZKgX01ooZKgX0_nZ_NPGojVmj2?ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`05ooooo`007_ooool2o`0004Oooooo>OnY_NP2ohaER`03ooNbNOnY_NSoZKgX023oZKgX0_nZ_NPB
ojVmj2Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`008?ooool00ol0
003oooooooooo`15ooooocSoZKgX0_n<EH/00oog/WWoZKgXojVmj00QojVmj003ojZmj?nY_NSoZKgX
00goZKgX;?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo04Gooooo=onY_NP2ohaER`03ooNbNOnY_NSoZKgX02;oZKgX0_nZ_NP:ojVmj2oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`008_ooool00ol0003ooooo
ooooo`15ooooocKoZKgX0_n<EH/00oog/WWoZKgXojVmj00RojVmj0;oZ[gX1onY_NPcooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01Oooool002?ooooo0_l00016ooooocGoZKgX0_n<
EH/00oog/WWoZKgXojVmj00SojVmj003ojZmj?nY_NSoZKgX03Wooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`05ooooo`009Oooool00ol0003oooooooooo`15oooooc?oZKgX0_n<EH/0
0oog/WWoZKgXojVmj00SojVmj3cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05
ooooo`009_ooool00ol0003oooooooooo`15oooooc;oZKgX0_n<EH/00oog/WWoZKgXojVmj00PojVm
j43ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`009oooool00ol0003o
ooooooooo`14oooooc;oZKgX0_n<EH/00oog/WWoZKgXojVmj00MojVmj4Cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`04ooooo`00:?ooool2o`0004Gooooo<OnY_NP2ohaER`03ooNb
NOnY_NSoZKgX01WoZKgXBOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo
000Zooooo`03o`000?oooooooooo04Cooooo;onY_NP2ohaER`03ooNbNOnY_NSoZKgX01KoZKgXC?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo000[ooooo`03o`000?oooooo
oooo04Cooooo;_nY_NP2ohaER`03ooNbNOnY_NSoZKgX01?oZKgXD?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Cooooo000/ooooo`03o`000?oooooooooo04Cooooo;OnY_NP2ohaE
R`03ooNbNOnY_NSoZKgX00ooZKgXEOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Cooooo000]ooooo`03o`000?oooooooooo04Cooooo;?nY_NP2ohaER`03ooNbNOnY_NSoZKgX00co
ZKgXFOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo000^ooooo`;o0000
AOooool[ojVmj0;oS5F;00?omk9iojVmj?nY_NP02OnY_NQLooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01?ooool0033ooooo00?o0000ooooooooool0@ooooolZojVmj0;oS5F;00?o
mk9iojVmj?nY_NP01OnY_NQQooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00ooo
ool0037ooooo00?o0000ooooooooool0@ooooolYojVmj0;oS5F;00?omk9iojVmj?nY_NP00_nY_NQU
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool003;ooooo00?o0000oooo
ooooool0@ooooolXojVmj0;oS5F;00?omk9iojVmj?ooool0J?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00?ooooo000cooooo`;o0000A?oooolWojVmj003oooooonU`nooYL?_06[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`00=Oooool00ol0003ooooo
ooooo`12ooooob?oZKgXLOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
000fooooo`03o`000?oooooooooo04;ooooo7onY_NQeooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool003Oooooo00?o0000ooooooooool0@ooooolIojVmj7Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`00>?ooool2o`0004Cooooo5_nY_NQloooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool003[ooooo00?o0000oooooooo
ool0@OoooolAojVmj8;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`00
>oooool00ol0003oooooooooo`12ooooo`goZKgXQOooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo000looooo`03o`000?oooooooooo04;ooooo2?nY_NR9ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool003gooooo0_l00013ooooo`CoZKgXSOooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo000oooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo0010ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0T?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0011ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0T?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo
0012ooooo`;o0000?_ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00Oooool004Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2B
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00Oooool004Gooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`2Cooooo`05o`000?ooooooooooooooool000000oooool0
04Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2Cooooo`05o`000?oooooooooo
ooooool000000oooool004Oooooo0_l0000iooooo`03o`000?oooooooooo09Cooooo00Co0000oooo
oooooooo00000oooool004Wooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Eoooo
o`03o`000?oooooo000000?ooooo001:ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0UOooool01?l0003oooooooooool00002ooooo`00Boooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo09Kooooo00?o0000ooooool000000_ooool004cooooo0_l0000dooooo`03o`00
0?oooooooooo09Oooooo0_l00002ooooo`00C_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo09Kooooo0ol00002ooooo`00Coooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo09?ooooo1?l00005ooooo`00D?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
08oooooo1?l00009ooooo`00DOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo08co
oooo0ol0000=ooooo`00D_ooool2o`0002gooooo00?o0000ooooooooool0R?ooool4o`00013ooooo
001Dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Q?ooool4o`0001Cooooo001E
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0P?ooool4o`0001Sooooo001Foooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0O?ooool4o`0001cooooo001Gooooo`;o
0000:?ooool00ol0003oooooooooo`1hooooo`Co00008?ooool005Wooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1eooooo`?o00009?ooool005[ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1aooooo`Co00009oooool005_ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1]ooooo`Co0000:oooool005cooooo0_l0000Sooooo`03o`000?oooooooooo
06Wooooo1?l0000_ooooo`00G_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Go
oooo1?l0000cooooo`00Goooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo
1?l0000gooooo`00H?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05kooooo0ol0
000kooooo`00HOooool2o`0001kooooo00?o0000ooooooooool0F_ooool4o`0003kooooo001Soooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool4o`0004;ooooo001Tooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0D_ooool4o`0004Kooooo001Uooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool4o`0004[ooooo001Vooooo`;o00006Ooo
ool00ol0003oooooooooo`1:ooooo`Co0000C_ooool006Sooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`17ooooo`?o0000D_ooool006Wooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`13ooooo`Co0000EOooool006[ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0oooooo`Co0000FOooool006_ooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo
1?l0001Mooooo`00KOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo1?l0
001Qooooo`00K_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Cooooo0ol0001U
ooooo`00Koooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo1?l0001Xoooo
o`00L?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02gooooo1?l0001/ooooo`00
LOooool2o`0000gooooo00?o0000ooooooooool0:Oooool4o`00073ooooo001cooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool09Oooool4o`0007Cooooo001dooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool08Oooool4o`0007Sooooo001eooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07_ooool3o`0007cooooo001fooooo`;o00002?ooool00ol0003o
ooooooooo`0Jooooo`Co0000Ooooool007Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Fooooo`Co0000Poooool007Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Booooo`Co0000Qoooool007[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`Co0000Roooool007_ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002?oooo
o`00OOooool01?l0003oooooooooool00009ooooo`?o0000Toooool007kooooo00?o0000ooooool0
00001Oooool4o`0009Kooooo001oooooo`;o000000?oooooo`000?l000000_l0002Jooooo`00P?oo
ool2o`0009kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0020ooooo`?o0000
DOooool3o`0004Wooooo0021ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0B?oo
ool002Kooooo0ol00004ooooo`?o00000_ooool3o`0000?ooooo1Ol00002ooooo`?o00000oooool3
o`0000Cooooo0_l00008ooooo`?o00001?ooool3o`0000;ooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o00000_ooool3o`0000Cooooo0ol0
0003ooooo`Co00000_ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o0000
0_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l00002ooooo`Go0000
0oooool2o`0000Cooooo00?o0000ooooooooool01oooool3o`0000Gooooo0_l000000ooooooo0000
o`000002o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o
00000_ooool3o`000003ooooool0003o0000013ooooo000Wooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooo
oooo0000ooooool00006ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000oooooooooooooooo
o`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Aooooo`009oooool00ol0
003oooooooooo`02ooooo`Go00000_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
ooooo`Go000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool5o`0000;ooooo0ol00002ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003ooooo
o`0000Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0?ooooo`009oooool3o`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooool000000oooool01?l0003oooooooooool0000;ooooo`?o00000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo
0_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000009ooooo`?o00000oooool01?l0003oooooooooool00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00006ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00oooooo000Wooooo`04o`000?ooooooooooo`0000;ooooo0ol00002ooooo`;o000000?ooooo
o`000?l000000_ooool4o`0000;ooooo0ol00003ooooo`?o00000_ooool4o`0000Wooooo00Co0000
oooooooooooo00000_ooool3o`0000;ooooo0ol00003ooooo`Co00000_ooool4o`0000Wooooo00?o
0000ooooooooool00_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000ooo
ool2o`0000Cooooo0ol0000:ooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`0000?ooooo
0ol00002ooooo`Co00000oooool4o`000004ooooool0003o0000o`0000?ooooo1?l00002ooooo`;o
000000?oooooo`000?l000002?ooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?l0
003ooooo1?l00003ooooo`?o00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000_ooool4o`00
01;ooooo000Wooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooool0000Looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000
5?ooool00ol0003oooooooooo`0Tooooo`009_ooool4o`00017ooooo0_l0000>ooooo`03o`000?oo
oooooooo00Sooooo1?l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_oo
ool3o`0001_ooooo0_l00008ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03_ooool5o`0001Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Mooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0949149, 0.046261, \
0.00367478, 0.00367478}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -108 0 ]
[.5 .82364 108 9 ]
[.13556 .20368 -23.9342 -9 ]
[.13556 .20368 .06581 0 ]
[.33513 .12517 -5.58548 -9 ]
[.33513 .12517 .41452 0 ]
[.55094 .04033 -15.5622 -9 ]
[.55094 .04033 2.43778 0 ]
[.76193 .08858 0 -6.1701 ]
[.76193 .08858 24 2.8299 ]
[.85677 .2338 0 -6.03088 ]
[.85677 .2338 6 2.96912 ]
[.93949 .36049 0 -5.91308 ]
[.93949 .36049 18 3.08692 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.0156 .31848 -24 -2.78745 ]
[.0156 .31848 0 6.21255 ]
[.00678 .37374 -18 -2.83433 ]
[.00678 .37374 0 6.16567 ]
[-0.00235 .43098 -24 -2.88307 ]
[-0.00235 .43098 0 6.11693 ]
[-0.01182 .49032 -6 -2.93379 ]
[-0.01182 .49032 0 6.06621 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Perfect Modulation Transfer Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.14481 .21299 m
.14944 .21764 L
s
[(-100)] .13556 .20368 .99452 1 Mshowa
.3437 .13511 m
.34798 .14008 L
s
[(0)] .33513 .12517 .86183 1 Mshowa
.55867 .05093 m
.56253 .05623 L
s
[(100)] .55094 .04033 .72914 1 Mshowa
.125 Mabswid
.18339 .19788 m
.18613 .20071 L
s
.22255 .18254 m
.22525 .18541 L
s
.26232 .16697 m
.26497 .16988 L
s
.30269 .15116 m
.30531 .15411 L
s
.38535 .1188 m
.38787 .12182 L
s
.42765 .10223 m
.43013 .10529 L
s
.47063 .0854 m
.47305 .0885 L
s
.5143 .06831 m
.51667 .07145 L
s
.1068 .22787 m
.10961 .23062 L
s
.06936 .24253 m
.0722 .24525 L
s
.60376 .03327 m
.60603 .03649 L
s
.6496 .01532 m
.65181 .01859 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74963 .09314 m
.74348 .09542 L
s
[(-100)] .76193 .08858 -1 .37113 Mshowa
.84435 .23803 m
.83813 .24014 L
s
[(0)] .85677 .2338 -1 .34019 Mshowa
.92697 .36442 m
.92071 .36638 L
s
[(100)] .93949 .36049 -1 .31402 Mshowa
.125 Mabswid
.76966 .12379 m
.76597 .12514 L
s
.78913 .15357 m
.78542 .1549 L
s
.80805 .18251 m
.80434 .18382 L
s
.82645 .21065 m
.82273 .21194 L
s
.86176 .26467 m
.85803 .26592 L
s
.87871 .2906 m
.87497 .29183 L
s
.89522 .31585 m
.89148 .31706 L
s
.9113 .34045 m
.90755 .34164 L
s
.72899 .06158 m
.72531 .06297 L
s
.70774 .02907 m
.70407 .03048 L
s
.94225 .38778 m
.93849 .38895 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02786 .31382 m
.03399 .31148 L
s
[(0.25)] .0156 .31848 1 -0.38057 Mshowa
.01909 .36919 m
.02524 .36691 L
s
[(0.5)] .00678 .37374 1 -0.37015 Mshowa
.01 .42655 m
.01617 .42433 L
s
[(0.75)] -0.00235 .43098 1 -0.35932 Mshowa
.00057 .48601 m
.00677 .48385 L
s
[(1)] -0.01182 .49032 1 -0.34805 Mshowa
.125 Mabswid
.03466 .27088 m
.03833 .26946 L
s
.03298 .28151 m
.03665 .28009 L
s
.03129 .2922 m
.03496 .29079 L
s
.02958 .30297 m
.03326 .30156 L
s
.02613 .32474 m
.02981 .32334 L
s
.02439 .33573 m
.02807 .33434 L
s
.02263 .3468 m
.02632 .34542 L
s
.02087 .35796 m
.02456 .35658 L
s
.01729 .38049 m
.02099 .37914 L
s
.01549 .39188 m
.01919 .39053 L
s
.01367 .40336 m
.01737 .40201 L
s
.01184 .41491 m
.01554 .41357 L
s
.00814 .43827 m
.01185 .43694 L
s
.00627 .45007 m
.00998 .44875 L
s
.00438 .46196 m
.0081 .46065 L
s
.00249 .47394 m
.0062 .47264 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.66 .741 .91 r
.40204 .60085 .40512 .60371 .41029 .60217 .40722 .59934 Mtetra
.659 .743 .912 r
.40722 .59934 .41029 .60217 .41547 .60062 .4124 .59785 Mtetra
.658 .747 .916 r
.4124 .59785 .41547 .60062 .42066 .59907 .41759 .59636 Mtetra
.658 .751 .919 r
.41759 .59636 .42066 .59907 .42586 .59752 .4228 .59486 Mtetra
.657 .755 .922 r
.4228 .59486 .42586 .59752 .43107 .59597 .42801 .59337 Mtetra
.657 .76 .926 r
.42801 .59337 .43107 .59597 .43628 .59441 .43323 .59187 Mtetra
.656 .764 .929 r
.43323 .59187 .43628 .59441 .44151 .59285 .43847 .59037 Mtetra
.655 .769 .933 r
.43847 .59037 .44151 .59285 .44675 .59129 .44371 .58886 Mtetra
.655 .774 .936 r
.44371 .58886 .44675 .59129 .452 .58972 .44897 .58736 Mtetra
.654 .778 .94 r
.44897 .58736 .452 .58972 .45726 .58815 .45423 .58585 Mtetra
.653 .783 .944 r
.45423 .58585 .45726 .58815 .46253 .58658 .45951 .58434 Mtetra
.652 .788 .947 r
.45951 .58434 .46253 .58658 .46781 .58501 .4648 .58282 Mtetra
.65 .793 .951 r
.4648 .58282 .46781 .58501 .4731 .58343 .47009 .5813 Mtetra
.649 .798 .954 r
.47009 .5813 .4731 .58343 .4784 .58185 .4754 .57978 Mtetra
.648 .803 .957 r
.4754 .57978 .4784 .58185 .48371 .58026 .48072 .57826 Mtetra
.646 .808 .961 r
.48072 .57826 .48371 .58026 .48903 .57868 .48605 .57673 Mtetra
.644 .813 .964 r
.48605 .57673 .48903 .57868 .49436 .57709 .49139 .5752 Mtetra
.642 .818 .967 r
.49139 .5752 .49436 .57709 .49971 .57549 .49674 .57367 Mtetra
.64 .823 .971 r
.49674 .57367 .49971 .57549 .50506 .57389 .5021 .57213 Mtetra
.637 .828 .974 r
.5021 .57213 .50506 .57389 .51042 .57229 .50747 .57059 Mtetra
.635 .833 .976 r
.50747 .57059 .51042 .57229 .5158 .57069 .51285 .56905 Mtetra
.632 .838 .979 r
.51285 .56905 .5158 .57069 .52118 .56909 .51824 .5675 Mtetra
.629 .842 .982 r
.51824 .5675 .52118 .56909 .52657 .56748 .52365 .56595 Mtetra
.625 .847 .984 r
.52365 .56595 .52657 .56748 .53198 .56586 .52906 .5644 Mtetra
.622 .852 .986 r
.52906 .5644 .53198 .56586 .5374 .56425 .53449 .56285 Mtetra
.618 .856 .988 r
.53449 .56285 .5374 .56425 .54282 .56263 .53992 .56129 Mtetra
.613 .861 .99 r
.53992 .56129 .54282 .56263 .54826 .56101 .54537 .55973 Mtetra
.609 .865 .991 r
.54537 .55973 .54826 .56101 .55371 .55938 .55083 .55817 Mtetra
.603 .869 .992 r
.55083 .55817 .55371 .55938 .55917 .55775 .5563 .5566 Mtetra
.598 .873 .993 r
.5563 .5566 .55917 .55775 .56464 .55612 .56178 .55503 Mtetra
.592 .876 .993 r
.56178 .55503 .56464 .55612 .57012 .55449 .56727 .55345 Mtetra
.586 .879 .993 r
.56727 .55345 .57012 .55449 .57561 .55285 .57278 .55188 Mtetra
.579 .882 .992 r
.57278 .55188 .57561 .55285 .58111 .55121 .57829 .5503 Mtetra
.571 .884 .991 r
.57829 .5503 .58111 .55121 .58662 .54956 .58381 .54871 Mtetra
.564 .887 .989 r
.58381 .54871 .58662 .54956 .59215 .54792 .58935 .54713 Mtetra
.555 .888 .987 r
.58935 .54713 .59215 .54792 .59768 .54626 .5949 .54554 Mtetra
.546 .889 .984 r
.5949 .54554 .59768 .54626 .60323 .54461 .60046 .54394 Mtetra
.537 .89 .98 r
.60046 .54394 .60323 .54461 .60879 .54295 .60603 .54235 Mtetra
.527 .89 .975 r
.60603 .54235 .60879 .54295 .61436 .54129 .61161 .54075 Mtetra
.516 .889 .97 r
.61161 .54075 .61436 .54129 .61994 .53963 .6172 .53914 Mtetra
.505 .888 .964 r
.6172 .53914 .61994 .53963 .62553 .53796 .62281 .53754 Mtetra
.493 .886 .957 r
.62281 .53754 .62553 .53796 .63113 .53629 .62843 .53593 Mtetra
.481 .883 .949 r
.62843 .53593 .63113 .53629 .63674 .53461 .63405 .53431 Mtetra
.468 .88 .94 r
.63405 .53431 .63674 .53461 .64237 .53293 .63969 .5327 Mtetra
.454 .876 .931 r
.63969 .5327 .64237 .53293 .648 .53125 .64534 .53108 Mtetra
.44 .871 .92 r
.64534 .53108 .648 .53125 .65365 .52957 .65101 .52945 Mtetra
.426 .865 .909 r
.65101 .52945 .65365 .52957 .65931 .52788 .65668 .52782 Mtetra
.412 .859 .897 r
.65668 .52782 .65931 .52788 .66498 .52619 .66237 .52619 Mtetra
.399 .853 .885 r
.66237 .52619 .66498 .52619 .67066 .52449 .66806 .52454 Mtetra
.396 .853 .877 r
.66806 .52454 .67066 .52449 .67635 .52278 .67377 .52284 Mtetra
.41 .86 .879 r
.67377 .52284 .67635 .52278 .68206 .52107 .67949 .52106 Mtetra
.424 .867 .89 r
.67949 .52106 .68206 .52107 .68777 .51934 .68521 .51927 Mtetra
.439 .874 .902 r
.68521 .51927 .68777 .51934 .6935 .51762 .69095 .51748 Mtetra
.453 .88 .913 r
.69095 .51748 .6935 .51762 .69924 .51589 .6967 .51568 Mtetra
.468 .885 .924 r
.6967 .51568 .69924 .51589 .70499 .51415 .70246 .51387 Mtetra
.481 .889 .934 r
.70246 .51387 .70499 .51415 .71075 .51242 .70823 .51207 Mtetra
.494 .893 .943 r
.70823 .51207 .71075 .51242 .71652 .51068 .71401 .51025 Mtetra
.507 .896 .951 r
.71401 .51025 .71652 .51068 .72231 .50893 .71981 .50844 Mtetra
.518 .898 .958 r
.71981 .50844 .72231 .50893 .72811 .50718 .72561 .50662 Mtetra
.53 .899 .965 r
.72561 .50662 .72811 .50718 .73391 .50543 .73143 .5048 Mtetra
.54 .9 .97 r
.73143 .5048 .73391 .50543 .73973 .50368 .73726 .50297 Mtetra
.55 .9 .975 r
.73726 .50297 .73973 .50368 .74557 .50192 .7431 .50114 Mtetra
.56 .9 .979 r
.7431 .50114 .74557 .50192 .75141 .50016 .74895 .4993 Mtetra
.569 .899 .983 r
.74895 .4993 .75141 .50016 .75727 .49839 .75481 .49746 Mtetra
.577 .897 .985 r
.75481 .49746 .75727 .49839 .76313 .49662 .76069 .49562 Mtetra
.585 .895 .987 r
.76069 .49562 .76313 .49662 .76901 .49485 .76658 .49378 Mtetra
.592 .893 .989 r
.76658 .49378 .76901 .49485 .77491 .49307 .77248 .49193 Mtetra
.599 .89 .99 r
.77248 .49193 .77491 .49307 .78081 .49129 .77839 .49007 Mtetra
.605 .887 .99 r
.77839 .49007 .78081 .49129 .78673 .48951 .78431 .48822 Mtetra
.611 .883 .99 r
.78431 .48822 .78673 .48951 .79265 .48772 .79025 .48636 Mtetra
.616 .879 .99 r
.79025 .48636 .79265 .48772 .7986 .48593 .7962 .48449 Mtetra
.621 .875 .989 r
.7962 .48449 .7986 .48593 .80455 .48413 .80215 .48262 Mtetra
.626 .871 .988 r
.80215 .48262 .80455 .48413 .81051 .48234 .80813 .48075 Mtetra
.63 .867 .987 r
.80813 .48075 .81051 .48234 .81649 .48053 .81411 .47887 Mtetra
.634 .862 .985 r
.81411 .47887 .81649 .48053 .82248 .47873 .8201 .47699 Mtetra
.638 .858 .983 r
.8201 .47699 .82248 .47873 .82848 .47692 .82611 .47511 Mtetra
.641 .853 .981 r
.82611 .47511 .82848 .47692 .8345 .4751 .83213 .47322 Mtetra
.644 .848 .978 r
.83213 .47322 .8345 .4751 .84052 .47329 .83816 .47133 Mtetra
.647 .843 .976 r
.83816 .47133 .84052 .47329 .84656 .47147 .84421 .46944 Mtetra
.649 .838 .973 r
.84421 .46944 .84656 .47147 .85261 .46964 .85027 .46754 Mtetra
.652 .833 .97 r
.85027 .46754 .85261 .46964 .85868 .46781 .85633 .46563 Mtetra
.654 .828 .967 r
.85633 .46563 .85868 .46781 .86476 .46598 .86242 .46373 Mtetra
.656 .823 .964 r
.86242 .46373 .86476 .46598 .87084 .46414 .86851 .46182 Mtetra
.657 .818 .96 r
.86851 .46182 .87084 .46414 .87695 .4623 .87462 .4599 Mtetra
.659 .813 .957 r
.87462 .4599 .87695 .4623 .88306 .46046 .88074 .45798 Mtetra
.66 .808 .954 r
.88074 .45798 .88306 .46046 .88919 .45861 .88687 .45606 Mtetra
.662 .803 .95 r
.88687 .45606 .88919 .45861 .89533 .45676 .89301 .45414 Mtetra
.663 .798 .947 r
.89301 .45414 .89533 .45676 .90148 .45491 .89917 .45221 Mtetra
.664 .793 .943 r
.89917 .45221 .90148 .45491 .90765 .45305 .90534 .45027 Mtetra
.664 .788 .94 r
.90534 .45027 .90765 .45305 .91383 .45118 .91152 .44834 Mtetra
.665 .783 .937 r
.91152 .44834 .91383 .45118 .92002 .44932 .91771 .44639 Mtetra
.666 .778 .933 r
.91771 .44639 .92002 .44932 .92623 .44744 .92392 .44445 Mtetra
.666 .773 .93 r
.92392 .44445 .92623 .44744 .93245 .44557 .93014 .4425 Mtetra
.667 .769 .926 r
.93014 .4425 .93245 .44557 .93868 .44369 .93637 .44055 Mtetra
.667 .764 .923 r
.93637 .44055 .93868 .44369 .94492 .44181 .94262 .43859 Mtetra
.667 .76 .919 r
.94262 .43859 .94492 .44181 .95118 .43992 .94888 .43663 Mtetra
.668 .755 .916 r
.94888 .43663 .95118 .43992 .95745 .43803 .95515 .43467 Mtetra
.667 .751 .913 r
.95515 .43467 .95745 .43803 .96373 .43614 .96144 .43271 Mtetra
.667 .747 .91 r
.96144 .43271 .96373 .43614 .97003 .43424 .96774 .43075 Mtetra
.656 .74 .911 r
.39896 .59798 .40204 .60085 .40722 .59934 .40413 .59652 Mtetra
.654 .743 .915 r
.40413 .59652 .40722 .59934 .4124 .59785 .40932 .59508 Mtetra
.653 .747 .918 r
.40932 .59508 .4124 .59785 .41759 .59636 .41452 .59365 Mtetra
.652 .751 .922 r
.41452 .59365 .41759 .59636 .4228 .59486 .41973 .59222 Mtetra
.651 .756 .926 r
.41973 .59222 .4228 .59486 .42801 .59337 .42494 .59079 Mtetra
.65 .761 .93 r
.42494 .59079 .42801 .59337 .43323 .59187 .43017 .58936 Mtetra
.65 .766 .934 r
.43017 .58936 .43323 .59187 .43847 .59037 .43541 .58793 Mtetra
.649 .771 .938 r
.43541 .58793 .43847 .59037 .44371 .58886 .44066 .58649 Mtetra
.647 .777 .942 r
.44066 .58649 .44371 .58886 .44897 .58736 .44592 .58505 Mtetra
.646 .782 .946 r
.44592 .58505 .44897 .58736 .45423 .58585 .45119 .58361 Mtetra
.645 .787 .95 r
.45119 .58361 .45423 .58585 .45951 .58434 .45648 .58217 Mtetra
.643 .793 .954 r
.45648 .58217 .45951 .58434 .4648 .58282 .46177 .58072 Mtetra
.642 .798 .958 r
.46177 .58072 .4648 .58282 .47009 .5813 .46707 .57927 Mtetra
.64 .804 .962 r
.46707 .57927 .47009 .5813 .4754 .57978 .47239 .57782 Mtetra
.637 .809 .966 r
.47239 .57782 .4754 .57978 .48072 .57826 .47771 .57636 Mtetra
.635 .815 .969 r
.47771 .57636 .48072 .57826 .48605 .57673 .48305 .5749 Mtetra
.632 .82 .973 r
.48305 .5749 .48605 .57673 .49139 .5752 .48839 .57344 Mtetra
.629 .826 .976 r
.48839 .57344 .49139 .5752 .49674 .57367 .49375 .57197 Mtetra
.626 .831 .979 r
.49375 .57197 .49674 .57367 .5021 .57213 .49912 .57051 Mtetra
.623 .837 .982 r
.49912 .57051 .5021 .57213 .50747 .57059 .5045 .56904 Mtetra
.619 .842 .985 r
.5045 .56904 .50747 .57059 .51285 .56905 .50989 .56756 Mtetra
.615 .847 .987 r
.50989 .56756 .51285 .56905 .51824 .5675 .51529 .56609 Mtetra
.61 .852 .99 r
.51529 .56609 .51824 .5675 .52365 .56595 .52071 .56461 Mtetra
.605 .857 .991 r
.52071 .56461 .52365 .56595 .52906 .5644 .52613 .56312 Mtetra
.599 .861 .993 r
.52613 .56312 .52906 .5644 .53449 .56285 .53157 .56164 Mtetra
.594 .866 .994 r
.53157 .56164 .53449 .56285 .53992 .56129 .53701 .56015 Mtetra
.587 .87 .994 r
.53701 .56015 .53992 .56129 .54537 .55973 .54247 .55866 Mtetra
.58 .873 .994 r
.54247 .55866 .54537 .55973 .55083 .55817 .54794 .55716 Mtetra
.572 .876 .994 r
.54794 .55716 .55083 .55817 .5563 .5566 .55342 .55566 Mtetra
.564 .879 .992 r
.55342 .55566 .5563 .5566 .56178 .55503 .55891 .55416 Mtetra
.555 .881 .99 r
.55891 .55416 .56178 .55503 .56727 .55345 .56442 .55266 Mtetra
.546 .883 .988 r
.56442 .55266 .56727 .55345 .57278 .55188 .56993 .55115 Mtetra
.536 .884 .984 r
.56993 .55115 .57278 .55188 .57829 .5503 .57546 .54964 Mtetra
.525 .885 .979 r
.57546 .54964 .57829 .5503 .58381 .54871 .581 .54813 Mtetra
.513 .884 .974 r
.581 .54813 .58381 .54871 .58935 .54713 .58655 .54661 Mtetra
.501 .883 .968 r
.58655 .54661 .58935 .54713 .5949 .54554 .59211 .54509 Mtetra
.488 .881 .96 r
.59211 .54509 .5949 .54554 .60046 .54394 .59768 .54357 Mtetra
.474 .878 .952 r
.59768 .54357 .60046 .54394 .60603 .54235 .60326 .54204 Mtetra
.459 .874 .942 r
.60326 .54204 .60603 .54235 .61161 .54075 .60886 .54051 Mtetra
.444 .87 .931 r
.60886 .54051 .61161 .54075 .6172 .53914 .61447 .53897 Mtetra
.427 .864 .919 r
.61447 .53897 .6172 .53914 .62281 .53754 .62009 .53744 Mtetra
.411 .857 .906 r
.62009 .53744 .62281 .53754 .62843 .53593 .62572 .5359 Mtetra
.393 .849 .891 r
.62572 .5359 .62843 .53593 .63405 .53431 .63136 .53435 Mtetra
.375 .84 .876 r
.63136 .53435 .63405 .53431 .63969 .5327 .63702 .53281 Mtetra
.357 .83 .859 r
.63702 .53281 .63969 .5327 .64534 .53108 .64268 .53125 Mtetra
.338 .819 .841 r
.64268 .53125 .64534 .53108 .65101 .52945 .64836 .5297 Mtetra
.318 .807 .823 r
.64836 .5297 .65101 .52945 .65668 .52782 .65405 .52814 Mtetra
.3 .796 .804 r
.65405 .52814 .65668 .52782 .66237 .52619 .65975 .52657 Mtetra
.285 .785 .786 r
.65975 .52657 .66237 .52619 .66806 .52454 .66547 .52498 Mtetra
.292 .788 .778 r
.66547 .52498 .66806 .52454 .67377 .52284 .67119 .52329 Mtetra
.322 .808 .788 r
.67119 .52329 .67377 .52284 .67949 .52106 .67692 .52144 Mtetra
.342 .821 .805 r
.67692 .52144 .67949 .52106 .68521 .51927 .68265 .51958 Mtetra
.362 .833 .824 r
.68265 .51958 .68521 .51927 .69095 .51748 .6884 .51771 Mtetra
.381 .845 .842 r
.6884 .51771 .69095 .51748 .6967 .51568 .69416 .51583 Mtetra
.4 .856 .859 r
.69416 .51583 .6967 .51568 .70246 .51387 .69993 .51395 Mtetra
.418 .865 .875 r
.69993 .51395 .70246 .51387 .70823 .51207 .70571 .51206 Mtetra
.436 .874 .89 r
.70571 .51206 .70823 .51207 .71401 .51025 .7115 .51017 Mtetra
.453 .881 .904 r
.7115 .51017 .71401 .51025 .71981 .50844 .71731 .50827 Mtetra
.469 .887 .917 r
.71731 .50827 .71981 .50844 .72561 .50662 .72312 .50637 Mtetra
.484 .893 .928 r
.72312 .50637 .72561 .50662 .73143 .5048 .72895 .50447 Mtetra
.499 .897 .939 r
.72895 .50447 .73143 .5048 .73726 .50297 .73479 .50256 Mtetra
.513 .9 .948 r
.73479 .50256 .73726 .50297 .7431 .50114 .74064 .50065 Mtetra
.526 .903 .956 r
.74064 .50065 .7431 .50114 .74895 .4993 .7465 .49873 Mtetra
.539 .904 .964 r
.7465 .49873 .74895 .4993 .75481 .49746 .75237 .49681 Mtetra
.55 .905 .97 r
.75237 .49681 .75481 .49746 .76069 .49562 .75825 .49489 Mtetra
.561 .905 .975 r
.75825 .49489 .76069 .49562 .76658 .49378 .76415 .49296 Mtetra
.572 .904 .979 r
.76415 .49296 .76658 .49378 .77248 .49193 .77006 .49103 Mtetra
.581 .902 .983 r
.77006 .49103 .77248 .49193 .77839 .49007 .77597 .4891 Mtetra
.59 .9 .985 r
.77597 .4891 .77839 .49007 .78431 .48822 .7819 .48716 Mtetra
.598 .898 .987 r
.7819 .48716 .78431 .48822 .79025 .48636 .78785 .48522 Mtetra
.605 .895 .988 r
.78785 .48522 .79025 .48636 .7962 .48449 .7938 .48327 Mtetra
.612 .891 .989 r
.7938 .48327 .7962 .48449 .80215 .48262 .79977 .48132 Mtetra
.619 .887 .989 r
.79977 .48132 .80215 .48262 .80813 .48075 .80574 .47937 Mtetra
.625 .883 .989 r
.80574 .47937 .80813 .48075 .81411 .47887 .81173 .47741 Mtetra
.63 .878 .988 r
.81173 .47741 .81411 .47887 .8201 .47699 .81773 .47545 Mtetra
.635 .873 .986 r
.81773 .47545 .8201 .47699 .82611 .47511 .82375 .47348 Mtetra
.639 .868 .984 r
.82375 .47348 .82611 .47511 .83213 .47322 .82977 .47151 Mtetra
.643 .863 .982 r
.82977 .47151 .83213 .47322 .83816 .47133 .83581 .46954 Mtetra
.647 .858 .98 r
.83581 .46954 .83816 .47133 .84421 .46944 .84186 .46756 Mtetra
.65 .852 .977 r
.84186 .46756 .84421 .46944 .85027 .46754 .84792 .46558 Mtetra
.653 .847 .974 r
.84792 .46558 .85027 .46754 .85633 .46563 .85399 .46359 Mtetra
.656 .841 .971 r
.85399 .46359 .85633 .46563 .86242 .46373 .86008 .4616 Mtetra
.658 .835 .968 r
.86008 .4616 .86242 .46373 .86851 .46182 .86618 .45961 Mtetra
.66 .83 .965 r
.86618 .45961 .86851 .46182 .87462 .4599 .87229 .45761 Mtetra
.662 .824 .961 r
.87229 .45761 .87462 .4599 .88074 .45798 .87841 .45561 Mtetra
.664 .818 .958 r
.87841 .45561 .88074 .45798 .88687 .45606 .88454 .45361 Mtetra
.665 .813 .954 r
.88454 .45361 .88687 .45606 .89301 .45414 .89069 .4516 Mtetra
.667 .807 .95 r
.89069 .4516 .89301 .45414 .89917 .45221 .89685 .44959 Mtetra
.668 .801 .946 r
.89685 .44959 .89917 .45221 .90534 .45027 .90302 .44757 Mtetra
.669 .796 .943 r
.90302 .44757 .90534 .45027 .91152 .44834 .90921 .44555 Mtetra
.67 .79 .939 r
.90921 .44555 .91152 .44834 .91771 .44639 .9154 .44353 Mtetra
.67 .785 .935 r
.9154 .44353 .91771 .44639 .92392 .44445 .92161 .4415 Mtetra
.671 .779 .931 r
.92161 .4415 .92392 .44445 .93014 .4425 .92783 .43947 Mtetra
.671 .774 .927 r
.92783 .43947 .93014 .4425 .93637 .44055 .93407 .43743 Mtetra
.672 .769 .923 r
.93407 .43743 .93637 .44055 .94262 .43859 .94032 .43539 Mtetra
.672 .764 .919 r
.94032 .43539 .94262 .43859 .94888 .43663 .94658 .43335 Mtetra
.672 .759 .916 r
.94658 .43335 .94888 .43663 .95515 .43467 .95285 .43131 Mtetra
.672 .754 .912 r
.95285 .43131 .95515 .43467 .96144 .43271 .95914 .42927 Mtetra
.671 .749 .909 r
.95914 .42927 .96144 .43271 .96774 .43075 .96544 .42725 Mtetra
.652 .739 .913 r
.39586 .5951 .39896 .59798 .40413 .59652 .40104 .59368 Mtetra
.649 .741 .917 r
.40104 .59368 .40413 .59652 .40932 .59508 .40623 .59231 Mtetra
.647 .746 .921 r
.40623 .59231 .40932 .59508 .41452 .59365 .41143 .59095 Mtetra
.646 .751 .926 r
.41143 .59095 .41452 .59365 .41973 .59222 .41664 .58959 Mtetra
.645 .756 .93 r
.41664 .58959 .41973 .59222 .42494 .59079 .42187 .58823 Mtetra
.644 .761 .934 r
.42187 .58823 .42494 .59079 .43017 .58936 .4271 .58687 Mtetra
.643 .767 .938 r
.4271 .58687 .43017 .58936 .43541 .58793 .43234 .58551 Mtetra
.641 .772 .943 r
.43234 .58551 .43541 .58793 .44066 .58649 .4376 .58415 Mtetra
.64 .778 .947 r
.4376 .58415 .44066 .58649 .44592 .58505 .44286 .58278 Mtetra
.638 .784 .951 r
.44286 .58278 .44592 .58505 .45119 .58361 .44814 .58141 Mtetra
.636 .789 .955 r
.44814 .58141 .45119 .58361 .45648 .58217 .45343 .58004 Mtetra
.634 .795 .96 r
.45343 .58004 .45648 .58217 .46177 .58072 .45873 .57867 Mtetra
.632 .801 .964 r
.45873 .57867 .46177 .58072 .46707 .57927 .46404 .57729 Mtetra
.63 .807 .968 r
.46404 .57729 .46707 .57927 .47239 .57782 .46936 .57591 Mtetra
.627 .812 .971 r
.46936 .57591 .47239 .57782 .47771 .57636 .47469 .57453 Mtetra
.624 .818 .975 r
.47469 .57453 .47771 .57636 .48305 .5749 .48003 .57314 Mtetra
.62 .824 .979 r
.48003 .57314 .48305 .5749 .48839 .57344 .48539 .57175 Mtetra
.617 .83 .982 r
.48539 .57175 .48839 .57344 .49375 .57197 .49075 .57036 Mtetra
.613 .835 .985 r
.49075 .57036 .49375 .57197 .49912 .57051 .49613 .56897 Mtetra
.608 .841 .988 r
.49613 .56897 .49912 .57051 .5045 .56904 .50152 .56757 Mtetra
.603 .846 .99 r
.50152 .56757 .5045 .56904 .50989 .56756 .50692 .56617 Mtetra
.598 .851 .992 r
.50692 .56617 .50989 .56756 .51529 .56609 .51233 .56477 Mtetra
.592 .856 .994 r
.51233 .56477 .51529 .56609 .52071 .56461 .51775 .56336 Mtetra
.585 .86 .995 r
.51775 .56336 .52071 .56461 .52613 .56312 .52319 .56195 Mtetra
.578 .864 .995 r
.52319 .56195 .52613 .56312 .53157 .56164 .52863 .56054 Mtetra
.571 .868 .995 r
.52863 .56054 .53157 .56164 .53701 .56015 .53409 .55913 Mtetra
.562 .871 .995 r
.53409 .55913 .53701 .56015 .54247 .55866 .53956 .55771 Mtetra
.554 .874 .993 r
.53956 .55771 .54247 .55866 .54794 .55716 .54504 .55629 Mtetra
.544 .876 .991 r
.54504 .55629 .54794 .55716 .55342 .55566 .55053 .55486 Mtetra
.533 .878 .988 r
.55053 .55486 .55342 .55566 .55891 .55416 .55603 .55344 Mtetra
.522 .879 .984 r
.55603 .55344 .55891 .55416 .56442 .55266 .56155 .55201 Mtetra
.51 .879 .978 r
.56155 .55201 .56442 .55266 .56993 .55115 .56708 .55057 Mtetra
.497 .878 .972 r
.56708 .55057 .56993 .55115 .57546 .54964 .57261 .54914 Mtetra
.483 .876 .965 r
.57261 .54914 .57546 .54964 .581 .54813 .57816 .5477 Mtetra
.469 .873 .956 r
.57816 .5477 .581 .54813 .58655 .54661 .58373 .54626 Mtetra
.453 .869 .946 r
.58373 .54626 .58655 .54661 .59211 .54509 .5893 .54481 Mtetra
.437 .865 .935 r
.5893 .54481 .59211 .54509 .59768 .54357 .59489 .54336 Mtetra
.42 .858 .922 r
.59489 .54336 .59768 .54357 .60326 .54204 .60049 .54191 Mtetra
.402 .851 .908 r
.60049 .54191 .60326 .54204 .60886 .54051 .6061 .54046 Mtetra
.383 .843 .893 r
.6061 .54046 .60886 .54051 .61447 .53897 .61172 .539 Mtetra
.364 .833 .876 r
.61172 .539 .61447 .53897 .62009 .53744 .61735 .53753 Mtetra
.344 .822 .858 r
.61735 .53753 .62009 .53744 .62572 .5359 .623 .53607 Mtetra
.323 .81 .839 r
.623 .53607 .62572 .5359 .63136 .53435 .62866 .5346 Mtetra
.302 .797 .818 r
.62866 .5346 .63136 .53435 .63702 .53281 .63433 .53313 Mtetra
.281 .783 .797 r
.63433 .53313 .63702 .53281 .64268 .53125 .64001 .53165 Mtetra
.259 .768 .774 r
.64001 .53165 .64268 .53125 .64836 .5297 .64571 .53017 Mtetra
.238 .752 .751 r
.64571 .53017 .64836 .5297 .65405 .52814 .65142 .52869 Mtetra
.219 .737 .729 r
.65142 .52869 .65405 .52814 .65975 .52657 .65714 .52719 Mtetra
.204 .724 .708 r
.65714 .52719 .65975 .52657 .66547 .52498 .66287 .52566 Mtetra
.222 .735 .704 r
.66287 .52566 .66547 .52498 .67119 .52329 .6686 .52398 Mtetra
.271 .769 .724 r
.6686 .52398 .67119 .52329 .67692 .52144 .67434 .52206 Mtetra
.294 .786 .745 r
.67434 .52206 .67692 .52144 .68265 .51958 .68009 .52012 Mtetra
.317 .803 .768 r
.68009 .52012 .68265 .51958 .6884 .51771 .68585 .51817 Mtetra
.339 .818 .79 r
.68585 .51817 .6884 .51771 .69416 .51583 .69162 .5162 Mtetra
.361 .832 .811 r
.69162 .5162 .69416 .51583 .69993 .51395 .6974 .51423 Mtetra
.381 .845 .831 r
.6974 .51423 .69993 .51395 .70571 .51206 .70319 .51226 Mtetra
.402 .857 .85 r
.70319 .51226 .70571 .51206 .7115 .51017 .70899 .51028 Mtetra
.421 .867 .867 r
.70899 .51028 .7115 .51017 .71731 .50827 .71481 .5083 Mtetra
.44 .877 .884 r
.71481 .5083 .71731 .50827 .72312 .50637 .72063 .50632 Mtetra
.458 .885 .899 r
.72063 .50632 .72312 .50637 .72895 .50447 .72647 .50433 Mtetra
.475 .892 .913 r
.72647 .50433 .72895 .50447 .73479 .50256 .73231 .50233 Mtetra
.492 .897 .925 r
.73231 .50233 .73479 .50256 .74064 .50065 .73817 .50034 Mtetra
.507 .902 .936 r
.73817 .50034 .74064 .50065 .7465 .49873 .74404 .49833 Mtetra
.522 .905 .946 r
.74404 .49833 .7465 .49873 .75237 .49681 .74992 .49633 Mtetra
.536 .908 .955 r
.74992 .49633 .75237 .49681 .75825 .49489 .75581 .49432 Mtetra
.549 .909 .963 r
.75581 .49432 .75825 .49489 .76415 .49296 .76172 .49231 Mtetra
.561 .91 .969 r
.76172 .49231 .76415 .49296 .77006 .49103 .76763 .49029 Mtetra
.572 .909 .974 r
.76763 .49029 .77006 .49103 .77597 .4891 .77356 .48827 Mtetra
.583 .908 .979 r
.77356 .48827 .77597 .4891 .7819 .48716 .7795 .48624 Mtetra
.592 .906 .982 r
.7795 .48624 .7819 .48716 .78785 .48522 .78545 .48421 Mtetra
.601 .904 .984 r
.78545 .48421 .78785 .48522 .7938 .48327 .79141 .48218 Mtetra
.609 .901 .986 r
.79141 .48218 .7938 .48327 .79977 .48132 .79738 .48014 Mtetra
.617 .897 .987 r
.79738 .48014 .79977 .48132 .80574 .47937 .80336 .4781 Mtetra
.624 .893 .987 r
.80336 .4781 .80574 .47937 .81173 .47741 .80936 .47606 Mtetra
.63 .889 .987 r
.80936 .47606 .81173 .47741 .81773 .47545 .81536 .47401 Mtetra
.636 .884 .986 r
.81536 .47401 .81773 .47545 .82375 .47348 .82138 .47196 Mtetra
.641 .879 .985 r
.82138 .47196 .82375 .47348 .82977 .47151 .82741 .4699 Mtetra
.646 .873 .983 r
.82741 .4699 .82977 .47151 .83581 .46954 .83346 .46784 Mtetra
.65 .868 .981 r
.83346 .46784 .83581 .46954 .84186 .46756 .83951 .46577 Mtetra
.653 .862 .979 r
.83951 .46577 .84186 .46756 .84792 .46558 .84557 .46371 Mtetra
.657 .856 .976 r
.84557 .46371 .84792 .46558 .85399 .46359 .85165 .46163 Mtetra
.66 .85 .973 r
.85165 .46163 .85399 .46359 .86008 .4616 .85774 .45956 Mtetra
.663 .844 .97 r
.85774 .45956 .86008 .4616 .86618 .45961 .86384 .45748 Mtetra
.665 .838 .966 r
.86384 .45748 .86618 .45961 .87229 .45761 .86996 .45539 Mtetra
.667 .832 .963 r
.86996 .45539 .87229 .45761 .87841 .45561 .87608 .4533 Mtetra
.669 .826 .959 r
.87608 .4533 .87841 .45561 .88454 .45361 .88222 .45121 Mtetra
.67 .82 .955 r
.88222 .45121 .88454 .45361 .89069 .4516 .88837 .44911 Mtetra
.672 .814 .951 r
.88837 .44911 .89069 .4516 .89685 .44959 .89453 .44701 Mtetra
.673 .808 .947 r
.89453 .44701 .89685 .44959 .90302 .44757 .9007 .44491 Mtetra
.674 .802 .943 r
.9007 .44491 .90302 .44757 .90921 .44555 .90689 .4428 Mtetra
.675 .796 .939 r
.90689 .4428 .90921 .44555 .9154 .44353 .91309 .44069 Mtetra
.676 .79 .935 r
.91309 .44069 .9154 .44353 .92161 .4415 .9193 .43857 Mtetra
.676 .784 .931 r
.9193 .43857 .92161 .4415 .92783 .43947 .92552 .43645 Mtetra
.677 .778 .927 r
.92552 .43645 .92783 .43947 .93407 .43743 .93176 .43433 Mtetra
.677 .773 .923 r
.93176 .43433 .93407 .43743 .94032 .43539 .938 .4322 Mtetra
.677 .767 .919 r
.938 .4322 .94032 .43539 .94658 .43335 .94426 .43007 Mtetra
.677 .761 .915 r
.94426 .43007 .94658 .43335 .95285 .43131 .95054 .42794 Mtetra
.676 .756 .911 r
.95054 .42794 .95285 .43131 .95914 .42927 .95683 .42583 Mtetra
.675 .751 .908 r
.95683 .42583 .95914 .42927 .96544 .42725 .96313 .42373 Mtetra
.648 .738 .915 r
.39275 .5922 .39586 .5951 .40104 .59368 .39793 .59084 Mtetra
.643 .74 .919 r
.39793 .59084 .40104 .59368 .40623 .59231 .40313 .58953 Mtetra
.641 .744 .924 r
.40313 .58953 .40623 .59231 .41143 .59095 .40833 .58824 Mtetra
.639 .749 .928 r
.40833 .58824 .41143 .59095 .41664 .58959 .41355 .58696 Mtetra
.638 .755 .933 r
.41355 .58696 .41664 .58959 .42187 .58823 .41877 .58568 Mtetra
.636 .76 .937 r
.41877 .58568 .42187 .58823 .4271 .58687 .42401 .58439 Mtetra
.635 .766 .942 r
.42401 .58439 .4271 .58687 .43234 .58551 .42926 .58311 Mtetra
.634 .772 .946 r
.42926 .58311 .43234 .58551 .4376 .58415 .43452 .58182 Mtetra
.632 .778 .951 r
.43452 .58182 .4376 .58415 .44286 .58278 .43979 .58053 Mtetra
.63 .783 .955 r
.43979 .58053 .44286 .58278 .44814 .58141 .44507 .57924 Mtetra
.628 .789 .96 r
.44507 .57924 .44814 .58141 .45343 .58004 .45037 .57794 Mtetra
.625 .795 .964 r
.45037 .57794 .45343 .58004 .45873 .57867 .45567 .57664 Mtetra
.623 .801 .968 r
.45567 .57664 .45873 .57867 .46404 .57729 .46099 .57534 Mtetra
.62 .807 .972 r
.46099 .57534 .46404 .57729 .46936 .57591 .46632 .57404 Mtetra
.616 .813 .976 r
.46632 .57404 .46936 .57591 .47469 .57453 .47166 .57273 Mtetra
.613 .819 .979 r
.47166 .57273 .47469 .57453 .48003 .57314 .47701 .57142 Mtetra
.609 .825 .983 r
.47701 .57142 .48003 .57314 .48539 .57175 .48237 .57011 Mtetra
.604 .83 .986 r
.48237 .57011 .48539 .57175 .49075 .57036 .48774 .56879 Mtetra
.6 .836 .989 r
.48774 .56879 .49075 .57036 .49613 .56897 .49313 .56748 Mtetra
.594 .841 .991 r
.49313 .56748 .49613 .56897 .50152 .56757 .49852 .56616 Mtetra
.588 .846 .993 r
.49852 .56616 .50152 .56757 .50692 .56617 .50393 .56483 Mtetra
.582 .851 .995 r
.50393 .56483 .50692 .56617 .51233 .56477 .50935 .56351 Mtetra
.575 .855 .996 r
.50935 .56351 .51233 .56477 .51775 .56336 .51478 .56218 Mtetra
.568 .86 .996 r
.51478 .56218 .51775 .56336 .52319 .56195 .52023 .56084 Mtetra
.559 .863 .996 r
.52023 .56084 .52319 .56195 .52863 .56054 .52568 .55951 Mtetra
.55 .866 .995 r
.52568 .55951 .52863 .56054 .53409 .55913 .53115 .55817 Mtetra
.541 .869 .994 r
.53115 .55817 .53409 .55913 .53956 .55771 .53663 .55683 Mtetra
.53 .871 .991 r
.53663 .55683 .53956 .55771 .54504 .55629 .54212 .55549 Mtetra
.519 .872 .987 r
.54212 .55549 .54504 .55629 .55053 .55486 .54762 .55414 Mtetra
.507 .872 .982 r
.54762 .55414 .55053 .55486 .55603 .55344 .55314 .55279 Mtetra
.494 .872 .977 r
.55314 .55279 .55603 .55344 .56155 .55201 .55867 .55144 Mtetra
.48 .871 .969 r
.55867 .55144 .56155 .55201 .56708 .55057 .56421 .55009 Mtetra
.465 .868 .961 r
.56421 .55009 .56708 .55057 .57261 .54914 .56976 .54873 Mtetra
.449 .865 .951 r
.56976 .54873 .57261 .54914 .57816 .5477 .57532 .54737 Mtetra
.433 .86 .94 r
.57532 .54737 .57816 .5477 .58373 .54626 .5809 .546 Mtetra
.415 .854 .928 r
.5809 .546 .58373 .54626 .5893 .54481 .58648 .54463 Mtetra
.397 .847 .914 r
.58648 .54463 .5893 .54481 .59489 .54336 .59208 .54326 Mtetra
.377 .838 .898 r
.59208 .54326 .59489 .54336 .60049 .54191 .5977 .54189 Mtetra
.357 .829 .881 r
.5977 .54189 .60049 .54191 .6061 .54046 .60332 .54051 Mtetra
.337 .817 .863 r
.60332 .54051 .6061 .54046 .61172 .539 .60896 .53913 Mtetra
.315 .805 .843 r
.60896 .53913 .61172 .539 .61735 .53753 .61461 .53775 Mtetra
.294 .792 .822 r
.61461 .53775 .61735 .53753 .623 .53607 .62027 .53636 Mtetra
.271 .777 .8 r
.62027 .53636 .623 .53607 .62866 .5346 .62594 .53497 Mtetra
.249 .761 .776 r
.62594 .53497 .62866 .5346 .63433 .53313 .63163 .53358 Mtetra
.226 .745 .752 r
.63163 .53358 .63433 .53313 .64001 .53165 .63733 .53218 Mtetra
.204 .727 .727 r
.63733 .53218 .64001 .53165 .64571 .53017 .64304 .53078 Mtetra
.182 .709 .701 r
.64304 .53078 .64571 .53017 .65142 .52869 .64877 .52937 Mtetra
0 0 0 r
.64877 .52937 .65142 .52869 .65714 .52719 .65451 .52795 Mtetra
.65451 .52795 .65714 .52719 .66287 .52566 .66025 .52649 Mtetra
.66025 .52649 .66287 .52566 .6686 .52398 .66601 .52481 Mtetra
.248 .749 .688 r
.66601 .52481 .6686 .52398 .67434 .52206 .67176 .52282 Mtetra
.274 .768 .711 r
.67176 .52282 .67434 .52206 .68009 .52012 .67752 .5208 Mtetra
.299 .787 .736 r
.67752 .5208 .68009 .52012 .68585 .51817 .68329 .51876 Mtetra
.322 .805 .76 r
.68329 .51876 .68585 .51817 .69162 .5162 .68907 .51671 Mtetra
.345 .82 .783 r
.68907 .51671 .69162 .5162 .6974 .51423 .69486 .51465 Mtetra
.367 .835 .805 r
.69486 .51465 .6974 .51423 .70319 .51226 .70066 .51259 Mtetra
.388 .849 .826 r
.70066 .51259 .70319 .51226 .70899 .51028 .70647 .51052 Mtetra
.409 .861 .845 r
.70647 .51052 .70899 .51028 .71481 .5083 .7123 .50845 Mtetra
.429 .872 .864 r
.7123 .50845 .71481 .5083 .72063 .50632 .71813 .50638 Mtetra
.449 .881 .881 r
.71813 .50638 .72063 .50632 .72647 .50433 .72398 .5043 Mtetra
.467 .89 .896 r
.72398 .5043 .72647 .50433 .73231 .50233 .72983 .50221 Mtetra
.485 .897 .911 r
.72983 .50221 .73231 .50233 .73817 .50034 .7357 .50013 Mtetra
.502 .903 .923 r
.7357 .50013 .73817 .50034 .74404 .49833 .74158 .49804 Mtetra
.518 .907 .935 r
.74158 .49804 .74404 .49833 .74992 .49633 .74747 .49594 Mtetra
.533 .911 .945 r
.74747 .49594 .74992 .49633 .75581 .49432 .75337 .49384 Mtetra
.547 .913 .954 r
.75337 .49384 .75581 .49432 .76172 .49231 .75928 .49174 Mtetra
.56 .914 .962 r
.75928 .49174 .76172 .49231 .76763 .49029 .7652 .48963 Mtetra
.572 .915 .968 r
.7652 .48963 .76763 .49029 .77356 .48827 .77114 .48752 Mtetra
.583 .914 .973 r
.77114 .48752 .77356 .48827 .7795 .48624 .77708 .48541 Mtetra
.594 .913 .978 r
.77708 .48541 .7795 .48624 .78545 .48421 .78304 .48329 Mtetra
.603 .911 .981 r
.78304 .48329 .78545 .48421 .79141 .48218 .789 .48117 Mtetra
.612 .908 .983 r
.789 .48117 .79141 .48218 .79738 .48014 .79498 .47904 Mtetra
.62 .904 .985 r
.79498 .47904 .79738 .48014 .80336 .4781 .80097 .47691 Mtetra
.627 .9 .986 r
.80097 .47691 .80336 .4781 .80936 .47606 .80697 .47478 Mtetra
.634 .896 .986 r
.80697 .47478 .80936 .47606 .81536 .47401 .81299 .47264 Mtetra
.64 .891 .985 r
.81299 .47264 .81536 .47401 .82138 .47196 .81901 .47049 Mtetra
.645 .886 .984 r
.81901 .47049 .82138 .47196 .82741 .4699 .82505 .46835 Mtetra
.65 .88 .983 r
.82505 .46835 .82741 .4699 .83346 .46784 .83109 .4662 Mtetra
.655 .875 .981 r
.83109 .4662 .83346 .46784 .83951 .46577 .83715 .46404 Mtetra
.659 .869 .978 r
.83715 .46404 .83951 .46577 .84557 .46371 .84322 .46188 Mtetra
.662 .863 .976 r
.84322 .46188 .84557 .46371 .85165 .46163 .8493 .45972 Mtetra
.665 .857 .973 r
.8493 .45972 .85165 .46163 .85774 .45956 .8554 .45755 Mtetra
.668 .85 .97 r
.8554 .45755 .85774 .45956 .86384 .45748 .8615 .45538 Mtetra
.671 .844 .966 r
.8615 .45538 .86384 .45748 .86996 .45539 .86762 .4532 Mtetra
.673 .838 .962 r
.86762 .4532 .86996 .45539 .87608 .4533 .87375 .45102 Mtetra
.675 .831 .959 r
.87375 .45102 .87608 .4533 .88222 .45121 .87989 .44884 Mtetra
.676 .825 .955 r
.87989 .44884 .88222 .45121 .88837 .44911 .88604 .44665 Mtetra
.678 .819 .951 r
.88604 .44665 .88837 .44911 .89453 .44701 .8922 .44446 Mtetra
.679 .812 .947 r
.8922 .44446 .89453 .44701 .9007 .44491 .89838 .44226 Mtetra
.68 .806 .943 r
.89838 .44226 .9007 .44491 .90689 .4428 .90457 .44006 Mtetra
.681 .8 .938 r
.90457 .44006 .90689 .4428 .91309 .44069 .91077 .43786 Mtetra
.681 .794 .934 r
.91077 .43786 .91309 .44069 .9193 .43857 .91698 .43565 Mtetra
.682 .788 .93 r
.91698 .43565 .9193 .43857 .92552 .43645 .9232 .43344 Mtetra
.682 .782 .926 r
.9232 .43344 .92552 .43645 .93176 .43433 .92944 .43122 Mtetra
.682 .776 .922 r
.92944 .43122 .93176 .43433 .938 .4322 .93568 .429 Mtetra
.682 .77 .918 r
.93568 .429 .938 .4322 .94426 .43007 .94194 .42678 Mtetra
.682 .764 .914 r
.94194 .42678 .94426 .43007 .95054 .42794 .94822 .42457 Mtetra
.681 .758 .91 r
.94822 .42457 .95054 .42794 .95683 .42583 .95451 .42237 Mtetra
.679 .753 .907 r
.95451 .42237 .95683 .42583 .96313 .42373 .96081 .4202 Mtetra
.643 .736 .916 r
.38963 .5893 .39275 .5922 .39793 .59084 .39482 .58799 Mtetra
.637 .739 .922 r
.39482 .58799 .39793 .59084 .40313 .58953 .40001 .58675 Mtetra
.634 .743 .926 r
.40001 .58675 .40313 .58953 .40833 .58824 .40522 .58553 Mtetra
.632 .748 .931 r
.40522 .58553 .40833 .58824 .41355 .58696 .41044 .58432 Mtetra
.631 .753 .936 r
.41044 .58432 .41355 .58696 .41877 .58568 .41567 .58312 Mtetra
.629 .759 .94 r
.41567 .58312 .41877 .58568 .42401 .58439 .42091 .58191 Mtetra
.628 .765 .945 r
.42091 .58191 .42401 .58439 .42926 .58311 .42617 .5807 Mtetra
.626 .77 .949 r
.42617 .5807 .42926 .58311 .43452 .58182 .43143 .57949 Mtetra
.624 .776 .954 r
.43143 .57949 .43452 .58182 .43979 .58053 .43671 .57828 Mtetra
.621 .782 .958 r
.43671 .57828 .43979 .58053 .44507 .57924 .442 .57706 Mtetra
.619 .788 .963 r
.442 .57706 .44507 .57924 .45037 .57794 .44729 .57584 Mtetra
.616 .794 .967 r
.44729 .57584 .45037 .57794 .45567 .57664 .45261 .57462 Mtetra
.613 .8 .971 r
.45261 .57462 .45567 .57664 .46099 .57534 .45793 .5734 Mtetra
.61 .806 .975 r
.45793 .5734 .46099 .57534 .46632 .57404 .46326 .57217 Mtetra
.606 .812 .979 r
.46326 .57217 .46632 .57404 .47166 .57273 .46861 .57094 Mtetra
.602 .817 .982 r
.46861 .57094 .47166 .57273 .47701 .57142 .47397 .56971 Mtetra
.598 .823 .986 r
.47397 .56971 .47701 .57142 .48237 .57011 .47933 .56847 Mtetra
.593 .829 .989 r
.47933 .56847 .48237 .57011 .48774 .56879 .48472 .56724 Mtetra
.587 .834 .991 r
.48472 .56724 .48774 .56879 .49313 .56748 .49011 .566 Mtetra
.582 .839 .994 r
.49011 .566 .49313 .56748 .49852 .56616 .49551 .56476 Mtetra
.575 .844 .995 r
.49551 .56476 .49852 .56616 .50393 .56483 .50093 .56351 Mtetra
.568 .848 .997 r
.50093 .56351 .50393 .56483 .50935 .56351 .50636 .56226 Mtetra
.56 .853 .997 r
.50636 .56226 .50935 .56351 .51478 .56218 .5118 .56101 Mtetra
.552 .856 .997 r
.5118 .56101 .51478 .56218 .52023 .56084 .51725 .55976 Mtetra
.543 .86 .997 r
.51725 .55976 .52023 .56084 .52568 .55951 .52272 .5585 Mtetra
.533 .862 .995 r
.52272 .5585 .52568 .55951 .53115 .55817 .5282 .55724 Mtetra
.523 .864 .992 r
.5282 .55724 .53115 .55817 .53663 .55683 .53369 .55598 Mtetra
.511 .866 .989 r
.53369 .55598 .53663 .55683 .54212 .55549 .53919 .55472 Mtetra
.499 .866 .984 r
.53919 .55472 .54212 .55549 .54762 .55414 .5447 .55345 Mtetra
.486 .866 .979 r
.5447 .55345 .54762 .55414 .55314 .55279 .55023 .55218 Mtetra
.472 .864 .972 r
.55023 .55218 .55314 .55279 .55867 .55144 .55577 .5509 Mtetra
.457 .862 .963 r
.55577 .5509 .55867 .55144 .56421 .55009 .56132 .54963 Mtetra
.441 .858 .954 r
.56132 .54963 .56421 .55009 .56976 .54873 .56688 .54835 Mtetra
.424 .854 .943 r
.56688 .54835 .56976 .54873 .57532 .54737 .57246 .54707 Mtetra
.406 .848 .93 r
.57246 .54707 .57532 .54737 .5809 .546 .57805 .54578 Mtetra
.387 .84 .916 r
.57805 .54578 .5809 .546 .58648 .54463 .58365 .54449 Mtetra
.368 .832 .901 r
.58365 .54449 .58648 .54463 .59208 .54326 .58926 .5432 Mtetra
.348 .822 .884 r
.58926 .5432 .59208 .54326 .5977 .54189 .59489 .54191 Mtetra
.327 .811 .865 r
.59489 .54191 .5977 .54189 .60332 .54051 .60053 .54061 Mtetra
.305 .799 .845 r
.60053 .54061 .60332 .54051 .60896 .53913 .60618 .53931 Mtetra
.283 .785 .824 r
.60618 .53931 .60896 .53913 .61461 .53775 .61185 .53801 Mtetra
.261 .77 .801 r
.61185 .53801 .61461 .53775 .62027 .53636 .61753 .5367 Mtetra
.238 .754 .777 r
.61753 .5367 .62027 .53636 .62594 .53497 .62322 .53539 Mtetra
.215 .737 .753 r
.62322 .53539 .62594 .53497 .63163 .53358 .62892 .53408 Mtetra
.192 .719 .727 r
.62892 .53408 .63163 .53358 .63733 .53218 .63464 .53277 Mtetra
.169 .701 .701 r
.63464 .53277 .63733 .53218 .64304 .53078 .64037 .53145 Mtetra
0 0 0 r
.64037 .53145 .64304 .53078 .64877 .52937 .64611 .53012 Mtetra
.64611 .53012 .64877 .52937 .65451 .52795 .65186 .52877 Mtetra
.65186 .52877 .65451 .52795 .66025 .52649 .65763 .52737 Mtetra
.65763 .52737 .66025 .52649 .66601 .52481 .6634 .52571 Mtetra
.249 .747 .678 r
.6634 .52571 .66601 .52481 .67176 .52282 .66916 .52364 Mtetra
.277 .768 .703 r
.66916 .52364 .67176 .52282 .67752 .5208 .67493 .52154 Mtetra
.303 .788 .728 r
.67493 .52154 .67752 .5208 .68329 .51876 .68071 .51941 Mtetra
.327 .806 .752 r
.68071 .51941 .68329 .51876 .68907 .51671 .6865 .51726 Mtetra
.35 .822 .776 r
.6865 .51726 .68907 .51671 .69486 .51465 .69231 .51512 Mtetra
.372 .837 .798 r
.69231 .51512 .69486 .51465 .70066 .51259 .69812 .51296 Mtetra
.394 .851 .819 r
.69812 .51296 .70066 .51259 .70647 .51052 .70394 .51081 Mtetra
.415 .864 .839 r
.70394 .51081 .70647 .51052 .7123 .50845 .70978 .50865 Mtetra
.435 .875 .858 r
.70978 .50865 .7123 .50845 .71813 .50638 .71562 .50648 Mtetra
.455 .885 .875 r
.71562 .50648 .71813 .50638 .72398 .5043 .72148 .50431 Mtetra
.474 .894 .891 r
.72148 .50431 .72398 .5043 .72983 .50221 .72734 .50214 Mtetra
.492 .901 .906 r
.72734 .50214 .72983 .50221 .7357 .50013 .73322 .49996 Mtetra
.508 .907 .919 r
.73322 .49996 .7357 .50013 .74158 .49804 .73911 .49778 Mtetra
.525 .912 .931 r
.73911 .49778 .74158 .49804 .74747 .49594 .745 .49559 Mtetra
.54 .915 .942 r
.745 .49559 .74747 .49594 .75337 .49384 .75091 .4934 Mtetra
.554 .918 .951 r
.75091 .4934 .75337 .49384 .75928 .49174 .75683 .49121 Mtetra
.567 .919 .958 r
.75683 .49121 .75928 .49174 .7652 .48963 .76276 .48901 Mtetra
.579 .92 .965 r
.76276 .48901 .7652 .48963 .77114 .48752 .7687 .48681 Mtetra
.591 .919 .971 r
.7687 .48681 .77114 .48752 .77708 .48541 .77466 .4846 Mtetra
.601 .918 .975 r
.77466 .4846 .77708 .48541 .78304 .48329 .78062 .48239 Mtetra
.611 .915 .979 r
.78062 .48239 .78304 .48329 .789 .48117 .78659 .48018 Mtetra
.619 .913 .981 r
.78659 .48018 .789 .48117 .79498 .47904 .79258 .47796 Mtetra
.627 .909 .983 r
.79258 .47796 .79498 .47904 .80097 .47691 .79858 .47574 Mtetra
.635 .905 .984 r
.79858 .47574 .80097 .47691 .80697 .47478 .80458 .47351 Mtetra
.641 .901 .984 r
.80458 .47351 .80697 .47478 .81299 .47264 .8106 .47128 Mtetra
.647 .896 .983 r
.8106 .47128 .81299 .47264 .81901 .47049 .81663 .46905 Mtetra
.653 .89 .982 r
.81663 .46905 .81901 .47049 .82505 .46835 .82267 .46681 Mtetra
.658 .885 .981 r
.82267 .46681 .82505 .46835 .83109 .4662 .82872 .46457 Mtetra
.662 .879 .979 r
.82872 .46457 .83109 .4662 .83715 .46404 .83479 .46232 Mtetra
.666 .873 .977 r
.83479 .46232 .83715 .46404 .84322 .46188 .84086 .46007 Mtetra
.669 .867 .974 r
.84086 .46007 .84322 .46188 .8493 .45972 .84695 .45781 Mtetra
.672 .861 .971 r
.84695 .45781 .8493 .45972 .8554 .45755 .85304 .45555 Mtetra
.675 .854 .968 r
.85304 .45555 .8554 .45755 .8615 .45538 .85915 .45329 Mtetra
.677 .848 .965 r
.85915 .45329 .8615 .45538 .86762 .4532 .86527 .45102 Mtetra
.679 .841 .961 r
.86527 .45102 .86762 .4532 .87375 .45102 .8714 .44875 Mtetra
.681 .835 .957 r
.8714 .44875 .87375 .45102 .87989 .44884 .87755 .44647 Mtetra
.682 .828 .953 r
.87755 .44647 .87989 .44884 .88604 .44665 .8837 .44419 Mtetra
.684 .822 .949 r
.8837 .44419 .88604 .44665 .8922 .44446 .88987 .44191 Mtetra
.685 .815 .945 r
.88987 .44191 .8922 .44446 .89838 .44226 .89605 .43962 Mtetra
.686 .809 .941 r
.89605 .43962 .89838 .44226 .90457 .44006 .90223 .43733 Mtetra
.686 .803 .937 r
.90223 .43733 .90457 .44006 .91077 .43786 .90844 .43503 Mtetra
.687 .796 .933 r
.90844 .43503 .91077 .43786 .91698 .43565 .91465 .43273 Mtetra
.687 .79 .928 r
.91465 .43273 .91698 .43565 .9232 .43344 .92087 .43042 Mtetra
.687 .784 .924 r
.92087 .43042 .9232 .43344 .92944 .43122 .92711 .42811 Mtetra
.688 .778 .92 r
.92711 .42811 .92944 .43122 .93568 .429 .93336 .4258 Mtetra
.687 .772 .916 r
.93336 .4258 .93568 .429 .94194 .42678 .93962 .42349 Mtetra
.687 .766 .912 r
.93962 .42349 .94194 .42678 .94822 .42457 .94589 .42119 Mtetra
.685 .76 .909 r
.94589 .42119 .94822 .42457 .95451 .42237 .95218 .4189 Mtetra
.683 .754 .906 r
.95218 .4189 .95451 .42237 .96081 .4202 .95848 .41665 Mtetra
.639 .735 .918 r
.38649 .58639 .38963 .5893 .39482 .58799 .39169 .58513 Mtetra
.631 .737 .924 r
.39169 .58513 .39482 .58799 .40001 .58675 .39689 .58396 Mtetra
.628 .741 .929 r
.39689 .58396 .40001 .58675 .40522 .58553 .4021 .58281 Mtetra
.625 .746 .934 r
.4021 .58281 .40522 .58553 .41044 .58432 .40732 .58168 Mtetra
.623 .751 .938 r
.40732 .58168 .41044 .58432 .41567 .58312 .41256 .58055 Mtetra
.621 .757 .943 r
.41256 .58055 .41567 .58312 .42091 .58191 .4178 .57942 Mtetra
.62 .762 .947 r
.4178 .57942 .42091 .58191 .42617 .5807 .42306 .57829 Mtetra
.618 .768 .952 r
.42306 .57829 .42617 .5807 .43143 .57949 .42833 .57715 Mtetra
.615 .774 .957 r
.42833 .57715 .43143 .57949 .43671 .57828 .43361 .57602 Mtetra
.613 .78 .961 r
.43361 .57602 .43671 .57828 .442 .57706 .4389 .57488 Mtetra
.61 .786 .965 r
.4389 .57488 .442 .57706 .44729 .57584 .44421 .57374 Mtetra
.607 .792 .97 r
.44421 .57374 .44729 .57584 .45261 .57462 .44952 .57259 Mtetra
.604 .797 .974 r
.44952 .57259 .45261 .57462 .45793 .5734 .45485 .57145 Mtetra
.6 .803 .977 r
.45485 .57145 .45793 .5734 .46326 .57217 .46019 .5703 Mtetra
.596 .809 .981 r
.46019 .5703 .46326 .57217 .46861 .57094 .46555 .56915 Mtetra
.592 .815 .985 r
.46555 .56915 .46861 .57094 .47397 .56971 .47091 .56799 Mtetra
.587 .82 .988 r
.47091 .56799 .47397 .56971 .47933 .56847 .47629 .56684 Mtetra
.582 .825 .991 r
.47629 .56684 .47933 .56847 .48472 .56724 .48168 .56568 Mtetra
.576 .831 .993 r
.48168 .56568 .48472 .56724 .49011 .566 .48708 .56451 Mtetra
.57 .836 .995 r
.48708 .56451 .49011 .566 .49551 .56476 .49249 .56335 Mtetra
.563 .84 .997 r
.49249 .56335 .49551 .56476 .50093 .56351 .49792 .56218 Mtetra
.555 .844 .998 r
.49792 .56218 .50093 .56351 .50636 .56226 .50335 .56101 Mtetra
.547 .848 .998 r
.50335 .56101 .50636 .56226 .5118 .56101 .5088 .55984 Mtetra
.539 .852 .998 r
.5088 .55984 .5118 .56101 .51725 .55976 .51427 .55867 Mtetra
.529 .855 .997 r
.51427 .55867 .51725 .55976 .52272 .5585 .51974 .55749 Mtetra
.519 .857 .995 r
.51974 .55749 .52272 .5585 .5282 .55724 .52523 .55631 Mtetra
.508 .858 .992 r
.52523 .55631 .5282 .55724 .53369 .55598 .53073 .55513 Mtetra
.496 .859 .988 r
.53073 .55513 .53369 .55598 .53919 .55472 .53624 .55394 Mtetra
.483 .859 .983 r
.53624 .55394 .53919 .55472 .5447 .55345 .54177 .55275 Mtetra
.469 .858 .977 r
.54177 .55275 .5447 .55345 .55023 .55218 .54731 .55156 Mtetra
.454 .856 .969 r
.54731 .55156 .55023 .55218 .55577 .5509 .55286 .55037 Mtetra
.439 .853 .96 r
.55286 .55037 .55577 .5509 .56132 .54963 .55842 .54917 Mtetra
.422 .849 .95 r
.55842 .54917 .56132 .54963 .56688 .54835 .564 .54797 Mtetra
.405 .844 .938 r
.564 .54797 .56688 .54835 .57246 .54707 .56959 .54677 Mtetra
.387 .837 .925 r
.56959 .54677 .57246 .54707 .57805 .54578 .57519 .54556 Mtetra
.368 .829 .91 r
.57519 .54556 .57805 .54578 .58365 .54449 .5808 .54436 Mtetra
.348 .82 .894 r
.5808 .54436 .58365 .54449 .58926 .5432 .58643 .54315 Mtetra
.327 .81 .876 r
.58643 .54315 .58926 .5432 .59489 .54191 .59207 .54193 Mtetra
.306 .798 .857 r
.59207 .54193 .59489 .54191 .60053 .54061 .59772 .54072 Mtetra
.284 .785 .836 r
.59772 .54072 .60053 .54061 .60618 .53931 .60339 .5395 Mtetra
.262 .771 .814 r
.60339 .5395 .60618 .53931 .61185 .53801 .60907 .53827 Mtetra
.239 .756 .791 r
.60907 .53827 .61185 .53801 .61753 .5367 .61477 .53705 Mtetra
.216 .739 .767 r
.61477 .53705 .61753 .5367 .62322 .53539 .62047 .53582 Mtetra
.193 .722 .742 r
.62047 .53582 .62322 .53539 .62892 .53408 .62619 .53459 Mtetra
.171 .704 .716 r
.62619 .53459 .62892 .53408 .63464 .53277 .63192 .53336 Mtetra
0 0 0 r
.63192 .53336 .63464 .53277 .64037 .53145 .63767 .53212 Mtetra
.63767 .53212 .64037 .53145 .64611 .53012 .64343 .53087 Mtetra
.64343 .53087 .64611 .53012 .65186 .52877 .6492 .52959 Mtetra
.6492 .52959 .65186 .52877 .65763 .52737 .65499 .52827 Mtetra
.65499 .52827 .65763 .52737 .6634 .52571 .66077 .52661 Mtetra
.264 .758 .684 r
.66077 .52661 .6634 .52571 .66916 .52364 .66655 .52447 Mtetra
.293 .779 .709 r
.66655 .52447 .66916 .52364 .67493 .52154 .67233 .52228 Mtetra
.32 .8 .734 r
.67233 .52228 .67493 .52154 .68071 .51941 .67812 .52006 Mtetra
.345 .817 .758 r
.67812 .52006 .68071 .51941 .6865 .51726 .68393 .51783 Mtetra
.367 .833 .781 r
.68393 .51783 .6865 .51726 .69231 .51512 .68974 .51559 Mtetra
.389 .848 .803 r
.68974 .51559 .69231 .51512 .69812 .51296 .69556 .51335 Mtetra
.411 .861 .824 r
.69556 .51335 .69812 .51296 .70394 .51081 .7014 .5111 Mtetra
.431 .873 .843 r
.7014 .5111 .70394 .51081 .70978 .50865 .70724 .50884 Mtetra
.451 .884 .862 r
.70724 .50884 .70978 .50865 .71562 .50648 .7131 .50659 Mtetra
.471 .893 .878 r
.7131 .50659 .71562 .50648 .72148 .50431 .71896 .50433 Mtetra
.489 .901 .894 r
.71896 .50433 .72148 .50431 .72734 .50214 .72484 .50206 Mtetra
.506 .908 .908 r
.72484 .50206 .72734 .50214 .73322 .49996 .73072 .49979 Mtetra
.523 .914 .921 r
.73072 .49979 .73322 .49996 .73911 .49778 .73662 .49752 Mtetra
.538 .918 .932 r
.73662 .49752 .73911 .49778 .745 .49559 .74252 .49524 Mtetra
.553 .921 .942 r
.74252 .49524 .745 .49559 .75091 .4934 .74844 .49296 Mtetra
.567 .923 .951 r
.74844 .49296 .75091 .4934 .75683 .49121 .75437 .49068 Mtetra
.579 .924 .958 r
.75437 .49068 .75683 .49121 .76276 .48901 .76031 .48839 Mtetra
.591 .924 .965 r
.76031 .48839 .76276 .48901 .7687 .48681 .76626 .48609 Mtetra
.602 .923 .97 r
.76626 .48609 .7687 .48681 .77466 .4846 .77222 .4838 Mtetra
.612 .922 .974 r
.77222 .4838 .77466 .4846 .78062 .48239 .77819 .4815 Mtetra
.621 .919 .977 r
.77819 .4815 .78062 .48239 .78659 .48018 .78417 .47919 Mtetra
.63 .916 .979 r
.78417 .47919 .78659 .48018 .79258 .47796 .79016 .47688 Mtetra
.637 .912 .981 r
.79016 .47688 .79258 .47796 .79858 .47574 .79616 .47457 Mtetra
.644 .908 .982 r
.79616 .47457 .79858 .47574 .80458 .47351 .80218 .47225 Mtetra
.65 .904 .982 r
.80218 .47225 .80458 .47351 .8106 .47128 .8082 .46992 Mtetra
.656 .899 .981 r
.8082 .46992 .8106 .47128 .81663 .46905 .81424 .4676 Mtetra
.661 .893 .98 r
.81424 .4676 .81663 .46905 .82267 .46681 .82028 .46527 Mtetra
.666 .888 .979 r
.82028 .46527 .82267 .46681 .82872 .46457 .82634 .46293 Mtetra
.67 .882 .977 r
.82634 .46293 .82872 .46457 .83479 .46232 .83241 .46059 Mtetra
.673 .876 .974 r
.83241 .46059 .83479 .46232 .84086 .46007 .83849 .45825 Mtetra
.677 .869 .972 r
.83849 .45825 .84086 .46007 .84695 .45781 .84458 .4559 Mtetra
.679 .863 .969 r
.84458 .4559 .84695 .45781 .85304 .45555 .85068 .45355 Mtetra
.682 .857 .966 r
.85068 .45355 .85304 .45555 .85915 .45329 .85679 .45119 Mtetra
.684 .85 .962 r
.85679 .45119 .85915 .45329 .86527 .45102 .86292 .44883 Mtetra
.686 .844 .959 r
.86292 .44883 .86527 .45102 .8714 .44875 .86905 .44647 Mtetra
.687 .837 .955 r
.86905 .44647 .8714 .44875 .87755 .44647 .8752 .4441 Mtetra
.689 .83 .951 r
.8752 .4441 .87755 .44647 .8837 .44419 .88135 .44173 Mtetra
.69 .824 .947 r
.88135 .44173 .8837 .44419 .88987 .44191 .88752 .43935 Mtetra
.691 .818 .943 r
.88752 .43935 .88987 .44191 .89605 .43962 .8937 .43697 Mtetra
.692 .811 .939 r
.8937 .43697 .89605 .43962 .90223 .43733 .89989 .43458 Mtetra
.692 .805 .935 r
.89989 .43458 .90223 .43733 .90844 .43503 .90609 .43219 Mtetra
.693 .799 .931 r
.90609 .43219 .90844 .43503 .91465 .43273 .91231 .42979 Mtetra
.693 .792 .926 r
.91231 .42979 .91465 .43273 .92087 .43042 .91853 .4274 Mtetra
.693 .786 .922 r
.91853 .4274 .92087 .43042 .92711 .42811 .92477 .42499 Mtetra
.693 .78 .918 r
.92477 .42499 .92711 .42811 .93336 .4258 .93102 .42259 Mtetra
.692 .774 .914 r
.93102 .42259 .93336 .4258 .93962 .42349 .93728 .42018 Mtetra
.691 .768 .91 r
.93728 .42018 .93962 .42349 .94589 .42119 .94355 .41779 Mtetra
.69 .762 .907 r
.94355 .41779 .94589 .42119 .95218 .4189 .94984 .41542 Mtetra
.687 .756 .904 r
.94984 .41542 .95218 .4189 .95848 .41665 .95615 .41309 Mtetra
.634 .734 .92 r
.38335 .58346 .38649 .58639 .39169 .58513 .38855 .58226 Mtetra
.625 .735 .926 r
.38855 .58226 .39169 .58513 .39689 .58396 .39375 .58115 Mtetra
.621 .739 .931 r
.39375 .58115 .39689 .58396 .4021 .58281 .39897 .58008 Mtetra
.618 .744 .936 r
.39897 .58008 .4021 .58281 .40732 .58168 .40419 .57902 Mtetra
.616 .749 .941 r
.40419 .57902 .40732 .58168 .41256 .58055 .40943 .57797 Mtetra
.614 .755 .945 r
.40943 .57797 .41256 .58055 .4178 .57942 .41468 .57692 Mtetra
.612 .76 .95 r
.41468 .57692 .4178 .57942 .42306 .57829 .41994 .57586 Mtetra
.609 .766 .955 r
.41994 .57586 .42306 .57829 .42833 .57715 .42522 .5748 Mtetra
.607 .772 .959 r
.42522 .5748 .42833 .57715 .43361 .57602 .4305 .57375 Mtetra
.604 .777 .963 r
.4305 .57375 .43361 .57602 .4389 .57488 .4358 .57269 Mtetra
.601 .783 .968 r
.4358 .57269 .4389 .57488 .44421 .57374 .44111 .57162 Mtetra
.598 .789 .972 r
.44111 .57162 .44421 .57374 .44952 .57259 .44643 .57056 Mtetra
.594 .795 .976 r
.44643 .57056 .44952 .57259 .45485 .57145 .45177 .56949 Mtetra
.59 .8 .98 r
.45177 .56949 .45485 .57145 .46019 .5703 .45711 .56842 Mtetra
.586 .806 .983 r
.45711 .56842 .46019 .5703 .46555 .56915 .46247 .56734 Mtetra
.581 .811 .987 r
.46247 .56734 .46555 .56915 .47091 .56799 .46784 .56627 Mtetra
.576 .817 .99 r
.46784 .56627 .47091 .56799 .47629 .56684 .47323 .56519 Mtetra
.571 .822 .993 r
.47323 .56519 .47629 .56684 .48168 .56568 .47862 .56411 Mtetra
.564 .827 .995 r
.47862 .56411 .48168 .56568 .48708 .56451 .48403 .56303 Mtetra
.558 .832 .997 r
.48403 .56303 .48708 .56451 .49249 .56335 .48945 .56194 Mtetra
.55 .836 .998 r
.48945 .56194 .49249 .56335 .49792 .56218 .49489 .56085 Mtetra
.542 .84 .999 r
.49489 .56085 .49792 .56218 .50335 .56101 .50033 .55976 Mtetra
.534 .844 .999 r
.50033 .55976 .50335 .56101 .5088 .55984 .50579 .55867 Mtetra
.524 .847 .998 r
.50579 .55867 .5088 .55984 .51427 .55867 .51127 .55757 Mtetra
.514 .849 .997 r
.51127 .55757 .51427 .55867 .51974 .55749 .51675 .55647 Mtetra
.503 .851 .994 r
.51675 .55647 .51974 .55749 .52523 .55631 .52225 .55537 Mtetra
.492 .852 .991 r
.52225 .55537 .52523 .55631 .53073 .55513 .52776 .55427 Mtetra
.479 .852 .986 r
.52776 .55427 .53073 .55513 .53624 .55394 .53328 .55316 Mtetra
.466 .852 .981 r
.53328 .55316 .53624 .55394 .54177 .55275 .53882 .55205 Mtetra
.451 .85 .974 r
.53882 .55205 .54177 .55275 .54731 .55156 .54437 .55094 Mtetra
.436 .848 .966 r
.54437 .55094 .54731 .55156 .55286 .55037 .54993 .54983 Mtetra
.42 .844 .956 r
.54993 .54983 .55286 .55037 .55842 .54917 .55551 .54871 Mtetra
.403 .839 .945 r
.55551 .54871 .55842 .54917 .564 .54797 .56109 .54759 Mtetra
.385 .834 .933 r
.56109 .54759 .564 .54797 .56959 .54677 .5667 .54647 Mtetra
.367 .826 .919 r
.5667 .54647 .56959 .54677 .57519 .54556 .57231 .54535 Mtetra
.347 .818 .903 r
.57231 .54535 .57519 .54556 .5808 .54436 .57794 .54422 Mtetra
.327 .808 .886 r
.57794 .54422 .5808 .54436 .58643 .54315 .58358 .54309 Mtetra
.306 .797 .868 r
.58358 .54309 .58643 .54315 .59207 .54193 .58923 .54196 Mtetra
.284 .785 .848 r
.58923 .54196 .59207 .54193 .59772 .54072 .5949 .54082 Mtetra
.262 .771 .827 r
.5949 .54082 .59772 .54072 .60339 .5395 .60058 .53968 Mtetra
.24 .756 .804 r
.60058 .53968 .60339 .5395 .60907 .53827 .60628 .53854 Mtetra
.217 .741 .781 r
.60628 .53854 .60907 .53827 .61477 .53705 .61199 .5374 Mtetra
.194 .724 .756 r
.61199 .5374 .61477 .53705 .62047 .53582 .61771 .53625 Mtetra
.171 .706 .73 r
.61771 .53625 .62047 .53582 .62619 .53459 .62345 .53511 Mtetra
.149 .688 .704 r
.62345 .53511 .62619 .53459 .63192 .53336 .6292 .53395 Mtetra
0 0 0 r
.6292 .53395 .63192 .53336 .63767 .53212 .63496 .53279 Mtetra
.63496 .53279 .63767 .53212 .64343 .53087 .64074 .53163 Mtetra
.64074 .53163 .64343 .53087 .6492 .52959 .64653 .53043 Mtetra
.64653 .53043 .6492 .52959 .65499 .52827 .65233 .52917 Mtetra
.65233 .52917 .65499 .52827 .66077 .52661 .65813 .52753 Mtetra
.279 .767 .689 r
.65813 .52753 .66077 .52661 .66655 .52447 .66392 .52531 Mtetra
.309 .79 .715 r
.66392 .52531 .66655 .52447 .67233 .52228 .66971 .52303 Mtetra
.337 .81 .74 r
.66971 .52303 .67233 .52228 .67812 .52006 .67552 .52073 Mtetra
.362 .828 .764 r
.67552 .52073 .67812 .52006 .68393 .51783 .68133 .5184 Mtetra
.384 .843 .786 r
.68133 .5184 .68393 .51783 .68974 .51559 .68716 .51607 Mtetra
.406 .857 .808 r
.68716 .51607 .68974 .51559 .69556 .51335 .69299 .51373 Mtetra
.427 .87 .828 r
.69299 .51373 .69556 .51335 .7014 .5111 .69884 .51139 Mtetra
.447 .882 .847 r
.69884 .51139 .7014 .5111 .70724 .50884 .70469 .50905 Mtetra
.467 .892 .864 r
.70469 .50905 .70724 .50884 .7131 .50659 .71056 .5067 Mtetra
.486 .901 .881 r
.71056 .5067 .7131 .50659 .71896 .50433 .71643 .50435 Mtetra
.504 .908 .896 r
.71643 .50435 .71896 .50433 .72484 .50206 .72232 .50199 Mtetra
.52 .915 .909 r
.72232 .50199 .72484 .50206 .73072 .49979 .72821 .49963 Mtetra
.536 .92 .922 r
.72821 .49963 .73072 .49979 .73662 .49752 .73412 .49727 Mtetra
.552 .924 .933 r
.73412 .49727 .73662 .49752 .74252 .49524 .74003 .4949 Mtetra
.566 .926 .942 r
.74003 .4949 .74252 .49524 .74844 .49296 .74596 .49252 Mtetra
.579 .928 .951 r
.74596 .49252 .74844 .49296 .75437 .49068 .7519 .49015 Mtetra
.591 .929 .958 r
.7519 .49015 .75437 .49068 .76031 .48839 .75784 .48776 Mtetra
.603 .928 .964 r
.75784 .48776 .76031 .48839 .76626 .48609 .7638 .48538 Mtetra
.613 .927 .969 r
.7638 .48538 .76626 .48609 .77222 .4838 .76977 .48299 Mtetra
.623 .925 .973 r
.76977 .48299 .77222 .4838 .77819 .4815 .77575 .48059 Mtetra
.631 .923 .976 r
.77575 .48059 .77819 .4815 .78417 .47919 .78173 .4782 Mtetra
.639 .919 .978 r
.78173 .4782 .78417 .47919 .79016 .47688 .78773 .47579 Mtetra
.647 .916 .979 r
.78773 .47579 .79016 .47688 .79616 .47457 .79374 .47339 Mtetra
.653 .911 .98 r
.79374 .47339 .79616 .47457 .80218 .47225 .79976 .47098 Mtetra
.659 .906 .98 r
.79976 .47098 .80218 .47225 .8082 .46992 .80579 .46856 Mtetra
.665 .901 .979 r
.80579 .46856 .8082 .46992 .81424 .4676 .81183 .46614 Mtetra
.669 .896 .978 r
.81183 .46614 .81424 .4676 .82028 .46527 .81789 .46372 Mtetra
.674 .89 .976 r
.81789 .46372 .82028 .46527 .82634 .46293 .82395 .46129 Mtetra
.678 .884 .974 r
.82395 .46129 .82634 .46293 .83241 .46059 .83002 .45886 Mtetra
.681 .878 .972 r
.83002 .45886 .83241 .46059 .83849 .45825 .83611 .45642 Mtetra
.684 .872 .969 r
.83611 .45642 .83849 .45825 .84458 .4559 .8422 .45398 Mtetra
.687 .865 .966 r
.8422 .45398 .84458 .4559 .85068 .45355 .84831 .45154 Mtetra
.689 .859 .963 r
.84831 .45154 .85068 .45355 .85679 .45119 .85442 .44909 Mtetra
.691 .852 .96 r
.85442 .44909 .85679 .45119 .86292 .44883 .86055 .44663 Mtetra
.692 .846 .956 r
.86055 .44663 .86292 .44883 .86905 .44647 .86669 .44418 Mtetra
.694 .839 .953 r
.86669 .44418 .86905 .44647 .8752 .4441 .87284 .44171 Mtetra
.695 .833 .949 r
.87284 .44171 .8752 .4441 .88135 .44173 .87899 .43925 Mtetra
.696 .826 .945 r
.87899 .43925 .88135 .44173 .88752 .43935 .88517 .43678 Mtetra
.697 .82 .941 r
.88517 .43678 .88752 .43935 .8937 .43697 .89135 .4343 Mtetra
.697 .813 .937 r
.89135 .4343 .8937 .43697 .89989 .43458 .89754 .43182 Mtetra
.698 .807 .933 r
.89754 .43182 .89989 .43458 .90609 .43219 .90374 .42934 Mtetra
.698 .801 .929 r
.90374 .42934 .90609 .43219 .91231 .42979 .90996 .42685 Mtetra
.698 .794 .924 r
.90996 .42685 .91231 .42979 .91853 .4274 .91618 .42435 Mtetra
.698 .788 .92 r
.91618 .42435 .91853 .4274 .92477 .42499 .92242 .42186 Mtetra
.698 .782 .916 r
.92242 .42186 .92477 .42499 .93102 .42259 .92867 .41936 Mtetra
.697 .776 .912 r
.92867 .41936 .93102 .42259 .93728 .42018 .93493 .41686 Mtetra
.696 .77 .909 r
.93493 .41686 .93728 .42018 .94355 .41779 .9412 .41438 Mtetra
.694 .764 .905 r
.9412 .41438 .94355 .41779 .94984 .41542 .94749 .41192 Mtetra
.691 .758 .903 r
.94749 .41192 .94984 .41542 .95615 .41309 .9538 .40952 Mtetra
.629 .733 .922 r
.38019 .58053 .38335 .58346 .38855 .58226 .3854 .57938 Mtetra
.619 .733 .928 r
.3854 .57938 .38855 .58226 .39375 .58115 .3906 .57834 Mtetra
.614 .737 .934 r
.3906 .57834 .39375 .58115 .39897 .58008 .39582 .57734 Mtetra
.611 .742 .938 r
.39582 .57734 .39897 .58008 .40419 .57902 .40105 .57636 Mtetra
.608 .747 .943 r
.40105 .57636 .40419 .57902 .40943 .57797 .40629 .57538 Mtetra
.605 .752 .948 r
.40629 .57538 .40943 .57797 .41468 .57692 .41155 .57441 Mtetra
.603 .758 .952 r
.41155 .57441 .41468 .57692 .41994 .57586 .41681 .57343 Mtetra
.601 .764 .957 r
.41681 .57343 .41994 .57586 .42522 .5748 .42209 .57245 Mtetra
.598 .769 .962 r
.42209 .57245 .42522 .5748 .4305 .57375 .42738 .57147 Mtetra
.595 .775 .966 r
.42738 .57147 .4305 .57375 .4358 .57269 .43268 .57049 Mtetra
.592 .781 .97 r
.43268 .57049 .4358 .57269 .44111 .57162 .438 .5695 Mtetra
.588 .786 .974 r
.438 .5695 .44111 .57162 .44643 .57056 .44333 .56851 Mtetra
.584 .792 .978 r
.44333 .56851 .44643 .57056 .45177 .56949 .44867 .56753 Mtetra
.58 .797 .982 r
.44867 .56753 .45177 .56949 .45711 .56842 .45402 .56653 Mtetra
.575 .803 .986 r
.45402 .56653 .45711 .56842 .46247 .56734 .45938 .56554 Mtetra
.57 .808 .989 r
.45938 .56554 .46247 .56734 .46784 .56627 .46476 .56454 Mtetra
.565 .813 .992 r
.46476 .56454 .46784 .56627 .47323 .56519 .47015 .56354 Mtetra
.559 .818 .994 r
.47015 .56354 .47323 .56519 .47862 .56411 .47556 .56254 Mtetra
.552 .823 .996 r
.47556 .56254 .47862 .56411 .48403 .56303 .48097 .56154 Mtetra
.545 .828 .998 r
.48097 .56154 .48403 .56303 .48945 .56194 .4864 .56053 Mtetra
.537 .832 .999 r
.4864 .56053 .48945 .56194 .49489 .56085 .49184 .55952 Mtetra
.528 .835 .999 r
.49184 .55952 .49489 .56085 .50033 .55976 .4973 .55851 Mtetra
.519 .839 .999 r
.4973 .55851 .50033 .55976 .50579 .55867 .50277 .55749 Mtetra
.509 .841 .998 r
.50277 .55749 .50579 .55867 .51127 .55757 .50825 .55648 Mtetra
.499 .843 .996 r
.50825 .55648 .51127 .55757 .51675 .55647 .51374 .55546 Mtetra
.487 .845 .993 r
.51374 .55546 .51675 .55647 .52225 .55537 .51925 .55444 Mtetra
.475 .845 .989 r
.51925 .55444 .52225 .55537 .52776 .55427 .52477 .55341 Mtetra
.462 .845 .984 r
.52477 .55341 .52776 .55427 .53328 .55316 .53031 .55239 Mtetra
.448 .844 .978 r
.53031 .55239 .53328 .55316 .53882 .55205 .53585 .55136 Mtetra
.433 .842 .97 r
.53585 .55136 .53882 .55205 .54437 .55094 .54141 .55033 Mtetra
.417 .839 .961 r
.54141 .55033 .54437 .55094 .54993 .54983 .54699 .5493 Mtetra
.4 .834 .951 r
.54699 .5493 .54993 .54983 .55551 .54871 .55257 .54826 Mtetra
.383 .829 .939 r
.55257 .54826 .55551 .54871 .56109 .54759 .55818 .54722 Mtetra
.364 .822 .926 r
.55818 .54722 .56109 .54759 .5667 .54647 .56379 .54618 Mtetra
.345 .814 .911 r
.56379 .54618 .5667 .54647 .57231 .54535 .56942 .54514 Mtetra
.325 .805 .895 r
.56942 .54514 .57231 .54535 .57794 .54422 .57506 .54409 Mtetra
.304 .795 .877 r
.57506 .54409 .57794 .54422 .58358 .54309 .58071 .54304 Mtetra
.283 .783 .858 r
.58071 .54304 .58358 .54309 .58923 .54196 .58638 .54199 Mtetra
.261 .77 .838 r
.58638 .54199 .58923 .54196 .5949 .54082 .59207 .54094 Mtetra
.239 .755 .815 r
.59207 .54094 .5949 .54082 .60058 .53968 .59776 .53988 Mtetra
.216 .74 .792 r
.59776 .53988 .60058 .53968 .60628 .53854 .60347 .53882 Mtetra
.194 .724 .768 r
.60347 .53882 .60628 .53854 .61199 .5374 .6092 .53776 Mtetra
.17 .706 .743 r
.6092 .53776 .61199 .5374 .61771 .53625 .61493 .5367 Mtetra
.147 .688 .717 r
.61493 .5367 .61771 .53625 .62345 .53511 .62069 .53563 Mtetra
0 0 0 r
.62069 .53563 .62345 .53511 .6292 .53395 .62645 .53456 Mtetra
.62645 .53456 .6292 .53395 .63496 .53279 .63223 .53349 Mtetra
.63223 .53349 .63496 .53279 .64074 .53163 .63803 .5324 Mtetra
.63803 .5324 .64074 .53163 .64653 .53043 .64383 .53128 Mtetra
.64383 .53128 .64653 .53043 .65233 .52917 .64965 .53009 Mtetra
.64965 .53009 .65233 .52917 .65813 .52753 .65547 .52846 Mtetra
.292 .776 .693 r
.65547 .52846 .65813 .52753 .66392 .52531 .66127 .52616 Mtetra
.324 .799 .719 r
.66127 .52616 .66392 .52531 .66971 .52303 .66708 .5238 Mtetra
.353 .82 .744 r
.66708 .5238 .66971 .52303 .67552 .52073 .6729 .5214 Mtetra
.377 .837 .767 r
.6729 .5214 .67552 .52073 .68133 .5184 .67872 .51899 Mtetra
.4 .852 .789 r
.67872 .51899 .68133 .5184 .68716 .51607 .68456 .51656 Mtetra
.421 .865 .81 r
.68456 .51656 .68716 .51607 .69299 .51373 .6904 .51413 Mtetra
.442 .878 .83 r
.6904 .51413 .69299 .51373 .69884 .51139 .69626 .5117 Mtetra
.462 .889 .849 r
.69626 .5117 .69884 .51139 .70469 .50905 .70213 .50926 Mtetra
.481 .899 .866 r
.70213 .50926 .70469 .50905 .71056 .5067 .708 .50682 Mtetra
.499 .907 .882 r
.708 .50682 .71056 .5067 .71643 .50435 .71389 .50438 Mtetra
.517 .915 .897 r
.71389 .50438 .71643 .50435 .72232 .50199 .71978 .50193 Mtetra
.533 .921 .91 r
.71978 .50193 .72232 .50199 .72821 .49963 .72569 .49947 Mtetra
.549 .925 .922 r
.72569 .49947 .72821 .49963 .73412 .49727 .7316 .49702 Mtetra
.564 .929 .932 r
.7316 .49702 .73412 .49727 .74003 .4949 .73753 .49455 Mtetra
.578 .931 .942 r
.73753 .49455 .74003 .4949 .74596 .49252 .74346 .49209 Mtetra
.59 .933 .95 r
.74346 .49209 .74596 .49252 .7519 .49015 .74941 .48962 Mtetra
.602 .933 .957 r
.74941 .48962 .7519 .49015 .75784 .48776 .75536 .48714 Mtetra
.613 .933 .962 r
.75536 .48714 .75784 .48776 .7638 .48538 .76133 .48466 Mtetra
.623 .931 .967 r
.76133 .48466 .7638 .48538 .76977 .48299 .7673 .48218 Mtetra
.633 .929 .971 r
.7673 .48218 .76977 .48299 .77575 .48059 .77329 .4797 Mtetra
.641 .926 .974 r
.77329 .4797 .77575 .48059 .78173 .4782 .77928 .4772 Mtetra
.649 .923 .976 r
.77928 .4772 .78173 .4782 .78773 .47579 .78529 .47471 Mtetra
.656 .919 .977 r
.78529 .47471 .78773 .47579 .79374 .47339 .79131 .47221 Mtetra
.662 .914 .978 r
.79131 .47221 .79374 .47339 .79976 .47098 .79733 .4697 Mtetra
.668 .909 .978 r
.79733 .4697 .79976 .47098 .80579 .46856 .80337 .4672 Mtetra
.673 .904 .977 r
.80337 .4672 .80579 .46856 .81183 .46614 .80942 .46468 Mtetra
.677 .898 .976 r
.80942 .46468 .81183 .46614 .81789 .46372 .81548 .46217 Mtetra
.682 .893 .974 r
.81548 .46217 .81789 .46372 .82395 .46129 .82154 .45965 Mtetra
.685 .887 .972 r
.82154 .45965 .82395 .46129 .83002 .45886 .82762 .45712 Mtetra
.688 .88 .97 r
.82762 .45712 .83002 .45886 .83611 .45642 .83371 .45459 Mtetra
.691 .874 .967 r
.83371 .45459 .83611 .45642 .8422 .45398 .83981 .45206 Mtetra
.693 .868 .964 r
.83981 .45206 .8422 .45398 .84831 .45154 .84592 .44952 Mtetra
.696 .861 .961 r
.84592 .44952 .84831 .45154 .85442 .44909 .85204 .44698 Mtetra
.697 .854 .958 r
.85204 .44698 .85442 .44909 .86055 .44663 .85817 .44443 Mtetra
.699 .848 .954 r
.85817 .44443 .86055 .44663 .86669 .44418 .86431 .44188 Mtetra
.7 .841 .95 r
.86431 .44188 .86669 .44418 .87284 .44171 .87046 .43932 Mtetra
.701 .835 .947 r
.87046 .43932 .87284 .44171 .87899 .43925 .87663 .43676 Mtetra
.702 .828 .943 r
.87663 .43676 .87899 .43925 .88517 .43678 .8828 .43419 Mtetra
.703 .822 .939 r
.8828 .43419 .88517 .43678 .89135 .4343 .88898 .43162 Mtetra
.703 .815 .935 r
.88898 .43162 .89135 .4343 .89754 .43182 .89518 .42905 Mtetra
.703 .809 .931 r
.89518 .42905 .89754 .43182 .90374 .42934 .90138 .42647 Mtetra
.704 .803 .927 r
.90138 .42647 .90374 .42934 .90996 .42685 .9076 .42389 Mtetra
.703 .796 .922 r
.9076 .42389 .90996 .42685 .91618 .42435 .91382 .4213 Mtetra
.703 .79 .918 r
.91382 .4213 .91618 .42435 .92242 .42186 .92006 .41871 Mtetra
.703 .784 .914 r
.92006 .41871 .92242 .42186 .92867 .41936 .92631 .41612 Mtetra
.702 .778 .91 r
.92631 .41612 .92867 .41936 .93493 .41686 .93257 .41353 Mtetra
.701 .772 .907 r
.93257 .41353 .93493 .41686 .9412 .41438 .93885 .41095 Mtetra
.698 .765 .904 r
.93885 .41095 .9412 .41438 .94749 .41192 .94514 .40841 Mtetra
.695 .759 .901 r
.94514 .40841 .94749 .41192 .9538 .40952 .95145 .40593 Mtetra
.625 .731 .923 r
.37703 .57758 .38019 .58053 .3854 .57938 .38223 .57649 Mtetra
.612 .731 .93 r
.38223 .57649 .3854 .57938 .3906 .57834 .38744 .57551 Mtetra
.607 .735 .936 r
.38744 .57551 .3906 .57834 .39582 .57734 .39266 .57459 Mtetra
.603 .739 .941 r
.39266 .57459 .39582 .57734 .40105 .57636 .3979 .57368 Mtetra
.6 .744 .946 r
.3979 .57368 .40105 .57636 .40629 .57538 .40314 .57278 Mtetra
.597 .75 .95 r
.40314 .57278 .40629 .57538 .41155 .57441 .4084 .57189 Mtetra
.595 .755 .955 r
.4084 .57189 .41155 .57441 .41681 .57343 .41367 .57099 Mtetra
.592 .761 .959 r
.41367 .57099 .41681 .57343 .42209 .57245 .41895 .57009 Mtetra
.589 .766 .964 r
.41895 .57009 .42209 .57245 .42738 .57147 .42424 .56918 Mtetra
.586 .772 .968 r
.42424 .56918 .42738 .57147 .43268 .57049 .42955 .56828 Mtetra
.582 .778 .972 r
.42955 .56828 .43268 .57049 .438 .5695 .43487 .56737 Mtetra
.578 .783 .976 r
.43487 .56737 .438 .5695 .44333 .56851 .44021 .56646 Mtetra
.574 .789 .98 r
.44021 .56646 .44333 .56851 .44867 .56753 .44555 .56555 Mtetra
.569 .794 .984 r
.44555 .56555 .44867 .56753 .45402 .56653 .45091 .56464 Mtetra
.564 .799 .987 r
.45091 .56464 .45402 .56653 .45938 .56554 .45628 .56372 Mtetra
.559 .804 .99 r
.45628 .56372 .45938 .56554 .46476 .56454 .46167 .5628 Mtetra
.553 .809 .993 r
.46167 .5628 .46476 .56454 .47015 .56354 .46706 .56188 Mtetra
.547 .814 .996 r
.46706 .56188 .47015 .56354 .47556 .56254 .47248 .56096 Mtetra
.539 .819 .997 r
.47248 .56096 .47556 .56254 .48097 .56154 .4779 .56004 Mtetra
.532 .823 .999 r
.4779 .56004 .48097 .56154 .4864 .56053 .48334 .55911 Mtetra
.524 .827 1 r
.48334 .55911 .4864 .56053 .49184 .55952 .48879 .55818 Mtetra
.515 .83 1 r
.48879 .55818 .49184 .55952 .4973 .55851 .49425 .55725 Mtetra
.505 .833 .999 r
.49425 .55725 .4973 .55851 .50277 .55749 .49973 .55631 Mtetra
.495 .835 .998 r
.49973 .55631 .50277 .55749 .50825 .55648 .50522 .55538 Mtetra
.484 .837 .995 r
.50522 .55538 .50825 .55648 .51374 .55546 .51072 .55444 Mtetra
.472 .838 .992 r
.51072 .55444 .51374 .55546 .51925 .55444 .51624 .5535 Mtetra
.459 .838 .988 r
.51624 .5535 .51925 .55444 .52477 .55341 .52177 .55255 Mtetra
.445 .837 .982 r
.52177 .55255 .52477 .55341 .53031 .55239 .52731 .55161 Mtetra
.431 .836 .975 r
.52731 .55161 .53031 .55239 .53585 .55136 .53287 .55066 Mtetra
.415 .833 .967 r
.53287 .55066 .53585 .55136 .54141 .55033 .53844 .54971 Mtetra
.399 .829 .958 r
.53844 .54971 .54141 .55033 .54699 .5493 .54403 .54876 Mtetra
.382 .825 .947 r
.54403 .54876 .54699 .5493 .55257 .54826 .54963 .5478 Mtetra
.364 .819 .934 r
.54963 .5478 .55257 .54826 .55818 .54722 .55524 .54684 Mtetra
.345 .811 .921 r
.55524 .54684 .55818 .54722 .56379 .54618 .56087 .54589 Mtetra
.326 .803 .905 r
.56087 .54589 .56379 .54618 .56942 .54514 .56651 .54492 Mtetra
.305 .793 .888 r
.56651 .54492 .56942 .54514 .57506 .54409 .57216 .54396 Mtetra
.284 .782 .87 r
.57216 .54396 .57506 .54409 .58071 .54304 .57783 .54299 Mtetra
.263 .77 .85 r
.57783 .54299 .58071 .54304 .58638 .54199 .58351 .54202 Mtetra
.241 .756 .829 r
.58351 .54202 .58638 .54199 .59207 .54094 .58921 .54105 Mtetra
.218 .742 .807 r
.58921 .54105 .59207 .54094 .59776 .53988 .59492 .54008 Mtetra
.196 .726 .783 r
.59492 .54008 .59776 .53988 .60347 .53882 .60065 .5391 Mtetra
.173 .709 .759 r
.60065 .5391 .60347 .53882 .6092 .53776 .60639 .53812 Mtetra
.15 .692 .733 r
.60639 .53812 .6092 .53776 .61493 .5367 .61214 .53714 Mtetra
.127 .673 .707 r
.61214 .53714 .61493 .5367 .62069 .53563 .61791 .53616 Mtetra
0 0 0 r
.61791 .53616 .62069 .53563 .62645 .53456 .62369 .53517 Mtetra
.62369 .53517 .62645 .53456 .63223 .53349 .62949 .53418 Mtetra
.62949 .53418 .63223 .53349 .63803 .5324 .6353 .53318 Mtetra
.6353 .53318 .63803 .5324 .64383 .53128 .64113 .53214 Mtetra
.64113 .53214 .64383 .53128 .64965 .53009 .64696 .53102 Mtetra
.64696 .53102 .64965 .53009 .65547 .52846 .65279 .52939 Mtetra
.309 .787 .701 r
.65279 .52939 .65547 .52846 .66127 .52616 .65861 .52702 Mtetra
.342 .811 .727 r
.65861 .52702 .66127 .52616 .66708 .5238 .66443 .52457 Mtetra
.372 .831 .751 r
.66443 .52457 .66708 .5238 .6729 .5214 .67026 .52208 Mtetra
.396 .848 .774 r
.67026 .52208 .6729 .5214 .67872 .51899 .6761 .51957 Mtetra
.418 .862 .796 r
.6761 .51957 .67872 .51899 .68456 .51656 .68194 .51705 Mtetra
.439 .875 .816 r
.68194 .51705 .68456 .51656 .6904 .51413 .6878 .51453 Mtetra
.46 .887 .835 r
.6878 .51453 .6904 .51413 .69626 .5117 .69367 .51201 Mtetra
.479 .898 .853 r
.69367 .51201 .69626 .5117 .70213 .50926 .69954 .50947 Mtetra
.497 .907 .87 r
.69954 .50947 .70213 .50926 .708 .50682 .70543 .50694 Mtetra
.515 .915 .885 r
.70543 .50694 .708 .50682 .71389 .50438 .71133 .5044 Mtetra
.532 .922 .899 r
.71133 .5044 .71389 .50438 .71978 .50193 .71723 .50186 Mtetra
.548 .927 .912 r
.71723 .50186 .71978 .50193 .72569 .49947 .72315 .49931 Mtetra
.563 .931 .923 r
.72315 .49931 .72569 .49947 .7316 .49702 .72907 .49676 Mtetra
.578 .934 .933 r
.72907 .49676 .7316 .49702 .73753 .49455 .73501 .49421 Mtetra
.591 .936 .942 r
.73501 .49421 .73753 .49455 .74346 .49209 .74095 .49165 Mtetra
.603 .937 .95 r
.74095 .49165 .74346 .49209 .74941 .48962 .7469 .48908 Mtetra
.614 .937 .956 r
.7469 .48908 .74941 .48962 .75536 .48714 .75287 .48652 Mtetra
.625 .936 .962 r
.75287 .48652 .75536 .48714 .76133 .48466 .75884 .48394 Mtetra
.634 .935 .966 r
.75884 .48394 .76133 .48466 .7673 .48218 .76483 .48137 Mtetra
.643 .932 .969 r
.76483 .48137 .7673 .48218 .77329 .4797 .77082 .47879 Mtetra
.651 .929 .972 r
.77082 .47879 .77329 .4797 .77928 .4772 .77682 .4762 Mtetra
.659 .925 .974 r
.77682 .4762 .77928 .4772 .78529 .47471 .78284 .47361 Mtetra
.665 .921 .975 r
.78284 .47361 .78529 .47471 .79131 .47221 .78886 .47102 Mtetra
.671 .917 .975 r
.78886 .47102 .79131 .47221 .79733 .4697 .79489 .46842 Mtetra
.677 .912 .975 r
.79489 .46842 .79733 .4697 .80337 .4672 .80094 .46582 Mtetra
.681 .906 .974 r
.80094 .46582 .80337 .4672 .80942 .46468 .80699 .46322 Mtetra
.686 .901 .973 r
.80699 .46322 .80942 .46468 .81548 .46217 .81305 .46061 Mtetra
.689 .895 .972 r
.81305 .46061 .81548 .46217 .82154 .45965 .81913 .45799 Mtetra
.693 .888 .97 r
.81913 .45799 .82154 .45965 .82762 .45712 .82521 .45537 Mtetra
.696 .882 .967 r
.82521 .45537 .82762 .45712 .83371 .45459 .8313 .45275 Mtetra
.698 .876 .964 r
.8313 .45275 .83371 .45459 .83981 .45206 .83741 .45012 Mtetra
.7 .869 .962 r
.83741 .45012 .83981 .45206 .84592 .44952 .84352 .44749 Mtetra
.702 .863 .958 r
.84352 .44749 .84592 .44952 .85204 .44698 .84965 .44485 Mtetra
.704 .856 .955 r
.84965 .44485 .85204 .44698 .85817 .44443 .85578 .44221 Mtetra
.705 .85 .951 r
.85578 .44221 .85817 .44443 .86431 .44188 .86192 .43956 Mtetra
.706 .843 .948 r
.86192 .43956 .86431 .44188 .87046 .43932 .86808 .43691 Mtetra
.707 .836 .944 r
.86808 .43691 .87046 .43932 .87663 .43676 .87425 .43426 Mtetra
.708 .83 .94 r
.87425 .43426 .87663 .43676 .8828 .43419 .88042 .4316 Mtetra
.708 .823 .936 r
.88042 .4316 .8828 .43419 .88898 .43162 .88661 .42894 Mtetra
.709 .817 .932 r
.88661 .42894 .88898 .43162 .89518 .42905 .8928 .42627 Mtetra
.709 .811 .928 r
.8928 .42627 .89518 .42905 .90138 .42647 .89901 .4236 Mtetra
.709 .804 .924 r
.89901 .4236 .90138 .42647 .9076 .42389 .90523 .42092 Mtetra
.709 .798 .92 r
.90523 .42092 .9076 .42389 .91382 .4213 .91146 .41824 Mtetra
.708 .792 .916 r
.91146 .41824 .91382 .4213 .92006 .41871 .91769 .41555 Mtetra
.708 .786 .912 r
.91769 .41555 .92006 .41871 .92631 .41612 .92394 .41286 Mtetra
.707 .78 .908 r
.92394 .41286 .92631 .41612 .93257 .41353 .9302 .41018 Mtetra
.705 .773 .905 r
.9302 .41018 .93257 .41353 .93885 .41095 .93648 .40752 Mtetra
.703 .767 .902 r
.93648 .40752 .93885 .41095 .94514 .40841 .94277 .40489 Mtetra
.698 .761 .9 r
.94277 .40489 .94514 .40841 .95145 .40593 .94908 .40233 Mtetra
.62 .73 .925 r
.37385 .57463 .37703 .57758 .38223 .57649 .37906 .57358 Mtetra
.606 .729 .932 r
.37906 .57358 .38223 .57649 .38744 .57551 .38427 .57268 Mtetra
.599 .733 .938 r
.38427 .57268 .38744 .57551 .39266 .57459 .3895 .57183 Mtetra
.595 .737 .943 r
.3895 .57183 .39266 .57459 .3979 .57368 .39473 .57099 Mtetra
.591 .742 .948 r
.39473 .57099 .3979 .57368 .40314 .57278 .39998 .57017 Mtetra
.588 .747 .953 r
.39998 .57017 .40314 .57278 .4084 .57189 .40524 .56936 Mtetra
.586 .753 .957 r
.40524 .56936 .4084 .57189 .41367 .57099 .41051 .56853 Mtetra
.583 .758 .962 r
.41051 .56853 .41367 .57099 .41895 .57009 .4158 .56771 Mtetra
.579 .763 .966 r
.4158 .56771 .41895 .57009 .42424 .56918 .4211 .56689 Mtetra
.576 .769 .97 r
.4211 .56689 .42424 .56918 .42955 .56828 .42641 .56606 Mtetra
.572 .774 .974 r
.42641 .56606 .42955 .56828 .43487 .56737 .43173 .56523 Mtetra
.568 .78 .978 r
.43173 .56523 .43487 .56737 .44021 .56646 .43707 .5644 Mtetra
.563 .785 .982 r
.43707 .5644 .44021 .56646 .44555 .56555 .44242 .56357 Mtetra
.559 .79 .986 r
.44242 .56357 .44555 .56555 .45091 .56464 .44779 .56273 Mtetra
.553 .796 .989 r
.44779 .56273 .45091 .56464 .45628 .56372 .45317 .5619 Mtetra
.547 .8 .992 r
.45317 .5619 .45628 .56372 .46167 .5628 .45856 .56106 Mtetra
.541 .805 .994 r
.45856 .56106 .46167 .5628 .46706 .56188 .46396 .56022 Mtetra
.534 .81 .997 r
.46396 .56022 .46706 .56188 .47248 .56096 .46938 .55937 Mtetra
.527 .814 .998 r
.46938 .55937 .47248 .56096 .4779 .56004 .47481 .55853 Mtetra
.519 .818 .999 r
.47481 .55853 .4779 .56004 .48334 .55911 .48026 .55768 Mtetra
.51 .821 1 r
.48026 .55768 .48334 .55911 .48879 .55818 .48572 .55683 Mtetra
.501 .824 1 r
.48572 .55683 .48879 .55818 .49425 .55725 .49119 .55598 Mtetra
.491 .827 .999 r
.49119 .55598 .49425 .55725 .49973 .55631 .49667 .55512 Mtetra
.48 .829 .997 r
.49667 .55512 .49973 .55631 .50522 .55538 .50217 .55427 Mtetra
.468 .83 .994 r
.50217 .55427 .50522 .55538 .51072 .55444 .50769 .55341 Mtetra
.456 .831 .99 r
.50769 .55341 .51072 .55444 .51624 .5535 .51321 .55255 Mtetra
.443 .83 .986 r
.51321 .55255 .51624 .5535 .52177 .55255 .51875 .55168 Mtetra
.429 .829 .98 r
.51875 .55168 .52177 .55255 .52731 .55161 .52431 .55082 Mtetra
.413 .827 .972 r
.52431 .55082 .52731 .55161 .53287 .55066 .52988 .54995 Mtetra
.397 .824 .964 r
.52988 .54995 .53287 .55066 .53844 .54971 .53546 .54908 Mtetra
.381 .82 .954 r
.53546 .54908 .53844 .54971 .54403 .54876 .54106 .54821 Mtetra
.363 .814 .942 r
.54106 .54821 .54403 .54876 .54963 .5478 .54667 .54734 Mtetra
.345 .808 .929 r
.54667 .54734 .54963 .5478 .55524 .54684 .55229 .54646 Mtetra
.326 .8 .915 r
.55229 .54646 .55524 .54684 .56087 .54589 .55793 .54558 Mtetra
.306 .791 .899 r
.55793 .54558 .56087 .54589 .56651 .54492 .56358 .5447 Mtetra
.285 .781 .882 r
.56358 .5447 .56651 .54492 .57216 .54396 .56925 .54382 Mtetra
.264 .769 .863 r
.56925 .54382 .57216 .54396 .57783 .54299 .57493 .54294 Mtetra
.243 .757 .843 r
.57493 .54294 .57783 .54299 .58351 .54202 .58063 .54205 Mtetra
.221 .743 .821 r
.58063 .54205 .58351 .54202 .58921 .54105 .58634 .54116 Mtetra
.198 .727 .798 r
.58634 .54116 .58921 .54105 .59492 .54008 .59207 .54027 Mtetra
.176 .712 .774 r
.59207 .54027 .59492 .54008 .60065 .5391 .59781 .53938 Mtetra
.153 .695 .75 r
.59781 .53938 .60065 .5391 .60639 .53812 .60356 .53848 Mtetra
.13 .677 .724 r
.60356 .53848 .60639 .53812 .61214 .53714 .60933 .53759 Mtetra
0 0 0 r
.60933 .53759 .61214 .53714 .61791 .53616 .61512 .53669 Mtetra
.61512 .53669 .61791 .53616 .62369 .53517 .62091 .53578 Mtetra
.62091 .53578 .62369 .53517 .62949 .53418 .62673 .53487 Mtetra
.62673 .53487 .62949 .53418 .6353 .53318 .63256 .53395 Mtetra
.63256 .53395 .6353 .53318 .64113 .53214 .6384 .53299 Mtetra
.6384 .53299 .64113 .53214 .64696 .53102 .64425 .53194 Mtetra
.64425 .53194 .64696 .53102 .65279 .52939 .6501 .53032 Mtetra
.326 .798 .709 r
.6501 .53032 .65279 .52939 .65861 .52702 .65593 .52787 Mtetra
.361 .822 .735 r
.65593 .52787 .65861 .52702 .66443 .52457 .66176 .52534 Mtetra
.391 .843 .759 r
.66176 .52534 .66443 .52457 .67026 .52208 .6676 .52276 Mtetra
.415 .859 .781 r
.6676 .52276 .67026 .52208 .6761 .51957 .67345 .52015 Mtetra
.436 .873 .802 r
.67345 .52015 .6761 .51957 .68194 .51705 .67931 .51754 Mtetra
.457 .885 .822 r
.67931 .51754 .68194 .51705 .6878 .51453 .68518 .51493 Mtetra
.477 .896 .84 r
.68518 .51493 .6878 .51453 .69367 .51201 .69106 .51231 Mtetra
.496 .906 .857 r
.69106 .51231 .69367 .51201 .69954 .50947 .69695 .50968 Mtetra
.514 .915 .873 r
.69695 .50968 .69954 .50947 .70543 .50694 .70285 .50706 Mtetra
.531 .922 .888 r
.70285 .50706 .70543 .50694 .71133 .5044 .70875 .50442 Mtetra
.548 .928 .901 r
.70875 .50442 .71133 .5044 .71723 .50186 .71467 .50179 Mtetra
.563 .933 .913 r
.71467 .50179 .71723 .50186 .72315 .49931 .72059 .49915 Mtetra
.577 .937 .924 r
.72059 .49915 .72315 .49931 .72907 .49676 .72653 .4965 Mtetra
.591 .939 .934 r
.72653 .4965 .72907 .49676 .73501 .49421 .73247 .49385 Mtetra
.604 .941 .942 r
.73247 .49385 .73501 .49421 .74095 .49165 .73842 .4912 Mtetra
.615 .941 .949 r
.73842 .4912 .74095 .49165 .7469 .48908 .74439 .48854 Mtetra
.626 .941 .955 r
.74439 .48854 .7469 .48908 .75287 .48652 .75036 .48588 Mtetra
.636 .94 .961 r
.75036 .48588 .75287 .48652 .75884 .48394 .75634 .48322 Mtetra
.645 .938 .965 r
.75634 .48322 .75884 .48394 .76483 .48137 .76233 .48055 Mtetra
.654 .935 .968 r
.76233 .48055 .76483 .48137 .77082 .47879 .76834 .47787 Mtetra
.661 .932 .97 r
.76834 .47787 .77082 .47879 .77682 .4762 .77435 .47519 Mtetra
.668 .928 .972 r
.77435 .47519 .77682 .4762 .78284 .47361 .78037 .47251 Mtetra
.674 .924 .973 r
.78037 .47251 .78284 .47361 .78886 .47102 .7864 .46983 Mtetra
.68 .919 .973 r
.7864 .46983 .78886 .47102 .79489 .46842 .79244 .46713 Mtetra
.685 .914 .973 r
.79244 .46713 .79489 .46842 .80094 .46582 .79849 .46444 Mtetra
.689 .908 .972 r
.79849 .46444 .80094 .46582 .80699 .46322 .80455 .46174 Mtetra
.693 .902 .971 r
.80455 .46174 .80699 .46322 .81305 .46061 .81062 .45903 Mtetra
.697 .896 .969 r
.81062 .45903 .81305 .46061 .81913 .45799 .8167 .45633 Mtetra
.7 .89 .967 r
.8167 .45633 .81913 .45799 .82521 .45537 .82278 .45361 Mtetra
.703 .884 .964 r
.82278 .45361 .82521 .45537 .8313 .45275 .82888 .4509 Mtetra
.705 .878 .962 r
.82888 .4509 .8313 .45275 .83741 .45012 .83499 .44817 Mtetra
.707 .871 .959 r
.83499 .44817 .83741 .45012 .84352 .44749 .84111 .44545 Mtetra
.709 .864 .956 r
.84111 .44545 .84352 .44749 .84965 .44485 .84724 .44272 Mtetra
.71 .858 .952 r
.84724 .44272 .84965 .44485 .85578 .44221 .85338 .43998 Mtetra
.711 .851 .949 r
.85338 .43998 .85578 .44221 .86192 .43956 .85953 .43724 Mtetra
.712 .845 .945 r
.85953 .43724 .86192 .43956 .86808 .43691 .86569 .4345 Mtetra
.713 .838 .942 r
.86569 .4345 .86808 .43691 .87425 .43426 .87185 .43175 Mtetra
.713 .832 .938 r
.87185 .43175 .87425 .43426 .88042 .4316 .87803 .42899 Mtetra
.714 .825 .934 r
.87803 .42899 .88042 .4316 .88661 .42894 .88422 .42624 Mtetra
.714 .819 .93 r
.88422 .42624 .88661 .42894 .8928 .42627 .89042 .42347 Mtetra
.714 .812 .926 r
.89042 .42347 .8928 .42627 .89901 .4236 .89663 .42071 Mtetra
.714 .806 .922 r
.89663 .42071 .89901 .4236 .90523 .42092 .90285 .41793 Mtetra
.714 .8 .918 r
.90285 .41793 .90523 .42092 .91146 .41824 .90908 .41516 Mtetra
.713 .794 .914 r
.90908 .41516 .91146 .41824 .91769 .41555 .91532 .41238 Mtetra
.713 .788 .91 r
.91532 .41238 .91769 .41555 .92394 .41286 .92157 .4096 Mtetra
.712 .781 .906 r
.92157 .4096 .92394 .41286 .9302 .41018 .92783 .40682 Mtetra
.71 .775 .903 r
.92783 .40682 .9302 .41018 .93648 .40752 .9341 .40406 Mtetra
.707 .769 .9 r
.9341 .40406 .93648 .40752 .94277 .40489 .94039 .40135 Mtetra
.702 .762 .898 r
.94039 .40135 .94277 .40489 .94908 .40233 .94671 .39871 Mtetra
.615 .728 .927 r
.37066 .57166 .37385 .57463 .37906 .57358 .37587 .57067 Mtetra
.599 .727 .935 r
.37587 .57067 .37906 .57358 .38427 .57268 .38109 .56983 Mtetra
.591 .73 .94 r
.38109 .56983 .38427 .57268 .3895 .57183 .38631 .56905 Mtetra
.587 .734 .945 r
.38631 .56905 .3895 .57183 .39473 .57099 .39155 .5683 Mtetra
.583 .739 .95 r
.39155 .5683 .39473 .57099 .39998 .57017 .3968 .56756 Mtetra
.579 .744 .955 r
.3968 .56756 .39998 .57017 .40524 .56936 .40207 .56682 Mtetra
.577 .75 .959 r
.40207 .56682 .40524 .56936 .41051 .56853 .40734 .56607 Mtetra
.573 .755 .964 r
.40734 .56607 .41051 .56853 .4158 .56771 .41263 .56533 Mtetra
.57 .76 .968 r
.41263 .56533 .4158 .56771 .4211 .56689 .41794 .56458 Mtetra
.566 .766 .972 r
.41794 .56458 .4211 .56689 .42641 .56606 .42325 .56383 Mtetra
.562 .771 .976 r
.42325 .56383 .42641 .56606 .43173 .56523 .42858 .56308 Mtetra
.557 .776 .98 r
.42858 .56308 .43173 .56523 .43707 .5644 .43393 .56233 Mtetra
.552 .782 .984 r
.43393 .56233 .43707 .5644 .44242 .56357 .43928 .56158 Mtetra
.547 .787 .987 r
.43928 .56158 .44242 .56357 .44779 .56273 .44465 .56082 Mtetra
.541 .792 .99 r
.44465 .56082 .44779 .56273 .45317 .5619 .45004 .56006 Mtetra
.535 .796 .993 r
.45004 .56006 .45317 .5619 .45856 .56106 .45544 .55931 Mtetra
.528 .801 .996 r
.45544 .55931 .45856 .56106 .46396 .56022 .46085 .55854 Mtetra
.521 .805 .998 r
.46085 .55854 .46396 .56022 .46938 .55937 .46627 .55778 Mtetra
.513 .809 .999 r
.46627 .55778 .46938 .55937 .47481 .55853 .47171 .55701 Mtetra
.505 .813 1 r
.47171 .55701 .47481 .55853 .48026 .55768 .47716 .55625 Mtetra
.496 .816 1 r
.47716 .55625 .48026 .55768 .48572 .55683 .48263 .55548 Mtetra
.486 .819 .999 r
.48263 .55548 .48572 .55683 .49119 .55598 .48811 .5547 Mtetra
.475 .821 .998 r
.48811 .5547 .49119 .55598 .49667 .55512 .4936 .55393 Mtetra
.464 .822 .996 r
.4936 .55393 .49667 .55512 .50217 .55427 .49911 .55315 Mtetra
.452 .823 .993 r
.49911 .55315 .50217 .55427 .50769 .55341 .50463 .55237 Mtetra
.438 .823 .988 r
.50463 .55237 .50769 .55341 .51321 .55255 .51017 .5516 Mtetra
.425 .822 .983 r
.51017 .5516 .51321 .55255 .51875 .55168 .51572 .55081 Mtetra
.41 .82 .976 r
.51572 .55081 .51875 .55168 .52431 .55082 .52129 .55003 Mtetra
.395 .818 .968 r
.52129 .55003 .52431 .55082 .52988 .54995 .52686 .54924 Mtetra
.378 .814 .959 r
.52686 .54924 .52988 .54995 .53546 .54908 .53246 .54846 Mtetra
.361 .809 .948 r
.53246 .54846 .53546 .54908 .54106 .54821 .53807 .54767 Mtetra
.343 .803 .936 r
.53807 .54767 .54106 .54821 .54667 .54734 .54369 .54687 Mtetra
.324 .796 .922 r
.54369 .54687 .54667 .54734 .55229 .54646 .54932 .54608 Mtetra
.304 .787 .907 r
.54932 .54608 .55229 .54646 .55793 .54558 .55498 .54528 Mtetra
.284 .778 .891 r
.55498 .54528 .55793 .54558 .56358 .5447 .56064 .54449 Mtetra
.263 .767 .872 r
.56064 .54449 .56358 .5447 .56925 .54382 .56632 .54369 Mtetra
.242 .755 .853 r
.56632 .54369 .56925 .54382 .57493 .54294 .57202 .54289 Mtetra
.22 .742 .832 r
.57202 .54289 .57493 .54294 .58063 .54205 .57773 .54208 Mtetra
.198 .727 .81 r
.57773 .54208 .58063 .54205 .58634 .54116 .58345 .54128 Mtetra
.175 .711 .787 r
.58345 .54128 .58634 .54116 .59207 .54027 .58919 .54047 Mtetra
.153 .695 .762 r
.58919 .54047 .59207 .54027 .59781 .53938 .59495 .53966 Mtetra
.13 .678 .737 r
.59495 .53966 .59781 .53938 .60356 .53848 .60072 .53885 Mtetra
.107 .66 .711 r
.60072 .53885 .60356 .53848 .60933 .53759 .6065 .53803 Mtetra
0 0 0 r
.6065 .53803 .60933 .53759 .61512 .53669 .6123 .53722 Mtetra
.6123 .53722 .61512 .53669 .62091 .53578 .61812 .5364 Mtetra
.61812 .5364 .62091 .53578 .62673 .53487 .62395 .53557 Mtetra
.62395 .53557 .62673 .53487 .63256 .53395 .6298 .53474 Mtetra
.6298 .53474 .63256 .53395 .6384 .53299 .63566 .53385 Mtetra
.63566 .53385 .6384 .53299 .64425 .53194 .64153 .53287 Mtetra
.64153 .53287 .64425 .53194 .6501 .53032 .64739 .53127 Mtetra
.34 .807 .713 r
.64739 .53127 .6501 .53032 .65593 .52787 .65323 .52873 Mtetra
.376 .832 .739 r
.65323 .52873 .65593 .52787 .66176 .52534 .65908 .52612 Mtetra
.407 .852 .763 r
.65908 .52612 .66176 .52534 .6676 .52276 .66493 .52344 Mtetra
.431 .868 .785 r
.66493 .52344 .6676 .52276 .67345 .52015 .6708 .52075 Mtetra
.452 .881 .806 r
.6708 .52075 .67345 .52015 .67931 .51754 .67667 .51804 Mtetra
.472 .893 .825 r
.67667 .51804 .67931 .51754 .68518 .51493 .68255 .51533 Mtetra
.492 .904 .843 r
.68255 .51533 .68518 .51493 .69106 .51231 .68844 .51262 Mtetra
.51 .913 .86 r
.68844 .51262 .69106 .51231 .69695 .50968 .69434 .5099 Mtetra
.528 .921 .875 r
.69434 .5099 .69695 .50968 .70285 .50706 .70025 .50718 Mtetra
.545 .928 .889 r
.70025 .50718 .70285 .50706 .70875 .50442 .70616 .50445 Mtetra
.561 .934 .902 r
.70616 .50445 .70875 .50442 .71467 .50179 .71209 .50172 Mtetra
.576 .938 .914 r
.71209 .50172 .71467 .50179 .72059 .49915 .71802 .49898 Mtetra
.59 .941 .924 r
.71802 .49898 .72059 .49915 .72653 .4965 .72397 .49624 Mtetra
.603 .944 .933 r
.72397 .49624 .72653 .4965 .73247 .49385 .72992 .4935 Mtetra
.615 .945 .941 r
.72992 .4935 .73247 .49385 .73842 .4912 .73588 .49075 Mtetra
.626 .945 .948 r
.73588 .49075 .73842 .4912 .74439 .48854 .74186 .488 Mtetra
.637 .945 .954 r
.74186 .488 .74439 .48854 .75036 .48588 .74784 .48525 Mtetra
.646 .943 .959 r
.74784 .48525 .75036 .48588 .75634 .48322 .75383 .48249 Mtetra
.655 .941 .963 r
.75383 .48249 .75634 .48322 .76233 .48055 .75983 .47972 Mtetra
.663 .938 .966 r
.75983 .47972 .76233 .48055 .76834 .47787 .76584 .47696 Mtetra
.671 .935 .968 r
.76584 .47696 .76834 .47787 .77435 .47519 .77186 .47418 Mtetra
.677 .931 .97 r
.77186 .47418 .77435 .47519 .78037 .47251 .77789 .47141 Mtetra
.683 .926 .97 r
.77789 .47141 .78037 .47251 .7864 .46983 .78392 .46863 Mtetra
.688 .921 .971 r
.78392 .46863 .7864 .46983 .79244 .46713 .78997 .46584 Mtetra
.693 .916 .97 r
.78997 .46584 .79244 .46713 .79849 .46444 .79603 .46305 Mtetra
.697 .91 .969 r
.79603 .46305 .79849 .46444 .80455 .46174 .80209 .46026 Mtetra
.701 .904 .968 r
.80209 .46026 .80455 .46174 .81062 .45903 .80817 .45746 Mtetra
.704 .898 .966 r
.80817 .45746 .81062 .45903 .8167 .45633 .81425 .45465 Mtetra
.707 .892 .964 r
.81425 .45465 .8167 .45633 .82278 .45361 .82035 .45185 Mtetra
.71 .886 .962 r
.82035 .45185 .82278 .45361 .82888 .4509 .82645 .44904 Mtetra
.712 .879 .959 r
.82645 .44904 .82888 .4509 .83499 .44817 .83257 .44622 Mtetra
.714 .873 .956 r
.83257 .44622 .83499 .44817 .84111 .44545 .83869 .4434 Mtetra
.715 .866 .953 r
.83869 .4434 .84111 .44545 .84724 .44272 .84482 .44057 Mtetra
.716 .86 .95 r
.84482 .44057 .84724 .44272 .85338 .43998 .85097 .43774 Mtetra
.717 .853 .946 r
.85097 .43774 .85338 .43998 .85953 .43724 .85712 .43491 Mtetra
.718 .846 .943 r
.85712 .43491 .85953 .43724 .86569 .4345 .86328 .43207 Mtetra
.719 .84 .939 r
.86328 .43207 .86569 .4345 .87185 .43175 .86945 .42923 Mtetra
.719 .833 .935 r
.86945 .42923 .87185 .43175 .87803 .42899 .87563 .42638 Mtetra
.719 .827 .932 r
.87563 .42638 .87803 .42899 .88422 .42624 .88182 .42352 Mtetra
.719 .82 .928 r
.88182 .42352 .88422 .42624 .89042 .42347 .88803 .42067 Mtetra
.719 .814 .924 r
.88803 .42067 .89042 .42347 .89663 .42071 .89424 .4178 Mtetra
.719 .808 .92 r
.89424 .4178 .89663 .42071 .90285 .41793 .90046 .41494 Mtetra
.719 .801 .916 r
.90046 .41494 .90285 .41793 .90908 .41516 .90669 .41207 Mtetra
.718 .795 .912 r
.90669 .41207 .90908 .41516 .91532 .41238 .91293 .40919 Mtetra
.718 .789 .908 r
.91293 .40919 .91532 .41238 .92157 .4096 .91918 .40631 Mtetra
.717 .783 .904 r
.91918 .40631 .92157 .4096 .92783 .40682 .92544 .40344 Mtetra
.714 .777 .901 r
.92544 .40344 .92783 .40682 .9341 .40406 .93172 .4006 Mtetra
.711 .77 .899 r
.93172 .4006 .9341 .40406 .94039 .40135 .93801 .3978 Mtetra
.706 .763 .897 r
.93801 .3978 .94039 .40135 .94671 .39871 .94432 .39508 Mtetra
.609 .727 .928 r
.36746 .56869 .37066 .57166 .37587 .57067 .37267 .56775 Mtetra
.592 .725 .937 r
.37267 .56775 .37587 .57067 .38109 .56983 .37789 .56698 Mtetra
.584 .728 .942 r
.37789 .56698 .38109 .56983 .38631 .56905 .38312 .56627 Mtetra
.578 .732 .947 r
.38312 .56627 .38631 .56905 .39155 .5683 .38836 .56559 Mtetra
.574 .736 .952 r
.38836 .56559 .39155 .5683 .3968 .56756 .39362 .56493 Mtetra
.57 .741 .957 r
.39362 .56493 .3968 .56756 .40207 .56682 .39888 .56427 Mtetra
.567 .747 .961 r
.39888 .56427 .40207 .56682 .40734 .56607 .40416 .5636 Mtetra
.564 .752 .966 r
.40416 .5636 .40734 .56607 .41263 .56533 .40946 .56293 Mtetra
.56 .757 .97 r
.40946 .56293 .41263 .56533 .41794 .56458 .41476 .56227 Mtetra
.556 .762 .974 r
.41476 .56227 .41794 .56458 .42325 .56383 .42009 .5616 Mtetra
.551 .768 .978 r
.42009 .5616 .42325 .56383 .42858 .56308 .42542 .56093 Mtetra
.546 .773 .982 r
.42542 .56093 .42858 .56308 .43393 .56233 .43077 .56026 Mtetra
.541 .778 .986 r
.43077 .56026 .43393 .56233 .43928 .56158 .43613 .55958 Mtetra
.535 .783 .989 r
.43613 .55958 .43928 .56158 .44465 .56082 .44151 .5589 Mtetra
.529 .787 .992 r
.44151 .5589 .44465 .56082 .45004 .56006 .4469 .55823 Mtetra
.522 .792 .994 r
.4469 .55823 .45004 .56006 .45544 .55931 .4523 .55755 Mtetra
.515 .796 .997 r
.4523 .55755 .45544 .55931 .46085 .55854 .45772 .55686 Mtetra
.508 .8 .998 r
.45772 .55686 .46085 .55854 .46627 .55778 .46315 .55618 Mtetra
.499 .804 .999 r
.46315 .55618 .46627 .55778 .47171 .55701 .46859 .55549 Mtetra
.49 .807 1 r
.46859 .55549 .47171 .55701 .47716 .55625 .47405 .55481 Mtetra
.481 .81 1 r
.47405 .55481 .47716 .55625 .48263 .55548 .47953 .55412 Mtetra
.47 .812 .999 r
.47953 .55412 .48263 .55548 .48811 .5547 .48502 .55342 Mtetra
.459 .814 .997 r
.48502 .55342 .48811 .5547 .4936 .55393 .49052 .55273 Mtetra
.447 .815 .994 r
.49052 .55273 .4936 .55393 .49911 .55315 .49604 .55204 Mtetra
.435 .815 .99 r
.49604 .55204 .49911 .55315 .50463 .55237 .50157 .55134 Mtetra
.421 .815 .986 r
.50157 .55134 .50463 .55237 .51017 .5516 .50711 .55064 Mtetra
.407 .813 .98 r
.50711 .55064 .51017 .5516 .51572 .55081 .51267 .54994 Mtetra
.392 .811 .972 r
.51267 .54994 .51572 .55081 .52129 .55003 .51825 .54924 Mtetra
.375 .808 .964 r
.51825 .54924 .52129 .55003 .52686 .54924 .52384 .54853 Mtetra
.358 .803 .954 r
.52384 .54853 .52686 .54924 .53246 .54846 .52944 .54783 Mtetra
.341 .798 .942 r
.52944 .54783 .53246 .54846 .53807 .54767 .53506 .54712 Mtetra
.322 .792 .93 r
.53506 .54712 .53807 .54767 .54369 .54687 .54069 .54641 Mtetra
.303 .784 .915 r
.54069 .54641 .54369 .54687 .54932 .54608 .54634 .5457 Mtetra
.283 .775 .899 r
.54634 .5457 .54932 .54608 .55498 .54528 .55201 .54498 Mtetra
.263 .764 .882 r
.55201 .54498 .55498 .54528 .56064 .54449 .55768 .54427 Mtetra
.241 .753 .863 r
.55768 .54427 .56064 .54449 .56632 .54369 .56338 .54355 Mtetra
.22 .74 .843 r
.56338 .54355 .56632 .54369 .57202 .54289 .56909 .54284 Mtetra
.198 .727 .822 r
.56909 .54284 .57202 .54289 .57773 .54208 .57481 .54211 Mtetra
.176 .712 .799 r
.57481 .54211 .57773 .54208 .58345 .54128 .58055 .54139 Mtetra
.153 .695 .775 r
.58055 .54139 .58345 .54128 .58919 .54047 .5863 .54067 Mtetra
.131 .679 .751 r
.5863 .54067 .58919 .54047 .59495 .53966 .59207 .53994 Mtetra
.108 .661 .725 r
.59207 .53994 .59495 .53966 .60072 .53885 .59786 .53921 Mtetra
0 0 0 r
.59786 .53921 .60072 .53885 .6065 .53803 .60366 .53849 Mtetra
.60366 .53849 .6065 .53803 .6123 .53722 .60948 .53776 Mtetra
.60948 .53776 .6123 .53722 .61812 .5364 .61531 .53702 Mtetra
.61531 .53702 .61812 .5364 .62395 .53557 .62116 .53628 Mtetra
.62116 .53628 .62395 .53557 .6298 .53474 .62702 .53553 Mtetra
.006 0 0 r
.62702 .53553 .6298 .53474 .63566 .53385 .6329 .53472 Mtetra
.002 0 0 r
.6329 .53472 .63566 .53385 .64153 .53287 .63878 .53381 Mtetra
0 0 0 r
.63878 .53381 .64153 .53287 .64739 .53127 .64466 .53222 Mtetra
.355 .816 .719 r
.64466 .53222 .64739 .53127 .65323 .52873 .65052 .52961 Mtetra
.392 .841 .745 r
.65052 .52961 .65323 .52873 .65908 .52612 .65638 .5269 Mtetra
.423 .861 .768 r
.65638 .5269 .65908 .52612 .66493 .52344 .66225 .52413 Mtetra
.448 .877 .79 r
.66225 .52413 .66493 .52344 .6708 .52075 .66812 .52134 Mtetra
.468 .89 .81 r
.66812 .52134 .6708 .52075 .67667 .51804 .67401 .51854 Mtetra
.488 .901 .828 r
.67401 .51854 .67667 .51804 .68255 .51533 .6799 .51574 Mtetra
.507 .911 .846 r
.6799 .51574 .68255 .51533 .68844 .51262 .6858 .51293 Mtetra
.525 .92 .862 r
.6858 .51293 .68844 .51262 .69434 .5099 .69171 .51011 Mtetra
.542 .928 .877 r
.69171 .51011 .69434 .5099 .70025 .50718 .69763 .5073 Mtetra
.559 .934 .891 r
.69763 .5073 .70025 .50718 .70616 .50445 .70356 .50448 Mtetra
.574 .939 .903 r
.70356 .50448 .70616 .50445 .71209 .50172 .70949 .50165 Mtetra
.588 .943 .914 r
.70949 .50165 .71209 .50172 .71802 .49898 .71544 .49882 Mtetra
.602 .946 .924 r
.71544 .49882 .71802 .49898 .72397 .49624 .72139 .49599 Mtetra
.615 .948 .933 r
.72139 .49599 .72397 .49624 .72992 .4935 .72736 .49315 Mtetra
.627 .949 .941 r
.72736 .49315 .72992 .4935 .73588 .49075 .73333 .49031 Mtetra
.637 .949 .947 r
.73333 .49031 .73588 .49075 .74186 .488 .73931 .48746 Mtetra
.647 .948 .953 r
.73931 .48746 .74186 .488 .74784 .48525 .7453 .48461 Mtetra
.657 .946 .957 r
.7453 .48461 .74784 .48525 .75383 .48249 .7513 .48176 Mtetra
.665 .944 .961 r
.7513 .48176 .75383 .48249 .75983 .47972 .75731 .4789 Mtetra
.673 .941 .964 r
.75731 .4789 .75983 .47972 .76584 .47696 .76333 .47603 Mtetra
.68 .937 .966 r
.76333 .47603 .76584 .47696 .77186 .47418 .76936 .47317 Mtetra
.686 .933 .967 r
.76936 .47317 .77186 .47418 .77789 .47141 .77539 .4703 Mtetra
.691 .928 .968 r
.77539 .4703 .77789 .47141 .78392 .46863 .78144 .46742 Mtetra
.696 .923 .968 r
.78144 .46742 .78392 .46863 .78997 .46584 .78749 .46454 Mtetra
.701 .918 .968 r
.78749 .46454 .78997 .46584 .79603 .46305 .79355 .46165 Mtetra
.705 .912 .967 r
.79355 .46165 .79603 .46305 .80209 .46026 .79963 .45877 Mtetra
.708 .906 .965 r
.79963 .45877 .80209 .46026 .80817 .45746 .80571 .45587 Mtetra
.711 .9 .964 r
.80571 .45587 .80817 .45746 .81425 .45465 .8118 .45297 Mtetra
.714 .894 .962 r
.8118 .45297 .81425 .45465 .82035 .45185 .8179 .45007 Mtetra
.716 .888 .959 r
.8179 .45007 .82035 .45185 .82645 .44904 .82401 .44717 Mtetra
.718 .881 .956 r
.82401 .44717 .82645 .44904 .83257 .44622 .83013 .44425 Mtetra
.72 .874 .954 r
.83013 .44425 .83257 .44622 .83869 .4434 .83626 .44134 Mtetra
.721 .868 .951 r
.83626 .44134 .83869 .4434 .84482 .44057 .84239 .43842 Mtetra
.722 .861 .947 r
.84239 .43842 .84482 .44057 .85097 .43774 .84854 .43549 Mtetra
.723 .855 .944 r
.84854 .43549 .85097 .43774 .85712 .43491 .8547 .43256 Mtetra
.724 .848 .94 r
.8547 .43256 .85712 .43491 .86328 .43207 .86086 .42963 Mtetra
.724 .841 .937 r
.86086 .42963 .86328 .43207 .86945 .42923 .86704 .42669 Mtetra
.725 .835 .933 r
.86704 .42669 .86945 .42923 .87563 .42638 .87322 .42375 Mtetra
.725 .828 .929 r
.87322 .42375 .87563 .42638 .88182 .42352 .87942 .4208 Mtetra
.725 .822 .925 r
.87942 .4208 .88182 .42352 .88803 .42067 .88562 .41785 Mtetra
.724 .816 .921 r
.88562 .41785 .88803 .42067 .89424 .4178 .89183 .41489 Mtetra
.724 .809 .918 r
.89183 .41489 .89424 .4178 .90046 .41494 .89806 .41193 Mtetra
.724 .803 .914 r
.89806 .41193 .90046 .41494 .90669 .41207 .90429 .40896 Mtetra
.723 .797 .91 r
.90429 .40896 .90669 .41207 .91293 .40919 .91053 .40599 Mtetra
.723 .791 .906 r
.91053 .40599 .91293 .40919 .91918 .40631 .91678 .40302 Mtetra
.721 .785 .902 r
.91678 .40302 .91918 .40631 .92544 .40344 .92304 .40005 Mtetra
.719 .778 .899 r
.92304 .40005 .92544 .40344 .93172 .4006 .92932 .39712 Mtetra
.715 .772 .897 r
.92932 .39712 .93172 .4006 .93801 .3978 .93561 .39423 Mtetra
.71 .765 .896 r
.93561 .39423 .93801 .3978 .94432 .39508 .94193 .39144 Mtetra
.604 .725 .93 r
.36425 .5657 .36746 .56869 .37267 .56775 .36946 .56481 Mtetra
.584 .723 .938 r
.36946 .56481 .37267 .56775 .37789 .56698 .37469 .56411 Mtetra
.575 .725 .944 r
.37469 .56411 .37789 .56698 .38312 .56627 .37992 .56348 Mtetra
.569 .729 .949 r
.37992 .56348 .38312 .56627 .38836 .56559 .38516 .56287 Mtetra
.564 .733 .954 r
.38516 .56287 .38836 .56559 .39362 .56493 .39042 .56229 Mtetra
.561 .738 .959 r
.39042 .56229 .39362 .56493 .39888 .56427 .39569 .5617 Mtetra
.557 .743 .963 r
.39569 .5617 .39888 .56427 .40416 .5636 .40097 .56112 Mtetra
.553 .748 .968 r
.40097 .56112 .40416 .5636 .40946 .56293 .40627 .56053 Mtetra
.549 .753 .972 r
.40627 .56053 .40946 .56293 .41476 .56227 .41158 .55994 Mtetra
.545 .759 .976 r
.41158 .55994 .41476 .56227 .42009 .5616 .4169 .55935 Mtetra
.54 .764 .98 r
.4169 .55935 .42009 .5616 .42542 .56093 .42224 .55876 Mtetra
.535 .769 .983 r
.42224 .55876 .42542 .56093 .43077 .56026 .4276 .55817 Mtetra
.529 .773 .987 r
.4276 .55817 .43077 .56026 .43613 .55958 .43296 .55757 Mtetra
.523 .778 .99 r
.43296 .55757 .43613 .55958 .44151 .5589 .43834 .55697 Mtetra
.517 .783 .993 r
.43834 .55697 .44151 .5589 .4469 .55823 .44374 .55638 Mtetra
.51 .787 .995 r
.44374 .55638 .4469 .55823 .4523 .55755 .44915 .55578 Mtetra
.502 .791 .997 r
.44915 .55578 .4523 .55755 .45772 .55686 .45457 .55517 Mtetra
.494 .795 .999 r
.45457 .55517 .45772 .55686 .46315 .55618 .46001 .55457 Mtetra
.485 .798 .999 r
.46001 .55457 .46315 .55618 .46859 .55549 .46546 .55396 Mtetra
.476 .801 1 r
.46546 .55396 .46859 .55549 .47405 .55481 .47093 .55336 Mtetra
.466 .803 .999 r
.47093 .55336 .47405 .55481 .47953 .55412 .47641 .55275 Mtetra
.455 .805 .998 r
.47641 .55275 .47953 .55412 .48502 .55342 .48191 .55214 Mtetra
.443 .807 .996 r
.48191 .55214 .48502 .55342 .49052 .55273 .48742 .55152 Mtetra
.431 .807 .992 r
.48742 .55152 .49052 .55273 .49604 .55204 .49294 .55091 Mtetra
.418 .807 .988 r
.49294 .55091 .49604 .55204 .50157 .55134 .49848 .55029 Mtetra
.404 .806 .983 r
.49848 .55029 .50157 .55134 .50711 .55064 .50404 .54968 Mtetra
.389 .804 .976 r
.50404 .54968 .50711 .55064 .51267 .54994 .50961 .54906 Mtetra
.374 .802 .969 r
.50961 .54906 .51267 .54994 .51825 .54924 .51519 .54844 Mtetra
.357 .798 .959 r
.51519 .54844 .51825 .54924 .52384 .54853 .52079 .54781 Mtetra
.34 .793 .949 r
.52079 .54781 .52384 .54853 .52944 .54783 .52641 .54719 Mtetra
.322 .787 .937 r
.52641 .54719 .52944 .54783 .53506 .54712 .53204 .54656 Mtetra
.303 .78 .924 r
.53204 .54656 .53506 .54712 .54069 .54641 .53768 .54594 Mtetra
.283 .771 .909 r
.53768 .54594 .54069 .54641 .54634 .5457 .54334 .54531 Mtetra
.263 .762 .892 r
.54334 .54531 .54634 .5457 .55201 .54498 .54902 .54468 Mtetra
.243 .751 .875 r
.54902 .54468 .55201 .54498 .55768 .54427 .55471 .54405 Mtetra
.221 .739 .855 r
.55471 .54405 .55768 .54427 .56338 .54355 .56042 .54341 Mtetra
.199 .726 .835 r
.56042 .54341 .56338 .54355 .56909 .54284 .56614 .54278 Mtetra
.178 .712 .813 r
.56614 .54278 .56909 .54284 .57481 .54211 .57188 .54214 Mtetra
.155 .697 .79 r
.57188 .54214 .57481 .54211 .58055 .54139 .57763 .5415 Mtetra
.133 .681 .766 r
.57763 .5415 .58055 .54139 .5863 .54067 .5834 .54086 Mtetra
.11 .664 .741 r
.5834 .54086 .5863 .54067 .59207 .53994 .58918 .54022 Mtetra
.089 .646 .715 r
.58918 .54022 .59207 .53994 .59786 .53921 .59498 .53958 Mtetra
0 0 0 r
.59498 .53958 .59786 .53921 .60366 .53849 .6008 .53894 Mtetra
.6008 .53894 .60366 .53849 .60948 .53776 .60663 .53829 Mtetra
.60663 .53829 .60948 .53776 .61531 .53702 .61248 .53764 Mtetra
.61248 .53764 .61531 .53702 .62116 .53628 .61834 .53699 Mtetra
.014 0 0 r
.61834 .53699 .62116 .53628 .62702 .53553 .62422 .53632 Mtetra
.023 0 0 r
.62422 .53632 .62702 .53553 .6329 .53472 .63012 .53559 Mtetra
.016 0 0 r
.63012 .53559 .6329 .53472 .63878 .53381 .63602 .53475 Mtetra
0 0 0 r
.63602 .53475 .63878 .53381 .64466 .53222 .64192 .53317 Mtetra
.372 .827 .726 r
.64192 .53317 .64466 .53222 .65052 .52961 .64779 .53048 Mtetra
.41 .852 .752 r
.64779 .53048 .65052 .52961 .65638 .5269 .65366 .52768 Mtetra
.441 .872 .775 r
.65366 .52768 .65638 .5269 .66225 .52413 .65954 .52482 Mtetra
.466 .887 .796 r
.65954 .52482 .66225 .52413 .66812 .52134 .66543 .52194 Mtetra
.486 .899 .815 r
.66543 .52194 .66812 .52134 .67401 .51854 .67133 .51904 Mtetra
.505 .91 .833 r
.67133 .51904 .67401 .51854 .6799 .51574 .67723 .51614 Mtetra
.524 .919 .85 r
.67723 .51614 .6799 .51574 .6858 .51293 .68315 .51324 Mtetra
.541 .927 .865 r
.68315 .51324 .6858 .51293 .69171 .51011 .68907 .51033 Mtetra
.558 .934 .88 r
.68907 .51033 .69171 .51011 .69763 .5073 .695 .50741 Mtetra
.573 .94 .893 r
.695 .50741 .69763 .5073 .70356 .50448 .70094 .5045 Mtetra
.588 .945 .904 r
.70094 .5045 .70356 .50448 .70949 .50165 .70688 .50158 Mtetra
.602 .948 .915 r
.70688 .50158 .70949 .50165 .71544 .49882 .71284 .49865 Mtetra
.615 .951 .925 r
.71284 .49865 .71544 .49882 .72139 .49599 .71881 .49572 Mtetra
.627 .952 .933 r
.71881 .49572 .72139 .49599 .72736 .49315 .72478 .49279 Mtetra
.638 .953 .94 r
.72478 .49279 .72736 .49315 .73333 .49031 .73076 .48985 Mtetra
.649 .952 .946 r
.73076 .48985 .73333 .49031 .73931 .48746 .73675 .48691 Mtetra
.658 .951 .952 r
.73675 .48691 .73931 .48746 .7453 .48461 .74275 .48397 Mtetra
.667 .949 .956 r
.74275 .48397 .7453 .48461 .7513 .48176 .74876 .48102 Mtetra
.675 .946 .959 r
.74876 .48102 .7513 .48176 .75731 .4789 .75478 .47806 Mtetra
.682 .943 .962 r
.75478 .47806 .75731 .4789 .76333 .47603 .76081 .4751 Mtetra
.689 .939 .964 r
.76081 .4751 .76333 .47603 .76936 .47317 .76684 .47214 Mtetra
.695 .935 .965 r
.76684 .47214 .76936 .47317 .77539 .4703 .77288 .46917 Mtetra
.7 .93 .966 r
.77288 .46917 .77539 .4703 .78144 .46742 .77894 .4662 Mtetra
.705 .925 .965 r
.77894 .4662 .78144 .46742 .78749 .46454 .785 .46323 Mtetra
.709 .919 .965 r
.785 .46323 .78749 .46454 .79355 .46165 .79107 .46025 Mtetra
.712 .914 .964 r
.79107 .46025 .79355 .46165 .79963 .45877 .79715 .45727 Mtetra
.716 .908 .963 r
.79715 .45727 .79963 .45877 .80571 .45587 .80324 .45428 Mtetra
.718 .902 .961 r
.80324 .45428 .80571 .45587 .8118 .45297 .80933 .45128 Mtetra
.721 .895 .959 r
.80933 .45128 .8118 .45297 .8179 .45007 .81544 .44829 Mtetra
.723 .889 .956 r
.81544 .44829 .8179 .45007 .82401 .44717 .82155 .44529 Mtetra
.725 .882 .954 r
.82155 .44529 .82401 .44717 .83013 .44425 .82768 .44228 Mtetra
.726 .876 .951 r
.82768 .44228 .83013 .44425 .83626 .44134 .83381 .43927 Mtetra
.727 .869 .948 r
.83381 .43927 .83626 .44134 .84239 .43842 .83995 .43625 Mtetra
.728 .863 .944 r
.83995 .43625 .84239 .43842 .84854 .43549 .84611 .43323 Mtetra
.729 .856 .941 r
.84611 .43323 .84854 .43549 .8547 .43256 .85227 .43021 Mtetra
.729 .849 .938 r
.85227 .43021 .8547 .43256 .86086 .42963 .85844 .42718 Mtetra
.73 .843 .934 r
.85844 .42718 .86086 .42963 .86704 .42669 .86461 .42414 Mtetra
.73 .836 .93 r
.86461 .42414 .86704 .42669 .87322 .42375 .8708 .42111 Mtetra
.73 .83 .927 r
.8708 .42111 .87322 .42375 .87942 .4208 .877 .41806 Mtetra
.73 .823 .923 r
.877 .41806 .87942 .4208 .88562 .41785 .8832 .41501 Mtetra
.729 .817 .919 r
.8832 .41501 .88562 .41785 .89183 .41489 .88942 .41196 Mtetra
.729 .811 .915 r
.88942 .41196 .89183 .41489 .89806 .41193 .89564 .4089 Mtetra
.728 .804 .911 r
.89564 .4089 .89806 .41193 .90429 .40896 .90188 .40584 Mtetra
.728 .798 .908 r
.90188 .40584 .90429 .40896 .91053 .40599 .90812 .40278 Mtetra
.727 .792 .904 r
.90812 .40278 .91053 .40599 .91678 .40302 .91437 .39971 Mtetra
.726 .786 .9 r
.91437 .39971 .91678 .40302 .92304 .40005 .92064 .39665 Mtetra
.723 .78 .897 r
.92064 .39665 .92304 .40005 .92932 .39712 .92691 .39362 Mtetra
.719 .773 .895 r
.92691 .39362 .92932 .39712 .93561 .39423 .93321 .39065 Mtetra
.713 .766 .894 r
.93321 .39065 .93561 .39423 .94193 .39144 .93953 .38778 Mtetra
.599 .723 .932 r
.36102 .5627 .36425 .5657 .36946 .56481 .36624 .56187 Mtetra
.577 .72 .94 r
.36624 .56187 .36946 .56481 .37469 .56411 .37147 .56123 Mtetra
.567 .722 .946 r
.37147 .56123 .37469 .56411 .37992 .56348 .3767 .56067 Mtetra
.56 .725 .951 r
.3767 .56067 .37992 .56348 .38516 .56287 .38195 .56015 Mtetra
.555 .73 .956 r
.38195 .56015 .38516 .56287 .39042 .56229 .3872 .55964 Mtetra
.551 .734 .961 r
.3872 .55964 .39042 .56229 .39569 .5617 .39248 .55913 Mtetra
.547 .74 .965 r
.39248 .55913 .39569 .5617 .40097 .56112 .39776 .55863 Mtetra
.543 .745 .969 r
.39776 .55863 .40097 .56112 .40627 .56053 .40306 .55812 Mtetra
.538 .75 .974 r
.40306 .55812 .40627 .56053 .41158 .55994 .40838 .55761 Mtetra
.534 .755 .978 r
.40838 .55761 .41158 .55994 .4169 .55935 .41371 .5571 Mtetra
.529 .76 .981 r
.41371 .5571 .4169 .55935 .42224 .55876 .41905 .55658 Mtetra
.523 .764 .985 r
.41905 .55658 .42224 .55876 .4276 .55817 .42441 .55607 Mtetra
.517 .769 .988 r
.42441 .55607 .4276 .55817 .43296 .55757 .42978 .55556 Mtetra
.511 .773 .991 r
.42978 .55556 .43296 .55757 .43834 .55697 .43517 .55504 Mtetra
.504 .778 .994 r
.43517 .55504 .43834 .55697 .44374 .55638 .44057 .55452 Mtetra
.496 .782 .996 r
.44057 .55452 .44374 .55638 .44915 .55578 .44598 .554 Mtetra
.488 .786 .997 r
.44598 .554 .44915 .55578 .45457 .55517 .45141 .55348 Mtetra
.48 .789 .999 r
.45141 .55348 .45457 .55517 .46001 .55457 .45686 .55295 Mtetra
.47 .792 .999 r
.45686 .55295 .46001 .55457 .46546 .55396 .46232 .55243 Mtetra
.461 .795 .999 r
.46232 .55243 .46546 .55396 .47093 .55336 .46779 .5519 Mtetra
.45 .797 .998 r
.46779 .5519 .47093 .55336 .47641 .55275 .47328 .55137 Mtetra
.439 .798 .996 r
.47328 .55137 .47641 .55275 .48191 .55214 .47879 .55084 Mtetra
.427 .799 .994 r
.47879 .55084 .48191 .55214 .48742 .55152 .4843 .55031 Mtetra
.414 .799 .99 r
.4843 .55031 .48742 .55152 .49294 .55091 .48984 .54978 Mtetra
.4 .799 .985 r
.48984 .54978 .49294 .55091 .49848 .55029 .49539 .54924 Mtetra
.385 .797 .979 r
.49539 .54924 .49848 .55029 .50404 .54968 .50095 .54871 Mtetra
.37 .795 .972 r
.50095 .54871 .50404 .54968 .50961 .54906 .50653 .54817 Mtetra
.354 .791 .964 r
.50653 .54817 .50961 .54906 .51519 .54844 .51213 .54763 Mtetra
.337 .787 .954 r
.51213 .54763 .51519 .54844 .52079 .54781 .51774 .54709 Mtetra
.319 .781 .943 r
.51774 .54709 .52079 .54781 .52641 .54719 .52336 .54655 Mtetra
.301 .775 .93 r
.52336 .54655 .52641 .54719 .53204 .54656 .529 .54601 Mtetra
.282 .767 .916 r
.529 .54601 .53204 .54656 .53768 .54594 .53466 .54546 Mtetra
.262 .758 .901 r
.53466 .54546 .53768 .54594 .54334 .54531 .54033 .54492 Mtetra
.241 .748 .884 r
.54033 .54492 .54334 .54531 .54902 .54468 .54602 .54437 Mtetra
.221 .737 .865 r
.54602 .54437 .54902 .54468 .55471 .54405 .55172 .54382 Mtetra
.199 .724 .845 r
.55172 .54382 .55471 .54405 .56042 .54341 .55744 .54327 Mtetra
.177 .711 .824 r
.55744 .54327 .56042 .54341 .56614 .54278 .56317 .54272 Mtetra
.155 .696 .802 r
.56317 .54272 .56614 .54278 .57188 .54214 .56893 .54217 Mtetra
.133 .681 .779 r
.56893 .54217 .57188 .54214 .57763 .5415 .57469 .54162 Mtetra
.111 .664 .754 r
.57469 .54162 .57763 .5415 .5834 .54086 .58048 .54106 Mtetra
.089 .647 .729 r
.58048 .54106 .5834 .54086 .58918 .54022 .58627 .54051 Mtetra
0 0 0 r
.58627 .54051 .58918 .54022 .59498 .53958 .59209 .53995 Mtetra
.59209 .53995 .59498 .53958 .6008 .53894 .59792 .53939 Mtetra
.59792 .53939 .6008 .53894 .60663 .53829 .60377 .53883 Mtetra
.60377 .53883 .60663 .53829 .61248 .53764 .60963 .53827 Mtetra
.017 0 0 r
.60963 .53827 .61248 .53764 .61834 .53699 .61551 .5377 Mtetra
.034 0 0 r
.61551 .5377 .61834 .53699 .62422 .53632 .62141 .53711 Mtetra
.041 0 0 r
.62141 .53711 .62422 .53632 .63012 .53559 .62732 .53647 Mtetra
.033 0 0 r
.62732 .53647 .63012 .53559 .63602 .53475 .63324 .5357 Mtetra
0 0 0 r
.63324 .5357 .63602 .53475 .64192 .53317 .63916 .53413 Mtetra
.387 .836 .732 r
.63916 .53413 .64192 .53317 .64779 .53048 .64504 .53135 Mtetra
.426 .861 .757 r
.64504 .53135 .64779 .53048 .65366 .52768 .65093 .52847 Mtetra
.458 .881 .78 r
.65093 .52847 .65366 .52768 .65954 .52482 .65682 .52552 Mtetra
.482 .895 .8 r
.65682 .52552 .65954 .52482 .66543 .52194 .66272 .52253 Mtetra
.502 .907 .819 r
.66272 .52253 .66543 .52194 .67133 .51904 .66863 .51954 Mtetra
.52 .917 .836 r
.66863 .51954 .67133 .51904 .67723 .51614 .67455 .51655 Mtetra
.539 .926 .852 r
.67455 .51655 .67723 .51614 .68315 .51324 .68047 .51355 Mtetra
.555 .934 .867 r
.68047 .51355 .68315 .51324 .68907 .51033 .68641 .51054 Mtetra
.571 .94 .881 r
.68641 .51054 .68907 .51033 .695 .50741 .69235 .50753 Mtetra
.587 .945 .894 r
.69235 .50753 .695 .50741 .70094 .5045 .6983 .50452 Mtetra
.601 .95 .905 r
.6983 .50452 .70094 .5045 .70688 .50158 .70426 .5015 Mtetra
.614 .953 .915 r
.70426 .5015 .70688 .50158 .71284 .49865 .71023 .49848 Mtetra
.627 .955 .924 r
.71023 .49848 .71284 .49865 .71881 .49572 .7162 .49546 Mtetra
.639 .956 .932 r
.7162 .49546 .71881 .49572 .72478 .49279 .72219 .49243 Mtetra
.649 .956 .939 r
.72219 .49243 .72478 .49279 .73076 .48985 .72818 .4894 Mtetra
.659 .955 .945 r
.72818 .4894 .73076 .48985 .73675 .48691 .73418 .48636 Mtetra
.668 .954 .95 r
.73418 .48636 .73675 .48691 .74275 .48397 .74019 .48332 Mtetra
.677 .952 .954 r
.74019 .48332 .74275 .48397 .74876 .48102 .74621 .48027 Mtetra
.684 .949 .957 r
.74621 .48027 .74876 .48102 .75478 .47806 .75223 .47722 Mtetra
.691 .945 .96 r
.75223 .47722 .75478 .47806 .76081 .4751 .75827 .47417 Mtetra
.697 .941 .961 r
.75827 .47417 .76081 .4751 .76684 .47214 .76431 .47111 Mtetra
.703 .937 .962 r
.76431 .47111 .76684 .47214 .77288 .46917 .77036 .46805 Mtetra
.708 .932 .963 r
.77036 .46805 .77288 .46917 .77894 .4662 .77642 .46498 Mtetra
.712 .927 .963 r
.77642 .46498 .77894 .4662 .785 .46323 .78249 .46191 Mtetra
.716 .921 .962 r
.78249 .46191 .785 .46323 .79107 .46025 .78857 .45884 Mtetra
.72 .915 .961 r
.78857 .45884 .79107 .46025 .79715 .45727 .79466 .45576 Mtetra
.723 .909 .96 r
.79466 .45576 .79715 .45727 .80324 .45428 .80075 .45267 Mtetra
.725 .903 .958 r
.80075 .45267 .80324 .45428 .80933 .45128 .80685 .44958 Mtetra
.727 .897 .956 r
.80685 .44958 .80933 .45128 .81544 .44829 .81297 .44649 Mtetra
.729 .89 .953 r
.81297 .44649 .81544 .44829 .82155 .44529 .81909 .4434 Mtetra
.731 .884 .951 r
.81909 .4434 .82155 .44529 .82768 .44228 .82522 .44029 Mtetra
.732 .877 .948 r
.82522 .44029 .82768 .44228 .83381 .43927 .83136 .43719 Mtetra
.733 .871 .945 r
.83136 .43719 .83381 .43927 .83995 .43625 .8375 .43408 Mtetra
.734 .864 .942 r
.8375 .43408 .83995 .43625 .84611 .43323 .84366 .43096 Mtetra
.735 .857 .938 r
.84366 .43096 .84611 .43323 .85227 .43021 .84982 .42784 Mtetra
.735 .851 .935 r
.84982 .42784 .85227 .43021 .85844 .42718 .856 .42471 Mtetra
.735 .844 .931 r
.856 .42471 .85844 .42718 .86461 .42414 .86218 .42159 Mtetra
.735 .838 .928 r
.86218 .42159 .86461 .42414 .8708 .42111 .86837 .41845 Mtetra
.735 .831 .924 r
.86837 .41845 .8708 .42111 .877 .41806 .87457 .41531 Mtetra
.735 .825 .921 r
.87457 .41531 .877 .41806 .8832 .41501 .88078 .41217 Mtetra
.734 .818 .917 r
.88078 .41217 .8832 .41501 .88942 .41196 .88699 .40902 Mtetra
.734 .812 .913 r
.88699 .40902 .88942 .41196 .89564 .4089 .89322 .40587 Mtetra
.733 .806 .909 r
.89322 .40587 .89564 .4089 .90188 .40584 .89946 .40271 Mtetra
.733 .8 .905 r
.89946 .40271 .90188 .40584 .90812 .40278 .9057 .39955 Mtetra
.732 .794 .902 r
.9057 .39955 .90812 .40278 .91437 .39971 .91195 .39638 Mtetra
.73 .788 .898 r
.91195 .39638 .91437 .39971 .92064 .39665 .91822 .39323 Mtetra
.727 .781 .896 r
.91822 .39323 .92064 .39665 .92691 .39362 .9245 .39011 Mtetra
.723 .775 .893 r
.9245 .39011 .92691 .39362 .93321 .39065 .93079 .38705 Mtetra
.717 .768 .892 r
.93079 .38705 .93321 .39065 .93953 .38778 .93711 .3841 Mtetra
.593 .721 .933 r
.35779 .55969 .36102 .5627 .36624 .56187 .36301 .55891 Mtetra
.569 .718 .942 r
.36301 .55891 .36624 .56187 .37147 .56123 .36824 .55835 Mtetra
.558 .719 .948 r
.36824 .55835 .37147 .56123 .3767 .56067 .37347 .55786 Mtetra
.551 .722 .953 r
.37347 .55786 .3767 .56067 .38195 .56015 .37872 .55741 Mtetra
.545 .726 .958 r
.37872 .55741 .38195 .56015 .3872 .55964 .38398 .55698 Mtetra
.541 .731 .963 r
.38398 .55698 .3872 .55964 .39248 .55913 .38925 .55655 Mtetra
.537 .736 .967 r
.38925 .55655 .39248 .55913 .39776 .55863 .39454 .55612 Mtetra
.532 .741 .971 r
.39454 .55612 .39776 .55863 .40306 .55812 .39985 .55569 Mtetra
.527 .746 .975 r
.39985 .55569 .40306 .55812 .40838 .55761 .40517 .55527 Mtetra
.522 .75 .979 r
.40517 .55527 .40838 .55761 .41371 .5571 .4105 .55483 Mtetra
.517 .755 .983 r
.4105 .55483 .41371 .5571 .41905 .55658 .41585 .5544 Mtetra
.511 .76 .986 r
.41585 .5544 .41905 .55658 .42441 .55607 .42121 .55397 Mtetra
.504 .764 .989 r
.42121 .55397 .42441 .55607 .42978 .55556 .42659 .55353 Mtetra
.498 .769 .992 r
.42659 .55353 .42978 .55556 .43517 .55504 .43198 .55309 Mtetra
.49 .773 .994 r
.43198 .55309 .43517 .55504 .44057 .55452 .43738 .55265 Mtetra
.482 .776 .996 r
.43738 .55265 .44057 .55452 .44598 .554 .4428 .55221 Mtetra
.474 .78 .998 r
.4428 .55221 .44598 .554 .45141 .55348 .44824 .55177 Mtetra
.465 .783 .998 r
.44824 .55177 .45141 .55348 .45686 .55295 .45369 .55133 Mtetra
.455 .786 .999 r
.45369 .55133 .45686 .55295 .46232 .55243 .45916 .55089 Mtetra
.445 .788 .998 r
.45916 .55089 .46232 .55243 .46779 .5519 .46464 .55044 Mtetra
.434 .79 .997 r
.46464 .55044 .46779 .5519 .47328 .55137 .47014 .54999 Mtetra
.422 .79 .994 r
.47014 .54999 .47328 .55137 .47879 .55084 .47565 .54954 Mtetra
.409 .791 .991 r
.47565 .54954 .47879 .55084 .4843 .55031 .48117 .54909 Mtetra
.396 .791 .987 r
.48117 .54909 .4843 .55031 .48984 .54978 .48672 .54864 Mtetra
.382 .789 .982 r
.48672 .54864 .48984 .54978 .49539 .54924 .49227 .54819 Mtetra
.366 .787 .975 r
.49227 .54819 .49539 .54924 .50095 .54871 .49785 .54774 Mtetra
.351 .784 .968 r
.49785 .54774 .50095 .54871 .50653 .54817 .50344 .54728 Mtetra
.334 .781 .958 r
.50344 .54728 .50653 .54817 .51213 .54763 .50904 .54683 Mtetra
.317 .775 .948 r
.50904 .54683 .51213 .54763 .51774 .54709 .51466 .54637 Mtetra
.298 .769 .936 r
.51466 .54637 .51774 .54709 .52336 .54655 .5203 .54591 Mtetra
.28 .762 .923 r
.5203 .54591 .52336 .54655 .529 .54601 .52595 .54545 Mtetra
.26 .754 .908 r
.52595 .54545 .529 .54601 .53466 .54546 .53162 .54499 Mtetra
.24 .744 .892 r
.53162 .54499 .53466 .54546 .54033 .54492 .5373 .54453 Mtetra
.219 .734 .874 r
.5373 .54453 .54033 .54492 .54602 .54437 .543 .54407 Mtetra
.198 .722 .855 r
.543 .54407 .54602 .54437 .55172 .54382 .54871 .5436 Mtetra
.176 .709 .834 r
.54871 .5436 .55172 .54382 .55744 .54327 .55445 .54314 Mtetra
.154 .694 .813 r
.55445 .54314 .55744 .54327 .56317 .54272 .56019 .54267 Mtetra
.133 .68 .79 r
.56019 .54267 .56317 .54272 .56893 .54217 .56596 .5422 Mtetra
.11 .664 .766 r
.56596 .5422 .56893 .54217 .57469 .54162 .57174 .54173 Mtetra
.088 .647 .741 r
.57174 .54173 .57469 .54162 .58048 .54106 .57753 .54126 Mtetra
.066 .629 .715 r
.57753 .54126 .58048 .54106 .58627 .54051 .58335 .54079 Mtetra
0 0 0 r
.58335 .54079 .58627 .54051 .59209 .53995 .58918 .54032 Mtetra
.58918 .54032 .59209 .53995 .59792 .53939 .59503 .53985 Mtetra
.59503 .53985 .59792 .53939 .60377 .53883 .60089 .53938 Mtetra
.018 0 0 r
.60089 .53938 .60377 .53883 .60963 .53827 .60677 .5389 Mtetra
.038 0 0 r
.60677 .5389 .60963 .53827 .61551 .5377 .61267 .53842 Mtetra
.054 0 0 r
.61267 .53842 .61551 .5377 .62141 .53711 .61858 .53791 Mtetra
.06 0 0 r
.61858 .53791 .62141 .53711 .62732 .53647 .62451 .53735 Mtetra
.05 0 0 r
.62451 .53735 .62732 .53647 .63324 .5357 .63045 .53666 Mtetra
0 0 0 r
.63045 .53666 .63324 .5357 .63916 .53413 .63638 .53509 Mtetra
.4 .844 .736 r
.63638 .53509 .63916 .53413 .64504 .53135 .64227 .53224 Mtetra
.44 .869 .761 r
.64227 .53224 .64504 .53135 .65093 .52847 .64818 .52927 Mtetra
.473 .889 .783 r
.64818 .52927 .65093 .52847 .65682 .52552 .65408 .52622 Mtetra
.497 .903 .803 r
.65408 .52622 .65682 .52552 .66272 .52253 .66 .52314 Mtetra
.516 .914 .821 r
.66 .52314 .66272 .52253 .66863 .51954 .66592 .52005 Mtetra
.534 .923 .838 r
.66592 .52005 .66863 .51954 .67455 .51655 .67185 .51696 Mtetra
.552 .932 .854 r
.67185 .51696 .67455 .51655 .68047 .51355 .67779 .51386 Mtetra
.569 .939 .868 r
.67779 .51386 .68047 .51355 .68641 .51054 .68373 .51076 Mtetra
.584 .945 .882 r
.68373 .51076 .68641 .51054 .69235 .50753 .68969 .50766 Mtetra
.599 .95 .894 r
.68969 .50766 .69235 .50753 .6983 .50452 .69565 .50455 Mtetra
.613 .954 .905 r
.69565 .50455 .6983 .50452 .70426 .5015 .70162 .50143 Mtetra
.626 .957 .915 r
.70162 .50143 .70426 .5015 .71023 .49848 .7076 .49832 Mtetra
.638 .958 .923 r
.7076 .49832 .71023 .49848 .7162 .49546 .71358 .49519 Mtetra
.649 .959 .931 r
.71358 .49519 .7162 .49546 .72219 .49243 .71958 .49207 Mtetra
.66 .959 .938 r
.71958 .49207 .72219 .49243 .72818 .4894 .72558 .48894 Mtetra
.669 .958 .943 r
.72558 .48894 .72818 .4894 .73418 .48636 .73159 .48581 Mtetra
.678 .956 .948 r
.73159 .48581 .73418 .48636 .74019 .48332 .73761 .48267 Mtetra
.686 .954 .952 r
.73761 .48267 .74019 .48332 .74621 .48027 .74364 .47953 Mtetra
.693 .951 .955 r
.74364 .47953 .74621 .48027 .75223 .47722 .74967 .47638 Mtetra
.7 .947 .957 r
.74967 .47638 .75223 .47722 .75827 .47417 .75572 .47323 Mtetra
.706 .943 .959 r
.75572 .47323 .75827 .47417 .76431 .47111 .76177 .47008 Mtetra
.711 .939 .96 r
.76177 .47008 .76431 .47111 .77036 .46805 .76783 .46692 Mtetra
.715 .934 .96 r
.76783 .46692 .77036 .46805 .77642 .46498 .7739 .46376 Mtetra
.72 .928 .96 r
.7739 .46376 .77642 .46498 .78249 .46191 .77997 .46059 Mtetra
.723 .923 .959 r
.77997 .46059 .78249 .46191 .78857 .45884 .78606 .45742 Mtetra
.726 .917 .958 r
.78606 .45742 .78857 .45884 .79466 .45576 .79215 .45424 Mtetra
.729 .911 .957 r
.79215 .45424 .79466 .45576 .80075 .45267 .79825 .45106 Mtetra
.732 .905 .955 r
.79825 .45106 .80075 .45267 .80685 .44958 .80436 .44788 Mtetra
.734 .898 .953 r
.80436 .44788 .80685 .44958 .81297 .44649 .81048 .44469 Mtetra
.735 .892 .951 r
.81048 .44469 .81297 .44649 .81909 .4434 .81661 .4415 Mtetra
.737 .885 .948 r
.81661 .4415 .81909 .4434 .82522 .44029 .82274 .4383 Mtetra
.738 .879 .945 r
.82274 .4383 .82522 .44029 .83136 .43719 .82889 .4351 Mtetra
.739 .872 .942 r
.82889 .4351 .83136 .43719 .8375 .43408 .83504 .43189 Mtetra
.739 .865 .939 r
.83504 .43189 .8375 .43408 .84366 .43096 .8412 .42868 Mtetra
.74 .859 .936 r
.8412 .42868 .84366 .43096 .84982 .42784 .84737 .42546 Mtetra
.74 .852 .932 r
.84737 .42546 .84982 .42784 .856 .42471 .85355 .42224 Mtetra
.74 .846 .929 r
.85355 .42224 .856 .42471 .86218 .42159 .85973 .41902 Mtetra
.74 .839 .925 r
.85973 .41902 .86218 .42159 .86837 .41845 .86593 .41579 Mtetra
.74 .833 .922 r
.86593 .41579 .86837 .41845 .87457 .41531 .87213 .41255 Mtetra
.74 .826 .918 r
.87213 .41255 .87457 .41531 .88078 .41217 .87834 .40931 Mtetra
.739 .82 .914 r
.87834 .40931 .88078 .41217 .88699 .40902 .88456 .40607 Mtetra
.739 .814 .911 r
.88456 .40607 .88699 .40902 .89322 .40587 .89079 .40282 Mtetra
.738 .807 .907 r
.89079 .40282 .89322 .40587 .89946 .40271 .89703 .39956 Mtetra
.737 .801 .903 r
.89703 .39956 .89946 .40271 .9057 .39955 .90327 .39631 Mtetra
.736 .795 .9 r
.90327 .39631 .9057 .39955 .91195 .39638 .90953 .39305 Mtetra
.735 .789 .896 r
.90953 .39305 .91195 .39638 .91822 .39323 .91579 .3898 Mtetra
.732 .783 .894 r
.91579 .3898 .91822 .39323 .9245 .39011 .92207 .38659 Mtetra
.727 .776 .892 r
.92207 .38659 .9245 .39011 .93079 .38705 .92837 .38344 Mtetra
.72 .769 .891 r
.92837 .38344 .93079 .38705 .93711 .3841 .93469 .38041 Mtetra
.587 .72 .935 r
.35454 .55667 .35779 .55969 .36301 .55891 .35976 .55594 Mtetra
.561 .715 .944 r
.35976 .55594 .36301 .55891 .36824 .55835 .36499 .55545 Mtetra
.549 .716 .95 r
.36499 .55545 .36824 .55835 .37347 .55786 .37023 .55504 Mtetra
.541 .719 .955 r
.37023 .55504 .37347 .55786 .37872 .55741 .37548 .55466 Mtetra
.535 .723 .96 r
.37548 .55466 .37872 .55741 .38398 .55698 .38074 .55431 Mtetra
.53 .727 .964 r
.38074 .55431 .38398 .55698 .38925 .55655 .38602 .55396 Mtetra
.526 .732 .968 r
.38602 .55396 .38925 .55655 .39454 .55612 .39131 .55361 Mtetra
.521 .737 .973 r
.39131 .55361 .39454 .55612 .39985 .55569 .39662 .55326 Mtetra
.516 .741 .977 r
.39662 .55326 .39985 .55569 .40517 .55527 .40194 .55291 Mtetra
.511 .746 .98 r
.40194 .55291 .40517 .55527 .4105 .55483 .40728 .55256 Mtetra
.505 .751 .984 r
.40728 .55256 .4105 .55483 .41585 .5544 .41263 .55221 Mtetra
.498 .755 .987 r
.41263 .55221 .41585 .5544 .42121 .55397 .418 .55185 Mtetra
.492 .759 .99 r
.418 .55185 .42121 .55397 .42659 .55353 .42338 .5515 Mtetra
.485 .763 .992 r
.42338 .5515 .42659 .55353 .43198 .55309 .42877 .55114 Mtetra
.477 .767 .995 r
.42877 .55114 .43198 .55309 .43738 .55265 .43418 .55078 Mtetra
.468 .77 .996 r
.43418 .55078 .43738 .55265 .4428 .55221 .43961 .55042 Mtetra
.46 .774 .997 r
.43961 .55042 .4428 .55221 .44824 .55177 .44505 .55006 Mtetra
.45 .776 .998 r
.44505 .55006 .44824 .55177 .45369 .55133 .45051 .5497 Mtetra
.44 .779 .998 r
.45051 .5497 .45369 .55133 .45916 .55089 .45598 .54933 Mtetra
.429 .78 .997 r
.45598 .54933 .45916 .55089 .46464 .55044 .46147 .54897 Mtetra
.417 .782 .995 r
.46147 .54897 .46464 .55044 .47014 .54999 .46697 .5486 Mtetra
.405 .782 .992 r
.46697 .5486 .47014 .54999 .47565 .54954 .47249 .54824 Mtetra
.392 .782 .989 r
.47249 .54824 .47565 .54954 .48117 .54909 .47803 .54787 Mtetra
.378 .782 .984 r
.47803 .54787 .48117 .54909 .48672 .54864 .48358 .5475 Mtetra
.363 .78 .978 r
.48358 .5475 .48672 .54864 .49227 .54819 .48915 .54713 Mtetra
.348 .777 .971 r
.48915 .54713 .49227 .54819 .49785 .54774 .49473 .54676 Mtetra
.331 .774 .963 r
.49473 .54676 .49785 .54774 .50344 .54728 .50033 .54639 Mtetra
.315 .769 .953 r
.50033 .54639 .50344 .54728 .50904 .54683 .50594 .54601 Mtetra
.297 .764 .942 r
.50594 .54601 .50904 .54683 .51466 .54637 .51157 .54564 Mtetra
.278 .757 .929 r
.51157 .54564 .51466 .54637 .5203 .54591 .51722 .54527 Mtetra
.259 .749 .915 r
.51722 .54527 .5203 .54591 .52595 .54545 .52288 .54489 Mtetra
.239 .741 .9 r
.52288 .54489 .52595 .54545 .53162 .54499 .52856 .54451 Mtetra
.218 .73 .883 r
.52856 .54451 .53162 .54499 .5373 .54453 .53425 .54413 Mtetra
.198 .719 .865 r
.53425 .54413 .5373 .54453 .543 .54407 .53996 .54376 Mtetra
.177 .707 .845 r
.53996 .54376 .543 .54407 .54871 .5436 .54569 .54338 Mtetra
.155 .693 .824 r
.54569 .54338 .54871 .5436 .55445 .54314 .55143 .543 Mtetra
.133 .679 .802 r
.55143 .543 .55445 .54314 .56019 .54267 .55719 .54261 Mtetra
.111 .664 .779 r
.55719 .54261 .56019 .54267 .56596 .5422 .56297 .54223 Mtetra
.089 .648 .755 r
.56297 .54223 .56596 .5422 .57174 .54173 .56877 .54185 Mtetra
.067 .63 .729 r
.56877 .54185 .57174 .54173 .57753 .54126 .57458 .54147 Mtetra
0 0 0 r
.57458 .54147 .57753 .54126 .58335 .54079 .5804 .54108 Mtetra
.5804 .54108 .58335 .54079 .58918 .54032 .58625 .54069 Mtetra
.58625 .54069 .58918 .54032 .59503 .53985 .59211 .54031 Mtetra
.019 0 0 r
.59211 .54031 .59503 .53985 .60089 .53938 .59799 .53992 Mtetra
.038 0 0 r
.59799 .53992 .60089 .53938 .60677 .5389 .60389 .53953 Mtetra
.057 0 0 r
.60389 .53953 .60677 .5389 .61267 .53842 .6098 .53914 Mtetra
.072 0 0 r
.6098 .53914 .61267 .53842 .61858 .53791 .61573 .53872 Mtetra
.077 0 0 r
.61573 .53872 .61858 .53791 .62451 .53735 .62168 .53824 Mtetra
.065 0 0 r
.62168 .53824 .62451 .53735 .63045 .53666 .62763 .53762 Mtetra
0 0 0 r
.62763 .53762 .63045 .53666 .63638 .53509 .63358 .53607 Mtetra
.416 .853 .741 r
.63358 .53607 .63638 .53509 .64227 .53224 .63949 .53313 Mtetra
.457 .878 .766 r
.63949 .53313 .64227 .53224 .64818 .52927 .64541 .53007 Mtetra
.489 .897 .788 r
.64541 .53007 .64818 .52927 .65408 .52622 .65133 .52692 Mtetra
.513 .911 .807 r
.65133 .52692 .65408 .52622 .66 .52314 .65726 .52375 Mtetra
.532 .921 .825 r
.65726 .52375 .66 .52314 .66592 .52005 .66319 .52056 Mtetra
.55 .93 .841 r
.66319 .52056 .66592 .52005 .67185 .51696 .66913 .51737 Mtetra
.567 .938 .856 r
.66913 .51737 .67185 .51696 .67779 .51386 .67508 .51418 Mtetra
.583 .945 .87 r
.67508 .51418 .67779 .51386 .68373 .51076 .68104 .51098 Mtetra
.598 .95 .883 r
.68104 .51098 .68373 .51076 .68969 .50766 .68701 .50778 Mtetra
.612 .955 .895 r
.68701 .50778 .68969 .50766 .69565 .50455 .69298 .50457 Mtetra
.626 .958 .905 r
.69298 .50457 .69565 .50455 .70162 .50143 .69896 .50136 Mtetra
.638 .961 .915 r
.69896 .50136 .70162 .50143 .7076 .49832 .70495 .49814 Mtetra
.649 .962 .923 r
.70495 .49814 .7076 .49832 .71358 .49519 .71095 .49493 Mtetra
.66 .962 .93 r
.71095 .49493 .71358 .49519 .71958 .49207 .71695 .4917 Mtetra
.67 .962 .936 r
.71695 .4917 .71958 .49207 .72558 .48894 .72297 .48848 Mtetra
.679 .961 .942 r
.72297 .48848 .72558 .48894 .73159 .48581 .72899 .48525 Mtetra
.688 .959 .946 r
.72899 .48525 .73159 .48581 .73761 .48267 .73502 .48201 Mtetra
.695 .956 .95 r
.73502 .48201 .73761 .48267 .74364 .47953 .74105 .47878 Mtetra
.702 .953 .953 r
.74105 .47878 .74364 .47953 .74967 .47638 .7471 .47553 Mtetra
.708 .949 .955 r
.7471 .47553 .74967 .47638 .75572 .47323 .75315 .47229 Mtetra
.714 .945 .956 r
.75315 .47229 .75572 .47323 .76177 .47008 .75921 .46904 Mtetra
.719 .94 .957 r
.75921 .46904 .76177 .47008 .76783 .46692 .76528 .46578 Mtetra
.723 .935 .957 r
.76528 .46578 .76783 .46692 .7739 .46376 .77136 .46252 Mtetra
.727 .93 .957 r
.77136 .46252 .7739 .46376 .77997 .46059 .77744 .45926 Mtetra
.73 .924 .956 r
.77744 .45926 .77997 .46059 .78606 .45742 .78353 .45599 Mtetra
.733 .918 .955 r
.78353 .45599 .78606 .45742 .79215 .45424 .78963 .45272 Mtetra
.736 .912 .954 r
.78963 .45272 .79215 .45424 .79825 .45106 .79574 .44944 Mtetra
.738 .906 .952 r
.79574 .44944 .79825 .45106 .80436 .44788 .80186 .44616 Mtetra
.74 .899 .95 r
.80186 .44616 .80436 .44788 .81048 .44469 .80798 .44288 Mtetra
.741 .893 .948 r
.80798 .44288 .81048 .44469 .81661 .4415 .81412 .43959 Mtetra
.743 .886 .945 r
.81412 .43959 .81661 .4415 .82274 .4383 .82026 .43629 Mtetra
.744 .88 .942 r
.82026 .43629 .82274 .4383 .82889 .4351 .82641 .43299 Mtetra
.744 .873 .939 r
.82641 .43299 .82889 .4351 .83504 .43189 .83256 .42969 Mtetra
.745 .867 .936 r
.83256 .42969 .83504 .43189 .8412 .42868 .83873 .42638 Mtetra
.745 .86 .933 r
.83873 .42638 .8412 .42868 .84737 .42546 .8449 .42307 Mtetra
.745 .853 .93 r
.8449 .42307 .84737 .42546 .85355 .42224 .85108 .41975 Mtetra
.745 .847 .926 r
.85108 .41975 .85355 .42224 .85973 .41902 .85727 .41643 Mtetra
.745 .84 .923 r
.85727 .41643 .85973 .41902 .86593 .41579 .86347 .41311 Mtetra
.745 .834 .919 r
.86347 .41311 .86593 .41579 .87213 .41255 .86968 .40977 Mtetra
.744 .827 .916 r
.86968 .40977 .87213 .41255 .87834 .40931 .87589 .40644 Mtetra
.744 .821 .912 r
.87589 .40644 .87834 .40931 .88456 .40607 .88211 .4031 Mtetra
.743 .815 .908 r
.88211 .4031 .88456 .40607 .89079 .40282 .88834 .39975 Mtetra
.742 .809 .905 r
.88834 .39975 .89079 .40282 .89703 .39956 .89458 .3964 Mtetra
.742 .803 .901 r
.89458 .3964 .89703 .39956 .90327 .39631 .90083 .39305 Mtetra
.741 .797 .897 r
.90083 .39305 .90327 .39631 .90953 .39305 .90709 .3897 Mtetra
.739 .791 .894 r
.90709 .3897 .90953 .39305 .91579 .3898 .91335 .38635 Mtetra
.736 .784 .892 r
.91335 .38635 .91579 .3898 .92207 .38659 .91964 .38305 Mtetra
.731 .777 .89 r
.91964 .38305 .92207 .38659 .92837 .38344 .92593 .37982 Mtetra
.724 .77 .889 r
.92593 .37982 .92837 .38344 .93469 .38041 .93226 .37671 Mtetra
.582 .718 .936 r
.35128 .55364 .35454 .55667 .35976 .55594 .35651 .55296 Mtetra
.553 .712 .946 r
.35651 .55296 .35976 .55594 .36499 .55545 .36174 .55254 Mtetra
.54 .712 .952 r
.36174 .55254 .36499 .55545 .37023 .55504 .36698 .5522 Mtetra
.531 .715 .957 r
.36698 .5522 .37023 .55504 .37548 .55466 .37223 .5519 Mtetra
.525 .719 .961 r
.37223 .5519 .37548 .55466 .38074 .55431 .37749 .55163 Mtetra
.519 .723 .966 r
.37749 .55163 .38074 .55431 .38602 .55396 .38277 .55136 Mtetra
.515 .728 .97 r
.38277 .55136 .38602 .55396 .39131 .55361 .38807 .55109 Mtetra
.51 .732 .974 r
.38807 .55109 .39131 .55361 .39662 .55326 .39338 .55082 Mtetra
.504 .737 .978 r
.39338 .55082 .39662 .55326 .40194 .55291 .3987 .55055 Mtetra
.498 .741 .981 r
.3987 .55055 .40194 .55291 .40728 .55256 .40404 .55028 Mtetra
.492 .746 .985 r
.40404 .55028 .40728 .55256 .41263 .55221 .4094 .55 Mtetra
.485 .75 .988 r
.4094 .55 .41263 .55221 .418 .55185 .41477 .54973 Mtetra
.478 .754 .99 r
.41477 .54973 .418 .55185 .42338 .5515 .42015 .54945 Mtetra
.471 .758 .993 r
.42015 .54945 .42338 .5515 .42877 .55114 .42556 .54918 Mtetra
.463 .761 .995 r
.42556 .54918 .42877 .55114 .43418 .55078 .43097 .5489 Mtetra
.454 .764 .996 r
.43097 .5489 .43418 .55078 .43961 .55042 .4364 .54862 Mtetra
.445 .767 .997 r
.4364 .54862 .43961 .55042 .44505 .55006 .44185 .54834 Mtetra
.435 .77 .997 r
.44185 .54834 .44505 .55006 .45051 .5497 .44731 .54806 Mtetra
.424 .771 .996 r
.44731 .54806 .45051 .5497 .45598 .54933 .45279 .54778 Mtetra
.412 .773 .995 r
.45279 .54778 .45598 .54933 .46147 .54897 .45829 .54749 Mtetra
.401 .774 .993 r
.45829 .54749 .46147 .54897 .46697 .5486 .4638 .54721 Mtetra
.388 .774 .99 r
.4638 .54721 .46697 .5486 .47249 .54824 .46933 .54692 Mtetra
.374 .773 .985 r
.46933 .54692 .47249 .54824 .47803 .54787 .47487 .54664 Mtetra
.36 .772 .98 r
.47487 .54664 .47803 .54787 .48358 .5475 .48043 .54635 Mtetra
.345 .77 .974 r
.48043 .54635 .48358 .5475 .48915 .54713 .486 .54606 Mtetra
.328 .767 .966 r
.486 .54606 .48915 .54713 .49473 .54676 .49159 .54578 Mtetra
.312 .763 .957 r
.49159 .54578 .49473 .54676 .50033 .54639 .4972 .54549 Mtetra
.294 .758 .947 r
.4972 .54549 .50033 .54639 .50594 .54601 .50282 .5452 Mtetra
.276 .752 .935 r
.50282 .5452 .50594 .54601 .51157 .54564 .50846 .54491 Mtetra
.257 .744 .922 r
.50846 .54491 .51157 .54564 .51722 .54527 .51412 .54462 Mtetra
.238 .736 .907 r
.51412 .54462 .51722 .54527 .52288 .54489 .51979 .54432 Mtetra
.218 .727 .891 r
.51979 .54432 .52288 .54489 .52856 .54451 .52548 .54403 Mtetra
.197 .716 .874 r
.52548 .54403 .52856 .54451 .53425 .54413 .53119 .54374 Mtetra
.176 .704 .855 r
.53119 .54374 .53425 .54413 .53996 .54376 .53691 .54344 Mtetra
.155 .692 .835 r
.53691 .54344 .53996 .54376 .54569 .54338 .54265 .54315 Mtetra
.133 .678 .814 r
.54265 .54315 .54569 .54338 .55143 .543 .54841 .54285 Mtetra
.111 .663 .791 r
.54841 .54285 .55143 .543 .55719 .54261 .55418 .54256 Mtetra
.09 .648 .768 r
.55418 .54256 .55719 .54261 .56297 .54223 .55997 .54226 Mtetra
.068 .631 .743 r
.55997 .54226 .56297 .54223 .56877 .54185 .56578 .54196 Mtetra
.045 .614 .718 r
.56578 .54196 .56877 .54185 .57458 .54147 .5716 .54167 Mtetra
0 0 0 r
.5716 .54167 .57458 .54147 .5804 .54108 .57744 .54137 Mtetra
.57744 .54137 .5804 .54108 .58625 .54069 .5833 .54107 Mtetra
.018 0 0 r
.5833 .54107 .58625 .54069 .59211 .54031 .58918 .54077 Mtetra
.039 0 0 r
.58918 .54077 .59211 .54031 .59799 .53992 .59507 .54047 Mtetra
.057 0 0 r
.59507 .54047 .59799 .53992 .60389 .53953 .60099 .54017 Mtetra
.075 0 0 r
.60099 .54017 .60389 .53953 .6098 .53914 .60692 .53986 Mtetra
.09 0 0 r
.60692 .53986 .6098 .53914 .61573 .53872 .61286 .53953 Mtetra
.094 0 0 r
.61286 .53953 .61573 .53872 .62168 .53824 .61883 .53913 Mtetra
.079 0 0 r
.61883 .53913 .62168 .53824 .62763 .53762 .6248 .53858 Mtetra
0 0 0 r
.6248 .53858 .62763 .53762 .63358 .53607 .63076 .53704 Mtetra
.431 .862 .747 r
.63076 .53704 .63358 .53607 .63949 .53313 .63669 .53402 Mtetra
.473 .887 .771 r
.63669 .53402 .63949 .53313 .64541 .53007 .64262 .53087 Mtetra
.505 .905 .793 r
.64262 .53087 .64541 .53007 .65133 .52692 .64855 .52763 Mtetra
.529 .919 .811 r
.64855 .52763 .65133 .52692 .65726 .52375 .6545 .52436 Mtetra
.547 .928 .828 r
.6545 .52436 .65726 .52375 .66319 .52056 .66044 .52107 Mtetra
.564 .937 .844 r
.66044 .52107 .66319 .52056 .66913 .51737 .6664 .51779 Mtetra
.581 .944 .858 r
.6664 .51779 .66913 .51737 .67508 .51418 .67236 .51449 Mtetra
.597 .95 .872 r
.67236 .51449 .67508 .51418 .68104 .51098 .67833 .51119 Mtetra
.611 .955 .884 r
.67833 .51119 .68104 .51098 .68701 .50778 .68431 .5079 Mtetra
.625 .959 .895 r
.68431 .5079 .68701 .50778 .69298 .50457 .6903 .50459 Mtetra
.638 .962 .905 r
.6903 .50459 .69298 .50457 .69896 .50136 .69629 .50128 Mtetra
.649 .964 .914 r
.69629 .50128 .69896 .50136 .70495 .49814 .70229 .49797 Mtetra
.661 .965 .922 r
.70229 .49797 .70495 .49814 .71095 .49493 .7083 .49466 Mtetra
.671 .965 .929 r
.7083 .49466 .71095 .49493 .71695 .4917 .71432 .49134 Mtetra
.68 .964 .935 r
.71432 .49134 .71695 .4917 .72297 .48848 .72034 .48801 Mtetra
.689 .963 .94 r
.72034 .48801 .72297 .48848 .72899 .48525 .72637 .48469 Mtetra
.697 .961 .944 r
.72637 .48469 .72899 .48525 .73502 .48201 .73241 .48135 Mtetra
.704 .958 .948 r
.73241 .48135 .73502 .48201 .74105 .47878 .73845 .47802 Mtetra
.711 .955 .95 r
.73845 .47802 .74105 .47878 .7471 .47553 .74451 .47468 Mtetra
.716 .951 .952 r
.74451 .47468 .7471 .47553 .75315 .47229 .75057 .47134 Mtetra
.722 .946 .954 r
.75057 .47134 .75315 .47229 .75921 .46904 .75664 .46799 Mtetra
.726 .941 .954 r
.75664 .46799 .75921 .46904 .76528 .46578 .76272 .46464 Mtetra
.73 .936 .955 r
.76272 .46464 .76528 .46578 .77136 .46252 .7688 .46128 Mtetra
.734 .931 .954 r
.7688 .46128 .77136 .46252 .77744 .45926 .77489 .45792 Mtetra
.737 .925 .954 r
.77489 .45792 .77744 .45926 .78353 .45599 .78099 .45456 Mtetra
.74 .919 .952 r
.78099 .45456 .78353 .45599 .78963 .45272 .7871 .45119 Mtetra
.742 .913 .951 r
.7871 .45119 .78963 .45272 .79574 .44944 .79322 .44781 Mtetra
.744 .907 .949 r
.79322 .44781 .79574 .44944 .80186 .44616 .79934 .44444 Mtetra
.746 .9 .947 r
.79934 .44444 .80186 .44616 .80798 .44288 .80547 .44105 Mtetra
.747 .894 .945 r
.80547 .44105 .80798 .44288 .81412 .43959 .81161 .43767 Mtetra
.749 .887 .942 r
.81161 .43767 .81412 .43959 .82026 .43629 .81776 .43428 Mtetra
.749 .881 .939 r
.81776 .43428 .82026 .43629 .82641 .43299 .82391 .43088 Mtetra
.75 .874 .937 r
.82391 .43088 .82641 .43299 .83256 .42969 .83007 .42748 Mtetra
.75 .868 .933 r
.83007 .42748 .83256 .42969 .83873 .42638 .83625 .42408 Mtetra
.751 .861 .93 r
.83625 .42408 .83873 .42638 .8449 .42307 .84242 .42067 Mtetra
.75 .854 .927 r
.84242 .42067 .8449 .42307 .85108 .41975 .84861 .41726 Mtetra
.75 .848 .924 r
.84861 .41726 .85108 .41975 .85727 .41643 .8548 .41384 Mtetra
.75 .841 .92 r
.8548 .41384 .85727 .41643 .86347 .41311 .861 .41041 Mtetra
.75 .835 .917 r
.861 .41041 .86347 .41311 .86968 .40977 .86721 .40699 Mtetra
.749 .829 .913 r
.86721 .40699 .86968 .40977 .87589 .40644 .87343 .40356 Mtetra
.748 .822 .91 r
.87343 .40356 .87589 .40644 .88211 .4031 .87966 .40012 Mtetra
.748 .816 .906 r
.87966 .40012 .88211 .4031 .88834 .39975 .88589 .39667 Mtetra
.747 .81 .902 r
.88589 .39667 .88834 .39975 .89458 .3964 .89213 .39323 Mtetra
.746 .804 .899 r
.89213 .39323 .89458 .3964 .90083 .39305 .89838 .38978 Mtetra
.745 .798 .895 r
.89838 .38978 .90083 .39305 .90709 .3897 .90464 .38633 Mtetra
.743 .792 .892 r
.90464 .38633 .90709 .3897 .91335 .38635 .91091 .38289 Mtetra
.74 .785 .89 r
.91091 .38289 .91335 .38635 .91964 .38305 .91719 .37949 Mtetra
.735 .779 .888 r
.91719 .37949 .91964 .38305 .92593 .37982 .92349 .37618 Mtetra
.727 .771 .888 r
.92349 .37618 .92593 .37982 .93226 .37671 .92982 .37299 Mtetra
.576 .716 .938 r
.34801 .5506 .35128 .55364 .35651 .55296 .35324 .54997 Mtetra
.545 .709 .947 r
.35324 .54997 .35651 .55296 .36174 .55254 .35847 .54962 Mtetra
.53 .709 .953 r
.35847 .54962 .36174 .55254 .36698 .5522 .36371 .54935 Mtetra
.521 .711 .958 r
.36371 .54935 .36698 .5522 .37223 .5519 .36896 .54913 Mtetra
.514 .715 .963 r
.36896 .54913 .37223 .5519 .37749 .55163 .37423 .54894 Mtetra
.508 .719 .967 r
.37423 .54894 .37749 .55163 .38277 .55136 .37951 .54875 Mtetra
.503 .723 .971 r
.37951 .54875 .38277 .55136 .38807 .55109 .38481 .54856 Mtetra
.498 .728 .975 r
.38481 .54856 .38807 .55109 .39338 .55082 .39012 .54837 Mtetra
.492 .732 .979 r
.39012 .54837 .39338 .55082 .3987 .55055 .39545 .54818 Mtetra
.486 .736 .982 r
.39545 .54818 .3987 .55055 .40404 .55028 .40079 .54798 Mtetra
.479 .741 .985 r
.40079 .54798 .40404 .55028 .4094 .55 .40615 .54779 Mtetra
.472 .744 .988 r
.40615 .54779 .4094 .55 .41477 .54973 .41153 .5476 Mtetra
.464 .748 .991 r
.41153 .5476 .41477 .54973 .42015 .54945 .41692 .5474 Mtetra
.457 .752 .993 r
.41692 .5474 .42015 .54945 .42556 .54918 .42232 .5472 Mtetra
.448 .755 .994 r
.42232 .5472 .42556 .54918 .43097 .5489 .42774 .54701 Mtetra
.438 .758 .995 r
.42774 .54701 .43097 .5489 .4364 .54862 .43318 .54681 Mtetra
.429 .76 .996 r
.43318 .54681 .4364 .54862 .44185 .54834 .43863 .54661 Mtetra
.418 .762 .996 r
.43863 .54661 .44185 .54834 .44731 .54806 .4441 .54641 Mtetra
.407 .764 .995 r
.4441 .54641 .44731 .54806 .45279 .54778 .44959 .54621 Mtetra
.395 .765 .993 r
.44959 .54621 .45279 .54778 .45829 .54749 .45509 .54601 Mtetra
.383 .765 .99 r
.45509 .54601 .45829 .54749 .4638 .54721 .46061 .54581 Mtetra
.369 .765 .986 r
.46061 .54581 .4638 .54721 .46933 .54692 .46614 .54561 Mtetra
.355 .764 .982 r
.46614 .54561 .46933 .54692 .47487 .54664 .47169 .5454 Mtetra
.34 .762 .976 r
.47169 .5454 .47487 .54664 .48043 .54635 .47726 .5452 Mtetra
.325 .759 .969 r
.47726 .5452 .48043 .54635 .486 .54606 .48284 .54499 Mtetra
.308 .755 .96 r
.48284 .54499 .486 .54606 .49159 .54578 .48844 .54479 Mtetra
.291 .751 .951 r
.48844 .54479 .49159 .54578 .4972 .54549 .49406 .54458 Mtetra
.273 .745 .94 r
.49406 .54458 .4972 .54549 .50282 .5452 .49969 .54438 Mtetra
.254 .738 .927 r
.49969 .54438 .50282 .5452 .50846 .54491 .50534 .54417 Mtetra
.235 .731 .913 r
.50534 .54417 .50846 .54491 .51412 .54462 .511 .54396 Mtetra
.216 .722 .898 r
.511 .54396 .51412 .54462 .51979 .54432 .51669 .54376 Mtetra
.195 .712 .882 r
.51669 .54376 .51979 .54432 .52548 .54403 .52239 .54355 Mtetra
.174 .7 .863 r
.52239 .54355 .52548 .54403 .53119 .54374 .5281 .54334 Mtetra
.153 .688 .844 r
.5281 .54334 .53119 .54374 .53691 .54344 .53384 .54313 Mtetra
.132 .675 .823 r
.53384 .54313 .53691 .54344 .54265 .54315 .53959 .54292 Mtetra
.11 .661 .801 r
.53959 .54292 .54265 .54315 .54841 .54285 .54536 .54271 Mtetra
.088 .646 .778 r
.54536 .54271 .54841 .54285 .55418 .54256 .55115 .5425 Mtetra
.067 .63 .755 r
.55115 .5425 .55418 .54256 .55997 .54226 .55695 .54229 Mtetra
.045 .614 .73 r
.55695 .54229 .55997 .54226 .56578 .54196 .56277 .54208 Mtetra
0 0 0 r
.56277 .54208 .56578 .54196 .5716 .54167 .56861 .54187 Mtetra
.56861 .54187 .5716 .54167 .57744 .54137 .57447 .54166 Mtetra
.018 0 0 r
.57447 .54166 .57744 .54137 .5833 .54107 .58034 .54145 Mtetra
.039 0 0 r
.58034 .54145 .5833 .54107 .58918 .54077 .58623 .54124 Mtetra
.06 0 0 r
.58623 .54124 .58918 .54077 .59507 .54047 .59214 .54103 Mtetra
.078 0 0 r
.59214 .54103 .59507 .54047 .60099 .54017 .59807 .54081 Mtetra
.095 0 0 r
.59807 .54081 .60099 .54017 .60692 .53986 .60402 .54059 Mtetra
.11 0 0 r
.60402 .54059 .60692 .53986 .61286 .53953 .60998 .54035 Mtetra
.112 0 0 r
.60998 .54035 .61286 .53953 .61883 .53913 .61596 .54003 Mtetra
.096 0 0 r
.61596 .54003 .61883 .53913 .6248 .53858 .62195 .53956 Mtetra
0 0 0 r
.62195 .53956 .6248 .53858 .63076 .53704 .62793 .53802 Mtetra
.444 .869 .75 r
.62793 .53802 .63076 .53704 .63669 .53402 .63387 .53492 Mtetra
.486 .894 .775 r
.63387 .53492 .63669 .53402 .64262 .53087 .63982 .53168 Mtetra
.519 .912 .795 r
.63982 .53168 .64262 .53087 .64855 .52763 .64576 .52835 Mtetra
.543 .925 .814 r
.64576 .52835 .64855 .52763 .6545 .52436 .65172 .52497 Mtetra
.561 .934 .83 r
.65172 .52497 .6545 .52436 .66044 .52107 .65768 .52159 Mtetra
.578 .942 .845 r
.65768 .52159 .66044 .52107 .6664 .51779 .66365 .51821 Mtetra
.594 .949 .859 r
.66365 .51821 .6664 .51779 .67236 .51449 .66963 .51481 Mtetra
.609 .955 .872 r
.66963 .51481 .67236 .51449 .67833 .51119 .67561 .51142 Mtetra
.623 .96 .884 r
.67561 .51142 .67833 .51119 .68431 .5079 .6816 .50802 Mtetra
.636 .963 .895 r
.6816 .50802 .68431 .5079 .6903 .50459 .6876 .50462 Mtetra
.649 .966 .904 r
.6876 .50462 .6903 .50459 .69629 .50128 .6936 .50121 Mtetra
.66 .967 .913 r
.6936 .50121 .69629 .50128 .70229 .49797 .69961 .4978 Mtetra
.671 .968 .921 r
.69961 .4978 .70229 .49797 .7083 .49466 .70563 .49439 Mtetra
.681 .968 .927 r
.70563 .49439 .7083 .49466 .71432 .49134 .71166 .49097 Mtetra
.69 .967 .933 r
.71166 .49097 .71432 .49134 .72034 .48801 .7177 .48755 Mtetra
.698 .965 .938 r
.7177 .48755 .72034 .48801 .72637 .48469 .72374 .48412 Mtetra
.706 .963 .942 r
.72374 .48412 .72637 .48469 .73241 .48135 .72979 .48069 Mtetra
.713 .96 .945 r
.72979 .48069 .73241 .48135 .73845 .47802 .73584 .47726 Mtetra
.719 .956 .948 r
.73584 .47726 .73845 .47802 .74451 .47468 .74191 .47382 Mtetra
.724 .952 .95 r
.74191 .47382 .74451 .47468 .75057 .47134 .74798 .47038 Mtetra
.729 .948 .951 r
.74798 .47038 .75057 .47134 .75664 .46799 .75405 .46694 Mtetra
.734 .943 .952 r
.75405 .46694 .75664 .46799 .76272 .46464 .76014 .46349 Mtetra
.737 .938 .952 r
.76014 .46349 .76272 .46464 .7688 .46128 .76623 .46003 Mtetra
.741 .932 .951 r
.76623 .46003 .7688 .46128 .77489 .45792 .77233 .45658 Mtetra
.744 .926 .951 r
.77233 .45658 .77489 .45792 .78099 .45456 .77844 .45311 Mtetra
.746 .92 .949 r
.77844 .45311 .78099 .45456 .7871 .45119 .78456 .44965 Mtetra
.749 .914 .948 r
.78456 .44965 .7871 .45119 .79322 .44781 .79068 .44618 Mtetra
.751 .908 .946 r
.79068 .44618 .79322 .44781 .79934 .44444 .79681 .4427 Mtetra
.752 .902 .944 r
.79681 .4427 .79934 .44444 .80547 .44105 .80295 .43922 Mtetra
.753 .895 .942 r
.80295 .43922 .80547 .44105 .81161 .43767 .80909 .43574 Mtetra
.754 .889 .939 r
.80909 .43574 .81161 .43767 .81776 .43428 .81525 .43225 Mtetra
.755 .882 .937 r
.81525 .43225 .81776 .43428 .82391 .43088 .82141 .42876 Mtetra
.755 .875 .934 r
.82141 .42876 .82391 .43088 .83007 .42748 .82757 .42527 Mtetra
.755 .869 .931 r
.82757 .42527 .83007 .42748 .83625 .42408 .83375 .42176 Mtetra
.756 .862 .927 r
.83375 .42176 .83625 .42408 .84242 .42067 .83993 .41826 Mtetra
.755 .856 .924 r
.83993 .41826 .84242 .42067 .84861 .41726 .84612 .41475 Mtetra
.755 .849 .921 r
.84612 .41475 .84861 .41726 .8548 .41384 .85232 .41123 Mtetra
.755 .843 .918 r
.85232 .41123 .8548 .41384 .861 .41041 .85853 .40771 Mtetra
.754 .836 .914 r
.85853 .40771 .861 .41041 .86721 .40699 .86474 .40419 Mtetra
.754 .83 .911 r
.86474 .40419 .86721 .40699 .87343 .40356 .87096 .40066 Mtetra
.753 .824 .907 r
.87096 .40066 .87343 .40356 .87966 .40012 .87719 .39712 Mtetra
.752 .817 .904 r
.87719 .39712 .87966 .40012 .88589 .39667 .88343 .39358 Mtetra
.751 .811 .9 r
.88343 .39358 .88589 .39667 .89213 .39323 .88967 .39004 Mtetra
.75 .805 .897 r
.88967 .39004 .89213 .39323 .89838 .38978 .89592 .3865 Mtetra
.749 .799 .893 r
.89592 .3865 .89838 .38978 .90464 .38633 .90218 .38295 Mtetra
.747 .793 .89 r
.90218 .38295 .90464 .38633 .91091 .38289 .90845 .37941 Mtetra
.744 .787 .888 r
.90845 .37941 .91091 .38289 .91719 .37949 .91473 .37593 Mtetra
.739 .78 .886 r
.91473 .37593 .91719 .37949 .92349 .37618 .92103 .37252 Mtetra
.731 .773 .886 r
.92103 .37252 .92349 .37618 .92982 .37299 .92736 .36925 Mtetra
.57 .714 .939 r
.34472 .54754 .34801 .5506 .35324 .54997 .34996 .54697 Mtetra
.536 .706 .949 r
.34996 .54697 .35324 .54997 .35847 .54962 .35519 .54669 Mtetra
.521 .705 .955 r
.35519 .54669 .35847 .54962 .36371 .54935 .36043 .5465 Mtetra
.511 .707 .96 r
.36043 .5465 .36371 .54935 .36896 .54913 .36569 .54635 Mtetra
.503 .71 .964 r
.36569 .54635 .36896 .54913 .37423 .54894 .37095 .54624 Mtetra
.496 .714 .968 r
.37095 .54624 .37423 .54894 .37951 .54875 .37624 .54613 Mtetra
.492 .719 .972 r
.37624 .54613 .37951 .54875 .38481 .54856 .38154 .54602 Mtetra
.486 .723 .976 r
.38154 .54602 .38481 .54856 .39012 .54837 .38685 .5459 Mtetra
.479 .727 .979 r
.38685 .5459 .39012 .54837 .39545 .54818 .39218 .54579 Mtetra
.473 .731 .983 r
.39218 .54579 .39545 .54818 .40079 .54798 .39753 .54568 Mtetra
.466 .735 .986 r
.39753 .54568 .40079 .54798 .40615 .54779 .40289 .54557 Mtetra
.458 .739 .988 r
.40289 .54557 .40615 .54779 .41153 .5476 .40827 .54545 Mtetra
.45 .742 .991 r
.40827 .54545 .41153 .5476 .41692 .5474 .41367 .54534 Mtetra
.442 .745 .992 r
.41367 .54534 .41692 .5474 .42232 .5472 .41908 .54522 Mtetra
.433 .748 .994 r
.41908 .54522 .42232 .5472 .42774 .54701 .4245 .54511 Mtetra
.423 .751 .994 r
.4245 .54511 .42774 .54701 .43318 .54681 .42994 .54499 Mtetra
.413 .753 .994 r
.42994 .54499 .43318 .54681 .43863 .54661 .4354 .54488 Mtetra
.402 .755 .994 r
.4354 .54488 .43863 .54661 .4441 .54641 .44088 .54476 Mtetra
.39 .756 .992 r
.44088 .54476 .4441 .54641 .44959 .54621 .44637 .54464 Mtetra
.378 .756 .99 r
.44637 .54464 .44959 .54621 .45509 .54601 .45188 .54452 Mtetra
.365 .756 .987 r
.45188 .54452 .45509 .54601 .46061 .54581 .4574 .5444 Mtetra
.351 .755 .983 r
.4574 .5444 .46061 .54581 .46614 .54561 .46294 .54428 Mtetra
.336 .754 .977 r
.46294 .54428 .46614 .54561 .47169 .5454 .4685 .54416 Mtetra
.321 .751 .971 r
.4685 .54416 .47169 .5454 .47726 .5452 .47407 .54404 Mtetra
.305 .748 .963 r
.47407 .54404 .47726 .5452 .48284 .54499 .47966 .54392 Mtetra
.287 .744 .954 r
.47966 .54392 .48284 .54499 .48844 .54479 .48527 .5438 Mtetra
.27 .739 .944 r
.48527 .5438 .48844 .54479 .49406 .54458 .4909 .54368 Mtetra
.252 .733 .932 r
.4909 .54368 .49406 .54458 .49969 .54438 .49654 .54355 Mtetra
.233 .725 .919 r
.49654 .54355 .49969 .54438 .50534 .54417 .5022 .54343 Mtetra
.213 .717 .905 r
.5022 .54343 .50534 .54417 .511 .54396 .50787 .54331 Mtetra
.193 .707 .889 r
.50787 .54331 .511 .54396 .51669 .54376 .51357 .54319 Mtetra
.173 .697 .872 r
.51357 .54319 .51669 .54376 .52239 .54355 .51928 .54306 Mtetra
.152 .685 .853 r
.51928 .54306 .52239 .54355 .5281 .54334 .52501 .54294 Mtetra
.131 .672 .833 r
.52501 .54294 .5281 .54334 .53384 .54313 .53075 .54282 Mtetra
.109 .659 .812 r
.53075 .54282 .53384 .54313 .53959 .54292 .53652 .54269 Mtetra
.087 .644 .789 r
.53652 .54269 .53959 .54292 .54536 .54271 .5423 .54257 Mtetra
.066 .629 .766 r
.5423 .54257 .54536 .54271 .55115 .5425 .54809 .54245 Mtetra
.045 .613 .742 r
.54809 .54245 .55115 .5425 .55695 .54229 .55391 .54232 Mtetra
.023 .596 .717 r
.55391 .54232 .55695 .54229 .56277 .54208 .55975 .5422 Mtetra
0 0 0 r
.55975 .5422 .56277 .54208 .56861 .54187 .5656 .54208 Mtetra
.019 0 0 r
.5656 .54208 .56861 .54187 .57447 .54166 .57147 .54195 Mtetra
.039 0 0 r
.57147 .54195 .57447 .54166 .58034 .54145 .57736 .54183 Mtetra
.06 0 0 r
.57736 .54183 .58034 .54145 .58623 .54124 .58326 .5417 Mtetra
.08 0 0 r
.58326 .5417 .58623 .54124 .59214 .54103 .58919 .54158 Mtetra
.097 0 0 r
.58919 .54158 .59214 .54103 .59807 .54081 .59513 .54146 Mtetra
.114 0 0 r
.59513 .54146 .59807 .54081 .60402 .54059 .6011 .54132 Mtetra
.128 0 0 r
.6011 .54132 .60402 .54059 .60998 .54035 .60708 .54117 Mtetra
.129 0 0 r
.60708 .54117 .60998 .54035 .61596 .54003 .61307 .54094 Mtetra
.111 0 0 r
.61307 .54094 .61596 .54003 .62195 .53956 .61908 .54054 Mtetra
0 0 0 r
.61908 .54054 .62195 .53956 .62793 .53802 .62508 .53902 Mtetra
.458 .876 .755 r
.62508 .53902 .62793 .53802 .63387 .53492 .63103 .53583 Mtetra
.501 .901 .778 r
.63103 .53583 .63387 .53492 .63982 .53168 .63699 .5325 Mtetra
.534 .919 .799 r
.63699 .5325 .63982 .53168 .64576 .52835 .64296 .52906 Mtetra
.557 .931 .816 r
.64296 .52906 .64576 .52835 .65172 .52497 .64892 .52559 Mtetra
.575 .94 .832 r
.64892 .52559 .65172 .52497 .65768 .52159 .6549 .52211 Mtetra
.591 .948 .847 r
.6549 .52211 .65768 .52159 .66365 .51821 .66088 .51863 Mtetra
.607 .954 .86 r
.66088 .51863 .66365 .51821 .66963 .51481 .66687 .51513 Mtetra
.621 .96 .873 r
.66687 .51513 .66963 .51481 .67561 .51142 .67287 .51164 Mtetra
.635 .964 .884 r
.67287 .51164 .67561 .51142 .6816 .50802 .67887 .50814 Mtetra
.648 .967 .895 r
.67887 .50814 .6816 .50802 .6876 .50462 .68488 .50464 Mtetra
.66 .969 .904 r
.68488 .50464 .6876 .50462 .6936 .50121 .6909 .50114 Mtetra
.671 .97 .912 r
.6909 .50114 .6936 .50121 .69961 .4978 .69692 .49763 Mtetra
.681 .971 .92 r
.69692 .49763 .69961 .4978 .70563 .49439 .70295 .49412 Mtetra
.691 .97 .926 r
.70295 .49412 .70563 .49439 .71166 .49097 .70899 .4906 Mtetra
.699 .969 .931 r
.70899 .4906 .71166 .49097 .7177 .48755 .71504 .48708 Mtetra
.707 .967 .936 r
.71504 .48708 .7177 .48755 .72374 .48412 .72109 .48356 Mtetra
.714 .965 .94 r
.72109 .48356 .72374 .48412 .72979 .48069 .72715 .48003 Mtetra
.721 .961 .943 r
.72715 .48003 .72979 .48069 .73584 .47726 .73321 .4765 Mtetra
.727 .958 .945 r
.73321 .4765 .73584 .47726 .74191 .47382 .73929 .47296 Mtetra
.732 .954 .947 r
.73929 .47296 .74191 .47382 .74798 .47038 .74537 .46942 Mtetra
.737 .949 .948 r
.74537 .46942 .74798 .47038 .75405 .46694 .75146 .46588 Mtetra
.741 .944 .949 r
.75146 .46588 .75405 .46694 .76014 .46349 .75755 .46233 Mtetra
.744 .939 .949 r
.75755 .46233 .76014 .46349 .76623 .46003 .76365 .45878 Mtetra
.748 .933 .948 r
.76365 .45878 .76623 .46003 .77233 .45658 .76976 .45523 Mtetra
.75 .927 .948 r
.76976 .45523 .77233 .45658 .77844 .45311 .77588 .45167 Mtetra
.753 .921 .946 r
.77588 .45167 .77844 .45311 .78456 .44965 .782 .4481 Mtetra
.755 .915 .945 r
.782 .4481 .78456 .44965 .79068 .44618 .78813 .44453 Mtetra
.756 .909 .943 r
.78813 .44453 .79068 .44618 .79681 .4427 .79427 .44096 Mtetra
.758 .903 .941 r
.79427 .44096 .79681 .4427 .80295 .43922 .80041 .43739 Mtetra
.759 .896 .939 r
.80041 .43739 .80295 .43922 .80909 .43574 .80656 .43381 Mtetra
.76 .89 .936 r
.80656 .43381 .80909 .43574 .81525 .43225 .81272 .43022 Mtetra
.76 .883 .934 r
.81272 .43022 .81525 .43225 .82141 .42876 .81889 .42663 Mtetra
.76 .876 .931 r
.81889 .42663 .82141 .42876 .82757 .42527 .82506 .42304 Mtetra
.761 .87 .928 r
.82506 .42304 .82757 .42527 .83375 .42176 .83124 .41944 Mtetra
.761 .863 .925 r
.83124 .41944 .83375 .42176 .83993 .41826 .83743 .41583 Mtetra
.76 .857 .922 r
.83743 .41583 .83993 .41826 .84612 .41475 .84363 .41223 Mtetra
.76 .85 .918 r
.84363 .41223 .84612 .41475 .85232 .41123 .84983 .40861 Mtetra
.76 .844 .915 r
.84983 .40861 .85232 .41123 .85853 .40771 .85604 .405 Mtetra
.759 .837 .912 r
.85604 .405 .85853 .40771 .86474 .40419 .86226 .40137 Mtetra
.758 .831 .908 r
.86226 .40137 .86474 .40419 .87096 .40066 .86848 .39775 Mtetra
.757 .825 .905 r
.86848 .39775 .87096 .40066 .87719 .39712 .87471 .39412 Mtetra
.757 .819 .901 r
.87471 .39412 .87719 .39712 .88343 .39358 .88095 .39048 Mtetra
.756 .813 .898 r
.88095 .39048 .88343 .39358 .88967 .39004 .8872 .38684 Mtetra
.754 .807 .894 r
.8872 .38684 .88967 .39004 .89592 .3865 .89345 .3832 Mtetra
.753 .801 .891 r
.89345 .3832 .89592 .3865 .90218 .38295 .89971 .37955 Mtetra
.751 .794 .888 r
.89971 .37955 .90218 .38295 .90845 .37941 .90598 .37592 Mtetra
.748 .788 .886 r
.90598 .37592 .90845 .37941 .91473 .37593 .91227 .37234 Mtetra
.742 .781 .884 r
.91227 .37234 .91473 .37593 .92103 .37252 .91857 .36885 Mtetra
.734 .774 .885 r
.91857 .36885 .92103 .37252 .92736 .36925 .9249 .3655 Mtetra
.563 .711 .941 r
.34143 .54448 .34472 .54754 .34996 .54697 .34666 .54396 Mtetra
.527 .702 .95 r
.34666 .54396 .34996 .54697 .35519 .54669 .3519 .54374 Mtetra
.511 .701 .956 r
.3519 .54374 .35519 .54669 .36043 .5465 .35714 .54363 Mtetra
.5 .703 .961 r
.35714 .54363 .36043 .5465 .36569 .54635 .3624 .54356 Mtetra
.491 .706 .965 r
.3624 .54356 .36569 .54635 .37095 .54624 .36767 .54352 Mtetra
.485 .709 .969 r
.36767 .54352 .37095 .54624 .37624 .54613 .37295 .5435 Mtetra
.479 .714 .973 r
.37295 .5435 .37624 .54613 .38154 .54602 .37825 .54346 Mtetra
.473 .718 .977 r
.37825 .54346 .38154 .54602 .38685 .5459 .38357 .54343 Mtetra
.466 .721 .98 r
.38357 .54343 .38685 .5459 .39218 .54579 .38891 .5434 Mtetra
.459 .725 .983 r
.38891 .5434 .39218 .54579 .39753 .54568 .39425 .54337 Mtetra
.452 .729 .986 r
.39425 .54337 .39753 .54568 .40289 .54557 .39962 .54333 Mtetra
.444 .732 .988 r
.39962 .54333 .40289 .54557 .40827 .54545 .405 .5433 Mtetra
.436 .736 .99 r
.405 .5433 .40827 .54545 .41367 .54534 .4104 .54327 Mtetra
.427 .739 .992 r
.4104 .54327 .41367 .54534 .41908 .54522 .41581 .54323 Mtetra
.417 .741 .993 r
.41581 .54323 .41908 .54522 .4245 .54511 .42125 .5432 Mtetra
.407 .743 .993 r
.42125 .5432 .4245 .54511 .42994 .54499 .42669 .54317 Mtetra
.397 .745 .993 r
.42669 .54317 .42994 .54499 .4354 .54488 .43216 .54313 Mtetra
.385 .746 .992 r
.43216 .54313 .4354 .54488 .44088 .54476 .43764 .54309 Mtetra
.373 .747 .99 r
.43764 .54309 .44088 .54476 .44637 .54464 .44313 .54306 Mtetra
.36 .747 .987 r
.44313 .54306 .44637 .54464 .45188 .54452 .44865 .54302 Mtetra
.347 .747 .984 r
.44865 .54302 .45188 .54452 .4574 .5444 .45418 .54298 Mtetra
.332 .745 .979 r
.45418 .54298 .4574 .5444 .46294 .54428 .45973 .54295 Mtetra
.317 .743 .973 r
.45973 .54295 .46294 .54428 .4685 .54416 .46529 .54291 Mtetra
.301 .74 .966 r
.46529 .54291 .4685 .54416 .47407 .54404 .47087 .54287 Mtetra
.285 .737 .958 r
.47087 .54287 .47407 .54404 .47966 .54392 .47647 .54283 Mtetra
.267 .732 .948 r
.47647 .54283 .47966 .54392 .48527 .5438 .48209 .5428 Mtetra
.249 .726 .937 r
.48209 .5428 .48527 .5438 .4909 .54368 .48772 .54276 Mtetra
.231 .72 .925 r
.48772 .54276 .4909 .54368 .49654 .54355 .49337 .54272 Mtetra
.212 .712 .911 r
.49337 .54272 .49654 .54355 .5022 .54343 .49904 .54268 Mtetra
.192 .703 .896 r
.49904 .54268 .5022 .54343 .50787 .54331 .50473 .54265 Mtetra
.172 .693 .88 r
.50473 .54265 .50787 .54331 .51357 .54319 .51043 .54261 Mtetra
.151 .682 .862 r
.51043 .54261 .51357 .54319 .51928 .54306 .51615 .54257 Mtetra
.13 .67 .842 r
.51615 .54257 .51928 .54306 .52501 .54294 .52189 .54253 Mtetra
.109 .657 .822 r
.52189 .54253 .52501 .54294 .53075 .54282 .52765 .5425 Mtetra
.088 .643 .801 r
.52765 .5425 .53075 .54282 .53652 .54269 .53342 .54246 Mtetra
.066 .628 .778 r
.53342 .54246 .53652 .54269 .5423 .54257 .53922 .54242 Mtetra
.044 .612 .754 r
.53922 .54242 .5423 .54257 .54809 .54245 .54503 .54239 Mtetra
.024 .596 .73 r
.54503 .54239 .54809 .54245 .55391 .54232 .55086 .54235 Mtetra
0 0 0 r
.55086 .54235 .55391 .54232 .55975 .5422 .5567 .54231 Mtetra
.019 0 0 r
.5567 .54231 .55975 .5422 .5656 .54208 .56257 .54228 Mtetra
.039 0 0 r
.56257 .54228 .5656 .54208 .57147 .54195 .56845 .54224 Mtetra
.059 0 0 r
.56845 .54224 .57147 .54195 .57736 .54183 .57436 .54221 Mtetra
.079 0 0 r
.57436 .54221 .57736 .54183 .58326 .5417 .58028 .54217 Mtetra
.098 0 0 r
.58028 .54217 .58326 .5417 .58919 .54158 .58622 .54214 Mtetra
.115 0 0 r
.58622 .54214 .58919 .54158 .59513 .54146 .59218 .5421 Mtetra
.132 0 0 r
.59218 .5421 .59513 .54146 .6011 .54132 .59816 .54206 Mtetra
.145 0 0 r
.59816 .54206 .6011 .54132 .60708 .54117 .60415 .54199 Mtetra
.60415 .54199 .60708 .54117 .61307 .54094 .61017 .54185 Mtetra
.125 0 0 r
.61017 .54185 .61307 .54094 .61908 .54054 .61619 .54152 Mtetra
0 0 0 r
.61619 .54152 .61908 .54054 .62508 .53902 .62221 .54001 Mtetra
.473 .885 .76 r
.62221 .54001 .62508 .53902 .63103 .53583 .62818 .53674 Mtetra
.516 .909 .783 r
.62818 .53674 .63103 .53583 .63699 .5325 .63415 .53331 Mtetra
.549 .926 .803 r
.63415 .53331 .63699 .5325 .64296 .52906 .64013 .52978 Mtetra
.572 .938 .82 r
.64013 .52978 .64296 .52906 .64892 .52559 .64611 .52621 Mtetra
.589 .946 .835 r
.64611 .52621 .64892 .52559 .6549 .52211 .6521 .52263 Mtetra
.605 .953 .849 r
.6521 .52263 .6549 .52211 .66088 .51863 .6581 .51905 Mtetra
.62 .959 .862 r
.6581 .51905 .66088 .51863 .66687 .51513 .6641 .51545 Mtetra
.634 .964 .874 r
.6641 .51545 .66687 .51513 .67287 .51164 .67011 .51186 Mtetra
.647 .968 .885 r
.67011 .51186 .67287 .51164 .67887 .50814 .67613 .50826 Mtetra
.659 .97 .895 r
.67613 .50826 .67887 .50814 .68488 .50464 .68215 .50466 Mtetra
.671 .972 .903 r
.68215 .50466 .68488 .50464 .6909 .50114 .68818 .50106 Mtetra
.681 .973 .911 r
.68818 .50106 .6909 .50114 .69692 .49763 .69421 .49745 Mtetra
.691 .973 .918 r
.69421 .49745 .69692 .49763 .70295 .49412 .70026 .49384 Mtetra
.7 .973 .924 r
.70026 .49384 .70295 .49412 .70899 .4906 .70631 .49022 Mtetra
.709 .971 .93 r
.70631 .49022 .70899 .4906 .71504 .48708 .71236 .4866 Mtetra
.716 .969 .934 r
.71236 .4866 .71504 .48708 .72109 .48356 .71843 .48298 Mtetra
.723 .966 .938 r
.71843 .48298 .72109 .48356 .72715 .48003 .7245 .47936 Mtetra
.729 .963 .94 r
.7245 .47936 .72715 .48003 .73321 .4765 .73057 .47573 Mtetra
.735 .959 .943 r
.73057 .47573 .73321 .4765 .73929 .47296 .73665 .47209 Mtetra
.74 .955 .944 r
.73665 .47209 .73929 .47296 .74537 .46942 .74275 .46846 Mtetra
.744 .95 .945 r
.74275 .46846 .74537 .46942 .75146 .46588 .74884 .46481 Mtetra
.748 .945 .946 r
.74884 .46481 .75146 .46588 .75755 .46233 .75495 .46117 Mtetra
.751 .94 .946 r
.75495 .46117 .75755 .46233 .76365 .45878 .76106 .45752 Mtetra
.754 .934 .945 r
.76106 .45752 .76365 .45878 .76976 .45523 .76717 .45386 Mtetra
.757 .928 .944 r
.76717 .45386 .76976 .45523 .77588 .45167 .7733 .45021 Mtetra
.759 .922 .943 r
.7733 .45021 .77588 .45167 .782 .4481 .77943 .44655 Mtetra
.761 .916 .942 r
.77943 .44655 .782 .4481 .78813 .44453 .78557 .44288 Mtetra
.762 .91 .94 r
.78557 .44288 .78813 .44453 .79427 .44096 .79171 .43921 Mtetra
.763 .903 .938 r
.79171 .43921 .79427 .44096 .80041 .43739 .79786 .43553 Mtetra
.764 .897 .936 r
.79786 .43553 .80041 .43739 .80656 .43381 .80402 .43186 Mtetra
.765 .89 .933 r
.80402 .43186 .80656 .43381 .81272 .43022 .81019 .42817 Mtetra
.765 .884 .931 r
.81019 .42817 .81272 .43022 .81889 .42663 .81636 .42448 Mtetra
.765 .877 .928 r
.81636 .42448 .81889 .42663 .82506 .42304 .82254 .42079 Mtetra
.766 .871 .925 r
.82254 .42079 .82506 .42304 .83124 .41944 .82872 .4171 Mtetra
.765 .864 .922 r
.82872 .4171 .83124 .41944 .83743 .41583 .83492 .4134 Mtetra
.765 .858 .919 r
.83492 .4134 .83743 .41583 .84363 .41223 .84112 .40969 Mtetra
.765 .851 .916 r
.84112 .40969 .84363 .41223 .84983 .40861 .84732 .40598 Mtetra
.764 .845 .912 r
.84732 .40598 .84983 .40861 .85604 .405 .85354 .40227 Mtetra
.763 .838 .909 r
.85354 .40227 .85604 .405 .86226 .40137 .85976 .39855 Mtetra
.763 .832 .906 r
.85976 .39855 .86226 .40137 .86848 .39775 .86599 .39483 Mtetra
.762 .826 .902 r
.86599 .39483 .86848 .39775 .87471 .39412 .87222 .3911 Mtetra
.761 .82 .899 r
.87222 .3911 .87471 .39412 .88095 .39048 .87846 .38736 Mtetra
.76 .814 .895 r
.87846 .38736 .88095 .39048 .8872 .38684 .88471 .38363 Mtetra
.759 .808 .892 r
.88471 .38363 .8872 .38684 .89345 .3832 .89097 .37989 Mtetra
.757 .802 .889 r
.89097 .37989 .89345 .3832 .89971 .37955 .89723 .37614 Mtetra
.755 .796 .886 r
.89723 .37614 .89971 .37955 .90598 .37592 .9035 .37242 Mtetra
.751 .789 .884 r
.9035 .37242 .90598 .37592 .91227 .37234 .90979 .36875 Mtetra
.746 .782 .883 r
.90979 .36875 .91227 .37234 .91857 .36885 .9161 .36516 Mtetra
.737 .775 .883 r
.9161 .36516 .91857 .36885 .9249 .3655 .92243 .36174 Mtetra
.557 .709 .942 r
.33812 .5414 .34143 .54448 .34666 .54396 .34336 .54094 Mtetra
.518 .699 .952 r
.34336 .54094 .34666 .54396 .3519 .54374 .34859 .54079 Mtetra
.5 .697 .957 r
.34859 .54079 .3519 .54374 .35714 .54363 .35384 .54075 Mtetra
.488 .698 .962 r
.35384 .54075 .35714 .54363 .3624 .54356 .35909 .54076 Mtetra
.479 .701 .966 r
.35909 .54076 .3624 .54356 .36767 .54352 .36437 .5408 Mtetra
.472 .704 .97 r
.36437 .5408 .36767 .54352 .37295 .5435 .36965 .54085 Mtetra
.467 .708 .974 r
.36965 .54085 .37295 .5435 .37825 .54346 .37496 .5409 Mtetra
.46 .712 .977 r
.37496 .5409 .37825 .54346 .38357 .54343 .38028 .54095 Mtetra
.453 .716 .98 r
.38028 .54095 .38357 .54343 .38891 .5434 .38561 .541 Mtetra
.446 .72 .983 r
.38561 .541 .38891 .5434 .39425 .54337 .39096 .54105 Mtetra
.438 .723 .986 r
.39096 .54105 .39425 .54337 .39962 .54333 .39633 .54109 Mtetra
.429 .726 .988 r
.39633 .54109 .39962 .54333 .405 .5433 .40172 .54114 Mtetra
.421 .729 .99 r
.40172 .54114 .405 .5433 .4104 .54327 .40712 .54119 Mtetra
.412 .732 .991 r
.40712 .54119 .4104 .54327 .41581 .54323 .41254 .54124 Mtetra
.401 .734 .991 r
.41254 .54124 .41581 .54323 .42125 .5432 .41797 .54128 Mtetra
.39 .735 .991 r
.41797 .54128 .42125 .5432 .42669 .54317 .42343 .54133 Mtetra
.38 .737 .991 r
.42343 .54133 .42669 .54317 .43216 .54313 .4289 .54138 Mtetra
.368 .738 .989 r
.4289 .54138 .43216 .54313 .43764 .54309 .43438 .54142 Mtetra
.355 .738 .987 r
.43438 .54142 .43764 .54309 .44313 .54306 .43988 .54147 Mtetra
.341 .738 .984 r
.43988 .54147 .44313 .54306 .44865 .54302 .4454 .54152 Mtetra
.328 .737 .979 r
.4454 .54152 .44865 .54302 .45418 .54298 .45094 .54156 Mtetra
.313 .735 .974 r
.45094 .54156 .45418 .54298 .45973 .54295 .4565 .54161 Mtetra
.297 .732 .968 r
.4565 .54161 .45973 .54295 .46529 .54291 .46207 .54166 Mtetra
.281 .729 .96 r
.46207 .54166 .46529 .54291 .47087 .54287 .46766 .5417 Mtetra
.264 .725 .951 r
.46766 .5417 .47087 .54287 .47647 .54283 .47326 .54175 Mtetra
.246 .719 .941 r
.47326 .54175 .47647 .54283 .48209 .5428 .47889 .54179 Mtetra
.228 .713 .929 r
.47889 .54179 .48209 .5428 .48772 .54276 .48453 .54184 Mtetra
.209 .706 .916 r
.48453 .54184 .48772 .54276 .49337 .54272 .49019 .54189 Mtetra
.19 .697 .902 r
.49019 .54189 .49337 .54272 .49904 .54268 .49587 .54193 Mtetra
.169 .688 .886 r
.49587 .54193 .49904 .54268 .50473 .54265 .50156 .54198 Mtetra
.149 .677 .869 r
.50156 .54198 .50473 .54265 .51043 .54261 .50728 .54203 Mtetra
.129 .666 .851 r
.50728 .54203 .51043 .54261 .51615 .54257 .51301 .54208 Mtetra
.107 .653 .831 r
.51301 .54208 .51615 .54257 .52189 .54253 .51876 .54213 Mtetra
.086 .64 .81 r
.51876 .54213 .52189 .54253 .52765 .5425 .52453 .54218 Mtetra
.065 .626 .788 r
.52453 .54218 .52765 .5425 .53342 .54246 .53031 .54223 Mtetra
.043 .611 .765 r
.53031 .54223 .53342 .54246 .53922 .54242 .53612 .54228 Mtetra
.022 .595 .741 r
.53612 .54228 .53922 .54242 .54503 .54239 .54194 .54233 Mtetra
.002 .579 .716 r
.54194 .54233 .54503 .54239 .55086 .54235 .54778 .54238 Mtetra
.019 0 0 r
.54778 .54238 .55086 .54235 .5567 .54231 .55364 .54243 Mtetra
.04 0 0 r
.55364 .54243 .5567 .54231 .56257 .54228 .55952 .54248 Mtetra
.06 0 0 r
.55952 .54248 .56257 .54228 .56845 .54224 .56542 .54254 Mtetra
.079 0 0 r
.56542 .54254 .56845 .54224 .57436 .54221 .57134 .54259 Mtetra
.099 0 0 r
.57134 .54259 .57436 .54221 .58028 .54217 .57727 .54265 Mtetra
.118 0 0 r
.57727 .54265 .58028 .54217 .58622 .54214 .58323 .5427 Mtetra
.134 0 0 r
.58323 .5427 .58622 .54214 .59218 .5421 .58921 .54275 Mtetra
.15 0 0 r
.58921 .54275 .59218 .5421 .59816 .54206 .5952 .5428 Mtetra
.163 0 0 r
.5952 .5428 .59816 .54206 .60415 .54199 .60121 .54282 Mtetra
.162 0 0 r
.60121 .54282 .60415 .54199 .61017 .54185 .60724 .54276 Mtetra
.14 0 0 r
.60724 .54276 .61017 .54185 .61619 .54152 .61329 .54251 Mtetra
0 0 0 r
.61329 .54251 .61619 .54152 .62221 .54001 .61932 .54101 Mtetra
.486 .891 .763 r
.61932 .54101 .62221 .54001 .62818 .53674 .6253 .53766 Mtetra
.53 .916 .786 r
.6253 .53766 .62818 .53674 .63415 .53331 .63129 .53414 Mtetra
.563 .932 .805 r
.63129 .53414 .63415 .53331 .64013 .52978 .63728 .53051 Mtetra
.586 .944 .821 r
.63728 .53051 .64013 .52978 .64611 .52621 .64328 .52684 Mtetra
.602 .951 .836 r
.64328 .52684 .64611 .52621 .6521 .52263 .64929 .52316 Mtetra
.617 .958 .85 r
.64929 .52316 .6521 .52263 .6581 .51905 .6553 .51947 Mtetra
.632 .964 .862 r
.6553 .51947 .6581 .51905 .6641 .51545 .66131 .51578 Mtetra
.646 .968 .874 r
.66131 .51578 .6641 .51545 .67011 .51186 .66733 .51208 Mtetra
.658 .971 .884 r
.66733 .51208 .67011 .51186 .67613 .50826 .67336 .50839 Mtetra
.67 .974 .894 r
.67336 .50839 .67613 .50826 .68215 .50466 .6794 .50469 Mtetra
.681 .975 .902 r
.6794 .50469 .68215 .50466 .68818 .50106 .68544 .50098 Mtetra
.691 .976 .91 r
.68544 .50098 .68818 .50106 .69421 .49745 .69149 .49727 Mtetra
.701 .975 .917 r
.69149 .49727 .69421 .49745 .70026 .49384 .69754 .49356 Mtetra
.709 .975 .922 r
.69754 .49356 .70026 .49384 .70631 .49022 .7036 .48985 Mtetra
.717 .973 .927 r
.7036 .48985 .70631 .49022 .71236 .4866 .70967 .48613 Mtetra
.724 .97 .932 r
.70967 .48613 .71236 .4866 .71843 .48298 .71575 .48241 Mtetra
.731 .968 .935 r
.71575 .48241 .71843 .48298 .7245 .47936 .72183 .47868 Mtetra
.737 .964 .938 r
.72183 .47868 .7245 .47936 .73057 .47573 .72791 .47495 Mtetra
.742 .96 .94 r
.72791 .47495 .73057 .47573 .73665 .47209 .73401 .47122 Mtetra
.747 .956 .941 r
.73401 .47122 .73665 .47209 .74275 .46846 .74011 .46748 Mtetra
.751 .951 .942 r
.74011 .46748 .74275 .46846 .74884 .46481 .74621 .46374 Mtetra
.755 .946 .943 r
.74621 .46374 .74884 .46481 .75495 .46117 .75233 .46 Mtetra
.758 .941 .943 r
.75233 .46 .75495 .46117 .76106 .45752 .75845 .45625 Mtetra
.761 .935 .942 r
.75845 .45625 .76106 .45752 .76717 .45386 .76457 .4525 Mtetra
.763 .929 .941 r
.76457 .4525 .76717 .45386 .7733 .45021 .7707 .44874 Mtetra
.765 .923 .94 r
.7707 .44874 .7733 .45021 .77943 .44655 .77684 .44498 Mtetra
.766 .917 .939 r
.77684 .44498 .77943 .44655 .78557 .44288 .78299 .44122 Mtetra
.768 .911 .937 r
.78299 .44122 .78557 .44288 .79171 .43921 .78914 .43745 Mtetra
.769 .904 .935 r
.78914 .43745 .79171 .43921 .79786 .43553 .7953 .43367 Mtetra
.769 .898 .933 r
.7953 .43367 .79786 .43553 .80402 .43186 .80147 .4299 Mtetra
.77 .891 .93 r
.80147 .4299 .80402 .43186 .81019 .42817 .80764 .42612 Mtetra
.77 .885 .928 r
.80764 .42612 .81019 .42817 .81636 .42448 .81382 .42233 Mtetra
.77 .878 .925 r
.81382 .42233 .81636 .42448 .82254 .42079 .82 .41854 Mtetra
.77 .872 .922 r
.82 .41854 .82254 .42079 .82872 .4171 .82619 .41475 Mtetra
.77 .865 .919 r
.82619 .41475 .82872 .4171 .83492 .4134 .83239 .41095 Mtetra
.77 .859 .916 r
.83239 .41095 .83492 .4134 .84112 .40969 .8386 .40715 Mtetra
.769 .852 .913 r
.8386 .40715 .84112 .40969 .84732 .40598 .84481 .40334 Mtetra
.769 .846 .91 r
.84481 .40334 .84732 .40598 .85354 .40227 .85103 .39953 Mtetra
.768 .839 .906 r
.85103 .39953 .85354 .40227 .85976 .39855 .85725 .39571 Mtetra
.767 .833 .903 r
.85725 .39571 .85976 .39855 .86599 .39483 .86348 .39189 Mtetra
.766 .827 .9 r
.86348 .39189 .86599 .39483 .87222 .3911 .86972 .38806 Mtetra
.765 .821 .896 r
.86972 .38806 .87222 .3911 .87846 .38736 .87596 .38423 Mtetra
.764 .815 .893 r
.87596 .38423 .87846 .38736 .88471 .38363 .88222 .3804 Mtetra
.763 .809 .89 r
.88222 .3804 .88471 .38363 .89097 .37989 .88847 .37656 Mtetra
.761 .803 .886 r
.88847 .37656 .89097 .37989 .89723 .37614 .89474 .37272 Mtetra
.759 .797 .884 r
.89474 .37272 .89723 .37614 .9035 .37242 .90101 .3689 Mtetra
.755 .79 .882 r
.90101 .3689 .9035 .37242 .90979 .36875 .9073 .36513 Mtetra
.749 .784 .881 r
.9073 .36513 .90979 .36875 .9161 .36516 .91361 .36146 Mtetra
.741 .776 .882 r
.91361 .36146 .9161 .36516 .92243 .36174 .91995 .35796 Mtetra
.551 .707 .943 r
.3348 .53831 .33812 .5414 .34336 .54094 .34004 .53791 Mtetra
.509 .695 .953 r
.34004 .53791 .34336 .54094 .34859 .54079 .34528 .53782 Mtetra
.489 .693 .958 r
.34528 .53782 .34859 .54079 .35384 .54075 .35052 .53786 Mtetra
.477 .694 .963 r
.35052 .53786 .35384 .54075 .35909 .54076 .35578 .53795 Mtetra
.467 .696 .967 r
.35578 .53795 .35909 .54076 .36437 .5408 .36105 .53807 Mtetra
.46 .699 .971 r
.36105 .53807 .36437 .5408 .36965 .54085 .36634 .5382 Mtetra
.454 .703 .974 r
.36634 .5382 .36965 .54085 .37496 .5409 .37165 .53833 Mtetra
.447 .707 .977 r
.37165 .53833 .37496 .5409 .38028 .54095 .37697 .53845 Mtetra
.439 .71 .98 r
.37697 .53845 .38028 .54095 .38561 .541 .38231 .53859 Mtetra
.431 .713 .983 r
.38231 .53859 .38561 .541 .39096 .54105 .38766 .53871 Mtetra
.423 .717 .985 r
.38766 .53871 .39096 .54105 .39633 .54109 .39303 .53884 Mtetra
.414 .719 .987 r
.39303 .53884 .39633 .54109 .40172 .54114 .39842 .53897 Mtetra
.405 .722 .989 r
.39842 .53897 .40172 .54114 .40712 .54119 .40383 .5391 Mtetra
.396 .724 .989 r
.40383 .5391 .40712 .54119 .41254 .54124 .40925 .53923 Mtetra
.385 .726 .99 r
.40925 .53923 .41254 .54124 .41797 .54128 .41469 .53936 Mtetra
.373 .727 .989 r
.41469 .53936 .41797 .54128 .42343 .54133 .42015 .53949 Mtetra
.362 .728 .988 r
.42015 .53949 .42343 .54133 .4289 .54138 .42562 .53962 Mtetra
.35 .729 .986 r
.42562 .53962 .4289 .54138 .43438 .54142 .43111 .53975 Mtetra
.336 .728 .983 r
.43111 .53975 .43438 .54142 .43988 .54147 .43662 .53988 Mtetra
.322 .728 .979 r
.43662 .53988 .43988 .54147 .4454 .54152 .44214 .54001 Mtetra
.308 .726 .975 r
.44214 .54001 .4454 .54152 .45094 .54156 .44769 .54013 Mtetra
.293 .724 .969 r
.44769 .54013 .45094 .54156 .4565 .54161 .45325 .54026 Mtetra
.276 .721 .962 r
.45325 .54026 .4565 .54161 .46207 .54166 .45883 .5404 Mtetra
.26 .717 .953 r
.45883 .5404 .46207 .54166 .46766 .5417 .46442 .54053 Mtetra
.243 .712 .944 r
.46442 .54053 .46766 .5417 .47326 .54175 .47004 .54065 Mtetra
.224 .706 .933 r
.47004 .54065 .47326 .54175 .47889 .54179 .47567 .54079 Mtetra
.206 .699 .92 r
.47567 .54079 .47889 .54179 .48453 .54184 .48132 .54092 Mtetra
.187 .691 .907 r
.48132 .54092 .48453 .54184 .49019 .54189 .48699 .54105 Mtetra
.167 .682 .892 r
.48699 .54105 .49019 .54189 .49587 .54193 .49268 .54118 Mtetra
.146 .672 .875 r
.49268 .54118 .49587 .54193 .50156 .54198 .49838 .54132 Mtetra
.126 .661 .858 r
.49838 .54132 .50156 .54198 .50728 .54203 .50411 .54145 Mtetra
.106 .65 .839 r
.50411 .54145 .50728 .54203 .51301 .54208 .50985 .54158 Mtetra
.084 .636 .818 r
.50985 .54158 .51301 .54208 .51876 .54213 .51561 .54172 Mtetra
.063 .623 .797 r
.51561 .54172 .51876 .54213 .52453 .54218 .52139 .54186 Mtetra
.042 .608 .775 r
.52139 .54186 .52453 .54218 .53031 .54223 .52718 .54199 Mtetra
.021 .593 .751 r
.52718 .54199 .53031 .54223 .53612 .54228 .533 .54213 Mtetra
0 .576 .727 r
.533 .54213 .53612 .54228 .54194 .54233 .53884 .54227 Mtetra
.021 0 0 r
.53884 .54227 .54194 .54233 .54778 .54238 .54469 .54241 Mtetra
.041 0 0 r
.54469 .54241 .54778 .54238 .55364 .54243 .55056 .54255 Mtetra
.062 0 0 r
.55056 .54255 .55364 .54243 .55952 .54248 .55646 .54269 Mtetra
.081 0 0 r
.55646 .54269 .55952 .54248 .56542 .54254 .56237 .54284 Mtetra
.1 0 0 r
.56237 .54284 .56542 .54254 .57134 .54259 .5683 .54298 Mtetra
.119 0 0 r
.5683 .54298 .57134 .54259 .57727 .54265 .57425 .54312 Mtetra
.138 0 0 r
.57425 .54312 .57727 .54265 .58323 .5427 .58022 .54327 Mtetra
.153 0 0 r
.58022 .54327 .58323 .5427 .58921 .54275 .58621 .54341 Mtetra
.169 0 0 r
.58621 .54341 .58921 .54275 .5952 .5428 .59222 .54355 Mtetra
.181 0 0 r
.59222 .54355 .5952 .5428 .60121 .54282 .59825 .54366 Mtetra
.179 0 0 r
.59825 .54366 .60121 .54282 .60724 .54276 .6043 .54369 Mtetra
.155 0 0 r
.6043 .54369 .60724 .54276 .61329 .54251 .61036 .54351 Mtetra
0 0 0 r
.61036 .54351 .61329 .54251 .61932 .54101 .61641 .54202 Mtetra
.498 .898 .766 r
.61641 .54202 .61932 .54101 .6253 .53766 .62241 .53858 Mtetra
.543 .922 .788 r
.62241 .53858 .6253 .53766 .63129 .53414 .62841 .53497 Mtetra
.576 .938 .807 r
.62841 .53497 .63129 .53414 .63728 .53051 .63442 .53124 Mtetra
.598 .949 .823 r
.63442 .53124 .63728 .53051 .64328 .52684 .64043 .52747 Mtetra
.614 .956 .837 r
.64043 .52747 .64328 .52684 .64929 .52316 .64645 .52369 Mtetra
.629 .962 .85 r
.64645 .52369 .64929 .52316 .6553 .51947 .65248 .5199 Mtetra
.644 .967 .862 r
.65248 .5199 .6553 .51947 .66131 .51578 .65851 .51611 Mtetra
.657 .971 .874 r
.65851 .51611 .66131 .51578 .66733 .51208 .66454 .51231 Mtetra
.669 .974 .884 r
.66454 .51231 .66733 .51208 .67336 .50839 .67058 .50851 Mtetra
.68 .976 .893 r
.67058 .50851 .67336 .50839 .6794 .50469 .67663 .50471 Mtetra
.691 .978 .901 r
.67663 .50471 .6794 .50469 .68544 .50098 .68269 .50091 Mtetra
.701 .978 .908 r
.68269 .50091 .68544 .50098 .69149 .49727 .68875 .4971 Mtetra
.71 .977 .915 r
.68875 .4971 .69149 .49727 .69754 .49356 .69482 .49329 Mtetra
.718 .976 .92 r
.69482 .49329 .69754 .49356 .7036 .48985 .70089 .48947 Mtetra
.726 .974 .925 r
.70089 .48947 .7036 .48985 .70967 .48613 .70697 .48565 Mtetra
.732 .972 .929 r
.70697 .48565 .70967 .48613 .71575 .48241 .71305 .48183 Mtetra
.739 .969 .932 r
.71305 .48183 .71575 .48241 .72183 .47868 .71914 .47801 Mtetra
.744 .965 .935 r
.71914 .47801 .72183 .47868 .72791 .47495 .72524 .47418 Mtetra
.749 .961 .937 r
.72524 .47418 .72791 .47495 .73401 .47122 .73135 .47034 Mtetra
.754 .957 .938 r
.73135 .47034 .73401 .47122 .74011 .46748 .73746 .46651 Mtetra
.758 .952 .939 r
.73746 .46651 .74011 .46748 .74621 .46374 .74357 .46267 Mtetra
.761 .947 .94 r
.74357 .46267 .74621 .46374 .75233 .46 .74969 .45882 Mtetra
.764 .941 .94 r
.74969 .45882 .75233 .46 .75845 .45625 .75582 .45498 Mtetra
.767 .936 .939 r
.75582 .45498 .75845 .45625 .76457 .4525 .76196 .45112 Mtetra
.769 .93 .938 r
.76196 .45112 .76457 .4525 .7707 .44874 .7681 .44727 Mtetra
.77 .924 .937 r
.7681 .44727 .7707 .44874 .77684 .44498 .77425 .44341 Mtetra
.772 .918 .936 r
.77425 .44341 .77684 .44498 .78299 .44122 .7804 .43955 Mtetra
.773 .911 .934 r
.7804 .43955 .78299 .44122 .78914 .43745 .78656 .43568 Mtetra
.774 .905 .932 r
.78656 .43568 .78914 .43745 .7953 .43367 .79273 .43181 Mtetra
.775 .898 .93 r
.79273 .43181 .7953 .43367 .80147 .4299 .7989 .42793 Mtetra
.775 .892 .927 r
.7989 .42793 .80147 .4299 .80764 .42612 .80508 .42405 Mtetra
.775 .885 .925 r
.80508 .42405 .80764 .42612 .81382 .42233 .81126 .42017 Mtetra
.775 .879 .922 r
.81126 .42017 .81382 .42233 .82 .41854 .81745 .41628 Mtetra
.775 .872 .919 r
.81745 .41628 .82 .41854 .82619 .41475 .82365 .41239 Mtetra
.775 .866 .916 r
.82365 .41239 .82619 .41475 .83239 .41095 .82985 .40849 Mtetra
.774 .859 .913 r
.82985 .40849 .83239 .41095 .8386 .40715 .83606 .40459 Mtetra
.774 .853 .91 r
.83606 .40459 .8386 .40715 .84481 .40334 .84228 .40068 Mtetra
.773 .847 .907 r
.84228 .40068 .84481 .40334 .85103 .39953 .8485 .39677 Mtetra
.772 .84 .904 r
.8485 .39677 .85103 .39953 .85725 .39571 .85473 .39286 Mtetra
.771 .834 .901 r
.85473 .39286 .85725 .39571 .86348 .39189 .86097 .38894 Mtetra
.77 .828 .897 r
.86097 .38894 .86348 .39189 .86972 .38806 .86721 .38501 Mtetra
.769 .822 .894 r
.86721 .38501 .86972 .38806 .87596 .38423 .87346 .38108 Mtetra
.768 .816 .891 r
.87346 .38108 .87596 .38423 .88222 .3804 .87971 .37715 Mtetra
.767 .81 .887 r
.87971 .37715 .88222 .3804 .88847 .37656 .88597 .37322 Mtetra
.765 .804 .884 r
.88597 .37322 .88847 .37656 .89474 .37272 .89224 .36928 Mtetra
.763 .798 .881 r
.89224 .36928 .89474 .37272 .90101 .3689 .89851 .36536 Mtetra
.759 .792 .88 r
.89851 .36536 .90101 .3689 .9073 .36513 .9048 .3615 Mtetra
.753 .785 .879 r
.9048 .3615 .9073 .36513 .91361 .36146 .91112 .35775 Mtetra
.744 .777 .88 r
.91112 .35775 .91361 .36146 .91995 .35796 .91745 .35416 Mtetra
.544 .704 .945 r
.33147 .53522 .3348 .53831 .34004 .53791 .33671 .53486 Mtetra
.499 .691 .954 r
.33671 .53486 .34004 .53791 .34528 .53782 .34195 .53485 Mtetra
.478 .688 .959 r
.34195 .53485 .34528 .53782 .35052 .53786 .34719 .53496 Mtetra
.465 .689 .964 r
.34719 .53496 .35052 .53786 .35578 .53795 .35245 .53512 Mtetra
.454 .69 .967 r
.35245 .53512 .35578 .53795 .36105 .53807 .35772 .53532 Mtetra
.446 .693 .971 r
.35772 .53532 .36105 .53807 .36634 .5382 .36301 .53553 Mtetra
.44 .697 .974 r
.36301 .53553 .36634 .5382 .37165 .53833 .36832 .53574 Mtetra
.433 .7 .977 r
.36832 .53574 .37165 .53833 .37697 .53845 .37364 .53595 Mtetra
.425 .703 .98 r
.37364 .53595 .37697 .53845 .38231 .53859 .37899 .53616 Mtetra
.417 .707 .983 r
.37899 .53616 .38231 .53859 .38766 .53871 .38434 .53637 Mtetra
.408 .71 .985 r
.38434 .53637 .38766 .53871 .39303 .53884 .38972 .53658 Mtetra
.399 .712 .986 r
.38972 .53658 .39303 .53884 .39842 .53897 .39511 .53679 Mtetra
.389 .714 .987 r
.39511 .53679 .39842 .53897 .40383 .5391 .40052 .537 Mtetra
.379 .716 .988 r
.40052 .537 .40383 .5391 .40925 .53923 .40594 .53721 Mtetra
.368 .718 .988 r
.40594 .53721 .40925 .53923 .41469 .53936 .41139 .53742 Mtetra
.356 .719 .987 r
.41139 .53742 .41469 .53936 .42015 .53949 .41685 .53764 Mtetra
.344 .719 .985 r
.41685 .53764 .42015 .53949 .42562 .53962 .42233 .53785 Mtetra
.332 .719 .983 r
.42233 .53785 .42562 .53962 .43111 .53975 .42782 .53806 Mtetra
.317 .719 .979 r
.42782 .53806 .43111 .53975 .43662 .53988 .43334 .53827 Mtetra
.303 .717 .975 r
.43334 .53827 .43662 .53988 .44214 .54001 .43887 .53849 Mtetra
.289 .715 .97 r
.43887 .53849 .44214 .54001 .44769 .54013 .44442 .5387 Mtetra
.273 .712 .963 r
.44442 .5387 .44769 .54013 .45325 .54026 .44999 .53891 Mtetra
.256 .709 .955 r
.44999 .53891 .45325 .54026 .45883 .5404 .45557 .53913 Mtetra
.239 .704 .947 r
.45557 .53913 .45883 .5404 .46442 .54053 .46118 .53934 Mtetra
.222 .699 .936 r
.46118 .53934 .46442 .54053 .47004 .54065 .4668 .53956 Mtetra
.203 .692 .925 r
.4668 .53956 .47004 .54065 .47567 .54079 .47244 .53977 Mtetra
.184 .685 .912 r
.47244 .53977 .47567 .54079 .48132 .54092 .4781 .53999 Mtetra
.165 .677 .898 r
.4781 .53999 .48132 .54092 .48699 .54105 .48377 .54021 Mtetra
.145 .667 .882 r
.48377 .54021 .48699 .54105 .49268 .54118 .48947 .54043 Mtetra
.124 .657 .865 r
.48947 .54043 .49268 .54118 .49838 .54132 .49518 .54065 Mtetra
.104 .646 .847 r
.49518 .54065 .49838 .54132 .50411 .54145 .50092 .54087 Mtetra
.083 .633 .827 r
.50092 .54087 .50411 .54145 .50985 .54158 .50667 .54109 Mtetra
.062 .62 .806 r
.50667 .54109 .50985 .54158 .51561 .54172 .51244 .54131 Mtetra
.041 .606 .785 r
.51244 .54131 .51561 .54172 .52139 .54186 .51823 .54153 Mtetra
.021 .591 .762 r
.51823 .54153 .52139 .54186 .52718 .54199 .52404 .54176 Mtetra
0 .575 .738 r
.52404 .54176 .52718 .54199 .533 .54213 .52987 .54198 Mtetra
0 .559 .714 r
.52987 .54198 .533 .54213 .53884 .54227 .53571 .54221 Mtetra
.041 0 0 r
.53571 .54221 .53884 .54227 .54469 .54241 .54158 .54244 Mtetra
.062 0 0 r
.54158 .54244 .54469 .54241 .55056 .54255 .54747 .54267 Mtetra
.082 0 0 r
.54747 .54267 .55056 .54255 .55646 .54269 .55337 .5429 Mtetra
.101 0 0 r
.55337 .5429 .55646 .54269 .56237 .54284 .5593 .54313 Mtetra
.119 0 0 r
.5593 .54313 .56237 .54284 .5683 .54298 .56525 .54336 Mtetra
.138 0 0 r
.56525 .54336 .5683 .54298 .57425 .54312 .57121 .5436 Mtetra
.156 0 0 r
.57121 .5436 .57425 .54312 .58022 .54327 .5772 .54384 Mtetra
.171 0 0 r
.5772 .54384 .58022 .54327 .58621 .54341 .5832 .54407 Mtetra
.186 0 0 r
.5832 .54407 .58621 .54341 .59222 .54355 .58923 .5443 Mtetra
.197 0 0 r
.58923 .5443 .59222 .54355 .59825 .54366 .59527 .5445 Mtetra
.194 0 0 r
.59527 .5445 .59825 .54366 .6043 .54369 .60134 .54461 Mtetra
.169 0 0 r
.60134 .54461 .6043 .54369 .61036 .54351 .60742 .54452 Mtetra
0 0 0 r
.60742 .54452 .61036 .54351 .61641 .54202 .61348 .54304 Mtetra
.512 .905 .77 r
.61348 .54304 .61641 .54202 .62241 .53858 .6195 .53951 Mtetra
.557 .928 .792 r
.6195 .53951 .62241 .53858 .62841 .53497 .62552 .5358 Mtetra
.59 .944 .81 r
.62552 .5358 .62841 .53497 .63442 .53124 .63154 .53198 Mtetra
.612 .954 .825 r
.63154 .53198 .63442 .53124 .64043 .52747 .63757 .5281 Mtetra
.627 .961 .839 r
.63757 .5281 .64043 .52747 .64645 .52369 .6436 .52422 Mtetra
.642 .967 .851 r
.6436 .52422 .64645 .52369 .65248 .5199 .64964 .52033 Mtetra
.656 .971 .863 r
.64964 .52033 .65248 .5199 .65851 .51611 .65568 .51643 Mtetra
.668 .975 .874 r
.65568 .51643 .65851 .51611 .66454 .51231 .66173 .51254 Mtetra
.68 .977 .883 r
.66173 .51254 .66454 .51231 .67058 .50851 .66779 .50864 Mtetra
.691 .979 .892 r
.66779 .50864 .67058 .50851 .67663 .50471 .67385 .50474 Mtetra
.701 .98 .9 r
.67385 .50474 .67663 .50471 .68269 .50091 .67992 .50083 Mtetra
.71 .98 .907 r
.67992 .50083 .68269 .50091 .68875 .4971 .68599 .49692 Mtetra
.719 .979 .913 r
.68599 .49692 .68875 .4971 .69482 .49329 .69207 .49301 Mtetra
.727 .978 .918 r
.69207 .49301 .69482 .49329 .70089 .48947 .69816 .48909 Mtetra
.734 .976 .923 r
.69816 .48909 .70089 .48947 .70697 .48565 .70425 .48517 Mtetra
.74 .973 .927 r
.70425 .48517 .70697 .48565 .71305 .48183 .71034 .48125 Mtetra
.746 .97 .93 r
.71034 .48125 .71305 .48183 .71914 .47801 .71645 .47732 Mtetra
.752 .966 .932 r
.71645 .47732 .71914 .47801 .72524 .47418 .72255 .47339 Mtetra
.756 .962 .934 r
.72255 .47339 .72524 .47418 .73135 .47034 .72867 .46946 Mtetra
.76 .957 .935 r
.72867 .46946 .73135 .47034 .73746 .46651 .73479 .46553 Mtetra
.764 .953 .936 r
.73479 .46553 .73746 .46651 .74357 .46267 .74091 .46158 Mtetra
.767 .947 .937 r
.74091 .46158 .74357 .46267 .74969 .45882 .74705 .45764 Mtetra
.77 .942 .936 r
.74705 .45764 .74969 .45882 .75582 .45498 .75318 .45369 Mtetra
.773 .936 .936 r
.75318 .45369 .75582 .45498 .76196 .45112 .75933 .44974 Mtetra
.775 .93 .935 r
.75933 .44974 .76196 .45112 .7681 .44727 .76548 .44579 Mtetra
.776 .924 .934 r
.76548 .44579 .7681 .44727 .77425 .44341 .77163 .44183 Mtetra
.777 .918 .932 r
.77163 .44183 .77425 .44341 .7804 .43955 .7778 .43787 Mtetra
.779 .912 .931 r
.7778 .43787 .7804 .43955 .78656 .43568 .78396 .4339 Mtetra
.779 .905 .929 r
.78396 .4339 .78656 .43568 .79273 .43181 .79014 .42993 Mtetra
.78 .899 .927 r
.79014 .42993 .79273 .43181 .7989 .42793 .79632 .42595 Mtetra
.78 .893 .924 r
.79632 .42595 .7989 .42793 .80508 .42405 .8025 .42198 Mtetra
.78 .886 .922 r
.8025 .42198 .80508 .42405 .81126 .42017 .80869 .41799 Mtetra
.78 .88 .919 r
.80869 .41799 .81126 .42017 .81745 .41628 .81489 .41401 Mtetra
.78 .873 .916 r
.81489 .41401 .81745 .41628 .82365 .41239 .82109 .41001 Mtetra
.779 .867 .913 r
.82109 .41001 .82365 .41239 .82985 .40849 .8273 .40602 Mtetra
.779 .86 .91 r
.8273 .40602 .82985 .40849 .83606 .40459 .83352 .40202 Mtetra
.778 .854 .907 r
.83352 .40202 .83606 .40459 .84228 .40068 .83974 .39802 Mtetra
.777 .848 .904 r
.83974 .39802 .84228 .40068 .8485 .39677 .84597 .394 Mtetra
.776 .841 .901 r
.84597 .394 .8485 .39677 .85473 .39286 .8522 .38999 Mtetra
.775 .835 .898 r
.8522 .38999 .85473 .39286 .86097 .38894 .85844 .38598 Mtetra
.774 .829 .895 r
.85844 .38598 .86097 .38894 .86721 .38501 .86468 .38195 Mtetra
.773 .823 .891 r
.86468 .38195 .86721 .38501 .87346 .38108 .87093 .37792 Mtetra
.772 .817 .888 r
.87093 .37792 .87346 .38108 .87971 .37715 .87719 .37389 Mtetra
.77 .811 .885 r
.87719 .37389 .87971 .37715 .88597 .37322 .88346 .36986 Mtetra
.769 .805 .882 r
.88346 .36986 .88597 .37322 .89224 .36928 .88973 .36583 Mtetra
.767 .799 .879 r
.88973 .36583 .89224 .36928 .89851 .36536 .896 .36181 Mtetra
.763 .793 .878 r
.896 .36181 .89851 .36536 .9048 .3615 .9023 .35786 Mtetra
.756 .786 .877 r
.9023 .35786 .9048 .3615 .91112 .35775 .90861 .35402 Mtetra
.747 .778 .878 r
.90861 .35402 .91112 .35775 .91745 .35416 .91495 .35035 Mtetra
.537 .702 .946 r
.32812 .5321 .33147 .53522 .33671 .53486 .33337 .5318 Mtetra
.489 .687 .955 r
.33337 .5318 .33671 .53486 .34195 .53485 .3386 .53186 Mtetra
.467 .684 .96 r
.3386 .53186 .34195 .53485 .34719 .53496 .34385 .53204 Mtetra
.453 .683 .964 r
.34385 .53204 .34719 .53496 .35245 .53512 .34911 .53229 Mtetra
.441 .685 .968 r
.34911 .53229 .35245 .53512 .35772 .53532 .35438 .53257 Mtetra
.433 .687 .971 r
.35438 .53257 .35772 .53532 .36301 .53553 .35968 .53286 Mtetra
.427 .691 .974 r
.35968 .53286 .36301 .53553 .36832 .53574 .36498 .53315 Mtetra
.419 .694 .977 r
.36498 .53315 .36832 .53574 .37364 .53595 .37031 .53344 Mtetra
.41 .697 .98 r
.37031 .53344 .37364 .53595 .37899 .53616 .37565 .53373 Mtetra
.402 .7 .982 r
.37565 .53373 .37899 .53616 .38434 .53637 .38101 .53402 Mtetra
.393 .702 .984 r
.38101 .53402 .38434 .53637 .38972 .53658 .38639 .53431 Mtetra
.383 .704 .985 r
.38639 .53431 .38972 .53658 .39511 .53679 .39178 .5346 Mtetra
.373 .706 .985 r
.39178 .5346 .39511 .53679 .40052 .537 .39719 .5349 Mtetra
.362 .708 .986 r
.39719 .5349 .40052 .537 .40594 .53721 .40262 .53519 Mtetra
.351 .709 .985 r
.40262 .53519 .40594 .53721 .41139 .53742 .40807 .53548 Mtetra
.338 .71 .984 r
.40807 .53548 .41139 .53742 .41685 .53764 .41354 .53578 Mtetra
.326 .71 .982 r
.41354 .53578 .41685 .53764 .42233 .53785 .41902 .53607 Mtetra
.313 .71 .979 r
.41902 .53607 .42233 .53785 .42782 .53806 .42452 .53636 Mtetra
.298 .708 .975 r
.42452 .53636 .42782 .53806 .43334 .53827 .43004 .53666 Mtetra
.284 .706 .97 r
.43004 .53666 .43334 .53827 .43887 .53849 .43558 .53696 Mtetra
.269 .704 .964 r
.43558 .53696 .43887 .53849 .44442 .5387 .44113 .53725 Mtetra
.252 .701 .957 r
.44113 .53725 .44442 .5387 .44999 .53891 .44671 .53755 Mtetra
.235 .696 .949 r
.44671 .53755 .44999 .53891 .45557 .53913 .4523 .53785 Mtetra
.218 .691 .939 r
.4523 .53785 .45557 .53913 .46118 .53934 .45791 .53815 Mtetra
.2 .685 .928 r
.45791 .53815 .46118 .53934 .4668 .53956 .46354 .53845 Mtetra
.181 .678 .916 r
.46354 .53845 .4668 .53956 .47244 .53977 .46919 .53875 Mtetra
.162 .67 .902 r
.46919 .53875 .47244 .53977 .4781 .53999 .47485 .53906 Mtetra
.143 .662 .888 r
.47485 .53906 .4781 .53999 .48377 .54021 .48054 .53936 Mtetra
.123 .652 .871 r
.48054 .53936 .48377 .54021 .48947 .54043 .48624 .53966 Mtetra
.102 .641 .854 r
.48624 .53966 .48947 .54043 .49518 .54065 .49197 .53997 Mtetra
.082 .629 .835 r
.49197 .53997 .49518 .54065 .50092 .54087 .49771 .54028 Mtetra
.061 .617 .815 r
.49771 .54028 .50092 .54087 .50667 .54109 .50347 .54058 Mtetra
.04 .603 .794 r
.50347 .54058 .50667 .54109 .51244 .54131 .50925 .5409 Mtetra
.019 .589 .772 r
.50925 .5409 .51244 .54131 .51823 .54153 .51505 .54121 Mtetra
0 .574 .749 r
.51505 .54121 .51823 .54153 .52404 .54176 .52087 .54152 Mtetra
0 .558 .725 r
.52087 .54152 .52404 .54176 .52987 .54198 .52671 .54183 Mtetra
.043 0 0 r
.52671 .54183 .52987 .54198 .53571 .54221 .53257 .54215 Mtetra
.062 0 0 r
.53257 .54215 .53571 .54221 .54158 .54244 .53845 .54247 Mtetra
.082 0 0 r
.53845 .54247 .54158 .54244 .54747 .54267 .54435 .54279 Mtetra
.102 0 0 r
.54435 .54279 .54747 .54267 .55337 .5429 .55027 .54311 Mtetra
.12 0 0 r
.55027 .54311 .55337 .5429 .5593 .54313 .55621 .54343 Mtetra
.138 0 0 r
.55621 .54343 .5593 .54313 .56525 .54336 .56217 .54375 Mtetra
.157 0 0 r
.56217 .54375 .56525 .54336 .57121 .5436 .56815 .54408 Mtetra
.174 0 0 r
.56815 .54408 .57121 .5436 .5772 .54384 .57415 .54441 Mtetra
.189 0 0 r
.57415 .54441 .5772 .54384 .5832 .54407 .58017 .54474 Mtetra
.203 0 0 r
.58017 .54474 .5832 .54407 .58923 .5443 .58621 .54505 Mtetra
.213 0 0 r
.58621 .54505 .58923 .5443 .59527 .5445 .59228 .54535 Mtetra
.21 0 0 r
.59228 .54535 .59527 .5445 .60134 .54461 .59836 .54555 Mtetra
.183 0 0 r
.59836 .54555 .60134 .54461 .60742 .54452 .60445 .54552 Mtetra
0 0 0 r
.60445 .54552 .60742 .54452 .61348 .54304 .61053 .54406 Mtetra
.525 .911 .774 r
.61053 .54406 .61348 .54304 .6195 .53951 .61656 .54045 Mtetra
.57 .934 .795 r
.61656 .54045 .6195 .53951 .62552 .5358 .6226 .53664 Mtetra
.603 .949 .812 r
.6226 .53664 .62552 .5358 .63154 .53198 .62864 .53271 Mtetra
.625 .959 .827 r
.62864 .53271 .63154 .53198 .63757 .5281 .63468 .52874 Mtetra
.64 .965 .84 r
.63468 .52874 .63757 .5281 .6436 .52422 .64073 .52475 Mtetra
.654 .971 .852 r
.64073 .52475 .6436 .52422 .64964 .52033 .64678 .52076 Mtetra
.667 .975 .863 r
.64678 .52076 .64964 .52033 .65568 .51643 .65284 .51676 Mtetra
.679 .978 .873 r
.65284 .51676 .65568 .51643 .66173 .51254 .65891 .51276 Mtetra
.69 .98 .883 r
.65891 .51276 .66173 .51254 .66779 .50864 .66497 .50876 Mtetra
.701 .982 .891 r
.66497 .50876 .66779 .50864 .67385 .50474 .67105 .50476 Mtetra
.711 .982 .899 r
.67105 .50476 .67385 .50474 .67992 .50083 .67713 .50075 Mtetra
.719 .982 .905 r
.67713 .50075 .67992 .50083 .68599 .49692 .68322 .49674 Mtetra
.728 .981 .911 r
.68322 .49674 .68599 .49692 .69207 .49301 .68931 .49272 Mtetra
.735 .979 .916 r
.68931 .49272 .69207 .49301 .69816 .48909 .69541 .48871 Mtetra
.742 .977 .921 r
.69541 .48871 .69816 .48909 .70425 .48517 .70151 .48469 Mtetra
.748 .974 .924 r
.70151 .48469 .70425 .48517 .71034 .48125 .70762 .48066 Mtetra
.754 .971 .927 r
.70762 .48066 .71034 .48125 .71645 .47732 .71373 .47664 Mtetra
.759 .967 .929 r
.71373 .47664 .71645 .47732 .72255 .47339 .71985 .4726 Mtetra
.763 .963 .931 r
.71985 .4726 .72255 .47339 .72867 .46946 .72598 .46857 Mtetra
.767 .958 .932 r
.72598 .46857 .72867 .46946 .73479 .46553 .73211 .46454 Mtetra
.771 .953 .933 r
.73211 .46454 .73479 .46553 .74091 .46158 .73824 .46049 Mtetra
.774 .948 .933 r
.73824 .46049 .74091 .46158 .74705 .45764 .74438 .45645 Mtetra
.776 .942 .933 r
.74438 .45645 .74705 .45764 .75318 .45369 .75053 .4524 Mtetra
.778 .937 .933 r
.75053 .4524 .75318 .45369 .75933 .44974 .75668 .44835 Mtetra
.78 .931 .932 r
.75668 .44835 .75933 .44974 .76548 .44579 .76284 .4443 Mtetra
.781 .925 .931 r
.76284 .4443 .76548 .44579 .77163 .44183 .76901 .44024 Mtetra
.783 .919 .929 r
.76901 .44024 .77163 .44183 .7778 .43787 .77518 .43618 Mtetra
.784 .912 .927 r
.77518 .43618 .7778 .43787 .78396 .4339 .78135 .43211 Mtetra
.784 .906 .926 r
.78135 .43211 .78396 .4339 .79014 .42993 .78753 .42804 Mtetra
.785 .9 .924 r
.78753 .42804 .79014 .42993 .79632 .42595 .79372 .42397 Mtetra
.785 .893 .921 r
.79372 .42397 .79632 .42595 .8025 .42198 .79991 .41989 Mtetra
.785 .887 .919 r
.79991 .41989 .8025 .42198 .80869 .41799 .80611 .4158 Mtetra
.784 .88 .916 r
.80611 .4158 .80869 .41799 .81489 .41401 .81232 .41172 Mtetra
.784 .874 .913 r
.81232 .41172 .81489 .41401 .82109 .41001 .81853 .40763 Mtetra
.784 .867 .91 r
.81853 .40763 .82109 .41001 .8273 .40602 .82474 .40353 Mtetra
.783 .861 .908 r
.82474 .40353 .8273 .40602 .83352 .40202 .83096 .39944 Mtetra
.782 .855 .905 r
.83096 .39944 .83352 .40202 .83974 .39802 .83719 .39533 Mtetra
.781 .848 .902 r
.83719 .39533 .83974 .39802 .84597 .394 .84342 .39122 Mtetra
.78 .842 .898 r
.84342 .39122 .84597 .394 .8522 .38999 .84966 .38711 Mtetra
.779 .836 .895 r
.84966 .38711 .8522 .38999 .85844 .38598 .8559 .383 Mtetra
.778 .83 .892 r
.8559 .383 .85844 .38598 .86468 .38195 .86215 .37888 Mtetra
.777 .824 .889 r
.86215 .37888 .86468 .38195 .87093 .37792 .8684 .37475 Mtetra
.776 .818 .886 r
.8684 .37475 .87093 .37792 .87719 .37389 .87466 .37062 Mtetra
.774 .812 .883 r
.87466 .37062 .87719 .37389 .88346 .36986 .88093 .36649 Mtetra
.773 .806 .88 r
.88093 .36649 .88346 .36986 .88973 .36583 .8872 .36236 Mtetra
.77 .8 .877 r
.8872 .36236 .88973 .36583 .896 .36181 .89348 .35825 Mtetra
.766 .794 .875 r
.89348 .35825 .896 .36181 .9023 .35786 .89978 .3542 Mtetra
.76 .787 .875 r
.89978 .3542 .9023 .35786 .90861 .35402 .90609 .35027 Mtetra
.75 .779 .877 r
.90609 .35027 .90861 .35402 .91495 .35035 .91244 .34652 Mtetra
.53 .699 .947 r
.32477 .52898 .32812 .5321 .33337 .5318 .33001 .52874 Mtetra
.479 .683 .956 r
.33001 .52874 .33337 .5318 .3386 .53186 .33525 .52886 Mtetra
.455 .679 .961 r
.33525 .52886 .3386 .53186 .34385 .53204 .34049 .52912 Mtetra
.44 .678 .964 r
.34049 .52912 .34385 .53204 .34911 .53229 .34576 .52944 Mtetra
.428 .679 .968 r
.34576 .52944 .34911 .53229 .35438 .53257 .35103 .5298 Mtetra
.419 .681 .971 r
.35103 .5298 .35438 .53257 .35968 .53286 .35632 .53017 Mtetra
.412 .685 .974 r
.35632 .53017 .35968 .53286 .36498 .53315 .36163 .53054 Mtetra
.404 .687 .977 r
.36163 .53054 .36498 .53315 .37031 .53344 .36696 .53091 Mtetra
.395 .69 .979 r
.36696 .53091 .37031 .53344 .37565 .53373 .3723 .53129 Mtetra
.386 .693 .981 r
.3723 .53129 .37565 .53373 .38101 .53402 .37766 .53166 Mtetra
.377 .695 .982 r
.37766 .53166 .38101 .53402 .38639 .53431 .38304 .53203 Mtetra
.366 .697 .983 r
.38304 .53203 .38639 .53431 .39178 .5346 .38844 .53241 Mtetra
.356 .698 .983 r
.38844 .53241 .39178 .5346 .39719 .5349 .39386 .53278 Mtetra
.345 .7 .983 r
.39386 .53278 .39719 .5349 .40262 .53519 .39929 .53316 Mtetra
.333 .7 .982 r
.39929 .53316 .40262 .53519 .40807 .53548 .40474 .53353 Mtetra
.32 .7 .98 r
.40474 .53353 .40807 .53548 .41354 .53578 .41021 .53391 Mtetra
.307 .7 .978 r
.41021 .53391 .41354 .53578 .41902 .53607 .4157 .53429 Mtetra
.294 .699 .974 r
.4157 .53429 .41902 .53607 .42452 .53636 .4212 .53466 Mtetra
.278 .697 .97 r
.4212 .53466 .42452 .53636 .43004 .53666 .42673 .53504 Mtetra
.263 .695 .964 r
.42673 .53504 .43004 .53666 .43558 .53696 .43227 .53542 Mtetra
.248 .692 .958 r
.43227 .53542 .43558 .53696 .44113 .53725 .43783 .5358 Mtetra
.231 .688 .95 r
.43783 .5358 .44113 .53725 .44671 .53755 .44341 .53619 Mtetra
.214 .683 .941 r
.44341 .53619 .44671 .53755 .4523 .53785 .44901 .53657 Mtetra
.196 .678 .931 r
.44901 .53657 .4523 .53785 .45791 .53815 .45463 .53696 Mtetra
.178 .671 .919 r
.45463 .53696 .45791 .53815 .46354 .53845 .46027 .53734 Mtetra
.158 .663 .906 r
.46027 .53734 .46354 .53845 .46919 .53875 .46592 .53773 Mtetra
.139 .655 .892 r
.46592 .53773 .46919 .53875 .47485 .53906 .4716 .53812 Mtetra
.12 .646 .877 r
.4716 .53812 .47485 .53906 .48054 .53936 .47729 .53851 Mtetra
.099 .635 .86 r
.47729 .53851 .48054 .53936 .48624 .53966 .483 .5389 Mtetra
.079 .624 .841 r
.483 .5389 .48624 .53966 .49197 .53997 .48873 .53929 Mtetra
.059 .612 .822 r
.48873 .53929 .49197 .53997 .49771 .54028 .49449 .53969 Mtetra
.038 .599 .802 r
.49449 .53969 .49771 .54028 .50347 .54058 .50026 .54008 Mtetra
.017 .585 .78 r
.50026 .54008 .50347 .54058 .50925 .5409 .50605 .54048 Mtetra
0 .57 .758 r
.50605 .54048 .50925 .5409 .51505 .54121 .51186 .54088 Mtetra
0 .556 .735 r
.51186 .54088 .51505 .54121 .52087 .54152 .51769 .54128 Mtetra
0 .539 .71 r
.51769 .54128 .52087 .54152 .52671 .54183 .52354 .54169 Mtetra
.065 0 0 r
.52354 .54169 .52671 .54183 .53257 .54215 .52941 .54209 Mtetra
.084 0 0 r
.52941 .54209 .53257 .54215 .53845 .54247 .53531 .5425 Mtetra
.104 0 0 r
.53531 .5425 .53845 .54247 .54435 .54279 .54122 .54291 Mtetra
.123 0 0 r
.54122 .54291 .54435 .54279 .55027 .54311 .54715 .54332 Mtetra
.141 0 0 r
.54715 .54332 .55027 .54311 .55621 .54343 .5531 .54373 Mtetra
.158 0 0 r
.5531 .54373 .55621 .54343 .56217 .54375 .55908 .54415 Mtetra
.176 0 0 r
.55908 .54415 .56217 .54375 .56815 .54408 .56507 .54457 Mtetra
.193 0 0 r
.56507 .54457 .56815 .54408 .57415 .54441 .57109 .54499 Mtetra
.207 0 0 r
.57109 .54499 .57415 .54441 .58017 .54474 .57712 .54541 Mtetra
.221 0 0 r
.57712 .54541 .58017 .54474 .58621 .54505 .58318 .54582 Mtetra
.23 0 0 r
.58318 .54582 .58621 .54505 .59228 .54535 .58926 .5462 Mtetra
.226 0 0 r
.58926 .5462 .59228 .54535 .59836 .54555 .59535 .54649 Mtetra
.198 0 0 r
.59535 .54649 .59836 .54555 .60445 .54552 .60147 .54654 Mtetra
0 0 0 r
.60147 .54654 .60445 .54552 .61053 .54406 .60756 .54509 Mtetra
.537 .917 .776 r
.60756 .54509 .61053 .54406 .61656 .54045 .61361 .54139 Mtetra
.582 .939 .796 r
.61361 .54139 .61656 .54045 .6226 .53664 .61967 .53749 Mtetra
.615 .954 .813 r
.61967 .53749 .6226 .53664 .62864 .53271 .62572 .53346 Mtetra
.636 .963 .827 r
.62572 .53346 .62864 .53271 .63468 .52874 .63178 .52938 Mtetra
.651 .969 .84 r
.63178 .52938 .63468 .52874 .64073 .52475 .63784 .52529 Mtetra
.664 .974 .852 r
.63784 .52529 .64073 .52475 .64678 .52076 .64391 .5212 Mtetra
.678 .978 .863 r
.64391 .5212 .64678 .52076 .65284 .51676 .64998 .5171 Mtetra
.689 .981 .873 r
.64998 .5171 .65284 .51676 .65891 .51276 .65606 .51299 Mtetra
.7 .982 .882 r
.65606 .51299 .65891 .51276 .66497 .50876 .66214 .50889 Mtetra
.71 .984 .89 r
.66214 .50889 .66497 .50876 .67105 .50476 .66823 .50478 Mtetra
.72 .984 .897 r
.66823 .50478 .67105 .50476 .67713 .50075 .67433 .50067 Mtetra
.728 .983 .903 r
.67433 .50067 .67713 .50075 .68322 .49674 .68043 .49656 Mtetra
.736 .982 .909 r
.68043 .49656 .68322 .49674 .68931 .49272 .68653 .49244 Mtetra
.743 .981 .914 r
.68653 .49244 .68931 .49272 .69541 .48871 .69264 .48832 Mtetra
.75 .978 .918 r
.69264 .48832 .69541 .48871 .70151 .48469 .69876 .4842 Mtetra
.755 .975 .922 r
.69876 .4842 .70151 .48469 .70762 .48066 .70488 .48008 Mtetra
.761 .972 .924 r
.70488 .48008 .70762 .48066 .71373 .47664 .711 .47595 Mtetra
.766 .968 .927 r
.711 .47595 .71373 .47664 .71985 .4726 .71713 .47181 Mtetra
.77 .963 .928 r
.71713 .47181 .71985 .4726 .72598 .46857 .72327 .46768 Mtetra
.773 .959 .929 r
.72327 .46768 .72598 .46857 .73211 .46454 .72941 .46354 Mtetra
.777 .954 .93 r
.72941 .46354 .73211 .46454 .73824 .46049 .73556 .4594 Mtetra
.779 .949 .93 r
.73556 .4594 .73824 .46049 .74438 .45645 .74171 .45526 Mtetra
.782 .943 .93 r
.74171 .45526 .74438 .45645 .75053 .4524 .74786 .45111 Mtetra
.784 .937 .93 r
.74786 .45111 .75053 .4524 .75668 .44835 .75403 .44696 Mtetra
.786 .931 .929 r
.75403 .44696 .75668 .44835 .76284 .4443 .7602 .4428 Mtetra
.787 .925 .928 r
.7602 .4428 .76284 .4443 .76901 .44024 .76637 .43864 Mtetra
.788 .919 .926 r
.76637 .43864 .76901 .44024 .77518 .43618 .77255 .43448 Mtetra
.789 .913 .924 r
.77255 .43448 .77518 .43618 .78135 .43211 .77873 .43031 Mtetra
.789 .907 .923 r
.77873 .43031 .78135 .43211 .78753 .42804 .78492 .42614 Mtetra
.789 .9 .92 r
.78492 .42614 .78753 .42804 .79372 .42397 .79111 .42197 Mtetra
.789 .894 .918 r
.79111 .42197 .79372 .42397 .79991 .41989 .79731 .41779 Mtetra
.789 .887 .916 r
.79731 .41779 .79991 .41989 .80611 .4158 .80352 .41361 Mtetra
.789 .881 .913 r
.80352 .41361 .80611 .4158 .81232 .41172 .80973 .40942 Mtetra
.789 .874 .91 r
.80973 .40942 .81232 .41172 .81853 .40763 .81594 .40523 Mtetra
.788 .868 .908 r
.81594 .40523 .81853 .40763 .82474 .40353 .82217 .40104 Mtetra
.787 .862 .905 r
.82217 .40104 .82474 .40353 .83096 .39944 .82839 .39684 Mtetra
.786 .855 .902 r
.82839 .39684 .83096 .39944 .83719 .39533 .83462 .39264 Mtetra
.786 .849 .899 r
.83462 .39264 .83719 .39533 .84342 .39122 .84086 .38843 Mtetra
.785 .843 .896 r
.84086 .38843 .84342 .39122 .84966 .38711 .8471 .38422 Mtetra
.783 .837 .893 r
.8471 .38422 .84966 .38711 .8559 .383 .85335 .38001 Mtetra
.782 .831 .89 r
.85335 .38001 .8559 .383 .86215 .37888 .8596 .37579 Mtetra
.781 .825 .886 r
.8596 .37579 .86215 .37888 .8684 .37475 .86586 .37156 Mtetra
.78 .819 .884 r
.86586 .37156 .8684 .37475 .87466 .37062 .87212 .36733 Mtetra
.778 .813 .88 r
.87212 .36733 .87466 .37062 .88093 .36649 .87839 .36311 Mtetra
.777 .807 .877 r
.87839 .36311 .88093 .36649 .8872 .36236 .88467 .35888 Mtetra
.774 .801 .875 r
.88467 .35888 .8872 .36236 .89348 .35825 .89095 .35467 Mtetra
.77 .795 .873 r
.89095 .35467 .89348 .35825 .89978 .3542 .89725 .35053 Mtetra
.763 .788 .873 r
.89725 .35053 .89978 .3542 .90609 .35027 .90357 .34651 Mtetra
.753 .78 .875 r
.90357 .34651 .90609 .35027 .91244 .34652 .90992 .34268 Mtetra
.523 .697 .948 r
.3214 .52585 .32477 .52898 .33001 .52874 .32664 .52566 Mtetra
.469 .679 .957 r
.32664 .52566 .33001 .52874 .33525 .52886 .33188 .52585 Mtetra
.443 .673 .961 r
.33188 .52585 .33525 .52886 .34049 .52912 .33713 .52619 Mtetra
.427 .672 .964 r
.33713 .52619 .34049 .52912 .34576 .52944 .34239 .52659 Mtetra
.414 .672 .968 r
.34239 .52659 .34576 .52944 .35103 .5298 .34766 .52703 Mtetra
.405 .675 .971 r
.34766 .52703 .35103 .5298 .35632 .53017 .35296 .52748 Mtetra
.398 .678 .973 r
.35296 .52748 .35632 .53017 .36163 .53054 .35827 .52793 Mtetra
.389 .68 .976 r
.35827 .52793 .36163 .53054 .36696 .53091 .36359 .52838 Mtetra
.379 .682 .978 r
.36359 .52838 .36696 .53091 .3723 .53129 .36894 .52883 Mtetra
.37 .685 .979 r
.36894 .52883 .3723 .53129 .37766 .53166 .3743 .52929 Mtetra
.361 .687 .98 r
.3743 .52929 .37766 .53166 .38304 .53203 .37969 .52974 Mtetra
.35 .688 .981 r
.37969 .52974 .38304 .53203 .38844 .53241 .38509 .5302 Mtetra
.338 .689 .981 r
.38509 .5302 .38844 .53241 .39386 .53278 .3905 .53066 Mtetra
.327 .69 .98 r
.3905 .53066 .39386 .53278 .39929 .53316 .39594 .53111 Mtetra
.315 .691 .979 r
.39594 .53111 .39929 .53316 .40474 .53353 .4014 .53157 Mtetra
.301 .69 .976 r
.4014 .53157 .40474 .53353 .41021 .53391 .40687 .53203 Mtetra
.288 .69 .973 r
.40687 .53203 .41021 .53391 .4157 .53429 .41236 .53249 Mtetra
.274 .688 .969 r
.41236 .53249 .4157 .53429 .4212 .53466 .41787 .53295 Mtetra
.258 .686 .964 r
.41787 .53295 .4212 .53466 .42673 .53504 .4234 .53342 Mtetra
.243 .683 .958 r
.4234 .53342 .42673 .53504 .43227 .53542 .42895 .53388 Mtetra
.227 .68 .951 r
.42895 .53388 .43227 .53542 .43783 .5358 .43452 .53435 Mtetra
.21 .675 .943 r
.43452 .53435 .43783 .5358 .44341 .53619 .4401 .53482 Mtetra
.192 .67 .933 r
.4401 .53482 .44341 .53619 .44901 .53657 .44571 .53529 Mtetra
.174 .664 .922 r
.44571 .53529 .44901 .53657 .45463 .53696 .45133 .53576 Mtetra
.156 .657 .91 r
.45133 .53576 .45463 .53696 .46027 .53734 .45697 .53623 Mtetra
.136 .648 .896 r
.45697 .53623 .46027 .53734 .46592 .53773 .46264 .5367 Mtetra
.117 .64 .881 r
.46264 .5367 .46592 .53773 .4716 .53812 .46832 .53718 Mtetra
.097 .63 .866 r
.46832 .53718 .4716 .53812 .47729 .53851 .47402 .53765 Mtetra
.077 .619 .848 r
.47402 .53765 .47729 .53851 .483 .5389 .47974 .53813 Mtetra
.056 .607 .829 r
.47974 .53813 .483 .5389 .48873 .53929 .48548 .53861 Mtetra
.036 .595 .81 r
.48548 .53861 .48873 .53929 .49449 .53969 .49125 .53909 Mtetra
.015 .582 .789 r
.49125 .53909 .49449 .53969 .50026 .54008 .49703 .53958 Mtetra
0 .567 .767 r
.49703 .53958 .50026 .54008 .50605 .54048 .50283 .54007 Mtetra
0 .553 .744 r
.50283 .54007 .50605 .54048 .51186 .54088 .50865 .54055 Mtetra
0 .538 .721 r
.50865 .54055 .51186 .54088 .51769 .54128 .51449 .54104 Mtetra
.066 0 0 r
.51449 .54104 .51769 .54128 .52354 .54169 .52035 .54154 Mtetra
.086 0 0 r
.52035 .54154 .52354 .54169 .52941 .54209 .52624 .54203 Mtetra
.105 0 0 r
.52624 .54203 .52941 .54209 .53531 .5425 .53214 .54253 Mtetra
.124 0 0 r
.53214 .54253 .53531 .5425 .54122 .54291 .53806 .54303 Mtetra
.143 0 0 r
.53806 .54303 .54122 .54291 .54715 .54332 .54401 .54353 Mtetra
.16 0 0 r
.54401 .54353 .54715 .54332 .5531 .54373 .54998 .54404 Mtetra
.177 0 0 r
.54998 .54404 .5531 .54373 .55908 .54415 .55596 .54454 Mtetra
.194 0 0 r
.55596 .54454 .55908 .54415 .56507 .54457 .56197 .54506 Mtetra
.21 0 0 r
.56197 .54506 .56507 .54457 .57109 .54499 .568 .54557 Mtetra
.224 0 0 r
.568 .54557 .57109 .54499 .57712 .54541 .57405 .54608 Mtetra
.237 0 0 r
.57405 .54608 .57712 .54541 .58318 .54582 .58013 .54659 Mtetra
.246 0 0 r
.58013 .54659 .58318 .54582 .58926 .5462 .58622 .54706 Mtetra
.241 0 0 r
.58622 .54706 .58926 .5462 .59535 .54649 .59233 .54744 Mtetra
.212 0 0 r
.59233 .54744 .59535 .54649 .60147 .54654 .59846 .54757 Mtetra
0 0 0 r
.59846 .54757 .60147 .54654 .60756 .54509 .60458 .54612 Mtetra
.549 .923 .779 r
.60458 .54612 .60756 .54509 .61361 .54139 .61064 .54234 Mtetra
.595 .944 .799 r
.61064 .54234 .61361 .54139 .61967 .53749 .61671 .53834 Mtetra
.627 .959 .815 r
.61671 .53834 .61967 .53749 .62572 .53346 .62278 .53421 Mtetra
.648 .967 .828 r
.62278 .53421 .62572 .53346 .63178 .52938 .62886 .53003 Mtetra
.662 .973 .84 r
.62886 .53003 .63178 .52938 .63784 .52529 .63493 .52584 Mtetra
.675 .977 .852 r
.63493 .52584 .63784 .52529 .64391 .5212 .64102 .52164 Mtetra
.688 .981 .862 r
.64102 .52164 .64391 .5212 .64998 .5171 .64711 .51743 Mtetra
.699 .983 .872 r
.64711 .51743 .64998 .5171 .65606 .51299 .6532 .51323 Mtetra
.709 .985 .881 r
.6532 .51323 .65606 .51299 .66214 .50889 .6593 .50902 Mtetra
.719 .986 .888 r
.6593 .50902 .66214 .50889 .66823 .50478 .6654 .50481 Mtetra
.728 .986 .895 r
.6654 .50481 .66823 .50478 .67433 .50067 .67151 .50059 Mtetra
.736 .985 .902 r
.67151 .50059 .67433 .50067 .68043 .49656 .67762 .49638 Mtetra
.744 .984 .907 r
.67762 .49638 .68043 .49656 .68653 .49244 .68374 .49216 Mtetra
.751 .982 .912 r
.68374 .49216 .68653 .49244 .69264 .48832 .68986 .48794 Mtetra
.757 .979 .916 r
.68986 .48794 .69264 .48832 .69876 .4842 .69599 .48371 Mtetra
.763 .976 .919 r
.69599 .48371 .69876 .4842 .70488 .48008 .70212 .47949 Mtetra
.768 .972 .921 r
.70212 .47949 .70488 .48008 .711 .47595 .70826 .47525 Mtetra
.772 .968 .924 r
.70826 .47525 .711 .47595 .71713 .47181 .7144 .47102 Mtetra
.776 .964 .925 r
.7144 .47102 .71713 .47181 .72327 .46768 .72054 .46678 Mtetra
.78 .959 .926 r
.72054 .46678 .72327 .46768 .72941 .46354 .7267 .46255 Mtetra
.783 .954 .927 r
.7267 .46255 .72941 .46354 .73556 .4594 .73285 .4583 Mtetra
.785 .949 .927 r
.73285 .4583 .73556 .4594 .74171 .45526 .73902 .45405 Mtetra
.787 .943 .927 r
.73902 .45405 .74171 .45526 .74786 .45111 .74518 .44981 Mtetra
.789 .938 .926 r
.74518 .44981 .74786 .45111 .75403 .44696 .75136 .44555 Mtetra
.791 .932 .925 r
.75136 .44555 .75403 .44696 .7602 .4428 .75753 .4413 Mtetra
.792 .926 .924 r
.75753 .4413 .7602 .4428 .76637 .43864 .76371 .43704 Mtetra
.793 .92 .923 r
.76371 .43704 .76637 .43864 .77255 .43448 .7699 .43277 Mtetra
.794 .913 .921 r
.7699 .43277 .77255 .43448 .77873 .43031 .77609 .42851 Mtetra
.794 .907 .919 r
.77609 .42851 .77873 .43031 .78492 .42614 .78229 .42424 Mtetra
.794 .901 .917 r
.78229 .42424 .78492 .42614 .79111 .42197 .78849 .41996 Mtetra
.794 .894 .915 r
.78849 .41996 .79111 .42197 .79731 .41779 .7947 .41568 Mtetra
.794 .888 .913 r
.7947 .41568 .79731 .41779 .80352 .41361 .80091 .4114 Mtetra
.793 .881 .91 r
.80091 .4114 .80352 .41361 .80973 .40942 .80713 .40712 Mtetra
.793 .875 .908 r
.80713 .40712 .80973 .40942 .81594 .40523 .81335 .40283 Mtetra
.792 .869 .905 r
.81335 .40283 .81594 .40523 .82217 .40104 .81958 .39853 Mtetra
.791 .862 .902 r
.81958 .39853 .82217 .40104 .82839 .39684 .82581 .39423 Mtetra
.79 .856 .899 r
.82581 .39423 .82839 .39684 .83462 .39264 .83205 .38993 Mtetra
.79 .85 .896 r
.83205 .38993 .83462 .39264 .84086 .38843 .83829 .38563 Mtetra
.788 .844 .893 r
.83829 .38563 .84086 .38843 .8471 .38422 .84454 .38131 Mtetra
.787 .838 .89 r
.84454 .38131 .8471 .38422 .85335 .38001 .85079 .377 Mtetra
.786 .832 .887 r
.85079 .377 .85335 .38001 .8596 .37579 .85704 .37268 Mtetra
.785 .826 .884 r
.85704 .37268 .8596 .37579 .86586 .37156 .86331 .36836 Mtetra
.783 .82 .881 r
.86331 .36836 .86586 .37156 .87212 .36733 .86957 .36403 Mtetra
.782 .814 .878 r
.86957 .36403 .87212 .36733 .87839 .36311 .87585 .35971 Mtetra
.78 .808 .875 r
.87585 .35971 .87839 .36311 .88467 .35888 .88212 .35538 Mtetra
.778 .802 .873 r
.88212 .35538 .88467 .35888 .89095 .35467 .88841 .35107 Mtetra
.773 .796 .871 r
.88841 .35107 .89095 .35467 .89725 .35053 .89471 .34684 Mtetra
.766 .789 .871 r
.89471 .34684 .89725 .35053 .90357 .34651 .90103 .34273 Mtetra
.756 .781 .873 r
.90103 .34273 .90357 .34651 .90992 .34268 .90738 .33882 Mtetra
.516 .694 .949 r
.31802 .5227 .3214 .52585 .32664 .52566 .32326 .52256 Mtetra
.458 .674 .957 r
.32326 .52256 .32664 .52566 .33188 .52585 .3285 .52283 Mtetra
.431 .668 .961 r
.3285 .52283 .33188 .52585 .33713 .52619 .33375 .52324 Mtetra
.414 .666 .964 r
.33375 .52324 .33713 .52619 .34239 .52659 .33901 .52372 Mtetra
.4 .666 .967 r
.33901 .52372 .34239 .52659 .34766 .52703 .34428 .52424 Mtetra
.39 .668 .97 r
.34428 .52424 .34766 .52703 .35296 .52748 .34958 .52477 Mtetra
.383 .671 .972 r
.34958 .52477 .35296 .52748 .35827 .52793 .35489 .5253 Mtetra
.373 .673 .974 r
.35489 .5253 .35827 .52793 .36359 .52838 .36022 .52583 Mtetra
.363 .675 .976 r
.36022 .52583 .36359 .52838 .36894 .52883 .36556 .52637 Mtetra
.354 .677 .977 r
.36556 .52637 .36894 .52883 .3743 .52929 .37093 .5269 Mtetra
.344 .679 .978 r
.37093 .5269 .3743 .52929 .37969 .52974 .37631 .52744 Mtetra
.332 .679 .978 r
.37631 .52744 .37969 .52974 .38509 .5302 .38172 .52798 Mtetra
.321 .68 .978 r
.38172 .52798 .38509 .5302 .3905 .53066 .38714 .52852 Mtetra
.309 .681 .977 r
.38714 .52852 .3905 .53066 .39594 .53111 .39258 .52906 Mtetra
.296 .681 .975 r
.39258 .52906 .39594 .53111 .4014 .53157 .39803 .5296 Mtetra
.282 .68 .972 r
.39803 .5296 .4014 .53157 .40687 .53203 .40351 .53015 Mtetra
.269 .679 .968 r
.40351 .53015 .40687 .53203 .41236 .53249 .40901 .53069 Mtetra
.254 .677 .964 r
.40901 .53069 .41236 .53249 .41787 .53295 .41452 .53123 Mtetra
.238 .674 .958 r
.41452 .53123 .41787 .53295 .4234 .53342 .42006 .53178 Mtetra
.222 .671 .952 r
.42006 .53178 .4234 .53342 .42895 .53388 .42561 .53233 Mtetra
.206 .667 .944 r
.42561 .53233 .42895 .53388 .43452 .53435 .43118 .53288 Mtetra
.189 .662 .935 r
.43118 .53288 .43452 .53435 .4401 .53482 .43677 .53344 Mtetra
.171 .656 .924 r
.43677 .53344 .4401 .53482 .44571 .53529 .44238 .53399 Mtetra
.153 .649 .913 r
.44238 .53399 .44571 .53529 .45133 .53576 .44801 .53455 Mtetra
.134 .642 .9 r
.44801 .53455 .45133 .53576 .45697 .53623 .45367 .5351 Mtetra
.114 .633 .886 r
.45367 .5351 .45697 .53623 .46264 .5367 .45934 .53566 Mtetra
.095 .624 .871 r
.45934 .53566 .46264 .5367 .46832 .53718 .46503 .53623 Mtetra
.075 .614 .854 r
.46503 .53623 .46832 .53718 .47402 .53765 .47074 .53679 Mtetra
.055 .603 .836 r
.47074 .53679 .47402 .53765 .47974 .53813 .47647 .53736 Mtetra
.034 .59 .817 r
.47647 .53736 .47974 .53813 .48548 .53861 .48222 .53793 Mtetra
.014 .578 .797 r
.48222 .53793 .48548 .53861 .49125 .53909 .48799 .5385 Mtetra
0 .564 .776 r
.48799 .5385 .49125 .53909 .49703 .53958 .49378 .53907 Mtetra
0 .55 .753 r
.49378 .53907 .49703 .53958 .50283 .54007 .49959 .53964 Mtetra
0 .535 .731 r
.49959 .53964 .50283 .54007 .50865 .54055 .50542 .54022 Mtetra
0 .52 .707 r
.50542 .54022 .50865 .54055 .51449 .54104 .51127 .5408 Mtetra
.087 0 0 r
.51127 .5408 .51449 .54104 .52035 .54154 .51715 .54139 Mtetra
.107 0 0 r
.51715 .54139 .52035 .54154 .52624 .54203 .52304 .54197 Mtetra
.125 0 0 r
.52304 .54197 .52624 .54203 .53214 .54253 .52896 .54256 Mtetra
.143 0 0 r
.52896 .54256 .53214 .54253 .53806 .54303 .53489 .54315 Mtetra
.162 0 0 r
.53489 .54315 .53806 .54303 .54401 .54353 .54085 .54375 Mtetra
.178 0 0 r
.54085 .54375 .54401 .54353 .54998 .54404 .54683 .54434 Mtetra
.195 0 0 r
.54683 .54434 .54998 .54404 .55596 .54454 .55283 .54494 Mtetra
.212 0 0 r
.55283 .54494 .55596 .54454 .56197 .54506 .55885 .54555 Mtetra
.227 0 0 r
.55885 .54555 .56197 .54506 .568 .54557 .5649 .54616 Mtetra
.24 0 0 r
.5649 .54616 .568 .54557 .57405 .54608 .57096 .54676 Mtetra
.253 0 0 r
.57096 .54676 .57405 .54608 .58013 .54659 .57705 .54735 Mtetra
.262 0 0 r
.57705 .54735 .58013 .54659 .58622 .54706 .58316 .54793 Mtetra
.255 0 0 r
.58316 .54793 .58622 .54706 .59233 .54744 .58929 .54839 Mtetra
.225 0 0 r
.58929 .54839 .59233 .54744 .59846 .54757 .59544 .5486 Mtetra
0 0 0 r
.59544 .5486 .59846 .54757 .60458 .54612 .60157 .54716 Mtetra
.562 .929 .782 r
.60157 .54716 .60458 .54612 .61064 .54234 .60765 .54329 Mtetra
.608 .95 .801 r
.60765 .54329 .61064 .54234 .61671 .53834 .61374 .5392 Mtetra
.64 .963 .816 r
.61374 .5392 .61671 .53834 .62278 .53421 .61982 .53496 Mtetra
.66 .971 .829 r
.61982 .53496 .62278 .53421 .62886 .53003 .62591 .53068 Mtetra
.674 .976 .841 r
.62591 .53068 .62886 .53003 .63493 .52584 .63201 .52638 Mtetra
.687 .98 .852 r
.63201 .52638 .63493 .52584 .64102 .52164 .63811 .52208 Mtetra
.699 .983 .862 r
.63811 .52208 .64102 .52164 .64711 .51743 .64421 .51777 Mtetra
.709 .986 .871 r
.64421 .51777 .64711 .51743 .6532 .51323 .65032 .51346 Mtetra
.719 .987 .88 r
.65032 .51346 .6532 .51323 .6593 .50902 .65643 .50915 Mtetra
.729 .987 .887 r
.65643 .50915 .6593 .50902 .6654 .50481 .66255 .50483 Mtetra
.737 .987 .894 r
.66255 .50483 .6654 .50481 .67151 .50059 .66867 .50051 Mtetra
.745 .986 .9 r
.66867 .50051 .67151 .50059 .67762 .49638 .67479 .49619 Mtetra
.752 .985 .905 r
.67479 .49619 .67762 .49638 .68374 .49216 .68092 .49187 Mtetra
.759 .982 .909 r
.68092 .49187 .68374 .49216 .68986 .48794 .68706 .48755 Mtetra
.765 .98 .913 r
.68706 .48755 .68986 .48794 .69599 .48371 .6932 .48322 Mtetra
.77 .976 .916 r
.6932 .48322 .69599 .48371 .70212 .47949 .69934 .47889 Mtetra
.775 .973 .919 r
.69934 .47889 .70212 .47949 .70826 .47525 .70549 .47455 Mtetra
.779 .969 .921 r
.70549 .47455 .70826 .47525 .7144 .47102 .71165 .47022 Mtetra
.782 .964 .922 r
.71165 .47022 .7144 .47102 .72054 .46678 .71781 .46588 Mtetra
.786 .959 .923 r
.71781 .46588 .72054 .46678 .7267 .46255 .72397 .46154 Mtetra
.789 .954 .924 r
.72397 .46154 .7267 .46255 .73285 .4583 .73014 .45719 Mtetra
.791 .949 .924 r
.73014 .45719 .73285 .4583 .73902 .45405 .73631 .45284 Mtetra
.793 .943 .924 r
.73631 .45284 .73902 .45405 .74518 .44981 .74249 .44849 Mtetra
.795 .938 .923 r
.74249 .44849 .74518 .44981 .75136 .44555 .74867 .44414 Mtetra
.796 .932 .922 r
.74867 .44414 .75136 .44555 .75753 .4413 .75485 .43978 Mtetra
.797 .926 .921 r
.75485 .43978 .75753 .4413 .76371 .43704 .76105 .43542 Mtetra
.798 .92 .92 r
.76105 .43542 .76371 .43704 .7699 .43277 .76724 .43106 Mtetra
.798 .913 .918 r
.76724 .43106 .7699 .43277 .77609 .42851 .77344 .42669 Mtetra
.798 .907 .916 r
.77344 .42669 .77609 .42851 .78229 .42424 .77965 .42232 Mtetra
.798 .901 .914 r
.77965 .42232 .78229 .42424 .78849 .41996 .78586 .41794 Mtetra
.798 .895 .912 r
.78586 .41794 .78849 .41996 .7947 .41568 .79207 .41356 Mtetra
.798 .888 .91 r
.79207 .41356 .7947 .41568 .80091 .4114 .79829 .40918 Mtetra
.798 .882 .907 r
.79829 .40918 .80091 .4114 .80713 .40712 .80452 .4048 Mtetra
.797 .875 .905 r
.80452 .4048 .80713 .40712 .81335 .40283 .81074 .40041 Mtetra
.796 .869 .902 r
.81074 .40041 .81335 .40283 .81958 .39853 .81698 .39601 Mtetra
.795 .863 .899 r
.81698 .39601 .81958 .39853 .82581 .39423 .82322 .39161 Mtetra
.794 .857 .896 r
.82322 .39161 .82581 .39423 .83205 .38993 .82946 .38721 Mtetra
.793 .85 .893 r
.82946 .38721 .83205 .38993 .83829 .38563 .83571 .38281 Mtetra
.792 .844 .891 r
.83571 .38281 .83829 .38563 .84454 .38131 .84196 .3784 Mtetra
.791 .838 .888 r
.84196 .3784 .84454 .38131 .85079 .377 .84821 .37398 Mtetra
.79 .832 .885 r
.84821 .37398 .85079 .377 .85704 .37268 .85447 .36957 Mtetra
.789 .826 .882 r
.85447 .36957 .85704 .37268 .86331 .36836 .86074 .36514 Mtetra
.787 .82 .879 r
.86074 .36514 .86331 .36836 .86957 .36403 .86701 .36072 Mtetra
.785 .815 .876 r
.86701 .36072 .86957 .36403 .87585 .35971 .87329 .35629 Mtetra
.784 .809 .873 r
.87329 .35629 .87585 .35971 .88212 .35538 .87957 .35186 Mtetra
.781 .803 .87 r
.87957 .35186 .88212 .35538 .88841 .35107 .88586 .34746 Mtetra
.777 .797 .869 r
.88586 .34746 .88841 .35107 .89471 .34684 .89216 .34313 Mtetra
.77 .79 .87 r
.89216 .34313 .89471 .34684 .90103 .34273 .89848 .33893 Mtetra
.759 .782 .872 r
.89848 .33893 .90103 .34273 .90738 .33882 .90484 .33495 Mtetra
.509 .691 .95 r
.31462 .51955 .31802 .5227 .32326 .52256 .31987 .51946 Mtetra
.447 .67 .958 r
.31987 .51946 .32326 .52256 .3285 .52283 .32511 .5198 Mtetra
.418 .662 .961 r
.32511 .5198 .3285 .52283 .33375 .52324 .33035 .52028 Mtetra
.4 .66 .964 r
.33035 .52028 .33375 .52324 .33901 .52372 .33561 .52084 Mtetra
.386 .659 .966 r
.33561 .52084 .33901 .52372 .34428 .52424 .34089 .52144 Mtetra
.375 .66 .969 r
.34089 .52144 .34428 .52424 .34958 .52477 .34618 .52205 Mtetra
.367 .663 .971 r
.34618 .52205 .34958 .52477 .35489 .5253 .35149 .52266 Mtetra
.357 .665 .973 r
.35149 .52266 .35489 .5253 .36022 .52583 .35682 .52328 Mtetra
.347 .667 .974 r
.35682 .52328 .36022 .52583 .36556 .52637 .36217 .52389 Mtetra
.337 .668 .975 r
.36217 .52389 .36556 .52637 .37093 .5269 .36754 .52451 Mtetra
.327 .67 .976 r
.36754 .52451 .37093 .5269 .37631 .52744 .37293 .52513 Mtetra
.315 .67 .975 r
.37293 .52513 .37631 .52744 .38172 .52798 .37833 .52575 Mtetra
.303 .671 .974 r
.37833 .52575 .38172 .52798 .38714 .52852 .38375 .52638 Mtetra
.291 .671 .973 r
.38375 .52638 .38714 .52852 .39258 .52906 .3892 .527 Mtetra
.277 .67 .97 r
.3892 .527 .39258 .52906 .39803 .5296 .39466 .52762 Mtetra
.263 .669 .967 r
.39466 .52762 .39803 .5296 .40351 .53015 .40014 .52825 Mtetra
.249 .667 .963 r
.40014 .52825 .40351 .53015 .40901 .53069 .40564 .52888 Mtetra
.234 .665 .958 r
.40564 .52888 .40901 .53069 .41452 .53123 .41116 .52951 Mtetra
.217 .662 .951 r
.41116 .52951 .41452 .53123 .42006 .53178 .4167 .53014 Mtetra
.201 .658 .944 r
.4167 .53014 .42006 .53178 .42561 .53233 .42225 .53078 Mtetra
.185 .654 .936 r
.42225 .53078 .42561 .53233 .43118 .53288 .42783 .53141 Mtetra
.167 .648 .926 r
.42783 .53141 .43118 .53288 .43677 .53344 .43343 .53205 Mtetra
.148 .641 .915 r
.43343 .53205 .43677 .53344 .44238 .53399 .43905 .53269 Mtetra
.13 .634 .903 r
.43905 .53269 .44238 .53399 .44801 .53455 .44468 .53333 Mtetra
.111 .627 .89 r
.44468 .53333 .44801 .53455 .45367 .5351 .45034 .53398 Mtetra
.091 .617 .875 r
.45034 .53398 .45367 .5351 .45934 .53566 .45602 .53462 Mtetra
.072 .607 .859 r
.45602 .53462 .45934 .53566 .46503 .53623 .46171 .53527 Mtetra
.052 .597 .842 r
.46171 .53527 .46503 .53623 .47074 .53679 .46743 .53592 Mtetra
.032 .585 .823 r
.46743 .53592 .47074 .53679 .47647 .53736 .47317 .53658 Mtetra
.011 .573 .804 r
.47317 .53658 .47647 .53736 .48222 .53793 .47893 .53724 Mtetra
0 .56 .783 r
.47893 .53724 .48222 .53793 .48799 .5385 .48471 .53789 Mtetra
0 .546 .762 r
.48471 .53789 .48799 .5385 .49378 .53907 .49051 .53856 Mtetra
0 .531 .739 r
.49051 .53856 .49378 .53907 .49959 .53964 .49633 .53922 Mtetra
0 .517 .716 r
.49633 .53922 .49959 .53964 .50542 .54022 .50217 .53989 Mtetra
.088 0 0 r
.50217 .53989 .50542 .54022 .51127 .5408 .50803 .54056 Mtetra
.108 0 0 r
.50803 .54056 .51127 .5408 .51715 .54139 .51392 .54123 Mtetra
.127 0 0 r
.51392 .54123 .51715 .54139 .52304 .54197 .51983 .54191 Mtetra
.145 0 0 r
.51983 .54191 .52304 .54197 .52896 .54256 .52575 .54259 Mtetra
.163 0 0 r
.52575 .54259 .52896 .54256 .53489 .54315 .5317 .54327 Mtetra
.181 0 0 r
.5317 .54327 .53489 .54315 .54085 .54375 .53767 .54396 Mtetra
.197 0 0 r
.53767 .54396 .54085 .54375 .54683 .54434 .54366 .54465 Mtetra
.213 0 0 r
.54366 .54465 .54683 .54434 .55283 .54494 .54968 .54534 Mtetra
.23 0 0 r
.54968 .54534 .55283 .54494 .55885 .54555 .55572 .54604 Mtetra
.245 0 0 r
.55572 .54604 .55885 .54555 .5649 .54616 .56177 .54674 Mtetra
.257 0 0 r
.56177 .54674 .5649 .54616 .57096 .54676 .56786 .54744 Mtetra
.269 0 0 r
.56786 .54744 .57096 .54676 .57705 .54735 .57396 .54813 Mtetra
.277 0 0 r
.57396 .54813 .57705 .54735 .58316 .54793 .58008 .5488 Mtetra
.27 0 0 r
.58008 .5488 .58316 .54793 .58929 .54839 .58623 .54934 Mtetra
.238 0 0 r
.58623 .54934 .58929 .54839 .59544 .5486 .59239 .54964 Mtetra
0 0 0 r
.59239 .54964 .59544 .5486 .60157 .54716 .59854 .54821 Mtetra
.573 .933 .784 r
.59854 .54821 .60157 .54716 .60765 .54329 .60464 .54425 Mtetra
.619 .954 .802 r
.60464 .54425 .60765 .54329 .61374 .5392 .61074 .54006 Mtetra
.651 .967 .817 r
.61074 .54006 .61374 .5392 .61982 .53496 .61685 .53572 Mtetra
.671 .975 .83 r
.61685 .53572 .61982 .53496 .62591 .53068 .62295 .53133 Mtetra
.684 .979 .841 r
.62295 .53133 .62591 .53068 .63201 .52638 .62906 .52693 Mtetra
.696 .983 .852 r
.62906 .52693 .63201 .52638 .63811 .52208 .63518 .52252 Mtetra
.708 .986 .861 r
.63518 .52252 .63811 .52208 .64421 .51777 .6413 .51811 Mtetra
.719 .988 .87 r
.6413 .51811 .64421 .51777 .65032 .51346 .64742 .51369 Mtetra
.728 .989 .878 r
.64742 .51369 .65032 .51346 .65643 .50915 .65355 .50927 Mtetra
.737 .989 .885 r
.65355 .50927 .65643 .50915 .66255 .50483 .65968 .50485 Mtetra
.745 .988 .892 r
.65968 .50485 .66255 .50483 .66867 .50051 .66581 .50043 Mtetra
.753 .987 .897 r
.66581 .50043 .66867 .50051 .67479 .49619 .67195 .49601 Mtetra
.759 .986 .902 r
.67195 .49601 .67479 .49619 .68092 .49187 .6781 .49158 Mtetra
.766 .983 .907 r
.6781 .49158 .68092 .49187 .68706 .48755 .68424 .48715 Mtetra
.771 .98 .91 r
.68424 .48715 .68706 .48755 .6932 .48322 .6904 .48272 Mtetra
.776 .977 .913 r
.6904 .48272 .6932 .48322 .69934 .47889 .69655 .47829 Mtetra
.781 .973 .916 r
.69655 .47829 .69934 .47889 .70549 .47455 .70272 .47385 Mtetra
.785 .969 .918 r
.70272 .47385 .70549 .47455 .71165 .47022 .70888 .46941 Mtetra
.788 .965 .919 r
.70888 .46941 .71165 .47022 .71781 .46588 .71505 .46497 Mtetra
.791 .96 .92 r
.71505 .46497 .71781 .46588 .72397 .46154 .72123 .46053 Mtetra
.794 .955 .92 r
.72123 .46053 .72397 .46154 .73014 .45719 .7274 .45608 Mtetra
.796 .949 .921 r
.7274 .45608 .73014 .45719 .73631 .45284 .73359 .45163 Mtetra
.798 .944 .92 r
.73359 .45163 .73631 .45284 .74249 .44849 .73978 .44718 Mtetra
.8 .938 .92 r
.73978 .44718 .74249 .44849 .74867 .44414 .74597 .44272 Mtetra
.801 .932 .919 r
.74597 .44272 .74867 .44414 .75485 .43978 .75216 .43826 Mtetra
.802 .926 .918 r
.75216 .43826 .75485 .43978 .76105 .43542 .75836 .4338 Mtetra
.802 .92 .916 r
.75836 .4338 .76105 .43542 .76724 .43106 .76457 .42933 Mtetra
.803 .914 .915 r
.76457 .42933 .76724 .43106 .77344 .42669 .77078 .42486 Mtetra
.803 .908 .913 r
.77078 .42486 .77344 .42669 .77965 .42232 .77699 .42039 Mtetra
.803 .901 .911 r
.77699 .42039 .77965 .42232 .78586 .41794 .78321 .41591 Mtetra
.803 .895 .909 r
.78321 .41591 .78586 .41794 .79207 .41356 .78943 .41143 Mtetra
.802 .889 .907 r
.78943 .41143 .79207 .41356 .79829 .40918 .79566 .40695 Mtetra
.802 .882 .904 r
.79566 .40695 .79829 .40918 .80452 .4048 .80189 .40246 Mtetra
.801 .876 .902 r
.80189 .40246 .80452 .4048 .81074 .40041 .80812 .39797 Mtetra
.8 .87 .899 r
.80812 .39797 .81074 .40041 .81698 .39601 .81436 .39348 Mtetra
.799 .863 .896 r
.81436 .39348 .81698 .39601 .82322 .39161 .82061 .38898 Mtetra
.798 .857 .894 r
.82061 .38898 .82322 .39161 .82946 .38721 .82686 .38448 Mtetra
.797 .851 .891 r
.82686 .38448 .82946 .38721 .83571 .38281 .83311 .37997 Mtetra
.796 .845 .888 r
.83311 .37997 .83571 .38281 .84196 .3784 .83937 .37546 Mtetra
.795 .839 .885 r
.83937 .37546 .84196 .3784 .84821 .37398 .84563 .37095 Mtetra
.793 .833 .882 r
.84563 .37095 .84821 .37398 .85447 .36957 .85189 .36643 Mtetra
.792 .827 .879 r
.85189 .36643 .85447 .36957 .86074 .36514 .85816 .36191 Mtetra
.79 .821 .876 r
.85816 .36191 .86074 .36514 .86701 .36072 .86444 .35739 Mtetra
.789 .815 .873 r
.86444 .35739 .86701 .36072 .87329 .35629 .87072 .35286 Mtetra
.787 .81 .87 r
.87072 .35286 .87329 .35629 .87957 .35186 .877 .34834 Mtetra
.785 .804 .868 r
.877 .34834 .87957 .35186 .88586 .34746 .88329 .34384 Mtetra
.78 .798 .867 r
.88329 .34384 .88586 .34746 .89216 .34313 .8896 .33941 Mtetra
.773 .791 .868 r
.8896 .33941 .89216 .34313 .89848 .33893 .89592 .33512 Mtetra
.762 .783 .87 r
.89592 .33512 .89848 .33893 .90484 .33495 .90228 .33105 Mtetra
.501 .688 .951 r
.31121 .51638 .31462 .51955 .31987 .51946 .31646 .51635 Mtetra
.436 .665 .958 r
.31646 .51635 .31987 .51946 .32511 .5198 .3217 .51675 Mtetra
.405 .656 .961 r
.3217 .51675 .32511 .5198 .33035 .52028 .32695 .51731 Mtetra
.386 .653 .963 r
.32695 .51731 .33035 .52028 .33561 .52084 .33221 .51795 Mtetra
.371 .652 .965 r
.33221 .51795 .33561 .52084 .34089 .52144 .33748 .51863 Mtetra
.36 .653 .967 r
.33748 .51863 .34089 .52144 .34618 .52205 .34278 .51932 Mtetra
.351 .655 .969 r
.34278 .51932 .34618 .52205 .35149 .52266 .34809 .52001 Mtetra
.341 .657 .971 r
.34809 .52001 .35149 .52266 .35682 .52328 .35342 .52071 Mtetra
.33 .658 .972 r
.35342 .52071 .35682 .52328 .36217 .52389 .35877 .52141 Mtetra
.32 .659 .972 r
.35877 .52141 .36217 .52389 .36754 .52451 .36414 .52211 Mtetra
.309 .661 .973 r
.36414 .52211 .36754 .52451 .37293 .52513 .36952 .52281 Mtetra
.296 .661 .972 r
.36952 .52281 .37293 .52513 .37833 .52575 .37493 .52352 Mtetra
.284 .661 .97 r
.37493 .52352 .37833 .52575 .38375 .52638 .38036 .52422 Mtetra
.272 .661 .968 r
.38036 .52422 .38375 .52638 .3892 .527 .3858 .52493 Mtetra
.258 .659 .965 r
.3858 .52493 .3892 .527 .39466 .52762 .39127 .52564 Mtetra
.243 .657 .961 r
.39127 .52564 .39466 .52762 .40014 .52825 .39675 .52635 Mtetra
.228 .655 .957 r
.39675 .52635 .40014 .52825 .40564 .52888 .40225 .52706 Mtetra
.213 .653 .951 r
.40225 .52706 .40564 .52888 .41116 .52951 .40778 .52777 Mtetra
.196 .649 .944 r
.40778 .52777 .41116 .52951 .4167 .53014 .41332 .52849 Mtetra
.179 .644 .936 r
.41332 .52849 .4167 .53014 .42225 .53078 .41888 .52921 Mtetra
.163 .64 .927 r
.41888 .52921 .42225 .53078 .42783 .53141 .42446 .52993 Mtetra
.145 .633 .917 r
.42446 .52993 .42783 .53141 .43343 .53205 .43007 .53066 Mtetra
.126 .626 .905 r
.43007 .53066 .43343 .53205 .43905 .53269 .43569 .53139 Mtetra
.107 .619 .893 r
.43569 .53139 .43905 .53269 .44468 .53333 .44133 .53211 Mtetra
.088 .611 .879 r
.44133 .53211 .44468 .53333 .45034 .53398 .447 .53284 Mtetra
.068 .601 .863 r
.447 .53284 .45034 .53398 .45602 .53462 .45268 .53358 Mtetra
.049 .591 .846 r
.45268 .53358 .45602 .53462 .46171 .53527 .45839 .53432 Mtetra
.029 .58 .829 r
.45839 .53432 .46171 .53527 .46743 .53592 .46411 .53506 Mtetra
.008 .568 .81 r
.46411 .53506 .46743 .53592 .47317 .53658 .46986 .5358 Mtetra
0 .555 .79 r
.46986 .5358 .47317 .53658 .47893 .53724 .47562 .53655 Mtetra
0 .542 .769 r
.47562 .53655 .47893 .53724 .48471 .53789 .48141 .53729 Mtetra
0 .528 .747 r
.48141 .53729 .48471 .53789 .49051 .53856 .48722 .53804 Mtetra
0 .513 .724 r
.48722 .53804 .49051 .53856 .49633 .53922 .49305 .5388 Mtetra
.091 0 0 r
.49305 .5388 .49633 .53922 .50217 .53989 .4989 .53956 Mtetra
.11 0 0 r
.4989 .53956 .50217 .53989 .50803 .54056 .50478 .54032 Mtetra
.13 0 0 r
.50478 .54032 .50803 .54056 .51392 .54123 .51067 .54108 Mtetra
.148 0 0 r
.51067 .54108 .51392 .54123 .51983 .54191 .51659 .54185 Mtetra
.165 0 0 r
.51659 .54185 .51983 .54191 .52575 .54259 .52253 .54262 Mtetra
.183 0 0 r
.52253 .54262 .52575 .54259 .5317 .54327 .52849 .5434 Mtetra
.2 0 0 r
.52849 .5434 .5317 .54327 .53767 .54396 .53447 .54418 Mtetra
.216 0 0 r
.53447 .54418 .53767 .54396 .54366 .54465 .54048 .54496 Mtetra
.231 0 0 r
.54048 .54496 .54366 .54465 .54968 .54534 .54651 .54575 Mtetra
.247 0 0 r
.54651 .54575 .54968 .54534 .55572 .54604 .55256 .54654 Mtetra
.262 0 0 r
.55256 .54654 .55572 .54604 .56177 .54674 .55863 .54734 Mtetra
.274 0 0 r
.55863 .54734 .56177 .54674 .56786 .54744 .56473 .54813 Mtetra
.285 0 0 r
.56473 .54813 .56786 .54744 .57396 .54813 .57085 .54891 Mtetra
.293 0 0 r
.57085 .54891 .57396 .54813 .58008 .5488 .57699 .54967 Mtetra
.285 0 0 r
.57699 .54967 .58008 .5488 .58623 .54934 .58315 .55031 Mtetra
.252 0 0 r
.58315 .55031 .58623 .54934 .59239 .54964 .58933 .55068 Mtetra
0 0 0 r
.58933 .55068 .59239 .54964 .59854 .54821 .59549 .54927 Mtetra
.584 .938 .786 r
.59549 .54927 .59854 .54821 .60464 .54425 .60161 .54522 Mtetra
.63 .958 .803 r
.60161 .54522 .60464 .54425 .61074 .54006 .60773 .54093 Mtetra
.662 .971 .818 r
.60773 .54093 .61074 .54006 .61685 .53572 .61385 .53649 Mtetra
.681 .978 .83 r
.61385 .53649 .61685 .53572 .62295 .53133 .61997 .53199 Mtetra
.694 .982 .841 r
.61997 .53199 .62295 .53133 .62906 .52693 .6261 .52748 Mtetra
.706 .985 .851 r
.6261 .52748 .62906 .52693 .63518 .52252 .63223 .52297 Mtetra
.718 .988 .86 r
.63223 .52297 .63518 .52252 .6413 .51811 .63836 .51845 Mtetra
.727 .989 .869 r
.63836 .51845 .6413 .51811 .64742 .51369 .6445 .51393 Mtetra
.736 .99 .876 r
.6445 .51393 .64742 .51369 .65355 .50927 .65064 .50941 Mtetra
.745 .99 .883 r
.65064 .50941 .65355 .50927 .65968 .50485 .65679 .50488 Mtetra
.753 .99 .89 r
.65679 .50488 .65968 .50485 .66581 .50043 .66294 .50035 Mtetra
.76 .988 .895 r
.66294 .50035 .66581 .50043 .67195 .49601 .66909 .49583 Mtetra
.767 .986 .9 r
.66909 .49583 .67195 .49601 .6781 .49158 .67525 .4913 Mtetra
.773 .984 .904 r
.67525 .4913 .6781 .49158 .68424 .48715 .68141 .48676 Mtetra
.778 .981 .907 r
.68141 .48676 .68424 .48715 .6904 .48272 .68758 .48223 Mtetra
.783 .978 .91 r
.68758 .48223 .6904 .48272 .69655 .47829 .69375 .47769 Mtetra
.787 .974 .913 r
.69375 .47769 .69655 .47829 .70272 .47385 .69992 .47315 Mtetra
.791 .969 .914 r
.69992 .47315 .70272 .47385 .70888 .46941 .7061 .4686 Mtetra
.794 .965 .916 r
.7061 .4686 .70888 .46941 .71505 .46497 .71228 .46406 Mtetra
.797 .96 .917 r
.71228 .46406 .71505 .46497 .72123 .46053 .71847 .45951 Mtetra
.8 .955 .917 r
.71847 .45951 .72123 .46053 .7274 .45608 .72466 .45496 Mtetra
.802 .95 .917 r
.72466 .45496 .7274 .45608 .73359 .45163 .73085 .45041 Mtetra
.803 .944 .917 r
.73085 .45041 .73359 .45163 .73978 .44718 .73705 .44585 Mtetra
.805 .938 .917 r
.73705 .44585 .73978 .44718 .74597 .44272 .74325 .44129 Mtetra
.806 .932 .916 r
.74325 .44129 .74597 .44272 .75216 .43826 .74946 .43673 Mtetra
.806 .926 .915 r
.74946 .43673 .75216 .43826 .75836 .4338 .75567 .43217 Mtetra
.807 .92 .913 r
.75567 .43217 .75836 .4338 .76457 .42933 .76188 .4276 Mtetra
.807 .914 .912 r
.76188 .4276 .76457 .42933 .77078 .42486 .7681 .42303 Mtetra
.807 .908 .91 r
.7681 .42303 .77078 .42486 .77699 .42039 .77432 .41845 Mtetra
.807 .902 .908 r
.77432 .41845 .77699 .42039 .78321 .41591 .78055 .41388 Mtetra
.807 .895 .906 r
.78055 .41388 .78321 .41591 .78943 .41143 .78678 .40929 Mtetra
.807 .889 .904 r
.78678 .40929 .78943 .41143 .79566 .40695 .79301 .40471 Mtetra
.806 .883 .901 r
.79301 .40471 .79566 .40695 .80189 .40246 .79925 .40012 Mtetra
.805 .876 .899 r
.79925 .40012 .80189 .40246 .80812 .39797 .80549 .39553 Mtetra
.804 .87 .896 r
.80549 .39553 .80812 .39797 .81436 .39348 .81174 .39093 Mtetra
.803 .864 .894 r
.81174 .39093 .81436 .39348 .82061 .38898 .81799 .38634 Mtetra
.802 .858 .891 r
.81799 .38634 .82061 .38898 .82686 .38448 .82424 .38174 Mtetra
.801 .852 .888 r
.82424 .38174 .82686 .38448 .83311 .37997 .8305 .37713 Mtetra
.8 .846 .885 r
.8305 .37713 .83311 .37997 .83937 .37546 .83676 .37252 Mtetra
.798 .84 .883 r
.83676 .37252 .83937 .37546 .84563 .37095 .84303 .36791 Mtetra
.797 .834 .88 r
.84303 .36791 .84563 .37095 .85189 .36643 .8493 .36329 Mtetra
.796 .828 .877 r
.8493 .36329 .85189 .36643 .85816 .36191 .85557 .35866 Mtetra
.794 .822 .874 r
.85557 .35866 .85816 .36191 .86444 .35739 .86185 .35404 Mtetra
.792 .816 .871 r
.86185 .35404 .86444 .35739 .87072 .35286 .86814 .34942 Mtetra
.791 .811 .868 r
.86814 .34942 .87072 .35286 .877 .34834 .87442 .34479 Mtetra
.788 .805 .866 r
.87442 .34479 .877 .34834 .88329 .34384 .88072 .34019 Mtetra
.783 .799 .865 r
.88072 .34019 .88329 .34384 .8896 .33941 .88703 .33568 Mtetra
.776 .792 .866 r
.88703 .33568 .8896 .33941 .89592 .33512 .89335 .3313 Mtetra
.765 .784 .869 r
.89335 .3313 .89592 .33512 .90228 .33105 .89972 .32715 Mtetra
.493 .685 .952 r
.30779 .5132 .31121 .51638 .31646 .51635 .31304 .51322 Mtetra
.424 .659 .958 r
.31304 .51322 .31646 .51635 .3217 .51675 .31828 .51369 Mtetra
.392 .65 .96 r
.31828 .51369 .3217 .51675 .32695 .51731 .32353 .51433 Mtetra
.371 .646 .962 r
.32353 .51433 .32695 .51731 .33221 .51795 .32879 .51505 Mtetra
.355 .644 .964 r
.32879 .51505 .33221 .51795 .33748 .51863 .33406 .51581 Mtetra
.344 .645 .966 r
.33406 .51581 .33748 .51863 .34278 .51932 .33935 .51658 Mtetra
.335 .647 .968 r
.33935 .51658 .34278 .51932 .34809 .52001 .34467 .51735 Mtetra
.324 .648 .969 r
.34467 .51735 .34809 .52001 .35342 .52071 .35 .51813 Mtetra
.313 .649 .969 r
.35 .51813 .35342 .52071 .35877 .52141 .35535 .51892 Mtetra
.302 .65 .969 r
.35535 .51892 .35877 .52141 .36414 .52211 .36072 .5197 Mtetra
.291 .651 .969 r
.36072 .5197 .36414 .52211 .36952 .52281 .36611 .52048 Mtetra
.278 .651 .968 r
.36611 .52048 .36952 .52281 .37493 .52352 .37152 .52127 Mtetra
.265 .65 .966 r
.37152 .52127 .37493 .52352 .38036 .52422 .37694 .52206 Mtetra
.252 .65 .964 r
.37694 .52206 .38036 .52422 .3858 .52493 .38239 .52285 Mtetra
.238 .648 .96 r
.38239 .52285 .3858 .52493 .39127 .52564 .38786 .52364 Mtetra
.223 .646 .956 r
.38786 .52364 .39127 .52564 .39675 .52635 .39335 .52444 Mtetra
.208 .643 .95 r
.39335 .52444 .39675 .52635 .40225 .52706 .39885 .52523 Mtetra
.192 .64 .944 r
.39885 .52523 .40225 .52706 .40778 .52777 .40438 .52603 Mtetra
.175 .635 .937 r
.40438 .52603 .40778 .52777 .41332 .52849 .40993 .52684 Mtetra
.158 .631 .928 r
.40993 .52684 .41332 .52849 .41888 .52921 .41549 .52764 Mtetra
.141 .625 .919 r
.41549 .52764 .41888 .52921 .42446 .52993 .42108 .52845 Mtetra
.123 .619 .907 r
.42108 .52845 .42446 .52993 .43007 .53066 .42669 .52926 Mtetra
.104 .611 .895 r
.42669 .52926 .43007 .53066 .43569 .53139 .43232 .53007 Mtetra
.085 .604 .882 r
.43232 .53007 .43569 .53139 .44133 .53211 .43797 .53089 Mtetra
.066 .595 .867 r
.43797 .53089 .44133 .53211 .447 .53284 .44364 .5317 Mtetra
.046 .584 .851 r
.44364 .5317 .447 .53284 .45268 .53358 .44933 .53253 Mtetra
.026 .574 .834 r
.44933 .53253 .45268 .53358 .45839 .53432 .45504 .53335 Mtetra
.007 .563 .816 r
.45504 .53335 .45839 .53432 .46411 .53506 .46077 .53418 Mtetra
0 .55 .797 r
.46077 .53418 .46411 .53506 .46986 .5358 .46653 .53501 Mtetra
0 .537 .776 r
.46653 .53501 .46986 .5358 .47562 .53655 .4723 .53585 Mtetra
0 .524 .755 r
.4723 .53585 .47562 .53655 .48141 .53729 .4781 .53668 Mtetra
0 .51 .733 r
.4781 .53668 .48141 .53729 .48722 .53804 .48392 .53753 Mtetra
0 .495 .71 r
.48392 .53753 .48722 .53804 .49305 .5388 .48976 .53837 Mtetra
.112 0 0 r
.48976 .53837 .49305 .5388 .4989 .53956 .49562 .53922 Mtetra
.13 0 0 r
.49562 .53922 .4989 .53956 .50478 .54032 .5015 .54007 Mtetra
.149 0 0 r
.5015 .54007 .50478 .54032 .51067 .54108 .50741 .54093 Mtetra
.168 0 0 r
.50741 .54093 .51067 .54108 .51659 .54185 .51334 .54179 Mtetra
.184 0 0 r
.51334 .54179 .51659 .54185 .52253 .54262 .51929 .54265 Mtetra
.201 0 0 r
.51929 .54265 .52253 .54262 .52849 .5434 .52526 .54352 Mtetra
.218 0 0 r
.52526 .54352 .52849 .5434 .53447 .54418 .53126 .5444 Mtetra
.233 0 0 r
.53126 .5444 .53447 .54418 .54048 .54496 .53727 .54527 Mtetra
.248 0 0 r
.53727 .54527 .54048 .54496 .54651 .54575 .54332 .54615 Mtetra
.264 0 0 r
.54332 .54615 .54651 .54575 .55256 .54654 .54938 .54704 Mtetra
.278 0 0 r
.54938 .54704 .55256 .54654 .55863 .54734 .55547 .54793 Mtetra
.289 0 0 r
.55547 .54793 .55863 .54734 .56473 .54813 .56158 .54882 Mtetra
.3 0 0 r
.56158 .54882 .56473 .54813 .57085 .54891 .56771 .5497 Mtetra
.307 0 0 r
.56771 .5497 .57085 .54891 .57699 .54967 .57387 .55055 Mtetra
.298 0 0 r
.57387 .55055 .57699 .54967 .58315 .55031 .58005 .55128 Mtetra
.264 0 0 r
.58005 .55128 .58315 .55031 .58933 .55068 .58624 .55173 Mtetra
0 0 0 r
.58624 .55173 .58933 .55068 .59549 .54927 .59242 .55034 Mtetra
.596 .943 .789 r
.59242 .55034 .59549 .54927 .60161 .54522 .59856 .54619 Mtetra
.642 .963 .805 r
.59856 .54619 .60161 .54522 .60773 .54093 .6047 .5418 Mtetra
.673 .974 .819 r
.6047 .5418 .60773 .54093 .61385 .53649 .61083 .53726 Mtetra
.692 .981 .83 r
.61083 .53726 .61385 .53649 .61997 .53199 .61697 .53265 Mtetra
.705 .985 .841 r
.61697 .53265 .61997 .53199 .6261 .52748 .62312 .52804 Mtetra
.716 .988 .851 r
.62312 .52804 .6261 .52748 .63223 .52297 .62926 .52342 Mtetra
.727 .99 .859 r
.62926 .52342 .63223 .52297 .63836 .51845 .63541 .51879 Mtetra
.737 .991 .868 r
.63541 .51879 .63836 .51845 .6445 .51393 .64157 .51416 Mtetra
.745 .991 .875 r
.64157 .51416 .6445 .51393 .65064 .50941 .64772 .50954 Mtetra
.753 .991 .882 r
.64772 .50954 .65064 .50941 .65679 .50488 .65388 .50491 Mtetra
.761 .99 .888 r
.65388 .50491 .65679 .50488 .66294 .50035 .66005 .50027 Mtetra
.768 .989 .893 r
.66005 .50027 .66294 .50035 .66909 .49583 .66622 .49564 Mtetra
.774 .987 .898 r
.66622 .49564 .66909 .49583 .67525 .4913 .67239 .491 Mtetra
.78 .984 .901 r
.67239 .491 .67525 .4913 .68141 .48676 .67856 .48636 Mtetra
.785 .981 .905 r
.67856 .48636 .68141 .48676 .68758 .48223 .68474 .48172 Mtetra
.789 .978 .908 r
.68474 .48172 .68758 .48223 .69375 .47769 .69092 .47708 Mtetra
.793 .974 .91 r
.69092 .47708 .69375 .47769 .69992 .47315 .69711 .47244 Mtetra
.797 .97 .911 r
.69711 .47244 .69992 .47315 .7061 .4686 .7033 .46779 Mtetra
.8 .965 .913 r
.7033 .46779 .7061 .4686 .71228 .46406 .70949 .46314 Mtetra
.802 .96 .914 r
.70949 .46314 .71228 .46406 .71847 .45951 .71569 .45849 Mtetra
.805 .955 .914 r
.71569 .45849 .71847 .45951 .72466 .45496 .72189 .45384 Mtetra
.807 .949 .914 r
.72189 .45384 .72466 .45496 .73085 .45041 .7281 .44918 Mtetra
.808 .944 .914 r
.7281 .44918 .73085 .45041 .73705 .44585 .73431 .44452 Mtetra
.81 .938 .913 r
.73431 .44452 .73705 .44585 .74325 .44129 .74052 .43986 Mtetra
.81 .932 .912 r
.74052 .43986 .74325 .44129 .74946 .43673 .74674 .43519 Mtetra
.811 .926 .911 r
.74674 .43519 .74946 .43673 .75567 .43217 .75296 .43053 Mtetra
.811 .92 .91 r
.75296 .43053 .75567 .43217 .76188 .4276 .75918 .42586 Mtetra
.812 .914 .908 r
.75918 .42586 .76188 .4276 .7681 .42303 .76541 .42118 Mtetra
.812 .908 .907 r
.76541 .42118 .7681 .42303 .77432 .41845 .77164 .4165 Mtetra
.811 .902 .905 r
.77164 .4165 .77432 .41845 .78055 .41388 .77787 .41183 Mtetra
.811 .895 .903 r
.77787 .41183 .78055 .41388 .78678 .40929 .78411 .40714 Mtetra
.811 .889 .901 r
.78411 .40714 .78678 .40929 .79301 .40471 .79035 .40245 Mtetra
.81 .883 .898 r
.79035 .40245 .79301 .40471 .79925 .40012 .7966 .39777 Mtetra
.809 .877 .896 r
.7966 .39777 .79925 .40012 .80549 .39553 .80285 .39307 Mtetra
.808 .871 .893 r
.80285 .39307 .80549 .39553 .81174 .39093 .8091 .38838 Mtetra
.807 .864 .891 r
.8091 .38838 .81174 .39093 .81799 .38634 .81536 .38368 Mtetra
.806 .858 .888 r
.81536 .38368 .81799 .38634 .82424 .38174 .82162 .37898 Mtetra
.805 .852 .885 r
.82162 .37898 .82424 .38174 .8305 .37713 .82788 .37427 Mtetra
.803 .846 .883 r
.82788 .37427 .8305 .37713 .83676 .37252 .83415 .36956 Mtetra
.802 .84 .88 r
.83415 .36956 .83676 .37252 .84303 .36791 .84042 .36485 Mtetra
.801 .834 .877 r
.84042 .36485 .84303 .36791 .8493 .36329 .8467 .36013 Mtetra
.799 .829 .874 r
.8467 .36013 .8493 .36329 .85557 .35866 .85297 .3554 Mtetra
.797 .823 .871 r
.85297 .3554 .85557 .35866 .86185 .35404 .85926 .35068 Mtetra
.796 .817 .869 r
.85926 .35068 .86185 .35404 .86814 .34942 .86554 .34596 Mtetra
.794 .811 .866 r
.86554 .34596 .86814 .34942 .87442 .34479 .87183 .34123 Mtetra
.791 .806 .864 r
.87183 .34123 .87442 .34479 .88072 .34019 .87813 .33654 Mtetra
.786 .799 .863 r
.87813 .33654 .88072 .34019 .88703 .33568 .88444 .33192 Mtetra
.779 .793 .864 r
.88444 .33192 .88703 .33568 .89335 .3313 .89077 .32745 Mtetra
.768 .785 .867 r
.89077 .32745 .89335 .3313 .89972 .32715 .89714 .32322 Mtetra
.485 .682 .953 r
.30436 .51 .30779 .5132 .31304 .51322 .30961 .51008 Mtetra
.413 .654 .958 r
.30961 .51008 .31304 .51322 .31828 .51369 .31485 .51063 Mtetra
.378 .643 .96 r
.31485 .51063 .31828 .51369 .32353 .51433 .32009 .51134 Mtetra
.356 .638 .961 r
.32009 .51134 .32353 .51433 .32879 .51505 .32535 .51213 Mtetra
.339 .636 .962 r
.32535 .51213 .32879 .51505 .33406 .51581 .33063 .51297 Mtetra
.327 .637 .964 r
.33063 .51297 .33406 .51581 .33935 .51658 .33592 .51383 Mtetra
.318 .639 .965 r
.33592 .51383 .33935 .51658 .34467 .51735 .34123 .51468 Mtetra
.307 .639 .966 r
.34123 .51468 .34467 .51735 .35 .51813 .34656 .51554 Mtetra
.295 .64 .966 r
.34656 .51554 .35 .51813 .35535 .51892 .35191 .51641 Mtetra
.284 .641 .966 r
.35191 .51641 .35535 .51892 .36072 .5197 .35729 .51727 Mtetra
.273 .641 .965 r
.35729 .51727 .36072 .5197 .36611 .52048 .36268 .51814 Mtetra
.259 .64 .963 r
.36268 .51814 .36611 .52048 .37152 .52127 .36809 .51901 Mtetra
.246 .639 .961 r
.36809 .51901 .37152 .52127 .37694 .52206 .37352 .51988 Mtetra
.233 .638 .958 r
.37352 .51988 .37694 .52206 .38239 .52285 .37897 .52076 Mtetra
.218 .636 .954 r
.37897 .52076 .38239 .52285 .38786 .52364 .38444 .52163 Mtetra
.202 .633 .949 r
.38444 .52163 .38786 .52364 .39335 .52444 .38993 .52251 Mtetra
.187 .631 .943 r
.38993 .52251 .39335 .52444 .39885 .52523 .39544 .5234 Mtetra
.171 .627 .937 r
.39544 .5234 .39885 .52523 .40438 .52603 .40097 .52428 Mtetra
.154 .622 .928 r
.40097 .52428 .40438 .52603 .40993 .52684 .40652 .52517 Mtetra
.136 .617 .919 r
.40652 .52517 .40993 .52684 .41549 .52764 .41209 .52606 Mtetra
.119 .611 .909 r
.41209 .52606 .41549 .52764 .42108 .52845 .41768 .52695 Mtetra
.1 .604 .897 r
.41768 .52695 .42108 .52845 .42669 .52926 .42329 .52785 Mtetra
.081 .596 .884 r
.42329 .52785 .42669 .52926 .43232 .53007 .42893 .52875 Mtetra
.063 .588 .871 r
.42893 .52875 .43232 .53007 .43797 .53089 .43458 .52965 Mtetra
.044 .578 .856 r
.43458 .52965 .43797 .53089 .44364 .5317 .44026 .53056 Mtetra
.023 .568 .839 r
.44026 .53056 .44364 .5317 .44933 .53253 .44596 .53147 Mtetra
.004 .557 .821 r
.44596 .53147 .44933 .53253 .45504 .53335 .45167 .53238 Mtetra
0 .546 .803 r
.45167 .53238 .45504 .53335 .46077 .53418 .45742 .5333 Mtetra
0 .533 .783 r
.45742 .5333 .46077 .53418 .46653 .53501 .46318 .53422 Mtetra
0 .519 .762 r
.46318 .53422 .46653 .53501 .4723 .53585 .46896 .53515 Mtetra
0 .506 .741 r
.46896 .53515 .4723 .53585 .4781 .53668 .47477 .53607 Mtetra
0 .492 .719 r
.47477 .53607 .4781 .53668 .48392 .53753 .48059 .537 Mtetra
.114 0 0 r
.48059 .537 .48392 .53753 .48976 .53837 .48644 .53794 Mtetra
.133 0 0 r
.48644 .53794 .48976 .53837 .49562 .53922 .49231 .53888 Mtetra
.151 0 0 r
.49231 .53888 .49562 .53922 .5015 .54007 .49821 .53982 Mtetra
.169 0 0 r
.49821 .53982 .5015 .54007 .50741 .54093 .50413 .54077 Mtetra
.187 0 0 r
.50413 .54077 .50741 .54093 .51334 .54179 .51006 .54173 Mtetra
.203 0 0 r
.51006 .54173 .51334 .54179 .51929 .54265 .51603 .54268 Mtetra
.22 0 0 r
.51603 .54268 .51929 .54265 .52526 .54352 .52201 .54364 Mtetra
.236 0 0 r
.52201 .54364 .52526 .54352 .53126 .5444 .52802 .54461 Mtetra
.251 0 0 r
.52802 .54461 .53126 .5444 .53727 .54527 .53405 .54558 Mtetra
.265 0 0 r
.53405 .54558 .53727 .54527 .54332 .54615 .5401 .54656 Mtetra
.28 0 0 r
.5401 .54656 .54332 .54615 .54938 .54704 .54618 .54754 Mtetra
.293 0 0 r
.54618 .54754 .54938 .54704 .55547 .54793 .55228 .54853 Mtetra
.304 0 0 r
.55228 .54853 .55547 .54793 .56158 .54882 .55841 .54951 Mtetra
.315 0 0 r
.55841 .54951 .56158 .54882 .56771 .5497 .56456 .55049 Mtetra
.321 0 0 r
.56456 .55049 .56771 .5497 .57387 .55055 .57073 .55144 Mtetra
.312 0 0 r
.57073 .55144 .57387 .55055 .58005 .55128 .57692 .55226 Mtetra
.277 0 0 r
.57692 .55226 .58005 .55128 .58624 .55173 .58314 .55279 Mtetra
0 0 0 r
.58314 .55279 .58624 .55173 .59242 .55034 .58934 .5514 Mtetra
.607 .948 .791 r
.58934 .5514 .59242 .55034 .59856 .54619 .59549 .54717 Mtetra
.653 .966 .807 r
.59549 .54717 .59856 .54619 .6047 .5418 .60164 .54268 Mtetra
.684 .978 .819 r
.60164 .54268 .6047 .5418 .61083 .53726 .6078 .53803 Mtetra
.703 .984 .83 r
.6078 .53803 .61083 .53726 .61697 .53265 .61395 .53332 Mtetra
.715 .987 .84 r
.61395 .53332 .61697 .53265 .62312 .52804 .62011 .5286 Mtetra
.726 .99 .85 r
.62011 .5286 .62312 .52804 .62926 .52342 .62628 .52387 Mtetra
.736 .992 .858 r
.62628 .52387 .62926 .52342 .63541 .51879 .63244 .51913 Mtetra
.745 .993 .866 r
.63244 .51913 .63541 .51879 .64157 .51416 .63861 .5144 Mtetra
.753 .993 .874 r
.63861 .5144 .64157 .51416 .64772 .50954 .64478 .50967 Mtetra
.761 .992 .88 r
.64478 .50967 .64772 .50954 .65388 .50491 .65096 .50493 Mtetra
.769 .991 .886 r
.65096 .50493 .65388 .50491 .66005 .50027 .65714 .50019 Mtetra
.775 .99 .891 r
.65714 .50019 .66005 .50027 .66622 .49564 .66332 .49545 Mtetra
.781 .987 .895 r
.66332 .49545 .66622 .49564 .67239 .491 .66951 .49071 Mtetra
.786 .985 .899 r
.66951 .49071 .67239 .491 .67856 .48636 .6757 .48596 Mtetra
.791 .981 .902 r
.6757 .48596 .67856 .48636 .68474 .48172 .68189 .48122 Mtetra
.795 .978 .905 r
.68189 .48122 .68474 .48172 .69092 .47708 .68808 .47647 Mtetra
.799 .974 .907 r
.68808 .47647 .69092 .47708 .69711 .47244 .69428 .47172 Mtetra
.803 .97 .908 r
.69428 .47172 .69711 .47244 .7033 .46779 .70049 .46697 Mtetra
.805 .965 .91 r
.70049 .46697 .7033 .46779 .70949 .46314 .70669 .46222 Mtetra
.808 .96 .91 r
.70669 .46222 .70949 .46314 .71569 .45849 .7129 .45746 Mtetra
.81 .955 .911 r
.7129 .45746 .71569 .45849 .72189 .45384 .71911 .4527 Mtetra
.812 .949 .911 r
.71911 .4527 .72189 .45384 .7281 .44918 .72533 .44794 Mtetra
.813 .944 .911 r
.72533 .44794 .7281 .44918 .73431 .44452 .73155 .44318 Mtetra
.814 .938 .91 r
.73155 .44318 .73431 .44452 .74052 .43986 .73777 .43841 Mtetra
.815 .932 .909 r
.73777 .43841 .74052 .43986 .74674 .43519 .744 .43364 Mtetra
.815 .926 .908 r
.744 .43364 .74674 .43519 .75296 .43053 .75023 .42887 Mtetra
.816 .92 .907 r
.75023 .42887 .75296 .43053 .75918 .42586 .75646 .4241 Mtetra
.816 .914 .905 r
.75646 .4241 .75918 .42586 .76541 .42118 .7627 .41932 Mtetra
.816 .908 .904 r
.7627 .41932 .76541 .42118 .77164 .4165 .76894 .41455 Mtetra
.815 .902 .902 r
.76894 .41455 .77164 .4165 .77787 .41183 .77518 .40976 Mtetra
.815 .896 .9 r
.77518 .40976 .77787 .41183 .78411 .40714 .78143 .40498 Mtetra
.814 .889 .897 r
.78143 .40498 .78411 .40714 .79035 .40245 .78768 .40019 Mtetra
.814 .883 .895 r
.78768 .40019 .79035 .40245 .7966 .39777 .79393 .3954 Mtetra
.813 .877 .893 r
.79393 .3954 .7966 .39777 .80285 .39307 .80019 .39061 Mtetra
.812 .871 .89 r
.80019 .39061 .80285 .39307 .8091 .38838 .80645 .38581 Mtetra
.811 .865 .888 r
.80645 .38581 .8091 .38838 .81536 .38368 .81271 .38101 Mtetra
.809 .859 .885 r
.81271 .38101 .81536 .38368 .82162 .37898 .81898 .3762 Mtetra
.808 .853 .883 r
.81898 .3762 .82162 .37898 .82788 .37427 .82525 .37139 Mtetra
.807 .847 .88 r
.82525 .37139 .82788 .37427 .83415 .36956 .83152 .36658 Mtetra
.805 .841 .877 r
.83152 .36658 .83415 .36956 .84042 .36485 .8378 .36177 Mtetra
.804 .835 .875 r
.8378 .36177 .84042 .36485 .8467 .36013 .84408 .35695 Mtetra
.803 .829 .872 r
.84408 .35695 .8467 .36013 .85297 .3554 .85036 .35213 Mtetra
.801 .823 .869 r
.85036 .35213 .85297 .3554 .85926 .35068 .85665 .3473 Mtetra
.799 .818 .866 r
.85665 .3473 .85926 .35068 .86554 .34596 .86294 .34248 Mtetra
.797 .812 .864 r
.86294 .34248 .86554 .34596 .87183 .34123 .86923 .33766 Mtetra
.794 .806 .862 r
.86923 .33766 .87183 .34123 .87813 .33654 .87553 .33286 Mtetra
.79 .8 .861 r
.87553 .33286 .87813 .33654 .88444 .33192 .88185 .32815 Mtetra
.782 .794 .862 r
.88185 .32815 .88444 .33192 .89077 .32745 .88818 .32359 Mtetra
.771 .786 .865 r
.88818 .32359 .89077 .32745 .89714 .32322 .89455 .31928 Mtetra
.477 .678 .953 r
.30091 .5068 .30436 .51 .30961 .51008 .30617 .50693 Mtetra
.4 .648 .958 r
.30617 .50693 .30961 .51008 .31485 .51063 .3114 .50755 Mtetra
.364 .636 .959 r
.3114 .50755 .31485 .51063 .32009 .51134 .31665 .50833 Mtetra
.341 .631 .96 r
.31665 .50833 .32009 .51134 .32535 .51213 .3219 .50921 Mtetra
.323 .628 .96 r
.3219 .50921 .32535 .51213 .33063 .51297 .32718 .51013 Mtetra
.311 .628 .961 r
.32718 .51013 .33063 .51297 .33592 .51383 .33247 .51107 Mtetra
.301 .63 .962 r
.33247 .51107 .33592 .51383 .34123 .51468 .33778 .512 Mtetra
.29 .63 .963 r
.33778 .512 .34123 .51468 .34656 .51554 .34311 .51294 Mtetra
.277 .63 .963 r
.34311 .51294 .34656 .51554 .35191 .51641 .34847 .51389 Mtetra
.266 .63 .962 r
.34847 .51389 .35191 .51641 .35729 .51727 .35384 .51484 Mtetra
.254 .63 .961 r
.35384 .51484 .35729 .51727 .36268 .51814 .35923 .51579 Mtetra
.24 .629 .958 r
.35923 .51579 .36268 .51814 .36809 .51901 .36464 .51674 Mtetra
.226 .628 .956 r
.36464 .51674 .36809 .51901 .37352 .51988 .37007 .5177 Mtetra
.212 .627 .952 r
.37007 .5177 .37352 .51988 .37897 .52076 .37552 .51866 Mtetra
.197 .624 .948 r
.37552 .51866 .37897 .52076 .38444 .52163 .381 .51962 Mtetra
.181 .621 .942 r
.381 .51962 .38444 .52163 .38993 .52251 .38649 .52059 Mtetra
.166 .617 .936 r
.38649 .52059 .38993 .52251 .39544 .5234 .392 .52155 Mtetra
.149 .613 .928 r
.392 .52155 .39544 .5234 .40097 .52428 .39754 .52252 Mtetra
.131 .608 .919 r
.39754 .52252 .40097 .52428 .40652 .52517 .40309 .5235 Mtetra
.114 .602 .909 r
.40309 .5235 .40652 .52517 .41209 .52606 .40867 .52447 Mtetra
.096 .596 .899 r
.40867 .52447 .41209 .52606 .41768 .52695 .41426 .52545 Mtetra
.077 .588 .886 r
.41426 .52545 .41768 .52695 .42329 .52785 .41988 .52644 Mtetra
.058 .579 .873 r
.41988 .52644 .42329 .52785 .42893 .52875 .42552 .52743 Mtetra
.039 .571 .858 r
.42552 .52743 .42893 .52875 .43458 .52965 .43118 .52842 Mtetra
.02 .561 .843 r
.43118 .52842 .43458 .52965 .44026 .53056 .43686 .52941 Mtetra
0 .55 .825 r
.43686 .52941 .44026 .53056 .44596 .53147 .44257 .53041 Mtetra
0 .539 .807 r
.44257 .53041 .44596 .53147 .45167 .53238 .44829 .53141 Mtetra
0 .527 .789 r
.44829 .53141 .45167 .53238 .45742 .5333 .45404 .53242 Mtetra
0 .514 .768 r
.45404 .53242 .45742 .5333 .46318 .53422 .45981 .53343 Mtetra
0 .501 .747 r
.45981 .53343 .46318 .53422 .46896 .53515 .4656 .53444 Mtetra
0 .488 .726 r
.4656 .53444 .46896 .53515 .47477 .53607 .47141 .53546 Mtetra
0 .473 .703 r
.47141 .53546 .47477 .53607 .48059 .537 .47725 .53648 Mtetra
.136 0 0 r
.47725 .53648 .48059 .537 .48644 .53794 .48311 .53751 Mtetra
.154 0 0 r
.48311 .53751 .48644 .53794 .49231 .53888 .48899 .53854 Mtetra
.172 0 0 r
.48899 .53854 .49231 .53888 .49821 .53982 .49489 .53958 Mtetra
.19 0 0 r
.49489 .53958 .49821 .53982 .50413 .54077 .50082 .54062 Mtetra
.207 0 0 r
.50082 .54062 .50413 .54077 .51006 .54173 .50677 .54167 Mtetra
.222 0 0 r
.50677 .54167 .51006 .54173 .51603 .54268 .51274 .54272 Mtetra
.239 0 0 r
.51274 .54272 .51603 .54268 .52201 .54364 .51874 .54377 Mtetra
.255 0 0 r
.51874 .54377 .52201 .54364 .52802 .54461 .52476 .54484 Mtetra
.269 0 0 r
.52476 .54484 .52802 .54461 .53405 .54558 .5308 .5459 Mtetra
.282 0 0 r
.5308 .5459 .53405 .54558 .5401 .54656 .53687 .54697 Mtetra
.297 0 0 r
.53687 .54697 .5401 .54656 .54618 .54754 .54296 .54805 Mtetra
.31 0 0 r
.54296 .54805 .54618 .54754 .55228 .54853 .54908 .54914 Mtetra
.32 0 0 r
.54908 .54914 .55228 .54853 .55841 .54951 .55522 .55021 Mtetra
.33 0 0 r
.55522 .55021 .55841 .54951 .56456 .55049 .56138 .55129 Mtetra
.336 0 0 r
.56138 .55129 .56456 .55049 .57073 .55144 .56757 .55233 Mtetra
.326 0 0 r
.56757 .55233 .57073 .55144 .57692 .55226 .57378 .55325 Mtetra
.29 0 0 r
.57378 .55325 .57692 .55226 .58314 .55279 .58001 .55386 Mtetra
0 0 0 r
.58001 .55386 .58314 .55279 .58934 .5514 .58623 .55249 Mtetra
.617 .952 .791 r
.58623 .55249 .58934 .5514 .59549 .54717 .5924 .54816 Mtetra
.662 .97 .807 r
.5924 .54816 .59549 .54717 .60164 .54268 .59857 .54357 Mtetra
.693 .98 .819 r
.59857 .54357 .60164 .54268 .6078 .53803 .60474 .53882 Mtetra
.712 .986 .829 r
.60474 .53882 .6078 .53803 .61395 .53332 .61092 .53399 Mtetra
.723 .989 .839 r
.61092 .53399 .61395 .53332 .62011 .5286 .61709 .52916 Mtetra
.734 .991 .848 r
.61709 .52916 .62011 .5286 .62628 .52387 .62327 .52433 Mtetra
.744 .993 .857 r
.62327 .52433 .62628 .52387 .63244 .51913 .62945 .51948 Mtetra
.753 .994 .864 r
.62945 .51948 .63244 .51913 .63861 .5144 .63564 .51464 Mtetra
.761 .994 .871 r
.63564 .51464 .63861 .5144 .64478 .50967 .64183 .5098 Mtetra
.769 .993 .878 r
.64183 .5098 .64478 .50967 .65096 .50493 .64802 .50496 Mtetra
.776 .992 .883 r
.64802 .50496 .65096 .50493 .65714 .50019 .65421 .50011 Mtetra
.781 .99 .888 r
.65421 .50011 .65714 .50019 .66332 .49545 .66041 .49526 Mtetra
.787 .988 .892 r
.66041 .49526 .66332 .49545 .66951 .49071 .66661 .49042 Mtetra
.793 .985 .896 r
.66661 .49042 .66951 .49071 .6757 .48596 .67281 .48556 Mtetra
.797 .982 .899 r
.67281 .48556 .6757 .48596 .68189 .48122 .67902 .48071 Mtetra
.801 .978 .902 r
.67902 .48071 .68189 .48122 .68808 .47647 .68523 .47586 Mtetra
.805 .974 .903 r
.68523 .47586 .68808 .47647 .69428 .47172 .69144 .47101 Mtetra
.808 .97 .905 r
.69144 .47101 .69428 .47172 .70049 .46697 .69766 .46615 Mtetra
.81 .965 .906 r
.69766 .46615 .70049 .46697 .70669 .46222 .70387 .46129 Mtetra
.813 .96 .907 r
.70387 .46129 .70669 .46222 .7129 .45746 .7101 .45643 Mtetra
.815 .955 .907 r
.7101 .45643 .7129 .45746 .71911 .4527 .71632 .45157 Mtetra
.816 .949 .908 r
.71632 .45157 .71911 .4527 .72533 .44794 .72255 .4467 Mtetra
.818 .944 .907 r
.72255 .4467 .72533 .44794 .73155 .44318 .72878 .44183 Mtetra
.819 .938 .907 r
.72878 .44183 .73155 .44318 .73777 .43841 .73501 .43696 Mtetra
.819 .932 .906 r
.73501 .43696 .73777 .43841 .744 .43364 .74125 .43209 Mtetra
.82 .926 .905 r
.74125 .43209 .744 .43364 .75023 .42887 .74749 .42722 Mtetra
.82 .92 .904 r
.74749 .42722 .75023 .42887 .75646 .4241 .75373 .42234 Mtetra
.82 .914 .902 r
.75373 .42234 .75646 .4241 .7627 .41932 .75998 .41746 Mtetra
.82 .908 .9 r
.75998 .41746 .7627 .41932 .76894 .41455 .76623 .41258 Mtetra
.819 .902 .899 r
.76623 .41258 .76894 .41455 .77518 .40976 .77248 .4077 Mtetra
.819 .896 .897 r
.77248 .4077 .77518 .40976 .78143 .40498 .77873 .40281 Mtetra
.818 .89 .894 r
.77873 .40281 .78143 .40498 .78768 .40019 .78499 .39791 Mtetra
.817 .884 .892 r
.78499 .39791 .78768 .40019 .79393 .3954 .79125 .39302 Mtetra
.816 .877 .89 r
.79125 .39302 .79393 .3954 .80019 .39061 .79752 .38813 Mtetra
.816 .871 .888 r
.79752 .38813 .80019 .39061 .80645 .38581 .80378 .38322 Mtetra
.814 .865 .885 r
.80378 .38322 .80645 .38581 .81271 .38101 .81005 .37832 Mtetra
.813 .859 .883 r
.81005 .37832 .81271 .38101 .81898 .3762 .81633 .37342 Mtetra
.812 .853 .88 r
.81633 .37342 .81898 .3762 .82525 .37139 .8226 .36851 Mtetra
.81 .847 .877 r
.8226 .36851 .82525 .37139 .83152 .36658 .82888 .36359 Mtetra
.809 .841 .875 r
.82888 .36359 .83152 .36658 .8378 .36177 .83516 .35868 Mtetra
.807 .836 .872 r
.83516 .35868 .8378 .36177 .84408 .35695 .84145 .35376 Mtetra
.806 .83 .869 r
.84145 .35376 .84408 .35695 .85036 .35213 .84774 .34884 Mtetra
.804 .824 .867 r
.84774 .34884 .85036 .35213 .85665 .3473 .85403 .34391 Mtetra
.802 .818 .864 r
.85403 .34391 .85665 .3473 .86294 .34248 .86032 .33899 Mtetra
.801 .813 .861 r
.86032 .33899 .86294 .34248 .86923 .33766 .86662 .33407 Mtetra
.798 .807 .859 r
.86662 .33407 .86923 .33766 .87553 .33286 .87292 .32917 Mtetra
.793 .801 .859 r
.87292 .32917 .87553 .33286 .88185 .32815 .87924 .32437 Mtetra
.785 .794 .86 r
.87924 .32437 .88185 .32815 .88818 .32359 .88558 .31972 Mtetra
.774 .787 .864 r
.88558 .31972 .88818 .32359 .89455 .31928 .89196 .31533 Mtetra
.469 .675 .954 r
.29746 .50358 .30091 .5068 .30617 .50693 .30271 .50377 Mtetra
.388 .642 .957 r
.30271 .50377 .30617 .50693 .3114 .50755 .30794 .50445 Mtetra
.35 .629 .957 r
.30794 .50445 .3114 .50755 .31665 .50833 .31319 .50532 Mtetra
.325 .623 .958 r
.31319 .50532 .31665 .50833 .3219 .50921 .31844 .50627 Mtetra
.307 .619 .958 r
.31844 .50627 .3219 .50921 .32718 .51013 .32371 .50727 Mtetra
.293 .619 .959 r
.32371 .50727 .32718 .51013 .33247 .51107 .32901 .50829 Mtetra
.284 .62 .959 r
.32901 .50829 .33247 .51107 .33778 .512 .33432 .50931 Mtetra
.272 .62 .959 r
.33432 .50931 .33778 .512 .34311 .51294 .33965 .51033 Mtetra
.259 .62 .959 r
.33965 .51033 .34311 .51294 .34847 .51389 .345 .51137 Mtetra
.247 .62 .958 r
.345 .51137 .34847 .51389 .35384 .51484 .35037 .5124 Mtetra
.235 .62 .956 r
.35037 .5124 .35384 .51484 .35923 .51579 .35577 .51343 Mtetra
.22 .618 .953 r
.35577 .51343 .35923 .51579 .36464 .51674 .36118 .51447 Mtetra
.206 .616 .95 r
.36118 .51447 .36464 .51674 .37007 .5177 .36661 .51551 Mtetra
.192 .614 .946 r
.36661 .51551 .37007 .5177 .37552 .51866 .37207 .51655 Mtetra
.176 .611 .941 r
.37207 .51655 .37552 .51866 .381 .51962 .37754 .5176 Mtetra
.16 .607 .934 r
.37754 .5176 .381 .51962 .38649 .52059 .38304 .51865 Mtetra
.144 .604 .927 r
.38304 .51865 .38649 .52059 .392 .52155 .38855 .5197 Mtetra
.128 .599 .919 r
.38855 .5197 .392 .52155 .39754 .52252 .39409 .52075 Mtetra
.109 .593 .91 r
.39409 .52075 .39754 .52252 .40309 .5235 .39965 .52182 Mtetra
.091 .587 .899 r
.39965 .52182 .40309 .5235 .40867 .52447 .40523 .52288 Mtetra
.074 .58 .888 r
.40523 .52288 .40867 .52447 .41426 .52545 .41083 .52395 Mtetra
.055 .572 .875 r
.41083 .52395 .41426 .52545 .41988 .52644 .41645 .52502 Mtetra
.035 .563 .861 r
.41645 .52502 .41988 .52644 .42552 .52743 .4221 .52609 Mtetra
.017 .554 .846 r
.4221 .52609 .42552 .52743 .43118 .52842 .42776 .52717 Mtetra
0 .544 .83 r
.42776 .52717 .43118 .52842 .43686 .52941 .43345 .52825 Mtetra
0 .533 .812 r
.43345 .52825 .43686 .52941 .44257 .53041 .43916 .52934 Mtetra
0 .521 .794 r
.43916 .52934 .44257 .53041 .44829 .53141 .44489 .53043 Mtetra
0 .51 .774 r
.44489 .53043 .44829 .53141 .45404 .53242 .45065 .53153 Mtetra
0 .496 .754 r
.45065 .53153 .45404 .53242 .45981 .53343 .45642 .53263 Mtetra
0 .483 .732 r
.45642 .53263 .45981 .53343 .4656 .53444 .46222 .53374 Mtetra
0 .469 .711 r
.46222 .53374 .4656 .53444 .47141 .53546 .46804 .53484 Mtetra
.138 0 0 r
.46804 .53484 .47141 .53546 .47725 .53648 .47389 .53596 Mtetra
.157 0 0 r
.47389 .53596 .47725 .53648 .48311 .53751 .47976 .53708 Mtetra
.174 0 0 r
.47976 .53708 .48311 .53751 .48899 .53854 .48565 .5382 Mtetra
.191 0 0 r
.48565 .5382 .48899 .53854 .49489 .53958 .49156 .53933 Mtetra
.209 0 0 r
.49156 .53933 .49489 .53958 .50082 .54062 .4975 .54047 Mtetra
.226 0 0 r
.4975 .54047 .50082 .54062 .50677 .54167 .50346 .54161 Mtetra
.241 0 0 r
.50346 .54161 .50677 .54167 .51274 .54272 .50944 .54275 Mtetra
.256 0 0 r
.50944 .54275 .51274 .54272 .51874 .54377 .51545 .5439 Mtetra
.272 0 0 r
.51545 .5439 .51874 .54377 .52476 .54484 .52148 .54506 Mtetra
.285 0 0 r
.52148 .54506 .52476 .54484 .5308 .5459 .52754 .54622 Mtetra
.298 0 0 r
.52754 .54622 .5308 .5459 .53687 .54697 .53362 .54739 Mtetra
.312 0 0 r
.53362 .54739 .53687 .54697 .54296 .54805 .53972 .54856 Mtetra
.325 0 0 r
.53972 .54856 .54296 .54805 .54908 .54914 .54585 .54975 Mtetra
.334 0 0 r
.54585 .54975 .54908 .54914 .55522 .55021 .55201 .55092 Mtetra
.344 0 0 r
.55201 .55092 .55522 .55021 .56138 .55129 .55819 .55209 Mtetra
.349 0 0 r
.55819 .55209 .56138 .55129 .56757 .55233 .56439 .55324 Mtetra
.339 0 0 r
.56439 .55324 .56757 .55233 .57378 .55325 .57061 .55424 Mtetra
.302 0 0 r
.57061 .55424 .57378 .55325 .58001 .55386 .57686 .55494 Mtetra
0 0 0 r
.57686 .55494 .58001 .55386 .58623 .55249 .58309 .55357 Mtetra
.627 .956 .793 r
.58309 .55357 .58623 .55249 .5924 .54816 .58928 .54916 Mtetra
.673 .973 .808 r
.58928 .54916 .5924 .54816 .59857 .54357 .59548 .54447 Mtetra
.703 .983 .819 r
.59548 .54447 .59857 .54357 .60474 .53882 .60166 .5396 Mtetra
.721 .988 .829 r
.60166 .5396 .60474 .53882 .61092 .53399 .60786 .53467 Mtetra
.733 .991 .839 r
.60786 .53467 .61092 .53399 .61709 .52916 .61405 .52973 Mtetra
.743 .993 .847 r
.61405 .52973 .61709 .52916 .62327 .52433 .62025 .52479 Mtetra
.753 .994 .855 r
.62025 .52479 .62327 .52433 .62945 .51948 .62644 .51984 Mtetra
.761 .995 .863 r
.62644 .51984 .62945 .51948 .63564 .51464 .63265 .51488 Mtetra
.768 .995 .87 r
.63265 .51488 .63564 .51464 .64183 .5098 .63885 .50994 Mtetra
.776 .994 .875 r
.63885 .50994 .64183 .5098 .64802 .50496 .64506 .50498 Mtetra
.783 .992 .881 r
.64506 .50498 .64802 .50496 .65421 .50011 .65127 .50003 Mtetra
.788 .99 .886 r
.65127 .50003 .65421 .50011 .66041 .49526 .65748 .49508 Mtetra
.794 .988 .89 r
.65748 .49508 .66041 .49526 .66661 .49042 .66369 .49012 Mtetra
.799 .985 .893 r
.66369 .49012 .66661 .49042 .67281 .48556 .66991 .48516 Mtetra
.803 .982 .896 r
.66991 .48516 .67281 .48556 .67902 .48071 .67613 .4802 Mtetra
.807 .978 .899 r
.67613 .4802 .67902 .48071 .68523 .47586 .68235 .47525 Mtetra
.81 .974 .9 r
.68235 .47525 .68523 .47586 .69144 .47101 .68858 .47028 Mtetra
.813 .969 .902 r
.68858 .47028 .69144 .47101 .69766 .46615 .69481 .46532 Mtetra
.816 .965 .903 r
.69481 .46532 .69766 .46615 .70387 .46129 .70104 .46036 Mtetra
.818 .96 .904 r
.70104 .46036 .70387 .46129 .7101 .45643 .70727 .45539 Mtetra
.82 .955 .904 r
.70727 .45539 .7101 .45643 .71632 .45157 .71351 .45042 Mtetra
.821 .949 .904 r
.71351 .45042 .71632 .45157 .72255 .4467 .71975 .44545 Mtetra
.822 .944 .904 r
.71975 .44545 .72255 .4467 .72878 .44183 .72599 .44048 Mtetra
.823 .938 .903 r
.72599 .44048 .72878 .44183 .73501 .43696 .73224 .43551 Mtetra
.824 .932 .903 r
.73224 .43551 .73501 .43696 .74125 .43209 .73848 .43053 Mtetra
.824 .926 .902 r
.73848 .43053 .74125 .43209 .74749 .42722 .74473 .42555 Mtetra
.824 .92 .9 r
.74473 .42555 .74749 .42722 .75373 .42234 .75099 .42057 Mtetra
.824 .914 .899 r
.75099 .42057 .75373 .42234 .75998 .41746 .75724 .41559 Mtetra
.824 .908 .897 r
.75724 .41559 .75998 .41746 .76623 .41258 .7635 .4106 Mtetra
.823 .902 .896 r
.7635 .4106 .76623 .41258 .77248 .4077 .76976 .40561 Mtetra
.823 .896 .893 r
.76976 .40561 .77248 .4077 .77873 .40281 .77602 .40062 Mtetra
.822 .89 .891 r
.77602 .40062 .77873 .40281 .78499 .39791 .78229 .39563 Mtetra
.821 .884 .889 r
.78229 .39563 .78499 .39791 .79125 .39302 .78856 .39063 Mtetra
.82 .878 .887 r
.78856 .39063 .79125 .39302 .79752 .38813 .79483 .38563 Mtetra
.819 .872 .885 r
.79483 .38563 .79752 .38813 .80378 .38322 .80111 .38063 Mtetra
.818 .866 .882 r
.80111 .38063 .80378 .38322 .81005 .37832 .80738 .37563 Mtetra
.816 .86 .88 r
.80738 .37563 .81005 .37832 .81633 .37342 .81366 .37062 Mtetra
.815 .854 .877 r
.81366 .37062 .81633 .37342 .8226 .36851 .81995 .36561 Mtetra
.814 .848 .875 r
.81995 .36561 .8226 .36851 .82888 .36359 .82623 .36059 Mtetra
.812 .842 .872 r
.82623 .36059 .82888 .36359 .83516 .35868 .83252 .35558 Mtetra
.811 .836 .869 r
.83252 .35558 .83516 .35868 .84145 .35376 .83881 .35056 Mtetra
.809 .83 .867 r
.83881 .35056 .84145 .35376 .84774 .34884 .8451 .34553 Mtetra
.807 .825 .864 r
.8451 .34553 .84774 .34884 .85403 .34391 .8514 .34051 Mtetra
.806 .819 .862 r
.8514 .34051 .85403 .34391 .86032 .33899 .85769 .33548 Mtetra
.804 .814 .859 r
.85769 .33548 .86032 .33899 .86662 .33407 .864 .33046 Mtetra
.801 .808 .857 r
.864 .33046 .86662 .33407 .87292 .32917 .8703 .32547 Mtetra
.796 .802 .857 r
.8703 .32547 .87292 .32917 .87924 .32437 .87663 .32057 Mtetra
.788 .795 .858 r
.87663 .32057 .87924 .32437 .88558 .31972 .88297 .31583 Mtetra
.776 .788 .862 r
.88297 .31583 .88558 .31972 .89196 .31533 .88935 .31135 Mtetra
.461 .671 .955 r
.29398 .50035 .29746 .50358 .30271 .50377 .29924 .50059 Mtetra
.375 .636 .957 r
.29924 .50059 .30271 .50377 .30794 .50445 .30447 .50135 Mtetra
.335 .622 .956 r
.30447 .50135 .30794 .50445 .31319 .50532 .30971 .50229 Mtetra
.309 .614 .955 r
.30971 .50229 .31319 .50532 .31844 .50627 .31497 .50332 Mtetra
.29 .61 .955 r
.31497 .50332 .31844 .50627 .32371 .50727 .32024 .50441 Mtetra
.276 .609 .955 r
.32024 .50441 .32371 .50727 .32901 .50829 .32553 .50551 Mtetra
.266 .611 .956 r
.32553 .50551 .32901 .50829 .33432 .50931 .33084 .50661 Mtetra
.253 .61 .955 r
.33084 .50661 .33432 .50931 .33965 .51033 .33617 .50771 Mtetra
.24 .609 .954 r
.33617 .50771 .33965 .51033 .345 .51137 .34152 .50883 Mtetra
.228 .609 .953 r
.34152 .50883 .345 .51137 .35037 .5124 .3469 .50994 Mtetra
.215 .608 .951 r
.3469 .50994 .35037 .5124 .35577 .51343 .35229 .51106 Mtetra
.2 .606 .947 r
.35229 .51106 .35577 .51343 .36118 .51447 .3577 .51218 Mtetra
.186 .604 .943 r
.3577 .51218 .36118 .51447 .36661 .51551 .36314 .51331 Mtetra
.171 .602 .939 r
.36314 .51331 .36661 .51551 .37207 .51655 .36859 .51443 Mtetra
.155 .598 .933 r
.36859 .51443 .37207 .51655 .37754 .5176 .37407 .51556 Mtetra
.139 .594 .926 r
.37407 .51556 .37754 .5176 .38304 .51865 .37957 .5167 Mtetra
.123 .59 .919 r
.37957 .5167 .38304 .51865 .38855 .5197 .38509 .51784 Mtetra
.106 .585 .91 r
.38509 .51784 .38855 .5197 .39409 .52075 .39063 .51898 Mtetra
.087 .578 .9 r
.39063 .51898 .39409 .52075 .39965 .52182 .39619 .52012 Mtetra
.069 .571 .889 r
.39619 .52012 .39965 .52182 .40523 .52288 .40177 .52128 Mtetra
.052 .565 .877 r
.40177 .52128 .40523 .52288 .41083 .52395 .40738 .52243 Mtetra
.033 .556 .863 r
.40738 .52243 .41083 .52395 .41645 .52502 .41301 .52359 Mtetra
.013 .547 .849 r
.41301 .52359 .41645 .52502 .4221 .52609 .41865 .52475 Mtetra
0 .537 .833 r
.41865 .52475 .4221 .52609 .42776 .52717 .42433 .52592 Mtetra
0 .527 .817 r
.42433 .52592 .42776 .52717 .43345 .52825 .43002 .52709 Mtetra
0 .515 .799 r
.43002 .52709 .43345 .52825 .43916 .52934 .43574 .52827 Mtetra
0 .504 .78 r
.43574 .52827 .43916 .52934 .44489 .53043 .44147 .52945 Mtetra
0 .492 .76 r
.44147 .52945 .44489 .53043 .45065 .53153 .44723 .53063 Mtetra
0 .479 .74 r
.44723 .53063 .45065 .53153 .45642 .53263 .45302 .53182 Mtetra
0 .465 .718 r
.45302 .53182 .45642 .53263 .46222 .53374 .45883 .53302 Mtetra
0 .451 .696 r
.45883 .53302 .46222 .53374 .46804 .53484 .46466 .53422 Mtetra
.158 0 0 r
.46466 .53422 .46804 .53484 .47389 .53596 .47051 .53543 Mtetra
.177 0 0 r
.47051 .53543 .47389 .53596 .47976 .53708 .47638 .53664 Mtetra
.194 0 0 r
.47638 .53664 .47976 .53708 .48565 .5382 .48228 .53786 Mtetra
.21 0 0 r
.48228 .53786 .48565 .5382 .49156 .53933 .48821 .53908 Mtetra
.227 0 0 r
.48821 .53908 .49156 .53933 .4975 .54047 .49416 .54031 Mtetra
.244 0 0 r
.49416 .54031 .4975 .54047 .50346 .54161 .50013 .54154 Mtetra
.258 0 0 r
.50013 .54154 .50346 .54161 .50944 .54275 .50612 .54278 Mtetra
.273 0 0 r
.50612 .54278 .50944 .54275 .51545 .5439 .51214 .54403 Mtetra
.288 0 0 r
.51214 .54403 .51545 .5439 .52148 .54506 .51819 .54528 Mtetra
.301 0 0 r
.51819 .54528 .52148 .54506 .52754 .54622 .52425 .54654 Mtetra
.314 0 0 r
.52425 .54654 .52754 .54622 .53362 .54739 .53035 .5478 Mtetra
.327 0 0 r
.53035 .5478 .53362 .54739 .53972 .54856 .53646 .54907 Mtetra
.339 0 0 r
.53646 .54907 .53972 .54856 .54585 .54975 .54261 .55035 Mtetra
.348 0 0 r
.54261 .55035 .54585 .54975 .55201 .55092 .54877 .55163 Mtetra
.357 0 0 r
.54877 .55163 .55201 .55092 .55819 .55209 .55497 .5529 Mtetra
.362 0 0 r
.55497 .5529 .55819 .55209 .56439 .55324 .56119 .55414 Mtetra
.351 0 0 r
.56119 .55414 .56439 .55324 .57061 .55424 .56743 .55524 Mtetra
.313 0 0 r
.56743 .55524 .57061 .55424 .57686 .55494 .57369 .55602 Mtetra
0 0 0 r
.57369 .55602 .57686 .55494 .58309 .55357 .57994 .55466 Mtetra
.638 .96 .795 r
.57994 .55466 .58309 .55357 .58928 .54916 .58615 .55016 Mtetra
.683 .976 .809 r
.58615 .55016 .58928 .54916 .59548 .54447 .59236 .54536 Mtetra
.713 .986 .82 r
.59236 .54536 .59548 .54447 .60166 .5396 .59857 .54039 Mtetra
.731 .99 .829 r
.59857 .54039 .60166 .5396 .60786 .53467 .60478 .53535 Mtetra
.742 .993 .838 r
.60478 .53535 .60786 .53467 .61405 .52973 .61099 .5303 Mtetra
.752 .994 .847 r
.61099 .5303 .61405 .52973 .62025 .52479 .6172 .52525 Mtetra
.761 .995 .854 r
.6172 .52525 .62025 .52479 .62644 .51984 .62342 .52019 Mtetra
.769 .996 .861 r
.62342 .52019 .62644 .51984 .63265 .51488 .62963 .51512 Mtetra
.776 .995 .868 r
.62963 .51512 .63265 .51488 .63885 .50994 .63585 .51007 Mtetra
.783 .994 .873 r
.63585 .51007 .63885 .50994 .64506 .50498 .64208 .50501 Mtetra
.79 .993 .878 r
.64208 .50501 .64506 .50498 .65127 .50003 .6483 .49994 Mtetra
.795 .991 .883 r
.6483 .49994 .65127 .50003 .65748 .49508 .65453 .49488 Mtetra
.8 .988 .887 r
.65453 .49488 .65748 .49508 .66369 .49012 .66076 .48982 Mtetra
.805 .985 .89 r
.66076 .48982 .66369 .49012 .66991 .48516 .66699 .48475 Mtetra
.809 .982 .893 r
.66699 .48475 .66991 .48516 .67613 .4802 .67323 .47969 Mtetra
.812 .978 .896 r
.67323 .47969 .67613 .4802 .68235 .47525 .67946 .47462 Mtetra
.816 .974 .897 r
.67946 .47462 .68235 .47525 .68858 .47028 .6857 .46956 Mtetra
.818 .969 .899 r
.6857 .46956 .68858 .47028 .69481 .46532 .69194 .46448 Mtetra
.821 .964 .9 r
.69194 .46448 .69481 .46532 .70104 .46036 .69819 .45942 Mtetra
.823 .959 .901 r
.69819 .45942 .70104 .46036 .70727 .45539 .70443 .45434 Mtetra
.824 .954 .901 r
.70443 .45434 .70727 .45539 .71351 .45042 .71068 .44927 Mtetra
.826 .949 .901 r
.71068 .44927 .71351 .45042 .71975 .44545 .71693 .44419 Mtetra
.827 .943 .901 r
.71693 .44419 .71975 .44545 .72599 .44048 .72319 .43912 Mtetra
.827 .938 .9 r
.72319 .43912 .72599 .44048 .73224 .43551 .72944 .43404 Mtetra
.828 .932 .899 r
.72944 .43404 .73224 .43551 .73848 .43053 .7357 .42895 Mtetra
.828 .926 .898 r
.7357 .42895 .73848 .43053 .74473 .42555 .74196 .42387 Mtetra
.828 .92 .897 r
.74196 .42387 .74473 .42555 .75099 .42057 .74823 .41879 Mtetra
.828 .914 .896 r
.74823 .41879 .75099 .42057 .75724 .41559 .75449 .4137 Mtetra
.828 .908 .894 r
.75449 .4137 .75724 .41559 .7635 .4106 .76076 .40861 Mtetra
.827 .902 .892 r
.76076 .40861 .7635 .4106 .76976 .40561 .76703 .40352 Mtetra
.826 .896 .89 r
.76703 .40352 .76976 .40561 .77602 .40062 .7733 .39843 Mtetra
.826 .89 .888 r
.7733 .39843 .77602 .40062 .78229 .39563 .77958 .39333 Mtetra
.825 .884 .886 r
.77958 .39333 .78229 .39563 .78856 .39063 .78585 .38823 Mtetra
.824 .878 .884 r
.78585 .38823 .78856 .39063 .79483 .38563 .79213 .38313 Mtetra
.823 .872 .882 r
.79213 .38313 .79483 .38563 .80111 .38063 .79842 .37802 Mtetra
.821 .866 .88 r
.79842 .37802 .80111 .38063 .80738 .37563 .8047 .37292 Mtetra
.82 .86 .877 r
.8047 .37292 .80738 .37563 .81366 .37062 .81099 .36781 Mtetra
.819 .854 .875 r
.81099 .36781 .81366 .37062 .81995 .36561 .81727 .36269 Mtetra
.817 .848 .872 r
.81727 .36269 .81995 .36561 .82623 .36059 .82357 .35758 Mtetra
.815 .842 .87 r
.82357 .35758 .82623 .36059 .83252 .35558 .82986 .35246 Mtetra
.814 .837 .867 r
.82986 .35246 .83252 .35558 .83881 .35056 .83615 .34734 Mtetra
.812 .831 .864 r
.83615 .34734 .83881 .35056 .8451 .34553 .84245 .34221 Mtetra
.811 .825 .862 r
.84245 .34221 .8451 .34553 .8514 .34051 .84875 .33709 Mtetra
.809 .82 .859 r
.84875 .33709 .8514 .34051 .85769 .33548 .85506 .33196 Mtetra
.807 .814 .857 r
.85506 .33196 .85769 .33548 .864 .33046 .86136 .32684 Mtetra
.804 .809 .855 r
.86136 .32684 .864 .33046 .8703 .32547 .86767 .32175 Mtetra
.799 .803 .855 r
.86767 .32175 .8703 .32547 .87663 .32057 .874 .31675 Mtetra
.791 .796 .856 r
.874 .31675 .87663 .32057 .88297 .31583 .88034 .31192 Mtetra
.779 .788 .86 r
.88034 .31192 .88297 .31583 .88935 .31135 .88673 .30736 Mtetra
.452 .667 .955 r
.2905 .49711 .29398 .50035 .29924 .50059 .29575 .49741 Mtetra
.362 .63 .956 r
.29575 .49741 .29924 .50059 .30447 .50135 .30098 .49823 Mtetra
.32 .614 .954 r
.30098 .49823 .30447 .50135 .30971 .50229 .30622 .49925 Mtetra
.293 .606 .953 r
.30622 .49925 .30971 .50229 .31497 .50332 .31148 .50036 Mtetra
.272 .601 .952 r
.31148 .50036 .31497 .50332 .32024 .50441 .31675 .50153 Mtetra
.258 .6 .952 r
.31675 .50153 .32024 .50441 .32553 .50551 .32204 .50271 Mtetra
.247 .6 .952 r
.32204 .50271 .32553 .50551 .33084 .50661 .32735 .50389 Mtetra
.235 .6 .951 r
.32735 .50389 .33084 .50661 .33617 .50771 .33268 .50508 Mtetra
.221 .598 .949 r
.33268 .50508 .33617 .50771 .34152 .50883 .33803 .50628 Mtetra
.208 .598 .947 r
.33803 .50628 .34152 .50883 .3469 .50994 .3434 .50748 Mtetra
.195 .597 .945 r
.3434 .50748 .3469 .50994 .35229 .51106 .3488 .50868 Mtetra
.18 .594 .941 r
.3488 .50868 .35229 .51106 .3577 .51218 .35421 .50988 Mtetra
.165 .591 .936 r
.35421 .50988 .3577 .51218 .36314 .51331 .35965 .51109 Mtetra
.15 .589 .931 r
.35965 .51109 .36314 .51331 .36859 .51443 .3651 .5123 Mtetra
.134 .585 .925 r
.3651 .5123 .36859 .51443 .37407 .51556 .37058 .51352 Mtetra
.117 .58 .917 r
.37058 .51352 .37407 .51556 .37957 .5167 .37608 .51474 Mtetra
.1 .575 .909 r
.37608 .51474 .37957 .5167 .38509 .51784 .3816 .51597 Mtetra
.083 .57 .9 r
.3816 .51597 .38509 .51784 .39063 .51898 .38715 .51719 Mtetra
.065 .563 .889 r
.38715 .51719 .39063 .51898 .39619 .52012 .39271 .51843 Mtetra
.047 .556 .878 r
.39271 .51843 .39619 .52012 .40177 .52128 .3983 .51967 Mtetra
.029 .548 .865 r
.3983 .51967 .40177 .52128 .40738 .52243 .40391 .52091 Mtetra
.01 .539 .851 r
.40391 .52091 .40738 .52243 .41301 .52359 .40954 .52215 Mtetra
0 .53 .836 r
.40954 .52215 .41301 .52359 .41865 .52475 .41519 .52341 Mtetra
0 .52 .82 r
.41519 .52341 .41865 .52475 .42433 .52592 .42087 .52466 Mtetra
0 .509 .803 r
.42087 .52466 .42433 .52592 .43002 .52709 .42657 .52592 Mtetra
0 .497 .784 r
.42657 .52592 .43002 .52709 .43574 .52827 .43229 .52719 Mtetra
0 .486 .765 r
.43229 .52719 .43574 .52827 .44147 .52945 .43804 .52846 Mtetra
0 .473 .745 r
.43804 .52846 .44147 .52945 .44723 .53063 .4438 .52974 Mtetra
0 .46 .724 r
.4438 .52974 .44723 .53063 .45302 .53182 .44959 .53102 Mtetra
0 .446 .702 r
.44959 .53102 .45302 .53182 .45883 .53302 .45541 .53231 Mtetra
.161 0 0 r
.45541 .53231 .45883 .53302 .46466 .53422 .46125 .5336 Mtetra
.179 0 0 r
.46125 .5336 .46466 .53422 .47051 .53543 .46711 .5349 Mtetra
.197 0 0 r
.46711 .5349 .47051 .53543 .47638 .53664 .47299 .5362 Mtetra
.214 0 0 r
.47299 .5362 .47638 .53664 .48228 .53786 .4789 .53751 Mtetra
.23 0 0 r
.4789 .53751 .48228 .53786 .48821 .53908 .48484 .53883 Mtetra
.246 0 0 r
.48484 .53883 .48821 .53908 .49416 .54031 .49079 .54015 Mtetra
.262 0 0 r
.49079 .54015 .49416 .54031 .50013 .54154 .49677 .54148 Mtetra
.276 0 0 r
.49677 .54148 .50013 .54154 .50612 .54278 .50278 .54281 Mtetra
.291 0 0 r
.50278 .54281 .50612 .54278 .51214 .54403 .50881 .54416 Mtetra
.305 0 0 r
.50881 .54416 .51214 .54403 .51819 .54528 .51487 .54551 Mtetra
.318 0 0 r
.51487 .54551 .51819 .54528 .52425 .54654 .52095 .54686 Mtetra
.329 0 0 r
.52095 .54686 .52425 .54654 .53035 .5478 .52705 .54822 Mtetra
.342 0 0 r
.52705 .54822 .53035 .5478 .53646 .54907 .53318 .54959 Mtetra
.354 0 0 r
.53318 .54959 .53646 .54907 .54261 .55035 .53934 .55097 Mtetra
.363 0 0 r
.53934 .55097 .54261 .55035 .54877 .55163 .54552 .55234 Mtetra
.371 0 0 r
.54552 .55234 .54877 .55163 .55497 .5529 .55173 .55371 Mtetra
.376 0 0 r
.55173 .55371 .55497 .5529 .56119 .55414 .55796 .55505 Mtetra
.364 0 0 r
.55796 .55505 .56119 .55414 .56743 .55524 .56422 .55624 Mtetra
.326 0 0 r
.56422 .55624 .56743 .55524 .57369 .55602 .5705 .55711 Mtetra
0 0 0 r
.5705 .55711 .57369 .55602 .57994 .55466 .57677 .55577 Mtetra
.647 .963 .796 r
.57677 .55577 .57994 .55466 .58615 .55016 .583 .55116 Mtetra
.693 .979 .809 r
.583 .55116 .58615 .55016 .59236 .54536 .58922 .54627 Mtetra
.722 .988 .819 r
.58922 .54627 .59236 .54536 .59857 .54039 .59545 .54119 Mtetra
.739 .992 .828 r
.59545 .54119 .59857 .54039 .60478 .53535 .60168 .53604 Mtetra
.75 .994 .837 r
.60168 .53604 .60478 .53535 .61099 .5303 .6079 .53088 Mtetra
.759 .996 .845 r
.6079 .53088 .61099 .5303 .6172 .52525 .61414 .52571 Mtetra
.769 .996 .852 r
.61414 .52571 .6172 .52525 .62342 .52019 .62037 .52054 Mtetra
.776 .996 .859 r
.62037 .52054 .62342 .52019 .62963 .51512 .6266 .51537 Mtetra
.783 .996 .866 r
.6266 .51537 .62963 .51512 .63585 .51007 .63284 .5102 Mtetra
.79 .995 .871 r
.63284 .5102 .63585 .51007 .64208 .50501 .63908 .50503 Mtetra
.796 .993 .876 r
.63908 .50503 .64208 .50501 .6483 .49994 .64532 .49986 Mtetra
.801 .991 .88 r
.64532 .49986 .6483 .49994 .65453 .49488 .65156 .49469 Mtetra
.806 .988 .884 r
.65156 .49469 .65453 .49488 .66076 .48982 .65781 .48952 Mtetra
.81 .985 .887 r
.65781 .48952 .66076 .48982 .66699 .48475 .66405 .48435 Mtetra
.814 .981 .89 r
.66405 .48435 .66699 .48475 .67323 .47969 .6703 .47917 Mtetra
.818 .978 .892 r
.6703 .47917 .67323 .47969 .67946 .47462 .67655 .474 Mtetra
.821 .973 .894 r
.67655 .474 .67946 .47462 .6857 .46956 .68281 .46883 Mtetra
.823 .969 .895 r
.68281 .46883 .6857 .46956 .69194 .46448 .68906 .46365 Mtetra
.825 .964 .897 r
.68906 .46365 .69194 .46448 .69819 .45942 .69532 .45847 Mtetra
.827 .959 .897 r
.69532 .45847 .69819 .45942 .70443 .45434 .70158 .45329 Mtetra
.829 .954 .897 r
.70158 .45329 .70443 .45434 .71068 .44927 .70784 .44811 Mtetra
.83 .949 .898 r
.70784 .44811 .71068 .44927 .71693 .44419 .7141 .44293 Mtetra
.831 .943 .897 r
.7141 .44293 .71693 .44419 .72319 .43912 .72037 .43775 Mtetra
.832 .938 .897 r
.72037 .43775 .72319 .43912 .72944 .43404 .72664 .43256 Mtetra
.832 .932 .896 r
.72664 .43256 .72944 .43404 .7357 .42895 .73291 .42737 Mtetra
.832 .926 .895 r
.73291 .42737 .7357 .42895 .74196 .42387 .73918 .42219 Mtetra
.832 .92 .894 r
.73918 .42219 .74196 .42387 .74823 .41879 .74545 .417 Mtetra
.832 .914 .892 r
.74545 .417 .74823 .41879 .75449 .4137 .75173 .41181 Mtetra
.831 .908 .891 r
.75173 .41181 .75449 .4137 .76076 .40861 .758 .40661 Mtetra
.831 .902 .889 r
.758 .40661 .76076 .40861 .76703 .40352 .76428 .40142 Mtetra
.83 .896 .887 r
.76428 .40142 .76703 .40352 .7733 .39843 .77056 .39622 Mtetra
.829 .89 .885 r
.77056 .39622 .7733 .39843 .77958 .39333 .77685 .39102 Mtetra
.828 .884 .883 r
.77685 .39102 .77958 .39333 .78585 .38823 .78313 .38582 Mtetra
.827 .878 .881 r
.78313 .38582 .78585 .38823 .79213 .38313 .78942 .38061 Mtetra
.826 .872 .879 r
.78942 .38061 .79213 .38313 .79842 .37802 .79571 .3754 Mtetra
.825 .866 .877 r
.79571 .3754 .79842 .37802 .8047 .37292 .802 .37019 Mtetra
.823 .86 .874 r
.802 .37019 .8047 .37292 .81099 .36781 .8083 .36498 Mtetra
.822 .854 .872 r
.8083 .36498 .81099 .36781 .81727 .36269 .81459 .35977 Mtetra
.82 .849 .869 r
.81459 .35977 .81727 .36269 .82357 .35758 .82089 .35455 Mtetra
.819 .843 .867 r
.82089 .35455 .82357 .35758 .82986 .35246 .82719 .34933 Mtetra
.817 .837 .864 r
.82719 .34933 .82986 .35246 .83615 .34734 .83349 .3441 Mtetra
.816 .831 .862 r
.83349 .3441 .83615 .34734 .84245 .34221 .83979 .33887 Mtetra
.814 .826 .859 r
.83979 .33887 .84245 .34221 .84875 .33709 .8461 .33365 Mtetra
.812 .82 .857 r
.8461 .33365 .84875 .33709 .85506 .33196 .8524 .32842 Mtetra
.81 .815 .854 r
.8524 .32842 .85506 .33196 .86136 .32684 .85871 .3232 Mtetra
.807 .809 .853 r
.85871 .3232 .86136 .32684 .86767 .32175 .86503 .31801 Mtetra
.802 .803 .853 r
.86503 .31801 .86767 .32175 .874 .31675 .87136 .31292 Mtetra
.794 .797 .854 r
.87136 .31292 .874 .31675 .88034 .31192 .87771 .308 Mtetra
.782 .789 .859 r
.87771 .308 .88034 .31192 .88673 .30736 .8841 .30336 Mtetra
.443 .664 .955 r
.287 .49386 .2905 .49711 .29575 .49741 .29225 .49421 Mtetra
.349 .623 .954 r
.29225 .49421 .29575 .49741 .30098 .49823 .29748 .49511 Mtetra
.304 .606 .952 r
.29748 .49511 .30098 .49823 .30622 .49925 .30272 .4962 Mtetra
.276 .597 .95 r
.30272 .4962 .30622 .49925 .31148 .50036 .30797 .49739 Mtetra
.255 .591 .948 r
.30797 .49739 .31148 .50036 .31675 .50153 .31324 .49864 Mtetra
.24 .589 .948 r
.31324 .49864 .31675 .50153 .32204 .50271 .31853 .4999 Mtetra
.229 .59 .947 r
.31853 .4999 .32204 .50271 .32735 .50389 .32384 .50117 Mtetra
.215 .589 .946 r
.32384 .50117 .32735 .50389 .33268 .50508 .32917 .50244 Mtetra
.201 .587 .944 r
.32917 .50244 .33268 .50508 .33803 .50628 .33452 .50372 Mtetra
.188 .586 .941 r
.33452 .50372 .33803 .50628 .3434 .50748 .3399 .505 Mtetra
.175 .584 .938 r
.3399 .505 .3434 .50748 .3488 .50868 .34529 .50628 Mtetra
.159 .581 .934 r
.34529 .50628 .3488 .50868 .35421 .50988 .3507 .50758 Mtetra
.143 .578 .929 r
.3507 .50758 .35421 .50988 .35965 .51109 .35614 .50887 Mtetra
.129 .575 .923 r
.35614 .50887 .35965 .51109 .3651 .5123 .3616 .51017 Mtetra
.112 .571 .916 r
.3616 .51017 .3651 .5123 .37058 .51352 .36708 .51147 Mtetra
.095 .565 .908 r
.36708 .51147 .37058 .51352 .37608 .51474 .37258 .51278 Mtetra
.078 .56 .899 r
.37258 .51278 .37608 .51474 .3816 .51597 .37811 .51409 Mtetra
.061 .554 .889 r
.37811 .51409 .3816 .51597 .38715 .51719 .38365 .5154 Mtetra
.042 .547 .878 r
.38365 .5154 .38715 .51719 .39271 .51843 .38922 .51672 Mtetra
.024 .539 .866 r
.38922 .51672 .39271 .51843 .3983 .51967 .39481 .51805 Mtetra
.006 .532 .853 r
.39481 .51805 .3983 .51967 .40391 .52091 .40042 .51938 Mtetra
0 .522 .838 r
.40042 .51938 .40391 .52091 .40954 .52215 .40606 .52071 Mtetra
0 .512 .822 r
.40606 .52071 .40954 .52215 .41519 .52341 .41172 .52205 Mtetra
0 .502 .806 r
.41172 .52205 .41519 .52341 .42087 .52466 .4174 .5234 Mtetra
0 .491 .788 r
.4174 .5234 .42087 .52466 .42657 .52592 .4231 .52475 Mtetra
0 .479 .769 r
.4231 .52475 .42657 .52592 .43229 .52719 .42883 .52611 Mtetra
0 .467 .75 r
.42883 .52611 .43229 .52719 .43804 .52846 .43458 .52747 Mtetra
0 .455 .73 r
.43458 .52747 .43804 .52846 .4438 .52974 .44035 .52883 Mtetra
0 .441 .708 r
.44035 .52883 .4438 .52974 .44959 .53102 .44615 .53021 Mtetra
.165 0 0 r
.44615 .53021 .44959 .53102 .45541 .53231 .45197 .53159 Mtetra
.182 0 0 r
.45197 .53159 .45541 .53231 .46125 .5336 .45782 .53297 Mtetra
.199 0 0 r
.45782 .53297 .46125 .5336 .46711 .5349 .46369 .53436 Mtetra
.217 0 0 r
.46369 .53436 .46711 .5349 .47299 .5362 .46958 .53576 Mtetra
.233 0 0 r
.46958 .53576 .47299 .5362 .4789 .53751 .4755 .53717 Mtetra
.249 0 0 r
.4755 .53717 .4789 .53751 .48484 .53883 .48144 .53858 Mtetra
.265 0 0 r
.48144 .53858 .48484 .53883 .49079 .54015 .48741 .54 Mtetra
.28 0 0 r
.48741 .54 .49079 .54015 .49677 .54148 .4934 .54142 Mtetra
.294 0 0 r
.4934 .54142 .49677 .54148 .50278 .54281 .49942 .54285 Mtetra
.307 0 0 r
.49942 .54285 .50278 .54281 .50881 .54416 .50546 .54429 Mtetra
.321 0 0 r
.50546 .54429 .50881 .54416 .51487 .54551 .51153 .54574 Mtetra
.333 0 0 r
.51153 .54574 .51487 .54551 .52095 .54686 .51762 .54719 Mtetra
.345 0 0 r
.51762 .54719 .52095 .54686 .52705 .54822 .52374 .54865 Mtetra
.357 0 0 r
.52374 .54865 .52705 .54822 .53318 .54959 .52988 .55012 Mtetra
.368 0 0 r
.52988 .55012 .53318 .54959 .53934 .55097 .53605 .5516 Mtetra
.377 0 0 r
.53605 .5516 .53934 .55097 .54552 .55234 .54225 .55307 Mtetra
.385 0 0 r
.54225 .55307 .54552 .55234 .55173 .55371 .54847 .55454 Mtetra
.389 0 0 r
.54847 .55454 .55173 .55371 .55796 .55505 .55472 .55597 Mtetra
.376 0 0 r
.55472 .55597 .55796 .55505 .56422 .55624 .56099 .55726 Mtetra
.338 0 0 r
.56099 .55726 .56422 .55624 .5705 .55711 .56728 .55821 Mtetra
0 0 0 r
.56728 .55821 .5705 .55711 .57677 .55577 .57357 .55688 Mtetra
.657 .966 .796 r
.57357 .55688 .57677 .55577 .583 .55116 .57982 .55218 Mtetra
.702 .981 .809 r
.57982 .55218 .583 .55116 .58922 .54627 .58606 .54718 Mtetra
.731 .989 .818 r
.58606 .54718 .58922 .54627 .59545 .54119 .59231 .54199 Mtetra
.748 .993 .827 r
.59231 .54199 .59545 .54119 .60168 .53604 .59855 .53673 Mtetra
.758 .995 .836 r
.59855 .53673 .60168 .53604 .6079 .53088 .6048 .53146 Mtetra
.767 .997 .843 r
.6048 .53146 .6079 .53088 .61414 .52571 .61105 .52619 Mtetra
.776 .997 .851 r
.61105 .52619 .61414 .52571 .62037 .52054 .6173 .5209 Mtetra
.783 .997 .857 r
.6173 .5209 .62037 .52054 .6266 .51537 .62355 .51562 Mtetra
.79 .996 .863 r
.62355 .51562 .6266 .51537 .63284 .5102 .62981 .51034 Mtetra
.796 .995 .869 r
.62981 .51034 .63284 .5102 .63908 .50503 .63606 .50506 Mtetra
.802 .993 .873 r
.63606 .50506 .63908 .50503 .64532 .49986 .64232 .49978 Mtetra
.807 .991 .878 r
.64232 .49978 .64532 .49986 .65156 .49469 .64858 .4945 Mtetra
.812 .988 .881 r
.64858 .4945 .65156 .49469 .65781 .48952 .65484 .48922 Mtetra
.816 .985 .884 r
.65484 .48922 .65781 .48952 .66405 .48435 .6611 .48394 Mtetra
.82 .981 .887 r
.6611 .48394 .66405 .48435 .6703 .47917 .66736 .47866 Mtetra
.823 .977 .889 r
.66736 .47866 .6703 .47917 .67655 .474 .67363 .47338 Mtetra
.826 .973 .891 r
.67363 .47338 .67655 .474 .68281 .46883 .6799 .46809 Mtetra
.828 .969 .892 r
.6799 .46809 .68281 .46883 .68906 .46365 .68616 .46281 Mtetra
.83 .964 .893 r
.68616 .46281 .68906 .46365 .69532 .45847 .69243 .45752 Mtetra
.832 .959 .894 r
.69243 .45752 .69532 .45847 .70158 .45329 .69871 .45224 Mtetra
.833 .954 .894 r
.69871 .45224 .70158 .45329 .70784 .44811 .70498 .44695 Mtetra
.834 .948 .894 r
.70498 .44695 .70784 .44811 .7141 .44293 .71126 .44166 Mtetra
.835 .943 .894 r
.71126 .44166 .7141 .44293 .72037 .43775 .71753 .43637 Mtetra
.836 .937 .893 r
.71753 .43637 .72037 .43775 .72664 .43256 .72381 .43108 Mtetra
.836 .932 .893 r
.72381 .43108 .72664 .43256 .73291 .42737 .73009 .42579 Mtetra
.836 .926 .892 r
.73009 .42579 .73291 .42737 .73918 .42219 .73638 .4205 Mtetra
.836 .92 .891 r
.73638 .4205 .73918 .42219 .74545 .417 .74266 .4152 Mtetra
.836 .914 .889 r
.74266 .4152 .74545 .417 .75173 .41181 .74895 .4099 Mtetra
.835 .908 .888 r
.74895 .4099 .75173 .41181 .758 .40661 .75523 .4046 Mtetra
.834 .902 .886 r
.75523 .4046 .758 .40661 .76428 .40142 .76152 .39931 Mtetra
.834 .896 .884 r
.76152 .39931 .76428 .40142 .77056 .39622 .76781 .394 Mtetra
.833 .89 .882 r
.76781 .394 .77056 .39622 .77685 .39102 .77411 .3887 Mtetra
.832 .884 .881 r
.77411 .3887 .77685 .39102 .78313 .38582 .7804 .38339 Mtetra
.83 .878 .878 r
.7804 .38339 .78313 .38582 .78942 .38061 .7867 .37808 Mtetra
.829 .872 .876 r
.7867 .37808 .78942 .38061 .79571 .3754 .79299 .37277 Mtetra
.828 .866 .874 r
.79299 .37277 .79571 .3754 .802 .37019 .79929 .36746 Mtetra
.826 .86 .872 r
.79929 .36746 .802 .37019 .8083 .36498 .80559 .36214 Mtetra
.825 .855 .869 r
.80559 .36214 .8083 .36498 .81459 .35977 .81189 .35682 Mtetra
.824 .849 .867 r
.81189 .35682 .81459 .35977 .82089 .35455 .8182 .3515 Mtetra
.822 .843 .865 r
.8182 .3515 .82089 .35455 .82719 .34933 .8245 .34618 Mtetra
.82 .838 .862 r
.8245 .34618 .82719 .34933 .83349 .3441 .83081 .34086 Mtetra
.819 .832 .859 r
.83081 .34086 .83349 .3441 .83979 .33887 .83712 .33552 Mtetra
.817 .826 .857 r
.83712 .33552 .83979 .33887 .8461 .33365 .84343 .3302 Mtetra
.815 .821 .855 r
.84343 .3302 .8461 .33365 .8524 .32842 .84974 .32487 Mtetra
.813 .816 .852 r
.84974 .32487 .8524 .32842 .85871 .3232 .85606 .31954 Mtetra
.81 .81 .85 r
.85606 .31954 .85871 .3232 .86503 .31801 .86238 .31425 Mtetra
.805 .804 .851 r
.86238 .31425 .86503 .31801 .87136 .31292 .86871 .30907 Mtetra
.797 .797 .852 r
.86871 .30907 .87136 .31292 .87771 .308 .87506 .30406 Mtetra
.785 .79 .857 r
.87506 .30406 .87771 .308 .8841 .30336 .88146 .29933 Mtetra
.434 .66 .955 r
.28349 .49059 .287 .49386 .29225 .49421 .28874 .491 Mtetra
.335 .616 .953 r
.28874 .491 .29225 .49421 .29748 .49511 .29397 .49197 Mtetra
.288 .597 .949 r
.29397 .49197 .29748 .49511 .30272 .4962 .29921 .49314 Mtetra
.259 .587 .947 r
.29921 .49314 .30272 .4962 .30797 .49739 .30446 .49441 Mtetra
.236 .581 .944 r
.30446 .49441 .30797 .49739 .31324 .49864 .30972 .49573 Mtetra
.221 .579 .943 r
.30972 .49573 .31324 .49864 .31853 .4999 .31501 .49708 Mtetra
.21 .579 .942 r
.31501 .49708 .31853 .4999 .32384 .50117 .32032 .49843 Mtetra
.196 .577 .94 r
.32032 .49843 .32384 .50117 .32917 .50244 .32565 .49979 Mtetra
.181 .575 .938 r
.32565 .49979 .32917 .50244 .33452 .50372 .331 .50115 Mtetra
.168 .574 .935 r
.331 .50115 .33452 .50372 .3399 .505 .33637 .50252 Mtetra
.154 .572 .931 r
.33637 .50252 .3399 .505 .34529 .50628 .34177 .50388 Mtetra
.138 .568 .926 r
.34177 .50388 .34529 .50628 .3507 .50758 .34718 .50526 Mtetra
.122 .565 .921 r
.34718 .50526 .3507 .50758 .35614 .50887 .35262 .50664 Mtetra
.108 .561 .915 r
.35262 .50664 .35614 .50887 .3616 .51017 .35808 .50802 Mtetra
.091 .556 .907 r
.35808 .50802 .3616 .51017 .36708 .51147 .36356 .50941 Mtetra
.073 .551 .898 r
.36356 .50941 .36708 .51147 .37258 .51278 .36906 .5108 Mtetra
.056 .545 .889 r
.36906 .5108 .37258 .51278 .37811 .51409 .37459 .5122 Mtetra
.039 .539 .879 r
.37459 .5122 .37811 .51409 .38365 .5154 .38014 .5136 Mtetra
.02 .531 .867 r
.38014 .5136 .38365 .5154 .38922 .51672 .38571 .51501 Mtetra
.001 .523 .854 r
.38571 .51501 .38922 .51672 .39481 .51805 .3913 .51642 Mtetra
0 .515 .84 r
.3913 .51642 .39481 .51805 .40042 .51938 .39692 .51784 Mtetra
0 .505 .825 r
.39692 .51784 .40042 .51938 .40606 .52071 .40256 .51926 Mtetra
0 .495 .809 r
.40256 .51926 .40606 .52071 .41172 .52205 .40822 .52069 Mtetra
0 .485 .792 r
.40822 .52069 .41172 .52205 .4174 .5234 .41391 .52213 Mtetra
0 .474 .774 r
.41391 .52213 .4174 .5234 .4231 .52475 .41962 .52357 Mtetra
0 .461 .755 r
.41962 .52357 .4231 .52475 .42883 .52611 .42535 .52501 Mtetra
0 .449 .735 r
.42535 .52501 .42883 .52611 .43458 .52747 .43111 .52647 Mtetra
0 .437 .715 r
.43111 .52647 .43458 .52747 .44035 .52883 .43689 .52793 Mtetra
0 .423 .694 r
.43689 .52793 .44035 .52883 .44615 .53021 .44269 .52939 Mtetra
.185 0 0 r
.44269 .52939 .44615 .53021 .45197 .53159 .44852 .53086 Mtetra
.201 0 0 r
.44852 .53086 .45197 .53159 .45782 .53297 .45437 .53234 Mtetra
.218 0 0 r
.45437 .53234 .45782 .53297 .46369 .53436 .46025 .53382 Mtetra
.236 0 0 r
.46025 .53382 .46369 .53436 .46958 .53576 .46615 .53532 Mtetra
.251 0 0 r
.46615 .53532 .46958 .53576 .4755 .53717 .47208 .53682 Mtetra
.266 0 0 r
.47208 .53682 .4755 .53717 .48144 .53858 .47803 .53832 Mtetra
.282 0 0 r
.47803 .53832 .48144 .53858 .48741 .54 .48401 .53984 Mtetra
.297 0 0 r
.48401 .53984 .48741 .54 .4934 .54142 .49001 .54136 Mtetra
.31 0 0 r
.49001 .54136 .4934 .54142 .49942 .54285 .49603 .54288 Mtetra
.323 0 0 r
.49603 .54288 .49942 .54285 .50546 .54429 .50209 .54442 Mtetra
.337 0 0 r
.50209 .54442 .50546 .54429 .51153 .54574 .50817 .54596 Mtetra
.348 0 0 r
.50817 .54596 .51153 .54574 .51762 .54719 .51427 .54751 Mtetra
.359 0 0 r
.51427 .54751 .51762 .54719 .52374 .54865 .5204 .54907 Mtetra
.371 0 0 r
.5204 .54907 .52374 .54865 .52988 .55012 .52656 .55064 Mtetra
.381 0 0 r
.52656 .55064 .52988 .55012 .53605 .5516 .53274 .55222 Mtetra
.389 0 0 r
.53274 .55222 .53605 .5516 .54225 .55307 .53895 .55379 Mtetra
.397 0 0 r
.53895 .55379 .54225 .55307 .54847 .55454 .54519 .55536 Mtetra
.401 0 0 r
.54519 .55536 .54847 .55454 .55472 .55597 .55145 .5569 Mtetra
.388 0 0 r
.55145 .5569 .55472 .55597 .56099 .55726 .55774 .55828 Mtetra
.348 0 0 r
.55774 .55828 .56099 .55726 .56728 .55821 .56405 .55931 Mtetra
0 0 0 r
.56405 .55931 .56728 .55821 .57357 .55688 .57035 .558 Mtetra
.667 .97 .798 r
.57035 .558 .57357 .55688 .57982 .55218 .57662 .5532 Mtetra
.711 .984 .809 r
.57662 .5532 .57982 .55218 .58606 .54718 .58288 .5481 Mtetra
.74 .991 .818 r
.58288 .5481 .58606 .54718 .59231 .54199 .58915 .5428 Mtetra
.757 .995 .827 r
.58915 .5428 .59231 .54199 .59855 .53673 .59541 .53743 Mtetra
.766 .997 .835 r
.59541 .53743 .59855 .53673 .6048 .53146 .60168 .53204 Mtetra
.775 .998 .842 r
.60168 .53204 .6048 .53146 .61105 .52619 .60794 .52666 Mtetra
.783 .998 .849 r
.60794 .52666 .61105 .52619 .6173 .5209 .61421 .52126 Mtetra
.79 .997 .856 r
.61421 .52126 .6173 .5209 .62355 .51562 .62048 .51587 Mtetra
.796 .996 .861 r
.62048 .51587 .62355 .51562 .62981 .51034 .62675 .51048 Mtetra
.803 .995 .866 r
.62675 .51048 .62981 .51034 .63606 .50506 .63302 .50509 Mtetra
.808 .993 .871 r
.63302 .50509 .63606 .50506 .64232 .49978 .6393 .4997 Mtetra
.813 .991 .875 r
.6393 .4997 .64232 .49978 .64858 .4945 .64557 .49431 Mtetra
.817 .988 .879 r
.64557 .49431 .64858 .4945 .65484 .48922 .65185 .48892 Mtetra
.821 .984 .881 r
.65185 .48892 .65484 .48922 .6611 .48394 .65813 .48353 Mtetra
.825 .981 .884 r
.65813 .48353 .6611 .48394 .66736 .47866 .6644 .47813 Mtetra
.828 .977 .886 r
.6644 .47813 .66736 .47866 .67363 .47338 .67068 .47275 Mtetra
.831 .973 .888 r
.67068 .47275 .67363 .47338 .6799 .46809 .67697 .46735 Mtetra
.833 .968 .889 r
.67697 .46735 .6799 .46809 .68616 .46281 .68325 .46196 Mtetra
.834 .963 .89 r
.68325 .46196 .68616 .46281 .69243 .45752 .68953 .45657 Mtetra
.836 .958 .891 r
.68953 .45657 .69243 .45752 .69871 .45224 .69582 .45117 Mtetra
.837 .953 .891 r
.69582 .45117 .69871 .45224 .70498 .44695 .7021 .44578 Mtetra
.838 .948 .891 r
.7021 .44578 .70498 .44695 .71126 .44166 .70839 .44038 Mtetra
.839 .942 .891 r
.70839 .44038 .71126 .44166 .71753 .43637 .71468 .43499 Mtetra
.84 .937 .89 r
.71468 .43499 .71753 .43637 .72381 .43108 .72097 .42959 Mtetra
.84 .931 .889 r
.72097 .42959 .72381 .43108 .73009 .42579 .72727 .42419 Mtetra
.84 .925 .889 r
.72727 .42419 .73009 .42579 .73638 .4205 .73356 .41879 Mtetra
.839 .92 .887 r
.73356 .41879 .73638 .4205 .74266 .4152 .73985 .41339 Mtetra
.839 .914 .886 r
.73985 .41339 .74266 .4152 .74895 .4099 .74615 .40799 Mtetra
.838 .908 .885 r
.74615 .40799 .74895 .4099 .75523 .4046 .75245 .40258 Mtetra
.838 .902 .883 r
.75245 .40258 .75523 .4046 .76152 .39931 .75875 .39718 Mtetra
.837 .896 .881 r
.75875 .39718 .76152 .39931 .76781 .394 .76505 .39177 Mtetra
.836 .89 .879 r
.76505 .39177 .76781 .394 .77411 .3887 .77135 .38636 Mtetra
.835 .884 .878 r
.77135 .38636 .77411 .3887 .7804 .38339 .77765 .38095 Mtetra
.834 .878 .875 r
.77765 .38095 .7804 .38339 .7867 .37808 .78396 .37554 Mtetra
.833 .872 .873 r
.78396 .37554 .7867 .37808 .79299 .37277 .79026 .37012 Mtetra
.831 .866 .871 r
.79026 .37012 .79299 .37277 .79929 .36746 .79657 .36471 Mtetra
.83 .861 .869 r
.79657 .36471 .79929 .36746 .80559 .36214 .80288 .35929 Mtetra
.828 .855 .866 r
.80288 .35929 .80559 .36214 .81189 .35682 .80919 .35387 Mtetra
.827 .849 .864 r
.80919 .35387 .81189 .35682 .8182 .3515 .8155 .34844 Mtetra
.825 .843 .862 r
.8155 .34844 .8182 .3515 .8245 .34618 .82181 .34302 Mtetra
.823 .838 .859 r
.82181 .34302 .8245 .34618 .83081 .34086 .82812 .33759 Mtetra
.822 .832 .857 r
.82812 .33759 .83081 .34086 .83712 .33552 .83443 .33216 Mtetra
.82 .827 .855 r
.83443 .33216 .83712 .33552 .84343 .3302 .84075 .32673 Mtetra
.818 .821 .852 r
.84075 .32673 .84343 .3302 .84974 .32487 .84707 .3213 Mtetra
.816 .816 .85 r
.84707 .3213 .84974 .32487 .85606 .31954 .85339 .31587 Mtetra
.813 .811 .848 r
.85339 .31587 .85606 .31954 .86238 .31425 .85971 .31048 Mtetra
.807 .805 .848 r
.85971 .31048 .86238 .31425 .86871 .30907 .86605 .3052 Mtetra
.799 .798 .85 r
.86605 .3052 .86871 .30907 .87506 .30406 .87241 .3001 Mtetra
.787 .791 .855 r
.87241 .3001 .87506 .30406 .88146 .29933 .8788 .29529 Mtetra
.425 .655 .956 r
.27996 .48732 .28349 .49059 .28874 .491 .28522 .48777 Mtetra
.321 .609 .951 r
.28522 .48777 .28874 .491 .29397 .49197 .29044 .48881 Mtetra
.272 .588 .946 r
.29044 .48881 .29397 .49197 .29921 .49314 .29568 .49006 Mtetra
.241 .578 .943 r
.29568 .49006 .29921 .49314 .30446 .49441 .30093 .49141 Mtetra
.218 .571 .94 r
.30093 .49141 .30446 .49441 .30972 .49573 .30619 .49282 Mtetra
.202 .568 .938 r
.30619 .49282 .30972 .49573 .31501 .49708 .31148 .49425 Mtetra
.19 .568 .937 r
.31148 .49425 .31501 .49708 .32032 .49843 .31678 .49568 Mtetra
.176 .566 .935 r
.31678 .49568 .32032 .49843 .32565 .49979 .32211 .49712 Mtetra
.161 .563 .931 r
.32211 .49712 .32565 .49979 .331 .50115 .32746 .49857 Mtetra
.148 .561 .928 r
.32746 .49857 .331 .50115 .33637 .50252 .33283 .50002 Mtetra
.133 .559 .924 r
.33283 .50002 .33637 .50252 .34177 .50388 .33823 .50147 Mtetra
.117 .555 .918 r
.33823 .50147 .34177 .50388 .34718 .50526 .34364 .50293 Mtetra
.101 .551 .912 r
.34364 .50293 .34718 .50526 .35262 .50664 .34908 .50439 Mtetra
.086 .547 .906 r
.34908 .50439 .35262 .50664 .35808 .50802 .35454 .50586 Mtetra
.069 .542 .897 r
.35454 .50586 .35808 .50802 .36356 .50941 .36002 .50733 Mtetra
.051 .535 .888 r
.36002 .50733 .36356 .50941 .36906 .5108 .36553 .50882 Mtetra
.034 .53 .878 r
.36553 .50882 .36906 .5108 .37459 .5122 .37106 .5103 Mtetra
.016 .523 .867 r
.37106 .5103 .37459 .5122 .38014 .5136 .37661 .51179 Mtetra
0 .515 .854 r
.37661 .51179 .38014 .5136 .38571 .51501 .38218 .51328 Mtetra
0 .506 .841 r
.38218 .51328 .38571 .51501 .3913 .51642 .38778 .51479 Mtetra
0 .498 .827 r
.38778 .51479 .3913 .51642 .39692 .51784 .3934 .51629 Mtetra
0 .488 .812 r
.3934 .51629 .39692 .51784 .40256 .51926 .39904 .5178 Mtetra
0 .477 .795 r
.39904 .5178 .40256 .51926 .40822 .52069 .40471 .51932 Mtetra
0 .467 .778 r
.40471 .51932 .40822 .52069 .41391 .52213 .4104 .52085 Mtetra
0 .456 .76 r
.4104 .52085 .41391 .52213 .41962 .52357 .41611 .52238 Mtetra
0 .443 .74 r
.41611 .52238 .41962 .52357 .42535 .52501 .42185 .52392 Mtetra
0 .431 .72 r
.42185 .52392 .42535 .52501 .43111 .52647 .42761 .52546 Mtetra
0 .419 .7 r
.42761 .52546 .43111 .52647 .43689 .52793 .4334 .52701 Mtetra
.187 0 0 r
.4334 .52701 .43689 .52793 .44269 .52939 .43921 .52857 Mtetra
.205 0 0 r
.43921 .52857 .44269 .52939 .44852 .53086 .44505 .53014 Mtetra
.221 0 0 r
.44505 .53014 .44852 .53086 .45437 .53234 .45091 .53171 Mtetra
.238 0 0 r
.45091 .53171 .45437 .53234 .46025 .53382 .45679 .53328 Mtetra
.255 0 0 r
.45679 .53328 .46025 .53382 .46615 .53532 .4627 .53487 Mtetra
.27 0 0 r
.4627 .53487 .46615 .53532 .47208 .53682 .46864 .53647 Mtetra
.284 0 0 r
.46864 .53647 .47208 .53682 .47803 .53832 .4746 .53806 Mtetra
.299 0 0 r
.4746 .53806 .47803 .53832 .48401 .53984 .48058 .53967 Mtetra
.314 0 0 r
.48058 .53967 .48401 .53984 .49001 .54136 .48659 .54129 Mtetra
.326 0 0 r
.48659 .54129 .49001 .54136 .49603 .54288 .49263 .54292 Mtetra
.339 0 0 r
.49263 .54292 .49603 .54288 .50209 .54442 .49869 .54455 Mtetra
.352 0 0 r
.49869 .54455 .50209 .54442 .50817 .54596 .50478 .54619 Mtetra
.363 0 0 r
.50478 .54619 .50817 .54596 .51427 .54751 .5109 .54784 Mtetra
.373 0 0 r
.5109 .54784 .51427 .54751 .5204 .54907 .51704 .5495 Mtetra
.385 0 0 r
.51704 .5495 .5204 .54907 .52656 .55064 .52321 .55117 Mtetra
.395 0 0 r
.52321 .55117 .52656 .55064 .53274 .55222 .52941 .55284 Mtetra
.402 0 0 r
.52941 .55284 .53274 .55222 .53895 .55379 .53563 .55452 Mtetra
.41 0 0 r
.53563 .55452 .53895 .55379 .54519 .55536 .54188 .55619 Mtetra
.413 0 0 r
.54188 .55619 .54519 .55536 .55145 .5569 .54816 .55783 Mtetra
.399 0 0 r
.54816 .55783 .55145 .5569 .55774 .55828 .55446 .5593 Mtetra
.359 0 0 r
.55446 .5593 .55774 .55828 .56405 .55931 .56079 .56042 Mtetra
0 0 0 r
.56079 .56042 .56405 .55931 .57035 .558 .56711 .55912 Mtetra
.676 .973 .799 r
.56711 .55912 .57035 .558 .57662 .5532 .5734 .55423 Mtetra
.72 .986 .809 r
.5734 .55423 .57662 .5532 .58288 .5481 .57968 .54902 Mtetra
.749 .993 .818 r
.57968 .54902 .58288 .5481 .58915 .5428 .58597 .54361 Mtetra
.765 .996 .826 r
.58597 .54361 .58915 .5428 .59541 .53743 .59225 .53812 Mtetra
.774 .998 .833 r
.59225 .53812 .59541 .53743 .60168 .53204 .59853 .53263 Mtetra
.782 .998 .841 r
.59853 .53263 .60168 .53204 .60794 .52666 .60482 .52713 Mtetra
.79 .998 .847 r
.60482 .52713 .60794 .52666 .61421 .52126 .6111 .52162 Mtetra
.797 .998 .853 r
.6111 .52162 .61421 .52126 .62048 .51587 .61739 .51612 Mtetra
.803 .997 .859 r
.61739 .51612 .62048 .51587 .62675 .51048 .62368 .51062 Mtetra
.809 .995 .864 r
.62368 .51062 .62675 .51048 .63302 .50509 .62997 .50512 Mtetra
.814 .993 .868 r
.62997 .50512 .63302 .50509 .6393 .4997 .63626 .49961 Mtetra
.818 .99 .872 r
.63626 .49961 .6393 .4997 .64557 .49431 .64255 .49411 Mtetra
.823 .987 .876 r
.64255 .49411 .64557 .49431 .65185 .48892 .64884 .48861 Mtetra
.827 .984 .878 r
.64884 .48861 .65185 .48892 .65813 .48353 .65513 .48311 Mtetra
.83 .98 .881 r
.65513 .48311 .65813 .48353 .6644 .47813 .66143 .47761 Mtetra
.833 .976 .883 r
.66143 .47761 .6644 .47813 .67068 .47275 .66772 .47211 Mtetra
.835 .972 .885 r
.66772 .47211 .67068 .47275 .67697 .46735 .67402 .46661 Mtetra
.837 .968 .886 r
.67402 .46661 .67697 .46735 .68325 .46196 .68032 .4611 Mtetra
.839 .963 .887 r
.68032 .4611 .68325 .46196 .68953 .45657 .68661 .4556 Mtetra
.84 .958 .887 r
.68661 .4556 .68953 .45657 .69582 .45117 .69291 .4501 Mtetra
.842 .953 .888 r
.69291 .4501 .69582 .45117 .7021 .44578 .69921 .4446 Mtetra
.842 .947 .888 r
.69921 .4446 .7021 .44578 .70839 .44038 .70551 .4391 Mtetra
.843 .942 .887 r
.70551 .4391 .70839 .44038 .71468 .43499 .71182 .43359 Mtetra
.843 .936 .887 r
.71182 .43359 .71468 .43499 .72097 .42959 .71812 .42809 Mtetra
.843 .931 .886 r
.71812 .42809 .72097 .42959 .72727 .42419 .72442 .42258 Mtetra
.843 .925 .885 r
.72442 .42258 .72727 .42419 .73356 .41879 .73073 .41708 Mtetra
.843 .919 .884 r
.73073 .41708 .73356 .41879 .73985 .41339 .73703 .41157 Mtetra
.843 .913 .883 r
.73703 .41157 .73985 .41339 .74615 .40799 .74334 .40606 Mtetra
.842 .908 .882 r
.74334 .40606 .74615 .40799 .75245 .40258 .74965 .40055 Mtetra
.841 .902 .88 r
.74965 .40055 .75245 .40258 .75875 .39718 .75596 .39504 Mtetra
.84 .896 .878 r
.75596 .39504 .75875 .39718 .76505 .39177 .76227 .38953 Mtetra
.839 .89 .876 r
.76227 .38953 .76505 .39177 .77135 .38636 .76858 .38401 Mtetra
.838 .884 .875 r
.76858 .38401 .77135 .38636 .77765 .38095 .77489 .3785 Mtetra
.837 .878 .873 r
.77489 .3785 .77765 .38095 .78396 .37554 .7812 .37298 Mtetra
.836 .872 .87 r
.7812 .37298 .78396 .37554 .79026 .37012 .78752 .36746 Mtetra
.834 .867 .868 r
.78752 .36746 .79026 .37012 .79657 .36471 .79383 .36194 Mtetra
.833 .861 .866 r
.79383 .36194 .79657 .36471 .80288 .35929 .80015 .35642 Mtetra
.831 .855 .864 r
.80015 .35642 .80288 .35929 .80919 .35387 .80646 .3509 Mtetra
.83 .849 .862 r
.80646 .3509 .80919 .35387 .8155 .34844 .81278 .34537 Mtetra
.828 .844 .859 r
.81278 .34537 .8155 .34844 .82181 .34302 .8191 .33984 Mtetra
.826 .838 .857 r
.8191 .33984 .82181 .34302 .82812 .33759 .82542 .33431 Mtetra
.825 .833 .854 r
.82542 .33431 .82812 .33759 .83443 .33216 .83174 .32878 Mtetra
.823 .827 .852 r
.83174 .32878 .83443 .33216 .84075 .32673 .83806 .32324 Mtetra
.821 .822 .85 r
.83806 .32324 .84075 .32673 .84707 .3213 .84438 .31772 Mtetra
.819 .817 .847 r
.84438 .31772 .84707 .3213 .85339 .31587 .8507 .31219 Mtetra
.816 .811 .846 r
.8507 .31219 .85339 .31587 .85971 .31048 .85703 .3067 Mtetra
.81 .805 .846 r
.85703 .3067 .85971 .31048 .86605 .3052 .86337 .30132 Mtetra
.802 .799 .849 r
.86337 .30132 .86605 .3052 .87241 .3001 .86974 .29612 Mtetra
.79 .791 .854 r
.86974 .29612 .87241 .3001 .8788 .29529 .87614 .29124 Mtetra
.416 .651 .956 r
.27643 .48403 .27996 .48732 .28522 .48777 .28168 .48454 Mtetra
.307 .601 .949 r
.28168 .48454 .28522 .48777 .29044 .48881 .2869 .48565 Mtetra
.255 .579 .943 r
.2869 .48565 .29044 .48881 .29568 .49006 .29213 .48697 Mtetra
.223 .567 .939 r
.29213 .48697 .29568 .49006 .30093 .49141 .29738 .4884 Mtetra
.199 .56 .935 r
.29738 .4884 .30093 .49141 .30619 .49282 .30264 .48989 Mtetra
.182 .556 .932 r
.30264 .48989 .30619 .49282 .31148 .49425 .30793 .49141 Mtetra
.17 .556 .931 r
.30793 .49141 .31148 .49425 .31678 .49568 .31323 .49292 Mtetra
.156 .553 .928 r
.31323 .49292 .31678 .49568 .32211 .49712 .31856 .49444 Mtetra
.14 .55 .924 r
.31856 .49444 .32211 .49712 .32746 .49857 .32391 .49598 Mtetra
.126 .548 .92 r
.32391 .49598 .32746 .49857 .33283 .50002 .32928 .49751 Mtetra
.112 .545 .916 r
.32928 .49751 .33283 .50002 .33823 .50147 .33467 .49905 Mtetra
.095 .541 .909 r
.33467 .49905 .33823 .50147 .34364 .50293 .34009 .50059 Mtetra
.079 .536 .903 r
.34009 .50059 .34364 .50293 .34908 .50439 .34553 .50214 Mtetra
.063 .532 .896 r
.34553 .50214 .34908 .50439 .35454 .50586 .35099 .5037 Mtetra
.046 .526 .887 r
.35099 .5037 .35454 .50586 .36002 .50733 .35647 .50525 Mtetra
.028 .52 .877 r
.35647 .50525 .36002 .50733 .36553 .50882 .36198 .50682 Mtetra
.011 .514 .866 r
.36198 .50682 .36553 .50882 .37106 .5103 .36751 .50839 Mtetra
0 .506 .855 r
.36751 .50839 .37106 .5103 .37661 .51179 .37306 .50997 Mtetra
0 .498 .841 r
.37306 .50997 .37661 .51179 .38218 .51328 .37864 .51155 Mtetra
0 .489 .828 r
.37864 .51155 .38218 .51328 .38778 .51479 .38424 .51315 Mtetra
0 .48 .813 r
.38424 .51315 .38778 .51479 .3934 .51629 .38986 .51474 Mtetra
0 .47 .797 r
.38986 .51474 .3934 .51629 .39904 .5178 .39551 .51634 Mtetra
0 .459 .78 r
.39551 .51634 .39904 .5178 .40471 .51932 .40118 .51795 Mtetra
0 .449 .762 r
.40118 .51795 .40471 .51932 .4104 .52085 .40687 .51957 Mtetra
0 .437 .744 r
.40687 .51957 .4104 .52085 .41611 .52238 .41259 .52119 Mtetra
0 .424 .724 r
.41259 .52119 .41611 .52238 .42185 .52392 .41833 .52282 Mtetra
0 .412 .704 r
.41833 .52282 .42185 .52392 .42761 .52546 .4241 .52445 Mtetra
0 .4 .683 r
.4241 .52445 .42761 .52546 .4334 .52701 .42989 .5261 Mtetra
.208 0 0 r
.42989 .5261 .4334 .52701 .43921 .52857 .43571 .52775 Mtetra
.226 0 0 r
.43571 .52775 .43921 .52857 .44505 .53014 .44155 .52941 Mtetra
.241 0 0 r
.44155 .52941 .44505 .53014 .45091 .53171 .44742 .53107 Mtetra
.258 0 0 r
.44742 .53107 .45091 .53171 .45679 .53328 .45331 .53274 Mtetra
.274 0 0 r
.45331 .53274 .45679 .53328 .4627 .53487 .45923 .53443 Mtetra
.289 0 0 r
.45923 .53443 .4627 .53487 .46864 .53647 .46517 .53612 Mtetra
.303 0 0 r
.46517 .53612 .46864 .53647 .4746 .53806 .47114 .53781 Mtetra
.317 0 0 r
.47114 .53781 .4746 .53806 .48058 .53967 .47714 .53952 Mtetra
.331 0 0 r
.47714 .53952 .48058 .53967 .48659 .54129 .48316 .54123 Mtetra
.343 0 0 r
.48316 .54123 .48659 .54129 .49263 .54292 .48921 .54295 Mtetra
.355 0 0 r
.48921 .54295 .49263 .54292 .49869 .54455 .49528 .54468 Mtetra
.367 0 0 r
.49528 .54468 .49869 .54455 .50478 .54619 .50138 .54643 Mtetra
.378 0 0 r
.50138 .54643 .50478 .54619 .5109 .54784 .50751 .54818 Mtetra
.388 0 0 r
.50751 .54818 .5109 .54784 .51704 .5495 .51366 .54993 Mtetra
.399 0 0 r
.51366 .54993 .51704 .5495 .52321 .55117 .51984 .5517 Mtetra
.408 0 0 r
.51984 .5517 .52321 .55117 .52941 .55284 .52605 .55348 Mtetra
.415 0 0 r
.52605 .55348 .52941 .55284 .53563 .55452 .53229 .55526 Mtetra
.422 0 0 r
.53229 .55526 .53563 .55452 .54188 .55619 .53855 .55703 Mtetra
.425 0 0 r
.53855 .55703 .54188 .55619 .54816 .55783 .54485 .55877 Mtetra
.411 0 0 r
.54485 .55877 .54816 .55783 .55446 .5593 .55116 .56034 Mtetra
.371 0 0 r
.55116 .56034 .55446 .5593 .56079 .56042 .55751 .56155 Mtetra
0 0 0 r
.55751 .56155 .56079 .56042 .56711 .55912 .56385 .56026 Mtetra
.684 .975 .799 r
.56385 .56026 .56711 .55912 .5734 .55423 .57015 .55527 Mtetra
.728 .988 .809 r
.57015 .55527 .5734 .55423 .57968 .54902 .57646 .54996 Mtetra
.756 .994 .816 r
.57646 .54996 .57968 .54902 .58597 .54361 .58276 .54444 Mtetra
.772 .997 .824 r
.58276 .54444 .58597 .54361 .59225 .53812 .58907 .53883 Mtetra
.781 .998 .831 r
.58907 .53883 .59225 .53812 .59853 .53263 .59537 .53323 Mtetra
.789 .999 .839 r
.59537 .53323 .59853 .53263 .60482 .52713 .60167 .52761 Mtetra
.797 .999 .845 r
.60167 .52761 .60482 .52713 .6111 .52162 .60798 .52199 Mtetra
.803 .998 .851 r
.60798 .52199 .6111 .52162 .61739 .51612 .61428 .51637 Mtetra
.809 .997 .856 r
.61428 .51637 .61739 .51612 .62368 .51062 .62059 .51076 Mtetra
.814 .995 .861 r
.62059 .51076 .62368 .51062 .62997 .50512 .62689 .50515 Mtetra
.82 .993 .865 r
.62689 .50515 .62997 .50512 .63626 .49961 .6332 .49953 Mtetra
.824 .99 .869 r
.6332 .49953 .63626 .49961 .64255 .49411 .63951 .49392 Mtetra
.828 .987 .873 r
.63951 .49392 .64255 .49411 .64884 .48861 .64581 .48831 Mtetra
.831 .984 .875 r
.64581 .48831 .64884 .48861 .65513 .48311 .65212 .4827 Mtetra
.834 .98 .878 r
.65212 .4827 .65513 .48311 .66143 .47761 .65843 .47708 Mtetra
.837 .976 .88 r
.65843 .47708 .66143 .47761 .66772 .47211 .66474 .47147 Mtetra
.84 .972 .881 r
.66474 .47147 .66772 .47211 .67402 .46661 .67105 .46586 Mtetra
.842 .967 .883 r
.67105 .46586 .67402 .46661 .68032 .4611 .67737 .46025 Mtetra
.843 .963 .884 r
.67737 .46025 .68032 .4611 .68661 .4556 .68368 .45464 Mtetra
.844 .958 .884 r
.68368 .45464 .68661 .4556 .69291 .4501 .68999 .44903 Mtetra
.846 .952 .884 r
.68999 .44903 .69291 .4501 .69921 .4446 .6963 .44342 Mtetra
.846 .947 .884 r
.6963 .44342 .69921 .4446 .70551 .4391 .70262 .43781 Mtetra
.847 .942 .884 r
.70262 .43781 .70551 .4391 .71182 .43359 .70893 .4322 Mtetra
.847 .936 .884 r
.70893 .4322 .71182 .43359 .71812 .42809 .71525 .42658 Mtetra
.847 .931 .883 r
.71525 .42658 .71812 .42809 .72442 .42258 .72156 .42097 Mtetra
.847 .925 .882 r
.72156 .42097 .72442 .42258 .73073 .41708 .72788 .41536 Mtetra
.846 .919 .881 r
.72788 .41536 .73073 .41708 .73703 .41157 .7342 .40974 Mtetra
.846 .913 .88 r
.7342 .40974 .73703 .41157 .74334 .40606 .74052 .40413 Mtetra
.845 .908 .878 r
.74052 .40413 .74334 .40606 .74965 .40055 .74683 .39851 Mtetra
.844 .902 .877 r
.74683 .39851 .74965 .40055 .75596 .39504 .75315 .3929 Mtetra
.844 .896 .875 r
.75315 .3929 .75596 .39504 .76227 .38953 .75947 .38728 Mtetra
.843 .89 .873 r
.75947 .38728 .76227 .38953 .76858 .38401 .76579 .38166 Mtetra
.841 .884 .872 r
.76579 .38166 .76858 .38401 .77489 .3785 .77211 .37604 Mtetra
.84 .878 .87 r
.77211 .37604 .77489 .3785 .7812 .37298 .77844 .37042 Mtetra
.839 .873 .868 r
.77844 .37042 .7812 .37298 .78752 .36746 .78476 .36479 Mtetra
.837 .867 .866 r
.78476 .36479 .78752 .36746 .79383 .36194 .79108 .35917 Mtetra
.836 .861 .864 r
.79108 .35917 .79383 .36194 .80015 .35642 .7974 .35354 Mtetra
.834 .855 .861 r
.7974 .35354 .80015 .35642 .80646 .3509 .80373 .34791 Mtetra
.833 .85 .859 r
.80373 .34791 .80646 .3509 .81278 .34537 .81005 .34228 Mtetra
.831 .844 .857 r
.81005 .34228 .81278 .34537 .8191 .33984 .81638 .33665 Mtetra
.829 .839 .854 r
.81638 .33665 .8191 .33984 .82542 .33431 .8227 .33102 Mtetra
.828 .833 .852 r
.8227 .33102 .82542 .33431 .83174 .32878 .82903 .32538 Mtetra
.826 .828 .85 r
.82903 .32538 .83174 .32878 .83806 .32324 .83535 .31975 Mtetra
.824 .822 .848 r
.83535 .31975 .83806 .32324 .84438 .31772 .84168 .31411 Mtetra
.822 .817 .845 r
.84168 .31411 .84438 .31772 .8507 .31219 .84801 .30848 Mtetra
.819 .812 .844 r
.84801 .30848 .8507 .31219 .85703 .3067 .85434 .30289 Mtetra
.813 .806 .844 r
.85434 .30289 .85703 .3067 .86337 .30132 .86069 .29742 Mtetra
.805 .799 .847 r
.86069 .29742 .86337 .30132 .86974 .29612 .86706 .29213 Mtetra
.792 .792 .852 r
.86706 .29213 .86974 .29612 .87614 .29124 .87346 .28716 Mtetra
.406 .647 .955 r
.27287 .48072 .27643 .48403 .28168 .48454 .27812 .48129 Mtetra
.292 .594 .947 r
.27812 .48129 .28168 .48454 .2869 .48565 .28335 .48247 Mtetra
.238 .57 .94 r
.28335 .48247 .2869 .48565 .29213 .48697 .28858 .48387 Mtetra
.205 .557 .934 r
.28858 .48387 .29213 .48697 .29738 .4884 .29382 .48538 Mtetra
.18 .548 .93 r
.29382 .48538 .29738 .4884 .30264 .48989 .29908 .48696 Mtetra
.163 .544 .927 r
.29908 .48696 .30264 .48989 .30793 .49141 .30436 .48855 Mtetra
.15 .544 .925 r
.30436 .48855 .30793 .49141 .31323 .49292 .30967 .49015 Mtetra
.136 .541 .921 r
.30967 .49015 .31323 .49292 .31856 .49444 .31499 .49176 Mtetra
.119 .537 .917 r
.31499 .49176 .31856 .49444 .32391 .49598 .32034 .49337 Mtetra
.105 .535 .912 r
.32034 .49337 .32391 .49598 .32928 .49751 .32571 .49499 Mtetra
.091 .532 .907 r
.32571 .49499 .32928 .49751 .33467 .49905 .3311 .49661 Mtetra
.074 .527 .9 r
.3311 .49661 .33467 .49905 .34009 .50059 .33652 .49824 Mtetra
.057 .522 .893 r
.33652 .49824 .34009 .50059 .34553 .50214 .34196 .49988 Mtetra
.042 .517 .885 r
.34196 .49988 .34553 .50214 .35099 .5037 .34742 .50152 Mtetra
.024 .511 .876 r
.34742 .50152 .35099 .5037 .35647 .50525 .3529 .50316 Mtetra
.006 .504 .865 r
.3529 .50316 .35647 .50525 .36198 .50682 .35841 .50482 Mtetra
0 .497 .854 r
.35841 .50482 .36198 .50682 .36751 .50839 .36394 .50648 Mtetra
0 .49 .842 r
.36394 .50648 .36751 .50839 .37306 .50997 .36949 .50814 Mtetra
0 .481 .829 r
.36949 .50814 .37306 .50997 .37864 .51155 .37507 .50982 Mtetra
0 .472 .814 r
.37507 .50982 .37864 .51155 .38424 .51315 .38067 .5115 Mtetra
0 .463 .799 r
.38067 .5115 .38424 .51315 .38986 .51474 .3863 .51318 Mtetra
0 .452 .783 r
.3863 .51318 .38986 .51474 .39551 .51634 .39195 .51487 Mtetra
0 .441 .765 r
.39195 .51487 .39551 .51634 .40118 .51795 .39763 .51657 Mtetra
0 .431 .748 r
.39763 .51657 .40118 .51795 .40687 .51957 .40332 .51828 Mtetra
0 .419 .729 r
.40332 .51828 .40687 .51957 .41259 .52119 .40905 .51999 Mtetra
0 .406 .708 r
.40905 .51999 .41259 .52119 .41833 .52282 .4148 .52171 Mtetra
0 .394 .688 r
.4148 .52171 .41833 .52282 .4241 .52445 .42057 .52344 Mtetra
.211 0 0 r
.42057 .52344 .4241 .52445 .42989 .5261 .42637 .52517 Mtetra
.228 0 0 r
.42637 .52517 .42989 .5261 .43571 .52775 .43219 .52692 Mtetra
.245 0 0 r
.43219 .52692 .43571 .52775 .44155 .52941 .43804 .52867 Mtetra
.26 0 0 r
.43804 .52867 .44155 .52941 .44742 .53107 .44391 .53043 Mtetra
.276 0 0 r
.44391 .53043 .44742 .53107 .45331 .53274 .44981 .5322 Mtetra
.292 0 0 r
.44981 .5322 .45331 .53274 .45923 .53443 .45574 .53398 Mtetra
.306 0 0 r
.45574 .53398 .45923 .53443 .46517 .53612 .46169 .53576 Mtetra
.319 0 0 r
.46169 .53576 .46517 .53612 .47114 .53781 .46767 .53755 Mtetra
.333 0 0 r
.46767 .53755 .47114 .53781 .47714 .53952 .47367 .53936 Mtetra
.346 0 0 r
.47367 .53936 .47714 .53952 .48316 .54123 .4797 .54117 Mtetra
.358 0 0 r
.4797 .54117 .48316 .54123 .48921 .54295 .48576 .54299 Mtetra
.37 0 0 r
.48576 .54299 .48921 .54295 .49528 .54468 .49184 .54482 Mtetra
.382 0 0 r
.49184 .54482 .49528 .54468 .50138 .54643 .49796 .54666 Mtetra
.392 0 0 r
.49796 .54666 .50138 .54643 .50751 .54818 .50409 .54851 Mtetra
.401 0 0 r
.50409 .54851 .50751 .54818 .51366 .54993 .51026 .55037 Mtetra
.412 0 0 r
.51026 .55037 .51366 .54993 .51984 .5517 .51645 .55224 Mtetra
.421 0 0 r
.51645 .55224 .51984 .5517 .52605 .55348 .52268 .55412 Mtetra
.427 0 0 r
.52268 .55412 .52605 .55348 .53229 .55526 .52893 .556 Mtetra
.434 0 0 r
.52893 .556 .53229 .55526 .53855 .55703 .5352 .55788 Mtetra
.436 0 0 r
.5352 .55788 .53855 .55703 .54485 .55877 .54151 .55972 Mtetra
.422 0 0 r
.54151 .55972 .54485 .55877 .55116 .56034 .54784 .56139 Mtetra
.381 0 0 r
.54784 .56139 .55116 .56034 .55751 .56155 .5542 .56268 Mtetra
0 0 0 r
.5542 .56268 .55751 .56155 .56385 .56026 .56056 .5614 Mtetra
.693 .978 .799 r
.56056 .5614 .56385 .56026 .57015 .55527 .56689 .55632 Mtetra
.737 .99 .809 r
.56689 .55632 .57015 .55527 .57646 .54996 .57321 .5509 Mtetra
.764 .996 .816 r
.57321 .5509 .57646 .54996 .58276 .54444 .57954 .54526 Mtetra
.779 .998 .823 r
.57954 .54526 .58276 .54444 .58907 .53883 .58586 .53955 Mtetra
.788 .999 .83 r
.58586 .53955 .58907 .53883 .59537 .53323 .59218 .53382 Mtetra
.796 .999 .837 r
.59218 .53382 .59537 .53323 .60167 .52761 .5985 .5281 Mtetra
.803 .999 .843 r
.5985 .5281 .60167 .52761 .60798 .52199 .60483 .52236 Mtetra
.809 .998 .849 r
.60483 .52236 .60798 .52199 .61428 .51637 .61115 .51663 Mtetra
.815 .997 .854 r
.61115 .51663 .61428 .51637 .62059 .51076 .61747 .51091 Mtetra
.82 .995 .859 r
.61747 .51091 .62059 .51076 .62689 .50515 .6238 .50518 Mtetra
.825 .992 .863 r
.6238 .50518 .62689 .50515 .6332 .49953 .63012 .49945 Mtetra
.829 .99 .867 r
.63012 .49945 .6332 .49953 .63951 .49392 .63645 .49373 Mtetra
.833 .987 .87 r
.63645 .49373 .63951 .49392 .64581 .48831 .64277 .488 Mtetra
.836 .983 .872 r
.64277 .488 .64581 .48831 .65212 .4827 .64909 .48228 Mtetra
.839 .98 .875 r
.64909 .48228 .65212 .4827 .65843 .47708 .65542 .47655 Mtetra
.842 .975 .877 r
.65542 .47655 .65843 .47708 .66474 .47147 .66175 .47083 Mtetra
.844 .971 .878 r
.66175 .47083 .66474 .47147 .67105 .46586 .66807 .46511 Mtetra
.846 .967 .879 r
.66807 .46511 .67105 .46586 .67737 .46025 .6744 .45939 Mtetra
.847 .962 .88 r
.6744 .45939 .67737 .46025 .68368 .45464 .68072 .45367 Mtetra
.848 .957 .881 r
.68072 .45367 .68368 .45464 .68999 .44903 .68705 .44795 Mtetra
.849 .952 .881 r
.68705 .44795 .68999 .44903 .6963 .44342 .69338 .44223 Mtetra
.85 .947 .881 r
.69338 .44223 .6963 .44342 .70262 .43781 .6997 .43651 Mtetra
.85 .941 .881 r
.6997 .43651 .70262 .43781 .70893 .4322 .70603 .43079 Mtetra
.851 .936 .88 r
.70603 .43079 .70893 .4322 .71525 .42658 .71236 .42507 Mtetra
.851 .93 .88 r
.71236 .42507 .71525 .42658 .72156 .42097 .71869 .41935 Mtetra
.85 .924 .879 r
.71869 .41935 .72156 .42097 .72788 .41536 .72502 .41363 Mtetra
.85 .919 .878 r
.72502 .41363 .72788 .41536 .7342 .40974 .73135 .40791 Mtetra
.849 .913 .877 r
.73135 .40791 .7342 .40974 .74052 .40413 .73767 .40218 Mtetra
.849 .907 .875 r
.73767 .40218 .74052 .40413 .74683 .39851 .744 .39646 Mtetra
.848 .901 .874 r
.744 .39646 .74683 .39851 .75315 .3929 .75033 .39074 Mtetra
.847 .896 .872 r
.75033 .39074 .75315 .3929 .75947 .38728 .75666 .38501 Mtetra
.846 .89 .87 r
.75666 .38501 .75947 .38728 .76579 .38166 .76299 .37929 Mtetra
.844 .884 .869 r
.76299 .37929 .76579 .38166 .77211 .37604 .76932 .37356 Mtetra
.843 .878 .867 r
.76932 .37356 .77211 .37604 .77844 .37042 .77565 .36784 Mtetra
.842 .873 .865 r
.77565 .36784 .77844 .37042 .78476 .36479 .78199 .3621 Mtetra
.84 .867 .863 r
.78199 .3621 .78476 .36479 .79108 .35917 .78832 .35638 Mtetra
.839 .861 .861 r
.78832 .35638 .79108 .35917 .7974 .35354 .79465 .35065 Mtetra
.837 .856 .859 r
.79465 .35065 .7974 .35354 .80373 .34791 .80098 .34491 Mtetra
.836 .85 .856 r
.80098 .34491 .80373 .34791 .81005 .34228 .80731 .33918 Mtetra
.834 .844 .854 r
.80731 .33918 .81005 .34228 .81638 .33665 .81364 .33345 Mtetra
.832 .839 .852 r
.81364 .33345 .81638 .33665 .8227 .33102 .81997 .32771 Mtetra
.83 .834 .849 r
.81997 .32771 .8227 .33102 .82903 .32538 .8263 .32197 Mtetra
.828 .828 .847 r
.8263 .32197 .82903 .32538 .83535 .31975 .83264 .31623 Mtetra
.826 .823 .845 r
.83264 .31623 .83535 .31975 .84168 .31411 .83897 .3105 Mtetra
.825 .818 .843 r
.83897 .3105 .84168 .31411 .84801 .30848 .8453 .30476 Mtetra
.821 .812 .842 r
.8453 .30476 .84801 .30848 .85434 .30289 .85164 .29907 Mtetra
.816 .806 .842 r
.85164 .29907 .85434 .30289 .86069 .29742 .85799 .2935 Mtetra
.808 .8 .845 r
.85799 .2935 .86069 .29742 .86706 .29213 .86436 .28812 Mtetra
.795 .793 .85 r
.86436 .28812 .86706 .29213 .87346 .28716 .87078 .28307 Mtetra
.397 .642 .955 r
.26931 .47741 .27287 .48072 .27812 .48129 .27456 .47803 Mtetra
.277 .586 .945 r
.27456 .47803 .27812 .48129 .28335 .48247 .27978 .47928 Mtetra
.221 .56 .936 r
.27978 .47928 .28335 .48247 .28858 .48387 .28501 .48076 Mtetra
.186 .546 .929 r
.28501 .48076 .28858 .48387 .29382 .48538 .29025 .48235 Mtetra
.16 .537 .924 r
.29025 .48235 .29382 .48538 .29908 .48696 .2955 .48401 Mtetra
.143 .532 .92 r
.2955 .48401 .29908 .48696 .30436 .48855 .30078 .48569 Mtetra
.13 .531 .918 r
.30078 .48569 .30436 .48855 .30967 .49015 .30608 .48737 Mtetra
.115 .528 .914 r
.30608 .48737 .30967 .49015 .31499 .49176 .31141 .48906 Mtetra
.099 .524 .909 r
.31141 .48906 .31499 .49176 .32034 .49337 .31675 .49076 Mtetra
.084 .521 .904 r
.31675 .49076 .32034 .49337 .32571 .49499 .32212 .49246 Mtetra
.069 .517 .898 r
.32212 .49246 .32571 .49499 .3311 .49661 .32752 .49417 Mtetra
.052 .512 .891 r
.32752 .49417 .3311 .49661 .33652 .49824 .33293 .49588 Mtetra
.035 .507 .883 r
.33293 .49588 .33652 .49824 .34196 .49988 .33837 .49761 Mtetra
.02 .502 .875 r
.33837 .49761 .34196 .49988 .34742 .50152 .34383 .49933 Mtetra
.002 .495 .865 r
.34383 .49933 .34742 .50152 .3529 .50316 .34932 .50106 Mtetra
0 .488 .854 r
.34932 .50106 .3529 .50316 .35841 .50482 .35482 .50281 Mtetra
0 .481 .842 r
.35482 .50281 .35841 .50482 .36394 .50648 .36036 .50455 Mtetra
0 .473 .83 r
.36036 .50455 .36394 .50648 .36949 .50814 .36591 .5063 Mtetra
0 .464 .815 r
.36591 .5063 .36949 .50814 .37507 .50982 .37149 .50807 Mtetra
0 .455 .801 r
.37149 .50807 .37507 .50982 .38067 .5115 .3771 .50984 Mtetra
0 .446 .785 r
.3771 .50984 .38067 .5115 .3863 .51318 .38273 .51161 Mtetra
0 .435 .768 r
.38273 .51161 .3863 .51318 .39195 .51487 .38838 .51339 Mtetra
0 .424 .751 r
.38838 .51339 .39195 .51487 .39763 .51657 .39406 .51518 Mtetra
0 .413 .733 r
.39406 .51518 .39763 .51657 .40332 .51828 .39976 .51698 Mtetra
0 .401 .714 r
.39976 .51698 .40332 .51828 .40905 .51999 .40549 .51878 Mtetra
0 .388 .693 r
.40549 .51878 .40905 .51999 .4148 .52171 .41124 .5206 Mtetra
.214 0 0 r
.41124 .5206 .4148 .52171 .42057 .52344 .41702 .52242 Mtetra
.23 0 0 r
.41702 .52242 .42057 .52344 .42637 .52517 .42282 .52424 Mtetra
.247 0 0 r
.42282 .52424 .42637 .52517 .43219 .52692 .42865 .52608 Mtetra
.264 0 0 r
.42865 .52608 .43219 .52692 .43804 .52867 .4345 .52793 Mtetra
.278 0 0 r
.4345 .52793 .43804 .52867 .44391 .53043 .44039 .52978 Mtetra
.293 0 0 r
.44039 .52978 .44391 .53043 .44981 .5322 .44629 .53165 Mtetra
.309 0 0 r
.44629 .53165 .44981 .5322 .45574 .53398 .45223 .53352 Mtetra
.322 0 0 r
.45223 .53352 .45574 .53398 .46169 .53576 .45818 .5354 Mtetra
.335 0 0 r
.45818 .5354 .46169 .53576 .46767 .53755 .46417 .53729 Mtetra
.349 0 0 r
.46417 .53729 .46767 .53755 .47367 .53936 .47018 .53919 Mtetra
.362 0 0 r
.47018 .53919 .47367 .53936 .4797 .54117 .47622 .54111 Mtetra
.372 0 0 r
.47622 .54111 .4797 .54117 .48576 .54299 .48229 .54302 Mtetra
.384 0 0 r
.48229 .54302 .48576 .54299 .49184 .54482 .48839 .54495 Mtetra
.395 0 0 r
.48839 .54495 .49184 .54482 .49796 .54666 .49451 .54689 Mtetra
.405 0 0 r
.49451 .54689 .49796 .54666 .50409 .54851 .50066 .54884 Mtetra
.414 0 0 r
.50066 .54884 .50409 .54851 .51026 .55037 .50684 .5508 Mtetra
.424 0 0 r
.50684 .5508 .51026 .55037 .51645 .55224 .51304 .55277 Mtetra
.433 0 0 r
.51304 .55277 .51645 .55224 .52268 .55412 .51928 .55476 Mtetra
.439 0 0 r
.51928 .55476 .52268 .55412 .52893 .556 .52554 .55674 Mtetra
.445 0 0 r
.52554 .55674 .52893 .556 .5352 .55788 .53183 .55872 Mtetra
.447 0 0 r
.53183 .55872 .5352 .55788 .54151 .55972 .53815 .56066 Mtetra
.433 0 0 r
.53815 .56066 .54151 .55972 .54784 .56139 .5445 .56243 Mtetra
.391 0 0 r
.5445 .56243 .54784 .56139 .5542 .56268 .55088 .56381 Mtetra
0 0 0 r
.55088 .56381 .5542 .56268 .56056 .5614 .55725 .56255 Mtetra
.702 .98 .8 r
.55725 .56255 .56056 .5614 .56689 .55632 .5636 .55737 Mtetra
.745 .992 .809 r
.5636 .55737 .56689 .55632 .57321 .5509 .56995 .55184 Mtetra
.772 .997 .815 r
.56995 .55184 .57321 .5509 .57954 .54526 .57629 .54609 Mtetra
.787 .999 .822 r
.57629 .54609 .57954 .54526 .58586 .53955 .58263 .54026 Mtetra
.795 .999 .829 r
.58263 .54026 .58586 .53955 .59218 .53382 .58897 .53442 Mtetra
.803 .999 .836 r
.58897 .53442 .59218 .53382 .5985 .5281 .59532 .52858 Mtetra
.81 .999 .841 r
.59532 .52858 .5985 .5281 .60483 .52236 .60166 .52273 Mtetra
.816 .998 .847 r
.60166 .52273 .60483 .52236 .61115 .51663 .608 .51688 Mtetra
.821 .996 .852 r
.608 .51688 .61115 .51663 .61747 .51091 .61434 .51104 Mtetra
.826 .994 .856 r
.61434 .51104 .61747 .51091 .6238 .50518 .62068 .5052 Mtetra
.831 .992 .86 r
.62068 .5052 .6238 .50518 .63012 .49945 .62702 .49936 Mtetra
.834 .989 .864 r
.62702 .49936 .63012 .49945 .63645 .49373 .63336 .49352 Mtetra
.838 .986 .867 r
.63336 .49352 .63645 .49373 .64277 .488 .63971 .48769 Mtetra
.841 .983 .869 r
.63971 .48769 .64277 .488 .64909 .48228 .64605 .48185 Mtetra
.844 .979 .872 r
.64605 .48185 .64909 .48228 .65542 .47655 .65239 .47602 Mtetra
.846 .975 .874 r
.65239 .47602 .65542 .47655 .66175 .47083 .65873 .47019 Mtetra
.848 .97 .875 r
.65873 .47019 .66175 .47083 .66807 .46511 .66507 .46435 Mtetra
.85 .966 .876 r
.66507 .46435 .66807 .46511 .6744 .45939 .67141 .45852 Mtetra
.851 .961 .877 r
.67141 .45852 .6744 .45939 .68072 .45367 .67775 .45269 Mtetra
.852 .956 .878 r
.67775 .45269 .68072 .45367 .68705 .44795 .68409 .44686 Mtetra
.853 .951 .878 r
.68409 .44686 .68705 .44795 .69338 .44223 .69043 .44103 Mtetra
.854 .946 .878 r
.69043 .44103 .69338 .44223 .6997 .43651 .69677 .4352 Mtetra
.854 .94 .878 r
.69677 .4352 .6997 .43651 .70603 .43079 .70312 .42937 Mtetra
.854 .935 .877 r
.70312 .42937 .70603 .43079 .71236 .42507 .70946 .42354 Mtetra
.854 .929 .876 r
.70946 .42354 .71236 .42507 .71869 .41935 .7158 .41771 Mtetra
.854 .924 .876 r
.7158 .41771 .71869 .41935 .72502 .41363 .72214 .41188 Mtetra
.853 .918 .875 r
.72214 .41188 .72502 .41363 .73135 .40791 .72848 .40606 Mtetra
.853 .913 .873 r
.72848 .40606 .73135 .40791 .73767 .40218 .73482 .40022 Mtetra
.852 .907 .872 r
.73482 .40022 .73767 .40218 .744 .39646 .74116 .39439 Mtetra
.851 .901 .871 r
.74116 .39439 .744 .39646 .75033 .39074 .7475 .38857 Mtetra
.85 .895 .869 r
.7475 .38857 .75033 .39074 .75666 .38501 .75384 .38273 Mtetra
.849 .89 .867 r
.75384 .38273 .75666 .38501 .76299 .37929 .76018 .3769 Mtetra
.847 .884 .866 r
.76018 .3769 .76299 .37929 .76932 .37356 .76652 .37107 Mtetra
.846 .878 .864 r
.76652 .37107 .76932 .37356 .77565 .36784 .77286 .36524 Mtetra
.845 .872 .862 r
.77286 .36524 .77565 .36784 .78199 .3621 .7792 .3594 Mtetra
.843 .867 .86 r
.7792 .3594 .78199 .3621 .78832 .35638 .78554 .35357 Mtetra
.842 .861 .858 r
.78554 .35357 .78832 .35638 .79465 .35065 .79188 .34774 Mtetra
.84 .856 .856 r
.79188 .34774 .79465 .35065 .80098 .34491 .79822 .3419 Mtetra
.838 .85 .854 r
.79822 .3419 .80098 .34491 .80731 .33918 .80455 .33606 Mtetra
.837 .845 .852 r
.80455 .33606 .80731 .33918 .81364 .33345 .81089 .33022 Mtetra
.835 .839 .849 r
.81089 .33022 .81364 .33345 .81997 .32771 .81723 .32438 Mtetra
.833 .834 .847 r
.81723 .32438 .81997 .32771 .8263 .32197 .82357 .31854 Mtetra
.831 .828 .845 r
.82357 .31854 .8263 .32197 .83264 .31623 .82991 .3127 Mtetra
.829 .823 .843 r
.82991 .3127 .83264 .31623 .83897 .3105 .83625 .30686 Mtetra
.827 .818 .841 r
.83625 .30686 .83897 .3105 .8453 .30476 .84258 .30103 Mtetra
.824 .813 .839 r
.84258 .30103 .8453 .30476 .85164 .29907 .84893 .29524 Mtetra
.818 .807 .84 r
.84893 .29524 .85164 .29907 .85799 .2935 .85528 .28956 Mtetra
.81 .801 .843 r
.85528 .28956 .85799 .2935 .86436 .28812 .86166 .28409 Mtetra
.797 .793 .848 r
.86166 .28409 .86436 .28812 .87078 .28307 .86808 .27896 Mtetra
.387 .637 .955 r
.26573 .47408 .26931 .47741 .27456 .47803 .27098 .47476 Mtetra
.262 .577 .942 r
.27098 .47476 .27456 .47803 .27978 .47928 .2762 .47608 Mtetra
.203 .55 .931 r
.2762 .47608 .27978 .47928 .28501 .48076 .28142 .47764 Mtetra
.167 .535 .924 r
.28142 .47764 .28501 .48076 .29025 .48235 .28666 .47931 Mtetra
.14 .525 .917 r
.28666 .47931 .29025 .48235 .2955 .48401 .29191 .48105 Mtetra
.122 .52 .913 r
.29191 .48105 .2955 .48401 .30078 .48569 .29719 .48281 Mtetra
.109 .518 .91 r
.29719 .48281 .30078 .48569 .30608 .48737 .30249 .48457 Mtetra
.094 .514 .906 r
.30249 .48457 .30608 .48737 .31141 .48906 .30781 .48635 Mtetra
.077 .51 .9 r
.30781 .48635 .31141 .48906 .31675 .49076 .31315 .48813 Mtetra
.063 .507 .895 r
.31315 .48813 .31675 .49076 .32212 .49246 .31852 .48992 Mtetra
.047 .503 .889 r
.31852 .48992 .32212 .49246 .32752 .49417 .32391 .49171 Mtetra
.03 .497 .88 r
.32391 .49171 .32752 .49417 .33293 .49588 .32933 .49351 Mtetra
.013 .491 .872 r
.32933 .49351 .33293 .49588 .33837 .49761 .33476 .49532 Mtetra
0 .486 .863 r
.33476 .49532 .33837 .49761 .34383 .49933 .34023 .49713 Mtetra
0 .479 .853 r
.34023 .49713 .34383 .49933 .34932 .50106 .34571 .49895 Mtetra
0 .471 .841 r
.34571 .49895 .34932 .50106 .35482 .50281 .35122 .50078 Mtetra
0 .464 .829 r
.35122 .50078 .35482 .50281 .36036 .50455 .35675 .50262 Mtetra
0 .456 .816 r
.35675 .50262 .36036 .50455 .36591 .5063 .36231 .50446 Mtetra
0 .446 .801 r
.36231 .50446 .36591 .5063 .37149 .50807 .36789 .50631 Mtetra
0 .437 .786 r
.36789 .50631 .37149 .50807 .3771 .50984 .3735 .50817 Mtetra
0 .428 .77 r
.3735 .50817 .3771 .50984 .38273 .51161 .37913 .51003 Mtetra
0 .417 .753 r
.37913 .51003 .38273 .51161 .38838 .51339 .38479 .5119 Mtetra
0 .405 .735 r
.38479 .5119 .38838 .51339 .39406 .51518 .39047 .51379 Mtetra
0 .394 .717 r
.39047 .51379 .39406 .51518 .39976 .51698 .39618 .51568 Mtetra
0 .383 .697 r
.39618 .51568 .39976 .51698 .40549 .51878 .40191 .51757 Mtetra
0 .37 .677 r
.40191 .51757 .40549 .51878 .41124 .5206 .40766 .51948 Mtetra
.235 0 0 r
.40766 .51948 .41124 .5206 .41702 .52242 .41345 .52139 Mtetra
.25 0 0 r
.41345 .52139 .41702 .52242 .42282 .52424 .41926 .52331 Mtetra
.267 0 0 r
.41926 .52331 .42282 .52424 .42865 .52608 .42509 .52525 Mtetra
.283 0 0 r
.42509 .52525 .42865 .52608 .4345 .52793 .43095 .52719 Mtetra
.297 0 0 r
.43095 .52719 .4345 .52793 .44039 .52978 .43684 .52914 Mtetra
.312 0 0 r
.43684 .52914 .44039 .52978 .44629 .53165 .44275 .5311 Mtetra
.327 0 0 r
.44275 .5311 .44629 .53165 .45223 .53352 .44869 .53307 Mtetra
.34 0 0 r
.44869 .53307 .45223 .53352 .45818 .5354 .45466 .53505 Mtetra
.352 0 0 r
.45466 .53505 .45818 .5354 .46417 .53729 .46065 .53703 Mtetra
.365 0 0 r
.46065 .53703 .46417 .53729 .47018 .53919 .46668 .53903 Mtetra
.377 0 0 r
.46668 .53903 .47018 .53919 .47622 .54111 .47272 .54105 Mtetra
.388 0 0 r
.47272 .54105 .47622 .54111 .48229 .54302 .4788 .54306 Mtetra
.399 0 0 r
.4788 .54306 .48229 .54302 .48839 .54495 .48491 .54509 Mtetra
.41 0 0 r
.48491 .54509 .48839 .54495 .49451 .54689 .49104 .54713 Mtetra
.419 0 0 r
.49104 .54713 .49451 .54689 .50066 .54884 .4972 .54919 Mtetra
.427 0 0 r
.4972 .54919 .50066 .54884 .50684 .5508 .50339 .55124 Mtetra
.437 0 0 r
.50339 .55124 .50684 .5508 .51304 .55277 .50961 .55332 Mtetra
.445 0 0 r
.50961 .55332 .51304 .55277 .51928 .55476 .51586 .55541 Mtetra
.451 0 0 r
.51586 .55541 .51928 .55476 .52554 .55674 .52213 .5575 Mtetra
.457 0 0 r
.52213 .5575 .52554 .55674 .53183 .55872 .52844 .55958 Mtetra
.458 0 0 r
.52844 .55958 .53183 .55872 .53815 .56066 .53477 .56163 Mtetra
.444 0 0 r
.53477 .56163 .53815 .56066 .5445 .56243 .54114 .56349 Mtetra
.402 0 0 r
.54114 .56349 .5445 .56243 .55088 .56381 .54752 .56496 Mtetra
0 0 0 r
.54752 .56496 .55088 .56381 .55725 .56255 .55392 .56371 Mtetra
.71 .982 .8 r
.55392 .56371 .55725 .56255 .5636 .55737 .56029 .55843 Mtetra
.752 .993 .808 r
.56029 .55843 .5636 .55737 .56995 .55184 .56665 .55279 Mtetra
.779 .997 .814 r
.56665 .55279 .56995 .55184 .57629 .54609 .57302 .54693 Mtetra
.793 .999 .82 r
.57302 .54693 .57629 .54609 .58263 .54026 .57938 .54098 Mtetra
.801 1 .827 r
.57938 .54098 .58263 .54026 .58897 .53442 .58574 .53503 Mtetra
.808 1 .833 r
.58574 .53503 .58897 .53442 .59532 .52858 .5921 .52907 Mtetra
.816 .999 .839 r
.5921 .52907 .59532 .52858 .60166 .52273 .59847 .5231 Mtetra
.821 .998 .844 r
.59847 .5231 .60166 .52273 .608 .51688 .60483 .51714 Mtetra
.826 .996 .849 r
.60483 .51714 .608 .51688 .61434 .51104 .61119 .51119 Mtetra
.831 .994 .854 r
.61119 .51119 .61434 .51104 .62068 .5052 .61755 .50523 Mtetra
.835 .992 .857 r
.61755 .50523 .62068 .5052 .62702 .49936 .6239 .49928 Mtetra
.839 .989 .861 r
.6239 .49928 .62702 .49936 .63336 .49352 .63026 .49333 Mtetra
.842 .986 .864 r
.63026 .49333 .63336 .49352 .63971 .48769 .63662 .48738 Mtetra
.846 .982 .866 r
.63662 .48738 .63971 .48769 .64605 .48185 .64298 .48143 Mtetra
.848 .978 .869 r
.64298 .48143 .64605 .48185 .65239 .47602 .64934 .47548 Mtetra
.85 .974 .87 r
.64934 .47548 .65239 .47602 .65873 .47019 .65569 .46954 Mtetra
.852 .97 .872 r
.65569 .46954 .65873 .47019 .66507 .46435 .66205 .46359 Mtetra
.854 .965 .873 r
.66205 .46359 .66507 .46435 .67141 .45852 .66841 .45765 Mtetra
.855 .961 .874 r
.66841 .45765 .67141 .45852 .67775 .45269 .67476 .45171 Mtetra
.856 .956 .874 r
.67476 .45171 .67775 .45269 .68409 .44686 .68112 .44577 Mtetra
.857 .951 .874 r
.68112 .44577 .68409 .44686 .69043 .44103 .68747 .43983 Mtetra
.857 .945 .875 r
.68747 .43983 .69043 .44103 .69677 .4352 .69383 .43389 Mtetra
.857 .94 .874 r
.69383 .43389 .69677 .4352 .70312 .42937 .70018 .42795 Mtetra
.857 .935 .874 r
.70018 .42795 .70312 .42937 .70946 .42354 .70654 .42201 Mtetra
.857 .929 .873 r
.70654 .42201 .70946 .42354 .7158 .41771 .71289 .41607 Mtetra
.857 .924 .873 r
.71289 .41607 .7158 .41771 .72214 .41188 .71924 .41013 Mtetra
.856 .918 .872 r
.71924 .41013 .72214 .41188 .72848 .40606 .7256 .4042 Mtetra
.856 .912 .87 r
.7256 .4042 .72848 .40606 .73482 .40022 .73195 .39826 Mtetra
.855 .907 .869 r
.73195 .39826 .73482 .40022 .74116 .39439 .7383 .39232 Mtetra
.854 .901 .868 r
.7383 .39232 .74116 .39439 .7475 .38857 .74465 .38639 Mtetra
.853 .895 .866 r
.74465 .38639 .7475 .38857 .75384 .38273 .751 .38045 Mtetra
.852 .89 .865 r
.751 .38045 .75384 .38273 .76018 .3769 .75735 .37451 Mtetra
.85 .884 .863 r
.75735 .37451 .76018 .3769 .76652 .37107 .7637 .36857 Mtetra
.849 .878 .861 r
.7637 .36857 .76652 .37107 .77286 .36524 .77005 .36263 Mtetra
.848 .873 .859 r
.77005 .36263 .77286 .36524 .7792 .3594 .7764 .35669 Mtetra
.846 .867 .857 r
.7764 .35669 .7792 .3594 .78554 .35357 .78275 .35075 Mtetra
.844 .861 .855 r
.78275 .35075 .78554 .35357 .79188 .34774 .78909 .34482 Mtetra
.843 .856 .853 r
.78909 .34482 .79188 .34774 .79822 .3419 .79544 .33887 Mtetra
.841 .85 .851 r
.79544 .33887 .79822 .3419 .80455 .33606 .80179 .33293 Mtetra
.839 .845 .849 r
.80179 .33293 .80455 .33606 .81089 .33022 .80813 .32699 Mtetra
.838 .84 .847 r
.80813 .32699 .81089 .33022 .81723 .32438 .81448 .32104 Mtetra
.836 .834 .845 r
.81448 .32104 .81723 .32438 .82357 .31854 .82082 .31509 Mtetra
.834 .829 .843 r
.82082 .31509 .82357 .31854 .82991 .3127 .82717 .30915 Mtetra
.832 .824 .84 r
.82717 .30915 .82991 .3127 .83625 .30686 .83351 .30321 Mtetra
.83 .819 .838 r
.83351 .30321 .83625 .30686 .84258 .30103 .83985 .29727 Mtetra
.827 .813 .837 r
.83985 .29727 .84258 .30103 .84893 .29524 .8462 .29138 Mtetra
.821 .807 .838 r
.8462 .29138 .84893 .29524 .85528 .28956 .85256 .28561 Mtetra
.813 .801 .841 r
.85256 .28561 .85528 .28956 .86166 .28409 .85895 .28005 Mtetra
.8 .794 .847 r
.85895 .28005 .86166 .28409 .86808 .27896 .86537 .27483 Mtetra
.377 .633 .954 r
.26214 .47074 .26573 .47408 .27098 .47476 .26738 .47147 Mtetra
.246 .569 .939 r
.26738 .47147 .27098 .47476 .2762 .47608 .2726 .47286 Mtetra
.185 .539 .926 r
.2726 .47286 .2762 .47608 .28142 .47764 .27782 .4745 Mtetra
.148 .523 .918 r
.27782 .4745 .28142 .47764 .28666 .47931 .28305 .47625 Mtetra
.12 .512 .91 r
.28305 .47625 .28666 .47931 .29191 .48105 .28831 .47807 Mtetra
.101 .507 .906 r
.28831 .47807 .29191 .48105 .29719 .48281 .29358 .47992 Mtetra
.089 .505 .902 r
.29358 .47992 .29719 .48281 .30249 .48457 .29888 .48177 Mtetra
.073 .501 .897 r
.29888 .48177 .30249 .48457 .30781 .48635 .3042 .48362 Mtetra
.055 .496 .891 r
.3042 .48362 .30781 .48635 .31315 .48813 .30954 .4855 Mtetra
.041 .492 .885 r
.30954 .4855 .31315 .48813 .31852 .48992 .3149 .48737 Mtetra
.025 .488 .878 r
.3149 .48737 .31852 .48992 .32391 .49171 .32029 .48924 Mtetra
.007 .482 .87 r
.32029 .48924 .32391 .49171 .32933 .49351 .32571 .49113 Mtetra
0 .476 .861 r
.32571 .49113 .32933 .49351 .33476 .49532 .33114 .49303 Mtetra
0 .47 .851 r
.33114 .49303 .33476 .49532 .34023 .49713 .33661 .49493 Mtetra
0 .463 .84 r
.33661 .49493 .34023 .49713 .34571 .49895 .34209 .49684 Mtetra
0 .454 .828 r
.34209 .49684 .34571 .49895 .35122 .50078 .3476 .49876 Mtetra
0 .447 .815 r
.3476 .49876 .35122 .50078 .35675 .50262 .35314 .50068 Mtetra
0 .439 .802 r
.35314 .50068 .35675 .50262 .36231 .50446 .35869 .50261 Mtetra
0 .429 .786 r
.35869 .50261 .36231 .50446 .36789 .50631 .36428 .50455 Mtetra
0 .419 .771 r
.36428 .50455 .36789 .50631 .3735 .50817 .36989 .5065 Mtetra
0 .409 .755 r
.36989 .5065 .3735 .50817 .37913 .51003 .37552 .50845 Mtetra
0 .398 .737 r
.37552 .50845 .37913 .51003 .38479 .5119 .38118 .51041 Mtetra
0 .387 .719 r
.38118 .51041 .38479 .5119 .39047 .51379 .38686 .51239 Mtetra
0 .376 .7 r
.38686 .51239 .39047 .51379 .39618 .51568 .39257 .51437 Mtetra
0 .364 .681 r
.39257 .51437 .39618 .51568 .40191 .51757 .39831 .51636 Mtetra
.239 0 0 r
.39831 .51636 .40191 .51757 .40766 .51948 .40407 .51836 Mtetra
.255 0 0 r
.40407 .51836 .40766 .51948 .41345 .52139 .40986 .52037 Mtetra
.27 0 0 r
.40986 .52037 .41345 .52139 .41926 .52331 .41567 .52238 Mtetra
.286 0 0 r
.41567 .52238 .41926 .52331 .42509 .52525 .42151 .52441 Mtetra
.302 0 0 r
.42151 .52441 .42509 .52525 .43095 .52719 .42738 .52645 Mtetra
.315 0 0 r
.42738 .52645 .43095 .52719 .43684 .52914 .43327 .52849 Mtetra
.33 0 0 r
.43327 .52849 .43684 .52914 .44275 .5311 .43919 .53055 Mtetra
.344 0 0 r
.43919 .53055 .44275 .5311 .44869 .53307 .44514 .53261 Mtetra
.356 0 0 r
.44514 .53261 .44869 .53307 .45466 .53505 .45111 .53469 Mtetra
.368 0 0 r
.45111 .53469 .45466 .53505 .46065 .53703 .45712 .53678 Mtetra
.381 0 0 r
.45712 .53678 .46065 .53703 .46668 .53903 .46315 .53888 Mtetra
.393 0 0 r
.46315 .53888 .46668 .53903 .47272 .54105 .4692 .54099 Mtetra
.402 0 0 r
.4692 .54099 .47272 .54105 .4788 .54306 .47529 .5431 Mtetra
.413 0 0 r
.47529 .5431 .4788 .54306 .48491 .54509 .48141 .54523 Mtetra
.423 0 0 r
.48141 .54523 .48491 .54509 .49104 .54713 .48755 .54738 Mtetra
.432 0 0 r
.48755 .54738 .49104 .54713 .4972 .54919 .49372 .54953 Mtetra
.44 0 0 r
.49372 .54953 .4972 .54919 .50339 .55124 .49992 .55169 Mtetra
.449 0 0 r
.49992 .55169 .50339 .55124 .50961 .55332 .50615 .55388 Mtetra
.457 0 0 r
.50615 .55388 .50961 .55332 .51586 .55541 .51241 .55607 Mtetra
.463 0 0 r
.51241 .55607 .51586 .55541 .52213 .5575 .5187 .55826 Mtetra
.468 0 0 r
.5187 .55826 .52213 .5575 .52844 .55958 .52502 .56045 Mtetra
.469 0 0 r
.52502 .56045 .52844 .55958 .53477 .56163 .53137 .5626 Mtetra
.454 0 0 r
.53137 .5626 .53477 .56163 .54114 .56349 .53775 .56457 Mtetra
.412 0 0 r
.53775 .56457 .54114 .56349 .54752 .56496 .54415 .56612 Mtetra
0 0 0 r
.54415 .56612 .54752 .56496 .55392 .56371 .55056 .56489 Mtetra
.717 .984 .799 r
.55056 .56489 .55392 .56371 .56029 .55843 .55695 .55951 Mtetra
.759 .994 .806 r
.55695 .55951 .56029 .55843 .56665 .55279 .56334 .55376 Mtetra
.786 .998 .812 r
.56334 .55376 .56665 .55279 .57302 .54693 .56973 .54778 Mtetra
.8 1 .818 r
.56973 .54778 .57302 .54693 .57938 .54098 .57611 .54172 Mtetra
.807 1 .825 r
.57611 .54172 .57938 .54098 .58574 .53503 .58249 .53565 Mtetra
.814 1 .831 r
.58249 .53565 .58574 .53503 .5921 .52907 .58887 .52957 Mtetra
.821 .999 .836 r
.58887 .52957 .5921 .52907 .59847 .5231 .59525 .52349 Mtetra
.826 .998 .842 r
.59525 .52349 .59847 .5231 .60483 .51714 .60163 .51741 Mtetra
.831 .996 .847 r
.60163 .51741 .60483 .51714 .61119 .51119 .60801 .51134 Mtetra
.836 .994 .851 r
.60801 .51134 .61119 .51119 .61755 .50523 .61439 .50527 Mtetra
.84 .991 .854 r
.61439 .50527 .61755 .50523 .6239 .49928 .62077 .4992 Mtetra
.844 .988 .858 r
.62077 .4992 .6239 .49928 .63026 .49333 .62714 .49314 Mtetra
.847 .985 .861 r
.62714 .49314 .63026 .49333 .63662 .48738 .63352 .48707 Mtetra
.85 .982 .863 r
.63352 .48707 .63662 .48738 .64298 .48143 .63989 .48101 Mtetra
.852 .978 .865 r
.63989 .48101 .64298 .48143 .64934 .47548 .64627 .47495 Mtetra
.854 .974 .867 r
.64627 .47495 .64934 .47548 .65569 .46954 .65264 .46889 Mtetra
.856 .969 .869 r
.65264 .46889 .65569 .46954 .66205 .46359 .65901 .46283 Mtetra
.858 .965 .87 r
.65901 .46283 .66205 .46359 .66841 .45765 .66539 .45678 Mtetra
.859 .96 .871 r
.66539 .45678 .66841 .45765 .67476 .45171 .67176 .45072 Mtetra
.86 .955 .871 r
.67176 .45072 .67476 .45171 .68112 .44577 .67813 .44467 Mtetra
.86 .95 .871 r
.67813 .44467 .68112 .44577 .68747 .43983 .6845 .43862 Mtetra
.861 .945 .871 r
.6845 .43862 .68747 .43983 .69383 .43389 .69086 .43257 Mtetra
.861 .94 .871 r
.69086 .43257 .69383 .43389 .70018 .42795 .69723 .42652 Mtetra
.861 .934 .871 r
.69723 .42652 .70018 .42795 .70654 .42201 .7036 .42047 Mtetra
.861 .929 .87 r
.7036 .42047 .70654 .42201 .71289 .41607 .70997 .41442 Mtetra
.86 .923 .869 r
.70997 .41442 .71289 .41607 .71924 .41013 .71633 .40838 Mtetra
.859 .918 .868 r
.71633 .40838 .71924 .41013 .7256 .4042 .7227 .40233 Mtetra
.859 .912 .867 r
.7227 .40233 .7256 .4042 .73195 .39826 .72906 .39628 Mtetra
.858 .906 .866 r
.72906 .39628 .73195 .39826 .7383 .39232 .73542 .39024 Mtetra
.857 .901 .865 r
.73542 .39024 .7383 .39232 .74465 .38639 .74179 .3842 Mtetra
.856 .895 .863 r
.74179 .3842 .74465 .38639 .751 .38045 .74815 .37815 Mtetra
.855 .889 .862 r
.74815 .37815 .751 .38045 .75735 .37451 .75451 .3721 Mtetra
.853 .884 .86 r
.75451 .3721 .75735 .37451 .7637 .36857 .76087 .36606 Mtetra
.852 .878 .858 r
.76087 .36606 .7637 .36857 .77005 .36263 .76723 .36001 Mtetra
.851 .873 .856 r
.76723 .36001 .77005 .36263 .7764 .35669 .77358 .35397 Mtetra
.849 .867 .855 r
.77358 .35397 .7764 .35669 .78275 .35075 .77994 .34792 Mtetra
.847 .862 .853 r
.77994 .34792 .78275 .35075 .78909 .34482 .7863 .34188 Mtetra
.846 .856 .851 r
.7863 .34188 .78909 .34482 .79544 .33887 .79265 .33583 Mtetra
.844 .851 .849 r
.79265 .33583 .79544 .33887 .80179 .33293 .79901 .32978 Mtetra
.842 .845 .847 r
.79901 .32978 .80179 .33293 .80813 .32699 .80536 .32374 Mtetra
.84 .84 .844 r
.80536 .32374 .80813 .32699 .81448 .32104 .81171 .31769 Mtetra
.839 .835 .842 r
.81171 .31769 .81448 .32104 .82082 .31509 .81806 .31163 Mtetra
.837 .829 .84 r
.81806 .31163 .82082 .31509 .82717 .30915 .82441 .30559 Mtetra
.835 .824 .838 r
.82441 .30559 .82717 .30915 .83351 .30321 .83076 .29955 Mtetra
.833 .819 .836 r
.83076 .29955 .83351 .30321 .83985 .29727 .83711 .29351 Mtetra
.829 .814 .835 r
.83711 .29351 .83985 .29727 .8462 .29138 .84346 .28751 Mtetra
.824 .808 .836 r
.84346 .28751 .8462 .29138 .85256 .28561 .84983 .28164 Mtetra
.815 .802 .839 r
.84983 .28164 .85256 .28561 .85895 .28005 .85622 .27599 Mtetra
.802 .795 .845 r
.85622 .27599 .85895 .28005 .86537 .27483 .86265 .27069 Mtetra
.366 .628 .954 r
.25853 .46738 .26214 .47074 .26738 .47147 .26378 .46817 Mtetra
.23 .56 .935 r
.26378 .46817 .26738 .47147 .2726 .47286 .26899 .46964 Mtetra
.167 .529 .921 r
.26899 .46964 .2726 .47286 .27782 .4745 .27421 .47135 Mtetra
.129 .511 .911 r
.27421 .47135 .27782 .4745 .28305 .47625 .27944 .47318 Mtetra
.1 .499 .903 r
.27944 .47318 .28305 .47625 .28831 .47807 .28469 .47509 Mtetra
.081 .493 .898 r
.28469 .47509 .28831 .47807 .29358 .47992 .28996 .47702 Mtetra
.068 .491 .894 r
.28996 .47702 .29358 .47992 .29888 .48177 .29525 .47895 Mtetra
.052 .487 .888 r
.29525 .47895 .29888 .48177 .3042 .48362 .30057 .48089 Mtetra
.034 .481 .881 r
.30057 .48089 .3042 .48362 .30954 .4855 .30591 .48285 Mtetra
.019 .477 .875 r
.30591 .48285 .30954 .4855 .3149 .48737 .31127 .4848 Mtetra
.004 .473 .868 r
.31127 .4848 .3149 .48737 .32029 .48924 .31666 .48677 Mtetra
0 .466 .859 r
.31666 .48677 .32029 .48924 .32571 .49113 .32207 .48874 Mtetra
0 .46 .849 r
.32207 .48874 .32571 .49113 .33114 .49303 .32751 .49072 Mtetra
0 .454 .84 r
.32751 .49072 .33114 .49303 .33661 .49493 .33297 .49271 Mtetra
0 .446 .828 r
.33297 .49271 .33661 .49493 .34209 .49684 .33845 .49471 Mtetra
0 .438 .815 r
.33845 .49471 .34209 .49684 .3476 .49876 .34396 .49671 Mtetra
0 .43 .802 r
.34396 .49671 .3476 .49876 .35314 .50068 .3495 .49872 Mtetra
0 .422 .788 r
.3495 .49872 .35314 .50068 .35869 .50261 .35506 .50074 Mtetra
0 .411 .773 r
.35506 .50074 .35869 .50261 .36428 .50455 .36064 .50277 Mtetra
0 .402 .757 r
.36064 .50277 .36428 .50455 .36989 .5065 .36625 .50481 Mtetra
0 .392 .741 r
.36625 .50481 .36989 .5065 .37552 .50845 .37189 .50685 Mtetra
0 .381 .723 r
.37189 .50685 .37552 .50845 .38118 .51041 .37755 .50891 Mtetra
0 .369 .704 r
.37755 .50891 .38118 .51041 .38686 .51239 .38324 .51098 Mtetra
0 .359 .686 r
.38324 .51098 .38686 .51239 .39257 .51437 .38895 .51305 Mtetra
0 .347 .666 r
.38895 .51305 .39257 .51437 .39831 .51636 .39469 .51513 Mtetra
.257 0 0 r
.39469 .51513 .39831 .51636 .40407 .51836 .40045 .51722 Mtetra
.273 0 0 r
.40045 .51722 .40407 .51836 .40986 .52037 .40625 .51933 Mtetra
.288 0 0 r
.40625 .51933 .40986 .52037 .41567 .52238 .41206 .52144 Mtetra
.303 0 0 r
.41206 .52144 .41567 .52238 .42151 .52441 .41791 .52356 Mtetra
.318 0 0 r
.41791 .52356 .42151 .52441 .42738 .52645 .42378 .52569 Mtetra
.331 0 0 r
.42378 .52569 .42738 .52645 .43327 .52849 .42968 .52783 Mtetra
.345 0 0 r
.42968 .52783 .43327 .52849 .43919 .53055 .43561 .52998 Mtetra
.359 0 0 r
.43561 .52998 .43919 .53055 .44514 .53261 .44156 .53215 Mtetra
.371 0 0 r
.44156 .53215 .44514 .53261 .45111 .53469 .44755 .53433 Mtetra
.382 0 0 r
.44755 .53433 .45111 .53469 .45712 .53678 .45356 .53651 Mtetra
.394 0 0 r
.45356 .53651 .45712 .53678 .46315 .53888 .45959 .53871 Mtetra
.406 0 0 r
.45959 .53871 .46315 .53888 .4692 .54099 .46566 .54092 Mtetra
.415 0 0 r
.46566 .54092 .4692 .54099 .47529 .5431 .47176 .54314 Mtetra
.425 0 0 r
.47176 .54314 .47529 .5431 .48141 .54523 .47788 .54537 Mtetra
.435 0 0 r
.47788 .54537 .48141 .54523 .48755 .54738 .48403 .54762 Mtetra
.443 0 0 r
.48403 .54762 .48755 .54738 .49372 .54953 .49022 .54987 Mtetra
.451 0 0 r
.49022 .54987 .49372 .54953 .49992 .55169 .49643 .55214 Mtetra
.46 0 0 r
.49643 .55214 .49992 .55169 .50615 .55388 .50267 .55442 Mtetra
.468 0 0 r
.50267 .55442 .50615 .55388 .51241 .55607 .50894 .55672 Mtetra
.473 0 0 r
.50894 .55672 .51241 .55607 .5187 .55826 .51524 .55902 Mtetra
.478 0 0 r
.51524 .55902 .5187 .55826 .52502 .56045 .52158 .56131 Mtetra
.479 0 0 r
.52158 .56131 .52502 .56045 .53137 .5626 .52794 .56357 Mtetra
.464 0 0 r
.52794 .56357 .53137 .5626 .53775 .56457 .53433 .56563 Mtetra
.421 0 0 r
.53433 .56563 .53775 .56457 .54415 .56612 .54075 .56728 Mtetra
0 0 0 r
.54075 .56728 .54415 .56612 .55056 .56489 .54718 .56605 Mtetra
.727 .987 .801 r
.54718 .56605 .55056 .56489 .55695 .55951 .55359 .56058 Mtetra
.768 .995 .807 r
.55359 .56058 .55695 .55951 .56334 .55376 .56 .55472 Mtetra
.794 .999 .812 r
.56 .55472 .56334 .55376 .56973 .54778 .56641 .54863 Mtetra
.807 1 .817 r
.56641 .54863 .56973 .54778 .57611 .54172 .57281 .54244 Mtetra
.815 1 .824 r
.57281 .54244 .57611 .54172 .58249 .53565 .57922 .53625 Mtetra
.821 .999 .83 r
.57922 .53625 .58249 .53565 .58887 .52957 .58562 .53006 Mtetra
.828 .998 .835 r
.58562 .53006 .58887 .52957 .59525 .52349 .59202 .52386 Mtetra
.832 .997 .84 r
.59202 .52386 .59525 .52349 .60163 .51741 .59842 .51767 Mtetra
.837 .995 .845 r
.59842 .51767 .60163 .51741 .60801 .51134 .60482 .51148 Mtetra
.841 .993 .849 r
.60482 .51148 .60801 .51134 .61439 .50527 .61121 .5053 Mtetra
.845 .99 .852 r
.61121 .5053 .61439 .50527 .62077 .4992 .61761 .49911 Mtetra
.848 .987 .855 r
.61761 .49911 .62077 .4992 .62714 .49314 .624 .49293 Mtetra
.851 .984 .858 r
.624 .49293 .62714 .49314 .63352 .48707 .6304 .48675 Mtetra
.854 .98 .86 r
.6304 .48675 .63352 .48707 .63989 .48101 .63679 .48057 Mtetra
.856 .976 .863 r
.63679 .48057 .63989 .48101 .64627 .47495 .64318 .4744 Mtetra
.858 .972 .864 r
.64318 .4744 .64627 .47495 .65264 .46889 .64957 .46823 Mtetra
.86 .968 .866 r
.64957 .46823 .65264 .46889 .65901 .46283 .65596 .46206 Mtetra
.861 .963 .866 r
.65596 .46206 .65901 .46283 .66539 .45678 .66234 .45589 Mtetra
.862 .959 .867 r
.66234 .45589 .66539 .45678 .67176 .45072 .66873 .44973 Mtetra
.863 .954 .868 r
.66873 .44973 .67176 .45072 .67813 .44467 .67512 .44356 Mtetra
.864 .949 .868 r
.67512 .44356 .67813 .44467 .6845 .43862 .6815 .4374 Mtetra
.864 .944 .868 r
.6815 .4374 .6845 .43862 .69086 .43257 .68788 .43124 Mtetra
.864 .939 .868 r
.68788 .43124 .69086 .43257 .69723 .42652 .69427 .42508 Mtetra
.864 .933 .867 r
.69427 .42508 .69723 .42652 .7036 .42047 .70065 .41892 Mtetra
.864 .928 .867 r
.70065 .41892 .7036 .42047 .70997 .41442 .70703 .41276 Mtetra
.863 .922 .866 r
.70703 .41276 .70997 .41442 .71633 .40838 .7134 .40661 Mtetra
.862 .917 .865 r
.7134 .40661 .71633 .40838 .7227 .40233 .71978 .40045 Mtetra
.862 .911 .864 r
.71978 .40045 .7227 .40233 .72906 .39628 .72616 .39429 Mtetra
.861 .906 .863 r
.72616 .39429 .72906 .39628 .73542 .39024 .73253 .38814 Mtetra
.86 .9 .862 r
.73253 .38814 .73542 .39024 .74179 .3842 .7389 .38199 Mtetra
.859 .895 .86 r
.7389 .38199 .74179 .3842 .74815 .37815 .74528 .37583 Mtetra
.857 .889 .859 r
.74528 .37583 .74815 .37815 .75451 .3721 .75165 .36968 Mtetra
.856 .883 .857 r
.75165 .36968 .75451 .3721 .76087 .36606 .75802 .36353 Mtetra
.855 .878 .855 r
.75802 .36353 .76087 .36606 .76723 .36001 .76439 .35738 Mtetra
.853 .872 .854 r
.76439 .35738 .76723 .36001 .77358 .35397 .77075 .35122 Mtetra
.851 .867 .852 r
.77075 .35122 .77358 .35397 .77994 .34792 .77712 .34507 Mtetra
.85 .861 .85 r
.77712 .34507 .77994 .34792 .7863 .34188 .78348 .33893 Mtetra
.848 .856 .848 r
.78348 .33893 .7863 .34188 .79265 .33583 .78985 .33277 Mtetra
.847 .851 .846 r
.78985 .33277 .79265 .33583 .79901 .32978 .79621 .32662 Mtetra
.845 .845 .844 r
.79621 .32662 .79901 .32978 .80536 .32374 .80257 .32047 Mtetra
.843 .84 .842 r
.80257 .32047 .80536 .32374 .81171 .31769 .80893 .31431 Mtetra
.841 .835 .84 r
.80893 .31431 .81171 .31769 .81806 .31163 .81529 .30815 Mtetra
.839 .829 .838 r
.81529 .30815 .81806 .31163 .82441 .30559 .82165 .30201 Mtetra
.837 .824 .836 r
.82165 .30201 .82441 .30559 .83076 .29955 .828 .29586 Mtetra
.835 .819 .834 r
.828 .29586 .83076 .29955 .83711 .29351 .83436 .28972 Mtetra
.832 .814 .833 r
.83436 .28972 .83711 .29351 .84346 .28751 .84072 .28362 Mtetra
.826 .808 .834 r
.84072 .28362 .84346 .28751 .84983 .28164 .84709 .27766 Mtetra
.818 .802 .837 r
.84709 .27766 .84983 .28164 .85622 .27599 .85348 .27191 Mtetra
.805 .795 .843 r
.85348 .27191 .85622 .27599 .86265 .27069 .85991 .26652 Mtetra
.356 .622 .953 r
.25491 .46402 .25853 .46738 .26378 .46817 .26015 .46486 Mtetra
.214 .551 .932 r
.26015 .46486 .26378 .46817 .26899 .46964 .26536 .4664 Mtetra
.149 .517 .916 r
.26536 .4664 .26899 .46964 .27421 .47135 .27058 .46819 Mtetra
.109 .499 .904 r
.27058 .46819 .27421 .47135 .27944 .47318 .2758 .4701 Mtetra
.079 .486 .895 r
.2758 .4701 .27944 .47318 .28469 .47509 .28105 .47209 Mtetra
.06 .48 .889 r
.28105 .47209 .28469 .47509 .28996 .47702 .28632 .4741 Mtetra
.047 .477 .885 r
.28632 .4741 .28996 .47702 .29525 .47895 .29161 .47612 Mtetra
.03 .472 .879 r
.29161 .47612 .29525 .47895 .30057 .48089 .29692 .47814 Mtetra
.013 .467 .871 r
.29692 .47814 .30057 .48089 .30591 .48285 .30226 .48018 Mtetra
0 .462 .865 r
.30226 .48018 .30591 .48285 .31127 .4848 .30762 .48223 Mtetra
0 .457 .857 r
.30762 .48223 .31127 .4848 .31666 .48677 .31301 .48427 Mtetra
0 .45 .847 r
.31301 .48427 .31666 .48677 .32207 .48874 .31842 .48634 Mtetra
0 .444 .837 r
.31842 .48634 .32207 .48874 .32751 .49072 .32385 .48841 Mtetra
0 .438 .827 r
.32385 .48841 .32751 .49072 .33297 .49271 .32931 .49048 Mtetra
0 .43 .815 r
.32931 .49048 .33297 .49271 .33845 .49471 .3348 .49256 Mtetra
0 .421 .802 r
.3348 .49256 .33845 .49471 .34396 .49671 .34031 .49466 Mtetra
0 .413 .789 r
.34031 .49466 .34396 .49671 .3495 .49872 .34584 .49676 Mtetra
0 .404 .774 r
.34584 .49676 .3495 .49872 .35506 .50074 .3514 .49886 Mtetra
0 .394 .758 r
.3514 .49886 .35506 .50074 .36064 .50277 .35699 .50099 Mtetra
0 .384 .742 r
.35699 .50099 .36064 .50277 .36625 .50481 .3626 .50311 Mtetra
0 .375 .726 r
.3626 .50311 .36625 .50481 .37189 .50685 .36824 .50525 Mtetra
0 .363 .708 r
.36824 .50525 .37189 .50685 .37755 .50891 .3739 .5074 Mtetra
0 .352 .689 r
.3739 .5074 .37755 .50891 .38324 .51098 .37959 .50955 Mtetra
0 .341 .67 r
.37959 .50955 .38324 .51098 .38895 .51305 .38531 .51172 Mtetra
.259 0 0 r
.38531 .51172 .38895 .51305 .39469 .51513 .39105 .51389 Mtetra
.276 0 0 r
.39105 .51389 .39469 .51513 .40045 .51722 .39682 .51608 Mtetra
.291 0 0 r
.39682 .51608 .40045 .51722 .40625 .51933 .40262 .51828 Mtetra
.305 0 0 r
.40262 .51828 .40625 .51933 .41206 .52144 .40844 .52048 Mtetra
.321 0 0 r
.40844 .52048 .41206 .52144 .41791 .52356 .41429 .5227 Mtetra
.335 0 0 r
.41429 .5227 .41791 .52356 .42378 .52569 .42017 .52493 Mtetra
.348 0 0 r
.42017 .52493 .42378 .52569 .42968 .52783 .42607 .52717 Mtetra
.361 0 0 r
.42607 .52717 .42968 .52783 .43561 .52998 .43201 .52941 Mtetra
.374 0 0 r
.43201 .52941 .43561 .52998 .44156 .53215 .43797 .53168 Mtetra
.386 0 0 r
.43797 .53168 .44156 .53215 .44755 .53433 .44396 .53395 Mtetra
.397 0 0 r
.44396 .53395 .44755 .53433 .45356 .53651 .44997 .53624 Mtetra
.408 0 0 r
.44997 .53624 .45356 .53651 .45959 .53871 .45602 .53853 Mtetra
.419 0 0 r
.45602 .53853 .45959 .53871 .46566 .54092 .4621 .54085 Mtetra
.428 0 0 r
.4621 .54085 .46566 .54092 .47176 .54314 .4682 .54316 Mtetra
.438 0 0 r
.4682 .54316 .47176 .54314 .47788 .54537 .47434 .5455 Mtetra
.447 0 0 r
.47434 .5455 .47788 .54537 .48403 .54762 .4805 .54785 Mtetra
.455 0 0 r
.4805 .54785 .48403 .54762 .49022 .54987 .48669 .55021 Mtetra
.463 0 0 r
.48669 .55021 .49022 .54987 .49643 .55214 .49291 .55258 Mtetra
.471 0 0 r
.49291 .55258 .49643 .55214 .50267 .55442 .49917 .55497 Mtetra
.478 0 0 r
.49917 .55497 .50267 .55442 .50894 .55672 .50545 .55737 Mtetra
.483 0 0 r
.50545 .55737 .50894 .55672 .51524 .55902 .51177 .55977 Mtetra
.488 0 0 r
.51177 .55977 .51524 .55902 .52158 .56131 .51811 .56217 Mtetra
.51811 .56217 .52158 .56131 .52794 .56357 .52449 .56453 Mtetra
.473 0 0 r
.52449 .56453 .52794 .56357 .53433 .56563 .53089 .5667 Mtetra
.43 0 0 r
.53089 .5667 .53433 .56563 .54075 .56728 .53733 .56844 Mtetra
0 0 0 r
.53733 .56844 .54075 .56728 .54718 .56605 .54378 .56723 Mtetra
.735 .989 .801 r
.54378 .56723 .54718 .56605 .55359 .56058 .55021 .56165 Mtetra
.776 .996 .807 r
.55021 .56165 .55359 .56058 .56 .55472 .55664 .55568 Mtetra
.801 .999 .811 r
.55664 .55568 .56 .55472 .56641 .54863 .56307 .54947 Mtetra
.814 1 .816 r
.56307 .54947 .56641 .54863 .57281 .54244 .5695 .54317 Mtetra
.821 1 .822 r
.5695 .54317 .57281 .54244 .57922 .53625 .57592 .53686 Mtetra
.827 .999 .828 r
.57592 .53686 .57922 .53625 .58562 .53006 .58234 .53055 Mtetra
.833 .998 .833 r
.58234 .53055 .58562 .53006 .59202 .52386 .58876 .52423 Mtetra
.838 .996 .838 r
.58876 .52423 .59202 .52386 .59842 .51767 .59518 .51792 Mtetra
.842 .995 .842 r
.59518 .51792 .59842 .51767 .60482 .51148 .6016 .51162 Mtetra
.846 .992 .846 r
.6016 .51162 .60482 .51148 .61121 .5053 .60801 .50532 Mtetra
.85 .989 .849 r
.60801 .50532 .61121 .5053 .61761 .49911 .61443 .49901 Mtetra
.853 .986 .853 r
.61443 .49901 .61761 .49911 .624 .49293 .62084 .49272 Mtetra
.856 .983 .855 r
.62084 .49272 .624 .49293 .6304 .48675 .62725 .48643 Mtetra
.859 .979 .857 r
.62725 .48643 .6304 .48675 .63679 .48057 .63366 .48013 Mtetra
.861 .976 .859 r
.63366 .48013 .63679 .48057 .64318 .4744 .64007 .47385 Mtetra
.862 .971 .861 r
.64007 .47385 .64318 .4744 .64957 .46823 .64648 .46756 Mtetra
.864 .967 .862 r
.64648 .46756 .64957 .46823 .65596 .46206 .65288 .46128 Mtetra
.865 .962 .863 r
.65288 .46128 .65596 .46206 .66234 .45589 .65929 .45499 Mtetra
.866 .958 .864 r
.65929 .45499 .66234 .45589 .66873 .44973 .66569 .44872 Mtetra
.866 .953 .865 r
.66569 .44872 .66873 .44973 .67512 .44356 .67209 .44244 Mtetra
.867 .948 .865 r
.67209 .44244 .67512 .44356 .6815 .4374 .67849 .43617 Mtetra
.867 .943 .865 r
.67849 .43617 .6815 .4374 .68788 .43124 .68488 .42989 Mtetra
.867 .938 .865 r
.68488 .42989 .68788 .43124 .69427 .42508 .69128 .42363 Mtetra
.867 .932 .864 r
.69128 .42363 .69427 .42508 .70065 .41892 .69767 .41735 Mtetra
.867 .927 .864 r
.69767 .41735 .70065 .41892 .70703 .41276 .70407 .41108 Mtetra
.866 .922 .863 r
.70407 .41108 .70703 .41276 .7134 .40661 .71046 .40482 Mtetra
.865 .916 .862 r
.71046 .40482 .7134 .40661 .71978 .40045 .71685 .39856 Mtetra
.865 .911 .861 r
.71685 .39856 .71978 .40045 .72616 .39429 .72324 .39229 Mtetra
.864 .905 .86 r
.72324 .39229 .72616 .39429 .73253 .38814 .72962 .38603 Mtetra
.862 .9 .859 r
.72962 .38603 .73253 .38814 .7389 .38199 .73601 .37977 Mtetra
.861 .894 .857 r
.73601 .37977 .7389 .38199 .74528 .37583 .74239 .3735 Mtetra
.86 .889 .856 r
.74239 .3735 .74528 .37583 .75165 .36968 .74877 .36724 Mtetra
.859 .883 .854 r
.74877 .36724 .75165 .36968 .75802 .36353 .75515 .36099 Mtetra
.857 .878 .853 r
.75515 .36099 .75802 .36353 .76439 .35738 .76153 .35473 Mtetra
.856 .872 .851 r
.76153 .35473 .76439 .35738 .77075 .35122 .76791 .34847 Mtetra
.854 .867 .849 r
.76791 .34847 .77075 .35122 .77712 .34507 .77429 .34221 Mtetra
.852 .861 .847 r
.77429 .34221 .77712 .34507 .78348 .33893 .78066 .33596 Mtetra
.851 .856 .845 r
.78066 .33596 .78348 .33893 .78985 .33277 .78703 .32969 Mtetra
.849 .851 .843 r
.78703 .32969 .78985 .33277 .79621 .32662 .7934 .32344 Mtetra
.847 .845 .842 r
.7934 .32344 .79621 .32662 .80257 .32047 .79977 .31718 Mtetra
.846 .84 .839 r
.79977 .31718 .80257 .32047 .80893 .31431 .80614 .31092 Mtetra
.844 .835 .837 r
.80614 .31092 .80893 .31431 .81529 .30815 .8125 .30466 Mtetra
.842 .83 .835 r
.8125 .30466 .81529 .30815 .82165 .30201 .81887 .29841 Mtetra
.84 .825 .833 r
.81887 .29841 .82165 .30201 .828 .29586 .82523 .29216 Mtetra
.838 .82 .831 r
.82523 .29216 .828 .29586 .83436 .28972 .83159 .28591 Mtetra
.834 .814 .831 r
.83159 .28591 .83436 .28972 .84072 .28362 .83795 .27972 Mtetra
.829 .809 .832 r
.83795 .27972 .84072 .28362 .84709 .27766 .84433 .27365 Mtetra
.82 .803 .835 r
.84433 .27365 .84709 .27766 .85348 .27191 .85073 .26781 Mtetra
.807 .796 .842 r
.85073 .26781 .85348 .27191 .85991 .26652 .85717 .26234 Mtetra
.345 .617 .952 r
.25127 .46064 .25491 .46402 .26015 .46486 .25652 .46154 Mtetra
.198 .541 .927 r
.25652 .46154 .26015 .46486 .26536 .4664 .26173 .46314 Mtetra
.13 .506 .91 r
.26173 .46314 .26536 .4664 .27058 .46819 .26693 .46501 Mtetra
.089 .486 .897 r
.26693 .46501 .27058 .46819 .2758 .4701 .27216 .467 Mtetra
.059 .473 .887 r
.27216 .467 .2758 .4701 .28105 .47209 .2774 .46907 Mtetra
.039 .466 .88 r
.2774 .46907 .28105 .47209 .28632 .4741 .28266 .47117 Mtetra
.026 .463 .876 r
.28266 .47117 .28632 .4741 .29161 .47612 .28795 .47327 Mtetra
.009 .458 .869 r
.28795 .47327 .29161 .47612 .29692 .47814 .29326 .47538 Mtetra
0 .452 .861 r
.29326 .47538 .29692 .47814 .30226 .48018 .2986 .47751 Mtetra
0 .447 .854 r
.2986 .47751 .30226 .48018 .30762 .48223 .30396 .47964 Mtetra
0 .442 .846 r
.30396 .47964 .30762 .48223 .31301 .48427 .30934 .48177 Mtetra
0 .435 .835 r
.30934 .48177 .31301 .48427 .31842 .48634 .31475 .48392 Mtetra
0 .428 .825 r
.31475 .48392 .31842 .48634 .32385 .48841 .32018 .48607 Mtetra
0 .422 .814 r
.32018 .48607 .32385 .48841 .32931 .49048 .32564 .48823 Mtetra
0 .413 .802 r
.32564 .48823 .32931 .49048 .3348 .49256 .33113 .4904 Mtetra
0 .404 .788 r
.33113 .4904 .3348 .49256 .34031 .49466 .33664 .49259 Mtetra
0 .396 .775 r
.33664 .49259 .34031 .49466 .34584 .49676 .34217 .49478 Mtetra
0 .387 .76 r
.34217 .49478 .34584 .49676 .3514 .49886 .34773 .49697 Mtetra
0 .377 .744 r
.34773 .49697 .3514 .49886 .35699 .50099 .35332 .49918 Mtetra
0 .367 .728 r
.35332 .49918 .35699 .50099 .3626 .50311 .35893 .5014 Mtetra
0 .357 .711 r
.35893 .5014 .3626 .50311 .36824 .50525 .36457 .50363 Mtetra
0 .346 .693 r
.36457 .50363 .36824 .50525 .3739 .5074 .37024 .50587 Mtetra
0 .334 .674 r
.37024 .50587 .3739 .5074 .37959 .50955 .37593 .50812 Mtetra
.261 0 0 r
.37593 .50812 .37959 .50955 .38531 .51172 .38165 .51038 Mtetra
.277 0 0 r
.38165 .51038 .38531 .51172 .39105 .51389 .38739 .51264 Mtetra
.294 0 0 r
.38739 .51264 .39105 .51389 .39682 .51608 .39317 .51492 Mtetra
.308 0 0 r
.39317 .51492 .39682 .51608 .40262 .51828 .39897 .51722 Mtetra
.322 0 0 r
.39897 .51722 .40262 .51828 .40844 .52048 .40479 .51951 Mtetra
.337 0 0 r
.40479 .51951 .40844 .52048 .41429 .5227 .41065 .52183 Mtetra
.351 0 0 r
.41065 .52183 .41429 .5227 .42017 .52493 .41653 .52416 Mtetra
.363 0 0 r
.41653 .52416 .42017 .52493 .42607 .52717 .42244 .52649 Mtetra
.376 0 0 r
.42244 .52649 .42607 .52717 .43201 .52941 .42838 .52884 Mtetra
.389 0 0 r
.42838 .52884 .43201 .52941 .43797 .53168 .43435 .5312 Mtetra
.4 0 0 r
.43435 .5312 .43797 .53168 .44396 .53395 .44035 .53357 Mtetra
.41 0 0 r
.44035 .53357 .44396 .53395 .44997 .53624 .44637 .53595 Mtetra
.421 0 0 r
.44637 .53595 .44997 .53624 .45602 .53853 .45243 .53835 Mtetra
.432 0 0 r
.45243 .53835 .45602 .53853 .4621 .54085 .45851 .54076 Mtetra
.44 0 0 r
.45851 .54076 .4621 .54085 .4682 .54316 .46462 .54318 Mtetra
.449 0 0 r
.46462 .54318 .4682 .54316 .47434 .5455 .47077 .54562 Mtetra
.459 0 0 r
.47077 .54562 .47434 .5455 .4805 .54785 .47694 .54807 Mtetra
.466 0 0 r
.47694 .54807 .4805 .54785 .48669 .55021 .48314 .55054 Mtetra
.473 0 0 r
.48314 .55054 .48669 .55021 .49291 .55258 .48938 .55301 Mtetra
.481 0 0 r
.48938 .55301 .49291 .55258 .49917 .55497 .49564 .5555 Mtetra
.488 0 0 r
.49564 .5555 .49917 .55497 .50545 .55737 .50194 .55802 Mtetra
.493 0 0 r
.50194 .55802 .50545 .55737 .51177 .55977 .50826 .56052 Mtetra
.497 0 0 r
.50826 .56052 .51177 .55977 .51811 .56217 .51462 .56303 Mtetra
.51462 .56303 .51811 .56217 .52449 .56453 .52101 .5655 Mtetra
.482 0 0 r
.52101 .5655 .52449 .56453 .53089 .5667 .52743 .56777 Mtetra
.439 0 0 r
.52743 .56777 .53089 .5667 .53733 .56844 .53388 .56959 Mtetra
0 0 0 r
.53388 .56959 .53733 .56844 .54378 .56723 .54035 .5684 Mtetra
.743 .991 .803 r
.54035 .5684 .54378 .56723 .55021 .56165 .54681 .56272 Mtetra
.783 .997 .807 r
.54681 .56272 .55021 .56165 .55664 .55568 .55326 .55664 Mtetra
.808 1 .81 r
.55326 .55664 .55664 .55568 .56307 .54947 .55971 .55031 Mtetra
.821 1 .815 r
.55971 .55031 .56307 .54947 .5695 .54317 .56616 .54389 Mtetra
.827 1 .821 r
.56616 .54389 .5695 .54317 .57592 .53686 .5726 .53746 Mtetra
.833 .999 .826 r
.5726 .53746 .57592 .53686 .58234 .53055 .57904 .53104 Mtetra
.839 .997 .831 r
.57904 .53104 .58234 .53055 .58876 .52423 .58548 .5246 Mtetra
.843 .996 .836 r
.58548 .5246 .58876 .52423 .59518 .51792 .59192 .51817 Mtetra
.847 .994 .84 r
.59192 .51817 .59518 .51792 .6016 .51162 .59836 .51175 Mtetra
.851 .991 .844 r
.59836 .51175 .6016 .51162 .60801 .50532 .6048 .50533 Mtetra
.855 .988 .847 r
.6048 .50533 .60801 .50532 .61443 .49901 .61123 .49891 Mtetra
.857 .985 .85 r
.61123 .49891 .61443 .49901 .62084 .49272 .61766 .4925 Mtetra
.86 .982 .853 r
.61766 .4925 .62084 .49272 .62725 .48643 .62409 .48609 Mtetra
.863 .978 .855 r
.62409 .48609 .62725 .48643 .63366 .48013 .63052 .47968 Mtetra
.864 .974 .857 r
.63052 .47968 .63366 .48013 .64007 .47385 .63694 .47328 Mtetra
.866 .97 .858 r
.63694 .47328 .64007 .47385 .64648 .46756 .64337 .46688 Mtetra
.867 .966 .859 r
.64337 .46688 .64648 .46756 .65288 .46128 .64979 .46048 Mtetra
.869 .961 .86 r
.64979 .46048 .65288 .46128 .65929 .45499 .65621 .45409 Mtetra
.869 .957 .861 r
.65621 .45409 .65929 .45499 .66569 .44872 .66263 .4477 Mtetra
.87 .952 .862 r
.66263 .4477 .66569 .44872 .67209 .44244 .66904 .44131 Mtetra
.87 .947 .862 r
.66904 .44131 .67209 .44244 .67849 .43617 .67546 .43492 Mtetra
.87 .942 .862 r
.67546 .43492 .67849 .43617 .68488 .42989 .68187 .42854 Mtetra
.87 .937 .862 r
.68187 .42854 .68488 .42989 .69128 .42363 .68828 .42216 Mtetra
.87 .931 .861 r
.68828 .42216 .69128 .42363 .69767 .41735 .69469 .41577 Mtetra
.87 .926 .861 r
.69469 .41577 .69767 .41735 .70407 .41108 .70109 .40939 Mtetra
.869 .921 .86 r
.70109 .40939 .70407 .41108 .71046 .40482 .7075 .40302 Mtetra
.868 .915 .859 r
.7075 .40302 .71046 .40482 .71685 .39856 .7139 .39664 Mtetra
.867 .91 .858 r
.7139 .39664 .71685 .39856 .72324 .39229 .7203 .39027 Mtetra
.866 .904 .857 r
.7203 .39027 .72324 .39229 .72962 .38603 .7267 .3839 Mtetra
.865 .899 .856 r
.7267 .3839 .72962 .38603 .73601 .37977 .7331 .37753 Mtetra
.864 .893 .854 r
.7331 .37753 .73601 .37977 .74239 .3735 .73949 .37116 Mtetra
.863 .888 .853 r
.73949 .37116 .74239 .3735 .74877 .36724 .74588 .36479 Mtetra
.861 .883 .851 r
.74588 .36479 .74877 .36724 .75515 .36099 .75228 .35842 Mtetra
.86 .877 .85 r
.75228 .35842 .75515 .36099 .76153 .35473 .75866 .35206 Mtetra
.858 .872 .848 r
.75866 .35206 .76153 .35473 .76791 .34847 .76505 .34569 Mtetra
.857 .866 .846 r
.76505 .34569 .76791 .34847 .77429 .34221 .77144 .33933 Mtetra
.855 .861 .845 r
.77144 .33933 .77429 .34221 .78066 .33596 .77782 .33297 Mtetra
.853 .856 .843 r
.77782 .33297 .78066 .33596 .78703 .32969 .7842 .3266 Mtetra
.852 .85 .841 r
.7842 .3266 .78703 .32969 .7934 .32344 .79058 .32024 Mtetra
.85 .845 .839 r
.79058 .32024 .7934 .32344 .79977 .31718 .79696 .31388 Mtetra
.848 .84 .837 r
.79696 .31388 .79977 .31718 .80614 .31092 .80333 .30751 Mtetra
.846 .835 .835 r
.80333 .30751 .80614 .31092 .8125 .30466 .8097 .30115 Mtetra
.844 .83 .833 r
.8097 .30115 .8125 .30466 .81887 .29841 .81607 .29479 Mtetra
.842 .825 .831 r
.81607 .29479 .81887 .29841 .82523 .29216 .82244 .28844 Mtetra
.84 .82 .829 r
.82244 .28844 .82523 .29216 .83159 .28591 .82881 .28209 Mtetra
.837 .815 .828 r
.82881 .28209 .83159 .28591 .83795 .27972 .83518 .27579 Mtetra
.831 .809 .83 r
.83518 .27579 .83795 .27972 .84433 .27365 .84156 .26963 Mtetra
.823 .803 .833 r
.84156 .26963 .84433 .27365 .85073 .26781 .84797 .2637 Mtetra
.809 .796 .84 r
.84797 .2637 .85073 .26781 .85717 .26234 .85441 .25815 Mtetra
.335 .612 .951 r
.24763 .45724 .25127 .46064 .25652 .46154 .25287 .4582 Mtetra
.182 .532 .923 r
.25287 .4582 .25652 .46154 .26173 .46314 .25807 .45987 Mtetra
.112 .495 .903 r
.25807 .45987 .26173 .46314 .26693 .46501 .26328 .46182 Mtetra
.07 .474 .89 r
.26328 .46182 .26693 .46501 .27216 .467 .2685 .46389 Mtetra
.04 .46 .879 r
.2685 .46389 .27216 .467 .2774 .46907 .27373 .46604 Mtetra
.02 .452 .872 r
.27373 .46604 .2774 .46907 .28266 .47117 .27899 .46822 Mtetra
.007 .449 .867 r
.27899 .46822 .28266 .47117 .28795 .47327 .28428 .4704 Mtetra
0 .444 .86 r
.28428 .4704 .28795 .47327 .29326 .47538 .28959 .47259 Mtetra
0 .438 .852 r
.28959 .47259 .29326 .47538 .2986 .47751 .29492 .4748 Mtetra
0 .433 .844 r
.29492 .4748 .2986 .47751 .30396 .47964 .30028 .47701 Mtetra
0 .428 .836 r
.30028 .47701 .30396 .47964 .30934 .48177 .30566 .47923 Mtetra
0 .421 .826 r
.30566 .47923 .30934 .48177 .31475 .48392 .31107 .48146 Mtetra
0 .414 .815 r
.31107 .48146 .31475 .48392 .32018 .48607 .3165 .4837 Mtetra
0 .408 .805 r
.3165 .4837 .32018 .48607 .32564 .48823 .32196 .48595 Mtetra
0 .399 .793 r
.32196 .48595 .32564 .48823 .33113 .4904 .32744 .48821 Mtetra
0 .391 .779 r
.32744 .48821 .33113 .4904 .33664 .49259 .33295 .49048 Mtetra
0 .383 .766 r
.33295 .49048 .33664 .49259 .34217 .49478 .33848 .49275 Mtetra
0 .374 .752 r
.33848 .49275 .34217 .49478 .34773 .49697 .34405 .49504 Mtetra
0 .364 .736 r
.34405 .49504 .34773 .49697 .35332 .49918 .34963 .49734 Mtetra
0 .354 .72 r
.34963 .49734 .35332 .49918 .35893 .5014 .35525 .49964 Mtetra
0 .345 .704 r
.35525 .49964 .35893 .5014 .36457 .50363 .36089 .50196 Mtetra
0 .334 .686 r
.36089 .50196 .36457 .50363 .37024 .50587 .36655 .50429 Mtetra
0 .323 .668 r
.36655 .50429 .37024 .50587 .37593 .50812 .37225 .50663 Mtetra
.272 0 0 r
.37225 .50663 .37593 .50812 .38165 .51038 .37797 .50898 Mtetra
.287 0 0 r
.37797 .50898 .38165 .51038 .38739 .51264 .38372 .51133 Mtetra
.303 0 0 r
.38372 .51133 .38739 .51264 .39317 .51492 .38949 .51371 Mtetra
.317 0 0 r
.38949 .51371 .39317 .51492 .39897 .51722 .3953 .51609 Mtetra
.331 0 0 r
.3953 .51609 .39897 .51722 .40479 .51951 .40113 .51849 Mtetra
.345 0 0 r
.40113 .51849 .40479 .51951 .41065 .52183 .40699 .52089 Mtetra
.359 0 0 r
.40699 .52089 .41065 .52183 .41653 .52416 .41288 .52331 Mtetra
.37 0 0 r
.41288 .52331 .41653 .52416 .42244 .52649 .41879 .52574 Mtetra
.383 0 0 r
.41879 .52574 .42244 .52649 .42838 .52884 .42474 .52819 Mtetra
.395 0 0 r
.42474 .52819 .42838 .52884 .43435 .5312 .43071 .53064 Mtetra
.406 0 0 r
.43071 .53064 .43435 .5312 .44035 .53357 .43672 .53311 Mtetra
.416 0 0 r
.43672 .53311 .44035 .53357 .44637 .53595 .44275 .53559 Mtetra
.427 0 0 r
.44275 .53559 .44637 .53595 .45243 .53835 .44881 .53809 Mtetra
.437 0 0 r
.44881 .53809 .45243 .53835 .45851 .54076 .4549 .5406 Mtetra
.445 0 0 r
.4549 .5406 .45851 .54076 .46462 .54318 .46102 .54312 Mtetra
.454 0 0 r
.46102 .54312 .46462 .54318 .47077 .54562 .46718 .54566 Mtetra
.463 0 0 r
.46718 .54566 .47077 .54562 .47694 .54807 .47336 .54821 Mtetra
.471 0 0 r
.47336 .54821 .47694 .54807 .48314 .55054 .47957 .55078 Mtetra
.478 0 0 r
.47957 .55078 .48314 .55054 .48938 .55301 .48582 .55335 Mtetra
.486 0 0 r
.48582 .55335 .48938 .55301 .49564 .5555 .49209 .55595 Mtetra
.492 0 0 r
.49209 .55595 .49564 .5555 .50194 .55802 .4984 .55857 Mtetra
.497 0 0 r
.4984 .55857 .50194 .55802 .50826 .56052 .50474 .56118 Mtetra
.501 0 0 r
.50474 .56118 .50826 .56052 .51462 .56303 .51111 .56379 Mtetra
.51111 .56379 .51462 .56303 .52101 .5655 .51751 .56636 Mtetra
.485 0 0 r
.51751 .56636 .52101 .5655 .52743 .56777 .52395 .56873 Mtetra
.44 0 0 r
.52395 .56873 .52743 .56777 .53388 .56959 .53041 .57065 Mtetra
0 0 0 r
.53041 .57065 .53388 .56959 .54035 .5684 .5369 .56946 Mtetra
.761 .995 .812 r
.5369 .56946 .54035 .5684 .54681 .56272 .54337 .56368 Mtetra
.798 .999 .814 r
.54337 .56368 .54681 .56272 .55326 .55664 .54985 .55749 Mtetra
.821 1 .816 r
.54985 .55749 .55326 .55664 .55971 .55031 .55632 .55105 Mtetra
.832 .999 .82 r
.55632 .55105 .55971 .55031 .56616 .54389 .56279 .54452 Mtetra
.838 .998 .825 r
.56279 .54452 .56616 .54389 .5726 .53746 .56926 .53797 Mtetra
.843 .997 .829 r
.56926 .53797 .5726 .53746 .57904 .53104 .57572 .53143 Mtetra
.848 .995 .833 r
.57572 .53143 .57904 .53104 .58548 .5246 .58218 .52487 Mtetra
.852 .993 .837 r
.58218 .52487 .58548 .5246 .59192 .51817 .58864 .51833 Mtetra
.855 .991 .841 r
.58864 .51833 .59192 .51817 .59836 .51175 .5951 .51179 Mtetra
.859 .988 .844 r
.5951 .51179 .59836 .51175 .6048 .50533 .60155 .50526 Mtetra
.861 .985 .847 r
.60155 .50526 .6048 .50533 .61123 .49891 .60801 .49872 Mtetra
.864 .981 .849 r
.60801 .49872 .61123 .49891 .61766 .4925 .61446 .4922 Mtetra
.866 .978 .851 r
.61446 .4922 .61766 .4925 .62409 .48609 .6209 .48568 Mtetra
.868 .974 .853 r
.6209 .48568 .62409 .48609 .63052 .47968 .62735 .47915 Mtetra
.869 .97 .855 r
.62735 .47915 .63052 .47968 .63694 .47328 .63379 .47264 Mtetra
.87 .966 .856 r
.63379 .47264 .63694 .47328 .64337 .46688 .64023 .46613 Mtetra
.872 .962 .857 r
.64023 .46613 .64337 .46688 .64979 .46048 .64667 .45962 Mtetra
.872 .957 .858 r
.64667 .45962 .64979 .46048 .65621 .45409 .65311 .45311 Mtetra
.873 .952 .858 r
.65311 .45311 .65621 .45409 .66263 .4477 .65954 .44661 Mtetra
.873 .948 .859 r
.65954 .44661 .66263 .4477 .66904 .44131 .66597 .44011 Mtetra
.873 .943 .859 r
.66597 .44011 .66904 .44131 .67546 .43492 .6724 .43361 Mtetra
.873 .938 .859 r
.6724 .43361 .67546 .43492 .68187 .42854 .67883 .42711 Mtetra
.873 .933 .858 r
.67883 .42711 .68187 .42854 .68828 .42216 .68526 .42062 Mtetra
.873 .928 .858 r
.68526 .42062 .68828 .42216 .69469 .41577 .69168 .41413 Mtetra
.872 .922 .857 r
.69168 .41413 .69469 .41577 .70109 .40939 .6981 .40764 Mtetra
.871 .917 .856 r
.6981 .40764 .70109 .40939 .7075 .40302 .70452 .40116 Mtetra
.87 .912 .856 r
.70452 .40116 .7075 .40302 .7139 .39664 .71093 .39468 Mtetra
.87 .907 .854 r
.71093 .39468 .7139 .39664 .7203 .39027 .71735 .38819 Mtetra
.868 .901 .853 r
.71735 .38819 .7203 .39027 .7267 .3839 .72376 .38171 Mtetra
.867 .896 .852 r
.72376 .38171 .7267 .3839 .7331 .37753 .73017 .37524 Mtetra
.866 .891 .851 r
.73017 .37524 .7331 .37753 .73949 .37116 .73657 .36876 Mtetra
.865 .886 .849 r
.73657 .36876 .73949 .37116 .74588 .36479 .74298 .36229 Mtetra
.863 .88 .848 r
.74298 .36229 .74588 .36479 .75228 .35842 .74938 .35582 Mtetra
.862 .875 .846 r
.74938 .35582 .75228 .35842 .75866 .35206 .75578 .34934 Mtetra
.86 .87 .845 r
.75578 .34934 .75866 .35206 .76505 .34569 .76218 .34287 Mtetra
.859 .865 .843 r
.76218 .34287 .76505 .34569 .77144 .33933 .76857 .3364 Mtetra
.857 .859 .842 r
.76857 .3364 .77144 .33933 .77782 .33297 .77496 .32994 Mtetra
.855 .854 .84 r
.77496 .32994 .77782 .33297 .7842 .3266 .78135 .32347 Mtetra
.854 .849 .838 r
.78135 .32347 .7842 .3266 .79058 .32024 .78774 .317 Mtetra
.852 .844 .836 r
.78774 .317 .79058 .32024 .79696 .31388 .79413 .31054 Mtetra
.85 .839 .834 r
.79413 .31054 .79696 .31388 .80333 .30751 .80051 .30407 Mtetra
.848 .834 .832 r
.80051 .30407 .80333 .30751 .8097 .30115 .80689 .2976 Mtetra
.846 .829 .83 r
.80689 .2976 .8097 .30115 .81607 .29479 .81327 .29114 Mtetra
.844 .824 .829 r
.81327 .29114 .81607 .29479 .82244 .28844 .81964 .28469 Mtetra
.842 .82 .827 r
.81964 .28469 .82244 .28844 .82881 .28209 .82602 .27824 Mtetra
.839 .815 .826 r
.82602 .27824 .82881 .28209 .83518 .27579 .83239 .27185 Mtetra
.833 .809 .827 r
.83239 .27185 .83518 .27579 .84156 .26963 .83878 .26559 Mtetra
.825 .804 .831 r
.83878 .26559 .84156 .26963 .84797 .2637 .84519 .25956 Mtetra
.811 .797 .838 r
.84519 .25956 .84797 .2637 .85441 .25815 .85164 .25393 Mtetra
.325 .607 .95 r
.24396 .45384 .24763 .45724 .25287 .4582 .2492 .45484 Mtetra
.167 .523 .919 r
.2492 .45484 .25287 .4582 .25807 .45987 .2544 .45658 Mtetra
.096 .484 .897 r
.2544 .45658 .25807 .45987 .26328 .46182 .25961 .45859 Mtetra
.054 .462 .883 r
.25961 .45859 .26328 .46182 .2685 .46389 .26482 .46074 Mtetra
.024 .448 .872 r
.26482 .46074 .2685 .46389 .27373 .46604 .27005 .46297 Mtetra
.005 .44 .864 r
.27005 .46297 .27373 .46604 .27899 .46822 .27531 .46522 Mtetra
0 .438 .86 r
.27531 .46522 .27899 .46822 .28428 .4704 .28059 .46748 Mtetra
0 .432 .853 r
.28059 .46748 .28428 .4704 .28959 .47259 .2859 .46975 Mtetra
0 .426 .845 r
.2859 .46975 .28959 .47259 .29492 .4748 .29123 .47204 Mtetra
0 .422 .838 r
.29123 .47204 .29492 .4748 .30028 .47701 .29658 .47433 Mtetra
0 .417 .831 r
.29658 .47433 .30028 .47701 .30566 .47923 .30196 .47662 Mtetra
0 .41 .821 r
.30196 .47662 .30566 .47923 .31107 .48146 .30737 .47894 Mtetra
0 .404 .811 r
.30737 .47894 .31107 .48146 .3165 .4837 .3128 .48126 Mtetra
0 .398 .802 r
.3128 .48126 .3165 .4837 .32196 .48595 .31826 .48358 Mtetra
0 .39 .79 r
.31826 .48358 .32196 .48595 .32744 .48821 .32374 .48592 Mtetra
0 .382 .778 r
.32374 .48592 .32744 .48821 .33295 .49048 .32925 .48827 Mtetra
0 .375 .766 r
.32925 .48827 .33295 .49048 .33848 .49275 .33478 .49063 Mtetra
0 .367 .753 r
.33478 .49063 .33848 .49275 .34405 .49504 .34034 .493 Mtetra
0 .358 .738 r
.34034 .493 .34405 .49504 .34963 .49734 .34593 .49538 Mtetra
0 .349 .724 r
.34593 .49538 .34963 .49734 .35525 .49964 .35155 .49777 Mtetra
0 .34 .709 r
.35155 .49777 .35525 .49964 .36089 .50196 .35719 .50017 Mtetra
0 .33 .693 r
.35719 .50017 .36089 .50196 .36655 .50429 .36286 .50258 Mtetra
0 .32 .676 r
.36286 .50258 .36655 .50429 .37225 .50663 .36855 .50501 Mtetra
0 .311 .66 r
.36855 .50501 .37225 .50663 .37797 .50898 .37428 .50745 Mtetra
.283 0 0 r
.37428 .50745 .37797 .50898 .38372 .51133 .38003 .50989 Mtetra
.299 0 0 r
.38003 .50989 .38372 .51133 .38949 .51371 .38581 .51235 Mtetra
.312 0 0 r
.38581 .51235 .38949 .51371 .3953 .51609 .39161 .51482 Mtetra
.325 0 0 r
.39161 .51482 .3953 .51609 .40113 .51849 .39745 .5173 Mtetra
.339 0 0 r
.39745 .5173 .40113 .51849 .40699 .52089 .40331 .5198 Mtetra
.352 0 0 r
.40331 .5198 .40699 .52089 .41288 .52331 .40921 .52231 Mtetra
.364 0 0 r
.40921 .52231 .41288 .52331 .41879 .52574 .41513 .52483 Mtetra
.375 0 0 r
.41513 .52483 .41879 .52574 .42474 .52819 .42108 .52736 Mtetra
.388 0 0 r
.42108 .52736 .42474 .52819 .43071 .53064 .42706 .52991 Mtetra
.398 0 0 r
.42706 .52991 .43071 .53064 .43672 .53311 .43307 .53247 Mtetra
.409 0 0 r
.43307 .53247 .43672 .53311 .44275 .53559 .43911 .53505 Mtetra
.419 0 0 r
.43911 .53505 .44275 .53559 .44881 .53809 .44518 .53764 Mtetra
.429 0 0 r
.44518 .53764 .44881 .53809 .4549 .5406 .45128 .54024 Mtetra
.438 0 0 r
.45128 .54024 .4549 .5406 .46102 .54312 .45741 .54286 Mtetra
.447 0 0 r
.45741 .54286 .46102 .54312 .46718 .54566 .46357 .54549 Mtetra
.456 0 0 r
.46357 .54549 .46718 .54566 .47336 .54821 .46976 .54814 Mtetra
.464 0 0 r
.46976 .54814 .47336 .54821 .47957 .55078 .47598 .5508 Mtetra
.471 0 0 r
.47598 .5508 .47957 .55078 .48582 .55335 .48224 .55347 Mtetra
.479 0 0 r
.48224 .55347 .48582 .55335 .49209 .55595 .48852 .55617 Mtetra
.486 0 0 r
.48852 .55617 .49209 .55595 .4984 .55857 .49484 .55888 Mtetra
.49 0 0 r
.49484 .55888 .4984 .55857 .50474 .56118 .50119 .56159 Mtetra
.495 0 0 r
.50119 .56159 .50474 .56118 .51111 .56379 .50757 .5643 Mtetra
.50757 .5643 .51111 .56379 .51751 .56636 .51399 .56697 Mtetra
.477 0 0 r
.51399 .56697 .51751 .56636 .52395 .56873 .52044 .56944 Mtetra
.429 0 0 r
.52044 .56944 .52395 .56873 .53041 .57065 .52692 .57143 Mtetra
0 0 0 r
.52692 .57143 .53041 .57065 .5369 .56946 .53342 .57026 Mtetra
.79 .999 .833 r
.53342 .57026 .5369 .56946 .54337 .56368 .53992 .56439 Mtetra
.822 .999 .83 r
.53992 .56439 .54337 .56368 .54985 .55749 .54641 .55809 Mtetra
.841 .997 .829 r
.54641 .55809 .54985 .55749 .55632 .55105 .55291 .55154 Mtetra
.85 .995 .83 r
.55291 .55154 .55632 .55105 .56279 .54452 .5594 .54489 Mtetra
.854 .993 .834 r
.5594 .54489 .56279 .54452 .56926 .53797 .56589 .53824 Mtetra
.858 .991 .837 r
.56589 .53824 .56926 .53797 .57572 .53143 .57237 .53158 Mtetra
.861 .988 .84 r
.57237 .53158 .57572 .53143 .58218 .52487 .57885 .52492 Mtetra
.864 .986 .843 r
.57885 .52492 .58218 .52487 .58864 .51833 .58533 .51826 Mtetra
.866 .983 .845 r
.58533 .51826 .58864 .51833 .5951 .51179 .59181 .51161 Mtetra
.868 .979 .847 r
.59181 .51161 .5951 .51179 .60155 .50526 .59829 .50497 Mtetra
.87 .976 .849 r
.59829 .50497 .60155 .50526 .60801 .49872 .60476 .49832 Mtetra
.871 .972 .851 r
.60476 .49832 .60801 .49872 .61446 .4922 .61123 .49169 Mtetra
.873 .969 .852 r
.61123 .49169 .61446 .4922 .6209 .48568 .61769 .48506 Mtetra
.874 .965 .853 r
.61769 .48506 .6209 .48568 .62735 .47915 .62416 .47843 Mtetra
.875 .96 .854 r
.62416 .47843 .62735 .47915 .63379 .47264 .63062 .47181 Mtetra
.875 .956 .855 r
.63062 .47181 .63379 .47264 .64023 .46613 .63707 .46519 Mtetra
.876 .952 .855 r
.63707 .46519 .64023 .46613 .64667 .45962 .64353 .45857 Mtetra
.876 .947 .855 r
.64353 .45857 .64667 .45962 .65311 .45311 .64998 .45195 Mtetra
.876 .943 .856 r
.64998 .45195 .65311 .45311 .65954 .44661 .65643 .44535 Mtetra
.876 .938 .856 r
.65643 .44535 .65954 .44661 .66597 .44011 .66288 .43874 Mtetra
.876 .933 .855 r
.66288 .43874 .66597 .44011 .6724 .43361 .66933 .43214 Mtetra
.875 .929 .855 r
.66933 .43214 .6724 .43361 .67883 .42711 .67577 .42554 Mtetra
.875 .924 .855 r
.67577 .42554 .67883 .42711 .68526 .42062 .68221 .41894 Mtetra
.874 .919 .854 r
.68221 .41894 .68526 .42062 .69168 .41413 .68865 .41235 Mtetra
.873 .914 .853 r
.68865 .41235 .69168 .41413 .6981 .40764 .69508 .40575 Mtetra
.872 .909 .852 r
.69508 .40575 .6981 .40764 .70452 .40116 .70151 .39917 Mtetra
.871 .904 .851 r
.70151 .39917 .70452 .40116 .71093 .39468 .70794 .39258 Mtetra
.871 .899 .85 r
.70794 .39258 .71093 .39468 .71735 .38819 .71437 .38599 Mtetra
.869 .894 .849 r
.71437 .38599 .71735 .38819 .72376 .38171 .72079 .37941 Mtetra
.868 .89 .848 r
.72079 .37941 .72376 .38171 .73017 .37524 .72721 .37284 Mtetra
.867 .885 .847 r
.72721 .37284 .73017 .37524 .73657 .36876 .73363 .36626 Mtetra
.865 .88 .845 r
.73363 .36626 .73657 .36876 .74298 .36229 .74005 .35968 Mtetra
.864 .875 .844 r
.74005 .35968 .74298 .36229 .74938 .35582 .74646 .35311 Mtetra
.863 .87 .842 r
.74646 .35311 .74938 .35582 .75578 .34934 .75287 .34654 Mtetra
.861 .865 .841 r
.75287 .34654 .75578 .34934 .76218 .34287 .75928 .33996 Mtetra
.859 .86 .839 r
.75928 .33996 .76218 .34287 .76857 .3364 .76568 .3334 Mtetra
.858 .855 .838 r
.76568 .3334 .76857 .3364 .77496 .32994 .77209 .32683 Mtetra
.856 .851 .836 r
.77209 .32683 .77496 .32994 .78135 .32347 .77849 .32026 Mtetra
.855 .846 .834 r
.77849 .32026 .78135 .32347 .78774 .317 .78488 .3137 Mtetra
.853 .841 .833 r
.78488 .3137 .78774 .317 .79413 .31054 .79128 .30714 Mtetra
.851 .837 .831 r
.79128 .30714 .79413 .31054 .80051 .30407 .79767 .30057 Mtetra
.85 .832 .829 r
.79767 .30057 .80051 .30407 .80689 .2976 .80406 .294 Mtetra
.848 .827 .828 r
.80406 .294 .80689 .2976 .81327 .29114 .81044 .28745 Mtetra
.846 .823 .826 r
.81044 .28745 .81327 .29114 .81964 .28469 .81683 .2809 Mtetra
.844 .818 .824 r
.81683 .2809 .81964 .28469 .82602 .27824 .82321 .27435 Mtetra
.841 .814 .824 r
.82321 .27435 .82602 .27824 .83239 .27185 .82959 .26786 Mtetra
.835 .809 .825 r
.82959 .26786 .83239 .27185 .83878 .26559 .83599 .26151 Mtetra
.827 .803 .829 r
.83599 .26151 .83878 .26559 .84519 .25956 .8424 .25541 Mtetra
.813 .797 .837 r
.8424 .25541 .84519 .25956 .85164 .25393 .84886 .24969 Mtetra
.316 .602 .948 r
.24029 .45042 .24396 .45384 .2492 .45484 .24553 .45146 Mtetra
.154 .514 .915 r
.24553 .45146 .2492 .45484 .2544 .45658 .25072 .45326 Mtetra
.083 .474 .892 r
.25072 .45326 .2544 .45658 .25961 .45859 .25592 .45534 Mtetra
.041 .452 .877 r
.25592 .45534 .25961 .45859 .26482 .46074 .26113 .45755 Mtetra
.012 .438 .866 r
.26113 .45755 .26482 .46074 .27005 .46297 .26636 .45984 Mtetra
0 .431 .859 r
.26636 .45984 .27005 .46297 .27531 .46522 .27162 .46217 Mtetra
0 .428 .855 r
.27162 .46217 .27531 .46522 .28059 .46748 .27689 .46449 Mtetra
0 .423 .849 r
.27689 .46449 .28059 .46748 .2859 .46975 .2822 .46683 Mtetra
0 .418 .842 r
.2822 .46683 .2859 .46975 .29123 .47204 .28752 .46919 Mtetra
0 .414 .836 r
.28752 .46919 .29123 .47204 .29658 .47433 .29288 .47155 Mtetra
0 .41 .829 r
.29288 .47155 .29658 .47433 .30196 .47662 .29826 .47392 Mtetra
0 .404 .821 r
.29826 .47392 .30196 .47662 .30737 .47894 .30366 .4763 Mtetra
0 .398 .812 r
.30366 .4763 .30737 .47894 .3128 .48126 .30909 .4787 Mtetra
0 .393 .804 r
.30909 .4787 .3128 .48126 .31826 .48358 .31455 .48109 Mtetra
0 .387 .795 r
.31455 .48109 .31826 .48358 .32374 .48592 .32003 .4835 Mtetra
0 .38 .784 r
.32003 .4835 .32374 .48592 .32925 .48827 .32554 .48593 Mtetra
0 .374 .774 r
.32554 .48593 .32925 .48827 .33478 .49063 .33107 .48836 Mtetra
0 .367 .763 r
.33107 .48836 .33478 .49063 .34034 .493 .33663 .4908 Mtetra
0 .359 .751 r
.33663 .4908 .34034 .493 .34593 .49538 .34222 .49326 Mtetra
0 .351 .738 r
.34222 .49326 .34593 .49538 .35155 .49777 .34784 .49573 Mtetra
0 .344 .726 r
.34784 .49573 .35155 .49777 .35719 .50017 .35348 .4982 Mtetra
0 .336 .713 r
.35348 .4982 .35719 .50017 .36286 .50258 .35915 .50069 Mtetra
0 .327 .698 r
.35915 .50069 .36286 .50258 .36855 .50501 .36485 .5032 Mtetra
0 .319 .685 r
.36485 .5032 .36855 .50501 .37428 .50745 .37058 .50571 Mtetra
0 .31 .67 r
.37058 .50571 .37428 .50745 .38003 .50989 .37633 .50823 Mtetra
0 .3 .654 r
.37633 .50823 .38003 .50989 .38581 .51235 .38211 .51077 Mtetra
.291 0 0 r
.38211 .51077 .38581 .51235 .39161 .51482 .38792 .51332 Mtetra
.303 0 0 r
.38792 .51332 .39161 .51482 .39745 .5173 .39376 .51588 Mtetra
.317 0 0 r
.39376 .51588 .39745 .5173 .40331 .5198 .39963 .51846 Mtetra
.329 0 0 r
.39963 .51846 .40331 .5198 .40921 .52231 .40553 .52105 Mtetra
.34 0 0 r
.40553 .52105 .40921 .52231 .41513 .52483 .41145 .52365 Mtetra
.352 0 0 r
.41145 .52365 .41513 .52483 .42108 .52736 .41741 .52626 Mtetra
.364 0 0 r
.41741 .52626 .42108 .52736 .42706 .52991 .42339 .5289 Mtetra
.375 0 0 r
.42339 .5289 .42706 .52991 .43307 .53247 .42941 .53154 Mtetra
.385 0 0 r
.42941 .53154 .43307 .53247 .43911 .53505 .43545 .5342 Mtetra
.396 0 0 r
.43545 .5342 .43911 .53505 .44518 .53764 .44153 .53687 Mtetra
.406 0 0 r
.44153 .53687 .44518 .53764 .45128 .54024 .44764 .53956 Mtetra
.414 0 0 r
.44764 .53956 .45128 .54024 .45741 .54286 .45377 .54226 Mtetra
.424 0 0 r
.45377 .54226 .45741 .54286 .46357 .54549 .45994 .54498 Mtetra
.433 0 0 r
.45994 .54498 .46357 .54549 .46976 .54814 .46614 .54771 Mtetra
.441 0 0 r
.46614 .54771 .46976 .54814 .47598 .5508 .47237 .55046 Mtetra
.449 0 0 r
.47237 .55046 .47598 .5508 .48224 .55347 .47864 .55322 Mtetra
.458 0 0 r
.47864 .55322 .48224 .55347 .48852 .55617 .48493 .55601 Mtetra
.465 0 0 r
.48493 .55601 .48852 .55617 .49484 .55888 .49126 .55881 Mtetra
.47 0 0 r
.49126 .55881 .49484 .55888 .50119 .56159 .49762 .56161 Mtetra
.475 0 0 r
.49762 .56161 .50119 .56159 .50757 .5643 .50401 .56441 Mtetra
.50401 .56441 .50757 .5643 .51399 .56697 .51044 .56716 Mtetra
.455 0 0 r
.51044 .56716 .51399 .56697 .52044 .56944 .5169 .56971 Mtetra
.401 0 0 r
.5169 .56971 .52044 .56944 .52692 .57143 .52339 .57179 Mtetra
.178 .713 .759 r
.52339 .57179 .52692 .57143 .53342 .57026 .52991 .57062 Mtetra
.822 .995 .856 r
.52991 .57062 .53342 .57026 .53992 .56439 .53643 .56466 Mtetra
.847 .991 .848 r
.53643 .56466 .53992 .56439 .54641 .55809 .54295 .55827 Mtetra
.861 .987 .843 r
.54295 .55827 .54641 .55809 .55291 .55154 .54947 .55162 Mtetra
.868 .983 .842 r
.54947 .55162 .55291 .55154 .5594 .54489 .55598 .54487 Mtetra
.87 .98 .844 r
.55598 .54487 .5594 .54489 .56589 .53824 .56249 .53811 Mtetra
.872 .977 .846 r
.56249 .53811 .56589 .53824 .57237 .53158 .569 .53135 Mtetra
.874 .974 .847 r
.569 .53135 .57237 .53158 .57885 .52492 .5755 .52459 Mtetra
.875 .971 .848 r
.5755 .52459 .57885 .52492 .58533 .51826 .582 .51783 Mtetra
.876 .967 .85 r
.582 .51783 .58533 .51826 .59181 .51161 .5885 .51108 Mtetra
.877 .964 .85 r
.5885 .51108 .59181 .51161 .59829 .50497 .59499 .50434 Mtetra
.877 .96 .851 r
.59499 .50434 .59829 .50497 .60476 .49832 .60148 .49759 Mtetra
.878 .956 .852 r
.60148 .49759 .60476 .49832 .61123 .49169 .60797 .49086 Mtetra
.878 .953 .852 r
.60797 .49086 .61123 .49169 .61769 .48506 .61445 .48413 Mtetra
.879 .948 .853 r
.61445 .48413 .61769 .48506 .62416 .47843 .62093 .4774 Mtetra
.879 .944 .853 r
.62093 .4774 .62416 .47843 .63062 .47181 .62741 .47067 Mtetra
.878 .94 .853 r
.62741 .47067 .63062 .47181 .63707 .46519 .63389 .46396 Mtetra
.878 .936 .853 r
.63389 .46396 .63707 .46519 .64353 .45857 .64036 .45724 Mtetra
.878 .932 .853 r
.64036 .45724 .64353 .45857 .64998 .45195 .64683 .45053 Mtetra
.877 .928 .853 r
.64683 .45053 .64998 .45195 .65643 .44535 .6533 .44382 Mtetra
.877 .923 .852 r
.6533 .44382 .65643 .44535 .66288 .43874 .65976 .43712 Mtetra
.877 .919 .851 r
.65976 .43712 .66288 .43874 .66933 .43214 .66622 .43041 Mtetra
.876 .915 .851 r
.66622 .43041 .66933 .43214 .67577 .42554 .67268 .42372 Mtetra
.875 .91 .85 r
.67268 .42372 .67577 .42554 .68221 .41894 .67913 .41703 Mtetra
.874 .906 .849 r
.67913 .41703 .68221 .41894 .68865 .41235 .68559 .41034 Mtetra
.873 .901 .848 r
.68559 .41034 .68865 .41235 .69508 .40575 .69203 .40365 Mtetra
.872 .897 .848 r
.69203 .40365 .69508 .40575 .70151 .39917 .69848 .39696 Mtetra
.871 .893 .847 r
.69848 .39696 .70151 .39917 .70794 .39258 .70492 .39028 Mtetra
.87 .888 .845 r
.70492 .39028 .70794 .39258 .71437 .38599 .71136 .3836 Mtetra
.869 .884 .844 r
.71136 .3836 .71437 .38599 .72079 .37941 .7178 .37693 Mtetra
.867 .879 .843 r
.7178 .37693 .72079 .37941 .72721 .37284 .72424 .37026 Mtetra
.866 .875 .842 r
.72424 .37026 .72721 .37284 .73363 .36626 .73067 .36358 Mtetra
.865 .871 .841 r
.73067 .36358 .73363 .36626 .74005 .35968 .73709 .35691 Mtetra
.863 .866 .839 r
.73709 .35691 .74005 .35968 .74646 .35311 .74352 .35025 Mtetra
.862 .862 .838 r
.74352 .35025 .74646 .35311 .75287 .34654 .74994 .34359 Mtetra
.861 .858 .836 r
.74994 .34359 .75287 .34654 .75928 .33996 .75636 .33692 Mtetra
.859 .853 .835 r
.75636 .33692 .75928 .33996 .76568 .3334 .76278 .33026 Mtetra
.858 .849 .834 r
.76278 .33026 .76568 .3334 .77209 .32683 .76919 .32361 Mtetra
.856 .845 .832 r
.76919 .32361 .77209 .32683 .77849 .32026 .7756 .31695 Mtetra
.855 .841 .83 r
.7756 .31695 .77849 .32026 .78488 .3137 .78201 .31029 Mtetra
.853 .837 .829 r
.78201 .31029 .78488 .3137 .79128 .30714 .78841 .30364 Mtetra
.852 .832 .827 r
.78841 .30364 .79128 .30714 .79767 .30057 .79481 .29699 Mtetra
.85 .828 .826 r
.79481 .29699 .79767 .30057 .80406 .294 .80121 .29033 Mtetra
.848 .824 .824 r
.80121 .29033 .80406 .294 .81044 .28745 .8076 .28369 Mtetra
.847 .82 .823 r
.8076 .28369 .81044 .28745 .81683 .2809 .81399 .27705 Mtetra
.845 .816 .821 r
.81399 .27705 .81683 .2809 .82321 .27435 .82038 .27042 Mtetra
.842 .812 .821 r
.82038 .27042 .82321 .27435 .82959 .26786 .82677 .26384 Mtetra
.836 .808 .823 r
.82677 .26384 .82959 .26786 .83599 .26151 .83318 .25741 Mtetra
.828 .803 .827 r
.83318 .25741 .83599 .26151 .8424 .25541 .8396 .25122 Mtetra
.815 .797 .835 r
.8396 .25122 .8424 .25541 .84886 .24969 .84607 .24544 Mtetra
.318 .603 .949 r
.2366 .44698 .24029 .45042 .24553 .45146 .24184 .44801 Mtetra
.166 .517 .916 r
.24184 .44801 .24553 .45146 .25072 .45326 .24704 .4498 Mtetra
.107 .48 .897 r
.24704 .4498 .25072 .45326 .25592 .45534 .25224 .45186 Mtetra
.08 .462 .887 r
.25224 .45186 .25592 .45534 .26113 .45755 .25746 .45405 Mtetra
.066 .452 .881 r
.25746 .45405 .26113 .45755 .26636 .45984 .26269 .45632 Mtetra
.064 .45 .88 r
.26269 .45632 .26636 .45984 .27162 .46217 .26794 .45863 Mtetra
.068 .451 .881 r
.26794 .45863 .27162 .46217 .27689 .46449 .27322 .46094 Mtetra
.069 .451 .881 r
.27322 .46094 .27689 .46449 .2822 .46683 .27853 .46326 Mtetra
.07 .451 .881 r
.27853 .46326 .2822 .46683 .28752 .46919 .28386 .4656 Mtetra
.074 .452 .882 r
.28386 .4656 .28752 .46919 .29288 .47155 .28922 .46794 Mtetra
.077 .454 .883 r
.28922 .46794 .29288 .47155 .29826 .47392 .2946 .47029 Mtetra
.078 .453 .883 r
.2946 .47029 .29826 .47392 .30366 .4763 .3 .47266 Mtetra
.081 .454 .884 r
.3 .47266 .30366 .4763 .30909 .4787 .30544 .47503 Mtetra
.084 .455 .885 r
.30544 .47503 .30909 .4787 .31455 .48109 .3109 .47741 Mtetra
.086 .455 .885 r
.3109 .47741 .31455 .48109 .32003 .4835 .31638 .47981 Mtetra
.088 .455 .885 r
.31638 .47981 .32003 .4835 .32554 .48593 .32189 .48221 Mtetra
.091 .456 .886 r
.32189 .48221 .32554 .48593 .33107 .48836 .32743 .48463 Mtetra
.094 .457 .886 r
.32743 .48463 .33107 .48836 .33663 .4908 .333 .48705 Mtetra
.095 .457 .886 r
.333 .48705 .33663 .4908 .34222 .49326 .33859 .48949 Mtetra
.097 .458 .886 r
.33859 .48949 .34222 .49326 .34784 .49573 .34421 .49194 Mtetra
.1 .459 .887 r
.34421 .49194 .34784 .49573 .35348 .4982 .34985 .49439 Mtetra
.102 .459 .887 r
.34985 .49439 .35348 .4982 .35915 .50069 .35552 .49686 Mtetra
.104 .459 .887 r
.35552 .49686 .35915 .50069 .36485 .5032 .36123 .49935 Mtetra
.107 .459 .888 r
.36123 .49935 .36485 .5032 .37058 .50571 .36695 .50184 Mtetra
.109 .46 .888 r
.36695 .50184 .37058 .50571 .37633 .50823 .37271 .50434 Mtetra
.11 .46 .888 r
.37271 .50434 .37633 .50823 .38211 .51077 .3785 .50686 Mtetra
.112 .46 .888 r
.3785 .50686 .38211 .51077 .38792 .51332 .38431 .50939 Mtetra
.115 .461 .889 r
.38431 .50939 .38792 .51332 .39376 .51588 .39015 .51193 Mtetra
.116 .461 .889 r
.39015 .51193 .39376 .51588 .39963 .51846 .39602 .51449 Mtetra
.118 .461 .889 r
.39602 .51449 .39963 .51846 .40553 .52105 .40192 .51706 Mtetra
.121 .461 .889 r
.40192 .51706 .40553 .52105 .41145 .52365 .40785 .51964 Mtetra
.122 .462 .889 r
.40785 .51964 .41145 .52365 .41741 .52626 .41381 .52224 Mtetra
.123 .461 .889 r
.41381 .52224 .41741 .52626 .42339 .5289 .4198 .52485 Mtetra
.126 .462 .889 r
.4198 .52485 .42339 .5289 .42941 .53154 .42582 .52747 Mtetra
.128 .462 .889 r
.42582 .52747 .42941 .53154 .43545 .5342 .43187 .53011 Mtetra
.129 .462 .889 r
.43187 .53011 .43545 .5342 .44153 .53687 .43795 .53276 Mtetra
.13 .462 .889 r
.43795 .53276 .44153 .53687 .44764 .53956 .44406 .53543 Mtetra
.133 .463 .889 r
.44406 .53543 .44764 .53956 .45377 .54226 .4502 .53811 Mtetra
.135 .462 .889 r
.4502 .53811 .45377 .54226 .45994 .54498 .45637 .5408 Mtetra
.45637 .5408 .45994 .54498 .46614 .54771 .46257 .54352 Mtetra
.137 .462 .889 r
.46257 .54352 .46614 .54771 .47237 .55046 .46881 .54625 Mtetra
.14 .463 .889 r
.46881 .54625 .47237 .55046 .47864 .55322 .47507 .54899 Mtetra
.14 .462 .889 r
.47507 .54899 .47864 .55322 .48493 .55601 .48137 .55175 Mtetra
.141 .462 .889 r
.48137 .55175 .48493 .55601 .49126 .55881 .4877 .55453 Mtetra
.146 .464 .89 r
.4877 .55453 .49126 .55881 .49762 .56161 .49407 .55731 Mtetra
.15 .465 .89 r
.49407 .55731 .49762 .56161 .50401 .56441 .50047 .56009 Mtetra
.16 .471 .893 r
.50047 .56009 .50401 .56441 .51044 .56716 .5069 .56282 Mtetra
.194 .492 .902 r
.5069 .56282 .51044 .56716 .5169 .56971 .51336 .56535 Mtetra
.265 .533 .917 r
.51336 .56535 .5169 .56971 .52339 .57179 .51986 .5674 Mtetra
.597 .701 .916 r
.51986 .5674 .52339 .57179 .52991 .57062 .52638 .56623 Mtetra
.803 .762 .815 r
.52638 .56623 .52991 .57062 .53643 .56466 .53292 .56027 Mtetra
.813 .764 .807 r
.53292 .56027 .53643 .56466 .54295 .55827 .53945 .55388 Mtetra
.819 .765 .802 r
.53945 .55388 .54295 .55827 .54947 .55162 .54598 .54724 Mtetra
.822 .766 .8 r
.54598 .54724 .54947 .55162 .55598 .54487 .55251 .54049 Mtetra
.822 .767 .8 r
.55251 .54049 .55598 .54487 .56249 .53811 .55903 .53373 Mtetra
.55903 .53373 .56249 .53811 .569 .53135 .56555 .52698 Mtetra
.823 .768 .801 r
.56555 .52698 .569 .53135 .5755 .52459 .57206 .52021 Mtetra
.823 .769 .801 r
.57206 .52021 .5755 .52459 .582 .51783 .57858 .51346 Mtetra
.57858 .51346 .582 .51783 .5885 .51108 .58509 .50672 Mtetra
.824 .77 .802 r
.58509 .50672 .5885 .51108 .59499 .50434 .5916 .49997 Mtetra
.824 .771 .802 r
.5916 .49997 .59499 .50434 .60148 .49759 .5981 .49323 Mtetra
.5981 .49323 .60148 .49759 .60797 .49086 .6046 .4865 Mtetra
.825 .772 .803 r
.6046 .4865 .60797 .49086 .61445 .48413 .6111 .47978 Mtetra
.825 .773 .803 r
.6111 .47978 .61445 .48413 .62093 .4774 .6176 .47305 Mtetra
.6176 .47305 .62093 .4774 .62741 .47067 .62409 .46633 Mtetra
.825 .774 .804 r
.62409 .46633 .62741 .47067 .63389 .46396 .63058 .45961 Mtetra
.826 .775 .804 r
.63058 .45961 .63389 .46396 .64036 .45724 .63707 .4529 Mtetra
.63707 .4529 .64036 .45724 .64683 .45053 .64355 .44619 Mtetra
.826 .776 .805 r
.64355 .44619 .64683 .45053 .6533 .44382 .65003 .43949 Mtetra
.827 .777 .805 r
.65003 .43949 .6533 .44382 .65976 .43712 .65651 .43279 Mtetra
.65651 .43279 .65976 .43712 .66622 .43041 .66299 .42609 Mtetra
.827 .778 .806 r
.66299 .42609 .66622 .43041 .67268 .42372 .66946 .41939 Mtetra
.828 .779 .806 r
.66946 .41939 .67268 .42372 .67913 .41703 .67593 .4127 Mtetra
.828 .78 .806 r
.67593 .4127 .67913 .41703 .68559 .41034 .6824 .40601 Mtetra
.828 .78 .807 r
.6824 .40601 .68559 .41034 .69203 .40365 .68886 .39933 Mtetra
.829 .781 .807 r
.68886 .39933 .69203 .40365 .69848 .39696 .69532 .39265 Mtetra
.829 .782 .807 r
.69532 .39265 .69848 .39696 .70492 .39028 .70178 .38597 Mtetra
.829 .782 .808 r
.70178 .38597 .70492 .39028 .71136 .3836 .70823 .37929 Mtetra
.83 .783 .808 r
.70823 .37929 .71136 .3836 .7178 .37693 .71469 .37262 Mtetra
.83 .784 .808 r
.71469 .37262 .7178 .37693 .72424 .37026 .72114 .36595 Mtetra
.83 .785 .808 r
.72114 .36595 .72424 .37026 .73067 .36358 .72758 .35928 Mtetra
.831 .785 .809 r
.72758 .35928 .73067 .36358 .73709 .35691 .73403 .35261 Mtetra
.831 .786 .809 r
.73403 .35261 .73709 .35691 .74352 .35025 .74047 .34595 Mtetra
.831 .787 .809 r
.74047 .34595 .74352 .35025 .74994 .34359 .7469 .33929 Mtetra
.832 .787 .81 r
.7469 .33929 .74994 .34359 .75636 .33692 .75334 .33262 Mtetra
.832 .788 .81 r
.75334 .33262 .75636 .33692 .76278 .33026 .75977 .32597 Mtetra
.832 .789 .81 r
.75977 .32597 .76278 .33026 .76919 .32361 .7662 .31931 Mtetra
.833 .79 .811 r
.7662 .31931 .76919 .32361 .7756 .31695 .77262 .31265 Mtetra
.77262 .31265 .7756 .31695 .78201 .31029 .77904 .306 Mtetra
.834 .791 .811 r
.77904 .306 .78201 .31029 .78841 .30364 .78546 .29935 Mtetra
.834 .792 .811 r
.78546 .29935 .78841 .30364 .79481 .29699 .79188 .2927 Mtetra
.835 .793 .812 r
.79188 .2927 .79481 .29699 .80121 .29033 .79829 .28605 Mtetra
.79829 .28605 .80121 .29033 .8076 .28369 .8047 .2794 Mtetra
.835 .794 .812 r
.8047 .2794 .8076 .28369 .81399 .27705 .81111 .27277 Mtetra
.835 .795 .813 r
.81111 .27277 .81399 .27705 .82038 .27042 .81751 .26614 Mtetra
.834 .795 .814 r
.81751 .26614 .82038 .27042 .82677 .26384 .82392 .25956 Mtetra
.831 .795 .818 r
.82392 .25956 .82677 .26384 .83318 .25741 .83034 .25313 Mtetra
.824 .795 .824 r
.83034 .25313 .83318 .25741 .8396 .25122 .83678 .24694 Mtetra
.813 .793 .833 r
.83678 .24694 .8396 .25122 .84607 .24544 .84326 .24115 Mtetra
.327 .607 .95 r
.23289 .44353 .2366 .44698 .24184 .44801 .23814 .44451 Mtetra
.185 .526 .92 r
.23814 .44451 .24184 .44801 .24704 .4498 .24335 .44622 Mtetra
.136 .492 .904 r
.24335 .44622 .24704 .4498 .25224 .45186 .24856 .44821 Mtetra
.118 .476 .896 r
.24856 .44821 .25224 .45186 .25746 .45405 .25378 .45033 Mtetra
.113 .468 .892 r
.25378 .45033 .25746 .45405 .26269 .45632 .25902 .45253 Mtetra
.119 .467 .892 r
.25902 .45253 .26269 .45632 .26794 .45863 .26428 .45476 Mtetra
.131 .469 .893 r
.26428 .45476 .26794 .45863 .27322 .46094 .26957 .45699 Mtetra
.14 .47 .893 r
.26957 .45699 .27322 .46094 .27853 .46326 .27488 .45924 Mtetra
.148 .47 .893 r
.27488 .45924 .27853 .46326 .28386 .4656 .28022 .4615 Mtetra
.159 .472 .893 r
.28022 .4615 .28386 .4656 .28922 .46794 .28558 .46377 Mtetra
.169 .473 .893 r
.28558 .46377 .28922 .46794 .2946 .47029 .29097 .46604 Mtetra
.177 .473 .892 r
.29097 .46604 .2946 .47029 .3 .47266 .29638 .46832 Mtetra
.185 .474 .892 r
.29638 .46832 .3 .47266 .30544 .47503 .30182 .47062 Mtetra
.195 .475 .891 r
.30182 .47062 .30544 .47503 .3109 .47741 .30728 .47292 Mtetra
.203 .475 .89 r
.30728 .47292 .3109 .47741 .31638 .47981 .31278 .47523 Mtetra
.21 .475 .889 r
.31278 .47523 .31638 .47981 .32189 .48221 .31829 .47756 Mtetra
.218 .475 .887 r
.31829 .47756 .32189 .48221 .32743 .48463 .32383 .47989 Mtetra
.226 .475 .886 r
.32383 .47989 .32743 .48463 .333 .48705 .3294 .48223 Mtetra
.232 .475 .884 r
.3294 .48223 .333 .48705 .33859 .48949 .335 .48458 Mtetra
.239 .475 .883 r
.335 .48458 .33859 .48949 .34421 .49194 .34062 .48695 Mtetra
.247 .475 .881 r
.34062 .48695 .34421 .49194 .34985 .49439 .34627 .48932 Mtetra
.253 .474 .879 r
.34627 .48932 .34985 .49439 .35552 .49686 .35195 .49171 Mtetra
.258 .473 .877 r
.35195 .49171 .35552 .49686 .36123 .49935 .35766 .49411 Mtetra
.265 .473 .875 r
.35766 .49411 .36123 .49935 .36695 .50184 .36339 .49651 Mtetra
.271 .473 .873 r
.36339 .49651 .36695 .50184 .37271 .50434 .36915 .49893 Mtetra
.276 .472 .87 r
.36915 .49893 .37271 .50434 .3785 .50686 .37494 .50137 Mtetra
.282 .471 .868 r
.37494 .50137 .3785 .50686 .38431 .50939 .38075 .50381 Mtetra
.287 .471 .866 r
.38075 .50381 .38431 .50939 .39015 .51193 .3866 .50626 Mtetra
.292 .47 .864 r
.3866 .50626 .39015 .51193 .39602 .51449 .39247 .50873 Mtetra
.297 .469 .861 r
.39247 .50873 .39602 .51449 .40192 .51706 .39838 .51122 Mtetra
.302 .469 .859 r
.39838 .51122 .40192 .51706 .40785 .51964 .40431 .51371 Mtetra
.307 .468 .857 r
.40431 .51371 .40785 .51964 .41381 .52224 .41027 .51621 Mtetra
.31 .466 .854 r
.41027 .51621 .41381 .52224 .4198 .52485 .41626 .51873 Mtetra
.315 .466 .852 r
.41626 .51873 .4198 .52485 .42582 .52747 .42228 .52127 Mtetra
.32 .465 .849 r
.42228 .52127 .42582 .52747 .43187 .53011 .42833 .52381 Mtetra
.323 .464 .847 r
.42833 .52381 .43187 .53011 .43795 .53276 .43441 .52637 Mtetra
.327 .463 .844 r
.43441 .52637 .43795 .53276 .44406 .53543 .44052 .52895 Mtetra
.331 .462 .842 r
.44052 .52895 .44406 .53543 .4502 .53811 .44666 .53154 Mtetra
.335 .461 .84 r
.44666 .53154 .4502 .53811 .45637 .5408 .45284 .53414 Mtetra
.338 .46 .837 r
.45284 .53414 .45637 .5408 .46257 .54352 .45904 .53676 Mtetra
.342 .459 .835 r
.45904 .53676 .46257 .54352 .46881 .54625 .46527 .5394 Mtetra
.345 .459 .833 r
.46527 .5394 .46881 .54625 .47507 .54899 .47154 .54204 Mtetra
.348 .457 .83 r
.47154 .54204 .47507 .54899 .48137 .55175 .47784 .54471 Mtetra
.351 .456 .828 r
.47784 .54471 .48137 .55175 .4877 .55453 .48417 .54739 Mtetra
.355 .456 .825 r
.48417 .54739 .4877 .55453 .49407 .55731 .49053 .55007 Mtetra
.36 .456 .823 r
.49053 .55007 .49407 .55731 .50047 .56009 .49693 .55276 Mtetra
.367 .457 .821 r
.49693 .55276 .50047 .56009 .5069 .56282 .50336 .5554 Mtetra
.387 .467 .82 r
.50336 .5554 .5069 .56282 .51336 .56535 .50982 .55783 Mtetra
.424 .486 .819 r
.50982 .55783 .51336 .56535 .51986 .5674 .51631 .5598 Mtetra
.602 .582 .803 r
.51631 .5598 .51986 .5674 .52638 .56623 .52284 .5586 Mtetra
.746 .65 .753 r
.52284 .5586 .52638 .56623 .53292 .56027 .52938 .5527 Mtetra
.756 .655 .75 r
.52938 .5527 .53292 .56027 .53945 .55388 .53592 .54639 Mtetra
.762 .659 .748 r
.53592 .54639 .53945 .55388 .54598 .54724 .54246 .53981 Mtetra
.765 .662 .748 r
.54246 .53981 .54598 .54724 .55251 .54049 .549 .53314 Mtetra
.767 .664 .75 r
.549 .53314 .55251 .54049 .55903 .53373 .55553 .52646 Mtetra
.768 .667 .751 r
.55553 .52646 .55903 .53373 .56555 .52698 .56206 .51978 Mtetra
.77 .669 .752 r
.56206 .51978 .56555 .52698 .57206 .52021 .56858 .51309 Mtetra
.771 .671 .753 r
.56858 .51309 .57206 .52021 .57858 .51346 .5751 .50641 Mtetra
.772 .674 .755 r
.5751 .50641 .57858 .51346 .58509 .50672 .58163 .49974 Mtetra
.773 .676 .756 r
.58163 .49974 .58509 .50672 .5916 .49997 .58814 .49307 Mtetra
.775 .679 .757 r
.58814 .49307 .5916 .49997 .5981 .49323 .59466 .48641 Mtetra
.776 .681 .759 r
.59466 .48641 .5981 .49323 .6046 .4865 .60117 .47975 Mtetra
.777 .683 .76 r
.60117 .47975 .6046 .4865 .6111 .47978 .60768 .4731 Mtetra
.779 .686 .761 r
.60768 .4731 .6111 .47978 .6176 .47305 .61419 .46644 Mtetra
.78 .688 .763 r
.61419 .46644 .6176 .47305 .62409 .46633 .62069 .45979 Mtetra
.781 .691 .764 r
.62069 .45979 .62409 .46633 .63058 .45961 .6272 .45315 Mtetra
.783 .694 .765 r
.6272 .45315 .63058 .45961 .63707 .4529 .6337 .44651 Mtetra
.784 .696 .767 r
.6337 .44651 .63707 .4529 .64355 .44619 .64019 .43987 Mtetra
.786 .699 .768 r
.64019 .43987 .64355 .44619 .65003 .43949 .64669 .43324 Mtetra
.787 .701 .77 r
.64669 .43324 .65003 .43949 .65651 .43279 .65318 .42661 Mtetra
.789 .704 .771 r
.65318 .42661 .65651 .43279 .66299 .42609 .65967 .41998 Mtetra
.79 .707 .773 r
.65967 .41998 .66299 .42609 .66946 .41939 .66615 .41336 Mtetra
.792 .71 .774 r
.66615 .41336 .66946 .41939 .67593 .4127 .67264 .40674 Mtetra
.793 .713 .775 r
.67264 .40674 .67593 .4127 .6824 .40601 .67912 .40012 Mtetra
.795 .715 .777 r
.67912 .40012 .6824 .40601 .68886 .39933 .6856 .3935 Mtetra
.796 .718 .779 r
.6856 .3935 .68886 .39933 .69532 .39265 .69207 .38689 Mtetra
.798 .721 .78 r
.69207 .38689 .69532 .39265 .70178 .38597 .69855 .38028 Mtetra
.799 .724 .781 r
.69855 .38028 .70178 .38597 .70823 .37929 .70502 .37367 Mtetra
.801 .727 .783 r
.70502 .37367 .70823 .37929 .71469 .37262 .71149 .36706 Mtetra
.802 .73 .785 r
.71149 .36706 .71469 .37262 .72114 .36595 .71795 .36046 Mtetra
.804 .733 .786 r
.71795 .36046 .72114 .36595 .72758 .35928 .72442 .35386 Mtetra
.806 .737 .788 r
.72442 .35386 .72758 .35928 .73403 .35261 .73088 .34726 Mtetra
.807 .74 .789 r
.73088 .34726 .73403 .35261 .74047 .34595 .73733 .34066 Mtetra
.809 .743 .791 r
.73733 .34066 .74047 .34595 .7469 .33929 .74379 .33406 Mtetra
.81 .746 .792 r
.74379 .33406 .7469 .33929 .75334 .33262 .75024 .32747 Mtetra
.812 .749 .794 r
.75024 .32747 .75334 .33262 .75977 .32597 .75669 .32087 Mtetra
.814 .753 .795 r
.75669 .32087 .75977 .32597 .7662 .31931 .76314 .31429 Mtetra
.815 .756 .797 r
.76314 .31429 .7662 .31931 .77262 .31265 .76958 .30769 Mtetra
.817 .759 .798 r
.76958 .30769 .77262 .31265 .77904 .306 .77602 .3011 Mtetra
.819 .763 .8 r
.77602 .3011 .77904 .306 .78546 .29935 .78246 .29452 Mtetra
.82 .766 .802 r
.78246 .29452 .78546 .29935 .79188 .2927 .7889 .28793 Mtetra
.822 .77 .803 r
.7889 .28793 .79188 .2927 .79829 .28605 .79533 .28134 Mtetra
.824 .773 .805 r
.79533 .28134 .79829 .28605 .8047 .2794 .80176 .27476 Mtetra
.825 .777 .807 r
.80176 .27476 .8047 .2794 .81111 .27277 .80819 .26818 Mtetra
.827 .78 .808 r
.80819 .26818 .81111 .27277 .81751 .26614 .81461 .26161 Mtetra
.827 .784 .811 r
.81461 .26161 .81751 .26614 .82392 .25956 .82104 .25509 Mtetra
.825 .786 .816 r
.82104 .25509 .82392 .25956 .83034 .25313 .82748 .24872 Mtetra
.82 .789 .823 r
.82748 .24872 .83034 .25313 .83678 .24694 .83394 .24259 Mtetra
.81 .789 .833 r
.83394 .24259 .83678 .24694 .84326 .24115 .84044 .23685 Mtetra
.337 .613 .951 r
.22917 .44006 .23289 .44353 .23814 .44451 .23443 .44098 Mtetra
.201 .534 .924 r
.23443 .44098 .23814 .44451 .24335 .44622 .23965 .44262 Mtetra
.155 .502 .909 r
.23965 .44262 .24335 .44622 .24856 .44821 .24486 .44453 Mtetra
.139 .487 .902 r
.24486 .44453 .24856 .44821 .25378 .45033 .25009 .44657 Mtetra
.136 .479 .898 r
.25009 .44657 .25378 .45033 .25902 .45253 .25534 .44868 Mtetra
.142 .478 .897 r
.25534 .44868 .25902 .45253 .26428 .45476 .26061 .45083 Mtetra
.155 .48 .898 r
.26061 .45083 .26428 .45476 .26957 .45699 .26591 .45297 Mtetra
.165 .481 .898 r
.26591 .45297 .26957 .45699 .27488 .45924 .27123 .45513 Mtetra
.174 .481 .897 r
.27123 .45513 .27488 .45924 .28022 .4615 .27657 .4573 Mtetra
.185 .482 .897 r
.27657 .4573 .28022 .4615 .28558 .46377 .28194 .45948 Mtetra
.195 .483 .896 r
.28194 .45948 .28558 .46377 .29097 .46604 .28733 .46167 Mtetra
.203 .483 .895 r
.28733 .46167 .29097 .46604 .29638 .46832 .29275 .46386 Mtetra
.212 .483 .894 r
.29275 .46386 .29638 .46832 .30182 .47062 .2982 .46607 Mtetra
.222 .483 .892 r
.2982 .46607 .30182 .47062 .30728 .47292 .30367 .46828 Mtetra
.23 .483 .891 r
.30367 .46828 .30728 .47292 .31278 .47523 .30917 .4705 Mtetra
.237 .482 .889 r
.30917 .4705 .31278 .47523 .31829 .47756 .31469 .47274 Mtetra
.245 .482 .887 r
.31469 .47274 .31829 .47756 .32383 .47989 .32024 .47498 Mtetra
.253 .482 .885 r
.32024 .47498 .32383 .47989 .3294 .48223 .32581 .47722 Mtetra
.26 .481 .882 r
.32581 .47722 .3294 .48223 .335 .48458 .33141 .47949 Mtetra
.267 .481 .88 r
.33141 .47949 .335 .48458 .34062 .48695 .33704 .48176 Mtetra
.274 .48 .878 r
.33704 .48176 .34062 .48695 .34627 .48932 .3427 .48404 Mtetra
.28 .48 .875 r
.3427 .48404 .34627 .48932 .35195 .49171 .34838 .48633 Mtetra
.286 .479 .873 r
.34838 .48633 .35195 .49171 .35766 .49411 .35409 .48864 Mtetra
.292 .478 .87 r
.35409 .48864 .35766 .49411 .36339 .49651 .35982 .49095 Mtetra
.298 .477 .868 r
.35982 .49095 .36339 .49651 .36915 .49893 .36559 .49327 Mtetra
.303 .476 .865 r
.36559 .49327 .36915 .49893 .37494 .50137 .37138 .49561 Mtetra
.308 .475 .862 r
.37138 .49561 .37494 .50137 .38075 .50381 .3772 .49795 Mtetra
.314 .474 .859 r
.3772 .49795 .38075 .50381 .3866 .50626 .38305 .50031 Mtetra
.319 .473 .857 r
.38305 .50031 .3866 .50626 .39247 .50873 .38893 .50268 Mtetra
.323 .472 .854 r
.38893 .50268 .39247 .50873 .39838 .51122 .39483 .50507 Mtetra
.328 .471 .851 r
.39483 .50507 .39838 .51122 .40431 .51371 .40077 .50746 Mtetra
.333 .47 .848 r
.40077 .50746 .40431 .51371 .41027 .51621 .40673 .50986 Mtetra
.336 .469 .846 r
.40673 .50986 .41027 .51621 .41626 .51873 .41272 .51229 Mtetra
.341 .468 .843 r
.41272 .51229 .41626 .51873 .42228 .52127 .41874 .51472 Mtetra
.345 .467 .84 r
.41874 .51472 .42228 .52127 .42833 .52381 .42479 .51716 Mtetra
.348 .465 .837 r
.42479 .51716 .42833 .52381 .43441 .52637 .43088 .51962 Mtetra
.352 .464 .835 r
.43088 .51962 .43441 .52637 .44052 .52895 .43699 .5221 Mtetra
.356 .463 .832 r
.43699 .5221 .44052 .52895 .44666 .53154 .44313 .52458 Mtetra
.359 .462 .829 r
.44313 .52458 .44666 .53154 .45284 .53414 .4493 .52708 Mtetra
.362 .46 .826 r
.4493 .52708 .45284 .53414 .45904 .53676 .45551 .52959 Mtetra
.366 .459 .824 r
.45551 .52959 .45904 .53676 .46527 .5394 .46174 .53212 Mtetra
.369 .458 .821 r
.46174 .53212 .46527 .5394 .47154 .54204 .46801 .53466 Mtetra
.371 .457 .819 r
.46801 .53466 .47154 .54204 .47784 .54471 .4743 .53722 Mtetra
.374 .456 .816 r
.4743 .53722 .47784 .54471 .48417 .54739 .48063 .5398 Mtetra
.379 .455 .813 r
.48063 .5398 .48417 .54739 .49053 .55007 .48699 .54237 Mtetra
.382 .455 .811 r
.48699 .54237 .49053 .55007 .49693 .55276 .49339 .54494 Mtetra
.389 .456 .809 r
.49339 .54494 .49693 .55276 .50336 .5554 .49981 .54748 Mtetra
.407 .464 .807 r
.49981 .54748 .50336 .5554 .50982 .55783 .50627 .54981 Mtetra
.44 .481 .806 r
.50627 .54981 .50982 .55783 .51631 .5598 .51277 .55169 Mtetra
.602 .569 .79 r
.51277 .55169 .51631 .5598 .52284 .5586 .5193 .55046 Mtetra
.738 .636 .746 r
.5193 .55046 .52284 .5586 .52938 .5527 .52584 .54463 Mtetra
.747 .642 .743 r
.52584 .54463 .52938 .5527 .53592 .54639 .53239 .53839 Mtetra
.753 .646 .742 r
.53239 .53839 .53592 .54639 .54246 .53981 .53893 .5319 Mtetra
.757 .649 .742 r
.53893 .5319 .54246 .53981 .549 .53314 .54547 .52532 Mtetra
.758 .651 .744 r
.54547 .52532 .549 .53314 .55553 .52646 .55201 .51873 Mtetra
.76 .654 .745 r
.55201 .51873 .55553 .52646 .56206 .51978 .55855 .51213 Mtetra
.761 .656 .746 r
.55855 .51213 .56206 .51978 .56858 .51309 .56508 .50553 Mtetra
.762 .659 .748 r
.56508 .50553 .56858 .51309 .5751 .50641 .57162 .49894 Mtetra
.764 .661 .749 r
.57162 .49894 .5751 .50641 .58163 .49974 .57815 .49235 Mtetra
.765 .664 .751 r
.57815 .49235 .58163 .49974 .58814 .49307 .58467 .48577 Mtetra
.767 .666 .752 r
.58467 .48577 .58814 .49307 .59466 .48641 .5912 .47918 Mtetra
.768 .669 .754 r
.5912 .47918 .59466 .48641 .60117 .47975 .59772 .47261 Mtetra
.769 .672 .755 r
.59772 .47261 .60117 .47975 .60768 .4731 .60424 .46604 Mtetra
.771 .674 .756 r
.60424 .46604 .60768 .4731 .61419 .46644 .61076 .45947 Mtetra
.772 .677 .758 r
.61076 .45947 .61419 .46644 .62069 .45979 .61728 .4529 Mtetra
.774 .68 .76 r
.61728 .4529 .62069 .45979 .6272 .45315 .62379 .44635 Mtetra
.775 .682 .761 r
.62379 .44635 .6272 .45315 .6337 .44651 .6303 .43979 Mtetra
.777 .685 .763 r
.6303 .43979 .6337 .44651 .64019 .43987 .63681 .43323 Mtetra
.778 .688 .764 r
.63681 .43323 .64019 .43987 .64669 .43324 .64332 .42668 Mtetra
.78 .691 .766 r
.64332 .42668 .64669 .43324 .65318 .42661 .64982 .42013 Mtetra
.782 .694 .767 r
.64982 .42013 .65318 .42661 .65967 .41998 .65633 .41358 Mtetra
.783 .697 .769 r
.65633 .41358 .65967 .41998 .66615 .41336 .66283 .40704 Mtetra
.785 .7 .771 r
.66283 .40704 .66615 .41336 .67264 .40674 .66932 .4005 Mtetra
.786 .703 .772 r
.66932 .4005 .67264 .40674 .67912 .40012 .67582 .39396 Mtetra
.788 .706 .774 r
.67582 .39396 .67912 .40012 .6856 .3935 .68231 .38742 Mtetra
.79 .709 .775 r
.68231 .38742 .6856 .3935 .69207 .38689 .68881 .38089 Mtetra
.791 .712 .777 r
.68881 .38089 .69207 .38689 .69855 .38028 .69529 .37436 Mtetra
.793 .716 .779 r
.69529 .37436 .69855 .38028 .70502 .37367 .70178 .36782 Mtetra
.795 .719 .78 r
.70178 .36782 .70502 .37367 .71149 .36706 .70827 .3613 Mtetra
.796 .722 .782 r
.70827 .3613 .71149 .36706 .71795 .36046 .71475 .35477 Mtetra
.798 .726 .784 r
.71475 .35477 .71795 .36046 .72442 .35386 .72123 .34824 Mtetra
.8 .729 .786 r
.72123 .34824 .72442 .35386 .73088 .34726 .7277 .34172 Mtetra
.802 .732 .787 r
.7277 .34172 .73088 .34726 .73733 .34066 .73418 .3352 Mtetra
.804 .736 .789 r
.73418 .3352 .73733 .34066 .74379 .33406 .74065 .32868 Mtetra
.805 .739 .791 r
.74065 .32868 .74379 .33406 .75024 .32747 .74712 .32216 Mtetra
.807 .743 .793 r
.74712 .32216 .75024 .32747 .75669 .32087 .75359 .31564 Mtetra
.809 .747 .794 r
.75359 .31564 .75669 .32087 .76314 .31429 .76006 .30912 Mtetra
.811 .75 .796 r
.76006 .30912 .76314 .31429 .76958 .30769 .76652 .3026 Mtetra
.813 .754 .798 r
.76652 .3026 .76958 .30769 .77602 .3011 .77298 .29609 Mtetra
.814 .758 .8 r
.77298 .29609 .77602 .3011 .78246 .29452 .77944 .28958 Mtetra
.816 .762 .801 r
.77944 .28958 .78246 .29452 .7889 .28793 .7859 .28306 Mtetra
.818 .766 .803 r
.7859 .28306 .7889 .28793 .79533 .28134 .79235 .27654 Mtetra
.82 .77 .805 r
.79235 .27654 .79533 .28134 .80176 .27476 .7988 .27003 Mtetra
.822 .774 .807 r
.7988 .27003 .80176 .27476 .80819 .26818 .80525 .26353 Mtetra
.824 .778 .809 r
.80525 .26353 .80819 .26818 .81461 .26161 .8117 .25703 Mtetra
.824 .781 .812 r
.8117 .25703 .81461 .26161 .82104 .25509 .81815 .25058 Mtetra
.822 .785 .817 r
.81815 .25058 .82104 .25509 .82748 .24872 .82461 .24428 Mtetra
.818 .787 .824 r
.82461 .24428 .82748 .24872 .83394 .24259 .83109 .2382 Mtetra
.808 .788 .834 r
.83109 .2382 .83394 .24259 .84044 .23685 .83761 .23252 Mtetra
.348 .618 .952 r
.22544 .43658 .22917 .44006 .23443 .44098 .23071 .43743 Mtetra
.217 .543 .928 r
.23071 .43743 .23443 .44098 .23965 .44262 .23593 .439 Mtetra
.174 .513 .914 r
.23593 .439 .23965 .44262 .24486 .44453 .24116 .44082 Mtetra
.159 .498 .907 r
.24116 .44082 .24486 .44453 .25009 .44657 .24639 .44277 Mtetra
.156 .491 .904 r
.24639 .44277 .25009 .44657 .25534 .44868 .25165 .4448 Mtetra
.163 .489 .903 r
.25165 .4448 .25534 .44868 .26061 .45083 .25693 .44685 Mtetra
.175 .491 .903 r
.25693 .44685 .26061 .45083 .26591 .45297 .26223 .44891 Mtetra
.185 .491 .902 r
.26223 .44891 .26591 .45297 .27123 .45513 .26756 .45097 Mtetra
.194 .491 .901 r
.26756 .45097 .27123 .45513 .27657 .4573 .27291 .45306 Mtetra
.205 .492 .9 r
.27291 .45306 .27657 .4573 .28194 .45948 .27829 .45514 Mtetra
.215 .492 .899 r
.27829 .45514 .28194 .45948 .28733 .46167 .28369 .45723 Mtetra
.223 .492 .898 r
.28369 .45723 .28733 .46167 .29275 .46386 .28912 .45934 Mtetra
.232 .491 .896 r
.28912 .45934 .29275 .46386 .2982 .46607 .29457 .46145 Mtetra
.242 .492 .894 r
.29457 .46145 .2982 .46607 .30367 .46828 .30005 .46356 Mtetra
.25 .491 .892 r
.30005 .46356 .30367 .46828 .30917 .4705 .30555 .46569 Mtetra
.257 .49 .89 r
.30555 .46569 .30917 .4705 .31469 .47274 .31108 .46783 Mtetra
.265 .49 .887 r
.31108 .46783 .31469 .47274 .32024 .47498 .31663 .46998 Mtetra
.272 .489 .885 r
.31663 .46998 .32024 .47498 .32581 .47722 .32221 .47213 Mtetra
.279 .488 .882 r
.32221 .47213 .32581 .47722 .33141 .47949 .32782 .47429 Mtetra
.285 .487 .88 r
.32782 .47429 .33141 .47949 .33704 .48176 .33345 .47647 Mtetra
.292 .487 .877 r
.33345 .47647 .33704 .48176 .3427 .48404 .33911 .47865 Mtetra
.298 .485 .874 r
.33911 .47865 .3427 .48404 .34838 .48633 .3448 .48084 Mtetra
.304 .484 .871 r
.3448 .48084 .34838 .48633 .35409 .48864 .35051 .48305 Mtetra
.31 .483 .869 r
.35051 .48305 .35409 .48864 .35982 .49095 .35625 .48526 Mtetra
.316 .482 .866 r
.35625 .48526 .35982 .49095 .36559 .49327 .36202 .48748 Mtetra
.32 .481 .863 r
.36202 .48748 .36559 .49327 .37138 .49561 .36782 .48972 Mtetra
.326 .48 .86 r
.36782 .48972 .37138 .49561 .3772 .49795 .37364 .49196 Mtetra
.331 .479 .857 r
.37364 .49196 .3772 .49795 .38305 .50031 .37949 .49422 Mtetra
.335 .477 .854 r
.37949 .49422 .38305 .50031 .38893 .50268 .38537 .49649 Mtetra
.34 .476 .851 r
.38537 .49649 .38893 .50268 .39483 .50507 .39128 .49877 Mtetra
.344 .475 .848 r
.39128 .49877 .39483 .50507 .40077 .50746 .39722 .50106 Mtetra
.349 .474 .845 r
.39722 .50106 .40077 .50746 .40673 .50986 .40318 .50336 Mtetra
.352 .472 .842 r
.40318 .50336 .40673 .50986 .41272 .51229 .40918 .50567 Mtetra
.356 .471 .839 r
.40918 .50567 .41272 .51229 .41874 .51472 .4152 .508 Mtetra
.36 .47 .836 r
.4152 .508 .41874 .51472 .42479 .51716 .42126 .51034 Mtetra
.364 .468 .833 r
.42126 .51034 .42479 .51716 .43088 .51962 .42734 .51269 Mtetra
.367 .467 .83 r
.42734 .51269 .43088 .51962 .43699 .5221 .43345 .51506 Mtetra
.371 .466 .827 r
.43345 .51506 .43699 .5221 .44313 .52458 .43959 .51743 Mtetra
.374 .464 .825 r
.43959 .51743 .44313 .52458 .4493 .52708 .44576 .51982 Mtetra
.377 .463 .822 r
.44576 .51982 .4493 .52708 .45551 .52959 .45197 .52223 Mtetra
.38 .462 .819 r
.45197 .52223 .45551 .52959 .46174 .53212 .4582 .52464 Mtetra
.383 .461 .816 r
.4582 .52464 .46174 .53212 .46801 .53466 .46447 .52707 Mtetra
.385 .459 .814 r
.46447 .52707 .46801 .53466 .4743 .53722 .47076 .52952 Mtetra
.388 .458 .811 r
.47076 .52952 .4743 .53722 .48063 .5398 .47709 .53198 Mtetra
.392 .457 .808 r
.47709 .53198 .48063 .5398 .48699 .54237 .48345 .53444 Mtetra
.396 .457 .806 r
.48345 .53444 .48699 .54237 .49339 .54494 .48984 .5369 Mtetra
.402 .457 .803 r
.48984 .5369 .49339 .54494 .49981 .54748 .49626 .53932 Mtetra
.418 .465 .801 r
.49626 .53932 .49981 .54748 .50627 .54981 .50272 .54155 Mtetra
.45 .481 .799 r
.50272 .54155 .50627 .54981 .51277 .55169 .50921 .54332 Mtetra
.602 .564 .784 r
.50921 .54332 .51277 .55169 .5193 .55046 .51574 .54207 Mtetra
.733 .629 .743 r
.51574 .54207 .5193 .55046 .52584 .54463 .52229 .53632 Mtetra
.742 .635 .741 r
.52229 .53632 .52584 .54463 .53239 .53839 .52885 .53016 Mtetra
.748 .64 .74 r
.52885 .53016 .53239 .53839 .53893 .5319 .5354 .52376 Mtetra
.752 .643 .74 r
.5354 .52376 .53893 .5319 .54547 .52532 .54194 .51727 Mtetra
.753 .645 .742 r
.54194 .51727 .54547 .52532 .55201 .51873 .54849 .51077 Mtetra
.755 .648 .743 r
.54849 .51077 .55201 .51873 .55855 .51213 .55504 .50427 Mtetra
.756 .65 .744 r
.55504 .50427 .55855 .51213 .56508 .50553 .56158 .49775 Mtetra
.758 .653 .746 r
.56158 .49775 .56508 .50553 .57162 .49894 .56812 .49125 Mtetra
.759 .655 .747 r
.56812 .49125 .57162 .49894 .57815 .49235 .57466 .48476 Mtetra
.76 .658 .749 r
.57466 .48476 .57815 .49235 .58467 .48577 .58119 .47826 Mtetra
.762 .661 .75 r
.58119 .47826 .58467 .48577 .5912 .47918 .58773 .47177 Mtetra
.763 .663 .752 r
.58773 .47177 .5912 .47918 .59772 .47261 .59426 .46528 Mtetra
.765 .666 .753 r
.59426 .46528 .59772 .47261 .60424 .46604 .60079 .4588 Mtetra
.766 .669 .755 r
.60079 .4588 .60424 .46604 .61076 .45947 .60732 .45232 Mtetra
.768 .671 .756 r
.60732 .45232 .61076 .45947 .61728 .4529 .61385 .44584 Mtetra
.769 .674 .758 r
.61385 .44584 .61728 .4529 .62379 .44635 .62037 .43937 Mtetra
.771 .677 .76 r
.62037 .43937 .62379 .44635 .6303 .43979 .6269 .4329 Mtetra
.772 .68 .761 r
.6269 .4329 .6303 .43979 .63681 .43323 .63342 .42643 Mtetra
.774 .683 .763 r
.63342 .42643 .63681 .43323 .64332 .42668 .63994 .41996 Mtetra
.776 .686 .765 r
.63994 .41996 .64332 .42668 .64982 .42013 .64646 .4135 Mtetra
.777 .689 .766 r
.64646 .4135 .64982 .42013 .65633 .41358 .65297 .40704 Mtetra
.779 .692 .768 r
.65297 .40704 .65633 .41358 .66283 .40704 .65948 .40058 Mtetra
.78 .695 .77 r
.65948 .40058 .66283 .40704 .66932 .4005 .666 .39412 Mtetra
.782 .698 .771 r
.666 .39412 .66932 .4005 .67582 .39396 .67251 .38767 Mtetra
.784 .701 .773 r
.67251 .38767 .67582 .39396 .68231 .38742 .67901 .38121 Mtetra
.786 .705 .775 r
.67901 .38121 .68231 .38742 .68881 .38089 .68552 .37476 Mtetra
.787 .708 .776 r
.68552 .37476 .68881 .38089 .69529 .37436 .69203 .36831 Mtetra
.789 .711 .778 r
.69203 .36831 .69529 .37436 .70178 .36782 .69853 .36186 Mtetra
.791 .715 .78 r
.69853 .36186 .70178 .36782 .70827 .3613 .70503 .35542 Mtetra
.793 .718 .782 r
.70503 .35542 .70827 .3613 .71475 .35477 .71153 .34898 Mtetra
.794 .722 .784 r
.71153 .34898 .71475 .35477 .72123 .34824 .71802 .34253 Mtetra
.796 .725 .785 r
.71802 .34253 .72123 .34824 .7277 .34172 .72452 .33609 Mtetra
.798 .729 .787 r
.72452 .33609 .7277 .34172 .73418 .3352 .73101 .32965 Mtetra
.8 .732 .789 r
.73101 .32965 .73418 .3352 .74065 .32868 .7375 .32321 Mtetra
.802 .736 .791 r
.7375 .32321 .74065 .32868 .74712 .32216 .74399 .31676 Mtetra
.804 .74 .793 r
.74399 .31676 .74712 .32216 .75359 .31564 .75048 .31033 Mtetra
.805 .744 .795 r
.75048 .31033 .75359 .31564 .76006 .30912 .75696 .30389 Mtetra
.808 .748 .797 r
.75696 .30389 .76006 .30912 .76652 .3026 .76344 .29745 Mtetra
.809 .751 .798 r
.76344 .29745 .76652 .3026 .77298 .29609 .76992 .29101 Mtetra
.811 .755 .801 r
.76992 .29101 .77298 .29609 .77944 .28958 .7764 .28458 Mtetra
.813 .759 .802 r
.7764 .28458 .77944 .28958 .7859 .28306 .78288 .27814 Mtetra
.815 .764 .804 r
.78288 .27814 .7859 .28306 .79235 .27654 .78935 .2717 Mtetra
.817 .768 .806 r
.78935 .2717 .79235 .27654 .7988 .27003 .79583 .26526 Mtetra
.819 .772 .808 r
.79583 .26526 .7988 .27003 .80525 .26353 .8023 .25884 Mtetra
.821 .776 .81 r
.8023 .25884 .80525 .26353 .8117 .25703 .80877 .25241 Mtetra
.822 .78 .813 r
.80877 .25241 .8117 .25703 .81815 .25058 .81524 .24604 Mtetra
.82 .783 .818 r
.81524 .24604 .81815 .25058 .82461 .24428 .82172 .2398 Mtetra
.815 .786 .825 r
.82172 .2398 .82461 .24428 .83109 .2382 .82823 .2338 Mtetra
.805 .787 .836 r
.82823 .2338 .83109 .2382 .83761 .23252 .83477 .22817 Mtetra
.359 .623 .953 r
.22169 .43309 .22544 .43658 .23071 .43743 .22697 .43388 Mtetra
.233 .552 .932 r
.22697 .43388 .23071 .43743 .23593 .439 .2322 .43536 Mtetra
.191 .523 .919 r
.2322 .43536 .23593 .439 .24116 .44082 .23743 .4371 Mtetra
.177 .509 .912 r
.23743 .4371 .24116 .44082 .24639 .44277 .24268 .43896 Mtetra
.174 .501 .909 r
.24268 .43896 .24639 .44277 .25165 .4448 .24795 .44089 Mtetra
.181 .5 .907 r
.24795 .44089 .25165 .4448 .25693 .44685 .25323 .44286 Mtetra
.193 .501 .907 r
.25323 .44286 .25693 .44685 .26223 .44891 .25854 .44482 Mtetra
.203 .501 .906 r
.25854 .44482 .26223 .44891 .26756 .45097 .26388 .44679 Mtetra
.212 .5 .905 r
.26388 .44679 .26756 .45097 .27291 .45306 .26924 .44878 Mtetra
.222 .501 .904 r
.26924 .44878 .27291 .45306 .27829 .45514 .27462 .45077 Mtetra
.232 .501 .902 r
.27462 .45077 .27829 .45514 .28369 .45723 .28003 .45277 Mtetra
.24 .5 .9 r
.28003 .45277 .28369 .45723 .28912 .45934 .28547 .45478 Mtetra
.248 .5 .898 r
.28547 .45478 .28912 .45934 .29457 .46145 .29093 .4568 Mtetra
.257 .5 .896 r
.29093 .4568 .29457 .46145 .30005 .46356 .29641 .45882 Mtetra
.265 .499 .894 r
.29641 .45882 .30005 .46356 .30555 .46569 .30192 .46085 Mtetra
.272 .498 .891 r
.30192 .46085 .30555 .46569 .31108 .46783 .30746 .46289 Mtetra
.28 .497 .889 r
.30746 .46289 .31108 .46783 .31663 .46998 .31302 .46494 Mtetra
.287 .496 .886 r
.31302 .46494 .31663 .46998 .32221 .47213 .3186 .46699 Mtetra
.293 .495 .883 r
.3186 .46699 .32221 .47213 .32782 .47429 .32422 .46906 Mtetra
.299 .494 .881 r
.32422 .46906 .32782 .47429 .33345 .47647 .32985 .47114 Mtetra
.306 .493 .878 r
.32985 .47114 .33345 .47647 .33911 .47865 .33552 .47322 Mtetra
.312 .492 .875 r
.33552 .47322 .33911 .47865 .3448 .48084 .34121 .47531 Mtetra
.317 .49 .872 r
.34121 .47531 .3448 .48084 .35051 .48305 .34693 .47742 Mtetra
.323 .489 .869 r
.34693 .47742 .35051 .48305 .35625 .48526 .35268 .47953 Mtetra
.328 .488 .866 r
.35268 .47953 .35625 .48526 .36202 .48748 .35845 .48165 Mtetra
.333 .487 .863 r
.35845 .48165 .36202 .48748 .36782 .48972 .36425 .48378 Mtetra
.338 .485 .86 r
.36425 .48378 .36782 .48972 .37364 .49196 .37008 .48593 Mtetra
.343 .484 .857 r
.37008 .48593 .37364 .49196 .37949 .49422 .37593 .48808 Mtetra
.347 .483 .854 r
.37593 .48808 .37949 .49422 .38537 .49649 .38181 .49024 Mtetra
.351 .481 .851 r
.38181 .49024 .38537 .49649 .39128 .49877 .38773 .49242 Mtetra
.356 .48 .848 r
.38773 .49242 .39128 .49877 .39722 .50106 .39366 .4946 Mtetra
.359 .479 .845 r
.39366 .4946 .39722 .50106 .40318 .50336 .39963 .4968 Mtetra
.363 .477 .841 r
.39963 .4968 .40318 .50336 .40918 .50567 .40563 .49901 Mtetra
.367 .476 .838 r
.40563 .49901 .40918 .50567 .4152 .508 .41165 .50123 Mtetra
.371 .474 .836 r
.41165 .50123 .4152 .508 .42126 .51034 .41771 .50345 Mtetra
.374 .473 .833 r
.41771 .50345 .42126 .51034 .42734 .51269 .42379 .5057 Mtetra
.377 .471 .83 r
.42379 .5057 .42734 .51269 .43345 .51506 .42991 .50796 Mtetra
.381 .47 .827 r
.42991 .50796 .43345 .51506 .43959 .51743 .43605 .51022 Mtetra
.383 .469 .824 r
.43605 .51022 .43959 .51743 .44576 .51982 .44222 .5125 Mtetra
.386 .467 .821 r
.44222 .5125 .44576 .51982 .45197 .52223 .44842 .5148 Mtetra
.389 .466 .818 r
.44842 .5148 .45197 .52223 .4582 .52464 .45466 .5171 Mtetra
.392 .464 .815 r
.45466 .5171 .4582 .52464 .46447 .52707 .46092 .51941 Mtetra
.394 .463 .813 r
.46092 .51941 .46447 .52707 .47076 .52952 .46722 .52175 Mtetra
.397 .461 .81 r
.46722 .52175 .47076 .52952 .47709 .53198 .47354 .5241 Mtetra
.401 .461 .807 r
.47354 .5241 .47709 .53198 .48345 .53444 .4799 .52645 Mtetra
.404 .46 .805 r
.4799 .52645 .48345 .53444 .48984 .5369 .48629 .52879 Mtetra
.41 .461 .802 r
.48629 .52879 .48984 .5369 .49626 .53932 .49271 .5311 Mtetra
.426 .468 .8 r
.49271 .5311 .49626 .53932 .50272 .54155 .49916 .53321 Mtetra
.456 .483 .798 r
.49916 .53321 .50272 .54155 .50921 .54332 .50565 .53489 Mtetra
.602 .563 .783 r
.50565 .53489 .50921 .54332 .51574 .54207 .51218 .5336 Mtetra
.73 .627 .743 r
.51218 .5336 .51574 .54207 .52229 .53632 .51874 .52793 Mtetra
.74 .633 .741 r
.51874 .52793 .52229 .53632 .52885 .53016 .5253 .52186 Mtetra
.746 .637 .74 r
.5253 .52186 .52885 .53016 .5354 .52376 .53185 .51555 Mtetra
.749 .64 .74 r
.53185 .51555 .5354 .52376 .54194 .51727 .53841 .50915 Mtetra
.75 .643 .742 r
.53841 .50915 .54194 .51727 .54849 .51077 .54496 .50274 Mtetra
.752 .645 .743 r
.54496 .50274 .54849 .51077 .55504 .50427 .55151 .49633 Mtetra
.754 .648 .744 r
.55151 .49633 .55504 .50427 .56158 .49775 .55806 .48991 Mtetra
.755 .651 .746 r
.55806 .48991 .56158 .49775 .56812 .49125 .56461 .4835 Mtetra
.756 .653 .748 r
.56461 .4835 .56812 .49125 .57466 .48476 .57116 .4771 Mtetra
.758 .656 .749 r
.57116 .4771 .57466 .48476 .58119 .47826 .57771 .4707 Mtetra
.759 .658 .751 r
.57771 .4707 .58119 .47826 .58773 .47177 .58425 .46429 Mtetra
.76 .661 .752 r
.58425 .46429 .58773 .47177 .59426 .46528 .59079 .4579 Mtetra
.762 .664 .754 r
.59079 .4579 .59426 .46528 .60079 .4588 .59733 .45151 Mtetra
.764 .667 .755 r
.59733 .45151 .60079 .4588 .60732 .45232 .60387 .44511 Mtetra
.765 .669 .757 r
.60387 .44511 .60732 .45232 .61385 .44584 .61041 .43872 Mtetra
.767 .672 .759 r
.61041 .43872 .61385 .44584 .62037 .43937 .61695 .43234 Mtetra
.768 .675 .76 r
.61695 .43234 .62037 .43937 .6269 .4329 .62348 .42596 Mtetra
.77 .678 .762 r
.62348 .42596 .6269 .4329 .63342 .42643 .63001 .41957 Mtetra
.771 .681 .763 r
.63001 .41957 .63342 .42643 .63994 .41996 .63655 .41319 Mtetra
.773 .684 .765 r
.63655 .41319 .63994 .41996 .64646 .4135 .64308 .40682 Mtetra
.775 .687 .767 r
.64308 .40682 .64646 .4135 .65297 .40704 .6496 .40044 Mtetra
.776 .69 .769 r
.6496 .40044 .65297 .40704 .65948 .40058 .65613 .39407 Mtetra
.778 .693 .77 r
.65613 .39407 .65948 .40058 .666 .39412 .66266 .3877 Mtetra
.78 .696 .772 r
.66266 .3877 .666 .39412 .67251 .38767 .66918 .38133 Mtetra
.781 .7 .774 r
.66918 .38133 .67251 .38767 .67901 .38121 .6757 .37496 Mtetra
.783 .703 .776 r
.6757 .37496 .67901 .38121 .68552 .37476 .68222 .36859 Mtetra
.785 .706 .777 r
.68222 .36859 .68552 .37476 .69203 .36831 .68874 .36223 Mtetra
.786 .71 .779 r
.68874 .36223 .69203 .36831 .69853 .36186 .69526 .35586 Mtetra
.788 .713 .781 r
.69526 .35586 .69853 .36186 .70503 .35542 .70178 .3495 Mtetra
.79 .716 .783 r
.70178 .3495 .70503 .35542 .71153 .34898 .70829 .34314 Mtetra
.792 .72 .785 r
.70829 .34314 .71153 .34898 .71802 .34253 .71481 .33677 Mtetra
.794 .724 .786 r
.71481 .33677 .71802 .34253 .72452 .33609 .72132 .33041 Mtetra
.795 .727 .788 r
.72132 .33041 .72452 .33609 .73101 .32965 .72783 .32406 Mtetra
.797 .731 .79 r
.72783 .32406 .73101 .32965 .7375 .32321 .73434 .3177 Mtetra
.799 .735 .792 r
.73434 .3177 .7375 .32321 .74399 .31676 .74084 .31133 Mtetra
.801 .738 .794 r
.74084 .31133 .74399 .31676 .75048 .31033 .74735 .30498 Mtetra
.803 .742 .796 r
.74735 .30498 .75048 .31033 .75696 .30389 .75385 .29862 Mtetra
.805 .746 .798 r
.75385 .29862 .75696 .30389 .76344 .29745 .76035 .29226 Mtetra
.807 .75 .8 r
.76035 .29226 .76344 .29745 .76992 .29101 .76686 .2859 Mtetra
.809 .754 .802 r
.76686 .2859 .76992 .29101 .7764 .28458 .77335 .27955 Mtetra
.811 .758 .804 r
.77335 .27955 .7764 .28458 .78288 .27814 .77985 .27319 Mtetra
.813 .762 .806 r
.77985 .27319 .78288 .27814 .78935 .2717 .78635 .26682 Mtetra
.815 .767 .808 r
.78635 .26682 .78935 .2717 .79583 .26526 .79284 .26047 Mtetra
.816 .771 .81 r
.79284 .26047 .79583 .26526 .8023 .25884 .79933 .25412 Mtetra
.818 .775 .812 r
.79933 .25412 .8023 .25884 .80877 .25241 .80582 .24777 Mtetra
.819 .779 .815 r
.80582 .24777 .80877 .25241 .81524 .24604 .81232 .24148 Mtetra
.817 .783 .82 r
.81232 .24148 .81524 .24604 .82172 .2398 .81882 .23531 Mtetra
.813 .785 .827 r
.81882 .23531 .82172 .2398 .82823 .2338 .82535 .22937 Mtetra
.803 .787 .838 r
.82535 .22937 .82823 .2338 .83477 .22817 .83191 .2238 Mtetra
.369 .628 .954 r
.21793 .42958 .22169 .43309 .22697 .43388 .22321 .4303 Mtetra
.249 .561 .935 r
.22321 .4303 .22697 .43388 .2322 .43536 .22845 .43171 Mtetra
.208 .533 .923 r
.22845 .43171 .2322 .43536 .23743 .4371 .2337 .43336 Mtetra
.195 .519 .917 r
.2337 .43336 .23743 .4371 .24268 .43896 .23895 .43513 Mtetra
.192 .512 .913 r
.23895 .43513 .24268 .43896 .24795 .44089 .24423 .43697 Mtetra
.199 .51 .912 r
.24423 .43697 .24795 .44089 .25323 .44286 .24952 .43884 Mtetra
.211 .511 .911 r
.24952 .43884 .25323 .44286 .25854 .44482 .25484 .44071 Mtetra
.22 .511 .91 r
.25484 .44071 .25854 .44482 .26388 .44679 .26019 .4426 Mtetra
.228 .51 .908 r
.26019 .4426 .26388 .44679 .26924 .44878 .26556 .44449 Mtetra
.238 .51 .907 r
.26556 .44449 .26924 .44878 .27462 .45077 .27095 .44639 Mtetra
.248 .51 .905 r
.27095 .44639 .27462 .45077 .28003 .45277 .27637 .44829 Mtetra
.255 .509 .903 r
.27637 .44829 .28003 .45277 .28547 .45478 .28181 .4502 Mtetra
.263 .508 .901 r
.28181 .4502 .28547 .45478 .29093 .4568 .28727 .45213 Mtetra
.272 .508 .899 r
.28727 .45213 .29093 .4568 .29641 .45882 .29276 .45405 Mtetra
.279 .507 .896 r
.29276 .45405 .29641 .45882 .30192 .46085 .29828 .45599 Mtetra
.286 .505 .893 r
.29828 .45599 .30192 .46085 .30746 .46289 .30382 .45793 Mtetra
.293 .505 .891 r
.30382 .45793 .30746 .46289 .31302 .46494 .30939 .45988 Mtetra
.3 .504 .888 r
.30939 .45988 .31302 .46494 .3186 .46699 .31498 .46184 Mtetra
.306 .502 .885 r
.31498 .46184 .3186 .46699 .32422 .46906 .3206 .46381 Mtetra
.312 .501 .882 r
.3206 .46381 .32422 .46906 .32985 .47114 .32625 .46578 Mtetra
.318 .5 .879 r
.32625 .46578 .32985 .47114 .33552 .47322 .33192 .46777 Mtetra
.324 .498 .876 r
.33192 .46777 .33552 .47322 .34121 .47531 .33761 .46976 Mtetra
.329 .497 .873 r
.33761 .46976 .34121 .47531 .34693 .47742 .34334 .47176 Mtetra
.334 .496 .87 r
.34334 .47176 .34693 .47742 .35268 .47953 .34909 .47377 Mtetra
.339 .494 .867 r
.34909 .47377 .35268 .47953 .35845 .48165 .35487 .47579 Mtetra
.344 .492 .863 r
.35487 .47579 .35845 .48165 .36425 .48378 .36067 .47782 Mtetra
.348 .491 .86 r
.36067 .47782 .36425 .48378 .37008 .48593 .3665 .47987 Mtetra
.353 .49 .857 r
.3665 .47987 .37008 .48593 .37593 .48808 .37236 .48191 Mtetra
.357 .488 .854 r
.37236 .48191 .37593 .48808 .38181 .49024 .37825 .48397 Mtetra
.361 .486 .851 r
.37825 .48397 .38181 .49024 .38773 .49242 .38416 .48604 Mtetra
.365 .485 .848 r
.38416 .48604 .38773 .49242 .39366 .4946 .3901 .48812 Mtetra
.369 .484 .845 r
.3901 .48812 .39366 .4946 .39963 .4968 .39607 .49021 Mtetra
.372 .482 .842 r
.39607 .49021 .39963 .4968 .40563 .49901 .40207 .49231 Mtetra
.376 .48 .839 r
.40207 .49231 .40563 .49901 .41165 .50123 .4081 .49443 Mtetra
.38 .479 .836 r
.4081 .49443 .41165 .50123 .41771 .50345 .41415 .49655 Mtetra
.382 .477 .833 r
.41415 .49655 .41771 .50345 .42379 .5057 .42024 .49868 Mtetra
.385 .476 .83 r
.42024 .49868 .42379 .5057 .42991 .50796 .42635 .50083 Mtetra
.389 .475 .827 r
.42635 .50083 .42991 .50796 .43605 .51022 .4325 .50298 Mtetra
.392 .473 .824 r
.4325 .50298 .43605 .51022 .44222 .5125 .43867 .50515 Mtetra
.394 .471 .821 r
.43867 .50515 .44222 .5125 .44842 .5148 .44487 .50734 Mtetra
.397 .47 .818 r
.44487 .50734 .44842 .5148 .45466 .5171 .45111 .50953 Mtetra
.4 .469 .815 r
.45111 .50953 .45466 .5171 .46092 .51941 .45737 .51173 Mtetra
.402 .467 .812 r
.45737 .51173 .46092 .51941 .46722 .52175 .46366 .51395 Mtetra
.404 .465 .81 r
.46366 .51395 .46722 .52175 .47354 .5241 .46999 .51619 Mtetra
.408 .465 .807 r
.46999 .51619 .47354 .5241 .4799 .52645 .47634 .51842 Mtetra
.411 .464 .804 r
.47634 .51842 .4799 .52645 .48629 .52879 .48273 .52065 Mtetra
.417 .464 .802 r
.48273 .52065 .48629 .52879 .49271 .5311 .48915 .52284 Mtetra
.432 .471 .8 r
.48915 .52284 .49271 .5311 .49916 .53321 .4956 .52484 Mtetra
.461 .485 .797 r
.4956 .52484 .49916 .53321 .50565 .53489 .50209 .52642 Mtetra
.603 .563 .782 r
.50209 .52642 .50565 .53489 .51218 .5336 .50862 .52511 Mtetra
.728 .626 .744 r
.50862 .52511 .51218 .5336 .51874 .52793 .51518 .51951 Mtetra
.737 .632 .741 r
.51518 .51951 .51874 .52793 .5253 .52186 .52174 .51353 Mtetra
.744 .636 .741 r
.52174 .51353 .5253 .52186 .53185 .51555 .5283 .50731 Mtetra
.747 .639 .741 r
.5283 .50731 .53185 .51555 .53841 .50915 .53487 .501 Mtetra
.748 .642 .742 r
.53487 .501 .53841 .50915 .54496 .50274 .54143 .49469 Mtetra
.75 .644 .744 r
.54143 .49469 .54496 .50274 .55151 .49633 .54799 .48837 Mtetra
.751 .647 .745 r
.54799 .48837 .55151 .49633 .55806 .48991 .55454 .48204 Mtetra
.753 .649 .747 r
.55454 .48204 .55806 .48991 .56461 .4835 .5611 .47572 Mtetra
.754 .652 .748 r
.5611 .47572 .56461 .4835 .57116 .4771 .56765 .46941 Mtetra
.755 .655 .75 r
.56765 .46941 .57116 .4771 .57771 .4707 .57421 .4631 Mtetra
.757 .657 .751 r
.57421 .4631 .57771 .4707 .58425 .46429 .58076 .45679 Mtetra
.758 .66 .753 r
.58076 .45679 .58425 .46429 .59079 .4579 .58731 .45048 Mtetra
.76 .663 .755 r
.58731 .45048 .59079 .4579 .59733 .45151 .59386 .44418 Mtetra
.761 .665 .756 r
.59386 .44418 .59733 .45151 .60387 .44511 .60041 .43787 Mtetra
.763 .668 .758 r
.60041 .43787 .60387 .44511 .61041 .43872 .60696 .43157 Mtetra
.764 .671 .759 r
.60696 .43157 .61041 .43872 .61695 .43234 .61351 .42528 Mtetra
.766 .674 .761 r
.61351 .42528 .61695 .43234 .62348 .42596 .62006 .41898 Mtetra
.768 .677 .763 r
.62006 .41898 .62348 .42596 .63001 .41957 .6266 .41269 Mtetra
.769 .68 .765 r
.6266 .41269 .63001 .41957 .63655 .41319 .63314 .4064 Mtetra
.771 .683 .766 r
.63314 .4064 .63655 .41319 .64308 .40682 .63969 .40011 Mtetra
.772 .686 .768 r
.63969 .40011 .64308 .40682 .6496 .40044 .64623 .39382 Mtetra
.774 .689 .77 r
.64623 .39382 .6496 .40044 .65613 .39407 .65277 .38753 Mtetra
.775 .692 .771 r
.65277 .38753 .65613 .39407 .66266 .3877 .65931 .38125 Mtetra
.777 .695 .773 r
.65931 .38125 .66266 .3877 .66918 .38133 .66585 .37496 Mtetra
.779 .699 .775 r
.66585 .37496 .66918 .38133 .6757 .37496 .67238 .36868 Mtetra
.781 .702 .777 r
.67238 .36868 .6757 .37496 .68222 .36859 .67892 .3624 Mtetra
.782 .705 .779 r
.67892 .3624 .68222 .36859 .68874 .36223 .68545 .35611 Mtetra
.784 .709 .78 r
.68545 .35611 .68874 .36223 .69526 .35586 .69199 .34983 Mtetra
.786 .712 .782 r
.69199 .34983 .69526 .35586 .70178 .3495 .69852 .34355 Mtetra
.788 .715 .784 r
.69852 .34355 .70178 .3495 .70829 .34314 .70505 .33728 Mtetra
.789 .719 .786 r
.70505 .33728 .70829 .34314 .71481 .33677 .71158 .33099 Mtetra
.791 .723 .788 r
.71158 .33099 .71481 .33677 .72132 .33041 .71811 .32471 Mtetra
.793 .726 .79 r
.71811 .32471 .72132 .33041 .72783 .32406 .72464 .31844 Mtetra
.795 .73 .792 r
.72464 .31844 .72783 .32406 .73434 .3177 .73116 .31216 Mtetra
.797 .734 .794 r
.73116 .31216 .73434 .3177 .74084 .31133 .73769 .30588 Mtetra
.799 .738 .796 r
.73769 .30588 .74084 .31133 .74735 .30498 .74421 .2996 Mtetra
.801 .741 .798 r
.74421 .2996 .74735 .30498 .75385 .29862 .75073 .29333 Mtetra
.803 .745 .799 r
.75073 .29333 .75385 .29862 .76035 .29226 .75725 .28705 Mtetra
.804 .749 .802 r
.75725 .28705 .76035 .29226 .76686 .2859 .76377 .28077 Mtetra
.806 .753 .804 r
.76377 .28077 .76686 .2859 .77335 .27955 .77029 .27449 Mtetra
.808 .758 .806 r
.77029 .27449 .77335 .27955 .77985 .27319 .77681 .26821 Mtetra
.81 .762 .807 r
.77681 .26821 .77985 .27319 .78635 .26682 .78333 .26193 Mtetra
.812 .766 .81 r
.78333 .26193 .78635 .26682 .79284 .26047 .78984 .25565 Mtetra
.814 .77 .812 r
.78984 .25565 .79284 .26047 .79933 .25412 .79635 .24938 Mtetra
.816 .774 .814 r
.79635 .24938 .79933 .25412 .80582 .24777 .80287 .24311 Mtetra
.817 .779 .817 r
.80287 .24311 .80582 .24777 .81232 .24148 .80938 .23689 Mtetra
.815 .782 .822 r
.80938 .23689 .81232 .24148 .81882 .23531 .81591 .2308 Mtetra
.81 .785 .829 r
.81591 .2308 .81882 .23531 .82535 .22937 .82246 .22493 Mtetra
.801 .786 .839 r
.82246 .22493 .82535 .22937 .83191 .2238 .82904 .21942 Mtetra
.379 .633 .954 r
.21415 .42606 .21793 .42958 .22321 .4303 .21944 .42672 Mtetra
.264 .57 .938 r
.21944 .42672 .22321 .4303 .22845 .43171 .22469 .42804 Mtetra
.225 .543 .927 r
.22469 .42804 .22845 .43171 .2337 .43336 .22995 .4296 Mtetra
.212 .529 .921 r
.22995 .4296 .2337 .43336 .23895 .43513 .23521 .43128 Mtetra
.21 .522 .918 r
.23521 .43128 .23895 .43513 .24423 .43697 .2405 .43304 Mtetra
.216 .52 .916 r
.2405 .43304 .24423 .43697 .24952 .43884 .2458 .43481 Mtetra
.228 .521 .915 r
.2458 .43481 .24952 .43884 .25484 .44071 .25113 .43659 Mtetra
.236 .52 .913 r
.25113 .43659 .25484 .44071 .26019 .4426 .25648 .43838 Mtetra
.244 .519 .912 r
.25648 .43838 .26019 .4426 .26556 .44449 .26186 .44018 Mtetra
.254 .519 .91 r
.26186 .44018 .26556 .44449 .27095 .44639 .26726 .44198 Mtetra
.263 .518 .908 r
.26726 .44198 .27095 .44639 .27637 .44829 .27268 .44379 Mtetra
.27 .517 .905 r
.27268 .44379 .27637 .44829 .28181 .4502 .27813 .44561 Mtetra
.278 .516 .903 r
.27813 .44561 .28181 .4502 .28727 .45213 .28361 .44744 Mtetra
.286 .516 .901 r
.28361 .44744 .28727 .45213 .29276 .45405 .28911 .44926 Mtetra
.293 .514 .898 r
.28911 .44926 .29276 .45405 .29828 .45599 .29463 .4511 Mtetra
.299 .513 .895 r
.29463 .4511 .29828 .45599 .30382 .45793 .30018 .45295 Mtetra
.306 .512 .892 r
.30018 .45295 .30382 .45793 .30939 .45988 .30575 .4548 Mtetra
.313 .511 .889 r
.30575 .4548 .30939 .45988 .31498 .46184 .31135 .45666 Mtetra
.318 .509 .886 r
.31135 .45666 .31498 .46184 .3206 .46381 .31698 .45853 Mtetra
.324 .507 .883 r
.31698 .45853 .3206 .46381 .32625 .46578 .32263 .46041 Mtetra
.33 .506 .88 r
.32263 .46041 .32625 .46578 .33192 .46777 .3283 .46229 Mtetra
.335 .504 .877 r
.3283 .46229 .33192 .46777 .33761 .46976 .33401 .46418 Mtetra
.34 .503 .874 r
.33401 .46418 .33761 .46976 .34334 .47176 .33974 .46609 Mtetra
.345 .501 .87 r
.33974 .46609 .34334 .47176 .34909 .47377 .34549 .46799 Mtetra
.35 .5 .867 r
.34549 .46799 .34909 .47377 .35487 .47579 .35127 .46991 Mtetra
.354 .498 .864 r
.35127 .46991 .35487 .47579 .36067 .47782 .35708 .47184 Mtetra
.359 .497 .861 r
.35708 .47184 .36067 .47782 .3665 .47987 .36292 .47378 Mtetra
.363 .495 .858 r
.36292 .47378 .3665 .47987 .37236 .48191 .36878 .47572 Mtetra
.367 .493 .854 r
.36878 .47572 .37236 .48191 .37825 .48397 .37467 .47767 Mtetra
.371 .492 .851 r
.37467 .47767 .37825 .48397 .38416 .48604 .38059 .47964 Mtetra
.375 .49 .848 r
.38059 .47964 .38416 .48604 .3901 .48812 .38653 .48161 Mtetra
.378 .489 .845 r
.38653 .48161 .3901 .48812 .39607 .49021 .3925 .4836 Mtetra
.381 .487 .842 r
.3925 .4836 .39607 .49021 .40207 .49231 .39851 .48559 Mtetra
.385 .485 .839 r
.39851 .48559 .40207 .49231 .4081 .49443 .40453 .4876 Mtetra
.389 .484 .836 r
.40453 .4876 .4081 .49443 .41415 .49655 .41059 .48961 Mtetra
.391 .482 .833 r
.41059 .48961 .41415 .49655 .42024 .49868 .41668 .49163 Mtetra
.394 .48 .83 r
.41668 .49163 .42024 .49868 .42635 .50083 .42279 .49367 Mtetra
.397 .479 .827 r
.42279 .49367 .42635 .50083 .4325 .50298 .42894 .49572 Mtetra
.4 .477 .824 r
.42894 .49572 .4325 .50298 .43867 .50515 .43511 .49777 Mtetra
.402 .475 .821 r
.43511 .49777 .43867 .50515 .44487 .50734 .44132 .49985 Mtetra
.405 .474 .818 r
.44132 .49985 .44487 .50734 .45111 .50953 .44755 .50193 Mtetra
.408 .473 .815 r
.44755 .50193 .45111 .50953 .45737 .51173 .45381 .50401 Mtetra
.41 .471 .812 r
.45381 .50401 .45737 .51173 .46366 .51395 .4601 .50612 Mtetra
.412 .469 .81 r
.4601 .50612 .46366 .51395 .46999 .51619 .46643 .50824 Mtetra
.415 .468 .807 r
.46643 .50824 .46999 .51619 .47634 .51842 .47278 .51036 Mtetra
.419 .468 .804 r
.47278 .51036 .47634 .51842 .48273 .52065 .47917 .51247 Mtetra
.424 .468 .802 r
.47917 .51247 .48273 .52065 .48915 .52284 .48559 .51455 Mtetra
.439 .474 .799 r
.48559 .51455 .48915 .52284 .4956 .52484 .49204 .51644 Mtetra
.466 .488 .797 r
.49204 .51644 .4956 .52484 .50209 .52642 .49852 .51792 Mtetra
.603 .563 .781 r
.49852 .51792 .50209 .52642 .50862 .52511 .50505 .51658 Mtetra
.726 .624 .744 r
.50505 .51658 .50862 .52511 .51518 .51951 .51161 .51105 Mtetra
.735 .63 .742 r
.51161 .51105 .51518 .51951 .52174 .51353 .51818 .50516 Mtetra
.741 .635 .741 r
.51818 .50516 .52174 .51353 .5283 .50731 .52475 .49903 Mtetra
.744 .638 .742 r
.52475 .49903 .5283 .50731 .53487 .501 .53132 .49282 Mtetra
.746 .64 .743 r
.53132 .49282 .53487 .501 .54143 .49469 .53788 .4866 Mtetra
.747 .643 .745 r
.53788 .4866 .54143 .49469 .54799 .48837 .54445 .48037 Mtetra
.749 .645 .746 r
.54445 .48037 .54799 .48837 .55454 .48204 .55102 .47414 Mtetra
.75 .648 .748 r
.55102 .47414 .55454 .48204 .5611 .47572 .55758 .46791 Mtetra
.752 .651 .749 r
.55758 .46791 .5611 .47572 .56765 .46941 .56414 .46169 Mtetra
.753 .653 .751 r
.56414 .46169 .56765 .46941 .57421 .4631 .57071 .45547 Mtetra
.755 .656 .752 r
.57071 .45547 .57421 .4631 .58076 .45679 .57727 .44925 Mtetra
.756 .659 .754 r
.57727 .44925 .58076 .45679 .58731 .45048 .58383 .44303 Mtetra
.757 .661 .755 r
.58383 .44303 .58731 .45048 .59386 .44418 .59039 .43682 Mtetra
.759 .664 .757 r
.59039 .43682 .59386 .44418 .60041 .43787 .59695 .43061 Mtetra
.761 .667 .759 r
.59695 .43061 .60041 .43787 .60696 .43157 .60351 .4244 Mtetra
.762 .67 .76 r
.60351 .4244 .60696 .43157 .61351 .42528 .61006 .41819 Mtetra
.764 .673 .762 r
.61006 .41819 .61351 .42528 .62006 .41898 .61662 .41198 Mtetra
.765 .676 .764 r
.61662 .41198 .62006 .41898 .6266 .41269 .62318 .40577 Mtetra
.767 .679 .766 r
.62318 .40577 .6266 .41269 .63314 .4064 .62973 .39957 Mtetra
.768 .682 .767 r
.62973 .39957 .63314 .4064 .63969 .40011 .63629 .39337 Mtetra
.77 .685 .769 r
.63629 .39337 .63969 .40011 .64623 .39382 .64284 .38716 Mtetra
.772 .688 .771 r
.64284 .38716 .64623 .39382 .65277 .38753 .6494 .38096 Mtetra
.773 .691 .773 r
.6494 .38096 .65277 .38753 .65931 .38125 .65595 .37477 Mtetra
.775 .694 .774 r
.65595 .37477 .65931 .38125 .66585 .37496 .6625 .36857 Mtetra
.777 .697 .776 r
.6625 .36857 .66585 .37496 .67238 .36868 .66905 .36237 Mtetra
.778 .701 .778 r
.66905 .36237 .67238 .36868 .67892 .3624 .6756 .35617 Mtetra
.78 .704 .78 r
.6756 .35617 .67892 .3624 .68545 .35611 .68215 .34997 Mtetra
.782 .708 .782 r
.68215 .34997 .68545 .35611 .69199 .34983 .6887 .34378 Mtetra
.783 .711 .784 r
.6887 .34378 .69199 .34983 .69852 .34355 .69525 .33758 Mtetra
.785 .714 .785 r
.69525 .33758 .69852 .34355 .70505 .33728 .70179 .33139 Mtetra
.787 .718 .787 r
.70179 .33139 .70505 .33728 .71158 .33099 .70834 .32519 Mtetra
.789 .722 .789 r
.70834 .32519 .71158 .33099 .71811 .32471 .71489 .31899 Mtetra
.791 .725 .791 r
.71489 .31899 .71811 .32471 .72464 .31844 .72143 .3128 Mtetra
.793 .729 .793 r
.72143 .3128 .72464 .31844 .73116 .31216 .72797 .3066 Mtetra
.794 .733 .795 r
.72797 .3066 .73116 .31216 .73769 .30588 .73452 .3004 Mtetra
.796 .737 .797 r
.73452 .3004 .73769 .30588 .74421 .2996 .74106 .29421 Mtetra
.798 .741 .799 r
.74106 .29421 .74421 .2996 .75073 .29333 .7476 .28801 Mtetra
.8 .745 .801 r
.7476 .28801 .75073 .29333 .75725 .28705 .75414 .28181 Mtetra
.802 .749 .803 r
.75414 .28181 .75725 .28705 .76377 .28077 .76068 .27561 Mtetra
.804 .753 .805 r
.76068 .27561 .76377 .28077 .77029 .27449 .76722 .26942 Mtetra
.806 .757 .807 r
.76722 .26942 .77029 .27449 .77681 .26821 .77376 .26322 Mtetra
.808 .761 .809 r
.77376 .26322 .77681 .26821 .78333 .26193 .78029 .25701 Mtetra
.81 .765 .812 r
.78029 .25701 .78333 .26193 .78984 .25565 .78683 .25081 Mtetra
.812 .769 .814 r
.78683 .25081 .78984 .25565 .79635 .24938 .79336 .24462 Mtetra
.813 .774 .816 r
.79336 .24462 .79635 .24938 .80287 .24311 .7999 .23843 Mtetra
.814 .778 .819 r
.7999 .23843 .80287 .24311 .80938 .23689 .80644 .23229 Mtetra
.812 .781 .824 r
.80644 .23229 .80938 .23689 .81591 .2308 .81299 .22627 Mtetra
.808 .784 .831 r
.81299 .22627 .81591 .2308 .82246 .22493 .81956 .22046 Mtetra
.798 .785 .841 r
.81956 .22046 .82246 .22493 .82904 .21942 .82616 .21501 Mtetra
.389 .638 .955 r
.21035 .42252 .21415 .42606 .21944 .42672 .21566 .42311 Mtetra
.279 .578 .94 r
.21566 .42311 .21944 .42672 .22469 .42804 .22092 .42435 Mtetra
.242 .552 .931 r
.22092 .42435 .22469 .42804 .22995 .4296 .22618 .42583 Mtetra
.229 .539 .925 r
.22618 .42583 .22995 .4296 .23521 .43128 .23146 .42742 Mtetra
.227 .532 .922 r
.23146 .42742 .23521 .43128 .2405 .43304 .23675 .42908 Mtetra
.233 .53 .92 r
.23675 .42908 .2405 .43304 .2458 .43481 .24206 .43077 Mtetra
.244 .53 .918 r
.24206 .43077 .2458 .43481 .25113 .43659 .2474 .43245 Mtetra
.252 .529 .917 r
.2474 .43245 .25113 .43659 .25648 .43838 .25276 .43415 Mtetra
.26 .528 .914 r
.25276 .43415 .25648 .43838 .26186 .44018 .25815 .43586 Mtetra
.269 .527 .912 r
.25815 .43586 .26186 .44018 .26726 .44198 .26356 .43756 Mtetra
.278 .527 .91 r
.26356 .43756 .26726 .44198 .27268 .44379 .26899 .43928 Mtetra
.284 .525 .908 r
.26899 .43928 .27268 .44379 .27813 .44561 .27445 .441 Mtetra
.292 .524 .905 r
.27445 .441 .27813 .44561 .28361 .44744 .27993 .44273 Mtetra
.3 .523 .902 r
.27993 .44273 .28361 .44744 .28911 .44926 .28544 .44446 Mtetra
.306 .522 .9 r
.28544 .44446 .28911 .44926 .29463 .4511 .29097 .4462 Mtetra
.312 .52 .897 r
.29097 .4462 .29463 .4511 .30018 .45295 .29652 .44795 Mtetra
.319 .519 .894 r
.29652 .44795 .30018 .45295 .30575 .4548 .3021 .44971 Mtetra
.325 .517 .891 r
.3021 .44971 .30575 .4548 .31135 .45666 .30771 .45147 Mtetra
.33 .515 .887 r
.30771 .45147 .31135 .45666 .31698 .45853 .31334 .45324 Mtetra
.336 .514 .884 r
.31334 .45324 .31698 .45853 .32263 .46041 .319 .45501 Mtetra
.342 .513 .881 r
.319 .45501 .32263 .46041 .3283 .46229 .32468 .4568 Mtetra
.346 .511 .878 r
.32468 .4568 .3283 .46229 .33401 .46418 .33039 .45859 Mtetra
.351 .509 .875 r
.33039 .45859 .33401 .46418 .33974 .46609 .33612 .46039 Mtetra
.356 .507 .871 r
.33612 .46039 .33974 .46609 .34549 .46799 .34188 .4622 Mtetra
.361 .506 .868 r
.34188 .4622 .34549 .46799 .35127 .46991 .34767 .46401 Mtetra
.364 .504 .865 r
.34767 .46401 .35127 .46991 .35708 .47184 .35348 .46584 Mtetra
.369 .502 .862 r
.35348 .46584 .35708 .47184 .36292 .47378 .35932 .46767 Mtetra
.373 .501 .858 r
.35932 .46767 .36292 .47378 .36878 .47572 .36519 .46951 Mtetra
.376 .499 .855 r
.36519 .46951 .36878 .47572 .37467 .47767 .37108 .47136 Mtetra
.38 .497 .852 r
.37108 .47136 .37467 .47767 .38059 .47964 .377 .47322 Mtetra
.384 .495 .849 r
.377 .47322 .38059 .47964 .38653 .48161 .38295 .47509 Mtetra
.387 .494 .845 r
.38295 .47509 .38653 .48161 .3925 .4836 .38893 .47697 Mtetra
.39 .492 .842 r
.38893 .47697 .3925 .4836 .39851 .48559 .39493 .47885 Mtetra
.393 .49 .839 r
.39493 .47885 .39851 .48559 .40453 .4876 .40096 .48075 Mtetra
.397 .488 .836 r
.40096 .48075 .40453 .4876 .41059 .48961 .40702 .48266 Mtetra
.399 .487 .833 r
.40702 .48266 .41059 .48961 .41668 .49163 .41311 .48457 Mtetra
.402 .485 .83 r
.41311 .48457 .41668 .49163 .42279 .49367 .41923 .4865 Mtetra
.405 .483 .827 r
.41923 .4865 .42279 .49367 .42894 .49572 .42537 .48844 Mtetra
.408 .482 .824 r
.42537 .48844 .42894 .49572 .43511 .49777 .43155 .49038 Mtetra
.41 .48 .821 r
.43155 .49038 .43511 .49777 .44132 .49985 .43775 .49234 Mtetra
.412 .478 .818 r
.43775 .49234 .44132 .49985 .44755 .50193 .44398 .49431 Mtetra
.415 .477 .815 r
.44398 .49431 .44755 .50193 .45381 .50401 .45025 .49629 Mtetra
.417 .475 .813 r
.45025 .49629 .45381 .50401 .4601 .50612 .45654 .49828 Mtetra
.419 .473 .81 r
.45654 .49828 .4601 .50612 .46643 .50824 .46286 .50029 Mtetra
.422 .472 .807 r
.46286 .50029 .46643 .50824 .47278 .51036 .46922 .50229 Mtetra
.425 .471 .804 r
.46922 .50229 .47278 .51036 .47917 .51247 .4756 .50429 Mtetra
.43 .472 .802 r
.4756 .50429 .47917 .51247 .48559 .51455 .48201 .50625 Mtetra
.444 .477 .799 r
.48201 .50625 .48559 .51455 .49204 .51644 .48846 .50803 Mtetra
.471 .491 .797 r
.48846 .50803 .49204 .51644 .49852 .51792 .49494 .50941 Mtetra
.604 .563 .781 r
.49494 .50941 .49852 .51792 .50505 .51658 .50147 .50803 Mtetra
.725 .624 .745 r
.50147 .50803 .50505 .51658 .51161 .51105 .50804 .50259 Mtetra
.733 .629 .743 r
.50804 .50259 .51161 .51105 .51818 .50516 .51462 .49678 Mtetra
.739 .634 .742 r
.51462 .49678 .51818 .50516 .52475 .49903 .52119 .49075 Mtetra
.742 .637 .743 r
.52119 .49075 .52475 .49903 .53132 .49282 .52776 .48462 Mtetra
.744 .639 .744 r
.52776 .48462 .53132 .49282 .53788 .4866 .53434 .47849 Mtetra
.745 .642 .746 r
.53434 .47849 .53788 .4866 .54445 .48037 .54091 .47236 Mtetra
.747 .645 .747 r
.54091 .47236 .54445 .48037 .55102 .47414 .54748 .46622 Mtetra
.748 .647 .749 r
.54748 .46622 .55102 .47414 .55758 .46791 .55405 .46009 Mtetra
.75 .65 .75 r
.55405 .46009 .55758 .46791 .56414 .46169 .56062 .45396 Mtetra
.751 .652 .752 r
.56062 .45396 .56414 .46169 .57071 .45547 .56719 .44783 Mtetra
.753 .655 .753 r
.56719 .44783 .57071 .45547 .57727 .44925 .57376 .4417 Mtetra
.754 .658 .755 r
.57376 .4417 .57727 .44925 .58383 .44303 .58033 .43557 Mtetra
.755 .66 .757 r
.58033 .43557 .58383 .44303 .59039 .43682 .5869 .42945 Mtetra
.757 .663 .758 r
.5869 .42945 .59039 .43682 .59695 .43061 .59347 .42332 Mtetra
.758 .666 .76 r
.59347 .42332 .59695 .43061 .60351 .4244 .60004 .4172 Mtetra
.76 .669 .762 r
.60004 .4172 .60351 .4244 .61006 .41819 .60661 .41108 Mtetra
.762 .672 .763 r
.60661 .41108 .61006 .41819 .61662 .41198 .61318 .40496 Mtetra
.763 .675 .765 r
.61318 .40496 .61662 .41198 .62318 .40577 .61975 .39884 Mtetra
.765 .678 .767 r
.61975 .39884 .62318 .40577 .62973 .39957 .62631 .39273 Mtetra
.766 .681 .768 r
.62631 .39273 .62973 .39957 .63629 .39337 .63288 .38661 Mtetra
.768 .684 .77 r
.63288 .38661 .63629 .39337 .64284 .38716 .63945 .38049 Mtetra
.769 .687 .772 r
.63945 .38049 .64284 .38716 .6494 .38096 .64601 .37438 Mtetra
.771 .69 .774 r
.64601 .37438 .6494 .38096 .65595 .37477 .65258 .36827 Mtetra
.773 .693 .776 r
.65258 .36827 .65595 .37477 .6625 .36857 .65914 .36215 Mtetra
.774 .697 .777 r
.65914 .36215 .6625 .36857 .66905 .36237 .66571 .35604 Mtetra
.776 .7 .779 r
.66571 .35604 .66905 .36237 .6756 .35617 .67227 .34993 Mtetra
.778 .703 .781 r
.67227 .34993 .6756 .35617 .68215 .34997 .67884 .34381 Mtetra
.78 .707 .783 r
.67884 .34381 .68215 .34997 .6887 .34378 .6854 .3377 Mtetra
.781 .71 .785 r
.6854 .3377 .6887 .34378 .69525 .33758 .69197 .33159 Mtetra
.783 .714 .787 r
.69197 .33159 .69525 .33758 .70179 .33139 .69853 .32548 Mtetra
.785 .717 .789 r
.69853 .32548 .70179 .33139 .70834 .32519 .70509 .31936 Mtetra
.787 .721 .791 r
.70509 .31936 .70834 .32519 .71489 .31899 .71165 .31325 Mtetra
.788 .725 .793 r
.71165 .31325 .71489 .31899 .72143 .3128 .71822 .30714 Mtetra
.79 .728 .795 r
.71822 .30714 .72143 .3128 .72797 .3066 .72478 .30102 Mtetra
.792 .732 .797 r
.72478 .30102 .72797 .3066 .73452 .3004 .73134 .2949 Mtetra
.794 .736 .799 r
.73134 .2949 .73452 .3004 .74106 .29421 .7379 .28879 Mtetra
.796 .74 .801 r
.7379 .28879 .74106 .29421 .7476 .28801 .74446 .28268 Mtetra
.798 .744 .803 r
.74446 .28268 .7476 .28801 .75414 .28181 .75102 .27656 Mtetra
.8 .748 .805 r
.75102 .27656 .75414 .28181 .76068 .27561 .75758 .27044 Mtetra
.801 .752 .807 r
.75758 .27044 .76068 .27561 .76722 .26942 .76413 .26432 Mtetra
.803 .756 .809 r
.76413 .26432 .76722 .26942 .77376 .26322 .77069 .2582 Mtetra
.806 .76 .811 r
.77069 .2582 .77376 .26322 .78029 .25701 .77725 .25207 Mtetra
.807 .764 .813 r
.77725 .25207 .78029 .25701 .78683 .25081 .78381 .24596 Mtetra
.809 .769 .816 r
.78381 .24596 .78683 .25081 .79336 .24462 .79036 .23984 Mtetra
.811 .773 .818 r
.79036 .23984 .79336 .24462 .7999 .23843 .79692 .23373 Mtetra
.812 .777 .821 r
.79692 .23373 .7999 .23843 .80644 .23229 .80348 .22766 Mtetra
.81 .781 .826 r
.80348 .22766 .80644 .23229 .81299 .22627 .81005 .22171 Mtetra
.805 .784 .833 r
.81005 .22171 .81299 .22627 .81956 .22046 .81664 .21598 Mtetra
.796 .785 .842 r
.81664 .21598 .81956 .22046 .82616 .21501 .82327 .21059 Mtetra
.399 .643 .955 r
.20655 .41897 .21035 .42252 .21566 .42311 .21186 .4195 Mtetra
.294 .586 .943 r
.21186 .4195 .21566 .42311 .22092 .42435 .21713 .42066 Mtetra
.258 .561 .934 r
.21713 .42066 .22092 .42435 .22618 .42583 .2224 .42205 Mtetra
.246 .549 .929 r
.2224 .42205 .22618 .42583 .23146 .42742 .22769 .42355 Mtetra
.244 .542 .925 r
.22769 .42355 .23146 .42742 .23675 .42908 .23299 .42512 Mtetra
.25 .539 .923 r
.23299 .42512 .23675 .42908 .24206 .43077 .23831 .42671 Mtetra
.26 .539 .921 r
.23831 .42671 .24206 .43077 .2474 .43245 .24366 .4283 Mtetra
.268 .538 .919 r
.24366 .4283 .2474 .43245 .25276 .43415 .24903 .4299 Mtetra
.275 .536 .917 r
.24903 .4299 .25276 .43415 .25815 .43586 .25443 .43152 Mtetra
.284 .536 .915 r
.25443 .43152 .25815 .43586 .26356 .43756 .25984 .43313 Mtetra
.292 .535 .912 r
.25984 .43313 .26356 .43756 .26899 .43928 .26528 .43475 Mtetra
.298 .533 .91 r
.26528 .43475 .26899 .43928 .27445 .441 .27075 .43637 Mtetra
.305 .532 .907 r
.27075 .43637 .27445 .441 .27993 .44273 .27624 .43801 Mtetra
.313 .53 .904 r
.27624 .43801 .27993 .44273 .28544 .44446 .28175 .43964 Mtetra
.319 .529 .901 r
.28175 .43964 .28544 .44446 .29097 .4462 .28729 .44129 Mtetra
.325 .527 .898 r
.28729 .44129 .29097 .4462 .29652 .44795 .29285 .44294 Mtetra
.331 .526 .895 r
.29285 .44294 .29652 .44795 .3021 .44971 .29844 .4446 Mtetra
.337 .524 .892 r
.29844 .4446 .3021 .44971 .30771 .45147 .30406 .44626 Mtetra
.342 .522 .889 r
.30406 .44626 .30771 .45147 .31334 .45324 .30969 .44793 Mtetra
.347 .52 .885 r
.30969 .44793 .31334 .45324 .319 .45501 .31536 .44961 Mtetra
.353 .519 .882 r
.31536 .44961 .319 .45501 .32468 .4568 .32104 .45129 Mtetra
.357 .517 .879 r
.32104 .45129 .32468 .4568 .33039 .45859 .32676 .45298 Mtetra
.361 .515 .875 r
.32676 .45298 .33039 .45859 .33612 .46039 .3325 .45468 Mtetra
.366 .513 .872 r
.3325 .45468 .33612 .46039 .34188 .4622 .33826 .45639 Mtetra
.37 .511 .869 r
.33826 .45639 .34188 .4622 .34767 .46401 .34406 .4581 Mtetra
.374 .509 .866 r
.34406 .4581 .34767 .46401 .35348 .46584 .34987 .45983 Mtetra
.378 .508 .862 r
.34987 .45983 .35348 .46584 .35932 .46767 .35572 .46156 Mtetra
.382 .506 .859 r
.35572 .46156 .35932 .46767 .36519 .46951 .36159 .46329 Mtetra
.386 .504 .856 r
.36159 .46329 .36519 .46951 .37108 .47136 .36749 .46504 Mtetra
.389 .502 .852 r
.36749 .46504 .37108 .47136 .377 .47322 .37341 .46679 Mtetra
.393 .5 .849 r
.37341 .46679 .377 .47322 .38295 .47509 .37936 .46856 Mtetra
.396 .499 .846 r
.37936 .46856 .38295 .47509 .38893 .47697 .38534 .47033 Mtetra
.398 .497 .843 r
.38534 .47033 .38893 .47697 .39493 .47885 .39135 .47211 Mtetra
.402 .495 .84 r
.39135 .47211 .39493 .47885 .40096 .48075 .39738 .4739 Mtetra
.405 .493 .837 r
.39738 .4739 .40096 .48075 .40702 .48266 .40344 .47569 Mtetra
.407 .491 .834 r
.40344 .47569 .40702 .48266 .41311 .48457 .40953 .4775 Mtetra
.41 .489 .831 r
.40953 .4775 .41311 .48457 .41923 .4865 .41565 .47932 Mtetra
.413 .488 .828 r
.41565 .47932 .41923 .4865 .42537 .48844 .4218 .48115 Mtetra
.415 .486 .825 r
.4218 .48115 .42537 .48844 .43155 .49038 .42797 .48298 Mtetra
.417 .484 .822 r
.42797 .48298 .43155 .49038 .43775 .49234 .43418 .48483 Mtetra
.42 .483 .819 r
.43418 .48483 .43775 .49234 .44398 .49431 .44041 .48669 Mtetra
.422 .481 .816 r
.44041 .48669 .44398 .49431 .45025 .49629 .44667 .48855 Mtetra
.424 .479 .813 r
.44667 .48855 .45025 .49629 .45654 .49828 .45297 .49043 Mtetra
.426 .477 .81 r
.45297 .49043 .45654 .49828 .46286 .50029 .45929 .49233 Mtetra
.429 .477 .807 r
.45929 .49233 .46286 .50029 .46922 .50229 .46564 .49421 Mtetra
.432 .475 .805 r
.46564 .49421 .46922 .50229 .4756 .50429 .47202 .4961 Mtetra
.436 .476 .802 r
.47202 .4961 .4756 .50429 .48201 .50625 .47844 .49794 Mtetra
.45 .481 .8 r
.47844 .49794 .48201 .50625 .48846 .50803 .48488 .49962 Mtetra
.476 .494 .797 r
.48488 .49962 .48846 .50803 .49494 .50941 .49136 .50089 Mtetra
.605 .563 .781 r
.49136 .50089 .49494 .50941 .50147 .50803 .49789 .49949 Mtetra
.723 .623 .746 r
.49789 .49949 .50147 .50803 .50804 .50259 .50447 .49412 Mtetra
.732 .629 .744 r
.50447 .49412 .50804 .50259 .51462 .49678 .51104 .4884 Mtetra
.738 .633 .743 r
.51104 .4884 .51462 .49678 .52119 .49075 .51762 .48245 Mtetra
.741 .636 .744 r
.51762 .48245 .52119 .49075 .52776 .48462 .5242 .47642 Mtetra
.742 .639 .745 r
.5242 .47642 .52776 .48462 .53434 .47849 .53078 .47039 Mtetra
.744 .641 .747 r
.53078 .47039 .53434 .47849 .54091 .47236 .53736 .46435 Mtetra
.745 .644 .748 r
.53736 .46435 .54091 .47236 .54748 .46622 .54394 .4583 Mtetra
.746 .646 .75 r
.54394 .4583 .54748 .46622 .55405 .46009 .55052 .45225 Mtetra
.748 .649 .751 r
.55052 .45225 .55405 .46009 .56062 .45396 .5571 .44622 Mtetra
.749 .652 .753 r
.5571 .44622 .56062 .45396 .56719 .44783 .56368 .44018 Mtetra
.751 .654 .755 r
.56368 .44018 .56719 .44783 .57376 .4417 .57025 .43413 Mtetra
.752 .657 .756 r
.57025 .43413 .57376 .4417 .58033 .43557 .57683 .4281 Mtetra
.753 .66 .758 r
.57683 .4281 .58033 .43557 .5869 .42945 .58341 .42207 Mtetra
.755 .663 .759 r
.58341 .42207 .5869 .42945 .59347 .42332 .58999 .41603 Mtetra
.756 .665 .761 r
.58999 .41603 .59347 .42332 .60004 .4172 .59657 .41 Mtetra
.758 .668 .763 r
.59657 .41 .60004 .4172 .60661 .41108 .60315 .40397 Mtetra
.759 .671 .765 r
.60315 .40397 .60661 .41108 .61318 .40496 .60973 .39793 Mtetra
.761 .674 .766 r
.60973 .39793 .61318 .40496 .61975 .39884 .61631 .3919 Mtetra
.762 .677 .768 r
.61631 .3919 .61975 .39884 .62631 .39273 .62288 .38587 Mtetra
.764 .68 .77 r
.62288 .38587 .62631 .39273 .63288 .38661 .62946 .37984 Mtetra
.766 .683 .772 r
.62946 .37984 .63288 .38661 .63945 .38049 .63604 .37381 Mtetra
.767 .686 .773 r
.63604 .37381 .63945 .38049 .64601 .37438 .64262 .36778 Mtetra
.769 .69 .775 r
.64262 .36778 .64601 .37438 .65258 .36827 .6492 .36176 Mtetra
.771 .693 .777 r
.6492 .36176 .65258 .36827 .65914 .36215 .65578 .35573 Mtetra
.772 .696 .779 r
.65578 .35573 .65914 .36215 .66571 .35604 .66236 .3497 Mtetra
.774 .699 .781 r
.66236 .3497 .66571 .35604 .67227 .34993 .66894 .34367 Mtetra
.776 .703 .783 r
.66894 .34367 .67227 .34993 .67884 .34381 .67552 .33764 Mtetra
.777 .706 .785 r
.67552 .33764 .67884 .34381 .6854 .3377 .68209 .33161 Mtetra
.779 .71 .787 r
.68209 .33161 .6854 .3377 .69197 .33159 .68867 .32558 Mtetra
.781 .713 .789 r
.68867 .32558 .69197 .33159 .69853 .32548 .69525 .31955 Mtetra
.783 .717 .79 r
.69525 .31955 .69853 .32548 .70509 .31936 .70183 .31352 Mtetra
.784 .72 .792 r
.70183 .31352 .70509 .31936 .71165 .31325 .70841 .30749 Mtetra
.786 .724 .794 r
.70841 .30749 .71165 .31325 .71822 .30714 .71499 .30146 Mtetra
.788 .728 .796 r
.71499 .30146 .71822 .30714 .72478 .30102 .72157 .29543 Mtetra
.79 .732 .798 r
.72157 .29543 .72478 .30102 .73134 .2949 .72815 .28939 Mtetra
.792 .735 .8 r
.72815 .28939 .73134 .2949 .7379 .28879 .73472 .28336 Mtetra
.793 .739 .803 r
.73472 .28336 .7379 .28879 .74446 .28268 .7413 .27732 Mtetra
.795 .743 .805 r
.7413 .27732 .74446 .28268 .75102 .27656 .74788 .27128 Mtetra
.797 .747 .807 r
.74788 .27128 .75102 .27656 .75758 .27044 .75446 .26524 Mtetra
.799 .751 .809 r
.75446 .26524 .75758 .27044 .76413 .26432 .76104 .25921 Mtetra
.801 .755 .811 r
.76104 .25921 .76413 .26432 .77069 .2582 .76761 .25316 Mtetra
.803 .76 .813 r
.76761 .25316 .77069 .2582 .77725 .25207 .77419 .24712 Mtetra
.805 .764 .815 r
.77419 .24712 .77725 .25207 .78381 .24596 .78077 .24108 Mtetra
.807 .768 .817 r
.78077 .24108 .78381 .24596 .79036 .23984 .78735 .23504 Mtetra
.808 .773 .82 r
.78735 .23504 .79036 .23984 .79692 .23373 .79393 .22901 Mtetra
.809 .777 .823 r
.79393 .22901 .79692 .23373 .80348 .22766 .80051 .22302 Mtetra
.807 .78 .828 r
.80051 .22302 .80348 .22766 .81005 .22171 .8071 .21714 Mtetra
.803 .783 .834 r
.8071 .21714 .81005 .22171 .81664 .21598 .81371 .21148 Mtetra
.794 .784 .844 r
.81371 .21148 .81664 .21598 .82327 .21059 .82036 .20614 Mtetra
.409 .647 .955 r
.20272 .41541 .20655 .41897 .21186 .4195 .20805 .41587 Mtetra
.308 .593 .945 r
.20805 .41587 .21186 .4195 .21713 .42066 .21333 .41695 Mtetra
.274 .57 .937 r
.21333 .41695 .21713 .42066 .2224 .42205 .21861 .41825 Mtetra
.263 .558 .932 r
.21861 .41825 .2224 .42205 .22769 .42355 .2239 .41966 Mtetra
.26 .551 .928 r
.2239 .41966 .22769 .42355 .23299 .42512 .22922 .42114 Mtetra
.266 .548 .926 r
.22922 .42114 .23299 .42512 .23831 .42671 .23455 .42264 Mtetra
.276 .548 .924 r
.23455 .42264 .23831 .42671 .24366 .4283 .23991 .42414 Mtetra
.283 .546 .922 r
.23991 .42414 .24366 .4283 .24903 .4299 .24529 .42564 Mtetra
.29 .545 .919 r
.24529 .42564 .24903 .4299 .25443 .43152 .25069 .42716 Mtetra
.298 .544 .917 r
.25069 .42716 .25443 .43152 .25984 .43313 .25612 .42868 Mtetra
.306 .542 .914 r
.25612 .42868 .25984 .43313 .26528 .43475 .26157 .4302 Mtetra
.312 .54 .911 r
.26157 .4302 .26528 .43475 .27075 .43637 .26704 .43173 Mtetra
.319 .539 .908 r
.26704 .43173 .27075 .43637 .27624 .43801 .27254 .43327 Mtetra
.326 .538 .906 r
.27254 .43327 .27624 .43801 .28175 .43964 .27806 .43481 Mtetra
.332 .536 .902 r
.27806 .43481 .28175 .43964 .28729 .44129 .2836 .43636 Mtetra
.337 .534 .899 r
.2836 .43636 .28729 .44129 .29285 .44294 .28918 .43791 Mtetra
.343 .532 .896 r
.28918 .43791 .29285 .44294 .29844 .4446 .29477 .43947 Mtetra
.349 .53 .893 r
.29477 .43947 .29844 .4446 .30406 .44626 .30039 .44103 Mtetra
.353 .528 .889 r
.30039 .44103 .30406 .44626 .30969 .44793 .30603 .44261 Mtetra
.358 .526 .886 r
.30603 .44261 .30969 .44793 .31536 .44961 .3117 .44419 Mtetra
.364 .525 .883 r
.3117 .44419 .31536 .44961 .32104 .45129 .3174 .44577 Mtetra
.368 .523 .879 r
.3174 .44577 .32104 .45129 .32676 .45298 .32312 .44736 Mtetra
.372 .521 .876 r
.32312 .44736 .32676 .45298 .3325 .45468 .32886 .44896 Mtetra
.376 .519 .873 r
.32886 .44896 .3325 .45468 .33826 .45639 .33463 .45056 Mtetra
.381 .517 .869 r
.33463 .45056 .33826 .45639 .34406 .4581 .34043 .45217 Mtetra
.384 .515 .866 r
.34043 .45217 .34406 .4581 .34987 .45983 .34625 .45379 Mtetra
.388 .513 .863 r
.34625 .45379 .34987 .45983 .35572 .46156 .3521 .45542 Mtetra
.392 .511 .859 r
.3521 .45542 .35572 .46156 .36159 .46329 .35798 .45705 Mtetra
.395 .509 .856 r
.35798 .45705 .36159 .46329 .36749 .46504 .36388 .4587 Mtetra
.398 .507 .853 r
.36388 .4587 .36749 .46504 .37341 .46679 .36981 .46035 Mtetra
.401 .505 .849 r
.36981 .46035 .37341 .46679 .37936 .46856 .37576 .462 Mtetra
.404 .503 .846 r
.37576 .462 .37936 .46856 .38534 .47033 .38175 .46367 Mtetra
.407 .501 .843 r
.38175 .46367 .38534 .47033 .39135 .47211 .38776 .46534 Mtetra
.41 .499 .84 r
.38776 .46534 .39135 .47211 .39738 .4739 .39379 .46702 Mtetra
.413 .498 .837 r
.39379 .46702 .39738 .4739 .40344 .47569 .39986 .46871 Mtetra
.415 .496 .834 r
.39986 .46871 .40344 .47569 .40953 .4775 .40595 .47041 Mtetra
.417 .494 .831 r
.40595 .47041 .40953 .4775 .41565 .47932 .41207 .47212 Mtetra
.42 .492 .828 r
.41207 .47212 .41565 .47932 .4218 .48115 .41822 .47384 Mtetra
.423 .49 .825 r
.41822 .47384 .4218 .48115 .42797 .48298 .42439 .47556 Mtetra
.424 .488 .822 r
.42439 .47556 .42797 .48298 .43418 .48483 .4306 .4773 Mtetra
.427 .487 .819 r
.4306 .4773 .43418 .48483 .44041 .48669 .43683 .47905 Mtetra
.429 .485 .816 r
.43683 .47905 .44041 .48669 .44667 .48855 .4431 .4808 Mtetra
.431 .483 .813 r
.4431 .4808 .44667 .48855 .45297 .49043 .44939 .48257 Mtetra
.432 .481 .81 r
.44939 .48257 .45297 .49043 .45929 .49233 .45571 .48434 Mtetra
.435 .48 .807 r
.45571 .48434 .45929 .49233 .46564 .49421 .46206 .48612 Mtetra
.438 .479 .805 r
.46206 .48612 .46564 .49421 .47202 .4961 .46844 .48789 Mtetra
.443 .479 .802 r
.46844 .48789 .47202 .4961 .47844 .49794 .47485 .48962 Mtetra
.456 .484 .8 r
.47485 .48962 .47844 .49794 .48488 .49962 .4813 .49118 Mtetra
.481 .496 .797 r
.4813 .49118 .48488 .49962 .49136 .50089 .48778 .49236 Mtetra
.605 .564 .781 r
.48778 .49236 .49136 .50089 .49789 .49949 .49431 .49093 Mtetra
.721 .622 .747 r
.49431 .49093 .49789 .49949 .50447 .49412 .50088 .48564 Mtetra
.73 .628 .745 r
.50088 .48564 .50447 .49412 .51104 .4884 .50747 .48 Mtetra
.735 .632 .744 r
.50747 .48 .51104 .4884 .51762 .48245 .51405 .47414 Mtetra
.738 .635 .745 r
.51405 .47414 .51762 .48245 .5242 .47642 .52063 .46821 Mtetra
.74 .638 .746 r
.52063 .46821 .5242 .47642 .53078 .47039 .52722 .46226 Mtetra
.741 .64 .748 r
.52722 .46226 .53078 .47039 .53736 .46435 .5338 .45631 Mtetra
.743 .643 .749 r
.5338 .45631 .53736 .46435 .54394 .4583 .54039 .45035 Mtetra
.744 .645 .751 r
.54039 .45035 .54394 .4583 .55052 .45225 .54698 .4444 Mtetra
.746 .648 .752 r
.54698 .4444 .55052 .45225 .5571 .44622 .55356 .43845 Mtetra
.747 .651 .754 r
.55356 .43845 .5571 .44622 .56368 .44018 .56015 .4325 Mtetra
.749 .653 .756 r
.56015 .4325 .56368 .44018 .57025 .43413 .56674 .42655 Mtetra
.75 .656 .757 r
.56674 .42655 .57025 .43413 .57683 .4281 .57332 .42061 Mtetra
.751 .659 .759 r
.57332 .42061 .57683 .4281 .58341 .42207 .57991 .41466 Mtetra
.753 .662 .761 r
.57991 .41466 .58341 .42207 .58999 .41603 .5865 .40871 Mtetra
.754 .664 .762 r
.5865 .40871 .58999 .41603 .59657 .41 .59309 .40277 Mtetra
.756 .667 .764 r
.59309 .40277 .59657 .41 .60315 .40397 .59968 .39683 Mtetra
.757 .67 .766 r
.59968 .39683 .60315 .40397 .60973 .39793 .60627 .39088 Mtetra
.759 .673 .767 r
.60627 .39088 .60973 .39793 .61631 .3919 .61286 .38494 Mtetra
.76 .676 .769 r
.61286 .38494 .61631 .3919 .62288 .38587 .61945 .379 Mtetra
.762 .679 .771 r
.61945 .379 .62288 .38587 .62946 .37984 .62604 .37305 Mtetra
.763 .682 .773 r
.62604 .37305 .62946 .37984 .63604 .37381 .63263 .36711 Mtetra
.765 .685 .775 r
.63263 .36711 .63604 .37381 .64262 .36778 .63922 .36116 Mtetra
.767 .689 .777 r
.63922 .36116 .64262 .36778 .6492 .36176 .64581 .35522 Mtetra
.768 .692 .778 r
.64581 .35522 .6492 .36176 .65578 .35573 .6524 .34928 Mtetra
.77 .695 .78 r
.6524 .34928 .65578 .35573 .66236 .3497 .659 .34333 Mtetra
.772 .698 .782 r
.659 .34333 .66236 .3497 .66894 .34367 .66559 .33739 Mtetra
.773 .702 .784 r
.66559 .33739 .66894 .34367 .67552 .33764 .67218 .33145 Mtetra
.775 .705 .786 r
.67218 .33145 .67552 .33764 .68209 .33161 .67878 .3255 Mtetra
.777 .709 .788 r
.67878 .3255 .68209 .33161 .68867 .32558 .68537 .31955 Mtetra
.778 .712 .79 r
.68537 .31955 .68867 .32558 .69525 .31955 .69197 .31361 Mtetra
.78 .716 .792 r
.69197 .31361 .69525 .31955 .70183 .31352 .69856 .30766 Mtetra
.782 .719 .794 r
.69856 .30766 .70183 .31352 .70841 .30749 .70515 .30171 Mtetra
.784 .723 .796 r
.70515 .30171 .70841 .30749 .71499 .30146 .71175 .29576 Mtetra
.785 .727 .798 r
.71175 .29576 .71499 .30146 .72157 .29543 .71835 .28981 Mtetra
.787 .731 .8 r
.71835 .28981 .72157 .29543 .72815 .28939 .72494 .28385 Mtetra
.789 .735 .802 r
.72494 .28385 .72815 .28939 .73472 .28336 .73154 .2779 Mtetra
.791 .738 .804 r
.73154 .2779 .73472 .28336 .7413 .27732 .73814 .27195 Mtetra
.793 .742 .806 r
.73814 .27195 .7413 .27732 .74788 .27128 .74473 .26599 Mtetra
.795 .746 .808 r
.74473 .26599 .74788 .27128 .75446 .26524 .75133 .26003 Mtetra
.797 .751 .811 r
.75133 .26003 .75446 .26524 .76104 .25921 .75793 .25407 Mtetra
.799 .755 .813 r
.75793 .25407 .76104 .25921 .76761 .25316 .76453 .24811 Mtetra
.801 .759 .815 r
.76453 .24811 .76761 .25316 .77419 .24712 .77112 .24214 Mtetra
.802 .763 .817 r
.77112 .24214 .77419 .24712 .78077 .24108 .77772 .23618 Mtetra
.804 .767 .819 r
.77772 .23618 .78077 .24108 .78735 .23504 .78432 .23022 Mtetra
.806 .772 .822 r
.78432 .23022 .78735 .23504 .79393 .22901 .79092 .22427 Mtetra
.806 .776 .825 r
.79092 .22427 .79393 .22901 .80051 .22302 .79752 .21835 Mtetra
.805 .78 .829 r
.79752 .21835 .80051 .22302 .8071 .21714 .80414 .21255 Mtetra
.8 .782 .836 r
.80414 .21255 .8071 .21714 .81371 .21148 .81077 .20695 Mtetra
.791 .784 .846 r
.81077 .20695 .81371 .21148 .82036 .20614 .81744 .20168 Mtetra
.418 .652 .955 r
.19889 .41183 .20272 .41541 .20805 .41587 .20422 .41223 Mtetra
.322 .6 .947 r
.20422 .41223 .20805 .41587 .21333 .41695 .20951 .41322 Mtetra
.29 .578 .939 r
.20951 .41322 .21333 .41695 .21861 .41825 .2148 .41444 Mtetra
.279 .567 .935 r
.2148 .41444 .21861 .41825 .2239 .41966 .22011 .41576 Mtetra
.277 .56 .931 r
.22011 .41576 .2239 .41966 .22922 .42114 .22543 .41714 Mtetra
.282 .557 .929 r
.22543 .41714 .22922 .42114 .23455 .42264 .23077 .41855 Mtetra
.291 .556 .926 r
.23077 .41855 .23455 .42264 .23991 .42414 .23614 .41995 Mtetra
.298 .555 .924 r
.23614 .41995 .23991 .42414 .24529 .42564 .24153 .42136 Mtetra
.305 .552 .921 r
.24153 .42136 .24529 .42564 .25069 .42716 .24694 .42279 Mtetra
.313 .551 .919 r
.24694 .42279 .25069 .42716 .25612 .42868 .25237 .42421 Mtetra
.32 .55 .916 r
.25237 .42421 .25612 .42868 .26157 .4302 .25783 .42564 Mtetra
.326 .548 .913 r
.25783 .42564 .26157 .4302 .26704 .43173 .26332 .42708 Mtetra
.332 .546 .91 r
.26332 .42708 .26704 .43173 .27254 .43327 .26882 .42852 Mtetra
.339 .544 .907 r
.26882 .42852 .27254 .43327 .27806 .43481 .27435 .42996 Mtetra
.344 .542 .903 r
.27435 .42996 .27806 .43481 .2836 .43636 .27991 .43141 Mtetra
.349 .54 .9 r
.27991 .43141 .2836 .43636 .28918 .43791 .28548 .43287 Mtetra
.355 .539 .897 r
.28548 .43287 .28918 .43791 .29477 .43947 .29109 .43433 Mtetra
.36 .537 .894 r
.29109 .43433 .29477 .43947 .30039 .44103 .29671 .43579 Mtetra
.365 .534 .89 r
.29671 .43579 .30039 .44103 .30603 .44261 .30236 .43726 Mtetra
.369 .532 .887 r
.30236 .43726 .30603 .44261 .3117 .44419 .30804 .43874 Mtetra
.374 .53 .883 r
.30804 .43874 .3117 .44419 .3174 .44577 .31374 .44023 Mtetra
.378 .528 .88 r
.31374 .44023 .3174 .44577 .32312 .44736 .31947 .44172 Mtetra
.382 .526 .876 r
.31947 .44172 .32312 .44736 .32886 .44896 .32522 .44322 Mtetra
.386 .524 .873 r
.32522 .44322 .32886 .44896 .33463 .45056 .331 .44472 Mtetra
.39 .522 .87 r
.331 .44472 .33463 .45056 .34043 .45217 .3368 .44623 Mtetra
.394 .52 .866 r
.3368 .44623 .34043 .45217 .34625 .45379 .34263 .44774 Mtetra
.397 .518 .863 r
.34263 .44774 .34625 .45379 .3521 .45542 .34848 .44927 Mtetra
.401 .516 .86 r
.34848 .44927 .3521 .45542 .35798 .45705 .35436 .4508 Mtetra
.404 .514 .856 r
.35436 .4508 .35798 .45705 .36388 .4587 .36027 .45233 Mtetra
.407 .512 .853 r
.36027 .45233 .36388 .4587 .36981 .46035 .3662 .45388 Mtetra
.41 .51 .85 r
.3662 .45388 .36981 .46035 .37576 .462 .37216 .45543 Mtetra
.413 .508 .846 r
.37216 .45543 .37576 .462 .38175 .46367 .37814 .45699 Mtetra
.415 .506 .843 r
.37814 .45699 .38175 .46367 .38776 .46534 .38416 .45856 Mtetra
.418 .504 .84 r
.38416 .45856 .38776 .46534 .39379 .46702 .39019 .46013 Mtetra
.421 .502 .837 r
.39019 .46013 .39379 .46702 .39986 .46871 .39626 .46171 Mtetra
.423 .5 .834 r
.39626 .46171 .39986 .46871 .40595 .47041 .40236 .4633 Mtetra
.425 .498 .831 r
.40236 .4633 .40595 .47041 .41207 .47212 .40848 .46491 Mtetra
.428 .496 .828 r
.40848 .46491 .41207 .47212 .41822 .47384 .41463 .46651 Mtetra
.43 .494 .825 r
.41463 .46651 .41822 .47384 .42439 .47556 .42081 .46813 Mtetra
.432 .492 .822 r
.42081 .46813 .42439 .47556 .4306 .4773 .42701 .46975 Mtetra
.434 .491 .819 r
.42701 .46975 .4306 .4773 .43683 .47905 .43325 .47139 Mtetra
.436 .489 .816 r
.43325 .47139 .43683 .47905 .4431 .4808 .43951 .47302 Mtetra
.438 .487 .813 r
.43951 .47302 .4431 .4808 .44939 .48257 .4458 .47468 Mtetra
.439 .485 .81 r
.4458 .47468 .44939 .48257 .45571 .48434 .45212 .47635 Mtetra
.442 .484 .807 r
.45212 .47635 .45571 .48434 .46206 .48612 .45847 .478 Mtetra
.445 .483 .805 r
.45847 .478 .46206 .48612 .46844 .48789 .46485 .47966 Mtetra
.449 .483 .802 r
.46485 .47966 .46844 .48789 .47485 .48962 .47127 .48128 Mtetra
.462 .488 .799 r
.47127 .48128 .47485 .48962 .4813 .49118 .47771 .48273 Mtetra
.485 .499 .796 r
.47771 .48273 .4813 .49118 .48778 .49236 .48418 .48381 Mtetra
.606 .564 .781 r
.48418 .48381 .48778 .49236 .49431 .49093 .49072 .48235 Mtetra
.719 .621 .747 r
.49072 .48235 .49431 .49093 .50088 .48564 .4973 .47713 Mtetra
.728 .627 .746 r
.4973 .47713 .50088 .48564 .50747 .48 .50388 .47158 Mtetra
.733 .631 .745 r
.50388 .47158 .50747 .48 .51405 .47414 .51047 .46581 Mtetra
.736 .634 .746 r
.51047 .46581 .51405 .47414 .52063 .46821 .51706 .45997 Mtetra
.738 .637 .747 r
.51706 .45997 .52063 .46821 .52722 .46226 .52365 .45411 Mtetra
.739 .639 .749 r
.52365 .45411 .52722 .46226 .5338 .45631 .53024 .44826 Mtetra
.741 .642 .75 r
.53024 .44826 .5338 .45631 .54039 .45035 .53683 .44239 Mtetra
.742 .644 .752 r
.53683 .44239 .54039 .45035 .54698 .4444 .54343 .43653 Mtetra
.743 .647 .753 r
.54343 .43653 .54698 .4444 .55356 .43845 .55002 .43067 Mtetra
.745 .65 .755 r
.55002 .43067 .55356 .43845 .56015 .4325 .55662 .42481 Mtetra
.746 .652 .757 r
.55662 .42481 .56015 .4325 .56674 .42655 .56321 .41895 Mtetra
.748 .655 .758 r
.56321 .41895 .56674 .42655 .57332 .42061 .56981 .4131 Mtetra
.749 .658 .76 r
.56981 .4131 .57332 .42061 .57991 .41466 .5764 .40724 Mtetra
.751 .661 .762 r
.5764 .40724 .57991 .41466 .5865 .40871 .583 .40138 Mtetra
.752 .663 .763 r
.583 .40138 .5865 .40871 .59309 .40277 .5896 .39552 Mtetra
.753 .666 .765 r
.5896 .39552 .59309 .40277 .59968 .39683 .5962 .38967 Mtetra
.755 .669 .767 r
.5962 .38967 .59968 .39683 .60627 .39088 .6028 .38381 Mtetra
.757 .672 .769 r
.6028 .38381 .60627 .39088 .61286 .38494 .6094 .37795 Mtetra
.758 .675 .77 r
.6094 .37795 .61286 .38494 .61945 .379 .616 .3721 Mtetra
.76 .678 .772 r
.616 .3721 .61945 .379 .62604 .37305 .6226 .36624 Mtetra
.761 .681 .774 r
.6226 .36624 .62604 .37305 .63263 .36711 .6292 .36038 Mtetra
.763 .684 .776 r
.6292 .36038 .63263 .36711 .63922 .36116 .63581 .35452 Mtetra
.764 .688 .778 r
.63581 .35452 .63922 .36116 .64581 .35522 .64241 .34867 Mtetra
.766 .691 .78 r
.64241 .34867 .64581 .35522 .6524 .34928 .64902 .34281 Mtetra
.768 .694 .782 r
.64902 .34281 .6524 .34928 .659 .34333 .65562 .33695 Mtetra
.769 .698 .784 r
.65562 .33695 .659 .34333 .66559 .33739 .66223 .33109 Mtetra
.771 .701 .785 r
.66223 .33109 .66559 .33739 .67218 .33145 .66884 .32523 Mtetra
.773 .704 .787 r
.66884 .32523 .67218 .33145 .67878 .3255 .67545 .31936 Mtetra
.774 .708 .789 r
.67545 .31936 .67878 .3255 .68537 .31955 .68206 .3135 Mtetra
.776 .711 .791 r
.68206 .3135 .68537 .31955 .69197 .31361 .68867 .30764 Mtetra
.778 .715 .793 r
.68867 .30764 .69197 .31361 .69856 .30766 .69528 .30177 Mtetra
.78 .719 .795 r
.69528 .30177 .69856 .30766 .70515 .30171 .70189 .2959 Mtetra
.781 .722 .797 r
.70189 .2959 .70515 .30171 .71175 .29576 .7085 .29004 Mtetra
.783 .726 .8 r
.7085 .29004 .71175 .29576 .71835 .28981 .71511 .28417 Mtetra
.785 .73 .802 r
.71511 .28417 .71835 .28981 .72494 .28385 .72173 .2783 Mtetra
.787 .734 .804 r
.72173 .2783 .72494 .28385 .73154 .2779 .72834 .27242 Mtetra
.788 .738 .806 r
.72834 .27242 .73154 .2779 .73814 .27195 .73496 .26655 Mtetra
.79 .742 .808 r
.73496 .26655 .73814 .27195 .74473 .26599 .74157 .26067 Mtetra
.792 .746 .81 r
.74157 .26067 .74473 .26599 .75133 .26003 .74819 .25479 Mtetra
.794 .75 .812 r
.74819 .25479 .75133 .26003 .75793 .25407 .75481 .24892 Mtetra
.796 .754 .814 r
.75481 .24892 .75793 .25407 .76453 .24811 .76142 .24303 Mtetra
.798 .758 .816 r
.76142 .24303 .76453 .24811 .77112 .24214 .76804 .23715 Mtetra
.8 .762 .819 r
.76804 .23715 .77112 .24214 .77772 .23618 .77466 .23126 Mtetra
.801 .767 .821 r
.77466 .23126 .77772 .23618 .78432 .23022 .78128 .22538 Mtetra
.803 .771 .823 r
.78128 .22538 .78432 .23022 .79092 .22427 .7879 .2195 Mtetra
.804 .775 .827 r
.7879 .2195 .79092 .22427 .79752 .21835 .79453 .21367 Mtetra
.802 .779 .831 r
.79453 .21367 .79752 .21835 .80414 .21255 .80116 .20794 Mtetra
.798 .782 .838 r
.80116 .20794 .80414 .21255 .81077 .20695 .80782 .20241 Mtetra
.789 .783 .847 r
.80782 .20241 .81077 .20695 .81744 .20168 .81451 .1972 Mtetra
.427 .656 .955 r
.19503 .40824 .19889 .41183 .20422 .41223 .20037 .40857 Mtetra
.336 .608 .948 r
.20037 .40857 .20422 .41223 .20951 .41322 .20568 .40948 Mtetra
.305 .586 .942 r
.20568 .40948 .20951 .41322 .2148 .41444 .21098 .41061 Mtetra
.294 .575 .937 r
.21098 .41061 .2148 .41444 .22011 .41576 .21629 .41184 Mtetra
.292 .568 .934 r
.21629 .41184 .22011 .41576 .22543 .41714 .22163 .41313 Mtetra
.297 .565 .931 r
.22163 .41313 .22543 .41714 .23077 .41855 .22698 .41444 Mtetra
.306 .564 .929 r
.22698 .41444 .23077 .41855 .23614 .41995 .23236 .41575 Mtetra
.313 .562 .926 r
.23236 .41575 .23614 .41995 .24153 .42136 .23775 .41707 Mtetra
.319 .56 .923 r
.23775 .41707 .24153 .42136 .24694 .42279 .24318 .4184 Mtetra
.326 .559 .92 r
.24318 .4184 .24694 .42279 .25237 .42421 .24862 .41973 Mtetra
.333 .557 .917 r
.24862 .41973 .25237 .42421 .25783 .42564 .25409 .42106 Mtetra
.339 .555 .914 r
.25409 .42106 .25783 .42564 .26332 .42708 .25958 .4224 Mtetra
.345 .553 .911 r
.25958 .4224 .26332 .42708 .26882 .42852 .26509 .42375 Mtetra
.351 .551 .908 r
.26509 .42375 .26882 .42852 .27435 .42996 .27063 .42509 Mtetra
.356 .549 .904 r
.27063 .42509 .27435 .42996 .27991 .43141 .27619 .42645 Mtetra
.361 .547 .901 r
.27619 .42645 .27991 .43141 .28548 .43287 .28178 .42781 Mtetra
.367 .545 .898 r
.28178 .42781 .28548 .43287 .29109 .43433 .28739 .42917 Mtetra
.372 .543 .894 r
.28739 .42917 .29109 .43433 .29671 .43579 .29302 .43053 Mtetra
.376 .54 .891 r
.29302 .43053 .29671 .43579 .30236 .43726 .29868 .43191 Mtetra
.38 .538 .887 r
.29868 .43191 .30236 .43726 .30804 .43874 .30437 .43329 Mtetra
.385 .536 .884 r
.30437 .43329 .30804 .43874 .31374 .44023 .31007 .43467 Mtetra
.388 .534 .88 r
.31007 .43467 .31374 .44023 .31947 .44172 .31581 .43606 Mtetra
.392 .532 .877 r
.31581 .43606 .31947 .44172 .32522 .44322 .32156 .43746 Mtetra
.396 .53 .873 r
.32156 .43746 .32522 .44322 .331 .44472 .32735 .43886 Mtetra
.4 .527 .87 r
.32735 .43886 .331 .44472 .3368 .44623 .33315 .44026 Mtetra
.403 .525 .867 r
.33315 .44026 .3368 .44623 .34263 .44774 .33899 .44168 Mtetra
.406 .523 .863 r
.33899 .44168 .34263 .44774 .34848 .44927 .34485 .4431 Mtetra
.41 .521 .86 r
.34485 .4431 .34848 .44927 .35436 .4508 .35073 .44453 Mtetra
.412 .519 .856 r
.35073 .44453 .35436 .4508 .36027 .45233 .35664 .44596 Mtetra
.415 .517 .853 r
.35664 .44596 .36027 .45233 .3662 .45388 .36258 .4474 Mtetra
.418 .515 .85 r
.36258 .4474 .3662 .45388 .37216 .45543 .36854 .44885 Mtetra
.421 .513 .847 r
.36854 .44885 .37216 .45543 .37814 .45699 .37453 .4503 Mtetra
.423 .51 .843 r
.37453 .4503 .37814 .45699 .38416 .45856 .38055 .45176 Mtetra
.426 .508 .84 r
.38055 .45176 .38416 .45856 .39019 .46013 .38659 .45323 Mtetra
.428 .507 .837 r
.38659 .45323 .39019 .46013 .39626 .46171 .39266 .4547 Mtetra
.43 .504 .834 r
.39266 .4547 .39626 .46171 .40236 .4633 .39876 .45618 Mtetra
.432 .502 .831 r
.39876 .45618 .40236 .4633 .40848 .46491 .40488 .45768 Mtetra
.435 .501 .828 r
.40488 .45768 .40848 .46491 .41463 .46651 .41103 .45917 Mtetra
.437 .499 .825 r
.41103 .45917 .41463 .46651 .42081 .46813 .41721 .46068 Mtetra
.439 .497 .822 r
.41721 .46068 .42081 .46813 .42701 .46975 .42342 .4622 Mtetra
.441 .495 .819 r
.42342 .4622 .42701 .46975 .43325 .47139 .42965 .46372 Mtetra
.443 .493 .816 r
.42965 .46372 .43325 .47139 .43951 .47302 .43592 .46524 Mtetra
.444 .491 .813 r
.43592 .46524 .43951 .47302 .4458 .47468 .44221 .46679 Mtetra
.446 .489 .81 r
.44221 .46679 .4458 .47468 .45212 .47635 .44853 .46834 Mtetra
.448 .488 .808 r
.44853 .46834 .45212 .47635 .45847 .478 .45488 .46988 Mtetra
.451 .487 .805 r
.45488 .46988 .45847 .478 .46485 .47966 .46126 .47142 Mtetra
.455 .486 .802 r
.46126 .47142 .46485 .47966 .47127 .48128 .46767 .47293 Mtetra
.467 .491 .799 r
.46767 .47293 .47127 .48128 .47771 .48273 .47411 .47428 Mtetra
.49 .502 .796 r
.47411 .47428 .47771 .48273 .48418 .48381 .48059 .47525 Mtetra
.606 .564 .781 r
.48059 .47525 .48418 .48381 .49072 .48235 .48712 .47376 Mtetra
.717 .62 .748 r
.48712 .47376 .49072 .48235 .4973 .47713 .4937 .46862 Mtetra
.726 .626 .746 r
.4937 .46862 .4973 .47713 .50388 .47158 .50029 .46315 Mtetra
.731 .63 .746 r
.50029 .46315 .50388 .47158 .51047 .46581 .50689 .45748 Mtetra
.734 .633 .747 r
.50689 .45748 .51047 .46581 .51706 .45997 .51348 .45172 Mtetra
.736 .636 .748 r
.51348 .45172 .51706 .45997 .52365 .45411 .52008 .44596 Mtetra
.737 .638 .75 r
.52008 .44596 .52365 .45411 .53024 .44826 .52667 .44019 Mtetra
.739 .641 .751 r
.52667 .44019 .53024 .44826 .53683 .44239 .53327 .43442 Mtetra
.74 .644 .753 r
.53327 .43442 .53683 .44239 .54343 .43653 .53987 .42865 Mtetra
.741 .646 .755 r
.53987 .42865 .54343 .43653 .55002 .43067 .54647 .42288 Mtetra
.743 .649 .756 r
.54647 .42288 .55002 .43067 .55662 .42481 .55307 .41711 Mtetra
.744 .652 .758 r
.55307 .41711 .55662 .42481 .56321 .41895 .55968 .41134 Mtetra
.745 .654 .759 r
.55968 .41134 .56321 .41895 .56981 .4131 .56628 .40557 Mtetra
.747 .657 .761 r
.56628 .40557 .56981 .4131 .5764 .40724 .57289 .3998 Mtetra
.748 .66 .763 r
.57289 .3998 .5764 .40724 .583 .40138 .57949 .39403 Mtetra
.75 .663 .765 r
.57949 .39403 .583 .40138 .5896 .39552 .5861 .38826 Mtetra
.751 .666 .766 r
.5861 .38826 .5896 .39552 .5962 .38967 .59271 .3825 Mtetra
.753 .668 .768 r
.59271 .3825 .5962 .38967 .6028 .38381 .59932 .37673 Mtetra
.754 .671 .77 r
.59932 .37673 .6028 .38381 .6094 .37795 .60593 .37095 Mtetra
.756 .674 .772 r
.60593 .37095 .6094 .37795 .616 .3721 .61254 .36519 Mtetra
.757 .678 .774 r
.61254 .36519 .616 .3721 .6226 .36624 .61916 .35942 Mtetra
.759 .681 .775 r
.61916 .35942 .6226 .36624 .6292 .36038 .62577 .35364 Mtetra
.76 .684 .777 r
.62577 .35364 .6292 .36038 .63581 .35452 .63239 .34787 Mtetra
.762 .687 .779 r
.63239 .34787 .63581 .35452 .64241 .34867 .639 .3421 Mtetra
.764 .69 .781 r
.639 .3421 .64241 .34867 .64902 .34281 .64562 .33632 Mtetra
.765 .693 .783 r
.64562 .33632 .64902 .34281 .65562 .33695 .65224 .33055 Mtetra
.767 .697 .785 r
.65224 .33055 .65562 .33695 .66223 .33109 .65886 .32477 Mtetra
.769 .7 .787 r
.65886 .32477 .66223 .33109 .66884 .32523 .66549 .319 Mtetra
.77 .704 .789 r
.66549 .319 .66884 .32523 .67545 .31936 .67211 .31321 Mtetra
.772 .707 .791 r
.67211 .31321 .67545 .31936 .68206 .3135 .67873 .30744 Mtetra
.774 .711 .793 r
.67873 .30744 .68206 .3135 .68867 .30764 .68536 .30166 Mtetra
.775 .714 .795 r
.68536 .30166 .68867 .30764 .69528 .30177 .69198 .29587 Mtetra
.777 .718 .797 r
.69198 .29587 .69528 .30177 .70189 .2959 .69861 .29009 Mtetra
.779 .722 .799 r
.69861 .29009 .70189 .2959 .7085 .29004 .70524 .2843 Mtetra
.781 .725 .801 r
.70524 .2843 .7085 .29004 .71511 .28417 .71187 .27851 Mtetra
.782 .729 .803 r
.71187 .27851 .71511 .28417 .72173 .2783 .7185 .27272 Mtetra
.784 .733 .805 r
.7185 .27272 .72173 .2783 .72834 .27242 .72513 .26693 Mtetra
.786 .737 .808 r
.72513 .26693 .72834 .27242 .73496 .26655 .73177 .26114 Mtetra
.788 .741 .81 r
.73177 .26114 .73496 .26655 .74157 .26067 .7384 .25534 Mtetra
.79 .745 .812 r
.7384 .25534 .74157 .26067 .74819 .25479 .74504 .24954 Mtetra
.791 .749 .814 r
.74504 .24954 .74819 .25479 .75481 .24892 .75167 .24374 Mtetra
.793 .753 .816 r
.75167 .24374 .75481 .24892 .76142 .24303 .75831 .23794 Mtetra
.795 .758 .818 r
.75831 .23794 .76142 .24303 .76804 .23715 .76495 .23213 Mtetra
.797 .762 .821 r
.76495 .23213 .76804 .23715 .77466 .23126 .77159 .22633 Mtetra
.799 .766 .823 r
.77159 .22633 .77466 .23126 .78128 .22538 .77823 .22053 Mtetra
.801 .77 .825 r
.77823 .22053 .78128 .22538 .7879 .2195 .78487 .21472 Mtetra
.801 .775 .829 r
.78487 .21472 .7879 .2195 .79453 .21367 .79152 .20896 Mtetra
.8 .778 .833 r
.79152 .20896 .79453 .21367 .80116 .20794 .79818 .20331 Mtetra
.795 .781 .84 r
.79818 .20331 .80116 .20794 .80782 .20241 .80485 .19785 Mtetra
.786 .782 .849 r
.80485 .19785 .80782 .20241 .81451 .1972 .81157 .19269 Mtetra
.437 .66 .955 r
.19116 .40464 .19503 .40824 .20037 .40857 .19651 .4049 Mtetra
.349 .614 .95 r
.19651 .4049 .20037 .40857 .20568 .40948 .20183 .40573 Mtetra
.32 .594 .944 r
.20183 .40573 .20568 .40948 .21098 .41061 .20714 .40677 Mtetra
.31 .583 .939 r
.20714 .40677 .21098 .41061 .21629 .41184 .21247 .40791 Mtetra
.308 .577 .936 r
.21247 .40791 .21629 .41184 .22163 .41313 .21781 .40911 Mtetra
.312 .573 .933 r
.21781 .40911 .22163 .41313 .22698 .41444 .22317 .41033 Mtetra
.321 .572 .93 r
.22317 .41033 .22698 .41444 .23236 .41575 .22856 .41154 Mtetra
.327 .57 .928 r
.22856 .41154 .23236 .41575 .23775 .41707 .23397 .41277 Mtetra
.333 .568 .925 r
.23397 .41277 .23775 .41707 .24318 .4184 .2394 .414 Mtetra
.34 .566 .922 r
.2394 .414 .24318 .4184 .24862 .41973 .24485 .41524 Mtetra
.347 .564 .919 r
.24485 .41524 .24862 .41973 .25409 .42106 .25033 .41647 Mtetra
.352 .562 .915 r
.25033 .41647 .25409 .42106 .25958 .4224 .25583 .41772 Mtetra
.357 .56 .912 r
.25583 .41772 .25958 .4224 .26509 .42375 .26135 .41896 Mtetra
.363 .558 .909 r
.26135 .41896 .26509 .42375 .27063 .42509 .2669 .42021 Mtetra
.368 .555 .905 r
.2669 .42021 .27063 .42509 .27619 .42645 .27247 .42147 Mtetra
.373 .553 .902 r
.27247 .42147 .27619 .42645 .28178 .42781 .27806 .42273 Mtetra
.378 .551 .898 r
.27806 .42273 .28178 .42781 .28739 .42917 .28368 .42399 Mtetra
.383 .549 .895 r
.28368 .42399 .28739 .42917 .29302 .43053 .28932 .42526 Mtetra
.386 .546 .891 r
.28932 .42526 .29302 .43053 .29868 .43191 .29499 .42654 Mtetra
.391 .544 .888 r
.29499 .42654 .29868 .43191 .30437 .43329 .30068 .42782 Mtetra
.395 .542 .884 r
.30068 .42782 .30437 .43329 .31007 .43467 .30639 .4291 Mtetra
.399 .539 .881 r
.30639 .4291 .31007 .43467 .31581 .43606 .31213 .43039 Mtetra
.402 .537 .877 r
.31213 .43039 .31581 .43606 .32156 .43746 .3179 .43169 Mtetra
.406 .535 .874 r
.3179 .43169 .32156 .43746 .32735 .43886 .32369 .43298 Mtetra
.409 .533 .87 r
.32369 .43298 .32735 .43886 .33315 .44026 .3295 .43429 Mtetra
.412 .53 .867 r
.3295 .43429 .33315 .44026 .33899 .44168 .33534 .4356 Mtetra
.415 .528 .863 r
.33534 .4356 .33899 .44168 .34485 .4431 .3412 .43692 Mtetra
.418 .526 .86 r
.3412 .43692 .34485 .4431 .35073 .44453 .34709 .43824 Mtetra
.421 .523 .857 r
.34709 .43824 .35073 .44453 .35664 .44596 .35301 .43957 Mtetra
.424 .521 .853 r
.35301 .43957 .35664 .44596 .36258 .4474 .35895 .44091 Mtetra
.426 .519 .85 r
.35895 .44091 .36258 .4474 .36854 .44885 .36492 .44225 Mtetra
.429 .517 .847 r
.36492 .44225 .36854 .44885 .37453 .4503 .37091 .44359 Mtetra
.431 .515 .843 r
.37091 .44359 .37453 .4503 .38055 .45176 .37693 .44495 Mtetra
.434 .513 .84 r
.37693 .44495 .38055 .45176 .38659 .45323 .38297 .44631 Mtetra
.436 .511 .837 r
.38297 .44631 .38659 .45323 .39266 .4547 .38905 .44768 Mtetra
.438 .509 .834 r
.38905 .44768 .39266 .4547 .39876 .45618 .39515 .44905 Mtetra
.44 .506 .831 r
.39515 .44905 .39876 .45618 .40488 .45768 .40127 .45044 Mtetra
.442 .505 .828 r
.40127 .45044 .40488 .45768 .41103 .45917 .40743 .45182 Mtetra
.444 .503 .825 r
.40743 .45182 .41103 .45917 .41721 .46068 .41361 .45322 Mtetra
.446 .5 .822 r
.41361 .45322 .41721 .46068 .42342 .4622 .41982 .45462 Mtetra
.448 .499 .819 r
.41982 .45462 .42342 .4622 .42965 .46372 .42605 .45603 Mtetra
.45 .497 .816 r
.42605 .45603 .42965 .46372 .43592 .46524 .43232 .45745 Mtetra
.451 .495 .813 r
.43232 .45745 .43592 .46524 .44221 .46679 .43861 .45888 Mtetra
.452 .493 .81 r
.43861 .45888 .44221 .46679 .44853 .46834 .44493 .46032 Mtetra
.455 .492 .808 r
.44493 .46032 .44853 .46834 .45488 .46988 .45128 .46175 Mtetra
.457 .49 .805 r
.45128 .46175 .45488 .46988 .46126 .47142 .45766 .46318 Mtetra
.461 .49 .802 r
.45766 .46318 .46126 .47142 .46767 .47293 .46407 .46457 Mtetra
.472 .494 .799 r
.46407 .46457 .46767 .47293 .47411 .47428 .47051 .46581 Mtetra
.494 .504 .796 r
.47051 .46581 .47411 .47428 .48059 .47525 .47698 .46668 Mtetra
.607 .565 .781 r
.47698 .46668 .48059 .47525 .48712 .47376 .48352 .46517 Mtetra
.715 .62 .749 r
.48352 .46517 .48712 .47376 .4937 .46862 .4901 .4601 Mtetra
.724 .625 .747 r
.4901 .4601 .4937 .46862 .50029 .46315 .4967 .45471 Mtetra
.729 .629 .747 r
.4967 .45471 .50029 .46315 .50689 .45748 .50329 .44913 Mtetra
.732 .632 .748 r
.50329 .44913 .50689 .45748 .51348 .45172 .50989 .44346 Mtetra
.734 .635 .749 r
.50989 .44346 .51348 .45172 .52008 .44596 .5165 .43779 Mtetra
.735 .638 .751 r
.5165 .43779 .52008 .44596 .52667 .44019 .5231 .43212 Mtetra
.737 .64 .752 r
.5231 .43212 .52667 .44019 .53327 .43442 .5297 .42643 Mtetra
.738 .643 .754 r
.5297 .42643 .53327 .43442 .53987 .42865 .53631 .42075 Mtetra
.739 .645 .756 r
.53631 .42075 .53987 .42865 .54647 .42288 .54292 .41507 Mtetra
.741 .648 .757 r
.54292 .41507 .54647 .42288 .55307 .41711 .54953 .40939 Mtetra
.742 .651 .759 r
.54953 .40939 .55307 .41711 .55968 .41134 .55614 .40371 Mtetra
.743 .653 .761 r
.55614 .40371 .55968 .41134 .56628 .40557 .56275 .39803 Mtetra
.745 .656 .762 r
.56275 .39803 .56628 .40557 .57289 .3998 .56936 .39235 Mtetra
.746 .659 .764 r
.56936 .39235 .57289 .3998 .57949 .39403 .57598 .38667 Mtetra
.748 .662 .766 r
.57598 .38667 .57949 .39403 .5861 .38826 .58259 .38099 Mtetra
.749 .665 .768 r
.58259 .38099 .5861 .38826 .59271 .3825 .58921 .37531 Mtetra
.751 .668 .769 r
.58921 .37531 .59271 .3825 .59932 .37673 .59583 .36962 Mtetra
.752 .671 .771 r
.59583 .36962 .59932 .37673 .60593 .37095 .60245 .36394 Mtetra
.753 .674 .773 r
.60245 .36394 .60593 .37095 .61254 .36519 .60908 .35826 Mtetra
.755 .677 .775 r
.60908 .35826 .61254 .36519 .61916 .35942 .6157 .35257 Mtetra
.757 .68 .777 r
.6157 .35257 .61916 .35942 .62577 .35364 .62233 .34688 Mtetra
.758 .683 .779 r
.62233 .34688 .62577 .35364 .63239 .34787 .62896 .3412 Mtetra
.76 .686 .781 r
.62896 .3412 .63239 .34787 .639 .3421 .63559 .33551 Mtetra
.761 .689 .782 r
.63559 .33551 .639 .3421 .64562 .33632 .64222 .32982 Mtetra
.763 .693 .784 r
.64222 .32982 .64562 .33632 .65224 .33055 .64885 .32413 Mtetra
.764 .696 .786 r
.64885 .32413 .65224 .33055 .65886 .32477 .65548 .31844 Mtetra
.766 .699 .788 r
.65548 .31844 .65886 .32477 .66549 .319 .66212 .31274 Mtetra
.768 .703 .79 r
.66212 .31274 .66549 .319 .67211 .31321 .66876 .30705 Mtetra
.769 .706 .792 r
.66876 .30705 .67211 .31321 .67873 .30744 .6754 .30135 Mtetra
.771 .71 .794 r
.6754 .30135 .67873 .30744 .68536 .30166 .68204 .29565 Mtetra
.773 .713 .796 r
.68204 .29565 .68536 .30166 .69198 .29587 .68868 .28995 Mtetra
.775 .717 .799 r
.68868 .28995 .69198 .29587 .69861 .29009 .69532 .28425 Mtetra
.776 .721 .801 r
.69532 .28425 .69861 .29009 .70524 .2843 .70197 .27854 Mtetra
.778 .725 .803 r
.70197 .27854 .70524 .2843 .71187 .27851 .70861 .27284 Mtetra
.78 .728 .805 r
.70861 .27284 .71187 .27851 .7185 .27272 .71526 .26713 Mtetra
.782 .732 .807 r
.71526 .26713 .7185 .27272 .72513 .26693 .72191 .26142 Mtetra
.783 .736 .809 r
.72191 .26142 .72513 .26693 .73177 .26114 .72856 .2557 Mtetra
.785 .74 .811 r
.72856 .2557 .73177 .26114 .7384 .25534 .73522 .24999 Mtetra
.787 .744 .814 r
.73522 .24999 .7384 .25534 .74504 .24954 .74187 .24427 Mtetra
.789 .748 .816 r
.74187 .24427 .74504 .24954 .75167 .24374 .74853 .23855 Mtetra
.791 .752 .818 r
.74853 .23855 .75167 .24374 .75831 .23794 .75518 .23282 Mtetra
.793 .757 .82 r
.75518 .23282 .75831 .23794 .76495 .23213 .76184 .22709 Mtetra
.794 .761 .823 r
.76184 .22709 .76495 .23213 .77159 .22633 .7685 .22137 Mtetra
.796 .765 .825 r
.7685 .22137 .77159 .22633 .77823 .22053 .77516 .21565 Mtetra
.798 .77 .827 r
.77516 .21565 .77823 .22053 .78487 .21472 .78183 .20992 Mtetra
.798 .774 .83 r
.78183 .20992 .78487 .21472 .79152 .20896 .7885 .20424 Mtetra
.797 .777 .835 r
.7885 .20424 .79152 .20896 .79818 .20331 .79518 .19866 Mtetra
.793 .78 .841 r
.79518 .19866 .79818 .20331 .80485 .19785 .80188 .19326 Mtetra
.784 .781 .851 r
.80188 .19326 .80485 .19785 .81157 .19269 .80861 .18817 Mtetra
.445 .664 .955 r
.18728 .40102 .19116 .40464 .19651 .4049 .19264 .40121 Mtetra
.362 .621 .951 r
.19264 .40121 .19651 .4049 .20183 .40573 .19796 .40196 Mtetra
.334 .602 .945 r
.19796 .40196 .20183 .40573 .20714 .40677 .20329 .40291 Mtetra
.325 .591 .941 r
.20329 .40291 .20714 .40677 .21247 .40791 .20863 .40396 Mtetra
.323 .585 .938 r
.20863 .40396 .21247 .40791 .21781 .40911 .21398 .40506 Mtetra
.327 .581 .935 r
.21398 .40506 .21781 .40911 .22317 .41033 .21935 .40619 Mtetra
.335 .58 .932 r
.21935 .40619 .22317 .41033 .22856 .41154 .22475 .40731 Mtetra
.341 .577 .929 r
.22475 .40731 .22856 .41154 .23397 .41277 .23017 .40844 Mtetra
.347 .575 .926 r
.23017 .40844 .23397 .41277 .2394 .414 .23561 .40958 Mtetra
.353 .573 .923 r
.23561 .40958 .2394 .414 .24485 .41524 .24107 .41072 Mtetra
.36 .571 .919 r
.24107 .41072 .24485 .41524 .25033 .41647 .24656 .41186 Mtetra
.364 .568 .916 r
.24656 .41186 .25033 .41647 .25583 .41772 .25207 .41301 Mtetra
.37 .566 .913 r
.25207 .41301 .25583 .41772 .26135 .41896 .2576 .41416 Mtetra
.375 .564 .909 r
.2576 .41416 .26135 .41896 .2669 .42021 .26316 .41531 Mtetra
.38 .561 .906 r
.26316 .41531 .2669 .42021 .27247 .42147 .26873 .41647 Mtetra
.384 .559 .902 r
.26873 .41647 .27247 .42147 .27806 .42273 .27434 .41763 Mtetra
.389 .557 .899 r
.27434 .41763 .27806 .42273 .28368 .42399 .27996 .4188 Mtetra
.394 .554 .895 r
.27996 .4188 .28368 .42399 .28932 .42526 .28561 .41997 Mtetra
.397 .552 .892 r
.28561 .41997 .28932 .42526 .29499 .42654 .29128 .42115 Mtetra
.401 .549 .888 r
.29128 .42115 .29499 .42654 .30068 .42782 .29698 .42233 Mtetra
.405 .547 .884 r
.29698 .42233 .30068 .42782 .30639 .4291 .3027 .42351 Mtetra
.408 .544 .881 r
.3027 .42351 .30639 .4291 .31213 .43039 .30845 .4247 Mtetra
.412 .542 .877 r
.30845 .4247 .31213 .43039 .3179 .43169 .31422 .42589 Mtetra
.415 .54 .874 r
.31422 .42589 .3179 .43169 .32369 .43298 .32002 .42709 Mtetra
.418 .537 .87 r
.32002 .42709 .32369 .43298 .3295 .43429 .32583 .42829 Mtetra
.421 .535 .867 r
.32583 .42829 .3295 .43429 .33534 .4356 .33168 .4295 Mtetra
.424 .533 .863 r
.33168 .4295 .33534 .4356 .3412 .43692 .33755 .43072 Mtetra
.427 .53 .86 r
.33755 .43072 .3412 .43692 .34709 .43824 .34344 .43193 Mtetra
.43 .528 .857 r
.34344 .43193 .34709 .43824 .35301 .43957 .34936 .43316 Mtetra
.432 .526 .853 r
.34936 .43316 .35301 .43957 .35895 .44091 .35531 .43439 Mtetra
.435 .524 .85 r
.35531 .43439 .35895 .44091 .36492 .44225 .36128 .43563 Mtetra
.437 .521 .847 r
.36128 .43563 .36492 .44225 .37091 .44359 .36728 .43687 Mtetra
.439 .519 .843 r
.36728 .43687 .37091 .44359 .37693 .44495 .3733 .43812 Mtetra
.441 .517 .84 r
.3733 .43812 .37693 .44495 .38297 .44631 .37935 .43937 Mtetra
.444 .515 .837 r
.37935 .43937 .38297 .44631 .38905 .44768 .38543 .44063 Mtetra
.445 .513 .834 r
.38543 .44063 .38905 .44768 .39515 .44905 .39153 .4419 Mtetra
.447 .51 .831 r
.39153 .4419 .39515 .44905 .40127 .45044 .39766 .44317 Mtetra
.449 .509 .828 r
.39766 .44317 .40127 .45044 .40743 .45182 .40382 .44445 Mtetra
.451 .506 .825 r
.40382 .44445 .40743 .45182 .41361 .45322 .41 .44573 Mtetra
.452 .504 .822 r
.41 .44573 .41361 .45322 .41982 .45462 .41621 .44703 Mtetra
.454 .502 .819 r
.41621 .44703 .41982 .45462 .42605 .45603 .42245 .44833 Mtetra
.456 .501 .816 r
.42245 .44833 .42605 .45603 .43232 .45745 .42871 .44963 Mtetra
.457 .498 .813 r
.42871 .44963 .43232 .45745 .43861 .45888 .43501 .45095 Mtetra
.459 .496 .81 r
.43501 .45095 .43861 .45888 .44493 .46032 .44133 .45228 Mtetra
.461 .495 .807 r
.44133 .45228 .44493 .46032 .45128 .46175 .44768 .45359 Mtetra
.463 .494 .805 r
.44768 .45359 .45128 .46175 .45766 .46318 .45405 .45491 Mtetra
.467 .493 .802 r
.45405 .45491 .45766 .46318 .46407 .46457 .46046 .45619 Mtetra
.478 .497 .799 r
.46046 .45619 .46407 .46457 .47051 .46581 .4669 .45732 Mtetra
.499 .507 .796 r
.4669 .45732 .47051 .46581 .47698 .46668 .47337 .4581 Mtetra
.608 .565 .781 r
.47337 .4581 .47698 .46668 .48352 .46517 .47991 .45655 Mtetra
.713 .618 .75 r
.47991 .45655 .48352 .46517 .4901 .4601 .4865 .45156 Mtetra
.722 .624 .748 r
.4865 .45156 .4901 .4601 .4967 .45471 .49309 .44625 Mtetra
.727 .628 .748 r
.49309 .44625 .4967 .45471 .50329 .44913 .4997 .44076 Mtetra
.73 .631 .749 r
.4997 .44076 .50329 .44913 .50989 .44346 .5063 .43518 Mtetra
.731 .634 .75 r
.5063 .43518 .50989 .44346 .5165 .43779 .51291 .4296 Mtetra
.733 .636 .752 r
.51291 .4296 .5165 .43779 .5231 .43212 .51952 .42402 Mtetra
.734 .639 .753 r
.51952 .42402 .5231 .43212 .5297 .42643 .52613 .41842 Mtetra
.736 .642 .755 r
.52613 .41842 .5297 .42643 .53631 .42075 .53274 .41283 Mtetra
.737 .644 .757 r
.53274 .41283 .53631 .42075 .54292 .41507 .53935 .40725 Mtetra
.738 .647 .758 r
.53935 .40725 .54292 .41507 .54953 .40939 .54597 .40165 Mtetra
.74 .65 .76 r
.54597 .40165 .54953 .40939 .55614 .40371 .55259 .39606 Mtetra
.741 .652 .762 r
.55259 .39606 .55614 .40371 .56275 .39803 .55921 .39047 Mtetra
.742 .655 .763 r
.55921 .39047 .56275 .39803 .56936 .39235 .56583 .38488 Mtetra
.744 .658 .765 r
.56583 .38488 .56936 .39235 .57598 .38667 .57245 .37928 Mtetra
.745 .661 .767 r
.57245 .37928 .57598 .38667 .58259 .38099 .57908 .37369 Mtetra
.747 .664 .769 r
.57908 .37369 .58259 .38099 .58921 .37531 .58571 .3681 Mtetra
.748 .667 .77 r
.58571 .3681 .58921 .37531 .59583 .36962 .59234 .3625 Mtetra
.75 .67 .772 r
.59234 .3625 .59583 .36962 .60245 .36394 .59897 .3569 Mtetra
.751 .672 .774 r
.59897 .3569 .60245 .36394 .60908 .35826 .6056 .3513 Mtetra
.753 .676 .776 r
.6056 .3513 .60908 .35826 .6157 .35257 .61224 .34571 Mtetra
.754 .679 .778 r
.61224 .34571 .6157 .35257 .62233 .34688 .61888 .3401 Mtetra
.756 .682 .78 r
.61888 .3401 .62233 .34688 .62896 .3412 .62552 .3345 Mtetra
.757 .685 .782 r
.62552 .3345 .62896 .3412 .63559 .33551 .63216 .3289 Mtetra
.759 .688 .784 r
.63216 .3289 .63559 .33551 .64222 .32982 .6388 .32329 Mtetra
.76 .692 .786 r
.6388 .32329 .64222 .32982 .64885 .32413 .64545 .31769 Mtetra
.762 .695 .788 r
.64545 .31769 .64885 .32413 .65548 .31844 .6521 .31208 Mtetra
.764 .698 .79 r
.6521 .31208 .65548 .31844 .66212 .31274 .65875 .30647 Mtetra
.765 .702 .792 r
.65875 .30647 .66212 .31274 .66876 .30705 .6654 .30085 Mtetra
.767 .705 .794 r
.6654 .30085 .66876 .30705 .6754 .30135 .67205 .29524 Mtetra
.769 .709 .796 r
.67205 .29524 .6754 .30135 .68204 .29565 .67871 .28963 Mtetra
.77 .712 .798 r
.67871 .28963 .68204 .29565 .68868 .28995 .68536 .28401 Mtetra
.772 .716 .8 r
.68536 .28401 .68868 .28995 .69532 .28425 .69202 .27838 Mtetra
.774 .72 .802 r
.69202 .27838 .69532 .28425 .70197 .27854 .69868 .27276 Mtetra
.776 .724 .804 r
.69868 .27276 .70197 .27854 .70861 .27284 .70535 .26714 Mtetra
.777 .727 .806 r
.70535 .26714 .70861 .27284 .71526 .26713 .71201 .26151 Mtetra
.779 .731 .809 r
.71201 .26151 .71526 .26713 .72191 .26142 .71868 .25588 Mtetra
.781 .735 .811 r
.71868 .25588 .72191 .26142 .72856 .2557 .72535 .25025 Mtetra
.783 .739 .813 r
.72535 .25025 .72856 .2557 .73522 .24999 .73202 .24461 Mtetra
.784 .743 .815 r
.73202 .24461 .73522 .24999 .74187 .24427 .73869 .23897 Mtetra
.786 .747 .818 r
.73869 .23897 .74187 .24427 .74853 .23855 .74537 .23333 Mtetra
.788 .752 .82 r
.74537 .23333 .74853 .23855 .75518 .23282 .75204 .22769 Mtetra
.79 .756 .822 r
.75204 .22769 .75518 .23282 .76184 .22709 .75872 .22204 Mtetra
.792 .76 .824 r
.75872 .22204 .76184 .22709 .7685 .22137 .7654 .21639 Mtetra
.793 .764 .827 r
.7654 .21639 .7685 .22137 .77516 .21565 .77209 .21075 Mtetra
.795 .769 .829 r
.77209 .21075 .77516 .21565 .78183 .20992 .77877 .2051 Mtetra
.796 .773 .832 r
.77877 .2051 .78183 .20992 .7885 .20424 .78546 .19949 Mtetra
.794 .777 .837 r
.78546 .19949 .7885 .20424 .79518 .19866 .79216 .19399 Mtetra
.79 .779 .843 r
.79216 .19399 .79518 .19866 .80188 .19326 .79888 .18866 Mtetra
.781 .781 .852 r
.79888 .18866 .80188 .19326 .80861 .18817 .80563 .18363 Mtetra
.454 .668 .955 r
.18338 .39738 .18728 .40102 .19264 .40121 .18875 .39751 Mtetra
.375 .627 .952 r
.18875 .39751 .19264 .40121 .19796 .40196 .19409 .39817 Mtetra
.348 .609 .947 r
.19409 .39817 .19796 .40196 .20329 .40291 .19942 .39904 Mtetra
.339 .599 .943 r
.19942 .39904 .20329 .40291 .20863 .40396 .20477 .4 Mtetra
.338 .592 .939 r
.20477 .4 .20863 .40396 .21398 .40506 .21013 .40101 Mtetra
.342 .589 .936 r
.21013 .40101 .21398 .40506 .21935 .40619 .21552 .40204 Mtetra
.349 .587 .933 r
.21552 .40204 .21935 .40619 .22475 .40731 .22092 .40307 Mtetra
.355 .585 .93 r
.22092 .40307 .22475 .40731 .23017 .40844 .22635 .4041 Mtetra
.36 .582 .927 r
.22635 .4041 .23017 .40844 .23561 .40958 .2318 .40515 Mtetra
.366 .58 .924 r
.2318 .40515 .23561 .40958 .24107 .41072 .23728 .40619 Mtetra
.372 .577 .92 r
.23728 .40619 .24107 .41072 .24656 .41186 .24277 .40724 Mtetra
.377 .575 .917 r
.24277 .40724 .24656 .41186 .25207 .41301 .24829 .40829 Mtetra
.382 .572 .913 r
.24829 .40829 .25207 .41301 .2576 .41416 .25383 .40934 Mtetra
.387 .57 .91 r
.25383 .40934 .2576 .41416 .26316 .41531 .2594 .4104 Mtetra
.391 .567 .906 r
.2594 .4104 .26316 .41531 .26873 .41647 .26499 .41146 Mtetra
.395 .565 .903 r
.26499 .41146 .26873 .41647 .27434 .41763 .2706 .41252 Mtetra
.4 .562 .899 r
.2706 .41252 .27434 .41763 .27996 .4188 .27623 .41359 Mtetra
.404 .56 .895 r
.27623 .41359 .27996 .4188 .28561 .41997 .28189 .41466 Mtetra
.407 .557 .892 r
.28189 .41466 .28561 .41997 .29128 .42115 .28757 .41574 Mtetra
.411 .555 .888 r
.28757 .41574 .29128 .42115 .29698 .42233 .29327 .41682 Mtetra
.415 .552 .885 r
.29327 .41682 .29698 .42233 .3027 .42351 .299 .4179 Mtetra
.418 .55 .881 r
.299 .4179 .3027 .42351 .30845 .4247 .30476 .41899 Mtetra
.421 .547 .877 r
.30476 .41899 .30845 .4247 .31422 .42589 .31053 .42008 Mtetra
.424 .545 .874 r
.31053 .42008 .31422 .42589 .32002 .42709 .31633 .42118 Mtetra
.427 .542 .87 r
.31633 .42118 .32002 .42709 .32583 .42829 .32216 .42228 Mtetra
.43 .54 .867 r
.32216 .42228 .32583 .42829 .33168 .4295 .32801 .42339 Mtetra
.433 .537 .863 r
.32801 .42339 .33168 .4295 .33755 .43072 .33389 .4245 Mtetra
.436 .535 .86 r
.33389 .4245 .33755 .43072 .34344 .43193 .33979 .42561 Mtetra
.438 .533 .857 r
.33979 .42561 .34344 .43193 .34936 .43316 .34571 .42673 Mtetra
.44 .53 .853 r
.34571 .42673 .34936 .43316 .35531 .43439 .35166 .42786 Mtetra
.443 .528 .85 r
.35166 .42786 .35531 .43439 .36128 .43563 .35764 .42899 Mtetra
.445 .526 .847 r
.35764 .42899 .36128 .43563 .36728 .43687 .36364 .43012 Mtetra
.447 .523 .843 r
.36364 .43012 .36728 .43687 .3733 .43812 .36967 .43127 Mtetra
.449 .521 .84 r
.36967 .43127 .3733 .43812 .37935 .43937 .37572 .43242 Mtetra
.451 .519 .837 r
.37572 .43242 .37935 .43937 .38543 .44063 .3818 .43357 Mtetra
.453 .517 .834 r
.3818 .43357 .38543 .44063 .39153 .4419 .3879 .43473 Mtetra
.454 .514 .831 r
.3879 .43473 .39153 .4419 .39766 .44317 .39404 .43589 Mtetra
.456 .513 .828 r
.39404 .43589 .39766 .44317 .40382 .44445 .4002 .43706 Mtetra
.458 .51 .825 r
.4002 .43706 .40382 .44445 .41 .44573 .40638 .43824 Mtetra
.459 .508 .822 r
.40638 .43824 .41 .44573 .41621 .44703 .41259 .43942 Mtetra
.461 .506 .819 r
.41259 .43942 .41621 .44703 .42245 .44833 .41883 .44061 Mtetra
.463 .504 .816 r
.41883 .44061 .42245 .44833 .42871 .44963 .4251 .4418 Mtetra
.464 .502 .813 r
.4251 .4418 .42871 .44963 .43501 .45095 .43139 .44301 Mtetra
.465 .5 .81 r
.43139 .44301 .43501 .45095 .44133 .45228 .43771 .44422 Mtetra
.467 .499 .807 r
.43771 .44422 .44133 .45228 .44768 .45359 .44406 .44543 Mtetra
.469 .497 .805 r
.44406 .44543 .44768 .45359 .45405 .45491 .45044 .44663 Mtetra
.473 .497 .802 r
.45044 .44663 .45405 .45491 .46046 .45619 .45685 .4478 Mtetra
.483 .5 .799 r
.45685 .4478 .46046 .45619 .4669 .45732 .46329 .44882 Mtetra
.503 .509 .796 r
.46329 .44882 .4669 .45732 .47337 .4581 .46976 .4495 Mtetra
.608 .565 .781 r
.46976 .4495 .47337 .4581 .47991 .45655 .47629 .44792 Mtetra
.711 .618 .751 r
.47629 .44792 .47991 .45655 .4865 .45156 .48289 .443 Mtetra
.72 .623 .749 r
.48289 .443 .4865 .45156 .49309 .44625 .48949 .43778 Mtetra
.725 .627 .749 r
.48949 .43778 .49309 .44625 .4997 .44076 .49609 .43237 Mtetra
.728 .63 .75 r
.49609 .43237 .4997 .44076 .5063 .43518 .5027 .42689 Mtetra
.729 .633 .751 r
.5027 .42689 .5063 .43518 .51291 .4296 .50931 .4214 Mtetra
.731 .635 .753 r
.50931 .4214 .51291 .4296 .51952 .42402 .51593 .41591 Mtetra
.732 .638 .754 r
.51593 .41591 .51952 .42402 .52613 .41842 .52254 .4104 Mtetra
.733 .641 .756 r
.52254 .4104 .52613 .41842 .53274 .41283 .52916 .4049 Mtetra
.735 .643 .758 r
.52916 .4049 .53274 .41283 .53935 .40725 .53578 .3994 Mtetra
.736 .646 .759 r
.53578 .3994 .53935 .40725 .54597 .40165 .54241 .3939 Mtetra
.737 .649 .761 r
.54241 .3939 .54597 .40165 .55259 .39606 .54903 .38839 Mtetra
.739 .651 .763 r
.54903 .38839 .55259 .39606 .55921 .39047 .55566 .38289 Mtetra
.74 .654 .765 r
.55566 .38289 .55921 .39047 .56583 .38488 .56229 .37739 Mtetra
.742 .657 .766 r
.56229 .37739 .56583 .38488 .57245 .37928 .56892 .37188 Mtetra
.743 .66 .768 r
.56892 .37188 .57245 .37928 .57908 .37369 .57556 .36637 Mtetra
.744 .663 .77 r
.57556 .36637 .57908 .37369 .58571 .3681 .58219 .36087 Mtetra
.746 .666 .772 r
.58219 .36087 .58571 .3681 .59234 .3625 .58883 .35536 Mtetra
.747 .669 .774 r
.58883 .35536 .59234 .3625 .59897 .3569 .59547 .34985 Mtetra
.749 .672 .775 r
.59547 .34985 .59897 .3569 .6056 .3513 .60212 .34434 Mtetra
.75 .675 .777 r
.60212 .34434 .6056 .3513 .61224 .34571 .60877 .33882 Mtetra
.752 .678 .779 r
.60877 .33882 .61224 .34571 .61888 .3401 .61541 .33331 Mtetra
.753 .681 .781 r
.61541 .33331 .61888 .3401 .62552 .3345 .62207 .32779 Mtetra
.755 .684 .783 r
.62207 .32779 .62552 .3345 .63216 .3289 .62872 .32227 Mtetra
.756 .687 .785 r
.62872 .32227 .63216 .3289 .6388 .32329 .63538 .31675 Mtetra
.758 .691 .787 r
.63538 .31675 .6388 .32329 .64545 .31769 .64203 .31122 Mtetra
.76 .694 .789 r
.64203 .31122 .64545 .31769 .6521 .31208 .6487 .3057 Mtetra
.761 .697 .791 r
.6487 .3057 .6521 .31208 .65875 .30647 .65536 .30018 Mtetra
.763 .701 .793 r
.65536 .30018 .65875 .30647 .6654 .30085 .66203 .29464 Mtetra
.764 .704 .795 r
.66203 .29464 .6654 .30085 .67205 .29524 .66869 .28911 Mtetra
.766 .708 .797 r
.66869 .28911 .67205 .29524 .67871 .28963 .67536 .28358 Mtetra
.768 .712 .799 r
.67536 .28358 .67871 .28963 .68536 .28401 .68204 .27804 Mtetra
.77 .715 .802 r
.68204 .27804 .68536 .28401 .69202 .27838 .68871 .2725 Mtetra
.771 .719 .804 r
.68871 .2725 .69202 .27838 .69868 .27276 .69539 .26696 Mtetra
.773 .723 .806 r
.69539 .26696 .69868 .27276 .70535 .26714 .70207 .26142 Mtetra
.775 .727 .808 r
.70207 .26142 .70535 .26714 .71201 .26151 .70875 .25587 Mtetra
.776 .73 .81 r
.70875 .25587 .71201 .26151 .71868 .25588 .71544 .25032 Mtetra
.778 .734 .813 r
.71544 .25032 .71868 .25588 .72535 .25025 .72212 .24477 Mtetra
.78 .738 .815 r
.72212 .24477 .72535 .25025 .73202 .24461 .72881 .23922 Mtetra
.782 .743 .817 r
.72881 .23922 .73202 .24461 .73869 .23897 .7355 .23366 Mtetra
.783 .747 .819 r
.7355 .23366 .73869 .23897 .74537 .23333 .7422 .2281 Mtetra
.785 .751 .822 r
.7422 .2281 .74537 .23333 .75204 .22769 .74889 .22253 Mtetra
.787 .755 .824 r
.74889 .22253 .75204 .22769 .75872 .22204 .75559 .21696 Mtetra
.789 .759 .826 r
.75559 .21696 .75872 .22204 .7654 .21639 .76229 .21139 Mtetra
.791 .764 .829 r
.76229 .21139 .7654 .21639 .77209 .21075 .769 .20583 Mtetra
.792 .768 .831 r
.769 .20583 .77209 .21075 .77877 .2051 .7757 .20026 Mtetra
.793 .772 .834 r
.7757 .20026 .77877 .2051 .78546 .19949 .78241 .19473 Mtetra
.791 .776 .839 r
.78241 .19473 .78546 .19949 .79216 .19399 .78914 .18929 Mtetra
.787 .779 .845 r
.78914 .18929 .79216 .19399 .79888 .18866 .79588 .18404 Mtetra
.778 .78 .854 r
.79588 .18404 .79888 .18866 .80563 .18363 .80265 .17906 Mtetra
.463 .672 .954 r
.17946 .39373 .18338 .39738 .18875 .39751 .18485 .39379 Mtetra
.388 .633 .952 r
.18485 .39379 .18875 .39751 .19409 .39817 .19019 .39438 Mtetra
.362 .616 .948 r
.19019 .39438 .19409 .39817 .19942 .39904 .19554 .39515 Mtetra
.354 .606 .944 r
.19554 .39515 .19942 .39904 .20477 .4 .2009 .39602 Mtetra
.352 .6 .94 r
.2009 .39602 .20477 .4 .21013 .40101 .20627 .39694 Mtetra
.356 .596 .937 r
.20627 .39694 .21013 .40101 .21552 .40204 .21167 .39787 Mtetra
.363 .594 .934 r
.21167 .39787 .21552 .40204 .22092 .40307 .21709 .39881 Mtetra
.368 .591 .931 r
.21709 .39881 .22092 .40307 .22635 .4041 .22253 .39975 Mtetra
.373 .588 .928 r
.22253 .39975 .22635 .4041 .2318 .40515 .22799 .4007 Mtetra
.379 .586 .924 r
.22799 .4007 .2318 .40515 .23728 .40619 .23347 .40165 Mtetra
.384 .584 .921 r
.23347 .40165 .23728 .40619 .24277 .40724 .23898 .4026 Mtetra
.389 .581 .917 r
.23898 .4026 .24277 .40724 .24829 .40829 .2445 .40355 Mtetra
.393 .578 .914 r
.2445 .40355 .24829 .40829 .25383 .40934 .25005 .40451 Mtetra
.398 .576 .91 r
.25005 .40451 .25383 .40934 .2594 .4104 .25563 .40547 Mtetra
.402 .573 .906 r
.25563 .40547 .2594 .4104 .26499 .41146 .26122 .40643 Mtetra
.406 .57 .903 r
.26122 .40643 .26499 .41146 .2706 .41252 .26684 .4074 Mtetra
.41 .568 .899 r
.26684 .4074 .2706 .41252 .27623 .41359 .27249 .40837 Mtetra
.414 .565 .896 r
.27249 .40837 .27623 .41359 .28189 .41466 .27815 .40934 Mtetra
.418 .562 .892 r
.27815 .40934 .28189 .41466 .28757 .41574 .28384 .41032 Mtetra
.421 .56 .888 r
.28384 .41032 .28757 .41574 .29327 .41682 .28955 .4113 Mtetra
.425 .557 .885 r
.28955 .4113 .29327 .41682 .299 .4179 .29529 .41228 Mtetra
.427 .555 .881 r
.29529 .41228 .299 .4179 .30476 .41899 .30105 .41327 Mtetra
.43 .552 .877 r
.30105 .41327 .30476 .41899 .31053 .42008 .30683 .41426 Mtetra
.433 .55 .874 r
.30683 .41426 .31053 .42008 .31633 .42118 .31264 .41525 Mtetra
.436 .547 .87 r
.31264 .41525 .31633 .42118 .32216 .42228 .31847 .41625 Mtetra
.439 .544 .867 r
.31847 .41625 .32216 .42228 .32801 .42339 .32433 .41726 Mtetra
.441 .542 .863 r
.32433 .41726 .32801 .42339 .33389 .4245 .33021 .41827 Mtetra
.444 .54 .86 r
.33021 .41827 .33389 .4245 .33979 .42561 .33612 .41928 Mtetra
.446 .537 .856 r
.33612 .41928 .33979 .42561 .34571 .42673 .34205 .42029 Mtetra
.448 .535 .853 r
.34205 .42029 .34571 .42673 .35166 .42786 .348 .42132 Mtetra
.45 .532 .85 r
.348 .42132 .35166 .42786 .35764 .42899 .35398 .42234 Mtetra
.452 .53 .846 r
.35398 .42234 .35764 .42899 .36364 .43012 .35999 .42337 Mtetra
.454 .527 .843 r
.35999 .42337 .36364 .43012 .36967 .43127 .36602 .42441 Mtetra
.456 .525 .84 r
.36602 .42441 .36967 .43127 .37572 .43242 .37208 .42545 Mtetra
.458 .523 .837 r
.37208 .42545 .37572 .43242 .3818 .43357 .37816 .42649 Mtetra
.46 .521 .834 r
.37816 .42649 .3818 .43357 .3879 .43473 .38427 .42754 Mtetra
.461 .518 .831 r
.38427 .42754 .3879 .43473 .39404 .43589 .39041 .4286 Mtetra
.463 .516 .828 r
.39041 .4286 .39404 .43589 .4002 .43706 .39657 .42966 Mtetra
.465 .514 .825 r
.39657 .42966 .4002 .43706 .40638 .43824 .40275 .43073 Mtetra
.466 .512 .822 r
.40275 .43073 .40638 .43824 .41259 .43942 .40897 .4318 Mtetra
.467 .51 .819 r
.40897 .4318 .41259 .43942 .41883 .44061 .41521 .43288 Mtetra
.469 .508 .816 r
.41521 .43288 .41883 .44061 .4251 .4418 .42148 .43396 Mtetra
.47 .506 .813 r
.42148 .43396 .4251 .4418 .43139 .44301 .42777 .43506 Mtetra
.471 .504 .81 r
.42777 .43506 .43139 .44301 .43771 .44422 .4341 .43616 Mtetra
.473 .502 .807 r
.4341 .43616 .43771 .44422 .44406 .44543 .44045 .43725 Mtetra
.475 .501 .805 r
.44045 .43725 .44406 .44543 .45044 .44663 .44682 .43834 Mtetra
.479 .5 .802 r
.44682 .43834 .45044 .44663 .45685 .4478 .45323 .4394 Mtetra
.489 .503 .799 r
.45323 .4394 .45685 .4478 .46329 .44882 .45967 .44031 Mtetra
.508 .512 .796 r
.45967 .44031 .46329 .44882 .46976 .4495 .46614 .44089 Mtetra
.609 .566 .781 r
.46614 .44089 .46976 .4495 .47629 .44792 .47267 .43928 Mtetra
.71 .617 .751 r
.47267 .43928 .47629 .44792 .48289 .443 .47927 .43444 Mtetra
.717 .622 .75 r
.47927 .43444 .48289 .443 .48949 .43778 .48587 .4293 Mtetra
.723 .626 .75 r
.48587 .4293 .48949 .43778 .49609 .43237 .49248 .42398 Mtetra
.726 .629 .751 r
.49248 .42398 .49609 .43237 .5027 .42689 .4991 .41859 Mtetra
.727 .632 .752 r
.4991 .41859 .5027 .42689 .50931 .4214 .50571 .41319 Mtetra
.728 .635 .754 r
.50571 .41319 .50931 .4214 .51593 .41591 .51233 .40779 Mtetra
.73 .637 .755 r
.51233 .40779 .51593 .41591 .52254 .4104 .51895 .40237 Mtetra
.731 .64 .757 r
.51895 .40237 .52254 .4104 .52916 .4049 .52558 .39696 Mtetra
.732 .642 .759 r
.52558 .39696 .52916 .4049 .53578 .3994 .5322 .39155 Mtetra
.734 .645 .76 r
.5322 .39155 .53578 .3994 .54241 .3939 .53883 .38613 Mtetra
.735 .648 .762 r
.53883 .38613 .54241 .3939 .54903 .38839 .54547 .38072 Mtetra
.736 .65 .764 r
.54547 .38072 .54903 .38839 .55566 .38289 .5521 .3753 Mtetra
.738 .653 .766 r
.5521 .3753 .55566 .38289 .56229 .37739 .55874 .36989 Mtetra
.739 .656 .767 r
.55874 .36989 .56229 .37739 .56892 .37188 .56538 .36447 Mtetra
.741 .659 .769 r
.56538 .36447 .56892 .37188 .57556 .36637 .57202 .35905 Mtetra
.742 .662 .771 r
.57202 .35905 .57556 .36637 .58219 .36087 .57867 .35363 Mtetra
.744 .665 .773 r
.57867 .35363 .58219 .36087 .58883 .35536 .58532 .3482 Mtetra
.745 .668 .775 r
.58532 .3482 .58883 .35536 .59547 .34985 .59197 .34278 Mtetra
.746 .671 .777 r
.59197 .34278 .59547 .34985 .60212 .34434 .59863 .33735 Mtetra
.748 .674 .779 r
.59863 .33735 .60212 .34434 .60877 .33882 .60528 .33192 Mtetra
.749 .677 .781 r
.60528 .33192 .60877 .33882 .61541 .33331 .61194 .32649 Mtetra
.751 .68 .783 r
.61194 .32649 .61541 .33331 .62207 .32779 .61861 .32106 Mtetra
.752 .683 .785 r
.61861 .32106 .62207 .32779 .62872 .32227 .62527 .31563 Mtetra
.754 .687 .786 r
.62527 .31563 .62872 .32227 .63538 .31675 .63194 .31019 Mtetra
.756 .69 .788 r
.63194 .31019 .63538 .31675 .64203 .31122 .63861 .30475 Mtetra
.757 .693 .791 r
.63861 .30475 .64203 .31122 .6487 .3057 .64529 .29931 Mtetra
.759 .697 .793 r
.64529 .29931 .6487 .3057 .65536 .30018 .65196 .29386 Mtetra
.76 .7 .795 r
.65196 .29386 .65536 .30018 .66203 .29464 .65864 .28842 Mtetra
.762 .704 .797 r
.65864 .28842 .66203 .29464 .66869 .28911 .66532 .28297 Mtetra
.764 .707 .799 r
.66532 .28297 .66869 .28911 .67536 .28358 .67201 .27752 Mtetra
.765 .711 .801 r
.67201 .27752 .67536 .28358 .68204 .27804 .6787 .27206 Mtetra
.767 .714 .803 r
.6787 .27206 .68204 .27804 .68871 .2725 .68539 .2666 Mtetra
.769 .718 .805 r
.68539 .2666 .68871 .2725 .69539 .26696 .69208 .26115 Mtetra
.77 .722 .807 r
.69208 .26115 .69539 .26696 .70207 .26142 .69878 .25568 Mtetra
.772 .726 .81 r
.69878 .25568 .70207 .26142 .70875 .25587 .70548 .25022 Mtetra
.774 .73 .812 r
.70548 .25022 .70875 .25587 .71544 .25032 .71218 .24475 Mtetra
.775 .734 .814 r
.71218 .24475 .71544 .25032 .72212 .24477 .71888 .23928 Mtetra
.777 .738 .816 r
.71888 .23928 .72212 .24477 .72881 .23922 .72559 .2338 Mtetra
.779 .742 .819 r
.72559 .2338 .72881 .23922 .7355 .23366 .7323 .22832 Mtetra
.781 .746 .821 r
.7323 .22832 .7355 .23366 .7422 .2281 .73901 .22284 Mtetra
.783 .75 .823 r
.73901 .22284 .7422 .2281 .74889 .22253 .74573 .21736 Mtetra
.784 .754 .826 r
.74573 .21736 .74889 .22253 .75559 .21696 .75245 .21186 Mtetra
.786 .759 .828 r
.75245 .21186 .75559 .21696 .76229 .21139 .75917 .20637 Mtetra
.788 .763 .831 r
.75917 .20637 .76229 .21139 .769 .20583 .76589 .20089 Mtetra
.789 .767 .833 r
.76589 .20089 .769 .20583 .7757 .20026 .77262 .1954 Mtetra
.79 .771 .836 r
.77262 .1954 .7757 .20026 .78241 .19473 .77935 .18994 Mtetra
.788 .775 .841 r
.77935 .18994 .78241 .19473 .78914 .18929 .7861 .18458 Mtetra
.784 .778 .847 r
.7861 .18458 .78914 .18929 .79588 .18404 .79286 .17939 Mtetra
.776 .779 .855 r
.79286 .17939 .79588 .18404 .80265 .17906 .79965 .17448 Mtetra
.471 .675 .954 r
.17553 .39007 .17946 .39373 .18485 .39379 .18093 .39006 Mtetra
.4 .639 .953 r
.18093 .39006 .18485 .39379 .19019 .39438 .18628 .39056 Mtetra
.376 .623 .949 r
.18628 .39056 .19019 .39438 .19554 .39515 .19164 .39125 Mtetra
.368 .613 .945 r
.19164 .39125 .19554 .39515 .2009 .39602 .19701 .39202 Mtetra
.366 .607 .941 r
.19701 .39202 .2009 .39602 .20627 .39694 .2024 .39285 Mtetra
.37 .603 .938 r
.2024 .39285 .20627 .39694 .21167 .39787 .2078 .39369 Mtetra
.376 .601 .935 r
.2078 .39369 .21167 .39787 .21709 .39881 .21323 .39453 Mtetra
.381 .598 .932 r
.21323 .39453 .21709 .39881 .22253 .39975 .21868 .39538 Mtetra
.386 .595 .928 r
.21868 .39538 .22253 .39975 .22799 .4007 .22415 .39623 Mtetra
.391 .592 .925 r
.22415 .39623 .22799 .4007 .23347 .40165 .22965 .39709 Mtetra
.397 .59 .921 r
.22965 .39709 .23347 .40165 .23898 .4026 .23516 .39794 Mtetra
.401 .587 .918 r
.23516 .39794 .23898 .4026 .2445 .40355 .2407 .3988 Mtetra
.405 .584 .914 r
.2407 .3988 .2445 .40355 .25005 .40451 .24626 .39966 Mtetra
.41 .582 .91 r
.24626 .39966 .25005 .40451 .25563 .40547 .25185 .40052 Mtetra
.413 .579 .907 r
.25185 .40052 .25563 .40547 .26122 .40643 .25745 .40138 Mtetra
.417 .576 .903 r
.25745 .40138 .26122 .40643 .26684 .4074 .26308 .40225 Mtetra
.421 .573 .899 r
.26308 .40225 .26684 .4074 .27249 .40837 .26873 .40313 Mtetra
.425 .57 .895 r
.26873 .40313 .27249 .40837 .27815 .40934 .2744 .404 Mtetra
.427 .567 .892 r
.2744 .404 .27815 .40934 .28384 .41032 .2801 .40488 Mtetra
.431 .565 .888 r
.2801 .40488 .28384 .41032 .28955 .4113 .28582 .40576 Mtetra
.434 .562 .884 r
.28582 .40576 .28955 .4113 .29529 .41228 .29157 .40664 Mtetra
.437 .559 .881 r
.29157 .40664 .29529 .41228 .30105 .41327 .29733 .40753 Mtetra
.439 .557 .877 r
.29733 .40753 .30105 .41327 .30683 .41426 .30312 .40842 Mtetra
.442 .554 .874 r
.30312 .40842 .30683 .41426 .31264 .41525 .30894 .40931 Mtetra
.445 .552 .87 r
.30894 .40931 .31264 .41525 .31847 .41625 .31478 .41021 Mtetra
.447 .549 .867 r
.31478 .41021 .31847 .41625 .32433 .41726 .32064 .41111 Mtetra
.45 .546 .863 r
.32064 .41111 .32433 .41726 .33021 .41827 .32653 .41201 Mtetra
.452 .544 .86 r
.32653 .41201 .33021 .41827 .33612 .41928 .33244 .41292 Mtetra
.454 .541 .856 r
.33244 .41292 .33612 .41928 .34205 .42029 .33838 .41383 Mtetra
.456 .539 .853 r
.33838 .41383 .34205 .42029 .348 .42132 .34434 .41475 Mtetra
.458 .536 .849 r
.34434 .41475 .348 .42132 .35398 .42234 .35032 .41567 Mtetra
.46 .534 .846 r
.35032 .41567 .35398 .42234 .35999 .42337 .35633 .4166 Mtetra
.462 .531 .843 r
.35633 .4166 .35999 .42337 .36602 .42441 .36237 .41753 Mtetra
.463 .529 .84 r
.36237 .41753 .36602 .42441 .37208 .42545 .36843 .41846 Mtetra
.465 .527 .837 r
.36843 .41846 .37208 .42545 .37816 .42649 .37452 .4194 Mtetra
.467 .524 .833 r
.37452 .4194 .37816 .42649 .38427 .42754 .38063 .42034 Mtetra
.468 .522 .83 r
.38063 .42034 .38427 .42754 .39041 .4286 .38677 .42129 Mtetra
.47 .52 .827 r
.38677 .42129 .39041 .4286 .39657 .42966 .39293 .42224 Mtetra
.471 .518 .824 r
.39293 .42224 .39657 .42966 .40275 .43073 .39912 .4232 Mtetra
.472 .516 .821 r
.39912 .4232 .40275 .43073 .40897 .4318 .40534 .42417 Mtetra
.474 .514 .818 r
.40534 .42417 .40897 .4318 .41521 .43288 .41158 .42514 Mtetra
.475 .512 .815 r
.41158 .42514 .41521 .43288 .42148 .43396 .41785 .42611 Mtetra
.476 .509 .813 r
.41785 .42611 .42148 .43396 .42777 .43506 .42415 .42709 Mtetra
.477 .507 .81 r
.42415 .42709 .42777 .43506 .4341 .43616 .43047 .42808 Mtetra
.479 .506 .807 r
.43047 .42808 .4341 .43616 .44045 .43725 .43682 .42906 Mtetra
.481 .504 .804 r
.43682 .42906 .44045 .43725 .44682 .43834 .4432 .43003 Mtetra
.484 .503 .802 r
.4432 .43003 .44682 .43834 .45323 .4394 .44961 .43098 Mtetra
.494 .506 .799 r
.44961 .43098 .45323 .4394 .45967 .44031 .45604 .43178 Mtetra
.512 .514 .795 r
.45604 .43178 .45967 .44031 .46614 .44089 .46251 .43226 Mtetra
.61 .566 .78 r
.46251 .43226 .46614 .44089 .47267 .43928 .46905 .43063 Mtetra
.707 .616 .752 r
.46905 .43063 .47267 .43928 .47927 .43444 .47565 .42586 Mtetra
.715 .621 .751 r
.47565 .42586 .47927 .43444 .48587 .4293 .48225 .4208 Mtetra
.721 .625 .751 r
.48225 .4208 .48587 .4293 .49248 .42398 .48887 .41557 Mtetra
.723 .628 .751 r
.48887 .41557 .49248 .42398 .4991 .41859 .49548 .41027 Mtetra
.725 .631 .753 r
.49548 .41027 .4991 .41859 .50571 .41319 .5021 .40496 Mtetra
.726 .633 .755 r
.5021 .40496 .50571 .41319 .51233 .40779 .50873 .39965 Mtetra
.728 .636 .756 r
.50873 .39965 .51233 .40779 .51895 .40237 .51536 .39432 Mtetra
.729 .639 .758 r
.51536 .39432 .51895 .40237 .52558 .39696 .52199 .389 Mtetra
.73 .641 .76 r
.52199 .389 .52558 .39696 .5322 .39155 .52862 .38367 Mtetra
.731 .644 .761 r
.52862 .38367 .5322 .39155 .53883 .38613 .53525 .37835 Mtetra
.733 .647 .763 r
.53525 .37835 .53883 .38613 .54547 .38072 .54189 .37302 Mtetra
.734 .649 .765 r
.54189 .37302 .54547 .38072 .5521 .3753 .54854 .36769 Mtetra
.735 .652 .767 r
.54854 .36769 .5521 .3753 .55874 .36989 .55518 .36236 Mtetra
.737 .655 .769 r
.55518 .36236 .55874 .36989 .56538 .36447 .56183 .35703 Mtetra
.738 .658 .77 r
.56183 .35703 .56538 .36447 .57202 .35905 .56848 .3517 Mtetra
.74 .661 .772 r
.56848 .3517 .57202 .35905 .57867 .35363 .57514 .34636 Mtetra
.741 .664 .774 r
.57514 .34636 .57867 .35363 .58532 .3482 .5818 .34103 Mtetra
.743 .667 .776 r
.5818 .34103 .58532 .3482 .59197 .34278 .58846 .33568 Mtetra
.744 .67 .778 r
.58846 .33568 .59197 .34278 .59863 .33735 .59512 .33035 Mtetra
.745 .673 .78 r
.59512 .33035 .59863 .33735 .60528 .33192 .60179 .325 Mtetra
.747 .676 .782 r
.60179 .325 .60528 .33192 .61194 .32649 .60846 .31966 Mtetra
.748 .679 .784 r
.60846 .31966 .61194 .32649 .61861 .32106 .61514 .31431 Mtetra
.75 .682 .786 r
.61514 .31431 .61861 .32106 .62527 .31563 .62181 .30896 Mtetra
.752 .686 .788 r
.62181 .30896 .62527 .31563 .63194 .31019 .62849 .30361 Mtetra
.753 .689 .79 r
.62849 .30361 .63194 .31019 .63861 .30475 .63518 .29825 Mtetra
.755 .692 .792 r
.63518 .29825 .63861 .30475 .64529 .29931 .64187 .29289 Mtetra
.756 .696 .794 r
.64187 .29289 .64529 .29931 .65196 .29386 .64856 .28753 Mtetra
.758 .699 .796 r
.64856 .28753 .65196 .29386 .65864 .28842 .65525 .28217 Mtetra
.759 .703 .798 r
.65525 .28217 .65864 .28842 .66532 .28297 .66195 .2768 Mtetra
.761 .706 .8 r
.66195 .2768 .66532 .28297 .67201 .27752 .66865 .27143 Mtetra
.763 .71 .802 r
.66865 .27143 .67201 .27752 .6787 .27206 .67535 .26606 Mtetra
.764 .713 .805 r
.67535 .26606 .6787 .27206 .68539 .2666 .68205 .26068 Mtetra
.766 .717 .807 r
.68205 .26068 .68539 .2666 .69208 .26115 .68876 .25531 Mtetra
.768 .721 .809 r
.68876 .25531 .69208 .26115 .69878 .25568 .69548 .24992 Mtetra
.769 .725 .811 r
.69548 .24992 .69878 .25568 .70548 .25022 .70219 .24454 Mtetra
.771 .729 .814 r
.70219 .24454 .70548 .25022 .71218 .24475 .70891 .23915 Mtetra
.773 .733 .816 r
.70891 .23915 .71218 .24475 .71888 .23928 .71563 .23376 Mtetra
.775 .737 .818 r
.71563 .23376 .71888 .23928 .72559 .2338 .72236 .22836 Mtetra
.776 .741 .82 r
.72236 .22836 .72559 .2338 .7323 .22832 .72909 .22296 Mtetra
.778 .745 .823 r
.72909 .22296 .7323 .22832 .73901 .22284 .73582 .21756 Mtetra
.78 .749 .825 r
.73582 .21756 .73901 .22284 .74573 .21736 .74255 .21216 Mtetra
.782 .753 .827 r
.74255 .21216 .74573 .21736 .75245 .21186 .74929 .20674 Mtetra
.783 .758 .83 r
.74929 .20674 .75245 .21186 .75917 .20637 .75603 .20133 Mtetra
.785 .762 .832 r
.75603 .20133 .75917 .20637 .76589 .20089 .76278 .19592 Mtetra
.787 .766 .835 r
.76278 .19592 .76589 .20089 .77262 .1954 .76952 .19051 Mtetra
.787 .771 .838 r
.76952 .19051 .77262 .1954 .77935 .18994 .77628 .18513 Mtetra
.786 .774 .843 r
.77628 .18513 .77935 .18994 .7861 .18458 .78304 .17985 Mtetra
.781 .777 .849 r
.78304 .17985 .7861 .18458 .79286 .17939 .78983 .17473 Mtetra
.773 .778 .857 r
.78983 .17473 .79286 .17939 .79965 .17448 .79664 .16987 Mtetra
.479 .679 .953 r
.17159 .38639 .17553 .39007 .18093 .39006 .17699 .38631 Mtetra
.412 .645 .953 r
.17699 .38631 .18093 .39006 .18628 .39056 .18236 .38673 Mtetra
.389 .629 .949 r
.18236 .38673 .18628 .39056 .19164 .39125 .18773 .38733 Mtetra
.381 .62 .946 r
.18773 .38733 .19164 .39125 .19701 .39202 .19311 .38801 Mtetra
.38 .614 .942 r
.19311 .38801 .19701 .39202 .2024 .39285 .19851 .38875 Mtetra
.383 .61 .939 r
.19851 .38875 .2024 .39285 .2078 .39369 .20393 .3895 Mtetra
.389 .607 .936 r
.20393 .3895 .2078 .39369 .21323 .39453 .20937 .39024 Mtetra
.394 .604 .932 r
.20937 .39024 .21323 .39453 .21868 .39538 .21483 .39099 Mtetra
.398 .601 .929 r
.21483 .39099 .21868 .39538 .22415 .39623 .22031 .39175 Mtetra
.403 .598 .925 r
.22031 .39175 .22415 .39623 .22965 .39709 .22581 .39251 Mtetra
.408 .596 .921 r
.22581 .39251 .22965 .39709 .23516 .39794 .23134 .39326 Mtetra
.412 .593 .918 r
.23134 .39326 .23516 .39794 .2407 .3988 .23689 .39403 Mtetra
.416 .59 .914 r
.23689 .39403 .2407 .3988 .24626 .39966 .24246 .39479 Mtetra
.421 .587 .91 r
.24246 .39479 .24626 .39966 .25185 .40052 .24805 .39555 Mtetra
.424 .584 .906 r
.24805 .39555 .25185 .40052 .25745 .40138 .25366 .39632 Mtetra
.427 .581 .903 r
.25366 .39632 .25745 .40138 .26308 .40225 .2593 .39709 Mtetra
.431 .578 .899 r
.2593 .39709 .26308 .40225 .26873 .40313 .26496 .39787 Mtetra
.434 .575 .895 r
.26496 .39787 .26873 .40313 .2744 .404 .27064 .39864 Mtetra
.437 .572 .892 r
.27064 .39864 .2744 .404 .2801 .40488 .27635 .39942 Mtetra
.44 .57 .888 r
.27635 .39942 .2801 .40488 .28582 .40576 .28208 .4002 Mtetra
.443 .567 .884 r
.28208 .4002 .28582 .40576 .29157 .40664 .28783 .40098 Mtetra
.446 .564 .881 r
.28783 .40098 .29157 .40664 .29733 .40753 .29361 .40177 Mtetra
.448 .561 .877 r
.29361 .40177 .29733 .40753 .30312 .40842 .2994 .40256 Mtetra
.451 .559 .873 r
.2994 .40256 .30312 .40842 .30894 .40931 .30523 .40335 Mtetra
.453 .556 .87 r
.30523 .40335 .30894 .40931 .31478 .41021 .31107 .40414 Mtetra
.455 .553 .866 r
.31107 .40414 .31478 .41021 .32064 .41111 .31694 .40494 Mtetra
.458 .551 .863 r
.31694 .40494 .32064 .41111 .32653 .41201 .32284 .40574 Mtetra
.46 .548 .859 r
.32284 .40574 .32653 .41201 .33244 .41292 .32875 .40655 Mtetra
.462 .545 .856 r
.32875 .40655 .33244 .41292 .33838 .41383 .33469 .40736 Mtetra
.464 .543 .852 r
.33469 .40736 .33838 .41383 .34434 .41475 .34066 .40817 Mtetra
.466 .54 .849 r
.34066 .40817 .34434 .41475 .35032 .41567 .34665 .40899 Mtetra
.467 .538 .846 r
.34665 .40899 .35032 .41567 .35633 .4166 .35267 .4098 Mtetra
.469 .535 .843 r
.35267 .4098 .35633 .4166 .36237 .41753 .35871 .41063 Mtetra
.471 .533 .839 r
.35871 .41063 .36237 .41753 .36843 .41846 .36477 .41146 Mtetra
.472 .531 .836 r
.36477 .41146 .36843 .41846 .37452 .4194 .37086 .41229 Mtetra
.474 .528 .833 r
.37086 .41229 .37452 .4194 .38063 .42034 .37698 .41312 Mtetra
.475 .526 .83 r
.37698 .41312 .38063 .42034 .38677 .42129 .38312 .41397 Mtetra
.477 .524 .827 r
.38312 .41397 .38677 .42129 .39293 .42224 .38929 .41481 Mtetra
.478 .521 .824 r
.38929 .41481 .39293 .42224 .39912 .4232 .39548 .41566 Mtetra
.479 .519 .821 r
.39548 .41566 .39912 .4232 .40534 .42417 .4017 .41651 Mtetra
.48 .517 .818 r
.4017 .41651 .40534 .42417 .41158 .42514 .40794 .41737 Mtetra
.482 .515 .815 r
.40794 .41737 .41158 .42514 .41785 .42611 .41422 .41823 Mtetra
.482 .513 .812 r
.41422 .41823 .41785 .42611 .42415 .42709 .42051 .4191 Mtetra
.483 .51 .81 r
.42051 .4191 .42415 .42709 .43047 .42808 .42684 .41998 Mtetra
.485 .509 .807 r
.42684 .41998 .43047 .42808 .43682 .42906 .43319 .42085 Mtetra
.487 .507 .804 r
.43319 .42085 .43682 .42906 .4432 .43003 .43957 .42171 Mtetra
.49 .506 .801 r
.43957 .42171 .4432 .43003 .44961 .43098 .44598 .42254 Mtetra
.499 .509 .798 r
.44598 .42254 .44961 .43098 .45604 .43178 .45241 .42324 Mtetra
.517 .517 .795 r
.45241 .42324 .45604 .43178 .46251 .43226 .45888 .42362 Mtetra
.61 .566 .78 r
.45888 .42362 .46251 .43226 .46905 .43063 .46542 .42196 Mtetra
.705 .615 .753 r
.46542 .42196 .46905 .43063 .47565 .42586 .47202 .41726 Mtetra
.713 .62 .752 r
.47202 .41726 .47565 .42586 .48225 .4208 .47863 .41229 Mtetra
.718 .624 .751 r
.47863 .41229 .48225 .4208 .48887 .41557 .48524 .40715 Mtetra
.721 .627 .752 r
.48524 .40715 .48887 .41557 .49548 .41027 .49187 .40193 Mtetra
.723 .63 .754 r
.49187 .40193 .49548 .41027 .5021 .40496 .49849 .39671 Mtetra
.724 .632 .756 r
.49849 .39671 .5021 .40496 .50873 .39965 .50512 .39149 Mtetra
.725 .635 .757 r
.50512 .39149 .50873 .39965 .51536 .39432 .51175 .38625 Mtetra
.727 .638 .759 r
.51175 .38625 .51536 .39432 .52199 .389 .51839 .38102 Mtetra
.728 .64 .761 r
.51839 .38102 .52199 .389 .52862 .38367 .52503 .37578 Mtetra
.729 .643 .762 r
.52503 .37578 .52862 .38367 .53525 .37835 .53167 .37054 Mtetra
.73 .646 .764 r
.53167 .37054 .53525 .37835 .54189 .37302 .53831 .3653 Mtetra
.732 .648 .766 r
.53831 .3653 .54189 .37302 .54854 .36769 .54496 .36006 Mtetra
.733 .651 .768 r
.54496 .36006 .54854 .36769 .55518 .36236 .55162 .35482 Mtetra
.735 .654 .77 r
.55162 .35482 .55518 .36236 .56183 .35703 .55827 .34958 Mtetra
.736 .657 .772 r
.55827 .34958 .56183 .35703 .56848 .3517 .56493 .34433 Mtetra
.737 .66 .773 r
.56493 .34433 .56848 .3517 .57514 .34636 .5716 .33908 Mtetra
.739 .663 .775 r
.5716 .33908 .57514 .34636 .5818 .34103 .57827 .33383 Mtetra
.74 .666 .777 r
.57827 .33383 .5818 .34103 .58846 .33568 .58494 .32857 Mtetra
.741 .669 .779 r
.58494 .32857 .58846 .33568 .59512 .33035 .59161 .32332 Mtetra
.743 .672 .781 r
.59161 .32332 .59512 .33035 .60179 .325 .59829 .31806 Mtetra
.744 .675 .783 r
.59829 .31806 .60179 .325 .60846 .31966 .60497 .3128 Mtetra
.746 .678 .785 r
.60497 .3128 .60846 .31966 .61514 .31431 .61166 .30754 Mtetra
.747 .681 .787 r
.61166 .30754 .61514 .31431 .62181 .30896 .61835 .30227 Mtetra
.749 .685 .789 r
.61835 .30227 .62181 .30896 .62849 .30361 .62504 .297 Mtetra
.751 .688 .791 r
.62504 .297 .62849 .30361 .63518 .29825 .63173 .29173 Mtetra
.752 .691 .793 r
.63173 .29173 .63518 .29825 .64187 .29289 .63843 .28646 Mtetra
.754 .695 .795 r
.63843 .28646 .64187 .29289 .64856 .28753 .64514 .28118 Mtetra
.755 .698 .797 r
.64514 .28118 .64856 .28753 .65525 .28217 .65184 .2759 Mtetra
.757 .702 .8 r
.65184 .2759 .65525 .28217 .66195 .2768 .65856 .27061 Mtetra
.758 .705 .802 r
.65856 .27061 .66195 .2768 .66865 .27143 .66527 .26533 Mtetra
.76 .709 .804 r
.66527 .26533 .66865 .27143 .67535 .26606 .67199 .26004 Mtetra
.762 .712 .806 r
.67199 .26004 .67535 .26606 .68205 .26068 .67871 .25474 Mtetra
.763 .716 .808 r
.67871 .25474 .68205 .26068 .68876 .25531 .68543 .24945 Mtetra
.765 .72 .811 r
.68543 .24945 .68876 .25531 .69548 .24992 .69216 .24414 Mtetra
.767 .724 .813 r
.69216 .24414 .69548 .24992 .70219 .24454 .69889 .23884 Mtetra
.768 .728 .815 r
.69889 .23884 .70219 .24454 .70891 .23915 .70563 .23353 Mtetra
.77 .732 .818 r
.70563 .23353 .70891 .23915 .71563 .23376 .71237 .22822 Mtetra
.772 .736 .82 r
.71237 .22822 .71563 .23376 .72236 .22836 .71911 .22291 Mtetra
.773 .74 .822 r
.71911 .22291 .72236 .22836 .72909 .22296 .72586 .21759 Mtetra
.775 .744 .825 r
.72586 .21759 .72909 .22296 .73582 .21756 .73261 .21227 Mtetra
.777 .748 .827 r
.73261 .21227 .73582 .21756 .74255 .21216 .73936 .20694 Mtetra
.779 .753 .829 r
.73936 .20694 .74255 .21216 .74929 .20674 .74612 .2016 Mtetra
.78 .757 .832 r
.74612 .2016 .74929 .20674 .75603 .20133 .75288 .19627 Mtetra
.782 .761 .834 r
.75288 .19627 .75603 .20133 .76278 .19592 .75965 .19094 Mtetra
.784 .766 .837 r
.75965 .19094 .76278 .19592 .76952 .19051 .76641 .18561 Mtetra
.784 .77 .84 r
.76641 .18561 .76952 .19051 .77628 .18513 .77319 .18031 Mtetra
.783 .773 .844 r
.77319 .18031 .77628 .18513 .78304 .17985 .77998 .1751 Mtetra
.779 .776 .85 r
.77998 .1751 .78304 .17985 .78983 .17473 .78678 .17004 Mtetra
.77 .777 .859 r
.78678 .17004 .78983 .17473 .79664 .16987 .79361 .16525 Mtetra
.487 .682 .952 r
.16762 .3827 .17159 .38639 .17699 .38631 .17304 .38255 Mtetra
.423 .65 .953 r
.17304 .38255 .17699 .38631 .18236 .38673 .17842 .38289 Mtetra
.402 .635 .95 r
.17842 .38289 .18236 .38673 .18773 .38733 .1838 .3834 Mtetra
.395 .626 .946 r
.1838 .3834 .18773 .38733 .19311 .38801 .18919 .38399 Mtetra
.393 .62 .943 r
.18919 .38399 .19311 .38801 .19851 .38875 .1946 .38463 Mtetra
.396 .616 .939 r
.1946 .38463 .19851 .38875 .20393 .3895 .20003 .38528 Mtetra
.402 .614 .936 r
.20003 .38528 .20393 .3895 .20937 .39024 .20548 .38594 Mtetra
.406 .61 .932 r
.20548 .38594 .20937 .39024 .21483 .39099 .21096 .38659 Mtetra
.41 .607 .929 r
.21096 .38659 .21483 .39099 .22031 .39175 .21645 .38725 Mtetra
.415 .604 .925 r
.21645 .38725 .22031 .39175 .22581 .39251 .22196 .38791 Mtetra
.42 .601 .921 r
.22196 .38791 .22581 .39251 .23134 .39326 .2275 .38857 Mtetra
.423 .598 .918 r
.2275 .38857 .23134 .39326 .23689 .39403 .23306 .38924 Mtetra
.427 .595 .914 r
.23306 .38924 .23689 .39403 .24246 .39479 .23864 .38991 Mtetra
.431 .592 .91 r
.23864 .38991 .24246 .39479 .24805 .39555 .24424 .39057 Mtetra
.434 .589 .906 r
.24424 .39057 .24805 .39555 .25366 .39632 .24987 .39124 Mtetra
.438 .586 .903 r
.24987 .39124 .25366 .39632 .2593 .39709 .25551 .39192 Mtetra
.441 .583 .899 r
.25551 .39192 .2593 .39709 .26496 .39787 .26118 .39259 Mtetra
.444 .58 .895 r
.26118 .39259 .26496 .39787 .27064 .39864 .26687 .39326 Mtetra
.447 .577 .891 r
.26687 .39326 .27064 .39864 .27635 .39942 .27259 .39394 Mtetra
.449 .574 .888 r
.27259 .39394 .27635 .39942 .28208 .4002 .27832 .39463 Mtetra
.452 .572 .884 r
.27832 .39463 .28208 .4002 .28783 .40098 .28408 .39531 Mtetra
.455 .569 .88 r
.28408 .39531 .28783 .40098 .29361 .40177 .28987 .39599 Mtetra
.457 .566 .877 r
.28987 .39599 .29361 .40177 .2994 .40256 .29567 .39668 Mtetra
.46 .563 .873 r
.29567 .39668 .2994 .40256 .30523 .40335 .3015 .39737 Mtetra
.462 .56 .869 r
.3015 .39737 .30523 .40335 .31107 .40414 .30736 .39806 Mtetra
.464 .557 .866 r
.30736 .39806 .31107 .40414 .31694 .40494 .31323 .39876 Mtetra
.466 .555 .862 r
.31323 .39876 .31694 .40494 .32284 .40574 .31913 .39946 Mtetra
.468 .552 .859 r
.31913 .39946 .32284 .40574 .32875 .40655 .32506 .40016 Mtetra
.469 .549 .856 r
.32506 .40016 .32875 .40655 .33469 .40736 .331 .40087 Mtetra
.471 .547 .852 r
.331 .40087 .33469 .40736 .34066 .40817 .33697 .40158 Mtetra
.473 .544 .849 r
.33697 .40158 .34066 .40817 .34665 .40899 .34297 .40229 Mtetra
.475 .542 .846 r
.34297 .40229 .34665 .40899 .35267 .4098 .34899 .403 Mtetra
.476 .539 .842 r
.34899 .403 .35267 .4098 .35871 .41063 .35504 .40372 Mtetra
.478 .537 .839 r
.35504 .40372 .35871 .41063 .36477 .41146 .36111 .40444 Mtetra
.479 .534 .836 r
.36111 .40444 .36477 .41146 .37086 .41229 .3672 .40516 Mtetra
.48 .532 .833 r
.3672 .40516 .37086 .41229 .37698 .41312 .37332 .40589 Mtetra
.482 .53 .83 r
.37332 .40589 .37698 .41312 .38312 .41397 .37947 .40663 Mtetra
.483 .527 .827 r
.37947 .40663 .38312 .41397 .38929 .41481 .38564 .40736 Mtetra
.484 .525 .824 r
.38564 .40736 .38929 .41481 .39548 .41566 .39183 .4081 Mtetra
.485 .523 .821 r
.39183 .4081 .39548 .41566 .4017 .41651 .39805 .40885 Mtetra
.486 .521 .818 r
.39805 .40885 .4017 .41651 .40794 .41737 .4043 .4096 Mtetra
.488 .518 .815 r
.4043 .4096 .40794 .41737 .41422 .41823 .41057 .41035 Mtetra
.488 .516 .812 r
.41057 .41035 .41422 .41823 .42051 .4191 .41687 .4111 Mtetra
.489 .514 .809 r
.41687 .4111 .42051 .4191 .42684 .41998 .4232 .41187 Mtetra
.491 .512 .807 r
.4232 .41187 .42684 .41998 .43319 .42085 .42955 .41263 Mtetra
.493 .511 .804 r
.42955 .41263 .43319 .42085 .43957 .42171 .43593 .41338 Mtetra
.495 .51 .801 r
.43593 .41338 .43957 .42171 .44598 .42254 .44234 .4141 Mtetra
.504 .512 .798 r
.44234 .4141 .44598 .42254 .45241 .42324 .44878 .41469 Mtetra
.521 .519 .795 r
.44878 .41469 .45241 .42324 .45888 .42362 .45525 .41498 Mtetra
.611 .567 .78 r
.45525 .41498 .45888 .42362 .46542 .42196 .46178 .41328 Mtetra
.703 .614 .754 r
.46178 .41328 .46542 .42196 .47202 .41726 .46838 .40866 Mtetra
.711 .619 .753 r
.46838 .40866 .47202 .41726 .47863 .41229 .475 .40377 Mtetra
.716 .623 .752 r
.475 .40377 .47863 .41229 .48524 .40715 .48162 .39871 Mtetra
.719 .626 .753 r
.48162 .39871 .48524 .40715 .49187 .40193 .48824 .39359 Mtetra
.72 .629 .755 r
.48824 .39359 .49187 .40193 .49849 .39671 .49487 .38846 Mtetra
.722 .631 .757 r
.49487 .38846 .49849 .39671 .50512 .39149 .5015 .38332 Mtetra
.723 .634 .758 r
.5015 .38332 .50512 .39149 .51175 .38625 .50814 .37817 Mtetra
.724 .637 .76 r
.50814 .37817 .51175 .38625 .51839 .38102 .51478 .37302 Mtetra
.725 .639 .762 r
.51478 .37302 .51839 .38102 .52503 .37578 .52142 .36788 Mtetra
.727 .642 .764 r
.52142 .36788 .52503 .37578 .53167 .37054 .52807 .36273 Mtetra
.728 .645 .765 r
.52807 .36273 .53167 .37054 .53831 .3653 .53473 .35757 Mtetra
.729 .647 .767 r
.53473 .35757 .53831 .3653 .54496 .36006 .54138 .35242 Mtetra
.731 .65 .769 r
.54138 .35242 .54496 .36006 .55162 .35482 .54804 .34727 Mtetra
.732 .653 .771 r
.54804 .34727 .55162 .35482 .55827 .34958 .55471 .34211 Mtetra
.733 .656 .773 r
.55471 .34211 .55827 .34958 .56493 .34433 .56138 .33695 Mtetra
.735 .659 .775 r
.56138 .33695 .56493 .34433 .5716 .33908 .56805 .33178 Mtetra
.736 .662 .777 r
.56805 .33178 .5716 .33908 .57827 .33383 .57472 .32662 Mtetra
.738 .665 .778 r
.57472 .32662 .57827 .33383 .58494 .32857 .5814 .32145 Mtetra
.739 .668 .78 r
.5814 .32145 .58494 .32857 .59161 .32332 .58809 .31628 Mtetra
.74 .671 .782 r
.58809 .31628 .59161 .32332 .59829 .31806 .59478 .31111 Mtetra
.742 .674 .784 r
.59478 .31111 .59829 .31806 .60497 .3128 .60147 .30593 Mtetra
.743 .677 .786 r
.60147 .30593 .60497 .3128 .61166 .30754 .60817 .30075 Mtetra
.745 .68 .788 r
.60817 .30075 .61166 .30754 .61835 .30227 .61487 .29557 Mtetra
.746 .684 .79 r
.61487 .29557 .61835 .30227 .62504 .297 .62157 .29038 Mtetra
.748 .687 .793 r
.62157 .29038 .62504 .297 .63173 .29173 .62828 .28519 Mtetra
.749 .69 .795 r
.62828 .28519 .63173 .29173 .63843 .28646 .63499 .28 Mtetra
.751 .694 .797 r
.63499 .28 .63843 .28646 .64514 .28118 .64171 .27481 Mtetra
.753 .697 .799 r
.64171 .27481 .64514 .28118 .65184 .2759 .64843 .26961 Mtetra
.754 .701 .801 r
.64843 .26961 .65184 .2759 .65856 .27061 .65515 .26441 Mtetra
.756 .704 .803 r
.65515 .26441 .65856 .27061 .66527 .26533 .66188 .2592 Mtetra
.757 .708 .805 r
.66188 .2592 .66527 .26533 .67199 .26004 .66861 .25399 Mtetra
.759 .712 .808 r
.66861 .25399 .67199 .26004 .67871 .25474 .67535 .24878 Mtetra
.761 .715 .81 r
.67535 .24878 .67871 .25474 .68543 .24945 .68209 .24357 Mtetra
.762 .719 .812 r
.68209 .24357 .68543 .24945 .69216 .24414 .68884 .23835 Mtetra
.764 .723 .814 r
.68884 .23835 .69216 .24414 .69889 .23884 .69558 .23312 Mtetra
.766 .727 .817 r
.69558 .23312 .69889 .23884 .70563 .23353 .70234 .22789 Mtetra
.767 .731 .819 r
.70234 .22789 .70563 .23353 .71237 .22822 .70909 .22267 Mtetra
.769 .735 .821 r
.70909 .22267 .71237 .22822 .71911 .22291 .71585 .21743 Mtetra
.771 .739 .824 r
.71585 .21743 .71911 .22291 .72586 .21759 .72262 .21219 Mtetra
.772 .743 .826 r
.72262 .21219 .72586 .21759 .73261 .21227 .72939 .20695 Mtetra
.774 .747 .829 r
.72939 .20695 .73261 .21227 .73936 .20694 .73616 .2017 Mtetra
.776 .752 .831 r
.73616 .2017 .73936 .20694 .74612 .2016 .74294 .19644 Mtetra
.777 .756 .834 r
.74294 .19644 .74612 .2016 .75288 .19627 .74972 .19119 Mtetra
.779 .76 .836 r
.74972 .19119 .75288 .19627 .75965 .19094 .7565 .18594 Mtetra
.781 .765 .839 r
.7565 .18594 .75965 .19094 .76641 .18561 .76329 .18068 Mtetra
.781 .769 .842 r
.76329 .18068 .76641 .18561 .77319 .18031 .77009 .17546 Mtetra
.78 .772 .846 r
.77009 .17546 .77319 .18031 .77998 .1751 .77689 .17032 Mtetra
.776 .775 .852 r
.77689 .17032 .77998 .1751 .78678 .17004 .78372 .16534 Mtetra
.768 .776 .86 r
.78372 .16534 .78678 .17004 .79361 .16525 .79057 .1606 Mtetra
.495 .685 .951 r
.16364 .37899 .16762 .3827 .17304 .38255 .16907 .37878 Mtetra
.435 .655 .953 r
.16907 .37878 .17304 .38255 .17842 .38289 .17446 .37903 Mtetra
.415 .641 .95 r
.17446 .37903 .17842 .38289 .1838 .3834 .17986 .37945 Mtetra
.408 .632 .946 r
.17986 .37945 .1838 .3834 .18919 .38399 .18526 .37995 Mtetra
.406 .626 .943 r
.18526 .37995 .18919 .38399 .1946 .38463 .19068 .3805 Mtetra
.409 .622 .94 r
.19068 .3805 .1946 .38463 .20003 .38528 .19613 .38106 Mtetra
.414 .62 .936 r
.19613 .38106 .20003 .38528 .20548 .38594 .20159 .38161 Mtetra
.418 .616 .932 r
.20159 .38161 .20548 .38594 .21096 .38659 .20707 .38217 Mtetra
.422 .613 .929 r
.20707 .38217 .21096 .38659 .21645 .38725 .21258 .38274 Mtetra
.427 .61 .925 r
.21258 .38274 .21645 .38725 .22196 .38791 .2181 .3833 Mtetra
.431 .607 .921 r
.2181 .3833 .22196 .38791 .2275 .38857 .22365 .38387 Mtetra
.434 .603 .917 r
.22365 .38387 .2275 .38857 .23306 .38924 .22922 .38444 Mtetra
.438 .6 .914 r
.22922 .38444 .23306 .38924 .23864 .38991 .23481 .38501 Mtetra
.442 .597 .91 r
.23481 .38501 .23864 .38991 .24424 .39057 .24042 .38558 Mtetra
.445 .594 .906 r
.24042 .38558 .24424 .39057 .24987 .39124 .24605 .38615 Mtetra
.447 .591 .902 r
.24605 .38615 .24987 .39124 .25551 .39192 .25171 .38672 Mtetra
.451 .588 .898 r
.25171 .38672 .25551 .39192 .26118 .39259 .25739 .3873 Mtetra
.454 .585 .895 r
.25739 .3873 .26118 .39259 .26687 .39326 .26309 .38787 Mtetra
.456 .582 .891 r
.26309 .38787 .26687 .39326 .27259 .39394 .26881 .38845 Mtetra
.459 .579 .887 r
.26881 .38845 .27259 .39394 .27832 .39463 .27456 .38904 Mtetra
.461 .576 .884 r
.27456 .38904 .27832 .39463 .28408 .39531 .28033 .38962 Mtetra
.463 .573 .88 r
.28033 .38962 .28408 .39531 .28987 .39599 .28612 .3902 Mtetra
.465 .57 .876 r
.28612 .3902 .28987 .39599 .29567 .39668 .29193 .39079 Mtetra
.468 .567 .873 r
.29193 .39079 .29567 .39668 .3015 .39737 .29777 .39138 Mtetra
.47 .565 .869 r
.29777 .39138 .3015 .39737 .30736 .39806 .30363 .39197 Mtetra
.472 .562 .866 r
.30363 .39197 .30736 .39806 .31323 .39876 .30951 .39256 Mtetra
.474 .559 .862 r
.30951 .39256 .31323 .39876 .31913 .39946 .31542 .39316 Mtetra
.475 .556 .859 r
.31542 .39316 .31913 .39946 .32506 .40016 .32135 .39376 Mtetra
.477 .553 .855 r
.32135 .39376 .32506 .40016 .331 .40087 .3273 .39436 Mtetra
.479 .551 .852 r
.3273 .39436 .331 .40087 .33697 .40158 .33328 .39496 Mtetra
.48 .548 .848 r
.33328 .39496 .33697 .40158 .34297 .40229 .33928 .39557 Mtetra
.482 .546 .845 r
.33928 .39557 .34297 .40229 .34899 .403 .34531 .39618 Mtetra
.483 .543 .842 r
.34531 .39618 .34899 .403 .35504 .40372 .35136 .39679 Mtetra
.484 .541 .839 r
.35136 .39679 .35504 .40372 .36111 .40444 .35743 .39741 Mtetra
.486 .538 .836 r
.35743 .39741 .36111 .40444 .3672 .40516 .36353 .39802 Mtetra
.487 .536 .833 r
.36353 .39802 .3672 .40516 .37332 .40589 .36965 .39865 Mtetra
.488 .533 .829 r
.36965 .39865 .37332 .40589 .37947 .40663 .3758 .39927 Mtetra
.49 .531 .826 r
.3758 .39927 .37947 .40663 .38564 .40736 .38198 .3999 Mtetra
.491 .529 .823 r
.38198 .3999 .38564 .40736 .39183 .4081 .38818 .40053 Mtetra
.491 .526 .82 r
.38818 .40053 .39183 .4081 .39805 .40885 .3944 .40117 Mtetra
.493 .524 .818 r
.3944 .40117 .39805 .40885 .4043 .4096 .40065 .40181 Mtetra
.494 .522 .815 r
.40065 .40181 .4043 .4096 .41057 .41035 .40693 .40244 Mtetra
.494 .519 .812 r
.40693 .40244 .41057 .41035 .41687 .4111 .41323 .40309 Mtetra
.495 .517 .809 r
.41323 .40309 .41687 .4111 .4232 .41187 .41955 .40375 Mtetra
.497 .515 .806 r
.41955 .40375 .4232 .41187 .42955 .41263 .42591 .40439 Mtetra
.498 .514 .804 r
.42591 .40439 .42955 .41263 .43593 .41338 .43229 .40503 Mtetra
.501 .513 .801 r
.43229 .40503 .43593 .41338 .44234 .4141 .43869 .40564 Mtetra
.509 .515 .798 r
.43869 .40564 .44234 .4141 .44878 .41469 .44513 .40612 Mtetra
.525 .522 .794 r
.44513 .40612 .44878 .41469 .45525 .41498 .4516 .40631 Mtetra
.611 .567 .78 r
.4516 .40631 .45525 .41498 .46178 .41328 .45814 .40459 Mtetra
.701 .613 .754 r
.45814 .40459 .46178 .41328 .46838 .40866 .46474 .40004 Mtetra
.709 .618 .753 r
.46474 .40004 .46838 .40866 .475 .40377 .47136 .39523 Mtetra
.714 .622 .753 r
.47136 .39523 .475 .40377 .48162 .39871 .47798 .39026 Mtetra
.717 .625 .754 r
.47798 .39026 .48162 .39871 .48824 .39359 .48461 .38523 Mtetra
.718 .628 .756 r
.48461 .38523 .48824 .39359 .49487 .38846 .49124 .38018 Mtetra
.719 .63 .758 r
.49124 .38018 .49487 .38846 .5015 .38332 .49788 .37513 Mtetra
.721 .633 .759 r
.49788 .37513 .5015 .38332 .50814 .37817 .50452 .37007 Mtetra
.722 .636 .761 r
.50452 .37007 .50814 .37817 .51478 .37302 .51117 .36501 Mtetra
.723 .638 .763 r
.51117 .36501 .51478 .37302 .52142 .36788 .51782 .35996 Mtetra
.724 .641 .765 r
.51782 .35996 .52142 .36788 .52807 .36273 .52447 .35489 Mtetra
.726 .644 .766 r
.52447 .35489 .52807 .36273 .53473 .35757 .53113 .34983 Mtetra
.727 .646 .768 r
.53113 .34983 .53473 .35757 .54138 .35242 .53779 .34476 Mtetra
.728 .649 .77 r
.53779 .34476 .54138 .35242 .54804 .34727 .54446 .33969 Mtetra
.73 .652 .772 r
.54446 .33969 .54804 .34727 .55471 .34211 .55113 .33462 Mtetra
.731 .655 .774 r
.55113 .33462 .55471 .34211 .56138 .33695 .55781 .32954 Mtetra
.732 .658 .776 r
.55781 .32954 .56138 .33695 .56805 .33178 .56449 .32447 Mtetra
.734 .661 .778 r
.56449 .32447 .56805 .33178 .57472 .32662 .57117 .31939 Mtetra
.735 .664 .78 r
.57117 .31939 .57472 .32662 .5814 .32145 .57786 .3143 Mtetra
.736 .667 .782 r
.57786 .3143 .5814 .32145 .58809 .31628 .58456 .30922 Mtetra
.738 .67 .784 r
.58456 .30922 .58809 .31628 .59478 .31111 .59126 .30413 Mtetra
.739 .673 .786 r
.59126 .30413 .59478 .31111 .60147 .30593 .59796 .29904 Mtetra
.741 .676 .788 r
.59796 .29904 .60147 .30593 .60817 .30075 .60467 .29394 Mtetra
.742 .679 .79 r
.60467 .29394 .60817 .30075 .61487 .29557 .61138 .28884 Mtetra
.744 .683 .792 r
.61138 .28884 .61487 .29557 .62157 .29038 .61809 .28374 Mtetra
.745 .686 .794 r
.61809 .28374 .62157 .29038 .62828 .28519 .62481 .27863 Mtetra
.747 .689 .796 r
.62481 .27863 .62828 .28519 .63499 .28 .63154 .27353 Mtetra
.748 .693 .798 r
.63154 .27353 .63499 .28 .64171 .27481 .63827 .26841 Mtetra
.75 .696 .8 r
.63827 .26841 .64171 .27481 .64843 .26961 .645 .2633 Mtetra
.751 .7 .803 r
.645 .2633 .64843 .26961 .65515 .26441 .65174 .25818 Mtetra
.753 .703 .805 r
.65174 .25818 .65515 .26441 .66188 .2592 .65848 .25306 Mtetra
.755 .707 .807 r
.65848 .25306 .66188 .2592 .66861 .25399 .66523 .24793 Mtetra
.756 .711 .809 r
.66523 .24793 .66861 .25399 .67535 .24878 .67198 .2428 Mtetra
.758 .714 .812 r
.67198 .2428 .67535 .24878 .68209 .24357 .67874 .23766 Mtetra
.759 .718 .814 r
.67874 .23766 .68209 .24357 .68884 .23835 .6855 .23253 Mtetra
.761 .722 .816 r
.6855 .23253 .68884 .23835 .69558 .23312 .69226 .22738 Mtetra
.763 .726 .819 r
.69226 .22738 .69558 .23312 .70234 .22789 .69903 .22224 Mtetra
.764 .73 .821 r
.69903 .22224 .70234 .22789 .70909 .22267 .70581 .21709 Mtetra
.766 .734 .823 r
.70581 .21709 .70909 .22267 .71585 .21743 .71258 .21193 Mtetra
.768 .738 .826 r
.71258 .21193 .71585 .21743 .72262 .21219 .71937 .20677 Mtetra
.769 .742 .828 r
.71937 .20677 .72262 .21219 .72939 .20695 .72615 .20161 Mtetra
.771 .746 .83 r
.72615 .20161 .72939 .20695 .73616 .2017 .73294 .19644 Mtetra
.773 .751 .833 r
.73294 .19644 .73616 .2017 .74294 .19644 .73974 .19126 Mtetra
.774 .755 .835 r
.73974 .19126 .74294 .19644 .74972 .19119 .74654 .18609 Mtetra
.776 .759 .838 r
.74654 .18609 .74972 .19119 .7565 .18594 .75335 .18092 Mtetra
.778 .764 .841 r
.75335 .18092 .7565 .18594 .76329 .18068 .76016 .17574 Mtetra
.778 .768 .844 r
.76016 .17574 .76329 .18068 .77009 .17546 .76697 .17059 Mtetra
.777 .772 .848 r
.76697 .17059 .77009 .17546 .77689 .17032 .7738 .16552 Mtetra
.773 .774 .854 r
.7738 .16552 .77689 .17032 .78372 .16534 .78065 .16061 Mtetra
.765 .776 .862 r
.78065 .16061 .78372 .16534 .79057 .1606 .78752 .15593 Mtetra
.503 .688 .951 r
.15965 .37526 .16364 .37899 .16907 .37878 .16509 .37499 Mtetra
.446 .66 .952 r
.16509 .37499 .16907 .37878 .17446 .37903 .17049 .37516 Mtetra
.427 .647 .95 r
.17049 .37516 .17446 .37903 .17986 .37945 .1759 .37549 Mtetra
.42 .638 .947 r
.1759 .37549 .17986 .37945 .18526 .37995 .18132 .37589 Mtetra
.419 .632 .943 r
.18132 .37589 .18526 .37995 .19068 .3805 .18675 .37635 Mtetra
.421 .628 .94 r
.18675 .37635 .19068 .3805 .19613 .38106 .1922 .37681 Mtetra
.426 .625 .936 r
.1922 .37681 .19613 .38106 .20159 .38161 .19768 .37727 Mtetra
.43 .622 .932 r
.19768 .37727 .20159 .38161 .20707 .38217 .20317 .37774 Mtetra
.434 .618 .928 r
.20317 .37774 .20707 .38217 .21258 .38274 .20869 .37821 Mtetra
.438 .615 .925 r
.20869 .37821 .21258 .38274 .2181 .3833 .21423 .37868 Mtetra
.442 .612 .921 r
.21423 .37868 .2181 .3833 .22365 .38387 .21978 .37914 Mtetra
.445 .609 .917 r
.21978 .37914 .22365 .38387 .22922 .38444 .22536 .37962 Mtetra
.448 .605 .913 r
.22536 .37962 .22922 .38444 .23481 .38501 .23096 .38009 Mtetra
.452 .602 .909 r
.23096 .38009 .23481 .38501 .24042 .38558 .23659 .38056 Mtetra
.455 .599 .906 r
.23659 .38056 .24042 .38558 .24605 .38615 .24223 .38103 Mtetra
.457 .596 .902 r
.24223 .38103 .24605 .38615 .25171 .38672 .2479 .38151 Mtetra
.46 .593 .898 r
.2479 .38151 .25171 .38672 .25739 .3873 .25358 .38199 Mtetra
.463 .59 .894 r
.25358 .38199 .25739 .3873 .26309 .38787 .25929 .38246 Mtetra
.465 .586 .89 r
.25929 .38246 .26309 .38787 .26881 .38845 .26503 .38294 Mtetra
.467 .583 .887 r
.26503 .38294 .26881 .38845 .27456 .38904 .27078 .38343 Mtetra
.47 .58 .883 r
.27078 .38343 .27456 .38904 .28033 .38962 .27656 .38391 Mtetra
.472 .577 .879 r
.27656 .38391 .28033 .38962 .28612 .3902 .28236 .38439 Mtetra
.474 .574 .876 r
.28236 .38439 .28612 .3902 .29193 .39079 .28818 .38488 Mtetra
.476 .571 .872 r
.28818 .38488 .29193 .39079 .29777 .39138 .29402 .38536 Mtetra
.478 .569 .868 r
.29402 .38536 .29777 .39138 .30363 .39197 .29989 .38585 Mtetra
.479 .566 .865 r
.29989 .38585 .30363 .39197 .30951 .39256 .30578 .38634 Mtetra
.481 .563 .861 r
.30578 .38634 .30951 .39256 .31542 .39316 .31169 .38684 Mtetra
.483 .56 .858 r
.31169 .38684 .31542 .39316 .32135 .39376 .31763 .38733 Mtetra
.484 .557 .855 r
.31763 .38733 .32135 .39376 .3273 .39436 .32359 .38783 Mtetra
.486 .554 .851 r
.32359 .38783 .3273 .39436 .33328 .39496 .32957 .38833 Mtetra
.488 .552 .848 r
.32957 .38833 .33328 .39496 .33928 .39557 .33558 .38883 Mtetra
.489 .549 .845 r
.33558 .38883 .33928 .39557 .34531 .39618 .34161 .38934 Mtetra
.49 .547 .841 r
.34161 .38934 .34531 .39618 .35136 .39679 .34767 .38984 Mtetra
.491 .544 .838 r
.34767 .38984 .35136 .39679 .35743 .39741 .35375 .39035 Mtetra
.493 .542 .835 r
.35375 .39035 .35743 .39741 .36353 .39802 .35985 .39086 Mtetra
.494 .539 .832 r
.35985 .39086 .36353 .39802 .36965 .39865 .36598 .39138 Mtetra
.495 .537 .829 r
.36598 .39138 .36965 .39865 .3758 .39927 .37213 .3919 Mtetra
.496 .534 .826 r
.37213 .3919 .3758 .39927 .38198 .3999 .37831 .39242 Mtetra
.497 .532 .823 r
.37831 .39242 .38198 .3999 .38818 .40053 .38451 .39294 Mtetra
.498 .529 .82 r
.38451 .39294 .38818 .40053 .3944 .40117 .39074 .39347 Mtetra
.499 .527 .817 r
.39074 .39347 .3944 .40117 .40065 .40181 .39699 .39399 Mtetra
.5 .525 .814 r
.39699 .39399 .40065 .40181 .40693 .40244 .40327 .39452 Mtetra
.5 .523 .811 r
.40327 .39452 .40693 .40244 .41323 .40309 .40957 .39506 Mtetra
.501 .52 .809 r
.40957 .39506 .41323 .40309 .41955 .40375 .4159 .3956 Mtetra
.502 .519 .806 r
.4159 .3956 .41955 .40375 .42591 .40439 .42226 .39614 Mtetra
.504 .517 .803 r
.42226 .39614 .42591 .40439 .43229 .40503 .42864 .39666 Mtetra
.506 .516 .8 r
.42864 .39666 .43229 .40503 .43869 .40564 .43505 .39716 Mtetra
.514 .518 .797 r
.43505 .39716 .43869 .40564 .44513 .40612 .44148 .39754 Mtetra
.529 .524 .794 r
.44148 .39754 .44513 .40612 .4516 .40631 .44795 .39763 Mtetra
.612 .567 .78 r
.44795 .39763 .4516 .40631 .45814 .40459 .45449 .39588 Mtetra
.699 .612 .755 r
.45449 .39588 .45814 .40459 .46474 .40004 .4611 .3914 Mtetra
.707 .617 .754 r
.4611 .3914 .46474 .40004 .47136 .39523 .46771 .38667 Mtetra
.711 .621 .754 r
.46771 .38667 .47136 .39523 .47798 .39026 .47434 .38179 Mtetra
.714 .624 .755 r
.47434 .38179 .47798 .39026 .48461 .38523 .48097 .37684 Mtetra
.715 .626 .757 r
.48097 .37684 .48461 .38523 .49124 .38018 .48761 .37189 Mtetra
.717 .629 .759 r
.48761 .37189 .49124 .38018 .49788 .37513 .49425 .36693 Mtetra
.718 .632 .76 r
.49425 .36693 .49788 .37513 .50452 .37007 .50089 .36196 Mtetra
.719 .634 .762 r
.50089 .36196 .50452 .37007 .51117 .36501 .50755 .35699 Mtetra
.721 .637 .764 r
.50755 .35699 .51117 .36501 .51782 .35996 .5142 .35202 Mtetra
.722 .64 .766 r
.5142 .35202 .51782 .35996 .52447 .35489 .52086 .34704 Mtetra
.723 .642 .767 r
.52086 .34704 .52447 .35489 .53113 .34983 .52753 .34206 Mtetra
.724 .645 .769 r
.52753 .34206 .53113 .34983 .53779 .34476 .5342 .33708 Mtetra
.726 .648 .771 r
.5342 .33708 .53779 .34476 .54446 .33969 .54087 .3321 Mtetra
.727 .651 .773 r
.54087 .3321 .54446 .33969 .55113 .33462 .54755 .32711 Mtetra
.728 .654 .775 r
.54755 .32711 .55113 .33462 .55781 .32954 .55423 .32212 Mtetra
.73 .656 .777 r
.55423 .32212 .55781 .32954 .56449 .32447 .56092 .31713 Mtetra
.731 .659 .779 r
.56092 .31713 .56449 .32447 .57117 .31939 .56762 .31214 Mtetra
.733 .662 .781 r
.56762 .31214 .57117 .31939 .57786 .3143 .57431 .30714 Mtetra
.734 .665 .783 r
.57431 .30714 .57786 .3143 .58456 .30922 .58102 .30214 Mtetra
.735 .669 .785 r
.58102 .30214 .58456 .30922 .59126 .30413 .58773 .29713 Mtetra
.737 .672 .787 r
.58773 .29713 .59126 .30413 .59796 .29904 .59444 .29212 Mtetra
.738 .675 .789 r
.59444 .29212 .59796 .29904 .60467 .29394 .60116 .28711 Mtetra
.74 .678 .791 r
.60116 .28711 .60467 .29394 .61138 .28884 .60788 .2821 Mtetra
.741 .681 .793 r
.60788 .2821 .61138 .28884 .61809 .28374 .61461 .27708 Mtetra
.743 .685 .795 r
.61461 .27708 .61809 .28374 .62481 .27863 .62134 .27205 Mtetra
.744 .688 .797 r
.62134 .27205 .62481 .27863 .63154 .27353 .62808 .26703 Mtetra
.746 .692 .8 r
.62808 .26703 .63154 .27353 .63827 .26841 .63482 .262 Mtetra
.747 .695 .802 r
.63482 .262 .63827 .26841 .645 .2633 .64156 .25697 Mtetra
.749 .699 .804 r
.64156 .25697 .645 .2633 .65174 .25818 .64832 .25193 Mtetra
.75 .702 .806 r
.64832 .25193 .65174 .25818 .65848 .25306 .65507 .24689 Mtetra
.752 .706 .808 r
.65507 .24689 .65848 .25306 .66523 .24793 .66183 .24184 Mtetra
.753 .71 .811 r
.66183 .24184 .66523 .24793 .67198 .2428 .6686 .23679 Mtetra
.755 .713 .813 r
.6686 .23679 .67198 .2428 .67874 .23766 .67537 .23174 Mtetra
.757 .717 .815 r
.67537 .23174 .67874 .23766 .6855 .23253 .68215 .22668 Mtetra
.758 .721 .818 r
.68215 .22668 .6855 .23253 .69226 .22738 .68893 .22162 Mtetra
.76 .725 .82 r
.68893 .22162 .69226 .22738 .69903 .22224 .69571 .21655 Mtetra
.761 .729 .823 r
.69571 .21655 .69903 .22224 .70581 .21709 .70251 .21149 Mtetra
.763 .733 .825 r
.70251 .21149 .70581 .21709 .71258 .21193 .7093 .20641 Mtetra
.765 .737 .827 r
.7093 .20641 .71258 .21193 .71937 .20677 .7161 .20133 Mtetra
.766 .741 .83 r
.7161 .20133 .71937 .20677 .72615 .20161 .72291 .19625 Mtetra
.768 .745 .832 r
.72291 .19625 .72615 .20161 .73294 .19644 .72972 .19116 Mtetra
.77 .75 .835 r
.72972 .19116 .73294 .19644 .73974 .19126 .73653 .18606 Mtetra
.771 .754 .837 r
.73653 .18606 .73974 .19126 .74654 .18609 .74335 .18097 Mtetra
.773 .758 .84 r
.74335 .18097 .74654 .18609 .75335 .18092 .75018 .17587 Mtetra
.774 .763 .842 r
.75018 .17587 .75335 .18092 .76016 .17574 .75701 .17077 Mtetra
.775 .767 .846 r
.75701 .17077 .76016 .17574 .76697 .17059 .76384 .1657 Mtetra
.774 .771 .85 r
.76384 .1657 .76697 .17059 .7738 .16552 .77069 .16071 Mtetra
.77 .773 .856 r
.77069 .16071 .7738 .16552 .78065 .16061 .77756 .15586 Mtetra
.762 .775 .863 r
.77756 .15586 .78065 .16061 .78752 .15593 .78446 .15125 Mtetra
.51 .691 .95 r
.15564 .37153 .15965 .37526 .16509 .37499 .16109 .37118 Mtetra
.457 .665 .952 r
.16109 .37118 .16509 .37499 .17049 .37516 .1665 .37127 Mtetra
.439 .652 .95 r
.1665 .37127 .17049 .37516 .1759 .37549 .17192 .37151 Mtetra
.432 .644 .946 r
.17192 .37151 .1759 .37549 .18132 .37589 .17735 .37182 Mtetra
.431 .638 .943 r
.17735 .37182 .18132 .37589 .18675 .37635 .1828 .37218 Mtetra
.434 .634 .939 r
.1828 .37218 .18675 .37635 .1922 .37681 .18827 .37255 Mtetra
.438 .631 .936 r
.18827 .37255 .1922 .37681 .19768 .37727 .19375 .37292 Mtetra
.442 .627 .932 r
.19375 .37292 .19768 .37727 .20317 .37774 .19926 .37329 Mtetra
.445 .624 .928 r
.19926 .37329 .20317 .37774 .20869 .37821 .20479 .37366 Mtetra
.449 .62 .924 r
.20479 .37366 .20869 .37821 .21423 .37868 .21033 .37403 Mtetra
.453 .617 .92 r
.21033 .37403 .21423 .37868 .21978 .37914 .2159 .3744 Mtetra
.455 .614 .917 r
.2159 .3744 .21978 .37914 .22536 .37962 .22149 .37478 Mtetra
.458 .61 .913 r
.22149 .37478 .22536 .37962 .23096 .38009 .22711 .37516 Mtetra
.462 .607 .909 r
.22711 .37516 .23096 .38009 .23659 .38056 .23274 .37553 Mtetra
.464 .604 .905 r
.23274 .37553 .23659 .38056 .24223 .38103 .23839 .3759 Mtetra
.467 .6 .901 r
.23839 .3759 .24223 .38103 .2479 .38151 .24407 .37628 Mtetra
.469 .597 .897 r
.24407 .37628 .2479 .38151 .25358 .38199 .24977 .37666 Mtetra
.472 .594 .894 r
.24977 .37666 .25358 .38199 .25929 .38246 .25549 .37704 Mtetra
.474 .591 .89 r
.25549 .37704 .25929 .38246 .26503 .38294 .26123 .37742 Mtetra
.476 .588 .886 r
.26123 .37742 .26503 .38294 .27078 .38343 .26699 .3778 Mtetra
.478 .585 .882 r
.26699 .3778 .27078 .38343 .27656 .38391 .27278 .37818 Mtetra
.48 .581 .879 r
.27278 .37818 .27656 .38391 .28236 .38439 .27858 .37856 Mtetra
.482 .578 .875 r
.27858 .37856 .28236 .38439 .28818 .38488 .28441 .37895 Mtetra
.484 .575 .872 r
.28441 .37895 .28818 .38488 .29402 .38536 .29027 .37933 Mtetra
.486 .573 .868 r
.29027 .37933 .29402 .38536 .29989 .38585 .29614 .37972 Mtetra
.487 .569 .864 r
.29614 .37972 .29989 .38585 .30578 .38634 .30204 .38011 Mtetra
.489 .567 .861 r
.30204 .38011 .30578 .38634 .31169 .38684 .30796 .3805 Mtetra
.49 .564 .858 r
.30796 .3805 .31169 .38684 .31763 .38733 .3139 .38089 Mtetra
.492 .561 .854 r
.3139 .38089 .31763 .38733 .32359 .38783 .31987 .38129 Mtetra
.493 .558 .851 r
.31987 .38129 .32359 .38783 .32957 .38833 .32586 .38168 Mtetra
.495 .556 .847 r
.32586 .38168 .32957 .38833 .33558 .38883 .33187 .38208 Mtetra
.496 .553 .844 r
.33187 .38208 .33558 .38883 .34161 .38934 .33791 .38248 Mtetra
.497 .55 .841 r
.33791 .38248 .34161 .38934 .34767 .38984 .34397 .38288 Mtetra
.498 .548 .838 r
.34397 .38288 .34767 .38984 .35375 .39035 .35006 .38328 Mtetra
.499 .545 .835 r
.35006 .38328 .35375 .39035 .35985 .39086 .35616 .38369 Mtetra
.5 .543 .832 r
.35616 .38369 .35985 .39086 .36598 .39138 .3623 .3841 Mtetra
.501 .54 .829 r
.3623 .3841 .36598 .39138 .37213 .3919 .36845 .38451 Mtetra
.502 .538 .825 r
.36845 .38451 .37213 .3919 .37831 .39242 .37464 .38492 Mtetra
.503 .535 .823 r
.37464 .38492 .37831 .39242 .38451 .39294 .38084 .38533 Mtetra
.504 .533 .82 r
.38084 .38533 .38451 .39294 .39074 .39347 .38707 .38575 Mtetra
.505 .531 .817 r
.38707 .38575 .39074 .39347 .39699 .39399 .39333 .38617 Mtetra
.506 .528 .814 r
.39333 .38617 .39699 .39399 .40327 .39452 .39961 .38659 Mtetra
.506 .526 .811 r
.39961 .38659 .40327 .39452 .40957 .39506 .40591 .38702 Mtetra
.507 .524 .808 r
.40591 .38702 .40957 .39506 .4159 .3956 .41224 .38745 Mtetra
.508 .522 .806 r
.41224 .38745 .4159 .3956 .42226 .39614 .4186 .38787 Mtetra
.509 .52 .803 r
.4186 .38787 .42226 .39614 .42864 .39666 .42498 .38829 Mtetra
.512 .519 .8 r
.42498 .38829 .42864 .39666 .43505 .39716 .43139 .38867 Mtetra
.519 .52 .797 r
.43139 .38867 .43505 .39716 .44148 .39754 .43783 .38894 Mtetra
.533 .526 .793 r
.43783 .38894 .44148 .39754 .44795 .39763 .4443 .38894 Mtetra
.613 .568 .78 r
.4443 .38894 .44795 .39763 .45449 .39588 .45083 .38716 Mtetra
.697 .611 .756 r
.45083 .38716 .45449 .39588 .4611 .3914 .45744 .38275 Mtetra
.704 .616 .755 r
.45744 .38275 .4611 .3914 .46771 .38667 .46406 .37811 Mtetra
.709 .62 .755 r
.46406 .37811 .46771 .38667 .47434 .38179 .47069 .37331 Mtetra
.712 .623 .756 r
.47069 .37331 .47434 .38179 .48097 .37684 .47733 .36845 Mtetra
.713 .625 .758 r
.47733 .36845 .48097 .37684 .48761 .37189 .48397 .36358 Mtetra
.714 .628 .76 r
.48397 .36358 .48761 .37189 .49425 .36693 .49061 .35871 Mtetra
.716 .631 .761 r
.49061 .35871 .49425 .36693 .50089 .36196 .49726 .35383 Mtetra
.717 .633 .763 r
.49726 .35383 .50089 .36196 .50755 .35699 .50392 .34894 Mtetra
.718 .636 .765 r
.50392 .34894 .50755 .35699 .5142 .35202 .51058 .34406 Mtetra
.719 .639 .767 r
.51058 .34406 .5142 .35202 .52086 .34704 .51724 .33917 Mtetra
.721 .641 .769 r
.51724 .33917 .52086 .34704 .52753 .34206 .52391 .33428 Mtetra
.722 .644 .771 r
.52391 .33428 .52753 .34206 .5342 .33708 .53059 .32939 Mtetra
.723 .647 .772 r
.53059 .32939 .5342 .33708 .54087 .3321 .53727 .32449 Mtetra
.725 .65 .774 r
.53727 .32449 .54087 .3321 .54755 .32711 .54396 .31959 Mtetra
.726 .653 .776 r
.54396 .31959 .54755 .32711 .55423 .32212 .55065 .31468 Mtetra
.727 .655 .778 r
.55065 .31468 .55423 .32212 .56092 .31713 .55735 .30978 Mtetra
.729 .658 .78 r
.55735 .30978 .56092 .31713 .56762 .31214 .56405 .30487 Mtetra
.73 .661 .782 r
.56405 .30487 .56762 .31214 .57431 .30714 .57075 .29995 Mtetra
.731 .664 .784 r
.57075 .29995 .57431 .30714 .58102 .30214 .57747 .29504 Mtetra
.733 .668 .786 r
.57747 .29504 .58102 .30214 .58773 .29713 .58418 .29012 Mtetra
.734 .671 .788 r
.58418 .29012 .58773 .29713 .59444 .29212 .59091 .28519 Mtetra
.736 .674 .79 r
.59091 .28519 .59444 .29212 .60116 .28711 .59764 .28026 Mtetra
.737 .677 .792 r
.59764 .28026 .60116 .28711 .60788 .2821 .60437 .27533 Mtetra
.738 .68 .794 r
.60437 .27533 .60788 .2821 .61461 .27708 .61111 .2704 Mtetra
.74 .684 .797 r
.61111 .2704 .61461 .27708 .62134 .27205 .61785 .26546 Mtetra
.741 .687 .799 r
.61785 .26546 .62134 .27205 .62808 .26703 .6246 .26051 Mtetra
.743 .691 .801 r
.6246 .26051 .62808 .26703 .63482 .262 .63136 .25557 Mtetra
.744 .694 .803 r
.63136 .25557 .63482 .262 .64156 .25697 .63812 .25061 Mtetra
.746 .698 .805 r
.63812 .25061 .64156 .25697 .64832 .25193 .64488 .24566 Mtetra
.747 .701 .808 r
.64488 .24566 .64832 .25193 .65507 .24689 .65165 .2407 Mtetra
.749 .705 .81 r
.65165 .2407 .65507 .24689 .66183 .24184 .65843 .23574 Mtetra
.751 .709 .812 r
.65843 .23574 .66183 .24184 .6686 .23679 .66521 .23077 Mtetra
.752 .712 .815 r
.66521 .23077 .6686 .23679 .67537 .23174 .67199 .2258 Mtetra
.754 .716 .817 r
.67199 .2258 .67537 .23174 .68215 .22668 .67879 .22082 Mtetra
.755 .72 .819 r
.67879 .22082 .68215 .22668 .68893 .22162 .68558 .21584 Mtetra
.757 .724 .822 r
.68558 .21584 .68893 .22162 .69571 .21655 .69238 .21085 Mtetra
.758 .728 .824 r
.69238 .21085 .69571 .21655 .70251 .21149 .69919 .20586 Mtetra
.76 .732 .827 r
.69919 .20586 .70251 .21149 .7093 .20641 .706 .20087 Mtetra
.762 .736 .829 r
.706 .20087 .7093 .20641 .7161 .20133 .71282 .19587 Mtetra
.763 .74 .832 r
.71282 .19587 .7161 .20133 .72291 .19625 .71965 .19086 Mtetra
.765 .744 .834 r
.71965 .19086 .72291 .19625 .72972 .19116 .72647 .18585 Mtetra
.767 .749 .836 r
.72647 .18585 .72972 .19116 .73653 .18606 .73331 .18084 Mtetra
.768 .753 .839 r
.73331 .18084 .73653 .18606 .74335 .18097 .74015 .17582 Mtetra
.77 .757 .842 r
.74015 .17582 .74335 .18097 .75018 .17587 .74699 .1708 Mtetra
.771 .762 .844 r
.74699 .1708 .75018 .17587 .75701 .17077 .75384 .16578 Mtetra
.772 .766 .848 r
.75384 .16578 .75701 .17077 .76384 .1657 .7607 .16079 Mtetra
.77 .77 .852 r
.7607 .16079 .76384 .1657 .77069 .16071 .76757 .15587 Mtetra
.767 .772 .858 r
.76757 .15587 .77069 .16071 .77756 .15586 .77446 .15109 Mtetra
.759 .774 .865 r
.77446 .15109 .77756 .15586 .78446 .15125 .78137 .14654 Mtetra
.518 .694 .949 r
.15161 .36777 .15564 .37153 .16109 .37118 .15707 .36736 Mtetra
.467 .669 .951 r
.15707 .36736 .16109 .37118 .1665 .37127 .1625 .36736 Mtetra
.45 .657 .949 r
.1625 .36736 .1665 .37127 .17192 .37151 .16793 .36751 Mtetra
.444 .65 .946 r
.16793 .36751 .17192 .37151 .17735 .37182 .17338 .36774 Mtetra
.443 .644 .943 r
.17338 .36774 .17735 .37182 .1828 .37218 .17884 .368 Mtetra
.445 .639 .939 r
.17884 .368 .1828 .37218 .18827 .37255 .18431 .36827 Mtetra
.45 .636 .935 r
.18431 .36827 .18827 .37255 .19375 .37292 .18981 .36854 Mtetra
.453 .632 .931 r
.18981 .36854 .19375 .37292 .19926 .37329 .19533 .36882 Mtetra
.456 .629 .928 r
.19533 .36882 .19926 .37329 .20479 .37366 .20087 .3691 Mtetra
.46 .625 .924 r
.20087 .3691 .20479 .37366 .21033 .37403 .20643 .36937 Mtetra
.463 .622 .92 r
.20643 .36937 .21033 .37403 .2159 .3744 .21201 .36965 Mtetra
.465 .618 .916 r
.21201 .36965 .2159 .3744 .22149 .37478 .21761 .36993 Mtetra
.468 .615 .912 r
.21761 .36993 .22149 .37478 .22711 .37516 .22323 .3702 Mtetra
.471 .612 .908 r
.22323 .3702 .22711 .37516 .23274 .37553 .22888 .37048 Mtetra
.474 .608 .904 r
.22888 .37048 .23274 .37553 .23839 .3759 .23454 .37076 Mtetra
.476 .605 .901 r
.23454 .37076 .23839 .3759 .24407 .37628 .24023 .37104 Mtetra
.478 .602 .897 r
.24023 .37104 .24407 .37628 .24977 .37666 .24594 .37132 Mtetra
.481 .598 .893 r
.24594 .37132 .24977 .37666 .25549 .37704 .25167 .37159 Mtetra
.483 .595 .889 r
.25167 .37159 .25549 .37704 .26123 .37742 .25742 .37188 Mtetra
.485 .592 .886 r
.25742 .37188 .26123 .37742 .26699 .3778 .26319 .37216 Mtetra
.487 .589 .882 r
.26319 .37216 .26699 .3778 .27278 .37818 .26898 .37244 Mtetra
.488 .586 .878 r
.26898 .37244 .27278 .37818 .27858 .37856 .2748 .37272 Mtetra
.49 .582 .875 r
.2748 .37272 .27858 .37856 .28441 .37895 .28064 .373 Mtetra
.492 .579 .871 r
.28064 .373 .28441 .37895 .29027 .37933 .2865 .37329 Mtetra
.493 .576 .867 r
.2865 .37329 .29027 .37933 .29614 .37972 .29238 .37357 Mtetra
.495 .573 .864 r
.29238 .37357 .29614 .37972 .30204 .38011 .29829 .37386 Mtetra
.496 .57 .86 r
.29829 .37386 .30204 .38011 .30796 .3805 .30421 .37415 Mtetra
.498 .568 .857 r
.30421 .37415 .30796 .3805 .3139 .38089 .31017 .37444 Mtetra
.499 .565 .854 r
.31017 .37444 .3139 .38089 .31987 .38129 .31614 .37473 Mtetra
.5 .562 .85 r
.31614 .37473 .31987 .38129 .32586 .38168 .32214 .37502 Mtetra
.501 .559 .847 r
.32214 .37502 .32586 .38168 .33187 .38208 .32816 .37531 Mtetra
.502 .557 .844 r
.32816 .37531 .33187 .38208 .33791 .38248 .3342 .37561 Mtetra
.503 .554 .841 r
.3342 .37561 .33791 .38248 .34397 .38288 .34026 .3759 Mtetra
.504 .551 .837 r
.34026 .3759 .34397 .38288 .35006 .38328 .34635 .3762 Mtetra
.506 .549 .834 r
.34635 .3762 .35006 .38328 .35616 .38369 .35247 .3765 Mtetra
.506 .546 .831 r
.35247 .3765 .35616 .38369 .3623 .3841 .35861 .3768 Mtetra
.507 .543 .828 r
.35861 .3768 .3623 .3841 .36845 .38451 .36477 .3771 Mtetra
.508 .541 .825 r
.36477 .3771 .36845 .38451 .37464 .38492 .37095 .37741 Mtetra
.509 .539 .822 r
.37095 .37741 .37464 .38492 .38084 .38533 .37716 .37771 Mtetra
.51 .536 .819 r
.37716 .37771 .38084 .38533 .38707 .38575 .3834 .37802 Mtetra
.51 .534 .816 r
.3834 .37802 .38707 .38575 .39333 .38617 .38965 .37833 Mtetra
.511 .532 .814 r
.38965 .37833 .39333 .38617 .39961 .38659 .39594 .37864 Mtetra
.512 .529 .811 r
.39594 .37864 .39961 .38659 .40591 .38702 .40224 .37896 Mtetra
.512 .527 .808 r
.40224 .37896 .40591 .38702 .41224 .38745 .40858 .37928 Mtetra
.513 .525 .805 r
.40858 .37928 .41224 .38745 .4186 .38787 .41494 .37959 Mtetra
.515 .523 .803 r
.41494 .37959 .4186 .38787 .42498 .38829 .42132 .3799 Mtetra
.517 .522 .8 r
.42132 .3799 .42498 .38829 .43139 .38867 .42773 .38018 Mtetra
.524 .523 .797 r
.42773 .38018 .43139 .38867 .43783 .38894 .43417 .38034 Mtetra
.537 .529 .793 r
.43417 .38034 .43783 .38894 .4443 .38894 .44064 .38024 Mtetra
.613 .568 .78 r
.44064 .38024 .4443 .38894 .45083 .38716 .44717 .37843 Mtetra
.695 .61 .757 r
.44717 .37843 .45083 .38716 .45744 .38275 .45378 .3741 Mtetra
.702 .615 .756 r
.45378 .3741 .45744 .38275 .46406 .37811 .46041 .36953 Mtetra
.707 .619 .756 r
.46041 .36953 .46406 .37811 .47069 .37331 .46704 .36482 Mtetra
.709 .622 .757 r
.46704 .36482 .47069 .37331 .47733 .36845 .47368 .36005 Mtetra
.711 .624 .759 r
.47368 .36005 .47733 .36845 .48397 .36358 .48032 .35527 Mtetra
.712 .627 .761 r
.48032 .35527 .48397 .36358 .49061 .35871 .48697 .35048 Mtetra
.713 .63 .762 r
.48697 .35048 .49061 .35871 .49726 .35383 .49362 .34568 Mtetra
.714 .632 .764 r
.49362 .34568 .49726 .35383 .50392 .34894 .50028 .34089 Mtetra
.716 .635 .766 r
.50028 .34089 .50392 .34894 .51058 .34406 .50695 .33609 Mtetra
.717 .637 .768 r
.50695 .33609 .51058 .34406 .51724 .33917 .51362 .33129 Mtetra
.718 .64 .77 r
.51362 .33129 .51724 .33917 .52391 .33428 .52029 .32648 Mtetra
.719 .643 .772 r
.52029 .32648 .52391 .33428 .53059 .32939 .52698 .32167 Mtetra
.721 .646 .774 r
.52698 .32167 .53059 .32939 .53727 .32449 .53366 .31686 Mtetra
.722 .649 .775 r
.53366 .31686 .53727 .32449 .54396 .31959 .54036 .31205 Mtetra
.723 .651 .777 r
.54036 .31205 .54396 .31959 .55065 .31468 .54706 .30723 Mtetra
.725 .654 .779 r
.54706 .30723 .55065 .31468 .55735 .30978 .55376 .30241 Mtetra
.726 .657 .781 r
.55376 .30241 .55735 .30978 .56405 .30487 .56047 .29758 Mtetra
.727 .66 .783 r
.56047 .29758 .56405 .30487 .57075 .29995 .56719 .29275 Mtetra
.729 .663 .785 r
.56719 .29275 .57075 .29995 .57747 .29504 .57391 .28792 Mtetra
.73 .666 .787 r
.57391 .28792 .57747 .29504 .58418 .29012 .58063 .28308 Mtetra
.732 .67 .789 r
.58063 .28308 .58418 .29012 .59091 .28519 .58737 .27824 Mtetra
.733 .673 .792 r
.58737 .27824 .59091 .28519 .59764 .28026 .59411 .2734 Mtetra
.734 .676 .794 r
.59411 .2734 .59764 .28026 .60437 .27533 .60085 .26855 Mtetra
.736 .679 .796 r
.60085 .26855 .60437 .27533 .61111 .2704 .6076 .2637 Mtetra
.737 .683 .798 r
.6076 .2637 .61111 .2704 .61785 .26546 .61435 .25884 Mtetra
.739 .686 .8 r
.61435 .25884 .61785 .26546 .6246 .26051 .62112 .25398 Mtetra
.74 .69 .802 r
.62112 .25398 .6246 .26051 .63136 .25557 .62788 .24911 Mtetra
.742 .693 .805 r
.62788 .24911 .63136 .25557 .63812 .25061 .63466 .24424 Mtetra
.743 .697 .807 r
.63466 .24424 .63812 .25061 .64488 .24566 .64143 .23937 Mtetra
.745 .7 .809 r
.64143 .23937 .64488 .24566 .65165 .2407 .64822 .23449 Mtetra
.746 .704 .811 r
.64822 .23449 .65165 .2407 .65843 .23574 .65501 .22961 Mtetra
.748 .707 .814 r
.65501 .22961 .65843 .23574 .66521 .23077 .6618 .22472 Mtetra
.749 .711 .816 r
.6618 .22472 .66521 .23077 .67199 .2258 .6686 .21983 Mtetra
.751 .715 .819 r
.6686 .21983 .67199 .2258 .67879 .22082 .67541 .21494 Mtetra
.752 .719 .821 r
.67541 .21494 .67879 .22082 .68558 .21584 .68222 .21003 Mtetra
.754 .723 .823 r
.68222 .21003 .68558 .21584 .69238 .21085 .68904 .20513 Mtetra
.755 .727 .826 r
.68904 .20513 .69238 .21085 .69919 .20586 .69587 .20022 Mtetra
.757 .731 .828 r
.69587 .20022 .69919 .20586 .706 .20087 .7027 .1953 Mtetra
.759 .735 .831 r
.7027 .1953 .706 .20087 .71282 .19587 .70953 .19038 Mtetra
.76 .739 .833 r
.70953 .19038 .71282 .19587 .71965 .19086 .71637 .18546 Mtetra
.762 .743 .836 r
.71637 .18546 .71965 .19086 .72647 .18585 .72322 .18053 Mtetra
.764 .748 .838 r
.72322 .18053 .72647 .18585 .73331 .18084 .73007 .17559 Mtetra
.765 .752 .841 r
.73007 .17559 .73331 .18084 .74015 .17582 .73693 .17065 Mtetra
.767 .756 .844 r
.73693 .17065 .74015 .17582 .74699 .1708 .7438 .16571 Mtetra
.768 .761 .846 r
.7438 .16571 .74699 .1708 .75384 .16578 .75067 .16077 Mtetra
.769 .765 .849 r
.75067 .16077 .75384 .16578 .7607 .16079 .75755 .15585 Mtetra
.767 .769 .854 r
.75755 .15585 .7607 .16079 .76757 .15587 .76444 .15101 Mtetra
.764 .771 .859 r
.76444 .15101 .76757 .15587 .77446 .15109 .77134 .1463 Mtetra
.756 .773 .867 r
.77134 .1463 .77446 .15109 .78137 .14654 .77828 .1418 Mtetra
.525 .697 .948 r
.14757 .364 .15161 .36777 .15707 .36736 .15304 .36352 Mtetra
.477 .674 .951 r
.15304 .36352 .15707 .36736 .1625 .36736 .15848 .36344 Mtetra
.461 .662 .949 r
.15848 .36344 .1625 .36736 .16793 .36751 .16393 .3635 Mtetra
.456 .655 .946 r
.16393 .3635 .16793 .36751 .17338 .36774 .16938 .36363 Mtetra
.455 .649 .942 r
.16938 .36363 .17338 .36774 .17884 .368 .17486 .3638 Mtetra
.457 .645 .939 r
.17486 .3638 .17884 .368 .18431 .36827 .18035 .36398 Mtetra
.461 .641 .935 r
.18035 .36398 .18431 .36827 .18981 .36854 .18586 .36416 Mtetra
.464 .637 .931 r
.18586 .36416 .18981 .36854 .19533 .36882 .19139 .36433 Mtetra
.467 .634 .927 r
.19139 .36433 .19533 .36882 .20087 .3691 .19694 .36452 Mtetra
.47 .63 .923 r
.19694 .36452 .20087 .3691 .20643 .36937 .20251 .3647 Mtetra
.473 .627 .919 r
.20251 .3647 .20643 .36937 .21201 .36965 .2081 .36487 Mtetra
.475 .623 .915 r
.2081 .36487 .21201 .36965 .21761 .36993 .21372 .36505 Mtetra
.478 .619 .911 r
.21372 .36505 .21761 .36993 .22323 .3702 .21935 .36524 Mtetra
.481 .616 .908 r
.21935 .36524 .22323 .3702 .22888 .37048 .22501 .36541 Mtetra
.483 .613 .904 r
.22501 .36541 .22888 .37048 .23454 .37076 .23068 .36559 Mtetra
.485 .609 .9 r
.23068 .36559 .23454 .37076 .24023 .37104 .23638 .36577 Mtetra
.487 .606 .896 r
.23638 .36577 .24023 .37104 .24594 .37132 .24209 .36595 Mtetra
.489 .602 .892 r
.24209 .36595 .24594 .37132 .25167 .37159 .24783 .36613 Mtetra
.491 .599 .888 r
.24783 .36613 .25167 .37159 .25742 .37188 .25359 .36631 Mtetra
.493 .596 .885 r
.25359 .36631 .25742 .37188 .26319 .37216 .25938 .3665 Mtetra
.495 .593 .881 r
.25938 .3665 .26319 .37216 .26898 .37244 .26518 .36668 Mtetra
.496 .589 .877 r
.26518 .36668 .26898 .37244 .2748 .37272 .271 .36686 Mtetra
.498 .586 .874 r
.271 .36686 .2748 .37272 .28064 .373 .27685 .36704 Mtetra
.5 .583 .87 r
.27685 .36704 .28064 .373 .2865 .37329 .28272 .36722 Mtetra
.501 .58 .867 r
.28272 .36722 .2865 .37329 .29238 .37357 .28861 .36741 Mtetra
.502 .577 .863 r
.28861 .36741 .29238 .37357 .29829 .37386 .29452 .36759 Mtetra
.503 .574 .86 r
.29452 .36759 .29829 .37386 .30421 .37415 .30046 .36778 Mtetra
.505 .571 .856 r
.30046 .36778 .30421 .37415 .31017 .37444 .30642 .36796 Mtetra
.506 .568 .853 r
.30642 .36796 .31017 .37444 .31614 .37473 .3124 .36815 Mtetra
.507 .565 .85 r
.3124 .36815 .31614 .37473 .32214 .37502 .3184 .36834 Mtetra
.508 .563 .846 r
.3184 .36834 .32214 .37502 .32816 .37531 .32443 .36852 Mtetra
.509 .56 .843 r
.32443 .36852 .32816 .37531 .3342 .37561 .33048 .36871 Mtetra
.51 .557 .84 r
.33048 .36871 .3342 .37561 .34026 .3759 .33655 .36891 Mtetra
.511 .554 .837 r
.33655 .36891 .34026 .3759 .34635 .3762 .34264 .3691 Mtetra
.512 .552 .834 r
.34264 .3691 .34635 .3762 .35247 .3765 .34876 .36929 Mtetra
.513 .549 .831 r
.34876 .36929 .35247 .3765 .35861 .3768 .35491 .36948 Mtetra
.513 .547 .827 r
.35491 .36948 .35861 .3768 .36477 .3771 .36107 .36968 Mtetra
.514 .544 .824 r
.36107 .36968 .36477 .3771 .37095 .37741 .36726 .36988 Mtetra
.515 .542 .822 r
.36726 .36988 .37095 .37741 .37716 .37771 .37347 .37007 Mtetra
.515 .539 .819 r
.37347 .37007 .37716 .37771 .3834 .37802 .37971 .37028 Mtetra
.516 .537 .816 r
.37971 .37028 .3834 .37802 .38965 .37833 .38597 .37048 Mtetra
.517 .535 .813 r
.38597 .37048 .38965 .37833 .39594 .37864 .39226 .37068 Mtetra
.517 .532 .81 r
.39226 .37068 .39594 .37864 .40224 .37896 .39857 .37089 Mtetra
.518 .53 .807 r
.39857 .37089 .40224 .37896 .40858 .37928 .4049 .37109 Mtetra
.519 .528 .805 r
.4049 .37109 .40858 .37928 .41494 .37959 .41126 .3713 Mtetra
.52 .526 .802 r
.41126 .3713 .41494 .37959 .42132 .3799 .41765 .37149 Mtetra
.522 .525 .799 r
.41765 .37149 .42132 .3799 .42773 .38018 .42406 .37166 Mtetra
.528 .526 .796 r
.42406 .37166 .42773 .38018 .43417 .38034 .4305 .37171 Mtetra
.542 .531 .793 r
.4305 .37171 .43417 .38034 .44064 .38024 .43697 .37152 Mtetra
.614 .568 .78 r
.43697 .37152 .44064 .38024 .44717 .37843 .44351 .36969 Mtetra
.693 .609 .757 r
.44351 .36969 .44717 .37843 .45378 .3741 .45012 .36542 Mtetra
.7 .613 .757 r
.45012 .36542 .45378 .3741 .46041 .36953 .45674 .36093 Mtetra
.704 .617 .757 r
.45674 .36093 .46041 .36953 .46704 .36482 .46338 .3563 Mtetra
.707 .62 .758 r
.46338 .3563 .46704 .36482 .47368 .36005 .47002 .35162 Mtetra
.708 .623 .76 r
.47002 .35162 .47368 .36005 .48032 .35527 .47666 .34693 Mtetra
.709 .626 .762 r
.47666 .34693 .48032 .35527 .48697 .35048 .48332 .34223 Mtetra
.711 .628 .763 r
.48332 .34223 .48697 .35048 .49362 .34568 .48997 .33752 Mtetra
.712 .631 .765 r
.48997 .33752 .49362 .34568 .50028 .34089 .49664 .33281 Mtetra
.713 .633 .767 r
.49664 .33281 .50028 .34089 .50695 .33609 .50331 .3281 Mtetra
.714 .636 .769 r
.50331 .3281 .50695 .33609 .51362 .33129 .50998 .32339 Mtetra
.716 .639 .771 r
.50998 .32339 .51362 .33129 .52029 .32648 .51667 .31866 Mtetra
.717 .642 .773 r
.51667 .31866 .52029 .32648 .52698 .32167 .52335 .31394 Mtetra
.718 .644 .775 r
.52335 .31394 .52698 .32167 .53366 .31686 .53005 .30922 Mtetra
.719 .647 .777 r
.53005 .30922 .53366 .31686 .54036 .31205 .53675 .30449 Mtetra
.721 .65 .779 r
.53675 .30449 .54036 .31205 .54706 .30723 .54345 .29975 Mtetra
.722 .653 .781 r
.54345 .29975 .54706 .30723 .55376 .30241 .55017 .29502 Mtetra
.723 .656 .782 r
.55017 .29502 .55376 .30241 .56047 .29758 .55688 .29027 Mtetra
.725 .659 .785 r
.55688 .29027 .56047 .29758 .56719 .29275 .56361 .28553 Mtetra
.726 .662 .787 r
.56361 .28553 .56719 .29275 .57391 .28792 .57034 .28078 Mtetra
.727 .665 .789 r
.57034 .28078 .57391 .28792 .58063 .28308 .57707 .27603 Mtetra
.729 .668 .791 r
.57707 .27603 .58063 .28308 .58737 .27824 .58382 .27127 Mtetra
.73 .672 .793 r
.58382 .27127 .58737 .27824 .59411 .2734 .59056 .26651 Mtetra
.731 .675 .795 r
.59056 .26651 .59411 .2734 .60085 .26855 .59732 .26174 Mtetra
.733 .678 .797 r
.59732 .26174 .60085 .26855 .6076 .2637 .60408 .25697 Mtetra
.734 .682 .799 r
.60408 .25697 .6076 .2637 .61435 .25884 .61085 .2522 Mtetra
.736 .685 .802 r
.61085 .2522 .61435 .25884 .62112 .25398 .61762 .24742 Mtetra
.737 .688 .804 r
.61762 .24742 .62112 .25398 .62788 .24911 .6244 .24264 Mtetra
.739 .692 .806 r
.6244 .24264 .62788 .24911 .63466 .24424 .63118 .23785 Mtetra
.74 .695 .808 r
.63118 .23785 .63466 .24424 .64143 .23937 .63798 .23306 Mtetra
.742 .699 .811 r
.63798 .23306 .64143 .23937 .64822 .23449 .64477 .22826 Mtetra
.743 .703 .813 r
.64477 .22826 .64822 .23449 .65501 .22961 .65158 .22346 Mtetra
.745 .706 .815 r
.65158 .22346 .65501 .22961 .6618 .22472 .65839 .21865 Mtetra
.746 .71 .818 r
.65839 .21865 .6618 .22472 .6686 .21983 .6652 .21385 Mtetra
.748 .714 .82 r
.6652 .21385 .6686 .21983 .67541 .21494 .67202 .20903 Mtetra
.749 .718 .823 r
.67202 .20903 .67541 .21494 .68222 .21003 .67885 .20421 Mtetra
.751 .722 .825 r
.67885 .20421 .68222 .21003 .68904 .20513 .68569 .19938 Mtetra
.752 .726 .827 r
.68569 .19938 .68904 .20513 .69587 .20022 .69253 .19455 Mtetra
.754 .73 .83 r
.69253 .19455 .69587 .20022 .7027 .1953 .69937 .18972 Mtetra
.756 .734 .832 r
.69937 .18972 .7027 .1953 .70953 .19038 .70623 .18488 Mtetra
.757 .738 .835 r
.70623 .18488 .70953 .19038 .71637 .18546 .71309 .18003 Mtetra
.759 .742 .838 r
.71309 .18003 .71637 .18546 .72322 .18053 .71995 .17518 Mtetra
.76 .747 .84 r
.71995 .17518 .72322 .18053 .73007 .17559 .72682 .17032 Mtetra
.762 .751 .843 r
.72682 .17032 .73007 .17559 .73693 .17065 .7337 .16546 Mtetra
.763 .755 .845 r
.7337 .16546 .73693 .17065 .7438 .16571 .74059 .1606 Mtetra
.765 .76 .848 r
.74059 .1606 .7438 .16571 .75067 .16077 .74748 .15574 Mtetra
.765 .764 .851 r
.74748 .15574 .75067 .16077 .75755 .15585 .75438 .1509 Mtetra
.764 .768 .856 r
.75438 .1509 .75755 .15585 .76444 .15101 .76129 .14613 Mtetra
.761 .77 .861 r
.76129 .14613 .76444 .15101 .77134 .1463 .76822 .14148 Mtetra
.753 .772 .868 r
.76822 .14148 .77134 .1463 .77828 .1418 .77517 .13705 Mtetra
.532 .699 .947 r
.14351 .36022 .14757 .364 .15304 .36352 .14899 .35967 Mtetra
.487 .678 .95 r
.14899 .35967 .15304 .36352 .15848 .36344 .15445 .3595 Mtetra
.472 .667 .948 r
.15445 .3595 .15848 .36344 .16393 .3635 .1599 .35947 Mtetra
.467 .66 .945 r
.1599 .35947 .16393 .3635 .16938 .36363 .16537 .35951 Mtetra
.466 .654 .942 r
.16537 .35951 .16938 .36363 .17486 .3638 .17086 .35959 Mtetra
.468 .65 .938 r
.17086 .35959 .17486 .3638 .18035 .36398 .17636 .35967 Mtetra
.472 .646 .934 r
.17636 .35967 .18035 .36398 .18586 .36416 .18189 .35975 Mtetra
.474 .642 .93 r
.18189 .35975 .18586 .36416 .19139 .36433 .18743 .35983 Mtetra
.477 .638 .926 r
.18743 .35983 .19139 .36433 .19694 .36452 .19299 .35992 Mtetra
.48 .635 .922 r
.19299 .35992 .19694 .36452 .20251 .3647 .19858 .36 Mtetra
.483 .631 .918 r
.19858 .36 .20251 .3647 .2081 .36487 .20418 .36008 Mtetra
.485 .627 .914 r
.20418 .36008 .2081 .36487 .21372 .36505 .20981 .36017 Mtetra
.487 .624 .911 r
.20981 .36017 .21372 .36505 .21935 .36524 .21545 .36025 Mtetra
.49 .62 .907 r
.21545 .36025 .21935 .36524 .22501 .36541 .22112 .36033 Mtetra
.492 .617 .903 r
.22112 .36033 .22501 .36541 .23068 .36559 .2268 .36041 Mtetra
.494 .613 .899 r
.2268 .36041 .23068 .36559 .23638 .36577 .23251 .36049 Mtetra
.496 .61 .895 r
.23251 .36049 .23638 .36577 .24209 .36595 .23824 .36057 Mtetra
.498 .606 .891 r
.23824 .36057 .24209 .36595 .24783 .36613 .24399 .36065 Mtetra
.499 .603 .888 r
.24399 .36065 .24783 .36613 .25359 .36631 .24976 .36073 Mtetra
.501 .6 .884 r
.24976 .36073 .25359 .36631 .25938 .3665 .25555 .36082 Mtetra
.503 .596 .88 r
.25555 .36082 .25938 .3665 .26518 .36668 .26136 .3609 Mtetra
.504 .593 .877 r
.26136 .3609 .26518 .36668 .271 .36686 .2672 .36098 Mtetra
.506 .59 .873 r
.2672 .36098 .271 .36686 .27685 .36704 .27305 .36106 Mtetra
.507 .587 .869 r
.27305 .36106 .27685 .36704 .28272 .36722 .27893 .36114 Mtetra
.508 .584 .866 r
.27893 .36114 .28272 .36722 .28861 .36741 .28483 .36122 Mtetra
.509 .581 .862 r
.28483 .36122 .28861 .36741 .29452 .36759 .29075 .3613 Mtetra
.511 .578 .859 r
.29075 .3613 .29452 .36759 .30046 .36778 .29669 .36139 Mtetra
.512 .575 .855 r
.29669 .36139 .30046 .36778 .30642 .36796 .30266 .36147 Mtetra
.513 .572 .852 r
.30266 .36147 .30642 .36796 .3124 .36815 .30865 .36155 Mtetra
.514 .569 .849 r
.30865 .36155 .3124 .36815 .3184 .36834 .31466 .36164 Mtetra
.515 .566 .846 r
.31466 .36164 .3184 .36834 .32443 .36852 .32069 .36172 Mtetra
.516 .563 .842 r
.32069 .36172 .32443 .36852 .33048 .36871 .32675 .3618 Mtetra
.516 .56 .839 r
.32675 .3618 .33048 .36871 .33655 .36891 .33282 .36189 Mtetra
.517 .558 .836 r
.33282 .36189 .33655 .36891 .34264 .3691 .33893 .36198 Mtetra
.518 .555 .833 r
.33893 .36198 .34264 .3691 .34876 .36929 .34505 .36206 Mtetra
.519 .552 .83 r
.34505 .36206 .34876 .36929 .35491 .36948 .3512 .36215 Mtetra
.519 .55 .827 r
.3512 .36215 .35491 .36948 .36107 .36968 .35737 .36224 Mtetra
.52 .547 .824 r
.35737 .36224 .36107 .36968 .36726 .36988 .36356 .36233 Mtetra
.521 .545 .821 r
.36356 .36233 .36726 .36988 .37347 .37007 .36978 .36242 Mtetra
.521 .542 .818 r
.36978 .36242 .37347 .37007 .37971 .37028 .37602 .36251 Mtetra
.522 .54 .815 r
.37602 .36251 .37971 .37028 .38597 .37048 .38229 .3626 Mtetra
.523 .538 .812 r
.38229 .3626 .38597 .37048 .39226 .37068 .38858 .3627 Mtetra
.523 .535 .81 r
.38858 .3627 .39226 .37068 .39857 .37089 .39489 .36279 Mtetra
.523 .533 .807 r
.39489 .36279 .39857 .37089 .4049 .37109 .40123 .36289 Mtetra
.524 .531 .804 r
.40123 .36289 .4049 .37109 .41126 .3713 .40759 .36298 Mtetra
.525 .529 .802 r
.40759 .36298 .41126 .3713 .41765 .37149 .41398 .36307 Mtetra
.527 .527 .799 r
.41398 .36307 .41765 .37149 .42406 .37166 .42039 .36312 Mtetra
.533 .528 .796 r
.42039 .36312 .42406 .37166 .4305 .37171 .42683 .36307 Mtetra
.545 .533 .792 r
.42683 .36307 .4305 .37171 .43697 .37152 .4333 .36279 Mtetra
.614 .569 .779 r
.4333 .36279 .43697 .37152 .44351 .36969 .43984 .36092 Mtetra
.691 .607 .758 r
.43984 .36092 .44351 .36969 .45012 .36542 .44645 .35673 Mtetra
.697 .612 .758 r
.44645 .35673 .45012 .36542 .45674 .36093 .45308 .35232 Mtetra
.702 .616 .758 r
.45308 .35232 .45674 .36093 .46338 .3563 .45971 .34778 Mtetra
.704 .619 .759 r
.45971 .34778 .46338 .3563 .47002 .35162 .46635 .34318 Mtetra
.706 .622 .761 r
.46635 .34318 .47002 .35162 .47666 .34693 .473 .33857 Mtetra
.707 .624 .763 r
.473 .33857 .47666 .34693 .48332 .34223 .47966 .33396 Mtetra
.708 .627 .764 r
.47966 .33396 .48332 .34223 .48997 .33752 .48632 .32934 Mtetra
.709 .63 .766 r
.48632 .32934 .48997 .33752 .49664 .33281 .49299 .32472 Mtetra
.71 .632 .768 r
.49299 .32472 .49664 .33281 .50331 .3281 .49966 .32009 Mtetra
.712 .635 .77 r
.49966 .32009 .50331 .3281 .50998 .32339 .50634 .31546 Mtetra
.713 .638 .772 r
.50634 .31546 .50998 .32339 .51667 .31866 .51303 .31083 Mtetra
.714 .64 .774 r
.51303 .31083 .51667 .31866 .52335 .31394 .51972 .30619 Mtetra
.715 .643 .776 r
.51972 .30619 .52335 .31394 .53005 .30922 .52642 .30155 Mtetra
.717 .646 .778 r
.52642 .30155 .53005 .30922 .53675 .30449 .53313 .29691 Mtetra
.718 .649 .78 r
.53313 .29691 .53675 .30449 .54345 .29975 .53984 .29226 Mtetra
.719 .652 .782 r
.53984 .29226 .54345 .29975 .55017 .29502 .54656 .28761 Mtetra
.721 .655 .784 r
.54656 .28761 .55017 .29502 .55688 .29027 .55329 .28295 Mtetra
.722 .658 .786 r
.55329 .28295 .55688 .29027 .56361 .28553 .56002 .27828 Mtetra
.723 .661 .788 r
.56002 .27828 .56361 .28553 .57034 .28078 .56676 .27362 Mtetra
.725 .664 .79 r
.56676 .27362 .57034 .28078 .57707 .27603 .5735 .26895 Mtetra
.726 .667 .792 r
.5735 .26895 .57707 .27603 .58382 .27127 .58026 .26428 Mtetra
.727 .67 .794 r
.58026 .26428 .58382 .27127 .59056 .26651 .58701 .2596 Mtetra
.729 .674 .796 r
.58701 .2596 .59056 .26651 .59732 .26174 .59378 .25492 Mtetra
.73 .677 .798 r
.59378 .25492 .59732 .26174 .60408 .25697 .60055 .25023 Mtetra
.732 .68 .801 r
.60055 .25023 .60408 .25697 .61085 .2522 .60733 .24554 Mtetra
.733 .684 .803 r
.60733 .24554 .61085 .2522 .61762 .24742 .61411 .24084 Mtetra
.734 .687 .805 r
.61411 .24084 .61762 .24742 .6244 .24264 .6209 .23614 Mtetra
.736 .691 .807 r
.6209 .23614 .6244 .24264 .63118 .23785 .6277 .23144 Mtetra
.737 .694 .81 r
.6277 .23144 .63118 .23785 .63798 .23306 .6345 .22673 Mtetra
.739 .698 .812 r
.6345 .22673 .63798 .23306 .64477 .22826 .64132 .22201 Mtetra
.74 .701 .814 r
.64132 .22201 .64477 .22826 .65158 .22346 .64813 .21729 Mtetra
.742 .705 .817 r
.64813 .21729 .65158 .22346 .65839 .21865 .65496 .21257 Mtetra
.743 .709 .819 r
.65496 .21257 .65839 .21865 .6652 .21385 .66179 .20784 Mtetra
.745 .713 .822 r
.66179 .20784 .6652 .21385 .67202 .20903 .66862 .2031 Mtetra
.746 .717 .824 r
.66862 .2031 .67202 .20903 .67885 .20421 .67547 .19836 Mtetra
.748 .721 .827 r
.67547 .19836 .67885 .20421 .68569 .19938 .68232 .19362 Mtetra
.749 .725 .829 r
.68232 .19362 .68569 .19938 .69253 .19455 .68918 .18887 Mtetra
.751 .729 .832 r
.68918 .18887 .69253 .19455 .69937 .18972 .69604 .18411 Mtetra
.752 .733 .834 r
.69604 .18411 .69937 .18972 .70623 .18488 .70291 .17935 Mtetra
.754 .737 .837 r
.70291 .17935 .70623 .18488 .71309 .18003 .70979 .17458 Mtetra
.756 .741 .839 r
.70979 .17458 .71309 .18003 .71995 .17518 .71667 .16981 Mtetra
.757 .745 .842 r
.71667 .16981 .71995 .17518 .72682 .17032 .72356 .16503 Mtetra
.759 .75 .845 r
.72356 .16503 .72682 .17032 .7337 .16546 .73046 .16025 Mtetra
.76 .754 .847 r
.73046 .16025 .7337 .16546 .74059 .1606 .73736 .15547 Mtetra
.762 .759 .85 r
.73736 .15547 .74059 .1606 .74748 .15574 .74427 .15068 Mtetra
.762 .763 .853 r
.74427 .15068 .74748 .15574 .75438 .1509 .75119 .14592 Mtetra
.761 .766 .857 r
.75119 .14592 .75438 .1509 .76129 .14613 .75812 .14122 Mtetra
.757 .769 .863 r
.75812 .14122 .76129 .14613 .76822 .14148 .76507 .13665 Mtetra
.75 .771 .87 r
.76507 .13665 .76822 .14148 .77517 .13705 .77205 .13228 Mtetra
.539 .702 .945 r
.13943 .35642 .14351 .36022 .14899 .35967 .14493 .3558 Mtetra
.497 .682 .949 r
.14493 .3558 .14899 .35967 .15445 .3595 .1504 .35555 Mtetra
.483 .672 .947 r
.1504 .35555 .15445 .3595 .1599 .35947 .15587 .35543 Mtetra
.478 .664 .944 r
.15587 .35543 .1599 .35947 .16537 .35951 .16135 .35538 Mtetra
.477 .659 .941 r
.16135 .35538 .16537 .35951 .17086 .35959 .16685 .35536 Mtetra
.479 .654 .937 r
.16685 .35536 .17086 .35959 .17636 .35967 .17237 .35534 Mtetra
.482 .651 .933 r
.17237 .35534 .17636 .35967 .18189 .35975 .1779 .35533 Mtetra
.485 .647 .929 r
.1779 .35533 .18189 .35975 .18743 .35983 .18346 .35532 Mtetra
.487 .643 .925 r
.18346 .35532 .18743 .35983 .19299 .35992 .18904 .35531 Mtetra
.49 .639 .921 r
.18904 .35531 .19299 .35992 .19858 .36 .19463 .35529 Mtetra
.492 .635 .917 r
.19463 .35529 .19858 .36 .20418 .36008 .20025 .35528 Mtetra
.494 .632 .914 r
.20025 .35528 .20418 .36008 .20981 .36017 .20588 .35526 Mtetra
.497 .628 .91 r
.20588 .35526 .20981 .36017 .21545 .36025 .21154 .35525 Mtetra
.499 .624 .906 r
.21154 .35525 .21545 .36025 .22112 .36033 .21722 .35523 Mtetra
.501 .621 .902 r
.21722 .35523 .22112 .36033 .2268 .36041 .22292 .35521 Mtetra
.502 .617 .898 r
.22292 .35521 .2268 .36041 .23251 .36049 .22863 .3552 Mtetra
.504 .614 .894 r
.22863 .3552 .23251 .36049 .23824 .36057 .23437 .35518 Mtetra
.506 .61 .89 r
.23437 .35518 .23824 .36057 .24399 .36065 .24013 .35516 Mtetra
.507 .607 .887 r
.24013 .35516 .24399 .36065 .24976 .36073 .24591 .35514 Mtetra
.509 .604 .883 r
.24591 .35514 .24976 .36073 .25555 .36082 .25171 .35512 Mtetra
.511 .6 .879 r
.25171 .35512 .25555 .36082 .26136 .3609 .25754 .3551 Mtetra
.512 .597 .876 r
.25754 .3551 .26136 .3609 .2672 .36098 .26338 .35508 Mtetra
.513 .594 .872 r
.26338 .35508 .2672 .36098 .27305 .36106 .26924 .35506 Mtetra
.514 .591 .869 r
.26924 .35506 .27305 .36106 .27893 .36114 .27513 .35504 Mtetra
.516 .587 .865 r
.27513 .35504 .27893 .36114 .28483 .36122 .28104 .35502 Mtetra
.516 .584 .862 r
.28104 .35502 .28483 .36122 .29075 .3613 .28697 .355 Mtetra
.518 .581 .858 r
.28697 .355 .29075 .3613 .29669 .36139 .29292 .35498 Mtetra
.519 .578 .855 r
.29292 .35498 .29669 .36139 .30266 .36147 .29889 .35496 Mtetra
.519 .575 .852 r
.29889 .35496 .30266 .36147 .30865 .36155 .30489 .35494 Mtetra
.52 .572 .848 r
.30489 .35494 .30865 .36155 .31466 .36164 .3109 .35492 Mtetra
.521 .569 .845 r
.3109 .35492 .31466 .36164 .32069 .36172 .31694 .3549 Mtetra
.522 .567 .842 r
.31694 .3549 .32069 .36172 .32675 .3618 .32301 .35488 Mtetra
.523 .564 .839 r
.32301 .35488 .32675 .3618 .33282 .36189 .32909 .35486 Mtetra
.523 .561 .835 r
.32909 .35486 .33282 .36189 .33893 .36198 .3352 .35484 Mtetra
.524 .558 .832 r
.3352 .35484 .33893 .36198 .34505 .36206 .34133 .35482 Mtetra
.525 .556 .829 r
.34133 .35482 .34505 .36206 .3512 .36215 .34748 .3548 Mtetra
.525 .553 .826 r
.34748 .3548 .3512 .36215 .35737 .36224 .35366 .35479 Mtetra
.526 .551 .823 r
.35366 .35479 .35737 .36224 .36356 .36233 .35985 .35477 Mtetra
.526 .548 .821 r
.35985 .35477 .36356 .36233 .36978 .36242 .36608 .35475 Mtetra
.527 .545 .818 r
.36608 .35475 .36978 .36242 .37602 .36251 .37232 .35474 Mtetra
.527 .543 .815 r
.37232 .35474 .37602 .36251 .38229 .3626 .37859 .35472 Mtetra
.528 .541 .812 r
.37859 .35472 .38229 .3626 .38858 .3627 .38488 .3547 Mtetra
.528 .538 .809 r
.38488 .3547 .38858 .3627 .39489 .36279 .3912 .35469 Mtetra
.529 .536 .807 r
.3912 .35469 .39489 .36279 .40123 .36289 .39754 .35468 Mtetra
.529 .534 .804 r
.39754 .35468 .40123 .36289 .40759 .36298 .4039 .35466 Mtetra
.53 .532 .801 r
.4039 .35466 .40759 .36298 .41398 .36307 .41029 .35463 Mtetra
.532 .53 .798 r
.41029 .35463 .41398 .36307 .42039 .36312 .41671 .35458 Mtetra
.538 .531 .795 r
.41671 .35458 .42039 .36312 .42683 .36307 .42315 .35443 Mtetra
.549 .535 .792 r
.42315 .35443 .42683 .36307 .4333 .36279 .42962 .35404 Mtetra
.615 .569 .779 r
.42962 .35404 .4333 .36279 .43984 .36092 .43616 .35215 Mtetra
.689 .606 .759 r
.43616 .35215 .43984 .36092 .44645 .35673 .44277 .34802 Mtetra
.695 .611 .759 r
.44277 .34802 .44645 .35673 .45308 .35232 .4494 .3437 Mtetra
.699 .615 .759 r
.4494 .3437 .45308 .35232 .45971 .34778 .45604 .33924 Mtetra
.702 .618 .76 r
.45604 .33924 .45971 .34778 .46635 .34318 .46268 .33473 Mtetra
.703 .621 .762 r
.46268 .33473 .46635 .34318 .473 .33857 .46933 .33021 Mtetra
.704 .623 .764 r
.46933 .33021 .473 .33857 .47966 .33396 .47599 .32568 Mtetra
.706 .626 .765 r
.47599 .32568 .47966 .33396 .48632 .32934 .48266 .32115 Mtetra
.707 .629 .767 r
.48266 .32115 .48632 .32934 .49299 .32472 .48933 .31661 Mtetra
.708 .631 .769 r
.48933 .31661 .49299 .32472 .49966 .32009 .49601 .31207 Mtetra
.709 .634 .771 r
.49601 .31207 .49966 .32009 .50634 .31546 .50269 .30753 Mtetra
.71 .637 .773 r
.50269 .30753 .50634 .31546 .51303 .31083 .50939 .30298 Mtetra
.712 .639 .775 r
.50939 .30298 .51303 .31083 .51972 .30619 .51608 .29843 Mtetra
.713 .642 .777 r
.51608 .29843 .51972 .30619 .52642 .30155 .52279 .29387 Mtetra
.714 .645 .779 r
.52279 .29387 .52642 .30155 .53313 .29691 .5295 .28931 Mtetra
.715 .648 .781 r
.5295 .28931 .53313 .29691 .53984 .29226 .53622 .28475 Mtetra
.717 .651 .783 r
.53622 .28475 .53984 .29226 .54656 .28761 .54295 .28018 Mtetra
.718 .654 .785 r
.54295 .28018 .54656 .28761 .55329 .28295 .54968 .2756 Mtetra
.719 .657 .787 r
.54968 .2756 .55329 .28295 .56002 .27828 .55642 .27103 Mtetra
.721 .66 .789 r
.55642 .27103 .56002 .27828 .56676 .27362 .56317 .26645 Mtetra
.722 .663 .791 r
.56317 .26645 .56676 .27362 .5735 .26895 .56992 .26186 Mtetra
.723 .666 .793 r
.56992 .26186 .5735 .26895 .58026 .26428 .57668 .25727 Mtetra
.725 .669 .795 r
.57668 .25727 .58026 .26428 .58701 .2596 .58345 .25267 Mtetra
.726 .673 .798 r
.58345 .25267 .58701 .2596 .59378 .25492 .59023 .24807 Mtetra
.727 .676 .8 r
.59023 .24807 .59378 .25492 .60055 .25023 .59701 .24347 Mtetra
.729 .679 .802 r
.59701 .24347 .60055 .25023 .60733 .24554 .6038 .23886 Mtetra
.73 .683 .804 r
.6038 .23886 .60733 .24554 .61411 .24084 .61059 .23425 Mtetra
.732 .686 .807 r
.61059 .23425 .61411 .24084 .6209 .23614 .6174 .22963 Mtetra
.733 .69 .809 r
.6174 .22963 .6209 .23614 .6277 .23144 .62421 .225 Mtetra
.734 .693 .811 r
.62421 .225 .6277 .23144 .6345 .22673 .63102 .22037 Mtetra
.736 .697 .814 r
.63102 .22037 .6345 .22673 .64132 .22201 .63785 .21574 Mtetra
.737 .7 .816 r
.63785 .21574 .64132 .22201 .64813 .21729 .64468 .2111 Mtetra
.739 .704 .818 r
.64468 .2111 .64813 .21729 .65496 .21257 .65152 .20646 Mtetra
.74 .708 .821 r
.65152 .20646 .65496 .21257 .66179 .20784 .65836 .20181 Mtetra
.742 .712 .823 r
.65836 .20181 .66179 .20784 .66862 .2031 .66521 .19715 Mtetra
.743 .716 .826 r
.66521 .19715 .66862 .2031 .67547 .19836 .67207 .19249 Mtetra
.745 .719 .828 r
.67207 .19249 .67547 .19836 .68232 .19362 .67894 .18783 Mtetra
.746 .723 .831 r
.67894 .18783 .68232 .19362 .68918 .18887 .68581 .18316 Mtetra
.748 .728 .833 r
.68581 .18316 .68918 .18887 .69604 .18411 .69269 .17848 Mtetra
.749 .732 .836 r
.69269 .17848 .69604 .18411 .70291 .17935 .69958 .1738 Mtetra
.751 .736 .839 r
.69958 .1738 .70291 .17935 .70979 .17458 .70647 .16912 Mtetra
.752 .74 .841 r
.70647 .16912 .70979 .17458 .71667 .16981 .71338 .16442 Mtetra
.754 .744 .844 r
.71338 .16442 .71667 .16981 .72356 .16503 .72028 .15972 Mtetra
.755 .749 .846 r
.72028 .15972 .72356 .16503 .73046 .16025 .7272 .15502 Mtetra
.757 .753 .849 r
.7272 .15502 .73046 .16025 .73736 .15547 .73412 .15032 Mtetra
.758 .758 .852 r
.73412 .15032 .73736 .15547 .74427 .15068 .74105 .14561 Mtetra
.759 .762 .855 r
.74105 .14561 .74427 .15068 .75119 .14592 .74799 .14092 Mtetra
.757 .765 .859 r
.74799 .14092 .75119 .14592 .75812 .14122 .75495 .1363 Mtetra
.754 .768 .865 r
.75495 .1363 .75812 .14122 .76507 .13665 .76192 .13179 Mtetra
.747 .77 .871 r
.76192 .13179 .76507 .13665 .77205 .13228 .76891 .12748 Mtetra
.545 .705 .944 r
.13534 .3526 .13943 .35642 .14493 .3558 .14085 .35192 Mtetra
.506 .686 .948 r
.14085 .35192 .14493 .3558 .1504 .35555 .14633 .35158 Mtetra
.493 .676 .946 r
.14633 .35158 .1504 .35555 .15587 .35543 .15181 .35137 Mtetra
.489 .669 .943 r
.15181 .35137 .15587 .35543 .16135 .35538 .15731 .35123 Mtetra
.488 .663 .94 r
.15731 .35123 .16135 .35538 .16685 .35536 .16282 .35111 Mtetra
.489 .659 .936 r
.16282 .35111 .16685 .35536 .17237 .35534 .16835 .351 Mtetra
.492 .655 .932 r
.16835 .351 .17237 .35534 .1779 .35533 .1739 .35089 Mtetra
.495 .651 .928 r
.1739 .35089 .1779 .35533 .18346 .35532 .17947 .35078 Mtetra
.497 .647 .924 r
.17947 .35078 .18346 .35532 .18904 .35531 .18506 .35067 Mtetra
.499 .643 .92 r
.18506 .35067 .18904 .35531 .19463 .35529 .19067 .35056 Mtetra
.502 .64 .916 r
.19067 .35056 .19463 .35529 .20025 .35528 .1963 .35045 Mtetra
.504 .636 .913 r
.1963 .35045 .20025 .35528 .20588 .35526 .20195 .35034 Mtetra
.506 .632 .909 r
.20195 .35034 .20588 .35526 .21154 .35525 .20762 .35023 Mtetra
.508 .628 .905 r
.20762 .35023 .21154 .35525 .21722 .35523 .2133 .35011 Mtetra
.509 .625 .901 r
.2133 .35011 .21722 .35523 .22292 .35521 .21901 .34999 Mtetra
.511 .621 .897 r
.21901 .34999 .22292 .35521 .22863 .3552 .22474 .34988 Mtetra
.513 .618 .893 r
.22474 .34988 .22863 .3552 .23437 .35518 .23049 .34976 Mtetra
.514 .614 .889 r
.23049 .34976 .23437 .35518 .24013 .35516 .23626 .34964 Mtetra
.515 .611 .886 r
.23626 .34964 .24013 .35516 .24591 .35514 .24205 .34953 Mtetra
.517 .607 .882 r
.24205 .34953 .24591 .35514 .25171 .35512 .24786 .34941 Mtetra
.518 .604 .878 r
.24786 .34941 .25171 .35512 .25754 .3551 .2537 .34929 Mtetra
.519 .6 .875 r
.2537 .34929 .25754 .3551 .26338 .35508 .25955 .34917 Mtetra
.52 .597 .871 r
.25955 .34917 .26338 .35508 .26924 .35506 .26542 .34905 Mtetra
.522 .594 .868 r
.26542 .34905 .26924 .35506 .27513 .35504 .27132 .34892 Mtetra
.523 .591 .864 r
.27132 .34892 .27513 .35504 .28104 .35502 .27724 .3488 Mtetra
.523 .588 .861 r
.27724 .3488 .28104 .35502 .28697 .355 .28317 .34868 Mtetra
.524 .585 .857 r
.28317 .34868 .28697 .355 .29292 .35498 .28913 .34856 Mtetra
.525 .582 .854 r
.28913 .34856 .29292 .35498 .29889 .35496 .29511 .34843 Mtetra
.526 .579 .851 r
.29511 .34843 .29889 .35496 .30489 .35494 .30112 .34831 Mtetra
.527 .576 .847 r
.30112 .34831 .30489 .35494 .3109 .35492 .30714 .34819 Mtetra
.528 .573 .844 r
.30714 .34819 .3109 .35492 .31694 .3549 .31319 .34806 Mtetra
.528 .57 .841 r
.31319 .34806 .31694 .3549 .32301 .35488 .31926 .34794 Mtetra
.529 .567 .838 r
.31926 .34794 .32301 .35488 .32909 .35486 .32535 .34781 Mtetra
.529 .564 .835 r
.32535 .34781 .32909 .35486 .3352 .35484 .33146 .34769 Mtetra
.53 .562 .832 r
.33146 .34769 .3352 .35484 .34133 .35482 .3376 .34756 Mtetra
.531 .559 .829 r
.3376 .34756 .34133 .35482 .34748 .3548 .34375 .34744 Mtetra
.531 .556 .826 r
.34375 .34744 .34748 .3548 .35366 .35479 .34994 .34732 Mtetra
.532 .554 .823 r
.34994 .34732 .35366 .35479 .35985 .35477 .35614 .34719 Mtetra
.532 .551 .82 r
.35614 .34719 .35985 .35477 .36608 .35475 .36237 .34707 Mtetra
.532 .548 .817 r
.36237 .34707 .36608 .35475 .37232 .35474 .36862 .34694 Mtetra
.533 .546 .814 r
.36862 .34694 .37232 .35474 .37859 .35472 .37489 .34682 Mtetra
.533 .544 .811 r
.37489 .34682 .37859 .35472 .38488 .3547 .38118 .34669 Mtetra
.534 .541 .809 r
.38118 .34669 .38488 .3547 .3912 .35469 .3875 .34657 Mtetra
.534 .539 .806 r
.3875 .34657 .3912 .35469 .39754 .35468 .39385 .34645 Mtetra
.535 .537 .803 r
.39385 .34645 .39754 .35468 .4039 .35466 .40021 .34632 Mtetra
.535 .534 .801 r
.40021 .34632 .4039 .35466 .41029 .35463 .40661 .34619 Mtetra
.537 .533 .798 r
.40661 .34619 .41029 .35463 .41671 .35458 .41302 .34602 Mtetra
.542 .534 .795 r
.41302 .34602 .41671 .35458 .42315 .35443 .41947 .34576 Mtetra
.553 .537 .791 r
.41947 .34576 .42315 .35443 .42962 .35404 .42594 .34528 Mtetra
.616 .569 .779 r
.42594 .34528 .42962 .35404 .43616 .35215 .43248 .34336 Mtetra
.686 .605 .76 r
.43248 .34336 .43616 .35215 .44277 .34802 .43909 .33931 Mtetra
.693 .61 .759 r
.43909 .33931 .44277 .34802 .4494 .3437 .44572 .33506 Mtetra
.697 .614 .76 r
.44572 .33506 .4494 .3437 .45604 .33924 .45236 .33069 Mtetra
.699 .617 .761 r
.45236 .33069 .45604 .33924 .46268 .33473 .45901 .32626 Mtetra
.7 .619 .763 r
.45901 .32626 .46268 .33473 .46933 .33021 .46566 .32183 Mtetra
.702 .622 .765 r
.46566 .32183 .46933 .33021 .47599 .32568 .47232 .31739 Mtetra
.703 .625 .766 r
.47232 .31739 .47599 .32568 .48266 .32115 .47899 .31294 Mtetra
.704 .627 .768 r
.47899 .31294 .48266 .32115 .48933 .31661 .48566 .30849 Mtetra
.705 .63 .77 r
.48566 .30849 .48933 .31661 .49601 .31207 .49235 .30404 Mtetra
.706 .633 .772 r
.49235 .30404 .49601 .31207 .50269 .30753 .49904 .29958 Mtetra
.708 .635 .774 r
.49904 .29958 .50269 .30753 .50939 .30298 .50573 .29511 Mtetra
.709 .638 .776 r
.50573 .29511 .50939 .30298 .51608 .29843 .51244 .29064 Mtetra
.71 .641 .778 r
.51244 .29064 .51608 .29843 .52279 .29387 .51915 .28617 Mtetra
.711 .644 .78 r
.51915 .28617 .52279 .29387 .5295 .28931 .52587 .2817 Mtetra
.713 .647 .782 r
.52587 .2817 .5295 .28931 .53622 .28475 .53259 .27722 Mtetra
.714 .65 .784 r
.53259 .27722 .53622 .28475 .54295 .28018 .53933 .27273 Mtetra
.715 .653 .786 r
.53933 .27273 .54295 .28018 .54968 .2756 .54607 .26824 Mtetra
.716 .656 .788 r
.54607 .26824 .54968 .2756 .55642 .27103 .55282 .26375 Mtetra
.718 .659 .79 r
.55282 .26375 .55642 .27103 .56317 .26645 .55957 .25925 Mtetra
.719 .662 .792 r
.55957 .25925 .56317 .26645 .56992 .26186 .56633 .25475 Mtetra
.72 .665 .795 r
.56633 .25475 .56992 .26186 .57668 .25727 .5731 .25024 Mtetra
.722 .668 .797 r
.5731 .25024 .57668 .25727 .58345 .25267 .57988 .24573 Mtetra
.723 .671 .799 r
.57988 .24573 .58345 .25267 .59023 .24807 .58667 .24121 Mtetra
.724 .675 .801 r
.58667 .24121 .59023 .24807 .59701 .24347 .59346 .23669 Mtetra
.726 .678 .803 r
.59346 .23669 .59701 .24347 .6038 .23886 .60026 .23216 Mtetra
.727 .681 .806 r
.60026 .23216 .6038 .23886 .61059 .23425 .60706 .22763 Mtetra
.729 .685 .808 r
.60706 .22763 .61059 .23425 .6174 .22963 .61388 .22309 Mtetra
.73 .688 .81 r
.61388 .22309 .6174 .22963 .62421 .225 .6207 .21855 Mtetra
.731 .692 .813 r
.6207 .21855 .62421 .225 .63102 .22037 .62753 .214 Mtetra
.733 .696 .815 r
.62753 .214 .63102 .22037 .63785 .21574 .63437 .20945 Mtetra
.734 .699 .817 r
.63437 .20945 .63785 .21574 .64468 .2111 .64121 .20489 Mtetra
.736 .703 .82 r
.64121 .20489 .64468 .2111 .65152 .20646 .64806 .20032 Mtetra
.737 .707 .822 r
.64806 .20032 .65152 .20646 .65836 .20181 .65492 .19576 Mtetra
.739 .71 .825 r
.65492 .19576 .65836 .20181 .66521 .19715 .66179 .19118 Mtetra
.74 .714 .827 r
.66179 .19118 .66521 .19715 .67207 .19249 .66866 .1866 Mtetra
.742 .718 .83 r
.66866 .1866 .67207 .19249 .67894 .18783 .67555 .18202 Mtetra
.743 .722 .832 r
.67555 .18202 .67894 .18783 .68581 .18316 .68243 .17743 Mtetra
.745 .726 .835 r
.68243 .17743 .68581 .18316 .69269 .17848 .68933 .17283 Mtetra
.746 .731 .838 r
.68933 .17283 .69269 .17848 .69958 .1738 .69624 .16823 Mtetra
.747 .735 .84 r
.69624 .16823 .69958 .1738 .70647 .16912 .70315 .16362 Mtetra
.749 .739 .843 r
.70315 .16362 .70647 .16912 .71338 .16442 .71007 .15901 Mtetra
.751 .743 .845 r
.71007 .15901 .71338 .16442 .72028 .15972 .71699 .15439 Mtetra
.752 .748 .848 r
.71699 .15439 .72028 .15972 .7272 .15502 .72393 .14977 Mtetra
.753 .752 .851 r
.72393 .14977 .7272 .15502 .73412 .15032 .73087 .14514 Mtetra
.755 .756 .854 r
.73087 .14514 .73412 .15032 .74105 .14561 .73782 .14051 Mtetra
.755 .761 .857 r
.73782 .14051 .74105 .14561 .74799 .14092 .74478 .1359 Mtetra
.754 .764 .861 r
.74478 .1359 .74799 .14092 .75495 .1363 .75175 .13135 Mtetra
.751 .767 .866 r
.75175 .13135 .75495 .1363 .76192 .13179 .75874 .12691 Mtetra
.744 .769 .873 r
.75874 .12691 .76192 .13179 .76891 .12748 .76576 .12266 Mtetra
.552 .707 .943 r
.13123 .34877 .13534 .3526 .14085 .35192 .13675 .34802 Mtetra
.516 .689 .946 r
.13675 .34802 .14085 .35192 .14633 .35158 .14224 .3476 Mtetra
.504 .68 .945 r
.14224 .3476 .14633 .35158 .15181 .35137 .14774 .3473 Mtetra
.499 .673 .942 r
.14774 .3473 .15181 .35137 .15731 .35123 .15325 .34706 Mtetra
.498 .668 .939 r
.15325 .34706 .15731 .35123 .16282 .35111 .15878 .34685 Mtetra
.5 .663 .935 r
.15878 .34685 .16282 .35111 .16835 .351 .16432 .34664 Mtetra
.502 .659 .931 r
.16432 .34664 .16835 .351 .1739 .35089 .16989 .34644 Mtetra
.505 .655 .927 r
.16989 .34644 .1739 .35089 .17947 .35078 .17547 .34623 Mtetra
.506 .651 .923 r
.17547 .34623 .17947 .35078 .18506 .35067 .18107 .34603 Mtetra
.509 .647 .919 r
.18107 .34603 .18506 .35067 .19067 .35056 .18669 .34582 Mtetra
.511 .644 .915 r
.18669 .34582 .19067 .35056 .1963 .35045 .19234 .34561 Mtetra
.513 .64 .911 r
.19234 .34561 .1963 .35045 .20195 .35034 .198 .3454 Mtetra
.514 .636 .907 r
.198 .3454 .20195 .35034 .20762 .35023 .20368 .34519 Mtetra
.516 .632 .904 r
.20368 .34519 .20762 .35023 .2133 .35011 .20938 .34497 Mtetra
.518 .628 .9 r
.20938 .34497 .2133 .35011 .21901 .34999 .2151 .34476 Mtetra
.519 .625 .896 r
.2151 .34476 .21901 .34999 .22474 .34988 .22084 .34455 Mtetra
.521 .621 .892 r
.22084 .34455 .22474 .34988 .23049 .34976 .2266 .34433 Mtetra
.522 .618 .888 r
.2266 .34433 .23049 .34976 .23626 .34964 .23238 .34411 Mtetra
.523 .614 .885 r
.23238 .34411 .23626 .34964 .24205 .34953 .23818 .34389 Mtetra
.524 .611 .881 r
.23818 .34389 .24205 .34953 .24786 .34941 .244 .34367 Mtetra
.526 .607 .877 r
.244 .34367 .24786 .34941 .2537 .34929 .24985 .34345 Mtetra
.527 .604 .874 r
.24985 .34345 .2537 .34929 .25955 .34917 .25571 .34323 Mtetra
.528 .601 .87 r
.25571 .34323 .25955 .34917 .26542 .34905 .26159 .34301 Mtetra
.529 .597 .867 r
.26159 .34301 .26542 .34905 .27132 .34892 .2675 .34279 Mtetra
.53 .594 .863 r
.2675 .34279 .27132 .34892 .27724 .3488 .27342 .34256 Mtetra
.53 .591 .86 r
.27342 .34256 .27724 .3488 .28317 .34868 .27937 .34234 Mtetra
.531 .588 .856 r
.27937 .34234 .28317 .34868 .28913 .34856 .28534 .34211 Mtetra
.532 .585 .853 r
.28534 .34211 .28913 .34856 .29511 .34843 .29133 .34189 Mtetra
.533 .582 .85 r
.29133 .34189 .29511 .34843 .30112 .34831 .29734 .34166 Mtetra
.533 .579 .847 r
.29734 .34166 .30112 .34831 .30714 .34819 .30337 .34143 Mtetra
.534 .576 .843 r
.30337 .34143 .30714 .34819 .31319 .34806 .30942 .3412 Mtetra
.534 .573 .84 r
.30942 .3412 .31319 .34806 .31926 .34794 .3155 .34097 Mtetra
.535 .57 .837 r
.3155 .34097 .31926 .34794 .32535 .34781 .3216 .34075 Mtetra
.535 .567 .834 r
.3216 .34075 .32535 .34781 .33146 .34769 .32771 .34052 Mtetra
.536 .564 .831 r
.32771 .34052 .33146 .34769 .3376 .34756 .33386 .34028 Mtetra
.536 .562 .828 r
.33386 .34028 .3376 .34756 .34375 .34744 .34002 .34005 Mtetra
.537 .559 .825 r
.34002 .34005 .34375 .34744 .34994 .34732 .34621 .33983 Mtetra
.537 .556 .822 r
.34621 .33983 .34994 .34732 .35614 .34719 .35242 .33959 Mtetra
.538 .554 .819 r
.35242 .33959 .35614 .34719 .36237 .34707 .35865 .33936 Mtetra
.538 .551 .816 r
.35865 .33936 .36237 .34707 .36862 .34694 .3649 .33913 Mtetra
.538 .549 .814 r
.3649 .33913 .36862 .34694 .37489 .34682 .37118 .3389 Mtetra
.539 .546 .811 r
.37118 .3389 .37489 .34682 .38118 .34669 .37748 .33866 Mtetra
.539 .544 .808 r
.37748 .33866 .38118 .34669 .3875 .34657 .3838 .33843 Mtetra
.539 .541 .805 r
.3838 .33843 .3875 .34657 .39385 .34645 .39015 .3382 Mtetra
.54 .539 .803 r
.39015 .3382 .39385 .34645 .40021 .34632 .39652 .33796 Mtetra
.54 .537 .8 r
.39652 .33796 .40021 .34632 .40661 .34619 .40291 .33772 Mtetra
.542 .535 .797 r
.40291 .33772 .40661 .34619 .41302 .34602 .40933 .33745 Mtetra
.547 .536 .794 r
.40933 .33745 .41302 .34602 .41947 .34576 .41577 .33708 Mtetra
.557 .539 .791 r
.41577 .33708 .41947 .34576 .42594 .34528 .42225 .33651 Mtetra
.616 .57 .779 r
.42225 .33651 .42594 .34528 .43248 .34336 .42879 .33456 Mtetra
.684 .604 .76 r
.42879 .33456 .43248 .34336 .43909 .33931 .4354 .33057 Mtetra
.69 .609 .76 r
.4354 .33057 .43909 .33931 .44572 .33506 .44203 .3264 Mtetra
.694 .613 .761 r
.44203 .3264 .44572 .33506 .45236 .33069 .44867 .32211 Mtetra
.697 .616 .762 r
.44867 .32211 .45236 .33069 .45901 .32626 .45532 .31777 Mtetra
.698 .618 .764 r
.45532 .31777 .45901 .32626 .46566 .32183 .46198 .31343 Mtetra
.699 .621 .766 r
.46198 .31343 .46566 .32183 .47232 .31739 .46864 .30907 Mtetra
.7 .623 .767 r
.46864 .30907 .47232 .31739 .47899 .31294 .47531 .30471 Mtetra
.701 .626 .769 r
.47531 .30471 .47899 .31294 .48566 .30849 .48199 .30034 Mtetra
.703 .629 .771 r
.48199 .30034 .48566 .30849 .49235 .30404 .48868 .29598 Mtetra
.704 .631 .773 r
.48868 .29598 .49235 .30404 .49904 .29958 .49537 .2916 Mtetra
.705 .634 .775 r
.49537 .2916 .49904 .29958 .50573 .29511 .50207 .28722 Mtetra
.706 .637 .777 r
.50207 .28722 .50573 .29511 .51244 .29064 .50878 .28284 Mtetra
.707 .64 .779 r
.50878 .28284 .51244 .29064 .51915 .28617 .5155 .27845 Mtetra
.709 .643 .781 r
.5155 .27845 .51915 .28617 .52587 .2817 .52222 .27406 Mtetra
.71 .645 .783 r
.52222 .27406 .52587 .2817 .53259 .27722 .52896 .26966 Mtetra
.711 .648 .785 r
.52896 .26966 .53259 .27722 .53933 .27273 .5357 .26526 Mtetra
.712 .651 .787 r
.5357 .26526 .53933 .27273 .54607 .26824 .54244 .26086 Mtetra
.714 .654 .789 r
.54244 .26086 .54607 .26824 .55282 .26375 .5492 .25645 Mtetra
.715 .657 .791 r
.5492 .25645 .55282 .26375 .55957 .25925 .55596 .25203 Mtetra
.716 .66 .794 r
.55596 .25203 .55957 .25925 .56633 .25475 .56273 .24761 Mtetra
.717 .664 .796 r
.56273 .24761 .56633 .25475 .5731 .25024 .56951 .24319 Mtetra
.719 .667 .798 r
.56951 .24319 .5731 .25024 .57988 .24573 .5763 .23876 Mtetra
.72 .67 .8 r
.5763 .23876 .57988 .24573 .58667 .24121 .58309 .23432 Mtetra
.721 .673 .802 r
.58309 .23432 .58667 .24121 .59346 .23669 .5899 .22988 Mtetra
.723 .677 .805 r
.5899 .22988 .59346 .23669 .60026 .23216 .59671 .22544 Mtetra
.724 .68 .807 r
.59671 .22544 .60026 .23216 .60706 .22763 .60352 .22099 Mtetra
.726 .684 .809 r
.60352 .22099 .60706 .22763 .61388 .22309 .61035 .21653 Mtetra
.727 .687 .812 r
.61035 .21653 .61388 .22309 .6207 .21855 .61718 .21207 Mtetra
.728 .691 .814 r
.61718 .21207 .6207 .21855 .62753 .214 .62403 .2076 Mtetra
.73 .694 .817 r
.62403 .2076 .62753 .214 .63437 .20945 .63087 .20313 Mtetra
.731 .698 .819 r
.63087 .20313 .63437 .20945 .64121 .20489 .63773 .19865 Mtetra
.733 .702 .821 r
.63773 .19865 .64121 .20489 .64806 .20032 .6446 .19417 Mtetra
.734 .705 .824 r
.6446 .19417 .64806 .20032 .65492 .19576 .65147 .18968 Mtetra
.735 .709 .826 r
.65147 .18968 .65492 .19576 .66179 .19118 .65835 .18519 Mtetra
.737 .713 .829 r
.65835 .18519 .66179 .19118 .66866 .1866 .66524 .18069 Mtetra
.738 .717 .831 r
.66524 .18069 .66866 .1866 .67555 .18202 .67214 .17619 Mtetra
.74 .721 .834 r
.67214 .17619 .67555 .18202 .68243 .17743 .67904 .17168 Mtetra
.741 .725 .837 r
.67904 .17168 .68243 .17743 .68933 .17283 .68596 .16716 Mtetra
.743 .729 .839 r
.68596 .16716 .68933 .17283 .69624 .16823 .69288 .16264 Mtetra
.744 .733 .842 r
.69288 .16264 .69624 .16823 .70315 .16362 .69981 .15811 Mtetra
.746 .738 .845 r
.69981 .15811 .70315 .16362 .71007 .15901 .70675 .15357 Mtetra
.747 .742 .847 r
.70675 .15357 .71007 .15901 .71699 .15439 .71369 .14903 Mtetra
.749 .746 .85 r
.71369 .14903 .71699 .15439 .72393 .14977 .72064 .14449 Mtetra
.75 .751 .853 r
.72064 .14449 .72393 .14977 .73087 .14514 .72761 .13994 Mtetra
.751 .755 .856 r
.72761 .13994 .73087 .14514 .73782 .14051 .73458 .13539 Mtetra
.752 .759 .859 r
.73458 .13539 .73782 .14051 .74478 .1359 .74156 .13086 Mtetra
.751 .763 .863 r
.74156 .13086 .74478 .1359 .75175 .13135 .74855 .12638 Mtetra
.747 .766 .868 r
.74855 .12638 .75175 .13135 .75874 .12691 .75556 .12201 Mtetra
.741 .768 .874 r
.75556 .12201 .75874 .12691 .76576 .12266 .76259 .11782 Mtetra
.558 .709 .941 r
.1271 .34493 .13123 .34877 .13675 .34802 .13263 .3441 Mtetra
.525 .693 .945 r
.13263 .3441 .13675 .34802 .14224 .3476 .13814 .3436 Mtetra
.513 .684 .944 r
.13814 .3436 .14224 .3476 .14774 .3473 .14366 .34321 Mtetra
.509 .677 .941 r
.14366 .34321 .14774 .3473 .15325 .34706 .14918 .34287 Mtetra
.508 .672 .937 r
.14918 .34287 .15325 .34706 .15878 .34685 .15472 .34257 Mtetra
.51 .667 .934 r
.15472 .34257 .15878 .34685 .16432 .34664 .16028 .34227 Mtetra
.512 .663 .93 r
.16028 .34227 .16432 .34664 .16989 .34644 .16586 .34196 Mtetra
.514 .659 .926 r
.16586 .34196 .16989 .34644 .17547 .34623 .17145 .34166 Mtetra
.516 .655 .922 r
.17145 .34166 .17547 .34623 .18107 .34603 .17707 .34136 Mtetra
.518 .651 .918 r
.17707 .34136 .18107 .34603 .18669 .34582 .1827 .34106 Mtetra
.52 .647 .914 r
.1827 .34106 .18669 .34582 .19234 .34561 .18836 .34075 Mtetra
.521 .643 .91 r
.18836 .34075 .19234 .34561 .198 .3454 .19403 .34044 Mtetra
.523 .64 .906 r
.19403 .34044 .198 .3454 .20368 .34519 .19972 .34013 Mtetra
.525 .636 .902 r
.19972 .34013 .20368 .34519 .20938 .34497 .20544 .33982 Mtetra
.526 .632 .899 r
.20544 .33982 .20938 .34497 .2151 .34476 .21117 .33951 Mtetra
.527 .628 .895 r
.21117 .33951 .2151 .34476 .22084 .34455 .21692 .33919 Mtetra
.529 .625 .891 r
.21692 .33919 .22084 .34455 .2266 .34433 .22269 .33888 Mtetra
.53 .621 .887 r
.22269 .33888 .2266 .34433 .23238 .34411 .22849 .33856 Mtetra
.531 .618 .884 r
.22849 .33856 .23238 .34411 .23818 .34389 .2343 .33824 Mtetra
.532 .614 .88 r
.2343 .33824 .23818 .34389 .244 .34367 .24013 .33792 Mtetra
.533 .611 .876 r
.24013 .33792 .244 .34367 .24985 .34345 .24598 .3376 Mtetra
.534 .607 .873 r
.24598 .3376 .24985 .34345 .25571 .34323 .25185 .33728 Mtetra
.535 .604 .869 r
.25185 .33728 .25571 .34323 .26159 .34301 .25775 .33696 Mtetra
.536 .601 .866 r
.25775 .33696 .26159 .34301 .2675 .34279 .26366 .33663 Mtetra
.536 .597 .862 r
.26366 .33663 .2675 .34279 .27342 .34256 .2696 .33631 Mtetra
.537 .594 .859 r
.2696 .33631 .27342 .34256 .27937 .34234 .27555 .33598 Mtetra
.538 .591 .856 r
.27555 .33598 .27937 .34234 .28534 .34211 .28153 .33565 Mtetra
.538 .588 .852 r
.28153 .33565 .28534 .34211 .29133 .34189 .28753 .33532 Mtetra
.539 .585 .849 r
.28753 .33532 .29133 .34189 .29734 .34166 .29355 .33499 Mtetra
.539 .582 .846 r
.29355 .33499 .29734 .34166 .30337 .34143 .29959 .33466 Mtetra
.54 .579 .843 r
.29959 .33466 .30337 .34143 .30942 .3412 .30565 .33433 Mtetra
.541 .576 .839 r
.30565 .33433 .30942 .3412 .3155 .34097 .31173 .334 Mtetra
.541 .573 .836 r
.31173 .334 .3155 .34097 .3216 .34075 .31783 .33366 Mtetra
.541 .57 .833 r
.31783 .33366 .3216 .34075 .32771 .34052 .32396 .33333 Mtetra
.542 .568 .83 r
.32396 .33333 .32771 .34052 .33386 .34028 .33011 .33299 Mtetra
.542 .565 .827 r
.33011 .33299 .33386 .34028 .34002 .34005 .33628 .33266 Mtetra
.542 .562 .824 r
.33628 .33266 .34002 .34005 .34621 .33983 .34247 .33232 Mtetra
.543 .559 .821 r
.34247 .33232 .34621 .33983 .35242 .33959 .34868 .33198 Mtetra
.543 .557 .819 r
.34868 .33198 .35242 .33959 .35865 .33936 .35492 .33164 Mtetra
.543 .554 .816 r
.35492 .33164 .35865 .33936 .3649 .33913 .36118 .3313 Mtetra
.544 .552 .813 r
.36118 .3313 .3649 .33913 .37118 .3389 .36746 .33096 Mtetra
.544 .549 .81 r
.36746 .33096 .37118 .3389 .37748 .33866 .37376 .33062 Mtetra
.544 .547 .808 r
.37376 .33062 .37748 .33866 .3838 .33843 .38009 .33028 Mtetra
.544 .544 .805 r
.38009 .33028 .3838 .33843 .39015 .3382 .38644 .32994 Mtetra
.545 .542 .802 r
.38644 .32994 .39015 .3382 .39652 .33796 .39281 .32959 Mtetra
.545 .54 .8 r
.39281 .32959 .39652 .33796 .40291 .33772 .39921 .32924 Mtetra
.547 .538 .797 r
.39921 .32924 .40291 .33772 .40933 .33745 .40563 .32886 Mtetra
.551 .538 .794 r
.40563 .32886 .40933 .33745 .41577 .33708 .41208 .32839 Mtetra
.561 .542 .79 r
.41208 .32839 .41577 .33708 .42225 .33651 .41856 .32772 Mtetra
.617 .57 .779 r
.41856 .32772 .42225 .33651 .42879 .33456 .4251 .32574 Mtetra
.682 .603 .761 r
.4251 .32574 .42879 .33456 .4354 .33057 .43171 .32183 Mtetra
.688 .608 .761 r
.43171 .32183 .4354 .33057 .44203 .3264 .43834 .31773 Mtetra
.692 .611 .762 r
.43834 .31773 .44203 .3264 .44867 .32211 .44498 .31353 Mtetra
.694 .614 .763 r
.44498 .31353 .44867 .32211 .45532 .31777 .45163 .30928 Mtetra
.695 .617 .765 r
.45163 .30928 .45532 .31777 .46198 .31343 .45829 .30501 Mtetra
.696 .619 .767 r
.45829 .30501 .46198 .31343 .46864 .30907 .46495 .30075 Mtetra
.698 .622 .768 r
.46495 .30075 .46864 .30907 .47531 .30471 .47163 .29647 Mtetra
.699 .625 .77 r
.47163 .29647 .47531 .30471 .48199 .30034 .47831 .29219 Mtetra
.7 .627 .772 r
.47831 .29219 .48199 .30034 .48868 .29598 .485 .2879 Mtetra
.701 .63 .774 r
.485 .2879 .48868 .29598 .49537 .2916 .4917 .28361 Mtetra
.702 .633 .776 r
.4917 .28361 .49537 .2916 .50207 .28722 .4984 .27932 Mtetra
.703 .636 .778 r
.4984 .27932 .50207 .28722 .50878 .28284 .50512 .27502 Mtetra
.705 .638 .78 r
.50512 .27502 .50878 .28284 .5155 .27845 .51184 .27072 Mtetra
.706 .641 .782 r
.51184 .27072 .5155 .27845 .52222 .27406 .51857 .26641 Mtetra
.707 .644 .784 r
.51857 .26641 .52222 .27406 .52896 .26966 .52531 .2621 Mtetra
.708 .647 .786 r
.52531 .2621 .52896 .26966 .5357 .26526 .53205 .25778 Mtetra
.709 .65 .788 r
.53205 .25778 .5357 .26526 .54244 .26086 .53881 .25346 Mtetra
.711 .653 .791 r
.53881 .25346 .54244 .26086 .5492 .25645 .54557 .24913 Mtetra
.712 .656 .793 r
.54557 .24913 .5492 .25645 .55596 .25203 .55234 .2448 Mtetra
.713 .659 .795 r
.55234 .2448 .55596 .25203 .56273 .24761 .55912 .24046 Mtetra
.715 .662 .797 r
.55912 .24046 .56273 .24761 .56951 .24319 .56591 .23612 Mtetra
.716 .666 .799 r
.56591 .23612 .56951 .24319 .5763 .23876 .57271 .23177 Mtetra
.717 .669 .802 r
.57271 .23177 .5763 .23876 .58309 .23432 .57951 .22742 Mtetra
.719 .672 .804 r
.57951 .22742 .58309 .23432 .5899 .22988 .58632 .22306 Mtetra
.72 .676 .806 r
.58632 .22306 .5899 .22988 .59671 .22544 .59314 .21869 Mtetra
.721 .679 .808 r
.59314 .21869 .59671 .22544 .60352 .22099 .59997 .21432 Mtetra
.723 .682 .811 r
.59997 .21432 .60352 .22099 .61035 .21653 .60681 .20995 Mtetra
.724 .686 .813 r
.60681 .20995 .61035 .21653 .61718 .21207 .61365 .20557 Mtetra
.725 .689 .816 r
.61365 .20557 .61718 .21207 .62403 .2076 .62051 .20119 Mtetra
.727 .693 .818 r
.62051 .20119 .62403 .2076 .63087 .20313 .62737 .1968 Mtetra
.728 .697 .82 r
.62737 .1968 .63087 .20313 .63773 .19865 .63424 .1924 Mtetra
.729 .7 .823 r
.63424 .1924 .63773 .19865 .6446 .19417 .64112 .188 Mtetra
.731 .704 .825 r
.64112 .188 .6446 .19417 .65147 .18968 .64801 .18359 Mtetra
.732 .708 .828 r
.64801 .18359 .65147 .18968 .65835 .18519 .6549 .17918 Mtetra
.734 .712 .83 r
.6549 .17918 .65835 .18519 .66524 .18069 .66181 .17476 Mtetra
.735 .716 .833 r
.66181 .17476 .66524 .18069 .67214 .17619 .66872 .17033 Mtetra
.736 .72 .836 r
.66872 .17033 .67214 .17619 .67904 .17168 .67564 .1659 Mtetra
.738 .724 .838 r
.67564 .1659 .67904 .17168 .68596 .16716 .68257 .16146 Mtetra
.739 .728 .841 r
.68257 .16146 .68596 .16716 .69288 .16264 .68951 .15702 Mtetra
.741 .732 .844 r
.68951 .15702 .69288 .16264 .69981 .15811 .69646 .15257 Mtetra
.742 .736 .846 r
.69646 .15257 .69981 .15811 .70675 .15357 .70341 .14812 Mtetra
.744 .741 .849 r
.70341 .14812 .70675 .15357 .71369 .14903 .71037 .14365 Mtetra
.745 .745 .852 r
.71037 .14365 .71369 .14903 .72064 .14449 .71735 .13919 Mtetra
.746 .75 .855 r
.71735 .13919 .72064 .14449 .72761 .13994 .72433 .13472 Mtetra
.748 .754 .857 r
.72433 .13472 .72761 .13994 .73458 .13539 .73132 .13025 Mtetra
.748 .758 .861 r
.73132 .13025 .73458 .13539 .74156 .13086 .73832 .12579 Mtetra
.747 .762 .865 r
.73832 .12579 .74156 .13086 .74855 .12638 .74533 .12139 Mtetra
.744 .765 .87 r
.74533 .12139 .74855 .12638 .75556 .12201 .75236 .11709 Mtetra
.738 .766 .876 r
.75236 .11709 .75556 .12201 .76259 .11782 .75941 .11296 Mtetra
.565 .711 .94 r
.12296 .34106 .1271 .34493 .13263 .3441 .1285 .34017 Mtetra
.533 .696 .944 r
.1285 .34017 .13263 .3441 .13814 .3436 .13403 .33958 Mtetra
.523 .688 .942 r
.13403 .33958 .13814 .3436 .14366 .34321 .13955 .3391 Mtetra
.519 .681 .939 r
.13955 .3391 .14366 .34321 .14918 .34287 .14509 .33867 Mtetra
.518 .676 .936 r
.14509 .33867 .14918 .34287 .15472 .34257 .15065 .33827 Mtetra
.519 .671 .932 r
.15065 .33827 .15472 .34257 .16028 .34227 .15622 .33787 Mtetra
.522 .667 .928 r
.15622 .33787 .16028 .34227 .16586 .34196 .16181 .33748 Mtetra
.523 .663 .924 r
.16181 .33748 .16586 .34196 .17145 .34166 .16742 .33708 Mtetra
.525 .659 .921 r
.16742 .33708 .17145 .34166 .17707 .34136 .17305 .33668 Mtetra
.527 .655 .917 r
.17305 .33668 .17707 .34136 .1827 .34106 .1787 .33628 Mtetra
.528 .651 .913 r
.1787 .33628 .1827 .34106 .18836 .34075 .18437 .33587 Mtetra
.53 .647 .909 r
.18437 .33587 .18836 .34075 .19403 .34044 .19005 .33547 Mtetra
.531 .643 .905 r
.19005 .33547 .19403 .34044 .19972 .34013 .19576 .33506 Mtetra
.533 .64 .901 r
.19576 .33506 .19972 .34013 .20544 .33982 .20148 .33465 Mtetra
.534 .636 .897 r
.20148 .33465 .20544 .33982 .21117 .33951 .20723 .33424 Mtetra
.535 .632 .894 r
.20723 .33424 .21117 .33951 .21692 .33919 .21299 .33383 Mtetra
.536 .628 .89 r
.21299 .33383 .21692 .33919 .22269 .33888 .21877 .33341 Mtetra
.537 .625 .886 r
.21877 .33341 .22269 .33888 .22849 .33856 .22458 .33299 Mtetra
.538 .621 .883 r
.22458 .33299 .22849 .33856 .2343 .33824 .2304 .33258 Mtetra
.539 .617 .879 r
.2304 .33258 .2343 .33824 .24013 .33792 .23624 .33216 Mtetra
.54 .614 .875 r
.23624 .33216 .24013 .33792 .24598 .3376 .24211 .33173 Mtetra
.541 .611 .872 r
.24211 .33173 .24598 .3376 .25185 .33728 .24799 .33131 Mtetra
.541 .607 .868 r
.24799 .33131 .25185 .33728 .25775 .33696 .25389 .33089 Mtetra
.542 .604 .865 r
.25389 .33089 .25775 .33696 .26366 .33663 .25982 .33046 Mtetra
.543 .601 .861 r
.25982 .33046 .26366 .33663 .2696 .33631 .26576 .33003 Mtetra
.543 .597 .858 r
.26576 .33003 .2696 .33631 .27555 .33598 .27173 .32961 Mtetra
.544 .594 .855 r
.27173 .32961 .27555 .33598 .28153 .33565 .27771 .32918 Mtetra
.545 .591 .851 r
.27771 .32918 .28153 .33565 .28753 .33532 .28372 .32874 Mtetra
.545 .588 .848 r
.28372 .32874 .28753 .33532 .29355 .33499 .28974 .32831 Mtetra
.545 .585 .845 r
.28974 .32831 .29355 .33499 .29959 .33466 .29579 .32788 Mtetra
.546 .582 .842 r
.29579 .32788 .29959 .33466 .30565 .33433 .30186 .32744 Mtetra
.546 .579 .839 r
.30186 .32744 .30565 .33433 .31173 .334 .30795 .327 Mtetra
.547 .576 .836 r
.30795 .327 .31173 .334 .31783 .33366 .31406 .32656 Mtetra
.547 .573 .832 r
.31406 .32656 .31783 .33366 .32396 .33333 .3202 .32613 Mtetra
.547 .57 .829 r
.3202 .32613 .32396 .33333 .33011 .33299 .32635 .32568 Mtetra
.548 .568 .827 r
.32635 .32568 .33011 .33299 .33628 .33266 .33253 .32524 Mtetra
.548 .565 .824 r
.33253 .32524 .33628 .33266 .34247 .33232 .33872 .3248 Mtetra
.548 .562 .821 r
.33872 .3248 .34247 .33232 .34868 .33198 .34494 .32435 Mtetra
.548 .56 .818 r
.34494 .32435 .34868 .33198 .35492 .33164 .35119 .32391 Mtetra
.549 .557 .815 r
.35119 .32391 .35492 .33164 .36118 .3313 .35745 .32346 Mtetra
.549 .554 .812 r
.35745 .32346 .36118 .3313 .36746 .33096 .36374 .32302 Mtetra
.549 .552 .81 r
.36374 .32302 .36746 .33096 .37376 .33062 .37004 .32256 Mtetra
.549 .549 .807 r
.37004 .32256 .37376 .33062 .38009 .33028 .37637 .32212 Mtetra
.549 .547 .804 r
.37637 .32212 .38009 .33028 .38644 .32994 .38273 .32167 Mtetra
.55 .545 .802 r
.38273 .32167 .38644 .32994 .39281 .32959 .3891 .32121 Mtetra
.55 .543 .799 r
.3891 .32121 .39281 .32959 .39921 .32924 .3955 .32075 Mtetra
.551 .541 .796 r
.3955 .32075 .39921 .32924 .40563 .32886 .40193 .32026 Mtetra
.556 .541 .793 r
.40193 .32026 .40563 .32886 .41208 .32839 .40838 .31968 Mtetra
.565 .544 .79 r
.40838 .31968 .41208 .32839 .41856 .32772 .41485 .31892 Mtetra
.618 .57 .779 r
.41485 .31892 .41856 .32772 .4251 .32574 .4214 .31691 Mtetra
.68 .602 .762 r
.4214 .31691 .4251 .32574 .43171 .32183 .42801 .31307 Mtetra
.685 .606 .762 r
.42801 .31307 .43171 .32183 .43834 .31773 .43464 .30905 Mtetra
.689 .61 .763 r
.43464 .30905 .43834 .31773 .44498 .31353 .44128 .30493 Mtetra
.691 .613 .764 r
.44128 .30493 .44498 .31353 .45163 .30928 .44793 .30076 Mtetra
.693 .616 .766 r
.44793 .30076 .45163 .30928 .45829 .30501 .45459 .29659 Mtetra
.694 .618 .768 r
.45459 .29659 .45829 .30501 .46495 .30075 .46126 .2924 Mtetra
.695 .621 .77 r
.46126 .2924 .46495 .30075 .47163 .29647 .46794 .28821 Mtetra
.696 .624 .771 r
.46794 .28821 .47163 .29647 .47831 .29219 .47462 .28401 Mtetra
.697 .626 .773 r
.47462 .28401 .47831 .29219 .485 .2879 .48131 .27981 Mtetra
.698 .629 .775 r
.48131 .27981 .485 .2879 .4917 .28361 .48802 .27561 Mtetra
.699 .632 .777 r
.48802 .27561 .4917 .28361 .4984 .27932 .49473 .2714 Mtetra
.701 .634 .779 r
.49473 .2714 .4984 .27932 .50512 .27502 .50145 .26718 Mtetra
.702 .637 .781 r
.50145 .26718 .50512 .27502 .51184 .27072 .50817 .26297 Mtetra
.703 .64 .783 r
.50817 .26297 .51184 .27072 .51857 .26641 .51491 .25874 Mtetra
.704 .643 .785 r
.51491 .25874 .51857 .26641 .52531 .2621 .52165 .25451 Mtetra
.705 .646 .788 r
.52165 .25451 .52531 .2621 .53205 .25778 .52841 .25028 Mtetra
.707 .649 .79 r
.52841 .25028 .53205 .25778 .53881 .25346 .53517 .24604 Mtetra
.708 .652 .792 r
.53517 .24604 .53881 .25346 .54557 .24913 .54194 .24179 Mtetra
.709 .655 .794 r
.54194 .24179 .54557 .24913 .55234 .2448 .54872 .23754 Mtetra
.71 .658 .796 r
.54872 .23754 .55234 .2448 .55912 .24046 .5555 .23329 Mtetra
.712 .661 .798 r
.5555 .23329 .55912 .24046 .56591 .23612 .5623 .22903 Mtetra
.713 .664 .801 r
.5623 .22903 .56591 .23612 .57271 .23177 .5691 .22476 Mtetra
.714 .668 .803 r
.5691 .22476 .57271 .23177 .57951 .22742 .57592 .22049 Mtetra
.716 .671 .805 r
.57592 .22049 .57951 .22742 .58632 .22306 .58274 .21621 Mtetra
.717 .674 .807 r
.58274 .21621 .58632 .22306 .59314 .21869 .58957 .21193 Mtetra
.718 .678 .81 r
.58957 .21193 .59314 .21869 .59997 .21432 .59641 .20764 Mtetra
.719 .681 .812 r
.59641 .20764 .59997 .21432 .60681 .20995 .60326 .20335 Mtetra
.721 .685 .815 r
.60326 .20335 .60681 .20995 .61365 .20557 .61011 .19905 Mtetra
.722 .688 .817 r
.61011 .19905 .61365 .20557 .62051 .20119 .61698 .19475 Mtetra
.723 .692 .819 r
.61698 .19475 .62051 .20119 .62737 .1968 .62385 .19044 Mtetra
.725 .696 .822 r
.62385 .19044 .62737 .1968 .63424 .1924 .63074 .18612 Mtetra
.726 .699 .824 r
.63074 .18612 .63424 .1924 .64112 .188 .63763 .1818 Mtetra
.728 .703 .827 r
.63763 .1818 .64112 .188 .64801 .18359 .64453 .17747 Mtetra
.729 .707 .83 r
.64453 .17747 .64801 .18359 .6549 .17918 .65144 .17314 Mtetra
.73 .711 .832 r
.65144 .17314 .6549 .17918 .66181 .17476 .65836 .1688 Mtetra
.732 .715 .835 r
.65836 .1688 .66181 .17476 .66872 .17033 .66529 .16445 Mtetra
.733 .719 .837 r
.66529 .16445 .66872 .17033 .67564 .1659 .67222 .1601 Mtetra
.735 .723 .84 r
.67222 .1601 .67564 .1659 .68257 .16146 .67917 .15575 Mtetra
.736 .727 .843 r
.67917 .15575 .68257 .16146 .68951 .15702 .68612 .15138 Mtetra
.737 .731 .845 r
.68612 .15138 .68951 .15702 .69646 .15257 .69309 .14701 Mtetra
.739 .735 .848 r
.69309 .14701 .69646 .15257 .70341 .14812 .70006 .14264 Mtetra
.74 .74 .851 r
.70006 .14264 .70341 .14812 .71037 .14365 .70704 .13825 Mtetra
.742 .744 .854 r
.70704 .13825 .71037 .14365 .71735 .13919 .71403 .13387 Mtetra
.743 .748 .856 r
.71403 .13387 .71735 .13919 .72433 .13472 .72103 .12948 Mtetra
.744 .753 .859 r
.72103 .12948 .72433 .13472 .73132 .13025 .72804 .12508 Mtetra
.745 .757 .863 r
.72804 .12508 .73132 .13025 .73832 .12579 .73506 .1207 Mtetra
.744 .761 .867 r
.73506 .1207 .73832 .12579 .74533 .12139 .74209 .11638 Mtetra
.741 .764 .871 r
.74209 .11638 .74533 .12139 .75236 .11709 .74914 .11214 Mtetra
.735 .765 .877 r
.74914 .11214 .75236 .11709 .75941 .11296 .75622 .10807 Mtetra
.571 .714 .939 r
.1188 .33719 .12296 .34106 .1285 .34017 .12435 .33622 Mtetra
.542 .7 .942 r
.12435 .33622 .1285 .34017 .13403 .33958 .12989 .33555 Mtetra
.532 .691 .941 r
.12989 .33555 .13403 .33958 .13955 .3391 .13544 .33498 Mtetra
.529 .685 .938 r
.13544 .33498 .13955 .3391 .14509 .33867 .14099 .33445 Mtetra
.528 .68 .935 r
.14099 .33445 .14509 .33867 .15065 .33827 .14656 .33396 Mtetra
.529 .675 .931 r
.14656 .33396 .15065 .33827 .15622 .33787 .15215 .33346 Mtetra
.531 .671 .927 r
.15215 .33346 .15622 .33787 .16181 .33748 .15775 .33297 Mtetra
.532 .667 .923 r
.15775 .33297 .16181 .33748 .16742 .33708 .16338 .33247 Mtetra
.534 .663 .919 r
.16338 .33247 .16742 .33708 .17305 .33668 .16902 .33198 Mtetra
.535 .659 .915 r
.16902 .33198 .17305 .33668 .1787 .33628 .17468 .33148 Mtetra
.537 .655 .911 r
.17468 .33148 .1787 .33628 .18437 .33587 .18036 .33097 Mtetra
.538 .651 .907 r
.18036 .33097 .18437 .33587 .19005 .33547 .18606 .33047 Mtetra
.539 .647 .904 r
.18606 .33047 .19005 .33547 .19576 .33506 .19178 .32997 Mtetra
.541 .643 .9 r
.19178 .32997 .19576 .33506 .20148 .33465 .19752 .32946 Mtetra
.542 .639 .896 r
.19752 .32946 .20148 .33465 .20723 .33424 .20327 .32895 Mtetra
.543 .635 .892 r
.20327 .32895 .20723 .33424 .21299 .33383 .20905 .32844 Mtetra
.544 .632 .889 r
.20905 .32844 .21299 .33383 .21877 .33341 .21484 .32792 Mtetra
.545 .628 .885 r
.21484 .32792 .21877 .33341 .22458 .33299 .22066 .32741 Mtetra
.545 .624 .881 r
.22066 .32741 .22458 .33299 .2304 .33258 .22649 .32689 Mtetra
.546 .621 .878 r
.22649 .32689 .2304 .33258 .23624 .33216 .23235 .32637 Mtetra
.547 .617 .874 r
.23235 .32637 .23624 .33216 .24211 .33173 .23822 .32585 Mtetra
.548 .614 .871 r
.23822 .32585 .24211 .33173 .24799 .33131 .24411 .32532 Mtetra
.548 .61 .867 r
.24411 .32532 .24799 .33131 .25389 .33089 .25003 .3248 Mtetra
.549 .607 .864 r
.25003 .3248 .25389 .33089 .25982 .33046 .25596 .32427 Mtetra
.549 .604 .86 r
.25596 .32427 .25982 .33046 .26576 .33003 .26191 .32374 Mtetra
.55 .6 .857 r
.26191 .32374 .26576 .33003 .27173 .32961 .26789 .32321 Mtetra
.55 .597 .854 r
.26789 .32321 .27173 .32961 .27771 .32918 .27388 .32268 Mtetra
.551 .594 .85 r
.27388 .32268 .27771 .32918 .28372 .32874 .2799 .32214 Mtetra
.551 .591 .847 r
.2799 .32214 .28372 .32874 .28974 .32831 .28593 .32161 Mtetra
.551 .588 .844 r
.28593 .32161 .28974 .32831 .29579 .32788 .29199 .32107 Mtetra
.552 .585 .841 r
.29199 .32107 .29579 .32788 .30186 .32744 .29807 .32053 Mtetra
.552 .582 .838 r
.29807 .32053 .30186 .32744 .30795 .327 .30416 .31999 Mtetra
.552 .579 .835 r
.30416 .31999 .30795 .327 .31406 .32656 .31028 .31945 Mtetra
.553 .576 .832 r
.31028 .31945 .31406 .32656 .3202 .32613 .31642 .3189 Mtetra
.553 .573 .829 r
.31642 .3189 .3202 .32613 .32635 .32568 .32258 .31835 Mtetra
.553 .57 .826 r
.32258 .31835 .32635 .32568 .33253 .32524 .32877 .31781 Mtetra
.553 .568 .823 r
.32877 .31781 .33253 .32524 .33872 .3248 .33497 .31726 Mtetra
.554 .565 .82 r
.33497 .31726 .33872 .3248 .34494 .32435 .3412 .31671 Mtetra
.554 .562 .817 r
.3412 .31671 .34494 .32435 .35119 .32391 .34744 .31615 Mtetra
.554 .56 .814 r
.34744 .31615 .35119 .32391 .35745 .32346 .35371 .3156 Mtetra
.554 .557 .812 r
.35371 .3156 .35745 .32346 .36374 .32302 .36 .31505 Mtetra
.554 .555 .809 r
.36 .31505 .36374 .32302 .37004 .32256 .36632 .31449 Mtetra
.554 .552 .806 r
.36632 .31449 .37004 .32256 .37637 .32212 .37265 .31393 Mtetra
.554 .549 .804 r
.37265 .31393 .37637 .32212 .38273 .32167 .37901 .31337 Mtetra
.555 .547 .801 r
.37901 .31337 .38273 .32167 .3891 .32121 .38539 .31281 Mtetra
.555 .545 .798 r
.38539 .31281 .3891 .32121 .3955 .32075 .39179 .31224 Mtetra
.556 .543 .796 r
.39179 .31224 .3955 .32075 .40193 .32026 .39822 .31164 Mtetra
.56 .543 .793 r
.39822 .31164 .40193 .32026 .40838 .31968 .40467 .31096 Mtetra
.568 .546 .789 r
.40467 .31096 .40838 .31968 .41485 .31892 .41115 .3101 Mtetra
.618 .571 .779 r
.41115 .3101 .41485 .31892 .4214 .31691 .41769 .30807 Mtetra
.677 .601 .763 r
.41769 .30807 .4214 .31691 .42801 .31307 .4243 .30429 Mtetra
.683 .605 .763 r
.4243 .30429 .42801 .31307 .43464 .30905 .43093 .30035 Mtetra
.686 .609 .763 r
.43093 .30035 .43464 .30905 .44128 .30493 .43758 .29631 Mtetra
.689 .612 .765 r
.43758 .29631 .44128 .30493 .44793 .30076 .44423 .29223 Mtetra
.69 .614 .767 r
.44423 .29223 .44793 .30076 .45459 .29659 .45089 .28814 Mtetra
.691 .617 .769 r
.45089 .28814 .45459 .29659 .46126 .2924 .45756 .28404 Mtetra
.692 .619 .77 r
.45756 .28404 .46126 .2924 .46794 .28821 .46424 .27993 Mtetra
.693 .622 .772 r
.46424 .27993 .46794 .28821 .47462 .28401 .47093 .27582 Mtetra
.694 .625 .774 r
.47093 .27582 .47462 .28401 .48131 .27981 .47762 .27171 Mtetra
.695 .627 .776 r
.47762 .27171 .48131 .27981 .48802 .27561 .48433 .26758 Mtetra
.697 .63 .778 r
.48433 .26758 .48802 .27561 .49473 .2714 .49104 .26346 Mtetra
.698 .633 .78 r
.49104 .26346 .49473 .2714 .50145 .26718 .49776 .25933 Mtetra
.699 .636 .782 r
.49776 .25933 .50145 .26718 .50817 .26297 .5045 .25519 Mtetra
.7 .639 .784 r
.5045 .25519 .50817 .26297 .51491 .25874 .51124 .25105 Mtetra
.701 .642 .787 r
.51124 .25105 .51491 .25874 .52165 .25451 .51799 .2469 Mtetra
.702 .644 .789 r
.51799 .2469 .52165 .25451 .52841 .25028 .52475 .24275 Mtetra
.704 .647 .791 r
.52475 .24275 .52841 .25028 .53517 .24604 .53151 .2386 Mtetra
.705 .651 .793 r
.53151 .2386 .53517 .24604 .54194 .24179 .53829 .23443 Mtetra
.706 .654 .795 r
.53829 .23443 .54194 .24179 .54872 .23754 .54508 .23027 Mtetra
.707 .657 .797 r
.54508 .23027 .54872 .23754 .5555 .23329 .55187 .22609 Mtetra
.709 .66 .8 r
.55187 .22609 .5555 .23329 .5623 .22903 .55868 .22191 Mtetra
.71 .663 .802 r
.55868 .22191 .5623 .22903 .5691 .22476 .56549 .21773 Mtetra
.711 .666 .804 r
.56549 .21773 .5691 .22476 .57592 .22049 .57231 .21354 Mtetra
.712 .67 .806 r
.57231 .21354 .57592 .22049 .58274 .21621 .57914 .20935 Mtetra
.714 .673 .809 r
.57914 .20935 .58274 .21621 .58957 .21193 .58598 .20514 Mtetra
.715 .676 .811 r
.58598 .20514 .58957 .21193 .59641 .20764 .59283 .20094 Mtetra
.716 .68 .814 r
.59283 .20094 .59641 .20764 .60326 .20335 .59969 .19673 Mtetra
.718 .683 .816 r
.59969 .19673 .60326 .20335 .61011 .19905 .60656 .19251 Mtetra
.719 .687 .818 r
.60656 .19251 .61011 .19905 .61698 .19475 .61344 .18829 Mtetra
.72 .69 .821 r
.61344 .18829 .61698 .19475 .62385 .19044 .62033 .18406 Mtetra
.722 .694 .823 r
.62033 .18406 .62385 .19044 .63074 .18612 .62722 .17982 Mtetra
.723 .698 .826 r
.62722 .17982 .63074 .18612 .63763 .1818 .63413 .17558 Mtetra
.724 .702 .828 r
.63413 .17558 .63763 .1818 .64453 .17747 .64104 .17133 Mtetra
.726 .705 .831 r
.64104 .17133 .64453 .17747 .65144 .17314 .64797 .16708 Mtetra
.727 .709 .834 r
.64797 .16708 .65144 .17314 .65836 .1688 .6549 .16282 Mtetra
.728 .713 .836 r
.6549 .16282 .65836 .1688 .66529 .16445 .66184 .15855 Mtetra
.73 .717 .839 r
.66184 .15855 .66529 .16445 .67222 .1601 .66879 .15428 Mtetra
.731 .721 .842 r
.66879 .15428 .67222 .1601 .67917 .15575 .67576 .15001 Mtetra
.733 .726 .844 r
.67576 .15001 .67917 .15575 .68612 .15138 .68273 .14572 Mtetra
.734 .73 .847 r
.68273 .14572 .68612 .15138 .69309 .14701 .68971 .14143 Mtetra
.735 .734 .85 r
.68971 .14143 .69309 .14701 .70006 .14264 .6967 .13713 Mtetra
.737 .738 .852 r
.6967 .13713 .70006 .14264 .70704 .13825 .7037 .13283 Mtetra
.738 .743 .855 r
.7037 .13283 .70704 .13825 .71403 .13387 .71071 .12852 Mtetra
.739 .747 .858 r
.71071 .12852 .71403 .13387 .72103 .12948 .71772 .12421 Mtetra
.741 .751 .861 r
.71772 .12421 .72103 .12948 .72804 .12508 .72475 .11989 Mtetra
.741 .756 .864 r
.72475 .11989 .72804 .12508 .73506 .1207 .73179 .11559 Mtetra
.74 .759 .868 r
.73179 .11559 .73506 .1207 .74209 .11638 .73884 .11134 Mtetra
.737 .762 .873 r
.73884 .11134 .74209 .11638 .74914 .11214 .74591 .10718 Mtetra
.731 .764 .879 r
.74591 .10718 .74914 .11214 .75622 .10807 .75301 .10316 Mtetra
.577 .716 .937 r
.11462 .33329 .1188 .33719 .12435 .33622 .12019 .33226 Mtetra
.55 .703 .941 r
.12019 .33226 .12435 .33622 .12989 .33555 .12574 .3315 Mtetra
.541 .695 .939 r
.12574 .3315 .12989 .33555 .13544 .33498 .1313 .33084 Mtetra
.538 .689 .936 r
.1313 .33084 .13544 .33498 .14099 .33445 .13687 .33022 Mtetra
.537 .683 .933 r
.13687 .33022 .14099 .33445 .14656 .33396 .14245 .32963 Mtetra
.538 .679 .929 r
.14245 .32963 .14656 .33396 .15215 .33346 .14806 .32904 Mtetra
.54 .675 .925 r
.14806 .32904 .15215 .33346 .15775 .33297 .15368 .32845 Mtetra
.541 .67 .921 r
.15368 .32845 .15775 .33297 .16338 .33247 .15931 .32785 Mtetra
.542 .666 .918 r
.15931 .32785 .16338 .33247 .16902 .33198 .16497 .32726 Mtetra
.544 .662 .914 r
.16497 .32726 .16902 .33198 .17468 .33148 .17065 .32666 Mtetra
.545 .658 .91 r
.17065 .32666 .17468 .33148 .18036 .33097 .17634 .32606 Mtetra
.546 .654 .906 r
.17634 .32606 .18036 .33097 .18606 .33047 .18205 .32546 Mtetra
.547 .65 .902 r
.18205 .32546 .18606 .33047 .19178 .32997 .18778 .32486 Mtetra
.548 .646 .898 r
.18778 .32486 .19178 .32997 .19752 .32946 .19353 .32425 Mtetra
.549 .642 .895 r
.19353 .32425 .19752 .32946 .20327 .32895 .1993 .32364 Mtetra
.55 .638 .891 r
.1993 .32364 .20327 .32895 .20905 .32844 .20509 .32303 Mtetra
.551 .635 .887 r
.20509 .32303 .20905 .32844 .21484 .32792 .2109 .32242 Mtetra
.552 .631 .884 r
.2109 .32242 .21484 .32792 .22066 .32741 .21672 .3218 Mtetra
.552 .627 .88 r
.21672 .3218 .22066 .32741 .22649 .32689 .22257 .32118 Mtetra
.553 .624 .876 r
.22257 .32118 .22649 .32689 .23235 .32637 .22844 .32056 Mtetra
.554 .62 .873 r
.22844 .32056 .23235 .32637 .23822 .32585 .23432 .31994 Mtetra
.554 .617 .869 r
.23432 .31994 .23822 .32585 .24411 .32532 .24023 .31932 Mtetra
.555 .613 .866 r
.24023 .31932 .24411 .32532 .25003 .3248 .24615 .31869 Mtetra
.555 .61 .862 r
.24615 .31869 .25003 .3248 .25596 .32427 .25209 .31806 Mtetra
.556 .607 .859 r
.25209 .31806 .25596 .32427 .26191 .32374 .25806 .31743 Mtetra
.556 .603 .856 r
.25806 .31743 .26191 .32374 .26789 .32321 .26404 .3168 Mtetra
.556 .6 .852 r
.26404 .3168 .26789 .32321 .27388 .32268 .27004 .31616 Mtetra
.557 .597 .849 r
.27004 .31616 .27388 .32268 .2799 .32214 .27607 .31552 Mtetra
.557 .594 .846 r
.27607 .31552 .2799 .32214 .28593 .32161 .28211 .31489 Mtetra
.557 .591 .843 r
.28211 .31489 .28593 .32161 .29199 .32107 .28818 .31424 Mtetra
.558 .588 .84 r
.28818 .31424 .29199 .32107 .29807 .32053 .29426 .3136 Mtetra
.558 .585 .837 r
.29426 .3136 .29807 .32053 .30416 .31999 .30037 .31295 Mtetra
.558 .582 .834 r
.30037 .31295 .30416 .31999 .31028 .31945 .30649 .31231 Mtetra
.558 .579 .831 r
.30649 .31231 .31028 .31945 .31642 .3189 .31264 .31166 Mtetra
.559 .576 .828 r
.31264 .31166 .31642 .3189 .32258 .31835 .31881 .31101 Mtetra
.559 .573 .825 r
.31881 .31101 .32258 .31835 .32877 .31781 .325 .31035 Mtetra
.559 .57 .822 r
.325 .31035 .32877 .31781 .33497 .31726 .33121 .3097 Mtetra
.559 .568 .819 r
.33121 .3097 .33497 .31726 .3412 .31671 .33744 .30904 Mtetra
.559 .565 .816 r
.33744 .30904 .3412 .31671 .34744 .31615 .34369 .30838 Mtetra
.559 .562 .814 r
.34369 .30838 .34744 .31615 .35371 .3156 .34997 .30772 Mtetra
.559 .56 .811 r
.34997 .30772 .35371 .3156 .36 .31505 .35626 .30706 Mtetra
.559 .557 .808 r
.35626 .30706 .36 .31505 .36632 .31449 .36258 .3064 Mtetra
.559 .555 .805 r
.36258 .3064 .36632 .31449 .37265 .31393 .36892 .30573 Mtetra
.559 .552 .803 r
.36892 .30573 .37265 .31393 .37901 .31337 .37528 .30506 Mtetra
.559 .55 .8 r
.37528 .30506 .37901 .31337 .38539 .31281 .38166 .30439 Mtetra
.56 .548 .798 r
.38166 .30439 .38539 .31281 .39179 .31224 .38807 .30371 Mtetra
.561 .546 .795 r
.38807 .30371 .39179 .31224 .39822 .31164 .3945 .30301 Mtetra
.564 .545 .792 r
.3945 .30301 .39822 .31164 .40467 .31096 .40095 .30222 Mtetra
.572 .548 .789 r
.40095 .30222 .40467 .31096 .41115 .3101 .40743 .30127 Mtetra
.619 .571 .778 r
.40743 .30127 .41115 .3101 .41769 .30807 .41398 .29921 Mtetra
.675 .599 .763 r
.41398 .29921 .41769 .30807 .4243 .30429 .42059 .2955 Mtetra
.68 .604 .764 r
.42059 .2955 .4243 .30429 .43093 .30035 .42722 .29164 Mtetra
.684 .607 .764 r
.42722 .29164 .43093 .30035 .43758 .29631 .43387 .28768 Mtetra
.686 .61 .766 r
.43387 .28768 .43758 .29631 .44423 .29223 .44052 .28368 Mtetra
.687 .613 .768 r
.44052 .28368 .44423 .29223 .45089 .28814 .44718 .27967 Mtetra
.688 .615 .77 r
.44718 .27967 .45089 .28814 .45756 .28404 .45385 .27566 Mtetra
.689 .618 .771 r
.45385 .27566 .45756 .28404 .46424 .27993 .46053 .27164 Mtetra
.69 .621 .773 r
.46053 .27164 .46424 .27993 .47093 .27582 .46722 .26761 Mtetra
.691 .623 .775 r
.46722 .26761 .47093 .27582 .47762 .27171 .47392 .26358 Mtetra
.693 .626 .777 r
.47392 .26358 .47762 .27171 .48433 .26758 .48063 .25954 Mtetra
.694 .629 .779 r
.48063 .25954 .48433 .26758 .49104 .26346 .48735 .2555 Mtetra
.695 .632 .781 r
.48735 .2555 .49104 .26346 .49776 .25933 .49408 .25145 Mtetra
.696 .634 .783 r
.49408 .25145 .49776 .25933 .5045 .25519 .50081 .2474 Mtetra
.697 .637 .786 r
.50081 .2474 .5045 .25519 .51124 .25105 .50756 .24334 Mtetra
.698 .64 .788 r
.50756 .24334 .51124 .25105 .51799 .2469 .51431 .23928 Mtetra
.699 .643 .79 r
.51431 .23928 .51799 .2469 .52475 .24275 .52108 .23521 Mtetra
.701 .646 .792 r
.52108 .23521 .52475 .24275 .53151 .2386 .52785 .23113 Mtetra
.702 .649 .794 r
.52785 .23113 .53151 .2386 .53829 .23443 .53464 .22705 Mtetra
.703 .652 .796 r
.53464 .22705 .53829 .23443 .54508 .23027 .54143 .22297 Mtetra
.704 .655 .799 r
.54143 .22297 .54508 .23027 .55187 .22609 .54823 .21888 Mtetra
.706 .659 .801 r
.54823 .21888 .55187 .22609 .55868 .22191 .55504 .21478 Mtetra
.707 .662 .803 r
.55504 .21478 .55868 .22191 .56549 .21773 .56187 .21068 Mtetra
.708 .665 .805 r
.56187 .21068 .56549 .21773 .57231 .21354 .5687 .20657 Mtetra
.709 .668 .808 r
.5687 .20657 .57231 .21354 .57914 .20935 .57554 .20246 Mtetra
.711 .672 .81 r
.57554 .20246 .57914 .20935 .58598 .20514 .58239 .19834 Mtetra
.712 .675 .813 r
.58239 .19834 .58598 .20514 .59283 .20094 .58925 .19421 Mtetra
.713 .678 .815 r
.58925 .19421 .59283 .20094 .59969 .19673 .59612 .19008 Mtetra
.714 .682 .817 r
.59612 .19008 .59969 .19673 .60656 .19251 .603 .18594 Mtetra
.716 .686 .82 r
.603 .18594 .60656 .19251 .61344 .18829 .60989 .1818 Mtetra
.717 .689 .822 r
.60989 .1818 .61344 .18829 .62033 .18406 .61679 .17765 Mtetra
.718 .693 .825 r
.61679 .17765 .62033 .18406 .62722 .17982 .62369 .1735 Mtetra
.72 .697 .827 r
.62369 .1735 .62722 .17982 .63413 .17558 .63061 .16934 Mtetra
.721 .7 .83 r
.63061 .16934 .63413 .17558 .64104 .17133 .63754 .16517 Mtetra
.722 .704 .833 r
.63754 .16517 .64104 .17133 .64797 .16708 .64448 .161 Mtetra
.724 .708 .835 r
.64448 .161 .64797 .16708 .6549 .16282 .65143 .15682 Mtetra
.725 .712 .838 r
.65143 .15682 .6549 .16282 .66184 .15855 .65838 .15263 Mtetra
.726 .716 .841 r
.65838 .15263 .66184 .15855 .66879 .15428 .66535 .14844 Mtetra
.728 .72 .843 r
.66535 .14844 .66879 .15428 .67576 .15001 .67233 .14424 Mtetra
.729 .724 .846 r
.67233 .14424 .67576 .15001 .68273 .14572 .67932 .14004 Mtetra
.73 .728 .849 r
.67932 .14004 .68273 .14572 .68971 .14143 .68631 .13583 Mtetra
.732 .733 .851 r
.68631 .13583 .68971 .14143 .6967 .13713 .69332 .13161 Mtetra
.733 .737 .854 r
.69332 .13161 .6967 .13713 .7037 .13283 .70034 .12738 Mtetra
.734 .741 .857 r
.70034 .12738 .7037 .13283 .71071 .12852 .70736 .12315 Mtetra
.736 .746 .86 r
.70736 .12315 .71071 .12852 .71772 .12421 .7144 .11892 Mtetra
.737 .75 .863 r
.7144 .11892 .71772 .12421 .72475 .11989 .72145 .11468 Mtetra
.737 .754 .866 r
.72145 .11468 .72475 .11989 .73179 .11559 .72851 .11046 Mtetra
.736 .758 .87 r
.72851 .11046 .73179 .11559 .73884 .11134 .73558 .10628 Mtetra
.734 .761 .875 r
.73558 .10628 .73884 .11134 .74591 .10718 .74267 .10218 Mtetra
.728 .763 .881 r
.74267 .10218 .74591 .10718 .75301 .10316 .74978 .09823 Mtetra
.583 .718 .936 r
.11042 .32938 .11462 .33329 .12019 .33226 .11601 .32828 Mtetra
.558 .705 .939 r
.11601 .32828 .12019 .33226 .12574 .3315 .12157 .32743 Mtetra
.55 .698 .938 r
.12157 .32743 .12574 .3315 .1313 .33084 .12715 .32668 Mtetra
.547 .692 .935 r
.12715 .32668 .1313 .33084 .13687 .33022 .13273 .32597 Mtetra
.546 .687 .931 r
.13273 .32597 .13687 .33022 .14245 .32963 .13833 .32528 Mtetra
.547 .682 .928 r
.13833 .32528 .14245 .32963 .14806 .32904 .14395 .32459 Mtetra
.548 .678 .924 r
.14395 .32459 .14806 .32904 .15368 .32845 .14958 .3239 Mtetra
.55 .674 .92 r
.14958 .3239 .15368 .32845 .15931 .32785 .15524 .32321 Mtetra
.551 .669 .916 r
.15524 .32321 .15931 .32785 .16497 .32726 .16091 .32252 Mtetra
.552 .665 .912 r
.16091 .32252 .16497 .32726 .17065 .32666 .1666 .32183 Mtetra
.553 .661 .908 r
.1666 .32183 .17065 .32666 .17634 .32606 .1723 .32113 Mtetra
.554 .657 .905 r
.1723 .32113 .17634 .32606 .18205 .32546 .17803 .32043 Mtetra
.555 .653 .901 r
.17803 .32043 .18205 .32546 .18778 .32486 .18377 .31973 Mtetra
.556 .649 .897 r
.18377 .31973 .18778 .32486 .19353 .32425 .18954 .31902 Mtetra
.557 .645 .893 r
.18954 .31902 .19353 .32425 .1993 .32364 .19532 .31832 Mtetra
.557 .642 .89 r
.19532 .31832 .1993 .32364 .20509 .32303 .20112 .31761 Mtetra
.558 .638 .886 r
.20112 .31761 .20509 .32303 .2109 .32242 .20694 .31689 Mtetra
.559 .634 .882 r
.20694 .31689 .2109 .32242 .21672 .3218 .21278 .31618 Mtetra
.559 .63 .879 r
.21278 .31618 .21672 .3218 .22257 .32118 .21864 .31546 Mtetra
.56 .627 .875 r
.21864 .31546 .22257 .32118 .22844 .32056 .22451 .31474 Mtetra
.56 .623 .872 r
.22451 .31474 .22844 .32056 .23432 .31994 .23041 .31402 Mtetra
.561 .62 .868 r
.23041 .31402 .23432 .31994 .24023 .31932 .23632 .31329 Mtetra
.561 .616 .865 r
.23632 .31329 .24023 .31932 .24615 .31869 .24226 .31257 Mtetra
.562 .613 .861 r
.24226 .31257 .24615 .31869 .25209 .31806 .24821 .31184 Mtetra
.562 .61 .858 r
.24821 .31184 .25209 .31806 .25806 .31743 .25419 .3111 Mtetra
.562 .606 .855 r
.25419 .3111 .25806 .31743 .26404 .3168 .26018 .31037 Mtetra
.563 .603 .851 r
.26018 .31037 .26404 .3168 .27004 .31616 .26619 .30963 Mtetra
.563 .6 .848 r
.26619 .30963 .27004 .31616 .27607 .31552 .27223 .30889 Mtetra
.563 .597 .845 r
.27223 .30889 .27607 .31552 .28211 .31489 .27828 .30815 Mtetra
.563 .594 .842 r
.27828 .30815 .28211 .31489 .28818 .31424 .28435 .3074 Mtetra
.563 .591 .839 r
.28435 .3074 .28818 .31424 .29426 .3136 .29045 .30666 Mtetra
.564 .588 .836 r
.29045 .30666 .29426 .3136 .30037 .31295 .29656 .30591 Mtetra
.564 .585 .833 r
.29656 .30591 .30037 .31295 .30649 .31231 .3027 .30516 Mtetra
.564 .582 .83 r
.3027 .30516 .30649 .31231 .31264 .31166 .30885 .3044 Mtetra
.564 .579 .827 r
.30885 .3044 .31264 .31166 .31881 .31101 .31503 .30365 Mtetra
.564 .576 .824 r
.31503 .30365 .31881 .31101 .325 .31035 .32122 .30289 Mtetra
.564 .573 .821 r
.32122 .30289 .325 .31035 .33121 .3097 .32744 .30213 Mtetra
.564 .57 .818 r
.32744 .30213 .33121 .3097 .33744 .30904 .33368 .30137 Mtetra
.564 .568 .816 r
.33368 .30137 .33744 .30904 .34369 .30838 .33993 .3006 Mtetra
.564 .565 .813 r
.33993 .3006 .34369 .30838 .34997 .30772 .34621 .29983 Mtetra
.564 .562 .81 r
.34621 .29983 .34997 .30772 .35626 .30706 .35252 .29906 Mtetra
.564 .56 .808 r
.35252 .29906 .35626 .30706 .36258 .3064 .35884 .29829 Mtetra
.564 .557 .805 r
.35884 .29829 .36258 .3064 .36892 .30573 .36518 .29752 Mtetra
.564 .555 .802 r
.36518 .29752 .36892 .30573 .37528 .30506 .37155 .29674 Mtetra
.564 .552 .8 r
.37155 .29674 .37528 .30506 .38166 .30439 .37793 .29596 Mtetra
.564 .55 .797 r
.37793 .29596 .38166 .30439 .38807 .30371 .38434 .29517 Mtetra
.565 .548 .795 r
.38434 .29517 .38807 .30371 .3945 .30301 .39077 .29436 Mtetra
.568 .548 .792 r
.39077 .29436 .3945 .30301 .40095 .30222 .39723 .29348 Mtetra
.576 .55 .788 r
.39723 .29348 .40095 .30222 .40743 .30127 .40372 .29243 Mtetra
.619 .571 .778 r
.40372 .29243 .40743 .30127 .41398 .29921 .41026 .29034 Mtetra
.672 .598 .764 r
.41026 .29034 .41398 .29921 .42059 .2955 .41687 .2867 Mtetra
.677 .603 .765 r
.41687 .2867 .42059 .2955 .42722 .29164 .4235 .28291 Mtetra
.681 .606 .765 r
.4235 .28291 .42722 .29164 .43387 .28768 .43015 .27904 Mtetra
.683 .609 .767 r
.43015 .27904 .43387 .28768 .44052 .28368 .4368 .27512 Mtetra
.684 .612 .769 r
.4368 .27512 .44052 .28368 .44718 .27967 .44346 .2712 Mtetra
.685 .614 .771 r
.44346 .2712 .44718 .27967 .45385 .27566 .45014 .26727 Mtetra
.687 .617 .772 r
.45014 .26727 .45385 .27566 .46053 .27164 .45682 .26333 Mtetra
.688 .619 .774 r
.45682 .26333 .46053 .27164 .46722 .26761 .46351 .25939 Mtetra
.689 .622 .776 r
.46351 .25939 .46722 .26761 .47392 .26358 .47021 .25544 Mtetra
.69 .625 .778 r
.47021 .25544 .47392 .26358 .48063 .25954 .47692 .25148 Mtetra
.691 .628 .78 r
.47692 .25148 .48063 .25954 .48735 .2555 .48365 .24752 Mtetra
.692 .63 .783 r
.48365 .24752 .48735 .2555 .49408 .25145 .49038 .24356 Mtetra
.693 .633 .785 r
.49038 .24356 .49408 .25145 .50081 .2474 .49712 .23959 Mtetra
.694 .636 .787 r
.49712 .23959 .50081 .2474 .50756 .24334 .50387 .23561 Mtetra
.695 .639 .789 r
.50387 .23561 .50756 .24334 .51431 .23928 .51063 .23163 Mtetra
.696 .642 .791 r
.51063 .23163 .51431 .23928 .52108 .23521 .5174 .22765 Mtetra
.698 .645 .793 r
.5174 .22765 .52108 .23521 .52785 .23113 .52418 .22366 Mtetra
.699 .648 .795 r
.52418 .22366 .52785 .23113 .53464 .22705 .53097 .21966 Mtetra
.7 .651 .798 r
.53097 .21966 .53464 .22705 .54143 .22297 .53777 .21565 Mtetra
.701 .654 .8 r
.53777 .21565 .54143 .22297 .54823 .21888 .54458 .21165 Mtetra
.702 .657 .802 r
.54458 .21165 .54823 .21888 .55504 .21478 .5514 .20763 Mtetra
.704 .66 .804 r
.5514 .20763 .55504 .21478 .56187 .21068 .55823 .20361 Mtetra
.705 .664 .807 r
.55823 .20361 .56187 .21068 .5687 .20657 .56507 .19958 Mtetra
.706 .667 .809 r
.56507 .19958 .5687 .20657 .57554 .20246 .57192 .19555 Mtetra
.707 .67 .811 r
.57192 .19555 .57554 .20246 .58239 .19834 .57878 .19151 Mtetra
.709 .674 .814 r
.57878 .19151 .58239 .19834 .58925 .19421 .58565 .18747 Mtetra
.71 .677 .816 r
.58565 .18747 .58925 .19421 .59612 .19008 .59253 .18342 Mtetra
.711 .681 .819 r
.59253 .18342 .59612 .19008 .603 .18594 .59942 .17936 Mtetra
.712 .684 .821 r
.59942 .17936 .603 .18594 .60989 .1818 .60632 .1753 Mtetra
.714 .688 .824 r
.60632 .1753 .60989 .1818 .61679 .17765 .61323 .17123 Mtetra
.715 .692 .826 r
.61323 .17123 .61679 .17765 .62369 .1735 .62015 .16716 Mtetra
.716 .695 .829 r
.62015 .16716 .62369 .1735 .63061 .16934 .62709 .16307 Mtetra
.718 .699 .832 r
.62709 .16307 .63061 .16934 .63754 .16517 .63403 .15899 Mtetra
.719 .703 .834 r
.63403 .15899 .63754 .16517 .64448 .161 .64098 .15489 Mtetra
.72 .707 .837 r
.64098 .15489 .64448 .161 .65143 .15682 .64794 .15079 Mtetra
.721 .711 .839 r
.64794 .15079 .65143 .15682 .65838 .15263 .65491 .14669 Mtetra
.723 .715 .842 r
.65491 .14669 .65838 .15263 .66535 .14844 .6619 .14258 Mtetra
.724 .719 .845 r
.6619 .14258 .66535 .14844 .67233 .14424 .66889 .13846 Mtetra
.725 .723 .848 r
.66889 .13846 .67233 .14424 .67932 .14004 .67589 .13433 Mtetra
.727 .727 .85 r
.67589 .13433 .67932 .14004 .68631 .13583 .6829 .1302 Mtetra
.728 .731 .853 r
.6829 .1302 .68631 .13583 .69332 .13161 .68993 .12606 Mtetra
.729 .736 .856 r
.68993 .12606 .69332 .13161 .70034 .12738 .69696 .12191 Mtetra
.731 .74 .859 r
.69696 .12191 .70034 .12738 .70736 .12315 .70401 .11776 Mtetra
.732 .744 .862 r
.70401 .11776 .70736 .12315 .7144 .11892 .71106 .11361 Mtetra
.733 .749 .865 r
.71106 .11361 .7144 .11892 .72145 .11468 .71813 .10945 Mtetra
.734 .753 .868 r
.71813 .10945 .72145 .11468 .72851 .11046 .72521 .1053 Mtetra
.733 .757 .872 r
.72521 .1053 .72851 .11046 .73558 .10628 .7323 .1012 Mtetra
.73 .76 .876 r
.7323 .1012 .73558 .10628 .74267 .10218 .73941 .09717 Mtetra
.725 .762 .882 r
.73941 .09717 .74267 .10218 .74978 .09823 .74654 .09328 Mtetra
.589 .72 .934 r
.10621 .32545 .11042 .32938 .11601 .32828 .11181 .32428 Mtetra
.566 .708 .937 r
.11181 .32428 .11601 .32828 .12157 .32743 .11739 .32335 Mtetra
.558 .701 .936 r
.11739 .32335 .12157 .32743 .12715 .32668 .12298 .32251 Mtetra
.556 .695 .933 r
.12298 .32251 .12715 .32668 .13273 .32597 .12858 .3217 Mtetra
.555 .69 .93 r
.12858 .3217 .13273 .32597 .13833 .32528 .13419 .32091 Mtetra
.555 .686 .926 r
.13419 .32091 .13833 .32528 .14395 .32459 .13983 .32013 Mtetra
.557 .681 .922 r
.13983 .32013 .14395 .32459 .14958 .3239 .14548 .31935 Mtetra
.558 .677 .918 r
.14548 .31935 .14958 .3239 .15524 .32321 .15114 .31856 Mtetra
.559 .673 .914 r
.15114 .31856 .15524 .32321 .16091 .32252 .15683 .31777 Mtetra
.56 .669 .911 r
.15683 .31777 .16091 .32252 .1666 .32183 .16253 .31698 Mtetra
.561 .664 .907 r
.16253 .31698 .1666 .32183 .1723 .32113 .16825 .31618 Mtetra
.562 .66 .903 r
.16825 .31618 .1723 .32113 .17803 .32043 .17399 .31539 Mtetra
.562 .656 .899 r
.17399 .31539 .17803 .32043 .18377 .31973 .17975 .31459 Mtetra
.563 .652 .895 r
.17975 .31459 .18377 .31973 .18954 .31902 .18553 .31378 Mtetra
.564 .648 .892 r
.18553 .31378 .18954 .31902 .19532 .31832 .19132 .31297 Mtetra
.564 .645 .888 r
.19132 .31297 .19532 .31832 .20112 .31761 .19714 .31217 Mtetra
.565 .641 .884 r
.19714 .31217 .20112 .31761 .20694 .31689 .20297 .31135 Mtetra
.566 .637 .881 r
.20297 .31135 .20694 .31689 .21278 .31618 .20882 .31054 Mtetra
.566 .633 .877 r
.20882 .31054 .21278 .31618 .21864 .31546 .21469 .30972 Mtetra
.566 .63 .874 r
.21469 .30972 .21864 .31546 .22451 .31474 .22058 .3089 Mtetra
.567 .626 .87 r
.22058 .3089 .22451 .31474 .23041 .31402 .22649 .30808 Mtetra
.567 .623 .867 r
.22649 .30808 .23041 .31402 .23632 .31329 .23241 .30725 Mtetra
.567 .619 .864 r
.23241 .30725 .23632 .31329 .24226 .31257 .23836 .30642 Mtetra
.568 .616 .86 r
.23836 .30642 .24226 .31257 .24821 .31184 .24432 .30559 Mtetra
.568 .612 .857 r
.24432 .30559 .24821 .31184 .25419 .3111 .25031 .30476 Mtetra
.568 .609 .854 r
.25031 .30476 .25419 .3111 .26018 .31037 .25631 .30392 Mtetra
.568 .606 .85 r
.25631 .30392 .26018 .31037 .26619 .30963 .26233 .30308 Mtetra
.569 .603 .847 r
.26233 .30308 .26619 .30963 .27223 .30889 .26838 .30224 Mtetra
.569 .599 .844 r
.26838 .30224 .27223 .30889 .27828 .30815 .27444 .30139 Mtetra
.569 .596 .841 r
.27444 .30139 .27828 .30815 .28435 .3074 .28052 .30055 Mtetra
.569 .593 .838 r
.28052 .30055 .28435 .3074 .29045 .30666 .28662 .29969 Mtetra
.569 .59 .835 r
.28662 .29969 .29045 .30666 .29656 .30591 .29275 .29884 Mtetra
.569 .587 .832 r
.29275 .29884 .29656 .30591 .3027 .30516 .29889 .29799 Mtetra
.569 .584 .829 r
.29889 .29799 .3027 .30516 .30885 .3044 .30505 .29713 Mtetra
.569 .581 .826 r
.30505 .29713 .30885 .3044 .31503 .30365 .31123 .29627 Mtetra
.569 .579 .823 r
.31123 .29627 .31503 .30365 .32122 .30289 .31744 .2954 Mtetra
.569 .576 .82 r
.31744 .2954 .32122 .30289 .32744 .30213 .32366 .29454 Mtetra
.569 .573 .817 r
.32366 .29454 .32744 .30213 .33368 .30137 .3299 .29367 Mtetra
.569 .57 .815 r
.3299 .29367 .33368 .30137 .33993 .3006 .33617 .2928 Mtetra
.569 .568 .812 r
.33617 .2928 .33993 .3006 .34621 .29983 .34245 .29193 Mtetra
.569 .565 .809 r
.34245 .29193 .34621 .29983 .35252 .29906 .34876 .29105 Mtetra
.569 .562 .807 r
.34876 .29105 .35252 .29906 .35884 .29829 .35509 .29017 Mtetra
.569 .56 .804 r
.35509 .29017 .35884 .29829 .36518 .29752 .36144 .28929 Mtetra
.569 .557 .802 r
.36144 .28929 .36518 .29752 .37155 .29674 .36781 .28841 Mtetra
.569 .555 .799 r
.36781 .28841 .37155 .29674 .37793 .29596 .3742 .28752 Mtetra
.569 .553 .796 r
.3742 .28752 .37793 .29596 .38434 .29517 .38061 .28662 Mtetra
.57 .551 .794 r
.38061 .28662 .38434 .29517 .39077 .29436 .38704 .2857 Mtetra
.573 .55 .791 r
.38704 .2857 .39077 .29436 .39723 .29348 .3935 .28471 Mtetra
.579 .552 .788 r
.3935 .28471 .39723 .29348 .40372 .29243 .39999 .28357 Mtetra
.62 .572 .778 r
.39999 .28357 .40372 .29243 .41026 .29034 .40654 .28145 Mtetra
.67 .597 .765 r
.40654 .28145 .41026 .29034 .41687 .2867 .41315 .27788 Mtetra
.675 .601 .765 r
.41315 .27788 .41687 .2867 .4235 .28291 .41978 .27417 Mtetra
.678 .605 .766 r
.41978 .27417 .4235 .28291 .43015 .27904 .42642 .27038 Mtetra
.68 .608 .768 r
.42642 .27038 .43015 .27904 .4368 .27512 .43308 .26655 Mtetra
.681 .61 .77 r
.43308 .26655 .4368 .27512 .44346 .2712 .43974 .26271 Mtetra
.682 .613 .772 r
.43974 .26271 .44346 .2712 .45014 .26727 .44641 .25886 Mtetra
.684 .615 .773 r
.44641 .25886 .45014 .26727 .45682 .26333 .4531 .255 Mtetra
.685 .618 .775 r
.4531 .255 .45682 .26333 .46351 .25939 .45979 .25114 Mtetra
.686 .621 .777 r
.45979 .25114 .46351 .25939 .47021 .25544 .4665 .24728 Mtetra
.687 .623 .779 r
.4665 .24728 .47021 .25544 .47692 .25148 .47321 .24341 Mtetra
.688 .626 .782 r
.47321 .24341 .47692 .25148 .48365 .24752 .47994 .23953 Mtetra
.689 .629 .784 r
.47994 .23953 .48365 .24752 .49038 .24356 .48667 .23565 Mtetra
.69 .632 .786 r
.48667 .23565 .49038 .24356 .49712 .23959 .49342 .23176 Mtetra
.691 .635 .788 r
.49342 .23176 .49712 .23959 .50387 .23561 .50017 .22787 Mtetra
.692 .637 .79 r
.50017 .22787 .50387 .23561 .51063 .23163 .50694 .22397 Mtetra
.693 .64 .792 r
.50694 .22397 .51063 .23163 .5174 .22765 .51371 .22007 Mtetra
.695 .643 .794 r
.51371 .22007 .5174 .22765 .52418 .22366 .5205 .21616 Mtetra
.696 .646 .797 r
.5205 .21616 .52418 .22366 .53097 .21966 .5273 .21224 Mtetra
.697 .65 .799 r
.5273 .21224 .53097 .21966 .53777 .21565 .5341 .20832 Mtetra
.698 .653 .801 r
.5341 .20832 .53777 .21565 .54458 .21165 .54092 .20439 Mtetra
.699 .656 .803 r
.54092 .20439 .54458 .21165 .5514 .20763 .54775 .20046 Mtetra
.7 .659 .806 r
.54775 .20046 .5514 .20763 .55823 .20361 .55458 .19652 Mtetra
.702 .662 .808 r
.55458 .19652 .55823 .20361 .56507 .19958 .56143 .19257 Mtetra
.703 .666 .81 r
.56143 .19257 .56507 .19958 .57192 .19555 .56829 .18862 Mtetra
.704 .669 .813 r
.56829 .18862 .57192 .19555 .57878 .19151 .57516 .18466 Mtetra
.705 .672 .815 r
.57516 .18466 .57878 .19151 .58565 .18747 .58204 .1807 Mtetra
.707 .676 .818 r
.58204 .1807 .58565 .18747 .59253 .18342 .58893 .17673 Mtetra
.708 .679 .82 r
.58893 .17673 .59253 .18342 .59942 .17936 .59583 .17275 Mtetra
.709 .683 .823 r
.59583 .17275 .59942 .17936 .60632 .1753 .60275 .16877 Mtetra
.71 .686 .825 r
.60275 .16877 .60632 .1753 .61323 .17123 .60967 .16478 Mtetra
.712 .69 .828 r
.60967 .16478 .61323 .17123 .62015 .16716 .6166 .16079 Mtetra
.713 .694 .83 r
.6166 .16079 .62015 .16716 .62709 .16307 .62355 .15679 Mtetra
.714 .698 .833 r
.62355 .15679 .62709 .16307 .63403 .15899 .6305 .15278 Mtetra
.715 .701 .836 r
.6305 .15278 .63403 .15899 .64098 .15489 .63747 .14877 Mtetra
.717 .705 .838 r
.63747 .14877 .64098 .15489 .64794 .15079 .64444 .14475 Mtetra
.718 .709 .841 r
.64444 .14475 .64794 .15079 .65491 .14669 .65143 .14072 Mtetra
.719 .713 .844 r
.65143 .14072 .65491 .14669 .6619 .14258 .65843 .13669 Mtetra
.721 .717 .846 r
.65843 .13669 .6619 .14258 .66889 .13846 .66543 .13265 Mtetra
.722 .721 .849 r
.66543 .13265 .66889 .13846 .67589 .13433 .67245 .1286 Mtetra
.723 .726 .852 r
.67245 .1286 .67589 .13433 .6829 .1302 .67948 .12455 Mtetra
.724 .73 .855 r
.67948 .12455 .6829 .1302 .68993 .12606 .68652 .12049 Mtetra
.726 .734 .858 r
.68652 .12049 .68993 .12606 .69696 .12191 .69358 .11642 Mtetra
.727 .738 .861 r
.69358 .11642 .69696 .12191 .70401 .11776 .70064 .11235 Mtetra
.728 .743 .864 r
.70064 .11235 .70401 .11776 .71106 .11361 .70771 .10827 Mtetra
.729 .747 .866 r
.70771 .10827 .71106 .11361 .71813 .10945 .7148 .10419 Mtetra
.73 .752 .87 r
.7148 .10419 .71813 .10945 .72521 .1053 .72189 .10012 Mtetra
.729 .755 .874 r
.72189 .10012 .72521 .1053 .7323 .1012 .72901 .09609 Mtetra
.726 .759 .878 r
.72901 .09609 .7323 .1012 .73941 .09717 .73613 .09213 Mtetra
.721 .761 .884 r
.73613 .09213 .73941 .09717 .74654 .09328 .74328 .0883 Mtetra
.594 .721 .933 r
.10198 .32151 .10621 .32545 .11181 .32428 .10759 .32027 Mtetra
.573 .711 .936 r
.10759 .32027 .11181 .32428 .11739 .32335 .11319 .31925 Mtetra
.567 .704 .934 r
.11319 .31925 .11739 .32335 .12298 .32251 .11879 .31831 Mtetra
.564 .698 .931 r
.11879 .31831 .12298 .32251 .12858 .3217 .12441 .31741 Mtetra
.563 .693 .928 r
.12441 .31741 .12858 .3217 .13419 .32091 .13004 .31653 Mtetra
.564 .689 .924 r
.13004 .31653 .13419 .32091 .13983 .32013 .13569 .31565 Mtetra
.565 .684 .92 r
.13569 .31565 .13983 .32013 .14548 .31935 .14135 .31477 Mtetra
.566 .68 .916 r
.14135 .31477 .14548 .31935 .15114 .31856 .14704 .31389 Mtetra
.567 .676 .913 r
.14704 .31389 .15114 .31856 .15683 .31777 .15274 .313 Mtetra
.568 .672 .909 r
.15274 .313 .15683 .31777 .16253 .31698 .15845 .31211 Mtetra
.568 .667 .905 r
.15845 .31211 .16253 .31698 .16825 .31618 .16419 .31122 Mtetra
.569 .663 .901 r
.16419 .31122 .16825 .31618 .17399 .31539 .16994 .31032 Mtetra
.57 .659 .898 r
.16994 .31032 .17399 .31539 .17975 .31459 .17572 .30942 Mtetra
.57 .655 .894 r
.17572 .30942 .17975 .31459 .18553 .31378 .18151 .30852 Mtetra
.571 .651 .89 r
.18151 .30852 .18553 .31378 .19132 .31297 .18731 .30761 Mtetra
.571 .647 .887 r
.18731 .30761 .19132 .31297 .19714 .31217 .19314 .3067 Mtetra
.572 .644 .883 r
.19314 .3067 .19714 .31217 .20297 .31135 .19899 .30579 Mtetra
.572 .64 .879 r
.19899 .30579 .20297 .31135 .20882 .31054 .20485 .30488 Mtetra
.573 .636 .876 r
.20485 .30488 .20882 .31054 .21469 .30972 .21073 .30396 Mtetra
.573 .633 .872 r
.21073 .30396 .21469 .30972 .22058 .3089 .21663 .30304 Mtetra
.573 .629 .869 r
.21663 .30304 .22058 .3089 .22649 .30808 .22255 .30211 Mtetra
.573 .625 .866 r
.22255 .30211 .22649 .30808 .23241 .30725 .22849 .30119 Mtetra
.574 .622 .862 r
.22849 .30119 .23241 .30725 .23836 .30642 .23445 .30026 Mtetra
.574 .618 .859 r
.23445 .30026 .23836 .30642 .24432 .30559 .24042 .29932 Mtetra
.574 .615 .856 r
.24042 .29932 .24432 .30559 .25031 .30476 .24642 .29839 Mtetra
.574 .612 .852 r
.24642 .29839 .25031 .30476 .25631 .30392 .25243 .29745 Mtetra
.574 .608 .849 r
.25243 .29745 .25631 .30392 .26233 .30308 .25846 .29651 Mtetra
.574 .605 .846 r
.25846 .29651 .26233 .30308 .26838 .30224 .26452 .29556 Mtetra
.574 .602 .843 r
.26452 .29556 .26838 .30224 .27444 .30139 .27059 .29462 Mtetra
.574 .599 .84 r
.27059 .29462 .27444 .30139 .28052 .30055 .27668 .29367 Mtetra
.574 .596 .837 r
.27668 .29367 .28052 .30055 .28662 .29969 .28279 .29271 Mtetra
.574 .593 .834 r
.28279 .29271 .28662 .29969 .29275 .29884 .28892 .29175 Mtetra
.574 .59 .831 r
.28892 .29175 .29275 .29884 .29889 .29799 .29507 .29079 Mtetra
.574 .587 .828 r
.29507 .29079 .29889 .29799 .30505 .29713 .30124 .28983 Mtetra
.574 .584 .825 r
.30124 .28983 .30505 .29713 .31123 .29627 .30743 .28887 Mtetra
.574 .581 .822 r
.30743 .28887 .31123 .29627 .31744 .2954 .31364 .2879 Mtetra
.574 .578 .819 r
.31364 .2879 .31744 .2954 .32366 .29454 .31987 .28693 Mtetra
.574 .575 .817 r
.31987 .28693 .32366 .29454 .3299 .29367 .32612 .28595 Mtetra
.574 .573 .814 r
.32612 .28595 .3299 .29367 .33617 .2928 .33239 .28498 Mtetra
.574 .57 .811 r
.33239 .28498 .33617 .2928 .34245 .29193 .33868 .284 Mtetra
.574 .567 .808 r
.33868 .284 .34245 .29193 .34876 .29105 .345 .28301 Mtetra
.574 .565 .806 r
.345 .28301 .34876 .29105 .35509 .29017 .35133 .28203 Mtetra
.573 .562 .803 r
.35133 .28203 .35509 .29017 .36144 .28929 .35768 .28104 Mtetra
.573 .56 .801 r
.35768 .28104 .36144 .28929 .36781 .28841 .36406 .28005 Mtetra
.573 .557 .798 r
.36406 .28005 .36781 .28841 .3742 .28752 .37045 .27905 Mtetra
.573 .555 .796 r
.37045 .27905 .3742 .28752 .38061 .28662 .37687 .27804 Mtetra
.574 .553 .793 r
.37687 .27804 .38061 .28662 .38704 .2857 .38331 .27702 Mtetra
.577 .552 .79 r
.38331 .27702 .38704 .2857 .3935 .28471 .38977 .27593 Mtetra
.583 .553 .787 r
.38977 .27593 .3935 .28471 .39999 .28357 .39626 .2747 Mtetra
.62 .572 .778 r
.39626 .2747 .39999 .28357 .40654 .28145 .40281 .27255 Mtetra
.668 .596 .766 r
.40281 .27255 .40654 .28145 .41315 .27788 .40942 .26904 Mtetra
.672 .6 .766 r
.40942 .26904 .41315 .27788 .41978 .27417 .41605 .26541 Mtetra
.675 .603 .767 r
.41605 .26541 .41978 .27417 .42642 .27038 .42269 .2617 Mtetra
.677 .606 .769 r
.42269 .2617 .42642 .27038 .43308 .26655 .42935 .25795 Mtetra
.678 .609 .771 r
.42935 .25795 .43308 .26655 .43974 .26271 .43601 .25419 Mtetra
.679 .611 .772 r
.43601 .25419 .43974 .26271 .44641 .25886 .44269 .25043 Mtetra
.681 .614 .774 r
.44269 .25043 .44641 .25886 .4531 .255 .44937 .24666 Mtetra
.682 .616 .776 r
.44937 .24666 .4531 .255 .45979 .25114 .45607 .24288 Mtetra
.683 .619 .778 r
.45607 .24288 .45979 .25114 .4665 .24728 .46277 .2391 Mtetra
.684 .622 .78 r
.46277 .2391 .4665 .24728 .47321 .24341 .46949 .23531 Mtetra
.685 .625 .782 r
.46949 .23531 .47321 .24341 .47994 .23953 .47622 .23152 Mtetra
.686 .627 .785 r
.47622 .23152 .47994 .23953 .48667 .23565 .48296 .22772 Mtetra
.687 .63 .787 r
.48296 .22772 .48667 .23565 .49342 .23176 .4897 .22391 Mtetra
.688 .633 .789 r
.4897 .22391 .49342 .23176 .50017 .22787 .49646 .2201 Mtetra
.689 .636 .791 r
.49646 .2201 .50017 .22787 .50694 .22397 .50323 .21628 Mtetra
.69 .639 .793 r
.50323 .21628 .50694 .22397 .51371 .22007 .51002 .21246 Mtetra
.691 .642 .795 r
.51002 .21246 .51371 .22007 .5205 .21616 .51681 .20863 Mtetra
.693 .645 .798 r
.51681 .20863 .5205 .21616 .5273 .21224 .52361 .2048 Mtetra
.694 .648 .8 r
.52361 .2048 .5273 .21224 .5341 .20832 .53042 .20096 Mtetra
.695 .651 .802 r
.53042 .20096 .5341 .20832 .54092 .20439 .53725 .19711 Mtetra
.696 .654 .805 r
.53725 .19711 .54092 .20439 .54775 .20046 .54408 .19326 Mtetra
.697 .658 .807 r
.54408 .19326 .54775 .20046 .55458 .19652 .55093 .1894 Mtetra
.698 .661 .809 r
.55093 .1894 .55458 .19652 .56143 .19257 .55779 .18554 Mtetra
.7 .664 .812 r
.55779 .18554 .56143 .19257 .56829 .18862 .56465 .18167 Mtetra
.701 .667 .814 r
.56465 .18167 .56829 .18862 .57516 .18466 .57153 .17779 Mtetra
.702 .671 .817 r
.57153 .17779 .57516 .18466 .58204 .1807 .57842 .17391 Mtetra
.703 .674 .819 r
.57842 .17391 .58204 .1807 .58893 .17673 .58532 .17002 Mtetra
.704 .678 .821 r
.58532 .17002 .58893 .17673 .59583 .17275 .59223 .16612 Mtetra
.706 .681 .824 r
.59223 .16612 .59583 .17275 .60275 .16877 .59916 .16222 Mtetra
.707 .685 .827 r
.59916 .16222 .60275 .16877 .60967 .16478 .60609 .15831 Mtetra
.708 .689 .829 r
.60609 .15831 .60967 .16478 .6166 .16079 .61304 .1544 Mtetra
.709 .692 .832 r
.61304 .1544 .6166 .16079 .62355 .15679 .61999 .15048 Mtetra
.711 .696 .834 r
.61999 .15048 .62355 .15679 .6305 .15278 .62696 .14655 Mtetra
.712 .7 .837 r
.62696 .14655 .6305 .15278 .63747 .14877 .63394 .14262 Mtetra
.713 .704 .84 r
.63394 .14262 .63747 .14877 .64444 .14475 .64093 .13868 Mtetra
.714 .708 .843 r
.64093 .13868 .64444 .14475 .65143 .14072 .64793 .13473 Mtetra
.716 .712 .845 r
.64793 .13473 .65143 .14072 .65843 .13669 .65494 .13078 Mtetra
.717 .716 .848 r
.65494 .13078 .65843 .13669 .66543 .13265 .66197 .12681 Mtetra
.718 .72 .851 r
.66197 .12681 .66543 .13265 .67245 .1286 .669 .12285 Mtetra
.719 .724 .854 r
.669 .12285 .67245 .1286 .67948 .12455 .67605 .11887 Mtetra
.721 .728 .857 r
.67605 .11887 .67948 .12455 .68652 .12049 .6831 .11489 Mtetra
.722 .733 .859 r
.6831 .11489 .68652 .12049 .69358 .11642 .69017 .11091 Mtetra
.723 .737 .862 r
.69017 .11091 .69358 .11642 .70064 .11235 .69725 .10691 Mtetra
.724 .741 .865 r
.69725 .10691 .70064 .11235 .70771 .10827 .70435 .10292 Mtetra
.725 .746 .868 r
.70435 .10292 .70771 .10827 .7148 .10419 .71145 .09891 Mtetra
.726 .75 .872 r
.71145 .09891 .7148 .10419 .72189 .10012 .71857 .09492 Mtetra
.725 .754 .875 r
.71857 .09492 .72189 .10012 .72901 .09609 .7257 .09096 Mtetra
.723 .757 .88 r
.7257 .09096 .72901 .09609 .73613 .09213 .73284 .08707 Mtetra
.718 .759 .885 r
.73284 .08707 .73613 .09213 .74328 .0883 .74001 .0833 Mtetra
.6 .723 .931 r
.09773 .31755 .10198 .32151 .10759 .32027 .10336 .31624 Mtetra
.581 .713 .934 r
.10336 .31624 .10759 .32027 .11319 .31925 .10897 .31514 Mtetra
.575 .707 .932 r
.10897 .31514 .11319 .31925 .11879 .31831 .11459 .31411 Mtetra
.572 .701 .929 r
.11459 .31411 .11879 .31831 .12441 .31741 .12022 .31311 Mtetra
.571 .696 .926 r
.12022 .31311 .12441 .31741 .13004 .31653 .12587 .31213 Mtetra
.572 .692 .922 r
.12587 .31213 .13004 .31653 .13569 .31565 .13153 .31116 Mtetra
.573 .687 .918 r
.13153 .31116 .13569 .31565 .14135 .31477 .13721 .31018 Mtetra
.574 .683 .915 r
.13721 .31018 .14135 .31477 .14704 .31389 .14291 .30919 Mtetra
.574 .679 .911 r
.14291 .30919 .14704 .31389 .15274 .313 .14863 .30821 Mtetra
.575 .675 .907 r
.14863 .30821 .15274 .313 .15845 .31211 .15436 .30722 Mtetra
.576 .67 .903 r
.15436 .30722 .15845 .31211 .16419 .31122 .16011 .30623 Mtetra
.576 .666 .9 r
.16011 .30623 .16419 .31122 .16994 .31032 .16588 .30524 Mtetra
.577 .662 .896 r
.16588 .30524 .16994 .31032 .17572 .30942 .17166 .30424 Mtetra
.577 .658 .892 r
.17166 .30424 .17572 .30942 .18151 .30852 .17747 .30324 Mtetra
.578 .654 .889 r
.17747 .30324 .18151 .30852 .18731 .30761 .18329 .30223 Mtetra
.578 .65 .885 r
.18329 .30223 .18731 .30761 .19314 .3067 .18913 .30122 Mtetra
.578 .646 .881 r
.18913 .30122 .19314 .3067 .19899 .30579 .19499 .30021 Mtetra
.579 .643 .878 r
.19499 .30021 .19899 .30579 .20485 .30488 .20086 .2992 Mtetra
.579 .639 .874 r
.20086 .2992 .20485 .30488 .21073 .30396 .20676 .29818 Mtetra
.579 .635 .871 r
.20676 .29818 .21073 .30396 .21663 .30304 .21267 .29716 Mtetra
.579 .632 .868 r
.21267 .29716 .21663 .30304 .22255 .30211 .2186 .29613 Mtetra
.58 .628 .864 r
.2186 .29613 .22255 .30211 .22849 .30119 .22455 .29511 Mtetra
.58 .625 .861 r
.22455 .29511 .22849 .30119 .23445 .30026 .23052 .29408 Mtetra
.58 .621 .858 r
.23052 .29408 .23445 .30026 .24042 .29932 .23651 .29304 Mtetra
.58 .618 .854 r
.23651 .29304 .24042 .29932 .24642 .29839 .24251 .292 Mtetra
.58 .614 .851 r
.24251 .292 .24642 .29839 .25243 .29745 .24854 .29096 Mtetra
.58 .611 .848 r
.24854 .29096 .25243 .29745 .25846 .29651 .25458 .28992 Mtetra
.58 .608 .845 r
.25458 .28992 .25846 .29651 .26452 .29556 .26064 .28887 Mtetra
.58 .605 .842 r
.26064 .28887 .26452 .29556 .27059 .29462 .26672 .28782 Mtetra
.58 .602 .839 r
.26672 .28782 .27059 .29462 .27668 .29367 .27283 .28677 Mtetra
.58 .598 .836 r
.27283 .28677 .27668 .29367 .28279 .29271 .27895 .28571 Mtetra
.58 .595 .833 r
.27895 .28571 .28279 .29271 .28892 .29175 .28508 .28465 Mtetra
.58 .592 .83 r
.28508 .28465 .28892 .29175 .29507 .29079 .29124 .28359 Mtetra
.58 .589 .827 r
.29124 .28359 .29507 .29079 .30124 .28983 .29742 .28252 Mtetra
.579 .587 .824 r
.29742 .28252 .30124 .28983 .30743 .28887 .30362 .28145 Mtetra
.579 .584 .821 r
.30362 .28145 .30743 .28887 .31364 .2879 .30984 .28038 Mtetra
.579 .581 .819 r
.30984 .28038 .31364 .2879 .31987 .28693 .31608 .2793 Mtetra
.579 .578 .816 r
.31608 .2793 .31987 .28693 .32612 .28595 .32233 .27822 Mtetra
.579 .575 .813 r
.32233 .27822 .32612 .28595 .33239 .28498 .32861 .27714 Mtetra
.579 .573 .81 r
.32861 .27714 .33239 .28498 .33868 .284 .33491 .27605 Mtetra
.578 .57 .808 r
.33491 .27605 .33868 .284 .345 .28301 .34123 .27497 Mtetra
.578 .567 .805 r
.34123 .27497 .345 .28301 .35133 .28203 .34756 .27387 Mtetra
.578 .565 .803 r
.34756 .27387 .35133 .28203 .35768 .28104 .35392 .27278 Mtetra
.578 .562 .8 r
.35392 .27278 .35768 .28104 .36406 .28005 .3603 .27168 Mtetra
.578 .56 .798 r
.3603 .27168 .36406 .28005 .37045 .27905 .3667 .27057 Mtetra
.578 .557 .795 r
.3667 .27057 .37045 .27905 .37687 .27804 .37312 .26946 Mtetra
.578 .555 .793 r
.37312 .26946 .37687 .27804 .38331 .27702 .37957 .26833 Mtetra
.581 .554 .79 r
.37957 .26833 .38331 .27702 .38977 .27593 .38603 .26714 Mtetra
.586 .555 .787 r
.38603 .26714 .38977 .27593 .39626 .2747 .39252 .26581 Mtetra
.621 .572 .778 r
.39252 .26581 .39626 .2747 .40281 .27255 .39907 .26363 Mtetra
.665 .595 .766 r
.39907 .26363 .40281 .27255 .40942 .26904 .40568 .26019 Mtetra
.669 .598 .767 r
.40568 .26019 .40942 .26904 .41605 .26541 .41231 .25664 Mtetra
.673 .602 .768 r
.41231 .25664 .41605 .26541 .42269 .2617 .41895 .25301 Mtetra
.674 .605 .77 r
.41895 .25301 .42269 .2617 .42935 .25795 .42561 .24934 Mtetra
.675 .607 .772 r
.42561 .24934 .42935 .25795 .43601 .25419 .43227 .24567 Mtetra
.677 .61 .773 r
.43227 .24567 .43601 .25419 .44269 .25043 .43895 .24199 Mtetra
.678 .613 .775 r
.43895 .24199 .44269 .25043 .44937 .24666 .44564 .2383 Mtetra
.679 .615 .777 r
.44564 .2383 .44937 .24666 .45607 .24288 .45233 .2346 Mtetra
.68 .618 .779 r
.45233 .2346 .45607 .24288 .46277 .2391 .45904 .2309 Mtetra
.681 .621 .782 r
.45904 .2309 .46277 .2391 .46949 .23531 .46576 .2272 Mtetra
.682 .623 .784 r
.46576 .2272 .46949 .23531 .47622 .23152 .47249 .22349 Mtetra
.683 .626 .786 r
.47249 .22349 .47622 .23152 .48296 .22772 .47923 .21977 Mtetra
.684 .629 .788 r
.47923 .21977 .48296 .22772 .4897 .22391 .48599 .21605 Mtetra
.685 .632 .79 r
.48599 .21605 .4897 .22391 .49646 .2201 .49275 .21232 Mtetra
.686 .635 .792 r
.49275 .21232 .49646 .2201 .50323 .21628 .49952 .20858 Mtetra
.687 .638 .794 r
.49952 .20858 .50323 .21628 .51002 .21246 .50631 .20484 Mtetra
.688 .641 .797 r
.50631 .20484 .51002 .21246 .51681 .20863 .51311 .2011 Mtetra
.689 .644 .799 r
.51311 .2011 .51681 .20863 .52361 .2048 .51992 .19734 Mtetra
.691 .647 .801 r
.51992 .19734 .52361 .2048 .53042 .20096 .52673 .19358 Mtetra
.692 .65 .803 r
.52673 .19358 .53042 .20096 .53725 .19711 .53357 .18982 Mtetra
.693 .653 .806 r
.53357 .18982 .53725 .19711 .54408 .19326 .54041 .18605 Mtetra
.694 .656 .808 r
.54041 .18605 .54408 .19326 .55093 .1894 .54726 .18227 Mtetra
.695 .659 .811 r
.54726 .18227 .55093 .1894 .55779 .18554 .55413 .17849 Mtetra
.696 .663 .813 r
.55413 .17849 .55779 .18554 .56465 .18167 .561 .1747 Mtetra
.698 .666 .815 r
.561 .1747 .56465 .18167 .57153 .17779 .56789 .1709 Mtetra
.699 .669 .818 r
.56789 .1709 .57153 .17779 .57842 .17391 .57479 .1671 Mtetra
.7 .673 .82 r
.57479 .1671 .57842 .17391 .58532 .17002 .5817 .16329 Mtetra
.701 .676 .823 r
.5817 .16329 .58532 .17002 .59223 .16612 .58862 .15947 Mtetra
.702 .68 .825 r
.58862 .15947 .59223 .16612 .59916 .16222 .59556 .15565 Mtetra
.703 .684 .828 r
.59556 .15565 .59916 .16222 .60609 .15831 .6025 .15182 Mtetra
.705 .687 .831 r
.6025 .15182 .60609 .15831 .61304 .1544 .60946 .14799 Mtetra
.706 .691 .833 r
.60946 .14799 .61304 .1544 .61999 .15048 .61643 .14415 Mtetra
.707 .695 .836 r
.61643 .14415 .61999 .15048 .62696 .14655 .62341 .1403 Mtetra
.708 .699 .839 r
.62341 .1403 .62696 .14655 .63394 .14262 .6304 .13644 Mtetra
.71 .702 .841 r
.6304 .13644 .63394 .14262 .64093 .13868 .6374 .13258 Mtetra
.711 .706 .844 r
.6374 .13258 .64093 .13868 .64793 .13473 .64442 .12872 Mtetra
.712 .71 .847 r
.64442 .12872 .64793 .13473 .65494 .13078 .65144 .12484 Mtetra
.713 .714 .85 r
.65144 .12484 .65494 .13078 .66197 .12681 .65848 .12096 Mtetra
.714 .719 .853 r
.65848 .12096 .66197 .12681 .669 .12285 .66553 .11707 Mtetra
.716 .723 .855 r
.66553 .11707 .669 .12285 .67605 .11887 .6726 .11318 Mtetra
.717 .727 .858 r
.6726 .11318 .67605 .11887 .6831 .11489 .67967 .10928 Mtetra
.718 .731 .861 r
.67967 .10928 .6831 .11489 .69017 .11091 .68676 .10537 Mtetra
.719 .736 .864 r
.68676 .10537 .69017 .11091 .69725 .10691 .69385 .10145 Mtetra
.72 .74 .867 r
.69385 .10145 .69725 .10691 .70435 .10292 .70096 .09753 Mtetra
.721 .744 .87 r
.70096 .09753 .70435 .10292 .71145 .09891 .70809 .09361 Mtetra
.722 .749 .873 r
.70809 .09361 .71145 .09891 .71857 .09492 .71522 .08969 Mtetra
.721 .753 .877 r
.71522 .08969 .71857 .09492 .7257 .09096 .72237 .08581 Mtetra
.719 .756 .881 r
.72237 .08581 .7257 .09096 .73284 .08707 .72954 .08199 Mtetra
.715 .758 .886 r
.72954 .08199 .73284 .08707 .74001 .0833 .73673 .07828 Mtetra
.605 .725 .929 r
.09346 .31358 .09773 .31755 .10336 .31624 .0991 .31219 Mtetra
.588 .716 .932 r
.0991 .31219 .10336 .31624 .10897 .31514 .10473 .311 Mtetra
.582 .71 .93 r
.10473 .311 .10897 .31514 .11459 .31411 .11037 .30988 Mtetra
.58 .704 .927 r
.11037 .30988 .11459 .31411 .12022 .31311 .11602 .30879 Mtetra
.579 .699 .924 r
.11602 .30879 .12022 .31311 .12587 .31213 .12168 .30772 Mtetra
.58 .695 .92 r
.12168 .30772 .12587 .31213 .13153 .31116 .12736 .30664 Mtetra
.581 .69 .917 r
.12736 .30664 .13153 .31116 .13721 .31018 .13306 .30557 Mtetra
.581 .686 .913 r
.13306 .30557 .13721 .31018 .14291 .30919 .13877 .30449 Mtetra
.582 .682 .909 r
.13877 .30449 .14291 .30919 .14863 .30821 .1445 .3034 Mtetra
.582 .677 .905 r
.1445 .3034 .14863 .30821 .15436 .30722 .15025 .30232 Mtetra
.583 .673 .902 r
.15025 .30232 .15436 .30722 .16011 .30623 .15602 .30123 Mtetra
.583 .669 .898 r
.15602 .30123 .16011 .30623 .16588 .30524 .1618 .30014 Mtetra
.584 .665 .894 r
.1618 .30014 .16588 .30524 .17166 .30424 .1676 .29904 Mtetra
.584 .661 .891 r
.1676 .29904 .17166 .30424 .17747 .30324 .17342 .29794 Mtetra
.584 .657 .887 r
.17342 .29794 .17747 .30324 .18329 .30223 .17925 .29683 Mtetra
.585 .653 .884 r
.17925 .29683 .18329 .30223 .18913 .30122 .18511 .29573 Mtetra
.585 .649 .88 r
.18511 .29573 .18913 .30122 .19499 .30021 .19098 .29462 Mtetra
.585 .645 .876 r
.19098 .29462 .19499 .30021 .20086 .2992 .19687 .2935 Mtetra
.585 .642 .873 r
.19687 .2935 .20086 .2992 .20676 .29818 .20277 .29238 Mtetra
.585 .638 .87 r
.20277 .29238 .20676 .29818 .21267 .29716 .2087 .29126 Mtetra
.586 .634 .866 r
.2087 .29126 .21267 .29716 .2186 .29613 .21464 .29014 Mtetra
.586 .631 .863 r
.21464 .29014 .2186 .29613 .22455 .29511 .2206 .28901 Mtetra
.586 .627 .86 r
.2206 .28901 .22455 .29511 .23052 .29408 .22658 .28788 Mtetra
.586 .624 .856 r
.22658 .28788 .23052 .29408 .23651 .29304 .23258 .28674 Mtetra
.586 .62 .853 r
.23258 .28674 .23651 .29304 .24251 .292 .2386 .2856 Mtetra
.586 .617 .85 r
.2386 .2856 .24251 .292 .24854 .29096 .24463 .28446 Mtetra
.585 .614 .847 r
.24463 .28446 .24854 .29096 .25458 .28992 .25069 .28331 Mtetra
.585 .611 .844 r
.25069 .28331 .25458 .28992 .26064 .28887 .25676 .28216 Mtetra
.585 .607 .841 r
.25676 .28216 .26064 .28887 .26672 .28782 .26285 .28101 Mtetra
.585 .604 .838 r
.26285 .28101 .26672 .28782 .27283 .28677 .26896 .27986 Mtetra
.585 .601 .835 r
.26896 .27986 .27283 .28677 .27895 .28571 .27509 .2787 Mtetra
.585 .598 .832 r
.27509 .2787 .27895 .28571 .28508 .28465 .28124 .27753 Mtetra
.585 .595 .829 r
.28124 .27753 .28508 .28465 .29124 .28359 .28741 .27637 Mtetra
.585 .592 .826 r
.28741 .27637 .29124 .28359 .29742 .28252 .29359 .27519 Mtetra
.584 .589 .823 r
.29359 .27519 .29742 .28252 .30362 .28145 .2998 .27402 Mtetra
.584 .586 .82 r
.2998 .27402 .30362 .28145 .30984 .28038 .30603 .27284 Mtetra
.584 .583 .818 r
.30603 .27284 .30984 .28038 .31608 .2793 .31227 .27166 Mtetra
.584 .581 .815 r
.31227 .27166 .31608 .2793 .32233 .27822 .31854 .27048 Mtetra
.584 .578 .812 r
.31854 .27048 .32233 .27822 .32861 .27714 .32482 .26929 Mtetra
.583 .575 .81 r
.32482 .26929 .32861 .27714 .33491 .27605 .33112 .2681 Mtetra
.583 .572 .807 r
.33112 .2681 .33491 .27605 .34123 .27497 .33745 .2669 Mtetra
.583 .57 .804 r
.33745 .2669 .34123 .27497 .34756 .27387 .34379 .2657 Mtetra
.583 .567 .802 r
.34379 .2657 .34756 .27387 .35392 .27278 .35016 .2645 Mtetra
.582 .565 .799 r
.35016 .2645 .35392 .27278 .3603 .27168 .35654 .2633 Mtetra
.582 .562 .797 r
.35654 .2633 .3603 .27168 .3667 .27057 .36295 .26208 Mtetra
.582 .56 .794 r
.36295 .26208 .3667 .27057 .37312 .26946 .36937 .26086 Mtetra
.583 .558 .792 r
.36937 .26086 .37312 .26946 .37957 .26833 .37582 .25963 Mtetra
.585 .557 .789 r
.37582 .25963 .37957 .26833 .38603 .26714 .38229 .25833 Mtetra
.59 .557 .786 r
.38229 .25833 .38603 .26714 .39252 .26581 .38878 .25691 Mtetra
.622 .573 .778 r
.38878 .25691 .39252 .26581 .39907 .26363 .39533 .2547 Mtetra
.663 .593 .767 r
.39533 .2547 .39907 .26363 .40568 .26019 .40194 .25133 Mtetra
.667 .597 .768 r
.40194 .25133 .40568 .26019 .41231 .25664 .40857 .24785 Mtetra
.67 .6 .769 r
.40857 .24785 .41231 .25664 .41895 .25301 .41521 .2443 Mtetra
.671 .603 .771 r
.41521 .2443 .41895 .25301 .42561 .24934 .42186 .24072 Mtetra
.673 .606 .773 r
.42186 .24072 .42561 .24934 .43227 .24567 .42853 .23713 Mtetra
.674 .608 .774 r
.42853 .23713 .43227 .24567 .43895 .24199 .4352 .23353 Mtetra
.675 .611 .776 r
.4352 .23353 .43895 .24199 .44564 .2383 .44189 .22992 Mtetra
.676 .614 .778 r
.44189 .22992 .44564 .2383 .45233 .2346 .44859 .22631 Mtetra
.677 .616 .781 r
.44859 .22631 .45233 .2346 .45904 .2309 .4553 .22269 Mtetra
.678 .619 .783 r
.4553 .22269 .45904 .2309 .46576 .2272 .46202 .21907 Mtetra
.679 .622 .785 r
.46202 .21907 .46576 .2272 .47249 .22349 .46876 .21544 Mtetra
.68 .625 .787 r
.46876 .21544 .47249 .22349 .47923 .21977 .4755 .21181 Mtetra
.681 .627 .789 r
.4755 .21181 .47923 .21977 .48599 .21605 .48226 .20816 Mtetra
.682 .63 .791 r
.48226 .20816 .48599 .21605 .49275 .21232 .48902 .20452 Mtetra
.683 .633 .793 r
.48902 .20452 .49275 .21232 .49952 .20858 .4958 .20086 Mtetra
.684 .636 .796 r
.4958 .20086 .49952 .20858 .50631 .20484 .50259 .1972 Mtetra
.685 .639 .798 r
.50259 .1972 .50631 .20484 .51311 .2011 .5094 .19354 Mtetra
.686 .642 .8 r
.5094 .19354 .51311 .2011 .51992 .19734 .51621 .18987 Mtetra
.687 .645 .802 r
.51621 .18987 .51992 .19734 .52673 .19358 .52304 .18619 Mtetra
.688 .648 .805 r
.52304 .18619 .52673 .19358 .53357 .18982 .52987 .1825 Mtetra
.69 .652 .807 r
.52987 .1825 .53357 .18982 .54041 .18605 .53672 .17881 Mtetra
.691 .655 .809 r
.53672 .17881 .54041 .18605 .54726 .18227 .54358 .17512 Mtetra
.692 .658 .812 r
.54358 .17512 .54726 .18227 .55413 .17849 .55046 .17141 Mtetra
.693 .661 .814 r
.55046 .17141 .55413 .17849 .561 .1747 .55734 .1677 Mtetra
.694 .665 .817 r
.55734 .1677 .561 .1747 .56789 .1709 .56424 .16399 Mtetra
.695 .668 .819 r
.56424 .16399 .56789 .1709 .57479 .1671 .57115 .16026 Mtetra
.696 .671 .822 r
.57115 .16026 .57479 .1671 .5817 .16329 .57807 .15654 Mtetra
.698 .675 .824 r
.57807 .15654 .5817 .16329 .58862 .15947 .585 .1528 Mtetra
.699 .679 .827 r
.585 .1528 .58862 .15947 .59556 .15565 .59194 .14906 Mtetra
.7 .682 .829 r
.59194 .14906 .59556 .15565 .6025 .15182 .5989 .14531 Mtetra
.701 .686 .832 r
.5989 .14531 .6025 .15182 .60946 .14799 .60587 .14155 Mtetra
.702 .69 .835 r
.60587 .14155 .60946 .14799 .61643 .14415 .61285 .13779 Mtetra
.703 .693 .837 r
.61285 .13779 .61643 .14415 .62341 .1403 .61984 .13402 Mtetra
.705 .697 .84 r
.61984 .13402 .62341 .1403 .6304 .13644 .62685 .13025 Mtetra
.706 .701 .843 r
.62685 .13025 .6304 .13644 .6374 .13258 .63386 .12647 Mtetra
.707 .705 .846 r
.63386 .12647 .6374 .13258 .64442 .12872 .64089 .12268 Mtetra
.708 .709 .848 r
.64089 .12268 .64442 .12872 .65144 .12484 .64793 .11888 Mtetra
.709 .713 .851 r
.64793 .11888 .65144 .12484 .65848 .12096 .65499 .11508 Mtetra
.711 .717 .854 r
.65499 .11508 .65848 .12096 .66553 .11707 .66205 .11127 Mtetra
.712 .721 .857 r
.66205 .11127 .66553 .11707 .6726 .11318 .66913 .10746 Mtetra
.713 .725 .86 r
.66913 .10746 .6726 .11318 .67967 .10928 .67622 .10363 Mtetra
.714 .73 .863 r
.67622 .10363 .67967 .10928 .68676 .10537 .68332 .0998 Mtetra
.715 .734 .866 r
.68332 .0998 .68676 .10537 .69385 .10145 .69044 .09597 Mtetra
.716 .738 .869 r
.69044 .09597 .69385 .10145 .70096 .09753 .69757 .09213 Mtetra
.717 .743 .872 r
.69757 .09213 .70096 .09753 .70809 .09361 .70471 .08828 Mtetra
.718 .747 .875 r
.70471 .08828 .70809 .09361 .71522 .08969 .71186 .08444 Mtetra
.717 .751 .879 r
.71186 .08444 .71522 .08969 .72237 .08581 .71903 .08063 Mtetra
.715 .754 .883 r
.71903 .08063 .72237 .08581 .72954 .08199 .72622 .07688 Mtetra
.711 .757 .888 r
.72622 .07688 .72954 .08199 .73673 .07828 .73343 .07323 Mtetra
.61 .726 .928 r
.08918 .30958 .09346 .31358 .0991 .31219 .09483 .30813 Mtetra
.595 .718 .93 r
.09483 .30813 .0991 .31219 .10473 .311 .10048 .30685 Mtetra
.59 .712 .928 r
.10048 .30685 .10473 .311 .11037 .30988 .10613 .30564 Mtetra
.588 .707 .925 r
.10613 .30564 .11037 .30988 .11602 .30879 .1118 .30445 Mtetra
.587 .702 .922 r
.1118 .30445 .11602 .30879 .12168 .30772 .11748 .30328 Mtetra
.587 .697 .918 r
.11748 .30328 .12168 .30772 .12736 .30664 .12317 .30211 Mtetra
.588 .693 .915 r
.12317 .30211 .12736 .30664 .13306 .30557 .12889 .30094 Mtetra
.589 .689 .911 r
.12889 .30094 .13306 .30557 .13877 .30449 .13462 .29976 Mtetra
.589 .684 .907 r
.13462 .29976 .13877 .30449 .1445 .3034 .14036 .29858 Mtetra
.59 .68 .903 r
.14036 .29858 .1445 .3034 .15025 .30232 .14613 .29739 Mtetra
.59 .676 .9 r
.14613 .29739 .15025 .30232 .15602 .30123 .15191 .29621 Mtetra
.59 .672 .896 r
.15191 .29621 .15602 .30123 .1618 .30014 .1577 .29501 Mtetra
.59 .667 .892 r
.1577 .29501 .1618 .30014 .1676 .29904 .16352 .29382 Mtetra
.591 .663 .889 r
.16352 .29382 .1676 .29904 .17342 .29794 .16935 .29262 Mtetra
.591 .66 .885 r
.16935 .29262 .17342 .29794 .17925 .29683 .1752 .29142 Mtetra
.591 .656 .882 r
.1752 .29142 .17925 .29683 .18511 .29573 .18107 .29021 Mtetra
.591 .652 .878 r
.18107 .29021 .18511 .29573 .19098 .29462 .18695 .289 Mtetra
.591 .648 .875 r
.18695 .289 .19098 .29462 .19687 .2935 .19286 .28778 Mtetra
.591 .644 .871 r
.19286 .28778 .19687 .2935 .20277 .29238 .19878 .28657 Mtetra
.591 .64 .868 r
.19878 .28657 .20277 .29238 .2087 .29126 .20471 .28534 Mtetra
.591 .637 .865 r
.20471 .28534 .2087 .29126 .21464 .29014 .21067 .28412 Mtetra
.591 .633 .861 r
.21067 .28412 .21464 .29014 .2206 .28901 .21664 .28289 Mtetra
.591 .63 .858 r
.21664 .28289 .2206 .28901 .22658 .28788 .22264 .28166 Mtetra
.591 .626 .855 r
.22264 .28166 .22658 .28788 .23258 .28674 .22864 .28042 Mtetra
.591 .623 .852 r
.22864 .28042 .23258 .28674 .2386 .2856 .23467 .27918 Mtetra
.591 .619 .849 r
.23467 .27918 .2386 .2856 .24463 .28446 .24072 .27794 Mtetra
.591 .616 .846 r
.24072 .27794 .24463 .28446 .25069 .28331 .24678 .27669 Mtetra
.591 .613 .842 r
.24678 .27669 .25069 .28331 .25676 .28216 .25287 .27543 Mtetra
.591 .61 .839 r
.25287 .27543 .25676 .28216 .26285 .28101 .25897 .27418 Mtetra
.59 .606 .836 r
.25897 .27418 .26285 .28101 .26896 .27986 .26509 .27292 Mtetra
.59 .603 .833 r
.26509 .27292 .26896 .27986 .27509 .2787 .27123 .27166 Mtetra
.59 .6 .831 r
.27123 .27166 .27509 .2787 .28124 .27753 .27739 .27039 Mtetra
.59 .597 .828 r
.27739 .27039 .28124 .27753 .28741 .27637 .28356 .26912 Mtetra
.59 .594 .825 r
.28356 .26912 .28741 .27637 .29359 .27519 .28976 .26785 Mtetra
.589 .591 .822 r
.28976 .26785 .29359 .27519 .2998 .27402 .29597 .26657 Mtetra
.589 .588 .819 r
.29597 .26657 .2998 .27402 .30603 .27284 .3022 .26528 Mtetra
.589 .586 .817 r
.3022 .26528 .30603 .27284 .31227 .27166 .30846 .264 Mtetra
.589 .583 .814 r
.30846 .264 .31227 .27166 .31854 .27048 .31473 .26271 Mtetra
.588 .58 .811 r
.31473 .26271 .31854 .27048 .32482 .26929 .32102 .26141 Mtetra
.588 .577 .809 r
.32102 .26141 .32482 .26929 .33112 .2681 .32733 .26012 Mtetra
.588 .575 .806 r
.32733 .26012 .33112 .2681 .33745 .2669 .33366 .25882 Mtetra
.587 .572 .803 r
.33366 .25882 .33745 .2669 .34379 .2657 .34001 .25751 Mtetra
.587 .569 .801 r
.34001 .25751 .34379 .2657 .35016 .2645 .34638 .2562 Mtetra
.587 .567 .798 r
.34638 .2562 .35016 .2645 .35654 .2633 .35277 .25489 Mtetra
.587 .564 .796 r
.35277 .25489 .35654 .2633 .36295 .26208 .35918 .25357 Mtetra
.586 .562 .794 r
.35918 .25357 .36295 .26208 .36937 .26086 .36561 .25224 Mtetra
.587 .56 .791 r
.36561 .25224 .36937 .26086 .37582 .25963 .37206 .2509 Mtetra
.589 .559 .788 r
.37206 .2509 .37582 .25963 .38229 .25833 .37854 .2495 Mtetra
.593 .559 .785 r
.37854 .2495 .38229 .25833 .38878 .25691 .38503 .24799 Mtetra
.622 .573 .778 r
.38503 .24799 .38878 .25691 .39533 .2547 .39158 .24576 Mtetra
.66 .592 .768 r
.39158 .24576 .39533 .2547 .40194 .25133 .39819 .24245 Mtetra
.664 .596 .768 r
.39819 .24245 .40194 .25133 .40857 .24785 .40482 .23905 Mtetra
.667 .599 .77 r
.40482 .23905 .40857 .24785 .41521 .2443 .41146 .23558 Mtetra
.668 .602 .771 r
.41146 .23558 .41521 .2443 .42186 .24072 .41811 .23208 Mtetra
.669 .604 .773 r
.41811 .23208 .42186 .24072 .42853 .23713 .42478 .22857 Mtetra
.67 .607 .775 r
.42478 .22857 .42853 .23713 .4352 .23353 .43145 .22505 Mtetra
.672 .609 .777 r
.43145 .22505 .4352 .23353 .44189 .22992 .43814 .22153 Mtetra
.673 .612 .779 r
.43814 .22153 .44189 .22992 .44859 .22631 .44484 .218 Mtetra
.673 .615 .781 r
.44484 .218 .44859 .22631 .4553 .22269 .45155 .21446 Mtetra
.675 .617 .783 r
.45155 .21446 .4553 .22269 .46202 .21907 .45828 .21092 Mtetra
.676 .62 .786 r
.45828 .21092 .46202 .21907 .46876 .21544 .46501 .20737 Mtetra
.677 .623 .788 r
.46501 .20737 .46876 .21544 .4755 .21181 .47176 .20382 Mtetra
.678 .626 .79 r
.47176 .20382 .4755 .21181 .48226 .20816 .47852 .20026 Mtetra
.679 .629 .792 r
.47852 .20026 .48226 .20816 .48902 .20452 .48529 .19669 Mtetra
.68 .632 .794 r
.48529 .19669 .48902 .20452 .4958 .20086 .49207 .19312 Mtetra
.681 .634 .797 r
.49207 .19312 .4958 .20086 .50259 .1972 .49887 .18954 Mtetra
.682 .638 .799 r
.49887 .18954 .50259 .1972 .5094 .19354 .50568 .18596 Mtetra
.683 .641 .801 r
.50568 .18596 .5094 .19354 .51621 .18987 .5125 .18236 Mtetra
.684 .644 .803 r
.5125 .18236 .51621 .18987 .52304 .18619 .51933 .17877 Mtetra
.685 .647 .806 r
.51933 .17877 .52304 .18619 .52987 .1825 .52617 .17516 Mtetra
.686 .65 .808 r
.52617 .17516 .52987 .1825 .53672 .17881 .53303 .17155 Mtetra
.687 .653 .811 r
.53303 .17155 .53672 .17881 .54358 .17512 .5399 .16794 Mtetra
.688 .656 .813 r
.5399 .16794 .54358 .17512 .55046 .17141 .54678 .16431 Mtetra
.69 .66 .815 r
.54678 .16431 .55046 .17141 .55734 .1677 .55367 .16069 Mtetra
.691 .663 .818 r
.55367 .16069 .55734 .1677 .56424 .16399 .56057 .15705 Mtetra
.692 .666 .82 r
.56057 .15705 .56424 .16399 .57115 .16026 .56749 .15341 Mtetra
.693 .67 .823 r
.56749 .15341 .57115 .16026 .57807 .15654 .57442 .14976 Mtetra
.694 .673 .826 r
.57442 .14976 .57807 .15654 .585 .1528 .58136 .1461 Mtetra
.695 .677 .828 r
.58136 .1461 .585 .1528 .59194 .14906 .58832 .14244 Mtetra
.696 .681 .831 r
.58832 .14244 .59194 .14906 .5989 .14531 .59529 .13877 Mtetra
.698 .684 .833 r
.59529 .13877 .5989 .14531 .60587 .14155 .60226 .1351 Mtetra
.699 .688 .836 r
.60226 .1351 .60587 .14155 .61285 .13779 .60926 .13141 Mtetra
.7 .692 .839 r
.60926 .13141 .61285 .13779 .61984 .13402 .61626 .12773 Mtetra
.701 .695 .842 r
.61626 .12773 .61984 .13402 .62685 .13025 .62328 .12403 Mtetra
.702 .699 .844 r
.62328 .12403 .62685 .13025 .63386 .12647 .63031 .12033 Mtetra
.703 .703 .847 r
.63031 .12033 .63386 .12647 .64089 .12268 .63735 .11662 Mtetra
.704 .707 .85 r
.63735 .11662 .64089 .12268 .64793 .11888 .64441 .1129 Mtetra
.706 .711 .853 r
.64441 .1129 .64793 .11888 .65499 .11508 .65148 .10918 Mtetra
.707 .715 .856 r
.65148 .10918 .65499 .11508 .66205 .11127 .65856 .10545 Mtetra
.708 .72 .859 r
.65856 .10545 .66205 .11127 .66913 .10746 .66565 .10171 Mtetra
.709 .724 .862 r
.66565 .10171 .66913 .10746 .67622 .10363 .67276 .09797 Mtetra
.71 .728 .864 r
.67276 .09797 .67622 .10363 .68332 .0998 .67988 .09422 Mtetra
.711 .732 .867 r
.67988 .09422 .68332 .0998 .69044 .09597 .68701 .09046 Mtetra
.712 .737 .871 r
.68701 .09046 .69044 .09597 .69757 .09213 .69416 .0867 Mtetra
.713 .741 .874 r
.69416 .0867 .69757 .09213 .70471 .08828 .70132 .08293 Mtetra
.714 .746 .877 r
.70132 .08293 .70471 .08828 .71186 .08444 .70849 .07917 Mtetra
.713 .749 .881 r
.70849 .07917 .71186 .08444 .71903 .08063 .71568 .07543 Mtetra
.711 .753 .885 r
.71568 .07543 .71903 .08063 .72622 .07688 .72288 .07175 Mtetra
.708 .755 .889 r
.72288 .07175 .72622 .07688 .73343 .07323 .73011 .06816 Mtetra
.616 .728 .926 r
.08488 .30557 .08918 .30958 .09483 .30813 .09055 .30405 Mtetra
.602 .72 .928 r
.09055 .30405 .09483 .30813 .10048 .30685 .09621 .30269 Mtetra
.597 .715 .926 r
.09621 .30269 .10048 .30685 .10613 .30564 .10188 .30138 Mtetra
.595 .709 .923 r
.10188 .30138 .10613 .30564 .1118 .30445 .10756 .3001 Mtetra
.595 .705 .92 r
.10756 .3001 .1118 .30445 .11748 .30328 .11326 .29883 Mtetra
.595 .7 .916 r
.11326 .29883 .11748 .30328 .12317 .30211 .11897 .29756 Mtetra
.595 .696 .913 r
.11897 .29756 .12317 .30211 .12889 .30094 .1247 .29629 Mtetra
.596 .691 .909 r
.1247 .29629 .12889 .30094 .13462 .29976 .13045 .29501 Mtetra
.596 .687 .905 r
.13045 .29501 .13462 .29976 .14036 .29858 .13621 .29374 Mtetra
.596 .683 .902 r
.13621 .29374 .14036 .29858 .14613 .29739 .14199 .29245 Mtetra
.597 .678 .898 r
.14199 .29245 .14613 .29739 .15191 .29621 .14778 .29116 Mtetra
.597 .674 .894 r
.14778 .29116 .15191 .29621 .1577 .29501 .1536 .28987 Mtetra
.597 .67 .891 r
.1536 .28987 .1577 .29501 .16352 .29382 .15943 .28858 Mtetra
.597 .666 .887 r
.15943 .28858 .16352 .29382 .16935 .29262 .16527 .28728 Mtetra
.597 .662 .884 r
.16527 .28728 .16935 .29262 .1752 .29142 .17114 .28598 Mtetra
.597 .658 .88 r
.17114 .28598 .1752 .29142 .18107 .29021 .17702 .28467 Mtetra
.597 .654 .877 r
.17702 .28467 .18107 .29021 .18695 .289 .18292 .28336 Mtetra
.597 .65 .873 r
.18292 .28336 .18695 .289 .19286 .28778 .18883 .28205 Mtetra
.597 .647 .87 r
.18883 .28205 .19286 .28778 .19878 .28657 .19477 .28073 Mtetra
.597 .643 .867 r
.19477 .28073 .19878 .28657 .20471 .28534 .20072 .27941 Mtetra
.597 .639 .863 r
.20072 .27941 .20471 .28534 .21067 .28412 .20668 .27808 Mtetra
.597 .636 .86 r
.20668 .27808 .21067 .28412 .21664 .28289 .21267 .27675 Mtetra
.597 .632 .857 r
.21267 .27675 .21664 .28289 .22264 .28166 .21867 .27542 Mtetra
.597 .629 .854 r
.21867 .27542 .22264 .28166 .22864 .28042 .2247 .27408 Mtetra
.597 .625 .85 r
.2247 .27408 .22864 .28042 .23467 .27918 .23074 .27274 Mtetra
.596 .622 .847 r
.23074 .27274 .23467 .27918 .24072 .27794 .23679 .27139 Mtetra
.596 .619 .844 r
.23679 .27139 .24072 .27794 .24678 .27669 .24287 .27004 Mtetra
.596 .615 .841 r
.24287 .27004 .24678 .27669 .25287 .27543 .24896 .26869 Mtetra
.596 .612 .838 r
.24896 .26869 .25287 .27543 .25897 .27418 .25507 .26733 Mtetra
.596 .609 .835 r
.25507 .26733 .25897 .27418 .26509 .27292 .2612 .26597 Mtetra
.595 .606 .832 r
.2612 .26597 .26509 .27292 .27123 .27166 .26735 .2646 Mtetra
.595 .603 .829 r
.26735 .2646 .27123 .27166 .27739 .27039 .27352 .26323 Mtetra
.595 .6 .827 r
.27352 .26323 .27739 .27039 .28356 .26912 .27971 .26186 Mtetra
.594 .597 .824 r
.27971 .26186 .28356 .26912 .28976 .26785 .28591 .26048 Mtetra
.594 .594 .821 r
.28591 .26048 .28976 .26785 .29597 .26657 .29213 .2591 Mtetra
.594 .591 .818 r
.29213 .2591 .29597 .26657 .3022 .26528 .29838 .25771 Mtetra
.594 .588 .816 r
.29838 .25771 .3022 .26528 .30846 .264 .30464 .25632 Mtetra
.593 .585 .813 r
.30464 .25632 .30846 .264 .31473 .26271 .31092 .25492 Mtetra
.593 .582 .81 r
.31092 .25492 .31473 .26271 .32102 .26141 .31721 .25352 Mtetra
.593 .58 .808 r
.31721 .25352 .32102 .26141 .32733 .26012 .32353 .25212 Mtetra
.592 .577 .805 r
.32353 .25212 .32733 .26012 .33366 .25882 .32987 .25072 Mtetra
.592 .574 .803 r
.32987 .25072 .33366 .25882 .34001 .25751 .33623 .2493 Mtetra
.591 .572 .8 r
.33623 .2493 .34001 .25751 .34638 .2562 .3426 .24789 Mtetra
.591 .569 .798 r
.3426 .24789 .34638 .2562 .35277 .25489 .349 .24647 Mtetra
.591 .567 .795 r
.349 .24647 .35277 .25489 .35918 .25357 .35541 .24504 Mtetra
.591 .564 .793 r
.35541 .24504 .35918 .25357 .36561 .25224 .36185 .24361 Mtetra
.591 .562 .79 r
.36185 .24361 .36561 .25224 .37206 .2509 .3683 .24216 Mtetra
.593 .561 .788 r
.3683 .24216 .37206 .2509 .37854 .2495 .37478 .24066 Mtetra
.596 .561 .785 r
.37478 .24066 .37854 .2495 .38503 .24799 .38128 .23906 Mtetra
.623 .573 .778 r
.38128 .23906 .38503 .24799 .39158 .24576 .38783 .23679 Mtetra
.657 .591 .769 r
.38783 .23679 .39158 .24576 .39819 .24245 .39444 .23356 Mtetra
.661 .594 .769 r
.39444 .23356 .39819 .24245 .40482 .23905 .40106 .23023 Mtetra
.664 .597 .771 r
.40106 .23023 .40482 .23905 .41146 .23558 .4077 .22683 Mtetra
.665 .6 .772 r
.4077 .22683 .41146 .23558 .41811 .23208 .41435 .22342 Mtetra
.666 .603 .774 r
.41435 .22342 .41811 .23208 .42478 .22857 .42102 .21999 Mtetra
.667 .605 .776 r
.42102 .21999 .42478 .22857 .43145 .22505 .4277 .21656 Mtetra
.668 .608 .778 r
.4277 .21656 .43145 .22505 .43814 .22153 .43438 .21311 Mtetra
.669 .611 .78 r
.43438 .21311 .43814 .22153 .44484 .218 .44108 .20966 Mtetra
.67 .613 .782 r
.44108 .20966 .44484 .218 .45155 .21446 .4478 .20621 Mtetra
.671 .616 .785 r
.4478 .20621 .45155 .21446 .45828 .21092 .45452 .20275 Mtetra
.672 .619 .787 r
.45452 .20275 .45828 .21092 .46501 .20737 .46126 .19928 Mtetra
.673 .621 .789 r
.46126 .19928 .46501 .20737 .47176 .20382 .46801 .19581 Mtetra
.674 .624 .791 r
.46801 .19581 .47176 .20382 .47852 .20026 .47477 .19233 Mtetra
.675 .627 .793 r
.47477 .19233 .47852 .20026 .48529 .19669 .48155 .18885 Mtetra
.676 .63 .795 r
.48155 .18885 .48529 .19669 .49207 .19312 .48833 .18536 Mtetra
.677 .633 .798 r
.48833 .18536 .49207 .19312 .49887 .18954 .49513 .18186 Mtetra
.679 .636 .8 r
.49513 .18186 .49887 .18954 .50568 .18596 .50195 .17835 Mtetra
.68 .639 .802 r
.50195 .17835 .50568 .18596 .5125 .18236 .50877 .17484 Mtetra
.681 .642 .805 r
.50877 .17484 .5125 .18236 .51933 .17877 .51561 .17133 Mtetra
.682 .645 .807 r
.51561 .17133 .51933 .17877 .52617 .17516 .52246 .1678 Mtetra
.683 .648 .809 r
.52246 .1678 .52617 .17516 .53303 .17155 .52932 .16427 Mtetra
.684 .652 .812 r
.52932 .16427 .53303 .17155 .5399 .16794 .5362 .16074 Mtetra
.685 .655 .814 r
.5362 .16074 .5399 .16794 .54678 .16431 .54308 .1572 Mtetra
.686 .658 .817 r
.54308 .1572 .54678 .16431 .55367 .16069 .54998 .15365 Mtetra
.687 .661 .819 r
.54998 .15365 .55367 .16069 .56057 .15705 .5569 .15009 Mtetra
.688 .665 .822 r
.5569 .15009 .56057 .15705 .56749 .15341 .56382 .14653 Mtetra
.689 .668 .824 r
.56382 .14653 .56749 .15341 .57442 .14976 .57076 .14296 Mtetra
.691 .672 .827 r
.57076 .14296 .57442 .14976 .58136 .1461 .57772 .13938 Mtetra
.692 .675 .83 r
.57772 .13938 .58136 .1461 .58832 .14244 .58468 .1358 Mtetra
.693 .679 .832 r
.58468 .1358 .58832 .14244 .59529 .13877 .59166 .13221 Mtetra
.694 .683 .835 r
.59166 .13221 .59529 .13877 .60226 .1351 .59865 .12861 Mtetra
.695 .686 .838 r
.59865 .12861 .60226 .1351 .60926 .13141 .60565 .12501 Mtetra
.696 .69 .84 r
.60565 .12501 .60926 .13141 .61626 .12773 .61267 .1214 Mtetra
.697 .694 .843 r
.61267 .1214 .61626 .12773 .62328 .12403 .6197 .11779 Mtetra
.698 .698 .846 r
.6197 .11779 .62328 .12403 .63031 .12033 .62674 .11416 Mtetra
.699 .702 .849 r
.62674 .11416 .63031 .12033 .63735 .11662 .6338 .11053 Mtetra
.701 .706 .852 r
.6338 .11053 .63735 .11662 .64441 .1129 .64087 .1069 Mtetra
.702 .71 .854 r
.64087 .1069 .64441 .1129 .65148 .10918 .64795 .10325 Mtetra
.703 .714 .857 r
.64795 .10325 .65148 .10918 .65856 .10545 .65505 .0996 Mtetra
.704 .718 .86 r
.65505 .0996 .65856 .10545 .66565 .10171 .66216 .09594 Mtetra
.705 .722 .863 r
.66216 .09594 .66565 .10171 .67276 .09797 .66928 .09228 Mtetra
.706 .727 .866 r
.66928 .09228 .67276 .09797 .67988 .09422 .67642 .0886 Mtetra
.707 .731 .869 r
.67642 .0886 .67988 .09422 .68701 .09046 .68357 .08493 Mtetra
.708 .735 .872 r
.68357 .08493 .68701 .09046 .69416 .0867 .69073 .08124 Mtetra
.709 .74 .875 r
.69073 .08124 .69416 .0867 .70132 .08293 .69791 .07755 Mtetra
.71 .744 .879 r
.69791 .07755 .70132 .08293 .70849 .07917 .7051 .07387 Mtetra
.709 .748 .882 r
.7051 .07387 .70849 .07917 .71568 .07543 .71231 .07021 Mtetra
.707 .751 .886 r
.71231 .07021 .71568 .07543 .72288 .07175 .71953 .06659 Mtetra
.704 .754 .891 r
.71953 .06659 .72288 .07175 .73011 .06816 .72678 .06306 Mtetra
.621 .73 .924 r
.08056 .30155 .08488 .30557 .09055 .30405 .08624 .29995 Mtetra
.608 .722 .926 r
.08624 .29995 .09055 .30405 .09621 .30269 .09192 .2985 Mtetra
.604 .717 .924 r
.09192 .2985 .09621 .30269 .10188 .30138 .09761 .2971 Mtetra
.603 .712 .921 r
.09761 .2971 .10188 .30138 .10756 .3001 .10331 .29573 Mtetra
.602 .707 .918 r
.10331 .29573 .10756 .3001 .11326 .29883 .10902 .29436 Mtetra
.602 .702 .914 r
.10902 .29436 .11326 .29883 .11897 .29756 .11475 .293 Mtetra
.603 .698 .911 r
.11475 .293 .11897 .29756 .1247 .29629 .1205 .29163 Mtetra
.603 .694 .907 r
.1205 .29163 .1247 .29629 .13045 .29501 .12626 .29025 Mtetra
.603 .689 .903 r
.12626 .29025 .13045 .29501 .13621 .29374 .13204 .28887 Mtetra
.603 .685 .9 r
.13204 .28887 .13621 .29374 .14199 .29245 .13783 .28749 Mtetra
.603 .681 .896 r
.13783 .28749 .14199 .29245 .14778 .29116 .14364 .28611 Mtetra
.603 .677 .893 r
.14364 .28611 .14778 .29116 .1536 .28987 .14947 .28472 Mtetra
.603 .673 .889 r
.14947 .28472 .1536 .28987 .15943 .28858 .15532 .28332 Mtetra
.604 .669 .885 r
.15532 .28332 .15943 .28858 .16527 .28728 .16118 .28193 Mtetra
.604 .665 .882 r
.16118 .28193 .16527 .28728 .17114 .28598 .16706 .28052 Mtetra
.603 .661 .879 r
.16706 .28052 .17114 .28598 .17702 .28467 .17295 .27912 Mtetra
.603 .657 .875 r
.17295 .27912 .17702 .28467 .18292 .28336 .17887 .27771 Mtetra
.603 .653 .872 r
.17887 .27771 .18292 .28336 .18883 .28205 .18479 .27629 Mtetra
.603 .649 .868 r
.18479 .27629 .18883 .28205 .19477 .28073 .19074 .27488 Mtetra
.603 .645 .865 r
.19074 .27488 .19477 .28073 .20072 .27941 .19671 .27345 Mtetra
.603 .642 .862 r
.19671 .27345 .20072 .27941 .20668 .27808 .20269 .27203 Mtetra
.603 .638 .859 r
.20269 .27203 .20668 .27808 .21267 .27675 .20869 .2706 Mtetra
.603 .635 .855 r
.20869 .2706 .21267 .27675 .21867 .27542 .2147 .26916 Mtetra
.602 .631 .852 r
.2147 .26916 .21867 .27542 .2247 .27408 .22074 .26772 Mtetra
.602 .628 .849 r
.22074 .26772 .2247 .27408 .23074 .27274 .22679 .26628 Mtetra
.602 .624 .846 r
.22679 .26628 .23074 .27274 .23679 .27139 .23286 .26483 Mtetra
.602 .621 .843 r
.23286 .26483 .23679 .27139 .24287 .27004 .23894 .26338 Mtetra
.601 .618 .84 r
.23894 .26338 .24287 .27004 .24896 .26869 .24505 .26192 Mtetra
.601 .615 .837 r
.24505 .26192 .24896 .26869 .25507 .26733 .25117 .26046 Mtetra
.601 .611 .834 r
.25117 .26046 .25507 .26733 .2612 .26597 .25731 .259 Mtetra
.6 .608 .831 r
.25731 .259 .2612 .26597 .26735 .2646 .26347 .25753 Mtetra
.6 .605 .828 r
.26347 .25753 .26735 .2646 .27352 .26323 .26965 .25606 Mtetra
.6 .602 .826 r
.26965 .25606 .27352 .26323 .27971 .26186 .27584 .25458 Mtetra
.599 .599 .823 r
.27584 .25458 .27971 .26186 .28591 .26048 .28205 .2531 Mtetra
.599 .596 .82 r
.28205 .2531 .28591 .26048 .29213 .2591 .28829 .25161 Mtetra
.599 .593 .817 r
.28829 .25161 .29213 .2591 .29838 .25771 .29454 .25012 Mtetra
.598 .59 .815 r
.29454 .25012 .29838 .25771 .30464 .25632 .30081 .24863 Mtetra
.598 .588 .812 r
.30081 .24863 .30464 .25632 .31092 .25492 .30709 .24713 Mtetra
.597 .585 .81 r
.30709 .24713 .31092 .25492 .31721 .25352 .3134 .24562 Mtetra
.597 .582 .807 r
.3134 .24562 .31721 .25352 .32353 .25212 .31972 .24412 Mtetra
.597 .579 .804 r
.31972 .24412 .32353 .25212 .32987 .25072 .32607 .2426 Mtetra
.596 .577 .802 r
.32607 .2426 .32987 .25072 .33623 .2493 .33243 .24109 Mtetra
.596 .574 .799 r
.33243 .24109 .33623 .2493 .3426 .24789 .33881 .23957 Mtetra
.595 .571 .797 r
.33881 .23957 .3426 .24789 .349 .24647 .34521 .23804 Mtetra
.595 .569 .795 r
.34521 .23804 .349 .24647 .35541 .24504 .35163 .23651 Mtetra
.595 .567 .792 r
.35163 .23651 .35541 .24504 .36185 .24361 .35807 .23497 Mtetra
.595 .564 .79 r
.35807 .23497 .36185 .24361 .3683 .24216 .36453 .23341 Mtetra
.596 .563 .787 r
.36453 .23341 .3683 .24216 .37478 .24066 .37101 .23181 Mtetra
.6 .563 .784 r
.37101 .23181 .37478 .24066 .38128 .23906 .37752 .23012 Mtetra
.623 .573 .778 r
.37752 .23012 .38128 .23906 .38783 .23679 .38407 .22782 Mtetra
.655 .589 .769 r
.38407 .22782 .38783 .23679 .39444 .23356 .39068 .22465 Mtetra
.658 .593 .77 r
.39068 .22465 .39444 .23356 .40106 .23023 .3973 .2214 Mtetra
.661 .596 .772 r
.3973 .2214 .40106 .23023 .4077 .22683 .40394 .21808 Mtetra
.662 .599 .773 r
.40394 .21808 .4077 .22683 .41435 .22342 .41059 .21475 Mtetra
.663 .601 .775 r
.41059 .21475 .41435 .22342 .42102 .21999 .41725 .2114 Mtetra
.664 .604 .777 r
.41725 .2114 .42102 .21999 .4277 .21656 .42393 .20805 Mtetra
.665 .607 .779 r
.42393 .20805 .4277 .21656 .43438 .21311 .43062 .20469 Mtetra
.666 .609 .781 r
.43062 .20469 .43438 .21311 .44108 .20966 .43732 .20132 Mtetra
.667 .612 .784 r
.43732 .20132 .44108 .20966 .4478 .20621 .44403 .19795 Mtetra
.668 .615 .786 r
.44403 .19795 .4478 .20621 .45452 .20275 .45076 .19457 Mtetra
.669 .617 .788 r
.45076 .19457 .45452 .20275 .46126 .19928 .4575 .19118 Mtetra
.67 .62 .79 r
.4575 .19118 .46126 .19928 .46801 .19581 .46425 .18779 Mtetra
.671 .623 .792 r
.46425 .18779 .46801 .19581 .47477 .19233 .47102 .18439 Mtetra
.672 .626 .794 r
.47102 .18439 .47477 .19233 .48155 .18885 .4778 .18099 Mtetra
.673 .629 .797 r
.4778 .18099 .48155 .18885 .48833 .18536 .48459 .17758 Mtetra
.674 .632 .799 r
.48459 .17758 .48833 .18536 .49513 .18186 .49139 .17416 Mtetra
.675 .635 .801 r
.49139 .17416 .49513 .18186 .50195 .17835 .49821 .17074 Mtetra
.676 .638 .804 r
.49821 .17074 .50195 .17835 .50877 .17484 .50504 .16731 Mtetra
.677 .641 .806 r
.50504 .16731 .50877 .17484 .51561 .17133 .51188 .16387 Mtetra
.678 .644 .808 r
.51188 .16387 .51561 .17133 .52246 .1678 .51873 .16043 Mtetra
.679 .647 .811 r
.51873 .16043 .52246 .1678 .52932 .16427 .5256 .15698 Mtetra
.68 .65 .813 r
.5256 .15698 .52932 .16427 .5362 .16074 .53248 .15352 Mtetra
.682 .653 .816 r
.53248 .15352 .5362 .16074 .54308 .1572 .53938 .15006 Mtetra
.683 .657 .818 r
.53938 .15006 .54308 .1572 .54998 .15365 .54629 .14659 Mtetra
.684 .66 .821 r
.54629 .14659 .54998 .15365 .5569 .15009 .55321 .14311 Mtetra
.685 .663 .823 r
.55321 .14311 .5569 .15009 .56382 .14653 .56014 .13963 Mtetra
.686 .667 .826 r
.56014 .13963 .56382 .14653 .57076 .14296 .56709 .13614 Mtetra
.687 .67 .828 r
.56709 .13614 .57076 .14296 .57772 .13938 .57405 .13264 Mtetra
.688 .674 .831 r
.57405 .13264 .57772 .13938 .58468 .1358 .58103 .12914 Mtetra
.689 .677 .834 r
.58103 .12914 .58468 .1358 .59166 .13221 .58802 .12563 Mtetra
.69 .681 .836 r
.58802 .12563 .59166 .13221 .59865 .12861 .59502 .12211 Mtetra
.691 .685 .839 r
.59502 .12211 .59865 .12861 .60565 .12501 .60204 .11859 Mtetra
.692 .689 .842 r
.60204 .11859 .60565 .12501 .61267 .1214 .60906 .11506 Mtetra
.693 .692 .845 r
.60906 .11506 .61267 .1214 .6197 .11779 .61611 .11152 Mtetra
.695 .696 .847 r
.61611 .11152 .6197 .11779 .62674 .11416 .62316 .10798 Mtetra
.696 .7 .85 r
.62316 .10798 .62674 .11416 .6338 .11053 .63023 .10443 Mtetra
.697 .704 .853 r
.63023 .10443 .6338 .11053 .64087 .1069 .63732 .10087 Mtetra
.698 .708 .856 r
.63732 .10087 .64087 .1069 .64795 .10325 .64441 .0973 Mtetra
.699 .712 .859 r
.64441 .0973 .64795 .10325 .65505 .0996 .65153 .09373 Mtetra
.7 .716 .862 r
.65153 .09373 .65505 .0996 .66216 .09594 .65865 .09015 Mtetra
.701 .721 .865 r
.65865 .09015 .66216 .09594 .66928 .09228 .66579 .08656 Mtetra
.702 .725 .868 r
.66579 .08656 .66928 .09228 .67642 .0886 .67294 .08297 Mtetra
.703 .729 .871 r
.67294 .08297 .67642 .0886 .68357 .08493 .68011 .07937 Mtetra
.704 .734 .874 r
.68011 .07937 .68357 .08493 .69073 .08124 .68729 .07577 Mtetra
.705 .738 .877 r
.68729 .07577 .69073 .08124 .69791 .07755 .69449 .07215 Mtetra
.705 .742 .88 r
.69449 .07215 .69791 .07755 .7051 .07387 .7017 .06854 Mtetra
.705 .746 .884 r
.7017 .06854 .7051 .07387 .71231 .07021 .70892 .06496 Mtetra
.703 .75 .888 r
.70892 .06496 .71231 .07021 .71953 .06659 .71616 .06141 Mtetra
.7 .752 .892 r
.71616 .06141 .71953 .06659 .72678 .06306 .72343 .05794 Mtetra
.626 .731 .923 r
.07622 .2975 .08056 .30155 .08624 .29995 .08192 .29584 Mtetra
.615 .724 .924 r
.08192 .29584 .08624 .29995 .09192 .2985 .08761 .2943 Mtetra
.611 .719 .922 r
.08761 .2943 .09192 .2985 .09761 .2971 .09332 .29281 Mtetra
.61 .714 .919 r
.09332 .29281 .09761 .2971 .10331 .29573 .09904 .29134 Mtetra
.609 .709 .916 r
.09904 .29134 .10331 .29573 .10902 .29436 .10477 .28987 Mtetra
.609 .705 .912 r
.10477 .28987 .10902 .29436 .11475 .293 .11051 .28841 Mtetra
.609 .7 .908 r
.11051 .28841 .11475 .293 .1205 .29163 .11628 .28694 Mtetra
.61 .696 .905 r
.11628 .28694 .1205 .29163 .12626 .29025 .12206 .28547 Mtetra
.61 .692 .901 r
.12206 .28547 .12626 .29025 .13204 .28887 .12785 .28399 Mtetra
.61 .687 .898 r
.12785 .28399 .13204 .28887 .13783 .28749 .13366 .28251 Mtetra
.61 .683 .894 r
.13366 .28251 .13783 .28749 .14364 .28611 .13949 .28103 Mtetra
.61 .679 .891 r
.13949 .28103 .14364 .28611 .14947 .28472 .14533 .27954 Mtetra
.61 .675 .887 r
.14533 .27954 .14947 .28472 .15532 .28332 .15119 .27805 Mtetra
.61 .671 .884 r
.15119 .27805 .15532 .28332 .16118 .28193 .15707 .27655 Mtetra
.61 .667 .88 r
.15707 .27655 .16118 .28193 .16706 .28052 .16296 .27505 Mtetra
.609 .663 .877 r
.16296 .27505 .16706 .28052 .17295 .27912 .16887 .27355 Mtetra
.609 .659 .873 r
.16887 .27355 .17295 .27912 .17887 .27771 .1748 .27204 Mtetra
.609 .655 .87 r
.1748 .27204 .17887 .27771 .18479 .27629 .18074 .27052 Mtetra
.609 .651 .867 r
.18074 .27052 .18479 .27629 .19074 .27488 .1867 .269 Mtetra
.609 .648 .864 r
.1867 .269 .19074 .27488 .19671 .27345 .19268 .26748 Mtetra
.609 .644 .86 r
.19268 .26748 .19671 .27345 .20269 .27203 .19868 .26595 Mtetra
.608 .64 .857 r
.19868 .26595 .20269 .27203 .20869 .2706 .20469 .26442 Mtetra
.608 .637 .854 r
.20469 .26442 .20869 .2706 .2147 .26916 .21072 .26289 Mtetra
.608 .633 .851 r
.21072 .26289 .2147 .26916 .22074 .26772 .21676 .26134 Mtetra
.607 .63 .848 r
.21676 .26134 .22074 .26772 .22679 .26628 .22283 .2598 Mtetra
.607 .627 .845 r
.22283 .2598 .22679 .26628 .23286 .26483 .22891 .25825 Mtetra
.607 .623 .842 r
.22891 .25825 .23286 .26483 .23894 .26338 .23501 .2567 Mtetra
.606 .62 .839 r
.23501 .2567 .23894 .26338 .24505 .26192 .24112 .25514 Mtetra
.606 .617 .836 r
.24112 .25514 .24505 .26192 .25117 .26046 .24726 .25358 Mtetra
.606 .614 .833 r
.24726 .25358 .25117 .26046 .25731 .259 .25341 .25201 Mtetra
.605 .61 .83 r
.25341 .25201 .25731 .259 .26347 .25753 .25958 .25044 Mtetra
.605 .607 .827 r
.25958 .25044 .26347 .25753 .26965 .25606 .26576 .24886 Mtetra
.604 .604 .824 r
.26576 .24886 .26965 .25606 .27584 .25458 .27197 .24728 Mtetra
.604 .601 .822 r
.27197 .24728 .27584 .25458 .28205 .2531 .27819 .2457 Mtetra
.604 .598 .819 r
.27819 .2457 .28205 .2531 .28829 .25161 .28443 .24411 Mtetra
.603 .595 .816 r
.28443 .24411 .28829 .25161 .29454 .25012 .29069 .24251 Mtetra
.603 .592 .814 r
.29069 .24251 .29454 .25012 .30081 .24863 .29697 .24091 Mtetra
.602 .59 .811 r
.29697 .24091 .30081 .24863 .30709 .24713 .30326 .23931 Mtetra
.602 .587 .808 r
.30326 .23931 .30709 .24713 .3134 .24562 .30958 .2377 Mtetra
.601 .584 .806 r
.30958 .2377 .3134 .24562 .31972 .24412 .31591 .23609 Mtetra
.601 .581 .803 r
.31591 .23609 .31972 .24412 .32607 .2426 .32226 .23447 Mtetra
.601 .579 .801 r
.32226 .23447 .32607 .2426 .33243 .24109 .32863 .23285 Mtetra
.6 .576 .798 r
.32863 .23285 .33243 .24109 .33881 .23957 .33502 .23122 Mtetra
.6 .574 .796 r
.33502 .23122 .33881 .23957 .34521 .23804 .34142 .22959 Mtetra
.599 .571 .794 r
.34142 .22959 .34521 .23804 .35163 .23651 .34785 .22795 Mtetra
.599 .569 .791 r
.34785 .22795 .35163 .23651 .35807 .23497 .35429 .22631 Mtetra
.599 .566 .789 r
.35429 .22631 .35807 .23497 .36453 .23341 .36076 .22464 Mtetra
.6 .565 .786 r
.36076 .22464 .36453 .23341 .37101 .23181 .36724 .22294 Mtetra
.603 .564 .784 r
.36724 .22294 .37101 .23181 .37752 .23012 .37375 .22116 Mtetra
.624 .574 .777 r
.37375 .22116 .37752 .23012 .38407 .22782 .38031 .21884 Mtetra
.652 .588 .77 r
.38031 .21884 .38407 .22782 .39068 .22465 .38691 .21573 Mtetra
.655 .591 .771 r
.38691 .21573 .39068 .22465 .3973 .2214 .39353 .21255 Mtetra
.658 .594 .772 r
.39353 .21255 .3973 .2214 .40394 .21808 .40017 .20931 Mtetra
.659 .597 .774 r
.40017 .20931 .40394 .21808 .41059 .21475 .40682 .20606 Mtetra
.66 .6 .776 r
.40682 .20606 .41059 .21475 .41725 .2114 .41348 .20279 Mtetra
.661 .602 .778 r
.41348 .20279 .41725 .2114 .42393 .20805 .42016 .19952 Mtetra
.662 .605 .78 r
.42016 .19952 .42393 .20805 .43062 .20469 .42684 .19624 Mtetra
.663 .607 .782 r
.42684 .19624 .43062 .20469 .43732 .20132 .43355 .19295 Mtetra
.664 .61 .784 r
.43355 .19295 .43732 .20132 .44403 .19795 .44026 .18966 Mtetra
.665 .613 .787 r
.44026 .18966 .44403 .19795 .45076 .19457 .44699 .18636 Mtetra
.666 .616 .789 r
.44699 .18636 .45076 .19457 .4575 .19118 .45373 .18306 Mtetra
.667 .618 .791 r
.45373 .18306 .4575 .19118 .46425 .18779 .46049 .17975 Mtetra
.668 .621 .793 r
.46049 .17975 .46425 .18779 .47102 .18439 .46725 .17643 Mtetra
.669 .624 .795 r
.46725 .17643 .47102 .18439 .4778 .18099 .47403 .17311 Mtetra
.67 .627 .798 r
.47403 .17311 .4778 .18099 .48459 .17758 .48083 .16978 Mtetra
.671 .63 .8 r
.48083 .16978 .48459 .17758 .49139 .17416 .48764 .16644 Mtetra
.672 .633 .802 r
.48764 .16644 .49139 .17416 .49821 .17074 .49446 .1631 Mtetra
.673 .636 .805 r
.49446 .1631 .49821 .17074 .50504 .16731 .50129 .15974 Mtetra
.674 .639 .807 r
.50129 .15974 .50504 .16731 .51188 .16387 .50814 .15639 Mtetra
.675 .642 .809 r
.50814 .15639 .51188 .16387 .51873 .16043 .515 .15303 Mtetra
.676 .645 .812 r
.515 .15303 .51873 .16043 .5256 .15698 .52187 .14966 Mtetra
.677 .648 .814 r
.52187 .14966 .5256 .15698 .53248 .15352 .52876 .14628 Mtetra
.678 .652 .817 r
.52876 .14628 .53248 .15352 .53938 .15006 .53567 .1429 Mtetra
.679 .655 .819 r
.53567 .1429 .53938 .15006 .54629 .14659 .54258 .13951 Mtetra
.68 .658 .822 r
.54258 .13951 .54629 .14659 .55321 .14311 .54951 .13611 Mtetra
.681 .662 .824 r
.54951 .13611 .55321 .14311 .56014 .13963 .55645 .13271 Mtetra
.682 .665 .827 r
.55645 .13271 .56014 .13963 .56709 .13614 .56341 .1293 Mtetra
.683 .669 .83 r
.56341 .1293 .56709 .13614 .57405 .13264 .57038 .12588 Mtetra
.684 .672 .832 r
.57038 .12588 .57405 .13264 .58103 .12914 .57737 .12245 Mtetra
.685 .676 .835 r
.57737 .12245 .58103 .12914 .58802 .12563 .58437 .11902 Mtetra
.686 .679 .838 r
.58437 .11902 .58802 .12563 .59502 .12211 .59138 .11559 Mtetra
.687 .683 .84 r
.59138 .11559 .59502 .12211 .60204 .11859 .59841 .11214 Mtetra
.688 .687 .843 r
.59841 .11214 .60204 .11859 .60906 .11506 .60545 .10869 Mtetra
.69 .691 .846 r
.60545 .10869 .60906 .11506 .61611 .11152 .6125 .10523 Mtetra
.691 .695 .849 r
.6125 .10523 .61611 .11152 .62316 .10798 .61957 .10177 Mtetra
.692 .699 .852 r
.61957 .10177 .62316 .10798 .63023 .10443 .62665 .09829 Mtetra
.693 .702 .855 r
.62665 .09829 .63023 .10443 .63732 .10087 .63375 .09482 Mtetra
.694 .707 .857 r
.63375 .09482 .63732 .10087 .64441 .0973 .64086 .09133 Mtetra
.695 .711 .86 r
.64086 .09133 .64441 .0973 .65153 .09373 .64799 .08783 Mtetra
.696 .715 .863 r
.64799 .08783 .65153 .09373 .65865 .09015 .65513 .08433 Mtetra
.697 .719 .866 r
.65513 .08433 .65865 .09015 .66579 .08656 .66228 .08083 Mtetra
.698 .723 .869 r
.66228 .08083 .66579 .08656 .67294 .08297 .66945 .07731 Mtetra
.699 .728 .873 r
.66945 .07731 .67294 .08297 .68011 .07937 .67664 .07379 Mtetra
.7 .732 .876 r
.67664 .07379 .68011 .07937 .68729 .07577 .68383 .07026 Mtetra
.701 .736 .879 r
.68383 .07026 .68729 .07577 .69449 .07215 .69105 .06673 Mtetra
.701 .741 .882 r
.69105 .06673 .69449 .07215 .7017 .06854 .69827 .0632 Mtetra
.701 .745 .886 r
.69827 .0632 .7017 .06854 .70892 .06496 .70552 .05969 Mtetra
.699 .748 .889 r
.70552 .05969 .70892 .06496 .71616 .06141 .71278 .05621 Mtetra
.697 .751 .894 r
.71278 .05621 .71616 .06141 .72343 .05794 .72006 .0528 Mtetra
.63 .732 .921 r
.07186 .29344 .07622 .2975 .08192 .29584 .07758 .2917 Mtetra
.621 .726 .922 r
.07758 .2917 .08192 .29584 .08761 .2943 .08329 .29008 Mtetra
.618 .721 .92 r
.08329 .29008 .08761 .2943 .09332 .29281 .08901 .2885 Mtetra
.617 .716 .917 r
.08901 .2885 .09332 .29281 .09904 .29134 .09475 .28693 Mtetra
.616 .712 .913 r
.09475 .28693 .09904 .29134 .10477 .28987 .1005 .28537 Mtetra
.616 .707 .91 r
.1005 .28537 .10477 .28987 .11051 .28841 .10626 .28381 Mtetra
.616 .703 .906 r
.10626 .28381 .11051 .28841 .11628 .28694 .11204 .28224 Mtetra
.616 .698 .903 r
.11204 .28224 .11628 .28694 .12206 .28547 .11784 .28067 Mtetra
.616 .694 .899 r
.11784 .28067 .12206 .28547 .12785 .28399 .12365 .2791 Mtetra
.616 .69 .896 r
.12365 .2791 .12785 .28399 .13366 .28251 .12948 .27752 Mtetra
.616 .685 .892 r
.12948 .27752 .13366 .28251 .13949 .28103 .13532 .27593 Mtetra
.616 .681 .889 r
.13532 .27593 .13949 .28103 .14533 .27954 .14118 .27435 Mtetra
.616 .677 .885 r
.14118 .27435 .14533 .27954 .15119 .27805 .14706 .27275 Mtetra
.616 .673 .882 r
.14706 .27275 .15119 .27805 .15707 .27655 .15295 .27116 Mtetra
.616 .669 .878 r
.15295 .27116 .15707 .27655 .16296 .27505 .15886 .26956 Mtetra
.615 .665 .875 r
.15886 .26956 .16296 .27505 .16887 .27355 .16478 .26795 Mtetra
.615 .661 .872 r
.16478 .26795 .16887 .27355 .1748 .27204 .17072 .26634 Mtetra
.615 .657 .868 r
.17072 .26634 .1748 .27204 .18074 .27052 .17668 .26473 Mtetra
.614 .654 .865 r
.17668 .26473 .18074 .27052 .1867 .269 .18266 .26311 Mtetra
.614 .65 .862 r
.18266 .26311 .1867 .269 .19268 .26748 .18865 .26148 Mtetra
.614 .646 .859 r
.18865 .26148 .19268 .26748 .19868 .26595 .19465 .25986 Mtetra
.614 .643 .856 r
.19465 .25986 .19868 .26595 .20469 .26442 .20068 .25822 Mtetra
.613 .639 .852 r
.20068 .25822 .20469 .26442 .21072 .26289 .20672 .25659 Mtetra
.613 .636 .849 r
.20672 .25659 .21072 .26289 .21676 .26134 .21278 .25494 Mtetra
.612 .632 .846 r
.21278 .25494 .21676 .26134 .22283 .2598 .21886 .2533 Mtetra
.612 .629 .843 r
.21886 .2533 .22283 .2598 .22891 .25825 .22495 .25165 Mtetra
.612 .625 .84 r
.22495 .25165 .22891 .25825 .23501 .2567 .23106 .24999 Mtetra
.611 .622 .837 r
.23106 .24999 .23501 .2567 .24112 .25514 .23719 .24833 Mtetra
.611 .619 .834 r
.23719 .24833 .24112 .25514 .24726 .25358 .24333 .24667 Mtetra
.61 .616 .832 r
.24333 .24667 .24726 .25358 .25341 .25201 .24949 .245 Mtetra
.61 .613 .829 r
.24949 .245 .25341 .25201 .25958 .25044 .25567 .24332 Mtetra
.61 .609 .826 r
.25567 .24332 .25958 .25044 .26576 .24886 .26187 .24164 Mtetra
.609 .606 .823 r
.26187 .24164 .26576 .24886 .27197 .24728 .26808 .23996 Mtetra
.609 .603 .821 r
.26808 .23996 .27197 .24728 .27819 .2457 .27432 .23827 Mtetra
.608 .6 .818 r
.27432 .23827 .27819 .2457 .28443 .24411 .28057 .23658 Mtetra
.608 .597 .815 r
.28057 .23658 .28443 .24411 .29069 .24251 .28683 .23488 Mtetra
.607 .595 .813 r
.28683 .23488 .29069 .24251 .29697 .24091 .29312 .23318 Mtetra
.607 .592 .81 r
.29312 .23318 .29697 .24091 .30326 .23931 .29942 .23147 Mtetra
.606 .589 .807 r
.29942 .23147 .30326 .23931 .30958 .2377 .30574 .22976 Mtetra
.606 .586 .805 r
.30574 .22976 .30958 .2377 .31591 .23609 .31208 .22804 Mtetra
.605 .583 .802 r
.31208 .22804 .31591 .23609 .32226 .23447 .31844 .22632 Mtetra
.605 .581 .8 r
.31844 .22632 .32226 .23447 .32863 .23285 .32482 .22459 Mtetra
.604 .578 .797 r
.32482 .22459 .32863 .23285 .33502 .23122 .33121 .22286 Mtetra
.604 .576 .795 r
.33121 .22286 .33502 .23122 .34142 .22959 .33763 .22112 Mtetra
.603 .573 .793 r
.33763 .22112 .34142 .22959 .34785 .22795 .34406 .21937 Mtetra
.603 .571 .79 r
.34406 .21937 .34785 .22795 .35429 .22631 .35051 .21762 Mtetra
.603 .568 .788 r
.35051 .21762 .35429 .22631 .36076 .22464 .35698 .21586 Mtetra
.604 .567 .785 r
.35698 .21586 .36076 .22464 .36724 .22294 .36347 .21405 Mtetra
.606 .566 .783 r
.36347 .21405 .36724 .22294 .37375 .22116 .36998 .21218 Mtetra
.625 .574 .777 r
.36998 .21218 .37375 .22116 .38031 .21884 .37654 .20983 Mtetra
.65 .587 .771 r
.37654 .20983 .38031 .21884 .38691 .21573 .38314 .20679 Mtetra
.652 .59 .772 r
.38314 .20679 .38691 .21573 .39353 .21255 .38976 .20368 Mtetra
.655 .593 .773 r
.38976 .20368 .39353 .21255 .40017 .20931 .39639 .20052 Mtetra
.656 .595 .775 r
.39639 .20052 .40017 .20931 .40682 .20606 .40304 .19735 Mtetra
.657 .598 .777 r
.40304 .19735 .40682 .20606 .41348 .20279 .4097 .19416 Mtetra
.658 .6 .779 r
.4097 .19416 .41348 .20279 .42016 .19952 .41638 .19097 Mtetra
.659 .603 .781 r
.41638 .19097 .42016 .19952 .42684 .19624 .42306 .18777 Mtetra
.66 .606 .783 r
.42306 .18777 .42684 .19624 .43355 .19295 .42977 .18457 Mtetra
.661 .608 .785 r
.42977 .18457 .43355 .19295 .44026 .18966 .43648 .18136 Mtetra
.662 .611 .787 r
.43648 .18136 .44026 .18966 .44699 .18636 .44321 .17814 Mtetra
.663 .614 .79 r
.44321 .17814 .44699 .18636 .45373 .18306 .44995 .17491 Mtetra
.663 .617 .792 r
.44995 .17491 .45373 .18306 .46049 .17975 .45671 .17168 Mtetra
.664 .619 .794 r
.45671 .17168 .46049 .17975 .46725 .17643 .46348 .16845 Mtetra
.665 .622 .796 r
.46348 .16845 .46725 .17643 .47403 .17311 .47026 .1652 Mtetra
.666 .625 .799 r
.47026 .1652 .47403 .17311 .48083 .16978 .47706 .16195 Mtetra
.667 .628 .801 r
.47706 .16195 .48083 .16978 .48764 .16644 .48387 .15869 Mtetra
.668 .631 .803 r
.48387 .15869 .48764 .16644 .49446 .1631 .4907 .15543 Mtetra
.669 .634 .806 r
.4907 .15543 .49446 .1631 .50129 .15974 .49754 .15216 Mtetra
.67 .637 .808 r
.49754 .15216 .50129 .15974 .50814 .15639 .50439 .14888 Mtetra
.671 .64 .81 r
.50439 .14888 .50814 .15639 .515 .15303 .51126 .1456 Mtetra
.672 .644 .813 r
.51126 .1456 .515 .15303 .52187 .14966 .51814 .14231 Mtetra
.673 .647 .815 r
.51814 .14231 .52187 .14966 .52876 .14628 .52503 .13901 Mtetra
.674 .65 .818 r
.52503 .13901 .52876 .14628 .53567 .1429 .53194 .13571 Mtetra
.675 .653 .82 r
.53194 .13571 .53567 .1429 .54258 .13951 .53886 .1324 Mtetra
.676 .657 .823 r
.53886 .1324 .54258 .13951 .54951 .13611 .5458 .12908 Mtetra
.677 .66 .826 r
.5458 .12908 .54951 .13611 .55645 .13271 .55275 .12576 Mtetra
.678 .663 .828 r
.55275 .12576 .55645 .13271 .56341 .1293 .55972 .12243 Mtetra
.679 .667 .831 r
.55972 .12243 .56341 .1293 .57038 .12588 .5667 .11909 Mtetra
.68 .67 .834 r
.5667 .11909 .57038 .12588 .57737 .12245 .57369 .11574 Mtetra
.681 .674 .836 r
.57369 .11574 .57737 .12245 .58437 .11902 .5807 .11239 Mtetra
.683 .678 .839 r
.5807 .11239 .58437 .11902 .59138 .11559 .58772 .10903 Mtetra
.684 .681 .842 r
.58772 .10903 .59138 .11559 .59841 .11214 .59476 .10567 Mtetra
.685 .685 .845 r
.59476 .10567 .59841 .11214 .60545 .10869 .60181 .1023 Mtetra
.686 .689 .847 r
.60181 .1023 .60545 .10869 .6125 .10523 .60888 .09892 Mtetra
.687 .693 .85 r
.60888 .09892 .6125 .10523 .61957 .10177 .61596 .09553 Mtetra
.688 .697 .853 r
.61596 .09553 .61957 .10177 .62665 .09829 .62306 .09214 Mtetra
.689 .701 .856 r
.62306 .09214 .62665 .09829 .63375 .09482 .63017 .08874 Mtetra
.69 .705 .859 r
.63017 .08874 .63375 .09482 .64086 .09133 .6373 .08533 Mtetra
.691 .709 .862 r
.6373 .08533 .64086 .09133 .64799 .08783 .64444 .08191 Mtetra
.692 .713 .865 r
.64444 .08191 .64799 .08783 .65513 .08433 .65159 .07849 Mtetra
.693 .717 .868 r
.65159 .07849 .65513 .08433 .66228 .08083 .65876 .07506 Mtetra
.694 .721 .871 r
.65876 .07506 .66228 .08083 .66945 .07731 .66595 .07163 Mtetra
.694 .726 .874 r
.66595 .07163 .66945 .07731 .67664 .07379 .67315 .06818 Mtetra
.695 .73 .877 r
.67315 .06818 .67664 .07379 .68383 .07026 .68036 .06474 Mtetra
.696 .735 .88 r
.68036 .06474 .68383 .07026 .69105 .06673 .68759 .06128 Mtetra
.697 .739 .884 r
.68759 .06128 .69105 .06673 .69827 .0632 .69484 .05783 Mtetra
.696 .743 .887 r
.69484 .05783 .69827 .0632 .70552 .05969 .7021 .05439 Mtetra
.695 .747 .891 r
.7021 .05439 .70552 .05969 .71278 .05621 .70938 .05098 Mtetra
.693 .749 .895 r
.70938 .05098 .71278 .05621 .72006 .0528 .71668 .04763 Mtetra
.635 .734 .919 r
.06749 .28937 .07186 .29344 .07758 .2917 .07322 .28756 Mtetra
.627 .728 .92 r
.07322 .28756 .07758 .2917 .08329 .29008 .07895 .28585 Mtetra
.625 .723 .917 r
.07895 .28585 .08329 .29008 .08901 .2885 .08469 .28417 Mtetra
.623 .718 .915 r
.08469 .28417 .08901 .2885 .09475 .28693 .09044 .2825 Mtetra
.623 .714 .911 r
.09044 .2825 .09475 .28693 .1005 .28537 .09621 .28085 Mtetra
.623 .709 .908 r
.09621 .28085 .1005 .28537 .10626 .28381 .10199 .27919 Mtetra
.623 .705 .904 r
.10199 .27919 .10626 .28381 .11204 .28224 .10779 .27752 Mtetra
.623 .7 .901 r
.10779 .27752 .11204 .28224 .11784 .28067 .1136 .27585 Mtetra
.622 .696 .897 r
.1136 .27585 .11784 .28067 .12365 .2791 .11943 .27418 Mtetra
.622 .692 .894 r
.11943 .27418 .12365 .2791 .12948 .27752 .12527 .2725 Mtetra
.622 .688 .89 r
.12527 .2725 .12948 .27752 .13532 .27593 .13113 .27082 Mtetra
.622 .683 .887 r
.13113 .27082 .13532 .27593 .14118 .27435 .13701 .26913 Mtetra
.622 .679 .883 r
.13701 .26913 .14118 .27435 .14706 .27275 .1429 .26744 Mtetra
.622 .675 .88 r
.1429 .26744 .14706 .27275 .15295 .27116 .14881 .26574 Mtetra
.621 .671 .877 r
.14881 .26574 .15295 .27116 .15886 .26956 .15473 .26404 Mtetra
.621 .667 .873 r
.15473 .26404 .15886 .26956 .16478 .26795 .16067 .26234 Mtetra
.621 .663 .87 r
.16067 .26234 .16478 .26795 .17072 .26634 .16663 .26063 Mtetra
.62 .66 .867 r
.16663 .26063 .17072 .26634 .17668 .26473 .1726 .25891 Mtetra
.62 .656 .864 r
.1726 .25891 .17668 .26473 .18266 .26311 .17859 .2572 Mtetra
.62 .652 .86 r
.17859 .2572 .18266 .26311 .18865 .26148 .1846 .25547 Mtetra
.619 .649 .857 r
.1846 .25547 .18865 .26148 .19465 .25986 .19062 .25374 Mtetra
.619 .645 .854 r
.19062 .25374 .19465 .25986 .20068 .25822 .19666 .25201 Mtetra
.618 .641 .851 r
.19666 .25201 .20068 .25822 .20672 .25659 .20271 .25027 Mtetra
.618 .638 .848 r
.20271 .25027 .20672 .25659 .21278 .25494 .20878 .24853 Mtetra
.618 .634 .845 r
.20878 .24853 .21278 .25494 .21886 .2533 .21487 .24678 Mtetra
.617 .631 .842 r
.21487 .24678 .21886 .2533 .22495 .25165 .22098 .24503 Mtetra
.617 .628 .839 r
.22098 .24503 .22495 .25165 .23106 .24999 .2271 .24327 Mtetra
.616 .624 .836 r
.2271 .24327 .23106 .24999 .23719 .24833 .23324 .24151 Mtetra
.616 .621 .833 r
.23324 .24151 .23719 .24833 .24333 .24667 .23939 .23974 Mtetra
.615 .618 .831 r
.23939 .23974 .24333 .24667 .24949 .245 .24557 .23797 Mtetra
.615 .615 .828 r
.24557 .23797 .24949 .245 .25567 .24332 .25176 .23619 Mtetra
.614 .612 .825 r
.25176 .23619 .25567 .24332 .26187 .24164 .25796 .23441 Mtetra
.614 .609 .822 r
.25796 .23441 .26187 .24164 .26808 .23996 .26419 .23263 Mtetra
.613 .606 .82 r
.26419 .23263 .26808 .23996 .27432 .23827 .27043 .23083 Mtetra
.613 .603 .817 r
.27043 .23083 .27432 .23827 .28057 .23658 .27669 .22904 Mtetra
.612 .6 .814 r
.27669 .22904 .28057 .23658 .28683 .23488 .28297 .22724 Mtetra
.612 .597 .812 r
.28297 .22724 .28683 .23488 .29312 .23318 .28926 .22543 Mtetra
.611 .594 .809 r
.28926 .22543 .29312 .23318 .29942 .23147 .29557 .22362 Mtetra
.611 .591 .807 r
.29557 .22362 .29942 .23147 .30574 .22976 .3019 .2218 Mtetra
.61 .589 .804 r
.3019 .2218 .30574 .22976 .31208 .22804 .30825 .21998 Mtetra
.61 .586 .802 r
.30825 .21998 .31208 .22804 .31844 .22632 .31462 .21815 Mtetra
.609 .583 .799 r
.31462 .21815 .31844 .22632 .32482 .22459 .321 .21632 Mtetra
.608 .58 .797 r
.321 .21632 .32482 .22459 .33121 .22286 .3274 .21448 Mtetra
.608 .578 .794 r
.3274 .21448 .33121 .22286 .33763 .22112 .33382 .21264 Mtetra
.608 .575 .792 r
.33382 .21264 .33763 .22112 .34406 .21937 .34026 .21079 Mtetra
.607 .573 .79 r
.34026 .21079 .34406 .21937 .35051 .21762 .34672 .20893 Mtetra
.607 .571 .787 r
.34672 .20893 .35051 .21762 .35698 .21586 .35319 .20706 Mtetra
.608 .569 .785 r
.35319 .20706 .35698 .21586 .36347 .21405 .35969 .20516 Mtetra
.61 .568 .782 r
.35969 .20516 .36347 .21405 .36998 .21218 .3662 .20319 Mtetra
.625 .574 .777 r
.3662 .20319 .36998 .21218 .37654 .20983 .37276 .20081 Mtetra
.647 .585 .771 r
.37276 .20081 .37654 .20983 .38314 .20679 .37936 .19784 Mtetra
.65 .588 .773 r
.37936 .19784 .38314 .20679 .38976 .20368 .38598 .1948 Mtetra
.652 .591 .774 r
.38598 .1948 .38976 .20368 .39639 .20052 .39261 .19172 Mtetra
.653 .594 .776 r
.39261 .19172 .39639 .20052 .40304 .19735 .39925 .18863 Mtetra
.654 .596 .778 r
.39925 .18863 .40304 .19735 .4097 .19416 .40591 .18552 Mtetra
.655 .599 .78 r
.40591 .18552 .4097 .19416 .41638 .19097 .41259 .18241 Mtetra
.656 .602 .782 r
.41259 .18241 .41638 .19097 .42306 .18777 .41928 .17929 Mtetra
.657 .604 .784 r
.41928 .17929 .42306 .18777 .42977 .18457 .42598 .17617 Mtetra
.657 .607 .786 r
.42598 .17617 .42977 .18457 .43648 .18136 .43269 .17304 Mtetra
.658 .61 .789 r
.43269 .17304 .43648 .18136 .44321 .17814 .43942 .1699 Mtetra
.659 .612 .791 r
.43942 .1699 .44321 .17814 .44995 .17491 .44617 .16676 Mtetra
.66 .615 .793 r
.44617 .16676 .44995 .17491 .45671 .17168 .45293 .1636 Mtetra
.661 .618 .795 r
.45293 .1636 .45671 .17168 .46348 .16845 .4597 .16045 Mtetra
.662 .621 .798 r
.4597 .16045 .46348 .16845 .47026 .1652 .46648 .15728 Mtetra
.663 .624 .8 r
.46648 .15728 .47026 .1652 .47706 .16195 .47328 .15411 Mtetra
.664 .627 .802 r
.47328 .15411 .47706 .16195 .48387 .15869 .4801 .15093 Mtetra
.665 .63 .805 r
.4801 .15093 .48387 .15869 .4907 .15543 .48693 .14775 Mtetra
.666 .633 .807 r
.48693 .14775 .4907 .15543 .49754 .15216 .49377 .14456 Mtetra
.667 .636 .809 r
.49377 .14456 .49754 .15216 .50439 .14888 .50063 .14136 Mtetra
.668 .639 .812 r
.50063 .14136 .50439 .14888 .51126 .1456 .5075 .13816 Mtetra
.669 .642 .814 r
.5075 .13816 .51126 .1456 .51814 .14231 .51439 .13495 Mtetra
.67 .645 .817 r
.51439 .13495 .51814 .14231 .52503 .13901 .52129 .13173 Mtetra
.671 .648 .819 r
.52129 .13173 .52503 .13901 .53194 .13571 .5282 .1285 Mtetra
.672 .652 .822 r
.5282 .1285 .53194 .13571 .53886 .1324 .53513 .12527 Mtetra
.673 .655 .824 r
.53513 .12527 .53886 .1324 .5458 .12908 .54208 .12203 Mtetra
.674 .658 .827 r
.54208 .12203 .5458 .12908 .55275 .12576 .54904 .11879 Mtetra
.675 .662 .83 r
.54904 .11879 .55275 .12576 .55972 .12243 .55601 .11554 Mtetra
.676 .665 .832 r
.55601 .11554 .55972 .12243 .5667 .11909 .563 .11228 Mtetra
.677 .669 .835 r
.563 .11228 .5667 .11909 .57369 .11574 .57 .10901 Mtetra
.678 .673 .838 r
.57 .10901 .57369 .11574 .5807 .11239 .57702 .10574 Mtetra
.679 .676 .84 r
.57702 .10574 .5807 .11239 .58772 .10903 .58406 .10246 Mtetra
.68 .68 .843 r
.58406 .10246 .58772 .10903 .59476 .10567 .5911 .09917 Mtetra
.681 .684 .846 r
.5911 .09917 .59476 .10567 .60181 .1023 .59817 .09588 Mtetra
.682 .687 .849 r
.59817 .09588 .60181 .1023 .60888 .09892 .60525 .09258 Mtetra
.683 .691 .852 r
.60525 .09258 .60888 .09892 .61596 .09553 .61234 .08927 Mtetra
.684 .695 .855 r
.61234 .08927 .61596 .09553 .62306 .09214 .61945 .08596 Mtetra
.685 .699 .858 r
.61945 .08596 .62306 .09214 .63017 .08874 .62657 .08264 Mtetra
.686 .703 .861 r
.62657 .08264 .63017 .08874 .6373 .08533 .63371 .07931 Mtetra
.686 .707 .864 r
.63371 .07931 .6373 .08533 .64444 .08191 .64087 .07597 Mtetra
.687 .711 .867 r
.64087 .07597 .64444 .08191 .65159 .07849 .64804 .07263 Mtetra
.688 .716 .87 r
.64804 .07263 .65159 .07849 .65876 .07506 .65522 .06928 Mtetra
.689 .72 .873 r
.65522 .06928 .65876 .07506 .66595 .07163 .66243 .06592 Mtetra
.69 .724 .876 r
.66243 .06592 .66595 .07163 .67315 .06818 .66964 .06256 Mtetra
.691 .728 .879 r
.66964 .06256 .67315 .06818 .68036 .06474 .67688 .05918 Mtetra
.692 .733 .882 r
.67688 .05918 .68036 .06474 .68759 .06128 .68412 .05581 Mtetra
.692 .737 .885 r
.68412 .05581 .68759 .06128 .69484 .05783 .69139 .05243 Mtetra
.692 .741 .889 r
.69139 .05243 .69484 .05783 .7021 .05439 .69867 .04907 Mtetra
.691 .745 .892 r
.69867 .04907 .7021 .05439 .70938 .05098 .70597 .04573 Mtetra
.689 .748 .896 r
.70597 .04573 .70938 .05098 .71668 .04763 .71329 .04244 Mtetra
.64 .735 .918 r
.06309 .28527 .06749 .28937 .07322 .28756 .06884 .28339 Mtetra
.633 .73 .918 r
.06884 .28339 .07322 .28756 .07895 .28585 .07459 .28159 Mtetra
.631 .725 .915 r
.07459 .28159 .07895 .28585 .08469 .28417 .08035 .27982 Mtetra
.63 .72 .912 r
.08035 .27982 .08469 .28417 .09044 .2825 .08612 .27806 Mtetra
.629 .716 .909 r
.08612 .27806 .09044 .2825 .09621 .28085 .0919 .2763 Mtetra
.629 .711 .906 r
.0919 .2763 .09621 .28085 .10199 .27919 .0977 .27455 Mtetra
.629 .707 .902 r
.0977 .27455 .10199 .27919 .10779 .27752 .10352 .27278 Mtetra
.629 .702 .899 r
.10352 .27278 .10779 .27752 .1136 .27585 .10935 .27102 Mtetra
.629 .698 .895 r
.10935 .27102 .1136 .27585 .11943 .27418 .11519 .26924 Mtetra
.628 .694 .892 r
.11519 .26924 .11943 .27418 .12527 .2725 .12106 .26747 Mtetra
.628 .69 .888 r
.12106 .26747 .12527 .2725 .13113 .27082 .12693 .26569 Mtetra
.628 .686 .885 r
.12693 .26569 .13113 .27082 .13701 .26913 .13283 .2639 Mtetra
.628 .681 .882 r
.13283 .2639 .13701 .26913 .1429 .26744 .13873 .26211 Mtetra
.627 .677 .878 r
.13873 .26211 .1429 .26744 .14881 .26574 .14466 .26031 Mtetra
.627 .673 .875 r
.14466 .26031 .14881 .26574 .15473 .26404 .1506 .25851 Mtetra
.626 .669 .872 r
.1506 .25851 .15473 .26404 .16067 .26234 .15655 .25671 Mtetra
.626 .666 .868 r
.15655 .25671 .16067 .26234 .16663 .26063 .16252 .2549 Mtetra
.626 .662 .865 r
.16252 .2549 .16663 .26063 .1726 .25891 .16851 .25309 Mtetra
.625 .658 .862 r
.16851 .25309 .1726 .25891 .17859 .2572 .17452 .25127 Mtetra
.625 .654 .859 r
.17452 .25127 .17859 .2572 .1846 .25547 .18053 .24944 Mtetra
.624 .651 .856 r
.18053 .24944 .1846 .25547 .19062 .25374 .18657 .24761 Mtetra
.624 .647 .853 r
.18657 .24761 .19062 .25374 .19666 .25201 .19262 .24578 Mtetra
.623 .644 .85 r
.19262 .24578 .19666 .25201 .20271 .25027 .19869 .24394 Mtetra
.623 .64 .847 r
.19869 .24394 .20271 .25027 .20878 .24853 .20478 .2421 Mtetra
.622 .637 .844 r
.20478 .2421 .20878 .24853 .21487 .24678 .21088 .24025 Mtetra
.622 .633 .841 r
.21088 .24025 .21487 .24678 .22098 .24503 .21699 .2384 Mtetra
.621 .63 .838 r
.21699 .2384 .22098 .24503 .2271 .24327 .22313 .23654 Mtetra
.621 .627 .835 r
.22313 .23654 .2271 .24327 .23324 .24151 .22928 .23467 Mtetra
.62 .623 .832 r
.22928 .23467 .23324 .24151 .23939 .23974 .23545 .2328 Mtetra
.62 .62 .829 r
.23545 .2328 .23939 .23974 .24557 .23797 .24163 .23093 Mtetra
.619 .617 .827 r
.24163 .23093 .24557 .23797 .25176 .23619 .24783 .22905 Mtetra
.619 .614 .824 r
.24783 .22905 .25176 .23619 .25796 .23441 .25405 .22717 Mtetra
.618 .611 .821 r
.25405 .22717 .25796 .23441 .26419 .23263 .26028 .22528 Mtetra
.618 .608 .819 r
.26028 .22528 .26419 .23263 .27043 .23083 .26654 .22338 Mtetra
.617 .605 .816 r
.26654 .22338 .27043 .23083 .27669 .22904 .27281 .22148 Mtetra
.617 .602 .813 r
.27281 .22148 .27669 .22904 .28297 .22724 .27909 .21958 Mtetra
.616 .599 .811 r
.27909 .21958 .28297 .22724 .28926 .22543 .2854 .21767 Mtetra
.615 .596 .808 r
.2854 .21767 .28926 .22543 .29557 .22362 .29172 .21575 Mtetra
.615 .593 .806 r
.29172 .21575 .29557 .22362 .3019 .2218 .29806 .21383 Mtetra
.614 .591 .803 r
.29806 .21383 .3019 .2218 .30825 .21998 .30441 .21191 Mtetra
.614 .588 .801 r
.30441 .21191 .30825 .21998 .31462 .21815 .31078 .20997 Mtetra
.613 .585 .798 r
.31078 .20997 .31462 .21815 .321 .21632 .31718 .20804 Mtetra
.613 .583 .796 r
.31718 .20804 .321 .21632 .3274 .21448 .32358 .20609 Mtetra
.612 .58 .794 r
.32358 .20609 .3274 .21448 .33382 .21264 .33001 .20415 Mtetra
.612 .578 .791 r
.33001 .20415 .33382 .21264 .34026 .21079 .33645 .20219 Mtetra
.611 .575 .789 r
.33645 .20219 .34026 .21079 .34672 .20893 .34292 .20023 Mtetra
.611 .573 .787 r
.34292 .20023 .34672 .20893 .35319 .20706 .3494 .19826 Mtetra
.611 .571 .784 r
.3494 .19826 .35319 .20706 .35969 .20516 .3559 .19625 Mtetra
.613 .57 .782 r
.3559 .19625 .35969 .20516 .3662 .20319 .36242 .19419 Mtetra
.626 .575 .777 r
.36242 .19419 .3662 .20319 .37276 .20081 .36898 .19179 Mtetra
.644 .584 .772 r
.36898 .19179 .37276 .20081 .37936 .19784 .37557 .18888 Mtetra
.647 .587 .774 r
.37557 .18888 .37936 .19784 .38598 .1948 .38219 .18591 Mtetra
.648 .59 .775 r
.38219 .18591 .38598 .1948 .39261 .19172 .38882 .18291 Mtetra
.65 .592 .777 r
.38882 .18291 .39261 .19172 .39925 .18863 .39546 .1799 Mtetra
.651 .595 .779 r
.39546 .1799 .39925 .18863 .40591 .18552 .40212 .17687 Mtetra
.651 .597 .781 r
.40212 .17687 .40591 .18552 .41259 .18241 .40879 .17384 Mtetra
.652 .6 .783 r
.40879 .17384 .41259 .18241 .41928 .17929 .41548 .1708 Mtetra
.653 .603 .785 r
.41548 .1708 .41928 .17929 .42598 .17617 .42218 .16776 Mtetra
.654 .605 .788 r
.42218 .16776 .42598 .17617 .43269 .17304 .4289 .16471 Mtetra
.655 .608 .79 r
.4289 .16471 .43269 .17304 .43942 .1699 .43563 .16165 Mtetra
.656 .611 .792 r
.43563 .16165 .43942 .1699 .44617 .16676 .44237 .15858 Mtetra
.657 .614 .794 r
.44237 .15858 .44617 .16676 .45293 .1636 .44913 .15551 Mtetra
.658 .616 .796 r
.44913 .15551 .45293 .1636 .4597 .16045 .45591 .15243 Mtetra
.659 .619 .799 r
.45591 .15243 .4597 .16045 .46648 .15728 .46269 .14935 Mtetra
.66 .622 .801 r
.46269 .14935 .46648 .15728 .47328 .15411 .4695 .14626 Mtetra
.66 .625 .803 r
.4695 .14626 .47328 .15411 .4801 .15093 .47631 .14316 Mtetra
.661 .628 .806 r
.47631 .14316 .4801 .15093 .48693 .14775 .48315 .14005 Mtetra
.662 .631 .808 r
.48315 .14005 .48693 .14775 .49377 .14456 .48999 .13694 Mtetra
.663 .634 .811 r
.48999 .13694 .49377 .14456 .50063 .14136 .49686 .13382 Mtetra
.664 .637 .813 r
.49686 .13382 .50063 .14136 .5075 .13816 .50373 .1307 Mtetra
.665 .64 .815 r
.50373 .1307 .5075 .13816 .51439 .13495 .51063 .12757 Mtetra
.666 .644 .818 r
.51063 .12757 .51439 .13495 .52129 .13173 .51753 .12443 Mtetra
.667 .647 .821 r
.51753 .12443 .52129 .13173 .5282 .1285 .52445 .12128 Mtetra
.668 .65 .823 r
.52445 .12128 .5282 .1285 .53513 .12527 .53139 .11813 Mtetra
.669 .653 .826 r
.53139 .11813 .53513 .12527 .54208 .12203 .53834 .11497 Mtetra
.67 .657 .828 r
.53834 .11497 .54208 .12203 .54904 .11879 .54531 .1118 Mtetra
.671 .66 .831 r
.54531 .1118 .54904 .11879 .55601 .11554 .55229 .10863 Mtetra
.672 .664 .834 r
.55229 .10863 .55601 .11554 .563 .11228 .55929 .10545 Mtetra
.673 .667 .836 r
.55929 .10545 .563 .11228 .57 .10901 .5663 .10226 Mtetra
.674 .671 .839 r
.5663 .10226 .57 .10901 .57702 .10574 .57333 .09907 Mtetra
.675 .675 .842 r
.57333 .09907 .57702 .10574 .58406 .10246 .58038 .09587 Mtetra
.676 .678 .845 r
.58038 .09587 .58406 .10246 .5911 .09917 .58743 .09266 Mtetra
.677 .682 .848 r
.58743 .09266 .5911 .09917 .59817 .09588 .59451 .08944 Mtetra
.678 .686 .85 r
.59451 .08944 .59817 .09588 .60525 .09258 .6016 .08622 Mtetra
.679 .69 .853 r
.6016 .08622 .60525 .09258 .61234 .08927 .60871 .08299 Mtetra
.679 .693 .856 r
.60871 .08299 .61234 .08927 .61945 .08596 .61583 .07976 Mtetra
.68 .697 .859 r
.61583 .07976 .61945 .08596 .62657 .08264 .62297 .07651 Mtetra
.681 .701 .862 r
.62297 .07651 .62657 .08264 .63371 .07931 .63012 .07326 Mtetra
.682 .705 .865 r
.63012 .07326 .63371 .07931 .64087 .07597 .63729 .07 Mtetra
.683 .71 .868 r
.63729 .07 .64087 .07597 .64804 .07263 .64447 .06674 Mtetra
.684 .714 .871 r
.64447 .06674 .64804 .07263 .65522 .06928 .65167 .06347 Mtetra
.685 .718 .874 r
.65167 .06347 .65522 .06928 .66243 .06592 .65889 .06019 Mtetra
.686 .722 .877 r
.65889 .06019 .66243 .06592 .66964 .06256 .66612 .0569 Mtetra
.687 .727 .881 r
.66612 .0569 .66964 .06256 .67688 .05918 .67337 .05361 Mtetra
.687 .731 .884 r
.67337 .05361 .67688 .05918 .68412 .05581 .68064 .05031 Mtetra
.688 .735 .887 r
.68064 .05031 .68412 .05581 .69139 .05243 .68792 .04701 Mtetra
.688 .739 .89 r
.68792 .04701 .69139 .05243 .69867 .04907 .69522 .04372 Mtetra
.687 .743 .894 r
.69522 .04372 .69867 .04907 .70597 .04573 .70254 .04045 Mtetra
.685 .746 .898 r
.70254 .04045 .70597 .04573 .71329 .04244 .70987 .03722 Mtetra
.644 .736 .916 r
.05868 .28116 .06309 .28527 .06884 .28339 .06444 .27921 Mtetra
.639 .731 .915 r
.06444 .27921 .06884 .28339 .07459 .28159 .07021 .27732 Mtetra
.637 .727 .913 r
.07021 .27732 .07459 .28159 .08035 .27982 .07599 .27546 Mtetra
.636 .722 .91 r
.07599 .27546 .08035 .27982 .08612 .27806 .08178 .2736 Mtetra
.636 .718 .907 r
.08178 .2736 .08612 .27806 .0919 .2763 .08758 .27175 Mtetra
.635 .713 .903 r
.08758 .27175 .0919 .2763 .0977 .27455 .0934 .26989 Mtetra
.635 .709 .9 r
.0934 .26989 .0977 .27455 .10352 .27278 .09923 .26803 Mtetra
.635 .704 .896 r
.09923 .26803 .10352 .27278 .10935 .27102 .10508 .26616 Mtetra
.635 .7 .893 r
.10508 .26616 .10935 .27102 .11519 .26924 .11094 .26429 Mtetra
.634 .696 .89 r
.11094 .26429 .11519 .26924 .12106 .26747 .11682 .26241 Mtetra
.634 .692 .886 r
.11682 .26241 .12106 .26747 .12693 .26569 .12272 .26053 Mtetra
.634 .687 .883 r
.12272 .26053 .12693 .26569 .13283 .2639 .12863 .25865 Mtetra
.633 .683 .88 r
.12863 .25865 .13283 .2639 .13873 .26211 .13455 .25676 Mtetra
.633 .679 .876 r
.13455 .25676 .13873 .26211 .14466 .26031 .14049 .25486 Mtetra
.632 .675 .873 r
.14049 .25486 .14466 .26031 .1506 .25851 .14645 .25296 Mtetra
.632 .671 .87 r
.14645 .25296 .1506 .25851 .15655 .25671 .15242 .25106 Mtetra
.631 .668 .867 r
.15242 .25106 .15655 .25671 .16252 .2549 .1584 .24915 Mtetra
.631 .664 .863 r
.1584 .24915 .16252 .2549 .16851 .25309 .16441 .24723 Mtetra
.63 .66 .86 r
.16441 .24723 .16851 .25309 .17452 .25127 .17043 .24532 Mtetra
.63 .656 .857 r
.17043 .24532 .17452 .25127 .18053 .24944 .17646 .24339 Mtetra
.629 .653 .854 r
.17646 .24339 .18053 .24944 .18657 .24761 .18251 .24146 Mtetra
.629 .649 .851 r
.18251 .24146 .18657 .24761 .19262 .24578 .18858 .23953 Mtetra
.628 .646 .848 r
.18858 .23953 .19262 .24578 .19869 .24394 .19466 .23759 Mtetra
.628 .642 .845 r
.19466 .23759 .19869 .24394 .20478 .2421 .20076 .23564 Mtetra
.627 .639 .842 r
.20076 .23564 .20478 .2421 .21088 .24025 .20687 .23369 Mtetra
.627 .635 .839 r
.20687 .23369 .21088 .24025 .21699 .2384 .213 .23174 Mtetra
.626 .632 .836 r
.213 .23174 .21699 .2384 .22313 .23654 .21915 .22978 Mtetra
.626 .629 .834 r
.21915 .22978 .22313 .23654 .22928 .23467 .22531 .22781 Mtetra
.625 .625 .831 r
.22531 .22781 .22928 .23467 .23545 .2328 .23149 .22584 Mtetra
.624 .622 .828 r
.23149 .22584 .23545 .2328 .24163 .23093 .23768 .22387 Mtetra
.624 .619 .825 r
.23768 .22387 .24163 .23093 .24783 .22905 .2439 .22188 Mtetra
.623 .616 .823 r
.2439 .22188 .24783 .22905 .25405 .22717 .25013 .2199 Mtetra
.623 .613 .82 r
.25013 .2199 .25405 .22717 .26028 .22528 .25637 .21791 Mtetra
.622 .61 .817 r
.25637 .21791 .26028 .22528 .26654 .22338 .26263 .21591 Mtetra
.621 .607 .815 r
.26263 .21591 .26654 .22338 .27281 .22148 .26891 .21391 Mtetra
.621 .604 .812 r
.26891 .21391 .27281 .22148 .27909 .21958 .27521 .2119 Mtetra
.62 .601 .81 r
.27521 .2119 .27909 .21958 .2854 .21767 .28152 .20988 Mtetra
.62 .598 .807 r
.28152 .20988 .2854 .21767 .29172 .21575 .28785 .20786 Mtetra
.619 .595 .805 r
.28785 .20786 .29172 .21575 .29806 .21383 .2942 .20584 Mtetra
.618 .593 .802 r
.2942 .20584 .29806 .21383 .30441 .21191 .30056 .20381 Mtetra
.618 .59 .8 r
.30056 .20381 .30441 .21191 .31078 .20997 .30694 .20177 Mtetra
.617 .587 .797 r
.30694 .20177 .31078 .20997 .31718 .20804 .31334 .19973 Mtetra
.617 .585 .795 r
.31334 .19973 .31718 .20804 .32358 .20609 .31976 .19768 Mtetra
.616 .582 .793 r
.31976 .19768 .32358 .20609 .33001 .20415 .32619 .19563 Mtetra
.615 .579 .79 r
.32619 .19563 .33001 .20415 .33645 .20219 .33264 .19357 Mtetra
.615 .577 .788 r
.33264 .19357 .33645 .20219 .34292 .20023 .33911 .19151 Mtetra
.615 .574 .786 r
.33911 .19151 .34292 .20023 .3494 .19826 .3456 .18943 Mtetra
.615 .572 .783 r
.3456 .18943 .3494 .19826 .3559 .19625 .3521 .18732 Mtetra
.616 .571 .781 r
.3521 .18732 .3559 .19625 .36242 .19419 .35863 .18517 Mtetra
.626 .575 .777 r
.35863 .18517 .36242 .19419 .36898 .19179 .36519 .18274 Mtetra
.641 .582 .773 r
.36519 .18274 .36898 .19179 .37557 .18888 .37178 .17989 Mtetra
.643 .585 .774 r
.37178 .17989 .37557 .18888 .38219 .18591 .37839 .177 Mtetra
.645 .588 .776 r
.37839 .177 .38219 .18591 .38882 .18291 .38502 .17408 Mtetra
.646 .59 .778 r
.38502 .17408 .38882 .18291 .39546 .1799 .39166 .17114 Mtetra
.647 .593 .78 r
.39166 .17114 .39546 .1799 .40212 .17687 .39832 .1682 Mtetra
.648 .596 .782 r
.39832 .1682 .40212 .17687 .40879 .17384 .40499 .16525 Mtetra
.649 .598 .784 r
.40499 .16525 .40879 .17384 .41548 .1708 .41168 .16229 Mtetra
.65 .601 .786 r
.41168 .16229 .41548 .1708 .42218 .16776 .41838 .15932 Mtetra
.651 .603 .788 r
.41838 .15932 .42218 .16776 .4289 .16471 .42509 .15635 Mtetra
.652 .606 .791 r
.42509 .15635 .4289 .16471 .43563 .16165 .43182 .15337 Mtetra
.652 .609 .793 r
.43182 .15337 .43563 .16165 .44237 .15858 .43857 .15038 Mtetra
.653 .612 .795 r
.43857 .15038 .44237 .15858 .44913 .15551 .44533 .14739 Mtetra
.654 .615 .797 r
.44533 .14739 .44913 .15551 .45591 .15243 .4521 .14439 Mtetra
.655 .617 .8 r
.4521 .14439 .45591 .15243 .46269 .14935 .4589 .14139 Mtetra
.656 .62 .802 r
.4589 .14139 .46269 .14935 .4695 .14626 .4657 .13838 Mtetra
.657 .623 .804 r
.4657 .13838 .4695 .14626 .47631 .14316 .47252 .13536 Mtetra
.658 .626 .807 r
.47252 .13536 .47631 .14316 .48315 .14005 .47936 .13233 Mtetra
.659 .629 .809 r
.47936 .13233 .48315 .14005 .48999 .13694 .48621 .1293 Mtetra
.66 .632 .812 r
.48621 .1293 .48999 .13694 .49686 .13382 .49307 .12626 Mtetra
.661 .635 .814 r
.49307 .12626 .49686 .13382 .50373 .1307 .49996 .12321 Mtetra
.661 .639 .816 r
.49996 .12321 .50373 .1307 .51063 .12757 .50685 .12016 Mtetra
.662 .642 .819 r
.50685 .12016 .51063 .12757 .51753 .12443 .51377 .1171 Mtetra
.663 .645 .822 r
.51377 .1171 .51753 .12443 .52445 .12128 .52069 .11403 Mtetra
.664 .648 .824 r
.52069 .11403 .52445 .12128 .53139 .11813 .52764 .11096 Mtetra
.665 .652 .827 r
.52764 .11096 .53139 .11813 .53834 .11497 .5346 .10788 Mtetra
.666 .655 .829 r
.5346 .10788 .53834 .11497 .54531 .1118 .54157 .10479 Mtetra
.667 .658 .832 r
.54157 .10479 .54531 .1118 .55229 .10863 .54856 .10169 Mtetra
.668 .662 .835 r
.54856 .10169 .55229 .10863 .55929 .10545 .55557 .09859 Mtetra
.669 .665 .838 r
.55557 .09859 .55929 .10545 .5663 .10226 .56259 .09548 Mtetra
.67 .669 .84 r
.56259 .09548 .5663 .10226 .57333 .09907 .56963 .09237 Mtetra
.671 .673 .843 r
.56963 .09237 .57333 .09907 .58038 .09587 .57668 .08925 Mtetra
.672 .676 .846 r
.57668 .08925 .58038 .09587 .58743 .09266 .58375 .08612 Mtetra
.673 .68 .849 r
.58375 .08612 .58743 .09266 .59451 .08944 .59084 .08298 Mtetra
.673 .684 .852 r
.59084 .08298 .59451 .08944 .6016 .08622 .59794 .07984 Mtetra
.674 .688 .855 r
.59794 .07984 .6016 .08622 .60871 .08299 .60506 .07668 Mtetra
.675 .692 .858 r
.60506 .07668 .60871 .08299 .61583 .07976 .61219 .07353 Mtetra
.676 .695 .861 r
.61219 .07353 .61583 .07976 .62297 .07651 .61934 .07036 Mtetra
.677 .7 .864 r
.61934 .07036 .62297 .07651 .63012 .07326 .62651 .06719 Mtetra
.678 .704 .867 r
.62651 .06719 .63012 .07326 .63729 .07 .63369 .06401 Mtetra
.679 .708 .87 r
.63369 .06401 .63729 .07 .64447 .06674 .64089 .06082 Mtetra
.68 .712 .873 r
.64089 .06082 .64447 .06674 .65167 .06347 .64811 .05763 Mtetra
.68 .716 .876 r
.64811 .05763 .65167 .06347 .65889 .06019 .65534 .05443 Mtetra
.681 .72 .879 r
.65534 .05443 .65889 .06019 .66612 .0569 .66259 .05122 Mtetra
.682 .725 .882 r
.66259 .05122 .66612 .0569 .67337 .05361 .66985 .04801 Mtetra
.683 .729 .885 r
.66985 .04801 .67337 .05361 .68064 .05031 .67714 .04479 Mtetra
.683 .733 .889 r
.67714 .04479 .68064 .05031 .68792 .04701 .68444 .04156 Mtetra
.683 .738 .892 r
.68444 .04156 .68792 .04701 .69522 .04372 .69175 .03835 Mtetra
.683 .741 .895 r
.69175 .03835 .69522 .04372 .70254 .04045 .69909 .03515 Mtetra
.681 .745 .899 r
.69909 .03515 .70254 .04045 .70987 .03722 .70644 .03198 Mtetra
.649 .737 .914 r
.05425 .27703 .05868 .28116 .06444 .27921 .06003 .275 Mtetra
.645 .733 .913 r
.06003 .275 .06444 .27921 .07021 .27732 .06581 .27303 Mtetra
.643 .729 .911 r
.06581 .27303 .07021 .27732 .07599 .27546 .07161 .27107 Mtetra
.642 .724 .908 r
.07161 .27107 .07599 .27546 .08178 .2736 .07742 .26912 Mtetra
.642 .72 .904 r
.07742 .26912 .08178 .2736 .08758 .27175 .08324 .26717 Mtetra
.641 .715 .901 r
.08324 .26717 .08758 .27175 .0934 .26989 .08908 .26521 Mtetra
.641 .711 .898 r
.08908 .26521 .0934 .26989 .09923 .26803 .09493 .26325 Mtetra
.641 .706 .894 r
.09493 .26325 .09923 .26803 .10508 .26616 .1008 .26129 Mtetra
.64 .702 .891 r
.1008 .26129 .10508 .26616 .11094 .26429 .10668 .25932 Mtetra
.64 .698 .888 r
.10668 .25932 .11094 .26429 .11682 .26241 .11257 .25735 Mtetra
.64 .694 .884 r
.11257 .25735 .11682 .26241 .12272 .26053 .11848 .25537 Mtetra
.639 .69 .881 r
.11848 .25537 .12272 .26053 .12863 .25865 .12441 .25338 Mtetra
.639 .686 .878 r
.12441 .25338 .12863 .25865 .13455 .25676 .13035 .25139 Mtetra
.638 .682 .875 r
.13035 .25139 .13455 .25676 .14049 .25486 .13631 .2494 Mtetra
.638 .678 .871 r
.13631 .2494 .14049 .25486 .14645 .25296 .14228 .2474 Mtetra
.637 .674 .868 r
.14228 .2474 .14645 .25296 .15242 .25106 .14827 .2454 Mtetra
.637 .67 .865 r
.14827 .2454 .15242 .25106 .1584 .24915 .15427 .24339 Mtetra
.636 .666 .862 r
.15427 .24339 .1584 .24915 .16441 .24723 .16029 .24137 Mtetra
.636 .662 .859 r
.16029 .24137 .16441 .24723 .17043 .24532 .16632 .23935 Mtetra
.635 .659 .856 r
.16632 .23935 .17043 .24532 .17646 .24339 .17237 .23733 Mtetra
.634 .655 .853 r
.17237 .23733 .17646 .24339 .18251 .24146 .17843 .2353 Mtetra
.634 .651 .85 r
.17843 .2353 .18251 .24146 .18858 .23953 .18451 .23327 Mtetra
.633 .648 .847 r
.18451 .23327 .18858 .23953 .19466 .23759 .19061 .23123 Mtetra
.633 .644 .844 r
.19061 .23123 .19466 .23759 .20076 .23564 .19672 .22918 Mtetra
.632 .641 .841 r
.19672 .22918 .20076 .23564 .20687 .23369 .20285 .22713 Mtetra
.631 .638 .838 r
.20285 .22713 .20687 .23369 .213 .23174 .20899 .22507 Mtetra
.631 .634 .835 r
.20899 .22507 .213 .23174 .21915 .22978 .21515 .22301 Mtetra
.63 .631 .833 r
.21515 .22301 .21915 .22978 .22531 .22781 .22133 .22095 Mtetra
.63 .628 .83 r
.22133 .22095 .22531 .22781 .23149 .22584 .22752 .21887 Mtetra
.629 .625 .827 r
.22752 .21887 .23149 .22584 .23768 .22387 .23373 .2168 Mtetra
.628 .622 .824 r
.23373 .2168 .23768 .22387 .2439 .22188 .23995 .21471 Mtetra
.628 .618 .822 r
.23995 .21471 .2439 .22188 .25013 .2199 .24619 .21263 Mtetra
.627 .615 .819 r
.24619 .21263 .25013 .2199 .25637 .21791 .25245 .21053 Mtetra
.626 .612 .817 r
.25245 .21053 .25637 .21791 .26263 .21591 .25872 .20843 Mtetra
.626 .609 .814 r
.25872 .20843 .26263 .21591 .26891 .21391 .26501 .20633 Mtetra
.625 .606 .811 r
.26501 .20633 .26891 .21391 .27521 .2119 .27131 .20422 Mtetra
.624 .604 .809 r
.27131 .20422 .27521 .2119 .28152 .20988 .27764 .2021 Mtetra
.624 .601 .807 r
.27764 .2021 .28152 .20988 .28785 .20786 .28398 .19998 Mtetra
.623 .598 .804 r
.28398 .19998 .28785 .20786 .2942 .20584 .29033 .19785 Mtetra
.623 .595 .802 r
.29033 .19785 .2942 .20584 .30056 .20381 .2967 .19572 Mtetra
.622 .592 .799 r
.2967 .19572 .30056 .20381 .30694 .20177 .30309 .19358 Mtetra
.621 .59 .797 r
.30309 .19358 .30694 .20177 .31334 .19973 .3095 .19143 Mtetra
.621 .587 .795 r
.3095 .19143 .31334 .19973 .31976 .19768 .31592 .18928 Mtetra
.62 .585 .792 r
.31592 .18928 .31976 .19768 .32619 .19563 .32237 .18712 Mtetra
.619 .582 .79 r
.32237 .18712 .32619 .19563 .33264 .19357 .32882 .18496 Mtetra
.619 .579 .788 r
.32882 .18496 .33264 .19357 .33911 .19151 .3353 .18279 Mtetra
.618 .577 .785 r
.3353 .18279 .33911 .19151 .3456 .18943 .34179 .18061 Mtetra
.618 .575 .783 r
.34179 .18061 .3456 .18943 .3521 .18732 .3483 .17841 Mtetra
.619 .573 .781 r
.3483 .17841 .3521 .18732 .35863 .18517 .35483 .17617 Mtetra
.627 .576 .777 r
.35483 .17617 .35863 .18517 .36519 .18274 .36139 .17371 Mtetra
.639 .582 .774 r
.36139 .17371 .36519 .18274 .37178 .17989 .36798 .17092 Mtetra
.641 .584 .775 r
.36798 .17092 .37178 .17989 .37839 .177 .37459 .1681 Mtetra
.642 .587 .777 r
.37459 .1681 .37839 .177 .38502 .17408 .38121 .16525 Mtetra
.643 .589 .779 r
.38121 .16525 .38502 .17408 .39166 .17114 .38785 .1624 Mtetra
.644 .592 .781 r
.38785 .1624 .39166 .17114 .39832 .1682 .39451 .15953 Mtetra
.645 .594 .783 r
.39451 .15953 .39832 .1682 .40499 .16525 .40118 .15666 Mtetra
.646 .597 .785 r
.40118 .15666 .40499 .16525 .41168 .16229 .40786 .15378 Mtetra
.647 .6 .788 r
.40786 .15378 .41168 .16229 .41838 .15932 .41456 .15089 Mtetra
.647 .602 .79 r
.41456 .15089 .41838 .15932 .42509 .15635 .42128 .148 Mtetra
.648 .605 .792 r
.42128 .148 .42509 .15635 .43182 .15337 .42801 .1451 Mtetra
.649 .608 .794 r
.42801 .1451 .43182 .15337 .43857 .15038 .43476 .14219 Mtetra
.65 .611 .796 r
.43476 .14219 .43857 .15038 .44533 .14739 .44152 .13927 Mtetra
.651 .613 .799 r
.44152 .13927 .44533 .14739 .4521 .14439 .44829 .13635 Mtetra
.652 .616 .801 r
.44829 .13635 .4521 .14439 .4589 .14139 .45509 .13343 Mtetra
.653 .619 .803 r
.45509 .13343 .4589 .14139 .4657 .13838 .46189 .13049 Mtetra
.653 .622 .806 r
.46189 .13049 .4657 .13838 .47252 .13536 .46872 .12755 Mtetra
.654 .625 .808 r
.46872 .12755 .47252 .13536 .47936 .13233 .47556 .1246 Mtetra
.655 .628 .811 r
.47556 .1246 .47936 .13233 .48621 .1293 .48241 .12165 Mtetra
.656 .631 .813 r
.48241 .12165 .48621 .1293 .49307 .12626 .48928 .11869 Mtetra
.657 .634 .816 r
.48928 .11869 .49307 .12626 .49996 .12321 .49617 .11572 Mtetra
.658 .637 .818 r
.49617 .11572 .49996 .12321 .50685 .12016 .50307 .11274 Mtetra
.659 .64 .821 r
.50307 .11274 .50685 .12016 .51377 .1171 .50999 .10976 Mtetra
.66 .644 .823 r
.50999 .10976 .51377 .1171 .52069 .11403 .51692 .10677 Mtetra
.661 .647 .826 r
.51692 .10677 .52069 .11403 .52764 .11096 .52387 .10378 Mtetra
.661 .65 .828 r
.52387 .10378 .52764 .11096 .5346 .10788 .53084 .10077 Mtetra
.662 .654 .831 r
.53084 .10077 .5346 .10788 .54157 .10479 .53782 .09776 Mtetra
.663 .657 .834 r
.53782 .09776 .54157 .10479 .54856 .10169 .54482 .09475 Mtetra
.664 .661 .836 r
.54482 .09475 .54856 .10169 .55557 .09859 .55183 .09172 Mtetra
.665 .664 .839 r
.55183 .09172 .55557 .09859 .56259 .09548 .55886 .08869 Mtetra
.666 .668 .842 r
.55886 .08869 .56259 .09548 .56963 .09237 .56591 .08566 Mtetra
.667 .671 .845 r
.56591 .08566 .56963 .09237 .57668 .08925 .57297 .08261 Mtetra
.668 .675 .848 r
.57297 .08261 .57668 .08925 .58375 .08612 .58005 .07956 Mtetra
.669 .679 .85 r
.58005 .07956 .58375 .08612 .59084 .08298 .58715 .0765 Mtetra
.669 .682 .853 r
.58715 .0765 .59084 .08298 .59794 .07984 .59426 .07343 Mtetra
.67 .686 .856 r
.59426 .07343 .59794 .07984 .60506 .07668 .60139 .07036 Mtetra
.671 .69 .859 r
.60139 .07036 .60506 .07668 .61219 .07353 .60854 .06728 Mtetra
.672 .694 .862 r
.60854 .06728 .61219 .07353 .61934 .07036 .6157 .06419 Mtetra
.673 .698 .865 r
.6157 .06419 .61934 .07036 .62651 .06719 .62288 .0611 Mtetra
.674 .702 .868 r
.62288 .0611 .62651 .06719 .63369 .06401 .63008 .058 Mtetra
.674 .706 .871 r
.63008 .058 .63369 .06401 .64089 .06082 .63729 .05489 Mtetra
.675 .71 .874 r
.63729 .05489 .64089 .06082 .64811 .05763 .64452 .05177 Mtetra
.676 .714 .877 r
.64452 .05177 .64811 .05763 .65534 .05443 .65177 .04865 Mtetra
.677 .719 .881 r
.65177 .04865 .65534 .05443 .66259 .05122 .65904 .04552 Mtetra
.677 .723 .884 r
.65904 .04552 .66259 .05122 .66985 .04801 .66632 .04238 Mtetra
.678 .727 .887 r
.66632 .04238 .66985 .04801 .67714 .04479 .67362 .03924 Mtetra
.679 .732 .89 r
.67362 .03924 .67714 .04479 .68444 .04156 .68094 .03609 Mtetra
.679 .736 .894 r
.68094 .03609 .68444 .04156 .69175 .03835 .68827 .03295 Mtetra
.678 .74 .897 r
.68827 .03295 .69175 .03835 .69909 .03515 .69563 .02982 Mtetra
.677 .743 .9 r
.69563 .02982 .69909 .03515 .70644 .03198 .703 .02671 Mtetra
.653 .738 .912 r
.0498 .27288 .05425 .27703 .06003 .275 .0556 .27079 Mtetra
.65 .735 .911 r
.0556 .27079 .06003 .275 .06581 .27303 .0614 .26873 Mtetra
.649 .73 .909 r
.0614 .26873 .06581 .27303 .07161 .27107 .06721 .26668 Mtetra
.648 .726 .906 r
.06721 .26668 .07161 .27107 .07742 .26912 .07304 .26463 Mtetra
.648 .722 .902 r
.07304 .26463 .07742 .26912 .08324 .26717 .07888 .26258 Mtetra
.647 .717 .899 r
.07888 .26258 .08324 .26717 .08908 .26521 .08474 .26053 Mtetra
.647 .713 .896 r
.08474 .26053 .08908 .26521 .09493 .26325 .09061 .25848 Mtetra
.646 .709 .893 r
.09061 .25848 .09493 .26325 .1008 .26129 .09649 .25641 Mtetra
.646 .705 .889 r
.09649 .25641 .1008 .26129 .10668 .25932 .10239 .25435 Mtetra
.646 .7 .886 r
.10239 .25435 .10668 .25932 .11257 .25735 .1083 .25228 Mtetra
.645 .696 .883 r
.1083 .25228 .11257 .25735 .11848 .25537 .11423 .2502 Mtetra
.645 .692 .88 r
.11423 .2502 .11848 .25537 .12441 .25338 .12018 .24812 Mtetra
.644 .688 .877 r
.12018 .24812 .12441 .25338 .13035 .25139 .12614 .24603 Mtetra
.644 .684 .873 r
.12614 .24603 .13035 .25139 .13631 .2494 .13211 .24394 Mtetra
.643 .68 .87 r
.13211 .24394 .13631 .2494 .14228 .2474 .1381 .24184 Mtetra
.642 .677 .867 r
.1381 .24184 .14228 .2474 .14827 .2454 .1441 .23974 Mtetra
.642 .673 .864 r
.1441 .23974 .14827 .2454 .15427 .24339 .15012 .23763 Mtetra
.641 .669 .861 r
.15012 .23763 .15427 .24339 .16029 .24137 .15615 .23552 Mtetra
.641 .665 .858 r
.15615 .23552 .16029 .24137 .16632 .23935 .1622 .2334 Mtetra
.64 .662 .855 r
.1622 .2334 .16632 .23935 .17237 .23733 .16826 .23128 Mtetra
.639 .658 .852 r
.16826 .23128 .17237 .23733 .17843 .2353 .17434 .22915 Mtetra
.639 .655 .849 r
.17434 .22915 .17843 .2353 .18451 .23327 .18044 .22702 Mtetra
.638 .651 .847 r
.18044 .22702 .18451 .23327 .19061 .23123 .18655 .22488 Mtetra
.638 .648 .844 r
.18655 .22488 .19061 .23123 .19672 .22918 .19267 .22274 Mtetra
.637 .644 .841 r
.19267 .22274 .19672 .22918 .20285 .22713 .19881 .22059 Mtetra
.636 .641 .838 r
.19881 .22059 .20285 .22713 .20899 .22507 .20497 .21843 Mtetra
.636 .638 .835 r
.20497 .21843 .20899 .22507 .21515 .22301 .21114 .21627 Mtetra
.635 .635 .833 r
.21114 .21627 .21515 .22301 .22133 .22095 .21733 .21411 Mtetra
.634 .631 .83 r
.21733 .21411 .22133 .22095 .22752 .21887 .22353 .21193 Mtetra
.634 .628 .827 r
.22353 .21193 .22752 .21887 .23373 .2168 .22975 .20976 Mtetra
.633 .625 .825 r
.22975 .20976 .23373 .2168 .23995 .21471 .23599 .20757 Mtetra
.632 .622 .822 r
.23599 .20757 .23995 .21471 .24619 .21263 .24224 .20538 Mtetra
.632 .619 .819 r
.24224 .20538 .24619 .21263 .25245 .21053 .24851 .20319 Mtetra
.631 .616 .817 r
.24851 .20319 .25245 .21053 .25872 .20843 .25479 .20099 Mtetra
.63 .613 .814 r
.25479 .20099 .25872 .20843 .26501 .20633 .26109 .19878 Mtetra
.63 .61 .812 r
.26109 .19878 .26501 .20633 .27131 .20422 .26741 .19657 Mtetra
.629 .607 .81 r
.26741 .19657 .27131 .20422 .27764 .2021 .27374 .19436 Mtetra
.628 .605 .807 r
.27374 .19436 .27764 .2021 .28398 .19998 .28009 .19213 Mtetra
.628 .602 .805 r
.28009 .19213 .28398 .19998 .29033 .19785 .28645 .1899 Mtetra
.627 .599 .802 r
.28645 .1899 .29033 .19785 .2967 .19572 .29283 .18767 Mtetra
.626 .596 .8 r
.29283 .18767 .2967 .19572 .30309 .19358 .29923 .18543 Mtetra
.626 .594 .798 r
.29923 .18543 .30309 .19358 .3095 .19143 .30565 .18318 Mtetra
.625 .591 .795 r
.30565 .18318 .3095 .19143 .31592 .18928 .31208 .18093 Mtetra
.624 .588 .793 r
.31208 .18093 .31592 .18928 .32237 .18712 .31853 .17867 Mtetra
.624 .586 .791 r
.31853 .17867 .32237 .18712 .32882 .18496 .32499 .1764 Mtetra
.623 .583 .789 r
.32499 .1764 .32882 .18496 .3353 .18279 .33147 .17413 Mtetra
.623 .581 .786 r
.33147 .17413 .3353 .18279 .34179 .18061 .33797 .17185 Mtetra
.622 .579 .784 r
.33797 .17185 .34179 .18061 .3483 .17841 .34449 .16955 Mtetra
.623 .577 .782 r
.34449 .16955 .3483 .17841 .35483 .17617 .35102 .16722 Mtetra
.628 .578 .779 r
.35102 .16722 .35483 .17617 .36139 .17371 .35758 .16473 Mtetra
.637 .582 .776 r
.35758 .16473 .36139 .17371 .36798 .17092 .36417 .16201 Mtetra
.638 .585 .778 r
.36417 .16201 .36798 .17092 .37459 .1681 .37078 .15926 Mtetra
.639 .587 .78 r
.37078 .15926 .37459 .1681 .38121 .16525 .3774 .15649 Mtetra
.64 .59 .782 r
.3774 .15649 .38121 .16525 .38785 .1624 .38404 .15371 Mtetra
.641 .592 .784 r
.38404 .15371 .38785 .1624 .39451 .15953 .39069 .15092 Mtetra
.642 .595 .786 r
.39069 .15092 .39451 .15953 .40118 .15666 .39736 .14812 Mtetra
.643 .597 .788 r
.39736 .14812 .40118 .15666 .40786 .15378 .40404 .14532 Mtetra
.644 .6 .79 r
.40404 .14532 .40786 .15378 .41456 .15089 .41074 .1425 Mtetra
.645 .603 .792 r
.41074 .1425 .41456 .15089 .42128 .148 .41746 .13969 Mtetra
.645 .605 .795 r
.41746 .13969 .42128 .148 .42801 .1451 .42419 .13686 Mtetra
.646 .608 .797 r
.42419 .13686 .42801 .1451 .43476 .14219 .43093 .13403 Mtetra
.647 .611 .799 r
.43093 .13403 .43476 .14219 .44152 .13927 .4377 .1312 Mtetra
.648 .614 .801 r
.4377 .1312 .44152 .13927 .44829 .13635 .44447 .12835 Mtetra
.649 .616 .804 r
.44447 .12835 .44829 .13635 .45509 .13343 .45127 .1255 Mtetra
.65 .619 .806 r
.45127 .1255 .45509 .13343 .46189 .13049 .45808 .12264 Mtetra
.65 .622 .808 r
.45808 .12264 .46189 .13049 .46872 .12755 .4649 .11978 Mtetra
.651 .625 .811 r
.4649 .11978 .46872 .12755 .47556 .1246 .47175 .11691 Mtetra
.652 .628 .813 r
.47175 .11691 .47556 .1246 .48241 .12165 .4786 .11403 Mtetra
.653 .631 .816 r
.4786 .11403 .48241 .12165 .48928 .11869 .48548 .11114 Mtetra
.654 .634 .818 r
.48548 .11114 .48928 .11869 .49617 .11572 .49237 .10825 Mtetra
.655 .637 .82 r
.49237 .10825 .49617 .11572 .50307 .11274 .49928 .10535 Mtetra
.655 .64 .823 r
.49928 .10535 .50307 .11274 .50999 .10976 .5062 .10245 Mtetra
.656 .644 .826 r
.5062 .10245 .50999 .10976 .51692 .10677 .51314 .09953 Mtetra
.657 .647 .828 r
.51314 .09953 .51692 .10677 .52387 .10378 .52009 .09661 Mtetra
.658 .65 .831 r
.52009 .09661 .52387 .10378 .53084 .10077 .52707 .09369 Mtetra
.659 .653 .833 r
.52707 .09369 .53084 .10077 .53782 .09776 .53406 .09075 Mtetra
.66 .657 .836 r
.53406 .09075 .53782 .09776 .54482 .09475 .54106 .08781 Mtetra
.661 .66 .839 r
.54106 .08781 .54482 .09475 .55183 .09172 .54809 .08487 Mtetra
.661 .664 .841 r
.54809 .08487 .55183 .09172 .55886 .08869 .55512 .08191 Mtetra
.662 .667 .844 r
.55512 .08191 .55886 .08869 .56591 .08566 .56218 .07895 Mtetra
.663 .671 .847 r
.56218 .07895 .56591 .08566 .57297 .08261 .56925 .07598 Mtetra
.664 .674 .85 r
.56925 .07598 .57297 .08261 .58005 .07956 .57634 .07301 Mtetra
.665 .678 .853 r
.57634 .07301 .58005 .07956 .58715 .0765 .58345 .07002 Mtetra
.665 .682 .856 r
.58345 .07002 .58715 .0765 .59426 .07343 .59058 .06703 Mtetra
.666 .685 .858 r
.59058 .06703 .59426 .07343 .60139 .07036 .59772 .06404 Mtetra
.667 .689 .861 r
.59772 .06404 .60139 .07036 .60854 .06728 .60488 .06103 Mtetra
.668 .693 .864 r
.60488 .06103 .60854 .06728 .6157 .06419 .61205 .05802 Mtetra
.669 .697 .867 r
.61205 .05802 .6157 .06419 .62288 .0611 .61924 .055 Mtetra
.669 .701 .87 r
.61924 .055 .62288 .0611 .63008 .058 .62645 .05198 Mtetra
.67 .705 .873 r
.62645 .05198 .63008 .058 .63729 .05489 .63368 .04895 Mtetra
.671 .709 .876 r
.63368 .04895 .63729 .05489 .64452 .05177 .64093 .04591 Mtetra
.672 .713 .879 r
.64093 .04591 .64452 .05177 .65177 .04865 .64819 .04286 Mtetra
.672 .717 .883 r
.64819 .04286 .65177 .04865 .65904 .04552 .65547 .03981 Mtetra
.673 .722 .886 r
.65547 .03981 .65904 .04552 .66632 .04238 .66277 .03674 Mtetra
.674 .726 .889 r
.66277 .03674 .66632 .04238 .67362 .03924 .67009 .03368 Mtetra
.674 .73 .892 r
.67009 .03368 .67362 .03924 .68094 .03609 .67742 .03061 Mtetra
.674 .734 .895 r
.67742 .03061 .68094 .03609 .68827 .03295 .68477 .02753 Mtetra
.674 .738 .898 r
.68477 .02753 .68827 .03295 .69563 .02982 .69215 .02447 Mtetra
.673 .742 .902 r
.69215 .02447 .69563 .02982 .703 .02671 .69954 .02142 Mtetra
.657 .739 .911 r
.04533 .26872 .0498 .27288 .0556 .27079 .05114 .26655 Mtetra
.655 .736 .909 r
.05114 .26655 .0556 .27079 .0614 .26873 .05696 .26441 Mtetra
.654 .732 .907 r
.05696 .26441 .0614 .26873 .06721 .26668 .0628 .26227 Mtetra
.654 .728 .904 r
.0628 .26227 .06721 .26668 .07304 .26463 .06864 .26013 Mtetra
.653 .724 .901 r
.06864 .26013 .07304 .26463 .07888 .26258 .0745 .25799 Mtetra
.653 .72 .898 r
.0745 .25799 .07888 .26258 .08474 .26053 .08038 .25585 Mtetra
.652 .715 .894 r
.08038 .25585 .08474 .26053 .09061 .25848 .08627 .2537 Mtetra
.652 .711 .891 r
.08627 .2537 .09061 .25848 .09649 .25641 .09217 .25154 Mtetra
.651 .707 .888 r
.09217 .25154 .09649 .25641 .10239 .25435 .09808 .24938 Mtetra
.651 .703 .885 r
.09808 .24938 .10239 .25435 .1083 .25228 .10402 .24722 Mtetra
.65 .699 .882 r
.10402 .24722 .1083 .25228 .11423 .2502 .10996 .24504 Mtetra
.65 .695 .879 r
.10996 .24504 .11423 .2502 .12018 .24812 .11592 .24287 Mtetra
.649 .692 .876 r
.11592 .24287 .12018 .24812 .12614 .24603 .1219 .24069 Mtetra
.649 .688 .873 r
.1219 .24069 .12614 .24603 .13211 .24394 .12789 .2385 Mtetra
.648 .684 .87 r
.12789 .2385 .13211 .24394 .1381 .24184 .13389 .23631 Mtetra
.647 .68 .867 r
.13389 .23631 .1381 .24184 .1441 .23974 .13991 .23411 Mtetra
.647 .677 .864 r
.13991 .23411 .1441 .23974 .15012 .23763 .14595 .23191 Mtetra
.646 .673 .861 r
.14595 .23191 .15012 .23763 .15615 .23552 .15199 .2297 Mtetra
.646 .669 .858 r
.15199 .2297 .15615 .23552 .1622 .2334 .15806 .22749 Mtetra
.645 .666 .856 r
.15806 .22749 .1622 .2334 .16826 .23128 .16414 .22527 Mtetra
.644 .662 .853 r
.16414 .22527 .16826 .23128 .17434 .22915 .17023 .22305 Mtetra
.644 .659 .85 r
.17023 .22305 .17434 .22915 .18044 .22702 .17634 .22082 Mtetra
.643 .655 .847 r
.17634 .22082 .18044 .22702 .18655 .22488 .18246 .21858 Mtetra
.642 .652 .844 r
.18246 .21858 .18655 .22488 .19267 .22274 .1886 .21634 Mtetra
.642 .649 .842 r
.1886 .21634 .19267 .22274 .19881 .22059 .19476 .2141 Mtetra
.641 .646 .839 r
.19476 .2141 .19881 .22059 .20497 .21843 .20093 .21184 Mtetra
.64 .642 .836 r
.20093 .21184 .20497 .21843 .21114 .21627 .20711 .20959 Mtetra
.64 .639 .834 r
.20711 .20959 .21114 .21627 .21733 .21411 .21331 .20732 Mtetra
.639 .636 .831 r
.21331 .20732 .21733 .21411 .22353 .21193 .21953 .20506 Mtetra
.638 .633 .829 r
.21953 .20506 .22353 .21193 .22975 .20976 .22576 .20278 Mtetra
.638 .63 .826 r
.22576 .20278 .22975 .20976 .23599 .20757 .23201 .2005 Mtetra
.637 .627 .823 r
.23201 .2005 .23599 .20757 .24224 .20538 .23827 .19822 Mtetra
.636 .624 .821 r
.23827 .19822 .24224 .20538 .24851 .20319 .24455 .19592 Mtetra
.636 .621 .819 r
.24455 .19592 .24851 .20319 .25479 .20099 .25084 .19363 Mtetra
.635 .618 .816 r
.25084 .19363 .25479 .20099 .26109 .19878 .25715 .19132 Mtetra
.634 .615 .814 r
.25715 .19132 .26109 .19878 .26741 .19657 .26348 .18901 Mtetra
.634 .612 .811 r
.26348 .18901 .26741 .19657 .27374 .19436 .26982 .1867 Mtetra
.633 .61 .809 r
.26982 .1867 .27374 .19436 .28009 .19213 .27618 .18438 Mtetra
.632 .607 .807 r
.27618 .18438 .28009 .19213 .28645 .1899 .28256 .18205 Mtetra
.632 .604 .804 r
.28256 .18205 .28645 .1899 .29283 .18767 .28895 .17972 Mtetra
.631 .602 .802 r
.28895 .17972 .29283 .18767 .29923 .18543 .29535 .17738 Mtetra
.63 .599 .8 r
.29535 .17738 .29923 .18543 .30565 .18318 .30178 .17503 Mtetra
.63 .596 .798 r
.30178 .17503 .30565 .18318 .31208 .18093 .30821 .17268 Mtetra
.629 .594 .795 r
.30821 .17268 .31208 .18093 .31853 .17867 .31467 .17033 Mtetra
.628 .591 .793 r
.31467 .17033 .31853 .17867 .32499 .1764 .32114 .16796 Mtetra
.628 .589 .791 r
.32114 .16796 .32499 .1764 .33147 .17413 .32763 .16559 Mtetra
.627 .586 .789 r
.32763 .16559 .33147 .17413 .33797 .17185 .33414 .16321 Mtetra
.627 .584 .787 r
.33414 .16321 .33797 .17185 .34449 .16955 .34066 .16082 Mtetra
.627 .582 .785 r
.34066 .16082 .34449 .16955 .35102 .16722 .3472 .15841 Mtetra
.63 .582 .782 r
.3472 .15841 .35102 .16722 .35758 .16473 .35376 .15589 Mtetra
.635 .585 .78 r
.35376 .15589 .35758 .16473 .36417 .16201 .36035 .15322 Mtetra
.637 .587 .782 r
.36035 .15322 .36417 .16201 .37078 .15926 .36695 .15054 Mtetra
.637 .589 .784 r
.36695 .15054 .37078 .15926 .3774 .15649 .37357 .14784 Mtetra
.638 .592 .786 r
.37357 .14784 .3774 .15649 .38404 .15371 .38021 .14513 Mtetra
.639 .594 .788 r
.38021 .14513 .38404 .15371 .39069 .15092 .38686 .14241 Mtetra
.64 .597 .79 r
.38686 .14241 .39069 .15092 .39736 .14812 .39352 .13969 Mtetra
.641 .599 .792 r
.39352 .13969 .39736 .14812 .40404 .14532 .40021 .13696 Mtetra
.641 .602 .794 r
.40021 .13696 .40404 .14532 .41074 .1425 .4069 .13422 Mtetra
.642 .604 .796 r
.4069 .13422 .41074 .1425 .41746 .13969 .41362 .13148 Mtetra
.643 .607 .798 r
.41362 .13148 .41746 .13969 .42419 .13686 .42035 .12873 Mtetra
.644 .61 .801 r
.42035 .12873 .42419 .13686 .43093 .13403 .4271 .12597 Mtetra
.645 .612 .803 r
.4271 .12597 .43093 .13403 .4377 .1312 .43386 .1232 Mtetra
.645 .615 .805 r
.43386 .1232 .4377 .1312 .44447 .12835 .44064 .12043 Mtetra
.646 .618 .807 r
.44064 .12043 .44447 .12835 .45127 .1255 .44744 .11766 Mtetra
.647 .621 .81 r
.44744 .11766 .45127 .1255 .45808 .12264 .45425 .11487 Mtetra
.648 .624 .812 r
.45425 .11487 .45808 .12264 .4649 .11978 .46108 .11208 Mtetra
.648 .627 .814 r
.46108 .11208 .4649 .11978 .47175 .11691 .46792 .10928 Mtetra
.649 .629 .817 r
.46792 .10928 .47175 .11691 .4786 .11403 .47478 .10648 Mtetra
.65 .632 .819 r
.47478 .10648 .4786 .11403 .48548 .11114 .48166 .10367 Mtetra
.651 .635 .822 r
.48166 .10367 .48548 .11114 .49237 .10825 .48856 .10085 Mtetra
.652 .638 .824 r
.48856 .10085 .49237 .10825 .49928 .10535 .49547 .09802 Mtetra
.652 .642 .826 r
.49547 .09802 .49928 .10535 .5062 .10245 .5024 .09519 Mtetra
.653 .645 .829 r
.5024 .09519 .5062 .10245 .51314 .09953 .50934 .09235 Mtetra
.654 .648 .832 r
.50934 .09235 .51314 .09953 .52009 .09661 .51631 .0895 Mtetra
.655 .651 .834 r
.51631 .0895 .52009 .09661 .52707 .09369 .52329 .08665 Mtetra
.656 .654 .837 r
.52329 .08665 .52707 .09369 .53406 .09075 .53028 .08379 Mtetra
.656 .658 .839 r
.53028 .08379 .53406 .09075 .54106 .08781 .5373 .08092 Mtetra
.657 .661 .842 r
.5373 .08092 .54106 .08781 .54809 .08487 .54433 .07805 Mtetra
.658 .664 .845 r
.54433 .07805 .54809 .08487 .55512 .08191 .55137 .07517 Mtetra
.659 .668 .847 r
.55137 .07517 .55512 .08191 .56218 .07895 .55844 .07228 Mtetra
.66 .671 .85 r
.55844 .07228 .56218 .07895 .56925 .07598 .56552 .06938 Mtetra
.66 .675 .853 r
.56552 .06938 .56925 .07598 .57634 .07301 .57262 .06648 Mtetra
.661 .678 .856 r
.57262 .06648 .57634 .07301 .58345 .07002 .57974 .06357 Mtetra
.662 .682 .858 r
.57974 .06357 .58345 .07002 .59058 .06703 .58687 .06065 Mtetra
.663 .686 .861 r
.58687 .06065 .59058 .06703 .59772 .06404 .59403 .05773 Mtetra
.663 .689 .864 r
.59403 .05773 .59772 .06404 .60488 .06103 .6012 .0548 Mtetra
.664 .693 .867 r
.6012 .0548 .60488 .06103 .61205 .05802 .60839 .05186 Mtetra
.665 .697 .87 r
.60839 .05186 .61205 .05802 .61924 .055 .61559 .04892 Mtetra
.665 .701 .873 r
.61559 .04892 .61924 .055 .62645 .05198 .62282 .04596 Mtetra
.666 .704 .876 r
.62282 .04596 .62645 .05198 .63368 .04895 .63006 .043 Mtetra
.667 .708 .879 r
.63006 .043 .63368 .04895 .64093 .04591 .63732 .04004 Mtetra
.667 .712 .882 r
.63732 .04004 .64093 .04591 .64819 .04286 .6446 .03706 Mtetra
.668 .716 .885 r
.6446 .03706 .64819 .04286 .65547 .03981 .65189 .03408 Mtetra
.669 .72 .888 r
.65189 .03408 .65547 .03981 .66277 .03674 .65921 .03109 Mtetra
.669 .725 .891 r
.65921 .03109 .66277 .03674 .67009 .03368 .66654 .0281 Mtetra
.67 .729 .894 r
.66654 .0281 .67009 .03368 .67742 .03061 .67389 .0251 Mtetra
.67 .733 .897 r
.67389 .0251 .67742 .03061 .68477 .02753 .68126 .0221 Mtetra
.67 .737 .9 r
.68126 .0221 .68477 .02753 .69215 .02447 .68865 .01909 Mtetra
.67 .74 .903 r
.68865 .01909 .69215 .02447 .69954 .02142 .69606 .0161 Mtetra
.661 .74 .909 r
.04084 .26453 .04533 .26872 .05114 .26655 .04667 .26231 Mtetra
.66 .737 .907 r
.04667 .26231 .05114 .26655 .05696 .26441 .05251 .26009 Mtetra
.659 .734 .905 r
.05251 .26009 .05696 .26441 .0628 .26227 .05836 .25787 Mtetra
.659 .73 .902 r
.05836 .25787 .0628 .26227 .06864 .26013 .06422 .25564 Mtetra
.658 .726 .899 r
.06422 .25564 .06864 .26013 .0745 .25799 .0701 .25341 Mtetra
.658 .722 .897 r
.0701 .25341 .0745 .25799 .08038 .25585 .07599 .25118 Mtetra
.657 .719 .894 r
.07599 .25118 .08038 .25585 .08627 .2537 .0819 .24894 Mtetra
.657 .715 .891 r
.0819 .24894 .08627 .2537 .09217 .25154 .08782 .2467 Mtetra
.656 .711 .888 r
.08782 .2467 .09217 .25154 .09808 .24938 .09375 .24445 Mtetra
.656 .707 .885 r
.09375 .24445 .09808 .24938 .10402 .24722 .0997 .2422 Mtetra
.655 .704 .882 r
.0997 .2422 .10402 .24722 .10996 .24504 .10567 .23994 Mtetra
.655 .7 .88 r
.10567 .23994 .10996 .24504 .11592 .24287 .11164 .23767 Mtetra
.654 .696 .877 r
.11164 .23767 .11592 .24287 .1219 .24069 .11764 .2354 Mtetra
.654 .693 .874 r
.11764 .2354 .1219 .24069 .12789 .2385 .12364 .23313 Mtetra
.653 .689 .871 r
.12364 .23313 .12789 .2385 .13389 .23631 .12966 .23085 Mtetra
.653 .686 .869 r
.12966 .23085 .13389 .23631 .13991 .23411 .1357 .22856 Mtetra
.652 .682 .866 r
.1357 .22856 .13991 .23411 .14595 .23191 .14175 .22627 Mtetra
.651 .679 .863 r
.14175 .22627 .14595 .23191 .15199 .2297 .14781 .22397 Mtetra
.651 .675 .86 r
.14781 .22397 .15199 .2297 .15806 .22749 .15389 .22167 Mtetra
.65 .672 .858 r
.15389 .22167 .15806 .22749 .16414 .22527 .15998 .21936 Mtetra
.649 .669 .855 r
.15998 .21936 .16414 .22527 .17023 .22305 .16609 .21705 Mtetra
.649 .666 .853 r
.16609 .21705 .17023 .22305 .17634 .22082 .17221 .21473 Mtetra
.648 .662 .85 r
.17221 .21473 .17634 .22082 .18246 .21858 .17835 .2124 Mtetra
.648 .659 .847 r
.17835 .2124 .18246 .21858 .1886 .21634 .1845 .21007 Mtetra
.647 .656 .845 r
.1845 .21007 .1886 .21634 .19476 .2141 .19067 .20773 Mtetra
.646 .653 .842 r
.19067 .20773 .19476 .2141 .20093 .21184 .19686 .20539 Mtetra
.646 .65 .84 r
.19686 .20539 .20093 .21184 .20711 .20959 .20305 .20304 Mtetra
.645 .647 .837 r
.20305 .20304 .20711 .20959 .21331 .20732 .20927 .20069 Mtetra
.644 .644 .835 r
.20927 .20069 .21331 .20732 .21953 .20506 .2155 .19833 Mtetra
.644 .641 .833 r
.2155 .19833 .21953 .20506 .22576 .20278 .22174 .19597 Mtetra
.643 .638 .83 r
.22174 .19597 .22576 .20278 .23201 .2005 .228 .19359 Mtetra
.642 .635 .828 r
.228 .19359 .23201 .2005 .23827 .19822 .23427 .19122 Mtetra
.642 .632 .825 r
.23427 .19122 .23827 .19822 .24455 .19592 .24056 .18884 Mtetra
.641 .629 .823 r
.24056 .18884 .24455 .19592 .25084 .19363 .24687 .18645 Mtetra
.64 .627 .821 r
.24687 .18645 .25084 .19363 .25715 .19132 .25319 .18405 Mtetra
.64 .624 .818 r
.25319 .18405 .25715 .19132 .26348 .18901 .25953 .18165 Mtetra
.639 .621 .816 r
.25953 .18165 .26348 .18901 .26982 .1867 .26588 .17924 Mtetra
.638 .619 .814 r
.26588 .17924 .26982 .1867 .27618 .18438 .27225 .17683 Mtetra
.638 .616 .812 r
.27225 .17683 .27618 .18438 .28256 .18205 .27863 .17441 Mtetra
.637 .613 .81 r
.27863 .17441 .28256 .18205 .28895 .17972 .28503 .17199 Mtetra
.636 .611 .807 r
.28503 .17199 .28895 .17972 .29535 .17738 .29145 .16956 Mtetra
.636 .608 .805 r
.29145 .16956 .29535 .17738 .30178 .17503 .29788 .16712 Mtetra
.635 .606 .803 r
.29788 .16712 .30178 .17503 .30821 .17268 .30432 .16468 Mtetra
.634 .603 .801 r
.30432 .16468 .30821 .17268 .31467 .17033 .31079 .16223 Mtetra
.634 .601 .799 r
.31079 .16223 .31467 .17033 .32114 .16796 .31727 .15977 Mtetra
.633 .598 .797 r
.31727 .15977 .32114 .16796 .32763 .16559 .32376 .15731 Mtetra
.632 .596 .795 r
.32376 .15731 .32763 .16559 .33414 .16321 .33028 .15484 Mtetra
.632 .594 .793 r
.33028 .15484 .33414 .16321 .34066 .16082 .33681 .15236 Mtetra
.632 .592 .791 r
.33681 .15236 .34066 .16082 .3472 .15841 .34335 .14987 Mtetra
.633 .591 .789 r
.34335 .14987 .3472 .15841 .35376 .15589 .34992 .14733 Mtetra
.635 .592 .788 r
.34992 .14733 .35376 .15589 .36035 .15322 .3565 .14471 Mtetra
.636 .594 .79 r
.3565 .14471 .36035 .15322 .36695 .15054 .3631 .14209 Mtetra
.637 .596 .791 r
.3631 .14209 .36695 .15054 .37357 .14784 .36972 .13945 Mtetra
.638 .598 .793 r
.36972 .13945 .37357 .14784 .38021 .14513 .37635 .13681 Mtetra
.638 .601 .795 r
.37635 .13681 .38021 .14513 .38686 .14241 .383 .13416 Mtetra
.639 .603 .797 r
.383 .13416 .38686 .14241 .39352 .13969 .38967 .1315 Mtetra
.64 .606 .799 r
.38967 .1315 .39352 .13969 .40021 .13696 .39635 .12884 Mtetra
.64 .608 .801 r
.39635 .12884 .40021 .13696 .4069 .13422 .40305 .12617 Mtetra
.641 .611 .803 r
.40305 .12617 .4069 .13422 .41362 .13148 .40976 .12349 Mtetra
.642 .613 .805 r
.40976 .12349 .41362 .13148 .42035 .12873 .4165 .1208 Mtetra
.643 .616 .808 r
.4165 .1208 .42035 .12873 .4271 .12597 .42324 .11811 Mtetra
.643 .618 .81 r
.42324 .11811 .4271 .12597 .43386 .1232 .43001 .11542 Mtetra
.644 .621 .812 r
.43001 .11542 .43386 .1232 .44064 .12043 .43679 .11271 Mtetra
.645 .623 .814 r
.43679 .11271 .44064 .12043 .44744 .11766 .44359 .11 Mtetra
.645 .626 .816 r
.44359 .11 .44744 .11766 .45425 .11487 .4504 .10728 Mtetra
.646 .629 .819 r
.4504 .10728 .45425 .11487 .46108 .11208 .45724 .10456 Mtetra
.647 .632 .821 r
.45724 .10456 .46108 .11208 .46792 .10928 .46408 .10183 Mtetra
.648 .634 .823 r
.46408 .10183 .46792 .10928 .47478 .10648 .47095 .09909 Mtetra
.648 .637 .825 r
.47095 .09909 .47478 .10648 .48166 .10367 .47783 .09635 Mtetra
.649 .64 .828 r
.47783 .09635 .48166 .10367 .48856 .10085 .48473 .09359 Mtetra
.65 .643 .83 r
.48473 .09359 .48856 .10085 .49547 .09802 .49165 .09084 Mtetra
.65 .646 .833 r
.49165 .09084 .49547 .09802 .5024 .09519 .49858 .08807 Mtetra
.651 .649 .835 r
.49858 .08807 .5024 .09519 .50934 .09235 .50553 .0853 Mtetra
.652 .652 .837 r
.50553 .0853 .50934 .09235 .51631 .0895 .5125 .08252 Mtetra
.653 .655 .84 r
.5125 .08252 .51631 .0895 .52329 .08665 .51949 .07973 Mtetra
.653 .658 .842 r
.51949 .07973 .52329 .08665 .53028 .08379 .52649 .07694 Mtetra
.654 .661 .845 r
.52649 .07694 .53028 .08379 .5373 .08092 .53351 .07414 Mtetra
.655 .664 .847 r
.53351 .07414 .5373 .08092 .54433 .07805 .54055 .07133 Mtetra
.655 .668 .85 r
.54055 .07133 .54433 .07805 .55137 .07517 .54761 .06852 Mtetra
.656 .671 .852 r
.54761 .06852 .55137 .07517 .55844 .07228 .55468 .0657 Mtetra
.657 .674 .855 r
.55468 .0657 .55844 .07228 .56552 .06938 .56178 .06287 Mtetra
.657 .678 .858 r
.56178 .06287 .56552 .06938 .57262 .06648 .56889 .06003 Mtetra
.658 .681 .86 r
.56889 .06003 .57262 .06648 .57974 .06357 .57601 .05719 Mtetra
.659 .684 .863 r
.57601 .05719 .57974 .06357 .58687 .06065 .58316 .05434 Mtetra
.659 .688 .866 r
.58316 .05434 .58687 .06065 .59403 .05773 .59032 .05149 Mtetra
.66 .691 .868 r
.59032 .05149 .59403 .05773 .6012 .0548 .59751 .04862 Mtetra
.661 .695 .871 r
.59751 .04862 .6012 .0548 .60839 .05186 .60471 .04575 Mtetra
.661 .698 .874 r
.60471 .04575 .60839 .05186 .61559 .04892 .61193 .04287 Mtetra
.662 .702 .876 r
.61193 .04287 .61559 .04892 .62282 .04596 .61916 .03999 Mtetra
.663 .706 .879 r
.61916 .03999 .62282 .04596 .63006 .043 .62642 .03709 Mtetra
.663 .709 .882 r
.62642 .03709 .63006 .043 .63732 .04004 .63369 .03419 Mtetra
.664 .713 .885 r
.63369 .03419 .63732 .04004 .6446 .03706 .64099 .03129 Mtetra
.664 .717 .888 r
.64099 .03129 .6446 .03706 .65189 .03408 .6483 .02837 Mtetra
.665 .72 .89 r
.6483 .02837 .65189 .03408 .65921 .03109 .65563 .02545 Mtetra
.665 .724 .893 r
.65563 .02545 .65921 .03109 .66654 .0281 .66298 .02252 Mtetra
.666 .728 .896 r
.66298 .02252 .66654 .0281 .67389 .0251 .67034 .01959 Mtetra
.666 .732 .899 r
.67034 .01959 .67389 .0251 .68126 .0221 .67773 .01664 Mtetra
.666 .736 .902 r
.67773 .01664 .68126 .0221 .68865 .01909 .68514 .0137 Mtetra
.666 .739 .904 r
.68514 .0137 .68865 .01909 .69606 .0161 .69256 .01075 Mtetra
.663 .741 .908 r
.03634 .26033 .04084 .26453 .04667 .26231 .04218 .25806 Mtetra
.663 .739 .906 r
.04218 .25806 .04667 .26231 .05251 .26009 .04803 .25577 Mtetra
.663 .736 .904 r
.04803 .25577 .05251 .26009 .05836 .25787 .0539 .25348 Mtetra
.663 .733 .902 r
.0539 .25348 .05836 .25787 .06422 .25564 .05978 .25119 Mtetra
.662 .73 .9 r
.05978 .25119 .06422 .25564 .0701 .25341 .06567 .24889 Mtetra
.662 .727 .898 r
.06567 .24889 .0701 .25341 .07599 .25118 .07158 .24659 Mtetra
.662 .724 .896 r
.07158 .24659 .07599 .25118 .0819 .24894 .0775 .24428 Mtetra
.661 .721 .893 r
.0775 .24428 .0819 .24894 .08782 .2467 .08344 .24196 Mtetra
.661 .718 .891 r
.08344 .24196 .08782 .2467 .09375 .24445 .08939 .23964 Mtetra
.66 .715 .889 r
.08939 .23964 .09375 .24445 .0997 .2422 .09535 .23731 Mtetra
.66 .712 .887 r
.09535 .23731 .0997 .2422 .10567 .23994 .10133 .23498 Mtetra
.66 .709 .884 r
.10133 .23498 .10567 .23994 .11164 .23767 .10732 .23265 Mtetra
.659 .706 .882 r
.10732 .23265 .11164 .23767 .11764 .2354 .11333 .2303 Mtetra
.659 .703 .88 r
.11333 .2303 .11764 .2354 .12364 .23313 .11935 .22796 Mtetra
.658 .701 .878 r
.11935 .22796 .12364 .23313 .12966 .23085 .12538 .2256 Mtetra
.658 .698 .876 r
.12538 .2256 .12966 .23085 .1357 .22856 .13143 .22324 Mtetra
.657 .695 .873 r
.13143 .22324 .1357 .22856 .14175 .22627 .1375 .22088 Mtetra
.657 .692 .871 r
.1375 .22088 .14175 .22627 .14781 .22397 .14357 .21851 Mtetra
.656 .689 .869 r
.14357 .21851 .14781 .22397 .15389 .22167 .14967 .21613 Mtetra
.656 .686 .867 r
.14967 .21613 .15389 .22167 .15998 .21936 .15577 .21375 Mtetra
.655 .684 .865 r
.15577 .21375 .15998 .21936 .16609 .21705 .1619 .21136 Mtetra
.655 .681 .863 r
.1619 .21136 .16609 .21705 .17221 .21473 .16803 .20897 Mtetra
.654 .678 .86 r
.16803 .20897 .17221 .21473 .17835 .2124 .17418 .20657 Mtetra
.654 .676 .858 r
.17418 .20657 .17835 .2124 .1845 .21007 .18035 .20416 Mtetra
.653 .673 .856 r
.18035 .20416 .1845 .21007 .19067 .20773 .18653 .20175 Mtetra
.653 .67 .854 r
.18653 .20175 .19067 .20773 .19686 .20539 .19273 .19934 Mtetra
.652 .668 .852 r
.19273 .19934 .19686 .20539 .20305 .20304 .19894 .19692 Mtetra
.652 .665 .85 r
.19894 .19692 .20305 .20304 .20927 .20069 .20516 .19449 Mtetra
.651 .663 .848 r
.20516 .19449 .20927 .20069 .2155 .19833 .2114 .19205 Mtetra
.651 .66 .846 r
.2114 .19205 .2155 .19833 .22174 .19597 .21766 .18961 Mtetra
.65 .658 .844 r
.21766 .18961 .22174 .19597 .228 .19359 .22393 .18717 Mtetra
.65 .655 .842 r
.22393 .18717 .228 .19359 .23427 .19122 .23021 .18472 Mtetra
.649 .653 .84 r
.23021 .18472 .23427 .19122 .24056 .18884 .23651 .18226 Mtetra
.649 .65 .838 r
.23651 .18226 .24056 .18884 .24687 .18645 .24283 .1798 Mtetra
.648 .648 .836 r
.24283 .1798 .24687 .18645 .25319 .18405 .24916 .17733 Mtetra
.647 .646 .834 r
.24916 .17733 .25319 .18405 .25953 .18165 .25551 .17485 Mtetra
.647 .643 .832 r
.25551 .17485 .25953 .18165 .26588 .17924 .26187 .17237 Mtetra
.646 .641 .831 r
.26187 .17237 .26588 .17924 .27225 .17683 .26825 .16988 Mtetra
.646 .639 .829 r
.26825 .16988 .27225 .17683 .27863 .17441 .27464 .16739 Mtetra
.645 .636 .827 r
.27464 .16739 .27863 .17441 .28503 .17199 .28105 .16489 Mtetra
.645 .634 .825 r
.28105 .16489 .28503 .17199 .29145 .16956 .28748 .16238 Mtetra
.644 .632 .823 r
.28748 .16238 .29145 .16956 .29788 .16712 .29392 .15987 Mtetra
.644 .63 .821 r
.29392 .15987 .29788 .16712 .30432 .16468 .30037 .15735 Mtetra
.643 .628 .82 r
.30037 .15735 .30432 .16468 .31079 .16223 .30684 .15483 Mtetra
.642 .625 .818 r
.30684 .15483 .31079 .16223 .31727 .15977 .31333 .1523 Mtetra
.642 .623 .816 r
.31333 .1523 .31727 .15977 .32376 .15731 .31984 .14976 Mtetra
.641 .621 .814 r
.31984 .14976 .32376 .15731 .33028 .15484 .32636 .14722 Mtetra
.641 .619 .813 r
.32636 .14722 .33028 .15484 .33681 .15236 .33289 .14467 Mtetra
.64 .617 .811 r
.33289 .14467 .33681 .15236 .34335 .14987 .33945 .14211 Mtetra
.64 .616 .81 r
.33945 .14211 .34335 .14987 .34992 .14733 .34601 .13955 Mtetra
.64 .615 .809 r
.34601 .13955 .34992 .14733 .3565 .14471 .3526 .13697 Mtetra
.641 .617 .811 r
.3526 .13697 .3565 .14471 .3631 .14209 .3592 .13439 Mtetra
.641 .619 .812 r
.3592 .13439 .3631 .14209 .36972 .13945 .36582 .1318 Mtetra
.642 .621 .814 r
.36582 .1318 .36972 .13945 .37635 .13681 .37245 .12921 Mtetra
.642 .623 .816 r
.37245 .12921 .37635 .13681 .383 .13416 .3791 .12661 Mtetra
.643 .625 .817 r
.3791 .12661 .383 .13416 .38967 .1315 .38577 .124 Mtetra
.643 .627 .819 r
.38577 .124 .38967 .1315 .39635 .12884 .39246 .12139 Mtetra
.644 .629 .821 r
.39246 .12139 .39635 .12884 .40305 .12617 .39916 .11876 Mtetra
.644 .632 .823 r
.39916 .11876 .40305 .12617 .40976 .12349 .40587 .11614 Mtetra
.645 .634 .825 r
.40587 .11614 .40976 .12349 .4165 .1208 .41261 .1135 Mtetra
.645 .636 .826 r
.41261 .1135 .4165 .1208 .42324 .11811 .41936 .11086 Mtetra
.646 .638 .828 r
.41936 .11086 .42324 .11811 .43001 .11542 .42613 .10822 Mtetra
.647 .641 .83 r
.42613 .10822 .43001 .11542 .43679 .11271 .43291 .10556 Mtetra
.647 .643 .832 r
.43291 .10556 .43679 .11271 .44359 .11 .43971 .1029 Mtetra
.648 .645 .834 r
.43971 .1029 .44359 .11 .4504 .10728 .44653 .10024 Mtetra
.648 .648 .836 r
.44653 .10024 .4504 .10728 .45724 .10456 .45337 .09756 Mtetra
.649 .65 .838 r
.45337 .09756 .45724 .10456 .46408 .10183 .46022 .09488 Mtetra
.649 .652 .84 r
.46022 .09488 .46408 .10183 .47095 .09909 .46709 .09219 Mtetra
.65 .655 .842 r
.46709 .09219 .47095 .09909 .47783 .09635 .47398 .0895 Mtetra
.65 .657 .844 r
.47398 .0895 .47783 .09635 .48473 .09359 .48089 .0868 Mtetra
.651 .66 .846 r
.48089 .0868 .48473 .09359 .49165 .09084 .48781 .08409 Mtetra
.651 .662 .848 r
.48781 .08409 .49165 .09084 .49858 .08807 .49475 .08138 Mtetra
.652 .665 .85 r
.49475 .08138 .49858 .08807 .50553 .0853 .50171 .07865 Mtetra
.653 .667 .852 r
.50171 .07865 .50553 .0853 .5125 .08252 .50869 .07593 Mtetra
.653 .67 .854 r
.50869 .07593 .5125 .08252 .51949 .07973 .51568 .07319 Mtetra
.654 .673 .856 r
.51568 .07319 .51949 .07973 .52649 .07694 .52269 .07045 Mtetra
.654 .675 .858 r
.52269 .07045 .52649 .07694 .53351 .07414 .52972 .0677 Mtetra
.655 .678 .86 r
.52972 .0677 .53351 .07414 .54055 .07133 .53677 .06494 Mtetra
.655 .681 .862 r
.53677 .06494 .54055 .07133 .54761 .06852 .54384 .06218 Mtetra
.656 .683 .864 r
.54384 .06218 .54761 .06852 .55468 .0657 .55092 .05941 Mtetra
.656 .686 .866 r
.55092 .05941 .55468 .0657 .56178 .06287 .55802 .05663 Mtetra
.657 .689 .868 r
.55802 .05663 .56178 .06287 .56889 .06003 .56514 .05385 Mtetra
.657 .692 .871 r
.56514 .05385 .56889 .06003 .57601 .05719 .57228 .05105 Mtetra
.658 .694 .873 r
.57228 .05105 .57601 .05719 .58316 .05434 .57944 .04826 Mtetra
.658 .697 .875 r
.57944 .04826 .58316 .05434 .59032 .05149 .58661 .04545 Mtetra
.659 .7 .877 r
.58661 .04545 .59032 .05149 .59751 .04862 .59381 .04264 Mtetra
.659 .703 .879 r
.59381 .04264 .59751 .04862 .60471 .04575 .60102 .03981 Mtetra
.659 .706 .882 r
.60102 .03981 .60471 .04575 .61193 .04287 .60825 .03699 Mtetra
.66 .709 .884 r
.60825 .03699 .61193 .04287 .61916 .03999 .6155 .03415 Mtetra
.66 .712 .886 r
.6155 .03415 .61916 .03999 .62642 .03709 .62277 .03131 Mtetra
.661 .715 .888 r
.62277 .03131 .62642 .03709 .63369 .03419 .63006 .02846 Mtetra
.661 .718 .89 r
.63006 .02846 .63369 .03419 .64099 .03129 .63736 .0256 Mtetra
.662 .721 .893 r
.63736 .0256 .64099 .03129 .6483 .02837 .64469 .02273 Mtetra
.662 .724 .895 r
.64469 .02273 .6483 .02837 .65563 .02545 .65203 .01986 Mtetra
.662 .727 .897 r
.65203 .01986 .65563 .02545 .66298 .02252 .6594 .01698 Mtetra
.663 .73 .899 r
.6594 .01698 .66298 .02252 .67034 .01959 .66678 .01409 Mtetra
.663 .733 .902 r
.66678 .01409 .67034 .01959 .67773 .01664 .67419 .0112 Mtetra
.663 .736 .904 r
.67419 .0112 .67773 .01664 .68514 .0137 .68161 .0083 Mtetra
.663 .739 .906 r
.68161 .0083 .68514 .0137 .69256 .01075 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14481 .21299 m
.14944 .21764 L
s
[(-100)] .13556 .20368 .99452 1 Mshowa
.3437 .13511 m
.34798 .14008 L
s
[(0)] .33513 .12517 .86183 1 Mshowa
.55867 .05093 m
.56253 .05623 L
s
[(100)] .55094 .04033 .72914 1 Mshowa
.125 Mabswid
.18339 .19788 m
.18613 .20071 L
s
.22255 .18254 m
.22525 .18541 L
s
.26232 .16697 m
.26497 .16988 L
s
.30269 .15116 m
.30531 .15411 L
s
.38535 .1188 m
.38787 .12182 L
s
.42765 .10223 m
.43013 .10529 L
s
.47063 .0854 m
.47305 .0885 L
s
.5143 .06831 m
.51667 .07145 L
s
.1068 .22787 m
.10961 .23062 L
s
.06936 .24253 m
.0722 .24525 L
s
.60376 .03327 m
.60603 .03649 L
s
.6496 .01532 m
.65181 .01859 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[80]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00b_ooool2
o`0005Cooooo0037ooooo`?o000000?oooooo`000?ooool0Doooool009Wooooo0ol00004ooooo`;o
00001?ooool2o`0001gooooo0_l00003ooooo`03ojVmiol0003o000005?ooooo002Jooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Ioooo
o`?o00000oooool2ojVli`04ojVmiol0003oooooo`0005;ooooo002Jooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Fooooo`Co00000_oo
ool02OnY^^KoZK_VojVki_nY_>OoZ[cVojZmiol0003oZ[gWo`00001Booooo`00V_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005?ooool2
o`0000Cooooo0_nY^^D01?nY^^KoZK_VojZki_nZ^nH2ojZliP04o`000?n[_NOoZkgWo`00057ooooo
002Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Aooooo`?o00001?ooool2ojVii@06ojVjiOnZ^NCoZ[[UojZjiOnZ^nKoZk_U0_n[_>H0
1Ol0003oZkgWojbmi_oooooo0000053ooooo002Iooooo`;o00001?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000oooooo0_l00003ooooo`06ojVghonY^>CoZKSTojVhi?nY
^NGoZ[SS0_nZ^N@00onZ^^GoZk[Toj^ki@02oj^ki@03oj^li_l0003o[;cU00;o[;gV0_l0001?oooo
o`00V_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000gooooo0ol00003ooooo`Co
ZKOS00?oZKSTojVghonY]n<00_nZ^><01OnZ^NCoZkWToj^ji?n[^^CoZk_U00;o[;_U00?o0000ojfm
iOn]_^H00_n]_^H00ol0003oooooooooo`1=ooooo`00/oooool2o`000003ooooool0003oZ;GR00?o
Z;KR00?oZKOSojVehOnY]^800_nY]^800onY]n?oZkORoj^hh`02oj^hh`0:oj^ii?n/^^Co[;[Tojbj
i?n/^nGo[KcTojfmiOl0003o[KgUojfniP;o[[kV00?o0000ooooooooool0C?ooool00;3ooooo0ol0
0002ooooo`06ojRdhOnX]N;oZ;GRojReh_nX]^;oZKCQ0onY]N400onY]^;oZ[KQoj^ghP02oj^ghP05
oj^hhon/^>;o[;WSojbihon/^^@00_n]^n<2ojfli006o`000?n^_NGo[[gUojjni_n__^Go0000C_oo
ool00:kooooo0_l00004ooooo`05ojRchOnX]>7oZ;CQojReh_nY/n000onY]>400onY]N7oZ[GQojZf
h@02ojZfh@05oj^gh_n/]n;o[;ORojbhh_n/^N<00_n]^^<01_n]^n?o[[_Sojjli?n^_>Co0000ojjm
i@;o[kkT0_n__^D00ol0003oooooooooo`1;ooooo`00Zoooool3o`0000;ooooo00GoZ;;OojRch?nX
/n3oZ;?PojRch@03ojVbg`;oZK?P00?oZKCQojZdh?nZ]>000_nZ]N401OnZ]^7o[;KQojbfhOn/]n;o
[KSQ00;o[KWR00?o[K[Sojjjh_n^^n<00_n^^n<01On^_>Co0000ok2mhon__^Co/;kT00?o/;oU00?o
0000ooooooooool0B_ooool00:Sooooo0ol00003ooooo`06ojRagonX/]ooZ;;OojRbgonX/n3oZ;3N
0_nY/Mh00onY/]ooZ[;NojZcg`02ojZcg`03ojZdh?n[]=ooZkGP00;oZkGP00Ko[;KQojffh?n]^>7o
[KSQojfih_n^^N43ojjjhP05ojjkhon`_>?o/;cSo`000?na_N<00on`_^@00on`_nGo/KoUo`00001<
ooooo`00Y_ooool2o`0000;ooooo00Co0000oooooonX/MkoZ;7N0_nX/Ml00onX/]ooZ;3MojR`gP02
ojR`gP06ojVag_nZ/]koZ[;NojZbg_nZ/mooZk?N0on[]=l00on[]N3o[;GOojffh002ojffh005ojfh
hOn^^>7o[[WQojjihOn^^^800_n_^n800on`_>?o/KcRo`000002ok6mh`06ok2ni?na_nCo/KoTok6o
iOoooooo0000Boooool00:?ooooo0ol00002ooooo`06ojN_gOnX/=koZ;3NojR`g_nX/MkoZ:kL0onX
[m`2ojR`g@05ojR`g_nY/=goZK7MojVagOnZ/]h00_n[/]d2oj^cgP03oj^dgon/]=ko[;CN00;o[;GO
00Co[KKPojjgh?n^]n3o[[SQ0on_^^401_n_^n;o/K_Qok6lh_na_>;o0000ok6mh`;o/[kS00Ko/KoT
ok:ohonb`>Co//3Tooooool0001:ooooo`00XOooool2o`0000Cooooo0onW[md00onX/=koZ:gKojR^
g002ojR^g003ojR_g?nY[]_oZJoL00;oZJoL00KoZK3Moj^agOn[/MgoZk7Moj^bgOn//]d3ojbcgP03
ojbdg_n]]Mko[[KO00;o[[KO00Go[[OPojnggon_^>3o[kSPojnjh@02ok2jh@;o/K_Q00Co/KcRo`00
0?nb_N;o/[kS0_nc_^801?nb_n?o//3Tok?0i?nc`>@2o`0004Wooooo002Nooooo`?o00000_ooool0
1onW[McoYjkLojN^g?nW[]coYjkMojN_gOnX[=X00onX[M/00onX[]coZJgKojV^f`02ojV^f`06ojV_
g?nZ[m_oZ[3LojZ`g?n[/Mgo[;7L0on//]d00on//mko[KCMojfegP02ojfegP05ojjfgon_]]ko[kOO
ojnggon_^>000_n`^N000on`^^7o/K[Pok:lh@02ok:lh@05o`000?nc_N7o/kgQok>nh_nd_^800_nc
_n<01?nc`>Co]<7TokC1i?l00019ooooo`00W?ooool2o`000004ooooool0003oooooojN/f`?oYjgL
00CoYjkLojN[fOnWZm[oYj_J0_nX[=X00onX[M_oZ:cJojV]f`02ojV]f`03ojV^fonZ[]_oZZoK00;o
ZZoK00KoZ[3Lojbag?n//Mco[;7LojbbgOn]/md3ojfdg@03ojfeg_n^]Mko[[GN00;o[kKN00Co[kOO
ok2hgon`^N3o/KWO0ona^^001Onb_>7o/kcQo`000?nc_N7o];gQ00;o];kR00Oo/koSokC0h_nd`>;o
]<7TokG1hooooooo000000gooooo0ol00004ooooo`;o00001?ooool2o`0002cooooo002Iooooo`?o
00000oooool4ojN/f`03ojN]g?nWZMSoYj_I00;oYj_I00CoYj_JojR[fOnXZmWoZ:_I0_nX[=X00onY
[M_oZZgJojZ]fP02ojZ^f`05ojZ_fon[[m_oZk3Koj^`fon//M`00_n]/M`2ojfcg@05ojfdgOn^]=go
[[CMojjeg_n_]]d00_n`]mh00on`^=oo/KSNok6ig`02ok6ig`05ok6jh?nc^n3o/k_Pok>lhOl00000
0ond_N401?nd_^;o]KoQokC0h_nf`>83okG1h`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002_ooooo002Goooo
o`;o00000oooool3ojN[fP?oYjcK1?nWZMP01_nWZmWoZ:WHojR[f?nXZmSoZ:_IojV[f0?oZJcI00?o
ZZgJoj^]fOn[[]X00_n[[]X2oj^_f`04oj^`fon//M_o[K7Lojjbf`?o[[?L00?o[[CMojndgOn_]]d0
0_n_]]d01On`]mko/KSNok6hg_na^=ko/KWO00;o/[[O00Wo/k_PokBkgond_>3o0000okBlh?nd_N7o
]KkQokFohOnf_n400onf`>801?ne`N?o]/7SokK1hol00005ooooo`Go00000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000:oooool009Co
oooo0ol00003ooooo`05ojJZfOnWZ][oYj[JojN[f_nWYmL00onWZ=L3ojNYf005ojRYeonXZMSoZ:WH
ojRYf?nXZmP00onYZmP00onY[=WoZjcIoj^]f@02oj^]f@06oj^^f_n/[m[o[;3Jojb`f_n//M_o[K7K
0on^/]/00on^/mco[k?Lojndg@02ojndg@05ojnfgOna]]go/KONok6gg_na^=h00_nb^Mh00onb^]oo
/k[NokBkg`02okBkg`04o`000?ne_Moo]KgOokFnh@?o][oQ00Ko]/3RokO1h_ng`N;o]/7SokO2h_l0
000=ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000[ooooo`00TOooool3o`0000;ooooo00?oYZSHojJYfOnVZMT00onVZ]T01_nWZ][oYjOG
ojNWeonWYmOoYjSGojNWeP?oYjSF0_nXZML01_nXZMSoZJWGojVZf?nYZ]SoZJ_HojZ[f0?oZjcI00?o
ZjgIojb^fOn/[mX00_n/[mX01_n//=[o[K7Kojfafon]/M_o[[;Kojnbf`?o[k?L00?o[kCMok2eg?n`
]M`00_na]]d01?na]mko/[SMok:ig_nc^Mh3ok>jgP05okBkgone_=oo0000okFmgonf_Ml00_nf_^00
1?nf_n7o]l3QokO0hOng`N82okS1h@;o]l;R00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000:oooool008oooooo
0_l00002ooooo`03o`000?nVZ=SoYZSH00;oYZSH0_nVZMT01_nVZ]WoYZKEojJVe_nVY]KoYjOGojNV
e@?oYjOF00?oYjSFojRXe_nYZ=H00_nYZ=H00onYZMOoZJ[HojZ[e`03ojZ[f003oj^/fOn/[MSo[:kI
00;o[:kI00Ko[:oJojf_fOn]/=[o[K3Jojfafon_/MX3ojnbf`05ojncg?n`]=_o/;CKok2eg?na]]`0
0_nb]m`00onb^=go/kSMok>igP02ok>igP05ok>jg_nd^mko];_NokFlgol000000_nf_Ml01?nf_^3o
]koOokNogong`>42okS0h006okS1hOni`N7o]l;RokO2h_oooooo00002_ooool2o`0000Cooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000[ooooo`00K?ooool2o`0001kooooo
0ol00004ooooo`CoYZSH00CoYZCDojJUeOnVYMGoYZGE0_nVY]D01_nVY]KoYjKEojNVeOnWY]GoYjOF
ojRWe@?oZ:SF00CoZJSFojVYe_nZZMKoZZWF0_nZZmL00onZZmSoZjcGojb]f002ojb]f003ojb^fOn]
[]Wo[JoI00;o[JoI00Go[K3Jojj`f_n_/M[o[k7Jojnbf`02ok2cf`03ok2dfona]=_o/KKL00;o/KKL
00Go/[OLok>hgOnc^=go/kSMok>igP02okBjg@08okBkg_nf^mgo][cNo`000?nf_=ko][gOokNngong
_ml2okRog`03okS0h?ni`Moo^L7Q00;o^L7Q00Co]l;RokS2h_l0003o00002_ooool00ol0003ooooo
ooooo`03ooooo`;o00001?ooool2o`0002cooooo001[ooooo`04o`000?ooooooooooo`0001_ooooo
0_l00003ooooo`07ojJVe_nVY]OoYZKGojJVeonVYmOoYZSHojJSd`03ojJTe003ojJUeOnVY=?oYjGD
00?oYjGD00?oYjKEojRVe?nXYmD00_nXYmD00onXZ=KoZJSEojVYeP02ojVYeP04ojZYe_n[ZmOoZj_G
oj^[e`;oZjcG00?o[:gHojf]f?n][MP00_n][]T01?n][mWo[ZoIojj_fOn^/=X3ok2bfP03ok2cfona
/m[o/KCK00;o/KCK00Go/KKLok:ffonc]mco/kOLok>hg@02okBhg003okBjgOne^]go][_M00;o][_M
00?o][cNo`000?ng_]l00_nh_]h00onh_moo^KoOokW1g`02okW1g`03okW1hOni`^3o^<;R00;o^L?Q
00?o0000ooooooooool0@_ooool006_ooooo00Co0000oooooooooooo00006?ooool3o`0000?ooooo
00OoYJGFojJVe_nVY]KoYZKFojJVeonUX];oYJ?C00?oYZ?C00?oYZCDojJSd_nVY=<00_nVY=<00onW
YMCoYjCCojRUd`03ojRVe003ojRWeOnYYmCoZJSE00;oZJSE00KoZJWFoj^YeOn[Z]KoZj[Foj^[eon/
ZmH3ojb/e`03ojf]f?n^[]Oo[ZoH00;o[ZoH00Ko[ZoIojn`f?n_/MWo[k7Iok2bf_na/]X3ok6cfP03
ok6dfonb]M_o/[GK00;o/[KK00Co/kOLokBgg?nd^=co]KWL0one^]d01onf^mgo]k_MokNkgOl0003o
^;gMokRng_ni_]h00oni_ml01_ni`Moo^/7Ook[1goni`^3o^/;PokW3h@;o^/?Q00?o0000oooooooo
ool0@Oooool006_ooooo00Co0000oooooooooooo00005_ooool2o`000004ooooool0003oooooojFT
e0;oYJGE0_nUYMH00onVY]KoYJ7BojFRdP02ojFRdP03ojFSdonVXm?oYZ;B00?oYZ?B00?oYZCCojNS
d_nWY=<00_nWY=<00onXYM?oZ:KDojVVd`03ojVWe003ojVXeOnZZ=CoZjWE00;oZjWE00KoZj[Fojb[
e_n/ZmKo[:_Fojb/eon][ML3ojj^e`06ojj_f?n_[mSo[k3Hojn`f?n_/MWo/;7I0ona/]X01Ona/m[o
/[CJok:df_nb]M_o/kGJ00;o/kKK00?o];OLokFhfone^M`00_ne^M`01one^]go][[LokJjg?ng^mgo
^;cMo`000?ni_Md00oni_]h01_ni_moo^/3Nok[0g_nj`Moo^l7Ook[2h0;o^l;O00?o^/?Qok_3hOl0
0000@oooool006_ooooo00Co0000oooooooooooo00004oooool3o`0000?ooooo1?nUY=@00onUYMGo
YJ7AojFQd@03ojFQdP03ojFRd_nVXM7oYZ7A00?oYZ;B00?oYZ?BojNSdOnWXm800_nWXm801?nWY=?o
Z:CBojVUdonYYM<2ojVVd`03ojVWe?nZYmCoZZSD00;oZZSD00KoZjWEojbYeOn/Z]Ko[:[Fojb[e_n]
[=H3ojf]e`03ojj^eon_[]Oo[joH00;o[joH00Go[k3Hok2afOn`/MWo/;7Iok6bfP02ok:cf@03ok:d
f_nc]=[o/kGJ00;o/kGJ00Go/kKKokFhfone^=_o]KSKokFig002okJig005okJjg?ng^mco]k_LokRl
gOl000000_ni_Md01?ni_]ko^[oMokZogOnj`=h2ok_0gP04ok_1gonk`]oo^l;Ook_2g`?o^l?Q00?o
0000ooooooooool0@?ooool006_ooooo00Co0000oooooooooooo00004?ooool3o`0000;ooooo00?o
YJ;CojFSdonUXm<01?nUY=@00onUWm3oYJ3@ojFPd002ojFQd@03ojFQd_nUX=3oYZ7A00?oYZ7A00?o
YZ;BojNRdOnWXm400_nWXm400onWXm;oZ:?BojRTdP02ojRTdP04ojVUdonZY]?oZZKCojZVd`;oZZOD
00?oZZSDoj^Xe?n/ZMD00_n/ZMD01_n/Z]Ko[JcFojf/e_n][=Ko[JgGojj]eP?o[jkG00Go[joHok2_
eon`/=So/;3Hok2af@02ok6bf0;o/[?I0onc]=X01Onc]M[o];KJokBgfond]m_o]KSK00;o][SK00So
][WLokNjfong^]_o]k_LokRkfoni_=co0000okVmg@;o^[kM00Go^[oMok^ogOnk_mgo^l3Nokc1g@02
okc2gP04ok_2gonl`moo_<?Ook_3h@;o_<?P00?o0000ooooooooool0?oooool006cooooo0_l0000>
ooooo`?o00001?ooool3ojFRd`;oYJ?C00?oYJCDojBNconUWm000_nUWm000onUX=3oYIo?ojFOc`03
ojFPd004ojJQdOnVX=3oYj7@ojNQd0;oYj;A00?oYj?AojRSdOnXXm800_nXXm801_nXY=;oZJGBojVU
d_nYYM;oZZKCoj^Wd`?oZjSC0_n[Z=@01_n/ZMGo[J[Dojf[eOn]ZmGo[JcFojj/eP?o[ZgF0on_[]L2
ok2_e`04ok2`f?na/MSo/K;Hok:bf0?o/[?I00Go/kCJokBdfOnd]][o];KJokBgf`02okJgfP03okJh
fong^M[o]k[K00;o]k[K0onh^m/01?l0003o^[cLokZngOnk_]`3ok^og@;o_<7M00Co_<;Nokg2g_nm
`]ko_<?O0_nm`mh00onl`n3o_<CPo`000011ooooo`00N_ooool4o`000004oooooonTXM;oY:7BojBQ
dP?oYJ;C00?oY9g>ojBNconTW/l00onTW/l01?nUWm3oYIk>ojFNconUW/l2ojFOc`03ojFPd?nVWloo
YZ3@00;oYZ3@00?oYj7@ojRRd?nXX]000onXXm400onXXm;oZJCAojVUdP03ojVUdP?oZjOC00?oZjSC
ojbXdon/ZM@00_n/ZM@2ojfZe005ojf[eOn^ZmGo[ZcFojj/e_n^[MH00_n_[MH01_n_[]Oo/:oFok6`
eona/=Oo/K7Hok:ae`?o/[;H00?o/[?Iok>cf?nd]=T00_nd]=T01?nd]][o]KKIokJgf_nf^=X3okNi
fP07okNjfonh^]_o^;[KokRkfoni^m_o0000ok^mf`03ok^ng006ok^ogOnl_mco_;oLokc1gOnm`Mgo
_L;N0_nn`]d01_nm`mko_/?Nokk3g_nla>3o_LCOo`00043ooooo001hooooo`;o00000oooool00onT
X=7oY:7BojBQdP03ojBQdP04ojFRdonTWLkoY9g>ojBMcP?oY9k?00GoYIg>ojFNc_nUW/koYIk>ojFN
c`02ojJOcP?oYYo?00CoYZ3@ojNPconWXM3oYj7@0_nXX]000onXXm7oZJ?@ojVTd@02ojVTd@06ojVU
d_nZYM;oZjKBoj^Vd_n[Ym?o[:OB0on/Z=<01_n/ZMCo[JWCojfZe?n]Z]Co[Z_Eojn/e0?o[jgE00?o
[jgFok2^e_n`[mH00_n`[mH01Ona/=Oo/[7Gok:aeonb/MOo/[;H00;o/k;H0_nc/mP01?nd]=Wo]KGI
okFefOne]]T3okJhfP04okNif_nh^M[o^;WJokRjf`;o^K[J00Go^K_Ko`000?nk_M_o^kgKok^ng002
okbng003okbog?nm`=co_L7M00;o_/7L00Go_/;Moko3gOno`mgo_/?Noko4gP02okg4g`;o0000?ooo
ool007Gooooo0ol00004ooooo`?oY:3A00CoY:7Boj>KcOnTW<goY9c=0_nTW<h01?nTWLkoY9c=ojFL
cOnUW<d3ojFMcP04ojFNc_nVWLgoYYk>ojJNcP;oYYo>00?oYYo?ojNOc_nWX<l00_nWX<l00onWXM3o
ZJ;@ojVRd003ojVSd003ojVTdOnZY=7oZZGB00;oZZGB00KoZjKBojbWd_n/Ym;o[:OBojbXdon]Z=<3
ojfYd`06ojfZe?n_[=Co[jcDojn/e?n_[MGo/:gE0on`[]H01On`[mKo/JoFok:`eonb/=Oo/[7G00;o
/k7G00?o/k;HokBceond]=P00_nd]=P01One]MWo][GHokJffOnf]]Wo][SJ00;o]kSI00Oo^;WJokVi
f_ni^M[o^K[JokZkf_nj_=_o000000?o^kgK00Oo_;kLokfofonm_m_o_L3Lokk0fonn`Mco_l;L00?o
_l?M0_noa=h01?nma=oo_/COokk4gol0000oooooo`00Loooool2o`0000?ooooo00OoY9k@ojBOd?nT
Wm3oY9o@ojBOdOnTX=7oXi_<00?oXi_=0_nTW<d01?nTW<koY9c=ojBLcOnTW<d2ojFLc@04ojFMc_nU
WLgoYYg=ojJMc@;oYYk>00?oYYo>ojNOc_nWWlh00_nWWlh01?nWX<ooZ:7?ojRQconXXLl2ojVRd003
ojVSd?nZXm3oZZCA00;oZZCA00KoZZGBoj^UdOn/Y];o[:KBojbWd_n]Z=83ojfXd`06ojfYdon^Z]?o
[Z_Dojj[e?n_[=Co/:cD0on`[MD00on`[]Ko/JkEok6_eP02ok6_eP04ok:`eonc/MKo/k7GokBbe`?o
];?G00Go];CHokJdf?nf]MSo][GHokJff@02okNgf@03okNhfOnh^=Wo^KWJ00;o^KWJ0_nj^mX01?nj
_=_o0000ok^lf_nk_M/2okbnfP04okfofonn_m_o_/3Kokk0f`?o_l;L00Ko_l?Mol33g?o0`mco_lCN
ol34gOnna=l2oko5gP03o`000?oooooooooo03cooooo001`ooooo`?o00001?ooool3ojBNd003ojBO
d?nSVL_oXi[<00?oXi_<0_nSVld01_nTW<goY9[;ojBKc?nTVlcoY9c=ojFKc0;oYIc<0onUWLd00onV
WLgoYik=ojNNc@04ojNOcP03ojRPc_nXXLooZ:7?00;oZ:7?0_nYXm03ojZSd006ojZTdOn[YM7oZjGA
oj^UdOn/Y];o[:OA0on]Z=800on]Z=?o[ZWBojjZd`02ojjZd`06ojj[e?n`[=Co/:cDok2/e?n`[MGo
/JgD0ona[]D01?na[mKo/[3Fok:`e_nc/MH3okBbe`03okBceone/mOo][CH00;o][CH00Co][GHokNf
f?ng]mWo^;OH0onh^=T01oni^M[o^[[IokZjfOnj^m[o^k_Io`000?nl_=X00onl_]X3okjof`03okk0
fono`M_o_l;L00;o`<;K00?o`<?Lol73g?o0a=d00_o1a=d3oko5gP03o`000?oooooooooo03_ooooo
001^ooooo`;o00000oooool00ol0003oY9g?ojBMc`02ojBNc`03ojBNd?nSVL_oXiW;00;oXiW;00?o
Xi[<oj>Kc?nTVLX01OnTV//01?nTVlcoYI_<ojFKc?nUVl`2ojFLc004ojFMcOnVW<coYYg=ojJMc@;o
Yik=00?oYio>ojROcOnXX<h00_nXX<h01?nXXLooZJ7>ojVRconYX/l2ojVSd003ojZSd?n[Y=3oZjGA
00?oZjGA0on/Ym400on]Z=;o[ZSBojjYdP02ojjYdP06ojjZdon_Z]?o[j_Cojn[don`[=Co/JcD0ona
[M@01Ona[]Go/ZoEok:_eOnb/=Ko/k3E00;o/k7F00?o];;GokFbe_ne/mL00_ne/mL01?nf]=So][GG
okJeeong]]P3okRgf003okRhfOni^MWo^KWI00?o^[[I00Go^k_Io`000?nl_=[o_;cJokbnfP02okfn
fP03okjofonn_m[o_l7K00;o`<7K00Ko`<;Kol72foo1`]_o`L?Lol73foo1a=d2ol74g003oko5g_o0
aMko000003gooooo001[ooooo`?o00000oooool4oj>Mc`;oY9g?00?oY9k?oj>IbonSVL/00onSVL/0
1?nSV/coY9W:ojBIb_nTVLX3ojBJb`03ojFJb_nUV/_oYI[;00;oYI_<00?oYIc<ojJLbonVW<`00_nV
W<`00onVWLgoYik=ojNNc@03ojROc@03ojRPc_nYX<koZJ7>00;oZJ7>00CoZJ;?oj^Scon[XlooZj??
0_n[Y=001_n[YM7o[:G@ojbVdOn/Y]7o[:OAojfWd@?o[ZSB00?o[ZWBojnYd_n_Z]<00_n_Z]<01On_
Zm?o/JcDok6/e?na[=Co/JgD00;o/ZkD00Ko/ZoEok>_e?nc/=Go/k3Eok>ae_nd/MH3okFbeP05okFc
eonf]=Oo][CGokJeeong]ML00_nh]]P01?nh]mSo^KSHokVhf?ni^MT2okZif005okZjfOnk^]So_;_I
o`000?nl_=X00_nm_MT01_nm_][o_[kJokjnf_nn_m[o_l3Jol31f`;o`L7J00Co`L;Kol;3f_o1`m_o
`L?K0oo1a=`3ol35gP03o`000?oooooooooo03[ooooo001Xooooo`?o00000oooool00onTW]3oXig?
oj>Mc`03oj>Mc`03oj:GbOnRV<[oXYS:00;oXiS:00CoXiW;oj>GbOnSV<WoXiS90_nSV<X01?nTVL[o
Y9S9ojBIb_nTVLX3ojFJbP03ojFJbonVVl_oYY_;00?oYYc;00CoYYc<ojNMc?nWWLcoYig<0_nWW/d2
ojROc@?oZJ3>00CoZJ7>ojZRc_nZX/ooZZ;?0_n[Xll2ojbTd0?o[:G@00Ko[:KAojfWdOn]Ym7o[JOA
ojjXd_n_Z=83ojnYdP05ojnZdon`Zm;o/:cCok2/dona[=@00_na[M<00onb[]Co/jkDok>_e002ok>_
e005ok>`eOnd/MKo];7FokBae_ne/]H00_nf/mH01Onf]=Oo]kCFokNeeong]MOo^;KH00;o^KOG00?o
^KSHokZheonj^MP00_nj^MP2ok^jf004okbkfOl0003o_KcIokfmf@;o_[gI00Co_[kJoknnfOno`=[o
_l3J0oo1`MX3ol;3fP03ol73foo2a=_o`LCL00;o`/GL00Co`<GNol75gOoooooo0000>oooool006Ko
oooo0_l00004ooooo`CoY9k@0_nSWLl4oj:Gb@;oXYS:00CoXiS:oj>GbOnSUlWoXiO90_nSV<T01?nS
V<[oY9S9ojBHbOnTV<T2ojBIbPCoYI[:0_nVVl/00onVW<_oYic;ojNMc003ojNMc0GoZ9o=00?oZJ3>
ojZQc_nZX/h00_nZX/h01?nZX/ooZj??oj^Scon[Xll2ojbTd006ojbUd?n]YM3o[JKAojfVdOn]Ym7o
[ZSA0on_Z=800on_ZM;o/:[Bok2ZdP02ok2[dP04ok2/dona[=?o/JgCok:]d`?o/jkD00Go/joDokB_
e?nd/=Go];3EokBaeP02okJbe@03okJce_ng/mKo]kCF00;o]kCF00Co]kGGokRfe_ni]mOo^KOG0onj
^=L01onj^MSo^kWHok^if?nk^]So_;_Ho`000?nm_=P00onn_MT2oknnf@04oko0f_o0`=Wo`<3Iol71
fP;o`/;J00?o`/?Jol?3f_o2a=/00_o3a=/01_o2aMco`lGKol?5foo1aMgo`/KMo`0003_ooooo001S
ooooo`?o00000_ooool00ol0003oY9oAojBOd004ojBNd003oj6HbonQUl[oXYO900?oXYO900?oXYG7
oj>Fb?nSU/P00_nSU/P2oj>Gb@03oj>HbOnTUlSoY9S900?oY9S900?oY9W:ojFIbOnUV/X00onUV/X2
ojJKb`?oYic;00CoYig<ojRMbonXW/coZ9k<0onXWld01_nYX<goZZ7>ojZQc_nZXLkoZZ;>oj^RcP;o
Zj?>00?oZj??ojbTcon]YLl00_n]YLl2ojfUd005ojfVdOn^Ym3o[ZSAojjXdOn_Z=800_n_ZM401_n`
Z];o/J[Aok6[d_naZm;o/JcCok:/dP?o/ZgC00?o/jkDok>_dond[m@00_nd[m@01?nd/=Go]K7DokJb
eOnf/]D3okNceP04okNde_nh]=Ko^;CFokRfeP?o^KOG00_o^[SGok^heonk^=Oo^kWHokbjeonl^mSo
_K_Hokflf?l0003o_KcHokjmf@02oknmf003oknnfOo0_mWo`<3I00;o`L3I00Ko`/;Jol?2fOo3`]Wo
`l?Jol?3fOo3a=/2olC4fP03ol?5foo4aM_o`/KM00;o`lKL00?o0000ooooooooool0>?ooool0067o
oooo0_l00004ooooo`06ojBPdOnTWm7oY9oAojBOdOnTWm3oY9k@1?nQV</00onQUl[oXYO9oj6Db003
oj:Ea`?oXiK80_nSUlP3ojBGb003ojBHbOnUV<SoYIS800?oYIW900CoYI[:ojJJbOnVVl[oYY_:0_nV
Vl/00onWW<_oZ9g;ojRMb`02ojRMb`03ojRNc?nXWlgoZIo<00?oZJ3=00?oZZ7>oj^QcOn[X/h00_n[
X/h01?n[Xlko[:C?ojbTcon/Y<l2ojfUc`?o[ZK@00Ko[ZO@ojnXdOn_Z=7o[jSAojnYdOn`ZM43ok6Z
d@06ok6[d_nb[=;o/ZcBok:/d_nb[M?o/jkC0onc[m<01?nd[mCo]K3DokF`e?ne/M@3okJbe@05okNc
e_nh/mGo^;?EokRde_ni]MD00_ni]]H01Oni]mOo^[OFokZge_nk^=Oo_;WG00;o_;[G0onm^mP01_l0
003o_[cHokjlf?no_MSo`;kHol2of@;o`KoH00?o`L3Iol;1f?o2`MP00_o3`]T01?o3`mWoa<?IolC3
fOo4a=X2olG5fP03olC5foo5aM_o`lKL00;o`lKL00?o0000ooooooooool0=oooool005kooooo0ol0
0003ooooo`?oY:7B0_nTX=400onTWm7oXYW<oj:Ic004oj6Hb`03oj2EbOnPU<SoXIC800;oXIC80_nR
ULL01?nSU/SoXiG7oj>FaonSU/L2oj>Gb003ojBGb?nTUlOoYIS800?oYIS800?oYIW9ojJIbOnVV/T0
0_nVV/T00onVVl[oYY_;ojNLbP04ojRMb`03ojVNbonYW/coZIo<00;oZIo<00?oZJ3=ojZPcOn[XLd0
0_n[XLd01_n[X/ko[:;>ojbSc_n/Xlko[:C?ojfTcP?o[JG?00Ko[ZK@ojnVcon_Ym3o[jO@ojnXdOn`
Z=03ok2Yd@06ok6ZdOnaZm7o/Z_Bok:[d_nb[=;o/jgB0onc[]<01Onc[m?o]:oCokB_done/=Co][3C
00;o][7D00?o][;EokNbe?nh/mD00_nh/mD2okVee@05okVfe_nj]]Ko^[KFokZge_nk^=H00onl^ML0
1_nl^]Oo_K[Gokfkf?nn^mOo0000okjlf0;o_kgG00Co`;kHol6of?o1_mSo`KoH0oo2`MP2ol?2f@?o
a<?I0oo5aMX2olG5f`?o`lKL00?o0000ooooooooool0=oooool005cooooo0_l00003ooooo`;oYJ;C
1?nTXM82oj:Jc@CoXYW<00?oXIS;oj2FbOnPULT00_nPULT00onPU<SoXIC8oj2Ca`02oj>DaP?oXiG7
00?oXiK7oj>Gb?nTU/L00onTUlL2ojFHb007ojJIb?nVVLWoYYW9ojJIbOnVV/WoYi[9ojNKbP03ojNL
bP;oZ9g;0onYW//00onYW/coZIo<ojZOc003ojZPc@05oj^QcOn/X/go[:;>ojbRc_n/Xlh01?n]Y<h0
0on]YLoo[ZG?ojnVc`02ojnVc`06ojnWd?n`Z=3o/:S@ok2Xd?n`ZM7o/J[A0onaZm401OnbZm;o/jgB
ok>]d_nc[M;o/jkC00;o]:kB00Ko]:oCokF_donf/=?o][3CokJae?ng/M@3okNbe004okRceOnh]=Go
^;CEokVee@?o^[KF0onk^=H01onl^MOo_;WFokbie_nm^]Oo_[[Fokjkeol000000ono_ML2ol6nf004
ol6of?o2_mSo`[oHol;1f0;o`l7H00?o`l;IolC2f?o4`mT00_o5a=T00oo5aM[oa/GIolG5f`02olG6
fP04ol?6g?o4a]coa<KLo`0003Sooooo001Iooooo`?o000000Coooooo`000?ooooooYJ?D1?nUX]<0
1?nTXM;oXY_>oj:KcOnRVld2oj:Jc@03oj:Ic?nPUl_oX9K:00?oX9K90_nPULT01?nPU<SoX9?7oj2C
aonPTlL2oj>DaP03oj>EaonTULKoY9K600?oY9K700?oY9O7ojFGaonUV<P00onVVLP00onVVLWoYi[8
ojNJb@02ojNJb@03ojNKb_nWW<[oZ9c:00?oZ9g;0_nYW//01_nZWl_oZYo<ojZOc?nZWlcoZZ3=oj^Q
c0?o[:;=00?o[:;>ojfTc_n]Y<h00_n]Y<h01_n^YLko[ZG?ojjUcon^YLoo[jK?ojnWc`;o/:O@00?o
/:S@ok6Yd?naZ]400_naZ]401_naZm7o/Z_Aok>/dOnc[=7o/jgBokB]dP?o]:kB0one[m<01Onf/=?o
]k7DokNae?ng/MCo]k;D00;o^;?D00Go^;CEokVde?nj]MGo^[GEokZfeP02ok^ge@05ok^he_nl^=Ko
_;SFokbie_nm^MH00_nn^]H01?no_=Oo0000oknleono_ML2ol2me`03ol6nf?o1_]Oo`[oH00;o`l3G
00?o`l7HolC1f?o4`]P00_o5`mP00oo5a=Woa/CHolK4f002olK5f@07olG6f_o6a][oa/KJolC6g?o5
a]_oooooo`00000gooooo`00:_ooool3o`0000Cooooo0_l00004ooooo`;o00007Oooool3o`0000?o
oooo0_nUY=@3ojFSe003ojFRdonRW<koXYc>00?oXY_>00?oXY_=oj:JcOnQV</00onPUl/00onPU/[o
X9K9oinDb@02oinDb0;oWi?80_nPTlL2oj>DaP?oY9G600?oY9K6ojBFaonUUlL00onUUlL00onUV<So
YYW8ojJIb003ojNJb0;oYi[900KoYi_:ojRLb_nXW<[oZ9c:ojRMbonYWLX3ojVNb`03ojZObonZWlco
Zj3<00?oZj7<0_n/X/d2ojfSc@03ojfTc_n^Y<ko[ZG>00;o[ZG>00?o[ZG?ojnVc_n_Yll00_n_Yll0
1_n`Ym3o/JW@ok6Yd?naZM3o/J[Aok:Zd0?o/Z_A00Go/jcAokB]d_nd[M;o]:gBokB^dP02okF^dP05
okF_donf/=;o]k7CokNadong/M@00_nh/]<00onh/mCo^K?CokVde002okVde003okZeeOnj]]Co^kOE
00;o_;OE00Go_;SFokfheOnm^MKo_KWFokjjeP02okjkeP06o`000?o0_=Ko`;cFol2meoo1_MKo`KkG
0_o2_mL3ol?0e`03olC1f?o5`MOoaL?H00;oa/?G00?oa/CHolO4f?o6aMT00_o7aMP01_o6a][oalKI
olO6fOo5a]_oaLOKo`0003Oooooo000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000Jooooo`;o00001?ooool00onUYMGoYJCDojFTe002
ojFTe004ojFSe?nSWLooXic?oj>Lc`;oXYc>00?oXY_>oj6Ic?nQV<`00onQV</00onPUl_oWiK:oinE
b@03oinDb@;oWiC800?oWi?8oj2Ca_nPTlH00onSU<H2ojBEaP03ojBFa_nUUlOoYIO700?oYIO700Ko
YIS8ojJIb?nVVLSoYYW8ojNJb?nXV/P2ojRKb@;oZ9c900?oZ9c:ojVMb_nYWLX00_nYWLX00onYW/_o
Zik;oj^Ob`03oj^Pc003oj^Qc?n/XLco[:;=00;o[:;=00Ko[J?=ojjTc_n^Y<ko[ZC>ojjUc_n_YLh3
ojnVcP06ojnWcon`Yloo/JS?ok6XconaZM3o/ZW@0onbZ]001OnbZm7o/j_Aok>/dOnc[=7o]:gB00;o
]JgA00?o]JkBokJ_d_nf/=800_nf/=82okNad`03okRbdoni/]?o^K?C00;o^K?C00Co^KCDokZde?nj
]]Co^kKD0onl]mD3okfhe@06okfie_nn^MGo_[_Foknke_l0003o`;cF0_o1_=H01?o1_MKo`[oGol:o
eoo2_mL3ol?0e`;oaL7G0oo6`mL2olO4f004olO4eoo7aMSob<GHolS5f0;oalKI00CoaLOKolK7f_o6
am[o0000=_ooool002?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000Gooooo`?o00000oooool3ojFUeP;oYJGE00?oYJCD
oj>Nd?nSW]000onSWLl00onSW<ooXI[=oj6Jc@03oj6Ic003oj6Hc?nQV<_oWiK;00?oWiK:00GoWiG9
oinDbOnOU<WoWiC8oijCb002oijBa`;oX9?600CoXiC6ojBDaOnTULKoY9G60_nUU/H00onUUlOoYYO6
ojJHa`03ojJHa`03ojJIb?nWV/SoZ9[800;oZ9[80_nXVlT00onXW<WoZIg:ojVMbP02ojVMbP06ojZN
b_n[W/_oZik;oj^Nbon[Wl_oZj3<1?n/XL`01_n/X/go[J;<ojjScOn^Xlgo[ZC>ojnTc@?o[jG>00Co
[jK>ok2Vc_n`Yloo/:O?0_naZ<l3ok:Yd003ok:Zd?ncZ]3o/j_A00;o/j_A00Co/jcAokB]dOne[M7o
]ZkA0onf[m801?nf/=;o]k3BokNadonh/M83okVbd`04okVcdonj/m?o^[?CokZde0?o^kKD00Co_;OE
okbge?nl]mCo_KSE0_nn^=@01?nn^MGo_k[Eoknke_l00003ol6leP;o`[gF00Ko`[oGol>oe_o3_mKo
`l3GolC0e_o5`ML2olG2e`05olK3eoo7`mOoal?GolO4f?o7a=L00oo8aMP2olO6f@05olS7f?o6am[o
alOJolO7f_l00000=Oooool002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0001Gooooo0_l00002ooooo`03o`000?ooooooYZOG00;oYZKF
00CoYJGFoj>Pd_nSWm7oXioA1?nSW]000onSWLooXI_>oj6Jc@03oj6Jc@03oj6Ic?nPV<coWiO;00?o
WiK;0_nOU/X00onOULWoWY?8oijCb003oijCb003oijBaonPTlKoX9?600?oY9C50_nTULH01?nUU/Ko
YYO6ojJGa_nVUlH3ojJHa`?oYi[80_nXV/P01_nXVlWoZI_8ojVLbOnYW<WoZIg:ojZMb@?oZYk:0_n[
W//00on[Wl_o[:7<ojbQc002ojbQc0Co[J;<00Ko[Z?=ojnTcOn_Y<go[jC=ojnUc_n`YLh3ok2VcP06
ok2WconaZ<oo/JS?ok6XconbZM3o/jW?0oncZ]001?ncZm7o]:c@okB]dOne[M03okJ^d@04okJ_d_ng
[m7o]k3BokN`dP?o^;7B00Go^K;CokVbd_ni/];o^[?Cok^dd`02ok^ed`04ok^fe?nl]]Co_;KDokbg
e0;o_KOD00[o_[SDokjie?no^]Go_k[Eol2keOl0003o`;_Eol6le_o1_=Go`[gF0_o3_]H01_o3_mKo
a;oFolBoe_o4`=KoaL7FolG2e`;oa/;F00?oal?GolO3e_o7a=L00_o8aML01Oo8aMSobLKGolW6eoo7
a]Wob<OH00?oalOJ00?o0000ooooooooool0<oooool002_ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001;ooooo0ol00003ooooo`GoYZOG
00CoYZKFoj>Pd_nSX=;oXj3B0_nSWm400onSW]3oXYc?oj:Lc`03oj6KcP03oj6JcOnPV<coX9S<00?o
X9S<00?oWiO;oinFbonNULX00_nNU<X2oijDb@?oWY?800?oWI;8oifBaonPTlH00_nPTlH2ojBDa@04
ojBEa_nUU/KoYIO6ojFGaP;oYYO600KoYYS7ojNHaonWVLOoYiW7ojNJb?nXV/L2ojRKb0?oZI_800Ko
ZIc9ojZMbOnZWLWoZYg9ojZNb_n[W/X2oj^ObP;o[:3;00?o[:7<ojfQbon]X/`00on]X/`01On^Xlco
[ZC=ojjTcOn_Y<go[jG=00?o/:G>00Ko/:K>ok6Wc_naYlko/JO>ok6XconbZLl3ok>Yc`04ok>Zd?nd
Zm3o]:_@okB/d0?o]Jg@0_nf[]43okN_d@03okN`d_nh/=;o^;7B00Co^K;B0onk]=<01?nk]M?o_;GC
okbfe?nm]]<3okfge0;o_[WD00Co_k[Eol2je?o0^]Co00000_o1^m@00oo1_=Go`[gEol>neP02ol>n
e@06olBoe_o5_mGoaKoEolG1e_o6`MGoa/;F0_o7`]H00oo7`mKob<CFolS5e`02olW5eP;obLKG00?o
b<OHolW7f?o9amP00_o7amX00ooooooo0000ooooo`0cooooo`00:_ooool2o`0000Cooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`;o00001?ooool3ojJXf004ojJW
eonTX]?oY:7CojBQd`;oY:7B00CoXj3Boj:Nd?nRWM3oXYg@1?nRW<l01?nQVlkoX9[>oj2IcOnPVLd3
oj2Hc003oijGc?nNU/_oWYG:00;oWYG:0_nNU<X00onNU<WoWI;9oifBb@03oifBb003oifBaonPTlKo
X9?600;oY9G50onUU/H00onUUlKoYiS6ojNHaP03ojNHa`04ojNIaonXV/OoZ9[7ojRJa`;oZ9_800Ko
ZI_8ojVLb?nZW<WoZYc9ojZMbOn[WLT3oj^NbP;oZio:00Ko[:3;ojfQbon]XL_o[J7;ojfRc?n^X/`3
ojjSc006ojjTcOn_YLgo[jG=ojnUcOn`YLko/JK=1?naYlh3ok:Yc`05ok>YconcZ/oo/j[?okB[d?nd
Zll00_ne[=000one[M3o]Zg@okJ^d@02okJ^d@04okN_dOnh[m7o^:oAokR`dPCo^K;B0_nj/m801?nk
]=?o^kCBokbedonl]M<3okffd`0:okfge?nn^=?o_[SCokjie?no^MCo`;[Dol6je?l0003o`K_Dol:l
e0;o`[gE0oo3_]D3olFoe@;oa/7E0oo7`]H2olS4eP07olW4eOo9aMKob/GFol[5e_o9a]Oob/KFolW7
f002ol[7e`04olO7f_o8amWoooooo`0003?ooooo000[ooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`;o00003_ooool3o`0000?ooooo00?oYZ[IojJYfOnVZMT00onVZ=P3ojBRd`;oY:7C00Co
Y:7Boj:Nd?nRW]3oXYk@0_nRWM000onRW<ooX9[>oj2JcP03oj2JcP03oj2IcOnPV<coWiO<00?oWYO<
00?oWYK;oijEb_nMU</00_nMU<X2oifCb@;oWI;90_nMT/P01?nMT/OoX9?6oj2Ca_nPTlH2ojBEa@04
ojFFa_nVU/GoYYO6ojJGaP;oYiS600CoYiS7ojRIa_nXVLOoZ9W70_nXV/L00onXVlSoZI_8ojVLb002
ojVLb004ojZLbOn[WLWoZig9oj^Mb@;oZik:00KoZio:ojbOb_n/X<_o[:3;ojfQbon^XL/3ojjRc006
ojjSc?n_Xlco[jC<ojnTc?n_YLgo/:G=0onaY/d01_naYlko/ZO>ok:Xc_nbZ<ko/ZW?ok>YcP?o/j[?
0ondZll01One[=3o]Zg@okJ]d?nf[M3o]ZkA00;o]jk@00Go^:oAokR`dOni/M7o^K7AokVbdP02okZb
d@05okZcd_nk/m;o^kCBok^dd_nl]M<00_nm]M<01onm]]?o_[OCokjgdonn^=?o_kSCoknie?o0^M<0
0_o1^]@01ol0003o`[cDol:le?o2_=Co`[gEol>me?o3_]D00_o4_]@00oo5_mGoaL3EolK1e@02olK1
e@05olO2e_o8`]Gob<;EolS4e_o9a=D00oo:aMH01_o:a]KoblKFol_6e_o:amOoblOGolS7f@;obLSI
00?o0000ooooooooool0<Oooool004Gooooo0_l00002ooooo`04o`000?nVZm[oYZ_JojJ[fP;oYZ[I
00OoYZWIojBTeOnTY=GoY:CEojBSe?nTX]?oXj3B00?oXYoB00?oXYkAoj:Nd?nQW=000_nQW<l2oj6K
c`?oX9[>00?oWiW=oinHcOnOUl`00_nOUl`2oijGc004oijFbonMU<_oWIC;oifDb`;oWIC:00?oWI?9
oifBbOnLT/T00_nLT/P2oibAb0;oX9?600?oY9G5ojFEaOnVU/D00_nVU/D00onVUlKoYiS6ojNHaP03
ojRIaP03ojRIaonYV/OoZI[700?oZI_800?oZIc8ojZLb?n[WLT00_n[WLT3ojbNb@?o[9o:00Ko[:3;
ojjQbon^XL_o[Z7;ojjRc?n_X//3ojnSc004ojnTc?n`YLgo/:G=ok2Uc@;o/JK=0onbYlh01OnbZ<ko
/jW>ok>Yc_ncZLko/j[?00;o]:[?00Go]:_?okJ/conf[=3o]Zc@okJ]d003okN^d008okR_d?nh/=7o
^;3AokR`dOni/M7o^[7AokZbdOnk/]43ok^cdP03ok^dd_nl]=;o_KGC00;o_KKB00Co_[OCokjgd_no
^=?o_kSC0oo0^M<01_o1^]Co0000ol6kdoo2_=Co`kcDol>me0;oa;gD00Koa;kDolFne?o5_]CoaL3E
olK0e?o6`MD2olO1e003olS2eOo8`mCobLCE00;obLCE00?ob/GFol_5eOo;a]H00_o;a]H01?o<a]Go
blOGol_7eoo9b=T2olW8f003o`000?oooooooooo033ooooo0012ooooo`?o00000oooool01OnW[=_o
Yj_JojN[f_nVZm[oYJKG00;oYJGF0onTY=D00onSX]CoXj7Coj>Qd`02oj>PdP03oj:Od_nQW]7oXIgA
00?oXIc@0_nQW<l00onQVlooWiW>oinIcP03oinIc@03oinHcOnOUlcoWYO<00;oWIK<0_nMUL/2oifD
b`03oifDb_nLTl[oW9?900?oW9;90_nLT/P00onLTLSoWi;6oinBaP03ojFEa@;oYYK500CoYYO6ojNH
a_nWV<KoYiS60_nXVLH4ojVJa`03ojVKb?nZVlOoZYc800;oZYc800?oZig9ojbNbOn/W/T00on/W/T0
1_n/Wl[o[J3:ojfQb_n]XL[o[Z7;ojjRb`?o[j;;00Ko[j?<ok2Tc?n`Y<co/:C<ok2UcOnaYL`3ok6V
c@05ok:Wc_nbYlgo/jS>ok>Xc_ncZLh00_ndZLh00ondZ/oo]J_>okJ/c`02okJ/c`04okJ/d?ng[]3o
]jk@okN^d0?o^:o@00Co^;3AokV`d?nj/M7o^[7A0onk/]401?nk/m;o_;?AokbcdOnl]=83okffdP?o
_[OB00?o_kSCol2hdoo0^M<00_o1^]<01_l0003o`[_Col:kdoo3_=Co`kcColBme0;oa;gC00?oaKkD
olJoe?o6`=@00_o7`=@01_o7`MCob<;DolS2e?o8`mCobL?DolW4e@;ob/CD00?oblGEol_5e?o;a]H0
0_o<a]D2ol_7e`05olc8e_o9b=Sob/SHol[8f?l00000<Oooool003oooooo0ol00003ooooo`03ojN]
g?nW[M_oYjgK00;oYjcK00CoYj_JojFVeonUY]OoYJKG0_nUYMH01?nTY=GoXj;Doj>Re?nSX]@2oj>Q
d`07oj>Pd_nQW]7oXIkAoj6NdOnQWM7oXIc@oj2Kd002oinKc`;oWi[?0_nOVLh00onOVLgoWYS>oijG
c@03oijGc0;oWIK<00?oWIG;oibDbonLU</00onLTlX00onLTlWoW9;9oi^Bb@02oi^Ab0;oW9780_nO
T/H01?nUULGoYYK5ojJGaOnVUlD2ojNGa@03ojNHa_nXV<KoZ9W600;oZ9W60_nYV/L4ojZKa`04ojZL
b?n[W<SoZig8oj^Mb0?o[9k900Go[Io9ojfPb_n]X<[o[J3:ojfQbP03ojjRb`03ojnRbon_Xl_o/:C<
00?o/:C<0onaYL`00onaY/go/ZO=ok:Wc@02ok:Wc@04ok>Xc_ndZ<go]:W>okFZcP?o]J_>0_nf[<l2
okN]c`05okN^d?nh[/oo^:k?okR_d?ni[m000_ni/=03okZad@;o^k;A0onl/m42okfedP04okffd_nn
]];o_[KBokjgdP;o_kOB00Go`;SCol6id_o1^]?o`[[Bo`000002ol:kd`;o`kcC0oo4_M<2olJoe0?o
al3D0oo8`]@2olW3e004ol[3e?o:a=CoblCDol_5e0;oc<KD00Goc<KEolc7eOo<amGoblOGolc8eP03
ol[8f0;o0000<?ooool003gooooo0_l00004ooooo`;oYjkL0_nW[M`01onW[M_oYJOHojFWf?nUYmSo
YJOGojFVeonSY=H00onSXmD2oj>Re008oj:PdonRWm?oXYoCoj:OdonQWm;oXIkAoj2MdOnPW=43oj2K
d0;oWi_?00?oWi[?oijIc_nNVLh00onNV<h00onNUlgoWYO<oifFc@02oibEc0;oW9G;0_nLU</00onL
Tl[oVi?:oi^BbP03oi^Bb@;oVi7800?oW978oinBa_nOT/H00onVU/D00onVUlGoYiO5ojRHa@03ojRH
aP;oZ9W600?oZI[7ojZKaonZVlL00_nZVlL01On[W<OoZic8oj^Lb?n[W<SoZig800;o[Ik90on]WlT0
1_n]X<[o[Z39ojjQb_n^XL[o[Z;;ojnRbP?o[j?;00?o/:C<ok2TbonaYL`00_naYL`00onbY/co/ZO=
ok:Wc@02ok:Wc@03ok>XcOndZ<go]:W=00?o]J[>00Co]J_>okJ[c_nf[<oo]Zc?0ong[Ll00onh[/oo
^Jk?okV_d002okV_d004okV`d?nj/=3o^[7Aok^bd0?o^k;A00?o_;?AokfddOnm]M800_nn]M400onn
]];o_kKAokngdP02okngdP;o`KWB0_o2^]801?l0003o`[_Col>kdoo3_=<2olBld`06olBmdoo5_]?o
aKkColJoe?o6_m?oal3D0_o8`=<00oo8`]CobL;ColW3e002ol[3e0;oblCD00Koc<GColc6e?o=a]Co
cLKDolc7eOo=am@3olc8eP04ol[8f?o;b=So0000o`00033ooooo000jooooo`?o00000_ooool01_l0
003oYjoMojN_gOnW[mgoYjkLojJZfP?oYJWI00?oYJSHojFWf?nTY]L00_nTYMH2oj>TeP03oj>SeOnR
X]GoXZ7D00?oXZ3C00?oXYoCoj2Od_nPW]800onPWM400onPW=7oX9_@oijKd002oijJc`;oWYW?0_nN
VLh00onNV<koWIO>oifGc@03oifFc@;oW9G<00?oW9G;oi^CbonKTl/00onKTlX01_nKT/[oVi;9oi^B
bOnKTLSoVY78oi^@b0?oWi;60_nVU/D01_nVUlGoZ9S5ojRHaOnXV<GoZ9S6ojVIa@;oZIW60_nYV/H0
0onZVlOoZi_7oj^La`02oj^La`04oj^Lb?n/WLOo[9g8ojbMb0;o[Ik900?o[Io9ojjObOn^X<T00_n^
X<T01_n^XL[o[j;:ojnRb_n_X/[o[j?;ok2Sb`?o/:C;00Ko/JG<ok:Vc?nbY/co/ZK<ok:WcOncYl`2
ok>Xc@?o]:W=00?o]J[>okJZcOnfZlh00_nfZlh01?nf[<oo]jc>okN]conh[Lh3okV^c`04okV_d?nj
[loo^Zo?okZ`d0?o^k;@00?o^k;Aokbcd?nl/m000_nm]=42okjed@?o_kKA00?o_kOBol2hd_o1^M80
0_o1^M82ol:jdP04o`000?o3^m?oa;_BolBld`;oaKgB00KoaKkColJndoo6_]?oa[oColNodoo8`=<2
olS1d`;obL;C00Gob/?Dol_3doo;`m?oblCDolc5d`03olg6e004olg6doo=amCoc/ODolc8eP;ocLSE
00CoblSHol_8eooooooo00002?ooool2o`0002Gooooo000hooooo`;o00000oooool00onX/MkoYk3N
ojN`gP03ojN_g@?oYZ[J00?oYJWIojBWf?nTY]P00onTY]L00onTYMKoXZ?Eoj:Se@03oj:Re@03oj:Q
e?nRX=?oXIoC00?oX9oB00CoX9kBoj2MdOnOW=7oWicA0onNVm02oijJc`03oijIconMV<koWIS>00?o
WIO>00?oWIO=oifFcOnLU/d00_nKUL`2oi^Dc0;oVi?;0_nKTlX00onKT/[oVY79oiZAb@03oiZAb003
oi^@b?nOT/KoWi;600;oYYK50_nWUlD00onXV<GoZIS5ojVIa@02ojVIa@;oZIW600KoZI[6oj^Kaon[
VlOoZi_7oj^Laon/W<L3ojbMa`03ojbMb?n]W/Wo[Io800?o[Yo900Ko[Z39ojnQbOn_XL[o[j7:ojnR
b_n`X/X3ok2Sb`06ok2TbonaY<_o/ZG<ok:Uc?nbY/co/jK<0oncYl`01?ncZ<go]:S=okBYcOneZLd3
okJZc@04okJ[c_ngZlko]jc>okN/cP?o^:g>00?o^Jk?okV_conj[ll00_nj[ll2ok^ad005ok^bd?nl
/]3o_;;@okbcd?nm/m000_nm]=43okjed@06oknfdOo0]m7o`;OAol2hd_o1^=7o`KWB0_o2^M401?o2
^];o0000olBkd_o4^m83olFmdP?oa[kC0_o7_m<01?o8_m;ob<7ColW1d_o9`]<2ol[2dP?obl?C00?o
c<GColg5doo=a]@00_o=a]<2olk7e004olk7doo=b=Goc/SEol_8e`;oc<SG00?o0000ooooooooool0
1Oooool01?l0003oooooooooool0000Tooooo`00=Oooool3o`0000?ooooo0_nX/Ml2ojRagP07ojN`
g_nV[=_oYZcKojJ/fonVZm[oYZ[JojBXf@03ojBWf003ojBVf?nTY]OoXjCG00;oXZCF0_nRXmD01?nR
X]GoXJ7Eoj6Pe?nQX=@2oj6Od`03oj2Od_nOW]?oWigB00CoWicA00CoWY_@oifJd?nMV]3oWI[@0_nM
VLl2oifHcP03oifGc_nLUlkoW9K=00?oW9K=0_nKUL`00onKU<coVi?;oiZCb`02oiZBb`;oVY;:0_nJ
TLT2oiZAb003oi^@b?nOT/KoWi;600?oYYK500CoYiO5ojVHaOnYV<GoZIS50_nYVLD01_nYVLKoZY[6
ojZJa_nZV/KoZi_7ojbKaP?o[9c70_n/WLL01_n/WLSo[Io8ojfOb?n]WlSo[Yo9ojjPb@;o[j7900?o
[j7:ok2RbOn`X/X00_n`X/X01_n`Xl_o/J?:ok6TbonaY<_o/ZG<ok:Ub`?o/jK<00Co/jO<okBWc?nd
Ylco]:S=0oneZLd00onfZ/go]Z_=okN[cP02okN[cP04okN/c_nh[Lko^:g>okV^cP?o^Jo?00Co^Zo?
okZ`conk/M3o^k7?0onl/]03okfcd003okfddOnn]=3o_[GA00;o_kK@00Co`;OAol6gdOo1^=7o`KSA
0oo2^M401Oo3^];o0000ol>jd_o4^m;oa;cB00?oaKgB00?oa[kColNnd_o7_m<00_o8_m82olW1dP?o
b/;B00Cobl;Bol_3doo<a=;ocLGC0_o=aM800oo=a]?oc/KColk7e002olk7d`04olo7doo>b=Goc/SD
olc8e`;ocLWF00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Tooooo`00<oooool2
o`0000?ooooo00GoZ;?PojRbh?nX/^3oZ;7OojJ^g@03ojJ]g003ojJ/g?nV[=_oYJ[K00;oY:WJ0_nT
Z=T01?nTYmSoXjKHoj>Uf?nSYMP2oj>Te`04oj:Te_nQXmKoXJ;Eoj6Re@;oXJ7E00?oXJ3DoinOdonO
Wm<00onOW]<01?nOWM;oWicAoijLd_nNVm45oifJd003oifIconLV<ooW9S?00?oW9O>0_nLU/d01?nJ
ULgoVYC<oiZDc?nJTl`3oiZCb`;oVY;;00?oVY;:oiV@bOnIT<T00_nIT<T2oiZ@b0;oWi;600CoYYK5
ojNFa?nXUlGoZ9O50_nYV<D00onYVLGoZYW5ojZJaP03ojZJaP?o[9_600Co[9c7ojfMaon]WLOo[Ig7
0_n]W/P00on]WlSo[Yo8ojjPb@02ojjPb@05ojnQbOn`X/Wo/:;9ok2RbOn`X/X01?naXlX01OnaY<_o
/ZG;ok:UbonbYL_o/jK<00;o/jK;00Ko]:O<okBXc?neZ<co]JS<okFYcOnfZLd3okJ[c@04okN[c_nh
[<go^:c=okR]cP?o^Jk>00Co^Jo?okZ_c_nj[lko^[3?0onk/Ll01onl/]3o_K;?okfbconm/m3o_[?@
okjdd?no]=000ono]]03ol6gd@03ol6hdOo2^=7o`[WA00;o`kWA00?o0000olBkdOo4_=800_o5_=40
0oo5_M;oa[gAolJmd@02olNndP06olRod_o8`=;ob<3BolW1d_o:`M;ob/;B0_o;`]82olc4dP07olg4
d_o=aM;oc/GBolk5d_o>a]?oclKBolk7d`02olo7d`;oc/SD00CoclSDolg9e_o=bMKo00001_ooool0
1?l0003oooooooooool0000Tooooo`00<?ooool3o`0000;ooooo00?o0000ojRchOnX/n400_nX/n00
1_nX/^3oYjoNojN_g_nV[]goYZgLojF/g0;oYJ_K0_nUZ]/01?nTZM[oXjSJoj>WfOnSYmT2oj>Vf004
oj>Uf?nQY=OoXJCGoj6Te`;oXJ?F00?oXJ;Eoj2QeOnPXMD00_nOWm@2oinOd`03oinNdonNWM?oWYgB
00?oWYcB00?oWY_AoifJd?nLV]400_nLVM04oibHc`03oibGc_nKU/koViK>00?oVYG=0_nJU<`00onJ
TlcoVY?;oiVBb`02oiVBb`;oVI7:1?nIT<T00onJT<SoWi;7oinBa`03ojNFa003ojRGaOnYV<GoZIS5
00?oZYW500KoZY[6oj^JaOn[VlKoZi_6ojbKa_n/W<H5ojfMa`06ojfNb?n^WlSo[Yo8ojjOb?n^X<Wo
[j380_n_XLT2ok2Rb@Co/J?:00Co/ZC:ok:UbonbYL_o/ZG;1?ncY//3okBXc006okFXc?nfZLgo]ZW=
okJYcOnfZlgo]j_=0onh[<d2okV]cP03okV^c_nj[/ko^Zo>00;o^Zo>0_nk/<l00onk/Loo_;7?okba
c`02okfbc`;o_[?@0ono]=001_no]]3o`;K@ol2fd?o1]m7o`KO@ol:hd@;o`[S@00Ko`kWAolBjdOl0
003oa;_AolFkdOo5_=42olJld@03olJmdOo7_M7oakkB00;ob;oA00Kob<3BolW0dOo9`=7ob/7Bol_1
dOo;`]82olc3dP03olc4d_o=a=;oc/GB00;oc/GB0oo?a]800oo?am?oclOBolk8e002olo8e004om38
doo=bMKoc/WFo`0000Gooooo00Co0000oooooooooooo00009?ooool002kooooo0_l00003ooooo`;o
Z;GR0_nX]>401_nX/n7oYk3NojN`g_nW/=koYjoNojF^g@;oYJgM0_nU[=`01?nUZm_oXjWJoj>Yf_nS
ZMX2oj>XfP07oj>WfOnRYMSoXZGHoj:Uf?nRY=SoXJCGoj2Se`02oj2ReP;oX:7F0_nPXMD01?nOWmCo
WYkDoijNe?nNW]@2oijMd`04oijMd_nNW=;oWI_BoibKd@?oW9[A0_nLVM000onLV<ooViO?oi^Gc`04
oi^FcP;oVYG=00?oVYC<oiVDcOnITl`01OnIT//00onITL[oVI39oiR@bP02oiR@b@;oVI380_nOT/L0
1?nWU/CoZ9O4ojVHa?nYV<@2ojVHa@03ojZIaOn[V/GoZi[500;oZi[500CoZi_6ojbLa_n/W<Ko[9c6
0on]WLL01On^W/Oo[Yk8ojjNb?n^WlSo[io800?o[j3800Ko[j79ok2RbOn`X/Wo/:;9ok6Sb_naXlT3
ok:TbP03ok:UboncY/_o/jK;00;o/jK;0_ndYl/01_ndZ<co]JS;okJYc?nfZLco]ZW=okNZc0?o]j_=
0_nh[<d00oni[Lko^Jg=okZ^cP02okZ^cP07okZ_c_nk[lko^jo>ok^`conl/<ko_;7?okfacP03okfb
c`03okjcd?nn]<oo_kC@00;o`;G?00Co`;K@ol6fd?o1]]3o`KO@0oo2^=02olBjd@03o`000?o5^m7o
aK_A00?oa[cA0_o7_M43olRod@?obL3A00Kobl7Aol_2dOo;`]7oc<?Bolc3dOo=a=82olg4d@03olk5
d_o>aM7oclKB00;oclKB00Cod<OAolo7d_o@b=;oclSD0_o@b=<2olk9eP03olk9eOl0003ooooo00?o
oooo00Co0000oooooooooooo00009?ooool002_ooooo0ol00002ooooo`05ojRghonX]^?oZ;KSojRf
honX]N800onW/^000onW/MooYk3NojF_gP03ojF^g@07ojF]gOnTZmcoY:_LojB[g?nTZ]_oXjWJoj:X
f`03oj:WfP04oj:VfOnRYMSoX:GIoj2Tf0?oX:?G0_nPX]H01onPXMKoWZ3EoijPeOnNX=GoWYoDoijN
e?nMW]@00_nMWM<2oifLd`;oWI_B00?oW9_AoibJdOnKVM401?nKV=02oi^Gc`03oi^Fc_nJU/koVIG>
00GoVIC=00KoVI?<oiVBbonIT/_oVI;;oiRAbonHTLX3oiR@bP;oV93900?oVI38oinBaonOT/L00onX
Ul@00onYV<CoZIS5ojZIa@04oj^Ja@03ojbKaOn/VlKo[9_600;o[9c600Ko[Ig7ojfMa_n^W/Oo[Yk7
ojjNb?n_WlL3ojnOb006ojnPb?n`XLSo/:79ok2QbOn`X/Wo/J;90onaXlT2ok:TbP;o/jG:00Go/jK;
okBVbondY/_o]:O;okFWb`03okFXb`05okJYc?ngZ/co]j[<okNZc?ngZld00_nhZl`01Onh[<go^Jg=
okV]cOni[Lgo^Zk>00;o^Zk=0_nk[lh2okb`cP?o_K7>00Co_K;?okjcconn/loo_[C?0oo0]Ll3ol6f
d0;o`[O@00Wo`[S@ol>id?o3^M3oa;[Ao`000?o4^]3oaK_AolFkd?o6_=400_o6_=000oo7_M7ob;kA
olRod@02olVod@03olW0dOo:`=7obl;A00;obl;A0_o<`m401oo=`m7ocLCAolk4dOo>a=7oc/GAolo5
dOo?a]800_o@am401_o@b=;odLSAom78dOo@b=?od<WColk9eP;oc/WE0_l00004ooooo`;o00009Ooo
ool002Sooooo1?l00003ooooo`;oZKOT00OoZ;OSojRfhonW]>7oYkCQojNchOnW/^3oY[7P00;oY[3O
0_nU[mh01_nU[]goY:gMojB]gOnT[=goY:_Loj:Zg0;oXZWK0_nRZ=/00onRYm[oXJOJoj6Vf@03oj2U
f@03oj2Tf?nPXmOoWj?H00?oWj;G00CoWZ7FoijPeOnMWmKoWIkE0onMW]@2oifMd`04oifLdonKVm;o
Vi_Boi^JdP?oViWA0onKV=02oiZGc`?oVYK>00GoVIG>oiVDcOnIU<goVIC=oiRCc@03oiRBc0?oV97;
00KoV97:oiR@b_nHT<[oV939oiN?bOnHSlP3oinBa`;oZ9O400CoZIS4ojZIaOnZVLGoZYW50_n[V/D3
ojbKa@03ojbKa_n/W<Ko[Ic600?o[Ig600Ko[Yk7ojnOaon_WlOo[io7ojnOb?n`X<P3ok2Qb006ok2Q
bOnaX/Wo/J;9ok6RbOnaXlWo/Z?90onbY<X01?ncYL[o]:K;okBVbondY//3okFWb`06okFXbonfZ<_o
]jW<okNYc?ngZ/co^:[<0onhZl`2okV/c@05okV]cOnj[Lgo^Zg=okZ^cOnk[ld00onk[lh00onl/<ko
_K7>okfacP02okjbcP04okjccono/lko_kC?okndc`?o`;G?00Oo`KK@ol:fcoo2]/oo`[O@ol>hcoo3
^M3oa;W@00;o000000GoaK[@olFkd?o6^m3oa[_@olJld002olNld003olRndOo8_]3obKoA00;obKo@
00?ob/3Aol_0d?o;`]400_o<`]000oo<`m7ocL?Aolk4d@02olk4d@05olo5dOo@a]3od<K@om37dOoA
am401?oAb=401_o@bM?odLWBolk9eOo?bMGod<_Eo`0002_ooooo000Vooooo`;o00001?ooool01?nY
^NGoZKSTojVhi?nY]n@2ojNfh`03ojNdh_nW]>7oY[;Q00;oY[7Q0_nV/N001_nV/=ooY:oOojB_gonT
[]koY:gMoj>/gP;oXj_M0_nRZ]`01?nRZM_oXJSLoj6WfonQYm/2oj6WfP03oj6VfOnPYMWoWjCI00Co
Wj?H00?oWj;GoifQeonMX=H00onMWmH00onMW]GoWIkDoibMe002oibLe0;oW9_C0_nKVm800onKV];o
ViWAoiZId@02oiZHd0;oVYO@0_nJUll00onJU/koV9G?oiRDcP02oiRDc@?oV9?=0onHT/`00onHTL_o
Ui7;oiN@b`02oiN?bP?oUho900?oV8o8oinBaonOT/L00_nXUl@2ojVHa003ojZIaOn[VLCoZi[500;o
Zi[50_n/VlD01_n]W<Go[Ic6ojfLa_n]W<Ko[Ig6ojjMaP;o[Yk70_n_WlL3ok2Pb005ok2Qb?naXLSo
/J;8ok6Rb?naX/T01?nbXlT01OnbY<[o/jC9okBUb_ndYL[o]:K;00;o]JK:00Ko]JO;okJWbonfZ<_o
]ZS;okNYc?ngZL/3okRZc004okR[c?niZlco^J_<okV/c@?o^Zg=0onk[ld01?nk[lko_;3=okfac_nm
/Lh3okjbcP?o_k?>00?o_kC?ol2dc_o0]Ll00_o1]/l00oo2]/oo`[O?ol>hc`03o`000003olBid?l0
003oaK[@00?oa[_@0oo7_=02olRnd0?obKo@00Cobl3@ol_1d?o;`M3oc<;@0_o=`]000oo=`m7oc/?@
olk4d@02olo4d0?od<K@00?odLOAom77d?oAb=400_oAb=43om79dP04olo9eOo@bmGoooooo`0002[o
oooo000Sooooo`?o00000oooool3ojVji@06ojViiOnX^>CoZ;OTojRgi?nW]^?oY[CS0_nV/n82ojJb
h@06ojJahOnT/>3oY;3PojB`h?nT[mooXjkO0_nS[Mh2oj>/gP04oj>[gOnQZMcoXJWLoj6Yg0;oXJSL
00?oXJOKoinVfonOY]/00_nOYMX2oinTf@04oinSf?nNX]SoWZ;HoijRf0;oWJ7G00CoWJ3FoifOe_nL
WmKoW9kE0onLWM@2oibLe003oibKdonJV];oVY[B00;oVYWB0_nJVM42oiZHd003oiZGd?nIU/ooVIK?
00?oV9G?00KoV9C>oiRDcOnHU<goV9?=oiNBcOnGT/`2oiNAc0?oUi7;00KoUi3;oiN?b_nGSl[oUho9
oiJ?bOnGSlP2oinBa`?oZ9O400KoZIS4oj^Ia?n[VLCoZiW4oj^JaOn/V/D3ojbKa@03ojfLaOn]W<Ko
[Yg600?o[Yg600Ko[Yk7ojnOaon_WlOo[io7ok2Pb?n`X<L3ok6Qb003ok6Rb?nbXlWo/Z?900;o/Z?9
1?ncY<T01?ndYL[o]JK:okFVb_neY/X3okJWb`05okJXbongZL_o]jW;okNYbonhZ/`00_nhZl`01Oni
Zlco^Jc<okZ]c?nj[Lco^Zg=00;o^jk=00Co^jo=okb_cOnl/<go_;3=0onm/Lh3okjbcP;o_k?>00?o
`;C>ol6dc_o1]/l00_o1]/l3o`0000;o`kS?00Koa;W@olBicoo4^Loo0000olJjcoo6^m02olNkd003
olNld?o8_M3ob;k@00;obKk@00?obKo@olZod?o;`M000_o;`M000oo<`M3ocL;@olg2d003olk3d0;o
clC@0oo@a]001ooAam3od/O@om;7d?oAb=7od/SAom?9d?oAbM800_oBbm800oo@bmGod<cEo`00000Z
ooooo`008_ooool2o`0000?ooooo0_nY^nH01?nY^^KoZK[UojRhiOnX^>D2ojRhi005ojRgi?nV]^Co
Y[CSojJdhonV/n800onU/^801?nU/N7oY;3Poj>_h?nS[n02oj>^g`07oj>]g_nQZmkoXJ_Noj6[g_nQ
ZmgoXJWLoj2Yg@03oinXg004oinWfonOY]_oWjKKoinUfP?oWZCI00?oWZ?IoijRf?nLXMP00_nLXML2
oibOe`;oW9oF00?oW9kEoibMe?nKWMD00_nJW=@2oiZKd`;oVY[B00?oVYWBoiVHdOnIV=400_nIUm42
oiVGd0;oVIK?0_nHULl00onHU<koUi?>oiNCcP03oiNBc@03oiNBc?nGTLcoUi7<00;oUi7;00?oUi3;
oiJ?b_nFSlX00onFSlT01OnGSlSoWi;7oinBaonXUlCoZIO400;oZYS400?oZiW4ojbJa?n/V/D00_n/
V/D2ojbKa@03ojfLaOn^WLKo[Yg600;o[Yg60on_W/H00on_WlOo/9o7ok2Pa`02ok2Pa`06ok6Qb?na
XLOo/Z;8ok:Rb?nbXlWo/j?81?ncY<T01?ndYLWo]:K:okBVb_neY/X2okJWbP06okJWbongZ<[o]jS;
okNXbongZL_o^:[;0onhZl`3okV/c0;o^Zg<00?o^jk=ok^^c?nl[ld00_nl[ld00onl/<go_K3=okfa
cP02okjac@04okjbc_no//go_k?>oknccP;o`KC>0ol000001?o2]/ko`[O?ol>gc_o3^<l2olBhc`06
olBicoo5^Looa[[?o`000?o6^/ooak_@0_o7_<l00oo8_M3ob;g?olVnd002olZnc`03olZod?o;_loo
bl7@00;oc<7@0_o=`]002_o>`/ooc/?@olo3coo?`looclC@om35coo@a]3odLK?om;6cooBam02om;7
c`03om;8dOoCbM3od/_B00;od/_B00Cod<cEom3<e_o@c=Ko0000:Oooool002;ooooo0_l00002ojVm
i`06ojVlionY^nKoZ;[VojRji_nX^NKoZ;SU0_nW^>D2ojJgi006ojJfi?nU]>?oYKCSojFdhonU/n;o
YK;R0_nS/N82oj>`h@07oj>_h?nR[N3oXZgPoj:]h?nQ[=ooXJ_Noj2[g`02oj2ZgP;oX:WM00?oWjSL
oijWgOnNY]`00onNY]/01?nNYM[oWZCIoibSf_nLX]T3oibQf0;oW:7G00?oW9oGoi^Ne_nKW]H00_nK
WMH2oi^Me@;oVYcD00?oVY_CoiVJdonIV]<00_nIVM82oiVHd@;oVIOA00?oVIO@oiNEd?nGUM000_nG
U<l2oiNDcP;oUi?>0_nGT/d00onGT/coUY7<oiJAc002oiJ@b`;oUXo;0_nFSlX2oiJ?b@03oiN?b?nO
T/OoWi;700?oZIO400CoZYS4ojbJa?n/V/Co[9[40_n/V/D01_n/VlGo[I_5ojfLaOn]W<Go[Yg6ojnM
a@Co[ik60on`WlL00on`X<Oo/J77ok6Qa`02ok6Qa`06ok:Rb?ncXlSo/j?8ok>Sb?ncY<Wo]:C80ond
YLT01?ndY/[o]JK9okJWb_nfYlT3okNXbP05okNXbonhZ/_o^:[;okRZbonhZl`00_niZl/01?ni[<co
^Zc;okZ]c?nj[L`3ok^^c004okb_cOnm[lco_Jo<okf`c@?o_[7=0ono//d3o`0000;o`KG>00Co`[K>
ol>fc_o3]/ko`kO>0oo4^<l2olFic`;oa[[?00Co0000olNlcoo7_<ooakc?0_o8_Ll01oo9_Loob[k?
olZncoo:_/oobko?olc0coo<`M000_o=`Ll00oo=`]3oc/;?olo3c`02olo3c`?od<G?00?odLK?om;6
cooBall00_oBall02_oCbM3oe<_AomC;dOoBbm;odlgCom?=e?o@c=KoclcFooooool0000Xooooo`00
6_ooool2o`0000Kooooo00?o0000ojVmj?nY_NL00_nX_>P01?nX^nOoZ;[VojNjionW^^L2ojNiiP06
ojNhiOnU]^GoYKKUojFfiOnU]NCoYKCS0_nS/n@2oj>bh`07oj>ah_nR[n;oXZoRoj:_h_nR[^7oXZgP
oj2]h002oj2/g`;oX:_O00CoX:[NoijYg_nNZ=goWZSM0_nNYmd00onNY]coWZKKoifUf`02oifTf`;o
W:?J00?oW:;IoibQf?nKXMT00onKX=P01?nKWmOoVikFoi^Ne_nKWMH2oiVLe@?oVI_D0onIV]<00onI
VM;oV9SBoiRHdP02oiRGd@;oV9K@0_nGUM02oiNDc`03oiNDc_nFTlkoUY?>00;oUY;=0_nFTLd2oiJA
c0;oUY3;00?oUXo;oiF>b_nES/X00_nES/T2oiN>b@;oWi;700CoZIO4ojZHa?n[VLCoZiW40_n/V/@0
0on/V/Go[I_4ojfKa@02ojfKa@06ojfLaOn_WLGo[ig5ojnMaOn_W/Ko/9k60_n`WlH00on`WlOo/J36
ok6Qa`03ok6Qa`03ok:RaonbX/So/Z;800;o/j?80ondY<P01?ndYLWo]JG9okFVbOneY/T3okJWb@;o
]jS:0_nhZLX01OnhZ/_o^J[;okVZboniZl_o^Z_;00;o^Zc;00Go^Zg<ok^]c?nk[Lco^jk<okb^c003
okf_c0;o_[3=00?o_[7=oknacOl000000_l000000oo0/lgo`;?>ol6ecP02ol6ecP?o`kK>0_o4]lh0
2oo4^<ooaKS>olFhc_o5^Looa[[>olJjcol0003oak_?olNlcoo8_<oob;g?00;obKg?0oo:_/l3olc0
c`;ocL7?0oo>`/l00oo?`looclC?om35c`02om35c`07om75c_oBa/ood/O?om;7cooCb<ooeL_@omC;
d@02omK>dP05om?=dooCcMCodlgDolo<e_o?bmL00_l0000Wooooo`006Oooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooZKgXojRlj0;oYkcX0_nW^nP01_nW^^OoYKSVojFhi_nU^>KoYKOV
ojFfi@;oY;KU00?oY;CToj>ci?nR/n@00onR/^<00onR/N;oXZoRoj2_hP02oj2^h@;oX:gP00CoX:cO
oijZgonNZ]ooWZ[O0_nNZMh00onNZ=goWJOMoifWg@02oifVg0;oWJGK00?oWJCKoi^Sf_nKXmX00onK
X]T01?nKXMWoVj3HoiZOf?nJW]L3oiVNe`06oiVMe_nIW=GoVIcEoiVKe?nHVmCoV9[D0_nHVM<4oiRH
dP;oV9OA00?oV9K@oiJEd?nFUM000_nFU<l2oiJCc`;oUY?>0_nFT/d00onFTLgoU93<oiB@c002oiB?
c0;oU8o;0_nES/X2oiF>b@03oiN>bOnOT/OoWY;700?oZYS400?oZiW4ojbJa?n/V/@00on]Vl@01?n]
VlGo[Yc5ojjLaOn^W<D2ojnMa@?o/9k600Ko/9o6ok6Pa_naX<Ko/J36ok6QaonbXLL3ok:Ra`04ok:R
b?ncXlSo/j?8ok>Sb0;o]:C80_neYLT01OneY/Wo]ZK9okJVbOnfYlWo]jO900?o]jS:00Co^:W:okVZ
boniZ/_o^J[;0onjZl/01?nj[<_o^jc;ok^]c?nl[L/3okb^c0;o_Jo<00Go_[3=o`000?l0003o0000
oknbc003ol2cc@;o`KC=00?o`KG>ol:ecOo2]Ld00_o3]/h3olBgcP03olFhc_o5^LkoaKW>00;oa[[>
00Koak_?o`000?o8^lkob;c?olVlc_o9_Ll2olZmcP03olZncoo;_/koc<3?00;oc<3?0_o=`Ll01oo>
`Lkoc/;?olo3c_o?`lkoclC?om34c_o@aLl00_oAaLh02?oBaloodlO>om?7c_oCb<ooeL_@omO?d_oF
c];oeLoC0ooCcM@01?o?bmOoc/_Golk;eol0000Wooooo`006Oooool01?l0003oooooooooool00004
ooooo`;o000000GoooooojRmjOnX_NWoZ;gYojNlj003ojJjj007ojFiionU^>KoY;SWojBhionT]nKo
Y;KUoj:eiP03oj:di@05oj:ci?nR/^?oX;7Toj2ai?nP/><00_nP[n801onP[^7oWjcQoin/hOnO[>7o
WZ_PoijZgonMZ]l00onMZMl01?nMZ=koWJOMoifWgOnMY]`3oi^Tg006oi^SfonKXm[oVj?Joi^RfOnJ
XM[oVZ3I0onJWmP01?nJW]OoVIkGoiRMeonHW=H2oiRKe@?oV9_D00CoV9[DoiRIdonHVM?oV9SB0_nF
Um84oiJFd@;oUYG@0_nFU<l00onFTlooUI;>oiFBcP04oiFAc@;oU93<0_nDSl`00onDSl_oUHk:oi>>
b`02oiB=bP04oiJ>bOnNT/OoWY;7oijBa`;oZYS400KoZiW4ojbJa?n/V/Co[9[4ojfKa?n^Vl@3ojjL
a@Co[ig500Co/9k6ok2NaOn`WlKo/9o60_naX<H3ok:Qa`05ok:RaoncX/Oo/j?7ok>SaoncXlP01?nd
Y<P01?neYLWo]ZK9okJVbOnfY/T3okNWb@05okNXb_nhZ<Wo^:W:okRYb_niZ//00_niZ/X01?njZl_o
^Zc;ok^/bonk[</3okb]b`03okb^c?nm[lco_Jo<00;o00000_nn/L`3oknbc003ol2ccOo1/lgo`KC=
00;o`[C=00Oo`[G=ol>ecOo3]Lgo`kK>olBfcOo4]lkoaKS=00?oaKW>0_o6^/h2olRkcP05o`000?o8
^lkobKc>olVlc_o:_Lh00_o;_Lh00oo;_/koc;o>olc0c`02olg0cP03olg1coo>`Lkocl?>00;ocl?>
00God<C>om74c_oAa<kodLG>om;6cP03om?7cP;oeL_@00OoeloBomO@d_oEcm?oeLoCom?=e?oBcMGo
dLgE00?oc/_G00?o0000ooooooooool09?ooool001Wooooo00Co0000oooooooooooo00001?ooool0
1Ol0003oooooooooooooooooZ;gY00;oYkcY00KoY[cYojJjj?nT^^WoY;[YojBij?nT^>L2oj:gj0;o
X[KW00OoX[GVoj:diOnQ/nKoXK?Voj6biOnP/NCoWk7T00;oWk3S0_nO[^<00onO[N;oWjcQoif/h@03
oif[h003oifZgonMZMooVjSO00;oVjON0_nKY]d01?nKYMgoVjCLoiZTg?nJXm/3oiZRfP;oVZ7J00Co
VZ3IoiZOf?nHWmSoV9kH0onHWML01_nHW=KoV9_EoiRKeOnHVmCoUi[EoiNIe0CoUiSC0_nFUm83oiJF
d@;oUIC@1?nETll2oiFBcP?oUI7=00CoU93<oi>?c?nCSlcoTho<1?nCS//2oiB=bP03oiJ>bOnNT/Oo
WY;700;oZiS40_n/VL@00on/V/Co[I[4ojjKa002ojjKa003ojjLaOn_WLGo[ig500;o[ig51?n`W/D0
1_n`WlKo/J36ok6Pa_naX<Ko/Z77ok:QaP?o/j;700?o/j?7okBTb?ndY<P00_ndY<P01?neYLSo]ZG8
okJUb?nfY/T3okNWb@Co^:S900Co^:W:okVYb_niZ/[o^Z_:0onj[</01?nk[<_o^jg;okb]bonl[//3
o`0000;o_[3<00Co_[7<oknac?no/Lco_k;<0_o0//`01?o1/lgo`[C=ol:dcOo2]<d3ol>ec@;oa;K=
0oo5^<d00oo5^Lkoa[W=olJjcP02olNjcP03olRkc_l0003ob;_>00;obKc>0oo;_Lh3olbocP;ocL3>
00Goc/7>olk2c_o>`/kocl?>om33cP03om74cP04om75c_oBa/kodlK>om?7cP;oeL_@00CoeloBomO@
d_oGd=;oeLoC0_oDcm@01_oBcMGodLgEom7=e_o>bmOocL_Ho`0002Kooooo000Iooooo`04o`000?oo
ooooooooo`0000Cooooo0_l00003ooooo`05ojNljOnV_>WoY[cYojFkjOnT^^T00_nS^^T2oj:hj007
oj:gj?nQ]^OoXKKWoj6fionQ]>KoXK?VoinciP02oinbi@;oWk7T00GoWk3Soif^honM[^?oWJkSoif]
hP02oif/h@04oif[h?nLZ^7oVjWPoi^Yh0;oVjSO00?oVjONoiZVg_nJY]h00_nJYMd2oiZTg003oiZS
fonJX][oV:7K00;oV:7J0_nHWmT2oiROf004oiRNf?nHWMOoUicGoiNLeP?oUi_F0_nGV]D01?nGVMCo
UiSCoiFHe?nEUm<2oiFFdP;oUIKA0_nEUM42oiFDd0?oUI??1?nCTLh00onCT<goTho<oi>?c002oi>?
c0CoThk;00?oU8g:oi>=b_nESLT00onNT/L2oj^Ha004ojbIa?n]V/Co[I[4ojfJa0;o[Y_40_n_W<@0
0on_WLGo/9g5ok2Na@03ok2Na@04ok6OaOnaWlKo/Io6ok6PaPCo/Z760_ncX/L2okBSa`03okBTb?ne
Y<Oo]JG800;o]JG800Co]ZG8okJVb?ngYlWo]jO81?nhZ<T00oniZLWo^JW:okVYbP03okZ[bP03okZ/
bonk[<[o^jc:00?o000000So_:k;okf_c?nn[l_o_Zo;okj`c?no/<_o_k7<ol2ac0?o`;;<0_o1/l`0
1?o2]<go`[C<ol:dc?o3]Ld2ol>fc@03olBfcOo5]lgoaKS=00;oa[S=00?oa[W=olNicOo7^/h00_o8
^/d00oo8^lko0000olVlcP02olZlc@03ol^mc_o;_/koc;o>00;oc;o>0_o=`<h01oo>`<goc/;>olo2
cOo?`/god<?>om33cOoAa<h00_oAaLh01ooCa/koeL_?omG;cooEbm3of=3BomSAd_oGd=800_oFd=<2
omC?e007om7=eOoAcMKodLgFom3=e_o=bmSoc<_Ho`00000Uooooo`006Oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00?ooooo00?oY[cYojBlj_nT_>X00_nS^nX01_nS^^WoXKSY
oj6hjOnQ^>WoXKOXoj6fi`;oWkGX00GoWkCWoinci_nO/nKoWk;UoifaiP02oif`i@03oif_i?nM[^?o
W:gT00?oW:cS00CoW:_RoibZhOnLZ^7oVjWP0onJZ=l01?nJYmooVZKNoiZVg_nJYMd3oiRSg003oiRR
g?nHXM_oV:7K00;oV:7J00?oV9oIoiNNfOnGW]T00_nGWMP2oiNLe`03oiNLe_nGVmKoUI[F00;oUIWE
00GoUIWDoiFHe?nEV=CoUISDoiFGd`02oiFFdP;oUIKA00?oUIGAoiBCd?nDTm000_nDTm02oiBBc`Co
Ti7>00CoTi3=oi>?c?nBSlgoTXk<0_nBS//2oi:=b`;oThg:0_nESLT2oijBa`06oj^Ha?n[V<?o[9W3
ojbI`on]V/Co[Y_30on^Vl@01_n_W<Co/9g5ok2MaOn`WLGo/9k5ok6Na@?o/Io500?o/Io6ok:Qa_nb
XLH00_nbXLH00oncX/Ko/j;7ok>Ra`02okBSa`?o]JC700Co]JG8okJUb?nfY/So]ZK80ongYlP2okRX
b@;o^JW900Go^JW:okZZbOnjZ/Wo^Z_:ok^[b@03o`0000;o_:g:00?o_:k;okf^bonm[//00_nn[l/2
okn`b`?o`;7<00Ko`;;<ol6bc?o1//co`K?<ol:cc?o2]<`2ol>dc004ol>fcOo4]/coaKO=olFgc0?o
a[S=0_o7^Ld4olRjc@03olVkcOl0003ob[c=00;obkg=00?obkk>olbncOo<_lh00_o=_ld00oo=`<ko
c/3=olo2c@02olo2c@05om32cOo@`lgodLC=om75c_oBaLh00_oEbll2omSAdP03omS@d_oHdM;oem7C
00;oe]3C00CoeM3DomC?e?oCc]GodLgF0_o@cMH01?o<bmSoc<_Iolc;fOl0000Tooooo`006_ooool2
o`0000Gooooo00?o0000ooooooooool01Oooool01_nT_>[oXkc[oj:jjonR^^_oXKWZoj6hj@;oWkOZ
00?oWkKYoinej?nM]>P00_nM/nL2oifbi`05oifai_nL[nGoW:oUoib_iOnL[^@00_nL[N@01?nL[>?o
VZcSoiZ[h_nJZn82oiZZh@03oiZYhOnJZ=ooV:OP00;oV:KO0_nHYMh01?nHY=goV:?LoiNSgOnGX]`3
oiNQf`;oUj3J00CoUioJoiNNfOnGW]WoUigH0_nEW=P2oiFKe`;oUI[F0_nEVMD01?nEVMCoUISDoiBG
e?nDU]<2oiBFdP?oU9GB00?oU9CAoiBCd?nDTm000_nDTm000onDT/ooTY7>oi:AcP02oi:@cPCoTXo=
00?oTXk<oi:>bonBS//00_nBSL/00onCSL[oUHg9oiB=b@02oijBa`?oZiS300Go[9W3ojjK`on^Vl?o
[Y_3ojjKa003ojnLa0;o/9g50onaW/D2ok6Oa@;o/Z3500?o/Z76ok>Qa_ncX/H00_ncX/H01_ncX/Oo
]:?7okBSaondXlOo]JC7okJTa`?o]ZG800Co]ZK8okNVb?ngYlSo^:O80onhZ<T2okVYb@09okZZbOl0
003o0000o`000?nkZlWo^jc:okb/b_nl[L[o_Jg:00?o_Jk;0onn[l/2okn`b`05ol2ac?o1/L_o`K7;
ol6bc?o2///00_o2/l`3ol>dc0;oa;K<0oo5]l`3olJhc@;oakW=0oo8^/d2olVlc@03o`000?o;_Lgo
bkg=00?oc;k=0oo=_ld00oo>`<gocl7=olo2c@02om32c@09om74cOoBaLgod/G=om;5c_oEbloofM;B
omSAd_oHd]?of=7B00;oem7C00Soe]3ComG@e?oEd=Coe=3Eom?>eOoBc]Kod<gFom3=e`?oc<_I00?o
0000ooooooooool08_ooool0027ooooo00?o0000ooooooooool01_ooool01_nS_>_oX[_[oj2jjonP
^^_oWkWZoingjP;oWKOZ00GoWKKYoifdj?nM]>SoWK?Woi^cj002oibbi`03oibai_nL[nGoVZoV00?o
VZkU00CoVZgToiZ/honJ[>?oVZ_R0onHZN801?nHZ>7oV:OPoiRWh?nHY]l2oiNTgP;oUj?N0_nGXmd0
0onGX]coUj7KoiJPg002oiJOf`05oiJNf_nFWMWoUYgIoiJMfOnEWMP00_nEW=P00onEVmOoU9[GoiBJ
eP02oiBIeP;oU9SE0_nDUm@01OnDU]?oU9KBoiBFd_nDUM;oTYCB00?oTY?A0_nBT]02oi:Ac`;oTY7>
00?oTY3>oi:?cOnBSld00_nBSld00onBS/coTHg;oi6=b`02oi6=b`04oi:<b_nDSLWoU8g9oiB=b@;o
WY;700KoZiS3ojbI`on]V/?o[I[3ojjK`on_Vl<4ojnLa003ok2MaOn`WLCo/9g400;o/Ik500Co/Io5
ok:OaOnbWlGo/Z350oncXLH01_ncX/Ko]:;6okBSa_ndXlKo]:?7okFTa`?o]ZC700Co]ZG8okNUaong
Y/So]jK80onhYlP00onhZ<Wo^JS8o`000002o`0000;o^Z[90_nkZlT2okb/bP?o_Jg:00Oo_Jk;okj^
b_nn[/[o_Zo;okn_bono/<_o`;3;00?o`K7;0_o2///01?o2/lco`kC<ol>dc?o3]<`2olBec003olBf
c?o5]/coaKO<00;oa[O<00?oa[S=olNhc?o7^Ld00_o8^L`01Oo8^/gobK_<olVkc?o9_<go000000?o
bkg=0_o<_/d3olfoc@?ocl7=00?od<;=om33cOoBaLd00_oBaLd2omG;c`08omWBd_oIdm?of=;ComSB
e?oGdM?oem7DomKAe?oEd=@2omC@e@?od/kF00God<gGolo=eoo<bmWobl_Iol[:fP02o`0002;ooooo
000Pooooo`03o`000?oooooooooo00Sooooo00OoX[_[oijik?nN^NcoW[W/oijhjonM]n[oW;K[00;o
VkGZ0_nK]>T01?nK/nSoV[;YoiZaj?nJ/NP2oiZ`i`03oiZ_i_nJ[^GoV:gU00;oV:cT0_nHZn@01?nH
Z^?oV:WRoiNXh_nGYn43oiNVh004oiNUgonGY=koUjCNoiNSgP;oUZ;M0onFXM`01onFX=coUYoKoiJO
fonFW][oUYgIoiBMfOnDW=T00onDVmP2oiBJe`04oiBJe_nDVMKoU9WFoiBHe@;oTYOD00?oTYKCoi:E
donBUM<00onBU=83oi:Cd@;oTY;@00CoTY7?oi:Ac_nAT<ooTHo>0_nASld2oi6>c@;oTHk<1?nASL/0
0onBS<[oU8g9oiB=b@02oijBa`?o[9W300Co[I[3ojnK`on_Vl?o[i_30on_W<@3ok2Ma0;o/Ik50onb
WlD01?nbX<Go/j35ok>Qa_ncXLH3okBRaP06okBSa_neY<Oo]JC7okFTaonfY<Oo]ZG70ongYLL00ong
Y/So^:K8okRWb003o`000004okVXb?niZLWo^ZW8okZZb@Co^j_900?o_:c:okb/bOnm[LX00_nm[LX0
1?nn[/[o_Zo:okn_bono[l/3ol2`b`06ol6aboo1//_o`K;;ol:bboo2/l_o`kC<0_o3]</01?o4]Lco
a;G;olBeboo5]/`3olJgc0;oakS<0oo8^L`02Oo8^/cobK_<olZkc?o:_<cobkc<o`000?o;_Lgoc;g<
olbnc@02olfnc003olfocOo>_lcocl7=00;ocl7=00Cod<;<om33cOoAa<god/G=0_oEbll01?oId];o
fM?ComWCdooHd]@2omOCe003omOAe?oFdMCoeM7E00;oe=3E00Codm3Fom;>e_oAc]OoclgG0_o>c=P0
1?o;bmWob/[Jol[:f_l0000Rooooo`008?ooool00ol0003oooooooooo`09ooooo`04oj6kjonN^Nco
WKW/oifik0;oW;S/00GoW;K[oi^ej_nJ]>_oV[C[oiZcj@02oiZbj@05oiZaj?nH[nOoV:oWoiR_ionH
[^H00_nH[ND01OnH[>CoUj[ToiNZi?nGZ^CoUjWS00;oUjSR00?oUjOQoiNVh?nEY^400_nEYN02oiFT
g`06oiFSg_nFX]goUZ;MoiJQg?nDX=goU9oL0onDW]/01_nDW][oU9gIoiBMfOnDW=WoU9_Hoi:Jf0;o
TY[G00?oTYWGoi:He_nBV=H00_nBUmD2oi:Ge006oi:FdonBUM?oTYGCoi:Dd_nAU=;oTI?A0_nAT]42
oi6Ad005oi6AconAT<ooTI3?oi6@conASlh00_nASld2oi6>c@03oi6>c?nASL_oT8c<00;oT8c;00?o
THc:oi><bOnCS<T00onNT/L2ojbI``;o[Y[30_n_Vl<00on_W<Co/9c3ok2Ma002ok2Ma004ok6Na?na
W/Go/Ik5ok6Na@;o/Yo50_ncX<D00oncXLKo]:75okBQa@02okBRaP;o]J?600?o]JC7okJTa_nfYLL0
0_nfYLL00ongYLOo]jK7okRVb002o`0000;o^JO800Co^JS8okZXb?njZLSo^ZW81?nkZlT3okb/b@?o
_Jg:0onn[lX00ono[l_o`;3:ol2`b`02ol6abP04ol6bboo2//_o`[?;ol:cb`?o`kC;0oo4]L/2olFf
b`?oa[O<0_o7^<`00oo8^Lcob;[<olRjc002olZkc0?obkc<00Co0000olbmc?o=_LcocKk<0_o>_/`0
0oo>_lcocl3<olo1c@02om32c00<om74cOoEb/ooeL[?omG;cooIdm?ofMCDomWCdooHe=Cof=CEomOC
e?oGdmGoe]7D0_oEdMD01_oEdMKoe=3Eom?@e_oBd=KodLkGom3>e`;oc/cH0oo:b]X00ol0003ooooo
ooooo`0Pooooo`008?ooool2o`0000_ooooo0_nP^n`01_nM^NcoVkS]oiZgk?nJ]ncoV[K[oiZdj`;o
V;C[00KoV;?ZoiRbjOnH/^WoV;3XoiR_ionF[nP2oiN^i`;oUjgV00?oUjcUoiNZi?nEZ^@00_nEZN@2
oiFXh`04oiFWh_nEY^7oUJKQoiFUh0;oU:?O0_nDX]h2oiBQgP;oU:3M00CoU9oLoiBNfonBW]_oTYgK
0_nBW=X2oi:Kf@;oTY[H0_nBV]L01?nBVMOoTYSFoi:He_nBUmD2oi6Fe003oi6Ee?nAU=?oTICC00?o
TICB00?oTI?Aoi6BdOnAT]400_nATM001?nATLooTI3?oi2?con@Slh2oi2>cP;oT8k=00CoT8g<oi2<
c?n@S<coT8c<0_n@S</00onAS<[oThc9oi><b@02oijBa`;o[9W30_n^V/<2ojnK``?o/9c300Ko/9g4
ok6Na?naW/Co/Ik4ok6NaOnbWl@2ok:Oa@03ok>PaOncXLGo]:7500;o]:7500Co]:;6okFRa_neX/Ko
]J?60onfY<H00onfYLOo]jG7o`000002o`0000;o^:O700?o^JO8okVXaonjZ<P00_njZ<P01?njZLSo
^jW8ok^[bOnlZlP3okb/b@;o_Jg900Go_Jg:okj^bOnn[/Wo_Zo:okn_b@02ol2`bP?o`K7:0oo2///0
0oo2/l_o`k?;ol>db`02olBdb`03olBeboo5]L_oaKK;00;oa[K;00Koa[O<olNhboo7^<_oakS<olRi
boo8^/`2olVjb`;ob[_<0_o;_<`00ol0003oc;g<olfmc003oljnc005oljoc?o?`<cod<7<om32c?oA
`l`00ooEb/l03OoJe=?ofM?ComWDe?oIeMCof=CDomSDeOoGe=Goem?EomKBe_oEdMGoeM7FomCAe_oC
d=H00_oBd=H02Oo@c]Ood<kHom3>f?o>c=SocLcIol[:f_o9b][oooooo`00000Qooooo`008?ooool0
0ol0003oooooooooo`0;ooooo`;oW[[/00OoVkS]oiZhkOnH]ngoV;O]oiRek?nH]>_oU[?/00;oU[;[
0_nF/NX01?nF/>WoUZoXoiJ_j?nG[^L3oiF/iP04oiF[iOnEZ^CoUJ[ToiFYi0;oTjOS0_nCY^82oi>U
h@04oiBTh?nDXmooU:?OoiBRgP;oTZ7N0_nBWmd2oi:Og0;oTYkK00CoTYgKoi:Lf_nBW=[oTY_I0_nA
V]P2oi6If005oi6HeonAUmKoTIOFoi6Ge_nAUmD00_nAU]@01_nAUMCoTICCoi6DdonAU=;oT9?Boi2B
dP;oT97A0_n@TM001On@T=3oT8o?oi2?con@SlooT8o>00;oT8k>0_n@S/d01_n@SLcoT8c<oi2<c?n@
S<_oSh_;oi2;bP;oTXc90onNT/L00on/VL?o[Y[3ojjJ``03ojnK``;o/9c30_naWL@00onaW/Co/Yk4
ok:Oa002ok:Oa006ok:OaOncXLGo/j75ok>QaOndXLGo]:;50oneX/H2okJSaP06okJTa_l0003o0000
o`000?ngYLOo]jK70onhYlL3okVXa`04okZXb?njZLSo^ZW8ok^Yb0?o_:_800Co_:c9okf/bOnm[<Wo
_Jg90onn[/T3okn_b@;o`;3:0oo1/LX00oo2//_o`[;:ol>cb`02ol>cbP04olBdboo4]<[oaKG;olFe
b`?oa[K;0oo7^</2olRib`04olViboo9^/_ob[[;olZkc0;obk_;00Kobkc<olblbol0003ocKg<olfm
boo>_/`2oljoc0;od<7<00OodL;<om73c?oEb/ooeL[?om[DdooIe]CofMCD00;ofMGD00oof=CEomOD
eOoGe=Goe]CFomKBe_oEd]Koe=;GomCAe_oCdMOod]3Fom;?eooAcmSod<kHolo>f?o=c=T00_o<c=T0
1?o9b][ob<[Kooooool0000Pooooo`008?ooool00ol0003oooooooooo`0<ooooo`;oWK[]00GoV[S]
oiRgk_nG]^goUkK]oiJdk002oiJck005oiJbjonD/>[oU;3ZoiB`j_nD[nT00_nD[^P00onD[NOoUJcV
oi>[i`02oi>ZiP;oTjWU00CoTjSToi>WhonCYn?oTjKR0_nBY>82oi:Sh@;oTZ;P00?oTZ;Ooi:Qg_nB
XMh00_nBWmd01?nBWmcoTIgLoi6Mg?nAW=/3oi6KfP03oi6KfOnAV]SoTI[H00;oTIWH00CoTISGoi6G
e_n@UmKoT9KF0_n@UMD01?n@U=CoT9CCoi2Ddon@U=<2oi2CdP03oi2Bd_n@TM7oT97A00;oT97@00?o
T93@oi2?con?Sll00on?S/h2ohn=c@?oShc<0on?Rl/00on@Rl[oTXc9oi:<b@02oijBa`05ojbI`on^
V/?o[Y[3ojjJ`on_Vl<01?n`W<<01_naWLCo/Yk4ok:Na?nbW/Co/Yo4ok>Oa0;o/j3400?o/j75okBQ
aOndX/D00_ndX/D00oneX/Ko]J?5o`000002o`0000;o]jC600Go]jG7okRUa_nhY/Oo^:K7okRWa`02
okVWa`03okVXaonjZ<Oo^ZW800;o^ZW80_nkZ/P2okb[b0?o_Jc90_nn[LT01onn[/Wo_jk9okn^bOno
[lWo`:o9ol2`b_o1/<T00oo1/LX2ol:bbP?o`k?:0oo4]<X00oo5]L_oa[K;olJfb`02olNgb`03olNh
boo8^<_ob;W;00;obKW;0_o:^//3ol^kb`?oc;c;00Ko0000oljnboo>_/_oc[o<olnoboo@`L`2om72
c0;oeL[?00Sof]KDom[GeOoIe]CofMKEomWEe?oHeMGof=GFomODe@;oe]CF00?oeM;FomCBeooDd]L0
0ooCdML02?oBcmOodLoHom3?f?o?c]Soc/kIolc<fOo<c=[ob<[K0_o8bM/00ol0003oooooooooo`0N
ooooo`007oooool3o`0000kooooo0_nL^Nd01OnH]nkoU;G^oiBek_nD]NkoU;C]00;oU;;/00GoU;7[
oiB`j_nB[n_oTZo[oi:^jP02oi:]j@04oi>/j?nCZnOoTj_Woi>ZiP?oTJSU00CoTJOToi:VhonBY^?o
TZGS0_nBY>800onBXn7oT:;Poi2Rh003oi2Qg`04oi6Pg_nAWmgoTIoMoi6Ng@;oTIgL00CoTIcKoi6K
f_n?Vm[oT9[I0_n@VMT2oi2Hf0;oT9SG0_n@UmH01_n@U]KoT9GEoi2EeOn@U=CoT9CCohnCd`;oSi;C
00?oSi7BohnAdOn?TM400_n?T=001?n?Sm3oSho?ohn?con?Sll3ohn>cP;oShg=0on?S<`2ohn;b`03
oi2;b_nARlWoTH_900;oWY;70_n]VL<00on^V/?o[i_3ok2L``03ok2L``?o/Ig30_nbW/@3ok>Oa005
ok>Pa?ndXLGo]:75okBQaOndX/D00ol000000oneXlGo]Z?6okJSaP02okNTaP?o^:G600Co^:K7okVV
a_niYlOo^ZO70onjZ<L01?njZLSo^jW7ok^Zb?nlZ/P3okb[b003okf/bOnm[<So_Zg900;o_Zg80_no
[/T2ol2_b@?o`K3900Ko`K7:ol:abOo2/LWo`[;:ol>bb_o3/lX2olBcbP06olBdb_o5]<[oaKC:olJf
boo6]/[oakO;0_o7]lX00oo8^<_ob;S:olVib`02olVib`03olZjboo;^/_obk_;00;oc;_;00Goc;c;
olflboo>_/_o0000oljnb`02olnob`05om31c?oA`/coeL[?omG:cooJe]@00_oJemD02OoIe]GofMOF
omWGe_oHemKof=GFomOEeooFe=Koe]CGomGDe`02omCBe`04om?Bf?oCdMOod]7Hom7?f0;od<oH00Wo
c/kIolk=fOo>cMWoc<cJol_<f_o8bM_oalWLooooool000007oooool000Kooooo0_l00004ooooo`04
o`000?ooooooooooooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool04?ooool00onJ
^NgoU[O^oiBekP02oi>dkP06oi:ckOnB/^goT[;]oi:ak?nB[n_oT:o[0_n@[^X2oi6]j@07oi6/j?nA
Z^OoTJ[Woi6Yi_nAZ>GoSjOVoi2Vi@03oi2Ui004oi2Uhon@Y>;oT:CRoi2Sh@;oT:;P00?oT:7OohnP
gon?Wml00_n?W]h2ohnMg@;oSicL00CoSicKohnKf_n?Vm[oT9[I0_n@VMT00on@V=SoT9SGohjGe`02
ohjFe`04ohjEe_n>U=GoSYCEohjDe0?oSi?C0_n?T]<01?n?TM;oSi7AohnAdOn?T=02ohn?d0;oSho?
00?oShk>ohf=c_n=SLh00_n=S<d00on>S<goSX_<ohj;c002ohj;b`;oSh_;0_nARlT2oijBa`06ojfI
`on_Vl?o[i_3ojnK`on`W<?o/Ic31?naWL<3ok:Na0;o/io40_ndX<@3o`0000;o]J;500Co]J?5okJS
aOnfXlGo]Z?60ongY<H01?nhYLKo^:K6okVVa_niY/H3okZWa`04okZXaonkZ<Oo^jW7ok^Ya`?o_:[8
00Co_:_8okf[b?nmZlSo_Jc80onn[LP3okn^b@03ol2_bOo1[lWo`K3900;o`[3900Co`[79ol>abOo3
/LWo`k;:0oo4/lX3olFdbP;oa[K:0oo7]lX2olRhbP?obKW;00Cob[W:ol^jboo;^/[oc;_;0_o<_<X0
0oo=_<_ocKg;o`000002olnob`;od<7<0_oEb/l01_oJemCof]SEom[GeOoJf=KofMSFomWGeP;of=OF
00CoemGGomKEeooFeMOoe]CG0_oDdmP02ooDd]Oodm;Hom;BfOoBdMSodM7Hom3?f?o@cmWocloIolk=
fOo=cM[oblcJ00;ob/_K00CoalWLolK9g?l0003o00007_ooool000Gooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Aooooo`05oiVik_nD]^ooU;K_oi>dk_nA]>l00_n@/^h01On@/NgoT;3/oi2_
jon@[n_oT:kZ00?oSjcY00CoSj_YohnYj?n?ZNSoSjSW0_n?YnH01?n@Y^GoT:GTohjUi?n>Y><3ohjS
hP03ohnRhOn?XN7oSj7Q00;oSj3O00CoSioOohnNg_n?W]koSigM0_n>W=`01?n>Vm_oSY[KohjJfon>
VMX3ohjHf@03ohjHf?n>UmOoSYOG00;oSYKG00KoSYGFohjDeOn>U=GoSYCDohnCdon=T]@2ohfAd`04
ohfAd_n=T=7oSI3Aohf?d@;oSHo@1?n=S/l2ohf=cP;oSHc=00?oSXc=ohj;c?n>Rl`00_n>Rl/01On?
Rl_oTH_9oi6;bOnNT/OoWY7700;o[Y[300?o[i_3ok2K`_naW<<00_naW<<01onaWL?o/Yg3ok:N`onb
W/?o/Yk4ok>O`oncWl@00ol00003okFQa003okFRaOnfX/Go]Z?500;o]Z?50_ngY<D00ongY<Ko^:G6
okRVaP02okRVaP04okVVa_niYlKo^ZO7okZWaP?o^jS700Co^jW7okbYaonlZ/So_J_70onmZlP2okj/
b004okj]b?no[LSo_jg8okn^b@;o`:k800Co`Jo9ol:`bOo2/<Wo`[390oo3/LT2olBbb@06olBcb_o5
]<WoaKC9olFdb_o6]LWoa[K:0_o7]/X01_o7]l[ob;O:olRgb_o8^<[obKS:olVib`;ob[W:0_o;^/X3
olblbP06olfmboo>_/_oc[k;o`000?o@`<_od<7<0_oEb/l04?oKf=Cof]ODom[HeOoJfMKof]SFomWH
e_oHf=Oof=OFomOGeooGemSoe]GGomKEf?oEeMSoe=?Hom?Cf?oCd]P2om;Bf@0;om7Af?o@d=Wod=3I
om3?fOo?cmWoc/oJolg=f_o<cM[ob/_KolW;foo6bM`00_o6bMd00ol0003oooooooooo`0Looooo`00
1Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool2o`0001?ooooo00CoV;S^oi:fkonB]^ooTKC_0on>/Nh01on>/>koSZo]ohj_kOn>[^co
SZg[ohn/jOn=ZnX00_n=Z^T2ohfYj004ohfXion>YnKoSZOVohjVi@;oSZGT00?oSZCSohjSh_n=X^<0
0_n=XN801On=X>7oSIoPohfOh?n=Wn3oSIkO00;oSIgN00CoSYcMohjLg?n>W=coSY_K0_n>V]/01?n>
VM[oSYSIohfHfOn=UmP2ohfFf0;oSIGG00?oSICFohfDeOn=U=D00_n=Tm@2ohfBe0;oSI7C00CoSI7B
ohf@dOn=T=7oSHoA0_n=Sm03ohf>c`;oS8c>0_n<S<d00on<RlgoS8_<ohb;c002ohf:b`03ohj:bon@
Rl[oT8_:00?oWY7700Ko[Y[3ok2K`_n`Vl;o/9_2ok6L`onaW<83ok:M``06ok:N`oncWl?o0000o`00
0?ncWlCo]:330_ndXL@2okFQa0?o]Z;500Co]Z?5okNSaOngY<Go]jC50onhYLH01?nhY/Ko^JK6okVW
a_niYlH3okZWaP04ok^XaonkZLOo_:W7okbYa`?o_J_700Co_J_8okj/aonn[<Oo_Zc80ono[LP3ol2^
b0;o`Jo800Co`[39ol:abOo2/LWo`k790_o3//T00oo4//Woa;?9olFdb@02olFdb@;oa[G900KoakK:
olNfbOo7]/Wob;O:olRgbOo9^<X2olVhb@03olZib_o;^L[obk[:00;oc;_:00?oc;c:olflb_o>_//0
0_o>_//01?o?_l_o0000omC9cooEb/l2om_He004om[HeOoJfMKof]WFomWHeP;of=SG00Wof=SHomOG
eooGemSoe]OHomKEf?oEeMSoe=GIom?Cf?oCdmT00_oBd]T01?oAd][od=3Iom3@f_o?cmT2olk?fP09
olg?f_o<cM[oblgKolW;foo8bmcoa/WMolG9gOoooooo000001gooooo0005ooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01?ooooo00GoU[S_oi2ekon@]NooS[?_ohjakP02ohbak`04oh^_k_n<[^goS:k]ohb]k0;o
S:c[00CoSJ_ZohfZjOn=Z^WoSJWX0_n;YnL2ohbViP04ohbUiOn<Y>GoS:CUohbSi0;oSJ;S0_n=XN80
1?n=X>7oSIoPoh^Nh?n<WMl2ohbMgP03ohbLgOn<VmgoS9_M00;oS9[L0_n<VM/01?n<V=[oSISIohfH
fOn=UmP2ohfFf0;oSIGG00CoSICFohfDeOn=U=GoSI?D0_n<TM@2ohbAd`04ohb@d_n<Sm;oS8oBohb?
d@;oS8k@1?n<SLl2ohb<cP;oS8c=00?oS8_=ohb;c?n<Rl`00_n=R//01On>R/_oT8_:oi2;b_nNTLOo
WI7700;o[Y[20_n`Vl83ok6L`P06ok:M`ol0003o0000o`000?ncWl?o]9o30ondX<<01_ndXLCo]J74
okFQa?neXLCo]Z;5okJRa0;o]j?500Go]jC5okRTaOnhY<Go^:G6okVUa@03okVVaP04okVWa_njYlKo
^ZO6ok^XaP?o^jW700Co_:W7okbZaonmZlOo_J_70onn[<L3okn]b0?o`:k80oo1[lP00oo2/<So`[79
ol>ab003ol>bb@;oa;?90oo5]<T2olJeb@?oakK90_o8]lT3olVhb@;obkW:00Oobk[9olbkb_o<^lWo
c;_9olflb_o>_L[oc[k;00;ocko;013o0000omC9cooKfMGofmSDom_Ie_oJf]Oof]WFom[IeooIfMOo
f=SGomSHf?oGf=SoemOHomKGf?oEe]WoeMGH0_oDeMT02OoCdmWod]?Jom;Cf_oBd]WodM;Jom3Bf_o@
d=[ocm3Jolk?fP02olg?fP?oblgK0_o8bm`01?o5bMgoa<SMooooool0000Looooo`001Oooool01?l0
003oooooooooool00007ooooo`06o`000?ooooooooooooooool0003ooooo1?l00005ooooo`03o`00
0?oooooooooo01Cooooo00KoUKO_ohjdl?n>]?3oS;;`ohbakon9/>l2ohV^kP;oRJg]00CoRZc/ohZ[
jon:Zn_oRZ[[0_n;ZNT01?n;Z>SoRjOWoh^Wion<Y^H2ohZTiP05ohZSiOn;X^CoRj;Toh^Ri?n;XN<0
0_n;X>801?n;Wn7oRikPoh^Nh?n<WMl2ohbMgP04ohbLgOn<VmgoS9_MohbJg0;oRiSK00CoRiSJoh^G
fOn;UmWoRiKI0_n;UMP2oh^De`;oRiCF0_n<TmH00on<T]CoS97DohbAe002ohbAd`04ohb@d_n<Sm;o
S8oBohb?d@;oS8k@0on<SLl2ohb<cP03ohb<cOn;RlkoRh[=00;oRh[<0_n<RL`00on=RL_oSh[:ohn:
bP03oifAa`04ojjJ`_n`Vl;o/9_2ok2K`P?o000000?o/Yg2ok>N`oncW/<00ondWl<00ondX<?o]J33
okFQa002okFQa0Co]Z;400Co]j?5okRTaOnhY<Go^:C50oniYLD01?niY/Ko^ZK5okZWa_njYlH3ok^X
aP04ok^YaonlZLKo_:W6okbZa`?o_J_70onn[<L01?no[LSo_jg7ol2^b?o0[/L3ol6_b0;o`[380oo3
/LP00oo3//Woa;;8olBcb@02olFcb006olFdbOo6]<Woa[C9olJebOo7]LWoakK90_o8]/T00oo8]lWo
bKO9olVhb@02olZib@03ol^ib_o;^/Woc;_900;oc;_900CocKc9oljmb_o?_/[ocko;0_oDbLl01?l0
003ofm[Fom_Je_oJf]L2om[Ke`0:omWKf?oIfMOof=WHomSIfOoGf=Soe]SIomKHf_oEe]Woe=KJomCE
f@;odmGJ00Cod]?Jom7Cf_oAdm[od=;J0_o?dM/02_o?d=[oc]3Kolg?f_o=c]_oc<kKol_=foo:c=co
b<_LolO;gOo4b=d2ol?8gP03o`000?oooooooooo01[ooooo0005ooooo`04o`000?ooooooooooo`00
00Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo0_l0000Gooooo`04oi>gkon<
/o3oS;?`ohZal0;oRK3_00GoRJk^ohN/k_n7[>koQjc^ohN[k@02ohRZk004ohRYjon8Z>[oR:SZohVW
j@;oRJKX00OoRJGWohZTi_n:Y>KoRZ?Uoh^Ri?n8XNCoRJ3S00;oRIoR00GoRIkRohVMhOn9WN7oRIgQ
ohZMg`02ohZLg`04ohZKg_n:V]goRY[Moh^Ig0;oRiSK00CoRiSJoh^GfOn;UmWoRiKI0_n;UMP2oh^D
e`04oh^De_n:T]KoRY;FohZAe@;oRY7D0_n:T=<01?n:Sm;oRhoBoh^?d_n;S]44oh^=d003oh^<con;
S<koRhc>00?oRh_>00?oRh[=oh^:c?n;R/`00_n<RL`00on=RL_oSh[:ohn:bP02oifAa`05ojjJ`_l0
003o0000o`000?naW<800onbWL83ok>N``;o]9o30oneX<<00oneXLCo]Z;4okJRa002okJRa003okNS
a?ngXlGo]j?500?o^:C50_niYLD2okZVa@05okZWa_nkYlKo^jO6ok^Xa_nlZ<H00onlZLH2okfZaP05
okf[aonnZlOo_Z_7okj/aono[<L00_no[LL3ol2^a`;o`Jo80oo2/<P3ol>ab0;oa;;80oo5/lP00oo6
]<Woa[C8olNeb@02olNeb006olRfbOo8]/Sob;K8olVgbOo9^<Wob[W90_o;^LT00oo;^/Woc;[9olbk
b@02olflb@;ockk:0_oDbLl01_oKf]GofmcFo`000?oKfmOof]cHom[Ke`;ofM_H00Cof=WHomSIfOoH
fMWoe]SI0_oFf=X3omCFfP;odmGJ00Cod]CKom7Cf_oAdm_od=?K0_o?dM/01?o>d=_ocM3Kolg@foo<
c]/2ol_>g004ol[<g?o9c=coal_MolK:g@;o`lSN00?oooooo`000?ooool06_ooool000Kooooo0_l0
0009ooooo`?o00000_ooool5o`0000?ooooo00?o0000ooooooooool05oooool2oi:fl008ohZclOn8
/?3oQjo`ohN_l?n7[^ooQjc^ohB[k_n5Z^d3ohFYk004ohJXjon6Yn[oQZOZohNVj@;oQjGX00CoQjCW
ohRSi_n8XnKoR:;U0_n8XN@01on9X>?oRIoRohVOh_n9W^;oRIgQohRMhOn8W>000_n8Vml01?n8V]ko
RIWMohVIgOn9V=`2ohVHf`03ohVGfon9U][oRIKJ00;oRIGI0_n9U=P2ohZDe`04ohZCe_n:T]KoRY;F
ohZAe@;oRY7D0_n:T=<01?n:Sm;oRhoBoh^?d_n;S]44oh^=d003oh^<con;S<koRhc>00;oRh_>00?o
Rh[=oh^:c?n:RL`00_n:R<`00on<RL_oSXW:ohj9bP03o`000003ojnJ`_n`Vl;o/Ic200Co/Yg20onc
W/<3okBO``;o]J330_nfXL<00onfX/Co]j;4okNSa002okNSa004okNSaOnhY<Go^:C5okRTa@?o^JG5
00Co^ZK5ok^Wa_nkYlKo^jO60onlZ<H01?nlZLKo_JW6okfZa_nnZ/H3okj[a`;o_jc700Co_jg7ol2]
aoo0[LOo`:k70_o1[/L01?o1[lSo`[38ol:`b?o2/<P3ol>ab0;oa;;80oo5/lP2olJdb0?oakG80oo8
]/P2olVhb@?obkW900Coc;[9olfkbOo=^lWocKc90_o?_/X2omC9c`05omcKe_oKf]GofmcFom_Meol0
00000_oJg=P02_oIfmSofM_IomSKfOoHfMWoemWIomKIf_oFf=[oeMSJomCHfooDe]X2om?Ff`0>om;D
fooAe=_odMCKom7Cfoo@dm_ocm?LoloAfoo>dMcocM3Kolg@g?o<cmgoblkLol[>gOo9c=`2olS<g@04
olK:gOo5b]ko`lSNol;8g`;o00006_ooool001kooooo0_l0000Iooooo`;oT;K`00GoR;;aohF`lOn4
[_3oQ:k`ohB]k`02ohB[kP04ohFZkOn5ZNcoPjS]ohBWk0;oQ:K[0_n5YNT2ohFTj004ohFSion6X^Ko
QZ;VohJQiP;oQZ3U00CoQioTohNNhon7W^?oQikR0_n8WN401?n8W>3oR9_OohRKgon8V]h2ohVIg@04
ohVHg?n9V=_oRISKohVGf`;oRIKJ00?oRIGIohRDf?n8U=P00_n8TmL01?n8T]OoR97FohRAe_n8TMD2
ohV@e0?oRHoC0_n9S]800on9SM7oRHg@ohV=d002ohV<d003ohV;con9RlkoRH_>00;oRH[>00GoRXW=
ohZ9c?n:RLcoRXW<ohZ8c003o`000004ohj9b_nMTLOoWI77ojnJ`P?o/Ic20_nbWL82ok>N`P03ok>N
`ondWl;o]9o300;o]9o300Co]J33okJP`onfX<?o]Z730ongX/@01OngXlCo^:?4okRTa?nhY<Co^:C5
00;o^JG400Go^JG5okZVaOnjY/Go^ZK5ok^WaP02ok^Wa@04okbXa_nlZ<Go_JW6okfYaP?o_Z[600Co
_Z_7okj[a_nnZlKo_jc70oo0[LL3ol6^a`;o`Zo700Co`[38ol>`aoo3/<Oo`k780_o4/LP00oo4//So
aK;8olFcb002olJcb003olJdb?o7]<SoakG800?ob;K800KobKO8olVhbOo:^<Sob[S8ol^ibOo;^LP3
olfkb@;ockk:0_oDbLl2omcKeP05om_Le_oKgMOofmgGo`000?oJg=P00_oIg=T01?oIfmWoem_JomOK
f_oGfMT2omKIf`0<omGHf_oDf=_odmSKom?FfooBe]_odMKLom7Dfoo@e=cod=?KoloCg?o>dmgoc]7L
0_o=dMd01oo=d=coc<oMol_?gOo:c]gobLkMolS<gOo7c=d00_o5b]h01?o2b=oo`LOOol77gol00008
ooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`007_ooool00ol0003oooooooooo`0Ioooo
o`;oS[G`00GoQ[7aoh>_lOn3[o7oPZg`oh:/k`02oh:Zk`04oh>Yk_n3Z>goPjS]ohBWk0;oQ:K[00Co
QJGYoh>SjOn3XnWoPj;X0_n4XNL01?n4X>KoQ9oUohBOiOn5W^@2ohFNh`05ohFMh_n6W>7oQYcQohJL
hOn6Vn000_n6V]l01?n7VMkoQiSMohNHgOn7V=`2ohNGg004ohNFfon8UM[oR9GJohRDf@;oR9CH0_n8
TmL01?n8T]OoR97FohRAe_n8TMD2ohV@e0?oRHoC0_n9S]800on9SM7oRHg@ohV=d002ohV<d003ohV;
con9RlkoRH_>00;oRH[>00SoRXW=o`000?l0003o0000ohZ8c?n<RL_oSXW:ohf9bP;oWI770_n_V/82
ok6L`P?o/Yg200Ko/ik2okBO`_ndWl;o]9o2okBO`oneX<<3okJP``;o]Z7300?o]j;4okNR`onhXl@0
0_nhXl@01?nhY<Co^JG4okVUa?niYL@4okZVa@?o^jO50onlZ<D2okfYaP03okjZa_nnZlKo_Z_600;o
_Z_60_no[<H01?o0[LOo`Jg7ol6]aoo1[/L2ol:^a`03ol:_aoo3[lOo`k3700;oa;3700Coa;78olFa
aoo5//SoaK;80oo6/lP2olNdb0?ob;K80_o9]lP01oo:]lSob[S8ol^hb?o;^<SobkW8olbjbOo=^lT0
0_o>_LT02oo?_/[oe<W?omcLe_oLfmKog=gGomcNf?oKgMOofmgHom[MfOl0003ofMcI00;of=cJ00Co
em_JomOKfooFfm_oe]WK0_oEfM/01?oCf=_odmOLom?Gg?oBe]/2om7Fg@0;om3Dg?o?e=gocmCMolkC
gOo=d]gocM7MolcAgOo<cmgobloMol[?g_o9c]d00_o8cMh02?o7c=goa/cNolG:g_o4bMko`LOOol37
gooooooo00002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool001kooooo00?o0000ooooooooool06_ooool2ohfdl@05ohB`l_n1
[_7oPJkaogn/lOmoZo000_moZNl01?n0Z>koPJO]oh6WkOn1Y^`2oh:Uj`04oh:Tj_n3XnWoPj?Yoh>R
j0;oQ:7W00CoQ:3VohBOiOn4WnGoQIkT0_n5W^<01?n5WN;oQYcQohBKhOn4V^02ohBIg`?oQISN00Co
QIOMohFFg?n5U]coQYGK0_n6U=X00on6U=WoQY?HohJCf002ohNBf004ohNAeon7TMKoQi7FohN@e@Co
QhoD00CoQhkCohR=d_n8SM;oR8gA0_n8S=42ohR;d004ohR;con8R/ooR8[?ohR9cP;o00000_n8R<d2
ohV8c004ohZ8bon=RL[oSHW:ohf9bP;oWI7700Ko[i[2ok6L`_naW<;o/Ic2ok:M`_ncWL82okBN`P03
okBO`_neWl;o]J3300;o]J3300Co]Z33okJQ`onfXL?o]Z730ongX/<2okRSa0;o^JC400Go^JG4okZU
a?njYLCo^ZK5ok^Va003ok^Wa@?o_:S500?o_JW5okfYa_nmZLH01?nnZlH3okn/aP03ol2]a_o1[LOo
`Jk600?o`Zk70_o3[lL3olB`a`;oaK7700CoaK;8olJbaoo6//Ooa[?80_o7/lL00oo7]<Sob;G8olRf
b002olVfb003olVgb?o:]lSobkS800;obkS80_o<^/T00oo>_<Woc[g9omC9c`02omC9c`;og=kG00Oo
g=kHom_OfOoKgmWofmoIom[MfOoIgM[o000000;of=cJ00coemcKomOKfooFfm_oeM[LomGIfooDfMco
dmWMom?Gg?oBemgodMOMom7FgOo@e]d3oloDg@0;olgBgOo=d]kocM;NolcAgOo;dMkob]3Nol[?g_o9
cmkob<gNolO=g_o6c=h00_o5bmh01_o4bMko`lWOol37gonoan3oooooo`0000Oooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo000N
ooooo`;o00007?ooool2oh^dl@04oh6_l_mn[O;oOZgbogf[l@;oO:W`00GoOJS_ogfWk_mnY^goOZK]
ognUk002ognTj`04oh2Sj_n1X^WoPJ;Yoh6Qj0;oPZ3W00CoPYoVoh:NiOn2W^GoPikT0_n3WN<01?n3
W>;oQ9_QohBKhOn4V^02ohBIg`?oQISN00CoQIOMohFFg?n5U]coQYGK0_n6U=X00on6U=WoQY?HohJC
f002ohNBf004ohNAeon7TMKoQi7FohN@e@CoQhoD00CoQhkCohR=d_n8SM;oR8gA0_n8S=42ohR;d0?o
00000_n8RLh00on8RLgoR8S=ohR8c@02ohV8c003ohZ8bon=RL[oSHW:00;oWI770_n`Vl800onaW<;o
/Yc2ok>M`P02ok>M`P06okBN`_neWl;o]Io2okFO`_neX<?o]Z320onfXL<3okNR``05okRS`onhXlCo
^:?4okRSa?niY<@00onjYL@3ok^Va004ok^WaOnlYlGo_:S5okbXa@?o_JW500?o_JW6okjZaOnnZlH0
0_noZlH01?no[<Ko`:c6ol2]a_o0[LH3ol6^aP06ol:^aoo2[lKo`Zo6ol>_aoo3/<Ooa;370_o4/LL0
0oo5/LOoaK;7olJba`02olJca`03olNcaoo7]<Oob;G800;ob;G700KobKK8olVfaoo9]/Oob[O8ol^g
b?o;^<P2olbib009olbjbOo>_<Woe<S?omC9cooLgMKogMoHomcNeooLgmSog>3I00?ofmoI0_oIgMX0
0ooHgM_o0000omOLf`02omKLg004omKKfooDf]goe=[MomCIg0;od]WM00_od]OMom7GgOo@emkod=KM
oloFg_o?e=goc]CNolgDgoo=d]koc=;Nol_AgP02ol[@gP09olW?g_o8cmoob<oOolO=g_o7cMooaL_N
olG;goo3bMoo`/WO00?o_lOP00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool001kooooo00?o0000oooo
ooooool07?ooool2ohVcl@04ogn^l_mk[?;oNjcbogZYl@;oNZS`00GoNZO_og^Vk_mlYNgoO:G]ogbT
k002ogfSj`04ogfRj_mnXNWoOZ7YognPj0;oOioW00CoP9kVoh2MiOn0WNGoPIgT0_n1W><01?n1Vn?o
PY[Roh:Jh_n2VN42oh>Hh0;oPiON00CoQ9KMohBEg?n4UMcoQ9CK0on4TmX2ohFBf@;oQI7H00CoQI7G
ohF@e_n5T=KoQHoE1?n6S]@01On6SM?oQXgBohJ=d_n6S=;oQX_A00?o000000?oQh[?ohN9con7RLl0
0_n7RLh3ohN8c@;oR8O<00?oRHO;ohb8b_n<R<X00onMTLL01_n`Vl;o/Yc2ok:L`_nbW<;o/ig2okBM
`@;o]9k200?o]Io2okJO`_nfX<800_nfX<801?nfXL?o]j;3okNR`ongX/<3okRS``04okRSa?niY<?o
^JC4okVTa0?o^ZG40_nkY/@2okbWa@?o_:S50onmZLD01?nnZ/Go_j_6okn[a_noZlH3ol2/aP03ol2]
a_o1[LKo`Jk600;o`Zk600Co`Zo6ol>_a_o3/<Oo`k370oo4/LL2olFba`?oa[?70_o7]<L3olRea`?o
bKK70_o;]lP01?o;^<Soc;W8olfkbOo>_<T2omC8c`09omgNeooLgMKogMoHomcQfOoLgmSog>3Iom_P
f_oKgmWof]oJ00;ofMoK00oof=gKo`000?oGgMcoe]cLomKLgOoEg=goe=[Mom?JgOoCf]kod]WMom7I
g_oAemgod=ONoloGgoo?e]h00_o>e]l02oo=e=ooc=COolcDgoo<d]kobm;Ool[@g_o9d=oob=3PolS?
goo7c]ooalgO00;oa/gO00SoaL_OolC;goo2bMoo`LWPoko7h?nna^7oooooo`0000Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
000Mooooo`03o`000?oooooooooo01oooooo00GoR;;bogb]lomhZ_;oN:[bogNXl@02ogNWl@05ogNV
l?mhYNooNJC^ogVTk_mjXnd00_mjX^`2ogbPj@04ogbOjOmmW^SoOIkXogfMi`;oOYcV00CoOYcUognK
i?moVnCoOi[S0_n0VN801?n0V>7oPIOPoh6Gh?n1Uml2oh>GgP04ohBFgOn4UMcoQ9GLohBDf`?oQ9?J
0_n5T]T2ohFAf004ohFAeon5T=KoQI3FohF?e@?oQXkD0_n6SM<3o`0000;oQX_A0_n6Rm001?n7R/oo
QhW?ohN9con7RLh4ohN8c@03ohR7c?n9Ql_oRHO;00;oS8S:0_nMTLL2ok2K`P;o/Yc20ondWL401?nd
W/;o]Yo2okJO`_nfWl82okJP`P;o]j7200?o]j;3okRR`onhX/<00_nhXl<2okVT``03okVTa?njYL?o
^ZG400;o^ZG40onkY/@01?nlYlGo_:O4okbXaOnmZ<@3okfYa@;o_Z[500Go_j_6okn[aOnoZlGo`:c6
ol2/a@02ol6]aP?o`Zk60_o3[lH01?o3/<Ooa;36olB`a_o4/LL2olFaaP03olFbaoo6//Koa[?700;o
ak?700?oakC7olRdaoo8]LL00_o9]LL00oo9]/Oob[O7ol^gb002ol^hb0;ocK_900Koe<S>omC8cooM
g]OogMkGomgOf?oLhMT2omcRf@03om_Pf_oJh=[of^3J00?ofMoK00Gof=oLomOMg?l0003oe]gMomKL
g@02omCLgP06om?JgOoCf]kod][Oom7Ig_oAfMood=WO0_o?eml01_o>e]oocMGOolgEh?o<e=oobm?P
ol_Bg`;ob];P0oo8d>001oo7c]ooa/kPolK=goo5c>3oa<_Ool?;h?o1bN000_o0b>401?nna^7o_LKQ
o`000?l00004ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo000Mooooo`?o00008?ooool01On6/_;oNZccogJYl_mfZO;oM:Ob00;oM:Ka00CoM:G`
ogJTkomfXnkoMj;]0_mhXN`01?miX>_oO:3YogbPjOmlWnT2ogfNj004ogfMiomnW>KoOYcVogjLi@;o
Oi_T00CoOi[Soh2Ih_n0VN;oP9SQ0_n1Un001?n1UmooPIKNoh6Fg_n2UMd2oh:Dg004oh:Cfon3Tm[o
Pi?Joh>BfP;oPi7I0_n3T=P2ohB?eP03ohB>e_n4S]GoQ8kE00?o00000_n5S=800on5Rm;oQH[AohF:
d@02ohF:d004ohF9con5R<ooQHS?ohF8cPCoQXO=00?oQXK<ohR7bon8Ql/00_n;R<X2oifAa`;o/9_2
00?o/Yc2ok>L`OncW<400_ndWL42okFO`@;o]Yo20onfX<801OngXL;o^:;3okRR`onhX/?o^:?300;o
^J?300Go^JC3okZU`onjYL?o^ZG3okZUa002ok^Ua004ok^Va?nlY/Co_:O4okbWa0?o_JS400Co_JW5
okjYaOnnZ/Go_j[50onoZlD2ol2/a@?o`Jg60oo2[/H2ol>_aP?oa;360_o5/LH3olJbaP06olNcaoo7
/lKoak?6olRdaoo8]<KobKG70_o9]/L00oo:]lOobkS7ol^hb002olfjb00MolfkbOoDb<kogMoGomgN
eooMhMSogN;IomcSf_oLh]Wofn;Jom_RfooJh=[of^3KomWPg?oIgm_of=oLomOOgOoFgmkoe]gMo`00
0?oDgMkoe=cNom?LgooCf]kod][Oom7JgooAfMood=WOoloHh?o?eml00_o>en002oo=eN3oc=GQolcE
hOo;dn3ob]?Qol[Bh?o9dN7ob=7QolS@h?o7d>7oa/kP00;oaLkQ00OoaLcPolC<hOo3bn3o`/[Qol38
hOnob>7o_LKQ00;o_<KR00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o0000
1?ooool2o`0000?ooooo000:ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Ooo
ool00ol0003oooooooooo`0Qooooo`05ohBal_mgZo?oLjSbog>Xl_maY_800_maY?42og>Rk`05og>Q
k_mgX^goN:7/ogRQk?miX>/00_miWnX01?mjW^WoNigXog^Mj?mkW>L2ogbKiP04ogbKiOmmV^CoOI[T
ogfIh`;oOYSR00?oOYOQogjFh?moU]l00_moUMh01?n0U=goP9?Loh2Cg?n0T]`2oh6Bf`03oh6Af_n1
T=WoPI3I00;oPY3H00?oPXoGohB?e_l000000_l000001?n4S]GoQ8gDohB<don4S=<2ohF<dP03ohF;
d_n5R]7oQH[A00;oQH[@00CoQHW?ohF8con5R<ooQHS>1?n6Qld00on6Q/coR8O;ohR7b`02oh^8bP03
oifAaon`Vl;o/I_100?o/ic100Co]9g1okBN`OndW/7o]Io10onfWl801_nfX<;o]j72okNQ`_ngXL;o
^:;3okRR`P?o^J?30_njY<<2okZU``?o^jG40_nlY/@01OnlYlCo_JO4okfWa?nmZ<Co_ZS400;o_ZW5
0onoZ/D01onoZlGo`:_5ol2[aOo0[<Go`Jc5ol6]a_o2[LD00oo2[/H2ol>_aP?oa;360_o5/LH3olJb
aP?oak?60_o8]<H3olVfa`;obkS70oo=^/P2omC8cP03omgOeooMh]SogN7H00;og>?J00Wog>?Kom_R
f_oJh]cof^;LomWRg?oIh=cof>3MomOPgOoGgmd00_oFgmh04Ol0003oe=gNom?MgooCg=ood]cOom7L
h?oAf]ood=[PoloJhOo?f>3oc]SQolkGh?o=en7oc=ORolcEhOo;eN7ob]?Q00;obM?Q00[ob=7QolOA
h_o7dN;oam3QolK?h_o5c^7oa<kQolC<hOo3c>7o`/[Q0_o1b^401_nob>7o_/SRokc6h_nka^;ooooo
o`0001Gooooo0009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo02;ooooo00GoP[3cogBZlom`Y_?oL:KcofjTlP02ofjSl@;oLj;_
00GoLj7^ogBQkOmeWncoMIo/ogJOj`02ogNNjP04ogNMjOmhW>SoN9cXogVKi`;oNI[V0_mkVN@01?mk
V>?oO9ORogbGh_mlU^42ogbFh004ognFgomoUMkoOiGNoh2Dg@;oP9?L00CoP9;Loh6Bfon1T]_oPI7J
0_n1T=T3o`0000;oPXkG00?oPXgFoh>=eOn3S=@00_n3S=<2oh>;dP03oh>:d_n3RM7oPhWA00;oQ8W@
00?oQ8S@ohB8con4R<l00on4Qlh2ohF6c@03ohF6c?n7Q/_oQhK;00;oRXO;00KoWI77ok6K`OnaVl7o
/I_1ok>L`OncWL43okBN`@04okFO`OnfWl7o]Yo2okJO`PCo]j720onhX/83okVS``05okZT`onjYL?o
^ZG3okZU`onkYL@00_nkY/<01?nlY/Co_JO4okfWa?nmYl@3okjXa004okjYaOnoZLCo_j[5ol2[a0?o
`:_50_o1[<D3ol:]a@06ol:^a_o3[/Go`jk5ol>_a_o4[lGoa;360_o5/<H00oo5/LKoa[76olJbaP02
olNbaP03olNca_o8/lKob;C600;obKG600CobKK7ol^gaoo;]lOobkS70_o=^/P2omC8cP09omgOeooM
h]SogNCIomgTf_oLhm[og>?Kom_SfooJhmcof^;L00;ofN;L00?of>3MomOPgOoGh=h00_oFgmh02ooE
gmooe=gNo`000?oCgN3od]cOom7Lh?o@g>7od=[PoloJhOo>f^;oc]SQ00;ocMSR00_oc=ORol_Fh_o;
e^;obmGQol[Dh_o9dn7ob=?RolOCh_o7dN;oa]7RolK?hP02olG?hP07olC>hOo3cN;o`lcQol;<h_o1
bn;o`<WRoko9hP02okg7hP;o^lGR00?o0000ooooooooool04oooool000Wooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`02ooooo`;o00009?ooool01on0/??oLZScoffUlom]YO?o
Jj?bof^QlOm[X?000_m`XNl01OmaX>koLIo]og:Nk?mbW^coLig[00;oM9gZ00?oMIcYogJKj?mfV^L0
0_mgVNH01?mhV>GoNiWTog^Ii?mkV><2ogbGhP04ogbFhOmlU^3oO9KPogfDg`;oOICN00?oOY?MogjB
gOmnT]d00_moTM/3o`000003oh2?f?n0S]SoP8kH00;oP8gG00CoPHgFoh6<eOn1S=GoPhcD0_n3S=<2
oh>;dP04oh>:d_n3RM7oPhWAohB9d0;oQ8S@0_n4R<l3ohB7cP;oQHK=00?oQHK<ohN6bon7Q//00_n:
Ql/00onMTLOo/I_1ok6L`@03ok>M`@05okBN`OneW/7o]Yo1okJO`OnfWl800_ngX<400ongXL;o^:72
okRR`P02okRR`P04okVS`_niXl?o^J?3okVS``;o^ZC300?o^ZG3ok^U`onkY/<00_nkY/<2okbWa005
okfWa?nmZ<Co_JS4okjXa?nnZL@00_noZL@3ol2[a006ol2[aOo1ZlGo`J_5ol6/aOo2[<Go`Zg50_o3
[LD01?o3[/Goa:k5olB_aOo4[lD3olF`aP;oa[760oo7//H2olRcaP?obKG60oo;]lL07_o=^/Soe<S>
omC8c_oDb<kogN7GomkSfOoMiM[ogNCIomgTf_oLi=_ofnGLom_SfooJhmcof^?MomWRg?oHh]gof>;N
omORgooGh=koe^3OomGPgooEgmooe=oPom?OhOl0003od]gQom7MhOo@g>7od=_RoloKhP;oc][R00Wo
cMSRolcHh_o;f>?obmKRol[Fhoo:e>;obMCSolSDhoo7dn800_o6d^<02_o6dN;oaM7SolG?h_o4cn?o
`lgRol;=h_o1cN?o`L_Rol3;honobN82okk9h`05okg7h_nlan?o^/GSok[5hol000005?ooool000Wo
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Cooooo00OoOZocofnWlom_Yo?oJZCcofRQl_mWX?7oJj3`00;oKIo_00OoKYo^ofnNkOm`WNcoL9g/
og6LjomaVn[oLY[Y00;oLi[X00CoMY[WogNIi_mgVNKoN9SU0_mhV>@01OmiUn?oNIKRogVFh_mjUN7o
NYCQ00?oNi?O00?oO9;NogbAgOmlTMd00_l000001OmoTM_oOi3Jogn?fOmoSmWoP8oH00;oP8kH0_n0
SML00on1SMKoPHcEoh6<e@02oh6;d`;oPX[C00?oPXWBoh:9dOn2RM400on2R=02oh>7c`?oPhK>0_n3
QLd00on4QLcoQXG<ohJ5c002ohZ7b`06oifAaonaW<7o/Ic1ok6L`OncWL7o]9g10oneW/401?nfWl7o
]j31okNP`OngX<43okRQ`P05okRR`_niXl;o^J?2okVS`_niXl<00_njXl801OnjY<?o^jG3ok^U`onk
YL?o^jK300;o_:K300Co_:O4okfXa?nmZ<Co_JS40onnZL@00onoZLCo_j[4ol2[a002ol2[a004ol6[
aOo1[<Co`Zc5ol:/a@?o`jg50_o4[/D3olB_a@06olF`a_o5/<GoaK35olJaa_o6/LGoak;60_o7/lH0
0oo8/lKobKC6olVeaP02olZfaP04ol^gaoo<^LOoe<S>omC8cP;og^;H00Gog^?IomgUf_oMi]_ogNKK
omcTf`02om_Ug00<om[Sg?oJhmgofN?MomWSgOoHh]koen;OomKRgooFh=ooeN3OomCPh?oDgn3odmoQ
0_oBgn401?l0003od=gRom3Mh_o@fn82olkKh`0=olkJh_o=f^?oc=WTol_Hhoo:f>Cob]KSolWFhoo8
e^Cob=CSolODi?o6d^?oaM;TolGAh`02olC@i00:olC?hoo2c^Co`/kTol7=hoo0cNCo`<_Soko;honn
bN?o_LSSokc7h`;o^lKS00?o^LGSooooool000004oooool000Wooooo00Co0000oooooooooooo0000
1oooool4o`0000Gooooo00?o0000ooooooooool09Oooool01?ml[_?oK:KcofbVlomVX_<2ofBNl@05
ofROl?mYW^ooJIk_of^Mk_m/W>d00_m]W>`2ofnJjP04og:JjOmcV^SoLi[XogBIi`;oM9SV00?oMIOU
ogJGi?mfUn@00_mgUN<00omhU>;oN9?QogRCh@02og^Cg`?o000000OoO97MogfAg?mmT=_oOI3Kogf?
f_mnS]WoOXkH00;oOXgH0_moS=L01?moS=KoOh_Eogn;eOmoRm@2oh6;d`;oPX[C00?oPXWBoh:9dOn2
RM400on2R=02oh>7c`?oPhK>0_n3QLd01?n4QLcoQXG<ohV7bon9Ql/2oibAa`03ok6L`OnbW<7o]9g1
00;o]9g100Co]Ik1okJN`OnfWl7o]Yo10ongX<42okRQ`P;o^J;200?o^J?2okZS`_njXl800_njXl82
ok^T`P03ok^U`onlYL?o_:K300;o_:K30_nmYl<01OnmZ<Co_ZS3okjX`onnZLCo_jW400;o_j[40oo0
Zl@3ol6/a003ol:/aOo2[LCo`jg500;o`jk500?oa:k5olB_aOo4[lD00oo5/<D2olJaa@;oak;500Ko
ak?6olRcaOo8/lGobKC6olZea_o:]/H2olbha`0:olbiaooDb<kog^?HomkRf?oNi=Wog^KJomgWfooM
i]_og>KKomcVg0;ofnGL01gof^GMomWUg_oIhmgof>?NomOSgooFhn3oe^;OomGRh?oDh^7oe>3Pom?P
hOoBh>;od]oQom7Oh_l0003od=gRoloMhoo>gNCoc]_SolgKi?o=f^?oc=WTol_Ii?o:f>CobMSTolWF
hoo8e^CoamKUolODi002olKDi@0:olGBi?o4d^Coa=3Tol?@i?o2d>Go`/kTol7>i?o0cNCo_lcToko;
h`;o_/[T00Co_LSSokc8i?nka^?o^/KT0_nha>@2o`0001;ooooo0009ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool01Oooool2o`0002Sooooo00CoNZgcofVUlomYYO?oHj7b0_mT
W_401omUWO3oIYg_ofJMkomWW>koJ9_]ofZJk?m[VN/00_m_V^X01_m`VNWoLISXog6Hj?maV>OoLYOV
og>Fi@;oM9GU00CoM9CTogNEhomgUN?oN9CR0ol00002ogVBg`;oNY3M00CoNi3Log^?fomkSm_oNhkJ
0_mlSMT00omnS]SoOXgHogj=f002ogn<e`05ogn<e_moRmGoOh_Eogn;e?n0R]@00_n0RM<01?n0R=;o
PHSAoh68dOn1Qm42oh67d0;oPHK?00?oPHK>oh:5c_n2QLh00_n2QLd00on4QLcoQXG<ohJ5c002ohV7
b`04oibAaonbW<7o/Yc1ok:L`@;o]9g10_nfW/400onfWl7o]io1okNP`@02okNP`@04okRQ`_nhXL7o
^:71okVR`PCo^Z?20_njY<801OnkY<;o_:G3okbU`onlYL?o_:K300;o_JK300Co_JO3okjX`onnZ<?o
_ZS30onoZL@00onoZ/Co`:[4ol2[a002ol6[a004ol6/a?o2[<Co`Zg4ol:]a0?o`jk50_o4[lD3olF`
a@;oa[750oo7//D3olRca@;ob[G60oo<^<L01OoDb<kog^?HomkSf?oNi]Wog^CI00;ogNOK00KogNOL
omcVfooKi]gofnKMom[Vg_oJiMd2omSUg`05omOSgooFhn3oe^?PomGRh?oDh^400_oCh^801ooCh>7o
dN3Som7PhooAgn;ocmkSo`000?o?gN<00_o=gN@04?o=fnCobm_Uol_KiOo;fNCob]WUolWHi?o8enGo
amOUolOFiOo6eNGoa]CUolGCiOo4d^Co`m;Uol;Ai_o2d>D2ol7@i@07ol7>i?noc^Go_lcTokk<iOnn
b^Co_L[Tokc8i002ok_8i005ok[6i?nia^Co]lCTokK4i?l000004_ooool000[ooooo0_l00008oooo
o`Go00000oooool00ol0003oooooooooo`0Xooooo`04ogR/m?mVXo?oIZ?cof2OlP;oHIga00CoHYc`
of>KkomSVnooI9[^0_mWVN`01?m[VN_oK9W[ofbIjom]V>T2ofjGj0;oL9KW00?oLiKUogBEiOmdUND0
0ol000000omfTn;oMY;QogNAh002ogNAg`04ogR@g_mjT=goNY3Mog^@g0;oNhoK00GoNhkJogb=fOml
SMWoO8gIogf<f002ogf<e`03ogf;e_mnR]GoOX[E00?oOXWD0_n0RM<01?n0R=;oPHSAoh68dOn1Qm42
oh67d0;oPHK?00GoPHK>oh:5c_n2QLkoPXG=oh>4c002ohB5c0;oR8K;0_nLTLL2ok:L`@?o]9g100Go
]Yk1okNO`OngWl7o]io1okNP`@04okRQ`@;o^J;10_njXl83okZT`P;o^jG200?o_:G3okbV`_nmY/<0
0_nmY/<2okfW``?o_ZS300Co_jW4oknY`oo0Z/Co`:[30oo1Zl@2ol:/a004ol:]a?o3[LCo`jg4ol>^
a@;oa:k400?oa:o5olF_a?o5/<D00_o6/<D00oo6/LGoak75olNba@02olRba@03olRcaOo9]<Kob[G6
00;obkO700ooc;S7omC8c_oNi=Sog^?HomkVfOoNj=[ogNSKomgWfooMimcog>OLom_WgOoKi]gof^KN
omWVg_oIi]l00_oHiMl01OoGiN3oe^?PomKShOoEhn7oe>?R00;odn;R01;od^;Som7Phoo@h>?od>3T
oloNhoo>g^Co0000olgMi?o<g>GobmcVol_KiOo:fnKob]WUolWIi_o7fNKoamOUolKGi_o6eND2olGE
iP0:olGCiOo3dnKo`m?Vol;Ai_o1dNKo`M3Uol3?i_noc^Go_/gVokk<i@;o_LcU00Oo_L[Tokc9iOnk
b>Co^/OUokW6i?nhaNGo]/CT00;o]L?U00?o0000ooooooooool03oooool001cooooo00?o0000oooo
ooooool0:Oooool01?mf[?CoHj;cof>RlomLWO82oefKl004oejJl?mPVNooH9W_of:Hk@;oIiW/00?o
J9S[ofVGjomYUn/00_m[U^P00om/UNOoL9KWo`000002o`000004og6DiOmbTnCoLY;Sog>BhP;oM97Q
00CoMi7PogNAgomgTMooN93N0_mhSmd2ogV>f`?oNXgJ00?oNXcIog^;f?mkRmP00_mmS=L00ommRmKo
OX[Eogj:e@03ogj9e005ogj8domoR=;oOhOAogn7dOmoQ]400_moQ]02ogn5c`03oh25con0Q<koP8C>
00;oPXG=00?oPhC<ohB5c?n4QL`00_n8Q//01?nLTLOo/Yc1ok:L`OnbW<42okBM`@;o]Yo000?o]io1
okRP`?nhXL400onhXL400oniXL7o^J;1okVR`@03okZS`P04okZT`_nkY<;o^jG2okbU`P?o_:K20onm
Y/<01?nmYl?o_ZS3okjX`onnZ<<2oknY``?o`:[30oo1Zl@2ol:/a0;o`jg40oo4[/@2olF_a0?oa[35
0_o7/LD3olRba@;obKC6017obkO6ol^gaooDalkoe<O>omC8c_oNi=Sog^OIomkYfooNj=[ogNSKomgY
g?oLjMgog>OLom_WgOoJj=kof^SOomWVgP02omSVh005omOUh?oFiN7oeNGRomGUh_oEhn400_oChn<0
1?oCh^;odN;Tom7Ri?o@h>@2oloPi@04olgNiOl0003oc=kVolcLi@;ob]cV00gob]_VolSJioo8f^Oo
amWVolKIioo6enKoaMOWolGEi_o4eNOo`mCWol?Ci_o1dnOo`M7V00;o`=7W00Oo`<oVoko?i_nncNKo
_LgVokg<iOnlbnKo_<WU00;o^/WU00Oo^/OUokW7iOnhaNGo]lGUokG3iOnd`nGo0000017ooooo000L
ooooo`;o0000:oooool01?mdZoCoGj3coenPlomIVo82oeZIl004oe^HkomLV>ooG9S_of:Hk@;oI9O/
00?oIIO[ofJFjomWUNT00ol00002offDi`04ofjCi_m_TnGoKi;Tog2Ah`;oLi;R00GoM97QogB@h?md
T>3oMI3OogJ?gP02ogJ>g@03ogN>g?miS]_oNHkK00?oNXgJ00GoNXcIog^;f?mkRmSoNh_Gog^:eP02
ogb9eP04ogb9eOmlR=CoO8SDogf7d`;oOhSB0_moQm400omoQ]7oOhK@ogn6d002ogn5c`05oh25con0
Q<koPHC=oh64cOn1Q<`00_n3Q<`2ohN6b`05oibAaonbW<7o/Yc1ok:L`OndWL400_neW/001OnfWl3o
^:30okRP`?nhX<3o^:7100?o^J7100Go^J;1okZR`OnjX/7o^Z?2ok^S`@02ok^T`P?o_:G200?o_:K2
okfV`_nmY/<00_nmY/<2okjW``07okjX`onoZ<?o_jS3oknY`oo0ZL?o`:[3ol6Z``03ol6[a0;o`Zc4
0oo3[L@3olB^a0;oaJo400?oa[35olJ`a?o6/<@00_o7/LD01Oo8//GobK?5olVcaOo9]<KobkO600?o
e<O>00?ognGIomkWfOoNjM/00_oNj]/09_oMjMcog>WMom_YgOoKjMgof^SNom[XgooIj=oof>SPomSV
h?oGi^7oe^KRomGVh_oEiN;oe>GSom?UhooChn?od^?Tom7Si?oAh^Cod>;UoloRiOo?h>Goc^3VolgP
i_o<g^Ko0000ol[Nioo:g>KobMcWolSLj?o8f^Ooam[XolKIioo5f>SoaMOWolCFioo3e^So`mCW0_o2
e>P01oo1dnOo`=;Xol3Aionod>Oo_loVokg?ionmcNH00_nlcNL01onlbnKo^l_Vok[9iOnibNKo^LOU
okS7i_ngaND00_nfaNH00ond`nGo/l?Uo`00000@ooooo`007?ooool00ol0003oooooooooo`0[oooo
o`04og6Ym?mLW_?oG9kcoeFJl@;oEYO`00GoEiK_oeVFk_mJUNkoGiK]of6Fk003o`000007ofNEjOmX
U>SoJ9CXofVDj?mZTnOoJi;VofbAi@02ofnBi003og2AhomaTN;oLI7R00;oLXoP0_mcSml01?mfSmko
MXkMogJ>gOmgS]`2ogN=f`;oN8cJ00CoNH_IogV:f?miR]SoNHWG0_mkR]H2ogb9eP03ogb9eOmlR=Co
O8SD00;oOHOB0_mmQ]400omnQ]7oOXG@ogj5d003ogj4c`;oP8C>0_n1Q<d00on1Q<coPhC<oh>4c002
ohN6b`03oibAaonbW<7o/ic100?o]Ik000Co]Yo0okNO`?nhX<3o^:301?niXL43okZR`@?o^j?100Co
^jC2okbT`_nlYL;o_:G20onmY/801?nmY/?o_ZO2okjW`onoZ<83oknX``;o`:W30oo1Z/<01_o1ZlCo
`Z_3ol:[`oo2[<Co`jc3ol>]a0;oa:g400?oa:k4olF^a?o5[l@00_o6[l@01_o6/<Coak74olNaa?o7
/LGob;?5olVca@;obkK6013obkO6om?7c_oDalkognGIomoXf_oNj]_og^_LomkZfooMj]cog>[Mom_[
g_oKjMgofnWNom[YgooIjN3ofNSO0_oGj>401OoFj>;oe^KRomCVhooDi^?oe>GS00;od^GT00godN?T
om3SiOo?hnKocn;UolkRi_o=hNOocN3VolcOioo;gnSob]kWo`000?o9g^SobMcW00;oamcX00ooam[X
olKJj?o5f>Soa=SXol?HjOo3e^So`]KYol;Dj?o1e>Wo`=;XokoBj?nnd^Wo_]3Xokg@jOnlc^P00_nk
c^P01?nkc>Oo^/cXok[:ionib^L2okS8iP05okS7i_nfa^Ko]/GVokC4i_nc`nD00_nb`^H00ol0003o
ooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0/ooooo`04ofnXm?mIWO?oFIgcoe6Hl@;o
DYG`00CoDiC_oeFDk_l0003o00000_mMU>`2of>DjP03ofBCjOmUTnSoII?X00;oIi7W00CoJi;VofbA
iOm]TNCoKI7T0_m_Sn801?m_Sn7oLXoPog:?h?mcSml2og>>gP05ogB=gOmeSMcoMHcKogF<fomfRm/0
0_mhS=X01OmiRmWoNH[HogV:f?miRMOoNXWF00;oNXSF00CoNXSEog^7e?mkQmCoNhKC0_mmQm82ogf6
d@03ogj6dOmnQM3oOXG@00;oOXC?0_moPlh2ogn3c@03oh23cOn2PlcoPX?<00;oQXG;00KoW977ok>L
`OncW<7o/ic1okFN`?nfW/02okNO`0?o^:3000Go^J71okVQ`?niX/7o^J;1okZR`@02okZS`@04ok^S
`OnkY<7o_:C2okbT`P?o_:G20_nmY/82okjW`P?o_jS200Ko_jS3ol2Y`oo0ZL?o`:W3ol6Y`oo1Z/<4
ol:[``;o`jc30oo4[L@2olF^a0?oaZo40oo7/L@2olRca@?obkK600GodlO>omoVfOoOi]WognWJomoX
fP02omk[g003omg/g?oLj]gofn_N00;ofn_O02Gof^WOomWYh?oHjN7oenWRomOXhOoFj>;oeNSSomCX
i?oDi^?odnKTom;ViOoBiNCodNGUom3Ui_o?iNOocn?VolkSioo=hnSocN7WolcQj?o;hNSobmoXolWO
j?o9g^So0000olOMjOo7g>Soa]_YolKJj?o4f^Wo`mWZol?HjOo2f>[o`]KYol7FjOnoeN[o_mCY00;o
_]?Z00Oo_];YokgAjOnmd>Wo^loYok_>j?njcNWo^/cX00;o^LcX00Co^L[WokO9j?ngb>Oo]/OW0_ne
a^L01?nda>Ko/lCVok;2i_na`^H2o`0000kooooo000Kooooo`;o0000;oooool01?m]YoCoEY_boeJK
l_m>U_43o`000005oe:Bk_mGTngoF9?]oeZBk?mLT^/00_mPTnX00omQT^WoHi7XofBAi`02ofNAi`04
ofRAi_mYT>GoJhoTof^?h`;oKhoR00?oKhoQog2>h?m`S^000_maSMh2og:<g@04ogF=g?meS=_oMHcK
ogJ;f`;oMX_J0_mgRMP00omhR=OoN8SFogR8eP02ogZ8eP05ogZ8eOmkQmCoNhODog^6domkQ]800_ml
QM800omlQM7oO8C@ogb4d002ogb4c`03ogj4comoPlkoOh?>00;oOh?=00?oP8?=oh:3c?n2Pl`00_n6
QL/00onLTLOo/ic1ok>M`@03okJN`004okNO`?nhX<3o^:30okRP`0?o^J7000Co^J;1okZS`OnjXl7o
^Z?10onkY<401?nlY<;o_:G2okbU`_nlYL83okfV`P;o_ZO20onoZ<801?o0ZL?o`:W2ol6Y`oo1ZL<4
ol:[``?o`jc300Oo`jg3olB]a?o4[/?oa:k3olF^a?o5[l?oaZo400;oa[3400?oak74olRba?o8/lD0
0_o:]LH05Oo;]/KodlO>omoWfOoOi]WognWJomo/fooNkMcog^_Lomg/g?oLk=gog>cNom_/gooKjmoo
f^_OomW[h?oHjn7of>WQomOYh_oFjN;oe^WSomGXh`02om?Xi00Com;ViOoAi^Kod>KVom3Ui_o?iNOo
c^GWolkSioo=hnSoc>?XolcQj?o;hNSobN7YolWOj?o8gnWoamoZo`000?o6gN[oaMg[olGKjP02ol?K
j`03ol?Ij_o2fN_o`]SZ00;o_mO[00Oo_mGZokkEjonndn[o_M?[okgAjOnkdN[o^loY00;o^/oZ00Oo
^/gYokW=jOnic>So]l_YokO9j?nfbNSo]/OW00;o]<OX00Oo]<GWok?5j?nb`nOo//?Wok72i_n``^Oo
000000kooooo000Kooooo`03o`000?oooooooooo02oooooo0ol000002Om:To3oBY7_odZAkom<T>ko
CY3]oe>AkOmETNcoEi3/oebBj`02oefAjP;oGi3X00CoI97WofF@iomVSnKoIhoU0_mXS^@00om[Sn?o
K8kRofb>hP02ofj=h004ofj<gomaSMkoLHgNog:<g@?oLh_L00CoM8[KogB9f_mdRM[oMHWI0_mgRMP0
1OmhR=OoN8SFogR8e_mhQmKoNHOE00;oNHKD00?oNXKCogZ5d_mjQM800_mlQM801OmlQM7oO8C@ogb4
d?mlQ<ooOH??00;oOH?>0omnP/d2oh63c0;oQHC;00CoW977ok>M`OncWL7o/ig10_nfW/02okNO`005
okRP`?niX<3o^J30okVQ`?njXL000_njX/401?njXl7o^j?1ok^S`OnkY<43okbT`@05okbU`_nmYL7o
_JG1okfV`_nnY/800_nnYl83oknX`P?o`:W200?o`JW3ol6Z`_o2Zl<00_o2Zl<2ol>/``;o`jg30oo4
[/<2olF_``?oa[340_o8//@3olZeaP;odlO>00GognOIomo[f_oOkM_ogncKomk]g002omg]g@06omc]
g_oLk=kof^cPom[/h?oIjn3of>_Q0_oGjn804_oFjN;oe^WSomCYi?oCjNGodnSTom;XiOoAj>Kod>SW
om3Vi_o?i^Ooc^KXolkUioo=iNSoc>GYolcSj?o;hnWobN?ZolWQj@;oan7[00goamoZolGOk?l0003o
aMg[ol?Mk?o3fn_o`]_/ol7Kk?o1fN_o_mW/okoGjonnenco_]G[00;o_MG/00Oo_M?[okcCjonkdN[o
^]7[ok[?j_nicn_o^LgY00;o^<gZ00Oo]l_YokK;jOnfbNSo]LWYokC7j?ncanSo/lGX00;o//GX00Go
/L?Wok32ion_`NOoooooo`00000=ooooo`006oooool00ol0003oooooooooo`0/ooooo`?o000000Go
ooooofRUm?m>Uo7oCYOaodJAk`02odJ?kP;oBXk]00CoD8o]oe>?jomCSn_oF93[0_mJSnX2oen@j004
of6?iomSS^KoHhkVofN?i@;oJ8kT00?oJHkSofZ=h_m[S>400_m^SN000om^S=ooKhcNofn<gP02og2:
g0;oLH[L00GoM8[KogB9f_mdRM[oMHWIogF8f003ogJ7e`;oMhKF00GoNHOEogV6e?miQ]CoNXKCogZ5
dP02ogZ4dP03ogZ4dOmkPm3oNh?@00;oNh??00?oOH??ogf3c_mmPlh00omnP/d2oh63c005ohF4bonL
TLOoW977ok>M`OndWL000onfW/001?ngWl3o^J30okVP`?niX<03okZQ`004okZR`OnkXl7o^j?1ok^S
`@Co_:C10onmYL43okjV`P03okjW`_noYl;o_jS200;o`:S200Co`:W2ol6Y`_o1Z/;o`J[20oo2Zl<2
ol>/``04ol>]`oo4[L?oa:g3olB^``;oaJk300?oaJo3olJ_`oo6/<@00_o8/L@00oo8//Cob[C5olZe
aP02om?7cP03omoXfOoOimWogngK00;og^kL0_oMkMd02OoLkMkofngOom[]h?oJk>3ofNcQomS/hOoG
k>;oen_RomK[h`02omC[i005omCYi?oBjNKodNWVom7Yi_oAj>H00_o?j>P04_o>i^SocNKYolcVjOo<
iNWobnCZolWTjoo9hn[ob>?[olORk?o7hN_oa^7/olGPk?o5gncoa=k/o`000?o2g>co`Mc]ol7Kk0;o
_m[]00?o_mW/okkHkOnnen`00_nle^d01onle>co^]C]ok[Bk?nid^co^M3[okS@k?nhc^/00_nfc^`0
1?nfc>_o]Lc[okG:j_nebNT2ok?8j@04ok?7j?nba^Wo//GXok34j0;o/<?X00?o[l7Wojk1iol00000
3Oooool001_ooooo0_l0000Zooooo`?o00001Oooool01?mVY?CoBiKaod^FlOm2Snl2od:=k@;oBXk]
00KoC8k/oe>?jomCSn_oEHkZoeJ>jOmHSNT2oeb>j006oen=i_mSS^KoHhkVofB=iOmUSNCoIXcS0_mW
S>800om[S>7oJhcPof^<h002off:gP03ofj:gOm`R]coL8[L00;oLH[L0_mbR=X00omcR=WoLhOHog>7
f003ogJ7e`05ogN6e_mgQ]GoMhGDogN5e?mhQM<00_mhQ=82ogZ4dP05ogZ4dOmkPm3oNh?@og^3comk
P/l00_mlP/h00omlPLgoOH7=ogf1c@02oh63c003ohF4bonLTLOoW93700?o]9g000Go]Yk0okNN`?nh
Wl3o^9o0okVP`002okVQ`0;o^Z700_nkX/000onkXl7o^j?0ok^S`002okbT`@?o_JG10_nnY/401?nn
Y/;o_ZK1oknW`_noYl83ol2X`P;o`JW200Co`J[2ol:Z`_o2Z/;o`Z_30_o3Zl801?o3[<?oa:c2olB]
`oo5[L<3olF^``;oaZo30oo8/L@02Oo9]<Gob[C5om?7c_oCalkognSIomo/f_oOk]_og^oLomk^g002
omg^g@03omc_g_oKkmoofngO00;ofNkQ017of>kRomS/hOoGk>?oe^gTomC]iOoDjnCodn_Uom;[i_oA
jnOodNWVom3Yioo?jNSocnSXolkXj?o=j>Woc>SZolcVj@02olWVj`06olWTjoo7i>coanC/olORk?o5
h^goaN3/0_o3h>d03oo4g^co0000ol7Nk_o1g>go`=c^okoJkOnnf^ko_M[^okgHkOnlf>ko_=K]ok[F
k_nje>go^M?]okWBk002okSAk@07okS@k?nfcngo]/k/okG=k?nec>_o/l_/ok?:j`02ok;9j`08ok;8
j_nba^Wo/LKYok76jOn`a>So[lCYojo2j?n^`^P2ojg0j003o`000?oooooooooo00[ooooo0002oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00005oooo
o`03o`000?oooooooooo02Kooooo0ol0000:ooooo`;oAi?`00Co?Hg^ocj:k?lnR^coAXc/0_m8Rn`2
oe2=j`06oe6<j_mCS>WoF8gYoeV=j?mKS>OoGhgV0_mPSND2of:;i003ofJ<homWS>;oIhcR00;oJH[P
00GoJX[Ooff:g_m]R]koKX[Mofj9g002ofn8g004og28fombR=[oLXSJog>8f@;oLhOH0_mdQ]L00ome
QMKoMhKEogN6e@02ogN5e005ogR5domhQ=;oN8CBogR4d_miPm400_miPm000omiP]3oNh;?og^2c`02
ogb2cP05ogb1cOmmPLgoOh;<ogn2c?n4Q</00onLT<L2okBM`0?o]ik000Go^9o0okVQ`?niXL3o^J70
okZQ`002okZR`004ok^R`?nkXl3o^j?0ok^S`0?o_:C100?o_JG1okjV`OnnY/401?nnY/400onoYl;o
_jO1ol2X`P02ol2X`P04ol6Y`_o2Z/;o`Z[2ol:Z`P?o`j_20_o4[<83olF]``03olF^`oo6[/?oaZo3
00;oak3400?ob;74olVdaOo9]<D00_oCalh01?oPj]WogngJomo/f_oNkm`2omg`g@0;omg^gOoLkmko
fnoOom[_h?oIkn7ofNkQomS^h_oGk^;oenkSomK^i?oFkN@00_oCkND07_oBkNKod^_Vom3[j?o@jnSo
cnWXolkYjOo=jN[ocNSYolcXj_o;j>_obNS/olWVjoo8i^coanK]olOTk?o6i>goaNC^olGRkOo3h^ko
`n3]ol;Pk_o1gnoo`Mk^o`000?o0g>ko_]c^okgKkonmf^ko_=W_okcHkP;o^]O_00Oo^]K^okWEk_ni
dngo^=?^okKCkonfdNko]M7^00;o]Lo]00Oo]Lg/okC=kOncbnco//_/ok;9jonabNco/LO[00;o/<O[
00Co[lGZojo4jOn^`nWo[/;X0_n]`NT00on/`>So0000o`00000;ooooo`0000Goooooo`000?oooooo
ooooo`000009ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02?ooooo0ol0000>ooooo`;o@i7`00Ko>H_]ocZ8k?ljR>co@XW[odB9jom6
RNX2odb;jP;oCh[Y00KoE8_XoeR:iomHR^OoG8cVoef;iOmORn@2of:;i003ofB;homUR^;oIXWQ00;o
JH[P00?oJX[Oof^9g_m[R=d00_m/R=`01Om_R=coL8SKog28fom`Qm[oLHOI00;oLHKH00GoLXGGogB6
eomdQ]OoMHGFogF5e@02ogJ4e004ogJ4domgPm?oMh?CogR4dP;oNH?A0_miPm02ogZ1c`;oNX7>00?o
Nh7=og^0cOmkP<d00_moP/`00on4Q<_oW937oib@a`03okBM`0;o]ik00_niX;l00oniXL3o^Z6ookZR
`002okZR`0;o^j;000?o^j?0okbS`?nlY<400_nlY<42okfU`@Co_ZK10onoYl43ol2X`P;o`JW20oo2
Z/83ol>[`P;oa:c200KoaJg3olF^`_o5[/;oaZk3olN``oo7/<@2olVca@0?olVdaOoCa/kodlO>on3Z
fOoOkM[ogo3Komkag?oMlMgogO3Momg`g_oLl=kofo3Oom[`h?oJkn3ofNoQ00;oenoS00[oenkSomK^
i?oDk^GodnkVom?]iOoBkNKodNgWom3]j?o@jnSocn_X0_o=jnX02_o=jN[obnW[ol_Yjoo;j>_ob>O]
olOWkOo7i^goa^G^olCUk_o5i>h2ol?SkP0;ol?Rk_o1hNoo`Mo_okoOkonngo3o_]g_o`000?nmgO3o
_M__okcKl?nlfNl00_nifO001onienoo^=O`okSEkonfe?3o]]?_okGBkonedNh00_ncd>l01?nccnko
//k^ok;=kOnac>h2ok7:k@06ok79k?n_b>co/<O[ojk6k?n^aN_o[LC[0_n]`^X01On]`NWo[<7Yoj^o
j?n[_nSo000000_ooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooooooool2o`0002?ooooo0_l0000Booooo`03oe^OlolkSNko=HS/00;o
=HG[00?o?XO[od27j_m6RNX00_m8RNX2odn:j@03oe>9iomHR^OoF8[W00;oFXWU00?oGh_Tof2:i?mP
R^@00_mRRN800omVRN7oIXWPofJ9h002ofR8gP03of^8gOm/R=coK8SL00;oKXOK0_m^Q]X00omaQmWo
LHKHog66f002og:5e`03og>4e_mcQ=GoLhCE00;oMXCD00?oMXCCogN3domgPm800_mgP]42ogR2d003
ogR1d?mjPLooNX7?00;oNX7>00GoNh7=og^0cOmnPLcoOX7<oh>3b`02oib@a`?o]9g000Co]ik0okNO
_oniX;oo^J2o0onjXKl00onjX/3o^j:ook^R`004okbS`004okbT`OnmY<3o_JG1okjU`0?o_ZK10ono
Yl42ol2X`@06ol2X`_o1Z<7o`JS1ol6Y`_o2ZL7o`Z[21?o3Zl82olB/`P?oaJk20_o7/<<3olVca@;o
dlK>00Goh>_Ion3^f_oOlM_ogo3Komkag002omgagP06omcag_oKl=oof_3PomW`hOoHlN;oeo7S0_oG
kn<01?oFknCoe?3Uom?`i_oCk^H2om7^i`09om3]j?o?kNWoc^gZolg]joo=jn[oc>_[ol_[k?o;jN_o
bNW/00;oanW^00CoanO]olCWkoo4inooa>G^0_o2iO000oo2hnoo`N?`ol7Qk`02okkQl@0:okkOl?nm
go7o_Mg`o`000?njg?7o^]_`okWJlOnifO3o]mSaokSGl0;o]]Ka00Wo]]C`okGDl?ned^oo/m;`ok?@
konbd>oo//k^ok7>konac>h00_n_bnh01?n_b^go[/W^ojk8kOn^a^`2ojg5k008ojg4jon/`n_o[<;Z
ojc2j_n/`NWoZ/3YojZoj?l0000;ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Qooooo`?o00005Oooool00omIW_?o
<8G[oc25j`02oc63j@05ocZ5j_llQNWo@XOYodB6jOm7Q^P00_m<R>P00omCRNOoE8WVoeB9iP02oeZ9
i@03oeb9i?mMR>?oGXSS00;oHXWR00?oHhSQofB8h?mUQml00_mXR=h00omYQmgoJXOLof^6g002ofj7
f`05ofj6f_m_Q]WoKhGHofn5f?m`Q=L00_mbQML01OmcQ=KoLhCEogB3e?mdPmCoM8?C00;oMH;C00?o
Mh?BogN2dOmgP]400_mhP]02ogR1c`?oNH3>0_mkP<d2ogj1c005oh>3bonLT<OoW937okBM`?neWL00
0_ngWkl3okVP_`;o^Z6o0_nkX[l4okbS`0?o_JC00onnYL001_nnY/7o_jK1oknV`OnoYl7o`:O1ol2X
`@Co`JS10_o2ZL44ol>[`P;oa:c20_o5[L801_o5[/;oaZo3olJ_`oo7/<?obK;4olVca@;odlK>00?o
h>cJon3[fOoOlM/00_oNl]`02OoMl]kogO7Nomcag_oKlMoof_;PomWbhOoHl^;of?7RomKai002omGa
i006omC`iOoCl>Kod_3Wom7`j?oAk^Ood>kX0_o>k^X07Oo>kN[oc>g[ol[]k?o;jncobN_]olS[kOo6
jnkoanW^olGYkoo4jNooa>O_ol?Wl?o2io3o`^G`ol3UlOnoi?7o_n?aokkRlOnnhO7o_>7aok_Pl_nk
g_7o^]kbo`000?nhg?;o]mccokOJl_nffO;o]]Sa00;o]=Ob00Wo]=Kaok?El_ncdo7o/]?aok;Al?n`
dO7o/Lo`ojo?l?n_cNl00_n^c?001?n^bnoo[/W^ojg8k_n]and2oj_6k@06ojc4k?n/`n_oZ/;[oj[2
jon[`N[oZ/3Y0_ooool00ol0003oooooooooo`09ooooo`0000Goooooo`000?ooooooooooo`00000;
ooooo`03o`000?oooooo000000?o00001?ooool00ol0003oooooooooo`0Looooo`?o00006Oooool0
0omFW??o;8?Yobb3j@02obb0j00:ocJ2jOlhP^So?XCYod64j?m7Q^SoB8KXodZ6iom@QnOoDHOVoe>6
i@;oEhSU0_mJQn<00omNR>?oGhORof27h@02of66h003ofF7gomVQ]koIhKM00;oIhGL00?oJhKLof^5
fom/QMX00_m]Q=T2ofn5f0;oL8CG00?oLH?Fog63eOmaPmD00_mdPm@00omdPm?oMH;CogF2dP02ogJ1
d@;oMX7@00?oN87@ogR1comhPLl00_miP<h2ogYoc@;oOH3<00?oPX?;oi^@aonKT<L00oneWL001?ng
Wkoo^9nookVP_oniX;l3okZQ_`;o^j:o0_nlXl05okfT`0;o_ZG00onoY/42ol2W`@Co`JS10_o1ZL40
1?o2ZL7o`Z[1ol>[`_o3Zl42olB/`P?oaJg20oo6[l<2olVba0;odlK>017oh>cJon3`fooOl]_og_?L
omkbg?oMl]gogO;Nomccg_oKlmoof_;PomWbhOoHl^;oeo;SomKbi?oEl^CoeO7TomCai@02om;ai`0X
om;`ioo@l>Soco3Yolk`j_o>k^[ocNk[ol_^k?o:k^cob^g/olW/kOo7k>kob>_]olK[k_o4j_3oa>W_
ol?Xl?o1j?7o`^O`ol3VlOnni_;o_nCaokgTl_nli??o_>;bok_Rlonkh?;o^N3cokSOm?nhg_?o]mgc
o`000?ngg??o]M_cokKIl_ndfO?o]=Obok?Glonae_?o/MGbok3Dl`;o/=;b00So/=7aojo@lOn_co3o
[/kaojk<l?n/bo3o[L[_oj_8k`;oZlO^00GoZlK]oj[4kOnZ`ncoZ/?/oj[2j`05ooooo`03o`000?oo
oooooooo00Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Oo0000oooooooooooooooo
o`000?oooooo000000Oooooo0_l0000Jooooo`?o00007Oooool00omCVo?o9h3XobN0j002obMmi`05
oc60j?lcP>Oo>X;Xocb2j?m3Q>P00_m:Q^L01Om<QNKoCXGVoe>6iOmDQ^GoEXKT00;oFXOS0_mMQ^80
0omPQn7oHHKPof66h002of>5gP03ofN6gOmWQMcoIhGL00;oJHCK00GoK8GJoff4fOm]Q=WoKHCHofj3
e`02ofn3e`05og63e_maPmGoLH?Eog:2e?mbP]<00_mcPM<01OmeP];oMX7AogJ1dOmfPM3oMX3@00;o
Mgo?0_mgOlh00omhOlkoNWo=ogYoc@02ogf0c005oh:3bonKT<OoVi37okFM`?nfW/000_nhWkl01Oni
X;oo^Z2ookZP_onjXKoo^j6o00;o^j:o00Go_:?0okbS_onlXkoo_JC0okfT_`02okfT`0?o_ZG000Go
_jK1oknV`?noY/3o`:O1ol2W`002ol6X`@?o`JW10_o2Z/43ol>[`@;oa:c200CoaJg2olJ^`_o6[/;o
aZo30_o8//@01_o9//CodlK>on3]f_oPlM_oh?3Komkcg0;ogO?M01;og?CNomccg_oKlmoof_?PomWc
hOoHln;oeo?SomObhooEl^Coe?;Uom?bi_oBl^Ood_7Wom7aj?o@lNWoc_7Yolo`jOo>l>X2ol_`k00;
ol[^k?o9k^goank^olO/k_o6k>ooaNc_ol?/l?o4j_3o`^[aol7ZlOo1j?400_nnj?801_nni_;o^nGc
ok_Ulonli??o^N?dokWQm0;o]n7d00co^=odokCNmOndg_Go]Mgdo`000?ndfoCo/][eok;Im?naf?Co
/MKcojoFm?n`e?<2ojkCl`06ojoBl_n]dO?o[Lobojc>l_n/cO7oZl_a0_n[b_000on[b>ooZ/O^oj[5
kP0;ooooo`03o`000?oooooooooo00Sooooo0002ooooo`;o00002?ooool5o`000003ooooool0003o
000000?o00000oooool00ol0003oooooooooo`0Fooooo`?o00008Oooool02_mAV_;o8WgWob9miolR
N^Go97[Uobamiol_ONKo=WoWocR0ioloP^L2odN4i`;oBh?U00?oChGUoe64i?mFQ^@00_mGQN<2oef6
hP03oej5hOmOQN3oH8CO00;oHhGN0_mUQ=`00omVQ=coJHCKofV4f`02of^3f@;oJh?H00?oKX?Gofn3
eom_PmL00_m`P]D00om`PMCoLX;Cog:2d`02og>1d`;oM83A0_mdP=000omfP=3oMgo?ogMoc`02ogMo
cP;oNGo=0_mkOl`00on0P/_oVi37oi^@a`03okJN`004okRO_onjX;oo^Z2ookZP_`?o^j6o00Co^j:o
okbS_onlXkoo_:>o0onmY;l00onmY<3o_ZG0okjU`004oknV`0;o`:O00oo1Z<400oo1ZL7o`ZW1ol:Z
`@02ol>Z`@04ol>[`Oo4Zl7oa:_1olB/`P;oaZk20_o8/L<02Oo8//CodlK=om?6c_oPkM[oh?7Komoc
fooNm=cogOGMomgcg@02omcdgP;of_CP00WofOCQomSch_oGln?oe_?TomGdi?oDm>God_CVom?bi_o@
l^P00_o?l^T01_o>lNWocO7Zolcajoo;lNcobo3/olW`k@;oano^01koank^olC^l?o3kO3o`nc`ol;/
lOo0jo;o`N[aokoYl_nmjO?o_^SbokcWlonkioCo^nGcok[Um?nhiOGo^N?dokOSmOneh_Ko]^7eokCP
m_ndg_Go/mkfok?LmOnbg?Ko0000ok3JmOn_fOKo[mSeojgGm_n^eO@2ojcDm@04ojgCm?n[dOCo[=3c
ojc>lP;oZlgb00?oZl_aojW9l?nZb>l03_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`0Cooooo`?o00009Oooool01om@V_;o9h?ZoaEii?lLMnCo7WOTobMjiOlZNnD00_ld
ONH00olmOnKo@h;Vod>2iP02od^3i@;oCX?T00?oDhCToeB3homFPn800_mJQ>42oeb3g`03of24gomQ
Q=koHX?M00;oIHCL00?oIXCLofN3fomXPmX00_m[PmT01Om[PmSoK8;Goff2eom]P]OoKH7F00;oL8;E
0_maPM<2og60d`05og9od_mdP=7oM83AogB0d?mdOm000_meO/l2ogIncP03ogQoc_miOlgoNGo=00;o
Ngo<0onKT<L01OnfW/3o]YjookRO_onhWkoo^Z2o00;o^Z6o0_nkXKl2okbR_`05okbS_onmXkoo_J>o
okfT_onnY;l00_nnYL04oknV`0;o`:K000Co`:O0ol6W`?o1Z<7o`ZS00_o2ZL43ol>Z`@?oa:_10_o6
[/83olRa``;odlK=00Koh>kJon3bf_oOm=_ogo?Komkdg?oLmMd2om_egP04omWfh?oJm>3ofOCQomSe
hP;oe_GT00Soe?GTomGdi?oBm>KodOCWom3dj?o?m>Woco;Yolkbj@;obo;[00Kobo7/olWakOo8lNko
a_7^olO_k_o5knl2ol;_l@0Jol?]l?nokO;o_^gcokk[l_nmjo?o^n_dokcYm?njjOCo^NSeokWWmOng
i_Ko]^KfokKTm_ndi?Ko]N;fok?Rm_nbhOOo/^3fok3Omonag_Ko[mggok3Km_l0003o[]_gojoIm_n[
f?L2ojcFmP05ojcDmOn[doGoZm7doj[@m?nZc_<00_nYc?800onYbo7oooooooooo`0?ooooo`03o`00
0?oooooooooo00Sooooo000Iooooo`;o00004_ooool3o`0002Wooooo00?oDi_cobZ5jolHNnD00_l@
Ln401olQN>Co8gSTocAmi_lgONKo?GoVocmoiOm1OnD00_m7PND2odj3i0;oDH;R00?oEX?RoeN3hOmH
P^000_mLPml2oej2gP03of:3gOmSPmcoI8;K00;oIH;K00?oJ8?JofR2fOmYP]P00_mZPML2off2e`;o
KX7E00?oKX3Dog61domaPM<00_maP=<2og9od@;oLgo@00?oM7o@ogEncomeO/l00_mfO/h2ogMnc@;o
NWo<00?oP8;;oi^@aonKT<L00onfW[l01OnhWkoo^Z6ookZQ_onjXKoo^j6o00;o^j:o00Co_::ookfS
_onmXkoo_J>o0onnY;l01?nnYL3o_ZFooknV`?noY[l3ol2V`0;o`JO00oo2Z<000oo2ZL7o`jW1ol>Z
`@03olB[`@;oaJg200?oaZk2olN``oo8/L<00ooCa/d02OoPk][ogoCKomkfg?oNm]cog?KMom_gg_oK
mMkof_KOomWfh002omOfhP04omGfhooFmNCoe?GTom?ei@;odOGW00ood?GXom3dj?o>m>Woc?CZol_d
joo;l^_ob_;/olObk_o6l^koa_7^olGakoo3l?3o`_3aol;_lOo1ko400_nmk_<04onnkO?o^^cdok[/
m?nkjoCo^>[fokWXmOngj?Ko]NOgokKVm_ndiOOo/^Ghok?SmonahoSo/^7gok3Qn?n^h?So[mohojgN
n?n]g?P00_n/g?P02Ol0003oZmWhoj_HmonZe_OoZ]CfojWBm_nYdOGoZ<kdojW=l`0Eooooo`03o`00
0?oooooooooo00Sooooo000Iooooo`03o`000?oooooooooo00oooooo0_l0000]ooooo`05oeRMlol^
R>co77kWo`efh_l0K]/00_lALn402Ol_NnGo<G_UocUmiOlkONGo@GoUod=oi?m5OnCoBh7Todb1h`02
oe62hP;oE87Q00?oF8;PoeV2gomKPMh00_mNP]h2of22g003ofB2fomUP]_oIH7J00;oIX7I00GoJH;H
ofZ1eom[PMOoJh7Gof^0eP02ofj1e@;oKh3C0_m_Om<01Om`Om;oLWoAog9odOmcOm3oLgk@00;oLgk?
0_mdOLh01OmfO/koMgk=ogMncOmjOlcoOh7;00?oVi370_nfW[l2okVO_`03okZQ_onkXKko^j:o00;o
^j:o0_nlXkl3okfS_`;o_ZBo0_nnYKl3oknV_`03ol2V`?o0Yl3o`JO000;o`JS000Co`ZS0ol:Y`?o3
ZL7o`jW10oo4Zl43olF]`P;oak330_oCa/d2on3_fP06omoffooMmm_og_KLomgfg?oLm]gof_OO0_oI
mn002_oGmn;oeoKRomKfhooEm^?odoKUom;fi_o@mnOodOGWom3ej?o>mNP2olcejP0>ol_djoo9m>co
b?C]olKdk_o5lnkoa_;^olCbkoo1l_7o`_3aol3`l_nnl?;o_?3cokg^lonkk_@2okS]m@0@okW/mOne
joOo]N_gokKYm_nbj?So/nOgok7Vn?n_i_Wo/>GhojkTnOn_hoSo[N;ioj_Qn_n/h?WoZ]ojoj_Mn@;o
ZMci00OoZ]_iojSInOl0003oZ=GgojSDmonXdOGoZ=3d01Sooooo00?o0000ooooooooool02?ooool0
01Wooooo00?o0000ooooooooool03?ooool3o`00033ooooo01GoFiococ::kOlQPNSo4GWSo`5`gOl0
KM[o06cIobQhi?l[NNCo<g_UocIki?lmONCo?ggTodEoi?m7On?oC87Sodj0h_m?P>7oE87QoeF1h?mG
P=l00_mKPMh01?mLPMkoGH7Mof22g?mPP]`2of:1f`03ofF1f_mVPMWoIX7I00;oJ83G0_m[PML2ofao
e@03ofaoe?m_P=?oKh3C00;oKgoC0_m`O]42og5nd003og=nd?mcO/ooLgk?00;oM7g>0_mfOLd2ogQn
c004ogn1bonKT<OoVi37okJN_`;o]ijo00Go^Inook^Q__nkXKko^j6nok^R_`02okbR_P04okbS_onm
Xkoo_J>ookfS_`?o_ZBo00Co_ZFooknU_onoY[oo`:Jo0_o0Yl03ol6X`0?o`ZW000?o`jW1ol>Z`?o4
Zl400_o5[<400oo5[L;oak33olN```02om?6c@05on3`f_oPkm[oh??JomggfooMmm`00_oLmmd08?oJ
n=oofOSOomWgh?oHmn7oe_ORomGghooCn>Cod_SUom7hi_oBm^Kod?OWolkgj?o<mnWoboOZolcej_o:
mN_obOG/olGekOo4mNkoaO?^ol?ckoo2lo3o`??aol7blOnolO;o^o7cokW`m?njkoCo^NodokO_mOnh
kOGo]^gf0_nbk?L03OncjoOo[nWiok3Xn?n^ioWo[>OjojgUnOn[iO[o[>?ioj[Sn_nXh__oZN7jojOO
nonXg_X00_nWg?X01OnXfoWoYmSiojOGn?l0003oYm;f01_ooooo00?o0000ooooooooool02?ooool0
01Wooooo00?o0000ooooooooool02Oooool3o`0003Cooooo0_mMX?@01olVQ>[o6goWo`Ecgol5Lmoo
06_Goa9chOlCM>800_l_NN@2ocYki003od=mhom9O^;oBGkR00;oCh3Q0_mBOn000omGP=ooF83NoeUo
g@02oef1g@04oej0g?mOP=_oHX7Kof:1f`;oI7oI00GoIGoHofR0eomXP=OoJ7oGofUoeP02ofaoe@05
ofaoe?m]O]?oKWkCofindom^OM800_m`O]401OmaO]3oLGg@og9mcombOLooLWc>00;oM7g>0_mfOLd0
1?mhO/coOX7;oi^@aonKT<L3okNN_`;o^J2n0_nkXKh3okbR_P;o_J>n00Co_J>ookjT_onnY;oo_ZBo
0onoYKl3ol2V_`03ol2W`?o1Ykoo`JS000;o`ZS000Co`ZW0ol>Y`?o3Z/3o`j[00oo5[<42olN```03
om?5cOoCa/goh?3J00;ogoCJ00oogOSKomchg?oKn=gog?OMom_hg_oIn=oof?SPomOhhOoEn>;oe?WS
om?ii?oCn>CodOSVom3hi_o>n>L00_o<n>T03?o:n>WoboOZolSfk?o6m^coaOK]ol?fk_o4mNko`OC`
okodl?nmm?7o__?aokcblP;o^?;d00Go^O3dokK`mOnckoKo]Nkfok?^m`02ojk]n006ok3[n?n[j_Wo
Zn[iojgYnOnXio[oZ^Kj0_nWi_/00onYi?[oYN;kojKQn`02ojGOn`05ojKNnonUfo[oY][jojKFnOnV
eOP00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo000Iooooo`;o0000
1oooool3o`0003Sooooo0_mPX_@01?lZQn_o8H;YoaAliOl?N^<2o`1]f00:o`1Xe?l_NNCo;gWTocYk
i?llNn?o@ggSodEmh_m7O>7oC7kQodinh0;oDWoP0_mEO]h01omIOmgoFWoMoe]og?mKOmcoGh3Kof1o
f_mQOmX00_mTOmT2ofEoe`05ofIneomYOmKoJGoFofYneOmZO]@00_m[OM<2ofind`;oKggA00?oKgg@
og5md?maOM000_mbOLl2og=lcP;oM7c=00?oN7k<ogj1bomnPL/00_nKT<L2okNN_`;o^J2n0onkXKh2
okbR_P;o_J>n0onnY;l5oknU_`04ol2V_oo1Y[oo`JNool6W_`?o`ZS00oo3ZL000oo3Z/3oa:c1olF/
`@02olN_`P0BolN``ooCaLgohO7Jomoef_oOm=[og_OKomghfooKn=gof_WMomWig_oHnMooeoWPomKi
hOoEnN;oeOSRom?ii?oBnNCod?WU0_o>nNL03_o;nNSoc?SYol[hjOo8n>_oaOO/olCgkOo5m^go`oK^
ol7fkonmmO3o_?GaokgdlOnkm?;o^O?c0_nel_@02?nflOCo/_3fok3`m_nakoOo[nkgojg^n?n^kOSo
[>ci0_nWjoX00onYjO[oY>SkojKWn`02ojCVn`03ojGUnonRh_coY>7l00;oXmkk00?oY=ckojCIn_nU
eoT01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo000Iooooo`03o`00
0?oooooooooo00?ooooo0ol0000looooo`;oHj?d01;o@i?aobF5jolUQN_o57kUo`ajh_l0Lmco06[D
o`1Wd_l0ILoo<gWSocEiholnNn?o@7_RodMlhOm8O>7oCWkPodmmgomAOMl2oeEngP;oF7gL00OoFgoL
oeanfomMO][oGGkJof5of_mRO]WoHgkH00;oIGoG0_mWO]H2ofQme@05ofYne?m[OM?oK7gCofamdom/
O=800_m_OM42og1ld0;oL7c?00GoLWc>og=lc_mcO<koM7c=ogMmc002ogf0b`;oVi370_ngW[l01Oni
X;ko^Z2nokZP__nkXKko_:6n00;o_::n0onmXkh00onnY;oo_ZBnokjT_P04oknU_`?o`JJo00?o`JNo
ol:W_oo2Z<000_o3ZKl00oo3ZL3oa:_1olB/`@02olJ^`P0AolN_`_oCaLgodlG=om?5cOoOmM[og_SJ
omgifooLnM_ofoWLom[jgOoIn]kof?[OomSigooFnN7oeOWRom?jh_oAn^@00_o?n^D01_o=n^Koc_WW
olcij?o;nNSoaoWZolKij`;o`_S/01;oa?O]ol3gk_nnmnoo_?K`ok[fl?nlmO7o^_GaokKdlonclo?o
]O;dok?bm?n^lOKo[?3fojk_mon[koOoZNkhojK]n?nXk?T2oj?[nP08ojGZn_nPj?_oX^Okoj3Vo?nO
i?coXN?loj7Po?nRgo`2oj?Kn`03ojCJnooooooooooo00Sooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`07ooooo`006?ooool3o`000004ooooool0003o0000o`00043ooooo00?oIJCd
odJFlOm6U_400_lZR>`01_lIPNOo5X7Vo`=gg_l3Mmko077Ho`1Tc@;o5WCR0_liNN82odAkh@;oC7cO
00?oDGgOoe9mg_mCO=d00_mHOM`2oeYmf`;oGGkJ0_mOOMT00omSO]SoHggGofAmeP02ofMneP06ofQm
eOmXOMCoJGcCofUldom/OM?oK7cB0_m]O=401?m]O=3oL7c@og1ld?m`O<l3og5kcP;oLW_=00?oMgg<
ogf0bommP</00_nKT<L01?ngW[oo^Z2nokZP__njX;h3okbQ_P04okbR__nmXkko_J>nokfS_P?o_ZBn
00?o_jFooknU__noYKl00_o0Y[l01?o1Y[oo`JNool:W_oo2Ykl3ol>Y_`;oa:_10oo6[/83om?5c@0a
omogf_oNnM[og?[Jom_jfooLnM_ofoWLomWjg_oHn]ooe_[OomGjh?oCnn;odO_Som3khoo?nnCoco[U
olkji_o;n^OobO[XolSjj?o5nN[o`oW[ol7ik?o2n>co`OS]okkhk_nkmnoo^OO`okKgl?nhm_7o]_Ga
ok7dlon_m??o/O?dojobm?n/l_GoYo3fojW`monWkoOoY>khoj;]n?nTkOWoXNcioicZn_nNjO_oW>Sk
oi_Vo?nMiOcoW^?moioRo@02oj7Mo003oj;Lo?oooooooooo00_ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`07ooooo`006?ooool4o`0004Cooooo00goIjGdodZHl_m:V?;o?97`ocB>
kolXRNco6hCXoa:0iOl>O^Co07CKo`1_eOl0J<ko067800;o>GWR0_m4Nn42odalg`;oCg_N00CoDgcM
oeElg?mFO=coFWgK0_mKO=X00omLO=WoGggIof1mf002of5le`07ofAme_mUO=KoIWcEofIleOmXOMCo
JGcCofYld`02ofYkdP;oKGcA0_m^Nm02ofikc`?oLG_>00CoLW_=ogIlc?mlOl_oO7o;0_nKT<L2okRN
_`?o^Z2n0_nlXKh2okfR_P05okfS__nnXkko_Z>nokjT__noY;h00_noYKh3ol2V_`?o`JNo00?o`ZNo
ol:X_oo3ZKl00_o4Z/000oo4Zl7oaZk2olJ^`P03om?5c@0Won7bf_oOmm[og?[Jom_jfooJn]cofO_L
omSkgOoGnmkoe__OomCkgooBnn7od?cRom7khoo@nn?ocO_Uolcki_o:nnKoao_XolGjj?o3n^Wo`O[Z
ol?ijoo1nNco_OW]ok_hkOngn>oo]?O_okKgl?ndm_7o/_Kaojgdl_n[m??oZ??coj[bm?nXl_CoX_3f
oio_m_nRkoOoWnkg00;oV^ch00SoW>cioiSYn_nJjO_oVNOkoi[Uo?nLi?goW]omoj3No1;ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`004?ooool3o`0000Gooooo0_l00018
ooooo`03ofbWm?mBVo?o@ICa00;o;Xc^0_lQQn/01OlCP^Ko2WgRo`1gfol0K=3o067700;o67CR00Co
?GWRocmihOm7N]ooAg[O0_m?Nmh2oe5kg0;oEg_K00OoFgcJoealfOmMO=WoGGcIof1mf?mQO=OoHWcF
00;oHg_F0_mVO=D2ofMkd`05ofYldomZNm;oJg_Aof]kdOm/Nm000_m^Nm001?m^NlooKg[>og1jc_m`
N/h2og9kc@03ogIlc?mlOl_oO7o;00;oVi3700Go^9jookZP__njX;ko^Z2nokbQ_P02okbR_P04okfR
__nnXkko_Z>nokjS_P?o_jBn00?o_jFnol2U__o0Y[l00_o1Y[h01?o1Ykoo`ZNool:X_oo2Z;l3olBZ
`0;oaZk200?od/G=om?5cOoPlmX00_oOn=X0;?oLnm[ofo_JomWkfooHo=coeocMomOkg_oFnmooe?_O
om?kh?o@o>;ococSolklhoo<o>CobOcVolOki_o5nnOoa?_Xol;kj?o3n^Wo_o[[okgjjoninNco]oW]
okGhk_n`mnko/_O`ok3fl?n]m_7oZoGaojKcl_nSl_;oYO;coj?am?nMkoCoV^kdoiO]mOnJkOKoUncg
oi;ZmonEjOWoUNSjoiOVo?nIiOcoW>;m5oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00Oooooo000Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A_ooool05_m_
Z?CoEIgcodFFl_lmTo7o=i;`obj>k_l[S^ko6HKXoaF5iol<P>?o1goQo`1deol0IlWo05g0oaQeh_lo
NN7o@7WQod9ih?m:N]koC7[Noe5kg?mCN]`2oeMkf`;oFG_I0_mMO=T2oemke`07of9le_mSNmKoI7_E
ofAkeOmTN]CoIg_CofQkdP02ofQjdP;oJg_A0_m/N]02ofejc`05ofmjc_m`N/koLG[=og5jcOmdNl`0
0_mkO/`01_nKT<OoVY37okRO_onhWkoo^Z2nok^Q_P?o_::n0_nmXkh3okjS_P;o_jBn0_o0YKh3ol6V
_P?o`ZNo00?o`ZRool>Y`?o4Z/000_o6[L409?o6[/;od/G=on3df_oNn=WogoSJomgjfOoLnm[ofO_K
omSlg?oGo=goe_cMom?lgooBo>3odOcQololhOo<o>?obocSolWli?o7o>Goa_cUolCli_o4nnSo`__X
ol3kjOnln^[o^_[[okOijoncnNco/?S]oj_gkOnXm^koZoK_ojSel?nVm?3oX?;`oigal0;oUnoa00Wo
V^ocoiC]lon=jo?oSN_coi7[mOn?j?SoT^OjoiCVnonIhod06_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0A_ooool02?maZOCoFIododfKlom2U_;o?9Caoc>Al?l`TNoo9hg]0_lJR>T03_l=PnCo0ggOo`1l
g?l0L=3o06?2oaUeholJMN?o@WWPod=igom<N]koCGWMoe=jg?mDN]_oEG[J0_mINmT01?mKN]WoFg[H
oemkeomONmL2of5jeP06ofAkeOmTN]CoIG[CofEjdomXNm;oJ7[B0_mYN]401OmZN]3oK7[@ofajd?m]
N/ooKG[>00;oKWW>0_maN/d00omdNlcoNgk<oiZ@a`02oiZ@a`05okRO_onkXKko^j6nok^Q__nlX[h0
0_nmX[d01?nmXkko_Z>nokjS__nnXkh3oknT_P03ol2U__o1YKko`JJn00;o`ZNn00Co`ZNool>Y_oo3
ZL3o`jW00oo6[L42om;5c@06omkhfOoMnmWofocIom[lf_oIo=[oe_gL0_oEoMd08_oBoMkodOgOom3m
goo>oN3obogRolWmh_o7oN?oaocUolKliOo4o>Ko`_cVokkkj?nlnnSo^__YokGjj_ncnN[o[_S[oj_g
jonVm^coXoG/oj3dk?nSm>koX??^oi[ak_nGl>ooT>g^ohg/k_n9jnkoSN_aoh[ZlOn9j?CoS>OhohoW
nOnEiO`Nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool0017ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`16ooooo`04og>Zm?mLXOCoDIgdoe6Mm0;o@IOb
00go=ICaoc:Cl?lYT>ko9Ho]oab;j_lHR^So1H3Oo`1ngOl0L]3o06C2o`1F]_lJMN?o6gGS00;oAWSN
0_m@NM/01?mEN][oEgWIoeQifOmKN]P2oeaje`03oeeie_mQN]KoHG[E00;oHWWD0_mUN]<2ofIidP;o
JG[A0_mZNM02of]ic`05ofejc_m^NLkoKgW=ofmicOmcNl`00_mkO/`2oiZ@a`04okRO_oniWkko^j6n
ok^Q_P?o_J:m0_nnXkd01OnnXkko_jBmoknT_OnoY;ko`:Fn00;o`JFn0oo2Ykh2ol>Y_`04ol>Y`?o5
[L7oaJg1olJ]`@;od/G=02Gog_WIomclf?oJo=SofOgIomSmf_oEoM_oe?gLomGmgOoDoMgod_gNom3m
goo>oN3ocOgQol_mh_o7oN?oa_gTolCmi?o0o>Go__cVokcli_nhnnOo]O[Xok3ij?n^nNWoZoSYojKf
jOnSm^[oWO?Zoi[bj_nCl>WoT>kYohc]jOn@k^coS>c/ohGYjon0incoPNK_00;oSnKj00?oTNKkoooo
ooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo000Aooooo`03
o`000?oooooooooo00Wooooo0_l00016ooooo`;oMZ_d00CoGj;doeFOm?mEWoCoAIWc0_m2VO<2ocNF
lP;o:i;_00So7Hk[oaV=jOl6P^3o1X;Po`1keol0KLWo056]o`1A[`;oAWSN0_m@NM/2oe9hfP;oFGWH
0_mLN]L2oeiieP06of5jeOmRNMCoHgWCof=idomTNM;oIWWB0_mWNM401OmXNM3oJWW@ofYid?m[NLoo
K7S>00;oK7S=00CoKgW=og=kc?miO/coNGk<0_nJT<L2okVO_P?o^j6n0onmX[d01?nnXkgo_jBmoknT
_OnoY;d2ol2U_P04ol6U__o1Y[ko`JJnol:W_P;o`jRo00?o`jVoolF/`Oo5[L400ooBaLd08ooPmMWo
g_WIom[lf?oIoMWof?gJomOmf_oEoM_odogLom7ngOo@o]koc_kNol_nh?o:o^3ob?gQolCmh_o2oN?o
`?gSokcli?njo>Go^?_Uok?ji_n`n^Ko[_WVojShionVmnOoX?GWoicdionFlNOoT_3Wohc]i_n8k>Ko
PNSUoggVi?mghnGoNNCY00;oR^Kh00?oS>Kiooooooooool09?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00Kooooo000@ooooo`;o00003Oooool00ol0003oooooooooo`15ooooo`;o
NZgc00?oFJ7doe>OmOmCWoD00_m6Vo@00om4W?Co@9cdocRIlP02obbEl0;o7i3[00Go4H[Uo`N5h?l2
Pmgo07K@o`1?Z`02oaaeh`04odUhgOm:N=goDWSJoe=hf@;oFGWH00CoFWSGoe]he_mNNMKoGWWF0_mP
N=@2of=id`;oI7SB00GoIgWAofQid?mXN<ooJ7S?ofUhc`02ofahcP04ofahcOm^N<goLG[<og5jc0;o
NGk<0_nJT<L2okVO_P;o^j6n0onmX[d00onnXkgo_j>moknT_@02oknT_@04ol2U__o1Y[ko`JJnol6V
_P?o`jRo0_o5[<43om;5c@0Qon3ffOoNn]SofOgHomSmf?oGo]Woe_kIomCnf_oAo]_ocokMolgngOo;
o]kob_kNolKngoo4o^3o`_gQokkmh_nloN;o^_cSokGkhoncnnCo/?[Toj_ii?nXn>GoX_KUoioeiOnL
m>GoU_7Toi;`i?moj=koMnCMog?Rg?m]gmgoL>3R00;oQ>Ge00?oQnKgooooooooool09oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo000Aooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0AOooool2ogb^l`0IofVWmOmGXOGoEj7eoe:PmOm?X?KoB9keodFNmOm2
W_Go>Y_cocNKlol^V?3o:YO_ob6Ck?lLT^[o4XgUo`j;hol0OmOo07;8odX00?lMM^?oBWSModahg?mC
N=WoEGSIoeIhf002oe]heP03oeahe_mMMmGoH7SD00;oHGSC00?oHWSBofAhd_mUN=400_mVN=02ofQh
c`;oJWO>0_m[Mld01?m^N<goLG[<ogQmc?mhOL`2oiZ@a`;o^Inn00Go^j6nokbQ_OnlXKgo_J:mokjR
_@02oknS_@?o_jBm0_o1YKh01?o1Y[ko`ZNnol:W__o3Z;l2olF[`00SolF/`OoBa<god/G=on3ffOoN
n]SofocHomWmf?oGo]Woe_kIomCnf_o@om[ocOoKol_ng?o:o]cob?kMol;ng_o0o]oo__gOokcmh?nh
o>7o]OcQok?khOn^n^;oZoWRojGgh_nRm^;oWoGRohk_gOn:kMgoP^WLogkWfomfhmWoL^7HofKKfOmn
i?40;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`00
0?oooooooooo04Gooooo00OoOZocofbXmOm/Z?GoI:KeoejUm_mFX_KoDj?f00;oDJ?g0_m6XOH2ocbN
m003ocRNlol[V_3o:i[`00;o7ICZ00Ko3hgSo`21eol0N]3oC@00oaefholNM^<2odigf`;oEgOG0_mH
MmL2oeege006of5hdomRN=;oHWOBof9gd_mUN=7oIWS@0_mVMll01OmWMlooJWO>ofYgc_m[MlgoK7O=
00;oL7W<0_mhOL`00onJT<Oo^InnokVO_P03okbQ_@;o_Z:m0onoXkd01?noY;go`:Fmol2U_Oo1YKh3
ol:W_P?oaJ_00_oBa<d07_oMnmSof_gGomSneooGo]Ooe_kHom?nfOoBo][od?oJoloofoo=om_ob_kL
olSngOo6o]ko__kMok[mg_nho=ko/__Ook3kgon]n]ooZ?SOojGggonRm]ooTO3Kohg^f_n6jmWoPNWH
of_McomWflkoG=C?ogORk3?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06oooo
o`008_ooool2o`0004Kooooo00OoP;3cofnZmOm_Z_GoIjOfof:Wm_mNY_OoF:Gg00;oEJGg00ooDZGh
oe2Vn?m8Y?OoAJCgod:Sm_liX?Co=Z3cobfLl?lXVnoo7iO[oa^Ej?l@T>?o38kPo`21domD00000_m>
Mm/2oeMge`04oeQgeomIMmKoGGODoeege0;oGgKC0_mRMm82ofAfd0;oIWO?0_mXMlh2ofUfc@05ofag
cOm`NLcoMgc<ogMlc?nJT<L00oniWkh3okbQ_@04okjR_OnoXkgo_j>moknS_@?o`:Fm00?o`JFnol:W
__o2Ykh00oo5Zl02om;4c@0LomgleooJo]KoeokFomKne_oDomOod_oHoloofOo=omWoc?oJol[ofoo6
o]_oa?kLol;ng?o0o]go]ocLok;kg?n`nmcoZ_WLojOhg?nTmmcoW_GLoi3_f?n8k=KoQN[FofoOcOm[
g<_oDlk0og3OiSKooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`009?oo
ool00ol0003oooooooooo`14ooooo`05oh:`lombZoGoLZ_eof^Ym_mVZ?H00_mRZ?L01?mOZ?SoGJWh
oeNXn?mDZ?P2oe6Xn0;oAjKg00Wo@jKgod2Vm_lgX_Co<j;bobZMkolVW>go6iOXoaNFi_l=T>000_lO
M^<00om@Mm[oDGOIoe5gf@02oeYfe@05oe]fe?mOM]?oH7KBof1fd_mQM]400omTM]001OmUM/ooJ7O>
ofQgc_mYM/goJWK=00;oL7W<0_mgO<`00onJT<Oo^InnokZP_P03okbQ_@;o_Z>m00Go_j>mol2T_Oo0
Y;go`:Fmol:V_P02ol:W_P?oaJ_00_oBa<d06_oOn=WogOcGomOne_oFo]Koe?oGom?oeooBomSoc?oH
ol[of?o6omWoa?kJol3nf_nno]_o_?gKok[mfon/n][oZOWJojOhf_nQm]WoWOGIohc]don8jm?oQ>WB
ofkNb?m6a;?oJ=cQ>_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo000U
ooooo`03o`000?oooooooooo04Gooooo00CoQK;bogR]m?ma[?KoLJcf0_mVZ_L01?mSZoSoHZ_hoen/
nOmO[?T2oeJ[n@04oe>[nOm@ZoWoCJ_iodFYm`;o@ZSg0_leY?<02?laXo7o;:;_ob:MjolNW>So293L
ob1fhomAMmWoDWKH0_mJM]D2oe]fe0;oH7KB0_mRM]02ofAfd0;oIWK>0_mYM/d2ofihc0;oMWc<00Go
VY37okZP__njX;ko^Z2nokbQ_@02okfR_@04okjS_Oo0Y;go`:Bmol2T_@?o`ZJn00?o`ZNnolBZ`?o5
Zl000_oBa<d05ooOnMSog?cGomKoe?oComGod_oFom3oe_o?omOocOoGol[of?o4omOo`_kHokknf?ni
oMWo]ocIokClfOnbnm[oXoOGoj3fe_n>k]3oRnc@ohO[com`glKoAlB`03oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`06ooooo`009_ooool00ol0003oooooooooo`14ooooo`;oQk;b
00OoNZkdogB]m_md[OKoL:gfoff]mom[[_SoIJgi00;oHjki00CoHJkjoej_n_mL[o[oG:oj0_mB[_X0
2_m?[_[oBjkiod^^nOm8[_SoA:ggoc^ZmOlgZO?o<jSaobVSkOlUX^X2ob5fh`03oe=ff?mDM]OoFgKD
00;oG7GC00KoGGGBof9fd?mRMM3oHWG@of=ecomVM/h2ofMecP04ofQfcOm^N<coKWS<ogIlc0;oVY38
0_njX;h3okfR_@03okjS_OnoXkgo`:Bm00;o`JJm01_o`ZJnolBY_oo4ZKooa:[0om;4c?oBa<gogoWH
omcleooIo]Goe_oDom3oe?o>omGobooFolWoe_o8omOoa?oGol;nf?nioMKo]ocGok7keon_n]OoX_KC
oicddonIl];oR>_<og3N`_m]g<40@oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Gooooo000Wooooo`03o`000?oooooooooo04Cooooo0_n9/o801Omm[oCoMjoeog>^m_mc[_KoL:og
00;oKZoh00CoKK3iof^an_mX/_[oJ;;j0_mP/O/01OmM/__oFk;koeRcnomH/o_oEK?k00;oDK?j0_m6
/?P00om2[oKo?Zkeocj^m@03ob5fh`;oEGKG0_mLMM<2oeiedP04of9ed?mSMLooI7C>ofAdcP;oIgG>
0_m]Ml`2ogAkc004oiZ@b?njX;ko^Z2nokZP_P;o_J:m0_noXkd3ol6V_@?oa:Vo0_oBa<`04ooOn]So
fogFomGodooCom?od_oDolkoeOo9omCoaooDolCoeOo2o]Ko_OkFokKle?nanmCo[_[DojShe?nJl/oo
Uo7?oh3Vaomli<H0A_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo000X
ooooo`;o0000AOooool2oh^dl@06ogn`m?n2/O?oMk3fogN`m_md/?OoL[7h0_m`/_T01Om^/o[oK;?j
ofbcn_mZ]?_oJ;Gl00;oI[Kl00OoHkKlof6go?mQ]ocoG[Oloe^ho?mH^?coD;Gj00;oC;Gi00CoB;Ch
odBdm_m4]?Ko@;?d0_mEM]L01?mFMMKoEgGEoeied_mNM=42oemdd004ofAdc_mUM<koIGC>ofIdc@;o
KGO<00?oM7_<oiZ@b?nJT<P00_njX;h3okfR_@03oknS_Oo0YKgo`JJm00;o`jVo01Coa:Voom;4c?oB
a<cogo[Hom_me_oCom;od_oBom3od_o=om?obooDolOoe?o1o]?o_OgCok_me?nfo=CoZOSAojKgdOnS
m]3oS^g:ogWR`T[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`00:_oo
ool00ol0003oooooooooo`14ooooo`05ohjelOn4/_?oQ;;cognbm?ml/_H00_mj/oL01Omh]?SoMkGi
ogNenOme]_[oLkOj00;oL[Sk00GoL;Wloffio?m[^_goJk[mofVko@02ofJko@05of>loOmQ_?goHKcm
oejloOmJ_?`00_mG_?/01?mC_?[o8WKSob9fhomGMMD2oeQee@06oeiddOmOM=3oHGC@of5dd?mUM<ko
IWC=0_m[Mld2og=kc006oiZ@b?njX;ko^j6nok^Q__nmX[go_jBn0_o0YKd3ol>Y_`;od/C<00oog_[H
om[neOoCom;od_oBom3od_o;om7oaooBolGod_o1o]?o]_cAok?kdOnan]7oW_C=oi_ccOn6jLH0C_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000[ooooo`03o`000?oooooo
oooo04Cooooo00GoT;K`ohJclon6/o?oP[?dogncmP02ogfdm`05ogben?mj]_WoNKOjogVgn_mg^?X0
0_me^O/00omc^_coLK_logFmo002og>mo@05og6noOm^_okoK<3nofc0o_mY`?h00_mV`Oh01_mS`Ogo
H<7moeg1o?mM`OcoFL7kob=fh`;oF7GE0_mIM=<01?mQM=3oHGC?of=dcomSM<l2of]gc@03og=kc?nJ
T<So^j6n00;o^j6n0onoY;h00oo0YKgo`jRool>Y_`02om;4c00=omkkeooIo]Cod_o@olkodOo<om7o
booAol?nd?noo]7o_OgAojcic_nYn<koYoO>oi;^b01Aooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01Oooool002cooooo00?o0000ooooooooool0A?ooool00onA]_3oRKCbohFdm002
ohNel`06ohFfmOn3]oKoP[Sgoh:hmon0^OSoOk[i0_mm^oX01_ml_?_oN[glogZmo?mh__coM[omogC0
oP;oN<;n00KoM/;nogC3o_maa?ooLLCoofo5oom/aOh2og37o`03ofg7oomZb?koIlSm00;o8gKS00Go
FGCCoeYddomJM=?oHGC?of=dc`02ofQfcP04og=kc?nJT<SoVY38ok^Q_P;o_::n017o_jBnol6W_oo3
Z;oo`jRoom73cOoBa<cog__GomWne?oDom7od_o@olWocoo5om3o`ok@okKkconcnloo/O[?oi_bbP1E
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool002gooooo0_l00014oooo
o`05oi>gl?nD]nooU;O_ohffl_n:]_<00_n7]o@01_n6^?KoQ;WgohBimon3^_SoP[_ioh6lnP;oQ;gj
00OoP[kjoh70nomo`OcoOl7logg2oOml`ogoOlCm00;oOLGn00KoNlKnogW7oomiaoooMlSoog[9oomh
b_l2ogK;o`06og?<oomgcOooM<koobAfhomJM=?oG7CB0_mMM=801?mXM/koL7_>oiZAb_nJTLX3okbR
_P;o`JNo00go`jRoom73cOoA`lgog?cGomOoe?o>oloocOo?ol_oconnoLoo^_c?ojSgbonUm/_oXoG;
05Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`00;oooool00ol0003o
ooooooooo`13ooooo`;oU[S_00OoSkOaohbglon:^?CoR[SdohRimOn;^OGoR[_f00;oRKcg00OoR;gh
ohJnnOn5_o[oQKojohC1non7`__oQL?l00;oQ<Cl00?oP/GmohG7oOn4b?h00_n2bOh01?n0b_ooPl_o
oh;<oomocOl2oh??o`07oh7@oomnd?ooP];ooh3BoolUM^?oG7CBoeeddP02of=gd@04og1kc_nJTL[o
VY7:okbR_P;o_ZK000_o`JNoom33c_oA`lgog?cGomOoe?o8olkoa?k>ol;nc_o0o/ko[oW<o`00001L
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool0033ooooo00?o0000oooo
ooooool0@oooool01_nG^>koTKOaoi6glOn>^?;oTKSbohnil`;oS[[d00?oSK_fohbmmon;__P00_n=
_oL02?n<`?SoRl;ioh[3n_n:`o[oR<Ckoh_5non:aocoR<Sm0_n<bO`00on:b_goR<_nohO=oP02oh[>
oP06ohS?oon6d?ooRM7oohSBoon;doooRMCo0_n<e_l01?lVMn?o:7STof=gdOm/O=42oiZDc@?o_ZK0
00SocL?@om33c_oHoMWoc?o@olSoc_njo<go]O_<ok?jc5oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`04ooooo`00<Oooool00ol0003oooooooooo`13ooooo`03oiVik_nC^?3oUKW`
00;oTkWa00SoTK[boi2km?n@^oCoSkceoi6mm?nA_oKoT<3goho1n0;oTL;g00?oT<Choho5nOn>a_X0
0_nAaoX00on@b?_oSl[loi7;n`02oi3<o006oho=oOnAc_goT=3mohoAo_nBd_koT=?n0_nCe?h01onA
e_koT=Oooi?Ho_nAfOooU=Wnoc5mi_m/O=400_nJU<d01onnY/3ocL?@olg3d?oBo]_o`_k?okkmcOnj
o<d0Hoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo000booooo`;o0000
A?ooool00onJ^NkoVk[]oiNik`02oiFjl@03oi>kl_nF^o7oUKgc00;oU;kd00GoTkoeoiK0m?nE`_Ko
U<?goi?4n002oiK5m`03oiC7n?nCb?WoU/Wi00;oUL[j00KoU<ckoiO<n_nFc__oU<oloiO@o?nFdO`2
oiWBo006oiODoOnFeOgoVMKmoiSGoOnKeocoV]Sm0_nNeo`01onMf?co@hSZoiRcj_nH/n[ocL?@om;n
foo:omD0Ioooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo000dooooo`03
o`000?oooooooooo04;ooooo0_nM^^d00onI^^ooUk[`oiVkl002oiRll@03oiNml_nF_o?oV;oc00;o
V<7d00GoUl;eoiK4m_nIa?KoV<KgoiO7n002oiW8m`05oiW9n?nHboWoV/cioiW=n_nLc_T00_nKcoX0
2OnJdO_oW=7joi_CnonNd_[oWMCkoj7CnOnPe?[oXm;hoj?Cn@1aooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool003Gooooo00?o0000ooooooooool0@_ooool2oijjk005oi^j
k_nL^nkoVkc_oiZml?nI__800_nK_o400onJ`?;oV/;coic2l`02oi_4m005oi_5mOnMa_CoW<Ofoic9
monNbOH00_nMboL01_nLc?SoWlggoik>n?nQc_OoX<ohoioAn@;oX]3h00?oXM7iojC@m_nTdOL0Looo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo000fooooo`03o`000?oooooo
oooo04;ooooo00WoWk_/oj6kk?nN^ngoW[_]oiflkonN_NkoW[k_oifol?nM`O400_nN`O400onN`o;o
W/Ccoj35lP02oio6m008oik8mOnQb?CoX<Weoj;9m?nRboGoXLgfojC<mOnScOH2ojK<m003ojG=m?nU
c_Kooooo07Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`00=oooool2
o`0004Cooooo00?oX[_[oinlkOnQ_>`00_nP_Nd01OnO_^ooWl3`oj70konQ`_3oX<?a00;oX/Ca00Go
X/Gboj77lonSao;oXlScojG8lP02ojG9l`03ojC;m?nVbO;oY/_c07cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`04ooooo`00>Oooool00ol0003oooooooooo`11ooooo`;oXkc[00Go
XKc/oj>mk?nR_^goXKo^oj>ok@02oj?1kP04oj;2konT`^ooY<C`ojC5l@;oY/G`00CoYLKaojO6konW
ao3oYlSaOoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo000jooooo`03
o`000?oooooooooo047ooooo00WoY;cZojFlj_nT_N_oY;g[ojBnk?nU_^_oYL3]ojG1k_nV`Nd00_nV
`^h00onVa>ooYl?]ojO4kP24ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool003_ooooo00?o0000ooooooooool0@_ooool00onV_NWoY[gZojNnjP02ojNoj`04ojK0k?nX`>_o
Z<7/ojS2kHSooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`00??ooool2
o`0004?ooooo00CoYkgYojRmj?nX_^WoZ;oZSOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo000nooooo`03o`000?oooooooooo043ooooo00?oZ;gXo`000?ooool0S_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo000oooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo0010ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Soooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0011ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0Soooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
0012ooooo`;o0000?_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool004Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2A
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool004Gooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`2Booooo`05o`000?ooooooooooooooool000001?ooool0
04Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2Booooo`05o`000?oooooooooo
ooooool000001?ooool004Oooooo0_l0000iooooo`03o`000?oooooooooo09?ooooo00Co0000oooo
oooooooo00001?ooool004Wooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Doooo
o`03o`000?oooooo000000Cooooo001:ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0U?ooool01?l0003oooooooooool00003ooooo`00Boooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo09Gooooo00?o0000ooooool000000oooool004cooooo0_l0000dooooo`03o`00
0?oooooooooo09Kooooo0_l00003ooooo`00C_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo09Kooooo0ol00003ooooo`00Coooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo09;ooooo1?l00006ooooo`00D?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
08kooooo1?l0000:ooooo`00DOooool2o`0002kooooo00?o0000ooooooooool0Roooool3o`0000ko
oooo001Cooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Qoooool4o`00017ooooo
001Dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Poooool4o`0001Gooooo001E
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Ooooool4o`0001Wooooo001Foooo
o`;o0000:Oooool00ol0003oooooooooo`1kooooo`Co00007Oooool005Sooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1hooooo`?o00008Oooool005Wooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1dooooo`Co00009?ooool005[ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1`ooooo`Co0000:?ooool005_ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1/ooooo`Co0000;?ooool005cooooo0_l0000Sooooo`03o`000?oooooooooo
06Sooooo1?l0000`ooooo`00G_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Go
oooo0ol0000dooooo`00Goooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo
1?l0000gooooo`00H?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05gooooo1?l0
000kooooo`00HOooool2o`0001kooooo00?o0000ooooooooool0FOooool4o`0003oooooo001Soooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0EOooool4o`0004?ooooo001Tooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0D_ooool3o`0004Oooooo001Uooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool4o`0004[ooooo001Vooooo`;o00006Ooo
ool00ol0003oooooooooo`1:ooooo`Co0000C_ooool006Sooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`16ooooo`Co0000D_ooool006Wooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`12ooooo`Co0000E_ooool006[ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0oooooo`?o0000F_ooool006_ooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo
1?l0001Mooooo`00KOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo1?l0
001Qooooo`00K_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo1?l0001U
ooooo`00Koooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo1?l0001Yoooo
o`00L?ooool2o`0000kooooo00?o0000ooooooooool0;Oooool3o`0006gooooo001booooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool4o`00073ooooo001cooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool09Oooool4o`0007Cooooo001dooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool08Oooool4o`0007Sooooo001eooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07Oooool4o`0007cooooo001fooooo`;o00002?ooool00ol0003o
ooooooooo`0Jooooo`?o0000P?ooool007Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Fooooo`Co0000Poooool007Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Booooo`Co0000Qoooool007[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`Co0000Roooool007_ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002?oooo
o`00OOooool01?l0003oooooooooool00009ooooo`?o0000Toooool007kooooo00?o0000ooooool0
00001Oooool4o`0009Kooooo001oooooo`;o000000?oooooo`000?l000000_l0002Jooooo`00P?oo
ool2o`0009kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo000^ooooo`?o00001?ooool3o`0000;ooooo0ol00003ooooo`Go00000_ooool3
o`0000?ooooo0ol00004ooooo`;o00002?ooool2o`000005ooooool0003o0000o`000?ooool00ol0
0003ooooo`Co00000oooool2o`000003ooooool0003o000000Co00000_ooool4o`0000?ooooo0_l0
0002ooooo`Go00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000007ooooo`?o00000_oo
ool3o`0000Cooooo1?l000001Ooooooo0000o`000?l0003ooooo00Ko00000_ooool5o`0000;ooooo
0ol00002ooooo`?o00002Oooool3o`0000Gooooo0_l000000ooooooo0000o`000002o`000004oooo
ool0003o0000ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000003
ooooool0003o000001[ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00001oooool01ol0003ooooooooooooo
oooo0000ooooool000000oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001_o
oooo000_ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooooooo1Ol000000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo00So
oooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`?o0000
0oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`?o00001?ooool0
1?l0003oooooooooooooool5o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool06Oooool002oooooo0ol00002ooooo`05o`000?oooooo
ooooooooool000000_ooool2o`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo00002_ooool01ol0003ooooooooooooooooo0000
ooooool000000oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00Co0000
oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;o00002_ooool3o`0000?ooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo
00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Iooooo`00;oooool01?l0003oooooooooool00002ooooo`?o00000_ooool2
o`000003ooooool0003o000000;ooooo1?l00002ooooo`?o00000oooool3o`0000;ooooo1?l00008
ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000?ooooo0ol00002ooooo`;o000000?o
ooooo`000?l000000oooool00ol0003oooooooooo`02ooooo`;o00000oooool4o`0000;ooooo0ol0
0004ooooo`?o00000_ooool4o`0000Sooooo00Ko0000ooooool0003oooooo`000?ooool2o`000003
ooooool0003o000000;ooooo0_l00003ooooo`Co00000oooool4o`0000;ooooo1?l00002ooooo`?o
00000_ooool2o`000003ooooool0003o000000Sooooo00?o0000ooooooooool00_ooool2o`000004
ooooool0003o0000ooooo`Co00000oooool3o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`00
00;ooooo1?l0000Looooo`00;oooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02?ooool2o`000003ooooool0003o000000[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00Go0000oooo
ool0003oooooo`00000Kooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00005?oo
ool00ol0003oooooooooo`0^ooooo`00;_ooool4o`00017ooooo0_l0000>ooooo`03o`000?oooooo
oooo00Sooooo00Co0000oooooooooooooooo0_l00008ooooo`;o00002?ooool3o`0000[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`Go00007?ooool2o`0001?ooooo1Ol0
000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0901317, 0.0476865, \
0.00366202, 0.00366202}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -84 0 ]
[.5 .82364 84 9 ]
[.13556 .20368 -23.9342 -9 ]
[.13556 .20368 .06581 0 ]
[.33513 .12517 -5.58548 -9 ]
[.33513 .12517 .41452 0 ]
[.55094 .04033 -15.5622 -9 ]
[.55094 .04033 2.43778 0 ]
[.76193 .08858 0 -6.1701 ]
[.76193 .08858 24 2.8299 ]
[.85677 .2338 0 -6.03088 ]
[.85677 .2338 6 2.96912 ]
[.93949 .36049 0 -5.91308 ]
[.93949 .36049 18 3.08692 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01645 .31313 -24 -2.78292 ]
[.01645 .31313 0 6.21708 ]
[.00854 .36268 -18 -2.82493 ]
[.00854 .36268 0 6.17507 ]
[.00038 .41383 -24 -2.86844 ]
[.00038 .41383 0 6.13156 ]
[-0.00804 .46664 -18 -2.91353 ]
[-0.00804 .46664 0 6.08647 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Modulation Transfer Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.14481 .21299 m
.14944 .21764 L
s
[(-100)] .13556 .20368 .99452 1 Mshowa
.3437 .13511 m
.34798 .14008 L
s
[(0)] .33513 .12517 .86183 1 Mshowa
.55867 .05093 m
.56253 .05623 L
s
[(100)] .55094 .04033 .72914 1 Mshowa
.125 Mabswid
.18339 .19788 m
.18613 .20071 L
s
.22255 .18254 m
.22525 .18541 L
s
.26232 .16697 m
.26497 .16988 L
s
.30269 .15116 m
.30531 .15411 L
s
.38535 .1188 m
.38787 .12182 L
s
.42765 .10223 m
.43013 .10529 L
s
.47063 .0854 m
.47305 .0885 L
s
.5143 .06831 m
.51667 .07145 L
s
.1068 .22787 m
.10961 .23062 L
s
.06936 .24253 m
.0722 .24525 L
s
.60376 .03327 m
.60603 .03649 L
s
.6496 .01532 m
.65181 .01859 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74963 .09314 m
.74348 .09542 L
s
[(-100)] .76193 .08858 -1 .37113 Mshowa
.84435 .23803 m
.83813 .24014 L
s
[(0)] .85677 .2338 -1 .34019 Mshowa
.92697 .36442 m
.92071 .36638 L
s
[(100)] .93949 .36049 -1 .31402 Mshowa
.125 Mabswid
.76966 .12379 m
.76597 .12514 L
s
.78913 .15357 m
.78542 .1549 L
s
.80805 .18251 m
.80434 .18382 L
s
.82645 .21065 m
.82273 .21194 L
s
.86176 .26467 m
.85803 .26592 L
s
.87871 .2906 m
.87497 .29183 L
s
.89522 .31585 m
.89148 .31706 L
s
.9113 .34045 m
.90755 .34164 L
s
.72899 .06158 m
.72531 .06297 L
s
.70774 .02907 m
.70407 .03048 L
s
.94225 .38778 m
.93849 .38895 L
s
.95714 .41057 m
.95338 .41171 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02871 .30846 m
.03484 .30612 L
s
[(0.05)] .01645 .31313 1 -0.38157 Mshowa
.02084 .3581 m
.02699 .35582 L
s
[(0.1)] .00854 .36268 1 -0.37224 Mshowa
.01272 .40935 m
.01889 .40712 L
s
[(0.15)] .00038 .41383 1 -0.36257 Mshowa
.00433 .46228 m
.01052 .4601 L
s
[(0.2)] -0.00804 .46664 1 -0.35255 Mshowa
.125 Mabswid
.03483 .26984 m
.0385 .26841 L
s
.03331 .2794 m
.03699 .27798 L
s
.03179 .28903 m
.03546 .28761 L
s
.03025 .29871 m
.03393 .2973 L
s
.02716 .31826 m
.03084 .31686 L
s
.02559 .32813 m
.02928 .32674 L
s
.02402 .33806 m
.0277 .33667 L
s
.02244 .34805 m
.02612 .34667 L
s
.01924 .36822 m
.02293 .36686 L
s
.01763 .37841 m
.02132 .37705 L
s
.016 .38866 m
.0197 .3873 L
s
.01437 .39897 m
.01807 .39762 L
s
.01107 .4198 m
.01477 .41847 L
s
.0094 .43032 m
.0131 .42899 L
s
.00772 .4409 m
.01143 .43958 L
s
.00603 .45156 m
.00974 .45024 L
s
.00262 .47308 m
.00634 .47177 L
s
.0009 .48394 m
.00462 .48265 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.647 .738 .915 r
.40204 .60086 .40512 .60371 .41029 .60219 .40721 .59952 Mtetra
.648 .752 .925 r
.40721 .59952 .41029 .60219 .41547 .60067 .41239 .59815 Mtetra
.669 .768 .924 r
.41239 .59815 .41547 .60067 .42066 .59912 .41759 .59649 Mtetra
.681 .763 .913 r
.41759 .59649 .42066 .59912 .42586 .59752 .4228 .59467 Mtetra
.652 .741 .915 r
.4228 .59467 .42586 .59752 .43107 .59596 .42801 .59326 Mtetra
.673 .756 .913 r
.42801 .59326 .43107 .59596 .43628 .59439 .43324 .59154 Mtetra
.661 .744 .912 r
.43324 .59154 .43628 .59439 .44151 .59283 .43848 .59 Mtetra
.663 .747 .912 r
.43848 .59 .44151 .59283 .44675 .59123 .44372 .58843 Mtetra
.67 .751 .911 r
.44372 .58843 .44675 .59123 .452 .58968 .44898 .58676 Mtetra
.661 .74 .909 r
.44898 .58676 .452 .58968 .45726 .58809 .45425 .58522 Mtetra
.663 .744 .911 r
.45425 .58522 .45726 .58809 .46253 .5865 .45952 .58364 Mtetra
.667 .746 .91 r
.45952 .58364 .46253 .5865 .46781 .58494 .46481 .582 Mtetra
.663 .741 .908 r
.46481 .582 .46781 .58494 .4731 .58333 .47011 .58041 Mtetra
.663 .742 .909 r
.47011 .58041 .4731 .58333 .4784 .58175 .47541 .57883 Mtetra
.666 .743 .908 r
.47541 .57883 .4784 .58175 .48371 .58017 .48073 .57719 Mtetra
.662 .739 .907 r
.48073 .57719 .48371 .58017 .48903 .57855 .48606 .57561 Mtetra
.664 .743 .908 r
.48606 .57561 .48903 .57855 .49436 .57698 .4914 .574 Mtetra
.663 .74 .907 r
.4914 .574 .49436 .57698 .49971 .57536 .49675 .57239 Mtetra
.664 .742 .908 r
.49675 .57239 .49971 .57536 .50506 .57377 .50211 .57077 Mtetra
.663 .739 .907 r
.50211 .57077 .50506 .57377 .51042 .57217 .50748 .56917 Mtetra
.664 .739 .906 r
.50748 .56917 .51042 .57217 .5158 .57052 .51286 .56755 Mtetra
.663 .742 .909 r
.51286 .56755 .5158 .57052 .52118 .56894 .51825 .56593 Mtetra
.663 .74 .907 r
.51825 .56593 .52118 .56894 .52657 .56736 .52365 .56431 Mtetra
.664 .738 .905 r
.52365 .56431 .52657 .56736 .53198 .56576 .52906 .56268 Mtetra
.662 .736 .904 r
.52906 .56268 .53198 .56576 .53739 .56415 .53448 .56107 Mtetra
.662 .737 .905 r
.53448 .56107 .53739 .56415 .54282 .56254 .53992 .55946 Mtetra
.663 .737 .904 r
.53992 .55946 .54282 .56254 .54826 .56094 .54536 .55783 Mtetra
.665 .736 .902 r
.54536 .55783 .54826 .56094 .55371 .55934 .55081 .55616 Mtetra
.661 .731 .901 r
.55081 .55616 .55371 .55934 .55917 .55769 .55628 .55456 Mtetra
.658 .733 .905 r
.55628 .55456 .55917 .55769 .56463 .55595 .56176 .553 Mtetra
.657 .746 .915 r
.56176 .553 .56463 .55595 .57012 .55434 .56725 .55144 Mtetra
.67 .753 .913 r
.56725 .55144 .57012 .55434 .57561 .55287 .57274 .54969 Mtetra
.665 .733 .901 r
.57274 .54969 .57561 .55287 .58111 .55113 .57825 .54801 Mtetra
.648 .733 .911 r
.57825 .54801 .58111 .55113 .58662 .5494 .58378 .54658 Mtetra
.681 .763 .913 r
.58378 .54658 .58662 .5494 .59215 .54792 .5893 .54465 Mtetra
.641 .721 .906 r
.5893 .54465 .59215 .54792 .59768 .54599 .59485 .54332 Mtetra
.675 .773 .924 r
.59485 .54332 .59768 .54599 .60323 .54457 .6004 .54147 Mtetra
.642 .733 .915 r
.6004 .54147 .60323 .54457 .60878 .54274 .60598 .54011 Mtetra
.689 .78 .92 r
.60598 .54011 .60878 .54274 .61436 .54123 .61154 .53805 Mtetra
.624 .722 .917 r
.61154 .53805 .61436 .54123 .61993 .5394 .61714 .53693 Mtetra
.697 .794 .925 r
.61714 .53693 .61993 .5394 .62553 .53794 .62273 .53473 Mtetra
.631 .723 .914 r
.62273 .53473 .62553 .53794 .63112 .53595 .62835 .53352 Mtetra
.65 .786 .947 r
.62835 .53352 .63112 .53595 .63674 .53464 .63398 .53193 Mtetra
.7 .779 .913 r
.63398 .53193 .63674 .53464 .64236 .53278 .63959 .52967 Mtetra
.585 .714 .932 r
.63959 .52967 .64236 .53278 .648 .53113 .64527 .52899 Mtetra
.701 .825 .942 r
.64527 .52899 .648 .53113 .65366 .5297 .6509 .5267 Mtetra
.606 .73 .933 r
.6509 .5267 .65366 .5297 .6593 .52769 .6566 .52574 Mtetra
.692 .839 .953 r
.6566 .52574 .6593 .52769 .66499 .5265 .66226 .52352 Mtetra
.641 .745 .924 r
.66226 .52352 .66499 .5265 .6707 .52527 .66796 .52212 Mtetra
.671 .744 .906 r
.66796 .52212 .6707 .52527 .67641 .52391 .67366 .52029 Mtetra
.658 .711 .887 r
.67366 .52029 .67641 .52391 .68206 .52114 .67938 .51867 Mtetra
.669 .793 .941 r
.67938 .51867 .68206 .52114 .68778 .51942 .68509 .51681 Mtetra
.654 .778 .94 r
.68509 .51681 .68778 .51942 .69351 .51775 .69083 .51516 Mtetra
.658 .782 .94 r
.69083 .51516 .69351 .51775 .69922 .51561 .69658 .51345 Mtetra
.724 .833 .932 r
.69658 .51345 .69922 .51561 .70499 .51412 .70229 .51078 Mtetra
.611 .712 .917 r
.70229 .51078 .70499 .51412 .71075 .51238 .7081 .50981 Mtetra
.694 .795 .927 r
.7081 .50981 .71075 .51238 .71651 .51041 .71386 .50758 Mtetra
.662 .766 .928 r
.71386 .50758 .71651 .51041 .72231 .50893 .71965 .50584 Mtetra
.647 .744 .92 r
.71965 .50584 .72231 .50893 .72809 .50688 .72547 .50433 Mtetra
.703 .801 .925 r
.72547 .50433 .72809 .50688 .73391 .5054 .73125 .50196 Mtetra
.628 .714 .909 r
.73125 .50196 .73391 .5054 .73972 .50339 .73712 .50076 Mtetra
.698 .794 .925 r
.73712 .50076 .73972 .50339 .74557 .5019 .74292 .49846 Mtetra
.638 .719 .906 r
.74292 .49846 .74557 .5019 .75139 .49988 .7488 .4971 Mtetra
.691 .782 .92 r
.7488 .4971 .75139 .49988 .75727 .49837 .75464 .49489 Mtetra
.644 .719 .903 r
.75464 .49489 .75727 .49837 .76313 .49652 .76054 .49344 Mtetra
.674 .757 .913 r
.76054 .49344 .76313 .49652 .769 .49471 .76641 .49151 Mtetra
.67 .748 .909 r
.76641 .49151 .769 .49471 .77491 .4931 .77231 .48963 Mtetra
.654 .725 .901 r
.77231 .48963 .77491 .4931 .7808 .49119 .77823 .48801 Mtetra
.668 .75 .912 r
.77823 .48801 .7808 .49119 .78671 .48929 .78415 .48616 Mtetra
.67 .754 .913 r
.78415 .48616 .78671 .48929 .79265 .48765 .79008 .48427 Mtetra
.666 .737 .903 r
.79008 .48427 .79265 .48765 .79859 .48589 .79603 .48243 Mtetra
.663 .731 .901 r
.79603 .48243 .79859 .48589 .80454 .48407 .80199 .48066 Mtetra
.664 .735 .903 r
.80199 .48066 .80454 .48407 .81051 .48225 .80796 .47886 Mtetra
.665 .737 .904 r
.80796 .47886 .81051 .48225 .81648 .48043 .81395 .47705 Mtetra
.665 .738 .904 r
.81395 .47705 .81648 .48043 .82247 .47862 .81995 .47522 Mtetra
.664 .736 .904 r
.81995 .47522 .82247 .47862 .82847 .4768 .82596 .47341 Mtetra
.664 .737 .905 r
.82596 .47341 .82847 .4768 .83448 .47496 .83198 .47159 Mtetra
.664 .74 .906 r
.83198 .47159 .83448 .47496 .84051 .4731 .83802 .46978 Mtetra
.664 .743 .909 r
.83802 .46978 .84051 .4731 .84655 .47133 .84406 .46795 Mtetra
.663 .739 .906 r
.84406 .46795 .84655 .47133 .8526 .46952 .85013 .46613 Mtetra
.664 .74 .906 r
.85013 .46613 .8526 .46952 .85866 .46766 .8562 .4643 Mtetra
.663 .742 .909 r
.8562 .4643 .85866 .46766 .86474 .46587 .86229 .46248 Mtetra
.664 .74 .907 r
.86229 .46248 .86474 .46587 .87083 .46401 .86839 .46064 Mtetra
.664 .742 .909 r
.86839 .46064 .87083 .46401 .87694 .46221 .8745 .4588 Mtetra
.662 .74 .907 r
.8745 .4588 .87694 .46221 .88305 .46035 .88063 .45698 Mtetra
.665 .744 .909 r
.88063 .45698 .88305 .46035 .88918 .45852 .88676 .45511 Mtetra
.662 .74 .908 r
.88676 .45511 .88918 .45852 .89532 .45669 .89292 .45329 Mtetra
.662 .741 .909 r
.89292 .45329 .89532 .45669 .90147 .45481 .89908 .45146 Mtetra
.666 .747 .911 r
.89908 .45146 .90147 .45481 .90764 .45299 .90525 .44957 Mtetra
.662 .741 .909 r
.90525 .44957 .90764 .45299 .91382 .45113 .91145 .44773 Mtetra
.659 .742 .911 r
.91145 .44773 .91382 .45113 .92001 .44925 .91766 .44594 Mtetra
.667 .751 .913 r
.91766 .44594 .92001 .44925 .92622 .44742 .92387 .444 Mtetra
.659 .741 .911 r
.92387 .444 .92622 .44742 .93244 .44553 .9301 .44219 Mtetra
.659 .747 .915 r
.9301 .44219 .93244 .44553 .93868 .44369 .93635 .44038 Mtetra
.667 .753 .915 r
.93635 .44038 .93868 .44369 .94492 .44179 .9426 .43844 Mtetra
.654 .745 .917 r
.9426 .43844 .94492 .44179 .95118 .43996 .94889 .43669 Mtetra
.652 .75 .922 r
.94889 .43669 .95118 .43996 .95746 .43808 .95519 .43498 Mtetra
.672 .771 .924 r
.95519 .43498 .95746 .43808 .96374 .43617 .96147 .43293 Mtetra
.679 .765 .916 r
.96147 .43293 .96374 .43617 .97003 .43424 .96774 .43078 Mtetra
.637 .735 .919 r
.39896 .598 .40204 .60086 .40721 .59952 .40413 .59678 Mtetra
.655 .749 .919 r
.40413 .59678 .40721 .59952 .41239 .59815 .40931 .59533 Mtetra
.686 .751 .901 r
.40931 .59533 .41239 .59815 .41759 .59649 .41453 .59342 Mtetra
.664 .73 .899 r
.41453 .59342 .41759 .59649 .4228 .59467 .41974 .59185 Mtetra
.672 .749 .908 r
.41974 .59185 .4228 .59467 .42801 .59326 .42496 .59016 Mtetra
.664 .729 .898 r
.42496 .59016 .42801 .59326 .43324 .59154 .43019 .58858 Mtetra
.665 .738 .905 r
.43019 .58858 .43324 .59154 .43848 .59 .43544 .58699 Mtetra
.662 .734 .903 r
.43544 .58699 .43848 .59 .44372 .58843 .44069 .58543 Mtetra
.661 .735 .905 r
.44069 .58543 .44372 .58843 .44898 .58676 .44595 .58388 Mtetra
.665 .745 .91 r
.44595 .58388 .44898 .58676 .45425 .58522 .45122 .58228 Mtetra
.666 .741 .906 r
.45122 .58228 .45425 .58522 .45952 .58364 .45651 .58065 Mtetra
.66 .737 .907 r
.45651 .58065 .45952 .58364 .46481 .582 .4618 .5791 Mtetra
.663 .744 .911 r
.4618 .5791 .46481 .582 .47011 .58041 .4671 .57751 Mtetra
.668 .745 .908 r
.4671 .57751 .47011 .58041 .47541 .57883 .47242 .57585 Mtetra
.661 .739 .908 r
.47242 .57585 .47541 .57883 .48073 .57719 .47774 .57428 Mtetra
.664 .744 .91 r
.47774 .57428 .48073 .57719 .48606 .57561 .48307 .57266 Mtetra
.665 .743 .908 r
.48307 .57266 .48606 .57561 .4914 .574 .48842 .57103 Mtetra
.663 .741 .909 r
.48842 .57103 .4914 .574 .49675 .57239 .49378 .56943 Mtetra
.664 .743 .908 r
.49378 .56943 .49675 .57239 .50211 .57077 .49914 .5678 Mtetra
.663 .742 .908 r
.49914 .5678 .50211 .57077 .50748 .56917 .50452 .56618 Mtetra
.663 .741 .909 r
.50452 .56618 .50748 .56917 .51286 .56755 .5099 .56457 Mtetra
.664 .743 .908 r
.5099 .56457 .51286 .56755 .51825 .56593 .5153 .56293 Mtetra
.663 .741 .908 r
.5153 .56293 .51825 .56593 .52365 .56431 .52071 .56131 Mtetra
.663 .742 .909 r
.52071 .56131 .52365 .56431 .52906 .56268 .52613 .55969 Mtetra
.662 .742 .909 r
.52613 .55969 .52906 .56268 .53448 .56107 .53156 .55807 Mtetra
.663 .742 .909 r
.53156 .55807 .53448 .56107 .53992 .55946 .537 .55644 Mtetra
.663 .741 .908 r
.537 .55644 .53992 .55946 .54536 .55783 .54245 .55481 Mtetra
.661 .741 .909 r
.54245 .55481 .54536 .55783 .55081 .55616 .54791 .55319 Mtetra
.657 .744 .914 r
.54791 .55319 .55081 .55616 .55628 .55456 .55339 .55163 Mtetra
.66 .748 .915 r
.55339 .55163 .55628 .55456 .56176 .553 .55887 .55002 Mtetra
.671 .748 .908 r
.55887 .55002 .56176 .553 .56725 .55144 .56436 .54824 Mtetra
.661 .731 .901 r
.56436 .54824 .56725 .55144 .57274 .54969 .56987 .54662 Mtetra
.65 .737 .913 r
.56987 .54662 .57274 .54969 .57825 .54801 .57539 .54516 Mtetra
.677 .759 .913 r
.57539 .54516 .57825 .54801 .58378 .54658 .58092 .54328 Mtetra
.649 .722 .902 r
.58092 .54328 .58378 .54658 .5893 .54465 .58646 .54184 Mtetra
.662 .759 .922 r
.58646 .54184 .5893 .54465 .59485 .54332 .59201 .54018 Mtetra
.655 .735 .908 r
.59201 .54018 .59485 .54332 .6004 .54147 .59757 .53862 Mtetra
.671 .76 .917 r
.59757 .53862 .6004 .54147 .60598 .54011 .60314 .53683 Mtetra
.637 .721 .908 r
.60314 .53683 .60598 .54011 .61154 .53805 .60874 .53555 Mtetra
.705 .795 .92 r
.60874 .53555 .61154 .53805 .61714 .53693 .61431 .53323 Mtetra
.619 .689 .894 r
.61431 .53323 .61714 .53693 .62273 .53473 .61994 .53223 Mtetra
.673 .788 .935 r
.61994 .53223 .62273 .53473 .62835 .53352 .62555 .53036 Mtetra
.679 .744 .9 r
.62555 .53036 .62835 .53352 .63398 .53193 .63117 .52842 Mtetra
.619 .702 .904 r
.63117 .52842 .63398 .53193 .63959 .52967 .63683 .5274 Mtetra
.718 .817 .927 r
.63683 .5274 .63959 .52967 .64527 .52899 .64246 .52485 Mtetra
.617 .666 .875 r
.64246 .52485 .64527 .52899 .6509 .5267 .64815 .52391 Mtetra
.7 .777 .911 r
.64815 .52391 .6509 .5267 .6566 .52574 .6538 .52164 Mtetra
.659 .685 .864 r
.6538 .52164 .6566 .52574 .66226 .52352 .65949 .51998 Mtetra
.684 .725 .881 r
.65949 .51998 .66226 .52352 .66796 .52212 .66517 .51791 Mtetra
.659 .681 .86 r
.66517 .51791 .66796 .52212 .67366 .52029 .67088 .51624 Mtetra
.652 .686 .869 r
.67088 .51624 .67366 .52029 .67938 .51867 .67661 .51469 Mtetra
.648 .689 .874 r
.67661 .51469 .67938 .51867 .68509 .51681 .68235 .51322 Mtetra
.654 .713 .891 r
.68235 .51322 .68509 .51681 .69083 .51516 .6881 .51164 Mtetra
.673 .724 .888 r
.6881 .51164 .69083 .51516 .69658 .51345 .69385 .50975 Mtetra
.637 .701 .892 r
.69385 .50975 .69658 .51345 .70229 .51078 .69964 .50845 Mtetra
.728 .821 .923 r
.69964 .50845 .70229 .51078 .7081 .50981 .70537 .50569 Mtetra
.613 .668 .879 r
.70537 .50569 .7081 .50981 .71386 .50758 .7112 .50478 Mtetra
.677 .774 .924 r
.7112 .50478 .71386 .50758 .71965 .50584 .71699 .50281 Mtetra
.684 .761 .909 r
.71699 .50281 .71965 .50584 .72547 .50433 .72279 .50073 Mtetra
.632 .706 .899 r
.72279 .50073 .72547 .50433 .73125 .50196 .72864 .49947 Mtetra
.706 .807 .928 r
.72864 .49947 .73125 .50196 .73712 .50076 .73444 .49704 Mtetra
.635 .701 .894 r
.73444 .49704 .73712 .50076 .74292 .49846 .74032 .49575 Mtetra
.688 .787 .926 r
.74032 .49575 .74292 .49846 .7488 .4971 .74615 .49359 Mtetra
.651 .721 .9 r
.74615 .49359 .7488 .4971 .75464 .49489 .75204 .49203 Mtetra
.687 .777 .919 r
.75204 .49203 .75464 .49489 .76054 .49344 .7579 .48987 Mtetra
.647 .716 .899 r
.7579 .48987 .76054 .49344 .76641 .49151 .76382 .48837 Mtetra
.672 .754 .912 r
.76382 .48837 .76641 .49151 .77231 .48963 .76972 .48645 Mtetra
.67 .75 .911 r
.76972 .48645 .77231 .48963 .77823 .48801 .77563 .48456 Mtetra
.656 .729 .903 r
.77563 .48456 .77823 .48801 .78415 .48616 .78157 .48289 Mtetra
.664 .744 .909 r
.78157 .48289 .78415 .48616 .79008 .48427 .78752 .48109 Mtetra
.669 .752 .912 r
.78752 .48109 .79008 .48427 .79603 .48243 .79347 .4792 Mtetra
.666 .748 .911 r
.79347 .4792 .79603 .48243 .80199 .48066 .79944 .47735 Mtetra
.664 .742 .909 r
.79944 .47735 .80199 .48066 .80796 .47886 .80542 .47554 Mtetra
.664 .742 .908 r
.80542 .47554 .80796 .47886 .81395 .47705 .81141 .47372 Mtetra
.665 .742 .908 r
.81141 .47372 .81395 .47705 .81995 .47522 .81742 .4719 Mtetra
.664 .743 .909 r
.81742 .4719 .81995 .47522 .82596 .47341 .82344 .47007 Mtetra
.664 .742 .908 r
.82344 .47007 .82596 .47341 .83198 .47159 .82947 .46824 Mtetra
.663 .741 .908 r
.82947 .46824 .83198 .47159 .83802 .46978 .83552 .46643 Mtetra
.664 .742 .909 r
.83552 .46643 .83802 .46978 .84406 .46795 .84157 .4646 Mtetra
.665 .743 .908 r
.84157 .4646 .84406 .46795 .85013 .46613 .84764 .46275 Mtetra
.662 .74 .908 r
.84764 .46275 .85013 .46613 .8562 .4643 .85373 .46094 Mtetra
.665 .744 .909 r
.85373 .46094 .8562 .4643 .86229 .46248 .85982 .45907 Mtetra
.661 .739 .908 r
.85982 .45907 .86229 .46248 .86839 .46064 .86593 .45727 Mtetra
.665 .744 .909 r
.86593 .45727 .86839 .46064 .8745 .4588 .87205 .45541 Mtetra
.663 .742 .909 r
.87205 .45541 .8745 .4588 .88063 .45698 .87819 .45357 Mtetra
.661 .74 .909 r
.87819 .45357 .88063 .45698 .88676 .45511 .88434 .45176 Mtetra
.666 .746 .91 r
.88434 .45176 .88676 .45511 .89292 .45329 .8905 .44986 Mtetra
.664 .742 .908 r
.8905 .44986 .89292 .45329 .89908 .45146 .89667 .44799 Mtetra
.661 .737 .907 r
.89667 .44799 .89908 .45146 .90525 .44957 .90286 .44618 Mtetra
.664 .745 .91 r
.90286 .44618 .90525 .44957 .91145 .44773 .90906 .4443 Mtetra
.667 .743 .908 r
.90906 .4443 .91145 .44773 .91766 .44594 .91527 .44237 Mtetra
.664 .734 .903 r
.91527 .44237 .91766 .44594 .92387 .444 .92149 .4405 Mtetra
.664 .739 .906 r
.92149 .4405 .92387 .444 .9301 .44219 .92773 .43862 Mtetra
.664 .735 .902 r
.92773 .43862 .9301 .44219 .93635 .44038 .93398 .43672 Mtetra
.656 .726 .901 r
.93398 .43672 .93635 .44038 .9426 .43844 .94026 .43497 Mtetra
.669 .744 .907 r
.94026 .43497 .9426 .43844 .94889 .43669 .94653 .433 Mtetra
.64 .718 .904 r
.94653 .433 .94889 .43669 .95519 .43498 .95288 .4315 Mtetra
.664 .743 .909 r
.95288 .4315 .95519 .43498 .96147 .43293 .95918 .42959 Mtetra
.686 .761 .908 r
.95918 .42959 .96147 .43293 .96774 .43078 .96545 .4273 Mtetra
.646 .737 .915 r
.39586 .59511 .39896 .598 .40413 .59678 .40104 .59378 Mtetra
.674 .737 .898 r
.40104 .59378 .40413 .59678 .40931 .59533 .40624 .59206 Mtetra
.67 .72 .886 r
.40624 .59206 .40931 .59533 .41453 .59342 .41145 .59039 Mtetra
.656 .731 .904 r
.41145 .59039 .41453 .59342 .41974 .59185 .41666 .58892 Mtetra
.668 .741 .905 r
.41666 .58892 .41974 .59185 .42496 .59016 .42189 .58727 Mtetra
.663 .743 .91 r
.42189 .58727 .42496 .59016 .43019 .58858 .42713 .5857 Mtetra
.663 .744 .91 r
.42713 .5857 .43019 .58858 .43544 .58699 .43238 .58413 Mtetra
.667 .747 .91 r
.43238 .58413 .43544 .58699 .44069 .58543 .43764 .58249 Mtetra
.665 .741 .907 r
.43764 .58249 .44069 .58543 .44595 .58388 .44291 .58088 Mtetra
.662 .736 .905 r
.44291 .58088 .44595 .58388 .45122 .58228 .44819 .5793 Mtetra
.662 .739 .907 r
.44819 .5793 .45122 .58228 .45651 .58065 .45348 .57773 Mtetra
.664 .744 .909 r
.45348 .57773 .45651 .58065 .4618 .5791 .45878 .57612 Mtetra
.666 .74 .906 r
.45878 .57612 .4618 .5791 .4671 .57751 .46409 .57449 Mtetra
.661 .737 .906 r
.46409 .57449 .4671 .57751 .47242 .57585 .46941 .57293 Mtetra
.664 .744 .91 r
.46941 .57293 .47242 .57585 .47774 .57428 .47474 .57131 Mtetra
.666 .743 .907 r
.47474 .57131 .47774 .57428 .48307 .57266 .48008 .56966 Mtetra
.662 .739 .907 r
.48008 .56966 .48307 .57266 .48842 .57103 .48543 .56807 Mtetra
.665 .743 .908 r
.48543 .56807 .48842 .57103 .49378 .56943 .49079 .56642 Mtetra
.662 .74 .908 r
.49079 .56642 .49378 .56943 .49914 .5678 .49617 .56482 Mtetra
.665 .742 .908 r
.49617 .56482 .49914 .5678 .50452 .56618 .50155 .56318 Mtetra
.663 .741 .908 r
.50155 .56318 .50452 .56618 .5099 .56457 .50694 .56156 Mtetra
.662 .74 .908 r
.50694 .56156 .5099 .56457 .5153 .56293 .51235 .55995 Mtetra
.663 .743 .909 r
.51235 .55995 .5153 .56293 .52071 .56131 .51776 .55832 Mtetra
.662 .742 .91 r
.51776 .55832 .52071 .56131 .52613 .55969 .52319 .5567 Mtetra
.662 .744 .91 r
.52319 .5567 .52613 .55969 .53156 .55807 .52863 .55508 Mtetra
.662 .743 .911 r
.52863 .55508 .53156 .55807 .537 .55644 .53407 .55346 Mtetra
.66 .744 .912 r
.53407 .55346 .537 .55644 .54245 .55481 .53953 .55186 Mtetra
.659 .746 .914 r
.53953 .55186 .54245 .55481 .54791 .55319 .545 .55026 Mtetra
.663 .749 .914 r
.545 .55026 .54791 .55319 .55339 .55163 .55048 .54861 Mtetra
.668 .745 .908 r
.55048 .54861 .55339 .55163 .55887 .55002 .55597 .54688 Mtetra
.661 .736 .905 r
.55597 .54688 .55887 .55002 .56436 .54824 .56147 .54525 Mtetra
.65 .742 .917 r
.56147 .54525 .56436 .54824 .56987 .54662 .56699 .54378 Mtetra
.678 .761 .914 r
.56699 .54378 .56987 .54662 .57539 .54516 .57251 .54189 Mtetra
.653 .726 .902 r
.57251 .54189 .57539 .54516 .58092 .54328 .57805 .54038 Mtetra
.657 .751 .92 r
.57805 .54038 .58092 .54328 .58646 .54184 .5836 .53879 Mtetra
.67 .745 .907 r
.5836 .53879 .58646 .54184 .59201 .54018 .58915 .53701 Mtetra
.648 .732 .91 r
.58915 .53701 .59201 .54018 .59757 .53862 .59473 .53555 Mtetra
.661 .743 .911 r
.59473 .53555 .59757 .53862 .60314 .53683 .60031 .53391 Mtetra
.682 .759 .91 r
.60031 .53391 .60314 .53683 .60874 .53555 .60589 .53193 Mtetra
.631 .699 .894 r
.60589 .53193 .60874 .53555 .61431 .53323 .61151 .53074 Mtetra
.698 .795 .925 r
.61151 .53074 .61431 .53323 .61994 .53223 .6171 .52852 Mtetra
.64 .698 .887 r
.6171 .52852 .61994 .53223 .62555 .53036 .62274 .5272 Mtetra
.653 .736 .911 r
.62274 .5272 .62555 .53036 .63117 .52842 .62838 .52565 Mtetra
.702 .777 .91 r
.62838 .52565 .63117 .52842 .63683 .5274 .63401 .52334 Mtetra
.611 .668 .881 r
.63401 .52334 .63683 .5274 .64246 .52485 .6397 .52249 Mtetra
.708 .809 .928 r
.6397 .52249 .64246 .52485 .64815 .52391 .64534 .52008 Mtetra
.631 .689 .886 r
.64534 .52008 .64815 .52391 .6538 .52164 .65105 .5189 Mtetra
.701 .781 .913 r
.65105 .5189 .6538 .52164 .65949 .51998 .65672 .51659 Mtetra
.643 .72 .904 r
.65672 .51659 .65949 .51998 .66517 .51791 .66243 .51517 Mtetra
.666 .773 .929 r
.66243 .51517 .66517 .51791 .67088 .51624 .66815 .51338 Mtetra
.67 .766 .922 r
.66815 .51338 .67088 .51624 .67661 .51469 .67387 .51154 Mtetra
.645 .738 .917 r
.67387 .51154 .67661 .51469 .68235 .51322 .67962 .51008 Mtetra
.666 .746 .91 r
.67962 .51008 .68235 .51322 .6881 .51164 .68537 .5083 Mtetra
.645 .726 .907 r
.68537 .5083 .6881 .51164 .69385 .50975 .69115 .50684 Mtetra
.71 .775 .903 r
.69115 .50684 .69385 .50975 .69964 .50845 .69689 .50435 Mtetra
.62 .673 .879 r
.69689 .50435 .69964 .50845 .70537 .50569 .70271 .50333 Mtetra
.696 .813 .938 r
.70271 .50333 .70537 .50569 .7112 .50478 .70848 .50106 Mtetra
.656 .709 .886 r
.70848 .50106 .7112 .50478 .71699 .50281 .7143 .49943 Mtetra
.649 .727 .906 r
.7143 .49943 .71699 .50281 .72279 .50073 .72014 .49789 Mtetra
.703 .781 .913 r
.72014 .49789 .72279 .50073 .72864 .49947 .72593 .49551 Mtetra
.628 .686 .885 r
.72593 .49551 .72864 .49947 .73444 .49704 .73181 .49433 Mtetra
.685 .786 .927 r
.73181 .49433 .73444 .49704 .74032 .49575 .73765 .49222 Mtetra
.658 .723 .897 r
.73765 .49222 .74032 .49575 .74615 .49359 .74353 .49054 Mtetra
.672 .759 .916 r
.74353 .49054 .74615 .49359 .75204 .49203 .7494 .48861 Mtetra
.659 .731 .903 r
.7494 .48861 .75204 .49203 .7579 .48987 .7553 .48691 Mtetra
.681 .769 .918 r
.7553 .48691 .7579 .48987 .76382 .48837 .76119 .48485 Mtetra
.648 .721 .902 r
.76119 .48485 .76382 .48837 .76972 .48645 .76712 .48332 Mtetra
.671 .755 .914 r
.76712 .48332 .76972 .48645 .77563 .48456 .77304 .4814 Mtetra
.669 .753 .913 r
.77304 .4814 .77563 .48456 .78157 .48289 .77898 .47951 Mtetra
.66 .735 .906 r
.77898 .47951 .78157 .48289 .78752 .48109 .78494 .47778 Mtetra
.662 .741 .909 r
.78494 .47778 .78752 .48109 .79347 .4792 .79091 .47599 Mtetra
.667 .75 .912 r
.79091 .47599 .79347 .4792 .79944 .47735 .79688 .47413 Mtetra
.667 .749 .912 r
.79688 .47413 .79944 .47735 .80542 .47554 .80287 .47226 Mtetra
.665 .746 .91 r
.80287 .47226 .80542 .47554 .81141 .47372 .80887 .47042 Mtetra
.665 .744 .91 r
.80887 .47042 .81141 .47372 .81742 .4719 .81489 .46858 Mtetra
.665 .744 .909 r
.81489 .46858 .81742 .4719 .82344 .47007 .82091 .46674 Mtetra
.664 .743 .909 r
.82091 .46674 .82344 .47007 .82947 .46824 .82695 .4649 Mtetra
.82695 .4649 .82947 .46824 .83552 .46643 .83301 .46306 Mtetra
.664 .742 .908 r
.83301 .46306 .83552 .46643 .84157 .4646 .83907 .46121 Mtetra
.663 .74 .908 r
.83907 .46121 .84157 .4646 .84764 .46275 .84515 .45938 Mtetra
.664 .743 .909 r
.84515 .45938 .84764 .46275 .85373 .46094 .85124 .45753 Mtetra
.663 .74 .907 r
.85124 .45753 .85373 .46094 .85982 .45907 .85735 .4557 Mtetra
.664 .743 .909 r
.85735 .4557 .85982 .45907 .86593 .45727 .86347 .45384 Mtetra
.661 .738 .907 r
.86347 .45384 .86593 .45727 .87205 .45541 .8696 .45203 Mtetra
.665 .744 .909 r
.8696 .45203 .87205 .45541 .87819 .45357 .87574 .45014 Mtetra
.664 .742 .908 r
.87574 .45014 .87819 .45357 .88434 .45176 .8819 .44827 Mtetra
.661 .737 .906 r
.8819 .44827 .88434 .45176 .8905 .44986 .88807 .44645 Mtetra
.664 .743 .909 r
.88807 .44645 .8905 .44986 .89667 .44799 .89425 .44457 Mtetra
.666 .744 .908 r
.89425 .44457 .89667 .44799 .90286 .44618 .90045 .44266 Mtetra
.664 .738 .905 r
.90045 .44266 .90286 .44618 .90906 .4443 .90665 .44078 Mtetra
.663 .737 .905 r
.90665 .44078 .90906 .4443 .91527 .44237 .91288 .43891 Mtetra
.661 .741 .909 r
.91288 .43891 .91527 .44237 .92149 .4405 .91912 .43706 Mtetra
.666 .745 .909 r
.91912 .43706 .92149 .4405 .92773 .43862 .92536 .43514 Mtetra
.659 .739 .909 r
.92536 .43514 .92773 .43862 .93398 .43672 .93163 .43332 Mtetra
.662 .746 .913 r
.93163 .43332 .93398 .43672 .94026 .43497 .93791 .43145 Mtetra
.67 .742 .904 r
.93791 .43145 .94026 .43497 .94653 .433 .94418 .42944 Mtetra
.66 .737 .906 r
.94418 .42944 .94653 .433 .95288 .4315 .95049 .42759 Mtetra
.652 .712 .892 r
.95049 .42759 .95288 .4315 .95918 .42959 .95684 .42589 Mtetra
.676 .736 .896 r
.95684 .42589 .95918 .42959 .96545 .4273 .96314 .42377 Mtetra
.658 .739 .909 r
.39275 .5922 .39586 .59511 .40104 .59378 .39794 .5907 Mtetra
.657 .728 .902 r
.39794 .5907 .40104 .59378 .40624 .59206 .40314 .58923 Mtetra
.67 .748 .909 r
.40314 .58923 .40624 .59206 .41145 .59039 .40836 .58755 Mtetra
.667 .747 .91 r
.40836 .58755 .41145 .59039 .41666 .58892 .41358 .58592 Mtetra
.665 .737 .903 r
.41358 .58592 .41666 .58892 .42189 .58727 .41882 .58432 Mtetra
.664 .74 .906 r
.41882 .58432 .42189 .58727 .42713 .5857 .42406 .58272 Mtetra
.662 .738 .906 r
.42406 .58272 .42713 .5857 .43238 .58413 .42932 .58116 Mtetra
.662 .738 .907 r
.42932 .58116 .43238 .58413 .43764 .58249 .43458 .57959 Mtetra
.665 .744 .909 r
.43458 .57959 .43764 .58249 .44291 .58088 .43986 .57797 Mtetra
.666 .744 .909 r
.43986 .57797 .44291 .58088 .44819 .5793 .44514 .57633 Mtetra
.664 .74 .907 r
.44514 .57633 .44819 .5793 .45348 .57773 .45044 .57473 Mtetra
.662 .738 .906 r
.45044 .57473 .45348 .57773 .45878 .57612 .45574 .57315 Mtetra
.662 .74 .908 r
.45574 .57315 .45878 .57612 .46409 .57449 .46106 .57157 Mtetra
.664 .745 .91 r
.46106 .57157 .46409 .57449 .46941 .57293 .46639 .56994 Mtetra
.666 .741 .906 r
.46639 .56994 .46941 .57293 .47474 .57131 .47173 .56829 Mtetra
.662 .738 .907 r
.47173 .56829 .47474 .57131 .48008 .56966 .47707 .5667 Mtetra
.665 .743 .909 r
.47707 .5667 .48008 .56966 .48543 .56807 .48243 .56506 Mtetra
.664 .74 .907 r
.48243 .56506 .48543 .56807 .49079 .56642 .4878 .56343 Mtetra
.664 .742 .908 r
.4878 .56343 .49079 .56642 .49617 .56482 .49318 .5618 Mtetra
.662 .74 .908 r
.49318 .5618 .49617 .56482 .50155 .56318 .49857 .56018 Mtetra
.664 .743 .909 r
.49857 .56018 .50155 .56318 .50694 .56156 .50397 .55855 Mtetra
.664 .742 .908 r
.50397 .55855 .50694 .56156 .51235 .55995 .50938 .55691 Mtetra
.661 .739 .908 r
.50938 .55691 .51235 .55995 .51776 .55832 .5148 .5553 Mtetra
.661 .741 .91 r
.5148 .5553 .51776 .55832 .52319 .5567 .52024 .5537 Mtetra
.661 .742 .911 r
.52024 .5537 .52319 .5567 .52863 .55508 .52568 .55209 Mtetra
.661 .744 .912 r
.52568 .55209 .52863 .55508 .53407 .55346 .53114 .55048 Mtetra
.661 .745 .912 r
.53114 .55048 .53407 .55346 .53953 .55186 .5366 .54886 Mtetra
.664 .745 .91 r
.5366 .54886 .53953 .55186 .545 .55026 .54208 .54718 Mtetra
.667 .741 .905 r
.54208 .54718 .545 .55026 .55048 .54861 .54757 .54547 Mtetra
.661 .736 .905 r
.54757 .54547 .55048 .54861 .55597 .54688 .55306 .54384 Mtetra
.649 .739 .915 r
.55306 .54384 .55597 .54688 .56147 .54525 .55858 .54239 Mtetra
.676 .759 .914 r
.55858 .54239 .56147 .54525 .56699 .54378 .56409 .54053 Mtetra
.662 .73 .901 r
.56409 .54053 .56699 .54378 .57251 .54189 .56963 .53889 Mtetra
.653 .744 .916 r
.56963 .53889 .57251 .54189 .57805 .54038 .57517 .53736 Mtetra
.682 .752 .904 r
.57517 .53736 .57805 .54038 .5836 .53879 .58072 .5354 Mtetra
.638 .715 .903 r
.58072 .5354 .5836 .53879 .58915 .53701 .58629 .5341 Mtetra
.683 .76 .91 r
.58629 .5341 .58915 .53701 .59473 .53555 .59186 .53211 Mtetra
.647 .715 .897 r
.59186 .53211 .59473 .53555 .60031 .53391 .59745 .53068 Mtetra
.662 .734 .903 r
.59745 .53068 .60031 .53391 .60589 .53193 .60305 .529 Mtetra
.686 .761 .909 r
.60305 .529 .60589 .53193 .61151 .53074 .60865 .52696 Mtetra
.638 .693 .885 r
.60865 .52696 .61151 .53074 .6171 .52852 .61428 .52566 Mtetra
.68 .765 .915 r
.61428 .52566 .6171 .52852 .62274 .5272 .61991 .5237 Mtetra
.656 .717 .893 r
.61991 .5237 .62274 .5272 .62838 .52565 .62556 .52212 Mtetra
.645 .711 .896 r
.62556 .52212 .62838 .52565 .63401 .52334 .63122 .52071 Mtetra
.699 .787 .919 r
.63122 .52071 .63401 .52334 .6397 .52249 .63687 .51844 Mtetra
.632 .679 .876 r
.63687 .51844 .6397 .52249 .64534 .52008 .64257 .51724 Mtetra
.696 .773 .911 r
.64257 .51724 .64534 .52008 .65105 .5189 .64824 .51501 Mtetra
.641 .691 .881 r
.64824 .51501 .65105 .5189 .65672 .51659 .65395 .51365 Mtetra
.652 .754 .925 r
.65395 .51365 .65672 .51659 .66243 .51517 .65967 .51208 Mtetra
.664 .748 .912 r
.65967 .51208 .66243 .51517 .66815 .51338 .6654 .51033 Mtetra
.668 .752 .913 r
.6654 .51033 .66815 .51338 .67387 .51154 .67113 .50851 Mtetra
.692 .761 .905 r
.67113 .50851 .67387 .51154 .67962 .51008 .67686 .50633 Mtetra
.635 .698 .891 r
.67686 .50633 .67962 .51008 .68537 .5083 .68264 .50504 Mtetra
.685 .746 .897 r
.68264 .50504 .68537 .5083 .69115 .50684 .68839 .50294 Mtetra
.635 .69 .884 r
.68839 .50294 .69115 .50684 .69689 .50435 .6942 .50167 Mtetra
.699 .79 .921 r
.6942 .50167 .69689 .50435 .70271 .50333 .69996 .49935 Mtetra
.645 .691 .878 r
.69996 .49935 .70271 .50333 .70848 .50106 .70579 .4979 Mtetra
.663 .747 .912 r
.70579 .4979 .70848 .50106 .7143 .49943 .7116 .49614 Mtetra
.686 .746 .897 r
.7116 .49614 .7143 .49943 .72014 .49789 .71741 .49402 Mtetra
.638 .694 .886 r
.71741 .49402 .72014 .49789 .72593 .49551 .72328 .49268 Mtetra
.68 .776 .923 r
.72328 .49268 .72593 .49551 .73181 .49433 .72912 .49064 Mtetra
.659 .714 .889 r
.72912 .49064 .73181 .49433 .73765 .49222 .73499 .48895 Mtetra
.659 .74 .91 r
.73499 .48895 .73765 .49222 .74353 .49054 .74087 .48725 Mtetra
.678 .746 .902 r
.74087 .48725 .74353 .49054 .7494 .48861 .74675 .48522 Mtetra
.655 .732 .906 r
.74675 .48522 .7494 .48861 .7553 .48691 .75266 .48357 Mtetra
.665 .739 .905 r
.75266 .48357 .7553 .48691 .76119 .48485 .75857 .48176 Mtetra
.673 .758 .915 r
.75857 .48176 .76119 .48485 .76712 .48332 .76449 .47981 Mtetra
.649 .723 .903 r
.76449 .47981 .76712 .48332 .77304 .4814 .77045 .47824 Mtetra
.673 .755 .912 r
.77045 .47824 .77304 .4814 .77898 .47951 .77639 .47628 Mtetra
.67 .75 .91 r
.77639 .47628 .77898 .47951 .78494 .47778 .78234 .47437 Mtetra
.66 .735 .905 r
.78234 .47437 .78494 .47778 .79091 .47599 .78832 .47261 Mtetra
.662 .738 .906 r
.78832 .47261 .79091 .47599 .79688 .47413 .79431 .47083 Mtetra
.665 .745 .909 r
.79431 .47083 .79688 .47413 .80287 .47226 .80031 .46898 Mtetra
.666 .747 .91 r
.80031 .46898 .80287 .47226 .80887 .47042 .80632 .46712 Mtetra
.666 .746 .91 r
.80632 .46712 .80887 .47042 .81489 .46858 .81234 .46525 Mtetra
.666 .745 .909 r
.81234 .46525 .81489 .46858 .82091 .46674 .81838 .46338 Mtetra
.666 .743 .908 r
.81838 .46338 .82091 .46674 .82695 .4649 .82442 .46151 Mtetra
.664 .741 .907 r
.82442 .46151 .82695 .4649 .83301 .46306 .83049 .45967 Mtetra
.663 .741 .908 r
.83049 .45967 .83301 .46306 .83907 .46121 .83656 .45783 Mtetra
.665 .743 .908 r
.83656 .45783 .83907 .46121 .84515 .45938 .84265 .45596 Mtetra
.663 .74 .907 r
.84265 .45596 .84515 .45938 .85124 .45753 .84875 .45412 Mtetra
.663 .741 .908 r
.84875 .45412 .85124 .45753 .85735 .4557 .85487 .45228 Mtetra
.664 .741 .908 r
.85487 .45228 .85735 .4557 .86347 .45384 .86099 .45042 Mtetra
.664 .742 .908 r
.86099 .45042 .86347 .45384 .8696 .45203 .86713 .44856 Mtetra
.661 .738 .907 r
.86713 .44856 .8696 .45203 .87574 .45014 .87329 .44673 Mtetra
.664 .743 .909 r
.87329 .44673 .87574 .45014 .8819 .44827 .87946 .44486 Mtetra
.666 .744 .909 r
.87946 .44486 .8819 .44827 .88807 .44645 .88563 .44295 Mtetra
.664 .738 .905 r
.88563 .44295 .88807 .44645 .89425 .44457 .89182 .44107 Mtetra
.664 .739 .906 r
.89182 .44107 .89425 .44457 .90045 .44266 .89803 .43919 Mtetra
.663 .741 .908 r
.89803 .43919 .90045 .44266 .90665 .44078 .90425 .43732 Mtetra
.663 .742 .909 r
.90425 .43732 .90665 .44078 .91288 .43891 .91048 .43545 Mtetra
.665 .743 .908 r
.91048 .43545 .91288 .43891 .91912 .43706 .91672 .43353 Mtetra
.661 .737 .906 r
.91672 .43353 .91912 .43706 .92536 .43514 .92298 .43167 Mtetra
.665 .744 .909 r
.92298 .43167 .92536 .43514 .93163 .43332 .92925 .42975 Mtetra
.665 .738 .904 r
.92925 .42975 .93163 .43332 .93791 .43145 .93554 .42783 Mtetra
.657 .732 .905 r
.93554 .42783 .93791 .43145 .94418 .42944 .94185 .42603 Mtetra
.662 .747 .914 r
.94185 .42603 .94418 .42944 .95049 .42759 .94816 .42415 Mtetra
.664 .747 .912 r
.94816 .42415 .95049 .42759 .95684 .42589 .95449 .42222 Mtetra
.671 .735 .899 r
.95449 .42222 .95684 .42589 .96314 .42377 .96081 .42018 Mtetra
.65 .738 .914 r
.38963 .5893 .39275 .5922 .39794 .5907 .39482 .5879 Mtetra
.675 .751 .908 r
.39482 .5879 .39794 .5907 .40314 .58923 .40004 .58615 Mtetra
.661 .73 .901 r
.40004 .58615 .40314 .58923 .40836 .58755 .40525 .58461 Mtetra
.667 .741 .905 r
.40525 .58461 .40836 .58755 .41358 .58592 .41049 .58297 Mtetra
.661 .739 .908 r
.41049 .58297 .41358 .58592 .41882 .58432 .41573 .58142 Mtetra
.667 .744 .908 r
.41573 .58142 .41882 .58432 .42406 .58272 .42098 .57978 Mtetra
.663 .741 .908 r
.42098 .57978 .42406 .58272 .42932 .58116 .42624 .57819 Mtetra
.664 .74 .907 r
.42624 .57819 .42932 .58116 .43458 .57959 .43151 .57659 Mtetra
.663 .738 .906 r
.43151 .57659 .43458 .57959 .43986 .57797 .43679 .57499 Mtetra
.664 .74 .907 r
.43679 .57499 .43986 .57797 .44514 .57633 .44209 .57338 Mtetra
.664 .742 .908 r
.44209 .57338 .44514 .57633 .45044 .57473 .44739 .57177 Mtetra
.663 .742 .909 r
.44739 .57177 .45044 .57473 .45574 .57315 .4527 .57016 Mtetra
.664 .741 .907 r
.4527 .57016 .45574 .57315 .46106 .57157 .45802 .56854 Mtetra
.662 .738 .906 r
.45802 .56854 .46106 .57157 .46639 .56994 .46336 .56693 Mtetra
.662 .74 .908 r
.46336 .56693 .46639 .56994 .47173 .56829 .4687 .56533 Mtetra
.665 .744 .909 r
.4687 .56533 .47173 .56829 .47707 .5667 .47406 .56369 Mtetra
.665 .741 .907 r
.47406 .56369 .47707 .5667 .48243 .56506 .47942 .56204 Mtetra
.664 .74 .907 r
.47942 .56204 .48243 .56506 .4878 .56343 .4848 .56041 Mtetra
.662 .74 .908 r
.4848 .56041 .4878 .56343 .49318 .5618 .49018 .55879 Mtetra
.664 .742 .908 r
.49018 .55879 .49318 .5618 .49857 .56018 .49558 .55714 Mtetra
.66 .739 .908 r
.49558 .55714 .49857 .56018 .50397 .55855 .50099 .55555 Mtetra
.664 .743 .909 r
.50099 .55555 .50397 .55855 .50938 .55691 .50641 .5539 Mtetra
.666 .744 .908 r
.50641 .5539 .50938 .55691 .5148 .5553 .51184 .55221 Mtetra
.66 .737 .907 r
.51184 .55221 .5148 .5553 .52024 .5537 .51728 .55062 Mtetra
.661 .738 .907 r
.51728 .55062 .52024 .5537 .52568 .55209 .52273 .549 Mtetra
.662 .739 .907 r
.52273 .549 .52568 .55209 .53114 .55048 .52819 .54737 Mtetra
.663 .738 .906 r
.52819 .54737 .53114 .55048 .5366 .54886 .53366 .54571 Mtetra
.667 .738 .902 r
.53366 .54571 .5366 .54886 .54208 .54718 .53914 .54399 Mtetra
.657 .731 .904 r
.53914 .54399 .54208 .54718 .54757 .54547 .54464 .54243 Mtetra
.65 .739 .915 r
.54464 .54243 .54757 .54547 .55306 .54384 .55015 .54095 Mtetra
.671 .756 .915 r
.55015 .54095 .55306 .54384 .55858 .54239 .55566 .53917 Mtetra
.671 .735 .898 r
.55566 .53917 .55858 .54239 .56409 .54053 .56119 .53737 Mtetra
.648 .732 .91 r
.56119 .53737 .56409 .54053 .56963 .53889 .56673 .53591 Mtetra
.681 .755 .907 r
.56673 .53591 .56963 .53889 .57517 .53736 .57228 .53396 Mtetra
.648 .718 .899 r
.57228 .53396 .57517 .53736 .58072 .5354 .57784 .53251 Mtetra
.676 .76 .914 r
.57784 .53251 .58072 .5354 .58629 .5341 .58341 .53062 Mtetra
.648 .714 .896 r
.58341 .53062 .58629 .5341 .59186 .53211 .589 .52918 Mtetra
.684 .76 .909 r
.589 .52918 .59186 .53211 .59745 .53068 .59458 .52717 Mtetra
.654 .715 .893 r
.59458 .52717 .59745 .53068 .60305 .529 .60019 .52563 Mtetra
.666 .727 .895 r
.60019 .52563 .60305 .529 .60865 .52696 .60581 .52388 Mtetra
.667 .747 .91 r
.60581 .52388 .60865 .52696 .61428 .52566 .61144 .52211 Mtetra
.651 .712 .893 r
.61144 .52211 .61428 .52566 .61991 .5237 .61708 .5206 Mtetra
.673 .748 .907 r
.61708 .5206 .61991 .5237 .62556 .52212 .62273 .51874 Mtetra
.662 .727 .898 r
.62273 .51874 .62556 .52212 .63122 .52071 .62839 .51705 Mtetra
.656 .709 .887 r
.62839 .51705 .63122 .52071 .63687 .51844 .63407 .51545 Mtetra
.665 .754 .917 r
.63407 .51545 .63687 .51844 .64257 .51724 .63975 .5137 Mtetra
.647 .713 .896 r
.63975 .5137 .64257 .51724 .64824 .51501 .64546 .51224 Mtetra
.667 .771 .928 r
.64546 .51224 .64824 .51501 .65395 .51365 .65117 .51043 Mtetra
.682 .746 .899 r
.65117 .51043 .65395 .51365 .65967 .51208 .65688 .5084 Mtetra
.664 .712 .884 r
.65688 .5084 .65967 .51208 .6654 .51033 .66261 .50666 Mtetra
.651 .709 .889 r
.66261 .50666 .6654 .51033 .67113 .50851 .66836 .50512 Mtetra
.647 .724 .905 r
.66836 .50512 .67113 .50851 .67686 .50633 .67413 .50364 Mtetra
.693 .787 .922 r
.67413 .50364 .67686 .50633 .68264 .50504 .67987 .50142 Mtetra
.65 .713 .893 r
.67987 .50142 .68264 .50504 .68839 .50294 .68566 .49988 Mtetra
.682 .759 .909 r
.68566 .49988 .68839 .50294 .6942 .50167 .69144 .49783 Mtetra
.654 .702 .882 r
.69144 .49783 .6942 .50167 .69996 .49935 .69725 .49623 Mtetra
.663 .75 .915 r
.69725 .49623 .69996 .49935 .70579 .4979 .70306 .49447 Mtetra
.676 .735 .894 r
.70306 .49447 .70579 .4979 .7116 .49614 .70888 .49249 Mtetra
.654 .714 .892 r
.70888 .49249 .7116 .49614 .71741 .49402 .71473 .49087 Mtetra
.669 .751 .912 r
.71473 .49087 .71741 .49402 .72328 .49268 .72057 .489 Mtetra
.661 .716 .889 r
.72057 .489 .72328 .49268 .72912 .49064 .72644 .48727 Mtetra
.653 .731 .907 r
.72644 .48727 .72912 .49064 .73499 .48895 .73232 .48566 Mtetra
.682 .748 .901 r
.73232 .48566 .73499 .48895 .74087 .48725 .73819 .48357 Mtetra
.646 .712 .895 r
.73819 .48357 .74087 .48725 .74675 .48522 .74411 .48207 Mtetra
.682 .757 .908 r
.74411 .48207 .74675 .48522 .75266 .48357 .75 .47998 Mtetra
.646 .718 .9 r
.75 .47998 .75266 .48357 .75857 .48176 .75594 .47846 Mtetra
.671 .746 .906 r
.75594 .47846 .75857 .48176 .76449 .47981 .76187 .47654 Mtetra
.664 .746 .911 r
.76187 .47654 .76449 .47981 .77045 .47824 .76781 .47473 Mtetra
.653 .726 .902 r
.76781 .47473 .77045 .47824 .77639 .47628 .77379 .47309 Mtetra
.674 .755 .912 r
.77379 .47309 .77639 .47628 .78234 .47437 .77975 .47112 Mtetra
.674 .751 .909 r
.77975 .47112 .78234 .47437 .78832 .47261 .78572 .46913 Mtetra
.659 .731 .903 r
.78572 .46913 .78832 .47261 .79431 .47083 .79172 .46738 Mtetra
.663 .736 .904 r
.79172 .46738 .79431 .47083 .80031 .46898 .79773 .46556 Mtetra
.665 .739 .905 r
.79773 .46556 .80031 .46898 .80632 .46712 .80375 .46371 Mtetra
.666 .74 .905 r
.80375 .46371 .80632 .46712 .81234 .46525 .80978 .46184 Mtetra
.667 .741 .905 r
.80978 .46184 .81234 .46525 .81838 .46338 .81582 .45995 Mtetra
.663 .738 .906 r
.81582 .45995 .81838 .46338 .82442 .46151 .82189 .45813 Mtetra
.662 .741 .909 r
.82189 .45813 .82442 .46151 .83049 .45967 .82796 .45631 Mtetra
.666 .745 .909 r
.82796 .45631 .83049 .45967 .83656 .45783 .83404 .45442 Mtetra
.664 .741 .908 r
.83404 .45442 .83656 .45783 .84265 .45596 .84014 .45256 Mtetra
.665 .743 .908 r
.84014 .45256 .84265 .45596 .84875 .45412 .84625 .45069 Mtetra
.663 .741 .908 r
.84625 .45069 .84875 .45412 .85487 .45228 .85237 .44884 Mtetra
.662 .74 .908 r
.85237 .44884 .85487 .45228 .86099 .45042 .85851 .44699 Mtetra
.663 .742 .908 r
.85851 .44699 .86099 .45042 .86713 .44856 .86466 .44513 Mtetra
.665 .743 .908 r
.86466 .44513 .86713 .44856 .87329 .44673 .87082 .44323 Mtetra
.662 .738 .906 r
.87082 .44323 .87329 .44673 .87946 .44486 .877 .44138 Mtetra
.663 .74 .907 r
.877 .44138 .87946 .44486 .88563 .44295 .88319 .43951 Mtetra
.665 .743 .909 r
.88319 .43951 .88563 .44295 .89182 .44107 .88939 .4376 Mtetra
.664 .742 .908 r
.88939 .4376 .89182 .44107 .89803 .43919 .8956 .43571 Mtetra
.663 .741 .908 r
.8956 .43571 .89803 .43919 .90425 .43732 .90183 .43382 Mtetra
.662 .74 .907 r
.90183 .43382 .90425 .43732 .91048 .43545 .90807 .43194 Mtetra
.663 .74 .908 r
.90807 .43194 .91048 .43545 .91672 .43353 .91433 .43006 Mtetra
.665 .744 .909 r
.91433 .43006 .91672 .43353 .92298 .43167 .92059 .42813 Mtetra
.663 .739 .906 r
.92059 .42813 .92298 .43167 .92925 .42975 .92687 .42623 Mtetra
.663 .741 .908 r
.92687 .42623 .92925 .42975 .93554 .42783 .93317 .42433 Mtetra
.66 .741 .91 r
.93317 .42433 .93554 .42783 .94185 .42603 .93949 .42248 Mtetra
.669 .742 .905 r
.93949 .42248 .94185 .42603 .94816 .42415 .9458 .42047 Mtetra
.653 .728 .904 r
.9458 .42047 .94816 .42415 .95449 .42222 .95216 .41873 Mtetra
.673 .749 .908 r
.95216 .41873 .95449 .42222 .96081 .42018 .95848 .41665 Mtetra
.658 .74 .91 r
.38649 .58638 .38963 .5893 .39482 .5879 .3917 .58488 Mtetra
.666 .735 .901 r
.3917 .58488 .39482 .5879 .40004 .58615 .39692 .58325 Mtetra
.663 .743 .909 r
.39692 .58325 .40004 .58615 .40525 .58461 .40214 .58166 Mtetra
.666 .741 .906 r
.40214 .58166 .40525 .58461 .41049 .58297 .40738 .58003 Mtetra
.663 .741 .908 r
.40738 .58003 .41049 .58297 .41573 .58142 .41263 .57845 Mtetra
.663 .739 .907 r
.41263 .57845 .41573 .58142 .42098 .57978 .41788 .57685 Mtetra
.665 .743 .909 r
.41788 .57685 .42098 .57978 .42624 .57819 .42315 .57523 Mtetra
.661 .74 .908 r
.42315 .57523 .42624 .57819 .43151 .57659 .42843 .57366 Mtetra
.664 .744 .909 r
.42843 .57366 .43151 .57659 .43679 .57499 .43372 .57204 Mtetra
.665 .743 .908 r
.43372 .57204 .43679 .57499 .44209 .57338 .43902 .5704 Mtetra
.664 .741 .908 r
.43902 .5704 .44209 .57338 .44739 .57177 .44433 .56878 Mtetra
.662 .741 .908 r
.44433 .56878 .44739 .57177 .4527 .57016 .44964 .56718 Mtetra
.662 .741 .909 r
.44964 .56718 .4527 .57016 .45802 .56854 .45497 .56559 Mtetra
.664 .744 .91 r
.45497 .56559 .45802 .56854 .46336 .56693 .46031 .56396 Mtetra
.666 .743 .908 r
.46031 .56396 .46336 .56693 .4687 .56533 .46567 .5623 Mtetra
.665 .74 .906 r
.46567 .5623 .4687 .56533 .47406 .56369 .47103 .56065 Mtetra
.664 .74 .907 r
.47103 .56065 .47406 .56369 .47942 .56204 .4764 .55902 Mtetra
.662 .74 .908 r
.4764 .55902 .47942 .56204 .4848 .56041 .48178 .5574 Mtetra
.662 .742 .909 r
.48178 .5574 .4848 .56041 .49018 .55879 .48718 .55578 Mtetra
.663 .742 .909 r
.48718 .55578 .49018 .55879 .49558 .55714 .49258 .55414 Mtetra
.663 .743 .909 r
.49258 .55414 .49558 .55714 .50099 .55555 .49799 .55249 Mtetra
.659 .739 .909 r
.49799 .55249 .50099 .55555 .50641 .5539 .50342 .55091 Mtetra
.664 .745 .91 r
.50342 .55091 .50641 .5539 .51184 .55221 .50886 .54924 Mtetra
.667 .747 .911 r
.50886 .54924 .51184 .55221 .51728 .55062 .5143 .54754 Mtetra
.666 .74 .906 r
.5143 .54754 .51728 .55062 .52273 .549 .51976 .54584 Mtetra
.664 .735 .902 r
.51976 .54584 .52273 .549 .52819 .54737 .52523 .54417 Mtetra
.66 .731 .902 r
.52523 .54417 .52819 .54737 .53366 .54571 .53071 .54256 Mtetra
.655 .733 .907 r
.53071 .54256 .53366 .54571 .53914 .54399 .5362 .54102 Mtetra
.653 .745 .917 r
.5362 .54102 .53914 .54399 .54464 .54243 .5417 .53949 Mtetra
.666 .752 .915 r
.5417 .53949 .54464 .54243 .55015 .54095 .54721 .53778 Mtetra
.682 .741 .896 r
.54721 .53778 .55015 .54095 .55566 .53917 .55274 .53581 Mtetra
.644 .719 .903 r
.55274 .53581 .55566 .53917 .56119 .53737 .55827 .53443 Mtetra
.673 .755 .913 r
.55827 .53443 .56119 .53737 .56673 .53591 .56382 .5326 Mtetra
.666 .73 .897 r
.56382 .5326 .56673 .53591 .57228 .53396 .56937 .53086 Mtetra
.657 .741 .912 r
.56937 .53086 .57228 .53396 .57784 .53251 .57494 .52927 Mtetra
.672 .737 .899 r
.57494 .52927 .57784 .53251 .58341 .53062 .58052 .52744 Mtetra
.658 .736 .907 r
.58052 .52744 .58341 .53062 .589 .52918 .58611 .52582 Mtetra
.668 .729 .895 r
.58611 .52582 .589 .52918 .59458 .52717 .59171 .52405 Mtetra
.663 .743 .909 r
.59171 .52405 .59458 .52717 .60019 .52563 .59733 .52234 Mtetra
.662 .732 .902 r
.59733 .52234 .60019 .52563 .60581 .52388 .60295 .52065 Mtetra
.67 .739 .902 r
.60295 .52065 .60581 .52388 .61144 .52211 .60859 .51885 Mtetra
.658 .733 .905 r
.60859 .51885 .61144 .52211 .61708 .5206 .61423 .51722 Mtetra
.666 .729 .896 r
.61423 .51722 .61708 .5206 .62273 .51874 .61989 .51546 Mtetra
.663 .734 .903 r
.61989 .51546 .62273 .51874 .62839 .51705 .62556 .51375 Mtetra
.647 .728 .908 r
.62556 .51375 .62839 .51705 .63407 .51545 .63125 .51226 Mtetra
.673 .744 .904 r
.63125 .51226 .63407 .51545 .63975 .5137 .63694 .51038 Mtetra
.648 .728 .907 r
.63694 .51038 .63975 .5137 .64546 .51224 .64265 .50887 Mtetra
.679 .736 .893 r
.64265 .50887 .64546 .51224 .65117 .51043 .64836 .50687 Mtetra
.651 .715 .895 r
.64836 .50687 .65117 .51043 .65688 .5084 .6541 .50534 Mtetra
.659 .75 .917 r
.6541 .50534 .65688 .5084 .66261 .50666 .65984 .50365 Mtetra
.686 .763 .909 r
.65984 .50365 .66261 .50666 .66836 .50512 .66558 .50154 Mtetra
.643 .712 .898 r
.66558 .50154 .66836 .50512 .67413 .50364 .67135 .50012 Mtetra
.67 .726 .892 r
.67135 .50012 .67413 .50364 .67987 .50142 .67712 .49826 Mtetra
.663 .746 .912 r
.67712 .49826 .67987 .50142 .68566 .49988 .68291 .49651 Mtetra
.681 .739 .895 r
.68291 .49651 .68566 .49988 .69144 .49783 .6887 .49446 Mtetra
.657 .732 .905 r
.6887 .49446 .69144 .49783 .69725 .49623 .69451 .4928 Mtetra
.666 .732 .899 r
.69451 .4928 .69725 .49623 .70306 .49447 .70033 .49099 Mtetra
.666 .729 .897 r
.70033 .49099 .70306 .49447 .70888 .49249 .70616 .48917 Mtetra
.656 .736 .909 r
.70616 .48917 .70888 .49249 .71473 .49087 .71202 .48751 Mtetra
.669 .738 .902 r
.71202 .48751 .71473 .49087 .72057 .489 .71787 .48564 Mtetra
.661 .736 .905 r
.71787 .48564 .72057 .489 .72644 .48727 .72374 .4839 Mtetra
.664 .736 .904 r
.72374 .4839 .72644 .48727 .73232 .48566 .72963 .4821 Mtetra
.661 .724 .896 r
.72963 .4821 .73232 .48566 .73819 .48357 .73552 .48035 Mtetra
.661 .746 .913 r
.73552 .48035 .73819 .48357 .74411 .48207 .74143 .47859 Mtetra
.665 .731 .899 r
.74143 .47859 .74411 .48207 .75 .47998 .74735 .47676 Mtetra
.667 .749 .912 r
.74735 .47676 .75 .47998 .75594 .47846 .75328 .4749 Mtetra
.65 .721 .901 r
.75328 .4749 .75594 .47846 .76187 .47654 .75924 .47331 Mtetra
.678 .753 .907 r
.75924 .47331 .76187 .47654 .76781 .47473 .76518 .47126 Mtetra
.653 .73 .905 r
.76518 .47126 .76781 .47473 .77379 .47309 .77116 .46961 Mtetra
.658 .731 .903 r
.77116 .46961 .77379 .47309 .77975 .47112 .77714 .46788 Mtetra
.672 .752 .911 r
.77714 .46788 .77975 .47112 .78572 .46913 .78313 .46593 Mtetra
.673 .755 .913 r
.78313 .46593 .78572 .46913 .79172 .46738 .78912 .46395 Mtetra
.668 .739 .903 r
.78912 .46395 .79172 .46738 .79773 .46556 .79514 .46205 Mtetra
.664 .733 .901 r
.79514 .46205 .79773 .46556 .80375 .46371 .80117 .46021 Mtetra
.662 .733 .903 r
.80117 .46021 .80375 .46371 .80978 .46184 .80721 .4584 Mtetra
.661 .737 .907 r
.80721 .4584 .80978 .46184 .81582 .45995 .81327 .45661 Mtetra
.662 .745 .911 r
.81327 .45661 .81582 .45995 .82189 .45813 .81934 .45479 Mtetra
.667 .747 .91 r
.81934 .45479 .82189 .45813 .82796 .45631 .82542 .45289 Mtetra
.666 .742 .907 r
.82542 .45289 .82796 .45631 .83404 .45442 .83151 .451 Mtetra
.662 .741 .908 r
.83151 .451 .83404 .45442 .84014 .45256 .83762 .44916 Mtetra
.666 .744 .908 r
.83762 .44916 .84014 .45256 .84625 .45069 .84374 .44726 Mtetra
.664 .742 .908 r
.84374 .44726 .84625 .45069 .85237 .44884 .84987 .44538 Mtetra
.663 .741 .907 r
.84987 .44538 .85237 .44884 .85851 .44699 .85601 .44352 Mtetra
.662 .739 .907 r
.85601 .44352 .85851 .44699 .86466 .44513 .86218 .44167 Mtetra
.662 .741 .908 r
.86218 .44167 .86466 .44513 .87082 .44323 .86835 .43981 Mtetra
.664 .744 .91 r
.86835 .43981 .87082 .44323 .877 .44138 .87453 .43792 Mtetra
.665 .743 .908 r
.87453 .43792 .877 .44138 .88319 .43951 .88073 .436 Mtetra
.664 .74 .906 r
.88073 .436 .88319 .43951 .88939 .4376 .88694 .4341 Mtetra
.662 .74 .908 r
.88694 .4341 .88939 .4376 .8956 .43571 .89317 .43223 Mtetra
.662 .742 .909 r
.89317 .43223 .8956 .43571 .90183 .43382 .89941 .43036 Mtetra
.663 .744 .91 r
.89941 .43036 .90183 .43382 .90807 .43194 .90566 .42846 Mtetra
.666 .744 .909 r
.90566 .42846 .90807 .43194 .91433 .43006 .91192 .42652 Mtetra
.665 .74 .906 r
.91192 .42652 .91433 .43006 .92059 .42813 .91819 .42459 Mtetra
.663 .74 .908 r
.91819 .42459 .92059 .42813 .92687 .42623 .92449 .42269 Mtetra
.662 .74 .908 r
.92449 .42269 .92687 .42623 .93317 .42433 .93079 .42081 Mtetra
.665 .743 .908 r
.93079 .42081 .93317 .42433 .93949 .42248 .93711 .41885 Mtetra
.664 .737 .904 r
.93711 .41885 .93949 .42248 .9458 .42047 .94344 .41693 Mtetra
.657 .739 .91 r
.94344 .41693 .9458 .42047 .95216 .41873 .9498 .4151 Mtetra
.671 .74 .902 r
.9498 .4151 .95216 .41873 .95848 .41665 .95614 .41305 Mtetra
.657 .74 .911 r
.38335 .58345 .38649 .58638 .3917 .58488 .38856 .58195 Mtetra
.669 .743 .906 r
.38856 .58195 .3917 .58488 .39692 .58325 .39379 .58027 Mtetra
.658 .738 .909 r
.39379 .58027 .39692 .58325 .40214 .58166 .39902 .57876 Mtetra
.668 .745 .908 r
.39902 .57876 .40214 .58166 .40738 .58003 .40426 .57709 Mtetra
.664 .742 .908 r
.40426 .57709 .40738 .58003 .41263 .57845 .40952 .57548 Mtetra
.664 .741 .907 r
.40952 .57548 .41263 .57845 .41788 .57685 .41478 .57386 Mtetra
.664 .739 .906 r
.41478 .57386 .41788 .57685 .42315 .57523 .42005 .57225 Mtetra
.662 .74 .908 r
.42005 .57225 .42315 .57523 .42843 .57366 .42534 .57067 Mtetra
.42534 .57067 .42843 .57366 .43372 .57204 .43063 .56907 Mtetra
.665 .742 .908 r
.43063 .56907 .43372 .57204 .43902 .5704 .43594 .56744 Mtetra
.665 .743 .908 r
.43594 .56744 .43902 .5704 .44433 .56878 .44125 .56579 Mtetra
.663 .741 .908 r
.44125 .56579 .44433 .56878 .44964 .56718 .44658 .56417 Mtetra
.664 .74 .907 r
.44658 .56417 .44964 .56718 .45497 .56559 .45192 .56254 Mtetra
.663 .738 .906 r
.45192 .56254 .45497 .56559 .46031 .56396 .45726 .56092 Mtetra
.663 .739 .906 r
.45726 .56092 .46031 .56396 .46567 .5623 .46262 .55929 Mtetra
.664 .742 .908 r
.46262 .55929 .46567 .5623 .47103 .56065 .46799 .55765 Mtetra
.663 .742 .909 r
.46799 .55765 .47103 .56065 .4764 .55902 .47337 .55601 Mtetra
.662 .742 .909 r
.47337 .55601 .4764 .55902 .48178 .5574 .47876 .55439 Mtetra
.665 .743 .908 r
.47876 .55439 .48178 .5574 .48718 .55578 .48416 .55271 Mtetra
.659 .738 .908 r
.48416 .55271 .48718 .55578 .49258 .55414 .48957 .55112 Mtetra
.666 .744 .909 r
.48957 .55112 .49258 .55414 .49799 .55249 .49499 .54944 Mtetra
.663 .741 .908 r
.49499 .54944 .49799 .55249 .50342 .55091 .50042 .54779 Mtetra
.66 .736 .907 r
.50042 .54779 .50342 .55091 .50886 .54924 .50586 .54619 Mtetra
.663 .742 .909 r
.50586 .54619 .50886 .54924 .5143 .54754 .51132 .54454 Mtetra
.663 .746 .911 r
.51132 .54454 .5143 .54754 .51976 .54584 .51678 .54287 Mtetra
.662 .748 .914 r
.51678 .54287 .51976 .54584 .52523 .54417 .52226 .54122 Mtetra
.66 .749 .916 r
.52226 .54122 .52523 .54417 .53071 .54256 .52775 .53959 Mtetra
.659 .748 .916 r
.52775 .53959 .53071 .54256 .5362 .54102 .53324 .53798 Mtetra
.663 .745 .911 r
.53324 .53798 .5362 .54102 .5417 .53949 .53875 .5363 Mtetra
.676 .739 .899 r
.53875 .5363 .5417 .53949 .54721 .53778 .54427 .53444 Mtetra
.653 .723 .9 r
.54427 .53444 .54721 .53778 .55274 .53581 .5498 .53291 Mtetra
.663 .755 .919 r
.5498 .53291 .55274 .53581 .55827 .53443 .55535 .53122 Mtetra
.675 .738 .898 r
.55535 .53122 .55827 .53443 .56382 .5326 .5609 .52934 Mtetra
.655 .73 .904 r
.5609 .52934 .56382 .5326 .56937 .53086 .56646 .52777 Mtetra
.664 .744 .909 r
.56646 .52777 .56937 .53086 .57494 .52927 .57204 .52606 Mtetra
.661 .736 .905 r
.57204 .52606 .57494 .52927 .58052 .52744 .57763 .52439 Mtetra
.668 .749 .911 r
.57763 .52439 .58052 .52744 .58611 .52582 .58322 .52261 Mtetra
.661 .736 .905 r
.58322 .52261 .58611 .52582 .59171 .52405 .58883 .52093 Mtetra
.666 .745 .909 r
.58883 .52093 .59171 .52405 .59733 .52234 .59445 .51919 Mtetra
.652 .738 .912 r
.59445 .51919 .59733 .52234 .60295 .52065 .60009 .51763 Mtetra
.673 .754 .911 r
.60009 .51763 .60295 .52065 .60859 .51885 .60573 .51576 Mtetra
.658 .745 .914 r
.60573 .51576 .60859 .51885 .61423 .51722 .61138 .51411 Mtetra
.658 .744 .914 r
.61138 .51411 .61423 .51722 .61989 .51546 .61705 .51246 Mtetra
.672 .756 .914 r
.61705 .51246 .61989 .51546 .62556 .51375 .62273 .51059 Mtetra
.662 .744 .911 r
.62273 .51059 .62556 .51375 .63125 .51226 .62842 .50888 Mtetra
.658 .728 .901 r
.62842 .50888 .63125 .51226 .63694 .51038 .63412 .50723 Mtetra
.666 .746 .91 r
.63412 .50723 .63694 .51038 .64265 .50887 .63983 .50544 Mtetra
.655 .725 .9 r
.63983 .50544 .64265 .50887 .64836 .50687 .64556 .50383 Mtetra
.661 .752 .918 r
.64556 .50383 .64836 .50687 .6541 .50534 .6513 .50211 Mtetra
.661 .74 .909 r
.6513 .50211 .6541 .50534 .65984 .50365 .65705 .5004 Mtetra
.667 .742 .906 r
.65705 .5004 .65984 .50365 .66558 .50154 .66281 .49859 Mtetra
.68 .766 .916 r
.66281 .49859 .66558 .50154 .67135 .50012 .66857 .49657 Mtetra
.651 .718 .897 r
.66857 .49657 .67135 .50012 .67712 .49826 .67436 .49501 Mtetra
.676 .745 .903 r
.67436 .49501 .67712 .49826 .68291 .49651 .68014 .49304 Mtetra
.657 .726 .9 r
.68014 .49304 .68291 .49651 .6887 .49446 .68596 .49137 Mtetra
.656 .75 .919 r
.68596 .49137 .6887 .49446 .69451 .4928 .69178 .4897 Mtetra
.675 .756 .912 r
.69178 .4897 .69451 .4928 .70033 .49099 .6976 .48774 Mtetra
.661 .742 .91 r
.6976 .48774 .70033 .49099 .70616 .48917 .70345 .486 Mtetra
.658 .747 .916 r
.70345 .486 .70616 .48917 .71202 .48751 .70931 .4843 Mtetra
.675 .751 .908 r
.70931 .4843 .71202 .48751 .71787 .48564 .71516 .48232 Mtetra
.655 .737 .91 r
.71516 .48232 .71787 .48564 .72374 .4839 .72105 .48065 Mtetra
.672 .748 .908 r
.72105 .48065 .72374 .4839 .72963 .4821 .72693 .47872 Mtetra
.654 .733 .908 r
.72693 .47872 .72963 .4821 .73552 .48035 .73284 .47707 Mtetra
.67 .746 .907 r
.73284 .47707 .73552 .48035 .74143 .47859 .73875 .47516 Mtetra
.659 .733 .905 r
.73875 .47516 .74143 .47859 .74735 .47676 .74469 .47343 Mtetra
.67 .744 .905 r
.74469 .47343 .74735 .47676 .75328 .4749 .75062 .47151 Mtetra
.656 .736 .908 r
.75062 .47151 .75328 .4749 .75924 .47331 .75658 .46981 Mtetra
.66 .731 .902 r
.75658 .46981 .75924 .47331 .76518 .47126 .76255 .46805 Mtetra
.675 .755 .911 r
.76255 .46805 .76518 .47126 .77116 .46961 .76851 .46604 Mtetra
.653 .724 .901 r
.76851 .46604 .77116 .46961 .77714 .46788 .77451 .46439 Mtetra
.662 .733 .902 r
.77451 .46439 .77714 .46788 .78313 .46593 .78052 .46258 Mtetra
.668 .745 .908 r
.78052 .46258 .78313 .46593 .78912 .46395 .78653 .46068 Mtetra
.666 .75 .913 r
.78653 .46068 .78912 .46395 .79514 .46205 .79255 .4588 Mtetra
.665 .751 .914 r
.79255 .4588 .79514 .46205 .80117 .46021 .79859 .45693 Mtetra
.664 .749 .914 r
.79859 .45693 .80117 .46021 .80721 .4584 .80464 .45508 Mtetra
.664 .746 .912 r
.80464 .45508 .80721 .4584 .81327 .45661 .81071 .45322 Mtetra
.667 .744 .908 r
.81071 .45322 .81327 .45661 .81934 .45479 .81678 .45132 Mtetra
.666 .739 .905 r
.81678 .45132 .81934 .45479 .82542 .45289 .82287 .44942 Mtetra
.66 .738 .907 r
.82287 .44942 .82542 .45289 .83151 .451 .82898 .44761 Mtetra
.668 .746 .909 r
.82898 .44761 .83151 .451 .83762 .44916 .83509 .44568 Mtetra
.661 .738 .907 r
.83509 .44568 .83762 .44916 .84374 .44726 .84122 .44385 Mtetra
.666 .744 .909 r
.84122 .44385 .84374 .44726 .84987 .44538 .84736 .44194 Mtetra
.664 .742 .908 r
.84736 .44194 .84987 .44538 .85601 .44352 .85351 .44006 Mtetra
.664 .741 .908 r
.85351 .44006 .85601 .44352 .86218 .44167 .85968 .43818 Mtetra
.664 .74 .907 r
.85968 .43818 .86218 .44167 .86835 .43981 .86586 .43629 Mtetra
.662 .738 .906 r
.86586 .43629 .86835 .43981 .87453 .43792 .87206 .43442 Mtetra
.663 .74 .907 r
.87206 .43442 .87453 .43792 .88073 .436 .87827 .43253 Mtetra
.665 .743 .908 r
.87827 .43253 .88073 .436 .88694 .4341 .88448 .43061 Mtetra
.663 .741 .908 r
.88448 .43061 .88694 .4341 .89317 .43223 .89072 .42872 Mtetra
.89072 .42872 .89317 .43223 .89941 .43036 .89697 .42683 Mtetra
.664 .74 .907 r
.89697 .42683 .89941 .43036 .90566 .42846 .90323 .42491 Mtetra
.664 .739 .906 r
.90323 .42491 .90566 .42846 .91192 .42652 .9095 .42298 Mtetra
.663 .74 .907 r
.9095 .42298 .91192 .42652 .91819 .42459 .91579 .42108 Mtetra
.662 .742 .909 r
.91579 .42108 .91819 .42459 .92449 .42269 .92209 .41918 Mtetra
.666 .744 .909 r
.92209 .41918 .92449 .42269 .93079 .42081 .9284 .41721 Mtetra
.661 .738 .907 r
.9284 .41721 .93079 .42081 .93711 .41885 .93474 .41533 Mtetra
.666 .745 .909 r
.93474 .41533 .93711 .41885 .94344 .41693 .94107 .41336 Mtetra
.661 .74 .909 r
.94107 .41336 .94344 .41693 .9498 .4151 .94743 .41147 Mtetra
.665 .738 .904 r
.94743 .41147 .9498 .4151 .95614 .41305 .9538 .40949 Mtetra
.654 .738 .911 r
.3802 .58051 .38335 .58345 .38856 .58195 .38541 .57904 Mtetra
.671 .745 .906 r
.38541 .57904 .38856 .58195 .39379 .58027 .39064 .57733 Mtetra
.661 .741 .909 r
.39064 .57733 .39379 .58027 .39902 .57876 .39588 .57576 Mtetra
.663 .738 .906 r
.39588 .57576 .39902 .57876 .40426 .57709 .40113 .57417 Mtetra
.667 .745 .908 r
.40113 .57417 .40426 .57709 .40952 .57548 .40639 .57251 Mtetra
.662 .741 .908 r
.40639 .57251 .40952 .57548 .41478 .57386 .41166 .57092 Mtetra
.665 .743 .909 r
.41166 .57092 .41478 .57386 .42005 .57225 .41694 .56929 Mtetra
.664 .742 .908 r
.41694 .56929 .42005 .57225 .42534 .57067 .42223 .56766 Mtetra
.663 .74 .907 r
.42223 .56766 .42534 .57067 .43063 .56907 .42754 .56605 Mtetra
.664 .739 .906 r
.42754 .56605 .43063 .56907 .43594 .56744 .43285 .56442 Mtetra
.664 .74 .907 r
.43285 .56442 .43594 .56744 .44125 .56579 .43817 .56279 Mtetra
.662 .741 .909 r
.43817 .56279 .44125 .56579 .44658 .56417 .4435 .56118 Mtetra
.662 .742 .909 r
.4435 .56118 .44658 .56417 .45192 .56254 .44884 .55957 Mtetra
.664 .744 .91 r
.44884 .55957 .45192 .56254 .45726 .56092 .4542 .55792 Mtetra
.665 .743 .908 r
.4542 .55792 .45726 .56092 .46262 .55929 .45956 .55626 Mtetra
.663 .741 .907 r
.45956 .55626 .46262 .55929 .46799 .55765 .46494 .55462 Mtetra
.662 .741 .908 r
.46494 .55462 .46799 .55765 .47337 .55601 .47032 .55298 Mtetra
.665 .742 .908 r
.47032 .55298 .47337 .55601 .47876 .55439 .47572 .55131 Mtetra
.66 .738 .908 r
.47572 .55131 .47876 .55439 .48416 .55271 .48113 .54971 Mtetra
.667 .745 .909 r
.48113 .54971 .48416 .55271 .48957 .55112 .48654 .54801 Mtetra
.66 .736 .906 r
.48654 .54801 .48957 .55112 .49499 .54944 .49197 .54641 Mtetra
.665 .744 .909 r
.49197 .54641 .49499 .54944 .50042 .54779 .49741 .54472 Mtetra
.664 .741 .907 r
.49741 .54472 .50042 .54779 .50586 .54619 .50286 .54305 Mtetra
.66 .736 .906 r
.50286 .54305 .50586 .54619 .51132 .54454 .50832 .54143 Mtetra
.662 .739 .907 r
.50832 .54143 .51132 .54454 .51678 .54287 .5138 .53978 Mtetra
.662 .741 .909 r
.5138 .53978 .51678 .54287 .52226 .54122 .51928 .53814 Mtetra
.661 .741 .909 r
.51928 .53814 .52226 .54122 .52775 .53959 .52477 .5365 Mtetra
.662 .741 .909 r
.52477 .5365 .52775 .53959 .53324 .53798 .53028 .53483 Mtetra
.67 .74 .903 r
.53028 .53483 .53324 .53798 .53875 .5363 .53579 .53305 Mtetra
.659 .731 .903 r
.53579 .53305 .53875 .5363 .54427 .53444 .54132 .53144 Mtetra
.659 .748 .916 r
.54132 .53144 .54427 .53444 .5498 .53291 .54686 .52981 Mtetra
.672 .745 .906 r
.54686 .52981 .5498 .53291 .55535 .53122 .55241 .52799 Mtetra
.663 .735 .903 r
.55241 .52799 .55535 .53122 .5609 .52934 .55797 .5263 Mtetra
.656 .745 .915 r
.55797 .5263 .5609 .52934 .56646 .52777 .56354 .5247 Mtetra
.671 .748 .909 r
.56354 .5247 .56646 .52777 .57204 .52606 .56912 .52288 Mtetra
.653 .736 .911 r
.56912 .52288 .57204 .52606 .57763 .52439 .57472 .52133 Mtetra
.674 .751 .908 r
.57472 .52133 .57763 .52439 .58322 .52261 .58032 .51945 Mtetra
.651 .738 .913 r
.58032 .51945 .58322 .52261 .58883 .52093 .58594 .51792 Mtetra
.669 .753 .913 r
.58594 .51792 .58883 .52093 .59445 .51919 .59157 .51611 Mtetra
.668 .749 .911 r
.59157 .51611 .59445 .51919 .60009 .51763 .59721 .51432 Mtetra
.652 .729 .906 r
.59721 .51432 .60009 .51763 .60573 .51576 .60286 .51277 Mtetra
.674 .757 .913 r
.60286 .51277 .60573 .51576 .61138 .51411 .60852 .51087 Mtetra
.657 .737 .908 r
.60852 .51087 .61138 .51411 .61705 .51246 .6142 .50923 Mtetra
.662 .739 .907 r
.6142 .50923 .61705 .51246 .62273 .51059 .61988 .50751 Mtetra
.673 .752 .911 r
.61988 .50751 .62273 .51059 .62842 .50888 .62558 .50563 Mtetra
.65 .734 .911 r
.62558 .50563 .62842 .50888 .63412 .50723 .63129 .50409 Mtetra
.673 .75 .908 r
.63129 .50409 .63412 .50723 .63983 .50544 .63701 .50219 Mtetra
.655 .737 .91 r
.63701 .50219 .63983 .50544 .64556 .50383 .64275 .50057 Mtetra
.662 .739 .907 r
.64275 .50057 .64556 .50383 .6513 .50211 .64849 .49884 Mtetra
.666 .74 .905 r
.64849 .49884 .6513 .50211 .65705 .5004 .65424 .49703 Mtetra
.659 .732 .904 r
.65424 .49703 .65705 .5004 .66281 .49859 .66002 .49535 Mtetra
.674 .745 .904 r
.66002 .49535 .66281 .49859 .66857 .49657 .66579 .49342 Mtetra
.658 .747 .915 r
.66579 .49342 .66857 .49657 .67436 .49501 .67158 .49172 Mtetra
.671 .743 .904 r
.67158 .49172 .67436 .49501 .68014 .49304 .67738 .48984 Mtetra
.655 .743 .915 r
.67738 .48984 .68014 .49304 .68596 .49137 .6832 .48819 Mtetra
.675 .751 .908 r
.6832 .48819 .68596 .49137 .69178 .4897 .68902 .48623 Mtetra
.656 .727 .901 r
.68902 .48623 .69178 .4897 .6976 .48774 .69487 .48457 Mtetra
.658 .747 .916 r
.69487 .48457 .6976 .48774 .70345 .486 .70072 .48286 Mtetra
.678 .757 .91 r
.70072 .48286 .70345 .486 .70931 .4843 .70657 .48084 Mtetra
.65 .727 .905 r
.70657 .48084 .70931 .4843 .71516 .48232 .71246 .47926 Mtetra
.666 .759 .919 r
.71246 .47926 .71516 .48232 .72105 .48065 .71834 .47741 Mtetra
.672 .749 .908 r
.71834 .47741 .72105 .48065 .72693 .47872 .72424 .47547 Mtetra
.655 .743 .915 r
.72424 .47547 .72693 .47872 .73284 .47707 .73016 .47379 Mtetra
.67 .747 .908 r
.73016 .47379 .73284 .47707 .73875 .47516 .73607 .47188 Mtetra
.658 .743 .913 r
.73607 .47188 .73875 .47516 .74469 .47343 .74201 .47015 Mtetra
.67 .748 .909 r
.74201 .47015 .74469 .47343 .75062 .47151 .74796 .46822 Mtetra
.666 .747 .91 r
.74796 .46822 .75062 .47151 .75658 .46981 .75391 .46635 Mtetra
.654 .731 .906 r
.75391 .46635 .75658 .46981 .76255 .46805 .7599 .46469 Mtetra
.667 .743 .907 r
.7599 .46469 .76255 .46805 .76851 .46604 .76588 .4628 Mtetra
.67 .753 .913 r
.76588 .4628 .76851 .46604 .77451 .46439 .77187 .46087 Mtetra
.658 .731 .903 r
.77187 .46087 .77451 .46439 .78052 .46258 .77789 .45913 Mtetra
.664 .737 .905 r
.77789 .45913 .78052 .46258 .78653 .46068 .78391 .45729 Mtetra
.666 .742 .907 r
.78391 .45729 .78653 .46068 .79255 .4588 .78995 .4554 Mtetra
.666 .743 .908 r
.78995 .4554 .79255 .4588 .79859 .45693 .79599 .45352 Mtetra
.665 .742 .907 r
.79599 .45352 .79859 .45693 .80464 .45508 .80205 .45164 Mtetra
.666 .741 .906 r
.80205 .45164 .80464 .45508 .81071 .45322 .80812 .44974 Mtetra
.665 .738 .904 r
.80812 .44974 .81071 .45322 .81678 .45132 .81421 .44786 Mtetra
.662 .739 .907 r
.81421 .44786 .81678 .45132 .82287 .44942 .82031 .44603 Mtetra
.666 .745 .909 r
.82031 .44603 .82287 .44942 .82898 .44761 .82642 .44412 Mtetra
.662 .738 .906 r
.82642 .44412 .82898 .44761 .83509 .44568 .83255 .44227 Mtetra
.666 .745 .909 r
.83255 .44227 .83509 .44568 .84122 .44385 .83868 .44036 Mtetra
.662 .739 .907 r
.83868 .44036 .84122 .44385 .84736 .44194 .84484 .4385 Mtetra
.665 .744 .909 r
.84484 .4385 .84736 .44194 .85351 .44006 .851 .43659 Mtetra
.663 .742 .908 r
.851 .43659 .85351 .44006 .85968 .43818 .85718 .4347 Mtetra
.662 .741 .909 r
.85718 .4347 .85968 .43818 .86586 .43629 .86337 .43282 Mtetra
.663 .743 .909 r
.86337 .43282 .86586 .43629 .87206 .43442 .86957 .43093 Mtetra
.664 .742 .908 r
.86957 .43093 .87206 .43442 .87827 .43253 .87579 .42902 Mtetra
.665 .741 .907 r
.87579 .42902 .87827 .43253 .88448 .43061 .88202 .42709 Mtetra
.663 .741 .908 r
.88202 .42709 .88448 .43061 .89072 .42872 .88826 .42519 Mtetra
.663 .74 .907 r
.88826 .42519 .89072 .42872 .89697 .42683 .89452 .42328 Mtetra
.664 .74 .907 r
.89452 .42328 .89697 .42683 .90323 .42491 .90079 .42136 Mtetra
.663 .74 .908 r
.90079 .42136 .90323 .42491 .9095 .42298 .90707 .41945 Mtetra
.661 .741 .909 r
.90707 .41945 .9095 .42298 .91579 .42108 .91338 .41756 Mtetra
.665 .744 .909 r
.91338 .41756 .91579 .42108 .92209 .41918 .91968 .4156 Mtetra
.663 .74 .907 r
.91968 .4156 .92209 .41918 .9284 .41721 .92601 .41368 Mtetra
.664 .743 .909 r
.92601 .41368 .9284 .41721 .93474 .41533 .93234 .41173 Mtetra
.664 .739 .906 r
.93234 .41173 .93474 .41533 .94107 .41336 .93869 .40978 Mtetra
.657 .738 .91 r
.93869 .40978 .94107 .41336 .94743 .41147 .94507 .40794 Mtetra
.671 .748 .909 r
.94507 .40794 .94743 .41147 .9538 .40949 .95144 .40587 Mtetra
.662 .742 .909 r
.37703 .57757 .3802 .58051 .38541 .57904 .38225 .57599 Mtetra
.663 .735 .903 r
.38225 .57599 .38541 .57904 .39064 .57733 .38749 .5744 Mtetra
.666 .744 .908 r
.38749 .5744 .39064 .57733 .39588 .57576 .39274 .57275 Mtetra
.66 .738 .907 r
.39274 .57275 .39588 .57576 .40113 .57417 .39799 .57119 Mtetra
.666 .742 .906 r
.39799 .57119 .40113 .57417 .40639 .57251 .40326 .56954 Mtetra
.662 .741 .909 r
.40326 .56954 .40639 .57251 .41166 .57092 .40853 .56795 Mtetra
.664 .742 .908 r
.40853 .56795 .41166 .57092 .41694 .56929 .41382 .56633 Mtetra
.666 .744 .908 r
.41382 .56633 .41694 .56929 .42223 .56766 .41912 .56467 Mtetra
.662 .741 .909 r
.41912 .56467 .42223 .56766 .42754 .56605 .42443 .56306 Mtetra
.664 .742 .909 r
.42443 .56306 .42754 .56605 .43285 .56442 .42974 .56143 Mtetra
.665 .743 .908 r
.42974 .56143 .43285 .56442 .43817 .56279 .43507 .55978 Mtetra
.664 .741 .908 r
.43507 .55978 .43817 .56279 .4435 .56118 .44041 .55814 Mtetra
.663 .74 .907 r
.44041 .55814 .4435 .56118 .44884 .55957 .44576 .5565 Mtetra
.663 .739 .906 r
.44576 .5565 .44884 .55957 .4542 .55792 .45112 .55486 Mtetra
.663 .74 .907 r
.45112 .55486 .4542 .55792 .45956 .55626 .4565 .55322 Mtetra
.664 .741 .908 r
.4565 .55322 .45956 .55626 .46494 .55462 .46188 .55157 Mtetra
.663 .741 .908 r
.46188 .55157 .46494 .55462 .47032 .55298 .46727 .54992 Mtetra
.661 .739 .908 r
.46727 .54992 .47032 .55298 .47572 .55131 .47267 .5483 Mtetra
.665 .745 .909 r
.47267 .5483 .47572 .55131 .48113 .54971 .47809 .54662 Mtetra
.663 .739 .906 r
.47809 .54662 .48113 .54971 .48654 .54801 .48351 .54497 Mtetra
.664 .743 .909 r
.48351 .54497 .48654 .54801 .49197 .54641 .48895 .54329 Mtetra
.662 .738 .906 r
.48895 .54329 .49197 .54641 .49741 .54472 .49439 .54164 Mtetra
.663 .742 .908 r
.49439 .54164 .49741 .54472 .50286 .54305 .49985 .53997 Mtetra
.664 .742 .908 r
.49985 .53997 .50286 .54305 .50832 .54143 .50532 .5383 Mtetra
.66 .738 .907 r
.50532 .5383 .50832 .54143 .5138 .53978 .5108 .53667 Mtetra
.661 .739 .908 r
.5108 .53667 .5138 .53978 .51928 .53814 .51629 .53502 Mtetra
.663 .74 .908 r
.51629 .53502 .51928 .53814 .52477 .5365 .52179 .53335 Mtetra
.665 .739 .905 r
.52179 .53335 .52477 .5365 .53028 .53483 .5273 .53164 Mtetra
.662 .736 .905 r
.5273 .53164 .53028 .53483 .53579 .53305 .53282 .52997 Mtetra
.655 .742 .914 r
.53282 .52997 .53579 .53305 .54132 .53144 .53836 .5284 Mtetra
.668 .749 .911 r
.53836 .5284 .54132 .53144 .54686 .52981 .5439 .52664 Mtetra
.669 .741 .904 r
.5439 .52664 .54686 .52981 .55241 .52799 .54946 .52485 Mtetra
.656 .739 .911 r
.54946 .52485 .55241 .52799 .55797 .5263 .55503 .52326 Mtetra
.669 .75 .911 r
.55503 .52326 .55797 .5263 .56354 .5247 .56061 .52146 Mtetra
.654 .733 .907 r
.56061 .52146 .56354 .5247 .56912 .52288 .5662 .51989 Mtetra
.674 .756 .912 r
.5662 .51989 .56912 .52288 .57472 .52133 .5718 .51802 Mtetra
.653 .728 .904 r
.5718 .51802 .57472 .52133 .58032 .51945 .57741 .51646 Mtetra
.674 .756 .912 r
.57741 .51646 .58032 .51945 .58594 .51792 .58304 .51457 Mtetra
.65 .726 .905 r
.58304 .51457 .58594 .51792 .59157 .51611 .58868 .51306 Mtetra
.67 .752 .912 r
.58868 .51306 .59157 .51611 .59721 .51432 .59432 .51122 Mtetra
.669 .749 .911 r
.59432 .51122 .59721 .51432 .60286 .51277 .59998 .50941 Mtetra
.647 .726 .906 r
.59998 .50941 .60286 .51277 .60852 .51087 .60565 .50792 Mtetra
.68 .763 .914 r
.60565 .50792 .60852 .51087 .6142 .50923 .61133 .50593 Mtetra
.654 .732 .907 r
.61133 .50593 .6142 .50923 .61988 .50751 .61703 .50434 Mtetra
.661 .743 .911 r
.61703 .50434 .61988 .50751 .62558 .50563 .62273 .50263 Mtetra
.674 .759 .915 r
.62273 .50263 .62558 .50563 .63129 .50409 .62845 .50071 Mtetra
.657 .729 .903 r
.62845 .50071 .63129 .50409 .63701 .50219 .63418 .49905 Mtetra
.663 .747 .913 r
.63418 .49905 .63701 .50219 .64275 .50057 .63992 .49729 Mtetra
.666 .74 .905 r
.63992 .49729 .64275 .50057 .64849 .49884 .64567 .49549 Mtetra
.665 .735 .903 r
.64567 .49549 .64849 .49884 .65424 .49703 .65143 .49371 Mtetra
.663 .737 .905 r
.65143 .49371 .65424 .49703 .66002 .49535 .65721 .49195 Mtetra
.656 .73 .904 r
.65721 .49195 .66002 .49535 .66579 .49342 .663 .4903 Mtetra
.675 .755 .911 r
.663 .4903 .66579 .49342 .67158 .49172 .66879 .48833 Mtetra
.649 .729 .907 r
.66879 .48833 .67158 .49172 .67738 .48984 .67461 .48677 Mtetra
.675 .759 .914 r
.67461 .48677 .67738 .48984 .6832 .48819 .68043 .48481 Mtetra
.661 .735 .904 r
.68043 .48481 .6832 .48819 .68902 .48623 .68627 .48306 Mtetra
.656 .747 .917 r
.68627 .48306 .68902 .48623 .69487 .48457 .69212 .48138 Mtetra
.678 .753 .908 r
.69212 .48138 .69487 .48457 .70072 .48286 .69797 .47936 Mtetra
.653 .725 .902 r
.69797 .47936 .70072 .48286 .70657 .48084 .70385 .47773 Mtetra
.667 .756 .917 r
.70385 .47773 .70657 .48084 .71246 .47926 .70973 .47587 Mtetra
.67 .74 .903 r
.70973 .47587 .71246 .47926 .71834 .47741 .71562 .47396 Mtetra
.653 .731 .906 r
.71562 .47396 .71834 .47741 .72424 .47547 .72154 .47232 Mtetra
.675 .757 .912 r
.72154 .47232 .72424 .47547 .73016 .47379 .72744 .47031 Mtetra
.65 .728 .906 r
.72744 .47031 .73016 .47379 .73607 .47188 .73339 .4687 Mtetra
.676 .757 .912 r
.73339 .4687 .73607 .47188 .74201 .47015 .73932 .46667 Mtetra
.656 .732 .905 r
.73932 .46667 .74201 .47015 .74796 .46822 .74529 .46498 Mtetra
.672 .752 .911 r
.74529 .46498 .74796 .46822 .75391 .46635 .75125 .46301 Mtetra
.66 .742 .91 r
.75125 .46301 .75391 .46635 .7599 .46469 .75723 .46122 Mtetra
.656 .733 .907 r
.75723 .46122 .7599 .46469 .76588 .4628 .76324 .45951 Mtetra
.672 .751 .91 r
.76324 .45951 .76588 .4628 .77187 .46087 .76924 .45753 Mtetra
.664 .745 .91 r
.76924 .45753 .77187 .46087 .77789 .45913 .77525 .45567 Mtetra
.663 .738 .905 r
.77525 .45567 .77789 .45913 .78391 .45729 .78129 .45383 Mtetra
.664 .738 .905 r
.78129 .45383 .78391 .45729 .78995 .4554 .78733 .45197 Mtetra
.666 .741 .907 r
.78733 .45197 .78995 .4554 .79599 .45352 .79339 .45008 Mtetra
.667 .742 .906 r
.79339 .45008 .79599 .45352 .80205 .45164 .79945 .44817 Mtetra
.664 .739 .906 r
.79945 .44817 .80205 .45164 .80812 .44974 .80554 .4463 Mtetra
.664 .742 .908 r
.80554 .4463 .80812 .44974 .81421 .44786 .81163 .44442 Mtetra
.81163 .44442 .81421 .44786 .82031 .44603 .81774 .44254 Mtetra
.664 .74 .906 r
.81774 .44254 .82031 .44603 .82642 .44412 .82386 .44066 Mtetra
.663 .741 .908 r
.82386 .44066 .82642 .44412 .83255 .44227 .83 .43879 Mtetra
.663 .74 .907 r
.83 .43879 .83255 .44227 .83868 .44036 .83615 .43691 Mtetra
.666 .744 .909 r
.83615 .43691 .83868 .44036 .84484 .4385 .8423 .43499 Mtetra
.663 .739 .907 r
.8423 .43499 .84484 .4385 .851 .43659 .84848 .4331 Mtetra
.664 .742 .908 r
.84848 .4331 .851 .43659 .85718 .4347 .85466 .4312 Mtetra
.664 .741 .908 r
.85466 .4312 .85718 .4347 .86337 .43282 .86086 .42929 Mtetra
.663 .74 .907 r
.86086 .42929 .86337 .43282 .86957 .43093 .86708 .42739 Mtetra
.86708 .42739 .86957 .43093 .87579 .42902 .8733 .42549 Mtetra
.664 .741 .908 r
.8733 .42549 .87579 .42902 .88202 .42709 .87954 .42357 Mtetra
.662 .741 .908 r
.87954 .42357 .88202 .42709 .88826 .42519 .8858 .42167 Mtetra
.663 .742 .909 r
.8858 .42167 .88826 .42519 .89452 .42328 .89207 .41977 Mtetra
.665 .744 .909 r
.89207 .41977 .89452 .42328 .90079 .42136 .89834 .41781 Mtetra
.662 .741 .909 r
.89834 .41781 .90079 .42136 .90707 .41945 .90464 .4159 Mtetra
.662 .742 .909 r
.90464 .4159 .90707 .41945 .91338 .41756 .91095 .41399 Mtetra
.666 .742 .907 r
.91095 .41399 .91338 .41756 .91968 .4156 .91726 .41201 Mtetra
.662 .74 .907 r
.91726 .41201 .91968 .4156 .92601 .41368 .9236 .41009 Mtetra
.665 .741 .907 r
.9236 .41009 .92601 .41368 .93234 .41173 .92995 .40812 Mtetra
.66 .739 .908 r
.92995 .40812 .93234 .41173 .93869 .40978 .93632 .40623 Mtetra
.664 .745 .91 r
.93632 .40623 .93869 .40978 .94507 .40794 .94269 .40427 Mtetra
.666 .738 .904 r
.94269 .40427 .94507 .40794 .95144 .40587 .94907 .40228 Mtetra
.659 .74 .91 r
.37385 .5746 .37703 .57757 .38225 .57599 .37908 .57306 Mtetra
.665 .744 .909 r
.37908 .57306 .38225 .57599 .38749 .5744 .38432 .57143 Mtetra
.666 .742 .907 r
.38432 .57143 .38749 .5744 .39274 .57275 .38958 .56978 Mtetra
.662 .741 .908 r
.38958 .56978 .39274 .57275 .39799 .57119 .39484 .56818 Mtetra
.663 .739 .906 r
.39484 .56818 .39799 .57119 .40326 .56954 .40011 .56656 Mtetra
.664 .742 .908 r
.40011 .56656 .40326 .56954 .40853 .56795 .40539 .56494 Mtetra
.662 .74 .908 r
.40539 .56494 .40853 .56795 .41382 .56633 .41069 .56333 Mtetra
.666 .742 .907 r
.41069 .56333 .41382 .56633 .41912 .56467 .41599 .56166 Mtetra
.662 .741 .909 r
.41599 .56166 .41912 .56467 .42443 .56306 .42131 .56006 Mtetra
.664 .742 .908 r
.42131 .56006 .42443 .56306 .42974 .56143 .42663 .55842 Mtetra
.665 .742 .908 r
.42663 .55842 .42974 .56143 .43507 .55978 .43197 .55676 Mtetra
.662 .741 .909 r
.43197 .55676 .43507 .55978 .44041 .55814 .43731 .55514 Mtetra
.663 .743 .909 r
.43731 .55514 .44041 .55814 .44576 .5565 .44267 .5535 Mtetra
.665 .744 .909 r
.44267 .5535 .44576 .5565 .45112 .55486 .44804 .55183 Mtetra
.664 .742 .908 r
.44804 .55183 .45112 .55486 .4565 .55322 .45342 .55017 Mtetra
.662 .741 .908 r
.45342 .55017 .4565 .55322 .46188 .55157 .4588 .54853 Mtetra
.662 .742 .909 r
.4588 .54853 .46188 .55157 .46727 .54992 .4642 .54689 Mtetra
.666 .744 .909 r
.4642 .54689 .46727 .54992 .47267 .5483 .46961 .5452 Mtetra
.662 .739 .906 r
.46961 .5452 .47267 .5483 .47809 .54662 .47503 .54355 Mtetra
.663 .742 .908 r
.47503 .54355 .47809 .54662 .48351 .54497 .48047 .54189 Mtetra
.664 .741 .907 r
.48047 .54189 .48351 .54497 .48895 .54329 .48591 .5402 Mtetra
.662 .741 .909 r
.48591 .5402 .48895 .54329 .49439 .54164 .49136 .53856 Mtetra
.663 .741 .909 r
.49136 .53856 .49439 .54164 .49985 .53997 .49683 .53689 Mtetra
.666 .743 .908 r
.49683 .53689 .49985 .53997 .50532 .5383 .5023 .53518 Mtetra
.661 .74 .908 r
.5023 .53518 .50532 .5383 .5108 .53667 .50779 .53352 Mtetra
.662 .739 .907 r
.50779 .53352 .5108 .53667 .51629 .53502 .51328 .53186 Mtetra
.664 .738 .905 r
.51328 .53186 .51629 .53502 .52179 .53335 .51879 .53016 Mtetra
.656 .735 .907 r
.51879 .53016 .52179 .53335 .5273 .53164 .52431 .52857 Mtetra
.654 .742 .915 r
.52431 .52857 .5273 .53164 .53282 .52997 .52984 .52701 Mtetra
.669 .754 .914 r
.52984 .52701 .53282 .52997 .53836 .5284 .53538 .52522 Mtetra
.672 .741 .902 r
.53538 .52522 .53836 .5284 .5439 .52664 .54094 .52338 Mtetra
.652 .73 .907 r
.54094 .52338 .5439 .52664 .54946 .52485 .5465 .52185 Mtetra
.671 .753 .913 r
.5465 .52185 .54946 .52485 .55503 .52326 .55208 .52003 Mtetra
.66 .736 .906 r
.55208 .52003 .55503 .52326 .56061 .52146 .55766 .51837 Mtetra
.662 .745 .912 r
.55766 .51837 .56061 .52146 .5662 .51989 .56326 .51666 Mtetra
.662 .737 .906 r
.56326 .51666 .5662 .51989 .5718 .51802 .56887 .51497 Mtetra
.671 .752 .912 r
.56887 .51497 .5718 .51802 .57741 .51646 .57449 .51313 Mtetra
.65 .728 .906 r
.57449 .51313 .57741 .51646 .58304 .51457 .58013 .5116 Mtetra
.678 .76 .913 r
.58013 .5116 .58304 .51457 .58868 .51306 .58576 .50964 Mtetra
.654 .725 .901 r
.58576 .50964 .58868 .51306 .59432 .51122 .59142 .50805 Mtetra
.661 .743 .91 r
.59142 .50805 .59432 .51122 .59998 .50941 .59709 .50634 Mtetra
.675 .754 .911 r
.59709 .50634 .59998 .50941 .60565 .50792 .60276 .50443 Mtetra
.649 .72 .9 r
.60276 .50443 .60565 .50792 .61133 .50593 .60846 .50291 Mtetra
.673 .758 .914 r
.60846 .50291 .61133 .50593 .61703 .50434 .61416 .501 Mtetra
.66 .734 .904 r
.61416 .501 .61703 .50434 .62273 .50263 .61987 .49931 Mtetra
.665 .737 .904 r
.61987 .49931 .62273 .50263 .62845 .50071 .6256 .49754 Mtetra
.658 .744 .914 r
.6256 .49754 .62845 .50071 .63418 .49905 .63133 .49586 Mtetra
.672 .748 .907 r
.63133 .49586 .63418 .49905 .63992 .49729 .63708 .49396 Mtetra
.661 .736 .905 r
.63708 .49396 .63992 .49729 .64567 .49549 .64284 .49223 Mtetra
.664 .742 .908 r
.64284 .49223 .64567 .49549 .65143 .49371 .64861 .49044 Mtetra
.666 .743 .907 r
.64861 .49044 .65143 .49371 .65721 .49195 .65439 .48862 Mtetra
.658 .736 .907 r
.65439 .48862 .65721 .49195 .663 .4903 .66019 .48693 Mtetra
.657 .734 .906 r
.66019 .48693 .663 .4903 .66879 .48833 .666 .48524 Mtetra
.674 .757 .914 r
.666 .48524 .66879 .48833 .67461 .48677 .67182 .48329 Mtetra
.655 .727 .902 r
.67182 .48329 .67461 .48677 .68043 .48481 .67765 .48163 Mtetra
.663 .749 .914 r
.67765 .48163 .68043 .48481 .68627 .48306 .6835 .47983 Mtetra
.677 .751 .907 r
.6835 .47983 .68627 .48306 .69212 .48138 .68934 .47782 Mtetra
.647 .721 .902 r
.68934 .47782 .69212 .48138 .69797 .47936 .69522 .47628 Mtetra
.675 .761 .916 r
.69522 .47628 .69797 .47936 .70385 .47773 .70109 .47429 Mtetra
.664 .735 .902 r
.70109 .47429 .70385 .47773 .70973 .47587 .70699 .47247 Mtetra
.652 .733 .909 r
.70699 .47247 .70973 .47587 .71562 .47396 .7129 .47084 Mtetra
.678 .76 .913 r
.7129 .47084 .71562 .47396 .72154 .47232 .7188 .46878 Mtetra
.653 .726 .903 r
.7188 .46878 .72154 .47232 .72744 .47031 .72474 .46713 Mtetra
.672 .756 .914 r
.72474 .46713 .72744 .47031 .73339 .4687 .73068 .46518 Mtetra
.656 .729 .903 r
.73068 .46518 .73339 .4687 .73932 .46667 .73664 .46347 Mtetra
.673 .756 .913 r
.73664 .46347 .73932 .46667 .74529 .46498 .74259 .46148 Mtetra
.655 .731 .905 r
.74259 .46148 .74529 .46498 .75125 .46301 .74858 .45978 Mtetra
.672 .755 .913 r
.74858 .45978 .75125 .46301 .75723 .46122 .75456 .4578 Mtetra
.66 .738 .908 r
.75456 .4578 .75723 .46122 .76324 .45951 .76057 .45601 Mtetra
.655 .732 .906 r
.76057 .45601 .76324 .45951 .76924 .45753 .7666 .4543 Mtetra
.67 .755 .914 r
.7666 .4543 .76924 .45753 .77525 .45567 .77262 .45234 Mtetra
.672 .75 .909 r
.77262 .45234 .77525 .45567 .78129 .45383 .77865 .45034 Mtetra
.663 .738 .905 r
.77865 .45034 .78129 .45383 .78733 .45197 .7847 .44848 Mtetra
.665 .738 .905 r
.7847 .44848 .78733 .45197 .79339 .45008 .79077 .4466 Mtetra
.665 .74 .905 r
.79077 .4466 .79339 .45008 .79945 .44817 .79685 .4447 Mtetra
.662 .739 .907 r
.79685 .4447 .79945 .44817 .80554 .4463 .80294 .44286 Mtetra
.664 .742 .908 r
.80294 .44286 .80554 .4463 .81163 .44442 .80904 .44098 Mtetra
.665 .743 .908 r
.80904 .44098 .81163 .44442 .81774 .44254 .81516 .43907 Mtetra
.663 .741 .908 r
.81516 .43907 .81774 .44254 .82386 .44066 .82129 .43719 Mtetra
.665 .742 .908 r
.82129 .43719 .82386 .44066 .83 .43879 .82743 .43528 Mtetra
.663 .739 .907 r
.82743 .43528 .83 .43879 .83615 .43691 .83359 .43341 Mtetra
.662 .74 .908 r
.83359 .43341 .83615 .43691 .8423 .43499 .83976 .43153 Mtetra
.665 .744 .909 r
.83976 .43153 .8423 .43499 .84848 .4331 .84594 .4296 Mtetra
.664 .741 .908 r
.84594 .4296 .84848 .4331 .85466 .4312 .85214 .42768 Mtetra
.663 .741 .908 r
.85214 .42768 .85466 .4312 .86086 .42929 .85835 .42579 Mtetra
.662 .742 .909 r
.85835 .42579 .86086 .42929 .86708 .42739 .86458 .4239 Mtetra
.664 .743 .909 r
.86458 .4239 .86708 .42739 .8733 .42549 .87081 .42198 Mtetra
.665 .743 .908 r
.87081 .42198 .8733 .42549 .87954 .42357 .87706 .42003 Mtetra
.663 .741 .908 r
.87706 .42003 .87954 .42357 .8858 .42167 .88332 .41811 Mtetra
.663 .74 .907 r
.88332 .41811 .8858 .42167 .89207 .41977 .8896 .4162 Mtetra
.665 .741 .907 r
.8896 .4162 .89207 .41977 .89834 .41781 .89589 .41424 Mtetra
.663 .741 .908 r
.89589 .41424 .89834 .41781 .90464 .4159 .90219 .41232 Mtetra
.663 .74 .907 r
.90219 .41232 .90464 .4159 .91095 .41399 .90851 .41038 Mtetra
.665 .74 .906 r
.90851 .41038 .91095 .41399 .91726 .41201 .91484 .40842 Mtetra
.663 .741 .908 r
.91484 .40842 .91726 .41201 .9236 .41009 .92118 .40648 Mtetra
.663 .74 .907 r
.92118 .40648 .9236 .41009 .92995 .40812 .92754 .40453 Mtetra
.66 .74 .91 r
.92754 .40453 .92995 .40812 .93632 .40623 .93392 .40263 Mtetra
.666 .743 .907 r
.93392 .40263 .93632 .40623 .94269 .40427 .9403 .40062 Mtetra
.664 .74 .907 r
.9403 .40062 .94269 .40427 .94907 .40228 .9467 .39865 Mtetra
.657 .74 .911 r
.37066 .57163 .37385 .5746 .37908 .57306 .3759 .57011 Mtetra
.669 .744 .907 r
.3759 .57011 .37908 .57306 .38432 .57143 .38115 .56841 Mtetra
.663 .739 .907 r
.38115 .56841 .38432 .57143 .38958 .56978 .38641 .56681 Mtetra
.665 .743 .908 r
.38641 .56681 .38958 .56978 .39484 .56818 .39168 .56517 Mtetra
.663 .74 .907 r
.39168 .56517 .39484 .56818 .40011 .56656 .39695 .56355 Mtetra
.664 .74 .907 r
.39695 .56355 .40011 .56656 .40539 .56494 .40224 .56191 Mtetra
.663 .74 .907 r
.40224 .56191 .40539 .56494 .41069 .56333 .40754 .5603 Mtetra
.665 .74 .906 r
.40754 .5603 .41069 .56333 .41599 .56166 .41286 .55864 Mtetra
.663 .741 .908 r
.41286 .55864 .41599 .56166 .42131 .56006 .41818 .55702 Mtetra
.664 .74 .907 r
.41818 .55702 .42131 .56006 .42663 .55842 .42351 .55537 Mtetra
.42351 .55537 .42663 .55842 .43197 .55676 .42885 .55372 Mtetra
.662 .741 .908 r
.42885 .55372 .43197 .55676 .43731 .55514 .4342 .55209 Mtetra
.663 .741 .908 r
.4342 .55209 .43731 .55514 .44267 .5535 .43957 .55044 Mtetra
.665 .741 .907 r
.43957 .55044 .44267 .5535 .44804 .55183 .44494 .54877 Mtetra
.664 .741 .907 r
.44494 .54877 .44804 .55183 .45342 .55017 .45032 .54711 Mtetra
.664 .741 .908 r
.45032 .54711 .45342 .55017 .4588 .54853 .45572 .54545 Mtetra
.663 .74 .907 r
.45572 .54545 .4588 .54853 .4642 .54689 .46113 .54379 Mtetra
.662 .739 .907 r
.46113 .54379 .4642 .54689 .46961 .5452 .46654 .54215 Mtetra
.665 .744 .909 r
.46654 .54215 .46961 .5452 .47503 .54355 .47197 .54047 Mtetra
.665 .741 .907 r
.47197 .54047 .47503 .54355 .48047 .54189 .47741 .53878 Mtetra
.661 .739 .908 r
.47741 .53878 .48047 .54189 .48591 .5402 .48286 .53713 Mtetra
.666 .743 .908 r
.48286 .53713 .48591 .5402 .49136 .53856 .48832 .53542 Mtetra
.659 .738 .908 r
.48832 .53542 .49136 .53856 .49683 .53689 .49379 .5338 Mtetra
.66 .741 .91 r
.49379 .5338 .49683 .53689 .5023 .53518 .49927 .53217 Mtetra
.661 .747 .914 r
.49927 .53217 .5023 .53518 .50779 .53352 .50476 .53051 Mtetra
.66 .747 .915 r
.50476 .53051 .50779 .53352 .51328 .53186 .51027 .52886 Mtetra
.659 .748 .916 r
.51027 .52886 .51328 .53186 .51879 .53016 .51578 .52722 Mtetra
.662 .753 .918 r
.51578 .52722 .51879 .53016 .52431 .52857 .52131 .52553 Mtetra
.671 .75 .91 r
.52131 .52553 .52431 .52857 .52984 .52701 .52685 .52372 Mtetra
.662 .732 .901 r
.52685 .52372 .52984 .52701 .53538 .52522 .5324 .52203 Mtetra
.654 .736 .91 r
.5324 .52203 .53538 .52522 .54094 .52338 .53796 .52047 Mtetra
.677 .761 .915 r
.53796 .52047 .54094 .52338 .5465 .52185 .54353 .51855 Mtetra
.66 .732 .903 r
.54353 .51855 .5465 .52185 .55208 .52003 .54911 .51689 Mtetra
.658 .742 .912 r
.54911 .51689 .55208 .52003 .55766 .51837 .55471 .51525 Mtetra
.667 .746 .91 r
.55471 .51525 .55766 .51837 .56326 .51666 .56031 .51347 Mtetra
.665 .741 .907 r
.56031 .51347 .56326 .51666 .56887 .51497 .56593 .51171 Mtetra
.66 .736 .906 r
.56593 .51171 .56887 .51497 .57449 .51313 .57156 .51003 Mtetra
.67 .749 .91 r
.57156 .51003 .57449 .51313 .58013 .5116 .5772 .5082 Mtetra
.653 .725 .902 r
.5772 .5082 .58013 .5116 .58576 .50964 .58285 .50661 Mtetra
.676 .757 .912 r
.58285 .50661 .58576 .50964 .59142 .50805 .58851 .50468 Mtetra
.657 .729 .903 r
.58851 .50468 .59142 .50805 .59709 .50634 .59419 .50304 Mtetra
.658 .734 .906 r
.59419 .50304 .59709 .50634 .60276 .50443 .59987 .50138 Mtetra
.678 .757 .911 r
.59987 .50138 .60276 .50443 .60846 .50291 .60557 .49939 Mtetra
.648 .719 .9 r
.60557 .49939 .60846 .50291 .61416 .501 .61128 .49789 Mtetra
.673 .752 .911 r
.61128 .49789 .61416 .501 .61987 .49931 .617 .49599 Mtetra
.653 .733 .908 r
.617 .49599 .61987 .49931 .6256 .49754 .62274 .49438 Mtetra
.68 .753 .906 r
.62274 .49438 .6256 .49754 .63133 .49586 .62847 .49235 Mtetra
.639 .718 .904 r
.62847 .49235 .63133 .49586 .63708 .49396 .63424 .49095 Mtetra
.665 .759 .92 r
.63424 .49095 .63708 .49396 .64284 .49223 .64001 .48915 Mtetra
.661 .754 .919 r
.64001 .48915 .64284 .49223 .64861 .49044 .64579 .4874 Mtetra
.664 .757 .92 r
.64579 .4874 .64861 .49044 .65439 .48862 .65158 .4856 Mtetra
.681 .764 .914 r
.65158 .4856 .65439 .48862 .66019 .48693 .65737 .48354 Mtetra
.658 .734 .905 r
.65737 .48354 .66019 .48693 .666 .48524 .66319 .48183 Mtetra
.66 .733 .904 r
.66319 .48183 .666 .48524 .67182 .48329 .66902 .48009 Mtetra
.668 .75 .912 r
.66902 .48009 .67182 .48329 .67765 .48163 .67486 .47822 Mtetra
.668 .737 .902 r
.67486 .47822 .67765 .48163 .6835 .47983 .68071 .47635 Mtetra
.655 .729 .904 r
.68071 .47635 .6835 .47983 .68934 .47782 .68658 .47469 Mtetra
.675 .759 .914 r
.68658 .47469 .68934 .47782 .69522 .47628 .69245 .4727 Mtetra
.658 .724 .898 r
.69245 .4727 .69522 .47628 .70109 .47429 .69834 .47098 Mtetra
.661 .742 .91 r
.69834 .47098 .70109 .47429 .70699 .47247 .70424 .4692 Mtetra
.675 .75 .908 r
.70424 .4692 .70699 .47247 .7129 .47084 .71014 .4672 Mtetra
.65 .719 .899 r
.71014 .4672 .7129 .47084 .7188 .46878 .71608 .4656 Mtetra
.674 .757 .913 r
.71608 .4656 .7188 .46878 .72474 .46713 .72201 .4636 Mtetra
.654 .728 .903 r
.72201 .4636 .72474 .46713 .73068 .46518 .72797 .46193 Mtetra
.668 .751 .912 r
.72797 .46193 .73068 .46518 .73664 .46347 .73393 .46001 Mtetra
.661 .736 .905 r
.73393 .46001 .73664 .46347 .74259 .46148 .7399 .45821 Mtetra
.673 .753 .91 r
.7399 .45821 .74259 .46148 .74858 .45978 .74588 .4562 Mtetra
.65 .725 .904 r
.74588 .4562 .74858 .45978 .75456 .4578 .7519 .45458 Mtetra
.668 .755 .915 r
.7519 .45458 .75456 .4578 .76057 .45601 .7579 .45266 Mtetra
.67 .748 .908 r
.7579 .45266 .76057 .45601 .7666 .4543 .76392 .45069 Mtetra
.656 .727 .901 r
.76392 .45069 .7666 .4543 .77262 .45234 .76997 .44896 Mtetra
.663 .744 .911 r
.76997 .44896 .77262 .45234 .77865 .45034 .77602 .44711 Mtetra
.667 .756 .917 r
.77602 .44711 .77865 .45034 .7847 .44848 .78208 .44518 Mtetra
.666 .751 .914 r
.78208 .44518 .7847 .44848 .79077 .4466 .78815 .44326 Mtetra
.666 .749 .913 r
.78815 .44326 .79077 .4466 .79685 .4447 .79424 .44135 Mtetra
.667 .749 .912 r
.79424 .44135 .79685 .4447 .80294 .44286 .80033 .43942 Mtetra
.667 .745 .908 r
.80033 .43942 .80294 .44286 .80904 .44098 .80644 .43747 Mtetra
.663 .739 .907 r
.80644 .43747 .80904 .44098 .81516 .43907 .81257 .4356 Mtetra
.665 .743 .908 r
.81257 .4356 .81516 .43907 .82129 .43719 .81871 .43369 Mtetra
.663 .74 .907 r
.81871 .43369 .82129 .43719 .82743 .43528 .82486 .43181 Mtetra
.664 .743 .909 r
.82486 .43181 .82743 .43528 .83359 .43341 .83103 .4299 Mtetra
.665 .742 .907 r
.83103 .4299 .83359 .43341 .83976 .43153 .83721 .42798 Mtetra
.662 .738 .906 r
.83721 .42798 .83976 .43153 .84594 .4296 .8434 .42609 Mtetra
.664 .742 .908 r
.8434 .42609 .84594 .4296 .85214 .42768 .84961 .42417 Mtetra
.665 .743 .908 r
.84961 .42417 .85214 .42768 .85835 .42579 .85583 .42224 Mtetra
.663 .74 .907 r
.85583 .42224 .85835 .42579 .86458 .4239 .86206 .42032 Mtetra
.664 .739 .906 r
.86206 .42032 .86458 .4239 .87081 .42198 .8683 .4184 Mtetra
.663 .739 .906 r
.8683 .4184 .87081 .42198 .87706 .42003 .87456 .41647 Mtetra
.663 .741 .908 r
.87456 .41647 .87706 .42003 .88332 .41811 .88084 .41454 Mtetra
.664 .741 .908 r
.88084 .41454 .88332 .41811 .8896 .4162 .88712 .41261 Mtetra
.664 .74 .907 r
.88712 .41261 .8896 .4162 .89589 .41424 .89342 .41066 Mtetra
.664 .741 .908 r
.89342 .41066 .89589 .41424 .90219 .41232 .89974 .40872 Mtetra
.664 .74 .907 r
.89974 .40872 .90219 .41232 .90851 .41038 .90606 .40677 Mtetra
.663 .74 .907 r
.90606 .40677 .90851 .41038 .91484 .40842 .9124 .40483 Mtetra
.664 .742 .908 r
.9124 .40483 .91484 .40842 .92118 .40648 .91876 .40287 Mtetra
.661 .74 .909 r
.91876 .40287 .92118 .40648 .92754 .40453 .92513 .40095 Mtetra
.665 .744 .909 r
.92513 .40095 .92754 .40453 .93392 .40263 .93151 .39896 Mtetra
.661 .737 .906 r
.93151 .39896 .93392 .40263 .9403 .40062 .93791 .39703 Mtetra
.668 .746 .908 r
.93791 .39703 .9403 .40062 .9467 .39865 .94431 .39499 Mtetra
.662 .741 .909 r
.36746 .56866 .37066 .57163 .3759 .57011 .3727 .56706 Mtetra
.661 .737 .906 r
.3727 .56706 .3759 .57011 .38115 .56841 .37796 .56547 Mtetra
.666 .745 .909 r
.37796 .56547 .38115 .56841 .38641 .56681 .38322 .56381 Mtetra
.664 .742 .908 r
.38322 .56381 .38641 .56681 .39168 .56517 .3885 .56217 Mtetra
.3885 .56217 .39168 .56517 .39695 .56355 .39379 .56054 Mtetra
.663 .741 .908 r
.39379 .56054 .39695 .56355 .40224 .56191 .39908 .5589 Mtetra
.664 .742 .908 r
.39908 .5589 .40224 .56191 .40754 .5603 .40439 .55725 Mtetra
.663 .74 .907 r
.40439 .55725 .40754 .5603 .41286 .55864 .40971 .55563 Mtetra
.664 .742 .908 r
.40971 .55563 .41286 .55864 .41818 .55702 .41503 .55397 Mtetra
.663 .74 .908 r
.41503 .55397 .41818 .55702 .42351 .55537 .42037 .55234 Mtetra
.664 .742 .908 r
.42037 .55234 .42351 .55537 .42885 .55372 .42572 .55068 Mtetra
.665 .742 .908 r
.42572 .55068 .42885 .55372 .4342 .55209 .43108 .54901 Mtetra
.663 .74 .907 r
.43108 .54901 .4342 .55209 .43957 .55044 .43645 .54736 Mtetra
.664 .74 .907 r
.43645 .54736 .43957 .55044 .44494 .54877 .44183 .5457 Mtetra
.663 .741 .908 r
.44183 .5457 .44494 .54877 .45032 .54711 .44722 .54405 Mtetra
.662 .741 .909 r
.44722 .54405 .45032 .54711 .45572 .54545 .45262 .54241 Mtetra
.664 .743 .909 r
.45262 .54241 .45572 .54545 .46113 .54379 .45804 .54073 Mtetra
.666 .744 .908 r
.45804 .54073 .46113 .54379 .46654 .54215 .46346 .53903 Mtetra
.663 .739 .906 r
.46346 .53903 .46654 .54215 .47197 .54047 .4689 .53736 Mtetra
.662 .74 .908 r
.4689 .53736 .47197 .54047 .47741 .53878 .47434 .5357 Mtetra
.665 .744 .909 r
.47434 .5357 .47741 .53878 .48286 .53713 .4798 .53399 Mtetra
.659 .738 .908 r
.4798 .53399 .48286 .53713 .48832 .53542 .48526 .53238 Mtetra
.664 .746 .911 r
.48526 .53238 .48832 .53542 .49379 .5338 .49074 .53067 Mtetra
.668 .742 .906 r
.49074 .53067 .49379 .5338 .49927 .53217 .49623 .52891 Mtetra
.661 .732 .903 r
.49623 .52891 .49927 .53217 .50476 .53051 .50173 .52726 Mtetra
.662 .733 .903 r
.50173 .52726 .50476 .53051 .51027 .52886 .50724 .52558 Mtetra
.667 .733 .9 r
.50724 .52558 .51027 .52886 .51578 .52722 .51277 .52383 Mtetra
.655 .723 .899 r
.51277 .52383 .51578 .52722 .52131 .52553 .5183 .52225 Mtetra
.649 .729 .907 r
.5183 .52225 .52131 .52553 .52685 .52372 .52385 .52075 Mtetra
.666 .754 .917 r
.52385 .52075 .52685 .52372 .5324 .52203 .5294 .519 Mtetra
.683 .756 .906 r
.5294 .519 .5324 .52203 .53796 .52047 .53497 .51698 Mtetra
.646 .716 .899 r
.53497 .51698 .53796 .52047 .54353 .51855 .54055 .51552 Mtetra
.668 .752 .914 r
.54055 .51552 .54353 .51855 .54911 .51689 .54614 .51374 Mtetra
.664 .743 .909 r
.54614 .51374 .54911 .51689 .55471 .51525 .55174 .512 Mtetra
.662 .737 .906 r
.55174 .512 .55471 .51525 .56031 .51347 .55735 .5103 Mtetra
.665 .743 .908 r
.55735 .5103 .56031 .51347 .56593 .51171 .56298 .50854 Mtetra
.665 .743 .909 r
.56298 .50854 .56593 .51171 .57156 .51003 .56861 .50677 Mtetra
.654 .735 .909 r
.56861 .50677 .57156 .51003 .5772 .5082 .57426 .50518 Mtetra
.684 .76 .909 r
.57426 .50518 .5772 .5082 .58285 .50661 .57992 .50312 Mtetra
.646 .719 .901 r
.57992 .50312 .58285 .50661 .58851 .50468 .58559 .50164 Mtetra
.664 .754 .917 r
.58559 .50164 .58851 .50468 .59419 .50304 .59127 .49987 Mtetra
.676 .749 .906 r
.59127 .49987 .59419 .50304 .59987 .50138 .59696 .49792 Mtetra
.645 .721 .904 r
.59696 .49792 .59987 .50138 .60557 .49939 .60268 .49645 Mtetra
.678 .766 .917 r
.60268 .49645 .60557 .49939 .61128 .49789 .60839 .49446 Mtetra
.651 .726 .904 r
.60839 .49446 .61128 .49789 .617 .49599 .61412 .49288 Mtetra
.671 .754 .913 r
.61412 .49288 .617 .49599 .62274 .49438 .61986 .49099 Mtetra
.648 .729 .908 r
.61986 .49099 .62274 .49438 .62847 .49235 .62562 .48946 Mtetra
.685 .773 .918 r
.62562 .48946 .62847 .49235 .63424 .49095 .63137 .48735 Mtetra
.664 .722 .892 r
.63137 .48735 .63424 .49095 .64001 .48915 .63715 .48557 Mtetra
.662 .723 .894 r
.63715 .48557 .64001 .48915 .64579 .4874 .64294 .48381 Mtetra
.667 .725 .892 r
.64294 .48381 .64579 .4874 .65158 .4856 .64873 .48197 Mtetra
.645 .714 .898 r
.64873 .48197 .65158 .4856 .65737 .48354 .65456 .48047 Mtetra
.67 .759 .917 r
.65456 .48047 .65737 .48354 .66319 .48183 .66038 .47856 Mtetra
.668 .746 .909 r
.66038 .47856 .66319 .48183 .66902 .48009 .66621 .47669 Mtetra
.662 .736 .904 r
.66621 .47669 .66902 .48009 .67486 .47822 .67206 .47491 Mtetra
.66 .741 .91 r
.67206 .47491 .67486 .47822 .68071 .47635 .67792 .47315 Mtetra
.679 .755 .908 r
.67792 .47315 .68071 .47635 .68658 .47469 .68378 .47108 Mtetra
.647 .719 .901 r
.68378 .47108 .68658 .47469 .69245 .4727 .68968 .46953 Mtetra
.669 .755 .915 r
.68968 .46953 .69245 .4727 .69834 .47098 .69557 .46762 Mtetra
.67 .743 .905 r
.69557 .46762 .69834 .47098 .70424 .4692 .70147 .46569 Mtetra
.65 .728 .906 r
.70147 .46569 .70424 .4692 .71014 .4672 .70741 .46408 Mtetra
.679 .763 .915 r
.70741 .46408 .71014 .4672 .71608 .4656 .71333 .46201 Mtetra
.653 .724 .901 r
.71333 .46201 .71608 .4656 .72201 .4636 .71928 .46035 Mtetra
.671 .753 .912 r
.71928 .46035 .72201 .4636 .72797 .46193 .72524 .45839 Mtetra
.654 .729 .904 r
.72524 .45839 .72797 .46193 .73393 .46001 .73122 .4567 Mtetra
.672 .75 .909 r
.73122 .4567 .73393 .46001 .7399 .45821 .73719 .45471 Mtetra
.655 .733 .907 r
.73719 .45471 .7399 .45821 .74588 .4562 .7432 .453 Mtetra
.676 .759 .913 r
.7432 .453 .74588 .4562 .7519 .45458 .74919 .45093 Mtetra
.653 .724 .901 r
.74919 .45093 .7519 .45458 .7579 .45266 .75522 .44925 Mtetra
.656 .74 .912 r
.75522 .44925 .7579 .45266 .76392 .45069 .76127 .44751 Mtetra
.676 .762 .916 r
.76127 .44751 .76392 .45069 .76997 .44896 .7673 .44544 Mtetra
.675 .741 .9 r
.7673 .44544 .76997 .44896 .77602 .44711 .77335 .44339 Mtetra
.661 .724 .896 r
.77335 .44339 .77602 .44711 .78208 .44518 .77942 .44157 Mtetra
.664 .732 .9 r
.77942 .44157 .78208 .44518 .78815 .44326 .78551 .43968 Mtetra
.667 .735 .901 r
.78551 .43968 .78815 .44326 .79424 .44135 .7916 .43774 Mtetra
.66 .732 .902 r
.7916 .43774 .79424 .44135 .80033 .43942 .79771 .43591 Mtetra
.662 .739 .907 r
.79771 .43591 .80033 .43942 .80644 .43747 .80384 .43405 Mtetra
.667 .747 .91 r
.80384 .43405 .80644 .43747 .81257 .4356 .80997 .4321 Mtetra
.663 .74 .907 r
.80997 .4321 .81257 .4356 .81871 .43369 .81612 .43021 Mtetra
.666 .743 .908 r
.81612 .43021 .81871 .43369 .82486 .43181 .82228 .42826 Mtetra
.662 .739 .907 r
.82228 .42826 .82486 .43181 .83103 .4299 .82846 .42638 Mtetra
.662 .74 .908 r
.82846 .42638 .83103 .4299 .83721 .42798 .83465 .4245 Mtetra
.664 .744 .91 r
.83465 .4245 .83721 .42798 .8434 .42609 .84085 .42257 Mtetra
.665 .743 .908 r
.84085 .42257 .8434 .42609 .84961 .42417 .84706 .42063 Mtetra
.664 .741 .908 r
.84706 .42063 .84961 .42417 .85583 .42224 .85329 .41871 Mtetra
.663 .742 .909 r
.85329 .41871 .85583 .42224 .86206 .42032 .85954 .41679 Mtetra
.664 .743 .909 r
.85954 .41679 .86206 .42032 .8683 .4184 .86579 .41485 Mtetra
.665 .743 .908 r
.86579 .41485 .8683 .4184 .87456 .41647 .87206 .4129 Mtetra
.662 .74 .908 r
.87206 .4129 .87456 .41647 .88084 .41454 .87834 .41099 Mtetra
.665 .743 .909 r
.87834 .41099 .88084 .41454 .88712 .41261 .88464 .40903 Mtetra
.663 .742 .908 r
.88464 .40903 .88712 .41261 .89342 .41066 .89095 .40709 Mtetra
.663 .742 .909 r
.89095 .40709 .89342 .41066 .89974 .40872 .89727 .40514 Mtetra
.664 .743 .909 r
.89727 .40514 .89974 .40872 .90606 .40677 .90361 .40317 Mtetra
.662 .741 .909 r
.90361 .40317 .90606 .40677 .9124 .40483 .90996 .40124 Mtetra
.665 .743 .908 r
.90996 .40124 .9124 .40483 .91876 .40287 .91632 .39925 Mtetra
.661 .74 .909 r
.91632 .39925 .91876 .40287 .92513 .40095 .92271 .39732 Mtetra
.665 .742 .908 r
.92271 .39732 .92513 .40095 .93151 .39896 .9291 .39533 Mtetra
.664 .742 .909 r
.9291 .39533 .93151 .39896 .93791 .39703 .9355 .39335 Mtetra
.664 .74 .906 r
.9355 .39335 .93791 .39703 .94431 .39499 .94192 .39136 Mtetra
.66 .74 .909 r
.36425 .56566 .36746 .56866 .3727 .56706 .3695 .56409 Mtetra
.662 .742 .91 r
.3695 .56409 .3727 .56706 .37796 .56547 .37476 .56248 Mtetra
.668 .743 .906 r
.37476 .56248 .37796 .56547 .38322 .56381 .38003 .56079 Mtetra
.661 .74 .908 r
.38003 .56079 .38322 .56381 .3885 .56217 .38531 .55919 Mtetra
.666 .744 .908 r
.38531 .55919 .3885 .56217 .39379 .56054 .39061 .55751 Mtetra
.661 .74 .909 r
.39061 .55751 .39379 .56054 .39908 .5589 .39591 .5559 Mtetra
.666 .743 .908 r
.39591 .5559 .39908 .5589 .40439 .55725 .40122 .55422 Mtetra
.661 .741 .909 r
.40122 .55422 .40439 .55725 .40971 .55563 .40654 .55261 Mtetra
.666 .743 .908 r
.40654 .55261 .40971 .55563 .41503 .55397 .41188 .55093 Mtetra
.661 .741 .909 r
.41188 .55093 .41503 .55397 .42037 .55234 .41722 .54931 Mtetra
.665 .743 .908 r
.41722 .54931 .42037 .55234 .42572 .55068 .42258 .54764 Mtetra
.664 .742 .908 r
.42258 .54764 .42572 .55068 .43108 .54901 .42795 .54597 Mtetra
.662 .742 .909 r
.42795 .54597 .43108 .54901 .43645 .54736 .43332 .54433 Mtetra
.664 .744 .909 r
.43332 .54433 .43645 .54736 .44183 .5457 .43871 .54265 Mtetra
.665 .743 .908 r
.43871 .54265 .44183 .5457 .44722 .54405 .44411 .54096 Mtetra
.663 .741 .908 r
.44411 .54096 .44722 .54405 .45262 .54241 .44952 .5393 Mtetra
.662 .739 .907 r
.44952 .5393 .45262 .54241 .45804 .54073 .45494 .53765 Mtetra
.663 .742 .908 r
.45494 .53765 .45804 .54073 .46346 .53903 .46037 .53597 Mtetra
.665 .744 .909 r
.46037 .53597 .46346 .53903 .4689 .53736 .46581 .53426 Mtetra
.664 .742 .908 r
.46581 .53426 .4689 .53736 .47434 .5357 .47126 .53256 Mtetra
.66 .738 .908 r
.47126 .53256 .47434 .5357 .4798 .53399 .47673 .53093 Mtetra
.666 .745 .909 r
.47673 .53093 .4798 .53399 .48526 .53238 .4822 .52919 Mtetra
.661 .737 .906 r
.4822 .52919 .48526 .53238 .49074 .53067 .48769 .52754 Mtetra
.658 .74 .91 r
.48769 .52754 .49074 .53067 .49623 .52891 .49318 .52592 Mtetra
.66 .75 .917 r
.49318 .52592 .49623 .52891 .50173 .52726 .49869 .52427 Mtetra
.49869 .52427 .50173 .52726 .50724 .52558 .50421 .52261 Mtetra
.659 .752 .919 r
.50421 .52261 .50724 .52558 .51277 .52383 .50974 .52095 Mtetra
.664 .76 .921 r
.50974 .52095 .51277 .52383 .5183 .52225 .51528 .51922 Mtetra
.679 .754 .908 r
.51528 .51922 .5183 .52225 .52385 .52075 .52083 .51726 Mtetra
.647 .716 .898 r
.52083 .51726 .52385 .52075 .5294 .519 .52639 .51579 Mtetra
.66 .738 .907 r
.52639 .51579 .5294 .519 .53497 .51698 .53197 .51411 Mtetra
.683 .767 .915 r
.53197 .51411 .53497 .51698 .54055 .51552 .53756 .51209 Mtetra
.648 .721 .902 r
.53756 .51209 .54055 .51552 .54614 .51374 .54315 .51059 Mtetra
.668 .746 .909 r
.54315 .51059 .54614 .51374 .55174 .512 .54876 .50879 Mtetra
.657 .739 .91 r
.54876 .50879 .55174 .512 .55735 .5103 .55438 .50714 Mtetra
.675 .748 .906 r
.55438 .50714 .55735 .5103 .56298 .50854 .56001 .50523 Mtetra
.65 .731 .908 r
.56001 .50523 .56298 .50854 .56861 .50677 .56566 .50369 Mtetra
.681 .755 .908 r
.56566 .50369 .56861 .50677 .57426 .50518 .57131 .50168 Mtetra
.65 .72 .899 r
.57131 .50168 .57426 .50518 .57992 .50312 .57698 .50013 Mtetra
.664 .757 .92 r
.57698 .50013 .57992 .50312 .58559 .50164 .58266 .49836 Mtetra
.677 .743 .901 r
.58266 .49836 .58559 .50164 .59127 .49987 .58834 .4964 Mtetra
.644 .721 .904 r
.58834 .4964 .59127 .49987 .59696 .49792 .59405 .49494 Mtetra
.673 .762 .917 r
.59405 .49494 .59696 .49792 .60268 .49645 .59976 .49301 Mtetra
.659 .729 .901 r
.59976 .49301 .60268 .49645 .60839 .49446 .60549 .49132 Mtetra
.659 .748 .916 r
.60549 .49132 .60839 .49446 .61412 .49288 .61123 .48961 Mtetra
.668 .743 .906 r
.61123 .48961 .61412 .49288 .61986 .49099 .61697 .48777 Mtetra
.664 .745 .91 r
.61697 .48777 .61986 .49099 .62562 .48946 .62273 .48597 Mtetra
.649 .724 .903 r
.62273 .48597 .62562 .48946 .63137 .48735 .62851 .48441 Mtetra
.671 .767 .922 r
.62851 .48441 .63137 .48735 .63715 .48557 .63429 .4825 Mtetra
.661 .756 .92 r
.63429 .4825 .63715 .48557 .64294 .48381 .64009 .48073 Mtetra
.655 .753 .922 r
.64009 .48073 .64294 .48381 .64873 .48197 .6459 .47905 Mtetra
.676 .772 .923 r
.6459 .47905 .64873 .48197 .65456 .48047 .65172 .47705 Mtetra
.671 .738 .9 r
.65172 .47705 .65456 .48047 .66038 .47856 .65754 .47512 Mtetra
.651 .73 .907 r
.65754 .47512 .66038 .47856 .66621 .47669 .6634 .47351 Mtetra
.676 .755 .91 r
.6634 .47351 .66621 .47669 .67206 .47491 .66924 .47149 Mtetra
.657 .735 .907 r
.66924 .47149 .67206 .47491 .67792 .47315 .67512 .46977 Mtetra
.66 .738 .908 r
.67512 .46977 .67792 .47315 .68378 .47108 .681 .46801 Mtetra
.681 .765 .915 r
.681 .46801 .68378 .47108 .68968 .46953 .68688 .46591 Mtetra
.646 .719 .901 r
.68688 .46591 .68968 .46953 .69557 .46762 .6928 .46436 Mtetra
.671 .751 .911 r
.6928 .46436 .69557 .46762 .70147 .46569 .69871 .46242 Mtetra
.667 .749 .912 r
.69871 .46242 .70147 .46569 .70741 .46408 .70464 .46052 Mtetra
.651 .726 .904 r
.70464 .46052 .70741 .46408 .71333 .46201 .71059 .45888 Mtetra
.684 .765 .913 r
.71059 .45888 .71333 .46201 .71928 .46035 .71653 .45671 Mtetra
.646 .72 .902 r
.71653 .45671 .71928 .46035 .72524 .45839 .72251 .45516 Mtetra
.678 .757 .911 r
.72251 .45516 .72524 .45839 .73122 .4567 .72848 .45308 Mtetra
.65 .723 .902 r
.72848 .45308 .73122 .4567 .73719 .45471 .73448 .45145 Mtetra
.681 .757 .909 r
.73448 .45145 .73719 .45471 .7432 .453 .74047 .4493 Mtetra
.648 .719 .9 r
.74047 .4493 .7432 .453 .74919 .45093 .7465 .4477 Mtetra
.66 .753 .919 r
.7465 .4477 .74919 .45093 .75522 .44925 .75254 .44588 Mtetra
.681 .752 .905 r
.75254 .44588 .75522 .44925 .76127 .44751 .75856 .44373 Mtetra
.652 .717 .896 r
.75856 .44373 .76127 .44751 .7673 .44544 .76463 .44205 Mtetra
.66 .744 .912 r
.76463 .44205 .7673 .44544 .77335 .44339 .7707 .44023 Mtetra
.666 .762 .922 r
.7707 .44023 .77335 .44339 .77942 .44157 .77678 .4383 Mtetra
.667 .755 .916 r
.77678 .4383 .77942 .44157 .78551 .43968 .78287 .43636 Mtetra
.666 .752 .914 r
.78287 .43636 .78551 .43968 .7916 .43774 .78897 .43442 Mtetra
.668 .753 .914 r
.78897 .43442 .7916 .43774 .79771 .43591 .79509 .43245 Mtetra
.668 .745 .908 r
.79509 .43245 .79771 .43591 .80384 .43405 .80121 .43047 Mtetra
.66 .735 .905 r
.80121 .43047 .80384 .43405 .80997 .4321 .80736 .42863 Mtetra
.667 .745 .908 r
.80736 .42863 .80997 .4321 .81612 .43021 .81352 .42666 Mtetra
.662 .738 .907 r
.81352 .42666 .81612 .43021 .82228 .42826 .81969 .42477 Mtetra
.663 .743 .91 r
.81969 .42477 .82228 .42826 .82846 .42638 .82588 .42287 Mtetra
.665 .743 .909 r
.82588 .42287 .82846 .42638 .83465 .4245 .83208 .42094 Mtetra
.665 .74 .906 r
.83208 .42094 .83465 .4245 .84085 .42257 .83829 .41899 Mtetra
.664 .739 .906 r
.83829 .41899 .84085 .42257 .84706 .42063 .84451 .41707 Mtetra
.663 .74 .908 r
.84451 .41707 .84706 .42063 .85329 .41871 .85075 .41515 Mtetra
.662 .741 .909 r
.85075 .41515 .85329 .41871 .85954 .41679 .857 .41324 Mtetra
.664 .742 .908 r
.857 .41324 .85954 .41679 .86579 .41485 .86327 .41129 Mtetra
.665 .742 .908 r
.86327 .41129 .86579 .41485 .87206 .4129 .86954 .40932 Mtetra
.662 .741 .909 r
.86954 .40932 .87206 .4129 .87834 .41099 .87584 .40741 Mtetra
.665 .742 .907 r
.87584 .40741 .87834 .41099 .88464 .40903 .88214 .40543 Mtetra
.662 .74 .908 r
.88214 .40543 .88464 .40903 .89095 .40709 .88847 .4035 Mtetra
.664 .743 .908 r
.88847 .4035 .89095 .40709 .89727 .40514 .8948 .40153 Mtetra
.663 .741 .908 r
.8948 .40153 .89727 .40514 .90361 .40317 .90115 .39958 Mtetra
.664 .743 .909 r
.90115 .39958 .90361 .40317 .90996 .40124 .9075 .3976 Mtetra
.662 .74 .908 r
.9075 .3976 .90996 .40124 .91632 .39925 .91388 .39565 Mtetra
.666 .745 .909 r
.91388 .39565 .91632 .39925 .92271 .39732 .92027 .39364 Mtetra
.66 .737 .907 r
.92027 .39364 .92271 .39732 .9291 .39533 .92667 .39171 Mtetra
.667 .745 .908 r
.92667 .39171 .9291 .39533 .9355 .39335 .93308 .38966 Mtetra
.663 .739 .907 r
.93308 .38966 .9355 .39335 .94192 .39136 .93951 .38768 Mtetra
.659 .741 .91 r
.36102 .56267 .36425 .56566 .3695 .56409 .36628 .5611 Mtetra
.667 .744 .907 r
.36628 .5611 .3695 .56409 .37476 .56248 .37155 .55941 Mtetra
.661 .737 .906 r
.37155 .55941 .37476 .56248 .38003 .56079 .37682 .55782 Mtetra
.665 .745 .91 r
.37682 .55782 .38003 .56079 .38531 .55919 .38211 .55615 Mtetra
.664 .741 .907 r
.38211 .55615 .38531 .55919 .39061 .55751 .38741 .5545 Mtetra
.662 .742 .91 r
.38741 .5545 .39061 .55751 .39591 .5559 .39272 .55287 Mtetra
.666 .742 .907 r
.39272 .55287 .39591 .5559 .40122 .55422 .39804 .55119 Mtetra
.662 .742 .909 r
.39804 .55119 .40122 .55422 .40654 .55261 .40337 .54957 Mtetra
.665 .742 .907 r
.40337 .54957 .40654 .55261 .41188 .55093 .40871 .54788 Mtetra
.663 .742 .909 r
.40871 .54788 .41188 .55093 .41722 .54931 .41407 .54624 Mtetra
.664 .741 .907 r
.41407 .54624 .41722 .54931 .42258 .54764 .41943 .54457 Mtetra
.664 .741 .908 r
.41943 .54457 .42258 .54764 .42795 .54597 .4248 .54289 Mtetra
.662 .741 .909 r
.4248 .54289 .42795 .54597 .43332 .54433 .43018 .54125 Mtetra
.664 .741 .908 r
.43018 .54125 .43332 .54433 .43871 .54265 .43558 .53957 Mtetra
.665 .742 .907 r
.43558 .53957 .43871 .54265 .44411 .54096 .44098 .53787 Mtetra
.663 .741 .908 r
.44098 .53787 .44411 .54096 .44952 .5393 .4464 .53619 Mtetra
.664 .741 .907 r
.4464 .53619 .44952 .5393 .45494 .53765 .45183 .5345 Mtetra
.662 .738 .907 r
.45183 .5345 .45494 .53765 .46037 .53597 .45726 .53285 Mtetra
.663 .74 .908 r
.45726 .53285 .46037 .53597 .46581 .53426 .46271 .53116 Mtetra
.665 .743 .909 r
.46271 .53116 .46581 .53426 .47126 .53256 .46817 .52945 Mtetra
.663 .742 .909 r
.46817 .52945 .47126 .53256 .47673 .53093 .47364 .52776 Mtetra
.662 .739 .907 r
.47364 .52776 .47673 .53093 .4822 .52919 .47912 .52609 Mtetra
.659 .742 .911 r
.47912 .52609 .4822 .52919 .48769 .52754 .48462 .52445 Mtetra
.664 .745 .91 r
.48462 .52445 .48769 .52754 .49318 .52592 .49012 .52273 Mtetra
.665 .739 .905 r
.49012 .52273 .49318 .52592 .49869 .52427 .49563 .521 Mtetra
.662 .734 .903 r
.49563 .521 .49869 .52427 .50421 .52261 .50116 .51931 Mtetra
.659 .731 .903 r
.50116 .51931 .50421 .52261 .50974 .52095 .5067 .51767 Mtetra
.653 .73 .906 r
.5067 .51767 .50974 .52095 .51528 .51922 .51224 .51611 Mtetra
.66 .744 .912 r
.51224 .51611 .51528 .51922 .52083 .51726 .5178 .51443 Mtetra
.683 .769 .917 r
.5178 .51443 .52083 .51726 .52639 .51579 .52338 .5124 Mtetra
.652 .725 .902 r
.52338 .5124 .52639 .51579 .53197 .51411 .52896 .51085 Mtetra
.662 .736 .905 r
.52896 .51085 .53197 .51411 .53756 .51209 .53455 .50914 Mtetra
.678 .762 .914 r
.53455 .50914 .53756 .51209 .54315 .51059 .54016 .50718 Mtetra
.643 .722 .906 r
.54016 .50718 .54315 .51059 .54876 .50879 .54577 .50575 Mtetra
.683 .758 .908 r
.54577 .50575 .54876 .50879 .55438 .50714 .5514 .50371 Mtetra
.649 .723 .903 r
.5514 .50371 .55438 .50714 .56001 .50523 .55704 .50219 Mtetra
.675 .756 .912 r
.55704 .50219 .56001 .50523 .56566 .50369 .56269 .50026 Mtetra
.657 .727 .901 r
.56269 .50026 .56566 .50369 .57131 .50168 .56836 .49861 Mtetra
.663 .753 .917 r
.56836 .49861 .57131 .50168 .57698 .50013 .57403 .49686 Mtetra
.673 .742 .903 r
.57403 .49686 .57698 .50013 .58266 .49836 .57971 .49495 Mtetra
.651 .727 .905 r
.57971 .49495 .58266 .49836 .58834 .4964 .58541 .49338 Mtetra
.666 .758 .919 r
.58541 .49338 .58834 .4964 .59405 .49494 .59112 .49156 Mtetra
.67 .736 .9 r
.59112 .49156 .59405 .49494 .59976 .49301 .59684 .48968 Mtetra
.646 .731 .911 r
.59684 .48968 .59976 .49301 .60549 .49132 .60258 .48816 Mtetra
.685 .756 .905 r
.60258 .48816 .60549 .49132 .61123 .48961 .60832 .48604 Mtetra
.639 .715 .903 r
.60832 .48604 .61123 .48961 .61697 .48777 .61408 .48464 Mtetra
.68 .757 .91 r
.61408 .48464 .61697 .48777 .62273 .48597 .61984 .4826 Mtetra
.663 .737 .905 r
.61984 .4826 .62273 .48597 .62851 .48441 .62562 .48083 Mtetra
.654 .721 .898 r
.62562 .48083 .62851 .48441 .63429 .4825 .63142 .47917 Mtetra
.66 .739 .909 r
.63142 .47917 .63429 .4825 .64009 .48073 .63723 .47743 Mtetra
.674 .746 .905 r
.63723 .47743 .64009 .48073 .6459 .47905 .64304 .47545 Mtetra
.669 .727 .893 r
.64304 .47545 .6459 .47905 .65172 .47705 .64886 .47355 Mtetra
.644 .725 .907 r
.64886 .47355 .65172 .47705 .65754 .47512 .65471 .47203 Mtetra
.684 .765 .912 r
.65471 .47203 .65754 .47512 .6634 .47351 .66055 .46989 Mtetra
.645 .719 .902 r
.66055 .46989 .6634 .47351 .66924 .47149 .66643 .46837 Mtetra
.687 .764 .91 r
.66643 .46837 .66924 .47149 .67512 .46977 .67229 .46618 Mtetra
.645 .721 .903 r
.67229 .46618 .67512 .46977 .681 .46801 .67819 .46465 Mtetra
.669 .744 .907 r
.67819 .46465 .681 .46801 .68688 .46591 .68409 .46274 Mtetra
.671 .757 .915 r
.68409 .46274 .68688 .46591 .6928 .46436 .69 .46078 Mtetra
.652 .725 .902 r
.69 .46078 .6928 .46436 .69871 .46242 .69593 .45913 Mtetra
.675 .751 .909 r
.69593 .45913 .69871 .46242 .70464 .46052 .70186 .45711 Mtetra
.659 .738 .909 r
.70186 .45711 .70464 .46052 .71059 .45888 .70782 .45534 Mtetra
.658 .731 .903 r
.70782 .45534 .71059 .45888 .71653 .45671 .71379 .45357 Mtetra
.674 .762 .917 r
.71379 .45357 .71653 .45671 .72251 .45516 .71975 .45154 Mtetra
.649 .724 .904 r
.71975 .45154 .72251 .45516 .72848 .45308 .72576 .44992 Mtetra
.679 .764 .916 r
.72576 .44992 .72848 .45308 .73448 .45145 .73174 .44781 Mtetra
.655 .726 .901 r
.73174 .44781 .73448 .45145 .74047 .4493 .73776 .44609 Mtetra
.661 .755 .92 r
.73776 .44609 .74047 .4493 .7465 .4477 .74379 .44426 Mtetra
.676 .746 .904 r
.74379 .44426 .7465 .4477 .75254 .44588 .74982 .44218 Mtetra
.647 .72 .901 r
.74982 .44218 .75254 .44588 .75856 .44373 .75589 .44057 Mtetra
.662 .761 .923 r
.75589 .44057 .75856 .44373 .76463 .44205 .76195 .4387 Mtetra
.673 .752 .91 r
.76195 .4387 .76463 .44205 .7707 .44023 .76802 .43665 Mtetra
.669 .737 .901 r
.76802 .43665 .7707 .44023 .77678 .4383 .7741 .43467 Mtetra
.665 .733 .9 r
.7741 .43467 .77678 .4383 .78287 .43636 .7802 .43274 Mtetra
.663 .734 .902 r
.7802 .43274 .78287 .43636 .78897 .43442 .78632 .43086 Mtetra
.662 .737 .905 r
.78632 .43086 .78897 .43442 .79509 .43245 .79245 .42898 Mtetra
.666 .744 .909 r
.79245 .42898 .79509 .43245 .80121 .43047 .79859 .42703 Mtetra
.667 .747 .91 r
.79859 .42703 .80121 .43047 .80736 .42863 .80474 .42506 Mtetra
.663 .738 .906 r
.80474 .42506 .80736 .42863 .81352 .42666 .81091 .42316 Mtetra
.664 .744 .91 r
.81091 .42316 .81352 .42666 .81969 .42477 .81709 .42124 Mtetra
.665 .742 .908 r
.81709 .42124 .81969 .42477 .82588 .42287 .82328 .4193 Mtetra
.664 .74 .907 r
.82328 .4193 .82588 .42287 .83208 .42094 .82949 .41737 Mtetra
.663 .74 .908 r
.82949 .41737 .83208 .42094 .83829 .41899 .83572 .41546 Mtetra
.665 .743 .909 r
.83572 .41546 .83829 .41899 .84451 .41707 .84195 .4135 Mtetra
.664 .742 .908 r
.84195 .4135 .84451 .41707 .85075 .41515 .8482 .41157 Mtetra
.663 .74 .908 r
.8482 .41157 .85075 .41515 .857 .41324 .85446 .40963 Mtetra
.664 .74 .907 r
.85446 .40963 .857 .41324 .86327 .41129 .86073 .40768 Mtetra
.664 .741 .907 r
.86073 .40768 .86327 .41129 .86954 .40932 .86702 .40572 Mtetra
.663 .741 .908 r
.86702 .40572 .86954 .40932 .87584 .40741 .87332 .40378 Mtetra
.664 .74 .907 r
.87332 .40378 .87584 .40741 .88214 .40543 .87964 .40181 Mtetra
.662 .74 .908 r
.87964 .40181 .88214 .40543 .88847 .4035 .88597 .39987 Mtetra
.665 .742 .907 r
.88597 .39987 .88847 .4035 .8948 .40153 .89231 .39787 Mtetra
.661 .739 .908 r
.89231 .39787 .8948 .40153 .90115 .39958 .89867 .39595 Mtetra
.666 .743 .908 r
.89867 .39595 .90115 .39958 .9075 .3976 .90504 .39393 Mtetra
.661 .739 .908 r
.90504 .39393 .9075 .3976 .91388 .39565 .91143 .392 Mtetra
.665 .742 .908 r
.91143 .392 .91388 .39565 .92027 .39364 .91782 .38999 Mtetra
.664 .742 .909 r
.91782 .38999 .92027 .39364 .92667 .39171 .92423 .388 Mtetra
.663 .739 .906 r
.92423 .388 .92667 .39171 .93308 .38966 .93066 .38601 Mtetra
.665 .744 .909 r
.93066 .38601 .93308 .38966 .93951 .38768 .9371 .38399 Mtetra
.663 .741 .908 r
.35779 .55965 .36102 .56267 .36628 .5611 .36305 .55802 Mtetra
.66 .736 .907 r
.36305 .55802 .36628 .5611 .37155 .55941 .36832 .55644 Mtetra
.664 .745 .91 r
.36832 .55644 .37155 .55941 .37682 .55782 .37361 .55479 Mtetra
.667 .742 .907 r
.37361 .55479 .37682 .55782 .38211 .55615 .3789 .5531 Mtetra
.661 .739 .908 r
.3789 .5531 .38211 .55615 .38741 .5545 .38421 .55149 Mtetra
.666 .744 .908 r
.38421 .55149 .38741 .5545 .39272 .55287 .38953 .54979 Mtetra
.662 .739 .907 r
.38953 .54979 .39272 .55287 .39804 .55119 .39485 .54816 Mtetra
.665 .743 .909 r
.39485 .54816 .39804 .55119 .40337 .54957 .40019 .54648 Mtetra
.664 .74 .907 r
.40019 .54648 .40337 .54957 .40871 .54788 .40554 .54482 Mtetra
.664 .742 .908 r
.40554 .54482 .40871 .54788 .41407 .54624 .4109 .54315 Mtetra
.664 .74 .907 r
.4109 .54315 .41407 .54624 .41943 .54457 .41626 .54147 Mtetra
.663 .74 .907 r
.41626 .54147 .41943 .54457 .4248 .54289 .42164 .5398 Mtetra
.663 .741 .908 r
.42164 .5398 .4248 .54289 .43018 .54125 .42703 .53813 Mtetra
.664 .74 .907 r
.42703 .53813 .43018 .54125 .43558 .53957 .43244 .53645 Mtetra
.664 .741 .907 r
.43244 .53645 .43558 .53957 .44098 .53787 .43785 .53476 Mtetra
.663 .741 .908 r
.43785 .53476 .44098 .53787 .4464 .53619 .44327 .53309 Mtetra
.663 .742 .908 r
.44327 .53309 .4464 .53619 .45183 .5345 .4487 .53141 Mtetra
.665 .743 .908 r
.4487 .53141 .45183 .5345 .45726 .53285 .45415 .5297 Mtetra
.661 .739 .908 r
.45415 .5297 .45726 .53285 .46271 .53116 .4596 .52803 Mtetra
.663 .741 .908 r
.4596 .52803 .46271 .53116 .46817 .52945 .46507 .52634 Mtetra
.665 .743 .908 r
.46507 .52634 .46817 .52945 .47364 .52776 .47055 .52461 Mtetra
.659 .739 .909 r
.47055 .52461 .47364 .52776 .47912 .52609 .47604 .52297 Mtetra
.665 .743 .908 r
.47604 .52297 .47912 .52609 .48462 .52445 .48154 .52124 Mtetra
.665 .738 .905 r
.48154 .52124 .48462 .52445 .49012 .52273 .48705 .51951 Mtetra
.661 .737 .906 r
.48705 .51951 .49012 .52273 .49563 .521 .49257 .51782 Mtetra
.661 .74 .908 r
.49257 .51782 .49563 .521 .50116 .51931 .4981 .51614 Mtetra
.665 .742 .907 r
.4981 .51614 .50116 .51931 .5067 .51767 .50365 .5144 Mtetra
.66 .735 .905 r
.50365 .5144 .5067 .51767 .51224 .51611 .5092 .51272 Mtetra
.647 .724 .904 r
.5092 .51272 .51224 .51611 .5178 .51443 .51477 .51123 Mtetra
.665 .742 .907 r
.51477 .51123 .5178 .51443 .52338 .5124 .52035 .50948 Mtetra
.68 .764 .914 r
.52035 .50948 .52338 .5124 .52896 .51085 .52594 .50749 Mtetra
.653 .729 .905 r
.52594 .50749 .52896 .51085 .53455 .50914 .53154 .50592 Mtetra
.664 .741 .907 r
.53154 .50592 .53455 .50914 .54016 .50718 .53715 .50416 Mtetra
.664 .755 .918 r
.53715 .50416 .54016 .50718 .54577 .50575 .54277 .5024 Mtetra
.665 .734 .901 r
.54277 .5024 .54577 .50575 .5514 .50371 .54841 .50062 Mtetra
.663 .75 .915 r
.54841 .50062 .5514 .50371 .55704 .50219 .55406 .49887 Mtetra
.668 .738 .903 r
.55406 .49887 .55704 .50219 .56269 .50026 .55971 .49705 Mtetra
.652 .74 .914 r
.55971 .49705 .56269 .50026 .56836 .49861 .56539 .49545 Mtetra
.677 .751 .907 r
.56539 .49545 .56836 .49861 .57403 .49686 .57107 .49347 Mtetra
.654 .73 .905 r
.57107 .49347 .57403 .49686 .57971 .49495 .57676 .49185 Mtetra
.661 .751 .917 r
.57676 .49185 .57971 .49495 .58541 .49338 .58247 .49011 Mtetra
.675 .745 .903 r
.58247 .49011 .58541 .49338 .59112 .49156 .58818 .48815 Mtetra
.647 .728 .907 r
.58818 .48815 .59112 .49156 .59684 .48968 .59391 .48661 Mtetra
.671 .758 .916 r
.59391 .48661 .59684 .48968 .60258 .48816 .59965 .48471 Mtetra
.658 .729 .902 r
.59965 .48471 .60258 .48816 .60832 .48604 .60541 .48301 Mtetra
.668 .76 .919 r
.60541 .48301 .60832 .48604 .61408 .48464 .61117 .48114 Mtetra
.651 .725 .903 r
.61117 .48114 .61408 .48464 .61984 .4826 .61695 .47955 Mtetra
.683 .764 .913 r
.61695 .47955 .61984 .4826 .62562 .48083 .62273 .47745 Mtetra
.665 .738 .905 r
.62273 .47745 .62562 .48083 .63142 .47917 .62853 .47562 Mtetra
.664 .728 .897 r
.62853 .47562 .63142 .47917 .63723 .47743 .63434 .47381 Mtetra
.663 .724 .895 r
.63434 .47381 .63723 .47743 .64304 .47545 .64017 .47201 Mtetra
.645 .728 .91 r
.64017 .47201 .64304 .47545 .64886 .47355 .64601 .47049 Mtetra
.671 .762 .919 r
.64601 .47049 .64886 .47355 .65471 .47203 .65186 .46855 Mtetra
.667 .734 .9 r
.65186 .46855 .65471 .47203 .66055 .46989 .65772 .46667 Mtetra
.658 .748 .917 r
.65772 .46667 .66055 .46989 .66643 .46837 .66359 .46492 Mtetra
.664 .736 .904 r
.66359 .46492 .66643 .46837 .67229 .46618 .66948 .46309 Mtetra
.674 .763 .917 r
.66948 .46309 .67229 .46618 .67819 .46465 .67537 .46108 Mtetra
.65 .725 .904 r
.67537 .46108 .67819 .46465 .68409 .46274 .68129 .45946 Mtetra
.678 .753 .908 r
.68129 .45946 .68409 .46274 .69 .46078 .6872 .45739 Mtetra
.66 .741 .909 r
.6872 .45739 .69 .46078 .69593 .45913 .69314 .4556 Mtetra
.656 .73 .904 r
.69314 .4556 .69593 .45913 .70186 .45711 .69909 .45387 Mtetra
.677 .757 .911 r
.69909 .45387 .70186 .45711 .70782 .45534 .70504 .45181 Mtetra
.65 .73 .907 r
.70504 .45181 .70782 .45534 .71379 .45357 .71102 .45016 Mtetra
.675 .746 .904 r
.71102 .45016 .71379 .45357 .71975 .45154 .717 .44811 Mtetra
.65 .736 .913 r
.717 .44811 .71975 .45154 .72576 .44992 .72301 .44646 Mtetra
.673 .743 .903 r
.72301 .44646 .72576 .44992 .73174 .44781 .72901 .44445 Mtetra
.656 .744 .914 r
.72901 .44445 .73174 .44781 .73776 .44609 .73504 .44268 Mtetra
.676 .748 .906 r
.73504 .44268 .73776 .44609 .74379 .44426 .74106 .44061 Mtetra
.652 .725 .903 r
.74106 .44061 .74379 .44426 .74982 .44218 .74712 .43892 Mtetra
.656 .752 .921 r
.74712 .43892 .74982 .44218 .75589 .44057 .75319 .43715 Mtetra
.679 .75 .905 r
.75319 .43715 .75589 .44057 .76195 .4387 .75925 .43502 Mtetra
.668 .731 .897 r
.75925 .43502 .76195 .4387 .76802 .43665 .76533 .43305 Mtetra
.663 .735 .903 r
.76533 .43305 .76802 .43665 .7741 .43467 .77143 .43116 Mtetra
.665 .741 .907 r
.77143 .43116 .7741 .43467 .7802 .43274 .77754 .42924 Mtetra
.666 .742 .907 r
.77754 .42924 .7802 .43274 .78632 .43086 .78366 .42729 Mtetra
.664 .738 .905 r
.78366 .42729 .78632 .43086 .79245 .42898 .7898 .42538 Mtetra
.661 .736 .905 r
.7898 .42538 .79245 .42898 .79859 .42703 .79595 .42351 Mtetra
.668 .744 .907 r
.79595 .42351 .79859 .42703 .80474 .42506 .80211 .42153 Mtetra
.662 .741 .908 r
.80211 .42153 .80474 .42506 .81091 .42316 .80829 .41963 Mtetra
.665 .743 .908 r
.80829 .41963 .81091 .42316 .81709 .42124 .81448 .41768 Mtetra
.664 .74 .907 r
.81448 .41768 .81709 .42124 .82328 .4193 .82068 .41575 Mtetra
.662 .741 .909 r
.82068 .41575 .82328 .4193 .82949 .41737 .8269 .41384 Mtetra
.665 .744 .909 r
.8269 .41384 .82949 .41737 .83572 .41546 .83313 .41189 Mtetra
.665 .742 .908 r
.83313 .41189 .83572 .41546 .84195 .4135 .83937 .40992 Mtetra
.664 .742 .908 r
.83937 .40992 .84195 .4135 .8482 .41157 .84563 .40798 Mtetra
.664 .741 .908 r
.84563 .40798 .8482 .41157 .85446 .40963 .8519 .40602 Mtetra
.663 .74 .907 r
.8519 .40602 .85446 .40963 .86073 .40768 .85819 .40408 Mtetra
.663 .741 .908 r
.85819 .40408 .86073 .40768 .86702 .40572 .86449 .40212 Mtetra
.664 .743 .908 r
.86449 .40212 .86702 .40572 .87332 .40378 .8708 .40015 Mtetra
.663 .741 .907 r
.8708 .40015 .87332 .40378 .87964 .40181 .87712 .39819 Mtetra
.663 .741 .908 r
.87712 .39819 .87964 .40181 .88597 .39987 .88346 .39622 Mtetra
.664 .74 .907 r
.88346 .39622 .88597 .39987 .89231 .39787 .88982 .39424 Mtetra
.662 .741 .909 r
.88982 .39424 .89231 .39787 .89867 .39595 .89618 .39228 Mtetra
.663 .74 .907 r
.89618 .39228 .89867 .39595 .90504 .39393 .90257 .3903 Mtetra
.665 .744 .909 r
.90257 .3903 .90504 .39393 .91143 .392 .90896 .38829 Mtetra
.661 .738 .907 r
.90896 .38829 .91143 .392 .91782 .38999 .91537 .38634 Mtetra
.665 .744 .908 r
.91537 .38634 .91782 .38999 .92423 .388 .92179 .38432 Mtetra
.665 .741 .907 r
.92179 .38432 .92423 .388 .93066 .38601 .92822 .3823 Mtetra
.662 .739 .907 r
.92822 .3823 .93066 .38601 .9371 .38399 .93468 .38031 Mtetra
.659 .74 .91 r
.35454 .55663 .35779 .55965 .36305 .55802 .35981 .55504 Mtetra
.664 .745 .91 r
.35981 .55504 .36305 .55802 .36832 .55644 .36509 .55339 Mtetra
.666 .741 .906 r
.36509 .55339 .36832 .55644 .37361 .55479 .37038 .55171 Mtetra
.661 .738 .907 r
.37038 .55171 .37361 .55479 .3789 .5531 .37568 .55009 Mtetra
.665 .745 .909 r
.37568 .55009 .3789 .5531 .38421 .55149 .38099 .54841 Mtetra
.664 .74 .906 r
.38099 .54841 .38421 .55149 .38953 .54979 .38632 .54674 Mtetra
.663 .741 .909 r
.38632 .54674 .38953 .54979 .39485 .54816 .39165 .54509 Mtetra
.665 .741 .907 r
.39165 .54509 .39485 .54816 .40019 .54648 .39699 .5434 Mtetra
.663 .74 .907 r
.39699 .5434 .40019 .54648 .40554 .54482 .40235 .54174 Mtetra
.663 .741 .908 r
.40235 .54174 .40554 .54482 .4109 .54315 .40771 .54007 Mtetra
.664 .742 .908 r
.40771 .54007 .4109 .54315 .41626 .54147 .41309 .53838 Mtetra
.662 .741 .909 r
.41309 .53838 .41626 .54147 .42164 .5398 .41847 .53673 Mtetra
.664 .743 .908 r
.41847 .53673 .42164 .5398 .42703 .53813 .42387 .53503 Mtetra
.664 .741 .908 r
.42387 .53503 .42703 .53813 .43244 .53645 .42928 .53334 Mtetra
.663 .741 .908 r
.42928 .53334 .43244 .53645 .43785 .53476 .4347 .53165 Mtetra
.663 .742 .908 r
.4347 .53165 .43785 .53476 .44327 .53309 .44013 .52996 Mtetra
.662 .741 .908 r
.44013 .52996 .44327 .53309 .4487 .53141 .44557 .52828 Mtetra
.664 .742 .908 r
.44557 .52828 .4487 .53141 .45415 .5297 .45102 .52658 Mtetra
.664 .743 .909 r
.45102 .52658 .45415 .5297 .4596 .52803 .45648 .52487 Mtetra
.66 .739 .908 r
.45648 .52487 .4596 .52803 .46507 .52634 .46196 .52322 Mtetra
.666 .744 .908 r
.46196 .52322 .46507 .52634 .47055 .52461 .46744 .52146 Mtetra
.66 .74 .91 r
.46744 .52146 .47055 .52461 .47604 .52297 .47294 .51981 Mtetra
.667 .742 .906 r
.47294 .51981 .47604 .52297 .48154 .52124 .47844 .51804 Mtetra
.66 .739 .908 r
.47844 .51804 .48154 .52124 .48705 .51951 .48396 .51637 Mtetra
.657 .741 .912 r
.48396 .51637 .48705 .51951 .49257 .51782 .48949 .51474 Mtetra
.659 .746 .914 r
.48949 .51474 .49257 .51782 .4981 .51614 .49503 .51307 Mtetra
.664 .749 .914 r
.49503 .51307 .4981 .51614 .50365 .5144 .50058 .51133 Mtetra
.669 .751 .912 r
.50058 .51133 .50365 .5144 .5092 .51272 .50614 .50952 Mtetra
.655 .739 .911 r
.50614 .50952 .5092 .51272 .51477 .51123 .51172 .5079 Mtetra
.652 .73 .906 r
.51172 .5079 .51477 .51123 .52035 .50948 .5173 .50634 Mtetra
.682 .751 .904 r
.5173 .50634 .52035 .50948 .52594 .50749 .5229 .50431 Mtetra
.663 .743 .91 r
.5229 .50431 .52594 .50749 .53154 .50592 .52851 .50257 Mtetra
.65 .73 .908 r
.52851 .50257 .53154 .50592 .53715 .50416 .53413 .50103 Mtetra
.679 .752 .906 r
.53413 .50103 .53715 .50416 .54277 .5024 .53976 .49904 Mtetra
.651 .729 .907 r
.53976 .49904 .54277 .5024 .54841 .50062 .54541 .49747 Mtetra
.678 .752 .907 r
.54541 .49747 .54841 .50062 .55406 .49887 .55106 .49549 Mtetra
.649 .729 .907 r
.55106 .49549 .55406 .49887 .55971 .49705 .55673 .49394 Mtetra
.666 .752 .914 r
.55673 .49394 .55971 .49705 .56539 .49545 .5624 .49213 Mtetra
.672 .74 .902 r
.5624 .49213 .56539 .49545 .57107 .49347 .56809 .49023 Mtetra
.649 .738 .915 r
.56809 .49023 .57107 .49347 .57676 .49185 .5738 .48866 Mtetra
.674 .75 .908 r
.5738 .48866 .57676 .49185 .58247 .49011 .57951 .48672 Mtetra
.665 .735 .902 r
.57951 .48672 .58247 .49011 .58818 .48815 .58523 .48491 Mtetra
.647 .739 .916 r
.58523 .48491 .58818 .48815 .59391 .48661 .59097 .48336 Mtetra
.683 .75 .902 r
.59097 .48336 .59391 .48661 .59965 .48471 .59672 .48125 Mtetra
.641 .724 .909 r
.59672 .48125 .59965 .48471 .60541 .48301 .60248 .4798 Mtetra
.685 .755 .904 r
.60248 .4798 .60541 .48301 .61117 .48114 .60825 .47766 Mtetra
.641 .723 .908 r
.60825 .47766 .61117 .48114 .61695 .47955 .61404 .47619 Mtetra
.668 .741 .905 r
.61404 .47619 .61695 .47955 .62273 .47745 .61984 .47432 Mtetra
.677 .759 .912 r
.61984 .47432 .62273 .47745 .62853 .47562 .62564 .4723 Mtetra
.662 .741 .909 r
.62564 .4723 .62853 .47562 .63434 .47381 .63146 .4705 Mtetra
.652 .74 .914 r
.63146 .4705 .63434 .47381 .64017 .47201 .6373 .46885 Mtetra
.658 .752 .919 r
.6373 .46885 .64017 .47201 .64601 .47049 .64314 .4671 Mtetra
.682 .746 .899 r
.64314 .4671 .64601 .47049 .65186 .46855 .64899 .46497 Mtetra
.645 .722 .904 r
.64899 .46497 .65186 .46855 .65772 .46667 .65487 .46343 Mtetra
.679 .755 .908 r
.65487 .46343 .65772 .46667 .66359 .46492 .66074 .46135 Mtetra
.644 .722 .905 r
.66074 .46135 .66359 .46492 .66948 .46309 .66665 .45981 Mtetra
.685 .755 .905 r
.66665 .45981 .66948 .46309 .67537 .46108 .67254 .45763 Mtetra
.648 .732 .911 r
.67254 .45763 .67537 .46108 .68129 .45946 .67847 .45602 Mtetra
.666 .74 .905 r
.67847 .45602 .68129 .45946 .6872 .45739 .6844 .45413 Mtetra
.674 .754 .911 r
.6844 .45413 .6872 .45739 .69314 .4556 .69033 .45211 Mtetra
.65 .732 .909 r
.69033 .45211 .69314 .4556 .69909 .45387 .6963 .45046 Mtetra
.672 .745 .905 r
.6963 .45046 .69909 .45387 .70504 .45181 .70226 .44846 Mtetra
.662 .746 .913 r
.70226 .44846 .70504 .45181 .71102 .45016 .70824 .44662 Mtetra
.66 .734 .904 r
.70824 .44662 .71102 .45016 .717 .44811 .71424 .44481 Mtetra
.667 .751 .913 r
.71424 .44481 .717 .44811 .72301 .44646 .72024 .44288 Mtetra
.655 .73 .904 r
.72024 .44288 .72301 .44646 .72901 .44445 .72627 .44113 Mtetra
.671 .753 .912 r
.72627 .44113 .72901 .44445 .73504 .44268 .73229 .43913 Mtetra
.67 .738 .901 r
.73229 .43913 .73504 .44268 .74106 .44061 .73833 .43714 Mtetra
.644 .734 .914 r
.73833 .43714 .74106 .44061 .74712 .43892 .7444 .43555 Mtetra
.669 .75 .911 r
.7444 .43555 .74712 .43892 .75319 .43715 .75047 .43357 Mtetra
.675 .74 .899 r
.75047 .43357 .75319 .43715 .75925 .43502 .75654 .43148 Mtetra
.659 .737 .907 r
.75654 .43148 .75925 .43502 .76533 .43305 .76264 .42965 Mtetra
.662 .747 .914 r
.76264 .42965 .76533 .43305 .77143 .43116 .76875 .42777 Mtetra
.667 .75 .913 r
.76875 .42777 .77143 .43116 .77754 .42924 .77487 .42581 Mtetra
.669 .749 .911 r
.77487 .42581 .77754 .42924 .78366 .42729 .78099 .42381 Mtetra
.667 .746 .909 r
.78099 .42381 .78366 .42729 .7898 .42538 .78714 .42184 Mtetra
.661 .74 .908 r
.78714 .42184 .7898 .42538 .79595 .42351 .7933 .41996 Mtetra
.666 .742 .907 r
.7933 .41996 .79595 .42351 .80211 .42153 .79947 .41799 Mtetra
.662 .742 .909 r
.79947 .41799 .80211 .42153 .80829 .41963 .80566 .41609 Mtetra
.667 .743 .907 r
.80566 .41609 .80829 .41963 .81448 .41768 .81186 .4141 Mtetra
.661 .74 .908 r
.81186 .4141 .81448 .41768 .82068 .41575 .81807 .41221 Mtetra
.664 .744 .909 r
.81807 .41221 .82068 .41575 .8269 .41384 .8243 .41026 Mtetra
.665 .742 .907 r
.8243 .41026 .8269 .41384 .83313 .41189 .83054 .40829 Mtetra
.663 .741 .908 r
.83054 .40829 .83313 .41189 .83937 .40992 .83679 .40635 Mtetra
.664 .743 .909 r
.83679 .40635 .83937 .40992 .84563 .40798 .84306 .40439 Mtetra
.665 .743 .908 r
.84306 .40439 .84563 .40798 .8519 .40602 .84934 .40241 Mtetra
.661 .74 .909 r
.84934 .40241 .8519 .40602 .85819 .40408 .85564 .40049 Mtetra
.664 .743 .909 r
.85564 .40049 .85819 .40408 .86449 .40212 .86194 .39851 Mtetra
.664 .742 .908 r
.86194 .39851 .86449 .40212 .8708 .40015 .86826 .39653 Mtetra
.663 .742 .909 r
.86826 .39653 .8708 .40015 .87712 .39819 .8746 .39455 Mtetra
.664 .742 .908 r
.8746 .39455 .87712 .39819 .88346 .39622 .88095 .39257 Mtetra
.664 .741 .908 r
.88095 .39257 .88346 .39622 .88982 .39424 .88731 .39058 Mtetra
.88731 .39058 .88982 .39424 .89618 .39228 .89369 .38859 Mtetra
.662 .739 .907 r
.89369 .38859 .89618 .39228 .90257 .3903 .90008 .38662 Mtetra
.664 .741 .908 r
.90008 .38662 .90257 .3903 .90896 .38829 .90648 .38462 Mtetra
.664 .742 .908 r
.90648 .38462 .90896 .38829 .91537 .38634 .9129 .38261 Mtetra
.662 .738 .906 r
.9129 .38261 .91537 .38634 .92179 .38432 .91934 .38064 Mtetra
.665 .743 .908 r
.91934 .38064 .92179 .38432 .92822 .3823 .92578 .3786 Mtetra
.665 .742 .908 r
.92578 .3786 .92822 .3823 .93468 .38031 .93224 .37657 Mtetra
.663 .742 .908 r
.35128 .5536 .35454 .55663 .35981 .55504 .35656 .55196 Mtetra
.662 .738 .906 r
.35656 .55196 .35981 .55504 .36509 .55339 .36184 .55033 Mtetra
.661 .74 .908 r
.36184 .55033 .36509 .55339 .37038 .55171 .36714 .5487 Mtetra
.666 .745 .909 r
.36714 .5487 .37038 .55171 .37568 .55009 .37245 .54701 Mtetra
.664 .74 .906 r
.37245 .54701 .37568 .55009 .38099 .54841 .37777 .54533 Mtetra
.662 .74 .908 r
.37777 .54533 .38099 .54841 .38632 .54674 .3831 .54369 Mtetra
.665 .743 .908 r
.3831 .54369 .38632 .54674 .39165 .54509 .38844 .54199 Mtetra
.664 .74 .907 r
.38844 .54199 .39165 .54509 .39699 .5434 .39379 .54032 Mtetra
.663 .741 .908 r
.39379 .54032 .39699 .5434 .40235 .54174 .39915 .53865 Mtetra
.662 .741 .909 r
.39915 .53865 .40235 .54174 .40771 .54007 .40452 .53699 Mtetra
.664 .743 .908 r
.40452 .53699 .40771 .54007 .41309 .53838 .4099 .53529 Mtetra
.662 .742 .909 r
.4099 .53529 .41309 .53838 .41847 .53673 .41529 .53362 Mtetra
.663 .741 .908 r
.41529 .53362 .41847 .53673 .42387 .53503 .4207 .53195 Mtetra
.666 .744 .908 r
.4207 .53195 .42387 .53503 .42928 .53334 .42611 .53022 Mtetra
.663 .741 .908 r
.42611 .53022 .42928 .53334 .4347 .53165 .43154 .52854 Mtetra
.663 .742 .908 r
.43154 .52854 .4347 .53165 .44013 .52996 .43698 .52684 Mtetra
.664 .742 .908 r
.43698 .52684 .44013 .52996 .44557 .52828 .44242 .52513 Mtetra
.663 .74 .907 r
.44242 .52513 .44557 .52828 .45102 .52658 .44788 .52343 Mtetra
.665 .741 .907 r
.44788 .52343 .45102 .52658 .45648 .52487 .45335 .5217 Mtetra
.658 .738 .909 r
.45335 .5217 .45648 .52487 .46196 .52322 .45883 .52008 Mtetra
.667 .743 .907 r
.45883 .52008 .46196 .52322 .46744 .52146 .46432 .51831 Mtetra
.658 .741 .911 r
.46432 .51831 .46744 .52146 .47294 .51981 .46982 .51667 Mtetra
.67 .745 .907 r
.46982 .51667 .47294 .51981 .47844 .51804 .47534 .51485 Mtetra
.659 .739 .909 r
.47534 .51485 .47844 .51804 .48396 .51637 .48086 .51319 Mtetra
.657 .74 .911 r
.48086 .51319 .48396 .51637 .48949 .51474 .4864 .51156 Mtetra
.659 .741 .911 r
.4864 .51156 .48949 .51474 .49503 .51307 .49195 .5099 Mtetra
.663 .743 .909 r
.49195 .5099 .49503 .51307 .50058 .51133 .49751 .50817 Mtetra
.671 .746 .907 r
.49751 .50817 .50058 .51133 .50614 .50952 .50308 .50632 Mtetra
.656 .74 .911 r
.50308 .50632 .50614 .50952 .51172 .5079 .50866 .50468 Mtetra
.65 .737 .913 r
.50866 .50468 .51172 .5079 .5173 .50634 .51425 .50314 Mtetra
.682 .748 .901 r
.51425 .50314 .5173 .50634 .5229 .50431 .51986 .5011 Mtetra
.665 .743 .908 r
.51986 .5011 .5229 .50431 .52851 .50257 .52547 .49932 Mtetra
.647 .735 .913 r
.52547 .49932 .52851 .50257 .53413 .50103 .5311 .4978 Mtetra
.681 .747 .901 r
.5311 .4978 .53413 .50103 .53976 .49904 .53674 .49576 Mtetra
.65 .735 .912 r
.53674 .49576 .53976 .49904 .54541 .49747 .54239 .4942 Mtetra
.678 .745 .901 r
.54239 .4942 .54541 .49747 .55106 .49549 .54805 .4922 Mtetra
.648 .734 .912 r
.54805 .4922 .55106 .49549 .55673 .49394 .55373 .49066 Mtetra
.669 .742 .905 r
.55373 .49066 .55673 .49394 .5624 .49213 .55941 .4888 Mtetra
.668 .739 .904 r
.55941 .4888 .5624 .49213 .56809 .49023 .56511 .48695 Mtetra
.652 .738 .913 r
.56511 .48695 .56809 .49023 .5738 .48866 .57082 .48533 Mtetra
.674 .742 .902 r
.57082 .48533 .5738 .48866 .57951 .48672 .57654 .48339 Mtetra
.662 .739 .907 r
.57654 .48339 .57951 .48672 .58523 .48491 .58227 .48162 Mtetra
.649 .738 .914 r
.58227 .48162 .58523 .48491 .59097 .48336 .58802 .48003 Mtetra
.684 .746 .899 r
.58802 .48003 .59097 .48336 .59672 .48125 .59377 .47791 Mtetra
.641 .732 .915 r
.59377 .47791 .59672 .48125 .60248 .4798 .59954 .47644 Mtetra
.683 .745 .898 r
.59954 .47644 .60248 .4798 .60825 .47766 .60532 .47431 Mtetra
.646 .734 .914 r
.60532 .47431 .60825 .47766 .61404 .47619 .61112 .47277 Mtetra
.665 .736 .903 r
.61112 .47277 .61404 .47619 .61984 .47432 .61692 .47094 Mtetra
.672 .742 .903 r
.61692 .47094 .61984 .47432 .62564 .4723 .62273 .46899 Mtetra
.664 .744 .91 r
.62273 .46899 .62564 .4723 .63146 .4705 .62856 .46717 Mtetra
.66 .742 .911 r
.62856 .46717 .63146 .4705 .6373 .46885 .6344 .4654 Mtetra
.659 .734 .905 r
.6344 .4654 .6373 .46885 .64314 .4671 .64026 .46364 Mtetra
.677 .74 .898 r
.64026 .46364 .64314 .4671 .64899 .46497 .64612 .46158 Mtetra
.649 .736 .913 r
.64612 .46158 .64899 .46497 .65487 .46343 .652 .45997 Mtetra
.679 .742 .898 r
.652 .45997 .65487 .46343 .66074 .46135 .65788 .45788 Mtetra
.641 .729 .912 r
.65788 .45788 .66074 .46135 .66665 .45981 .6638 .45638 Mtetra
.681 .745 .899 r
.6638 .45638 .66665 .45981 .67254 .45763 .6697 .45424 Mtetra
.651 .738 .913 r
.6697 .45424 .67254 .45763 .67847 .45602 .67564 .45258 Mtetra
.664 .74 .906 r
.67564 .45258 .67847 .45602 .6844 .45413 .68157 .45071 Mtetra
.676 .745 .903 r
.68157 .45071 .6844 .45413 .69033 .45211 .68752 .44865 Mtetra
.651 .735 .911 r
.68752 .44865 .69033 .45211 .6963 .45046 .69349 .44699 Mtetra
.67 .741 .904 r
.69349 .44699 .6963 .45046 .70226 .44846 .69946 .44501 Mtetra
.664 .741 .908 r
.69946 .44501 .70226 .44846 .70824 .44662 .70545 .44314 Mtetra
.658 .738 .908 r
.70545 .44314 .70824 .44662 .71424 .44481 .71146 .44135 Mtetra
.668 .743 .906 r
.71146 .44135 .71424 .44481 .72024 .44288 .71747 .43939 Mtetra
.653 .736 .91 r
.71747 .43939 .72024 .44288 .72627 .44113 .72351 .43767 Mtetra
.673 .746 .905 r
.72351 .43767 .72627 .44113 .73229 .43913 .72954 .43562 Mtetra
.668 .742 .905 r
.72954 .43562 .73229 .43913 .73833 .43714 .73558 .43366 Mtetra
.643 .734 .915 r
.73558 .43366 .73833 .43714 .7444 .43555 .74167 .43208 Mtetra
.67 .745 .907 r
.74167 .43208 .7444 .43555 .75047 .43357 .74774 .43007 Mtetra
.676 .746 .903 r
.74774 .43007 .75047 .43357 .75654 .43148 .75382 .42796 Mtetra
.656 .738 .91 r
.75382 .42796 .75654 .43148 .76264 .42965 .75993 .42617 Mtetra
.662 .743 .91 r
.75993 .42617 .76264 .42965 .76875 .42777 .76605 .42428 Mtetra
.667 .745 .908 r
.76605 .42428 .76875 .42777 .77487 .42581 .77218 .4223 Mtetra
.669 .745 .907 r
.77218 .4223 .77487 .42581 .78099 .42381 .77832 .42029 Mtetra
.669 .744 .907 r
.77832 .42029 .78099 .42381 .78714 .42184 .78447 .41828 Mtetra
.659 .739 .909 r
.78447 .41828 .78714 .42184 .7933 .41996 .79064 .41643 Mtetra
.666 .744 .908 r
.79064 .41643 .7933 .41996 .79947 .41799 .79682 .41446 Mtetra
.663 .743 .909 r
.79682 .41446 .79947 .41799 .80566 .41609 .80302 .41253 Mtetra
.667 .743 .907 r
.80302 .41253 .80566 .41609 .81186 .4141 .80922 .41053 Mtetra
.662 .741 .909 r
.80922 .41053 .81186 .4141 .81807 .41221 .81545 .40862 Mtetra
.664 .741 .907 r
.81545 .40862 .81807 .41221 .8243 .41026 .82169 .40665 Mtetra
.663 .74 .908 r
.82169 .40665 .8243 .41026 .83054 .40829 .82794 .40471 Mtetra
.663 .742 .909 r
.82794 .40471 .83054 .40829 .83679 .40635 .8342 .40276 Mtetra
.666 .743 .908 r
.8342 .40276 .83679 .40635 .84306 .40439 .84047 .40076 Mtetra
.663 .74 .907 r
.84047 .40076 .84306 .40439 .84934 .40241 .84677 .39881 Mtetra
.662 .742 .909 r
.84677 .39881 .84934 .40241 .85564 .40049 .85307 .39686 Mtetra
.666 .743 .908 r
.85307 .39686 .85564 .40049 .86194 .39851 .85939 .39485 Mtetra
.661 .739 .908 r
.85939 .39485 .86194 .39851 .86826 .39653 .86572 .39291 Mtetra
.666 .744 .909 r
.86572 .39291 .86826 .39653 .8746 .39455 .87206 .39089 Mtetra
.662 .74 .908 r
.87206 .39089 .8746 .39455 .88095 .39257 .87843 .38893 Mtetra
.665 .743 .909 r
.87843 .38893 .88095 .39257 .88731 .39058 .8848 .38691 Mtetra
.664 .742 .908 r
.8848 .38691 .88731 .39058 .89369 .38859 .89118 .3849 Mtetra
.663 .741 .908 r
.89118 .3849 .89369 .38859 .90008 .38662 .89758 .38292 Mtetra
.663 .74 .907 r
.89758 .38292 .90008 .38662 .90648 .38462 .904 .38093 Mtetra
.663 .741 .908 r
.904 .38093 .90648 .38462 .9129 .38261 .91043 .37892 Mtetra
.665 .743 .908 r
.91043 .37892 .9129 .38261 .91934 .38064 .91687 .37688 Mtetra
.663 .739 .906 r
.91687 .37688 .91934 .38064 .92578 .3786 .92333 .37488 Mtetra
.662 .741 .908 r
.92333 .37488 .92578 .3786 .93224 .37657 .9298 .37288 Mtetra
.66 .74 .909 r
.34801 .55055 .35128 .5536 .35656 .55196 .35329 .54895 Mtetra
.664 .744 .91 r
.35329 .54895 .35656 .55196 .36184 .55033 .35858 .54729 Mtetra
.666 .743 .908 r
.35858 .54729 .36184 .55033 .36714 .5487 .36389 .54559 Mtetra
.662 .737 .906 r
.36389 .54559 .36714 .5487 .37245 .54701 .3692 .54395 Mtetra
.663 .742 .908 r
.3692 .54395 .37245 .54701 .37777 .54533 .37453 .54228 Mtetra
.665 .743 .908 r
.37453 .54228 .37777 .54533 .3831 .54369 .37986 .54058 Mtetra
.664 .74 .906 r
.37986 .54058 .3831 .54369 .38844 .54199 .38521 .5389 Mtetra
.663 .741 .908 r
.38521 .5389 .38844 .54199 .39379 .54032 .39057 .53723 Mtetra
.661 .741 .909 r
.39057 .53723 .39379 .54032 .39915 .53865 .39593 .53558 Mtetra
.666 .744 .909 r
.39593 .53558 .39915 .53865 .40452 .53699 .40131 .53386 Mtetra
.661 .739 .908 r
.40131 .53386 .40452 .53699 .4099 .53529 .4067 .53222 Mtetra
.667 .745 .908 r
.4067 .53222 .4099 .53529 .41529 .53362 .4121 .53047 Mtetra
.66 .738 .908 r
.4121 .53047 .41529 .53362 .4207 .53195 .41751 .52883 Mtetra
.664 .742 .908 r
.41751 .52883 .4207 .53195 .42611 .53022 .42293 .52712 Mtetra
.666 .744 .909 r
.42293 .52712 .42611 .53022 .43154 .52854 .42837 .52539 Mtetra
.663 .74 .908 r
.42837 .52539 .43154 .52854 .43698 .52684 .43381 .52369 Mtetra
.664 .741 .908 r
.43381 .52369 .43698 .52684 .44242 .52513 .43927 .52198 Mtetra
.665 .742 .907 r
.43927 .52198 .44242 .52513 .44788 .52343 .44473 .52025 Mtetra
.662 .739 .908 r
.44473 .52025 .44788 .52343 .45335 .5217 .45021 .51857 Mtetra
.66 .742 .911 r
.45021 .51857 .45335 .5217 .45883 .52008 .45569 .5169 Mtetra
.666 .742 .906 r
.45569 .5169 .45883 .52008 .46432 .51831 .46119 .51514 Mtetra
.656 .739 .911 r
.46119 .51514 .46432 .51831 .46982 .51667 .4667 .51352 Mtetra
.669 .745 .907 r
.4667 .51352 .46982 .51667 .47534 .51485 .47222 .51171 Mtetra
.663 .744 .91 r
.47222 .51171 .47534 .51485 .48086 .51319 .47776 .50998 Mtetra
.656 .738 .91 r
.47776 .50998 .48086 .51319 .4864 .51156 .4833 .50836 Mtetra
.659 .74 .909 r
.4833 .50836 .4864 .51156 .49195 .5099 .48885 .50668 Mtetra
.666 .742 .907 r
.48885 .50668 .49195 .5099 .49751 .50817 .49442 .5049 Mtetra
.674 .741 .901 r
.49442 .5049 .49751 .50817 .50308 .50632 .5 .50299 Mtetra
.636 .726 .913 r
.5 .50299 .50308 .50632 .50866 .50468 .50559 .50164 Mtetra
.658 .752 .919 r
.50559 .50164 .50866 .50468 .51425 .50314 .51119 .49996 Mtetra
.691 .753 .899 r
.51119 .49996 .51425 .50314 .51986 .5011 .5168 .49777 Mtetra
.65 .731 .909 r
.5168 .49777 .51986 .5011 .52547 .49932 .52242 .49621 Mtetra
.656 .748 .918 r
.52242 .49621 .52547 .49932 .5311 .4978 .52806 .49455 Mtetra
.672 .744 .905 r
.52806 .49455 .5311 .4978 .53674 .49576 .5337 .49266 Mtetra
.662 .751 .916 r
.5337 .49266 .53674 .49576 .54239 .4942 .53936 .4909 Mtetra
.667 .741 .905 r
.53936 .4909 .54239 .4942 .54805 .4922 .54503 .48908 Mtetra
.666 .752 .914 r
.54503 .48908 .54805 .4922 .55373 .49066 .55071 .48725 Mtetra
.655 .731 .905 r
.55071 .48725 .55373 .49066 .55941 .4888 .55641 .48561 Mtetra
.68 .752 .906 r
.55641 .48561 .55941 .4888 .56511 .48695 .56211 .48357 Mtetra
.65 .731 .909 r
.56211 .48357 .56511 .48695 .57082 .48533 .56783 .48199 Mtetra
.659 .737 .907 r
.56783 .48199 .57082 .48533 .57654 .48339 .57356 .48026 Mtetra
.681 .758 .909 r
.57356 .48026 .57654 .48339 .58227 .48162 .5793 .47818 Mtetra
.639 .726 .911 r
.5793 .47818 .58227 .48162 .58802 .48003 .58506 .47675 Mtetra
.682 .75 .902 r
.58506 .47675 .58802 .48003 .59377 .47791 .59081 .47465 Mtetra
.65 .741 .916 r
.59081 .47465 .59377 .47791 .59954 .47644 .59659 .47304 Mtetra
.673 .74 .901 r
.59659 .47304 .59954 .47644 .60532 .47431 .60238 .47107 Mtetra
.648 .743 .919 r
.60238 .47107 .60532 .47431 .61112 .47277 .60819 .46948 Mtetra
.676 .749 .906 r
.60819 .46948 .61112 .47277 .61692 .47094 .61399 .46746 Mtetra
.672 .737 .899 r
.61399 .46746 .61692 .47094 .62273 .46899 .61981 .46551 Mtetra
.667 .735 .901 r
.61981 .46551 .62273 .46899 .62856 .46717 .62565 .46363 Mtetra
.657 .729 .902 r
.62565 .46363 .62856 .46717 .6344 .4654 .6315 .46191 Mtetra
.645 .728 .909 r
.6315 .46191 .6344 .4654 .64026 .46364 .63737 .46035 Mtetra
.669 .749 .911 r
.63737 .46035 .64026 .46364 .64612 .46158 .64324 .45843 Mtetra
.671 .759 .916 r
.64324 .45843 .64612 .46158 .652 .45997 .64912 .45646 Mtetra
.66 .733 .904 r
.64912 .45646 .652 .45997 .65788 .45788 .65502 .45466 Mtetra
.658 .751 .919 r
.65502 .45466 .65788 .45788 .6638 .45638 .66094 .45289 Mtetra
.681 .743 .898 r
.66094 .45289 .6638 .45638 .6697 .45424 .66685 .45075 Mtetra
.64 .729 .913 r
.66685 .45075 .6697 .45424 .67564 .45258 .6728 .44925 Mtetra
.676 .752 .908 r
.6728 .44925 .67564 .45258 .68157 .45071 .67874 .44719 Mtetra
.664 .736 .904 r
.67874 .44719 .68157 .45071 .68752 .44865 .6847 .44532 Mtetra
.653 .745 .917 r
.6847 .44532 .68752 .44865 .69349 .44699 .69068 .4436 Mtetra
.683 .752 .904 r
.69068 .4436 .69349 .44699 .69946 .44501 .69665 .44142 Mtetra
.644 .726 .908 r
.69665 .44142 .69946 .44501 .70545 .44314 .70266 .43984 Mtetra
.673 .755 .912 r
.70266 .43984 .70545 .44314 .71146 .44135 .70866 .43781 Mtetra
.653 .734 .908 r
.70866 .43781 .71146 .44135 .71747 .43939 .7147 .43608 Mtetra
.667 .753 .915 r
.7147 .43608 .71747 .43939 .72351 .43767 .72073 .43413 Mtetra
.662 .738 .906 r
.72073 .43413 .72351 .43767 .72954 .43562 .72678 .43227 Mtetra
.683 .757 .907 r
.72678 .43227 .72954 .43562 .73558 .43366 .73282 .43004 Mtetra
.635 .723 .912 r
.73282 .43004 .73558 .43366 .74167 .43208 .73893 .42859 Mtetra
.66 .741 .91 r
.73893 .42859 .74167 .43208 .74774 .43007 .74502 .42673 Mtetra
.689 .761 .907 r
.74502 .42673 .74774 .43007 .75382 .42796 .75109 .42441 Mtetra
.658 .738 .909 r
.75109 .42441 .75382 .42796 .75993 .42617 .75721 .42258 Mtetra
.659 .736 .906 r
.75721 .42258 .75993 .42617 .76605 .42428 .76334 .42073 Mtetra
.667 .742 .906 r
.76334 .42073 .76605 .42428 .77218 .4223 .76948 .41875 Mtetra
.67 .744 .905 r
.76948 .41875 .77218 .4223 .77832 .42029 .77562 .41671 Mtetra
.667 .742 .906 r
.77562 .41671 .77832 .42029 .78447 .41828 .78179 .41472 Mtetra
.657 .739 .911 r
.78179 .41472 .78447 .41828 .79064 .41643 .78797 .4129 Mtetra
.668 .745 .908 r
.78797 .4129 .79064 .41643 .79682 .41446 .79416 .41089 Mtetra
.663 .742 .908 r
.79416 .41089 .79682 .41446 .80302 .41253 .80037 .40894 Mtetra
.668 .743 .906 r
.80037 .40894 .80302 .41253 .80922 .41053 .80658 .40692 Mtetra
.662 .74 .907 r
.80658 .40692 .80922 .41053 .81545 .40862 .81281 .40499 Mtetra
.662 .739 .907 r
.81281 .40499 .81545 .40862 .82169 .40665 .81906 .40306 Mtetra
.663 .742 .909 r
.81906 .40306 .82169 .40665 .82794 .40471 .82532 .4011 Mtetra
.666 .743 .908 r
.82532 .4011 .82794 .40471 .8342 .40276 .83159 .39911 Mtetra
.664 .74 .907 r
.83159 .39911 .8342 .40276 .84047 .40076 .83788 .39713 Mtetra
.662 .741 .908 r
.83788 .39713 .84047 .40076 .84677 .39881 .84418 .39519 Mtetra
.665 .743 .908 r
.84418 .39519 .84677 .39881 .85307 .39686 .85049 .39319 Mtetra
.663 .739 .907 r
.85049 .39319 .85307 .39686 .85939 .39485 .85682 .39121 Mtetra
.664 .743 .909 r
.85682 .39121 .85939 .39485 .86572 .39291 .86316 .38923 Mtetra
.663 .74 .907 r
.86316 .38923 .86572 .39291 .87206 .39089 .86952 .38725 Mtetra
.665 .744 .909 r
.86952 .38725 .87206 .39089 .87843 .38893 .87589 .38523 Mtetra
.662 .739 .907 r
.87589 .38523 .87843 .38893 .8848 .38691 .88227 .38326 Mtetra
.665 .744 .909 r
.88227 .38326 .8848 .38691 .89118 .3849 .88867 .38122 Mtetra
.664 .742 .908 r
.88867 .38122 .89118 .3849 .89758 .38292 .89508 .37921 Mtetra
.663 .741 .908 r
.89508 .37921 .89758 .38292 .904 .38093 .9015 .37721 Mtetra
.663 .741 .907 r
.9015 .37721 .904 .38093 .91043 .37892 .90794 .37519 Mtetra
.663 .74 .908 r
.90794 .37519 .91043 .37892 .91687 .37688 .9144 .37318 Mtetra
.665 .744 .909 r
.9144 .37318 .91687 .37688 .92333 .37488 .92086 .37113 Mtetra
.664 .741 .907 r
.92086 .37113 .92333 .37488 .9298 .37288 .92734 .36909 Mtetra
.664 .741 .908 r
.34473 .54749 .34801 .55055 .35329 .54895 .35002 .54583 Mtetra
.66 .737 .906 r
.35002 .54583 .35329 .54895 .35858 .54729 .35531 .54421 Mtetra
.662 .74 .908 r
.35531 .54421 .35858 .54729 .36389 .54559 .36062 .54256 Mtetra
.666 .745 .909 r
.36062 .54256 .36389 .54559 .3692 .54395 .36595 .54085 Mtetra
.665 .741 .907 r
.36595 .54085 .3692 .54395 .37453 .54228 .37128 .53916 Mtetra
.664 .74 .906 r
.37128 .53916 .37453 .54228 .37986 .54058 .37662 .53747 Mtetra
.662 .74 .908 r
.37662 .53747 .37986 .54058 .38521 .5389 .38197 .53582 Mtetra
.661 .742 .91 r
.38197 .53582 .38521 .5389 .39057 .53723 .38733 .53416 Mtetra
.666 .744 .909 r
.38733 .53416 .39057 .53723 .39593 .53558 .39271 .53244 Mtetra
.661 .739 .908 r
.39271 .53244 .39593 .53558 .40131 .53386 .39809 .53078 Mtetra
.666 .745 .909 r
.39809 .53078 .40131 .53386 .4067 .53222 .40349 .52906 Mtetra
.662 .739 .907 r
.40349 .52906 .4067 .53222 .4121 .53047 .4089 .52739 Mtetra
.667 .745 .909 r
.4089 .52739 .4121 .53047 .41751 .52883 .41432 .52564 Mtetra
.66 .737 .907 r
.41432 .52564 .41751 .52883 .42293 .52712 .41974 .52398 Mtetra
.663 .742 .908 r
.41974 .52398 .42293 .52712 .42837 .52539 .42518 .52228 Mtetra
.665 .745 .909 r
.42518 .52228 .42837 .52539 .43381 .52369 .43063 .52054 Mtetra
.665 .742 .908 r
.43063 .52054 .43381 .52369 .43927 .52198 .4361 .51881 Mtetra
.661 .74 .908 r
.4361 .51881 .43927 .52198 .44473 .52025 .44157 .51712 Mtetra
.659 .743 .912 r
.44157 .51712 .44473 .52025 .45021 .51857 .44705 .51546 Mtetra
.665 .746 .911 r
.44705 .51546 .45021 .51857 .45569 .5169 .45255 .51371 Mtetra
.666 .741 .907 r
.45255 .51371 .45569 .5169 .46119 .51514 .45805 .51195 Mtetra
.658 .74 .91 r
.45805 .51195 .46119 .51514 .4667 .51352 .46357 .5103 Mtetra
.662 .739 .907 r
.46357 .5103 .4667 .51352 .47222 .51171 .4691 .50859 Mtetra
.67 .748 .909 r
.4691 .50859 .47222 .51171 .47776 .50998 .47464 .50675 Mtetra
.663 .74 .907 r
.47464 .50675 .47776 .50998 .4833 .50836 .48019 .50501 Mtetra
.661 .732 .902 r
.48019 .50501 .4833 .50836 .48885 .50668 .48575 .50329 Mtetra
.666 .732 .899 r
.48575 .50329 .48885 .50668 .49442 .5049 .49132 .50151 Mtetra
.643 .725 .908 r
.49132 .50151 .49442 .5049 .5 .50299 .49691 .50006 Mtetra
.64 .754 .931 r
.49691 .50006 .5 .50299 .50559 .50164 .5025 .4986 Mtetra
.681 .759 .91 r
.5025 .4986 .50559 .50164 .51119 .49996 .50811 .49657 Mtetra
.675 .736 .896 r
.50811 .49657 .51119 .49996 .5168 .49777 .51373 .49462 Mtetra
.646 .743 .92 r
.51373 .49462 .5168 .49777 .52242 .49621 .51936 .49309 Mtetra
.676 .754 .91 r
.51936 .49309 .52242 .49621 .52806 .49455 .525 .49113 Mtetra
.647 .726 .907 r
.525 .49113 .52806 .49455 .5337 .49266 .53066 .48961 Mtetra
.686 .762 .909 r
.53066 .48961 .5337 .49266 .53936 .4909 .53632 .48749 Mtetra
.642 .726 .909 r
.53632 .48749 .53936 .4909 .54503 .48908 .542 .48602 Mtetra
.69 .764 .908 r
.542 .48602 .54503 .48908 .55071 .48725 .54769 .48383 Mtetra
.639 .725 .91 r
.54769 .48383 .55071 .48725 .55641 .48561 .55339 .48241 Mtetra
.669 .749 .911 r
.55339 .48241 .55641 .48561 .56211 .48357 .55911 .48053 Mtetra
.673 .761 .917 r
.55911 .48053 .56211 .48357 .56783 .48199 .56483 .47858 Mtetra
.642 .729 .911 r
.56483 .47858 .56783 .48199 .57356 .48026 .57057 .4771 Mtetra
.688 .759 .906 r
.57057 .4771 .57356 .48026 .5793 .47818 .57631 .47491 Mtetra
.649 .74 .916 r
.57631 .47491 .5793 .47818 .58506 .47675 .58208 .47332 Mtetra
.662 .735 .904 r
.58208 .47332 .58506 .47675 .59081 .47465 .58785 .47153 Mtetra
.676 .76 .914 r
.58785 .47153 .59081 .47465 .59659 .47304 .59363 .46951 Mtetra
.646 .725 .906 r
.59363 .46951 .59659 .47304 .60238 .47107 .59943 .46797 Mtetra
.665 .758 .92 r
.59943 .46797 .60238 .47107 .60819 .46948 .60524 .46612 Mtetra
.688 .749 .898 r
.60524 .46612 .60819 .46948 .61399 .46746 .61105 .4639 Mtetra
.651 .725 .903 r
.61105 .4639 .61399 .46746 .61981 .46551 .61689 .46227 Mtetra
.663 .75 .915 r
.61689 .46227 .61981 .46551 .62565 .46363 .62273 .46044 Mtetra
.677 .758 .912 r
.62273 .46044 .62565 .46363 .6315 .46191 .62859 .45838 Mtetra
.638 .724 .911 r
.62859 .45838 .6315 .46191 .63737 .46035 .63447 .45694 Mtetra
.657 .738 .909 r
.63447 .45694 .63737 .46035 .64324 .45843 .64035 .45519 Mtetra
.691 .761 .905 r
.64035 .45519 .64324 .45843 .64912 .45646 .64623 .45289 Mtetra
.635 .722 .91 r
.64623 .45289 .64912 .45646 .65502 .45466 .65215 .45147 Mtetra
.685 .763 .911 r
.65215 .45147 .65502 .45466 .66094 .45289 .65806 .44928 Mtetra
.656 .727 .902 r
.65806 .44928 .66094 .45289 .66685 .45075 .664 .44754 Mtetra
.652 .752 .923 r
.664 .44754 .66685 .45075 .6728 .44925 .66995 .44583 Mtetra
.685 .75 .9 r
.66995 .44583 .6728 .44925 .67874 .44719 .67589 .4436 Mtetra
.64 .724 .909 r
.67589 .4436 .67874 .44719 .6847 .44532 .68187 .4421 Mtetra
.667 .757 .918 r
.68187 .4421 .6847 .44532 .69068 .4436 .68785 .44016 Mtetra
.676 .747 .905 r
.68785 .44016 .69068 .4436 .69665 .44142 .69384 .43808 Mtetra
.641 .742 .922 r
.69384 .43808 .69665 .44142 .70266 .43984 .69986 .43653 Mtetra
.693 .762 .904 r
.69986 .43653 .70266 .43984 .70866 .43781 .70586 .43416 Mtetra
.633 .72 .91 r
.70586 .43416 .70866 .43781 .7147 .43608 .71191 .43273 Mtetra
.688 .759 .905 r
.71191 .43273 .7147 .43608 .72073 .43413 .71794 .43043 Mtetra
.642 .721 .905 r
.71794 .43043 .72073 .43413 .72678 .43227 .72401 .42887 Mtetra
.675 .753 .909 r
.72401 .42887 .72678 .43227 .73282 .43004 .73007 .42677 Mtetra
.663 .757 .92 r
.73007 .42677 .73282 .43004 .73893 .42859 .73616 .42486 Mtetra
.638 .719 .906 r
.73616 .42486 .73893 .42859 .74502 .42673 .74228 .42335 Mtetra
.678 .756 .91 r
.74228 .42335 .74502 .42673 .75109 .42441 .74838 .4212 Mtetra
.685 .77 .916 r
.74838 .4212 .75109 .42441 .75721 .42258 .75448 .41894 Mtetra
.665 .736 .903 r
.75448 .41894 .75721 .42258 .76334 .42073 .76061 .41699 Mtetra
.664 .731 .899 r
.76061 .41699 .76334 .42073 .76948 .41875 .76676 .41505 Mtetra
.666 .734 .901 r
.76676 .41505 .76948 .41875 .77562 .41671 .77292 .41308 Mtetra
.657 .735 .907 r
.77292 .41308 .77562 .41671 .78179 .41472 .7791 .41124 Mtetra
.663 .747 .913 r
.7791 .41124 .78179 .41472 .78797 .4129 .78529 .40931 Mtetra
.671 .744 .905 r
.78529 .40931 .78797 .4129 .79416 .41089 .79148 .40724 Mtetra
.658 .736 .907 r
.79148 .40724 .79416 .41089 .80037 .40894 .79771 .40537 Mtetra
.665 .743 .909 r
.79771 .40537 .80037 .40894 .80658 .40692 .80393 .40339 Mtetra
.668 .748 .91 r
.80393 .40339 .80658 .40692 .81281 .40499 .81017 .40135 Mtetra
.662 .74 .907 r
.81017 .40135 .81281 .40499 .81906 .40306 .81643 .39941 Mtetra
.664 .74 .906 r
.81643 .39941 .81906 .40306 .82532 .4011 .82269 .39743 Mtetra
.663 .739 .906 r
.82269 .39743 .82532 .4011 .83159 .39911 .82898 .39547 Mtetra
.663 .741 .908 r
.82898 .39547 .83159 .39911 .83788 .39713 .83528 .39351 Mtetra
.664 .743 .909 r
.83528 .39351 .83788 .39713 .84418 .39519 .84159 .39152 Mtetra
.665 .741 .907 r
.84159 .39152 .84418 .39519 .85049 .39319 .84791 .3895 Mtetra
.662 .739 .908 r
.84791 .3895 .85049 .39319 .85682 .39121 .85425 .38755 Mtetra
.665 .742 .908 r
.85425 .38755 .85682 .39121 .86316 .38923 .8606 .38553 Mtetra
.662 .74 .908 r
.8606 .38553 .86316 .38923 .86952 .38725 .86697 .38356 Mtetra
.663 .74 .908 r
.86697 .38356 .86952 .38725 .87589 .38523 .87335 .38157 Mtetra
.667 .745 .909 r
.87335 .38157 .87589 .38523 .88227 .38326 .87973 .37951 Mtetra
.661 .738 .907 r
.87973 .37951 .88227 .38326 .88867 .38122 .88615 .37755 Mtetra
.665 .744 .909 r
.88615 .37755 .88867 .38122 .89508 .37921 .89257 .37551 Mtetra
.664 .743 .908 r
.89257 .37551 .89508 .37921 .9015 .37721 .899 .37347 Mtetra
.662 .74 .908 r
.899 .37347 .9015 .37721 .90794 .37519 .90545 .37147 Mtetra
.665 .743 .908 r
.90545 .37147 .90794 .37519 .9144 .37318 .91191 .36941 Mtetra
.663 .74 .907 r
.91191 .36941 .9144 .37318 .92086 .37113 .91839 .36739 Mtetra
.662 .741 .909 r
.91839 .36739 .92086 .37113 .92734 .36909 .92489 .36538 Mtetra
.661 .742 .91 r
.34143 .54444 .34473 .54749 .35002 .54583 .34672 .54281 Mtetra
.666 .746 .91 r
.34672 .54281 .35002 .54583 .35531 .54421 .35203 .54111 Mtetra
.663 .74 .907 r
.35203 .54111 .35531 .54421 .36062 .54256 .35735 .53944 Mtetra
.663 .739 .906 r
.35735 .53944 .36062 .54256 .36595 .54085 .36268 .53777 Mtetra
.664 .742 .908 r
.36268 .53777 .36595 .54085 .37128 .53916 .36801 .53608 Mtetra
.663 .742 .909 r
.36801 .53608 .37128 .53916 .37662 .53747 .37336 .53441 Mtetra
.663 .744 .91 r
.37336 .53441 .37662 .53747 .38197 .53582 .37872 .53272 Mtetra
.665 .743 .908 r
.37872 .53272 .38197 .53582 .38733 .53416 .38409 .53101 Mtetra
.661 .739 .908 r
.38409 .53101 .38733 .53416 .39271 .53244 .38947 .52936 Mtetra
.666 .745 .909 r
.38947 .52936 .39271 .53244 .39809 .53078 .39487 .52762 Mtetra
.663 .739 .907 r
.39487 .52762 .39809 .53078 .40349 .52906 .40027 .52594 Mtetra
.664 .742 .908 r
.40027 .52594 .40349 .52906 .4089 .52739 .40568 .52423 Mtetra
.663 .74 .907 r
.40568 .52423 .4089 .52739 .41432 .52564 .41111 .52253 Mtetra
.665 .744 .909 r
.41111 .52253 .41432 .52564 .41974 .52398 .41654 .52079 Mtetra
.661 .738 .907 r
.41654 .52079 .41974 .52398 .42518 .52228 .42199 .51911 Mtetra
.661 .74 .908 r
.42199 .51911 .42518 .52228 .43063 .52054 .42744 .51743 Mtetra
.663 .744 .911 r
.42744 .51743 .43063 .52054 .4361 .51881 .43291 .51572 Mtetra
.664 .747 .912 r
.43291 .51572 .4361 .51881 .44157 .51712 .43839 .51398 Mtetra
.664 .744 .91 r
.43839 .51398 .44157 .51712 .44705 .51546 .44388 .51225 Mtetra
.667 .741 .905 r
.44388 .51225 .44705 .51546 .45255 .51371 .44939 .51046 Mtetra
.654 .735 .909 r
.44939 .51046 .45255 .51371 .45805 .51195 .4549 .50886 Mtetra
.672 .751 .91 r
.4549 .50886 .45805 .51195 .46357 .5103 .46042 .50699 Mtetra
.651 .731 .908 r
.46042 .50699 .46357 .5103 .4691 .50859 .46596 .50544 Mtetra
.659 .744 .913 r
.46596 .50544 .4691 .50859 .47464 .50675 .4715 .50377 Mtetra
.663 .756 .92 r
.4715 .50377 .47464 .50675 .48019 .50501 .47706 .50202 Mtetra
.659 .756 .922 r
.47706 .50202 .48019 .50501 .48575 .50329 .48263 .50033 Mtetra
.65 .755 .926 r
.48263 .50033 .48575 .50329 .49132 .50151 .48821 .49875 Mtetra
.649 .77 .937 r
.48821 .49875 .49132 .50151 .49691 .50006 .4938 .49715 Mtetra
.681 .768 .917 r
.4938 .49715 .49691 .50006 .5025 .4986 .49941 .49512 Mtetra
.673 .73 .893 r
.49941 .49512 .5025 .4986 .50811 .49657 .50502 .49321 Mtetra
.647 .73 .91 r
.50502 .49321 .50811 .49657 .51373 .49462 .51065 .49169 Mtetra
.681 .768 .917 r
.51065 .49169 .51373 .49462 .51936 .49309 .51629 .48965 Mtetra
.66 .73 .901 r
.51629 .48965 .51936 .49309 .525 .49113 .52194 .48793 Mtetra
.659 .745 .914 r
.52194 .48793 .525 .49113 .53066 .48961 .5276 .48621 Mtetra
.671 .737 .9 r
.5276 .48621 .53066 .48961 .53632 .48749 .53327 .48431 Mtetra
.657 .746 .916 r
.53327 .48431 .53632 .48749 .542 .48602 .53896 .48261 Mtetra
.659 .733 .904 r
.53896 .48261 .542 .48602 .54769 .48383 .54466 .48089 Mtetra
.684 .771 .917 r
.54466 .48089 .54769 .48383 .55339 .48241 .55037 .47878 Mtetra
.643 .715 .9 r
.55037 .47878 .55339 .48241 .55911 .48053 .55609 .4773 Mtetra
.679 .752 .906 r
.55609 .4773 .55911 .48053 .56483 .47858 .56182 .47526 Mtetra
.666 .743 .907 r
.56182 .47526 .56483 .47858 .57057 .4771 .56756 .47341 Mtetra
.649 .715 .896 r
.56756 .47341 .57057 .4771 .57631 .47491 .57332 .47182 Mtetra
.676 .761 .915 r
.57332 .47182 .57631 .47491 .58208 .47332 .57909 .46982 Mtetra
.65 .728 .906 r
.57909 .46982 .58208 .47332 .58785 .47153 .58487 .46822 Mtetra
.672 .747 .907 r
.58487 .46822 .58785 .47153 .59363 .46951 .59066 .46626 Mtetra
.655 .745 .916 r
.59066 .46626 .59363 .46951 .59943 .46797 .59647 .46455 Mtetra
.682 .744 .898 r
.59647 .46455 .59943 .46797 .60524 .46612 .60228 .46242 Mtetra
.645 .716 .899 r
.60228 .46242 .60524 .46612 .61105 .4639 .60811 .46088 Mtetra
.655 .762 .929 r
.60811 .46088 .61105 .4639 .61689 .46227 .61396 .45915 Mtetra
.666 .759 .92 r
.61396 .45915 .61689 .46227 .62273 .46044 .61981 .45725 Mtetra
.665 .756 .918 r
.61981 .45725 .62273 .46044 .62859 .45838 .62568 .45538 Mtetra
.676 .771 .922 r
.62568 .45538 .62859 .45838 .63447 .45694 .63155 .45333 Mtetra
.662 .729 .899 r
.63155 .45333 .63447 .45694 .64035 .45519 .63744 .45151 Mtetra
.659 .724 .897 r
.63744 .45151 .64035 .45519 .64623 .45289 .64334 .44973 Mtetra
.664 .758 .92 r
.64334 .44973 .64623 .45289 .65215 .45147 .64926 .44785 Mtetra
.664 .73 .899 r
.64926 .44785 .65215 .45147 .65806 .44928 .65518 .44597 Mtetra
.655 .747 .917 r
.65518 .44597 .65806 .44928 .664 .44754 .66113 .44423 Mtetra
.684 .757 .907 r
.66113 .44423 .664 .44754 .66995 .44583 .66707 .44203 Mtetra
.649 .715 .896 r
.66707 .44203 .66995 .44583 .67589 .4436 .67304 .44038 Mtetra
.664 .757 .919 r
.67304 .44038 .67589 .4436 .68187 .4421 .67902 .43849 Mtetra
.677 .738 .896 r
.67902 .43849 .68187 .4421 .68785 .44016 .685 .43637 Mtetra
.643 .715 .9 r
.685 .43637 .68785 .44016 .69384 .43808 .69102 .43482 Mtetra
.677 .76 .914 r
.69102 .43482 .69384 .43808 .69986 .43653 .69702 .43271 Mtetra
.656 .719 .895 r
.69702 .43271 .69986 .43653 .70586 .43416 .70306 .43094 Mtetra
.67 .762 .919 r
.70306 .43094 .70586 .43416 .71191 .43273 .70909 .42893 Mtetra
.649 .719 .899 r
.70909 .42893 .71191 .43273 .71794 .43043 .71516 .42726 Mtetra
.68 .77 .919 r
.71516 .42726 .71794 .43043 .72401 .42887 .72121 .42509 Mtetra
.645 .719 .902 r
.72121 .42509 .72401 .42887 .73007 .42677 .72731 .42348 Mtetra
.67 .758 .917 r
.72731 .42348 .73007 .42677 .73616 .42486 .7334 .42146 Mtetra
.669 .752 .913 r
.7334 .42146 .73616 .42486 .74228 .42335 .7395 .41945 Mtetra
.64 .711 .899 r
.7395 .41945 .74228 .42335 .74838 .4212 .74565 .41791 Mtetra
.67 .76 .918 r
.74565 .41791 .74838 .4212 .75448 .41894 .75177 .41586 Mtetra
.675 .777 .927 r
.75177 .41586 .75448 .41894 .76061 .41699 .7579 .41374 Mtetra
.668 .763 .921 r
.7579 .41374 .76061 .41699 .76676 .41505 .76406 .41171 Mtetra
.664 .756 .919 r
.76406 .41171 .76676 .41505 .77292 .41308 .77023 .40976 Mtetra
.666 .759 .92 r
.77023 .40976 .77292 .41308 .7791 .41124 .77641 .40777 Mtetra
.675 .753 .909 r
.77641 .40777 .7791 .41124 .78529 .40931 .78259 .40563 Mtetra
.658 .734 .905 r
.78259 .40563 .78529 .40931 .79148 .40724 .78881 .40376 Mtetra
.669 .751 .912 r
.78881 .40376 .79148 .40724 .79771 .40537 .79503 .40171 Mtetra
.661 .737 .907 r
.79503 .40171 .79771 .40537 .80393 .40339 .80127 .39979 Mtetra
.665 .743 .908 r
.80127 .39979 .80393 .40339 .81017 .40135 .80752 .3978 Mtetra
.664 .746 .912 r
.80752 .3978 .81017 .40135 .81643 .39941 .81379 .39583 Mtetra
.664 .745 .91 r
.81379 .39583 .81643 .39941 .82269 .39743 .82006 .39384 Mtetra
.82006 .39384 .82269 .39743 .82898 .39547 .82636 .39185 Mtetra
.664 .743 .909 r
.82636 .39185 .82898 .39547 .83528 .39351 .83266 .38985 Mtetra
.666 .743 .907 r
.83266 .38985 .83528 .39351 .84159 .39152 .83898 .38782 Mtetra
.661 .739 .907 r
.83898 .38782 .84159 .39152 .84791 .3895 .84532 .38587 Mtetra
.665 .744 .909 r
.84532 .38587 .84791 .3895 .85425 .38755 .85166 .38385 Mtetra
.663 .74 .908 r
.85166 .38385 .85425 .38755 .8606 .38553 .85802 .38186 Mtetra
.664 .743 .909 r
.85802 .38186 .8606 .38553 .86697 .38356 .8644 .37985 Mtetra
.664 .741 .907 r
.8644 .37985 .86697 .38356 .87335 .38157 .87079 .37784 Mtetra
.661 .739 .908 r
.87079 .37784 .87335 .38157 .87973 .37951 .8772 .37587 Mtetra
.666 .747 .911 r
.8772 .37587 .87973 .37951 .88615 .37755 .88361 .3738 Mtetra
.664 .74 .907 r
.88361 .3738 .88615 .37755 .89257 .37551 .89004 .37178 Mtetra
.663 .741 .908 r
.89004 .37178 .89257 .37551 .899 .37347 .89649 .36975 Mtetra
.665 .743 .909 r
.89649 .36975 .899 .37347 .90545 .37147 .90294 .3677 Mtetra
.663 .74 .907 r
.90294 .3677 .90545 .37147 .91191 .36941 .90942 .36567 Mtetra
.664 .743 .908 r
.90942 .36567 .91191 .36941 .91839 .36739 .91591 .36362 Mtetra
.662 .74 .908 r
.91591 .36362 .91839 .36739 .92489 .36538 .92241 .3616 Mtetra
.66 .74 .909 r
.33812 .54135 .34143 .54444 .34672 .54281 .34342 .53973 Mtetra
.663 .741 .908 r
.34342 .53973 .34672 .54281 .35203 .54111 .34874 .53806 Mtetra
.666 .745 .909 r
.34874 .53806 .35203 .54111 .35735 .53944 .35406 .53635 Mtetra
.664 .742 .908 r
.35406 .53635 .35735 .53944 .36268 .53777 .35939 .53466 Mtetra
.664 .741 .908 r
.35939 .53466 .36268 .53777 .36801 .53608 .36474 .53297 Mtetra
.665 .741 .907 r
.36474 .53297 .36801 .53608 .37336 .53441 .3701 .53126 Mtetra
.659 .738 .908 r
.3701 .53126 .37336 .53441 .37872 .53272 .37546 .52962 Mtetra
.663 .743 .909 r
.37546 .52962 .37872 .53272 .38409 .53101 .38084 .52793 Mtetra
.667 .745 .909 r
.38084 .52793 .38409 .53101 .38947 .52936 .38623 .52619 Mtetra
.662 .738 .907 r
.38623 .52619 .38947 .52936 .39487 .52762 .39162 .52451 Mtetra
.665 .744 .909 r
.39162 .52451 .39487 .52762 .40027 .52594 .39703 .52279 Mtetra
.664 .741 .908 r
.39703 .52279 .40027 .52594 .40568 .52423 .40245 .52107 Mtetra
.663 .741 .908 r
.40245 .52107 .40568 .52423 .41111 .52253 .40788 .51937 Mtetra
.662 .741 .908 r
.40788 .51937 .41111 .52253 .41654 .52079 .41333 .51767 Mtetra
.665 .744 .909 r
.41333 .51767 .41654 .52079 .42199 .51911 .41878 .51593 Mtetra
.664 .741 .907 r
.41878 .51593 .42199 .51911 .42744 .51743 .42425 .51419 Mtetra
.663 .738 .905 r
.42425 .51419 .42744 .51743 .43291 .51572 .42972 .51246 Mtetra
.664 .737 .905 r
.42972 .51246 .43291 .51572 .43839 .51398 .43521 .51073 Mtetra
.66 .737 .906 r
.43521 .51073 .43839 .51398 .44388 .51225 .4407 .50904 Mtetra
.657 .739 .91 r
.4407 .50904 .44388 .51225 .44939 .51046 .44621 .50739 Mtetra
.671 .752 .912 r
.44621 .50739 .44939 .51046 .4549 .50886 .45173 .50554 Mtetra
.654 .732 .907 r
.45173 .50554 .4549 .50886 .46042 .50699 .45726 .50394 Mtetra
.673 .755 .912 r
.45726 .50394 .46042 .50699 .46596 .50544 .46281 .50205 Mtetra
.655 .728 .903 r
.46281 .50205 .46596 .50544 .4715 .50377 .46836 .50043 Mtetra
.651 .731 .908 r
.46836 .50043 .4715 .50377 .47706 .50202 .47392 .49885 Mtetra
.656 .743 .914 r
.47392 .49885 .47706 .50202 .48263 .50033 .4795 .49721 Mtetra
.665 .749 .913 r
.4795 .49721 .48263 .50033 .48821 .49875 .48509 .49543 Mtetra
.684 .743 .896 r
.48509 .49543 .48821 .49875 .4938 .49715 .49069 .49333 Mtetra
.635 .699 .892 r
.49069 .49333 .4938 .49715 .49941 .49512 .4963 .492 Mtetra
.649 .746 .92 r
.4963 .492 .49941 .49512 .50502 .49321 .50192 .49043 Mtetra
.705 .784 .913 r
.50192 .49043 .50502 .49321 .51065 .49169 .50756 .48802 Mtetra
.652 .714 .894 r
.50756 .48802 .51065 .49169 .51629 .48965 .5132 .48642 Mtetra
.644 .739 .918 r
.5132 .48642 .51629 .48965 .52194 .48793 .51886 .48491 Mtetra
.681 .764 .914 r
.51886 .48491 .52194 .48793 .5276 .48621 .52453 .48286 Mtetra
.658 .736 .908 r
.52453 .48286 .5276 .48621 .53327 .48431 .53021 .48115 Mtetra
.67 .752 .912 r
.53021 .48115 .53327 .48431 .53896 .48261 .53591 .47925 Mtetra
.667 .739 .904 r
.53591 .47925 .53896 .48261 .54466 .48089 .54161 .4774 Mtetra
.651 .727 .904 r
.54161 .4774 .54466 .48089 .55037 .47878 .54733 .47579 Mtetra
.685 .769 .915 r
.54733 .47579 .55037 .47878 .55609 .4773 .55306 .47364 Mtetra
.642 .715 .9 r
.55306 .47364 .55609 .4773 .56182 .47526 .5588 .47217 Mtetra
.663 .757 .92 r
.5588 .47217 .56182 .47526 .56756 .47341 .56455 .47036 Mtetra
.681 .765 .915 r
.56455 .47036 .56756 .47341 .57332 .47182 .57031 .46828 Mtetra
.645 .723 .905 r
.57031 .46828 .57332 .47182 .57909 .46982 .57609 .46674 Mtetra
.686 .766 .912 r
.57609 .46674 .57909 .46982 .58487 .46822 .58188 .46456 Mtetra
.646 .718 .901 r
.58188 .46456 .58487 .46822 .59066 .46626 .58768 .46301 Mtetra
.676 .753 .909 r
.58768 .46301 .59066 .46626 .59647 .46455 .59349 .46097 Mtetra
.64 .721 .907 r
.59349 .46097 .59647 .46455 .60228 .46242 .59932 .4595 Mtetra
.675 .775 .926 r
.59932 .4595 .60228 .46242 .60811 .46088 .60516 .45747 Mtetra
.68 .746 .901 r
.60516 .45747 .60811 .46088 .61396 .45915 .611 .45536 Mtetra
.66 .718 .891 r
.611 .45536 .61396 .45915 .61981 .45725 .61686 .45356 Mtetra
.648 .719 .9 r
.61686 .45356 .61981 .45725 .62568 .45538 .62274 .45195 Mtetra
.652 .737 .912 r
.62274 .45195 .62568 .45538 .63155 .45333 .62863 .45027 Mtetra
.682 .771 .918 r
.62863 .45027 .63155 .45333 .63744 .45151 .63452 .44811 Mtetra
.656 .741 .912 r
.63452 .44811 .63744 .45151 .64334 .44973 .64044 .44636 Mtetra
.666 .747 .91 r
.64044 .44636 .64334 .44973 .64926 .44785 .64636 .44445 Mtetra
.662 .744 .911 r
.64636 .44445 .64926 .44785 .65518 .44597 .6523 .44261 Mtetra
.682 .753 .905 r
.6523 .44261 .65518 .44597 .66113 .44423 .65823 .44044 Mtetra
.638 .712 .901 r
.65823 .44044 .66113 .44423 .66707 .44203 .66421 .43896 Mtetra
.669 .769 .925 r
.66421 .43896 .66707 .44203 .67304 .44038 .67018 .43697 Mtetra
.671 .748 .908 r
.67018 .43697 .67304 .44038 .67902 .43849 .67616 .43496 Mtetra
.645 .732 .912 r
.67616 .43496 .67902 .43849 .685 .43637 .68217 .43335 Mtetra
.693 .781 .919 r
.68217 .43335 .685 .43637 .69102 .43482 .68816 .43098 Mtetra
.637 .711 .901 r
.68816 .43098 .69102 .43482 .69702 .43271 .69421 .42951 Mtetra
.673 .764 .919 r
.69421 .42951 .69702 .43271 .70306 .43094 .70024 .42744 Mtetra
.656 .74 .911 r
.70024 .42744 .70306 .43094 .70909 .42893 .70629 .42565 Mtetra
.661 .756 .92 r
.70629 .42565 .70909 .42893 .71516 .42726 .71236 .42377 Mtetra
.669 .746 .908 r
.71236 .42377 .71516 .42726 .72121 .42509 .71843 .42177 Mtetra
.685 .762 .91 r
.71843 .42177 .72121 .42509 .72731 .42348 .7245 .4195 Mtetra
.625 .7 .9 r
.7245 .4195 .72731 .42348 .7334 .42146 .73064 .41821 Mtetra
.663 .76 .922 r
.73064 .41821 .7334 .42146 .7395 .41945 .73676 .41628 Mtetra
.699 .778 .913 r
.73676 .41628 .7395 .41945 .74565 .41791 .74285 .41377 Mtetra
.645 .701 .887 r
.74285 .41377 .74565 .41791 .75177 .41586 .74901 .41214 Mtetra
.659 .731 .902 r
.74901 .41214 .75177 .41586 .7579 .41374 .75517 .41026 Mtetra
.67 .75 .911 r
.75517 .41026 .7579 .41374 .76406 .41171 .76133 .40822 Mtetra
.674 .751 .909 r
.76133 .40822 .76406 .41171 .77023 .40976 .7675 .4061 Mtetra
.675 .742 .901 r
.7675 .4061 .77023 .40976 .77641 .40777 .77368 .40395 Mtetra
.655 .725 .901 r
.77368 .40395 .77641 .40777 .78259 .40563 .7799 .40214 Mtetra
.669 .751 .912 r
.7799 .40214 .78259 .40563 .78881 .40376 .78611 .4001 Mtetra
.661 .738 .907 r
.78611 .4001 .78881 .40376 .79503 .40171 .79235 .39817 Mtetra
.671 .75 .91 r
.79235 .39817 .79503 .40171 .80127 .39979 .79859 .39607 Mtetra
.66 .735 .905 r
.79859 .39607 .80127 .39979 .80752 .3978 .80486 .39415 Mtetra
.664 .741 .908 r
.80486 .39415 .80752 .3978 .81379 .39583 .81113 .39217 Mtetra
.665 .741 .907 r
.81113 .39217 .81379 .39583 .82006 .39384 .81742 .39016 Mtetra
.664 .74 .907 r
.81742 .39016 .82006 .39384 .82636 .39185 .82372 .38815 Mtetra
.82372 .38815 .82636 .39185 .83266 .38985 .83003 .38616 Mtetra
.661 .739 .908 r
.83003 .38616 .83266 .38985 .83898 .38782 .83637 .38421 Mtetra
.666 .746 .91 r
.83637 .38421 .83898 .38782 .84532 .38587 .84271 .38217 Mtetra
.663 .74 .908 r
.84271 .38217 .84532 .38587 .85166 .38385 .84907 .38018 Mtetra
.665 .743 .909 r
.84907 .38018 .85166 .38385 .85802 .38186 .85544 .37815 Mtetra
.663 .741 .908 r
.85544 .37815 .85802 .38186 .8644 .37985 .86182 .37614 Mtetra
.662 .741 .909 r
.86182 .37614 .8644 .37985 .87079 .37784 .86823 .37415 Mtetra
.666 .745 .909 r
.86823 .37415 .87079 .37784 .8772 .37587 .87464 .37209 Mtetra
.662 .738 .906 r
.87464 .37209 .8772 .37587 .88361 .3738 .88107 .37009 Mtetra
.663 .743 .91 r
.88107 .37009 .88361 .3738 .89004 .37178 .88751 .36807 Mtetra
.666 .745 .909 r
.88751 .36807 .89004 .37178 .89649 .36975 .89396 .36599 Mtetra
.664 .741 .908 r
.89396 .36599 .89649 .36975 .90294 .3677 .90043 .36395 Mtetra
.663 .742 .909 r
.90043 .36395 .90294 .3677 .90942 .36567 .90692 .36191 Mtetra
.664 .742 .908 r
.90692 .36191 .90942 .36567 .91591 .36362 .91341 .35984 Mtetra
.665 .742 .908 r
.91341 .35984 .91591 .36362 .92241 .3616 .91992 .35777 Mtetra
.662 .74 .908 r
.3348 .53824 .33812 .54135 .34342 .53973 .34011 .53659 Mtetra
.66 .738 .907 r
.34011 .53659 .34342 .53973 .34874 .53806 .34543 .53495 Mtetra
.664 .741 .907 r
.34543 .53495 .34874 .53806 .35406 .53635 .35076 .53326 Mtetra
.665 .743 .908 r
.35076 .53326 .35406 .53635 .35939 .53466 .3561 .53155 Mtetra
.663 .742 .909 r
.3561 .53155 .35939 .53466 .36474 .53297 .36145 .52987 Mtetra
.663 .743 .909 r
.36145 .52987 .36474 .53297 .3701 .53126 .36681 .52818 Mtetra
.667 .745 .909 r
.36681 .52818 .3701 .53126 .37546 .52962 .37219 .52644 Mtetra
.659 .737 .907 r
.37219 .52644 .37546 .52962 .38084 .52793 .37757 .5248 Mtetra
.665 .742 .908 r
.37757 .5248 .38084 .52793 .38623 .52619 .38296 .52308 Mtetra
.666 .744 .909 r
.38296 .52308 .38623 .52619 .39162 .52451 .38837 .52134 Mtetra
.663 .74 .907 r
.38837 .52134 .39162 .52451 .39703 .52279 .39379 .51964 Mtetra
.664 .742 .909 r
.39379 .51964 .39703 .52279 .40245 .52107 .39921 .51793 Mtetra
.663 .742 .909 r
.39921 .51793 .40245 .52107 .40788 .51937 .40465 .51622 Mtetra
.667 .744 .908 r
.40465 .51622 .40788 .51937 .41333 .51767 .4101 .51445 Mtetra
.661 .738 .907 r
.4101 .51445 .41333 .51767 .41878 .51593 .41556 .51277 Mtetra
.661 .742 .91 r
.41556 .51277 .41878 .51593 .42425 .51419 .42103 .51107 Mtetra
.661 .745 .913 r
.42103 .51107 .42425 .51419 .42972 .51246 .42651 .50937 Mtetra
.662 .748 .914 r
.42651 .50937 .42972 .51246 .43521 .51073 .43201 .50765 Mtetra
.666 .75 .913 r
.43201 .50765 .43521 .51073 .4407 .50904 .43751 .50586 Mtetra
.669 .745 .907 r
.43751 .50586 .4407 .50904 .44621 .50739 .44303 .50404 Mtetra
.651 .73 .906 r
.44303 .50404 .44621 .50739 .45173 .50554 .44855 .50247 Mtetra
.674 .754 .911 r
.44855 .50247 .45173 .50554 .45726 .50394 .4541 .50057 Mtetra
.644 .727 .908 r
.4541 .50057 .45726 .50394 .46281 .50205 .45964 .49909 Mtetra
.657 .758 .924 r
.45964 .49909 .46281 .50205 .46836 .50043 .4652 .49742 Mtetra
.663 .756 .919 r
.4652 .49742 .46836 .50043 .47392 .49885 .47077 .49565 Mtetra
.657 .743 .913 r
.47077 .49565 .47392 .49885 .4795 .49721 .47636 .49398 Mtetra
.644 .738 .917 r
.47636 .49398 .4795 .49721 .48509 .49543 .48195 .49248 Mtetra
.645 .757 .931 r
.48195 .49248 .48509 .49543 .49069 .49333 .48755 .49095 Mtetra
.69 .809 .938 r
.48755 .49095 .49069 .49333 .4963 .492 .49318 .48876 Mtetra
.673 .746 .905 r
.49318 .48876 .4963 .492 .50192 .49043 .49881 .48683 Mtetra
.645 .717 .9 r
.49881 .48683 .50192 .49043 .50756 .48802 .50445 .48533 Mtetra
.691 .788 .925 r
.50445 .48533 .50756 .48802 .5132 .48642 .51011 .48313 Mtetra
.651 .738 .913 r
.51011 .48313 .5132 .48642 .51886 .48491 .51577 .48151 Mtetra
.667 .737 .902 r
.51577 .48151 .51886 .48491 .52453 .48286 .52145 .47966 Mtetra
.667 .75 .912 r
.52145 .47966 .52453 .48286 .53021 .48115 .52714 .47782 Mtetra
.662 .74 .908 r
.52714 .47782 .53021 .48115 .53591 .47925 .53284 .47603 Mtetra
.651 .744 .918 r
.53284 .47603 .53591 .47925 .54161 .4774 .53855 .4744 Mtetra
.696 .771 .91 r
.53855 .4744 .54161 .4774 .54733 .47579 .54428 .47208 Mtetra
.636 .71 .9 r
.54428 .47208 .54733 .47579 .55306 .47364 .55002 .47069 Mtetra
.674 .77 .923 r
.55002 .47069 .55306 .47364 .5588 .47217 .55576 .46871 Mtetra
.678 .739 .897 r
.55576 .46871 .5588 .47217 .56455 .47036 .56152 .46666 Mtetra
.635 .711 .902 r
.56152 .46666 .56455 .47036 .57031 .46828 .5673 .46528 Mtetra
.678 .769 .919 r
.5673 .46528 .57031 .46828 .57609 .46674 .57308 .46322 Mtetra
.652 .728 .905 r
.57308 .46322 .57609 .46674 .58188 .46456 .57888 .46156 Mtetra
.674 .769 .922 r
.57888 .46156 .58188 .46456 .58768 .46301 .58469 .45956 Mtetra
.66 .736 .907 r
.58469 .45956 .58768 .46301 .59349 .46097 .59051 .45778 Mtetra
.678 .759 .912 r
.59051 .45778 .59349 .46097 .59932 .4595 .59634 .45571 Mtetra
.642 .711 .897 r
.59634 .45571 .59932 .4595 .60516 .45747 .60219 .45419 Mtetra
.66 .748 .916 r
.60219 .45419 .60516 .45747 .611 .45536 .60805 .45239 Mtetra
.658 .769 .931 r
.60805 .45239 .611 .45536 .61686 .45356 .61392 .45059 Mtetra
.66 .769 .931 r
.61392 .45059 .61686 .45356 .62274 .45195 .6198 .44876 Mtetra
.681 .762 .912 r
.6198 .44876 .62274 .45195 .62863 .45027 .62569 .44662 Mtetra
.67 .731 .895 r
.62569 .44662 .62863 .45027 .63452 .44811 .63159 .44464 Mtetra
.65 .735 .912 r
.63159 .44464 .63452 .44811 .64044 .44636 .63752 .44298 Mtetra
.675 .749 .907 r
.63752 .44298 .64044 .44636 .64636 .44445 .64344 .44092 Mtetra
.657 .735 .907 r
.64344 .44092 .64636 .44445 .6523 .44261 .64939 .43915 Mtetra
.653 .738 .912 r
.64939 .43915 .6523 .44261 .65823 .44044 .65536 .43743 Mtetra
.689 .78 .92 r
.65536 .43743 .65823 .44044 .66421 .43896 .66131 .43513 Mtetra
.641 .713 .899 r
.66131 .43513 .66421 .43896 .67018 .43697 .66731 .4336 Mtetra
.677 .754 .909 r
.66731 .4336 .67018 .43697 .67616 .43496 .67329 .4315 Mtetra
.673 .747 .906 r
.67329 .4315 .67616 .43496 .68217 .43335 .6793 .42945 Mtetra
.641 .71 .897 r
.6793 .42945 .68217 .43335 .68816 .43098 .68533 .42792 Mtetra
.686 .778 .921 r
.68533 .42792 .68816 .43098 .69421 .42951 .69135 .42565 Mtetra
.645 .715 .899 r
.69135 .42565 .69421 .42951 .70024 .42744 .69741 .42405 Mtetra
.68 .755 .908 r
.69741 .42405 .70024 .42744 .70629 .42565 .70346 .42187 Mtetra
.634 .715 .906 r
.70346 .42187 .70629 .42565 .71236 .42377 .70956 .42042 Mtetra
.692 .763 .906 r
.70956 .42042 .71236 .42377 .71843 .42177 .71561 .41803 Mtetra
.635 .719 .908 r
.71561 .41803 .71843 .42177 .7245 .4195 .72174 .41655 Mtetra
.664 .782 .936 r
.72174 .41655 .7245 .4195 .73064 .41821 .72785 .41457 Mtetra
.676 .742 .9 r
.72785 .41457 .73064 .41821 .73676 .41628 .73396 .41243 Mtetra
.625 .71 .907 r
.73396 .41243 .73676 .41628 .74285 .41377 .74014 .4111 Mtetra
.67 .805 .947 r
.74014 .4111 .74285 .41377 .74901 .41214 .74628 .40898 Mtetra
.682 .775 .922 r
.74628 .40898 .74901 .41214 .75517 .41026 .75242 .40673 Mtetra
.672 .748 .908 r
.75242 .40673 .75517 .41026 .76133 .40822 .75859 .40465 Mtetra
.664 .743 .909 r
.75859 .40465 .76133 .40822 .7675 .4061 .76478 .40268 Mtetra
.667 .755 .916 r
.76478 .40268 .7675 .4061 .77368 .40395 .77098 .40067 Mtetra
.679 .768 .918 r
.77098 .40067 .77368 .40395 .7799 .40214 .77718 .39844 Mtetra
.659 .735 .906 r
.77718 .39844 .7799 .40214 .78611 .4001 .78342 .39654 Mtetra
.672 .749 .909 r
.78342 .39654 .78611 .4001 .79235 .39817 .78965 .39444 Mtetra
.658 .734 .905 r
.78965 .39444 .79235 .39817 .79859 .39607 .79592 .39255 Mtetra
.663 .749 .914 r
.79592 .39255 .79859 .39607 .80486 .39415 .80219 .39057 Mtetra
.666 .747 .911 r
.80219 .39057 .80486 .39415 .81113 .39217 .80847 .38854 Mtetra
.665 .744 .909 r
.80847 .38854 .81113 .39217 .81742 .39016 .81476 .38652 Mtetra
.663 .743 .91 r
.81476 .38652 .81742 .39016 .82372 .38815 .82108 .38454 Mtetra
.664 .746 .911 r
.82108 .38454 .82372 .38815 .83003 .38616 .8274 .38252 Mtetra
.668 .746 .909 r
.8274 .38252 .83003 .38616 .83637 .38421 .83374 .38045 Mtetra
.659 .736 .907 r
.83374 .38045 .83637 .38421 .84271 .38217 .8401 .37852 Mtetra
.668 .747 .91 r
.8401 .37852 .84271 .38217 .84907 .38018 .84646 .37644 Mtetra
.662 .739 .908 r
.84646 .37644 .84907 .38018 .85544 .37815 .85284 .37446 Mtetra
.665 .744 .909 r
.85284 .37446 .85544 .37815 .86182 .37614 .85924 .37242 Mtetra
.664 .742 .908 r
.85924 .37242 .86182 .37614 .86823 .37415 .86565 .37038 Mtetra
.662 .739 .907 r
.86565 .37038 .86823 .37415 .87464 .37209 .87207 .36838 Mtetra
.66 .742 .911 r
.87207 .36838 .87464 .37209 .88107 .37009 .87852 .36639 Mtetra
.667 .746 .909 r
.87852 .36639 .88107 .37009 .88751 .36807 .88496 .36429 Mtetra
.664 .741 .907 r
.88496 .36429 .88751 .36807 .89396 .36599 .89143 .36223 Mtetra
.663 .741 .908 r
.89143 .36223 .89396 .36599 .90043 .36395 .89791 .36019 Mtetra
.665 .743 .908 r
.89791 .36019 .90043 .36395 .90692 .36191 .9044 .35811 Mtetra
.664 .741 .908 r
.9044 .35811 .90692 .36191 .91341 .35984 .91091 .35605 Mtetra
.662 .741 .909 r
.91091 .35605 .91341 .35984 .91992 .35777 .91744 .35401 Mtetra
.663 .743 .909 r
.33147 .53517 .3348 .53824 .34011 .53659 .33679 .53349 Mtetra
.663 .742 .909 r
.33679 .53349 .34011 .53659 .34543 .53495 .34211 .53181 Mtetra
.662 .739 .907 r
.34211 .53181 .34543 .53495 .35076 .53326 .34745 .53014 Mtetra
.666 .742 .907 r
.34745 .53014 .35076 .53326 .3561 .53155 .35279 .52842 Mtetra
.662 .74 .908 r
.35279 .52842 .3561 .53155 .36145 .52987 .35815 .52675 Mtetra
.66 .741 .91 r
.35815 .52675 .36145 .52987 .36681 .52818 .36352 .5251 Mtetra
.666 .745 .909 r
.36352 .5251 .36681 .52818 .37219 .52644 .3689 .52335 Mtetra
.665 .745 .91 r
.3689 .52335 .37219 .52644 .37757 .5248 .37429 .52162 Mtetra
.661 .739 .907 r
.37429 .52162 .37757 .5248 .38296 .52308 .37969 .51994 Mtetra
.665 .743 .908 r
.37969 .51994 .38296 .52308 .38837 .52134 .3851 .5182 Mtetra
.666 .744 .908 r
.3851 .5182 .38837 .52134 .39379 .51964 .39053 .51645 Mtetra
.658 .738 .909 r
.39053 .51645 .39379 .51964 .39921 .51793 .39596 .5148 Mtetra
.67 .746 .908 r
.39596 .5148 .39921 .51793 .40465 .51622 .40141 .51298 Mtetra
.658 .737 .908 r
.40141 .51298 .40465 .51622 .4101 .51445 .40686 .51134 Mtetra
.663 .746 .912 r
.40686 .51134 .4101 .51445 .41556 .51277 .41233 .50961 Mtetra
.665 .744 .909 r
.41233 .50961 .41556 .51277 .42103 .51107 .41781 .50786 Mtetra
.663 .741 .908 r
.41781 .50786 .42103 .51107 .42651 .50937 .4233 .50612 Mtetra
.662 .739 .907 r
.4233 .50612 .42651 .50937 .43201 .50765 .4288 .50441 Mtetra
.66 .739 .908 r
.4288 .50441 .43201 .50765 .43751 .50586 .43431 .50271 Mtetra
.662 .746 .912 r
.43431 .50271 .43751 .50586 .44303 .50404 .43983 .50098 Mtetra
.672 .755 .913 r
.43983 .50098 .44303 .50404 .44855 .50247 .44537 .49911 Mtetra
.647 .729 .908 r
.44537 .49911 .44855 .50247 .4541 .50057 .45091 .4976 Mtetra
.661 .758 .922 r
.45091 .4976 .4541 .50057 .45964 .49909 .45646 .49586 Mtetra
.679 .747 .902 r
.45646 .49586 .45964 .49909 .4652 .49742 .46204 .49385 Mtetra
.663 .723 .893 r
.46204 .49385 .4652 .49742 .47077 .49565 .46762 .49208 Mtetra
.66 .722 .895 r
.46762 .49208 .47077 .49565 .47636 .49398 .47321 .49037 Mtetra
.667 .722 .89 r
.47321 .49037 .47636 .49398 .48195 .49248 .47881 .48853 Mtetra
.617 .686 .892 r
.47881 .48853 .48195 .49248 .48755 .49095 .48442 .48746 Mtetra
.629 .718 .911 r
.48442 .48746 .48755 .49095 .49318 .48876 .49004 .48619 Mtetra
.718 .801 .917 r
.49004 .48619 .49318 .48876 .49881 .48683 .49569 .48356 Mtetra
.655 .741 .913 r
.49569 .48356 .49881 .48683 .50445 .48533 .50134 .4819 Mtetra
.661 .733 .903 r
.50134 .4819 .50445 .48533 .51011 .48313 .507 .48015 Mtetra
.695 .771 .91 r
.507 .48015 .51011 .48313 .51577 .48151 .51267 .47787 Mtetra
.619 .706 .908 r
.51267 .47787 .51577 .48151 .52145 .47966 .51836 .47673 Mtetra
.713 .779 .904 r
.51836 .47673 .52145 .47966 .52714 .47782 .52406 .47414 Mtetra
.618 .705 .907 r
.52406 .47414 .52714 .47782 .53284 .47603 .52976 .47301 Mtetra
.688 .768 .913 r
.52976 .47301 .53284 .47603 .53855 .4744 .53548 .47082 Mtetra
.655 .724 .9 r
.53548 .47082 .53855 .4744 .54428 .47208 .54122 .46913 Mtetra
.653 .764 .931 r
.54122 .46913 .54428 .47208 .55002 .47069 .54696 .46743 Mtetra
.695 .756 .899 r
.54696 .46743 .55002 .47069 .55576 .46871 .55271 .46509 Mtetra
.638 .718 .905 r
.55271 .46509 .55576 .46871 .56152 .46666 .55849 .46365 Mtetra
.672 .767 .922 r
.55849 .46365 .56152 .46666 .5673 .46528 .56427 .46168 Mtetra
.68 .734 .891 r
.56427 .46168 .5673 .46528 .57308 .46322 .57005 .45956 Mtetra
.624 .712 .909 r
.57005 .45956 .57308 .46322 .57888 .46156 .57587 .45831 Mtetra
.701 .761 .899 r
.57587 .45831 .57888 .46156 .58469 .45956 .58167 .45586 Mtetra
.628 .711 .906 r
.58167 .45586 .58469 .45956 .59051 .45778 .58751 .45455 Mtetra
.68 .757 .91 r
.58751 .45455 .59051 .45778 .59634 .45571 .59335 .45244 Mtetra
.677 .755 .91 r
.59335 .45244 .59634 .45571 .60219 .45419 .5992 .45037 Mtetra
.647 .712 .895 r
.5992 .45037 .60219 .45419 .60805 .45239 .60507 .44877 Mtetra
.662 .73 .899 r
.60507 .44877 .60805 .45239 .61392 .45059 .61095 .44693 Mtetra
.671 .731 .895 r
.61095 .44693 .61392 .45059 .6198 .44876 .61683 .44493 Mtetra
.671 .722 .887 r
.61683 .44493 .6198 .44876 .62569 .44662 .62273 .44292 Mtetra
.641 .718 .904 r
.62273 .44292 .62569 .44662 .63159 .44464 .62866 .4414 Mtetra
.689 .763 .908 r
.62866 .4414 .63159 .44464 .63752 .44298 .63457 .43911 Mtetra
.628 .705 .901 r
.63457 .43911 .63752 .44298 .64344 .44092 .64053 .43779 Mtetra
.7 .775 .909 r
.64053 .43779 .64344 .44092 .64939 .43915 .64647 .43532 Mtetra
.631 .709 .902 r
.64647 .43532 .64939 .43915 .65536 .43743 .65245 .43394 Mtetra
.681 .747 .901 r
.65245 .43394 .65536 .43743 .66131 .43513 .65842 .43175 Mtetra
.672 .751 .91 r
.65842 .43175 .66131 .43513 .66731 .4336 .6644 .42972 Mtetra
.636 .709 .899 r
.6644 .42972 .66731 .4336 .67329 .4315 .67043 .42825 Mtetra
.676 .762 .916 r
.67043 .42825 .67329 .4315 .6793 .42945 .67643 .42614 Mtetra
.657 .752 .92 r
.67643 .42614 .6793 .42945 .68533 .42792 .68247 .42432 Mtetra
.648 .731 .91 r
.68247 .42432 .68533 .42792 .69135 .42565 .68852 .42265 Mtetra
.7 .787 .918 r
.68852 .42265 .69135 .42565 .69741 .42405 .69455 .42015 Mtetra
.625 .705 .903 r
.69455 .42015 .69741 .42405 .70346 .42187 .70065 .41883 Mtetra
.701 .786 .918 r
.70065 .41883 .70346 .42187 .70956 .42042 .7067 .41631 Mtetra
.632 .697 .892 r
.7067 .41631 .70956 .42042 .71561 .41803 .71282 .4149 Mtetra
.66 .768 .929 r
.71282 .4149 .71561 .41803 .72174 .41655 .71893 .41299 Mtetra
.691 .752 .898 r
.71893 .41299 .72174 .41655 .72785 .41457 .72502 .41058 Mtetra
.593 .688 .908 r
.72502 .41058 .72785 .41457 .73396 .41243 .73123 .40973 Mtetra
.681 .807 .942 r
.73123 .40973 .73396 .41243 .74014 .4111 .73735 .40746 Mtetra
.707 .754 .889 r
.73735 .40746 .74014 .4111 .74628 .40898 .74346 .40474 Mtetra
.666 .706 .877 r
.74346 .40474 .74628 .40898 .75242 .40673 .74963 .40271 Mtetra
.664 .718 .889 r
.74963 .40271 .75242 .40673 .75859 .40465 .75582 .40074 Mtetra
.668 .726 .893 r
.75582 .40074 .75859 .40465 .76478 .40268 .76201 .39869 Mtetra
.648 .714 .896 r
.76201 .39869 .76478 .40268 .77098 .40067 .76824 .39698 Mtetra
.66 .737 .907 r
.76824 .39698 .77098 .40067 .77718 .39844 .77448 .39506 Mtetra
.684 .765 .913 r
.77448 .39506 .77718 .39844 .78342 .39654 .78069 .39275 Mtetra
.651 .727 .905 r
.78069 .39275 .78342 .39654 .78965 .39444 .78696 .39097 Mtetra
.67 .756 .915 r
.78696 .39097 .78965 .39444 .79592 .39255 .79322 .38888 Mtetra
.669 .743 .905 r
.79322 .38888 .79592 .39255 .80219 .39057 .79949 .38679 Mtetra
.664 .735 .903 r
.79949 .38679 .80219 .39057 .80847 .38854 .80578 .38478 Mtetra
.663 .736 .904 r
.80578 .38478 .80847 .38854 .81476 .38652 .81209 .38279 Mtetra
.663 .739 .906 r
.81209 .38279 .81476 .38652 .82108 .38454 .81842 .3808 Mtetra
.659 .737 .907 r
.81842 .3808 .82108 .38454 .8274 .38252 .82476 .37887 Mtetra
.666 .745 .909 r
.82476 .37887 .8274 .38252 .83374 .38045 .83111 .37682 Mtetra
.665 .747 .911 r
.83111 .37682 .83374 .38045 .8401 .37852 .83747 .37477 Mtetra
.662 .739 .907 r
.83747 .37477 .8401 .37852 .84646 .37644 .84385 .37278 Mtetra
.665 .746 .91 r
.84385 .37278 .84646 .37644 .85284 .37446 .85024 .37072 Mtetra
.664 .742 .908 r
.85024 .37072 .85284 .37446 .85924 .37242 .85664 .36868 Mtetra
.85664 .36868 .85924 .37242 .86565 .37038 .86306 .36664 Mtetra
.659 .74 .91 r
.86306 .36664 .86565 .37038 .87207 .36838 .8695 .36467 Mtetra
.665 .745 .91 r
.8695 .36467 .87207 .36838 .87852 .36639 .87595 .3626 Mtetra
.668 .742 .906 r
.87595 .3626 .87852 .36639 .88496 .36429 .8824 .36048 Mtetra
.661 .739 .908 r
.8824 .36048 .88496 .36429 .89143 .36223 .88888 .35848 Mtetra
.664 .744 .909 r
.88888 .35848 .89143 .36223 .89791 .36019 .89537 .35641 Mtetra
.665 .743 .908 r
.89537 .35641 .89791 .36019 .9044 .35811 .90188 .35432 Mtetra
.664 .742 .908 r
.90188 .35432 .9044 .35811 .91091 .35605 .90839 .35224 Mtetra
.66 .74 .909 r
.90839 .35224 .91091 .35605 .91744 .35401 .91494 .35023 Mtetra
.662 .742 .909 r
.32813 .53207 .33147 .53517 .33679 .53349 .33345 .5304 Mtetra
.667 .744 .908 r
.33345 .5304 .33679 .53349 .34211 .53181 .33878 .52866 Mtetra
.66 .739 .908 r
.33878 .52866 .34211 .53181 .34745 .53014 .34412 .52702 Mtetra
.664 .742 .908 r
.34412 .52702 .34745 .53014 .35279 .52842 .34948 .5253 Mtetra
.664 .743 .909 r
.34948 .5253 .35279 .52842 .35815 .52675 .35484 .52358 Mtetra
.657 .739 .91 r
.35484 .52358 .35815 .52675 .36352 .5251 .36021 .52197 Mtetra
.664 .743 .909 r
.36021 .52197 .36352 .5251 .3689 .52335 .3656 .52026 Mtetra
.671 .747 .908 r
.3656 .52026 .3689 .52335 .37429 .52162 .371 .51843 Mtetra
.661 .739 .908 r
.371 .51843 .37429 .52162 .37969 .51994 .37641 .51675 Mtetra
.661 .74 .908 r
.37641 .51675 .37969 .51994 .3851 .5182 .38182 .51506 Mtetra
.665 .744 .909 r
.38182 .51506 .3851 .5182 .39053 .51645 .38725 .51332 Mtetra
.662 .744 .911 r
.38725 .51332 .39053 .51645 .39596 .5148 .39269 .51161 Mtetra
.665 .742 .907 r
.39269 .51161 .39596 .5148 .40141 .51298 .39815 .50985 Mtetra
.658 .744 .913 r
.39815 .50985 .40141 .51298 .40686 .51134 .40361 .50819 Mtetra
.668 .746 .908 r
.40361 .50819 .40686 .51134 .41233 .50961 .40908 .50638 Mtetra
.665 .74 .906 r
.40908 .50638 .41233 .50961 .41781 .50786 .41457 .50461 Mtetra
.664 .74 .906 r
.41457 .50461 .41781 .50786 .4233 .50612 .42007 .50285 Mtetra
.665 .738 .905 r
.42007 .50285 .4233 .50612 .4288 .50441 .42558 .50107 Mtetra
.656 .732 .906 r
.42558 .50107 .4288 .50441 .43431 .50271 .43109 .49943 Mtetra
.651 .735 .911 r
.43109 .49943 .43431 .50271 .43983 .50098 .43662 .49786 Mtetra
.677 .752 .908 r
.43662 .49786 .43983 .50098 .44537 .49911 .44216 .4959 Mtetra
.64 .737 .919 r
.44216 .4959 .44537 .49911 .45091 .4976 .44771 .49445 Mtetra
.683 .753 .905 r
.44771 .49445 .45091 .4976 .45646 .49586 .45328 .49239 Mtetra
.654 .726 .902 r
.45328 .49239 .45646 .49586 .46204 .49385 .45885 .49077 Mtetra
.638 .746 .927 r
.45885 .49077 .46204 .49385 .46762 .49208 .46444 .48933 Mtetra
.647 .772 .939 r
.46444 .48933 .46762 .49208 .47321 .49037 .47003 .48773 Mtetra
.671 .787 .936 r
.47003 .48773 .47321 .49037 .47881 .48853 .47565 .48581 Mtetra
.698 .787 .92 r
.47565 .48581 .47881 .48853 .48442 .48746 .48128 .4835 Mtetra
.574 .67 .904 r
.48128 .4835 .48442 .48746 .49004 .48619 .4869 .48298 Mtetra
.673 .75 .909 r
.4869 .48298 .49004 .48619 .49569 .48356 .49254 .48104 Mtetra
.727 .807 .915 r
.49254 .48104 .49569 .48356 .50134 .4819 .49821 .47826 Mtetra
.636 .713 .903 r
.49821 .47826 .50134 .4819 .507 .48015 .50388 .47688 Mtetra
.667 .746 .909 r
.50388 .47688 .507 .48015 .51267 .47787 .50956 .47502 Mtetra
.644 .767 .938 r
.50956 .47502 .51267 .47787 .51836 .47673 .51525 .47344 Mtetra
.702 .755 .893 r
.51525 .47344 .51836 .47673 .52406 .47414 .52096 .47099 Mtetra
.629 .743 .93 r
.52096 .47099 .52406 .47414 .52976 .47301 .52667 .46963 Mtetra
.7 .75 .891 r
.52667 .46963 .52976 .47301 .53548 .47082 .5324 .4672 Mtetra
.629 .714 .908 r
.5324 .4672 .53548 .47082 .54122 .46913 .53814 .46589 Mtetra
.67 .751 .911 r
.53814 .46589 .54122 .46913 .54696 .46743 .5439 .46396 Mtetra
.674 .739 .899 r
.5439 .46396 .54696 .46743 .55271 .46509 .54966 .46197 Mtetra
.642 .75 .928 r
.54966 .46197 .55271 .46509 .55849 .46365 .55544 .46043 Mtetra
.697 .761 .901 r
.55544 .46043 .55849 .46365 .56427 .46168 .56122 .45805 Mtetra
.652 .723 .901 r
.56122 .45805 .56427 .46168 .57005 .45956 .56702 .45639 Mtetra
.645 .75 .926 r
.56702 .45639 .57005 .45956 .57587 .45831 .57284 .4548 Mtetra
.681 .741 .896 r
.57284 .4548 .57587 .45831 .58167 .45586 .57866 .45266 Mtetra
.642 .748 .925 r
.57866 .45266 .58167 .45586 .58751 .45455 .5845 .45109 Mtetra
.662 .739 .907 r
.5845 .45109 .58751 .45455 .59335 .45244 .59035 .44926 Mtetra
.69 .765 .909 r
.59035 .44926 .59335 .45244 .5992 .45037 .59621 .44698 Mtetra
.665 .745 .909 r
.59621 .44698 .5992 .45037 .60507 .44877 .60208 .44509 Mtetra
.665 .727 .896 r
.60208 .44509 .60507 .44877 .61095 .44693 .60796 .44318 Mtetra
.666 .725 .893 r
.60796 .44318 .61095 .44693 .61683 .44493 .61386 .44127 Mtetra
.643 .722 .905 r
.61386 .44127 .61683 .44493 .62273 .44292 .61978 .43971 Mtetra
.657 .756 .923 r
.61978 .43971 .62273 .44292 .62866 .4414 .62571 .43792 Mtetra
.68 .746 .901 r
.62571 .43792 .62866 .4414 .63457 .43911 .63164 .43577 Mtetra
.629 .738 .926 r
.63164 .43577 .63457 .43911 .64053 .43779 .6376 .43437 Mtetra
.696 .756 .898 r
.6376 .43437 .64053 .43779 .64647 .43532 .64354 .43193 Mtetra
.649 .743 .918 r
.64354 .43193 .64647 .43532 .65245 .43394 .64953 .43024 Mtetra
.656 .727 .901 r
.64953 .43024 .65245 .43394 .65842 .43175 .65552 .42846 Mtetra
.682 .761 .911 r
.65552 .42846 .65842 .43175 .6644 .42972 .66151 .42626 Mtetra
.635 .735 .92 r
.66151 .42626 .6644 .42972 .67043 .42825 .66754 .42477 Mtetra
.661 .743 .911 r
.66754 .42477 .67043 .42825 .67643 .42614 .67356 .42288 Mtetra
.685 .765 .913 r
.67356 .42288 .67643 .42614 .68247 .42432 .67959 .42062 Mtetra
.626 .718 .912 r
.67959 .42062 .68247 .42432 .68852 .42265 .68567 .41927 Mtetra
.708 .766 .898 r
.68567 .41927 .68852 .42265 .69455 .42015 .69169 .4166 Mtetra
.607 .72 .925 r
.69169 .4166 .69455 .42015 .70065 .41883 .69781 .41548 Mtetra
.696 .765 .905 r
.69781 .41548 .70065 .41883 .7067 .41631 .70387 .41301 Mtetra
.638 .749 .929 r
.70387 .41301 .7067 .41631 .71282 .4149 .71 .41143 Mtetra
.681 .754 .907 r
.71 .41143 .71282 .4149 .71893 .41299 .7161 .4092 Mtetra
.631 .717 .909 r
.7161 .4092 .71893 .41299 .72502 .41058 .72226 .40777 Mtetra
.61 .775 .959 r
.72226 .40777 .72502 .41058 .73123 .40973 .72844 .40642 Mtetra
.732 .782 .893 r
.72844 .40642 .73123 .40973 .73735 .40746 .73452 .40327 Mtetra
.652 .704 .885 r
.73452 .40327 .73735 .40746 .74346 .40474 .74071 .40149 Mtetra
.645 .758 .931 r
.74071 .40149 .74346 .40474 .74963 .40271 .74691 .39978 Mtetra
.671 .789 .938 r
.74691 .39978 .74963 .40271 .75582 .40074 .75309 .39766 Mtetra
.683 .784 .927 r
.75309 .39766 .75582 .40074 .76201 .39869 .75928 .39537 Mtetra
.683 .768 .916 r
.75928 .39537 .76201 .39869 .76824 .39698 .76548 .39307 Mtetra
.641 .717 .903 r
.76548 .39307 .76824 .39698 .77448 .39506 .77174 .39146 Mtetra
.676 .749 .906 r
.77174 .39146 .77448 .39506 .78069 .39275 .77798 .38928 Mtetra
.659 .751 .918 r
.77798 .38928 .78069 .39275 .78696 .39097 .78425 .38735 Mtetra
.679 .75 .905 r
.78425 .38735 .78696 .39097 .79322 .38888 .7905 .38509 Mtetra
.66 .734 .904 r
.7905 .38509 .79322 .38888 .79949 .38679 .7968 .38315 Mtetra
.662 .744 .911 r
.7968 .38315 .79949 .38679 .80578 .38478 .8031 .38117 Mtetra
.664 .747 .912 r
.8031 .38117 .80578 .38478 .81209 .38279 .80942 .37915 Mtetra
.667 .746 .91 r
.80942 .37915 .81209 .38279 .81842 .3808 .81575 .37709 Mtetra
.66 .74 .909 r
.81575 .37709 .81842 .3808 .82476 .37887 .8221 .37513 Mtetra
.66 .739 .908 r
.8221 .37513 .82476 .37887 .83111 .37682 .82847 .37316 Mtetra
.673 .75 .908 r
.82847 .37316 .83111 .37682 .83747 .37477 .83482 .37098 Mtetra
.655 .734 .908 r
.83482 .37098 .83747 .37477 .84385 .37278 .84123 .36909 Mtetra
.67 .747 .908 r
.84123 .36909 .84385 .37278 .85024 .37072 .84762 .36694 Mtetra
.662 .739 .907 r
.84762 .36694 .85024 .37072 .85664 .36868 .85403 .36493 Mtetra
.661 .741 .909 r
.85403 .36493 .85664 .36868 .86306 .36664 .86047 .36292 Mtetra
.662 .744 .911 r
.86047 .36292 .86306 .36664 .8695 .36467 .86692 .3609 Mtetra
.668 .744 .907 r
.86692 .3609 .8695 .36467 .87595 .3626 .87337 .35877 Mtetra
.661 .738 .906 r
.87337 .35877 .87595 .3626 .8824 .36048 .87984 .35674 Mtetra
.661 .744 .911 r
.87984 .35674 .8824 .36048 .88888 .35848 .88633 .35472 Mtetra
.665 .745 .909 r
.88633 .35472 .88888 .35848 .89537 .35641 .89283 .35262 Mtetra
.666 .744 .908 r
.89283 .35262 .89537 .35641 .90188 .35432 .89934 .35051 Mtetra
.665 .742 .908 r
.89934 .35051 .90188 .35432 .90839 .35224 .90587 .34841 Mtetra
.658 .739 .909 r
.90587 .34841 .90839 .35224 .91494 .35023 .91243 .34641 Mtetra
.661 .742 .91 r
.32477 .52896 .32813 .53207 .33345 .5304 .33009 .52729 Mtetra
.667 .744 .908 r
.33009 .52729 .33345 .5304 .33878 .52866 .33544 .52555 Mtetra
.661 .742 .91 r
.33544 .52555 .33878 .52866 .34412 .52702 .34078 .52388 Mtetra
.663 .742 .908 r
.34078 .52388 .34412 .52702 .34948 .5253 .34614 .52218 Mtetra
.668 .744 .908 r
.34614 .52218 .34948 .5253 .35484 .52358 .35152 .52041 Mtetra
.655 .738 .911 r
.35152 .52041 .35484 .52358 .36021 .52197 .35689 .51882 Mtetra
.662 .742 .91 r
.35689 .51882 .36021 .52197 .3656 .52026 .36228 .51713 Mtetra
.671 .746 .907 r
.36228 .51713 .3656 .52026 .371 .51843 .36769 .5153 Mtetra
.662 .744 .911 r
.36769 .5153 .371 .51843 .37641 .51675 .37311 .51359 Mtetra
.661 .742 .91 r
.37311 .51359 .37641 .51675 .38182 .51506 .37853 .51189 Mtetra
.663 .742 .909 r
.37853 .51189 .38182 .51506 .38725 .51332 .38397 .51016 Mtetra
.665 .744 .909 r
.38397 .51016 .38725 .51332 .39269 .51161 .38942 .5084 Mtetra
.66 .74 .909 r
.38942 .5084 .39269 .51161 .39815 .50985 .39488 .50671 Mtetra
.661 .745 .912 r
.39488 .50671 .39815 .50985 .40361 .50819 .40034 .50501 Mtetra
.671 .745 .906 r
.40034 .50501 .40361 .50819 .40908 .50638 .40583 .50315 Mtetra
.663 .741 .908 r
.40583 .50315 .40908 .50638 .41457 .50461 .41132 .50141 Mtetra
.663 .743 .91 r
.41132 .50141 .41457 .50461 .42007 .50285 .41682 .49967 Mtetra
.665 .745 .91 r
.41682 .49967 .42007 .50285 .42558 .50107 .42234 .49789 Mtetra
.663 .745 .911 r
.42234 .49789 .42558 .50107 .43109 .49943 .42787 .49614 Mtetra
.643 .733 .914 r
.42787 .49614 .43109 .49943 .43662 .49786 .4334 .49466 Mtetra
.67 .747 .908 r
.4334 .49466 .43662 .49786 .44216 .4959 .43895 .4928 Mtetra
.648 .747 .922 r
.43895 .4928 .44216 .4959 .44771 .49445 .4445 .49124 Mtetra
.691 .752 .898 r
.4445 .49124 .44771 .49445 .45328 .49239 .45009 .48902 Mtetra
.625 .724 .918 r
.45009 .48902 .45328 .49239 .45885 .49077 .45566 .48779 Mtetra
.632 .752 .934 r
.45566 .48779 .45885 .49077 .46444 .48933 .46124 .4864 Mtetra
.642 .758 .933 r
.46124 .4864 .46444 .48933 .47003 .48773 .46685 .48489 Mtetra
.664 .771 .929 r
.46685 .48489 .47003 .48773 .47565 .48581 .47247 .48307 Mtetra
.723 .791 .906 r
.47247 .48307 .47565 .48581 .48128 .4835 .47811 .48033 Mtetra
.556 .713 .945 r
.47811 .48033 .48128 .4835 .4869 .48298 .48374 .47981 Mtetra
.64 .743 .923 r
.48374 .47981 .4869 .48298 .49254 .48104 .48939 .47833 Mtetra
.76 .8 .885 r
.48939 .47833 .49254 .48104 .49821 .47826 .49507 .47486 Mtetra
.617 .722 .92 r
.49507 .47486 .49821 .47826 .50388 .47688 .50074 .47369 Mtetra
.662 .75 .916 r
.50074 .47369 .50388 .47688 .50956 .47502 .50643 .47191 Mtetra
.652 .753 .924 r
.50643 .47191 .50956 .47502 .51525 .47344 .51213 .47025 Mtetra
.709 .763 .895 r
.51213 .47025 .51525 .47344 .52096 .47099 .51785 .46769 Mtetra
.632 .734 .922 r
.51785 .46769 .52096 .47099 .52667 .46963 .52357 .46631 Mtetra
.704 .755 .892 r
.52357 .46631 .52667 .46963 .5324 .4672 .52931 .46381 Mtetra
.623 .726 .921 r
.52931 .46381 .5324 .4672 .53814 .46589 .53506 .46255 Mtetra
.669 .746 .908 r
.53506 .46255 .53814 .46589 .5439 .46396 .54082 .46063 Mtetra
.675 .748 .906 r
.54082 .46063 .5439 .46396 .54966 .46197 .54659 .45861 Mtetra
.638 .735 .919 r
.54659 .45861 .54966 .46197 .55544 .46043 .55238 .45715 Mtetra
.706 .761 .895 r
.55238 .45715 .55544 .46043 .56122 .45805 .55817 .4546 Mtetra
.645 .733 .913 r
.55817 .4546 .56122 .45805 .56702 .45639 .56398 .45303 Mtetra
.649 .74 .915 r
.56398 .45303 .56702 .45639 .57284 .4548 .5698 .45138 Mtetra
.681 .747 .901 r
.5698 .45138 .57284 .4548 .57866 .45266 .57563 .44923 Mtetra
.64 .734 .917 r
.57563 .44923 .57866 .45266 .5845 .45109 .58148 .44772 Mtetra
.66 .744 .912 r
.58148 .44772 .5845 .45109 .59035 .44926 .58734 .4459 Mtetra
.691 .755 .9 r
.58734 .4459 .59035 .44926 .59621 .44698 .5932 .44358 Mtetra
.668 .746 .908 r
.5932 .44358 .59621 .44698 .60208 .44509 .59908 .44163 Mtetra
.668 .743 .906 r
.59908 .44163 .60208 .44509 .60796 .44318 .60497 .43968 Mtetra
.66 .738 .908 r
.60497 .43968 .60796 .44318 .61386 .44127 .61088 .43786 Mtetra
.641 .737 .919 r
.61088 .43786 .61386 .44127 .61978 .43971 .61681 .43631 Mtetra
.66 .745 .913 r
.61681 .43631 .61978 .43971 .62571 .43792 .62275 .43447 Mtetra
.679 .749 .904 r
.62275 .43447 .62571 .43792 .63164 .43577 .62868 .43232 Mtetra
.628 .732 .922 r
.62868 .43232 .63164 .43577 .6376 .43437 .63466 .43094 Mtetra
.7 .757 .896 r
.63466 .43094 .6376 .43437 .64354 .43193 .64061 .42842 Mtetra
.652 .737 .912 r
.64061 .42842 .64354 .43193 .64953 .43024 .6466 .42668 Mtetra
.647 .733 .912 r
.6466 .42668 .64953 .43024 .65552 .42846 .6526 .42503 Mtetra
.682 .753 .905 r
.6526 .42503 .65552 .42846 .66151 .42626 .6586 .42281 Mtetra
.633 .735 .922 r
.6586 .42281 .66151 .42626 .66754 .42477 .66464 .42134 Mtetra
.663 .748 .913 r
.66464 .42134 .66754 .42477 .67356 .42288 .67067 .41942 Mtetra
.686 .754 .903 r
.67067 .41942 .67356 .42288 .67959 .42062 .6767 .41712 Mtetra
.619 .728 .924 r
.6767 .41712 .67959 .42062 .68567 .41927 .6828 .41584 Mtetra
.713 .765 .893 r
.6828 .41584 .68567 .41927 .69169 .4166 .68883 .41306 Mtetra
.59 .714 .929 r
.68883 .41306 .69169 .4166 .69781 .41548 .69497 .41214 Mtetra
.696 .767 .906 r
.69497 .41214 .69781 .41548 .70387 .41301 .70104 .40966 Mtetra
.645 .75 .925 r
.70104 .40966 .70387 .41301 .71 .41143 .70717 .40798 Mtetra
.687 .758 .906 r
.70717 .40798 .71 .41143 .7161 .4092 .71327 .40565 Mtetra
.588 .714 .931 r
.71327 .40565 .7161 .4092 .72226 .40777 .71947 .40475 Mtetra
.639 .771 .943 r
.71947 .40475 .72226 .40777 .72844 .40642 .72565 .40309 Mtetra
.756 .787 .879 r
.72565 .40309 .72844 .40642 .73452 .40327 .73171 .39942 Mtetra
.598 .701 .915 r
.73171 .39942 .73452 .40327 .74071 .40149 .73795 .39844 Mtetra
.65 .774 .939 r
.73795 .39844 .74071 .40149 .74691 .39978 .74415 .39662 Mtetra
.679 .777 .925 r
.74415 .39662 .74691 .39978 .75309 .39766 .75034 .39439 Mtetra
.687 .774 .917 r
.75034 .39439 .75309 .39766 .75928 .39537 .75654 .39204 Mtetra
.697 .773 .91 r
.75654 .39204 .75928 .39537 .76548 .39307 .76273 .3895 Mtetra
.645 .739 .918 r
.76273 .3895 .76548 .39307 .77174 .39146 .769 .3878 Mtetra
.665 .743 .908 r
.769 .3878 .77174 .39146 .77798 .38928 .77525 .38577 Mtetra
.669 .754 .914 r
.77525 .38577 .77798 .38928 .78425 .38735 .78152 .38368 Mtetra
.678 .747 .903 r
.78152 .38368 .78425 .38735 .7905 .38509 .78779 .38143 Mtetra
.655 .74 .912 r
.78779 .38143 .7905 .38509 .7968 .38315 .7941 .37956 Mtetra
.663 .748 .913 r
.7941 .37956 .7968 .38315 .8031 .38117 .80041 .37756 Mtetra
.665 .748 .912 r
.80041 .37756 .8031 .38117 .80942 .37915 .80674 .37552 Mtetra
.67 .749 .91 r
.80674 .37552 .80942 .37915 .81575 .37709 .81307 .3734 Mtetra
.663 .744 .91 r
.81307 .3734 .81575 .37709 .8221 .37513 .81943 .37138 Mtetra
.656 .738 .91 r
.81943 .37138 .8221 .37513 .82847 .37316 .82581 .36947 Mtetra
.673 .748 .907 r
.82581 .36947 .82847 .37316 .83482 .37098 .83218 .36727 Mtetra
.655 .741 .913 r
.83218 .36727 .83482 .37098 .84123 .36909 .83859 .36537 Mtetra
.671 .746 .907 r
.83859 .36537 .84123 .36909 .84762 .36694 .84499 .36321 Mtetra
.661 .742 .91 r
.84499 .36321 .84762 .36694 .85403 .36493 .85142 .3612 Mtetra
.662 .744 .911 r
.85142 .3612 .85403 .36493 .86047 .36292 .85786 .35916 Mtetra
.663 .743 .909 r
.85786 .35916 .86047 .36292 .86692 .3609 .86432 .35711 Mtetra
.67 .745 .906 r
.86432 .35711 .86692 .3609 .87337 .35877 .87077 .35493 Mtetra
.657 .736 .908 r
.87077 .35493 .87337 .35877 .87984 .35674 .87727 .35298 Mtetra
.661 .743 .911 r
.87727 .35298 .87984 .35674 .88633 .35472 .88377 .35094 Mtetra
.667 .745 .909 r
.88377 .35094 .88633 .35472 .89283 .35262 .89028 .34881 Mtetra
.666 .744 .908 r
.89028 .34881 .89283 .35262 .89934 .35051 .8968 .34669 Mtetra
.664 .743 .908 r
.8968 .34669 .89934 .35051 .90587 .34841 .90334 .34459 Mtetra
.659 .741 .91 r
.90334 .34459 .90587 .34841 .91243 .34641 .9099 .34258 Mtetra
.661 .741 .91 r
.3214 .52583 .32477 .52896 .33009 .52729 .32673 .52416 Mtetra
.667 .743 .907 r
.32673 .52416 .33009 .52729 .33544 .52555 .33208 .52241 Mtetra
.661 .741 .91 r
.33208 .52241 .33544 .52555 .34078 .52388 .33743 .52074 Mtetra
.663 .742 .909 r
.33743 .52074 .34078 .52388 .34614 .52218 .3428 .51904 Mtetra
.668 .744 .907 r
.3428 .51904 .34614 .52218 .35152 .52041 .34818 .51726 Mtetra
.653 .739 .913 r
.34818 .51726 .35152 .52041 .35689 .51882 .35356 .51569 Mtetra
.662 .744 .911 r
.35356 .51569 .35689 .51882 .36228 .51713 .35896 .51399 Mtetra
.672 .746 .906 r
.35896 .51399 .36228 .51713 .36769 .5153 .36438 .51213 Mtetra
.662 .742 .909 r
.36438 .51213 .36769 .5153 .37311 .51359 .3698 .51042 Mtetra
.661 .742 .91 r
.3698 .51042 .37311 .51359 .37853 .51189 .37523 .50873 Mtetra
.663 .743 .91 r
.37523 .50873 .37853 .51189 .38397 .51016 .38067 .50699 Mtetra
.665 .744 .909 r
.38067 .50699 .38397 .51016 .38942 .5084 .38613 .50522 Mtetra
.66 .742 .911 r
.38613 .50522 .38942 .5084 .39488 .50671 .39159 .50353 Mtetra
.66 .743 .911 r
.39159 .50353 .39488 .50671 .40034 .50501 .39707 .50183 Mtetra
.673 .747 .907 r
.39707 .50183 .40034 .50501 .40583 .50315 .40256 .49994 Mtetra
.663 .743 .909 r
.40256 .49994 .40583 .50315 .41132 .50141 .40806 .49819 Mtetra
.662 .743 .91 r
.40806 .49819 .41132 .50141 .41682 .49967 .41357 .49645 Mtetra
.666 .744 .908 r
.41357 .49645 .41682 .49967 .42234 .49789 .41909 .49465 Mtetra
.662 .742 .91 r
.41909 .49465 .42234 .49789 .42787 .49614 .42463 .49291 Mtetra
.638 .736 .919 r
.42463 .49291 .42787 .49614 .4334 .49466 .43016 .4915 Mtetra
.672 .75 .909 r
.43016 .4915 .4334 .49466 .43895 .4928 .43572 .48959 Mtetra
.643 .74 .919 r
.43572 .48959 .43895 .4928 .4445 .49124 .44128 .4881 Mtetra
.7 .759 .898 r
.44128 .4881 .4445 .49124 .45009 .48902 .44687 .48574 Mtetra
.614 .726 .925 r
.44687 .48574 .45009 .48902 .45566 .48779 .45245 .48461 Mtetra
.626 .738 .928 r
.45245 .48461 .45566 .48779 .46124 .4864 .45804 .48333 Mtetra
.639 .749 .928 r
.45804 .48333 .46124 .4864 .46685 .48489 .46365 .48187 Mtetra
.671 .762 .919 r
.46365 .48187 .46685 .48489 .47247 .48307 .46928 .47996 Mtetra
.735 .771 .882 r
.46928 .47996 .47247 .48307 .47811 .48033 .47494 .47692 Mtetra
.469 .66 .945 r
.47494 .47692 .47811 .48033 .48374 .47981 .48056 .47725 Mtetra
.656 .791 .947 r
.48056 .47725 .48374 .47981 .48939 .47833 .48622 .47548 Mtetra
.754 .791 .883 r
.48622 .47548 .48939 .47833 .49507 .47486 .49192 .47208 Mtetra
.621 .766 .949 r
.49192 .47208 .49507 .47486 .50074 .47369 .4976 .47075 Mtetra
.697 .776 .913 r
.4976 .47075 .50074 .47369 .50643 .47191 .5033 .46842 Mtetra
.606 .714 .921 r
.5033 .46842 .50643 .47191 .51213 .47025 .509 .4674 Mtetra
.747 .792 .889 r
.509 .4674 .51213 .47025 .51785 .46769 .51473 .46414 Mtetra
.6 .709 .92 r
.51473 .46414 .51785 .46769 .52357 .46631 .52046 .46319 Mtetra
.698 .767 .905 r
.52046 .46319 .52357 .46631 .52931 .46381 .5262 .46081 Mtetra
.65 .762 .931 r
.5262 .46081 .52931 .46381 .53506 .46255 .53196 .45914 Mtetra
.644 .734 .914 r
.53196 .45914 .53506 .46255 .54082 .46063 .53773 .45758 Mtetra
.711 .776 .904 r
.53773 .45758 .54082 .46063 .54659 .45861 .54351 .45498 Mtetra
.615 .711 .913 r
.54351 .45498 .54659 .45861 .55238 .45715 .5493 .45384 Mtetra
.701 .759 .897 r
.5493 .45384 .55238 .45715 .55817 .4546 .5551 .45137 Mtetra
.67 .755 .914 r
.5551 .45137 .55817 .4546 .56398 .45303 .56092 .4494 Mtetra
.622 .715 .913 r
.56092 .4494 .56398 .45303 .5698 .45138 .56676 .44816 Mtetra
.708 .767 .899 r
.56676 .44816 .5698 .45138 .57563 .44923 .57259 .44557 Mtetra
.609 .708 .915 r
.57259 .44557 .57563 .44923 .58148 .44772 .57845 .4445 Mtetra
.681 .761 .912 r
.57845 .4445 .58148 .44772 .58734 .4459 .58431 .44236 Mtetra
.695 .746 .891 r
.58431 .44236 .58734 .4459 .5932 .44358 .59018 .43995 Mtetra
.639 .723 .909 r
.59018 .43995 .5932 .44358 .59908 .44163 .59608 .43845 Mtetra
.669 .761 .919 r
.59608 .43845 .59908 .44163 .60497 .43968 .60198 .43647 Mtetra
.676 .762 .916 r
.60198 .43647 .60497 .43968 .61088 .43786 .60789 .43438 Mtetra
.652 .738 .912 r
.60789 .43438 .61088 .43786 .61681 .43631 .61382 .43266 Mtetra
.642 .724 .908 r
.61382 .43266 .61681 .43631 .62275 .43447 .61977 .4311 Mtetra
.7 .761 .899 r
.61977 .4311 .62275 .43447 .62868 .43232 .62571 .42861 Mtetra
.603 .706 .916 r
.62571 .42861 .62868 .43232 .63466 .43094 .6317 .42758 Mtetra
.711 .766 .895 r
.6317 .42758 .63466 .43094 .64061 .42842 .63766 .42487 Mtetra
.635 .73 .916 r
.63766 .42487 .64061 .42842 .6466 .42668 .64366 .42338 Mtetra
.665 .756 .918 r
.64366 .42338 .6466 .42668 .6526 .42503 .64967 .42143 Mtetra
.688 .746 .896 r
.64967 .42143 .6526 .42503 .6586 .42281 .65567 .41909 Mtetra
.603 .708 .918 r
.65567 .41909 .6586 .42281 .66464 .42134 .66174 .41806 Mtetra
.686 .766 .912 r
.66174 .41806 .66464 .42134 .67067 .41942 .66776 .41577 Mtetra
.654 .732 .907 r
.66776 .41577 .67067 .41942 .6767 .41712 .67383 .41399 Mtetra
.633 .758 .938 r
.67383 .41399 .6767 .41712 .6828 .41584 .67992 .41246 Mtetra
.721 .772 .892 r
.67992 .41246 .6828 .41584 .68883 .41306 .68595 .40951 Mtetra
.558 .702 .936 r
.68595 .40951 .68883 .41306 .69497 .41214 .69212 .40897 Mtetra
.733 .789 .897 r
.69212 .40897 .69497 .41214 .70104 .40966 .69816 .40583 Mtetra
.613 .707 .912 r
.69816 .40583 .70104 .40966 .70717 .40798 .70433 .40466 Mtetra
.663 .759 .922 r
.70433 .40466 .70717 .40798 .71327 .40565 .71047 .4027 Mtetra
.606 .764 .955 r
.71047 .4027 .71327 .40565 .71947 .40475 .71666 .40142 Mtetra
.601 .735 .939 r
.71666 .40142 .71947 .40475 .72565 .40309 .72287 .4003 Mtetra
.791 .828 .88 r
.72287 .4003 .72565 .40309 .73171 .39942 .7289 .39597 Mtetra
.594 .725 .936 r
.7289 .39597 .73171 .39942 .73795 .39844 .73515 .39495 Mtetra
.644 .744 .922 r
.73515 .39495 .73795 .39844 .74415 .39662 .74138 .39326 Mtetra
.681 .766 .915 r
.74138 .39326 .74415 .39662 .75034 .39439 .74757 .39098 Mtetra
.693 .767 .909 r
.74757 .39098 .75034 .39439 .75654 .39204 .75377 .38852 Mtetra
.704 .765 .899 r
.75377 .38852 .75654 .39204 .76273 .3895 .75996 .38583 Mtetra
.637 .731 .917 r
.75996 .38583 .76273 .3895 .769 .3878 .76625 .38424 Mtetra
.667 .751 .913 r
.76625 .38424 .769 .3878 .77525 .38577 .77251 .38218 Mtetra
.67 .75 .91 r
.77251 .38218 .77525 .38577 .78152 .38368 .77879 .38006 Mtetra
.683 .754 .905 r
.77879 .38006 .78152 .38368 .78779 .38143 .78506 .37773 Mtetra
.652 .737 .912 r
.78506 .37773 .78779 .38143 .7941 .37956 .79138 .3759 Mtetra
.663 .744 .911 r
.79138 .3759 .7941 .37956 .80041 .37756 .79771 .37389 Mtetra
.665 .746 .91 r
.79771 .37389 .80041 .37756 .80674 .37552 .80405 .37184 Mtetra
.671 .748 .908 r
.80405 .37184 .80674 .37552 .81307 .3734 .81039 .36968 Mtetra
.662 .742 .909 r
.81039 .36968 .81307 .3734 .81943 .37138 .81675 .36766 Mtetra
.654 .74 .912 r
.81675 .36766 .81943 .37138 .82581 .36947 .82315 .36577 Mtetra
.676 .75 .906 r
.82315 .36577 .82581 .36947 .83218 .36727 .82952 .36352 Mtetra
.653 .738 .912 r
.82952 .36352 .83218 .36727 .83859 .36537 .83595 .36164 Mtetra
.672 .748 .907 r
.83595 .36164 .83859 .36537 .84499 .36321 .84235 .35944 Mtetra
.66 .741 .91 r
.84235 .35944 .84499 .36321 .85142 .3612 .8488 .35744 Mtetra
.663 .743 .91 r
.8488 .35744 .85142 .3612 .85786 .35916 .85525 .3554 Mtetra
.664 .744 .909 r
.85525 .3554 .85786 .35916 .86432 .35711 .86171 .35333 Mtetra
.672 .746 .907 r
.86171 .35333 .86432 .35711 .87077 .35493 .86818 .35112 Mtetra
.656 .738 .911 r
.86818 .35112 .87077 .35493 .87727 .35298 .87468 .34917 Mtetra
.66 .741 .91 r
.87468 .34917 .87727 .35298 .88377 .35094 .8812 .34715 Mtetra
.667 .745 .909 r
.8812 .34715 .88377 .35094 .89028 .34881 .88771 .345 Mtetra
.667 .745 .908 r
.88771 .345 .89028 .34881 .8968 .34669 .89424 .34285 Mtetra
.664 .742 .908 r
.89424 .34285 .8968 .34669 .90334 .34459 .90079 .34075 Mtetra
.659 .74 .91 r
.90079 .34075 .90334 .34459 .9099 .34258 .90737 .33873 Mtetra
.662 .741 .909 r
.31802 .52269 .3214 .52583 .32673 .52416 .32336 .52101 Mtetra
.667 .742 .906 r
.32336 .52101 .32673 .52416 .33208 .52241 .32871 .51924 Mtetra
.658 .739 .91 r
.32871 .51924 .33208 .52241 .33743 .52074 .33407 .51761 Mtetra
.664 .744 .909 r
.33407 .51761 .33743 .52074 .3428 .51904 .33944 .51587 Mtetra
.664 .742 .908 r
.33944 .51587 .3428 .51904 .34818 .51726 .34483 .51414 Mtetra
.652 .742 .916 r
.34483 .51414 .34818 .51726 .35356 .51569 .35021 .51258 Mtetra
.666 .747 .911 r
.35021 .51258 .35356 .51569 .35896 .51399 .35562 .51081 Mtetra
.675 .745 .903 r
.35562 .51081 .35896 .51399 .36438 .51213 .36105 .5089 Mtetra
.659 .738 .909 r
.36105 .5089 .36438 .51213 .3698 .51042 .36647 .50723 Mtetra
.658 .741 .911 r
.36647 .50723 .3698 .51042 .37523 .50873 .37191 .50557 Mtetra
.667 .746 .91 r
.37191 .50557 .37523 .50873 .38067 .50699 .37736 .50378 Mtetra
.659 .741 .91 r
.37736 .50378 .38067 .50699 .38613 .50522 .38282 .5021 Mtetra
.669 .749 .91 r
.38282 .5021 .38613 .50522 .39159 .50353 .3883 .50027 Mtetra
.652 .736 .911 r
.3883 .50027 .39159 .50353 .39707 .50183 .39378 .49868 Mtetra
.673 .749 .908 r
.39378 .49868 .39707 .50183 .40256 .49994 .39928 .49678 Mtetra
.668 .748 .91 r
.39928 .49678 .40256 .49994 .40806 .49819 .40479 .49495 Mtetra
.665 .742 .908 r
.40479 .49495 .40806 .49819 .41357 .49645 .4103 .49316 Mtetra
.667 .741 .905 r
.4103 .49316 .41357 .49645 .41909 .49465 .41583 .49135 Mtetra
.647 .734 .913 r
.41583 .49135 .41909 .49465 .42463 .49291 .42137 .48981 Mtetra
.64 .746 .925 r
.42137 .48981 .42463 .49291 .43016 .4915 .42691 .48835 Mtetra
.689 .756 .903 r
.42691 .48835 .43016 .4915 .43572 .48959 .43249 .48617 Mtetra
.615 .718 .919 r
.43249 .48617 .43572 .48959 .44128 .4881 .43804 .48505 Mtetra
.696 .765 .905 r
.43804 .48505 .44128 .4881 .44687 .48574 .44364 .48276 Mtetra
.658 .76 .925 r
.44364 .48276 .44687 .48574 .45245 .48461 .44924 .48104 Mtetra
.62 .711 .911 r
.44924 .48104 .45245 .48461 .45804 .48333 .45484 .47987 Mtetra
.646 .727 .908 r
.45484 .47987 .45804 .48333 .46365 .48187 .46045 .47833 Mtetra
.696 .738 .883 r
.46045 .47833 .46365 .48187 .46928 .47996 .4661 .47596 Mtetra
.625 .69 .89 r
.4661 .47596 .46928 .47996 .47494 .47692 .47174 .47473 Mtetra
.299 .671 .974 r
.47174 .47473 .47494 .47692 .48056 .47725 .47736 .47538 Mtetra
.78 .859 .909 r
.47736 .47538 .48056 .47725 .48622 .47548 .48306 .47168 Mtetra
.626 .703 .9 r
.48306 .47168 .48622 .47548 .49192 .47208 .48873 .47043 Mtetra
.728 .874 .949 r
.48873 .47043 .49192 .47208 .4976 .47075 .49444 .46757 Mtetra
.732 .769 .883 r
.49444 .46757 .4976 .47075 .5033 .46842 .50015 .46455 Mtetra
.524 .658 .92 r
.50015 .46455 .5033 .46842 .509 .4674 .50586 .46453 Mtetra
.729 .789 .9 r
.50586 .46453 .509 .4674 .51473 .46414 .51159 .46163 Mtetra
.65 .797 .953 r
.51159 .46163 .51473 .46414 .52046 .46319 .51733 .45989 Mtetra
.643 .741 .92 r
.51733 .45989 .52046 .46319 .5262 .46081 .52309 .45835 Mtetra
.74 .82 .914 r
.52309 .45835 .5262 .46081 .53196 .45914 .52885 .45529 Mtetra
.583 .685 .911 r
.52885 .45529 .53196 .45914 .53773 .45758 .53463 .45459 Mtetra
.718 .782 .903 r
.53463 .45459 .53773 .45758 .54351 .45498 .54042 .45185 Mtetra
.654 .757 .925 r
.54042 .45185 .54351 .45498 .5493 .45384 .54622 .45012 Mtetra
.659 .722 .896 r
.54622 .45012 .5493 .45384 .5551 .45137 .55203 .44832 Mtetra
.671 .768 .923 r
.55203 .44832 .5551 .45137 .56092 .4494 .55785 .44634 Mtetra
.634 .756 .936 r
.55785 .44634 .56092 .4494 .56676 .44816 .5637 .44485 Mtetra
.686 .757 .905 r
.5637 .44485 .56676 .44816 .57259 .44557 .56954 .44262 Mtetra
.633 .765 .942 r
.56954 .44262 .57259 .44557 .57845 .4445 .57541 .44112 Mtetra
.71 .76 .891 r
.57541 .44112 .57845 .4445 .58431 .44236 .58127 .43844 Mtetra
.634 .705 .897 r
.58127 .43844 .58431 .44236 .59018 .43995 .58716 .43702 Mtetra
.644 .771 .94 r
.58716 .43702 .59018 .43995 .59608 .43845 .59307 .43536 Mtetra
.67 .768 .924 r
.59307 .43536 .59608 .43845 .60198 .43647 .59898 .43336 Mtetra
.663 .765 .926 r
.59898 .43336 .60198 .43647 .60789 .43438 .6049 .43146 Mtetra
.687 .786 .925 r
.6049 .43146 .60789 .43438 .61382 .43266 .61083 .42918 Mtetra
.652 .739 .914 r
.61083 .42918 .61382 .43266 .61977 .4311 .61678 .42746 Mtetra
.664 .734 .902 r
.61678 .42746 .61977 .4311 .62571 .42861 .62275 .42554 Mtetra
.637 .762 .938 r
.62275 .42554 .62571 .42861 .6317 .42758 .62873 .42397 Mtetra
.667 .737 .902 r
.62873 .42397 .6317 .42758 .63766 .42487 .63472 .42199 Mtetra
.659 .783 .94 r
.63472 .42199 .63766 .42487 .64366 .42338 .64072 .42009 Mtetra
.694 .767 .908 r
.64072 .42009 .64366 .42338 .64967 .42143 .64672 .41767 Mtetra
.649 .724 .903 r
.64672 .41767 .64967 .42143 .65567 .41909 .65275 .41598 Mtetra
.624 .756 .941 r
.65275 .41598 .65567 .41909 .66174 .41806 .65881 .41455 Mtetra
.717 .762 .888 r
.65881 .41455 .66174 .41806 .66776 .41577 .66482 .41167 Mtetra
.571 .673 .908 r
.66482 .41167 .66776 .41577 .67383 .41399 .67095 .41112 Mtetra
.695 .797 .928 r
.67095 .41112 .67383 .41399 .67992 .41246 .67701 .40867 Mtetra
.655 .727 .902 r
.67701 .40867 .67992 .41246 .68595 .40951 .68311 .40685 Mtetra
.612 .787 .965 r
.68311 .40685 .68595 .40951 .69212 .40897 .68924 .40543 Mtetra
.717 .763 .888 r
.68924 .40543 .69212 .40897 .69816 .40583 .69531 .40252 Mtetra
.638 .751 .93 r
.69531 .40252 .69816 .40583 .70433 .40466 .70146 .40091 Mtetra
.538 .681 .931 r
.70146 .40091 .70433 .40466 .71047 .4027 .7077 .40065 Mtetra
.773 .876 .923 r
.7077 .40065 .71047 .4027 .71666 .40142 .71376 .39688 Mtetra
.448 .589 .9 r
.71376 .39688 .71666 .40142 .72287 .4003 .72011 .39792 Mtetra
.783 .856 .905 r
.72011 .39792 .72287 .4003 .7289 .39597 .72618 .3939 Mtetra
.752 .875 .935 r
.72618 .3939 .7289 .39597 .73515 .39495 .73228 .39047 Mtetra
.614 .676 .885 r
.73228 .39047 .73515 .39495 .74138 .39326 .73855 .38931 Mtetra
.672 .729 .892 r
.73855 .38931 .74138 .39326 .74757 .39098 .74477 .38716 Mtetra
.696 .745 .889 r
.74477 .38716 .74757 .39098 .75377 .38852 .75096 .38459 Mtetra
.685 .735 .889 r
.75096 .38459 .75377 .38852 .75996 .38583 .75719 .3822 Mtetra
.62 .728 .924 r
.75719 .3822 .75996 .38583 .76625 .38424 .7635 .38085 Mtetra
.69 .77 .912 r
.7635 .38085 .76625 .38424 .77251 .38218 .76975 .3784 Mtetra
.654 .734 .908 r
.76975 .3784 .77251 .38218 .77879 .38006 .77605 .37654 Mtetra
.693 .764 .906 r
.77605 .37654 .77879 .38006 .78506 .37773 .78232 .37403 Mtetra
.658 .74 .911 r
.78232 .37403 .78506 .37773 .79138 .3759 .78865 .3721 Mtetra
.66 .736 .906 r
.78865 .3721 .79138 .3759 .79771 .37389 .79499 .37014 Mtetra
.666 .741 .906 r
.79499 .37014 .79771 .37389 .80405 .37184 .80133 .36806 Mtetra
.67 .742 .905 r
.80133 .36806 .80405 .37184 .81039 .36968 .80769 .36592 Mtetra
.656 .738 .91 r
.80769 .36592 .81039 .36968 .81675 .36766 .81407 .364 Mtetra
.657 .745 .914 r
.81407 .364 .81675 .36766 .82315 .36577 .82047 .36205 Mtetra
.682 .751 .904 r
.82047 .36205 .82315 .36577 .82952 .36352 .82685 .35969 Mtetra
.647 .732 .911 r
.82685 .35969 .82952 .36352 .83595 .36164 .83329 .35791 Mtetra
.676 .75 .907 r
.83329 .35791 .83595 .36164 .84235 .35944 .8397 .35564 Mtetra
.66 .74 .909 r
.8397 .35564 .84235 .35944 .8488 .35744 .84616 .35364 Mtetra
.84616 .35364 .8488 .35744 .85525 .3554 .85262 .35162 Mtetra
.663 .744 .91 r
.85262 .35162 .85525 .3554 .86171 .35333 .8591 .34955 Mtetra
.67 .747 .908 r
.8591 .34955 .86171 .35333 .86818 .35112 .86558 .34736 Mtetra
.661 .745 .912 r
.86558 .34736 .86818 .35112 .87468 .34917 .87209 .34532 Mtetra
.658 .738 .909 r
.87209 .34532 .87468 .34917 .8812 .34715 .87861 .34333 Mtetra
.666 .744 .909 r
.87861 .34333 .8812 .34715 .88771 .345 .88514 .3412 Mtetra
.67 .748 .908 r
.88514 .3412 .88771 .345 .89424 .34285 .89168 .33899 Mtetra
.665 .742 .908 r
.89168 .33899 .89424 .34285 .90079 .34075 .89824 .33687 Mtetra
.656 .738 .91 r
.89824 .33687 .90079 .34075 .90737 .33873 .90483 .33488 Mtetra
.664 .741 .907 r
.31462 .51952 .31802 .52269 .32336 .52101 .31997 .5178 Mtetra
.662 .739 .907 r
.31997 .5178 .32336 .52101 .32871 .51924 .32533 .5161 Mtetra
.658 .742 .912 r
.32533 .5161 .32871 .51924 .33407 .51761 .33069 .51446 Mtetra
.669 .745 .907 r
.33069 .51446 .33407 .51761 .33944 .51587 .33608 .51265 Mtetra
.653 .736 .91 r
.33608 .51265 .33944 .51587 .34483 .51414 .34146 .51107 Mtetra
.655 .747 .917 r
.34146 .51107 .34483 .51414 .35021 .51258 .34686 .50944 Mtetra
.674 .748 .906 r
.34686 .50944 .35021 .51258 .35562 .51081 .35228 .50754 Mtetra
.665 .738 .904 r
.35228 .50754 .35562 .51081 .36105 .5089 .3577 .50578 Mtetra
.66 .746 .914 r
.3577 .50578 .36105 .5089 .36647 .50723 .36314 .50408 Mtetra
.66 .744 .913 r
.36314 .50408 .36647 .50723 .37191 .50557 .36858 .50238 Mtetra
.673 .746 .905 r
.36858 .50238 .37191 .50557 .37736 .50378 .37404 .50049 Mtetra
.646 .733 .912 r
.37404 .50049 .37736 .50378 .38282 .5021 .3795 .49898 Mtetra
.683 .754 .905 r
.3795 .49898 .38282 .5021 .3883 .50027 .385 .49692 Mtetra
.644 .73 .911 r
.385 .49692 .3883 .50027 .39378 .49868 .39047 .49544 Mtetra
.662 .742 .909 r
.39047 .49544 .39378 .49868 .39928 .49678 .39598 .4937 Mtetra
.671 .754 .913 r
.39598 .4937 .39928 .49678 .40479 .49495 .40149 .49182 Mtetra
.664 .75 .914 r
.40149 .49182 .40479 .49495 .4103 .49316 .40702 .49003 Mtetra
.654 .747 .918 r
.40702 .49003 .4103 .49316 .41583 .49135 .41255 .48838 Mtetra
.648 .757 .929 r
.41255 .48838 .41583 .49135 .42137 .48981 .41809 .48681 Mtetra
.663 .759 .921 r
.41809 .48681 .42137 .48981 .42691 .48835 .42365 .48502 Mtetra
.683 .744 .897 r
.42365 .48502 .42691 .48835 .43249 .48617 .42923 .48292 Mtetra
.615 .729 .928 r
.42923 .48292 .43249 .48617 .43804 .48505 .4348 .48177 Mtetra
.653 .74 .913 r
.4348 .48177 .43804 .48505 .44364 .48276 .44039 .48012 Mtetra
.7 .794 .923 r
.44039 .48012 .44364 .48276 .44924 .48104 .44601 .47778 Mtetra
.686 .751 .901 r
.44601 .47778 .44924 .48104 .45484 .47987 .45164 .47563 Mtetra
.657 .689 .869 r
.45164 .47563 .45484 .47987 .46045 .47833 .45726 .4739 Mtetra
.581 .65 .884 r
.45726 .4739 .46045 .47833 .4661 .47596 .46288 .47334 Mtetra
.366 .673 .975 r
.46288 .47334 .4661 .47596 .47174 .47473 .46849 .47391 Mtetra
.529 .88 .985 r
.46849 .47391 .47174 .47473 .47736 .47538 .47416 .47238 Mtetra
.796 .786 .844 r
.47416 .47238 .47736 .47538 .48306 .47168 .47988 .46777 Mtetra
.378 .584 .923 r
.47988 .46777 .48306 .47168 .48873 .47043 .48553 .46903 Mtetra
.864 .879 .847 r
.48553 .46903 .48873 .47043 .49444 .46757 .49128 .46317 Mtetra
.555 .643 .892 r
.49128 .46317 .49444 .46757 .50015 .46455 .49698 .46293 Mtetra
.734 .879 .947 r
.49698 .46293 .50015 .46455 .50586 .46453 .50271 .45996 Mtetra
.579 .645 .88 r
.50271 .45996 .50586 .46453 .51159 .46163 .50844 .45943 Mtetra
.782 .841 .896 r
.50844 .45943 .51159 .46163 .51733 .45989 .5142 .45558 Mtetra
.549 .645 .897 r
.5142 .45558 .51733 .45989 .52309 .45835 .51996 .4554 Mtetra
.719 .784 .904 r
.51996 .4554 .52309 .45835 .52885 .45529 .52573 .45266 Mtetra
.679 .798 .938 r
.52573 .45266 .52885 .45529 .53463 .45459 .53151 .45054 Mtetra
.65 .701 .884 r
.53151 .45054 .53463 .45459 .54042 .45185 .53731 .44889 Mtetra
.683 .777 .922 r
.53731 .44889 .54042 .45185 .54622 .45012 .54312 .44673 Mtetra
.682 .75 .903 r
.54312 .44673 .54622 .45012 .55203 .44832 .54894 .44456 Mtetra
.589 .695 .916 r
.54894 .44456 .55203 .44832 .55785 .44634 .55478 .44376 Mtetra
.735 .815 .914 r
.55478 .44376 .55785 .44634 .5637 .44485 .56061 .44075 Mtetra
.624 .691 .892 r
.56061 .44075 .5637 .44485 .56954 .44262 .56648 .43949 Mtetra
.7 .773 .908 r
.56648 .43949 .56954 .44262 .57541 .44112 .57234 .43703 Mtetra
.638 .698 .889 r
.57234 .43703 .57541 .44112 .58127 .43844 .57823 .43555 Mtetra
.663 .78 .936 r
.57823 .43555 .58127 .43844 .58716 .43702 .58413 .43363 Mtetra
.677 .752 .907 r
.58413 .43363 .58716 .43702 .59307 .43536 .59003 .43152 Mtetra
.668 .723 .89 r
.59003 .43152 .59307 .43536 .59898 .43336 .59595 .42954 Mtetra
.637 .714 .903 r
.59595 .42954 .59898 .43336 .6049 .43146 .60189 .42806 Mtetra
.645 .742 .92 r
.60189 .42806 .6049 .43146 .61083 .42918 .60784 .42643 Mtetra
.705 .803 .926 r
.60784 .42643 .61083 .42918 .61678 .42746 .61378 .42386 Mtetra
.652 .734 .909 r
.61378 .42386 .61678 .42746 .62275 .42554 .61976 .42212 Mtetra
.691 .757 .902 r
.61976 .42212 .62275 .42554 .62873 .42397 .62573 .41975 Mtetra
.597 .677 .897 r
.62573 .41975 .62873 .42397 .63472 .42199 .63176 .41886 Mtetra
.72 .785 .903 r
.63176 .41886 .63472 .42199 .64072 .42009 .63774 .416 Mtetra
.602 .686 .902 r
.63774 .416 .64072 .42009 .64672 .41767 .64379 .41503 Mtetra
.696 .812 .937 r
.64379 .41503 .64672 .41767 .65275 .41598 .64981 .41256 Mtetra
.685 .758 .907 r
.64981 .41256 .65275 .41598 .65881 .41455 .65584 .41027 Mtetra
.627 .688 .888 r
.65584 .41027 .65881 .41455 .66482 .41167 .66193 .40893 Mtetra
.639 .79 .954 r
.66193 .40893 .66482 .41167 .67095 .41112 .66802 .40722 Mtetra
.704 .738 .878 r
.66802 .40722 .67095 .41112 .67701 .40867 .67407 .40452 Mtetra
.582 .676 .905 r
.67407 .40452 .67701 .40867 .68311 .40685 .68023 .40381 Mtetra
.731 .797 .905 r
.68023 .40381 .68311 .40685 .68924 .40543 .68629 .40072 Mtetra
.56 .637 .885 r
.68629 .40072 .68924 .40543 .69531 .40252 .6925 .40042 Mtetra
.741 .868 .939 r
.6925 .40042 .69531 .40252 .70146 .40091 .69858 .39719 Mtetra
.416 .622 .937 r
.69858 .39719 .70146 .40091 .7077 .40065 .7049 .39812 Mtetra
.74 .838 .924 r
.7049 .39812 .7077 .40065 .71376 .39688 .711 .39489 Mtetra
.533 .812 .997 r
.711 .39489 .71376 .39688 .72011 .39792 .71724 .39386 Mtetra
.615 .699 .904 r
.71724 .39386 .72011 .39792 .72618 .3939 .72349 .39263 Mtetra
.801 .938 .919 r
.72349 .39263 .72618 .3939 .73228 .39047 .72955 .38824 Mtetra
.761 .866 .926 r
.72955 .38824 .73228 .39047 .73855 .38931 .73567 .38465 Mtetra
.67 .692 .862 r
.73567 .38465 .73855 .38931 .74477 .38716 .74189 .38248 Mtetra
.649 .682 .868 r
.74189 .38248 .74477 .38716 .75096 .38459 .74815 .38069 Mtetra
.626 .715 .91 r
.74815 .38069 .75096 .38459 .75719 .3822 .75445 .37927 Mtetra
.656 .79 .946 r
.75445 .37927 .75719 .3822 .7635 .38085 .76073 .37731 Mtetra
.716 .771 .895 r
.76073 .37731 .7635 .38085 .76975 .3784 .76695 .37437 Mtetra
.628 .708 .904 r
.76695 .37437 .76975 .3784 .77605 .37654 .7733 .37293 Mtetra
.679 .755 .908 r
.7733 .37293 .77605 .37654 .78232 .37403 .7796 .37064 Mtetra
.684 .771 .917 r
.7796 .37064 .78232 .37403 .78865 .3721 .7859 .36827 Mtetra
.662 .736 .905 r
.7859 .36827 .78865 .3721 .79499 .37014 .79225 .36625 Mtetra
.663 .734 .902 r
.79225 .36625 .79499 .37014 .80133 .36806 .79861 .36422 Mtetra
.66 .736 .906 r
.79861 .36422 .80133 .36806 .80769 .36592 .80498 .36223 Mtetra
.651 .741 .916 r
.80498 .36223 .80769 .36592 .81407 .364 .81139 .36038 Mtetra
.671 .754 .913 r
.81139 .36038 .81407 .364 .82047 .36205 .81777 .3582 Mtetra
.667 .739 .904 r
.81777 .3582 .82047 .36205 .82685 .35969 .82418 .35609 Mtetra
.659 .751 .918 r
.82418 .35609 .82685 .35969 .83329 .35791 .83062 .35409 Mtetra
.666 .742 .906 r
.83062 .35409 .83329 .35791 .8397 .35564 .83706 .35198 Mtetra
.669 .752 .913 r
.83706 .35198 .8397 .35564 .84616 .35364 .84351 .34981 Mtetra
.66 .74 .909 r
.84351 .34981 .84616 .35364 .85262 .35162 .84998 .34779 Mtetra
.659 .74 .909 r
.84998 .34779 .85262 .35162 .8591 .34955 .85648 .34578 Mtetra
.665 .746 .91 r
.85648 .34578 .8591 .34955 .86558 .34736 .86297 .34366 Mtetra
.674 .755 .911 r
.86297 .34366 .86558 .34736 .87209 .34532 .86947 .34139 Mtetra
.655 .733 .907 r
.86947 .34139 .87209 .34532 .87861 .34333 .87601 .33943 Mtetra
.66 .738 .907 r
.87601 .33943 .87861 .34333 .88514 .3412 .88256 .33738 Mtetra
.67 .747 .908 r
.88256 .33738 .88514 .3412 .89168 .33899 .88911 .33517 Mtetra
.669 .747 .909 r
.88911 .33517 .89168 .33899 .89824 .33687 .89567 .33297 Mtetra
.654 .737 .91 r
.89567 .33297 .89824 .33687 .90483 .33488 .90228 .33101 Mtetra
.663 .739 .906 r
.31122 .51631 .31462 .51952 .31997 .5178 .31657 .51459 Mtetra
.654 .736 .91 r
.31657 .51459 .31997 .5178 .32533 .5161 .32193 .513 Mtetra
.665 .747 .911 r
.32193 .513 .32533 .5161 .33069 .51446 .32731 .51125 Mtetra
.661 .74 .908 r
.32731 .51125 .33069 .51446 .33608 .51265 .33269 .50956 Mtetra
.654 .746 .917 r
.33269 .50956 .33608 .51265 .34146 .51107 .33808 .50795 Mtetra
.668 .748 .911 r
.33808 .50795 .34146 .51107 .34686 .50944 .34349 .50615 Mtetra
.674 .739 .899 r
.34349 .50615 .34686 .50944 .35228 .50754 .34892 .50424 Mtetra
.654 .734 .908 r
.34892 .50424 .35228 .50754 .3577 .50578 .35435 .50264 Mtetra
.661 .746 .913 r
.35435 .50264 .3577 .50578 .36314 .50408 .35979 .50092 Mtetra
.669 .747 .909 r
.35979 .50092 .36314 .50408 .36858 .50238 .36524 .49909 Mtetra
.661 .737 .906 r
.36524 .49909 .36858 .50238 .37404 .50049 .37071 .49736 Mtetra
.657 .747 .916 r
.37071 .49736 .37404 .50049 .3795 .49898 .37618 .49568 Mtetra
.664 .739 .906 r
.37618 .49568 .3795 .49898 .385 .49692 .38167 .49391 Mtetra
.676 .76 .914 r
.38167 .49391 .385 .49692 .39047 .49544 .38717 .49196 Mtetra
.645 .723 .905 r
.38717 .49196 .39047 .49544 .39598 .4937 .39267 .49045 Mtetra
.66 .742 .911 r
.39267 .49045 .39598 .4937 .40149 .49182 .39819 .48873 Mtetra
.66 .752 .918 r
.39819 .48873 .40149 .49182 .40702 .49003 .40372 .487 Mtetra
.655 .755 .923 r
.40372 .487 .40702 .49003 .41255 .48838 .40926 .48532 Mtetra
.666 .756 .918 r
.40926 .48532 .41255 .48838 .41809 .48681 .41482 .48349 Mtetra
.691 .748 .894 r
.41482 .48349 .41809 .48681 .42365 .48502 .4204 .48125 Mtetra
.617 .699 .903 r
.4204 .48125 .42365 .48502 .42923 .48292 .42596 .48014 Mtetra
.703 .785 .915 r
.42596 .48014 .42923 .48292 .4348 .48177 .43156 .47774 Mtetra
.596 .677 .898 r
.43156 .47774 .4348 .48177 .44039 .48012 .43714 .47694 Mtetra
.637 .742 .924 r
.43714 .47694 .44039 .48012 .44601 .47778 .44274 .47549 Mtetra
.635 .805 .965 r
.44274 .47549 .44601 .47778 .45164 .47563 .44836 .4739 Mtetra
.554 .825 .996 r
.44836 .4739 .45164 .47563 .45726 .4739 .45399 .47278 Mtetra
.385 .797 .979 r
.45399 .47278 .45726 .4739 .46288 .47334 .45962 .47221 Mtetra
.574 .876 .994 r
.45962 .47221 .46288 .47334 .46849 .47391 .46528 .4706 Mtetra
.8 .77 .825 r
.46528 .4706 .46849 .47391 .47416 .47238 .47101 .46561 Mtetra
.278 .39 .798 r
.47101 .46561 .47416 .47238 .47988 .46777 .47661 .46931 Mtetra
.831 .998 .777 r
.47661 .46931 .47988 .46777 .48553 .46903 .48237 .46295 Mtetra
.498 .543 .833 r
.48237 .46295 .48553 .46903 .49128 .46317 .48805 .46383 Mtetra
.811 .997 .855 r
.48805 .46383 .49128 .46317 .49698 .46293 .49381 .45867 Mtetra
.55 .649 .899 r
.49381 .45867 .49698 .46293 .50271 .45996 .49953 .45844 Mtetra
.791 .889 .915 r
.49953 .45844 .50271 .45996 .50844 .45943 .50529 .45453 Mtetra
.601 .64 .861 r
.50529 .45453 .50844 .45943 .5142 .45558 .51104 .45369 Mtetra
.737 .862 .939 r
.51104 .45369 .5142 .45558 .51996 .4554 .51682 .45069 Mtetra
.649 .669 .856 r
.51682 .45069 .51996 .4554 .52573 .45266 .5226 .44901 Mtetra
.629 .717 .91 r
.5226 .44901 .52573 .45266 .53151 .45054 .52839 .44767 Mtetra
.707 .789 .915 r
.52839 .44767 .53151 .45054 .53731 .44889 .53419 .44512 Mtetra
.62 .707 .908 r
.53419 .44512 .53731 .44889 .54312 .44673 .54001 .4439 Mtetra
.677 .786 .931 r
.54001 .4439 .54312 .44673 .54894 .44456 .54584 .4418 Mtetra
.699 .796 .925 r
.54584 .4418 .54894 .44456 .55478 .44376 .55168 .43938 Mtetra
.656 .689 .869 r
.55168 .43938 .55478 .44376 .56061 .44075 .55753 .43758 Mtetra
.667 .762 .921 r
.55753 .43758 .56061 .44075 .56648 .43949 .5634 .43564 Mtetra
.633 .709 .902 r
.5634 .43564 .56648 .43949 .57234 .43703 .56928 .43423 Mtetra
.715 .799 .917 r
.56928 .43423 .57234 .43703 .57823 .43555 .57516 .43152 Mtetra
.631 .699 .894 r
.57516 .43152 .57823 .43555 .58413 .43363 .58107 .43013 Mtetra
.65 .736 .913 r
.58107 .43013 .58413 .43363 .59003 .43152 .58699 .42843 Mtetra
.669 .77 .925 r
.58699 .42843 .59003 .43152 .59595 .42954 .59292 .42643 Mtetra
.689 .774 .917 r
.59292 .42643 .59595 .42954 .60189 .42806 .59885 .42413 Mtetra
.67 .72 .887 r
.59885 .42413 .60189 .42806 .60784 .42643 .6048 .42208 Mtetra
.61 .676 .888 r
.6048 .42208 .60784 .42643 .61378 .42386 .61079 .42101 Mtetra
.686 .793 .931 r
.61079 .42101 .61378 .42386 .61976 .42212 .61676 .41873 Mtetra
.668 .753 .914 r
.61676 .41873 .61976 .42212 .62573 .41975 .62275 .41673 Mtetra
.686 .782 .924 r
.62275 .41673 .62573 .41975 .63176 .41886 .62875 .41444 Mtetra
.637 .684 .878 r
.62875 .41444 .63176 .41886 .63774 .416 .63478 .41294 Mtetra
.642 .767 .939 r
.63478 .41294 .63774 .416 .64379 .41503 .64082 .41127 Mtetra
.674 .734 .896 r
.64082 .41127 .64379 .41503 .64981 .41256 .64686 .40914 Mtetra
.6 .728 .934 r
.64686 .40914 .64981 .41256 .65584 .41027 .65295 .40806 Mtetra
.759 .858 .924 r
.65295 .40806 .65584 .41027 .66193 .40893 .65896 .40457 Mtetra
.573 .662 .898 r
.65896 .40457 .66193 .40893 .66802 .40722 .6651 .40402 Mtetra
.666 .768 .926 r
.6651 .40402 .66802 .40722 .67407 .40452 .6712 .40201 Mtetra
.691 .825 .947 r
.6712 .40201 .67407 .40452 .68023 .40381 .67729 .39957 Mtetra
.5 .634 .913 r
.67729 .39957 .68023 .40381 .68629 .40072 .68352 .39988 Mtetra
.816 .96 .905 r
.68352 .39988 .68629 .40072 .6925 .40042 .68952 .39514 Mtetra
.417 .536 .87 r
.68952 .39514 .6925 .40042 .69858 .39719 .69587 .39684 Mtetra
.845 .982 .867 r
.69587 .39684 .69858 .39719 .7049 .39812 .70184 .39126 Mtetra
.307 .41 .804 r
.70184 .39126 .7049 .39812 .711 .39489 .70835 .39519 Mtetra
.875 .993 .8 r
.70835 .39519 .711 .39489 .71724 .39386 .71427 .38836 Mtetra
.558 .604 .855 r
.71427 .38836 .71724 .39386 .72349 .39263 .72059 .38821 Mtetra
.639 .691 .882 r
.72059 .38821 .72349 .39263 .72955 .38824 .72684 .38661 Mtetra
.734 .907 .954 r
.72684 .38661 .72955 .38824 .73567 .38465 .73299 .38333 Mtetra
.686 .919 .972 r
.73299 .38333 .73567 .38465 .74189 .38248 .73918 .38048 Mtetra
.663 .863 .975 r
.73918 .38048 .74189 .38248 .74815 .38069 .74542 .37819 Mtetra
.675 .828 .957 r
.74542 .37819 .74815 .38069 .75445 .37927 .75168 .37588 Mtetra
.716 .78 .902 r
.75168 .37588 .75445 .37927 .76073 .37731 .7579 .37297 Mtetra
.647 .701 .885 r
.7579 .37297 .76073 .37731 .76695 .37437 .76422 .37121 Mtetra
.687 .787 .926 r
.76422 .37121 .76695 .37437 .7733 .37293 .7705 .36879 Mtetra
.642 .71 .897 r
.7705 .36879 .7733 .37293 .7796 .37064 .77685 .36712 Mtetra
.673 .759 .916 r
.77685 .36712 .7796 .37064 .7859 .36827 .78318 .36492 Mtetra
.674 .772 .924 r
.78318 .36492 .7859 .36827 .79225 .36625 .78952 .3627 Mtetra
.663 .754 .918 r
.78952 .3627 .79225 .36625 .79861 .36422 .79589 .36065 Mtetra
.657 .752 .92 r
.79589 .36065 .79861 .36422 .80498 .36223 .80228 .35869 Mtetra
.667 .758 .918 r
.80228 .35869 .80498 .36223 .81139 .36038 .80867 .35657 Mtetra
.682 .748 .901 r
.80867 .35657 .81139 .36038 .81777 .3582 .81505 .3542 Mtetra
.643 .721 .905 r
.81505 .3542 .81777 .3582 .82418 .35609 .82151 .35247 Mtetra
.68 .76 .912 r
.82151 .35247 .82418 .35609 .83062 .35409 .82792 .35013 Mtetra
.652 .729 .905 r
.82792 .35013 .83062 .35409 .83706 .35198 .8344 .34826 Mtetra
.675 .752 .909 r
.8344 .34826 .83706 .35198 .84351 .34981 .84084 .34599 Mtetra
.667 .744 .908 r
.84084 .34599 .84351 .34981 .84998 .34779 .84732 .34385 Mtetra
.655 .732 .906 r
.84732 .34385 .84998 .34779 .85648 .34578 .85383 .34189 Mtetra
.656 .736 .909 r
.85383 .34189 .85648 .34578 .86297 .34366 .86036 .33993 Mtetra
.671 .752 .912 r
.86036 .33993 .86297 .34366 .86947 .34139 .86687 .33771 Mtetra
.67 .756 .915 r
.86687 .33771 .86947 .34139 .87601 .33943 .8734 .33549 Mtetra
.659 .736 .907 r
.8734 .33549 .87601 .33943 .88256 .33738 .87996 .33346 Mtetra
.663 .74 .907 r
.87996 .33346 .88256 .33738 .88911 .33517 .88653 .33136 Mtetra
.671 .75 .91 r
.88653 .33136 .88911 .33517 .89567 .33297 .8931 .3291 Mtetra
.659 .742 .912 r
.8931 .3291 .89567 .33297 .90228 .33101 .89971 .32706 Mtetra
.656 .741 .912 r
.3078 .51315 .31122 .51631 .31657 .51459 .31315 .51152 Mtetra
.66 .748 .915 r
.31315 .51152 .31657 .51459 .32193 .513 .31852 .50983 Mtetra
.666 .743 .908 r
.31852 .50983 .32193 .513 .32731 .51125 .3239 .50805 Mtetra
.656 .74 .911 r
.3239 .50805 .32731 .51125 .33269 .50956 .32929 .50642 Mtetra
.664 .746 .911 r
.32929 .50642 .33269 .50956 .33808 .50795 .3347 .50467 Mtetra
.676 .74 .899 r
.3347 .50467 .33808 .50795 .34349 .50615 .34012 .50273 Mtetra
.646 .725 .906 r
.34012 .50273 .34349 .50615 .34892 .50424 .34554 .50124 Mtetra
.665 .756 .918 r
.34554 .50124 .34892 .50424 .35435 .50264 .35098 .49946 Mtetra
.674 .748 .906 r
.35098 .49946 .35435 .50264 .35979 .50092 .35643 .49755 Mtetra
.665 .734 .902 r
.35643 .49755 .35979 .50092 .36524 .49909 .36189 .49577 Mtetra
.648 .733 .911 r
.36189 .49577 .36524 .49909 .37071 .49736 .36735 .49423 Mtetra
.684 .754 .904 r
.36735 .49423 .37071 .49736 .37618 .49568 .37285 .49214 Mtetra
.639 .718 .905 r
.37285 .49214 .37618 .49568 .38167 .49391 .37833 .49073 Mtetra
.673 .749 .908 r
.37833 .49073 .38167 .49391 .38717 .49196 .38384 .48882 Mtetra
.671 .752 .911 r
.38384 .48882 .38717 .49196 .39267 .49045 .38936 .48692 Mtetra
.657 .725 .899 r
.38936 .48692 .39267 .49045 .39819 .48873 .39489 .48524 Mtetra
.66 .728 .9 r
.39489 .48524 .39819 .48873 .40372 .487 .40042 .48351 Mtetra
.665 .73 .898 r
.40042 .48351 .40372 .487 .40926 .48532 .40597 .4817 Mtetra
.677 .726 .887 r
.40597 .4817 .40926 .48532 .41482 .48349 .41154 .47968 Mtetra
.629 .701 .897 r
.41154 .47968 .41482 .48349 .4204 .48125 .4171 .47839 Mtetra
.663 .771 .929 r
.4171 .47839 .4204 .48125 .42596 .48014 .42269 .47658 Mtetra
.651 .723 .902 r
.42269 .47658 .42596 .48014 .43156 .47774 .42828 .47496 Mtetra
.705 .786 .914 r
.42828 .47496 .43156 .47774 .43714 .47694 .43391 .47251 Mtetra
.614 .665 .876 r
.43391 .47251 .43714 .47694 .44274 .47549 .43951 .47148 Mtetra
.623 .69 .892 r
.43951 .47148 .44274 .47549 .44836 .4739 .44512 .47028 Mtetra
.638 .717 .905 r
.44512 .47028 .44836 .4739 .45399 .47278 .45076 .46884 Mtetra
.692 .717 .868 r
.45076 .46884 .45399 .47278 .45962 .47221 .45643 .46647 Mtetra
.637 .622 .819 r
.45643 .46647 .45962 .47221 .46528 .4706 .46209 .46496 Mtetra
.319 .46 .845 r
.46209 .46496 .46528 .4706 .47101 .46561 .4677 .4676 Mtetra
.599 .924 .697 r
.4677 .4676 .47101 .46561 .47661 .46931 .47344 .46288 Mtetra
.426 .491 .823 r
.47344 .46288 .47661 .46931 .48237 .46295 .4791 .4648 Mtetra
.814 .993 .748 r
.4791 .4648 .48237 .46295 .48805 .46383 .48488 .45827 Mtetra
.52 .574 .85 r
.48488 .45827 .48805 .46383 .49381 .45867 .49059 .45872 Mtetra
.829 .979 .883 r
.49059 .45872 .49381 .45867 .49953 .45844 .49636 .45372 Mtetra
.434 .569 .89 r
.49636 .45372 .49953 .45844 .50529 .45453 .5021 .45488 Mtetra
.798 .992 .879 r
.5021 .45488 .50529 .45453 .51104 .45369 .50788 .45009 Mtetra
.606 .711 .919 r
.50788 .45009 .51104 .45369 .51682 .45069 .51366 .44903 Mtetra
.59 .848 .993 r
.51366 .44903 .51682 .45069 .5226 .44901 .51945 .44753 Mtetra
.808 .894 .904 r
.51945 .44753 .5226 .44901 .52839 .44767 .52525 .44323 Mtetra
.558 .645 .892 r
.52525 .44323 .52839 .44767 .53419 .44512 .53106 .44292 Mtetra
.718 .84 .939 r
.53106 .44292 .53419 .44512 .54001 .4439 .53689 .44019 Mtetra
.694 .736 .883 r
.53689 .44019 .54001 .4439 .54584 .4418 .54272 .43777 Mtetra
.6 .686 .902 r
.54272 .43777 .54584 .4418 .55168 .43938 .54858 .43684 Mtetra
.687 .81 .941 r
.54858 .43684 .55168 .43938 .55753 .43758 .55444 .43456 Mtetra
.625 .759 .942 r
.55444 .43456 .55753 .43758 .5634 .43564 .56032 .43314 Mtetra
.735 .824 .92 r
.56032 .43314 .5634 .43564 .56928 .43423 .56619 .43011 Mtetra
.611 .687 .897 r
.56619 .43011 .56928 .43423 .57516 .43152 .5721 .42903 Mtetra
.695 .818 .941 r
.5721 .42903 .57516 .43152 .58107 .43013 .57801 .42662 Mtetra
.698 .753 .894 r
.57801 .42662 .58107 .43013 .58699 .42843 .58392 .42414 Mtetra
.652 .695 .877 r
.58392 .42414 .58699 .42843 .59292 .42643 .58986 .4224 Mtetra
.667 .714 .884 r
.58986 .4224 .59292 .42643 .59885 .42413 .59581 .4204 Mtetra
.617 .714 .914 r
.59581 .4204 .59885 .42413 .6048 .42208 .60179 .41917 Mtetra
.674 .786 .933 r
.60179 .41917 .6048 .42208 .61079 .42101 .60776 .41706 Mtetra
.653 .715 .893 r
.60776 .41706 .61079 .42101 .61676 .41873 .61375 .41529 Mtetra
.66 .747 .914 r
.61375 .41529 .61676 .41873 .62275 .41673 .61976 .4134 Mtetra
.615 .739 .934 r
.61976 .4134 .62275 .41673 .62875 .41444 .62579 .41211 Mtetra
.708 .838 .945 r
.62579 .41211 .62875 .41444 .63478 .41294 .6318 .40945 Mtetra
.626 .734 .925 r
.6318 .40945 .63478 .41294 .64082 .41127 .63785 .40805 Mtetra
.696 .775 .912 r
.63785 .40805 .64082 .41127 .64686 .40914 .64389 .40557 Mtetra
.687 .751 .9 r
.64389 .40557 .64686 .40914 .65295 .40806 .64994 .40323 Mtetra
.535 .62 .883 r
.64994 .40323 .65295 .40806 .65896 .40457 .6561 .40328 Mtetra
.68 .912 .974 r
.6561 .40328 .65896 .40457 .6651 .40402 .66217 .40059 Mtetra
.643 .746 .924 r
.66217 .40059 .6651 .40402 .6712 .40201 .66829 .39891 Mtetra
.482 .701 .965 r
.66829 .39891 .6712 .40201 .67729 .39957 .6745 .3989 Mtetra
.837 .966 .887 r
.6745 .3989 .67729 .39957 .68352 .39988 .68048 .3937 Mtetra
.447 .517 .837 r
.68048 .3937 .68352 .39988 .68952 .39514 .68681 .39539 Mtetra
.83 .998 .834 r
.68681 .39539 .68952 .39514 .69587 .39684 .69278 .38956 Mtetra
.224 .344 .777 r
.69278 .38956 .69587 .39684 .70184 .39126 .69934 .39476 Mtetra
.608 .821 .421 r
.69934 .39476 .70184 .39126 .70835 .39519 .70517 .38622 Mtetra
.417 .425 .76 r
.70517 .38622 .70835 .39519 .71427 .38836 .71168 .38953 Mtetra
.741 .978 .734 r
.71168 .38953 .71427 .38836 .72059 .38821 .71767 .38353 Mtetra
.731 .716 .836 r
.71767 .38353 .72059 .38821 .72684 .38661 .7238 .37991 Mtetra
.61 .591 .806 r
.7238 .37991 .72684 .38661 .73299 .38333 .7301 .37881 Mtetra
.676 .703 .867 r
.7301 .37881 .73299 .38333 .73918 .38048 .73633 .37649 Mtetra
.696 .738 .884 r
.73633 .37649 .73918 .38048 .74542 .37819 .74256 .37388 Mtetra
.703 .725 .867 r
.74256 .37388 .74542 .37819 .75168 .37588 .74879 .37105 Mtetra
.639 .674 .867 r
.74879 .37105 .75168 .37588 .7579 .37297 .75511 .36942 Mtetra
.658 .751 .919 r
.75511 .36942 .7579 .37297 .76422 .37121 .76142 .36747 Mtetra
.682 .749 .902 r
.76142 .36747 .76422 .37121 .7705 .36879 .76772 .36511 Mtetra
.671 .749 .909 r
.76772 .36511 .7705 .36879 .77685 .36712 .77405 .36294 Mtetra
.651 .713 .893 r
.77405 .36294 .77685 .36712 .78318 .36492 .78041 .3611 Mtetra
.665 .739 .905 r
.78041 .3611 .78318 .36492 .78952 .3627 .78678 .35903 Mtetra
.665 .749 .913 r
.78678 .35903 .78952 .3627 .79589 .36065 .79315 .35695 Mtetra
.67 .749 .91 r
.79315 .35695 .79589 .36065 .80228 .35869 .79954 .35477 Mtetra
.676 .739 .898 r
.79954 .35477 .80228 .35869 .80867 .35657 .80592 .35249 Mtetra
.648 .719 .9 r
.80592 .35249 .80867 .35657 .81505 .3542 .81237 .35067 Mtetra
.668 .761 .92 r
.81237 .35067 .81505 .3542 .82151 .35247 .81879 .34852 Mtetra
.664 .734 .902 r
.81879 .34852 .82151 .35247 .82792 .35013 .82524 .34642 Mtetra
.668 .751 .912 r
.82524 .34642 .82792 .35013 .8344 .34826 .8317 .34427 Mtetra
.657 .73 .903 r
.8317 .34427 .8344 .34826 .84084 .34599 .83819 .34229 Mtetra
.67 .753 .913 r
.83819 .34229 .84084 .34599 .84732 .34385 .84467 .34009 Mtetra
.672 .751 .91 r
.84467 .34009 .84732 .34385 .85383 .34189 .85116 .33784 Mtetra
.651 .726 .903 r
.85116 .33784 .85383 .34189 .86036 .33993 .8577 .33594 Mtetra
.655 .732 .906 r
.8577 .33594 .86036 .33993 .86687 .33771 .86426 .33398 Mtetra
.672 .754 .913 r
.86426 .33398 .86687 .33771 .8734 .33549 .87079 .33173 Mtetra
.67 .752 .912 r
.87079 .33173 .8734 .33549 .87996 .33346 .87734 .3295 Mtetra
.659 .736 .906 r
.87734 .3295 .87996 .33346 .88653 .33136 .88393 .32745 Mtetra
.665 .742 .908 r
.88393 .32745 .88653 .33136 .8931 .3291 .89052 .3253 Mtetra
.674 .753 .91 r
.89052 .3253 .8931 .3291 .89971 .32706 .89711 .32298 Mtetra
.659 .745 .914 r
.30436 .51003 .3078 .51315 .31315 .51152 .30972 .50836 Mtetra
.671 .746 .907 r
.30972 .50836 .31315 .51152 .31852 .50983 .31511 .50652 Mtetra
.659 .734 .905 r
.31511 .50652 .31852 .50983 .3239 .50805 .32049 .50484 Mtetra
.659 .741 .91 r
.32049 .50484 .3239 .50805 .32929 .50642 .32589 .50316 Mtetra
.672 .741 .903 r
.32589 .50316 .32929 .50642 .3347 .50467 .33131 .50129 Mtetra
.643 .727 .909 r
.33131 .50129 .3347 .50467 .34012 .50273 .33671 .49983 Mtetra
.668 .764 .922 r
.33671 .49983 .34012 .50273 .34554 .50124 .34215 .498 Mtetra
.679 .745 .901 r
.34215 .498 .34554 .50124 .35098 .49946 .34761 .496 Mtetra
.658 .727 .9 r
.34761 .496 .35098 .49946 .35643 .49755 .35306 .49432 Mtetra
.656 .741 .912 r
.35306 .49432 .35643 .49755 .36189 .49577 .35852 .49266 Mtetra
.67 .752 .912 r
.35852 .49266 .36189 .49577 .36735 .49423 .364 .49079 Mtetra
.654 .728 .904 r
.364 .49079 .36735 .49423 .37285 .49214 .36949 .48915 Mtetra
.679 .763 .914 r
.36949 .48915 .37285 .49214 .37833 .49073 .375 .48714 Mtetra
.646 .718 .9 r
.375 .48714 .37833 .49073 .38384 .48882 .3805 .48562 Mtetra
.668 .748 .91 r
.3805 .48562 .38384 .48882 .38936 .48692 .38603 .48376 Mtetra
.672 .752 .911 r
.38603 .48376 .38936 .48692 .39489 .48524 .39157 .48184 Mtetra
.664 .736 .903 r
.39157 .48184 .39489 .48524 .40042 .48351 .39711 .48003 Mtetra
.657 .729 .903 r
.39711 .48003 .40042 .48351 .40597 .4817 .40267 .47834 Mtetra
.653 .736 .91 r
.40267 .47834 .40597 .4817 .41154 .47968 .40823 .4767 Mtetra
.66 .762 .926 r
.40823 .4767 .41154 .47968 .4171 .47839 .41381 .47494 Mtetra
.683 .739 .894 r
.41381 .47494 .4171 .47839 .42269 .47658 .41941 .47282 Mtetra
.631 .707 .9 r
.41941 .47282 .42269 .47658 .42828 .47496 .425 .47149 Mtetra
.656 .732 .905 r
.425 .47149 .42828 .47496 .43391 .47251 .43062 .46978 Mtetra
.677 .785 .931 r
.43062 .46978 .43391 .47251 .43951 .47148 .43625 .46775 Mtetra
.666 .72 .89 r
.43625 .46775 .43951 .47148 .44512 .47028 .44189 .46588 Mtetra
.631 .674 .873 r
.44189 .46588 .44512 .47028 .45076 .46884 .44753 .46455 Mtetra
.566 .654 .895 r
.44753 .46455 .45076 .46884 .45643 .46647 .45316 .46413 Mtetra
.483 .751 .989 r
.45316 .46413 .45643 .46647 .46209 .46496 .45881 .46379 Mtetra
.817 .906 .902 r
.45881 .46379 .46209 .46496 .4677 .4676 .46455 .45936 Mtetra
.351 .394 .765 r
.46455 .45936 .4677 .4676 .47344 .46288 .47016 .46297 Mtetra
.806 .981 .895 r
.47016 .46297 .47344 .46288 .4791 .4648 .47593 .45834 Mtetra
.345 .443 .819 r
.47593 .45834 .4791 .4648 .48488 .45827 .48159 .46117 Mtetra
.886 .97 .653 r
.48159 .46117 .48488 .45827 .49059 .45872 .48743 .45179 Mtetra
.4 .46 .807 r
.48743 .45179 .49059 .45872 .49636 .45372 .49313 .45423 Mtetra
.832 .993 .856 r
.49313 .45423 .49636 .45372 .5021 .45488 .49893 .44882 Mtetra
.601 .598 .82 r
.49893 .44882 .5021 .45488 .50788 .45009 .5047 .44799 Mtetra
.631 .826 .975 r
.5047 .44799 .50788 .45009 .51366 .44903 .51048 .4463 Mtetra
.797 .81 .863 r
.51048 .4463 .51366 .44903 .51945 .44753 .51629 .44185 Mtetra
.6 .611 .834 r
.51629 .44185 .51945 .44753 .52525 .44323 .5221 .44104 Mtetra
.57 .801 .986 r
.5221 .44104 .52525 .44323 .53106 .44292 .52792 .43993 Mtetra
.763 .794 .878 r
.52792 .43993 .53106 .44292 .53689 .44019 .53375 .43624 Mtetra
.568 .678 .914 r
.53375 .43624 .53689 .44019 .54272 .43777 .5396 .4357 Mtetra
.724 .852 .942 r
.5396 .4357 .54272 .43777 .54858 .43684 .54546 .43286 Mtetra
.695 .724 .872 r
.54546 .43286 .54858 .43684 .55444 .43456 .55132 .43036 Mtetra
.615 .684 .892 r
.55132 .43036 .55444 .43456 .56032 .43314 .55721 .42922 Mtetra
.711 .733 .868 r
.55721 .42922 .56032 .43314 .56619 .43011 .5631 .42641 Mtetra
.581 .699 .923 r
.5631 .42641 .56619 .43011 .5721 .42903 .56902 .42565 Mtetra
.672 .753 .911 r
.56902 .42565 .5721 .42903 .57801 .42662 .57494 .42359 Mtetra
.691 .781 .92 r
.57494 .42359 .57801 .42662 .58392 .42414 .58087 .42124 Mtetra
.629 .772 .949 r
.58087 .42124 .58392 .42414 .58986 .4224 .58682 .41972 Mtetra
.642 .793 .955 r
.58682 .41972 .58986 .4224 .59581 .4204 .59278 .418 Mtetra
.666 .82 .958 r
.59278 .418 .59581 .4204 .60179 .41917 .59875 .41593 Mtetra
.728 .779 .893 r
.59875 .41593 .60179 .41917 .60776 .41706 .60471 .41288 Mtetra
.569 .669 .906 r
.60471 .41288 .60776 .41706 .61375 .41529 .61074 .41234 Mtetra
.72 .798 .912 r
.61074 .41234 .61375 .41529 .61976 .4134 .61673 .40948 Mtetra
.634 .711 .903 r
.61673 .40948 .61976 .4134 .62579 .41211 .62277 .408 Mtetra
.663 .712 .885 r
.62277 .408 .62579 .41211 .6318 .40945 .6288 .40605 Mtetra
.681 .759 .91 r
.6288 .40605 .6318 .40945 .63785 .40805 .63484 .40381 Mtetra
.53 .649 .91 r
.63484 .40381 .63785 .40805 .64389 .40557 .64097 .40376 Mtetra
.773 .889 .928 r
.64097 .40376 .64389 .40557 .64994 .40323 .64698 .40001 Mtetra
.567 .731 .952 r
.64698 .40001 .64994 .40323 .6561 .40328 .65312 .39923 Mtetra
.584 .685 .911 r
.65312 .39923 .6561 .40328 .66217 .40059 .65927 .39845 Mtetra
.799 .87 .901 r
.65927 .39845 .66217 .40059 .66829 .39891 .66529 .39415 Mtetra
.465 .589 .893 r
.66529 .39415 .66829 .39891 .6745 .3989 .67155 .39503 Mtetra
.593 .701 .918 r
.67155 .39503 .6745 .3989 .68048 .3937 .67775 .39409 Mtetra
.708 .986 .852 r
.67775 .39409 .68048 .3937 .68681 .39539 .68379 .38964 Mtetra
.179 .372 .818 r
.68379 .38964 .68681 .39539 .69278 .38956 .69029 .39407 Mtetra
0 0 0 r
.69029 .39407 .69278 .38956 .69934 .39476 .69608 .38448 Mtetra
.379 .378 .732 r
.69608 .38448 .69934 .39476 .70517 .38622 .70265 .38909 Mtetra
.756 .908 .525 r
.70265 .38909 .70517 .38622 .71168 .38953 .70845 .37987 Mtetra
.519 .475 .748 r
.70845 .37987 .71168 .38953 .71767 .38353 .71487 .38114 Mtetra
.735 .851 .935 r
.71487 .38114 .71767 .38353 .7238 .37991 .72104 .37796 Mtetra
.761 .889 .935 r
.72104 .37796 .7238 .37991 .7301 .37881 .72719 .37434 Mtetra
.695 .714 .863 r
.72719 .37434 .7301 .37881 .73633 .37649 .73341 .37164 Mtetra
.661 .683 .86 r
.73341 .37164 .73633 .37649 .74256 .37388 .73969 .36958 Mtetra
.65 .705 .887 r
.73969 .36958 .74256 .37388 .74879 .37105 .74599 .36776 Mtetra
.662 .77 .93 r
.74599 .36776 .74879 .37105 .75511 .36942 .7523 .36572 Mtetra
.7 .758 .897 r
.7523 .36572 .75511 .36942 .76142 .36747 .75857 .36305 Mtetra
.637 .694 .887 r
.75857 .36305 .76142 .36747 .76772 .36511 .76494 .36145 Mtetra
.678 .754 .908 r
.76494 .36145 .76772 .36511 .77405 .36294 .77126 .35915 Mtetra
.679 .747 .903 r
.77126 .35915 .77405 .36294 .78041 .3611 .7776 .35684 Mtetra
.656 .712 .889 r
.7776 .35684 .78041 .3611 .78678 .35903 .78399 .3549 Mtetra
.664 .723 .893 r
.78399 .3549 .78678 .35903 .79315 .35695 .79037 .35283 Mtetra
.663 .724 .894 r
.79037 .35283 .79315 .35695 .79954 .35477 .79677 .35075 Mtetra
.652 .725 .903 r
.79677 .35075 .79954 .35477 .80592 .35249 .80321 .34887 Mtetra
.664 .755 .918 r
.80321 .34887 .80592 .35249 .81237 .35067 .80964 .34678 Mtetra
.675 .743 .902 r
.80964 .34678 .81237 .35067 .81879 .34852 .81606 .3445 Mtetra
.65 .725 .904 r
.81606 .3445 .81879 .34852 .82524 .34642 .82254 .34263 Mtetra
.674 .75 .907 r
.82254 .34263 .82524 .34642 .8317 .34427 .829 .34036 Mtetra
.662 .738 .906 r
.829 .34036 .8317 .34427 .83819 .34229 .83549 .33828 Mtetra
.658 .731 .903 r
.83549 .33828 .83819 .34229 .84467 .34009 .842 .33627 Mtetra
.664 .745 .91 r
.842 .33627 .84467 .34009 .85116 .33784 .84852 .33415 Mtetra
.673 .757 .914 r
.84852 .33415 .85116 .33784 .8577 .33594 .85503 .33189 Mtetra
.657 .729 .903 r
.85503 .33189 .8577 .33594 .86426 .33398 .86159 .32989 Mtetra
.652 .725 .903 r
.86159 .32989 .86426 .33398 .87079 .33173 .86818 .32797 Mtetra
.672 .754 .912 r
.86818 .32797 .87079 .33173 .87734 .3295 .87474 .32569 Mtetra
.673 .752 .91 r
.87474 .32569 .87734 .3295 .88393 .32745 .88131 .3234 Mtetra
.654 .73 .905 r
.88131 .3234 .88393 .32745 .89052 .3253 .88793 .32142 Mtetra
.669 .747 .909 r
.88793 .32142 .89052 .3253 .89711 .32298 .89454 .31918 Mtetra
.669 .742 .905 r
.30091 .50682 .30436 .51003 .30972 .50836 .30629 .505 Mtetra
.657 .731 .904 r
.30629 .505 .30972 .50836 .31511 .50652 .31167 .50335 Mtetra
.66 .744 .912 r
.31167 .50335 .31511 .50652 .32049 .50484 .31706 .50166 Mtetra
.669 .745 .908 r
.31706 .50166 .32049 .50484 .32589 .50316 .32247 .49983 Mtetra
.646 .731 .91 r
.32247 .49983 .32589 .50316 .33131 .50129 .32788 .49832 Mtetra
.668 .759 .918 r
.32788 .49832 .33131 .50129 .33671 .49983 .33331 .49648 Mtetra
.677 .738 .897 r
.33331 .49648 .33671 .49983 .34215 .498 .33876 .49451 Mtetra
.655 .725 .9 r
.33876 .49451 .34215 .498 .34761 .496 .34421 .49286 Mtetra
.663 .748 .914 r
.34421 .49286 .34761 .496 .35306 .49432 .34967 .49109 Mtetra
.667 .745 .909 r
.34967 .49109 .35306 .49432 .35852 .49266 .35515 .48927 Mtetra
.663 .734 .903 r
.35515 .48927 .35852 .49266 .364 .49079 .36063 .4875 Mtetra
.658 .739 .91 r
.36063 .4875 .364 .49079 .36949 .48915 .36613 .4858 Mtetra
.665 .738 .904 r
.36613 .4858 .36949 .48915 .375 .48714 .37163 .48399 Mtetra
.672 .753 .911 r
.37163 .48399 .375 .48714 .3805 .48562 .37716 .48207 Mtetra
.65 .723 .902 r
.37716 .48207 .3805 .48562 .38603 .48376 .38268 .48048 Mtetra
.662 .742 .909 r
.38268 .48048 .38603 .48376 .39157 .48184 .38822 .4787 Mtetra
.662 .752 .916 r
.38822 .4787 .39157 .48184 .39711 .48003 .39378 .47691 Mtetra
.657 .752 .92 r
.39378 .47691 .39711 .48003 .40267 .47834 .39934 .47519 Mtetra
.665 .753 .916 r
.39934 .47519 .40267 .47834 .40823 .4767 .40492 .47336 Mtetra
.685 .747 .898 r
.40492 .47336 .40823 .4767 .41381 .47494 .41052 .47121 Mtetra
.635 .71 .901 r
.41052 .47121 .41381 .47494 .41941 .47282 .4161 .46982 Mtetra
.688 .77 .914 r
.4161 .46982 .41941 .47282 .425 .47149 .42173 .46763 Mtetra
.63 .702 .897 r
.42173 .46763 .425 .47149 .43062 .46978 .42733 .46631 Mtetra
.654 .732 .907 r
.42733 .46631 .43062 .46978 .43625 .46775 .43296 .46463 Mtetra
.655 .755 .923 r
.43296 .46463 .43625 .46775 .44189 .46588 .43861 .46291 Mtetra
.641 .761 .935 r
.43861 .46291 .44189 .46588 .44753 .46455 .44426 .46135 Mtetra
.659 .751 .918 r
.44426 .46135 .44753 .46455 .45316 .46413 .44993 .45958 Mtetra
.699 .693 .84 r
.44993 .45958 .45316 .46413 .45881 .46379 .45563 .4569 Mtetra
.458 .494 .809 r
.45563 .4569 .45881 .46379 .46455 .45936 .46126 .45852 Mtetra
.778 .933 .933 r
.46126 .45852 .46455 .45936 .47016 .46297 .46701 .45475 Mtetra
.291 .357 .759 r
.46701 .45475 .47016 .46297 .47593 .45834 .47263 .4591 Mtetra
.932 .954 .773 r
.47263 .4591 .47593 .45834 .48159 .46117 .47847 .45073 Mtetra
.312 .325 .714 r
.47847 .45073 .48159 .46117 .48743 .45179 .48412 .45603 Mtetra
0 0 0 r
.48412 .45603 .48743 .45179 .49313 .45423 .48992 .45121 Mtetra
.793 .792 .851 r
.48992 .45121 .49313 .45423 .49893 .44882 .49572 .4467 Mtetra
.003 .49 .866 r
.49572 .4467 .49893 .44882 .5047 .44799 .50148 .44861 Mtetra
.831 .996 .846 r
.50148 .44861 .5047 .44799 .51048 .4463 .5073 .44306 Mtetra
.712 .768 .896 r
.5073 .44306 .51048 .4463 .51629 .44185 .51311 .44038 Mtetra
.382 .774 .988 r
.51311 .44038 .51629 .44185 .5221 .44104 .51893 .44004 Mtetra
.811 .928 .911 r
.51893 .44004 .5221 .44104 .52792 .43993 .52477 .43565 Mtetra
.689 .707 .861 r
.52477 .43565 .52792 .43993 .53375 .43624 .53061 .43322 Mtetra
.546 .73 .96 r
.53061 .43322 .53375 .43624 .5396 .4357 .53647 .43264 Mtetra
.711 .781 .907 r
.53647 .43264 .5396 .4357 .54546 .43286 .54233 .42998 Mtetra
.637 .774 .946 r
.54233 .42998 .54546 .43286 .55132 .43036 .54821 .42838 Mtetra
.7 .857 .957 r
.54821 .42838 .55132 .43036 .55721 .42922 .5541 .42583 Mtetra
.663 .749 .914 r
.5541 .42583 .55721 .42922 .5631 .42641 .56 .42391 Mtetra
.705 .821 .937 r
.56 .42391 .5631 .42641 .56902 .42565 .56591 .42135 Mtetra
.607 .678 .891 r
.56591 .42135 .56902 .42565 .57494 .42359 .57185 .42032 Mtetra
.66 .757 .922 r
.57185 .42032 .57494 .42359 .58087 .42124 .5778 .41844 Mtetra
.678 .794 .936 r
.5778 .41844 .58087 .42124 .58682 .41972 .58375 .41626 Mtetra
.629 .735 .924 r
.58375 .41626 .58682 .41972 .59278 .418 .58973 .41482 Mtetra
.688 .773 .916 r
.58973 .41482 .59278 .418 .59875 .41593 .5957 .4125 Mtetra
.713 .766 .893 r
.5957 .4125 .59875 .41593 .60471 .41288 .60167 .40971 Mtetra
.601 .745 .946 r
.60167 .40971 .60471 .41288 .61074 .41234 .6077 .40856 Mtetra
.674 .734 .895 r
.6077 .40856 .61074 .41234 .61673 .40948 .61371 .40642 Mtetra
.617 .76 .947 r
.61371 .40642 .61673 .40948 .62277 .408 .61976 .40504 Mtetra
.603 .762 .955 r
.61976 .40504 .62277 .408 .6288 .40605 .62583 .4038 Mtetra
.762 .856 .92 r
.62583 .4038 .6288 .40605 .63484 .40381 .63184 .40023 Mtetra
.529 .69 .941 r
.63184 .40023 .63484 .40381 .64097 .40376 .63797 .39996 Mtetra
.633 .72 .91 r
.63797 .39996 .64097 .40376 .64698 .40001 .64408 .39846 Mtetra
.766 .909 .938 r
.64408 .39846 .64698 .40001 .65312 .39923 .65011 .39478 Mtetra
.443 .595 .907 r
.65011 .39478 .65312 .39923 .65927 .39845 .65634 .39575 Mtetra
.465 .724 .981 r
.65634 .39575 .65927 .39845 .66529 .39415 .66255 .39564 Mtetra
.777 .979 .712 r
.66255 .39564 .66529 .39415 .67155 .39503 .66849 .38897 Mtetra
.281 .424 .828 r
.66849 .38897 .67155 .39503 .67775 .39409 .6749 .39255 Mtetra
.677 .898 .976 r
.6749 .39255 .67775 .39409 .68379 .38964 .68105 .38995 Mtetra
.703 .985 .86 r
.68105 .38995 .68379 .38964 .69029 .39407 .68712 .38561 Mtetra
.43 .444 .773 r
.68712 .38561 .69029 .39407 .69608 .38448 .69357 .38841 Mtetra
.683 .837 .41 r
.69357 .38841 .69608 .38448 .70265 .38909 .69935 .37821 Mtetra
.512 .453 .727 r
.69935 .37821 .70265 .38909 .70845 .37987 .70577 .37983 Mtetra
.816 .995 .86 r
.70577 .37983 .70845 .37987 .71487 .38114 .71181 .37442 Mtetra
.641 .607 .8 r
.71181 .37442 .71487 .38114 .72104 .37796 .71807 .37256 Mtetra
.651 .655 .841 r
.71807 .37256 .72104 .37796 .72719 .37434 .72433 .37064 Mtetra
.681 .751 .903 r
.72433 .37064 .72719 .37434 .73341 .37164 .73059 .36831 Mtetra
.672 .77 .924 r
.73059 .36831 .73341 .37164 .73969 .36958 .73686 .36613 Mtetra
.67 .763 .92 r
.73686 .36613 .73969 .36958 .74599 .36776 .74316 .36397 Mtetra
.689 .75 .898 r
.74316 .36397 .74599 .36776 .7523 .36572 .74944 .36148 Mtetra
.652 .71 .891 r
.74944 .36148 .7523 .36572 .75857 .36305 .75578 .35962 Mtetra
.677 .768 .92 r
.75578 .35962 .75857 .36305 .76494 .36145 .76211 .35735 Mtetra
.647 .717 .899 r
.76211 .35735 .76494 .36145 .77126 .35915 .76848 .35555 Mtetra
.671 .756 .915 r
.76848 .35555 .77126 .35915 .7776 .35684 .77484 .35337 Mtetra
.672 .765 .92 r
.77484 .35337 .7776 .35684 .78399 .3549 .78122 .35116 Mtetra
.662 .745 .912 r
.78122 .35116 .78399 .3549 .79037 .35283 .78762 .34911 Mtetra
.658 .746 .915 r
.78762 .34911 .79037 .35283 .79677 .35075 .79404 .34712 Mtetra
.667 .755 .916 r
.79404 .34712 .79677 .35075 .80321 .34887 .80046 .34499 Mtetra
.677 .744 .901 r
.80046 .34499 .80321 .34887 .80964 .34678 .80688 .34267 Mtetra
.647 .72 .901 r
.80688 .34267 .80964 .34678 .81606 .3445 .81336 .34085 Mtetra
.677 .759 .913 r
.81336 .34085 .81606 .3445 .82254 .34263 .81981 .33853 Mtetra
.652 .723 .901 r
.81981 .33853 .82254 .34263 .829 .34036 .82631 .33662 Mtetra
.674 .754 .911 r
.82631 .33662 .829 .34036 .83549 .33828 .83279 .33434 Mtetra
.665 .739 .905 r
.83279 .33434 .83549 .33828 .842 .33627 .8393 .3322 Mtetra
.657 .729 .902 r
.8393 .3322 .842 .33627 .84852 .33415 .84584 .33019 Mtetra
.654 .734 .908 r
.84584 .33019 .84852 .33415 .85503 .33189 .8524 .32822 Mtetra
.669 .758 .917 r
.8524 .32822 .85503 .33189 .86159 .32989 .85894 .326 Mtetra
.668 .745 .908 r
.85894 .326 .86159 .32989 .86818 .32797 .86551 .32379 Mtetra
.651 .722 .9 r
.86551 .32379 .86818 .32797 .87474 .32569 .87212 .32187 Mtetra
.673 .752 .91 r
.87212 .32187 .87474 .32569 .88131 .3234 .8787 .31957 Mtetra
.672 .752 .911 r
.8787 .31957 .88131 .3234 .88793 .32142 .8853 .31728 Mtetra
.65 .725 .904 r
.8853 .31728 .88793 .32142 .89454 .31918 .89196 .31536 Mtetra
.654 .732 .906 r
.29746 .50348 .30091 .50682 .30629 .505 .30283 .50187 Mtetra
.662 .747 .913 r
.30283 .50187 .30629 .505 .31167 .50335 .30822 .50014 Mtetra
.67 .744 .906 r
.30822 .50014 .31167 .50335 .31706 .50166 .31363 .49829 Mtetra
.648 .73 .908 r
.31363 .49829 .31706 .50166 .32247 .49983 .31903 .49675 Mtetra
.669 .753 .913 r
.31903 .49675 .32247 .49983 .32788 .49832 .32446 .49491 Mtetra
.667 .733 .899 r
.32446 .49491 .32788 .49832 .33331 .49648 .3299 .49308 Mtetra
.655 .73 .905 r
.3299 .49308 .33331 .49648 .33876 .49451 .33534 .49144 Mtetra
.67 .755 .914 r
.33534 .49144 .33876 .49451 .34421 .49286 .34081 .48956 Mtetra
.667 .741 .905 r
.34081 .48956 .34421 .49286 .34967 .49109 .34628 .48773 Mtetra
.664 .736 .904 r
.34628 .48773 .34967 .49109 .35515 .48927 .35176 .48594 Mtetra
.651 .735 .911 r
.35176 .48594 .35515 .48927 .36063 .4875 .35724 .48434 Mtetra
.678 .753 .907 r
.35724 .48434 .36063 .4875 .36613 .4858 .36276 .48233 Mtetra
.647 .726 .906 r
.36276 .48233 .36613 .4858 .37163 .48399 .36826 .48078 Mtetra
.666 .748 .911 r
.36826 .48078 .37163 .48399 .37716 .48207 .37379 .47895 Mtetra
.674 .756 .912 r
.37379 .47895 .37716 .48207 .38268 .48048 .37933 .47699 Mtetra
.661 .731 .901 r
.37933 .47699 .38268 .48048 .38822 .4787 .38488 .47523 Mtetra
.662 .732 .902 r
.38488 .47523 .38822 .4787 .39378 .47691 .39044 .47344 Mtetra
.668 .735 .9 r
.39044 .47344 .39378 .47691 .39934 .47519 .39601 .47156 Mtetra
.662 .724 .895 r
.39601 .47156 .39934 .47519 .40492 .47336 .4016 .46977 Mtetra
.635 .718 .907 r
.4016 .46977 .40492 .47336 .41052 .47121 .40718 .46836 Mtetra
.678 .777 .925 r
.40718 .46836 .41052 .47121 .4161 .46982 .41279 .46631 Mtetra
.635 .724 .912 r
.41279 .46631 .4161 .46982 .42173 .46763 .4184 .46489 Mtetra
.697 .79 .922 r
.4184 .46489 .42173 .46763 .42733 .46631 .42405 .46256 Mtetra
.657 .717 .893 r
.42405 .46256 .42733 .46631 .43296 .46463 .42969 .46082 Mtetra
.643 .71 .896 r
.42969 .46082 .43296 .46463 .43861 .46291 .43533 .45929 Mtetra
.671 .73 .894 r
.43533 .45929 .43861 .46291 .44426 .46135 .441 .45732 Mtetra
.668 .708 .877 r
.441 .45732 .44426 .46135 .44993 .45958 .44668 .45537 Mtetra
.545 .651 .904 r
.44668 .45537 .44993 .45958 .45563 .4569 .45234 .45516 Mtetra
.705 .866 .958 r
.45234 .45516 .45563 .4569 .46126 .45852 .45806 .45258 Mtetra
.504 .553 .839 r
.45806 .45258 .46126 .45852 .46701 .45475 .46372 .45329 Mtetra
.827 .887 .886 r
.46372 .45329 .46701 .45475 .47263 .4591 .46951 .44855 Mtetra
.311 .323 .712 r
.46951 .44855 .47263 .4591 .47847 .45073 .47514 .45386 Mtetra
.255 0 0 r
.47514 .45386 .47847 .45073 .48412 .45603 .48089 .45267 Mtetra
.86 .772 .763 r
.48089 .45267 .48412 .45603 .48992 .45121 .48674 .44456 Mtetra
.37 .453 .816 r
.48674 .44456 .48992 .45121 .49572 .4467 .49247 .44719 Mtetra
.426 .87 .841 r
.49247 .44719 .49572 .4467 .50148 .44861 .49828 .44496 Mtetra
.841 .763 .777 r
.49828 .44496 .50148 .44861 .5073 .44306 .50412 .43778 Mtetra
.495 .576 .866 r
.50412 .43778 .5073 .44306 .51311 .44038 .50992 .43844 Mtetra
.461 .777 .998 r
.50992 .43844 .51311 .44038 .51893 .44004 .51575 .43796 Mtetra
.835 .852 .858 r
.51575 .43796 .51893 .44004 .52477 .43565 .5216 .4327 Mtetra
.649 .772 .939 r
.5216 .4327 .52477 .43565 .53061 .43322 .52745 .43097 Mtetra
.596 .808 .981 r
.52745 .43097 .53061 .43322 .53647 .43264 .53331 .42963 Mtetra
.741 .792 .894 r
.53331 .42963 .53647 .43264 .54233 .42998 .53919 .4264 Mtetra
.674 .741 .901 r
.53919 .4264 .54233 .42998 .54821 .42838 .54507 .42432 Mtetra
.58 .679 .908 r
.54507 .42432 .54821 .42838 .5541 .42583 .55098 .42362 Mtetra
.731 .846 .935 r
.55098 .42362 .5541 .42583 .56 .42391 .55689 .42065 Mtetra
.671 .761 .918 r
.55689 .42065 .56 .42391 .56591 .42135 .56281 .41861 Mtetra
.591 .771 .965 r
.56281 .41861 .56591 .42135 .57185 .42032 .56876 .41745 Mtetra
.695 .795 .927 r
.56876 .41745 .57185 .42032 .5778 .41844 .57471 .41503 Mtetra
.687 .759 .906 r
.57471 .41503 .5778 .41844 .58375 .41626 .58067 .41272 Mtetra
.651 .739 .914 r
.58067 .41272 .58375 .41626 .58973 .41482 .58665 .41097 Mtetra
.67 .728 .893 r
.58665 .41097 .58973 .41482 .5957 .4125 .59263 .40891 Mtetra
.685 .748 .899 r
.59263 .40891 .5957 .4125 .60167 .40971 .59863 .40659 Mtetra
.54 .726 .96 r
.59863 .40659 .60167 .40971 .6077 .40856 .60468 .40605 Mtetra
.747 .834 .918 r
.60468 .40605 .6077 .40856 .61371 .40642 .61067 .40274 Mtetra
.541 .688 .935 r
.61067 .40274 .61371 .40642 .61976 .40504 .61676 .40237 Mtetra
.682 .81 .944 r
.61676 .40237 .61976 .40504 .62583 .4038 .62281 .40009 Mtetra
.723 .756 .878 r
.62281 .40009 .62583 .4038 .63184 .40023 .62884 .39702 Mtetra
.513 .708 .959 r
.62884 .39702 .63184 .40023 .63797 .39996 .63498 .39675 Mtetra
.424 .666 .962 r
.63498 .39675 .63797 .39996 .64408 .39846 .64117 .39725 Mtetra
.832 .932 .896 r
.64117 .39725 .64408 .39846 .65011 .39478 .64717 .39229 Mtetra
.449 .734 .988 r
.64717 .39229 .65011 .39478 .65634 .39575 .65337 .39217 Mtetra
.256 .546 .926 r
.65337 .39217 .65634 .39575 .66255 .39564 .65967 .39415 Mtetra
.845 .915 .882 r
.65967 .39415 .66255 .39564 .66849 .38897 .66569 .38885 Mtetra
.553 .928 .914 r
.66569 .38885 .66849 .38897 .6749 .39255 .67182 .38618 Mtetra
.223 .376 .807 r
.67182 .38618 .6749 .39255 .68105 .38995 .67831 .39059 Mtetra
.827 .999 .798 r
.67831 .39059 .68105 .38995 .68712 .38561 .68431 .38431 Mtetra
.874 .926 .856 r
.68431 .38431 .68712 .38561 .69357 .38841 .6903 .37819 Mtetra
.559 .491 .735 r
.6903 .37819 .69357 .38841 .69935 .37821 .69664 .37836 Mtetra
.839 .997 .834 r
.69664 .37836 .69935 .37821 .70577 .37983 .70265 .37238 Mtetra
.576 .554 .793 r
.70265 .37238 .70577 .37983 .71181 .37442 .70899 .37202 Mtetra
.76 .856 .922 r
.70899 .37202 .71181 .37442 .71807 .37256 .71515 .36841 Mtetra
.679 .725 .884 r
.71515 .36841 .71807 .37256 .72433 .37064 .72141 .36608 Mtetra
.648 .692 .877 r
.72141 .36608 .72433 .37064 .73059 .36831 .7277 .36428 Mtetra
.677 .732 .891 r
.7277 .36428 .73059 .36831 .73686 .36613 .73398 .36199 Mtetra
.679 .727 .886 r
.73398 .36199 .73686 .36613 .74316 .36397 .74027 .35965 Mtetra
.629 .697 .894 r
.74027 .35965 .74316 .36397 .74944 .36148 .74664 .35816 Mtetra
.675 .775 .925 r
.74664 .35816 .74944 .36148 .75578 .35962 .75296 .35592 Mtetra
.666 .748 .911 r
.75296 .35592 .75578 .35962 .76211 .35735 .75931 .3538 Mtetra
.685 .766 .912 r
.75931 .3538 .76211 .35735 .76848 .35555 .76565 .35138 Mtetra
.651 .716 .896 r
.76565 .35138 .76848 .35555 .77484 .35337 .77204 .34952 Mtetra
.66 .738 .908 r
.77204 .34952 .77484 .35337 .78122 .35116 .77844 .34749 Mtetra
.664 .752 .915 r
.77844 .34749 .78122 .35116 .78762 .34911 .78485 .3454 Mtetra
.673 .753 .911 r
.78485 .3454 .78762 .34911 .79404 .34712 .79126 .34315 Mtetra
.668 .736 .901 r
.79126 .34315 .79404 .34712 .80046 .34499 .79769 .34099 Mtetra
.651 .728 .905 r
.79769 .34099 .80046 .34499 .80688 .34267 .80416 .33909 Mtetra
.673 .763 .918 r
.80416 .33909 .80688 .34267 .81336 .34085 .81061 .33683 Mtetra
.658 .731 .903 r
.81061 .33683 .81336 .34085 .81981 .33853 .8171 .33482 Mtetra
.672 .755 .913 r
.8171 .33482 .81981 .33853 .82631 .33662 .82358 .33258 Mtetra
.656 .729 .903 r
.82358 .33258 .82631 .33662 .83279 .33434 .8301 .33059 Mtetra
.671 .753 .912 r
.8301 .33059 .83279 .33434 .8393 .3322 .83661 .32834 Mtetra
.668 .746 .909 r
.83661 .32834 .8393 .3322 .84584 .33019 .84314 .32614 Mtetra
.661 .733 .903 r
.84314 .32614 .84584 .33019 .8524 .32822 .8497 .32405 Mtetra
.649 .722 .902 r
.8497 .32405 .8524 .32822 .85894 .326 .85629 .32217 Mtetra
.664 .748 .913 r
.85629 .32217 .85894 .326 .86551 .32379 .86287 .32002 Mtetra
.677 .758 .912 r
.86287 .32002 .86551 .32379 .87212 .32187 .86945 .31764 Mtetra
.649 .72 .9 r
.86945 .31764 .87212 .32187 .8787 .31957 .87608 .31574 Mtetra
.672 .753 .912 r
.87608 .31574 .8787 .31957 .8853 .31728 .8827 .31345 Mtetra
.669 .752 .912 r
.8827 .31345 .8853 .31728 .89196 .31536 .88933 .31119 Mtetra
.667 .75 .913 r
.29398 .50038 .29746 .50348 .30283 .50187 .29937 .49858 Mtetra
.667 .739 .904 r
.29937 .49858 .30283 .50187 .30822 .50014 .30477 .49677 Mtetra
.653 .731 .907 r
.30477 .49677 .30822 .50014 .31363 .49829 .31017 .49517 Mtetra
.667 .75 .913 r
.31017 .49517 .31363 .49829 .31903 .49675 .3156 .49336 Mtetra
.657 .731 .905 r
.3156 .49336 .31903 .49675 .32446 .49491 .32102 .49169 Mtetra
.655 .742 .914 r
.32102 .49169 .32446 .49491 .3299 .49308 .32646 .49004 Mtetra
.68 .76 .911 r
.32646 .49004 .3299 .49308 .33534 .49144 .33192 .48802 Mtetra
.663 .733 .901 r
.33192 .48802 .33534 .49144 .34081 .48956 .33739 .48624 Mtetra
.662 .738 .907 r
.33739 .48624 .34081 .48956 .34628 .48773 .34286 .48448 Mtetra
.655 .742 .914 r
.34286 .48448 .34628 .48773 .35176 .48594 .34835 .48282 Mtetra
.676 .755 .91 r
.34835 .48282 .35176 .48594 .35724 .48434 .35385 .48083 Mtetra
.644 .724 .907 r
.35385 .48083 .35724 .48434 .36276 .48233 .35935 .47933 Mtetra
.677 .764 .917 r
.35935 .47933 .36276 .48233 .36826 .48078 .36488 .47732 Mtetra
.661 .732 .903 r
.36488 .47732 .36826 .48078 .37379 .47895 .37041 .47556 Mtetra
.652 .735 .91 r
.37041 .47556 .37379 .47895 .37933 .47699 .37595 .47392 Mtetra
.665 .758 .92 r
.37595 .47392 .37933 .47699 .38488 .47523 .38151 .47208 Mtetra
.663 .753 .917 r
.38151 .47208 .38488 .47523 .39044 .47344 .38708 .47027 Mtetra
.656 .75 .919 r
.38708 .47027 .39044 .47344 .39601 .47156 .39265 .46856 Mtetra
.664 .764 .924 r
.39265 .46856 .39601 .47156 .4016 .46977 .39825 .46672 Mtetra
.687 .767 .912 r
.39825 .46672 .4016 .46977 .40718 .46836 .40386 .46454 Mtetra
.635 .706 .898 r
.40386 .46454 .40718 .46836 .41279 .46631 .40946 .46314 Mtetra
.69 .76 .905 r
.40946 .46314 .41279 .46631 .4184 .46489 .4151 .4609 Mtetra
.628 .695 .893 r
.4151 .4609 .4184 .46489 .42405 .46256 .42072 .4596 Mtetra
.644 .764 .936 r
.42072 .4596 .42405 .46256 .42969 .46082 .42637 .458 Mtetra
.646 .774 .941 r
.42637 .458 .42969 .46082 .43533 .45929 .43202 .45636 Mtetra
.631 .763 .942 r
.43202 .45636 .43533 .45929 .441 .45732 .43769 .4549 Mtetra
.636 .801 .962 r
.43769 .4549 .441 .45732 .44668 .45537 .44337 .45329 Mtetra
.737 .845 .931 r
.44337 .45329 .44668 .45537 .45234 .45516 .44909 .4503 Mtetra
.502 .598 .882 r
.44909 .4503 .45234 .45516 .45806 .45258 .45476 .45074 Mtetra
.748 .864 .933 r
.45476 .45074 .45806 .45258 .46372 .45329 .46051 .44757 Mtetra
.416 .515 .851 r
.46051 .44757 .46372 .45329 .46951 .44855 .46618 .44926 Mtetra
.407 .858 .81 r
.46618 .44926 .46951 .44855 .47514 .45386 .47194 .44695 Mtetra
.721 .631 .757 r
.47194 .44695 .47514 .45386 .48089 .45267 .47774 .44257 Mtetra
.411 .396 .732 r
.47774 .44257 .48089 .45267 .48674 .44456 .48345 .44601 Mtetra
.402 0 0 r
.48345 .44601 .48674 .44456 .49247 .44719 .48921 .44695 Mtetra
.9 .94 .828 r
.48921 .44695 .49247 .44719 .49828 .44496 .49507 .44011 Mtetra
.755 .703 .803 r
.49507 .44011 .49828 .44496 .50412 .43778 .50091 .43567 Mtetra
0 .476 .855 r
.50091 .43567 .50412 .43778 .50992 .43844 .50671 .43767 Mtetra
.65 .928 .973 r
.50671 .43767 .50992 .43844 .51575 .43796 .51255 .43513 Mtetra
.81 .808 .849 r
.51255 .43513 .51575 .43796 .5216 .4327 .51841 .4302 Mtetra
.725 .822 .925 r
.51841 .4302 .5216 .4327 .52745 .43097 .52428 .42733 Mtetra
.458 .65 .942 r
.52428 .42733 .52745 .43097 .53331 .42963 .53015 .42775 Mtetra
.819 .871 .885 r
.53015 .42775 .53331 .42963 .53919 .4264 .53603 .42306 Mtetra
.7 .764 .901 r
.53603 .42306 .53919 .4264 .54507 .42432 .54193 .42054 Mtetra
.56 .688 .926 r
.54193 .42054 .54507 .42432 .55098 .42362 .54784 .42002 Mtetra
.75 .762 .863 r
.54784 .42002 .55098 .42362 .55689 .42065 .55375 .4164 Mtetra
.563 .663 .904 r
.55375 .4164 .55689 .42065 .56281 .41861 .5597 .41593 Mtetra
.694 .808 .936 r
.5597 .41593 .56281 .41861 .56876 .41745 .56564 .41352 Mtetra
.698 .733 .877 r
.56564 .41352 .56876 .41745 .57471 .41503 .57159 .41094 Mtetra
.629 .7 .896 r
.57159 .41094 .57471 .41503 .58067 .41272 .57757 .40953 Mtetra
.65 .762 .931 r
.57757 .40953 .58067 .41272 .58665 .41097 .58356 .40776 Mtetra
.651 .761 .93 r
.58356 .40776 .58665 .41097 .59263 .40891 .58957 .40597 Mtetra
.735 .802 .905 r
.58957 .40597 .59263 .40891 .59863 .40659 .59555 .40283 Mtetra
.499 .664 .936 r
.59555 .40283 .59863 .40659 .60468 .40605 .60163 .40292 Mtetra
.765 .797 .879 r
.60163 .40292 .60468 .40605 .61067 .40274 .60762 .39909 Mtetra
.541 .692 .937 r
.60762 .39909 .61067 .40274 .61676 .40237 .61371 .3987 Mtetra
.62 .724 .92 r
.61371 .3987 .61676 .40237 .62281 .40009 .6198 .39736 Mtetra
.76 .824 .902 r
.6198 .39736 .62281 .40009 .62884 .39702 .62582 .39375 Mtetra
.329 .611 .951 r
.62582 .39375 .62884 .39702 .63498 .39675 .63202 .39497 Mtetra
.366 .748 .989 r
.63202 .39497 .63498 .39675 .64117 .39725 .6382 .39488 Mtetra
.815 .855 .879 r
.6382 .39488 .64117 .39725 .64717 .39229 .64422 .39009 Mtetra
.732 .86 .941 r
.64422 .39009 .64717 .39229 .65337 .39217 .65031 .387 Mtetra
.242 .442 .857 r
.65031 .387 .65337 .39217 .65967 .39415 .65668 .39027 Mtetra
.6 .706 .918 r
.65668 .39027 .65967 .39415 .66569 .38885 .66289 .3892 Mtetra
.875 .992 .805 r
.66289 .3892 .66569 .38885 .67182 .38618 .66885 .38237 Mtetra
.658 .734 .905 r
.66885 .38237 .67182 .38618 .67831 .39059 .67505 .38044 Mtetra
.538 .48 .738 r
.67505 .38044 .67831 .39059 .68431 .38431 .68139 .38119 Mtetra
.777 .81 .879 r
.68139 .38119 .68431 .38431 .6903 .37819 .6875 .37705 Mtetra
.876 .937 .856 r
.6875 .37705 .6903 .37819 .69664 .37836 .69351 .37088 Mtetra
.533 .529 .797 r
.69351 .37088 .69664 .37836 .70265 .37238 .69989 .37143 Mtetra
.82 .958 .903 r
.69989 .37143 .70265 .37238 .70899 .37202 .70598 .36654 Mtetra
.599 .629 .853 r
.70598 .36654 .70899 .37202 .71515 .36841 .71232 .36563 Mtetra
.663 .806 .952 r
.71232 .36563 .71515 .36841 .72141 .36608 .71859 .36351 Mtetra
.687 .829 .952 r
.71859 .36351 .72141 .36608 .7277 .36428 .72486 .36103 Mtetra
.678 .78 .927 r
.72486 .36103 .7277 .36428 .73398 .36199 .73115 .35874 Mtetra
.676 .779 .928 r
.73115 .35874 .73398 .36199 .74027 .35965 .73746 .35647 Mtetra
.696 .791 .924 r
.73746 .35647 .74027 .35965 .74664 .35816 .74375 .35388 Mtetra
.648 .709 .891 r
.74375 .35388 .74664 .35816 .75296 .35592 .75012 .35206 Mtetra
.678 .744 .901 r
.75012 .35206 .75296 .35592 .75931 .3538 .75646 .34975 Mtetra
.645 .721 .903 r
.75646 .34975 .75931 .3538 .76565 .35138 .76286 .34797 Mtetra
.673 .771 .924 r
.76286 .34797 .76565 .35138 .77204 .34952 .76924 .34573 Mtetra
.674 .749 .907 r
.76924 .34573 .77204 .34952 .77844 .34749 .77563 .34347 Mtetra
.662 .731 .9 r
.77563 .34347 .77844 .34749 .78485 .3454 .78205 .3414 Mtetra
.655 .73 .904 r
.78205 .3414 .78485 .3454 .79126 .34315 .78849 .33944 Mtetra
.662 .75 .916 r
.78849 .33944 .79126 .34315 .79769 .34099 .79494 .33737 Mtetra
.681 .763 .914 r
.79494 .33737 .79769 .34099 .80416 .33909 .80138 .33497 Mtetra
.65 .722 .901 r
.80138 .33497 .80416 .33909 .81061 .33683 .80787 .33309 Mtetra
.669 .753 .913 r
.80787 .33309 .81061 .33683 .8171 .33482 .81435 .33087 Mtetra
.658 .737 .907 r
.81435 .33087 .8171 .33482 .82358 .33258 .82087 .32884 Mtetra
.674 .756 .912 r
.82087 .32884 .82358 .33258 .8301 .33059 .82737 .32653 Mtetra
.657 .731 .904 r
.82737 .32653 .8301 .33059 .83661 .32834 .83391 .32452 Mtetra
.667 .749 .912 r
.83391 .32452 .83661 .32834 .84314 .32614 .84046 .32232 Mtetra
.663 .748 .913 r
.84046 .32232 .84314 .32614 .8497 .32405 .84702 .32018 Mtetra
.67 .748 .909 r
.84702 .32018 .8497 .32405 .85629 .32217 .85359 .31793 Mtetra
.647 .718 .9 r
.85359 .31793 .85629 .32217 .86287 .32002 .86021 .31606 Mtetra
.659 .74 .909 r
.86021 .31606 .86287 .32002 .86945 .31764 .86683 .31398 Mtetra
.685 .768 .915 r
.86683 .31398 .86945 .31764 .87608 .31574 .87341 .31146 Mtetra
.645 .716 .9 r
.87341 .31146 .87608 .31574 .8827 .31345 .88008 .30961 Mtetra
.674 .755 .912 r
.88008 .30961 .8827 .31345 .88933 .31119 .88672 .30726 Mtetra
.665 .739 .905 r
.2905 .4971 .29398 .50038 .29937 .49858 .2959 .4953 Mtetra
.657 .738 .91 r
.2959 .4953 .29937 .49858 .30477 .49677 .30129 .49363 Mtetra
.668 .75 .912 r
.30129 .49363 .30477 .49677 .31017 .49517 .30671 .4918 Mtetra
.647 .731 .91 r
.30671 .4918 .31017 .49517 .3156 .49336 .31213 .49027 Mtetra
.66 .752 .918 r
.31213 .49027 .3156 .49336 .32102 .49169 .31756 .48854 Mtetra
.685 .754 .904 r
.31756 .48854 .32102 .49169 .32646 .49004 .32303 .48644 Mtetra
.65 .719 .899 r
.32303 .48644 .32646 .49004 .33192 .48802 .32848 .48485 Mtetra
.665 .749 .913 r
.32848 .48485 .33192 .48802 .33739 .48624 .33395 .48304 Mtetra
.668 .748 .911 r
.33395 .48304 .33739 .48624 .34286 .48448 .33944 .48119 Mtetra
.666 .743 .908 r
.33944 .48119 .34286 .48448 .34835 .48282 .34494 .47936 Mtetra
.65 .729 .907 r
.34494 .47936 .34835 .48282 .35385 .48083 .35043 .47776 Mtetra
.679 .76 .912 r
.35043 .47776 .35385 .48083 .35935 .47933 .35596 .47573 Mtetra
.651 .722 .9 r
.35596 .47573 .35935 .47933 .36488 .47732 .36148 .47411 Mtetra
.664 .749 .913 r
.36148 .47411 .36488 .47732 .37041 .47556 .36702 .4723 Mtetra
.676 .749 .906 r
.36702 .4723 .37041 .47556 .37595 .47392 .37258 .4703 Mtetra
.662 .725 .896 r
.37258 .4703 .37595 .47392 .38151 .47208 .37814 .46849 Mtetra
.663 .727 .897 r
.37814 .46849 .38151 .47208 .38708 .47027 .38372 .46668 Mtetra
.668 .729 .895 r
.38372 .46668 .38708 .47027 .39265 .46856 .38931 .46478 Mtetra
.659 .716 .891 r
.38931 .46478 .39265 .46856 .39825 .46672 .39491 .46301 Mtetra
.644 .716 .9 r
.39491 .46301 .39825 .46672 .40386 .46454 .4005 .46146 Mtetra
.675 .763 .917 r
.4005 .46146 .40386 .46454 .40946 .46314 .40613 .45945 Mtetra
.644 .718 .902 r
.40613 .45945 .40946 .46314 .4151 .4609 .41176 .4579 Mtetra
.685 .772 .917 r
.41176 .4579 .4151 .4609 .42072 .4596 .41741 .45573 Mtetra
.668 .715 .884 r
.41741 .45573 .42072 .4596 .42637 .458 .42307 .45379 Mtetra
.657 .695 .874 r
.42307 .45379 .42637 .458 .43202 .45636 .42874 .45202 Mtetra
.665 .692 .865 r
.42874 .45202 .43202 .45636 .43769 .4549 .43442 .45008 Mtetra
.612 .65 .863 r
.43442 .45008 .43769 .4549 .44337 .45329 .4401 .44902 Mtetra
.607 .675 .889 r
.4401 .44902 .44337 .45329 .44909 .4503 .44578 .44801 Mtetra
.741 .832 .921 r
.44578 .44801 .44909 .4503 .45476 .45074 .45153 .44495 Mtetra
.419 .514 .849 r
.45153 .44495 .45476 .45074 .46051 .44757 .45718 .4466 Mtetra
.803 .925 .917 r
.45718 .4466 .46051 .44757 .46618 .44926 .46298 .4424 Mtetra
.558 .553 .804 r
.46298 .4424 .46618 .44926 .47194 .44695 .4687 .44238 Mtetra
.349 .536 .897 r
.4687 .44238 .47194 .44695 .47774 .44257 .47442 .44412 Mtetra
.37 0 0 r
.47442 .44412 .47774 .44257 .48345 .44601 .48017 .44477 Mtetra
.609 .886 .99 r
.48017 .44477 .48345 .44601 .48921 .44695 .48598 .44287 Mtetra
.825 .746 .777 r
.48598 .44287 .48921 .44695 .49507 .44011 .49185 .43606 Mtetra
.691 .72 .872 r
.49185 .43606 .49507 .44011 .50091 .43567 .49768 .43364 Mtetra
.4 0 0 r
.49768 .43364 .50091 .43567 .50671 .43767 .50347 .43742 Mtetra
.672 .958 .944 r
.50347 .43742 .50671 .43767 .51255 .43513 .50934 .43432 Mtetra
.877 .924 .852 r
.50934 .43432 .51255 .43513 .51841 .4302 .51522 .4282 Mtetra
.791 .863 .903 r
.51522 .4282 .51841 .4302 .52428 .42733 .52109 .42414 Mtetra
.358 .632 .958 r
.52109 .42414 .52428 .42733 .53015 .42775 .52697 .42505 Mtetra
.725 .811 .918 r
.52697 .42505 .53015 .42775 .53603 .42306 .53287 .42216 Mtetra
.838 .935 .891 r
.53287 .42216 .53603 .42306 .54193 .42054 .53877 .41714 Mtetra
.562 .714 .943 r
.53877 .41714 .54193 .42054 .54784 .42002 .54469 .41647 Mtetra
.717 .758 .885 r
.54469 .41647 .54784 .42002 .55375 .4164 .55062 .4136 Mtetra
.612 .775 .959 r
.55062 .4136 .55375 .4164 .5597 .41593 .55656 .41223 Mtetra
.72 .751 .877 r
.55656 .41223 .5597 .41593 .56564 .41352 .56251 .40925 Mtetra
.676 .708 .872 r
.56251 .40925 .56564 .41352 .57159 .41094 .56847 .40704 Mtetra
.665 .724 .894 r
.56847 .40704 .57159 .41094 .57757 .40953 .57445 .40505 Mtetra
.627 .68 .881 r
.57445 .40505 .57757 .40953 .58356 .40776 .58045 .40368 Mtetra
.584 .684 .91 r
.58045 .40368 .58356 .40776 .58957 .40597 .58648 .4029 Mtetra
.705 .788 .915 r
.58648 .4029 .58957 .40597 .59555 .40283 .59249 .40027 Mtetra
.638 .805 .963 r
.59249 .40027 .59555 .40283 .60163 .40292 .59853 .39851 Mtetra
.671 .703 .871 r
.59853 .39851 .60163 .40292 .60762 .39909 .60457 .39635 Mtetra
.431 .706 .98 r
.60457 .39635 .60762 .39909 .61371 .3987 .61069 .3965 Mtetra
.658 .839 .97 r
.61069 .3965 .61371 .3987 .6198 .39736 .61677 .3944 Mtetra
.74 .806 .905 r
.61677 .3944 .6198 .39736 .62582 .39375 .62282 .39114 Mtetra
.027 .469 .877 r
.62282 .39114 .62582 .39375 .63202 .39497 .62906 .39359 Mtetra
.438 .815 .992 r
.62906 .39359 .63202 .39497 .6382 .39488 .63523 .39276 Mtetra
.79 .872 .908 r
.63523 .39276 .6382 .39488 .64422 .39009 .64129 .38861 Mtetra
.825 .917 .899 r
.64129 .38861 .64422 .39009 .65031 .387 .64733 .38378 Mtetra
.065 .449 .88 r
.64733 .38378 .65031 .387 .65668 .39027 .65368 .38665 Mtetra
.372 .613 .943 r
.65368 .38665 .65668 .39027 .66289 .3892 .65999 .38777 Mtetra
.793 .924 .924 r
.65999 .38777 .66289 .3892 .66885 .38237 .66609 .38354 Mtetra
.759 .985 .751 r
.66609 .38354 .66885 .38237 .67505 .38044 .67211 .37748 Mtetra
.832 .825 .841 r
.67211 .37748 .67505 .38044 .68139 .38119 .67815 .37184 Mtetra
.55 .5 .753 r
.67815 .37184 .68139 .38119 .6875 .37705 .68449 .37218 Mtetra
.646 .677 .865 r
.68449 .37218 .6875 .37705 .69351 .37088 .69075 .37041 Mtetra
.818 .981 .888 r
.69075 .37041 .69351 .37088 .69989 .37143 .69683 .36531 Mtetra
.621 .617 .825 r
.69683 .36531 .69989 .37143 .70598 .36654 .70313 .36395 Mtetra
.7 .831 .945 r
.70313 .36395 .70598 .36654 .71232 .36563 .70937 .36129 Mtetra
.711 .729 .864 r
.70937 .36129 .71232 .36563 .71859 .36351 .7156 .35828 Mtetra
.658 .668 .848 r
.7156 .35828 .71859 .36351 .72486 .36103 .7219 .3562 Mtetra
.661 .687 .863 r
.7219 .3562 .72486 .36103 .73115 .35874 .72822 .35411 Mtetra
.662 .697 .872 r
.72822 .35411 .73115 .35874 .73746 .35647 .73454 .35202 Mtetra
.641 .697 .887 r
.73454 .35202 .73746 .35647 .74375 .35388 .74091 .35032 Mtetra
.672 .76 .917 r
.74091 .35032 .74375 .35388 .75012 .35206 .74726 .34812 Mtetra
.665 .735 .902 r
.74726 .34812 .75012 .35206 .75646 .34975 .75363 .34601 Mtetra
.681 .754 .907 r
.75363 .34601 .75646 .34975 .76286 .34797 .75999 .34363 Mtetra
.653 .71 .89 r
.75999 .34363 .76286 .34797 .76924 .34573 .7664 .34171 Mtetra
.659 .73 .902 r
.7664 .34171 .76924 .34573 .77563 .34347 .77282 .33969 Mtetra
.663 .746 .912 r
.77282 .33969 .77563 .34347 .78205 .3414 .77925 .33759 Mtetra
.672 .748 .908 r
.77925 .33759 .78205 .3414 .78849 .33944 .78568 .33534 Mtetra
.663 .729 .898 r
.78568 .33534 .78849 .33944 .79494 .33737 .79214 .33323 Mtetra
.651 .722 .901 r
.79214 .33323 .79494 .33737 .80138 .33497 .79863 .33132 Mtetra
.675 .76 .915 r
.79863 .33132 .80138 .33497 .80787 .33309 .8051 .32901 Mtetra
.654 .728 .903 r
.8051 .32901 .80787 .33309 .81435 .33087 .81161 .32704 Mtetra
.672 .75 .909 r
.81161 .32704 .81435 .33087 .82087 .32884 .81811 .32478 Mtetra
.653 .729 .905 r
.81811 .32478 .82087 .32884 .82737 .32653 .82466 .32282 Mtetra
.675 .759 .914 r
.82466 .32282 .82737 .32653 .83391 .32452 .83119 .32049 Mtetra
.667 .738 .903 r
.83119 .32049 .83391 .32452 .84046 .32232 .83774 .31828 Mtetra
.657 .734 .906 r
.83774 .31828 .84046 .32232 .84702 .32018 .84433 .31624 Mtetra
.653 .738 .912 r
.84433 .31624 .84702 .32018 .85359 .31793 .85093 .31426 Mtetra
.672 .763 .919 r
.85093 .31426 .85359 .31793 .86021 .31606 .85752 .31196 Mtetra
.659 .733 .904 r
.85752 .31196 .86021 .31606 .86683 .31398 .86415 .30988 Mtetra
.654 .731 .906 r
.86415 .30988 .86683 .31398 .87341 .31146 .8708 .30788 Mtetra
.689 .777 .918 r
.8708 .30788 .87341 .31146 .88008 .30961 .8774 .30527 Mtetra
.649 .717 .897 r
.8774 .30527 .88008 .30961 .88672 .30726 .88409 .30334 Mtetra
.66 .739 .908 r
.287 .49382 .2905 .4971 .2959 .4953 .2924 .4921 Mtetra
.665 .745 .91 r
.2924 .4921 .2959 .4953 .30129 .49363 .29781 .49031 Mtetra
.644 .733 .914 r
.29781 .49031 .30129 .49363 .30671 .4918 .30322 .48881 Mtetra
.67 .761 .918 r
.30322 .48881 .30671 .4918 .31213 .49027 .30866 .48693 Mtetra
.661 .737 .906 r
.30866 .48693 .31213 .49027 .31756 .48854 .3141 .48518 Mtetra
.655 .735 .909 r
.3141 .48518 .31756 .48854 .32303 .48644 .31955 .48352 Mtetra
.685 .77 .916 r
.31955 .48352 .32303 .48644 .32848 .48485 .32504 .48141 Mtetra
.661 .733 .903 r
.32504 .48141 .32848 .48485 .33395 .48304 .33051 .47965 Mtetra
.661 .736 .905 r
.33051 .47965 .33395 .48304 .33944 .48119 .336 .47789 Mtetra
.66 .741 .91 r
.336 .47789 .33944 .48119 .34494 .47936 .3415 .47614 Mtetra
.673 .75 .909 r
.3415 .47614 .34494 .47936 .35043 .47776 .34702 .47419 Mtetra
.649 .723 .903 r
.34702 .47419 .35043 .47776 .35596 .47573 .35253 .47259 Mtetra
.672 .756 .914 r
.35253 .47259 .35596 .47573 .36148 .47411 .35808 .47065 Mtetra
.664 .735 .902 r
.35808 .47065 .36148 .47411 .36702 .4723 .36363 .46882 Mtetra
.651 .73 .907 r
.36363 .46882 .36702 .4723 .37258 .4703 .36918 .46718 Mtetra
.664 .757 .919 r
.36918 .46718 .37258 .4703 .37814 .46849 .37475 .46535 Mtetra
.664 .755 .918 r
.37475 .46535 .37814 .46849 .38372 .46668 .38033 .46351 Mtetra
.655 .752 .921 r
.38033 .46351 .38372 .46668 .38931 .46478 .38592 .46179 Mtetra
.662 .766 .927 r
.38592 .46179 .38931 .46478 .39491 .46301 .39153 .45996 Mtetra
.688 .769 .913 r
.39153 .45996 .39491 .46301 .4005 .46146 .39716 .45775 Mtetra
.631 .713 .905 r
.39716 .45775 .4005 .46146 .40613 .45945 .40277 .45638 Mtetra
.694 .769 .91 r
.40277 .45638 .40613 .45945 .41176 .4579 .40843 .45407 Mtetra
.627 .705 .902 r
.40843 .45407 .41176 .4579 .41741 .45573 .41406 .45276 Mtetra
.646 .765 .935 r
.41406 .45276 .41741 .45573 .42307 .45379 .41972 .45111 Mtetra
.651 .787 .946 r
.41972 .45111 .42307 .45379 .42874 .45202 .42539 .44936 Mtetra
.644 .787 .95 r
.42539 .44936 .42874 .45202 .43442 .45008 .43108 .4477 Mtetra
.66 .811 .956 r
.43108 .4477 .43442 .45008 .4401 .44902 .43678 .44579 Mtetra
.718 .768 .891 r
.43678 .44579 .4401 .44902 .44578 .44801 .44252 .443 Mtetra
.571 .625 .867 r
.44252 .443 .44578 .44801 .45153 .44495 .44821 .44257 Mtetra
.699 .821 .941 r
.44821 .44257 .45153 .44495 .45718 .4466 .45396 .44015 Mtetra
.58 .576 .814 r
.45396 .44015 .45718 .4466 .46298 .4424 .45968 .43969 Mtetra
.082 .505 .901 r
.45968 .43969 .46298 .4424 .4687 .44238 .46538 .44168 Mtetra
.585 .91 .978 r
.46538 .44168 .4687 .44238 .47442 .44412 .47117 .43962 Mtetra
.737 .712 .828 r
.47117 .43962 .47442 .44412 .48017 .44477 .47699 .43595 Mtetra
.654 .563 .74 r
.47699 .43595 .48017 .44477 .48598 .44287 .4828 .43331 Mtetra
.638 .543 .731 r
.4828 .43331 .48598 .44287 .49185 .43606 .48862 .43106 Mtetra
.617 .648 .858 r
.48862 .43106 .49185 .43606 .49768 .43364 .49444 .4299 Mtetra
0 .195 .706 r
.49444 .4299 .49768 .43364 .50347 .43742 .50024 .43458 Mtetra
.45 .705 .976 r
.50024 .43458 .50347 .43742 .50934 .43432 .50609 .43466 Mtetra
.873 .981 .839 r
.50609 .43466 .50934 .43432 .51522 .4282 .51199 .42841 Mtetra
.891 .97 .828 r
.51199 .42841 .51522 .4282 .52109 .42414 .51789 .42172 Mtetra
.664 .817 .957 r
.51789 .42172 .52109 .42414 .52697 .42505 .52378 .41969 Mtetra
.376 .512 .867 r
.52378 .41969 .52697 .42505 .53287 .42216 .52969 .42164 Mtetra
.878 .945 .853 r
.52969 .42164 .53287 .42216 .53877 .41714 .5356 .4155 Mtetra
.688 .882 .97 r
.5356 .4155 .53877 .41714 .54469 .41647 .54153 .41297 Mtetra
.657 .744 .914 r
.54153 .41297 .54469 .41647 .55062 .4136 .54747 .41112 Mtetra
.72 .828 .932 r
.54747 .41112 .55062 .4136 .55656 .41223 .55341 .40829 Mtetra
.695 .732 .879 r
.55341 .40829 .55656 .41223 .56251 .40925 .55937 .40577 Mtetra
.579 .718 .938 r
.55937 .40577 .56251 .40925 .56847 .40704 .56536 .40491 Mtetra
.559 .809 .992 r
.56536 .40491 .56847 .40704 .57445 .40505 .57136 .40377 Mtetra
.739 .919 .953 r
.57136 .40377 .57445 .40505 .58045 .40368 .57735 .40044 Mtetra
.691 .773 .914 r
.57735 .40044 .58045 .40368 .58648 .4029 .58336 .39804 Mtetra
.524 .616 .886 r
.58336 .39804 .58648 .4029 .59249 .40027 .58943 .39818 Mtetra
.797 .869 .901 r
.58943 .39818 .59249 .40027 .59853 .39851 .59542 .39392 Mtetra
.467 .601 .902 r
.59542 .39392 .59853 .39851 .60457 .39635 .60154 .39463 Mtetra
.312 .723 .977 r
.60154 .39463 .60457 .39635 .61069 .3965 .60767 .39478 Mtetra
.869 .888 .846 r
.60767 .39478 .61069 .3965 .61677 .3944 .61364 .38859 Mtetra
.294 .445 .842 r
.61364 .38859 .61677 .3944 .62282 .39114 .61989 .39171 Mtetra
.317 0 0 r
.61989 .39171 .62282 .39114 .62906 .39359 .62611 .39287 Mtetra
.488 .878 .965 r
.62611 .39287 .62906 .39359 .63523 .39276 .63226 .39119 Mtetra
.863 .904 .86 r
.63226 .39119 .63523 .39276 .64129 .38861 .63827 .38531 Mtetra
.824 .801 .83 r
.63827 .38531 .64129 .38861 .64733 .38378 .64429 .37965 Mtetra
.29 .532 .911 r
.64429 .37965 .64733 .38378 .65368 .38665 .65062 .38174 Mtetra
.588 .648 .877 r
.65062 .38174 .65368 .38665 .65999 .38777 .65686 .38096 Mtetra
.649 .609 .796 r
.65686 .38096 .65999 .38777 .66609 .38354 .66306 .37886 Mtetra
.65 .687 .871 r
.66306 .37886 .66609 .38354 .67211 .37748 .66928 .37703 Mtetra
.756 .978 .918 r
.66928 .37703 .67211 .37748 .67815 .37184 .67541 .37283 Mtetra
.849 .994 .751 r
.67541 .37283 .67815 .37184 .68449 .37218 .68139 .36562 Mtetra
.603 .594 .815 r
.68139 .36562 .68449 .37218 .69075 .37041 .68769 .36462 Mtetra
.675 .654 .822 r
.68769 .36462 .69075 .37041 .69683 .36531 .69392 .36208 Mtetra
.732 .797 .903 r
.69392 .36208 .69683 .36531 .70313 .36395 .70013 .35886 Mtetra
.629 .661 .862 r
.70013 .35886 .70313 .36395 .70937 .36129 .70644 .35737 Mtetra
.652 .73 .906 r
.70644 .35737 .70937 .36129 .7156 .35828 .71275 .35551 Mtetra
.672 .812 .95 r
.71275 .35551 .7156 .35828 .7219 .3562 .71905 .35324 Mtetra
.669 .798 .944 r
.71905 .35324 .7219 .3562 .72822 .35411 .72537 .35104 Mtetra
.672 .792 .938 r
.72537 .35104 .72822 .35411 .73454 .35202 .7317 .3488 Mtetra
.697 .79 .923 r
.7317 .3488 .73454 .35202 .74091 .35032 .73802 .34618 Mtetra
.643 .716 .9 r
.73802 .34618 .74091 .35032 .74726 .34812 .74441 .34442 Mtetra
.682 .757 .909 r
.74441 .34442 .74726 .34812 .75363 .34601 .75077 .34203 Mtetra
.643 .726 .909 r
.75077 .34203 .75363 .34601 .75999 .34363 .75719 .34027 Mtetra
.674 .776 .927 r
.75719 .34027 .75999 .34363 .7664 .34171 .76358 .33799 Mtetra
.674 .754 .911 r
.76358 .33799 .7664 .34171 .77282 .33969 .76999 .33572 Mtetra
.661 .735 .905 r
.76999 .33572 .77282 .33969 .77925 .33759 .77644 .33364 Mtetra
.657 .736 .907 r
.77644 .33364 .77925 .33759 .78568 .33534 .7829 .33163 Mtetra
.665 .753 .916 r
.7829 .33163 .78568 .33534 .79214 .33323 .78936 .3295 Mtetra
.68 .758 .91 r
.78936 .3295 .79214 .33323 .79863 .33132 .79582 .32709 Mtetra
.649 .718 .899 r
.79582 .32709 .79863 .33132 .8051 .32901 .80234 .32522 Mtetra
.672 .753 .911 r
.80234 .32522 .8051 .32901 .81161 .32704 .80884 .32294 Mtetra
.653 .727 .904 r
.80884 .32294 .81161 .32704 .81811 .32478 .81538 .32098 Mtetra
.675 .754 .911 r
.81538 .32098 .81811 .32478 .82466 .32282 .8219 .31864 Mtetra
.655 .725 .901 r
.8219 .31864 .82466 .32282 .83119 .32049 .82847 .31664 Mtetra
.667 .749 .912 r
.82847 .31664 .83119 .32049 .83774 .31828 .83503 .31443 Mtetra
.666 .75 .913 r
.83503 .31443 .83774 .31828 .84433 .31624 .84161 .31223 Mtetra
.669 .742 .905 r
.84161 .31223 .84433 .31624 .85093 .31426 .8482 .30997 Mtetra
.64 .714 .901 r
.8482 .30997 .85093 .31426 .85752 .31196 .85486 .30819 Mtetra
.662 .754 .919 r
.85486 .30819 .85752 .31196 .86415 .30988 .86149 .30605 Mtetra
.679 .759 .911 r
.86149 .30605 .86415 .30988 .8708 .30788 .86811 .30361 Mtetra
.646 .72 .902 r
.86811 .30361 .8708 .30788 .8774 .30527 .8748 .30172 Mtetra
.693 .782 .919 r
.8748 .30172 .8774 .30527 .88409 .30334 .88142 .29905 Mtetra
.67 .747 .908 r
.28349 .49061 .287 .49382 .2924 .4921 .2889 .48873 Mtetra
.639 .729 .914 r
.2889 .48873 .2924 .4921 .29781 .49031 .2943 .4873 Mtetra
.681 .762 .913 r
.2943 .4873 .29781 .49031 .30322 .48881 .29974 .48526 Mtetra
.634 .718 .908 r
.29974 .48526 .30322 .48881 .30866 .48693 .30516 .4839 Mtetra
.677 .761 .914 r
.30516 .4839 .30866 .48693 .3141 .48518 .31062 .48192 Mtetra
.675 .746 .904 r
.31062 .48192 .3141 .48518 .31955 .48352 .31609 .47995 Mtetra
.659 .725 .898 r
.31609 .47995 .31955 .48352 .32504 .48141 .32156 .47822 Mtetra
.668 .75 .912 r
.32156 .47822 .32504 .48141 .33051 .47965 .32706 .47635 Mtetra
.666 .743 .908 r
.32706 .47635 .33051 .47965 .336 .47789 .33255 .47451 Mtetra
.662 .738 .906 r
.33255 .47451 .336 .47789 .3415 .47614 .33806 .47272 Mtetra
.653 .734 .908 r
.33806 .47272 .3415 .47614 .34702 .47419 .34357 .47106 Mtetra
.672 .757 .914 r
.34357 .47106 .34702 .47419 .35253 .47259 .34911 .46912 Mtetra
.658 .733 .904 r
.34911 .46912 .35253 .47259 .35808 .47065 .35465 .46737 Mtetra
.655 .744 .915 r
.35465 .46737 .35808 .47065 .36363 .46882 .3602 .46568 Mtetra
.676 .758 .913 r
.3602 .46568 .36363 .46882 .36918 .46718 .36577 .46367 Mtetra
.67 .734 .898 r
.36577 .46367 .36918 .46718 .37475 .46535 .37136 .46173 Mtetra
.665 .728 .896 r
.37136 .46173 .37475 .46535 .38033 .46351 .37695 .45986 Mtetra
.658 .724 .898 r
.37695 .45986 .38033 .46351 .38592 .46179 .38255 .4581 Mtetra
.651 .72 .899 r
.38255 .4581 .38592 .46179 .39153 .45996 .38815 .45644 Mtetra
.66 .733 .904 r
.38815 .45644 .39153 .45996 .39716 .45775 .39377 .45465 Mtetra
.685 .766 .912 r
.39377 .45465 .39716 .45775 .40277 .45638 .39942 .45247 Mtetra
.635 .704 .896 r
.39942 .45247 .40277 .45638 .40843 .45407 .40506 .45105 Mtetra
.664 .767 .926 r
.40506 .45105 .40843 .45407 .41406 .45276 .41072 .44918 Mtetra
.675 .736 .896 r
.41072 .44918 .41406 .45276 .41972 .45111 .4164 .44713 Mtetra
.662 .71 .883 r
.4164 .44713 .41972 .45111 .42539 .44936 .42208 .44526 Mtetra
.64 .697 .887 r
.42208 .44526 .42539 .44936 .43108 .4477 .42777 .44374 Mtetra
.616 .697 .902 r
.42777 .44374 .43108 .4477 .43678 .44579 .43346 .44258 Mtetra
.657 .755 .922 r
.43346 .44258 .43678 .44579 .44252 .443 .43917 .44079 Mtetra
.697 .833 .948 r
.43917 .44079 .44252 .443 .44821 .44257 .44492 .43838 Mtetra
.554 .66 .907 r
.44492 .43838 .44821 .44257 .45396 .44015 .45063 .43801 Mtetra
.613 .82 .98 r
.45063 .43801 .45396 .44015 .45968 .43969 .45639 .4365 Mtetra
.698 .768 .907 r
.45639 .4365 .45968 .43969 .46538 .44168 .46217 .43407 Mtetra
.664 .591 .762 r
.46217 .43407 .46538 .44168 .47117 .43962 .46797 .43141 Mtetra
.568 .527 .769 r
.46797 .43141 .47117 .43962 .47699 .43595 .47374 .43123 Mtetra
.479 .598 .893 r
.47374 .43123 .47699 .43595 .4828 .43331 .47951 .43184 Mtetra
.647 .88 .984 r
.47951 .43184 .4828 .43331 .48862 .43106 .48534 .42971 Mtetra
.621 .883 .989 r
.48534 .42971 .48862 .43106 .49444 .4299 .49119 .42774 Mtetra
.134 .581 .925 r
.49119 .42774 .49444 .4299 .50024 .43458 .49701 .42907 Mtetra
.262 .439 .848 r
.49701 .42907 .50024 .43458 .50609 .43466 .50285 .43207 Mtetra
.622 .793 .964 r
.50285 .43207 .50609 .43466 .51199 .42841 .50874 .43054 Mtetra
.784 .979 .705 r
.50874 .43054 .51199 .42841 .51789 .42172 .51466 .4237 Mtetra
.831 .988 .719 r
.51466 .4237 .51789 .42172 .52378 .41969 .52058 .41639 Mtetra
.528 .708 .954 r
.52058 .41639 .52378 .41969 .52969 .42164 .52649 .41602 Mtetra
.441 .538 .86 r
.52649 .41602 .52969 .42164 .5356 .4155 .53243 .41737 Mtetra
.89 .984 .713 r
.53243 .41737 .5356 .4155 .54153 .41297 .53835 .40891 Mtetra
.504 .649 .923 r
.53835 .40891 .54153 .41297 .54747 .41112 .54431 .40903 Mtetra
.813 .863 .885 r
.54431 .40903 .54747 .41112 .55341 .40829 .55025 .40441 Mtetra
.43 .624 .934 r
.55025 .40441 .55341 .40829 .55937 .40577 .55625 .40515 Mtetra
.511 .891 .964 r
.55625 .40515 .55937 .40577 .56536 .40491 .56224 .40334 Mtetra
.683 .889 .973 r
.56224 .40334 .56536 .40491 .57136 .40377 .56824 .40079 Mtetra
.576 .753 .962 r
.56824 .40079 .57136 .40377 .57735 .40044 .57427 .39981 Mtetra
.743 .96 .94 r
.57427 .39981 .57735 .40044 .58336 .39804 .58027 .3961 Mtetra
.676 .863 .97 r
.58027 .3961 .58336 .39804 .58943 .39818 .5863 .39372 Mtetra
.578 .663 .896 r
.5863 .39372 .58943 .39818 .59542 .39392 .59238 .39305 Mtetra
0 .536 .788 r
.59238 .39305 .59542 .39392 .60154 .39463 .59852 .39403 Mtetra
.898 .944 .83 r
.59852 .39403 .60154 .39463 .60767 .39478 .60449 .38715 Mtetra
.341 .411 .789 r
.60449 .38715 .60767 .39478 .61364 .38859 .61073 .39073 Mtetra
.559 .045 0 r
.61073 .39073 .61364 .38859 .61989 .39171 .61697 .39321 Mtetra
0 0 0 r
.61697 .39321 .61989 .39171 .62611 .39287 .62312 .39154 Mtetra
.809 .927 .913 r
.62312 .39154 .62611 .39287 .63226 .39119 .62919 .38701 Mtetra
.845 .762 .771 r
.62919 .38701 .63226 .39119 .63827 .38531 .63516 .37944 Mtetra
.761 .685 .777 r
.63516 .37944 .63827 .38531 .64429 .37965 .6412 .37416 Mtetra
.558 .609 .859 r
.6412 .37416 .64429 .37965 .65062 .38174 .64744 .37392 Mtetra
.624 .572 .775 r
.64744 .37392 .65062 .38174 .65686 .38096 .65364 .3723 Mtetra
.649 .568 .751 r
.65364 .3723 .65686 .38096 .66306 .37886 .65982 .3698 Mtetra
.584 .525 .755 r
.65982 .3698 .66306 .37886 .66928 .37703 .6661 .3692 Mtetra
.64 .581 .772 r
.6661 .3692 .66928 .37703 .67541 .37283 .67233 .36713 Mtetra
.692 .665 .818 r
.67233 .36713 .67541 .37283 .68139 .36562 .67853 .36416 Mtetra
.749 .922 .948 r
.67853 .36416 .68139 .36562 .68769 .36462 .68471 .36057 Mtetra
.677 .731 .891 r
.68471 .36057 .68769 .36462 .69392 .36208 .69097 .35827 Mtetra
.685 .748 .9 r
.69097 .35827 .69392 .36208 .70013 .35886 .69723 .35585 Mtetra
.639 .783 .951 r
.69723 .35585 .70013 .35886 .70644 .35737 .70354 .35406 Mtetra
.708 .787 .913 r
.70354 .35406 .70644 .35737 .71275 .35551 .7098 .35126 Mtetra
.687 .726 .88 r
.7098 .35126 .71275 .35551 .71905 .35324 .7161 .34874 Mtetra
.665 .705 .878 r
.7161 .34874 .71905 .35324 .72537 .35104 .72243 .34661 Mtetra
.653 .704 .885 r
.72243 .34661 .72537 .35104 .7317 .3488 .72879 .34469 Mtetra
.658 .725 .898 r
.72879 .34469 .7317 .3488 .73802 .34618 .73516 .34269 Mtetra
.692 .774 .914 r
.73516 .34269 .73802 .34618 .74441 .34442 .7415 .34013 Mtetra
.643 .709 .895 r
.7415 .34013 .74441 .34442 .75077 .34203 .74792 .33838 Mtetra
.678 .76 .913 r
.74792 .33838 .75077 .34203 .75719 .34027 .75431 .33604 Mtetra
.67 .725 .89 r
.75431 .33604 .75719 .34027 .76358 .33799 .76072 .3338 Mtetra
.655 .72 .897 r
.76072 .3338 .76358 .33799 .76999 .33572 .76716 .33183 Mtetra
.664 .742 .908 r
.76716 .33183 .76999 .33572 .77644 .33364 .77361 .32971 Mtetra
.669 .742 .905 r
.77361 .32971 .77644 .33364 .7829 .33163 .78006 .3275 Mtetra
.657 .726 .9 r
.78006 .3275 .7829 .33163 .78936 .3295 .78655 .32549 Mtetra
.655 .733 .907 r
.78655 .32549 .78936 .3295 .79582 .32709 .79306 .3235 Mtetra
.68 .768 .918 r
.79306 .3235 .79582 .32709 .80234 .32522 .79954 .32109 Mtetra
.65 .725 .904 r
.79954 .32109 .80234 .32522 .80884 .32294 .80608 .31917 Mtetra
.675 .757 .912 r
.80608 .31917 .80884 .32294 .81538 .32098 .8126 .31683 Mtetra
.652 .726 .903 r
.8126 .31683 .81538 .32098 .8219 .31864 .81917 .31488 Mtetra
.675 .758 .913 r
.81917 .31488 .8219 .31864 .82847 .31664 .82572 .31253 Mtetra
.669 .736 .901 r
.82572 .31253 .82847 .31664 .83503 .31443 .83229 .31028 Mtetra
.659 .73 .902 r
.83229 .31028 .83503 .31443 .84161 .31223 .83889 .30819 Mtetra
.648 .732 .91 r
.83889 .30819 .84161 .31223 .8482 .30997 .84553 .30628 Mtetra
.662 .76 .922 r
.84553 .30628 .8482 .30997 .85486 .30819 .85215 .30412 Mtetra
.666 .739 .905 r
.85215 .30412 .85486 .30819 .86149 .30605 .85879 .3019 Mtetra
.645 .726 .907 r
.85879 .3019 .86149 .30605 .86811 .30361 .86548 .30002 Mtetra
.699 .782 .916 r
.86548 .30002 .86811 .30361 .8748 .30172 .87209 .29723 Mtetra
.65 .711 .892 r
.87209 .29723 .8748 .30172 .88142 .29905 .8788 .29527 Mtetra
.647 .731 .91 r
.27997 .48722 .28349 .49061 .2889 .48873 .28537 .48568 Mtetra
.679 .759 .912 r
.28537 .48568 .2889 .48873 .2943 .4873 .29081 .48367 Mtetra
.624 .71 .908 r
.29081 .48367 .2943 .4873 .29974 .48526 .2962 .48244 Mtetra
.695 .778 .915 r
.2962 .48244 .29974 .48526 .30516 .4839 .30168 .48019 Mtetra
.638 .711 .899 r
.30168 .48019 .30516 .4839 .31062 .48192 .30712 .47876 Mtetra
.679 .754 .908 r
.30712 .47876 .31062 .48192 .31609 .47995 .3126 .47673 Mtetra
.68 .751 .905 r
.3126 .47673 .31609 .47995 .32156 .47822 .3181 .47468 Mtetra
.656 .727 .901 r
.3181 .47468 .32156 .47822 .32706 .47635 .32359 .47298 Mtetra
.654 .737 .91 r
.32359 .47298 .32706 .47635 .33255 .47451 .32908 .4713 Mtetra
.667 .75 .913 r
.32908 .4713 .33255 .47451 .33806 .47272 .3346 .46943 Mtetra
.659 .743 .913 r
.3346 .46943 .33806 .47272 .34357 .47106 .34012 .46768 Mtetra
.668 .741 .905 r
.34012 .46768 .34357 .47106 .34911 .46912 .34567 .46578 Mtetra
.654 .74 .913 r
.34567 .46578 .34911 .46912 .35465 .46737 .35121 .46409 Mtetra
.68 .751 .905 r
.35121 .46409 .35465 .46737 .3602 .46568 .35679 .46201 Mtetra
.656 .723 .898 r
.35679 .46201 .3602 .46568 .36577 .46367 .36235 .46029 Mtetra
.657 .74 .911 r
.36235 .46029 .36577 .46367 .37136 .46173 .36793 .45855 Mtetra
.664 .755 .918 r
.36793 .45855 .37136 .46173 .37695 .45986 .37353 .4567 Mtetra
.662 .756 .92 r
.37353 .4567 .37695 .45986 .38255 .4581 .37914 .45487 Mtetra
.669 .753 .914 r
.37914 .45487 .38255 .4581 .38815 .45644 .38476 .45294 Mtetra
.666 .737 .903 r
.38476 .45294 .38815 .45644 .39377 .45465 .3904 .45104 Mtetra
.642 .723 .908 r
.3904 .45104 .39377 .45465 .39942 .45247 .39603 .4495 Mtetra
.681 .774 .922 r
.39603 .4495 .39942 .45247 .40506 .45105 .40169 .44739 Mtetra
.662 .727 .898 r
.40169 .44739 .40506 .45105 .41072 .44918 .40736 .44554 Mtetra
.642 .723 .907 r
.40736 .44554 .41072 .44918 .4164 .44713 .41303 .44399 Mtetra
.655 .758 .925 r
.41303 .44399 .4164 .44713 .42208 .44526 .41872 .44223 Mtetra
.666 .768 .926 r
.41872 .44223 .42208 .44526 .42777 .44374 .42442 .44031 Mtetra
.692 .751 .897 r
.42442 .44031 .42777 .44374 .43346 .44258 .43015 .43797 Mtetra
.627 .669 .871 r
.43015 .43797 .43346 .44258 .43917 .44079 .43587 .43665 Mtetra
.672 .708 .875 r
.43587 .43665 .43917 .44079 .44492 .43838 .44161 .43459 Mtetra
.533 .675 .929 r
.44161 .43459 .44492 .43838 .45063 .43801 .44733 .43434 Mtetra
.748 .752 .856 r
.44733 .43434 .45063 .43801 .45639 .4365 .45313 .43075 Mtetra
.529 .577 .847 r
.45313 .43075 .45639 .4365 .46217 .43407 .45887 .43101 Mtetra
.499 .71 .966 r
.45887 .43101 .46217 .43407 .46797 .43141 .46463 .43081 Mtetra
.079 .63 .823 r
.46463 .43081 .46797 .43141 .47374 .43123 .4704 .43102 Mtetra
.289 0 0 r
.4704 .43102 .47374 .43123 .47951 .43184 .47618 .43248 Mtetra
.096 0 0 r
.47618 .43248 .47951 .43184 .48534 .42971 .482 .43233 Mtetra
0 0 0 r
.482 .43233 .48534 .42971 .49119 .42774 .48787 .4289 Mtetra
.63 .959 .806 r
.48787 .4289 .49119 .42774 .49701 .42907 .49376 .42478 Mtetra
.516 .641 .911 r
.49376 .42478 .49701 .42907 .50285 .43207 .49963 .42484 Mtetra
.4 .457 .804 r
.49963 .42484 .50285 .43207 .50874 .43054 .50549 .4273 Mtetra
.634 .753 .934 r
.50549 .4273 .50874 .43054 .51466 .4237 .51141 .42575 Mtetra
.566 .903 .669 r
.51141 .42575 .51466 .4237 .52058 .41639 .51734 .42091 Mtetra
0 0 0 r
.51734 .42091 .52058 .41639 .52649 .41602 .52328 .41293 Mtetra
.658 .772 .933 r
.52328 .41293 .52649 .41602 .53243 .41737 .52922 .41104 Mtetra
.507 .547 .832 r
.52922 .41104 .53243 .41737 .53835 .40891 .53518 .41174 Mtetra
.811 .958 .627 r
.53518 .41174 .53835 .40891 .54431 .40903 .54111 .40326 Mtetra
.45 .537 .855 r
.54111 .40326 .54431 .40903 .55025 .40441 .5471 .40456 Mtetra
.761 .989 .892 r
.5471 .40456 .55025 .40441 .55625 .40515 .55307 .40012 Mtetra
.696 .684 .835 r
.55307 .40012 .55625 .40515 .56224 .40334 .55906 .3973 Mtetra
.598 .605 .829 r
.55906 .3973 .56224 .40334 .56824 .40079 .56508 .39642 Mtetra
.733 .726 .844 r
.56508 .39642 .56824 .40079 .57427 .39981 .57108 .39289 Mtetra
.468 .507 .816 r
.57108 .39289 .57427 .39981 .58027 .3961 .57717 .39434 Mtetra
.714 .884 .959 r
.57717 .39434 .58027 .3961 .5863 .39372 .58321 .39144 Mtetra
.28 .662 .97 r
.58321 .39144 .5863 .39372 .59238 .39305 .58932 .39218 Mtetra
.853 .945 .879 r
.58932 .39218 .59238 .39305 .59852 .39403 .59533 .38669 Mtetra
.258 .368 .785 r
.59533 .38669 .59852 .39403 .60449 .38715 .60157 .39109 Mtetra
.59 .141 .154 r
.60157 .39109 .60449 .38715 .61073 .39073 .60781 .39374 Mtetra
0 0 0 r
.60781 .39374 .61073 .39073 .61697 .39321 .61388 .38955 Mtetra
.769 .775 .857 r
.61388 .38955 .61697 .39321 .62312 .39154 .61997 .38536 Mtetra
.774 .681 .76 r
.61997 .38536 .62312 .39154 .62919 .38701 .62599 .37927 Mtetra
.704 .615 .754 r
.62599 .37927 .62919 .38701 .63516 .37944 .63208 .37512 Mtetra
.627 .695 .894 r
.63208 .37512 .63516 .37944 .6412 .37416 .63828 .37367 Mtetra
.071 .627 .807 r
.63828 .37367 .6412 .37416 .64744 .37392 .64454 .37383 Mtetra
.497 .904 .904 r
.64454 .37383 .64744 .37392 .65364 .3723 .65073 .37145 Mtetra
.779 .96 .926 r
.65073 .37145 .65364 .3723 .65982 .3698 .65686 .36722 Mtetra
.756 .843 .917 r
.65686 .36722 .65982 .3698 .6661 .3692 .66302 .36365 Mtetra
.705 .676 .819 r
.66302 .36365 .6661 .3692 .67233 .36713 .6692 .36038 Mtetra
.616 .596 .808 r
.6692 .36038 .67233 .36713 .67853 .36416 .67549 .35908 Mtetra
.633 .664 .862 r
.67549 .35908 .67853 .36416 .68471 .36057 .68177 .3575 Mtetra
.788 .819 .877 r
.68177 .3575 .68471 .36057 .69097 .35827 .68793 .3531 Mtetra
.619 .654 .862 r
.68793 .3531 .69097 .35827 .69723 .35585 .69426 .35177 Mtetra
.71 .743 .878 r
.69426 .35177 .69723 .35585 .70354 .35406 .70051 .34882 Mtetra
.63 .657 .858 r
.70051 .34882 .70354 .35406 .7098 .35126 .70686 .34729 Mtetra
.658 .732 .904 r
.70686 .34729 .7098 .35126 .7161 .34874 .7132 .3453 Mtetra
.669 .768 .924 r
.7132 .3453 .7161 .34874 .72243 .34661 .71954 .34312 Mtetra
.681 .77 .918 r
.71954 .34312 .72243 .34661 .72879 .34469 .72588 .34075 Mtetra
.677 .742 .9 r
.72588 .34075 .72879 .34469 .73516 .34269 .73224 .33842 Mtetra
.638 .709 .898 r
.73224 .33842 .73516 .34269 .7415 .34013 .73865 .33674 Mtetra
.694 .782 .918 r
.73865 .33674 .7415 .34013 .74792 .33838 .74502 .33414 Mtetra
.644 .713 .898 r
.74502 .33414 .74792 .33838 .75431 .33604 .75146 .33235 Mtetra
.665 .754 .917 r
.75146 .33235 .75431 .33604 .76072 .3338 .75788 .33021 Mtetra
.667 .762 .921 r
.75788 .33021 .76072 .3338 .76716 .33183 .76432 .32802 Mtetra
.661 .747 .913 r
.76432 .32802 .76716 .33183 .77361 .32971 .77078 .32593 Mtetra
.664 .75 .914 r
.77078 .32593 .77361 .32971 .78006 .3275 .77726 .32379 Mtetra
.675 .759 .914 r
.77726 .32379 .78006 .3275 .78655 .32549 .78373 .32147 Mtetra
.662 .737 .905 r
.78373 .32147 .78655 .32549 .79306 .3235 .79023 .31935 Mtetra
.653 .725 .902 r
.79023 .31935 .79306 .3235 .79954 .32109 .79677 .31738 Mtetra
.679 .762 .914 r
.79677 .31738 .79954 .32109 .80608 .31917 .80328 .31497 Mtetra
.646 .721 .903 r
.80328 .31497 .80608 .31917 .8126 .31683 .80985 .3131 Mtetra
.677 .761 .915 r
.80985 .3131 .8126 .31683 .81917 .31488 .81639 .31072 Mtetra
.657 .729 .902 r
.81639 .31072 .81917 .31488 .82572 .31253 .82298 .30866 Mtetra
.667 .75 .912 r
.82298 .30866 .82572 .31253 .83229 .31028 .82956 .30643 Mtetra
.668 .752 .913 r
.82956 .30643 .83229 .31028 .83889 .30819 .83616 .30418 Mtetra
.658 .739 .91 r
.83616 .30418 .83889 .30819 .84553 .30628 .84279 .30208 Mtetra
.659 .729 .902 r
.84279 .30208 .84553 .30628 .85215 .30412 .84943 .29998 Mtetra
.635 .723 .911 r
.84943 .29998 .85215 .30412 .85879 .3019 .85614 .29825 Mtetra
.699 .779 .913 r
.85614 .29825 .85879 .3019 .86548 .30002 .86274 .29545 Mtetra
.633 .699 .893 r
.86274 .29545 .86548 .30002 .87209 .29723 .86948 .29378 Mtetra
.703 .794 .921 r
.86948 .29378 .87209 .29723 .8788 .29527 .8761 .29092 Mtetra
.667 .749 .912 r
.27642 .48405 .27997 .48722 .28537 .48568 .28185 .48221 Mtetra
.633 .723 .912 r
.28185 .48221 .28537 .48568 .29081 .48367 .28725 .48084 Mtetra
.688 .777 .918 r
.28725 .48084 .29081 .48367 .2962 .48244 .29272 .47868 Mtetra
.63 .706 .901 r
.29272 .47868 .2962 .48244 .30168 .48019 .29814 .47736 Mtetra
.699 .78 .914 r
.29814 .47736 .30168 .48019 .30712 .47876 .30364 .47503 Mtetra
.652 .715 .895 r
.30364 .47503 .30712 .47876 .3126 .47673 .30911 .47339 Mtetra
.668 .743 .906 r
.30911 .47339 .3126 .47673 .3181 .47468 .3146 .47152 Mtetra
.664 .753 .916 r
.3146 .47152 .3181 .47468 .32359 .47298 .3201 .46969 Mtetra
.668 .746 .909 r
.3201 .46969 .32359 .47298 .32908 .4713 .32561 .46781 Mtetra
.651 .73 .907 r
.32561 .46781 .32908 .4713 .3346 .46943 .33113 .46618 Mtetra
.676 .751 .907 r
.33113 .46618 .3346 .46943 .34012 .46768 .33667 .46416 Mtetra
.65 .728 .906 r
.33667 .46416 .34012 .46768 .34567 .46578 .34221 .46252 Mtetra
.682 .753 .905 r
.34221 .46252 .34567 .46578 .35121 .46409 .34778 .46042 Mtetra
.644 .719 .902 r
.34778 .46042 .35121 .46409 .35679 .46201 .35333 .45886 Mtetra
.662 .755 .92 r
.35333 .45886 .35679 .46201 .36235 .46029 .35891 .45705 Mtetra
.672 .753 .912 r
.35891 .45705 .36235 .46029 .36793 .45855 .36451 .45508 Mtetra
.665 .738 .904 r
.36451 .45508 .36793 .45855 .37353 .4567 .37011 .4532 Mtetra
.653 .734 .909 r
.37011 .4532 .37353 .4567 .37914 .45487 .37572 .45151 Mtetra
.657 .743 .913 r
.37572 .45151 .37914 .45487 .38476 .45294 .38135 .44974 Mtetra
.683 .76 .91 r
.38135 .44974 .38476 .45294 .3904 .45104 .387 .44758 Mtetra
.651 .736 .912 r
.387 .44758 .3904 .45104 .39603 .4495 .39264 .4459 Mtetra
.673 .734 .897 r
.39264 .4459 .39603 .4495 .40169 .44739 .39831 .44388 Mtetra
.641 .731 .914 r
.39831 .44388 .40169 .44739 .40736 .44554 .40398 .44234 Mtetra
.66 .756 .921 r
.40398 .44234 .40736 .44554 .41303 .44399 .40966 .44051 Mtetra
.658 .739 .909 r
.40966 .44051 .41303 .44399 .41872 .44223 .41536 .43871 Mtetra
.646 .733 .913 r
.41536 .43871 .41872 .44223 .42442 .44031 .42106 .43708 Mtetra
.651 .753 .924 r
.42106 .43708 .42442 .44031 .43015 .43797 .42678 .43537 Mtetra
.706 .807 .928 r
.42678 .43537 .43015 .43797 .43587 .43665 .43254 .43283 Mtetra
.584 .695 .918 r
.43254 .43283 .43587 .43665 .44161 .43459 .43826 .43203 Mtetra
.733 .816 .916 r
.43826 .43203 .44161 .43459 .44733 .43434 .44405 .42905 Mtetra
.586 .623 .855 r
.44405 .42905 .44733 .43434 .45313 .43075 .44979 .42839 Mtetra
.458 .745 .991 r
.44979 .42839 .45313 .43075 .45887 .43101 .45554 .42814 Mtetra
.513 .732 .973 r
.45554 .42814 .45887 .43101 .46463 .43081 .46132 .42773 Mtetra
.614 .755 .946 r
.46132 .42773 .46463 .43081 .4704 .43102 .46712 .42643 Mtetra
.515 .624 .897 r
.46712 .42643 .4704 .43102 .47618 .43248 .47292 .42657 Mtetra
.368 .485 .847 r
.47292 .42657 .47618 .43248 .482 .43233 .47871 .42877 Mtetra
.414 .638 .948 r
.47871 .42877 .482 .43233 .48787 .4289 .48454 .42944 Mtetra
.769 .994 .871 r
.48454 .42944 .48787 .4289 .49376 .42478 .49046 .42473 Mtetra
.845 .975 .874 r
.49046 .42473 .49376 .42478 .49963 .42484 .49638 .4193 Mtetra
.59 .617 .847 r
.49638 .4193 .49963 .42484 .50549 .4273 .50227 .41857 Mtetra
.503 .481 .765 r
.50227 .41857 .50549 .4273 .51141 .42575 .50817 .4198 Mtetra
.569 .593 .838 r
.50817 .4198 .51141 .42575 .51734 .42091 .5141 .41945 Mtetra
.335 .754 .977 r
.5141 .41945 .51734 .42091 .52328 .41293 .52004 .41926 Mtetra
0 0 0 r
.52004 .41926 .52328 .41293 .52922 .41104 .526 .41169 Mtetra
.868 .992 .819 r
.526 .41169 .52922 .41104 .53518 .41174 .53196 .40519 Mtetra
.528 .552 .823 r
.53196 .40519 .53518 .41174 .54111 .40326 .53794 .40558 Mtetra
.735 .957 .667 r
.53794 .40558 .54111 .40326 .5471 .40456 .5439 .39883 Mtetra
.456 .543 .857 r
.5439 .39883 .5471 .40456 .55307 .40012 .54992 .40003 Mtetra
.398 .851 .895 r
.54992 .40003 .55307 .40012 .55906 .3973 .55593 .39834 Mtetra
.403 .847 .743 r
.55593 .39834 .55906 .3973 .56508 .39642 .56195 .39546 Mtetra
.315 .773 .949 r
.56195 .39546 .56508 .39642 .57108 .39289 .56801 .39495 Mtetra
.562 .894 .645 r
.56801 .39495 .57108 .39289 .57717 .39434 .57401 .38986 Mtetra
.509 .632 .907 r
.57401 .38986 .57717 .39434 .58321 .39144 .58011 .39003 Mtetra
.766 .917 .939 r
.58011 .39003 .58321 .39144 .58932 .39218 .58615 .38631 Mtetra
.032 .277 .773 r
.58615 .38631 .58932 .39218 .59533 .38669 .59239 .39166 Mtetra
.513 .087 .168 r
.59239 .39166 .59533 .38669 .60157 .39109 .59858 .39268 Mtetra
.845 .989 .721 r
.59858 .39268 .60157 .39109 .60781 .39374 .60457 .38507 Mtetra
.689 .59 .739 r
.60457 .38507 .60781 .39374 .61388 .38955 .61066 .3811 Mtetra
.699 .599 .74 r
.61066 .3811 .61388 .38955 .61997 .38536 .61674 .37682 Mtetra
.673 .583 .747 r
.61674 .37682 .61997 .38536 .62599 .37927 .62286 .37351 Mtetra
.546 .592 .852 r
.62286 .37351 .62599 .37927 .63208 .37512 .62909 .37349 Mtetra
0 .453 .805 r
.62909 .37349 .63208 .37512 .63828 .37367 .63542 .37553 Mtetra
.061 0 0 r
.63542 .37553 .63828 .37367 .64454 .37383 .64164 .37404 Mtetra
.699 .983 .879 r
.64164 .37404 .64454 .37383 .65073 .37145 .64778 .36986 Mtetra
.757 .912 .943 r
.64778 .36986 .65073 .37145 .65686 .36722 .65395 .36621 Mtetra
.716 .944 .956 r
.65395 .36621 .65686 .36722 .66302 .36365 .66013 .36284 Mtetra
.792 .964 .917 r
.66013 .36284 .66302 .36365 .6692 .36038 .66627 .35835 Mtetra
.79 .887 .915 r
.66627 .35835 .6692 .36038 .67549 .35908 .67244 .35416 Mtetra
.682 .693 .853 r
.67244 .35416 .67549 .35908 .68177 .3575 .67869 .35162 Mtetra
.592 .613 .842 r
.67869 .35162 .68177 .3575 .68793 .3531 .68503 .3508 Mtetra
.75 .866 .933 r
.68503 .3508 .68793 .3531 .69426 .35177 .69126 .34731 Mtetra
.619 .689 .893 r
.69126 .34731 .69426 .35177 .70051 .34882 .69761 .34596 Mtetra
.664 .805 .95 r
.69761 .34596 .70051 .34882 .70686 .34729 .70393 .34379 Mtetra
.681 .769 .918 r
.70393 .34379 .70686 .34729 .7132 .3453 .71026 .34142 Mtetra
.67 .743 .905 r
.71026 .34142 .7132 .3453 .71954 .34312 .71661 .33921 Mtetra
.665 .74 .905 r
.71661 .33921 .71954 .34312 .72588 .34075 .72297 .33707 Mtetra
.68 .759 .911 r
.72297 .33707 .72588 .34075 .73224 .33842 .72934 .3347 Mtetra
.667 .752 .914 r
.72934 .3347 .73224 .33842 .73865 .33674 .73573 .33254 Mtetra
.66 .723 .896 r
.73573 .33254 .73865 .33674 .74502 .33414 .74215 .33048 Mtetra
.655 .753 .922 r
.74215 .33048 .74502 .33414 .75146 .33235 .74858 .3285 Mtetra
.678 .75 .905 r
.74858 .3285 .75146 .33235 .75788 .33021 .755 .32612 Mtetra
.669 .734 .899 r
.755 .32612 .75788 .33021 .76432 .32802 .76145 .32389 Mtetra
.662 .729 .899 r
.76145 .32389 .76432 .32802 .77078 .32593 .76792 .32178 Mtetra
.659 .727 .9 r
.76792 .32178 .77078 .32593 .77726 .32379 .77441 .31971 Mtetra
.655 .73 .905 r
.77441 .31971 .77726 .32379 .78373 .32147 .78092 .3177 Mtetra
.67 .755 .914 r
.78092 .3177 .78373 .32147 .79023 .31935 .78742 .31545 Mtetra
.67 .748 .909 r
.78742 .31545 .79023 .31935 .79677 .31738 .79394 .31318 Mtetra
.655 .725 .901 r
.79394 .31318 .79677 .31738 .80328 .31497 .8005 .31117 Mtetra
.668 .754 .915 r
.8005 .31117 .80328 .31497 .80985 .3131 .80705 .30893 Mtetra
.66 .729 .901 r
.80705 .30893 .80985 .3131 .81639 .31072 .81362 .30682 Mtetra
.659 .745 .914 r
.81362 .30682 .81639 .31072 .82298 .30866 .82022 .30472 Mtetra
.679 .751 .906 r
.82022 .30472 .82298 .30866 .82956 .30643 .82679 .30227 Mtetra
.662 .733 .902 r
.82679 .30227 .82956 .30643 .83616 .30418 .83341 .30011 Mtetra
.659 .737 .907 r
.83341 .30011 .83616 .30418 .84279 .30208 .84005 .29799 Mtetra
.638 .727 .913 r
.84005 .29799 .84279 .30208 .84943 .29998 .84674 .29622 Mtetra
.69 .769 .912 r
.84674 .29622 .84943 .29998 .85614 .29825 .85336 .29358 Mtetra
.62 .688 .892 r
.85336 .29358 .85614 .29825 .86274 .29545 .86012 .29211 Mtetra
.711 .804 .923 r
.86012 .29211 .86274 .29545 .86948 .29378 .86673 .28912 Mtetra
.65 .704 .886 r
.86673 .28912 .86948 .29378 .8761 .29092 .87346 .28713 Mtetra
.645 .73 .91 r
.27288 .48062 .27642 .48405 .28185 .48221 .27829 .47909 Mtetra
.662 .753 .918 r
.27829 .47909 .28185 .48221 .28725 .48084 .28373 .47731 Mtetra
.644 .724 .906 r
.28373 .47731 .28725 .48084 .29272 .47868 .28916 .47578 Mtetra
.684 .772 .918 r
.28916 .47578 .29272 .47868 .29814 .47736 .29464 .47368 Mtetra
.646 .716 .899 r
.29464 .47368 .29814 .47736 .30364 .47503 .30009 .47212 Mtetra
.693 .774 .914 r
.30009 .47212 .30364 .47503 .30911 .47339 .30561 .46988 Mtetra
.659 .73 .902 r
.30561 .46988 .30911 .47339 .3146 .47152 .3111 .46812 Mtetra
.663 .738 .906 r
.3111 .46812 .3146 .47152 .3201 .46969 .3166 .4663 Mtetra
.658 .738 .909 r
.3166 .4663 .3201 .46969 .32561 .46781 .32212 .46456 Mtetra
.674 .75 .909 r
.32212 .46456 .32561 .46781 .33113 .46618 .32766 .46258 Mtetra
.645 .723 .905 r
.32766 .46258 .33113 .46618 .33667 .46416 .33318 .46101 Mtetra
.683 .761 .91 r
.33318 .46101 .33667 .46416 .34221 .46252 .33875 .45888 Mtetra
.644 .721 .904 r
.33875 .45888 .34221 .46252 .34778 .46042 .3443 .45733 Mtetra
.667 .761 .921 r
.3443 .45733 .34778 .46042 .35333 .45886 .34988 .45543 Mtetra
.677 .743 .901 r
.34988 .45543 .35333 .45886 .35891 .45705 .35548 .45338 Mtetra
.661 .726 .897 r
.35548 .45338 .35891 .45705 .36451 .45508 .36107 .45156 Mtetra
.663 .735 .903 r
.36107 .45156 .36451 .45508 .37011 .4532 .36668 .44971 Mtetra
.669 .739 .902 r
.36668 .44971 .37011 .4532 .37572 .45151 .37231 .44776 Mtetra
.661 .723 .894 r
.37231 .44776 .37572 .45151 .38135 .44974 .37795 .44592 Mtetra
.644 .714 .898 r
.37795 .44592 .38135 .44974 .387 .44758 .38358 .44435 Mtetra
.672 .757 .914 r
.38358 .44435 .387 .44758 .39264 .4459 .38924 .44235 Mtetra
.644 .73 .911 r
.38924 .44235 .39264 .4459 .39831 .44388 .3949 .44075 Mtetra
.688 .768 .912 r
.3949 .44075 .39831 .44388 .40398 .44234 .4006 .4385 Mtetra
.664 .721 .891 r
.4006 .4385 .40398 .44234 .40966 .44051 .4063 .4366 Mtetra
.655 .714 .892 r
.4063 .4366 .40966 .44051 .41536 .43871 .412 .43484 Mtetra
.673 .722 .886 r
.412 .43484 .41536 .43871 .42106 .43708 .41772 .43278 Mtetra
.644 .691 .879 r
.41772 .43278 .42106 .43708 .42678 .43537 .42344 .43117 Mtetra
.638 .695 .886 r
.42344 .43117 .42678 .43537 .43254 .43283 .42918 .42966 Mtetra
.687 .768 .913 r
.42918 .42966 .43254 .43283 .43826 .43203 .43494 .42739 Mtetra
.602 .659 .878 r
.43494 .42739 .43826 .43203 .44405 .42905 .44069 .42644 Mtetra
.565 .77 .975 r
.44069 .42644 .44405 .42905 .44979 .42839 .44645 .4255 Mtetra
.732 .796 .903 r
.44645 .4255 .44979 .42839 .45554 .42814 .45227 .42247 Mtetra
.656 .641 .823 r
.45227 .42247 .45554 .42814 .46132 .42773 .45808 .42046 Mtetra
.595 .564 .79 r
.45808 .42046 .46132 .42773 .46712 .42643 .46387 .41965 Mtetra
.578 .569 .807 r
.46387 .41965 .46712 .42643 .47292 .42657 .46968 .41918 Mtetra
.506 .514 .798 r
.46968 .41918 .47292 .42657 .47871 .42877 .47549 .42007 Mtetra
.328 .374 .757 r
.47549 .42007 .47871 .42877 .48454 .42944 .48127 .42406 Mtetra
.498 .58 .868 r
.48127 .42406 .48454 .42944 .49046 .42473 .48714 .42461 Mtetra
.876 .962 .852 r
.48714 .42461 .49046 .42473 .49638 .4193 .49308 .41846 Mtetra
.874 .925 .855 r
.49308 .41846 .49638 .4193 .50227 .41857 .49903 .41239 Mtetra
.636 .618 .814 r
.49903 .41239 .50227 .41857 .50817 .4198 .50494 .41072 Mtetra
.583 .522 .751 r
.50494 .41072 .50817 .4198 .5141 .41945 .51087 .41013 Mtetra
.638 .549 .738 r
.51087 .41013 .5141 .41945 .52004 .41926 .51682 .40787 Mtetra
.344 .337 .707 r
.51682 .40787 .52004 .41926 .526 .41169 .52277 .41298 Mtetra
.485 .887 .744 r
.52277 .41298 .526 .41169 .53196 .40519 .52875 .40947 Mtetra
.652 .852 .459 r
.52875 .40947 .53196 .40519 .53794 .40558 .53472 .40066 Mtetra
.614 .657 .869 r
.53472 .40066 .53794 .40558 .5439 .39883 .54072 .39948 Mtetra
.672 .976 .855 r
.54072 .39948 .5439 .39883 .54992 .40003 .54672 .39539 Mtetra
.611 .669 .882 r
.54672 .39539 .54992 .40003 .55593 .39834 .55274 .39424 Mtetra
.551 .673 .918 r
.55274 .39424 .55593 .39834 .56195 .39546 .55879 .39381 Mtetra
.834 .896 .884 r
.55879 .39381 .56195 .39546 .56801 .39495 .5648 .38873 Mtetra
.57 .586 .831 r
.5648 .38873 .56801 .39495 .57401 .38986 .57088 .38835 Mtetra
.352 .762 .981 r
.57088 .38835 .57401 .38986 .58011 .39003 .57699 .38809 Mtetra
0 .454 .826 r
.57699 .38809 .58011 .39003 .58615 .38631 .58315 .39024 Mtetra
0 0 0 r
.58315 .39024 .58615 .38631 .59239 .39166 .58921 .38561 Mtetra
.719 .663 .793 r
.58921 .38561 .59239 .39166 .59858 .39268 .59529 .38172 Mtetra
.605 .509 .719 r
.59529 .38172 .59858 .39268 .60457 .38507 .60143 .38029 Mtetra
.72 .709 .839 r
.60143 .38029 .60457 .38507 .61066 .3811 .60754 .37691 Mtetra
.765 .749 .838 r
.60754 .37691 .61066 .3811 .61674 .37682 .61363 .37259 Mtetra
.634 .704 .896 r
.61363 .37259 .61674 .37682 .62286 .37351 .61981 .37102 Mtetra
0 .405 .826 r
.61981 .37102 .62286 .37351 .62909 .37349 .62614 .37387 Mtetra
.172 0 0 r
.62614 .37387 .62909 .37349 .63542 .37553 .63243 .37437 Mtetra
.801 .941 .919 r
.63243 .37437 .63542 .37553 .64164 .37404 .63856 .3699 Mtetra
.791 .76 .826 r
.63856 .3699 .64164 .37404 .64778 .36986 .64468 .3648 Mtetra
.751 .711 .815 r
.64468 .3648 .64778 .36986 .65395 .36621 .65082 .36042 Mtetra
.724 .676 .803 r
.65082 .36042 .65395 .36621 .66013 .36284 .65699 .35649 Mtetra
.667 .634 .807 r
.65699 .35649 .66013 .36284 .66627 .35835 .66323 .35399 Mtetra
.651 .707 .888 r
.66323 .35399 .66627 .35835 .67244 .35416 .66951 .35211 Mtetra
.772 .885 .927 r
.66951 .35211 .67244 .35416 .67869 .35162 .67571 .34823 Mtetra
.669 .771 .926 r
.67571 .34823 .67869 .35162 .68503 .3508 .682 .34606 Mtetra
.667 .696 .867 r
.682 .34606 .68503 .3508 .69126 .34731 .6883 .34384 Mtetra
.675 .768 .921 r
.6883 .34384 .69126 .34731 .69761 .34596 .69461 .34156 Mtetra
.686 .721 .876 r
.69461 .34156 .69761 .34596 .70393 .34379 .70092 .33901 Mtetra
.651 .688 .872 r
.70092 .33901 .70393 .34379 .71026 .34142 .70728 .3371 Mtetra
.667 .718 .887 r
.70728 .3371 .71026 .34142 .71661 .33921 .71364 .33492 Mtetra
.667 .72 .889 r
.71364 .33492 .71661 .33921 .72297 .33707 .72001 .33272 Mtetra
.64 .706 .895 r
.72001 .33272 .72297 .33707 .72934 .3347 .72643 .331 Mtetra
.671 .756 .914 r
.72643 .331 .72934 .3347 .73573 .33254 .73283 .32877 Mtetra
.668 .751 .912 r
.73283 .32877 .73573 .33254 .74215 .33048 .73925 .32656 Mtetra
.678 .747 .903 r
.73925 .32656 .74215 .33048 .74858 .3285 .74566 .32419 Mtetra
.654 .717 .894 r
.74566 .32419 .74858 .3285 .755 .32612 .75212 .3222 Mtetra
.658 .74 .91 r
.75212 .3222 .755 .32612 .76145 .32389 .7586 .32015 Mtetra
.663 .753 .917 r
.7586 .32015 .76145 .32389 .76792 .32178 .76507 .318 Mtetra
.673 .756 .913 r
.76507 .318 .76792 .32178 .77441 .31971 .77156 .3157 Mtetra
.664 .739 .906 r
.77156 .3157 .77441 .31971 .78092 .3177 .77806 .31353 Mtetra
.651 .725 .903 r
.77806 .31353 .78092 .3177 .78742 .31545 .7846 .31158 Mtetra
.671 .751 .911 r
.7846 .31158 .78742 .31545 .79394 .31318 .79113 .3093 Mtetra
.663 .748 .913 r
.79113 .3093 .79394 .31318 .8005 .31117 .79769 .30713 Mtetra
.665 .74 .906 r
.79769 .30713 .8005 .31117 .80705 .30893 .80425 .30493 Mtetra
.656 .739 .91 r
.80425 .30493 .80705 .30893 .81362 .30682 .81084 .30287 Mtetra
.677 .751 .907 r
.81084 .30287 .81362 .30682 .82022 .30472 .81742 .30046 Mtetra
.654 .724 .901 r
.81742 .30046 .82022 .30472 .82679 .30227 .82405 .29843 Mtetra
.669 .755 .915 r
.82405 .29843 .82679 .30227 .83341 .30011 .83067 .29615 Mtetra
.659 .744 .913 r
.83067 .29615 .83341 .30011 .84005 .29799 .83732 .29404 Mtetra
.671 .75 .91 r
.83732 .29404 .84005 .29799 .84674 .29622 .84396 .29171 Mtetra
.625 .7 .898 r
.84396 .29171 .84674 .29622 .85336 .29358 .85071 .29014 Mtetra
.688 .791 .928 r
.85071 .29014 .85336 .29358 .86012 .29211 .85735 .28752 Mtetra
.641 .704 .892 r
.85735 .28752 .86012 .29211 .86673 .28912 .8641 .28569 Mtetra
.706 .798 .922 r
.8641 .28569 .86673 .28912 .87346 .28713 .87074 .28275 Mtetra
.651 .746 .919 r
.26931 .47743 .27288 .48062 .27829 .47909 .27473 .4758 Mtetra
.659 .742 .912 r
.27473 .4758 .27829 .47909 .28373 .47731 .28017 .47406 Mtetra
.65 .743 .917 r
.28017 .47406 .28373 .47731 .28916 .47578 .28561 .47244 Mtetra
.668 .742 .905 r
.28561 .47244 .28916 .47578 .29464 .47368 .29108 .47055 Mtetra
.675 .757 .913 r
.29108 .47055 .29464 .47368 .30009 .47212 .29658 .46857 Mtetra
.659 .728 .9 r
.29658 .46857 .30009 .47212 .30561 .46988 .30206 .46681 Mtetra
.684 .764 .912 r
.30206 .46681 .30561 .46988 .3111 .46812 .30758 .46467 Mtetra
.662 .737 .905 r
.30758 .46467 .3111 .46812 .3166 .4663 .3131 .46286 Mtetra
.657 .736 .907 r
.3131 .46286 .3166 .4663 .32212 .46456 .31862 .46112 Mtetra
.654 .735 .909 r
.31862 .46112 .32212 .46456 .32766 .46258 .32414 .45942 Mtetra
.673 .758 .914 r
.32414 .45942 .32766 .46258 .33318 .46101 .3297 .45743 Mtetra
.656 .728 .903 r
.3297 .45743 .33318 .46101 .33875 .45888 .33525 .4557 Mtetra
.666 .756 .917 r
.33525 .4557 .33875 .45888 .3443 .45733 .34083 .45382 Mtetra
.675 .738 .898 r
.34083 .45382 .3443 .45733 .34988 .45543 .34642 .45179 Mtetra
.646 .723 .905 r
.34642 .45179 .34988 .45543 .35548 .45338 .352 .45019 Mtetra
.66 .755 .921 r
.352 .45019 .35548 .45338 .36107 .45156 .35761 .44838 Mtetra
.665 .757 .919 r
.35761 .44838 .36107 .45156 .36668 .44971 .36323 .44649 Mtetra
.661 .754 .919 r
.36323 .44649 .36668 .44971 .37231 .44776 .36886 .44466 Mtetra
.671 .765 .921 r
.36886 .44466 .37231 .44776 .37795 .44592 .3745 .44269 Mtetra
.672 .757 .914 r
.3745 .44269 .37795 .44592 .38358 .44435 .38016 .44068 Mtetra
.644 .723 .906 r
.38016 .44068 .38358 .44435 .38924 .44235 .38582 .43909 Mtetra
.68 .758 .91 r
.38582 .43909 .38924 .44235 .3949 .44075 .39151 .43696 Mtetra
.664 .723 .893 r
.39151 .43696 .3949 .44075 .4006 .4385 .3972 .43505 Mtetra
.646 .738 .916 r
.3972 .43505 .4006 .4385 .4063 .4366 .40289 .43341 Mtetra
.655 .757 .925 r
.40289 .43341 .4063 .4366 .412 .43484 .4086 .43163 Mtetra
.664 .759 .921 r
.4086 .43163 .412 .43484 .41772 .43278 .41433 .42972 Mtetra
.686 .775 .919 r
.41433 .42972 .41772 .43278 .42344 .43117 .42008 .42749 Mtetra
.611 .714 .918 r
.42008 .42749 .42344 .43117 .42918 .42966 .42581 .42632 Mtetra
.636 .744 .926 r
.42581 .42632 .42918 .42966 .43494 .42739 .43156 .42478 Mtetra
.684 .806 .94 r
.43156 .42478 .43494 .42739 .44069 .42644 .43735 .42254 Mtetra
.711 .735 .869 r
.43735 .42254 .44069 .42644 .44645 .4255 .44316 .41971 Mtetra
.612 .617 .832 r
.44316 .41971 .44645 .4255 .45227 .42247 .44894 .4186 Mtetra
.552 .682 .925 r
.44894 .4186 .45227 .42247 .45808 .42046 .45472 .41813 Mtetra
.563 .793 .985 r
.45472 .41813 .45808 .42046 .46387 .41965 .46054 .41707 Mtetra
.72 .817 .925 r
.46054 .41707 .46387 .41965 .46968 .41918 .46639 .41427 Mtetra
.621 .657 .864 r
.46639 .41427 .46968 .41918 .47549 .42007 .47224 .41299 Mtetra
.445 .488 .81 r
.47224 .41299 .47549 .42007 .48127 .42406 .47805 .41471 Mtetra
.28 .329 .736 r
.47805 .41471 .48127 .42406 .48714 .42461 .48385 .41967 Mtetra
.659 .673 .852 r
.48385 .41967 .48714 .42461 .49308 .41846 .48977 .41768 Mtetra
.909 .907 .808 r
.48977 .41768 .49308 .41846 .49903 .41239 .49574 .41005 Mtetra
.812 .844 .873 r
.49574 .41005 .49903 .41239 .50494 .41072 .50169 .40531 Mtetra
.516 .588 .866 r
.50169 .40531 .50494 .41072 .51087 .41013 .50761 .40563 Mtetra
.294 .516 .899 r
.50761 .40563 .51087 .41013 .51682 .40787 .51355 .40772 Mtetra
.665 .962 .934 r
.51355 .40772 .51682 .40787 .52277 .41298 .51953 .40449 Mtetra
.708 .601 .734 r
.51953 .40449 .52277 .41298 .52875 .40947 .52551 .39984 Mtetra
.438 .426 .748 r
.52551 .39984 .52875 .40947 .53472 .40066 .53151 .40253 Mtetra
0 0 0 r
.53151 .40253 .53472 .40066 .54072 .39948 .53752 .39944 Mtetra
.789 .986 .896 r
.53752 .39944 .54072 .39948 .54672 .39539 .54353 .39477 Mtetra
.844 .956 .885 r
.54353 .39477 .54672 .39539 .55274 .39424 .54954 .38944 Mtetra
.65 .68 .864 r
.54954 .38944 .55274 .39424 .55879 .39381 .55558 .38761 Mtetra
.484 .543 .841 r
.55558 .38761 .55879 .39381 .5648 .38873 .56167 .38856 Mtetra
.478 0 0 r
.56167 .38856 .5648 .38873 .57088 .38835 .5678 .39142 Mtetra
.642 .889 .55 r
.5678 .39142 .57088 .38835 .57699 .38809 .57382 .38424 Mtetra
.431 .633 .939 r
.57382 .38424 .57699 .38809 .58315 .39024 .57996 .3849 Mtetra
.459 .566 .876 r
.57996 .3849 .58315 .39024 .58921 .38561 .58614 .38591 Mtetra
.535 0 0 r
.58614 .38591 .58921 .38561 .59529 .38172 .59238 .38903 Mtetra
.095 0 .08 r
.59238 .38903 .59529 .38172 .60143 .38029 .59845 .3831 Mtetra
.707 .92 .58 r
.59845 .3831 .60143 .38029 .60754 .37691 .60448 .37542 Mtetra
.797 .917 .92 r
.60448 .37542 .60754 .37691 .61363 .37259 .61059 .37112 Mtetra
.548 .861 .996 r
.61059 .37112 .61363 .37259 .61981 .37102 .61678 .36958 Mtetra
0 .312 .672 r
.61678 .36958 .61981 .37102 .62614 .37387 .62312 .37235 Mtetra
.624 .887 .988 r
.62312 .37235 .62614 .37387 .63243 .37437 .62933 .3702 Mtetra
.842 .767 .778 r
.62933 .3702 .63243 .37437 .63856 .3699 .63537 .36284 Mtetra
.765 .659 .745 r
.63537 .36284 .63856 .3699 .64468 .3648 .64145 .35653 Mtetra
.668 .588 .756 r
.64145 .35653 .64468 .3648 .65082 .36042 .64765 .35344 Mtetra
.659 .613 .791 r
.64765 .35344 .65082 .36042 .65699 .35649 .65388 .35099 Mtetra
.677 .668 .833 r
.65388 .35099 .65699 .35649 .66323 .35399 .66013 .34843 Mtetra
.657 .657 .838 r
.66013 .34843 .66323 .35399 .66951 .35211 .6664 .3463 Mtetra
.623 .632 .839 r
.6664 .3463 .66951 .35211 .67571 .34823 .67272 .34487 Mtetra
.685 .778 .921 r
.67272 .34487 .67571 .34823 .682 .34606 .67901 .34243 Mtetra
.654 .752 .922 r
.67901 .34243 .682 .34606 .6883 .34384 .68533 .34048 Mtetra
.719 .79 .907 r
.68533 .34048 .6883 .34384 .69461 .34156 .69162 .33744 Mtetra
.649 .722 .902 r
.69162 .33744 .69461 .34156 .70092 .33901 .69798 .33558 Mtetra
.659 .767 .929 r
.69798 .33558 .70092 .33901 .70728 .3371 .70434 .33352 Mtetra
.67 .762 .92 r
.70434 .33352 .70728 .3371 .71364 .33492 .71071 .33131 Mtetra
.677 .764 .916 r
.71071 .33131 .71364 .33492 .72001 .33272 .71708 .32897 Mtetra
.672 .754 .912 r
.71708 .32897 .72001 .33272 .72643 .331 .72347 .32671 Mtetra
.642 .712 .898 r
.72347 .32671 .72643 .331 .73283 .32877 .72991 .32494 Mtetra
.688 .756 .904 r
.72991 .32494 .73283 .32877 .73925 .32656 .73632 .32239 Mtetra
.641 .719 .904 r
.73632 .32239 .73925 .32656 .74566 .32419 .74279 .32062 Mtetra
.665 .765 .924 r
.74279 .32062 .74566 .32419 .75212 .3222 .74925 .31845 Mtetra
.67 .756 .915 r
.74925 .31845 .75212 .3222 .7586 .32015 .75571 .31619 Mtetra
.661 .741 .909 r
.75571 .31619 .7586 .32015 .76507 .318 .76221 .31407 Mtetra
.661 .743 .91 r
.76221 .31407 .76507 .318 .77156 .3157 .76871 .31195 Mtetra
.67 .758 .916 r
.76871 .31195 .77156 .3157 .77806 .31353 .77522 .30967 Mtetra
.676 .754 .909 r
.77522 .30967 .77806 .31353 .7846 .31158 .78174 .30729 Mtetra
.647 .719 .9 r
.78174 .30729 .7846 .31158 .79113 .3093 .78831 .30539 Mtetra
.675 .752 .908 r
.78831 .30539 .79113 .3093 .79769 .30713 .79486 .30302 Mtetra
.648 .729 .908 r
.79486 .30302 .79769 .30713 .80425 .30493 .80146 .30109 Mtetra
.679 .758 .911 r
.80146 .30109 .80425 .30493 .81084 .30287 .80803 .29865 Mtetra
.651 .726 .903 r
.80803 .29865 .81084 .30287 .81742 .30046 .81466 .29666 Mtetra
.674 .76 .915 r
.81466 .29666 .81742 .30046 .82405 .29843 .82126 .29429 Mtetra
.671 .739 .902 r
.82126 .29429 .82405 .29843 .83067 .29615 .82789 .29197 Mtetra
.661 .733 .903 r
.82789 .29197 .83067 .29615 .83732 .29404 .83455 .2898 Mtetra
.639 .722 .908 r
.83455 .2898 .83732 .29404 .84396 .29171 .84126 .28799 Mtetra
.659 .762 .926 r
.84126 .28799 .84396 .29171 .85071 .29014 .84795 .28584 Mtetra
.656 .726 .901 r
.84795 .28584 .85071 .29014 .85735 .28752 .85466 .28374 Mtetra
.674 .765 .919 r
.85466 .28374 .85735 .28752 .8641 .28569 .86136 .28134 Mtetra
.671 .732 .895 r
.86136 .28134 .8641 .28569 .87074 .28275 .86808 .27896 Mtetra
.662 .737 .906 r
.26573 .47403 .26931 .47743 .27473 .4758 .27117 .47225 Mtetra
.625 .718 .913 r
.27117 .47225 .27473 .4758 .28017 .47406 .27658 .47097 Mtetra
.689 .762 .908 r
.27658 .47097 .28017 .47406 .28561 .47244 .28207 .46877 Mtetra
.629 .713 .907 r
.28207 .46877 .28561 .47244 .29108 .47055 .28751 .46744 Mtetra
.693 .763 .906 r
.28751 .46744 .29108 .47055 .29658 .46857 .29303 .46517 Mtetra
.668 .741 .905 r
.29303 .46517 .29658 .46857 .30206 .46681 .29853 .46328 Mtetra
.666 .733 .9 r
.29853 .46328 .30206 .46681 .30758 .46467 .30405 .4614 Mtetra
.66 .747 .914 r
.30405 .4614 .30758 .46467 .3131 .46286 .30956 .45962 Mtetra
.669 .751 .912 r
.30956 .45962 .3131 .46286 .31862 .46112 .3151 .45769 Mtetra
.655 .737 .91 r
.3151 .45769 .31862 .46112 .32414 .45942 .32064 .45598 Mtetra
.668 .74 .904 r
.32064 .45598 .32414 .45942 .3297 .45743 .3262 .45406 Mtetra
.658 .742 .912 r
.3262 .45406 .3297 .45743 .33525 .4557 .33176 .45228 Mtetra
.674 .744 .903 r
.33176 .45228 .33525 .4557 .34083 .45382 .33735 .45026 Mtetra
.645 .728 .91 r
.33735 .45026 .34083 .45382 .34642 .45179 .34292 .44868 Mtetra
.669 .762 .92 r
.34292 .44868 .34642 .45179 .352 .45019 .34853 .44673 Mtetra
.675 .743 .902 r
.34853 .44673 .352 .45019 .35761 .44838 .35415 .44469 Mtetra
.666 .728 .895 r
.35415 .44469 .35761 .44838 .36323 .44649 .35978 .44276 Mtetra
.655 .723 .899 r
.35978 .44276 .36323 .44649 .36886 .44466 .36541 .44101 Mtetra
.653 .727 .903 r
.36541 .44101 .36886 .44466 .3745 .44269 .37105 .43929 Mtetra
.665 .746 .91 r
.37105 .43929 .3745 .44269 .38016 .44068 .37672 .43738 Mtetra
.678 .755 .91 r
.37672 .43738 .38016 .44068 .38582 .43909 .3824 .43527 Mtetra
.639 .715 .902 r
.3824 .43527 .38582 .43909 .39151 .43696 .38807 .43374 Mtetra
.658 .757 .923 r
.38807 .43374 .39151 .43696 .3972 .43505 .39377 .43192 Mtetra
.677 .767 .919 r
.39377 .43192 .3972 .43505 .40289 .43341 .39949 .42981 Mtetra
.669 .738 .902 r
.39949 .42981 .40289 .43341 .4086 .43163 .40521 .42783 Mtetra
.652 .721 .9 r
.40521 .42783 .4086 .43163 .41433 .42972 .41094 .4261 Mtetra
.643 .729 .911 r
.41094 .4261 .41433 .42972 .42008 .42749 .41668 .4245 Mtetra
.683 .78 .924 r
.41668 .4245 .42008 .42749 .42581 .42632 .42244 .42228 Mtetra
.65 .709 .891 r
.42244 .42228 .42581 .42632 .43156 .42478 .42821 .42056 Mtetra
.678 .709 .872 r
.42821 .42056 .43156 .42478 .43735 .42254 .434 .41834 Mtetra
.565 .669 .908 r
.434 .41834 .43735 .42254 .44316 .41971 .43976 .4178 Mtetra
.546 .818 .996 r
.43976 .4178 .44316 .41971 .44894 .4186 .44555 .41669 Mtetra
.668 .855 .971 r
.44555 .41669 .44894 .4186 .45472 .41813 .45138 .41449 Mtetra
.548 .695 .937 r
.45138 .41449 .45472 .41813 .46054 .41707 .45719 .414 Mtetra
.453 .693 .97 r
.45719 .414 .46054 .41707 .46639 .41427 .463 .41411 Mtetra
.54 .917 .937 r
.463 .41411 .46639 .41427 .47224 .41299 .46888 .41185 Mtetra
.86 .909 .865 r
.46888 .41185 .47224 .41299 .47805 .41471 .47482 .40615 Mtetra
.159 .269 .729 r
.47482 .40615 .47805 .41471 .48385 .41967 .4806 .41201 Mtetra
.324 .4 .786 r
.4806 .41201 .48385 .41967 .48977 .41768 .48645 .41549 Mtetra
.892 .832 .78 r
.48645 .41549 .48977 .41768 .49574 .41005 .49245 .40719 Mtetra
.717 .803 .918 r
.49245 .40719 .49574 .41005 .50169 .40531 .49839 .40438 Mtetra
.37 0 0 r
.49839 .40438 .50169 .40531 .50761 .40563 .50431 .40698 Mtetra
.646 .131 .004 r
.50431 .40698 .50761 .40563 .51355 .40772 .51025 .41087 Mtetra
.566 .092 .09 r
.51025 .41087 .51355 .40772 .51953 .40449 .51624 .41312 Mtetra
.308 0 .209 r
.51624 .41312 .51953 .40449 .52551 .39984 .52225 .4094 Mtetra
.224 0 .198 r
.52225 .4094 .52551 .39984 .53151 .40253 .52827 .40381 Mtetra
.978 .909 .666 r
.52827 .40381 .53151 .40253 .53752 .39944 .53427 .39045 Mtetra
0 .114 .647 r
.53427 .39045 .53752 .39944 .54353 .39477 .54035 .39925 Mtetra
0 0 0 r
.54035 .39925 .54353 .39477 .54954 .38944 .54638 .39418 Mtetra
.402 0 .091 r
.54638 .39418 .54954 .38944 .55558 .38761 .55246 .39363 Mtetra
.47 .067 .193 r
.55246 .39363 .55558 .38761 .56167 .38856 .55856 .39365 Mtetra
.789 .874 .441 r
.55856 .39365 .56167 .38856 .5678 .39142 .56453 .38114 Mtetra
0 0 .514 r
.56453 .38114 .5678 .39142 .57382 .38424 .57084 .39425 Mtetra
.36 .033 .267 r
.57084 .39425 .57382 .38424 .57996 .3849 .57695 .3907 Mtetra
.09 0 0 r
.57695 .3907 .57996 .3849 .58614 .38591 .58304 .38607 Mtetra
.301 .796 .828 r
.58304 .38607 .58614 .38591 .59238 .38903 .58921 .38453 Mtetra
.764 .736 .827 r
.58921 .38453 .59238 .38903 .59845 .3831 .59532 .38006 Mtetra
.708 .8 .922 r
.59532 .38006 .59845 .3831 .60448 .37542 .60148 .37731 Mtetra
.867 .98 .685 r
.60148 .37731 .60448 .37542 .61059 .37112 .6075 .36868 Mtetra
.533 .783 .99 r
.6075 .36868 .61059 .37112 .61678 .36958 .61372 .36779 Mtetra
0 .327 .715 r
.61372 .36779 .61678 .36958 .62312 .37235 .62007 .37072 Mtetra
.922 .877 .774 r
.62007 .37072 .62312 .37235 .62933 .3702 .62608 .36178 Mtetra
.772 .637 .712 r
.62608 .36178 .62933 .3702 .63537 .36284 .63212 .35389 Mtetra
.55 .509 .763 r
.63212 .35389 .63537 .36284 .64145 .35653 .63843 .3541 Mtetra
.707 .845 .949 r
.63843 .3541 .64145 .35653 .64765 .35344 .64465 .35131 Mtetra
.721 .871 .952 r
.64465 .35131 .64765 .35344 .65388 .35099 .65088 .34827 Mtetra
.651 .81 .96 r
.65088 .34827 .65388 .35099 .66013 .34843 .65715 .34625 Mtetra
.747 .874 .938 r
.65715 .34625 .66013 .34843 .6664 .3463 .66338 .3428 Mtetra
.681 .769 .917 r
.66338 .3428 .6664 .3463 .67272 .34487 .66967 .34042 Mtetra
.665 .711 .882 r
.66967 .34042 .67272 .34487 .67901 .34243 .67598 .33827 Mtetra
.692 .736 .885 r
.67598 .33827 .67901 .34243 .68533 .34048 .68228 .33564 Mtetra
.631 .679 .877 r
.68228 .33564 .68533 .34048 .69162 .33744 .68865 .33406 Mtetra
.681 .778 .924 r
.68865 .33406 .69162 .33744 .69798 .33558 .69499 .33167 Mtetra
.678 .746 .903 r
.69499 .33167 .69798 .33558 .70434 .33352 .70135 .32932 Mtetra
.661 .724 .896 r
.70135 .32932 .70434 .33352 .71071 .33131 .70773 .32724 Mtetra
.651 .727 .905 r
.70773 .32724 .71071 .33131 .71708 .32897 .71414 .32532 Mtetra
.662 .757 .921 r
.71414 .32532 .71708 .32897 .72347 .32671 .72056 .32321 Mtetra
.694 .778 .916 r
.72056 .32321 .72347 .32671 .72991 .32494 .72695 .32058 Mtetra
.643 .71 .896 r
.72695 .32058 .72991 .32494 .73632 .32239 .73342 .31878 Mtetra
.673 .765 .92 r
.73342 .31878 .73632 .32239 .74279 .32062 .73986 .31648 Mtetra
.676 .736 .896 r
.73986 .31648 .74279 .32062 .74925 .31845 .74632 .3141 Mtetra
.658 .719 .893 r
.74632 .3141 .74925 .31845 .75571 .31619 .75281 .31202 Mtetra
.664 .731 .899 r
.75281 .31202 .75571 .31619 .76221 .31407 .75931 .30984 Mtetra
.66 .726 .898 r
.75931 .30984 .76221 .31407 .76871 .31195 .76582 .30773 Mtetra
.652 .724 .902 r
.76582 .30773 .76871 .31195 .77522 .30967 .77237 .30575 Mtetra
.664 .746 .911 r
.77237 .30575 .77522 .30967 .78174 .30729 .77891 .30356 Mtetra
.681 .765 .914 r
.77891 .30356 .78174 .30729 .78831 .30539 .78545 .30109 Mtetra
.647 .719 .901 r
.78545 .30109 .78831 .30539 .79486 .30302 .79204 .29918 Mtetra
.676 .758 .912 r
.79204 .29918 .79486 .30302 .80146 .30109 .79861 .29677 Mtetra
.648 .72 .9 r
.79861 .29677 .80146 .30109 .80803 .29865 .80524 .29483 Mtetra
.671 .758 .916 r
.80524 .29483 .80803 .29865 .81466 .29666 .81185 .29251 Mtetra
.671 .739 .902 r
.81185 .29251 .81466 .29666 .82126 .29429 .81847 .29017 Mtetra
.665 .739 .905 r
.81847 .29017 .82126 .29429 .82789 .29197 .82512 .28794 Mtetra
.651 .739 .914 r
.82512 .28794 .82789 .29197 .83455 .2898 .8318 .28593 Mtetra
.651 .749 .921 r
.8318 .28593 .83455 .2898 .84126 .28799 .8385 .2839 Mtetra
.67 .744 .906 r
.8385 .2839 .84126 .28799 .84795 .28584 .84519 .28157 Mtetra
.63 .718 .91 r
.84519 .28157 .84795 .28584 .85466 .28374 .85196 .27988 Mtetra
.691 .767 .91 r
.85196 .27988 .85466 .28374 .86136 .28134 .85864 .27719 Mtetra
.685 .749 .9 r
.85864 .27719 .86136 .28134 .86808 .27896 .86534 .27456 Mtetra
.635 .736 .921 r
.26214 .47073 .26573 .47403 .27117 .47225 .26755 .4693 Mtetra
.697 .773 .91 r
.26755 .4693 .27117 .47225 .27658 .47097 .27305 .46699 Mtetra
.6 .686 .903 r
.27305 .46699 .27658 .47097 .28207 .46877 .27845 .46605 Mtetra
.717 .791 .91 r
.27845 .46605 .28207 .46877 .28751 .46744 .284 .4634 Mtetra
.625 .692 .893 r
.284 .4634 .28751 .46744 .29303 .46517 .28945 .46214 Mtetra
.693 .769 .91 r
.28945 .46214 .29303 .46517 .29853 .46328 .29498 .45986 Mtetra
.671 .741 .903 r
.29498 .45986 .29853 .46328 .30405 .4614 .30051 .4579 Mtetra
.657 .733 .906 r
.30051 .4579 .30405 .4614 .30956 .45962 .30603 .45616 Mtetra
.658 .736 .908 r
.30603 .45616 .30956 .45962 .3151 .45769 .31156 .45439 Mtetra
.671 .75 .91 r
.31156 .45439 .3151 .45769 .32064 .45598 .31712 .45243 Mtetra
.647 .729 .909 r
.31712 .45243 .32064 .45598 .3262 .45406 .32267 .45081 Mtetra
.684 .757 .907 r
.32267 .45081 .3262 .45406 .33176 .45228 .32826 .44865 Mtetra
.643 .723 .907 r
.32826 .44865 .33176 .45228 .33735 .45026 .33383 .44708 Mtetra
.679 .761 .913 r
.33383 .44708 .33735 .45026 .34292 .44868 .33944 .44499 Mtetra
.665 .728 .896 r
.33944 .44499 .34292 .44868 .34853 .44673 .34505 .44309 Mtetra
.652 .727 .904 r
.34505 .44309 .34853 .44673 .35415 .44469 .35066 .44139 Mtetra
.665 .751 .914 r
.35066 .44139 .35415 .44469 .35978 .44276 .3563 .43948 Mtetra
.67 .754 .913 r
.3563 .43948 .35978 .44276 .36541 .44101 .36195 .4375 Mtetra
.673 .741 .902 r
.36195 .4375 .36541 .44101 .37105 .43929 .36761 .43546 Mtetra
.64 .714 .901 r
.36761 .43546 .37105 .43929 .37672 .43738 .37326 .43392 Mtetra
.67 .745 .907 r
.37326 .43392 .37672 .43738 .3824 .43527 .37895 .43193 Mtetra
.654 .748 .919 r
.37895 .43193 .3824 .43527 .38807 .43374 .38464 .43018 Mtetra
.685 .743 .896 r
.38464 .43018 .38807 .43374 .39377 .43192 .39036 .42792 Mtetra
.659 .713 .888 r
.39036 .42792 .39377 .43192 .39949 .42981 .39607 .42606 Mtetra
.66 .727 .899 r
.39607 .42606 .39949 .42981 .40521 .42783 .4018 .4242 Mtetra
.673 .738 .899 r
.4018 .4242 .40521 .42783 .41094 .4261 .40755 .42213 Mtetra
.625 .704 .902 r
.40755 .42213 .41094 .4261 .41668 .4245 .41328 .42079 Mtetra
.62 .717 .916 r
.41328 .42079 .41668 .4245 .42244 .42228 .41903 .41949 Mtetra
.729 .802 .91 r
.41903 .41949 .42244 .42228 .42821 .42056 .42484 .41652 Mtetra
.552 .673 .918 r
.42484 .41652 .42821 .42056 .434 .41834 .43059 .41609 Mtetra
.732 .84 .931 r
.43059 .41609 .434 .41834 .43976 .4178 .43642 .41311 Mtetra
.644 .676 .866 r
.43642 .41311 .43976 .4178 .44555 .41669 .44223 .41145 Mtetra
.644 .654 .845 r
.44223 .41145 .44555 .41669 .45138 .41449 .44806 .40974 Mtetra
.659 .68 .859 r
.44806 .40974 .45138 .41449 .45719 .414 .4539 .40779 Mtetra
.574 .587 .828 r
.4539 .40779 .45719 .414 .463 .41411 .45973 .40733 Mtetra
.38 .461 .819 r
.45973 .40733 .463 .41411 .46888 .41185 .46552 .40971 Mtetra
.528 .797 .995 r
.46552 .40971 .46888 .41185 .47482 .40615 .47139 .4088 Mtetra
.846 .977 .675 r
.47139 .4088 .47482 .40615 .4806 .41201 .47739 .40044 Mtetra
0 .042 .582 r
.47739 .40044 .4806 .41201 .48645 .41549 .48313 .41156 Mtetra
.75 .749 .851 r
.48313 .41156 .48645 .41549 .49245 .40719 .4891 .40775 Mtetra
.812 .997 .855 r
.4891 .40775 .49245 .40719 .49839 .40438 .49508 .40238 Mtetra
.814 .332 0 r
.49508 .40238 .49839 .40438 .50431 .40698 .50096 .41153 Mtetra
0 0 0 r
.50096 .41153 .50431 .40698 .51025 .41087 .50697 .40631 Mtetra
.821 .738 .773 r
.50697 .40631 .51025 .41087 .51624 .41312 .51299 .39933 Mtetra
.643 .505 .68 r
.51299 .39933 .51624 .41312 .52225 .4094 .519 .39571 Mtetra
.455 .384 .688 r
.519 .39571 .52225 .4094 .52827 .40381 .52501 .39906 Mtetra
.79 .361 0 r
.52501 .39906 .52827 .40381 .53427 .39045 .53108 .41148 Mtetra
0 0 .15 r
.53108 .41148 .53427 .39045 .54035 .39925 .53707 .38655 Mtetra
.056 .126 .621 r
.53707 .38655 .54035 .39925 .54638 .39418 .54319 .39726 Mtetra
.126 0 0 r
.54319 .39726 .54638 .39418 .55246 .39363 .54928 .39525 Mtetra
.955 .951 .683 r
.54928 .39525 .55246 .39363 .55856 .39365 .55529 .38411 Mtetra
0 0 .442 r
.55529 .38411 .55856 .39365 .56453 .38114 .56157 .39798 Mtetra
0 0 .1 r
.56157 .39798 .56453 .38114 .57084 .39425 .56744 .37636 Mtetra
.535 .409 .656 r
.56744 .37636 .57084 .39425 .57695 .3907 .57361 .37754 Mtetra
.734 .566 .665 r
.57361 .37754 .57695 .3907 .58304 .38607 .57962 .36841 Mtetra
.5 .387 .657 r
.57962 .36841 .58304 .38607 .58921 .38453 .58585 .37109 Mtetra
.276 .27 .671 r
.58585 .37109 .58921 .38453 .59532 .38006 .59221 .37875 Mtetra
.492 .848 .993 r
.59221 .37875 .59532 .38006 .60148 .37731 .59842 .37747 Mtetra
.975 .894 .678 r
.59842 .37747 .60148 .37731 .6075 .36868 .60435 .36437 Mtetra
0 .216 .735 r
.60435 .36437 .6075 .36868 .61372 .36779 .61074 .36967 Mtetra
.802 .977 .687 r
.61074 .36967 .61372 .36779 .62007 .37072 .61681 .36215 Mtetra
.795 .646 .696 r
.61681 .36215 .62007 .37072 .62608 .36178 .62281 .35255 Mtetra
.475 .459 .761 r
.62281 .35255 .62608 .36178 .63212 .35389 .62917 .35444 Mtetra
.646 .967 .843 r
.62917 .35444 .63212 .35389 .63843 .3541 .63534 .35033 Mtetra
.744 .771 .875 r
.63534 .35033 .63843 .3541 .64465 .35131 .64155 .34671 Mtetra
.66 .701 .877 r
.64155 .34671 .64465 .35131 .65088 .34827 .64782 .34465 Mtetra
.717 .773 .897 r
.64782 .34465 .65088 .34827 .65715 .34625 .65407 .34164 Mtetra
.694 .714 .864 r
.65407 .34164 .65715 .34625 .66338 .3428 .66033 .33888 Mtetra
.629 .725 .917 r
.66033 .33888 .66338 .3428 .66967 .34042 .66667 .33731 Mtetra
.741 .812 .907 r
.66667 .33731 .66967 .34042 .67598 .33827 .67293 .3339 Mtetra
.605 .691 .903 r
.67293 .3339 .67598 .33827 .68228 .33564 .67931 .33271 Mtetra
.693 .812 .939 r
.67931 .33271 .68228 .33564 .68865 .33406 .68564 .33012 Mtetra
.701 .753 .891 r
.68564 .33012 .68865 .33406 .69499 .33167 .69197 .32732 Mtetra
.659 .715 .89 r
.69197 .32732 .69499 .33167 .70135 .32932 .69835 .32526 Mtetra
.663 .734 .902 r
.69835 .32526 .70135 .32932 .70773 .32724 .70475 .32312 Mtetra
.671 .734 .897 r
.70475 .32312 .70773 .32724 .71414 .32532 .71115 .32085 Mtetra
.641 .704 .892 r
.71115 .32085 .71414 .32532 .72056 .32321 .71759 .31907 Mtetra
.663 .731 .9 r
.71759 .31907 .72056 .32321 .72695 .32058 .72403 .31694 Mtetra
.671 .763 .92 r
.72403 .31694 .72695 .32058 .73342 .31878 .73047 .31467 Mtetra
.67 .736 .899 r
.73047 .31467 .73342 .31878 .73986 .31648 .73693 .31239 Mtetra
.652 .73 .907 r
.73693 .31239 .73986 .31648 .74632 .3141 .74342 .31042 Mtetra
.659 .758 .923 r
.74342 .31042 .74632 .3141 .75281 .31202 .74992 .30833 Mtetra
.661 .758 .922 r
.74992 .30833 .75281 .31202 .75931 .30984 .75644 .30619 Mtetra
.671 .765 .921 r
.75644 .30619 .75931 .30984 .76582 .30773 .76295 .3039 Mtetra
.681 .759 .91 r
.76295 .3039 .76582 .30773 .77237 .30575 .76947 .30142 Mtetra
.649 .719 .899 r
.76947 .30142 .77237 .30575 .77891 .30356 .77604 .29947 Mtetra
.661 .737 .906 r
.77604 .29947 .77891 .30356 .78545 .30109 .78261 .29731 Mtetra
.672 .76 .917 r
.78261 .29731 .78545 .30109 .79204 .29918 .78919 .29498 Mtetra
.654 .729 .904 r
.78919 .29498 .79204 .29918 .79861 .29677 .7958 .29294 Mtetra
.669 .757 .916 r
.7958 .29294 .79861 .29677 .80524 .29483 .80241 .29065 Mtetra
.672 .738 .901 r
.80241 .29065 .80524 .29483 .81185 .29251 .80903 .2883 Mtetra
.652 .729 .906 r
.80903 .2883 .81185 .29251 .81847 .29017 .81569 .28628 Mtetra
.674 .757 .913 r
.81569 .28628 .81847 .29017 .82512 .28794 .82233 .28388 Mtetra
.653 .739 .913 r
.82233 .28388 .82512 .28794 .8318 .28593 .82903 .28182 Mtetra
.672 .745 .905 r
.82903 .28182 .8318 .28593 .8385 .2839 .8357 .27945 Mtetra
.615 .701 .906 r
.8357 .27945 .8385 .2839 .84519 .28157 .84249 .27802 Mtetra
.718 .796 .913 r
.84249 .27802 .84519 .28157 .85196 .27988 .84912 .27485 Mtetra
.607 .669 .883 r
.84912 .27485 .85196 .27988 .85864 .27719 .85596 .27358 Mtetra
.704 .79 .918 r
.85596 .27358 .85864 .27719 .86534 .27456 .86264 .27065 Mtetra
.661 .744 .912 r
.25853 .46743 .26214 .47073 .26755 .4693 .26398 .46564 Mtetra
.624 .713 .91 r
.26398 .46564 .26755 .4693 .27305 .46699 .2694 .46436 Mtetra
.693 .794 .928 r
.2694 .46436 .27305 .46699 .27845 .46605 .27491 .46211 Mtetra
.635 .702 .894 r
.27491 .46211 .27845 .46605 .284 .4634 .28037 .46069 Mtetra
.707 .792 .917 r
.28037 .46069 .284 .4634 .28945 .46214 .28592 .4582 Mtetra
.641 .704 .893 r
.28592 .4582 .28945 .46214 .29498 .45986 .2914 .4567 Mtetra
.676 .759 .913 r
.2914 .4567 .29498 .45986 .30051 .4579 .29694 .45467 Mtetra
.675 .755 .911 r
.29694 .45467 .30051 .4579 .30603 .45616 .30248 .45265 Mtetra
.659 .734 .905 r
.30248 .45265 .30603 .45616 .31156 .45439 .30803 .45085 Mtetra
.647 .73 .909 r
.30803 .45085 .31156 .45439 .31712 .45243 .31357 .44923 Mtetra
.684 .76 .909 r
.31357 .44923 .31712 .45243 .32267 .45081 .31916 .44706 Mtetra
.642 .717 .902 r
.31916 .44706 .32267 .45081 .32826 .44865 .32472 .44551 Mtetra
.682 .764 .913 r
.32472 .44551 .32826 .44865 .33383 .44708 .33033 .44336 Mtetra
.651 .722 .901 r
.33033 .44336 .33383 .44708 .33944 .44499 .33592 .44167 Mtetra
.657 .748 .917 r
.33592 .44167 .33944 .44499 .34505 .44309 .34153 .43989 Mtetra
.671 .759 .917 r
.34153 .43989 .34505 .44309 .35066 .44139 .34717 .4379 Mtetra
.666 .741 .906 r
.34717 .4379 .35066 .44139 .3563 .43948 .35281 .43597 Mtetra
.653 .736 .911 r
.35281 .43597 .3563 .43948 .36195 .4375 .35846 .43423 Mtetra
.657 .753 .921 r
.35846 .43423 .36195 .4375 .36761 .43546 .36412 .43243 Mtetra
.686 .775 .919 r
.36412 .43243 .36761 .43546 .37326 .43392 .36981 .43019 Mtetra
.645 .723 .905 r
.36981 .43019 .37326 .43392 .37895 .43193 .37549 .42857 Mtetra
.68 .754 .907 r
.37549 .42857 .37895 .43193 .38464 .43018 .3812 .42641 Mtetra
.636 .719 .907 r
.3812 .42641 .38464 .43018 .39036 .42792 .38689 .42491 Mtetra
.657 .771 .934 r
.38689 .42491 .39036 .42792 .39607 .42606 .39262 .42307 Mtetra
.659 .774 .934 r
.39262 .42307 .39607 .42606 .4018 .4242 .39835 .42121 Mtetra
.65 .772 .938 r
.39835 .42121 .4018 .4242 .40755 .42213 .4041 .41944 Mtetra
.658 .795 .948 r
.4041 .41944 .40755 .42213 .41328 .42079 .40986 .41754 Mtetra
.705 .77 .903 r
.40986 .41754 .41328 .42079 .41903 .41949 .41566 .41495 Mtetra
.631 .678 .876 r
.41566 .41495 .41903 .41949 .42484 .41652 .42143 .4135 Mtetra
.675 .778 .928 r
.42143 .4135 .42484 .41652 .43059 .41609 .42723 .41139 Mtetra
.674 .687 .855 r
.42723 .41139 .43059 .41609 .43642 .41311 .43305 .40914 Mtetra
.529 .669 .926 r
.43305 .40914 .43642 .41311 .44223 .41145 .43883 .40892 Mtetra
.665 .81 .953 r
.43883 .40892 .44223 .41145 .44806 .40974 .44467 .40687 Mtetra
.69 .794 .929 r
.44467 .40687 .44806 .40974 .4539 .40779 .45054 .40451 Mtetra
.623 .749 .937 r
.45054 .40451 .4539 .40779 .45973 .40733 .45639 .40308 Mtetra
.687 .715 .87 r
.45639 .40308 .45973 .40733 .46552 .40971 .46228 .40064 Mtetra
.338 .373 .751 r
.46228 .40064 .46552 .40971 .47139 .4088 .46806 .40456 Mtetra
.569 .672 .908 r
.46806 .40456 .47139 .4088 .47739 .40044 .47395 .40394 Mtetra
0 0 0 r
.47395 .40394 .47739 .40044 .48313 .41156 .47994 .39794 Mtetra
.08 .129 .613 r
.47994 .39794 .48313 .41156 .4891 .40775 .48572 .40856 Mtetra
.965 .916 .709 r
.48572 .40856 .4891 .40775 .49508 .40238 .49179 .39705 Mtetra
.776 .361 0 r
.49179 .39705 .49508 .40238 .50096 .41153 .49763 .40949 Mtetra
.888 .848 .798 r
.49763 .40949 .50096 .41153 .50697 .40631 .50368 .4018 Mtetra
.9 .741 .675 r
.50368 .4018 .50697 .40631 .51299 .39933 .50974 .38706 Mtetra
0 .01 .559 r
.50974 .38706 .51299 .39933 .519 .39571 .5157 .39959 Mtetra
.797 .401 .303 r
.5157 .39959 .519 .39571 .52501 .39906 .52172 .41003 Mtetra
0 0 0 r
.52172 .41003 .52501 .39906 .53108 .41148 .52778 .39157 Mtetra
.278 .221 .612 r
.52778 .39157 .53108 .41148 .53707 .38655 .53388 .40244 Mtetra
0 0 .109 r
.53388 .40244 .53707 .38655 .54319 .39726 .53989 .38365 Mtetra
.617 .49 .686 r
.53989 .38365 .54319 .39726 .54928 .39525 .54597 .38131 Mtetra
.296 .277 .668 r
.54597 .38131 .54928 .39525 .55529 .38411 .55213 .38862 Mtetra
.638 .209 .211 r
.55213 .38862 .55529 .38411 .56157 .39798 .55832 .39248 Mtetra
0 0 .369 r
.55832 .39248 .56157 .39798 .56744 .37636 .56462 .40302 Mtetra
.318 .087 .398 r
.56462 .40302 .56744 .37636 .57361 .37754 .57065 .3904 Mtetra
0 0 .109 r
.57065 .3904 .57361 .37754 .57962 .36841 .57662 .3758 Mtetra
0 0 0 r
.57662 .3758 .57962 .36841 .58585 .37109 .58258 .36253 Mtetra
0 0 .504 r
.58258 .36253 .58585 .37109 .59221 .37875 .58902 .3746 Mtetra
.816 .763 .804 r
.58902 .3746 .59221 .37875 .59842 .37747 .59513 .36849 Mtetra
.729 .607 .722 r
.59513 .36849 .59842 .37747 .60435 .36437 .60125 .36258 Mtetra
.302 .717 .974 r
.60125 .36258 .60435 .36437 .61074 .36967 .60752 .36276 Mtetra
.836 .689 .7 r
.60752 .36276 .61074 .36967 .61681 .36215 .6135 .352 Mtetra
.493 .455 .743 r
.6135 .352 .61681 .36215 .62281 .35255 .61984 .35365 Mtetra
.707 .978 .776 r
.61984 .35365 .62281 .35255 .62917 .35444 .62598 .34833 Mtetra
.724 .668 .794 r
.62598 .34833 .62917 .35444 .63534 .35033 .63217 .34425 Mtetra
.687 .653 .811 r
.63217 .34425 .63534 .35033 .64155 .34671 .6384 .34128 Mtetra
.654 .662 .846 r
.6384 .34128 .64155 .34671 .64782 .34465 .64468 .33923 Mtetra
.652 .662 .847 r
.64468 .33923 .64782 .34465 .65407 .34164 .65098 .33722 Mtetra
.696 .725 .872 r
.65098 .33722 .65407 .34164 .66033 .33888 .65725 .33445 Mtetra
.639 .702 .892 r
.65725 .33445 .66033 .33888 .66667 .33731 .66359 .33274 Mtetra
.674 .71 .875 r
.66359 .33274 .66667 .33731 .67293 .3339 .66991 .33039 Mtetra
.698 .777 .912 r
.66991 .33039 .67293 .3339 .67931 .33271 .67623 .32771 Mtetra
.621 .668 .874 r
.67623 .32771 .67931 .33271 .68564 .33012 .68263 .32629 Mtetra
.659 .745 .914 r
.68263 .32629 .68564 .33012 .69197 .32732 .68901 .32423 Mtetra
.673 .797 .941 r
.68901 .32423 .69197 .32732 .69835 .32526 .69539 .32192 Mtetra
.667 .779 .933 r
.69539 .32192 .69835 .32526 .70475 .32312 .70179 .31971 Mtetra
.666 .775 .931 r
.70179 .31971 .70475 .32312 .71115 .32085 .7082 .31751 Mtetra
.685 .787 .927 r
.7082 .31751 .71115 .32085 .71759 .31907 .71461 .31501 Mtetra
.661 .735 .905 r
.71461 .31501 .71759 .31907 .72403 .31694 .72106 .31291 Mtetra
.665 .739 .905 r
.72106 .31291 .72403 .31694 .73047 .31467 .72752 .31072 Mtetra
.652 .739 .913 r
.72752 .31072 .73047 .31467 .73693 .31239 .73401 .30874 Mtetra
.679 .767 .918 r
.73401 .30874 .73693 .31239 .74342 .31042 .74049 .30632 Mtetra
.675 .74 .9 r
.74049 .30632 .74342 .31042 .74992 .30833 .74698 .30395 Mtetra
.658 .719 .894 r
.74698 .30395 .74992 .30833 .75644 .30619 .7535 .30185 Mtetra
.651 .718 .898 r
.7535 .30185 .75644 .30619 .76295 .3039 .76006 .29987 Mtetra
.658 .739 .91 r
.76006 .29987 .76295 .3039 .76947 .30142 .76661 .29777 Mtetra
.679 .77 .92 r
.76661 .29777 .76947 .30142 .77604 .29947 .77316 .29533 Mtetra
.659 .734 .905 r
.77316 .29533 .77604 .29947 .78261 .29731 .77974 .29319 Mtetra
.664 .738 .905 r
.77974 .29319 .78261 .29731 .78919 .29498 .78634 .29098 Mtetra
.658 .743 .913 r
.78634 .29098 .78919 .29498 .7958 .29294 .79296 .28886 Mtetra
.671 .745 .906 r
.79296 .28886 .7958 .29294 .80241 .29065 .79957 .28652 Mtetra
.658 .737 .908 r
.79957 .28652 .80241 .29065 .80903 .2883 .80622 .2844 Mtetra
.67 .755 .915 r
.80622 .2844 .80903 .2883 .81569 .28628 .81287 .28207 Mtetra
.674 .74 .9 r
.81287 .28207 .81569 .28628 .82233 .28388 .81952 .27965 Mtetra
.657 .732 .905 r
.81952 .27965 .82233 .28388 .82903 .28182 .82622 .27753 Mtetra
.625 .715 .911 r
.82622 .27753 .82903 .28182 .8357 .27945 .83298 .27592 Mtetra
.698 .791 .923 r
.83298 .27592 .8357 .27945 .84249 .27802 .83965 .2731 Mtetra
.61 .677 .888 r
.83965 .2731 .84249 .27802 .84912 .27485 .84648 .27178 Mtetra
.719 .83 .933 r
.84648 .27178 .84912 .27485 .85596 .27358 .85313 .2686 Mtetra
.653 .694 .876 r
.85313 .2686 .85596 .27358 .86264 .27065 .85991 .2665 Mtetra
.621 .72 .917 r
.25492 .4639 .25853 .46743 .26398 .46564 .26033 .46265 Mtetra
.678 .768 .919 r
.26033 .46265 .26398 .46564 .2694 .46436 .26582 .46061 Mtetra
.642 .714 .9 r
.26582 .46061 .2694 .46436 .27491 .46211 .27128 .45908 Mtetra
.677 .766 .919 r
.27128 .45908 .27491 .46211 .28037 .46069 .27679 .45705 Mtetra
.658 .726 .899 r
.27679 .45705 .28037 .46069 .28592 .4582 .28229 .45528 Mtetra
.696 .778 .914 r
.28229 .45528 .28592 .4582 .2914 .4567 .28785 .45294 Mtetra
.65 .718 .898 r
.28785 .45294 .2914 .4567 .29694 .45467 .29336 .45129 Mtetra
.666 .744 .909 r
.29336 .45129 .29694 .45467 .30248 .45265 .29891 .44939 Mtetra
.667 .753 .914 r
.29891 .44939 .30248 .45265 .30803 .45085 .30446 .44748 Mtetra
.67 .747 .908 r
.30446 .44748 .30803 .45085 .31357 .44923 .31004 .44551 Mtetra
.644 .72 .903 r
.31004 .44551 .31357 .44923 .31916 .44706 .31559 .44394 Mtetra
.687 .766 .912 r
.31559 .44394 .31916 .44706 .32472 .44551 .3212 .44172 Mtetra
.643 .716 .901 r
.3212 .44172 .32472 .44551 .33033 .44336 .32678 .44015 Mtetra
.67 .758 .917 r
.32678 .44015 .33033 .44336 .33592 .44167 .3324 .43817 Mtetra
.674 .742 .902 r
.3324 .43817 .33592 .44167 .34153 .43989 .33804 .43613 Mtetra
.658 .723 .897 r
.33804 .43613 .34153 .43989 .34717 .4379 .34367 .43431 Mtetra
.666 .736 .902 r
.34367 .43431 .34717 .4379 .35281 .43597 .34932 .43238 Mtetra
.669 .737 .901 r
.34932 .43238 .35281 .43597 .35846 .43423 .35498 .43039 Mtetra
.661 .721 .894 r
.35498 .43039 .35846 .43423 .36412 .43243 .36065 .42851 Mtetra
.643 .712 .898 r
.36065 .42851 .36412 .43243 .36981 .43019 .36632 .42692 Mtetra
.671 .758 .915 r
.36632 .42692 .36981 .43019 .37549 .42857 .37202 .42489 Mtetra
.649 .728 .907 r
.37202 .42489 .37549 .42857 .3812 .42641 .37772 .4232 Mtetra
.689 .767 .911 r
.37772 .4232 .3812 .42641 .38689 .42491 .38346 .42089 Mtetra
.659 .713 .888 r
.38346 .42089 .38689 .42491 .39262 .42307 .38919 .41903 Mtetra
.656 .712 .889 r
.38919 .41903 .39262 .42307 .39835 .42121 .39493 .4172 Mtetra
.673 .719 .884 r
.39493 .4172 .39835 .42121 .4041 .41944 .40069 .41509 Mtetra
.645 .693 .88 r
.40069 .41509 .4041 .41944 .40986 .41754 .40645 .41344 Mtetra
.641 .705 .893 r
.40645 .41344 .40986 .41754 .41566 .41495 .41222 .41184 Mtetra
.686 .775 .919 r
.41222 .41184 .41566 .41495 .42143 .4135 .41803 .40956 Mtetra
.602 .7 .912 r
.41803 .40956 .42143 .4135 .42723 .41139 .42381 .40849 Mtetra
.655 .783 .942 r
.42381 .40849 .42723 .41139 .43305 .40914 .42963 .40662 Mtetra
.695 .818 .941 r
.42963 .40662 .43305 .40914 .43883 .40892 .43548 .40419 Mtetra
.612 .664 .876 r
.43548 .40419 .43883 .40892 .44467 .40687 .4413 .40303 Mtetra
.64 .721 .906 r
.4413 .40303 .44467 .40687 .45054 .40451 .44715 .40142 Mtetra
.622 .762 .946 r
.44715 .40142 .45054 .40451 .45639 .40308 .45301 .39997 Mtetra
.544 .733 .963 r
.45301 .39997 .45639 .40308 .46228 .40064 .45887 .39932 Mtetra
.796 .911 .919 r
.45887 .39932 .46228 .40064 .46806 .40456 .46482 .39514 Mtetra
.358 .379 .746 r
.46482 .39514 .46806 .40456 .47395 .40394 .47063 .39891 Mtetra
.637 .664 .859 r
.47063 .39891 .47395 .40394 .47994 .39794 .47656 .39731 Mtetra
.14 .675 .855 r
.47656 .39731 .47994 .39794 .48572 .40856 .48248 .39727 Mtetra
.559 .476 .718 r
.48248 .39727 .48572 .40856 .49179 .39705 .48842 .39726 Mtetra
.468 0 0 r
.48842 .39726 .49179 .39705 .49763 .40949 .49436 .39964 Mtetra
.651 .55 .728 r
.49436 .39964 .49763 .40949 .50368 .4018 .50037 .39673 Mtetra
.647 .668 .856 r
.50037 .39673 .50368 .4018 .50974 .38706 .50639 .39492 Mtetra
.622 .253 .322 r
.50639 .39492 .50974 .38706 .5157 .39959 .51239 .3987 Mtetra
.253 0 0 r
.51239 .3987 .5157 .39959 .52172 .41003 .51843 .40067 Mtetra
0 0 .53 r
.51843 .40067 .52172 .41003 .52778 .39157 .52451 .41215 Mtetra
.505 .224 .421 r
.52451 .41215 .52778 .39157 .53388 .40244 .53062 .41083 Mtetra
.772 .801 .314 r
.53062 .41083 .53388 .40244 .53989 .38365 .53669 .39284 Mtetra
.243 0 .193 r
.53669 .39284 .53989 .38365 .54597 .38131 .54278 .38781 Mtetra
.823 .464 .378 r
.54278 .38781 .54597 .38131 .55213 .38862 .54903 .40419 Mtetra
.002 0 .208 r
.54903 .40419 .55213 .38862 .55832 .39248 .55509 .39 Mtetra
.937 .803 .686 r
.55509 .39 .55832 .39248 .56462 .40302 .56111 .37604 Mtetra
.591 .419 .617 r
.56111 .37604 .56462 .40302 .57065 .3904 .56724 .37326 Mtetra
.208 .191 .619 r
.56724 .37326 .57065 .3904 .57662 .3758 .57361 .38453 Mtetra
.738 .768 .267 r
.57361 .38453 .57662 .3758 .58258 .36253 .57952 .36577 Mtetra
.755 .321 .22 r
.57952 .36577 .58258 .36253 .58902 .3746 .58588 .37341 Mtetra
.953 .864 .715 r
.58588 .37341 .58902 .3746 .59513 .36849 .59189 .36161 Mtetra
.56 .566 .816 r
.59189 .36161 .59513 .36849 .60125 .36258 .59814 .36138 Mtetra
.939 .886 .753 r
.59814 .36138 .60125 .36258 .60752 .36276 .60417 .35151 Mtetra
.551 .475 .722 r
.60417 .35151 .60752 .36276 .6135 .352 .61046 .35174 Mtetra
.811 .985 .886 r
.61046 .35174 .6135 .352 .61984 .35365 .61661 .34661 Mtetra
.73 .646 .765 r
.61661 .34661 .61984 .35365 .62598 .34833 .62278 .34183 Mtetra
.606 .602 .821 r
.62278 .34183 .62598 .34833 .63217 .34425 .62907 .34067 Mtetra
.613 .74 .936 r
.62907 .34067 .63217 .34425 .6384 .34128 .63537 .33927 Mtetra
.68 .872 .971 r
.63537 .33927 .6384 .34128 .64468 .33923 .64164 .33669 Mtetra
.732 .847 .935 r
.64164 .33669 .64468 .33923 .65098 .33722 .6479 .33348 Mtetra
.652 .746 .919 r
.6479 .33348 .65098 .33722 .65725 .33445 .65422 .33154 Mtetra
.701 .816 .936 r
.65422 .33154 .65725 .33445 .66359 .33274 .66053 .32882 Mtetra
.675 .745 .903 r
.66053 .32882 .66359 .33274 .66991 .33039 .66686 .3265 Mtetra
.67 .746 .907 r
.66686 .3265 .66991 .33039 .67623 .32771 .67321 .32427 Mtetra
.673 .774 .926 r
.67321 .32427 .67623 .32771 .68263 .32629 .67958 .32198 Mtetra
.688 .731 .883 r
.67958 .32198 .68263 .32629 .68901 .32423 .68594 .31938 Mtetra
.648 .689 .874 r
.68594 .31938 .68901 .32423 .69539 .32192 .69235 .31747 Mtetra
.665 .715 .886 r
.69235 .31747 .69539 .32192 .70179 .31971 .69876 .31527 Mtetra
.671 .719 .885 r
.69876 .31527 .70179 .31971 .7082 .31751 .70518 .31295 Mtetra
.639 .7 .89 r
.70518 .31295 .7082 .31751 .71461 .31501 .71164 .3112 Mtetra
.667 .752 .914 r
.71164 .3112 .71461 .31501 .72106 .31291 .7181 .30898 Mtetra
.67 .747 .909 r
.7181 .30898 .72106 .31291 .72752 .31072 .72456 .30671 Mtetra
.678 .746 .903 r
.72456 .30671 .72752 .31072 .73401 .30874 .73103 .30429 Mtetra
.654 .714 .892 r
.73103 .30429 .73401 .30874 .74049 .30632 .73754 .30227 Mtetra
.656 .737 .909 r
.73754 .30227 .74049 .30632 .74698 .30395 .74407 .3002 Mtetra
.659 .756 .922 r
.74407 .3002 .74698 .30395 .7535 .30185 .7506 .29808 Mtetra
.672 .761 .917 r
.7506 .29808 .7535 .30185 .76006 .29987 .75714 .29575 Mtetra
.672 .741 .902 r
.75714 .29575 .76006 .29987 .76661 .29777 .76369 .2934 Mtetra
.647 .717 .899 r
.76369 .2934 .76661 .29777 .77316 .29533 .77029 .29147 Mtetra
.673 .757 .914 r
.77029 .29147 .77316 .29533 .77974 .29319 .77687 .2891 Mtetra
.659 .739 .909 r
.77687 .2891 .77974 .29319 .78634 .29098 .78348 .28697 Mtetra
.671 .748 .909 r
.78348 .28697 .78634 .29098 .79296 .28886 .79009 .28463 Mtetra
.652 .729 .905 r
.79009 .28463 .79296 .28886 .79957 .28652 .79674 .2826 Mtetra
.677 .758 .912 r
.79674 .2826 .79957 .28652 .80622 .2844 .80337 .28014 Mtetra
.668 .735 .9 r
.80337 .28014 .80622 .2844 .81287 .28207 .81003 .27783 Mtetra
.65 .73 .907 r
.81003 .27783 .81287 .28207 .81952 .27965 .81674 .27581 Mtetra
.655 .755 .923 r
.81674 .27581 .81952 .27965 .82622 .27753 .82345 .2737 Mtetra
.674 .764 .918 r
.82345 .2737 .82622 .27753 .83298 .27592 .83014 .27127 Mtetra
.622 .696 .897 r
.83014 .27127 .83298 .27592 .83965 .2731 .83694 .26972 Mtetra
.681 .796 .936 r
.83694 .26972 .83965 .2731 .84648 .27178 .84366 .26716 Mtetra
.633 .704 .897 r
.84366 .26716 .84648 .27178 .85313 .2686 .85048 .26542 Mtetra
.73 .828 .926 r
.85048 .26542 .85313 .2686 .85991 .2665 .85714 .26204 Mtetra
.631 .746 .93 r
.25127 .46073 .25492 .4639 .26033 .46265 .2567 .45931 Mtetra
.668 .746 .908 r
.2567 .45931 .26033 .46265 .26582 .46061 .26219 .45739 Mtetra
.659 .751 .918 r
.26219 .45739 .26582 .46061 .27128 .45908 .26767 .45561 Mtetra
.682 .742 .897 r
.26767 .45561 .27128 .45908 .27679 .45705 .2732 .45347 Mtetra
.67 .733 .897 r
.2732 .45347 .27679 .45705 .28229 .45528 .27872 .45151 Mtetra
.639 .715 .902 r
.27872 .45151 .28229 .45528 .28785 .45294 .28422 .45001 Mtetra
.686 .777 .92 r
.28422 .45001 .28785 .45294 .29336 .45129 .28978 .44782 Mtetra
.667 .74 .905 r
.28978 .44782 .29336 .45129 .29891 .44939 .29533 .4459 Mtetra
.665 .738 .905 r
.29533 .4459 .29891 .44939 .30446 .44748 .30089 .44401 Mtetra
.652 .737 .912 r
.30089 .44401 .30446 .44748 .31004 .44551 .30645 .4423 Mtetra
.681 .76 .911 r
.30645 .4423 .31004 .44551 .31559 .44394 .31205 .44017 Mtetra
.643 .718 .902 r
.31205 .44017 .31559 .44394 .3212 .44172 .31763 .43858 Mtetra
.682 .766 .915 r
.31763 .43858 .3212 .44172 .32678 .44015 .32326 .43643 Mtetra
.652 .724 .902 r
.32326 .43643 .32678 .44015 .3324 .43817 .32886 .43472 Mtetra
.658 .742 .911 r
.32886 .43472 .3324 .43817 .33804 .43613 .33449 .4329 Mtetra
.671 .759 .916 r
.33449 .4329 .33804 .43613 .34367 .43431 .34014 .43088 Mtetra
.662 .745 .912 r
.34014 .43088 .34367 .43431 .34932 .43238 .34579 .42901 Mtetra
.65 .746 .92 r
.34579 .42901 .34932 .43238 .35498 .43039 .35145 .4273 Mtetra
.663 .767 .927 r
.35145 .4273 .35498 .43039 .36065 .42851 .35713 .4254 Mtetra
.689 .772 .915 r
.35713 .4254 .36065 .42851 .36632 .42692 .36284 .4231 Mtetra
.647 .72 .901 r
.36284 .4231 .36632 .42692 .37202 .42489 .36853 .42143 Mtetra
.675 .749 .906 r
.36853 .42143 .37202 .42489 .37772 .4232 .37426 .41933 Mtetra
.645 .717 .901 r
.37426 .41933 .37772 .4232 .38346 .42089 .37997 .41769 Mtetra
.664 .762 .923 r
.37997 .41769 .38346 .42089 .38919 .41903 .38571 .41575 Mtetra
.662 .758 .921 r
.38571 .41575 .38919 .41903 .39493 .4172 .39147 .41384 Mtetra
.654 .751 .921 r
.39147 .41384 .39493 .4172 .40069 .41509 .39723 .41203 Mtetra
.664 .773 .931 r
.39723 .41203 .40069 .41509 .40645 .41344 .40301 .41008 Mtetra
.687 .761 .908 r
.40301 .41008 .40645 .41344 .41222 .41184 .40881 .40777 Mtetra
.599 .692 .908 r
.40881 .40777 .41222 .41184 .41803 .40956 .41458 .40675 Mtetra
.719 .803 .917 r
.41458 .40675 .41803 .40956 .42381 .40849 .42042 .40394 Mtetra
.645 .685 .873 r
.42042 .40394 .42381 .40849 .42963 .40662 .42624 .40224 Mtetra
.624 .686 .888 r
.42624 .40224 .42963 .40662 .43548 .40419 .43207 .40088 Mtetra
.619 .747 .937 r
.43207 .40088 .43548 .40419 .4413 .40303 .43791 .39949 Mtetra
.688 .754 .901 r
.43791 .39949 .4413 .40303 .44715 .40142 .44378 .39712 Mtetra
.685 .713 .87 r
.44378 .39712 .44715 .40142 .45301 .39997 .44967 .39471 Mtetra
.598 .636 .86 r
.44967 .39471 .45301 .39997 .45887 .39932 .45554 .39377 Mtetra
.424 .537 .868 r
.45554 .39377 .45887 .39932 .46482 .39514 .46138 .39512 Mtetra
.742 .979 .918 r
.46138 .39512 .46482 .39514 .47063 .39891 .46735 .39113 Mtetra
.388 .438 .791 r
.46735 .39113 .47063 .39891 .47656 .39731 .47321 .39378 Mtetra
.746 .771 .873 r
.47321 .39378 .47656 .39731 .48248 .39727 .47919 .39023 Mtetra
.083 .269 .755 r
.47919 .39023 .48248 .39727 .48842 .39726 .48506 .39562 Mtetra
.87 .881 .841 r
.48506 .39562 .48842 .39726 .49436 .39964 .4911 .38927 Mtetra
0 0 .543 r
.4911 .38927 .49436 .39964 .50037 .39673 .49698 .40086 Mtetra
0 0 0 r
.49698 .40086 .50037 .39673 .50639 .39492 .50304 .39592 Mtetra
.759 .278 .099 r
.50304 .39592 .50639 .39492 .51239 .3987 .50904 .40262 Mtetra
.836 .934 .558 r
.50904 .40262 .51239 .3987 .51843 .40067 .51514 .3919 Mtetra
.106 .233 .714 r
.51514 .3919 .51843 .40067 .52451 .41215 .5212 .39857 Mtetra
.703 .545 .671 r
.5212 .39857 .52451 .41215 .53062 .41083 .5273 .39142 Mtetra
0 .016 .528 r
.5273 .39142 .53062 .41083 .53669 .39284 .53346 .40923 Mtetra
.294 .026 .325 r
.53346 .40923 .53669 .39284 .54278 .38781 .53959 .40124 Mtetra
.253 0 .277 r
.53959 .40124 .54278 .38781 .54903 .40419 .54571 .39387 Mtetra
0 .066 .609 r
.54571 .39387 .54903 .40419 .55509 .39 .55198 .40436 Mtetra
.139 0 .247 r
.55198 .40436 .55509 .39 .56111 .37604 .55809 .39392 Mtetra
0 0 .085 r
.55809 .39392 .56111 .37604 .56724 .37326 .56403 .3702 Mtetra
.925 .536 .182 r
.56403 .3702 .56724 .37326 .57361 .38453 .57053 .39144 Mtetra
.989 .827 .446 r
.57053 .39144 .57361 .38453 .57952 .36577 .57626 .35891 Mtetra
0 0 .397 r
.57626 .35891 .57952 .36577 .58588 .37341 .5827 .37096 Mtetra
.948 .801 .665 r
.5827 .37096 .58588 .37341 .59189 .36161 .58866 .35536 Mtetra
.659 .635 .815 r
.58866 .35536 .59189 .36161 .59814 .36138 .59486 .35307 Mtetra
.681 .595 .753 r
.59486 .35307 .59814 .36138 .60417 .35151 .60105 .34951 Mtetra
.81 .888 .9 r
.60105 .34951 .60417 .35151 .61046 .35174 .60722 .34487 Mtetra
.687 .631 .787 r
.60722 .34487 .61046 .35174 .61661 .34661 .61344 .34163 Mtetra
.623 .669 .873 r
.61344 .34163 .61661 .34661 .62278 .34183 .61971 .34019 Mtetra
.759 .912 .942 r
.61971 .34019 .62278 .34183 .62907 .34067 .62594 .33646 Mtetra
.716 .741 .872 r
.62594 .33646 .62907 .34067 .63537 .33927 .63218 .33332 Mtetra
.645 .64 .831 r
.63218 .33332 .63537 .33927 .64164 .33669 .63849 .33138 Mtetra
.679 .68 .843 r
.63849 .33138 .64164 .33669 .6479 .33348 .64478 .32878 Mtetra
.685 .709 .866 r
.64478 .32878 .6479 .33348 .65422 .33154 .65108 .32619 Mtetra
.626 .656 .859 r
.65108 .32619 .65422 .33154 .66053 .32882 .65744 .32467 Mtetra
.636 .718 .907 r
.65744 .32467 .66053 .32882 .66686 .3265 .66382 .32297 Mtetra
.709 .781 .908 r
.66382 .32297 .66686 .3265 .67321 .32427 .67015 .32008 Mtetra
.655 .725 .9 r
.67015 .32008 .67321 .32427 .67958 .32198 .67653 .31806 Mtetra
.657 .741 .912 r
.67653 .31806 .67958 .32198 .68594 .31938 .68293 .31603 Mtetra
.672 .781 .932 r
.68293 .31603 .68594 .31938 .69235 .31747 .68934 .31373 Mtetra
.666 .756 .917 r
.68934 .31373 .69235 .31747 .69876 .31527 .69576 .31153 Mtetra
.662 .755 .919 r
.69576 .31153 .69876 .31527 .70518 .31295 .7022 .30938 Mtetra
.677 .771 .922 r
.7022 .30938 .70518 .31295 .71164 .3112 .70864 .307 Mtetra
.663 .731 .9 r
.70864 .307 .71164 .3112 .7181 .30898 .7151 .30482 Mtetra
.664 .733 .901 r
.7151 .30482 .7181 .30898 .72456 .30671 .72159 .30263 Mtetra
.647 .732 .91 r
.72159 .30263 .72456 .30671 .73103 .30429 .7281 .30071 Mtetra
.675 .773 .924 r
.7281 .30071 .73103 .30429 .73754 .30227 .7346 .29834 Mtetra
.678 .753 .908 r
.7346 .29834 .73754 .30227 .74407 .3002 .74111 .29591 Mtetra
.662 .727 .898 r
.74111 .29591 .74407 .3002 .7506 .29808 .74765 .29372 Mtetra
.65 .719 .899 r
.74765 .29372 .7506 .29808 .75714 .29575 .75422 .29173 Mtetra
.655 .741 .913 r
.75422 .29173 .75714 .29575 .76369 .2934 .7608 .28966 Mtetra
.68 .768 .917 r
.7608 .28966 .76369 .2934 .77029 .29147 .76737 .28719 Mtetra
.657 .728 .901 r
.76737 .28719 .77029 .29147 .77687 .2891 .77398 .28508 Mtetra
.666 .746 .91 r
.77398 .28508 .77687 .2891 .78348 .28697 .78059 .28281 Mtetra
.657 .736 .908 r
.78059 .28281 .78348 .28697 .79009 .28463 .78723 .28069 Mtetra
.676 .756 .911 r
.78723 .28069 .79009 .28463 .79674 .2826 .79386 .27825 Mtetra
.656 .725 .9 r
.79386 .27825 .79674 .2826 .80337 .28014 .80054 .27613 Mtetra
.663 .748 .914 r
.80054 .27613 .80337 .28014 .81003 .27783 .80722 .2739 Mtetra
.663 .753 .917 r
.80722 .2739 .81003 .27783 .81674 .27581 .81391 .27165 Mtetra
.669 .743 .906 r
.81391 .27165 .81674 .27581 .82345 .2737 .82061 .26931 Mtetra
.639 .718 .905 r
.82061 .26931 .82345 .2737 .83014 .27127 .82738 .26747 Mtetra
.66 .762 .925 r
.82738 .26747 .83014 .27127 .83694 .26972 .83412 .26525 Mtetra
.655 .722 .898 r
.83412 .26525 .83694 .26972 .84366 .26716 .84089 .26312 Mtetra
.64 .74 .921 r
.84089 .26312 .84366 .26716 .85048 .26542 .84771 .26121 Mtetra
.699 .756 .896 r
.84771 .26121 .85048 .26542 .85714 .26204 .85443 .25829 Mtetra
.625 .731 .923 r
.24762 .45733 .25127 .46073 .2567 .45931 .25305 .45601 Mtetra
.695 .755 .897 r
.25305 .45601 .2567 .45931 .26219 .45739 .25858 .45366 Mtetra
.663 .723 .894 r
.25858 .45366 .26219 .45739 .26767 .45561 .26407 .45181 Mtetra
.661 .719 .892 r
.26407 .45181 .26767 .45561 .2732 .45347 .26958 .44998 Mtetra
.639 .731 .915 r
.26958 .44998 .2732 .45347 .27872 .45151 .27508 .44847 Mtetra
.698 .772 .909 r
.27508 .44847 .27872 .45151 .28422 .45001 .28065 .44609 Mtetra
.645 .709 .894 r
.28065 .44609 .28422 .45001 .28978 .44782 .28617 .44449 Mtetra
.666 .749 .912 r
.28617 .44449 .28978 .44782 .29533 .4459 .29173 .44257 Mtetra
.67 .751 .911 r
.29173 .44257 .29533 .4459 .30089 .44401 .2973 .44061 Mtetra
.67 .747 .908 r
.2973 .44061 .30089 .44401 .30645 .4423 .30289 .43863 Mtetra
.65 .726 .904 r
.30289 .43863 .30645 .4423 .31205 .44017 .30847 .43694 Mtetra
.679 .76 .912 r
.30847 .43694 .31205 .44017 .31763 .43858 .31408 .43483 Mtetra
.644 .72 .903 r
.31408 .43483 .31763 .43858 .32326 .43643 .31968 .43322 Mtetra
.681 .762 .913 r
.31968 .43322 .32326 .43643 .32886 .43472 .32532 .43107 Mtetra
.66 .732 .902 r
.32532 .43107 .32886 .43472 .33449 .4329 .33096 .42921 Mtetra
.658 .73 .902 r
.33096 .42921 .33449 .4329 .34014 .43088 .3366 .42738 Mtetra
.665 .742 .908 r
.3366 .42738 .34014 .43088 .34579 .42901 .34227 .42546 Mtetra
.658 .738 .909 r
.34227 .42546 .34579 .42901 .35145 .4273 .34794 .42362 Mtetra
.671 .735 .898 r
.34794 .42362 .35145 .4273 .35713 .4254 .35363 .42158 Mtetra
.653 .722 .9 r
.35363 .42158 .35713 .4254 .36284 .4231 .35932 .41982 Mtetra
.654 .755 .924 r
.35932 .41982 .36284 .4231 .36853 .42143 .36503 .41803 Mtetra
.668 .751 .913 r
.36503 .41803 .36853 .42143 .37426 .41933 .37075 .41603 Mtetra
.687 .763 .909 r
.37075 .41603 .37426 .41933 .37997 .41769 .37651 .41374 Mtetra
.645 .714 .898 r
.37651 .41374 .37997 .41769 .38571 .41575 .38224 .41208 Mtetra
.656 .734 .906 r
.38224 .41208 .38571 .41575 .39147 .41384 .388 .41025 Mtetra
.669 .743 .905 r
.388 .41025 .39147 .41384 .39723 .41203 .39378 .40821 Mtetra
.673 .731 .893 r
.39378 .40821 .39723 .41203 .40301 .41008 .39957 .4061 Mtetra
.61 .702 .909 r
.39957 .4061 .40301 .41008 .40881 .40777 .40534 .40491 Mtetra
.686 .793 .931 r
.40534 .40491 .40881 .40777 .41458 .40675 .41116 .40261 Mtetra
.644 .706 .892 r
.41116 .40261 .41458 .40675 .42042 .40394 .41697 .40095 Mtetra
.671 .782 .933 r
.41697 .40095 .42042 .40394 .42624 .40224 .42281 .39887 Mtetra
.676 .76 .914 r
.42281 .39887 .42624 .40224 .43207 .40088 .42867 .39671 Mtetra
.673 .715 .88 r
.42867 .39671 .43207 .40088 .43791 .39949 .43454 .39453 Mtetra
.634 .665 .862 r
.43454 .39453 .43791 .39949 .44378 .39712 .4404 .39299 Mtetra
.566 .678 .915 r
.4404 .39299 .44378 .39712 .44967 .39471 .44625 .39236 Mtetra
.516 .778 .992 r
.44625 .39236 .44967 .39471 .45554 .39377 .45213 .39161 Mtetra
.799 .857 .892 r
.45213 .39161 .45554 .39377 .46138 .39512 .45809 .38726 Mtetra
.394 .439 .789 r
.45809 .38726 .46138 .39512 .46735 .39113 .46393 .38983 Mtetra
.707 .91 .966 r
.46393 .38983 .46735 .39113 .47321 .39378 .4699 .38691 Mtetra
.369 .456 .819 r
.4699 .38691 .47321 .39378 .47919 .39023 .47579 .3894 Mtetra
.774 .946 .934 r
.47579 .3894 .47919 .39023 .48506 .39562 .48179 .38542 Mtetra
.295 .326 .724 r
.48179 .38542 .48506 .39562 .4911 .38927 .4877 .39048 Mtetra
.723 .232 .075 r
.4877 .39048 .4911 .38927 .49698 .40086 .49364 .39609 Mtetra
.897 .736 .674 r
.49364 .39609 .49698 .40086 .50304 .39592 .49979 .3812 Mtetra
.791 .517 0 r
.49979 .3812 .50304 .39592 .50904 .40262 .50563 .41188 Mtetra
.71 .766 .269 r
.50563 .41188 .50904 .40262 .51514 .3919 .5118 .39423 Mtetra
.921 .583 .383 r
.5118 .39423 .51514 .3919 .5212 .39857 .51781 .42773 Mtetra
.208 .001 .363 r
.51781 .42773 .5212 .39857 .5273 .39142 .52399 .40954 Mtetra
.592 .291 .427 r
.52399 .40954 .5273 .39142 .53346 .40923 .53016 .41343 Mtetra
.812 .422 .314 r
.53016 .41343 .53346 .40923 .53959 .40124 .53639 .42561 Mtetra
0 0 .073 r
.53639 .42561 .53959 .40124 .54571 .39387 .54243 .39123 Mtetra
.292 .651 .969 r
.54243 .39123 .54571 .39387 .55198 .40436 .54863 .39206 Mtetra
.275 .283 .688 r
.54863 .39206 .55198 .40436 .55809 .39392 .5549 .39881 Mtetra
.971 .882 .504 r
.5549 .39881 .55809 .39392 .56403 .3702 .56092 .37849 Mtetra
.31 0 .193 r
.56092 .37849 .56403 .3702 .57053 .39144 .56711 .37503 Mtetra
.56 .435 .667 r
.56711 .37503 .57053 .39144 .57626 .35891 .57335 .37489 Mtetra
0 0 .037 r
.57335 .37489 .57626 .35891 .5827 .37096 .57922 .35185 Mtetra
.456 .35 .645 r
.57922 .35185 .5827 .37096 .58866 .35536 .58555 .35644 Mtetra
.911 .982 .74 r
.58555 .35644 .58866 .35536 .59486 .35307 .59165 .34779 Mtetra
.754 .707 .808 r
.59165 .34779 .59486 .35307 .60105 .34951 .59782 .34319 Mtetra
.6 .605 .829 r
.59782 .34319 .60105 .34951 .60722 .34487 .60409 .34215 Mtetra
.784 .841 .895 r
.60409 .34215 .60722 .34487 .61344 .34163 .61029 .33792 Mtetra
.746 .776 .878 r
.61029 .33792 .61344 .34163 .61971 .34019 .61651 .33427 Mtetra
.595 .618 .844 r
.61651 .33427 .61971 .34019 .62594 .33646 .62282 .33331 Mtetra
.702 .8 .926 r
.62282 .33331 .62594 .33646 .63218 .33332 .6291 .33058 Mtetra
.706 .828 .941 r
.6291 .33058 .63218 .33332 .63849 .33138 .63538 .32778 Mtetra
.663 .76 .922 r
.63538 .32778 .63849 .33138 .64478 .32878 .6417 .32565 Mtetra
.67 .793 .94 r
.6417 .32565 .64478 .32878 .65108 .32619 .64803 .32338 Mtetra
.679 .818 .95 r
.64803 .32338 .65108 .32619 .65744 .32467 .65437 .32095 Mtetra
.701 .767 .903 r
.65437 .32095 .65744 .32467 .66382 .32297 .6607 .31817 Mtetra
.616 .677 .886 r
.6607 .31817 .66382 .32297 .67015 .32008 .66711 .31681 Mtetra
.713 .799 .918 r
.66711 .31681 .67015 .32008 .67653 .31806 .67347 .31386 Mtetra
.662 .728 .898 r
.67347 .31386 .67653 .31806 .68293 .31603 .67987 .31172 Mtetra
.654 .72 .897 r
.67987 .31172 .68293 .31603 .68934 .31373 .6863 .30972 Mtetra
.669 .742 .905 r
.6863 .30972 .68934 .31373 .69576 .31153 .69273 .30746 Mtetra
.679 .744 .899 r
.69273 .30746 .69576 .31153 .7022 .30938 .69916 .30502 Mtetra
.65 .717 .897 r
.69916 .30502 .7022 .30938 .70864 .307 .70563 .30306 Mtetra
.648 .74 .916 r
.70563 .30306 .70864 .307 .7151 .30482 .71213 .30113 Mtetra
.688 .769 .913 r
.71213 .30113 .7151 .30482 .72159 .30263 .7186 .29854 Mtetra
.649 .732 .91 r
.7186 .29854 .72159 .30263 .7281 .30071 .72512 .29658 Mtetra
.663 .736 .904 r
.72512 .29658 .7281 .30071 .7346 .29834 .73164 .29438 Mtetra
.67 .75 .91 r
.73164 .29438 .7346 .29834 .74111 .29591 .73817 .29208 Mtetra
.657 .753 .92 r
.73817 .29208 .74111 .29591 .74765 .29372 .74473 .28997 Mtetra
.661 .759 .923 r
.74473 .28997 .74765 .29372 .75422 .29173 .7513 .28778 Mtetra
.681 .756 .908 r
.7513 .28778 .75422 .29173 .7608 .28966 .75786 .28527 Mtetra
.654 .721 .898 r
.75786 .28527 .7608 .28966 .76737 .28719 .76447 .2832 Mtetra
.656 .745 .915 r
.76447 .2832 .76737 .28719 .77398 .28508 .77109 .28109 Mtetra
.679 .755 .908 r
.77109 .28109 .77398 .28508 .78059 .28281 .77769 .27859 Mtetra
.657 .733 .906 r
.77769 .27859 .78059 .28281 .78723 .28069 .78435 .27646 Mtetra
.658 .734 .905 r
.78435 .27646 .78723 .28069 .79386 .27825 .79101 .27431 Mtetra
.673 .756 .913 r
.79101 .27431 .79386 .27825 .80054 .27613 .79767 .2719 Mtetra
.67 .739 .902 r
.79767 .2719 .80054 .27613 .80722 .2739 .80435 .26953 Mtetra
.645 .722 .904 r
.80435 .26953 .80722 .2739 .81391 .27165 .81108 .26759 Mtetra
.645 .739 .918 r
.81108 .26759 .81391 .27165 .82061 .26931 .81783 .26563 Mtetra
.697 .784 .918 r
.81783 .26563 .82061 .26931 .82738 .26747 .82452 .2628 Mtetra
.63 .701 .896 r
.82452 .2628 .82738 .26747 .83412 .26525 .83132 .2611 Mtetra
.667 .745 .909 r
.83132 .2611 .83412 .26525 .84089 .26312 .83809 .25876 Mtetra
.637 .721 .909 r
.83809 .25876 .84089 .26312 .84771 .26121 .84492 .25691 Mtetra
.697 .75 .893 r
.84492 .25691 .84771 .26121 .85443 .25829 .85165 .25401 Mtetra
.651 .735 .911 r
.24396 .45386 .24762 .45733 .25305 .45601 .24943 .4522 Mtetra
.68 .723 .883 r
.24943 .4522 .25305 .45601 .25858 .45366 .25494 .45005 Mtetra
.644 .726 .908 r
.25494 .45005 .25858 .45366 .26407 .45181 .26042 .44848 Mtetra
.664 .747 .912 r
.26042 .44848 .26407 .45181 .26958 .44998 .26594 .44661 Mtetra
.678 .749 .904 r
.26594 .44661 .26958 .44998 .27508 .44847 .27149 .44452 Mtetra
.644 .708 .893 r
.27149 .44452 .27508 .44847 .28065 .44609 .277 .44292 Mtetra
.653 .756 .925 r
.277 .44292 .28065 .44609 .28617 .44449 .28254 .44118 Mtetra
.682 .755 .907 r
.28254 .44118 .28617 .44449 .29173 .44257 .28813 .43903 Mtetra
.665 .737 .904 r
.28813 .43903 .29173 .44257 .2973 .44061 .2937 .43712 Mtetra
.661 .739 .908 r
.2937 .43712 .2973 .44061 .30289 .43863 .29929 .43527 Mtetra
.662 .748 .914 r
.29929 .43527 .30289 .43863 .30847 .43694 .30488 .43339 Mtetra
.669 .74 .903 r
.30488 .43339 .30847 .43694 .31408 .43483 .3105 .43141 Mtetra
.653 .743 .915 r
.3105 .43141 .31408 .43483 .31968 .43322 .31611 .42965 Mtetra
.66 .737 .907 r
.31611 .42965 .31968 .43322 .32532 .43107 .32174 .42781 Mtetra
.682 .761 .911 r
.32174 .42781 .32532 .43107 .33096 .42921 .32741 .42563 Mtetra
.662 .737 .905 r
.32741 .42563 .33096 .42921 .3366 .42738 .33306 .42373 Mtetra
.666 .735 .901 r
.33306 .42373 .3366 .42738 .34227 .42546 .33873 .42177 Mtetra
.667 .734 .899 r
.33873 .42177 .34227 .42546 .34794 .42362 .34442 .41978 Mtetra
.657 .722 .897 r
.34442 .41978 .34794 .42362 .35363 .42158 .35011 .41796 Mtetra
.641 .731 .914 r
.35011 .41796 .35363 .42158 .35932 .41982 .3558 .41636 Mtetra
.677 .751 .906 r
.3558 .41636 .35932 .41982 .36503 .41803 .36153 .41422 Mtetra
.636 .719 .907 r
.36153 .41422 .36503 .41803 .37075 .41603 .36724 .41268 Mtetra
.687 .76 .908 r
.36724 .41268 .37075 .41603 .37651 .41374 .373 .41039 Mtetra
.682 .76 .91 r
.373 .41039 .37651 .41374 .38224 .41208 .37877 .40817 Mtetra
.655 .721 .897 r
.37877 .40817 .38224 .41208 .388 .41025 .38453 .40634 Mtetra
.67 .726 .891 r
.38453 .40634 .388 .41025 .39378 .40821 .39032 .40427 Mtetra
.629 .711 .906 r
.39032 .40427 .39378 .40821 .39957 .4061 .39609 .40282 Mtetra
.637 .754 .933 r
.39609 .40282 .39957 .4061 .40534 .40491 .40188 .40121 Mtetra
.705 .748 .885 r
.40188 .40121 .40534 .40491 .41116 .40261 .40773 .39851 Mtetra
.641 .708 .895 r
.40773 .39851 .41116 .40261 .41697 .40095 .41354 .39689 Mtetra
.592 .692 .912 r
.41354 .39689 .41697 .40095 .42281 .39887 .41936 .39593 Mtetra
.667 .786 .937 r
.41936 .39593 .42281 .39887 .42867 .39671 .42522 .39387 Mtetra
.683 .797 .935 r
.42522 .39387 .42867 .39671 .43454 .39453 .4311 .39159 Mtetra
.583 .761 .963 r
.4311 .39159 .43454 .39453 .4404 .39299 .43695 .39049 Mtetra
.586 .795 .979 r
.43695 .39049 .4404 .39299 .44625 .39236 .44283 .38923 Mtetra
.752 .793 .887 r
.44283 .38923 .44625 .39236 .45213 .39161 .44878 .38568 Mtetra
.52 .573 .85 r
.44878 .38568 .45213 .39161 .45809 .38726 .45465 .38597 Mtetra
.383 .794 .98 r
.45465 .38597 .45809 .38726 .46393 .38983 .46056 .38536 Mtetra
.679 .706 .868 r
.46056 .38536 .46393 .38983 .4699 .38691 .46653 .38301 Mtetra
.566 .695 .928 r
.46653 .38301 .4699 .38691 .47579 .3894 .47247 .38231 Mtetra
.276 .393 .801 r
.47247 .38231 .47579 .3894 .48179 .38542 .47837 .38589 Mtetra
.782 .995 .871 r
.47837 .38589 .48179 .38542 .4877 .39048 .48442 .38095 Mtetra
.426 .422 .752 r
.48442 .38095 .4877 .39048 .49364 .39609 .49038 .38362 Mtetra
0 0 .487 r
.49038 .38362 .49364 .39609 .49979 .3812 .49627 .39804 Mtetra
.307 .037 .329 r
.49627 .39804 .49979 .3812 .50563 .41188 .50239 .39045 Mtetra
.522 .385 .635 r
.50239 .39045 .50563 .41188 .5118 .39423 .50845 .39226 Mtetra
.948 .607 .334 r
.50845 .39226 .5118 .39423 .51781 .42773 .51444 .42689 Mtetra
.964 .836 .667 r
.51444 .42689 .51781 .42773 .52399 .40954 .52064 .41137 Mtetra
.919 .571 .363 r
.52064 .41137 .52399 .40954 .53016 .41343 .52684 .44118 Mtetra
.446 .189 .43 r
.52684 .44118 .53016 .41343 .53639 .42561 .53308 .43536 Mtetra
.735 .386 .388 r
.53308 .43536 .53639 .42561 .54243 .39123 .53939 .44631 Mtetra
0 0 .263 r
.53939 .44631 .54243 .39123 .54863 .39206 .54532 .38554 Mtetra
.691 .642 .796 r
.54532 .38554 .54863 .39206 .5549 .39881 .5515 .38232 Mtetra
.431 .349 .662 r
.5515 .38232 .5549 .39881 .56092 .37849 .55778 .38701 Mtetra
.848 .82 .34 r
.55778 .38701 .56092 .37849 .56711 .37503 .56378 .36554 Mtetra
.796 .635 .682 r
.56378 .36554 .56711 .37503 .57335 .37489 .56987 .35475 Mtetra
.474 .358 .64 r
.56987 .35475 .57335 .37489 .57922 .35185 .57618 .35873 Mtetra
0 0 0 r
.57618 .35873 .57922 .35185 .58555 .35644 .58225 .34795 Mtetra
.733 .619 .731 r
.58225 .34795 .58555 .35644 .59165 .34779 .58841 .34215 Mtetra
.5 .581 .868 r
.58841 .34215 .59165 .34779 .59782 .34319 .5947 .34263 Mtetra
.917 .943 .804 r
.5947 .34263 .59782 .34319 .60409 .34215 .60082 .33476 Mtetra
.485 .511 .81 r
.60082 .33476 .60409 .34215 .61029 .33792 .60717 .3359 Mtetra
.834 .889 .881 r
.60717 .3359 .61029 .33792 .61651 .33427 .61336 .33064 Mtetra
.68 .764 .914 r
.61336 .33064 .61651 .33427 .62282 .33331 .61964 .32825 Mtetra
.636 .673 .868 r
.61964 .32825 .62282 .33331 .6291 .33058 .62595 .32655 Mtetra
.687 .744 .895 r
.62595 .32655 .6291 .33058 .63538 .32778 .63226 .32401 Mtetra
.646 .745 .921 r
.63226 .32401 .63538 .32778 .6417 .32565 .6386 .32213 Mtetra
.686 .774 .918 r
.6386 .32213 .6417 .32565 .64803 .32338 .64493 .31962 Mtetra
.731 .774 .887 r
.64493 .31962 .64803 .32338 .65437 .32095 .65124 .31626 Mtetra
.652 .698 .88 r
.65124 .31626 .65437 .32095 .6607 .31817 .65762 .31428 Mtetra
.634 .734 .92 r
.65762 .31428 .6607 .31817 .66711 .31681 .66402 .31257 Mtetra
.672 .73 .894 r
.66402 .31257 .66711 .31681 .67347 .31386 .67041 .31025 Mtetra
.7 .776 .911 r
.67041 .31025 .67347 .31386 .67987 .31172 .6768 .30749 Mtetra
.66 .727 .899 r
.6768 .30749 .67987 .31172 .6863 .30972 .68323 .30538 Mtetra
.667 .724 .892 r
.68323 .30538 .6863 .30972 .69273 .30746 .68967 .30312 Mtetra
.654 .72 .897 r
.68967 .30312 .69273 .30746 .69916 .30502 .69614 .3011 Mtetra
.637 .737 .921 r
.69614 .3011 .69916 .30502 .70563 .30306 .70263 .29932 Mtetra
.677 .764 .916 r
.70263 .29932 .70563 .30306 .71213 .30113 .70911 .29692 Mtetra
.665 .733 .9 r
.70911 .29692 .71213 .30113 .7186 .29854 .71561 .29469 Mtetra
.687 .762 .909 r
.71561 .29469 .7186 .29854 .72512 .29658 .7221 .2921 Mtetra
.655 .716 .893 r
.7221 .2921 .72512 .29658 .73164 .29438 .72864 .29003 Mtetra
.656 .723 .898 r
.72864 .29003 .73164 .29438 .73817 .29208 .7352 .28794 Mtetra
.658 .736 .907 r
.7352 .28794 .73817 .29208 .74473 .28997 .74177 .28581 Mtetra
.675 .742 .901 r
.74177 .28581 .74473 .28997 .7513 .28778 .74833 .28338 Mtetra
.658 .723 .897 r
.74833 .28338 .7513 .28778 .75786 .28527 .75493 .28125 Mtetra
.645 .739 .917 r
.75493 .28125 .75786 .28527 .76447 .2832 .76156 .2793 Mtetra
.688 .763 .909 r
.76156 .2793 .76447 .2832 .77109 .28109 .76815 .27665 Mtetra
.643 .716 .901 r
.76815 .27665 .77109 .28109 .77769 .27859 .77481 .27475 Mtetra
.68 .765 .915 r
.77481 .27475 .77769 .27859 .78435 .27646 .78145 .27223 Mtetra
.66 .735 .905 r
.78145 .27223 .78435 .27646 .79101 .27431 .78812 .27003 Mtetra
.656 .731 .905 r
.78812 .27003 .79101 .27431 .79767 .2719 .79482 .2679 Mtetra
.664 .751 .915 r
.79482 .2679 .79767 .2719 .80435 .26953 .80151 .26563 Mtetra
.682 .765 .914 r
.80151 .26563 .80435 .26953 .81108 .26759 .8082 .26305 Mtetra
.641 .713 .899 r
.8082 .26305 .81108 .26759 .81783 .26563 .81497 .26115 Mtetra
.652 .721 .899 r
.81497 .26115 .81783 .26563 .82452 .2628 .82173 .25906 Mtetra
.675 .774 .925 r
.82173 .25906 .82452 .2628 .83132 .2611 .82848 .2566 Mtetra
.666 .727 .895 r
.82848 .2566 .83132 .2611 .83809 .25876 .83525 .25426 Mtetra
.611 .702 .909 r
.83525 .25426 .83809 .25876 .84492 .25691 .84214 .25282 Mtetra
.706 .767 .9 r
.84214 .25282 .84492 .25691 .85165 .25401 .84887 .24977 Mtetra
.678 .782 .928 r
.24023 .45104 .24396 .45386 .24943 .4522 .24574 .44897 Mtetra
.666 .754 .916 r
.24574 .44897 .24943 .4522 .25494 .45005 .25124 .44707 Mtetra
.666 .77 .927 r
.25124 .44707 .25494 .45005 .26042 .44848 .25676 .44516 Mtetra
.675 .752 .909 r
.25676 .44516 .26042 .44848 .26594 .44661 .26229 .44312 Mtetra
.666 .74 .905 r
.26229 .44312 .26594 .44661 .27149 .44452 .26783 .4412 Mtetra
.628 .74 .928 r
.26783 .4412 .27149 .44452 .277 .44292 .27334 .4398 Mtetra
.685 .766 .913 r
.27334 .4398 .277 .44292 .28254 .44118 .27892 .4376 Mtetra
.677 .739 .897 r
.27892 .4376 .28254 .44118 .28813 .43903 .28451 .4355 Mtetra
.662 .738 .906 r
.28451 .4355 .28813 .43903 .2937 .43712 .29009 .43362 Mtetra
.656 .739 .911 r
.29009 .43362 .2937 .43712 .29929 .43527 .29568 .43183 Mtetra
.669 .746 .908 r
.29568 .43183 .29929 .43527 .30488 .43339 .30129 .42986 Mtetra
.652 .736 .911 r
.30129 .42986 .30488 .43339 .3105 .43141 .30689 .42812 Mtetra
.682 .759 .91 r
.30689 .42812 .3105 .43141 .31611 .42965 .31254 .42594 Mtetra
.642 .724 .908 r
.31254 .42594 .31611 .42965 .32174 .42781 .31816 .42435 Mtetra
.675 .748 .906 r
.31816 .42435 .32174 .42781 .32741 .42563 .32382 .42225 Mtetra
.676 .754 .91 r
.32382 .42225 .32741 .42563 .33306 .42373 .3295 .42015 Mtetra
.666 .74 .905 r
.3295 .42015 .33306 .42373 .33873 .42177 .33518 .41818 Mtetra
.653 .736 .911 r
.33518 .41818 .33873 .42177 .34442 .41978 .34086 .41642 Mtetra
.655 .75 .92 r
.34086 .41642 .34442 .41978 .35011 .41796 .34656 .41461 Mtetra
.66 .753 .919 r
.34656 .41461 .35011 .41796 .3558 .41636 .35227 .41273 Mtetra
.686 .744 .895 r
.35227 .41273 .3558 .41636 .36153 .41422 .35801 .41043 Mtetra
.627 .718 .912 r
.35801 .41043 .36153 .41422 .36724 .41268 .36372 .40901 Mtetra
.672 .739 .9 r
.36372 .40901 .36724 .41268 .373 .41039 .36948 .40692 Mtetra
.684 .754 .904 r
.36948 .40692 .373 .41039 .37877 .40817 .37526 .40464 Mtetra
.67 .748 .909 r
.37526 .40464 .37877 .40817 .38453 .40634 .38104 .40259 Mtetra
.65 .729 .907 r
.38104 .40259 .38453 .40634 .39032 .40427 .38682 .40083 Mtetra
.632 .742 .927 r
.38682 .40083 .39032 .40427 .39609 .40282 .3926 .39929 Mtetra
.668 .748 .91 r
.3926 .39929 .39609 .40282 .40188 .40121 .39842 .39725 Mtetra
.661 .722 .894 r
.39842 .39725 .40188 .40121 .40773 .39851 .40425 .3953 Mtetra
.686 .773 .917 r
.40425 .3953 .40773 .39851 .41354 .39689 .4101 .39298 Mtetra
.566 .692 .926 r
.4101 .39298 .41354 .39689 .41936 .39593 .4159 .39229 Mtetra
.676 .746 .904 r
.4159 .39229 .41936 .39593 .42522 .39387 .42178 .39011 Mtetra
.652 .732 .908 r
.42178 .39011 .42522 .39387 .4311 .39159 .42765 .38829 Mtetra
.593 .741 .947 r
.42765 .38829 .4311 .39159 .43695 .39049 .43352 .38717 Mtetra
.698 .772 .909 r
.43352 .38717 .43695 .39049 .44283 .38923 .43944 .38463 Mtetra
.693 .704 .856 r
.43944 .38463 .44283 .38923 .44878 .38568 .44537 .38197 Mtetra
.373 .616 .945 r
.44537 .38197 .44878 .38568 .45465 .38597 .45124 .38289 Mtetra
.747 .798 .893 r
.45124 .38289 .45465 .38597 .46056 .38536 .45721 .37945 Mtetra
.409 .516 .856 r
.45721 .37945 .46056 .38536 .46653 .38301 .4631 .38106 Mtetra
.764 .873 .927 r
.4631 .38106 .46653 .38301 .47247 .38231 .46911 .37743 Mtetra
.058 .354 .827 r
.46911 .37743 .47247 .38231 .47837 .38589 .47501 .38122 Mtetra
.43 .589 .908 r
.47501 .38122 .47837 .38589 .48442 .38095 .48098 .38213 Mtetra
.968 .924 .697 r
.48098 .38213 .48442 .38095 .49038 .38362 .48713 .37022 Mtetra
0 0 .521 r
.48713 .37022 .49038 .38362 .49627 .39804 .493 .38423 Mtetra
.12 .158 .627 r
.493 .38423 .49627 .39804 .50239 .39045 .49897 .39428 Mtetra
.666 .226 .195 r
.49897 .39428 .50239 .39045 .50845 .39226 .50503 .39884 Mtetra
.356 0 .145 r
.50503 .39884 .50845 .39226 .51444 .42689 .51117 .39703 Mtetra
.698 .49 .603 r
.51117 .39703 .51444 .42689 .52064 .41137 .51734 .38141 Mtetra
.985 .703 .359 r
.51734 .38141 .52064 .41137 .52684 .44118 .52339 .57257 Mtetra
0 0 .292 r
.52339 .57257 .52684 .44118 .53308 .43536 .52971 .43041 Mtetra
.56 .645 .892 r
.52971 .43041 .53308 .43536 .53939 .44631 .53598 .42991 Mtetra
.769 .573 .632 r
.53598 .42991 .53939 .44631 .54532 .38554 .54219 .41445 Mtetra
0 0 .235 r
.54219 .41445 .54532 .38554 .5515 .38232 .54825 .3841 Mtetra
.994 .864 .592 r
.54825 .3841 .5515 .38232 .55778 .38701 .55432 .36469 Mtetra
.71 .512 .62 r
.55432 .36469 .55778 .38701 .56378 .36554 .56041 .35185 Mtetra
.227 .235 .659 r
.56041 .35185 .56378 .36554 .56987 .35475 .56675 .3603 Mtetra
0 0 0 r
.56675 .3603 .56987 .35475 .57618 .35873 .5729 .35299 Mtetra
.87 .722 .696 r
.5729 .35299 .57618 .35873 .58225 .34795 .57897 .34084 Mtetra
.523 .541 .816 r
.57897 .34084 .58225 .34795 .58841 .34215 .58525 .34126 Mtetra
.758 .956 .937 r
.58525 .34126 .58841 .34215 .5947 .34263 .59147 .33728 Mtetra
.766 .71 .8 r
.59147 .33728 .5947 .34263 .60082 .33476 .59766 .33221 Mtetra
.565 .795 .986 r
.59766 .33221 .60082 .33476 .60717 .3359 .60396 .331 Mtetra
.697 .705 .853 r
.60396 .331 .60717 .3359 .61336 .33064 .61023 .32809 Mtetra
.796 .856 .895 r
.61023 .32809 .61336 .33064 .61964 .32825 .61646 .32362 Mtetra
.603 .68 .895 r
.61646 .32362 .61964 .32825 .62595 .32655 .6228 .32245 Mtetra
.687 .741 .892 r
.6228 .32245 .62595 .32655 .63226 .32401 .62911 .31989 Mtetra
.667 .733 .9 r
.62911 .31989 .63226 .32401 .6386 .32213 .63545 .31768 Mtetra
.667 .716 .886 r
.63545 .31768 .6386 .32213 .64493 .31962 .6418 .31545 Mtetra
.714 .748 .879 r
.6418 .31545 .64493 .31962 .65124 .31626 .64813 .31233 Mtetra
.628 .731 .921 r
.64813 .31233 .65124 .31626 .65762 .31428 .65453 .3107 Mtetra
.687 .774 .917 r
.65453 .3107 .65762 .31428 .66402 .31257 .66091 .30815 Mtetra
.646 .712 .895 r
.66091 .30815 .66402 .31257 .67041 .31025 .66733 .30627 Mtetra
.687 .751 .9 r
.66733 .30627 .67041 .31025 .6768 .30749 .67374 .30368 Mtetra
.681 .76 .911 r
.67374 .30368 .6768 .30749 .68323 .30538 .68016 .30122 Mtetra
.661 .733 .903 r
.68016 .30122 .68323 .30538 .68967 .30312 .68662 .29907 Mtetra
.644 .733 .913 r
.68662 .29907 .68967 .30312 .69614 .3011 .6931 .29719 Mtetra
.648 .743 .919 r
.6931 .29719 .69614 .3011 .70263 .29932 .6996 .29525 Mtetra
.689 .749 .898 r
.6996 .29525 .70263 .29932 .70911 .29692 .70607 .2926 Mtetra
.647 .721 .902 r
.70607 .2926 .70911 .29692 .71561 .29469 .7126 .29067 Mtetra
.677 .749 .905 r
.7126 .29067 .71561 .29469 .7221 .2921 .71911 .28822 Mtetra
.675 .757 .913 r
.71911 .28822 .7221 .2921 .72864 .29003 .72564 .28583 Mtetra
.653 .731 .906 r
.72564 .28583 .72864 .29003 .7352 .28794 .73221 .28378 Mtetra
.665 .738 .905 r
.73221 .28378 .7352 .28794 .74177 .28581 .73878 .28153 Mtetra
.666 .733 .899 r
.73878 .28153 .74177 .28581 .74833 .28338 .74537 .27924 Mtetra
.646 .733 .912 r
.74537 .27924 .74833 .28338 .75493 .28125 .75199 .2773 Mtetra
.664 .752 .915 r
.75199 .2773 .75493 .28125 .76156 .2793 .75861 .27505 Mtetra
.677 .74 .898 r
.75861 .27505 .76156 .2793 .76815 .27665 .76523 .27255 Mtetra
.644 .736 .916 r
.76523 .27255 .76815 .27665 .77481 .27475 .7719 .27062 Mtetra
.679 .748 .904 r
.7719 .27062 .77481 .27475 .78145 .27223 .77854 .2681 Mtetra
.663 .743 .91 r
.77854 .2681 .78145 .27223 .78812 .27003 .78522 .26584 Mtetra
.659 .739 .909 r
.78522 .26584 .78812 .27003 .79482 .2679 .79192 .26364 Mtetra
.656 .734 .907 r
.79192 .26364 .79482 .2679 .80151 .26563 .79865 .26149 Mtetra
.663 .744 .911 r
.79865 .26149 .80151 .26563 .8082 .26305 .80538 .25922 Mtetra
.677 .769 .92 r
.80538 .25922 .8082 .26305 .81497 .26115 .8121 .25671 Mtetra
.634 .716 .907 r
.8121 .25671 .81497 .26115 .82173 .25906 .8189 .25492 Mtetra
.671 .749 .909 r
.8189 .25492 .82173 .25906 .82848 .2566 .82566 .25249 Mtetra
.686 .758 .906 r
.82566 .25249 .82848 .2566 .83525 .25426 .83242 .24981 Mtetra
.603 .703 .914 r
.83242 .24981 .83525 .25426 .84214 .25282 .83932 .24848 Mtetra
.634 .723 .912 r
.83932 .24848 .84214 .25282 .84887 .24977 .8462 .24665 Mtetra
.666 .733 .899 r
.23656 .44744 .24023 .45104 .24574 .44897 .24205 .44554 Mtetra
.676 .745 .903 r
.24205 .44554 .24574 .44897 .25124 .44707 .24758 .44348 Mtetra
.658 .732 .904 r
.24758 .44348 .25124 .44707 .25676 .44516 .25309 .44168 Mtetra
.672 .742 .903 r
.25309 .44168 .25676 .44516 .26229 .44312 .25863 .43967 Mtetra
.665 .742 .908 r
.25863 .43967 .26229 .44312 .26783 .4412 .26417 .43776 Mtetra
.632 .734 .922 r
.26417 .43776 .26783 .4412 .27334 .4398 .26969 .43631 Mtetra
.684 .746 .898 r
.26969 .43631 .27334 .4398 .27892 .4376 .27528 .43409 Mtetra
.678 .743 .9 r
.27528 .43409 .27892 .4376 .28451 .4355 .28088 .43197 Mtetra
.661 .739 .908 r
.28088 .43197 .28451 .4355 .29009 .43362 .28646 .43011 Mtetra
.653 .738 .912 r
.28646 .43011 .29009 .43362 .29568 .43183 .29205 .42836 Mtetra
.672 .746 .906 r
.29205 .42836 .29568 .43183 .30129 .42986 .29767 .42633 Mtetra
.651 .737 .912 r
.29767 .42633 .30129 .42986 .30689 .42812 .30329 .42459 Mtetra
.682 .746 .9 r
.30329 .42459 .30689 .42812 .31254 .42594 .30894 .42239 Mtetra
.641 .734 .916 r
.30894 .42239 .31254 .42594 .31816 .42435 .31457 .42078 Mtetra
.673 .742 .903 r
.31457 .42078 .31816 .42435 .32382 .42225 .32024 .41871 Mtetra
.676 .745 .903 r
.32024 .41871 .32382 .42225 .3295 .42015 .32592 .41659 Mtetra
.666 .742 .906 r
.32592 .41659 .3295 .42015 .33518 .41818 .33161 .41461 Mtetra
.657 .739 .91 r
.33161 .41461 .33518 .41818 .34086 .41642 .3373 .41277 Mtetra
.649 .733 .91 r
.3373 .41277 .34086 .41642 .34656 .41461 .343 .41105 Mtetra
.658 .74 .911 r
.343 .41105 .34656 .41461 .35227 .41273 .34872 .40919 Mtetra
.689 .751 .899 r
.34872 .40919 .35227 .41273 .35801 .41043 .35447 .40684 Mtetra
.63 .732 .921 r
.35447 .40684 .35801 .41043 .36372 .40901 .36019 .40536 Mtetra
.671 .741 .903 r
.36019 .40536 .36372 .40901 .36948 .40692 .36596 .40329 Mtetra
.681 .745 .899 r
.36596 .40329 .36948 .40692 .37526 .40464 .37174 .40105 Mtetra
.668 .744 .907 r
.37174 .40105 .37526 .40464 .38104 .40259 .37753 .39901 Mtetra
.647 .739 .916 r
.37753 .39901 .38104 .40259 .38682 .40083 .38331 .39729 Mtetra
.631 .737 .924 r
.38331 .39729 .38682 .40083 .3926 .39929 .3891 .39576 Mtetra
.669 .749 .911 r
.3891 .39576 .3926 .39929 .39842 .39725 .39493 .39371 Mtetra
.667 .748 .911 r
.39493 .39371 .39842 .39725 .40425 .3953 .40077 .39167 Mtetra
.666 .744 .908 r
.40077 .39167 .40425 .3953 .4101 .39298 .40661 .38965 Mtetra
.623 .749 .937 r
.40661 .38965 .4101 .39298 .4159 .39229 .41246 .38819 Mtetra
.629 .706 .901 r
.41246 .38819 .4159 .39229 .42178 .39011 .41831 .38672 Mtetra
.658 .757 .923 r
.41831 .38672 .42178 .39011 .42765 .38829 .4242 .38479 Mtetra
.657 .751 .919 r
.4242 .38479 .42765 .38829 .43352 .38717 .43009 .38288 Mtetra
.637 .7 .892 r
.43009 .38288 .43352 .38717 .43944 .38463 .436 .38128 Mtetra
.747 .782 .881 r
.436 .38128 .43944 .38463 .44537 .38197 .44196 .37777 Mtetra
.255 .519 .91 r
.44196 .37777 .44537 .38197 .45124 .38289 .4478 .37975 Mtetra
.748 .795 .891 r
.4478 .37975 .45124 .38289 .45721 .37945 .45379 .37627 Mtetra
.163 .535 .923 r
.45379 .37627 .45721 .37945 .4631 .38106 .45968 .37811 Mtetra
.792 .812 .868 r
.45968 .37811 .4631 .38106 .46911 .37743 .46572 .37362 Mtetra
0 .121 .637 r
.46572 .37362 .46911 .37743 .47501 .38122 .47159 .37881 Mtetra
.706 .838 .945 r
.47159 .37881 .47501 .38122 .48098 .38213 .47763 .37609 Mtetra
.849 .705 .703 r
.47763 .37609 .48098 .38213 .48713 .37022 .48378 .36489 Mtetra
.84 .432 0 r
.48378 .36489 .48713 .37022 .493 .38423 .48963 .37938 Mtetra
.852 .436 0 r
.48963 .37938 .493 .38423 .49897 .39428 .49556 .39377 Mtetra
.393 0 0 r
.49556 .39377 .49897 .39428 .50503 .39884 .50165 .39624 Mtetra
.872 .832 .805 r
.50165 .39624 .50503 .39884 .51117 .39703 .50782 .38889 Mtetra
0 0 .392 r
.50782 .38889 .51117 .39703 .51734 .38141 .51392 .40156 Mtetra
.912 .616 .471 r
.51392 .40156 .51734 .38141 .52339 .57257 .51993 .51777 Mtetra
0 0 .443 r
.51993 .51777 .52339 .57257 .52971 .43041 .52638 .56622 Mtetra
0 0 .323 r
.52638 .56622 .52971 .43041 .53598 .42991 .53261 .42954 Mtetra
.979 .773 .555 r
.53261 .42954 .53598 .42991 .54219 .41445 .53877 .39641 Mtetra
.708 .525 .64 r
.53877 .39641 .54219 .41445 .54825 .3841 .54497 .38637 Mtetra
.997 .848 .565 r
.54497 .38637 .54825 .3841 .55432 .36469 .55105 .3638 Mtetra
.969 .84 .661 r
.55105 .3638 .55432 .36469 .56041 .35185 .55714 .34827 Mtetra
.623 .139 0 r
.55714 .34827 .56041 .35185 .56675 .3603 .56348 .35635 Mtetra
.867 .777 .76 r
.56348 .35635 .56675 .3603 .5729 .35299 .56963 .34768 Mtetra
.866 .733 .713 r
.56963 .34768 .5729 .35299 .57897 .34084 .57573 .33679 Mtetra
.584 .702 .924 r
.57573 .33679 .57897 .34084 .58525 .34126 .582 .33581 Mtetra
.625 .652 .856 r
.582 .33581 .58525 .34126 .59147 .33728 .58827 .33429 Mtetra
.864 .826 .809 r
.58827 .33429 .59147 .33728 .59766 .33221 .59444 .3272 Mtetra
.483 .603 .896 r
.59444 .3272 .59766 .33221 .60396 .331 .60078 .32768 Mtetra
.779 .807 .875 r
.60078 .32768 .60396 .331 .61023 .32809 .60702 .32335 Mtetra
.73 .724 .845 r
.60702 .32335 .61023 .32809 .61646 .32362 .61328 .3197 Mtetra
.638 .734 .918 r
.61328 .3197 .61646 .32362 .6228 .32245 .61962 .31795 Mtetra
.633 .701 .894 r
.61962 .31795 .6228 .32245 .62911 .31989 .62597 .31628 Mtetra
.673 .766 .92 r
.62597 .31628 .62911 .31989 .63545 .31768 .63231 .31397 Mtetra
.708 .771 .902 r
.63231 .31397 .63545 .31768 .6418 .31545 .63865 .31105 Mtetra
.698 .732 .877 r
.63865 .31105 .6418 .31545 .64813 .31233 .645 .30822 Mtetra
.616 .716 .917 r
.645 .30822 .64813 .31233 .65453 .3107 .65142 .30678 Mtetra
.686 .754 .903 r
.65142 .30678 .65453 .3107 .66091 .30815 .65781 .30423 Mtetra
.644 .739 .918 r
.65781 .30423 .66091 .30815 .66733 .30627 .66424 .30236 Mtetra
.689 .757 .904 r
.66424 .30236 .66733 .30627 .67374 .30368 .67066 .29975 Mtetra
.682 .754 .906 r
.67066 .29975 .67374 .30368 .68016 .30122 .67709 .29726 Mtetra
.664 .746 .911 r
.67709 .29726 .68016 .30122 .68662 .29907 .68355 .29506 Mtetra
.647 .737 .915 r
.68355 .29506 .68662 .29907 .6931 .29719 .69005 .29312 Mtetra
.65 .736 .912 r
.69005 .29312 .6931 .29719 .6996 .29525 .69655 .29113 Mtetra
.689 .748 .897 r
.69655 .29113 .6996 .29525 .70607 .2926 .70303 .28847 Mtetra
.64 .729 .913 r
.70303 .28847 .70607 .2926 .7126 .29067 .70958 .28663 Mtetra
.681 .751 .904 r
.70958 .28663 .7126 .29067 .71911 .28822 .7161 .28412 Mtetra
.67 .743 .905 r
.7161 .28412 .71911 .28822 .72564 .28583 .72264 .28178 Mtetra
.656 .742 .913 r
.72264 .28178 .72564 .28583 .73221 .28378 .72922 .27967 Mtetra
.667 .743 .907 r
.72922 .27967 .73221 .28378 .73878 .28153 .7358 .27738 Mtetra
.665 .74 .906 r
.7358 .27738 .73878 .28153 .74537 .27924 .7424 .27511 Mtetra
.65 .736 .913 r
.7424 .27511 .74537 .27924 .75199 .2773 .74903 .2731 Mtetra
.662 .738 .906 r
.74903 .2731 .75199 .2773 .75861 .27505 .75566 .27087 Mtetra
.678 .746 .902 r
.75566 .27087 .75861 .27505 .76523 .27255 .76228 .26835 Mtetra
.644 .731 .912 r
.76228 .26835 .76523 .27255 .7719 .27062 .76897 .26641 Mtetra
.676 .745 .902 r
.76897 .26641 .7719 .27062 .77854 .2681 .77563 .26393 Mtetra
.663 .742 .908 r
.77563 .26393 .77854 .2681 .78522 .26584 .78232 .26166 Mtetra
.657 .74 .91 r
.78232 .26166 .78522 .26584 .79192 .26364 .78903 .25949 Mtetra
.662 .743 .91 r
.78903 .25949 .79192 .26364 .79865 .26149 .79576 .25724 Mtetra
.663 .739 .906 r
.79576 .25724 .79865 .26149 .80538 .25922 .8025 .25495 Mtetra
.673 .742 .903 r
.8025 .25495 .80538 .25922 .8121 .25671 .80923 .25249 Mtetra
.632 .728 .917 r
.80923 .25249 .8121 .25671 .8189 .25492 .81605 .2507 Mtetra
.668 .744 .907 r
.81605 .2507 .8189 .25492 .82566 .25249 .82283 .24831 Mtetra
.692 .757 .901 r
.82283 .24831 .82566 .25249 .83242 .24981 .82958 .24549 Mtetra
.59 .705 .923 r
.82958 .24549 .83242 .24981 .83932 .24848 .83652 .24433 Mtetra
.664 .749 .913 r
.83652 .24433 .83932 .24848 .8462 .24665 .84335 .24199 Mtetra
.668 .725 .892 r
.23288 .44368 .23656 .44744 .24205 .44554 .23839 .44172 Mtetra
.667 .722 .89 r
.23839 .44172 .24205 .44554 .24758 .44348 .24391 .43977 Mtetra
.649 .724 .903 r
.24391 .43977 .24758 .44348 .25309 .44168 .24941 .4381 Mtetra
.664 .735 .903 r
.24941 .4381 .25309 .44168 .25863 .43967 .25495 .4362 Mtetra
.674 .745 .904 r
.25495 .4362 .25863 .43967 .26417 .43776 .26051 .43414 Mtetra
.655 .732 .906 r
.26051 .43414 .26417 .43776 .26969 .43631 .26606 .43238 Mtetra
.644 .711 .897 r
.26606 .43238 .26969 .43631 .27528 .43409 .27161 .43077 Mtetra
.683 .756 .907 r
.27161 .43077 .27528 .43409 .28088 .43197 .27722 .42857 Mtetra
.668 .749 .911 r
.27722 .42857 .28088 .43197 .28646 .43011 .28282 .42661 Mtetra
.664 .742 .908 r
.28282 .42661 .28646 .43011 .29205 .42836 .28843 .42469 Mtetra
.655 .73 .905 r
.28843 .42469 .29205 .42836 .29767 .42633 .29404 .42289 Mtetra
.675 .75 .907 r
.29404 .42289 .29767 .42633 .30329 .42459 .29968 .4208 Mtetra
.649 .723 .903 r
.29968 .4208 .30329 .42459 .30894 .42239 .30531 .41909 Mtetra
.662 .756 .92 r
.30531 .41909 .30894 .42239 .31457 .42078 .31096 .41719 Mtetra
.681 .744 .899 r
.31096 .41719 .31457 .42078 .32024 .41871 .31665 .41499 Mtetra
.662 .732 .901 r
.31665 .41499 .32024 .41871 .32592 .41659 .32233 .41307 Mtetra
.663 .744 .91 r
.32233 .41307 .32592 .41659 .33161 .41461 .32802 .41113 Mtetra
.671 .749 .909 r
.32802 .41113 .33161 .41461 .3373 .41277 .33373 .40907 Mtetra
.656 .733 .906 r
.33373 .40907 .3373 .41277 .343 .41105 .33944 .40723 Mtetra
.643 .723 .906 r
.33944 .40723 .343 .41105 .34872 .40919 .34515 .40559 Mtetra
.676 .745 .902 r
.34515 .40559 .34872 .40919 .35447 .40684 .35091 .40343 Mtetra
.642 .747 .925 r
.35091 .40343 .35447 .40684 .36019 .40536 .35664 .40176 Mtetra
.687 .749 .898 r
.35664 .40176 .36019 .40536 .36596 .40329 .36243 .39941 Mtetra
.664 .728 .896 r
.36243 .39941 .36596 .40329 .37174 .40105 .36821 .39742 Mtetra
.657 .74 .911 r
.36821 .39742 .37174 .40105 .37753 .39901 .374 .39554 Mtetra
.676 .755 .91 r
.374 .39554 .37753 .39901 .38331 .39729 .37981 .39338 Mtetra
.637 .718 .907 r
.37981 .39338 .38331 .39729 .3891 .39576 .38561 .3918 Mtetra
.64 .717 .903 r
.38561 .3918 .3891 .39576 .39493 .39371 .39142 .39016 Mtetra
.694 .756 .899 r
.39142 .39016 .39493 .39371 .40077 .39167 .39729 .38767 Mtetra
.61 .705 .912 r
.39729 .38767 .40077 .39167 .40661 .38965 .40311 .38645 Mtetra
.655 .768 .932 r
.40311 .38645 .40661 .38965 .41246 .38819 .40898 .38456 Mtetra
.663 .744 .911 r
.40898 .38456 .41246 .38819 .41831 .38672 .41486 .38257 Mtetra
.633 .706 .899 r
.41486 .38257 .41831 .38672 .4242 .38479 .42074 .38102 Mtetra
.665 .738 .904 r
.42074 .38102 .4242 .38479 .43009 .38288 .42665 .37897 Mtetra
.608 .711 .918 r
.42665 .37897 .43009 .38288 .436 .38128 .43255 .37775 Mtetra
.667 .753 .915 r
.43255 .37775 .436 .38128 .44196 .37777 .43848 .37568 Mtetra
.614 .836 .985 r
.43848 .37568 .44196 .37777 .4478 .37975 .44442 .37398 Mtetra
.396 .516 .862 r
.44442 .37398 .4478 .37975 .45379 .37627 .4503 .37563 Mtetra
.846 .947 .884 r
.4503 .37563 .45379 .37627 .45968 .37811 .45635 .37024 Mtetra
.345 .413 .788 r
.45635 .37024 .45968 .37811 .46572 .37362 .46224 .37336 Mtetra
.201 .726 .844 r
.46224 .37336 .46572 .37362 .47159 .37881 .46823 .37273 Mtetra
.752 .676 .777 r
.46823 .37273 .47159 .37881 .47763 .37609 .47431 .36764 Mtetra
.045 .202 .704 r
.47431 .36764 .47763 .37609 .48378 .36489 .48022 .37439 Mtetra
.767 .423 .403 r
.48022 .37439 .48378 .36489 .48963 .37938 .4861 .38787 Mtetra
.718 .788 .305 r
.4861 .38787 .48963 .37938 .49556 .39377 .49235 .37172 Mtetra
.013 .022 .52 r
.49235 .37172 .49556 .39377 .50165 .39624 .49827 .3904 Mtetra
.924 .552 .136 r
.49827 .3904 .50165 .39624 .50782 .38889 .50426 .41299 Mtetra
.348 .097 .384 r
.50426 .41299 .50782 .38889 .51392 .40156 .51051 .40369 Mtetra
.877 .983 .701 r
.51051 .40369 .51392 .40156 .51993 .51777 .51673 .39488 Mtetra
.616 .393 .555 r
.51673 .39488 .51993 .51777 .52638 .56622 .52296 .36942 Mtetra
.492 .292 .536 r
.52296 .36942 .52638 .56622 .53261 .42954 .52917 .39382 Mtetra
.616 .422 .597 r
.52917 .39382 .53261 .42954 .53877 .39641 .5354 .38675 Mtetra
.883 .672 .612 r
.5354 .38675 .53877 .39641 .54497 .38637 .54153 .36227 Mtetra
.25 .184 .585 r
.54153 .36227 .54497 .38637 .55105 .3638 .54787 .3761 Mtetra
0 0 .06 r
.54787 .3761 .55105 .3638 .55714 .34827 .55402 .36174 Mtetra
0 0 0 r
.55402 .36174 .55714 .34827 .56348 .35635 .56005 .33945 Mtetra
.351 .291 .649 r
.56005 .33945 .56348 .35635 .56963 .34768 .5664 .34659 Mtetra
.941 .889 .751 r
.5664 .34659 .56963 .34768 .57573 .33679 .57254 .33652 Mtetra
.826 .983 .881 r
.57254 .33652 .57573 .33679 .582 .33581 .57875 .33113 Mtetra
.598 .675 .895 r
.57875 .33113 .582 .33581 .58827 .33429 .58503 .33003 Mtetra
.805 .764 .815 r
.58503 .33003 .58827 .33429 .59444 .3272 .59124 .32432 Mtetra
.528 .757 .98 r
.59124 .32432 .59444 .3272 .60078 .32768 .59756 .32356 Mtetra
.797 .77 .828 r
.59756 .32356 .60078 .32768 .60702 .32335 .60379 .31824 Mtetra
.657 .682 .862 r
.60379 .31824 .60702 .32335 .61328 .3197 .61011 .31612 Mtetra
.619 .748 .938 r
.61011 .31612 .61328 .3197 .61962 .31795 .61646 .31458 Mtetra
.637 .769 .943 r
.61646 .31458 .61962 .31795 .62597 .31628 .62281 .31277 Mtetra
.705 .783 .912 r
.62281 .31277 .62597 .31628 .63231 .31397 .62915 .30992 Mtetra
.68 .744 .899 r
.62915 .30992 .63231 .31397 .63865 .31105 .63551 .30746 Mtetra
.694 .776 .914 r
.63551 .30746 .63865 .31105 .645 .30822 .64188 .3048 Mtetra
.669 .779 .932 r
.64188 .3048 .645 .30822 .65142 .30678 .64828 .30253 Mtetra
.659 .727 .9 r
.64828 .30253 .65142 .30678 .65781 .30423 .6547 .30042 Mtetra
.673 .757 .914 r
.6547 .30042 .65781 .30423 .66424 .30236 .66112 .29808 Mtetra
.693 .739 .886 r
.66112 .29808 .66424 .30236 .67066 .29975 .66754 .29533 Mtetra
.651 .716 .896 r
.66754 .29533 .67066 .29975 .67709 .29726 .67401 .29333 Mtetra
.667 .75 .912 r
.67401 .29333 .67709 .29726 .68355 .29506 .68048 .29107 Mtetra
.669 .748 .909 r
.68048 .29107 .68355 .29506 .69005 .29312 .68696 .28877 Mtetra
.637 .716 .904 r
.68696 .28877 .69005 .29312 .69655 .29113 .69349 .28698 Mtetra
.67 .74 .903 r
.69349 .28698 .69655 .29113 .70303 .28847 .7 .28465 Mtetra
.665 .758 .919 r
.7 .28465 .70303 .28847 .70958 .28663 .70653 .28241 Mtetra
.684 .742 .896 r
.70653 .28241 .70958 .28663 .7161 .28412 .71306 .27982 Mtetra
.651 .726 .904 r
.71306 .27982 .7161 .28412 .72264 .28178 .71964 .27779 Mtetra
.656 .746 .916 r
.71964 .27779 .72264 .28178 .72922 .27967 .72622 .27567 Mtetra
.662 .748 .914 r
.72622 .27567 .72922 .27967 .7358 .27738 .73282 .27346 Mtetra
.677 .759 .913 r
.73282 .27346 .7358 .27738 .7424 .27511 .73941 .27099 Mtetra
.661 .742 .91 r
.73941 .27099 .7424 .27511 .74903 .2731 .74604 .26878 Mtetra
.645 .725 .907 r
.74604 .26878 .74903 .2731 .75566 .27087 .7527 .26682 Mtetra
.685 .757 .906 r
.7527 .26682 .75566 .27087 .76228 .26835 .75933 .26419 Mtetra
.643 .734 .915 r
.75933 .26419 .76228 .26835 .76897 .26641 .76603 .26225 Mtetra
.679 .749 .904 r
.76603 .26225 .76897 .26641 .77563 .26393 .77269 .2597 Mtetra
.659 .738 .908 r
.77269 .2597 .77563 .26393 .78232 .26166 .7794 .2575 Mtetra
.662 .743 .91 r
.7794 .2575 .78232 .26166 .78903 .25949 .78612 .25523 Mtetra
.661 .739 .907 r
.78612 .25523 .78903 .25949 .79576 .25724 .79286 .25298 Mtetra
.674 .744 .903 r
.79286 .25298 .79576 .25724 .8025 .25495 .79959 .25049 Mtetra
.641 .72 .905 r
.79959 .25049 .8025 .25495 .80923 .25249 .80639 .24856 Mtetra
.662 .759 .922 r
.80639 .24856 .80923 .25249 .81605 .2507 .81317 .24628 Mtetra
.678 .739 .896 r
.81317 .24628 .81605 .2507 .82283 .24831 .81994 .24369 Mtetra
.649 .717 .897 r
.81994 .24369 .82283 .24831 .82958 .24549 .82678 .24162 Mtetra
.637 .753 .932 r
.82678 .24162 .82958 .24549 .83652 .24433 .83365 .23969 Mtetra
.672 .727 .891 r
.83365 .23969 .83652 .24433 .84335 .24199 .84048 .23719 Mtetra
.603 .713 .922 r
.22917 .44004 .23288 .44368 .23839 .44172 .23461 .43895 Mtetra
.71 .793 .916 r
.23461 .43895 .23839 .44172 .24391 .43977 .24019 .43638 Mtetra
.652 .743 .917 r
.24019 .43638 .24391 .43977 .24941 .4381 .24571 .43466 Mtetra
.675 .747 .905 r
.24571 .43466 .24941 .4381 .25495 .4362 .25127 .43259 Mtetra
.63 .725 .916 r
.25127 .43259 .25495 .4362 .26051 .43414 .25678 .43116 Mtetra
.695 .779 .916 r
.25678 .43116 .26051 .43414 .26606 .43238 .26239 .4288 Mtetra
.66 .736 .906 r
.26239 .4288 .26606 .43238 .27161 .43077 .26796 .42694 Mtetra
.658 .722 .896 r
.26796 .42694 .27161 .43077 .27722 .42857 .27355 .42511 Mtetra
.668 .746 .909 r
.27355 .42511 .27722 .42857 .28282 .42661 .27916 .42313 Mtetra
.67 .746 .907 r
.27916 .42313 .28282 .42661 .28843 .42469 .28478 .42112 Mtetra
.656 .738 .91 r
.28478 .42112 .28843 .42469 .29404 .42289 .2904 .41931 Mtetra
.668 .74 .904 r
.2904 .41931 .29404 .42289 .29968 .4208 .29604 .41732 Mtetra
.65 .741 .916 r
.29604 .41732 .29968 .4208 .30531 .41909 .30168 .41558 Mtetra
.683 .749 .901 r
.30168 .41558 .30531 .41909 .31096 .41719 .30736 .41333 Mtetra
.652 .722 .9 r
.30736 .41333 .31096 .41719 .31665 .41499 .31303 .41156 Mtetra
.659 .749 .917 r
.31303 .41156 .31665 .41499 .32233 .41307 .31871 .40969 Mtetra
.666 .754 .916 r
.31871 .40969 .32233 .41307 .32802 .41113 .32441 .40771 Mtetra
.661 .75 .916 r
.32441 .40771 .32802 .41113 .33373 .40907 .33012 .40579 Mtetra
.671 .762 .919 r
.33012 .40579 .33373 .40907 .33944 .40723 .33585 .40373 Mtetra
.665 .748 .912 r
.33585 .40373 .33944 .40723 .34515 .40559 .34159 .40175 Mtetra
.643 .723 .906 r
.34159 .40175 .34515 .40559 .35091 .40343 .34732 .40009 Mtetra
.681 .762 .912 r
.34732 .40009 .35091 .40343 .35664 .40176 .3531 .39785 Mtetra
.663 .725 .896 r
.3531 .39785 .35664 .40176 .36243 .39941 .35887 .39588 Mtetra
.643 .741 .92 r
.35887 .39588 .36243 .39941 .36821 .39742 .36464 .39419 Mtetra
.656 .764 .929 r
.36464 .39419 .36821 .39742 .374 .39554 .37044 .39231 Mtetra
.666 .767 .926 r
.37044 .39231 .374 .39554 .37981 .39338 .37625 .39029 Mtetra
.691 .783 .921 r
.37625 .39029 .37981 .39338 .38561 .3918 .3821 .3879 Mtetra
.639 .721 .907 r
.3821 .3879 .38561 .3918 .39142 .39016 .38792 .38627 Mtetra
.673 .733 .895 r
.38792 .38627 .39142 .39016 .39729 .38767 .39377 .38411 Mtetra
.605 .73 .933 r
.39377 .38411 .39729 .38767 .40311 .38645 .39961 .38289 Mtetra
.693 .757 .9 r
.39961 .38289 .40311 .38645 .40898 .38456 .4055 .3804 Mtetra
.68 .722 .881 r
.4055 .3804 .40898 .38456 .41486 .38257 .4114 .37808 Mtetra
.661 .7 .875 r
.4114 .37808 .41486 .38257 .42074 .38102 .4173 .37607 Mtetra
.63 .667 .867 r
.4173 .37607 .42074 .38102 .42665 .37897 .4232 .37456 Mtetra
.63 .693 .89 r
.4232 .37456 .42665 .37897 .43255 .37775 .42911 .37304 Mtetra
.502 .623 .903 r
.42911 .37304 .43255 .37775 .43848 .37568 .43499 .3732 Mtetra
.702 .831 .944 r
.43499 .3732 .43848 .37568 .44442 .37398 .44097 .37057 Mtetra
.487 .696 .961 r
.44097 .37057 .44442 .37398 .4503 .37563 .44689 .37044 Mtetra
.565 .631 .875 r
.44689 .37044 .4503 .37563 .45635 .37024 .45285 .36992 Mtetra
.199 .724 .851 r
.45285 .36992 .45635 .37024 .46224 .37336 .45882 .36935 Mtetra
.725 .747 .87 r
.45882 .36935 .46224 .37336 .46823 .37273 .46486 .36611 Mtetra
0 .112 .665 r
.46486 .36611 .46823 .37273 .47431 .36764 .47074 .37303 Mtetra
.359 0 .085 r
.47074 .37303 .47431 .36764 .48022 .37439 .47679 .37188 Mtetra
.56 .792 .986 r
.47679 .37188 .48022 .37439 .4861 .38787 .48286 .37075 Mtetra
0 0 .314 r
.48286 .37075 .4861 .38787 .49235 .37172 .48866 .39437 Mtetra
0 0 .161 r
.48866 .39437 .49235 .37172 .49827 .3904 .49502 .36993 Mtetra
.708 .487 0 r
.49502 .36993 .49827 .3904 .50426 .41299 .50086 .40716 Mtetra
.561 .608 .857 r
.50086 .40716 .50426 .41299 .51051 .40369 .50706 .40675 Mtetra
.997 .818 .539 r
.50706 .40675 .51051 .40369 .51673 .39488 .51339 .37696 Mtetra
.502 .387 .655 r
.51339 .37696 .51673 .39488 .52296 .36942 .51958 .37922 Mtetra
.835 .499 .419 r
.51958 .37922 .52296 .36942 .52917 .39382 .5258 .40323 Mtetra
.266 0 .192 r
.5258 .40323 .52917 .39382 .5354 .38675 .53208 .39867 Mtetra
.932 .809 .349 r
.53208 .39867 .5354 .38675 .54153 .36227 .53823 .36361 Mtetra
.776 .306 .124 r
.53823 .36361 .54153 .36227 .54787 .3761 .54453 .37143 Mtetra
.941 .735 .595 r
.54453 .37143 .54787 .3761 .55402 .36174 .5506 .3446 Mtetra
.047 .079 .572 r
.5506 .3446 .55402 .36174 .56005 .33945 .557 .35901 Mtetra
0 0 .066 r
.557 .35901 .56005 .33945 .5664 .34659 .56299 .33185 Mtetra
.462 .382 .681 r
.56299 .33185 .5664 .34659 .57254 .33652 .56931 .33503 Mtetra
.847 .918 .88 r
.56931 .33503 .57254 .33652 .57875 .33113 .57553 .32947 Mtetra
.881 .9 .839 r
.57553 .32947 .57875 .33113 .58503 .33003 .58173 .32273 Mtetra
.535 .545 .811 r
.58173 .32273 .58503 .33003 .59124 .32432 .58806 .32291 Mtetra
.87 .921 .859 r
.58806 .32291 .59124 .32432 .59756 .32356 .59428 .31668 Mtetra
.624 .604 .81 r
.59428 .31668 .59756 .32356 .60379 .31824 .6006 .31504 Mtetra
.644 .782 .947 r
.6006 .31504 .60379 .31824 .61011 .31612 .60693 .31311 Mtetra
.655 .799 .952 r
.60693 .31311 .61011 .31612 .61646 .31458 .61327 .311 Mtetra
.716 .782 .904 r
.61327 .311 .61646 .31458 .62281 .31277 .6196 .30796 Mtetra
.701 .714 .859 r
.6196 .30796 .62281 .31277 .62915 .30992 .62595 .30495 Mtetra
.617 .673 .881 r
.62595 .30495 .62915 .30992 .63551 .30746 .63235 .30354 Mtetra
.668 .748 .91 r
.63235 .30354 .63551 .30746 .64188 .3048 .63875 .30128 Mtetra
.726 .79 .903 r
.63875 .30128 .64188 .3048 .64828 .30253 .64512 .29802 Mtetra
.63 .703 .898 r
.64512 .29802 .64828 .30253 .6547 .30042 .65157 .29636 Mtetra
.697 .753 .895 r
.65157 .29636 .6547 .30042 .66112 .29808 .65798 .29357 Mtetra
.635 .705 .897 r
.65798 .29357 .66112 .29808 .66754 .29533 .66446 .29183 Mtetra
.657 .773 .934 r
.66446 .29183 .66754 .29533 .67401 .29333 .67093 .28971 Mtetra
.669 .77 .926 r
.67093 .28971 .67401 .29333 .68048 .29107 .67741 .28741 Mtetra
.679 .771 .921 r
.67741 .28741 .68048 .29107 .68696 .28877 .6839 .28494 Mtetra
.675 .761 .915 r
.6839 .28494 .68696 .28877 .69349 .28698 .6904 .28253 Mtetra
.638 .712 .901 r
.6904 .28253 .69349 .28698 .7 .28465 .69695 .28071 Mtetra
.693 .762 .905 r
.69695 .28071 .7 .28465 .70653 .28241 .70347 .27799 Mtetra
.642 .716 .902 r
.70347 .27799 .70653 .28241 .71306 .27982 .71005 .2761 Mtetra
.664 .766 .926 r
.71005 .2761 .71306 .27982 .71964 .27779 .71662 .27384 Mtetra
.668 .754 .915 r
.71662 .27384 .71964 .27779 .72622 .27567 .72321 .27152 Mtetra
.658 .739 .91 r
.72321 .27152 .72622 .27567 .73282 .27346 .72982 .26936 Mtetra
.661 .744 .911 r
.72982 .26936 .73282 .27346 .73941 .27099 .73644 .26714 Mtetra
.68 .766 .916 r
.73644 .26714 .73941 .27099 .74604 .26878 .74306 .2646 Mtetra
.66 .74 .909 r
.74306 .2646 .74604 .26878 .7527 .26682 .74971 .26239 Mtetra
.65 .723 .902 r
.74971 .26239 .7527 .26682 .75933 .26419 .75639 .26034 Mtetra
.688 .771 .914 r
.75639 .26034 .75933 .26419 .76603 .26225 .76304 .25764 Mtetra
.647 .713 .896 r
.76304 .25764 .76603 .26225 .77269 .2597 .76976 .25562 Mtetra
.668 .751 .913 r
.76976 .25562 .77269 .2597 .7794 .2575 .77647 .25326 Mtetra
.669 .743 .906 r
.77647 .25326 .7794 .2575 .78612 .25523 .78319 .25086 Mtetra
.662 .733 .903 r
.78319 .25086 .78612 .25523 .79286 .25298 .78994 .24859 Mtetra
.65 .728 .906 r
.78994 .24859 .79286 .25298 .79959 .25049 .79672 .2465 Mtetra
.652 .752 .923 r
.79672 .2465 .79959 .25049 .80639 .24856 .80351 .24437 Mtetra
.689 .756 .902 r
.80351 .24437 .80639 .24856 .81317 .24628 .81026 .2416 Mtetra
.618 .699 .903 r
.81026 .2416 .81317 .24628 .81994 .24369 .81714 .24004 Mtetra
.69 .789 .926 r
.81714 .24004 .81994 .24369 .82678 .24162 .82392 .23727 Mtetra
.599 .709 .921 r
.82392 .23727 .82678 .24162 .83365 .23969 .83087 .23595 Mtetra
.737 .802 .904 r
.83087 .23595 .83365 .23969 .84048 .23719 .83759 .23232 Mtetra
.653 .746 .918 r
.22543 .43668 .22917 .44004 .23461 .43895 .23093 .43495 Mtetra
.641 .706 .894 r
.23093 .43495 .23461 .43895 .24019 .43638 .23643 .43337 Mtetra
.681 .774 .921 r
.23643 .43337 .24019 .43638 .24571 .43466 .24199 .43122 Mtetra
.66 .744 .912 r
.24199 .43122 .24571 .43466 .25127 .43259 .24754 .42937 Mtetra
.689 .764 .909 r
.24754 .42937 .25127 .43259 .25678 .43116 .25313 .42709 Mtetra
.632 .702 .896 r
.25313 .42709 .25678 .43116 .26239 .4288 .25867 .42564 Mtetra
.682 .767 .916 r
.25867 .42564 .26239 .4288 .26796 .42694 .26427 .42346 Mtetra
.676 .747 .905 r
.26427 .42346 .26796 .42694 .27355 .42511 .26989 .42136 Mtetra
.661 .728 .9 r
.26989 .42136 .27355 .42511 .27916 .42313 .27549 .41947 Mtetra
.651 .731 .908 r
.27549 .41947 .27916 .42313 .28478 .42112 .2811 .41773 Mtetra
.678 .754 .909 r
.2811 .41773 .28478 .42112 .2904 .41931 .28675 .41559 Mtetra
.646 .727 .908 r
.28675 .41559 .2904 .41931 .29604 .41732 .29238 .41391 Mtetra
.685 .756 .905 r
.29238 .41391 .29604 .41732 .30168 .41558 .29806 .41163 Mtetra
.64 .714 .901 r
.29806 .41163 .30168 .41558 .30736 .41333 .30371 .41003 Mtetra
.664 .758 .92 r
.30371 .41003 .30736 .41333 .31303 .41156 .30939 .40808 Mtetra
.675 .751 .908 r
.30939 .40808 .31303 .41156 .31871 .40969 .3151 .40596 Mtetra
.665 .734 .901 r
.3151 .40596 .31871 .40969 .32441 .40771 .32081 .40398 Mtetra
.652 .731 .907 r
.32081 .40398 .32441 .40771 .33012 .40579 .32651 .4022 Mtetra
.655 .74 .912 r
.32651 .4022 .33012 .40579 .33585 .40373 .33224 .40036 Mtetra
.679 .759 .912 r
.33224 .40036 .33585 .40373 .34159 .40175 .338 .39816 Mtetra
.661 .743 .911 r
.338 .39816 .34159 .40175 .34732 .40009 .34375 .39623 Mtetra
.662 .728 .899 r
.34375 .39623 .34732 .40009 .3531 .39785 .34952 .39427 Mtetra
.647 .74 .918 r
.34952 .39427 .3531 .39785 .35887 .39588 .35529 .39254 Mtetra
.666 .761 .921 r
.35529 .39254 .35887 .39588 .36464 .39419 .36109 .39051 Mtetra
.662 .74 .908 r
.36109 .39051 .36464 .39419 .37044 .39231 .36689 .38855 Mtetra
.649 .732 .909 r
.36689 .38855 .37044 .39231 .37625 .39029 .3727 .38677 Mtetra
.651 .747 .92 r
.3727 .38677 .37625 .39029 .3821 .3879 .37853 .38495 Mtetra
.701 .795 .923 r
.37853 .38495 .3821 .3879 .38792 .38627 .3844 .3824 Mtetra
.631 .72 .912 r
.3844 .3824 .38792 .38627 .39377 .38411 .39023 .38088 Mtetra
.713 .781 .905 r
.39023 .38088 .39377 .38411 .39961 .38289 .39614 .37808 Mtetra
.639 .677 .87 r
.39614 .37808 .39961 .38289 .4055 .3804 .40201 .37642 Mtetra
.555 .687 .927 r
.40201 .37642 .4055 .3804 .4114 .37808 .40785 .37583 Mtetra
.636 .83 .975 r
.40785 .37583 .4114 .37808 .4173 .37607 .41376 .37397 Mtetra
.712 .857 .951 r
.41376 .37397 .4173 .37607 .4232 .37456 .41971 .37117 Mtetra
.642 .756 .931 r
.41971 .37117 .4232 .37456 .42911 .37304 .42564 .36944 Mtetra
.696 .759 .9 r
.42564 .36944 .42911 .37304 .43499 .3732 .4316 .36686 Mtetra
.317 .449 .836 r
.4316 .36686 .43499 .3732 .44097 .37057 .43744 .36949 Mtetra
.631 .909 .983 r
.43744 .36949 .44097 .37057 .44689 .37044 .44343 .36715 Mtetra
.519 .719 .963 r
.44343 .36715 .44689 .37044 .45285 .36992 .44939 .36669 Mtetra
.506 .718 .967 r
.44939 .36669 .45285 .36992 .45882 .36935 .45537 .36631 Mtetra
.146 .537 .922 r
.45537 .36631 .45882 .36935 .46486 .36611 .46132 .36811 Mtetra
.703 .967 .728 r
.46132 .36811 .46486 .36611 .47074 .37303 .46744 .36233 Mtetra
0 0 .437 r
.46744 .36233 .47074 .37303 .47679 .37188 .47324 .37605 Mtetra
.949 .927 .573 r
.47324 .37605 .47679 .37188 .48286 .37075 .47952 .36123 Mtetra
.683 .367 0 r
.47952 .36123 .48286 .37075 .48866 .39437 .48538 .37828 Mtetra
.771 .574 .633 r
.48538 .37828 .48866 .39437 .49502 .36993 .49166 .36291 Mtetra
.474 .518 .823 r
.49166 .36291 .49502 .36993 .50086 .40716 .49776 .36401 Mtetra
.388 .245 .562 r
.49776 .36401 .50086 .40716 .50706 .40675 .5038 .37851 Mtetra
.549 .384 .611 r
.5038 .37851 .50706 .40675 .51339 .37696 .50998 .37862 Mtetra
.355 .802 .656 r
.50998 .37862 .51339 .37696 .51958 .37922 .5162 .37536 Mtetra
.905 .771 .703 r
.5162 .37536 .51958 .37922 .5258 .40323 .52243 .36276 Mtetra
.582 .391 .588 r
.52243 .36276 .5258 .40323 .53208 .39867 .52864 .35895 Mtetra
.617 .418 .59 r
.52864 .35895 .53208 .39867 .53823 .36361 .53485 .35081 Mtetra
.451 .394 .703 r
.53485 .35081 .53823 .36361 .54453 .37143 .54111 .35377 Mtetra
.466 .364 .656 r
.54111 .35377 .54453 .37143 .5506 .3446 .5474 .35736 Mtetra
0 0 .013 r
.5474 .35736 .5506 .3446 .557 .35901 .55355 .34065 Mtetra
.578 .437 .652 r
.55355 .34065 .557 .35901 .56299 .33185 .55983 .33934 Mtetra
0 0 .014 r
.55983 .33934 .56299 .33185 .56931 .33503 .56605 .33248 Mtetra
.889 .844 .794 r
.56605 .33248 .56931 .33503 .57553 .32947 .57225 .32449 Mtetra
.568 .649 .89 r
.57225 .32449 .57553 .32947 .58173 .32273 .57856 .32384 Mtetra
.896 .987 .745 r
.57856 .32384 .58173 .32273 .58806 .32291 .58475 .31549 Mtetra
.535 .542 .809 r
.58475 .31549 .58806 .32291 .59428 .31668 .5911 .31567 Mtetra
.748 .951 .943 r
.5911 .31567 .59428 .31668 .6006 .31504 .59739 .3118 Mtetra
.733 .806 .91 r
.59739 .3118 .6006 .31504 .60693 .31311 .6037 .30848 Mtetra
.7 .722 .867 r
.6037 .30848 .60693 .31311 .61327 .311 .61003 .30555 Mtetra
.618 .653 .862 r
.61003 .30555 .61327 .311 .6196 .30796 .61641 .30411 Mtetra
.679 .756 .909 r
.61641 .30411 .6196 .30796 .62595 .30495 .62278 .30167 Mtetra
.734 .806 .909 r
.62278 .30167 .62595 .30495 .63235 .30354 .62914 .29831 Mtetra
.646 .676 .864 r
.62914 .29831 .63235 .30354 .63875 .30128 .63555 .29635 Mtetra
.625 .681 .882 r
.63555 .29635 .63875 .30128 .64512 .29802 .642 .29478 Mtetra
.707 .804 .926 r
.642 .29478 .64512 .29802 .65157 .29636 .6484 .29189 Mtetra
.624 .703 .902 r
.6484 .29189 .65157 .29636 .65798 .29357 .65488 .29032 Mtetra
.669 .793 .941 r
.65488 .29032 .65798 .29357 .66446 .29183 .66134 .288 Mtetra
.679 .761 .913 r
.66134 .288 .66446 .29183 .67093 .28971 .66781 .28553 Mtetra
.667 .738 .903 r
.66781 .28553 .67093 .28971 .67741 .28741 .6743 .28325 Mtetra
.661 .737 .907 r
.6743 .28325 .67741 .28741 .6839 .28494 .68081 .28107 Mtetra
.674 .759 .915 r
.68081 .28107 .6839 .28494 .6904 .28253 .68733 .27867 Mtetra
.679 .762 .914 r
.68733 .27867 .6904 .28253 .69695 .28071 .69386 .27619 Mtetra
.649 .715 .896 r
.69386 .27619 .69695 .28071 .70347 .27799 .70042 .27417 Mtetra
.661 .759 .923 r
.70042 .27417 .70347 .27799 .71005 .2761 .70699 .27196 Mtetra
.679 .748 .903 r
.70699 .27196 .71005 .2761 .71662 .27384 .71356 .26943 Mtetra
.668 .73 .896 r
.71356 .26943 .71662 .27384 .72321 .27152 .72016 .26709 Mtetra
.662 .726 .897 r
.72016 .26709 .72321 .27152 .72982 .26936 .72677 .26483 Mtetra
.653 .718 .896 r
.72677 .26483 .72982 .26936 .73644 .26714 .73341 .26273 Mtetra
.651 .724 .902 r
.73341 .26273 .73644 .26714 .74306 .2646 .74007 .26066 Mtetra
.674 .76 .915 r
.74007 .26066 .74306 .2646 .74971 .26239 .74672 .25821 Mtetra
.667 .744 .908 r
.74672 .25821 .74971 .26239 .75639 .26034 .7534 .25585 Mtetra
.656 .724 .899 r
.7534 .25585 .75639 .26034 .76304 .25764 .7601 .25369 Mtetra
.67 .76 .918 r
.7601 .25369 .76304 .25764 .76976 .25562 .7668 .25129 Mtetra
.668 .738 .902 r
.7668 .25129 .76976 .25562 .77647 .25326 .77352 .24891 Mtetra
.653 .731 .907 r
.77352 .24891 .77647 .25326 .78319 .25086 .78027 .24677 Mtetra
.669 .753 .913 r
.78027 .24677 .78319 .25086 .78994 .24859 .78702 .24436 Mtetra
.667 .745 .908 r
.78702 .24436 .78994 .24859 .79672 .2465 .79378 .24198 Mtetra
.655 .724 .9 r
.79378 .24198 .79672 .2465 .80351 .24437 .80058 .23979 Mtetra
.64 .716 .902 r
.80058 .23979 .80351 .24437 .81026 .2416 .80742 .23785 Mtetra
.685 .782 .924 r
.80742 .23785 .81026 .2416 .81714 .24004 .81421 .23517 Mtetra
.621 .693 .895 r
.81421 .23517 .81714 .24004 .82392 .23727 .82111 .23355 Mtetra
.687 .786 .926 r
.82111 .23355 .82392 .23727 .83087 .23595 .82793 .23082 Mtetra
.668 .703 .873 r
.82793 .23082 .83087 .23595 .83759 .23232 .83478 .22831 Mtetra
.618 .719 .918 r
.22169 .43303 .22543 .43668 .23093 .43495 .22716 .43175 Mtetra
.7 .766 .903 r
.22716 .43175 .23093 .43495 .23643 .43337 .23274 .42929 Mtetra
.61 .693 .902 r
.23274 .42929 .23643 .43337 .24199 .43122 .23822 .42814 Mtetra
.702 .775 .908 r
.23822 .42814 .24199 .43122 .24754 .42937 .24383 .42565 Mtetra
.641 .723 .908 r
.24383 .42565 .24754 .42937 .25313 .42709 .24937 .42405 Mtetra
.689 .776 .917 r
.24937 .42405 .25313 .42709 .25867 .42564 .25499 .42176 Mtetra
.663 .722 .893 r
.25499 .42176 .25867 .42564 .26427 .42346 .26058 .41984 Mtetra
.665 .737 .904 r
.26058 .41984 .26427 .42346 .26989 .42136 .26619 .41789 Mtetra
.659 .745 .914 r
.26619 .41789 .26989 .42136 .27549 .41947 .2718 .41603 Mtetra
.674 .751 .909 r
.2718 .41603 .27549 .41947 .2811 .41773 .27744 .41395 Mtetra
.648 .725 .905 r
.27744 .41395 .2811 .41773 .28675 .41559 .28306 .41224 Mtetra
.681 .759 .91 r
.28306 .41224 .28675 .41559 .29238 .41391 .28874 .41004 Mtetra
.641 .718 .904 r
.28874 .41004 .29238 .41391 .29806 .41163 .29438 .40842 Mtetra
.68 .767 .917 r
.29438 .40842 .29806 .41163 .30371 .41003 .30007 .40624 Mtetra
.667 .731 .898 r
.30007 .40624 .30371 .41003 .30939 .40808 .30577 .40422 Mtetra
.653 .724 .901 r
.30577 .40422 .30939 .40808 .3151 .40596 .31146 .40242 Mtetra
.665 .746 .91 r
.31146 .40242 .3151 .40596 .32081 .40398 .31717 .40043 Mtetra
.669 .747 .908 r
.31717 .40043 .32081 .40398 .32651 .4022 .32291 .39838 Mtetra
.673 .733 .895 r
.32291 .39838 .32651 .4022 .33224 .40036 .32866 .39625 Mtetra
.64 .708 .896 r
.32866 .39625 .33224 .40036 .338 .39816 .33439 .39463 Mtetra
.667 .749 .911 r
.33439 .39463 .338 .39816 .34375 .39623 .34015 .39259 Mtetra
.658 .741 .911 r
.34015 .39259 .34375 .39623 .34952 .39427 .34593 .39068 Mtetra
.687 .752 .901 r
.34593 .39068 .34952 .39427 .35529 .39254 .35174 .38832 Mtetra
.649 .707 .889 r
.35174 .38832 .35529 .39254 .36109 .39051 .35753 .38654 Mtetra
.66 .723 .896 r
.35753 .38654 .36109 .39051 .36689 .38855 .36334 .38459 Mtetra
.674 .729 .891 r
.36334 .38459 .36689 .38855 .3727 .38677 .36917 .3824 Mtetra
.643 .698 .886 r
.36917 .3824 .3727 .38677 .37853 .38495 .375 .3807 Mtetra
.628 .699 .896 r
.375 .3807 .37853 .38495 .3844 .3824 .38083 .37922 Mtetra
.71 .784 .909 r
.38083 .37922 .3844 .3824 .39023 .38088 .38673 .37647 Mtetra
.557 .664 .909 r
.38673 .37647 .39023 .38088 .39614 .37808 .39255 .37594 Mtetra
.728 .855 .941 r
.39255 .37594 .39614 .37808 .40201 .37642 .39848 .37293 Mtetra
.668 .757 .917 r
.39848 .37293 .40201 .37642 .40785 .37583 .40439 .37083 Mtetra
.612 .659 .872 r
.40439 .37083 .40785 .37583 .41376 .37397 .41028 .36959 Mtetra
.674 .712 .877 r
.41028 .36959 .41376 .37397 .41971 .37117 .41622 .36734 Mtetra
.591 .712 .928 r
.41622 .36734 .41971 .37117 .42564 .36944 .42213 .36629 Mtetra
.321 .633 .963 r
.42213 .36629 .42564 .36944 .4316 .36686 .428 .36716 Mtetra
.683 .975 .904 r
.428 .36716 .4316 .36686 .43744 .36949 .43403 .36344 Mtetra
.454 .54 .854 r
.43403 .36344 .43744 .36949 .44343 .36715 .43993 .3645 Mtetra
.003 .469 .867 r
.43993 .3645 .44343 .36715 .44939 .36669 .44584 .36666 Mtetra
.858 .973 .863 r
.44584 .36666 .44939 .36669 .45537 .36631 .45195 .36075 Mtetra
0 0 .425 r
.45195 .36075 .45537 .36631 .46132 .36811 .45776 .36957 Mtetra
.907 .983 .755 r
.45776 .36957 .46132 .36811 .46744 .36233 .46395 .36113 Mtetra
.863 .418 .121 r
.46395 .36113 .46744 .36233 .47324 .37605 .46979 .37259 Mtetra
.926 .764 .661 r
.46979 .37259 .47324 .37605 .47952 .36123 .47612 .35576 Mtetra
.051 .323 .806 r
.47612 .35576 .47952 .36123 .48538 .37828 .48213 .36003 Mtetra
.146 .137 .589 r
.48213 .36003 .48538 .37828 .49166 .36291 .48809 .37243 Mtetra
.728 .376 .382 r
.48809 .37243 .49166 .36291 .49776 .36401 .49413 .38266 Mtetra
0 0 0 r
.49413 .38266 .49776 .36401 .5038 .37851 .50054 .35404 Mtetra
.169 .124 .559 r
.50054 .35404 .5038 .37851 .50998 .37862 .5066 .37016 Mtetra
.727 .618 .736 r
.5066 .37016 .50998 .37862 .5162 .37536 .51282 .36464 Mtetra
.764 .606 .683 r
.51282 .36464 .5162 .37536 .52243 .36276 .51906 .35526 Mtetra
.726 .362 0 r
.51906 .35526 .52243 .36276 .52864 .35895 .52528 .37083 Mtetra
0 0 0 r
.52528 .37083 .52864 .35895 .53485 .35081 .53152 .35573 Mtetra
.646 .832 .42 r
.53152 .35573 .53485 .35081 .54111 .35377 .53775 .34585 Mtetra
.723 .627 .75 r
.53775 .34585 .54111 .35377 .5474 .35736 .54398 .34085 Mtetra
.714 .536 .646 r
.54398 .34085 .5474 .35736 .55355 .34065 .55019 .33117 Mtetra
.036 .174 .679 r
.55019 .33117 .55355 .34065 .55983 .33934 .55655 .33921 Mtetra
.979 .864 .654 r
.55655 .33921 .55983 .33934 .56605 .33248 .56269 .32368 Mtetra
.326 .382 .767 r
.56269 .32368 .56605 .33248 .57225 .32449 .56906 .3276 Mtetra
.84 .947 .589 r
.56906 .3276 .57225 .32449 .57856 .32384 .57525 .31741 Mtetra
.481 .544 .845 r
.57525 .31741 .57856 .32384 .58475 .31549 .58161 .31826 Mtetra
.798 .95 .608 r
.58161 .31826 .58475 .31549 .5911 .31567 .58781 .30933 Mtetra
.618 .619 .829 r
.58781 .30933 .5911 .31567 .59739 .3118 .59415 .30785 Mtetra
.673 .748 .907 r
.59415 .30785 .59739 .3118 .6037 .30848 .6005 .30552 Mtetra
.667 .808 .951 r
.6005 .30552 .6037 .30848 .61003 .30555 .60686 .30323 Mtetra
.641 .845 .978 r
.60686 .30323 .61003 .30555 .61641 .30411 .61323 .3011 Mtetra
.744 .826 .915 r
.61323 .3011 .61641 .30411 .62278 .30167 .61958 .29758 Mtetra
.673 .742 .903 r
.61958 .29758 .62278 .30167 .62914 .29831 .62598 .29523 Mtetra
.624 .788 .96 r
.62598 .29523 .62914 .29831 .63555 .29635 .63241 .29348 Mtetra
.732 .835 .928 r
.63241 .29348 .63555 .29635 .642 .29478 .63881 .29018 Mtetra
.635 .702 .894 r
.63881 .29018 .642 .29478 .6484 .29189 .64527 .28842 Mtetra
.688 .786 .925 r
.64527 .28842 .6484 .29189 .65488 .29032 .65171 .28582 Mtetra
.69 .729 .881 r
.65171 .28582 .65488 .29032 .66134 .288 .65817 .28309 Mtetra
.648 .694 .879 r
.65817 .28309 .66134 .288 .66781 .28553 .66467 .2811 Mtetra
.663 .724 .894 r
.66467 .2811 .66781 .28553 .6743 .28325 .67117 .27886 Mtetra
.675 .731 .892 r
.67117 .27886 .6743 .28325 .68081 .28107 .67768 .2764 Mtetra
.645 .705 .89 r
.67768 .2764 .68081 .28107 .68733 .27867 .68423 .27445 Mtetra
.659 .735 .906 r
.68423 .27445 .68733 .27867 .69386 .27619 .69078 .27228 Mtetra
.673 .759 .915 r
.69078 .27228 .69386 .27619 .70042 .27417 .69734 .26987 Mtetra
.668 .735 .9 r
.69734 .26987 .70042 .27417 .70699 .27196 .70391 .26752 Mtetra
.653 .722 .9 r
.70391 .26752 .70699 .27196 .71356 .26943 .71052 .26543 Mtetra
.66 .75 .917 r
.71052 .26543 .71356 .26943 .72016 .26709 .71713 .26323 Mtetra
.661 .759 .923 r
.71713 .26323 .72016 .26709 .72677 .26483 .72376 .261 Mtetra
.671 .765 .921 r
.72376 .261 .72677 .26483 .73341 .26273 .7304 .25861 Mtetra
.68 .753 .906 r
.7304 .25861 .73341 .26273 .74007 .26066 .73703 .25603 Mtetra
.645 .712 .896 r
.73703 .25603 .74007 .26066 .74672 .25821 .74373 .25404 Mtetra
.663 .745 .911 r
.74373 .25404 .74672 .25821 .7534 .25585 .75041 .25175 Mtetra
.674 .753 .91 r
.75041 .25175 .7534 .25585 .7601 .25369 .75711 .24927 Mtetra
.658 .73 .902 r
.75711 .24927 .7601 .25369 .7668 .25129 .76383 .24705 Mtetra
.659 .741 .91 r
.76383 .24705 .7668 .25129 .77352 .24891 .77057 .24482 Mtetra
.678 .757 .911 r
.77057 .24482 .77352 .24891 .78027 .24677 .7773 .24227 Mtetra
.661 .728 .899 r
.7773 .24227 .78027 .24677 .78702 .24436 .78407 .23999 Mtetra
.652 .732 .908 r
.78407 .23999 .78702 .24436 .79378 .24198 .79087 .23785 Mtetra
.663 .751 .915 r
.79087 .23785 .79378 .24198 .80058 .23979 .79767 .23552 Mtetra
.675 .748 .906 r
.79767 .23552 .80058 .23979 .80742 .23785 .80447 .23298 Mtetra
.607 .687 .899 r
.80447 .23298 .80742 .23785 .81421 .23517 .81139 .23158 Mtetra
.714 .804 .921 r
.81139 .23158 .81421 .23517 .82111 .23355 .81816 .22839 Mtetra
.601 .671 .889 r
.81816 .22839 .82111 .23355 .82793 .23082 .82513 .22712 Mtetra
.727 .803 .911 r
.82513 .22712 .82793 .23082 .83478 .22831 .8319 .22366 Mtetra
.669 .745 .908 r
.21793 .42958 .22169 .43303 .22716 .43175 .22346 .4276 Mtetra
.611 .69 .899 r
.22346 .4276 .22716 .43175 .23274 .42929 .22893 .42643 Mtetra
.712 .79 .913 r
.22893 .42643 .23274 .42929 .23822 .42814 .23455 .4238 Mtetra
.609 .68 .892 r
.23455 .4238 .23822 .42814 .24383 .42565 .24005 .42267 Mtetra
.711 .784 .909 r
.24005 .42267 .24383 .42565 .24937 .42405 .24569 .42003 Mtetra
.65 .711 .892 r
.24569 .42003 .24937 .42405 .25499 .42176 .25126 .4183 Mtetra
.664 .747 .912 r
.25126 .4183 .25499 .42176 .26058 .41984 .25686 .41636 Mtetra
.676 .749 .906 r
.25686 .41636 .26058 .41984 .26619 .41789 .26249 .41424 Mtetra
.661 .736 .905 r
.26249 .41424 .26619 .41789 .2718 .41603 .26811 .41233 Mtetra
.648 .73 .908 r
.26811 .41233 .2718 .41603 .27744 .41395 .27373 .41061 Mtetra
.678 .759 .912 r
.27373 .41061 .27744 .41395 .28306 .41224 .27939 .40845 Mtetra
.65 .726 .904 r
.27939 .40845 .28306 .41224 .28874 .41004 .28504 .4067 Mtetra
.684 .762 .91 r
.28504 .4067 .28874 .41004 .29438 .40842 .29073 .40444 Mtetra
.64 .713 .901 r
.29073 .40444 .29438 .40842 .30007 .40624 .29639 .40283 Mtetra
.664 .754 .917 r
.29639 .40283 .30007 .40624 .30577 .40422 .30209 .40087 Mtetra
.675 .759 .915 r
.30209 .40087 .30577 .40422 .31146 .40242 .30781 .39874 Mtetra
.667 .739 .904 r
.30781 .39874 .31146 .40242 .31717 .40043 .31354 .39671 Mtetra
.655 .735 .908 r
.31354 .39671 .31717 .40043 .32291 .39838 .31926 .39486 Mtetra
.655 .747 .917 r
.31926 .39486 .32291 .39838 .32866 .39625 .325 .39301 Mtetra
.672 .768 .922 r
.325 .39301 .32866 .39625 .33439 .39463 .33077 .39089 Mtetra
.667 .738 .903 r
.33077 .39089 .33439 .39463 .34015 .39259 .33655 .38884 Mtetra
.651 .733 .909 r
.33655 .38884 .34015 .39259 .34593 .39068 .34232 .38704 Mtetra
.648 .738 .915 r
.34232 .38704 .34593 .39068 .35174 .38832 .3481 .38527 Mtetra
.67 .781 .932 r
.3481 .38527 .35174 .38832 .35753 .38654 .35392 .38316 Mtetra
.666 .761 .921 r
.35392 .38316 .35753 .38654 .36334 .38459 .35975 .38112 Mtetra
.651 .751 .923 r
.35975 .38112 .36334 .38459 .36917 .3824 .36557 .37929 Mtetra
.646 .772 .94 r
.36557 .37929 .36917 .3824 .375 .3807 .37141 .37749 Mtetra
.693 .779 .917 r
.37141 .37749 .375 .3807 .38083 .37922 .37729 .37503 Mtetra
.658 .714 .89 r
.37729 .37503 .38083 .37922 .38673 .37647 .38316 .37308 Mtetra
.663 .761 .923 r
.38316 .37308 .38673 .37647 .39255 .37594 .38905 .37107 Mtetra
.632 .673 .871 r
.38905 .37107 .39255 .37594 .39848 .37293 .39493 .36951 Mtetra
.545 .72 .954 r
.39493 .36951 .39848 .37293 .40439 .37083 .40079 .36885 Mtetra
.696 .863 .962 r
.40079 .36885 .40439 .37083 .41028 .36959 .40674 .36624 Mtetra
.621 .752 .94 r
.40674 .36624 .41028 .36959 .41622 .36734 .41266 .36475 Mtetra
.546 .779 .985 r
.41266 .36475 .41622 .36734 .42213 .36629 .41858 .36379 Mtetra
.796 .84 .884 r
.41858 .36379 .42213 .36629 .428 .36716 .42463 .35936 Mtetra
.317 .399 .789 r
.42463 .35936 .428 .36716 .43403 .36344 .43045 .36265 Mtetra
.329 0 0 r
.43045 .36265 .43403 .36344 .43993 .3645 .43633 .36483 Mtetra
.907 .963 .81 r
.43633 .36483 .43993 .3645 .44584 .36666 .4425 .3573 Mtetra
0 .004 .574 r
.4425 .3573 .44584 .36666 .45195 .36075 .44824 .36706 Mtetra
0 0 0 r
.44824 .36706 .45195 .36075 .45776 .36957 .45444 .35882 Mtetra
.398 .386 .729 r
.45444 .35882 .45776 .36957 .46395 .36113 .4604 .36218 Mtetra
.692 .183 .02 r
.4604 .36218 .46395 .36113 .46979 .37259 .46636 .36719 Mtetra
.875 .726 .693 r
.46636 .36719 .46979 .37259 .47612 .35576 .47265 .35436 Mtetra
.807 .917 .912 r
.47265 .35436 .47612 .35576 .48213 .36003 .47879 .34981 Mtetra
.568 .5 .739 r
.47879 .34981 .48213 .36003 .48809 .37243 .48489 .34935 Mtetra
.486 .353 .624 r
.48489 .34935 .48809 .37243 .49413 .38266 .49097 .35278 Mtetra
.357 .241 .582 r
.49097 .35278 .49413 .38266 .50054 .35404 .49701 .36434 Mtetra
0 0 0 r
.49701 .36434 .50054 .35404 .5066 .37016 .50329 .34956 Mtetra
.569 .42 .639 r
.50329 .34956 .5066 .37016 .51282 .36464 .50948 .34857 Mtetra
.28 .248 .643 r
.50948 .34857 .51282 .36464 .51906 .35526 .51565 .35677 Mtetra
.993 .835 .579 r
.51565 .35677 .51906 .35526 .52528 .37083 .52191 .33376 Mtetra
.434 .285 .579 r
.52191 .33376 .52528 .37083 .53152 .35573 .52814 .34315 Mtetra
.71 .558 .681 r
.52814 .34315 .53152 .35573 .53775 .34585 .53437 .33616 Mtetra
.826 .648 .662 r
.53437 .33616 .53775 .34585 .54398 .34085 .54057 .32225 Mtetra
.384 .302 .64 r
.54057 .32225 .54398 .34085 .55019 .33117 .54687 .32883 Mtetra
.727 .216 0 r
.54687 .32883 .55019 .33117 .55655 .33921 .55324 .33703 Mtetra
.95 .816 .677 r
.55324 .33703 .55655 .33921 .56269 .32368 .55942 .32234 Mtetra
.322 0 0 r
.55942 .32234 .56269 .32368 .56906 .3276 .56578 .32527 Mtetra
.883 .861 .815 r
.56578 .32527 .56906 .3276 .57525 .31741 .57203 .31791 Mtetra
.839 .998 .823 r
.57203 .31791 .57525 .31741 .58161 .31826 .57829 .31156 Mtetra
.502 .548 .835 r
.57829 .31156 .58161 .31826 .58781 .30933 .58468 .31214 Mtetra
.713 .925 .591 r
.58468 .31214 .58781 .30933 .59415 .30785 .59091 .30428 Mtetra
.768 .797 .876 r
.59091 .30428 .59415 .30785 .6005 .30552 .59722 .3001 Mtetra
.659 .674 .853 r
.59722 .3001 .6005 .30552 .60686 .30323 .60359 .29786 Mtetra
.647 .671 .859 r
.60359 .29786 .60686 .30323 .61323 .3011 .60998 .29587 Mtetra
.629 .669 .869 r
.60998 .29587 .61323 .3011 .61958 .29758 .61639 .29421 Mtetra
.753 .807 .896 r
.61639 .29421 .61958 .29758 .62598 .29523 .62276 .29044 Mtetra
.623 .688 .889 r
.62276 .29044 .62598 .29523 .63241 .29348 .6292 .28888 Mtetra
.686 .722 .877 r
.6292 .28888 .63241 .29348 .63881 .29018 .63563 .28621 Mtetra
.683 .755 .906 r
.63563 .28621 .63881 .29018 .64527 .28842 .64207 .28367 Mtetra
.624 .691 .892 r
.64207 .28367 .64527 .28842 .65171 .28582 .64857 .28209 Mtetra
.674 .767 .92 r
.64857 .28209 .65171 .28582 .65817 .28309 .65505 .27969 Mtetra
.677 .789 .934 r
.65505 .27969 .65817 .28309 .66467 .2811 .66154 .27723 Mtetra
.663 .756 .919 r
.66154 .27723 .66467 .2811 .67117 .27886 .66805 .27499 Mtetra
.656 .754 .922 r
.66805 .27499 .67117 .27886 .67768 .2764 .67459 .27287 Mtetra
.672 .781 .931 r
.67459 .27287 .67768 .2764 .68423 .27445 .68113 .27048 Mtetra
.689 .761 .907 r
.68113 .27048 .68423 .27445 .69078 .27228 .68767 .2678 Mtetra
.644 .716 .9 r
.68767 .2678 .69078 .27228 .69734 .26987 .69426 .26585 Mtetra
.667 .752 .914 r
.69426 .26585 .69734 .26987 .70391 .26752 .70084 .26353 Mtetra
.678 .758 .911 r
.70084 .26353 .70391 .26752 .71052 .26543 .70744 .26101 Mtetra
.666 .73 .897 r
.70744 .26101 .71052 .26543 .71713 .26323 .71405 .25868 Mtetra
.661 .722 .894 r
.71405 .25868 .71713 .26323 .72376 .261 .72069 .25642 Mtetra
.654 .718 .895 r
.72069 .25642 .72376 .261 .7304 .25861 .72735 .25428 Mtetra
.653 .731 .907 r
.72735 .25428 .7304 .25861 .73703 .25603 .73403 .25216 Mtetra
.671 .765 .921 r
.73403 .25216 .73703 .25603 .74373 .25404 .74071 .24974 Mtetra
.672 .741 .902 r
.74071 .24974 .74373 .25404 .75041 .25175 .7474 .24728 Mtetra
.652 .725 .902 r
.7474 .24728 .75041 .25175 .75711 .24927 .75412 .24516 Mtetra
.672 .753 .912 r
.75412 .24516 .75711 .24927 .76383 .24705 .76084 .24271 Mtetra
.657 .735 .907 r
.76084 .24271 .76383 .24705 .77057 .24482 .7676 .2405 Mtetra
.666 .74 .905 r
.7676 .2405 .77057 .24482 .7773 .24227 .77436 .23813 Mtetra
.672 .753 .912 r
.77436 .23813 .7773 .24227 .78407 .23999 .78112 .23566 Mtetra
.666 .741 .906 r
.78112 .23566 .78407 .23999 .79087 .23785 .78791 .23328 Mtetra
.656 .724 .899 r
.78791 .23328 .79087 .23785 .79767 .23552 .79474 .23106 Mtetra
.632 .72 .911 r
.79474 .23106 .79767 .23552 .80447 .23298 .80161 .22923 Mtetra
.698 .789 .921 r
.80161 .22923 .80447 .23298 .81139 .23158 .8084 .2263 Mtetra
.606 .668 .884 r
.8084 .2263 .81139 .23158 .81816 .22839 .81535 .22494 Mtetra
.721 .816 .925 r
.81535 .22494 .81816 .22839 .82513 .22712 .82214 .22163 Mtetra
.659 .685 .863 r
.82214 .22163 .82513 .22712 .8319 .22366 .82903 .21926 Mtetra
.641 .737 .919 r
.21414 .42609 .21793 .42958 .22346 .4276 .21965 .4245 Mtetra
.678 .77 .92 r
.21965 .4245 .22346 .4276 .22893 .42643 .22522 .42237 Mtetra
.624 .701 .9 r
.22522 .42237 .22893 .42643 .23455 .4238 .23073 .42102 Mtetra
.703 .795 .922 r
.23073 .42102 .23455 .4238 .24005 .42267 .23635 .41852 Mtetra
.64 .702 .891 r
.23635 .41852 .24005 .42267 .24569 .42003 .2419 .41693 Mtetra
.684 .773 .919 r
.2419 .41693 .24569 .42003 .25126 .4183 .24752 .41471 Mtetra
.679 .743 .9 r
.24752 .41471 .25126 .4183 .25686 .41636 .25315 .41253 Mtetra
.655 .725 .9 r
.25315 .41253 .25686 .41636 .26249 .41424 .25876 .41071 Mtetra
.658 .743 .913 r
.25876 .41071 .26249 .41424 .26811 .41233 .26438 .40886 Mtetra
.668 .749 .911 r
.26438 .40886 .26811 .41233 .27373 .41061 .27003 .40685 Mtetra
.657 .73 .903 r
.27003 .40685 .27373 .41061 .27939 .40845 .27568 .40498 Mtetra
.667 .75 .912 r
.27568 .40498 .27939 .40845 .28504 .4067 .28135 .40297 Mtetra
.653 .732 .907 r
.28135 .40297 .28504 .4067 .29073 .40444 .28702 .40116 Mtetra
.683 .766 .914 r
.28702 .40116 .29073 .40444 .29639 .40283 .29273 .39891 Mtetra
.654 .722 .899 r
.29273 .39891 .29639 .40283 .30209 .40087 .29843 .39708 Mtetra
.655 .73 .905 r
.29843 .39708 .30209 .40087 .30781 .39874 .30414 .39523 Mtetra
.664 .749 .914 r
.30414 .39523 .30781 .39874 .31354 .39671 .30987 .39325 Mtetra
.665 .752 .915 r
.30987 .39325 .31354 .39671 .31926 .39486 .31561 .39125 Mtetra
.676 .747 .904 r
.31561 .39125 .31926 .39486 .325 .39301 .32138 .38907 Mtetra
.652 .723 .901 r
.32138 .38907 .325 .39301 .33077 .39089 .32713 .38725 Mtetra
.658 .741 .911 r
.32713 .38725 .33077 .39089 .33655 .38884 .33291 .38534 Mtetra
.666 .752 .915 r
.33291 .38534 .33655 .38884 .34232 .38704 .3387 .38331 Mtetra
.686 .745 .896 r
.3387 .38331 .34232 .38704 .3481 .38527 .34453 .38094 Mtetra
.646 .702 .887 r
.34453 .38094 .3481 .38527 .35392 .38316 .35033 .37918 Mtetra
.657 .724 .898 r
.35033 .37918 .35392 .38316 .35975 .38112 .35616 .37726 Mtetra
.671 .735 .898 r
.35616 .37726 .35975 .38112 .36557 .37929 .36201 .37511 Mtetra
.656 .715 .891 r
.36201 .37511 .36557 .37929 .37141 .37749 .36786 .37318 Mtetra
.598 .687 .904 r
.36786 .37318 .37141 .37749 .37729 .37503 .37368 .37211 Mtetra
.688 .797 .932 r
.37368 .37211 .37729 .37503 .38316 .37308 .37958 .36972 Mtetra
.635 .755 .935 r
.37958 .36972 .38316 .37308 .38905 .37107 .38546 .36806 Mtetra
.723 .799 .911 r
.38546 .36806 .38905 .37107 .39493 .36951 .39141 .36508 Mtetra
.65 .701 .884 r
.39141 .36508 .39493 .36951 .40079 .36885 .39732 .36322 Mtetra
.636 .644 .842 r
.39732 .36322 .40079 .36885 .40674 .36624 .40324 .36153 Mtetra
.643 .687 .876 r
.40324 .36153 .40674 .36624 .41266 .36475 .40918 .35977 Mtetra
.61 .661 .875 r
.40918 .35977 .41266 .36475 .41858 .36379 .41512 .35854 Mtetra
.319 .502 .881 r
.41512 .35854 .41858 .36379 .42463 .35936 .42096 .36055 Mtetra
.374 0 0 r
.42096 .36055 .42463 .35936 .43045 .36265 .42686 .36165 Mtetra
.859 .923 .87 r
.42686 .36165 .43045 .36265 .43633 .36483 .43298 .35586 Mtetra
.432 .441 .768 r
.43298 .35586 .43633 .36483 .4425 .3573 .43889 .35804 Mtetra
.692 .175 0 r
.43889 .35804 .4425 .3573 .44824 .36706 .44476 .36301 Mtetra
.89 .759 .711 r
.44476 .36301 .44824 .36706 .45444 .35882 .45106 .35114 Mtetra
.338 .417 .797 r
.45106 .35114 .45444 .35882 .4604 .36218 .45701 .35416 Mtetra
.287 .376 .78 r
.45701 .35416 .4604 .36218 .46636 .36719 .46299 .35795 Mtetra
.368 .397 .759 r
.46299 .35795 .46636 .36719 .47265 .35436 .46901 .36124 Mtetra
.427 .029 .18 r
.46901 .36124 .47265 .35436 .47879 .34981 .47512 .3606 Mtetra
.4 .062 .273 r
.47512 .3606 .47879 .34981 .48489 .34935 .48128 .3582 Mtetra
0 0 0 r
.48128 .3582 .48489 .34935 .49097 .35278 .48754 .34837 Mtetra
.744 .74 .848 r
.48754 .34837 .49097 .35278 .49701 .36434 .49373 .34447 Mtetra
.741 .541 .622 r
.49373 .34447 .49701 .36434 .50329 .34956 .50001 .32951 Mtetra
.561 .416 .641 r
.50001 .32951 .50329 .34956 .50948 .34857 .50616 .32896 Mtetra
.374 .289 .63 r
.50616 .32896 .50948 .34857 .51565 .35677 .51231 .33604 Mtetra
.385 .291 .626 r
.51231 .33604 .51565 .35677 .52191 .33376 .51851 .34317 Mtetra
.431 .074 .256 r
.51851 .34317 .52191 .33376 .52814 .34315 .52476 .34185 Mtetra
.935 .877 .754 r
.52476 .34185 .52814 .34315 .53437 .33616 .53101 .33174 Mtetra
.551 .672 .918 r
.53101 .33174 .53437 .33616 .54057 .32225 .53727 .33118 Mtetra
.43 .066 .244 r
.53727 .33118 .54057 .32225 .54687 .32883 .54356 .32996 Mtetra
0 0 0 r
.54356 .32996 .54687 .32883 .55324 .33703 .54986 .32871 Mtetra
.794 .653 .706 r
.54986 .32871 .55324 .33703 .55942 .32234 .55611 .31958 Mtetra
.83 .845 .857 r
.55611 .31958 .55942 .32234 .56578 .32527 .56238 .31402 Mtetra
.287 .309 .71 r
.56238 .31402 .56578 .32527 .57203 .31791 .56881 .31976 Mtetra
.959 .943 .648 r
.56881 .31976 .57203 .31791 .57829 .31156 .57499 .30726 Mtetra
.678 .732 .891 r
.57499 .30726 .57829 .31156 .58468 .31214 .58133 .30481 Mtetra
.551 .556 .812 r
.58133 .30481 .58468 .31214 .59091 .30428 .58773 .30463 Mtetra
.781 .997 .852 r
.58773 .30463 .59091 .30428 .59722 .3001 .59404 .29926 Mtetra
.811 .965 .906 r
.59404 .29926 .59722 .3001 .60359 .29786 .60036 .2943 Mtetra
.678 .776 .924 r
.60036 .2943 .60359 .29786 .60998 .29587 .60674 .29187 Mtetra
.658 .744 .913 r
.60674 .29187 .60998 .29587 .61639 .29421 .61315 .28975 Mtetra
.695 .733 .879 r
.61315 .28975 .61639 .29421 .62276 .29044 .61956 .28692 Mtetra
.627 .761 .943 r
.61956 .28692 .62276 .29044 .6292 .28888 .62601 .2852 Mtetra
.718 .783 .903 r
.62601 .2852 .6292 .28888 .63563 .28621 .63243 .28204 Mtetra
.604 .714 .922 r
.63243 .28204 .63563 .28621 .64207 .28367 .63893 .28071 Mtetra
.722 .83 .932 r
.63893 .28071 .64207 .28367 .64857 .28209 .64538 .27755 Mtetra
.68 .726 .884 r
.64538 .27755 .64857 .28209 .65505 .27969 .65186 .27497 Mtetra
.651 .705 .887 r
.65186 .27497 .65505 .27969 .66154 .27723 .65838 .27292 Mtetra
.666 .733 .9 r
.65838 .27292 .66154 .27723 .66805 .27499 .6649 .27061 Mtetra
.677 .734 .894 r
.6649 .27061 .66805 .27499 .67459 .27287 .67143 .26811 Mtetra
.648 .704 .888 r
.67143 .26811 .67459 .27287 .68113 .27048 .67799 .2661 Mtetra
.653 .726 .903 r
.67799 .2661 .68113 .27048 .68767 .2678 .68457 .26401 Mtetra
.683 .771 .918 r
.68457 .26401 .68767 .2678 .69426 .26585 .69114 .26142 Mtetra
.653 .724 .901 r
.69114 .26142 .69426 .26585 .70084 .26353 .69775 .25932 Mtetra
.658 .738 .909 r
.69775 .25932 .70084 .26353 .70744 .26101 .70437 .25713 Mtetra
.666 .761 .921 r
.70437 .25713 .70744 .26101 .71405 .25868 .711 .25479 Mtetra
.662 .76 .923 r
.711 .25479 .71405 .25868 .72069 .25642 .71765 .25252 Mtetra
.667 .761 .921 r
.71765 .25252 .72069 .25642 .72735 .25428 .72431 .25017 Mtetra
.677 .754 .909 r
.72431 .25017 .72735 .25428 .73403 .25216 .73098 .24763 Mtetra
.659 .725 .898 r
.73098 .24763 .73403 .25216 .74071 .24974 .73767 .24538 Mtetra
.652 .732 .908 r
.73767 .24538 .74071 .24974 .7474 .24728 .7444 .24326 Mtetra
.683 .763 .912 r
.7444 .24326 .7474 .24728 .75412 .24516 .7511 .24061 Mtetra
.646 .72 .902 r
.7511 .24061 .75412 .24516 .76084 .24271 .75786 .23858 Mtetra
.676 .755 .911 r
.75786 .23858 .76084 .24271 .7676 .2405 .7646 .23603 Mtetra
.657 .73 .903 r
.7646 .23603 .7676 .2405 .77436 .23813 .77138 .2338 Mtetra
.662 .739 .908 r
.77138 .2338 .77436 .23813 .78112 .23566 .77818 .23149 Mtetra
.676 .755 .91 r
.77818 .23149 .78112 .23566 .78791 .23328 .78496 .22893 Mtetra
.657 .738 .909 r
.78496 .22893 .78791 .23328 .79474 .23106 .79179 .22669 Mtetra
.65 .734 .911 r
.79179 .22669 .79474 .23106 .80161 .22923 .79865 .22455 Mtetra
.638 .713 .901 r
.79865 .22455 .80161 .22923 .8084 .2263 .80555 .22261 Mtetra
.689 .791 .928 r
.80555 .22261 .8084 .2263 .81535 .22494 .81238 .21982 Mtetra
.638 .692 .884 r
.81238 .21982 .81535 .22494 .82214 .22163 .81931 .21788 Mtetra
.691 .789 .925 r
.81931 .21788 .82214 .22163 .82903 .21926 .82617 .21504 Mtetra
.648 .729 .909 r
.21036 .42242 .21414 .42609 .21965 .4245 .21588 .42073 Mtetra
.646 .724 .905 r
.21588 .42073 .21965 .4245 .22522 .42237 .22142 .41906 Mtetra
.662 .755 .919 r
.22142 .41906 .22522 .42237 .23073 .42102 .22698 .41715 Mtetra
.659 .723 .896 r
.22698 .41715 .23073 .42102 .23635 .41852 .23255 .41527 Mtetra
.668 .761 .92 r
.23255 .41527 .23635 .41852 .2419 .41693 .23815 .41328 Mtetra
.688 .743 .893 r
.23815 .41328 .2419 .41693 .24752 .41471 .24379 .41094 Mtetra
.658 .729 .902 r
.24379 .41094 .24752 .41471 .25315 .41253 .2494 .40907 Mtetra
.661 .747 .914 r
.2494 .40907 .25315 .41253 .25876 .41071 .25502 .40716 Mtetra
.664 .744 .909 r
.25502 .40716 .25876 .41071 .26438 .40886 .26066 .4052 Mtetra
.664 .738 .905 r
.26066 .4052 .26438 .40886 .27003 .40685 .26631 .40324 Mtetra
.657 .74 .911 r
.26631 .40324 .27003 .40685 .27568 .40498 .27196 .40137 Mtetra
.672 .744 .905 r
.27196 .40137 .27568 .40498 .28135 .40297 .27765 .39928 Mtetra
.657 .735 .908 r
.27765 .39928 .28135 .40297 .28702 .40116 .28333 .39741 Mtetra
.654 .732 .906 r
.28333 .39741 .28702 .40116 .29273 .39891 .28902 .39557 Mtetra
.676 .762 .916 r
.28902 .39557 .29273 .39891 .29843 .39708 .29474 .39341 Mtetra
.673 .743 .903 r
.29474 .39341 .29843 .39708 .30414 .39523 .30048 .39129 Mtetra
.665 .726 .895 r
.30048 .39129 .30414 .39523 .30987 .39325 .30622 .38927 Mtetra
.659 .723 .896 r
.30622 .38927 .30987 .39325 .31561 .39125 .31196 .38734 Mtetra
.653 .725 .901 r
.31196 .38734 .31561 .39125 .32138 .38907 .31772 .38549 Mtetra
.655 .745 .916 r
.31772 .38549 .32138 .38907 .32713 .38725 .32348 .38361 Mtetra
.683 .749 .901 r
.32348 .38361 .32713 .38725 .33291 .38534 .32929 .3813 Mtetra
.631 .712 .905 r
.32929 .3813 .33291 .38534 .3387 .38331 .33506 .37977 Mtetra
.674 .753 .91 r
.33506 .37977 .3387 .38331 .34453 .38094 .34088 .37759 Mtetra
.682 .768 .916 r
.34088 .37759 .34453 .38094 .35033 .37918 .34672 .3753 Mtetra
.668 .733 .899 r
.34672 .3753 .35033 .37918 .35616 .37726 .35257 .37321 Mtetra
.655 .721 .897 r
.35257 .37321 .35616 .37726 .36201 .37511 .35841 .3713 Mtetra
.635 .728 .915 r
.35841 .3713 .36201 .37511 .36786 .37318 .36425 .36969 Mtetra
.668 .757 .917 r
.36425 .36969 .36786 .37318 .37368 .37211 .37013 .36759 Mtetra
.645 .695 .882 r
.37013 .36759 .37368 .37211 .37958 .36972 .37601 .36582 Mtetra
.681 .739 .895 r
.37601 .36582 .37958 .36972 .38546 .36806 .38193 .36349 Mtetra
.539 .651 .907 r
.38193 .36349 .38546 .36806 .39141 .36508 .38777 .36315 Mtetra
.662 .861 .975 r
.38777 .36315 .39141 .36508 .39732 .36322 .39371 .3609 Mtetra
.634 .827 .975 r
.39371 .3609 .39732 .36322 .40324 .36153 .39965 .35904 Mtetra
.472 .758 .993 r
.39965 .35904 .40324 .36153 .40918 .35977 .40555 .35858 Mtetra
.296 .754 .953 r
.40555 .35858 .40918 .35977 .41512 .35854 .41146 .35826 Mtetra
.196 .722 .845 r
.41146 .35826 .41512 .35854 .42096 .36055 .4174 .35767 Mtetra
.745 .816 .907 r
.4174 .35767 .42096 .36055 .42686 .36165 .42345 .35426 Mtetra
.676 .612 .776 r
.42345 .35426 .42686 .36165 .43298 .35586 .4295 .3512 Mtetra
.583 .133 0 r
.4295 .3512 .43298 .35586 .43889 .35804 .43525 .35907 Mtetra
0 0 0 r
.43525 .35907 .43889 .35804 .44476 .36301 .4413 .35738 Mtetra
.851 .717 .714 r
.4413 .35738 .44476 .36301 .45106 .35114 .44758 .3468 Mtetra
.669 .718 .885 r
.44758 .3468 .45106 .35114 .45701 .35416 .45366 .34457 Mtetra
.352 .379 .749 r
.45366 .34457 .45701 .35416 .46299 .35795 .45963 .3482 Mtetra
.449 .436 .753 r
.45963 .3482 .46299 .35795 .46901 .36124 .46566 .3503 Mtetra
.726 .583 .694 r
.46566 .3503 .46901 .36124 .47512 .3606 .47188 .3433 Mtetra
.643 .485 .653 r
.47188 .3433 .47512 .3606 .48128 .3582 .47806 .33845 Mtetra
.439 .333 .637 r
.47806 .33845 .48128 .3582 .48754 .34837 .48411 .34318 Mtetra
.866 .734 .714 r
.48411 .34318 .48754 .34837 .49373 .34447 .49039 .33216 Mtetra
.461 .406 .709 r
.49039 .33216 .49373 .34447 .50001 .32951 .49652 .3346 Mtetra
.446 .006 .107 r
.49652 .3346 .50001 .32951 .50616 .32896 .50269 .33483 Mtetra
0 0 0 r
.50269 .33483 .50616 .32896 .51231 .33604 .50893 .32776 Mtetra
.333 .4 .782 r
.50893 .32776 .51231 .33604 .51851 .34317 .51513 .33119 Mtetra
.712 .565 .687 r
.51513 .33119 .51851 .34317 .52476 .34185 .52137 .32441 Mtetra
.433 .343 .654 r
.52137 .32441 .52476 .34185 .53101 .33174 .52763 .32888 Mtetra
0 .228 .689 r
.52763 .32888 .53101 .33174 .53727 .33118 .53392 .33298 Mtetra
.395 .82 .647 r
.53392 .33298 .53727 .33118 .54356 .32996 .54021 .32926 Mtetra
.949 .9 .743 r
.54021 .32926 .54356 .32996 .54986 .32871 .54647 .31875 Mtetra
.742 .605 .704 r
.54647 .31875 .54986 .32871 .55611 .31958 .55273 .31149 Mtetra
.602 .563 .783 r
.55273 .31149 .55611 .31958 .56238 .31402 .55906 .31022 Mtetra
0 .343 .815 r
.55906 .31022 .56238 .31402 .56881 .31976 .56546 .31399 Mtetra
.741 .693 .806 r
.56546 .31399 .56881 .31976 .57499 .30726 .57179 .30952 Mtetra
.906 .965 .649 r
.57179 .30952 .57499 .30726 .58133 .30481 .57801 .29895 Mtetra
.657 .657 .838 r
.57801 .29895 .58133 .30481 .58773 .30463 .58437 .29667 Mtetra
.563 .546 .794 r
.58437 .29667 .58773 .30463 .59404 .29926 .59079 .29627 Mtetra
.72 .823 .929 r
.59079 .29627 .59404 .29926 .60036 .2943 .59716 .29316 Mtetra
.75 .947 .944 r
.59716 .29316 .60036 .2943 .60674 .29187 .60353 .28924 Mtetra
.694 .842 .954 r
.60353 .28924 .60674 .29187 .61315 .28975 .60994 .28649 Mtetra
.691 .8 .933 r
.60994 .28649 .61315 .28975 .61956 .28692 .61636 .28383 Mtetra
.754 .827 .909 r
.61636 .28383 .61956 .28692 .62601 .2852 .62276 .28008 Mtetra
.626 .676 .877 r
.62276 .28008 .62601 .2852 .63243 .28204 .62924 .27844 Mtetra
.707 .786 .913 r
.62924 .27844 .63243 .28204 .63893 .28071 .63569 .27549 Mtetra
.643 .679 .87 r
.63569 .27549 .63893 .28071 .64538 .27755 .64219 .27355 Mtetra
.689 .759 .905 r
.64219 .27355 .64538 .27755 .65186 .27497 .64868 .27088 Mtetra
.675 .749 .907 r
.64868 .27088 .65186 .27497 .65838 .27292 .65519 .26843 Mtetra
.66 .723 .895 r
.65519 .26843 .65838 .27292 .6649 .27061 .66173 .26621 Mtetra
.648 .723 .903 r
.66173 .26621 .6649 .27061 .67143 .26811 .66829 .26419 Mtetra
.648 .75 .924 r
.66829 .26419 .67143 .26811 .67799 .2661 .67487 .26216 Mtetra
.686 .764 .911 r
.67487 .26216 .67799 .2661 .68457 .26401 .68143 .25951 Mtetra
.652 .721 .899 r
.68143 .25951 .68457 .26401 .69114 .26142 .68804 .25742 Mtetra
.68 .759 .911 r
.68804 .25742 .69114 .26142 .69775 .25932 .69463 .25486 Mtetra
.666 .729 .897 r
.69463 .25486 .69775 .25932 .70437 .25713 .70126 .25251 Mtetra
.655 .718 .894 r
.70126 .25251 .70437 .25713 .711 .25479 .70791 .25034 Mtetra
.664 .73 .899 r
.70791 .25034 .711 .25479 .71765 .25252 .71456 .24802 Mtetra
.666 .729 .896 r
.71456 .24802 .71765 .25252 .72431 .25017 .72123 .24565 Mtetra
.655 .724 .9 r
.72123 .24565 .72431 .25017 .73098 .24763 .72793 .24347 Mtetra
.656 .744 .915 r
.72793 .24347 .73098 .24763 .73767 .24538 .73464 .24127 Mtetra
.681 .757 .909 r
.73464 .24127 .73767 .24538 .7444 .24326 .74135 .23866 Mtetra
.65 .719 .899 r
.74135 .23866 .7444 .24326 .7511 .24061 .7481 .23656 Mtetra
.675 .76 .914 r
.7481 .23656 .7511 .24061 .75786 .23858 .75484 .23403 Mtetra
.646 .721 .903 r
.75484 .23403 .75786 .23858 .7646 .23603 .76163 .23198 Mtetra
.68 .763 .914 r
.76163 .23198 .7646 .23603 .77138 .2338 .76839 .22936 Mtetra
.661 .735 .904 r
.76839 .22936 .77138 .2338 .77818 .23149 .77519 .22705 Mtetra
.667 .738 .903 r
.77519 .22705 .77818 .23149 .78496 .22893 .78201 .22462 Mtetra
.65 .738 .914 r
.78201 .22462 .78496 .22893 .79179 .22669 .78886 .22248 Mtetra
.667 .751 .913 r
.78886 .22248 .79179 .22669 .79865 .22455 .7957 .22006 Mtetra
.642 .726 .909 r
.7957 .22006 .79865 .22455 .80555 .22261 .8026 .21804 Mtetra
.66 .73 .901 r
.8026 .21804 .80555 .22261 .81238 .21982 .80949 .21571 Mtetra
.662 .757 .921 r
.80949 .21571 .81238 .21982 .81931 .21788 .81639 .21335 Mtetra
.702 .751 .889 r
.81639 .21335 .81931 .21788 .82617 .21504 .82323 .21022 Mtetra
.66 .748 .915 r
.20654 .41901 .21036 .42242 .21588 .42073 .21209 .41713 Mtetra
.64 .732 .915 r
.21209 .41713 .21588 .42073 .22142 .41906 .21762 .41553 Mtetra
.676 .746 .904 r
.21762 .41553 .22142 .41906 .22698 .41715 .22321 .41342 Mtetra
.643 .726 .909 r
.22321 .41342 .22698 .41715 .23255 .41527 .22877 .41177 Mtetra
.695 .753 .896 r
.22877 .41177 .23255 .41527 .23815 .41328 .23441 .40934 Mtetra
.647 .717 .899 r
.23441 .40934 .23815 .41328 .24379 .41094 .24 .40763 Mtetra
.68 .762 .913 r
.24 .40763 .24379 .41094 .2494 .40907 .24564 .40544 Mtetra
.666 .74 .906 r
.24564 .40544 .2494 .40907 .25502 .40716 .25128 .40344 Mtetra
.663 .735 .903 r
.25128 .40344 .25502 .40716 .26066 .4052 .25692 .40149 Mtetra
.646 .731 .911 r
.25692 .40149 .26066 .4052 .26631 .40324 .26256 .39979 Mtetra
.682 .756 .907 r
.26256 .39979 .26631 .40324 .27196 .40137 .26825 .39754 Mtetra
.644 .725 .907 r
.26825 .39754 .27196 .40137 .27765 .39928 .27391 .39585 Mtetra
.677 .757 .911 r
.27391 .39585 .27765 .39928 .28333 .39741 .27962 .39366 Mtetra
.662 .735 .904 r
.27962 .39366 .28333 .39741 .28902 .39557 .28533 .3917 Mtetra
.652 .726 .903 r
.28533 .3917 .28902 .39557 .29474 .39341 .29103 .38989 Mtetra
.666 .75 .913 r
.29103 .38989 .29474 .39341 .30048 .39129 .29677 .38787 Mtetra
.665 .756 .918 r
.29677 .38787 .30048 .39129 .30622 .38927 .30251 .38586 Mtetra
.655 .754 .923 r
.30251 .38586 .30622 .38927 .31196 .38734 .30826 .38398 Mtetra
.663 .761 .923 r
.30826 .38398 .31196 .38734 .31772 .38549 .31403 .38199 Mtetra
.686 .758 .906 r
.31403 .38199 .31772 .38549 .32348 .38361 .31984 .37963 Mtetra
.637 .718 .906 r
.31984 .37963 .32348 .38361 .32929 .3813 .32561 .37801 Mtetra
.689 .773 .915 r
.32561 .37801 .32929 .3813 .33506 .37977 .33144 .37561 Mtetra
.642 .711 .897 r
.33144 .37561 .33506 .37977 .34088 .37759 .33724 .37391 Mtetra
.65 .74 .915 r
.33724 .37391 .34088 .37759 .34672 .3753 .34306 .37208 Mtetra
.654 .77 .934 r
.34306 .37208 .34672 .3753 .35257 .37321 .3489 .37017 Mtetra
.652 .781 .943 r
.3489 .37017 .35257 .37321 .35841 .3713 .35475 .36827 Mtetra
.674 .787 .934 r
.35475 .36827 .35841 .3713 .36425 .36969 .36064 .36607 Mtetra
.682 .754 .906 r
.36064 .36607 .36425 .36969 .37013 .36759 .36654 .36374 Mtetra
.594 .714 .927 r
.36654 .36374 .37013 .36759 .37601 .36582 .37239 .36264 Mtetra
.717 .788 .908 r
.37239 .36264 .37601 .36582 .38193 .36349 .37834 .35973 Mtetra
.672 .745 .906 r
.37834 .35973 .38193 .36349 .38777 .36315 .38427 .35755 Mtetra
.561 .613 .862 r
.38427 .35755 .38777 .36315 .39371 .3609 .39014 .35707 Mtetra
.536 .694 .941 r
.39014 .35707 .39371 .3609 .39965 .35904 .39603 .35658 Mtetra
.606 .811 .979 r
.39603 .35658 .39965 .35904 .40555 .35858 .40198 .35502 Mtetra
.613 .741 .937 r
.40198 .35502 .40555 .35858 .41146 .35826 .40794 .35363 Mtetra
.678 .705 .868 r
.40794 .35363 .41146 .35826 .4174 .35767 .41395 .35121 Mtetra
.695 .645 .796 r
.41395 .35121 .4174 .35767 .42345 .35426 .42 .34789 Mtetra
0 .168 .705 r
.42 .34789 .42345 .35426 .4295 .3512 .42577 .35384 Mtetra
.613 .126 .074 r
.42577 .35384 .4295 .3512 .43525 .35907 .43166 .35714 Mtetra
.861 .87 .844 r
.43166 .35714 .43525 .35907 .4413 .35738 .43785 .35085 Mtetra
.793 .682 .742 r
.43785 .35085 .4413 .35738 .44758 .3468 .44407 .34344 Mtetra
.696 .781 .917 r
.44407 .34344 .44758 .3468 .45366 .34457 .45016 .34083 Mtetra
.629 .739 .926 r
.45016 .34083 .45366 .34457 .45963 .3482 .45625 .33921 Mtetra
.464 .461 .77 r
.45625 .33921 .45963 .3482 .46566 .3503 .46229 .34082 Mtetra
.265 .327 .74 r
.46229 .34082 .46566 .3503 .47188 .3433 .4683 .3456 Mtetra
.788 .979 .704 r
.4683 .3456 .47188 .3433 .47806 .33845 .47454 .33833 Mtetra
.917 .947 .803 r
.47454 .33833 .47806 .33845 .48411 .34318 .48078 .33035 Mtetra
.526 .441 .703 r
.48078 .33035 .48411 .34318 .49039 .33216 .48691 .3311 Mtetra
.172 .683 .898 r
.48691 .3311 .49039 .33216 .49652 .3346 .49307 .33122 Mtetra
.741 .795 .896 r
.49307 .33122 .49652 .3346 .50269 .33483 .49929 .32774 Mtetra
.598 .585 .81 r
.49929 .32774 .50269 .33483 .50893 .32776 .5055 .32663 Mtetra
.873 .927 .857 r
.5055 .32663 .50893 .32776 .51513 .33119 .51175 .32031 Mtetra
.348 .355 .725 r
.51175 .32031 .51513 .33119 .52137 .32441 .51797 .32462 Mtetra
.715 .984 .892 r
.51797 .32462 .52137 .32441 .52763 .32888 .52423 .32034 Mtetra
.736 .622 .732 r
.52423 .32034 .52763 .32888 .53392 .33298 .5305 .31438 Mtetra
.559 .422 .651 r
.5305 .31438 .53392 .33298 .54021 .32926 .53679 .31389 Mtetra
.634 .49 .67 r
.53679 .31389 .54021 .32926 .54647 .31875 .54308 .31007 Mtetra
.712 .609 .74 r
.54308 .31007 .54647 .31875 .55273 .31149 .54937 .30513 Mtetra
.556 .589 .843 r
.54937 .30513 .55273 .31149 .55906 .31022 .5557 .30476 Mtetra
.174 .408 .848 r
.5557 .30476 .55906 .31022 .56546 .31399 .56211 .30824 Mtetra
.505 .588 .872 r
.56211 .30824 .56546 .31399 .57179 .30952 .5685 .30852 Mtetra
.915 .925 .806 r
.5685 .30852 .57179 .30952 .57801 .29895 .57479 .30048 Mtetra
.851 .99 .726 r
.57479 .30048 .57801 .29895 .58437 .29667 .58108 .29252 Mtetra
.721 .756 .881 r
.58108 .29252 .58437 .29667 .59079 .29627 .58744 .28923 Mtetra
.657 .62 .801 r
.58744 .28923 .59079 .29627 .59716 .29316 .59384 .2867 Mtetra
.645 .632 .823 r
.59384 .2867 .59716 .29316 .60353 .28924 .60025 .28459 Mtetra
.725 .735 .859 r
.60025 .28459 .60353 .28924 .60994 .28649 .60665 .28105 Mtetra
.684 .687 .846 r
.60665 .28105 .60994 .28649 .61636 .28383 .61307 .27823 Mtetra
.629 .657 .858 r
.61307 .27823 .61636 .28383 .62276 .28008 .61954 .27652 Mtetra
.644 .768 .939 r
.61954 .27652 .62276 .28008 .62924 .27844 .62603 .27455 Mtetra
.704 .769 .903 r
.62603 .27455 .62924 .27844 .63569 .27549 .63249 .27162 Mtetra
.664 .757 .919 r
.63249 .27162 .63569 .27549 .64219 .27355 .63899 .26935 Mtetra
.645 .732 .912 r
.63899 .26935 .64219 .27355 .64868 .27088 .64552 .26738 Mtetra
.671 .783 .934 r
.64552 .26738 .64868 .27088 .65519 .26843 .65204 .265 Mtetra
.671 .788 .937 r
.65204 .265 .65519 .26843 .66173 .26621 .65858 .2626 Mtetra
.674 .779 .929 r
.65858 .2626 .66173 .26621 .66829 .26419 .66514 .26016 Mtetra
.687 .759 .907 r
.66514 .26016 .66829 .26419 .67487 .26216 .6717 .25749 Mtetra
.642 .708 .895 r
.6717 .25749 .67487 .26216 .68143 .25951 .6783 .25555 Mtetra
.682 .763 .913 r
.6783 .25555 .68143 .25951 .68804 .25742 .6849 .25296 Mtetra
.641 .72 .905 r
.6849 .25296 .68804 .25742 .69463 .25486 .69154 .25103 Mtetra
.675 .769 .921 r
.69154 .25103 .69463 .25486 .70126 .25251 .69816 .24854 Mtetra
.675 .761 .916 r
.69816 .24854 .70126 .25251 .70791 .25034 .70481 .24604 Mtetra
.661 .739 .907 r
.70481 .24604 .70791 .25034 .71456 .24802 .71148 .24377 Mtetra
.657 .74 .911 r
.71148 .24377 .71456 .24802 .72123 .24565 .71817 .24156 Mtetra
.664 .752 .916 r
.71817 .24156 .72123 .24565 .72793 .24347 .72487 .23924 Mtetra
.679 .75 .905 r
.72487 .23924 .72793 .24347 .73464 .24127 .73157 .23665 Mtetra
.649 .718 .899 r
.73157 .23665 .73464 .24127 .74135 .23866 .73832 .23455 Mtetra
.668 .754 .915 r
.73832 .23455 .74135 .23866 .7481 .23656 .74506 .23214 Mtetra
.658 .734 .906 r
.74506 .23214 .7481 .23656 .75484 .23403 .75183 .22988 Mtetra
.673 .755 .913 r
.75183 .22988 .75484 .23403 .76163 .23198 .7586 .22737 Mtetra
.653 .723 .9 r
.7586 .22737 .76163 .23198 .76839 .22936 .76541 .22519 Mtetra
.676 .756 .911 r
.76541 .22519 .76839 .22936 .77519 .22705 .7722 .22262 Mtetra
.669 .74 .903 r
.7722 .22262 .77519 .22705 .78201 .22462 .77902 .22015 Mtetra
.657 .733 .906 r
.77902 .22015 .78201 .22462 .78886 .22248 .78587 .21788 Mtetra
.638 .718 .906 r
.78587 .21788 .78886 .22248 .7957 .22006 .79277 .21593 Mtetra
.681 .763 .914 r
.79277 .21593 .7957 .22006 .8026 .21804 .79962 .21325 Mtetra
.627 .705 .902 r
.79962 .21325 .8026 .21804 .80949 .21571 .80658 .21148 Mtetra
.701 .766 .903 r
.80658 .21148 .80949 .21571 .81639 .21335 .81342 .20842 Mtetra
.656 .712 .889 r
.81342 .20842 .81639 .21335 .82323 .21022 .82036 .20613 Mtetra
.64 .727 .911 r
.20273 .4153 .20654 .41901 .21209 .41713 .20826 .41369 Mtetra
.679 .752 .907 r
.20826 .41369 .21209 .41713 .21762 .41553 .21385 .41153 Mtetra
.624 .706 .905 r
.21385 .41153 .21762 .41553 .22321 .41342 .21938 .41015 Mtetra
.699 .767 .905 r
.21938 .41015 .22321 .41342 .22877 .41177 .22502 .40766 Mtetra
.635 .704 .896 r
.22502 .40766 .22877 .41177 .23441 .40934 .23059 .40612 Mtetra
.685 .768 .915 r
.23059 .40612 .23441 .40934 .24 .40763 .23623 .40385 Mtetra
.672 .734 .896 r
.23623 .40385 .24 .40763 .24564 .40544 .24187 .40175 Mtetra
.658 .735 .907 r
.24187 .40175 .24564 .40544 .25128 .40344 .24751 .39986 Mtetra
.656 .742 .913 r
.24751 .39986 .25128 .40344 .25692 .40149 .25315 .39801 Mtetra
.673 .752 .91 r
.25315 .39801 .25692 .40149 .26256 .39979 .25882 .3959 Mtetra
.65 .724 .903 r
.25882 .3959 .26256 .39979 .26825 .39754 .26449 .39412 Mtetra
.677 .758 .912 r
.26449 .39412 .26825 .39754 .27391 .39585 .27019 .39194 Mtetra
.644 .721 .904 r
.27019 .39194 .27391 .39585 .27962 .39366 .27587 .39024 Mtetra
.677 .758 .912 r
.27587 .39024 .27962 .39366 .28533 .3917 .2816 .38806 Mtetra
.67 .744 .906 r
.2816 .38806 .28533 .3917 .29103 .38989 .28734 .38597 Mtetra
.656 .726 .9 r
.28734 .38597 .29103 .38989 .29677 .38787 .29307 .38408 Mtetra
.664 .736 .903 r
.29307 .38408 .29677 .38787 .30251 .38586 .29882 .38206 Mtetra
.667 .737 .902 r
.29882 .38206 .30251 .38586 .30826 .38398 .30459 .38 Mtetra
.669 .727 .893 r
.30459 .38 .30826 .38398 .31403 .38199 .31037 .37788 Mtetra
.646 .714 .897 r
.31037 .37788 .31403 .38199 .31984 .37963 .31615 .37612 Mtetra
.66 .752 .919 r
.31615 .37612 .31984 .37963 .32561 .37801 .32194 .37416 Mtetra
.661 .734 .904 r
.32194 .37416 .32561 .37801 .33144 .37561 .32776 .37218 Mtetra
.686 .764 .911 r
.32776 .37218 .33144 .37561 .33724 .37391 .33361 .36981 Mtetra
.647 .716 .899 r
.33361 .36981 .33724 .37391 .34306 .37208 .33943 .36802 Mtetra
.657 .723 .897 r
.33943 .36802 .34306 .37208 .3489 .37017 .34528 .36607 Mtetra
.673 .726 .889 r
.34528 .36607 .3489 .37017 .35475 .36827 .35116 .36386 Mtetra
.658 .706 .882 r
.35116 .36386 .35475 .36827 .36064 .36607 .35703 .36187 Mtetra
.619 .703 .905 r
.35703 .36187 .36064 .36607 .36654 .36374 .36289 .36048 Mtetra
.708 .782 .91 r
.36289 .36048 .36654 .36374 .37239 .36264 .36883 .35773 Mtetra
.534 .633 .895 r
.36883 .35773 .37239 .36264 .37834 .35973 .37467 .3575 Mtetra
.697 .848 .955 r
.37467 .3575 .37834 .35973 .38427 .35755 .38063 .35489 Mtetra
.718 .824 .93 r
.38063 .35489 .38427 .35755 .39014 .35707 .38661 .35199 Mtetra
.634 .668 .865 r
.38661 .35199 .39014 .35707 .39603 .35658 .39255 .35034 Mtetra
.599 .609 .833 r
.39255 .35034 .39603 .35658 .40198 .35502 .39849 .34927 Mtetra
.611 .632 .847 r
.39849 .34927 .40198 .35502 .40794 .35363 .40444 .34799 Mtetra
.617 .64 .85 r
.40444 .34799 .40794 .35363 .41395 .35121 .41042 .3466 Mtetra
0 .291 .788 r
.41042 .3466 .41395 .35121 .42 .34789 .41623 .35068 Mtetra
.586 .097 .061 r
.41623 .35068 .42 .34789 .42577 .35384 .42211 .3535 Mtetra
.722 .966 .938 r
.42211 .3535 .42577 .35384 .43166 .35714 .42823 .34981 Mtetra
.729 .639 .758 r
.42823 .34981 .43166 .35714 .43785 .35085 .43438 .34487 Mtetra
.527 .586 .857 r
.43438 .34487 .43785 .35085 .44407 .34344 .44041 .3449 Mtetra
.3 0 0 r
.44041 .3449 .44407 .34344 .45016 .34083 .44645 .34539 Mtetra
.382 0 .036 r
.44645 .34539 .45016 .34083 .45625 .33921 .45253 .34501 Mtetra
.307 0 .064 r
.45253 .34501 .45625 .33921 .46229 .34082 .45866 .3432 Mtetra
.959 .946 .664 r
.45866 .3432 .46229 .34082 .4683 .3456 .46501 .33087 Mtetra
.561 .446 .68 r
.46501 .33087 .4683 .3456 .47454 .33833 .47113 .33045 Mtetra
.661 .597 .772 r
.47113 .33045 .47454 .33833 .48078 .33035 .4773 .32763 Mtetra
.647 .814 .963 r
.4773 .32763 .48078 .33035 .48691 .3311 .48348 .3256 Mtetra
.775 .709 .79 r
.48348 .3256 .48691 .3311 .49307 .33122 .48971 .32007 Mtetra
.616 .517 .719 r
.48971 .32007 .49307 .33122 .49929 .32774 .4959 .31798 Mtetra
.591 .523 .747 r
.4959 .31798 .49929 .32774 .5055 .32663 .50211 .31686 Mtetra
.485 .46 .755 r
.50211 .31686 .5055 .32663 .51175 .32031 .50832 .31823 Mtetra
.822 .883 .888 r
.50832 .31823 .51175 .32031 .51797 .32462 .51458 .3132 Mtetra
.501 .444 .725 r
.51458 .3132 .51797 .32462 .52423 .32034 .52083 .31447 Mtetra
0 .234 .751 r
.52083 .31447 .52423 .32034 .5305 .31438 .52712 .31996 Mtetra
0 0 0 r
.52712 .31996 .5305 .31438 .53679 .31389 .53342 .31325 Mtetra
.873 .957 .857 r
.53342 .31325 .53679 .31389 .54308 .31007 .53971 .30687 Mtetra
.71 .804 .924 r
.53971 .30687 .54308 .31007 .54937 .30513 .54603 .30394 Mtetra
.724 .937 .957 r
.54603 .30394 .54937 .30513 .5557 .30476 .55235 .30043 Mtetra
.452 .633 .932 r
.55235 .30043 .5557 .30476 .56211 .30824 .55872 .30086 Mtetra
.324 .424 .81 r
.55872 .30086 .56211 .30824 .5685 .30852 .56516 .30401 Mtetra
.677 .724 .885 r
.56516 .30401 .5685 .30852 .57479 .30048 .57155 .30152 Mtetra
.885 .991 .756 r
.57155 .30152 .57479 .30048 .58108 .29252 .57785 .29341 Mtetra
.789 .998 .8 r
.57785 .29341 .58108 .29252 .58744 .28923 .58418 .28729 Mtetra
.758 .901 .94 r
.58418 .28729 .58744 .28923 .59384 .2867 .59057 .28349 Mtetra
.729 .814 .917 r
.59057 .28349 .59384 .2867 .60025 .28459 .59697 .28019 Mtetra
.692 .737 .885 r
.59697 .28019 .60025 .28459 .60665 .28105 .60339 .27741 Mtetra
.602 .747 .946 r
.60339 .27741 .60665 .28105 .61307 .27823 .60987 .27599 Mtetra
.682 .868 .969 r
.60987 .27599 .61307 .27823 .61954 .27652 .61632 .27329 Mtetra
.745 .819 .91 r
.61632 .27329 .61954 .27652 .62603 .27455 .62276 .26966 Mtetra
.639 .694 .885 r
.62276 .26966 .62603 .27455 .63249 .27162 .62927 .26779 Mtetra
.695 .772 .911 r
.62927 .26779 .63249 .27162 .63899 .26935 .63577 .26501 Mtetra
.679 .739 .896 r
.63577 .26501 .63899 .26935 .64552 .26738 .64228 .26246 Mtetra
.648 .697 .882 r
.64228 .26246 .64552 .26738 .65204 .265 .64883 .26042 Mtetra
.665 .722 .891 r
.64883 .26042 .65204 .265 .65858 .2626 .65539 .25809 Mtetra
.678 .731 .89 r
.65539 .25809 .65858 .2626 .66514 .26016 .66194 .25554 Mtetra
.648 .714 .896 r
.66194 .25554 .66514 .26016 .6717 .25749 .66854 .25349 Mtetra
.656 .752 .92 r
.66854 .25349 .6717 .25749 .6783 .25555 .67515 .25132 Mtetra
.68 .748 .902 r
.67515 .25132 .6783 .25555 .6849 .25296 .68175 .24874 Mtetra
.663 .743 .909 r
.68175 .24874 .6849 .25296 .69154 .25103 .68839 .24644 Mtetra
.657 .721 .896 r
.68839 .24644 .69154 .25103 .69816 .24854 .69504 .24422 Mtetra
.661 .737 .907 r
.69504 .24422 .69816 .24854 .70481 .24604 .70171 .24195 Mtetra
.661 .751 .916 r
.70171 .24195 .70481 .24604 .71148 .24377 .70839 .23966 Mtetra
.669 .754 .914 r
.70839 .23966 .71148 .24377 .71817 .24156 .71508 .23724 Mtetra
.674 .744 .903 r
.71508 .23724 .71817 .24156 .72487 .23924 .72178 .23472 Mtetra
.653 .726 .902 r
.72178 .23472 .72487 .23924 .73157 .23665 .72852 .23255 Mtetra
.661 .752 .918 r
.72852 .23255 .73157 .23665 .73832 .23455 .73526 .23025 Mtetra
.676 .747 .905 r
.73526 .23025 .73832 .23455 .74506 .23214 .74201 .22769 Mtetra
.653 .731 .906 r
.74201 .22769 .74506 .23214 .75183 .22988 .74879 .2255 Mtetra
.665 .74 .906 r
.74879 .2255 .75183 .22988 .7586 .22737 .75558 .2231 Mtetra
.67 .749 .91 r
.75558 .2231 .7586 .22737 .76541 .22519 .76238 .22062 Mtetra
.654 .727 .902 r
.76238 .22062 .76541 .22519 .7722 .22262 .76922 .2184 Mtetra
.673 .754 .912 r
.76922 .2184 .7722 .22262 .77902 .22015 .77604 .21586 Mtetra
.66 .745 .913 r
.77604 .21586 .77902 .22015 .78587 .21788 .7829 .21354 Mtetra
.668 .747 .909 r
.7829 .21354 .78587 .21788 .79277 .21593 .78977 .21108 Mtetra
.621 .699 .901 r
.78977 .21108 .79277 .21593 .79962 .21325 .79672 .20939 Mtetra
.705 .789 .917 r
.79672 .20939 .79962 .21325 .80658 .21148 .80356 .20629 Mtetra
.626 .686 .887 r
.80356 .20629 .80658 .21148 .81342 .20842 .81055 .20453 Mtetra
.705 .789 .917 r
.81055 .20453 .81342 .20842 .82036 .20613 .81742 .20143 Mtetra
.671 .75 .91 r
.19888 .41185 .20273 .4153 .20826 .41369 .20446 .40981 Mtetra
.629 .715 .909 r
.20446 .40981 .20826 .41369 .21385 .41153 .20998 .40836 Mtetra
.692 .772 .913 r
.20998 .40836 .21385 .41153 .21938 .41015 .21561 .40599 Mtetra
.627 .7 .897 r
.21561 .40599 .21938 .41015 .22502 .40766 .22116 .40456 Mtetra
.691 .777 .917 r
.22116 .40456 .22502 .40766 .23059 .40612 .22681 .40221 Mtetra
.666 .725 .894 r
.22681 .40221 .23059 .40612 .23623 .40385 .23244 .40019 Mtetra
.662 .738 .907 r
.23244 .40019 .23623 .40385 .24187 .40175 .23807 .39825 Mtetra
.662 .748 .914 r
.23807 .39825 .24187 .40175 .24751 .39986 .24372 .3963 Mtetra
.67 .747 .909 r
.24372 .3963 .24751 .39986 .25315 .39801 .24938 .39424 Mtetra
.654 .731 .906 r
.24938 .39424 .25315 .39801 .25882 .3959 .25504 .3924 Mtetra
.668 .751 .912 r
.25504 .3924 .25882 .3959 .26449 .39412 .26073 .39035 Mtetra
.66 .734 .905 r
.26073 .39035 .26449 .39412 .27019 .39194 .26643 .38842 Mtetra
.673 .752 .91 r
.26643 .38842 .27019 .39194 .27587 .39024 .27215 .38628 Mtetra
.648 .721 .902 r
.27215 .38628 .27587 .39024 .2816 .38806 .27785 .38451 Mtetra
.67 .751 .911 r
.27785 .38451 .2816 .38806 .28734 .38597 .28359 .38241 Mtetra
.673 .751 .91 r
.28359 .38241 .28734 .38597 .29307 .38408 .28935 .38027 Mtetra
.665 .736 .902 r
.28935 .38027 .29307 .38408 .29882 .38206 .29511 .37823 Mtetra
.653 .731 .907 r
.29511 .37823 .29882 .38206 .30459 .38 .30087 .37638 Mtetra
.65 .743 .917 r
.30087 .37638 .30459 .38 .31037 .37788 .30665 .37455 Mtetra
.67 .766 .922 r
.30665 .37455 .31037 .37788 .31615 .37612 .31245 .37243 Mtetra
.673 .746 .906 r
.31245 .37243 .31615 .37612 .32194 .37416 .31827 .37025 Mtetra
.647 .727 .907 r
.31827 .37025 .32194 .37416 .32776 .37218 .32408 .36846 Mtetra
.652 .74 .914 r
.32408 .36846 .32776 .37218 .33361 .36981 .3299 .3666 Mtetra
.671 .776 .929 r
.3299 .3666 .33361 .36981 .33943 .36802 .33576 .36445 Mtetra
.663 .752 .916 r
.33576 .36445 .33943 .36802 .34528 .36607 .34162 .36241 Mtetra
.643 .741 .921 r
.34162 .36241 .34528 .36607 .35116 .36386 .34748 .36066 Mtetra
.625 .765 .947 r
.34748 .36066 .35116 .36386 .35703 .36187 .35334 .3591 Mtetra
.683 .808 .942 r
.35334 .3591 .35703 .36187 .36289 .36048 .35926 .35674 Mtetra
.669 .746 .908 r
.35926 .35674 .36289 .36048 .36883 .35773 .36518 .35459 Mtetra
.67 .783 .934 r
.36518 .35459 .36883 .35773 .37467 .3575 .37111 .35242 Mtetra
.579 .646 .88 r
.37111 .35242 .37467 .3575 .38063 .35489 .37699 .35162 Mtetra
.511 .721 .968 r
.37699 .35162 .38063 .35489 .38661 .35199 .38288 .35116 Mtetra
.57 .903 .979 r
.38288 .35116 .38661 .35199 .39255 .35034 .38885 .34911 Mtetra
.644 .904 .983 r
.38885 .34911 .39255 .35034 .39849 .34927 .39485 .34671 Mtetra
.337 .69 .981 r
.39485 .34671 .39849 .34927 .40444 .34799 .40075 .34707 Mtetra
.36 0 0 r
.40075 .34707 .40444 .34799 .41042 .3466 .4066 .3495 Mtetra
.455 0 0 r
.4066 .3495 .41042 .3466 .41623 .35068 .41253 .35057 Mtetra
.666 .962 .935 r
.41253 .35057 .41623 .35068 .42211 .3535 .41863 .34725 Mtetra
.717 .662 .795 r
.41863 .34725 .42211 .3535 .42823 .34981 .42475 .34332 Mtetra
.498 .552 .842 r
.42475 .34332 .42823 .34981 .43438 .34487 .43076 .34383 Mtetra
0 .467 .739 r
.43076 .34383 .43438 .34487 .44041 .3449 .43676 .34516 Mtetra
.71 .982 .901 r
.43676 .34516 .44041 .3449 .44645 .34539 .44293 .34109 Mtetra
.827 .759 .787 r
.44293 .34109 .44645 .34539 .45253 .34501 .44917 .33417 Mtetra
.724 .583 .697 r
.44917 .33417 .45253 .34501 .45866 .3432 .45541 .32733 Mtetra
.449 .363 .667 r
.45541 .32733 .45866 .3432 .46501 .33087 .46144 .33072 Mtetra
.849 .975 .871 r
.46144 .33072 .46501 .33087 .47113 .33045 .46767 .32491 Mtetra
.684 .676 .836 r
.46767 .32491 .47113 .33045 .4773 .32763 .47385 .32213 Mtetra
.773 .708 .79 r
.47385 .32213 .4773 .32763 .48348 .3256 .48008 .31665 Mtetra
.441 .45 .773 r
.48008 .31665 .48348 .3256 .48971 .32007 .48622 .31863 Mtetra
.694 .912 .97 r
.48622 .31863 .48971 .32007 .4959 .31798 .49244 .31567 Mtetra
.769 .867 .92 r
.49244 .31567 .4959 .31798 .50211 .31686 .49868 .31177 Mtetra
.655 .685 .866 r
.49868 .31177 .50211 .31686 .50832 .31823 .50491 .30966 Mtetra
.489 .488 .783 r
.50491 .30966 .50832 .31823 .51458 .3132 .51115 .31074 Mtetra
.671 .841 .965 r
.51115 .31074 .51458 .3132 .52083 .31447 .51742 .30832 Mtetra
.751 .684 .786 r
.51742 .30832 .52083 .31447 .52712 .31996 .52371 .30327 Mtetra
.298 .256 .642 r
.52371 .30327 .52712 .31996 .53342 .31325 .53002 .3112 Mtetra
.612 .854 .989 r
.53002 .3112 .53342 .31325 .53971 .30687 .53635 .30925 Mtetra
0 0 0 r
.53635 .30925 .53971 .30687 .54603 .30394 .54268 .30563 Mtetra
.599 .929 .716 r
.54268 .30563 .54603 .30394 .55235 .30043 .54902 .30061 Mtetra
.772 .994 .874 r
.54902 .30061 .55235 .30043 .55872 .30086 .55535 .29557 Mtetra
.531 .623 .888 r
.55535 .29557 .55872 .30086 .56516 .30401 .56175 .29538 Mtetra
.461 .473 .784 r
.56175 .29538 .56516 .30401 .57155 .30152 .56819 .29699 Mtetra
.71 .736 .872 r
.56819 .29699 .57155 .30152 .57785 .29341 .57459 .29382 Mtetra
.828 .999 .831 r
.57459 .29382 .57785 .29341 .58418 .28729 .58095 .28761 Mtetra
.755 .994 .86 r
.58095 .28761 .58418 .28729 .59057 .28349 .58733 .28254 Mtetra
.649 .937 .966 r
.58733 .28254 .59057 .28349 .59697 .28019 .59375 .27958 Mtetra
.696 .964 .94 r
.59375 .27958 .59697 .28019 .60339 .27741 .60018 .27591 Mtetra
.808 .934 .914 r
.60018 .27591 .60339 .27741 .60987 .27599 .60658 .27111 Mtetra
.726 .728 .852 r
.60658 .27111 .60987 .27599 .61632 .27329 .61302 .26747 Mtetra
.602 .638 .858 r
.61302 .26747 .61632 .27329 .62276 .26966 .61954 .26622 Mtetra
.699 .796 .925 r
.61954 .26622 .62276 .26966 .62927 .26779 .62603 .26339 Mtetra
.623 .714 .911 r
.62603 .26339 .62927 .26779 .63577 .26501 .63257 .26175 Mtetra
.692 .807 .936 r
.63257 .26175 .63577 .26501 .64228 .26246 .63909 .25901 Mtetra
.687 .794 .931 r
.63909 .25901 .64228 .26246 .64883 .26042 .64563 .25635 Mtetra
.667 .751 .913 r
.64563 .25635 .64883 .26042 .65539 .25809 .65219 .25401 Mtetra
.657 .747 .916 r
.65219 .25401 .65539 .25809 .66194 .25554 .65878 .25183 Mtetra
.669 .774 .928 r
.65878 .25183 .66194 .25554 .66854 .25349 .66537 .24944 Mtetra
.689 .761 .907 r
.66537 .24944 .66854 .25349 .67515 .25132 .67197 .2467 Mtetra
.642 .713 .899 r
.67197 .2467 .67515 .25132 .68175 .24874 .67861 .24474 Mtetra
.67 .759 .917 r
.67861 .24474 .68175 .24874 .68839 .24644 .68525 .24231 Mtetra
.68 .756 .908 r
.68525 .24231 .68839 .24644 .69504 .24422 .69189 .23971 Mtetra
.657 .727 .9 r
.69189 .23971 .69504 .24422 .70171 .24195 .69857 .23747 Mtetra
.664 .732 .9 r
.69857 .23747 .70171 .24195 .70839 .23966 .70526 .23513 Mtetra
.665 .73 .898 r
.70526 .23513 .70839 .23966 .71508 .23724 .71197 .23276 Mtetra
.655 .729 .904 r
.71197 .23276 .71508 .23724 .72178 .23472 .7187 .23054 Mtetra
.662 .749 .915 r
.7187 .23054 .72178 .23472 .72852 .23255 .72544 .22823 Mtetra
.679 .748 .903 r
.72544 .22823 .72852 .23255 .73526 .23025 .73217 .22561 Mtetra
.646 .719 .901 r
.73217 .22561 .73526 .23025 .74201 .22769 .73896 .22354 Mtetra
.675 .757 .913 r
.73896 .22354 .74201 .22769 .74879 .2255 .74573 .22098 Mtetra
.65 .727 .906 r
.74573 .22098 .74879 .2255 .75558 .2231 .75255 .21883 Mtetra
.671 .75 .91 r
.75255 .21883 .75558 .2231 .76238 .22062 .75936 .21632 Mtetra
.671 .749 .909 r
.75936 .21632 .76238 .22062 .76922 .2184 .76619 .21382 Mtetra
.663 .731 .9 r
.76619 .21382 .76922 .2184 .77604 .21586 .77304 .21143 Mtetra
.655 .737 .909 r
.77304 .21143 .77604 .21586 .7829 .21354 .77992 .20917 Mtetra
.648 .737 .914 r
.77992 .20917 .7829 .21354 .78977 .21108 .78682 .20703 Mtetra
.678 .769 .919 r
.78682 .20703 .78977 .21108 .79672 .20939 .7937 .20439 Mtetra
.63 .698 .894 r
.7937 .20439 .79672 .20939 .80356 .20629 .80067 .20254 Mtetra
.704 .797 .923 r
.80067 .20254 .80356 .20629 .81055 .20453 .80754 .19945 Mtetra
.655 .706 .885 r
.80754 .19945 .81055 .20453 .81742 .20143 .8145 .19714 Mtetra
.647 .729 .909 r
.19504 .40813 .19888 .41185 .20446 .40981 .20059 .40642 Mtetra
.669 .754 .914 r
.20059 .40642 .20446 .40981 .20998 .40836 .20618 .40438 Mtetra
.636 .713 .903 r
.20618 .40438 .20998 .40836 .21561 .40599 .21174 .40282 Mtetra
.681 .771 .919 r
.21174 .40282 .21561 .40599 .22116 .40456 .21737 .40061 Mtetra
.656 .721 .897 r
.21737 .40061 .22116 .40456 .22681 .40221 .22298 .39874 Mtetra
.667 .751 .914 r
.22298 .39874 .22681 .40221 .23244 .40019 .22861 .39673 Mtetra
.683 .756 .907 r
.22861 .39673 .23244 .40019 .23807 .39825 .23428 .39447 Mtetra
.661 .733 .903 r
.23428 .39447 .23807 .39825 .24372 .3963 .23993 .39252 Mtetra
.657 .732 .905 r
.23993 .39252 .24372 .3963 .24938 .39424 .24559 .39063 Mtetra
.656 .742 .913 r
.24559 .39063 .24938 .39424 .25504 .3924 .25126 .38875 Mtetra
.673 .745 .905 r
.25126 .38875 .25504 .3924 .26073 .39035 .25696 .38662 Mtetra
.652 .735 .91 r
.25696 .38662 .26073 .39035 .26643 .38842 .26265 .38479 Mtetra
.666 .745 .909 r
.26265 .38479 .26643 .38842 .27215 .38628 .26837 .38275 Mtetra
.678 .754 .909 r
.26837 .38275 .27215 .38628 .27785 .38451 .27412 .38053 Mtetra
.648 .721 .902 r
.27412 .38053 .27785 .38451 .28359 .38241 .27985 .37874 Mtetra
.662 .743 .91 r
.27985 .37874 .28359 .38241 .28935 .38027 .2856 .37676 Mtetra
.666 .753 .916 r
.2856 .37676 .28935 .38027 .29511 .37823 .29137 .37471 Mtetra
.66 .752 .918 r
.29137 .37471 .29511 .37823 .30087 .37638 .29714 .37275 Mtetra
.665 .748 .912 r
.29714 .37275 .30087 .37638 .30665 .37455 .30294 .3707 Mtetra
.68 .74 .896 r
.30294 .3707 .30665 .37455 .31245 .37243 .30876 .3684 Mtetra
.636 .717 .906 r
.30876 .3684 .31245 .37243 .31827 .37025 .31455 .36678 Mtetra
.691 .764 .908 r
.31455 .36678 .31827 .37025 .32408 .36846 .32041 .36432 Mtetra
.639 .713 .901 r
.32041 .36432 .32408 .36846 .3299 .3666 .32623 .36264 Mtetra
.652 .727 .904 r
.32623 .36264 .3299 .3666 .33576 .36445 .33208 .36077 Mtetra
.661 .746 .913 r
.33208 .36077 .33576 .36445 .34162 .36241 .33794 .35876 Mtetra
.663 .749 .914 r
.33794 .35876 .34162 .36241 .34748 .36066 .34383 .35671 Mtetra
.683 .738 .893 r
.34383 .35671 .34748 .36066 .35334 .3591 .34974 .35432 Mtetra
.636 .683 .877 r
.34974 .35432 .35334 .3591 .35926 .35674 .35563 .35265 Mtetra
.635 .717 .907 r
.35563 .35265 .35926 .35674 .36518 .35459 .36153 .351 Mtetra
.589 .731 .942 r
.36153 .351 .36518 .35459 .37111 .35242 .36742 .34988 Mtetra
.723 .833 .932 r
.36742 .34988 .37111 .35242 .37699 .35162 .37341 .34689 Mtetra
.44 .599 .912 r
.37341 .34689 .37699 .35162 .38288 .35116 .37925 .34755 Mtetra
.559 .719 .948 r
.37925 .34755 .38288 .35116 .38885 .34911 .38518 .34674 Mtetra
.257 .66 .965 r
.38518 .34674 .38885 .34911 .39485 .34671 .39106 .34739 Mtetra
.356 0 0 r
.39106 .34739 .39485 .34671 .40075 .34707 .39694 .3487 Mtetra
.117 0 0 r
.39694 .3487 .40075 .34707 .4066 .3495 .40292 .34802 Mtetra
.701 .903 .968 r
.40292 .34802 .4066 .3495 .41253 .35057 .409 .3451 Mtetra
.712 .686 .824 r
.409 .3451 .41253 .35057 .41863 .34725 .41511 .34166 Mtetra
.554 .616 .869 r
.41511 .34166 .41863 .34725 .42475 .34332 .42113 .34124 Mtetra
.295 .702 .974 r
.42113 .34124 .42475 .34332 .43076 .34383 .42715 .34151 Mtetra
.838 .855 .858 r
.42715 .34151 .43076 .34383 .43676 .34516 .43336 .33585 Mtetra
.77 .626 .7 r
.43336 .33585 .43676 .34516 .44293 .34109 .43965 .32725 Mtetra
.588 .471 .687 r
.43965 .32725 .44293 .34109 .44917 .33417 .44575 .32578 Mtetra
.348 .407 .781 r
.44575 .32578 .44917 .33417 .45541 .32733 .45177 .32887 Mtetra
.783 .994 .78 r
.45177 .32887 .45541 .32733 .46144 .33072 .45801 .32267 Mtetra
.679 .603 .763 r
.45801 .32267 .46144 .33072 .46767 .32491 .4642 .31924 Mtetra
.672 .667 .837 r
.4642 .31924 .46767 .32491 .47385 .32213 .47038 .3167 Mtetra
.576 .635 .873 r
.47038 .3167 .47385 .32213 .48008 .31665 .47655 .31592 Mtetra
.833 .956 .894 r
.47655 .31592 .48008 .31665 .48622 .31863 .4828 .31063 Mtetra
.658 .594 .772 r
.4828 .31063 .48622 .31863 .49244 .31567 .48902 .30787 Mtetra
.537 .535 .8 r
.48902 .30787 .49244 .31567 .49868 .31177 .49522 .30794 Mtetra
.601 .73 .935 r
.49522 .30794 .49868 .31177 .50491 .30966 .50146 .30662 Mtetra
.796 .826 .875 r
.50146 .30662 .50491 .30966 .51115 .31074 .50774 .30193 Mtetra
.433 .45 .778 r
.50774 .30193 .51115 .31074 .51742 .30832 .51399 .304 Mtetra
.57 .691 .922 r
.51399 .304 .51742 .30832 .52371 .30327 .52029 .30313 Mtetra
.938 .938 .768 r
.52029 .30313 .52371 .30327 .53002 .3112 .52659 .29385 Mtetra
.382 .309 .649 r
.52659 .29385 .53002 .3112 .53635 .30925 .53293 .29974 Mtetra
.457 .45 .763 r
.53293 .29974 .53635 .30925 .54268 .30563 .53929 .3016 Mtetra
.557 .703 .938 r
.53929 .3016 .54268 .30563 .54902 .30061 .54566 .30081 Mtetra
.817 .996 .858 r
.54566 .30081 .54902 .30061 .55535 .29557 .55201 .29508 Mtetra
.847 .974 .874 r
.55201 .29508 .55535 .29557 .56175 .29538 .55836 .28923 Mtetra
.614 .629 .843 r
.55836 .28923 .56175 .29538 .56819 .29699 .56477 .28778 Mtetra
.551 .514 .767 r
.56477 .28778 .56819 .29699 .57459 .29382 .57122 .28763 Mtetra
.679 .658 .822 r
.57122 .28763 .57459 .29382 .58095 .28761 .57764 .28473 Mtetra
.829 .847 .861 r
.57764 .28473 .58095 .28761 .58733 .28254 .58402 .27914 Mtetra
.804 .818 .862 r
.58402 .27914 .58733 .28254 .59375 .27958 .59041 .27404 Mtetra
.725 .701 .827 r
.59041 .27404 .59375 .27958 .60018 .27591 .59684 .27015 Mtetra
.741 .699 .812 r
.59684 .27015 .60018 .27591 .60658 .27111 .60326 .26571 Mtetra
.51 .61 .888 r
.60326 .26571 .60658 .27111 .61302 .26747 .60981 .2658 Mtetra
.779 .925 .932 r
.60981 .2658 .61302 .26747 .61954 .26622 .61626 .26154 Mtetra
.651 .711 .892 r
.61626 .26154 .61954 .26622 .62603 .26339 .62278 .25944 Mtetra
.711 .772 .9 r
.62278 .25944 .62603 .26339 .63257 .26175 .62928 .25634 Mtetra
.633 .671 .868 r
.62928 .25634 .63257 .26175 .63909 .25901 .63585 .25452 Mtetra
.662 .726 .897 r
.63585 .25452 .63909 .25901 .64563 .25635 .64241 .25223 Mtetra
.666 .749 .912 r
.64241 .25223 .64563 .25635 .65219 .25401 .64898 .24989 Mtetra
.672 .751 .91 r
.64898 .24989 .65219 .25401 .65878 .25183 .65557 .24745 Mtetra
.687 .743 .894 r
.65557 .24745 .65878 .25183 .66537 .24944 .66216 .24472 Mtetra
.64 .708 .896 r
.66216 .24472 .66537 .24944 .67197 .2467 .6688 .24279 Mtetra
.685 .77 .915 r
.6688 .24279 .67197 .2467 .67861 .24474 .67542 .24011 Mtetra
.643 .715 .9 r
.67542 .24011 .67861 .24474 .68525 .24231 .68209 .23811 Mtetra
.67 .749 .91 r
.68209 .23811 .68525 .24231 .69189 .23971 .68876 .23567 Mtetra
.67 .759 .917 r
.68876 .23567 .69189 .23971 .69857 .23747 .69544 .23322 Mtetra
.66 .743 .912 r
.69544 .23322 .69857 .23747 .70526 .23513 .70214 .23094 Mtetra
.66 .747 .915 r
.70214 .23094 .70526 .23513 .71197 .23276 .70886 .22865 Mtetra
.67 .756 .915 r
.70886 .22865 .71197 .23276 .7187 .23054 .71559 .2262 Mtetra
.674 .746 .904 r
.71559 .2262 .7187 .23054 .72544 .22823 .72233 .22365 Mtetra
.646 .722 .904 r
.72233 .22365 .72544 .22823 .73217 .22561 .72911 .22158 Mtetra
.677 .765 .918 r
.72911 .22158 .73217 .22561 .73896 .22354 .73588 .21899 Mtetra
.65 .727 .905 r
.73588 .21899 .73896 .22354 .74573 .22098 .74269 .21683 Mtetra
.678 .761 .913 r
.74269 .21683 .74573 .22098 .75255 .21883 .74949 .21421 Mtetra
.653 .725 .902 r
.74949 .21421 .75255 .21883 .75936 .21632 .75633 .212 Mtetra
.673 .75 .908 r
.75633 .212 .75936 .21632 .76619 .21382 .76316 .20944 Mtetra
.666 .745 .909 r
.76316 .20944 .76619 .21382 .77304 .21143 .77002 .20699 Mtetra
.665 .742 .907 r
.77002 .20699 .77304 .21143 .77992 .20917 .7769 .20456 Mtetra
.64 .722 .908 r
.7769 .20456 .77992 .20917 .78682 .20703 .78383 .20254 Mtetra
.655 .736 .909 r
.78383 .20254 .78682 .20703 .7937 .20439 .79075 .20027 Mtetra
.678 .766 .917 r
.79075 .20027 .7937 .20439 .80067 .20254 .79766 .19761 Mtetra
.649 .711 .893 r
.79766 .19761 .80067 .20254 .80754 .19945 .80463 .19541 Mtetra
.694 .778 .916 r
.80463 .19541 .80754 .19945 .8145 .19714 .81154 .19246 Mtetra
.667 .75 .912 r
.19116 .40466 .19504 .40813 .20059 .40642 .19674 .40265 Mtetra
.648 .729 .908 r
.19674 .40265 .20059 .40642 .20618 .40438 .20231 .40091 Mtetra
.666 .75 .913 r
.20231 .40091 .20618 .40438 .21174 .40282 .20791 .39892 Mtetra
.653 .723 .9 r
.20791 .39892 .21174 .40282 .21737 .40061 .21351 .39709 Mtetra
.659 .747 .915 r
.21351 .39709 .21737 .40061 .22298 .39874 .21913 .39518 Mtetra
.692 .753 .898 r
.21913 .39518 .22298 .39874 .22861 .39673 .22481 .39274 Mtetra
.649 .719 .9 r
.22481 .39274 .22861 .39673 .23428 .39447 .23044 .39098 Mtetra
.668 .752 .913 r
.23044 .39098 .23428 .39447 .23993 .39252 .23611 .38893 Mtetra
.663 .745 .911 r
.23611 .38893 .23993 .39252 .24559 .39063 .24178 .38695 Mtetra
.671 .743 .904 r
.24178 .38695 .24559 .39063 .25126 .38875 .24748 .38484 Mtetra
.645 .723 .905 r
.24748 .38484 .25126 .38875 .25696 .38662 .25316 .38311 Mtetra
.683 .756 .907 r
.25316 .38311 .25696 .38662 .26265 .38479 .25889 .38081 Mtetra
.642 .719 .904 r
.25889 .38081 .26265 .38479 .26837 .38275 .26459 .37911 Mtetra
.666 .745 .91 r
.26459 .37911 .26837 .38275 .27412 .38053 .27033 .37706 Mtetra
.677 .759 .913 r
.27033 .37706 .27412 .38053 .27985 .37874 .2761 .37485 Mtetra
.663 .731 .901 r
.2761 .37485 .27985 .37874 .2856 .37676 .28186 .37284 Mtetra
.663 .73 .9 r
.28186 .37284 .2856 .37676 .29137 .37471 .28763 .37082 Mtetra
.671 .735 .898 r
.28763 .37082 .29137 .37471 .29714 .37275 .29343 .36866 Mtetra
.65 .718 .899 r
.29343 .36866 .29714 .37275 .30294 .3707 .29921 .36682 Mtetra
.647 .729 .909 r
.29921 .36682 .30294 .3707 .30876 .3684 .30501 .36504 Mtetra
.687 .77 .914 r
.30501 .36504 .30876 .3684 .31455 .36678 .31086 .36263 Mtetra
.63 .711 .904 r
.31086 .36263 .31455 .36678 .32041 .36432 .31667 .36108 Mtetra
.677 .776 .925 r
.31667 .36108 .32041 .36432 .32623 .36264 .32253 .35883 Mtetra
.682 .745 .899 r
.32253 .35883 .32623 .36264 .33208 .36077 .32841 .35647 Mtetra
.666 .716 .885 r
.32841 .35647 .33208 .36077 .33794 .35876 .3343 .35433 Mtetra
.644 .702 .889 r
.3343 .35433 .33794 .35876 .34383 .35671 .34017 .35255 Mtetra
.602 .702 .914 r
.34017 .35255 .34383 .35671 .34974 .35432 .34602 .35136 Mtetra
.592 .772 .966 r
.34602 .35136 .34974 .35432 .35563 .35265 .3519 .35007 Mtetra
.768 .833 .902 r
.3519 .35007 .35563 .35265 .36153 .351 .35792 .34625 Mtetra
.473 .615 .91 r
.35792 .34625 .36153 .351 .36742 .34988 .36374 .3466 Mtetra
.698 .783 .917 r
.36374 .3466 .36742 .34988 .37341 .34689 .36973 .34397 Mtetra
.74 .813 .909 r
.36973 .34397 .37341 .34689 .37925 .34755 .37576 .34064 Mtetra
.552 .565 .821 r
.37576 .34064 .37925 .34755 .38518 .34674 .38166 .34038 Mtetra
.311 .451 .841 r
.38166 .34038 .38518 .34674 .39106 .34739 .38747 .34287 Mtetra
.5 .642 .919 r
.38747 .34287 .39106 .34739 .39694 .3487 .3934 .34286 Mtetra
.65 .649 .836 r
.3934 .34286 .39694 .3487 .40292 .34802 .39944 .34079 Mtetra
.618 .591 .8 r
.39944 .34079 .40292 .34802 .409 .3451 .40547 .33923 Mtetra
.538 .597 .861 r
.40547 .33923 .409 .3451 .41511 .34166 .41147 .33906 Mtetra
.477 .758 .992 r
.41147 .33906 .41511 .34166 .42113 .34124 .4175 .33854 Mtetra
.837 .833 .843 r
.4175 .33854 .42113 .34124 .42715 .34151 .42373 .33267 Mtetra
.78 .637 .703 r
.42373 .33267 .42715 .34151 .43336 .33585 .43004 .32385 Mtetra
.538 .458 .713 r
.43004 .32385 .43336 .33585 .43965 .32725 .43608 .3241 Mtetra
.194 .568 .937 r
.43608 .3241 .43965 .32725 .44575 .32578 .44211 .32561 Mtetra
.797 .98 .902 r
.44211 .32561 .44575 .32578 .45177 .32887 .44833 .32077 Mtetra
.729 .626 .744 r
.44833 .32077 .45177 .32887 .45801 .32267 .45456 .31543 Mtetra
.526 .544 .817 r
.45456 .31543 .45801 .32267 .4642 .31924 .46068 .31561 Mtetra
.793 .79 .849 r
.46068 .31561 .4642 .31924 .47038 .3167 .46692 .31069 Mtetra
.661 .651 .829 r
.46692 .31069 .47038 .3167 .47655 .31592 .47311 .30831 Mtetra
.545 .544 .805 r
.47311 .30831 .47655 .31592 .4828 .31063 .47929 .30819 Mtetra
.699 .848 .954 r
.47929 .30819 .4828 .31063 .48902 .30787 .48553 .30543 Mtetra
.7 .849 .954 r
.48553 .30543 .48902 .30787 .49522 .30794 .49177 .30264 Mtetra
.759 .714 .81 r
.49177 .30264 .49522 .30794 .50146 .30662 .49805 .29784 Mtetra
.429 .448 .779 r
.49805 .29784 .50146 .30662 .50774 .30193 .50428 .29994 Mtetra
.851 .887 .864 r
.50428 .29994 .50774 .30193 .51399 .304 .51058 .29406 Mtetra
.354 .378 .747 r
.51058 .29406 .51399 .304 .52029 .30313 .51686 .29778 Mtetra
.627 .665 .868 r
.51686 .29778 .52029 .30313 .52659 .29385 .52317 .29613 Mtetra
.835 .978 .681 r
.52317 .29613 .52659 .29385 .53293 .29974 .5295 .28767 Mtetra
.437 .396 .715 r
.5295 .28767 .53293 .29974 .53929 .3016 .53585 .29052 Mtetra
.387 .379 .729 r
.53585 .29052 .53929 .3016 .54566 .30081 .54224 .29414 Mtetra
.552 .581 .837 r
.54224 .29414 .54566 .30081 .55201 .29508 .54864 .2938 Mtetra
.873 .93 .858 r
.54864 .2938 .55201 .29508 .55836 .28923 .55501 .28736 Mtetra
.884 .894 .833 r
.55501 .28736 .55836 .28923 .56477 .28778 .56136 .28029 Mtetra
.691 .626 .779 r
.56136 .28029 .56477 .28778 .57122 .28763 .56776 .27664 Mtetra
.612 .52 .726 r
.56776 .27664 .57122 .28763 .57764 .28473 .57419 .27465 Mtetra
.668 .565 .73 r
.57419 .27465 .57764 .28473 .58402 .27914 .58061 .27085 Mtetra
.682 .605 .763 r
.58061 .27085 .58402 .27914 .59041 .27404 .58704 .26717 Mtetra
.558 .579 .831 r
.58704 .26717 .59041 .27404 .59684 .27015 .59355 .26673 Mtetra
.674 .79 .936 r
.59355 .26673 .59684 .27015 .60326 .26571 .60003 .26429 Mtetra
.679 .922 .972 r
.60003 .26429 .60326 .26571 .60981 .2658 .60651 .26126 Mtetra
.752 .753 .853 r
.60651 .26126 .60981 .2658 .61626 .26154 .61297 .25706 Mtetra
.57 .688 .921 r
.61297 .25706 .61626 .26154 .62278 .25944 .61954 .25616 Mtetra
.696 .808 .934 r
.61954 .25616 .62278 .25944 .62928 .25634 .62607 .25335 Mtetra
.726 .835 .932 r
.62607 .25335 .62928 .25634 .63585 .25452 .63259 .25006 Mtetra
.685 .738 .891 r
.63259 .25006 .63585 .25452 .64241 .25223 .63915 .24735 Mtetra
.66 .708 .883 r
.63915 .24735 .64241 .25223 .64898 .24989 .64574 .24507 Mtetra
.646 .706 .89 r
.64574 .24507 .64898 .24989 .65557 .24745 .65235 .24303 Mtetra
.647 .727 .907 r
.65235 .24303 .65557 .24745 .66216 .24472 .65898 .24097 Mtetra
.685 .779 .922 r
.65898 .24097 .66216 .24472 .6688 .24279 .6656 .2383 Mtetra
.653 .727 .903 r
.6656 .2383 .6688 .24279 .67542 .24011 .67225 .23613 Mtetra
.688 .769 .913 r
.67225 .23613 .67542 .24011 .68209 .23811 .6789 .2334 Mtetra
.654 .717 .894 r
.6789 .2334 .68209 .23811 .68876 .23567 .68559 .23121 Mtetra
.655 .731 .905 r
.68559 .23121 .68876 .23567 .69544 .23322 .69229 .22899 Mtetra
.663 .747 .912 r
.69229 .22899 .69544 .23322 .70214 .23094 .699 .22664 Mtetra
.673 .748 .907 r
.699 .22664 .70214 .23094 .70886 .22865 .70572 .22412 Mtetra
.665 .732 .9 r
.70572 .22412 .70886 .22865 .71559 .2262 .71247 .22172 Mtetra
.651 .73 .907 r
.71247 .22172 .71559 .2262 .72233 .22365 .71924 .21956 Mtetra
.673 .761 .917 r
.71924 .21956 .72233 .22365 .72911 .22158 .72601 .21703 Mtetra
.66 .731 .902 r
.72601 .21703 .72911 .22158 .73588 .21899 .7328 .2147 Mtetra
.67 .75 .91 r
.7328 .2147 .73588 .21899 .74269 .21683 .7396 .2122 Mtetra
.654 .725 .902 r
.7396 .2122 .74269 .21683 .74949 .21421 .74644 .20997 Mtetra
.675 .756 .912 r
.74644 .20997 .74949 .21421 .75633 .212 .75327 .20738 Mtetra
.664 .731 .9 r
.75327 .20738 .75633 .212 .76316 .20944 .76012 .20496 Mtetra
.659 .737 .907 r
.76012 .20496 .76316 .20944 .77002 .20699 .767 .20262 Mtetra
.65 .74 .915 r
.767 .20262 .77002 .20699 .7769 .20456 .77391 .20043 Mtetra
.676 .765 .918 r
.77391 .20043 .7769 .20456 .78383 .20254 .7808 .19781 Mtetra
.644 .719 .903 r
.7808 .19781 .78383 .20254 .79075 .20027 .78775 .19572 Mtetra
.664 .738 .905 r
.78775 .19572 .79075 .20027 .79766 .19761 .79469 .19328 Mtetra
.681 .757 .909 r
.79469 .19328 .79766 .19761 .80463 .19541 .80163 .19054 Mtetra
.66 .721 .894 r
.80163 .19054 .80463 .19541 .81154 .19246 .8086 .18814 Mtetra
.66 .734 .905 r
.18729 .40094 .19116 .40466 .19674 .40265 .19287 .39902 Mtetra
.658 .74 .91 r
.19287 .39902 .19674 .40265 .20231 .40091 .19845 .39714 Mtetra
.655 .732 .906 r
.19845 .39714 .20231 .40091 .20791 .39892 .20405 .39529 Mtetra
.657 .741 .912 r
.20405 .39529 .20791 .39892 .21351 .39709 .20966 .39342 Mtetra
.678 .743 .9 r
.20966 .39342 .21351 .39709 .21913 .39518 .21531 .3912 Mtetra
.644 .718 .902 r
.21531 .3912 .21913 .39518 .22481 .39274 .22093 .3895 Mtetra
.68 .769 .919 r
.22093 .3895 .22481 .39274 .23044 .39098 .22661 .38728 Mtetra
.669 .741 .904 r
.22661 .38728 .23044 .39098 .23611 .38893 .23229 .38519 Mtetra
.661 .737 .906 r
.23229 .38519 .23611 .38893 .24178 .38695 .23797 .38322 Mtetra
.654 .737 .91 r
.23797 .38322 .24178 .38695 .24748 .38484 .24365 .38136 Mtetra
.679 .757 .91 r
.24365 .38136 .24748 .38484 .25316 .38311 .24938 .37912 Mtetra
.644 .72 .903 r
.24938 .37912 .25316 .38311 .25889 .38081 .25507 .37739 Mtetra
.68 .762 .913 r
.25507 .37739 .25889 .38081 .26459 .37911 .26082 .37513 Mtetra
.653 .724 .901 r
.26082 .37513 .26459 .37911 .27033 .37706 .26655 .37326 Mtetra
.657 .735 .907 r
.26655 .37326 .27033 .37706 .2761 .37485 .2723 .37133 Mtetra
.669 .755 .915 r
.2723 .37133 .2761 .37485 .28186 .37284 .27808 .36922 Mtetra
.665 .749 .913 r
.27808 .36922 .28186 .37284 .28763 .37082 .28386 .36717 Mtetra
.654 .745 .917 r
.28386 .36717 .28763 .37082 .29343 .36866 .28965 .36528 Mtetra
.657 .762 .927 r
.28965 .36528 .29343 .36866 .29921 .36682 .29545 .36333 Mtetra
.683 .762 .911 r
.29545 .36333 .29921 .36682 .30501 .36504 .30129 .36098 Mtetra
.648 .722 .902 r
.30129 .36098 .30501 .36504 .31086 .36263 .30711 .35916 Mtetra
.673 .762 .917 r
.30711 .35916 .31086 .36263 .31667 .36108 .31296 .35697 Mtetra
.634 .715 .906 r
.31296 .35697 .31667 .36108 .32253 .35883 .3188 .35534 Mtetra
.664 .76 .922 r
.3188 .35534 .32253 .35883 .32841 .35647 .32467 .35328 Mtetra
.663 .778 .934 r
.32467 .35328 .32841 .35647 .3343 .35433 .33055 .35121 Mtetra
.645 .778 .945 r
.33055 .35121 .3343 .35433 .34017 .35255 .33644 .34937 Mtetra
.647 .775 .942 r
.33644 .34937 .34017 .35255 .34602 .35136 .34234 .3475 Mtetra
.712 .753 .884 r
.34234 .3475 .34602 .35136 .3519 .35007 .34832 .34455 Mtetra
.576 .627 .865 r
.34832 .34455 .3519 .35007 .35792 .34625 .35418 .3438 Mtetra
.732 .84 .931 r
.35418 .3438 .35792 .34625 .36374 .3466 .36019 .34067 Mtetra
.407 .525 .865 r
.36019 .34067 .36374 .3466 .36973 .34397 .36598 .34203 Mtetra
.328 .729 .981 r
.36598 .34203 .36973 .34397 .37576 .34064 .37186 .34203 Mtetra
.672 .973 .813 r
.37186 .34203 .37576 .34064 .38166 .34038 .37798 .33744 Mtetra
.729 .812 .916 r
.37798 .33744 .38166 .34038 .38747 .34287 .38404 .33429 Mtetra
.617 .558 .766 r
.38404 .33429 .38747 .34287 .3934 .34286 .39004 .33259 Mtetra
.57 .501 .738 r
.39004 .33259 .3934 .34286 .39944 .34079 .39602 .33195 Mtetra
.376 .413 .771 r
.39602 .33195 .39944 .34079 .40547 .33923 .40188 .33472 Mtetra
.359 .574 .922 r
.40188 .33472 .40547 .33923 .41147 .33906 .40784 .33594 Mtetra
.787 .812 .872 r
.40784 .33594 .41147 .33906 .4175 .33854 .41402 .33144 Mtetra
.807 .677 .72 r
.41402 .33144 .4175 .33854 .42373 .33267 .42035 .32253 Mtetra
.602 .523 .738 r
.42035 .32253 .42373 .33267 .43004 .32385 .42643 .32102 Mtetra
.332 .671 .976 r
.42643 .32102 .43004 .32385 .43608 .3241 .43248 .32154 Mtetra
.716 .84 .941 r
.43248 .32154 .43608 .3241 .44211 .32561 .43864 .31857 Mtetra
.784 .671 .739 r
.43864 .31857 .44211 .32561 .44833 .32077 .44492 .31127 Mtetra
.449 .444 .761 r
.44492 .31127 .44833 .32077 .45456 .31543 .45099 .31316 Mtetra
.854 .861 .846 r
.45099 .31316 .45456 .31543 .46068 .31561 .45725 .30698 Mtetra
.525 .508 .78 r
.45725 .30698 .46068 .31561 .46692 .31069 .46339 .30732 Mtetra
.739 .798 .899 r
.46339 .30732 .46692 .31069 .47311 .30831 .46962 .30384 Mtetra
.736 .741 .855 r
.46962 .30384 .47311 .30831 .47929 .30819 .47586 .30012 Mtetra
.616 .572 .782 r
.47586 .30012 .47929 .30819 .48553 .30543 .48208 .29845 Mtetra
.65 .617 .804 r
.48208 .29845 .48553 .30543 .49177 .30264 .48832 .29613 Mtetra
.523 .569 .843 r
.48832 .29613 .49177 .30264 .49805 .29784 .49455 .29624 Mtetra
.747 .913 .949 r
.49455 .29624 .49805 .29784 .50428 .29994 .50084 .2926 Mtetra
.56 .562 .813 r
.50084 .2926 .50428 .29994 .51058 .29406 .50712 .29217 Mtetra
.795 .899 .916 r
.50712 .29217 .51058 .29406 .51686 .29778 .51343 .28774 Mtetra
.38 .393 .748 r
.51343 .28774 .51686 .29778 .52317 .29613 .51974 .29104 Mtetra
.729 .716 .839 r
.51974 .29104 .52317 .29613 .5295 .28767 .52608 .28724 Mtetra
.779 .978 .911 r
.52608 .28724 .5295 .28767 .53585 .29052 .53242 .28258 Mtetra
.459 .49 .804 r
.53242 .28258 .53585 .29052 .54224 .29414 .5388 .28397 Mtetra
.402 .405 .748 r
.5388 .28397 .54224 .29414 .54864 .2938 .54522 .28698 Mtetra
.645 .623 .814 r
.54522 .28698 .54864 .2938 .55501 .28736 .55163 .28477 Mtetra
.899 .848 .785 r
.55163 .28477 .55501 .28736 .56136 .28029 .55799 .27619 Mtetra
.77 .775 .857 r
.55799 .27619 .56136 .28029 .56776 .27664 .56438 .27169 Mtetra
.56 .658 .902 r
.56438 .27169 .56776 .27664 .57419 .27465 .57085 .27101 Mtetra
.621 .757 .943 r
.57085 .27101 .57419 .27465 .58061 .27085 .57731 .26932 Mtetra
.41 .806 .986 r
.57731 .26932 .58061 .27085 .58704 .26717 .58381 .26848 Mtetra
0 0 0 r
.58381 .26848 .58704 .26717 .59355 .26673 .5903 .26642 Mtetra
.864 .982 .848 r
.5903 .26642 .59355 .26673 .60003 .26429 .59671 .25993 Mtetra
.738 .759 .869 r
.59671 .25993 .60003 .26429 .60651 .26126 .60318 .25614 Mtetra
.646 .69 .877 r
.60318 .25614 .60651 .26126 .61297 .25706 .60971 .25409 Mtetra
.761 .843 .913 r
.60971 .25409 .61297 .25706 .61954 .25616 .6162 .25016 Mtetra
.605 .635 .854 r
.6162 .25016 .61954 .25616 .62607 .25335 .62279 .24882 Mtetra
.669 .728 .894 r
.62279 .24882 .62607 .25335 .63259 .25006 .62935 .2464 Mtetra
.681 .782 .927 r
.62935 .2464 .63259 .25006 .63915 .24735 .63592 .24381 Mtetra
.665 .784 .937 r
.63592 .24381 .63915 .24735 .64574 .24507 .64252 .24145 Mtetra
.661 .779 .936 r
.64252 .24145 .64574 .24507 .65235 .24303 .64914 .23915 Mtetra
.684 .772 .918 r
.64914 .23915 .65235 .24303 .65898 .24097 .65575 .23649 Mtetra
.67 .734 .898 r
.65575 .23649 .65898 .24097 .6656 .2383 .66239 .23403 Mtetra
.66 .742 .911 r
.66239 .23403 .6656 .2383 .67225 .23613 .66905 .23174 Mtetra
.656 .735 .907 r
.66905 .23174 .67225 .23613 .6789 .2334 .67574 .22951 Mtetra
.68 .772 .921 r
.67574 .22951 .6789 .2334 .68559 .23121 .68241 .2269 Mtetra
.673 .747 .906 r
.68241 .2269 .68559 .23121 .69229 .22899 .68911 .22438 Mtetra
.661 .727 .898 r
.68911 .22438 .69229 .22899 .699 .22664 .69584 .22205 Mtetra
.655 .726 .901 r
.69584 .22205 .699 .22664 .70572 .22412 .70258 .21982 Mtetra
.659 .743 .912 r
.70258 .21982 .70572 .22412 .71247 .22172 .70934 .21752 Mtetra
.676 .756 .911 r
.70934 .21752 .71247 .22172 .71924 .21956 .7161 .21494 Mtetra
.657 .727 .901 r
.7161 .21494 .71924 .21956 .72601 .21703 .7229 .21266 Mtetra
.666 .744 .909 r
.7229 .21266 .72601 .21703 .7328 .2147 .7297 .21023 Mtetra
.659 .736 .907 r
.7297 .21023 .7328 .2147 .7396 .2122 .73652 .20791 Mtetra
.672 .752 .91 r
.73652 .20791 .7396 .2122 .74644 .20997 .74335 .20535 Mtetra
.653 .728 .904 r
.74335 .20535 .74644 .20997 .75327 .20738 .75021 .20311 Mtetra
.67 .754 .913 r
.75021 .20311 .75327 .20738 .76012 .20496 .75708 .20058 Mtetra
.67 .749 .909 r
.75708 .20058 .76012 .20496 .767 .20262 .76395 .19806 Mtetra
.66 .735 .905 r
.76395 .19806 .767 .20262 .77391 .20043 .77086 .19568 Mtetra
.64 .717 .903 r
.77086 .19568 .77391 .20043 .7808 .19781 .77781 .19363 Mtetra
.675 .764 .917 r
.77781 .19363 .7808 .19781 .78775 .19572 .78473 .191 Mtetra
.661 .729 .9 r
.78473 .191 .78775 .19572 .79469 .19328 .79168 .1886 Mtetra
.658 .73 .903 r
.79168 .1886 .79469 .19328 .80163 .19054 .79866 .18624 Mtetra
.691 .765 .908 r
.79866 .18624 .80163 .19054 .8086 .18814 .80561 .18331 Mtetra
.668 .747 .91 r
.18338 .39739 .18729 .40094 .19287 .39902 .18898 .39536 Mtetra
.659 .739 .909 r
.18898 .39536 .19287 .39902 .19845 .39714 .19457 .39344 Mtetra
.661 .738 .907 r
.19457 .39344 .19845 .39714 .20405 .39529 .20018 .3915 Mtetra
.657 .732 .905 r
.20018 .3915 .20405 .39529 .20966 .39342 .2058 .3896 Mtetra
.651 .73 .907 r
.2058 .3896 .20966 .39342 .21531 .3912 .21142 .3878 Mtetra
.686 .762 .909 r
.21142 .3878 .21531 .3912 .22093 .3895 .21711 .38548 Mtetra
.656 .721 .896 r
.21711 .38548 .22093 .3895 .22661 .38728 .22276 .38358 Mtetra
.662 .741 .908 r
.22276 .38358 .22661 .38728 .23229 .38519 .22844 .3816 Mtetra
.663 .747 .913 r
.22844 .3816 .23229 .38519 .23797 .38322 .23412 .3796 Mtetra
.671 .748 .908 r
.23412 .3796 .23797 .38322 .24365 .38136 .23984 .37748 Mtetra
.647 .728 .907 r
.23984 .37748 .24365 .38136 .24938 .37912 .24553 .3757 Mtetra
.684 .763 .911 r
.24553 .3757 .24938 .37912 .25507 .37739 .25128 .37337 Mtetra
.642 .719 .904 r
.25128 .37337 .25507 .37739 .26082 .37513 .25699 .37165 Mtetra
.672 .758 .915 r
.25699 .37165 .26082 .37513 .26655 .37326 .26276 .3695 Mtetra
.672 .743 .903 r
.26276 .3695 .26655 .37326 .2723 .37133 .26853 .36733 Mtetra
.658 .726 .9 r
.26853 .36733 .2723 .37133 .27808 .36922 .2743 .36537 Mtetra
.663 .736 .904 r
.2743 .36537 .27808 .36922 .28386 .36717 .28009 .36334 Mtetra
.666 .739 .904 r
.28009 .36334 .28386 .36717 .28965 .36528 .2859 .36125 Mtetra
.669 .729 .895 r
.2859 .36125 .28965 .36528 .29545 .36333 .29172 .35909 Mtetra
.641 .71 .897 r
.29172 .35909 .29545 .36333 .30129 .36098 .29752 .35737 Mtetra
.667 .752 .914 r
.29752 .35737 .30129 .36098 .30711 .35916 .30337 .35525 Mtetra
.654 .732 .907 r
.30337 .35525 .30711 .35916 .31296 .35697 .30921 .35333 Mtetra
.689 .758 .904 r
.30921 .35333 .31296 .35697 .3188 .35534 .31511 .35087 Mtetra
.652 .704 .885 r
.31511 .35087 .3188 .35534 .32467 .35328 .32098 .34895 Mtetra
.655 .712 .889 r
.32098 .34895 .32467 .35328 .33055 .35121 .32686 .34697 Mtetra
.674 .723 .886 r
.32686 .34697 .33055 .35121 .33644 .34937 .33278 .34468 Mtetra
.623 .684 .887 r
.33278 .34468 .33644 .34937 .34234 .3475 .33867 .34321 Mtetra
.559 .68 .92 r
.33867 .34321 .34234 .3475 .34832 .34455 .34452 .34252 Mtetra
.731 .867 .945 r
.34452 .34252 .34832 .34455 .35418 .3438 .35053 .33937 Mtetra
.396 .597 .926 r
.35053 .33937 .35418 .3438 .36019 .34067 .35633 .34024 Mtetra
.839 .955 .89 r
.35633 .34024 .36019 .34067 .36598 .34203 .36248 .33492 Mtetra
.337 .44 .819 r
.36248 .33492 .36598 .34203 .37186 .34203 .36823 .33743 Mtetra
.44 .61 .92 r
.36823 .33743 .37186 .34203 .37798 .33744 .37412 .338 Mtetra
.146 .688 .724 r
.37412 .338 .37798 .33744 .38404 .33429 .3801 .33694 Mtetra
.524 .877 .639 r
.3801 .33694 .38404 .33429 .39004 .33259 .38626 .33204 Mtetra
.846 .952 .884 r
.38626 .33204 .39004 .33259 .39602 .33195 .39246 .32652 Mtetra
0 .297 .793 r
.39246 .32652 .39602 .33195 .40188 .33472 .39826 .33074 Mtetra
.498 .676 .944 r
.39826 .33074 .40188 .33472 .40784 .33594 .40427 .33057 Mtetra
.818 .721 .758 r
.40427 .33057 .40784 .33594 .41402 .33144 .41057 .32295 Mtetra
.719 .614 .739 r
.41057 .32295 .41402 .33144 .42035 .32253 .41678 .31781 Mtetra
.54 .653 .908 r
.41678 .31781 .42035 .32253 .42643 .32102 .42284 .31739 Mtetra
.592 .737 .945 r
.42284 .31739 .42643 .32102 .43248 .32154 .42894 .31615 Mtetra
.781 .714 .789 r
.42894 .31615 .43248 .32154 .43864 .31857 .43519 .31045 Mtetra
.578 .549 .786 r
.43519 .31045 .43864 .31857 .44492 .31127 .44131 .30966 Mtetra
.735 .906 .954 r
.44131 .30966 .44492 .31127 .45099 .31316 .44751 .30627 Mtetra
.673 .63 .798 r
.44751 .30627 .45099 .31316 .45725 .30698 .4537 .30338 Mtetra
.666 .766 .925 r
.4537 .30338 .45725 .30698 .46339 .30732 .4599 .30116 Mtetra
.605 .622 .842 r
.4599 .30116 .46339 .30732 .46962 .30384 .46609 .29988 Mtetra
.676 .75 .907 r
.46609 .29988 .46962 .30384 .47586 .30012 .47232 .2975 Mtetra
.683 .834 .956 r
.47232 .2975 .47586 .30012 .48208 .29845 .47857 .29495 Mtetra
.589 .748 .953 r
.47857 .29495 .48208 .29845 .48832 .29613 .48481 .29369 Mtetra
.691 .85 .959 r
.48481 .29369 .48832 .29613 .49455 .29624 .49108 .29099 Mtetra
.719 .705 .836 r
.49108 .29099 .49455 .29624 .50084 .2926 .49738 .28739 Mtetra
.555 .64 .889 r
.49738 .28739 .50084 .2926 .50712 .29217 .50366 .28683 Mtetra
.686 .69 .848 r
.50366 .28683 .50712 .29217 .51343 .28774 .50997 .284 Mtetra
.608 .742 .94 r
.50997 .284 .51343 .28774 .51974 .29104 .5163 .28253 Mtetra
.489 .493 .788 r
.5163 .28253 .51974 .29104 .52608 .28724 .52264 .2835 Mtetra
.818 .797 .832 r
.52264 .2835 .52608 .28724 .53242 .28258 .52899 .27768 Mtetra
.563 .66 .902 r
.52899 .27768 .53242 .28258 .5388 .28397 .53537 .27696 Mtetra
.422 .499 .833 r
.53537 .27696 .5388 .28397 .54522 .28698 .54178 .27859 Mtetra
.532 .522 .79 r
.54178 .27859 .54522 .28698 .55163 .28477 .54821 .27875 Mtetra
.791 .707 .772 r
.54821 .27875 .55163 .28477 .55799 .27619 .5546 .27222 Mtetra
.767 .782 .866 r
.5546 .27222 .55799 .27619 .56438 .27169 .56101 .26787 Mtetra
0 .314 .794 r
.56101 .26787 .56438 .27169 .57085 .27101 .56754 .2719 Mtetra
0 0 0 r
.56754 .2719 .57085 .27101 .57731 .26932 .57403 .27031 Mtetra
.732 .987 .796 r
.57403 .27031 .57731 .26932 .58381 .26848 .58046 .26471 Mtetra
.835 .804 .821 r
.58046 .26471 .58381 .26848 .5903 .26642 .58688 .25827 Mtetra
.686 .611 .767 r
.58688 .25827 .5903 .26642 .59671 .25993 .59335 .25452 Mtetra
.474 .595 .893 r
.59335 .25452 .59671 .25993 .60318 .25614 .59994 .25501 Mtetra
.866 .951 .866 r
.59994 .25501 .60318 .25614 .60971 .25409 .60638 .24874 Mtetra
.564 .643 .887 r
.60638 .24874 .60971 .25409 .6162 .25016 .61297 .24803 Mtetra
.74 .894 .949 r
.61297 .24803 .6162 .25016 .62279 .24882 .61949 .24442 Mtetra
.712 .752 .883 r
.61949 .24442 .62279 .24882 .62935 .2464 .62604 .24119 Mtetra
.648 .689 .875 r
.62604 .24119 .62935 .2464 .63592 .24381 .63264 .23907 Mtetra
.665 .719 .889 r
.63264 .23907 .63592 .24381 .64252 .24145 .63925 .23668 Mtetra
.674 .721 .885 r
.63925 .23668 .64252 .24145 .64914 .23915 .64586 .23411 Mtetra
.64 .695 .885 r
.64586 .23411 .64914 .23915 .65575 .23649 .65252 .23214 Mtetra
.662 .74 .907 r
.65252 .23214 .65575 .23649 .66239 .23403 .65917 .22981 Mtetra
.674 .752 .909 r
.65917 .22981 .66239 .23403 .66905 .23174 .66584 .2273 Mtetra
.67 .738 .901 r
.66584 .2273 .66905 .23174 .67574 .22951 .67252 .22482 Mtetra
.654 .72 .897 r
.67252 .22482 .67574 .22951 .68241 .2269 .67923 .2226 Mtetra
.662 .744 .911 r
.67923 .2226 .68241 .2269 .68911 .22438 .68595 .22026 Mtetra
.663 .755 .919 r
.68595 .22026 .68911 .22438 .69584 .22205 .69268 .2179 Mtetra
.67 .757 .915 r
.69268 .2179 .69584 .22205 .70258 .21982 .69943 .21541 Mtetra
.672 .744 .905 r
.69943 .21541 .70258 .21982 .70934 .21752 .70618 .21287 Mtetra
.649 .723 .902 r
.70618 .21287 .70934 .21752 .7161 .21494 .71298 .21071 Mtetra
.667 .753 .915 r
.71298 .21071 .7161 .21494 .7229 .21266 .71977 .20825 Mtetra
.665 .743 .908 r
.71977 .20825 .7229 .21266 .7297 .21023 .72659 .20583 Mtetra
.664 .743 .909 r
.72659 .20583 .7297 .21023 .73652 .20791 .73342 .20342 Mtetra
.659 .737 .908 r
.73342 .20342 .73652 .20791 .74335 .20535 .74027 .20108 Mtetra
.675 .756 .912 r
.74027 .20108 .74335 .20535 .75021 .20311 .74712 .19847 Mtetra
.662 .731 .901 r
.74712 .19847 .75021 .20311 .75708 .20058 .75401 .19606 Mtetra
.658 .737 .908 r
.75401 .19606 .75708 .20058 .76395 .19806 .76091 .19372 Mtetra
.656 .746 .916 r
.76091 .19372 .76395 .19806 .77086 .19568 .76783 .1914 Mtetra
.678 .759 .912 r
.76783 .1914 .77086 .19568 .77781 .19363 .77474 .18871 Mtetra
.646 .713 .896 r
.77474 .18871 .77781 .19363 .78473 .191 .78172 .18656 Mtetra
.664 .746 .911 r
.78172 .18656 .78473 .191 .79168 .1886 .78868 .18409 Mtetra
.682 .75 .903 r
.78868 .18409 .79168 .1886 .79866 .18624 .79563 .1813 Mtetra
.649 .715 .896 r
.79563 .1813 .79866 .18624 .80561 .18331 .80265 .17907 Mtetra
.663 .741 .908 r
.17946 .39374 .18338 .39739 .18898 .39536 .18506 .39177 Mtetra
.67 .746 .908 r
.18506 .39177 .18898 .39536 .19457 .39344 .19068 .38969 Mtetra
.653 .733 .908 r
.19068 .38969 .19457 .39344 .20018 .3915 .19629 .38784 Mtetra
.662 .742 .909 r
.19629 .38784 .20018 .3915 .2058 .3896 .20192 .38588 Mtetra
.666 .739 .905 r
.20192 .38588 .2058 .3896 .21142 .3878 .20757 .38384 Mtetra
.648 .722 .903 r
.20757 .38384 .21142 .3878 .21711 .38548 .21321 .38206 Mtetra
.677 .76 .914 r
.21321 .38206 .21711 .38548 .22276 .38358 .2189 .37986 Mtetra
.67 .742 .904 r
.2189 .37986 .22276 .38358 .22844 .3816 .22459 .37776 Mtetra
.66 .733 .904 r
.22459 .37776 .22844 .3816 .23412 .3796 .23028 .37578 Mtetra
.652 .733 .908 r
.23028 .37578 .23412 .3796 .23984 .37748 .23598 .37393 Mtetra
.675 .754 .91 r
.23598 .37393 .23984 .37748 .24553 .3757 .24171 .37173 Mtetra
.645 .723 .905 r
.24171 .37173 .24553 .3757 .25128 .37337 .24742 .36996 Mtetra
.684 .765 .913 r
.24742 .36996 .25128 .37337 .25699 .37165 .2532 .36762 Mtetra
.647 .721 .902 r
.2532 .36762 .25699 .37165 .26276 .3695 .25893 .36583 Mtetra
.659 .745 .914 r
.25893 .36583 .26276 .3695 .26853 .36733 .2647 .36386 Mtetra
.67 .76 .918 r
.2647 .36386 .26853 .36733 .2743 .36537 .27049 .36172 Mtetra
.664 .748 .913 r
.27049 .36172 .2743 .36537 .28009 .36334 .27629 .35967 Mtetra
.654 .745 .917 r
.27629 .35967 .28009 .36334 .2859 .36125 .28209 .35776 Mtetra
.659 .757 .923 r
.28209 .35776 .2859 .36125 .29172 .35909 .28791 .35577 Mtetra
.684 .774 .919 r
.28791 .35577 .29172 .35909 .29752 .35737 .29377 .3534 Mtetra
.647 .728 .908 r
.29377 .3534 .29752 .35737 .30337 .35525 .2996 .35157 Mtetra
.673 .752 .91 r
.2996 .35157 .30337 .35525 .30921 .35333 .30547 .34936 Mtetra
.629 .722 .915 r
.30547 .34936 .30921 .35333 .31511 .35087 .31131 .34779 Mtetra
.657 .784 .942 r
.31131 .34779 .31511 .35087 .32098 .34895 .3172 .34578 Mtetra
.655 .779 .94 r
.3172 .34578 .32098 .34895 .32686 .34697 .32309 .3438 Mtetra
.626 .771 .95 r
.32309 .3438 .32686 .34697 .33278 .34468 .32898 .34217 Mtetra
.596 .806 .98 r
.32898 .34217 .33278 .34468 .33867 .34321 .33487 .34069 Mtetra
.709 .834 .941 r
.33487 .34069 .33867 .34321 .34452 .34252 .34086 .33791 Mtetra
.615 .687 .894 r
.34086 .33791 .34452 .34252 .35053 .33937 .34677 .33652 Mtetra
.609 .789 .967 r
.34677 .33652 .35053 .33937 .35633 .34024 .35271 .33499 Mtetra
.489 .601 .891 r
.35271 .33499 .35633 .34024 .36248 .33492 .35857 .33526 Mtetra
.746 .986 .9 r
.35857 .33526 .36248 .33492 .36823 .33743 .36469 .33091 Mtetra
.564 .586 .834 r
.36469 .33091 .36823 .33743 .37412 .338 .37062 .33038 Mtetra
.2 .339 .781 r
.37062 .33038 .37412 .338 .3801 .33694 .37636 .33445 Mtetra
.755 .845 .919 r
.37636 .33445 .3801 .33694 .38626 .33204 .38248 .33085 Mtetra
.914 .88 .788 r
.38248 .33085 .38626 .33204 .39246 .32652 .38883 .32216 Mtetra
.148 .461 .888 r
.38883 .32216 .39246 .32652 .39826 .33074 .39471 .32465 Mtetra
.618 .629 .839 r
.39471 .32465 .39826 .33074 .40427 .33057 .40077 .32316 Mtetra
.765 .655 .741 r
.40077 .32316 .40427 .33057 .41057 .32295 .40704 .31654 Mtetra
.702 .655 .8 r
.40704 .31654 .41057 .32295 .41678 .31781 .4132 .31299 Mtetra
.523 .642 .908 r
.4132 .31299 .41678 .31781 .42284 .31739 .41926 .31277 Mtetra
.671 .712 .879 r
.41926 .31277 .42284 .31739 .42894 .31615 .4254 .31042 Mtetra
.752 .695 .797 r
.4254 .31042 .42894 .31615 .43519 .31045 .43163 .30558 Mtetra
.587 .668 .895 r
.43163 .30558 .43519 .31045 .44131 .30966 .43776 .30456 Mtetra
.71 .705 .843 r
.43776 .30456 .44131 .30966 .44751 .30627 .44397 .30126 Mtetra
.659 .691 .869 r
.44397 .30126 .44751 .30627 .4537 .30338 .45016 .29907 Mtetra
.677 .732 .891 r
.45016 .29907 .4537 .30338 .4599 .30116 .45637 .29663 Mtetra
.619 .699 .902 r
.45637 .29663 .4599 .30116 .46609 .29988 .46257 .29511 Mtetra
.652 .701 .882 r
.46257 .29511 .46609 .29988 .47232 .2975 .4688 .29306 Mtetra
.623 .707 .906 r
.4688 .29306 .47232 .2975 .47857 .29495 .47504 .29147 Mtetra
.686 .782 .924 r
.47504 .29147 .47857 .29495 .48481 .29369 .48131 .28891 Mtetra
.716 .724 .856 r
.48131 .28891 .48481 .29369 .49108 .29099 .4876 .28554 Mtetra
.637 .666 .862 r
.4876 .28554 .49108 .29099 .49738 .28739 .49388 .2837 Mtetra
.605 .745 .943 r
.49388 .2837 .49738 .28739 .50366 .28683 .50018 .28226 Mtetra
.698 .73 .875 r
.50018 .28226 .50366 .28683 .50997 .284 .50651 .27935 Mtetra
.677 .719 .881 r
.50651 .27935 .50997 .284 .5163 .28253 .51284 .27683 Mtetra
.484 .584 .88 r
.51284 .27683 .5163 .28253 .52264 .2835 .51918 .27727 Mtetra
.675 .656 .823 r
.51918 .27727 .52264 .2835 .52899 .27768 .52555 .27446 Mtetra
.721 .812 .921 r
.52555 .27446 .52899 .27768 .53537 .27696 .53193 .27128 Mtetra
.431 .558 .882 r
.53193 .27128 .53537 .27696 .54178 .27859 .53834 .27233 Mtetra
.601 .622 .844 r
.53834 .27233 .54178 .27859 .54821 .27875 .54476 .27107 Mtetra
.743 .647 .754 r
.54476 .27107 .54821 .27875 .5546 .27222 .55117 .26539 Mtetra
.584 .594 .829 r
.55117 .26539 .5546 .27222 .56101 .26787 .55762 .26444 Mtetra
0 .391 .839 r
.55762 .26444 .56101 .26787 .56754 .2719 .56415 .26766 Mtetra
.77 .772 .854 r
.56415 .26766 .56754 .2719 .57403 .27031 .5706 .26309 Mtetra
.787 .677 .742 r
.5706 .26309 .57403 .27031 .58046 .26471 .57701 .2557 Mtetra
.49 .484 .778 r
.57701 .2557 .58046 .26471 .58688 .25827 .58358 .25675 Mtetra
.647 .908 .981 r
.58358 .25675 .58688 .25827 .59335 .25452 .59009 .25408 Mtetra
.864 .979 .852 r
.59009 .25408 .59335 .25452 .59994 .25501 .59653 .24761 Mtetra
.583 .579 .813 r
.59653 .24761 .59994 .25501 .60638 .24874 .60311 .24666 Mtetra
.78 .902 .927 r
.60311 .24666 .60638 .24874 .61297 .24803 .60962 .24237 Mtetra
.589 .643 .872 r
.60962 .24237 .61297 .24803 .61949 .24442 .61623 .24128 Mtetra
.698 .821 .941 r
.61623 .24128 .61949 .24442 .62604 .24119 .6228 .2384 Mtetra
.695 .843 .954 r
.6228 .2384 .62604 .24119 .63264 .23907 .62939 .23552 Mtetra
.674 .789 .936 r
.62939 .23552 .63264 .23907 .63925 .23668 .636 .23302 Mtetra
.666 .78 .934 r
.636 .23302 .63925 .23668 .64586 .23411 .64264 .23062 Mtetra
.689 .799 .933 r
.64264 .23062 .64586 .23411 .65252 .23214 .64927 .22786 Mtetra
.672 .748 .908 r
.64927 .22786 .65252 .23214 .65917 .22981 .65593 .22537 Mtetra
.659 .735 .905 r
.65593 .22537 .65917 .22981 .66584 .2273 .66262 .22307 Mtetra
.657 .746 .916 r
.66262 .22307 .66584 .2273 .67252 .22482 .66932 .22082 Mtetra
.679 .767 .918 r
.66932 .22082 .67252 .22482 .67923 .2226 .67602 .21819 Mtetra
.673 .744 .904 r
.67602 .21819 .67923 .2226 .68595 .22026 .68274 .21565 Mtetra
.661 .729 .899 r
.68274 .21565 .68595 .22026 .69268 .2179 .68949 .21329 Mtetra
.655 .727 .902 r
.68949 .21329 .69268 .2179 .69943 .21541 .69626 .21104 Mtetra
.656 .74 .912 r
.69626 .21104 .69943 .21541 .70618 .21287 .70304 .20877 Mtetra
.675 .763 .917 r
.70304 .20877 .70618 .21287 .71298 .21071 .70982 .20617 Mtetra
.662 .735 .904 r
.70982 .20617 .71298 .21071 .71977 .20825 .71664 .20378 Mtetra
.66 .738 .908 r
.71664 .20378 .71977 .20825 .72659 .20583 .72347 .20143 Mtetra
.667 .746 .909 r
.72347 .20143 .72659 .20583 .73342 .20342 .7303 .19895 Mtetra
.668 .743 .906 r
.7303 .19895 .73342 .20342 .74027 .20108 .73716 .19644 Mtetra
.658 .73 .903 r
.73716 .19644 .74027 .20108 .74712 .19847 .74404 .1941 Mtetra
.668 .75 .911 r
.74404 .1941 .74712 .19847 .75401 .19606 .75093 .19158 Mtetra
.666 .743 .908 r
.75093 .19158 .75401 .19606 .76091 .19372 .75783 .1891 Mtetra
.666 .737 .903 r
.75783 .1891 .76091 .19372 .76783 .1914 .76475 .18661 Mtetra
.644 .719 .903 r
.76475 .18661 .76783 .1914 .77474 .18871 .77172 .18448 Mtetra
.668 .759 .919 r
.77172 .18448 .77474 .18871 .78172 .18656 .77868 .18195 Mtetra
.676 .743 .901 r
.77868 .18195 .78172 .18656 .78868 .18409 .78563 .17925 Mtetra
.647 .719 .901 r
.78563 .17925 .78868 .18409 .79563 .1813 .79265 .17705 Mtetra
.679 .765 .916 r
.79265 .17705 .79563 .1813 .80265 .17907 .79964 .17431 Mtetra
.657 .734 .906 r
.17554 .38998 .17946 .39374 .18506 .39177 .18114 .38809 Mtetra
.659 .739 .909 r
.18114 .38809 .18506 .39177 .19068 .38969 .18675 .38616 Mtetra
.672 .752 .911 r
.18675 .38616 .19068 .38969 .19629 .38784 .19239 .38405 Mtetra
.648 .731 .909 r
.19239 .38405 .19629 .38784 .20192 .38588 .19801 .38227 Mtetra
.664 .746 .911 r
.19801 .38227 .20192 .38588 .20757 .38384 .20366 .38025 Mtetra
.677 .751 .906 r
.20366 .38025 .20757 .38384 .21321 .38206 .20935 .37803 Mtetra
.649 .72 .9 r
.20935 .37803 .21321 .38206 .2189 .37986 .21501 .37622 Mtetra
.668 .746 .909 r
.21501 .37622 .2189 .37986 .22459 .37776 .2207 .37413 Mtetra
.668 .748 .91 r
.2207 .37413 .22459 .37776 .23028 .37578 .22641 .37204 Mtetra
.666 .741 .906 r
.22641 .37204 .23028 .37578 .23598 .37393 .23213 .36998 Mtetra
.649 .726 .905 r
.23213 .36998 .23598 .37393 .24171 .37173 .23784 .36815 Mtetra
.68 .755 .908 r
.23784 .36815 .24171 .37173 .24742 .36996 .24361 .36586 Mtetra
.643 .716 .901 r
.24361 .36586 .24742 .36996 .2532 .36762 .24934 .36412 Mtetra
.673 .758 .915 r
.24934 .36412 .2532 .36762 .25893 .36583 .25511 .36193 Mtetra
.67 .737 .9 r
.25511 .36193 .25893 .36583 .2647 .36386 .2609 .35978 Mtetra
.655 .723 .899 r
.2609 .35978 .2647 .36386 .27049 .36172 .26668 .35785 Mtetra
.661 .736 .906 r
.26668 .35785 .27049 .36172 .27629 .35967 .27249 .35583 Mtetra
.665 .74 .905 r
.27249 .35583 .27629 .35967 .28209 .35776 .27831 .35373 Mtetra
.673 .732 .895 r
.27831 .35373 .28209 .35776 .28791 .35577 .28415 .3515 Mtetra
.636 .709 .899 r
.28415 .3515 .28791 .35577 .29377 .3534 .28996 .34984 Mtetra
.663 .756 .919 r
.28996 .34984 .29377 .3534 .2996 .35157 .29582 .34776 Mtetra
.655 .74 .912 r
.29582 .34776 .2996 .35157 .30547 .34936 .30168 .34581 Mtetra
.695 .766 .906 r
.30168 .34581 .30547 .34936 .31131 .34779 .3076 .34323 Mtetra
.631 .694 .89 r
.3076 .34323 .31131 .34779 .3172 .34578 .31346 .34162 Mtetra
.644 .719 .903 r
.31346 .34162 .3172 .34578 .32309 .3438 .31935 .33982 Mtetra
.666 .736 .902 r
.31935 .33982 .32309 .3438 .32898 .34217 .32528 .33768 Mtetra
.696 .72 .868 r
.32528 .33768 .32898 .34217 .33487 .34069 .33126 .33492 Mtetra
.561 .612 .861 r
.33126 .33492 .33487 .34069 .34086 .33791 .33711 .33437 Mtetra
.654 .759 .927 r
.33711 .33437 .34086 .33791 .34677 .33652 .34307 .33239 Mtetra
.518 .675 .935 r
.34307 .33239 .34677 .33652 .35271 .33499 .34895 .33207 Mtetra
.738 .815 .912 r
.34895 .33207 .35271 .33499 .35857 .33526 .35501 .32877 Mtetra
0 .244 .754 r
.35501 .32877 .35857 .33526 .36469 .33091 .36065 .33368 Mtetra
.645 .934 .674 r
.36065 .33368 .36469 .33091 .37062 .33038 .36687 .32784 Mtetra
.754 .842 .918 r
.36687 .32784 .37062 .33038 .37636 .33445 .37298 .32426 Mtetra
.47 .443 .746 r
.37298 .32426 .37636 .33445 .38248 .33085 .37886 .3258 Mtetra
.804 .728 .78 r
.37886 .3258 .38248 .33085 .38883 .32216 .38513 .31926 Mtetra
.73 .819 .92 r
.38513 .31926 .38883 .32216 .39471 .32465 .39125 .31606 Mtetra
.52 .505 .781 r
.39125 .31606 .39471 .32465 .40077 .32316 .39723 .31643 Mtetra
.698 .644 .792 r
.39723 .31643 .40077 .32316 .40704 .31654 .4034 .31288 Mtetra
.79 .786 .849 r
.4034 .31288 .40704 .31654 .4132 .31299 .40961 .30802 Mtetra
.482 .614 .906 r
.40961 .30802 .4132 .31299 .41926 .31277 .41566 .30828 Mtetra
.726 .735 .858 r
.41566 .30828 .41926 .31277 .4254 .31042 .42185 .30478 Mtetra
.712 .685 .822 r
.42185 .30478 .4254 .31042 .43163 .30558 .42805 .30124 Mtetra
.598 .701 .915 r
.42805 .30124 .43163 .30558 .43776 .30456 .43419 .30001 Mtetra
.68 .721 .88 r
.43419 .30001 .43776 .30456 .44397 .30126 .44038 .29748 Mtetra
.622 .743 .933 r
.44038 .29748 .44397 .30126 .45016 .29907 .44657 .29587 Mtetra
.759 .812 .895 r
.44657 .29587 .45016 .29907 .45637 .29663 .45282 .292 Mtetra
.575 .678 .91 r
.45282 .292 .45637 .29663 .46257 .29511 .45902 .29109 Mtetra
.66 .743 .911 r
.45902 .29109 .46257 .29511 .4688 .29306 .46526 .28893 Mtetra
.677 .743 .901 r
.46526 .28893 .4688 .29306 .47504 .29147 .47152 .28648 Mtetra
.677 .702 .866 r
.47152 .28648 .47504 .29147 .48131 .28891 .4778 .28391 Mtetra
.697 .709 .857 r
.4778 .28391 .48131 .28891 .4876 .28554 .48409 .28091 Mtetra
.572 .678 .912 r
.48409 .28091 .4876 .28554 .49388 .2837 .49037 .28002 Mtetra
.666 .767 .926 r
.49037 .28002 .49388 .2837 .50018 .28226 .49669 .27775 Mtetra
.651 .717 .896 r
.49669 .27775 .50018 .28226 .50651 .27935 .50302 .27569 Mtetra
.705 .781 .911 r
.50302 .27569 .50651 .27935 .51284 .27683 .50936 .27277 Mtetra
.583 .716 .934 r
.50936 .27277 .51284 .27683 .51918 .27727 .51572 .27164 Mtetra
.654 .669 .852 r
.51572 .27164 .51918 .27727 .52555 .27446 .52209 .2694 Mtetra
.716 .716 .849 r
.52209 .2694 .52555 .27446 .53193 .27128 .52848 .26593 Mtetra
.363 .536 .892 r
.52848 .26593 .53193 .27128 .53834 .27233 .5349 .26752 Mtetra
.689 .72 .873 r
.5349 .26752 .53834 .27233 .54476 .27107 .54132 .26471 Mtetra
.755 .686 .785 r
.54132 .26471 .54476 .27107 .55117 .26539 .54773 .25943 Mtetra
.286 .462 .859 r
.54773 .25943 .55117 .26539 .55762 .26444 .55423 .26209 Mtetra
.543 .816 .996 r
.55423 .26209 .55762 .26444 .56415 .26766 .56071 .26078 Mtetra
.794 .688 .747 r
.56071 .26078 .56415 .26766 .5706 .26309 .56713 .25334 Mtetra
.291 .345 .747 r
.56713 .25334 .5706 .26309 .57701 .2557 .57374 .25796 Mtetra
0 0 0 r
.57374 .25796 .57701 .2557 .58358 .25675 .58026 .25561 Mtetra
.946 .903 .749 r
.58026 .25561 .58358 .25675 .59009 .25408 .58664 .24527 Mtetra
.47 .478 .784 r
.58664 .24527 .59009 .25408 .59653 .24761 .59326 .24664 Mtetra
.85 .962 .878 r
.59326 .24664 .59653 .24761 .60311 .24666 .59973 .24071 Mtetra
.609 .641 .858 r
.59973 .24071 .60311 .24666 .60962 .24237 .60632 .23927 Mtetra
.772 .84 .904 r
.60632 .23927 .60962 .24237 .61623 .24128 .61286 .23505 Mtetra
.626 .64 .844 r
.61286 .23505 .61623 .24128 .6228 .2384 .61947 .23325 Mtetra
.652 .696 .878 r
.61947 .23325 .6228 .2384 .62939 .23552 .62609 .23105 Mtetra
.677 .739 .897 r
.62609 .23105 .62939 .23552 .636 .23302 .63271 .22845 Mtetra
.691 .739 .888 r
.63271 .22845 .636 .23302 .64264 .23062 .63934 .22557 Mtetra
.642 .697 .886 r
.63934 .22557 .64264 .23062 .64927 .22786 .64601 .22355 Mtetra
.657 .741 .912 r
.64601 .22355 .64927 .22786 .65593 .22537 .65269 .22129 Mtetra
.682 .764 .913 r
.65269 .22129 .65593 .22537 .66262 .22307 .65937 .21861 Mtetra
.668 .739 .903 r
.65937 .21861 .66262 .22307 .66932 .22082 .66608 .21615 Mtetra
.653 .723 .9 r
.66608 .21615 .66932 .22082 .67602 .21819 .67281 .21393 Mtetra
.664 .749 .913 r
.67281 .21393 .67602 .21819 .68274 .21565 .67955 .21154 Mtetra
.664 .758 .92 r
.67955 .21154 .68274 .21565 .68949 .21329 .68631 .20913 Mtetra
.671 .758 .916 r
.68631 .20913 .68949 .21329 .69626 .21104 .69307 .20662 Mtetra
.676 .747 .904 r
.69307 .20662 .69626 .21104 .70304 .20877 .69985 .20399 Mtetra
.65 .718 .898 r
.69985 .20399 .70304 .20877 .70982 .20617 .70667 .2018 Mtetra
.667 .747 .91 r
.70667 .2018 .70982 .20617 .71664 .20378 .71348 .19932 Mtetra
.665 .742 .908 r
.71348 .19932 .71664 .20378 .72347 .20143 .72032 .19687 Mtetra
.666 .738 .904 r
.72032 .19687 .72347 .20143 .7303 .19895 .72717 .19439 Mtetra
.658 .736 .907 r
.72717 .19439 .7303 .19895 .73716 .19644 .73405 .19204 Mtetra
.671 .75 .91 r
.73405 .19204 .73716 .19644 .74404 .1941 .74093 .18948 Mtetra
.669 .737 .901 r
.74093 .18948 .74404 .1941 .75093 .19158 .74782 .18693 Mtetra
.655 .73 .905 r
.74782 .18693 .75093 .19158 .75783 .1891 .75475 .18461 Mtetra
.65 .738 .913 r
.75475 .18461 .75783 .1891 .76475 .18661 .76171 .18237 Mtetra
.671 .761 .918 r
.76171 .18237 .76475 .18661 .77172 .18448 .76865 .17978 Mtetra
.67 .737 .9 r
.76865 .17978 .77172 .18448 .77868 .18195 .77561 .17719 Mtetra
.651 .725 .904 r
.77561 .17719 .77868 .18195 .78563 .17925 .78262 .17493 Mtetra
.677 .76 .914 r
.78262 .17493 .78563 .17925 .79265 .17705 .78961 .17223 Mtetra
.661 .728 .899 r
.78961 .17223 .79265 .17705 .79964 .17431 .79663 .16977 Mtetra
.667 .749 .911 r
.17158 .38642 .17554 .38998 .18114 .38809 .1772 .38437 Mtetra
.662 .739 .907 r
.1772 .38437 .18114 .38809 .18675 .38616 .18282 .3824 Mtetra
.656 .735 .908 r
.18282 .3824 .18675 .38616 .19239 .38405 .18845 .3805 Mtetra
.673 .752 .91 r
.18845 .3805 .19239 .38405 .19801 .38227 .19411 .37836 Mtetra
.645 .725 .907 r
.19411 .37836 .19801 .38227 .20366 .38025 .19974 .37661 Mtetra
.663 .746 .912 r
.19974 .37661 .20366 .38025 .20935 .37803 .20541 .37461 Mtetra
.685 .763 .911 r
.20541 .37461 .20935 .37803 .21501 .37622 .21113 .37227 Mtetra
.653 .727 .903 r
.21113 .37227 .21501 .37622 .2207 .37413 .21681 .37039 Mtetra
.663 .741 .908 r
.21681 .37039 .2207 .37413 .22641 .37204 .22252 .36838 Mtetra
.666 .747 .91 r
.22252 .36838 .22641 .37204 .23213 .36998 .22825 .3663 Mtetra
.668 .747 .91 r
.22825 .3663 .23213 .36998 .23784 .36815 .23399 .3642 Mtetra
.652 .728 .905 r
.23399 .3642 .23784 .36815 .24361 .36586 .23973 .36233 Mtetra
.671 .757 .915 r
.23973 .36233 .24361 .36586 .24934 .36412 .2455 .36017 Mtetra
.665 .733 .9 r
.2455 .36017 .24934 .36412 .25511 .36193 .25127 .35809 Mtetra
.653 .735 .91 r
.25127 .35809 .25511 .36193 .2609 .35978 .25705 .35619 Mtetra
.665 .753 .916 r
.25705 .35619 .2609 .35978 .26668 .35785 .26285 .35411 Mtetra
.663 .745 .911 r
.26285 .35411 .26668 .35785 .27249 .35583 .26866 .35205 Mtetra
.657 .741 .912 r
.26866 .35205 .27249 .35583 .27831 .35373 .27448 .35008 Mtetra
.663 .751 .915 r
.27448 .35008 .27831 .35373 .28415 .3515 .28032 .34801 Mtetra
.684 .766 .913 r
.28032 .34801 .28415 .3515 .28996 .34984 .28619 .34562 Mtetra
.642 .715 .9 r
.28619 .34562 .28996 .34984 .29582 .34776 .29203 .34385 Mtetra
.677 .741 .9 r
.29203 .34385 .29582 .34776 .30168 .34581 .29793 .34154 Mtetra
.633 .71 .902 r
.29793 .34154 .30168 .34581 .3076 .34323 .30379 .33989 Mtetra
.658 .77 .932 r
.30379 .33989 .3076 .34323 .31346 .34162 .30968 .33787 Mtetra
.656 .746 .916 r
.30968 .33787 .31346 .34162 .31935 .33982 .3156 .33588 Mtetra
.637 .73 .916 r
.3156 .33588 .31935 .33982 .32528 .33768 .3215 .33416 Mtetra
.638 .755 .933 r
.3215 .33416 .32528 .33768 .33126 .33492 .32743 .33239 Mtetra
.739 .837 .925 r
.32743 .33239 .33126 .33492 .33711 .33437 .33346 .3291 Mtetra
.377 .543 .893 r
.33346 .3291 .33711 .33437 .34307 .33239 .33923 .33042 Mtetra
.627 .854 .985 r
.33923 .33042 .34307 .33239 .34895 .33207 .34521 .32844 Mtetra
.289 .595 .948 r
.34521 .32844 .34895 .33207 .35501 .32877 .35103 .3296 Mtetra
.833 .995 .847 r
.35103 .3296 .35501 .32877 .36065 .33368 .35726 .32366 Mtetra
.315 .349 .737 r
.35726 .32366 .36065 .33368 .36687 .32784 .36298 .32757 Mtetra
.926 .916 .788 r
.36298 .32757 .36687 .32784 .37298 .32426 .36936 .31878 Mtetra
.483 .59 .885 r
.36936 .31878 .37298 .32426 .37886 .3258 .3753 .31915 Mtetra
.609 .606 .823 r
.3753 .31915 .37886 .3258 .38513 .31926 .38134 .31777 Mtetra
.89 .883 .82 r
.38134 .31777 .38513 .31926 .39125 .31606 .38766 .31037 Mtetra
.449 .564 .879 r
.38766 .31037 .39125 .31606 .39723 .31643 .39363 .31117 Mtetra
.667 .682 .855 r
.39363 .31117 .39723 .31643 .4034 .31288 .39975 .3088 Mtetra
.792 .767 .83 r
.39975 .3088 .4034 .31288 .40961 .30802 .40599 .3036 Mtetra
.577 .688 .917 r
.40599 .3036 .40961 .30802 .41566 .30828 .41209 .30264 Mtetra
.65 .662 .848 r
.41209 .30264 .41566 .30828 .42185 .30478 .41824 .30054 Mtetra
.735 .751 .865 r
.41824 .30054 .42185 .30478 .42805 .30124 .42445 .29691 Mtetra
.523 .671 .93 r
.42445 .29691 .42805 .30124 .43419 .30001 .43057 .29655 Mtetra
.761 .797 .882 r
.43057 .29655 .43419 .30001 .44038 .29748 .43682 .29257 Mtetra
.582 .666 .896 r
.43682 .29257 .44038 .29748 .44657 .29587 .44299 .29159 Mtetra
.737 .752 .864 r
.44299 .29159 .44657 .29587 .45282 .292 .44925 .28789 Mtetra
.607 .719 .925 r
.44925 .28789 .45282 .292 .45902 .29109 .45547 .2865 Mtetra
.634 .705 .897 r
.45547 .2865 .45902 .29109 .46526 .28893 .46171 .28474 Mtetra
.68 .742 .898 r
.46171 .28474 .46526 .28893 .47152 .28648 .46798 .28221 Mtetra
.655 .73 .904 r
.46798 .28221 .47152 .28648 .4778 .28391 .47426 .28011 Mtetra
.714 .773 .899 r
.47426 .28011 .4778 .28391 .48409 .28091 .48056 .27702 Mtetra
.63 .743 .929 r
.48056 .27702 .48409 .28091 .49037 .28002 .48686 .27526 Mtetra
.675 .714 .878 r
.48686 .27526 .49037 .28002 .49669 .27775 .49319 .27275 Mtetra
.592 .67 .894 r
.49319 .27275 .49669 .27775 .50302 .27569 .49952 .27161 Mtetra
.72 .763 .886 r
.49952 .27161 .50302 .27569 .50936 .27277 .50588 .26832 Mtetra
.542 .677 .926 r
.50588 .26832 .50936 .27277 .51572 .27164 .51224 .26774 Mtetra
.755 .782 .875 r
.51224 .26774 .51572 .27164 .52209 .2694 .51862 .26372 Mtetra
.634 .66 .857 r
.51862 .26372 .52209 .2694 .52848 .26593 .52502 .26185 Mtetra
.489 .675 .947 r
.52502 .26185 .52848 .26593 .5349 .26752 .53144 .26172 Mtetra
.686 .678 .837 r
.53144 .26172 .5349 .26752 .54132 .26471 .53787 .25875 Mtetra
.671 .666 .837 r
.53787 .25875 .54132 .26471 .54773 .25943 .54431 .25607 Mtetra
.157 .533 .922 r
.54431 .25607 .54773 .25943 .55423 .26209 .5508 .258 Mtetra
.794 .785 .844 r
.5508 .258 .55423 .26209 .56071 .26078 .55725 .2528 Mtetra
.589 .566 .796 r
.55725 .2528 .56071 .26078 .56713 .25334 .56376 .25168 Mtetra
.034 .558 .864 r
.56376 .25168 .56713 .25334 .57374 .25796 .57032 .25294 Mtetra
.859 .758 .75 r
.57032 .25294 .57374 .25796 .58026 .25561 .57674 .24381 Mtetra
.323 .33 .712 r
.57674 .24381 .58026 .25561 .58664 .24527 .58342 .24886 Mtetra
.682 .886 .516 r
.58342 .24886 .58664 .24527 .59326 .24664 .58984 .23997 Mtetra
.533 .577 .845 r
.58984 .23997 .59326 .24664 .59973 .24071 .59646 .23986 Mtetra
.874 .963 .854 r
.59646 .23986 .59973 .24071 .60632 .23927 .60294 .23324 Mtetra
.595 .633 .859 r
.60294 .23324 .60632 .23927 .61286 .23505 .60956 .23203 Mtetra
.674 .823 .955 r
.60956 .23203 .61286 .23505 .61947 .23325 .61617 .22947 Mtetra
.691 .782 .92 r
.61617 .22947 .61947 .23325 .62609 .23105 .62278 .22667 Mtetra
.673 .743 .903 r
.62278 .22667 .62609 .23105 .63271 .22845 .62942 .22414 Mtetra
.667 .746 .909 r
.62942 .22414 .63271 .22845 .63934 .22557 .63607 .22172 Mtetra
.686 .778 .921 r
.63607 .22172 .63934 .22557 .64601 .22355 .64273 .21899 Mtetra
.663 .732 .9 r
.64273 .21899 .64601 .22355 .65269 .22129 .64941 .2166 Mtetra
.666 .727 .895 r
.64941 .2166 .65269 .22129 .65937 .21861 .65612 .21417 Mtetra
.653 .735 .909 r
.65612 .21417 .65937 .21861 .66608 .21615 .66284 .21195 Mtetra
.673 .756 .913 r
.66284 .21195 .66608 .21615 .67281 .21393 .66957 .2094 Mtetra
.672 .739 .9 r
.66957 .2094 .67281 .21393 .67955 .21154 .67631 .20685 Mtetra
.661 .727 .898 r
.67631 .20685 .67955 .21154 .68631 .20913 .68308 .20446 Mtetra
.656 .726 .901 r
.68308 .20446 .68631 .20913 .69307 .20662 .68987 .20218 Mtetra
.663 .742 .909 r
.68987 .20218 .69307 .20662 .69985 .20399 .69667 .19977 Mtetra
.68 .761 .912 r
.69667 .19977 .69985 .20399 .70667 .2018 .70347 .19707 Mtetra
.647 .721 .902 r
.70347 .19707 .70667 .2018 .71348 .19932 .71032 .19491 Mtetra
.674 .749 .908 r
.71032 .19491 .71348 .19932 .72032 .19687 .71716 .1923 Mtetra
.654 .734 .908 r
.71716 .1923 .72032 .19687 .72717 .19439 .72404 .19002 Mtetra
.674 .752 .91 r
.72404 .19002 .72717 .19439 .73405 .19204 .73091 .1874 Mtetra
.663 .735 .903 r
.73091 .1874 .73405 .19204 .74093 .18948 .73781 .18494 Mtetra
.657 .738 .909 r
.73781 .18494 .74093 .18948 .74782 .18693 .74473 .18259 Mtetra
.657 .749 .918 r
.74473 .18259 .74782 .18693 .75475 .18461 .75167 .18023 Mtetra
.674 .755 .911 r
.75167 .18023 .75475 .18461 .76171 .18237 .7586 .17758 Mtetra
.66 .728 .899 r
.7586 .17758 .76171 .18237 .76865 .17978 .76557 .17515 Mtetra
.652 .733 .909 r
.76557 .17515 .76865 .17978 .77561 .17719 .77257 .17286 Mtetra
.678 .761 .914 r
.77257 .17286 .77561 .17719 .78262 .17493 .77955 .17013 Mtetra
.664 .731 .899 r
.77955 .17013 .78262 .17493 .78961 .17223 .78657 .16761 Mtetra
.654 .737 .91 r
.78657 .16761 .78961 .17223 .79663 .16977 .79362 .16527 Mtetra
.658 .739 .91 r
.16762 .38272 .17158 .38642 .1772 .38437 .17323 .38079 Mtetra
.67 .749 .91 r
.17323 .38079 .1772 .38437 .18282 .3824 .17887 .37868 Mtetra
.66 .74 .909 r
.17887 .37868 .18282 .3824 .18845 .3805 .18451 .37672 Mtetra
.657 .736 .908 r
.18451 .37672 .18845 .3805 .19411 .37836 .19016 .3748 Mtetra
.676 .753 .909 r
.19016 .3748 .19411 .37836 .19974 .37661 .19584 .37259 Mtetra
.642 .719 .904 r
.19584 .37259 .19974 .37661 .20541 .37461 .20149 .37087 Mtetra
.663 .741 .908 r
.20149 .37087 .20541 .37461 .21113 .37227 .20719 .36884 Mtetra
.68 .763 .914 r
.20719 .36884 .21113 .37227 .21681 .37039 .21292 .36656 Mtetra
.66 .736 .906 r
.21292 .36656 .21681 .37039 .22252 .36838 .21863 .36458 Mtetra
.657 .738 .909 r
.21863 .36458 .22252 .36838 .22825 .3663 .22435 .36263 Mtetra
.668 .748 .91 r
.22435 .36263 .22825 .3663 .23399 .3642 .2301 .36052 Mtetra
.659 .745 .914 r
.2301 .36052 .23399 .3642 .23973 .36233 .23585 .35854 Mtetra
.672 .743 .904 r
.23585 .35854 .23973 .36233 .2455 .36017 .24163 .35635 Mtetra
.649 .736 .913 r
.24163 .35635 .2455 .36017 .25127 .35809 .24739 .3545 Mtetra
.673 .756 .913 r
.24739 .3545 .25127 .35809 .25705 .35619 .2532 .3523 Mtetra
.672 .739 .901 r
.2532 .3523 .25705 .35619 .26285 .35411 .25902 .35009 Mtetra
.665 .731 .899 r
.25902 .35009 .26285 .35411 .26866 .35205 .26484 .34797 Mtetra
.657 .726 .9 r
.26484 .34797 .26866 .35205 .27448 .35008 .27067 .34599 Mtetra
.649 .724 .903 r
.27067 .34599 .27448 .35008 .28032 .34801 .2765 .34411 Mtetra
.653 .735 .91 r
.2765 .34411 .28032 .34801 .28619 .34562 .28234 .34218 Mtetra
.692 .771 .912 r
.28234 .34218 .28619 .34562 .29203 .34385 .28825 .33964 Mtetra
.62 .709 .909 r
.28825 .33964 .29203 .34385 .29793 .34154 .29409 .33818 Mtetra
.666 .771 .928 r
.29409 .33818 .29793 .34154 .30379 .33989 .29999 .33605 Mtetra
.685 .749 .9 r
.29999 .33605 .30379 .33989 .30968 .33787 .30593 .33359 Mtetra
.672 .723 .888 r
.30593 .33359 .30968 .33787 .3156 .33588 .31186 .33131 Mtetra
.636 .697 .89 r
.31186 .33131 .3156 .33588 .3215 .33416 .31778 .3296 Mtetra
.551 .666 .913 r
.31778 .3296 .3215 .33416 .32743 .33239 .32363 .329 Mtetra
.427 .682 .97 r
.32363 .329 .32743 .33239 .33346 .3291 .32946 .32915 Mtetra
.676 .966 .931 r
.32946 .32915 .33346 .3291 .33923 .33042 .33552 .32571 Mtetra
.458 .616 .918 r
.33552 .32571 .33923 .33042 .34521 .32844 .34137 .3261 Mtetra
.562 .811 .992 r
.34137 .3261 .34521 .32844 .35103 .3296 .34734 .3248 Mtetra
.606 .678 .892 r
.34734 .3248 .35103 .3296 .35726 .32366 .35333 .32351 Mtetra
.893 .947 .836 r
.35333 .32351 .35726 .32366 .36298 .32757 .35963 .3165 Mtetra
.523 .462 .729 r
.35963 .3165 .36298 .32757 .36936 .31878 .36555 .31696 Mtetra
.863 .875 .845 r
.36555 .31696 .36936 .31878 .3753 .31915 .37182 .3106 Mtetra
.482 .485 .784 r
.37182 .3106 .3753 .31915 .38134 .31777 .37775 .31159 Mtetra
.722 .67 .799 r
.37775 .31159 .38134 .31777 .38766 .31037 .38393 .30755 Mtetra
.727 .825 .926 r
.38393 .30755 .38766 .31037 .39363 .31117 .39008 .30439 Mtetra
.603 .601 .822 r
.39008 .30439 .39363 .31117 .39975 .3088 .39616 .3031 Mtetra
.676 .67 .836 r
.39616 .3031 .39975 .3088 .40599 .3036 .40231 .30044 Mtetra
.739 .809 .907 r
.40231 .30044 .40599 .3036 .41209 .30264 .4085 .297 Mtetra
.54 .614 .875 r
.4085 .297 .41209 .30264 .41824 .30054 .41459 .29668 Mtetra
.758 .775 .867 r
.41459 .29668 .41824 .30054 .42445 .29691 .42083 .29263 Mtetra
.623 .716 .912 r
.42083 .29263 .42445 .29691 .43057 .29655 .427 .29103 Mtetra
.667 .675 .848 r
.427 .29103 .43057 .29655 .43682 .29257 .43321 .28857 Mtetra
.683 .752 .904 r
.43321 .28857 .43682 .29257 .44299 .29159 .43943 .28603 Mtetra
.636 .662 .858 r
.43943 .28603 .44299 .29159 .44925 .28789 .44565 .28419 Mtetra
.634 .754 .935 r
.44565 .28419 .44925 .28789 .45547 .2865 .45189 .28238 Mtetra
.669 .743 .906 r
.45189 .28238 .45547 .2865 .46171 .28474 .45815 .28006 Mtetra
.635 .702 .895 r
.45815 .28006 .46171 .28474 .46798 .28221 .46441 .27827 Mtetra
.664 .752 .915 r
.46441 .27827 .46798 .28221 .47426 .28011 .4707 .27602 Mtetra
.703 .756 .893 r
.4707 .27602 .47426 .28011 .48056 .27702 .47702 .27309 Mtetra
.684 .76 .909 r
.47702 .27309 .48056 .27702 .48686 .27526 .48334 .2705 Mtetra
.608 .689 .9 r
.48334 .2705 .48686 .27526 .49319 .27275 .48966 .2691 Mtetra
.733 .789 .898 r
.48966 .2691 .49319 .27275 .49952 .27161 .49602 .26565 Mtetra
.63 .647 .848 r
.49602 .26565 .49952 .27161 .50588 .26832 .50237 .26383 Mtetra
.589 .697 .917 r
.50237 .26383 .50588 .26832 .51224 .26774 .50874 .26266 Mtetra
.734 .723 .841 r
.50874 .26266 .51224 .26774 .51862 .26372 .51514 .25872 Mtetra
.497 .628 .909 r
.51514 .25872 .51862 .26372 .52502 .26185 .52154 .25877 Mtetra
.71 .821 .934 r
.52154 .25877 .52502 .26185 .53144 .26172 .52797 .25576 Mtetra
.7 .679 .826 r
.52797 .25576 .53144 .26172 .53787 .25875 .5344 .25239 Mtetra
.526 .583 .855 r
.5344 .25239 .53787 .25875 .54431 .25607 .54086 .25233 Mtetra
.687 .778 .92 r
.54086 .25233 .54431 .25607 .5508 .258 .54733 .24967 Mtetra
.66 .595 .772 r
.54733 .24967 .5508 .258 .55725 .2528 .55381 .24667 Mtetra
.433 .543 .868 r
.55381 .24667 .55725 .2528 .56376 .25168 .56035 .24781 Mtetra
.837 .802 .817 r
.56035 .24781 .56376 .25168 .57032 .25294 .56681 .24119 Mtetra
.314 .325 .712 r
.56681 .24119 .57032 .25294 .57674 .24381 .57345 .24633 Mtetra
.637 .912 .617 r
.57345 .24633 .57674 .24381 .58342 .24886 .57993 .23963 Mtetra
.497 .486 .775 r
.57993 .23963 .58342 .24886 .58984 .23997 .58656 .24051 Mtetra
.882 .992 .784 r
.58656 .24051 .58984 .23997 .59646 .23986 .59303 .23272 Mtetra
.501 .545 .833 r
.59303 .23272 .59646 .23986 .60294 .23324 .59969 .23319 Mtetra
.713 .984 .891 r
.59969 .23319 .60294 .23324 .60956 .23203 .60625 .22871 Mtetra
.767 .829 .901 r
.60625 .22871 .60956 .23203 .61617 .22947 .61282 .22454 Mtetra
.692 .723 .874 r
.61282 .22454 .61617 .22947 .62278 .22667 .61943 .22158 Mtetra
.656 .702 .881 r
.61943 .22158 .62278 .22667 .62942 .22414 .62609 .2193 Mtetra
.641 .708 .895 r
.62609 .2193 .62942 .22414 .63607 .22172 .63277 .21727 Mtetra
.654 .735 .908 r
.63277 .21727 .63607 .22172 .64273 .21899 .63945 .21504 Mtetra
.702 .78 .912 r
.63945 .21504 .64273 .21899 .64941 .2166 .64613 .21201 Mtetra
.638 .721 .908 r
.64613 .21201 .64941 .2166 .65612 .21417 .65286 .21003 Mtetra
.686 .765 .911 r
.65286 .21003 .65612 .21417 .66284 .21195 .65957 .20726 Mtetra
.669 .73 .895 r
.65957 .20726 .66284 .21195 .66957 .2094 .66631 .20474 Mtetra
.657 .727 .901 r
.66631 .20474 .66957 .2094 .67631 .20685 .67308 .20243 Mtetra
.665 .743 .909 r
.67308 .20243 .67631 .20685 .68308 .20446 .67986 .19999 Mtetra
.666 .741 .906 r
.67986 .19999 .68308 .20446 .68987 .20218 .68665 .19752 Mtetra
.653 .728 .904 r
.68665 .19752 .68987 .20218 .69667 .19977 .69347 .19526 Mtetra
.659 .738 .908 r
.69347 .19526 .69667 .19977 .70347 .19707 .7003 .1929 Mtetra
.684 .767 .914 r
.7003 .1929 .70347 .19707 .71032 .19491 .70713 .19012 Mtetra
.643 .718 .902 r
.70713 .19012 .71032 .19491 .71716 .1923 .71401 .18801 Mtetra
.68 .76 .912 r
.71401 .18801 .71716 .1923 .72404 .19002 .72087 .18529 Mtetra
.656 .728 .902 r
.72087 .18529 .72404 .19002 .73091 .1874 .72777 .18295 Mtetra
.661 .745 .913 r
.72777 .18295 .73091 .1874 .73781 .18494 .73468 .18054 Mtetra
.665 .75 .913 r
.73468 .18054 .73781 .18494 .74473 .18259 .74161 .17804 Mtetra
.676 .747 .904 r
.74161 .17804 .74473 .18259 .75167 .18023 .74853 .17534 Mtetra
.648 .718 .899 r
.74853 .17534 .75167 .18023 .7586 .17758 .75551 .17311 Mtetra
.654 .743 .915 r
.75551 .17311 .7586 .17758 .76557 .17515 .7625 .17078 Mtetra
.677 .758 .913 r
.7625 .17078 .76557 .17515 .77257 .17286 .76948 .16806 Mtetra
.669 .734 .898 r
.76948 .16806 .77257 .17286 .77955 .17013 .77648 .16545 Mtetra
.653 .734 .908 r
.77648 .16545 .77955 .17013 .78657 .16761 .78353 .16312 Mtetra
.673 .752 .91 r
.78353 .16312 .78657 .16761 .79362 .16527 .79056 .16045 Mtetra
.656 .734 .907 r
.16365 .37892 .16762 .38272 .17323 .38079 .16927 .37701 Mtetra
.659 .736 .907 r
.16927 .37701 .17323 .38079 .17887 .37868 .1749 .37506 Mtetra
.668 .748 .91 r
.1749 .37506 .17887 .37868 .18451 .37672 .18055 .37298 Mtetra
.656 .739 .911 r
.18055 .37298 .18451 .37672 .19016 .3748 .1862 .37107 Mtetra
.662 .742 .909 r
.1862 .37107 .19016 .3748 .19584 .37259 .19188 .36907 Mtetra
.681 .758 .91 r
.19188 .36907 .19584 .37259 .20149 .37087 .19759 .36677 Mtetra
.645 .718 .901 r
.19759 .36677 .20149 .37087 .20719 .36884 .20326 .365 Mtetra
.661 .736 .905 r
.20326 .365 .20719 .36884 .21292 .36656 .20897 .36298 Mtetra
.673 .754 .912 r
.20897 .36298 .21292 .36656 .21863 .36458 .21471 .3608 Mtetra
.667 .743 .907 r
.21471 .3608 .21863 .36458 .22435 .36263 .22046 .3587 Mtetra
.648 .729 .908 r
.22046 .3587 .22435 .36263 .2301 .36052 .22619 .35686 Mtetra
.682 .753 .906 r
.22619 .35686 .2301 .36052 .23585 .35854 .23198 .35453 Mtetra
.64 .723 .908 r
.23198 .35453 .23585 .35854 .24163 .35635 .23772 .3528 Mtetra
.678 .759 .912 r
.23772 .3528 .24163 .35635 .24739 .3545 .24353 .35051 Mtetra
.667 .733 .899 r
.24353 .35051 .24739 .3545 .2532 .3523 .24934 .34837 Mtetra
.652 .733 .909 r
.24934 .34837 .2532 .3523 .25902 .35009 .25514 .34647 Mtetra
.659 .752 .919 r
.25514 .34647 .25902 .35009 .26484 .34797 .26096 .34445 Mtetra
.664 .759 .921 r
.26096 .34445 .26484 .34797 .27067 .34599 .2668 .34236 Mtetra
.681 .759 .91 r
.2668 .34236 .27067 .34599 .2765 .34411 .27268 .34001 Mtetra
.638 .721 .908 r
.27268 .34001 .2765 .34411 .28234 .34218 .27851 .33828 Mtetra
.651 .736 .912 r
.27851 .33828 .28234 .34218 .28825 .33964 .28438 .33637 Mtetra
.668 .777 .931 r
.28438 .33637 .28825 .33964 .29409 .33818 .29028 .3342 Mtetra
.682 .741 .896 r
.29028 .3342 .29409 .33818 .29999 .33605 .29621 .33178 Mtetra
.602 .701 .913 r
.29621 .33178 .29999 .33605 .30593 .33359 .30207 .33054 Mtetra
.606 .776 .962 r
.30207 .33054 .30593 .33359 .31186 .33131 .30796 .32907 Mtetra
.593 .826 .988 r
.30796 .32907 .31186 .33131 .31778 .3296 .31387 .3275 Mtetra
.66 .854 .974 r
.31387 .3275 .31778 .3296 .32363 .329 .31984 .32523 Mtetra
.749 .77 .87 r
.31984 .32523 .32363 .329 .32946 .32915 .32592 .32146 Mtetra
.302 .402 .798 r
.32592 .32146 .32946 .32915 .33552 .32571 .3316 .32443 Mtetra
.689 .911 .972 r
.3316 .32443 .33552 .32571 .34137 .3261 .33765 .32158 Mtetra
.624 .699 .899 r
.33765 .32158 .34137 .3261 .34734 .3248 .34364 .32002 Mtetra
.736 .723 .839 r
.34364 .32002 .34734 .3248 .35333 .32351 .34977 .31617 Mtetra
.65 .606 .792 r
.34977 .31617 .35333 .32351 .35963 .3165 .35583 .31377 Mtetra
.73 .83 .926 r
.35583 .31377 .35963 .3165 .36555 .31696 .36195 .31058 Mtetra
.574 .6 .841 r
.36195 .31058 .36555 .31696 .37182 .3106 .36795 .30981 Mtetra
.849 .939 .882 r
.36795 .30981 .37182 .3106 .37775 .31159 .37421 .30418 Mtetra
.539 .549 .813 r
.37421 .30418 .37775 .31159 .38393 .30755 .38021 .30405 Mtetra
.697 .78 .915 r
.38021 .30405 .38393 .30755 .39008 .30439 .38635 .30134 Mtetra
.746 .816 .907 r
.38635 .30134 .39008 .30439 .39616 .3031 .39253 .2978 Mtetra
.579 .647 .881 r
.39253 .2978 .39616 .3031 .40231 .30044 .39862 .29689 Mtetra
.75 .79 .885 r
.39862 .29689 .40231 .30044 .4085 .297 .40484 .29313 Mtetra
.669 .753 .914 r
.40484 .29313 .4085 .297 .41459 .29668 .41101 .29084 Mtetra
.607 .637 .855 r
.41101 .29084 .41459 .29668 .42083 .29263 .41716 .28951 Mtetra
.712 .809 .925 r
.41716 .28951 .42083 .29263 .427 .29103 .42338 .28655 Mtetra
.586 .692 .915 r
.42338 .28655 .427 .29103 .43321 .28857 .42956 .28545 Mtetra
.758 .818 .9 r
.42956 .28545 .43321 .28857 .43943 .28603 .43583 .28161 Mtetra
.586 .696 .918 r
.43583 .28161 .43943 .28603 .44565 .28419 .44204 .2805 Mtetra
.674 .768 .922 r
.44204 .2805 .44565 .28419 .45189 .28238 .44829 .27811 Mtetra
.691 .743 .891 r
.44829 .27811 .45189 .28238 .45815 .28006 .45457 .27537 Mtetra
.681 .719 .878 r
.45457 .27537 .45815 .28006 .46441 .27827 .46086 .27277 Mtetra
.642 .669 .861 r
.46086 .27277 .46441 .27827 .4707 .27602 .46715 .27079 Mtetra
.632 .677 .875 r
.46715 .27079 .4707 .27602 .47702 .27309 .47346 .26901 Mtetra
.7 .757 .897 r
.47346 .26901 .47702 .27309 .48334 .2705 .47979 .26613 Mtetra
.602 .707 .918 r
.47979 .26613 .48334 .2705 .48966 .2691 .48612 .26478 Mtetra
.701 .746 .887 r
.48612 .26478 .48966 .2691 .49602 .26565 .49248 .26182 Mtetra
.575 .73 .947 r
.49248 .26182 .49602 .26565 .50237 .26383 .49885 .2607 Mtetra
.745 .824 .913 r
.49885 .2607 .50237 .26383 .50874 .26266 .50524 .25708 Mtetra
.62 .659 .866 r
.50524 .25708 .50874 .26266 .51514 .25872 .51164 .25546 Mtetra
.637 .789 .955 r
.51164 .25546 .51514 .25872 .52154 .25877 .51805 .25349 Mtetra
.702 .705 .85 r
.51805 .25349 .52154 .25877 .52797 .25576 .52448 .25027 Mtetra
.543 .629 .886 r
.52448 .25027 .52797 .25576 .5344 .25239 .53093 .24983 Mtetra
.637 .837 .977 r
.53093 .24983 .5344 .25239 .54086 .25233 .5374 .24768 Mtetra
.729 .743 .864 r
.5374 .24768 .54086 .25233 .54733 .24967 .54387 .24401 Mtetra
.451 .574 .887 r
.54387 .24401 .54733 .24967 .55381 .24667 .55039 .24476 Mtetra
.812 .911 .907 r
.55039 .24476 .55381 .24667 .56035 .24781 .55687 .23983 Mtetra
.53 .535 .805 r
.55687 .23983 .56035 .24781 .56681 .24119 .56343 .23989 Mtetra
.779 .947 .931 r
.56343 .23989 .56681 .24119 .57345 .24633 .56994 .23546 Mtetra
.418 .407 .74 r
.56994 .23546 .57345 .24633 .57993 .23963 .57658 .23826 Mtetra
.855 .941 .876 r
.57658 .23826 .57993 .23963 .58656 .24051 .58309 .23223 Mtetra
.488 .504 .8 r
.58309 .23223 .58656 .24051 .59303 .23272 .58975 .23309 Mtetra
.878 .992 .795 r
.58975 .23309 .59303 .23272 .59969 .23319 .59624 .22552 Mtetra
.615 .591 .803 r
.59624 .22552 .59969 .23319 .60625 .22871 .60287 .22381 Mtetra
.634 .702 .895 r
.60287 .22381 .60625 .22871 .61282 .22454 .60952 .22191 Mtetra
.692 .856 .961 r
.60952 .22191 .61282 .22454 .61943 .22158 .61615 .21901 Mtetra
.7 .863 .96 r
.61615 .21901 .61943 .22158 .62609 .2193 .6228 .21598 Mtetra
.716 .821 .93 r
.6228 .21598 .62609 .2193 .63277 .21727 .62945 .21275 Mtetra
.666 .736 .902 r
.62945 .21275 .63277 .21727 .63945 .21504 .63614 .21031 Mtetra
.642 .716 .902 r
.63614 .21031 .63945 .21504 .64613 .21201 .64286 .20826 Mtetra
.697 .791 .923 r
.64286 .20826 .64613 .21201 .65286 .21003 .64956 .20531 Mtetra
.656 .724 .899 r
.64956 .20531 .65286 .21003 .65957 .20726 .65631 .20302 Mtetra
.654 .749 .919 r
.65631 .20302 .65957 .20726 .66631 .20474 .66307 .20075 Mtetra
.668 .769 .926 r
.66307 .20075 .66631 .20474 .67308 .20243 .66984 .19827 Mtetra
.665 .759 .92 r
.66984 .19827 .67308 .20243 .67986 .19999 .67663 .19582 Mtetra
.669 .76 .919 r
.67663 .19582 .67986 .19999 .68665 .19752 .68344 .1933 Mtetra
.682 .763 .913 r
.68344 .1933 .68665 .19752 .69347 .19526 .69024 .19056 Mtetra
.65 .725 .904 r
.69024 .19056 .69347 .19526 .7003 .1929 .69709 .18834 Mtetra
.662 .738 .907 r
.69709 .18834 .7003 .1929 .70713 .19012 .70395 .18592 Mtetra
.672 .762 .918 r
.70395 .18592 .70713 .19012 .71401 .18801 .71081 .18332 Mtetra
.661 .732 .902 r
.71081 .18332 .71401 .18801 .72087 .18529 .7177 .18089 Mtetra
.66 .748 .915 r
.7177 .18089 .72087 .18529 .72777 .18295 .72461 .17847 Mtetra
.67 .748 .909 r
.72461 .17847 .72777 .18295 .73468 .18054 .73153 .17589 Mtetra
.671 .741 .902 r
.73153 .17589 .73468 .18054 .74161 .17804 .73846 .17327 Mtetra
.648 .725 .905 r
.73846 .17327 .74161 .17804 .74853 .17534 .74543 .17104 Mtetra
.658 .755 .922 r
.74543 .17104 .74853 .17534 .75551 .17311 .75241 .16864 Mtetra
.675 .753 .91 r
.75241 .16864 .75551 .17311 .7625 .17078 .75939 .16594 Mtetra
.666 .731 .898 r
.75939 .16594 .7625 .17078 .76948 .16806 .76639 .16339 Mtetra
.659 .737 .907 r
.76639 .16339 .76948 .16806 .77648 .16545 .77342 .16096 Mtetra
.667 .75 .912 r
.77342 .16096 .77648 .16545 .78353 .16312 .78046 .15838 Mtetra
.67 .739 .902 r
.78046 .15838 .78353 .16312 .79056 .16045 .7875 .15573 Mtetra
.665 .742 .908 r
.15966 .3752 .16365 .37892 .16927 .37701 .16529 .37317 Mtetra
.654 .733 .907 r
.16529 .37317 .16927 .37701 .1749 .37506 .17092 .37128 Mtetra
.663 .739 .906 r
.17092 .37128 .1749 .37506 .18055 .37298 .17658 .36925 Mtetra
.663 .742 .909 r
.17658 .36925 .18055 .37298 .1862 .37107 .18225 .36723 Mtetra
.653 .733 .908 r
.18225 .36723 .1862 .37107 .19188 .36907 .18791 .36534 Mtetra
.665 .744 .909 r
.18791 .36534 .19188 .36907 .19759 .36677 .19361 .36328 Mtetra
.68 .76 .912 r
.19361 .36328 .19759 .36677 .20326 .365 .19934 .36099 Mtetra
.652 .726 .903 r
.19934 .36099 .20326 .365 .20897 .36298 .20505 .3591 Mtetra
.66 .735 .906 r
.20505 .3591 .20897 .36298 .21471 .3608 .21077 .3571 Mtetra
.669 .747 .909 r
.21077 .3571 .21471 .3608 .22046 .3587 .21653 .35496 Mtetra
.665 .745 .91 r
.21653 .35496 .22046 .3587 .22619 .35686 .22229 .35287 Mtetra
.652 .728 .905 r
.22229 .35287 .22619 .35686 .23198 .35453 .22804 .35097 Mtetra
.67 .758 .916 r
.22804 .35097 .23198 .35453 .23772 .3528 .23383 .34881 Mtetra
.667 .734 .899 r
.23383 .34881 .23772 .3528 .24353 .35051 .23964 .34666 Mtetra
.648 .736 .913 r
.23964 .34666 .24353 .35051 .24934 .34837 .24543 .3448 Mtetra
.663 .757 .92 r
.24543 .3448 .24934 .34837 .25514 .34647 .25125 .34273 Mtetra
.661 .747 .914 r
.25125 .34273 .25514 .34647 .26096 .34445 .25708 .34068 Mtetra
.655 .744 .915 r
.25708 .34068 .26096 .34445 .2668 .34236 .26292 .3387 Mtetra
.662 .753 .917 r
.26292 .3387 .2668 .34236 .27268 .34001 .26878 .33662 Mtetra
.693 .776 .915 r
.26878 .33662 .27268 .34001 .27851 .33828 .27469 .33407 Mtetra
.625 .712 .909 r
.27469 .33407 .27851 .33828 .28438 .33637 .28054 .33252 Mtetra
.685 .75 .901 r
.28054 .33252 .28438 .33637 .29028 .3342 .28647 .33006 Mtetra
.598 .707 .92 r
.28647 .33006 .29028 .3342 .29621 .33178 .29231 .32885 Mtetra
.648 .795 .953 r
.29231 .32885 .29621 .33178 .30207 .33054 .29823 .32689 Mtetra
.659 .755 .921 r
.29823 .32689 .30207 .33054 .30796 .32907 .30417 .32483 Mtetra
.62 .711 .911 r
.30417 .32483 .30796 .32907 .31387 .3275 .31008 .32333 Mtetra
.551 .689 .931 r
.31008 .32333 .31387 .3275 .31984 .32523 .31596 .32264 Mtetra
.567 .796 .985 r
.31596 .32264 .31984 .32523 .32592 .32146 .32189 .32139 Mtetra
.847 .967 .878 r
.32189 .32139 .32592 .32146 .3316 .32443 .32811 .31573 Mtetra
.37 .414 .777 r
.32811 .31573 .3316 .32443 .33765 .32158 .33383 .31831 Mtetra
.797 .803 .856 r
.33383 .31831 .33765 .32158 .34364 .32002 .34003 .31342 Mtetra
.606 .607 .827 r
.34003 .31342 .34364 .32002 .34977 .31617 .34602 .31209 Mtetra
.759 .76 .853 r
.34602 .31209 .34977 .31617 .35583 .31377 .35219 .30791 Mtetra
.638 .648 .844 r
.35219 .30791 .35583 .31377 .36195 .31058 .35824 .30602 Mtetra
.716 .73 .861 r
.35824 .30602 .36195 .31058 .36795 .30981 .36438 .30275 Mtetra
.617 .599 .81 r
.36438 .30275 .36795 .30981 .37421 .30418 .37044 .30116 Mtetra
.747 .817 .907 r
.37044 .30116 .37421 .30418 .38021 .30405 .37661 .29759 Mtetra
.605 .613 .833 r
.37661 .29759 .38021 .30405 .38635 .30134 .38269 .29626 Mtetra
.668 .693 .864 r
.38269 .29626 .38635 .30134 .39253 .2978 .38884 .29388 Mtetra
.704 .76 .896 r
.38884 .29388 .39253 .2978 .39862 .29689 .39501 .29099 Mtetra
.592 .628 .857 r
.39501 .29099 .39862 .29689 .40484 .29313 .40113 .2899 Mtetra
.702 .8 .926 r
.40113 .2899 .40484 .29313 .41101 .29084 .40733 .28711 Mtetra
.658 .759 .925 r
.40733 .28711 .41101 .29084 .41716 .28951 .41352 .28498 Mtetra
.681 .725 .883 r
.41352 .28498 .41716 .28951 .42338 .28655 .41974 .2824 Mtetra
.682 .745 .899 r
.41974 .2824 .42338 .28655 .42956 .28545 .42596 .27985 Mtetra
.618 .654 .863 r
.42596 .27985 .42956 .28545 .43583 .28161 .43218 .27831 Mtetra
.698 .798 .927 r
.43218 .27831 .43583 .28161 .44204 .2805 .43844 .27554 Mtetra
.663 .7 .875 r
.43844 .27554 .44204 .2805 .44829 .27811 .4447 .27325 Mtetra
.641 .697 .886 r
.4447 .27325 .44829 .27811 .45457 .27537 .45097 .27132 Mtetra
.667 .748 .911 r
.45097 .27132 .45457 .27537 .46086 .27277 .45726 .26902 Mtetra
.692 .773 .914 r
.45726 .26902 .46086 .27277 .46715 .27079 .46358 .26632 Mtetra
.635 .715 .905 r
.46358 .26632 .46715 .27079 .47346 .26901 .46989 .26449 Mtetra
.626 .71 .906 r
.46989 .26449 .47346 .26901 .47979 .26613 .47622 .26279 Mtetra
.713 .804 .922 r
.47622 .26279 .47979 .26613 .48612 .26478 .48258 .25974 Mtetra
.642 .692 .881 r
.48258 .25974 .48612 .26478 .49248 .26182 .48894 .25778 Mtetra
.698 .761 .901 r
.48894 .25778 .49248 .26182 .49885 .2607 .49532 .25491 Mtetra
.628 .654 .857 r
.49532 .25491 .49885 .2607 .50524 .25708 .50171 .25313 Mtetra
.616 .74 .935 r
.50171 .25313 .50524 .25708 .51164 .25546 .50812 .25152 Mtetra
.716 .774 .898 r
.50812 .25152 .51164 .25546 .51805 .25349 .51455 .24831 Mtetra
.591 .666 .891 r
.51455 .24831 .51805 .25349 .52448 .25027 .52099 .24714 Mtetra
.728 .825 .925 r
.52099 .24714 .52448 .25027 .53093 .24983 .52744 .2438 Mtetra
.634 .65 .849 r
.52744 .2438 .53093 .24983 .5374 .24768 .53391 .24187 Mtetra
.619 .652 .861 r
.53391 .24187 .5374 .24768 .54387 .24401 .5404 .24023 Mtetra
.727 .789 .901 r
.5404 .24023 .54387 .24401 .55039 .24476 .5469 .23681 Mtetra
.526 .534 .806 r
.5469 .23681 .55039 .24476 .55687 .23983 .55344 .23692 Mtetra
.765 .848 .914 r
.55344 .23692 .55687 .23983 .56343 .23989 .55995 .23288 Mtetra
.507 .553 .837 r
.55995 .23288 .56343 .23989 .56994 .23546 .56654 .23318 Mtetra
.816 .893 .898 r
.56654 .23318 .56994 .23546 .57658 .23826 .57307 .22811 Mtetra
.405 .412 .754 r
.57307 .22811 .57658 .23826 .58309 .23223 .57974 .23092 Mtetra
.91 .927 .813 r
.57974 .23092 .58309 .23223 .58975 .23309 .58623 .2229 Mtetra
.485 .461 .756 r
.58623 .2229 .58975 .23309 .59624 .22552 .59292 .22413 Mtetra
.636 .916 .979 r
.59292 .22413 .59624 .22552 .60287 .22381 .59954 .22138 Mtetra
.758 .884 .935 r
.59954 .22138 .60287 .22381 .60952 .22191 .60615 .21744 Mtetra
.707 .753 .888 r
.60615 .21744 .60952 .22191 .61615 .21901 .61279 .21423 Mtetra
.67 .725 .891 r
.61279 .21423 .61615 .21901 .6228 .21598 .61946 .2117 Mtetra
.669 .751 .912 r
.61946 .2117 .6228 .21598 .62945 .21275 .62614 .20921 Mtetra
.711 .807 .925 r
.62614 .20921 .62945 .21275 .63614 .21031 .63282 .20604 Mtetra
.666 .751 .914 r
.63282 .20604 .63614 .21031 .64286 .20826 .63954 .20359 Mtetra
.671 .733 .896 r
.63954 .20359 .64286 .20826 .64956 .20531 .64627 .20102 Mtetra
.649 .745 .92 r
.64627 .20102 .64956 .20531 .65631 .20302 .65304 .19884 Mtetra
.678 .763 .915 r
.65304 .19884 .65631 .20302 .66307 .20075 .65979 .19619 Mtetra
.675 .741 .901 r
.65979 .19619 .66307 .20075 .66984 .19827 .66657 .19356 Mtetra
.662 .729 .899 r
.66657 .19356 .66984 .19827 .67663 .19582 .67337 .19113 Mtetra
.655 .728 .903 r
.67337 .19113 .67663 .19582 .68344 .1933 .68019 .18882 Mtetra
.664 .743 .909 r
.68019 .18882 .68344 .1933 .69024 .19056 .68703 .18636 Mtetra
.686 .768 .913 r
.68703 .18636 .69024 .19056 .69709 .18834 .69386 .18353 Mtetra
.642 .718 .903 r
.69386 .18353 .69709 .18834 .70395 .18592 .70075 .18142 Mtetra
.676 .749 .906 r
.70075 .18142 .70395 .18592 .71081 .18332 .70762 .17873 Mtetra
.654 .736 .91 r
.70762 .17873 .71081 .18332 .7177 .18089 .71453 .17642 Mtetra
.675 .751 .908 r
.71453 .17642 .7177 .18089 .72461 .17847 .72143 .17375 Mtetra
.666 .735 .901 r
.72143 .17375 .72461 .17847 .73153 .17589 .72836 .17121 Mtetra
.654 .733 .907 r
.72836 .17121 .73153 .17589 .73846 .17327 .73532 .16888 Mtetra
.658 .75 .918 r
.73532 .16888 .73846 .17327 .74543 .17104 .7423 .16648 Mtetra
.673 .748 .907 r
.7423 .16648 .74543 .17104 .75241 .16864 .74927 .16381 Mtetra
.666 .732 .899 r
.74927 .16381 .75241 .16864 .75939 .16594 .75627 .16125 Mtetra
.659 .736 .907 r
.75627 .16125 .75939 .16594 .76639 .16339 .76329 .15882 Mtetra
.665 .746 .91 r
.76329 .15882 .76639 .16339 .77342 .16096 .77033 .15627 Mtetra
.671 .743 .904 r
.77033 .15627 .77342 .16096 .78046 .15838 .77737 .1536 Mtetra
.657 .733 .905 r
.77737 .1536 .78046 .15838 .7875 .15573 .78445 .15117 Mtetra
.663 .743 .91 r
.15564 .37151 .15966 .3752 .16529 .37317 .16128 .36948 Mtetra
.664 .744 .91 r
.16128 .36948 .16529 .37317 .17092 .37128 .16693 .36744 Mtetra
.657 .735 .907 r
.16693 .36744 .17092 .37128 .17658 .36925 .17259 .3655 Mtetra
.668 .743 .906 r
.17259 .3655 .17658 .36925 .18225 .36723 .17827 .36338 Mtetra
.656 .735 .908 r
.17827 .36338 .18225 .36723 .18791 .36534 .18395 .36145 Mtetra
.654 .733 .907 r
.18395 .36145 .18791 .36534 .19361 .36328 .18964 .35953 Mtetra
.672 .746 .906 r
.18964 .35953 .19361 .36328 .19934 .36099 .19537 .35734 Mtetra
.669 .751 .912 r
.19537 .35734 .19934 .36099 .20505 .3591 .2011 .35521 Mtetra
.66 .735 .905 r
.2011 .35521 .20505 .3591 .21077 .3571 .20684 .35319 Mtetra
.658 .735 .906 r
.20684 .35319 .21077 .3571 .21653 .35496 .21258 .3512 Mtetra
.672 .747 .907 r
.21258 .3512 .21653 .35496 .22229 .35287 .21836 .349 Mtetra
.649 .735 .912 r
.21836 .349 .22229 .35287 .22804 .35097 .22412 .34713 Mtetra
.682 .746 .899 r
.22412 .34713 .22804 .35097 .23383 .34881 .22994 .34475 Mtetra
.642 .724 .908 r
.22994 .34475 .23383 .34881 .23964 .34666 .23571 .34298 Mtetra
.665 .751 .915 r
.23571 .34298 .23964 .34666 .24543 .3448 .24153 .34086 Mtetra
.672 .739 .901 r
.24153 .34086 .24543 .3448 .25125 .34273 .24737 .33863 Mtetra
.664 .729 .898 r
.24737 .33863 .25125 .34273 .25708 .34068 .25322 .3365 Mtetra
.655 .723 .899 r
.25322 .3365 .25708 .34068 .26292 .3387 .25907 .33452 Mtetra
.648 .721 .902 r
.25907 .33452 .26292 .3387 .26878 .33662 .26492 .33264 Mtetra
.658 .735 .907 r
.26492 .33264 .26878 .33662 .27469 .33407 .27079 .33061 Mtetra
.694 .774 .913 r
.27079 .33061 .27469 .33407 .28054 .33252 .27673 .32804 Mtetra
.608 .693 .903 r
.27673 .32804 .28054 .33252 .28647 .33006 .28257 .32671 Mtetra
.665 .775 .931 r
.28257 .32671 .28647 .33006 .29231 .32885 .2885 .32456 Mtetra
.699 .733 .877 r
.2885 .32456 .29231 .32885 .29823 .32689 .29448 .32176 Mtetra
.658 .682 .861 r
.29448 .32176 .29823 .32689 .30417 .32483 .30044 .3196 Mtetra
.657 .678 .858 r
.30044 .3196 .30417 .32483 .31008 .32333 .3064 .31745 Mtetra
.614 .635 .848 r
.3064 .31745 .31008 .32333 .31596 .32264 .31233 .31601 Mtetra
.495 .55 .842 r
.31233 .31601 .31596 .32264 .32189 .32139 .31815 .31642 Mtetra
.597 .668 .889 r
.31815 .31642 .32189 .32139 .32811 .31573 .3241 .31525 Mtetra
.863 .944 .869 r
.3241 .31525 .32811 .31573 .33383 .31831 .33036 .30922 Mtetra
.449 .454 .771 r
.33036 .30922 .33383 .31831 .34003 .31342 .33617 .31077 Mtetra
.843 .832 .836 r
.33617 .31077 .34003 .31342 .34602 .31209 .34245 .30459 Mtetra
.576 .566 .805 r
.34245 .30459 .34602 .31209 .35219 .30791 .34844 .30379 Mtetra
.684 .742 .895 r
.34844 .30379 .35219 .30791 .35824 .30602 .35453 .30125 Mtetra
.614 .686 .894 r
.35453 .30125 .35824 .30602 .36438 .30275 .36058 .2998 Mtetra
.77 .824 .895 r
.36058 .2998 .36438 .30275 .37044 .30116 .36678 .29577 Mtetra
.55 .631 .884 r
.36678 .29577 .37044 .30116 .37661 .29759 .37281 .29526 Mtetra
.743 .86 .934 r
.37281 .29526 .37661 .29759 .38269 .29626 .379 .29181 Mtetra
.646 .716 .898 r
.379 .29181 .38269 .29626 .38884 .29388 .38513 .28986 Mtetra
.667 .746 .909 r
.38513 .28986 .38884 .29388 .39501 .29099 .39129 .28759 Mtetra
.696 .789 .922 r
.39129 .28759 .39501 .29099 .40113 .2899 .39748 .28487 Mtetra
.656 .693 .872 r
.39748 .28487 .40113 .2899 .40733 .28711 .40366 .2827 Mtetra
.609 .706 .913 r
.40366 .2827 .40733 .28711 .41352 .28498 .40983 .28128 Mtetra
.715 .779 .902 r
.40983 .28128 .41352 .28498 .41974 .2824 .41608 .27819 Mtetra
.632 .726 .915 r
.41608 .27819 .41974 .2824 .42596 .27985 .42229 .27642 Mtetra
.699 .791 .922 r
.42229 .27642 .42596 .27985 .43218 .27831 .42855 .27363 Mtetra
.648 .709 .891 r
.42855 .27363 .43218 .27831 .43844 .27554 .4348 .2716 Mtetra
.652 .749 .921 r
.4348 .2716 .43844 .27554 .4447 .27325 .44107 .26953 Mtetra
.672 .769 .923 r
.44107 .26953 .4447 .27325 .45097 .27132 .44736 .26714 Mtetra
.669 .743 .905 r
.44736 .26714 .45097 .27132 .45726 .26902 .45366 .26478 Mtetra
.641 .73 .913 r
.45366 .26478 .45726 .26902 .46358 .26632 .45997 .26286 Mtetra
.656 .781 .94 r
.45997 .26286 .46358 .26632 .46989 .26449 .46629 .26069 Mtetra
.71 .777 .904 r
.46629 .26069 .46989 .26449 .47622 .26279 .47265 .25763 Mtetra
.634 .683 .879 r
.47265 .25763 .47622 .26279 .48258 .25974 .47901 .2558 Mtetra
.693 .766 .908 r
.47901 .2558 .48258 .25974 .48894 .25778 .48539 .25303 Mtetra
.597 .689 .906 r
.48539 .25303 .48894 .25778 .49532 .25491 .49176 .25175 Mtetra
.714 .818 .93 r
.49176 .25175 .49532 .25491 .50171 .25313 .49818 .24867 Mtetra
.628 .717 .911 r
.49818 .24867 .50171 .25313 .50812 .25152 .50459 .24691 Mtetra
.675 .728 .889 r
.50459 .24691 .50812 .25152 .51455 .24831 .51103 .24437 Mtetra
.685 .767 .913 r
.51103 .24437 .51455 .24831 .52099 .24714 .51748 .24172 Mtetra
.64 .677 .87 r
.51748 .24172 .52099 .24714 .52744 .2438 .52394 .23973 Mtetra
.618 .737 .931 r
.52394 .23973 .52744 .2438 .53391 .24187 .53042 .23807 Mtetra
.737 .79 .895 r
.53042 .23807 .53391 .24187 .5404 .24023 .53692 .23445 Mtetra
.564 .629 .874 r
.53692 .23445 .5404 .24023 .5469 .23681 .54344 .2337 Mtetra
.737 .832 .924 r
.54344 .2337 .5469 .23681 .55344 .23692 .54995 .23018 Mtetra
.575 .598 .839 r
.54995 .23018 .55344 .23692 .55995 .23288 .55651 .22931 Mtetra
.759 .811 .894 r
.55651 .22931 .55995 .23288 .56654 .23318 .56305 .22524 Mtetra
.458 .497 .811 r
.56305 .22524 .56654 .23318 .57307 .22811 .56968 .2265 Mtetra
.792 .933 .924 r
.56968 .2265 .57307 .22811 .57974 .23092 .57623 .22188 Mtetra
.537 .515 .779 r
.57623 .22188 .57974 .23092 .58623 .2229 .58288 .22185 Mtetra
.572 .91 .974 r
.58288 .22185 .58623 .2229 .59292 .22413 .58951 .21944 Mtetra
.779 .763 .839 r
.58951 .21944 .59292 .22413 .59954 .22138 .59609 .21437 Mtetra
.693 .649 .802 r
.59609 .21437 .59954 .22138 .60615 .21744 .60271 .21076 Mtetra
.644 .637 .829 r
.60271 .21076 .60615 .21744 .61279 .21423 .60938 .20848 Mtetra
.665 .68 .855 r
.60938 .20848 .61279 .21423 .61946 .2117 .61606 .20591 Mtetra
.619 .659 .867 r
.61606 .20591 .61946 .2117 .62614 .20921 .62278 .20421 Mtetra
.649 .708 .89 r
.62278 .20421 .62614 .20921 .63282 .20604 .6295 .20203 Mtetra
.719 .784 .904 r
.6295 .20203 .63282 .20604 .63954 .20359 .6362 .19865 Mtetra
.627 .702 .899 r
.6362 .19865 .63954 .20359 .64627 .20102 .64297 .19682 Mtetra
.685 .764 .911 r
.64297 .19682 .64627 .20102 .65304 .19884 .64972 .19403 Mtetra
.68 .731 .889 r
.64972 .19403 .65304 .19884 .65979 .19619 .65648 .19126 Mtetra
.656 .717 .893 r
.65648 .19126 .65979 .19619 .66657 .19356 .66329 .18893 Mtetra
.664 .735 .903 r
.66329 .18893 .66657 .19356 .67337 .19113 .6701 .18647 Mtetra
.663 .734 .903 r
.6701 .18647 .67337 .19113 .68019 .18882 .67692 .18402 Mtetra
.65 .722 .901 r
.67692 .18402 .68019 .18882 .68703 .18636 .68378 .18177 Mtetra
.668 .741 .905 r
.68378 .18177 .68703 .18636 .69386 .18353 .69064 .17923 Mtetra
.672 .758 .916 r
.69064 .17923 .69386 .18353 .70075 .18142 .69751 .17662 Mtetra
.655 .726 .901 r
.69751 .17662 .70075 .18142 .70762 .17873 .70441 .17428 Mtetra
.669 .75 .911 r
.70441 .17428 .70762 .17873 .71453 .17642 .71132 .17169 Mtetra
.667 .735 .901 r
.71132 .17169 .71453 .17642 .72143 .17375 .71824 .16913 Mtetra
.659 .738 .908 r
.71824 .16913 .72143 .17375 .72836 .17121 .72519 .16671 Mtetra
.661 .746 .913 r
.72519 .16671 .72836 .17121 .73532 .16888 .73216 .16426 Mtetra
.667 .743 .907 r
.73216 .16426 .73532 .16888 .7423 .16648 .73913 .16169 Mtetra
.671 .736 .899 r
.73913 .16169 .7423 .16648 .74927 .16381 .74612 .15904 Mtetra
.655 .731 .905 r
.74612 .15904 .74927 .16381 .75627 .16125 .75314 .15665 Mtetra
.662 .743 .911 r
.75314 .15665 .75627 .16125 .76329 .15882 .76018 .15415 Mtetra
.671 .744 .906 r
.76018 .15415 .76329 .15882 .77033 .15627 .76722 .15149 Mtetra
.668 .738 .903 r
.76722 .15149 .77033 .15627 .77737 .1536 .77427 .14887 Mtetra
.654 .735 .909 r
.77427 .14887 .77737 .1536 .78445 .15117 .78137 .14648 Mtetra
.662 .741 .909 r
.15161 .36776 .15564 .37151 .16128 .36948 .15726 .36575 Mtetra
.667 .744 .908 r
.15726 .36575 .16128 .36948 .16693 .36744 .16292 .36366 Mtetra
.658 .739 .909 r
.16292 .36366 .16693 .36744 .17259 .3655 .16858 .36169 Mtetra
.664 .739 .906 r
.16858 .36169 .17259 .3655 .17827 .36338 .17427 .35963 Mtetra
.665 .743 .908 r
.17427 .35963 .17827 .36338 .18395 .36145 .17997 .35755 Mtetra
.652 .732 .908 r
.17997 .35755 .18395 .36145 .18964 .35953 .18566 .35566 Mtetra
.664 .737 .904 r
.18566 .35566 .18964 .35953 .19537 .35734 .19138 .35358 Mtetra
.675 .746 .905 r
.19138 .35358 .19537 .35734 .2011 .35521 .19714 .35133 Mtetra
.659 .737 .907 r
.19714 .35133 .2011 .35521 .20684 .35319 .20288 .34932 Mtetra
.658 .737 .908 r
.20288 .34932 .20684 .35319 .21258 .3512 .20863 .34732 Mtetra
.665 .739 .905 r
.20863 .34732 .21258 .3512 .21836 .349 .21441 .3452 Mtetra
.661 .743 .911 r
.21441 .3452 .21836 .349 .22412 .34713 .22019 .34315 Mtetra
.666 .735 .902 r
.22019 .34315 .22412 .34713 .22994 .34475 .22599 .34102 Mtetra
.654 .746 .917 r
.22599 .34102 .22994 .34475 .23571 .34298 .23179 .33906 Mtetra
.673 .741 .902 r
.23179 .33906 .23571 .34298 .24153 .34086 .23763 .33681 Mtetra
.665 .732 .899 r
.23763 .33681 .24153 .34086 .24737 .33863 .24347 .33466 Mtetra
.664 .737 .904 r
.24347 .33466 .24737 .33863 .25322 .3365 .24932 .33254 Mtetra
.668 .739 .903 r
.24932 .33254 .25322 .3365 .25907 .33452 .25519 .33035 Mtetra
.649 .722 .902 r
.25519 .33035 .25907 .33452 .26492 .33264 .26105 .32845 Mtetra
.639 .719 .905 r
.26105 .32845 .26492 .33264 .27079 .33061 .26691 .32668 Mtetra
.684 .746 .898 r
.26691 .32668 .27079 .33061 .27673 .32804 .27285 .3242 Mtetra
.621 .734 .927 r
.27285 .3242 .27673 .32804 .28257 .32671 .27872 .32266 Mtetra
.697 .744 .888 r
.27872 .32266 .28257 .32671 .2885 .32456 .28469 .31994 Mtetra
.643 .7 .887 r
.28469 .31994 .2885 .32456 .29448 .32176 .29062 .31808 Mtetra
.616 .743 .936 r
.29062 .31808 .29448 .32176 .30044 .3196 .29653 .31657 Mtetra
.638 .789 .955 r
.29653 .31657 .30044 .3196 .3064 .31745 .30248 .31472 Mtetra
.694 .822 .943 r
.30248 .31472 .3064 .31745 .31233 .31601 .3085 .3121 Mtetra
.667 .746 .909 r
.3085 .3121 .31233 .31601 .31815 .31642 .3145 .30988 Mtetra
.486 .55 .847 r
.3145 .30988 .31815 .31642 .3241 .31525 .32034 .31037 Mtetra
.724 .717 .843 r
.32034 .31037 .3241 .31525 .33036 .30922 .32646 .30679 Mtetra
.663 .837 .967 r
.32646 .30679 .33036 .30922 .33617 .31077 .33251 .30451 Mtetra
.675 .65 .818 r
.33251 .30451 .33617 .31077 .34245 .30459 .3386 .30174 Mtetra
.747 .826 .913 r
.3386 .30174 .34245 .30459 .34844 .30379 .34475 .29821 Mtetra
.535 .615 .879 r
.34475 .29821 .34844 .30379 .35453 .30125 .35072 .2979 Mtetra
.742 .798 .897 r
.35072 .2979 .35453 .30125 .36058 .2998 .35689 .29437 Mtetra
.633 .665 .863 r
.35689 .29437 .36058 .2998 .36678 .29577 .36298 .29258 Mtetra
.659 .791 .945 r
.36298 .29258 .36678 .29577 .37281 .29526 .3691 .29042 Mtetra
.705 .717 .859 r
.3691 .29042 .37281 .29526 .379 .29181 .37529 .28731 Mtetra
.595 .695 .912 r
.37529 .28731 .379 .29181 .38513 .28986 .38139 .28609 Mtetra
.723 .775 .893 r
.38139 .28609 .38513 .28986 .39129 .28759 .3876 .28284 Mtetra
.637 .699 .891 r
.3876 .28284 .39129 .28759 .39748 .28487 .39376 .28102 Mtetra
.671 .758 .915 r
.39376 .28102 .39748 .28487 .40366 .2827 .39996 .27867 Mtetra
.678 .75 .906 r
.39996 .27867 .40366 .2827 .40983 .28128 .40618 .2762 Mtetra
.626 .68 .882 r
.40618 .2762 .40983 .28128 .41608 .27819 .41238 .27452 Mtetra
.696 .777 .914 r
.41238 .27452 .41608 .27819 .42229 .27642 .41864 .27176 Mtetra
.628 .702 .899 r
.41864 .27176 .42229 .27642 .42855 .27363 .42487 .27005 Mtetra
.712 .787 .911 r
.42487 .27005 .42855 .27363 .4348 .2716 .43116 .26702 Mtetra
.645 .714 .897 r
.43116 .26702 .4348 .2716 .44107 .26953 .43743 .26503 Mtetra
.644 .718 .902 r
.43743 .26503 .44107 .26953 .44736 .26714 .44372 .26307 Mtetra
.67 .75 .91 r
.44372 .26307 .44736 .26714 .45366 .26478 .45003 .26069 Mtetra
.669 .749 .91 r
.45003 .26069 .45366 .26478 .45997 .26286 .45636 .25832 Mtetra
.683 .731 .887 r
.45636 .25832 .45997 .26286 .46629 .26069 .46271 .25567 Mtetra
.639 .693 .884 r
.46271 .25567 .46629 .26069 .47265 .25763 .46905 .25374 Mtetra
.676 .764 .917 r
.46905 .25374 .47265 .25763 .47901 .2558 .47543 .25125 Mtetra
.629 .712 .906 r
.47543 .25125 .47901 .2558 .48539 .25303 .4818 .24947 Mtetra
.683 .786 .928 r
.4818 .24947 .48539 .25303 .49176 .25175 .48821 .24688 Mtetra
.652 .706 .887 r
.48821 .24688 .49176 .25175 .49818 .24867 .49462 .24473 Mtetra
.697 .77 .908 r
.49462 .24473 .49818 .24867 .50459 .24691 .50105 .24185 Mtetra
.65 .698 .881 r
.50105 .24185 .50459 .24691 .51103 .24437 .50749 .23971 Mtetra
.619 .705 .907 r
.50749 .23971 .51103 .24437 .51748 .24172 .51395 .23808 Mtetra
.719 .795 .911 r
.51395 .23808 .51748 .24172 .52394 .23973 .52043 .23483 Mtetra
.586 .68 .905 r
.52043 .23483 .52394 .23973 .53042 .23807 .52692 .23368 Mtetra
.679 .743 .899 r
.52692 .23368 .53042 .23807 .53692 .23445 .53342 .23107 Mtetra
.677 .8 .941 r
.53342 .23107 .53692 .23445 .54344 .2337 .53994 .22851 Mtetra
.61 .677 .889 r
.53994 .22851 .54344 .2337 .54995 .23018 .54649 .227 Mtetra
.747 .832 .916 r
.54649 .227 .54995 .23018 .55651 .22931 .55303 .22326 Mtetra
.613 .643 .857 r
.55303 .22326 .55651 .22931 .56305 .22524 .5596 .2217 Mtetra
.559 .749 .966 r
.5596 .2217 .56305 .22524 .56968 .2265 .56621 .22059 Mtetra
.704 .689 .833 r
.56621 .22059 .56968 .2265 .57623 .22188 .57279 .21707 Mtetra
.475 .634 .924 r
.57279 .21707 .57623 .22188 .58288 .22185 .57945 .21723 Mtetra
.769 .764 .849 r
.57945 .21723 .58288 .22185 .58951 .21944 .58604 .21251 Mtetra
.679 .646 .81 r
.58604 .21251 .58951 .21944 .59609 .21437 .59267 .20934 Mtetra
.619 .692 .896 r
.59267 .20934 .59609 .21437 .60271 .21076 .59935 .20766 Mtetra
.674 .823 .955 r
.59935 .20766 .60271 .21076 .60938 .20848 .60603 .20504 Mtetra
.701 .811 .933 r
.60603 .20504 .60938 .20848 .61606 .20591 .61271 .20203 Mtetra
.702 .786 .917 r
.61271 .20203 .61606 .20591 .62278 .20421 .6194 .19899 Mtetra
.619 .685 .89 r
.6194 .19899 .62278 .20421 .6295 .20203 .62615 .19729 Mtetra
.681 .735 .891 r
.62615 .19729 .6295 .20203 .6362 .19865 .63288 .19452 Mtetra
.659 .759 .924 r
.63288 .19452 .6362 .19865 .64297 .19682 .63964 .19215 Mtetra
.691 .743 .891 r
.63964 .19215 .64297 .19682 .64972 .19403 .64639 .18919 Mtetra
.652 .72 .898 r
.64639 .18919 .64972 .19403 .65648 .19126 .65319 .18692 Mtetra
.66 .749 .916 r
.65319 .18692 .65648 .19126 .66329 .18893 .66 .18452 Mtetra
.666 .748 .912 r
.66 .18452 .66329 .18893 .6701 .18647 .66682 .18201 Mtetra
.672 .749 .909 r
.66682 .18201 .6701 .18647 .67692 .18402 .67365 .17941 Mtetra
.658 .736 .908 r
.67365 .17941 .67692 .18402 .68378 .18177 .68051 .17704 Mtetra
.656 .729 .903 r
.68051 .17704 .68378 .18177 .69064 .17923 .68739 .17468 Mtetra
.681 .75 .903 r
.68739 .17468 .69064 .17923 .69751 .17662 .69426 .17189 Mtetra
.647 .726 .907 r
.69426 .17189 .69751 .17662 .70441 .17428 .70119 .16967 Mtetra
.676 .746 .903 r
.70119 .16967 .70441 .17428 .71132 .17169 .7081 .16696 Mtetra
.659 .733 .904 r
.7081 .16696 .71132 .17169 .71824 .16913 .71504 .16453 Mtetra
.661 .741 .909 r
.71504 .16453 .71824 .16913 .72519 .16671 .722 .16206 Mtetra
.664 .741 .907 r
.722 .16206 .72519 .16671 .73216 .16426 .72897 .15954 Mtetra
.671 .741 .903 r
.72897 .15954 .73216 .16426 .73913 .16169 .73596 .15689 Mtetra
.659 .732 .904 r
.73596 .15689 .73913 .16169 .74612 .15904 .74297 .15444 Mtetra
.659 .743 .912 r
.74297 .15444 .74612 .15904 .75314 .15665 .75 .15199 Mtetra
.666 .744 .908 r
.75 .15199 .75314 .15665 .76018 .15415 .75704 .1494 Mtetra
.669 .741 .904 r
.75704 .1494 .76018 .15415 .76722 .15149 .76409 .14675 Mtetra
.665 .739 .906 r
.76409 .14675 .76722 .15149 .77427 .14887 .77117 .14418 Mtetra
.657 .74 .911 r
.77117 .14418 .77427 .14887 .78137 .14648 .77827 .14173 Mtetra
.661 .74 .909 r
.14757 .36399 .15161 .36776 .15726 .36575 .15322 .36198 Mtetra
.667 .742 .906 r
.15322 .36198 .15726 .36575 .16292 .36366 .15889 .35988 Mtetra
.661 .741 .909 r
.15889 .35988 .16292 .36366 .16858 .36169 .16457 .35786 Mtetra
.662 .739 .907 r
.16457 .35786 .16858 .36169 .17427 .35963 .17025 .35582 Mtetra
.668 .742 .905 r
.17025 .35582 .17427 .35963 .17997 .35755 .17597 .35369 Mtetra
.653 .736 .91 r
.17597 .35369 .17997 .35755 .18566 .35566 .18167 .35177 Mtetra
.661 .737 .906 r
.18167 .35177 .18566 .35566 .19138 .35358 .18739 .34973 Mtetra
.672 .742 .903 r
.18739 .34973 .19138 .35358 .19714 .35133 .19315 .34752 Mtetra
.662 .742 .909 r
.19315 .34752 .19714 .35133 .20288 .34932 .1989 .34545 Mtetra
.661 .739 .908 r
.1989 .34545 .20288 .34932 .20863 .34732 .20466 .34341 Mtetra
.663 .738 .906 r
.20466 .34341 .20863 .34732 .21441 .3452 .21044 .34132 Mtetra
.666 .741 .906 r
.21044 .34132 .21441 .3452 .22019 .34315 .21624 .33919 Mtetra
.659 .735 .906 r
.21624 .33919 .22019 .34315 .22599 .34102 .22204 .33716 Mtetra
.661 .741 .91 r
.22204 .33716 .22599 .34102 .23179 .33906 .22786 .3351 Mtetra
.672 .739 .901 r
.22786 .3351 .23179 .33906 .23763 .33681 .2337 .33285 Mtetra
.663 .738 .906 r
.2337 .33285 .23763 .33681 .24347 .33466 .23955 .33075 Mtetra
.662 .74 .908 r
.23955 .33075 .24347 .33466 .24932 .33254 .2454 .32864 Mtetra
.666 .742 .908 r
.2454 .32864 .24932 .33254 .25519 .33035 .25128 .32649 Mtetra
.663 .744 .911 r
.25128 .32649 .25519 .33035 .26105 .32845 .25716 .32437 Mtetra
.639 .726 .911 r
.25716 .32437 .26105 .32845 .26691 .32668 .26303 .3226 Mtetra
.67 .736 .899 r
.26303 .3226 .26691 .32668 .27285 .3242 .26895 .32034 Mtetra
.646 .741 .918 r
.26895 .32034 .27285 .3242 .27872 .32266 .27486 .31846 Mtetra
.694 .737 .884 r
.27486 .31846 .27872 .32266 .28469 .31994 .28084 .31577 Mtetra
.617 .716 .916 r
.28084 .31577 .28469 .31994 .29062 .31808 .28674 .31428 Mtetra
.628 .74 .928 r
.28674 .31428 .29062 .31808 .29653 .31657 .29267 .31262 Mtetra
.641 .737 .918 r
.29267 .31262 .29653 .31657 .30248 .31472 .29863 .31079 Mtetra
.668 .747 .909 r
.29863 .31079 .30248 .31472 .3085 .3121 .30463 .30855 Mtetra
.735 .782 .89 r
.30463 .30855 .3085 .3121 .3145 .30988 .31072 .30514 Mtetra
.516 .646 .915 r
.31072 .30514 .3145 .30988 .32034 .31037 .31661 .3049 Mtetra
.645 .667 .857 r
.31661 .3049 .32034 .31037 .32646 .30679 .32264 .30291 Mtetra
.754 .77 .866 r
.32264 .30291 .32646 .30679 .33251 .30451 .3288 .29895 Mtetra
.622 .654 .861 r
.3288 .29895 .33251 .30451 .3386 .30174 .33482 .29736 Mtetra
.683 .73 .886 r
.33482 .29736 .3386 .30174 .34475 .29821 .34092 .2948 Mtetra
.614 .763 .951 r
.34092 .2948 .34475 .29821 .35072 .2979 .34698 .29323 Mtetra
.727 .729 .853 r
.34698 .29323 .35072 .2979 .35689 .29437 .35316 .28965 Mtetra
.606 .688 .9 r
.35316 .28965 .35689 .29437 .36298 .29258 .35923 .2883 Mtetra
.698 .741 .885 r
.35923 .2883 .36298 .29258 .3691 .29042 .36539 .28545 Mtetra
.641 .69 .88 r
.36539 .28545 .3691 .29042 .37529 .28731 .37152 .28355 Mtetra
.652 .756 .926 r
.37152 .28355 .37529 .28731 .38139 .28609 .37767 .2815 Mtetra
.695 .727 .875 r
.37767 .2815 .38139 .28609 .3876 .28284 .38388 .27865 Mtetra
.619 .722 .92 r
.38388 .27865 .3876 .28284 .39376 .28102 .39004 .27707 Mtetra
.705 .763 .897 r
.39004 .27707 .39376 .28102 .39996 .27867 .39627 .27411 Mtetra
.66 .719 .892 r
.39627 .27411 .39996 .27867 .40618 .2762 .40249 .2719 Mtetra
.63 .722 .913 r
.40249 .2719 .40618 .2762 .41238 .27452 .4087 .27016 Mtetra
.699 .741 .884 r
.4087 .27016 .41238 .27452 .41864 .27176 .41497 .26725 Mtetra
.615 .706 .91 r
.41497 .26725 .41864 .27176 .42487 .27005 .4212 .26571 Mtetra
.674 .736 .897 r
.4212 .26571 .42487 .27005 .43116 .26702 .42748 .26326 Mtetra
.701 .775 .91 r
.42748 .26326 .43116 .26702 .43743 .26503 .43379 .26039 Mtetra
.643 .711 .897 r
.43379 .26039 .43743 .26503 .44372 .26307 .44009 .25842 Mtetra
.667 .72 .888 r
.44009 .25842 .44372 .26307 .45003 .26069 .44641 .25604 Mtetra
.672 .722 .887 r
.44641 .25604 .45003 .26069 .45636 .25832 .45274 .25356 Mtetra
.644 .707 .893 r
.45274 .25356 .45636 .25832 .46271 .25567 .45909 .25156 Mtetra
.646 .742 .919 r
.45909 .25156 .46271 .25567 .46905 .25374 .46544 .24953 Mtetra
.695 .753 .896 r
.46544 .24953 .46905 .25374 .47543 .25125 .47183 .24667 Mtetra
.608 .704 .912 r
.47183 .24667 .47543 .25125 .4818 .24947 .47821 .2452 Mtetra
.712 .756 .887 r
.47821 .2452 .4818 .24947 .48821 .24688 .48463 .242 Mtetra
.634 .7 .893 r
.48463 .242 .48821 .24688 .49462 .24473 .49105 .24013 Mtetra
.658 .724 .897 r
.49105 .24013 .49462 .24473 .50105 .24185 .49749 .23787 Mtetra
.692 .767 .91 r
.49749 .23787 .50105 .24185 .50749 .23971 .50394 .23508 Mtetra
.608 .703 .912 r
.50394 .23508 .50749 .23971 .51395 .23808 .51041 .23359 Mtetra
.678 .738 .896 r
.51041 .23359 .51395 .23808 .52043 .23483 .51689 .23098 Mtetra
.664 .768 .927 r
.51689 .23098 .52043 .23483 .52692 .23368 .5234 .22862 Mtetra
.631 .693 .889 r
.5234 .22862 .52692 .23368 .53342 .23107 .52991 .22677 Mtetra
.723 .763 .885 r
.52991 .22677 .53342 .23107 .53994 .22851 .53644 .22331 Mtetra
.569 .66 .898 r
.53644 .22331 .53994 .22851 .54649 .227 .54299 .2224 Mtetra
.717 .747 .876 r
.54299 .2224 .54649 .227 .55303 .22326 .54955 .21898 Mtetra
.621 .73 .925 r
.54955 .21898 .55303 .22326 .5596 .2217 .55613 .21726 Mtetra
.672 .742 .903 r
.55613 .21726 .5596 .2217 .56621 .22059 .56273 .21473 Mtetra
.607 .649 .866 r
.56273 .21473 .56621 .22059 .57279 .21707 .56935 .21324 Mtetra
.616 .756 .945 r
.56935 .21324 .57279 .21707 .57945 .21723 .57599 .2115 Mtetra
.751 .715 .818 r
.57599 .2115 .57945 .21723 .58604 .21251 .58259 .20675 Mtetra
.593 .648 .874 r
.58259 .20675 .58604 .21251 .59267 .20934 .58927 .20549 Mtetra
.647 .769 .937 r
.58927 .20549 .59267 .20934 .59935 .20766 .59595 .20332 Mtetra
.681 .754 .906 r
.59595 .20332 .59935 .20766 .60603 .20504 .60263 .2006 Mtetra
.69 .753 .899 r
.60263 .2006 .60603 .20504 .61271 .20203 .60932 .1977 Mtetra
.703 .763 .899 r
.60932 .1977 .61271 .20203 .6194 .19899 .61602 .19457 Mtetra
.64 .736 .918 r
.61602 .19457 .6194 .19899 .62615 .19729 .62277 .19251 Mtetra
.664 .727 .896 r
.62277 .19251 .62615 .19729 .63288 .19452 .62952 .19003 Mtetra
.671 .745 .906 r
.62952 .19003 .63288 .19452 .63964 .19215 .63629 .18745 Mtetra
.679 .738 .895 r
.63629 .18745 .63964 .19215 .64639 .18919 .64306 .1847 Mtetra
.653 .739 .913 r
.64306 .1847 .64639 .18919 .65319 .18692 .64987 .18242 Mtetra
.663 .743 .91 r
.64987 .18242 .65319 .18692 .66 .18452 .65669 .17996 Mtetra
.665 .742 .907 r
.65669 .17996 .66 .18452 .66682 .18201 .66352 .17746 Mtetra
.671 .745 .906 r
.66352 .17746 .66682 .18201 .67365 .17941 .67037 .17485 Mtetra
.663 .742 .909 r
.67037 .17485 .67365 .17941 .68051 .17704 .67723 .17237 Mtetra
.655 .733 .907 r
.67723 .17237 .68051 .17704 .68739 .17468 .68413 .17003 Mtetra
.675 .743 .902 r
.68413 .17003 .68739 .17468 .69426 .17189 .69102 .16733 Mtetra
.654 .74 .913 r
.69102 .16733 .69426 .17189 .70119 .16967 .69794 .16499 Mtetra
.672 .741 .903 r
.69794 .16499 .70119 .16967 .7081 .16696 .70487 .16233 Mtetra
.66 .74 .909 r
.70487 .16233 .7081 .16696 .71504 .16453 .71182 .15988 Mtetra
.663 .74 .908 r
.71182 .15988 .71504 .16453 .722 .16206 .71879 .15737 Mtetra
.664 .739 .906 r
.71879 .15737 .722 .16206 .72897 .15954 .72578 .15483 Mtetra
.671 .742 .903 r
.72578 .15483 .72897 .15954 .73596 .15689 .73277 .15216 Mtetra
.655 .735 .908 r
.73277 .15216 .73596 .15689 .74297 .15444 .7398 .14976 Mtetra
.66 .74 .909 r
.7398 .14976 .74297 .15444 .75 .15199 .74684 .14726 Mtetra
.667 .741 .905 r
.74684 .14726 .75 .15199 .75704 .1494 .75389 .14464 Mtetra
.667 .74 .905 r
.75389 .14464 .75704 .1494 .76409 .14675 .76096 .14202 Mtetra
.664 .741 .907 r
.76096 .14202 .76409 .14675 .77117 .14418 .76805 .13944 Mtetra
.659 .739 .909 r
.76805 .13944 .77117 .14418 .77827 .14173 .77516 .13695 Mtetra
.661 .74 .908 r
.14351 .36019 .14757 .36399 .15322 .36198 .14917 .35817 Mtetra
.666 .741 .906 r
.14917 .35817 .15322 .36198 .15889 .35988 .15485 .35607 Mtetra
.661 .74 .908 r
.15485 .35607 .15889 .35988 .16457 .35786 .16053 .35404 Mtetra
.663 .74 .907 r
.16053 .35404 .16457 .35786 .17025 .35582 .16623 .35198 Mtetra
.667 .741 .905 r
.16623 .35198 .17025 .35582 .17597 .35369 .17194 .34986 Mtetra
.655 .739 .911 r
.17194 .34986 .17597 .35369 .18167 .35177 .17765 .3479 Mtetra
.662 .739 .907 r
.17765 .3479 .18167 .35177 .18739 .34973 .18339 .34585 Mtetra
.671 .741 .903 r
.18339 .34585 .18739 .34973 .19315 .34752 .18915 .34364 Mtetra
.662 .739 .907 r
.18915 .34364 .19315 .34752 .1989 .34545 .19491 .34157 Mtetra
.661 .74 .908 r
.19491 .34157 .1989 .34545 .20466 .34341 .20068 .33951 Mtetra
.663 .74 .907 r
.20068 .33951 .20466 .34341 .21044 .34132 .20647 .33741 Mtetra
.665 .739 .906 r
.20647 .33741 .21044 .34132 .21624 .33919 .21227 .33529 Mtetra
.661 .739 .908 r
.21227 .33529 .21624 .33919 .22204 .33716 .21808 .33322 Mtetra
.661 .738 .907 r
.21808 .33322 .22204 .33716 .22786 .3351 .2239 .33115 Mtetra
.67 .74 .903 r
.2239 .33115 .22786 .3351 .2337 .33285 .22975 .32892 Mtetra
.663 .74 .907 r
.22975 .32892 .2337 .33285 .23955 .33075 .23561 .3268 Mtetra
.23561 .3268 .23955 .33075 .2454 .32864 .24147 .32468 Mtetra
.665 .74 .906 r
.24147 .32468 .2454 .32864 .25128 .32649 .24735 .32252 Mtetra
.661 .739 .907 r
.24735 .32252 .25128 .32649 .25716 .32437 .25324 .32041 Mtetra
.645 .735 .915 r
.25324 .32041 .25716 .32437 .26303 .3226 .25913 .31855 Mtetra
.67 .738 .901 r
.25913 .31855 .26303 .3226 .26895 .32034 .26506 .31629 Mtetra
.648 .732 .91 r
.26506 .31629 .26895 .32034 .27486 .31846 .27097 .31437 Mtetra
.689 .742 .891 r
.27097 .31437 .27486 .31846 .28084 .31577 .27695 .31176 Mtetra
.628 .729 .92 r
.27695 .31176 .28084 .31577 .28674 .31428 .28287 .31012 Mtetra
.636 .724 .911 r
.28287 .31012 .28674 .31428 .29267 .31262 .28882 .30835 Mtetra
.646 .722 .904 r
.28882 .30835 .29267 .31262 .29863 .31079 .29479 .30645 Mtetra
.665 .724 .894 r
.29479 .30645 .29863 .31079 .30463 .30855 .30079 .30423 Mtetra
.712 .739 .872 r
.30079 .30423 .30463 .30855 .31072 .30514 .30687 .30111 Mtetra
.562 .707 .938 r
.30687 .30111 .31072 .30514 .31661 .3049 .31281 .30023 Mtetra
.644 .703 .889 r
.31281 .30023 .31661 .3049 .32264 .30291 .31884 .29832 Mtetra
.738 .734 .848 r
.31884 .29832 .32264 .30291 .3288 .29895 .325 .29448 Mtetra
.62 .705 .906 r
.325 .29448 .3288 .29895 .33482 .29736 .33103 .29292 Mtetra
.659 .72 .894 r
.33103 .29292 .33482 .29736 .34092 .2948 .33711 .29077 Mtetra
.655 .741 .913 r
.33711 .29077 .34092 .2948 .34698 .29323 .34321 .28869 Mtetra
.7 .729 .873 r
.34321 .28869 .34698 .29323 .35316 .28965 .34936 .28576 Mtetra
.634 .743 .927 r
.34936 .28576 .35316 .28965 .35923 .2883 .35546 .28397 Mtetra
.701 .741 .882 r
.35546 .28397 .35923 .2883 .36539 .28545 .36164 .28105 Mtetra
.623 .712 .91 r
.36164 .28105 .36539 .28545 .37152 .28355 .36776 .27942 Mtetra
.671 .743 .905 r
.36776 .27942 .37152 .28355 .37767 .2815 .37394 .27707 Mtetra
.671 .728 .892 r
.37394 .27707 .37767 .2815 .38388 .27865 .38013 .27468 Mtetra
.64 .743 .924 r
.38013 .27468 .38388 .27865 .39004 .27707 .38631 .27279 Mtetra
.702 .746 .886 r
.38631 .27279 .39004 .27707 .39627 .27411 .39255 .26983 Mtetra
.644 .728 .91 r
.39255 .26983 .39627 .27411 .40249 .2719 .39876 .26787 Mtetra
.651 .745 .918 r
.39876 .26787 .40249 .2719 .4087 .27016 .40499 .2658 Mtetra
.679 .737 .894 r
.40499 .2658 .4087 .27016 .41497 .26725 .41126 .26326 Mtetra
.643 .745 .923 r
.41126 .26326 .41497 .26725 .4212 .26571 .41752 .2613 Mtetra
.659 .729 .901 r
.41752 .2613 .4212 .26571 .42748 .26326 .4238 .2591 Mtetra
.69 .752 .899 r
.4238 .2591 .42748 .26326 .43379 .26039 .43011 .25636 Mtetra
.672 .754 .912 r
.43011 .25636 .43379 .26039 .44009 .25842 .43643 .25394 Mtetra
.666 .729 .897 r
.43643 .25394 .44009 .25842 .44641 .25604 .44276 .25159 Mtetra
.657 .728 .901 r
.44276 .25159 .44641 .25604 .45274 .25356 .4491 .24938 Mtetra
.642 .737 .918 r
.4491 .24938 .45274 .25356 .45909 .25156 .45545 .24741 Mtetra
.661 .746 .913 r
.45545 .24741 .45909 .25156 .46544 .24953 .46182 .24514 Mtetra
.677 .739 .897 r
.46182 .24514 .46544 .24953 .47183 .24667 .46821 .24258 Mtetra
.63 .74 .926 r
.46821 .24258 .47183 .24667 .47821 .2452 .47461 .24076 Mtetra
.696 .744 .888 r
.47461 .24076 .47821 .2452 .48463 .242 .48103 .23783 Mtetra
.655 .745 .916 r
.48103 .23783 .48463 .242 .49105 .24013 .48747 .23564 Mtetra
.647 .726 .906 r
.48747 .23564 .49105 .24013 .49749 .23787 .49391 .23357 Mtetra
.681 .748 .902 r
.49391 .23357 .49749 .23787 .50394 .23508 .50038 .23092 Mtetra
.636 .74 .924 r
.50038 .23092 .50394 .23508 .51041 .23359 .50685 .229 Mtetra
.661 .727 .898 r
.50685 .229 .51041 .23359 .51689 .23098 .51335 .22668 Mtetra
.688 .752 .9 r
.51335 .22668 .51689 .23098 .5234 .22862 .51986 .2239 Mtetra
.621 .706 .906 r
.51986 .2239 .5234 .22862 .52991 .22677 .52638 .2222 Mtetra
.707 .746 .882 r
.52638 .2222 .52991 .22677 .53644 .22331 .53292 .219 Mtetra
.597 .719 .93 r
.53292 .219 .53644 .22331 .54299 .2224 .53948 .21761 Mtetra
.689 .73 .882 r
.53948 .21761 .54299 .2224 .54955 .21898 .54605 .21471 Mtetra
.648 .743 .918 r
.54605 .21471 .54955 .21898 .55613 .21726 .55264 .21257 Mtetra
.684 .735 .889 r
.55264 .21257 .55613 .21726 .56273 .21473 .55924 .20977 Mtetra
.597 .687 .905 r
.55924 .20977 .56273 .21473 .56935 .21324 .56588 .20842 Mtetra
.643 .713 .899 r
.56588 .20842 .56935 .21324 .57599 .2115 .57252 .20634 Mtetra
.738 .733 .847 r
.57252 .20634 .57599 .2115 .58259 .20675 .57914 .20222 Mtetra
.601 .712 .922 r
.57914 .20222 .58259 .20675 .58927 .20549 .58583 .20075 Mtetra
.653 .723 .9 r
.58583 .20075 .58927 .20549 .59595 .20332 .59252 .1985 Mtetra
.675 .728 .89 r
.59252 .1985 .59595 .20332 .60263 .2006 .59921 .19582 Mtetra
.683 .734 .889 r
.59921 .19582 .60263 .2006 .60932 .1977 .60592 .19301 Mtetra
.693 .742 .889 r
.60592 .19301 .60932 .1977 .61602 .19457 .61263 .19001 Mtetra
.643 .73 .912 r
.61263 .19001 .61602 .19457 .62277 .19251 .61939 .18789 Mtetra
.666 .737 .903 r
.61939 .18789 .62277 .19251 .62952 .19003 .62615 .18538 Mtetra
.667 .736 .902 r
.62615 .18538 .62952 .19003 .63629 .18745 .63293 .18285 Mtetra
.678 .743 .9 r
.63293 .18285 .63629 .18745 .64306 .1847 .63971 .18012 Mtetra
.655 .736 .909 r
.63971 .18012 .64306 .1847 .64987 .18242 .64653 .17779 Mtetra
.663 .737 .905 r
.64653 .17779 .64987 .18242 .65669 .17996 .65336 .17532 Mtetra
.664 .738 .905 r
.65336 .17532 .65669 .17996 .66352 .17746 .66021 .17281 Mtetra
.669 .74 .903 r
.66021 .17281 .66352 .17746 .67037 .17485 .66706 .17022 Mtetra
.662 .739 .907 r
.66706 .17022 .67037 .17485 .67723 .17237 .67394 .16774 Mtetra
.657 .737 .909 r
.67394 .16774 .67723 .17237 .68413 .17003 .68084 .16536 Mtetra
.673 .742 .902 r
.68084 .16536 .68413 .17003 .69102 .16733 .68775 .16268 Mtetra
.655 .737 .909 r
.68775 .16268 .69102 .16733 .69794 .16499 .69468 .1603 Mtetra
.67 .741 .904 r
.69468 .1603 .69794 .16499 .70487 .16233 .70162 .15766 Mtetra
.661 .739 .908 r
.70162 .15766 .70487 .16233 .71182 .15988 .70859 .15517 Mtetra
.662 .739 .907 r
.70859 .15517 .71182 .15988 .71879 .15737 .71557 .15266 Mtetra
.663 .739 .907 r
.71557 .15266 .71879 .15737 .72578 .15483 .72257 .15013 Mtetra
.67 .743 .905 r
.72257 .15013 .72578 .15483 .73277 .15216 .72958 .14747 Mtetra
.657 .739 .91 r
.72958 .14747 .73277 .15216 .7398 .14976 .73662 .14502 Mtetra
.661 .739 .907 r
.73662 .14502 .7398 .14976 .74684 .14726 .74367 .1425 Mtetra
.666 .74 .905 r
.74367 .1425 .74684 .14726 .75389 .14464 .75073 .13988 Mtetra
.666 .741 .906 r
.75073 .13988 .75389 .14464 .76096 .14202 .75781 .13726 Mtetra
.664 .741 .907 r
.75781 .13726 .76096 .14202 .76805 .13944 .76491 .13467 Mtetra
.659 .738 .908 r
.76491 .13467 .76805 .13944 .77516 .13695 .77204 .13217 Mtetra
.662 .74 .908 r
.13944 .35638 .14351 .36019 .14917 .35817 .1451 .35434 Mtetra
.666 .74 .906 r
.1451 .35434 .14917 .35817 .15485 .35607 .15079 .35223 Mtetra
.66 .739 .909 r
.15079 .35223 .15485 .35607 .16053 .35404 .15647 .35022 Mtetra
.665 .741 .907 r
.15647 .35022 .16053 .35404 .16623 .35198 .16218 .34812 Mtetra
.664 .74 .907 r
.16218 .34812 .16623 .35198 .17194 .34986 .1679 .34604 Mtetra
.658 .741 .911 r
.1679 .34604 .17194 .34986 .17765 .3479 .17362 .34404 Mtetra
.664 .741 .907 r
.17362 .34404 .17765 .3479 .18339 .34585 .17936 .34194 Mtetra
.67 .74 .903 r
.17936 .34194 .18339 .34585 .18915 .34364 .18513 .33975 Mtetra
.661 .739 .908 r
.18513 .33975 .18915 .34364 .19491 .34157 .1909 .33768 Mtetra
.662 .74 .908 r
.1909 .33768 .19491 .34157 .20068 .33951 .19668 .33561 Mtetra
.665 .741 .906 r
.19668 .33561 .20068 .33951 .20647 .33741 .20248 .33348 Mtetra
.661 .738 .907 r
.20248 .33348 .20647 .33741 .21227 .33529 .20828 .3314 Mtetra
.667 .743 .907 r
.20828 .3314 .21227 .33529 .21808 .33322 .21411 .32923 Mtetra
.658 .736 .907 r
.21411 .32923 .21808 .33322 .2239 .33115 .21993 .32719 Mtetra
.667 .74 .905 r
.21993 .32719 .2239 .33115 .22975 .32892 .22579 .32501 Mtetra
.666 .743 .907 r
.22579 .32501 .22975 .32892 .23561 .3268 .23165 .32283 Mtetra
.665 .74 .906 r
.23165 .32283 .23561 .3268 .24147 .32468 .23753 .32068 Mtetra
.663 .738 .906 r
.23753 .32068 .24147 .32468 .24735 .32252 .24341 .31854 Mtetra
.656 .738 .91 r
.24341 .31854 .24735 .32252 .25324 .32041 .2493 .31651 Mtetra
.653 .741 .914 r
.2493 .31651 .25324 .32041 .25913 .31855 .2552 .31451 Mtetra
.677 .742 .899 r
.2552 .31451 .25913 .31855 .26506 .31629 .26115 .31213 Mtetra
.639 .724 .91 r
.26115 .31213 .26506 .31629 .27097 .31437 .26706 .31033 Mtetra
.679 .743 .899 r
.26706 .31033 .27097 .31437 .27695 .31176 .27304 .30791 Mtetra
.662 .749 .915 r
.27304 .30791 .27695 .31176 .28287 .31012 .279 .30577 Mtetra
.641 .716 .903 r
.279 .30577 .28287 .31012 .28882 .30835 .28496 .30394 Mtetra
.652 .717 .896 r
.28496 .30394 .28882 .30835 .29479 .30645 .29094 .30192 Mtetra
.671 .718 .884 r
.29094 .30192 .29479 .30645 .30079 .30423 .29696 .29956 Mtetra
.675 .713 .877 r
.29696 .29956 .30079 .30423 .30687 .30111 .30301 .2971 Mtetra
.572 .712 .937 r
.30301 .2971 .30687 .30111 .31281 .30023 .30896 .2961 Mtetra
.681 .742 .897 r
.30896 .2961 .31281 .30023 .31884 .29832 .31503 .2936 Mtetra
.703 .721 .863 r
.31503 .2936 .31884 .29832 .325 .29448 .32115 .29057 Mtetra
.638 .742 .924 r
.32115 .29057 .325 .29448 .33103 .29292 .32721 .28873 Mtetra
.671 .738 .9 r
.32721 .28873 .33103 .29292 .33711 .29077 .33331 .28638 Mtetra
.642 .719 .904 r
.33331 .28638 .33711 .29077 .34321 .28869 .3394 .28448 Mtetra
.702 .747 .886 r
.3394 .28448 .34321 .28869 .34936 .28576 .34556 .28155 Mtetra
.628 .724 .916 r
.34556 .28155 .34936 .28576 .35546 .28397 .35167 .27985 Mtetra
.699 .751 .892 r
.35167 .27985 .35546 .28397 .36164 .28105 .35785 .277 Mtetra
.631 .735 .923 r
.35785 .277 .36164 .28105 .36776 .27942 .36399 .27524 Mtetra
.668 .74 .904 r
.36399 .27524 .36776 .27942 .37394 .27707 .37017 .27291 Mtetra
.677 .745 .902 r
.37017 .27291 .37394 .27707 .38013 .27468 .37637 .27044 Mtetra
.643 .73 .912 r
.37637 .27044 .38013 .27468 .38631 .27279 .38256 .2685 Mtetra
.692 .744 .891 r
.38256 .2685 .38631 .27279 .39255 .26983 .3888 .26573 Mtetra
.655 .742 .914 r
.3888 .26573 .39255 .26983 .39876 .26787 .39503 .26359 Mtetra
.643 .73 .912 r
.39503 .26359 .39876 .26787 .40499 .2658 .40127 .26164 Mtetra
.685 .75 .901 r
.40127 .26164 .40499 .2658 .41126 .26326 .40755 .25901 Mtetra
.642 .731 .914 r
.40755 .25901 .41126 .26326 .41752 .2613 .41381 .25706 Mtetra
.664 .74 .907 r
.41381 .25706 .41752 .2613 .4238 .2591 .42011 .25476 Mtetra
.689 .744 .893 r
.42011 .25476 .4238 .2591 .43011 .25636 .42643 .25203 Mtetra
.66 .735 .905 r
.42643 .25203 .43011 .25636 .43643 .25394 .43275 .24977 Mtetra
.665 .746 .91 r
.43275 .24977 .43643 .25394 .44276 .25159 .43909 .24745 Mtetra
.671 .75 .91 r
.43909 .24745 .44276 .25159 .4491 .24938 .44544 .24502 Mtetra
.643 .73 .911 r
.44544 .24502 .4491 .24938 .45545 .24741 .4518 .24302 Mtetra
.655 .733 .906 r
.4518 .24302 .45545 .24741 .46182 .24514 .45818 .24083 Mtetra
.682 .746 .9 r
.45818 .24083 .46182 .24514 .46821 .24258 .46458 .23819 Mtetra
.629 .723 .915 r
.46458 .23819 .46821 .24258 .47461 .24076 .47099 .23639 Mtetra
.696 .749 .892 r
.47099 .23639 .47461 .24076 .48103 .23783 .47742 .23347 Mtetra
.646 .733 .912 r
.47742 .23347 .48103 .23783 .48747 .23564 .48386 .2314 Mtetra
.66 .745 .913 r
.48386 .2314 .48747 .23564 .49391 .23357 .49032 .22911 Mtetra
.681 .741 .896 r
.49032 .22911 .49391 .23357 .50038 .23092 .4968 .22645 Mtetra
.634 .724 .912 r
.4968 .22645 .50038 .23092 .50685 .229 .50328 .22455 Mtetra
.663 .736 .905 r
.50328 .22455 .50685 .229 .51335 .22668 .50979 .22219 Mtetra
.68 .741 .897 r
.50979 .22219 .51335 .22668 .51986 .2239 .51631 .21952 Mtetra
.628 .728 .919 r
.51631 .21952 .51986 .2239 .52638 .2222 .52284 .2177 Mtetra
.706 .75 .886 r
.52284 .2177 .52638 .2222 .53292 .219 .52939 .21453 Mtetra
.608 .716 .921 r
.52939 .21453 .53292 .219 .53948 .21761 .53596 .21298 Mtetra
.696 .742 .886 r
.53596 .21298 .53948 .21761 .54605 .21471 .54254 .20998 Mtetra
.635 .714 .904 r
.54254 .20998 .54605 .21471 .55264 .21257 .54914 .20803 Mtetra
.677 .741 .898 r
.54914 .20803 .55264 .21257 .55924 .20977 .55575 .20537 Mtetra
.641 .735 .917 r
.55575 .20537 .55924 .20977 .56588 .20842 .56239 .20332 Mtetra
.618 .691 .895 r
.56239 .20332 .56588 .20842 .57252 .20634 .56904 .20163 Mtetra
.718 .748 .876 r
.56904 .20163 .57252 .20634 .57914 .20222 .57569 .19812 Mtetra
.669 .764 .921 r
.57569 .19812 .57914 .20222 .58583 .20075 .58237 .19561 Mtetra
.644 .701 .887 r
.58237 .19561 .58583 .20075 .59252 .1985 .58907 .19346 Mtetra
.668 .716 .885 r
.58907 .19346 .59252 .1985 .59921 .19582 .59577 .1909 Mtetra
.679 .726 .885 r
.59577 .1909 .59921 .19582 .60592 .19301 .60249 .18813 Mtetra
.673 .727 .89 r
.60249 .18813 .60592 .19301 .61263 .19001 .60923 .18548 Mtetra
.643 .733 .914 r
.60923 .18548 .61263 .19001 .61939 .18789 .61599 .18335 Mtetra
.678 .747 .903 r
.61599 .18335 .61939 .18789 .62615 .18538 .62276 .18064 Mtetra
.656 .729 .902 r
.62276 .18064 .62615 .18538 .63293 .18285 .62956 .17828 Mtetra
.678 .746 .903 r
.62956 .17828 .63293 .18285 .63971 .18012 .63635 .17555 Mtetra
.662 .741 .908 r
.63635 .17555 .63971 .18012 .64653 .17779 .64318 .17309 Mtetra
.662 .734 .904 r
.64318 .17309 .64653 .17779 .65336 .17532 .65002 .17062 Mtetra
.664 .736 .903 r
.65002 .17062 .65336 .17532 .66021 .17281 .65687 .16811 Mtetra
.665 .737 .903 r
.65687 .16811 .66021 .17281 .66706 .17022 .66375 .16558 Mtetra
.66 .738 .908 r
.66375 .16558 .66706 .17022 .67394 .16774 .67064 .16314 Mtetra
.661 .741 .909 r
.67064 .16314 .67394 .16774 .68084 .16536 .67755 .16067 Mtetra
.672 .742 .903 r
.67755 .16067 .68084 .16536 .68775 .16268 .68446 .15799 Mtetra
.655 .736 .909 r
.68446 .15799 .68775 .16268 .69468 .1603 .69141 .1556 Mtetra
.67 .742 .904 r
.69141 .1556 .69468 .1603 .70162 .15766 .69836 .15296 Mtetra
.663 .739 .907 r
.69836 .15296 .70162 .15766 .70859 .15517 .70534 .15044 Mtetra
.661 .737 .907 r
.70534 .15044 .70859 .15517 .71557 .15266 .71234 .14794 Mtetra
.661 .739 .907 r
.71234 .14794 .71557 .15266 .72257 .15013 .71935 .14542 Mtetra
.668 .743 .907 r
.71935 .14542 .72257 .15013 .72958 .14747 .72637 .14279 Mtetra
.663 .743 .91 r
.72637 .14279 .72958 .14747 .73662 .14502 .73341 .14025 Mtetra
.661 .738 .907 r
.73341 .14025 .73662 .14502 .74367 .1425 .74048 .13771 Mtetra
.665 .74 .906 r
.74048 .13771 .74367 .1425 .75073 .13988 .74756 .13511 Mtetra
.666 .741 .906 r
.74756 .13511 .75073 .13988 .75781 .13726 .75465 .13248 Mtetra
.665 .741 .907 r
.75465 .13248 .75781 .13726 .76491 .13467 .76176 .12987 Mtetra
.658 .738 .908 r
.76176 .12987 .76491 .13467 .77204 .13217 .7689 .12736 Mtetra
.663 .74 .907 r
.13534 .35255 .13944 .35638 .1451 .35434 .14102 .35048 Mtetra
.661 .739 .907 r
.14102 .35048 .1451 .35434 .15079 .35223 .1467 .34843 Mtetra
.663 .743 .91 r
.1467 .34843 .15079 .35223 .15647 .35022 .1524 .34637 Mtetra
.665 .741 .907 r
.1524 .34637 .15647 .35022 .16218 .34812 .15812 .34426 Mtetra
.662 .74 .908 r
.15812 .34426 .16218 .34812 .1679 .34604 .16384 .3422 Mtetra
.66 .741 .91 r
.16384 .3422 .1679 .34604 .17362 .34404 .16957 .34015 Mtetra
.667 .741 .905 r
.16957 .34015 .17362 .34404 .17936 .34194 .17533 .338 Mtetra
.663 .737 .905 r
.17533 .338 .17936 .34194 .18513 .33975 .18109 .33589 Mtetra
.662 .742 .91 r
.18109 .33589 .18513 .33975 .1909 .33768 .18687 .33381 Mtetra
.666 .743 .908 r
.18687 .33381 .1909 .33768 .19668 .33561 .19266 .33167 Mtetra
.666 .74 .905 r
.19266 .33167 .19668 .33561 .20248 .33348 .19847 .32951 Mtetra
.658 .737 .908 r
.19847 .32951 .20248 .33348 .20828 .3314 .20427 .32747 Mtetra
.668 .742 .905 r
.20427 .32747 .20828 .3314 .21411 .32923 .21011 .32527 Mtetra
.659 .738 .908 r
.21011 .32527 .21411 .32923 .21993 .32719 .21595 .3232 Mtetra
.662 .738 .906 r
.21595 .3232 .21993 .32719 .22579 .32501 .2218 .32108 Mtetra
.664 .742 .908 r
.2218 .32108 .22579 .32501 .23165 .32283 .22767 .31893 Mtetra
.663 .744 .91 r
.22767 .31893 .23165 .32283 .23753 .32068 .23355 .3168 Mtetra
.662 .745 .912 r
.23355 .3168 .23753 .32068 .24341 .31854 .23944 .31468 Mtetra
.661 .746 .913 r
.23944 .31468 .24341 .31854 .2493 .31651 .24535 .31256 Mtetra
.664 .743 .909 r
.24535 .31256 .2493 .31651 .2552 .31451 .25127 .31039 Mtetra
.666 .735 .901 r
.25127 .31039 .2552 .31451 .26115 .31213 .25721 .30817 Mtetra
.652 .74 .914 r
.25721 .30817 .26115 .31213 .26706 .31033 .26315 .30618 Mtetra
.657 .732 .904 r
.26315 .30618 .26706 .31033 .27304 .30791 .2691 .3041 Mtetra
.677 .755 .91 r
.2691 .3041 .27304 .30791 .279 .30577 .27509 .30172 Mtetra
.672 .742 .903 r
.27509 .30172 .279 .30577 .28496 .30394 .28109 .29939 Mtetra
.66 .714 .888 r
.28109 .29939 .28496 .30394 .29094 .30192 .2871 .29722 Mtetra
.648 .703 .887 r
.2871 .29722 .29094 .30192 .29696 .29956 .2931 .29523 Mtetra
.617 .711 .913 r
.2931 .29523 .29696 .29956 .30301 .2971 .29908 .29371 Mtetra
.637 .772 .944 r
.29908 .29371 .30301 .2971 .30896 .2961 .3051 .29185 Mtetra
.716 .746 .876 r
.3051 .29185 .30896 .2961 .31503 .2936 .31123 .28865 Mtetra
.637 .689 .882 r
.31123 .28865 .31503 .2936 .32115 .29057 .31728 .28682 Mtetra
.667 .761 .92 r
.31728 .28682 .32115 .29057 .32721 .28873 .32337 .28455 Mtetra
.694 .746 .891 r
.32337 .28455 .32721 .28873 .33331 .28638 .3295 .2818 Mtetra
.616 .7 .905 r
.3295 .2818 .33331 .28638 .3394 .28448 .33557 .28027 Mtetra
.705 .749 .886 r
.33557 .28027 .3394 .28448 .34556 .28155 .34175 .27729 Mtetra
.619 .719 .918 r
.34175 .27729 .34556 .28155 .35167 .27985 .34785 .2757 Mtetra
.682 .746 .9 r
.34785 .2757 .35167 .27985 .35785 .277 .35403 .27315 Mtetra
.663 .757 .92 r
.35403 .27315 .35785 .277 .36399 .27524 .3602 .27091 Mtetra
.65 .728 .906 r
.3602 .27091 .36399 .27524 .37017 .27291 .36638 .26885 Mtetra
.697 .756 .898 r
.36638 .26885 .37017 .27291 .37637 .27044 .3726 .26602 Mtetra
.64 .721 .906 r
.3726 .26602 .37637 .27044 .38256 .2685 .3788 .26411 Mtetra
.664 .731 .899 r
.3788 .26411 .38256 .2685 .3888 .26573 .38503 .26182 Mtetra
.689 .764 .909 r
.38503 .26182 .3888 .26573 .39503 .26359 .39129 .25915 Mtetra
.62 .713 .913 r
.39129 .25915 .39503 .26359 .40127 .26164 .39752 .25752 Mtetra
.701 .758 .896 r
.39752 .25752 .40127 .26164 .40755 .25901 .40382 .25458 Mtetra
.626 .718 .912 r
.40382 .25458 .40755 .25901 .41381 .25706 .41009 .25285 Mtetra
.684 .749 .901 r
.41009 .25285 .41381 .25706 .42011 .25476 .4164 .25021 Mtetra
.666 .726 .894 r
.4164 .25021 .42011 .25476 .42643 .25203 .42272 .24785 Mtetra
.647 .74 .917 r
.42272 .24785 .42643 .25203 .43275 .24977 .42905 .24579 Mtetra
.662 .756 .92 r
.42905 .24579 .43275 .24977 .43909 .24745 .43539 .2435 Mtetra
.672 .762 .918 r
.43539 .2435 .43909 .24745 .44544 .24502 .44176 .24106 Mtetra
.681 .764 .914 r
.44176 .24106 .44544 .24502 .4518 .24302 .44814 .23847 Mtetra
.639 .719 .906 r
.44814 .23847 .4518 .24302 .45818 .24083 .45452 .23652 Mtetra
.683 .747 .9 r
.45452 .23652 .45818 .24083 .46458 .23819 .46094 .23385 Mtetra
.633 .729 .917 r
.46094 .23385 .46458 .23819 .47099 .23639 .46735 .23198 Mtetra
.692 .746 .893 r
.46735 .23198 .47099 .23639 .47742 .23347 .4738 .22912 Mtetra
.631 .729 .918 r
.4738 .22912 .47742 .23347 .48386 .2314 .48024 .22727 Mtetra
.688 .76 .907 r
.48024 .22727 .48386 .2314 .49032 .22911 .48672 .2245 Mtetra
.663 .728 .898 r
.48672 .2245 .49032 .22911 .4968 .22645 .4932 .22213 Mtetra
.64 .736 .918 r
.4932 .22213 .4968 .22645 .50328 .22455 .49969 .22012 Mtetra
.679 .744 .9 r
.49969 .22012 .50328 .22455 .50979 .22219 .50621 .21747 Mtetra
.649 .719 .899 r
.50621 .21747 .50979 .22219 .51631 .21952 .51274 .21531 Mtetra
.655 .748 .918 r
.51274 .21531 .51631 .21952 .52284 .2177 .51928 .21307 Mtetra
.688 .738 .889 r
.51928 .21307 .52284 .2177 .52939 .21453 .52584 .21022 Mtetra
.632 .735 .922 r
.52584 .21022 .52939 .21453 .53596 .21298 .53242 .2083 Mtetra
.687 .737 .889 r
.53242 .2083 .53596 .21298 .54254 .20998 .53901 .20546 Mtetra
.639 .728 .912 r
.53901 .20546 .54254 .20998 .54914 .20803 .54562 .20343 Mtetra
.656 .731 .904 r
.54562 .20343 .54914 .20803 .55575 .20537 .55225 .20112 Mtetra
.701 .765 .902 r
.55225 .20112 .55575 .20537 .56239 .20332 .55888 .19805 Mtetra
.592 .672 .895 r
.55888 .19805 .56239 .20332 .56904 .20163 .56555 .19677 Mtetra
.669 .724 .89 r
.56555 .19677 .56904 .20163 .57569 .19812 .57222 .1942 Mtetra
.707 .787 .913 r
.57222 .1942 .57569 .19812 .58237 .19561 .5789 .19104 Mtetra
.683 .745 .898 r
.5789 .19104 .58237 .19561 .58907 .19346 .5856 .18825 Mtetra
.66 .706 .881 r
.5856 .18825 .58907 .19346 .59577 .1909 .59232 .1858 Mtetra
.656 .71 .887 r
.59232 .1858 .59577 .1909 .60249 .18813 .59906 .18344 Mtetra
.65 .728 .906 r
.59906 .18344 .60249 .18813 .60923 .18548 .60581 .1812 Mtetra
.665 .756 .918 r
.60581 .1812 .60923 .18548 .61599 .18335 .61258 .17871 Mtetra
.681 .743 .898 r
.61258 .17871 .61599 .18335 .62276 .18064 .61936 .17593 Mtetra
.652 .729 .906 r
.61936 .17593 .62276 .18064 .62956 .17828 .62617 .17363 Mtetra
.668 .739 .904 r
.62617 .17363 .62956 .17828 .63635 .17555 .63298 .17106 Mtetra
.669 .749 .91 r
.63298 .17106 .63635 .17555 .64318 .17309 .63981 .16848 Mtetra
.666 .742 .907 r
.63981 .16848 .64318 .17309 .65002 .17062 .64666 .16594 Mtetra
.663 .737 .905 r
.64666 .16594 .65002 .17062 .65687 .16811 .65353 .16344 Mtetra
.661 .738 .907 r
.65353 .16344 .65687 .16811 .66375 .16558 .66042 .16096 Mtetra
.66 .741 .91 r
.66042 .16096 .66375 .16558 .67064 .16314 .66732 .1585 Mtetra
.667 .743 .907 r
.66732 .1585 .67064 .16314 .67755 .16067 .67424 .15592 Mtetra
.663 .736 .905 r
.67424 .15592 .67755 .16067 .68446 .15799 .68117 .1534 Mtetra
.664 .745 .911 r
.68117 .1534 .68446 .15799 .69141 .1556 .68813 .15086 Mtetra
.664 .738 .905 r
.68813 .15086 .69141 .1556 .69836 .15296 .69509 .14831 Mtetra
.665 .743 .909 r
.69509 .14831 .69836 .15296 .70534 .15044 .70208 .14574 Mtetra
.664 .742 .908 r
.70208 .14574 .70534 .15044 .71234 .14794 .70908 .14317 Mtetra
.659 .736 .907 r
.70908 .14317 .71234 .14794 .71935 .14542 .71611 .14068 Mtetra
.664 .741 .907 r
.71611 .14068 .71935 .14542 .72637 .14279 .72315 .13811 Mtetra
.669 .746 .908 r
.72315 .13811 .72637 .14279 .73341 .14025 .7302 .13544 Mtetra
.66 .737 .906 r
.7302 .13544 .73341 .14025 .74048 .13771 .73728 .13291 Mtetra
.664 .739 .906 r
.73728 .13291 .74048 .13771 .74756 .13511 .74437 .13031 Mtetra
.665 .74 .906 r
.74437 .13031 .74756 .13511 .75465 .13248 .75147 .12769 Mtetra
.664 .741 .908 r
.75147 .12769 .75465 .13248 .76176 .12987 .7586 .12508 Mtetra
.66 .74 .909 r
.7586 .12508 .76176 .12987 .7689 .12736 .76575 .12253 Mtetra
.661 .739 .908 r
.13124 .3487 .13534 .35255 .14102 .35048 .13691 .34665 Mtetra
.661 .741 .909 r
.13691 .34665 .14102 .35048 .1467 .34843 .1426 .34461 Mtetra
.664 .743 .909 r
.1426 .34461 .1467 .34843 .1524 .34637 .14831 .34251 Mtetra
.665 .742 .907 r
.14831 .34251 .1524 .34637 .15812 .34426 .15403 .3404 Mtetra
.663 .741 .908 r
.15403 .3404 .15812 .34426 .16384 .3422 .15977 .33831 Mtetra
.664 .741 .907 r
.15977 .33831 .16384 .3422 .16957 .34015 .16551 .3362 Mtetra
.664 .738 .905 r
.16551 .3362 .16957 .34015 .17533 .338 .17127 .33408 Mtetra
.659 .739 .908 r
.17127 .33408 .17533 .338 .18109 .33589 .17704 .33203 Mtetra
.666 .744 .908 r
.17704 .33203 .18109 .33589 .18687 .33381 .18283 .32988 Mtetra
.665 .74 .906 r
.18283 .32988 .18687 .33381 .19266 .33167 .18863 .32773 Mtetra
.662 .74 .908 r
.18863 .32773 .19266 .33167 .19847 .32951 .19443 .32563 Mtetra
.665 .744 .909 r
.19443 .32563 .19847 .32951 .20427 .32747 .20026 .32348 Mtetra
.661 .737 .906 r
.20026 .32348 .20427 .32747 .21011 .32527 .20609 .32137 Mtetra
.666 .744 .909 r
.20609 .32137 .21011 .32527 .21595 .3232 .21195 .31919 Mtetra
.662 .738 .906 r
.21195 .31919 .21595 .3232 .2218 .32108 .21781 .31706 Mtetra
.661 .737 .906 r
.21781 .31706 .2218 .32108 .22767 .31893 .22368 .31495 Mtetra
.661 .74 .908 r
.22368 .31495 .22767 .31893 .23355 .3168 .22957 .31284 Mtetra
.663 .742 .909 r
.22957 .31284 .23355 .3168 .23944 .31468 .23547 .31069 Mtetra
.668 .742 .906 r
.23547 .31069 .23944 .31468 .24535 .31256 .24139 .30846 Mtetra
.664 .736 .903 r
.24139 .30846 .24535 .31256 .25127 .31039 .24732 .30627 Mtetra
.653 .732 .907 r
.24732 .30627 .25127 .31039 .25721 .30817 .25325 .30425 Mtetra
.675 .749 .907 r
.25325 .30425 .25721 .30817 .26315 .30618 .25922 .3019 Mtetra
.646 .722 .904 r
.25922 .3019 .26315 .30618 .2691 .3041 .26517 .29997 Mtetra
.654 .733 .908 r
.26517 .29997 .2691 .3041 .27509 .30172 .27114 .29793 Mtetra
.66 .754 .919 r
.27114 .29793 .27509 .30172 .28109 .29939 .27714 .29578 Mtetra
.656 .764 .929 r
.27714 .29578 .28109 .29939 .2871 .29722 .28314 .2937 Mtetra
.646 .767 .937 r
.28314 .2937 .2871 .29722 .2931 .29523 .28915 .29174 Mtetra
.656 .772 .934 r
.28915 .29174 .2931 .29523 .29908 .29371 .29518 .28965 Mtetra
.698 .751 .893 r
.29518 .28965 .29908 .29371 .3051 .29185 .30128 .28685 Mtetra
.645 .69 .878 r
.30128 .28685 .3051 .29185 .31123 .28865 .30733 .28488 Mtetra
.659 .758 .923 r
.30733 .28488 .31123 .28865 .31728 .28682 .3134 .28273 Mtetra
.693 .751 .896 r
.3134 .28273 .31728 .28682 .32337 .28455 .31953 .27999 Mtetra
.636 .709 .9 r
.31953 .27999 .32337 .28455 .3295 .2818 .32562 .27817 Mtetra
.684 .774 .919 r
.32562 .27817 .3295 .2818 .33557 .28027 .33176 .27563 Mtetra
.652 .711 .891 r
.33176 .27563 .33557 .28027 .34175 .27729 .33789 .27354 Mtetra
.676 .766 .919 r
.33789 .27354 .34175 .27729 .34785 .2757 .34405 .27111 Mtetra
.642 .712 .898 r
.34405 .27111 .34785 .2757 .35403 .27315 .3502 .26917 Mtetra
.696 .76 .901 r
.3502 .26917 .35403 .27315 .3602 .27091 .35641 .26637 Mtetra
.639 .714 .902 r
.35641 .26637 .3602 .27091 .36638 .26885 .36258 .26448 Mtetra
.664 .732 .9 r
.36258 .26448 .36638 .26885 .3726 .26602 .36879 .26219 Mtetra
.684 .767 .914 r
.36879 .26219 .3726 .26602 .3788 .26411 .37503 .2596 Mtetra
.635 .715 .905 r
.37503 .2596 .3788 .26411 .38503 .26182 .38125 .25776 Mtetra
.674 .752 .91 r
.38125 .25776 .38503 .26182 .39129 .25915 .38751 .25532 Mtetra
.663 .763 .924 r
.38751 .25532 .39129 .25915 .39752 .25752 .39378 .25304 Mtetra
.663 .728 .898 r
.39378 .25304 .39752 .25752 .40382 .25458 .40006 .25073 Mtetra
.67 .765 .921 r
.40006 .25073 .40382 .25458 .41009 .25285 .40636 .24833 Mtetra
.664 .728 .897 r
.40636 .24833 .41009 .25285 .4164 .25021 .41267 .24599 Mtetra
.645 .737 .916 r
.41267 .24599 .4164 .25021 .42272 .24785 .41899 .24396 Mtetra
.666 .763 .922 r
.41899 .24396 .42272 .24785 .42905 .24579 .42533 .24161 Mtetra
.66 .746 .913 r
.42533 .24161 .42905 .24579 .43539 .2435 .43169 .23934 Mtetra
.658 .746 .915 r
.43169 .23934 .43539 .2435 .44176 .24106 .43806 .2371 Mtetra
.678 .765 .916 r
.43806 .2371 .44176 .24106 .44814 .23847 .44445 .23454 Mtetra
.683 .769 .916 r
.44445 .23454 .44814 .23847 .45452 .23652 .45086 .23189 Mtetra
.64 .717 .903 r
.45086 .23189 .45452 .23652 .46094 .23385 .45727 .22991 Mtetra
.686 .769 .915 r
.45727 .22991 .46094 .23385 .46735 .23198 .46371 .22721 Mtetra
.646 .713 .897 r
.46371 .22721 .46735 .23198 .4738 .22912 .47015 .22512 Mtetra
.66 .759 .923 r
.47015 .22512 .4738 .22912 .48024 .22727 .47661 .22281 Mtetra
.679 .742 .898 r
.47661 .22281 .48024 .22727 .48672 .2245 .48309 .22017 Mtetra
.643 .736 .917 r
.48309 .22017 .48672 .2245 .4932 .22213 .48958 .21812 Mtetra
.687 .769 .914 r
.48958 .21812 .4932 .22213 .49969 .22012 .49609 .21538 Mtetra
.658 .721 .896 r
.49609 .21538 .49969 .22012 .50621 .21747 .50262 .21307 Mtetra
.649 .736 .913 r
.50262 .21307 .50621 .21747 .51274 .21531 .50915 .2109 Mtetra
.688 .75 .899 r
.50915 .2109 .51274 .21531 .51928 .21307 .51571 .20808 Mtetra
.636 .703 .894 r
.51571 .20808 .51928 .21307 .52584 .21022 .52228 .20612 Mtetra
.689 .768 .912 r
.52228 .20612 .52584 .21022 .53242 .2083 .52887 .20329 Mtetra
.623 .697 .898 r
.52887 .20329 .53242 .2083 .53901 .20546 .53547 .20152 Mtetra
.704 .783 .913 r
.53547 .20152 .53901 .20546 .54562 .20343 .54209 .19844 Mtetra
.631 .702 .897 r
.54209 .19844 .54562 .20343 .55225 .20112 .54873 .19653 Mtetra
.655 .732 .906 r
.54873 .19653 .55225 .20112 .55888 .19805 .55538 .19424 Mtetra
.7 .79 .921 r
.55538 .19424 .55888 .19805 .56555 .19677 .56204 .19122 Mtetra
.617 .672 .88 r
.56204 .19122 .56555 .19677 .57222 .1942 .56873 .18952 Mtetra
.664 .733 .901 r
.56873 .18952 .57222 .1942 .5789 .19104 .57543 .18705 Mtetra
.68 .776 .923 r
.57543 .18705 .5789 .19104 .5856 .18825 .58214 .18433 Mtetra
.674 .779 .929 r
.58214 .18433 .5856 .18825 .59232 .1858 .58887 .18172 Mtetra
.668 .768 .925 r
.58887 .18172 .59232 .1858 .59906 .18344 .59562 .1792 Mtetra
.671 .761 .918 r
.59562 .1792 .59906 .18344 .60581 .1812 .60238 .1766 Mtetra
.68 .746 .901 r
.60238 .1766 .60581 .1812 .61258 .17871 .60915 .17383 Mtetra
.654 .722 .899 r
.60915 .17383 .61258 .17871 .61936 .17593 .61595 .1715 Mtetra
.675 .754 .91 r
.61595 .1715 .61936 .17593 .62617 .17363 .62276 .16882 Mtetra
.657 .728 .902 r
.62276 .16882 .62617 .17363 .63298 .17106 .62959 .16643 Mtetra
.662 .739 .907 r
.62959 .16643 .63298 .17106 .63981 .16848 .63644 .16395 Mtetra
.666 .747 .911 r
.63644 .16395 .63981 .16848 .64666 .16594 .6433 .1614 Mtetra
.6433 .1614 .64666 .16594 .65353 .16344 .65018 .15885 Mtetra
.664 .744 .91 r
.65018 .15885 .65353 .16344 .66042 .16096 .65707 .15633 Mtetra
.665 .743 .908 r
.65707 .15633 .66042 .16096 .66732 .1585 .66398 .15377 Mtetra
.665 .739 .905 r
.66398 .15377 .66732 .1585 .67424 .15592 .67091 .1512 Mtetra
.66 .738 .907 r
.67091 .1512 .67424 .15592 .68117 .1534 .67786 .14872 Mtetra
.668 .744 .907 r
.67786 .14872 .68117 .1534 .68813 .15086 .68482 .14609 Mtetra
.661 .737 .906 r
.68482 .14609 .68813 .15086 .69509 .14831 .69181 .14358 Mtetra
.664 .74 .907 r
.69181 .14358 .69509 .14831 .70208 .14574 .6988 .14101 Mtetra
.664 .741 .908 r
.6988 .14101 .70208 .14574 .70908 .14317 .70582 .13844 Mtetra
.663 .742 .908 r
.70582 .13844 .70908 .14317 .71611 .14068 .71285 .13587 Mtetra
.659 .736 .906 r
.71285 .13587 .71611 .14068 .72315 .13811 .71991 .13335 Mtetra
.667 .743 .907 r
.71991 .13335 .72315 .13811 .7302 .13544 .72697 .13071 Mtetra
.666 .745 .909 r
.72697 .13071 .7302 .13544 .73728 .13291 .73406 .12808 Mtetra
.662 .739 .907 r
.73406 .12808 .73728 .13291 .74437 .13031 .74116 .12551 Mtetra
.665 .741 .907 r
.74116 .12551 .74437 .13031 .75147 .12769 .74828 .12287 Mtetra
.664 .741 .907 r
.74828 .12287 .75147 .12769 .7586 .12508 .75542 .12026 Mtetra
.662 .74 .908 r
.75542 .12026 .7586 .12508 .76575 .12253 .76258 .11766 Mtetra
.66 .742 .91 r
.12711 .34488 .13124 .3487 .13691 .34665 .13279 .34284 Mtetra
.663 .743 .91 r
.13279 .34284 .13691 .34665 .1426 .34461 .13849 .34075 Mtetra
.666 .742 .907 r
.13849 .34075 .1426 .34461 .14831 .34251 .14421 .33861 Mtetra
.663 .74 .907 r
.14421 .33861 .14831 .34251 .15403 .3404 .14994 .33651 Mtetra
.665 .741 .907 r
.14994 .33651 .15403 .3404 .15977 .33831 .15568 .33439 Mtetra
.663 .739 .907 r
.15568 .33439 .15977 .33831 .16551 .3362 .16143 .33228 Mtetra
.66 .739 .908 r
.16143 .33228 .16551 .3362 .17127 .33408 .16719 .33022 Mtetra
.665 .744 .909 r
.16719 .33022 .17127 .33408 .17704 .33203 .17297 .32808 Mtetra
.665 .74 .906 r
.17297 .32808 .17704 .33203 .18283 .32988 .17877 .32593 Mtetra
.661 .739 .908 r
.17877 .32593 .18283 .32988 .18863 .32773 .18457 .32383 Mtetra
.666 .743 .908 r
.18457 .32383 .18863 .32773 .19443 .32563 .19039 .32166 Mtetra
.663 .74 .907 r
.19039 .32166 .19443 .32563 .20026 .32348 .19622 .31953 Mtetra
.665 .742 .908 r
.19622 .31953 .20026 .32348 .20609 .32137 .20206 .31737 Mtetra
.661 .738 .907 r
.20206 .31737 .20609 .32137 .21195 .31919 .20792 .31525 Mtetra
.664 .743 .909 r
.20792 .31525 .21195 .31919 .21781 .31706 .21379 .31309 Mtetra
.665 .742 .908 r
.21379 .31309 .21781 .31706 .22368 .31495 .21968 .31091 Mtetra
.664 .739 .905 r
.21968 .31091 .22368 .31495 .22957 .31284 .22557 .30874 Mtetra
.663 .735 .904 r
.22557 .30874 .22957 .31284 .23547 .31069 .23149 .30656 Mtetra
.658 .733 .905 r
.23149 .30656 .23547 .31069 .24139 .30846 .2374 .30447 Mtetra
.66 .742 .91 r
.2374 .30447 .24139 .30846 .24732 .30627 .24333 .30235 Mtetra
.672 .749 .908 r
.24333 .30235 .24732 .30627 .25325 .30425 .2493 .30004 Mtetra
.651 .728 .905 r
.2493 .30004 .25325 .30425 .25922 .3019 .25525 .29803 Mtetra
.67 .752 .912 r
.25525 .29803 .25922 .3019 .26517 .29997 .26123 .29575 Mtetra
.666 .733 .9 r
.26123 .29575 .26517 .29997 .27114 .29793 .26723 .29351 Mtetra
.651 .719 .898 r
.26723 .29351 .27114 .29793 .27714 .29578 .27322 .29148 Mtetra
.657 .727 .901 r
.27322 .29148 .27714 .29578 .28314 .2937 .27923 .28937 Mtetra
.668 .729 .895 r
.27923 .28937 .28314 .2937 .28915 .29174 .28527 .28707 Mtetra
.666 .712 .883 r
.28527 .28707 .28915 .29174 .29518 .28965 .29133 .28475 Mtetra
.625 .688 .889 r
.29133 .28475 .29518 .28965 .30128 .28685 .29735 .2831 Mtetra
.668 .762 .921 r
.29735 .2831 .30128 .28685 .30733 .28488 .30343 .28081 Mtetra
.698 .753 .894 r
.30343 .28081 .30733 .28488 .3134 .28273 .30956 .27798 Mtetra
.641 .702 .891 r
.30956 .27798 .3134 .28273 .31953 .27999 .31564 .27607 Mtetra
.66 .752 .918 r
.31564 .27607 .31953 .27999 .32562 .27817 .32176 .27389 Mtetra
.664 .734 .902 r
.32176 .27389 .32562 .27817 .33176 .27563 .32789 .27163 Mtetra
.673 .752 .91 r
.32789 .27163 .33176 .27563 .33789 .27354 .33404 .26922 Mtetra
.656 .731 .905 r
.33404 .26922 .33789 .27354 .34405 .27111 .3402 .26708 Mtetra
.684 .755 .905 r
.3402 .26708 .34405 .27111 .3502 .26917 .34639 .26449 Mtetra
.638 .707 .897 r
.34639 .26449 .3502 .26917 .35641 .26637 .35256 .2626 Mtetra
.682 .77 .917 r
.35256 .2626 .35641 .26637 .36258 .26448 .35878 .26005 Mtetra
.653 .726 .903 r
.35878 .26005 .36258 .26448 .36879 .26219 .36499 .25792 Mtetra
.655 .736 .909 r
.36499 .25792 .36879 .26219 .37503 .2596 .37121 .25577 Mtetra
.691 .77 .912 r
.37121 .25577 .37503 .2596 .38125 .25776 .37748 .25304 Mtetra
.641 .709 .896 r
.37748 .25304 .38125 .25776 .38751 .25532 .38373 .25109 Mtetra
.673 .745 .905 r
.38373 .25109 .38751 .25532 .39378 .25304 .39001 .24863 Mtetra
.66 .732 .903 r
.39001 .24863 .39378 .25304 .40006 .25073 .3963 .24638 Mtetra
.662 .736 .904 r
.3963 .24638 .40006 .25073 .40636 .24833 .40261 .24408 Mtetra
.65 .738 .913 r
.40261 .24408 .40636 .24833 .41267 .24599 .40892 .24197 Mtetra
.683 .761 .91 r
.40892 .24197 .41267 .24599 .41899 .24396 .41527 .23934 Mtetra
.673 .728 .891 r
.41527 .23934 .41899 .24396 .42533 .24161 .42162 .23683 Mtetra
.662 .717 .889 r
.42162 .23683 .42533 .24161 .43169 .23934 .42799 .23448 Mtetra
.65 .709 .891 r
.42799 .23448 .43169 .23934 .43806 .2371 .43436 .23234 Mtetra
.646 .713 .896 r
.43436 .23234 .43806 .2371 .44445 .23454 .44075 .23025 Mtetra
.672 .746 .906 r
.44075 .23025 .44445 .23454 .45086 .23189 .44717 .22776 Mtetra
.67 .755 .914 r
.44717 .22776 .45086 .23189 .45727 .22991 .45359 .22531 Mtetra
.652 .724 .902 r
.45359 .22531 .45727 .22991 .46371 .22721 .46003 .22313 Mtetra
.675 .76 .915 r
.46003 .22313 .46371 .22721 .47015 .22512 .46649 .22059 Mtetra
.671 .736 .899 r
.46649 .22059 .47015 .22512 .47661 .22281 .47297 .21807 Mtetra
.642 .715 .901 r
.47297 .21807 .47661 .22281 .48309 .22017 .47945 .21602 Mtetra
.678 .759 .912 r
.47945 .21602 .48309 .22017 .48958 .21812 .48595 .21342 Mtetra
.656 .723 .898 r
.48595 .21342 .48958 .21812 .49609 .21538 .49247 .21113 Mtetra
.654 .747 .918 r
.49247 .21113 .49609 .21538 .50262 .21307 .499 .2089 Mtetra
.692 .764 .907 r
.499 .2089 .50262 .21307 .50915 .2109 .50556 .20602 Mtetra
.631 .706 .9 r
.50556 .20602 .50915 .2109 .51571 .20808 .51212 .20413 Mtetra
.686 .775 .919 r
.51212 .20413 .51571 .20808 .52228 .20612 .5187 .20136 Mtetra
.644 .718 .902 r
.5187 .20136 .52228 .20612 .52887 .20329 .5253 .19925 Mtetra
.678 .769 .92 r
.5253 .19925 .52887 .20329 .53547 .20152 .53191 .19661 Mtetra
.653 .716 .894 r
.53191 .19661 .53547 .20152 .54209 .19844 .53854 .19434 Mtetra
.686 .77 .915 r
.53854 .19434 .54209 .19844 .54873 .19653 .54518 .19154 Mtetra
.637 .706 .897 r
.54518 .19154 .54873 .19653 .55538 .19424 .55185 .18952 Mtetra
.647 .724 .905 r
.55185 .18952 .55538 .19424 .56204 .19122 .55853 .18733 Mtetra
.699 .787 .919 r
.55853 .18733 .56204 .19122 .56873 .18952 .56522 .18432 Mtetra
.663 .708 .881 r
.56522 .18432 .56873 .18952 .57543 .18705 .57192 .1818 Mtetra
.652 .703 .883 r
.57192 .1818 .57543 .18705 .58214 .18433 .57865 .17948 Mtetra
.666 .727 .895 r
.57865 .17948 .58214 .18433 .58887 .18172 .58539 .17693 Mtetra
.672 .733 .896 r
.58539 .17693 .58887 .18172 .59562 .1792 .59215 .17428 Mtetra
.664 .724 .894 r
.59215 .17428 .59562 .1792 .60238 .1766 .59892 .17176 Mtetra
.655 .725 .9 r
.59892 .17176 .60238 .1766 .60915 .17383 .60571 .1694 Mtetra
.674 .754 .911 r
.60571 .1694 .60915 .17383 .61595 .1715 .61252 .16673 Mtetra
.656 .73 .904 r
.61252 .16673 .61595 .1715 .62276 .16882 .61934 .16434 Mtetra
.671 .752 .911 r
.61934 .16434 .62276 .16882 .62959 .16643 .62618 .16171 Mtetra
.664 .737 .904 r
.62618 .16171 .62959 .16643 .63644 .16395 .63304 .15919 Mtetra
.663 .735 .903 r
.63304 .15919 .63644 .16395 .6433 .1614 .63991 .15667 Mtetra
.664 .737 .905 r
.63991 .15667 .6433 .1614 .65018 .15885 .6468 .15412 Mtetra
.664 .738 .905 r
.6468 .15412 .65018 .15885 .65707 .15633 .65371 .15158 Mtetra
.663 .737 .905 r
.65371 .15158 .65707 .15633 .66398 .15377 .66063 .14905 Mtetra
.661 .739 .907 r
.66063 .14905 .66398 .15377 .67091 .1512 .66758 .14654 Mtetra
.667 .745 .908 r
.66758 .14654 .67091 .1512 .67786 .14872 .67453 .14393 Mtetra
.661 .736 .905 r
.67453 .14393 .67786 .14872 .68482 .14609 .68151 .14141 Mtetra
.665 .744 .909 r
.68151 .14141 .68482 .14609 .69181 .14358 .6885 .13881 Mtetra
.663 .74 .907 r
.6885 .13881 .69181 .14358 .6988 .14101 .69551 .13624 Mtetra
.661 .739 .908 r
.69551 .13624 .6988 .14101 .70582 .13844 .70254 .13371 Mtetra
.665 .743 .908 r
.70254 .13371 .70582 .13844 .71285 .13587 .70959 .13109 Mtetra
.664 .741 .908 r
.70959 .13109 .71285 .13587 .71991 .13335 .71665 .1285 Mtetra
.662 .737 .905 r
.71665 .1285 .71991 .13335 .72697 .13071 .72373 .12592 Mtetra
.665 .742 .908 r
.72373 .12592 .72697 .13071 .73406 .12808 .73083 .12329 Mtetra
.664 .742 .908 r
.73083 .12329 .73406 .12808 .74116 .12551 .73794 .12066 Mtetra
.663 .74 .907 r
.73794 .12066 .74116 .12551 .74828 .12287 .74508 .11806 Mtetra
.665 .743 .908 r
.74508 .11806 .74828 .12287 .75542 .12026 .75223 .11541 Mtetra
.664 .741 .908 r
.75223 .11541 .75542 .12026 .76258 .11766 .7594 .11277 Mtetra
.661 .741 .909 r
.12296 .34102 .12711 .34488 .13279 .34284 .12865 .33896 Mtetra
.666 .741 .906 r
.12865 .33896 .13279 .34284 .13849 .34075 .13437 .33681 Mtetra
.662 .737 .906 r
.13437 .33681 .13849 .34075 .14421 .33861 .14009 .33473 Mtetra
.663 .741 .908 r
.14009 .33473 .14421 .33861 .14994 .33651 .14582 .33263 Mtetra
.664 .742 .908 r
.14582 .33263 .14994 .33651 .15568 .33439 .15157 .3305 Mtetra
.663 .742 .909 r
.15157 .3305 .15568 .33439 .16143 .33228 .15733 .32839 Mtetra
.664 .742 .908 r
.15733 .32839 .16143 .33228 .16719 .33022 .1631 .32625 Mtetra
.663 .739 .906 r
.1631 .32625 .16719 .33022 .17297 .32808 .16889 .32413 Mtetra
.661 .739 .908 r
.16889 .32413 .17297 .32808 .17877 .32593 .17468 .32203 Mtetra
.667 .744 .908 r
.17468 .32203 .17877 .32593 .18457 .32383 .1805 .31984 Mtetra
.662 .739 .907 r
.1805 .31984 .18457 .32383 .19039 .32166 .18632 .31773 Mtetra
.666 .743 .908 r
.18632 .31773 .19039 .32166 .19622 .31953 .19216 .31555 Mtetra
.661 .739 .908 r
.19216 .31555 .19622 .31953 .20206 .31737 .19801 .31342 Mtetra
.665 .743 .908 r
.19801 .31342 .20206 .31737 .20792 .31525 .20388 .31124 Mtetra
.663 .739 .907 r
.20388 .31124 .20792 .31525 .21379 .31309 .20976 .30908 Mtetra
.66 .739 .908 r
.20976 .30908 .21379 .31309 .21968 .31091 .21565 .30695 Mtetra
.662 .743 .91 r
.21565 .30695 .21968 .31091 .22557 .30874 .22155 .3048 Mtetra
.665 .746 .91 r
.22155 .3048 .22557 .30874 .23149 .30656 .22747 .3026 Mtetra
.666 .745 .909 r
.22747 .3026 .23149 .30656 .2374 .30447 .23341 .30038 Mtetra
.663 .738 .905 r
.23341 .30038 .2374 .30447 .24333 .30235 .23935 .29819 Mtetra
.655 .733 .906 r
.23935 .29819 .24333 .30235 .2493 .30004 .2453 .29612 Mtetra
.671 .75 .91 r
.2453 .29612 .2493 .30004 .25525 .29803 .25128 .29382 Mtetra
.655 .731 .905 r
.25128 .29382 .25525 .29803 .26123 .29575 .25726 .29173 Mtetra
.655 .741 .914 r
.25726 .29173 .26123 .29575 .26723 .29351 .26325 .28966 Mtetra
.66 .753 .919 r
.26325 .28966 .26723 .29351 .27322 .29148 .26926 .28752 Mtetra
.658 .746 .915 r
.26926 .28752 .27322 .29148 .27923 .28937 .27528 .28539 Mtetra
.654 .745 .916 r
.27528 .28539 .27923 .28937 .28527 .28707 .28131 .28331 Mtetra
.663 .76 .922 r
.28131 .28331 .28527 .28707 .29133 .28475 .28736 .2811 Mtetra
.693 .774 .913 r
.28736 .2811 .29133 .28475 .29735 .2831 .29347 .27841 Mtetra
.641 .705 .893 r
.29347 .27841 .29735 .2831 .30343 .28081 .29953 .2765 Mtetra
.662 .732 .901 r
.29953 .2765 .30343 .28081 .30956 .27798 .30563 .27427 Mtetra
.69 .772 .914 r
.30563 .27427 .30956 .27798 .31564 .27607 .31177 .27161 Mtetra
.638 .717 .904 r
.31177 .27161 .31564 .27607 .32176 .27389 .31787 .26974 Mtetra
.68 .746 .901 r
.31787 .26974 .32176 .27389 .32789 .27163 .32403 .2672 Mtetra
.652 .725 .902 r
.32403 .2672 .32789 .27163 .33404 .26922 .33017 .26511 Mtetra
.675 .748 .906 r
.33017 .26511 .33404 .26922 .3402 .26708 .33635 .26265 Mtetra
.645 .723 .905 r
.33635 .26265 .3402 .26708 .34639 .26449 .34252 .26066 Mtetra
.689 .768 .912 r
.34252 .26066 .34639 .26449 .35256 .2626 .34874 .25798 Mtetra
.645 .714 .898 r
.34874 .25798 .35256 .2626 .35878 .26005 .35494 .25597 Mtetra
.666 .75 .913 r
.35494 .25597 .35878 .26005 .36499 .25792 .36117 .25365 Mtetra
.676 .743 .901 r
.36117 .25365 .36499 .25792 .37121 .25577 .36742 .25113 Mtetra
.645 .714 .898 r
.36742 .25113 .37121 .25577 .37748 .25304 .37366 .24911 Mtetra
.667 .759 .92 r
.37366 .24911 .37748 .25304 .38373 .25109 .37993 .24677 Mtetra
.666 .739 .904 r
.37993 .24677 .38373 .25109 .39001 .24863 .38622 .24441 Mtetra
.658 .742 .912 r
.38622 .24441 .39001 .24863 .3963 .24638 .39252 .24218 Mtetra
.672 .748 .908 r
.39252 .24218 .3963 .24638 .40261 .24408 .39884 .23972 Mtetra
.664 .738 .905 r
.39884 .23972 .40261 .24408 .40892 .24197 .40517 .23738 Mtetra
.649 .722 .902 r
.40517 .23738 .40892 .24197 .41527 .23934 .41151 .23527 Mtetra
.664 .754 .917 r
.41151 .23527 .41527 .23934 .42162 .23683 .41787 .23292 Mtetra
.668 .765 .923 r
.41787 .23292 .42162 .23683 .42799 .23448 .42424 .23052 Mtetra
.659 .76 .924 r
.42424 .23052 .42799 .23448 .43436 .23234 .43063 .22825 Mtetra
.67 .756 .915 r
.43063 .22825 .43436 .23234 .44075 .23025 .43704 .2258 Mtetra
.681 .741 .897 r
.43704 .2258 .44075 .23025 .44717 .22776 .44347 .22313 Mtetra
.643 .72 .904 r
.44347 .22313 .44717 .22776 .45359 .22531 .4499 .22108 Mtetra
.68 .754 .907 r
.4499 .22108 .45359 .22531 .46003 .22313 .45635 .21844 Mtetra
.647 .72 .901 r
.45635 .21844 .46003 .22313 .46649 .22059 .46281 .21632 Mtetra
.667 .749 .911 r
.46281 .21632 .46649 .22059 .47297 .21807 .4693 .21388 Mtetra
.674 .756 .912 r
.4693 .21388 .47297 .21807 .47945 .21602 .4758 .21133 Mtetra
.65 .722 .901 r
.4758 .21133 .47945 .21602 .48595 .21342 .48231 .20914 Mtetra
.678 .754 .908 r
.48231 .20914 .48595 .21342 .49247 .21113 .48884 .2065 Mtetra
.66 .73 .901 r
.48884 .2065 .49247 .21113 .499 .2089 .49538 .20413 Mtetra
.651 .72 .899 r
.49538 .20413 .499 .2089 .50556 .20602 .50194 .2019 Mtetra
.683 .766 .914 r
.50194 .2019 .50556 .20602 .51212 .20413 .50852 .19917 Mtetra
.642 .709 .895 r
.50852 .19917 .51212 .20413 .5187 .20136 .51511 .19707 Mtetra
.683 .758 .908 r
.51511 .19707 .5187 .20136 .5253 .19925 .52172 .19432 Mtetra
.634 .707 .9 r
.52172 .19432 .5253 .19925 .53191 .19661 .52834 .19236 Mtetra
.695 .765 .905 r
.52834 .19236 .53191 .19661 .53854 .19434 .53498 .18939 Mtetra
.638 .709 .898 r
.53498 .18939 .53854 .19434 .54518 .19154 .54163 .18734 Mtetra
.656 .755 .923 r
.54163 .18734 .54518 .19154 .55185 .18952 .54831 .18502 Mtetra
.691 .752 .899 r
.54831 .18502 .55185 .18952 .55853 .18733 .55499 .18207 Mtetra
.633 .694 .889 r
.55499 .18207 .55853 .18733 .56522 .18432 .5617 .18009 Mtetra
.661 .758 .922 r
.5617 .18009 .56522 .18432 .57192 .1818 .56842 .17767 Mtetra
.673 .768 .922 r
.56842 .17767 .57192 .1818 .57865 .17948 .57515 .17504 Mtetra
.67 .751 .911 r
.57515 .17504 .57865 .17948 .58539 .17693 .58191 .17245 Mtetra
.668 .748 .911 r
.58191 .17245 .58539 .17693 .59215 .17428 .58867 .1699 Mtetra
.671 .755 .914 r
.58867 .1699 .59215 .17428 .59892 .17176 .59546 .16728 Mtetra
.675 .752 .909 r
.59546 .16728 .59892 .17176 .60571 .1694 .60225 .16458 Mtetra
.655 .728 .903 r
.60225 .16458 .60571 .1694 .61252 .16673 .60907 .16222 Mtetra
.673 .751 .909 r
.60907 .16222 .61252 .16673 .61934 .16434 .61591 .15955 Mtetra
.66 .732 .903 r
.61591 .15955 .61934 .16434 .62618 .16171 .62276 .15709 Mtetra
.663 .743 .909 r
.62276 .15709 .62618 .16171 .63304 .15919 .62963 .15458 Mtetra
.663 .744 .91 r
.62963 .15458 .63304 .15919 .63991 .15667 .63651 .15204 Mtetra
.665 .745 .91 r
.63651 .15204 .63991 .15667 .6468 .15412 .64342 .14948 Mtetra
.665 .744 .909 r
.64342 .14948 .6468 .15412 .65371 .15158 .65033 .14691 Mtetra
.665 .743 .908 r
.65033 .14691 .65371 .15158 .66063 .14905 .65727 .14434 Mtetra
.665 .741 .907 r
.65727 .14434 .66063 .14905 .66758 .14654 .66422 .14176 Mtetra
.661 .737 .906 r
.66422 .14176 .66758 .14654 .67453 .14393 .67119 .13923 Mtetra
.666 .744 .909 r
.67119 .13923 .67453 .14393 .68151 .14141 .67818 .13662 Mtetra
.662 .739 .907 r
.67818 .13662 .68151 .14141 .6885 .13881 .68519 .13407 Mtetra
.663 .742 .908 r
.68519 .13407 .6885 .13881 .69551 .13624 .69221 .13149 Mtetra
.665 .743 .908 r
.69221 .13149 .69551 .13624 .70254 .13371 .69925 .12887 Mtetra
.66 .736 .907 r
.69925 .12887 .70254 .13371 .70959 .13109 .70631 .12633 Mtetra
.665 .744 .909 r
.70631 .12633 .70959 .13109 .71665 .1285 .71338 .1237 Mtetra
.665 .742 .907 r
.71338 .1237 .71665 .1285 .72373 .12592 .72047 .12105 Mtetra
.662 .738 .906 r
.72047 .12105 .72373 .12592 .73083 .12329 .72758 .11846 Mtetra
.665 .742 .907 r
.72758 .11846 .73083 .12329 .73794 .12066 .73471 .11581 Mtetra
.663 .741 .908 r
.73471 .11581 .73794 .12066 .74508 .11806 .74186 .11319 Mtetra
.664 .74 .907 r
.74186 .11319 .74508 .11806 .75223 .11541 .74902 .11055 Mtetra
.662 .74 .908 r
.74902 .11055 .75223 .11541 .7594 .11277 .75621 .10794 Mtetra
.662 .74 .907 r
.1188 .33713 .12296 .34102 .12865 .33896 .1245 .33504 Mtetra
.66 .738 .908 r
.1245 .33504 .12865 .33896 .13437 .33681 .13021 .33298 Mtetra
.664 .744 .91 r
.13021 .33298 .13437 .33681 .14009 .33473 .13594 .33086 Mtetra
.667 .744 .908 r
.13594 .33086 .14009 .33473 .14582 .33263 .14169 .3287 Mtetra
.664 .74 .907 r
.14169 .3287 .14582 .33263 .15157 .3305 .14745 .32656 Mtetra
.663 .74 .907 r
.14745 .32656 .15157 .3305 .15733 .32839 .15321 .32444 Mtetra
.662 .74 .907 r
.15321 .32444 .15733 .32839 .1631 .32625 .15899 .32232 Mtetra
.663 .741 .908 r
.15899 .32232 .1631 .32625 .16889 .32413 .16478 .3202 Mtetra
.665 .743 .908 r
.16478 .3202 .16889 .32413 .17468 .32203 .17059 .31802 Mtetra
.66 .738 .907 r
.17059 .31802 .17468 .32203 .1805 .31984 .17641 .31592 Mtetra
.667 .744 .908 r
.17641 .31592 .1805 .31984 .18632 .31773 .18225 .31372 Mtetra
.66 .738 .908 r
.18225 .31372 .18632 .31773 .19216 .31555 .18809 .3116 Mtetra
.666 .744 .908 r
.18809 .3116 .19216 .31555 .19801 .31342 .19395 .3094 Mtetra
.662 .739 .907 r
.19395 .3094 .19801 .31342 .20388 .31124 .19982 .30726 Mtetra
.662 .742 .909 r
.19982 .30726 .20388 .31124 .20976 .30908 .2057 .30511 Mtetra
.665 .744 .909 r
.2057 .30511 .20976 .30908 .21565 .30695 .21161 .30292 Mtetra
.665 .741 .907 r
.21161 .30292 .21565 .30695 .22155 .3048 .21752 .30072 Mtetra
.662 .738 .906 r
.21752 .30072 .22155 .3048 .22747 .3026 .22344 .29856 Mtetra
.661 .74 .909 r
.22344 .29856 .22747 .3026 .23341 .30038 .22938 .29641 Mtetra
.668 .746 .909 r
.22938 .29641 .23341 .30038 .23935 .29819 .23534 .29414 Mtetra
.66 .74 .91 r
.23534 .29414 .23935 .29819 .2453 .29612 .2413 .292 Mtetra
.665 .739 .905 r
.2413 .292 .2453 .29612 .25128 .29382 .24728 .28977 Mtetra
.656 .74 .912 r
.24728 .28977 .25128 .29382 .25726 .29173 .25327 .28766 Mtetra
.666 .742 .907 r
.25327 .28766 .25726 .29173 .26325 .28966 .25928 .28541 Mtetra
.666 .734 .9 r
.25928 .28541 .26325 .28966 .26926 .28752 .26531 .28313 Mtetra
.662 .726 .897 r
.26531 .28313 .26926 .28752 .27528 .28539 .27134 .28092 Mtetra
.653 .72 .897 r
.27134 .28092 .27528 .28539 .28131 .28331 .27738 .27883 Mtetra
.644 .717 .901 r
.27738 .27883 .28131 .28331 .28736 .2811 .28342 .27688 Mtetra
.658 .735 .907 r
.28342 .27688 .28736 .2811 .29347 .27841 .2895 .27472 Mtetra
.696 .774 .912 r
.2895 .27472 .29347 .27841 .29953 .2765 .29563 .27197 Mtetra
.647 .717 .899 r
.29563 .27197 .29953 .2765 .30563 .27427 .30172 .26996 Mtetra
.66 .732 .903 r
.30172 .26996 .30563 .27427 .31177 .27161 .30783 .26775 Mtetra
.686 .764 .911 r
.30783 .26775 .31177 .27161 .31787 .26974 .31399 .26514 Mtetra
.634 .71 .902 r
.31399 .26514 .31787 .26974 .32403 .2672 .32011 .26333 Mtetra
.693 .766 .907 r
.32011 .26333 .32403 .2672 .33017 .26511 .32631 .26058 Mtetra
.634 .714 .905 r
.32631 .26058 .33017 .26511 .33635 .26265 .33246 .25875 Mtetra
.681 .763 .913 r
.33246 .25875 .33635 .26265 .34252 .26066 .33866 .25619 Mtetra
.655 .726 .901 r
.33866 .25619 .34252 .26066 .34874 .25798 .34486 .25402 Mtetra
.657 .753 .921 r
.34486 .25402 .34874 .25798 .35494 .25597 .35108 .25184 Mtetra
.688 .754 .902 r
.35108 .25184 .35494 .25597 .36117 .25365 .35734 .24913 Mtetra
.637 .719 .907 r
.35734 .24913 .36117 .25365 .36742 .25113 .36357 .24723 Mtetra
.676 .764 .917 r
.36357 .24723 .36742 .25113 .37366 .24911 .36984 .24473 Mtetra
.67 .737 .9 r
.36984 .24473 .37366 .24911 .37993 .24677 .37613 .24229 Mtetra
.644 .724 .907 r
.37613 .24229 .37993 .24677 .38622 .24441 .38241 .24026 Mtetra
.689 .756 .903 r
.38241 .24026 .38622 .24441 .39252 .24218 .38874 .23751 Mtetra
.632 .711 .904 r
.38874 .23751 .39252 .24218 .39884 .23972 .39504 .23566 Mtetra
.681 .76 .911 r
.39504 .23566 .39884 .23972 .40517 .23738 .40139 .23306 Mtetra
.668 .743 .906 r
.40139 .23306 .40517 .23738 .41151 .23527 .40775 .23063 Mtetra
.649 .72 .901 r
.40775 .23063 .41151 .23527 .41787 .23292 .41411 .22851 Mtetra
.664 .738 .905 r
.41411 .22851 .41787 .23292 .42424 .23052 .4205 .22613 Mtetra
.676 .743 .901 r
.4205 .22613 .42424 .23052 .43063 .22825 .4269 .22355 Mtetra
.66 .723 .896 r
.4269 .22355 .43063 .22825 .43704 .2258 .43332 .22123 Mtetra
.644 .724 .907 r
.43332 .22123 .43704 .2258 .44347 .22313 .43974 .21916 Mtetra
.689 .771 .914 r
.43974 .21916 .44347 .22313 .4499 .22108 .44619 .21637 Mtetra
.638 .716 .904 r
.44619 .21637 .4499 .22108 .45635 .21844 .45264 .2144 Mtetra
.693 .769 .91 r
.45264 .2144 .45635 .21844 .46281 .21632 .45913 .21154 Mtetra
.641 .714 .901 r
.45913 .21154 .46281 .21632 .4693 .21388 .46562 .2095 Mtetra
.669 .745 .907 r
.46562 .2095 .4693 .21388 .4758 .21133 .47212 .20701 Mtetra
.677 .752 .908 r
.47212 .20701 .4758 .21133 .48231 .20914 .47865 .20439 Mtetra
.639 .716 .904 r
.47865 .20439 .48231 .20914 .48884 .2065 .48518 .20236 Mtetra
.679 .763 .915 r
.48518 .20236 .48884 .2065 .49538 .20413 .49174 .1997 Mtetra
.658 .741 .911 r
.49174 .1997 .49538 .20413 .50194 .2019 .49831 .19737 Mtetra
.656 .736 .908 r
.49831 .19737 .50194 .2019 .50852 .19917 .50489 .19507 Mtetra
.686 .769 .914 r
.50489 .19507 .50852 .19917 .51511 .19707 .5115 .19227 Mtetra
.641 .718 .903 r
.5115 .19227 .51511 .19707 .52172 .19432 .51811 .19018 Mtetra
.684 .768 .915 r
.51811 .19018 .52172 .19432 .52834 .19236 .52475 .18741 Mtetra
.647 .713 .896 r
.52475 .18741 .52834 .19236 .53498 .18939 .5314 .18521 Mtetra
.664 .76 .922 r
.5314 .18521 .53498 .18939 .54163 .18734 .53806 .18275 Mtetra
.684 .746 .899 r
.53806 .18275 .54163 .18734 .54831 .18502 .54474 .17993 Mtetra
.631 .702 .897 r
.54474 .17993 .54831 .18502 .55499 .18207 .55145 .17798 Mtetra
.663 .766 .927 r
.55145 .17798 .55499 .18207 .5617 .18009 .55816 .17552 Mtetra
.68 .748 .902 r
.55816 .17552 .5617 .18009 .56842 .17767 .56489 .17275 Mtetra
.672 .728 .891 r
.56489 .17275 .56842 .17767 .57515 .17504 .57163 .17007 Mtetra
.664 .723 .893 r
.57163 .17007 .57515 .17504 .58191 .17245 .5784 .16754 Mtetra
.66 .724 .897 r
.5784 .16754 .58191 .17245 .58867 .1699 .58518 .16509 Mtetra
.66 .73 .901 r
.58518 .16509 .58867 .1699 .59546 .16728 .59197 .16263 Mtetra
.668 .742 .905 r
.59197 .16263 .59546 .16728 .60225 .16458 .59878 .16003 Mtetra
.666 .747 .911 r
.59878 .16003 .60225 .16458 .60907 .16222 .60561 .15747 Mtetra
.663 .736 .904 r
.60561 .15747 .60907 .16222 .61591 .15955 .61246 .15495 Mtetra
.662 .744 .911 r
.61246 .15495 .61591 .15955 .62276 .15709 .61932 .15245 Mtetra
.668 .744 .907 r
.61932 .15245 .62276 .15709 .62963 .15458 .6262 .14983 Mtetra
.665 .739 .905 r
.6262 .14983 .62963 .15458 .63651 .15204 .6331 .14726 Mtetra
.662 .736 .905 r
.6331 .14726 .63651 .15204 .64342 .14948 .64001 .14473 Mtetra
.662 .738 .906 r
.64001 .14473 .64342 .14948 .65033 .14691 .64694 .14219 Mtetra
.663 .741 .908 r
.64694 .14219 .65033 .14691 .65727 .14434 .65389 .13962 Mtetra
.665 .743 .908 r
.65389 .13962 .65727 .14434 .66422 .14176 .66085 .13703 Mtetra
.664 .742 .908 r
.66085 .13703 .66422 .14176 .67119 .13923 .66784 .13445 Mtetra
.663 .74 .907 r
.66784 .13445 .67119 .13923 .67818 .13662 .67484 .13187 Mtetra
.663 .742 .909 r
.67484 .13187 .67818 .13662 .68519 .13407 .68185 .12929 Mtetra
.664 .741 .908 r
.68185 .12929 .68519 .13407 .69221 .13149 .68889 .12668 Mtetra
.661 .739 .908 r
.68889 .12668 .69221 .13149 .69925 .12887 .69594 .12412 Mtetra
.667 .745 .909 r
.69594 .12412 .69925 .12887 .70631 .12633 .70301 .12145 Mtetra
.662 .737 .906 r
.70301 .12145 .70631 .12633 .71338 .1237 .7101 .11886 Mtetra
.664 .741 .907 r
.7101 .11886 .71338 .1237 .72047 .12105 .7172 .11623 Mtetra
.664 .742 .908 r
.7172 .11623 .72047 .12105 .72758 .11846 .72432 .11359 Mtetra
.663 .74 .907 r
.72432 .11359 .72758 .11846 .73471 .11581 .73146 .11097 Mtetra
.664 .742 .908 r
.73146 .11097 .73471 .11581 .74186 .11319 .73862 .10831 Mtetra
.664 .741 .908 r
.73862 .10831 .74186 .11319 .74902 .11055 .7458 .10565 Mtetra
.662 .74 .908 r
.7458 .10565 .74902 .11055 .75621 .10794 .75299 .10302 Mtetra
.66 .741 .91 r
.11462 .33325 .1188 .33713 .1245 .33504 .12033 .33119 Mtetra
.665 .744 .909 r
.12033 .33119 .1245 .33504 .13021 .33298 .12605 .32905 Mtetra
.665 .741 .906 r
.12605 .32905 .13021 .33298 .13594 .33086 .13179 .3269 Mtetra
.661 .738 .907 r
.13179 .3269 .13594 .33086 .14169 .3287 .13754 .32481 Mtetra
.665 .743 .909 r
.13754 .32481 .14169 .3287 .14745 .32656 .1433 .32266 Mtetra
.666 .743 .908 r
.1433 .32266 .14745 .32656 .15321 .32444 .14908 .32049 Mtetra
.663 .741 .908 r
.14908 .32049 .15321 .32444 .15899 .32232 .15487 .31835 Mtetra
.663 .74 .907 r
.15487 .31835 .15899 .32232 .16478 .3202 .16067 .31621 Mtetra
.662 .74 .907 r
.16067 .31621 .16478 .3202 .17059 .31802 .16648 .31408 Mtetra
.665 .743 .908 r
.16648 .31408 .17059 .31802 .17641 .31592 .17231 .31189 Mtetra
.661 .738 .907 r
.17231 .31189 .17641 .31592 .18225 .31372 .17814 .30977 Mtetra
.666 .744 .909 r
.17814 .30977 .18225 .31372 .18809 .3116 .184 .30757 Mtetra
.663 .739 .907 r
.184 .30757 .18809 .3116 .19395 .3094 .18987 .30541 Mtetra
.662 .742 .909 r
.18987 .30541 .19395 .3094 .19982 .30726 .19574 .30326 Mtetra
.666 .743 .908 r
.19574 .30326 .19982 .30726 .2057 .30511 .20164 .30104 Mtetra
.664 .739 .906 r
.20164 .30104 .2057 .30511 .21161 .30292 .20755 .29884 Mtetra
.20755 .29884 .21161 .30292 .21752 .30072 .21347 .29664 Mtetra
.661 .739 .908 r
.21347 .29664 .21752 .30072 .22344 .29856 .2194 .29448 Mtetra
.662 .74 .908 r
.2194 .29448 .22344 .29856 .22938 .29641 .22535 .2923 Mtetra
.663 .739 .906 r
.22535 .2923 .22938 .29641 .23534 .29414 .23131 .2901 Mtetra
.667 .744 .908 r
.23131 .2901 .23534 .29414 .2413 .292 .23729 .28784 Mtetra
.655 .735 .908 r
.23729 .28784 .2413 .292 .24728 .28977 .24327 .28574 Mtetra
.664 .745 .911 r
.24327 .28574 .24728 .28977 .25327 .28766 .24927 .28352 Mtetra
.67 .741 .904 r
.24927 .28352 .25327 .28766 .25928 .28541 .2553 .28119 Mtetra
.661 .735 .904 r
.2553 .28119 .25928 .28541 .26531 .28313 .26132 .27899 Mtetra
.661 .739 .908 r
.26132 .27899 .26531 .28313 .27134 .28092 .26737 .27678 Mtetra
.667 .742 .906 r
.26737 .27678 .27134 .28092 .27738 .27883 .27343 .27448 Mtetra
.646 .725 .906 r
.27343 .27448 .27738 .27883 .28342 .27688 .27948 .2725 Mtetra
.644 .723 .906 r
.27948 .2725 .28342 .27688 .2895 .27472 .28554 .27054 Mtetra
.677 .744 .902 r
.28554 .27054 .2895 .27472 .29563 .27197 .29166 .26807 Mtetra
.679 .76 .912 r
.29166 .26807 .29563 .27197 .30172 .26996 .29779 .26558 Mtetra
.647 .725 .906 r
.29779 .26558 .30172 .26996 .30783 .26775 .30391 .26356 Mtetra
.674 .744 .903 r
.30391 .26356 .30783 .26775 .31399 .26514 .31006 .26112 Mtetra
.65 .746 .92 r
.31006 .26112 .31399 .26514 .32011 .26333 .3162 .25905 Mtetra
.681 .743 .898 r
.3162 .25905 .32011 .26333 .32631 .26058 .3224 .25647 Mtetra
.647 .742 .918 r
.3224 .25647 .32631 .26058 .33246 .25875 .32857 .25443 Mtetra
.686 .743 .895 r
.32857 .25443 .33246 .25875 .33866 .25619 .33479 .25175 Mtetra
.64 .723 .908 r
.33479 .25175 .33866 .25619 .34486 .25402 .34099 .2498 Mtetra
.67 .744 .906 r
.34099 .2498 .34486 .25402 .35108 .25184 .34722 .24739 Mtetra
.669 .733 .898 r
.34722 .24739 .35108 .25184 .35734 .24913 .35347 .24498 Mtetra
.644 .741 .919 r
.35347 .24498 .35734 .24913 .36357 .24723 .35972 .24296 Mtetra
.684 .747 .9 r
.35972 .24296 .36357 .24723 .36984 .24473 .36601 .2403 Mtetra
.648 .729 .908 r
.36601 .2403 .36984 .24473 .37613 .24229 .37229 .23821 Mtetra
.666 .753 .915 r
.37229 .23821 .37613 .24229 .38241 .24026 .37859 .23584 Mtetra
.672 .738 .9 r
.37859 .23584 .38241 .24026 .38874 .23751 .38492 .23335 Mtetra
.65 .745 .919 r
.38492 .23335 .38874 .23751 .39504 .23566 .39124 .23123 Mtetra
.665 .736 .903 r
.39124 .23123 .39504 .23566 .40139 .23306 .39759 .22884 Mtetra
.684 .754 .905 r
.39759 .22884 .40139 .23306 .40775 .23063 .40397 .22616 Mtetra
.654 .732 .906 r
.40397 .22616 .40775 .23063 .41411 .22851 .41034 .22394 Mtetra
.658 .728 .901 r
.41034 .22394 .41411 .22851 .4205 .22613 .41673 .22164 Mtetra
.675 .739 .899 r
.41673 .22164 .4205 .22613 .4269 .22355 .42315 .21907 Mtetra
.645 .729 .91 r
.42315 .21907 .4269 .22355 .43332 .22123 .42956 .21699 Mtetra
.653 .746 .918 r
.42956 .21699 .43332 .22123 .43974 .21916 .436 .21477 Mtetra
.69 .75 .898 r
.436 .21477 .43974 .21916 .44619 .21637 .44247 .21193 Mtetra
.64 .731 .914 r
.44247 .21193 .44619 .21637 .45264 .2144 .44893 .2099 Mtetra
.677 .742 .899 r
.44893 .2099 .45264 .2144 .45913 .21154 .45542 .20725 Mtetra
.66 .748 .915 r
.45542 .20725 .45913 .21154 .46562 .2095 .46192 .2049 Mtetra
.651 .729 .906 r
.46192 .2049 .46562 .2095 .47212 .20701 .46843 .20268 Mtetra
.686 .755 .904 r
.46843 .20268 .47212 .20701 .47865 .20439 .47497 .19989 Mtetra
.642 .732 .914 r
.47497 .19989 .47865 .20439 .48518 .20236 .48152 .1978 Mtetra
.667 .738 .903 r
.48152 .1978 .48518 .20236 .49174 .1997 .48808 .19531 Mtetra
.674 .75 .908 r
.48808 .19531 .49174 .1997 .49831 .19737 .49466 .1927 Mtetra
.644 .725 .907 r
.49466 .1927 .49831 .19737 .50489 .19507 .50126 .19056 Mtetra
.687 .749 .899 r
.50126 .19056 .50489 .19507 .5115 .19227 .50787 .1877 Mtetra
.636 .728 .914 r
.50787 .1877 .5115 .19227 .51811 .19018 .5145 .18568 Mtetra
.685 .75 .901 r
.5145 .18568 .51811 .19018 .52475 .18741 .52114 .18285 Mtetra
.645 .733 .913 r
.52114 .18285 .52475 .18741 .5314 .18521 .5278 .18069 Mtetra
.675 .747 .905 r
.5278 .18069 .5314 .18521 .53806 .18275 .53448 .17803 Mtetra
.66 .732 .902 r
.53448 .17803 .53806 .18275 .54474 .17993 .54117 .17559 Mtetra
.642 .746 .924 r
.54117 .17559 .54474 .17993 .55145 .17798 .54788 .17345 Mtetra
.678 .749 .905 r
.54788 .17345 .55145 .17798 .55816 .17552 .55461 .17072 Mtetra
.681 .737 .893 r
.55461 .17072 .55816 .17552 .56489 .17275 .56134 .16789 Mtetra
.66 .727 .899 r
.56134 .16789 .56489 .17275 .57163 .17007 .5681 .16543 Mtetra
.665 .74 .906 r
.5681 .16543 .57163 .17007 .5784 .16754 .57488 .1629 Mtetra
.667 .742 .906 r
.57488 .1629 .5784 .16754 .58518 .16509 .58166 .16032 Mtetra
.656 .732 .905 r
.58166 .16032 .58518 .16509 .59197 .16263 .58847 .15792 Mtetra
.662 .737 .906 r
.58847 .15792 .59197 .16263 .59878 .16003 .5953 .15542 Mtetra
.672 .747 .907 r
.5953 .15542 .59878 .16003 .60561 .15747 .60214 .15275 Mtetra
.66 .737 .907 r
.60214 .15275 .60561 .15747 .61246 .15495 .60899 .15028 Mtetra
.666 .742 .907 r
.60899 .15028 .61246 .15495 .61932 .15245 .61587 .14769 Mtetra
.666 .739 .905 r
.61587 .14769 .61932 .15245 .6262 .14983 .62276 .14509 Mtetra
.662 .739 .907 r
.62276 .14509 .6262 .14983 .6331 .14726 .62967 .14256 Mtetra
.663 .742 .909 r
.62967 .14256 .6331 .14726 .64001 .14473 .63659 .14 Mtetra
.665 .742 .908 r
.63659 .14 .64001 .14473 .64694 .14219 .64353 .13741 Mtetra
.662 .739 .907 r
.64353 .13741 .64694 .14219 .65389 .13962 .65049 .13486 Mtetra
.663 .741 .908 r
.65049 .13486 .65389 .13962 .66085 .13703 .65747 .13229 Mtetra
.666 .744 .908 r
.65747 .13229 .66085 .13703 .66784 .13445 .66446 .12966 Mtetra
.661 .74 .908 r
.66446 .12966 .66784 .13445 .67484 .13187 .67148 .1271 Mtetra
.666 .743 .908 r
.67148 .1271 .67484 .13187 .68185 .12929 .6785 .12447 Mtetra
.661 .739 .908 r
.6785 .12447 .68185 .12929 .68889 .12668 .68555 .1219 Mtetra
.666 .744 .908 r
.68555 .1219 .68889 .12668 .69594 .12412 .69261 .11924 Mtetra
.662 .738 .906 r
.69261 .11924 .69594 .12412 .70301 .12145 .6997 .11665 Mtetra
.665 .743 .909 r
.6997 .11665 .70301 .12145 .7101 .11886 .7068 .114 Mtetra
.665 .741 .907 r
.7068 .114 .7101 .11886 .7172 .11623 .71391 .11135 Mtetra
.663 .74 .907 r
.71391 .11135 .7172 .11623 .72432 .11359 .72105 .10872 Mtetra
.664 .742 .908 r
.72105 .10872 .72432 .11359 .73146 .11097 .7282 .10606 Mtetra
.662 .74 .907 r
.7282 .10606 .73146 .11097 .73862 .10831 .73537 .10343 Mtetra
.664 .742 .908 r
.73537 .10343 .73862 .10831 .7458 .10565 .74256 .10075 Mtetra
.74256 .10075 .7458 .10565 .75299 .10302 .74977 .09808 Mtetra
.664 .741 .908 r
.11043 .32933 .11462 .33325 .12033 .33119 .11615 .32721 Mtetra
.659 .737 .907 r
.11615 .32721 .12033 .33119 .12605 .32905 .12187 .32514 Mtetra
.663 .742 .909 r
.12187 .32514 .12605 .32905 .13179 .3269 .12761 .32302 Mtetra
.667 .745 .908 r
.12761 .32302 .13179 .3269 .13754 .32481 .13337 .32082 Mtetra
.662 .739 .907 r
.13337 .32082 .13754 .32481 .1433 .32266 .13914 .31871 Mtetra
.664 .741 .908 r
.13914 .31871 .1433 .32266 .14908 .32049 .14492 .31656 Mtetra
.666 .744 .908 r
.14492 .31656 .14908 .32049 .15487 .31835 .15072 .31437 Mtetra
.663 .741 .908 r
.15072 .31437 .15487 .31835 .16067 .31621 .15653 .31223 Mtetra
.15653 .31223 .16067 .31621 .16648 .31408 .16235 .31007 Mtetra
.663 .74 .907 r
.16235 .31007 .16648 .31408 .17231 .31189 .16818 .3079 Mtetra
.663 .742 .909 r
.16818 .3079 .17231 .31189 .17814 .30977 .17403 .30575 Mtetra
.665 .741 .907 r
.17403 .30575 .17814 .30977 .184 .30757 .17989 .30355 Mtetra
.661 .74 .908 r
.17989 .30355 .184 .30757 .18987 .30541 .18576 .3014 Mtetra
.665 .742 .908 r
.18576 .3014 .18987 .30541 .19574 .30326 .19166 .29919 Mtetra
.664 .74 .906 r
.19166 .29919 .19574 .30326 .20164 .30104 .19756 .29698 Mtetra
.663 .74 .907 r
.19756 .29698 .20164 .30104 .20755 .29884 .20347 .29479 Mtetra
.664 .741 .908 r
.20347 .29479 .20755 .29884 .21347 .29664 .2094 .29259 Mtetra
.664 .742 .908 r
.2094 .29259 .21347 .29664 .2194 .29448 .21534 .29038 Mtetra
.662 .739 .907 r
.21534 .29038 .2194 .29448 .22535 .2923 .2213 .28819 Mtetra
.66 .739 .908 r
.2213 .28819 .22535 .2923 .23131 .2901 .22726 .28603 Mtetra
.668 .744 .907 r
.22726 .28603 .23131 .2901 .23729 .28784 .23325 .28374 Mtetra
.656 .739 .911 r
.23325 .28374 .23729 .28784 .24327 .28574 .23924 .28162 Mtetra
.664 .741 .907 r
.23924 .28162 .24327 .28574 .24927 .28352 .24525 .27938 Mtetra
.669 .741 .905 r
.24525 .27938 .24927 .28352 .2553 .28119 .25128 .27706 Mtetra
.66 .74 .909 r
.25128 .27706 .2553 .28119 .26132 .27899 .25732 .27487 Mtetra
.661 .742 .91 r
.25732 .27487 .26132 .27899 .26737 .27678 .26337 .27266 Mtetra
.664 .743 .909 r
.26337 .27266 .26737 .27678 .27343 .27448 .26943 .2704 Mtetra
.659 .744 .913 r
.26943 .2704 .27343 .27448 .27948 .2725 .27551 .26821 Mtetra
.644 .729 .91 r
.27551 .26821 .27948 .2725 .28554 .27054 .28158 .26624 Mtetra
.669 .736 .901 r
.28158 .26624 .28554 .27054 .29166 .26807 .2877 .26388 Mtetra
.683 .747 .9 r
.2877 .26388 .29166 .26807 .29779 .26558 .29385 .26129 Mtetra
.648 .731 .91 r
.29385 .26129 .29779 .26558 .30391 .26356 .29997 .25925 Mtetra
.665 .737 .903 r
.29997 .25925 .30391 .26356 .31006 .26112 .30612 .25693 Mtetra
.661 .742 .91 r
.30612 .25693 .31006 .26112 .3162 .25905 .31228 .25469 Mtetra
.67 .736 .899 r
.31228 .25469 .3162 .25905 .3224 .25647 .31847 .25227 Mtetra
.659 .742 .911 r
.31847 .25227 .3224 .25647 .32857 .25443 .32467 .25004 Mtetra
.67 .736 .899 r
.32467 .25004 .32857 .25443 .33479 .25175 .33088 .24762 Mtetra
.653 .745 .917 r
.33088 .24762 .33479 .25175 .34099 .2498 .3371 .24547 Mtetra
.676 .742 .9 r
.3371 .24547 .34099 .2498 .34722 .24739 .34335 .24295 Mtetra
.655 .73 .904 r
.34335 .24295 .34722 .24739 .35347 .24498 .3496 .24075 Mtetra
.657 .742 .913 r
.3496 .24075 .35347 .24498 .35972 .24296 .35586 .23854 Mtetra
.679 .74 .896 r
.35586 .23854 .35972 .24296 .36601 .2403 .36216 .23593 Mtetra
.643 .731 .913 r
.36216 .23593 .36601 .2403 .37229 .23821 .36844 .23391 Mtetra
.674 .745 .904 r
.36844 .23391 .37229 .23821 .37859 .23584 .37476 .23139 Mtetra
.659 .733 .904 r
.37476 .23139 .37859 .23584 .38492 .23335 .38108 .2291 Mtetra
.667 .747 .91 r
.38108 .2291 .38492 .23335 .39124 .23123 .38743 .2267 Mtetra
.656 .73 .903 r
.38743 .2267 .39124 .23123 .39759 .22884 .39378 .22445 Mtetra
.674 .743 .902 r
.39378 .22445 .39759 .22884 .40397 .22616 .40016 .22191 Mtetra
.67 .749 .91 r
.40016 .22191 .40397 .22616 .41034 .22394 .40655 .21944 Mtetra
.662 .735 .904 r
.40655 .21944 .41034 .22394 .41673 .22164 .41296 .21709 Mtetra
.662 .732 .902 r
.41296 .21709 .41673 .22164 .42315 .21907 .41938 .21472 Mtetra
.654 .741 .913 r
.41938 .21472 .42315 .21907 .42956 .21699 .4258 .21249 Mtetra
.66 .736 .906 r
.4258 .21249 .42956 .21699 .436 .21477 .43225 .21015 Mtetra
.672 .734 .897 r
.43225 .21015 .436 .21477 .44247 .21193 .43872 .20759 Mtetra
.657 .744 .914 r
.43872 .20759 .44247 .21193 .44893 .2099 .4452 .2053 Mtetra
.662 .733 .902 r
.4452 .2053 .44893 .2099 .45542 .20725 .45169 .2029 Mtetra
.675 .75 .908 r
.45169 .2029 .45542 .20725 .46192 .2049 .45821 .20031 Mtetra
.646 .728 .909 r
.45821 .20031 .46192 .2049 .46843 .20268 .46473 .19817 Mtetra
.677 .744 .901 r
.46473 .19817 .46843 .20268 .47497 .19989 .47128 .1955 Mtetra
.659 .744 .913 r
.47128 .1955 .47497 .19989 .48152 .1978 .47784 .19315 Mtetra
.658 .731 .903 r
.47784 .19315 .48152 .1978 .48808 .19531 .48441 .19078 Mtetra
.678 .745 .901 r
.48441 .19078 .48808 .19531 .49466 .1927 .491 .18809 Mtetra
.646 .73 .91 r
.491 .18809 .49466 .1927 .50126 .19056 .4976 .18592 Mtetra
.676 .74 .899 r
.4976 .18592 .50126 .19056 .50787 .1877 .50423 .18324 Mtetra
.649 .74 .916 r
.50423 .18324 .50787 .1877 .5145 .18568 .51087 .18102 Mtetra
.674 .739 .9 r
.51087 .18102 .5145 .18568 .52114 .18285 .51752 .17837 Mtetra
.655 .742 .914 r
.51752 .17837 .52114 .18285 .5278 .18069 .52419 .17603 Mtetra
.675 .741 .9 r
.52419 .17603 .5278 .18069 .53448 .17803 .53088 .17334 Mtetra
.653 .732 .907 r
.53088 .17334 .53448 .17803 .54117 .17559 .53758 .17103 Mtetra
.651 .738 .913 r
.53758 .17103 .54117 .17559 .54788 .17345 .5443 .16873 Mtetra
.678 .741 .898 r
.5443 .16873 .54788 .17345 .55461 .17072 .55104 .16597 Mtetra
.671 .737 .9 r
.55104 .16597 .55461 .17072 .56134 .16789 .55779 .16332 Mtetra
.662 .744 .911 r
.55779 .16332 .56134 .16789 .5681 .16543 .56456 .16083 Mtetra
.666 .744 .909 r
.56456 .16083 .5681 .16543 .57488 .1629 .57134 .15828 Mtetra
.667 .744 .908 r
.57134 .15828 .57488 .1629 .58166 .16032 .57814 .1557 Mtetra
.66 .742 .91 r
.57814 .1557 .58166 .16032 .58847 .15792 .58496 .15322 Mtetra
.661 .739 .908 r
.58496 .15322 .58847 .15792 .5953 .15542 .5918 .15072 Mtetra
.67 .743 .905 r
.5918 .15072 .5953 .15542 .60214 .15275 .59864 .14807 Mtetra
.66 .74 .91 r
.59864 .14807 .60214 .15275 .60899 .15028 .60552 .14558 Mtetra
.669 .744 .907 r
.60552 .14558 .60899 .15028 .61587 .14769 .6124 .14294 Mtetra
.663 .739 .907 r
.6124 .14294 .61587 .14769 .62276 .14509 .6193 .14039 Mtetra
.664 .742 .909 r
.6193 .14039 .62276 .14509 .62967 .14256 .62622 .13782 Mtetra
.663 .741 .908 r
.62622 .13782 .62967 .14256 .63659 .14 .63316 .13526 Mtetra
.664 .742 .908 r
.63316 .13526 .63659 .14 .64353 .13741 .64011 .13267 Mtetra
.665 .743 .908 r
.64011 .13267 .64353 .13741 .65049 .13486 .64708 .13006 Mtetra
.661 .739 .908 r
.64708 .13006 .65049 .13486 .65747 .13229 .65407 .1275 Mtetra
.664 .742 .908 r
.65407 .1275 .65747 .13229 .66446 .12966 .66108 .12489 Mtetra
.665 .744 .909 r
.66108 .12489 .66446 .12966 .67148 .1271 .6681 .12226 Mtetra
.662 .739 .907 r
.6681 .12226 .67148 .1271 .6785 .12447 .67514 .11968 Mtetra
.666 .744 .909 r
.67514 .11968 .6785 .12447 .68555 .1219 .6822 .11702 Mtetra
.662 .739 .907 r
.6822 .11702 .68555 .1219 .69261 .11924 .68928 .11441 Mtetra
.664 .743 .908 r
.68928 .11441 .69261 .11924 .6997 .11665 .69637 .11177 Mtetra
.664 .741 .907 r
.69637 .11177 .6997 .11665 .7068 .114 .70348 .10911 Mtetra
.663 .74 .907 r
.70348 .10911 .7068 .114 .71391 .11135 .71061 .10647 Mtetra
.663 .741 .908 r
.71061 .10647 .71391 .11135 .72105 .10872 .71776 .10383 Mtetra
.71776 .10383 .72105 .10872 .7282 .10606 .72493 .10119 Mtetra
.665 .743 .909 r
.72493 .10119 .7282 .10606 .73537 .10343 .73211 .0985 Mtetra
.664 .741 .907 r
.73211 .0985 .73537 .10343 .74256 .10075 .73931 .09581 Mtetra
.662 .74 .908 r
.73931 .09581 .74256 .10075 .74977 .09808 .74653 .09316 Mtetra
.659 .74 .91 r
.10621 .32541 .11043 .32933 .11615 .32721 .11193 .32334 Mtetra
.666 .745 .909 r
.11193 .32334 .11615 .32721 .12187 .32514 .11767 .32117 Mtetra
.663 .74 .907 r
.11767 .32117 .12187 .32514 .12761 .32302 .12342 .31903 Mtetra
.662 .739 .907 r
.12342 .31903 .12761 .32302 .13337 .32082 .12918 .31692 Mtetra
.667 .745 .908 r
.12918 .31692 .13337 .32082 .13914 .31871 .13496 .31471 Mtetra
.662 .74 .908 r
.13496 .31471 .13914 .31871 .14492 .31656 .14075 .31258 Mtetra
.664 .742 .908 r
.14075 .31258 .14492 .31656 .15072 .31437 .14656 .31041 Mtetra
.665 .743 .908 r
.14656 .31041 .15072 .31437 .15653 .31223 .15237 .30823 Mtetra
.664 .741 .908 r
.15237 .30823 .15653 .31223 .16235 .31007 .1582 .30606 Mtetra
.663 .741 .908 r
.1582 .30606 .16235 .31007 .16818 .3079 .16404 .30388 Mtetra
.664 .741 .907 r
.16404 .30388 .16818 .3079 .17403 .30575 .1699 .3017 Mtetra
.663 .74 .907 r
.1699 .3017 .17403 .30575 .17989 .30355 .17577 .29952 Mtetra
.663 .741 .908 r
.17577 .29952 .17989 .30355 .18576 .3014 .18165 .29734 Mtetra
.664 .74 .907 r
.18165 .29734 .18576 .3014 .19166 .29919 .18755 .29513 Mtetra
.664 .741 .907 r
.18755 .29513 .19166 .29919 .19756 .29698 .19346 .29293 Mtetra
.664 .741 .908 r
.19346 .29293 .19756 .29698 .20347 .29479 .19938 .29072 Mtetra
.19938 .29072 .20347 .29479 .2094 .29259 .20532 .28851 Mtetra
.20532 .28851 .2094 .29259 .21534 .29038 .21127 .2863 Mtetra
.661 .741 .909 r
.21127 .2863 .21534 .29038 .2213 .28819 .21723 .28412 Mtetra
.662 .742 .909 r
.21723 .28412 .2213 .28819 .22726 .28603 .2232 .28191 Mtetra
.666 .741 .906 r
.2232 .28191 .22726 .28603 .23325 .28374 .2292 .27964 Mtetra
.66 .741 .91 r
.2292 .27964 .23325 .28374 .23924 .28162 .2352 .27746 Mtetra
.662 .739 .907 r
.2352 .27746 .23924 .28162 .24525 .27938 .24121 .27523 Mtetra
.667 .741 .906 r
.24121 .27523 .24525 .27938 .25128 .27706 .24725 .27293 Mtetra
.661 .742 .909 r
.24725 .27293 .25128 .27706 .25732 .27487 .2533 .27071 Mtetra
.662 .74 .908 r
.2533 .27071 .25732 .27487 .26337 .27266 .25935 .26848 Mtetra
.663 .74 .908 r
.25935 .26848 .26337 .27266 .26943 .2704 .26543 .26623 Mtetra
.658 .74 .91 r
.26543 .26623 .26943 .2704 .27551 .26821 .27151 .26405 Mtetra
.648 .738 .915 r
.27151 .26405 .27551 .26821 .28158 .26624 .2776 .26201 Mtetra
.671 .741 .903 r
.2776 .26201 .28158 .26624 .2877 .26388 .28372 .25961 Mtetra
.676 .742 .9 r
.28372 .25961 .2877 .26388 .29385 .26129 .28987 .25712 Mtetra
.651 .74 .914 r
.28987 .25712 .29385 .26129 .29997 .25925 .296 .25502 Mtetra
.667 .742 .906 r
.296 .25502 .29997 .25925 .30612 .25693 .30217 .25267 Mtetra
.659 .738 .909 r
.30217 .25267 .30612 .25693 .31228 .25469 .30834 .25044 Mtetra
.671 .744 .905 r
.30834 .25044 .31228 .25469 .31847 .25227 .31454 .24801 Mtetra
.658 .739 .91 r
.31454 .24801 .31847 .25227 .32467 .25004 .32074 .24579 Mtetra
.672 .744 .905 r
.32074 .24579 .32467 .25004 .33088 .24762 .32696 .24335 Mtetra
.651 .737 .912 r
.32696 .24335 .33088 .24762 .3371 .24547 .33318 .24122 Mtetra
.676 .747 .904 r
.33318 .24122 .3371 .24547 .34335 .24295 .33945 .23869 Mtetra
.657 .741 .912 r
.33945 .23869 .34335 .24295 .3496 .24075 .3457 .23647 Mtetra
.656 .74 .911 r
.3457 .23647 .3496 .24075 .35586 .23854 .35197 .23424 Mtetra
.679 .747 .902 r
.35197 .23424 .35586 .23854 .36216 .23593 .35828 .23164 Mtetra
.645 .737 .916 r
.35828 .23164 .36216 .23593 .36844 .23391 .36457 .22958 Mtetra
.672 .744 .905 r
.36457 .22958 .36844 .23391 .37476 .23139 .3709 .2271 Mtetra
.661 .743 .911 r
.3709 .2271 .37476 .23139 .38108 .2291 .37724 .22478 Mtetra
.667 .744 .908 r
.37724 .22478 .38108 .2291 .38743 .2267 .38359 .22236 Mtetra
.656 .74 .912 r
.38359 .22236 .38743 .2267 .39378 .22445 .38995 .22011 Mtetra
.676 .747 .904 r
.38995 .22011 .39378 .22445 .40016 .22191 .39635 .21753 Mtetra
.666 .742 .907 r
.39635 .21753 .40016 .22191 .40655 .21944 .40274 .2151 Mtetra
.663 .744 .91 r
.40274 .2151 .40655 .21944 .41296 .21709 .40916 .21271 Mtetra
.661 .742 .91 r
.40916 .21271 .41296 .21709 .41938 .21472 .41558 .21036 Mtetra
.656 .742 .913 r
.41558 .21036 .41938 .21472 .4258 .21249 .42202 .20808 Mtetra
.663 .742 .909 r
.42202 .20808 .4258 .21249 .43225 .21015 .42848 .20568 Mtetra
.669 .741 .905 r
.42848 .20568 .43225 .21015 .43872 .20759 .43496 .20318 Mtetra
.657 .741 .912 r
.43496 .20318 .43872 .20759 .4452 .2053 .44145 .20088 Mtetra
.663 .743 .91 r
.44145 .20088 .4452 .2053 .45169 .2029 .44795 .19847 Mtetra
.673 .746 .906 r
.44795 .19847 .45169 .2029 .45821 .20031 .45448 .19588 Mtetra
.647 .738 .915 r
.45448 .19588 .45821 .20031 .46473 .19817 .46101 .1937 Mtetra
.679 .748 .903 r
.46101 .1937 .46473 .19817 .47128 .1955 .46757 .19099 Mtetra
.657 .739 .91 r
.46757 .19099 .47128 .1955 .47784 .19315 .47413 .18866 Mtetra
.66 .741 .91 r
.47413 .18866 .47784 .19315 .48441 .19078 .48072 .18627 Mtetra
.677 .746 .903 r
.48072 .18627 .48441 .19078 .491 .18809 .48732 .18359 Mtetra
.648 .738 .915 r
.48732 .18359 .491 .18809 .4976 .18592 .49394 .18138 Mtetra
.677 .746 .903 r
.49394 .18138 .4976 .18592 .50423 .18324 .50057 .17868 Mtetra
.648 .735 .913 r
.50057 .17868 .50423 .18324 .51087 .18102 .50722 .17645 Mtetra
.675 .745 .903 r
.50722 .17645 .51087 .18102 .51752 .17837 .51388 .17377 Mtetra
.655 .737 .91 r
.51388 .17377 .51752 .17837 .52419 .17603 .52056 .17142 Mtetra
.674 .744 .904 r
.52056 .17142 .52419 .17603 .53088 .17334 .52726 .16875 Mtetra
.657 .74 .91 r
.52726 .16875 .53088 .17334 .53758 .17103 .53397 .16635 Mtetra
.65 .733 .91 r
.53397 .16635 .53758 .17103 .5443 .16873 .54071 .16406 Mtetra
.675 .743 .902 r
.54071 .16406 .5443 .16873 .55104 .16597 .54745 .16135 Mtetra
.672 .745 .905 r
.54745 .16135 .55104 .16597 .55779 .16332 .55421 .15869 Mtetra
.664 .742 .908 r
.55421 .15869 .55779 .16332 .56456 .16083 .56099 .15616 Mtetra
.665 .741 .907 r
.56099 .15616 .56456 .16083 .57134 .15828 .56779 .1536 Mtetra
.56779 .1536 .57134 .15828 .57814 .1557 .5746 .15103 Mtetra
.662 .741 .909 r
.5746 .15103 .57814 .1557 .58496 .15322 .58143 .14852 Mtetra
.663 .741 .908 r
.58143 .14852 .58496 .15322 .5918 .15072 .58828 .14598 Mtetra
.668 .741 .905 r
.58828 .14598 .5918 .15072 .59864 .14807 .59514 .14335 Mtetra
.66 .74 .909 r
.59514 .14335 .59864 .14807 .60552 .14558 .60202 .14085 Mtetra
.667 .742 .906 r
.60202 .14085 .60552 .14558 .6124 .14294 .60891 .13822 Mtetra
.664 .743 .909 r
.60891 .13822 .6124 .14294 .6193 .14039 .61583 .13564 Mtetra
.664 .742 .908 r
.61583 .13564 .6193 .14039 .62622 .13782 .62276 .13306 Mtetra
.62276 .13306 .62622 .13782 .63316 .13526 .62971 .13047 Mtetra
.663 .74 .907 r
.62971 .13047 .63316 .13526 .64011 .13267 .63667 .12787 Mtetra
.664 .741 .907 r
.63667 .12787 .64011 .13267 .64708 .13006 .64366 .12527 Mtetra
.663 .741 .908 r
.64366 .12527 .64708 .13006 .65407 .1275 .65066 .12267 Mtetra
.662 .739 .907 r
.65066 .12267 .65407 .1275 .66108 .12489 .65768 .12008 Mtetra
.666 .742 .907 r
.65768 .12008 .66108 .12489 .6681 .12226 .66471 .11742 Mtetra
.662 .74 .908 r
.66471 .11742 .6681 .12226 .67514 .11968 .67176 .11482 Mtetra
.665 .741 .907 r
.67176 .11482 .67514 .11968 .6822 .11702 .67883 .11216 Mtetra
.663 .741 .908 r
.67883 .11216 .6822 .11702 .68928 .11441 .68592 .10953 Mtetra
.663 .74 .907 r
.68592 .10953 .68928 .11441 .69637 .11177 .69303 .10688 Mtetra
.664 .741 .908 r
.69303 .10688 .69637 .11177 .70348 .10911 .70015 .10421 Mtetra
.662 .741 .908 r
.70015 .10421 .70348 .10911 .71061 .10647 .70729 .10158 Mtetra
.663 .742 .909 r
.70729 .10158 .71061 .10647 .71776 .10383 .71446 .09893 Mtetra
.665 .743 .908 r
.71446 .09893 .71776 .10383 .72493 .10119 .72163 .09623 Mtetra
.662 .739 .907 r
.72163 .09623 .72493 .10119 .73211 .0985 .72883 .09358 Mtetra
.665 .743 .908 r
.72883 .09358 .73211 .0985 .73931 .09581 .73604 .09087 Mtetra
.665 .742 .908 r
.73604 .09087 .73931 .09581 .74653 .09316 .74327 .08816 Mtetra
.662 .741 .908 r
.10198 .32147 .10621 .32541 .11193 .32334 .10771 .31935 Mtetra
.659 .738 .908 r
.10771 .31935 .11193 .32334 .11767 .32117 .11345 .31726 Mtetra
.666 .745 .909 r
.11345 .31726 .11767 .32117 .12342 .31903 .11921 .31507 Mtetra
.664 .742 .908 r
.11921 .31507 .12342 .31903 .12918 .31692 .12498 .31291 Mtetra
.662 .739 .907 r
.12498 .31291 .12918 .31692 .13496 .31471 .13076 .31077 Mtetra
.667 .744 .908 r
.13076 .31077 .13496 .31471 .14075 .31258 .13657 .30856 Mtetra
.661 .739 .908 r
.13657 .30856 .14075 .31258 .14656 .31041 .14237 .30643 Mtetra
.666 .743 .908 r
.14237 .30643 .14656 .31041 .15237 .30823 .1482 .30421 Mtetra
.662 .741 .908 r
.1482 .30421 .15237 .30823 .1582 .30606 .15404 .30205 Mtetra
.665 .742 .908 r
.15404 .30205 .1582 .30606 .16404 .30388 .15989 .29985 Mtetra
.663 .741 .908 r
.15989 .29985 .16404 .30388 .1699 .3017 .16575 .29767 Mtetra
.664 .742 .908 r
.16575 .29767 .1699 .3017 .17577 .29952 .17163 .29546 Mtetra
.663 .74 .908 r
.17163 .29546 .17577 .29952 .18165 .29734 .17752 .29327 Mtetra
.663 .741 .908 r
.17752 .29327 .18165 .29734 .18755 .29513 .18342 .29108 Mtetra
.664 .742 .908 r
.18342 .29108 .18755 .29513 .19346 .29293 .18934 .28886 Mtetra
.18934 .28886 .19346 .29293 .19938 .29072 .19527 .28664 Mtetra
.664 .741 .908 r
.19527 .28664 .19938 .29072 .20532 .28851 .20121 .28441 Mtetra
.662 .741 .908 r
.20121 .28441 .20532 .28851 .21127 .2863 .20717 .28221 Mtetra
.661 .741 .91 r
.20717 .28221 .21127 .2863 .21723 .28412 .21314 .28002 Mtetra
.666 .743 .907 r
.21314 .28002 .21723 .28412 .2232 .28191 .21913 .27774 Mtetra
.662 .738 .907 r
.21913 .27774 .2232 .28191 .2292 .27964 .22512 .27552 Mtetra
.664 .742 .908 r
.22512 .27552 .2292 .27964 .2352 .27746 .23114 .27327 Mtetra
.659 .738 .908 r
.23114 .27327 .2352 .27746 .24121 .27523 .23716 .27108 Mtetra
.665 .742 .908 r
.23716 .27108 .24121 .27523 .24725 .27293 .2432 .26881 Mtetra
.664 .744 .909 r
.2432 .26881 .24725 .27293 .2533 .27071 .24926 .26654 Mtetra
.662 .741 .908 r
.24926 .26654 .2533 .27071 .25935 .26848 .25533 .26429 Mtetra
.66 .74 .909 r
.25533 .26429 .25935 .26848 .26543 .26623 .2614 .26208 Mtetra
.652 .74 .914 r
.2614 .26208 .26543 .26623 .27151 .26405 .26749 .25998 Mtetra
.659 .747 .915 r
.26749 .25998 .27151 .26405 .2776 .26201 .27359 .25778 Mtetra
.68 .745 .9 r
.27359 .25778 .2776 .26201 .28372 .25961 .27974 .25522 Mtetra
.657 .73 .903 r
.27974 .25522 .28372 .25961 .28987 .25712 .28587 .25302 Mtetra
.659 .747 .915 r
.28587 .25302 .28987 .25712 .296 .25502 .29202 .2508 Mtetra
.676 .746 .903 r
.29202 .2508 .296 .25502 .30217 .25267 .29821 .24829 Mtetra
.644 .729 .91 r
.29821 .24829 .30217 .25267 .30834 .25044 .30437 .24627 Mtetra
.682 .751 .904 r
.30437 .24627 .30834 .25044 .31454 .24801 .31059 .24367 Mtetra
.647 .732 .911 r
.31059 .24367 .31454 .24801 .32074 .24579 .31679 .24159 Mtetra
.677 .749 .905 r
.31679 .24159 .32074 .24579 .32696 .24335 .32303 .23905 Mtetra
.652 .737 .912 r
.32303 .23905 .32696 .24335 .33318 .24122 .32926 .23689 Mtetra
.666 .741 .906 r
.32926 .23689 .33318 .24122 .33945 .23869 .33552 .23452 Mtetra
.673 .751 .91 r
.33552 .23452 .33945 .23869 .3457 .23647 .3418 .23204 Mtetra
.647 .731 .91 r
.3418 .23204 .3457 .23647 .35197 .23424 .34807 .22995 Mtetra
.672 .746 .906 r
.34807 .22995 .35197 .23424 .35828 .23164 .35438 .22745 Mtetra
.663 .749 .914 r
.35438 .22745 .35828 .23164 .36457 .22958 .3607 .2251 Mtetra
.653 .731 .907 r
.3607 .2251 .36457 .22958 .3709 .2271 .36702 .2229 Mtetra
.681 .755 .908 r
.36702 .2229 .3709 .2271 .37724 .22478 .37338 .22026 Mtetra
.646 .728 .908 r
.37338 .22026 .37724 .22478 .38359 .22236 .37973 .21815 Mtetra
.672 .753 .912 r
.37973 .21815 .38359 .22236 .38995 .22011 .38611 .21564 Mtetra
.672 .74 .902 r
.38611 .21564 .38995 .22011 .39635 .21753 .39251 .21311 Mtetra
.652 .737 .912 r
.39251 .21311 .39635 .21753 .40274 .2151 .39891 .2109 Mtetra
.665 .753 .916 r
.39891 .2109 .40274 .2151 .40916 .21271 .40533 .20849 Mtetra
.675 .755 .911 r
.40533 .20849 .40916 .21271 .41558 .21036 .41178 .20591 Mtetra
.66 .739 .909 r
.41178 .20591 .41558 .21036 .42202 .20808 .41823 .20356 Mtetra
.651 .733 .909 r
.41823 .20356 .42202 .20808 .42848 .20568 .42469 .20134 Mtetra
.68 .753 .906 r
.42469 .20134 .42848 .20568 .43496 .20318 .43119 .19865 Mtetra
.645 .731 .912 r
.43119 .19865 .43496 .20318 .44145 .20088 .43768 .19652 Mtetra
.681 .753 .906 r
.43768 .19652 .44145 .20088 .44795 .19847 .4442 .19381 Mtetra
.651 .728 .906 r
.4442 .19381 .44795 .19847 .45448 .19588 .45073 .19157 Mtetra
.663 .751 .916 r
.45073 .19157 .45448 .19588 .46101 .1937 .45727 .18915 Mtetra
.678 .744 .9 r
.45727 .18915 .46101 .1937 .46757 .19099 .46384 .18644 Mtetra
.647 .734 .912 r
.46384 .18644 .46757 .19099 .47413 .18866 .47042 .18425 Mtetra
.674 .751 .909 r
.47042 .18425 .47413 .18866 .48072 .18627 .47701 .18163 Mtetra
.664 .736 .904 r
.47701 .18163 .48072 .18627 .48732 .18359 .48362 .17915 Mtetra
.654 .744 .916 r
.48362 .17915 .48732 .18359 .49394 .18138 .49025 .17683 Mtetra
.679 .747 .903 r
.49025 .17683 .49394 .18138 .50057 .17868 .49689 .17409 Mtetra
.645 .734 .913 r
.49689 .17409 .50057 .17868 .50722 .17645 .50355 .17189 Mtetra
.68 .749 .903 r
.50355 .17189 .50722 .17645 .51388 .17377 .51023 .16912 Mtetra
.653 .735 .91 r
.51023 .16912 .51388 .17377 .52056 .17142 .51692 .1668 Mtetra
.665 .741 .907 r
.51692 .1668 .52056 .17142 .52726 .16875 .52363 .16427 Mtetra
.672 .752 .91 r
.52363 .16427 .52726 .16875 .53397 .16635 .53035 .16162 Mtetra
.647 .73 .909 r
.53035 .16162 .53397 .16635 .54071 .16406 .53709 .15936 Mtetra
.665 .739 .905 r
.53709 .15936 .54071 .16406 .54745 .16135 .54385 .15681 Mtetra
.675 .751 .908 r
.54385 .15681 .54745 .16135 .55421 .15869 .55062 .15409 Mtetra
.669 .747 .909 r
.55062 .15409 .55421 .15869 .56099 .15616 .55741 .15147 Mtetra
.665 .741 .907 r
.55741 .15147 .56099 .15616 .56779 .1536 .56422 .14891 Mtetra
.664 .741 .908 r
.56422 .14891 .56779 .1536 .5746 .15103 .57104 .14636 Mtetra
.662 .742 .909 r
.57104 .14636 .5746 .15103 .58143 .14852 .57788 .14383 Mtetra
.666 .743 .908 r
.57788 .14383 .58143 .14852 .58828 .14598 .58474 .14122 Mtetra
.665 .74 .906 r
.58474 .14122 .58828 .14598 .59514 .14335 .59161 .13863 Mtetra
.663 .742 .909 r
.59161 .13863 .59514 .14335 .60202 .14085 .59851 .13606 Mtetra
.663 .739 .907 r
.59851 .13606 .60202 .14085 .60891 .13822 .60542 .1335 Mtetra
.667 .744 .908 r
.60542 .1335 .60891 .13822 .61583 .13564 .61234 .13086 Mtetra
.663 .74 .908 r
.61234 .13086 .61583 .13564 .62276 .13306 .61928 .12828 Mtetra
.664 .741 .908 r
.61928 .12828 .62276 .13306 .62971 .13047 .62624 .12567 Mtetra
.62624 .12567 .62971 .13047 .63667 .12787 .63322 .12306 Mtetra
.663 .741 .907 r
.63322 .12306 .63667 .12787 .64366 .12527 .64021 .12044 Mtetra
.663 .741 .908 r
.64021 .12044 .64366 .12527 .65066 .12267 .64723 .11783 Mtetra
.64723 .11783 .65066 .12267 .65768 .12008 .65426 .11521 Mtetra
.664 .74 .907 r
.65426 .11521 .65768 .12008 .66471 .11742 .6613 .11257 Mtetra
.664 .741 .908 r
.6613 .11257 .66471 .11742 .67176 .11482 .66837 .10993 Mtetra
.663 .74 .907 r
.66837 .10993 .67176 .11482 .67883 .11216 .67545 .10729 Mtetra
.664 .741 .908 r
.67545 .10729 .67883 .11216 .68592 .10953 .68255 .10463 Mtetra
.663 .741 .908 r
.68255 .10463 .68592 .10953 .69303 .10688 .68967 .10199 Mtetra
.664 .742 .908 r
.68967 .10199 .69303 .10688 .70015 .10421 .69681 .09931 Mtetra
.662 .741 .909 r
.69681 .09931 .70015 .10421 .70729 .10158 .70396 .09668 Mtetra
.666 .743 .908 r
.70396 .09668 .70729 .10158 .71446 .09893 .71113 .09396 Mtetra
.661 .739 .907 r
.71113 .09396 .71446 .09893 .72163 .09623 .71833 .09132 Mtetra
.664 .744 .909 r
.71833 .09132 .72163 .09623 .72883 .09358 .72553 .08862 Mtetra
.666 .743 .907 r
.72553 .08862 .72883 .09358 .73604 .09087 .73276 .08587 Mtetra
.662 .739 .907 r
.73276 .08587 .73604 .09087 .74327 .08816 .74001 .08319 Mtetra
.66 .741 .91 r
.09773 .31752 .10198 .32147 .10771 .31935 .10347 .31542 Mtetra
.666 .744 .908 r
.10347 .31542 .10771 .31935 .11345 .31726 .10922 .31323 Mtetra
.66 .737 .907 r
.10922 .31323 .11345 .31726 .11921 .31507 .11498 .31111 Mtetra
.667 .744 .908 r
.11498 .31111 .11921 .31507 .12498 .31291 .12077 .3089 Mtetra
.662 .74 .908 r
.12077 .3089 .12498 .31291 .13076 .31077 .12655 .30676 Mtetra
.665 .741 .907 r
.12655 .30676 .13076 .31077 .13657 .30856 .13236 .30457 Mtetra
.663 .742 .909 r
.13236 .30457 .13657 .30856 .14237 .30643 .13818 .30239 Mtetra
.664 .741 .907 r
.13818 .30239 .14237 .30643 .1482 .30421 .14401 .3002 Mtetra
.663 .742 .909 r
.14401 .3002 .1482 .30421 .15404 .30205 .14985 .29802 Mtetra
.665 .742 .908 r
.14985 .29802 .15404 .30205 .15989 .29985 .15571 .29581 Mtetra
.662 .741 .909 r
.15571 .29581 .15989 .29985 .16575 .29767 .16158 .29363 Mtetra
.665 .743 .908 r
.16158 .29363 .16575 .29767 .17163 .29546 .16747 .2914 Mtetra
.662 .741 .909 r
.16747 .2914 .17163 .29546 .17752 .29327 .17336 .28921 Mtetra
.663 .742 .909 r
.17336 .28921 .17752 .29327 .18342 .29108 .17927 .28701 Mtetra
.665 .743 .908 r
.17927 .28701 .18342 .29108 .18934 .28886 .1852 .28477 Mtetra
.665 .742 .908 r
.1852 .28477 .18934 .28886 .19527 .28664 .19114 .28253 Mtetra
.663 .741 .908 r
.19114 .28253 .19527 .28664 .20121 .28441 .19709 .28032 Mtetra
.661 .741 .909 r
.19709 .28032 .20121 .28441 .20717 .28221 .20305 .27812 Mtetra
.665 .743 .909 r
.20305 .27812 .20717 .28221 .21314 .28002 .20903 .27586 Mtetra
.665 .74 .906 r
.20903 .27586 .21314 .28002 .21913 .27774 .21503 .2736 Mtetra
.661 .741 .909 r
.21503 .2736 .21913 .27774 .22512 .27552 .22103 .27138 Mtetra
.665 .742 .907 r
.22103 .27138 .22512 .27552 .23114 .27327 .22706 .2691 Mtetra
.66 .739 .909 r
.22706 .2691 .23114 .27327 .23716 .27108 .23309 .26689 Mtetra
.23309 .26689 .23716 .27108 .2432 .26881 .23913 .26469 Mtetra
.662 .744 .911 r
.23913 .26469 .2432 .26881 .24926 .26654 .24519 .26245 Mtetra
.661 .746 .913 r
.24519 .26245 .24926 .26654 .25533 .26429 .25127 .26023 Mtetra
.658 .747 .915 r
.25127 .26023 .25533 .26429 .2614 .26208 .25735 .25803 Mtetra
.661 .749 .915 r
.25735 .25803 .2614 .26208 .26749 .25998 .26345 .25579 Mtetra
.674 .746 .904 r
.26345 .25579 .26749 .25998 .27359 .25778 .26959 .25333 Mtetra
.662 .729 .899 r
.26959 .25333 .27359 .25778 .27974 .25522 .27572 .25104 Mtetra
.653 .741 .914 r
.27572 .25104 .27974 .25522 .28587 .25302 .28186 .2489 Mtetra
.677 .752 .908 r
.28186 .2489 .28587 .25302 .29202 .2508 .28804 .24639 Mtetra
.66 .732 .903 r
.28804 .24639 .29202 .2508 .29821 .24829 .29421 .24412 Mtetra
.656 .744 .915 r
.29421 .24412 .29821 .24829 .30437 .24627 .3004 .24193 Mtetra
.669 .739 .903 r
.3004 .24193 .30437 .24627 .31059 .24367 .30661 .23951 Mtetra
.662 .748 .914 r
.30661 .23951 .31059 .24367 .31679 .24159 .31283 .2372 Mtetra
.659 .735 .906 r
.31283 .2372 .31679 .24159 .32303 .23905 .31906 .23494 Mtetra
.68 .757 .909 r
.31906 .23494 .32303 .23905 .32926 .23689 .32533 .23235 Mtetra
.644 .723 .906 r
.32533 .23235 .32926 .23689 .33552 .23452 .33158 .23029 Mtetra
.673 .749 .908 r
.33158 .23029 .33552 .23452 .3418 .23204 .33787 .2278 Mtetra
.665 .747 .911 r
.33787 .2278 .3418 .23204 .34807 .22995 .34416 .22542 Mtetra
.649 .727 .906 r
.34416 .22542 .34807 .22995 .35438 .22745 .35046 .22328 Mtetra
.683 .757 .907 r
.35046 .22328 .35438 .22745 .3607 .2251 .35681 .2206 Mtetra
.644 .728 .91 r
.35681 .2206 .3607 .2251 .36702 .2229 .36313 .21852 Mtetra
.676 .745 .903 r
.36313 .21852 .36702 .2229 .37338 .22026 .3695 .21593 Mtetra
.651 .741 .915 r
.3695 .21593 .37338 .22026 .37973 .21815 .37586 .21375 Mtetra
.68 .747 .901 r
.37586 .21375 .37973 .21815 .38611 .21564 .38226 .21107 Mtetra
.644 .727 .909 r
.38226 .21107 .38611 .21564 .39251 .21311 .38865 .20898 Mtetra
.662 .756 .92 r
.38865 .20898 .39251 .21311 .39891 .2109 .39506 .20661 Mtetra
.662 .748 .914 r
.39506 .20661 .39891 .2109 .40533 .20849 .40149 .20422 Mtetra
.668 .752 .913 r
.40149 .20422 .40533 .20849 .41178 .20591 .40794 .20174 Mtetra
.68 .761 .913 r
.40794 .20174 .41178 .20591 .41823 .20356 .41442 .19906 Mtetra
.654 .737 .91 r
.41442 .19906 .41823 .20356 .42469 .20134 .42089 .19678 Mtetra
.664 .737 .904 r
.42089 .19678 .42469 .20134 .43119 .19865 .42739 .19433 Mtetra
.662 .75 .915 r
.42739 .19433 .43119 .19865 .43768 .19652 .4339 .19192 Mtetra
.671 .739 .901 r
.4339 .19192 .43768 .19652 .4442 .19381 .44043 .18933 Mtetra
.648 .738 .915 r
.44043 .18933 .4442 .19381 .45073 .19157 .44696 .18713 Mtetra
.684 .752 .903 r
.44696 .18713 .45073 .19157 .45727 .18915 .45353 .18434 Mtetra
.648 .722 .902 r
.45353 .18434 .45727 .18915 .46384 .18644 .46009 .18212 Mtetra
.662 .752 .917 r
.46009 .18212 .46384 .18644 .47042 .18425 .46668 .17968 Mtetra
.678 .745 .901 r
.46668 .17968 .47042 .18425 .47701 .18163 .47329 .17695 Mtetra
.645 .728 .91 r
.47329 .17695 .47701 .18163 .48362 .17915 .47991 .17477 Mtetra
.678 .756 .91 r
.47991 .17477 .48362 .17915 .49025 .17683 .48655 .17205 Mtetra
.656 .729 .903 r
.48655 .17205 .49025 .17683 .49689 .17409 .4932 .16969 Mtetra
.668 .753 .914 r
.4932 .16969 .49689 .17409 .50355 .17189 .49987 .16712 Mtetra
.66 .731 .903 r
.49987 .16712 .50355 .17189 .51023 .16912 .50656 .16467 Mtetra
.676 .754 .91 r
.50656 .16467 .51023 .16912 .51692 .1668 .51326 .16197 Mtetra
.648 .725 .905 r
.51326 .16197 .51692 .1668 .52363 .16427 .51998 .1597 Mtetra
.669 .747 .909 r
.51998 .1597 .52363 .16427 .53035 .16162 .52671 .15708 Mtetra
.672 .751 .91 r
.52671 .15708 .53035 .16162 .53709 .15936 .53346 .15442 Mtetra
.649 .722 .902 r
.53346 .15442 .53709 .15936 .54385 .15681 .54023 .15212 Mtetra
.665 .741 .907 r
.54023 .15212 .54385 .15681 .55062 .15409 .54702 .14955 Mtetra
.669 .751 .912 r
.54702 .14955 .55062 .15409 .55741 .15147 .55382 .14692 Mtetra
.667 .75 .912 r
.55382 .14692 .55741 .15147 .56422 .14891 .56064 .1443 Mtetra
.666 .748 .911 r
.56064 .1443 .56422 .14891 .57104 .14636 .56747 .14171 Mtetra
.667 .747 .91 r
.56747 .14171 .57104 .14636 .57788 .14383 .57432 .13909 Mtetra
.669 .743 .906 r
.57432 .13909 .57788 .14383 .58474 .14122 .58119 .13643 Mtetra
.661 .738 .907 r
.58119 .13643 .58474 .14122 .59161 .13863 .58808 .13389 Mtetra
.666 .743 .908 r
.58808 .13389 .59161 .13863 .59851 .13606 .59498 .13126 Mtetra
.661 .739 .907 r
.59498 .13126 .59851 .13606 .60542 .1335 .6019 .12871 Mtetra
.664 .741 .908 r
.6019 .12871 .60542 .1335 .61234 .13086 .60884 .1261 Mtetra
.666 .744 .909 r
.60884 .1261 .61234 .13086 .61928 .12828 .61579 .12346 Mtetra
.664 .741 .907 r
.61579 .12346 .61928 .12828 .62624 .12567 .62276 .12085 Mtetra
.663 .741 .908 r
.62276 .12085 .62624 .12567 .63322 .12306 .62975 .11824 Mtetra
.62975 .11824 .63322 .12306 .64021 .12044 .63676 .11563 Mtetra
.664 .743 .909 r
.63676 .11563 .64021 .12044 .64723 .11783 .64378 .11299 Mtetra
.665 .743 .908 r
.64378 .11299 .64723 .11783 .65426 .11521 .65082 .11033 Mtetra
.663 .74 .907 r
.65082 .11033 .65426 .11521 .6613 .11257 .65788 .10769 Mtetra
.663 .741 .908 r
.65788 .10769 .6613 .11257 .66837 .10993 .66496 .10505 Mtetra
.664 .742 .908 r
.66496 .10505 .66837 .10993 .67545 .10729 .67205 .10238 Mtetra
.662 .741 .908 r
.67205 .10238 .67545 .10729 .68255 .10463 .67917 .09974 Mtetra
.665 .743 .908 r
.67917 .09974 .68255 .10463 .68967 .10199 .6863 .09705 Mtetra
.661 .74 .908 r
.6863 .09705 .68967 .10199 .69681 .09931 .69345 .09441 Mtetra
.665 .744 .909 r
.69345 .09441 .69681 .09931 .70396 .09668 .70061 .0917 Mtetra
.663 .74 .907 r
.70061 .0917 .70396 .09668 .71113 .09396 .7078 .08903 Mtetra
.663 .743 .909 r
.7078 .08903 .71113 .09396 .71833 .09132 .715 .08634 Mtetra
.666 .743 .907 r
.715 .08634 .71833 .09132 .72553 .08862 .72222 .08359 Mtetra
.662 .739 .907 r
.72222 .08359 .72553 .08862 .73276 .08587 .72946 .08091 Mtetra
.665 .744 .909 r
.72946 .08091 .73276 .08587 .74001 .08319 .73672 .07817 Mtetra
.658 .739 .91 r
.09347 .31353 .09773 .31752 .10347 .31542 .0992 .31145 Mtetra
.665 .742 .908 r
.0992 .31145 .10347 .31542 .10922 .31323 .10497 .30927 Mtetra
.666 .744 .908 r
.10497 .30927 .10922 .31323 .11498 .31111 .11074 .30707 Mtetra
.663 .739 .907 r
.11074 .30707 .11498 .31111 .12077 .3089 .11653 .30491 Mtetra
.665 .743 .908 r
.11653 .30491 .12077 .3089 .12655 .30676 .12233 .3027 Mtetra
.662 .739 .907 r
.12233 .3027 .12655 .30676 .13236 .30457 .12814 .30054 Mtetra
.665 .742 .907 r
.12814 .30054 .13236 .30457 .13818 .30239 .13396 .29833 Mtetra
.662 .74 .907 r
.13396 .29833 .13818 .30239 .14401 .3002 .1398 .29616 Mtetra
.664 .742 .908 r
.1398 .29616 .14401 .3002 .14985 .29802 .14565 .29395 Mtetra
.663 .741 .907 r
.14565 .29395 .14985 .29802 .15571 .29581 .15152 .29175 Mtetra
.663 .741 .909 r
.15152 .29175 .15571 .29581 .16158 .29363 .15739 .28956 Mtetra
.666 .742 .907 r
.15739 .28956 .16158 .29363 .16747 .2914 .16329 .28731 Mtetra
.662 .741 .908 r
.16329 .28731 .16747 .2914 .17336 .28921 .16919 .28511 Mtetra
.663 .741 .908 r
.16919 .28511 .17336 .28921 .17927 .28701 .17511 .28289 Mtetra
.664 .741 .907 r
.17511 .28289 .17927 .28701 .1852 .28477 .18105 .28065 Mtetra
.663 .741 .908 r
.18105 .28065 .1852 .28477 .19114 .28253 .18699 .27843 Mtetra
.662 .741 .909 r
.18699 .27843 .19114 .28253 .19709 .28032 .19295 .27621 Mtetra
.664 .743 .909 r
.19295 .27621 .19709 .28032 .20305 .27812 .19892 .27396 Mtetra
.665 .741 .906 r
.19892 .27396 .20305 .27812 .20903 .27586 .20491 .27168 Mtetra
.661 .739 .908 r
.20491 .27168 .20903 .27586 .21503 .2736 .21091 .26946 Mtetra
.665 .743 .908 r
.21091 .26946 .21503 .2736 .22103 .27138 .21693 .26718 Mtetra
.66 .738 .908 r
.21693 .26718 .22103 .27138 .22706 .2691 .22296 .26496 Mtetra
.667 .744 .908 r
.22296 .26496 .22706 .2691 .23309 .26689 .229 .26264 Mtetra
.661 .737 .907 r
.229 .26264 .23309 .26689 .23913 .26469 .23506 .26041 Mtetra
.658 .735 .907 r
.23506 .26041 .23913 .26469 .24519 .26245 .24112 .25821 Mtetra
.66 .738 .908 r
.24112 .25821 .24519 .26245 .25127 .26023 .2472 .25597 Mtetra
.664 .739 .906 r
.2472 .25597 .25127 .26023 .25735 .25803 .25331 .25367 Mtetra
.671 .737 .899 r
.25331 .25367 .25735 .25803 .26345 .25579 .25943 .25124 Mtetra
.649 .721 .901 r
.25943 .25124 .26345 .25579 .26959 .25333 .26554 .24914 Mtetra
.653 .741 .915 r
.26554 .24914 .26959 .25333 .27572 .25104 .27167 .247 Mtetra
.68 .757 .909 r
.27167 .247 .27572 .25104 .28186 .2489 .27785 .24443 Mtetra
.661 .73 .9 r
.27785 .24443 .28186 .2489 .28804 .24639 .28402 .24213 Mtetra
.653 .739 .913 r
.28402 .24213 .28804 .24639 .29421 .24412 .2902 .23997 Mtetra
.68 .753 .906 r
.2902 .23997 .29421 .24412 .3004 .24193 .29642 .23738 Mtetra
.644 .722 .905 r
.29642 .23738 .3004 .24193 .30661 .23951 .30261 .23533 Mtetra
.68 .753 .906 r
.30261 .23533 .30661 .23951 .31283 .2372 .30886 .23273 Mtetra
.646 .728 .908 r
.30886 .23273 .31283 .2372 .31906 .23494 .31509 .23065 Mtetra
.668 .744 .908 r
.31509 .23065 .31906 .23494 .32533 .23235 .32135 .22823 Mtetra
.675 .756 .912 r
.32135 .22823 .32533 .23235 .33158 .23029 .32764 .22571 Mtetra
.645 .723 .905 r
.32764 .22571 .33158 .23029 .33787 .2278 .33391 .22363 Mtetra
.679 .756 .909 r
.33391 .22363 .33787 .2278 .34416 .22542 .34023 .22103 Mtetra
.657 .738 .91 r
.34023 .22103 .34416 .22542 .35046 .22328 .34655 .21876 Mtetra
.655 .731 .905 r
.34655 .21876 .35046 .22328 .35681 .2206 .35287 .2165 Mtetra
.686 .764 .91 r
.35287 .2165 .35681 .2206 .36313 .21852 .35924 .21376 Mtetra
.638 .714 .903 r
.35924 .21376 .36313 .21852 .3695 .21593 .36559 .21176 Mtetra
.688 .761 .907 r
.36559 .21176 .3695 .21593 .37586 .21375 .37199 .20898 Mtetra
.638 .715 .903 r
.37199 .20898 .37586 .21375 .38226 .21107 .37836 .20696 Mtetra
.668 .759 .919 r
.37836 .20696 .38226 .21107 .38865 .20898 .38478 .2045 Mtetra
.679 .745 .9 r
.38478 .2045 .38865 .20898 .39506 .20661 .39122 .20182 Mtetra
.661 .724 .896 r
.39122 .20182 .39506 .20661 .40149 .20422 .39766 .19942 Mtetra
.65 .72 .899 r
.39766 .19942 .40149 .20422 .40794 .20174 .40411 .1972 Mtetra
.659 .736 .907 r
.40411 .1972 .40794 .20174 .41442 .19906 .41058 .19484 Mtetra
.682 .761 .911 r
.41058 .19484 .41442 .19906 .42089 .19678 .41708 .19212 Mtetra
.648 .728 .907 r
.41708 .19212 .42089 .19678 .42739 .19433 .42357 .18991 Mtetra
.679 .751 .905 r
.42357 .18991 .42739 .19433 .4339 .19192 .4301 .18721 Mtetra
.645 .725 .907 r
.4301 .18721 .4339 .19192 .44043 .18933 .43663 .18504 Mtetra
.681 .759 .911 r
.43663 .18504 .44043 .18933 .44696 .18713 .44319 .18231 Mtetra
.654 .724 .9 r
.44319 .18231 .44696 .18713 .45353 .18434 .44975 .17998 Mtetra
.657 .749 .917 r
.44975 .17998 .45353 .18434 .46009 .18212 .45633 .17761 Mtetra
.683 .75 .903 r
.45633 .17761 .46009 .18212 .46668 .17968 .46294 .17481 Mtetra
.644 .719 .903 r
.46294 .17481 .46668 .17968 .47329 .17695 .46955 .17263 Mtetra
.67 .757 .916 r
.46955 .17263 .47329 .17695 .47991 .17477 .47618 .17005 Mtetra
.668 .736 .901 r
.47618 .17005 .47991 .17477 .48655 .17205 .48283 .16746 Mtetra
.656 .739 .911 r
.48283 .16746 .48655 .17205 .4932 .16969 .48949 .16508 Mtetra
.671 .744 .905 r
.48949 .16508 .4932 .16969 .49987 .16712 .49617 .16244 Mtetra
.655 .735 .909 r
.49617 .16244 .49987 .16712 .50656 .16467 .50287 .16007 Mtetra
.67 .746 .907 r
.50287 .16007 .50656 .16467 .51326 .16197 .50958 .15744 Mtetra
.673 .751 .91 r
.50958 .15744 .51326 .16197 .51998 .1597 .51631 .15477 Mtetra
.643 .72 .904 r
.51631 .15477 .51998 .1597 .52671 .15708 .52306 .15256 Mtetra
.67 .751 .911 r
.52306 .15256 .52671 .15708 .53346 .15442 .52982 .14992 Mtetra
.679 .756 .909 r
.52982 .14992 .53346 .15442 .54023 .15212 .5366 .14711 Mtetra
.656 .723 .898 r
.5366 .14711 .54023 .15212 .54702 .14955 .54339 .14467 Mtetra
.661 .732 .902 r
.54339 .14467 .54702 .14955 .55382 .14692 .55021 .14215 Mtetra
.666 .74 .905 r
.55021 .14215 .55382 .14692 .56064 .1443 .55704 .13954 Mtetra
.668 .741 .905 r
.55704 .13954 .56064 .1443 .56747 .14171 .56388 .13689 Mtetra
.668 .739 .904 r
.56388 .13689 .56747 .14171 .57432 .13909 .57074 .13424 Mtetra
.66 .735 .905 r
.57074 .13424 .57432 .13909 .58119 .13643 .57762 .13171 Mtetra
.665 .744 .909 r
.57762 .13171 .58119 .13643 .58808 .13389 .58452 .12909 Mtetra
.663 .74 .907 r
.58452 .12909 .58808 .13389 .59498 .13126 .59143 .1265 Mtetra
.666 .744 .908 r
.59143 .1265 .59498 .13126 .6019 .12871 .59836 .12385 Mtetra
.66 .737 .907 r
.59836 .12385 .6019 .12871 .60884 .1261 .60531 .1213 Mtetra
.664 .742 .908 r
.60531 .1213 .60884 .1261 .61579 .12346 .61228 .11867 Mtetra
.666 .744 .909 r
.61228 .11867 .61579 .12346 .62276 .12085 .61926 .11602 Mtetra
.663 .742 .908 r
.61926 .11602 .62276 .12085 .62975 .11824 .62626 .11339 Mtetra
.662 .741 .908 r
.62626 .11339 .62975 .11824 .63676 .11563 .63328 .11077 Mtetra
.663 .742 .908 r
.63328 .11077 .63676 .11563 .64378 .11299 .64032 .10813 Mtetra
.666 .743 .908 r
.64032 .10813 .64378 .11299 .65082 .11033 .64737 .10544 Mtetra
.662 .741 .908 r
.64737 .10544 .65082 .11033 .65788 .10769 .65444 .10281 Mtetra
.663 .742 .909 r
.65444 .10281 .65788 .10769 .66496 .10505 .66153 .10016 Mtetra
.665 .743 .908 r
.66153 .10016 .66496 .10505 .67205 .10238 .66864 .09745 Mtetra
.661 .74 .908 r
.66864 .09745 .67205 .10238 .67917 .09974 .67577 .09482 Mtetra
.666 .743 .907 r
.67577 .09482 .67917 .09974 .6863 .09705 .68291 .09209 Mtetra
.66 .739 .908 r
.68291 .09209 .6863 .09705 .69345 .09441 .69007 .08945 Mtetra
.666 .743 .907 r
.69007 .08945 .69345 .09441 .70061 .0917 .69725 .08671 Mtetra
.66 .739 .908 r
.69725 .08671 .70061 .0917 .7078 .08903 .70445 .08406 Mtetra
.667 .743 .908 r
.70445 .08406 .7078 .08903 .715 .08634 .71166 .0813 Mtetra
.66 .737 .907 r
.71166 .0813 .715 .08634 .72222 .08359 .7189 .07864 Mtetra
.666 .746 .91 r
.7189 .07864 .72222 .08359 .72946 .08091 .72615 .07587 Mtetra
.665 .741 .907 r
.72615 .07587 .72946 .08091 .73672 .07817 .73342 .07312 Mtetra
.664 .742 .908 r
.08918 .30956 .09347 .31353 .0992 .31145 .09494 .30738 Mtetra
.658 .736 .907 r
.09494 .30738 .0992 .31145 .10497 .30927 .10069 .30529 Mtetra
.668 .744 .907 r
.10069 .30529 .10497 .30927 .11074 .30707 .10648 .30304 Mtetra
.663 .74 .907 r
.10648 .30304 .11074 .30707 .11653 .30491 .11227 .30087 Mtetra
.665 .741 .907 r
.11227 .30087 .11653 .30491 .12233 .3027 .11808 .29866 Mtetra
.663 .741 .908 r
.11808 .29866 .12233 .3027 .12814 .30054 .1239 .29647 Mtetra
.663 .74 .907 r
.1239 .29647 .12814 .30054 .13396 .29833 .12973 .29428 Mtetra
.664 .741 .908 r
.12973 .29428 .13396 .29833 .1398 .29616 .13558 .29207 Mtetra
.663 .74 .907 r
.13558 .29207 .1398 .29616 .14565 .29395 .14144 .28987 Mtetra
.663 .741 .908 r
.14144 .28987 .14565 .29395 .15152 .29175 .14731 .28766 Mtetra
.14731 .28766 .15152 .29175 .15739 .28956 .15319 .28544 Mtetra
.664 .74 .907 r
.15319 .28544 .15739 .28956 .16329 .28731 .15909 .28321 Mtetra
.664 .741 .908 r
.15909 .28321 .16329 .28731 .16919 .28511 .16501 .28098 Mtetra
.663 .74 .907 r
.16501 .28098 .16919 .28511 .17511 .28289 .17093 .27875 Mtetra
.664 .74 .907 r
.17093 .27875 .17511 .28289 .18105 .28065 .17688 .27651 Mtetra
.663 .74 .908 r
.17688 .27651 .18105 .28065 .18699 .27843 .18283 .27428 Mtetra
.664 .741 .908 r
.18283 .27428 .18699 .27843 .19295 .27621 .1888 .27203 Mtetra
.663 .739 .907 r
.1888 .27203 .19295 .27621 .19892 .27396 .19478 .26978 Mtetra
.661 .74 .908 r
.19478 .26978 .19892 .27396 .20491 .27168 .20077 .26756 Mtetra
.666 .744 .909 r
.20077 .26756 .20491 .27168 .21091 .26946 .20678 .26526 Mtetra
.662 .739 .907 r
.20678 .26526 .21091 .26946 .21693 .26718 .2128 .26301 Mtetra
.664 .742 .909 r
.2128 .26301 .21693 .26718 .22296 .26496 .21884 .26073 Mtetra
.659 .738 .908 r
.21884 .26073 .22296 .26496 .229 .26264 .22489 .25851 Mtetra
.663 .745 .911 r
.22489 .25851 .229 .26264 .23506 .26041 .23095 .25624 Mtetra
.664 .744 .909 r
.23095 .25624 .23506 .26041 .24112 .25821 .23703 .25394 Mtetra
.662 .738 .907 r
.23703 .25394 .24112 .25821 .2472 .25597 .24313 .25166 Mtetra
.658 .736 .907 r
.24313 .25166 .2472 .25597 .25331 .25367 .24923 .24945 Mtetra
.655 .74 .912 r
.24923 .24945 .25331 .25367 .25943 .25124 .25534 .24728 Mtetra
.664 .757 .92 r
.25534 .24728 .25943 .25124 .26554 .24914 .26148 .24498 Mtetra
.68 .751 .905 r
.26148 .24498 .26554 .24914 .27167 .247 .26765 .24239 Mtetra
.65 .72 .9 r
.26765 .24239 .27167 .247 .27785 .24443 .2738 .24027 Mtetra
.663 .748 .913 r
.2738 .24027 .27785 .24443 .28402 .24213 .27998 .23795 Mtetra
.679 .752 .906 r
.27998 .23795 .28402 .24213 .2902 .23997 .2862 .23537 Mtetra
.64 .718 .904 r
.2862 .23537 .2902 .23997 .29642 .23738 .29238 .23338 Mtetra
.686 .764 .911 r
.29238 .23338 .29642 .23738 .30261 .23533 .29863 .23069 Mtetra
.644 .719 .903 r
.29863 .23069 .30261 .23533 .30886 .23273 .30485 .22864 Mtetra
.683 .76 .91 r
.30485 .22864 .30886 .23273 .31509 .23065 .31112 .22598 Mtetra
.644 .719 .902 r
.31112 .22598 .31509 .23065 .32135 .22823 .31737 .22392 Mtetra
.668 .745 .908 r
.31737 .22392 .32135 .22823 .32764 .22571 .32366 .22149 Mtetra
.673 .752 .91 r
.32366 .22149 .32764 .22571 .33391 .22363 .32997 .21897 Mtetra
.646 .721 .903 r
.32997 .21897 .33391 .22363 .34023 .22103 .33627 .21685 Mtetra
.677 .757 .911 r
.33627 .21685 .34023 .22103 .34655 .21876 .34261 .21425 Mtetra
.659 .734 .906 r
.34261 .21425 .34655 .21876 .35287 .2165 .34895 .21193 Mtetra
.655 .73 .905 r
.34895 .21193 .35287 .2165 .35924 .21376 .3553 .20967 Mtetra
.681 .764 .913 r
.3553 .20967 .35924 .21376 .36559 .21176 .36169 .20699 Mtetra
.644 .717 .902 r
.36169 .20699 .36559 .21176 .37199 .20898 .36807 .20489 Mtetra
.675 .763 .917 r
.36807 .20489 .37199 .20898 .37836 .20696 .37448 .2023 Mtetra
.666 .732 .899 r
.37448 .2023 .37836 .20696 .38478 .2045 .3809 .19983 Mtetra
.647 .725 .906 r
.3809 .19983 .38478 .2045 .39122 .20182 .38733 .19766 Mtetra
.664 .758 .92 r
.38733 .19766 .39122 .20182 .39766 .19942 .39378 .19523 Mtetra
.679 .761 .914 r
.39378 .19523 .39766 .19942 .40411 .1972 .40026 .19257 Mtetra
.668 .736 .901 r
.40026 .19257 .40411 .1972 .41058 .19484 .40674 .19003 Mtetra
.645 .72 .903 r
.40674 .19003 .41058 .19484 .41708 .19212 .41323 .18787 Mtetra
.685 .762 .91 r
.41323 .18787 .41708 .19212 .42357 .18991 .41976 .18507 Mtetra
.641 .718 .903 r
.41976 .18507 .42357 .18991 .4301 .18721 .42627 .18296 Mtetra
.684 .763 .911 r
.42627 .18296 .4301 .18721 .43663 .18504 .43283 .18017 Mtetra
.649 .72 .901 r
.43283 .18017 .43663 .18504 .44319 .18231 .43938 .17792 Mtetra
.664 .751 .915 r
.43938 .17792 .44319 .18231 .44975 .17998 .44596 .17545 Mtetra
.678 .748 .904 r
.44596 .17545 .44975 .17998 .45633 .17761 .45256 .17273 Mtetra
.647 .72 .902 r
.45256 .17273 .45633 .17761 .46294 .17481 .45916 .1705 Mtetra
.672 .759 .916 r
.45916 .1705 .46294 .17481 .46955 .17263 .46579 .16788 Mtetra
.665 .735 .902 r
.46579 .16788 .46955 .17263 .47618 .17005 .47244 .16535 Mtetra
.655 .734 .907 r
.47244 .16535 .47618 .17005 .48283 .16746 .47909 .16297 Mtetra
.677 .753 .908 r
.47909 .16297 .48283 .16746 .48949 .16508 .48577 .16023 Mtetra
.645 .724 .906 r
.48577 .16023 .48949 .16508 .49617 .16244 .49246 .15801 Mtetra
.684 .76 .909 r
.49246 .15801 .49617 .16244 .50287 .16007 .49917 .15514 Mtetra
.651 .723 .902 r
.49917 .15514 .50287 .16007 .50958 .15744 .50589 .1528 Mtetra
.66 .742 .91 r
.50589 .1528 .50958 .15744 .51631 .15477 .51263 .15033 Mtetra
.682 .76 .91 r
.51263 .15033 .51631 .15477 .52306 .15256 .51939 .14748 Mtetra
.644 .715 .899 r
.51939 .14748 .52306 .15256 .52982 .14992 .52616 .14523 Mtetra
.661 .741 .909 r
.52616 .14523 .52982 .14992 .5366 .14711 .53295 .14271 Mtetra
.672 .761 .917 r
.53295 .14271 .5366 .14711 .54339 .14467 .53976 .14002 Mtetra
.67 .747 .908 r
.53976 .14002 .54339 .14467 .55021 .14215 .54658 .13734 Mtetra
.665 .739 .905 r
.54658 .13734 .55021 .14215 .55704 .13954 .55342 .13473 Mtetra
.663 .738 .906 r
.55342 .13473 .55704 .13954 .56388 .13689 .56028 .13215 Mtetra
.664 .743 .909 r
.56028 .13215 .56388 .13689 .57074 .13424 .56715 .12956 Mtetra
.667 .748 .91 r
.56715 .12956 .57074 .13424 .57762 .13171 .57404 .12691 Mtetra
.665 .741 .907 r
.57404 .12691 .57762 .13171 .58452 .12909 .58095 .12428 Mtetra
.663 .741 .908 r
.58095 .12428 .58452 .12909 .59143 .1265 .58787 .12168 Mtetra
.663 .74 .908 r
.58787 .12168 .59143 .1265 .59836 .12385 .59482 .11908 Mtetra
.667 .745 .909 r
.59482 .11908 .59836 .12385 .60531 .1213 .60178 .1164 Mtetra
.661 .737 .906 r
.60178 .1164 .60531 .1213 .61228 .11867 .60875 .11381 Mtetra
.664 .741 .907 r
.60875 .11381 .61228 .11867 .61926 .11602 .61575 .11117 Mtetra
.665 .742 .908 r
.61575 .11117 .61926 .11602 .62626 .11339 .62276 .10851 Mtetra
.663 .741 .908 r
.62276 .10851 .62626 .11339 .63328 .11077 .62979 .10586 Mtetra
.663 .74 .907 r
.62979 .10586 .63328 .11077 .64032 .10813 .63684 .10321 Mtetra
.664 .74 .907 r
.63684 .10321 .64032 .10813 .64737 .10544 .6439 .10053 Mtetra
.662 .74 .908 r
.6439 .10053 .64737 .10544 .65444 .10281 .65099 .09789 Mtetra
.663 .741 .908 r
.65099 .09789 .65444 .10281 .66153 .10016 .65809 .09522 Mtetra
.665 .742 .907 r
.65809 .09522 .66153 .10016 .66864 .09745 .66521 .09251 Mtetra
.662 .741 .908 r
.66521 .09251 .66864 .09745 .67577 .09482 .67235 .08984 Mtetra
.665 .741 .907 r
.67235 .08984 .67577 .09482 .68291 .09209 .6795 .08713 Mtetra
.662 .741 .909 r
.6795 .08713 .68291 .09209 .69007 .08945 .68668 .08444 Mtetra
.664 .74 .907 r
.68668 .08444 .69007 .08945 .69725 .08671 .69387 .08172 Mtetra
.663 .742 .909 r
.69387 .08172 .69725 .08671 .70445 .08406 .70108 .07902 Mtetra
.663 .74 .907 r
.70108 .07902 .70445 .08406 .71166 .0813 .70831 .0763 Mtetra
.662 .742 .91 r
.70831 .0763 .71166 .0813 .7189 .07864 .71556 .07361 Mtetra
.667 .743 .907 r
.71556 .07361 .7189 .07864 .72615 .07587 .72282 .07081 Mtetra
.663 .74 .908 r
.72282 .07081 .72615 .07587 .73342 .07312 .7301 .06808 Mtetra
.658 .74 .91 r
.08488 .30555 .08918 .30956 .09494 .30738 .09063 .30345 Mtetra
.667 .746 .909 r
.09063 .30345 .09494 .30738 .10069 .30529 .09641 .30121 Mtetra
.664 .739 .906 r
.09641 .30121 .10069 .30529 .10648 .30304 .1022 .29901 Mtetra
.664 .742 .908 r
.1022 .29901 .10648 .30304 .11227 .30087 .108 .29681 Mtetra
.662 .74 .908 r
.108 .29681 .11227 .30087 .11808 .29866 .11381 .29463 Mtetra
.665 .743 .908 r
.11381 .29463 .11808 .29866 .1239 .29647 .11964 .29241 Mtetra
.662 .741 .908 r
.11964 .29241 .1239 .29647 .12973 .29428 .12548 .29022 Mtetra
.664 .742 .908 r
.12548 .29022 .12973 .29428 .13558 .29207 .13133 .288 Mtetra
.13133 .288 .13558 .29207 .14144 .28987 .1372 .28578 Mtetra
.663 .741 .908 r
.1372 .28578 .14144 .28987 .14731 .28766 .14308 .28357 Mtetra
.665 .742 .908 r
.14308 .28357 .14731 .28766 .15319 .28544 .14897 .28133 Mtetra
.663 .741 .908 r
.14897 .28133 .15319 .28544 .15909 .28321 .15488 .2791 Mtetra
.662 .741 .909 r
.15488 .2791 .15909 .28321 .16501 .28098 .1608 .27689 Mtetra
.664 .743 .909 r
.1608 .27689 .16501 .28098 .17093 .27875 .16673 .27465 Mtetra
.665 .743 .908 r
.16673 .27465 .17093 .27875 .17688 .27651 .17268 .27238 Mtetra
.664 .742 .908 r
.17268 .27238 .17688 .27651 .18283 .27428 .17865 .27011 Mtetra
.662 .74 .908 r
.17865 .27011 .18283 .27428 .1888 .27203 .18462 .26788 Mtetra
.662 .742 .909 r
.18462 .26788 .1888 .27203 .19478 .26978 .19061 .26564 Mtetra
.666 .744 .908 r
.19061 .26564 .19478 .26978 .20077 .26756 .19662 .26333 Mtetra
.661 .738 .907 r
.19662 .26333 .20077 .26756 .20678 .26526 .20263 .26109 Mtetra
.665 .743 .909 r
.20263 .26109 .20678 .26526 .2128 .26301 .20866 .25879 Mtetra
.662 .74 .908 r
.20866 .25879 .2128 .26301 .21884 .26073 .21471 .25654 Mtetra
.666 .743 .908 r
.21471 .25654 .21884 .26073 .22489 .25851 .22077 .25421 Mtetra
.66 .736 .906 r
.22077 .25421 .22489 .25851 .23095 .25624 .22684 .25197 Mtetra
.661 .739 .908 r
.22684 .25197 .23095 .25624 .23703 .25394 .23292 .24971 Mtetra
.661 .742 .91 r
.23292 .24971 .23703 .25394 .24313 .25166 .23902 .24745 Mtetra
.663 .743 .91 r
.23902 .24745 .24313 .25166 .24923 .24945 .24514 .24516 Mtetra
.666 .74 .906 r
.24514 .24516 .24923 .24945 .25534 .24728 .25127 .2428 Mtetra
.661 .73 .901 r
.25127 .2428 .25534 .24728 .26148 .24498 .25742 .24051 Mtetra
.651 .728 .905 r
.25742 .24051 .26148 .24498 .26765 .24239 .26356 .23837 Mtetra
.673 .758 .915 r
.26356 .23837 .26765 .24239 .2738 .24027 .26975 .2359 Mtetra
.67 .74 .903 r
.26975 .2359 .2738 .24027 .27998 .23795 .27595 .23345 Mtetra
.651 .728 .905 r
.27595 .23345 .27998 .23795 .2862 .23537 .28214 .2313 Mtetra
.675 .758 .913 r
.28214 .2313 .2862 .23537 .29238 .23338 .28837 .22878 Mtetra
.648 .723 .903 r
.28837 .22878 .29238 .23338 .29863 .23069 .29458 .22666 Mtetra
.683 .763 .912 r
.29458 .22666 .29863 .23069 .30485 .22864 .30085 .224 Mtetra
.644 .721 .904 r
.30085 .224 .30485 .22864 .31112 .22598 .3071 .22192 Mtetra
.676 .761 .915 r
.3071 .22192 .31112 .22598 .31737 .22392 .31339 .21937 Mtetra
.659 .731 .903 r
.31339 .21937 .31737 .22392 .32366 .22149 .31968 .21705 Mtetra
.656 .736 .909 r
.31968 .21705 .32366 .22149 .32997 .21897 .32598 .21478 Mtetra
.679 .756 .91 r
.32598 .21478 .32997 .21897 .33627 .21685 .33232 .21216 Mtetra
.65 .722 .902 r
.33232 .21216 .33627 .21685 .34261 .21425 .33864 .20997 Mtetra
.664 .749 .913 r
.33864 .20997 .34261 .21425 .34895 .21193 .345 .20756 Mtetra
.672 .747 .907 r
.345 .20756 .34895 .21193 .3553 .20967 .35137 .20502 Mtetra
.65 .726 .905 r
.35137 .20502 .3553 .20967 .36169 .20699 .35774 .20282 Mtetra
.679 .761 .913 r
.35774 .20282 .36169 .20699 .36807 .20489 .36416 .20016 Mtetra
.652 .724 .902 r
.36416 .20016 .36807 .20489 .37448 .2023 .37056 .19791 Mtetra
.662 .745 .912 r
.37056 .19791 .37448 .2023 .3809 .19983 .37699 .19551 Mtetra
.67 .752 .912 r
.37699 .19551 .3809 .19983 .38733 .19766 .38344 .19298 Mtetra
.662 .731 .901 r
.38344 .19298 .38733 .19766 .39378 .19523 .3899 .19055 Mtetra
.661 .731 .902 r
.3899 .19055 .39378 .19523 .40026 .19257 .39638 .18814 Mtetra
.66 .745 .913 r
.39638 .18814 .40026 .19257 .40674 .19003 .40287 .18575 Mtetra
.68 .759 .911 r
.40287 .18575 .40674 .19003 .41323 .18787 .40939 .18303 Mtetra
.643 .719 .903 r
.40939 .18303 .41323 .18787 .41976 .18507 .4159 .18088 Mtetra
.685 .767 .913 r
.4159 .18088 .41976 .18507 .42627 .18296 .42245 .17808 Mtetra
.642 .717 .902 r
.42245 .17808 .42627 .18296 .43283 .18017 .42899 .17593 Mtetra
.676 .762 .916 r
.42899 .17593 .43283 .18017 .43938 .17792 .43557 .17326 Mtetra
.666 .738 .904 r
.43557 .17326 .43938 .17792 .44596 .17545 .44216 .17073 Mtetra
.651 .731 .907 r
.44216 .17073 .44596 .17545 .45256 .17273 .44876 .16843 Mtetra
.68 .763 .914 r
.44876 .16843 .45256 .17273 .45916 .1705 .45538 .16568 Mtetra
.653 .727 .903 r
.45538 .16568 .45916 .1705 .46579 .16788 .46202 .16333 Mtetra
.662 .745 .911 r
.46202 .16333 .46579 .16788 .47244 .16535 .46867 .16085 Mtetra
.678 .753 .908 r
.46867 .16085 .47244 .16535 .47909 .16297 .47534 .1581 Mtetra
.648 .724 .904 r
.47534 .1581 .47909 .16297 .48577 .16023 .48202 .15582 Mtetra
.68 .76 .911 r
.48202 .15582 .48577 .16023 .49246 .15801 .48873 .15303 Mtetra
.65 .721 .901 r
.48873 .15303 .49246 .15801 .49917 .15514 .49544 .1507 Mtetra
.673 .757 .914 r
.49544 .1507 .49917 .15514 .50589 .1528 .50218 .14801 Mtetra
.662 .736 .905 r
.50218 .14801 .50589 .1528 .51263 .15033 .50893 .14548 Mtetra
.653 .73 .906 r
.50893 .14548 .51263 .15033 .51939 .14748 .5157 .1431 Mtetra
.673 .762 .918 r
.5157 .1431 .51939 .14748 .52616 .14523 .52248 .1404 Mtetra
.67 .738 .902 r
.52248 .1404 .52616 .14523 .53295 .14271 .52928 .13772 Mtetra
.659 .727 .9 r
.52928 .13772 .53295 .14271 .53976 .14002 .5361 .13521 Mtetra
.664 .739 .905 r
.5361 .13521 .53976 .14002 .54658 .13734 .54293 .13261 Mtetra
.666 .744 .908 r
.54293 .13261 .54658 .13734 .55342 .13473 .54978 .12998 Mtetra
.54978 .12998 .55342 .13473 .56028 .13215 .55665 .12734 Mtetra
.667 .741 .906 r
.55665 .12734 .56028 .13215 .56715 .12956 .56354 .12469 Mtetra
.662 .737 .905 r
.56354 .12469 .56715 .12956 .57404 .12691 .57044 .1221 Mtetra
.664 .742 .908 r
.57044 .1221 .57404 .12691 .58095 .12428 .57736 .11947 Mtetra
.57736 .11947 .58095 .12428 .58787 .12168 .5843 .11685 Mtetra
.5843 .11685 .58787 .12168 .59482 .11908 .59125 .1142 Mtetra
.661 .739 .908 r
.59125 .1142 .59482 .11908 .60178 .1164 .59822 .1116 Mtetra
.666 .745 .909 r
.59822 .1116 .60178 .1164 .60875 .11381 .60521 .10892 Mtetra
.664 .741 .907 r
.60521 .10892 .60875 .11381 .61575 .11117 .61222 .10626 Mtetra
.663 .74 .907 r
.61222 .10626 .61575 .11117 .62276 .10851 .61924 .10361 Mtetra
.663 .741 .908 r
.61924 .10361 .62276 .10851 .62979 .10586 .62629 .10096 Mtetra
.664 .742 .908 r
.62629 .10096 .62979 .10586 .63684 .10321 .63335 .09829 Mtetra
.63335 .09829 .63684 .10321 .6439 .10053 .64042 .09561 Mtetra
.64042 .09561 .6439 .10053 .65099 .09789 .64752 .09292 Mtetra
.663 .74 .907 r
.64752 .09292 .65099 .09789 .65809 .09522 .65463 .09024 Mtetra
.664 .74 .907 r
.65463 .09024 .65809 .09522 .66521 .09251 .66176 .08754 Mtetra
.664 .741 .908 r
.66176 .08754 .66521 .09251 .67235 .08984 .66891 .08483 Mtetra
.663 .74 .907 r
.66891 .08483 .67235 .08984 .6795 .08713 .67608 .08213 Mtetra
.663 .741 .908 r
.67608 .08213 .6795 .08713 .68668 .08444 .68327 .07941 Mtetra
.663 .74 .907 r
.68327 .07941 .68668 .08444 .69387 .08172 .69047 .07669 Mtetra
.664 .741 .907 r
.69047 .07669 .69387 .08172 .70108 .07902 .69769 .07395 Mtetra
.661 .738 .908 r
.69769 .07395 .70108 .07902 .70831 .0763 .70494 .07127 Mtetra
.666 .743 .908 r
.70494 .07127 .70831 .0763 .71556 .07361 .7122 .06849 Mtetra
.66 .737 .907 r
.7122 .06849 .71556 .07361 .72282 .07081 .71948 .0658 Mtetra
.668 .746 .909 r
.71948 .0658 .72282 .07081 .7301 .06808 .72677 .06297 Mtetra
.656 .739 .911 r
.08056 .30152 .08488 .30555 .09063 .30345 .08631 .29944 Mtetra
.669 .744 .906 r
.08631 .29944 .09063 .30345 .09641 .30121 .09211 .29716 Mtetra
.664 .741 .907 r
.09211 .29716 .09641 .30121 .1022 .29901 .0979 .29496 Mtetra
.663 .741 .908 r
.0979 .29496 .1022 .29901 .108 .29681 .10371 .29276 Mtetra
.661 .741 .909 r
.10371 .29276 .108 .29681 .11381 .29463 .10952 .29059 Mtetra
.666 .743 .908 r
.10952 .29059 .11381 .29463 .11964 .29241 .11536 .28834 Mtetra
.661 .741 .909 r
.11536 .28834 .11964 .29241 .12548 .29022 .12121 .28616 Mtetra
.665 .743 .908 r
.12121 .28616 .12548 .29022 .13133 .288 .12707 .28392 Mtetra
.664 .742 .908 r
.12707 .28392 .13133 .288 .1372 .28578 .13295 .28168 Mtetra
.662 .741 .909 r
.13295 .28168 .1372 .28578 .14308 .28357 .13883 .27948 Mtetra
.665 .743 .908 r
.13883 .27948 .14308 .28357 .14897 .28133 .14473 .27722 Mtetra
.664 .742 .908 r
.14473 .27722 .14897 .28133 .15488 .2791 .15065 .27496 Mtetra
.663 .741 .908 r
.15065 .27496 .15488 .2791 .1608 .27689 .15658 .27273 Mtetra
.664 .741 .907 r
.15658 .27273 .1608 .27689 .16673 .27465 .16252 .27047 Mtetra
.664 .74 .907 r
.16252 .27047 .16673 .27465 .17268 .27238 .16848 .2682 Mtetra
.663 .741 .908 r
.16848 .2682 .17268 .27238 .17865 .27011 .17445 .26595 Mtetra
.663 .742 .908 r
.17445 .26595 .17865 .27011 .18462 .26788 .18043 .26369 Mtetra
.664 .741 .907 r
.18043 .26369 .18462 .26788 .19061 .26564 .18643 .2614 Mtetra
.66 .738 .908 r
.18643 .2614 .19061 .26564 .19662 .26333 .19244 .25918 Mtetra
.666 .745 .909 r
.19244 .25918 .19662 .26333 .20263 .26109 .19847 .25685 Mtetra
.661 .739 .908 r
.19847 .25685 .20263 .26109 .20866 .25879 .2045 .2546 Mtetra
.665 .743 .908 r
.2045 .2546 .20866 .25879 .21471 .25654 .21056 .25228 Mtetra
.662 .74 .908 r
.21056 .25228 .21471 .25654 .22077 .25421 .21662 .25 Mtetra
.661 .742 .91 r
.21662 .25 .22077 .25421 .22684 .25197 .2227 .24774 Mtetra
.662 .742 .909 r
.2227 .24774 .22684 .25197 .23292 .24971 .2288 .24545 Mtetra
.662 .741 .909 r
.2288 .24545 .23292 .24971 .23902 .24745 .23491 .24316 Mtetra
.66 .739 .909 r
.23491 .24316 .23902 .24745 .24514 .24516 .24103 .2409 Mtetra
.66 .742 .91 r
.24103 .2409 .24514 .24516 .25127 .2428 .24716 .23863 Mtetra
.668 .749 .911 r
.24716 .23863 .25127 .2428 .25742 .24051 .25332 .23624 Mtetra
.668 .744 .907 r
.25332 .23624 .25742 .24051 .26356 .23837 .2595 .23384 Mtetra
.654 .727 .903 r
.2595 .23384 .26356 .23837 .26975 .2359 .26567 .23163 Mtetra
.669 .746 .908 r
.26567 .23163 .26975 .2359 .27595 .23345 .27187 .22919 Mtetra
.27187 .22919 .27595 .23345 .28214 .2313 .27809 .22675 Mtetra
.65 .726 .905 r
.27809 .22675 .28214 .2313 .28837 .22878 .2843 .2246 Mtetra
.675 .753 .91 r
.2843 .2246 .28837 .22878 .29458 .22666 .29056 .22206 Mtetra
.652 .726 .903 r
.29056 .22206 .29458 .22666 .30085 .224 .29681 .21986 Mtetra
.678 .757 .911 r
.29681 .21986 .30085 .224 .3071 .22192 .30309 .21727 Mtetra
.648 .722 .903 r
.30309 .21727 .3071 .22192 .31339 .21937 .30936 .21512 Mtetra
.666 .75 .913 r
.30936 .21512 .31339 .21937 .31968 .21705 .31567 .21271 Mtetra
.673 .748 .907 r
.31567 .21271 .31968 .21705 .32598 .21478 .322 .21016 Mtetra
.647 .726 .906 r
.322 .21016 .32598 .21478 .33232 .21216 .32831 .20802 Mtetra
.676 .76 .914 r
.32831 .20802 .33232 .21216 .33864 .20997 .33467 .20543 Mtetra
.663 .736 .904 r
.33467 .20543 .33864 .20997 .345 .20756 .34103 .20302 Mtetra
.652 .733 .909 r
.34103 .20302 .345 .20756 .35137 .20502 .3474 .20079 Mtetra
.68 .758 .91 r
.3474 .20079 .35137 .20502 .35774 .20282 .35381 .19811 Mtetra
.649 .724 .904 r
.35381 .19811 .35774 .20282 .36416 .20016 .3602 .19591 Mtetra
.675 .756 .912 r
.3602 .19591 .36416 .20016 .37056 .19791 .36664 .1933 Mtetra
.661 .734 .904 r
.36664 .1933 .37056 .19791 .37699 .19551 .37308 .1909 Mtetra
.654 .732 .907 r
.37308 .1909 .37699 .19551 .38344 .19298 .37952 .1886 Mtetra
.667 .749 .912 r
.37952 .1886 .38344 .19298 .3899 .19055 .386 .18611 Mtetra
.667 .747 .91 r
.386 .18611 .3899 .19055 .39638 .18814 .39249 .18359 Mtetra
.671 .743 .904 r
.39249 .18359 .39638 .18814 .40287 .18575 .39899 .181 Mtetra
.65 .726 .905 r
.39899 .181 .40287 .18575 .40939 .18303 .4055 .17874 Mtetra
.68 .76 .912 r
.4055 .17874 .40939 .18303 .4159 .18088 .41205 .17601 Mtetra
.645 .72 .902 r
.41205 .17601 .4159 .18088 .42245 .17808 .41859 .17382 Mtetra
.679 .763 .914 r
.41859 .17382 .42245 .17808 .42899 .17593 .42516 .17109 Mtetra
.655 .726 .901 r
.42516 .17109 .42899 .17593 .43557 .17326 .43174 .16873 Mtetra
.661 .744 .912 r
.43174 .16873 .43557 .17326 .44216 .17073 .43833 .16627 Mtetra
.678 .754 .908 r
.43833 .16627 .44216 .17073 .44876 .16843 .44495 .16352 Mtetra
.648 .722 .902 r
.44495 .16352 .44876 .16843 .45538 .16568 .45158 .16125 Mtetra
.671 .754 .913 r
.45158 .16125 .45538 .16568 .46202 .16333 .45823 .15862 Mtetra
.667 .739 .904 r
.45823 .15862 .46202 .16333 .46867 .16085 .46489 .15602 Mtetra
.657 .731 .903 r
.46489 .15602 .46867 .16085 .47534 .1581 .47157 .15359 Mtetra
.671 .752 .911 r
.47157 .15359 .47534 .1581 .48202 .15582 .47827 .15093 Mtetra
.654 .727 .903 r
.47827 .15093 .48202 .15582 .48873 .15303 .48498 .14854 Mtetra
.676 .756 .911 r
.48498 .14854 .48873 .15303 .49544 .1507 .49171 .1458 Mtetra
.66 .73 .902 r
.49171 .1458 .49544 .1507 .50218 .14801 .49845 .1433 Mtetra
.656 .739 .91 r
.49845 .1433 .50218 .14801 .50893 .14548 .50521 .14085 Mtetra
.673 .75 .908 r
.50521 .14085 .50893 .14548 .5157 .1431 .51199 .13813 Mtetra
.658 .728 .901 r
.51199 .13813 .5157 .1431 .52248 .1404 .51879 .13562 Mtetra
.66 .739 .908 r
.51879 .13562 .52248 .1404 .52928 .13772 .5256 .13311 Mtetra
.666 .75 .913 r
.5256 .13311 .52928 .13772 .5361 .13521 .53243 .13048 Mtetra
.668 .745 .908 r
.53243 .13048 .5361 .13521 .54293 .13261 .53927 .12782 Mtetra
.666 .742 .907 r
.53927 .12782 .54293 .13261 .54978 .12998 .54613 .12518 Mtetra
.665 .741 .907 r
.54613 .12518 .54978 .12998 .55665 .12734 .55301 .12255 Mtetra
.666 .743 .908 r
.55301 .12255 .55665 .12734 .56354 .12469 .55991 .1199 Mtetra
.665 .744 .909 r
.55991 .1199 .56354 .12469 .57044 .1221 .56682 .11725 Mtetra
.662 .74 .908 r
.56682 .11725 .57044 .1221 .57736 .11947 .57376 .11464 Mtetra
.666 .743 .908 r
.57376 .11464 .57736 .11947 .5843 .11685 .5807 .11198 Mtetra
.662 .74 .908 r
.5807 .11198 .5843 .11685 .59125 .1142 .58767 .10937 Mtetra
.666 .744 .908 r
.58767 .10937 .59125 .1142 .59822 .1116 .59465 .10668 Mtetra
.662 .738 .907 r
.59465 .10668 .59822 .1116 .60521 .10892 .60165 .10405 Mtetra
.665 .743 .908 r
.60165 .10405 .60521 .10892 .61222 .10626 .60867 .10137 Mtetra
.664 .742 .908 r
.60867 .10137 .61222 .10626 .61924 .10361 .61571 .09869 Mtetra
.662 .741 .908 r
.61571 .09869 .61924 .10361 .62629 .10096 .62276 .09604 Mtetra
.663 .742 .908 r
.62276 .09604 .62629 .10096 .63335 .09829 .62984 .09337 Mtetra
.665 .743 .908 r
.62984 .09337 .63335 .09829 .64042 .09561 .63692 .09066 Mtetra
.664 .742 .908 r
.63692 .09066 .64042 .09561 .64752 .09292 .64403 .08796 Mtetra
.662 .741 .909 r
.64403 .08796 .64752 .09292 .65463 .09024 .65116 .08528 Mtetra
.664 .743 .909 r
.65116 .08528 .65463 .09024 .66176 .08754 .6583 .08256 Mtetra
.664 .743 .908 r
.6583 .08256 .66176 .08754 .66891 .08483 .66546 .07983 Mtetra
.662 .741 .909 r
.66546 .07983 .66891 .08483 .67608 .08213 .67265 .07714 Mtetra
.665 .743 .909 r
.67265 .07714 .67608 .08213 .68327 .07941 .67984 .07438 Mtetra
.664 .742 .908 r
.67984 .07438 .68327 .07941 .69047 .07669 .68706 .07165 Mtetra
.68706 .07165 .69047 .07669 .69769 .07395 .69429 .0689 Mtetra
.662 .741 .908 r
.69429 .0689 .69769 .07395 .70494 .07127 .70155 .06617 Mtetra
.662 .739 .907 r
.70155 .06617 .70494 .07127 .7122 .06849 .70882 .06344 Mtetra
.663 .743 .91 r
.70882 .06344 .7122 .06849 .71948 .0658 .71612 .06069 Mtetra
.666 .742 .907 r
.71612 .06069 .71948 .0658 .72677 .06297 .72342 .05787 Mtetra
.663 .742 .909 r
.07622 .29749 .08056 .30152 .08631 .29944 .08199 .29531 Mtetra
.662 .737 .905 r
.08199 .29531 .08631 .29944 .09211 .29716 .08778 .29312 Mtetra
.666 .743 .908 r
.08778 .29312 .09211 .29716 .0979 .29496 .09359 .29089 Mtetra
.66 .74 .909 r
.09359 .29089 .0979 .29496 .10371 .29276 .09939 .28872 Mtetra
.664 .744 .909 r
.09939 .28872 .10371 .29276 .10952 .29059 .10522 .2865 Mtetra
.665 .742 .907 r
.10522 .2865 .10952 .29059 .11536 .28834 .11107 .28425 Mtetra
.662 .741 .909 r
.11107 .28425 .11536 .28834 .12121 .28616 .11692 .28205 Mtetra
.665 .742 .907 r
.11692 .28205 .12121 .28616 .12707 .28392 .12279 .27979 Mtetra
.664 .741 .907 r
.12279 .27979 .12707 .28392 .13295 .28168 .12867 .27755 Mtetra
.663 .741 .908 r
.12867 .27755 .13295 .28168 .13883 .27948 .13457 .27532 Mtetra
.664 .74 .907 r
.13457 .27532 .13883 .27948 .14473 .27722 .14048 .27306 Mtetra
.664 .741 .907 r
.14048 .27306 .14473 .27722 .15065 .27496 .1464 .27081 Mtetra
.663 .741 .908 r
.1464 .27081 .15065 .27496 .15658 .27273 .15234 .26856 Mtetra
.15234 .26856 .15658 .27273 .16252 .27047 .15829 .26631 Mtetra
.664 .742 .908 r
.15829 .26631 .16252 .27047 .16848 .2682 .16425 .26404 Mtetra
.665 .743 .908 r
.16425 .26404 .16848 .2682 .17445 .26595 .17023 .26175 Mtetra
.663 .741 .908 r
.17023 .26175 .17445 .26595 .18043 .26369 .17622 .25948 Mtetra
.662 .741 .908 r
.17622 .25948 .18043 .26369 .18643 .2614 .18222 .25722 Mtetra
.665 .743 .908 r
.18222 .25722 .18643 .2614 .19244 .25918 .18825 .25491 Mtetra
.66 .738 .908 r
.18825 .25491 .19244 .25918 .19847 .25685 .19427 .25267 Mtetra
.666 .745 .909 r
.19427 .25267 .19847 .25685 .2045 .2546 .20033 .25033 Mtetra
.661 .739 .908 r
.20033 .25033 .2045 .2546 .21056 .25228 .20639 .24806 Mtetra
.662 .742 .91 r
.20639 .24806 .21056 .25228 .21662 .25 .21246 .24578 Mtetra
.665 .743 .909 r
.21246 .24578 .21662 .25 .2227 .24774 .21855 .24344 Mtetra
.662 .739 .907 r
.21855 .24344 .2227 .24774 .2288 .24545 .22466 .24114 Mtetra
.22466 .24114 .2288 .24545 .23491 .24316 .23077 .23884 Mtetra
.23077 .23884 .23491 .24316 .24103 .2409 .2369 .23653 Mtetra
.661 .737 .906 r
.2369 .23653 .24103 .2409 .24716 .23863 .24305 .23423 Mtetra
.657 .735 .907 r
.24305 .23423 .24716 .23863 .25332 .23624 .2492 .23199 Mtetra
.669 .747 .909 r
.2492 .23199 .25332 .23624 .2595 .23384 .25539 .22956 Mtetra
.664 .744 .91 r
.25539 .22956 .2595 .23384 .26567 .23163 .26158 .2272 Mtetra
.661 .736 .905 r
.26158 .2272 .26567 .23163 .27187 .22919 .26779 .22487 Mtetra
.669 .745 .907 r
.26779 .22487 .27187 .22919 .27809 .22675 .27401 .22242 Mtetra
.663 .743 .909 r
.27401 .22242 .27809 .22675 .2843 .2246 .28025 .22006 Mtetra
.657 .731 .904 r
.28025 .22006 .2843 .2246 .29056 .22206 .28649 .21779 Mtetra
.669 .749 .91 r
.28649 .21779 .29056 .22206 .29681 .21986 .29277 .21532 Mtetra
.66 .733 .903 r
.29277 .21532 .29681 .21986 .30309 .21727 .29904 .21297 Mtetra
.664 .747 .912 r
.29904 .21297 .30309 .21727 .30936 .21512 .30534 .21059 Mtetra
.666 .736 .902 r
.30534 .21059 .30936 .21512 .31567 .21271 .31166 .20814 Mtetra
.655 .731 .906 r
.31166 .20814 .31567 .21271 .322 .21016 .31797 .20587 Mtetra
.674 .751 .909 r
.31797 .20587 .322 .21016 .32831 .20802 .32432 .2033 Mtetra
.657 .726 .9 r
.32432 .2033 .32831 .20802 .33467 .20543 .33067 .20098 Mtetra
.66 .741 .91 r
.33067 .20098 .33467 .20543 .34103 .20302 .33704 .19862 Mtetra
.671 .747 .908 r
.33704 .19862 .34103 .20302 .3474 .20079 .34344 .19608 Mtetra
.654 .727 .902 r
.34344 .19608 .3474 .20079 .35381 .19811 .34983 .19378 Mtetra
.671 .752 .911 r
.34983 .19378 .35381 .19811 .3602 .19591 .35626 .19122 Mtetra
.656 .729 .903 r
.35626 .19122 .3602 .19591 .36664 .1933 .36269 .18889 Mtetra
.667 .748 .91 r
.36269 .18889 .36664 .1933 .37308 .1909 .36914 .18639 Mtetra
.664 .742 .908 r
.36914 .18639 .37308 .1909 .37952 .1886 .3756 .18391 Mtetra
.662 .733 .902 r
.3756 .18391 .37952 .1886 .386 .18611 .38208 .18146 Mtetra
.663 .736 .904 r
.38208 .18146 .386 .18611 .39249 .18359 .38858 .179 Mtetra
.662 .739 .907 r
.38858 .179 .39249 .18359 .39899 .181 .39509 .17654 Mtetra
.668 .748 .91 r
.39509 .17654 .39899 .181 .4055 .17874 .40162 .17399 Mtetra
.661 .732 .902 r
.40162 .17399 .4055 .17874 .41205 .17601 .40816 .17153 Mtetra
.668 .748 .91 r
.40816 .17153 .41205 .17601 .41859 .17382 .41473 .16897 Mtetra
.655 .726 .901 r
.41473 .16897 .41859 .17382 .42516 .17109 .4213 .16659 Mtetra
.671 .749 .91 r
.4213 .16659 .42516 .17109 .43174 .16873 .42789 .16398 Mtetra
.661 .734 .904 r
.42789 .16398 .43174 .16873 .43833 .16627 .4345 .16149 Mtetra
.659 .732 .904 r
.4345 .16149 .43833 .16627 .44495 .16352 .44112 .15904 Mtetra
.671 .752 .911 r
.44112 .15904 .44495 .16352 .45158 .16125 .44777 .1564 Mtetra
.655 .729 .903 r
.44777 .1564 .45158 .16125 .45823 .15862 .45442 .154 Mtetra
.672 .747 .907 r
.45442 .154 .45823 .15862 .46489 .15602 .46109 .15133 Mtetra
.661 .739 .908 r
.46109 .15133 .46489 .15602 .47157 .15359 .46778 .14883 Mtetra
.664 .738 .905 r
.46778 .14883 .47157 .15359 .47827 .15093 .47449 .14627 Mtetra
.665 .744 .909 r
.47449 .14627 .47827 .15093 .48498 .14854 .48121 .1437 Mtetra
.666 .735 .902 r
.48121 .1437 .48498 .14854 .49171 .1458 .48795 .14109 Mtetra
.658 .74 .91 r
.48795 .14109 .49171 .1458 .49845 .1433 .49471 .13861 Mtetra
.666 .745 .909 r
.49471 .13861 .49845 .1433 .50521 .14085 .50148 .13599 Mtetra
.664 .736 .903 r
.50148 .13599 .50521 .14085 .51199 .13813 .50827 .13339 Mtetra
.656 .739 .911 r
.50827 .13339 .51199 .13813 .51879 .13562 .51507 .13094 Mtetra
.669 .747 .909 r
.51507 .13094 .51879 .13562 .5256 .13311 .5219 .12826 Mtetra
.667 .74 .904 r
.5219 .12826 .5256 .13311 .53243 .13048 .52874 .1256 Mtetra
.665 .738 .904 r
.52874 .1256 .53243 .13048 .53927 .12782 .53559 .12297 Mtetra
.665 .74 .906 r
.53559 .12297 .53927 .12782 .54613 .12518 .54247 .12033 Mtetra
.54247 .12033 .54613 .12518 .55301 .12255 .54936 .11769 Mtetra
.662 .739 .907 r
.54936 .11769 .55301 .12255 .55991 .1199 .55627 .11508 Mtetra
.665 .743 .908 r
.55627 .11508 .55991 .1199 .56682 .11725 .56319 .11243 Mtetra
.666 .744 .908 r
.56319 .11243 .56682 .11725 .57376 .11464 .57013 .10975 Mtetra
.661 .739 .908 r
.57013 .10975 .57376 .11464 .5807 .11198 .57709 .10714 Mtetra
.667 .745 .909 r
.57709 .10714 .5807 .11198 .58767 .10937 .58407 .10443 Mtetra
.661 .738 .907 r
.58407 .10443 .58767 .10937 .59465 .10668 .59107 .10181 Mtetra
.666 .744 .909 r
.59107 .10181 .59465 .10668 .60165 .10405 .59808 .09911 Mtetra
.663 .74 .907 r
.59808 .09911 .60165 .10405 .60867 .10137 .60511 .09643 Mtetra
.663 .741 .908 r
.60511 .09643 .60867 .10137 .61571 .09869 .61216 .09376 Mtetra
.664 .742 .908 r
.61216 .09376 .61571 .09869 .62276 .09604 .61922 .09107 Mtetra
.664 .741 .907 r
.61922 .09107 .62276 .09604 .62984 .09337 .62631 .08837 Mtetra
.663 .739 .907 r
.62631 .08837 .62984 .09337 .63692 .09066 .63341 .08567 Mtetra
.663 .74 .908 r
.63341 .08567 .63692 .09066 .64403 .08796 .64053 .08297 Mtetra
.662 .741 .909 r
.64053 .08297 .64403 .08796 .65116 .08528 .64767 .08028 Mtetra
.664 .742 .908 r
.64767 .08028 .65116 .08528 .6583 .08256 .65482 .07755 Mtetra
.65482 .07755 .6583 .08256 .66546 .07983 .662 .0748 Mtetra
.661 .74 .909 r
.662 .0748 .66546 .07983 .67265 .07714 .66919 .07211 Mtetra
.665 .743 .908 r
.66919 .07211 .67265 .07714 .67984 .07438 .6764 .06935 Mtetra
.665 .743 .909 r
.6764 .06935 .67984 .07438 .68706 .07165 .68363 .06659 Mtetra
.663 .741 .909 r
.68363 .06659 .68706 .07165 .69429 .0689 .69088 .06385 Mtetra
.666 .744 .908 r
.69088 .06385 .69429 .0689 .70155 .06617 .69815 .06105 Mtetra
.659 .738 .908 r
.69815 .06105 .70155 .06617 .70882 .06344 .70544 .05836 Mtetra
.667 .744 .908 r
.70544 .05836 .70882 .06344 .71612 .06069 .71274 .05552 Mtetra
.663 .739 .906 r
.71274 .05552 .71612 .06069 .72342 .05787 .72006 .05275 Mtetra
.656 .739 .911 r
.07187 .29342 .07622 .29749 .08199 .29531 .07763 .29133 Mtetra
.67 .748 .909 r
.07763 .29133 .08199 .29531 .08778 .29312 .08344 .28902 Mtetra
.662 .74 .907 r
.08344 .28902 .08778 .29312 .09359 .29089 .08925 .28683 Mtetra
.66 .742 .91 r
.08925 .28683 .09359 .29089 .09939 .28872 .09506 .28465 Mtetra
.668 .744 .907 r
.09506 .28465 .09939 .28872 .10522 .2865 .10091 .28237 Mtetra
.664 .74 .907 r
.10091 .28237 .10522 .2865 .11107 .28425 .10676 .28013 Mtetra
.664 .741 .908 r
.10676 .28013 .11107 .28425 .11692 .28205 .11262 .27789 Mtetra
.664 .739 .906 r
.11262 .27789 .11692 .28205 .12279 .27979 .1185 .27565 Mtetra
.663 .74 .908 r
.1185 .27565 .12279 .27979 .12867 .27755 .12438 .27341 Mtetra
.663 .741 .908 r
.12438 .27341 .12867 .27755 .13457 .27532 .13028 .27117 Mtetra
.664 .742 .908 r
.13028 .27117 .13457 .27532 .14048 .27306 .1362 .26891 Mtetra
.1362 .26891 .14048 .27306 .1464 .27081 .14213 .26664 Mtetra
.662 .741 .909 r
.14213 .26664 .1464 .27081 .15234 .26856 .14808 .26439 Mtetra
.664 .742 .908 r
.14808 .26439 .15234 .26856 .15829 .26631 .15403 .26212 Mtetra
.665 .741 .907 r
.15403 .26212 .15829 .26631 .16425 .26404 .16001 .25982 Mtetra
.663 .74 .907 r
.16001 .25982 .16425 .26404 .17023 .26175 .16599 .25755 Mtetra
.663 .741 .908 r
.16599 .25755 .17023 .26175 .17622 .25948 .17199 .25526 Mtetra
.17199 .25526 .17622 .25948 .18222 .25722 .17801 .25297 Mtetra
.662 .74 .908 r
.17801 .25297 .18222 .25722 .18825 .25491 .18403 .2507 Mtetra
.665 .743 .909 r
.18403 .2507 .18825 .25491 .19427 .25267 .19008 .24838 Mtetra
.661 .738 .907 r
.19008 .24838 .19427 .25267 .20033 .25033 .19613 .2461 Mtetra
.662 .743 .91 r
.19613 .2461 .20033 .25033 .20639 .24806 .2022 .24382 Mtetra
.666 .744 .908 r
.2022 .24382 .20639 .24806 .21246 .24578 .20828 .24147 Mtetra
.665 .74 .906 r
.20828 .24147 .21246 .24578 .21855 .24344 .21439 .23911 Mtetra
.661 .738 .907 r
.21439 .23911 .21855 .24344 .22466 .24114 .22049 .23682 Mtetra
.662 .74 .908 r
.22049 .23682 .22466 .24114 .23077 .23884 .22662 .23451 Mtetra
.665 .741 .907 r
.22662 .23451 .23077 .23884 .2369 .23653 .23276 .23215 Mtetra
.66 .737 .907 r
.23276 .23215 .2369 .23653 .24305 .23423 .23892 .22986 Mtetra
.657 .737 .908 r
.23892 .22986 .24305 .23423 .2492 .23199 .24508 .2276 Mtetra
.24508 .2276 .2492 .23199 .25539 .22956 .25126 .22534 Mtetra
.676 .751 .908 r
.25126 .22534 .25539 .22956 .26158 .2272 .25747 .22278 Mtetra
.659 .737 .908 r
.25747 .22278 .26158 .2272 .26779 .22487 .26368 .22049 Mtetra
.663 .741 .907 r
.26368 .22049 .26779 .22487 .27401 .22242 .26991 .21811 Mtetra
.67 .747 .908 r
.26991 .21811 .27401 .22242 .28025 .22006 .27617 .21563 Mtetra
.655 .736 .91 r
.27617 .21563 .28025 .22006 .28649 .21779 .28242 .21337 Mtetra
.67 .743 .905 r
.28242 .21337 .28649 .21779 .29277 .21532 .2887 .21088 Mtetra
.66 .739 .908 r
.2887 .21088 .29277 .21532 .29904 .21297 .29499 .20854 Mtetra
.668 .742 .906 r
.29499 .20854 .29904 .21297 .30534 .21059 .3013 .20606 Mtetra
.655 .734 .908 r
.3013 .20606 .30534 .21059 .31166 .20814 .30761 .20379 Mtetra
.669 .748 .909 r
.30761 .20379 .31166 .20814 .31797 .20587 .31395 .20129 Mtetra
.666 .736 .902 r
.31395 .20129 .31797 .20587 .32432 .2033 .3203 .19883 Mtetra
.656 .739 .91 r
.3203 .19883 .32432 .2033 .33067 .20098 .32666 .19652 Mtetra
.666 .743 .907 r
.32666 .19652 .33067 .20098 .33704 .19862 .33305 .19404 Mtetra
.667 .738 .903 r
.33305 .19404 .33704 .19862 .34344 .19608 .33945 .19154 Mtetra
.657 .738 .909 r
.33945 .19154 .34344 .19608 .34983 .19378 .34585 .1892 Mtetra
.668 .739 .903 r
.34585 .1892 .34983 .19378 .35626 .19122 .35229 .18666 Mtetra
.649 .735 .912 r
.35229 .18666 .35626 .19122 .36269 .18889 .35872 .18443 Mtetra
.668 .746 .909 r
.35872 .18443 .36269 .18889 .36914 .18639 .36518 .1819 Mtetra
.67 .747 .908 r
.36518 .1819 .36914 .18639 .3756 .18391 .37166 .17933 Mtetra
.662 .739 .907 r
.37166 .17933 .3756 .18391 .38208 .18146 .37815 .17688 Mtetra
.66 .74 .909 r
.37815 .17688 .38208 .18146 .38858 .179 .38465 .17445 Mtetra
.658 .741 .911 r
.38465 .17445 .38858 .179 .39509 .17654 .39117 .17205 Mtetra
.672 .749 .908 r
.39117 .17205 .39509 .17654 .40162 .17399 .39771 .16942 Mtetra
.66 .741 .91 r
.39771 .16942 .40162 .17399 .40816 .17153 .40426 .16698 Mtetra
.675 .748 .906 r
.40426 .16698 .40816 .17153 .41473 .16897 .41084 .16429 Mtetra
.657 .736 .908 r
.41084 .16429 .41473 .16897 .4213 .16659 .41742 .16188 Mtetra
.66 .736 .906 r
.41742 .16188 .4213 .16659 .42789 .16398 .42402 .15942 Mtetra
.673 .749 .908 r
.42402 .15942 .42789 .16398 .4345 .16149 .43065 .15675 Mtetra
.659 .735 .906 r
.43065 .15675 .4345 .16149 .44112 .15904 .43728 .15429 Mtetra
.661 .736 .905 r
.43728 .15429 .44112 .15904 .44777 .1564 .44393 .15178 Mtetra
.668 .746 .909 r
.44393 .15178 .44777 .1564 .45442 .154 .4506 .14917 Mtetra
.661 .734 .903 r
.4506 .14917 .45442 .154 .46109 .15133 .45728 .14666 Mtetra
.665 .743 .909 r
.45728 .14666 .46109 .15133 .46778 .14883 .46398 .14409 Mtetra
.659 .738 .908 r
.46398 .14409 .46778 .14883 .47449 .14627 .47069 .14161 Mtetra
.67 .747 .908 r
.47069 .14161 .47449 .14627 .48121 .1437 .47743 .13893 Mtetra
.661 .739 .908 r
.47743 .13893 .48121 .1437 .48795 .14109 .48418 .1364 Mtetra
.662 .744 .911 r
.48418 .1364 .48795 .14109 .49471 .13861 .49094 .13385 Mtetra
.671 .744 .905 r
.49094 .13385 .49471 .13861 .50148 .13599 .49773 .13113 Mtetra
.649 .732 .909 r
.49773 .13113 .50148 .13599 .50827 .13339 .50453 .12877 Mtetra
.668 .751 .913 r
.50453 .12877 .50827 .13339 .51507 .13094 .51134 .12611 Mtetra
.669 .742 .905 r
.51134 .12611 .51507 .13094 .5219 .12826 .51818 .1234 Mtetra
.668 .74 .904 r
.51818 .1234 .5219 .12826 .52874 .1256 .52503 .12071 Mtetra
.661 .737 .906 r
.52503 .12071 .52874 .1256 .53559 .12297 .5319 .11812 Mtetra
.665 .741 .907 r
.5319 .11812 .53559 .12297 .54247 .12033 .53878 .11547 Mtetra
.666 .742 .906 r
.53878 .11547 .54247 .12033 .54936 .11769 .54568 .11279 Mtetra
.662 .739 .907 r
.54568 .11279 .54936 .11769 .55627 .11508 .5526 .11018 Mtetra
.661 .739 .907 r
.5526 .11018 .55627 .11508 .56319 .11243 .55954 .10757 Mtetra
.664 .742 .908 r
.55954 .10757 .56319 .11243 .57013 .10975 .5665 .10491 Mtetra
.667 .745 .909 r
.5665 .10491 .57013 .10975 .57709 .10714 .57347 .10219 Mtetra
.661 .738 .907 r
.57347 .10219 .57709 .10714 .58407 .10443 .58046 .09956 Mtetra
.666 .744 .909 r
.58046 .09956 .58407 .10443 .59107 .10181 .58746 .09685 Mtetra
.664 .74 .907 r
.58746 .09685 .59107 .10181 .59808 .09911 .59449 .09416 Mtetra
.664 .741 .908 r
.59449 .09416 .59808 .09911 .60511 .09643 .60153 .09147 Mtetra
.663 .741 .908 r
.60153 .09147 .60511 .09643 .61216 .09376 .60859 .0888 Mtetra
.662 .741 .908 r
.60859 .0888 .61216 .09376 .61922 .09107 .61567 .08612 Mtetra
.664 .743 .909 r
.61567 .08612 .61922 .09107 .62631 .08837 .62276 .08341 Mtetra
.665 .744 .909 r
.62276 .08341 .62631 .08837 .63341 .08567 .62988 .08067 Mtetra
.664 .742 .908 r
.62988 .08067 .63341 .08567 .64053 .08297 .63701 .07794 Mtetra
.663 .74 .907 r
.63701 .07794 .64053 .08297 .64767 .08028 .64416 .07522 Mtetra
.64416 .07522 .64767 .08028 .65482 .07755 .65133 .07249 Mtetra
.664 .74 .907 r
.65133 .07249 .65482 .07755 .662 .0748 .65852 .06974 Mtetra
.662 .74 .908 r
.65852 .06974 .662 .0748 .66919 .07211 .66572 .06702 Mtetra
.663 .74 .907 r
.66572 .06702 .66919 .07211 .6764 .06935 .67295 .06428 Mtetra
.666 .743 .908 r
.67295 .06428 .6764 .06935 .68363 .06659 .68019 .06149 Mtetra
.66 .739 .908 r
.68019 .06149 .68363 .06659 .69088 .06385 .68745 .05877 Mtetra
.666 .744 .908 r
.68745 .05877 .69088 .06385 .69815 .06105 .69473 .05596 Mtetra
.663 .742 .909 r
.69473 .05596 .69815 .06105 .70544 .05836 .70203 .05319 Mtetra
.658 .737 .908 r
.70203 .05319 .70544 .05836 .71274 .05552 .70935 .05049 Mtetra
.671 .75 .91 r
.70935 .05049 .71274 .05552 .72006 .05275 .71668 .04756 Mtetra
.654 .739 .912 r
.06749 .28935 .07187 .29342 .07763 .29133 .07326 .28728 Mtetra
.673 .745 .905 r
.07326 .28728 .07763 .29133 .08344 .28902 .07908 .28492 Mtetra
.657 .739 .91 r
.07908 .28492 .08344 .28902 .08925 .28683 .08488 .28279 Mtetra
.667 .746 .909 r
.08488 .28279 .08925 .28683 .09506 .28465 .09072 .28051 Mtetra
.667 .741 .905 r
.09072 .28051 .09506 .28465 .10091 .28237 .09657 .27823 Mtetra
.662 .74 .908 r
.09657 .27823 .10091 .28237 .10676 .28013 .10242 .27601 Mtetra
.663 .742 .908 r
.10242 .27601 .10676 .28013 .11262 .27789 .10829 .27377 Mtetra
.665 .743 .908 r
.10829 .27377 .11262 .27789 .1185 .27565 .11418 .2715 Mtetra
.661 .741 .909 r
.11418 .2715 .1185 .27565 .12438 .27341 .12007 .26928 Mtetra
.663 .743 .909 r
.12007 .26928 .12438 .27341 .13028 .27117 .12598 .26703 Mtetra
.665 .743 .908 r
.12598 .26703 .13028 .27117 .1362 .26891 .13191 .26474 Mtetra
.665 .742 .908 r
.13191 .26474 .1362 .26891 .14213 .26664 .13785 .26245 Mtetra
.663 .741 .908 r
.13785 .26245 .14213 .26664 .14808 .26439 .1438 .26017 Mtetra
.662 .74 .908 r
.1438 .26017 .14808 .26439 .15403 .26212 .14976 .25792 Mtetra
.663 .741 .909 r
.14976 .25792 .15403 .26212 .16001 .25982 .15574 .25565 Mtetra
.665 .744 .909 r
.15574 .25565 .16001 .25982 .16599 .25755 .16174 .25334 Mtetra
.665 .743 .908 r
.16174 .25334 .16599 .25755 .17199 .25526 .16775 .25101 Mtetra
.663 .741 .908 r
.16775 .25101 .17199 .25526 .17801 .25297 .17377 .24871 Mtetra
.662 .74 .908 r
.17377 .24871 .17801 .25297 .18403 .2507 .1798 .24643 Mtetra
.663 .74 .907 r
.1798 .24643 .18403 .2507 .19008 .24838 .18585 .24411 Mtetra
.661 .741 .909 r
.18585 .24411 .19008 .24838 .19613 .2461 .19191 .24184 Mtetra
.666 .743 .907 r
.19191 .24184 .19613 .2461 .2022 .24382 .198 .23947 Mtetra
.661 .737 .906 r
.198 .23947 .2022 .24382 .20828 .24147 .20409 .23718 Mtetra
.659 .74 .91 r
.20409 .23718 .20828 .24147 .21439 .23911 .21019 .23491 Mtetra
.661 .746 .913 r
.21019 .23491 .21439 .23911 .22049 .23682 .2163 .23262 Mtetra
.661 .747 .913 r
.2163 .23262 .22049 .23682 .22662 .23451 .22243 .23031 Mtetra
.662 .748 .914 r
.22243 .23031 .22662 .23451 .23276 .23215 .22858 .22799 Mtetra
.667 .751 .914 r
.22858 .22799 .23276 .23215 .23892 .22986 .23475 .22559 Mtetra
.674 .749 .907 r
.23475 .22559 .23892 .22986 .24508 .2276 .24095 .22307 Mtetra
.648 .728 .907 r
.24095 .22307 .24508 .2276 .25126 .22534 .24712 .22093 Mtetra
.658 .738 .909 r
.24712 .22093 .25126 .22534 .25747 .22278 .25332 .21865 Mtetra
.684 .76 .909 r
.25332 .21865 .25747 .22278 .26368 .22049 .25958 .21595 Mtetra
.649 .729 .907 r
.25958 .21595 .26368 .22049 .26991 .21811 .2658 .21378 Mtetra
.668 .746 .909 r
.2658 .21378 .26991 .21811 .27617 .21563 .27206 .21132 Mtetra
.663 .747 .912 r
.27206 .21132 .27617 .21563 .28242 .21337 .27833 .20893 Mtetra
.663 .74 .907 r
.27833 .20893 .28242 .21337 .2887 .21088 .28461 .20654 Mtetra
.662 .746 .912 r
.28461 .20654 .2887 .21088 .29499 .20854 .29091 .20416 Mtetra
.674 .748 .906 r
.29091 .20416 .29499 .20854 .3013 .20606 .29723 .20157 Mtetra
.654 .737 .91 r
.29723 .20157 .3013 .20606 .30761 .20379 .30355 .1993 Mtetra
.671 .742 .904 r
.30355 .1993 .30761 .20379 .31395 .20129 .30991 .19674 Mtetra
.658 .736 .907 r
.30991 .19674 .31395 .20129 .3203 .19883 .31626 .19439 Mtetra
.662 .743 .91 r
.31626 .19439 .3203 .19883 .32666 .19652 .32263 .19198 Mtetra
.671 .742 .903 r
.32263 .19198 .32666 .19652 .33305 .19404 .32903 .18941 Mtetra
.646 .729 .909 r
.32903 .18941 .33305 .19404 .33945 .19154 .33542 .18723 Mtetra
.67 .754 .914 r
.33542 .18723 .33945 .19154 .34585 .1892 .34185 .18469 Mtetra
.658 .741 .911 r
.34185 .18469 .34585 .1892 .35229 .18666 .34828 .18232 Mtetra
.668 .753 .914 r
.34828 .18232 .35229 .18666 .35872 .18443 .35474 .17979 Mtetra
.642 .73 .912 r
.35474 .17979 .35872 .18443 .36518 .1819 .36119 .17765 Mtetra
.676 .761 .915 r
.36119 .17765 .36518 .1819 .37166 .17933 .36768 .17498 Mtetra
.662 .753 .917 r
.36768 .17498 .37166 .17933 .37815 .17688 .37418 .17253 Mtetra
.657 .751 .919 r
.37418 .17253 .37815 .17688 .38465 .17445 .38069 .17015 Mtetra
.675 .76 .915 r
.38069 .17015 .38465 .17445 .39117 .17205 .38723 .16749 Mtetra
.671 .746 .907 r
.38723 .16749 .39117 .17205 .39771 .16942 .39379 .16486 Mtetra
.661 .744 .911 r
.39379 .16486 .39771 .16942 .40426 .16698 .40035 .16239 Mtetra
.666 .744 .908 r
.40035 .16239 .40426 .16698 .41084 .16429 .40693 .15983 Mtetra
.675 .755 .91 r
.40693 .15983 .41084 .16429 .41742 .16188 .41353 .15712 Mtetra
.656 .734 .906 r
.41353 .15712 .41742 .16188 .42402 .15942 .42014 .15471 Mtetra
.67 .741 .903 r
.42014 .15471 .42402 .15942 .43065 .15675 .42677 .15206 Mtetra
.659 .739 .909 r
.42677 .15206 .43065 .15675 .43728 .15429 .43342 .14959 Mtetra
.661 .74 .909 r
.43342 .14959 .43728 .15429 .44393 .15178 .44007 .1471 Mtetra
.675 .746 .904 r
.44007 .1471 .44393 .15178 .4506 .14917 .44676 .14435 Mtetra
.649 .73 .908 r
.44676 .14435 .4506 .14917 .45728 .14666 .45345 .14201 Mtetra
.671 .748 .908 r
.45345 .14201 .45728 .14666 .46398 .14409 .46016 .13932 Mtetra
.655 .736 .91 r
.46016 .13932 .46398 .14409 .47069 .14161 .46688 .13689 Mtetra
.671 .745 .906 r
.46688 .13689 .47069 .14161 .47743 .13893 .47363 .13418 Mtetra
.655 .738 .911 r
.47363 .13418 .47743 .13893 .48418 .1364 .48039 .13174 Mtetra
.677 .751 .907 r
.48039 .13174 .48418 .1364 .49094 .13385 .48717 .12894 Mtetra
.647 .729 .908 r
.48717 .12894 .49094 .13385 .49773 .13113 .49396 .1266 Mtetra
.665 .755 .917 r
.49396 .1266 .49773 .13113 .50453 .12877 .50077 .12399 Mtetra
.678 .747 .903 r
.50077 .12399 .50453 .12877 .51134 .12611 .5076 .12113 Mtetra
.657 .731 .904 r
.5076 .12113 .51134 .12611 .51818 .1234 .51444 .11862 Mtetra
.66 .742 .911 r
.51444 .11862 .51818 .1234 .52503 .12071 .52131 .11606 Mtetra
.665 .752 .915 r
.52131 .11606 .52503 .12071 .5319 .11812 .52819 .11341 Mtetra
.666 .749 .912 r
.52819 .11341 .5319 .11812 .53878 .11547 .53508 .11073 Mtetra
.667 .748 .911 r
.53508 .11073 .53878 .11547 .54568 .11279 .542 .10804 Mtetra
.668 .749 .911 r
.542 .10804 .54568 .11279 .5526 .11018 .54893 .10532 Mtetra
.668 .744 .908 r
.54893 .10532 .5526 .11018 .55954 .10757 .55587 .10259 Mtetra
.66 .736 .906 r
.55587 .10259 .55954 .10757 .5665 .10491 .56284 .09998 Mtetra
.665 .741 .907 r
.56284 .09998 .5665 .10491 .57347 .10219 .56982 .09729 Mtetra
.665 .743 .908 r
.56982 .09729 .57347 .10219 .58046 .09956 .57682 .09459 Mtetra
.665 .74 .906 r
.57682 .09459 .58046 .09956 .58746 .09685 .58384 .09189 Mtetra
.663 .74 .908 r
.58384 .09189 .58746 .09685 .59449 .09416 .59088 .0892 Mtetra
.662 .741 .908 r
.59088 .0892 .59449 .09416 .60153 .09147 .59793 .08653 Mtetra
.663 .743 .909 r
.59793 .08653 .60153 .09147 .60859 .0888 .60501 .08383 Mtetra
.665 .743 .908 r
.60501 .08383 .60859 .0888 .61567 .08612 .6121 .08109 Mtetra
.664 .74 .906 r
.6121 .08109 .61567 .08612 .62276 .08341 .6192 .07836 Mtetra
.663 .739 .906 r
.6192 .07836 .62276 .08341 .62988 .08067 .62633 .07563 Mtetra
.662 .74 .908 r
.62633 .07563 .62988 .08067 .63701 .07794 .63347 .07292 Mtetra
.662 .742 .909 r
.63347 .07292 .63701 .07794 .64416 .07522 .64064 .07021 Mtetra
.664 .743 .909 r
.64064 .07021 .64416 .07522 .65133 .07249 .64782 .06746 Mtetra
.665 .744 .909 r
.64782 .06746 .65133 .07249 .65852 .06974 .65502 .06467 Mtetra
.664 .742 .908 r
.65502 .06467 .65852 .06974 .66572 .06702 .66223 .0619 Mtetra
.663 .739 .907 r
.66223 .0619 .66572 .06702 .67295 .06428 .66947 .05914 Mtetra
.66947 .05914 .67295 .06428 .68019 .06149 .67673 .05638 Mtetra
.662 .741 .909 r
.67673 .05638 .68019 .06149 .68745 .05877 .684 .05362 Mtetra
.661 .739 .908 r
.684 .05362 .68745 .05877 .69473 .05596 .6913 .05087 Mtetra
.668 .746 .909 r
.6913 .05087 .69473 .05596 .70203 .05319 .6986 .048 Mtetra
.657 .737 .909 r
.6986 .048 .70203 .05319 .70935 .05049 .70594 .04531 Mtetra
.669 .743 .906 r
.70594 .04531 .70935 .05049 .71668 .04756 .71328 .04241 Mtetra
.662 .741 .909 r
.0631 .28527 .06749 .28935 .07326 .28728 .06889 .28307 Mtetra
.661 .735 .904 r
.06889 .28307 .07326 .28728 .07908 .28492 .07469 .28087 Mtetra
.662 .744 .911 r
.07469 .28087 .07908 .28492 .08488 .28279 .08051 .27867 Mtetra
.67 .742 .905 r
.08051 .27867 .08488 .28279 .09072 .28051 .08636 .27633 Mtetra
.661 .738 .907 r
.08636 .27633 .09072 .28051 .09657 .27823 .09221 .27413 Mtetra
.662 .743 .91 r
.09221 .27413 .09657 .27823 .10242 .27601 .09807 .27191 Mtetra
.667 .744 .908 r
.09807 .27191 .10242 .27601 .10829 .27377 .10395 .26961 Mtetra
.664 .741 .908 r
.10395 .26961 .10829 .27377 .11418 .2715 .10984 .26734 Mtetra
.663 .742 .908 r
.10984 .26734 .11418 .2715 .12007 .26928 .11575 .26508 Mtetra
.664 .74 .907 r
.11575 .26508 .12007 .26928 .12598 .26703 .12167 .2628 Mtetra
.664 .739 .906 r
.12167 .2628 .12598 .26703 .13191 .26474 .1276 .26052 Mtetra
.663 .74 .907 r
.1276 .26052 .13191 .26474 .13785 .26245 .13354 .25824 Mtetra
.662 .741 .909 r
.13354 .25824 .13785 .26245 .1438 .26017 .1395 .25598 Mtetra
.664 .742 .909 r
.1395 .25598 .1438 .26017 .14976 .25792 .14548 .25369 Mtetra
.665 .741 .907 r
.14548 .25369 .14976 .25792 .15574 .25565 .15147 .25137 Mtetra
.661 .738 .907 r
.15147 .25137 .15574 .25565 .16174 .25334 .15746 .2491 Mtetra
.664 .742 .908 r
.15746 .2491 .16174 .25334 .16775 .25101 .16348 .24679 Mtetra
.666 .744 .908 r
.16348 .24679 .16775 .25101 .17377 .24871 .16951 .24445 Mtetra
.663 .741 .908 r
.16951 .24445 .17377 .24871 .1798 .24643 .17556 .24213 Mtetra
.662 .74 .908 r
.17556 .24213 .1798 .24643 .18585 .24411 .18161 .23984 Mtetra
.665 .742 .908 r
.18161 .23984 .18585 .24411 .19191 .24184 .18769 .23749 Mtetra
.661 .738 .907 r
.18769 .23749 .19191 .24184 .198 .23947 .19377 .23519 Mtetra
.66 .741 .91 r
.19377 .23519 .198 .23947 .20409 .23718 .19986 .23291 Mtetra
.662 .743 .91 r
.19986 .23291 .20409 .23718 .21019 .23491 .20598 .23059 Mtetra
.663 .741 .908 r
.20598 .23059 .21019 .23491 .2163 .23262 .21211 .22825 Mtetra
.661 .739 .908 r
.21211 .22825 .2163 .23262 .22243 .23031 .21825 .22593 Mtetra
.659 .738 .908 r
.21825 .22593 .22243 .23031 .22858 .22799 .2244 .22364 Mtetra
.658 .74 .91 r
.2244 .22364 .22858 .22799 .23475 .22559 .23057 .22136 Mtetra
.666 .749 .912 r
.23057 .22136 .23475 .22559 .24095 .22307 .23676 .21895 Mtetra
.682 .759 .91 r
.23676 .21895 .24095 .22307 .24712 .22093 .24299 .2163 Mtetra
.642 .722 .906 r
.24299 .2163 .24712 .22093 .25332 .21865 .24918 .21424 Mtetra
.662 .74 .908 r
.24918 .21424 .25332 .21865 .25958 .21595 .25541 .21186 Mtetra
.685 .764 .911 r
.25541 .21186 .25958 .21595 .2658 .21378 .26169 .20914 Mtetra
.641 .723 .908 r
.26169 .20914 .2658 .21378 .27206 .21132 .26792 .20708 Mtetra
.681 .756 .908 r
.26792 .20708 .27206 .21132 .27833 .20893 .27422 .2044 Mtetra
.641 .729 .912 r
.27422 .2044 .27833 .20893 .28461 .20654 .28049 .20233 Mtetra
.691 .761 .905 r
.28049 .20233 .28461 .20654 .29091 .20416 .28683 .19947 Mtetra
.64 .722 .908 r
.28683 .19947 .29091 .20416 .29723 .20157 .29313 .1974 Mtetra
.676 .761 .914 r
.29313 .1974 .29723 .20157 .30355 .1993 .29948 .19478 Mtetra
.66 .739 .908 r
.29948 .19478 .30355 .1993 .30991 .19674 .30583 .1924 Mtetra
.653 .746 .918 r
.30583 .1924 .30991 .19674 .31626 .19439 .31218 .19014 Mtetra
.683 .76 .91 r
.31218 .19014 .31626 .19439 .32263 .19198 .31859 .18739 Mtetra
.65 .733 .91 r
.31859 .18739 .32263 .19198 .32903 .18941 .32498 .18514 Mtetra
.662 .754 .918 r
.32498 .18514 .32903 .18941 .33542 .18723 .33139 .1827 Mtetra
.669 .744 .906 r
.33139 .1827 .33542 .18723 .34185 .18469 .33783 .18014 Mtetra
.641 .734 .916 r
.33783 .18014 .34185 .18469 .34828 .18232 .34425 .17803 Mtetra
.687 .762 .909 r
.34425 .17803 .34828 .18232 .35474 .17979 .35074 .17517 Mtetra
.659 .737 .908 r
.35074 .17517 .35474 .17979 .36119 .17765 .35721 .17276 Mtetra
.634 .716 .906 r
.35721 .17276 .36119 .17765 .36768 .17498 .36368 .17073 Mtetra
.664 .759 .921 r
.36368 .17073 .36768 .17498 .37418 .17253 .37019 .16825 Mtetra
.686 .765 .911 r
.37019 .16825 .37418 .17253 .38069 .17015 .37674 .16539 Mtetra
.68 .74 .896 r
.37674 .16539 .38069 .17015 .38723 .16749 .38329 .16257 Mtetra
.631 .715 .908 r
.38329 .16257 .38723 .16749 .39379 .16486 .38983 .16057 Mtetra
.696 .769 .908 r
.38983 .16057 .39379 .16486 .40035 .16239 .39643 .15753 Mtetra
.641 .723 .908 r
.39643 .15753 .40035 .16239 .40693 .15983 .403 .15536 Mtetra
.679 .756 .909 r
.403 .15536 .40693 .15983 .41353 .15712 .40962 .15258 Mtetra
.662 .747 .913 r
.40962 .15258 .41353 .15712 .42014 .15471 .41624 .15007 Mtetra
.654 .74 .913 r
.41624 .15007 .42014 .15471 .42677 .15206 .42287 .14769 Mtetra
.683 .765 .913 r
.42287 .14769 .42677 .15206 .43342 .14959 .42954 .14483 Mtetra
.653 .735 .909 r
.42954 .14483 .43342 .14959 .44007 .1471 .4362 .14244 Mtetra
.664 .745 .911 r
.4362 .14244 .44007 .1471 .44676 .14435 .44289 .13988 Mtetra
.672 .758 .915 r
.44289 .13988 .44676 .14435 .45345 .14201 .4496 .13719 Mtetra
.646 .731 .911 r
.4496 .13719 .45345 .14201 .46016 .13932 .45631 .1349 Mtetra
.689 .767 .911 r
.45631 .1349 .46016 .13932 .46688 .13689 .46306 .13191 Mtetra
.642 .723 .907 r
.46306 .13191 .46688 .13689 .47363 .13418 .46981 .12966 Mtetra
.68 .76 .912 r
.46981 .12966 .47363 .13418 .48039 .13174 .47658 .12681 Mtetra
.653 .73 .906 r
.47658 .12681 .48039 .13174 .48717 .12894 .48337 .12437 Mtetra
.658 .752 .919 r
.48337 .12437 .48717 .12894 .49396 .1266 .49017 .12186 Mtetra
.685 .752 .903 r
.49017 .12186 .49396 .1266 .50077 .12399 .497 .11888 Mtetra
.649 .722 .902 r
.497 .11888 .50077 .12399 .5076 .12113 .50383 .11649 Mtetra
.66 .75 .917 r
.50383 .11649 .5076 .12113 .51444 .11862 .51069 .11393 Mtetra
.668 .751 .913 r
.51069 .11393 .51444 .11862 .52131 .11606 .51756 .11123 Mtetra
.668 .745 .907 r
.51756 .11123 .52131 .11606 .52819 .11341 .52446 .1085 Mtetra
.666 .741 .906 r
.52446 .1085 .52819 .11341 .53508 .11073 .53136 .10581 Mtetra
.664 .74 .906 r
.53136 .10581 .53508 .11073 .542 .10804 .53829 .10313 Mtetra
.665 .741 .907 r
.53829 .10313 .542 .10804 .54893 .10532 .54523 .10045 Mtetra
.667 .745 .908 r
.54523 .10045 .54893 .10532 .55587 .10259 .55219 .09772 Mtetra
.667 .745 .909 r
.55219 .09772 .55587 .10259 .56284 .09998 .55917 .09498 Mtetra
.661 .737 .906 r
.55917 .09498 .56284 .09998 .56982 .09729 .56616 .09234 Mtetra
.666 .742 .907 r
.56616 .09234 .56982 .09729 .57682 .09459 .57317 .08961 Mtetra
.662 .74 .907 r
.57317 .08961 .57682 .09459 .58384 .09189 .58021 .08693 Mtetra
.662 .742 .909 r
.58021 .08693 .58384 .09189 .59088 .0892 .58725 .08425 Mtetra
.665 .743 .909 r
.58725 .08425 .59088 .0892 .59793 .08653 .59432 .08152 Mtetra
.664 .741 .907 r
.59432 .08152 .59793 .08653 .60501 .08383 .6014 .0788 Mtetra
.662 .739 .908 r
.6014 .0788 .60501 .08383 .6121 .08109 .60851 .0761 Mtetra
.664 .743 .909 r
.60851 .0761 .6121 .08109 .6192 .07836 .61563 .07336 Mtetra
.665 .744 .909 r
.61563 .07336 .6192 .07836 .62633 .07563 .62277 .0706 Mtetra
.664 .742 .908 r
.62277 .0706 .62633 .07563 .63347 .07292 .62992 .06784 Mtetra
.662 .74 .908 r
.62992 .06784 .63347 .07292 .64064 .07021 .6371 .06511 Mtetra
.6371 .06511 .64064 .07021 .64782 .06746 .64429 .06237 Mtetra
.664 .742 .908 r
.64429 .06237 .64782 .06746 .65502 .06467 .6515 .05959 Mtetra
.665 .743 .908 r
.6515 .05959 .65502 .06467 .66223 .0619 .65873 .05679 Mtetra
.662 .741 .909 r
.65873 .05679 .66223 .0619 .66947 .05914 .66598 .05404 Mtetra
.665 .743 .908 r
.66598 .05404 .66947 .05914 .67673 .05638 .67325 .05122 Mtetra
.663 .74 .908 r
.67325 .05122 .67673 .05638 .684 .05362 .68054 .04844 Mtetra
.66 .738 .908 r
.68054 .04844 .684 .05362 .6913 .05087 .68784 .04569 Mtetra
.666 .742 .907 r
.68784 .04569 .6913 .05087 .6986 .048 .69517 .04284 Mtetra
.661 .741 .909 r
.69517 .04284 .6986 .048 .70594 .04531 .70251 .04007 Mtetra
.666 .74 .905 r
.70251 .04007 .70594 .04531 .71328 .04241 .70987 .03719 Mtetra
.648 .737 .914 r
.05868 .28115 .0631 .28527 .06889 .28307 .06445 .27914 Mtetra
.675 .754 .911 r
.06445 .27914 .06889 .28307 .07469 .28087 .07029 .27675 Mtetra
.666 .742 .907 r
.07029 .27675 .07469 .28087 .08051 .27867 .07613 .27446 Mtetra
.663 .738 .905 r
.07613 .27446 .08051 .27867 .08636 .27633 .08198 .27221 Mtetra
.659 .742 .911 r
.08198 .27221 .08636 .27633 .09221 .27413 .08782 .27002 Mtetra
.667 .745 .908 r
.08782 .27002 .09221 .27413 .09807 .27191 .0937 .26771 Mtetra
.666 .741 .906 r
.0937 .26771 .09807 .27191 .10395 .26961 .09959 .26541 Mtetra
.662 .74 .908 r
.09959 .26541 .10395 .26961 .10984 .26734 .10549 .26316 Mtetra
.662 .741 .909 r
.10549 .26316 .10984 .26734 .11575 .26508 .1114 .26091 Mtetra
.663 .743 .909 r
.1114 .26091 .11575 .26508 .12167 .2628 .11732 .25863 Mtetra
.665 .744 .909 r
.11732 .25863 .12167 .2628 .1276 .26052 .12327 .25632 Mtetra
.665 .743 .908 r
.12327 .25632 .1276 .26052 .13354 .25824 .12922 .25401 Mtetra
.663 .741 .908 r
.12922 .25401 .13354 .25824 .1395 .25598 .13519 .25172 Mtetra
.661 .74 .908 r
.13519 .25172 .1395 .25598 .14548 .25369 .14117 .24946 Mtetra
.663 .742 .909 r
.14117 .24946 .14548 .25369 .15147 .25137 .14716 .24717 Mtetra
.666 .745 .909 r
.14716 .24717 .15147 .25137 .15746 .2491 .15317 .24481 Mtetra
.662 .74 .908 r
.15317 .24481 .15746 .2491 .16348 .24679 .1592 .24252 Mtetra
.663 .741 .908 r
.1592 .24252 .16348 .24679 .16951 .24445 .16523 .24019 Mtetra
.666 .744 .908 r
.16523 .24019 .16951 .24445 .17556 .24213 .17129 .23784 Mtetra
.662 .741 .908 r
.17129 .23784 .17556 .24213 .18161 .23984 .17735 .23552 Mtetra
.664 .741 .907 r
.17735 .23552 .18161 .23984 .18769 .23749 .18344 .23317 Mtetra
.661 .741 .909 r
.18344 .23317 .18769 .23749 .19377 .23519 .18953 .23086 Mtetra
.663 .741 .908 r
.18953 .23086 .19377 .23519 .19986 .23291 .19564 .22852 Mtetra
.664 .739 .906 r
.19564 .22852 .19986 .23291 .20598 .23059 .20176 .22615 Mtetra
.664 .737 .904 r
.20176 .22615 .20598 .23059 .21211 .22825 .2079 .22377 Mtetra
.663 .735 .903 r
.2079 .22377 .21211 .22825 .21825 .22593 .21405 .22141 Mtetra
.66 .732 .903 r
.21405 .22141 .21825 .22593 .2244 .22364 .22022 .21909 Mtetra
.655 .73 .904 r
.22022 .21909 .2244 .22364 .23057 .22136 .22639 .21682 Mtetra
.655 .732 .905 r
.22639 .21682 .23057 .22136 .23676 .21895 .23257 .21456 Mtetra
.665 .742 .908 r
.23257 .21456 .23676 .21895 .24299 .2163 .23879 .21214 Mtetra
.679 .759 .912 r
.23879 .21214 .24299 .2163 .24918 .21424 .24504 .20952 Mtetra
.644 .721 .904 r
.24504 .20952 .24918 .21424 .25541 .21186 .25125 .20741 Mtetra
.668 .741 .905 r
.25125 .20741 .25541 .21186 .26169 .20914 .25752 .20493 Mtetra
.672 .756 .913 r
.25752 .20493 .26169 .20914 .26792 .20708 .2638 .20239 Mtetra
.644 .723 .906 r
.2638 .20239 .26792 .20708 .27422 .2044 .27006 .20027 Mtetra
.683 .764 .913 r
.27006 .20027 .27422 .2044 .28049 .20233 .27639 .19755 Mtetra
.64 .719 .905 r
.27639 .19755 .28049 .20233 .28683 .19947 .28268 .19548 Mtetra
.672 .769 .924 r
.28268 .19548 .28683 .19947 .29313 .1974 .28902 .19294 Mtetra
.673 .746 .905 r
.28902 .19294 .29313 .1974 .29948 .19478 .29538 .19035 Mtetra
.644 .739 .918 r
.29538 .19035 .29948 .19478 .30583 .1924 .30172 .1882 Mtetra
.689 .765 .91 r
.30172 .1882 .30583 .1924 .31218 .19014 .30813 .18535 Mtetra
.639 .72 .907 r
.30813 .18535 .31218 .19014 .31859 .18739 .31449 .18327 Mtetra
.66 .762 .926 r
.31449 .18327 .31859 .18739 .32498 .18514 .3209 .18088 Mtetra
.693 .765 .907 r
.3209 .18088 .32498 .18514 .33139 .1827 .32736 .17794 Mtetra
.631 .72 .911 r
.32736 .17794 .33139 .1827 .33783 .18014 .33377 .17597 Mtetra
.695 .771 .91 r
.33377 .17597 .33783 .18014 .34425 .17803 .34025 .17298 Mtetra
.626 .705 .902 r
.34025 .17298 .34425 .17803 .35074 .17517 .34669 .17106 Mtetra
.698 .776 .912 r
.34669 .17106 .35074 .17517 .35721 .17276 .35321 .16803 Mtetra
.655 .732 .906 r
.35321 .16803 .35721 .17276 .36368 .17073 .35971 .16566 Mtetra
.663 .719 .89 r
.35971 .16566 .36368 .17073 .37019 .16825 .36623 .16312 Mtetra
.669 .719 .886 r
.36623 .16312 .37019 .16825 .37674 .16539 .37277 .16046 Mtetra
.63 .715 .908 r
.37277 .16046 .37674 .16539 .38329 .16257 .3793 .15846 Mtetra
.69 .777 .918 r
.3793 .15846 .38329 .16257 .38983 .16057 .38589 .15553 Mtetra
.639 .714 .902 r
.38589 .15553 .38983 .16057 .39643 .15753 .39245 .15337 Mtetra
.696 .778 .914 r
.39245 .15337 .39643 .15753 .403 .15536 .39908 .15031 Mtetra
.626 .71 .906 r
.39908 .15031 .403 .15536 .40962 .15258 .40567 .14835 Mtetra
.687 .773 .917 r
.40567 .14835 .40962 .15258 .41624 .15007 .41232 .14544 Mtetra
.663 .745 .911 r
.41232 .14544 .41624 .15007 .42287 .14769 .41896 .14289 Mtetra
.649 .732 .91 r
.41896 .14289 .42287 .14769 .42954 .14483 .42562 .14056 Mtetra
.693 .774 .914 r
.42562 .14056 .42954 .14483 .4362 .14244 .43232 .13753 Mtetra
.637 .723 .91 r
.43232 .13753 .4362 .14244 .44289 .13988 .43901 .13536 Mtetra
.673 .756 .913 r
.43901 .13536 .44289 .13988 .4496 .13719 .44572 .13263 Mtetra
.668 .753 .914 r
.44572 .13263 .4496 .13719 .45631 .1349 .45246 .12998 Mtetra
.658 .732 .904 r
.45246 .12998 .45631 .1349 .46306 .13191 .45921 .12747 Mtetra
.674 .763 .917 r
.45921 .12747 .46306 .13191 .46981 .12966 .46597 .12471 Mtetra
.665 .734 .902 r
.46597 .12471 .46981 .12966 .47658 .12681 .47276 .12208 Mtetra
.654 .742 .914 r
.47276 .12208 .47658 .12681 .48337 .12437 .47955 .11962 Mtetra
.681 .751 .904 r
.47955 .11962 .48337 .12437 .49017 .12186 .48637 .1167 Mtetra
.652 .721 .899 r
.48637 .1167 .49017 .12186 .497 .11888 .4932 .11425 Mtetra
.66 .751 .917 r
.4932 .11425 .497 .11888 .50383 .11649 .50005 .11168 Mtetra
.67 .746 .908 r
.50005 .11168 .50383 .11649 .51069 .11393 .50692 .10893 Mtetra
.67 .738 .901 r
.50692 .10893 .51069 .11393 .51756 .11123 .51381 .10616 Mtetra
.667 .733 .9 r
.51381 .10616 .51756 .11123 .52446 .1085 .52071 .10343 Mtetra
.663 .733 .901 r
.52071 .10343 .52446 .1085 .53136 .10581 .52763 .10076 Mtetra
.662 .734 .903 r
.52763 .10076 .53136 .10581 .53829 .10313 .53456 .09811 Mtetra
.662 .736 .905 r
.53456 .09811 .53829 .10313 .54523 .10045 .54152 .09545 Mtetra
.664 .738 .906 r
.54152 .09545 .54523 .10045 .55219 .09772 .54849 .09277 Mtetra
.665 .741 .907 r
.54849 .09277 .55219 .09772 .55917 .09498 .55548 .09005 Mtetra
.664 .743 .909 r
.55548 .09005 .55917 .09498 .56616 .09234 .56248 .08735 Mtetra
.664 .741 .907 r
.56248 .08735 .56616 .09234 .57317 .08961 .56951 .08464 Mtetra
.662 .741 .909 r
.56951 .08464 .57317 .08961 .58021 .08693 .57655 .08196 Mtetra
.665 .743 .908 r
.57655 .08196 .58021 .08693 .58725 .08425 .58361 .07922 Mtetra
.662 .74 .907 r
.58361 .07922 .58725 .08425 .59432 .08152 .59069 .07651 Mtetra
.662 .742 .909 r
.59069 .07651 .59432 .08152 .6014 .0788 .59779 .0738 Mtetra
.666 .744 .909 r
.59779 .0738 .6014 .0788 .60851 .0761 .6049 .07103 Mtetra
.665 .741 .907 r
.6049 .07103 .60851 .0761 .61563 .07336 .61203 .06826 Mtetra
.663 .739 .907 r
.61203 .06826 .61563 .07336 .62277 .0706 .61918 .06552 Mtetra
.663 .741 .908 r
.61918 .06552 .62277 .0706 .62992 .06784 .62635 .06276 Mtetra
.62635 .06276 .62992 .06784 .6371 .06511 .63354 .06001 Mtetra
.664 .742 .908 r
.63354 .06001 .6371 .06511 .64429 .06237 .64075 .05723 Mtetra
.664 .74 .907 r
.64075 .05723 .64429 .06237 .6515 .05959 .64797 .05444 Mtetra
.663 .74 .907 r
.64797 .05444 .6515 .05959 .65873 .05679 .65521 .05166 Mtetra
.663 .742 .909 r
.65521 .05166 .65873 .05679 .66598 .05404 .66248 .04888 Mtetra
.662 .74 .908 r
.66248 .04888 .66598 .05404 .67325 .05122 .66976 .04611 Mtetra
.666 .745 .909 r
.66976 .04611 .67325 .05122 .68054 .04844 .67706 .04327 Mtetra
.662 .741 .909 r
.67706 .04327 .68054 .04844 .68784 .04569 .68438 .04048 Mtetra
.665 .741 .907 r
.68438 .04048 .68784 .04569 .69517 .04284 .69171 .03763 Mtetra
.651 .736 .912 r
.69171 .03763 .69517 .04284 .70251 .04007 .69908 .03502 Mtetra
.676 .755 .91 r
.69908 .03502 .70251 .04007 .70987 .03719 .70644 .03197 Mtetra
.662 .741 .909 r
.05425 .27703 .05868 .28115 .06445 .27914 .06006 .27482 Mtetra
.654 .729 .904 r
.06006 .27482 .06445 .27914 .07029 .27675 .06586 .2727 Mtetra
.67 .748 .909 r
.06586 .2727 .07029 .27675 .07613 .27446 .07171 .27036 Mtetra
.663 .744 .91 r
.07171 .27036 .07613 .27446 .08198 .27221 .07756 .26811 Mtetra
.668 .745 .908 r
.07756 .26811 .08198 .27221 .08782 .27002 .08344 .26579 Mtetra
.665 .738 .905 r
.08344 .26579 .08782 .27002 .0937 .26771 .08932 .26349 Mtetra
.66 .738 .908 r
.08932 .26349 .0937 .26771 .09959 .26541 .09521 .26127 Mtetra
.662 .743 .911 r
.09521 .26127 .09959 .26541 .10549 .26316 .10111 .25902 Mtetra
.665 .745 .91 r
.10111 .25902 .10549 .26316 .1114 .26091 .10703 .25671 Mtetra
.666 .743 .907 r
.10703 .25671 .1114 .26091 .11732 .25863 .11297 .25438 Mtetra
.664 .74 .906 r
.11297 .25438 .11732 .25863 .12327 .25632 .11892 .25207 Mtetra
.663 .74 .908 r
.11892 .25207 .12327 .25632 .12922 .25401 .12488 .24979 Mtetra
.662 .742 .909 r
.12488 .24979 .12922 .25401 .13519 .25172 .13085 .2475 Mtetra
.665 .743 .908 r
.13085 .2475 .13519 .25172 .14117 .24946 .13684 .24517 Mtetra
.663 .74 .907 r
.13684 .24517 .14117 .24946 .14716 .24717 .14285 .24287 Mtetra
.661 .739 .908 r
.14285 .24287 .14716 .24717 .15317 .24481 .14886 .24058 Mtetra
.667 .745 .908 r
.14886 .24058 .15317 .24481 .1592 .24252 .1549 .2382 Mtetra
.661 .739 .908 r
.1549 .2382 .1592 .24252 .16523 .24019 .16094 .23591 Mtetra
.666 .743 .908 r
.16094 .23591 .16523 .24019 .17129 .23784 .167 .23353 Mtetra
.662 .741 .909 r
.167 .23353 .17129 .23784 .17735 .23552 .17307 .23121 Mtetra
.664 .742 .908 r
.17307 .23121 .17735 .23552 .18344 .23317 .17917 .22885 Mtetra
.663 .742 .909 r
.17917 .22885 .18344 .23317 .18953 .23086 .18527 .22651 Mtetra
.664 .741 .907 r
.18527 .22651 .18953 .23086 .19564 .22852 .19139 .22414 Mtetra
.662 .74 .907 r
.19139 .22414 .19564 .22852 .20176 .22615 .19752 .2218 Mtetra
.662 .741 .909 r
.19752 .2218 .20176 .22615 .2079 .22377 .20366 .21946 Mtetra
.662 .744 .911 r
.20366 .21946 .2079 .22377 .21405 .22141 .20982 .2171 Mtetra
.663 .745 .911 r
.20982 .2171 .21405 .22141 .22022 .21909 .21599 .21473 Mtetra
.666 .744 .909 r
.21599 .21473 .22022 .21909 .22639 .21682 .22219 .21231 Mtetra
.659 .735 .906 r
.22219 .21231 .22639 .21682 .23257 .21456 .22839 .20998 Mtetra
.656 .731 .904 r
.22839 .20998 .23257 .21456 .23879 .21214 .2346 .20768 Mtetra
.664 .74 .906 r
.2346 .20768 .23879 .21214 .24504 .20952 .24084 .20527 Mtetra
.674 .754 .911 r
.24084 .20527 .24504 .20952 .25125 .20741 .2471 .20269 Mtetra
.65 .724 .903 r
.2471 .20269 .25125 .20741 .25752 .20493 .25335 .20047 Mtetra
.668 .742 .906 r
.25335 .20047 .25752 .20493 .2638 .20239 .25964 .19798 Mtetra
.662 .744 .911 r
.25964 .19798 .2638 .20239 .27006 .20027 .26593 .19558 Mtetra
.651 .727 .904 r
.26593 .19558 .27006 .20027 .27639 .19755 .27223 .19332 Mtetra
.664 .755 .918 r
.27223 .19332 .27639 .19755 .28268 .19548 .27855 .19089 Mtetra
.669 .738 .902 r
.27855 .19089 .28268 .19548 .28902 .19294 .2849 .18835 Mtetra
.643 .731 .913 r
.2849 .18835 .28902 .19294 .29538 .19035 .29124 .18622 Mtetra
.697 .771 .909 r
.29124 .18622 .29538 .19035 .30172 .1882 .29765 .18324 Mtetra
.627 .707 .904 r
.29765 .18324 .30172 .1882 .30813 .18535 .30399 .18133 Mtetra
.671 .771 .925 r
.30399 .18133 .30813 .18535 .31449 .18327 .31041 .17876 Mtetra
.682 .749 .902 r
.31041 .17876 .31449 .18327 .3209 .18088 .31685 .17598 Mtetra
.623 .711 .909 r
.31685 .17598 .3209 .18088 .32736 .17794 .32324 .17411 Mtetra
.702 .791 .92 r
.32324 .17411 .32736 .17794 .33377 .17597 .32973 .17103 Mtetra
.648 .719 .9 r
.32973 .17103 .33377 .17597 .34025 .17298 .33618 .16877 Mtetra
.684 .768 .915 r
.33618 .16877 .34025 .17298 .34669 .17106 .34268 .16596 Mtetra
.653 .714 .892 r
.34268 .16596 .34669 .17106 .35321 .16803 .34917 .16358 Mtetra
.665 .751 .914 r
.34917 .16358 .35321 .16803 .35971 .16566 .35569 .16105 Mtetra
.664 .743 .909 r
.35569 .16105 .35971 .16566 .36623 .16312 .36222 .15852 Mtetra
.661 .743 .911 r
.36222 .15852 .36623 .16312 .37277 .16046 .36876 .15604 Mtetra
.669 .755 .915 r
.36876 .15604 .37277 .16046 .3793 .15846 .37533 .15343 Mtetra
.657 .721 .896 r
.37533 .15343 .3793 .15846 .38589 .15553 .3819 .15097 Mtetra
.654 .744 .916 r
.3819 .15097 .38589 .15553 .39245 .15337 .38849 .14859 Mtetra
.647 .731 .91 r
.38849 .14859 .39245 .15337 .39908 .15031 .39509 .1463 Mtetra
.708 .79 .915 r
.39509 .1463 .39908 .15031 .40567 .14835 .40174 .14304 Mtetra
.619 .696 .899 r
.40174 .14304 .40567 .14835 .41232 .14544 .40836 .14117 Mtetra
.68 .77 .919 r
.40836 .14117 .41232 .14544 .41896 .14289 .41503 .13835 Mtetra
.68 .756 .909 r
.41503 .13835 .41896 .14289 .42562 .14056 .42172 .13552 Mtetra
.639 .718 .905 r
.42172 .13552 .42562 .14056 .43232 .13753 .42839 .13333 Mtetra
.697 .781 .916 r
.42839 .13333 .43232 .13753 .43901 .13536 .43512 .13021 Mtetra
.637 .713 .902 r
.43512 .13021 .43901 .13536 .44572 .13263 .44183 .12803 Mtetra
.679 .756 .909 r
.44183 .12803 .44572 .13263 .45246 .12998 .44858 .12517 Mtetra
.662 .74 .908 r
.44858 .12517 .45246 .12998 .45921 .12747 .45534 .1226 Mtetra
.674 .742 .902 r
.45534 .1226 .45921 .12747 .46597 .12471 .46212 .1198 Mtetra
.655 .734 .907 r
.46212 .1198 .46597 .12471 .47276 .12208 .46891 .11732 Mtetra
.675 .749 .907 r
.46891 .11732 .47276 .12208 .47955 .11962 .47573 .1145 Mtetra
.655 .725 .9 r
.47573 .1145 .47955 .11962 .48637 .1167 .48255 .11199 Mtetra
.662 .748 .914 r
.48255 .11199 .48637 .1167 .4932 .11425 .48939 .10938 Mtetra
.668 .743 .906 r
.48939 .10938 .4932 .11425 .50005 .11168 .49626 .10665 Mtetra
.669 .736 .9 r
.49626 .10665 .50005 .11168 .50692 .10893 .50314 .10389 Mtetra
.66 .733 .903 r
.50314 .10389 .50692 .10893 .51381 .10616 .51003 .10127 Mtetra
.664 .743 .909 r
.51003 .10127 .51381 .10616 .52071 .10343 .51694 .0986 Mtetra
.665 .746 .911 r
.51694 .0986 .52071 .10343 .52763 .10076 .52387 .0959 Mtetra
.666 .746 .91 r
.52387 .0959 .52763 .10076 .53456 .09811 .53082 .09319 Mtetra
.665 .743 .908 r
.53082 .09319 .53456 .09811 .54152 .09545 .53779 .09047 Mtetra
.663 .74 .907 r
.53779 .09047 .54152 .09545 .54849 .09277 .54477 .08779 Mtetra
.664 .741 .907 r
.54477 .08779 .54849 .09277 .55548 .09005 .55177 .08507 Mtetra
.663 .741 .908 r
.55177 .08507 .55548 .09005 .56248 .08735 .55879 .08237 Mtetra
.664 .742 .908 r
.55879 .08237 .56248 .08735 .56951 .08464 .56583 .07965 Mtetra
.663 .742 .909 r
.56583 .07965 .56951 .08464 .57655 .08196 .57288 .07693 Mtetra
.664 .741 .908 r
.57288 .07693 .57655 .08196 .58361 .07922 .57995 .0742 Mtetra
.662 .741 .909 r
.57995 .0742 .58361 .07922 .59069 .07651 .58704 .07149 Mtetra
.667 .744 .908 r
.58704 .07149 .59069 .07651 .59779 .0738 .59415 .0687 Mtetra
.662 .738 .907 r
.59415 .0687 .59779 .0738 .6049 .07103 .60128 .06597 Mtetra
.663 .742 .909 r
.60128 .06597 .6049 .07103 .61203 .06826 .60842 .06322 Mtetra
.665 .744 .909 r
.60842 .06322 .61203 .06826 .61918 .06552 .61558 .06043 Mtetra
.664 .742 .908 r
.61558 .06043 .61918 .06552 .62635 .06276 .62277 .05764 Mtetra
.662 .74 .908 r
.62277 .05764 .62635 .06276 .63354 .06001 .62997 .05489 Mtetra
.661 .74 .908 r
.62997 .05489 .63354 .06001 .64075 .05723 .63719 .05214 Mtetra
.664 .743 .91 r
.63719 .05214 .64075 .05723 .64797 .05444 .64442 .04935 Mtetra
.666 .745 .909 r
.64442 .04935 .64797 .05444 .65521 .05166 .65168 .04651 Mtetra
.664 .742 .908 r
.65168 .04651 .65521 .05166 .66248 .04888 .65895 .04369 Mtetra
.663 .741 .908 r
.65895 .04369 .66248 .04888 .66976 .04611 .66625 .04088 Mtetra
.662 .739 .907 r
.66625 .04088 .66976 .04611 .67706 .04327 .67356 .03808 Mtetra
.659 .74 .91 r
.67356 .03808 .67706 .04327 .68438 .04048 .6809 .03534 Mtetra
.662 .745 .911 r
.6809 .03534 .68438 .04048 .69171 .03763 .68825 .03253 Mtetra
.669 .75 .911 r
.68825 .03253 .69171 .03763 .69908 .03502 .69561 .02959 Mtetra
.665 .733 .901 r
.69561 .02959 .69908 .03502 .70644 .03197 .703 .0267 Mtetra
.642 .737 .917 r
.0498 .2729 .05425 .27703 .06006 .27482 .05557 .27096 Mtetra
.672 .759 .915 r
.05557 .27096 .06006 .27482 .06586 .2727 .06142 .26858 Mtetra
.677 .747 .904 r
.06142 .26858 .06586 .2727 .07171 .27036 .0673 .26611 Mtetra
.659 .736 .907 r
.0673 .26611 .07171 .27036 .07756 .26811 .07314 .26392 Mtetra
.667 .742 .906 r
.07314 .26392 .07756 .26811 .08344 .26579 .07902 .26159 Mtetra
.659 .74 .91 r
.07902 .26159 .08344 .26579 .08932 .26349 .0849 .25938 Mtetra
.663 .746 .912 r
.0849 .25938 .08932 .26349 .09521 .26127 .0908 .25711 Mtetra
.668 .745 .908 r
.0908 .25711 .09521 .26127 .10111 .25902 .09672 .25475 Mtetra
.665 .739 .905 r
.09672 .25475 .10111 .25902 .10703 .25671 .10265 .25243 Mtetra
.663 .739 .906 r
.10265 .25243 .10703 .25671 .11297 .25438 .10859 .25014 Mtetra
.663 .741 .908 r
.10859 .25014 .11297 .25438 .11892 .25207 .11455 .24783 Mtetra
.664 .742 .908 r
.11455 .24783 .11892 .25207 .12488 .24979 .12052 .24552 Mtetra
.662 .741 .908 r
.12052 .24552 .12488 .24979 .13085 .2475 .1265 .24322 Mtetra
.661 .74 .909 r
.1265 .24322 .13085 .2475 .13684 .24517 .13249 .24094 Mtetra
.665 .744 .909 r
.13249 .24094 .13684 .24517 .14285 .24287 .13851 .23859 Mtetra
.664 .742 .908 r
.13851 .23859 .14285 .24287 .14886 .24058 .14453 .23625 Mtetra
.661 .739 .908 r
.14453 .23625 .14886 .24058 .1549 .2382 .15057 .23395 Mtetra
.667 .745 .909 r
.15057 .23395 .1549 .2382 .16094 .23591 .15663 .23155 Mtetra
.66 .739 .908 r
.15663 .23155 .16094 .23591 .167 .23353 .16269 .22925 Mtetra
.666 .744 .909 r
.16269 .22925 .167 .23353 .17307 .23121 .16878 .22686 Mtetra
.664 .741 .908 r
.16878 .22686 .17307 .23121 .17917 .22885 .17488 .2245 Mtetra
.662 .741 .909 r
.17488 .2245 .17917 .22885 .18527 .22651 .18099 .22217 Mtetra
.664 .742 .909 r
.18099 .22217 .18527 .22651 .19139 .22414 .18711 .2198 Mtetra
.663 .742 .909 r
.18711 .2198 .19139 .22414 .19752 .2218 .19325 .21743 Mtetra
.19325 .21743 .19752 .2218 .20366 .21946 .19941 .21505 Mtetra
.663 .74 .908 r
.19941 .21505 .20366 .21946 .20982 .2171 .20558 .21268 Mtetra
.661 .74 .908 r
.20558 .21268 .20982 .2171 .21599 .21473 .21176 .21032 Mtetra
.661 .74 .909 r
.21176 .21032 .21599 .21473 .22219 .21231 .21795 .20795 Mtetra
.664 .745 .91 r
.21795 .20795 .22219 .21231 .22839 .20998 .22417 .20555 Mtetra
.665 .742 .907 r
.22417 .20555 .22839 .20998 .2346 .20768 .2304 .20311 Mtetra
.662 .735 .904 r
.2304 .20311 .2346 .20768 .24084 .20527 .23664 .20071 Mtetra
.659 .735 .906 r
.23664 .20071 .24084 .20527 .2471 .20269 .2429 .19836 Mtetra
.674 .751 .909 r
.2429 .19836 .2471 .20269 .25335 .20047 .24919 .19577 Mtetra
.656 .728 .902 r
.24919 .19577 .25335 .20047 .25964 .19798 .25546 .19345 Mtetra
.663 .739 .907 r
.25546 .19345 .25964 .19798 .26593 .19558 .26177 .19101 Mtetra
.656 .736 .908 r
.26177 .19101 .26593 .19558 .27223 .19332 .26808 .18869 Mtetra
.662 .735 .904 r
.26808 .18869 .27223 .19332 .27855 .19089 .27441 .18625 Mtetra
.647 .73 .91 r
.27441 .18625 .27855 .19089 .2849 .18835 .28074 .18405 Mtetra
.691 .761 .905 r
.28074 .18405 .2849 .18835 .29124 .18622 .28715 .18115 Mtetra
.625 .702 .901 r
.28715 .18115 .29124 .18622 .29765 .18324 .29348 .17926 Mtetra
.687 .778 .92 r
.29348 .17926 .29765 .18324 .30399 .18133 .29991 .17643 Mtetra
.65 .721 .9 r
.29991 .17643 .30399 .18133 .31041 .17876 .30631 .17415 Mtetra
.644 .733 .914 r
.30631 .17415 .31041 .17876 .31685 .17598 .31271 .17198 Mtetra
.713 .785 .908 r
.31271 .17198 .31685 .17598 .32324 .17411 .31921 .16869 Mtetra
.607 .681 .894 r
.31921 .16869 .32324 .17411 .32973 .17103 .32561 .16705 Mtetra
.694 .782 .919 r
.32561 .16705 .32973 .17103 .33618 .16877 .33212 .16408 Mtetra
.667 .739 .904 r
.33212 .16408 .33618 .16877 .34268 .16596 .33862 .16151 Mtetra
.667 .752 .914 r
.33862 .16151 .34268 .16596 .34917 .16358 .34513 .15894 Mtetra
.656 .739 .911 r
.34513 .15894 .34917 .16358 .35569 .16105 .35164 .15654 Mtetra
.662 .748 .914 r
.35164 .15654 .35569 .16105 .36222 .15852 .35818 .15404 Mtetra
.673 .753 .911 r
.35818 .15404 .36222 .15852 .36876 .15604 .36475 .15136 Mtetra
.67 .743 .906 r
.36475 .15136 .36876 .15604 .37533 .15343 .37132 .14871 Mtetra
.638 .731 .916 r
.37132 .14871 .37533 .15343 .3819 .15097 .37789 .14656 Mtetra
.659 .755 .921 r
.37789 .14656 .3819 .15097 .38849 .14859 .38449 .14409 Mtetra
.688 .76 .906 r
.38449 .14409 .38849 .14859 .39509 .1463 .39113 .14112 Mtetra
.624 .705 .903 r
.39113 .14112 .39509 .1463 .40174 .14304 .39774 .13916 Mtetra
.707 .799 .922 r
.39774 .13916 .40174 .14304 .40836 .14117 .40442 .13592 Mtetra
.643 .71 .896 r
.40442 .13592 .40836 .14117 .41503 .13835 .41108 .13364 Mtetra
.662 .743 .911 r
.41108 .13364 .41503 .13835 .42172 .13552 .41777 .13109 Mtetra
.693 .768 .909 r
.41777 .13109 .42172 .13552 .42839 .13333 .42449 .12801 Mtetra
.632 .704 .898 r
.42449 .12801 .42839 .13333 .43512 .13021 .43119 .1259 Mtetra
.695 .776 .914 r
.43119 .1259 .43512 .13021 .44183 .12803 .43794 .1228 Mtetra
.647 .715 .897 r
.43794 .1228 .44183 .12803 .44858 .12517 .44469 .12044 Mtetra
.68 .751 .905 r
.44469 .12044 .44858 .12517 .45534 .1226 .45147 .11754 Mtetra
.657 .728 .901 r
.45147 .11754 .45534 .1226 .46212 .1198 .45825 .115 Mtetra
.672 .746 .906 r
.45825 .115 .46212 .1198 .46891 .11732 .46506 .11222 Mtetra
.654 .726 .902 r
.46506 .11222 .46891 .11732 .47573 .1145 .47188 .10973 Mtetra
.667 .747 .91 r
.47188 .10973 .47573 .1145 .48255 .11199 .47871 .10703 Mtetra
.664 .737 .905 r
.47871 .10703 .48255 .11199 .48939 .10938 .48557 .10437 Mtetra
.663 .735 .904 r
.48557 .10437 .48939 .10938 .49626 .10665 .49244 .10171 Mtetra
.663 .739 .907 r
.49244 .10171 .49626 .10665 .50314 .10389 .49933 .09906 Mtetra
.666 .747 .91 r
.49933 .09906 .50314 .10389 .51003 .10127 .50624 .09635 Mtetra
.666 .742 .907 r
.50624 .09635 .51003 .10127 .51694 .0986 .51316 .09363 Mtetra
.664 .741 .907 r
.51316 .09363 .51694 .0986 .52387 .0959 .5201 .09093 Mtetra
.5201 .09093 .52387 .0959 .53082 .09319 .52706 .08823 Mtetra
.664 .742 .908 r
.52706 .08823 .53082 .09319 .53779 .09047 .53404 .08552 Mtetra
.664 .743 .909 r
.53404 .08552 .53779 .09047 .54477 .08779 .54104 .08281 Mtetra
.665 .743 .908 r
.54104 .08281 .54477 .08779 .55177 .08507 .54805 .08008 Mtetra
.664 .742 .908 r
.54805 .08008 .55177 .08507 .55879 .08237 .55508 .07735 Mtetra
.661 .74 .908 r
.55508 .07735 .55879 .08237 .56583 .07965 .56213 .07466 Mtetra
.667 .744 .908 r
.56213 .07466 .56583 .07965 .57288 .07693 .56919 .07187 Mtetra
.66 .739 .908 r
.56919 .07187 .57288 .07693 .57995 .0742 .57628 .06918 Mtetra
.667 .745 .908 r
.57628 .06918 .57995 .0742 .58704 .07149 .58338 .06638 Mtetra
.661 .738 .907 r
.58338 .06638 .58704 .07149 .59415 .0687 .5905 .06367 Mtetra
.664 .744 .91 r
.5905 .06367 .59415 .0687 .60128 .06597 .59764 .0609 Mtetra
.667 .744 .908 r
.59764 .0609 .60128 .06597 .60842 .06322 .60479 .05808 Mtetra
.662 .739 .907 r
.60479 .05808 .60842 .06322 .61558 .06043 .61197 .05532 Mtetra
.664 .742 .908 r
.61197 .05532 .61558 .06043 .62277 .05764 .61916 .05253 Mtetra
.665 .743 .908 r
.61916 .05253 .62277 .05764 .62997 .05489 .62638 .04972 Mtetra
.664 .74 .907 r
.62638 .04972 .62997 .05489 .63719 .05214 .63361 .04692 Mtetra
.661 .737 .907 r
.63361 .04692 .63719 .05214 .64442 .04935 .64086 .04416 Mtetra
.661 .74 .908 r
.64086 .04416 .64442 .04935 .65168 .04651 .64813 .0414 Mtetra
.667 .746 .91 r
.64813 .0414 .65168 .04651 .65895 .04369 .65541 .03853 Mtetra
.663 .743 .91 r
.65541 .03853 .65895 .04369 .66625 .04088 .66272 .03572 Mtetra
.66272 .03572 .66625 .04088 .67356 .03808 .67005 .0329 Mtetra
.668 .746 .908 r
.67005 .0329 .67356 .03808 .6809 .03534 .67739 .02998 Mtetra
.655 .732 .906 r
.67739 .02998 .6809 .03534 .68825 .03253 .68476 .02728 Mtetra
.652 .737 .912 r
.68476 .02728 .68825 .03253 .69561 .02959 .69215 .02463 Mtetra
.681 .764 .913 r
.69215 .02463 .69561 .02959 .703 .0267 .69954 .02147 Mtetra
.638 .734 .918 r
.04533 .26873 .0498 .2729 .05557 .27096 .0511 .26684 Mtetra
.653 .741 .914 r
.0511 .26684 .05557 .27096 .06142 .26858 .05691 .26473 Mtetra
.686 .763 .91 r
.05691 .26473 .06142 .26858 .0673 .26611 .06282 .26213 Mtetra
.667 .753 .914 r
.06282 .26213 .0673 .26611 .07314 .26392 .06869 .25981 Mtetra
.671 .748 .908 r
.06869 .25981 .07314 .26392 .07902 .26159 .07459 .25742 Mtetra
.664 .743 .909 r
.07459 .25742 .07902 .26159 .0849 .25938 .08048 .25513 Mtetra
.667 .741 .905 r
.08048 .25513 .0849 .25938 .0908 .25711 .0864 .25278 Mtetra
.662 .736 .904 r
.0864 .25278 .0908 .25711 .09672 .25475 .09232 .25049 Mtetra
.662 .74 .908 r
.09232 .25049 .09672 .25475 .10265 .25243 .09825 .24821 Mtetra
.665 .743 .909 r
.09825 .24821 .10265 .25243 .10859 .25014 .1042 .24588 Mtetra
.663 .741 .908 r
.1042 .24588 .10859 .25014 .11455 .24783 .11016 .24358 Mtetra
.66 .741 .91 r
.11016 .24358 .11455 .24783 .12052 .24552 .11613 .24131 Mtetra
.665 .745 .91 r
.11613 .24131 .12052 .24552 .1265 .24322 .12213 .23896 Mtetra
.666 .744 .908 r
.12213 .23896 .1265 .24322 .13249 .24094 .12814 .23659 Mtetra
.659 .738 .908 r
.12814 .23659 .13249 .24094 .13851 .23859 .13415 .23432 Mtetra
.667 .744 .908 r
.13415 .23432 .13851 .23859 .14453 .23625 .14019 .23193 Mtetra
.662 .741 .909 r
.14019 .23193 .14453 .23625 .15057 .23395 .14623 .2296 Mtetra
.664 .741 .907 r
.14623 .2296 .15057 .23395 .15663 .23155 .1523 .22724 Mtetra
.663 .742 .909 r
.1523 .22724 .15663 .23155 .16269 .22925 .15837 .2249 Mtetra
.667 .742 .906 r
.15837 .2249 .16269 .22925 .16878 .22686 .16447 .22248 Mtetra
.659 .739 .909 r
.16447 .22248 .16878 .22686 .17488 .2245 .17057 .22017 Mtetra
.664 .743 .909 r
.17057 .22017 .17488 .2245 .18099 .22217 .17669 .21779 Mtetra
.665 .742 .908 r
.17669 .21779 .18099 .22217 .18711 .2198 .18282 .21539 Mtetra
.665 .741 .906 r
.18282 .21539 .18711 .2198 .19325 .21743 .18898 .21297 Mtetra
.662 .738 .906 r
.18898 .21297 .19325 .21743 .19941 .21505 .19514 .2106 Mtetra
.663 .739 .907 r
.19514 .2106 .19941 .21505 .20558 .21268 .20131 .20822 Mtetra
.664 .74 .906 r
.20131 .20822 .20558 .21268 .21176 .21032 .20751 .20581 Mtetra
.662 .737 .906 r
.20751 .20581 .21176 .21032 .21795 .20795 .21372 .20341 Mtetra
.657 .735 .907 r
.21372 .20341 .21795 .20795 .22417 .20555 .21993 .20109 Mtetra
.66 .74 .909 r
.21993 .20109 .22417 .20555 .2304 .20311 .22616 .19872 Mtetra
.67 .747 .908 r
.22616 .19872 .2304 .20311 .23664 .20071 .23243 .19619 Mtetra
.663 .739 .906 r
.23243 .19619 .23664 .20071 .2429 .19836 .23869 .19375 Mtetra
.658 .734 .906 r
.23869 .19375 .2429 .19836 .24919 .19577 .24497 .1914 Mtetra
.673 .75 .909 r
.24497 .1914 .24919 .19577 .25546 .19345 .25128 .1888 Mtetra
.658 .733 .905 r
.25128 .1888 .25546 .19345 .26177 .19101 .25759 .18644 Mtetra
.659 .737 .908 r
.25759 .18644 .26177 .19101 .26808 .18869 .26391 .18405 Mtetra
.656 .734 .907 r
.26391 .18405 .26808 .18869 .27441 .18625 .27025 .18171 Mtetra
.671 .744 .905 r
.27025 .18171 .27441 .18625 .28074 .18405 .27662 .17911 Mtetra
.639 .714 .902 r
.27662 .17911 .28074 .18405 .28715 .18115 .28296 .177 Mtetra
.692 .771 .912 r
.28296 .177 .28715 .18115 .29348 .17926 .28939 .17409 Mtetra
.633 .702 .896 r
.28939 .17409 .29348 .17926 .29991 .17643 .29576 .17206 Mtetra
.667 .753 .915 r
.29576 .17206 .29991 .17643 .30631 .17415 .30219 .16952 Mtetra
.677 .743 .901 r
.30219 .16952 .30631 .17415 .31271 .17198 .30864 .16679 Mtetra
.628 .701 .898 r
.30864 .16679 .31271 .17198 .31921 .16869 .31506 .16482 Mtetra
.708 .792 .917 r
.31506 .16482 .31921 .16869 .32561 .16705 .32157 .16162 Mtetra
.623 .689 .891 r
.32157 .16162 .32561 .16705 .33212 .16408 .32802 .15971 Mtetra
.694 .764 .905 r
.32802 .15971 .33212 .16408 .33862 .16151 .33455 .15668 Mtetra
.668 .734 .9 r
.33455 .15668 .33862 .16151 .34513 .15894 .34108 .15407 Mtetra
.647 .725 .906 r
.34108 .15407 .34513 .15894 .35164 .15654 .34759 .15179 Mtetra
.654 .735 .909 r
.34759 .15179 .35164 .15654 .35818 .15404 .35413 .1494 Mtetra
.692 .753 .898 r
.35413 .1494 .35818 .15404 .36475 .15136 .36073 .14636 Mtetra
.651 .723 .901 r
.36073 .14636 .36475 .15136 .37132 .14871 .3673 .144 Mtetra
.642 .734 .915 r
.3673 .144 .37132 .14871 .37789 .14656 .37388 .14178 Mtetra
.675 .742 .901 r
.37388 .14178 .37789 .14656 .38449 .14409 .3805 .13901 Mtetra
.637 .715 .904 r
.3805 .13901 .38449 .14409 .39113 .14112 .38712 .13684 Mtetra
.711 .779 .905 r
.38712 .13684 .39113 .14112 .39774 .13916 .3938 .13347 Mtetra
.621 .681 .886 r
.3938 .13347 .39774 .13916 .40442 .13592 .40043 .13153 Mtetra
.68 .766 .916 r
.40043 .13153 .40442 .13592 .41108 .13364 .40713 .12869 Mtetra
.669 .735 .899 r
.40713 .12869 .41108 .13364 .41777 .13109 .41383 .12598 Mtetra
.648 .72 .901 r
.41383 .12598 .41777 .13109 .42449 .12801 .42053 .12361 Mtetra
.695 .772 .911 r
.42053 .12361 .42449 .12801 .43119 .1259 .42728 .1205 Mtetra
.641 .705 .893 r
.42728 .1205 .43119 .1259 .43794 .1228 .43401 .11822 Mtetra
.681 .76 .911 r
.43401 .11822 .43794 .1228 .44469 .12044 .44079 .11532 Mtetra
.66 .727 .899 r
.44079 .11532 .44469 .12044 .45147 .11754 .44757 .11273 Mtetra
.671 .746 .907 r
.44757 .11273 .45147 .11754 .45825 .115 .45437 .10997 Mtetra
.656 .731 .904 r
.45437 .10997 .45825 .115 .46506 .11222 .46118 .10745 Mtetra
.665 .747 .911 r
.46118 .10745 .46506 .11222 .47188 .10973 .46801 .10477 Mtetra
.667 .739 .904 r
.46801 .10477 .47188 .10973 .47871 .10703 .47486 .10205 Mtetra
.656 .735 .908 r
.47486 .10205 .47871 .10703 .48557 .10437 .48172 .0995 Mtetra
.665 .745 .909 r
.48172 .0995 .48557 .10437 .49244 .10171 .48861 .0968 Mtetra
.669 .744 .907 r
.48861 .0968 .49244 .10171 .49933 .09906 .49551 .09403 Mtetra
.665 .738 .904 r
.49551 .09403 .49933 .09906 .50624 .09635 .50243 .09131 Mtetra
.663 .737 .905 r
.50243 .09131 .50624 .09635 .51316 .09363 .50936 .08863 Mtetra
.664 .739 .906 r
.50936 .08863 .51316 .09363 .5201 .09093 .51632 .08592 Mtetra
.665 .74 .906 r
.51632 .08592 .5201 .09093 .52706 .08823 .52329 .08318 Mtetra
.662 .738 .906 r
.52329 .08318 .52706 .08823 .53404 .08552 .53028 .08049 Mtetra
.662 .739 .907 r
.53028 .08049 .53404 .08552 .54104 .08281 .53728 .0778 Mtetra
.663 .741 .908 r
.53728 .0778 .54104 .08281 .54805 .08008 .54431 .07508 Mtetra
.667 .744 .908 r
.54431 .07508 .54805 .08008 .55508 .07735 .55135 .0723 Mtetra
.662 .741 .908 r
.55135 .0723 .55508 .07735 .56213 .07466 .55841 .06958 Mtetra
.663 .74 .907 r
.55841 .06958 .56213 .07466 .56919 .07187 .56549 .06685 Mtetra
.665 .744 .909 r
.56549 .06685 .56919 .07187 .57628 .06918 .57258 .06407 Mtetra
.662 .739 .907 r
.57258 .06407 .57628 .06918 .58338 .06638 .5797 .06133 Mtetra
.663 .743 .91 r
.5797 .06133 .58338 .06638 .5905 .06367 .58683 .05857 Mtetra
.667 .743 .907 r
.58683 .05857 .5905 .06367 .59764 .0609 .59398 .05573 Mtetra
.659 .737 .907 r
.59398 .05573 .59764 .0609 .60479 .05808 .60115 .05302 Mtetra
.665 .745 .91 r
.60115 .05302 .60479 .05808 .61197 .05532 .60834 .05021 Mtetra
.667 .744 .908 r
.60834 .05021 .61197 .05532 .61916 .05253 .61554 .04736 Mtetra
.661 .74 .908 r
.61554 .04736 .61916 .05253 .62638 .04972 .62277 .04459 Mtetra
.664 .743 .909 r
.62277 .04459 .62638 .04972 .63361 .04692 .63001 .04178 Mtetra
.666 .744 .909 r
.63001 .04178 .63361 .04692 .64086 .04416 .63727 .03892 Mtetra
.663 .739 .906 r
.63727 .03892 .64086 .04416 .64813 .0414 .64455 .03609 Mtetra
.661 .736 .905 r
.64455 .03609 .64813 .0414 .65541 .03853 .65186 .0333 Mtetra
.665 .742 .907 r
.65186 .0333 .65541 .03853 .66272 .03572 .65917 .03043 Mtetra
.653 .734 .909 r
.65917 .03043 .66272 .03572 .67005 .0329 .66652 .02776 Mtetra
.669 .749 .91 r
.66652 .02776 .67005 .0329 .67739 .02998 .67388 .02482 Mtetra
.639 .736 .919 r
.67388 .02482 .67739 .02998 .68476 .02728 .68128 .02237 Mtetra
.669 .762 .92 r
.68128 .02237 .68476 .02728 .69215 .02463 .68867 .01943 Mtetra
.686 .756 .904 r
.68867 .01943 .69215 .02463 .69954 .02147 .69606 .01615 Mtetra
.65 .737 .913 r
.04084 .26454 .04533 .26873 .0511 .26684 .04664 .26247 Mtetra
.651 .729 .906 r
.04664 .26247 .0511 .26684 .05691 .26473 .05246 .26037 Mtetra
.666 .734 .9 r
.05246 .26037 .05691 .26473 .06282 .26213 .05833 .25803 Mtetra
.682 .752 .904 r
.05833 .25803 .06282 .26213 .06869 .25981 .06425 .25546 Mtetra
.651 .731 .908 r
.06425 .25546 .06869 .25981 .07459 .25742 .07011 .25335 Mtetra
.676 .752 .908 r
.07011 .25335 .07459 .25742 .08048 .25513 .07604 .25087 Mtetra
.656 .738 .91 r
.07604 .25087 .08048 .25513 .0864 .25278 .08194 .24867 Mtetra
.666 .749 .912 r
.08194 .24867 .0864 .25278 .09232 .25049 .08787 .24633 Mtetra
.67 .748 .909 r
.08787 .24633 .09232 .25049 .09825 .24821 .09383 .24393 Mtetra
.658 .739 .909 r
.09383 .24393 .09825 .24821 .1042 .24588 .09977 .24169 Mtetra
.665 .746 .91 r
.09977 .24169 .1042 .24588 .11016 .24358 .10575 .23935 Mtetra
.669 .746 .908 r
.10575 .23935 .11016 .24358 .11613 .24131 .11174 .23693 Mtetra
.659 .736 .907 r
.11174 .23693 .11613 .24131 .12213 .23896 .11773 .23467 Mtetra
.664 .742 .908 r
.11773 .23467 .12213 .23896 .12814 .23659 .12375 .23231 Mtetra
.667 .744 .908 r
.12375 .23231 .12814 .23659 .13415 .23432 .12978 .22992 Mtetra
.66 .737 .907 r
.12978 .22992 .13415 .23432 .14019 .23193 .13582 .22762 Mtetra
.668 .744 .907 r
.13582 .22762 .14019 .23193 .14623 .2296 .14188 .2252 Mtetra
.659 .737 .907 r
.14188 .2252 .14623 .2296 .1523 .22724 .14794 .2229 Mtetra
.667 .743 .907 r
.14794 .2229 .1523 .22724 .15837 .2249 .15403 .22047 Mtetra
.661 .738 .907 r
.15403 .22047 .15837 .2249 .16447 .22248 .16013 .21814 Mtetra
.663 .743 .91 r
.16013 .21814 .16447 .22248 .17057 .22017 .16624 .21577 Mtetra
.666 .742 .907 r
.16624 .21577 .17057 .22017 .17669 .21779 .17237 .21334 Mtetra
.664 .739 .906 r
.17237 .21334 .17669 .21779 .18282 .21539 .17852 .21095 Mtetra
.661 .739 .908 r
.17852 .21095 .18282 .21539 .18898 .21297 .18467 .20859 Mtetra
.662 .743 .91 r
.18467 .20859 .18898 .21297 .19514 .2106 .19084 .20622 Mtetra
.663 .743 .91 r
.19084 .20622 .19514 .2106 .20131 .20822 .19703 .20382 Mtetra
.664 .744 .91 r
.19703 .20382 .20131 .20822 .20751 .20581 .20323 .20141 Mtetra
.666 .745 .909 r
.20323 .20141 .20751 .20581 .21372 .20341 .20945 .19896 Mtetra
.667 .743 .907 r
.20945 .19896 .21372 .20341 .21993 .20109 .21569 .19647 Mtetra
.656 .732 .905 r
.21569 .19647 .21993 .20109 .22616 .19872 .22192 .19415 Mtetra
.658 .736 .907 r
.22192 .19415 .22616 .19872 .23243 .19619 .22818 .19179 Mtetra
.671 .748 .909 r
.22818 .19179 .23243 .19619 .23869 .19375 .23446 .18923 Mtetra
.662 .74 .908 r
.23446 .18923 .23869 .19375 .24497 .1914 .24075 .1868 Mtetra
.662 .737 .905 r
.24075 .1868 .24497 .1914 .25128 .1888 .24706 .18436 Mtetra
.668 .747 .91 r
.24706 .18436 .25128 .1888 .25759 .18644 .25339 .18184 Mtetra
.662 .738 .906 r
.25339 .18184 .25759 .18644 .26391 .18405 .25972 .1794 Mtetra
.662 .736 .904 r
.25972 .1794 .26391 .18405 .27025 .18171 .26608 .17694 Mtetra
.653 .728 .904 r
.26608 .17694 .27025 .18171 .27662 .17911 .27243 .17461 Mtetra
.676 .748 .905 r
.27243 .17461 .27662 .17911 .28296 .177 .27884 .17191 Mtetra
.642 .71 .896 r
.27884 .17191 .28296 .177 .28939 .17409 .28521 .16973 Mtetra
.673 .756 .913 r
.28521 .16973 .28939 .17409 .29576 .17206 .29164 .16709 Mtetra
.658 .722 .896 r
.29164 .16709 .29576 .17206 .30219 .16952 .29806 .16465 Mtetra
.649 .724 .904 r
.29806 .16465 .30219 .16952 .30864 .16679 .3045 .16236 Mtetra
.69 .759 .905 r
.3045 .16236 .30864 .16679 .31506 .16482 .31099 .15941 Mtetra
.619 .689 .893 r
.31099 .15941 .31506 .16482 .32157 .16162 .31742 .15755 Mtetra
.685 .778 .921 r
.31742 .15755 .32157 .16162 .32802 .15971 .32394 .15471 Mtetra
.628 .713 .907 r
.32394 .15471 .32802 .15971 .33455 .15668 .33042 .15271 Mtetra
.71 .791 .915 r
.33042 .15271 .33455 .15668 .34108 .15407 .33699 .14945 Mtetra
.641 .737 .919 r
.33699 .14945 .34108 .15407 .34759 .15179 .34351 .14726 Mtetra
.665 .75 .914 r
.34351 .14726 .34759 .15179 .35413 .1494 .35007 .1447 Mtetra
.675 .745 .904 r
.35007 .1447 .35413 .1494 .36073 .14636 .35666 .14195 Mtetra
.638 .748 .928 r
.35666 .14195 .36073 .14636 .3673 .144 .36323 .13978 Mtetra
.672 .77 .924 r
.36323 .13978 .3673 .144 .37388 .14178 .36984 .1371 Mtetra
.667 .746 .909 r
.36984 .1371 .37388 .14178 .3805 .13901 .37647 .13447 Mtetra
.688 .76 .907 r
.37647 .13447 .3805 .13901 .38712 .13684 .38313 .13148 Mtetra
.642 .706 .893 r
.38313 .13148 .38712 .13684 .3938 .13347 .38977 .1292 Mtetra
.691 .776 .917 r
.38977 .1292 .3938 .13347 .40043 .13153 .39647 .12618 Mtetra
.648 .71 .892 r
.39647 .12618 .40043 .13153 .40713 .12869 .40315 .12379 Mtetra
.665 .737 .904 r
.40315 .12379 .40713 .12869 .41383 .12598 .40986 .12115 Mtetra
.676 .745 .903 r
.40986 .12115 .41383 .12598 .42053 .12361 .41659 .11831 Mtetra
.65 .714 .895 r
.41659 .11831 .42053 .12361 .42728 .1205 .42332 .11588 Mtetra
.679 .758 .911 r
.42332 .11588 .42728 .1205 .43401 .11822 .43009 .11301 Mtetra
.656 .721 .897 r
.43009 .11301 .43401 .11822 .44079 .11532 .43686 .11046 Mtetra
.667 .743 .907 r
.43686 .11046 .44079 .11532 .44757 .11273 .44365 .10775 Mtetra
.662 .736 .905 r
.44365 .10775 .44757 .11273 .45437 .10997 .45046 .10513 Mtetra
.661 .743 .911 r
.45046 .10513 .45437 .10997 .46118 .10745 .45728 .10252 Mtetra
.669 .742 .905 r
.45728 .10252 .46118 .10745 .46801 .10477 .46413 .09976 Mtetra
.654 .733 .907 r
.46413 .09976 .46801 .10477 .47486 .10205 .47098 .09724 Mtetra
.667 .748 .911 r
.47098 .09724 .47486 .10205 .48172 .0995 .47786 .09452 Mtetra
.671 .742 .903 r
.47786 .09452 .48172 .0995 .48861 .0968 .48476 .0917 Mtetra
.66 .733 .903 r
.48476 .0917 .48861 .0968 .49551 .09403 .49167 .08905 Mtetra
.661 .74 .908 r
.49167 .08905 .49551 .09403 .50243 .09131 .4986 .08639 Mtetra
.664 .744 .91 r
.4986 .08639 .50243 .09131 .50936 .08863 .50555 .08369 Mtetra
.665 .744 .91 r
.50555 .08369 .50936 .08863 .51632 .08592 .51251 .08097 Mtetra
.665 .744 .909 r
.51251 .08097 .51632 .08592 .52329 .08318 .51949 .07822 Mtetra
.666 .745 .909 r
.51949 .07822 .52329 .08318 .53028 .08049 .52649 .07546 Mtetra
.664 .741 .907 r
.52649 .07546 .53028 .08049 .53728 .0778 .53351 .07271 Mtetra
.66 .737 .907 r
.53351 .07271 .53728 .0778 .54431 .07508 .54055 .07002 Mtetra
.663 .741 .907 r
.54055 .07002 .54431 .07508 .55135 .0723 .5476 .06727 Mtetra
.668 .745 .908 r
.5476 .06727 .55135 .0723 .55841 .06958 .55467 .06445 Mtetra
.659 .737 .907 r
.55467 .06445 .55841 .06958 .56549 .06685 .56176 .06176 Mtetra
.666 .742 .907 r
.56176 .06176 .56549 .06685 .57258 .06407 .56887 .05894 Mtetra
.661 .739 .908 r
.56887 .05894 .57258 .06407 .5797 .06133 .576 .05622 Mtetra
.667 .743 .907 r
.576 .05622 .5797 .06133 .58683 .05857 .58314 .05337 Mtetra
.659 .737 .907 r
.58314 .05337 .58683 .05857 .59398 .05573 .59031 .05065 Mtetra
.665 .745 .91 r
.59031 .05065 .59398 .05573 .60115 .05302 .59749 .04783 Mtetra
.664 .74 .906 r
.59749 .04783 .60115 .05302 .60834 .05021 .60469 .04501 Mtetra
.659 .738 .908 r
.60469 .04501 .60834 .05021 .61554 .04736 .61191 .04227 Mtetra
.666 .747 .911 r
.61191 .04227 .61554 .04736 .62277 .04459 .61914 .03942 Mtetra
.666 .743 .908 r
.61914 .03942 .62277 .04459 .63001 .04178 .6264 .03655 Mtetra
.657 .738 .909 r
.6264 .03655 .63001 .04178 .63727 .03892 .63368 .03383 Mtetra
.666 .749 .912 r
.63368 .03383 .63727 .03892 .64455 .03609 .64097 .03095 Mtetra
.664 .746 .911 r
.64097 .03095 .64455 .03609 .65186 .0333 .64828 .0281 Mtetra
.657 .741 .912 r
.64828 .0281 .65186 .0333 .65917 .03043 .65562 .02535 Mtetra
.671 .754 .913 r
.65562 .02535 .65917 .03043 .66652 .02776 .66297 .02237 Mtetra
.652 .731 .907 r
.66297 .02237 .66652 .02776 .67388 .02482 .67035 .01969 Mtetra
.657 .747 .916 r
.67035 .01969 .67388 .02482 .68128 .02237 .67775 .01694 Mtetra
.672 .739 .901 r
.67775 .01694 .68128 .02237 .68867 .01943 .68515 .0139 Mtetra
.675 .736 .896 r
.68515 .0139 .68867 .01943 .69606 .01615 .69256 .01078 Mtetra
.663 .741 .908 r
.03634 .26033 .04084 .26454 .04664 .26247 .04217 .25806 Mtetra
.662 .731 .901 r
.04217 .25806 .04664 .26247 .05246 .26037 .04803 .25579 Mtetra
.661 .723 .895 r
.04803 .25579 .05246 .26037 .05833 .25803 .05389 .2535 Mtetra
.663 .726 .896 r
.05389 .2535 .05833 .25803 .06425 .25546 .05978 .25119 Mtetra
.664 .74 .907 r
.05978 .25119 .06425 .25546 .07011 .25335 .06567 .24889 Mtetra
.662 .73 .9 r
.06567 .24889 .07011 .25335 .07604 .25087 .07158 .24658 Mtetra
.664 .74 .907 r
.07158 .24658 .07604 .25087 .08194 .24867 .0775 .24426 Mtetra
.663 .734 .903 r
.0775 .24426 .08194 .24867 .08787 .24633 .08344 .24194 Mtetra
.663 .735 .904 r
.08344 .24194 .08787 .24633 .09383 .24393 .08939 .23962 Mtetra
.664 .741 .907 r
.08939 .23962 .09383 .24393 .09977 .24169 .09536 .23728 Mtetra
.663 .736 .904 r
.09536 .23728 .09977 .24169 .10575 .23935 .10133 .23496 Mtetra
.663 .737 .905 r
.10133 .23496 .10575 .23935 .11174 .23693 .10733 .23262 Mtetra
.664 .742 .908 r
.10733 .23262 .11174 .23693 .11773 .23467 .11333 .23026 Mtetra
.662 .737 .905 r
.11333 .23026 .11773 .23467 .12375 .23231 .11935 .22792 Mtetra
.664 .739 .906 r
.11935 .22792 .12375 .23231 .12978 .22992 .12539 .22556 Mtetra
.663 .74 .907 r
.12539 .22556 .12978 .22992 .13582 .22762 .13144 .2232 Mtetra
.663 .738 .906 r
.13144 .2232 .13582 .22762 .14188 .2252 .1375 .22083 Mtetra
.663 .741 .908 r
.1375 .22083 .14188 .2252 .14794 .2229 .14358 .21846 Mtetra
.664 .739 .906 r
.14358 .21846 .14794 .2229 .15403 .22047 .14967 .21607 Mtetra
.662 .74 .908 r
.14967 .21607 .15403 .22047 .16013 .21814 .15578 .21371 Mtetra
.664 .74 .907 r
.15578 .21371 .16013 .21814 .16624 .21577 .1619 .21131 Mtetra
.665 .739 .905 r
.1619 .21131 .16624 .21577 .17237 .21334 .16804 .20889 Mtetra
.662 .739 .907 r
.16804 .20889 .17237 .21334 .17852 .21095 .17419 .20652 Mtetra
.662 .741 .908 r
.17419 .20652 .17852 .21095 .18467 .20859 .18035 .20413 Mtetra
.662 .74 .908 r
.18035 .20413 .18467 .20859 .19084 .20622 .18653 .20173 Mtetra
.663 .739 .907 r
.18653 .20173 .19084 .20622 .19703 .20382 .19273 .19932 Mtetra
.19273 .19932 .19703 .20382 .20323 .20141 .19894 .19691 Mtetra
.664 .74 .907 r
.19894 .19691 .20323 .20141 .20945 .19896 .20516 .19447 Mtetra
.666 .742 .907 r
.20516 .19447 .20945 .19896 .21569 .19647 .21141 .192 Mtetra
.665 .743 .908 r
.21141 .192 .21569 .19647 .22192 .19415 .21766 .18954 Mtetra
.657 .734 .906 r
.21766 .18954 .22192 .19415 .22818 .19179 .22393 .18718 Mtetra
.662 .736 .905 r
.22393 .18718 .22818 .19179 .23446 .18923 .23021 .18475 Mtetra
.671 .746 .907 r
.23021 .18475 .23446 .18923 .24075 .1868 .23652 .18217 Mtetra
.657 .735 .907 r
.23652 .18217 .24075 .1868 .24706 .18436 .24283 .1798 Mtetra
.663 .741 .908 r
.24283 .1798 .24706 .18436 .25339 .18184 .24916 .17734 Mtetra
.669 .746 .908 r
.24916 .17734 .25339 .18184 .25972 .1794 .25552 .17476 Mtetra
.656 .736 .908 r
.25552 .17476 .25972 .1794 .26608 .17694 .26187 .17239 Mtetra
.672 .746 .906 r
.26187 .17239 .26608 .17694 .27243 .17461 .26826 .16977 Mtetra
.654 .726 .902 r
.26826 .16977 .27243 .17461 .27884 .17191 .27464 .16741 Mtetra
.672 .749 .908 r
.27464 .16741 .27884 .17191 .28521 .16973 .28106 .16477 Mtetra
.653 .721 .899 r
.28106 .16477 .28521 .16973 .29164 .16709 .28747 .16242 Mtetra
.672 .742 .903 r
.28747 .16242 .29164 .16709 .29806 .16465 .29392 .15976 Mtetra
.654 .726 .902 r
.29392 .15976 .29806 .16465 .3045 .16236 .30037 .15739 Mtetra
.664 .726 .895 r
.30037 .15739 .3045 .16236 .31099 .15941 .30685 .15482 Mtetra
.667 .746 .91 r
.30685 .15482 .31099 .15941 .31742 .15755 .31334 .15224 Mtetra
.65 .707 .888 r
.31334 .15224 .31742 .15755 .32394 .15471 .31983 .14987 Mtetra
.67 .736 .899 r
.31983 .14987 .32394 .15471 .33042 .15271 .32636 .14719 Mtetra
.648 .697 .882 r
.32636 .14719 .33042 .15271 .33699 .14945 .33288 .14483 Mtetra
.643 .739 .919 r
.33288 .14483 .33699 .14945 .34351 .14726 .33942 .14259 Mtetra
.653 .74 .914 r
.33942 .14259 .34351 .14726 .35007 .1447 .34597 .1402 Mtetra
.701 .764 .901 r
.34597 .1402 .35007 .1447 .35666 .14195 .3526 .137 Mtetra
.659 .73 .902 r
.3526 .137 .35666 .14195 .36323 .13978 .3592 .13448 Mtetra
.661 .715 .888 r
.3592 .13448 .36323 .13978 .36984 .1371 .36581 .1319 Mtetra
.673 .724 .887 r
.36581 .1319 .36984 .1371 .37647 .13447 .37246 .12909 Mtetra
.651 .708 .889 r
.37246 .12909 .37647 .13447 .38313 .13148 .3791 .12665 Mtetra
.667 .74 .905 r
.3791 .12665 .38313 .13148 .38977 .1292 .38577 .12399 Mtetra
.664 .722 .892 r
.38577 .12399 .38977 .1292 .39647 .12618 .39246 .12133 Mtetra
.659 .738 .908 r
.39246 .12133 .39647 .12618 .40315 .12379 .39916 .11879 Mtetra
.671 .735 .899 r
.39916 .11879 .40315 .12379 .40986 .12115 .40588 .11603 Mtetra
.655 .724 .9 r
.40588 .11603 .40986 .12115 .41659 .11831 .41261 .11352 Mtetra
.672 .747 .907 r
.41261 .11352 .41659 .11831 .42332 .11588 .41936 .11076 Mtetra
.655 .726 .901 r
.41936 .11076 .42332 .11588 .43009 .11301 .42613 .10823 Mtetra
.668 .748 .91 r
.42613 .10823 .43009 .11301 .43686 .11046 .43291 .10551 Mtetra
.661 .737 .906 r
.43291 .10551 .43686 .11046 .44365 .10775 .43971 .10289 Mtetra
.661 .742 .91 r
.43971 .10289 .44365 .10775 .45046 .10513 .44653 .10026 Mtetra
.672 .746 .907 r
.44653 .10026 .45046 .10513 .45728 .10252 .45337 .09746 Mtetra
.656 .732 .905 r
.45337 .09746 .45728 .10252 .46413 .09976 .46022 .0949 Mtetra
.664 .745 .911 r
.46022 .0949 .46413 .09976 .47098 .09724 .46709 .09222 Mtetra
.668 .74 .904 r
.46709 .09222 .47098 .09724 .47786 .09452 .47398 .08944 Mtetra
.664 .736 .904 r
.47398 .08944 .47786 .09452 .48476 .0917 .48089 .08673 Mtetra
.661 .741 .909 r
.48089 .08673 .48476 .0917 .49167 .08905 .48781 .08407 Mtetra
.663 .741 .908 r
.48781 .08407 .49167 .08905 .4986 .08639 .49475 .08137 Mtetra
.664 .74 .907 r
.49475 .08137 .4986 .08639 .50555 .08369 .50171 .07864 Mtetra
.664 .74 .906 r
.50171 .07864 .50555 .08369 .51251 .08097 .50869 .0759 Mtetra
.50869 .0759 .51251 .08097 .51949 .07822 .51568 .07316 Mtetra
.665 .741 .907 r
.51568 .07316 .51949 .07822 .52649 .07546 .52269 .0704 Mtetra
.665 .742 .907 r
.52269 .0704 .52649 .07546 .53351 .07271 .52972 .06763 Mtetra
.663 .74 .908 r
.52972 .06763 .53351 .07271 .54055 .07002 .53677 .06489 Mtetra
.663 .738 .906 r
.53677 .06489 .54055 .07002 .5476 .06727 .54383 .06214 Mtetra
.664 .74 .906 r
.54383 .06214 .5476 .06727 .55467 .06445 .55092 .05935 Mtetra
.663 .742 .908 r
.55092 .05935 .55467 .06445 .56176 .06176 .55802 .05658 Mtetra
.663 .738 .906 r
.55802 .05658 .56176 .06176 .56887 .05894 .56514 .0538 Mtetra
.664 .741 .907 r
.56514 .0538 .56887 .05894 .576 .05622 .57228 .05101 Mtetra
.663 .738 .906 r
.57228 .05101 .576 .05622 .58314 .05337 .57944 .04822 Mtetra
.664 .741 .908 r
.57944 .04822 .58314 .05337 .59031 .05065 .58661 .04541 Mtetra
.664 .738 .905 r
.58661 .04541 .59031 .05065 .59749 .04783 .59381 .04259 Mtetra
.663 .738 .906 r
.59381 .04259 .59749 .04783 .60469 .04501 .60102 .03979 Mtetra
.664 .74 .907 r
.60102 .03979 .60469 .04501 .61191 .04227 .60825 .03695 Mtetra
.663 .736 .904 r
.60825 .03695 .61191 .04227 .61914 .03942 .6155 .03412 Mtetra
.663 .738 .905 r
.6155 .03412 .61914 .03942 .6264 .03655 .62277 .03129 Mtetra
.664 .74 .907 r
.62277 .03129 .6264 .03655 .63368 .03383 .63006 .02843 Mtetra
.662 .734 .903 r
.63006 .02843 .63368 .03383 .64097 .03095 .63736 .02559 Mtetra
.663 .737 .904 r
.63736 .02559 .64097 .03095 .64828 .0281 .64469 .02272 Mtetra
.663 .736 .905 r
.64469 .02272 .64828 .0281 .65562 .02535 .65203 .01986 Mtetra
.663 .731 .901 r
.65203 .01986 .65562 .02535 .66297 .02237 .6594 .01698 Mtetra
.662 .736 .905 r
.6594 .01698 .66297 .02237 .67035 .01969 .66678 .01411 Mtetra
.662 .728 .899 r
.66678 .01411 .67035 .01969 .67775 .01694 .67419 .01122 Mtetra
.662 .723 .894 r
.67419 .01122 .67775 .01694 .68515 .0139 .68161 .00831 Mtetra
.663 .729 .899 r
.68161 .00831 .68515 .0139 .69256 .01078 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14481 .21299 m
.14944 .21764 L
s
[(-100)] .13556 .20368 .99452 1 Mshowa
.3437 .13511 m
.34798 .14008 L
s
[(0)] .33513 .12517 .86183 1 Mshowa
.55867 .05093 m
.56253 .05623 L
s
[(100)] .55094 .04033 .72914 1 Mshowa
.125 Mabswid
.18339 .19788 m
.18613 .20071 L
s
.22255 .18254 m
.22525 .18541 L
s
.26232 .16697 m
.26497 .16988 L
s
.30269 .15116 m
.30531 .15411 L
s
.38535 .1188 m
.38787 .12182 L
s
.42765 .10223 m
.43013 .10529 L
s
.47063 .0854 m
.47305 .0885 L
s
.5143 .06831 m
.51667 .07145 L
s
.1068 .22787 m
.10961 .23062 L
s
.06936 .24253 m
.0722 .24525 L
s
.60376 .03327 m
.60603 .03649 L
s
.6496 .01532 m
.65181 .01859 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[80]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00b_ooool2o`0005Cooooo0037
ooooo`?o000000?oooooo`000?ooool0Doooool00<Gooooo0_l00004ooooo`;o0000Doooool009Wo
oooo0ol00004ooooo`;o00001?ooool2o`0001[ooooo0ol00003ooooo`06ojVii?nY^^KoZK[Vo`00
0?oooooo0000D_ooool009[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0001Oooooo0_l00004ooooo`08ojVji_nY^NCoZKWTojVii?nY^^Ko
0000ojbliOl0001Booooo`00V_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00005?ooool3o`000004ooooool0003oooooooooo`;oZKcW0_nY
^^H01onY^NCo[;gVojbmi_l0003o[l7Wooooool00000DOooool009[ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004oooo
o`05ojVlionY^nKoZK_VojVlionV^nP00onX_nX00on/_NKoZl?[o`000002ojo1i`03ooooool0003o
oooo04oooooo002Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0000?ooooo`?o00001?ooool3ojVli`03ojVki_n[`NWoY[_X00;oY[_X00Ko
Z;oZoj>ljonS_>_oZl?[o`000?n_`NL2ojk3j@03o`000?oooooooooo04kooooo002Iooooo`;o0000
1?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000cooooo0ol00005oooo
o`;oZK_W0onY_>L01?nX_NWoZl7Yoj_1jOnV^nP2oj^oj007oj>ljonW^nOoY[cYo`000?nV_>Wo[/?Y
ojZkiP02o`0004oooooo002Jooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00002ooo
ool3o`0000?ooooo00KoZKcWojVmj?nY_NSoZKgXojVkionZ_nT2ojVnj@03ojRmjOnZ_NSoYk_X00;o
Yk_X00?oZkoXoj^nj?n[_^P00_nW^nL00onV_>Wo0000oj^oj@02ojZkiP03ooooool0003ooooo04go
oooo002`ooooo`?o00000oooool00ol0003oZKcWojVli`02ojVli`03ojVmj?nX_>SoZ;cX00;oZ[oY
00GoZKkYojVlionZ_NSoZ[gXojNkj002ojVnj003oj^nj?nX_NSoZKkY00;oZKkY00?o0000ojJljOn]
`NP00_n]`NP00ol0003oooooooooo`1<ooooo`00[_ooool2o`0000Gooooo0_nY_NP3ojVli`;oZ[kX
00KoZ;cXojZnj?nY_NOoZKgWojVlionZ_^P4ojVnj007ojVmj?nX_NSoZ;gXojRmj?nY_^WoZ[gXo`00
0002ojJlj@04ojg1j?nZ_NOoooooo`0004gooooo002[ooooo`?o00000oooool4ojVli`03ojVmj?nX
_>SoZ[oY00;oZ[oY00?oZ[kXojVnj?nZ_^P00_nZ_^P01OnY_NOoZKgXojZnj?nZ_^SoZKkX00CoZKgX
00GoZ;gXojVmj?nY_NSoZ[gXo`000003ojVmj003ojZmiooooooo000004gooooo002Yooooo`;o0000
1Oooool01?nY_NSoZKcWojVlionY_>L2ojVmi`;oZ;cX00?oZ[oYojVmj?nY_NP00_nY_^P00onZ_^So
ZKcXojVlj006ojVmj0?oZ[kX00OoZKgXojRlj?nZ_NSo0000ojZmj?nY_NSoZ;cX00;oZkkW00?ooooo
o`000?ooool0Boooool00:Kooooo1?l00004ooooo`;oZKcW00GoZKgXojZnj?nZ_^SoZ[kXojVmi`04
ojZnj003ojVmj?nZ_^SoZKgX00;oZKgX00CoZKcXojVnj?nZ_^SoZ[kX1OnY_NP00onZ_^SoZKgXojVm
j002ojRlj004o`000?n[_^SoZkkXojRlj0?oZkoX00?oooooo`000?ooool0B_ooool00:Cooooo0_l0
0004ooooo`06o`000?nY_NSoZKgXojVmj?nY_>OoZ[kX0_nX_>P00onZ_^SoZ;cXojRlj003ojZnj0;o
ZKgX0_nZ_^P3ojVmj003ojVnj?nY_NSoZKgX00?oZKgX0onZ_^P4ojVmj003o`000?n[_^SoZKgX00;o
Z;cX00CoZkoXojVmionY_NOo0000Boooool00:7ooooo0ol00004ooooo`;oZKgX0_nY_>L3ojVmj006
ojZnj?nX_>SoZ[kXojZnj?nX_>SoZ[kX3OnY_NP2ojZnj0;oZKgX00?oZ[kXojVmj?nY_NP00onY_NP0
1?l0003oZ[kXojVmj?nX_>P2ojZnj003ojVmionZ_NSooooo00;o0000BOooool009oooooo0_l00003
ooooo`06ojVlionY_NOoZKgWojVmionY_NSoZ;cX0onZ_NP2ojVmj0;oZKkX00?oZ[kXojVnj?nY_^P0
0_nZ_^P00onY_NSoZ[kXojZnj009ojVmj003ojZnj?nY_NSoZKgX00?oZKgX00KoZ[kXojRmj?nX_NSo
Z;gXo`000?nZ_^P2ojRlj003ojZnj?nY_^SoZKkX00;oZ[gX0_l00019ooooo`00W?ooool3o`0000Co
oooo0onY_>L00onY_NOoZkkXoj^nj002ojRlj003ojZmj?nZ_^SoZ[kX00;oZKgX00CoZKkXojVlj?nY
_^SoZKcX0onY_NP00onZ_^SoZKgXojVmj007ojVmj0;oZ[kX1OnY_NP2ojZnj005ojRmj?nY_NSo0000
ojZnj?nX_>P00_nY_NP00onY_^SoZ;cXoj^nj002oj^nj003o`000?oooooooooo04Oooooo002Joooo
o`;o00000_ooool00ol0003oooooooooo`02ojZmj005ojVmj?nY_>OoZKgXojVmj?n[_^P01?nY_NP0
0onZ_^SoZ;gXojZnj002ojZnj0CoZKcX00?oZKgXojZmj?nZ_NP02?nY_NP00onY_^SoZ[kXojVmj004
ojVmj0CoZ[kX00?oZKgXo`000?nY_NP00_nY_NP2ojZnj0;oZ;cX00CoZkkXojVmj?nY_NSo00003Ooo
ool3o`0000Cooooo0_l00004ooooo`;o0000;?ooool009Oooooo0ol00003ooooo`03ojVmionZ_NSo
Z[gX00;oZ[gX00CoZKgXojRlj?nX_>SoZKgX0_nZ_^P3ojVmj0;oZ[kX0_nX_NP01OnZ_^SoZKgXojVm
j?nZ_^SoZKcX00;oZ[kX00?oZ[gXojVnj?nZ_^P00_nZ_^P4ojVmj003ojVnj?nY_NSoZKgX00GoZKgX
0onZ_^P2ojVmj006o`000?nY_NSoZKcXojVlj?nZ_^SoZKgX0onZ_^P01?nY_NSoZ[gXooooool0000=
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000[ooooo`00U?ooool3o`0000Cooooo1?nY_NL00onZ_NSoZ[kXojZnj002ojVmj003ojRlj?nY
_NSoZ[kX00CoZKgX00?oZ[kXojVmj?nY_NP01_nY_NP00onZ_^SoZKgXojVmj002ojVnj003ojZnj?nY
_NOoZKgW00_oZKgX0onZ_^P2ojVmj003o`000?nY_NSoZKcX00CoZKgX0onZ_^P2ojZmj003o`000?oo
oooooooo00?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool0000[ooooo`00T_ooool2o`0000Gooooo0_nY_NP00onY_NOoZ[kX
ojZnj003ojZnj003ojVlionY_NSoZKgX00;oZKgX00?oZ[kXojVmj?nY_NP01_nY_NP2ojZnj0GoZKgX
00?oZ[kXojVmionY_NL00_nY_NL00onZ_^SoZKgXojVmj006ojVmj0;oZKkX0_nY_NP01OnZ_^SoZKgX
ojVmj?nY_NSo000000?oZKgX00KoZ[kXojRlj?nX_>SoZ;cXojZnj?nY_NP2ojZnj003ooooool0003o
oooo00_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0002_ooooo002?ooooo`Go00000_ooool4ojVmj0;oZKkX0onZ_^P2ojZmi`;oZKcW00Co
ZKgXojVnj?nY_^SoZ[kX2?nY_NP01OnZ_^SoZKgXojZnj?nZ_^SoZKgX00;oZKkX0_nZ_^P00onY_NOo
ZKkXojVnj002ojZnj0GoZKgX0onY_^P7ojVmj003o`000?nY_NSoZ;gX00?oZ[kX00?oZ;cXojZnj?nZ
_^P00_nY_NP01?nZ_^SoZKgXooooool0000;ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000[ooooo`00SOooool2o`0000Gooooo0_nY_>L4
ojVmj003ojVnj?nY_>OoZKgW00;oZKgW00?oZ[gWojVmj?nY_NP00_nY_NP00onY_^SoZKgXojVmj002
ojVmj0;oZKkX1onY_NP00onZ_^SoZKgXojVnj004ojVmj003ojVnj?nY_NSoZKgX00KoZKgX00?oZKkX
ojVmj?nY_NP00onY_NP2ojZmj0;oZKgX00Go0000ojZnj?nX_NSoZ;gXojZnj002ojVnj008ojZnj?nY
_^SoZ[kXojZnj?nY_NSoZ[gXooooool0000:ooooo`;o00001?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0002_ooooo001[ooooo`;o00007Oooool3o`0000?ooooo00KoZKkY
oj^mion[_NOoZkgWojVlion[_NL3ojRki`05ojVmj?nZ_>OoZKcWojVlionY_NL01OnY_NP2ojZnj006
ojVmj?nZ_NSoZ[gXojZmj?nY_^SoZKcW0onZ_NP00onY_NSoZ[gWojVmj00<ojVmj003ojZnj?nY_NSo
ZKgX00CoZKgX00KoZ[gXojVmj?nY_NSoZKgXojZmj?nZ_^P2ojRmj003ojZnj?l0003oZKgX00;oZKgX
00?oZKkXojVmj?nY_NP00_nY_^P2ojZnj0;oZ[gX0_l0000:ooooo`03o`000?oooooooooo00?ooooo
0_l00004ooooo`;o0000;?ooool006[ooooo00Co0000oooooooooooo00006_ooool2o`0000Gooooo
00CoYk_WojVnjOnY_^WoZkgW0_nZ_nT2oj^mi`04ojRkion[_^SoZkkXojZli`?oZ[gX00?oZKgXojZn
jOnZ_^P00onZ_^P3ojVli`03ojZmj?nZ_^SoZ[kX00;oZKcW00?oZ[gXojZnj?nZ_^P00_nZ_NL<ojVm
j003ojZnj?nY_NSoZKgX00CoZKgX0_nZ_NP3ojVmj007ojZnj?nX_NSoZKgXojVmj?l0003oZ[kXojVm
j002ojZnj005ojVmj?nZ_^SoZKgXojVmj?nZ_^P01?nY_NP00ooooooo0000ooooo`12ooooo`00J_oo
ool01?l0003oooooooooool0000Gooooo`?o00000oooool01OnY_NSo[;kXojbnj?n/_^SoYk_W00?o
Yk_X00?oZ[oYojNlj?nZ_^P00_nZ_^P01On[_^SoZKgXojVmj?nZ_nSoZ[gX00;oZKkX0_nZ_^T01OnZ
_^SoZK_WojVkionY_>OoZ[gX00?oZ[kX00KoZ;cWojZmj?nZ_NSoZ[gXojZnj?nY_>P3ojZnj003ojVm
j?nZ_^SoZKgX00ooZKgX0onZ_^P2ojVmj0;oZ[kX0_nY_NP01?l0003oZKgXojVmj?nZ_^P2ojVmj0;o
Z[kX00?oZKgXojZnj?nY_NP01?nY_NP00ol0003oooooooooo`11ooooo`00J_ooool01?l0003ooooo
ooooool0000Eooooo`;o00000oooool00ol0003oZKcWojVli`02ojVmj005ojbnj?nY_^WoZKkYoj^m
ionW^nP00_nZ_NL2ojNlj005ojZnj?nY_>OoZKcWojVmj?n[_>H00_nX^nL00onY_^SoZ[_VojVkiP02
ojVkiP03ojVkionY_NOoZKgW00;oZ[gX00GoZ[kXoj^nj?nX_>OoZ;cWojZmj002ojZnj0;oZKcX00?o
Z[kXojVlj?nY_>P01?nZ_^P>ojVmj005ojZnj?nY_NSoZKgXojVmj?nZ_^P00onY_NP00ol0003oZKgX
ojVmj005ojVmj003ojZnj?nY_NSoZKgX00GoZKgX00?o0000ooooooooool0@?ooool006[ooooo00Co
0000oooooooooooo00004_ooool3o`0000Gooooo00?oZkoXojVlionZ_^P00onY_>L00onY_^WoYk_W
ojZoj@02ojZoj@03ojZmionZ_nSoZKcW00;oZKcW0_n[_^L2oj^liP05ojRkion[_>KoZ[_VojZki_nY
^nH00_nZ_NL00onY_NOoZ[oYoj^oj@02oj^oj@05oj^nj?nY_NSoZKgXojVmj?nZ_^P00_nY_NP2ojZn
j005ojVlj?nZ_^SoZKcXojVlj?nZ_^P02?nY_NP3ojZnj0coZKgX00?o0000ojVmj?nY_NP03OnY_NP0
0ooooooo0000ooooo`10ooooo`00J_ooool01?l0003oooooooooool0000@ooooo`;o00001?ooool0
1_n/_nSoYkWVojNii_nW^NKoZkoXojNhi@;oZ[kX00?oZKcWoj^nj?n[_^P00_nW^nL01?nZ_nWoYkWV
ojNii_nZ_nP3ojVoj@03oj^nionX`>[oZkkX00;oZkkX00GoZkcVoj^nj?n[_^SoZkkXojZmi`04ojZo
j@03oj^ojOnY_NSoZKgX00;oZKgX0_nZ_^P00onY_NSoZ[kXojVmj002ojVmj0CoZ[kX0_nY_NP3ojZm
j0CoZKgX0onZ_^P:ojVmj003ojVnj?l0003oZKgX00;oZKgX00?oZ[gXojVmj?nY_NP02_nY_NP00ol0
003oooooooooo`0oooooo`00Joooool2o`0000kooooo0ol00004ooooo`;oYkWV0_n/_nP01?nW^NKo
[L;Yojg2jOnW^>D3ojRjiP03oj^nj?nX^^Ko[;kW00;o[;kW00GoYkWVojboj?n/_nSoYkWVojVoj@02
ojJhiP;oZ<3Z00GoZkkXojRoj_nX_n[oZl3Yoj^nj002oj[0jP03ojZojOnZ_NSoZ[gW00;oZ[gW0_nY
_NP3ojZnj0;oZKgX0_nZ_^P4ojVmj003ojZnj?nY_>OoZKcW00;oZKgX00?oZ[gXojVmj?nY_NP00_nY
_NP2ojVnj003ojZnj?nY_NSoZKgX00CoZKgX0_nZ_NP3ojVmj003ojVnj?l0003oZKgX00;oZ[kX0_nZ
_NP3ojVmj003ojZmj?nY_NSoZKgX00;oZKgX00GoZ[kXojVmj?nY_NSoooooo`000010ooooo`00NOoo
ool2o`0000;ooooo00?o0000oooooonX_>P00_n[_>H00onW^NKo[KkWojJfi@02ojJfi@05ojg2jOnT
]>CoY;CTojk2jOnX^^H00_n^`>L2ojRjiP05ojbnionW^nSoYk_Xojboj?nW_NT00_n^`>L00onV^>Ko
[l3WojJhiP02ojJhiP05ojRoj_nX^nOoZ;_WojRmjOnZ`>X00_nY_>L2ojZmj0?oZ[gW00CoZKgXojZn
j?nZ_^SoZ[kX1onY_NP2ojZnj003ojVlionY_NSoZKgX00;oZ[kX1?nY_NP00onY_^SoZKgXojVmj003
ojVmj0;oZ[gX0_nY_NP02OnZ_NSoZ[kXojVmj?nZ_^SoZKcWo`000?nY_>OoZ[kXojVli`03ojVmj0;o
ZKcW0_nZ_NP3ojVmj006ojZnj?nY_NSoZKgXojVmj?oooooo0000?oooool007Kooooo0ol00004oooo
o`;oZKST0_nX_>P01On[_>KoZ[cWojfnion]_^OoY[KU00;o/LGY00KoY;CTok76jOnU]nGoYKOUojk0
ionY_NP3ojbmiP03ojNkj?nZ^nKoZ[_V00;oYkgY00Go[/3WojS0jon_`>Oo[l3WojJhiP02ojfoi`06
ojRkion[_NOoZkgWoj^mionY_>OoZ[cW1?nZ_NL01?nZ_NSoZ[kXojZnj?nZ_^P2ojVli`OoZKgX00Co
Z[kXojRlj?nY_NSoZ[kX3?nY_NP01OnZ_NSoZ[kXojZnj?nY_NSoZ[kX00;oZKgX0_nZ_^P00ol0003o
Z[kXojZnj002ojVli`04ojVmj?nZ_NSoZKcWojZmj0CoZKgX00GoZ[gXojVmj?nY_NSoZKgXojRmj002
o`0003oooooo001cooooo`?o00001?ooool3ojZmi`03ojVhi?n`a^[oYKGT00;oYKGT00GoZ[cWoj^l
i_nU^>KoYKSVok75j@02oj6di@;o/LKY00GoYKOUojg1j?nY_NSoZKgXojbmiP02ojc3jP05ojZki_n^
`^WoYk[WojNjionX`>/00_nU^^P2oj[1jP03ojfoion[`>WoZl3Y00?oZkgW00CoZ[gWojZlionZ_>Oo
Z[gW1?nZ_NP01?nZ_^SoZ[gWojVlionZ_nP3ojZmj0;oZKgX0_nZ_^P00onX_>SoZKgXojVmj002ojZn
j0coZKgX00CoZ[kXojVmj?nZ_^SoZ[kX1?nY_NP01_l0003oZ[kXojRlj?nX_>SoZ[kXojZmj0;oZKcW
0_nZ_NP3ojVmj004ojZmj?nY_NSoZKgXojVmj0;oZ;gX00?oooooo`000?ooool0?Oooool0077ooooo
0_l00005ooooo`;o[;WS00CoY[GSojZmionT]>CoY;CT0_n`a^X01?nU]NCo[/CZojk4j_n[_>H3ok74
j003oj6diOnban[oXkKV00;oXkKV00Go[L7Xoj_0jOnX^nOoZ;_Wojc3jP02ojBij0;o[/;Y00CoYk[W
ojg0j?nU^^SoZkkW0onV^nP00on[`>WoYkgYoj^oj002oj^oj005ojZmion[_^SoZkkXoj^nj?nZ_NP0
1?nZ_^P01OnZ_NOoZKkXojZoj?nZ_nSoZ[gX00;oZ[kX0_nY_NP01?nZ_^SoZKgXojVmj?nZ_^P8ojVm
j0;oZ[kX0onY_NP2ojZnj003ojVmj?nZ_^SoZKgX00CoZKgX00Co0000ojZnj?nX_>SoZ[kX0_nY_NP0
0onY_>OoZ[kXojZnj002ojZnj005ojVmj?nY_NOoZ[gWojZmionY_NP00_nZ_NP2ojRlj003o`000?oo
oooooooo03cooooo001^ooooo`Co00000_ooool01_nX^^KoZKOSojVghonY]n?o[;WSojZnj0;o/<;X
00?oY;CTokK7ionN[^800_nN[^801On^a>[oY;GUojBeiOnY_^Wo/LCX00;oXkOW0_nbanX01?nS]^Ko
[<7Yojc1jOn[`>T3ok34j@03ojBij?n[_^OoYkcY00;oYkcY00Go[L3XojVnjOn[_^OoZkkWojJkj002
ojVli`;oYkgY00GoZkoXojRmj?nZ_nWoZ[oYoj^nj002ojVmi`03ojZnj?nZ_NOoZKcW00;oZKcW00Go
ZKkXojRlionX_>OoZ;cWojZnj002ojVlj0;oZ[kX0_nY_NP2ojZnj0OoZKgX00?oZ[kXojVmj?nY_NP0
0_nY_NP00onZ_^SoZKgXojVmj006ojVmj005o`000?nY_NSoZKgXojZnj?nY_NP00_nX_>L3ojZnj0;o
Z;cW00KoZKgWojZmionZ_NOoZ[gWojZmj?nY_NP3ojRlj003o`000?oooooooooo03_ooooo001/oooo
o`;o00001?ooool01Ol0003o/l?VojRji_nX^^KoZKOS00;o[<G/0_nZ_^P01On``^SoXkOWokK7ionf
anOoWZkR00;o]<c/00GoY;GUojk5jon^`NSo[/7Xoj>gi`02ok76j@;oXkWX00Go[<7Yojc2j_n/`^[o
YK_Yok34j@02ojNlj0;oZkkW00CoYkcYojVmj?nY_NSoZKkY0onZ_^P00onY_>Oo[;oXojRjiP02ojRj
iP05ojRmj?nX^^KoZ;[VojRji_nY_NL00_n[_nP2ojZmi`05ojVlion[_NOoZkgWoj^mionX_>L00_n[
_^L00onY_>SoZ[gWojVmj002ojVmj004ojZmionY_^SoZKkXojVnj0GoZKgX0_nZ_NP3ojVmj0;oZ[kX
0onY_NP00onZ_^SoZKgXojZnj002ojVmj003o`000?nY_NSoZKgX00;oZKgX00?oZ;cWojVmj?n[_^P0
0_n[_^P00onX_>OoZKcXojZmi`04ojZmi`;oZKgX00CoZ;cXojRmj?oooooo0000??ooool006Wooooo
0ol00003ooooo`05ojBmjonW_NWoYkgYojNmjOnc`nH00_n/_^L00onS_ngo[<G/ojBkjP03ojbmiP05
oj>gion``^OoWkCWoindiondc>`00_nN/^H2ojk5j`04ojk1j?nV^nSo/LKYojNlj0?oZKkY00Go[<;Z
ojJjj?n[_nSoZkoXojNlj002ojRlj0;oZkoX00GoZKgXojZli_nZ_>KoZ;gXojZnj002ojNmj0;o[;oX
00GoZ;[Vojc3jon/`n_oZkcVojRjiP02ojc2jP03oj^oj?nY^nKoZ[gW00;oZ[gW00GoZkgWojZojOnZ
_nSoZ[oXoj^ni`02ojZnj0;oZ[gW00GoZKgXojRmj?nZ_NOoZ[gWojVnj006ojVmj003ojZmj?nY_>Oo
ZKgX00;oZKgX00GoZ[kXojZmj?nY_>OoZKcWojZnj002ojVli`;oZ[kX00?oZKgXo`000?nY_NP00_nY
_NP2ojRlj0;oZKgX00CoZkkXojVnj?nY_^SoZKcX1OnZ_NL3ojVmj003ojRmj?nX_NWo000003cooooo
001Wooooo`;o00001Oooool01?nU/^7oY;g[ojBmjonW_NT2ojZoj@04ojbniona`>GoY[WVojJiiP;o
Y;_Z00Co[;gVojS1jonX`N_o/<;W0_nU^nP01?neb^[oW[;Vojo5j_n_aNX2ojVnj@05ojJkj?n^`nWo
YkcXojNlj?nY_^T00_n/_^L2ojJjj004oj^oj?nZ_^SoZ;cXojVli`?oZ[kX00GoZ[cVojg1jOnX^^Ko
Z;[VojNmj002ojVli`;oYk[W00Go[<?[ojBgi_nT]nKoZKgXojc2jP02ojNii@;oZK_V00CoZ[gWojZo
jOnZ_nWoZ[oY0onY_NP00onZ_^SoZKgXoj^mi`02oj^mi`;oZ;gX0_n[_^P00onY_NSoZ[gWojZmi`03
ojVmj0?oZKcW00?oZKgXojZnj?nZ_^P00_nZ_NP01?nY_>OoZ[kXojVlion[_^P3ojVli`05o`000?nZ
_^SoZKgXojVmj?nX_>P00_nY_NP2oj^nj004ojVnj?nX_NSoZKgXojVmj0GoZ[gW00KoZKgXojZmionX
_NWoYkcXooooool0000kooooo`00I?ooool4o`0000;ooooo00KoY[CSoj^li_n[_>KoZkcVojFbhOne
b^X2ojBlj`03ojZojOnW_>SoYkcX00;o/L3U00GoY[WVoj^nionS^n[oXk_ZojS1j`02ojNnjP06ojFk
j?nbanWoX;GWoj2eion_aN[oZKoY0onW_NT01On^`nWoZKgXojVmj?nY_NSo[;kW00;oZkkX0_nY^nL0
1OnZ_^SoZKgXojVlionY_>OoZ[kX00;oYk[W0_n]`NT01?nX^^Ko[<7YojVlionX_NP3ojk2j005ojBg
i_n[`>Wo[L7Xojg1j?nW^ND00_nZ_NP2oj_0j@03ojZojOnZ_NSoZ[gX00KoZKgX00CoZkgWoj^nionX
_NSoZ;cX0onZ_NP01OnZ_NOoZkkXojZmionZ_NOoZKcW00GoZ[kX0_nY_>L01?nY_NSoZ[kXojRlj?nX
_>P2oj^nj0;oZKcW00?o0000ojZnj?nY_NP00_nY_>P2ojVmj0?oZkkW1?nX_NP00onZ_NOoZ[kXojZn
j002oj^mi`06ojZmion[_>OoYkcXojNlj?oooooo0000>_ooool006;ooooo0_l00004ooooo`;oZ[kX
0_nV]><01?n[_>KoX;KXoj2fj?neb^X3ojFii`03ojNlj?nY_nWo[<3Y00;o[<3Y00GoZkkWojRhiOnX
^>GoZ;SUojNnjP02oj>fiP;o//OY00GoX;GWojg1j?nY_nWoZKoYojNmj@02oj^mi`06ojRmj?nY_NSo
ZKcWojVlion[_^SoYk[W0on/_nP01_nY_NSoZl3Yoj_0jOn[`>WoYk[Wojk2j@?oY[SV00Go[<7YojJi
i_nX_NSoZ;gXojk2j002ojBhi`;oZl3Y00Co[L7XojJhi_nZ_NSo[<3X0on[_nP4ojZmj003ojVmj?nX
_NSoZ;gX00;oZKgX00GoZkkWojboj?nX_>SoZ;cXojZmj002ojVnj@;oZkkX00?oZ[gWojVnj?nZ_^P0
1OnY_>L01?nZ_^SoZ[gWojZmionX_>P2ojVli`;oZKkY00GoZKcWoj^miol0003oZKgXojVlj004ojVm
j005oj^nion[_NOoYkcXojNlj?nX_NP00_nX_^T01_nZ_^SoZKkYoj^nion[_^OoZkcWoj^ni`?oZ;_W
00?o0000ooooooooool0>?ooool005oooooo0ol00003ooooo`06ojNii_nY^NGoZKWUojViiOnZ_^So
W[3T0_n_an/01OnP]^So/L?Wok73ion[^nKoYKWW00;oYkgY0_nY_nT01On/`>WoZKkYojVnjOn[`N[o
Z;SU00;o/<K[00?oXkKVok;4j?nT^NP00_nT^NP01On]`NSoYk_WojNkionW^nOoZkgW00;o[;oX00Co
Z;cWojVlion[`>WoZl3Y0_nW^^L01On/_nSoZ[gWojZmionX^nOoZl3Y00;oYKWW0_n^`^T01?nV^>Ko
[l;Xojo2j?nV^NH3ojc0j003ojBhion[_nSoZkoX00;o[<3X00GoY[SVojZmion/`>So[<3Xoj^oj002
ojVmj0;oZ[gX0_nZ_^P00onX_NSoYk_WojVli`02ojVli`05ojboj?nY_>OoZKcWojVlionY_^T00_nX
^nL3ojVnj0CoZKcW0_nY_^P01_nZ_^SoZ[gWojZnj?nZ_^SoZKcWojbmi`?oYkcX00?oZkgWo`000?nY
_NP00onY_NP3ojVmi`;oZkgW0_nX^nL00onX_^WoYk_WojNki`02ojVnj@05oj^nionZ_^SoZkkWoj^n
ionX^nL00_n[_NH00ol0003oooooooooo`0gooooo`00GOooool2o`0000Cooooo0_n/_NL2ojNiiP04
ojViiOn``^Oo/<;Woij`i0?oWk3T00Go/L?WojZmionZ`>WoZ/3YojNmj@02oj[0j@;oZKkX00GoZKkY
oj^hh_n[^>;oXKOXok36j`02oj6gj0;o//CX00GoY;WXojZnj?nZ_^So[<7XojNki`02ojRli`06ojbo
j?nY^nOoZ;_WojRkion[`>WoYKSV0on[`NT01OnZ_NOoZKkYojVnjOn]`>SoYKWW00;o[L3X0_nU^NL0
1On_`^SoYkcXojNlj?n[_^So[<3X00;oYKWW00KoZkoXojc0j?nU^^SoYK[XojZmion/_^H3ojbni`03
ojVmj?nY_^WoZKkY00;oZ[kX0_nZ_NL2ojNki`05ojVlion[_NOoZkgWojZojOnY_>L00_n/`>P00onX
^nOoZl3YojVli`02ojVli`CoZ[oY00GoZKkXojVlj?nY_>SoZ;gXojZnj002ojVmj0;o[;gW0_nW_>P0
0on[_NOo0000ojVmj002ojRmj0;oZKgX00CoZKgWojVmj?n[_NOoZ[kX0on[_>H01OnW^nOoZ[_VojRl
j?nX_>SoZ[kX00;oZ;cX0_nZ_nT01?n[_NKo[<3Xooooool0000hooooo`00F_ooool3o`0000?ooooo
00Go[;oXojNhi_nW^>Ko[;gWojRhi@03ojJii`05ok32ionP/nGoX;?UokG:j_nO/>@00_nab>/2ojZm
i`04oj[0jOnW]^CoYkKToj[0j@?oZKSS00GoZkSRojo3jOn^_NGo[[gUoj6gj002oj^nj0;oZKkY00Go
Z[kXojboion/_nOoZ;cXojRli`02oj^oj0;oZK_W00GoZ;_Wojg1j?nU^>KoYKSVoj_1j@02ojNji`06
ojVnjOnZ_>KoYk_XojNkj?n]`>SoYkgY0on[_^L01OnW_>SoZ;_WojRkion]`NSoYKWW00;oZ[gX0_n/
`>P01OnU^^SoY[_Xojbni_n/_^Ko[;kW00;oZkcV00?oZKkYojRji_nZ_NL00_nZ_NL01_nX^NGoZ;[V
ojRji_nX^^KoZkgWojc0j0;oYk[W00?o[<3XojNjionW^^L00_n[`>T00onY_>OoZKgXojZoj@02ojZo
j@;oZKcW00KoZKcXojZlionX_>SoZ;cXojVmj?nX_>P3ojbmiP05ojNlj?n/_NOo0000ojbmionX_NP0
0_nX^nL3ojVmj004ojVnjOnZ_^SoZ[kXoj^liP;o[;oX0_nZ^nH01?nX_>SoZ[_UojRlj?n[^nD3ojNk
j003ojc0j?oooooo000003Sooooo000Zooooo`?o00001?ooool2o`0000Cooooo0_l0000Oooooo`;o
00000oooool00ol0003oYkWVojNiiP02ojboj005ojNhi_n/`NWo[<7YojRhiOnV^NL00_n]_^H01OnP
/nGo]/SXoi^^i?nK[^Co/LS[00;oYKSV0_n_a>X01OnW]^Co//KYok;6jOnW^nOoZKSS00;oZL;[0_n_
`nT01?n^_NGo[<;Zoj^nj?n/_nP3ojRmj005ojboion[_nSoYkWVojNii_n[_nP00_nW^NH2ojVnj@05
ojg1j?nV^nSo[/?Yojk3jOnW^^L00_n/`^X2ojZliP05ojNkj?n[_>KoYkgYojNmjOn[_^L00_n[`>T0
1_nX^nOo[[oWojNlj?nW_>SoZ[gXojbni`?oZ;gX00GoY[_XojfmiOn]_NGo[KgUoj^liP02ojjli0;o
Z;[V00GoZ[gWojVii?nX^NGoZ;WUojRjiP02oj_1j@06ojc0j?n/`NWo[<7Yojc1jOnW^^Oo[<7X0onX
^^H01?nY_NSoZkoXojZmj?nZ_NP3ojVli`04ojZlionX_>SoZKgXojVmj0;oZ;cX00Go[;gVojbni_n/
_^KoYkgYo`000002ojfni`05ojRkionZ_>KoZ;cXojRlj?nY_^T00_nW^nP2ojRoj`05ojboj?nX`Nco
Z<7/ojc0j?nZ^nD00_n]`^T2oj^ki@06ojNkj?nY^nKoYkcXojNlj?oooooo0000=oooool002_ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
01_ooooo0ol00003ooooo`;oYkcX00Co[;kWojNii_n]_nOo[KoW0_nT]ND01On/`NWoX[?Uoj:ciOnZ
`>[o[KkV00;oY;_Y0_nfb>P01?nK[^Co/l[[ojFhi_naaNP3oj2diP05ok;6jOnX_>SoX[OWoj:gionY
`^/00_nY`>X2ojS0j`05ojc2j_nX_NWo[;oXojboj?nX_NP00_nY^nH2oj^oj004ojNii_n]`nWoYkWV
ojg3jP?oZ[cW00GoY[_XojFhi_nU^>KoYKSVojc2jP02ojBhi`;oZl7Z00GoZkcVojg1j?nW^^OoYk[W
oj_0j@02ojFkj@04ojjoionW_>SoYkcXojNlj0;o[;kW00GoZ;gXojNkj?nW^nSoY[cYojfmi@02ojfo
i`05ojjli?n^_nKo[;[Tojbji?nY^N@00_n[`>T2oj^oj@05oj_1jOnY^NCoZKWTojNii_n/`NT00_nW
^>H2ojc1j004ojRji_n[_NOoZkoXojVmj0?oZK_W0_nY_>L2oj^mi`?oZKgX0_nW^nP01On/_^Ko[[oW
ojFij?l0003o[KkW00;oZkoY0_nZ_>H01?nX_>SoZ[cVojNkj?n[_NH3ojFii`06ojS1k?nU]nKoYkkZ
ojNnj_n]`^WoY[_X0on]`^T01_nY^nKo[L;YojVji_nY^^Koooooo`0003Kooooo000Sooooo`Go0000
0oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00006?ooool3o`0000Cooooo0_n[_^P00onW_>SoZKcWojNji`02ojNji`06ojfoionaaNWo/LGY
ok75jOnR/nGo[lO[0_nV^>H00onT^nWo[[oVojjoiP02oinfj005ok?:jonQ^>WoXKSYok75j?nP]>H0
0_n_`nP2ojRlj004oj:gion]`^[oZL3ZojVmj0?oZ;gX00GoZ;gYojVmj?n[_nSoZkoXojVkiP02ojk2
j@;oYKSV00Go[L?YojBgi_n]`n[o[L?ZojZli`02ojW0jP06ojfoionU^>Ko[[oWojjoionT^>Oo[KkV
0onU^^P01_n]`NSo[KoWojfoion]_nOoYK_YojFlj@;o[;kW00?oYkcXojNmjOnW_NT00_n/_NH01OnW
^nSoZ;_VojRki_nT_^co[KoW00;oZLC]0_n^_nH01?n/^^Co[<C/oj_0jOnZ^^D3ojbki@05ojVii?n[
`^_o[[kVojjni_nW^>H00_n^_^D2ojJji`05oj^mion]_^OoZKgXojVmj?nY^nL01?nY_>L01?n[_NOo
ZkkWojVmj?nX_>P3ojNji`05ojjoionW^NKo0000ojNii_n[_nT00_nW_>P01?n/`>SoZ[cVoj^oj?n[
_nP2oj^miP05ojFiion]_nOo[KoWojFgi_nW_^X00_nX^^H2ojJkj004ojg2jOnV^NOo[L;YojFhiP?o
[L?Z00?o0000ooooooooool0=?ooool002_ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo0_l00004ooooo`;oZ;cX0_nY_NP01On[
_^SoZKcWojVlionY_>OoYk[W00;oZkkW00CoXkKVok75jOnO/nKoWk?V0_n_an/01?nV^>KoZlG/ojjo
i_nX`nd3ok73j005oj6hjOn[_^OoZkkWojBkj_n_`nP00_n[`>T2ojBjj@05ojg2j_n[_nSoZKgXojVm
j?nX_NP00_nY_>L01_nY_NSoZkkWojJiionV^NOo[/;YojBhi`?o[lCY00GoY;OVojJhi_nV^>KoY[SV
ojW0jP02ojNiiP04ojRoj_n^_nOoZL3ZojW0jP;o[KkV00GoYK[XojVlionY_>OoYkkZojfoi`02ojfn
i`;oYKcY00Co[;kWojbmi_nW_NWoYK_Y0on/_nL01OnX^nKo[kkVoj6ciOnQ/nGoZLC]00;oX[7S0_nY
`^`01On/a>coY[?RojZjiOnZ^^Go[;_U00;oZlC/00KoZl;[ojjni_nZ`N_oZ/7[ojjniOn]_nL3ojNj
iP05ojfnion]_^KoYkcXojNlj?nY_>L00_nY_^P01?nZ_NSoZkkWojboj?n/_nP2ojRlj005ojNjion[
_NOo[<;Zojc2j_l000000_n]_nL01_nW_>SoZK_VojRoj_nX_n[oZkoXojVnj@?oZ[oY00Go[KoWojRo
jon/`NWo[<7YojRjiP02oj_2j`;oZkcV00GoY[WWojfni_nU^>KoYKSVojg3jP02ojJgi@03o`000?oo
oooooooo03?ooooo000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000Cooooo`?o00000_ooool01_l0003oZKcWoj^nj?n[_^SoZ;cXojVl
i`?oZkoX00GoZKcWojNkj?nW^nSoYk_Xoj^ni`02ojFjj004ok32ionO/nKo//GXok;5j0;oX;CW00Go
ZlG/oj>hj?nS^>SoZ<?]ok73j002ojW1j`06oj^nion[`NWoZ;gYojRmjOn[`>WoY[cY0on[_^P01On[
_nSoZKgXojVki_nY^nKoZKcW00;oZ[oX0_n[_^L01OnV^NOo[/;YojBhionT^>Oo[lCY00;oY;OW00Ko
[l?YojJhi_n^`^Wo[/;YojNii_n_`>L2ojFhiP03ojW0j_nU^nWoYK_Y00;o[<3X00GoZKcWojfnionU
_>[oYKcZojfni`02ojfmiP;oY[gZ00Go[;gVojnoi_nU^nWoYK_Yojboi`02ojW2k006ojnni_nQ/nGo
/<3Vok30i_nR/N?o//W[0onY]N401OnV/n;o[/K/ojc7kOn/angoZlC/00;oYkGS00CoY[[Woj[1jonT
^nWoY;_Y0_n]_nL01?nW^^KoZ[cVojfni_n]_>D3ojNmj@06ojVnj?nX_n[oZ[oYojZojOn/_nSoZK_W
0onV^>H01On[_NOo[lCYojBgiol0003o[KoW00;o[<?[00CoZK_VojRoj_nW^^KoYk[V0_nY_^T01?nZ
_nWoZ;cXojRojonW^^L3ojJlj@05oj_2jonT^>OoZl;[oj_2jon]_^H00_nY_^T2ojjoi`04ojJgiOn`
`nSoooooo`0003Cooooo000Zooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`00017ooooo0_l00004ooooo`;oZ;_W0_nY_>L01On[_^SoZKgXojVlionY_>OoZkoX
00;oZ;_W00KoZ;cXojNkj?nY_>OoZKcWojFjj?n[_>H2ojBkj@03ok;5j?nT_N_oY;g[00;o/<?X00Go
XkSXojk2j?n^`^SoY[_XojW1j`02ojFjj0;oZl7Y00GoZ;gYoj^mionV_>WoY[cYoj^nj002ojZoj006
ojVmj?nZ_nWoZ[oYojZojOnZ_nSoZK_V0onX_^T01On^`^WoYKSWojo3j?n_`nSoY;OW00;o[L3W00Co
YKWXojk2jOnU_>[oYKcZ0_n_`>L00onU^>Ko[KkVojFkj@04ojRmj005ojfnionU^^SoYK[XojFjj?n]
_NH00_n__nH2oj:jj@05ojnoi_n_a>[oYKKUojFfiOnY`^`00_nS]ND01?nW`Nco/<3VojFiionU^NL2
ok;9j`04ojVehOnY^nKo[/K/ojjni@?oZ;CQ00KoYkGSojfih_n/^^?o[;[SojBkjOnT^^T3ojZli`05
ojZli_n[_^Oo[KcUojfliOnW_NT00_nV^>D01?nX_n[oZ[oYojVlionY_>L2ojVki`09ojJhi_nY_^So
[lCYojJiionY_>So0000ojVlj?n/`n_oY;OV00;o[/;Y00?oYk[Vojc0j?n/`>P00_nY_>L01OnX_>So
ZkcVojNjionW^^OoY[cY00;oZ[cW0_nT^>L01?n[`^_oYKKUojVnjOnY^^H3ojRji`03ok33j?nX^>Co
000003Cooooo000[ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00003oooool3o`00
00?ooooo00CoZ[gXojZnj?nZ_^SoZ;_W0_nX_>P2oj^oj005ojVmj?nX^nOo[;oXojboj?nX^nL00_nY
_NP01?nW_>SoZKcWojW1jonY`N/2oj^liP04ojBkjOn/_^Oo[;kWojBmj`?oYkk[00Go[/;XojVnj?n[
_NOoZkgWojFjj002ojZli`;oZ;cX00GoZkgWoj_0jOnW^^OoYk[WojZoj002ojVki`03ojNkj?nZ_nWo
ZK_V00?oZK_V00CoZ;kYoj^li_n[_>KoYKSW0onU^^P01On]`>OoZKoZoj^mi_n[_NKoYKcZ00;oY[[W
0_nY`>X00on]_^Ko[KoWojRmj002ojRmj0;oZ;_W00Ko[KkVojFjj?nT^NSoY;WXojnoi_n_a>T3ojBg
i`06ojo4j_na`nOo/L?Wok73ionS]NGo[lGZ0_nS]>D00onU^NOo/l[[oif/h@02oif/h@05ojVki_nd
bNWo[[kUojjniOnX]>400_n[]n801?n]^N;o[;[Sok6mhona_N<2ojBjj@04ojZlionY^^GoZK[Uoj^n
i`?o/;kT00GoY[SUojjkhon^^n?oYkOTojVli`02ojVjiP;oYk[W00GoZKkXojk3jOnV^NOoY[WWo`00
0002ojo4j@06ojBgi_nW^nSoYk_XojNkj?n/`>SoZ;cX0on[_nP01On[_>KoZkoYojZnj?nZ_^SoZ[cW
00;oYkkZ00Co[L;YojFfiOn/`n[o[<?Z0_nY^^H01_nX^^Oo[/7XojRhi?naan[oooooo`0003?ooooo
0016ooooo`;o00001?ooool2ojVmj0;oZ[gX00CoZ[kXojNkionX_>SoZkoX0onY_NL01_nX^nOoYk[V
ojNji_nW^^KoZKgXojVnj@?oY[[W00GoZL7[oj>hion/a>co[<C/ojbni`02ojg2j@04ojRmj?nW_^_o
Z;cXojRlj0;oZKkX00CoZkgWojZnj?nZ_>OoZkoX0onW^^H01On[`>WoY[WWojc1jOn/`NWoZK_W00;o
ZKkY00CoZl3YojVki_nY`^_oZL;[0_n]`^T01On[_>KoZ;cXojRlj?n^`^WoYK[X00;oZKcW0_nY_nX0
1?n[_NKo[/3WojJjion/_^L3ojFljP05ojfoion]_^KoZ;kYojRnjOnX^nL00_nZ_>L01?n/_nSoY;WX
ojNlj?nW_>P2ojo4j@05ojBgion^`^SoX[CVoj:di_na`nL00_nW]n@2ojo5jP05oj>diOnW^nOo/l[[
ok?:jonM[>400_n[^N<01_ndbNWoY;?SojBchonT/n?oZkORojbjh`;o[[_S00?o/KgSok?3i_nc`nH0
0_nS_>/01OnY^^Go[[cTojS2k?nX`^co/;kT00;o[l?Y00Go[[_Sojg3j_n/_NKo[;gVojVjiP02oj[2
j`;oZl;[00Go[/?YojNjionX_>So0000ojo4j@02ojFhiP04ojboj?nW^nSoZ[cWojZli`;oZ;cX00Co
ZkoXojRjion[_nWoZK_V0onX_>P01_nW_^[oZ;cWoj>gionS]nOo[<?ZojBhi`;oZKcW00?o[/7XojJf
i?nV]^@00_naanX00ooooooo0000ooooo`0aooooo`00@oooool3o`0000;ooooo00?o0000ojVmj?nY
_NP00_nY_NP4ojZnj005ojNkionX_NSoZ;gXoj^oj?nY_NL00_nX_>L01?n/`>SoYk[Voj^mion[_NL2
ojVnj@04ojJjion^`nWo[/?Yoj>hi`?oXkSX00Go[L;YojNlj?nW_>SoZkgWojRlj002ojZliP;oYkgX
00GoZ[kXojRmj?n[_nSoZkoXojNjiP02ojk2j006ojJiionV^NKoY[WVojJii_nY_^WoZ[_V0_nU^NL0
0onY`^_oZKWUojJhiP02ojJhiP05ojRlj?n^`^Wo[/;YojNlj?nY_>L00_n^`>L2ojFkj@05ojk0ionY
_^So[;kWojbnionU_>X00_nU^^P01_n]_^KoY;_YojBkjOnT^nWoZ[cWojg3jP;oZ;gY00?oYkcXojk4
jOnT]ND00_nT]ND01On^`^SoY;OVojg4jon]a>_oYkOT00;o]<SY00CoXK?UojNkionc`nKo/l?V0_nG
[>D01On[^N?o]koPoj_3jon[`n_oY;?S00;oYkWV0_n/^^<01?n^^n?o/<3Vok?3i_ncbNX3oij_h`05
ojjli?nhb>OoX;?Voj2ci_n_`nT00_nV_^/01_n]`n[o[;gVoj_4kOn[a>goZ/;[ojZnj0;oZ[gW00Oo
Yk[WojVmj?nY_NSo0000ojk2jOnU^>KoZ[oX00;oZ[gX00?oZ[cWojZnj?nZ_^P00_n[_^L01OnX^^Oo
[<7YojVki_nY^nKoZ;cX00;oZkoX00CoZ;cWoj>gion]`n_o[L?[0_nT^>L01?nY_>Oo[LCZojJfi?nd
c>`3ojNdhP03o`000?oooooooooo033ooooo0011ooooo`;o00001?ooool3ojVmj0CoZKkX00GoZ[kX
ojRlj?nX_>SoZ;cXojRmj002ojZmj004ojVlionX_>Oo[<7Yojc1j@;oY[WW00GoZkgWojc1jOnT^NOo
Y;WWojk3j@02ojBjj@06ok32ionS^>So[;oWojboionW_>SoYk_X0_n[_nP00onZ_>Ko[<3XojRiiP02
ojRiiP05ojRmj?nY_>OoY[_XojJkj?n^`^P00_nV^NL01?n]`^WoY[WVojc3j_n/`nX2ojZkiP05ojFi
ion]_^KoZKWUojViiOnV^>H00_n[`>T01On^`^WoZ;gXojJkj?nV^nSo[/3W00;oZkgW0_nX_NT01OnY
_^SoZK_Vojboj?n/_nSoYK[X00;oY[[W00Co[l7WojBkjOnS]nOoXkOW0_n]`nX01OnX_NWoY[SVojk4
jOn^a>WoY;GU00;o[lK[00KoY;OVoinbiOnO/^GoWk;UokC8jOnS^^T2ojNki`03ok?3i_nT_>[oW[3U
00;oW[3U00Go]koPokbkf?nI]^coVKK/ojNiiP02ojG4k`;o[/7W00So/<3Vok??k_ncbN[o/lWZoij_
honV]N?o^<SWoj[0j@?oZk_U00GoY[k[ojNii_nW_n_oYko[oj_4k@02ojRjiP;oZ[kX00GoZ[gWojNi
i_nY_NSo[KoWo`000002ojJgi@06ojZoj?nX_>SoZ;cXojRlj?nZ_^SoZKkX0_nX_>P00on/`NWoYk[W
ojNji`02oj_1j@05oj^oj?nX_>SoY[gZojJmj_n]`n/00_nS^>P01?nW_>So[LCZoj6bi?nQ/^@2okC<
k004ojNdh_ndbN[oooooo`00037ooooo000nooooo`?o00000oooool5ojVmj0CoZKkX0_nY_NL01_nY
_>OoZ;cXojVnj?nY_^SoZ[gXojNki`;oZKgW00?o[<7YojBhion[_NL00_n[_NL01On/`NWoY;WXojk1
j?n^`NSoY;[Y00;oZKgX00CoZKkYojboion[_NOoZkgW0_nW^nP01On[_nSoYk_Wojc0j?n/`>SoZ;WV
00;o[L;Y00KoZKcWojboj?n/_nSo[;oXojJiion^`nT2ojBgiP03ojc3j_nS]nOoXkOW00;oZl;[00Go
[KkVojW1jonY_nWoZKoYoj_0j@02ojc1j@;oZ;gX00CoY[_XojVmj?n[_NOo[;_U0onX_^T01OnY^nKo
[KgVojRoj_nX_n[oY[[W00;oZkkX00Co[L3Xoj>gion]`NSo[L7X0_nX^^H01OnV^>Ko/L?Xoj6di_nQ
]>Ko[lK[00;oX[?T00Co/<CYoinbiOn__>?o[kcS0_nS^^T01OnW^nOo[KgUojBlj_nT_>[oW[3U00;o
Y;KV00Go_;_HoiNUgonGYMooUjGOojG4k`02oijai@03ojcBm?nccnkoZZkJ00?oWZSM00GoY[GSokK>
k?nZ`>WoZ/3Yoj^ki@02ok;:k005ojNii_n[^^GoZk[Uoj^jiOnX^^H00_n/_NH02?nY^^GoYkWVoj_2
j_n[`^[o[KoWo`000?nV]nGo[<?Z0_nY_>L00onX_>SoZ[kXojZnj002ojVnj004ojRlj?n/`>SoYk[W
ojc1j@;oZK_V00?oZ;cXojZnj?nZ_^P00_nZ_NP01OnS^>SoYKcYojg4jon]a>_oXK;T00;o]<WZ0_nP
[n<01?ndbN[oYkKSooooool0000`ooooo`00??ooool2o`0000?ooooo00CoZKgXojZmionZ_NOoZKgX
0_nY_NL2ojVmj005ojVnj?nY_>OoZKgXojVmj?nY_NL00onY_NP00onY_^SoZ;cWojRli`02ojNki`05
ojVmion]`^WoY;SWojBhion[_NL00_n_`nT01OnT^NSoZKoYojVojOnY_nWoZKgX00;oZkkW00CoZ;gX
oj^mionY_nWoZKoY0_nZ_>H01OnW^nOo[;oXojFiionU^NOo[L;Y00;oY[SV00CoZKoYojboj?nW^^Oo
Yk[W0_n^`nT01?nT]nKo/<;Xoj>gion^_nH3ojBjj005ojW1jonV_>WoZ/3Zoj[0j_n/`NT00_nY_NP0
1?nW_NWoZKgXojRlionX_>L2ojbki@04ojRnjOnS^nWo[KgVok74j0?oY;KV00GoZkkXojc1jOnV^>Ko
Y[SVojg1j002ojNii@;oYko[00Go/L?XojJljOn`_nKo/;oVoj:ci002ok2lh`04oj6lk?n__>?o/[gR
ok:mhP;oX[KW00Ko[KgUojnlhonH[nOoV:oWojBfi_nM`O42ol2gd@05oiNUgon]YLoo[JG?oijaiOna
Y/d00_nTXm@2ojZ^fP05oijXgOn[`>WoZl3YokK>k?nZ_>H00_nT]nH01Onbb^coXkSXoj>hj?n_`nWo
Zk[U00;o[<7Y00Go[;gVojVojOnY`^_oZL;[oj_2jP02ojNjiP04o`000?nW_NWo[<?ZojJiiP;oZ/3Z
0onZ_^P01?nX_>So[<3XojNii_nW^NH2ojc1j@04ojVki_n/_nSoZ[kXojVkiP?oYkcX00KoYKcYoijb
i_nN/^KoW[;VokC9j_nP]>H2ok?4i`04ojNfhonc`>?o/l3So`00033ooooo000iooooo`?o00000_oo
ool00ol0003oZKgXojVmj002ojVmj004ojZmionZ_NSoZKgWojZmj0?oZ[gW00?oZKcWojVmj?nY_NP0
0_nY_NP2ojVnj@04ojZnj?nX_>OoYk_WojNki`;oZ[gX00Go[L;YojBhionY_NSoZKgXojo3j@02ojJj
j006oj^nj?nY_nWoYkcXojNlj?n[_^OoZkoX0_nX^nL00onY_nWoYKSWojZoj@02ojZoj@05ojboj?nW
_>So[L7Xojg1j?nV^>H00_n]`NT01?nX^nOoYk[Wojo3j?n_`nP2oj>fi`05ok32j?nV_N[o[[oVojjo
i_nT^^P00_n/_NH01OnV_>WoZKkXojVnj?nY_^SoZKgX00;oZK_V00CoYkgYojRlionW_^_oYkk[0_n`
_nD01OnS^nWoXkOWok74j?naa>SoY;KV00;oZ[oY00Ko[<7YojJhi_n]`^Wo[L;YojNiiOn_a>T2ojRh
i@03ojJljOnV^>KoYko[00;oYko[00Go/;cSokBoh_nK]n_oVkO[ok:mhP02ok2jh@03ojFnjon__>?o
[;gW00?oVjKM0_nM`O401?o0]m7o[JG?ojfUcon]YLl3ok6Vc@07ojBSe?nd`>?oZkWToj^ii?n[`>Wo
]m;^ojZliP02ojNlj0;o/lOY00GoXkSXojZjiOnW_>SoYkcXojc1j@02ojNiiP;oZKoY00SoZL;[ojVj
i_nW^^KoZl7Zojbniol0003oY[WVojg1j@?oZ;[V00GoZ[kXojRki_n[_nSoZkoXojNiiP02ojg2j@;o
YkWV00Ko[;oXoj^oj?nY^nKoZK_VojNlj?nX_^T2oj^oj003oijbi_n^`nWo[/?Y00;oX;CV00?o/lCW
ojW1jonc`><00_n`bN`00ol0003oooooooooo`06ooooo`;o00009Oooool003Oooooo0_l00003oooo
o`;oZKgX0_nY_NL01OnY_NSoZKcXojVnj?nY_^SoZ[gX00;oZKkX00?oZ[gXojZmionY_NP01?nY_NP2
ojVnj@06ojRkionW^^OoYk[WojNjionW^nOoZ[oY0_n^`^P01OnT^>OoZ;cXojRlj?n_`^SoY[[X00;o
ZKgX0_n[_nP01OnW_>SoZ;_Woj^oj?n[_nSoZ;_W00;o[L7Y00KoYKSWojZojOnX^nOoZ;_WojNlj?n/
`>P2ojFhi`05ojg1jOnX_>SoYk_WojNkion_`nP00_nT^^P2ojfni`05ojJmj_nU^^So[<3Yojc0jOn/
_NH00_n]_nL01_nZ_NSoZKkXojVlionY_>OoZK_VojbmiP;oYK[X00?oYkk[ojBij?nT^NP00_n`aNT0
1OnS]nOo[/7XojFhi_nU^>KoZ[oY00;oZkcV00CoY;OVojg2jOnT_>[oY;cZ0_n_a>T01OnX^>Go[KkV
ojJhi_nV^>KoYko[00;oX;[[00Ko];oRoiRhk_nH^>koV;S^ok2jhOng_n02oijjk0;o[;gW00CoVjKM
okB`eOnd/=GoNJ;/0_o4`mT01_n]YLooal?FolO3e_naY/go`^;_okC0h`;o/M_f00Ko/mceojNchOnT
]NGoY;GUojNlj?n_an/3ojVkiP05ojZjiOn^`nWoZkgWoj^mionW^NH00_n]a>/01?n/_^OoZK[VojW1
jonY`N/2oj_1jP05o`000?nX_^Wo[L7Yojg1jOnX^^H00_n/`^X01OnX^nKoY[[WojJjionV^^Oo[L;Y
00;oY[[W0_n[_nP2ojNjiP;o[<7Y00GoZ;kYojRkionS]nOoXkOWojk3j@02ojBij007ojRji_nY`N_o
Xk7Roj>ah_n`bNcoZ:oLo`000007ooooo`04o`000?ooooooooooo`0002Cooooo000dooooo`?o0000
1?ooool00onY_>OoZKgXojRlj003ojZnj005ojVlj?nZ_NOoZ;gXojRmj?nY_^P02?nY_NP01OnY_^Wo
ZKcWojRkionX^nOoYk[W00;oZ;gX00KoZ[oYojFjj?nU^^SoYK[XojRlj?n]`>P2ojRlj003ojVmj?n[
_^SoZkkX00;oZKkX00GoZ;_Wojc0j?nV^NOoY[WWojg1j@02ojBhi`04ojg2j_nX^nOoZkkXoj^nj0;o
[<3X00GoYKSWojg1j?nX_>SoZ;cXojNki`02ojk1j006ojBjj?n^`NSo[/7Xojk1j?nU^^SoZ[kX0_nW
_NT01On]_nOo[;kVojbni_n[_nSoZKcW00;oZ;[V0_n/_NH01?nU^^SoZ;WUojBij?n^_ND3ojBhi`06
ojk1j?n/`^[o[<;Zojc2j_n[_>KoZ<;/0_n]_ND00onT_>[oZK[UojVji@02oj>lj`05ojfni_nY_>Oo
[[gUojjmiOnP^^/00_nN]>L00ond_^7oV;S^oi6Xi@03okNoh006oijjk?nLY=_oSkogohnomond/=Go
b^k/0_n9PlL2ogaf`@06olO3e_nRj_[oX^[jol;RkonR/nGo/M_f0_na^Ml2ojNch@05ojBeiOnZ_^So
[lO[ojo7jonY^nH00_nX_NT01_n^`nWoZ;kZojRnj_nX_^[o[LC[ojNhi@;oZKkY00OoZL7[ojVjiOnY
^^GoYkWVo`000?nX_^WoZ[_V00;oY[[X00Go[<;ZojFhion]`n_o[L?[ojJji`02ojc1j@06ojJjionZ
_NOoZkoXoj^oj?nW^^Ko[L7Y0_n[_NL00onX^nOoY[cYojJlj@02oj[0j@06ojBij?nS]^Ko/<[]ok3:
kOnS/N;o^=3/0_nX[m`00ooooooo0000ooooo`05ooooo`04o`000?ooooooooooo`0002Cooooo000a
ooooo`Co00000oooool01?nY_NOoZKgXojVmj?nY_>L2oj^nj006ojRlj?nZ_^SoZKgXojVmj?nZ_NOo
Z[kX1onY_NP2ojVmi`?oZKcW00CoZKgXojRlj?nX_>SoZ;gX0_nZ`>T01?n/_nSoYK[XojRlj?nX_>P2
ojg0j004ojRlj?nY_>OoZkkXoj^nj0?oY[WW00Go[<3XojFiion^`nWo[/?YojBhi`02ojk2j004ojBh
i_n[_^So[<7Yojc1j@;oYKWW00Go[L7XojZojOnV^^OoY[[Wojk1j002ojVoj@05ojNkj?n^`NSoZKkY
ojVnjOnZ_^P00onW^^L01On/_^Ko[l7Wojo1ionW^nOoZ;[V00;oZKcW0_n]_^H01OnX^NGoZl7Zojjm
iOn^_NGoY;SW00;oZl7Y00CoY[WVojc2j_nU]^GoYKKU0_nX`^`01?n]_NGo/<;XojVjiOn^_ND3oj:i
j@06ojVlion``>Ko/<3Vok30i_nN]>OoXK7S0_ni`n82oi6Xi@04okNoh?noe>[o_mCZoibTf`?oMGo?
0_o:k^`01?n9PlOoj>g@ogaf`OmlM/43oifGc@04oj:ciOo4e>Ko/KWOok38j`;o[;kW00?oZ[kXok2m
hon`_N<00_nT/^801OnX_NWo[;oXojRlionX_>OoZ;kZ00;oZkcV00WoYkSUojboion/_nOo[;oWojVj
iOnY_nWo[;oXo`000?nZ^nH00_n[`NX2ojbni`05ojFhion]_nOoYKSVojFhi_n/`NT00_nW^nL01?nZ
_NOoZkoXojNii_nW^NH2ojg1j@04oj^mionZ_>OoY[cYojRlj0?oY[_Y00CoXkKVoi^[h_nKZn;oVj_R
0_nhd>`01?nX[mco^/gYooooool00005ooooo`04o`000?ooooooooooo`0002Cooooo000_ooooo`;o
00000oooool01_nY_NSoZKcWojVlionY_>OoZKgWojZnj0;oZ;cX00?oZkkXojVmj?nY_NP00_nY_NP2
ojRmj0;oZ[kX1onY_NP00onY_NOoZKgXojVmj002ojVmj0?oZKoY00?oZ/3YojRlj?nX_>P00_nX_>P2
oj^oj0;oZKkX00GoZKcWoj^nj?n[_^SoZkkXojJii`02ojc2j@06ojFiionT^>OoY;SWojBhion^`^So
YK[X0_n[_^P00on/`NWoY;WWojBii`02ojboj005ojZojOnU^nSo[;kWojbnionY_nT00_nU_>X01_n/
_^OoZKkYojRkionX^nOoZ[oXojNji`;oZ[cW00Go[l7Woj^nionV^>KoY[SVojVli`02oj_3k0;oZ<;/
00GoZl7ZojFfiOn/_^Oo[;kWoj_1j@02oj>gi`04ojo4j_nU]^Go/KkTok6ni0;oXK[[00Go/<;XojRn
jOn^_NGo[[gUoj:ij@02oj:mk004ojVjiOn``>KoZLC]ojW4k@;oXK7S00Co^L?Rojg<l?nL[N?o_=C/
0_nCVMH2ol;?i004ogEocoo@i>GoIfW1ofMY`@;oj>g@00KoO7K1on3mbooPoL_oWIO=okKki?o4e>H2
ojcBm0;o/<S[00?o[;kWojfmiOn`_N<00_nZanl2ok3<kP05ojboj?nY_NSo[<3Xojc0j?n[_>H00_nW
_>P01?n^aN_o[;oWojNkionW^nL2ojVoj@04o`000?nX_n[oZl7ZojNji`;oZKoZ00?o[KoWojW0jonY
`>/00_n]_nL01OnW^nOoZ;_Wojc1jOn/`NWoYkWV00;o[/?Y00CoZKcWojZlion]`NSo[L7X0_nX_>P0
1OnV^nWoXKSYok;9jonbbN_oVj_R00;o]/g[00GoVJ_Soj^cgon[/mooZk?Oo`000005ooooo`04o`00
0?ooooooooooo`0002Cooooo000/ooooo`?o00001?ooool2ojVli`06ojVmj?nY_>OoZKgXojVmj?nZ
_^SoZ;cX0_nZ_^P3ojVmj004ojZnj?nX_NSoZ[kXojZnj0OoZKgX0_nX_NP01_nY_^SoZKgXojVnjOnY
_^WoZKoYojVmj0;oZ[gX00GoZ;cXojVlionX_>SoZ;cXoj^oj002oj^nj0;oYk[W00GoZkkXoj^mionV
^^OoY[[Wojc2j@02oj>gi`04ojo3jOnT^>Oo[/3Wojk0i`;oYK[X00CoZkkXojk1j?nT^NOoZ[gW0on/
`>P01OnU^nSo[KoVojfoi_n]_nKoYKcZ00;oY;_Y00Ko[;kWojRkion/_>Ko[;cVojJnjonZ_>L2ojk2
j@;oZkkW00CoY[SVojW1j_n[`ncoZKOS0onV]N@01OnU]^Go[L?Zojk4j_n^a>[oXkOW00;o[[oV00Co
X[[Zok6ni?nb_nCo/[oT0_nU^nT01_nX_^WoYKWWojjoi_n^_nKoX[g/oi^cj@;o[KcU00CoZLC]oiJ^
ionF[^Oo[KkV0on@XMl2okcDk004oi>Ie_n1SMKoPHgFoh6=eP;od>CU00CoIfW1om[`h?mlPLcoO87<
0on0RmD2oiRRf`03ojcBm?nPXmSoX:?H00;oY[;P00Co[KgUojc9konZanoo[;SR0_nS/N800onY_NSo
Zk_Uoj^ki@02ojRmj@05ojNlj?n`a>WoYkOTojNgi?nW^nL00_n[`^X01?nX_^Wo0000ojZjiOnZ^^D2
ojNji`04ojVoj_nW^NKoZL3[ojJgiP?oZl7Z00KoZ;_WojFhionU^>OoYKSWojk3jOnX^^L2ojVmj003
ojg1j?nZ_NOoZ[gW00;oYkWV00KoXKSYojboionK[nKoVjoVokK=jonN/ND2ojo9k@03oj^cgonlcNOo
_<gW00;o00000oooool01?l0003oooooooooool0000Tooooo`00:_ooool2o`0000Cooooo00CoZKgX
ojVlionY_>OoZKcW0_n[_^P01?nX_>SoZKgXojZnj?nZ_^P2ojRlj004ojZnj?nY_NSoZKgXojZnj0?o
ZKgX0_nZ_^P3ojVmj004ojZmj?nY_>SoZKcXojRmj0;oZKcW00CoZ;gXojVnjOnY_>SoZKcX0_nY_NP0
1OnZ_NSoZKgXojVlionY_>OoZ;cX00;oZkoY00KoZkkXojc2j_n/`^[o[<;Zoj^mionY_nT2ojg0i`05
oj>gion^`>Oo[/3WojBhion^`>L00_nY_nT2ojRli`05ojk1j?nV_>WoZ[gWojZmion/`>P00_nX_NT0
1OnW_NWo[KoVojfmiOn]_NGoY;_Y00;oYK[X00KoZ/3Zojbli_n``NOo/<7Woj6fion^`^T2ojVli`;o
Y[SV00GoZL7Zojbji?nY]n?oZKOSojJei002ojRnjP06ojg3j_nS^>OoXkSWoj>hion^_nKo[[kV0_nQ
^NX00onb_nCo/[kSok:nh`02ojNnjP06ojFiionX^NGo/LCXok74j?nK/nWoW[CX0_nhbnT01_nF[^Oo
W[c^oijlk_nlb^GoT:7Ook[9iP?oQXS>00?o`mWYoh6=e_o7l^h00om[J;d01OoJl>3oO87<on7mb?oQ
oLSoP8_E00;ogoKJ00?oV:;KolGGionPXmP00_nbd_001?naeoCo[<W_ojZhhonZ^><2ojbhhP04oj>a
h_n_aN_oZk_Uojo7k0?oYk[W00Wo/<CYojBgi_n[_nSoZkoXoj_2j_nX^^KoZK_Vo`000?nZ^^D00_n[
`NT2ojbni`06ojNii_n]_nOoY[OVojJgi_n[`N[oY[SV0_n/`^T01OnU^>Oo[L7Yojg1jOnX^^OoZ[gW
00;o[<3Y00GoZ[gWojJkj?nY`>[oZL3Zojboi`02oj>giP;o[lS/00SoW[7Uok39kOnI]N_oVKG[okc=
ion/^^Coooooo`0000Cooooo0_l0000Uooooo`009oooool4o`0000;ooooo0onY_>L01OnY_NSoZ;gX
ojRmj?nZ_^SoZkkX00;oZ;gX0_nZ_^P2ojVmj0;oZ[kX0_nY_NP2ojZnj0?oZKgX00GoZ[kXojVmj?nY
_NSoZKgXojZmj002ojVmj006ojZnj?nY_>OoZ[kXojZnj?nZ_NOoZKcX1OnY_NP3ojRmj005oj^ojOnY
^^KoZK[VojJjion/`^X00_nV^>H01_nY_nWoZK[VojNmjOnW_NWo[/3WojNnjP;oZkgW00?oZKoYojFk
jOnU^nT00_n]_nL2ojJlj@;o[KoW00GoZ;gYojNjionW^^OoZ;gYojfmi@02ojnoiP06ojFjj?n[_>Ko
Y;WXojBij?n``NOoZ;gY0_n/_nP00onY_>OoY[cYojJlj@02ojk2j005ojbji?nZ`ncoZ;kYojRnjOnX
_^X00_n/`n/01?n^`nWoXkSWojNkionW^nL2ojjniP04oj6ij_nQ_Ngo/[kSokK1h`;oX[?T00?oZ;WU
ok;5j?nV/^400_nV/^401_nN]>SoXjgNoj>]g_nS[MkoW[c^oj:Vf@;oWZKL0_njbNH01_n6R<kocnWX
ohN8c_n7R<koD5>folObkP;oJfRm0_moO<H3ohRCf0;oVjCK00GoaMOWoiJTgonFY=oo/];`okK0hP02
ojF`g`03ojZhhonZb>ooZ/S_00;oZLO_00So[lG[ojFjj?n_anco[lO/ojNjion_aN[oY;OVoj_2jP?o
[/7X00GoZ;[Vo`000?l0003oZL3Zoj_1j@02ojRmj@04ojW0j_n]_nOoYkkZojNnjP;o[/7X00SoY[SV
ojk3jOnU^>KoYKSVojg1jOnX_>SoZ[gWojg1j@?oZK[V00KoY[_XojNii_nW^NKoYkWVoj>gi_n``NH2
oijbi`03ok39kOnV]nGoY[OU00;oXl3^00?o[;[Tooooool00000:oooool002Gooooo0_l00004oooo
o`;oZKgX00KoZK_WojVlion[_nSoZkoXojRmj?nZ_^P2ojVmj003ojRmj?nY_NSoZKgX00?oZKgX00Go
Z[kXojVmj?nY_NSoZKgXojZnj003ojVmj0;oZ[kX1OnY_NP01OnY_>SoZKkXojVnj?nZ_^SoZKgX00?o
Z[kX1?nY_NP01OnX_NSoZKkXojZmionZ_NOoZK[V00;oZL7[00Co[/3WojJhi_n^`NSo[/7X0_nY^^H0
2?nW_NWoZ;_WojNnj_nW_^[oZkgWojk0ionU^nWoZ;gX0on/_^L01OnV_>WoYkkZojfmi_n]_NKoYk[W
00;oZk_U00CoY;g[ojnoi_n]`n[o[L?Z0_n[_>H02?nT^NSoZ[gWojRmjOnX_NWo[;oXojVlionV_>Wo
ZK[U0onU_>X01OnZ`ncoYKgZojW1jonY`N_o[<?[00;oZkoX00KoY;[YojNkionY_^WoZKkYojfmiOnQ
_Nd2oi^dj@;o]/7S00GoX[?TojJdhonbaNSo//GXojJbh@02ojbjh`04ojo4jOnS[Mko^]?/ok[Ck0;o
XZKI00CoWZKLokZngOmcT^?oLi;S0_o?jNP01?n7R<koe/gAoe1C]_m[J;d2oe9D]P03ogmla_mhN/So
R9?H00;ofOKP00?oVjCKolOVkOnFY=l00_nmi?82okK0hP03ojF`gon^b>goZ/S_00;oZ;GR00CoYKCS
ojFjj?n__^Co[kkT0_nS]ND01?n_aN[oY;KVoj_2j_n[`^X3o`000006ojVlj?l0003oZKgXojVmj?nX
_NWoZ[[U0_nW^NH01OnW_^[oZ;WUojRiiOnV^nSo[/?Y00;oY[WV0_n/`>T01_nX_>SoZ;gXojg1jOn]
`NWoZK[Voj_0j@;oZ[kX00?oYkWVojK0k?nV`>`00_n``NH00onN/^Oo[KgUojJgi@02ok71iP05oiNd
k?nY_nWoZKoYooooool00000:_ooool002;ooooo0ol00003ooooo`;oZKgX00KoZK[VojVmj?nW_>So
YkcXojZojOn[_nP2ojVmj0;oZ[kX1onY_NP01OnZ_^SoZKgXojVmj?nY_NSoZ[kX00;oZKcX00?oZKgX
ojZnj?nY_NP00onY_NP2ojZnj0;oZKcX00GoZKkXojVmj?nY_NSoZKgXojZnj006ojVmj005ojVnj?nX
_>SoYkgYojNmjOnY`N/00_nV^>H01?nW_N[o[/7XojNmjOnW_NT2ojg0j006ojRkion]_^OoY;[XojBj
j?n^`>OoZkkW0_nX_NP01?n/_^OoZkcVoj^li_nW_^X3oj^ni`05oj^kiOn``NKo/<7Voj>hj?n]`nX0
0_nU]^D2oj[2j`06ojZmion/_^OoZ;_WojRkionY_>OoZl?[0_nY^^D01?nU_>[oZ[WTojZii?nU_NX3
ojZnj005oj^oj?nX^^KoZ;[VojBljonY_^T00_nU_N/01?na`>GoVkCYoj6fionQ]^L2ojk9k@05ojJd
honfdNkoX;OYoj2gjOn/^^<00_nga^D01?nGZ^Co^]?/oh^Qh_n;XN82oj?FnP05okZngOnXV<GoZ9S5
ojRHaOm^Rmh00_oFcM401Om@DkKofl:oom_2_omBE;Kol^No00;oN7[80onEU=02oi2Th`05okgTl_nJ
X][oVZ;Joj^ji?n^b>d00_n__>@01OnX]N;oZ[oYojc0j?n/`>So[kkT00;oZlK]0_n``^P3o`000003
ojVnj?nX^>Go[<C[00;o[<;Z00Go0000ojVji_nY^^KoZ[[UojNiiP02ojg1j005ojRiiOn[`n_o[;gV
ojbmi_nV^NH00_n/`>P01?nX^^KoZ;gXoj^li_n[_>H2ojNkj005oj_0jOnY^nOoY[[WojJjionV`>`0
0_nT^>L01_nY`^co[KgUoj^nj?n[_^So/L7Vojo2i`;oV[?Y00CoX[WYokC4i_oooooo0000:Oooool0
027ooooo0_l00002ooooo`?oZKWU00GoZKgXojJkj?nV^nSo[L3XojNlj002ojZmi`;oZKcW00GoZKgX
ojZmionY_NOoZKgWojVmj002ojVmi`GoZKgX0onZ_NP01?nY_>SoZ[kXojZnj?nZ_^P5ojVmj006ojZn
j?nX_>SoZ[kXojZnj?nY_NSoZ[kX0onY_NP2ojRli`;oZKgX0_nY_>P01_nX_>SoZKgWoj^li_n[_>Ko
Y[SVojbni`;oZK[V00?oYkgYojRjionX^^L00_nX_nX01On]_^OoZ[gWojRlj?nX_>SoZkkW00;oZkcV
00KoZ;gYoj^li_n__^Go[kkUoj>ij?n[_^L2ojS0j`06ok31i_nZ_nWo[KkVojfni_nU]^Go/<GY0_nT
]ND00on/_^OoZL?/ojW3k002ojVji@05oj_3jonP]nWo[koVojnoi_nZ^N@00_n`_^@01_nX_>OoZ[kX
ojZjiOnZ^^GoZ;[Vojbhh`;oY;CT00KoYKg[oj>ah_nS/N;o[L?Zoj6fionaa>P3oiR`i`06okKAk_nP
Ym_oWKg_oifmkonga^GoXlWd0_nc]=T01?n;XN;o/jgCohJEf_n6UMX2ojo7j`;oZ9S50_nFT</01?m:
F;oofl:oom_2_ooK`[l2oo;W_`06ogQjb?oMn][ogO[JoiFDd?oMlmgoT:CS0_o2enT01OnJX][o//k_
ok;>konieNko[kcT00;oZKWU0_nZ_nT00on/`>SoZ;oZoj_6k@03o`000003ojjoi_n^`nWo[/?Y00;o
Y;SW00Ko[<C[ojZjiOnW]nCoYkOTo`000?nY`^`2oj[2j`05ojg1j?nW^nSoYk_Xoj_3jon/_NH00_nY
_^T01On/`>SoYkWVoj_2jon[`^_oZkcV00;oZl3Y00CoZkkWojVkionY_NSoZKgX0_n/_^L01OnT^>Oo
[;gWoj6jj_nQ^^[oZkkX00;oZkoX00Co[l;WoiZcjOnL/nSoW;?X0_nda>H00ol0003oooooooooo`0W
ooooo`008Oooool2o`0000;oZK_V0onY^ND00on^`>OoY[_Xoj^oj003ojVnj005ojZmionY_^WoZkkX
oj^nj?nZ_NL00onZ_^P01?nY_NOoZ[kXojZnj?nZ_^P4ojVmj004ojZmj?nY_NSoZKgXojZnj0KoZKgX
0_nZ_^P01_nX_>SoZ[kXojVmj?nY_NSoZ[kXojVmj0;oZ[kX00GoZ;cWojVnjOnY_^WoZKkXojVlj002
ojRlj0;oZKgW00OoZkcVojVoj_n/_^Oo[;kWojVji_n^_^KoZ;[W00;o[KgV0_nV_NT01OnZ_NOoZ[cW
ojVmj?nY_NSoZkcV00;o[[kU00KoYKg[ojnniOn^`nWo[/?YojNii_nX`>/2ojFfi@;oZ[oY00So[KkV
ojNlj?n`aNWo/<GYojBeiOn/`>SoZL?/oijfj@?o/l;U00GoX;OYojBkjOnY_NSoZKgXok2ni002ok30
iP06ojc1jOnZ^^GoZ[SSojZhhon/^>?oY;CT0_n^^n<01?nS/N;o]LKWoj:^hOnR[^42ok74j004oiR`
ionb`^Ko//;Voj2Wf`?oWZSM00?oXlWdok>dfOned^l00onc[M<01?n6UM[oZj[FobR8k?nXV<D2ol_8
f004oiJ@boo;/;ooBURoom_2_`?oOG_700?oYNSkojnLa?miV>@00_nl`]h01_nU/>3oTK3[oi6`jonA
/>_o//k_okK5iP;oXZ_N00CoZKWUojo;k_n_bnkoZ/3Y0ol000001OnU]^Go[l;XojBeiOnT]NGo[/?Y
00;oY[SV00Co[/;YojZjiOnX_>SoZ;cX0_nZ`^/01_l0003oZKSTojNgiOnW]nGoYk_Xojk0i`;oYKKU
00CoZKkYojZnj?nZ_^SoYkWV0onU]^D01On[`>WoZ;cXojVnj?nY_^SoZKgX00;oZKkX0_nY_NL01_n/
_NOo[LC[oj:gj?nR]nSoZkoXojc6k0;oZ[[U00KoW;?Xoj>hj?nS^>So/[oTooooool0000Xooooo`00
6_ooool2o`0000Gooooo00Go0000ojVmj?nY_NSoZK_VojJji`02ojZkiP05ojk0ionZ`>WoZkoXoj^o
j?nY_^P00_nX_NP4ojVnj@05ojZnj?nY_NSoZKgXojVnj?nZ_^P00_nY_NL7ojVmj003ojZmj?nY_NSo
ZKgX00CoZKgX0onX_>P01?nZ_^SoZKcXojZnj?nZ_^P3ojVmj004ojRlj?nY_^WoZKcXojVlj0;oZ;cX
0_nY_^T2ojRojP08ojVoj_nV_NWoZ;oZojRoj_n^_^KoZkgWojfmi_n^_nH3ojFkj005ojZlion/_^Oo
Y[k[ojJnjon^_^D00_naa>P01_nR]^Oo[/?YojFiionU^NOo/<CYojFfi@;o[/GZ0_nW^NL01_nW_>So
[lCYoj:gionR]nOo[<3Xok33j0;oW[KY00Co/l;Uojnoi_n__nKoY;_Y0onX^^H01On``>Ko/lKXok?6
j?nT]^GoZ[SS00?oZkoX00?o[[_SojO7l?nWao000_nea^L01_nR[^7o]/g/ojBahOnT/N7o//;Voi>j
lP;o_];Y00CoWZSMok^ieonk^MOoOj3X0_ned^l01?nc[M?o[jgFojn]e_n[Z]H2odUff`05ol_8f?n;
d?kobk2ool^`_om:F;l00_o9[Kd01ommNlOoeLgBojnLa?n_W<CogO_Iokc2g_n]k?P00_o0`=X01OnA
/>_oY[KTojJfi?nfaNKoXZ_N00;o/Lk_0ol000001_nZ^>Co[K_Sojc7kOn/ango[l;XojBei@;o[l?Y
00KoY[SVojk5jonW^NKoYkWVojRlj?n]`^T2ojZji@03o`000?nY`^coZL;/00;oZl?[00Go[/3WojJi
i_n/`^[o[<;ZojZnj002ojJiiP06ok35jOnU]^Go[KoWojfoionX_>SoZKkX0_nX_NP01_nY_^SoYk_X
ojVnjOnY_^Wo[LC[ojBfiP?oY[SV00Ko[<K/oj6ciOnZ_^SoZ[kXoj>hj?nS_N/2ok;1i@03ooooool0
003ooooo02Kooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00Ko0000oooooonV_>WoY[cY
ojJjionW_NT2ojo3j005oj[0jOnX_>SoZ;cXojZmionX_NP00_nZ_>L00onX_>SoZKkYojVmj005ojVm
j004ojVmionZ_^SoZ[kXojZmj0GoZKgX00CoZ[gXojVmj?nZ_^SoZ[kX1?nY_NP01?nX_>SoZ[kXojZn
j?nY_>P4ojVmj0;oZ;cX00CoZ[kXojVlj?nX_NSoZ;gX0_nY_^T2ojVmj0;oZ;gX00KoY[gYojRmj?nU
_>[oYKcZoj^mion[_>H2ojjoiP04ojFkj?nU^NOoYKWWojbni`?oX[GV00Ko/LCXojJii_n/_nOo[;oW
ojFiion_`NL2oj>di@03ojk5j_nS]^KoXkKV00;oZK_V00Ko[lCYoj>hionY^nKoZK_Vok33j?nW_NT2
ojBjj@05ojnoi_n]_>Co[KcTojBnk?nX^^H00_n/_>D01Onca^SoYKKUojBgi_nT]nKoZkoX00;oZkkW
00CoY;[YojO7l?nR]nOoX[OW0_nP]NL01_nfcNcoV[C[ok>nhonc_^?oTk[boj6Uf@;oU[;Z00Co^kWG
ol78gonRZ=_oXZSK0_mm[?801On_[MKo/;SOol6_b?o1[lSoBGKK00;oUISD00?o06CFol^`_oo9[Kd0
0_o9[Kd01?nko<_oeLgBojnLa?oMnmT2ojc:k`05ojg/n?o0`=[oanc^olO/k_nV]^@00_nbbn`3o`00
0003ojfmiOnU/^7oZlS_00;oZlW_00Go[<O]ojFiionU^NOoYKo/ojo3j@02ojNii`;o[/G[00SoYkWV
oj[0jOn]`^Wo[L;YojZjiOnX_n[o0000ojVii@?oYkOU00KoY[WVojk4j_nX_NSoZ;gXojJii_n_`NL2
ojBkjP04ojfoion]_^Ko[KkVojVmj0?oZ;gX0_nW^nP02?nY_^Wo[/?YojBfi_nT]^KoY[SVok;8jonQ
/nGoZ<?/0onW^>D01OnS_N_o//7Uok[CkOnjdngo000002Oooooo000Iooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooooooo0_nS^n/01OnW_NWo[<;Zojc2j_n]_nOoZ;cX00;oZKkX
00CoZkkXojZlionZ_^SoZ[kX0_nZ_NL5ojVmj003ojVnj?nZ_^SoZKgX00ooZKgX00GoZ[kXojVmj?nY
_NSoZ[kXojVmj002ojZnj003ojRlj?nZ_NSoZ;gX00;oZ;gX0_nZ_NP00onY_^SoZKgXojVmj003ojVm
j005ojRmj?nX_^WoY;[XojBjj?n[_>H00_n]_^H01_n]`^WoYKWWojRkionX^nOo[l?Yoj:eiP;o[[kV
0_nV^NH01on/_nOoYk_Wojo1ion_`NOoXkCUok;2i_nS]^H00_nV^^L2ok;1i@06oj>hionT^^Wo/KkT
ok6ni?nW_NWoY;[X0_nV_^/01On]_>Co/[gRok:mh_nM]>So[;cU00;o]/WY00GoYKKUojBgi_n/a>co
[<C/oj^ni`02ojZoj@03ok75jOnR]nOoXJgO00;o/l7U00?oV[C[oi^`i_nK/>H00_nkbND01?nQYMWo
^<?RohZ]kOn:[Nd2ol78g`04oj:Xfong]mWoG8WToeb9i0;o/;SO00?o`Jo8okjU`OnEV=@00_o4b=d2
olG5fP04olV]_Onko<_oJ<klojjJ``;oSYCD00Co[<[_okfbconm//ooPYcS0_nJXm/3o`0000;o/LGY
00Go[KgUojFkjOnU^nWoZlS_ojboj002ojRii@05ojFiion]^nCoYKCSojFdhonW^NL00_n``^P01?nT
]nKoZ/3Yoj^li_n[_>H2ojNhiP08ojRoj_n[^^Go0000ojViiOnW]nGoZKkYojk4j_nY_NP3ojFij006
ojo1ion]_^KoY;_YojBkjOn]_^Ko[KoW0_nY_^P01OnX_NSoYk_WojNkionY`>[o[/?Y00;oYKSW00Co
YKg[ok;8jonS]nOoXkOW0_nX`n`01?nW^>Go[/__oj:diOnhe>h2ojNah003ooooool0003ooooo02Go
oooo000Iooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool2ojBljP05
ojc2j_nW^^OoYk[Woj^oj?nY_^P00_nY_>L01?nX_NWoZ[kXojVnj?nY_^P2ojZnj005ojVmj?nZ_^So
ZKgXojVmj?nY_^P02onY_NP2ojZnj0KoZKgX0_nZ_NL2ojVmj008ojZnj?nY_NSoZ[gXojZmj?nX_NSo
Z;cXojZmj?nZ_NL5ojVmj0;oZKkX00GoZ;kYojBiionT^NOoY;WWojfniP02ok;6j@06ojFgi_nX^nOo
/<GYok35jOnS]nOo[[kV0_nY^nH2ojc0j008ojNkion]a>_oY;KUojBfiOnb`^KoZL7[ojJjion[_NL3
ojfniP06ojBjjOnc_^;o/kkRok>nh_nT^^SoZ;ST0_nQ^>T01Onb_N;o//KYok;6jOnP/nKo]/WY00;o
YKGT00KoY[o[ojc4k?nT/^;oY;;RojZojOn^^>02ojB[g0;oXJgO00Co/l7Uojo2j?nK/>Ko[;KP0onG
Zn@00onh`n;oUKO_oiFgk`03ojN[fP03okNgfOm^S^7oKXkQ00;oVIoH0_nnYL401oo:]<Goa<SMolG6
foo5a]_oSjSVoik1lOn[T;X00_n^V/<01?n>U=Co^K?CokVcdonm//l2olk_j@;o00000_nndNP02?nS
/N;o]<CWojW1jonY`N_oYK_Yok32ion/_nSoY[CS0onZ^nH01_n]^nCoYl7/ojc7k_n/anko/<;XojRl
i`;o[<;Z00OoZkcVojW2k?nY`^co[KoWoj^jiOn[`N[o000000;oZ;gX00OoZKkYojg2jOnY_NSoZKgX
ojFij?nY_>Oo[KkV00;o[KgU0_nT_>X01_n]_nOo[/?ZojRlionX_>OoYk_Wojc1j@;oZkgV00GoYKSW
ojW0j_n[_^OoZkkWoj>gi`02ojc3j`04oinbiOn^bnooW:gSoib]h`;o^=C^00CoYk7PokC:jooooooo
00009Oooool001Wooooo00Co0000oooooooooooo00000oooool2o`0000Cooooo00CoY;cZojVmj?nW
^^Oo[<7Y0_nZ_NP00onY_>OoZkgWoj^mi`02ojVlj006ojVnj?nY_NSoZKgXojVmj?nZ_^SoZKgW2onY
_NP2ojVnj003ojZnj?nY_NSoZKgX00CoZKgX00CoZKkXojZmionZ_^SoZ[kX0_nZ_NL01_nY_NSoZKcX
ojVmj?nY_NSoZ;cXojVmj0;oZ[gW00CoZKgXojRmj?nX_NSoZKgX0onZ_NL01_nU^NOoY;WWojRlj?nX
_>So//KYojBdi0;oZK_V00Go/<GYojBci?nT/nCoZ<3[ojVkiP02ojo6j`;oY[KT00Ko[LC[oijhjon^
_^Ko[[kVojW1jonQ_>`2oj^mi`05ojfni_n[^^CoZk[Toj>nk?nc_^800_nd`nD01OnX^>CoX:kQoj2^
hOnP[^7o//KY00;oXKWZ00Ko//[/ojFei?nbc>go//c]ojVcgonT/^82ok2ni0;o[[SP00KoY:_LojW0
j_nc`NCo/l7Tojo2j?nQ_^d2ojbfh004oiN[i?nV]nGoY[OUokC7j@;oUKO_00CoYj_JojbWd_nhcn_o
^<o[0_m^S^402?nIWmSo_ZG1olZdaOo:]<Goi]W8olG6fon`X<OoW8Fi0on[T;X01?n^V/?ocM7LokVc
donbm_03o`000003ojkNn?nQZ=_oXJSK00;oY<C`00Ko]<CWojB]g_nT[MkoY:gNok32ion^^N82ojJd
h`04ojZki_nY`N_oZL7[ojO1k0?oYKCS00KoZ;cWojJgiOnV]nGoY[OUojW2k?nT]nH2ojW4k@05oj_1
j_nW_^[o0000ojVojOn]`^T00_nZ_NL2ojJlj@04ojVlionY`>[o[KgUok33j0;oY;OV00?o[/?ZojRk
ionX^nL00_nX^nL01_n/`NWoYkWVojVojOnY_nWoZL3ZojJjj0;oYl7/00Go[<?[oingjOnbb^co//[/
oib]h`02okO;j@05oi^[h_ndb^_o[koVojnoi_l000009Oooool001Wooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`04ooooo`05ojVmj?nU_>Wo[<7Yojc1jOnZ_NP00_nY_^T01?n[
_NOoZ[gWojZmionZ_NL4ojVmj003ojVmionZ_NSoZ[gX00CoZKgX00?oZ[kXojVmj?nY_NP00_nY_NP0
0onY_^SoZKgXojVmj008ojVmj003ojZnj?nY_NSoZKgX00;oZ[kX00CoZKcXojZmionX_NSoZ;gX0_nY
_NP2oj^mi`05ojRmj?nY_>OoZKcWojVmj?nZ_NL00_nW^>D01?nT]nKoZ;cXok76jOnaa^T2ojBdi004
ojVki_nb`>CoY;?Tok70i@;oX[GV00?o[lK[oifcionM/nL00_nd_n801_nN^>_oX;WZok;0i?nb`>Co
XKc/oinfj0;oZkkW00GoZk[Tok6jgona^]ooW[S[okC3i@02oj_2jP06ojfoionP[^7o]lOVokO7i_nQ
^N[o[[kV0_nNYm`01_nbc>goU[;[oiJbjon/a>co/;kToj^ni`;oX[?U00?oZL3ZojNjionW^^L00_nf
aNH01_nQ_^goTZgYoj[4kOnZa>goY[OUok:jg`;o[KSQ0_mkUN401_n/Ym;odLcDoi2Xi_n@Z>KoK7oE
ohR5bP?ob[C500?oi]W8ok2Paon`X<L00_nLQKT2oj^@^P04omCHg?l0003o0000o`0000;o/KcR00Co
V[obojn_f?nQZ=_o`M?X0_nP[N02okC9j@05ojB]g_nhe>ko^=C^ojjih_n/a>/00_n]bNl01OnY`N_o
ZKWTojbki?n/^nCoYKCS00;o[<;Z00Ko[L?YojJgiOna`nOo/L?WojBgi_n__ND2ojJii`05ojNnj_nW
_NWo0000ojZnj?nZ_NL00_nZ^nH01?nU^nWoZL3ZojFmj_nU_NX2ok33j003ojBgi_n]`NSoZ;_W00;o
Z;_W00Ko[L7YojNii_n]`^Wo[L;Yoj^li_nV^^P2ojbmiP;oZ;_W00KoWkOYojbnionM/nOoWK?WokO;
jOnQ]nP2ok34j004ojnoi_n[^nGoZk_Uo`0002Cooooo000Jooooo`;o00001?ooool2o`0000Kooooo
00GoYKcYojVmj?nY_NSoZKcWojVnj@02ojRmj004ojZnj?nZ_NOoZkkXoj^nj0CoZKgX00?oZ[gXojZn
j?nZ_^P01?nY_NP00onZ_NSoZKgXojVmj008ojVmj003ojZmj?nY_NSoZKgX00OoZKgX00KoZ[gWoj^n
j?nW_NWoYkgYojVmj?nY_^T2oj^mi`05ojVlionZ^nKoZ[_VojViiOnW^>D00_nW_^X01?nY`^co/LKY
oin`honO/><2oj_3j`08ok;0i?nX`^co/L3Uok70iOnR]NKo/KkToifcionT^>L3ok>ohP06oj2ij_nR
_^go/kgQok>mhOnO]^SoY;3Q0_nV`Nd01Ona^]oo^LKToj>bi?nS/^CoZl;Z00;oYk7O00KoVkCYokO7
i_n^^N;o[[WRojjni_nNYm`2ol;AiP04oiJbjonRZM_oXZWKoj;1k`;oZkkW00CoX[?UojjmiOnW^^Oo
[K?M0onb]M/01onB[NWoXj[LoiZnlOnJ__7o/[[Oojn`fOnK_O000ommO/T00ooAc=CoMGg=ogEmc@02
ofIW_`03ohR5b_o:]<Goi]W800;oh^CE00?o/:37oib5^OnLQKT00ol000001?o2i_3o^]3Zok[@j_na
_>82okVlf`08ojn_f?n`c>ko`M?Xol7Cj?nP[N3o]lSWoiZfk?n^`NL2oin`i003ojc4jon`^^7o/;[Q
00;oYK7Q00CoZKWTojZlionY_>SoZKcX0_n/`^X2oj>fiP05ok73ionZ`^_oZ/;[ojnmiOn^`>L00_n[
_^L01_nW_NWoYk_Wo`000?nZ_>OoZ[_VojbmiP;oZ;WU00GoYKgZojNhiOnW^>GoYkkZojg1j002ojZn
j0;oZ;cX00Co[L7YojJjion]`^WoZ;cX0_n[`NX01On/_NKo[<7Yojc1jOnW_NWo[;kW00;oY[o[0_n[
_^L02?nQ]nSoYkWVojc3jon/`n_oZk_UokC<k?oooooo00008oooool0023ooooo00?o0000oooooooo
ool01_ooool01OnY_NSoYkgYojNmjOn/_^OoZ;gX00;oZKgX00GoZ;gXoj^nj?nY_^SoZKkXojZmj003
ojVmj003ojZnj?nY_NSoZKgX00KoZKgX0_nZ_NP4ojVmj0;oZ[kX00?oZ[gXojVmj?nY_NP01OnY_NP3
ojRmj005oj^nj?nZ_^SoYkcXojNlj?nY_^T00_nW_NT01_nZ_NSoZ[_VojS0jonX`>_oZ;kZojNnjP;o
Zk[U00CoZ[KRoin`honb`>Co//3T0_nU/>001_nX`^coXk3Qoj[2jonZ`^_o/KkToj^liP;oY;SW00Co
/koRok>jgonc^]ooX[k]0onb_N801_nT/>7o];OKoiRajOnH/NWo^LKTojZnj0;o//W/00GoYk7Ook?<
kOncc>goZ<;/ojjihP02okK?k005oiJaj_o2dNKo[/3Wojk0ionRZM/00_nl`=d01OnK^>coX[CUoj:d
iOn^_NGo[KkV00;o[K?M00Co/[GKokNifong^M_oXj[L0_n>Xn<2ojn`f@;oHFBo00CoOGk9okZge_nj
]mKoKfFg0_meOLd01_mVIkooYIo@ojFOd?oOk]_oh^CEoifQe`?o000000Co[JSBom?oe?o9olco`^K`
0onUXM800oni_=_o/MOdok3<kP02ok6kh@;oX<;a00Oo]lSWojnhh?n^`NOo[/7Woin`i?n`bNco/;[Q
00;oZl_`00Co[L;YojZlion[aNgoZlG]0_n]aN/01on/`^[oXkOWoj^mion[_NOoZ/;[oj>jjOn^`>L0
0_n]_nL01?n/`NWoYk_WojNiiOl00002ojRlj006ojbmi_nY`^co[/7Xojk1j?nW^>Go[/CZ0_nX^^H0
1OnZ_^SoZ;gXojRmj?n[_nSoY[[W00;oZkkW00KoZ;cXojJjionV^^OoY[[Wojc1jOnZ_NL2ojJmj@05
ojJojonS^>SoXkSXojS3kOnW^NH00_n`b^d2ojBdi004okC<k?nV]>;o0000o`0002;ooooo000Ooooo
o`03o`000?oooooooooo00Sooooo0onW_NT01_n[_nSoZKgXojZnj?nZ_^SoZ;gXojVnj0;oZKgX0_nZ
_^P;ojVmj003ojZmj?nZ_^SoZKgX00goZKgX00CoZ;gXojVmionY_NOoZ[kX0onZ_NL01OnW_NWoYk_W
ojNkionW_NWoZ<3[00;oY[SU00OoZ;[Voj^jiOnUa>ooYLC_ojO5konb`>CoXlGa00?o]kkP00KoXk3Q
ok>hg?nS_NcoXkg/oj^li_nX^>@2ojNmj@05ok>jgonj^][o^[[Joi^`i_nb_N800_nXb_401Ond]m_o
YKOUojFgiOnU]nGoZ[kX00?oUj3K00Ko/lc]oj_0jOnKXm[oVj?JokK?k?nO]nT2ojZ/f@05ojk0ionD
Z^GoU:[Uokc0gOo2cnD00_nC[NP2ojRnj@06ojfni_nO]>Oo[lS/ojo8k?ng^M_o/=We0_nh]=H2ohjS
h`03ojn`fOo;i^[oHFBo00?o^[OF00?oKfFgof=Q^_mSHKX00_mVIkl02_nUWm3o0000o`000?l0003o
WJ7Gohf3a?n]Z=;odooDolWoc?nh`N42ojRNc@06ojFQd_nol_7o[LK/ojg6k?nX_^Wo/K_Q0_o0c^D0
1_nO/>?o[kSPok_EkOnkeNgoX[?TokC=k@;oWk?V00GoZl_`oj:diOnR]>GoZ<G_oj_5k@02ojZoj@04
oj^oj?nS]nOoY[cYojJlj@;o/;oU00CoXk[YojFhi_n]_nOo[l?X0_nW]n@01OnW^NGoZkoXo`000?nX
`>_oZL;/00;oY[SV0_nW_NT01_n^a>[oYKOVojc1jOn/`NWoZ;gXojVli`;oZ;kY00GoZkkWoj_1j_n/
_>Ko[;cVojJji`02oj^miP06ojZmionY^nOoZK_WojVkionS^>SoZkoX0_nO/nD01On`b^goW[3TokK=
k?nfcNcoY[CR00;o/l_[00?o0000ooooooooool08?ooool001oooooo0_l0000:ooooo`05ojNmjOnY
_NSoZKgXojVlionZ_^P01_nY_NP2ojZnj0OoZKgX00GoZ[gXojVmj?nY_NSoZKgXojZnj00?ojVmj005
ojVmion[_^SoZkkXojRmj?nZ_NL00_n[_nP01OnW^nOoZl3YojZki_nZ^nKoY[SU00;oZ<7[00GoYl?]
ojG4konU/n?oYK?Soiffj@02oj?5l@05okNnh?n^_NGo[[gUok>hg?nl^mT00_nN]>L02?nX^>Co[[[R
oig3lonM`o?o^[[Jokg<iOnRZ]coaM;U0on<XN801_nng>ooYKOUoj^agOn[/Mgo]<;UoiNPf`;o_l[R
0_n[`>T01onKXm[o`/KMoingjOnO]nWoZZcIol;<hOnDZ^D00_nO_^h00oo2cnGoTjgXoijbiP03ojJc
h@07oindion^eOCoU[ocoiJolon`fOGo^;CFokoYlP03ohn?d005oeYP_omQI;ooHFBookZge_mQCjH0
0_m_IKL01?mSHK[o0000o`000?l00002ohNOh`;oMWW800CoSH?4okFlgooRoL7ofOfi0_nh`N401OnX
W/gocoOWologion]a^coYJ_K00;oXJ_N00Go`<kUojbmion/_NOoWlWeok_Ek@02oin^h@06okC=kOnO
/nKo//3Uok;0iOnR]>Go/KgR0_nV]nD01OnZ_nWoZKkYojVnjOnU_>[oY[cY00;oYKk[00Co/;oUojFh
i_nZ^nKoZ[_V0_n_`nP02?nW]nCoZKcWoj^oj?n]`>So0000ojVjiOnV^>Ko[<;Z0_n/_NH00onU]nKo
[LG[ojg5j`02ojRki`06ojVlion/`^[oYk[WojNjion[`N[oYKSV0_n[`^X01On[_NKo[<;Zoj^mi_n[
_NKoZK_W00;oZ;kY00GoZkoXoinciOn`a>Wo/<CYoij`i003oj:bi004ok?;jonV]^Coooooo`00027o
oooo000Oooooo`03o`000?oooooooooo00[ooooo00?oZKgXojNmjOnW_NT00_n[_^L00onY_NSoZKgW
ojVmj002ojVmj005ojZmj?nY_NSoZKgXojVmj?nZ_NP01OnY_NP00onZ_NSoZKgXojVmj006ojVmj004
ojZmj?nY_NOoZKgWojVmj0?oZKgW00GoZKgXojVlionY_>OoZKgXoj^nj002ojVli`04ojNkion[_nSo
Y[[WojJji`;oZl3Y00CoZ[_VojNkj?nX`N_o[;gW0_nX]^<01?nU/n?oZkORojbfh?n/]^02oi:fk`04
ojjmiOnT/n?oY;?Sokbkf@?oWjOL00Ko[[[RohRMhOn8WN7oR9gQokg<iOnM[n@2olGBi@05ohbQh_no
dNSoVYcEoiZLeOn[/Md00_nnd>P01?nDYN7o_l[Rokg?j?nmcnP2ohZMg`07ol;6gOnl`=goQJ_^ohF[
k_o2c>7o[[SQoinnkP02ojR`gP04ojfki?nN/^KoW[;VojJch@;o[KoX00Go[]GdojJMcOnVWLgoYYg=
ohFAe`02ofeba`07ohn?d?oIhmgoFV2ooeYP_onPZ]kol?34of5?YP03o`000004of=Q^_n=U=KodOkK
olGng`;oQioS0_mfNLP00one_=ooZ:SFojRXeP02oi2;b`06olOof_o?mnOoZ:cJojR/f_nUZm_oXJ_N
0_nndnX01On/_NOo^lkXojF]gOnU[MgoWjkQ00;o^L[W00GoXK?Uok;0iOn/`NWo[<7Yok6mhP03ojk1
i`06ojVnjOnY^nOoY;_YojBkjOnU_^_oXkc[0_n]`nX01OnZ^nKo/<CYok34jOnV^nSoZKcW00;o[<G/
00Co[L3Xo`000?nY^^GoZ<7/0_n/`^X00on/_NKoZ;gXojg5j`02ojJhiP06ojVlion/`^[oYKSVojFh
i_n]`^WoYKSV0_n]`^T2ojJii`06ojc2j_nW^NKoZl7Zoj_1j_nX_^WoZ;cX0_nS^^T01On`a>WoX[WY
ok;7jOnbanWoX[;T00;o//SZ00?oY[KTok78jol000008Oooool001oooooo0_l0000=ooooo`06ojNm
jOnX_NSoZ[kXojZnj?nY_NOoZkkX0_nY_NP01OnZ_NSoZ[kXojVmj?nY_NSoZ[gX00KoZKgX00?oZ[gX
ojVmj?nY_NP01OnY_NP01OnZ_NSoZKgXojVmj?nZ_^SoZKgW00;oZ[kX00?oZ[gXojVlionZ_^P00_nZ
_^P01OnY_>OoZ;gXojRmj?n/_nSoY[[W00;o[;oX0_nU^>L01_nW^nSo[L7Xojbmion/_NOoZ;KSojJg
i@;oZkOR00Go[;KPokJmgon?]?3oSkC`ojBch`02ojFZf`06ol75gOnOYmco[:KAojbVdOnodnWoR9gQ
0_n__ND01?nM[nCoWIW?oifIconMVLl2okoAj004oiZLeOnban[o_]3XoiZIdP;o[J_F0_nC/>X2ojJY
f@03okc0gOnf[m;o]ZoB00;oVK?Z00?o[[SQokFdeonX/=h00_n/XL`01OnZa>coVYoGoiZOeon]_nSo
_;gJ00;oWI;800SoYYg=ok?Im?o2]/oo`[K?ofebaoo;dmooKW?7oeYP_`;oTK3/0_l000001omQCjKo
M7?3ogAc`on>/o3oVNfgokW_m?mcX^h00_mBK<l01?mfNLSo[KWRon[/c_oWmjH2ojRXeP04oi2;boo7
om[oa<cPojR/fP;oZ/kc00KoY=SjokkCj_n]`NSo[L7Xok_>j?nM[>42oj^oj006okW:ion[ankoZ;[V
ojRji_n/`NWoY;g[0_n``NL01On^`NOo[/;Yojk2jOnY^nOoZ[WT00;oYkSU00KoXkc[ojJgiOnU_N[o
YKgZok34jOnY^nH2ojFkj005ojc5k?nW]^CoYkKTojNlj?l000000_nX^>@01_nV]nGoZ;gXojk2j?n^
`^SoY[SVojVnj@;o[/?Y00GoYKSVojc0j?n/`>SoYK[Xojg2j@02ojNmj004ojg0j?nW^NKo[L3Wojg0
i`;oZK_V00SoZ;cXojRmj?nX^^KoZ;[Voj:ijOnZ_NOoYKWXojg2j@;oYKSV00Co/LS[ojJgiOnV]nGo
00008?ooool001oooooo00?o0000ooooooooool03Oooool01_nX_NSoZ;cXojRlj?nX_>SoZkkXojZn
j0;oZKgX00CoZ[kXojVmj?nY_NSoZ[gX0onY_NP00onZ_^SoZKgXojVmj005ojVmj003ojZmj?nY_NSo
ZKgX00GoZKgX00GoZ[kXojRmj?nX_NSoZKkXojZnj002ojVli`04ojRkionX_NSoZKcWojVli`;oYk_X
00Ko[;oXojJmjOnX^nOoZ;_Wojg1j?nY_nX2ojBgi`06ojJgiOnU^>OoZ[WTojZii?nf_Moo_<SS0_n4
YNX01_nUZ]_o^KOGokVgeonYe_Oo[:KAomODeP;oTi3>00Ko[kgUoj>Uf?nSYMSo]k[LoifIcooIl>43
ohV<d006ok;7j_njdngoVYWBoiZId_n]ZmKob/CD0_nC/>X00onVZMWo^KcKokJ_dP02ol2ac0;oUZ_U
00Co]KCGojbQc?n/XLco[:7<0_n6P/L2okg<iP04okbmf_nMT/So/]Wdok;Im0;o/mWd00Co`[K?oiVj
koo;dmoobm?O0ol00002oda1Y005of5?Y_mdLl?ogoCKokG=k?nfVkd00_n>U]L01?l/J=WoDVc?oe9/
con]^N82ojfki0?oSHk?00Goa<cPojboj?n/_nSoZ/kcok>hg@02oijWg005ojg1j?nc]]_o/kKKoif/
hOn^_^H00_naa^T02?n[ankoWKOZojo1ion_`NOoY;g[ojFfiOn_`>Ko/lKY0_nX^^H00onZ^NCoZkgW
ojfniP02ojfniP03ojJgiOn]aNcoZK_V00;oZK_V00GoZkoXojfnion]_^OoYkKTojg4j`02ojbmiP05
o`000?nY`^coZl?[oj_3jon^`^P00_nV^NH01_nY_^WoYKSVojFhi_nU^>Ko[<3XojVoj@;oZ[gW00Go
YkgXojRji_nX_^WoZ;kYojg0i`02ojZoj@06oj_0jOnX_NSoYK_XojFkj?nY`^coZ[gW0_nY`N/2ojg2
j@05ojFhi_n`a^_oY[OUojc1jOl000008?ooool000Kooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`0>ooooo`05ojVmj?nX_>SoZ[gX
ojZmj?nZ_^P00_nX_>P01OnZ_^SoZKgXojVmj?nY_NSoZ[kX00?oZKgX00?oZ[kXojVmj?nY_NP00onY
_NP2ojVlj006ojZnj?nY_NSoZ[kXojZnj?nY_NSoZ[kX0_nY_NP01OnX_NSoZ[gXojZmj?nY_NOoZKcW
00;oZKgX00CoZkgWojVlionY_^SoZKkX0_nZ_>H01_nV_NWoXkWXojfni_n]_^KoZKoZoj2jj`;oX[WY
00GoYKSWojBljon[_nSoZkoXokc8h`02ogb<f0?o^KOG0_mbM<D2omODeP04oi>@c_o2`][oXjGHok[D
k@;oTYWG0_mkO<P01?n9S=3o^:_<okR[c?mbT>43ojZ^fP05ol[4e?o:bMWoNigWog^Mioni_=/00oo0
/L`2oi><b@;oLW7200Co[:7<om[Lf?oJg=SoQX;70_nYY]@2oh^;cP;oZ9S50on9R<`3o`000004ogel
b?n[eoOo`:o9ol2_b@;oC46T00?oW=[moj9mZonfVkd00_nfVkd01_n>U]OoVY38o`1Gd?n1U]oo_K7>
ooGaY@;o[K_T00CoSHk?oijNe?nNW]Co[;oX0_nkc^P02?nc^=goYlccokO8iongb>Oo/kKKokC8jOn^
_^Ko]LGV0_nb^n000onM]n[oX;_[oj2kj`02ojo6jP06ojFfiOn/^^Co/lKYok?6jOnX^^KoYkSU0_n[
_NL00on]_^KoZL7[ojg5k002oj>ch`;oZ/3Y00KoZkoXojZmionV_NWoY[gYojg4jonV^^P2ojS2k006
o`000?nY^nKoZ;WUojRiiOnV^NKoZl;Z0_n]`NP01OnU^>KoZl3Yoj_0jOnY_nWoYkWV00;oZl7Z00Ko
Z;[Vojg2j_nX^^KoZ;[VojZojOn[_>H2ojRjiP05ojFkj?n[_NOoXkKVoj>fi_nY`N/00_nX^nL01onW
^nOo/<K[ojFgi_nU]nKo[<7Yooooool000007oooool000Gooooo00Co0000oooooooooooo00002?oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooooooo0_l0000Aoooo
o`06ojRmj?nZ_NSoZ[kXojZnj?nX_>SoZ[kX0onY_NP2ojZnj0;oZKgX0_nZ_^P4ojVmj004ojZnj?nY
_>SoZ[kXojZnj0;oZ;cX00OoZ[kXojVmj?nZ_^SoZ[kXojVmj?nY_^SoZ[gX00;oZKcW0_nY_NP3ojVn
j@03ojVnj?nW_NWoYkgY00;o[KgV00KoXkWXojFkj?n`_NCo/;gToj2jjonM]nX2oj2mk@05ojBljonS
bOCo/M;aok7BlOnZ_^P00_mlS=P01?ni]mOog?7Nog9daOo<cM/3oi^Kd`06ol;2f_nVVl[o^]C]ok[D
kOnBVMOog=oH0_mkO<P01OnhZlcohn;Aog:@hOmbT>7oZZkJ00;o/ZC:00Kob/WIok>Wc?n5Y>SoQJCX
oj^fhOo0/L`2olNfb@04oi><bOo8ZkgoLW72og9a`P;of]cH00OoQX;7ol_:fOnYY]CoZJKDoh^;c_oE
m>CoZ9S500?o00000_nW[md01OmmO<Sod^;Soh1a^Ol0>l3o`:o900;oC46T0onROJ/01OnfVkgo_IZd
oiZ@b?nJT<SoBDne00;o_K7>00?omO6UomKod_n0S=D00_o<li/00onNW]CoWi[?oinJc`02ojC8lP06
ojO<lonN_o3oXlCaoj?4lOndb>Wo[<C[0_neaNH00onb^n3o][oQoj2kj`02ojJbh@04oj:kjon/^^Co
]/c[okK<j`;oZK[U00SoYkSUojc7k_nZ`N[oZ/7ZojW1jon[^>;oXk?Sojo9k@;oZKcW00GoZ[gWoj_3
jon[`n_oZkcVojJjj002ojfli@04ojRhi?l0003oZK_VojVmj0;oZKkX00SoZl;ZojVmionV^NOoY[WW
oj_0jOn[_nSoYkWVojg3j@;oYKSW00?o[L;ZojJiionV^NL00_n/`^T01_n[_>KoZ[oYojZojOnZ_nWo
ZkgWojNlj@;o[<?[00KoZ;_WojRmj?n_a>[o[lCZojFgi_n/`>T2oj_0j@;o00007_ooool000Gooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`05o`000?oooooooooo
ooooool000004oooool2ojRmj004ojZnj?nX_>SoZ[kXojZnj0;oZKgX00GoZ[kXojVmj?nY_NSoZKgX
ojZnj004ojVmj0;oZ[kX00CoZ;cXojZnj?nY_NSoZKgX0_nZ_^P01OnY_NSoZ[gXojVlj?nY_>SoZKkX
00;oZKcW00CoZKgXojVnj?nY_^SoZKkY0_nY_>L01?nW_>SoYkgYojFlj_nU_>X2oj^liP06ojFkj?nU
_N_o/KcRok6lh_nM]n[oY;?S0_nM_^l01onSbOCoWJ;IoifRfOnMX]WoOXcGoiR[hooHmn000_mNJLH2
olc=f`04oi^Kdonl^MKoYY_:ojJKbP?oQGJj00GoNiORog]lb?nKVm;oVi_Bon?Rd@02ohF1a`?o/ZC:
0_ncYl`01_nhWKgoRZOXohZWj?nG_?7oakK9okOGl0;ob:^m00?oLW72okZP__njX;h00_n6Rm400oo;
b]Wo[:[Foi>Rg`03o`000003ok7Yn?nMQ;SoUhFo00?oO7G10_oBh^<01?n0LKWo03_0oda1Y?n?K:H3
oj9mZ`;o_IZd00GoVY38omCHfooDf=_oBDneooGaY@03og^;f0;oR8[?0onOV/l2ojR^g003oijol?nS
^n_oXk_[00;oX[?T00So[<C[ojZki_nZ]n;oZ[ORokJohOnka^?oY[;Qok?4i`;oWJgR00Go]/c[ojNi
i_nW^NKoZ;gYojc7kP02ojF`g`04ojZgh_n[^>;oZ/K^oj[6kP;o[lW]00CoZKcWojVki_n[`n_oY;GU
0_n/`n/01On]_>GoZ/?/oj[3k?n[`N[o000000;oZL3Z00Co[<7YojVmionW^^OoYk[W0_n[`NT01on[
_nSoYkWVojg3jOn]`nWoYKSWojc1jOnV^NL00_n/`NT01_nW^NKoZ[oYojZlionZ_>OoZ;_WojNlj@;o
ZkoX0_nU]nH01?nX_NSo[L;YojJhi_nV^>H2ojc0j@;oY[WW00?o0000ooooooooool07?ooool000Go
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
ooooooooool000005?ooool2ojVmj003ojRlj?nZ_^SoZKgX00;oZKgX00?oZ[kXojVmj?nZ_^P00_nZ
_^P4ojVmj003ojZnj?nY_NSoZKgX00;oZ[kX00KoZKgXojZnj?nY_NSoZKgXojZmj?nY_>L2ojZnj0;o
ZKcW0_nY_NP00onY_^SoZ[gWojVli`02ojZmi`03ojVmj?nU_>[oXkWY00?oZkcV00GoYKg[ok:nhonb
_^?o/[kSojBch`03ojR^g005ojR]fonMX]WoSK3^ohf`k_nAbo`00_m=I/`01?mNJLKo/>Whoinbi_nO
/^H2okbieP07ojJKb_oTl]KoQGJjohEf^_o]j/WoNiORoi^KdP02olfja`04onWQbOn5PLOoQH77ok:T
bP;o`jNm00?o/jO<okRM_OnJQK`00_nJQK`01?mDZoWo]mO`okOGl?o8Zkd3okZP_P;o[I[30ol00002
olFebP07og1caOnMQ;SoWHBhoif4^?nGQKooO7G1omo]f`02oeUJ^@05oh1a^OnlWk_o_9nkokbO^on?
K:H00_nROJ/02Oobi[ko_IZdol^W]?ocd:goDP00odU?]OoRg=3oeo:Fog^;f002ohR;c`03ohR:cooN
jm_oWi[?00;oc<GC00?oZ:kLokZif?nS^n/00_nJ[^D01_n__NCoZ[_VojFnjonU_^_o[lK[ok_6h`;o
[M7c0_nca>L01?nM[N;o]LOXojNii_n/a^d2ok2khP05ojF`gon/c?3o[<c`oj[7k_nZa^h00_n[^nD0
1_nT]>CoZK_Vok77j_naan[oY;GUok31i`;oY;SW00KoZ/?/ojNgi?nX_NSoZ;gXo`000?nY^^H2ojRj
iP05ojNjion/`^Wo[<;YojVlionW^NH00_n^a>/01_nV^NOo[<7YojNjionW^^Oo[<7YojNji`;o[<;Y
00KoZ[cWojZojOnY_nWoZKoYoj^oj?nV^>H2ojVoj@05ojg2jOnV^>KoY[SVojc0j?n/`>T00_nW^^L0
0on[_nSoooooo`00000Mooooo`001Oooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooo`000?ooool01?l00004ooooo`;o00005?ooool2ojRmj007ojZnj?nX_>SoZKgXojVmj?nZ_^So
ZKcXojZnj006ojVmj0;oZKgW00KoZKgXojZmionY_NSoZKgXojZnj?nY_NP2ojZnj006ojVlion[_NOo
Z;cXojRlj?nY_>OoZ[gW0_nZ_^P00onZ_NOoZKgXojZmi`02ojZmj0;oZKkY00KoXkWYoj^li_n__^Go
[kkUoijkkOnb_^<2oj[6kP06ok:kh?nX[]coZ<7[ojS1jonN]^WoSK3^0_nXf_T01OnoaMkoCFK<ojgg
k_n]mnkoMIg[00;oSlom00OoVjgTomGnf?m@FKcoQGJjongZbOo1en_oN76n00?ocK[700?ojN79oijQ
e_nNXMH00oo3Ykd2okRM_@03olj]^?nJQKcoVXFl00;oRGFf00Co<I7_oiIh[omIJ<Oo^Z2n0ol00000
1OoInMko[jgFojn]e_o5]L[oYM3f00;oa[G:0_nMQ;P01OnGQKooVIG?omo]fooOkM_oFEZi00;oKUNW
0_nlWk/01on?K:KoXWf[oo;V__obi[ko_IZdol^W]?ocd:d00_mCHL@01_oGlYKohmS;oi6VhooQi]Ko
R8_?olk3d0;oQl7j00Ooc<GColO>goo7c]oo^[WHol_KiOnJ[^GoXZcN00;o[kkU00CoYKk[ojW2k?nY
`^coZl_`0onPYm/01_nR]nSo[;kWoj^nj?n[_^So[<K]oij[g`;oZ;kY00Ko[<c`ojRghonY^nKoZK_V
oj^kiOnV^^L2ojW1j`05ok77j_nT]^GoY;KUok31ion[`>T00_n]_nL01OnW]nCo[KoWoj^ki_l0003o
ZK[V00?oZKoY00Ko[<;YojRii_nW^nSoYk_Xojk4jonV]nH2ojc0j@04ojNjion/_nSo[;oXojNji`?o
Z;_W00KoZ[oYoj^nj?nY^nOoZK_WojJhi_n[`^X2oj^nj006ojJhi_n/`NWo[<3Xojc0j?nW^^OoZ[gX
0_n/`>P00ooooooo0000ooooo`0Kooooo`001Oooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`0Dooooo`;oZKgX00KoZ;cXojZn
j?nZ_NOoZ[gWojVlj?nZ_^P6ojVmj005ojRmj?nZ_^SoZ[kXojZmionZ_^P00_nZ_NL01_nY_NSoZ[gW
ojRlj?nX_>SoZkgWojZnj0;oZ;cX00?oZ[gWoj^mionY_NP00onY_NP00onZ_NSoZkgWojJhiP02ojJh
iP06oj>hion__^Go/LKYok76jOnK/NOo[koV0_nI]>/01_nUbo?oZ<7[oi_6m_nKa_KoUm?loj:bh`;o
SJ[Y00WoKJkhof2;i?mPRnCoH8_Toj3Jo?m9V?;o_=3Yo`0n`Om@FK`00_nUkj`01OlcE/Oo`MO[ogQa
__o=^/OojN7900;of??R0_nNXMH00oo3YkgodKS2okRM_@02olj]^005oiZ5_?o7Xk?oRGFfohUe]_nF
N:l00ol00002og9LZP03ojfJ`ooInMkoZIS500;oZIS500GoQW2colJeb_o6]L[oWHBhokg;i@02oiVE
c`;oEFK800OoFEZiofiGYom^EjOoKUNWo`0j/?n?K:KoIM6U00;oHTfS0_o;Yk@00oocd:gon]fWoe=Q
a002on?Hb`05on7Ve_nI[>GoVJcUolk3d?oMdll00_mkV^D00oo7c]oo/[CJol_Ki@02ojk3j@;oXZcN
00Co[kkUokCCl?nY`^co[JkG0_n_]Md01OnPYm_o/m3_ok?@kon/_^Oo[;GO00;o//KY00KoWZ_Ook7?
l?nc`>Co/l3TojRghon]_^L2ojVii@07ojJjion]`n[o[<7Yojc1jOnT]^GoZl7Yoj_0j@02ojRii@08
ojO0k?n]_nOoZ/7Zoj[1j_nZ`n_o0000ojVojOnY_NP2oj^mi`06ojRii_nZ`>[o[/;Xojk2j?nV]nKo
[<;Z0_nW^^L01on/_nSoZ;cXojc1jOn/`NWoZ;_Woj_0jOn[_^P00_nX^^H01?nW^nSoZl;ZojRjionX
^^L2ojJii`06ojc1jOn[`>WoZ;cWojRlionZ_NSoZkoX0_nX_NT00ol0003oooooooooo`0Jooooo`00
1_ooool2o`0000[ooooo0_l00002ooooo`Go00000oooool2o`0001Kooooo0_nX_NP01OnZ_^SoZ;cX
ojVnj?nY_^SoZ[kX00KoZKgX00KoZ;gXojVlionX_NSoZ;gXojZnj?nY_NP2ojZnj0;oZ[gW0_nY_>P0
1_nZ_^SoZKgXojVlj?nY_>SoZkgWojbmiP;oZKcW00GoZKgXojVlion[_NOoZkgWojJhiP02ojFhiP05
ojRlj?nO]^SoWkKXoinfj?n__nH00on^_ND01_nJ/nWo[koVojbihon/^N?oX[;Soj>jjP;oXl7^00Go
_MK/of2;i?nW`^goYl;]ohB/k`02okc@j@08o`0n`Onno>KoT9KEoi2FeOlcE/OoN76nol7HjonMS/@2
oi60_004of1YaOmo[O7oOjgaom6h`P?ocZfh0_o7Xk<00on9MKKo0000o`000002oiIh[`04okVE/_mb
G:[oLUbZog9LZP;oSg:^0_nYV<D2ohI`/`;oMVNe0_nmbnD00onIULooGdVQoeEVb002okJ@[`;oKUNW
00?okn31om>UZOoCYJT00_mRCJ<02Ol9;:golm2]oo?@[OojgJOoMV6^on?HbooHjn7odo_QoiV/i@02
oinVf`06omgCcoo4]LcoT<_loi3;o?nb]=[oeN?Q0onHW]P01_ncc>goYJ?DojFSe?nUXmCo[JkGok_H
k`;oY[k[00Co/m3_oj>ci?n/]Moo_LoX0_nJ/>L01Onaco3oXJgPoj6]h?n^anco[KkW00;oZ<C]0_n[
`n/02?n]`n[oZ[SSoj>diOnS]>GoZl7Yoj[0jOnX^NGo/LS[0_nT]^D01OnZ`N[oZkWSoj^ihonW^>Go
000000;oZKcW00KoZ;cXoj[0j_nY^^GoZK[UojJhi_n/`^X2ojJhiP;oZl3Y00SoZ;cXojc1jOnW^^Oo
Yk[Woj_0jOnZ_NOoZ;[VojVnj0;o[<7Y00GoZ;[WojNkionW^nOo[<7Yoj_0j@02ojRlj007ojVmj?n[
_nSoZkoXoj^oj?nW_>Soooooo`00000Kooooo`007Oooool00ol0003oooooooooo`0Gooooo`;oZKgX
00CoZ;cXojZmionZ_NOoZKcW0onY_NP01_nZ_NSoZKgXojVmj?nY_NSoZKcWojZmi`;oZKcW1?nY_NP0
1_nZ_NOoZKgXojZmionZ_NOoZKgXojRli`;oZKgX0_n/_NH2ojZkiP05ojVlionY^^GoYkWVojNii_nU
^>H00_nY`>X01_naa^[oWkKXojJljOnV_>WoZlK^ojjmi@;oZ/G]00Go[koVojS5k_nW_^[oYkkZoj>j
jP03ok:hgP08ohnLg?nM[nCoWJoToif_i?nKbOOoOIWTomKdhomFL=43og2Lj`04ojcid?njcn[oWHk4
oif>a0;oTH2l00KoH6W5oe^Bk?mKT^cobLoOolj]^?oFeML3o`0000;oaJ2c00CoUWR_om?2bOniUK;o
^IFb0_mbG:X00ooelZWoSg:^ojVHa@02on[bc@03ohI`/ooM^kKoMVNe00;o_HZO00KoSfZToem9XOmR
BZ3oEFK8okJ@[om^EjL2onoP`@;odjFY00GoHTfSokJ9YOnfRJGo2Bb]oo[MY`03ogIQ[P05oo3S`?nE
/ncoUK?/oinVfoo2m>l00_o4]L`3ogb2c`;o_/KP00GoV9kHol;YlOo2jO7o]kgOojFSe002ojkOn006
ok_HkonVZMSo/[WOok:igonS/nCoXKWZ0_nmcnP00onJ/>Oo/KcRoj6]h002okS:j006ojJhi_nXa>go
Y[3OojJ`gonZ]n?oZ[SS0_nZ_NL01?n^`^WoZ/3Yoj>eiOnS]ND2ok78j`04ojBfiOn]`^WoZkWSojc6
k@;o[<7Y00Go0000ojVnjOn/_nSo[;oXojVji@02ojVojP06ojk3jOnV^>Ko[<?[ojc3jonX^nOo[<7Y
0_nV^NH01_n/`NWoZ[gWojRkionX^nOoZKkXojc0j0;oY[WW00CoYk_Woj_0jOn[`N[oZl7Z0_nX_>P3
oj^oj003ojZmj?nW_>SoYkcX00;o00006_ooool001gooooo00?o0000ooooooooool06Oooool01_nY
_NSoZ[gWojVnj?nY_^SoZ[gXojVmj0;oZ[gX0_nY_NP2ojRmj004ojZmion[_NOoZkgWoj^mi`GoZKgX
00GoZKcWojZmionZ_NOoZ;cWojZliP02ojNnjP06ojbmi_nZ`>[o[;gVojbmi_nY^^GoZKoY0_nW_^X0
1OnY`>[o[/;Xojk2j?nS^>SoY[cY00;o/LGY00KoW[GXojfmi_nR]NKoX[GVojS5k_nQ/N<2ojBhi`06
ojZli_nb^=koV<kjoiS>n_neeO3oWJoT0_nkgO401OmUV>goJ8KMofR6gOmFL=7oL9c[00;oSI3B00Go
Cg?Goif>a?nMS/CoTH2lojJVeP02oijGc004ohVHg?l0003o0000o`0000;oBk?i00Goe][KolFP/one
nnKo]O_Vom?2b@02okVE/P05og9LZ_m3Dkgo@e>mohmb[_o9n[@00_m`EJ<2omfk]P05ogIW]OnmRYoo
_HZOohmZY?mOBJ400_mRBZ000onfT:ooKdRDonoP`@02okF>[P04om>UZOnfRJGo]XVUokJ9Y@;oTfnV
00Co000@ogIQ[_mfHJkol>?00on5R]02ol;dk`04olBec?oZlLgoO8;?olSGi@?oWj_O0_nKV]801_nL
_Noo[jO?ojNYf?nWZMSoYZWHokO5i@;o/KKM00?oXKWZojk4j_n^a>X00_nZ]^401?na_>;oYl3/okS:
j?n/a>/2ojnhh005ojJ`gon^a>_oZkkWoj^nionZ_NL00_n^aN/01_n]_NKoXkGUok76jOnaa^WoY;GU
ojg2j@;oY;WX00Ko[<K]ojNehonX^^Ko0000ojVnjOnY^nH2ojNji`06ojVoj_n[_>KoY[[WojJjion/
`n_oYKSV0_n]`^T01onV^NKo[;oXojVlionY_>OoZ;_Woj_0jOn/`>P00_nW^nL2ojNlj006oj_0jOn/
`NWoYk_XojNkj?nX_>SoZ[kX0_n[_nP01OnZ_NSoZKgXojRmj?nX_NSo000000Sooooo0ol00004oooo
o`;o00001?ooool2o`0000?ooooo000Mooooo`;o00006oooool01OnX_NSoZKkXojVmj?nY_NSoZKkX
00?oZ[gX00GoZKgXojRmj?nX_NWoZ;gYojVmj003oj^mi`CoZKgX00KoZKcWojZmionY_^WoZKkYojZl
i_n^_^H2ojBij006oj[0j_nU_>WoZL7[ojW1jonY_nWoZ<3[0_nY`^/01?n^`^SoY[WWojJiionW_>P3
ojBgiP06ojfmi_nW_NWo/LCWok74ionQ/N?oZ<Sa0_nWao001OnPaO?o[;WRoin_honO[n?oSjk[00?o
Tj3M00Go^mO^ofR6gOnbb>[o//SZokg@j002ohf@dP04odmceomoY>_oOjC[ojJVeP?o00000_nf[m80
1?n=WMkoOhgGogn=eomoSML2ohJFf`04ol^^_Onban[oZkORoeYQ_`;oMWK50_m3Dkd01OnTO:OoL5FS
og1EXom`EJ?ogK^f00?o_HZO00KoSfZToem9XOmOBJ7oHTZPookEU?m_B9@3okF>[P04om>UZOnfRJGo
]XVUokJ9Y@;oTfnV00KoFDZVogIQ[_o`hl3ogK^fomjh/_n5R]02ok^N^`04ognDg_o1]<koVI[DoloS
iP;o[j7900CoWj_OokZU`onjYL?oVi[B0on_Yll01onWZMSoZ;?PokO5iOngaNGo/KKMokoOl?n^a>X0
0_nOXMH01_n_an_oYl3/ojZbgOnZ/]go[<C[ojnhh0;oZLkc00Ko[/C[ojRkion[a>coZlC/ojk5jonW
]>82ojRii@07ok76jOnT]nKo[/7Xojk1j?nT^NSo[/7XojNeh`02ojc5k004ojboj?l0003oZL3ZojW0
jP;o[<3Y00KoZkcVoj[1j_n]_^Ko[KkVojFhi_n/_^H2ojJii`07ojboj?n[`>WoZ;[WojRjion[`>Wo
Z[kXojNki`02ojRmj005ojZnj?n/`NWoZKkYojVnjOnX_>P01?nZ_^P01_nY_NSoZKkXojVnj?nX_NSo
ooooo`0000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo000Mooooo`03o`000?oooooooooo01_ooooo1?nY_NP01_nY_^SoZ[gX
ojZmj?nZ_NSoZKgXojRmj@;oYkgY00GoZKgXoj^mion/_NOo[;gWojVmj003ojRlj006ojZmion/_nSo
Y[cYojJljOn^_^KoZl;Z0_nZ^nH01_nU_>WoZ[_VojJkj?nV^nSoZ<3[ojZkiP;oZ;WV00GoY[WWojW0
j_nY`>[o[lCYojBgiP02ojW1j`06ojNmjOn/`>SoXKSZoj6hj_nXb?7oY[CR0_nW]^<01_n/^N;oYLOa
ojG6lOnUa_7o]/3Roi>Pg@;oa=GV00OoNIgXok;8j_nieNko^MG^og2IjOn?^?;oTNOj00?o000000Go
W:7HoifSfOnMXmWo]ZoBoj[fk`02okNYb`06ogn=eonjXl;o^Z?2ohJFfoo;[[gofKNf0_n[]n82og9_
`004od=C_OniUK7oY7bWojAlY`;oL5FS00Wo_[gIokf:WonmRYoo_HZOoi5[Xom7?jCoGdVQof9:X?on
eI@00_m_B9@2okF>[P;o^J2o00Co]XVUo``DT_l000?o000@0_mIBZH00ooMa/;og[Rbomjh/P03ok^N
^`03onWk_Oo1]<ko[YS000;ocn?V00Co[j79okZU`onjYL?o^ZG30_niZl/01on_Yloo_/GOokk5gonX
/n3o^=kcojK?mOn]ZmD00_nXZ=H01OnOXMKoaN;]oj_5kOn[aNgoZ[;M00;o_mg^00KoW[3Toj6XfonQ
Z=_oXJSKojRkion_^N42ojZdh006ojNdh_n/b_3o//[/ok;:k?nT]nKo[<;Z0_nZ_>H00on^`NSoYKSW
ojc5k002ojJgi@06ojRlj?l0003oZKkYojVnjOnX_^[oZ/7Z0_nV^NL01_nY`N_o[;kVoj_2jon[`^_o
ZK_Voj_0j@;oY[[W00?o[<3XojZnj?nX_NP00_nX_NP01OnY_^SoZkoXoj^oj?nY_^WoYkcY00;oZ;gX
1?nZ_^P01_nY_^SoZ[gXojRmj?nX_NSoooooo`0000Oooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo000Mooooo`;o00007Oooool2
ojVmj0;oZ[gW00KoZ;gXojZmj?nY_NSoZKgXojZmionW_NT2ojNlj005ojVlion/_NOo[;kWojbnionX
_>P00onX_>L01_n/_nSoZ[kXojJjionV^^OoZl;Zoj>ij0;o[L;Y00KoZ[_Vojc1jOn/_NKo[;gVojZk
i_nY_^T2ojRmj@04ojW0j_n/^nGo[;_Uoj:eiP?oYK[X00Ko[<3XojNkj?n``^Oo/<;WojJdh_nY`^`2
ojW7k`06ojG7lOnT/n?oV[?YoiZcjOnGaOOoXZkP0_nR]nP00onF^o7oU:GQoiBUh@03o`0000;oXZ_M
00CoVI_EoibQf?nLXMSoWJ?I0onaYL/01?ngZL_o^?O`okZS`_oLg]P2ol^^_@05omVg]_mFJ/coEV[<
oeYQ_ombKl000_niUK42ojAlY`;oL5FS0_nn_MT2okf:W`03oi5[Xom7?jCoAcnT00;oo]FD0_m_B9@0
2OneSZkoLfBcog=T/oniX;oo]XVUoo2lV?l000?on=NYoeU:YP02omg6`P;og[Rb00CoM5VUok^N^ooY
nkgoZ:;@0_n^V<02ohei^0;oOWBn00Oo^ZG3ogUe`_miML;o^J_;ojGgeonnaMoo]=Sb00?oZ9c:00Go
[J_EojRXe_nV]>?oY[CSolGRk@03oiNLe`;oWZOL0_ne_^000onQZ=_o]LWYojnih@02ojc?l`06oj_<
lOn/b_3oZK;OojVbgonT/^?o[<;Z0_nU]N@01_n]_^KoYKSWojo4jOn_a>WoY[OUoj_1jP;o[<?[00Ko
0000ojVii?nY^NCoZKWTojJiion]_ND2ojFhiP06oj_2jonT^>Oo[/;Yojk2jOnV^^OoZ[gW0_n[`>T3
ojRmj0;oZKkX0_n/_^P01?nW_>WoZ;cXojVnjOnY_^T4ojZnj005ojZmj?nY_NSoZ;gXojRmj?l00000
1oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool000[ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo01gooooo00CoZKgXojZmionZ_NOoZ[gW1?nY_NP01_n[_NOoYkcXojJkj?nV^nSo
ZKcWojbni`;oZl3Y0_nX_>L2oj^oj006ojZnj?nU^^So[/3Wojk0ionS^NSo[;kW0_nV_>T01_n/`NWo
YkcXoj[0j_nZ`>[oZKkYojVli`;oZ[gW00Go[;_UojS1k?nX`Nco[lK[ojFjj002oj[0j@06ojNkj?n/
`n[oX[OWoj:gionY`^co[[kV0_nZ]n801onT/n?oZKoYojjli?n^_>CoXZkPojk>lOn[_^P00ol00002
ok;Im005okOBk_n?W=coRK7`ohVal?nKcoX00_nL_Nl00on]]=ko/JG;okk@j002ojfLaP03ofi`a?oL
g]Sog=kH00;ofKNf00?ohl:foeIZc?m9H<L00_mbKl002OniUK7oY7bWojAlYom`EJ?oO5ZOoe/mU?nn
_MWo_HZOo`000002oi5[X`;oAcnT00?oo]FDofm8U?m_B9@00_nMJiL02?mcI;?oMefWokJ9YOo`_9So
31BBooSGZOlj?:SogLK20_miFj<00ol0003oM5VUogAIY@02ojRRd0;o[YS000?ol>;0ohei^?oF/;<0
0_mnM;h00oo;YK;oNGG2ohb2``02ohb2``;oZiK100GoZ9c:okV]cOnZX/koZZ;>ojJdh`02ol[SjP06
ojjaf_nGW=OobM7PolWAh?nNYmco[koV0_nSb?<00onebNWoY[[Wojc?l`02ojR[f@06ojV_g?nY/]oo
[LO]ojg7kOnbb^coYKGT0_n/a^`02_nZ_nWo[lCYojFgi_nU]nKoZl7ZojfoionW]^?o0000ojVii?nZ
_nT2oj^oj006ojfmiOnZ`^_o[[oVojjoi_nT^>OoZ[gW0_nX`>/00onZ_NOo[KoXojRmj002ojRmj0Co
ZKkX00KoZkkWojRlj?nY_>OoZKcWojVnjOnZ_^P2ojVnj003ojZnj?nY_NSoZKgX00;oZKgX00?ooooo
o`000?ooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool000Wooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01oooooo00CoZKgXojZmionZ_NOoZ[gW0_nY_NP2ojVmi`05
ojZnj?nV^nSoYk_XojNkj?n/_^L00onV^NL01_nX_>Oo[<7YojZnj?nZ_^SoYK[Xoj^oj0;oZ;kY00Ko
[;kWoj_1j_nZ^nKoZ[_VojNlj?n[_>H2ojNiiP08ojVlionY_nWoYkkZojNnj_nX`NcoZk[UojBeiOn^
`nT3ojFhiP06ojc3j_nQ]^Oo[LK/ojg6k?n^_^KoY[[W0_nY_^T00onY_nWoY;g[oio3lP03o`0000;o
]LSX00KoR:;UokO9j?n/_^Oo[;kWohnLg?nYg?T2oj;Cn@0;ogS2o_nT[n3oW:WOoibYgomAP>7oDFK9
ojfLa_oKk=koKW34onSfcooI]kH00_oS`[H2ofER^P;oGVG200?o^IFaomni/Oo]`jT00_nAOkd2oe/m
U007okf:Wol[7hoo0000oi5[Xom7?jCo`i^^ookEU002ofm8U0;oWF^G00KoLfBcogMMYoo`_9Sol;bH
ooSGZOnePih2ocXlZ0;oNE^S00Ko0009ogAIYOmdFJGol/fZojRRd?n^V<02oo3R`0;oe[2c00KoOWBn
ol^U/_o;YK;oNGG2olFS]_n<P/<2ol>X_P06oj^F`Oni[Lgo^Jg=okV]cOnZX/ko]:gA0_nMV<h01OnR
ZMco_ncboko/l_n]^nCo[koV00;o^lcW00KoXJWLojJjionf^]go][[MojR[fOn_e?<3ojg7k@05ojfj
h_nQ/^CoXK;Tojc6k?nV]N@00_n]a>/00onU]nKo[L7Xojfoi`02ojJfi006ojZmiol0003oZL7[ojW1
jonX`>_oZ/;[0_nV_NX01_n[`NWoZ[gWojk0ion^`>OoYK_Yojfoj0;o[;oX0_nX_NP01?nY_^SoZKkY
ojVnj?nY_^T2oj^nj006ojVlion[_NOoZKgXojVmj?nY_^SoZKgX0_nZ_^P2ojVmj0;oZ[gX00?ooooo
o`000?ooool00oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`002Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo
0_l0000Qooooo`06ojVmj?nZ_NOoZ[kXojZnj?nX_NSoZKgW0_n[_^L01_nW_>SoYk_XojZnj?nZ_^So
[/;YojJii`;oZKcW00Co[<7YojRlionX_>SoZ;cX0_n[_nP2ojJji`06oj_1j_nT]nKo[<;Zojc2j_n[
_>KoZ;kY0_n[`^/01_nY_nWoZKcWojZmionZ_NOoZk[UojS3k@;o[/?Y00?oYKSVojo5jOnQ]^L00_n`
`nP01_nS]^KoY[[Woj_6kOn[a^goZL3ZojBmj`;o000000KoZ;CQoijcion^`NOo[/7WoiRfkOngbNP2
ojjmi@;oRJKX00KoZMcioj:TeonRY=OoXZCGojB_h?nN`?02oh_7o003ol_Gh_mAI/Wo[_WW00;oM8[J
00So07SMon?2]_oKnMco0000ofER^_oXnl7oGVG2omni/@;okL>Y00?o9B>Foi5o_OmK?I@00_mK?I@0
0ol[7hoo0000oi5[X`03ol>K[P06ofm8U?nMJiOoWF^Goie[UomcI;?oMefW0_o`_9P2okF3WP06ocXl
Z?o;XZkobj:^ogUKXoomdg;oM5VU0_obcJX01?ocgKOoSi3@okZK^?oii:d2omJ`/`?objFb0_o5XkH3
ol>X_P;o`;K@00?o^Jg=okOam?nd[M400_nd[M401?nMV<ko/J[Aoko/l_nJV=02ojbWdP05ok_<ionN
WM?oWYgCok?DlOnf^]d00_nYc_<01_n_e??oYK7Pojfki?n]^nCo[K[Roj_3j`;o/;oU00SoY[GTok?2
iOnS/N?oXk7Sojg1j?n[_nSoY[KTojc2jP;o[<G/00Ko0000ojVki_nX_>OoZ;cWojJmj_nW_>P2ojRn
j@05ojk0ion]_nOo[KoWojNljOn/_nP00_n[_^P4ojVmj006ojVnjOnX_NSoZ[kXojZnj?n[_NOoZ[kX
1onY_NP01?nY_^SoZKgXojVmj?l00005ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o
00000oooool000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo027ooooo00KoZKgXojZnj?nY_^SoZKkXojRlj?n[_^L2ojVmj006ojNkj?nZ_^So
[/;Xojk2j?nU]nKoZKcW0_n^`nT01_nX_>OoZKgXojZoj?nZ_nSoZkoXojJii`;o[/7X00KoY;OVojo3
jOnU^>KoYKSVojRnjOn/_^L2ojRiiP04ojVlionZ_nWoYkkZoj^li@;oY[OV00GoYK[XojjmiOn^_NGo
X[OWok33j002ojFjj003ojJmjOn[a^go000000;o000000Go[;WSojK7lOnVao7o[<W_ojk1i`02oj_1
jP05ojFahOn^_NGoX/7_oj;1konic>T00_nV/n800onRY=Oo/]cfoik0l002ojbfh003oiNfkOmBX_Ko
//;V00;oDG;F00WoM8[Joj7Xnon4^?KoQ;Sfoh6gmooXnl7o^KoNok?g^_oO^K400_o]`jT02Ol=D/ko
9B>FogaJWomK?ICoHcj?o`000?l[7hooTF^SokZN_002ol>K[P05ofm8U?nMJiOoWF^Goie[Uoo^ceT0
0oo`_9P2okF3WP?obj:^00?oNE^SoogCL_mdFJD00_obcJX02?ocgKOo^Y^hokZK^?oii:gogOZ_omJ`
/ol0DkOobjFb0_o/h<H01_o5XkKoelC7ol>X__o:`]?o`;K@ol7Yl@;oaoG]00?o`MOZokB]dOnSU<D0
0_naZ]402?oIo/3oVYS@oiZHd?n/Ym;odO_SoijMdooAmNOoVJ7J0_o2fn`01_n]^N;oYK7Pojk0ion^
`>Oo[<G/oj_3j`;oY[CS00GoZLG^ok?2iOnX`>_oZ<3[ojjoiP03ojBei@06ojc2j_n_aN[oZKcWo`00
0?nY^nKoZ[gW0_n[_NL01_nW_>SoZKgXojNmjOnW_NWo[KoWojboj0;oYkgY00?oZkkXoj^oj?nY_NP0
0onY_NP01OnX_NSoZKgXojVmj?nX_NWoZ[kX00;oZKkX00KoZ[kXojVmj?nZ_^SoZ[kXojVmj?nY_^P3
ojVmj003ooooool0003ooooo01Cooooo0009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Rooooo`?oZKkX00OoYk_XojVmionY_NOoZKgXojNm
jOnY_NSo[L3X00;oY;SW00KoZKgXojo3jOnW^^OoYk[WojVmj?n[_nP2ojZmi`06ojJiion/`NSoYKWW
ojFiion_`nWoY;SW0_n/`^X01_n/_^OoZ;cXoj_1j_n[`N[oZ[oYojVjiP;oZkcU00?oY[OVojZojOn^
_ND00_n[a>`00on/_^OoYK[Xo`000002o`000005ojFgi_nV_N[oY[gZojO5konVao400_nW^>D01_nR
^^[oZl7ZoiV_ionI[nOo/<c^oj;1k`;oZL;/00KoXJcNoh^hm?n[`N[oZl7ZoibXgon/]^02okKKl`05
ojC1k_nb`^Ko//;Voe5be_nce?400_ml/_H00on@XMooF6W9oeQYb@02okVogP0:o`00Koo]`jWo2c>d
ojiM0?lU8iKoO5ZOoe/mU?mS?Xoo0000ob/OS`;o^Yjl00?o`i^^onO5/onDI9H00onMJiL01?oR[9co
?bnEoo2lV?ongIL2okF3WP03omWAEoo;XZkobj:^00;ooM=b00?oOf>Xoo;=Z_ocgKL00_o@`ld00onj
VkSonNB]olcZj`03oj:di@03o`1WdonOhocoelC700;ocO3[00?ob/;Cok;khOnOT/H00_nVTL001_nE
Q/7oXiC5oj>DaOnSU<Go/J[Aohao`0;oYJgM0on8Ql`2oi>=b`06ol;Kk?nTVlcoYZOGojJWeon^`>Oo
/KKL0_nY[]`01_nV]>?o/kWMok>igOnS[=goZ<3[ojFchP;o[lW]00?oY;GUojg1j?n_aNX00_nX_NT0
1?nX_>Oo0000ojZmionZ_^P2oj^oj004ojVmj?nY_^SoYkcXojNlj0;o[;oX0_nW^nP01?n[_nSoZ[kX
ojVmj?nZ_^P3ojVmj004ojZnj?nY_>OoZKcWojVnj0?oZKgX00KoZ[kXojVmj?nZ_^SoZ[kXojVmj?nZ
_^P2ojVmj003ooooool0003ooooo01?ooooo0009ooooo`04o`000?ooooooooooo`0000Sooooo0_l0
0005ooooo`;o00009?ooool2ojZmj006ojNkj?nX_>SoZkoXoj^oj?nW_NWoZ;cX0_n]`>P00onT^>Oo
ZKkYojo3j@02ojJhiP03oj^nj?n[_nSoZ;_W00;oY[_X00Ko[<7XojFjj?n_`nWo[l?YojBhion^`nT2
ojNiiP07ojRlj?n]`^WoZK_VojVki_nY^^KoZ/3ZojS0j`02ojNkj003ojJnj_n[a>co000000;o0000
00GoZK_Wok35j_n`aN[oY;KUojJmjP02ojk4jP06oj^ki_nW^>GoZkcUoj^liOnW]nCoVJoW0_naanX0
1OnX]^?oSZWXohjYj?n>ZNSo^][`00?oSZo]00KoX]Cioj6ZgOnQZ]goXJ[Moj6ahon0WnL2oj[0jP05
oigFo?mUQ=co_l_Toko;i?mHJLT00_o:cmh01oo0[LKo]=KaomVd/ol0053o9B>FolFBX_mK?I@00_mS
?Xl01_l[7hoo^Yjloe[=YomJcJOoilFcoiATUP;oWF^G00Cok/mIon:/W?oR[9co?bnE0_ongIL01One
PikofM5Gohm_Z_n?Kj[ooM=b00;o^i2Z0_m6AJ/2om33c@05ooWT[OndjiCoc>[[ol>oe_nR]>D00_n/
UKl01On;Um[o]9g1oj2ai?o2[lKoSY_K00?oWi;600KoYY70oiF6`OnEQ/7oXiC5ol7jjooDdmL2ohao
`003ojF]gOoPkm_oR8O<00;oe_oE00OoThg;ojBKc?nTVlcoY9_<ojJWeoo2hnoo/KKL00?o/[cR00Ko
/kWMojcCm?nganKo]lOVojFch_ngaND2oj2ei`03ojg1j?na`nOoZ;gY00;oY[cY00KoZKkYo`000?nZ
_nWoZ[oYoj^oj?nY_^P3ojRmj005ojboj?nZ_nWoZ[oYojVmj?n[_nP00_nY_NP01_nZ_^SoZKgXojVm
j?nY_NSoZ[kXojVmj0;oZ[oY00CoZKgXojZnj?nY_^SoZKkX1?nY_NP01OnZ_^SoZKgWojVmj?nY_NSo
000001Cooooo000:ooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Cooooo0_nW^nP01onX_>SoZkoXojRmj?nX_NSoZ;cXojc0j?nU^NP00_nY_^T01on]`>OoY[SVojg2
jOn]`^WoZkgWojRkionY_nT00_n[_nP01_nU^^So[L7XojBhionT^>Oo[/?YojBhi`;oZ[kX00?o[L;Y
ojFhi_nY_^P00_n/`>P00onZ_>KoYk_Xo`000002o`000005ojFfiOn_`^Oo[l;Woj>gion`aNX00_nQ
]^L01_n/`>So[/CZojFchonU/n?oZ;WUoj^li@;oY/3/00KoYLG`ok77j_nP/^GoX;;UokG8j?n>ZNP2
okK7i`06oj>]g_n>[ngo[[SQojjhhOnY/mooXJ[M0_nZ_>L02OnK]^_oZ/3Zoko8hOnob>7o@HCXoko;
i?noc>CoJ8CKol[?gP02ol?Ok@;o]=Ka00ComnbbolFBX_o5TZ;o0`F50_mS?Xl2ohaRW0;oP6>W00Go
ilFcoiATU_nDI9KoWF^Gonk?F@02on:/W005oooIT?ongIOoo]fGomWAEonGJid00_n?KjX01?omdg;o
^i2Zok^@Z_moHjP2odI5Z`05ol>ldonec>co^;GFokRee_o3_mH00on/UKl2okBM`@;o`Zo600Ood/gD
odZ8jOnOT/KoWi;6ojJA`?nVVl_oYZoN00;o`_c000?oe=?Gohao`?o6cn400on?OK`2oh=c^P;oQ7Vo
00?oY9_<okcIkonLUlh00_nLUlh01_n]/mgo/[cRojWLnOnYg?Wo[=?doj2gj0;oYl[b00Co]lGUok35
jOnW^nSoZkoX0_n^`NL01_nV_>WoYkgYojVojOnY_nWo0000ojVoj@;oZ[kX00OoZ;gXojRlj?nZ_^So
Z[kXojZojOnX_>SoZkoX00;oZKgX00CoZ[kXojVmj?nY_^SoZKkX0_nY_NP2ojZnj003ojVlj?nZ_^So
ZKgX00GoZKgX00OoZ[kXojVmionZ_^SoZ[kXojZmj?nY_NSo000001?ooooo000Looooo`;o00009_oo
ool2ojRmj003oj^oj?nY_NSoYkcX00;o[<3Y00KoYK_XojVnjOnZ_NOoZ[gWojFhion]`^T2ojNhi@03
ojVmj?nY_nWoZKcW00;oYkcX00Ko[L7XojFiion^`NSo[/7XojBhionZ_^P2ojg1j003ojFhi_n[`>Wo
[<3X00?o000000GoZ[cVojO1k?nW`NcoZL;/ojo2i`02ojNnjP06ojjoi_nQ]^OoZ/3Zoj[0j_n__^Go
YK?S0_n[anh01_nZ`^_oY/3/ojbji?n/^^CoY;;Roj2bi@;o/l_/00KoXKSYojbkiOnJ^^koV[[^ok71
i_n^^>42ojVnj@07oj:di_nZ_>OoZ<3[ojS0jonS/nCo_lSQok6df`02oenMl@;o_lcT00KoJ8CKojfd
g_n@/NgoAVC=ofjFj?o8o]h2olFBXP03okO9C_mS?XooHcj?00;oS6:L0_n0HjL01?nMI8koilFcoiAT
U_nMJiL3on:/W004o`00??m^FJWoKUVYomWAE`;oUf^M00KoSfnZoogCL_nkT:[o^i2ZogmSZ?m6AJ/2
ol>ld`03oiZ2^?nh]MKo/9Nm00;o/YVm00Wo[9FoolJ^`_o6[/;o]9g1omS3aOo2[lKod/gDom?Zi_l@
L^400_nFYN001?nVVl_obnc/omomc_nX^nL2ohUj_007olK?hOoOkM_oSgflohmm_?n^eVSoPg>jol7X
QP02ohAi_`;o^kOF00?oW9O>ok_Xm?n_joP00_n[/M`01_nV[]koX;OXojnlhon__>?oW[[/ok35j@;o
Z/3Y00[oZkoXoj_1jOn]_nOo[KoWojNmjOnX^nOoZKkYo`000?nY_nWoZKcW0_nY_NL02?nX_>SoZKkY
oj^nj?n[_^SoZ;cXojZnj?nY_NSoZ[kX0_nY_NP01_nY_^SoZKgXojVmj?nY_NSoZ[kXojVmj0;oZ[kX
1_nY_NP2ojVli`03ojZnj?nZ_NSoZKgX00;oZ[kX00?o0000ooooooooool04?ooool001_ooooo0_l0
000Xooooo`;oZ[oY00?oZKgXojRmj?n/`>T00_nW^nP01_nY_NSoZ[gWojJjj?nV^^So[l?XojNhi@;o
[/C[00?oZkgWojVlionY_^T00_n[_^L01onU^NOo[;kWojJlj?nV_>SoZ[kXojc0j?nU^>H00ol00000
1OnW^NKoZ[oYojZojOnZ`N_oYl7/00;oZ;WU00KoYkWVojNnj_nV^NKoY[WVojRmjOnZ`>X2ojJkj006
ojFlj_n[ankoY[CSojJdhonX^NGo[;[T0_nV^nP01onV_n_o/<S[oj>hj?nS^>So[;_Uok71i_nL]>T0
0_nWa>h01_nY_^WoXKCVojS1k?nX`NcoZ<3[oiNmlP;o//GX00Oo/KCKol3;hon5T]Woc=_TofA`bOn]
]=ko]>Sg00;oGWCA00OoAVC=od]C^Om;DkWoaI:RokO9C_miQ=;oHcj?00;oS6:L00Koom69oh1SYonM
I8koilFcoiATU_nMJiL3on:/W00?ok2Tbom^FJWoKUVYooSQPOo_cJooUf^MoogCL_n8J:Oo^i2ZofjR
l?meT>3o24K5ol>ldonhZL_oVX:h00?o/9Nm00Go/YVmolC6foo6[/;ocngYomS3a@02omcWg00>om;=
e?nkg?3o?G7KoceafomOW?7obnc/omomc_n=kNWo>F3>ohUj_?oColco/ocLofiaaOn?OK`2of5P^`;o
JVc200?oQ7Vookgj^onk]mH00_nS/>401?nkj?Co`]g]oj^ag?n/^^@2ok:nh`03ojnlhond`nKoXk_Z
00;oYKg[00KoZ[kXoj_1jOnX`>_oZ<3[ojfoionX^nL2oj^ni`06ojVliol0003oZ[kXojZnj?nY_^So
ZKkY0onY_NP01OnZ_^SoZKgXojVmj?nZ_^SoZKgX00;oZ[gX0_nY_NP2ojZnj003ojVmj?nZ_^SoZKgX
00KoZKgX00SoZKcXojZnj?nZ_^SoZ[gXojVmionZ_^SoZKgXo`0001;ooooo000Kooooo`03o`000?oo
oooooooo02Sooooo00GoZ;_WojVmj?nY_NSoZkkXojNkj002ojVlj006ojRkionV^^So[KkVojfni_nT
]nKo[/C[0_nV^>H00on[`>WoZKkYojRki`02ojNmj@03ojbnion[`>WoZ;_W00?o000000Go[L;YojVl
ionY_>OoY[WWojZoj@02ojbni`06ojZiiOnX^NGoZ/3Zoj[0j_n]_nOoY[WV0_n/a>`01_nZ_>OoY[_X
ojRmjOnX_NWo[l3VojJdh`;oZ/;[00GoZKgXojJkj?nZa>go/<S[oj>gj002oj>gi`04ok71i_nZ_nWo
Z[oYojZnj0;oWko_00?oXKCVojfnionV^nP00_n^c>l01OnE`_KoU/_joiK;n_o0bn?oQ<Om00;oc=_T
00CoI739of=`b_mSL<[oGWCA0_lEA<401?m;DkWoKFc0o`00QOneO002of<nS`08ohaRW?oodHWoWFB>
oieTS_oWaK?oU6BFoie[UonMK9P2on:/W003odZVn?n`Y<_oKUVY00;oklf_00OoUf^MohQXYon?i:Go
PZ7XokKRmOm7ZOSo24K500;of_7Q00GoVX:honGae?n`Ukgog^?HolC6f`02okg>i`05olo]jOmlh?Oo
g>OLol[Oj?o@f^400_nkg?02oceaf`05oiVdjoo6n[Koa_ZfocUPc_n]iOT00_neo=X01_m^LLGo>ES6
ocUHa_mQH;_oCVS=ofY/`P;ogok<00CoSY[Joj>`hOo=l>_o`=o_0_nM[N802?n/^^Co[/CZok74j?na
a>So]<?Vok;5j?nU_N_oY;OW0_n]_nL01_nX`>_oY[[Woj_1j_n[`N[oZkkWojVoj@;oZ[oY00?o0000
ojZmj?nY_NP00_nY_NP01OnY_^SoZ[kXojVnj?nY_^SoZ[gX00?oZKgX00KoZKkXojVmj?nZ_^SoZ[kX
ojVmj?nZ_^P6ojVmj004ojZnj?nY_>SoZ[gXojVmj0;oZ;cX00GoZ[kXojVmj?nY_NOoZKgWo`00000A
ooooo`006oooool2o`0002[ooooo00GoZKgXoj^oj?n[_nSoZ;gXojVlj002ojNki`06ojRmjOn]_^Ko
Z;oZojRoj_na`>GoY[SV0_n^`NP00onY^nOoZ;_Woj^oj002ojNki`;o00000_n]`^T00onT^>Oo[L7Y
ojVli`02ojNki`06ojg3j_n/_^OoYk[WojNjionY_nWoZ/3Z0_nW_>P01_nW_n[o[<C/oj>eiOnS]NGo
Z[oYojRmj@;oZK[V00CoYKg[oj[2jonT_N_oYl?]0_nX_NT01_n]`NSoXkOXoj>gj?nS]nOoZkoYojZo
j@;oZKST00Oo[lGZoi2akOn@/Ngo[KkWoj[9kon^c>oo[;OQ00;oXZ[L00OoT:gZojnfg_nIX]coVJ;L
ofb9g_o;jN_oFf6n00;oHg3:00Ko_/GOoaE4`OlEA<7og^7Go`00O?lN::02of<nS`;oom690_nMI8h0
3?mmBXWoU6BFoie/V?nMK9SohZbLokF6Xom:Y_SoATR`ofiIZOmWf;koklf_oiM[W@?oMh7@00?o]^;e
ojgLn?nCZND00_o<g^H01omgVNKoCkWjodnin_oNhmSoZ=Khokg>ioo2d^H00_mDW?<2oefoo@05om3J
hOo4j?3oa>S`og6Hj?m1Rnd00_o<g^H00omgU^CoUk?[omKgh`02og:4eP;oJXWN00?o>ES6omSkgOm>
J<d00_nme^`01_n8coooWK;WolSKioo8fnOo`=o_oiRik`;oY;k/00Co[/CZojg6k?n_a^[o[/S]0_n^
a>X01_nT]nOoZ;cXojo3jOn_`nWoY[[Wojboj0;oZ;_W00GoZKoYojRlionY_NSo0000ojZmj002ojVn
j005ojVmionY_NSoZKgXojVnj?nY_NP00_nZ_^P01OnY_NSoZ[kXojVmj?nY_NSoZ[kX00SoZKgX00?o
Z[kXojVmj?nY_NP00_nZ_^P01onX_>SoZ[gXojVmj?nY_NSoZKgWoj^nj?l000004Oooool001_ooooo
00?o0000ooooooooool0:_ooool01On[_nSoZ;_WojRkionX_NSoYk_W00;oZ[oY00KoYkWVojRoj_nW
^>GoYkSUoj[0jOn^`NP2ojVlj008ojVojOl0003o0000o`000?n/`>SoY[WWojk1j?nT^NP2ojbni`06
ojRlj?nW^nOo[/CYojk4jOnW^>KoYk[W0_n/`^X01_nZ_NOoYkcXoj^oj?n[_nSo[;_Uoj>ei@;o[L;Y
00CoZKkYojVji_n^`nWoZKWU0_n__nD01_nY^^GoZ;gYoj^nj?n[_^SoYKgZoj6lk0;oXKg]00KoZkoX
ojVhi?nd_n;o];oRojBeiOnG/NT2oj_8kP05ojg2jOn/]n7o[;OQoj:Zg?n``NH00_n_]]h01?nIX]co
Rk_fol_Yjoo;jN/3oj>Yf`?oSgVg00Co002;onFl[?mS?XooHcj?0_oodHT2oieTSP04oge:ROnDI9Ko
WFbHoie/V0;o]HJS00?o@016odI8/?m6B;000onIV]@01?nk^MSoMh7@okkel?n`aNT2ohJMhP03olcN
i_nSc_KoZk?N00;o`lcQ00GoR[7_oijijonN^N_o`];VokW1h002oh>em@03ofbZm_nR^>Soa>S`00;o
TK_c00GoUJoYolcNi_nT_^coY;k/og^cm`02omKgh`04og:4e_o@mNOoJXWNokgNl0;oJYo_00Oo_MK/
olGPk?mbU^KoLYKVolSKioo:dn7o`LWQ00;oVK?Z00KoY/K`ojg6k?n[bO3oZlW`ojk8kOn[^N@2ojFf
i@04ojRlj?n]a>_oZ;cWojboj0;oZKcX00KoZkoXojRlionZ_^SoZ[kXojVnjOl00003ojVmi`03ojZn
j?nY_NSoZKgX00CoZKgX00?oZ[kXojVnj?nY_NP01_nY_NP00onZ_NSoZKgXojZnj002ojVnj006ojVm
j?nZ_^SoZKgXojVmj?nZ_NSoZ[kX0_nY_>L00on[_^SoZKgXo`00000@ooooo`006oooool2o`0002co
oooo00GoZ;_WojZojOnZ_nWoYK[XojZoj@02oj:fi`05ojk5jonW^>Go/<KZok36j_nZ^N@00ol00000
1?nX_>SoYkgYojVlionU^nT2ojVli`06ojRmjOn/_^OoZ[oYojZojOnW^nSo[/CY0_nS]^H01_nY`N[o
[<;ZojNii_nW^NKoZ[kXoj^oj0;oY[_X00?oYkgYojg2jOnZ_nT00_nT^NL00on^`nWoY;o/ojnoi@02
oj^mi`06ojjni_n[_^SoZkoXoj^oj?nV^^SoXKg]0_nQ]^L01onS`Nko];oRojo;k_n_bnkoY;CToj_8
k_nU[ml00_nO[n<01OnN_nooW:WPoj>hionS^>OoWl?b00;o[kON0_mFGl001?mKHKkoXjWKo`000?lD
8I`2ohmi]`;oYXbj0_mS?Xl01OoodHWoh?^coieTS_nMI8koODZ900?oWFbH00Wo]HJSolBBXOmdRm_o
ATR`ol;mi?nb[mGoVI[DojkSnOnC`?H00_nmjo<00on`aNWoUJoXokC9jP02okc=i`05ognYkoo3c>7o
_mG[okoEjon:/>l00_n^co401_ni`N3o`m_[ohN`l?n7/?3oX[SXojo0iP;oR9kR0_n^jOT01onT_^co
Z/C]ok3Cl_n`do;oOj;Yok_<ion?Xn800_ng`n<00onS`>koRJk^ojW2k002oi_3m004oiVll?nSaO7o
`LWQok_8i0;oY[CR00GoYL;^ojZdh?nZ]>3oZKOSoj^ii002ojVnj006oj[1j_n]a>_oYkWVojNii_n[
`>WoZKcX0_n[`>T00onY_>SoZ[kXoj^oj002ojVmj003o`000?nY_NSoZ[kX00;oZKgX00KoZ[kXojVm
j?nZ_^SoZ[kXojVmj?nY_^P2ojVmj003ojVnj?nY_NSoZKgX00;oZKgX00?oZ[gXojVnj?nY_NP00_nY
_^P00onY_NSoZ[kXojVmj002ojVmj005ojZnj?nX_NSoZ;gXojZnj?nY_NP00_nZ_>L00ol0003ooooo
ooooo`0=ooooo`006oooool00ol0003oooooooooo`0/ooooo`05ojZojOnU^^SoYK[Xoj_1jOnR]^L0
0_naaNT01onP/nGo0000o`000?l0003o[lCZojbkiOn^`nT00_nZ_NL00onY_>OoZKkXojVli`02oj^o
j@06ojRjionZ_nWoY[WWojJiion_`nSoXkKV0_n^a>X01onZ^nGoYkWVojc0j?n/`>SoZ[_VojJkj?nY
_nX00_n[`n/00onZ_nWoY;WWojfniP02ok30iP06oj6kjon[_NOo[;gVojbmi_n_`NOoZkoX0_nW^>D0
1on[^NCoXKKWojbki?n/^nCoW;?Xojo;k_nI/NP00_nhcNX01_nU[mooYlSaok7Al?nadO3oW:WPoj[?
l`;o/<_]00goWko_ojngg_n_]mkoEUo0oi6/j?lXA;[of?Z/oa@QW?n?NKOomnZeoloof_nVS;[oHcj?
00;oSi_K00Coh?^coieTS_nMI8koODZ90onMK9P01oojaHkoLhWJom3Lh_o@g>;oKYo_ok6khOnD]o00
0_n]]Ml01onZ^NCoX:kQoj2^hOnE[nSoY/;^okc=ion__nH00_n:^OD01_noeN_o[;_Uoig2l_nM`_;o
V/?dojVfhP;o[/;X00KoQjKXok;6jOn_`>Ko[l3VohRNh_o2fn`2oi:Yi@04oj[4kOnd_>3oU:gWojNj
iP;oW<Wg00Ko]l?Sok_9iOnL]>WoW;CYojW2k?n_`^L2oiJfkP08oj?5lOnLa_Go^lSTok_8i?nV]>;o
]<7SojZdh?n^a^`2ojboj006ojVnj?n/`>So[;gVojbmi_nW^NKo[<3X0_nX^nL00on[`>WoZ;cXojZn
j002oj^ni`?oZKgX00Co0000ojVmj?nY_NSoZKgX0_nY_^P00onZ_^SoZKgXojVmj006ojVmj003ojZm
j?nY_NSoZKgX00;oZKgX00?oZKkXojVmj?nY_NP01OnY_NP2ojRmj0;oZKkX00CoZ[cWoj^oj?l0003o
00003_ooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`?o0000
1?ooool00ol0003oooooooooo`0^ooooo`04ojFjj?n[_nSoZkoXoj6gj0?o000000So//CWoj:diOna
`>Go/L3UojFgi_n`_^CoZ;[VojVoj@;oYkWV00KoZ;kYoj^ojOnU^^SoYK[Xojg2jOnV^NL2ojk2j007
ojBgion^a>[oXkKVoj>fi_nY`^_o[<3XojRojP02oj[1jP07ojVoj_n[_nSoYk_WojNkionT^NOoZ;gY
ok30iP02ojnni@06oj2gjOn/_NKo[l;Xojo2j?n^`^SoYkSU0_nW^nL00on[_^Oo[;_TojW5kP02ojo2
j006oiVaj?n_a^_oV[?YoiZcjOnWb?7o[:oJ0_n7Znd01OnZco?oY:OHojR^fonX[]_oTYKC00;oHGKA
00CoQlcnomcXgOlXA;[o526L0_no_mT01_oTe<Ooj>S>on?Ic?n?Vm_oUHG0on3k/`;oWFB>0_mmBXT0
1OnMK9Son/F>oo[5S_n1Y^cod=cR00;o^=?^00Co/K_QokS0h?n]]Moo/[_P0_nQ/nD01_nV`nkoY[gY
oj^ji?n[^^Co[koVokK4i0;oVKkb00Ko[;_UokS<jOnR]^OoX[KWojVfh_nee_42oj2kk004ok;6jOn/
^nGoVK[_ojo2j0;oX;3S00KoXl[dokBlh?nac>go/Lc]ojNji_nhaN@2ohjck`08ok_9iOnba>OoYKo/
ojFok?n_`^Oo[/7Xoj6gj?n``>D2oiN`j006ojk>lOnd`N?oZlkboj_>l_n^a^coZ;_V0_n[_nT02?n/
`>SoZL7[oj[2jonZ`^_o[<3XojVojOn[_^OoZkkX0_nY_NP00on[_^OoZ[kXojVmj002ojVmj005o`00
0?nZ_NSoZ[gXojVmj?nZ_NP01onY_NP01OnZ_NSoZKgXojVmj?nZ_NSoZ[kX00KoZKgX0_nZ_NL2ojVm
j0;oZ[gX00OoZ;gXojVmionX_>SoZ;cXoj^oj?nZ_>Oo000000kooooo00001Ooooooo0000oooooooo
oooo000000Wooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o
0000<?ooool3o`000006ojg0j?nO]>Oo[KkWojfnionT^NSo/L3U0_n[`^/01?n`_^Co[lG[ojfni_nW
^NH2ojfoi`06ojVlionU^^So[<3Xojc0j?nU^NOo[/;X0_nU^^P02?n_`NOoXkKVojjoi_n^_nKoY[SV
ojRoj_nY^nKoZKkX0_nZ_NL01_nX_NSoY[_XojNojonW_n_oZ<3[ojnni@;o[L3W00OoX[SXojo2j?n_
`nSo[l?XojFfiOnW^nOoZL;[00;oYl3[00KoZLG^ojFahOnT]>CoY;CTojo6jonQ[N02ojc7k@06ojb_
f_nkenkoY:gMojB]gOnTYmSoZm[h0_n</Nl02_mc/OSoWZSMoijXgOmaO<ooAeBloe9VbOno_mWoi=C7
onSXc_oOk=X2oj:Nd004oiF5`?oPnk?oWFB>oieTSP;oODZ900SoWFbHoo[5S_ojaHko/>7hojRnjOng
`^;oW<KeokS0h0;o/Lk_00Ko/[_Poj6ciOn_`^Oo[l;WojJmjOnQ_>`2ok35jP07okK4i?njanCoTJ_W
oi6[ionhc>WoZ;oYoifmk`03oj>_h006ojC4l?n/^nGo//o_ok;?kon_`^SoWl7`0_ng`n<02?nB[>So
Yk_Xoj;2l?nR`_3o^<GTokK3i?nG]^go//CW0_nb`nL01_nS_ngo[/7XojS4kOnXa>go/<3UojW8k`;o
[KgV00SoWkGXok;7jOnU/n?oYK?SojRki_n/a^goZl?[ojW1j`;oZ[_V00KoZ;cXojZmionX_NWoZ;gY
oj^nj?nZ_^P2ojVnj0;oZ[kX0_nY_NP01?nY_^So0000ojZnj?nZ_NP2ojZnj0GoZKgX00?oZ[gXojZn
j?nZ_^P01?nY_NP2ojZmj0CoZKgX00KoZ[gXojVmj?nY_NSoZKgXojVnj?nY_NL2ojZnj005ojVmj?nZ
_>OoZkgVooooool000003Oooool00005ooooool0003oooooooooool000002Oooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool00000;_ooool3o`000006oooooonS^^WoZ;oZojRo
j_nS^n[o[KkW0_nY`N/02?nX^NGoXk?Toj>ci?nS/nCo[lG[ojJfi?nY_nWo[KoW0_nZ_>L01_nX_^Wo
[<3XojJkj?nV^nSo[L7XojFjj0;oZkgW00?oY[gZojjoi_nY`N/00_n^_^H00onY^nKo[KkWojZmi`02
ojZmi`06ojNljOnW_n_oZ;SUojRhiOnT^nWo[L3W0_nW`N`00on[`>Wo[l?XojFgiP02ojW3k006ojW2
jonW]^?o[;SRojbhh_nU/N7oZ<_b0_ndaNL01?nQ[N3o^/gXohf/jon]]Ml2oi2[j005oh_Ao_nLWMCo
SJk/ohf^k?n@bo`00_nhdN`02?nNZ=goLGc?og5lcom7E;coDVK9ojR/f_oPm][ogncJ0_n0Nl<01?nE
QL3oh?^coieTS_nMI8h2oge:R@05oie/V?ojaHkon/F>ohnflOng`^800_no`m`02?n@ZNOoZl;[oiO5
monGaOOo/L_]ojS1k?n]bnooXKc/0_nTbo@01_nZdOGo^/OTojc9k_n/bNkoYkOTojRoj@;oZl3Y00So
[lS/oj>_h?nhb>Oo^<SWoiZ_i_naa>SoY[WWoio1l0;oV[G[00Ko[lCYojNkj?n_`NOo[l7Woijjk?nf
`n@2okG4i@08oi^hk?nb`nOo/lW[ok?9jonQ/^Co/L?Woj:hj?nYb>l2oinciP06ojW2k?nbanWoXkKV
oj>fi_n[`^_o[<K]0_nZ_>L01?nY^nKoZ[_Voj^nionZ_NL2oj^nj005ojRmj?nZ_^SoZ[gXojZmj?nY
_NP00onZ_^P3ojVmj004o`000?nY_NSoZ[kXojVmi`CoZKgX00CoZKkXojVmionY_NOoZKgW1?nY_NP0
0onZ_NSoZ[kXojVmj003ojVmj0;oZ[kX00KoZKgXojZnj?nY_>SoZKcXojZnj?nY_>L2ojRmj003oj^m
i_n/_nSo000000gooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000002_ooooo0ol00006ooooo`;oYK[X00SoYKWWoinci_nO
/nKoWk?Vok?;k?nS/nCo]/SXojJfi0;o/<KZ00KoZKSTojZlion]_nOo[KoWojVji_nV^nP2oj^nj008
ojNlj?n[_NOo[;oXojboj?nV^NOo[[kVojBkj_n/_NL2ojboi`06ojg1j?nZ_NOoZ[cVojZli_nZ^nKo
Z;SU0_n[_>D00onW^>KoYl7/ojFhiP02ojboi`07ojFgi_n`a>WoZ;KSojRfhonW]^?oZ<K_ojK5l002
ojbliP03oindi_nN]n[o[/O/00;oY[GT0_n]]Ml00on@ZnSo][cNoibMe002ojNTdP04oiR@b_nCTLko
Ti7>oh63c0;oDeo100?oAeBlojR/f_oPm]X00_oHnMl01?nGWMSoP7_3oh1k`ooPnk<2oieTSP;oODZ9
00SoWFbHoo[5S_o4TZ7o/l?Vohn`kOno`mco^mS_oj_2j`;o]=;_00GoVjgTojS1k?n`an_o/<O[oj75
lP03ojZfhP08oiffjOnL[N?oW:gSoib]hon_bnkoY[_Xok31i_nH[ND2ojZliP06ojS8l?naa>SoZ/7[
oj[1jon`_^GoV[G[0_nR_>`00onY_nWo[l7Wojo3j@02oj2gj@03okG4iOncbN_oWkCW00;o[/7X00Oo
X[OWok73ion[_^SoZkkXojo3j?nO/nKoZl;Z00;oZl3Y00OoXkKVojg1j?n_aN[o[lGZojZlionX_>Oo
Z[gW00;oZ[kX0_n[_^P01OnZ_^SoZKgXojVmj?nZ_NSoZkkX00;oZKgX00KoZ[kXojVnj?nZ_NSoZ[gX
ojVmj?l00002ojZmi`04ojVmionZ_^SoZKgXojZnj0;oZKgX00CoZKgWojVnj?nZ_^SoZ[kX1?nY_NP0
0onZ_^SoZKgXojVmj005ojVmj004ojZnj?nY_NSoZ[kXojRmj0;oZkgW00GoYk[WojVojOn[_>KoZkcV
o`00000<ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`04o`000?ooooooooooooooo`Co
00001?ooool2o`0002Sooooo0_l0000:ooooo`;oY;c[00So[LG[oinci_nfb^Wo]/[Yoi^^i?nca^So
Y;WXok36jP;oXK?U00Co[/CZojfoionX^>GoZ;SU0_n[_^P2ojVmj004ojNjion/_nSoY[cYojjniP;o
[/;X00KoY;WXojboion^`^Wo[/;YojVlionZ_>H2ojZmj003ojRlj?n[_>GoZLC]00;o/<GZ00OoYKSV
oj_2j_nV^^SoY[[Xok34jOnR^>SoZ<G_00;oZ;KS00?oZ;[Vojbli_nV^>H00_nT^^T01_n^ancoW;K[
oj:nkOnR_^go[lk`okJlgP;oT<Gi00Co^l_WojNTd_nWY=;oV93:0_nCTLh02on1PlcoDeo1oe=O`Omo
U=koa?kNoj7ec_n4Y>WoIWC=oh1k`onR`>ooh?^c00;oWFB>0_mmBXT2oo[5SP03olBBXOn/_NKoU:gX
00;o/m_d00KoZKoYokCBkonD/^coU;;/ojc0jOn`an/2ok;0i003ojJah?nZ]^;o/<KZ00;oZkSS00?o
W:gSokC=kOnV^nP00_nY^nH02?nS`o3oZ[cVokK4iOnfa>GoX[[Zoj[1jonU^nWo[/3W0_n^`^T01_nR
_>_oZKkYojg3j_n]`n[oZ<3[ojFkj0;o[lO[00?oYKOVojk1j?nW_NT00_nY`N/01_n[_^So[/G[ojFh
i_nU^>KoZl;ZojW1j`;oXkSW00Co[L7Xok32j?nX_>SoYkcX0_nY_^P01OnZ_^SoZ[oYoj^ojOn[_nWo
Z[kX00?oZKcW00KoZkkXojZoj?nY_>OoZKcWojVnj?nY_>P2ojVnj004ojZnj?l0003oZKkXojVli`;o
ZKgX00GoZ[kXojVmj?nY_NSoZKgXojVnj009ojVmj008ojVmionY_NSoZ[gWojZmionY_NSoZKgWojVm
j?nX_NP2ojRki`;oZKoY0_nV]^@00on]_>Go0000o`00000;ooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`;o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo
0ol0000=ooooo`;oZkkX00SoW;3Vok?4ionL/NKoW;7Vok?6j?nX_^Wo/<?Xoj6ci@;o/LOZ00KoZ;cW
ojRhiOn^`NSo[/7Xoj^ojOnY_NP2ojNlj@04ojbnion[_^SoY[cYojk2j0;oYkkZ00KoZ;cXojk2jOnX
^nKoZ;_VojRji_nZ_NP2ojVnj@03ojJnjonYa>goZKST00;oY;KU00OoZl;ZojFiion^`NSo[/7Xoj:h
j?n__^GoZ;KS00;o[LC[00?oZkcVojJhi_nY`^/00_n_a^/01OnL]^_oXk7Rojo4jOn_a>WoVZSP00?o
UYoJ00CoMKkmoh>knOn3^oWoWL7b0_n3WnD01OmNO=SoJJ?bojGQnonNh_goWJGK00;o@g3I00?oIWC=
oj;0kooOnmH00_nMI8h2oge:R@06o`00D_o4TZ7oa9:QokK7j?nSa_;o/m_d0_nM[n@01?nf^mkoW:oU
oib_iOnadO02oj6bi006ojJljOn[aNcoZkWSoj^ihonS]^OoYKg[0_n_bN`00onV_NWoZK_Vok?2iP02
oiZdjP08okK4iOnc`NGoY[cYojJljOnU^nWoYk[Vojk2jOn/`>P2oj:eiP06ojg3j_n/_nOoY;GUojBe
iOn_an_oXkKV0_n/`n/02?nW_NWoZl?[ojJhi_nV^>Ko[/G[ojBhion/`>So[/7X0_nR^NT01_nX_NSo
ZkkXojfnion]_^OoYkcXojRlj0;oZKoY00CoZ[oYojZmj?nZ_NSoZ[gX0_nY_>L01_nZ_^SoZ[oXojRl
ionX_>OoZ[kXojVlj0;oZ[kX00CoZKgXojVnj?nZ_NSo00000_nZ_^P8ojVmj003ojZmj?nY_NSoZKgX
00?oZKgX00OoZKkXojZnj?nY_NSoZKgXojZnj?nY_NOoZ[kX00;oZ[cW00KoZ;_Woj^mionX_>OoZ;cW
ojJfi?nY_^P2ojo2j003o`000?oooooooooo00Wooooo0002ooooo`;o00002_ooool01?l0003ooooo
ooooooooool5o`0000;ooooo00?o0000ooooooooool08_ooool3o`00017ooooo0_nN^>/02?nca>Oo
Y;CTojk6jon^a^_oZ;kYojboionQ^N[o/LOZ0_nW^nL02?nT]^Go[/7Xojfni_n]_^KoZKgXojVlionW
_NWoZkkX0_nY_nT01_n[_NOoYkkZojBhionT^>Oo[/?YojRkiP;oZ;gY00?oZl;ZojVnjOnZ_>H00_n[
_>H00onY^>CoZ<3[ojo6j`02oj>fiP07oj^nj?nW_n_oXkOVoj>gi_nX`Nco[LC[ojFljP02ojO1k006
ojW2jon/^>;oY;3QojB`hOnS/N;o]<k]0_nE/N/00onkd>[oUYoJoko0f`02ohNCf005ognemonAQ/Co
THK4oi66a?mjVN@00onSRk/01_nMYM_o/;SOod=`fOnOboKogo_Fon3/fP;oWFB>0_mmBXT00on?YNCo
a9:QolBBX@02okWJl@03ok6igonM[nCoWl;a00;o_=;[00?oW:oUokO<j_nQ/^@00_nYanl00on]`>So
ZkWSoj_4k002ojW3k@06ojo9k?nV_>WoY;WXojBij?nc`^Ko[KoW0_nP^n`01?nc`NGo//7UojJnjonQ
]NH2ojjoiP06ojc0j?nT]^Ko[L7Xojg1j?n/_nOoYK_Y0_naan/02?nS]^Ko[L;YojNhiOnW^>GoZl?[
oj:hj?n``^OoY;SW0_nY_>L02?n^`NSoZkgWojBkj_nT^n[oZkkXoj^ojOn/_NKoZ;cX0_n[^nD01_nY
_>OoZ[gXojZki_nZ^nKoZK_VojVli`;oZl3Y00CoZkkXojRlionZ_nSoZKgX0_nZ_^P00onY_NSoZKkX
ojVmj002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_nY_^P2ojVmj0;oZ[kX1onY_NP01OnZ_^SoZKcW
ojVlionZ_^SoZ;gX00;oZKkY00SoZkgWoj^nj?nS]nOoXkOWojVnj?n/aNco[L?Zo`0000_ooooo000I
ooooo`;o00008?ooool3o`0001Gooooo0_nW_^/01?nT]>Co]L_ZojJnj_n/_nL2ojVli`06ojbnionZ
_NSoXK_/oj6kk?n__^Go[lCY0_n]_ND01?nY_>OoZ[cWojVmj?nY_nT2ojJii`06ojg2jOnT^>Oo[/CZ
ojk4j_nV^NKoZ;gY0_n/_NH01?nX^NGoZ[cVojZmionW_>T2oj_1j@07ojbmi_nS]^KoZ[kXojZnj?n]
`NSoXkOVojk2j002ojVii006ojFlj_nY^>CoYkKTojNfi?n/^>;oYK_Y0_nV`>`00ondc^goX:_Nojbe
g`02ohR/k@03oko0fonLdO[o//CX00;oZIO300CoTHK4okbfdonWT;goYi2m0_nSRk/01?oC_/Ko/;SO
ol6ccOmnTmd2ojK]n@;oWFB>0_mmBXT2ohnUi004ok6lh_nI[nKoVJoVojo?l0;oYk3N00OoZ/?[oj:e
i_ncaNSo/lGXoj>bhonYanooX[CU00;oY<G`00KoZlC/oj_2jon]`n[o[L?ZojJljOnT_>/2ojRnj@04
ojfoion^_^KoXKc]oj2diP;o/lKX00KoXKGVojNljOn`an_o/<O[ojBfi_n[a>`2oj^oj004ojFkjOn]
_>GoY;OVojg2j@;oY;g/00So/L?Wojc1jOnW^nSoYk_Xoj[0j_nW_>So[;kWoj^mi`;oZkcV00OoY;_Y
oj^ojOnW`>_oYl3[ojfoion[^nGo[<3X00;oZkcV00?oZ[_Voj[1j_nZ`>T00_nZ_>H00onX^nKoZKgX
ojZnj002ojVmj004ojZnj?nY_NSoZ[gXojZmj0;oZKgX00CoZ[kXo`000?nY_NSoZ[kX1?nY_NP2ojVl
i`04ojVmj?nZ_^SoZKgWojZnj0KoZKgX00CoZ[kXojVmj?nZ_^SoZ;gX0_nY_>H01_nW^NKoZkkXojNn
j_nW_^[oY[o/ojc5k0;ooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000ooooooooool0
7?ooool3o`0001Wooooo0_nJ]^`01?nebn[oZ[SSojJiionY_>L2ojbmi`06ojZmj?nZ_NOoX;g]oj2m
kOn_a>WoYl7/0_n^`NP01?nZ_>OoZl3Yoj^oj?nV^NL2ojk2j@08ojBgi_n^a>[oY;OVojBgi_n[`^[o
[;gVojRoj_n[`^X2ojJji`07oj[0jOn[`NWoYkWVojNii_nW^^OoZ[kXojc1j@02ojBii`06ojk2j?nT
^^Wo/<CYok34jOnY^>CoZ<7[0_nX_NP01?nU^nWoZ/C]ok70iOnPZmh2ojS1k003ok;El_n=Z>So/];`
00;oU9?@00?o587VojVG`onEj?X00_nl]]<01OnWT;goXh^kom>na_oC_/Ko`K?=00;oel?600CoOY?M
okK4iOnMI8koWFB>0_mmBXT02?o3bn3oSjGTok6lh_na_>;oVJoVok;;k?nW/=ko_=3Y0_nO/>@02?nc
aNSoX/?aokG2i?ne`^CoX[CUok6ni?nS^NSoZkkX0_n[_^L01_nX_>SoZ[WTojBhionT^>OoZ<7/ojBg
i`;o/<?X00SoX;CVojboj?nX_>SoZ;cXojNljOn^`>OoXkKVoj_4k0;oY[OU00SoZL7[ojfliOnZ`N_o
Z/7[ojfoion^`>OoY;WXojc1j@;oZ;cX00OoZkkWojNlj?nW^^OoYk[Woj_0jOn[_>Ko[KoW00;oY[WW
00SoYl3[ojFhi_nY`^coZL;/ojc0j?nX_^WoZ/?/ojVii@;oZK_V00KoZ[cVojZojOnZ_nWoZ[oYojZn
j?nY_NP2ojZnj003ojVmj?nY_NOoZKgX00;oZKgX00?oZ[kXojVmj?l000001_nY_NP01?nY_^SoZKcW
ojVmj?nZ_^P2ojVli`03ojVmionY_NSoZKcW00;oZKcW00KoZKgXojVkionY_NOoZKgWojVli_nX_nX2
oj[0jP03ojNnj_oooooooooo00?ooooo00?o0000ooooooooool02Oooool001Wooooo00?o0000oooo
ooooool06Oooool3o`0001gooooo0_n[^N@01?nZ^>?o[KkWojRkionZaNd2ojc0j008ojZmion]_nOo
Y;GTojBei?nW`NcoYKGTojZojOn[`>T2ojZli`08ojJljOn^`^WoY;SWojBhion_a>WoY;OVojk3jOnV
^>H2ojg2j@06ojZjiOnV^^Oo[;kVojbni_nZ^^GoYkWV0_nY`N/00on[`n_o[<7YojBfi@02ojc1j@08
ojBjjOn/^nGoY;_YojBkjOnX`N_oY;WXojO2k?nY]N82oj>bh`05oifbi_nX`Nco]lCTokO4i?nBWmd0
0_m[PmT01OnDTm3ocNcZohj=cOn>SLgoFHWU00;oJFFk00GoVn;mom>na_oVl=?oKMkGomO3aP02omCn
f003okK4iOnMI8koWFB>00;oODZ90_ndbNX00onN]>So[LW^ojjoi`02oiJajP06okc@jOnR`Noo[l7W
ojo1ionR`o7oVkGZ0_n^`^T01?na_^Co/<7Voj^nj?nZ_^P2ojZji@08ojZii?n[^nGoZkSSoj^hhonT
]nOoZk_UojJljOn/_nP2ojZoj008ojVnjOn^`>OoYkoZojNoj_n_`NSoY[OUojnoi_nS^NP2ojVli`07
ojNnj_n^`>OoZkgWoj^mionY_NSoZ;cXojRki`02oj[0j@06ojNjion/_^OoYkkYojNnjOn]_nOoZL7[
0_n]_^L01?nU^>Ko[/3WojJgiOn]`nX2ojbmiP06ojViiOnZ`N[oZ/3Yoj[0jOnZ_nWoZ[gW1OnY_NP0
1OnY_NOoZ[kXojZnj?nY_>OoZ[kX00;oZKcX00?oZ[kXo`000?nY_NP00onY_NP00onZ_^SoZKcWojVn
j002ojZnj006ojVlionY_^SoZ[kXojZnj?nY_>OoZKkX0_nZ_^P01OnY^nOoZ/3YojRmjOnX_NWoZ;oZ
00Wooooo00?o0000ooooooooool02?ooool001Wooooo0_l0000Gooooo`?o00008Oooool01_nZ^nKo
[LS]oj[1j_nZ`N[oZ/G]ojBij0;oZKoY00So[KoWoj>kj_nbaNSo//GXojFei?n_a^_oZ[gWojZli`;o
Z/3Y00SoZkoXojFjj?n_`^So[l;XojBgi_n_`NSoY;WXojg2j@;oYK[X00OoZl?[ojbni_nX`N_oZ<7[
oj[1jonY`N_oZkgV00;oZKWT00SoY;KUojk2j?nV_>WoY[cYojbkiOn^a^coZK[UojW4k@;o[;cU00Go
ZKGRoj>bhonTbO?oY<WcojS?m003oi^/h`03okgDjom[PmWo_mg^00;oJX?I00KoJ=_?okRQ`OnhXL7o
JFFkomc5`omNLm02ol_:f@;oVIWA00CoXM?ioi^fjonMI8koWFB>0_mmBXT01_ndbN[oY[?Rojk6k?n^
a^co[[oWojRhi@;oZlC/00CoX/7_oingjOnea>Ko[[oV0_nS^nX01_nX_^WoZKgXok33j?n``nSoZ[kX
ojFfi@;oZK[V00CoZk_UojS4k_n^`nWoZk_U0_n^aN/02?nW_NWoZ[oXojW2jonY`^_oZK[Vojo3jOnW
^^KoY/3/0_nS^^T00on]`>SoZKcWojfni`02ojJlj@06oj^mion/_^OoZKkYojVnjOnX^nOo[;kW0_nV
_>T01?n/_^Oo[L?ZojNii_n^`NP2ojFhiP06ojS0jonW^NKoYkgYojNmjOn]`n[oYk[V0_nY_^T00onZ
`N[oZKcWojZli`03ojZmi`03ojVmionY_NSoZ[cW00;oZKgX00?oZ[kXojRlj?n[_^P00_nY_NP01?nZ
_^SoZKgXojVmj?l00003ojVmj0;oZKcX00KoZKkXojVmj?nY_>OoZKcWojVnj?nY_NP2ojVlj003ojVn
j?nY_NSoZ;gY00kooooo00?o0000ooooooooool02?ooool001Wooooo00?o0000ooooooooool04ooo
ool3o`0002Gooooo00Ko[LS]ojJljOn^^N;o[[WRojBij?nY^N@2ojVhi004oj>kj_n[^nGoXkOVok;7
j@;oY[OU00KoZ[kXojc1jOnX^nOoZ;_WojFjj?n[_nP2ojFjj004ojo1j?nX_NWo[;kWojFjj0;o[;cU
00?oYKWWojS1jonY^ND00_nY_>L00on[_NKoYk_XojRnj@02oj_0j@03ojZlionT^NSo[lCY00;oX[CU
00KoZLC]oj2di_nU`nooYL?_ojK9l_nX/Ml2ojZag@07oibVg?nK[>?o_=S^oh2IhOndgOGoPHgFofZ3
f@02om?ShP08okRQ`Om?DkKoCe>fomc5`omVMLkobl[IomCnfonIVM42olcmh@03oi^fjonMI8koWFB>
00;oODZ900?o[Lc`ojJch_ngb>L00_nW`N`01?nX^>Go/l;Uoj_1jOnU^nT2ojJmjP06ojjoi_n^_NGo
Y;o/ojBok?nY_NSo[/7X0_n]`NP01?nU]^GoZ;oZojS4k_nXa>h2ojFhiP04ojJljOn^aN_oZK[VojRi
i@;o/<;W00OoX[SXojo3jOnX`>_oZ<3[ojjniOnS^^WoY[cY00;oZKgW00Ko[KkWojc1jOnV^nSoY[_X
ojbnion]`NT2ojJjj004ojbnion/`n[oY[WWojg1j@;oY[WV00So[/7XojNkj?n]`^Wo[L;YojNii_n[
`N[oZkoXojNjiP;oZl7Y00?o[;oXojVlionY_>L00_nZ_NP02?nZ_NOoZ[gXojZmionZ_NOoZ[cWojZn
j?nZ_NOoZ[oX0_nZ_NP2ojVmj0;oZ[kX00?oZKgXo`000?nY_NP00_nY_NP00onY_>SoZ[kXojZnj002
ojVmj005ojZnj?nY_NSoZKgXojVmj?nZ_nT04Oooool00ol0003oooooooooo`08ooooo`006?ooool0
0ol0003oooooo`00000Booooo`;o0000:Oooool01_nV_>WoWk_/ok71iOna`NGoZKWTojS0j`;o[[gU
00CoZk_UojRii_nbanWoY;CT0_n]`^T02?n/`NWoZ;_WojRlj?nX_>SoZkoXojNlj?n[_NOoZ;gY0_nW
^^L02?nZ`N[o[;cUoj[2jonZ`^_o[KkVojViiOn/`>WoZ[cW0onY`N/01_n[`>WoY[SVojJhi_nX^nOo
[lCYoj6fi`;o/LCX00SoX;CVojo5j_n[]n;oZkORojRagonUa_3oXL?aoj;=mP;oZkGP00CoRjKWogEn
comeO/ooPHgF0_m:Fl801Om?D[Kok_C5odmC]_m?DkKoIWG>00;oe?[R00KoKi7Sol[Sj_nIXmcob=OU
on3k/onMI8h2oge:R@;oUJoY00So]lSWokK6ionM]^WoWKKYok?2iOnd`^GoYK_YojJiiP;oYKo]00Co
[[gUok?2i_nP]^Oo[/7X0_n]`^T02?nT]^GoZ;oZojjni_n^_^KoZ;OTojFhi_nZ`N_o[LG/0_nS^NT0
0onX_>So/<;Woj_2jP02ojRki`06ojS0jonT^^Wo[[kVojjni_nV_>WoYK_Y0_nZ_NL02?n/`NWoZ;gX
ojNjionW^^Oo[L7YojRlj?nX^nOo[l?Y0_nU^>H01?n]`NWoYk[Wojboj?nW^nP2ojc0j007ojJiion[
`N[oZ;cXojRlj?nW^nOoZl7YojVnj003ojVli`03ojZmj?nZ_^SoZ/3Y00;oZKoY00KoZKkYojVlj?nY
_^WoZKkYojZoj?nY_NP2ojZnj003ojVmj?nZ_^SoZKgX00;oZKgX00?o0000ojVnj?nY_>P00_nZ_^P2
ojVmj003ojZnj?nY_NSooooo01Cooooo00?o0000ooooooooool02?ooool000Gooooo0_l00004oooo
o`04o`000?ooooooooooooooo`Go00001?ooool2o`00013ooooo0ol0000]ooooo`07oj6nk_n[_^So
[LC[ojg4jonT]^Ko[LC[oj:ci002okC:jP06ojBdi?naa>SoZkgWoj^mionX^nOoZ;oY0_n[`>T2ojNl
j008ojc2jOnW^^Oo[/;Xojk2j?nT^>Oo[/3WojBhi_nY`N/2ojNii@07ojRmjOnY`N_oZ[[UojZjiOnX
^NGoY[SVojW4k@02ok34j@06oj6fion/`n[oY;OVojBgi_n_aN[oX;7T0_nT`nl01?nUa_3oY;GUoj^j
i?n[]N02ojS0j`0=ok:aeomeO/oodNOVoeUT`om:Fl;oc__UoeQadOm?DkKod?joohFBfOo?om[oS:KV
ok_QlP02oiBUh@03olSGiOoPnk?oWFB>00;oODZ900?oY/?^ojBkjOn[_^P00_n/_nL02?nS_>_oY;o]
ok;2i_nb`^KoY[WVojjki?nO]^So/l;V0_n/a>`02?nX_>So[L;Yoj>hj?nS^>So[<K]ojjni_nW`ngo
Z/;[0_nY_nX00on]`^WoXkWYojFjj002oj^oj@06oj_2j_nV_>Wo[KgUojfmiOnT^^WoY;SW0_n_`NL0
1?nU^nWoY[WWojg0j?n[`NX2ojJiiP04ojc0j?nZ_nWoY[WWojo3j@;oYkWV00OoZl3YojNjion[`>Wo
Zl3YojVlion/`>SoYk_W00;o[<7Y00SoZ;cXojNkj?n/`>So[<3XojVnj?nX^nOoZKcWoj^nj0;oZ[oY
00OoZ/3YojVki_nY^nOoZK_WojVlj?nZ_NOoZKcW00CoZKgX00OoZ[kXojVmj?nY_NSoZKkXojVmj?nZ
_^So000000CoZKgX6?ooool00ol0003oooooooooo`08ooooo`001?ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03?ooool3o`00037ooooo
00OoW[SZojg4jonO]^SoWkKXok7;kOnR/nCo]l[X00;oWk7T00Ko/LCXoj^mionZ^nKoZ[_VojRojOnY
_>L2ojRlj0;o[;oX00SoYKWWojg0j?nV^^OoY[[Wojk0ionW_NWo[/3WojNii@;o[L;Y00SoZk_UojZj
iOnY`N_oZL7[ojO0jonYa>goZ;OTojBgiP;o[lCY00OoX[CUok32ion``^OoX;7Tok;:k?nX]nCoYk_X
00;oYl7/00?oY<;_oi2WiOn@YnD00_mk`?d01OoAinKoFFC3oiW//_m]OM;oF77A00?oOh_E00SoSZCT
ok_4h_nka>;oQZS[ok[9i_nob^?oh?^coieTSP;oODZ90_nO^N/02?n[_^SoZl3Yojbmi_n/_NKoY;o]
oj>gion/a>co[[_T0_n]a>/01?nV^^Oo[lCYojFgi_n]`>P2ojNnjP07ojjniOnU]nKo/;oUok2oiOnV
^NOoZKoZojZliP02ojRjiP06ojFjj?nX^nOo[KgUojfmiOnV_>WoYKSW0_n]`NP01?nT^>OoZKcWojc3
j_nU^>L2oj^nj004oj_1j_nU^>KoZl3YojZoj@;oY[[W00?o[L?ZojNii_n/`NT00_nW^^L01_n[`>Wo
Yk[Wojc1jOn/`NWoYk_Wojc0j@;oZ;gX00CoYk_XojZnj?n[`>WoYkWV0_nY^nH01On[_^So[<7Yoj^m
ion[_NOoZK_V00?oZ[gW0onZ_^P00onY_NSoZKkXojVmj002ojVmj006ojZnj?nY_NSoZKgWojVmj?l0
003oZKgX6oooool00ol0003oooooooooo`08ooooo`001?ooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00Cooooo0_l0000:ooooo`?o0000=Oooool01onY_^WoWkKXok;5j?nbaNSo
VJoWokO:j?nQ]^P00_na`nL01?n[_NOoZ;[Vojo3jOnX^^H2ojVli`08ojRlj?n[_^SoY[[XojJjj?n]
`>SoZ;kYoj^mionW_NT2ojRki`04ojNnj_n]`^WoY[[XojJjj0;oZL7[00KoZK[Uoj^jiOn[^^GoZ;OT
ojW3k?n_a>T2oj:gj003ojg6k?nR^NWo/<GY00;oXK?U00OoYk_Xojg8k_nZ^>?oZ[SSoj6/gon@YnGo
/KON00;oXioA00WoDGGHodMSc?m7HlcoKGgBof2Ek?moRmGogN7Hok[Ol_nka>800_nba^T00onK]^_o
_l[Son3k/`02oieTSP08oge:ROnc_nCoXKKXoj6fj?n[`>WoYl?^ok71i_nS]nL2ojfmi@04oj:fi_n^
`n[oYKWWojo4j@;oY[[W00Oo[;oXojNnj_nU^NOoYKWWoj[2jon`_nGo[KoW00;o[;cV00SoZ[cVojVn
j?nX_NWoZ;gYojRkionX`>_o[[kVojFhi`;oZ[_V00SoZ;oZojFhi_n_`nSo[l?XojFhionX_>So[/?Z
ojFhiP;oZl7Z00?oZkkWojJjion/_nP00_nV^>H02?n/`NWoYkWWojc1jOn/`NWoYk[Wojg1jOnW^nOo
ZkoX0_nZ_nP02?nW^nOoZ;_Vojc1jOn/`NWoYkWVojRkion/`>Wo[<7Y0_nX^nL00onY_>OoZ[gWojZo
j004ojZnj003ojVnj?nY_NSoZKgX00;oZKgX00CoZKkXojVmionY_NOoZKgW0_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Sooooo0004ooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`?o0000>Oooool00onR_>_oZKcW
oingj@02ok33j003oj6fj?n[_NOo[<7Y00;oYKOV00?o/LKYojRji_n[_^L00_nY`>X02?n[_^SoYkcX
ojZojOnZ_nWoZ;kYojNkj?n/`NWoZ;_W0_n/`NT01?nY_>KoZKoYojfoionY^ND2oj[2j`07ojW0j_nW
_n_oZkcVoj^li_nY^NGoX[OXojnoi@02oj:eiP07ok35jOnQ]>KoYk_WojNkion]b>koWJ[Poin`i002
oj>gi`09ok6gg_mRc?[oT^3noi;Po_o<aM?oAf?<ol_9f?o7fnSoX;?V00;o`L[R00?oW/Cbok;6jOnY
_nX00_nV`>`02?oPnk?oWFB>oieTS_mmBXWo/koTok34jOnW^NKo//GX0_nR]NH01?n/aNcoY;OVojW1
jon^`nX2ojJgi@07ojg2j_nV^^OoZKcWojVlion]`^WoYKWWojbmiP02ojFnj`04ojfoionZ_>Oo[;gW
ojg2j@;oZKgX00SoY[gYojViiOnU^^SoYK[Xoj_3jonT^NSo[l?YojFhiP;o[L7X0_nX_>P2ojg1j003
ojFhi_n[`N[oZ;WU00;oZKgX00So[;oXojJkj?n]`^Wo[L;YojNiion/`NWoY[[Woj^oj0;oZ;kY00Co
ZkoXoj^nionW_>SoZ;_V0_n]`>P02?nW^^OoZ;_Wojc1jOn/`NWo[<3XojRkionY_>OoZ[kX0_nZ_nT2
ojZnj005ojZmj?nY_^SoZKkXojVmj?nY_>L00_nY_NL00onY_^Soooooooooo`04ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01oooool000Cooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool3o`0003gooooo
00CoZKcWojJnjonX_NWoY[kZ0_nT^NL01on_aN_oYKOVok;7jOnbanWoY[OUoj^nion^`>L00_nW^^H0
1?nW_>SoZ[kXojVlionX_NP2ojboj008ojJiion]`^WoY[SVojJhi_nY_nWoZK_WojJlj?nZ`^/3ojVk
iP06oj^li_nX`>_oZ/3Zoj[0j_n__nGoZ<?]0_n^_N@01?nQ]>KoY[WVokC9jOnMZ^02oj>mk007oj;>
mon_`>KoZ;3NojR`g_nDY^;o/[cRoin`h`02odb[n@04olOKj?nWb_;o`L[Rol;<hP;oWKS[00CoZKoZ
ojZnj?nTa?3oh?^c0_nMI8h02?mmBXWoZKgXojJnjonV_^_o//GXojJjion_a>[oY;OV0_n]`>L01onZ
_^SoY[OUok32ion``^OoY[gZojVlion^_nH00_nV_NX02?n/_NKo[[kUojFkjOnU^nWoZ[cWoj^mion]
`^WoZ[cW0_nY^^D01?nY^NGo[;kWoj^ji?nT^NP2oj^liP03ojJjj?n]`NSoZKcW00;oZ;gX00So[L7X
ojNjion/`^Wo[<;YojRiiOn/`^[oZKcVoj[1jP;oZkgW00SoYk_Wojboj?nW_^[oYkkZoj^oj?n[_^So
Z;_Woj^ni`;oZ[oY00?oY[SVojg0j?nY_^T00_nW^NH01?n/`NWoZkoXojRlionY_NP3ojZoj@?oZKgX
00?oZ[gXojZlionY_>L00_nY_>L:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1oooool000Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000ooooool0003ooooo0ol00011ooooo`04ojJnjonU^^SoZL3[ojBii`;o/<K[00CoXKCV
ok;7jOnS]^Ko[L7X0_n/_^L01onX^NGoZkoYojVkionY^nOoZKcWojRmj?nZ_^P00_nV^^P01?n]`^Wo
Y;WXojg3j_nY^nL2ojZoj@08ojc1jOnY^nKoZKgXojVmj?nY`>[oZ<3[ojRjionW_>P2ojfih`07oj6c
iOnYaNgoZLG]ojJii_ncb>[oV:gUoj>mk002ok?;k004ojo0i_nN]^WoYK[Xok:lhP;oZl?[00?o_<GQ
ogRXlOn>]_400_nS_^`01oo2c>;o^/kZoj:fionR]^OoZ[kXok75j?oPnk<00_nMI8h01OmmBXWoZKgX
oj_0jOnZ_NOoY[[W00;o[lGZ00OoY;OVojg0ion/`^[o[<;ZojBjjOn``^Oo[/;X00;oXkWY00Co[[oV
ojnni_nT^n[oY;WX0_n_`NL02?nT^NSoY[WWojk3jOn^`nWoZ[cWojNhiOnX_NSo[;kW0_nW`>`00on]
aNcoZkcVoj_2jP02oj^nj004ojVlion[_nWoZkcVojVoj@;o[L3X00KoYKSVojg0j?nW^NKoYkWVoj[1
j_nV^^L2oj[2j`;o[;oX00SoYk_Xoj^nj?nY_^WoZKkYojZki_n^`NSoYKOVoj^ni`;o[<;Z00?oY[WW
ojc1jOn[`>T00_nX_>L01_nY_NSoZl3YojZojOnZ_nWoZKgXojVli`;oZ[cW3_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Oooooo0005ooooo`;o00002Oooool3o`0000Cooooo1?l0
0015ooooo`04ojFjj?nZ_nWoX[WYojg2j@;oWkGX00Co/LOZoj>fi_n]`^Wo[;kW0_nW_>P00on_aN[o
ZK_WojZoj@02oj^oj@08ojZnj?nW_NWo[L7Xojg1j?nT^NSo[L3XojFiionZ_nT2ojc0j@04ojJii_n[
_nSo[<3YojVli`;oZ;[V00?oZ[[UojfihonZ`N/00_n`_n@02?nM/^Oo[[kUoifjkOnM^^goYkgYok;3
ionX`^coW[KY0_nP_>d01?nS_ngoZl?[ojW5kOnib^L2ok;9j`09oi:[ion/_nSo]lgZokO=j_nW_NWo
ZK_Wok39k?nV_>Woh?^c00;oWFB>00KoODZ9ojRlj?n[`>WoZ;kZojRkion_aNX2oj>ij004oj^ojOn^
`>OoY[_XojRlj0;o[;gV00?oZKgXojJljOnU_NX00_n^_nH02?nT^NSoZ;[Voj_2jon[`^_oY[WWojk1
j?nY_>OoYkSU0_n[a>`01?nY`N_oZKWTojZii?nU]^D2ojk3j@;oZ;_W00Go[<7YojNji_nW^^KoZKoY
ojVli`02ojNojP04ojg0j?nX_n[o[L7XojJji`;o[<3X00CoYkcXojboj?nY_>OoZKWU0_n^_nH00onU
]^Go[/7XojNki`02ojZmi`06ojc2j_nU^>KoZl7Yoj_1jOn[`>WoYk[W0_nY_^P01?n[`>WoZ[cWojVk
i_nY_>LBooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool001Oooooo0_l0
0018ooooo`;oYK_X00So[L;Yoj>jjOn^`nWo[/?Yoj:gj?n[`^_oZKcWojNlj0;o[l7W00?oY[SVojZo
jOnY^nH00_nY_>P01?nW_NWoZKcWojJljOnY^nL2ojRmj008ojZlion]`nWoYKOVojFgi_n[_nSoZl3Y
ojRii_nX^^H2ojS0j`03ojO1k?nZ`N_oYL7]00;oZL;[00So[[kUok31ionM]n_oWKO[ok;3ionc`^Go
WKW/oj2lk@;oXL3_00CoY<;^ojW5kOn[bNoo//W[0_nM[n@00onQ]nWo]lgZojbni`02ojFgiP03ok39
k?nV]^CoY;g[00;oWFB>00?oODZ9oj^li_n_`nP00_nT^NP01?n``nSoZ/3YojNkion^`>L2oj^mi`03
ojJljOn/_NKo[;oX00;oZ[cV00SoYKgZojFjj?n[`^[oZl;ZojRji_n_`NOoXkOWojk1j0;oZKkX00Co
Y[WWojo5jonY^>CoZKWT0onY`N/01_n^`nWoZ;cXojRkionX^nOo[<7YojJjj0;o[<;Y00CoZKcWojc0
j?nW^^KoZ;oZ0_nY_NP01?nX_n[oYkcXoj^li_nY_>L2ojVgh`03ojNkj?n^_nKoZ;gX00;o[KkV00So
Yk_WojRkion^a>_o[/C[ojFhi_n/`NWoZkoYojNji`;oZkoY00?oZl7Yooooooooool05Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo000Iooooo`03o`000?oooooooooo04Ko
oooo0_n[_nP01?nS^^WoZ[kXojBkjOn[`^/2ojFkj004ojS0jon_`NOoYkgYojk2j@;oYk[W00OoZl7Y
ojZmionY_nWoZKoYojZnj?nY^nOoZl3Y00;oYk[W00Co[L?Yoj>gion/_nSoZl3Y0_nU^NL01?nX_NWo
Z<3[ojVojOnW_n/2ojZmi`07ojFkjOnS_^coXkk/ok31ion/_nSoY;g[ojFok002ok30i@04oinijonW
^NKoXkk]ojG5l0;oZ;SU00?oZ[SSoif_i?nU`Nh00_n`co001_n/_^OoY[k[okC8jOndb>WoY[KTojk4
jP;oWFB>00KoODZ9ojFij?n_`nSoZL3ZojZmionZ`>T2ojFkj@;oZkgW00Go[;gVojJlj_nV_>[o[;oX
ojW0jP02ojbni`04ojFjj?n[_>KoYK_YojRjiP;oZ;oZ00CoZkkWoj_1jOnU^^So[lG[0_nS]nL00onZ
`^_oZL7[ojVmj002ojZnj008ojRlj?nW^^Oo[<7Yojc1jOnV^^SoZkkWojNnj_nX^NH2ojNoj`04ojc1
jOnZ^nKoZ[[UojNlj0;oYkKT00?oZl3YojVghon^a^`00_nX]^<02?nX_NSoZ;WUojc2j_n/`^[oZ;_W
ojo6jonU]nKo[<7Y0_n[_nP00onW^NKoooooooooo`0Hooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01oooool001[ooooo00?o0000ooooooooool0A_ooool01_nX_NSoZ[gWojZmionX
_>SoZkoYojNkj0;oZ[oY00CoZ;_Woj_0jOnZ^nKoYk[W0_n]_>D00onW^NKoZKoYojRjiP02ojNmj@08
oj_0jOnU^nWo[l7Wojo1ionS]nOoZKgWojg2jOnU^NL2ojVmj004oj_1jOn[_nSoZ[gXojZmi`;oZ[kX
00?oZKgXoj>ljonT^nT00_n[_nP01?nU_ncoXkc[ojk0ionW^NH2ojfoiP03ojVii?nX^>GoZ;kY00;o
Y;cZ00CoYL7^ojnniOnR/^Co[/CZ0_n/^^@00onU^^So[;cUojFnj`02oieTSP03oge:ROn/_^OoZL3Z
00;oY[cY00?o[KkVojFkjOnV^^P00_nZ`>T01?n/_NKo[L3XojNjion/_NL2ojJji`08oj[2jonT^>Oo
[<?Zojc3j_nX^^Ko[LCZojJiion[`NT2ojNkj003ojk0ionS]nOo[;oX00;oZKcW00SoZKgXojZlionY
_>OoZKcWojNjion/_^OoZ;oZojJgi@;o[KkW00CoZ;WVojjmiOnX^nOoZ[_V0_nY_nX00on]_>CoYkKT
ojnni@02oj>ahP0:ojk6k?nP[n;o[lW]ojo9kOnX^NGo/<W]ojJhi_n`b>_oY;SWojc1jAoooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`16
ooooo`06ojZmionZ_nWoZ[gWojZmionW^nSoZkkW0_nU^^P01?n[`>WoYK_Xoj_2jon]_>D2oj_3k004
ojfni_nX^^Ko[;oWojZkiP;oZkoX00?oZKcWojRoj_nU^nT00_n^`NL01?nT^^WoY[cYojboj?n[_nP3
ojVnj0;oZ[kX0_nY_^T01?nT^nWoY[cYojg0j?n/`NT2ojFjj008ojW2k?nT^^SoZ<;/ojS2k?nY`N_o
Y[_XojNnjOnZ_nT2ojK1k@03ojK5kon^a>[oXl7^00;o[/;X00[o[;cUok30i_nMI8koWFB>oge:ROnU
_>Wo[[oVojg0ionV^^So[L3X0_nY_nX00on[_>OoY[gYojRjiP02ojW0jP08ojbmionY`N_o[KkVojfn
i_nT^>Oo[KoWojFhion]a>X2ojFhiP04ojc0jOnW^nSoZ[cWojRnj@;oZ;[W00?oZKoYojZmionY_NP0
0_nZ_NL02?nX^nOoZ[gWojk4j_n^a>[oY[OUoj^ii?nY_^Wo[[gU0_n^`^P00onW/n7oZKoZojF`h002
ojVoj@04ojnniOnV^^Oo/lOYoj2_hP;o]<k]00CoX[?Tok;;k?nS^>Oo/<S[8oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Kooooo000Looooo`;o0000Aoooool02?nZ_nWoYk_WojVo
jOnY_nWoZkkWojRnjOn[_^SoYK_X0_n/_NL01?nT^^So[KgVojFiionZ`N/2ojNkj003ojVnjOn[_nSo
Z;kY00;o[;kW00SoYK_YojRmj?n[_nSoZkoXojJljOnX_^Wo[;oXojVnj0;oZKgX00CoZKkXojVmionZ
_>OoYk_W0_nX_NP00onY_^Wo[<7YojJji`02ojc1j@04ojBjj?n/`NWoYk[WojJkj0;oZL7[00?oZ<7/
ojK1kOnZ^nH00_nT^NP01OnS`NkoX[WYojS0jonX`>_o/<3V00;oWFB>00OoZKkXojJjj?nV^^So[L3W
ojW1jonZ^nKoZKoZ00;oY[WW00?o[<7YojRji_n^`NP00_nV^>H01?nY`N_oYKSVojW1j_n]_nL2ojRk
i`04ojg1jOnV^>Ko[<;YojRki`;oZKkY00?o[<;ZojRjion/_nP00_nW_>P02onY_NSoZL3[ojVmj?nY
_NSoZ[gWojo3j?nT]^GoZkWTok79k?nV]^Co[kkU00;oX[3R0_nbb^/01?nU/>3o/]3`ojNeh_n]a^`2
ojo2j004oj6di_nccNcoX;KXok;;k2Oooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`06ooooo`007_ooool00ol0003oooooooooo`15ooooo`03ojNkion[_NOoZ;_W00;oZkkX00?oZ;_W
ojRmj?nW_NT00_nY_^T01?n]_NKoZkoYojbmi_nW^nP2ojZli`;oZ;kY00OoZ;gYojZnj?nZ_^SoZ;gX
ojZnj?nX_NWoZ;gX00;oZKkY00CoZkkWoj^nj?nZ_NOoZKgW0onY_NP01_nX_NSoZ[oYoj^nj?n[_^So
Y[[Woj_0j@;oYk_X00Ko[<7YojJkj?nX_^WoZkoXojVmj?nY^nH2ojRmj003ojZmj?n/_NKoZkkX00;o
YkgY00SoY[cYojJjionMI8koWFB>ojVnj?nW^^OoZKgXojW1j`;oY;SW00Co[/;XojJiion/_nOoY[_X
0_nZ_^P00onW_>So[l;XojNiiP02ojg1j@04ojRjionY_^So[<7YojJhiP;o[/?Y00?oYk_XojVnjOn/
`>T00_nV^nT02_n/_nSoZ[kXojNii_nW^NKoZL3[ojJgiOnX_n[oZKKRojJehonU^NL2ok72i`07oj:b
i?n__^Go[kkUoj:`h_nea^OoWZcQok[Bk002oib[h@04ojg6k?nYa>goYKk[ok?=k2[ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`06ooooo`007oooool00ol0003oooooooooo`16oooo
o`03ojRnjOn[_^SoZ;oZ00;oZ[kX00CoYkgYojVmj?nW_^[oZkoY0_nW_nX01?n/_nOoZ[cWojbnionX
_>P3ojVmj006ojVnj?nY_NSoZ[kXojZnj?nX_NSoZ[gX0_nX_^T01?n[_^SoZKkYojZnj?nY_NP2ojVn
j@05ojVojOnZ_nWoZ;cWojRmj?nZ_NL00_nW_>P02?n/`>SoZ;gXojVmj?nY_NSoZkoXojVnj?nW_>So
Z;gX0_nX_NT00onY_^SoZkkXoj_0j@02ojNmj@04ojJjionMI8koWFB>ojNji`;oZKcW00Co[L?YojFh
i_n[_^SoZ;gX0_nY_>L2ojZnj007ojRlion[_nSoZkoXojNii_n]`^WoYkWVojVnj002oj^oj@04ojFi
ion^`nWoZ;cXojVmj0;o[<7Y00?oZKkYojRji_n/_^L00_nU^^P02On]_>CoZ/G]ojjni_n^_^KoZKKR
ojVojOn[`>Wo/L;WojFljP02ojZnj007ojFij?n/^N?oXk?Toj>ci?njd^coW;KZok7;k@0_ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool0023ooooo00?o0000ooooooooool0
A_ooool01?nW_NWoZ;oZojNlj?nZ_nT2ojRmj@03oj^nj?nW_>SoZKgX00;oY[gZ00CoZ[oYojVnjOn/
_^OoZKgX0_nY_^T2ojVmj007ojZnj?nY_^WoZKkYojZmj?n[_^SoZ;cXojZnj002ojVlj0;oZKgX0_nY
_>L2ojVoj@03ojVnj?nZ_NOoZ[kY00;oZ[gX00CoZ;gXojNmjOn[_^SoZKkX0_nX_NP2ojRmj@07ojRn
jOnY_nWoZ[gXojZmj?nX_>OoYKWWojRnj@02oieTSP04ojJii_nX_>So[/CZojFhiP;oZl3Y00?oZKkX
ojVlionZ_^P00_nZ_NP02_nX_>OoZl3YojJjionV^^Oo[L;YojJiion[`>WoZkoYojJjion/`NT3ojRn
j@06ojc1jOnY^nOoYK[XojFjj?n/_^OoZ/7Z0_nU]^D01OnZaNgoY;3QojK1k?nY_nWoZ/G]00;oZlC/
00OoYKcZojF`gonW]^CoYkKTojbihonXb?3o^MG^03?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`06ooooo`008Oooool2o`0004Kooooo00KoZKgWojVmj?nY_NSoZKgXojRmjOnX_NP2
ojVnj008ojVmj?n[_^SoYkgYojNmjOnY_^WoZKgXoj^nj?nY_^T2ojVmj0?oZ[kX00OoZ;cXojVmj?nY
_NSoZKgXojZnj?nY_NSoZ[kX00?oZKgX00?oZKkYojVojOnY_NP00_nX_^T01?nZ_^WoZ;gYojZmionZ
_^P2ojRmj@04oj^nj?nZ_NOoZ;gXojRmj@;oZKcW00?oZKgXojZmj?nX^nL00_nW^^L02OnX_^WoWFB>
oieTS_nU]nGoZ;cXojk1ionU]nKoZl3YojRki`02ojRmj@04ojZnj?nY_^WoZKcWojc1j@;oYk[W00Co
[<7YojJljOn[`>WoZkoY0_nV_>T00on/`NWoZ;kYojRki`02ojZji@0:ojVkionY^^GoYkGSojNehonZ
`N[oXJgPok;5jOnT/>7o/lOYojBhi`;o[kWQ00KoZ:kLojJ_g_nV[mkoYK3Ooj_;l?nWao0fooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool002?ooooo00?o0000ooooooooool0
A?ooool3ojVmj003ojZmionX_NSoZKgX00;oZKgX0_n[_^P01onW_>WoZ;gXojVnj?nY_^SoZkoXojZn
j?nY_NP00onZ_^P6ojVmj003ojZnj?nY_>SoZKgX00;oZ[kX00GoZ[gXojVmj?nZ_NSoZKgXojZmj002
ojRlj0;oZ[kX0_nX_NP01?nZ_NOoZ[kXojZlionY_>L2ojZmi`03ojVkionX^nOoZ<3[00;oZL;[0_nM
I8h02OnZ`N[oZK_VojNlj?nW_>So[L;ZojJjj?n[`>WoZ;cWoj^oj@02ojNkj00:ojc1jOnW_>Wo[<3X
ojc0j?nV_>WoZKcWojZnj?nV_>WoZK_Voj^miP;oZ[oX00?oY[KTojboj?nW]n@00_nU]^D01?nbbN_o
XJgPokG?kOnQ/>82ok?6j@03ojR_gOn_^N7oY;k/00;oZkkW00?oZ;KSooooooooool0>?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo000Tooooo`03o`000?oooooooooo04Go
oooo0_nY_NP2ojZnj0?oZKgX0_nY_^P2ojRmj0?oZ[kX00GoZ;cXojZmj?nZ_^SoZKcXojZnj004ojVm
j005ojZnj?nX_>SoZ;cXojVmj?nZ_^P01OnY_NP01?nZ_NSoZKkXojRmj?nX_NP2ojZnj006ojRmj?nZ
_^SoZ;gYojRmjOnY_^SoZ;gX0_nX_nX2ojVki`09ojZki_nW^NKoWFB>oieTS_n[_nSoZK_Voj_1jOn/
_NKoY[[X00;oZkgW00?oYkgYoj^ojOnW_^X00_n[_nP01?nW_>WoZKcWoj^ojOnX_>P2oj^ji@05ojVn
j?nW]nCoZ[[UojZoj?nS/N800_n^`nX02OnW]nCoYkcYok?6j?nca^SoW:_QokOAkOnMZ]oo/lKYoi^j
kP02ok7Fl`03ojBnk?oooooooooo03cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`06ooooo`009Oooool00ol0003oooooooooo`15ooooo`07ojVmj?nZ_^SoZ[kXojZnj?nX_NSoZKgX
ojZmj002ojVmj004ojRmj?nY_^SoZ[kXojRlj0;oZKkX00CoZ[kXojVmj?nZ_^SoZKgX0_nZ_^P00onY
_NSoZ[kXojRlj002ojVmj003ojZnj?nY_NSoZKgX00?oZKgX0_nZ_^P2ojVmj007ojZnj?nY_NSoZKgX
ojVmj?nZ_^SoZKcWojRmj002oj^mi`;oZK_W0onX_nX01?l0077oWFB>ojNmj_n[`NT2ojNmj@05oj^o
jOnX_n[o[;kWojVlion/_>D00_nW^^L02OnY_^SoZ;gYojbli_n/_>KoZ;cXojFfiOn_`^SoYkOTojVk
i`02ojo2j00:oj>ah_nbbncoXk;Soj>bhonW_>Wo[KkVoijcioncanWoUKK^ok?ClDCooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`05ooooo`009_ooool00ol0003oooooooooo`15oooo
o`03ojVmj?nY_^SoZKgX00?oZKgX00?oZ[kXojVmj?nY_NP00_nZ_NP01?nX_>SoZKkXojZnj?nY_NP2
ojZnj004ojVmj?nZ_^SoZKgXojZnj0?oZKgX00?oZ[kXojVmj?nY_NP01?nY_NP01_nZ_^SoZKcXojVl
j?nY_NSoZ[kXojVmj0;oZ;cX00KoZ[kXojRlj?nY_^WoZkgWojRmj?nY_nT3ojVmj008ojVliol0077o
WFB>ojZmionY_>OoZkgWojRkionX_nX2ojNiiP03ojW1jon/_>Go[<7Y00;oZ[[U00CoZ;gYojFgi_n]
`^WoYKKU0_n^`^P01OnU]nGoZK_Wojk2j?nQ/^Co]<_[00;oW[3T00Go[<W_oj6ijOnVbO;oY/Wbok?7
j@16ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool002Oooooo0_l00016
ooooo`04ojVnj?nY_NSoZ;cXojVmj0;oZ[kX1?nY_NP2ojVmi`GoZKgX00?oZ[kXojVmj?nY_^P00_nY
_NP2ojVnj0OoZKgX00?oZKcXojVmj?nZ_^P00_nY_NL00onY_NSoZ[kXojVmj002ojZnj005ojRlj?nY
_NSoZ[kXojVmj?nX_>P00_nY_NP02_l0077oWFB>ojVmj?nY_NSoZkgWojVnjOn]_NKoYkWVojjmiOnT
^>L2oj^li@03ojFkj?n^`NSoYkkZ00;o[/3W00GoXkOWoj^nj?nU^nSoZKkYoj_2jP02oj>hj005okC;
jonO^>[o//_/ok;;k?nQ^NT0B_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Go
oooo000Yooooo`03o`000?oooooooooo04Cooooo00KoZKgXojRmj?nY_NSoZ[kXojVmj?nY_NL2ojZn
j003ojZmj?nY_NOoZ[kX00;oZKgW3OnY_NP01?nZ_NSoZ[kXojVmj?nY_NP2ojVnj003ojZnj?nY_NOo
Z[kX00;oZ[gX1onY_NP01OnX_>SoZKgXojVmj?l0077oWFB>00;oZ;oZ00?oYk_XojNnj_nZ`>X00_nV
_NX00on[`N[oZkcUojg2j@02ojVjiP04ojNnj_nW^NKoZ<3[oj^nj0;oZL;/00CoYkcXoj_2j_nT^n[o
/<O[D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000Zooooo`03o`00
0?oooooooooo04Cooooo0_nY_NP01?nZ_^SoZ;cWojVmj?nZ_^P2ojVli`05ojVmj?nZ_^SoZKgXojZn
j?nY_NP00_nZ_NP9ojVmj0;oZKkX00CoZ[kXojVmj?nY_NSoZKkX0onY_NP01?nZ_^SoZKgWojVmj?nY
_NL2ojVnj004ojVlionZ_^SoZKgXojRli`;oZKgX00?oZKkYojVojOnMI8h00_nX^nH01OnW^nSoZ[cV
ojRkionV_N[oZKcW00;oY[gZ00[o[L;YojJmj_n]`^Wo[L;YojNii_n]`^WoY[SVojk3jOnT^>Oo[<G/
Doooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo000[ooooo`03o`000?oo
oooooooo04Cooooo00SoZKgXojRmj?nY_^SoZKkXojZnj?nY_NSoZ[kXojVmi`;oZ[kX00?oZKgWojVm
j?nY_NP00_nZ_^P01OnY_NSoZ[gXojVmj?nY_NSoZ[kX00GoZKgX00?oZ[gXojVmj?nY_NP00onY_NP0
1_nZ_^SoZKgXojVmj?nZ_^SoZKgWojZnj0;oZ;cW00GoZ[kXojVmj?nX_>SoZKgXojZoj@02ojZmi`04
oieTS_nY_NSoZKcWojVnj@;oZKkX00GoZ[gWojVojOn[_^SoZKcWoj^oj002ojVkiP04ojJljOnZ^nKo
YK_Yojk3jEOooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`00;?ooool2
o`0004Gooooo00WoZ;gXojVmj?nY_>OoZKcWojVmj?nZ_NOoZKcXojZnj?nY_NP00_nZ_^P01?nY_NSo
Z[gXojVmj?nY_NP2ojZnj0?oZKgX00KoZ[gXojVmj?nY_NSoZKgXojZmj?nZ_^P6ojVmj007ojZmj?nX
_>SoZ[kXojZnj?nX_>SoZ[kXojVnj002ojRmj005ojVnj?nZ_^SoZ;cXojVlj?nMI8h00onY_^T2ojRn
j@06ojVojOnX_^WoZ;kYojRoj_n[_nSoZ;kZ0_n[`>T00onZ^nKoooooooooo`1Hooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool01Oooool002kooooo00?o0000ooooooooool0A?ooool0
0onX_NSoZKkXojRlj002ojVnj003ojZmj?nZ_^SoZKgX00?oZKgX00?oZ[kXojVmj?nY_NP01onY_NP0
1_nY_^SoZKgXojVmionY_NOoZKgXojZnj0GoZKgX00SoZ[kXojVmj?nY_NSoZKgXojVnj?nX_NSoZKkX
ojZnj0?oZKgX00?oZKgYojVnj?nY_^T01?nY_NP00onZ_>KoZK_VojRki`1Pooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01?ooool002oooooo00?o0000ooooooooool0A?ooool00onY
_NSoZ;cXojZnj002ojVli`03ojZnj?nY_NSoZ[kX00GoZKgX00?oZ[gWojVmj?nY_NP00_nY_NP00onZ
_NSoZ[kXojVmj002ojVmj0;oZKkX00?oZ[kXojVmionY_NP02?nY_NP2ojVnj0;oZKgX00?oZKkXojVm
j?nY_NP00onY_NP2ojVli`03ojZli_oooooooooo067ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`00<?ooool00ol0003oooooooooo`13ooooo`?oZ;gX00?oZKgXoj^nionZ
_^P01onY_NP2ojZmj0?oZKgX00?oZ[kXojVmj?nY_NP00onY_NP01onY_>OoZKkXojZnj?nZ_^SoZ[gW
ojZnj?nZ_NP01OnY_NP00onZ_NSoZKgXojVmj002ojVnj0;oZKgX0_nY_>MXooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01?ooool0037ooooo0_l00014ooooo`08ojRmj?nY_NSoZKcW
ojVlionZ_^SoZKgXojZnj?nY_NP2ojVmi`?oZKgX00OoZ[kXojVmj?nY_NSoZKgXojVmionZ_NSoZ[kX
00CoZKgX00CoZKkXojVlionY_NSoZ[kX0_nY_>P01OnZ_^SoZKgXojZnj?nY_NSoZKkX00?oZKgX00?o
ZKgWojVmj?nY_NP0K?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo000c
ooooo`03o`000?oooooooooo04?ooooo00?oZ;gYoj^nj?nZ_^P00_nZ_NP00onY_NSoZ;cXojZmi`03
ojVmj003ojZnj?nY_NSoZKgX00;oZKgX00?oZ[gXojZnj?nY_NP01?nY_NP2ojVnj004ojZmionY_^So
Z[kXojVmj0;oZ[kX00?oZKgXojVnj?nY_NP00_nY_NP00onY_NOoooooooooo`1]ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool003Cooooo00?o0000ooooooooool0@oooool0
1?nX_NSoZ[kXojVlionZ_^P2ojVmj005ojVlionZ_^SoZKgXojVmj?nY_NL00_nZ_^P00onY_NSoZKkX
ojVli`04ojVmj003ojVlionY_NSoZ[gW00;oZKcW00KoZKkXojVmj?nY_^SoZKgXojVnj?nY_NQdoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool003Gooooo00?o0000oooooooo
ool0@oooool01OnY_NSoYkcYoj^nionY_NSoZ;cX00;oZkkX0onY_NP00onZ_^SoZKgXojVmj002ojVl
j0;oZ[kX00?oZKcWojVmj?nY_^P00_nX_>P00onY_^WoZkkXojVmj002ojZnj003ojVmj?oooooooooo
07Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`00=_ooool2o`0004Co
oooo0_nX_NT00on[_^OoZ[cVojVnj002ojZmi`;oZKgX00GoZ[kXojVmionY_>OoZKcXojZoj002ojZm
j006ojVlionZ_^SoZ[gWojRlj?nZ_^SoZKgXOOooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Cooooo000hooooo`03o`000?oooooooooo04;ooooo00WoZ;gXojZli_n/`>So[<3XojVj
i_nZ_NOoZ[oXojZlion[_NL00onY_^P01?nZ_>OoZK_WojVlion[`>T2ojVmj003ojVnjOoooooooooo
07gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`00>Oooool00ol0003o
ooooooooo`12ooooo`04ojJljOnX_NSoZ;[Voj^oj0;oZkSR00GoYk_Woj^mion/_nSoZK[UojZli`02
ojVnj@03ojVojOn[`>Wooooo08;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`00>_ooool00ol0003oooooooooo`12ooooo`06ojRmj?nU_>[o[;cUoj^hh_n_`>KoZK[V0_n^
`nT00onV_N[o[<7Yooooo`27ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool003_ooooo0_l00013ooooo`;oXkc[00CoYko[ojG0k?n[a>co[/?YS?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo000mooooo`03o`000?oooooooooo047ooooo00?oYKcZ
ooooooooool0S_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo000noooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo000oooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool0T?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0010ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo0011ooooo`;o0000?_ooool00ol0003oooooooooo`2Aooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool004?ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
04Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2Cooooo`05o`000?oooooooooo
ooooool000001?ooool004Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2Coooo
o`05o`000?ooooooooooooooool000001?ooool004Kooooo0_l0000iooooo`03o`000?oooooooooo
09Cooooo00Co0000oooooooooooo00001?ooool004Sooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`2Eooooo`03o`000?oooooo000000Cooooo0019ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0UOooool01?l0003oooooooooool00003ooooo`00B_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo09Kooooo00?o0000ooooool000000oooool004_ooooo
0_l0000dooooo`03o`000?oooooooooo09Oooooo0_l00003ooooo`00COooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo09Kooooo0ol00003ooooo`00C_ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo09?ooooo1?l00006ooooo`00Coooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo08oooooo1?l0000:ooooo`00D?ooool2o`0002kooooo00?o0000oooooooo
ool0S?ooool3o`0000kooooo001Booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
R?ooool4o`00017ooooo001Cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Q?oo
ool4o`0001Gooooo001Dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0P?ooool4
o`0001Wooooo001Eooooo`;o0000:Oooool00ol0003oooooooooo`1looooo`Co00007Oooool005Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1hooooo`Co00008Oooool005Sooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1eooooo`?o00009Oooool005Wooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1aooooo`Co0000:?ooool005[ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`1]ooooo`Co0000;?ooool005_ooooo0_l0000Soooo
o`03o`000?oooooooooo06Wooooo1?l0000`ooooo`00GOooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo06Gooooo1?l0000dooooo`00G_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo067ooooo1?l0000hooooo`00Goooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo05kooooo0ol0000looooo`00H?ooool2o`0001kooooo00?o0000ooooooooool0F_ooool4
o`0003oooooo001Rooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool4o`00
04?ooooo001Sooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0D_ooool4o`0004Oo
oooo001Tooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool4o`0004_ooooo
001Uooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000Coooool006Oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`17ooooo`?o0000Doooool006Sooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`13ooooo`Co0000E_ooool006Wooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0oooooo`Co0000F_ooool006[ooooo0_l0000Dooooo`03o`00
0?oooooooooo03_ooooo1?l0001Nooooo`00K?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo03Oooooo1?l0001Rooooo`00KOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03Cooooo0ol0001Vooooo`00K_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
033ooooo1?l0001Yooooo`00Koooool2o`0000kooooo00?o0000ooooooooool0;Oooool4o`0006go
oooo001aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool4o`00077ooooo
001booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool4o`0007Gooooo001c
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`0007Wooooo001doooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool3o`0007gooooo001eooooo`;o
00002?ooool00ol0003oooooooooo`0Jooooo`Co0000P?ooool007Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Fooooo`Co0000Q?ooool007Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Booooo`Co0000R?ooool007Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0>ooooo`Co0000S?ooool007[ooooo0_l00003ooooo`03o`000?oooooooooo
00[ooooo1?l0002@ooooo`00O?ooool01?l0003oooooooooool00009ooooo`?o0000U?ooool007go
oooo00?o0000ooooool000001Oooool4o`0009Oooooo001nooooo`;o000000?oooooo`000?l00000
0_l0002Kooooo`00Ooooool2o`0009oooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo0016ooooo`;o000000Goooooo`000?l0003o0000oooo
o`03o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000001?l00002ooooo`Co00000ooo
ool2o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o000000Oooooo0ol0
0002ooooo`?o00001?ooool4o`000005ooooool0003o0000o`000?ooool01_l00002ooooo`Go0000
0_ooool3o`0000;ooooo0ol00009ooooo`?o00001Oooool2o`000003ooooool0003o000000;o0000
00Coooooo`000?l0003ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o
000000?oooooo`000?l00000<_ooool004Kooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000cooooo`00A_ooool01ol0
003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol00003ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`04o`000?oo
ooooooooooooo`Go00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0aooooo`00A_ooool01ol0003ooooooooooooooooo0000ooooool0
00000oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00Co0000oooooooo
oooo00000oooool01_l0003oooooooooool0003oooooo`0000Oooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00;o00002_ooool3o`0000?ooooo00Co0000oooooooooooo
00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0aooooo`00A_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`?o
00000_ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooooooool00_ooool2o`0000?o
oooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l00008ooooo`06o`000?oooooo0000oooo
ool0003ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000?ooooo1?l00002
ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oooooo
oooo00;ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co00000_oo
ool3o`0000Cooooo0ol00002ooooo`Co0000=?ooool004Kooooo0_l000000ooooooo0000o`00000:
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0J
ooooo`05o`000?oooooo0000ooooool000006oooool00ol0003oooooooooo`0Dooooo`04o`000?oo
ooooooooo`0001Cooooo00?o0000ooooooooool0A_ooool004Kooooo00Co0000oooooooooooooooo
0_l00008ooooo`;o00002?ooool3o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Cooooo`Go00007?ooool2o`0001?ooooo1Ol0000Dooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0?oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oo
oooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0872763, 0.0488731, \
0.00365141, 0.00365141}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.7 GeometricPointSpreadFunction", "Subsection",
  CellTags->{"AOG0.", "5.7", "AOG5.", "AOG5.7"}],

Cell[CellGroupData[{

Cell["?GeometricPointSpreadFunction", "Input",
  CellLabel->"In[12]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[BoxData[
    \("GeometricPointSpreadFunction[system, options] calculates a histogram \
to show the geometric point spread function of an imaging system. \n\n\
GeometricPointSpreadFunction works together with GeometricFocalData to show \
the geometric point spread function of an imaging system. \
GeometricPointSpreadFunction can work directly with multiple wavelength \
(white light) sources, since it works with intensity (not amplitude and \
phase). GeometricPointSpreadFunction first calls GeometricFocalData to find \
the focal plane of an imaging system and trace a quantity of rays to the \
focal plane of the system. Finally, GeometricPointSpreadFunction calculates a \
histogram of the ray intercept points and intensities to determine the \
geometric point spread function of the optical system. As input, \
GeometricPointSpreadFunction takes either an optical system or the returned \
output from GeometricFocalData. The optical system must contain a light \
source followed by the imaging optics with the approximate focal surface as \
its last element. For FindImagePoint->True, the last system element need not \
be the exact focal surface, since the exact focal surface position is \
automatically determined. When the default FindImagePoint->False is given, \
the last system element is assumed to be the exact focal surface. In \
addition, the light source need only contain a small number of rays (since \
the actual number of rays is internally specified). The user can also give as \
input a specific focal point or exit pupil position with the FocalPoint and \
ExitPupilPosition options, although GeometricPointSpreadFunction does not \
make use of the exit pupil information. \n\nNote: \
GeometricPointSpreadFunction works equally well for both point sources and \
planar sources, as long as the described imaging system contains a focus. If \
a one-dimensional light source is used (ie. WedgeOfRays or LineOfRays), then \
a one-dimensional geometric point spread function is calculated. If a \
two-dimensional light source is used (ie. PointOfRays or GridOfRays), then \
the geometric point spread calculations are carried out in two-dimensions. \n\
\nGeometricPointSpreadFunction does not utilize PupilFunction. \
GeometricPointSpreadFunction is also an option of OpticalTransferFunction and \
PointSpreadFunction that indicates whether the diffraction point spread \
function or the geometric point spread function is to be used. \
GeometricPointSpreadFunction->True invokes the direct use of \
PointSpreadFunction, while GeometricPointSpreadFunction->False invokes the \
initial use of GeometricPointSpreadFunction. See also: FindLensParameters, \
GeometricFocalData, GPSF and OpticalTransferFunction."\)], "Print",
  CellLabel->"From In[12]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[GeometricPointSpreadFunction]", "Input",
  CellLabel->"In[13]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[BoxData[
    \({FindImagePoint \[Rule] False, NumberOfRays \[Rule] 64, 
      GeometricCellCapacity \[Rule] 2, FocalFraction \[Rule] Automatic, 
      FocalPoint \[Rule] Automatic, FindPupils \[Rule] False, 
      FieldStopPosition \[Rule] \(-2\), 
      GeometricScaleFactor \[Rule] Automatic, 
      GeometricMinimumCellWidth \[Rule] 0.001`, PlotRange \[Rule] All, 
      PlotPoints \[Rule] 64, Plot2D \[Rule] True, 
      InterpolationOrder \[Rule] 1, 
      RenderedParameters \[Rule] {PointSpreadFunction}}\)], "Output",
  CellLabel->"Out[13]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GPSF[sys3D, FindImagePoint->True, FocalFraction->0]", "Input",
  CellLabel->"In[14]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 1.29183 0.0147151 4.97235e-05 [
[.11245 .00222 -12 -9 ]
[.11245 .00222 12 0 ]
[.24163 .00222 -12 -9 ]
[.24163 .00222 12 0 ]
[.37082 .00222 -12 -9 ]
[.37082 .00222 12 0 ]
[.62918 .00222 -9 -9 ]
[.62918 .00222 9 0 ]
[.75837 .00222 -9 -9 ]
[.75837 .00222 9 0 ]
[.88755 .00222 -9 -9 ]
[.88755 .00222 9 0 ]
[.4875 .11416 -24 -4.5 ]
[.4875 .11416 0 4.5 ]
[.4875 .21361 -24 -4.5 ]
[.4875 .21361 0 4.5 ]
[.4875 .31306 -24 -4.5 ]
[.4875 .31306 0 4.5 ]
[.4875 .4125 -24 -4.5 ]
[.4875 .4125 0 4.5 ]
[.4875 .51195 -30 -4.5 ]
[.4875 .51195 0 4.5 ]
[.4875 .6114 -30 -4.5 ]
[.4875 .6114 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11245 .01472 m
.11245 .02097 L
s
[(-0.3)] .11245 .00222 0 1 Mshowa
.24163 .01472 m
.24163 .02097 L
s
[(-0.2)] .24163 .00222 0 1 Mshowa
.37082 .01472 m
.37082 .02097 L
s
[(-0.1)] .37082 .00222 0 1 Mshowa
.62918 .01472 m
.62918 .02097 L
s
[(0.1)] .62918 .00222 0 1 Mshowa
.75837 .01472 m
.75837 .02097 L
s
[(0.2)] .75837 .00222 0 1 Mshowa
.88755 .01472 m
.88755 .02097 L
s
[(0.3)] .88755 .00222 0 1 Mshowa
.125 Mabswid
.13829 .01472 m
.13829 .01847 L
s
.16412 .01472 m
.16412 .01847 L
s
.18996 .01472 m
.18996 .01847 L
s
.2158 .01472 m
.2158 .01847 L
s
.26747 .01472 m
.26747 .01847 L
s
.29331 .01472 m
.29331 .01847 L
s
.31914 .01472 m
.31914 .01847 L
s
.34498 .01472 m
.34498 .01847 L
s
.39665 .01472 m
.39665 .01847 L
s
.42249 .01472 m
.42249 .01847 L
s
.44833 .01472 m
.44833 .01847 L
s
.47416 .01472 m
.47416 .01847 L
s
.52584 .01472 m
.52584 .01847 L
s
.55167 .01472 m
.55167 .01847 L
s
.57751 .01472 m
.57751 .01847 L
s
.60335 .01472 m
.60335 .01847 L
s
.65502 .01472 m
.65502 .01847 L
s
.68086 .01472 m
.68086 .01847 L
s
.70669 .01472 m
.70669 .01847 L
s
.73253 .01472 m
.73253 .01847 L
s
.7842 .01472 m
.7842 .01847 L
s
.81004 .01472 m
.81004 .01847 L
s
.83588 .01472 m
.83588 .01847 L
s
.86171 .01472 m
.86171 .01847 L
s
.08661 .01472 m
.08661 .01847 L
s
.06078 .01472 m
.06078 .01847 L
s
.03494 .01472 m
.03494 .01847 L
s
.0091 .01472 m
.0091 .01847 L
s
.91339 .01472 m
.91339 .01847 L
s
.93922 .01472 m
.93922 .01847 L
s
.96506 .01472 m
.96506 .01847 L
s
.9909 .01472 m
.9909 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .11416 m
.50625 .11416 L
s
[(2000)] .4875 .11416 1 0 Mshowa
.5 .21361 m
.50625 .21361 L
s
[(4000)] .4875 .21361 1 0 Mshowa
.5 .31306 m
.50625 .31306 L
s
[(6000)] .4875 .31306 1 0 Mshowa
.5 .4125 m
.50625 .4125 L
s
[(8000)] .4875 .4125 1 0 Mshowa
.5 .51195 m
.50625 .51195 L
s
[(10000)] .4875 .51195 1 0 Mshowa
.5 .6114 m
.50625 .6114 L
s
[(12000)] .4875 .6114 1 0 Mshowa
.125 Mabswid
.5 .03958 m
.50375 .03958 L
s
.5 .06444 m
.50375 .06444 L
s
.5 .0893 m
.50375 .0893 L
s
.5 .13902 m
.50375 .13902 L
s
.5 .16389 m
.50375 .16389 L
s
.5 .18875 m
.50375 .18875 L
s
.5 .23847 m
.50375 .23847 L
s
.5 .26333 m
.50375 .26333 L
s
.5 .28819 m
.50375 .28819 L
s
.5 .33792 m
.50375 .33792 L
s
.5 .36278 m
.50375 .36278 L
s
.5 .38764 m
.50375 .38764 L
s
.5 .43737 m
.50375 .43737 L
s
.5 .46223 m
.50375 .46223 L
s
.5 .48709 m
.50375 .48709 L
s
.5 .53681 m
.50375 .53681 L
s
.5 .56167 m
.50375 .56167 L
s
.5 .58654 m
.50375 .58654 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Geometric Point Spread Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.04759 .01472 L
.07351 .01472 L
.09787 .01472 L
.12129 .01472 L
.13434 .01472 L
.14621 .01472 L
.14909 .01472 L
.15066 .01472 L
.15143 .01472 L
.15213 .01472 L
.15289 .01472 L
.15332 .01472 L
.15372 .01472 L
.15462 .01472 L
.15547 .01472 L
.15694 .01472 L
.15772 .01472 L
.15815 .01472 L
.15855 .01472 L
.15995 .01472 L
.16143 .01472 L
.16221 .01472 L
.16306 .01472 L
.16383 .01472 L
.16455 .01472 L
.16598 .01472 L
.16749 .01472 L
.16811 .01472 L
.16878 .01472 L
.16952 .01472 L
.17021 .01472 L
.17182 .01472 L
.17258 .01472 L
.17329 .01472 L
.17407 .01472 L
.17448 .01472 L
.17492 .01472 L
.17575 .01472 L
.17664 .01472 L
.17706 .01472 L
.1775 .01472 L
.17828 .01472 L
.17902 .01472 L
.17983 .01472 L
.18056 .01472 L
.18133 .01472 L
.18206 .01472 L
.18273 .01472 L
.18344 .01472 L
Mistroke
.18419 .01472 L
.1849 .01472 L
.18554 .01472 L
.18701 .01472 L
.18741 .01472 L
.18783 .01472 L
.18859 .01472 L
.18996 .01472 L
.19073 .01472 L
.19146 .01472 L
.19277 .01472 L
.19343 .01472 L
.19415 .01472 L
.19576 .01472 L
.19653 .01472 L
.19724 .01472 L
.19765 .01472 L
.19808 .01472 L
.19851 .01472 L
.19898 .01472 L
.2006 .01472 L
.20213 .01472 L
.20297 .01472 L
.20376 .01472 L
.2053 .01472 L
.2067 .01472 L
.20809 .01472 L
.20956 .01472 L
.21081 .01472 L
.21219 .01472 L
.21367 .01472 L
.21526 .01472 L
.21676 .01472 L
.21813 .01472 L
.21953 .01472 L
.22108 .01472 L
.2227 .01472 L
.22422 .01472 L
.22563 .01472 L
.22693 .01472 L
.22836 .01472 L
.22986 .01472 L
.23138 .01472 L
.23302 .01472 L
.23456 .01472 L
.23596 .01472 L
.2376 .01472 L
.23939 .01472 L
.24107 .01472 L
.24263 .01473 L
Mistroke
.2455 .01473 L
.24711 .01474 L
.24859 .01474 L
.24995 .01475 L
.25144 .01476 L
.25416 .01477 L
.25583 .01479 L
.25735 .01481 L
.25898 .01483 L
.26075 .01486 L
.26389 .01493 L
.26686 .01502 L
.26989 .01514 L
.27271 .01529 L
.27581 .01551 L
.27914 .01582 L
.28262 .01623 L
.28592 .01673 L
.2921 .01797 L
.29805 .0196 L
.30436 .02178 L
.3157 .02665 L
.33895 .0371 L
.3637 .04588 L
.37508 .05015 L
.38752 .05587 L
.39986 .06339 L
.40667 .06872 L
.41285 .07461 L
.41864 .08141 L
.42492 .09073 L
.43156 .10381 L
.43782 .12068 L
.44365 .14205 L
.45006 .1741 L
.45675 .21965 L
.46301 .27474 L
.47445 .40148 L
.48049 .47252 L
.48692 .53928 L
.49047 .56818 L
.49369 .58756 L
.49524 .5943 L
.49606 .59711 L
.49692 .59952 L
.49767 .60115 L
.49807 .60183 L
.4985 .60242 L
.49926 .6031 L
.49996 .60332 L
Mistroke
.50036 .60327 L
.50079 .60307 L
.50155 .60235 L
.50198 .60175 L
.50238 .60105 L
.50329 .599 L
.5048 .59413 L
.50644 .58696 L
.50951 .5683 L
.51233 .54597 L
.525 .40803 L
.53676 .27697 L
.54261 .22466 L
.54813 .18511 L
.55449 .15033 L
.56025 .12704 L
.56626 .1091 L
.5726 .09514 L
.57802 .08605 L
.58397 .07816 L
.59597 .06653 L
.6027 .06163 L
.60884 .05786 L
.63335 .04693 L
.65693 .03869 L
.68202 .02772 L
.69448 .02223 L
.70058 .02003 L
.70618 .0184 L
.71162 .01717 L
.71735 .01623 L
.72033 .01587 L
.72311 .0156 L
.72615 .01537 L
.7294 .01518 L
.73268 .01503 L
.7357 .01494 L
.73902 .01486 L
.74069 .01483 L
.74253 .01481 L
.74562 .01478 L
.74735 .01476 L
.74894 .01475 L
.75041 .01475 L
.75201 .01474 L
.75493 .01473 L
.75651 .01473 L
.75821 .01472 L
.75982 .01472 L
.76129 .01472 L
Mistroke
.7641 .01472 L
.76551 .01472 L
.76706 .01472 L
.76874 .01472 L
.77028 .01472 L
.77206 .01472 L
.77374 .01472 L
.77529 .01472 L
.77672 .01472 L
.7783 .01472 L
.77997 .01472 L
.78144 .01472 L
.78298 .01472 L
.7843 .01472 L
.78575 .01472 L
.78731 .01472 L
.78897 .01472 L
.79054 .01472 L
.79197 .01472 L
.79342 .01472 L
.79475 .01472 L
.79621 .01472 L
.79776 .01472 L
.79902 .01472 L
.79971 .01472 L
.80036 .01472 L
.80114 .01472 L
.80184 .01472 L
.8025 .01472 L
.80322 .01472 L
.80397 .01472 L
.80465 .01472 L
.80541 .01472 L
.8062 .01472 L
.80689 .01472 L
.80755 .01472 L
.80831 .01472 L
.80899 .01472 L
.80975 .01472 L
.81057 .01472 L
.81127 .01472 L
.81204 .01472 L
.81247 .01472 L
.81288 .01472 L
.81377 .01472 L
.81417 .01472 L
.8146 .01472 L
.81537 .01472 L
.81617 .01472 L
.81704 .01472 L
Mistroke
.81743 .01472 L
.81785 .01472 L
.81862 .01472 L
.81944 .01472 L
.82018 .01472 L
.8216 .01472 L
.82241 .01472 L
.82287 .01472 L
.82328 .01472 L
.82485 .01472 L
.8257 .01472 L
.82649 .01472 L
.82692 .01472 L
.82736 .01472 L
.82785 .01472 L
.82829 .01472 L
.82975 .01472 L
.83112 .01472 L
.8319 .01472 L
.83234 .01472 L
.83273 .01472 L
.83424 .01472 L
.83494 .01472 L
.83568 .01472 L
.83607 .01472 L
.8365 .01472 L
.83725 .01472 L
.83813 .01472 L
.83895 .01472 L
.84055 .01472 L
.84125 .01472 L
.84201 .01472 L
.84274 .01472 L
.8434 .01472 L
.84467 .01472 L
.84601 .01472 L
.84678 .01472 L
.84721 .01472 L
.8476 .01472 L
.8491 .01472 L
.85188 .01472 L
.87622 .01472 L
.89963 .01472 L
.92454 .01472 L
.94852 .01472 L
.97401 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[184]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001?ooooo0_l00004oooo
o`04o`000?ooooooooooooooo`Go00004Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`00037ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Booooo`;o00001?ooool0
1?l0003oooooooooooooool5o`0001;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0
000Xooooo`00:?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
4Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00013ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`0_ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool04?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00017o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo000Qoooo
o`Go00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Sooooo1Ol00002
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool02Oooool5o`0000;ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`0_ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool04?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
017ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Uooooo`00:?ooool01?l0
003oooooooooool00009ooooo`;o00004_ooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0_ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo013ooooo00Co0000oooooooooooo00002Oooool2o`0002Sooooo000Xoooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo02oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0@oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Aooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool09Oooool002Sooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo0000017ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo0000013ooooo00Co0000oooooooooooo00002?ooool2o`00037ooooo00Co
0000oooooooooooo00002?ooool2o`0001;ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo0000017ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000002Oooooo000Yooooo`;o00002Oooool3o`0001?ooooo0_l00009ooooo`?o00004_ooool2
o`0000[ooooo00?o0000ooooooooool0<?ooool2o`0000[ooooo00?o0000ooooooooool04Oooool2
o`0000Wooooo0ol0000Cooooo`;o00002Oooool3o`0002Sooooo002?ooooo`03o`000?oooooooooo
08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo
002?ooooo`03o`000?oooooooooo08kooooo000Aoooooogo00004_ooool001?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`Co00000oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo0ol00006ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04_ooool005kooooo0_l0000_ooooo`03o`000?oooooooooo
02gooooo0_l0001Oooooo`00H?ooool3o`0002cooooo00?o0000ooooooooool0:_ooool3o`00067o
oooo001Sooooo`?o0000:Oooool00ol0003oooooooooo`0Xooooo`;o0000I?ooool006Kooooo0_l0
000Wooooo`03o`000?oooooooooo02Kooooo0_l0001Vooooo`00J?ooool3o`0002Cooooo0_l0000U
ooooo`;o0000J?ooool006_ooooo0_l0000Rooooo`03o`000?oooooooooo027ooooo0ol0001Zoooo
o`00KOooool2o`00023ooooo00?o0000ooooooooool07_ooool3o`0006gooooo001_ooooo`?o0000
7Oooool00ol0003oooooooooo`0Looooo`;o0000L?ooool007;ooooo0ol0000Jooooo`03o`000?oo
oooooooo01[ooooo0_l0001booooo`00MOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01Sooooo0_l0001dooooo`00M_ooool00ol0003oooooooooo`0Fooooo`;o00005oooool2o`00
07Kooooo001gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`1fooooo`00N?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0Moooool007Wooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo07Sooooo001iooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1iooooo`00N_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0NOooool007_ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo07[ooooo001looooo`03o`00
0?oooooooooo013ooooo0_l0000Aooooo`03o`000?oooooooooo07_ooooo001looooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1looooo`00OOooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0O?ooool0
07Cooooo1Ol00003ooooo`?o00000oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0O?ooool007Gooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07gooooo001fooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1moooo
o`00Moooool01Ol0003ooooooooooooooooo000000;ooooo0_l000001Ooooooo0000oooooooooooo
000000;ooooo00Co0000oooooooooooo00001?ooool3o`0000kooooo00?o0000ooooooooool0OOoo
ool007Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o000000Go
ooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`1nooooo`00M?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00_l000001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07kooooo001eoooo
o`?o00001?ooool2o`000004ooooool0003oooooooooo`;o00001?ooool2o`0000Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1oooooo`00P?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Ooooool0083ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07oooooo0020ooooo`03o`00
0?oooooooooo00cooooo0_l0000=ooooo`03o`000?oooooooooo07oooooo0021ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`20ooooo`00POooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0P?ooool0
087ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
083ooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`20ooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0P?ooool008;ooooo00?o0000ooooooooool02_ooool2o`0000_ooooo00?o
0000ooooooooool0POooool008;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo087ooooo0022ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`21ooooo`00P_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0POooool008;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo087ooooo0022ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`22ooooo`00P_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0P_ooool0
08?ooooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool0P_ooool008?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08;o
oooo0023ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`22ooooo`00Poooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0P_ooool007Kooooo0ol00003ooooo`;o00001?ooool2o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0P_ooool007Oooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`23ooooo`00M?oo
ool5o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo0ol00008ooooo`03o`000?oooooooooo08?ooooo001dooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`23ooooo`00MOooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0Poooool007Kooooo0_l00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0Poooool007Oooooo00?o0000ooooooooool00_ooool2
o`0000Cooooo0ol00003ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo08?ooooo0024ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`23ooooo`00QOooool00ol0003oooooooooo`07ooooo`;o00002Oooool00ol0003o
ooooooooo`23ooooo`00QOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0Q?ooool008Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo08Cooooo0025ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`24ooooo`00QOooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Q?ooool008Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Cooooo0025ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`24ooooo`00Q_oo
ool00ol0003oooooooooo`06ooooo`;o00002?ooool00ol0003oooooooooo`24ooooo`00Q_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0QOooool0
08Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
08Gooooo0026ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`25ooooo`00Q_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0QOooool008Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo08Gooooo0026ooooo`03o`000?oooooooooo00Kooooo0_l00007
ooooo`03o`000?oooooooooo08Gooooo0026ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`25ooooo`00Qoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0QOooool008Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Kooooo001eooooo`?o00001?oo
ool2o`0000Cooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo08Kooooo001dooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo08Kooooo001dooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool3o`0000Gooooo00?o0000ooooooooool0Q_ooool007Cooooo1?l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q_ooool007Co
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo08Kooooo001eooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`26ooooo`00M_ooool2o`0000Cooooo0_l00004ooooo`;o0000
0oooool3o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`26ooooo`00Qooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q_oo
ool008Oooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool0Q_ooool0
08Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
08Kooooo0028ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`27ooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Qoooool008Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo08Oooooo0028ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`27ooooo`00R?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Qoooool008Sooooo00?o0000oooooooo
ool01?ooool2o`0000Gooooo00?o0000ooooooooool0Qoooool008Sooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo0028ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27ooooo`00R?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Qoooool0
08Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
08Oooooo0029ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`27ooooo`00ROooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003ooooo
ooooo`28ooooo`00ROooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0R?ooool008Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo08Sooooo0029ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`28ooooo`00MOooool3o`0000Cooooo0_l00004ooooo`;o
00001?ooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`28ooooo`00
M?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`28ooooo`00M?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo0000o`00
00Cooooo0ol00003ooooo`03o`000?oooooooooo08Sooooo001eooooo`?o00000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o00001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo001dooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
08Sooooo001dooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo08Sooooo001eooooo`?o00001?ooool2o`0000Cooooo0_l0
0004ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo0029
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`28
ooooo`00ROooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0ROooool008Wooooo00?o0000ooooooooool00oooool2o`0000?ooooo00?o0000oooooooo
ool0ROooool008[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo08Wooooo002:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`29ooooo`00R_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0ROooool008[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo08Wooooo002:ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`29ooooo`00R_ooool00ol0003ooooo
ooooo`02ooooo`;o00000oooool00ol0003oooooooooo`29ooooo`00R_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ROooool008[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Wooooo002:oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`29oooo
o`00R_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000S?ooool008[o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000008cooooo002:ooooo`03
o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo08[ooooo002:ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002<ooooo`00Roooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0R_ooool008_ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo08[ooooo001_ooooo`?o00001?ooool2o`0000Cooooo
0_l00004ooooo`;o00001?ooool2o`000003ooooool0003ooooo00;ooooo00Go0000oooooooooooo
ooooo`00002<ooooo`00L?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;o00000oooool01Ol0003ooooooooooooooooo000008cooooo001`ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?oooooooooooooo
ool00000S?ooool0073ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02o`0000?ooooo0ol000000ooooooo0000ooooo`2;ooooo`00L?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooooooo0000
08cooooo001_ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Go
0000ooooooooooooooooo`00002<ooooo`00L?ooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0000Cooooo0_l00004ooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo08_ooooo002<ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
Roooool008cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`2;ooooo`00S?oo
ool00ol0003oooooooooo`02o`000003ooooool0003ooooo08cooooo002<ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool0Roooool008cooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`2;ooooo`00S?ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo08_ooooo002<ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0Rooo
ool008gooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`2;ooooo`00SOooool00ol0
003oooooo`000002o`0008kooooo002=ooooo`05o`000?oooooo0000ooooool00000S_ooool008go
oooo00Go0000ooooool0003oooooo`00002>ooooo`00SOooool01Ol0003oooooo`000?oooooo0000
08kooooo002=ooooo`05o`000?oooooo0000ooooool00000S_ooool008gooooo00Go0000ooooool0
003oooooo`00002>ooooo`00SOooool00ol0003oooooo`000002o`0008kooooo002=ooooo`05o`00
0?oooooo0000ooooool00000S_ooool008kooooo0ol0002?ooooo`00S_ooool3o`0008oooooo001_
ooooo`?o00000_ooool5o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0ol0002?
ooooo`00L?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0S_ooool0073ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo08kooooo001`ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`?o0000S_ooool0073ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0S_ooool006oooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
0000UOooool0073ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l00004ooooo`;o0000
1?ooool2o`0009Kooooo003oooooob7ooooo002Hooooo`?o0000QOooool009Wooooo00?o0000oooo
ooooool0Q?ooool003?ooooo0ol00003ooooo`?o00000oooool3o`0000;ooooo00Go0000ooooool0
003oooooo`000002ooooo`?o00001?ooool2o`0000;ooooo0ol00003ooooo`Go00000_ooool3o`00
00Sooooo0ol00004ooooo`?o00000_ooool5o`000005ooooool0003o0000o`000?ooool00_l00002
ooooo`;o00002Oooool3o`0000?ooooo0ol00002ooooo`?o00001?ooool3o`0000?ooooo1?l00002
ooooo`Co00001oooool3o`0000Gooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o
0000ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000003ooooool0
003o000003Cooooo000booooo`07o`000?ooooooooooooooool0003oooooo`000005ooooo`0=o`00
0?ooooooooooooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000006ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool0000eooooo`00<_ooool01_l0003ooooooooooooooooo0000oooo
o`Go000000?oooooo`000?ooool00_ooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo
1Ol00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`Go0000
0_ooool3o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool0<oooool003;ooooo00?o0000ooooool000001?l00003ooooo`03o`00
0?oooooo000000?ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000oooool0
1?l0003oooooooooool00005ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool01_ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:oooo
o`;o00000oooool01?l0003oooooooooool00002ooooo`;o00000oooool01ol0003ooooooooooooo
oooo0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Oo
oooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0<oooool003;ooooo00?o0000oooooooo
ool01?ooool3o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?ooool00_ooool3o`0000;o
oooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00004ooooo`?o00002Oooool01?l0
003oooooooooool00002ooooo`?o00000_ooool3o`0000?ooooo1?l00002ooooo`Co00002Oooool0
0ol0003oooooooooo`02ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo0ol00003
ooooo`;o00001?ooool3o`0000Wooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003o
0000ooooo`Co00000oooool3o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l0
000fooooo`00<_ooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool06ooo
ool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo
00007?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000oooo
ooooool0B?ooool003?ooooo0ol0000Kooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03Oooool4o`0000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`?o
00006oooool2o`0000Sooooo1Ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0@Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.439135, -966.893, \
0.00306018, 79.5042}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(ComponentNumber \[Rule] 4.`\), ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(Full3D \[Rule] True\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {207.28232192993164`, 0, 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", \(NumberOfRays \[Rule] 4096\), 
        ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(OpticalMedium \[Rule] Air\), 
        ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"PointSpreadFunction", "\[Rule]", 
              RowBox[{"(", 
                
                TagBox[\(\[SkeletonIndicator]  
                    Graphics  \[SkeletonIndicator]\),
                  False,
                  Editable->False], ")"}]}], "}"}]}], 
        ",", \(PointSpreadFunction \[Rule] 
          "CompiledFunction[-intensity data-]"\), 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(RayBoundary \[Rule] {{\(-0.271850666622095`\), 
              0.271850666622095`}, {\(-0.2697934391868646`\), 
              0.2697934391868646`}}\), 
        ",", \(RayTraceFunction \[Rule] 
          "RayTraceFunction[{f1, f2}, -raytrace code: 7545428 Bytes- ]"\), 
        ",", \(RotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}\), 
        ",", \(SmoothKernelSize \[Rule] 0.024191317607805556`\), 
        ",", \(SourceID \[Rule] 19474\), 
        ",", \(SurfaceNormalFunction \[Rule] \(({{1, 0, 0}, {0, 1, 0}, {0, 0, 
                  1}} &)\)\), ",", \(SurfaceNumber \[Rule] 1.`\), 
        ",", \(SymbolicValues \[Rule] {f1 \[Rule] 100.`, f2 \[Rule] 100.`}\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1.`\), 
        ",", \(WaveLength \[Rule] 0.532`\)}], "}"}]], "Output",
  CellLabel->"Out[184]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
GPSF[sys3D, FindImagePoint->True, FocalFraction->0, Plot2D->False]\
\>", "Input",
  CellLabel->"In[15]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -93 0 ]
[.5 .82364 93 9 ]
[.1041 .21606 -24 -8.92748 ]
[.1041 .21606 0 .07252 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.58679 .02624 -15.3728 -9 ]
[.58679 .02624 2.62721 0 ]
[.74499 .06264 0 -6.19545 ]
[.74499 .06264 24 2.80455 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95162 .37907 0 -5.89608 ]
[.95162 .37907 18 3.10392 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01479 .32355 -12 -2.79174 ]
[.01479 .32355 0 6.20826 ]
[.0051 .38426 -18 -2.84327 ]
[.0051 .38426 0 6.15673 ]
[-0.00496 .44736 -18 -2.89705 ]
[-0.00496 .44736 0 6.10295 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Geometric Point Spread Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.11345 .22526 m
.11813 .22986 L
s
[(-0.2)] .1041 .21606 1 .98388 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.59438 .03695 m
.59817 .0423 L
s
[(0.2)] .58679 .02624 .70809 1 Mshowa
.125 Mabswid
.16898 .20352 m
.17173 .20634 L
s
.22573 .1813 m
.22842 .18417 L
s
.28374 .15858 m
.28638 .16151 L
s
.40374 .1116 m
.40624 .11463 L
s
.46582 .08729 m
.46825 .09038 L
s
.52935 .06241 m
.5317 .06557 L
s
.05912 .24654 m
.06197 .24925 L
s
.66096 .01088 m
.66315 .01415 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.73271 .06727 m
.72657 .06958 L
s
[(-0.2)] .74499 .06264 -1 .37677 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93909 .38296 m
.93282 .3849 L
s
[(0.2)] .95162 .37907 -1 .31024 Mshowa
.125 Mabswid
.76231 .11254 m
.75861 .1139 L
s
.79069 .15595 m
.78698 .15728 L
s
.81792 .19761 m
.8142 .1989 L
s
.86921 .27607 m
.86548 .27731 L
s
.89339 .31305 m
.88965 .31427 L
s
.91667 .34866 m
.91292 .34985 L
s
.70181 .02 m
.69814 .02142 L
s
.9607 .41602 m
.95694 .41716 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02706 .31889 m
.03319 .31657 L
s
[(50)] .01479 .32355 1 -0.37961 Mshowa
.01742 .37972 m
.02357 .37746 L
s
[(100)] .0051 .38426 1 -0.36816 Mshowa
.0074 .44295 m
.01358 .44075 L
s
[(150)] -0.00496 .44736 1 -0.35621 Mshowa
.125 Mabswid
.03451 .27187 m
.03818 .27045 L
s
.03267 .28349 m
.03634 .28208 L
s
.03081 .2952 m
.03449 .29379 L
s
.02894 .307 m
.03262 .3056 L
s
.02516 .33087 m
.02884 .32948 L
s
.02324 .34295 m
.02693 .34156 L
s
.02132 .35511 m
.02501 .35374 L
s
.01937 .36737 m
.02307 .366 L
s
.01544 .39217 m
.01914 .39082 L
s
.01346 .40472 m
.01716 .40337 L
s
.01145 .41736 m
.01515 .41603 L
s
.00943 .43011 m
.01314 .42878 L
s
.00535 .4559 m
.00906 .45459 L
s
.00328 .46895 m
.00699 .46764 L
s
.00119 .4821 m
.00491 .48081 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.663 .741 .908 r
.40025 .60008 .40509 .60458 .41322 .60215 .40839 .59763 Metetra
.663 .741 .908 r
.40839 .59763 .41322 .60215 .42137 .5997 .41656 .59517 Metetra
.673 .744 .904 r
.41656 .59517 .42137 .5997 .42956 .59683 .42476 .59249 Metetra
.673 .752 .91 r
.42476 .59249 .42956 .59683 .43778 .59394 .43299 .5898 Metetra
.663 .76 .922 r
.43299 .5898 .43778 .59394 .446 .59145 .44123 .5873 Metetra
.662 .76 .923 r
.44123 .5873 .446 .59145 .45426 .58897 .4495 .58481 Metetra
.671 .762 .919 r
.4495 .58481 .45426 .58897 .46253 .58649 .4578 .58213 Metetra
.673 .754 .912 r
.4578 .58213 .46253 .58649 .47083 .584 .46612 .57941 Metetra
.665 .743 .908 r
.46612 .57941 .47083 .584 .47916 .5815 .47446 .57687 Metetra
.664 .741 .908 r
.47446 .57687 .47916 .5815 .48751 .579 .48283 .57435 Metetra
.664 .741 .908 r
.48283 .57435 .48751 .579 .49589 .57648 .49123 .57182 Metetra
.664 .741 .908 r
.49123 .57182 .49589 .57648 .50429 .57396 .49965 .56929 Metetra
.664 .741 .908 r
.49965 .56929 .50429 .57396 .51272 .57143 .50809 .56674 Metetra
.664 .741 .908 r
.50809 .56674 .51272 .57143 .52118 .5689 .51657 .56419 Metetra
.664 .741 .908 r
.51657 .56419 .52118 .5689 .52966 .56635 .52506 .56163 Metetra
.664 .741 .908 r
.52506 .56163 .52966 .56635 .53817 .5638 .53359 .55907 Metetra
.664 .741 .908 r
.53359 .55907 .53817 .5638 .5467 .56124 .54214 .55649 Metetra
.664 .741 .908 r
.54214 .55649 .5467 .56124 .55526 .55867 .55072 .55391 Metetra
.664 .741 .908 r
.55072 .55391 .55526 .55867 .56385 .55609 .55932 .55132 Metetra
.664 .741 .908 r
.55932 .55132 .56385 .55609 .57247 .55351 .56796 .54872 Metetra
.664 .741 .908 r
.56796 .54872 .57247 .55351 .58111 .55092 .57661 .54611 Metetra
.664 .741 .908 r
.57661 .54611 .58111 .55092 .58977 .54832 .5853 .5435 Metetra
.664 .741 .908 r
.5853 .5435 .58977 .54832 .59847 .54571 .59401 .54087 Metetra
.664 .741 .908 r
.59401 .54087 .59847 .54571 .60719 .54309 .60275 .53824 Metetra
.664 .741 .908 r
.60275 .53824 .60719 .54309 .61594 .54047 .61152 .5356 Metetra
.664 .741 .908 r
.61152 .5356 .61594 .54047 .62472 .53783 .62032 .53295 Metetra
.664 .741 .908 r
.62032 .53295 .62472 .53783 .63352 .53519 .62914 .53029 Metetra
.664 .741 .908 r
.62914 .53029 .63352 .53519 .64235 .53254 .63799 .52763 Metetra
.664 .741 .908 r
.63799 .52763 .64235 .53254 .65121 .52989 .64687 .52496 Metetra
.664 .741 .908 r
.64687 .52496 .65121 .52989 .6601 .52722 .65578 .52227 Metetra
.664 .741 .908 r
.65578 .52227 .6601 .52722 .66902 .52454 .66471 .51958 Metetra
.664 .741 .908 r
.66471 .51958 .66902 .52454 .67796 .52186 .67368 .51688 Metetra
.664 .741 .908 r
.67368 .51688 .67796 .52186 .68694 .51917 .68267 .51418 Metetra
.664 .741 .908 r
.68267 .51418 .68694 .51917 .69594 .51647 .69169 .51146 Metetra
.664 .741 .908 r
.69169 .51146 .69594 .51647 .70497 .51376 .70074 .50874 Metetra
.664 .741 .908 r
.70074 .50874 .70497 .51376 .71403 .51104 .70982 .506 Metetra
.664 .741 .908 r
.70982 .506 .71403 .51104 .72311 .50832 .71893 .50326 Metetra
.664 .741 .908 r
.71893 .50326 .72311 .50832 .73223 .50558 .72806 .50051 Metetra
.664 .741 .908 r
.72806 .50051 .73223 .50558 .74138 .50284 .73723 .49775 Metetra
.664 .741 .908 r
.73723 .49775 .74138 .50284 .75055 .50008 .74643 .49498 Metetra
.664 .741 .908 r
.74643 .49498 .75055 .50008 .75976 .49732 .75565 .4922 Metetra
.664 .741 .908 r
.75565 .4922 .75976 .49732 .76899 .49455 .76491 .48941 Metetra
.664 .741 .908 r
.76491 .48941 .76899 .49455 .77826 .49177 .77419 .48662 Metetra
.664 .741 .908 r
.77419 .48662 .77826 .49177 .78755 .48898 .78351 .48381 Metetra
.664 .741 .908 r
.78351 .48381 .78755 .48898 .79688 .48619 .79286 .481 Metetra
.664 .741 .908 r
.79286 .481 .79688 .48619 .80623 .48338 .80223 .47818 Metetra
.664 .741 .908 r
.80223 .47818 .80623 .48338 .81562 .48057 .81164 .47534 Metetra
.664 .741 .908 r
.81164 .47534 .81562 .48057 .82503 .47774 .82108 .4725 Metetra
.664 .741 .908 r
.82108 .4725 .82503 .47774 .83448 .47491 .83054 .46965 Metetra
.664 .741 .908 r
.83054 .46965 .83448 .47491 .84395 .47206 .84004 .46679 Metetra
.664 .741 .908 r
.84004 .46679 .84395 .47206 .85346 .46921 .84957 .46392 Metetra
.664 .741 .908 r
.84957 .46392 .85346 .46921 .863 .46635 .85914 .46104 Metetra
.664 .741 .908 r
.85914 .46104 .863 .46635 .87257 .46348 .86873 .45815 Metetra
.664 .741 .908 r
.86873 .45815 .87257 .46348 .88217 .4606 .87835 .45526 Metetra
.662 .741 .908 r
.87835 .45526 .88217 .4606 .89181 .45771 .88801 .45238 Metetra
.655 .739 .912 r
.88801 .45238 .89181 .45771 .90147 .45481 .89773 .44968 Metetra
.655 .748 .919 r
.89773 .44968 .90147 .45481 .91117 .4519 .90747 .44695 Metetra
.662 .76 .923 r
.90747 .44695 .91117 .4519 .9209 .44898 .91723 .44402 Metetra
.662 .76 .923 r
.91723 .44402 .9209 .44898 .93066 .44608 .92701 .44108 Metetra
.653 .755 .925 r
.92701 .44108 .93066 .44608 .94052 .44359 .93686 .43836 Metetra
.654 .746 .918 r
.93686 .43836 .94052 .44359 .9504 .44108 .94674 .43561 Metetra
.663 .741 .908 r
.94674 .43561 .9504 .44108 .96026 .43812 .95663 .43264 Metetra
.663 .741 .908 r
.95663 .43264 .96026 .43812 .97016 .43516 .96655 .42965 Metetra
.663 .741 .908 r
.39538 .59555 .40025 .60008 .40839 .59763 .40354 .59308 Metetra
.663 .741 .908 r
.40354 .59308 .40839 .59763 .41656 .59517 .41173 .59061 Metetra
.664 .741 .908 r
.41173 .59061 .41656 .59517 .42476 .59249 .41994 .58812 Metetra
.663 .75 .915 r
.41994 .58812 .42476 .59249 .43299 .5898 .42817 .58563 Metetra
.662 .759 .922 r
.42817 .58563 .43299 .5898 .44123 .5873 .43643 .58313 Metetra
.662 .76 .923 r
.43643 .58313 .44123 .5873 .4495 .58481 .44472 .58063 Metetra
.68 .764 .915 r
.44472 .58063 .4495 .58481 .4578 .58213 .45303 .57774 Metetra
.682 .756 .908 r
.45303 .57774 .4578 .58213 .46612 .57941 .46138 .57479 Metetra
.666 .743 .908 r
.46138 .57479 .46612 .57941 .47446 .57687 .46974 .57221 Metetra
.664 .741 .908 r
.46974 .57221 .47446 .57687 .48283 .57435 .47812 .56968 Metetra
.664 .741 .908 r
.47812 .56968 .48283 .57435 .49123 .57182 .48653 .56713 Metetra
.664 .741 .908 r
.48653 .56713 .49123 .57182 .49965 .56929 .49497 .56459 Metetra
.664 .741 .908 r
.49497 .56459 .49965 .56929 .50809 .56674 .50344 .56203 Metetra
.664 .741 .908 r
.50344 .56203 .50809 .56674 .51657 .56419 .51193 .55946 Metetra
.664 .741 .908 r
.51193 .55946 .51657 .56419 .52506 .56163 .52044 .55689 Metetra
.664 .741 .908 r
.52044 .55689 .52506 .56163 .53359 .55907 .52898 .55431 Metetra
.664 .741 .908 r
.52898 .55431 .53359 .55907 .54214 .55649 .53755 .55172 Metetra
.664 .741 .908 r
.53755 .55172 .54214 .55649 .55072 .55391 .54615 .54912 Metetra
.664 .741 .908 r
.54615 .54912 .55072 .55391 .55932 .55132 .55477 .54651 Metetra
.664 .741 .908 r
.55477 .54651 .55932 .55132 .56796 .54872 .56342 .5439 Metetra
.664 .741 .908 r
.56342 .5439 .56796 .54872 .57661 .54611 .5721 .54128 Metetra
.664 .741 .908 r
.5721 .54128 .57661 .54611 .5853 .5435 .5808 .53865 Metetra
.664 .741 .908 r
.5808 .53865 .5853 .5435 .59401 .54087 .58953 .53601 Metetra
.664 .741 .908 r
.58953 .53601 .59401 .54087 .60275 .53824 .59829 .53336 Metetra
.664 .741 .908 r
.59829 .53336 .60275 .53824 .61152 .5356 .60708 .5307 Metetra
.664 .741 .908 r
.60708 .5307 .61152 .5356 .62032 .53295 .61589 .52804 Metetra
.664 .741 .908 r
.61589 .52804 .62032 .53295 .62914 .53029 .62473 .52537 Metetra
.664 .741 .908 r
.62473 .52537 .62914 .53029 .63799 .52763 .6336 .52269 Metetra
.664 .741 .908 r
.6336 .52269 .63799 .52763 .64687 .52496 .6425 .52 Metetra
.664 .741 .908 r
.6425 .52 .64687 .52496 .65578 .52227 .65143 .5173 Metetra
.664 .741 .908 r
.65143 .5173 .65578 .52227 .66471 .51958 .66038 .51459 Metetra
.664 .741 .908 r
.66038 .51459 .66471 .51958 .67368 .51688 .66937 .51188 Metetra
.664 .741 .908 r
.66937 .51188 .67368 .51688 .68267 .51418 .67838 .50916 Metetra
.664 .741 .908 r
.67838 .50916 .68267 .51418 .69169 .51146 .68742 .50642 Metetra
.664 .741 .908 r
.68742 .50642 .69169 .51146 .70074 .50874 .69649 .50368 Metetra
.664 .741 .908 r
.69649 .50368 .70074 .50874 .70982 .506 .70559 .50093 Metetra
.664 .741 .908 r
.70559 .50093 .70982 .506 .71893 .50326 .71472 .49817 Metetra
.664 .741 .908 r
.71472 .49817 .71893 .50326 .72806 .50051 .72387 .49541 Metetra
.664 .741 .908 r
.72387 .49541 .72806 .50051 .73723 .49775 .73306 .49263 Metetra
.664 .741 .908 r
.73306 .49263 .73723 .49775 .74643 .49498 .74228 .48984 Metetra
.664 .741 .908 r
.74228 .48984 .74643 .49498 .75565 .4922 .75152 .48705 Metetra
.664 .741 .908 r
.75152 .48705 .75565 .4922 .76491 .48941 .7608 .48425 Metetra
.664 .741 .908 r
.7608 .48425 .76491 .48941 .77419 .48662 .77011 .48143 Metetra
.664 .741 .908 r
.77011 .48143 .77419 .48662 .78351 .48381 .77944 .47861 Metetra
.664 .741 .908 r
.77944 .47861 .78351 .48381 .79286 .481 .78881 .47578 Metetra
.664 .741 .908 r
.78881 .47578 .79286 .481 .80223 .47818 .79821 .47294 Metetra
.664 .741 .908 r
.79821 .47294 .80223 .47818 .81164 .47534 .80764 .47009 Metetra
.664 .741 .908 r
.80764 .47009 .81164 .47534 .82108 .4725 .8171 .46723 Metetra
.664 .741 .908 r
.8171 .46723 .82108 .4725 .83054 .46965 .82659 .46436 Metetra
.664 .741 .908 r
.82659 .46436 .83054 .46965 .84004 .46679 .83611 .46149 Metetra
.664 .741 .908 r
.83611 .46149 .84004 .46679 .84957 .46392 .84566 .4586 Metetra
.664 .741 .908 r
.84566 .4586 .84957 .46392 .85914 .46104 .85525 .4557 Metetra
.664 .741 .908 r
.85525 .4557 .85914 .46104 .86873 .45815 .86486 .4528 Metetra
.664 .741 .908 r
.86486 .4528 .86873 .45815 .87835 .45526 .87451 .44988 Metetra
.661 .74 .909 r
.87451 .44988 .87835 .45526 .88801 .45238 .8842 .44701 Metetra
.646 .735 .914 r
.8842 .44701 .88801 .45238 .89773 .44968 .89396 .44452 Metetra
.646 .745 .921 r
.89396 .44452 .89773 .44968 .90747 .44695 .90375 .44197 Metetra
.662 .76 .923 r
.90375 .44197 .90747 .44695 .91723 .44402 .91353 .43902 Metetra
.662 .76 .923 r
.91353 .43902 .91723 .44402 .92701 .44108 .92334 .43606 Metetra
.662 .759 .922 r
.92334 .43606 .92701 .44108 .93686 .43836 .93319 .43309 Metetra
.663 .75 .915 r
.93319 .43309 .93686 .43836 .94674 .43561 .94307 .43011 Metetra
.663 .741 .908 r
.94307 .43011 .94674 .43561 .95663 .43264 .95298 .42712 Metetra
.663 .741 .908 r
.95298 .42712 .95663 .43264 .96655 .42965 .96292 .42412 Metetra
.655 .722 .898 r
.3905 .59057 .39538 .59555 .40354 .59308 .39867 .5883 Metetra
.655 .73 .905 r
.39867 .5883 .40354 .59308 .41173 .59061 .40686 .58602 Metetra
.654 .739 .912 r
.40686 .58602 .41173 .59061 .41994 .58812 .41508 .58373 Metetra
.653 .748 .919 r
.41508 .58373 .41994 .58812 .42817 .58563 .42332 .58144 Metetra
.671 .761 .918 r
.42332 .58144 .42817 .58563 .43643 .58313 .43161 .57875 Metetra
.672 .754 .912 r
.43161 .57875 .43643 .58313 .44472 .58063 .43991 .57603 Metetra
.665 .743 .908 r
.43991 .57603 .44472 .58063 .45303 .57774 .44824 .57346 Metetra
.664 .758 .92 r
.44824 .57346 .45303 .57774 .46138 .57479 .45659 .57091 Metetra
.678 .78 .927 r
.45659 .57091 .46138 .57479 .46974 .57221 .46498 .56801 Metetra
.681 .766 .916 r
.46498 .56801 .46974 .57221 .47812 .56968 .47339 .56504 Metetra
.666 .745 .909 r
.47339 .56504 .47812 .56968 .48653 .56713 .48182 .56242 Metetra
.664 .741 .908 r
.48182 .56242 .48653 .56713 .49497 .56459 .49027 .55986 Metetra
.664 .741 .908 r
.49027 .55986 .49497 .56459 .50344 .56203 .49875 .55728 Metetra
.664 .741 .908 r
.49875 .55728 .50344 .56203 .51193 .55946 .50726 .5547 Metetra
.664 .741 .908 r
.50726 .5547 .51193 .55946 .52044 .55689 .51579 .55212 Metetra
.664 .741 .908 r
.51579 .55212 .52044 .55689 .52898 .55431 .52435 .54952 Metetra
.664 .741 .908 r
.52435 .54952 .52898 .55431 .53755 .55172 .53294 .54691 Metetra
.664 .741 .908 r
.53294 .54691 .53755 .55172 .54615 .54912 .54155 .5443 Metetra
.664 .741 .908 r
.54155 .5443 .54615 .54912 .55477 .54651 .55019 .54168 Metetra
.664 .741 .908 r
.55019 .54168 .55477 .54651 .56342 .5439 .55886 .53905 Metetra
.664 .741 .908 r
.55886 .53905 .56342 .5439 .5721 .54128 .56755 .53641 Metetra
.664 .741 .908 r
.56755 .53641 .5721 .54128 .5808 .53865 .57628 .53377 Metetra
.664 .741 .908 r
.57628 .53377 .5808 .53865 .58953 .53601 .58502 .53111 Metetra
.664 .741 .908 r
.58502 .53111 .58953 .53601 .59829 .53336 .5938 .52845 Metetra
.664 .741 .908 r
.5938 .52845 .59829 .53336 .60708 .5307 .60261 .52578 Metetra
.664 .741 .908 r
.60261 .52578 .60708 .5307 .61589 .52804 .61144 .5231 Metetra
.664 .741 .908 r
.61144 .5231 .61589 .52804 .62473 .52537 .6203 .52041 Metetra
.664 .741 .908 r
.6203 .52041 .62473 .52537 .6336 .52269 .62919 .51772 Metetra
.664 .741 .908 r
.62919 .51772 .6336 .52269 .6425 .52 .63811 .51501 Metetra
.664 .741 .908 r
.63811 .51501 .6425 .52 .65143 .5173 .64705 .5123 Metetra
.664 .741 .908 r
.64705 .5123 .65143 .5173 .66038 .51459 .65603 .50957 Metetra
.664 .741 .908 r
.65603 .50957 .66038 .51459 .66937 .51188 .66503 .50684 Metetra
.664 .741 .908 r
.66503 .50684 .66937 .51188 .67838 .50916 .67406 .5041 Metetra
.664 .741 .908 r
.67406 .5041 .67838 .50916 .68742 .50642 .68312 .50136 Metetra
.664 .741 .908 r
.68312 .50136 .68742 .50642 .69649 .50368 .69221 .4986 Metetra
.664 .741 .908 r
.69221 .4986 .69649 .50368 .70559 .50093 .70133 .49583 Metetra
.664 .741 .908 r
.70133 .49583 .70559 .50093 .71472 .49817 .71048 .49306 Metetra
.664 .741 .908 r
.71048 .49306 .71472 .49817 .72387 .49541 .71966 .49027 Metetra
.664 .741 .908 r
.71966 .49027 .72387 .49541 .73306 .49263 .72887 .48748 Metetra
.664 .741 .908 r
.72887 .48748 .73306 .49263 .74228 .48984 .7381 .48468 Metetra
.664 .741 .908 r
.7381 .48468 .74228 .48984 .75152 .48705 .74737 .48187 Metetra
.664 .741 .908 r
.74737 .48187 .75152 .48705 .7608 .48425 .75667 .47905 Metetra
.664 .741 .908 r
.75667 .47905 .7608 .48425 .77011 .48143 .766 .47622 Metetra
.664 .741 .908 r
.766 .47622 .77011 .48143 .77944 .47861 .77535 .47338 Metetra
.664 .741 .908 r
.77535 .47338 .77944 .47861 .78881 .47578 .78474 .47053 Metetra
.664 .741 .908 r
.78474 .47053 .78881 .47578 .79821 .47294 .79416 .46767 Metetra
.664 .741 .908 r
.79416 .46767 .79821 .47294 .80764 .47009 .80361 .4648 Metetra
.664 .741 .908 r
.80361 .4648 .80764 .47009 .8171 .46723 .81309 .46193 Metetra
.664 .741 .908 r
.81309 .46193 .8171 .46723 .82659 .46436 .82261 .45904 Metetra
.664 .741 .908 r
.82261 .45904 .82659 .46436 .83611 .46149 .83215 .45615 Metetra
.664 .741 .908 r
.83215 .45615 .83611 .46149 .84566 .4586 .84173 .45324 Metetra
.664 .741 .908 r
.84173 .45324 .84566 .4586 .85525 .4557 .85133 .45033 Metetra
.661 .74 .909 r
.85133 .45033 .85525 .4557 .86486 .4528 .86098 .44747 Metetra
.646 .737 .915 r
.86098 .44747 .86486 .4528 .87451 .44988 .8707 .44497 Metetra
.646 .755 .929 r
.8707 .44497 .87451 .44988 .8842 .44701 .88044 .4424 Metetra
.66 .775 .935 r
.88044 .4424 .8842 .44701 .89396 .44452 .89018 .43947 Metetra
.661 .757 .921 r
.89018 .43947 .89396 .44452 .90375 .44197 .89996 .43655 Metetra
.655 .739 .912 r
.89996 .43655 .90375 .44197 .91353 .43902 .90979 .43379 Metetra
.655 .748 .918 r
.90979 .43379 .91353 .43902 .92334 .43606 .91964 .431 Metetra
.671 .763 .919 r
.91964 .431 .92334 .43606 .93319 .43309 .92949 .42779 Metetra
.672 .754 .912 r
.92949 .42779 .93319 .43309 .94307 .43011 .93936 .42457 Metetra
.672 .745 .905 r
.93936 .42457 .94307 .43011 .95298 .42712 .94927 .42134 Metetra
.672 .736 .899 r
.94927 .42134 .95298 .42712 .96292 .42412 .95921 .41811 Metetra
.645 .719 .902 r
.3856 .58556 .3905 .59057 .39867 .5883 .39377 .58349 Metetra
.645 .727 .909 r
.39377 .58349 .39867 .5883 .40686 .58602 .40197 .5814 Metetra
.644 .736 .916 r
.40197 .5814 .40686 .58602 .41508 .58373 .4102 .57931 Metetra
.643 .745 .923 r
.4102 .57931 .41508 .58373 .42332 .58144 .41845 .57722 Metetra
.679 .763 .914 r
.41845 .57722 .42332 .58144 .43161 .57875 .42675 .57433 Metetra
.682 .756 .907 r
.42675 .57433 .43161 .57875 .43991 .57603 .43508 .57138 Metetra
.648 .738 .915 r
.43508 .57138 .43991 .57603 .44824 .57346 .44342 .56917 Metetra
.642 .753 .929 r
.44342 .56917 .44824 .57346 .45659 .57091 .45178 .56703 Metetra
.693 .784 .921 r
.45178 .56703 .45659 .57091 .46498 .56801 .46019 .56379 Metetra
.699 .771 .907 r
.46019 .56379 .46498 .56801 .47339 .56504 .46863 .56039 Metetra
.669 .746 .908 r
.46863 .56039 .47339 .56504 .48182 .56242 .47707 .55768 Metetra
.664 .741 .908 r
.47707 .55768 .48182 .56242 .49027 .55986 .48554 .5551 Metetra
.664 .741 .908 r
.48554 .5551 .49027 .55986 .49875 .55728 .49404 .55251 Metetra
.664 .741 .908 r
.49404 .55251 .49875 .55728 .50726 .5547 .50256 .54992 Metetra
.664 .741 .908 r
.50256 .54992 .50726 .5547 .51579 .55212 .51111 .54732 Metetra
.664 .741 .908 r
.51111 .54732 .51579 .55212 .52435 .54952 .51969 .5447 Metetra
.664 .741 .908 r
.51969 .5447 .52435 .54952 .53294 .54691 .5283 .54208 Metetra
.664 .741 .908 r
.5283 .54208 .53294 .54691 .54155 .5443 .53693 .53946 Metetra
.664 .741 .908 r
.53693 .53946 .54155 .5443 .55019 .54168 .54558 .53682 Metetra
.664 .741 .908 r
.54558 .53682 .55019 .54168 .55886 .53905 .55427 .53417 Metetra
.664 .741 .908 r
.55427 .53417 .55886 .53905 .56755 .53641 .56298 .53152 Metetra
.664 .741 .908 r
.56298 .53152 .56755 .53641 .57628 .53377 .57172 .52886 Metetra
.664 .741 .908 r
.57172 .52886 .57628 .53377 .58502 .53111 .58049 .52619 Metetra
.664 .741 .908 r
.58049 .52619 .58502 .53111 .5938 .52845 .58929 .52351 Metetra
.664 .741 .908 r
.58929 .52351 .5938 .52845 .60261 .52578 .59811 .52083 Metetra
.664 .741 .908 r
.59811 .52083 .60261 .52578 .61144 .5231 .60696 .51813 Metetra
.664 .741 .908 r
.60696 .51813 .61144 .5231 .6203 .52041 .61584 .51543 Metetra
.664 .741 .908 r
.61584 .51543 .6203 .52041 .62919 .51772 .62475 .51272 Metetra
.664 .741 .908 r
.62475 .51272 .62919 .51772 .63811 .51501 .63369 .50999 Metetra
.664 .741 .908 r
.63369 .50999 .63811 .51501 .64705 .5123 .64265 .50726 Metetra
.664 .741 .908 r
.64265 .50726 .64705 .5123 .65603 .50957 .65164 .50453 Metetra
.664 .741 .908 r
.65164 .50453 .65603 .50957 .66503 .50684 .66067 .50178 Metetra
.664 .741 .908 r
.66067 .50178 .66503 .50684 .67406 .5041 .66972 .49902 Metetra
.664 .741 .908 r
.66972 .49902 .67406 .5041 .68312 .50136 .6788 .49626 Metetra
.664 .741 .908 r
.6788 .49626 .68312 .50136 .69221 .4986 .68791 .49348 Metetra
.664 .741 .908 r
.68791 .49348 .69221 .4986 .70133 .49583 .69705 .4907 Metetra
.664 .741 .908 r
.69705 .4907 .70133 .49583 .71048 .49306 .70622 .48791 Metetra
.664 .741 .908 r
.70622 .48791 .71048 .49306 .71966 .49027 .71542 .48511 Metetra
.664 .741 .908 r
.71542 .48511 .71966 .49027 .72887 .48748 .72464 .4823 Metetra
.664 .741 .908 r
.72464 .4823 .72887 .48748 .7381 .48468 .7339 .47948 Metetra
.664 .741 .908 r
.7339 .47948 .7381 .48468 .74737 .48187 .74319 .47665 Metetra
.664 .741 .908 r
.74319 .47665 .74737 .48187 .75667 .47905 .75251 .47381 Metetra
.664 .741 .908 r
.75251 .47381 .75667 .47905 .766 .47622 .76186 .47097 Metetra
.664 .741 .908 r
.76186 .47097 .766 .47622 .77535 .47338 .77124 .46811 Metetra
.664 .741 .908 r
.77124 .46811 .77535 .47338 .78474 .47053 .78065 .46525 Metetra
.664 .741 .908 r
.78065 .46525 .78474 .47053 .79416 .46767 .79009 .46237 Metetra
.664 .741 .908 r
.79009 .46237 .79416 .46767 .80361 .4648 .79956 .45949 Metetra
.664 .741 .908 r
.79956 .45949 .80361 .4648 .81309 .46193 .80907 .45659 Metetra
.664 .741 .908 r
.80907 .45659 .81309 .46193 .82261 .45904 .8186 .45369 Metetra
.664 .741 .908 r
.8186 .45369 .82261 .45904 .83215 .45615 .82817 .45078 Metetra
.664 .741 .908 r
.82817 .45078 .83215 .45615 .84173 .45324 .83777 .44786 Metetra
.664 .741 .908 r
.83777 .44786 .84173 .45324 .85133 .45033 .8474 .44492 Metetra
.658 .739 .91 r
.8474 .44492 .85133 .45033 .86098 .44747 .85707 .44212 Metetra
.627 .729 .921 r
.85707 .44212 .86098 .44747 .8707 .44497 .86686 .44004 Metetra
.631 .75 .934 r
.86686 .44004 .8707 .44497 .88044 .4424 .87666 .43779 Metetra
.679 .784 .929 r
.87666 .43779 .88044 .4424 .89018 .43947 .88638 .43439 Metetra
.676 .763 .916 r
.88638 .43439 .89018 .43947 .89996 .43655 .89614 .43107 Metetra
.646 .735 .914 r
.89614 .43107 .89996 .43655 .90979 .43379 .90602 .42852 Metetra
.647 .745 .92 r
.90602 .42852 .90979 .43379 .91964 .431 .91592 .4259 Metetra
.68 .766 .916 r
.91592 .4259 .91964 .431 .92949 .42779 .92577 .42245 Metetra
.68 .757 .909 r
.92577 .42245 .92949 .42779 .93936 .42457 .93564 .419 Metetra
.68 .748 .902 r
.93564 .419 .93936 .42457 .94927 .42134 .94554 .41553 Metetra
.68 .739 .896 r
.94554 .41553 .94927 .42134 .95921 .41811 .95547 .41205 Metetra
.643 .735 .915 r
.38065 .58092 .3856 .58556 .39377 .58349 .38883 .57885 Metetra
.643 .735 .916 r
.38883 .57885 .39377 .58349 .40197 .5814 .39705 .57677 Metetra
.652 .739 .913 r
.39705 .57677 .40197 .5814 .4102 .57931 .4053 .57448 Metetra
.653 .731 .907 r
.4053 .57448 .4102 .57931 .41845 .57722 .41357 .57219 Metetra
.672 .729 .893 r
.41357 .57219 .41845 .57722 .42675 .57433 .42189 .56945 Metetra
.673 .736 .897 r
.42189 .56945 .42675 .57433 .43508 .57138 .43023 .56667 Metetra
.647 .736 .914 r
.43023 .56667 .43508 .57138 .44342 .56917 .43858 .56448 Metetra
.643 .737 .917 r
.43858 .56448 .44342 .56917 .45178 .56703 .44695 .56236 Metetra
.678 .747 .903 r
.44695 .56236 .45178 .56703 .46019 .56379 .45538 .55944 Metetra
.684 .763 .911 r
.45538 .55944 .46019 .56379 .46863 .56039 .46382 .55639 Metetra
.673 .777 .928 r
.46382 .55639 .46863 .56039 .47707 .55768 .47229 .55356 Metetra
.671 .771 .925 r
.47229 .55356 .47707 .55768 .48554 .5551 .48078 .55077 Metetra
.664 .761 .922 r
.48078 .55077 .48554 .5551 .49404 .55251 .4893 .54812 Metetra
.663 .759 .921 r
.4893 .54812 .49404 .55251 .50256 .54992 .49784 .54551 Metetra
.67 .76 .918 r
.49784 .54551 .50256 .54992 .51111 .54732 .50641 .54274 Metetra
.672 .754 .912 r
.50641 .54274 .51111 .54732 .51969 .5447 .51501 .53991 Metetra
.666 .744 .909 r
.51501 .53991 .51969 .5447 .5283 .54208 .52363 .53723 Metetra
.664 .741 .908 r
.52363 .53723 .5283 .54208 .53693 .53946 .53228 .53458 Metetra
.664 .741 .908 r
.53228 .53458 .53693 .53946 .54558 .53682 .54095 .53193 Metetra
.664 .741 .908 r
.54095 .53193 .54558 .53682 .55427 .53417 .54966 .52927 Metetra
.664 .741 .908 r
.54966 .52927 .55427 .53417 .56298 .53152 .55839 .5266 Metetra
.664 .741 .908 r
.55839 .5266 .56298 .53152 .57172 .52886 .56714 .52393 Metetra
.664 .741 .908 r
.56714 .52393 .57172 .52886 .58049 .52619 .57593 .52124 Metetra
.664 .741 .908 r
.57593 .52124 .58049 .52619 .58929 .52351 .58475 .51855 Metetra
.664 .741 .908 r
.58475 .51855 .58929 .52351 .59811 .52083 .59359 .51584 Metetra
.664 .741 .908 r
.59359 .51584 .59811 .52083 .60696 .51813 .60246 .51313 Metetra
.664 .741 .908 r
.60246 .51313 .60696 .51813 .61584 .51543 .61136 .51041 Metetra
.664 .741 .908 r
.61136 .51041 .61584 .51543 .62475 .51272 .62028 .50769 Metetra
.664 .741 .908 r
.62028 .50769 .62475 .51272 .63369 .50999 .62924 .50495 Metetra
.664 .741 .908 r
.62924 .50495 .63369 .50999 .64265 .50726 .63822 .5022 Metetra
.664 .741 .908 r
.63822 .5022 .64265 .50726 .65164 .50453 .64724 .49945 Metetra
.664 .741 .908 r
.64724 .49945 .65164 .50453 .66067 .50178 .65628 .49668 Metetra
.664 .741 .908 r
.65628 .49668 .66067 .50178 .66972 .49902 .66535 .49391 Metetra
.664 .741 .908 r
.66535 .49391 .66972 .49902 .6788 .49626 .67445 .49113 Metetra
.664 .741 .908 r
.67445 .49113 .6788 .49626 .68791 .49348 .68358 .48834 Metetra
.664 .741 .908 r
.68358 .48834 .68791 .49348 .69705 .4907 .69274 .48554 Metetra
.664 .741 .908 r
.69274 .48554 .69705 .4907 .70622 .48791 .70193 .48273 Metetra
.664 .741 .908 r
.70193 .48273 .70622 .48791 .71542 .48511 .71115 .47991 Metetra
.664 .741 .908 r
.71115 .47991 .71542 .48511 .72464 .4823 .7204 .47709 Metetra
.664 .741 .908 r
.7204 .47709 .72464 .4823 .7339 .47948 .72968 .47425 Metetra
.664 .741 .908 r
.72968 .47425 .7339 .47948 .74319 .47665 .73899 .47141 Metetra
.664 .741 .908 r
.73899 .47141 .74319 .47665 .75251 .47381 .74833 .46855 Metetra
.664 .741 .908 r
.74833 .46855 .75251 .47381 .76186 .47097 .7577 .46569 Metetra
.664 .741 .908 r
.7577 .46569 .76186 .47097 .77124 .46811 .7671 .46281 Metetra
.664 .741 .908 r
.7671 .46281 .77124 .46811 .78065 .46525 .77653 .45993 Metetra
.664 .741 .908 r
.77653 .45993 .78065 .46525 .79009 .46237 .786 .45704 Metetra
.661 .74 .909 r
.786 .45704 .79009 .46237 .79956 .45949 .79549 .45419 Metetra
.655 .74 .912 r
.79549 .45419 .79956 .45949 .80907 .45659 .80504 .45149 Metetra
.656 .749 .918 r
.80504 .45149 .80907 .45659 .8186 .45369 .81461 .44873 Metetra
.663 .759 .921 r
.81461 .44873 .8186 .45369 .82817 .45078 .8242 .4458 Metetra
.661 .758 .922 r
.8242 .4458 .82817 .45078 .83777 .44786 .83383 .4429 Metetra
.654 .757 .926 r
.83383 .4429 .83777 .44786 .8474 .44492 .8435 .44015 Metetra
.65 .765 .933 r
.8435 .44015 .8474 .44492 .85707 .44212 .85321 .43745 Metetra
.639 .765 .94 r
.85321 .43745 .85707 .44212 .86686 .44004 .86298 .43496 Metetra
.647 .751 .925 r
.86298 .43496 .86686 .44004 .87666 .43779 .87278 .43235 Metetra
.681 .75 .904 r
.87278 .43235 .87666 .43779 .88638 .43439 .88252 .42891 Metetra
.678 .748 .904 r
.88252 .42891 .88638 .43439 .89614 .43107 .89229 .42553 Metetra
.654 .737 .91 r
.89229 .42553 .89614 .43107 .90602 .42852 .90217 .42276 Metetra
.655 .73 .904 r
.90217 .42276 .90602 .42852 .91592 .4259 .91208 .41996 Metetra
.672 .73 .893 r
.91208 .41996 .91592 .4259 .92577 .42245 .92197 .41668 Metetra
.673 .738 .899 r
.92197 .41668 .92577 .42245 .93564 .419 .93189 .41339 Metetra
.681 .748 .902 r
.93189 .41339 .93564 .419 .94554 .41553 .94182 .40989 Metetra
.68 .748 .902 r
.94182 .40989 .94554 .41553 .95547 .41205 .95177 .40637 Metetra
.643 .736 .916 r
.37567 .57629 .38065 .58092 .38883 .57885 .38387 .5742 Metetra
.643 .736 .916 r
.38387 .5742 .38883 .57885 .39705 .57677 .3921 .5721 Metetra
.662 .741 .909 r
.3921 .5721 .39705 .57677 .4053 .57448 .40037 .5696 Metetra
.663 .733 .902 r
.40037 .5696 .4053 .57448 .41357 .57219 .40867 .56708 Metetra
.664 .725 .894 r
.40867 .56708 .41357 .57219 .42189 .56945 .41699 .56451 Metetra
.664 .732 .9 r
.41699 .56451 .42189 .56945 .43023 .56667 .42535 .56193 Metetra
.646 .736 .915 r
.42535 .56193 .43023 .56667 .43858 .56448 .43371 .55975 Metetra
.643 .736 .916 r
.43371 .55975 .43858 .56448 .44695 .56236 .4421 .55761 Metetra
.663 .741 .908 r
.4421 .55761 .44695 .56236 .45538 .55944 .45053 .55505 Metetra
.665 .758 .92 r
.45053 .55505 .45538 .55944 .46382 .55639 .45899 .55241 Metetra
.678 .78 .927 r
.45899 .55241 .46382 .55639 .47229 .55356 .46748 .54946 Metetra
.681 .776 .922 r
.46748 .54946 .47229 .55356 .48078 .55077 .47599 .54643 Metetra
.666 .763 .922 r
.47599 .54643 .48078 .55077 .4893 .54812 .48453 .54374 Metetra
.663 .76 .922 r
.48453 .54374 .4893 .54812 .49784 .54551 .49309 .54111 Metetra
.677 .764 .916 r
.49309 .54111 .49784 .54551 .50641 .54274 .50168 .53816 Metetra
.681 .757 .909 r
.50168 .53816 .50641 .54274 .51501 .53991 .51029 .5351 Metetra
.668 .745 .908 r
.51029 .5351 .51501 .53991 .52363 .53723 .51893 .53234 Metetra
.664 .741 .908 r
.51893 .53234 .52363 .53723 .53228 .53458 .5276 .52968 Metetra
.664 .741 .908 r
.5276 .52968 .53228 .53458 .54095 .53193 .53629 .52701 Metetra
.664 .741 .908 r
.53629 .52701 .54095 .53193 .54966 .52927 .54501 .52434 Metetra
.664 .741 .908 r
.54501 .52434 .54966 .52927 .55839 .5266 .55376 .52165 Metetra
.664 .741 .908 r
.55376 .52165 .55839 .5266 .56714 .52393 .56254 .51896 Metetra
.664 .741 .908 r
.56254 .51896 .56714 .52393 .57593 .52124 .57134 .51626 Metetra
.664 .741 .908 r
.57134 .51626 .57593 .52124 .58475 .51855 .58018 .51355 Metetra
.664 .741 .908 r
.58018 .51355 .58475 .51855 .59359 .51584 .58904 .51083 Metetra
.664 .741 .908 r
.58904 .51083 .59359 .51584 .60246 .51313 .59793 .50811 Metetra
.664 .741 .908 r
.59793 .50811 .60246 .51313 .61136 .51041 .60684 .50537 Metetra
.664 .741 .908 r
.60684 .50537 .61136 .51041 .62028 .50769 .61579 .50263 Metetra
.664 .741 .908 r
.61579 .50263 .62028 .50769 .62924 .50495 .62477 .49987 Metetra
.664 .741 .908 r
.62477 .49987 .62924 .50495 .63822 .5022 .63377 .49711 Metetra
.664 .741 .908 r
.63377 .49711 .63822 .5022 .64724 .49945 .6428 .49434 Metetra
.664 .741 .908 r
.6428 .49434 .64724 .49945 .65628 .49668 .65186 .49156 Metetra
.664 .741 .908 r
.65186 .49156 .65628 .49668 .66535 .49391 .66096 .48877 Metetra
.664 .741 .908 r
.66096 .48877 .66535 .49391 .67445 .49113 .67008 .48597 Metetra
.664 .741 .908 r
.67008 .48597 .67445 .49113 .68358 .48834 .67923 .48316 Metetra
.664 .741 .908 r
.67923 .48316 .68358 .48834 .69274 .48554 .68841 .48035 Metetra
.664 .741 .908 r
.68841 .48035 .69274 .48554 .70193 .48273 .69762 .47752 Metetra
.664 .741 .908 r
.69762 .47752 .70193 .48273 .71115 .47991 .70686 .47469 Metetra
.664 .741 .908 r
.70686 .47469 .71115 .47991 .7204 .47709 .71613 .47184 Metetra
.664 .741 .908 r
.71613 .47184 .7204 .47709 .72968 .47425 .72543 .46899 Metetra
.664 .741 .908 r
.72543 .46899 .72968 .47425 .73899 .47141 .73476 .46613 Metetra
.664 .741 .908 r
.73476 .46613 .73899 .47141 .74833 .46855 .74412 .46326 Metetra
.664 .741 .908 r
.74412 .46326 .74833 .46855 .7577 .46569 .75351 .46038 Metetra
.664 .741 .908 r
.75351 .46038 .7577 .46569 .7671 .46281 .76293 .45749 Metetra
.664 .741 .908 r
.76293 .45749 .7671 .46281 .77653 .45993 .77239 .45458 Metetra
.664 .741 .908 r
.77239 .45458 .77653 .45993 .786 .45704 .78187 .45168 Metetra
.659 .74 .909 r
.78187 .45168 .786 .45704 .79549 .45419 .7914 .44887 Metetra
.646 .737 .915 r
.7914 .44887 .79549 .45419 .80504 .45149 .80098 .44636 Metetra
.649 .747 .921 r
.80098 .44636 .80504 .45149 .81461 .44873 .8106 .44376 Metetra
.663 .76 .922 r
.8106 .44376 .81461 .44873 .8242 .4458 .82021 .44081 Metetra
.659 .758 .923 r
.82021 .44081 .8242 .4458 .83383 .4429 .82986 .43793 Metetra
.644 .754 .929 r
.82986 .43793 .83383 .4429 .8435 .44015 .83958 .4354 Metetra
.645 .765 .936 r
.83958 .4354 .8435 .44015 .85321 .43745 .84933 .43279 Metetra
.659 .775 .935 r
.84933 .43279 .85321 .43745 .86298 .43496 .85908 .42984 Metetra
.664 .758 .92 r
.85908 .42984 .86298 .43496 .87278 .43235 .86886 .42682 Metetra
.681 .748 .902 r
.86886 .42682 .87278 .43235 .88252 .42891 .87862 .42337 Metetra
.679 .748 .903 r
.87862 .42337 .88252 .42891 .89229 .42553 .88842 .41994 Metetra
.663 .74 .908 r
.88842 .41994 .89229 .42553 .90217 .42276 .8983 .41694 Metetra
.663 .732 .901 r
.8983 .41694 .90217 .42276 .91208 .41996 .90821 .41392 Metetra
.664 .725 .894 r
.90821 .41392 .91208 .41996 .92197 .41668 .91815 .41085 Metetra
.665 .734 .901 r
.91815 .41085 .92197 .41668 .93189 .41339 .92812 .40775 Metetra
.681 .748 .902 r
.92812 .40775 .93189 .41339 .94182 .40989 .93807 .40423 Metetra
.681 .748 .902 r
.93807 .40423 .94182 .40989 .95177 .40637 .94805 .4007 Metetra
.652 .739 .913 r
.37066 .57163 .37567 .57629 .38387 .5742 .37889 .56933 Metetra
.653 .731 .906 r
.37889 .56933 .38387 .5742 .3921 .5721 .38714 .56703 Metetra
.647 .721 .903 r
.38714 .56703 .3921 .5721 .40037 .5696 .39541 .56486 Metetra
.646 .735 .914 r
.39541 .56486 .40037 .5696 .40867 .56708 .40371 .56269 Metetra
.662 .755 .919 r
.40371 .56269 .40867 .56708 .41699 .56451 .41205 .56015 Metetra
.663 .757 .92 r
.41205 .56015 .41699 .56451 .42535 .56193 .42042 .55757 Metetra
.643 .753 .929 r
.42042 .55757 .42535 .56193 .43371 .55975 .4288 .55538 Metetra
.641 .752 .93 r
.4288 .55538 .43371 .55975 .4421 .55761 .43721 .55323 Metetra
.668 .759 .919 r
.43721 .55323 .4421 .55761 .45053 .55505 .44566 .55052 Metetra
.672 .755 .913 r
.44566 .55052 .45053 .55505 .45899 .55241 .45414 .54772 Metetra
.666 .747 .91 r
.45414 .54772 .45899 .55241 .46748 .54946 .46264 .54503 Metetra
.665 .759 .92 r
.46264 .54503 .46748 .54946 .47599 .54643 .47117 .54236 Metetra
.669 .776 .93 r
.47117 .54236 .47599 .54643 .48453 .54374 .47972 .53956 Metetra
.671 .773 .926 r
.47972 .53956 .48453 .54374 .49309 .54111 .4883 .53673 Metetra
.68 .766 .916 r
.4883 .53673 .49309 .54111 .50168 .53816 .49691 .5337 Metetra
.682 .764 .913 r
.49691 .5337 .50168 .53816 .51029 .5351 .50555 .5306 Metetra
.674 .761 .916 r
.50555 .5306 .51029 .5351 .51893 .53234 .51421 .52768 Metetra
.672 .754 .912 r
.51421 .52768 .51893 .53234 .5276 .52968 .52289 .52481 Metetra
.666 .744 .909 r
.52289 .52481 .5276 .52968 .53629 .52701 .5316 .52207 Metetra
.664 .741 .908 r
.5316 .52207 .53629 .52701 .54501 .52434 .54034 .51938 Metetra
.664 .741 .908 r
.54034 .51938 .54501 .52434 .55376 .52165 .54911 .51668 Metetra
.664 .741 .908 r
.54911 .51668 .55376 .52165 .56254 .51896 .55791 .51397 Metetra
.664 .741 .908 r
.55791 .51397 .56254 .51896 .57134 .51626 .56673 .51125 Metetra
.664 .741 .908 r
.56673 .51125 .57134 .51626 .58018 .51355 .57558 .50853 Metetra
.664 .741 .908 r
.57558 .50853 .58018 .51355 .58904 .51083 .58446 .50579 Metetra
.664 .741 .908 r
.58446 .50579 .58904 .51083 .59793 .50811 .59337 .50305 Metetra
.664 .741 .908 r
.59337 .50305 .59793 .50811 .60684 .50537 .60231 .5003 Metetra
.664 .741 .908 r
.60231 .5003 .60684 .50537 .61579 .50263 .61127 .49754 Metetra
.664 .741 .908 r
.61127 .49754 .61579 .50263 .62477 .49987 .62027 .49477 Metetra
.664 .741 .908 r
.62027 .49477 .62477 .49987 .63377 .49711 .62929 .49199 Metetra
.664 .741 .908 r
.62929 .49199 .63377 .49711 .6428 .49434 .63834 .4892 Metetra
.664 .741 .908 r
.63834 .4892 .6428 .49434 .65186 .49156 .64742 .4864 Metetra
.664 .741 .908 r
.64742 .4864 .65186 .49156 .66096 .48877 .65654 .4836 Metetra
.664 .741 .908 r
.65654 .4836 .66096 .48877 .67008 .48597 .66568 .48078 Metetra
.664 .741 .908 r
.66568 .48078 .67008 .48597 .67923 .48316 .67485 .47796 Metetra
.664 .741 .908 r
.67485 .47796 .67923 .48316 .68841 .48035 .68405 .47513 Metetra
.664 .741 .908 r
.68405 .47513 .68841 .48035 .69762 .47752 .69328 .47228 Metetra
.664 .741 .908 r
.69328 .47228 .69762 .47752 .70686 .47469 .70254 .46943 Metetra
.664 .741 .908 r
.70254 .46943 .70686 .47469 .71613 .47184 .71183 .46657 Metetra
.664 .741 .908 r
.71183 .46657 .71613 .47184 .72543 .46899 .72115 .4637 Metetra
.664 .741 .908 r
.72115 .4637 .72543 .46899 .73476 .46613 .7305 .46082 Metetra
.664 .741 .908 r
.7305 .46082 .73476 .46613 .74412 .46326 .73989 .45793 Metetra
.664 .741 .908 r
.73989 .45793 .74412 .46326 .75351 .46038 .7493 .45503 Metetra
.664 .741 .908 r
.7493 .45503 .75351 .46038 .76293 .45749 .75874 .45212 Metetra
.661 .74 .909 r
.75874 .45212 .76293 .45749 .77239 .45458 .76823 .44926 Metetra
.655 .741 .912 r
.76823 .44926 .77239 .45458 .78187 .45168 .77775 .44654 Metetra
.652 .748 .92 r
.77775 .44654 .78187 .45168 .7914 .44887 .78731 .44386 Metetra
.643 .751 .927 r
.78731 .44386 .7914 .44887 .80098 .44636 .79692 .44137 Metetra
.645 .753 .927 r
.79692 .44137 .80098 .44636 .8106 .44376 .80656 .4388 Metetra
.654 .758 .927 r
.80656 .4388 .8106 .44376 .82021 .44081 .81621 .43604 Metetra
.654 .767 .933 r
.81621 .43604 .82021 .44081 .82986 .43793 .8259 .43323 Metetra
.659 .773 .934 r
.8259 .43323 .82986 .43793 .83958 .4354 .83561 .4303 Metetra
.66 .757 .922 r
.83561 .4303 .83958 .4354 .84933 .43279 .84536 .42738 Metetra
.655 .743 .914 r
.84536 .42738 .84933 .43279 .85908 .42984 .85515 .42457 Metetra
.658 .75 .918 r
.85515 .42457 .85908 .42984 .86886 .42682 .86496 .42167 Metetra
.681 .765 .915 r
.86496 .42167 .86886 .42682 .87862 .42337 .87475 .4182 Metetra
.679 .764 .915 r
.87475 .4182 .87862 .42337 .88842 .41994 .88457 .41475 Metetra
.663 .758 .921 r
.88457 .41475 .88842 .41994 .8983 .41694 .89447 .4117 Metetra
.664 .757 .92 r
.89447 .4117 .8983 .41694 .90821 .41392 .9044 .40862 Metetra
.679 .762 .914 r
.9044 .40862 .90821 .41392 .91815 .41085 .91432 .40515 Metetra
.678 .746 .902 r
.91432 .40515 .91815 .41085 .92812 .40775 .92427 .40167 Metetra
.673 .73 .893 r
.92427 .40167 .92812 .40775 .93807 .40423 .93428 .39833 Metetra
.673 .737 .899 r
.93428 .39833 .93807 .40423 .94805 .4007 .94431 .39498 Metetra
.662 .741 .908 r
.36563 .56694 .37066 .57163 .37889 .56933 .37388 .56442 Metetra
.662 .732 .902 r
.37388 .56442 .37889 .56933 .38714 .56703 .38215 .56189 Metetra
.628 .714 .908 r
.38215 .56189 .38714 .56703 .39541 .56486 .39042 .56011 Metetra
.624 .73 .923 r
.39042 .56011 .39541 .56486 .40371 .56269 .39873 .55835 Metetra
.66 .758 .922 r
.39873 .55835 .40371 .56269 .41205 .56015 .40708 .55582 Metetra
.663 .76 .922 r
.40708 .55582 .41205 .56015 .42042 .55757 .41547 .55323 Metetra
.643 .755 .93 r
.41547 .55323 .42042 .55757 .4288 .55538 .42386 .55103 Metetra
.641 .754 .931 r
.42386 .55103 .4288 .55538 .43721 .55323 .43229 .54886 Metetra
.676 .763 .916 r
.43229 .54886 .43721 .55323 .44566 .55052 .44076 .54595 Metetra
.681 .756 .908 r
.44076 .54595 .44566 .55052 .45414 .54772 .44926 .54292 Metetra
.652 .74 .914 r
.44926 .54292 .45414 .54772 .46264 .54503 .45778 .54054 Metetra
.644 .752 .927 r
.45778 .54054 .46264 .54503 .47117 .54236 .46631 .53829 Metetra
.673 .778 .929 r
.46631 .53829 .47117 .54236 .47972 .53956 .47489 .53538 Metetra
.681 .776 .923 r
.47489 .53538 .47972 .53956 .4883 .53673 .48349 .53232 Metetra
.682 .767 .916 r
.48349 .53232 .4883 .53673 .49691 .5337 .49212 .52922 Metetra
.682 .765 .914 r
.49212 .52922 .49691 .5337 .50555 .5306 .50078 .52611 Metetra
.681 .764 .914 r
.50078 .52611 .50555 .5306 .51421 .52768 .50946 .52301 Metetra
.681 .758 .909 r
.50946 .52301 .51421 .52768 .52289 .52481 .51816 .51991 Metetra
.669 .745 .908 r
.51816 .51991 .52289 .52481 .5316 .52207 .52689 .51709 Metetra
.664 .741 .908 r
.52689 .51709 .5316 .52207 .54034 .51938 .53565 .51439 Metetra
.664 .741 .908 r
.53565 .51439 .54034 .51938 .54911 .51668 .54443 .51167 Metetra
.664 .741 .908 r
.54443 .51167 .54911 .51668 .55791 .51397 .55325 .50895 Metetra
.664 .741 .908 r
.55325 .50895 .55791 .51397 .56673 .51125 .56209 .50621 Metetra
.664 .741 .908 r
.56209 .50621 .56673 .51125 .57558 .50853 .57096 .50347 Metetra
.664 .741 .908 r
.57096 .50347 .57558 .50853 .58446 .50579 .57986 .50072 Metetra
.664 .741 .908 r
.57986 .50072 .58446 .50579 .59337 .50305 .58878 .49796 Metetra
.664 .741 .908 r
.58878 .49796 .59337 .50305 .60231 .5003 .59774 .49519 Metetra
.664 .741 .908 r
.59774 .49519 .60231 .5003 .61127 .49754 .60673 .49241 Metetra
.664 .741 .908 r
.60673 .49241 .61127 .49754 .62027 .49477 .61574 .48963 Metetra
.664 .741 .908 r
.61574 .48963 .62027 .49477 .62929 .49199 .62478 .48683 Metetra
.664 .741 .908 r
.62478 .48683 .62929 .49199 .63834 .4892 .63386 .48403 Metetra
.664 .741 .908 r
.63386 .48403 .63834 .4892 .64742 .4864 .64296 .48122 Metetra
.664 .741 .908 r
.64296 .48122 .64742 .4864 .65654 .4836 .65209 .47839 Metetra
.664 .741 .908 r
.65209 .47839 .65654 .4836 .66568 .48078 .66125 .47556 Metetra
.664 .741 .908 r
.66125 .47556 .66568 .48078 .67485 .47796 .67044 .47272 Metetra
.664 .741 .908 r
.67044 .47272 .67485 .47796 .68405 .47513 .67966 .46987 Metetra
.664 .741 .908 r
.67966 .46987 .68405 .47513 .69328 .47228 .68891 .46701 Metetra
.664 .741 .908 r
.68891 .46701 .69328 .47228 .70254 .46943 .69819 .46414 Metetra
.664 .741 .908 r
.69819 .46414 .70254 .46943 .71183 .46657 .70751 .46126 Metetra
.664 .741 .908 r
.70751 .46126 .71183 .46657 .72115 .4637 .71685 .45838 Metetra
.664 .741 .908 r
.71685 .45838 .72115 .4637 .7305 .46082 .72622 .45548 Metetra
.664 .741 .908 r
.72622 .45548 .7305 .46082 .73989 .45793 .73563 .45257 Metetra
.664 .741 .908 r
.73563 .45257 .73989 .45793 .7493 .45503 .74506 .44965 Metetra
.664 .741 .908 r
.74506 .44965 .7493 .45503 .75874 .45212 .75453 .44673 Metetra
.659 .739 .91 r
.75453 .44673 .75874 .45212 .76823 .44926 .76404 .44391 Metetra
.646 .737 .916 r
.76404 .44391 .76823 .44926 .77775 .44654 .7736 .44139 Metetra
.645 .746 .923 r
.7736 .44139 .77775 .44654 .78731 .44386 .78319 .43886 Metetra
.643 .752 .928 r
.78319 .43886 .78731 .44386 .79692 .44137 .79283 .43635 Metetra
.643 .752 .928 r
.79283 .43635 .79692 .44137 .80656 .4388 .8025 .43382 Metetra
.644 .755 .93 r
.8025 .43382 .80656 .4388 .81621 .43604 .8122 .43126 Metetra
.649 .767 .935 r
.8122 .43126 .81621 .43604 .8259 .43323 .82192 .42853 Metetra
.678 .782 .928 r
.82192 .42853 .8259 .43323 .83561 .4303 .83161 .42513 Metetra
.673 .761 .916 r
.83161 .42513 .83561 .4303 .84536 .42738 .84135 .42186 Metetra
.646 .736 .915 r
.84135 .42186 .84536 .42738 .85515 .42457 .85118 .41926 Metetra
.65 .747 .92 r
.85118 .41926 .85515 .42457 .86496 .42167 .86104 .41653 Metetra
.681 .767 .916 r
.86104 .41653 .86496 .42167 .87475 .4182 .87086 .41304 Metetra
.679 .766 .917 r
.87086 .41304 .87475 .4182 .88457 .41475 .88071 .40957 Metetra
.663 .76 .922 r
.88071 .40957 .88457 .41475 .89447 .4117 .89063 .40651 Metetra
.665 .761 .922 r
.89063 .40651 .89447 .4117 .9044 .40862 .90059 .40338 Metetra
.696 .771 .91 r
.90059 .40338 .9044 .40862 .91432 .40515 .91048 .39944 Metetra
.694 .753 .897 r
.91048 .39944 .91432 .40515 .92427 .40167 .9204 .39552 Metetra
.665 .725 .894 r
.9204 .39552 .92427 .40167 .93428 .39833 .93045 .39238 Metetra
.665 .733 .901 r
.93045 .39238 .93428 .39833 .94431 .39498 .94054 .38923 Metetra
.664 .741 .908 r
.36056 .56222 .36563 .56694 .37388 .56442 .36883 .55966 Metetra
.664 .74 .907 r
.36883 .55966 .37388 .56442 .38215 .56189 .37712 .55709 Metetra
.641 .733 .915 r
.37712 .55709 .38215 .56189 .39042 .56011 .38542 .55499 Metetra
.642 .721 .905 r
.38542 .55499 .39042 .56011 .39873 .55835 .39375 .5529 Metetra
.647 .71 .893 r
.39375 .5529 .39873 .55835 .40708 .55582 .40211 .55068 Metetra
.647 .723 .904 r
.40211 .55068 .40708 .55582 .41547 .55323 .4105 .54845 Metetra
.652 .739 .914 r
.4105 .54845 .41547 .55323 .42386 .55103 .41891 .5461 Metetra
.652 .734 .909 r
.41891 .5461 .42386 .55103 .43229 .54886 .42736 .54373 Metetra
.678 .733 .892 r
.42736 .54373 .43229 .54886 .44076 .54595 .43585 .54075 Metetra
.681 .732 .889 r
.43585 .54075 .44076 .54595 .44926 .54292 .44437 .53768 Metetra
.651 .723 .901 r
.44437 .53768 .44926 .54292 .45778 .54054 .4529 .53533 Metetra
.645 .723 .905 r
.4529 .53533 .45778 .54054 .46631 .53829 .46145 .53312 Metetra
.668 .732 .897 r
.46145 .53312 .46631 .53829 .47489 .53538 .47004 .53034 Metetra
.674 .739 .899 r
.47004 .53034 .47489 .53538 .48349 .53232 .47866 .52742 Metetra
.662 .742 .909 r
.47866 .52742 .48349 .53232 .49212 .52922 .4873 .52478 Metetra
.656 .761 .926 r
.4873 .52478 .49212 .52922 .50078 .52611 .49597 .52222 Metetra
.674 .791 .937 r
.49597 .52222 .50078 .52611 .50946 .52301 .50467 .51923 Metetra
.68 .798 .938 r
.50467 .51923 .50946 .52301 .51816 .51991 .51339 .51608 Metetra
.678 .796 .938 r
.51339 .51608 .51816 .51991 .52689 .51709 .52215 .51297 Metetra
.679 .784 .929 r
.52215 .51297 .52689 .51709 .53565 .51439 .53092 .50987 Metetra
.674 .765 .92 r
.53092 .50987 .53565 .51439 .54443 .51167 .53973 .50689 Metetra
.671 .754 .913 r
.53973 .50689 .54443 .51167 .55325 .50895 .54856 .50396 Metetra
.666 .745 .909 r
.54856 .50396 .55325 .50895 .56209 .50621 .55742 .50114 Metetra
.664 .741 .908 r
.55742 .50114 .56209 .50621 .57096 .50347 .56631 .49839 Metetra
.664 .741 .908 r
.56631 .49839 .57096 .50347 .57986 .50072 .57523 .49562 Metetra
.664 .741 .908 r
.57523 .49562 .57986 .50072 .58878 .49796 .58417 .49284 Metetra
.664 .741 .908 r
.58417 .49284 .58878 .49796 .59774 .49519 .59315 .49006 Metetra
.664 .741 .908 r
.59315 .49006 .59774 .49519 .60673 .49241 .60215 .48726 Metetra
.664 .741 .908 r
.60215 .48726 .60673 .49241 .61574 .48963 .61119 .48446 Metetra
.664 .741 .908 r
.61119 .48446 .61574 .48963 .62478 .48683 .62025 .48165 Metetra
.664 .741 .908 r
.62025 .48165 .62478 .48683 .63386 .48403 .62934 .47883 Metetra
.664 .741 .908 r
.62934 .47883 .63386 .48403 .64296 .48122 .63846 .476 Metetra
.664 .741 .908 r
.63846 .476 .64296 .48122 .65209 .47839 .64761 .47316 Metetra
.664 .741 .908 r
.64761 .47316 .65209 .47839 .66125 .47556 .6568 .47031 Metetra
.664 .741 .908 r
.6568 .47031 .66125 .47556 .67044 .47272 .66601 .46745 Metetra
.664 .741 .908 r
.66601 .46745 .67044 .47272 .67966 .46987 .67525 .46458 Metetra
.664 .741 .908 r
.67525 .46458 .67966 .46987 .68891 .46701 .68452 .46171 Metetra
.664 .741 .908 r
.68452 .46171 .68891 .46701 .69819 .46414 .69382 .45882 Metetra
.664 .741 .908 r
.69382 .45882 .69819 .46414 .70751 .46126 .70316 .45592 Metetra
.664 .741 .908 r
.70316 .45592 .70751 .46126 .71685 .45838 .71252 .45302 Metetra
.661 .74 .909 r
.71252 .45302 .71685 .45838 .72622 .45548 .72192 .45017 Metetra
.656 .741 .913 r
.72192 .45017 .72622 .45548 .73563 .45257 .73136 .44744 Metetra
.652 .748 .92 r
.73136 .44744 .73563 .45257 .74506 .44965 .74083 .44476 Metetra
.645 .756 .93 r
.74083 .44476 .74506 .44965 .75453 .44673 .75035 .4422 Metetra
.641 .772 .943 r
.75035 .4422 .75453 .44673 .76404 .44391 .7599 .43965 Metetra
.636 .784 .952 r
.7599 .43965 .76404 .44391 .7736 .44139 .76949 .43714 Metetra
.643 .788 .951 r
.76949 .43714 .7736 .44139 .78319 .43886 .7791 .43447 Metetra
.665 .789 .941 r
.7791 .43447 .78319 .43886 .79283 .43635 .78872 .43136 Metetra
.664 .763 .923 r
.78872 .43136 .79283 .43635 .8025 .43382 .79837 .42833 Metetra
.653 .738 .912 r
.79837 .42833 .8025 .43382 .8122 .43126 .80807 .42558 Metetra
.659 .734 .905 r
.80807 .42558 .8122 .43126 .82192 .42853 .8178 .42269 Metetra
.68 .737 .894 r
.8178 .42269 .82192 .42853 .83161 .42513 .82752 .41922 Metetra
.675 .733 .894 r
.82752 .41922 .83161 .42513 .84135 .42186 .83727 .41588 Metetra
.646 .719 .902 r
.83727 .41588 .84135 .42186 .85118 .41926 .84713 .41329 Metetra
.65 .722 .901 r
.84713 .41329 .85118 .41926 .86104 .41653 .85702 .4106 Metetra
.673 .733 .896 r
.85702 .4106 .86104 .41653 .87086 .41304 .86688 .40727 Metetra
.674 .741 .901 r
.86688 .40727 .87086 .41304 .88071 .40957 .87677 .40393 Metetra
.678 .748 .904 r
.87677 .40393 .88071 .40957 .89063 .40651 .88667 .40045 Metetra
.678 .733 .892 r
.88667 .40045 .89063 .40651 .90059 .40338 .89661 .39696 Metetra
.681 .722 .881 r
.89661 .39696 .90059 .40338 .91048 .39944 .90657 .39333 Metetra
.681 .734 .891 r
.90657 .39333 .91048 .39944 .9204 .39552 .91655 .38971 Metetra
.664 .739 .906 r
.91655 .38971 .9204 .39552 .93045 .39238 .92663 .38658 Metetra
.664 .74 .907 r
.92663 .38658 .93045 .39238 .94054 .38923 .93675 .38345 Metetra
.664 .741 .908 r
.35547 .55748 .36056 .56222 .36883 .55966 .36375 .5549 Metetra
.664 .741 .908 r
.36375 .5549 .36883 .55966 .37712 .55709 .37206 .55231 Metetra
.661 .741 .909 r
.37206 .55231 .37712 .55709 .38542 .55499 .38039 .54979 Metetra
.661 .724 .896 r
.38039 .54979 .38542 .55499 .39375 .5529 .38875 .54725 Metetra
.631 .699 .894 r
.38875 .54725 .39375 .5529 .40211 .55068 .39711 .5454 Metetra
.627 .712 .907 r
.39711 .5454 .40211 .55068 .4105 .54845 .4055 .54358 Metetra
.659 .739 .909 r
.4055 .54358 .4105 .54845 .41891 .5461 .41394 .54106 Metetra
.662 .733 .903 r
.41394 .54106 .41891 .5461 .42736 .54373 .42241 .53846 Metetra
.678 .729 .889 r
.42241 .53846 .42736 .54373 .43585 .54075 .43092 .53544 Metetra
.68 .729 .887 r
.43092 .53544 .43585 .54075 .44437 .53768 .43945 .53235 Metetra
.651 .721 .899 r
.43945 .53235 .44437 .53768 .4529 .53533 .44799 .52999 Metetra
.645 .719 .902 r
.44799 .52999 .4529 .53533 .46145 .53312 .45656 .52776 Metetra
.661 .724 .895 r
.45656 .52776 .46145 .53312 .47004 .53034 .46516 .52514 Metetra
.665 .731 .899 r
.46516 .52514 .47004 .53034 .47866 .52742 .4738 .52242 Metetra
.637 .731 .917 r
.4738 .52242 .47866 .52742 .4873 .52478 .48245 .52032 Metetra
.623 .751 .938 r
.48245 .52032 .4873 .52478 .49597 .52222 .49113 .51839 Metetra
.665 .793 .943 r
.49113 .51839 .49597 .52222 .50467 .51923 .49985 .51555 Metetra
.68 .804 .942 r
.49985 .51555 .50467 .51923 .51339 .51608 .5086 .51239 Metetra
.692 .807 .936 r
.5086 .51239 .51339 .51608 .52215 .51297 .51737 .50896 Metetra
.698 .794 .924 r
.51737 .50896 .52215 .51297 .53092 .50987 .52617 .5054 Metetra
.686 .772 .917 r
.52617 .5054 .53092 .50987 .53973 .50689 .535 .50212 Metetra
.68 .758 .91 r
.535 .50212 .53973 .50689 .54856 .50396 .54385 .49896 Metetra
.67 .746 .908 r
.54385 .49896 .54856 .50396 .55742 .50114 .55272 .49604 Metetra
.664 .741 .908 r
.55272 .49604 .55742 .50114 .56631 .49839 .56163 .49327 Metetra
.664 .741 .908 r
.56163 .49327 .56631 .49839 .57523 .49562 .57057 .49049 Metetra
.664 .741 .908 r
.57057 .49049 .57523 .49562 .58417 .49284 .57953 .48769 Metetra
.664 .741 .908 r
.57953 .48769 .58417 .49284 .59315 .49006 .58853 .48489 Metetra
.664 .741 .908 r
.58853 .48489 .59315 .49006 .60215 .48726 .59755 .48208 Metetra
.664 .741 .908 r
.59755 .48208 .60215 .48726 .61119 .48446 .60661 .47926 Metetra
.664 .741 .908 r
.60661 .47926 .61119 .48446 .62025 .48165 .61569 .47643 Metetra
.664 .741 .908 r
.61569 .47643 .62025 .48165 .62934 .47883 .6248 .4736 Metetra
.664 .741 .908 r
.6248 .4736 .62934 .47883 .63846 .476 .63394 .47075 Metetra
.664 .741 .908 r
.63394 .47075 .63846 .476 .64761 .47316 .64311 .46789 Metetra
.664 .741 .908 r
.64311 .46789 .64761 .47316 .6568 .47031 .65232 .46503 Metetra
.664 .741 .908 r
.65232 .46503 .6568 .47031 .66601 .46745 .66155 .46215 Metetra
.664 .741 .908 r
.66155 .46215 .66601 .46745 .67525 .46458 .67081 .45927 Metetra
.664 .741 .908 r
.67081 .45927 .67525 .46458 .68452 .46171 .6801 .45637 Metetra
.664 .741 .908 r
.6801 .45637 .68452 .46171 .69382 .45882 .68943 .45347 Metetra
.664 .741 .908 r
.68943 .45347 .69382 .45882 .70316 .45592 .69878 .45055 Metetra
.664 .741 .908 r
.69878 .45055 .70316 .45592 .71252 .45302 .70817 .44763 Metetra
.658 .739 .91 r
.70817 .44763 .71252 .45302 .72192 .45017 .71759 .44484 Metetra
.646 .738 .916 r
.71759 .44484 .72192 .45017 .73136 .44744 .72706 .44232 Metetra
.639 .745 .925 r
.72706 .44232 .73136 .44744 .74083 .44476 .73658 .43991 Metetra
.623 .751 .938 r
.73658 .43991 .74083 .44476 .75035 .4422 .74615 .43778 Metetra
.624 .772 .951 r
.74615 .43778 .75035 .4422 .7599 .43965 .75575 .43553 Metetra
.634 .791 .958 r
.75575 .43553 .7599 .43965 .76949 .43714 .76537 .433 Metetra
.65 .797 .953 r
.76537 .433 .76949 .43714 .7791 .43447 .77499 .43014 Metetra
.694 .803 .932 r
.77499 .43014 .7791 .43447 .78872 .43136 .78458 .42634 Metetra
.687 .771 .915 r
.78458 .42634 .78872 .43136 .79837 .42833 .7942 .42273 Metetra
.662 .739 .907 r
.7942 .42273 .79837 .42833 .80807 .42558 .80392 .41974 Metetra
.666 .732 .899 r
.80392 .41974 .80807 .42558 .8178 .42269 .81365 .41665 Metetra
.68 .731 .889 r
.81365 .41665 .8178 .42269 .82752 .41922 .82339 .41316 Metetra
.675 .729 .891 r
.82339 .41316 .82752 .41922 .83727 .41588 .83316 .4098 Metetra
.646 .717 .9 r
.83316 .4098 .83727 .41588 .84713 .41329 .84305 .40719 Metetra
.649 .718 .899 r
.84305 .40719 .84713 .41329 .85702 .4106 .85296 .40451 Metetra
.665 .726 .895 r
.85296 .40451 .85702 .4106 .86688 .40727 .86286 .40139 Metetra
.668 .735 .901 r
.86286 .40139 .86688 .40727 .87677 .40393 .87279 .39818 Metetra
.694 .752 .896 r
.87279 .39818 .87677 .40393 .88667 .40045 .88268 .39424 Metetra
.691 .734 .884 r
.88268 .39424 .88667 .40045 .89661 .39696 .89259 .39033 Metetra
.665 .71 .881 r
.89259 .39033 .89661 .39696 .90657 .39333 .90262 .38714 Metetra
.666 .726 .894 r
.90262 .38714 .90657 .39333 .91655 .38971 .91269 .38393 Metetra
.664 .741 .908 r
.91269 .38393 .91655 .38971 .92663 .38658 .92279 .38078 Metetra
.664 .741 .908 r
.92279 .38078 .92663 .38658 .93675 .38345 .93294 .37762 Metetra
.664 .741 .908 r
.35035 .55271 .35547 .55748 .36375 .5549 .35865 .55012 Metetra
.664 .741 .908 r
.35865 .55012 .36375 .5549 .37206 .55231 .36697 .54752 Metetra
.664 .741 .908 r
.36697 .54752 .37206 .55231 .38039 .54979 .37532 .5449 Metetra
.664 .739 .906 r
.37532 .5449 .38039 .54979 .38875 .54725 .3837 .54229 Metetra
.634 .727 .916 r
.3837 .54229 .38875 .54725 .39711 .5454 .39208 .54031 Metetra
.632 .723 .913 r
.39208 .54031 .39711 .5454 .4055 .54358 .40048 .53837 Metetra
.646 .723 .904 r
.40048 .53837 .4055 .54358 .41394 .54106 .40893 .53612 Metetra
.647 .734 .912 r
.40893 .53612 .41394 .54106 .42241 .53846 .4174 .53383 Metetra
.678 .756 .91 r
.4174 .53383 .42241 .53846 .43092 .53544 .42593 .53084 Metetra
.682 .758 .909 r
.42593 .53084 .43092 .53544 .43945 .53235 .43448 .52773 Metetra
.649 .75 .923 r
.43448 .52773 .43945 .53235 .44799 .52999 .44304 .52535 Metetra
.642 .748 .926 r
.44304 .52535 .44799 .52999 .45656 .52776 .45163 .52311 Metetra
.659 .753 .919 r
.45163 .52311 .45656 .52776 .46516 .52514 .46025 .5205 Metetra
.663 .755 .919 r
.46025 .5205 .46516 .52514 .4738 .52242 .4689 .5178 Metetra
.644 .751 .927 r
.4689 .5178 .4738 .52242 .48245 .52032 .47757 .51549 Metetra
.639 .741 .923 r
.47757 .51549 .48245 .52032 .49113 .51839 .48627 .51329 Metetra
.666 .739 .904 r
.48627 .51329 .49113 .51839 .49985 .51555 .49501 .5105 Metetra
.674 .744 .903 r
.49501 .5105 .49985 .51555 .5086 .51239 .50378 .50751 Metetra
.682 .753 .905 r
.50378 .50751 .5086 .51239 .51737 .50896 .51257 .50432 Metetra
.685 .765 .912 r
.51257 .50432 .51737 .50896 .52617 .5054 .52139 .50105 Metetra
.677 .776 .925 r
.52139 .50105 .52617 .5054 .535 .50212 .53023 .49794 Metetra
.673 .783 .932 r
.53023 .49794 .535 .50212 .54385 .49896 .53911 .49491 Metetra
.676 .791 .936 r
.53911 .49491 .54385 .49896 .55272 .49604 .54801 .4918 Metetra
.678 .783 .929 r
.54801 .4918 .55272 .49604 .56163 .49327 .55693 .48864 Metetra
.674 .766 .92 r
.55693 .48864 .56163 .49327 .57057 .49049 .56589 .48558 Metetra
.671 .754 .913 r
.56589 .48558 .57057 .49049 .57953 .48769 .57487 .48259 Metetra
.667 .745 .909 r
.57487 .48259 .57953 .48769 .58853 .48489 .58388 .4797 Metetra
.664 .741 .908 r
.58388 .4797 .58853 .48489 .59755 .48208 .59292 .47687 Metetra
.664 .741 .908 r
.59292 .47687 .59755 .48208 .60661 .47926 .602 .47403 Metetra
.664 .741 .908 r
.602 .47403 .60661 .47926 .61569 .47643 .6111 .47119 Metetra
.664 .741 .908 r
.6111 .47119 .61569 .47643 .6248 .4736 .62023 .46833 Metetra
.664 .741 .908 r
.62023 .46833 .6248 .4736 .63394 .47075 .62939 .46547 Metetra
.664 .741 .908 r
.62939 .46547 .63394 .47075 .64311 .46789 .63859 .46259 Metetra
.664 .741 .908 r
.63859 .46259 .64311 .46789 .65232 .46503 .64781 .45971 Metetra
.664 .741 .908 r
.64781 .45971 .65232 .46503 .66155 .46215 .65706 .45682 Metetra
.664 .741 .908 r
.65706 .45682 .66155 .46215 .67081 .45927 .66634 .45391 Metetra
.66 .74 .909 r
.66634 .45391 .67081 .45927 .6801 .45637 .67566 .45108 Metetra
.656 .742 .913 r
.67566 .45108 .6801 .45637 .68943 .45347 .68501 .44834 Metetra
.652 .748 .92 r
.68501 .44834 .68943 .45347 .69878 .45055 .6944 .44567 Metetra
.646 .757 .93 r
.6944 .44567 .69878 .45055 .70817 .44763 .70383 .4431 Metetra
.645 .773 .941 r
.70383 .4431 .70817 .44763 .71759 .44484 .71329 .44048 Metetra
.647 .782 .946 r
.71329 .44048 .71759 .44484 .72706 .44232 .72278 .43779 Metetra
.644 .774 .943 r
.72278 .43779 .72706 .44232 .73658 .43991 .73231 .43517 Metetra
.637 .763 .939 r
.73231 .43517 .73658 .43991 .74615 .43778 .74188 .43272 Metetra
.643 .752 .928 r
.74188 .43272 .74615 .43778 .75575 .43553 .75149 .43018 Metetra
.652 .744 .917 r
.75149 .43018 .75575 .43553 .76537 .433 .76111 .42745 Metetra
.661 .74 .908 r
.76111 .42745 .76537 .433 .77499 .43014 .77075 .4245 Metetra
.683 .745 .898 r
.77075 .4245 .77499 .43014 .78458 .42634 .78038 .42095 Metetra
.679 .754 .908 r
.78038 .42095 .78458 .42634 .7942 .42273 .79005 .41751 Metetra
.663 .756 .92 r
.79005 .41751 .7942 .42273 .80392 .41974 .79979 .41447 Metetra
.667 .756 .917 r
.79979 .41447 .80392 .41974 .81365 .41665 .80954 .41134 Metetra
.681 .76 .911 r
.80954 .41134 .81365 .41665 .82339 .41316 .8193 .40782 Metetra
.675 .758 .913 r
.8193 .40782 .82339 .41316 .83316 .4098 .8291 .40444 Metetra
.644 .746 .923 r
.8291 .40444 .83316 .4098 .84305 .40719 .83901 .40182 Metetra
.649 .748 .922 r
.83901 .40182 .84305 .40719 .85296 .40451 .84895 .39907 Metetra
.678 .758 .911 r
.84895 .39907 .85296 .40451 .86286 .40139 .85884 .39559 Metetra
.679 .745 .901 r
.85884 .39559 .86286 .40139 .87279 .39818 .86876 .39207 Metetra
.689 .738 .888 r
.86876 .39207 .87279 .39818 .88268 .39424 .87868 .38822 Metetra
.688 .741 .892 r
.87868 .38822 .88268 .39424 .89259 .39033 .88864 .38441 Metetra
.664 .736 .904 r
.88864 .38441 .89259 .39033 .90262 .38714 .8987 .38127 Metetra
.664 .739 .906 r
.8987 .38127 .90262 .38714 .91269 .38393 .9088 .37811 Metetra
.664 .741 .908 r
.9088 .37811 .91269 .38393 .92279 .38078 .91893 .37494 Metetra
.664 .741 .908 r
.91893 .37494 .92279 .38078 .93294 .37762 .9291 .37176 Metetra
.664 .741 .908 r
.3452 .54792 .35035 .55271 .35865 .55012 .35351 .54531 Metetra
.664 .741 .908 r
.35351 .54531 .35865 .55012 .36697 .54752 .36185 .54269 Metetra
.664 .741 .908 r
.36185 .54269 .36697 .54752 .37532 .5449 .37022 .54006 Metetra
.664 .741 .908 r
.37022 .54006 .37532 .5449 .3837 .54229 .37861 .53743 Metetra
.643 .736 .916 r
.37861 .53743 .3837 .54229 .39208 .54031 .38701 .53523 Metetra
.642 .727 .91 r
.38701 .53523 .39208 .54031 .40048 .53837 .39544 .53306 Metetra
.629 .715 .908 r
.39544 .53306 .40048 .53837 .40893 .53612 .40389 .53117 Metetra
.626 .729 .921 r
.40389 .53117 .40893 .53612 .4174 .53383 .41237 .5293 Metetra
.675 .76 .915 r
.41237 .5293 .4174 .53383 .42593 .53084 .42091 .52634 Metetra
.682 .764 .913 r
.42091 .52634 .42593 .53084 .43448 .52773 .42948 .52322 Metetra
.648 .756 .928 r
.42948 .52322 .43448 .52773 .44304 .52535 .43806 .52083 Metetra
.641 .754 .93 r
.43806 .52083 .44304 .52535 .45163 .52311 .44666 .51857 Metetra
.659 .759 .924 r
.44666 .51857 .45163 .52311 .46025 .5205 .4553 .51595 Metetra
.663 .76 .922 r
.4553 .51595 .46025 .5205 .4689 .5178 .46397 .51323 Metetra
.66 .759 .923 r
.46397 .51323 .4689 .5178 .47757 .51549 .47267 .51057 Metetra
.66 .745 .913 r
.47267 .51057 .47757 .51549 .48627 .51329 .48139 .50792 Metetra
.664 .729 .898 r
.48139 .50792 .48627 .51329 .49501 .5105 .49014 .50517 Metetra
.665 .731 .899 r
.49014 .50517 .49501 .5105 .50378 .50751 .49893 .50237 Metetra
.666 .74 .905 r
.49893 .50237 .50378 .50751 .51257 .50432 .50774 .49954 Metetra
.667 .755 .916 r
.50774 .49954 .51257 .50432 .52139 .50105 .51658 .49668 Metetra
.664 .773 .931 r
.51658 .49668 .52139 .50105 .53023 .49794 .52544 .49385 Metetra
.662 .786 .94 r
.52544 .49385 .53023 .49794 .53911 .49491 .53434 .49102 Metetra
.684 .802 .937 r
.53434 .49102 .53911 .49491 .54801 .4918 .54326 .48769 Metetra
.697 .795 .926 r
.54326 .48769 .54801 .4918 .55693 .48864 .5522 .48408 Metetra
.687 .773 .917 r
.5522 .48408 .55693 .48864 .56589 .48558 .56117 .4807 Metetra
.68 .759 .911 r
.56117 .4807 .56589 .48558 .57487 .48259 .57017 .47747 Metetra
.67 .747 .908 r
.57017 .47747 .57487 .48259 .58388 .4797 .5792 .47447 Metetra
.664 .741 .908 r
.5792 .47447 .58388 .4797 .59292 .47687 .58827 .47163 Metetra
.664 .741 .908 r
.58827 .47163 .59292 .47687 .602 .47403 .59736 .46877 Metetra
.664 .741 .908 r
.59736 .46877 .602 .47403 .6111 .47119 .60648 .46591 Metetra
.664 .741 .908 r
.60648 .46591 .6111 .47119 .62023 .46833 .61563 .46304 Metetra
.664 .741 .908 r
.61563 .46304 .62023 .46833 .62939 .46547 .62482 .46015 Metetra
.664 .741 .908 r
.62482 .46015 .62939 .46547 .63859 .46259 .63403 .45726 Metetra
.664 .741 .908 r
.63403 .45726 .63859 .46259 .64781 .45971 .64327 .45436 Metetra
.664 .741 .908 r
.64327 .45436 .64781 .45971 .65706 .45682 .65255 .45145 Metetra
.664 .741 .908 r
.65255 .45145 .65706 .45682 .66634 .45391 .66185 .44853 Metetra
.657 .739 .91 r
.66185 .44853 .66634 .45391 .67566 .45108 .67119 .44577 Metetra
.646 .739 .917 r
.67119 .44577 .67566 .45108 .68501 .44834 .68058 .44324 Metetra
.638 .745 .926 r
.68058 .44324 .68501 .44834 .6944 .44567 .69001 .44085 Metetra
.623 .753 .939 r
.69001 .44085 .6944 .44567 .70383 .4431 .69948 .43871 Metetra
.633 .777 .95 r
.69948 .43871 .70383 .4431 .71329 .44048 .70898 .43628 Metetra
.656 .794 .949 r
.70898 .43628 .71329 .44048 .72278 .43779 .71848 .43335 Metetra
.657 .784 .942 r
.71848 .43335 .72278 .43779 .73231 .43517 .72801 .43042 Metetra
.658 .771 .933 r
.72801 .43042 .73231 .43517 .74188 .43272 .73758 .42751 Metetra
.66 .753 .919 r
.73758 .42751 .74188 .43272 .75149 .43018 .74718 .42458 Metetra
.662 .738 .907 r
.74718 .42458 .75149 .43018 .76111 .42745 .75681 .4216 Metetra
.663 .73 .9 r
.75681 .4216 .76111 .42745 .77075 .4245 .76647 .41859 Metetra
.667 .73 .897 r
.76647 .41859 .77075 .4245 .78038 .42095 .77616 .41546 Metetra
.666 .747 .911 r
.77616 .41546 .78038 .42095 .79005 .41751 .78588 .41235 Metetra
.663 .76 .922 r
.78588 .41235 .79005 .41751 .79979 .41447 .79564 .40929 Metetra
.666 .761 .921 r
.79564 .40929 .79979 .41447 .80954 .41134 .80542 .40613 Metetra
.681 .766 .916 r
.80542 .40613 .80954 .41134 .8193 .40782 .8152 .4026 Metetra
.675 .764 .918 r
.8152 .4026 .8193 .40782 .8291 .40444 .82503 .3992 Metetra
.643 .752 .928 r
.82503 .3992 .8291 .40444 .83901 .40182 .83497 .39655 Metetra
.65 .755 .926 r
.83497 .39655 .83901 .40182 .84895 .39907 .84492 .39373 Metetra
.695 .769 .909 r
.84492 .39373 .84895 .39907 .85884 .39559 .85479 .38979 Metetra
.692 .751 .896 r
.85479 .38979 .85884 .39559 .86876 .39207 .8647 .38586 Metetra
.681 .732 .889 r
.8647 .38586 .86876 .39207 .87868 .38822 .87467 .38222 Metetra
.681 .74 .896 r
.87467 .38222 .87868 .38822 .88864 .38441 .88467 .3786 Metetra
.664 .741 .908 r
.88467 .3786 .88864 .38441 .8987 .38127 .89476 .37543 Metetra
.664 .741 .908 r
.89476 .37543 .8987 .38127 .9088 .37811 .90488 .37225 Metetra
.664 .741 .908 r
.90488 .37225 .9088 .37811 .91893 .37494 .91504 .36906 Metetra
.664 .741 .908 r
.91504 .36906 .91893 .37494 .9291 .37176 .92523 .36586 Metetra
.664 .741 .908 r
.34002 .54309 .3452 .54792 .35351 .54531 .34835 .54047 Metetra
.664 .741 .908 r
.34835 .54047 .35351 .54531 .36185 .54269 .3567 .53783 Metetra
.664 .741 .908 r
.3567 .53783 .36185 .54269 .37022 .54006 .36509 .53519 Metetra
.664 .741 .908 r
.36509 .53519 .37022 .54006 .37861 .53743 .3735 .53254 Metetra
.645 .736 .916 r
.3735 .53254 .37861 .53743 .38701 .53523 .38192 .5303 Metetra
.643 .734 .915 r
.38192 .5303 .38701 .53523 .39544 .53306 .39036 .52807 Metetra
.632 .729 .918 r
.39036 .52807 .39544 .53306 .40389 .53117 .39883 .52607 Metetra
.631 .726 .915 r
.39883 .52607 .40389 .53117 .41237 .5293 .40732 .5241 Metetra
.669 .733 .898 r
.40732 .5241 .41237 .5293 .42091 .52634 .41588 .52127 Metetra
.674 .74 .9 r
.41588 .52127 .42091 .52634 .42948 .52322 .42446 .5183 Metetra
.649 .74 .916 r
.42446 .5183 .42948 .52322 .43806 .52083 .43305 .51592 Metetra
.643 .739 .919 r
.43305 .51592 .43806 .52083 .44666 .51857 .44167 .51365 Metetra
.66 .744 .912 r
.44167 .51365 .44666 .51857 .4553 .51595 .45033 .51101 Metetra
.663 .745 .911 r
.45033 .51101 .4553 .51595 .46397 .51323 .45902 .50828 Metetra
.663 .745 .911 r
.45902 .50828 .46397 .51323 .47267 .51057 .46773 .50553 Metetra
.663 .742 .909 r
.46773 .50553 .47267 .51057 .48139 .50792 .47648 .50278 Metetra
.658 .737 .908 r
.47648 .50278 .48139 .50792 .49014 .50517 .48525 .50015 Metetra
.656 .742 .914 r
.48525 .50015 .49014 .50517 .49893 .50237 .49405 .49756 Metetra
.661 .753 .918 r
.49405 .49756 .49893 .50237 .50774 .49954 .50287 .49484 Metetra
.663 .759 .921 r
.50287 .49484 .50774 .49954 .51658 .49668 .51173 .49205 Metetra
.662 .762 .924 r
.51173 .49205 .51658 .49668 .52544 .49385 .52062 .48926 Metetra
.662 .765 .926 r
.52062 .48926 .52544 .49385 .53434 .49102 .52953 .48645 Metetra
.678 .771 .921 r
.52953 .48645 .53434 .49102 .54326 .48769 .53848 .48329 Metetra
.686 .781 .923 r
.53848 .48329 .54326 .48769 .5522 .48408 .54745 .47993 Metetra
.683 .792 .932 r
.54745 .47993 .5522 .48408 .56117 .4807 .55644 .47662 Metetra
.681 .795 .935 r
.55644 .47662 .56117 .4807 .57017 .47747 .56546 .47333 Metetra
.674 .791 .937 r
.56546 .47333 .57017 .47747 .5792 .47447 .57452 .47019 Metetra
.669 .785 .935 r
.57452 .47019 .5792 .47447 .58827 .47163 .5836 .46715 Metetra
.674 .778 .928 r
.5836 .46715 .58827 .47163 .59736 .46877 .59271 .464 Metetra
.678 .767 .918 r
.59271 .464 .59736 .46877 .60648 .46591 .60184 .46077 Metetra
.671 .75 .91 r
.60184 .46077 .60648 .46591 .61563 .46304 .61101 .45771 Metetra
.664 .741 .908 r
.61101 .45771 .61563 .46304 .62482 .46015 .62021 .45481 Metetra
.656 .739 .911 r
.62021 .45481 .62482 .46015 .63403 .45726 .62945 .45207 Metetra
.648 .743 .919 r
.62945 .45207 .63403 .45726 .64327 .45436 .63873 .44951 Metetra
.65 .759 .929 r
.63873 .44951 .64327 .45436 .65255 .45145 .64803 .44686 Metetra
.653 .772 .936 r
.64803 .44686 .65255 .45145 .66185 .44853 .65737 .4441 Metetra
.646 .778 .943 r
.65737 .4441 .66185 .44853 .67119 .44577 .66674 .44144 Metetra
.637 .78 .95 r
.66674 .44144 .67119 .44577 .68058 .44324 .67615 .43894 Metetra
.635 .781 .952 r
.67615 .43894 .68058 .44324 .69001 .44085 .6856 .43646 Metetra
.632 .777 .95 r
.6856 .43646 .69001 .44085 .69948 .43871 .69508 .43403 Metetra
.645 .769 .939 r
.69508 .43403 .69948 .43871 .70898 .43628 .70459 .43139 Metetra
.662 .766 .927 r
.70459 .43139 .70898 .43628 .71848 .43335 .71412 .4284 Metetra
.662 .765 .926 r
.71412 .4284 .71848 .43335 .72801 .43042 .72367 .42539 Metetra
.662 .762 .924 r
.72367 .42539 .72801 .43042 .73758 .42751 .73326 .42238 Metetra
.665 .759 .921 r
.73326 .42238 .73758 .42751 .74718 .42458 .74287 .4193 Metetra
.67 .756 .915 r
.74287 .4193 .74718 .42458 .75681 .4216 .75251 .41608 Metetra
.669 .747 .909 r
.75251 .41608 .75681 .4216 .76647 .41859 .76219 .4129 Metetra
.663 .739 .906 r
.76219 .4129 .76647 .41859 .77616 .41546 .7719 .40985 Metetra
.663 .742 .909 r
.7719 .40985 .77616 .41546 .78588 .41235 .78165 .40678 Metetra
.663 .745 .911 r
.78165 .40678 .78588 .41235 .79564 .40929 .79143 .4037 Metetra
.667 .746 .91 r
.79143 .4037 .79564 .40929 .80542 .40613 .80124 .40053 Metetra
.681 .752 .905 r
.80124 .40053 .80542 .40613 .8152 .4026 .81105 .39697 Metetra
.676 .75 .906 r
.81105 .39697 .8152 .4026 .82503 .3992 .8209 .39353 Metetra
.652 .739 .913 r
.8209 .39353 .82503 .3992 .83497 .39655 .83084 .39068 Metetra
.658 .735 .906 r
.83084 .39068 .83497 .39655 .84492 .39373 .8408 .3877 Metetra
.69 .742 .891 r
.8408 .3877 .84492 .39373 .85479 .38979 .85071 .38382 Metetra
.689 .745 .894 r
.85071 .38382 .85479 .38979 .8647 .38586 .86065 .37996 Metetra
.68 .745 .9 r
.86065 .37996 .8647 .38586 .87467 .38222 .87065 .37634 Metetra
.679 .746 .901 r
.87065 .37634 .87467 .38222 .88467 .3786 .88068 .37274 Metetra
.664 .741 .908 r
.88068 .37274 .88467 .3786 .89476 .37543 .89079 .36955 Metetra
.664 .741 .908 r
.89079 .36955 .89476 .37543 .90488 .37225 .90094 .36636 Metetra
.664 .741 .908 r
.90094 .36636 .90488 .37225 .91504 .36906 .91112 .36315 Metetra
.664 .741 .908 r
.91112 .36315 .91504 .36906 .92523 .36586 .92134 .35993 Metetra
.664 .741 .908 r
.33481 .53824 .34002 .54309 .34835 .54047 .34315 .5356 Metetra
.664 .741 .908 r
.34315 .5356 .34835 .54047 .3567 .53783 .35152 .53295 Metetra
.664 .741 .908 r
.35152 .53295 .3567 .53783 .36509 .53519 .35992 .53029 Metetra
.664 .741 .908 r
.35992 .53029 .36509 .53519 .3735 .53254 .36835 .52763 Metetra
.645 .736 .916 r
.36835 .52763 .3735 .53254 .38192 .5303 .37678 .52537 Metetra
.643 .736 .916 r
.37678 .52537 .38192 .5303 .39036 .52807 .38525 .52313 Metetra
.641 .735 .917 r
.38525 .52313 .39036 .52807 .39883 .52607 .39374 .52092 Metetra
.642 .728 .911 r
.39374 .52092 .39883 .52607 .40732 .5241 .40225 .51871 Metetra
.662 .725 .896 r
.40225 .51871 .40732 .5241 .41588 .52127 .41082 .51603 Metetra
.665 .732 .899 r
.41082 .51603 .41588 .52127 .42446 .5183 .41941 .51326 Metetra
.647 .736 .914 r
.41941 .51326 .42446 .5183 .43305 .51592 .42802 .5109 Metetra
.643 .736 .916 r
.42802 .5109 .43305 .51592 .44167 .51365 .43666 .50861 Metetra
.66 .741 .91 r
.43666 .50861 .44167 .51365 .45033 .51101 .44533 .50596 Metetra
.663 .742 .908 r
.44533 .50596 .45033 .51101 .45902 .50828 .45404 .50321 Metetra
.663 .742 .908 r
.45404 .50321 .45902 .50828 .46773 .50553 .46277 .50045 Metetra
.663 .742 .908 r
.46277 .50045 .46773 .50553 .47648 .50278 .47153 .49768 Metetra
.651 .738 .913 r
.47153 .49768 .47648 .50278 .48525 .50015 .48032 .4952 Metetra
.645 .743 .92 r
.48032 .4952 .48525 .50015 .49405 .49756 .48913 .49281 Metetra
.658 .756 .922 r
.48913 .49281 .49405 .49756 .50287 .49484 .49798 .49013 Metetra
.663 .76 .922 r
.49798 .49013 .50287 .49484 .51173 .49205 .50686 .48733 Metetra
.663 .76 .922 r
.50686 .48733 .51173 .49205 .52062 .48926 .51577 .48452 Metetra
.663 .76 .922 r
.51577 .48452 .52062 .48926 .52953 .48645 .5247 .4817 Metetra
.665 .761 .921 r
.5247 .4817 .52953 .48645 .53848 .48329 .53366 .4788 Metetra
.666 .773 .929 r
.53366 .4788 .53848 .48329 .54745 .47993 .54266 .47587 Metetra
.674 .795 .939 r
.54266 .47587 .54745 .47993 .55644 .47662 .55168 .4727 Metetra
.68 .804 .941 r
.55168 .4727 .55644 .47662 .56546 .47333 .56072 .4694 Metetra
.678 .804 .942 r
.56072 .4694 .56546 .47333 .57452 .47019 .5698 .46611 Metetra
.678 .798 .939 r
.5698 .46611 .57452 .47019 .5836 .46715 .5789 .46284 Metetra
.689 .79 .928 r
.5789 .46284 .5836 .46715 .59271 .464 .58803 .45933 Metetra
.696 .778 .914 r
.58803 .45933 .59271 .464 .60184 .46077 .59717 .45564 Metetra
.679 .755 .908 r
.59717 .45564 .60184 .46077 .61101 .45771 .60636 .45235 Metetra
.664 .741 .908 r
.60636 .45235 .61101 .45771 .62021 .45481 .61558 .44943 Metetra
.647 .736 .914 r
.61558 .44943 .62021 .45481 .62945 .45207 .62485 .44689 Metetra
.627 .737 .926 r
.62485 .44689 .62945 .45207 .63873 .44951 .63416 .44475 Metetra
.633 .758 .938 r
.63416 .44475 .63873 .44951 .64803 .44686 .6435 .44243 Metetra
.641 .776 .946 r
.6435 .44243 .64803 .44686 .65737 .4441 .65287 .43987 Metetra
.637 .786 .953 r
.65287 .43987 .65737 .4441 .66674 .44144 .66227 .43733 Metetra
.634 .791 .957 r
.66227 .43733 .66674 .44144 .67615 .43894 .6717 .43481 Metetra
.641 .793 .955 r
.6717 .43481 .67615 .43894 .6856 .43646 .68117 .43214 Metetra
.654 .789 .947 r
.68117 .43214 .6856 .43646 .69508 .43403 .69066 .42925 Metetra
.659 .771 .932 r
.69066 .42925 .69508 .43403 .70459 .43139 .70017 .42631 Metetra
.663 .76 .922 r
.70017 .42631 .70459 .43139 .71412 .4284 .70972 .42329 Metetra
.663 .76 .922 r
.70972 .42329 .71412 .4284 .72367 .42539 .7193 .42027 Metetra
.663 .76 .922 r
.7193 .42027 .72367 .42539 .73326 .42238 .72891 .41724 Metetra
.668 .761 .92 r
.72891 .41724 .73326 .42238 .74287 .4193 .73854 .41408 Metetra
.679 .763 .914 r
.73854 .41408 .74287 .4193 .75251 .41608 .74819 .41062 Metetra
.675 .752 .909 r
.74819 .41062 .75251 .41608 .76219 .4129 .75788 .40725 Metetra
.663 .742 .908 r
.75788 .40725 .76219 .4129 .7719 .40985 .76762 .40418 Metetra
.663 .742 .908 r
.76762 .40418 .7719 .40985 .78165 .40678 .77739 .40109 Metetra
.663 .742 .908 r
.77739 .40109 .78165 .40678 .79143 .4037 .78719 .39799 Metetra
.667 .743 .907 r
.78719 .39799 .79143 .4037 .80124 .40053 .79702 .3948 Metetra
.681 .748 .902 r
.79702 .3948 .80124 .40053 .81105 .39697 .80686 .39123 Metetra
.678 .747 .903 r
.80686 .39123 .81105 .39697 .8209 .39353 .81673 .38772 Metetra
.661 .739 .908 r
.81673 .38772 .8209 .39353 .83084 .39068 .82667 .38463 Metetra
.664 .732 .9 r
.82667 .38463 .83084 .39068 .8408 .3877 .83664 .38146 Metetra
.681 .733 .889 r
.83664 .38146 .8408 .3877 .85071 .38382 .84659 .37779 Metetra
.682 .741 .896 r
.84659 .37779 .85071 .38382 .86065 .37996 .85658 .37412 Metetra
.681 .748 .902 r
.85658 .37412 .86065 .37996 .87065 .37634 .8666 .37047 Metetra
.68 .748 .903 r
.8666 .37047 .87065 .37634 .88068 .37274 .87666 .36685 Metetra
.664 .741 .908 r
.87666 .36685 .88068 .37274 .89079 .36955 .8868 .36364 Metetra
.664 .741 .908 r
.8868 .36364 .89079 .36955 .90094 .36636 .89697 .36042 Metetra
.664 .741 .908 r
.89697 .36042 .90094 .36636 .91112 .36315 .90718 .3572 Metetra
.664 .741 .908 r
.90718 .3572 .91112 .36315 .92134 .35993 .91743 .35396 Metetra
.664 .741 .908 r
.32956 .53336 .33481 .53824 .34315 .5356 .33793 .5307 Metetra
.664 .741 .908 r
.33793 .5307 .34315 .5356 .35152 .53295 .34632 .52804 Metetra
.664 .741 .908 r
.34632 .52804 .35152 .53295 .35992 .53029 .35473 .52537 Metetra
.664 .741 .908 r
.35473 .52537 .35992 .53029 .36835 .52763 .36317 .52269 Metetra
.652 .738 .913 r
.36317 .52269 .36835 .52763 .37678 .52537 .37163 .52025 Metetra
.652 .732 .908 r
.37163 .52025 .37678 .52537 .38525 .52313 .38012 .51783 Metetra
.645 .723 .906 r
.38012 .51783 .38525 .52313 .39374 .52092 .38862 .51555 Metetra
.644 .721 .904 r
.38862 .51555 .39374 .52092 .40225 .51871 .39716 .51327 Metetra
.642 .718 .903 r
.39716 .51327 .40225 .51871 .41082 .51603 .40572 .51105 Metetra
.64 .737 .919 r
.40572 .51105 .41082 .51603 .41941 .51326 .41431 .50882 Metetra
.654 .764 .93 r
.41431 .50882 .41941 .51326 .42802 .5109 .42295 .50625 Metetra
.658 .757 .923 r
.42295 .50625 .42802 .5109 .43666 .50861 .43161 .50361 Metetra
.662 .744 .911 r
.43161 .50361 .43666 .50861 .44533 .50596 .44031 .50087 Metetra
.663 .742 .908 r
.44031 .50087 .44533 .50596 .45404 .50321 .44903 .49811 Metetra
.663 .742 .908 r
.44903 .49811 .45404 .50321 .46277 .50045 .45778 .49533 Metetra
.663 .742 .908 r
.45778 .49533 .46277 .50045 .47153 .49768 .46656 .49255 Metetra
.649 .737 .914 r
.46656 .49255 .47153 .49768 .48032 .4952 .47536 .49009 Metetra
.643 .737 .917 r
.47536 .49009 .48032 .4952 .48913 .49281 .48419 .48773 Metetra
.658 .743 .913 r
.48419 .48773 .48913 .49281 .49798 .49013 .49306 .48505 Metetra
.663 .746 .911 r
.49306 .48505 .49798 .49013 .50686 .48733 .50196 .48223 Metetra
.658 .744 .913 r
.50196 .48223 .50686 .48733 .51577 .48452 .51088 .47952 Metetra
.656 .748 .918 r
.51088 .47952 .51577 .48452 .5247 .4817 .51984 .47685 Metetra
.66 .756 .921 r
.51984 .47685 .5247 .4817 .53366 .4788 .52882 .47407 Metetra
.662 .762 .924 r
.52882 .47407 .53366 .4788 .54266 .47587 .53784 .47121 Metetra
.67 .769 .924 r
.53784 .47121 .54266 .47587 .55168 .4727 .54688 .46818 Metetra
.674 .776 .927 r
.54688 .46818 .55168 .4727 .56072 .4694 .55595 .46502 Metetra
.669 .782 .934 r
.55595 .46502 .56072 .4694 .5698 .46611 .56505 .46196 Metetra
.664 .792 .943 r
.56505 .46196 .5698 .46611 .5789 .46284 .57418 .45896 Metetra
.67 .807 .949 r
.57418 .45896 .5789 .46284 .58803 .45933 .58334 .4558 Metetra
.673 .825 .956 r
.58334 .4558 .58803 .45933 .59717 .45564 .59252 .4525 Metetra
.656 .841 .971 r
.59252 .4525 .59717 .45564 .60636 .45235 .60173 .44939 Metetra
.64 .847 .979 r
.60173 .44939 .60636 .45235 .61558 .44943 .61098 .44646 Metetra
.628 .843 .982 r
.61098 .44646 .61558 .44943 .62485 .44689 .62027 .4437 Metetra
.62 .83 .981 r
.62027 .4437 .62485 .44689 .63416 .44475 .6296 .44113 Metetra
.637 .815 .968 r
.6296 .44113 .63416 .44475 .6435 .44243 .63895 .43843 Metetra
.651 .802 .955 r
.63895 .43843 .6435 .44243 .65287 .43987 .64833 .43557 Metetra
.65 .788 .948 r
.64833 .43557 .65287 .43987 .66227 .43733 .65775 .43276 Metetra
.647 .775 .942 r
.65775 .43276 .66227 .43733 .6717 .43481 .6672 .43005 Metetra
.654 .77 .934 r
.6672 .43005 .6717 .43481 .68117 .43214 .67668 .42722 Metetra
.662 .767 .927 r
.67668 .42722 .68117 .43214 .69066 .42925 .68619 .42421 Metetra
.665 .763 .923 r
.68619 .42421 .69066 .42925 .70017 .42631 .69572 .42113 Metetra
.67 .76 .918 r
.69572 .42113 .70017 .42631 .70972 .42329 .70528 .41792 Metetra
.668 .752 .913 r
.70528 .41792 .70972 .42329 .7193 .42027 .71487 .41476 Metetra
.663 .746 .911 r
.71487 .41476 .7193 .42027 .72891 .41724 .72451 .41171 Metetra
.668 .748 .91 r
.72451 .41171 .72891 .41724 .73854 .41408 .73417 .40852 Metetra
.681 .751 .905 r
.73417 .40852 .73854 .41408 .74819 .41062 .74383 .40499 Metetra
.676 .748 .905 r
.74383 .40499 .74819 .41062 .75788 .40725 .75354 .40157 Metetra
.663 .742 .908 r
.75354 .40157 .75788 .40725 .76762 .40418 .7633 .39847 Metetra
.663 .742 .908 r
.7633 .39847 .76762 .40418 .77739 .40109 .7731 .39537 Metetra
.663 .742 .908 r
.7731 .39537 .77739 .40109 .78719 .39799 .78293 .39225 Metetra
.664 .742 .908 r
.78293 .39225 .78719 .39799 .79702 .3948 .79279 .3891 Metetra
.668 .746 .909 r
.79279 .3891 .79702 .3948 .80686 .39123 .80267 .38586 Metetra
.67 .761 .918 r
.80267 .38586 .80686 .39123 .81673 .38772 .81259 .38253 Metetra
.684 .774 .919 r
.81259 .38253 .81673 .38772 .82667 .38463 .8225 .37885 Metetra
.683 .751 .903 r
.8225 .37885 .82667 .38463 .83664 .38146 .83245 .37516 Metetra
.679 .731 .889 r
.83245 .37516 .83664 .38146 .84659 .37779 .84244 .37152 Metetra
.679 .733 .891 r
.84244 .37152 .84659 .37779 .85658 .37412 .85245 .36789 Metetra
.674 .733 .895 r
.85245 .36789 .85658 .37412 .8666 .37047 .86252 .3644 Metetra
.673 .739 .9 r
.86252 .3644 .8666 .37047 .87666 .36685 .87262 .36092 Metetra
.664 .741 .908 r
.87262 .36092 .87666 .36685 .8868 .36364 .88278 .35769 Metetra
.664 .741 .908 r
.88278 .35769 .8868 .36364 .89697 .36042 .89298 .35445 Metetra
.664 .741 .908 r
.89298 .35445 .89697 .36042 .90718 .3572 .90322 .3512 Metetra
.664 .741 .908 r
.90322 .3512 .90718 .3572 .91743 .35396 .91349 .34794 Metetra
.664 .741 .908 r
.32429 .52845 .32956 .53336 .33793 .5307 .33267 .52578 Metetra
.664 .741 .908 r
.33267 .52578 .33793 .5307 .34632 .52804 .34108 .5231 Metetra
.664 .741 .908 r
.34108 .5231 .34632 .52804 .35473 .52537 .34951 .52041 Metetra
.664 .741 .908 r
.34951 .52041 .35473 .52537 .36317 .52269 .35797 .51772 Metetra
.661 .741 .909 r
.35797 .51772 .36317 .52269 .37163 .52025 .36645 .51506 Metetra
.661 .733 .903 r
.36645 .51506 .37163 .52025 .38012 .51783 .37496 .51241 Metetra
.646 .72 .902 r
.37496 .51241 .38012 .51783 .38862 .51555 .38348 .51009 Metetra
.644 .719 .902 r
.38348 .51009 .38862 .51555 .39716 .51327 .39203 .5078 Metetra
.615 .709 .912 r
.39203 .5078 .39716 .51327 .40572 .51105 .40059 .50613 Metetra
.605 .729 .933 r
.40059 .50613 .40572 .51105 .41431 .50882 .40918 .50454 Metetra
.666 .775 .931 r
.40918 .50454 .41431 .50882 .42295 .50625 .41784 .50169 Metetra
.677 .766 .918 r
.41784 .50169 .42295 .50625 .43161 .50361 .42653 .4986 Metetra
.666 .746 .91 r
.42653 .4986 .43161 .50361 .44031 .50087 .43525 .49576 Metetra
.663 .742 .908 r
.43525 .49576 .44031 .50087 .44903 .49811 .44399 .49298 Metetra
.663 .742 .908 r
.44399 .49298 .44903 .49811 .45778 .49533 .45276 .49019 Metetra
.663 .742 .908 r
.45276 .49019 .45778 .49533 .46656 .49255 .46156 .48739 Metetra
.649 .737 .914 r
.46156 .48739 .46656 .49255 .47536 .49009 .47038 .48491 Metetra
.644 .736 .916 r
.47038 .48491 .47536 .49009 .48419 .48773 .47923 .48254 Metetra
.658 .74 .911 r
.47923 .48254 .48419 .48773 .49306 .48505 .48811 .47984 Metetra
.663 .742 .908 r
.48811 .47984 .49306 .48505 .50196 .48223 .49703 .477 Metetra
.652 .738 .913 r
.49703 .477 .50196 .48223 .51088 .47952 .50597 .47442 Metetra
.646 .742 .919 r
.50597 .47442 .51088 .47952 .51984 .47685 .51494 .47196 Metetra
.657 .755 .922 r
.51494 .47196 .51984 .47685 .52882 .47407 .52395 .46923 Metetra
.663 .76 .922 r
.52395 .46923 .52882 .47407 .53784 .47121 .53298 .46636 Metetra
.664 .76 .922 r
.53298 .46636 .53784 .47121 .54688 .46818 .54205 .46344 Metetra
.665 .766 .925 r
.54205 .46344 .54688 .46818 .55595 .46502 .55114 .4605 Metetra
.653 .772 .936 r
.55114 .4605 .55595 .46502 .56505 .46196 .56027 .45777 Metetra
.642 .785 .95 r
.56027 .45777 .56505 .46196 .57418 .45896 .56943 .45519 Metetra
.638 .804 .963 r
.56943 .45519 .57418 .45896 .58334 .4558 .57862 .45257 Metetra
.629 .83 .978 r
.57862 .45257 .58334 .4558 .59252 .4525 .58784 .44992 Metetra
.619 .86 .988 r
.58784 .44992 .59252 .4525 .60173 .44939 .59709 .44712 Metetra
.617 .875 .99 r
.59709 .44712 .60173 .44939 .61098 .44646 .60637 .44417 Metetra
.627 .878 .988 r
.60637 .44417 .61098 .44646 .62027 .4437 .61568 .44108 Metetra
.648 .868 .982 r
.61568 .44108 .62027 .4437 .6296 .44113 .62501 .43783 Metetra
.664 .84 .967 r
.62501 .43783 .6296 .44113 .63895 .43843 .63437 .43454 Metetra
.672 .814 .951 r
.63437 .43454 .63895 .43843 .64833 .43557 .64376 .43122 Metetra
.667 .792 .941 r
.64376 .43122 .64833 .43557 .65775 .43276 .65319 .42805 Metetra
.659 .774 .934 r
.65319 .42805 .65775 .43276 .6672 .43005 .66266 .42509 Metetra
.661 .765 .927 r
.66266 .42509 .6672 .43005 .67668 .42722 .67216 .42211 Metetra
.663 .76 .922 r
.67216 .42211 .67668 .42722 .68619 .42421 .68168 .41908 Metetra
.669 .762 .92 r
.68168 .41908 .68619 .42421 .69572 .42113 .69124 .4159 Metetra
.679 .762 .914 r
.69124 .4159 .69572 .42113 .70528 .41792 .70081 .41245 Metetra
.674 .751 .909 r
.70081 .41245 .70528 .41792 .71487 .41476 .71042 .40912 Metetra
.663 .742 .908 r
.71042 .40912 .71487 .41476 .72451 .41171 .72007 .40605 Metetra
.668 .744 .906 r
.72007 .40605 .72451 .41171 .73417 .40852 .72976 .40283 Metetra
.681 .748 .902 r
.72976 .40283 .73417 .40852 .74383 .40499 .73945 .39929 Metetra
.676 .746 .904 r
.73945 .39929 .74383 .40499 .75354 .40157 .74918 .39584 Metetra
.663 .742 .908 r
.74918 .39584 .75354 .40157 .7633 .39847 .75896 .39273 Metetra
.663 .742 .908 r
.75896 .39273 .7633 .39847 .7731 .39537 .76878 .3896 Metetra
.663 .742 .908 r
.76878 .3896 .7731 .39537 .78293 .39225 .77863 .38647 Metetra
.661 .741 .909 r
.77863 .38647 .78293 .39225 .79279 .3891 .78853 .38339 Metetra
.65 .739 .915 r
.78853 .38339 .79279 .3891 .80267 .38586 .79848 .38057 Metetra
.659 .761 .926 r
.79848 .38057 .80267 .38586 .81259 .38253 .80844 .3775 Metetra
.71 .791 .915 r
.80844 .3775 .81259 .38253 .8225 .37885 .81832 .37312 Metetra
.704 .762 .897 r
.81832 .37312 .8225 .37885 .83245 .37516 .82824 .36882 Metetra
.679 .731 .889 r
.82824 .36882 .83245 .37516 .84244 .37152 .83825 .36516 Metetra
.678 .73 .89 r
.83825 .36516 .84244 .37152 .85245 .36789 .84829 .36153 Metetra
.665 .726 .895 r
.84829 .36153 .85245 .36789 .86252 .3644 .8584 .35824 Metetra
.666 .734 .901 r
.8584 .35824 .86252 .3644 .87262 .36092 .86855 .35495 Metetra
.664 .741 .908 r
.86855 .35495 .87262 .36092 .88278 .35769 .87874 .35171 Metetra
.664 .741 .908 r
.87874 .35171 .88278 .35769 .89298 .35445 .88897 .34845 Metetra
.664 .741 .908 r
.88897 .34845 .89298 .35445 .90322 .3512 .89923 .34517 Metetra
.664 .741 .908 r
.89923 .34517 .90322 .3512 .91349 .34794 .90953 .34189 Metetra
.664 .741 .908 r
.31899 .52351 .32429 .52845 .33267 .52578 .32738 .52083 Metetra
.664 .741 .908 r
.32738 .52083 .33267 .52578 .34108 .5231 .3358 .51813 Metetra
.664 .741 .908 r
.3358 .51813 .34108 .5231 .34951 .52041 .34425 .51543 Metetra
.664 .741 .908 r
.34425 .51543 .34951 .52041 .35797 .51772 .35273 .51272 Metetra
.664 .741 .908 r
.35273 .51272 .35797 .51772 .36645 .51506 .36123 .50999 Metetra
.664 .739 .906 r
.36123 .50999 .36645 .51506 .37496 .51241 .36976 .50726 Metetra
.652 .734 .909 r
.36976 .50726 .37496 .51241 .38348 .51009 .37831 .50478 Metetra
.651 .728 .905 r
.37831 .50478 .38348 .51009 .39203 .5078 .38688 .50231 Metetra
.608 .708 .915 r
.38688 .50231 .39203 .5078 .40059 .50613 .39545 .50075 Metetra
.6 .71 .921 r
.39545 .50075 .40059 .50613 .40918 .50454 .40404 .49932 Metetra
.664 .737 .904 r
.40404 .49932 .40918 .50454 .41784 .50169 .41272 .49653 Metetra
.675 .742 .901 r
.41272 .49653 .41784 .50169 .42653 .4986 .42143 .49346 Metetra
.66 .74 .909 r
.42143 .49346 .42653 .4986 .43525 .49576 .43016 .49075 Metetra
.656 .745 .915 r
.43016 .49075 .43525 .49576 .44399 .49298 .43891 .48811 Metetra
.661 .753 .918 r
.43891 .48811 .44399 .49298 .45276 .49019 .4477 .48534 Metetra
.663 .755 .918 r
.4477 .48534 .45276 .49019 .46156 .48739 .45652 .48253 Metetra
.648 .75 .924 r
.45652 .48253 .46156 .48739 .47038 .48491 .46536 .48003 Metetra
.642 .749 .926 r
.46536 .48003 .47038 .48491 .47923 .48254 .47422 .47764 Metetra
.657 .753 .921 r
.47422 .47764 .47923 .48254 .48811 .47984 .48313 .47493 Metetra
.663 .755 .919 r
.48313 .47493 .48811 .47984 .49703 .477 .49206 .47208 Metetra
.654 .752 .922 r
.49206 .47208 .49703 .477 .50597 .47442 .50103 .46941 Metetra
.65 .748 .921 r
.50103 .46941 .50597 .47442 .51494 .47196 .51002 .46682 Metetra
.654 .745 .917 r
.51002 .46682 .51494 .47196 .52395 .46923 .51904 .46415 Metetra
.656 .748 .918 r
.51904 .46415 .52395 .46923 .53298 .46636 .5281 .46142 Metetra
.655 .755 .923 r
.5281 .46142 .53298 .46636 .54205 .46344 .53718 .45868 Metetra
.655 .763 .929 r
.53718 .45868 .54205 .46344 .55114 .4605 .5463 .45594 Metetra
.655 .773 .936 r
.5463 .45594 .55114 .4605 .56027 .45777 .55545 .45316 Metetra
.656 .772 .934 r
.55545 .45316 .56027 .45777 .56943 .45519 .56463 .45035 Metetra
.653 .761 .929 r
.56463 .45035 .56943 .45519 .57862 .45257 .57384 .44763 Metetra
.65 .756 .928 r
.57384 .44763 .57862 .45257 .58784 .44992 .58308 .44497 Metetra
.656 .759 .925 r
.58308 .44497 .58784 .44992 .59709 .44712 .59235 .44215 Metetra
.662 .761 .923 r
.59235 .44215 .59709 .44712 .60637 .44417 .60166 .43918 Metetra
.668 .763 .921 r
.60166 .43918 .60637 .44417 .61568 .44108 .61099 .43607 Metetra
.675 .765 .918 r
.61099 .43607 .61568 .44108 .62501 .43783 .62034 .43279 Metetra
.672 .763 .919 r
.62034 .43279 .62501 .43783 .63437 .43454 .62973 .42958 Metetra
.668 .766 .924 r
.62973 .42958 .63437 .43454 .64376 .43122 .63915 .42645 Metetra
.668 .775 .93 r
.63915 .42645 .64376 .43122 .65319 .42805 .6486 .42329 Metetra
.669 .777 .931 r
.6486 .42329 .65319 .42805 .66266 .42509 .65809 .4201 Metetra
.669 .768 .924 r
.65809 .4201 .66266 .42509 .67216 .42211 .6676 .4169 Metetra
.67 .759 .918 r
.6676 .4169 .67216 .42211 .68168 .41908 .67714 .41368 Metetra
.672 .753 .912 r
.67714 .41368 .68168 .41908 .69124 .4159 .68672 .41041 Metetra
.675 .752 .909 r
.68672 .41041 .69124 .4159 .70081 .41245 .69632 .40706 Metetra
.671 .755 .913 r
.69632 .40706 .70081 .41245 .71042 .40912 .70595 .40378 Metetra
.663 .755 .919 r
.70595 .40378 .71042 .40912 .72007 .40605 .71563 .40069 Metetra
.668 .757 .917 r
.71563 .40069 .72007 .40605 .72976 .40283 .72534 .39746 Metetra
.681 .761 .912 r
.72534 .39746 .72976 .40283 .73945 .39929 .73505 .39389 Metetra
.677 .76 .914 r
.73505 .39389 .73945 .39929 .74918 .39584 .74481 .39043 Metetra
.663 .755 .918 r
.74481 .39043 .74918 .39584 .75896 .39273 .75462 .38729 Metetra
.665 .755 .918 r
.75462 .38729 .75896 .39273 .76878 .3896 .76446 .38411 Metetra
.67 .756 .915 r
.76446 .38411 .76878 .3896 .77863 .38647 .77432 .38079 Metetra
.666 .748 .911 r
.77432 .38079 .77863 .38647 .78853 .38339 .78423 .37754 Metetra
.652 .737 .912 r
.78423 .37754 .78853 .38339 .79848 .38057 .7942 .37465 Metetra
.662 .739 .907 r
.7942 .37465 .79848 .38057 .80844 .3775 .80418 .37149 Metetra
.711 .755 .886 r
.80418 .37149 .80844 .3775 .81832 .37312 .81407 .36691 Metetra
.706 .747 .883 r
.81407 .36691 .81832 .37312 .82824 .36882 .824 .36247 Metetra
.674 .729 .892 r
.824 .36247 .82824 .36882 .83825 .36516 .83405 .35895 Metetra
.673 .735 .897 r
.83405 .35895 .83825 .36516 .84829 .36153 .84413 .35545 Metetra
.664 .737 .905 r
.84413 .35545 .84829 .36153 .8584 .35824 .85428 .35221 Metetra
.664 .739 .906 r
.85428 .35221 .8584 .35824 .86855 .35495 .86446 .34895 Metetra
.664 .741 .908 r
.86446 .34895 .86855 .35495 .87874 .35171 .87467 .34568 Metetra
.664 .741 .908 r
.87467 .34568 .87874 .35171 .88897 .34845 .88492 .3424 Metetra
.664 .741 .908 r
.88492 .3424 .88897 .34845 .89923 .34517 .89521 .33911 Metetra
.664 .741 .908 r
.89521 .33911 .89923 .34517 .90953 .34189 .90553 .3358 Metetra
.664 .741 .908 r
.31365 .51855 .31899 .52351 .32738 .52083 .32207 .51584 Metetra
.664 .741 .908 r
.32207 .51584 .32738 .52083 .3358 .51813 .3305 .51313 Metetra
.664 .741 .908 r
.3305 .51313 .3358 .51813 .34425 .51543 .33897 .51041 Metetra
.664 .741 .908 r
.33897 .51041 .34425 .51543 .35273 .51272 .34746 .50769 Metetra
.664 .741 .908 r
.34746 .50769 .35273 .51272 .36123 .50999 .35598 .50495 Metetra
.664 .741 .908 r
.35598 .50495 .36123 .50999 .36976 .50726 .36453 .5022 Metetra
.661 .741 .909 r
.36453 .5022 .36976 .50726 .37831 .50478 .3731 .4995 Metetra
.661 .733 .903 r
.3731 .4995 .37831 .50478 .38688 .50231 .3817 .4968 Metetra
.61 .709 .915 r
.3817 .4968 .38688 .50231 .39545 .50075 .39028 .4952 Metetra
.601 .705 .916 r
.39028 .4952 .39545 .50075 .40404 .49932 .39889 .49375 Metetra
.656 .723 .898 r
.39889 .49375 .40404 .49932 .41272 .49653 .40757 .49112 Metetra
.666 .732 .899 r
.40757 .49112 .41272 .49653 .42143 .49346 .4163 .48826 Metetra
.65 .736 .912 r
.4163 .48826 .42143 .49346 .43016 .49075 .42503 .48575 Metetra
.646 .744 .92 r
.42503 .48575 .43016 .49075 .43891 .48811 .4338 .48332 Metetra
.659 .756 .922 r
.4338 .48332 .43891 .48811 .4477 .48534 .44261 .48058 Metetra
.663 .76 .922 r
.44261 .48058 .4477 .48534 .45652 .48253 .45144 .47775 Metetra
.647 .755 .928 r
.45144 .47775 .45652 .48253 .46536 .48003 .4603 .47524 Metetra
.642 .753 .93 r
.4603 .47524 .46536 .48003 .47422 .47764 .46919 .47283 Metetra
.657 .758 .924 r
.46919 .47283 .47422 .47764 .48313 .47493 .47811 .4701 Metetra
.663 .76 .922 r
.47811 .4701 .48313 .47493 .49206 .47208 .48707 .46723 Metetra
.661 .759 .923 r
.48707 .46723 .49206 .47208 .50103 .46941 .49605 .4644 Metetra
.66 .753 .919 r
.49605 .4644 .50103 .46941 .51002 .46682 .50506 .46157 Metetra
.651 .741 .915 r
.50506 .46157 .51002 .46682 .51904 .46415 .51411 .45894 Metetra
.646 .742 .919 r
.51411 .45894 .51904 .46415 .5281 .46142 .52318 .45642 Metetra
.645 .751 .926 r
.52318 .45642 .5281 .46142 .53718 .45868 .53229 .45389 Metetra
.644 .76 .933 r
.53229 .45389 .53718 .45868 .5463 .45594 .54143 .45135 Metetra
.663 .775 .933 r
.54143 .45135 .5463 .45594 .55545 .45316 .5506 .44839 Metetra
.676 .772 .923 r
.5506 .44839 .55545 .45316 .56463 .45035 .55979 .44512 Metetra
.668 .751 .913 r
.55979 .44512 .56463 .45035 .57384 .44763 .56902 .44206 Metetra
.661 .736 .906 r
.56902 .44206 .57384 .44763 .58308 .44497 .57828 .43916 Metetra
.662 .728 .899 r
.57828 .43916 .58308 .44497 .59235 .44215 .58757 .43621 Metetra
.663 .725 .895 r
.58757 .43621 .59235 .44215 .60166 .43918 .59689 .43323 Metetra
.664 .725 .895 r
.59689 .43323 .60166 .43918 .61099 .43607 .60624 .4302 Metetra
.666 .73 .897 r
.60624 .4302 .61099 .43607 .62034 .43279 .61563 .42713 Metetra
.659 .736 .907 r
.61563 .42713 .62034 .43279 .62973 .42958 .62505 .42422 Metetra
.649 .745 .919 r
.62505 .42422 .62973 .42958 .63915 .42645 .6345 .42152 Metetra
.661 .767 .929 r
.6345 .42152 .63915 .42645 .6486 .42329 .64399 .41851 Metetra
.679 .78 .927 r
.64399 .41851 .6486 .42329 .65809 .4201 .65348 .41508 Metetra
.679 .771 .92 r
.65348 .41508 .65809 .4201 .6676 .4169 .66301 .41163 Metetra
.679 .762 .914 r
.66301 .41163 .6676 .4169 .67714 .41368 .67257 .40817 Metetra
.674 .751 .909 r
.67257 .40817 .67714 .41368 .68672 .41041 .68216 .40482 Metetra
.666 .746 .91 r
.68216 .40482 .68672 .41041 .69632 .40706 .6918 .40166 Metetra
.665 .754 .917 r
.6918 .40166 .69632 .40706 .70595 .40378 .70146 .39852 Metetra
.663 .76 .922 r
.70146 .39852 .70595 .40378 .71563 .40069 .71117 .39541 Metetra
.668 .762 .92 r
.71117 .39541 .71563 .40069 .72534 .39746 .7209 .39216 Metetra
.681 .766 .915 r
.7209 .39216 .72534 .39746 .73505 .39389 .73064 .38857 Metetra
.677 .764 .917 r
.73064 .38857 .73505 .39389 .74481 .39043 .74042 .38509 Metetra
.663 .76 .922 r
.74042 .38509 .74481 .39043 .75462 .38729 .75025 .38193 Metetra
.666 .761 .921 r
.75025 .38193 .75462 .38729 .76446 .38411 .76012 .37868 Metetra
.679 .763 .915 r
.76012 .37868 .76446 .38411 .77432 .38079 .76999 .37511 Metetra
.675 .753 .91 r
.76999 .37511 .77432 .38079 .78423 .37754 .7799 .37162 Metetra
.661 .739 .908 r
.7799 .37162 .78423 .37754 .7942 .37465 .78988 .36849 Metetra
.669 .734 .898 r
.78988 .36849 .7942 .37465 .80418 .37149 .79987 .36511 Metetra
.709 .743 .878 r
.79987 .36511 .80418 .37149 .81407 .36691 .80978 .36052 Metetra
.704 .741 .88 r
.80978 .36052 .81407 .36691 .824 .36247 .81974 .35608 Metetra
.666 .726 .895 r
.81974 .35608 .824 .36247 .83405 .35895 .82983 .35277 Metetra
.666 .735 .901 r
.82983 .35277 .83405 .35895 .84413 .35545 .83996 .34945 Metetra
.664 .741 .908 r
.83996 .34945 .84413 .35545 .85428 .35221 .85013 .34618 Metetra
.664 .741 .908 r
.85013 .34618 .85428 .35221 .86446 .34895 .86034 .3429 Metetra
.664 .741 .908 r
.86034 .3429 .86446 .34895 .87467 .34568 .87058 .33961 Metetra
.664 .741 .908 r
.87058 .33961 .87467 .34568 .88492 .3424 .88085 .33631 Metetra
.664 .741 .908 r
.88085 .33631 .88492 .3424 .89521 .33911 .89117 .333 Metetra
.664 .741 .908 r
.89117 .333 .89521 .33911 .90553 .3358 .90152 .32967 Metetra
.664 .741 .908 r
.30829 .51355 .31365 .51855 .32207 .51584 .31672 .51083 Metetra
.664 .741 .908 r
.31672 .51083 .32207 .51584 .3305 .51313 .32517 .50811 Metetra
.664 .741 .908 r
.32517 .50811 .3305 .51313 .33897 .51041 .33365 .50537 Metetra
.664 .741 .908 r
.33365 .50537 .33897 .51041 .34746 .50769 .34216 .50263 Metetra
.664 .741 .908 r
.34216 .50263 .34746 .50769 .35598 .50495 .3507 .49987 Metetra
.664 .741 .908 r
.3507 .49987 .35598 .50495 .36453 .5022 .35926 .49711 Metetra
.664 .741 .908 r
.35926 .49711 .36453 .5022 .3731 .4995 .36785 .49434 Metetra
.664 .739 .906 r
.36785 .49434 .3731 .4995 .3817 .4968 .37647 .49156 Metetra
.622 .724 .92 r
.37647 .49156 .3817 .4968 .39028 .4952 .38508 .48966 Metetra
.617 .712 .913 r
.38508 .48966 .39028 .4952 .39889 .49375 .39371 .48789 Metetra
.645 .71 .894 r
.39371 .48789 .39889 .49375 .40757 .49112 .40241 .48551 Metetra
.65 .721 .9 r
.40241 .48551 .40757 .49112 .4163 .48826 .41113 .483 Metetra
.645 .733 .913 r
.41113 .483 .4163 .48826 .42503 .48575 .41988 .4806 Metetra
.643 .738 .918 r
.41988 .4806 .42503 .48575 .4338 .48332 .42867 .47821 Metetra
.659 .745 .914 r
.42867 .47821 .4338 .48332 .44261 .48058 .43749 .47547 Metetra
.663 .747 .912 r
.43749 .47547 .44261 .48058 .45144 .47775 .44634 .47262 Metetra
.648 .742 .918 r
.44634 .47262 .45144 .47775 .4603 .47524 .45522 .4701 Metetra
.643 .741 .92 r
.45522 .4701 .4603 .47524 .46919 .47283 .46413 .46767 Metetra
.658 .745 .915 r
.46413 .46767 .46919 .47283 .47811 .4701 .47307 .46493 Metetra
.663 .747 .912 r
.47307 .46493 .47811 .4701 .48707 .46723 .48204 .46204 Metetra
.654 .744 .916 r
.48204 .46204 .48707 .46723 .49605 .4644 .49104 .45936 Metetra
.649 .749 .923 r
.49104 .45936 .49605 .4644 .50506 .46157 .50008 .45676 Metetra
.648 .76 .93 r
.50008 .45676 .50506 .46157 .51411 .45894 .50914 .45415 Metetra
.649 .761 .931 r
.50914 .45415 .51411 .45894 .52318 .45642 .51823 .45152 Metetra
.649 .757 .928 r
.51823 .45152 .52318 .45642 .53229 .45389 .52736 .44888 Metetra
.649 .753 .925 r
.52736 .44888 .53229 .45389 .54143 .45135 .53652 .44623 Metetra
.657 .752 .92 r
.53652 .44623 .54143 .45135 .5506 .44839 .54571 .44341 Metetra
.662 .76 .923 r
.54571 .44341 .5506 .44839 .55979 .44512 .55493 .44047 Metetra
.657 .773 .935 r
.55493 .44047 .55979 .44512 .56902 .44206 .56418 .43759 Metetra
.653 .781 .942 r
.56418 .43759 .56902 .44206 .57828 .43916 .57347 .43476 Metetra
.656 .786 .944 r
.57347 .43476 .57828 .43916 .58757 .43621 .58279 .43185 Metetra
.659 .789 .944 r
.58279 .43185 .58757 .43621 .59689 .43323 .59213 .42884 Metetra
.663 .79 .942 r
.59213 .42884 .59689 .43323 .60624 .4302 .60151 .42575 Metetra
.667 .789 .939 r
.60151 .42575 .60624 .4302 .61563 .42713 .61091 .42257 Metetra
.665 .785 .938 r
.61091 .42257 .61563 .42713 .62505 .42422 .62035 .41944 Metetra
.662 .775 .933 r
.62035 .41944 .62505 .42422 .6345 .42152 .62982 .41638 Metetra
.668 .762 .92 r
.62982 .41638 .6345 .42152 .64399 .41851 .63932 .41318 Metetra
.675 .758 .913 r
.63932 .41318 .64399 .41851 .65348 .41508 .64884 .40982 Metetra
.675 .761 .916 r
.64884 .40982 .65348 .41508 .66301 .41163 .6584 .40645 Metetra
.675 .765 .919 r
.6584 .40645 .66301 .41163 .67257 .40817 .66798 .40307 Metetra
.675 .769 .921 r
.66798 .40307 .67257 .40817 .68216 .40482 .6776 .39967 Metetra
.676 .768 .92 r
.6776 .39967 .68216 .40482 .6918 .40166 .68725 .39624 Metetra
.672 .757 .914 r
.68725 .39624 .6918 .40166 .70146 .39852 .69693 .3929 Metetra
.663 .747 .912 r
.69693 .3929 .70146 .39852 .71117 .39541 .70666 .38977 Metetra
.668 .749 .91 r
.70666 .38977 .71117 .39541 .7209 .39216 .71641 .3865 Metetra
.681 .753 .906 r
.71641 .3865 .7209 .39216 .73064 .38857 .72618 .38289 Metetra
.676 .752 .908 r
.72618 .38289 .73064 .38857 .74042 .38509 .73598 .37939 Metetra
.663 .747 .912 r
.73598 .37939 .74042 .38509 .75025 .38193 .74584 .37622 Metetra
.667 .748 .911 r
.74584 .37622 .75025 .38193 .76012 .37868 .75572 .37293 Metetra
.681 .753 .906 r
.75572 .37293 .76012 .37868 .76999 .37511 .76562 .36927 Metetra
.68 .75 .904 r
.76562 .36927 .76999 .37511 .7799 .37162 .77554 .36563 Metetra
.675 .743 .902 r
.77554 .36563 .7799 .37162 .78988 .36849 .78551 .3621 Metetra
.679 .731 .89 r
.78551 .3621 .78988 .36849 .79987 .36511 .7955 .35843 Metetra
.698 .729 .875 r
.7955 .35843 .79987 .36511 .80978 .36052 .80547 .35413 Metetra
.695 .739 .885 r
.80547 .35413 .80978 .36052 .81974 .35608 .81548 .34995 Metetra
.664 .737 .904 r
.81548 .34995 .81974 .35608 .82983 .35277 .8256 .34669 Metetra
.664 .739 .906 r
.8256 .34669 .82983 .35277 .83996 .34945 .83576 .34341 Metetra
.664 .741 .908 r
.83576 .34341 .83996 .34945 .85013 .34618 .84596 .34012 Metetra
.664 .741 .908 r
.84596 .34012 .85013 .34618 .86034 .3429 .85619 .33682 Metetra
.664 .741 .908 r
.85619 .33682 .86034 .3429 .87058 .33961 .86646 .33351 Metetra
.664 .741 .908 r
.86646 .33351 .87058 .33961 .88085 .33631 .87676 .33018 Metetra
.664 .741 .908 r
.87676 .33018 .88085 .33631 .89117 .333 .8871 .32685 Metetra
.664 .741 .908 r
.8871 .32685 .89117 .333 .90152 .32967 .89748 .3235 Metetra
.664 .741 .908 r
.30289 .50853 .30829 .51355 .31672 .51083 .31134 .50579 Metetra
.664 .741 .908 r
.31134 .50579 .31672 .51083 .32517 .50811 .31981 .50305 Metetra
.664 .741 .908 r
.31981 .50305 .32517 .50811 .33365 .50537 .3283 .5003 Metetra
.664 .741 .908 r
.3283 .5003 .33365 .50537 .34216 .50263 .33683 .49754 Metetra
.664 .741 .908 r
.33683 .49754 .34216 .50263 .3507 .49987 .34538 .49477 Metetra
.664 .741 .908 r
.34538 .49477 .3507 .49987 .35926 .49711 .35396 .49199 Metetra
.664 .741 .908 r
.35396 .49199 .35926 .49711 .36785 .49434 .36257 .4892 Metetra
.664 .741 .908 r
.36257 .4892 .36785 .49434 .37647 .49156 .37121 .4864 Metetra
.64 .735 .917 r
.37121 .4864 .37647 .49156 .38508 .48966 .37985 .48411 Metetra
.638 .719 .907 r
.37985 .48411 .38508 .48966 .39371 .48789 .38852 .48188 Metetra
.633 .702 .895 r
.38852 .48188 .39371 .48789 .40241 .48551 .39721 .47978 Metetra
.631 .712 .905 r
.39721 .47978 .40241 .48551 .41113 .483 .40594 .4777 Metetra
.641 .732 .914 r
.40594 .4777 .41113 .483 .41988 .4806 .4147 .47536 Metetra
.643 .736 .916 r
.4147 .47536 .41988 .4806 .42867 .47821 .4235 .47296 Metetra
.659 .74 .91 r
.4235 .47296 .42867 .47821 .43749 .47547 .43234 .4702 Metetra
.663 .742 .908 r
.43234 .4702 .43749 .47547 .44634 .47262 .44122 .46734 Metetra
.649 .737 .914 r
.44122 .46734 .44634 .47262 .45522 .4701 .45011 .46479 Metetra
.643 .736 .916 r
.45011 .46479 .45522 .4701 .46413 .46767 .45904 .46235 Metetra
.658 .74 .911 r
.45904 .46235 .46413 .46767 .47307 .46493 .468 .45959 Metetra
.663 .742 .908 r
.468 .45959 .47307 .46493 .48204 .46204 .47699 .45668 Metetra
.641 .735 .917 r
.47699 .45668 .48204 .46204 .49104 .45936 .48601 .45428 Metetra
.627 .743 .93 r
.48601 .45428 .49104 .45936 .50008 .45676 .49505 .45212 Metetra
.647 .767 .937 r
.49505 .45212 .50008 .45676 .50914 .45415 .50414 .4495 Metetra
.658 .771 .933 r
.50414 .4495 .50914 .45415 .51823 .45152 .51326 .44663 Metetra
.659 .762 .926 r
.51326 .44663 .51823 .45152 .52736 .44888 .5224 .44375 Metetra
.66 .753 .919 r
.5224 .44375 .52736 .44888 .53652 .44623 .53158 .44086 Metetra
.644 .739 .918 r
.53158 .44086 .53652 .44623 .54571 .44341 .54079 .43832 Metetra
.631 .747 .931 r
.54079 .43832 .54571 .44341 .55493 .44047 .55004 .43603 Metetra
.634 .777 .95 r
.55004 .43603 .55493 .44047 .56418 .43759 .55932 .43356 Metetra
.636 .797 .96 r
.55932 .43356 .56418 .43759 .57347 .43476 .56864 .43094 Metetra
.644 .81 .963 r
.56864 .43094 .57347 .43476 .58279 .43185 .57798 .42811 Metetra
.653 .818 .963 r
.57798 .42811 .58279 .43185 .59213 .42884 .58735 .42509 Metetra
.663 .821 .959 r
.58735 .42509 .59213 .42884 .60151 .42575 .59675 .42187 Metetra
.674 .819 .953 r
.59675 .42187 .60151 .42575 .61091 .42257 .60618 .41845 Metetra
.682 .81 .944 r
.60618 .41845 .61091 .42257 .62035 .41944 .61563 .41488 Metetra
.691 .794 .929 r
.61563 .41488 .62035 .41944 .62982 .41638 .6251 .41112 Metetra
.681 .763 .913 r
.6251 .41112 .62982 .41638 .63932 .41318 .63461 .40761 Metetra
.666 .747 .91 r
.63461 .40761 .63932 .41318 .64884 .40982 .64417 .40445 Metetra
.666 .755 .917 r
.64417 .40445 .64884 .40982 .6584 .40645 .65376 .40129 Metetra
.666 .764 .924 r
.65376 .40129 .6584 .40645 .66798 .40307 .66338 .39811 Metetra
.676 .777 .926 r
.66338 .39811 .66798 .40307 .6776 .39967 .67302 .39467 Metetra
.694 .782 .919 r
.67302 .39467 .6776 .39967 .68725 .39624 .68267 .39078 Metetra
.684 .761 .91 r
.68267 .39078 .68725 .39624 .69693 .3929 .69236 .38712 Metetra
.663 .742 .908 r
.69236 .38712 .69693 .3929 .70666 .38977 .70211 .38397 Metetra
.668 .744 .907 r
.70211 .38397 .70666 .38977 .71641 .3865 .71189 .38067 Metetra
.681 .748 .902 r
.71189 .38067 .71641 .3865 .72618 .38289 .72167 .37705 Metetra
.676 .746 .904 r
.72167 .37705 .72618 .38289 .73598 .37939 .7315 .37352 Metetra
.663 .742 .908 r
.7315 .37352 .73598 .37939 .74584 .37622 .74139 .37033 Metetra
.667 .743 .907 r
.74139 .37033 .74584 .37622 .75572 .37293 .7513 .36702 Metetra
.681 .748 .902 r
.7513 .36702 .75572 .37293 .76562 .36927 .76121 .36334 Metetra
.683 .749 .901 r
.76121 .36334 .76562 .36927 .77554 .36563 .77116 .3596 Metetra
.692 .749 .895 r
.77116 .3596 .77554 .36563 .78551 .3621 .78111 .35558 Metetra
.689 .732 .884 r
.78111 .35558 .78551 .3621 .7955 .35843 .7911 .35159 Metetra
.683 .72 .877 r
.7911 .35159 .7955 .35843 .80547 .35413 .80113 .34772 Metetra
.682 .734 .89 r
.80113 .34772 .80547 .35413 .81548 .34995 .8112 .34391 Metetra
.664 .741 .908 r
.8112 .34391 .81548 .34995 .8256 .34669 .82135 .34063 Metetra
.664 .741 .908 r
.82135 .34063 .8256 .34669 .83576 .34341 .83153 .33733 Metetra
.664 .741 .908 r
.83153 .33733 .83576 .34341 .84596 .34012 .84176 .33402 Metetra
.664 .741 .908 r
.84176 .33402 .84596 .34012 .85619 .33682 .85201 .3307 Metetra
.664 .741 .908 r
.85201 .3307 .85619 .33682 .86646 .33351 .86231 .32736 Metetra
.664 .741 .908 r
.86231 .32736 .86646 .33351 .87676 .33018 .87264 .32402 Metetra
.664 .741 .908 r
.87264 .32402 .87676 .33018 .8871 .32685 .883 .32066 Metetra
.664 .741 .908 r
.883 .32066 .8871 .32685 .89748 .3235 .89341 .31729 Metetra
.664 .741 .908 r
.29746 .50347 .30289 .50853 .31134 .50579 .30592 .50072 Metetra
.664 .741 .908 r
.30592 .50072 .31134 .50579 .31981 .50305 .31441 .49796 Metetra
.664 .741 .908 r
.31441 .49796 .31981 .50305 .3283 .5003 .32292 .49519 Metetra
.664 .741 .908 r
.32292 .49519 .3283 .5003 .33683 .49754 .33147 .49241 Metetra
.664 .741 .908 r
.33147 .49241 .33683 .49754 .34538 .49477 .34004 .48963 Metetra
.664 .741 .908 r
.34004 .48963 .34538 .49477 .35396 .49199 .34863 .48683 Metetra
.664 .741 .908 r
.34863 .48683 .35396 .49199 .36257 .4892 .35726 .48403 Metetra
.664 .741 .908 r
.35726 .48403 .36257 .4892 .37121 .4864 .36591 .48122 Metetra
.652 .738 .913 r
.36591 .48122 .37121 .4864 .37985 .48411 .37458 .47865 Metetra
.651 .728 .906 r
.37458 .47865 .37985 .48411 .38852 .48188 .38328 .47612 Metetra
.623 .708 .907 r
.38328 .47612 .38852 .48188 .39721 .47978 .39198 .4742 Metetra
.616 .714 .915 r
.39198 .4742 .39721 .47978 .40594 .4777 .40071 .47239 Metetra
.638 .732 .916 r
.40071 .47239 .40594 .4777 .4147 .47536 .40949 .4701 Metetra
.643 .736 .916 r
.40949 .4701 .4147 .47536 .4235 .47296 .41831 .46768 Metetra
.654 .739 .912 r
.41831 .46768 .4235 .47296 .43234 .4702 .42717 .46502 Metetra
.657 .744 .914 r
.42717 .46502 .43234 .4702 .44122 .46734 .43605 .46228 Metetra
.651 .749 .921 r
.43605 .46228 .44122 .46734 .45011 .46479 .44497 .45965 Metetra
.65 .745 .919 r
.44497 .45965 .45011 .46479 .45904 .46235 .45391 .45704 Metetra
.65 .74 .915 r
.45391 .45704 .45904 .46235 .468 .45959 .46289 .45443 Metetra
.65 .746 .92 r
.46289 .45443 .468 .45959 .47699 .45668 .4719 .45181 Metetra
.634 .753 .934 r
.4719 .45181 .47699 .45668 .48601 .45428 .48093 .44948 Metetra
.625 .755 .94 r
.48093 .44948 .48601 .45428 .49505 .45212 .49 .44729 Metetra
.645 .761 .933 r
.49 .44729 .49505 .45212 .50414 .4495 .49911 .44471 Metetra
.655 .766 .931 r
.49911 .44471 .50414 .4495 .51326 .44663 .50824 .4419 Metetra
.659 .77 .932 r
.50824 .4419 .51326 .44663 .5224 .44375 .51741 .43899 Metetra
.662 .77 .93 r
.51741 .43899 .5224 .44375 .53158 .44086 .52661 .43601 Metetra
.641 .761 .935 r
.52661 .43601 .53158 .44086 .54079 .43832 .53585 .43346 Metetra
.625 .756 .941 r
.53585 .43346 .54079 .43832 .55004 .43603 .54512 .43121 Metetra
.629 .76 .941 r
.54512 .43121 .55004 .43603 .55932 .43356 .55442 .42888 Metetra
.631 .768 .945 r
.55442 .42888 .55932 .43356 .56864 .43094 .56376 .42647 Metetra
.645 .782 .947 r
.56376 .42647 .56864 .43094 .57798 .42811 .57313 .42373 Metetra
.659 .791 .945 r
.57313 .42373 .57798 .42811 .58735 .42509 .58252 .42069 Metetra
.673 .795 .94 r
.58252 .42069 .58735 .42509 .59675 .42187 .59195 .41735 Metetra
.687 .794 .931 r
.59195 .41735 .59675 .42187 .60618 .41845 .60139 .41368 Metetra
.69 .786 .923 r
.60139 .41368 .60618 .41845 .61563 .41488 .61086 .40993 Metetra
.694 .78 .918 r
.61086 .40993 .61563 .41488 .6251 .41112 .62036 .40609 Metetra
.681 .774 .921 r
.62036 .40609 .6251 .41112 .63461 .40761 .6299 .40256 Metetra
.662 .767 .928 r
.6299 .40256 .63461 .40761 .64417 .40445 .63948 .39946 Metetra
.664 .771 .929 r
.63948 .39946 .64417 .40445 .65376 .40129 .64909 .39628 Metetra
.669 .773 .928 r
.64909 .39628 .65376 .40129 .66338 .39811 .65873 .39301 Metetra
.678 .773 .922 r
.65873 .39301 .66338 .39811 .67302 .39467 .6684 .3895 Metetra
.693 .776 .915 r
.6684 .3895 .67302 .39467 .68267 .39078 .67807 .38559 Metetra
.688 .774 .917 r
.67807 .38559 .68267 .39078 .69236 .38712 .68779 .38182 Metetra
.675 .766 .919 r
.68779 .38182 .69236 .38712 .70211 .38397 .69754 .37834 Metetra
.675 .754 .91 r
.69754 .37834 .70211 .38397 .71189 .38067 .70733 .37486 Metetra
.675 .748 .905 r
.70733 .37486 .71189 .38067 .72167 .37705 .71716 .37136 Metetra
.674 .753 .91 r
.71716 .37136 .72167 .37705 .7315 .37352 .72701 .36789 Metetra
.669 .754 .914 r
.72701 .36789 .7315 .37352 .74139 .37033 .73691 .36452 Metetra
.672 .749 .909 r
.73691 .36452 .74139 .37033 .7513 .36702 .74684 .36107 Metetra
.681 .748 .902 r
.74684 .36107 .7513 .36702 .76121 .36334 .75678 .35738 Metetra
.685 .75 .901 r
.75678 .35738 .76121 .36334 .77116 .3596 .76675 .35355 Metetra
.702 .754 .892 r
.76675 .35355 .77116 .3596 .78111 .35558 .7767 .34921 Metetra
.696 .741 .886 r
.7767 .34921 .78111 .35558 .7911 .35159 .7867 .34499 Metetra
.674 .725 .888 r
.7867 .34499 .7911 .35159 .80113 .34772 .79678 .3414 Metetra
.673 .736 .897 r
.79678 .3414 .80113 .34772 .8112 .34391 .80689 .33784 Metetra
.664 .741 .908 r
.80689 .33784 .8112 .34391 .82135 .34063 .81707 .33453 Metetra
.664 .741 .908 r
.81707 .33453 .82135 .34063 .83153 .33733 .82728 .33121 Metetra
.664 .741 .908 r
.82728 .33121 .83153 .33733 .84176 .33402 .83753 .32788 Metetra
.664 .741 .908 r
.83753 .32788 .84176 .33402 .85201 .3307 .84781 .32453 Metetra
.664 .741 .908 r
.84781 .32453 .85201 .3307 .86231 .32736 .85813 .32118 Metetra
.664 .741 .908 r
.85813 .32118 .86231 .32736 .87264 .32402 .86849 .31781 Metetra
.664 .741 .908 r
.86849 .31781 .87264 .32402 .883 .32066 .87888 .31443 Metetra
.664 .741 .908 r
.87888 .31443 .883 .32066 .89341 .31729 .88931 .31104 Metetra
.664 .741 .908 r
.292 .49839 .29746 .50347 .30592 .50072 .30048 .49562 Metetra
.664 .741 .908 r
.30048 .49562 .30592 .50072 .31441 .49796 .30898 .49284 Metetra
.664 .741 .908 r
.30898 .49284 .31441 .49796 .32292 .49519 .31751 .49006 Metetra
.664 .741 .908 r
.31751 .49006 .32292 .49519 .33147 .49241 .32607 .48726 Metetra
.664 .741 .908 r
.32607 .48726 .33147 .49241 .34004 .48963 .33466 .48446 Metetra
.664 .741 .908 r
.33466 .48446 .34004 .48963 .34863 .48683 .34327 .48165 Metetra
.664 .741 .908 r
.34327 .48165 .34863 .48683 .35726 .48403 .35191 .47883 Metetra
.664 .741 .908 r
.35191 .47883 .35726 .48403 .36591 .48122 .36058 .476 Metetra
.661 .741 .909 r
.36058 .476 .36591 .48122 .37458 .47865 .36928 .47323 Metetra
.66 .733 .904 r
.36928 .47323 .37458 .47865 .38328 .47612 .378 .47046 Metetra
.615 .711 .913 r
.378 .47046 .38328 .47612 .39198 .4742 .38671 .46867 Metetra
.604 .713 .921 r
.38671 .46867 .39198 .4742 .40071 .47239 .39545 .46707 Metetra
.636 .732 .917 r
.39545 .46707 .40071 .47239 .40949 .4701 .40425 .4648 Metetra
.643 .736 .916 r
.40425 .4648 .40949 .4701 .41831 .46768 .41308 .46236 Metetra
.646 .737 .915 r
.41308 .46236 .41831 .46768 .42717 .46502 .42195 .45986 Metetra
.647 .744 .92 r
.42195 .45986 .42717 .46502 .43605 .46228 .43085 .45732 Metetra
.656 .755 .923 r
.43085 .45732 .43605 .46228 .44497 .45965 .43979 .45457 Metetra
.66 .752 .918 r
.43979 .45457 .44497 .45965 .45391 .45704 .44876 .45172 Metetra
.639 .737 .92 r
.44876 .45172 .45391 .45704 .46289 .45443 .45775 .44934 Metetra
.628 .743 .93 r
.45775 .44934 .46289 .45443 .4719 .45181 .46677 .44715 Metetra
.632 .763 .942 r
.46677 .44715 .4719 .45181 .48093 .44948 .47582 .4448 Metetra
.636 .764 .941 r
.47582 .4448 .48093 .44948 .49 .44729 .48491 .44237 Metetra
.642 .757 .932 r
.48491 .44237 .49 .44729 .49911 .44471 .49404 .43983 Metetra
.645 .76 .933 r
.49404 .43983 .49911 .44471 .50824 .4419 .5032 .43723 Metetra
.655 .773 .936 r
.5032 .43723 .50824 .4419 .51741 .43899 .51239 .43438 Metetra
.661 .778 .936 r
.51239 .43438 .51741 .43899 .52661 .43601 .52161 .43139 Metetra
.646 .774 .941 r
.52161 .43139 .52661 .43601 .53585 .43346 .53087 .42869 Metetra
.636 .765 .941 r
.53087 .42869 .53585 .43346 .54512 .43121 .54016 .42621 Metetra
.629 .753 .937 r
.54016 .42621 .54512 .43121 .55442 .42888 .54948 .42387 Metetra
.622 .752 .939 r
.54948 .42387 .55442 .42888 .56376 .42647 .55884 .42167 Metetra
.642 .768 .94 r
.55884 .42167 .56376 .42647 .57313 .42373 .56824 .41903 Metetra
.661 .779 .936 r
.56824 .41903 .57313 .42373 .58252 .42069 .57766 .41597 Metetra
.679 .784 .929 r
.57766 .41597 .58252 .42069 .59195 .41735 .5871 .4125 Metetra
.697 .784 .919 r
.5871 .4125 .59195 .41735 .60139 .41368 .59657 .40859 Metetra
.691 .774 .915 r
.59657 .40859 .60139 .41368 .61086 .40993 .60606 .4048 Metetra
.685 .771 .917 r
.60606 .4048 .61086 .40993 .62036 .40609 .61559 .40116 Metetra
.675 .777 .927 r
.61559 .40116 .62036 .40609 .6299 .40256 .62516 .39774 Metetra
.661 .778 .936 r
.62516 .39774 .6299 .40256 .63948 .39946 .63476 .39461 Metetra
.668 .78 .934 r
.63476 .39461 .63948 .39946 .64909 .39628 .6444 .39133 Metetra
.678 .78 .927 r
.6444 .39133 .64909 .39628 .65873 .39301 .65406 .38781 Metetra
.68 .772 .92 r
.65406 .38781 .65873 .39301 .6684 .3895 .66374 .38422 Metetra
.685 .77 .916 r
.66374 .38422 .6684 .3895 .67807 .38559 .67345 .38052 Metetra
.687 .78 .922 r
.67345 .38052 .67807 .38559 .68779 .38182 .68319 .37673 Metetra
.693 .782 .919 r
.68319 .37673 .68779 .38182 .69754 .37834 .69295 .37278 Metetra
.685 .762 .91 r
.69295 .37278 .69754 .37834 .70733 .37486 .70276 .36902 Metetra
.666 .745 .909 r
.70276 .36902 .70733 .37486 .71716 .37136 .71262 .36573 Metetra
.669 .755 .915 r
.71262 .36573 .71716 .37136 .72701 .36789 .7225 .36235 Metetra
.678 .763 .915 r
.7225 .36235 .72701 .36789 .73691 .36452 .73241 .35873 Metetra
.679 .754 .908 r
.73241 .35873 .73691 .36452 .74684 .36107 .74235 .35509 Metetra
.681 .748 .902 r
.74235 .35509 .74684 .36107 .75678 .35738 .75232 .35137 Metetra
.687 .75 .9 r
.75232 .35137 .75678 .35738 .76675 .35355 .76231 .34748 Metetra
.709 .757 .889 r
.76231 .34748 .76675 .35355 .7767 .34921 .77227 .34289 Metetra
.702 .746 .886 r
.77227 .34289 .7767 .34921 .7867 .34499 .78228 .33849 Metetra
.666 .727 .895 r
.78228 .33849 .7867 .34499 .79678 .3414 .7924 .33511 Metetra
.666 .735 .901 r
.7924 .33511 .79678 .3414 .80689 .33784 .80256 .33172 Metetra
.664 .741 .908 r
.80256 .33172 .80689 .33784 .81707 .33453 .81276 .32839 Metetra
.664 .741 .908 r
.81276 .32839 .81707 .33453 .82728 .33121 .823 .32505 Metetra
.664 .741 .908 r
.823 .32505 .82728 .33121 .83753 .32788 .83327 .32169 Metetra
.664 .741 .908 r
.83327 .32169 .83753 .32788 .84781 .32453 .84358 .31833 Metetra
.664 .741 .908 r
.84358 .31833 .84781 .32453 .85813 .32118 .85393 .31495 Metetra
.664 .741 .908 r
.85393 .31495 .85813 .32118 .86849 .31781 .86431 .31156 Metetra
.664 .741 .908 r
.86431 .31156 .86849 .31781 .87888 .31443 .87473 .30816 Metetra
.664 .741 .908 r
.87473 .30816 .87888 .31443 .88931 .31104 .88519 .30475 Metetra
.664 .741 .908 r
.28651 .49327 .292 .49839 .30048 .49562 .295 .49049 Metetra
.664 .741 .908 r
.295 .49049 .30048 .49562 .30898 .49284 .30352 .48769 Metetra
.664 .741 .908 r
.30352 .48769 .30898 .49284 .31751 .49006 .31207 .48489 Metetra
.664 .741 .908 r
.31207 .48489 .31751 .49006 .32607 .48726 .32064 .48208 Metetra
.664 .741 .908 r
.32064 .48208 .32607 .48726 .33466 .48446 .32925 .47926 Metetra
.664 .741 .908 r
.32925 .47926 .33466 .48446 .34327 .48165 .33788 .47643 Metetra
.664 .741 .908 r
.33788 .47643 .34327 .48165 .35191 .47883 .34654 .4736 Metetra
.664 .741 .908 r
.34654 .4736 .35191 .47883 .36058 .476 .35523 .47075 Metetra
.664 .741 .908 r
.35523 .47075 .36058 .476 .36928 .47323 .36394 .46789 Metetra
.664 .739 .906 r
.36394 .46789 .36928 .47323 .378 .47046 .37269 .46503 Metetra
.623 .724 .919 r
.37269 .46503 .378 .47046 .38671 .46867 .38142 .46304 Metetra
.615 .714 .916 r
.38142 .46304 .38671 .46867 .39545 .46707 .39018 .46121 Metetra
.629 .711 .905 r
.39018 .46121 .39545 .46707 .40425 .4648 .39899 .45912 Metetra
.631 .719 .91 r
.39899 .45912 .40425 .4648 .41308 .46236 .40783 .45695 Metetra
.641 .732 .915 r
.40783 .45695 .41308 .46236 .42195 .45986 .41671 .45455 Metetra
.643 .738 .918 r
.41671 .45455 .42195 .45986 .43085 .45732 .42563 .45208 Metetra
.653 .744 .916 r
.42563 .45208 .43085 .45732 .43979 .45457 .43458 .44937 Metetra
.657 .748 .917 r
.43458 .44937 .43979 .45457 .44876 .45172 .44357 .44658 Metetra
.636 .744 .926 r
.44357 .44658 .44876 .45172 .45775 .44934 .45258 .44421 Metetra
.627 .743 .93 r
.45258 .44421 .45775 .44934 .46677 .44715 .46161 .44201 Metetra
.633 .745 .929 r
.46161 .44201 .46677 .44715 .47582 .4448 .47069 .43969 Metetra
.635 .748 .93 r
.47069 .43969 .47582 .4448 .48491 .44237 .4798 .43731 Metetra
.648 .754 .927 r
.4798 .43731 .48491 .44237 .49404 .43983 .48894 .43464 Metetra
.656 .752 .921 r
.48894 .43464 .49404 .43983 .5032 .43723 .49812 .43181 Metetra
.645 .741 .919 r
.49812 .43181 .5032 .43723 .51239 .43438 .50733 .42923 Metetra
.636 .749 .93 r
.50733 .42923 .51239 .43438 .52161 .43139 .51658 .42679 Metetra
.622 .769 .95 r
.51658 .42679 .52161 .43139 .53087 .42869 .52585 .42452 Metetra
.608 .784 .966 r
.52585 .42452 .53087 .42869 .54016 .42621 .53517 .42237 Metetra
.62 .805 .971 r
.53517 .42237 .54016 .42621 .54948 .42387 .54452 .41991 Metetra
.637 .805 .963 r
.54452 .41991 .54948 .42387 .55884 .42167 .5539 .41719 Metetra
.652 .786 .946 r
.5539 .41719 .55884 .42167 .56824 .41903 .56331 .41429 Metetra
.661 .779 .936 r
.56331 .41429 .56824 .41903 .57766 .41597 .57276 .41121 Metetra
.668 .781 .933 r
.57276 .41121 .57766 .41597 .5871 .4125 .58223 .40797 Metetra
.675 .793 .938 r
.58223 .40797 .5871 .4125 .59657 .40859 .59173 .40453 Metetra
.684 .818 .947 r
.59173 .40453 .59657 .40859 .60606 .4048 .60126 .40084 Metetra
.698 .827 .944 r
.60126 .40084 .60606 .4048 .61559 .40116 .61081 .39683 Metetra
.693 .81 .937 r
.61081 .39683 .61559 .40116 .62516 .39774 .62039 .39293 Metetra
.686 .788 .928 r
.62039 .39293 .62516 .39774 .63476 .39461 .63 .38921 Metetra
.68 .763 .914 r
.63 .38921 .63476 .39461 .6444 .39133 .63965 .38563 Metetra
.67 .749 .91 r
.63965 .38563 .6444 .39133 .65406 .38781 .64934 .3823 Metetra
.676 .759 .913 r
.64934 .3823 .65406 .38781 .66374 .38422 .65905 .3788 Metetra
.687 .767 .912 r
.65905 .3788 .66374 .38422 .67345 .38052 .66879 .37501 Metetra
.689 .765 .91 r
.66879 .37501 .67345 .38052 .68319 .37673 .67855 .37115 Metetra
.693 .764 .906 r
.67855 .37115 .68319 .37673 .69295 .37278 .68833 .36717 Metetra
.686 .762 .909 r
.68833 .36717 .69295 .37278 .70276 .36902 .69816 .36336 Metetra
.669 .754 .914 r
.69816 .36336 .70276 .36902 .71262 .36573 .70804 .35998 Metetra
.672 .753 .911 r
.70804 .35998 .71262 .36573 .7225 .36235 .71795 .35651 Metetra
.681 .754 .906 r
.71795 .35651 .7225 .36235 .73241 .35873 .72788 .35279 Metetra
.683 .751 .903 r
.72788 .35279 .73241 .35873 .74235 .35509 .73783 .349 Metetra
.691 .749 .896 r
.73783 .349 .74235 .35509 .75232 .35137 .7478 .34497 Metetra
.692 .74 .888 r
.7478 .34497 .75232 .35137 .76231 .34748 .7578 .34086 Metetra
.7 .736 .879 r
.7578 .34086 .76231 .34748 .77227 .34289 .76781 .33646 Metetra
.695 .741 .887 r
.76781 .33646 .77227 .34289 .78228 .33849 .77785 .33223 Metetra
.663 .736 .904 r
.77785 .33223 .78228 .33849 .7924 .33511 .78801 .3289 Metetra
.664 .739 .906 r
.78801 .3289 .7924 .33511 .80256 .33172 .7982 .32556 Metetra
.664 .741 .908 r
.7982 .32556 .80256 .33172 .81276 .32839 .80843 .32221 Metetra
.664 .741 .908 r
.80843 .32221 .81276 .32839 .823 .32505 .81869 .31885 Metetra
.664 .741 .908 r
.81869 .31885 .823 .32505 .83327 .32169 .82899 .31547 Metetra
.664 .741 .908 r
.82899 .31547 .83327 .32169 .84358 .31833 .83932 .31208 Metetra
.664 .741 .908 r
.83932 .31208 .84358 .31833 .85393 .31495 .8497 .30868 Metetra
.664 .741 .908 r
.8497 .30868 .85393 .31495 .86431 .31156 .86011 .30527 Metetra
.664 .741 .908 r
.86011 .30527 .86431 .31156 .87473 .30816 .87055 .30185 Metetra
.664 .741 .908 r
.87055 .30185 .87473 .30816 .88519 .30475 .88104 .29841 Metetra
.664 .741 .908 r
.28098 .48812 .28651 .49327 .295 .49049 .28949 .48532 Metetra
.664 .741 .908 r
.28949 .48532 .295 .49049 .30352 .48769 .29803 .48252 Metetra
.664 .741 .908 r
.29803 .48252 .30352 .48769 .31207 .48489 .30659 .4797 Metetra
.664 .741 .908 r
.30659 .4797 .31207 .48489 .32064 .48208 .31518 .47687 Metetra
.664 .741 .908 r
.31518 .47687 .32064 .48208 .32925 .47926 .3238 .47403 Metetra
.664 .741 .908 r
.3238 .47403 .32925 .47926 .33788 .47643 .33245 .47119 Metetra
.664 .741 .908 r
.33245 .47119 .33788 .47643 .34654 .4736 .34113 .46833 Metetra
.664 .741 .908 r
.34113 .46833 .34654 .4736 .35523 .47075 .34983 .46547 Metetra
.664 .741 .908 r
.34983 .46547 .35523 .47075 .36394 .46789 .35857 .46259 Metetra
.664 .741 .908 r
.35857 .46259 .36394 .46789 .37269 .46503 .36733 .45971 Metetra
.64 .735 .917 r
.36733 .45971 .37269 .46503 .38142 .46304 .3761 .45734 Metetra
.637 .719 .908 r
.3761 .45734 .38142 .46304 .39018 .46121 .38489 .45505 Metetra
.617 .697 .901 r
.38489 .45505 .39018 .46121 .39899 .45912 .3937 .45321 Metetra
.611 .704 .911 r
.3937 .45321 .39899 .45912 .40783 .45695 .40254 .45147 Metetra
.636 .73 .916 r
.40254 .45147 .40783 .45695 .41671 .45455 .41144 .44915 Metetra
.643 .736 .916 r
.41144 .44915 .41671 .45455 .42563 .45208 .42037 .44666 Metetra
.646 .737 .915 r
.42037 .44666 .42563 .45208 .43458 .44937 .42934 .4441 Metetra
.647 .743 .92 r
.42934 .4441 .43458 .44937 .44357 .44658 .43834 .44151 Metetra
.64 .75 .928 r
.43834 .44151 .44357 .44658 .45258 .44421 .44737 .43903 Metetra
.638 .746 .926 r
.44737 .43903 .45258 .44421 .46161 .44201 .45643 .4366 Metetra
.63 .734 .923 r
.45643 .4366 .46161 .44201 .47069 .43969 .46552 .43434 Metetra
.625 .736 .926 r
.46552 .43434 .47069 .43969 .4798 .43731 .47465 .43217 Metetra
.658 .755 .922 r
.47465 .43217 .4798 .43731 .48894 .43464 .48382 .42927 Metetra
.675 .752 .909 r
.48382 .42927 .48894 .43464 .49812 .43181 .49302 .42597 Metetra
.629 .72 .913 r
.49302 .42597 .49812 .43181 .50733 .42923 .50225 .42374 Metetra
.592 .721 .934 r
.50225 .42374 .50733 .42923 .51658 .42679 .51151 .42218 Metetra
.576 .754 .962 r
.51151 .42218 .51658 .42679 .52585 .42452 .52081 .42067 Metetra
.554 .781 .983 r
.52081 .42067 .52585 .42452 .53517 .42237 .53015 .41918 Metetra
.618 .836 .984 r
.53015 .41918 .53517 .42237 .54452 .41991 .53952 .41652 Metetra
.679 .844 .962 r
.53952 .41652 .54452 .41991 .5539 .41719 .54892 .41288 Metetra
.672 .801 .944 r
.54892 .41288 .5539 .41719 .56331 .41429 .55836 .40952 Metetra
.661 .779 .936 r
.55836 .40952 .56331 .41429 .57276 .41121 .56783 .40642 Metetra
.648 .775 .941 r
.56783 .40642 .57276 .41121 .58223 .40797 .57733 .40359 Metetra
.628 .788 .958 r
.57733 .40359 .58223 .40797 .59173 .40453 .58688 .40105 Metetra
.669 .842 .966 r
.58688 .40105 .59173 .40453 .60126 .40084 .59644 .39752 Metetra
.724 .863 .947 r
.59644 .39752 .60126 .40084 .61081 .39683 .606 .39281 Metetra
.725 .832 .931 r
.606 .39281 .61081 .39683 .62039 .39293 .61558 .38812 Metetra
.721 .799 .912 r
.61558 .38812 .62039 .39293 .63 .38921 .62519 .38347 Metetra
.693 .756 .9 r
.62519 .38347 .63 .38921 .63965 .38563 .63485 .3795 Metetra
.652 .727 .905 r
.63485 .3795 .63965 .38563 .64934 .3823 .64458 .3766 Metetra
.667 .75 .912 r
.64458 .3766 .64934 .3823 .65905 .3788 .65433 .37329 Metetra
.695 .767 .907 r
.65433 .37329 .65905 .3788 .66879 .37501 .66408 .36925 Metetra
.691 .757 .902 r
.66408 .36925 .66879 .37501 .67855 .37115 .67386 .36529 Metetra
.684 .752 .903 r
.67386 .36529 .67855 .37115 .68833 .36717 .68368 .36152 Metetra
.683 .76 .91 r
.68368 .36152 .68833 .36717 .69816 .36336 .69354 .35778 Metetra
.678 .762 .915 r
.69354 .35778 .69816 .36336 .70804 .35998 .70343 .35415 Metetra
.679 .754 .908 r
.70343 .35415 .70804 .35998 .71795 .35651 .71335 .35049 Metetra
.681 .748 .902 r
.71335 .35049 .71795 .35651 .72788 .35279 .72331 .34675 Metetra
.687 .75 .9 r
.72331 .34675 .72788 .35279 .73783 .349 .73328 .34283 Metetra
.706 .753 .889 r
.73328 .34283 .73783 .349 .7478 .34497 .74325 .33832 Metetra
.7 .736 .879 r
.74325 .33832 .7478 .34497 .7578 .34086 .75325 .33391 Metetra
.684 .721 .877 r
.75325 .33391 .7578 .34086 .76781 .33646 .76331 .32995 Metetra
.682 .735 .891 r
.76331 .32995 .76781 .33646 .77785 .33223 .77341 .32608 Metetra
.664 .741 .908 r
.77341 .32608 .77785 .33223 .78801 .3289 .78359 .32273 Metetra
.664 .741 .908 r
.78359 .32273 .78801 .3289 .7982 .32556 .79381 .31937 Metetra
.664 .741 .908 r
.79381 .31937 .7982 .32556 .80843 .32221 .80406 .31599 Metetra
.664 .741 .908 r
.80406 .31599 .80843 .32221 .81869 .31885 .81435 .31261 Metetra
.664 .741 .908 r
.81435 .31261 .81869 .31885 .82899 .31547 .82468 .30921 Metetra
.664 .741 .908 r
.82468 .30921 .82899 .31547 .83932 .31208 .83504 .3058 Metetra
.664 .741 .908 r
.83504 .3058 .83932 .31208 .8497 .30868 .84544 .30238 Metetra
.664 .741 .908 r
.84544 .30238 .8497 .30868 .86011 .30527 .85587 .29894 Metetra
.664 .741 .908 r
.85587 .29894 .86011 .30527 .87055 .30185 .86635 .29549 Metetra
.664 .741 .908 r
.86635 .29549 .87055 .30185 .88104 .29841 .87686 .29204 Metetra
.664 .741 .908 r
.27542 .48295 .28098 .48812 .28949 .48532 .28395 .48013 Metetra
.664 .741 .908 r
.28395 .48013 .28949 .48532 .29803 .48252 .2925 .47731 Metetra
.664 .741 .908 r
.2925 .47731 .29803 .48252 .30659 .4797 .30108 .47447 Metetra
.664 .741 .908 r
.30108 .47447 .30659 .4797 .31518 .47687 .30969 .47163 Metetra
.664 .741 .908 r
.30969 .47163 .31518 .47687 .3238 .47403 .31833 .46877 Metetra
.664 .741 .908 r
.31833 .46877 .3238 .47403 .33245 .47119 .32699 .46591 Metetra
.664 .741 .908 r
.32699 .46591 .33245 .47119 .34113 .46833 .33569 .46304 Metetra
.664 .741 .908 r
.33569 .46304 .34113 .46833 .34983 .46547 .34441 .46015 Metetra
.664 .741 .908 r
.34441 .46015 .34983 .46547 .35857 .46259 .35316 .45726 Metetra
.664 .741 .908 r
.35316 .45726 .35857 .46259 .36733 .45971 .36194 .45436 Metetra
.652 .738 .913 r
.36194 .45436 .36733 .45971 .3761 .45734 .37074 .45171 Metetra
.65 .728 .906 r
.37074 .45171 .3761 .45734 .38489 .45505 .37956 .44911 Metetra
.612 .704 .91 r
.37956 .44911 .38489 .45505 .3937 .45321 .38838 .44733 Metetra
.602 .703 .915 r
.38838 .44733 .3937 .45321 .40254 .45147 .39723 .44574 Metetra
.63 .72 .912 r
.39723 .44574 .40254 .45147 .41144 .44915 .40614 .44355 Metetra
.638 .727 .913 r
.40614 .44355 .41144 .44915 .42037 .44666 .41509 .44118 Metetra
.637 .733 .917 r
.41509 .44118 .42037 .44666 .42934 .4441 .42407 .4388 Metetra
.636 .74 .923 r
.42407 .4388 .42934 .4441 .43834 .44151 .43308 .43642 Metetra
.645 .752 .927 r
.43308 .43642 .43834 .44151 .44737 .43903 .44213 .43383 Metetra
.649 .749 .923 r
.44213 .43383 .44737 .43903 .45643 .4366 .45122 .43115 Metetra
.631 .735 .922 r
.45122 .43115 .45643 .4366 .46552 .43434 .46033 .42886 Metetra
.622 .731 .925 r
.46033 .42886 .46552 .43434 .47465 .43217 .46947 .42676 Metetra
.646 .742 .919 r
.46947 .42676 .47465 .43217 .48382 .42927 .47865 .42412 Metetra
.659 .757 .923 r
.47865 .42412 .48382 .42927 .49302 .42597 .48788 .42118 Metetra
.602 .754 .951 r
.48788 .42118 .49302 .42597 .50225 .42374 .49712 .41929 Metetra
.552 .752 .97 r
.49712 .41929 .50225 .42374 .51151 .42218 .5064 .41806 Metetra
.542 .765 .98 r
.5064 .41806 .51151 .42218 .52081 .42067 .51572 .41683 Metetra
.532 .775 .987 r
.51572 .41683 .52081 .42067 .53015 .41918 .52508 .41559 Metetra
.596 .811 .982 r
.52508 .41559 .53015 .41918 .53952 .41652 .53449 .41336 Metetra
.638 .846 .98 r
.53449 .41336 .53952 .41652 .54892 .41288 .54392 .41032 Metetra
.622 .87 .989 r
.54392 .41032 .54892 .41288 .55836 .40952 .55339 .40725 Metetra
.613 .881 .99 r
.55339 .40725 .55836 .40952 .56783 .40642 .56289 .40414 Metetra
.615 .881 .99 r
.56289 .40414 .56783 .40642 .57733 .40359 .57242 .40099 Metetra
.628 .872 .988 r
.57242 .40099 .57733 .40359 .58688 .40105 .58199 .39781 Metetra
.69 .859 .963 r
.58199 .39781 .58688 .40105 .59644 .39752 .59157 .3938 Metetra
.736 .848 .933 r
.59157 .3938 .59644 .39752 .606 .39281 .60115 .3888 Metetra
.736 .836 .926 r
.60115 .3888 .606 .39281 .61558 .38812 .61076 .38379 Metetra
.735 .823 .919 r
.61076 .38379 .61558 .38812 .62519 .38347 .62039 .37877 Metetra
.71 .803 .923 r
.62039 .37877 .62519 .38347 .63485 .3795 .63006 .37442 Metetra
.666 .775 .931 r
.63006 .37442 .63485 .3795 .64458 .3766 .6398 .37112 Metetra
.679 .764 .915 r
.6398 .37112 .64458 .3766 .65433 .37329 .64956 .36751 Metetra
.698 .759 .899 r
.64956 .36751 .65433 .37329 .66408 .36925 .65933 .36336 Metetra
.691 .754 .9 r
.65933 .36336 .66408 .36925 .67386 .36529 .66914 .3594 Metetra
.676 .749 .906 r
.66914 .3594 .67386 .36529 .68368 .36152 .679 .35582 Metetra
.679 .759 .911 r
.679 .35582 .68368 .36152 .69354 .35778 .68888 .35216 Metetra
.687 .765 .911 r
.68888 .35216 .69354 .35778 .70343 .35415 .69879 .34828 Metetra
.686 .756 .905 r
.69879 .34828 .70343 .35415 .71335 .35049 .70873 .3444 Metetra
.686 .749 .899 r
.70873 .3444 .71335 .35049 .72331 .34675 .7187 .3405 Metetra
.691 .746 .893 r
.7187 .3405 .72331 .34675 .73328 .34283 .72869 .33641 Metetra
.71 .747 .881 r
.72869 .33641 .73328 .34283 .74325 .33832 .73867 .3317 Metetra
.703 .739 .879 r
.73867 .3317 .74325 .33832 .75325 .33391 .74868 .32718 Metetra
.674 .725 .888 r
.74868 .32718 .75325 .33391 .76331 .32995 .7588 .32351 Metetra
.673 .736 .897 r
.7588 .32351 .76331 .32995 .77341 .32608 .76894 .31988 Metetra
.664 .741 .908 r
.76894 .31988 .77341 .32608 .78359 .32273 .77915 .31651 Metetra
.664 .741 .908 r
.77915 .31651 .78359 .32273 .79381 .31937 .78939 .31313 Metetra
.664 .741 .908 r
.78939 .31313 .79381 .31937 .80406 .31599 .79967 .30973 Metetra
.664 .741 .908 r
.79967 .30973 .80406 .31599 .81435 .31261 .80998 .30632 Metetra
.664 .741 .908 r
.80998 .30632 .81435 .31261 .82468 .30921 .82034 .3029 Metetra
.664 .741 .908 r
.82034 .3029 .82468 .30921 .83504 .3058 .83072 .29947 Metetra
.664 .741 .908 r
.83072 .29947 .83504 .3058 .84544 .30238 .84115 .29603 Metetra
.664 .741 .908 r
.84115 .29603 .84544 .30238 .85587 .29894 .85161 .29257 Metetra
.664 .741 .908 r
.85161 .29257 .85587 .29894 .86635 .29549 .86211 .2891 Metetra
.664 .741 .908 r
.86211 .2891 .86635 .29549 .87686 .29204 .87265 .28562 Metetra
.664 .741 .908 r
.26983 .47774 .27542 .48295 .28395 .48013 .27837 .47491 Metetra
.664 .741 .908 r
.27837 .47491 .28395 .48013 .2925 .47731 .28694 .47206 Metetra
.664 .741 .908 r
.28694 .47206 .2925 .47731 .30108 .47447 .29554 .46921 Metetra
.664 .741 .908 r
.29554 .46921 .30108 .47447 .30969 .47163 .30417 .46635 Metetra
.664 .741 .908 r
.30417 .46635 .30969 .47163 .31833 .46877 .31282 .46348 Metetra
.664 .741 .908 r
.31282 .46348 .31833 .46877 .32699 .46591 .3215 .4606 Metetra
.664 .741 .908 r
.3215 .4606 .32699 .46591 .33569 .46304 .33021 .45771 Metetra
.664 .741 .908 r
.33021 .45771 .33569 .46304 .34441 .46015 .33895 .45481 Metetra
.664 .741 .908 r
.33895 .45481 .34441 .46015 .35316 .45726 .34772 .4519 Metetra
.664 .741 .908 r
.34772 .4519 .35316 .45726 .36194 .45436 .35652 .44898 Metetra
.66 .74 .909 r
.35652 .44898 .36194 .45436 .37074 .45171 .36534 .44613 Metetra
.66 .733 .904 r
.36534 .44613 .37074 .45171 .37956 .44911 .3742 .44328 Metetra
.614 .71 .914 r
.3742 .44328 .37956 .44911 .38838 .44733 .38303 .44144 Metetra
.602 .705 .916 r
.38303 .44144 .38838 .44733 .39723 .44574 .3919 .43984 Metetra
.622 .712 .91 r
.3919 .43984 .39723 .44574 .40614 .44355 .40081 .4378 Metetra
.628 .72 .913 r
.40081 .4378 .40614 .44355 .41509 .44118 .40977 .43564 Metetra
.627 .728 .92 r
.40977 .43564 .41509 .44118 .42407 .4388 .41876 .43347 Metetra
.625 .737 .927 r
.41876 .43347 .42407 .4388 .43308 .43642 .42778 .43129 Metetra
.649 .753 .925 r
.42778 .43129 .43308 .43642 .44213 .43383 .43686 .42859 Metetra
.659 .752 .919 r
.43686 .42859 .44213 .43383 .45122 .43115 .44597 .42567 Metetra
.634 .736 .921 r
.44597 .42567 .45122 .43115 .46033 .42886 .4551 .42329 Metetra
.622 .729 .923 r
.4551 .42329 .46033 .42886 .46947 .42676 .46426 .42117 Metetra
.619 .728 .924 r
.46426 .42117 .46947 .42676 .47865 .42412 .47345 .41909 Metetra
.613 .749 .942 r
.47345 .41909 .47865 .42412 .48788 .42118 .48269 .41703 Metetra
.566 .773 .976 r
.48269 .41703 .48788 .42118 .49712 .41929 .49195 .41547 Metetra
.531 .776 .987 r
.49195 .41547 .49712 .41929 .5064 .41806 .50125 .41423 Metetra
.531 .776 .987 r
.50125 .41423 .5064 .41806 .51572 .41683 .51059 .41298 Metetra
.531 .776 .987 r
.51059 .41298 .51572 .41683 .52508 .41559 .51998 .41173 Metetra
.54 .779 .986 r
.51998 .41173 .52508 .41559 .53449 .41336 .52941 .41036 Metetra
.511 .809 .999 r
.52941 .41036 .53449 .41336 .54392 .41032 .53888 .40889 Metetra
.49 .867 .979 r
.53888 .40889 .54392 .41032 .55339 .40725 .54839 .40657 Metetra
.508 .897 .949 r
.54839 .40657 .55339 .40725 .56289 .40414 .55793 .40344 Metetra
.587 .929 .954 r
.55793 .40344 .56289 .40414 .57242 .40099 .56748 .39951 Metetra
.694 .936 .964 r
.56748 .39951 .57242 .40099 .58199 .39781 .57706 .39471 Metetra
.73 .875 .949 r
.57706 .39471 .58199 .39781 .59157 .3938 .58665 .38982 Metetra
.736 .837 .927 r
.58665 .38982 .59157 .3938 .60115 .3888 .59627 .38479 Metetra
.736 .837 .927 r
.59627 .38479 .60115 .3888 .61076 .38379 .60591 .37976 Metetra
.736 .837 .927 r
.60591 .37976 .61076 .38379 .62039 .37877 .61557 .37472 Metetra
.724 .835 .933 r
.61557 .37472 .62039 .37877 .63006 .37442 .62526 .36998 Metetra
.703 .815 .934 r
.62526 .36998 .63006 .37442 .6398 .37112 .635 .36576 Metetra
.701 .777 .91 r
.635 .36576 .6398 .37112 .64956 .36751 .64476 .36155 Metetra
.697 .754 .895 r
.64476 .36155 .64956 .36751 .65933 .36336 .65456 .35738 Metetra
.688 .751 .899 r
.65456 .35738 .65933 .36336 .66914 .3594 .66439 .35346 Metetra
.667 .746 .909 r
.66439 .35346 .66914 .3594 .679 .35582 .67428 .35009 Metetra
.675 .758 .913 r
.67428 .35009 .679 .35582 .68888 .35216 .6842 .3465 Metetra
.695 .768 .908 r
.6842 .3465 .68888 .35216 .69879 .34828 .69412 .34238 Metetra
.694 .759 .902 r
.69412 .34238 .69879 .34828 .70873 .3444 .70407 .33824 Metetra
.693 .751 .895 r
.70407 .33824 .70873 .3444 .7187 .3405 .71405 .33409 Metetra
.697 .744 .888 r
.71405 .33409 .7187 .3405 .72869 .33641 .72405 .3298 Metetra
.709 .742 .877 r
.72405 .3298 .72869 .33641 .73867 .3317 .73406 .32507 Metetra
.702 .74 .881 r
.73406 .32507 .73867 .3317 .74868 .32718 .74411 .32058 Metetra
.667 .728 .895 r
.74411 .32058 .74868 .32718 .7588 .32351 .75426 .31711 Metetra
.666 .736 .902 r
.75426 .31711 .7588 .32351 .76894 .31988 .76445 .31365 Metetra
.664 .741 .908 r
.76445 .31365 .76894 .31988 .77915 .31651 .77468 .31025 Metetra
.664 .741 .908 r
.77468 .31025 .77915 .31651 .78939 .31313 .78494 .30685 Metetra
.664 .741 .908 r
.78494 .30685 .78939 .31313 .79967 .30973 .79525 .30343 Metetra
.664 .741 .908 r
.79525 .30343 .79967 .30973 .80998 .30632 .80559 .3 Metetra
.664 .741 .908 r
.80559 .3 .80998 .30632 .82034 .3029 .81597 .29656 Metetra
.664 .741 .908 r
.81597 .29656 .82034 .3029 .83072 .29947 .82638 .2931 Metetra
.664 .741 .908 r
.82638 .2931 .83072 .29947 .84115 .29603 .83683 .28963 Metetra
.664 .741 .908 r
.83683 .28963 .84115 .29603 .85161 .29257 .84732 .28615 Metetra
.664 .741 .908 r
.84732 .28615 .85161 .29257 .86211 .2891 .85785 .28266 Metetra
.664 .741 .908 r
.85785 .28266 .86211 .2891 .87265 .28562 .86842 .27915 Metetra
.664 .741 .908 r
.2642 .4725 .26983 .47774 .27837 .47491 .27276 .46965 Metetra
.664 .741 .908 r
.27276 .46965 .27837 .47491 .28694 .47206 .28135 .46679 Metetra
.664 .741 .908 r
.28135 .46679 .28694 .47206 .29554 .46921 .28996 .46392 Metetra
.664 .741 .908 r
.28996 .46392 .29554 .46921 .30417 .46635 .29861 .46104 Metetra
.664 .741 .908 r
.29861 .46104 .30417 .46635 .31282 .46348 .30728 .45815 Metetra
.664 .741 .908 r
.30728 .45815 .31282 .46348 .3215 .4606 .31598 .45526 Metetra
.664 .741 .908 r
.31598 .45526 .3215 .4606 .33021 .45771 .32471 .45235 Metetra
.664 .741 .908 r
.32471 .45235 .33021 .45771 .33895 .45481 .33346 .44943 Metetra
.664 .741 .908 r
.33346 .44943 .33895 .45481 .34772 .4519 .34225 .4465 Metetra
.664 .741 .908 r
.34225 .4465 .34772 .4519 .35652 .44898 .35107 .44357 Metetra
.664 .741 .908 r
.35107 .44357 .35652 .44898 .36534 .44613 .35991 .44062 Metetra
.664 .738 .906 r
.35991 .44062 .36534 .44613 .3742 .44328 .36878 .43766 Metetra
.618 .721 .919 r
.36878 .43766 .3742 .44328 .38303 .44144 .37764 .43568 Metetra
.607 .713 .919 r
.37764 .43568 .38303 .44144 .3919 .43984 .38653 .43393 Metetra
.61 .709 .915 r
.38653 .43393 .3919 .43984 .40081 .4378 .39545 .43212 Metetra
.61 .718 .922 r
.39545 .43212 .40081 .4378 .40977 .43564 .40441 .43029 Metetra
.627 .737 .927 r
.40441 .43029 .40977 .43564 .41876 .43347 .41342 .42807 Metetra
.634 .738 .924 r
.41342 .42807 .41876 .43347 .42778 .43129 .42247 .42571 Metetra
.643 .735 .916 r
.42247 .42571 .42778 .43129 .43686 .42859 .43156 .42315 Metetra
.646 .742 .919 r
.43156 .42315 .43686 .42859 .44597 .42567 .44068 .42051 Metetra
.632 .749 .932 r
.44068 .42051 .44597 .42567 .4551 .42329 .44983 .41812 Metetra
.626 .748 .935 r
.44983 .41812 .4551 .42329 .46426 .42117 .45901 .41585 Metetra
.593 .731 .94 r
.45901 .41585 .46426 .42117 .47345 .41909 .46822 .4142 Metetra
.565 .74 .958 r
.46822 .4142 .47345 .41909 .48269 .41703 .47746 .4129 Metetra
.543 .766 .98 r
.47746 .4129 .48269 .41703 .49195 .41547 .48674 .41162 Metetra
.531 .776 .987 r
.48674 .41162 .49195 .41547 .50125 .41423 .49607 .41037 Metetra
.473 .751 .99 r
.49607 .41037 .50125 .41423 .51059 .41298 .50543 .4098 Metetra
.381 .74 .991 r
.50543 .4098 .51059 .41298 .51998 .41173 .51484 .40972 Metetra
.246 .715 .944 r
.51484 .40972 .51998 .41173 .52941 .41036 .52429 .40982 Metetra
.035 .603 .77 r
.52429 .40982 .52941 .41036 .53888 .40889 .5338 .41007 Metetra
.5338 .41007 .53888 .40889 .54839 .40657 .54336 .40858 Metetra
.54336 .40858 .54839 .40657 .55793 .40344 .55294 .40544 Metetra
.383 .828 .705 r
.55294 .40544 .55793 .40344 .56748 .39951 .56253 .40064 Metetra
.655 .971 .84 r
.56253 .40064 .56748 .39951 .57706 .39471 .57213 .39409 Metetra
.752 .974 .924 r
.57213 .39409 .57706 .39471 .58665 .38982 .58174 .38768 Metetra
.776 .924 .934 r
.58174 .38768 .58665 .38982 .59627 .38479 .59137 .38145 Metetra
.762 .871 .928 r
.59137 .38145 .59627 .38479 .60591 .37976 .60102 .3757 Metetra
.736 .837 .927 r
.60102 .3757 .60591 .37976 .61557 .37472 .61071 .37063 Metetra
.735 .837 .927 r
.61071 .37063 .61557 .37472 .62526 .36998 .62043 .36557 Metetra
.733 .824 .921 r
.62043 .36557 .62526 .36998 .635 .36576 .63017 .36054 Metetra
.718 .789 .908 r
.63017 .36054 .635 .36576 .64476 .36155 .63994 .35586 Metetra
.694 .764 .906 r
.63994 .35586 .64476 .36155 .65456 .35738 .64977 .3518 Metetra
.689 .768 .912 r
.64977 .3518 .65456 .35738 .66439 .35346 .65963 .34785 Metetra
.679 .764 .915 r
.65963 .34785 .66439 .35346 .67428 .35009 .66953 .34416 Metetra
.681 .754 .906 r
.66953 .34416 .67428 .35009 .6842 .3465 .67946 .34038 Metetra
.688 .75 .899 r
.67946 .34038 .6842 .3465 .69412 .34238 .68942 .33641 Metetra
.693 .758 .901 r
.68942 .33641 .69412 .34238 .70407 .33824 .6994 .33228 Metetra
.707 .763 .896 r
.6994 .33228 .70407 .33824 .71405 .33409 .70938 .32775 Metetra
.705 .75 .887 r
.70938 .32775 .71405 .33409 .72405 .3298 .71939 .32319 Metetra
.705 .742 .88 r
.71939 .32319 .72405 .3298 .73406 .32507 .72943 .31856 Metetra
.698 .744 .887 r
.72943 .31856 .73406 .32507 .74411 .32058 .73951 .31417 Metetra
.663 .735 .903 r
.73951 .31417 .74411 .32058 .75426 .31711 .7497 .31078 Metetra
.664 .738 .906 r
.7497 .31078 .75426 .31711 .76445 .31365 .75992 .30737 Metetra
.664 .741 .908 r
.75992 .30737 .76445 .31365 .77468 .31025 .77017 .30396 Metetra
.664 .741 .908 r
.77017 .30396 .77468 .31025 .78494 .30685 .78047 .30053 Metetra
.664 .741 .908 r
.78047 .30053 .78494 .30685 .79525 .30343 .7908 .29709 Metetra
.664 .741 .908 r
.7908 .29709 .79525 .30343 .80559 .3 .80116 .29363 Metetra
.664 .741 .908 r
.80116 .29363 .80559 .3 .81597 .29656 .81157 .29017 Metetra
.664 .741 .908 r
.81157 .29017 .81597 .29656 .82638 .2931 .82201 .28669 Metetra
.664 .741 .908 r
.82201 .28669 .82638 .2931 .83683 .28963 .83249 .2832 Metetra
.664 .741 .908 r
.83249 .2832 .83683 .28963 .84732 .28615 .84301 .27969 Metetra
.664 .741 .908 r
.84301 .27969 .84732 .28615 .85785 .28266 .85356 .27618 Metetra
.664 .741 .908 r
.85356 .27618 .85785 .28266 .86842 .27915 .86416 .27265 Metetra
.664 .741 .908 r
.25854 .46723 .2642 .4725 .27276 .46965 .26712 .46436 Metetra
.664 .741 .908 r
.26712 .46436 .27276 .46965 .28135 .46679 .27572 .46149 Metetra
.664 .741 .908 r
.27572 .46149 .28135 .46679 .28996 .46392 .28435 .4586 Metetra
.664 .741 .908 r
.28435 .4586 .28996 .46392 .29861 .46104 .29301 .4557 Metetra
.664 .741 .908 r
.29301 .4557 .29861 .46104 .30728 .45815 .3017 .4528 Metetra
.664 .741 .908 r
.3017 .4528 .30728 .45815 .31598 .45526 .31042 .44988 Metetra
.664 .741 .908 r
.31042 .44988 .31598 .45526 .32471 .45235 .31916 .44695 Metetra
.664 .741 .908 r
.31916 .44695 .32471 .45235 .33346 .44943 .32794 .44402 Metetra
.664 .741 .908 r
.32794 .44402 .33346 .44943 .34225 .4465 .33674 .44107 Metetra
.664 .741 .908 r
.33674 .44107 .34225 .4465 .35107 .44357 .34558 .43812 Metetra
.664 .741 .908 r
.34558 .43812 .35107 .44357 .35991 .44062 .35444 .43516 Metetra
.664 .741 .908 r
.35444 .43516 .35991 .44062 .36878 .43766 .36333 .43218 Metetra
.627 .73 .922 r
.36333 .43218 .36878 .43766 .37764 .43568 .37222 .43 Metetra
.618 .721 .919 r
.37222 .43 .37764 .43568 .38653 .43393 .38113 .42801 Metetra
.595 .704 .919 r
.38113 .42801 .38653 .43393 .39545 .43212 .39005 .42648 Metetra
.585 .712 .93 r
.39005 .42648 .39545 .43212 .40441 .43029 .39901 .42508 Metetra
.637 .747 .928 r
.39901 .42508 .40441 .43029 .41342 .42807 .40805 .42263 Metetra
.654 .744 .916 r
.40805 .42263 .41342 .42807 .42247 .42571 .41713 .4198 Metetra
.628 .719 .912 r
.41713 .4198 .42247 .42571 .43156 .42315 .42622 .41757 Metetra
.614 .727 .926 r
.42622 .41757 .43156 .42315 .44068 .42051 .43535 .41558 Metetra
.627 .758 .941 r
.43535 .41558 .44068 .42051 .44983 .41812 .44452 .41324 Metetra
.635 .764 .941 r
.44452 .41324 .44983 .41812 .45901 .41585 .45372 .41073 Metetra
.569 .731 .951 r
.45372 .41073 .45901 .41585 .46822 .4142 .46294 .40942 Metetra
.514 .725 .969 r
.46294 .40942 .46822 .4142 .47746 .4129 .47219 .40877 Metetra
.522 .76 .983 r
.47219 .40877 .47746 .4129 .48674 .41162 .48149 .40775 Metetra
.531 .776 .987 r
.48149 .40775 .48674 .41162 .49607 .41037 .49084 .40648 Metetra
.355 .693 .982 r
.49084 .40648 .49607 .41037 .50543 .4098 .50022 .40708 Metetra
.063 .566 .886 r
.50022 .40708 .50543 .4098 .51484 .40972 .50964 .40905 Metetra
.2 0 0 r
.50964 .40905 .51484 .40972 .52429 .40982 .51913 .41108 Metetra
.374 0 0 r
.51913 .41108 .52429 .40982 .5338 .41007 .52867 .41317 Metetra
.24 0 0 r
.52867 .41317 .5338 .41007 .54336 .40858 .53828 .41257 Metetra
.053 0 0 r
.53828 .41257 .54336 .40858 .55294 .40544 .54791 .40942 Metetra
.54791 .40942 .55294 .40544 .56253 .40064 .55755 .40371 Metetra
.615 .925 .681 r
.55755 .40371 .56253 .40064 .57213 .39409 .56717 .39528 Metetra
.767 .997 .829 r
.56717 .39528 .57213 .39409 .58174 .38768 .5768 .3869 Metetra
.834 .97 .887 r
.5768 .3869 .58174 .38768 .59137 .38145 .58643 .37857 Metetra
.802 .895 .909 r
.58643 .37857 .59137 .38145 .60102 .3757 .5961 .3716 Metetra
.736 .837 .927 r
.5961 .3716 .60102 .3757 .61071 .37063 .60582 .36651 Metetra
.745 .839 .922 r
.60582 .36651 .61071 .37063 .62043 .36557 .61556 .36116 Metetra
.757 .83 .909 r
.61556 .36116 .62043 .36557 .63017 .36054 .62531 .35543 Metetra
.731 .797 .905 r
.62531 .35543 .63017 .36054 .63994 .35586 .6351 .35036 Metetra
.685 .77 .916 r
.6351 .35036 .63994 .35586 .64977 .3518 .64496 .3465 Metetra
.692 .781 .919 r
.64496 .3465 .64977 .3518 .65963 .34785 .65484 .34247 Metetra
.705 .783 .912 r
.65484 .34247 .65963 .34785 .66953 .34416 .66474 .33807 Metetra
.694 .753 .898 r
.66474 .33807 .66953 .34416 .67946 .34038 .67468 .33392 Metetra
.67 .733 .897 r
.67468 .33392 .67946 .34038 .68942 .33641 .68468 .33038 Metetra
.685 .754 .904 r
.68468 .33038 .68942 .33641 .6994 .33228 .6947 .32645 Metetra
.723 .775 .894 r
.6947 .32645 .6994 .33228 .70938 .32775 .70469 .32144 Metetra
.715 .756 .885 r
.70469 .32144 .70938 .32775 .71939 .32319 .71471 .31655 Metetra
.698 .74 .884 r
.71471 .31655 .71939 .32319 .72943 .31856 .72478 .31213 Metetra
.693 .746 .892 r
.72478 .31213 .72943 .31856 .73951 .31417 .7349 .3079 Metetra
.664 .741 .908 r
.7349 .3079 .73951 .31417 .7497 .31078 .74511 .30448 Metetra
.664 .741 .908 r
.74511 .30448 .7497 .31078 .75992 .30737 .75536 .30106 Metetra
.664 .741 .908 r
.75536 .30106 .75992 .30737 .77017 .30396 .76564 .29762 Metetra
.664 .741 .908 r
.76564 .29762 .77017 .30396 .78047 .30053 .77596 .29417 Metetra
.664 .741 .908 r
.77596 .29417 .78047 .30053 .7908 .29709 .78632 .2907 Metetra
.664 .741 .908 r
.78632 .2907 .7908 .29709 .80116 .29363 .79671 .28723 Metetra
.664 .741 .908 r
.79671 .28723 .80116 .29363 .81157 .29017 .80714 .28374 Metetra
.664 .741 .908 r
.80714 .28374 .81157 .29017 .82201 .28669 .81761 .28023 Metetra
.664 .741 .908 r
.81761 .28023 .82201 .28669 .83249 .2832 .82812 .27672 Metetra
.664 .741 .908 r
.82812 .27672 .83249 .2832 .84301 .27969 .83866 .27319 Metetra
.664 .741 .908 r
.83866 .27319 .84301 .27969 .85356 .27618 .84924 .26965 Metetra
.664 .741 .908 r
.84924 .26965 .85356 .27618 .86416 .27265 .85987 .2661 Metetra
.664 .741 .908 r
.25285 .46193 .25854 .46723 .26712 .46436 .26144 .45904 Metetra
.664 .741 .908 r
.26144 .45904 .26712 .46436 .27572 .46149 .27006 .45615 Metetra
.664 .741 .908 r
.27006 .45615 .27572 .46149 .28435 .4586 .27871 .45324 Metetra
.664 .741 .908 r
.27871 .45324 .28435 .4586 .29301 .4557 .28738 .45033 Metetra
.664 .741 .908 r
.28738 .45033 .29301 .4557 .3017 .4528 .29609 .4474 Metetra
.664 .741 .908 r
.29609 .4474 .3017 .4528 .31042 .44988 .30483 .44447 Metetra
.664 .741 .908 r
.30483 .44447 .31042 .44988 .31916 .44695 .31359 .44153 Metetra
.664 .741 .908 r
.31359 .44153 .31916 .44695 .32794 .44402 .32238 .43857 Metetra
.664 .741 .908 r
.32238 .43857 .32794 .44402 .33674 .44107 .3312 .43561 Metetra
.664 .741 .908 r
.3312 .43561 .33674 .44107 .34558 .43812 .34006 .43264 Metetra
.664 .741 .908 r
.34006 .43264 .34558 .43812 .35444 .43516 .34894 .42966 Metetra
.664 .741 .908 r
.34894 .42966 .35444 .43516 .36333 .43218 .35785 .42666 Metetra
.64 .734 .917 r
.35785 .42666 .36333 .43218 .37222 .43 .36676 .42419 Metetra
.635 .722 .911 r
.36676 .42419 .37222 .43 .38113 .42801 .3757 .42184 Metetra
.578 .689 .917 r
.3757 .42184 .38113 .42801 .39005 .42648 .38463 .42065 Metetra
.553 .694 .933 r
.38463 .42065 .39005 .42648 .39901 .42508 .39358 .4198 Metetra
.642 .747 .926 r
.39358 .4198 .39901 .42508 .40805 .42263 .40264 .41724 Metetra
.668 .751 .913 r
.40264 .41724 .40805 .42263 .41713 .4198 .41175 .41407 Metetra
.617 .723 .922 r
.41175 .41407 .41713 .4198 .42622 .41757 .42086 .41203 Metetra
.591 .722 .935 r
.42086 .41203 .42622 .41757 .43535 .41558 .42999 .41045 Metetra
.62 .749 .939 r
.42999 .41045 .43535 .41558 .44452 .41324 .43917 .40824 Metetra
.634 .76 .938 r
.43917 .40824 .44452 .41324 .45372 .41073 .4484 .40573 Metetra
.573 .74 .955 r
.4484 .40573 .45372 .41073 .46294 .40942 .45764 .4043 Metetra
.536 .721 .958 r
.45764 .4043 .46294 .40942 .47219 .40877 .46691 .40344 Metetra
.522 .706 .955 r
.46691 .40344 .47219 .40877 .48149 .40775 .47622 .40286 Metetra
.496 .716 .969 r
.47622 .40286 .48149 .40775 .49084 .40648 .48558 .40245 Metetra
.188 .592 .943 r
.48558 .40245 .49084 .40648 .50022 .40708 .49496 .40453 Metetra
0 .343 .702 r
.49496 .40453 .50022 .40708 .50964 .40905 .50439 .40843 Metetra
.824 .356 .09 r
.50439 .40843 .50964 .40905 .51913 .41108 .51386 .42291 Metetra
.799 .447 .39 r
.51386 .42291 .51913 .41108 .52867 .41317 .52347 .44646 Metetra
.618 .325 .45 r
.52347 .44646 .52867 .41317 .53828 .41257 .53323 .45641 Metetra
.507 .243 .448 r
.53323 .45641 .53828 .41257 .54791 .40942 .54304 .45328 Metetra
.372 .131 .414 r
.54304 .45328 .54791 .40942 .55755 .40371 .55276 .43702 Metetra
.016 0 .261 r
.55276 .43702 .55755 .40371 .56717 .39528 .56229 .40708 Metetra
.56229 .40708 .56717 .39528 .5768 .3869 .57182 .38616 Metetra
.883 .959 .845 r
.57182 .38616 .5768 .3869 .58643 .37857 .58146 .37585 Metetra
.842 .9 .879 r
.58146 .37585 .58643 .37857 .5961 .3716 .59113 .36736 Metetra
.766 .837 .907 r
.59113 .36736 .5961 .3716 .60582 .36651 .60086 .36137 Metetra
.754 .801 .89 r
.60086 .36137 .60582 .36651 .61556 .36116 .61062 .35553 Metetra
.742 .781 .884 r
.61062 .35553 .61556 .36116 .62531 .35543 .6204 .34996 Metetra
.725 .784 .899 r
.6204 .34996 .62531 .35543 .6351 .35036 .63022 .34499 Metetra
.687 .777 .92 r
.63022 .34499 .6351 .35036 .64496 .3465 .64011 .34109 Metetra
.698 .78 .915 r
.64011 .34109 .64496 .3465 .65484 .34247 .65002 .33687 Metetra
.719 .78 .9 r
.65002 .33687 .65484 .34247 .66474 .33807 .65992 .33202 Metetra
.701 .759 .897 r
.65992 .33202 .66474 .33807 .67468 .33392 .66988 .32763 Metetra
.658 .736 .907 r
.66988 .32763 .67468 .33392 .68468 .33038 .67992 .3244 Metetra
.682 .757 .908 r
.67992 .3244 .68468 .33038 .6947 .32645 .68997 .32054 Metetra
.74 .779 .884 r
.68997 .32054 .6947 .32645 .70469 .32144 .69995 .31493 Metetra
.725 .754 .875 r
.69995 .31493 .70469 .32144 .71471 .31655 .70998 .30965 Metetra
.686 .728 .882 r
.70998 .30965 .71471 .31655 .72478 .31213 .7201 .30556 Metetra
.683 .739 .893 r
.7201 .30556 .72478 .31213 .7349 .3079 .73026 .30158 Metetra
.664 .741 .908 r
.73026 .30158 .7349 .3079 .74511 .30448 .7405 .29815 Metetra
.664 .741 .908 r
.7405 .29815 .74511 .30448 .75536 .30106 .75077 .2947 Metetra
.664 .741 .908 r
.75077 .2947 .75536 .30106 .76564 .29762 .76108 .29124 Metetra
.664 .741 .908 r
.76108 .29124 .76564 .29762 .77596 .29417 .77142 .28776 Metetra
.664 .741 .908 r
.77142 .28776 .77596 .29417 .78632 .2907 .7818 .28427 Metetra
.664 .741 .908 r
.7818 .28427 .78632 .2907 .79671 .28723 .79222 .28077 Metetra
.664 .741 .908 r
.79222 .28077 .79671 .28723 .80714 .28374 .80268 .27726 Metetra
.664 .741 .908 r
.80268 .27726 .80714 .28374 .81761 .28023 .81318 .27374 Metetra
.664 .741 .908 r
.81318 .27374 .81761 .28023 .82812 .27672 .82371 .2702 Metetra
.664 .741 .908 r
.82371 .2702 .82812 .27672 .83866 .27319 .83429 .26665 Metetra
.664 .741 .908 r
.83429 .26665 .83866 .27319 .84924 .26965 .8449 .26308 Metetra
.664 .741 .908 r
.8449 .26308 .84924 .26965 .85987 .2661 .85555 .25951 Metetra
.664 .741 .908 r
.24712 .45659 .25285 .46193 .26144 .45904 .25573 .45369 Metetra
.664 .741 .908 r
.25573 .45369 .26144 .45904 .27006 .45615 .26436 .45078 Metetra
.664 .741 .908 r
.26436 .45078 .27006 .45615 .27871 .45324 .27303 .44786 Metetra
.664 .741 .908 r
.27303 .44786 .27871 .45324 .28738 .45033 .28172 .44492 Metetra
.664 .741 .908 r
.28172 .44492 .28738 .45033 .29609 .4474 .29045 .44198 Metetra
.664 .741 .908 r
.29045 .44198 .29609 .4474 .30483 .44447 .2992 .43903 Metetra
.664 .741 .908 r
.2992 .43903 .30483 .44447 .31359 .44153 .30798 .43607 Metetra
.664 .741 .908 r
.30798 .43607 .31359 .44153 .32238 .43857 .31679 .4331 Metetra
.664 .741 .908 r
.31679 .4331 .32238 .43857 .3312 .43561 .32563 .43012 Metetra
.664 .741 .908 r
.32563 .43012 .3312 .43561 .34006 .43264 .3345 .42712 Metetra
.664 .741 .908 r
.3345 .42712 .34006 .43264 .34894 .42966 .3434 .42412 Metetra
.664 .741 .908 r
.3434 .42412 .34894 .42966 .35785 .42666 .35233 .42111 Metetra
.656 .739 .911 r
.35233 .42111 .35785 .42666 .36676 .42419 .36128 .41826 Metetra
.654 .726 .901 r
.36128 .41826 .36676 .42419 .3757 .42184 .37026 .41545 Metetra
.556 .674 .917 r
.37026 .41545 .3757 .42184 .38463 .42065 .37918 .41466 Metetra
.512 .672 .936 r
.37918 .41466 .38463 .42065 .39358 .4198 .38811 .41447 Metetra
.641 .746 .925 r
.38811 .41447 .39358 .4198 .40264 .41724 .39719 .41189 Metetra
.678 .757 .911 r
.39719 .41189 .40264 .41724 .41175 .41407 .40633 .40847 Metetra
.611 .728 .928 r
.40633 .40847 .41175 .41407 .42086 .41203 .41545 .40651 Metetra
.577 .719 .94 r
.41545 .40651 .42086 .41203 .42999 .41045 .42459 .40514 Metetra
.609 .74 .938 r
.42459 .40514 .42999 .41045 .43917 .40824 .43379 .40314 Metetra
.623 .754 .94 r
.43379 .40314 .43917 .40824 .4484 .40573 .44303 .40084 Metetra
.601 .756 .952 r
.44303 .40084 .4484 .40573 .45764 .4043 .4523 .39888 Metetra
.596 .733 .94 r
.4523 .39888 .45764 .4043 .46691 .40344 .46161 .39711 Metetra
.502 .658 .93 r
.46161 .39711 .46691 .40344 .47622 .40286 .47093 .39713 Metetra
.397 .633 .949 r
.47093 .39713 .47622 .40286 .48558 .40245 .48028 .3983 Metetra
0 .442 .852 r
.48028 .3983 .48558 .40245 .49496 .40453 .48966 .4021 Metetra
.444 0 0 r
.48966 .4021 .49496 .40453 .50439 .40843 .4991 .40785 Metetra
.922 .554 .308 r
.4991 .40785 .50439 .40843 .51386 .42291 .50847 .44381 Metetra
.86 .547 .456 r
.50847 .44381 .51386 .42291 .52347 .44646 .51805 .5067 Metetra
.669 .394 .495 r
.51805 .5067 .52347 .44646 .53323 .45641 .52803 .53655 Metetra
.525 .28 .486 r
.52803 .53655 .53323 .45641 .54304 .45328 .53812 .53347 Metetra
.331 .125 .441 r
.53812 .53347 .54304 .45328 .55276 .43702 .54801 .49737 Metetra
0 0 .228 r
.54801 .49737 .55276 .43702 .56229 .40708 .55741 .42798 Metetra
.733 .717 .187 r
.55741 .42798 .56229 .40708 .57182 .38616 .56678 .38547 Metetra
.914 .944 .808 r
.56678 .38547 .57182 .38616 .58146 .37585 .57645 .37326 Metetra
.876 .897 .843 r
.57645 .37326 .58146 .37585 .59113 .36736 .58613 .363 Metetra
.807 .837 .873 r
.58613 .363 .59113 .36736 .60086 .36137 .59586 .35537 Metetra
.763 .774 .862 r
.59586 .35537 .60086 .36137 .61062 .35553 .60562 .34889 Metetra
.708 .738 .875 r
.60562 .34889 .61062 .35553 .6204 .34996 .61545 .34421 Metetra
.707 .769 .901 r
.61545 .34421 .6204 .34996 .63022 .34499 .62532 .33971 Metetra
.696 .785 .92 r
.62532 .33971 .63022 .34499 .64011 .34109 .63523 .33556 Metetra
.706 .779 .909 r
.63523 .33556 .64011 .34109 .65002 .33687 .64515 .3311 Metetra
.726 .777 .893 r
.64515 .3311 .65002 .33687 .65992 .33202 .65508 .32599 Metetra
.705 .762 .897 r
.65508 .32599 .65992 .33202 .66988 .32763 .66506 .32149 Metetra
.649 .739 .915 r
.66506 .32149 .66988 .32763 .67992 .3244 .67513 .31846 Metetra
.682 .76 .91 r
.67513 .31846 .67992 .3244 .68997 .32054 .68521 .31457 Metetra
.759 .783 .872 r
.68521 .31457 .68997 .32054 .69995 .31493 .69518 .30824 Metetra
.736 .753 .866 r
.69518 .30824 .69995 .31493 .70998 .30965 .70521 .30251 Metetra
.67 .716 .883 r
.70521 .30251 .70998 .30965 .7201 .30556 .71538 .29886 Metetra
.67 .731 .896 r
.71538 .29886 .7201 .30556 .73026 .30158 .72559 .29523 Metetra
.664 .741 .908 r
.72559 .29523 .73026 .30158 .7405 .29815 .73585 .29177 Metetra
.664 .741 .908 r
.73585 .29177 .7405 .29815 .75077 .2947 .74615 .2883 Metetra
.664 .741 .908 r
.74615 .2883 .75077 .2947 .76108 .29124 .75648 .28481 Metetra
.664 .741 .908 r
.75648 .28481 .76108 .29124 .77142 .28776 .76685 .28131 Metetra
.664 .741 .908 r
.76685 .28131 .77142 .28776 .7818 .28427 .77726 .2778 Metetra
.664 .741 .908 r
.77726 .2778 .7818 .28427 .79222 .28077 .78771 .27428 Metetra
.664 .741 .908 r
.78771 .27428 .79222 .28077 .80268 .27726 .7982 .27074 Metetra
.664 .741 .908 r
.7982 .27074 .80268 .27726 .81318 .27374 .80872 .2672 Metetra
.664 .741 .908 r
.80872 .2672 .81318 .27374 .82371 .2702 .81928 .26363 Metetra
.664 .741 .908 r
.81928 .26363 .82371 .2702 .83429 .26665 .82988 .26006 Metetra
.664 .741 .908 r
.82988 .26006 .83429 .26665 .8449 .26308 .84052 .25647 Metetra
.664 .741 .908 r
.84052 .25647 .8449 .26308 .85555 .25951 .8512 .25287 Metetra
.664 .741 .908 r
.24135 .45123 .24712 .45659 .25573 .45369 .24998 .44831 Metetra
.664 .741 .908 r
.24998 .44831 .25573 .45369 .26436 .45078 .25863 .44537 Metetra
.664 .741 .908 r
.25863 .44537 .26436 .45078 .27303 .44786 .26732 .44243 Metetra
.664 .741 .908 r
.26732 .44243 .27303 .44786 .28172 .44492 .27603 .43948 Metetra
.664 .741 .908 r
.27603 .43948 .28172 .44492 .29045 .44198 .28477 .43652 Metetra
.664 .741 .908 r
.28477 .43652 .29045 .44198 .2992 .43903 .29354 .43355 Metetra
.664 .741 .908 r
.29354 .43355 .2992 .43903 .30798 .43607 .30234 .43057 Metetra
.664 .741 .908 r
.30234 .43057 .30798 .43607 .31679 .4331 .31116 .42759 Metetra
.664 .741 .908 r
.31116 .42759 .31679 .4331 .32563 .43012 .32002 .42459 Metetra
.664 .741 .908 r
.32002 .42459 .32563 .43012 .3345 .42712 .32891 .42158 Metetra
.664 .741 .908 r
.32891 .42158 .3345 .42712 .3434 .42412 .33783 .41856 Metetra
.664 .741 .908 r
.33783 .41856 .3434 .42412 .35233 .42111 .34677 .41553 Metetra
.664 .741 .908 r
.34677 .41553 .35233 .42111 .36128 .41826 .35575 .41249 Metetra
.663 .735 .903 r
.35575 .41249 .36128 .41826 .37026 .41545 .36476 .40943 Metetra
.538 .682 .932 r
.36476 .40943 .37026 .41545 .37918 .41466 .37368 .40883 Metetra
.484 .667 .944 r
.37368 .40883 .37918 .41466 .38811 .41447 .38262 .40895 Metetra
.642 .741 .921 r
.38262 .40895 .38811 .41447 .39719 .41189 .39172 .40636 Metetra
.682 .752 .905 r
.39172 .40636 .39719 .41189 .40633 .40847 .40088 .40281 Metetra
.609 .726 .928 r
.40088 .40281 .40633 .40847 .41545 .40651 .41002 .40088 Metetra
.572 .714 .938 r
.41002 .40088 .41545 .40651 .42459 .40514 .41917 .3996 Metetra
.605 .73 .933 r
.41917 .3996 .42459 .40514 .43379 .40314 .42838 .39769 Metetra
.62 .74 .932 r
.42838 .39769 .43379 .40314 .44303 .40084 .43764 .39548 Metetra
.619 .744 .936 r
.43764 .39548 .44303 .40084 .4523 .39888 .44694 .39326 Metetra
.621 .735 .928 r
.44694 .39326 .4523 .39888 .46161 .39711 .45627 .39104 Metetra
.474 .657 .941 r
.45627 .39104 .46161 .39711 .47093 .39713 .4656 .39134 Metetra
.329 .595 .943 r
.4656 .39134 .47093 .39713 .48028 .3983 .47495 .39326 Metetra
0 .396 .84 r
.47495 .39326 .48028 .3983 .48966 .4021 .48433 .3979 Metetra
0 .168 .625 r
.48433 .3979 .48966 .4021 .4991 .40785 .49377 .40454 Metetra
.944 .593 .314 r
.49377 .40454 .4991 .40785 .50847 .44381 .50304 .4511 Metetra
.926 .608 .422 r
.50304 .4511 .50847 .44381 .51805 .5067 .5125 .53395 Metetra
.787 .473 .458 r
.5125 .53395 .51805 .5067 .52803 .53655 .52254 .57416 Metetra
.497 .221 .425 r
.52254 .57416 .52803 .53655 .53812 .53347 .53278 .57109 Metetra
0 0 .133 r
.53278 .57109 .53812 .53347 .54801 .49737 .54283 .52464 Metetra
.958 .782 .335 r
.54283 .52464 .54801 .49737 .55741 .42798 .55229 .43522 Metetra
1 .815 .496 r
.55229 .43522 .55741 .42798 .56678 .38547 .56167 .38203 Metetra
.9 .854 .788 r
.56167 .38203 .56678 .38547 .57645 .37326 .57137 .36889 Metetra
.867 .833 .811 r
.57137 .36889 .57645 .37326 .58613 .363 .58107 .35774 Metetra
.813 .806 .844 r
.58107 .35774 .58613 .363 .59586 .35537 .59081 .34931 Metetra
.77 .774 .856 r
.59081 .34931 .59586 .35537 .60562 .34889 .6006 .34249 Metetra
.696 .744 .889 r
.6006 .34249 .60562 .34889 .61545 .34421 .61047 .33824 Metetra
.698 .76 .9 r
.61047 .33824 .61545 .34421 .62532 .33971 .62037 .33396 Metetra
.699 .769 .906 r
.62037 .33396 .62532 .33971 .63523 .33556 .6303 .32968 Metetra
.709 .768 .899 r
.6303 .32968 .63523 .33556 .64515 .3311 .64025 .32508 Metetra
.728 .77 .886 r
.64025 .32508 .64515 .3311 .65508 .32599 .65019 .31984 Metetra
.706 .76 .894 r
.65019 .31984 .65508 .32599 .66506 .32149 .6602 .31527 Metetra
.644 .736 .916 r
.6602 .31527 .66506 .32149 .67513 .31846 .6703 .31233 Metetra
.682 .754 .906 r
.6703 .31233 .67513 .31846 .68521 .31457 .6804 .30841 Metetra
.766 .779 .864 r
.6804 .30841 .68521 .31457 .69518 .30824 .69039 .30172 Metetra
.744 .762 .868 r
.69039 .30172 .69518 .30824 .70521 .30251 .70043 .29576 Metetra
.663 .727 .897 r
.70043 .29576 .70521 .30251 .71538 .29886 .71064 .2923 Metetra
.663 .735 .903 r
.71064 .2923 .71538 .29886 .72559 .29523 .72089 .28883 Metetra
.664 .741 .908 r
.72089 .28883 .72559 .29523 .73585 .29177 .73118 .28535 Metetra
.664 .741 .908 r
.73118 .28535 .73585 .29177 .74615 .2883 .7415 .28185 Metetra
.664 .741 .908 r
.7415 .28185 .74615 .2883 .75648 .28481 .75186 .27834 Metetra
.664 .741 .908 r
.75186 .27834 .75648 .28481 .76685 .28131 .76226 .27482 Metetra
.664 .741 .908 r
.76226 .27482 .76685 .28131 .77726 .2778 .77269 .27129 Metetra
.664 .741 .908 r
.77269 .27129 .77726 .2778 .78771 .27428 .78317 .26774 Metetra
.664 .741 .908 r
.78317 .26774 .78771 .27428 .7982 .27074 .79368 .26418 Metetra
.664 .741 .908 r
.79368 .26418 .7982 .27074 .80872 .2672 .80423 .26061 Metetra
.664 .741 .908 r
.80423 .26061 .80872 .2672 .81928 .26363 .81482 .25702 Metetra
.664 .741 .908 r
.81482 .25702 .81928 .26363 .82988 .26006 .82545 .25342 Metetra
.664 .741 .908 r
.82545 .25342 .82988 .26006 .84052 .25647 .83611 .24981 Metetra
.664 .741 .908 r
.83611 .24981 .84052 .25647 .8512 .25287 .84682 .24619 Metetra
.664 .741 .908 r
.23555 .44583 .24135 .45123 .24998 .44831 .2442 .44289 Metetra
.664 .741 .908 r
.2442 .44289 .24998 .44831 .25863 .44537 .25287 .43994 Metetra
.664 .741 .908 r
.25287 .43994 .25863 .44537 .26732 .44243 .26157 .43698 Metetra
.664 .741 .908 r
.26157 .43698 .26732 .44243 .27603 .43948 .2703 .43401 Metetra
.664 .741 .908 r
.2703 .43401 .27603 .43948 .28477 .43652 .27905 .43103 Metetra
.664 .741 .908 r
.27905 .43103 .28477 .43652 .29354 .43355 .28784 .42805 Metetra
.664 .741 .908 r
.28784 .42805 .29354 .43355 .30234 .43057 .29666 .42505 Metetra
.664 .741 .908 r
.29666 .42505 .30234 .43057 .31116 .42759 .3055 .42204 Metetra
.664 .741 .908 r
.3055 .42204 .31116 .42759 .32002 .42459 .31438 .41902 Metetra
.664 .741 .908 r
.31438 .41902 .32002 .42459 .32891 .42158 .32328 .41599 Metetra
.664 .741 .908 r
.32328 .41599 .32891 .42158 .33783 .41856 .33222 .41295 Metetra
.664 .741 .908 r
.33222 .41295 .33783 .41856 .34677 .41553 .34119 .4099 Metetra
.664 .741 .908 r
.34119 .4099 .34677 .41553 .35575 .41249 .35018 .40685 Metetra
.664 .741 .908 r
.35018 .40685 .35575 .41249 .36476 .40943 .35921 .40378 Metetra
.531 .695 .944 r
.35921 .40378 .36476 .40943 .37368 .40883 .36815 .40316 Metetra
.478 .673 .95 r
.36815 .40316 .37368 .40883 .38262 .40895 .3771 .40326 Metetra
.642 .735 .917 r
.3771 .40326 .38262 .40895 .39172 .40636 .38621 .40065 Metetra
.681 .747 .901 r
.38621 .40065 .39172 .40636 .40088 .40281 .3954 .39708 Metetra
.609 .724 .927 r
.3954 .39708 .40088 .40281 .41002 .40088 .40455 .39513 Metetra
.573 .711 .936 r
.40455 .39513 .41002 .40088 .41917 .3996 .41372 .39383 Metetra
.607 .724 .928 r
.41372 .39383 .41917 .3996 .42838 .39769 .42295 .39191 Metetra
.622 .729 .923 r
.42295 .39191 .42838 .39769 .43764 .39548 .43223 .38968 Metetra
.622 .729 .923 r
.43223 .38968 .43764 .39548 .44694 .39326 .44154 .38744 Metetra
.622 .729 .923 r
.44154 .38744 .44694 .39326 .45627 .39104 .4509 .3852 Metetra
.466 .665 .948 r
.4509 .3852 .45627 .39104 .4656 .39134 .46024 .38549 Metetra
.33 .595 .942 r
.46024 .38549 .4656 .39134 .47495 .39326 .4696 .3874 Metetra
.043 .418 .864 r
.4696 .3874 .47495 .39326 .48433 .3979 .47899 .39202 Metetra
0 .255 .75 r
.47899 .39202 .48433 .3979 .49377 .40454 .48844 .39866 Metetra
.95 .599 .283 r
.48844 .39866 .49377 .40454 .50304 .4511 .49764 .44527 Metetra
.961 .641 .362 r
.49764 .44527 .50304 .4511 .5125 .53395 .50698 .52823 Metetra
.939 .569 .235 r
.50698 .52823 .5125 .53395 .52254 .57416 .51698 .56849 Metetra
.646 .762 .934 r
.51698 .56849 .52254 .57416 .53278 .57109 .52724 .56541 Metetra
.952 .746 .589 r
.52724 .56541 .53278 .57109 .54283 .52464 .53738 .51886 Metetra
.963 .721 .524 r
.53738 .51886 .54283 .52464 .55229 .43522 .54701 .42928 Metetra
.956 .737 .567 r
.54701 .42928 .55229 .43522 .56167 .38203 .55649 .376 Metetra
.865 .782 .768 r
.55649 .376 .56167 .38203 .57137 .36889 .56622 .36282 Metetra
.844 .783 .793 r
.56622 .36282 .57137 .36889 .58107 .35774 .57596 .35164 Metetra
.803 .779 .831 r
.57596 .35164 .58107 .35774 .59081 .34931 .58574 .34318 Metetra
.77 .773 .856 r
.58574 .34318 .59081 .34931 .6006 .34249 .59555 .33634 Metetra
.697 .754 .896 r
.59555 .33634 .6006 .34249 .61047 .33824 .60545 .33206 Metetra
.697 .754 .896 r
.60545 .33206 .61047 .33824 .62037 .33396 .61537 .32776 Metetra
.697 .754 .896 r
.61537 .32776 .62037 .33396 .6303 .32968 .62533 .32346 Metetra
.707 .757 .891 r
.62533 .32346 .6303 .32968 .64025 .32508 .6353 .31884 Metetra
.727 .763 .882 r
.6353 .31884 .64025 .32508 .65019 .31984 .64528 .31357 Metetra
.706 .757 .892 r
.64528 .31357 .65019 .31984 .6602 .31527 .6553 .30897 Metetra
.644 .735 .915 r
.6553 .30897 .6602 .31527 .6703 .31233 .66544 .30601 Metetra
.682 .749 .902 r
.66544 .30601 .6703 .31233 .6804 .30841 .67556 .30207 Metetra
.764 .774 .861 r
.67556 .30207 .6804 .30841 .69039 .30172 .68558 .29536 Metetra
.745 .769 .872 r
.68558 .29536 .69039 .30172 .70043 .29576 .69565 .28937 Metetra
.664 .741 .908 r
.69565 .28937 .70043 .29576 .71064 .2923 .70588 .28589 Metetra
.664 .741 .908 r
.70588 .28589 .71064 .2923 .72089 .28883 .71616 .28239 Metetra
.664 .741 .908 r
.71616 .28239 .72089 .28883 .73118 .28535 .72647 .27888 Metetra
.664 .741 .908 r
.72647 .27888 .73118 .28535 .7415 .28185 .73682 .27537 Metetra
.664 .741 .908 r
.73682 .27537 .7415 .28185 .75186 .27834 .7472 .27183 Metetra
.664 .741 .908 r
.7472 .27183 .75186 .27834 .76226 .27482 .75763 .26829 Metetra
.664 .741 .908 r
.75763 .26829 .76226 .27482 .77269 .27129 .76809 .26473 Metetra
.664 .741 .908 r
.76809 .26473 .77269 .27129 .78317 .26774 .77859 .26116 Metetra
.664 .741 .908 r
.77859 .26116 .78317 .26774 .79368 .26418 .78913 .25758 Metetra
.664 .741 .908 r
.78913 .25758 .79368 .26418 .80423 .26061 .79971 .25398 Metetra
.664 .741 .908 r
.79971 .25398 .80423 .26061 .81482 .25702 .81032 .25037 Metetra
.664 .741 .908 r
.81032 .25037 .81482 .25702 .82545 .25342 .82098 .24674 Metetra
.664 .741 .908 r
.82098 .24674 .82545 .25342 .83611 .24981 .83168 .24311 Metetra
.664 .741 .908 r
.83168 .24311 .83611 .24981 .84682 .24619 .84241 .23946 Metetra
.664 .741 .908 r
.22972 .44039 .23555 .44583 .2442 .44289 .23838 .43744 Metetra
.664 .741 .908 r
.23838 .43744 .2442 .44289 .25287 .43994 .24707 .43447 Metetra
.664 .741 .908 r
.24707 .43447 .25287 .43994 .26157 .43698 .25578 .43149 Metetra
.664 .741 .908 r
.25578 .43149 .26157 .43698 .2703 .43401 .26453 .42851 Metetra
.664 .741 .908 r
.26453 .42851 .2703 .43401 .27905 .43103 .2733 .42551 Metetra
.664 .741 .908 r
.2733 .42551 .27905 .43103 .28784 .42805 .28211 .4225 Metetra
.664 .741 .908 r
.28211 .4225 .28784 .42805 .29666 .42505 .29094 .41949 Metetra
.664 .741 .908 r
.29094 .41949 .29666 .42505 .3055 .42204 .29981 .41646 Metetra
.664 .741 .908 r
.29981 .41646 .3055 .42204 .31438 .41902 .3087 .41342 Metetra
.664 .741 .908 r
.3087 .41342 .31438 .41902 .32328 .41599 .31762 .41037 Metetra
.664 .741 .908 r
.31762 .41037 .32328 .41599 .33222 .41295 .32658 .40732 Metetra
.664 .741 .908 r
.32658 .40732 .33222 .41295 .34119 .4099 .33556 .40425 Metetra
.656 .739 .911 r
.33556 .40425 .34119 .4099 .35018 .40685 .34457 .40134 Metetra
.654 .745 .917 r
.34457 .40134 .35018 .40685 .35921 .40378 .3536 .39847 Metetra
.537 .714 .954 r
.3536 .39847 .35921 .40378 .36815 .40316 .36257 .39764 Metetra
.498 .689 .953 r
.36257 .39764 .36815 .40316 .3771 .40326 .37154 .3974 Metetra
.642 .731 .913 r
.37154 .3974 .3771 .40326 .38621 .40065 .38068 .39476 Metetra
.677 .741 .899 r
.38068 .39476 .38621 .40065 .3954 .39708 .38988 .39129 Metetra
.612 .724 .925 r
.38988 .39129 .3954 .39708 .40455 .39513 .39905 .38927 Metetra
.58 .711 .932 r
.39905 .38927 .40455 .39513 .41372 .39383 .40824 .38785 Metetra
.613 .719 .921 r
.40824 .38785 .41372 .39383 .42295 .39191 .41749 .38579 Metetra
.628 .72 .913 r
.41749 .38579 .42295 .39191 .43223 .38968 .42679 .38344 Metetra
.612 .71 .915 r
.42679 .38344 .43223 .38968 .44154 .38744 .43612 .38142 Metetra
.601 .715 .925 r
.43612 .38142 .44154 .38744 .4509 .3852 .44548 .3796 Metetra
.481 .683 .955 r
.44548 .3796 .4509 .3852 .46024 .38549 .45484 .37957 Metetra
.4 .631 .948 r
.45484 .37957 .46024 .38549 .4696 .3874 .46423 .38069 Metetra
.199 .485 .897 r
.46423 .38069 .4696 .3874 .47899 .39202 .47364 .38446 Metetra
.07 .371 .838 r
.47364 .38446 .47899 .39202 .48844 .39866 .4831 .39018 Metetra
.932 .561 .168 r
.4831 .39018 .48844 .39866 .49764 .44527 .49234 .42625 Metetra
.939 .625 .176 r
.49234 .42625 .49764 .44527 .50698 .52823 .50166 .48939 Metetra
.083 .065 .537 r
.50166 .48939 .50698 .52823 .51698 .56849 .51155 .51935 Metetra
.574 .4 .608 r
.51155 .51935 .51698 .56849 .52724 .56541 .5217 .5162 Metetra
.737 .518 .595 r
.5217 .5162 .52724 .56541 .53738 .51886 .53183 .47987 Metetra
.843 .602 .573 r
.53183 .47987 .53738 .51886 .54701 .42928 .54162 .41011 Metetra
.871 .651 .602 r
.54162 .41011 .54701 .42928 .55649 .376 .55125 .36736 Metetra
.822 .721 .754 r
.55125 .36736 .55649 .376 .56622 .36282 .56103 .35506 Metetra
.81 .737 .783 r
.56103 .35506 .56622 .36282 .57596 .35164 .57081 .3447 Metetra
.778 .751 .829 r
.57081 .3447 .57596 .35164 .58574 .34318 .58063 .33699 Metetra
.762 .771 .86 r
.58063 .33699 .58574 .34318 .59555 .33634 .59048 .33043 Metetra
.713 .769 .896 r
.59048 .33043 .59555 .33634 .60545 .33206 .60039 .32568 Metetra
.704 .751 .888 r
.60039 .32568 .60545 .33206 .61537 .32776 .61033 .32111 Metetra
.691 .738 .887 r
.61033 .32111 .61537 .32776 .62533 .32346 .62031 .31689 Metetra
.702 .745 .885 r
.62031 .31689 .62533 .32346 .6353 .31884 .63032 .31236 Metetra
.722 .755 .879 r
.63032 .31236 .6353 .31884 .64528 .31357 .64032 .30718 Metetra
.704 .753 .891 r
.64032 .30718 .64528 .31357 .6553 .30897 .65038 .3026 Metetra
.649 .735 .912 r
.65038 .3026 .6553 .30897 .66544 .30601 .66053 .29951 Metetra
.681 .743 .898 r
.66053 .29951 .66544 .30601 .67556 .30207 .67068 .29555 Metetra
.755 .767 .863 r
.67068 .29555 .67556 .30207 .68558 .29536 .68074 .28914 Metetra
.741 .774 .88 r
.68074 .28914 .68558 .29536 .69565 .28937 .69085 .28333 Metetra
.672 .759 .916 r
.69085 .28333 .69565 .28937 .70588 .28589 .7011 .2796 Metetra
.671 .75 .91 r
.7011 .2796 .70588 .28589 .71616 .28239 .71139 .27591 Metetra
.664 .741 .908 r
.71139 .27591 .71616 .28239 .72647 .27888 .72173 .27238 Metetra
.664 .741 .908 r
.72173 .27238 .72647 .27888 .73682 .27537 .7321 .26883 Metetra
.664 .741 .908 r
.7321 .26883 .73682 .27537 .7472 .27183 .74252 .26528 Metetra
.664 .741 .908 r
.74252 .26528 .7472 .27183 .75763 .26829 .75297 .26171 Metetra
.664 .741 .908 r
.75297 .26171 .75763 .26829 .76809 .26473 .76346 .25813 Metetra
.664 .741 .908 r
.76346 .25813 .76809 .26473 .77859 .26116 .77399 .25453 Metetra
.664 .741 .908 r
.77399 .25453 .77859 .26116 .78913 .25758 .78455 .25092 Metetra
.664 .741 .908 r
.78455 .25092 .78913 .25758 .79971 .25398 .79516 .2473 Metetra
.664 .741 .908 r
.79516 .2473 .79971 .25398 .81032 .25037 .8058 .24367 Metetra
.664 .741 .908 r
.8058 .24367 .81032 .25037 .82098 .24674 .81649 .24002 Metetra
.664 .741 .908 r
.81649 .24002 .82098 .24674 .83168 .24311 .82721 .23636 Metetra
.664 .741 .908 r
.82721 .23636 .83168 .24311 .84241 .23946 .83797 .23268 Metetra
.664 .741 .908 r
.22385 .43493 .22972 .44039 .23838 .43744 .23252 .43195 Metetra
.664 .741 .908 r
.23252 .43195 .23838 .43744 .24707 .43447 .24123 .42897 Metetra
.664 .741 .908 r
.24123 .42897 .24707 .43447 .25578 .43149 .24996 .42597 Metetra
.664 .741 .908 r
.24996 .42597 .25578 .43149 .26453 .42851 .25873 .42297 Metetra
.664 .741 .908 r
.25873 .42297 .26453 .42851 .2733 .42551 .26752 .41995 Metetra
.664 .741 .908 r
.26752 .41995 .2733 .42551 .28211 .4225 .27634 .41693 Metetra
.664 .741 .908 r
.27634 .41693 .28211 .4225 .29094 .41949 .28519 .41389 Metetra
.664 .741 .908 r
.28519 .41389 .29094 .41949 .29981 .41646 .29407 .41084 Metetra
.664 .741 .908 r
.29407 .41084 .29981 .41646 .3087 .41342 .30299 .40779 Metetra
.664 .741 .908 r
.30299 .40779 .3087 .41342 .31762 .41037 .31193 .40472 Metetra
.664 .741 .908 r
.31193 .40472 .31762 .41037 .32658 .40732 .3209 .40164 Metetra
.664 .741 .908 r
.3209 .40164 .32658 .40732 .33556 .40425 .3299 .39856 Metetra
.64 .734 .917 r
.3299 .39856 .33556 .40425 .34457 .40134 .33891 .39599 Metetra
.632 .746 .93 r
.33891 .39599 .34457 .40134 .3536 .39847 .34794 .39355 Metetra
.557 .739 .961 r
.34794 .39355 .3536 .39847 .36257 .39764 .35694 .39228 Metetra
.542 .716 .953 r
.35694 .39228 .36257 .39764 .37154 .3974 .36596 .39135 Metetra
.643 .725 .908 r
.36596 .39135 .37154 .3974 .38068 .39476 .37512 .38869 Metetra
.668 .733 .899 r
.37512 .38869 .38068 .39476 .38988 .39129 .38433 .38542 Metetra
.617 .725 .923 r
.38433 .38542 .38988 .39129 .39905 .38927 .39352 .38329 Metetra
.593 .713 .927 r
.39352 .38329 .39905 .38927 .40824 .38785 .40274 .38162 Metetra
.625 .716 .912 r
.40274 .38162 .40824 .38785 .41749 .38579 .41201 .37932 Metetra
.638 .713 .901 r
.41201 .37932 .41749 .38579 .42679 .38344 .42134 .37672 Metetra
.59 .687 .909 r
.42134 .37672 .42679 .38344 .43612 .38142 .43066 .37519 Metetra
.553 .69 .93 r
.43066 .37519 .43612 .38142 .44548 .3796 .44002 .37426 Metetra
.518 .712 .96 r
.44002 .37426 .44548 .3796 .45484 .37957 .44941 .37359 Metetra
.52 .687 .943 r
.44941 .37359 .45484 .37957 .46423 .38069 .45885 .3731 Metetra
.389 .563 .904 r
.45885 .3731 .46423 .38069 .47364 .38446 .46829 .37511 Metetra
.321 .47 .853 r
.46829 .37511 .47364 .38446 .4831 .39018 .47777 .37895 Metetra
0 0 .537 r
.47777 .37895 .4831 .39018 .49234 .42625 .4872 .39346 Metetra
.116 .102 .564 r
.4872 .39346 .49234 .42625 .50166 .48939 .4967 .4171 Metetra
.489 .318 .575 r
.4967 .4171 .50166 .48939 .51155 .51935 .50647 .42704 Metetra
.559 .363 .571 r
.50647 .42704 .51155 .51935 .5217 .5162 .51639 .4238 Metetra
.608 .399 .573 r
.51639 .4238 .5217 .5162 .53183 .47987 .52634 .40735 Metetra
.673 .455 .582 r
.52634 .40735 .53183 .47987 .54162 .41011 .53619 .3771 Metetra
.723 .525 .623 r
.53619 .3771 .54162 .41011 .55125 .36736 .54597 .35595 Metetra
.769 .661 .743 r
.54597 .35595 .55125 .36736 .56103 .35506 .55579 .34549 Metetra
.763 .688 .779 r
.55579 .34549 .56103 .35506 .57081 .3447 .56562 .33685 Metetra
.735 .716 .834 r
.56562 .33685 .57081 .3447 .58063 .33699 .57549 .33073 Metetra
.746 .766 .869 r
.57549 .33073 .58063 .33699 .59048 .33043 .58538 .32477 Metetra
.744 .787 .888 r
.58538 .32477 .59048 .33043 .60039 .32568 .59529 .31908 Metetra
.719 .749 .876 r
.59529 .31908 .60039 .32568 .61033 .32111 .60525 .31398 Metetra
.682 .721 .879 r
.60525 .31398 .61033 .32111 .62031 .31689 .61526 .30996 Metetra
.693 .732 .881 r
.61526 .30996 .62031 .31689 .63032 .31236 .62529 .30563 Metetra
.714 .746 .877 r
.62529 .30563 .63032 .31236 .64032 .30718 .63533 .30066 Metetra
.7 .749 .89 r
.63533 .30066 .64032 .30718 .65038 .3026 .64542 .29615 Metetra
.658 .738 .908 r
.64542 .29615 .65038 .3026 .66053 .29951 .65558 .29281 Metetra
.68 .738 .894 r
.65558 .29281 .66053 .29951 .67068 .29555 .66576 .28883 Metetra
.735 .757 .87 r
.66576 .28883 .67068 .29555 .68074 .28914 .67588 .28309 Metetra
.73 .778 .891 r
.67588 .28309 .68074 .28914 .69085 .28333 .68604 .27768 Metetra
.69 .782 .921 r
.68604 .27768 .69085 .28333 .7011 .2796 .6963 .27347 Metetra
.685 .763 .911 r
.6963 .27347 .7011 .2796 .71139 .27591 .70659 .26938 Metetra
.664 .741 .908 r
.70659 .26938 .71139 .27591 .72173 .27238 .71696 .26583 Metetra
.664 .741 .908 r
.71696 .26583 .72173 .27238 .7321 .26883 .72736 .26226 Metetra
.664 .741 .908 r
.72736 .26226 .7321 .26883 .74252 .26528 .7378 .25868 Metetra
.664 .741 .908 r
.7378 .25868 .74252 .26528 .75297 .26171 .74828 .25509 Metetra
.664 .741 .908 r
.74828 .25509 .75297 .26171 .76346 .25813 .75879 .25148 Metetra
.664 .741 .908 r
.75879 .25148 .76346 .25813 .77399 .25453 .76935 .24786 Metetra
.664 .741 .908 r
.76935 .24786 .77399 .25453 .78455 .25092 .77994 .24423 Metetra
.664 .741 .908 r
.77994 .24423 .78455 .25092 .79516 .2473 .79057 .24058 Metetra
.664 .741 .908 r
.79057 .24058 .79516 .2473 .8058 .24367 .80125 .23692 Metetra
.664 .741 .908 r
.80125 .23692 .8058 .24367 .81649 .24002 .81196 .23325 Metetra
.664 .741 .908 r
.81196 .23325 .81649 .24002 .82721 .23636 .82271 .22956 Metetra
.664 .741 .908 r
.82271 .22956 .82721 .23636 .83797 .23268 .8335 .22586 Metetra
.664 .741 .908 r
.21794 .42943 .22385 .43493 .23252 .43195 .22663 .42643 Metetra
.664 .741 .908 r
.22663 .42643 .23252 .43195 .24123 .42897 .23535 .42343 Metetra
.664 .741 .908 r
.23535 .42343 .24123 .42897 .24996 .42597 .24411 .42042 Metetra
.664 .741 .908 r
.24411 .42042 .24996 .42597 .25873 .42297 .25289 .41739 Metetra
.664 .741 .908 r
.25289 .41739 .25873 .42297 .26752 .41995 .2617 .41436 Metetra
.664 .741 .908 r
.2617 .41436 .26752 .41995 .27634 .41693 .27054 .41131 Metetra
.664 .741 .908 r
.27054 .41131 .27634 .41693 .28519 .41389 .27941 .40826 Metetra
.664 .741 .908 r
.27941 .40826 .28519 .41389 .29407 .41084 .28831 .40519 Metetra
.664 .741 .908 r
.28831 .40519 .29407 .41084 .30299 .40779 .29724 .40212 Metetra
.664 .741 .908 r
.29724 .40212 .30299 .40779 .31193 .40472 .3062 .39903 Metetra
.664 .741 .908 r
.3062 .39903 .31193 .40472 .3209 .40164 .31519 .39594 Metetra
.664 .741 .908 r
.31519 .39594 .3209 .40164 .3299 .39856 .32421 .39283 Metetra
.627 .73 .922 r
.32421 .39283 .3299 .39856 .33891 .39599 .33321 .39053 Metetra
.615 .737 .933 r
.33321 .39053 .33891 .39599 .34794 .39355 .34224 .38841 Metetra
.584 .741 .951 r
.34224 .38841 .34794 .39355 .35694 .39228 .35128 .38676 Metetra
.581 .725 .942 r
.35128 .38676 .35694 .39228 .36596 .39135 .36035 .38524 Metetra
.639 .723 .909 r
.36035 .38524 .36596 .39135 .37512 .38869 .36952 .38266 Metetra
.655 .732 .906 r
.36952 .38266 .37512 .38869 .38433 .38542 .37873 .37969 Metetra
.626 .734 .925 r
.37873 .37969 .38433 .38542 .39352 .38329 .38795 .37733 Metetra
.615 .723 .923 r
.38795 .37733 .39352 .38329 .40274 .38162 .3972 .37522 Metetra
.632 .713 .905 r
.3972 .37522 .40274 .38162 .41201 .37932 .4065 .37275 Metetra
.639 .711 .899 r
.4065 .37275 .41201 .37932 .42134 .37672 .41584 .3701 Metetra
.583 .689 .914 r
.41584 .3701 .42134 .37672 .43066 .37519 .42518 .36867 Metetra
.545 .677 .925 r
.42518 .36867 .43066 .37519 .44002 .37426 .43455 .3679 Metetra
.564 .692 .926 r
.43455 .3679 .44002 .37426 .44941 .37359 .44397 .36676 Metetra
.581 .683 .91 r
.44397 .36676 .44941 .37359 .45885 .3731 .45344 .36536 Metetra
.489 .611 .9 r
.45344 .36536 .45885 .3731 .46829 .37511 .46292 .36586 Metetra
.438 .54 .864 r
.46292 .36586 .46829 .37511 .47777 .37895 .47243 .36773 Metetra
.464 .51 .82 r
.47243 .36773 .47777 .37895 .4872 .39346 .48201 .36967 Metetra
.517 .415 .678 r
.48201 .36967 .4872 .39346 .4967 .4171 .49165 .37167 Metetra
.555 .387 .609 r
.49165 .37167 .4967 .4171 .50647 .42704 .50137 .37094 Metetra
.569 .387 .595 r
.50137 .37094 .50647 .42704 .51639 .4238 .51116 .36764 Metetra
.585 .399 .595 r
.51116 .36764 .51639 .4238 .52634 .40735 .52099 .36176 Metetra
.614 .429 .609 r
.52099 .36176 .52634 .40735 .53619 .3771 .53083 .35313 Metetra
.664 .511 .666 r
.53083 .35313 .53619 .3771 .54597 .35595 .54068 .34455 Metetra
.743 .65 .758 r
.54068 .34455 .54597 .35595 .55579 .34549 .55053 .33602 Metetra
.739 .682 .795 r
.55053 .33602 .55579 .34549 .56562 .33685 .56039 .32887 Metetra
.712 .706 .843 r
.56039 .32887 .56562 .33685 .57549 .33073 .5703 .32361 Metetra
.726 .735 .858 r
.5703 .32361 .57549 .33073 .58538 .32477 .58022 .31809 Metetra
.741 .754 .863 r
.58022 .31809 .58538 .32477 .59529 .31908 .59016 .31218 Metetra
.72 .742 .869 r
.59016 .31218 .59529 .31908 .60525 .31398 .60014 .30694 Metetra
.681 .725 .883 r
.60014 .30694 .60525 .31398 .61526 .30996 .61017 .30292 Metetra
.687 .728 .881 r
.61017 .30292 .61526 .30996 .62529 .30563 .62023 .29872 Metetra
.699 .737 .88 r
.62023 .29872 .62529 .30563 .63533 .30066 .63031 .29416 Metetra
.693 .749 .895 r
.63031 .29416 .63533 .30066 .64542 .29615 .64043 .28985 Metetra
.671 .749 .909 r
.64043 .28985 .64542 .29615 .65558 .29281 .65061 .28614 Metetra
.684 .742 .895 r
.65061 .28614 .65558 .29281 .66576 .28883 .6608 .28205 Metetra
.718 .751 .878 r
.6608 .28205 .66576 .28883 .67588 .28309 .67098 .27686 Metetra
.718 .77 .894 r
.67098 .27686 .67588 .28309 .68604 .27768 .68119 .2718 Metetra
.703 .779 .91 r
.68119 .2718 .68604 .27768 .6963 .27347 .69146 .26721 Metetra
.695 .763 .904 r
.69146 .26721 .6963 .27347 .70659 .26938 .70176 .26281 Metetra
.664 .741 .908 r
.70176 .26281 .70659 .26938 .71696 .26583 .71215 .25923 Metetra
.664 .741 .908 r
.71215 .25923 .71696 .26583 .72736 .26226 .72258 .25564 Metetra
.664 .741 .908 r
.72258 .25564 .72736 .26226 .7378 .25868 .73305 .25204 Metetra
.664 .741 .908 r
.73305 .25204 .7378 .25868 .74828 .25509 .74355 .24842 Metetra
.664 .741 .908 r
.74355 .24842 .74828 .25509 .75879 .25148 .7541 .24479 Metetra
.664 .741 .908 r
.7541 .24479 .75879 .25148 .76935 .24786 .76468 .24114 Metetra
.664 .741 .908 r
.76468 .24114 .76935 .24786 .77994 .24423 .7753 .23749 Metetra
.664 .741 .908 r
.7753 .23749 .77994 .24423 .79057 .24058 .78596 .23381 Metetra
.664 .741 .908 r
.78596 .23381 .79057 .24058 .80125 .23692 .79666 .23013 Metetra
.664 .741 .908 r
.79666 .23013 .80125 .23692 .81196 .23325 .8074 .22643 Metetra
.664 .741 .908 r
.8074 .22643 .81196 .23325 .82271 .22956 .81818 .22272 Metetra
.664 .741 .908 r
.81818 .22272 .82271 .22956 .8335 .22586 .829 .21899 Metetra
.664 .741 .908 r
.212 .42389 .21794 .42943 .22663 .42643 .22071 .42088 Metetra
.664 .741 .908 r
.22071 .42088 .22663 .42643 .23535 .42343 .22944 .41786 Metetra
.664 .741 .908 r
.22944 .41786 .23535 .42343 .24411 .42042 .23821 .41482 Metetra
.664 .741 .908 r
.23821 .41482 .24411 .42042 .25289 .41739 .24701 .41178 Metetra
.664 .741 .908 r
.24701 .41178 .25289 .41739 .2617 .41436 .25584 .40873 Metetra
.664 .741 .908 r
.25584 .40873 .2617 .41436 .27054 .41131 .2647 .40567 Metetra
.664 .741 .908 r
.2647 .40567 .27054 .41131 .27941 .40826 .27358 .40259 Metetra
.664 .741 .908 r
.27358 .40259 .27941 .40826 .28831 .40519 .2825 .39951 Metetra
.664 .741 .908 r
.2825 .39951 .28831 .40519 .29724 .40212 .29145 .39641 Metetra
.664 .741 .908 r
.29145 .39641 .29724 .40212 .3062 .39903 .30043 .39331 Metetra
.664 .741 .908 r
.30043 .39331 .3062 .39903 .31519 .39594 .30944 .39019 Metetra
.664 .741 .908 r
.30944 .39019 .31519 .39594 .32421 .39283 .31848 .38707 Metetra
.617 .727 .925 r
.31848 .38707 .32421 .39283 .33321 .39053 .32749 .38493 Metetra
.604 .73 .934 r
.32749 .38493 .33321 .39053 .34224 .38841 .33652 .38302 Metetra
.604 .739 .94 r
.33652 .38302 .34224 .38841 .35128 .38676 .34559 .38105 Metetra
.608 .728 .931 r
.34559 .38105 .35128 .38676 .36035 .38524 .35471 .37906 Metetra
.629 .719 .912 r
.35471 .37906 .36035 .38524 .36952 .38266 .36388 .37668 Metetra
.635 .729 .916 r
.36388 .37668 .36952 .38266 .37873 .37969 .37309 .37415 Metetra
.642 .748 .926 r
.37309 .37415 .37873 .37969 .38795 .37733 .38235 .37142 Metetra
.646 .736 .914 r
.38235 .37142 .38795 .37733 .3972 .37522 .39164 .3686 Metetra
.635 .709 .9 r
.39164 .3686 .3972 .37522 .4065 .37275 .40096 .36605 Metetra
.63 .704 .9 r
.40096 .36605 .4065 .37275 .41584 .3701 .41031 .3636 Metetra
.6 .701 .914 r
.41031 .3636 .41584 .3701 .42518 .36867 .41968 .36179 Metetra
.585 .683 .908 r
.41968 .36179 .42518 .36867 .43455 .3679 .42908 .36033 Metetra
.586 .661 .89 r
.42908 .36033 .43455 .3679 .44397 .36676 .43852 .35889 Metetra
.586 .653 .883 r
.43852 .35889 .44397 .36676 .45344 .36536 .448 .35748 Metetra
.554 .639 .889 r
.448 .35748 .45344 .36536 .46292 .36586 .45751 .35675 Metetra
.539 .598 .861 r
.45751 .35675 .46292 .36586 .47243 .36773 .46707 .35653 Metetra
.542 .554 .816 r
.46707 .35653 .47243 .36773 .48201 .36967 .47667 .35648 Metetra
.543 .521 .782 r
.47667 .35648 .48201 .36967 .49165 .37167 .48633 .35659 Metetra
.59 .525 .75 r
.48633 .35659 .49165 .37167 .50137 .37094 .49605 .35493 Metetra
.623 .535 .734 r
.49605 .35493 .50137 .37094 .51116 .36764 .50583 .3516 Metetra
.653 .552 .728 r
.50583 .3516 .51116 .36764 .52099 .36176 .51566 .34659 Metetra
.686 .579 .729 r
.51566 .34659 .52099 .36176 .53083 .35313 .5255 .33981 Metetra
.696 .604 .749 r
.5255 .33981 .53083 .35313 .54068 .34455 .53536 .33317 Metetra
.709 .636 .774 r
.53536 .33317 .54068 .34455 .55053 .33602 .54524 .3267 Metetra
.717 .677 .81 r
.54524 .3267 .55053 .33602 .56039 .32887 .55514 .32073 Metetra
.711 .703 .84 r
.55514 .32073 .56039 .32887 .5703 .32361 .56506 .31544 Metetra
.711 .703 .841 r
.56506 .31544 .5703 .32361 .58022 .31809 .57501 .31017 Metetra
.712 .71 .847 r
.57501 .31017 .58022 .31809 .59016 .31218 .58499 .30492 Metetra
.708 .728 .866 r
.58499 .30492 .59016 .31218 .60014 .30694 .595 .30002 Metetra
.69 .733 .884 r
.595 .30002 .60014 .30694 .61017 .30292 .60505 .29575 Metetra
.684 .724 .88 r
.60505 .29575 .61017 .30292 .62023 .29872 .61513 .2916 Metetra
.676 .723 .885 r
.61513 .2916 .62023 .29872 .63031 .29416 .62526 .2877 Metetra
.681 .748 .902 r
.62526 .2877 .63031 .29416 .64043 .28985 .63542 .28371 Metetra
.689 .763 .908 r
.63542 .28371 .64043 .28985 .65061 .28614 .64561 .27953 Metetra
.692 .748 .894 r
.64561 .27953 .65061 .28614 .6608 .28205 .65582 .27518 Metetra
.704 .745 .883 r
.65582 .27518 .6608 .28205 .67098 .27686 .66604 .27043 Metetra
.707 .761 .894 r
.66604 .27043 .67098 .27686 .68119 .2718 .6763 .26565 Metetra
.71 .773 .901 r
.6763 .26565 .68119 .2718 .69146 .26721 .68658 .26081 Metetra
.701 .762 .899 r
.68658 .26081 .69146 .26721 .70176 .26281 .6969 .25619 Metetra
.664 .741 .908 r
.6969 .25619 .70176 .26281 .71215 .25923 .70732 .25259 Metetra
.664 .741 .908 r
.70732 .25259 .71215 .25923 .72258 .25564 .71777 .24898 Metetra
.664 .741 .908 r
.71777 .24898 .72258 .25564 .73305 .25204 .72827 .24535 Metetra
.664 .741 .908 r
.72827 .24535 .73305 .25204 .74355 .24842 .7388 .24171 Metetra
.664 .741 .908 r
.7388 .24171 .74355 .24842 .7541 .24479 .74937 .23805 Metetra
.664 .741 .908 r
.74937 .23805 .7541 .24479 .76468 .24114 .75998 .23438 Metetra
.664 .741 .908 r
.75998 .23438 .76468 .24114 .7753 .23749 .77063 .2307 Metetra
.664 .741 .908 r
.77063 .2307 .7753 .23749 .78596 .23381 .78132 .227 Metetra
.664 .741 .908 r
.78132 .227 .78596 .23381 .79666 .23013 .79204 .22329 Metetra
.664 .741 .908 r
.79204 .22329 .79666 .23013 .8074 .22643 .80281 .21957 Metetra
.664 .741 .908 r
.80281 .21957 .8074 .22643 .81818 .22272 .81362 .21583 Metetra
.664 .741 .908 r
.81362 .21583 .81818 .22272 .829 .21899 .82447 .21208 Metetra
.664 .741 .908 r
.20602 .41832 .212 .42389 .22071 .42088 .21474 .41529 Metetra
.664 .741 .908 r
.21474 .41529 .22071 .42088 .22944 .41786 .2235 .41225 Metetra
.664 .741 .908 r
.2235 .41225 .22944 .41786 .23821 .41482 .23228 .4092 Metetra
.664 .741 .908 r
.23228 .4092 .23821 .41482 .24701 .41178 .2411 .40614 Metetra
.664 .741 .908 r
.2411 .40614 .24701 .41178 .25584 .40873 .24994 .40307 Metetra
.664 .741 .908 r
.24994 .40307 .25584 .40873 .2647 .40567 .25882 .39998 Metetra
.664 .741 .908 r
.25882 .39998 .2647 .40567 .27358 .40259 .26773 .39689 Metetra
.664 .741 .908 r
.26773 .39689 .27358 .40259 .2825 .39951 .27666 .39379 Metetra
.664 .741 .908 r
.27666 .39379 .2825 .39951 .29145 .39641 .28563 .39067 Metetra
.664 .741 .908 r
.28563 .39067 .29145 .39641 .30043 .39331 .29463 .38755 Metetra
.66 .74 .909 r
.29463 .38755 .30043 .39331 .30944 .39019 .30365 .38449 Metetra
.66 .743 .912 r
.30365 .38449 .30944 .39019 .31848 .38707 .3127 .38144 Metetra
.61 .732 .932 r
.3127 .38144 .31848 .38707 .32749 .38493 .32172 .37941 Metetra
.595 .731 .939 r
.32172 .37941 .32749 .38493 .33652 .38302 .33076 .37761 Metetra
.618 .744 .936 r
.33076 .37761 .33652 .38302 .34559 .38105 .33987 .37538 Metetra
.626 .737 .927 r
.33987 .37538 .34559 .38105 .35471 .37906 .34902 .37302 Metetra
.627 .724 .917 r
.34902 .37302 .35471 .37906 .36388 .37668 .3582 .37064 Metetra
.627 .725 .918 r
.3582 .37064 .36388 .37668 .37309 .37415 .36743 .36826 Metetra
.65 .739 .914 r
.36743 .36826 .37309 .37415 .38235 .37142 .37671 .36535 Metetra
.659 .736 .906 r
.37671 .36535 .38235 .37142 .39164 .3686 .38604 .36221 Metetra
.635 .718 .907 r
.38604 .36221 .39164 .3686 .40096 .36605 .39537 .35963 Metetra
.623 .713 .91 r
.39537 .35963 .40096 .36605 .41031 .3636 .40474 .3573 Metetra
.621 .717 .915 r
.40474 .3573 .41031 .3636 .41968 .36179 .41414 .35501 Metetra
.621 .701 .902 r
.41414 .35501 .41968 .36179 .42908 .36033 .42358 .35274 Metetra
.6 .668 .887 r
.42358 .35274 .42908 .36033 .43852 .35889 .43304 .35099 Metetra
.586 .653 .883 r
.43304 .35099 .43852 .35889 .448 .35748 .44253 .34955 Metetra
.586 .653 .883 r
.44253 .34955 .448 .35748 .45751 .35675 .45208 .34811 Metetra
.588 .634 .865 r
.45208 .34811 .45751 .35675 .46707 .35653 .46166 .34666 Metetra
.593 .608 .836 r
.46166 .34666 .46707 .35653 .47667 .35648 .47129 .34509 Metetra
.595 .579 .805 r
.47129 .34509 .47667 .35648 .48633 .35659 .48097 .34341 Metetra
.615 .562 .772 r
.48097 .34341 .48633 .35659 .49605 .35493 .49071 .34087 Metetra
.63 .56 .757 r
.49071 .34087 .49605 .35493 .50583 .3516 .50049 .33751 Metetra
.647 .569 .753 r
.50049 .33751 .50583 .3516 .51566 .34659 .51031 .33334 Metetra
.668 .59 .759 r
.51031 .33334 .51566 .34659 .5255 .33981 .52016 .32828 Metetra
.682 .622 .782 r
.52016 .32828 .5255 .33981 .53536 .33317 .53003 .32313 Metetra
.696 .654 .805 r
.53003 .32313 .53536 .33317 .54524 .3267 .53993 .31784 Metetra
.705 .684 .827 r
.53993 .31784 .54524 .3267 .55514 .32073 .54986 .31254 Metetra
.711 .703 .84 r
.54986 .31254 .55514 .32073 .56506 .31544 .5598 .30723 Metetra
.703 .7 .844 r
.5598 .30723 .56506 .31544 .57501 .31017 .56978 .30224 Metetra
.69 .703 .857 r
.56978 .30224 .57501 .31017 .58499 .30492 .57979 .29775 Metetra
.695 .728 .876 r
.57979 .29775 .58499 .30492 .595 .30002 .58983 .29329 Metetra
.695 .742 .888 r
.58983 .29329 .595 .30002 .60505 .29575 .5999 .28886 Metetra
.686 .735 .888 r
.5999 .28886 .60505 .29575 .61513 .2916 .61001 .28469 Metetra
.666 .728 .896 r
.61001 .28469 .61513 .2916 .62526 .2877 .62017 .28108 Metetra
.675 .741 .901 r
.62017 .28108 .62526 .2877 .63542 .28371 .63036 .27723 Metetra
.694 .754 .898 r
.63036 .27723 .63542 .28371 .64561 .27953 .64057 .27285 Metetra
.693 .748 .893 r
.64057 .27285 .64561 .27953 .65582 .27518 .6508 .26845 Metetra
.693 .746 .893 r
.6508 .26845 .65582 .27518 .66604 .27043 .66107 .26404 Metetra
.699 .761 .9 r
.66107 .26404 .66604 .27043 .6763 .26565 .67137 .25948 Metetra
.715 .775 .9 r
.67137 .25948 .6763 .26565 .68658 .26081 .68167 .25448 Metetra
.706 .767 .9 r
.68167 .25448 .68658 .26081 .6969 .25619 .69202 .24971 Metetra
.667 .749 .911 r
.69202 .24971 .6969 .25619 .70732 .25259 .70245 .24599 Metetra
.667 .745 .909 r
.70245 .24599 .70732 .25259 .71777 .24898 .71293 .24227 Metetra
.664 .741 .908 r
.71293 .24227 .71777 .24898 .72827 .24535 .72345 .23861 Metetra
.664 .741 .908 r
.72345 .23861 .72827 .24535 .7388 .24171 .73401 .23495 Metetra
.664 .741 .908 r
.73401 .23495 .7388 .24171 .74937 .23805 .74461 .23126 Metetra
.664 .741 .908 r
.74461 .23126 .74937 .23805 .75998 .23438 .75524 .22757 Metetra
.664 .741 .908 r
.75524 .22757 .75998 .23438 .77063 .2307 .76592 .22386 Metetra
.664 .741 .908 r
.76592 .22386 .77063 .2307 .78132 .227 .77664 .22014 Metetra
.664 .741 .908 r
.77664 .22014 .78132 .227 .79204 .22329 .78739 .2164 Metetra
.664 .741 .908 r
.78739 .2164 .79204 .22329 .80281 .21957 .79819 .21265 Metetra
.664 .741 .908 r
.79819 .21265 .80281 .21957 .81362 .21583 .80903 .20889 Metetra
.664 .741 .908 r
.80903 .20889 .81362 .21583 .82447 .21208 .81991 .20511 Metetra
.664 .741 .908 r
.2 .41272 .20602 .41832 .21474 .41529 .20874 .40967 Metetra
.664 .741 .908 r
.20874 .40967 .21474 .41529 .2235 .41225 .21751 .40661 Metetra
.664 .741 .908 r
.21751 .40661 .2235 .41225 .23228 .4092 .22632 .40354 Metetra
.664 .741 .908 r
.22632 .40354 .23228 .4092 .2411 .40614 .23515 .40046 Metetra
.664 .741 .908 r
.23515 .40046 .2411 .40614 .24994 .40307 .24401 .39737 Metetra
.664 .741 .908 r
.24401 .39737 .24994 .40307 .25882 .39998 .25291 .39426 Metetra
.664 .741 .908 r
.25291 .39426 .25882 .39998 .26773 .39689 .26183 .39115 Metetra
.664 .741 .908 r
.26183 .39115 .26773 .39689 .27666 .39379 .27078 .38803 Metetra
.664 .741 .908 r
.27078 .38803 .27666 .39379 .28563 .39067 .27977 .3849 Metetra
.664 .741 .908 r
.27977 .3849 .28563 .39067 .29463 .38755 .28879 .38175 Metetra
.652 .738 .913 r
.28879 .38175 .29463 .38755 .30365 .38449 .29781 .37886 Metetra
.65 .744 .919 r
.29781 .37886 .30365 .38449 .3127 .38144 .30687 .37602 Metetra
.606 .74 .939 r
.30687 .37602 .3127 .38144 .32172 .37941 .3159 .37401 Metetra
.594 .737 .944 r
.3159 .37401 .32172 .37941 .33076 .37761 .32496 .37219 Metetra
.627 .748 .934 r
.32496 .37219 .33076 .37761 .33987 .37538 .3341 .36977 Metetra
.636 .744 .926 r
.3341 .36977 .33987 .37538 .34902 .37302 .34328 .36716 Metetra
.637 .736 .92 r
.34328 .36716 .34902 .37302 .3582 .37064 .3525 .36454 Metetra
.637 .728 .914 r
.3525 .36454 .3582 .37064 .36743 .36826 .36175 .36191 Metetra
.646 .723 .904 r
.36175 .36191 .36743 .36826 .37671 .36535 .37104 .35907 Metetra
.65 .727 .906 r
.37104 .35907 .37671 .36535 .38604 .36221 .38038 .35615 Metetra
.631 .729 .918 r
.38038 .35615 .38604 .36221 .39537 .35963 .38973 .35361 Metetra
.622 .729 .923 r
.38973 .35361 .39537 .35963 .40474 .3573 .39912 .35126 Metetra
.647 .737 .915 r
.39912 .35126 .40474 .3573 .41414 .35501 .40856 .34837 Metetra
.658 .72 .895 r
.40856 .34837 .41414 .35501 .42358 .35274 .41804 .34517 Metetra
.615 .676 .885 r
.41804 .34517 .42358 .35274 .43304 .35099 .42753 .34304 Metetra
.586 .653 .883 r
.42753 .34304 .43304 .35099 .44253 .34955 .43704 .34158 Metetra
.586 .653 .883 r
.43704 .34158 .44253 .34955 .45208 .34811 .44659 .34011 Metetra
.586 .653 .883 r
.44659 .34011 .45208 .34811 .46166 .34666 .45619 .33864 Metetra
.626 .67 .872 r
.45619 .33864 .46166 .34666 .47129 .34509 .46585 .33616 Metetra
.652 .658 .843 r
.46585 .33616 .47129 .34509 .48097 .34341 .47557 .33285 Metetra
.645 .62 .811 r
.47557 .33285 .48097 .34341 .49071 .34087 .48532 .32951 Metetra
.642 .605 .797 r
.48532 .32951 .49071 .34087 .50049 .33751 .49511 .32612 Metetra
.643 .605 .796 r
.49511 .32612 .50049 .33751 .51031 .33334 .50493 .3227 Metetra
.647 .621 .81 r
.50493 .3227 .51031 .33334 .52016 .32828 .51479 .31924 Metetra
.678 .669 .834 r
.51479 .31924 .52016 .32828 .53003 .32313 .52468 .31494 Metetra
.711 .703 .84 r
.52468 .31494 .53003 .32313 .53993 .31784 .5346 .30963 Metetra
.711 .703 .84 r
.5346 .30963 .53993 .31784 .54986 .31254 .54454 .30431 Metetra
.711 .703 .84 r
.54454 .30431 .54986 .31254 .5598 .30723 .55451 .29898 Metetra
.693 .696 .848 r
.55451 .29898 .5598 .30723 .56978 .30224 .56451 .29431 Metetra
.662 .694 .869 r
.56451 .29431 .56978 .30224 .57979 .29775 .57456 .29073 Metetra
.676 .727 .888 r
.57456 .29073 .57979 .29775 .58983 .29329 .58463 .28683 Metetra
.697 .754 .895 r
.58463 .28683 .58983 .29329 .5999 .28886 .59473 .28238 Metetra
.69 .751 .898 r
.59473 .28238 .5999 .28886 .61001 .28469 .60487 .27811 Metetra
.675 .744 .902 r
.60487 .27811 .61001 .28469 .62017 .28108 .61505 .27424 Metetra
.678 .737 .895 r
.61505 .27424 .62017 .28108 .63036 .27723 .62526 .27028 Metetra
.684 .736 .89 r
.62526 .27028 .63036 .27723 .64057 .27285 .6355 .2661 Metetra
.685 .744 .896 r
.6355 .2661 .64057 .27285 .6508 .26845 .64577 .26191 Metetra
.686 .752 .902 r
.64577 .26191 .6508 .26845 .66107 .26404 .65607 .2577 Metetra
.693 .763 .905 r
.65607 .2577 .66107 .26404 .67137 .25948 .6664 .2533 Metetra
.715 .776 .9 r
.6664 .2533 .67137 .25948 .68167 .25448 .67674 .24827 Metetra
.708 .774 .904 r
.67674 .24827 .68167 .25448 .69202 .24971 .68711 .24343 Metetra
.676 .761 .915 r
.68711 .24343 .69202 .24971 .70245 .24599 .69756 .23945 Metetra
.674 .752 .91 r
.69756 .23945 .70245 .24599 .71293 .24227 .70806 .23551 Metetra
.664 .741 .908 r
.70806 .23551 .71293 .24227 .72345 .23861 .7186 .23183 Metetra
.664 .741 .908 r
.7186 .23183 .72345 .23861 .73401 .23495 .72919 .22814 Metetra
.664 .741 .908 r
.72919 .22814 .73401 .23495 .74461 .23126 .73981 .22443 Metetra
.664 .741 .908 r
.73981 .22443 .74461 .23126 .75524 .22757 .75048 .22071 Metetra
.664 .741 .908 r
.75048 .22071 .75524 .22757 .76592 .22386 .76118 .21698 Metetra
.664 .741 .908 r
.76118 .21698 .76592 .22386 .77664 .22014 .77193 .21323 Metetra
.664 .741 .908 r
.77193 .21323 .77664 .22014 .78739 .2164 .78271 .20947 Metetra
.664 .741 .908 r
.78271 .20947 .78739 .2164 .79819 .21265 .79354 .20569 Metetra
.664 .741 .908 r
.79354 .20569 .79819 .21265 .80903 .20889 .80441 .2019 Metetra
.664 .741 .908 r
.80441 .2019 .80903 .20889 .81991 .20511 .81531 .1981 Metetra
.664 .741 .908 r
.19394 .40708 .2 .41272 .20874 .40967 .2027 .40401 Metetra
.664 .741 .908 r
.2027 .40401 .20874 .40967 .21751 .40661 .21149 .40093 Metetra
.664 .741 .908 r
.21149 .40093 .21751 .40661 .22632 .40354 .22031 .39784 Metetra
.664 .741 .908 r
.22031 .39784 .22632 .40354 .23515 .40046 .22916 .39474 Metetra
.664 .741 .908 r
.22916 .39474 .23515 .40046 .24401 .39737 .23805 .39163 Metetra
.664 .741 .908 r
.23805 .39163 .24401 .39737 .25291 .39426 .24696 .38851 Metetra
.664 .741 .908 r
.24696 .38851 .25291 .39426 .26183 .39115 .2559 .38538 Metetra
.664 .741 .908 r
.2559 .38538 .26183 .39115 .27078 .38803 .26487 .38224 Metetra
.664 .741 .908 r
.26487 .38224 .27078 .38803 .27977 .3849 .27387 .37908 Metetra
.664 .741 .908 r
.27387 .37908 .27977 .3849 .28879 .38175 .28291 .37592 Metetra
.64 .735 .917 r
.28291 .37592 .28879 .38175 .29781 .37886 .29193 .37327 Metetra
.635 .743 .926 r
.29193 .37327 .29781 .37886 .30687 .37602 .30099 .37072 Metetra
.609 .747 .943 r
.30099 .37072 .30687 .37602 .3159 .37401 .31005 .36861 Metetra
.603 .742 .942 r
.31005 .36861 .3159 .37401 .32496 .37219 .31913 .3666 Metetra
.635 .745 .928 r
.31913 .3666 .32496 .37219 .3341 .36977 .3283 .36402 Metetra
.643 .742 .921 r
.3283 .36402 .3341 .36977 .34328 .36716 .3375 .36125 Metetra
.646 .738 .916 r
.3375 .36125 .34328 .36716 .3525 .36454 .34675 .3584 Metetra
.647 .731 .91 r
.34675 .3584 .3525 .36454 .36175 .36191 .35603 .35553 Metetra
.642 .721 .906 r
.35603 .35553 .36175 .36191 .37104 .35907 .36534 .35276 Metetra
.64 .724 .909 r
.36534 .35276 .37104 .35907 .38038 .35615 .37469 .35004 Metetra
.631 .729 .918 r
.37469 .35004 .38038 .35615 .38973 .35361 .38406 .3475 Metetra
.626 .728 .92 r
.38406 .3475 .38973 .35361 .39912 .35126 .39346 .34505 Metetra
.658 .735 .907 r
.39346 .34505 .39912 .35126 .40856 .34837 .40293 .34185 Metetra
.673 .731 .893 r
.40293 .34185 .40856 .34837 .41804 .34517 .41245 .33825 Metetra
.629 .703 .899 r
.41245 .33825 .41804 .34517 .42753 .34304 .42197 .33573 Metetra
.6 .68 .897 r
.42197 .33573 .42753 .34304 .43704 .34158 .4315 .33389 Metetra
.598 .668 .888 r
.4315 .33389 .43704 .34158 .44659 .34011 .44108 .3321 Metetra
.598 .659 .881 r
.44108 .3321 .44659 .34011 .45619 .33864 .4507 .33034 Metetra
.643 .67 .861 r
.4507 .33034 .45619 .33864 .46585 .33616 .46038 .32737 Metetra
.671 .67 .84 r
.46038 .32737 .46585 .33616 .47557 .33285 .47013 .32341 Metetra
.659 .65 .83 r
.47013 .32341 .47557 .33285 .48532 .32951 .47989 .31973 Metetra
.65 .64 .827 r
.47989 .31973 .48532 .32951 .49511 .32612 .48969 .31632 Metetra
.642 .636 .829 r
.48969 .31632 .49511 .32612 .50493 .3227 .49952 .31318 Metetra
.634 .639 .838 r
.49952 .31318 .50493 .3227 .51479 .31924 .50939 .31033 Metetra
.666 .668 .842 r
.50939 .31033 .51479 .31924 .52468 .31494 .5193 .30648 Metetra
.702 .694 .839 r
.5193 .30648 .52468 .31494 .5346 .30963 .52924 .30141 Metetra
.704 .701 .845 r
.52924 .30141 .5346 .30963 .54454 .30431 .5392 .29637 Metetra
.705 .709 .852 r
.5392 .29637 .54454 .30431 .55451 .29898 .5492 .29136 Metetra
.687 .713 .868 r
.5492 .29136 .55451 .29898 .56451 .29431 .55922 .28705 Metetra
.651 .71 .891 r
.55922 .28705 .56451 .29431 .57456 .29073 .5693 .28382 Metetra
.666 .729 .896 r
.5693 .28382 .57456 .29073 .58463 .28683 .5794 .28018 Metetra
.693 .747 .893 r
.5794 .28018 .58463 .28683 .59473 .28238 .58953 .2758 Metetra
.691 .749 .897 r
.58953 .2758 .59473 .28238 .60487 .27811 .59969 .27149 Metetra
.684 .747 .899 r
.59969 .27149 .60487 .27811 .61505 .27424 .60989 .26736 Metetra
.681 .738 .894 r
.60989 .26736 .61505 .27424 .62526 .27028 .62012 .26328 Metetra
.676 .733 .893 r
.62012 .26328 .62526 .27028 .6355 .2661 .63039 .2593 Metetra
.678 .741 .899 r
.63039 .2593 .6355 .2661 .64577 .26191 .6407 .25529 Metetra
.681 .749 .903 r
.6407 .25529 .64577 .26191 .65607 .2577 .65103 .2512 Metetra
.687 .757 .904 r
.65103 .2512 .65607 .2577 .6664 .2533 .6614 .24693 Metetra
.708 .769 .9 r
.6614 .24693 .6664 .2533 .67674 .24827 .67177 .24205 Metetra
.705 .774 .906 r
.67177 .24205 .67674 .24827 .68711 .24343 .68218 .23727 Metetra
.689 .772 .915 r
.68218 .23727 .68711 .24343 .69756 .23945 .69264 .23294 Metetra
.684 .759 .908 r
.69264 .23294 .69756 .23945 .70806 .23551 .70315 .22871 Metetra
.664 .741 .908 r
.70315 .22871 .70806 .23551 .7186 .23183 .71372 .225 Metetra
.664 .741 .908 r
.71372 .225 .7186 .23183 .72919 .22814 .72433 .22129 Metetra
.664 .741 .908 r
.72433 .22129 .72919 .22814 .73981 .22443 .73499 .21756 Metetra
.664 .741 .908 r
.73499 .21756 .73981 .22443 .75048 .22071 .74568 .21381 Metetra
.664 .741 .908 r
.74568 .21381 .75048 .22071 .76118 .21698 .75641 .21005 Metetra
.664 .741 .908 r
.75641 .21005 .76118 .21698 .77193 .21323 .76719 .20628 Metetra
.664 .741 .908 r
.76719 .20628 .77193 .21323 .78271 .20947 .778 .20249 Metetra
.664 .741 .908 r
.778 .20249 .78271 .20947 .79354 .20569 .78885 .19869 Metetra
.664 .741 .908 r
.78885 .19869 .79354 .20569 .80441 .2019 .79975 .19487 Metetra
.664 .741 .908 r
.79975 .19487 .80441 .2019 .81531 .1981 .81069 .19104 Metetra
.664 .741 .908 r
.18785 .40141 .19394 .40708 .2027 .40401 .19663 .39832 Metetra
.664 .741 .908 r
.19663 .39832 .2027 .40401 .21149 .40093 .20543 .39522 Metetra
.664 .741 .908 r
.20543 .39522 .21149 .40093 .22031 .39784 .21427 .39211 Metetra
.664 .741 .908 r
.21427 .39211 .22031 .39784 .22916 .39474 .22314 .38899 Metetra
.664 .741 .908 r
.22314 .38899 .22916 .39474 .23805 .39163 .23204 .38586 Metetra
.664 .741 .908 r
.23204 .38586 .23805 .39163 .24696 .38851 .24097 .38272 Metetra
.664 .741 .908 r
.24097 .38272 .24696 .38851 .2559 .38538 .24993 .37957 Metetra
.664 .741 .908 r
.24993 .37957 .2559 .38538 .26487 .38224 .25892 .3764 Metetra
.664 .741 .908 r
.25892 .3764 .26487 .38224 .27387 .37908 .26794 .37323 Metetra
.664 .741 .908 r
.26794 .37323 .27387 .37908 .28291 .37592 .27699 .37005 Metetra
.622 .729 .923 r
.27699 .37005 .28291 .37592 .29193 .37327 .28601 .36776 Metetra
.611 .74 .937 r
.28601 .36776 .29193 .37327 .30099 .37072 .29505 .36564 Metetra
.622 .761 .945 r
.29505 .36564 .30099 .37072 .31005 .36861 .30414 .36323 Metetra
.627 .752 .937 r
.30414 .36323 .31005 .36861 .31913 .3666 .31328 .36076 Metetra
.64 .739 .92 r
.31328 .36076 .31913 .3666 .3283 .36402 .32247 .35805 Metetra
.643 .736 .916 r
.32247 .35805 .3283 .36402 .3375 .36125 .33169 .35526 Metetra
.654 .739 .912 r
.33169 .35526 .3375 .36125 .34675 .3584 .34097 .35223 Metetra
.657 .734 .906 r
.34097 .35223 .34675 .3584 .35603 .35553 .35028 .3491 Metetra
.638 .72 .907 r
.35028 .3491 .35603 .35553 .36534 .35276 .35961 .34641 Metetra
.63 .721 .913 r
.35961 .34641 .36534 .35276 .37469 .35004 .36896 .3439 Metetra
.634 .73 .917 r
.36896 .3439 .37469 .35004 .38406 .3475 .37835 .34126 Metetra
.637 .728 .914 r
.37835 .34126 .38406 .3475 .39346 .34505 .38779 .33855 Metetra
.649 .724 .904 r
.38779 .33855 .39346 .34505 .40293 .34185 .39727 .33555 Metetra
.656 .734 .907 r
.39727 .33555 .40293 .34185 .41245 .33825 .40679 .33238 Metetra
.645 .747 .923 r
.40679 .33238 .41245 .33825 .42197 .33573 .41634 .32946 Metetra
.638 .731 .915 r
.41634 .32946 .42197 .33573 .4315 .33389 .42592 .32669 Metetra
.631 .697 .893 r
.42592 .32669 .4315 .33389 .44108 .3321 .43553 .32409 Metetra
.625 .671 .874 r
.43553 .32409 .44108 .3321 .4507 .33034 .44518 .32161 Metetra
.635 .657 .854 r
.44518 .32161 .4507 .33034 .46038 .32737 .45488 .31882 Metetra
.644 .666 .856 r
.45488 .31882 .46038 .32737 .47013 .32341 .46462 .31575 Metetra
.653 .695 .876 r
.46462 .31575 .47013 .32341 .47989 .31973 .4744 .31249 Metetra
.661 .711 .885 r
.4744 .31249 .47989 .31973 .48969 .31632 .48422 .30906 Metetra
.667 .713 .883 r
.48422 .30906 .48969 .31632 .49952 .31318 .49407 .30545 Metetra
.671 .701 .87 r
.49407 .30545 .49952 .31318 .50939 .31033 .50396 .30165 Metetra
.674 .678 .846 r
.50396 .30165 .50939 .31033 .5193 .30648 .51389 .29758 Metetra
.681 .676 .839 r
.51389 .29758 .5193 .30648 .52924 .30141 .52385 .29318 Metetra
.682 .694 .855 r
.52385 .29318 .52924 .30141 .5392 .29637 .53384 .2889 Metetra
.681 .716 .875 r
.53384 .2889 .5392 .29637 .5492 .29136 .54386 .2848 Metetra
.679 .744 .9 r
.54386 .2848 .5492 .29136 .55922 .28705 .55391 .28084 Metetra
.67 .755 .914 r
.55391 .28084 .55922 .28705 .5693 .28382 .56401 .27713 Metetra
.675 .74 .9 r
.56401 .27713 .5693 .28382 .5794 .28018 .57413 .27325 Metetra
.684 .737 .89 r
.57413 .27325 .5794 .28018 .58953 .2758 .58429 .26907 Metetra
.687 .745 .895 r
.58429 .26907 .58953 .2758 .59969 .27149 .59447 .26482 Metetra
.692 .749 .896 r
.59447 .26482 .59969 .27149 .60989 .26736 .60469 .26044 Metetra
.684 .739 .893 r
.60469 .26044 .60989 .26736 .62012 .26328 .61495 .25623 Metetra
.668 .73 .896 r
.61495 .25623 .62012 .26328 .63039 .2593 .62525 .25247 Metetra
.672 .739 .901 r
.62525 .25247 .63039 .2593 .6407 .25529 .63559 .2486 Metetra
.681 .748 .902 r
.63559 .2486 .6407 .25529 .65103 .2512 .64595 .24449 Metetra
.683 .749 .901 r
.64595 .24449 .65103 .2512 .6614 .24693 .65635 .24029 Metetra
.692 .756 .901 r
.65635 .24029 .6614 .24693 .67177 .24205 .66677 .23585 Metetra
.696 .773 .911 r
.66677 .23585 .67177 .24205 .68218 .23727 .67722 .23132 Metetra
.706 .787 .914 r
.67722 .23132 .68218 .23727 .69264 .23294 .68769 .22651 Metetra
.698 .768 .906 r
.68769 .22651 .69264 .23294 .70315 .22871 .6982 .22186 Metetra
.664 .741 .908 r
.6982 .22186 .70315 .22871 .71372 .225 .7088 .21813 Metetra
.664 .741 .908 r
.7088 .21813 .71372 .225 .72433 .22129 .71945 .21439 Metetra
.664 .741 .908 r
.71945 .21439 .72433 .22129 .73499 .21756 .73013 .21063 Metetra
.664 .741 .908 r
.73013 .21063 .73499 .21756 .74568 .21381 .74085 .20686 Metetra
.664 .741 .908 r
.74085 .20686 .74568 .21381 .75641 .21005 .75161 .20307 Metetra
.664 .741 .908 r
.75161 .20307 .75641 .21005 .76719 .20628 .76241 .19927 Metetra
.664 .741 .908 r
.76241 .19927 .76719 .20628 .778 .20249 .77325 .19546 Metetra
.664 .741 .908 r
.77325 .19546 .778 .20249 .78885 .19869 .78414 .19163 Metetra
.664 .741 .908 r
.78414 .19163 .78885 .19869 .79975 .19487 .79506 .18778 Metetra
.664 .741 .908 r
.79506 .18778 .79975 .19487 .81069 .19104 .80603 .18393 Metetra
.664 .741 .908 r
.18172 .3957 .18785 .40141 .19663 .39832 .19051 .39259 Metetra
.664 .741 .908 r
.19051 .39259 .19663 .39832 .20543 .39522 .19934 .38947 Metetra
.664 .741 .908 r
.19934 .38947 .20543 .39522 .21427 .39211 .20819 .38634 Metetra
.664 .741 .908 r
.20819 .38634 .21427 .39211 .22314 .38899 .21708 .3832 Metetra
.664 .741 .908 r
.21708 .3832 .22314 .38899 .23204 .38586 .22599 .38005 Metetra
.664 .741 .908 r
.22599 .38005 .23204 .38586 .24097 .38272 .23494 .37689 Metetra
.664 .741 .908 r
.23494 .37689 .24097 .38272 .24993 .37957 .24392 .37372 Metetra
.664 .741 .908 r
.24392 .37372 .24993 .37957 .25892 .3764 .25293 .37054 Metetra
.661 .741 .909 r
.25293 .37054 .25892 .3764 .26794 .37323 .26196 .36741 Metetra
.66 .743 .911 r
.26196 .36741 .26794 .37323 .27699 .37005 .27103 .36429 Metetra
.611 .731 .931 r
.27103 .36429 .27699 .37005 .28601 .36776 .28005 .36217 Metetra
.599 .735 .939 r
.28005 .36217 .28601 .36776 .29505 .36564 .28909 .36024 Metetra
.634 .754 .934 r
.28909 .36024 .29505 .36564 .30414 .36323 .29822 .35763 Metetra
.643 .749 .926 r
.29822 .35763 .30414 .36323 .31328 .36076 .30739 .35484 Metetra
.646 .739 .917 r
.30739 .35484 .31328 .36076 .32247 .35805 .31661 .35198 Metetra
.647 .735 .913 r
.31661 .35198 .32247 .35805 .33169 .35526 .32586 .34909 Metetra
.657 .735 .907 r
.32586 .34909 .33169 .35526 .34097 .35223 .33515 .34597 Metetra
.66 .733 .904 r
.33515 .34597 .34097 .35223 .35028 .3491 .34449 .34275 Metetra
.639 .725 .91 r
.34449 .34275 .35028 .3491 .35961 .34641 .35383 .34001 Metetra
.63 .721 .912 r
.35383 .34001 .35961 .34641 .36896 .3439 .3632 .33746 Metetra
.637 .722 .909 r
.3632 .33746 .36896 .3439 .37835 .34126 .37262 .33475 Metetra
.64 .722 .907 r
.37262 .33475 .37835 .34126 .38779 .33855 .38207 .33196 Metetra
.645 .721 .904 r
.38207 .33196 .38779 .33855 .39727 .33555 .39157 .32905 Metetra
.647 .726 .906 r
.39157 .32905 .39727 .33555 .40679 .33238 .4011 .32607 Metetra
.657 .736 .908 r
.4011 .32607 .40679 .33238 .41634 .32946 .41068 .32285 Metetra
.662 .728 .899 r
.41068 .32285 .41634 .32946 .42592 .32669 .4203 .31946 Metetra
.649 .705 .888 r
.4203 .31946 .42592 .32669 .43553 .32409 .42995 .31639 Metetra
.639 .687 .879 r
.42995 .31639 .43553 .32409 .44518 .32161 .43962 .31353 Metetra
.632 .674 .872 r
.43962 .31353 .44518 .32161 .45488 .31882 .44933 .31082 Metetra
.628 .676 .876 r
.44933 .31082 .45488 .31882 .46462 .31575 .45908 .30824 Metetra
.645 .697 .884 r
.45908 .30824 .46462 .31575 .4744 .31249 .46887 .30521 Metetra
.661 .711 .885 r
.46887 .30521 .4744 .31249 .48422 .30906 .47871 .30175 Metetra
.675 .716 .88 r
.47871 .30175 .48422 .30906 .49407 .30545 .48859 .29787 Metetra
.688 .713 .868 r
.48859 .29787 .49407 .30545 .50396 .30165 .4985 .29353 Metetra
.681 .696 .858 r
.4985 .29353 .50396 .30165 .51389 .29758 .50845 .28932 Metetra
.675 .691 .857 r
.50845 .28932 .51389 .29758 .52385 .29318 .51843 .28526 Metetra
.67 .699 .868 r
.51843 .28526 .52385 .29318 .53384 .2889 .52844 .28142 Metetra
.661 .709 .883 r
.52844 .28142 .53384 .2889 .54386 .2848 .53848 .27789 Metetra
.668 .73 .897 r
.53848 .27789 .54386 .2848 .55391 .28084 .54856 .27419 Metetra
.677 .743 .9 r
.54856 .27419 .55391 .28084 .56401 .27713 .55868 .27024 Metetra
.679 .736 .894 r
.55868 .27024 .56401 .27713 .57413 .27325 .56882 .26622 Metetra
.682 .734 .89 r
.56882 .26622 .57413 .27325 .58429 .26907 .57901 .26208 Metetra
.685 .737 .891 r
.57901 .26208 .58429 .26907 .59447 .26482 .58922 .25785 Metetra
.69 .74 .89 r
.58922 .25785 .59447 .26482 .60469 .26044 .59946 .25346 Metetra
.683 .739 .893 r
.59946 .25346 .60469 .26044 .61495 .25623 .60974 .24926 Metetra
.666 .733 .9 r
.60974 .24926 .61495 .25623 .62525 .25247 .62007 .24553 Metetra
.669 .736 .901 r
.62007 .24553 .62525 .25247 .63559 .2486 .63044 .24172 Metetra
.677 .742 .9 r
.63044 .24172 .63559 .2486 .64595 .24449 .64083 .23766 Metetra
.678 .745 .901 r
.64083 .23766 .64595 .24449 .65635 .24029 .65126 .23357 Metetra
.681 .751 .904 r
.65126 .23357 .65635 .24029 .66677 .23585 .66173 .2294 Metetra
.688 .763 .909 r
.66173 .2294 .66677 .23585 .67722 .23132 .67222 .22505 Metetra
.713 .779 .904 r
.67222 .22505 .67722 .23132 .68769 .22651 .68271 .21999 Metetra
.705 .769 .902 r
.68271 .21999 .68769 .22651 .6982 .22186 .69324 .21512 Metetra
.667 .748 .911 r
.69324 .21512 .6982 .22186 .7088 .21813 .70386 .21128 Metetra
.666 .745 .909 r
.70386 .21128 .7088 .21813 .71945 .21439 .71452 .20744 Metetra
.664 .741 .908 r
.71452 .20744 .71945 .21439 .73013 .21063 .72523 .20366 Metetra
.664 .741 .908 r
.72523 .20366 .73013 .21063 .74085 .20686 .73598 .19986 Metetra
.664 .741 .908 r
.73598 .19986 .74085 .20686 .75161 .20307 .74677 .19604 Metetra
.664 .741 .908 r
.74677 .19604 .75161 .20307 .76241 .19927 .7576 .19222 Metetra
.664 .741 .908 r
.7576 .19222 .76241 .19927 .77325 .19546 .76847 .18838 Metetra
.664 .741 .908 r
.76847 .18838 .77325 .19546 .78414 .19163 .77939 .18452 Metetra
.664 .741 .908 r
.77939 .18452 .78414 .19163 .79506 .18778 .79034 .18065 Metetra
.664 .741 .908 r
.79034 .18065 .79506 .18778 .80603 .18393 .80134 .17677 Metetra
.664 .741 .908 r
.17555 .38995 .18172 .3957 .19051 .39259 .18436 .38683 Metetra
.664 .741 .908 r
.18436 .38683 .19051 .39259 .19934 .38947 .1932 .38369 Metetra
.664 .741 .908 r
.1932 .38369 .19934 .38947 .20819 .38634 .20207 .38054 Metetra
.664 .741 .908 r
.20207 .38054 .20819 .38634 .21708 .3832 .21098 .37738 Metetra
.664 .741 .908 r
.21098 .37738 .21708 .3832 .22599 .38005 .21991 .37421 Metetra
.664 .741 .908 r
.21991 .37421 .22599 .38005 .23494 .37689 .22888 .37103 Metetra
.664 .741 .908 r
.22888 .37103 .23494 .37689 .24392 .37372 .23787 .36783 Metetra
.664 .741 .908 r
.23787 .36783 .24392 .37372 .25293 .37054 .2469 .36463 Metetra
.652 .738 .913 r
.2469 .36463 .25293 .37054 .26196 .36741 .25594 .36168 Metetra
.65 .745 .919 r
.25594 .36168 .26196 .36741 .27103 .36429 .265 .35876 Metetra
.618 .744 .936 r
.265 .35876 .27103 .36429 .28005 .36217 .27405 .35647 Metetra
.612 .736 .934 r
.27405 .35647 .28005 .36217 .28909 .36024 .28313 .3543 Metetra
.638 .736 .919 r
.28313 .3543 .28909 .36024 .29822 .35763 .29228 .35162 Metetra
.643 .736 .916 r
.29228 .35162 .29822 .35763 .30739 .35484 .30147 .34881 Metetra
.654 .739 .912 r
.30147 .34881 .30739 .35484 .31661 .35198 .31071 .34576 Metetra
.657 .734 .906 r
.31071 .34576 .31661 .35198 .32586 .34909 .32 .34262 Metetra
.652 .724 .902 r
.32 .34262 .32586 .34909 .33515 .34597 .32931 .33958 Metetra
.65 .728 .906 r
.32931 .33958 .33515 .34597 .34449 .34275 .33865 .33658 Metetra
.65 .736 .912 r
.33865 .33658 .34449 .34275 .35383 .34001 .34803 .33356 Metetra
.65 .727 .905 r
.34803 .33356 .35383 .34001 .3632 .33746 .35744 .33053 Metetra
.637 .707 .897 r
.35744 .33053 .3632 .33746 .37262 .33475 .36687 .32781 Metetra
.631 .705 .9 r
.36687 .32781 .37262 .33475 .38207 .33196 .37633 .32522 Metetra
.647 .718 .9 r
.37633 .32522 .38207 .33196 .39157 .32905 .38585 .32222 Metetra
.656 .719 .895 r
.38585 .32222 .39157 .32905 .4011 .32607 .39541 .319 Metetra
.659 .713 .888 r
.39541 .319 .4011 .32607 .41068 .32285 .40501 .31566 Metetra
.661 .711 .885 r
.40501 .31566 .41068 .32285 .4203 .31946 .41465 .31225 Metetra
.644 .705 .891 r
.41465 .31225 .4203 .31946 .42995 .31639 .42431 .30928 Metetra
.631 .704 .899 r
.42431 .30928 .42995 .31639 .43962 .31353 .434 .30663 Metetra
.634 .713 .904 r
.434 .30663 .43962 .31353 .44933 .31082 .44373 .30388 Metetra
.637 .713 .902 r
.44373 .30388 .44933 .31082 .45908 .30824 .4535 .30105 Metetra
.65 .71 .892 r
.4535 .30105 .45908 .30824 .46887 .30521 .46331 .29788 Metetra
.661 .711 .885 r
.46331 .29788 .46887 .30521 .47871 .30175 .47317 .2944 Metetra
.671 .715 .881 r
.47317 .2944 .47871 .30175 .48859 .29787 .48307 .29061 Metetra
.683 .722 .879 r
.48307 .29061 .48859 .29787 .4985 .29353 .493 .28648 Metetra
.686 .73 .884 r
.493 .28648 .4985 .29353 .50845 .28932 .50297 .28226 Metetra
.689 .732 .883 r
.50297 .28226 .50845 .28932 .51843 .28526 .51297 .27795 Metetra
.677 .721 .882 r
.51297 .27795 .51843 .28526 .52844 .28142 .523 .27395 Metetra
.661 .711 .885 r
.523 .27395 .52844 .28142 .53848 .27789 .53307 .27039 Metetra
.663 .712 .884 r
.53307 .27039 .53848 .27789 .54856 .27419 .54317 .26675 Metetra
.667 .716 .885 r
.54317 .26675 .54856 .27419 .55868 .27024 .55331 .26301 Metetra
.675 .726 .888 r
.55331 .26301 .55868 .27024 .56882 .26622 .56348 .25903 Metetra
.689 .733 .884 r
.56348 .25903 .56882 .26622 .57901 .26208 .57368 .25464 Metetra
.683 .724 .881 r
.57368 .25464 .57901 .26208 .58922 .25785 .58392 .25038 Metetra
.672 .719 .884 r
.58392 .25038 .58922 .25785 .59946 .25346 .5942 .24642 Metetra
.674 .735 .896 r
.5942 .24642 .59946 .25346 .60974 .24926 .60451 .24246 Metetra
.675 .744 .903 r
.60451 .24246 .60974 .24926 .62007 .24553 .61486 .23848 Metetra
.673 .735 .897 r
.61486 .23848 .62007 .24553 .63044 .24172 .62525 .23452 Metetra
.668 .73 .896 r
.62525 .23452 .63044 .24172 .64083 .23766 .63567 .23067 Metetra
.671 .739 .901 r
.63567 .23067 .64083 .23766 .65126 .23357 .64614 .22673 Metetra
.681 .748 .902 r
.64614 .22673 .65126 .23357 .66173 .2294 .65663 .22254 Metetra
.685 .75 .901 r
.65663 .22254 .66173 .2294 .67222 .22505 .66715 .2182 Metetra
.702 .757 .895 r
.66715 .2182 .67222 .22505 .68271 .21999 .67768 .21335 Metetra
.699 .764 .902 r
.67768 .21335 .68271 .21999 .69324 .21512 .68825 .20861 Metetra
.676 .761 .915 r
.68825 .20861 .69324 .21512 .70386 .21128 .69889 .20451 Metetra
.674 .752 .91 r
.69889 .20451 .70386 .21128 .71452 .20744 .70957 .20044 Metetra
.664 .741 .908 r
.70957 .20044 .71452 .20744 .72523 .20366 .7203 .19663 Metetra
.664 .741 .908 r
.7203 .19663 .72523 .20366 .73598 .19986 .73108 .19281 Metetra
.664 .741 .908 r
.73108 .19281 .73598 .19986 .74677 .19604 .7419 .18897 Metetra
.664 .741 .908 r
.7419 .18897 .74677 .19604 .7576 .19222 .75276 .18512 Metetra
.664 .741 .908 r
.75276 .18512 .7576 .19222 .76847 .18838 .76366 .18125 Metetra
.664 .741 .908 r
.76366 .18125 .76847 .18838 .77939 .18452 .7746 .17736 Metetra
.664 .741 .908 r
.7746 .17736 .77939 .18452 .79034 .18065 .78558 .17347 Metetra
.664 .741 .908 r
.78558 .17347 .79034 .18065 .80134 .17677 .79661 .16955 Metetra
.664 .741 .908 r
.16934 .38417 .17555 .38995 .18436 .38683 .17817 .38102 Metetra
.664 .741 .908 r
.17817 .38102 .18436 .38683 .1932 .38369 .18703 .37787 Metetra
.664 .741 .908 r
.18703 .37787 .1932 .38369 .20207 .38054 .19592 .3747 Metetra
.664 .741 .908 r
.19592 .3747 .20207 .38054 .21098 .37738 .20484 .37152 Metetra
.664 .741 .908 r
.20484 .37152 .21098 .37738 .21991 .37421 .21379 .36833 Metetra
.664 .741 .908 r
.21379 .36833 .21991 .37421 .22888 .37103 .22277 .36512 Metetra
.664 .741 .908 r
.22277 .36512 .22888 .37103 .23787 .36783 .23179 .36191 Metetra
.664 .741 .908 r
.23179 .36191 .23787 .36783 .2469 .36463 .24083 .35869 Metetra
.64 .735 .917 r
.24083 .35869 .2469 .36463 .25594 .36168 .24986 .35598 Metetra
.636 .743 .926 r
.24986 .35598 .25594 .36168 .265 .35876 .25892 .35334 Metetra
.628 .752 .936 r
.25892 .35334 .265 .35876 .27405 .35647 .26801 .35083 Metetra
.627 .744 .931 r
.26801 .35083 .27405 .35647 .28313 .3543 .27712 .34833 Metetra
.641 .737 .919 r
.27712 .34833 .28313 .3543 .29228 .35162 .2863 .34558 Metetra
.643 .736 .916 r
.2863 .34558 .29228 .35162 .30147 .34881 .29551 .34275 Metetra
.659 .74 .91 r
.29551 .34275 .30147 .34881 .31071 .34576 .30478 .33955 Metetra
.663 .737 .905 r
.30478 .33955 .31071 .34576 .32 .34262 .31409 .33624 Metetra
.649 .728 .907 r
.31409 .33624 .32 .34262 .32931 .33958 .32342 .33326 Metetra
.644 .729 .911 r
.32342 .33326 .32931 .33958 .33865 .33658 .33277 .33038 Metetra
.658 .739 .909 r
.33277 .33038 .33865 .33658 .34803 .33356 .34218 .32717 Metetra
.663 .734 .903 r
.34218 .32717 .34803 .33356 .35744 .33053 .35162 .32381 Metetra
.641 .717 .903 r
.35162 .32381 .35744 .33053 .36687 .32781 .36108 .32097 Metetra
.63 .71 .904 r
.36108 .32097 .36687 .32781 .37633 .32522 .37056 .31837 Metetra
.649 .717 .897 r
.37056 .31837 .37633 .32522 .38585 .32222 .38009 .3153 Metetra
.659 .718 .892 r
.38009 .3153 .38585 .32222 .39541 .319 .38968 .31197 Metetra
.659 .716 .89 r
.38968 .31197 .39541 .319 .40501 .31566 .3993 .30862 Metetra
.659 .716 .891 r
.3993 .30862 .40501 .31566 .41465 .31225 .40896 .30527 Metetra
.644 .713 .898 r
.40896 .30527 .41465 .31225 .42431 .30928 .41863 .30227 Metetra
.634 .709 .901 r
.41863 .30227 .42431 .30928 .434 .30663 .42834 .29952 Metetra
.641 .71 .897 r
.42834 .29952 .434 .30663 .44373 .30388 .43809 .29659 Metetra
.646 .707 .891 r
.43809 .29659 .44373 .30388 .4535 .30105 .44789 .29351 Metetra
.653 .702 .883 r
.44789 .29351 .4535 .30105 .46331 .29788 .45772 .29021 Metetra
.66 .701 .878 r
.45772 .29021 .46331 .29788 .47317 .2944 .4676 .2867 Metetra
.666 .704 .875 r
.4676 .2867 .47317 .2944 .48307 .29061 .47752 .28299 Metetra
.674 .71 .875 r
.47752 .28299 .48307 .29061 .493 .28648 .48747 .27907 Metetra
.679 .719 .879 r
.48747 .27907 .493 .28648 .50297 .28226 .49746 .27499 Metetra
.686 .726 .88 r
.49746 .27499 .50297 .28226 .51297 .27795 .50748 .27071 Metetra
.677 .725 .885 r
.50748 .27071 .51297 .27795 .523 .27395 .51753 .2667 Metetra
.664 .72 .891 r
.51753 .2667 .523 .27395 .53307 .27039 .52762 .26304 Metetra
.664 .718 .889 r
.52762 .26304 .53307 .27039 .54317 .26675 .53775 .25937 Metetra
.664 .718 .888 r
.53775 .25937 .54317 .26675 .55331 .26301 .54791 .25568 Metetra
.673 .724 .887 r
.54791 .25568 .55331 .26301 .56348 .25903 .55811 .25173 Metetra
.689 .731 .882 r
.55811 .25173 .56348 .25903 .57368 .25464 .56833 .2473 Metetra
.681 .727 .885 r
.56833 .2473 .57368 .25464 .58392 .25038 .57859 .24311 Metetra
.662 .724 .895 r
.57859 .24311 .58392 .25038 .5942 .24642 .5889 .23945 Metetra
.668 .736 .901 r
.5889 .23945 .5942 .24642 .60451 .24246 .59924 .23563 Metetra
.681 .746 .901 r
.59924 .23563 .60451 .24246 .61486 .23848 .60961 .23147 Metetra
.676 .74 .899 r
.60961 .23147 .61486 .23848 .62525 .23452 .62002 .22741 Metetra
.663 .732 .901 r
.62002 .22741 .62525 .23452 .63567 .23067 .63048 .22369 Metetra
.667 .739 .904 r
.63048 .22369 .63567 .23067 .64614 .22673 .64098 .21985 Metetra
.681 .748 .902 r
.64098 .21985 .64614 .22673 .65663 .22254 .6515 .21563 Metetra
.683 .749 .901 r
.6515 .21563 .65663 .22254 .66715 .2182 .66205 .21133 Metetra
.692 .754 .899 r
.66205 .21133 .66715 .2182 .67768 .21335 .67262 .20675 Metetra
.692 .765 .907 r
.67262 .20675 .67768 .21335 .68825 .20861 .68323 .20219 Metetra
.688 .771 .915 r
.68323 .20219 .68825 .20861 .69889 .20451 .69388 .19776 Metetra
.684 .758 .908 r
.69388 .19776 .69889 .20451 .70957 .20044 .70458 .1934 Metetra
.664 .741 .908 r
.70458 .1934 .70957 .20044 .7203 .19663 .71534 .18956 Metetra
.664 .741 .908 r
.71534 .18956 .7203 .19663 .73108 .19281 .72615 .18571 Metetra
.664 .741 .908 r
.72615 .18571 .73108 .19281 .7419 .18897 .73699 .18184 Metetra
.664 .741 .908 r
.73699 .18184 .7419 .18897 .75276 .18512 .74788 .17796 Metetra
.664 .741 .908 r
.74788 .17796 .75276 .18512 .76366 .18125 .75881 .17407 Metetra
.664 .741 .908 r
.75881 .17407 .76366 .18125 .7746 .17736 .76978 .17016 Metetra
.664 .741 .908 r
.76978 .17016 .7746 .17736 .78558 .17347 .7808 .16623 Metetra
.664 .741 .908 r
.7808 .16623 .78558 .17347 .79661 .16955 .79185 .16229 Metetra
.664 .741 .908 r
.16309 .37835 .16934 .38417 .17817 .38102 .17193 .37518 Metetra
.664 .741 .908 r
.17193 .37518 .17817 .38102 .18703 .37787 .18081 .37201 Metetra
.664 .741 .908 r
.18081 .37201 .18703 .37787 .19592 .3747 .18972 .36882 Metetra
.664 .741 .908 r
.18972 .36882 .19592 .3747 .20484 .37152 .19866 .36562 Metetra
.664 .741 .908 r
.19866 .36562 .20484 .37152 .21379 .36833 .20763 .36241 Metetra
.664 .741 .908 r
.20763 .36241 .21379 .36833 .22277 .36512 .21663 .35918 Metetra
.664 .741 .908 r
.21663 .35918 .22277 .36512 .23179 .36191 .22566 .35595 Metetra
.664 .741 .908 r
.22566 .35595 .23179 .36191 .24083 .35869 .23473 .35271 Metetra
.621 .729 .924 r
.23473 .35271 .24083 .35869 .24986 .35598 .24374 .35037 Metetra
.612 .741 .937 r
.24374 .35037 .24986 .35598 .25892 .35334 .25278 .34816 Metetra
.642 .767 .939 r
.25278 .34816 .25892 .35334 .26801 .35083 .26191 .34533 Metetra
.649 .757 .928 r
.26191 .34533 .26801 .35083 .27712 .34833 .27108 .34236 Metetra
.645 .739 .918 r
.27108 .34236 .27712 .34833 .2863 .34558 .28028 .33949 Metetra
.643 .736 .916 r
.28028 .33949 .2863 .34558 .29551 .34275 .28951 .33665 Metetra
.659 .74 .91 r
.28951 .33665 .29551 .34275 .30478 .33955 .2988 .33343 Metetra
.663 .742 .908 r
.2988 .33343 .30478 .33955 .31409 .33624 .30813 .33009 Metetra
.649 .737 .914 r
.30813 .33009 .31409 .33624 .32342 .33326 .31748 .32709 Metetra
.643 .736 .916 r
.31748 .32709 .32342 .33326 .33277 .33038 .32685 .3242 Metetra
.658 .74 .911 r
.32685 .3242 .33277 .33038 .34218 .32717 .33627 .32096 Metetra
.663 .742 .908 r
.33627 .32096 .34218 .32717 .35162 .32381 .34574 .31758 Metetra
.654 .739 .912 r
.34574 .31758 .35162 .32381 .36108 .32097 .35523 .31441 Metetra
.65 .727 .905 r
.35523 .31441 .36108 .32097 .37056 .31837 .36475 .31132 Metetra
.65 .712 .893 r
.36475 .31132 .37056 .31837 .38009 .3153 .37431 .30822 Metetra
.65 .712 .893 r
.37431 .30822 .38009 .3153 .38968 .31197 .3839 .30509 Metetra
.65 .719 .899 r
.3839 .30509 .38968 .31197 .3993 .30862 .39354 .30195 Metetra
.65 .727 .905 r
.39354 .30195 .3993 .30862 .40896 .30527 .4032 .2988 Metetra
.657 .737 .908 r
.4032 .2988 .40896 .30527 .41863 .30227 .41291 .29548 Metetra
.661 .728 .899 r
.41291 .29548 .41863 .30227 .42834 .29952 .42266 .29202 Metetra
.657 .705 .882 r
.42266 .29202 .42834 .29952 .43809 .29659 .43244 .28863 Metetra
.653 .69 .873 r
.43244 .28863 .43809 .29659 .44789 .29351 .44226 .28529 Metetra
.655 .685 .866 r
.44226 .28529 .44789 .29351 .45772 .29021 .45212 .28185 Metetra
.657 .683 .863 r
.45212 .28185 .45772 .29021 .4676 .2867 .46201 .27832 Metetra
.66 .684 .862 r
.46201 .27832 .4676 .2867 .47752 .28299 .47194 .2747 Metetra
.663 .688 .863 r
.47194 .2747 .47752 .28299 .48747 .27907 .48191 .27098 Metetra
.662 .694 .869 r
.48191 .27098 .48747 .27907 .49746 .27499 .49191 .26731 Metetra
.661 .706 .881 r
.49191 .26731 .49746 .27499 .50748 .27071 .50195 .26371 Metetra
.668 .73 .896 r
.50195 .26371 .50748 .27071 .51753 .2667 .51203 .25997 Metetra
.674 .743 .902 r
.51203 .25997 .51753 .2667 .52762 .26304 .52214 .25606 Metetra
.674 .735 .896 r
.52214 .25606 .52762 .26304 .53775 .25937 .53229 .25213 Metetra
.673 .727 .89 r
.53229 .25213 .53775 .25937 .54791 .25568 .54247 .24819 Metetra
.672 .72 .885 r
.54247 .24819 .54791 .25568 .55811 .25173 .55269 .24423 Metetra
.673 .72 .885 r
.55269 .24423 .55811 .25173 .56833 .2473 .56295 .24023 Metetra
.671 .734 .897 r
.56295 .24023 .56833 .2473 .57859 .24311 .57324 .23633 Metetra
.663 .742 .908 r
.57324 .23633 .57859 .24311 .5889 .23945 .58357 .23264 Metetra
.668 .744 .907 r
.58357 .23264 .5889 .23945 .59924 .23563 .59394 .2288 Metetra
.681 .748 .902 r
.59394 .2288 .59924 .23563 .60961 .23147 .60434 .22461 Metetra
.676 .746 .904 r
.60434 .22461 .60961 .23147 .62002 .22741 .61478 .22053 Metetra
.663 .742 .908 r
.61478 .22053 .62002 .22741 .63048 .22369 .62526 .21678 Metetra
.667 .743 .907 r
.62526 .21678 .63048 .22369 .64098 .21985 .63578 .21292 Metetra
.681 .748 .902 r
.63578 .21292 .64098 .21985 .6515 .21563 .64633 .20867 Metetra
.68 .748 .903 r
.64633 .20867 .6515 .21563 .66205 .21133 .65691 .20443 Metetra
.676 .749 .906 r
.65691 .20443 .66205 .21133 .67262 .20675 .66754 .2003 Metetra
.681 .768 .916 r
.66754 .2003 .67262 .20675 .68323 .20219 .67819 .19603 Metetra
.705 .787 .915 r
.67819 .19603 .68323 .20219 .69388 .19776 .68885 .1911 Metetra
.699 .769 .906 r
.68885 .1911 .69388 .19776 .70458 .1934 .69955 .1863 Metetra
.664 .741 .908 r
.69955 .1863 .70458 .1934 .71534 .18956 .71034 .18244 Metetra
.664 .741 .908 r
.71034 .18244 .71534 .18956 .72615 .18571 .72118 .17856 Metetra
.664 .741 .908 r
.72118 .17856 .72615 .18571 .73699 .18184 .73205 .17467 Metetra
.664 .741 .908 r
.73205 .17467 .73699 .18184 .74788 .17796 .74297 .17076 Metetra
.664 .741 .908 r
.74297 .17076 .74788 .17796 .75881 .17407 .75393 .16684 Metetra
.664 .741 .908 r
.75393 .16684 .75881 .17407 .76978 .17016 .76493 .1629 Metetra
.664 .741 .908 r
.76493 .1629 .76978 .17016 .7808 .16623 .77597 .15894 Metetra
.664 .741 .908 r
.77597 .15894 .7808 .16623 .79185 .16229 .78706 .15498 Metetra
.664 .741 .908 r
.1568 .3725 .16309 .37835 .17193 .37518 .16566 .36931 Metetra
.664 .741 .908 r
.16566 .36931 .17193 .37518 .18081 .37201 .17456 .36611 Metetra
.664 .741 .908 r
.17456 .36611 .18081 .37201 .18972 .36882 .18348 .3629 Metetra
.664 .741 .908 r
.18348 .3629 .18972 .36882 .19866 .36562 .19244 .35968 Metetra
.664 .741 .908 r
.19244 .35968 .19866 .36562 .20763 .36241 .20143 .35645 Metetra
.664 .741 .908 r
.20143 .35645 .20763 .36241 .21663 .35918 .21045 .35321 Metetra
.661 .741 .909 r
.21045 .35321 .21663 .35918 .22566 .35595 .21949 .35001 Metetra
.661 .743 .911 r
.21949 .35001 .22566 .35595 .23473 .35271 .22857 .34681 Metetra
.606 .729 .932 r
.22857 .34681 .23473 .35271 .24374 .35037 .23757 .34474 Metetra
.594 .736 .943 r
.23757 .34474 .24374 .35037 .25278 .34816 .2466 .34284 Metetra
.656 .766 .931 r
.2466 .34284 .25278 .34816 .26191 .34533 .25577 .33971 Metetra
.667 .759 .919 r
.25577 .33971 .26191 .34533 .27108 .34236 .265 .33633 Metetra
.65 .741 .915 r
.265 .33633 .27108 .34236 .28028 .33949 .27422 .33332 Metetra
.646 .735 .914 r
.27422 .33332 .28028 .33949 .28951 .33665 .28348 .33038 Metetra
.659 .736 .907 r
.28348 .33038 .28951 .33665 .2988 .33343 .29279 .32713 Metetra
.663 .737 .905 r
.29279 .32713 .2988 .33343 .30813 .33009 .30214 .32377 Metetra
.649 .733 .91 r
.30214 .32377 .30813 .33009 .31748 .32709 .31151 .32075 Metetra
.644 .731 .912 r
.31151 .32075 .31748 .32709 .32685 .3242 .32089 .31783 Metetra
.658 .735 .907 r
.32089 .31783 .32685 .3242 .33627 .32096 .33034 .31457 Metetra
.663 .737 .905 r
.33034 .31457 .33627 .32096 .34574 .31758 .33983 .31117 Metetra
.661 .736 .906 r
.33983 .31117 .34574 .31758 .35523 .31441 .34935 .3078 Metetra
.66 .73 .901 r
.34935 .3078 .35523 .31441 .36475 .31132 .3589 .30444 Metetra
.651 .719 .898 r
.3589 .30444 .36475 .31132 .37431 .30822 .36848 .30128 Metetra
.646 .716 .899 r
.36848 .30128 .37431 .30822 .3839 .30509 .37809 .29822 Metetra
.646 .719 .901 r
.37809 .29822 .3839 .30509 .39354 .30195 .38774 .29516 Metetra
.646 .723 .904 r
.38774 .29516 .39354 .30195 .4032 .2988 .39742 .29208 Metetra
.664 .732 .9 r
.39742 .29208 .4032 .2988 .41291 .29548 .40716 .28857 Metetra
.674 .73 .891 r
.40716 .28857 .41291 .29548 .42266 .29202 .41694 .28473 Metetra
.665 .715 .886 r
.41694 .28473 .42266 .29202 .43244 .28863 .42675 .2811 Metetra
.658 .706 .883 r
.42675 .2811 .43244 .28863 .44226 .28529 .43659 .27764 Metetra
.659 .704 .88 r
.43659 .27764 .44226 .28529 .45212 .28185 .44646 .27413 Metetra
.66 .703 .879 r
.44646 .27413 .45212 .28185 .46201 .27832 .45638 .27058 Metetra
.661 .703 .878 r
.45638 .27058 .46201 .27832 .47194 .2747 .46633 .26698 Metetra
.662 .705 .879 r
.46633 .26698 .47194 .2747 .48191 .27098 .47631 .26333 Metetra
.656 .706 .884 r
.47631 .26333 .48191 .27098 .49191 .26731 .48633 .25985 Metetra
.649 .709 .892 r
.48633 .25985 .49191 .26731 .50195 .26371 .49639 .25658 Metetra
.661 .725 .897 r
.49639 .25658 .50195 .26371 .51203 .25997 .50649 .25299 Metetra
.677 .736 .895 r
.50649 .25299 .51203 .25997 .52214 .25606 .51663 .24895 Metetra
.677 .733 .893 r
.51663 .24895 .52214 .25606 .53229 .25213 .5268 .2449 Metetra
.677 .73 .89 r
.5268 .2449 .53229 .25213 .54247 .24819 .537 .24084 Metetra
.672 .725 .889 r
.537 .24084 .54247 .24819 .55269 .24423 .54725 .23688 Metetra
.664 .723 .893 r
.54725 .23688 .55269 .24423 .56295 .24023 .55753 .23312 Metetra
.664 .732 .9 r
.55753 .23312 .56295 .24023 .57324 .23633 .56785 .22937 Metetra
.663 .737 .905 r
.56785 .22937 .57324 .23633 .58357 .23264 .5782 .22566 Metetra
.668 .739 .903 r
.5782 .22566 .58357 .23264 .59394 .2288 .5886 .22179 Metetra
.68 .743 .899 r
.5886 .22179 .59394 .2288 .60434 .22461 .59902 .21757 Metetra
.676 .742 .9 r
.59902 .21757 .60434 .22461 .61478 .22053 .60949 .21346 Metetra
.663 .737 .905 r
.60949 .21346 .61478 .22053 .62526 .21678 .62 .20969 Metetra
.666 .738 .904 r
.62 .20969 .62526 .21678 .63578 .21292 .63055 .20581 Metetra
.678 .743 .9 r
.63055 .20581 .63578 .21292 .64633 .20867 .64112 .20161 Metetra
.675 .744 .903 r
.64112 .20161 .64633 .20867 .65691 .20443 .65174 .19748 Metetra
.661 .743 .911 r
.65174 .19748 .65691 .20443 .66754 .2003 .66241 .19371 Metetra
.671 .761 .918 r
.66241 .19371 .66754 .2003 .67819 .19603 .67311 .1897 Metetra
.716 .787 .907 r
.67311 .1897 .67819 .19603 .68885 .1911 .68378 .18441 Metetra
.709 .773 .902 r
.68378 .18441 .68885 .1911 .69955 .1863 .6945 .17929 Metetra
.666 .747 .91 r
.6945 .17929 .69955 .1863 .71034 .18244 .70532 .17533 Metetra
.666 .744 .909 r
.70532 .17533 .71034 .18244 .72118 .17856 .71617 .17136 Metetra
.664 .741 .908 r
.71617 .17136 .72118 .17856 .73205 .17467 .72708 .16744 Metetra
.664 .741 .908 r
.72708 .16744 .73205 .17467 .74297 .17076 .73802 .1635 Metetra
.664 .741 .908 r
.73802 .1635 .74297 .17076 .75393 .16684 .74901 .15955 Metetra
.664 .741 .908 r
.74901 .15955 .75393 .16684 .76493 .1629 .76004 .15559 Metetra
.664 .741 .908 r
.76004 .15559 .76493 .1629 .77597 .15894 .77112 .15161 Metetra
.664 .741 .908 r
.77112 .15161 .77597 .15894 .78706 .15498 .78223 .14761 Metetra
.664 .741 .908 r
.15047 .3666 .1568 .3725 .16566 .36931 .15935 .3634 Metetra
.664 .741 .908 r
.15935 .3634 .16566 .36931 .17456 .36611 .16826 .36018 Metetra
.664 .741 .908 r
.16826 .36018 .17456 .36611 .18348 .3629 .17721 .35695 Metetra
.664 .741 .908 r
.17721 .35695 .18348 .3629 .19244 .35968 .18618 .35371 Metetra
.664 .741 .908 r
.18618 .35371 .19244 .35968 .20143 .35645 .19519 .35045 Metetra
.664 .741 .908 r
.19519 .35045 .20143 .35645 .21045 .35321 .20423 .34719 Metetra
.652 .738 .913 r
.20423 .34719 .21045 .35321 .21949 .35001 .21327 .34418 Metetra
.651 .745 .919 r
.21327 .34418 .21949 .35001 .22857 .34681 .22234 .34118 Metetra
.602 .739 .941 r
.22234 .34118 .22857 .34681 .23757 .34474 .23136 .33913 Metetra
.593 .737 .944 r
.23136 .33913 .23757 .34474 .2466 .34284 .24041 .3372 Metetra
.665 .758 .92 r
.24041 .3372 .2466 .34284 .25577 .33971 .24962 .33386 Metetra
.676 .754 .91 r
.24962 .33386 .25577 .33971 .265 .33633 .25888 .33024 Metetra
.66 .742 .911 r
.25888 .33024 .265 .33633 .27422 .33332 .26814 .32697 Metetra
.656 .733 .906 r
.26814 .32697 .27422 .33332 .28348 .33038 .27743 .32379 Metetra
.661 .727 .898 r
.27743 .32379 .28348 .33038 .29279 .32713 .28677 .32046 Metetra
.662 .726 .896 r
.28677 .32046 .29279 .32713 .30214 .32377 .29614 .31708 Metetra
.649 .721 .902 r
.29614 .31708 .30214 .32377 .31151 .32075 .30552 .31403 Metetra
.644 .72 .904 r
.30552 .31403 .31151 .32075 .32089 .31783 .31493 .31109 Metetra
.657 .724 .899 r
.31493 .31109 .32089 .31783 .33034 .31457 .32439 .30781 Metetra
.662 .726 .896 r
.32439 .30781 .33034 .31457 .33983 .31117 .3339 .30439 Metetra
.654 .723 .9 r
.3339 .30439 .33983 .31117 .34935 .3078 .34343 .30115 Metetra
.651 .727 .905 r
.34343 .30115 .34935 .3078 .3589 .30444 .35299 .29799 Metetra
.654 .736 .91 r
.35299 .29799 .3589 .30444 .36848 .30128 .36259 .29474 Metetra
.656 .734 .907 r
.36259 .29474 .36848 .30128 .37809 .29822 .37223 .29144 Metetra
.656 .727 .901 r
.37223 .29144 .37809 .29822 .38774 .29516 .38191 .28812 Metetra
.655 .719 .895 r
.38191 .28812 .38774 .29516 .39742 .29208 .39162 .28479 Metetra
.656 .712 .889 r
.39162 .28479 .39742 .29208 .40716 .28857 .40137 .28142 Metetra
.657 .718 .893 r
.40137 .28142 .40716 .28857 .41694 .28473 .41116 .27802 Metetra
.654 .732 .906 r
.41116 .27802 .41694 .28473 .42675 .2811 .42098 .2747 Metetra
.651 .742 .916 r
.42098 .2747 .42675 .2811 .43659 .27764 .43083 .27145 Metetra
.658 .752 .92 r
.43083 .27145 .43659 .27764 .44646 .27413 .44073 .26803 Metetra
.664 .758 .921 r
.44073 .26803 .44646 .27413 .45638 .27058 .45067 .26445 Metetra
.669 .76 .918 r
.45067 .26445 .45638 .27058 .46633 .26698 .46064 .26072 Metetra
.675 .758 .913 r
.46064 .26072 .46633 .26698 .47631 .26333 .47066 .25681 Metetra
.672 .749 .909 r
.47066 .25681 .47631 .26333 .48633 .25985 .48071 .25297 Metetra
.668 .736 .901 r
.48071 .25297 .48633 .25985 .49639 .25658 .49079 .24922 Metetra
.667 .721 .89 r
.49079 .24922 .49639 .25658 .50649 .25299 .50092 .24543 Metetra
.667 .716 .885 r
.50092 .24543 .50649 .25299 .51663 .24895 .51107 .24159 Metetra
.668 .724 .891 r
.51107 .24159 .51663 .24895 .5268 .2449 .52127 .23775 Metetra
.669 .731 .897 r
.52127 .23775 .5268 .2449 .537 .24084 .5315 .23389 Metetra
.671 .74 .902 r
.5315 .23389 .537 .24084 .54725 .23688 .54177 .22998 Metetra
.674 .743 .902 r
.54177 .22998 .54725 .23688 .55753 .23312 .55207 .22596 Metetra
.67 .734 .898 r
.55207 .22596 .55753 .23312 .56785 .22937 .56241 .22203 Metetra
.662 .726 .896 r
.56241 .22203 .56785 .22937 .5782 .22566 .5728 .21829 Metetra
.667 .728 .895 r
.5728 .21829 .5782 .22566 .5886 .22179 .58321 .2144 Metetra
.679 .732 .89 r
.58321 .2144 .5886 .22179 .59902 .21757 .59366 .21015 Metetra
.675 .731 .892 r
.59366 .21015 .59902 .21757 .60949 .21346 .60415 .20602 Metetra
.662 .726 .896 r
.60415 .20602 .60949 .21346 .62 .20969 .61469 .20222 Metetra
.664 .726 .896 r
.61469 .20222 .62 .20969 .63055 .20581 .62526 .19836 Metetra
.669 .73 .896 r
.62526 .19836 .63055 .20581 .64112 .20161 .63587 .19436 Metetra
.666 .736 .902 r
.63587 .19436 .64112 .20161 .65174 .19748 .64653 .19044 Metetra
.652 .739 .913 r
.64653 .19044 .65174 .19748 .66241 .19371 .65724 .18688 Metetra
.663 .751 .916 r
.65724 .18688 .66241 .19371 .67311 .1897 .66797 .18303 Metetra
.715 .776 .901 r
.66797 .18303 .67311 .1897 .68378 .18441 .67868 .17772 Metetra
.71 .775 .903 r
.67868 .17772 .68378 .18441 .6945 .17929 .68943 .17254 Metetra
.676 .761 .915 r
.68943 .17254 .6945 .17929 .70532 .17533 .70026 .16832 Metetra
.674 .753 .91 r
.70026 .16832 .70532 .17533 .71617 .17136 .71113 .16411 Metetra
.664 .741 .908 r
.71113 .16411 .71617 .17136 .72708 .16744 .72207 .16016 Metetra
.664 .741 .908 r
.72207 .16016 .72708 .16744 .73802 .1635 .73304 .1562 Metetra
.664 .741 .908 r
.73304 .1562 .73802 .1635 .74901 .15955 .74406 .15222 Metetra
.664 .741 .908 r
.74406 .15222 .74901 .15955 .76004 .15559 .75512 .14822 Metetra
.664 .741 .908 r
.75512 .14822 .76004 .15559 .77112 .15161 .76622 .14421 Metetra
.664 .741 .908 r
.76622 .14421 .77112 .15161 .78223 .14761 .77737 .14019 Metetra
.664 .741 .908 r
.1441 .36067 .15047 .3666 .15935 .3634 .153 .35744 Metetra
.664 .741 .908 r
.153 .35744 .15935 .3634 .16826 .36018 .16193 .3542 Metetra
.664 .741 .908 r
.16193 .3542 .16826 .36018 .17721 .35695 .17089 .35095 Metetra
.664 .741 .908 r
.17089 .35095 .17721 .35695 .18618 .35371 .17988 .34769 Metetra
.661 .741 .909 r
.17988 .34769 .18618 .35371 .19519 .35045 .1889 .34447 Metetra
.661 .743 .91 r
.1889 .34447 .19519 .35045 .20423 .34719 .19795 .34125 Metetra
.645 .74 .918 r
.19795 .34125 .20423 .34719 .21327 .34418 .207 .33837 Metetra
.643 .745 .923 r
.207 .33837 .21327 .34418 .22234 .34118 .21607 .33552 Metetra
.609 .742 .939 r
.21607 .33552 .22234 .34118 .23136 .33913 .22512 .33332 Metetra
.605 .735 .937 r
.22512 .33332 .23136 .33913 .24041 .3372 .2342 .3312 Metetra
.667 .747 .91 r
.2342 .3312 .24041 .3372 .24962 .33386 .24343 .32776 Metetra
.677 .747 .904 r
.24343 .32776 .24962 .33386 .25888 .33024 .25272 .32406 Metetra
.666 .743 .907 r
.25272 .32406 .25888 .33024 .26814 .32697 .26202 .32063 Metetra
.663 .737 .905 r
.26202 .32063 .26814 .32697 .27743 .32379 .27134 .31726 Metetra
.663 .731 .9 r
.27134 .31726 .27743 .32379 .28677 .32046 .2807 .31387 Metetra
.663 .73 .899 r
.2807 .31387 .28677 .32046 .29614 .31708 .29009 .31046 Metetra
.649 .725 .905 r
.29009 .31046 .29614 .31708 .30552 .31403 .29949 .3074 Metetra
.644 .724 .907 r
.29949 .3074 .30552 .31403 .31493 .31109 .30891 .30444 Metetra
.657 .728 .902 r
.30891 .30444 .31493 .31109 .32439 .30781 .3184 .30113 Metetra
.663 .73 .9 r
.3184 .30113 .32439 .30781 .3339 .30439 .32792 .29768 Metetra
.652 .726 .904 r
.32792 .29768 .3339 .30439 .34343 .30115 .33747 .2945 Metetra
.646 .727 .908 r
.33747 .2945 .34343 .30115 .35299 .29799 .34704 .29143 Metetra
.657 .734 .907 r
.34704 .29143 .35299 .29799 .36259 .29474 .35667 .28809 Metetra
.663 .734 .903 r
.35667 .28809 .36259 .29474 .37223 .29144 .36634 .28459 Metetra
.664 .729 .898 r
.36634 .28459 .37223 .29144 .38191 .28812 .37604 .28104 Metetra
.664 .722 .892 r
.37604 .28104 .38191 .28812 .39162 .28479 .38579 .27745 Metetra
.654 .712 .89 r
.38579 .27745 .39162 .28479 .40137 .28142 .39555 .27409 Metetra
.648 .71 .893 r
.39555 .27409 .40137 .28142 .41116 .27802 .40535 .27089 Metetra
.65 .718 .898 r
.40535 .27089 .41116 .27802 .42098 .2747 .41519 .26765 Metetra
.651 .721 .9 r
.41519 .26765 .42098 .2747 .43083 .27145 .42506 .26436 Metetra
.657 .723 .898 r
.42506 .26436 .43083 .27145 .44073 .26803 .43498 .26091 Metetra
.662 .725 .896 r
.43498 .26091 .44073 .26803 .45067 .26445 .44494 .25731 Metetra
.667 .727 .894 r
.44494 .25731 .45067 .26445 .46064 .26072 .45494 .25355 Metetra
.673 .729 .892 r
.45494 .25355 .46064 .26072 .47066 .25681 .46498 .24963 Metetra
.674 .729 .892 r
.46498 .24963 .47066 .25681 .48071 .25297 .47505 .24567 Metetra
.674 .727 .889 r
.47505 .24567 .48071 .25297 .49079 .24922 .48516 .24166 Metetra
.667 .717 .886 r
.48516 .24166 .49079 .24922 .50092 .24543 .49531 .23781 Metetra
.659 .713 .888 r
.49531 .23781 .50092 .24543 .51107 .24159 .50549 .23419 Metetra
.66 .721 .894 r
.50549 .23419 .51107 .24159 .52127 .23775 .5157 .23053 Metetra
.662 .728 .898 r
.5157 .23053 .52127 .23775 .5315 .23389 .52596 .22682 Metetra
.668 .736 .901 r
.52596 .22682 .5315 .23389 .54177 .22998 .53625 .22295 Metetra
.678 .742 .899 r
.53625 .22295 .54177 .22998 .55207 .22596 .54658 .21879 Metetra
.673 .736 .898 r
.54658 .21879 .55207 .22596 .56241 .22203 .55694 .21476 Metetra
.663 .73 .9 r
.55694 .21476 .56241 .22203 .5728 .21829 .56735 .21099 Metetra
.668 .732 .898 r
.56735 .21099 .5728 .21829 .58321 .2144 .5778 .20707 Metetra
.679 .736 .893 r
.5778 .20707 .58321 .2144 .59366 .21015 .58827 .2028 Metetra
.675 .735 .895 r
.58827 .2028 .59366 .21015 .60415 .20602 .59879 .19864 Metetra
.663 .73 .899 r
.59879 .19864 .60415 .20602 .61469 .20222 .60935 .19481 Metetra
.663 .73 .899 r
.60935 .19481 .61469 .20222 .62526 .19836 .61995 .19097 Metetra
.663 .731 .9 r
.61995 .19097 .62526 .19836 .63587 .19436 .63059 .18712 Metetra
.661 .736 .906 r
.63059 .18712 .63587 .19436 .64653 .19044 .64128 .18332 Metetra
.65 .737 .913 r
.64128 .18332 .64653 .19044 .65724 .18688 .65202 .17979 Metetra
.66 .742 .911 r
.65202 .17979 .65724 .18688 .66797 .18303 .66279 .17598 Metetra
.707 .762 .895 r
.66279 .17598 .66797 .18303 .67868 .17772 .67353 .17082 Metetra
.705 .768 .901 r
.67353 .17082 .67868 .17772 .68943 .17254 .68432 .16575 Metetra
.682 .764 .913 r
.68432 .16575 .68943 .17254 .70026 .16832 .69517 .16132 Metetra
.68 .757 .91 r
.69517 .16132 .70026 .16832 .71113 .16411 .70607 .15693 Metetra
.666 .746 .91 r
.70607 .15693 .71113 .16411 .72207 .16016 .71703 .15289 Metetra
.666 .744 .909 r
.71703 .15289 .72207 .16016 .73304 .1562 .72803 .14884 Metetra
.664 .741 .908 r
.72803 .14884 .73304 .1562 .74406 .15222 .73907 .14483 Metetra
.664 .741 .908 r
.73907 .14483 .74406 .15222 .75512 .14822 .75016 .14081 Metetra
.664 .741 .908 r
.75016 .14081 .75512 .14822 .76622 .14421 .7613 .13677 Metetra
.664 .741 .908 r
.7613 .13677 .76622 .14421 .77737 .14019 .77247 .13272 Metetra
.664 .741 .908 r
.13769 .3547 .1441 .36067 .153 .35744 .14661 .35145 Metetra
.664 .741 .908 r
.14661 .35145 .153 .35744 .16193 .3542 .15555 .34819 Metetra
.664 .741 .908 r
.15555 .34819 .16193 .3542 .17089 .35095 .16453 .34492 Metetra
.664 .741 .908 r
.16453 .34492 .17089 .35095 .17988 .34769 .17354 .34164 Metetra
.652 .738 .913 r
.17354 .34164 .17988 .34769 .1889 .34447 .18256 .33861 Metetra
.651 .746 .919 r
.18256 .33861 .1889 .34447 .19795 .34125 .1916 .33559 Metetra
.644 .752 .928 r
.1916 .33559 .19795 .34125 .207 .33837 .20066 .33272 Metetra
.643 .752 .928 r
.20066 .33272 .207 .33837 .21607 .33552 .20976 .32985 Metetra
.64 .752 .93 r
.20976 .32985 .21607 .33552 .22512 .33332 .21888 .32703 Metetra
.64 .73 .914 r
.21888 .32703 .22512 .33332 .2342 .3312 .22804 .32421 Metetra
.654 .712 .89 r
.22804 .32421 .2342 .3312 .24343 .32776 .23727 .32102 Metetra
.658 .722 .896 r
.23727 .32102 .24343 .32776 .25272 .32406 .24653 .31775 Metetra
.662 .738 .906 r
.24653 .31775 .25272 .32406 .26202 .32063 .25584 .31439 Metetra
.663 .742 .908 r
.25584 .31439 .26202 .32063 .27134 .31726 .26518 .31099 Metetra
.663 .742 .908 r
.26518 .31099 .27134 .31726 .2807 .31387 .27456 .30758 Metetra
.663 .742 .908 r
.27456 .30758 .2807 .31387 .29009 .31046 .28397 .30415 Metetra
.649 .737 .914 r
.28397 .30415 .29009 .31046 .29949 .3074 .29339 .30106 Metetra
.644 .736 .916 r
.29339 .30106 .29949 .3074 .30891 .30444 .30283 .29808 Metetra
.658 .74 .911 r
.30283 .29808 .30891 .30444 .3184 .30113 .31234 .29475 Metetra
.663 .742 .908 r
.31234 .29475 .3184 .30113 .32792 .29768 .32189 .29128 Metetra
.658 .74 .91 r
.32189 .29128 .32792 .29768 .33747 .2945 .33146 .28792 Metetra
.656 .734 .907 r
.33146 .28792 .33747 .2945 .34704 .29143 .34107 .2846 Metetra
.66 .728 .9 r
.34107 .2846 .34704 .29143 .35667 .28809 .35072 .28115 Metetra
.662 .726 .897 r
.35072 .28115 .35667 .28809 .36634 .28459 .36041 .27763 Metetra
.669 .728 .894 r
.36041 .27763 .36634 .28459 .37604 .28104 .37014 .27391 Metetra
.672 .725 .889 r
.37014 .27391 .37604 .28104 .38579 .27745 .37992 .27007 Metetra
.668 .716 .885 r
.37992 .27007 .38579 .27745 .39555 .27409 .38972 .26632 Metetra
.664 .704 .877 r
.38972 .26632 .39555 .27409 .40535 .27089 .39955 .26264 Metetra
.667 .692 .864 r
.39955 .26264 .40535 .27089 .41519 .26765 .40943 .25878 Metetra
.668 .677 .85 r
.40943 .25878 .41519 .26765 .42506 .26436 .41934 .25477 Metetra
.658 .657 .838 r
.41934 .25477 .42506 .26436 .43498 .26091 .42929 .25096 Metetra
.65 .646 .833 r
.42929 .25096 .43498 .26091 .44494 .25731 .43926 .24733 Metetra
.644 .643 .835 r
.43926 .24733 .44494 .25731 .45494 .25355 .44926 .24389 Metetra
.639 .649 .843 r
.44926 .24389 .45494 .25355 .46498 .24963 .4593 .24063 Metetra
.646 .669 .857 r
.4593 .24063 .46498 .24963 .47505 .24567 .46938 .23724 Metetra
.654 .687 .869 r
.46938 .23724 .47505 .24567 .48516 .24166 .4795 .23366 Metetra
.653 .7 .881 r
.4795 .23366 .48516 .24166 .49531 .23781 .48966 .23016 Metetra
.65 .71 .891 r
.48966 .23016 .49531 .23781 .50549 .23419 .49986 .22674 Metetra
.655 .719 .895 r
.49986 .22674 .50549 .23419 .5157 .23053 .5101 .22319 Metetra
.662 .726 .897 r
.5101 .22319 .5157 .23053 .52596 .22682 .52038 .21946 Metetra
.665 .727 .896 r
.52038 .21946 .52596 .22682 .53625 .22295 .53069 .21564 Metetra
.669 .731 .896 r
.53069 .21564 .53625 .22295 .54658 .21879 .54105 .21169 Metetra
.668 .738 .903 r
.54105 .21169 .54658 .21879 .55694 .21476 .55144 .20779 Metetra
.663 .742 .908 r
.55144 .20779 .55694 .21476 .56735 .21099 .56188 .204 Metetra
.668 .744 .906 r
.56188 .204 .56735 .21099 .5778 .20707 .57235 .20005 Metetra
.681 .748 .902 r
.57235 .20005 .5778 .20707 .58827 .2028 .58285 .19575 Metetra
.676 .746 .904 r
.58285 .19575 .58827 .2028 .59879 .19864 .59339 .19156 Metetra
.663 .742 .908 r
.59339 .19156 .59879 .19864 .60935 .19481 .60398 .18771 Metetra
.663 .742 .908 r
.60398 .18771 .60935 .19481 .61995 .19097 .61461 .18384 Metetra
.663 .742 .908 r
.61461 .18384 .61995 .19097 .63059 .18712 .62528 .17996 Metetra
.664 .742 .908 r
.62528 .17996 .63059 .18712 .64128 .18332 .63599 .17604 Metetra
.667 .74 .905 r
.63599 .17604 .64128 .18332 .65202 .17979 .64673 .17202 Metetra
.668 .726 .892 r
.64673 .17202 .65202 .17979 .66279 .17598 .65752 .16791 Metetra
.679 .722 .881 r
.65752 .16791 .66279 .17598 .67353 .17082 .66832 .16342 Metetra
.682 .744 .898 r
.66832 .16342 .67353 .17082 .68432 .16575 .67917 .15893 Metetra
.682 .765 .914 r
.67917 .15893 .68432 .16575 .69517 .16132 .69006 .15447 Metetra
.681 .764 .914 r
.69006 .15447 .69517 .16132 .70607 .15693 .70098 .15003 Metetra
.675 .761 .916 r
.70098 .15003 .70607 .15693 .71703 .15289 .71196 .14573 Metetra
.674 .753 .91 r
.71196 .14573 .71703 .15289 .72803 .14884 .72297 .14143 Metetra
.664 .741 .908 r
.72297 .14143 .72803 .14884 .73907 .14483 .73405 .13739 Metetra
.664 .741 .908 r
.73405 .13739 .73907 .14483 .75016 .14081 .74517 .13334 Metetra
.664 .741 .908 r
.74517 .13334 .75016 .14081 .7613 .13677 .75634 .12927 Metetra
.664 .741 .908 r
.75634 .12927 .7613 .13677 .77247 .13272 .76754 .12519 Metetra
.664 .741 .908 r
.13124 .3487 .13769 .3547 .14661 .35145 .14017 .34543 Metetra
.664 .741 .908 r
.14017 .34543 .14661 .35145 .15555 .34819 .14914 .34214 Metetra
.664 .741 .908 r
.14914 .34214 .15555 .34819 .16453 .34492 .15813 .33885 Metetra
.664 .741 .908 r
.15813 .33885 .16453 .34492 .17354 .34164 .16716 .33555 Metetra
.645 .736 .916 r
.16716 .33555 .17354 .34164 .18256 .33861 .17618 .33266 Metetra
.643 .742 .921 r
.17618 .33266 .18256 .33861 .1916 .33559 .18522 .3298 Metetra
.641 .747 .926 r
.18522 .3298 .1916 .33559 .20066 .33272 .19429 .32697 Metetra
.64 .75 .928 r
.19429 .32697 .20066 .33272 .20976 .32985 .2034 .32413 Metetra
.663 .757 .92 r
.2034 .32413 .20976 .32985 .21888 .32703 .21259 .32079 Metetra
.665 .741 .906 r
.21259 .32079 .21888 .32703 .22804 .32421 .22183 .31736 Metetra
.647 .716 .898 r
.22183 .31736 .22804 .32421 .23727 .32102 .23105 .31436 Metetra
.643 .721 .905 r
.23105 .31436 .23727 .32102 .24653 .31775 .2403 .31142 Metetra
.66 .738 .908 r
.2403 .31142 .24653 .31775 .25584 .31439 .24962 .3081 Metetra
.663 .742 .908 r
.24962 .3081 .25584 .31439 .26518 .31099 .25899 .30468 Metetra
.663 .742 .908 r
.25899 .30468 .26518 .31099 .27456 .30758 .26838 .30125 Metetra
.663 .742 .908 r
.26838 .30125 .27456 .30758 .28397 .30415 .27781 .2978 Metetra
.651 .738 .913 r
.27781 .2978 .28397 .30415 .29339 .30106 .28725 .29465 Metetra
.646 .735 .914 r
.28725 .29465 .29339 .30106 .30283 .29808 .29672 .29159 Metetra
.658 .737 .908 r
.29672 .29159 .30283 .29808 .31234 .29475 .30625 .28823 Metetra
.663 .738 .906 r
.30625 .28823 .31234 .29475 .32189 .29128 .31582 .28473 Metetra
.663 .738 .906 r
.31582 .28473 .32189 .29128 .33146 .28792 .32542 .28122 Metetra
.663 .734 .903 r
.32542 .28122 .33146 .28792 .34107 .2846 .33506 .2777 Metetra
.665 .729 .897 r
.33506 .2777 .34107 .2846 .35072 .28115 .34474 .2741 Metetra
.666 .725 .893 r
.34474 .2741 .35072 .28115 .36041 .27763 .35445 .27045 Metetra
.674 .724 .888 r
.35445 .27045 .36041 .27763 .37014 .27391 .36421 .26656 Metetra
.678 .721 .882 r
.36421 .26656 .37014 .27391 .37992 .27007 .37402 .26252 Metetra
.676 .715 .878 r
.37402 .26252 .37992 .27007 .38972 .26632 .38385 .25849 Metetra
.674 .707 .873 r
.38385 .25849 .38972 .26632 .39955 .26264 .39372 .25447 Metetra
.679 .701 .863 r
.39372 .25447 .39955 .26264 .40943 .25878 .40363 .25021 Metetra
.683 .692 .852 r
.40363 .25021 .40943 .25878 .41934 .25477 .41357 .24575 Metetra
.667 .675 .848 r
.41357 .24575 .41934 .25477 .42929 .25096 .42354 .24171 Metetra
.654 .665 .848 r
.42354 .24171 .42929 .25096 .43926 .24733 .43353 .23805 Metetra
.641 .659 .852 r
.43353 .23805 .43926 .24733 .44926 .24389 .44354 .23478 Metetra
.627 .658 .861 r
.44354 .23478 .44926 .24389 .4593 .24063 .45358 .23194 Metetra
.635 .673 .869 r
.45358 .23194 .4593 .24063 .46938 .23724 .46367 .22889 Metetra
.644 .687 .876 r
.46367 .22889 .46938 .23724 .4795 .23366 .47381 .2256 Metetra
.644 .696 .883 r
.47381 .2256 .4795 .23366 .48966 .23016 .48398 .22232 Metetra
.643 .703 .89 r
.48398 .22232 .48966 .23016 .49986 .22674 .4942 .21906 Metetra
.649 .711 .893 r
.4942 .21906 .49986 .22674 .5101 .22319 .50446 .21564 Metetra
.658 .719 .894 r
.50446 .21564 .5101 .22319 .52038 .21946 .51476 .21198 Metetra
.66 .723 .896 r
.51476 .21198 .52038 .21946 .53069 .21564 .5251 .20827 Metetra
.662 .728 .898 r
.5251 .20827 .53069 .21564 .54105 .21169 .53548 .20448 Metetra
.663 .734 .903 r
.53548 .20448 .54105 .21169 .55144 .20779 .5459 .20067 Metetra
.663 .738 .906 r
.5459 .20067 .55144 .20779 .56188 .204 .55636 .19685 Metetra
.668 .74 .904 r
.55636 .19685 .56188 .204 .57235 .20005 .56686 .19289 Metetra
.679 .744 .9 r
.56686 .19289 .57235 .20005 .58285 .19575 .57739 .18862 Metetra
.675 .745 .903 r
.57739 .18862 .58285 .19575 .59339 .19156 .58796 .18444 Metetra
.663 .742 .908 r
.58796 .18444 .59339 .19156 .60398 .18771 .59857 .18056 Metetra
.663 .742 .908 r
.59857 .18056 .60398 .18771 .61461 .18384 .60923 .17666 Metetra
.663 .742 .908 r
.60923 .17666 .61461 .18384 .62528 .17996 .61993 .17275 Metetra
.667 .743 .907 r
.61993 .17275 .62528 .17996 .63599 .17604 .63066 .16874 Metetra
.68 .746 .9 r
.63066 .16874 .63599 .17604 .64673 .17202 .64142 .16432 Metetra
.676 .733 .893 r
.64142 .16432 .64673 .17202 .65752 .16791 .65222 .15997 Metetra
.66 .72 .893 r
.65222 .15997 .65752 .16791 .66832 .16342 .66308 .15606 Metetra
.664 .74 .907 r
.66308 .15606 .66832 .16342 .67917 .15893 .67398 .15205 Metetra
.684 .765 .913 r
.67398 .15205 .67917 .15893 .69006 .15447 .6849 .14752 Metetra
.684 .763 .912 r
.6849 .14752 .69006 .15447 .70098 .15003 .69585 .14297 Metetra
.682 .76 .911 r
.69585 .14297 .70098 .15003 .71196 .14573 .70685 .13846 Metetra
.68 .754 .907 r
.70685 .13846 .71196 .14573 .72297 .14143 .71788 .13396 Metetra
.664 .741 .908 r
.71788 .13396 .72297 .14143 .73405 .13739 .72899 .1299 Metetra
.664 .741 .908 r
.72899 .1299 .73405 .13739 .74517 .13334 .74014 .12582 Metetra
.664 .741 .908 r
.74014 .12582 .74517 .13334 .75634 .12927 .75134 .12172 Metetra
.664 .741 .908 r
.75134 .12172 .75634 .12927 .76754 .12519 .76258 .11761 Metetra
.664 .741 .908 r
.12474 .34265 .13124 .3487 .14017 .34543 .1337 .33936 Metetra
.664 .741 .908 r
.1337 .33936 .14017 .34543 .14914 .34214 .14268 .33606 Metetra
.664 .741 .908 r
.14268 .33606 .14914 .34214 .15813 .33885 .15169 .33274 Metetra
.664 .741 .908 r
.15169 .33274 .15813 .33885 .16716 .33555 .16074 .32942 Metetra
.645 .736 .916 r
.16074 .32942 .16716 .33555 .17618 .33266 .16977 .32651 Metetra
.643 .736 .916 r
.16977 .32651 .17618 .33266 .18522 .3298 .17883 .32362 Metetra
.631 .732 .921 r
.17883 .32362 .18522 .3298 .19429 .32697 .1879 .32098 Metetra
.63 .739 .926 r
.1879 .32098 .19429 .32697 .2034 .32413 .197 .31835 Metetra
.67 .758 .917 r
.197 .31835 .2034 .32413 .21259 .32079 .20623 .31481 Metetra
.675 .754 .91 r
.20623 .31481 .21259 .32079 .22183 .31736 .21551 .31114 Metetra
.649 .739 .915 r
.21551 .31114 .22183 .31736 .23105 .31436 .22475 .30807 Metetra
.643 .736 .916 r
.22475 .30807 .23105 .31436 .2403 .31142 .23402 .30512 Metetra
.66 .741 .91 r
.23402 .30512 .2403 .31142 .24962 .3081 .24336 .30178 Metetra
.663 .742 .908 r
.24336 .30178 .24962 .3081 .25899 .30468 .25275 .29833 Metetra
.663 .742 .908 r
.25275 .29833 .25899 .30468 .26838 .30125 .26216 .29487 Metetra
.663 .742 .908 r
.26216 .29487 .26838 .30125 .27781 .2978 .27161 .2914 Metetra
.658 .74 .91 r
.27161 .2914 .27781 .2978 .28725 .29465 .28109 .28806 Metetra
.655 .734 .907 r
.28109 .28806 .28725 .29465 .29672 .29159 .29059 .28475 Metetra
.66 .727 .899 r
.29059 .28475 .29672 .29159 .30625 .28823 .30014 .2813 Metetra
.662 .726 .897 r
.30014 .2813 .30625 .28823 .31582 .28473 .30973 .27778 Metetra
.662 .726 .897 r
.30973 .27778 .31582 .28473 .32542 .28122 .31935 .27424 Metetra
.662 .726 .897 r
.31935 .27424 .32542 .28122 .33506 .2777 .32901 .2707 Metetra
.676 .73 .891 r
.32901 .2707 .33506 .2777 .34474 .2741 .33873 .26677 Metetra
.681 .723 .881 r
.33873 .26677 .34474 .2741 .35445 .27045 .34849 .26264 Metetra
.677 .708 .871 r
.34849 .26264 .35445 .27045 .36421 .26656 .35828 .25854 Metetra
.675 .702 .868 r
.35828 .25854 .36421 .26656 .37402 .26252 .3681 .25448 Metetra
.669 .7 .87 r
.3681 .25448 .37402 .26252 .38385 .25849 .37795 .25056 Metetra
.666 .703 .874 r
.37795 .25056 .38385 .25849 .39372 .25447 .38782 .24675 Metetra
.67 .711 .879 r
.38782 .24675 .39372 .25447 .40363 .25021 .39774 .24282 Metetra
.675 .723 .886 r
.39774 .24282 .40363 .25021 .41357 .24575 .40769 .23879 Metetra
.67 .736 .9 r
.40769 .23879 .41357 .24575 .42354 .24171 .41767 .23495 Metetra
.664 .741 .908 r
.41767 .23495 .42354 .24171 .43353 .23805 .42768 .23126 Metetra
.656 .739 .911 r
.42768 .23126 .43353 .23805 .44354 .23478 .43773 .22775 Metetra
.648 .729 .908 r
.43773 .22775 .44354 .23478 .45358 .23194 .4478 .22442 Metetra
.651 .715 .895 r
.4478 .22442 .45358 .23194 .46367 .22889 .45792 .22098 Metetra
.654 .705 .885 r
.45792 .22098 .46367 .22889 .47381 .2256 .46808 .21744 Metetra
.649 .696 .881 r
.46808 .21744 .47381 .2256 .48398 .22232 .47828 .21399 Metetra
.642 .69 .879 r
.47828 .21399 .48398 .22232 .4942 .21906 .48851 .2107 Metetra
.641 .689 .88 r
.48851 .2107 .4942 .21906 .50446 .21564 .49879 .20744 Metetra
.639 .694 .885 r
.49879 .20744 .50446 .21564 .51476 .21198 .50911 .20422 Metetra
.648 .711 .894 r
.50911 .20422 .51476 .21198 .5251 .20827 .51947 .20078 Metetra
.662 .726 .897 r
.51947 .20078 .5251 .20827 .53548 .20448 .52988 .19696 Metetra
.662 .726 .897 r
.52988 .19696 .53548 .20448 .5459 .20067 .54032 .19313 Metetra
.662 .726 .897 r
.54032 .19313 .5459 .20067 .55636 .19685 .5508 .18928 Metetra
.664 .727 .896 r
.5508 .18928 .55636 .19685 .56686 .19289 .56133 .18536 Metetra
.669 .731 .896 r
.56133 .18536 .56686 .19289 .57739 .18862 .57189 .1813 Metetra
.668 .738 .902 r
.57189 .1813 .57739 .18862 .58796 .18444 .58249 .17726 Metetra
.663 .742 .908 r
.58249 .17726 .58796 .18444 .59857 .18056 .59313 .17336 Metetra
.663 .742 .908 r
.59313 .17336 .59857 .18056 .60923 .17666 .60381 .16943 Metetra
.663 .742 .908 r
.60381 .16943 .60923 .17666 .61993 .17275 .61454 .1655 Metetra
.667 .743 .907 r
.61454 .1655 .61993 .17275 .63066 .16874 .6253 .16145 Metetra
.681 .748 .902 r
.6253 .16145 .63066 .16874 .64142 .16432 .63609 .15701 Metetra
.676 .746 .904 r
.63609 .15701 .64142 .16432 .65222 .15997 .64692 .15267 Metetra
.653 .738 .912 r
.64692 .15267 .65222 .15997 .66308 .15606 .65782 .14896 Metetra
.658 .748 .917 r
.65782 .14896 .66308 .15606 .67398 .15205 .66876 .14509 Metetra
.692 .767 .909 r
.66876 .14509 .67398 .15205 .6849 .14752 .67969 .1403 Metetra
.69 .759 .904 r
.67969 .1403 .6849 .14752 .69585 .14297 .69067 .13551 Metetra
.681 .748 .902 r
.69067 .13551 .69585 .14297 .70685 .13846 .70169 .13097 Metetra
.68 .748 .903 r
.70169 .13097 .70685 .13846 .71788 .13396 .71276 .12645 Metetra
.664 .741 .908 r
.71276 .12645 .71788 .13396 .72899 .1299 .7239 .12235 Metetra
.664 .741 .908 r
.7239 .12235 .72899 .1299 .74014 .12582 .73508 .11824 Metetra
.664 .741 .908 r
.73508 .11824 .74014 .12582 .75134 .12172 .7463 .11411 Metetra
.664 .741 .908 r
.7463 .11411 .75134 .12172 .76258 .11761 .75757 .10997 Metetra
.664 .741 .908 r
.11821 .33656 .12474 .34265 .1337 .33936 .12718 .33325 Metetra
.664 .741 .908 r
.12718 .33325 .1337 .33936 .14268 .33606 .13618 .32993 Metetra
.664 .741 .908 r
.13618 .32993 .14268 .33606 .15169 .33274 .14521 .32659 Metetra
.664 .741 .908 r
.14521 .32659 .15169 .33274 .16074 .32942 .15428 .32324 Metetra
.643 .736 .916 r
.15428 .32324 .16074 .32942 .16977 .32651 .16332 .32036 Metetra
.641 .737 .918 r
.16332 .32036 .16977 .32651 .17883 .32362 .17239 .31749 Metetra
.627 .734 .924 r
.17239 .31749 .17883 .32362 .1879 .32098 .18147 .31492 Metetra
.625 .737 .927 r
.18147 .31492 .1879 .32098 .197 .31835 .19058 .31236 Metetra
.676 .754 .91 r
.19058 .31236 .197 .31835 .20623 .31481 .19984 .30866 Metetra
.682 .75 .903 r
.19984 .30866 .20623 .31481 .21551 .31114 .20916 .30478 Metetra
.65 .736 .912 r
.20916 .30478 .21551 .31114 .22475 .30807 .21842 .30166 Metetra
.643 .733 .914 r
.21842 .30166 .22475 .30807 .23402 .30512 .22771 .29868 Metetra
.659 .737 .907 r
.22771 .29868 .23402 .30512 .24336 .30178 .23707 .29532 Metetra
.663 .738 .906 r
.23707 .29532 .24336 .30178 .25275 .29833 .24647 .29185 Metetra
.66 .738 .907 r
.24647 .29185 .25275 .29833 .26216 .29487 .2559 .28844 Metetra
.66 .74 .909 r
.2559 .28844 .26216 .29487 .27161 .2914 .26537 .28503 Metetra
.664 .744 .91 r
.26537 .28503 .27161 .2914 .28109 .28806 .27487 .28152 Metetra
.665 .739 .905 r
.27487 .28152 .28109 .28806 .29059 .28475 .28442 .27795 Metetra
.666 .732 .899 r
.28442 .27795 .29059 .28475 .30014 .2813 .294 .27435 Metetra
.666 .728 .896 r
.294 .27435 .30014 .2813 .30973 .27778 .30361 .27071 Metetra
.664 .725 .894 r
.30361 .27071 .30973 .27778 .31935 .27424 .31326 .2671 Metetra
.664 .723 .893 r
.31326 .2671 .31935 .27424 .32901 .2707 .32294 .26348 Metetra
.682 .727 .884 r
.32294 .26348 .32901 .2707 .33873 .26677 .33269 .25934 Metetra
.69 .724 .875 r
.33269 .25934 .33873 .26677 .34849 .26264 .34249 .25489 Metetra
.68 .712 .873 r
.34249 .25489 .34849 .26264 .35828 .25854 .3523 .25069 Metetra
.674 .708 .873 r
.3523 .25069 .35828 .25854 .3681 .25448 .36214 .24664 Metetra
.666 .706 .877 r
.36214 .24664 .3681 .25448 .37795 .25056 .372 .24283 Metetra
.66 .708 .883 r
.372 .24283 .37795 .25056 .38782 .24675 .38189 .23918 Metetra
.661 .714 .887 r
.38189 .23918 .38782 .24675 .39774 .24282 .39181 .23551 Metetra
.662 .723 .894 r
.39181 .23551 .39774 .24282 .40769 .23879 .40177 .23183 Metetra
.663 .735 .903 r
.40177 .23183 .40769 .23879 .41767 .23495 .41177 .22814 Metetra
.664 .741 .908 r
.41177 .22814 .41767 .23495 .42768 .23126 .4218 .22443 Metetra
.664 .741 .908 r
.4218 .22443 .42768 .23126 .43773 .22775 .43187 .22071 Metetra
.663 .735 .903 r
.43187 .22071 .43773 .22775 .4478 .22442 .44198 .21698 Metetra
.662 .723 .894 r
.44198 .21698 .4478 .22442 .45792 .22098 .45213 .21323 Metetra
.661 .714 .887 r
.45213 .21323 .45792 .22098 .46808 .21744 .46231 .20947 Metetra
.654 .706 .885 r
.46231 .20947 .46808 .21744 .47828 .21399 .47253 .20587 Metetra
.645 .698 .885 r
.47253 .20587 .47828 .21399 .48851 .2107 .48279 .20251 Metetra
.638 .694 .886 r
.48279 .20251 .48851 .2107 .49879 .20744 .49309 .1993 Metetra
.629 .693 .891 r
.49309 .1993 .49879 .20744 .50911 .20422 .50342 .19634 Metetra
.64 .706 .894 r
.50342 .19634 .50911 .20422 .51947 .20078 .51381 .19308 Metetra
.66 .72 .893 r
.51381 .19308 .51947 .20078 .52988 .19696 .52423 .18928 Metetra
.66 .721 .894 r
.52423 .18928 .52988 .19696 .54032 .19313 .5347 .18548 Metetra
.659 .723 .896 r
.5347 .18548 .54032 .19313 .5508 .18928 .54521 .18169 Metetra
.659 .726 .898 r
.54521 .18169 .5508 .18928 .56133 .18536 .55576 .17788 Metetra
.661 .73 .901 r
.55576 .17788 .56133 .18536 .57189 .1813 .56635 .17402 Metetra
.663 .739 .906 r
.56635 .17402 .57189 .1813 .58249 .17726 .57698 .17011 Metetra
.667 .745 .909 r
.57698 .17011 .58249 .17726 .59313 .17336 .58764 .16608 Metetra
.666 .742 .907 r
.58764 .16608 .59313 .17336 .60381 .16943 .59835 .16206 Metetra
.663 .738 .906 r
.59835 .16206 .60381 .16943 .61454 .1655 .60911 .15809 Metetra
.667 .74 .905 r
.60911 .15809 .61454 .1655 .6253 .16145 .6199 .15402 Metetra
.68 .745 .9 r
.6199 .15402 .6253 .16145 .63609 .15701 .63071 .14955 Metetra
.675 .743 .902 r
.63071 .14955 .63609 .15701 .64692 .15267 .64158 .14521 Metetra
.645 .732 .912 r
.64158 .14521 .64692 .15267 .65782 .14896 .65251 .14166 Metetra
.652 .741 .915 r
.65251 .14166 .65782 .14896 .66876 .14509 .66349 .13792 Metetra
.695 .763 .904 r
.66349 .13792 .66876 .14509 .67969 .1403 .67445 .133 Metetra
.693 .759 .902 r
.67445 .133 .67969 .1403 .69067 .13551 .68545 .12809 Metetra
.683 .752 .904 r
.68545 .12809 .69067 .13551 .70169 .13097 .6965 .12347 Metetra
.681 .75 .903 r
.6965 .12347 .70169 .13097 .71276 .12645 .7076 .11887 Metetra
.664 .741 .908 r
.7076 .11887 .71276 .12645 .7239 .12235 .71876 .11475 Metetra
.664 .741 .908 r
.71876 .11475 .7239 .12235 .73508 .11824 .72998 .11061 Metetra
.664 .741 .908 r
.72998 .11061 .73508 .11824 .7463 .11411 .74123 .10645 Metetra
.664 .741 .908 r
.74123 .10645 .7463 .11411 .75757 .10997 .75253 .10228 Metetra
.664 .741 .908 r
.11163 .33044 .11821 .33656 .12718 .33325 .12062 .32711 Metetra
.664 .741 .908 r
.12062 .32711 .12718 .33325 .13618 .32993 .12964 .32376 Metetra
.664 .741 .908 r
.12964 .32376 .13618 .32993 .14521 .32659 .13869 .3204 Metetra
.664 .741 .908 r
.13869 .3204 .14521 .32659 .15428 .32324 .14777 .31703 Metetra
.633 .733 .92 r
.14777 .31703 .15428 .32324 .16332 .32036 .1568 .31434 Metetra
.63 .74 .927 r
.1568 .31434 .16332 .32036 .17239 .31749 .16587 .31168 Metetra
.645 .752 .927 r
.16587 .31168 .17239 .31749 .18147 .31492 .17501 .30869 Metetra
.647 .739 .916 r
.17501 .30869 .18147 .31492 .19058 .31236 .18418 .30566 Metetra
.676 .732 .892 r
.18418 .30566 .19058 .31236 .19984 .30866 .19347 .30187 Metetra
.68 .731 .889 r
.19347 .30187 .19984 .30866 .20916 .30478 .20281 .29797 Metetra
.65 .722 .902 r
.20281 .29797 .20916 .30478 .21842 .30166 .21209 .29483 Metetra
.643 .72 .904 r
.21209 .29483 .21842 .30166 .22771 .29868 .2214 .29183 Metetra
.659 .725 .898 r
.2214 .29183 .22771 .29868 .23707 .29532 .23077 .28844 Metetra
.662 .726 .897 r
.23077 .28844 .23707 .29532 .24647 .29185 .2402 .28495 Metetra
.645 .721 .903 r
.2402 .28495 .24647 .29185 .2559 .28844 .24961 .28187 Metetra
.64 .731 .914 r
.24961 .28187 .2559 .28844 .26537 .28503 .25906 .2789 Metetra
.666 .754 .916 r
.25906 .2789 .26537 .28503 .27487 .28152 .26859 .27531 Metetra
.675 .755 .911 r
.26859 .27531 .27487 .28152 .28442 .27795 .27817 .27149 Metetra
.682 .749 .902 r
.27817 .27149 .28442 .27795 .294 .27435 .2878 .26747 Metetra
.683 .737 .891 r
.2878 .26747 .294 .27435 .30361 .27071 .29747 .26335 Metetra
.674 .72 .883 r
.29747 .26335 .30361 .27071 .31326 .2671 .30716 .2594 Metetra
.67 .709 .878 r
.30716 .2594 .31326 .2671 .32294 .26348 .31687 .25553 Metetra
.671 .703 .871 r
.31687 .25553 .32294 .26348 .33269 .25934 .32663 .25158 Metetra
.673 .71 .876 r
.32663 .25158 .33269 .25934 .34249 .25489 .33642 .24757 Metetra
.672 .723 .888 r
.33642 .24757 .34249 .25489 .3523 .25069 .34624 .24366 Metetra
.67 .733 .897 r
.34624 .24366 .3523 .25069 .36214 .24664 .35608 .23982 Metetra
.666 .739 .904 r
.35608 .23982 .36214 .24664 .372 .24283 .36596 .23608 Metetra
.664 .741 .908 r
.36596 .23608 .372 .24283 .38189 .23918 .37587 .2324 Metetra
.664 .741 .908 r
.37587 .2324 .38189 .23918 .39181 .23551 .38581 .22871 Metetra
.664 .741 .908 r
.38581 .22871 .39181 .23551 .40177 .23183 .3958 .225 Metetra
.664 .741 .908 r
.3958 .225 .40177 .23183 .41177 .22814 .40582 .22129 Metetra
.664 .741 .908 r
.40582 .22129 .41177 .22814 .4218 .22443 .41587 .21756 Metetra
.664 .741 .908 r
.41587 .21756 .4218 .22443 .43187 .22071 .42597 .21381 Metetra
.664 .741 .908 r
.42597 .21381 .43187 .22071 .44198 .21698 .4361 .21005 Metetra
.664 .741 .908 r
.4361 .21005 .44198 .21698 .45213 .21323 .44627 .20628 Metetra
.664 .741 .908 r
.44627 .20628 .45213 .21323 .46231 .20947 .45648 .20249 Metetra
.66 .74 .909 r
.45648 .20249 .46231 .20947 .47253 .20587 .46673 .19877 Metetra
.656 .735 .908 r
.46673 .19877 .47253 .20587 .48279 .20251 .47701 .19515 Metetra
.652 .727 .903 r
.47701 .19515 .48279 .20251 .49309 .1993 .48734 .19159 Metetra
.647 .715 .897 r
.48734 .19159 .49309 .1993 .50342 .19634 .4977 .18813 Metetra
.648 .701 .885 r
.4977 .18813 .50342 .19634 .51381 .19308 .50811 .18462 Metetra
.65 .695 .879 r
.50811 .18462 .51381 .19308 .52423 .18928 .51855 .18103 Metetra
.647 .701 .886 r
.51855 .18103 .52423 .18928 .5347 .18548 .52904 .17751 Metetra
.641 .708 .895 r
.52904 .17751 .5347 .18548 .54521 .18169 .53958 .17416 Metetra
.644 .724 .906 r
.53958 .17416 .54521 .18169 .55576 .17788 .55015 .17072 Metetra
.653 .74 .914 r
.55015 .17072 .55576 .17788 .56635 .17402 .56077 .16707 Metetra
.661 .751 .917 r
.56077 .16707 .56635 .17402 .57698 .17011 .57143 .16319 Metetra
.685 .761 .909 r
.57143 .16319 .57698 .17011 .58764 .16608 .58212 .15866 Metetra
.679 .744 .9 r
.58212 .15866 .58764 .16608 .59835 .16206 .59285 .15425 Metetra
.662 .726 .897 r
.59285 .15425 .59835 .16206 .60911 .15809 .60363 .15026 Metetra
.665 .727 .895 r
.60363 .15026 .60911 .15809 .6199 .15402 .61444 .14615 Metetra
.679 .732 .891 r
.61444 .14615 .6199 .15402 .63071 .14955 .62529 .14165 Metetra
.674 .73 .893 r
.62529 .14165 .63071 .14955 .64158 .14521 .63618 .13728 Metetra
.645 .719 .902 r
.63618 .13728 .64158 .14521 .65251 .14166 .64714 .13371 Metetra
.649 .72 .901 r
.64714 .13371 .65251 .14166 .66349 .13792 .65815 .13 Metetra
.676 .733 .893 r
.65815 .13 .66349 .13792 .67445 .133 .66916 .12551 Metetra
.679 .749 .904 r
.66916 .12551 .67445 .133 .68545 .12809 .68021 .12098 Metetra
.692 .768 .91 r
.68021 .12098 .68545 .12809 .6965 .12347 .69128 .1161 Metetra
.689 .759 .905 r
.69128 .1161 .6965 .12347 .7076 .11887 .7024 .11125 Metetra
.664 .741 .908 r
.7024 .11125 .7076 .11887 .71876 .11475 .71359 .10709 Metetra
.664 .741 .908 r
.71359 .10709 .71876 .11475 .72998 .11061 .72484 .10292 Metetra
.664 .741 .908 r
.72484 .10292 .72998 .11061 .74123 .10645 .73612 .09873 Metetra
.664 .741 .908 r
.73612 .09873 .74123 .10645 .75253 .10228 .74745 .09453 Metetra
.664 .741 .908 r
.10501 .32427 .11163 .33044 .12062 .32711 .11401 .32092 Metetra
.664 .741 .908 r
.11401 .32092 .12062 .32711 .12964 .32376 .12305 .31755 Metetra
.661 .741 .909 r
.12305 .31755 .12964 .32376 .13869 .3204 .13211 .31424 Metetra
.661 .743 .911 r
.13211 .31424 .13869 .3204 .14777 .31703 .1412 .31092 Metetra
.627 .736 .926 r
.1412 .31092 .14777 .31703 .1568 .31434 .15024 .30832 Metetra
.624 .739 .93 r
.15024 .30832 .1568 .31434 .16587 .31168 .15931 .30576 Metetra
.659 .753 .92 r
.15931 .30576 .16587 .31168 .17501 .30869 .1685 .30245 Metetra
.662 .744 .911 r
.1685 .30245 .17501 .30869 .18418 .30566 .17773 .29905 Metetra
.678 .736 .895 r
.17773 .29905 .18418 .30566 .19347 .30187 .18705 .29519 Metetra
.68 .736 .892 r
.18705 .29519 .19347 .30187 .20281 .29797 .1964 .29126 Metetra
.65 .727 .905 r
.1964 .29126 .20281 .29797 .21209 .29483 .2057 .2881 Metetra
.643 .725 .908 r
.2057 .2881 .21209 .29483 .2214 .29183 .21503 .28508 Metetra
.66 .73 .901 r
.21503 .28508 .2214 .29183 .23077 .28844 .22442 .28164 Metetra
.664 .73 .899 r
.22442 .28164 .23077 .28844 .2402 .28495 .23387 .27808 Metetra
.636 .721 .909 r
.23387 .27808 .2402 .28495 .24961 .28187 .24328 .27519 Metetra
.627 .724 .917 r
.24328 .27519 .24961 .28187 .25906 .2789 .25272 .27247 Metetra
.669 .746 .908 r
.25272 .27247 .25906 .2789 .26859 .27531 .26228 .26878 Metetra
.682 .747 .901 r
.26228 .26878 .26859 .27531 .27817 .27149 .2719 .26475 Metetra
.691 .744 .892 r
.2719 .26475 .27817 .27149 .2878 .26747 .28158 .26042 Metetra
.693 .736 .884 r
.28158 .26042 .2878 .26747 .29747 .26335 .29129 .25596 Metetra
.681 .723 .881 r
.29129 .25596 .29747 .26335 .30716 .2594 .30101 .25179 Metetra
.676 .715 .878 r
.30101 .25179 .30716 .2594 .31687 .25553 .31076 .24774 Metetra
.665 .707 .879 r
.31076 .24774 .31687 .25553 .32663 .25158 .32052 .24395 Metetra
.661 .711 .885 r
.32052 .24395 .32663 .25158 .33642 .24757 .3303 .2403 Metetra
.662 .723 .895 r
.3303 .2403 .33642 .24757 .34624 .24366 .34013 .23664 Metetra
.663 .732 .901 r
.34013 .23664 .34624 .24366 .35608 .23982 .34998 .23297 Metetra
.663 .739 .906 r
.34998 .23297 .35608 .23982 .36596 .23608 .35988 .22928 Metetra
.664 .741 .908 r
.35988 .22928 .36596 .23608 .37587 .2324 .36981 .22558 Metetra
.664 .741 .908 r
.36981 .22558 .37587 .2324 .38581 .22871 .37978 .22186 Metetra
.664 .741 .908 r
.37978 .22186 .38581 .22871 .3958 .225 .38979 .21813 Metetra
.664 .741 .908 r
.38979 .21813 .3958 .225 .40582 .22129 .39983 .21439 Metetra
.664 .741 .908 r
.39983 .21439 .40582 .22129 .41587 .21756 .40991 .21063 Metetra
.664 .741 .908 r
.40991 .21063 .41587 .21756 .42597 .21381 .42003 .20686 Metetra
.664 .741 .908 r
.42003 .20686 .42597 .21381 .4361 .21005 .43019 .20307 Metetra
.664 .741 .908 r
.43019 .20307 .4361 .21005 .44627 .20628 .44038 .19927 Metetra
.664 .741 .908 r
.44038 .19927 .44627 .20628 .45648 .20249 .45062 .19546 Metetra
.664 .741 .908 r
.45062 .19546 .45648 .20249 .46673 .19877 .46089 .19163 Metetra
.663 .739 .906 r
.46089 .19163 .46673 .19877 .47701 .19515 .4712 .18778 Metetra
.663 .732 .901 r
.4712 .18778 .47701 .19515 .48734 .19159 .48155 .18393 Metetra
.662 .723 .895 r
.48155 .18393 .48734 .19159 .4977 .18813 .49194 .18005 Metetra
.655 .709 .887 r
.49194 .18005 .4977 .18813 .50811 .18462 .50237 .17632 Metetra
.644 .699 .886 r
.50237 .17632 .50811 .18462 .51855 .18103 .51284 .17286 Metetra
.64 .702 .891 r
.51284 .17286 .51855 .18103 .52904 .17751 .52335 .16952 Metetra
.628 .703 .9 r
.52335 .16952 .52904 .17751 .53958 .17416 .53391 .16646 Metetra
.633 .715 .906 r
.53391 .16646 .53958 .17416 .55015 .17072 .54451 .16328 Metetra
.645 .729 .91 r
.54451 .16328 .55015 .17072 .56077 .16707 .55516 .15979 Metetra
.658 .74 .911 r
.55516 .15979 .56077 .16707 .57143 .16319 .56584 .15595 Metetra
.694 .756 .899 r
.56584 .15595 .57143 .16319 .58212 .15866 .57656 .15112 Metetra
.686 .744 .896 r
.57656 .15112 .58212 .15866 .59285 .15425 .58731 .14647 Metetra
.661 .728 .899 r
.58731 .14647 .59285 .15425 .60363 .15026 .59811 .14249 Metetra
.665 .731 .899 r
.59811 .14249 .60363 .15026 .61444 .14615 .60896 .13839 Metetra
.679 .737 .894 r
.60896 .13839 .61444 .14615 .62529 .14165 .61983 .13385 Metetra
.674 .735 .896 r
.61983 .13385 .62529 .14165 .63618 .13728 .63075 .12946 Metetra
.645 .724 .906 r
.63075 .12946 .63618 .13728 .64714 .13371 .64174 .12585 Metetra
.647 .725 .905 r
.64174 .12585 .64714 .13371 .65815 .13 .65277 .12216 Metetra
.664 .733 .901 r
.65277 .12216 .65815 .13 .66916 .12551 .66383 .118 Metetra
.668 .746 .909 r
.66383 .118 .66916 .12551 .68021 .12098 .67493 .11375 Metetra
.696 .767 .906 r
.67493 .11375 .68021 .12098 .69128 .1161 .68603 .10871 Metetra
.694 .762 .904 r
.68603 .10871 .69128 .1161 .7024 .11125 .69717 .10371 Metetra
.667 .747 .911 r
.69717 .10371 .7024 .11125 .71359 .10709 .70839 .09945 Metetra
.666 .745 .909 r
.70839 .09945 .71359 .10709 .72484 .10292 .71966 .09518 Metetra
.664 .741 .908 r
.71966 .09518 .72484 .10292 .73612 .09873 .73098 .09096 Metetra
.664 .741 .908 r
.73098 .09096 .73612 .09873 .74745 .09453 .74234 .08672 Metetra
.664 .741 .908 r
.09834 .31807 .10501 .32427 .11401 .32092 .10737 .31469 Metetra
.664 .741 .908 r
.10737 .31469 .11401 .32092 .12305 .31755 .11642 .3113 Metetra
.641 .735 .917 r
.11642 .3113 .12305 .31755 .13211 .31424 .12544 .30841 Metetra
.64 .751 .929 r
.12544 .30841 .13211 .31424 .1412 .31092 .1345 .30553 Metetra
.645 .768 .938 r
.1345 .30553 .1412 .31092 .15024 .30832 .1436 .30251 Metetra
.646 .754 .928 r
.1436 .30251 .15024 .30832 .15931 .30576 .15274 .29947 Metetra
.652 .74 .914 r
.15274 .29947 .15931 .30576 .1685 .30245 .16193 .2963 Metetra
.652 .746 .918 r
.16193 .2963 .1685 .30245 .17773 .29905 .17116 .2931 Metetra
.68 .76 .912 r
.17116 .2931 .17773 .29905 .18705 .29519 .18049 .28925 Metetra
.683 .762 .911 r
.18049 .28925 .18705 .29519 .1964 .29126 .18987 .2853 Metetra
.65 .754 .925 r
.18987 .2853 .1964 .29126 .2057 .2881 .19919 .28212 Metetra
.643 .752 .928 r
.19919 .28212 .2057 .2881 .21503 .28508 .20853 .27907 Metetra
.669 .759 .918 r
.20853 .27907 .21503 .28508 .22442 .28164 .21797 .27542 Metetra
.675 .754 .91 r
.21797 .27542 .22442 .28164 .23387 .27808 .22746 .27161 Metetra
.662 .743 .91 r
.22746 .27161 .23387 .27808 .24328 .27519 .23695 .2681 Metetra
.657 .722 .897 r
.23695 .2681 .24328 .27519 .25272 .27247 .24646 .26467 Metetra
.67 .706 .874 r
.24646 .26467 .25272 .27247 .26228 .26878 .25606 .26078 Metetra
.674 .702 .868 r
.25606 .26078 .26228 .26878 .2719 .26475 .26569 .25672 Metetra
.673 .702 .869 r
.26569 .25672 .2719 .26475 .28158 .26042 .27536 .2527 Metetra
.674 .711 .876 r
.27536 .2527 .28158 .26042 .29129 .25596 .28506 .24868 Metetra
.672 .724 .889 r
.28506 .24868 .29129 .25596 .30101 .25179 .29478 .24478 Metetra
.67 .733 .897 r
.29478 .24478 .30101 .25179 .31076 .24774 .30453 .24093 Metetra
.666 .739 .905 r
.30453 .24093 .31076 .24774 .32052 .24395 .31431 .2372 Metetra
.664 .741 .908 r
.31431 .2372 .32052 .24395 .3303 .2403 .32411 .23353 Metetra
.664 .741 .908 r
.32411 .23353 .3303 .2403 .34013 .23664 .33396 .22985 Metetra
.664 .741 .908 r
.33396 .22985 .34013 .23664 .34998 .23297 .34384 .22615 Metetra
.664 .741 .908 r
.34384 .22615 .34998 .23297 .35988 .22928 .35376 .22243 Metetra
.664 .741 .908 r
.35376 .22243 .35988 .22928 .36981 .22558 .36371 .2187 Metetra
.664 .741 .908 r
.36371 .2187 .36981 .22558 .37978 .22186 .3737 .21496 Metetra
.664 .741 .908 r
.3737 .21496 .37978 .22186 .38979 .21813 .38373 .21121 Metetra
.664 .741 .908 r
.38373 .21121 .38979 .21813 .39983 .21439 .3938 .20744 Metetra
.664 .741 .908 r
.3938 .20744 .39983 .21439 .40991 .21063 .4039 .20366 Metetra
.664 .741 .908 r
.4039 .20366 .40991 .21063 .42003 .20686 .41405 .19986 Metetra
.664 .741 .908 r
.41405 .19986 .42003 .20686 .43019 .20307 .42423 .19604 Metetra
.664 .741 .908 r
.42423 .19604 .43019 .20307 .44038 .19927 .43445 .19222 Metetra
.664 .741 .908 r
.43445 .19222 .44038 .19927 .45062 .19546 .44471 .18838 Metetra
.664 .741 .908 r
.44471 .18838 .45062 .19546 .46089 .19163 .455 .18452 Metetra
.664 .741 .908 r
.455 .18452 .46089 .19163 .4712 .18778 .46534 .18065 Metetra
.664 .741 .908 r
.46534 .18065 .4712 .18778 .48155 .18393 .47572 .17677 Metetra
.664 .741 .908 r
.47572 .17677 .48155 .18393 .49194 .18005 .48613 .17287 Metetra
.661 .74 .909 r
.48613 .17287 .49194 .18005 .50237 .17632 .49659 .16902 Metetra
.656 .736 .909 r
.49659 .16902 .50237 .17632 .51284 .17286 .50708 .1653 Metetra
.653 .727 .904 r
.50708 .1653 .51284 .17286 .52335 .16952 .51762 .16162 Metetra
.647 .715 .898 r
.51762 .16162 .52335 .16952 .53391 .16646 .5282 .15807 Metetra
.645 .701 .887 r
.5282 .15807 .53391 .16646 .54451 .16328 .53882 .15452 Metetra
.642 .69 .879 r
.53882 .15452 .54451 .16328 .55516 .15979 .54949 .15101 Metetra
.648 .692 .878 r
.54949 .15101 .55516 .15979 .56584 .15595 .5602 .14732 Metetra
.664 .704 .877 r
.5602 .14732 .56584 .15595 .57656 .15112 .57095 .14317 Metetra
.664 .724 .894 r
.57095 .14317 .57656 .15112 .58731 .14647 .58174 .13908 Metetra
.653 .739 .913 r
.58174 .13908 .58731 .14647 .59811 .14249 .59257 .13531 Metetra
.659 .749 .917 r
.59257 .13531 .59811 .14249 .60896 .13839 .60345 .13137 Metetra
.682 .764 .913 r
.60345 .13137 .60896 .13839 .61983 .13385 .61436 .1268 Metetra
.677 .762 .915 r
.61436 .1268 .61983 .13385 .63075 .12946 .62531 .12238 Metetra
.645 .75 .926 r
.62531 .12238 .63075 .12946 .64174 .12585 .63633 .11874 Metetra
.649 .752 .924 r
.63633 .11874 .64174 .12585 .65277 .12216 .64739 .11499 Metetra
.674 .761 .916 r
.64739 .11499 .65277 .12216 .66383 .118 .65847 .11057 Metetra
.674 .753 .91 r
.65847 .11057 .66383 .118 .67493 .11375 .66959 .10612 Metetra
.678 .749 .904 r
.66959 .10612 .67493 .11375 .68603 .10871 .68075 .10152 Metetra
.68 .765 .915 r
.68075 .10152 .68603 .10871 .69717 .10371 .69194 .0969 Metetra
.686 .781 .923 r
.69194 .0969 .69717 .10371 .70839 .09945 .70317 .09214 Metetra
.684 .764 .913 r
.70317 .09214 .70839 .09945 .71966 .09518 .71444 .08738 Metetra
.664 .741 .908 r
.71444 .08738 .71966 .09518 .73098 .09096 .72579 .08313 Metetra
.664 .741 .908 r
.72579 .08313 .73098 .09096 .74234 .08672 .73719 .07886 Metetra
.662 .741 .908 r
.09164 .31182 .09834 .31807 .10737 .31469 .10067 .30845 Metetra
.662 .742 .909 r
.10067 .30845 .10737 .31469 .11642 .3113 .10974 .30507 Metetra
.625 .733 .924 r
.10974 .30507 .11642 .3113 .12544 .30841 .11874 .30249 Metetra
.623 .744 .934 r
.11874 .30249 .12544 .30841 .1345 .30553 .12776 .29992 Metetra
.662 .766 .927 r
.12776 .29992 .1345 .30553 .1436 .30251 .13693 .29653 Metetra
.664 .754 .917 r
.13693 .29653 .1436 .30251 .15274 .29947 .14614 .29307 Metetra
.645 .736 .915 r
.14614 .29307 .15274 .29947 .16193 .2963 .15533 .29001 Metetra
.643 .74 .919 r
.15533 .29001 .16193 .2963 .17116 .2931 .16456 .287 Metetra
.677 .756 .91 r
.16456 .287 .17116 .2931 .18049 .28925 .1739 .28318 Metetra
.682 .759 .909 r
.1739 .28318 .18049 .28925 .18987 .2853 .18329 .27923 Metetra
.652 .752 .923 r
.18329 .27923 .18987 .2853 .19919 .28212 .19264 .27598 Metetra
.646 .749 .924 r
.19264 .27598 .19919 .28212 .20853 .27907 .20201 .27285 Metetra
.675 .755 .911 r
.20201 .27285 .20853 .27907 .21797 .27542 .21149 .26903 Metetra
.681 .751 .904 r
.21149 .26903 .21797 .27542 .22746 .27161 .22101 .26502 Metetra
.681 .746 .9 r
.22101 .26502 .22746 .27161 .23695 .2681 .23057 .26099 Metetra
.679 .729 .888 r
.23057 .26099 .23695 .2681 .24646 .26467 .24016 .25693 Metetra
.675 .71 .874 r
.24016 .25693 .24646 .26467 .25606 .26078 .24978 .25288 Metetra
.674 .706 .871 r
.24978 .25288 .25606 .26078 .26569 .25672 .25944 .24882 Metetra
.664 .704 .877 r
.25944 .24882 .26569 .25672 .27536 .2527 .2691 .24507 Metetra
.661 .711 .885 r
.2691 .24507 .27536 .2527 .28506 .24868 .27878 .24142 Metetra
.662 .724 .895 r
.27878 .24142 .28506 .24868 .29478 .24478 .2885 .23777 Metetra
.663 .732 .901 r
.2885 .23777 .29478 .24478 .30453 .24093 .29826 .2341 Metetra
.663 .739 .906 r
.29826 .2341 .30453 .24093 .31431 .2372 .30805 .23041 Metetra
.664 .741 .908 r
.30805 .23041 .31431 .2372 .32411 .23353 .31788 .22672 Metetra
.664 .741 .908 r
.31788 .22672 .32411 .23353 .33396 .22985 .32775 .223 Metetra
.664 .741 .908 r
.32775 .223 .33396 .22985 .34384 .22615 .33765 .21928 Metetra
.664 .741 .908 r
.33765 .21928 .34384 .22615 .35376 .22243 .34759 .21554 Metetra
.664 .741 .908 r
.34759 .21554 .35376 .22243 .36371 .2187 .35757 .21179 Metetra
.664 .741 .908 r
.35757 .21179 .36371 .2187 .3737 .21496 .36758 .20802 Metetra
.664 .741 .908 r
.36758 .20802 .3737 .21496 .38373 .21121 .37764 .20424 Metetra
.664 .741 .908 r
.37764 .20424 .38373 .21121 .3938 .20744 .38773 .20044 Metetra
.664 .741 .908 r
.38773 .20044 .3938 .20744 .4039 .20366 .39785 .19663 Metetra
.664 .741 .908 r
.39785 .19663 .4039 .20366 .41405 .19986 .40802 .19281 Metetra
.664 .741 .908 r
.40802 .19281 .41405 .19986 .42423 .19604 .41823 .18897 Metetra
.664 .741 .908 r
.41823 .18897 .42423 .19604 .43445 .19222 .42847 .18512 Metetra
.664 .741 .908 r
.42847 .18512 .43445 .19222 .44471 .18838 .43875 .18125 Metetra
.664 .741 .908 r
.43875 .18125 .44471 .18838 .455 .18452 .44908 .17736 Metetra
.664 .741 .908 r
.44908 .17736 .455 .18452 .46534 .18065 .45944 .17347 Metetra
.664 .741 .908 r
.45944 .17347 .46534 .18065 .47572 .17677 .46984 .16955 Metetra
.664 .741 .908 r
.46984 .16955 .47572 .17677 .48613 .17287 .48028 .16563 Metetra
.664 .741 .908 r
.48028 .16563 .48613 .17287 .49659 .16902 .49076 .16168 Metetra
.663 .739 .906 r
.49076 .16168 .49659 .16902 .50708 .1653 .50129 .15772 Metetra
.663 .732 .901 r
.50129 .15772 .50708 .1653 .51762 .16162 .51185 .15375 Metetra
.662 .724 .895 r
.51185 .15375 .51762 .16162 .5282 .15807 .52245 .14976 Metetra
.656 .709 .887 r
.52245 .14976 .5282 .15807 .53882 .15452 .5331 .14589 Metetra
.644 .696 .883 r
.5331 .14589 .53882 .15452 .54949 .15101 .54378 .14232 Metetra
.643 .695 .883 r
.54378 .14232 .54949 .15101 .5602 .14732 .55452 .13874 Metetra
.643 .698 .886 r
.55452 .13874 .5602 .14732 .57095 .14317 .5653 .13516 Metetra
.645 .717 .901 r
.5653 .13516 .57095 .14317 .58174 .13908 .57612 .13157 Metetra
.646 .734 .913 r
.57612 .13157 .58174 .13908 .59257 .13531 .58699 .12794 Metetra
.653 .742 .915 r
.58699 .12794 .59257 .13531 .60345 .13137 .5979 .12412 Metetra
.68 .758 .91 r
.5979 .12412 .60345 .13137 .61436 .1268 .60884 .11959 Metetra
.675 .758 .913 r
.60884 .11959 .61436 .1268 .62531 .12238 .61982 .11518 Metetra
.646 .748 .924 r
.61982 .11518 .62531 .12238 .63633 .11874 .63087 .11148 Metetra
.651 .749 .921 r
.63087 .11148 .63633 .11874 .64739 .11499 .64196 .10765 Metetra
.682 .759 .91 r
.64196 .10765 .64739 .11499 .65847 .11057 .65307 .10299 Metetra
.679 .752 .906 r
.65307 .10299 .65847 .11057 .66959 .10612 .66421 .09836 Metetra
.663 .741 .908 r
.66421 .09836 .66959 .10612 .68075 .10152 .67542 .09415 Metetra
.666 .755 .917 r
.67542 .09415 .68075 .10152 .69194 .0969 .68667 .08986 Metetra
.698 .78 .915 r
.68667 .08986 .69194 .0969 .70317 .09214 .69791 .08471 Metetra
.696 .767 .907 r
.69791 .08471 .70317 .09214 .71444 .08738 .70919 .07958 Metetra
.665 .744 .909 r
.70919 .07958 .71444 .08738 .72579 .08313 .72057 .07527 Metetra
.665 .743 .908 r
.72057 .07527 .72579 .08313 .73719 .07886 .732 .07094 Metetra
.652 .739 .913 r
.08488 .30554 .09164 .31182 .10067 .30845 .09391 .30237 Metetra
.653 .746 .918 r
.09391 .30237 .10067 .30845 .10974 .30507 .10296 .29919 Metetra
.646 .753 .927 r
.10296 .29919 .10974 .30507 .11874 .30249 .11203 .29615 Metetra
.646 .737 .916 r
.11203 .29615 .11874 .30249 .12776 .29992 .12114 .29311 Metetra
.661 .727 .898 r
.12114 .29311 .12776 .29992 .13693 .29653 .13033 .28966 Metetra
.662 .726 .897 r
.13033 .28966 .13693 .29653 .14614 .29307 .13955 .28618 Metetra
.645 .721 .904 r
.13955 .28618 .14614 .29307 .15533 .29001 .14876 .2831 Metetra
.643 .72 .904 r
.14876 .2831 .15533 .29001 .16456 .287 .158 .28006 Metetra
.667 .727 .895 r
.158 .28006 .16456 .287 .1739 .28318 .16734 .27642 Metetra
.671 .735 .898 r
.16734 .27642 .1739 .28318 .18329 .27923 .17673 .27268 Metetra
.666 .741 .906 r
.17673 .27268 .18329 .27923 .19264 .27598 .18613 .26905 Metetra
.664 .729 .898 r
.18613 .26905 .19264 .27598 .20201 .27285 .19557 .26544 Metetra
.667 .716 .885 r
.19557 .26544 .20201 .27285 .21149 .26903 .20505 .26169 Metetra
.669 .719 .887 r
.20505 .26169 .21149 .26903 .22101 .26502 .21457 .25789 Metetra
.677 .729 .889 r
.21457 .25789 .22101 .26502 .23057 .26099 .22414 .25388 Metetra
.679 .731 .889 r
.22414 .25388 .23057 .26099 .24016 .25693 .23376 .2498 Metetra
.673 .729 .892 r
.23376 .2498 .24016 .25693 .24978 .25288 .24338 .2459 Metetra
.671 .734 .897 r
.24338 .2459 .24978 .25288 .25944 .24882 .25304 .24205 Metetra
.666 .74 .905 r
.25304 .24205 .25944 .24882 .2691 .24507 .26271 .23833 Metetra
.664 .741 .908 r
.26271 .23833 .2691 .24507 .27878 .24142 .27242 .23466 Metetra
.664 .741 .908 r
.27242 .23466 .27878 .24142 .2885 .23777 .28216 .23098 Metetra
.664 .741 .908 r
.28216 .23098 .2885 .23777 .29826 .2341 .29194 .22729 Metetra
.664 .741 .908 r
.29194 .22729 .29826 .2341 .30805 .23041 .30175 .22358 Metetra
.664 .741 .908 r
.30175 .22358 .30805 .23041 .31788 .22672 .31161 .21985 Metetra
.664 .741 .908 r
.31161 .21985 .31788 .22672 .32775 .223 .32149 .21612 Metetra
.664 .741 .908 r
.32149 .21612 .32775 .223 .33765 .21928 .33142 .21237 Metetra
.664 .741 .908 r
.33142 .21237 .33765 .21928 .34759 .21554 .34138 .2086 Metetra
.664 .741 .908 r
.34138 .2086 .34759 .21554 .35757 .21179 .35138 .20482 Metetra
.664 .741 .908 r
.35138 .20482 .35757 .21179 .36758 .20802 .36142 .20103 Metetra
.664 .741 .908 r
.36142 .20103 .36758 .20802 .37764 .20424 .3715 .19722 Metetra
.664 .741 .908 r
.3715 .19722 .37764 .20424 .38773 .20044 .38161 .1934 Metetra
.664 .741 .908 r
.38161 .1934 .38773 .20044 .39785 .19663 .39176 .18956 Metetra
.664 .741 .908 r
.39176 .18956 .39785 .19663 .40802 .19281 .40195 .18571 Metetra
.664 .741 .908 r
.40195 .18571 .40802 .19281 .41823 .18897 .41218 .18184 Metetra
.664 .741 .908 r
.41218 .18184 .41823 .18897 .42847 .18512 .42245 .17796 Metetra
.664 .741 .908 r
.42245 .17796 .42847 .18512 .43875 .18125 .43276 .17407 Metetra
.664 .741 .908 r
.43276 .17407 .43875 .18125 .44908 .17736 .44311 .17016 Metetra
.664 .741 .908 r
.44311 .17016 .44908 .17736 .45944 .17347 .4535 .16623 Metetra
.664 .741 .908 r
.4535 .16623 .45944 .17347 .46984 .16955 .46392 .16229 Metetra
.664 .741 .908 r
.46392 .16229 .46984 .16955 .48028 .16563 .47439 .15833 Metetra
.664 .741 .908 r
.47439 .15833 .48028 .16563 .49076 .16168 .4849 .15436 Metetra
.664 .741 .908 r
.4849 .15436 .49076 .16168 .50129 .15772 .49545 .15038 Metetra
.664 .741 .908 r
.49545 .15038 .50129 .15772 .51185 .15375 .50603 .14638 Metetra
.664 .741 .908 r
.50603 .14638 .51185 .15375 .52245 .14976 .51666 .14236 Metetra
.661 .74 .909 r
.51666 .14236 .52245 .14976 .5331 .14589 .52734 .13839 Metetra
.655 .736 .909 r
.52734 .13839 .5331 .14589 .54378 .14232 .53805 .13455 Metetra
.652 .727 .904 r
.53805 .13455 .54378 .14232 .55452 .13874 .54881 .13077 Metetra
.644 .719 .902 r
.54881 .13077 .55452 .13874 .5653 .13516 .55961 .12717 Metetra
.647 .72 .902 r
.55961 .12717 .5653 .13516 .57612 .13157 .57046 .12349 Metetra
.654 .721 .898 r
.57046 .12349 .57612 .13157 .58699 .12794 .58135 .11959 Metetra
.655 .714 .892 r
.58135 .11959 .58699 .12794 .5979 .12412 .59229 .11565 Metetra
.659 .713 .888 r
.59229 .11565 .5979 .12412 .60884 .11959 .60326 .11156 Metetra
.66 .728 .9 r
.60326 .11156 .60884 .11959 .61982 .11518 .61428 .10747 Metetra
.655 .737 .91 r
.61428 .10747 .61982 .11518 .63087 .11148 .62535 .10351 Metetra
.658 .731 .903 r
.62535 .10351 .63087 .11148 .64196 .10765 .63646 .09944 Metetra
.679 .733 .891 r
.63646 .09944 .64196 .10765 .65307 .10299 .6476 .09475 Metetra
.677 .732 .892 r
.6476 .09475 .65307 .10299 .66421 .09836 .65877 .09009 Metetra
.662 .726 .897 r
.65877 .09009 .66421 .09836 .67542 .09415 .67001 .08585 Metetra
.663 .726 .896 r
.67001 .08585 .67542 .09415 .68667 .08986 .68129 .08156 Metetra
.677 .733 .893 r
.68129 .08156 .68667 .08986 .69791 .08471 .69259 .07685 Metetra
.679 .748 .904 r
.69259 .07685 .69791 .08471 .70919 .07958 .70393 .07214 Metetra
.674 .761 .916 r
.70393 .07214 .70919 .07958 .72057 .07527 .71533 .06755 Metetra
.674 .753 .911 r
.71533 .06755 .72057 .07527 .732 .07094 .72677 .06296 Metetra
.643 .736 .916 r
.07809 .29921 .08488 .30554 .09391 .30237 .0871 .29623 Metetra
.643 .743 .922 r
.0871 .29623 .09391 .30237 .10296 .29919 .09614 .29323 Metetra
.663 .755 .919 r
.09614 .29323 .10296 .29919 .11203 .29615 .10528 .2898 Metetra
.663 .743 .909 r
.10528 .2898 .11203 .29615 .12114 .29311 .11445 .28634 Metetra
.663 .73 .899 r
.11445 .28634 .12114 .29311 .13033 .28966 .12367 .28282 Metetra
.663 .729 .898 r
.12367 .28282 .13033 .28966 .13955 .28618 .13291 .27929 Metetra
.645 .723 .905 r
.13291 .27929 .13955 .28618 .14876 .2831 .14214 .27619 Metetra
.643 .722 .906 r
.14214 .27619 .14876 .2831 .158 .28006 .15139 .27313 Metetra
.661 .727 .898 r
.15139 .27313 .158 .28006 .16734 .27642 .16074 .2696 Metetra
.664 .733 .901 r
.16074 .2696 .16734 .27642 .17673 .27268 .17012 .266 Metetra
.678 .741 .899 r
.17012 .266 .17673 .27268 .18613 .26905 .17958 .26205 Metetra
.679 .732 .891 r
.17958 .26205 .18613 .26905 .19557 .26544 .18908 .25802 Metetra
.664 .716 .887 r
.18908 .25802 .19557 .26544 .20505 .26169 .19857 .25433 Metetra
.661 .718 .891 r
.19857 .25433 .20505 .26169 .21457 .25789 .20809 .25072 Metetra
.675 .728 .89 r
.20809 .25072 .21457 .25789 .22414 .25388 .21768 .24675 Metetra
.679 .731 .89 r
.21768 .24675 .22414 .25388 .23376 .2498 .22731 .24266 Metetra
.667 .729 .896 r
.22731 .24266 .23376 .2498 .24338 .2459 .23694 .23889 Metetra
.663 .732 .901 r
.23694 .23889 .24338 .2459 .25304 .24205 .24659 .23523 Metetra
.663 .739 .906 r
.24659 .23523 .25304 .24205 .26271 .23833 .25628 .23155 Metetra
.664 .741 .908 r
.25628 .23155 .26271 .23833 .27242 .23466 .26601 .22786 Metetra
.664 .741 .908 r
.26601 .22786 .27242 .23466 .28216 .23098 .27578 .22415 Metetra
.664 .741 .908 r
.27578 .22415 .28216 .23098 .29194 .22729 .28558 .22043 Metetra
.664 .741 .908 r
.28558 .22043 .29194 .22729 .30175 .22358 .29541 .21669 Metetra
.664 .741 .908 r
.29541 .21669 .30175 .22358 .31161 .21985 .30529 .21294 Metetra
.664 .741 .908 r
.30529 .21294 .31161 .21985 .32149 .21612 .3152 .20918 Metetra
.664 .741 .908 r
.3152 .20918 .32149 .21612 .33142 .21237 .32515 .2054 Metetra
.664 .741 .908 r
.32515 .2054 .33142 .21237 .34138 .2086 .33513 .20161 Metetra
.664 .741 .908 r
.33513 .20161 .34138 .2086 .35138 .20482 .34516 .19781 Metetra
.664 .741 .908 r
.34516 .19781 .35138 .20482 .36142 .20103 .35522 .19399 Metetra
.664 .741 .908 r
.35522 .19399 .36142 .20103 .3715 .19722 .36532 .19015 Metetra
.664 .741 .908 r
.36532 .19015 .3715 .19722 .38161 .1934 .37545 .1863 Metetra
.664 .741 .908 r
.37545 .1863 .38161 .1934 .39176 .18956 .38563 .18244 Metetra
.664 .741 .908 r
.38563 .18244 .39176 .18956 .40195 .18571 .39585 .17856 Metetra
.664 .741 .908 r
.39585 .17856 .40195 .18571 .41218 .18184 .4061 .17467 Metetra
.664 .741 .908 r
.4061 .17467 .41218 .18184 .42245 .17796 .41639 .17076 Metetra
.664 .741 .908 r
.41639 .17076 .42245 .17796 .43276 .17407 .42673 .16684 Metetra
.664 .741 .908 r
.42673 .16684 .43276 .17407 .44311 .17016 .4371 .1629 Metetra
.664 .741 .908 r
.4371 .1629 .44311 .17016 .4535 .16623 .44751 .15894 Metetra
.664 .741 .908 r
.44751 .15894 .4535 .16623 .46392 .16229 .45796 .15498 Metetra
.664 .741 .908 r
.45796 .15498 .46392 .16229 .47439 .15833 .46846 .15099 Metetra
.664 .741 .908 r
.46846 .15099 .47439 .15833 .4849 .15436 .47899 .14699 Metetra
.664 .741 .908 r
.47899 .14699 .4849 .15436 .49545 .15038 .48956 .14298 Metetra
.664 .741 .908 r
.48956 .14298 .49545 .15038 .50603 .14638 .50018 .13895 Metetra
.664 .741 .908 r
.50018 .13895 .50603 .14638 .51666 .14236 .51084 .1349 Metetra
.664 .741 .908 r
.51084 .1349 .51666 .14236 .52734 .13839 .52154 .13084 Metetra
.663 .739 .906 r
.52154 .13084 .52734 .13839 .53805 .13455 .53228 .12676 Metetra
.658 .731 .903 r
.53228 .12676 .53805 .13455 .54881 .13077 .54306 .12279 Metetra
.645 .721 .903 r
.54306 .12279 .54881 .13077 .55961 .12717 .55389 .11913 Metetra
.649 .721 .901 r
.55389 .11913 .55961 .12717 .57046 .12349 .56476 .11536 Metetra
.662 .724 .896 r
.56476 .11536 .57046 .12349 .58135 .11959 .57568 .11122 Metetra
.658 .717 .892 r
.57568 .11122 .58135 .11959 .59229 .11565 .58663 .10715 Metetra
.645 .708 .893 r
.58663 .10715 .59229 .11565 .60326 .11156 .59764 .10343 Metetra
.648 .722 .902 r
.59764 .10343 .60326 .11156 .61428 .10747 .6087 .09963 Metetra
.661 .737 .906 r
.6087 .09963 .61428 .10747 .62535 .10351 .61979 .09547 Metetra
.663 .733 .901 r
.61979 .09547 .62535 .10351 .63646 .09944 .63093 .09122 Metetra
.679 .734 .892 r
.63093 .09122 .63646 .09944 .6476 .09475 .64209 .0865 Metetra
.677 .734 .893 r
.64209 .0865 .6476 .09475 .65877 .09009 .65329 .08181 Metetra
.661 .727 .898 r
.65329 .08181 .65877 .09009 .67001 .08585 .66456 .07756 Metetra
.662 .728 .899 r
.66456 .07756 .67001 .08585 .68129 .08156 .67587 .07329 Metetra
.663 .73 .899 r
.67587 .07329 .68129 .08156 .69259 .07685 .68723 .06895 Metetra
.665 .743 .909 r
.68723 .06895 .69259 .07685 .70393 .07214 .69863 .06459 Metetra
.682 .763 .912 r
.69863 .06459 .70393 .07214 .71533 .06755 .71004 .05976 Metetra
.681 .755 .907 r
.71004 .05976 .71533 .06755 .72677 .06296 .7215 .05492 Metetra
.643 .736 .916 r
.07124 .29284 .07809 .29921 .0871 .29623 .08027 .28983 Metetra
.643 .736 .916 r
.08027 .28983 .0871 .29623 .09614 .29323 .08933 .28682 Metetra
.652 .739 .913 r
.08933 .28682 .09614 .29323 .10528 .2898 .09846 .28358 Metetra
.653 .746 .918 r
.09846 .28358 .10528 .2898 .11445 .28634 .10762 .28033 Metetra
.674 .759 .915 r
.10762 .28033 .11445 .28634 .12367 .28282 .11688 .27659 Metetra
.674 .752 .91 r
.11688 .27659 .12367 .28282 .13291 .27929 .12617 .27281 Metetra
.646 .738 .916 r
.12617 .27281 .13291 .27929 .14214 .27619 .13542 .26966 Metetra
.643 .736 .916 r
.13542 .26966 .14214 .27619 .15139 .27313 .14469 .26657 Metetra
.678 .745 .901 r
.14469 .26657 .15139 .27313 .16074 .2696 .15411 .26262 Metetra
.681 .733 .89 r
.15411 .26262 .16074 .2696 .17012 .266 .16356 .25853 Metetra
.67 .717 .883 r
.16356 .25853 .17012 .266 .17958 .26205 .17303 .25467 Metetra
.669 .72 .887 r
.17303 .25467 .17958 .26205 .18908 .25802 .18252 .25085 Metetra
.664 .725 .895 r
.18252 .25085 .18908 .25802 .19857 .25433 .19202 .24718 Metetra
.662 .726 .897 r
.19202 .24718 .19857 .25433 .20809 .25072 .20156 .24355 Metetra
.668 .728 .894 r
.20156 .24355 .20809 .25072 .21768 .24675 .21115 .23973 Metetra
.671 .734 .897 r
.21115 .23973 .21768 .24675 .22731 .24266 .22078 .23585 Metetra
.666 .74 .906 r
.22078 .23585 .22731 .24266 .23694 .23889 .23042 .23212 Metetra
.664 .741 .908 r
.23042 .23212 .23694 .23889 .24659 .23523 .2401 .22842 Metetra
.664 .741 .908 r
.2401 .22842 .24659 .23523 .25628 .23155 .24981 .22472 Metetra
.664 .741 .908 r
.24981 .22472 .25628 .23155 .26601 .22786 .25956 .221 Metetra
.664 .741 .908 r
.25956 .221 .26601 .22786 .27578 .22415 .26935 .21727 Metetra
.664 .741 .908 r
.26935 .21727 .27578 .22415 .28558 .22043 .27917 .21352 Metetra
.664 .741 .908 r
.27917 .21352 .28558 .22043 .29541 .21669 .28903 .20976 Metetra
.664 .741 .908 r
.28903 .20976 .29541 .21669 .30529 .21294 .29892 .20599 Metetra
.664 .741 .908 r
.29892 .20599 .30529 .21294 .3152 .20918 .30886 .2022 Metetra
.664 .741 .908 r
.30886 .2022 .3152 .20918 .32515 .2054 .31883 .19839 Metetra
.664 .741 .908 r
.31883 .19839 .32515 .2054 .33513 .20161 .32884 .19457 Metetra
.664 .741 .908 r
.32884 .19457 .33513 .20161 .34516 .19781 .33888 .19074 Metetra
.664 .741 .908 r
.33888 .19074 .34516 .19781 .35522 .19399 .34897 .1869 Metetra
.664 .741 .908 r
.34897 .1869 .35522 .19399 .36532 .19015 .35909 .18303 Metetra
.664 .741 .908 r
.35909 .18303 .36532 .19015 .37545 .1863 .36925 .17916 Metetra
.664 .741 .908 r
.36925 .17916 .37545 .1863 .38563 .18244 .37945 .17527 Metetra
.664 .741 .908 r
.37945 .17527 .38563 .18244 .39585 .17856 .38969 .17136 Metetra
.664 .741 .908 r
.38969 .17136 .39585 .17856 .4061 .17467 .39997 .16744 Metetra
.664 .741 .908 r
.39997 .16744 .4061 .17467 .41639 .17076 .41029 .1635 Metetra
.664 .741 .908 r
.41029 .1635 .41639 .17076 .42673 .16684 .42065 .15955 Metetra
.664 .741 .908 r
.42065 .15955 .42673 .16684 .4371 .1629 .43105 .15559 Metetra
.664 .741 .908 r
.43105 .15559 .4371 .1629 .44751 .15894 .44148 .15161 Metetra
.664 .741 .908 r
.44148 .15161 .44751 .15894 .45796 .15498 .45196 .14761 Metetra
.664 .741 .908 r
.45196 .14761 .45796 .15498 .46846 .15099 .46248 .1436 Metetra
.664 .741 .908 r
.46248 .1436 .46846 .15099 .47899 .14699 .47304 .13957 Metetra
.664 .741 .908 r
.47304 .13957 .47899 .14699 .48956 .14298 .48364 .13552 Metetra
.664 .741 .908 r
.48364 .13552 .48956 .14298 .50018 .13895 .49428 .13146 Metetra
.664 .741 .908 r
.49428 .13146 .50018 .13895 .51084 .1349 .50497 .12739 Metetra
.664 .741 .908 r
.50497 .12739 .51084 .1349 .52154 .13084 .51569 .1233 Metetra
.664 .741 .908 r
.51569 .1233 .52154 .13084 .53228 .12676 .52646 .11919 Metetra
.661 .74 .909 r
.52646 .11919 .53228 .12676 .54306 .12279 .53727 .11512 Metetra
.655 .736 .909 r
.53727 .11512 .54306 .12279 .55389 .11913 .54812 .11121 Metetra
.656 .729 .903 r
.54812 .11121 .55389 .11913 .56476 .11536 .55902 .10722 Metetra
.662 .726 .897 r
.55902 .10722 .56476 .11536 .57568 .11122 .56996 .10305 Metetra
.661 .725 .897 r
.56996 .10305 .57568 .11122 .58663 .10715 .58095 .0989 Metetra
.654 .721 .898 r
.58095 .0989 .58663 .10715 .59764 .10343 .59198 .09492 Metetra
.652 .713 .893 r
.59198 .09492 .59764 .10343 .6087 .09963 .60306 .09097 Metetra
.642 .706 .893 r
.60306 .09097 .6087 .09963 .61979 .09547 .61419 .08725 Metetra
.648 .722 .903 r
.61419 .08725 .61979 .09547 .63093 .09122 .62537 .08338 Metetra
.681 .748 .902 r
.62537 .08338 .63093 .09122 .64209 .0865 .63656 .07863 Metetra
.678 .747 .903 r
.63656 .07863 .64209 .0865 .65329 .08181 .6478 .07393 Metetra
.654 .738 .912 r
.6478 .07393 .65329 .08181 .66456 .07756 .6591 .06988 Metetra
.655 .746 .917 r
.6591 .06988 .66456 .07756 .67587 .07329 .67046 .06578 Metetra
.674 .761 .916 r
.67046 .06578 .67587 .07329 .68723 .06895 .68183 .06118 Metetra
.674 .753 .91 r
.68183 .06118 .68723 .06895 .69863 .06459 .69325 .05655 Metetra
.681 .748 .902 r
.69325 .05655 .69863 .06459 .71004 .05976 .7047 .05169 Metetra
.681 .748 .902 r
.7047 .05169 .71004 .05976 .7215 .05492 .71619 .04682 Metetra
.644 .737 .917 r
.06435 .28645 .07124 .29284 .08027 .28983 .0734 .28341 Metetra
.644 .737 .917 r
.0734 .28341 .08027 .28983 .08933 .28682 .08248 .28036 Metetra
.644 .736 .916 r
.08248 .28036 .08933 .28682 .09846 .28358 .09159 .27729 Metetra
.644 .743 .921 r
.09159 .27729 .09846 .28358 .10762 .28033 .10075 .27422 Metetra
.68 .759 .91 r
.10075 .27422 .10762 .28033 .11688 .27659 .11005 .27028 Metetra
.682 .753 .905 r
.11005 .27028 .11688 .27659 .12617 .27281 .11939 .26627 Metetra
.649 .738 .915 r
.11939 .26627 .12617 .27281 .13542 .26966 .12866 .26306 Metetra
.645 .735 .915 r
.12866 .26306 .13542 .26966 .14469 .26657 .13796 .25991 Metetra
.691 .746 .894 r
.13796 .25991 .14469 .26657 .15411 .26262 .14743 .25559 Metetra
.695 .737 .883 r
.14743 .25559 .15411 .26262 .16356 .25853 .15696 .25107 Metetra
.666 .717 .886 r
.15696 .25107 .16356 .25853 .17303 .25467 .16643 .2473 Metetra
.661 .719 .891 r
.16643 .2473 .17303 .25467 .18252 .25085 .17591 .24367 Metetra
.662 .726 .896 r
.17591 .24367 .18252 .25085 .19202 .24718 .18543 .24002 Metetra
.662 .727 .897 r
.18543 .24002 .19202 .24718 .20156 .24355 .19499 .23636 Metetra
.662 .727 .897 r
.19499 .23636 .20156 .24355 .21115 .23973 .20458 .23268 Metetra
.663 .732 .901 r
.20458 .23268 .21115 .23973 .22078 .23585 .2142 .22899 Metetra
.663 .739 .907 r
.2142 .22899 .22078 .23585 .23042 .23212 .22386 .22529 Metetra
.664 .741 .908 r
.22386 .22529 .23042 .23212 .2401 .22842 .23356 .22157 Metetra
.664 .741 .908 r
.23356 .22157 .2401 .22842 .24981 .22472 .2433 .21784 Metetra
.664 .741 .908 r
.2433 .21784 .24981 .22472 .25956 .221 .25307 .2141 Metetra
.664 .741 .908 r
.25307 .2141 .25956 .221 .26935 .21727 .26287 .21034 Metetra
.664 .741 .908 r
.26287 .21034 .26935 .21727 .27917 .21352 .27272 .20657 Metetra
.664 .741 .908 r
.27272 .20657 .27917 .21352 .28903 .20976 .2826 .20278 Metetra
.664 .741 .908 r
.2826 .20278 .28903 .20976 .29892 .20599 .29252 .19898 Metetra
.664 .741 .908 r
.29252 .19898 .29892 .20599 .30886 .2022 .30247 .19516 Metetra
.664 .741 .908 r
.30247 .19516 .30886 .2022 .31883 .19839 .31247 .19133 Metetra
.664 .741 .908 r
.31247 .19133 .31883 .19839 .32884 .19457 .3225 .18749 Metetra
.664 .741 .908 r
.3225 .18749 .32884 .19457 .33888 .19074 .33257 .18363 Metetra
.664 .741 .908 r
.33257 .18363 .33888 .19074 .34897 .1869 .34268 .17976 Metetra
.664 .741 .908 r
.34268 .17976 .34897 .1869 .35909 .18303 .35282 .17587 Metetra
.664 .741 .908 r
.35282 .17587 .35909 .18303 .36925 .17916 .36301 .17196 Metetra
.664 .741 .908 r
.36301 .17196 .36925 .17916 .37945 .17527 .37323 .16804 Metetra
.664 .741 .908 r
.37323 .16804 .37945 .17527 .38969 .17136 .3835 .16411 Metetra
.664 .741 .908 r
.3835 .16411 .38969 .17136 .39997 .16744 .3938 .16016 Metetra
.664 .741 .908 r
.3938 .16016 .39997 .16744 .41029 .1635 .40414 .1562 Metetra
.664 .741 .908 r
.40414 .1562 .41029 .1635 .42065 .15955 .41453 .15222 Metetra
.664 .741 .908 r
.41453 .15222 .42065 .15955 .43105 .15559 .42495 .14822 Metetra
.664 .741 .908 r
.42495 .14822 .43105 .15559 .44148 .15161 .43541 .14421 Metetra
.664 .741 .908 r
.43541 .14421 .44148 .15161 .45196 .14761 .44592 .14019 Metetra
.664 .741 .908 r
.44592 .14019 .45196 .14761 .46248 .1436 .45646 .13615 Metetra
.664 .741 .908 r
.45646 .13615 .46248 .1436 .47304 .13957 .46705 .13209 Metetra
.664 .741 .908 r
.46705 .13209 .47304 .13957 .48364 .13552 .47767 .12802 Metetra
.664 .741 .908 r
.47767 .12802 .48364 .13552 .49428 .13146 .48834 .12393 Metetra
.664 .741 .908 r
.48834 .12393 .49428 .13146 .50497 .12739 .49905 .11982 Metetra
.664 .741 .908 r
.49905 .11982 .50497 .12739 .51569 .1233 .50981 .1157 Metetra
.664 .741 .908 r
.50981 .1157 .51569 .1233 .52646 .11919 .5206 .11157 Metetra
.664 .741 .908 r
.5206 .11157 .52646 .11919 .53727 .11512 .53144 .10741 Metetra
.663 .739 .907 r
.53144 .10741 .53727 .11512 .54812 .11121 .54232 .10324 Metetra
.663 .732 .901 r
.54232 .10324 .54812 .11121 .55902 .10722 .55324 .09906 Metetra
.662 .727 .897 r
.55324 .09906 .55902 .10722 .56996 .10305 .56421 .09485 Metetra
.662 .727 .897 r
.56421 .09485 .56996 .10305 .58095 .0989 .57522 .09063 Metetra
.662 .726 .896 r
.57522 .09063 .58095 .0989 .59198 .09492 .58628 .0864 Metetra
.656 .717 .893 r
.58628 .0864 .59198 .09492 .60306 .09097 .59738 .08229 Metetra
.627 .701 .898 r
.59738 .08229 .60306 .09097 .61419 .08725 .60855 .07895 Metetra
.634 .716 .906 r
.60855 .07895 .61419 .08725 .62537 .08338 .61977 .07542 Metetra
.679 .746 .901 r
.61977 .07542 .62537 .08338 .63656 .07863 .63099 .07067 Metetra
.676 .746 .903 r
.63099 .07067 .63656 .07863 .6478 .07393 .64226 .06598 Metetra
.646 .735 .914 r
.64226 .06598 .6478 .07393 .6591 .06988 .65361 .06211 Metetra
.648 .742 .918 r
.65361 .06211 .6591 .06988 .67046 .06578 .665 .05816 Metetra
.681 .762 .912 r
.665 .05816 .67046 .06578 .68183 .06118 .6764 .05332 Metetra
.681 .755 .907 r
.6764 .05332 .68183 .06118 .69325 .05655 .68784 .04846 Metetra
.68 .748 .903 r
.68784 .04846 .69325 .05655 .7047 .05169 .69932 .04358 Metetra
.68 .749 .903 r
.69932 .04358 .7047 .05169 .71619 .04682 .71085 .03869 Metetra
.655 .755 .923 r
.05735 .28046 .06435 .28645 .0734 .28341 .06644 .27717 Metetra
.654 .747 .918 r
.06644 .27717 .0734 .28341 .08248 .28036 .07558 .27386 Metetra
.654 .739 .912 r
.07558 .27386 .08248 .28036 .09159 .27729 .08474 .27055 Metetra
.654 .732 .907 r
.08474 .27055 .09159 .27729 .10075 .27422 .09394 .26721 Metetra
.67 .729 .894 r
.09394 .26721 .10075 .27422 .11005 .27028 .10324 .26345 Metetra
.671 .735 .898 r
.10324 .26345 .11005 .27028 .11939 .26627 .11257 .25965 Metetra
.665 .741 .907 r
.11257 .25965 .11939 .26627 .12866 .26306 .12191 .25602 Metetra
.663 .728 .898 r
.12191 .25602 .12866 .26306 .13796 .25991 .13128 .25239 Metetra
.675 .717 .881 r
.13128 .25239 .13796 .25991 .14743 .25559 .14073 .24838 Metetra
.678 .729 .888 r
.14073 .24838 .14743 .25559 .15696 .25107 .15022 .2443 Metetra
.666 .74 .905 r
.15022 .2443 .15696 .25107 .16643 .2473 .1597 .24058 Metetra
.664 .741 .908 r
.1597 .24058 .16643 .2473 .17591 .24367 .1692 .23692 Metetra
.664 .741 .908 r
.1692 .23692 .17591 .24367 .18543 .24002 .17874 .23325 Metetra
.664 .741 .908 r
.17874 .23325 .18543 .24002 .19499 .23636 .18832 .22956 Metetra
.664 .741 .908 r
.18832 .22956 .19499 .23636 .20458 .23268 .19793 .22586 Metetra
.664 .741 .908 r
.19793 .22586 .20458 .23268 .2142 .22899 .20758 .22215 Metetra
.664 .741 .908 r
.20758 .22215 .2142 .22899 .22386 .22529 .21726 .21842 Metetra
.664 .741 .908 r
.21726 .21842 .22386 .22529 .23356 .22157 .22698 .21468 Metetra
.664 .741 .908 r
.22698 .21468 .23356 .22157 .2433 .21784 .23673 .21092 Metetra
.664 .741 .908 r
.23673 .21092 .2433 .21784 .25307 .2141 .24653 .20715 Metetra
.664 .741 .908 r
.24653 .20715 .25307 .2141 .26287 .21034 .25635 .20336 Metetra
.664 .741 .908 r
.25635 .20336 .26287 .21034 .27272 .20657 .26622 .19956 Metetra
.664 .741 .908 r
.26622 .19956 .27272 .20657 .2826 .20278 .27612 .19575 Metetra
.664 .741 .908 r
.27612 .19575 .2826 .20278 .29252 .19898 .28607 .19192 Metetra
.664 .741 .908 r
.28607 .19192 .29252 .19898 .30247 .19516 .29604 .18808 Metetra
.664 .741 .908 r
.29604 .18808 .30247 .19516 .31247 .19133 .30606 .18422 Metetra
.664 .741 .908 r
.30606 .18422 .31247 .19133 .3225 .18749 .31612 .18035 Metetra
.664 .741 .908 r
.31612 .18035 .3225 .18749 .33257 .18363 .32621 .17647 Metetra
.664 .741 .908 r
.32621 .17647 .33257 .18363 .34268 .17976 .33634 .17256 Metetra
.664 .741 .908 r
.33634 .17256 .34268 .17976 .35282 .17587 .34651 .16865 Metetra
.664 .741 .908 r
.34651 .16865 .35282 .17587 .36301 .17196 .35672 .16472 Metetra
.664 .741 .908 r
.35672 .16472 .36301 .17196 .37323 .16804 .36697 .16077 Metetra
.664 .741 .908 r
.36697 .16077 .37323 .16804 .3835 .16411 .37726 .15681 Metetra
.664 .741 .908 r
.37726 .15681 .3835 .16411 .3938 .16016 .38758 .15283 Metetra
.664 .741 .908 r
.38758 .15283 .3938 .16016 .40414 .1562 .39795 .14884 Metetra
.664 .741 .908 r
.39795 .14884 .40414 .1562 .41453 .15222 .40836 .14483 Metetra
.664 .741 .908 r
.40836 .14483 .41453 .15222 .42495 .14822 .41881 .14081 Metetra
.664 .741 .908 r
.41881 .14081 .42495 .14822 .43541 .14421 .4293 .13677 Metetra
.664 .741 .908 r
.4293 .13677 .43541 .14421 .44592 .14019 .43983 .13272 Metetra
.664 .741 .908 r
.43983 .13272 .44592 .14019 .45646 .13615 .4504 .12865 Metetra
.664 .741 .908 r
.4504 .12865 .45646 .13615 .46705 .13209 .46101 .12456 Metetra
.664 .741 .908 r
.46101 .12456 .46705 .13209 .47767 .12802 .47166 .12046 Metetra
.664 .741 .908 r
.47166 .12046 .47767 .12802 .48834 .12393 .48236 .11634 Metetra
.664 .741 .908 r
.48236 .11634 .48834 .12393 .49905 .11982 .4931 .1122 Metetra
.664 .741 .908 r
.4931 .1122 .49905 .11982 .50981 .1157 .50388 .10805 Metetra
.664 .741 .908 r
.50388 .10805 .50981 .1157 .5206 .11157 .5147 .10388 Metetra
.664 .741 .908 r
.5147 .10388 .5206 .11157 .53144 .10741 .52557 .0997 Metetra
.664 .741 .908 r
.52557 .0997 .53144 .10741 .54232 .10324 .53648 .0955 Metetra
.664 .741 .908 r
.53648 .0955 .54232 .10324 .55324 .09906 .54743 .09128 Metetra
.664 .741 .908 r
.54743 .09128 .55324 .09906 .56421 .09485 .55842 .08705 Metetra
.664 .741 .908 r
.55842 .08705 .56421 .09485 .57522 .09063 .56946 .0828 Metetra
.664 .741 .908 r
.56946 .0828 .57522 .09063 .58628 .0864 .58055 .07853 Metetra
.661 .74 .909 r
.58055 .07853 .58628 .0864 .59738 .08229 .59168 .07432 Metetra
.646 .732 .911 r
.59168 .07432 .59738 .08229 .60855 .07895 .60286 .07048 Metetra
.647 .718 .9 r
.60286 .07048 .60855 .07895 .61977 .07542 .61409 .06656 Metetra
.66 .713 .887 r
.61409 .06656 .61977 .07542 .63099 .07067 .62536 .06225 Metetra
.661 .727 .899 r
.62536 .06225 .63099 .07067 .64226 .06598 .63668 .05794 Metetra
.655 .737 .91 r
.63668 .05794 .64226 .06598 .65361 .06211 .64804 .05379 Metetra
.656 .73 .904 r
.64804 .05379 .65361 .06211 .665 .05816 .65946 .0496 Metetra
.67 .73 .895 r
.65946 .0496 .665 .05816 .6764 .05332 .6709 .04497 Metetra
.671 .737 .9 r
.6709 .04497 .6764 .05332 .68784 .04846 .68239 .04031 Metetra
.672 .745 .906 r
.68239 .04031 .68784 .04846 .69932 .04358 .69392 .03564 Metetra
.672 .753 .911 r
.69392 .03564 .69932 .04358 .71085 .03869 .70549 .03095 Metetra
.664 .757 .919 r
.05029 .27441 .05735 .28046 .06644 .27717 .05944 .27088 Metetra
.664 .749 .914 r
.05944 .27088 .06644 .27717 .07558 .27386 .06863 .26732 Metetra
.664 .742 .908 r
.06863 .26732 .07558 .27386 .08474 .27055 .07785 .26375 Metetra
.663 .734 .903 r
.07785 .26375 .08474 .27055 .09394 .26721 .0871 .26017 Metetra
.662 .727 .897 r
.0871 .26017 .09394 .26721 .10324 .26345 .09638 .25658 Metetra
.663 .733 .902 r
.09638 .25658 .10324 .26345 .11257 .25965 .1057 .25297 Metetra
.68 .744 .9 r
.1057 .25297 .11257 .25965 .12191 .25602 .11511 .24894 Metetra
.68 .733 .89 r
.11511 .24894 .12191 .25602 .13128 .25239 .12455 .24485 Metetra
.663 .715 .887 r
.12455 .24485 .13128 .25239 .14073 .24838 .13398 .24114 Metetra
.662 .725 .896 r
.13398 .24114 .14073 .24838 .15022 .2443 .14344 .23749 Metetra
.663 .739 .906 r
.14344 .23749 .15022 .2443 .1597 .24058 .15293 .23381 Metetra
.664 .741 .908 r
.15293 .23381 .1597 .24058 .1692 .23692 .16245 .23013 Metetra
.664 .741 .908 r
.16245 .23013 .1692 .23692 .17874 .23325 .17201 .22643 Metetra
.664 .741 .908 r
.17201 .22643 .17874 .23325 .18832 .22956 .18161 .22272 Metetra
.664 .741 .908 r
.18161 .22272 .18832 .22956 .19793 .22586 .19124 .21899 Metetra
.664 .741 .908 r
.19124 .21899 .19793 .22586 .20758 .22215 .20091 .21525 Metetra
.664 .741 .908 r
.20091 .21525 .20758 .22215 .21726 .21842 .21061 .2115 Metetra
.664 .741 .908 r
.21061 .2115 .21726 .21842 .22698 .21468 .22035 .20773 Metetra
.664 .741 .908 r
.22035 .20773 .22698 .21468 .23673 .21092 .23013 .20395 Metetra
.664 .741 .908 r
.23013 .20395 .23673 .21092 .24653 .20715 .23994 .20015 Metetra
.664 .741 .908 r
.23994 .20015 .24653 .20715 .25635 .20336 .24979 .19634 Metetra
.664 .741 .908 r
.24979 .19634 .25635 .20336 .26622 .19956 .25968 .19251 Metetra
.664 .741 .908 r
.25968 .19251 .26622 .19956 .27612 .19575 .2696 .18867 Metetra
.664 .741 .908 r
.2696 .18867 .27612 .19575 .28607 .19192 .27957 .18482 Metetra
.664 .741 .908 r
.27957 .18482 .28607 .19192 .29604 .18808 .28957 .18095 Metetra
.664 .741 .908 r
.28957 .18095 .29604 .18808 .30606 .18422 .29961 .17706 Metetra
.664 .741 .908 r
.29961 .17706 .30606 .18422 .31612 .18035 .30969 .17317 Metetra
.664 .741 .908 r
.30969 .17317 .31612 .18035 .32621 .17647 .3198 .16925 Metetra
.664 .741 .908 r
.3198 .16925 .32621 .17647 .33634 .17256 .32996 .16532 Metetra
.664 .741 .908 r
.32996 .16532 .33634 .17256 .34651 .16865 .34015 .16138 Metetra
.664 .741 .908 r
.34015 .16138 .34651 .16865 .35672 .16472 .35039 .15742 Metetra
.664 .741 .908 r
.35039 .15742 .35672 .16472 .36697 .16077 .36066 .15345 Metetra
.664 .741 .908 r
.36066 .15345 .36697 .16077 .37726 .15681 .37097 .14946 Metetra
.664 .741 .908 r
.37097 .14946 .37726 .15681 .38758 .15283 .38132 .14545 Metetra
.664 .741 .908 r
.38132 .14545 .38758 .15283 .39795 .14884 .39172 .14143 Metetra
.664 .741 .908 r
.39172 .14143 .39795 .14884 .40836 .14483 .40215 .13739 Metetra
.664 .741 .908 r
.40215 .13739 .40836 .14483 .41881 .14081 .41262 .13334 Metetra
.664 .741 .908 r
.41262 .13334 .41881 .14081 .4293 .13677 .42314 .12927 Metetra
.664 .741 .908 r
.42314 .12927 .4293 .13677 .43983 .13272 .43369 .12519 Metetra
.664 .741 .908 r
.43369 .12519 .43983 .13272 .4504 .12865 .44429 .12109 Metetra
.664 .741 .908 r
.44429 .12109 .4504 .12865 .46101 .12456 .45493 .11697 Metetra
.664 .741 .908 r
.45493 .11697 .46101 .12456 .47166 .12046 .46561 .11284 Metetra
.664 .741 .908 r
.46561 .11284 .47166 .12046 .48236 .11634 .47633 .10869 Metetra
.664 .741 .908 r
.47633 .10869 .48236 .11634 .4931 .1122 .4871 .10453 Metetra
.664 .741 .908 r
.4871 .10453 .4931 .1122 .50388 .10805 .49791 .10035 Metetra
.664 .741 .908 r
.49791 .10035 .50388 .10805 .5147 .10388 .50876 .09615 Metetra
.664 .741 .908 r
.50876 .09615 .5147 .10388 .52557 .0997 .51965 .09193 Metetra
.664 .741 .908 r
.51965 .09193 .52557 .0997 .53648 .0955 .53059 .0877 Metetra
.664 .741 .908 r
.53059 .0877 .53648 .0955 .54743 .09128 .54157 .08345 Metetra
.664 .741 .908 r
.54157 .08345 .54743 .09128 .55842 .08705 .55259 .07919 Metetra
.664 .741 .908 r
.55259 .07919 .55842 .08705 .56946 .0828 .56366 .07491 Metetra
.664 .741 .908 r
.56366 .07491 .56946 .0828 .58055 .07853 .57478 .07061 Metetra
.664 .741 .908 r
.57478 .07061 .58055 .07853 .59168 .07432 .58593 .06629 Metetra
.663 .739 .906 r
.58593 .06629 .59168 .07432 .60286 .07048 .59714 .06196 Metetra
.66 .724 .896 r
.59714 .06196 .60286 .07048 .61409 .06656 .60839 .05766 Metetra
.644 .707 .893 r
.60839 .05766 .61409 .06656 .62536 .06225 .6197 .05377 Metetra
.647 .721 .903 r
.6197 .05377 .62536 .06225 .63668 .05794 .63105 .04981 Metetra
.663 .74 .907 r
.63105 .04981 .63668 .05794 .64804 .05379 .64244 .04541 Metetra
.663 .733 .902 r
.64244 .04541 .64804 .05379 .65946 .0496 .65388 .04099 Metetra
.662 .727 .897 r
.65388 .04099 .65946 .0496 .6709 .04497 .66536 .03655 Metetra
.663 .734 .903 r
.66536 .03655 .6709 .04497 .68239 .04031 .67689 .0321 Metetra
.664 .742 .908 r
.67689 .0321 .68239 .04031 .69392 .03564 .68847 .02763 Metetra
.664 .749 .914 r
.68847 .02763 .69392 .03564 .70549 .03095 .70009 .02313 Metetra
.663 .741 .908 r
.04326 .26787 .05029 .27441 .05944 .27088 .05243 .26431 Metetra
.663 .741 .908 r
.05243 .26431 .05944 .27088 .06863 .26732 .06163 .26073 Metetra
.673 .744 .904 r
.06163 .26073 .06863 .26732 .07785 .26375 .0709 .25692 Metetra
.672 .736 .898 r
.0709 .25692 .07785 .26375 .0871 .26017 .08021 .25308 Metetra
.663 .727 .897 r
.08021 .25308 .0871 .26017 .09638 .25658 .08951 .24944 Metetra
.662 .726 .897 r
.08951 .24944 .09638 .25658 .1057 .25297 .09885 .24582 Metetra
.67 .728 .893 r
.09885 .24582 .1057 .25297 .11511 .24894 .10824 .24197 Metetra
.672 .735 .898 r
.10824 .24197 .11511 .24894 .12455 .24485 .11768 .23808 Metetra
.665 .741 .907 r
.11768 .23808 .12455 .24485 .13398 .24114 .12712 .23438 Metetra
.664 .741 .908 r
.12712 .23438 .13398 .24114 .14344 .23749 .1366 .2307 Metetra
.664 .741 .908 r
.1366 .2307 .14344 .23749 .15293 .23381 .14611 .227 Metetra
.664 .741 .908 r
.14611 .227 .15293 .23381 .16245 .23013 .15565 .22329 Metetra
.664 .741 .908 r
.15565 .22329 .16245 .23013 .17201 .22643 .16523 .21957 Metetra
.664 .741 .908 r
.16523 .21957 .17201 .22643 .18161 .22272 .17485 .21583 Metetra
.664 .741 .908 r
.17485 .21583 .18161 .22272 .19124 .21899 .1845 .21208 Metetra
.664 .741 .908 r
.1845 .21208 .19124 .21899 .20091 .21525 .19419 .20831 Metetra
.664 .741 .908 r
.19419 .20831 .20091 .21525 .21061 .2115 .20391 .20453 Metetra
.664 .741 .908 r
.20391 .20453 .21061 .2115 .22035 .20773 .21367 .20073 Metetra
.664 .741 .908 r
.21367 .20073 .22035 .20773 .23013 .20395 .22347 .19693 Metetra
.664 .741 .908 r
.22347 .19693 .23013 .20395 .23994 .20015 .23331 .1931 Metetra
.664 .741 .908 r
.23331 .1931 .23994 .20015 .24979 .19634 .24318 .18926 Metetra
.664 .741 .908 r
.24318 .18926 .24979 .19634 .25968 .19251 .25309 .18541 Metetra
.664 .741 .908 r
.25309 .18541 .25968 .19251 .2696 .18867 .26304 .18155 Metetra
.664 .741 .908 r
.26304 .18155 .2696 .18867 .27957 .18482 .27303 .17766 Metetra
.664 .741 .908 r
.27303 .17766 .27957 .18482 .28957 .18095 .28305 .17377 Metetra
.664 .741 .908 r
.28305 .17377 .28957 .18095 .29961 .17706 .29311 .16985 Metetra
.664 .741 .908 r
.29311 .16985 .29961 .17706 .30969 .17317 .30321 .16593 Metetra
.664 .741 .908 r
.30321 .16593 .30969 .17317 .3198 .16925 .31335 .16199 Metetra
.664 .741 .908 r
.31335 .16199 .3198 .16925 .32996 .16532 .32353 .15803 Metetra
.664 .741 .908 r
.32353 .15803 .32996 .16532 .34015 .16138 .33375 .15406 Metetra
.664 .741 .908 r
.33375 .15406 .34015 .16138 .35039 .15742 .34401 .15007 Metetra
.664 .741 .908 r
.34401 .15007 .35039 .15742 .36066 .15345 .3543 .14607 Metetra
.664 .741 .908 r
.3543 .14607 .36066 .15345 .37097 .14946 .36464 .14205 Metetra
.664 .741 .908 r
.36464 .14205 .37097 .14946 .38132 .14545 .37502 .13801 Metetra
.664 .741 .908 r
.37502 .13801 .38132 .14545 .39172 .14143 .38544 .13396 Metetra
.664 .741 .908 r
.38544 .13396 .39172 .14143 .40215 .13739 .3959 .1299 Metetra
.664 .741 .908 r
.3959 .1299 .40215 .13739 .41262 .13334 .4064 .12582 Metetra
.664 .741 .908 r
.4064 .12582 .41262 .13334 .42314 .12927 .41694 .12172 Metetra
.664 .741 .908 r
.41694 .12172 .42314 .12927 .43369 .12519 .42752 .11761 Metetra
.664 .741 .908 r
.42752 .11761 .43369 .12519 .44429 .12109 .43814 .11348 Metetra
.664 .741 .908 r
.43814 .11348 .44429 .12109 .45493 .11697 .44881 .10933 Metetra
.664 .741 .908 r
.44881 .10933 .45493 .11697 .46561 .11284 .45951 .10517 Metetra
.664 .741 .908 r
.45951 .10517 .46561 .11284 .47633 .10869 .47026 .10099 Metetra
.664 .741 .908 r
.47026 .10099 .47633 .10869 .4871 .10453 .48106 .09679 Metetra
.664 .741 .908 r
.48106 .09679 .4871 .10453 .49791 .10035 .49189 .09258 Metetra
.664 .741 .908 r
.49189 .09258 .49791 .10035 .50876 .09615 .50277 .08835 Metetra
.664 .741 .908 r
.50277 .08835 .50876 .09615 .51965 .09193 .51369 .08411 Metetra
.664 .741 .908 r
.51369 .08411 .51965 .09193 .53059 .0877 .52466 .07985 Metetra
.664 .741 .908 r
.52466 .07985 .53059 .0877 .54157 .08345 .53567 .07557 Metetra
.664 .741 .908 r
.53567 .07557 .54157 .08345 .55259 .07919 .54672 .07127 Metetra
.664 .741 .908 r
.54672 .07127 .55259 .07919 .56366 .07491 .55782 .06695 Metetra
.664 .741 .908 r
.55782 .06695 .56366 .07491 .57478 .07061 .56896 .06262 Metetra
.664 .741 .908 r
.56896 .06262 .57478 .07061 .58593 .06629 .58015 .05827 Metetra
.664 .741 .908 r
.58015 .05827 .58593 .06629 .59714 .06196 .59138 .05391 Metetra
.662 .741 .908 r
.59138 .05391 .59714 .06196 .60839 .05766 .60266 .04955 Metetra
.655 .737 .91 r
.60266 .04955 .60839 .05766 .6197 .05377 .61399 .04539 Metetra
.655 .73 .904 r
.61399 .04539 .6197 .05377 .63105 .04981 .62537 .04118 Metetra
.662 .726 .897 r
.62537 .04118 .63105 .04981 .64244 .04541 .63679 .03675 Metetra
.661 .726 .897 r
.63679 .03675 .64244 .04541 .65388 .04099 .64826 .03231 Metetra
.653 .723 .9 r
.64826 .03231 .65388 .04099 .66536 .03655 .65978 .02808 Metetra
.654 .73 .905 r
.65978 .02808 .66536 .03655 .67689 .0321 .67135 .02382 Metetra
.663 .741 .908 r
.67135 .02382 .67689 .0321 .68847 .02763 .68296 .01931 Metetra
.663 .741 .908 r
.68296 .01931 .68847 .02763 .70009 .02313 .69462 .01478 Metetra
.663 .741 .908 r
.03619 .26128 .04326 .26787 .05243 .26431 .04537 .2577 Metetra
.663 .741 .908 r
.04537 .2577 .05243 .26431 .06163 .26073 .05459 .2541 Metetra
.681 .746 .9 r
.05459 .2541 .06163 .26073 .0709 .25692 .06391 .25003 Metetra
.681 .739 .894 r
.06391 .25003 .0709 .25692 .08021 .25308 .07327 .24594 Metetra
.663 .727 .897 r
.07327 .24594 .08021 .25308 .08951 .24944 .08259 .24227 Metetra
.662 .726 .897 r
.08259 .24227 .08951 .24944 .09885 .24582 .09195 .23861 Metetra
.662 .726 .897 r
.09195 .23861 .09885 .24582 .10824 .24197 .10134 .23495 Metetra
.663 .733 .902 r
.10134 .23495 .10824 .24197 .11768 .23808 .11076 .23126 Metetra
.663 .74 .907 r
.11076 .23126 .11768 .23808 .12712 .23438 .12022 .22757 Metetra
.664 .741 .908 r
.12022 .22757 .12712 .23438 .1366 .2307 .12971 .22386 Metetra
.664 .741 .908 r
.12971 .22386 .1366 .2307 .14611 .227 .13924 .22014 Metetra
.664 .741 .908 r
.13924 .22014 .14611 .227 .15565 .22329 .1488 .2164 Metetra
.664 .741 .908 r
.1488 .2164 .15565 .22329 .16523 .21957 .1584 .21265 Metetra
.664 .741 .908 r
.1584 .21265 .16523 .21957 .17485 .21583 .16804 .20889 Metetra
.664 .741 .908 r
.16804 .20889 .17485 .21583 .1845 .21208 .17771 .20511 Metetra
.664 .741 .908 r
.17771 .20511 .1845 .21208 .19419 .20831 .18742 .20132 Metetra
.664 .741 .908 r
.18742 .20132 .19419 .20831 .20391 .20453 .19717 .19751 Metetra
.664 .741 .908 r
.19717 .19751 .20391 .20453 .21367 .20073 .20695 .19369 Metetra
.664 .741 .908 r
.20695 .19369 .21367 .20073 .22347 .19693 .21677 .18986 Metetra
.664 .741 .908 r
.21677 .18986 .22347 .19693 .23331 .1931 .22663 .18601 Metetra
.664 .741 .908 r
.22663 .18601 .23331 .1931 .24318 .18926 .23652 .18214 Metetra
.664 .741 .908 r
.23652 .18214 .24318 .18926 .25309 .18541 .24646 .17826 Metetra
.664 .741 .908 r
.24646 .17826 .25309 .18541 .26304 .18155 .25643 .17437 Metetra
.664 .741 .908 r
.25643 .17437 .26304 .18155 .27303 .17766 .26644 .17046 Metetra
.664 .741 .908 r
.26644 .17046 .27303 .17766 .28305 .17377 .27648 .16653 Metetra
.664 .741 .908 r
.27648 .16653 .28305 .17377 .29311 .16985 .28657 .16259 Metetra
.664 .741 .908 r
.28657 .16259 .29311 .16985 .30321 .16593 .29669 .15864 Metetra
.664 .741 .908 r
.29669 .15864 .30321 .16593 .31335 .16199 .30686 .15467 Metetra
.664 .741 .908 r
.30686 .15467 .31335 .16199 .32353 .15803 .31706 .15068 Metetra
.664 .741 .908 r
.31706 .15068 .32353 .15803 .33375 .15406 .3273 .14668 Metetra
.664 .741 .908 r
.3273 .14668 .33375 .15406 .34401 .15007 .33758 .14267 Metetra
.664 .741 .908 r
.33758 .14267 .34401 .15007 .3543 .14607 .3479 .13864 Metetra
.664 .741 .908 r
.3479 .13864 .3543 .14607 .36464 .14205 .35827 .13459 Metetra
.664 .741 .908 r
.35827 .13459 .36464 .14205 .37502 .13801 .36867 .13053 Metetra
.664 .741 .908 r
.36867 .13053 .37502 .13801 .38544 .13396 .37911 .12645 Metetra
.664 .741 .908 r
.37911 .12645 .38544 .13396 .3959 .1299 .3896 .12235 Metetra
.664 .741 .908 r
.3896 .12235 .3959 .1299 .4064 .12582 .40012 .11824 Metetra
.664 .741 .908 r
.40012 .11824 .4064 .12582 .41694 .12172 .41069 .11411 Metetra
.664 .741 .908 r
.41069 .11411 .41694 .12172 .42752 .11761 .4213 .10997 Metetra
.664 .741 .908 r
.4213 .10997 .42752 .11761 .43814 .11348 .43195 .10581 Metetra
.664 .741 .908 r
.43195 .10581 .43814 .11348 .44881 .10933 .44264 .10163 Metetra
.664 .741 .908 r
.44264 .10163 .44881 .10933 .45951 .10517 .45337 .09744 Metetra
.664 .741 .908 r
.45337 .09744 .45951 .10517 .47026 .10099 .46415 .09323 Metetra
.664 .741 .908 r
.46415 .09323 .47026 .10099 .48106 .09679 .47497 .08901 Metetra
.664 .741 .908 r
.47497 .08901 .48106 .09679 .49189 .09258 .48583 .08476 Metetra
.664 .741 .908 r
.48583 .08476 .49189 .09258 .50277 .08835 .49674 .0805 Metetra
.664 .741 .908 r
.49674 .0805 .50277 .08835 .51369 .08411 .50769 .07623 Metetra
.664 .741 .908 r
.50769 .07623 .51369 .08411 .52466 .07985 .51868 .07193 Metetra
.664 .741 .908 r
.51868 .07193 .52466 .07985 .53567 .07557 .52972 .06762 Metetra
.664 .741 .908 r
.52972 .06762 .53567 .07557 .54672 .07127 .5408 .06329 Metetra
.664 .741 .908 r
.5408 .06329 .54672 .07127 .55782 .06695 .55193 .05894 Metetra
.664 .741 .908 r
.55193 .05894 .55782 .06695 .56896 .06262 .5631 .05458 Metetra
.664 .741 .908 r
.5631 .05458 .56896 .06262 .58015 .05827 .57432 .0502 Metetra
.664 .741 .908 r
.57432 .0502 .58015 .05827 .59138 .05391 .58558 .0458 Metetra
.664 .741 .908 r
.58558 .0458 .59138 .05391 .60266 .04955 .59689 .04138 Metetra
.663 .74 .907 r
.59689 .04138 .60266 .04955 .61399 .04539 .60825 .03695 Metetra
.663 .733 .902 r
.60825 .03695 .61399 .04539 .62537 .04118 .61965 .03249 Metetra
.662 .726 .897 r
.61965 .03249 .62537 .04118 .63679 .03675 .6311 .02802 Metetra
.661 .726 .897 r
.6311 .02802 .63679 .03675 .64826 .03231 .6426 .02356 Metetra
.645 .719 .902 r
.6426 .02356 .64826 .03231 .65978 .02808 .65416 .01954 Metetra
.646 .727 .908 r
.65416 .01954 .65978 .02808 .67135 .02382 .66577 .01548 Metetra
.663 .741 .908 r
.66577 .01548 .67135 .02382 .68296 .01931 .67742 .01094 Metetra
.663 .741 .908 r
.67742 .01094 .68296 .01931 .69462 .01478 .68911 .00637 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.11345 .22526 m
.11813 .22986 L
s
[(-0.2)] .1041 .21606 1 .98388 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.59438 .03695 m
.59817 .0423 L
s
[(0.2)] .58679 .02624 .70809 1 Mshowa
.125 Mabswid
.16898 .20352 m
.17173 .20634 L
s
.22573 .1813 m
.22842 .18417 L
s
.28374 .15858 m
.28638 .16151 L
s
.40374 .1116 m
.40624 .11463 L
s
.46582 .08729 m
.46825 .09038 L
s
.52935 .06241 m
.5317 .06557 L
s
.05912 .24654 m
.06197 .24925 L
s
.66096 .01088 m
.66315 .01415 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00W`3oool2000000@0oooo00@0
00000?ooo`3oool0oooo1@00001b0?ooo`00WP3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000001T0oooo0P00001G0?ooo`00WP3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo01H0oooo1@00001G0?ooo`00WP3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo01<0oooo0P0000020?ooo`040000002Y_NP00000000005H0oooo002N0?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`<0000000@0oooo
00000000000000000P2Y_NP3000005D0oooo002N0?ooo`040000003oool0oooo000000L0oooo00D0
00000?ooo`3oool0oooo0000000?0?ooo`80000000@0oooo00000000000000000P2Y_NP00`000000
ZKgX0:Vmj003000005D0oooo002O0?ooo`8000002@3oool3000000d0oooo1P0000020:Fjj0030000
002Y_NP0ZKgX00@0000000<0ZKgX000000000000E03oool00;L0oooo1P0000020:FhiP030000002U
^^P0YK[X00<0000000<0ZKgX0000002Y_NP01@00001C0?ooo`00]@3oool500000080ZKWU00<00000
0:FhiP2U^>H00`000000102W^^L000000:Vmj02Y_NP300000080ZKoY0P00001C0?ooo`00/P3oool5
00000080ZKWU00<000000:Vii@2Y^ND00`000000102W^NH000000:Nji`2W^^L300000080ZKgX00<0
00000:Voj@2Y_nT00`00001B0?ooo`00[`3oool5000000030:VkiP000000ZKWU0080ZKWU0`000000
102Y^ND000000:NiiP2W^NH300000080ZK_W00<000000:Vmj02Y_NP00`000000102/`>T000000?oo
o`00001A0?ooo`00[@3oool4000000030:Vmj0000000ZK_V0080ZK_V00D000000:Vii@000000ZKWU
000000020:Vii@<0000000<0ZK[U0000002Y^nL00P2Y^nL500000080[<3Y0`00001A0?ooo`00Z`3o
ool2000000040?ooo`000000000000000080ZKgX00<000000:VkiP2Y^nH00P0000030:Vii@800000
00<0ZK_V0000002Y^^D00P2Y^^D01P000000ZK_W0000002[_>H000000:bni`@000000P2^_nL20000
0500oooo002X0?ooo`H000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Nji`000000ZKWU0:Vi
i@8000000`2Y^nH00`000000ZK[U0:Vji@0200000080ZkcV10000000102^_nL000000:joi`2^_nL2
000000h0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D00000<`3oool00:H0oooo0P000000
0`3oool00000000000020:Vmj0030000002Y_NP0ZKgX00<0000000@0YkcX0000002W^^L0Yk[W0`00
00020:Vmj0030000002Y^nH0ZK_V00<0000000T0Zk[U0000002[_>H000000:k1j0000000[[oW0000
002^_nL00`0000000`2^_nH000000000000<0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool00000<`3oool00:<0oooo1P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj000
0000YkcX0:Nlj0<000000P2U^>L00`000000ZKgX0:Vmj003000000040:Nji`000000Zk[U0:^ji@80
00000`2^`NP3000000040:joiP000000[[oV0:joiP<00000103oool500000080oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`0c0?ooo`00X03oool6000000040:Vmj0000000ZKgX
0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Bdi0030000002U^>L0YKSW00<0000000@0
YkcX0000002W^^L0Yk[W0`0000020:k3j@030000002^`NP0[/7X008000000P2^_nH300000080[/7X
00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0380
oooo002N0?ooo`D0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP000000080
00000P2X^ND00`000000Y;CT0:Bdi003000000040:VjiP000000YkcX0:Nlj0<000000P2U_N/00`00
0000[/?Y0:k3j@03000000040:c0j0000000[[oV00000080[/?Y00<000000:k1j02^`NP00P00000:
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`00V`3o
ool5000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgW
00<000000:Rii@2X^ND00`000000102X]^<000000:VjiP2Y^^H300000080YKcY00<000000:Fmj`2U
_N/00`000000102/`^X000000:c0j02/`>P2000000<0[/?Y0`0000000`2/`>T00000000000090?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`00V@3oool2
000000040?ooo`000000ZKgX00000080ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0
ZKgX0000002Y_NL0ZKgW0`000000102U]nH000000:Rfh`2X]^<300000080[KkW00<000000:Flj@2U
_>T00`000000102W_^X000000:c2jP2/`^X4000000060:Znj0000000[/?Y0000002/`^X000000P2/
`>T2000000X0oooo0P0000090?ooo`<00000=03oool009H0oooo0`0000000`3oool0000000000003
0:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000<0
YK_Y0000002U]nH00P2U]nH200000080[KkV00<000000:fni`2]_^L00`000000102W_>T000000:Nn
jP2W_^X300000080ZK[V0P0000000`2Z_^P00000000000020:c2jP<0000000<0Z[kX000000000000
B`3oool009@0oooo0P0000001P3oool00000000000000000ZKgX00000080ZKgX0P0000030:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002U^nT0000000@000000`2]_^H30000
00040:foi`000000YkcY0:Nlj@<000000P2Y^^H00`000000ZK[V0:VjiP03000000060:foi`000000
[<;Z0000002Z_^P000000P2Z_^P3000004X0oooo002A0?ooo`H000000P2Y_NP00`000000ZKgX0000
000200000080ZKgX00D000000:Vmj0000000ZKgX000000020:Vmj0<000000P2Y_NP00`000000ZKgX
0:Vmj002000000030:2ci@000000X[OW0080X[OW00D000000:fniP000000[[oV000000020:foi`<0
00000P2Y^^D00`000000ZK[V0:VjiP03000000040:fki0000000[KoW0:foi`8000000`2Z_^P20000
0080ZKgX00<000000?ooo`3oool0B03oool008l0oooo1@0000020:Vmj0030000002Y_NP0ZKgX0080
00000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX00<0
000000D0YkOT0000002P/nD0X;?U000000020::gi`8000000P2^_nH300000080[K_T00<000000:Vj
i@2Y^^D00`000000102Y^ND000000:fki02]^n@3000000040;;4j0000000Z[kX0:Znj08000000`2Y
_NP2000004T0oooo002<0?ooo`D000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000
ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000030:Vmj0<0000000<0ZKWU0000002W]n@0
0P2W]n@00`000000X;?U00000002000000060:Fhi`000000[[oV0000002]^n@000000`2]^n@30000
00040:Vii@000000ZKWU0:Vii@D000000P2ba>P300000080ZKgX00@000000:Vmj0000000ZKgX0P00
00180?ooo`00R@3oool500000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y
_NP300000080ZKgX00<000000:Vmj00000000P0000020:Vmj0050000002Y_NP000000:Vji@000000
0`2Y^ND00`000000YkOT00000002000000040:Bdi0000000YKSW0:Fhi`8000000`2]^n@01@000000
[K_T0000002]^n@000000080ZKWU0`0000000`2Z`NX000000;;7jP0400000080[l?Y00<000000:Vm
j02Y_NP00P0000030:Vmj0030000003oool0oooo04H0oooo001W0?ooo`8000007P3oool500000004
0:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP0
ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZK[U00<000000:Vii@0000000P000002
0:Jfi0030000002T]>@00000008000000P2Y^nH00`000000[K_T0:fki002000000<0[K_T0P000000
102Y_NP000000:[1jP2Z`NX300000080[lO/00<000000:o3j@2_`nT00`000000102Y_NP000000:Vm
j02Y_NP3000004L0oooo001V0?ooo`040000003oool0oooo000001X0oooo1@000000102Y_NP00000
0:Vmj02Y_NP300000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX00<0
000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y^^D000000:Vji@2Y^^D300000080YkSU00<00000
0:Jfi02V]^@00P0000020:Vli`030000002Y^nH0ZK_V00<0000000@0[K_T0000002]^n@0[K_T0P00
00020:Vmj0<000000P2^`nX00`000000[lO/0:o7k003000000040:Znj0000000ZKgX0:Vmj0<00000
00@0ZKgX0000003oool00000AP3oool006H0oooo00@000000?ooo`3oool00000603oool400000080
ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000
ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZK_V0000002Y^^D0ZK[U0`000002
0:Vii@030000002W^>D0YkSU00<0000000@0YKSV0000002Y_>L0ZKcW0`000000102X^nL000000:fk
i02]^n@3000000040:g0i`000000ZKgX00000080[KoW00<000000:k3jP2^`nX00`000000102Z_nT0
00000:Znj02Z_^P3000000040:Vmj0000000ZKgX0:Vmj0<00000AP3oool006H0oooo00@000000?oo
o`3oool000005@3oool400000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0
ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX
00<000000:VkiP0000000P0000020:Vii@030000002Y^ND0ZKWU00<0000000@0YKGT0000002U^>H0
YKSV0`000000102W_>P000000:Rki`2X^nL300000080[/;X00@000000:g0i`00000000000`2]_nL5
00000080Z[oY0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX0P0000150?ooo`00IP3oool0
10000000oooo0?ooo`00000C0?ooo`80000000<0oooo0000000000000`2Y_NP3000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP000000080
00000P2Y_NP00`000000ZKgX0:Vmj00200000080Yk[W00<000000:Vii@2Y^ND00`000000102X]n@0
00000:Fei02U]N@3000000040:RjiP000000YkcX0:Nlj0<000000P2V_n/00`000000[/;X0:k2j002
00000080[<3X00H000000:foi`000000//CW0000002a`nL4000000040:Vmj0000000ZKgX0:Vmj0<0
00000P2Y_NP00`000000ZKgX0:Vmj003000004@0oooo001V0?ooo`040000003oool0oooo00000100
oooo1P0000020:Vmj0050000002Y_NP000000:Vmj00000000P2Y_NP300000080ZKgX00<000000:Vm
j00000000P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj0030000
00040:Nlj0000000Yk[W0:Nji`<0000000@0ZKWU0000002X]n@0Z;OT0`0000020:Rfh`030000002X
^^H00000008000000P2U_n`00`000000Y[o[0:Joj`03000000040:c2jP000000[<3X0:c0j0800000
0P2ba>L3000000040;32i`000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00300000003
0:Vmj0000000000004@0oooo001W0?ooo`8000003`3oool2000000060?ooo`00000000000000002Y
_NP000000P2Y_NP2000000<0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`00
0000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002W_>P0YkcX0`00
0000102V^>H000000:Vii@2Y^ND300000080YkKT00<000000:Rfh`2X]^<00P0000020:c2j@030000
002U_n`0YKo/00<0000000@0Y/3/0000002/`^X0[<;Z0`000000102[_^P000000000000000020;74
j0030000002``^L00000008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX
0:Vmj0<00000@`3oool007D0oooo1P000000102Y_NP000000:Vmj02Y_NP300000080ZKgX00D00000
0:Vmj0000000ZKgX000000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP00000
0:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2U^>L00`000000Y[SV000000020000
0080YkSU00<000000:Nfi02W]^@00`000000102^`^P000000:c2j@2/`^T3000000040:Fok@000000
Y/3/0:K0k0<0000000@0ZK_V0000002[_^P000000P2]_nL00`000000/LCX0;74j00200000080[[oW
00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000oooo0000
0480oooo001b0?ooo`H000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj02Y
_NP00P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3
00000080ZKgX00<000000:Vmj00000000P0000020:Rki`030000002U^>L0YKSW008000000P2U^>H0
0`000000YkSU0:Nhi@03000000040:NmjP000000[/;X0:k2j0<0000000@0[L?Z0000002U_nd0YKo]
0`000000102U^NL000000:VkiP2Y^nH2000000<0[KoW0`000000102^`>L000000:joi`2^_nL30000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000120?ooo`00L03oool2
000000030?ooo`00000000000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0
ZKgX00<0000000@0ZKgX0000002Y_NP000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<0
00000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NL00`000000Z;_W0:Rk
i`03000000040:BhiP000000YKSV0:FhiP<0000000@0YK_Y0000002W_NX0YkgZ0`000000102^`nT0
00000:g3jP2]`nX300000080YKWW00<000000:Fii`0000000P0000020:fki0050000002]_nL00000
0;72iP0000000P2^`>L3000000040:joi`000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX
0`000000102Y_NP000000?ooo`0000110?ooo`00K@3oool6000000040:Vmj0000000ZKgX0:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP2000000<0ZKgX0P000002
0:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000
ZKgW0:Vmi`<0000000@0Y[[W0000002T^>H0Y;SV0`000000102U]nH000000:Fkj@2U^nT300000080
Z;oZ00<000000:k3j@0000000P0000020:bli@030000002U^NL0YKWW008000000P2V^>H00`000000
[K_T0:fki00200000080/L;V1@0000020:joi`<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vm
j0030000002Y_NP0000000800000@@3oool006/0oooo1@000000102Y_NP000000:Vmj02Y_NP30000
0080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP01@00
0000ZKgX0000002Y_NP000000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0YkcX0000002V^^L0Y[[W0`0000020:BbhP030000002U]nH000000080
00000P2W_NT00`000000Z;oZ0:RojP0200000080[KcT00<000000:bli@2/_>D00`000000102U^>H0
00000:JhiP2V^>H3000000070;73i`000000/L;V0000002``^L000000:joiP0400000080[/7X00<0
00000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP200000400oooo001X
0?ooo`D0000000@0ZKgX000000000000ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y
_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000YkcX
0000000200000080Y;7R00<000000:BbhP2T/^800P0000020:Vii0030000002W_NT0YkgY00<00000
00@0Z[_V0000002]_>@0[KcT0`000000102/^^@000000:FhiP2U^>H3000000040:JmjP000000/L?W
0;73i`<0000000@0/<;W00000000000000000P2^`^T00`000000[/7X0:k1j00200000080ZKgX00<0
00000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000003l0oooo001V0?ooo`@000000P2Y
_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vm
j02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX00000000000000000P2Y_NP00`00
0000ZKgX0000000200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX
008000000P2T/^800`000000Y;7R0:BahP03000000040:Vdh0000000ZKWT0:Vii0<0000000@0ZK[V
0000002Z^nH0Z[_V0`000000102]^n@000000:bji02/^^@3000000040:Fkj@000000Y[gZ0:JmjP<0
00000P2aa>P200000080[l?Y00<000000:k2j@2^`^T00`000000102/`>P000000:Vmj02Y_NP30000
00040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX000000000000?`3oool006<0oooo1@000000102Y
_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0000
000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj08000000P2Y_NP00`000000ZKgX0:Vm
j00200000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Ne
h`000000Y;;R0:BbhP<0000000@0YK7P0000002Y]>00ZKCP0`000000102__^D000000:VjiP2Y^^H3
000000040:Zji@000000[K_T0:fki0<000000P2/_^H00`000000YK_Y0000000200000080Z;oZ00D0
00000;74j0000000[l?Y000000020:o3j@<0000000@0[<;Z0000002/`>P0[<3X0`000000102Y_NP0
00000:Vmj02Y_NP3000000050:Vmj000000000000000002Y_NP00P00000n0?ooo`00H@3oool40000
0080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`00
0000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0050000002Y_NP00000
0:Vmj00000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX
0`000000102Y^ND000000:Neh`2W]N<3000000030:B`h@000000YK7P0080YK7P0P0000020;71iP03
0000002__^D00000008000000P2Y^ND00`000000Z[[U0000000200000080[[kV00<000000:bniP2/
_^H00P0000020:Nlj@030000002X_nX0Z;oZ008000000P2_`nT500000080[<;Z0`000000102Z_^P0
00000:Vmj02Y_NP3000000060:Vmj0000000ZKgX0000002Y_NP000000P2Y_NP3000003d0oooo001M
0?ooo`D000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P000002
0:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vm
j02Y_NP200000080ZKgX0`0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX
0000000200000080ZK_V00<000000:Vii@0000000P0000000`2U/n<000000:B`h@020:B`h@040000
002U/N000000000000<0/L7V0P0000020:fniP030000002Y^ND0ZKWU008000000P2Z_NL00`000000
[[kV0:jniP03000000040:fni`000000YkcY0:Nlj@<0000000L0ZKgX00000000000000000:k3j@00
0000[/?Y00@0000000@0Z[kX0000002Z_^P0Z[kX0`000000102Y_NP000000:Vmj02Y_NP300000004
0:Vmj0000000000000000080ZKgX00<000000?ooo`3oool0>`3oool005`0oooo10000000102Y_NP0
00000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`00
0000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX00000000
000000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vm
i`030000002Y^nH0ZK_V008000000P2U]nD01@000000YK?S0:Fch`000000Y;3Q00<000000P2X_NT0
1@000000/L7V0000002_`^P000000080[KkV0`000000102Y_>L000000:Zmi`2Z_NL3000000040:jo
iP000000[KkW0:fni`<0000000H0Z;ST0000002Y_NP000000:jni@0000020:k3j@<0000000@0[/7X
0000002Z_^P0Z[kX0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX0P0000020:Vmj0030000
002Y_NP0ZKgX00800000?03oool005T0oooo100000020:Vmj0030000002Y_NP00000008000000P2Y
_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y
_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX0P0000020:Vmj0030000002Y
_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmi`2Y_NL300000004
0:Nji`000000YKOU0:Fgi@D000000P2U^^P00`000000Z;gY0:Rmj@0200000080[l;X0`000000102Z
_NP000000:Vli`2Y_>L3000000040:Znj0000000[[oV0:joiP<0000000@0[K_T0000002X^>@0Z;ST
0P0000030:jni@8000000P2^`nT00`000000[/7X0000000200000080ZKgX00<000000:Vmj0000000
0P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000000000k0?ooo`00
EP3oool400000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX00800000
0P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000
002Y_NP0ZKgX008000000P2Y_NP01@000000ZKgX0000002Y_NP000000080ZKgX0`000000102Y_NP0
00000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0YkcX0000002W^^L0Yk[W0`00
00001@2P/nH000000::gi`2R]nL000000080YK[X0`0000001P2Y`>X00000000000000000Z[kX0000
0080Z[gX0`000000102Y_NP000000:Znj02Z_^P300000080[[kV00<000000:fki00000000P000002
0:fhh@050000002^_^D000000;C4iP0000000P2^`nT200000080[<3X00<000000:Vmj02Y_NP00P00
00020:Vmj0050000002Y_NP000000:Vmj00000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj080
0000>`3oool005@0oooo10000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vm
j0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000000000000020:Vm
j0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Nl
j00000000P0000020:>ci0030000002P/nH0000000D0000000@0YkgY00000000000000000P2Y_NL0
0`000000Z[kX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Znj0030000002^_^H0
[[kV008000000P2[^N@00`000000[KSQ0:fhh@0200000080]<CV1@0000020:c0j0<0000000@0ZKgX
0000002Y_NP0ZKgX0P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP00000
0000000j0?ooo`00D@3oool400000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y
_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P00
00020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX0P00
00020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<0
00000:Vmj02Y_NP00P0000020:BbhP030000002S/n@0Xk?T008000000P2T]ND00`000000Y;WW0:Bi
i`0200000080ZK[V00<000000:Vmi`2Y_NL00P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y
_NP00`000000Z[kX0:Znj003000000040:Zmi`000000ZkWT0:^ii0<0000000L0]<?U000000000000
00000;G6i`000000[L;Z00@0000000@0Z[kX0000002Y_NP0ZKgX0`0000001P2Y_NP0000000000000
0000ZKgX00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000003T0oooo001>0?ooo`<00000
00@0oooo0000002Y_NP000000P2Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj003
0000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y
_NP00P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vm
j0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Neh`00
0000Y;;R0:BbhP<0000000@0YK?R0000002T]ND0Y;GU0`000000102X^ND000000:VjiP2Y^^H30000
00040:^liP000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Zm
i`2Z_NL3000000060:Rmj@000000]<?U0000002ga^H000000P2ea^L3000000040:Zoj0000000Z[kX
0:Znj0<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX0000002Y_NP0
ZKgX0`0000000`2Y_NP000000000000i0?ooo`00C03oool7000000040:Vmj0000000000000000080
ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX
0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vm
j0000000000000000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP30000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKWU0000002W]N<0YkGS0`000000102V/N4000000:Fc
hP2U/n83000000040:Rii@000000Z;WU0:Rii@<0000000@0Zk_U0000002[_>H0ZkcV0`000000102Y
_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0Y[cY0000002X_NT0Z;gY
0P0000020;O6iP<0000000@0]LGV000000000000Z[oX0`0000001P2Y_NP00000000000000000ZKgX
00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000
>03oool001h0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000007@3oool2000000040?oo
o`000000000000000080ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000
ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP000000080
00000P2Y_NP00`000000ZKgX0000000200000080ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX0080
00000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:VkiP03
0000002Y^ND00000008000000P2U/n800`000000Y[7Q0000000200000080Z;ST00<000000:Rii@00
00000P0000020:Vji@030000002[^nD00000008000000P2/_^L00`000000ZKgX0000000200000004
0:Vmj0000000ZKgX0:Vmj0<0000000@0ZKcW0000002V_>T0Y[cY0`0000020:W0jP8000000P2gbNP0
0`000000]LGV0000000200000080ZKgX0P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP0
0`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0800000=`3oool0
01d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000J0?ooo`<0000000<0
oooo0000000000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0
ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj00200000080
ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y
_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmi`030000002Y^nH0
ZK_V008000000P2U]nD00`000000YK?R0:FchP0200000080Z;ST00<000000:Rhi02X^>@00P000002
0:Vii@030000002Y^^D0ZK[U008000000P2]_^H00`000000[;kW0:bni`0200000080ZKgX00<00000
0:Vmj00000000P0000020:VkiP030000002Y_>L00000008000000P2V_NT01@000000ZL3Z0000002[
`^/000000080]lWX0P0000000`2ba>L0000000000002000000040:Vmj0000000ZKgX0:Vmj0800000
0P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000
002Y_NP0ZKgX00800000=`3oool001H0oooo1@0000020?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool0603oool2000000050?ooo`00000000000000002Y_NP00`0000020:Vmj003
0000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj000
00000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX
00000000000000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<00000
00@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmi`2Y_NL3000000040:Jji`000000YKOU
0:Fgi@<0000000@0XkCT0000002X^>@0Z;ST0`000000102Y^ND000000:Vii@2Y^ND3000000040:^m
i`000000[KkV0:fniP<0000000@0[KkW0000002Y_NP0ZKgX0P0000020:VjiP030000002Y^nH0ZK_V
008000000P2Z_>H00`000000Y[gY0:Jmj@0200000080Zl;[0`0000001P2dbNX000000;;4i`000000
[l;X00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000000000f0?ooo`007@3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo01@0oooo0`0000000`3oool00000000000020:Vm
j08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vm
j0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vm
j00000000P0000020:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vm
j00000000P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX000000020000
00040:Nlj0000000Y[[W0:Jji`<0000000@0XK7T0000002S]>@0XkCT0`000000102Y^ND000000:Vi
i@2Y^ND3000000040:Vli`000000ZkgW0:^mi`<0000000@0[[oV0000002]_^L0[KkW0`000000102Y
^^H000000:VjiP2Y^^H3000000040:^ji@000000Z[cV0:ZliP<0000000H0ZKkY0000000000000000
0:k4jP0000020;C9jP<0000000H0[l;X00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX
0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0
0000=@3oool001d0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool00000
0180oooo0`0000001@3oool00000000000000000ZKgX00<000000P2Y_NP00`000000ZKgX00000002
000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP00000
0:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0<0000000@0ZKgX0000002Y
_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P000002
0:Vmj0030000002Y_NP0ZKgX008000000P2X_NP00`000000YkcX0000000200000080Xk7R00<00000
0:6ai00000000P0000020:Ffi0030000002Y^ND000000080000000@0ZK_W0000002Y_>L0ZKcW0`00
0000102[_^L000000:joiP2^_nH3000000040:bli@000000ZK[V0:VjiP<0000000@0ZKWU0000002[
^^D0Zk[U0`0000001P2/_^L00000000000000000[KoW00000080[/CZ0`0000001P2`aNX000000000
00000000[<3X00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX
0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000000000e0?ooo`007@3oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000403oool2000000040?oo
o`000000000000000080ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000
ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP000000080
00000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000000000000080ZKgX00<000000:Vm
j00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Rmj02X_NP200000080YK;R00<000000:>ahP2S
/N800P0000020:>ahP030000002U]^@0YKKT008000000P2Y^^D00`000000ZK_W0000000200000080
ZKgX00<000000:^ni`0000000P0000020:fli0030000002/_>D000000080000000@0ZKWU0000002Y
^ND0ZKWU0`0000020:fniP8000000P2^_nL00`000000[KoW0000000200000080/L?X0P000000102]
`^X000000000002/`>P3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX
0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000=03oool001h0
oooo0P0000090?ooo`<000003P3oool3000000050?ooo`00000000000000002Y_NP00`0000020:Vm
j0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP0
ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P000002
0:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj00000000P000002
0:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000
ZKgX0:Vmj0<0000000@0YkCR0000002U/^80YK;R0`000000102T/>4000000:>ahP2S/N8300000004
0:Rii@000000ZK[U0:Vji@8000000P2[_>L00`000000ZKgX0:Vmj00200000080Zk_U00<000000:fl
i02]_>@00P0000020:bki0030000002Y^ND00000008000000P2Z_>L01@000000[KkV0000002^_nH0
00000080[[oW0P0000020;71iP060000002a`nP000000;;3iP000000[L;Z0`0000020:Znj0030000
002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP30000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000000000000000<`3oool003P0oooo1P000002
0:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj00000000P000002
0:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vm
j02Y_NP3000000060:Vmj000000000000000002Y_NP000000P2Y_NP3000000040:Vmj0000000ZKgX
0:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P000002
0:Vmj0030000002Y_NP00000008000000P2Y]^<00`000000YkCR00000002000000040:B`h@000000
Y;3Q0:B`h@<0000000@0Z;ST0000002X^ND0Z;WU0`000000102[^nD000000:^li`2[_>L300000004
0:VjiP000000Zk_U0:^ki@<0000000@0[K_S0000002/^n@0[;_T0P0000020:Vli`030000002Z_>L0
Z[cW008000000P2^_nH3000000040:joiP000000/L7V0;71iP8000000P2b`nH2000000030:Zoj@00
000000000080Z[kX0P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000
0002000000030:Vmj0000000000000@0000000D0ZKgX00000000000000000:Vmj002000003<0oooo
000e0?ooo`@000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<00000
00@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000
ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj08000000P2Y_NP00`000000
ZKgX0000000200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP30000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vii0030000002Y
]^<0ZKKS008000000P2V/^400`000000Y;3Q0000000200000080Y[KT00<000000:Rhi00000000P00
00020:Zji@030000002[^nD000000080000000@0[;cU0000002Y^^H0ZK[V0`000000102Z^^D00000
0:fkh`2]^n<3000000040:fmiP000000ZKcW0:Vli`<0000000H0Z[kX00000000000000000:joiP00
00020:joiP<0000000L0/l7U00000000000000000;C4iP000000Z[oY00@0000000@0ZKgX0000002Y
_NP0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP200000080ZKgX00<000000:Vm
j00000000P000000102Y_NP000000:Vmj02Y_NP3000000P0oooo0P00000X0?ooo`00<`3oool30000
0080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`00
0000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP2
00000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P00
00020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<0
00000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vli`000000ZKWT0:Vii0<0
000000@0YkCR0000002V/^40Y[;Q0P0000020:Bch`030000002V]^@0Y[KT008000000P2Y^ND00`00
0000Z[[U0:Zji@0200000080[KgV00<000000:bli@0000000P0000020:Vii@030000002Z^^D00000
0080000000@0[[kV0000002]_NH0[KgV0`0000001P2Y_NP00000000000000000Z[gW00000080[[oV
0`0000001P2__nH000000;?1i@000000]/OW00000080]<CV0`000000102Y_NP000000:Vmj02Y_NP3
000000040:Vmj0000000ZKgX0:Vmj0<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj080
00000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`00000W0?ooo`00<03oool400000080ZKgX00<000000:Vmj00000000P000000102Y_NP0
00000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX
008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P000000102Y
_NP000000000000000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`00
0000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000
002Y_NP00000008000000P2Y_NP5000000040:Jgi@000000YkCR0:NdhP<0000000@0Y;;R0000002T
/n<0Y;?S0`000000102W^>D000000:Vii@2Y^ND3000000040:^liP000000[KgV0:fmiP8000000P2[
^nD00`000000ZKWU0:Vii@0200000080ZkgW00<000000:jniP0000000P000000102]_^L000000000
000000020:VkiP030000002Z_NL000000080000000@0[[oV0000002__nH0[koV0`0000001@2fanL0
0000000000000000//CW0080000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<0000000H0
ZKgX00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vm
j0030000002Y_NP0ZKgX008000001P3oool010000000oooo0?ooo`00000W0?ooo`00;P3oool30000
00030:Vmj000000000000080ZKgX0P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`00
0000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`00
00000`2Y_NP000000000000300000080ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y
_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vm
j02Y_NP3000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP3000000060:Nmj@000000YK[X0:Fj
j0000000Y[OU0`0000020:B_h0030000002T/^8000000080000000@0Y[GT0000002W^>D0YkSU0`00
0000102Y^^D000000:^liP2[_>H3000000040:bniP000000Zk_U0:^ki@<0000000@0ZKcW0000002[
_NL0ZkgW0P0000020:joiP8000000P2]_NH00`000000ZK_V0:VkiP0200000080ZkgV00<000000:jo
iP0000000P0000020;33j08000000P2dbNT00`000000//CW00000002000000040:Vmj0000000ZKgX
0:Vmj0<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX0000002Y_NP0
ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000000000D0oooo00@000000?oo
o`3oool000009`3oool002/0oooo100000020:VkiP030000002Y_NP000000080000000@0ZKgX0000
002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX00000002
00000080ZK_V00<000000:Vmj00000000P0000020:Vmj08000000P2Y_NL00`000000ZKgX00000002
00000080ZKgX00<000000:Vmj00000000P000000102Y_NL000000:Vmj02Y_NP200000080ZKgX00<0
00000:Vmj02Y_NP00P0000020:Vmi`030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000
0002000000040:Vli`000000000000000080ZKgX00<000000:Nmj@000000100000020::/gP030000
002T[n00Y:oP008000000P2W/n400`000000Y[GT0000000200000080Z;ST00<000000:Vji@000000
0P000000102[_NH000000:bniP2/_^H3000000040:VkiP000000ZKcW0:Vli`<0000000H0ZkkX0000
002^_nH000000:jniP0000020:fmiP<0000000@0Zk[U0000002[_NH0ZkgV0P0000020:k0i`050000
002``nP000000;;5j@0000000P2dbNT2000000040:o2j000000000000:Vmj0<0000000H0ZKgX0000
0000000000000:Vmj00000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP00000
0:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj08000001@3oool010000000oooo0?ooo`00000W
0?ooo`00:03oool400000080ZKWU00<000000:VkiP2Y^nH00P0000020:Zmj0030000002Y_NP00000
008000000P2Y_NL00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj08000000P2Y^^D0
0`000000ZK_V0:VkiP0200000080Z[gW0`000000102Y^nH000000:Vmi`2Y_NL200000080ZKgX00<0
00000:Vmj02Y_NP00P0000020:VkiP030000002Y_NL000000080000000@0ZKgX0000002Y_NP0ZKgX
0`000000102Y^nH000000:Vmi`2Y_NL200000080ZKgX1@0000020:Vii08000000P2[_>H00`000000
ZKgX0:Vmj002000000050:BXfP000000X:SL0:2Xg00000000P2R[=h3000000040:N_gP000000Yk?Q
0:Nch@8000000P2X]^<00`000000Z;ST0:Rhi00200000080Zk_U00<000000:^miP0000000P000002
0:Vii0030000002Y^nH000000080000000@0ZKgX0000002[_^P0ZkkX0P0000020:jniP<0000000@0
[;cU0000002[^^D0Zk[U0`000000102]_^H000000:k0i`2^`>L200000080//GY0`0000000`2`aNX0
00000:o2j00300000080ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y
_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000<0
ZKgX000000000000103oool010000000oooo0?ooo`00000W0?ooo`009P3oool400000080ZKWU00<0
00000:Vii@0000000P000000102/_>D000000:Zmj02Z_NP200000080ZKWU00<000000:Vmi`2Y_NL0
0P0000020:Vmj0030000002Y_NP00000008000000P2Y^^D00`000000ZK[U00000002000000040:^k
i@000000000000000080Z[[U00<000000:VkiP0000000P000000102Z_NL000000:Vmj02Y_NP30000
00040:Vii@000000ZK_V0:VkiP8000000P2Z_NL00`000000ZKgX0000000200000080ZKWU00<00000
0:VkiP0000000P000000102Z_NL000000000000000020:RehP030000002Y]^<000000080000000@0
[;WR0000002[_>H0ZkcV0`0000001P2WZ]T000000:BXfP2TZ=X000000:2Xg0<0000000@0YJ_K0000
002W[mh0YjoN0`000000102Z]n8000000:Rfh`2X]^<3000000040:^ii0000000Zk_U0:^ki@800000
0P2/^N<00`000000ZKWT0:Vii00200000080Zk_U00<000000:Vmj00000000P000000102[_>H00000
0000000000020:bni`030000002/_>D000000080000000@0[KgV0000002]_^H0[KkV0`0000001P2a
`NH00000000000000000]<KW00000080/<GZ0`0000001P2/`>P00000000000000000ZKgX00000080
ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y
_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000103oool2000002P0oooo000R
0?ooo`D000000P2Y^^D00`000000ZKWU0:Vii@0200000080Zk[T00<000000:bli@0000000P000002
0:Vgh`030000002Y^ND000000080000000@0Z[gW0000002Y_NP0ZKgX0P0000020:Vii@030000002Y
^^D0ZK[U008000000P2[^^@200000080[K_S00<000000:Zji@2Z^^D00P0000020:^ki@030000002Z
_NL00000008000000P2Y]^800`000000ZKWU00000002000000040:^ki@000000Z[gW0:Zmi`800000
0P2Y]^800`000000ZKWU0:Vii@0200000080Zk_U0P0000020:Zdh0030000002X]N80Z;GR00800000
0P2[]^400`000000[;WR00000002000000030:Z/f@000000Yj[I0080Yj[I00@000000:BXfP000000
00000P2SY]L00`000000YJ_K0000000200000080[;[S00<000000:ZghP0000000P000000102Z]n80
00000:^ii02[^N@3000000040:fjh`000000[;WS0:bih`<0000000@0[;SR0000002[^nD0Zk_U0P00
00020:Vii@8000000P2/_>D00`000000[;kW0:bni`0200000080ZkcV00<000000:fmiP0000000P00
00001P2^_nH000000;71iP000000]LCV00000080]<KW0`0000001P2]`^X00000000000000000Z[kX
00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P00
0000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000000000@0000000<0ZKgX000000000000
;P3oool00240oooo100000020:jmi0030000002Y^^D00000008000000P2Y^ND010000000Zk[T0000
000000020:jkh`030000002Y]n<0ZKOS008000000P2]^^<00`000000Z[gW0000000200000080ZKST
00<000000:Vii@0000000P000000102Y^ND000000:^ji00000020:bjh`030000002]^n<000000080
000000@0[;[T0000002[^nD0Zk_U0P0000020:Vdh0030000002Y]^80ZKKR008000000P2/^N<00`00
0000Zk_U0000000200000080Z[CQ00<000000:VfhP0000000P0000020:bih`80000000@0[;GO0000
002Z]>00Z[CP0`000000102Z/ml000000:^fh@2[]^42000000030:jafP000000ZZcI0080ZZcI00<0
00000:NZf@0000000P000000102TY=D000000:>Ve`2SY]L200000080[;[T00<000000:bjh`2/^^<0
0P0000020:Zhh`030000002Z]n8000000080000000@0[K_T0000002]^^<0[K[S0`000000102/^>80
00000:bhhP2/^>83000000060:jjhP00000000000000002/^>8000000P2/_>D3000000040:ZkiP00
0000ZkcV0:^liP8000000P2^_nH00`000000[[oV00000002000000050;G4iP00000000000000002e
a^L00`000000102Z_nT000000:Znj02Z_^P3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX
0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000H0ZKgX0000000000000000
0:Vmj00000020:Vmj0<0000000<0ZKgX000000000000;@3oool001h0oooo1@000000102^_^H00000
0:jmi02^_N@200000080ZK[U00<000000:Vii@2Y^ND00P0000020:jniP030000002^^n<000000080
000000@0[;OQ0000002]^^<0[K[S0P0000020:ZghP030000002Y^>@0ZKST008000000P2Y^ND50000
0080[;[S0P0000020:fkh`030000002/^^@00000008000000P2/]=h00`000000ZKCP000000020000
00040:bfh0000000[;WS0:bih`8000000P2]]n000`000000Z[CQ0:Zdh@0200000080[;GP00@00000
0:bih`00000000000`2/]Ml2000000030:^cgP000000Z[?O0080Z[?O0P0000001P2]/m`000000:ja
fP2^/MX000000:Z/f@<000000P2VYMD00`000000Y:CE00000002000000040:bji0000000[;[T0:bj
i0<0000000@0ZkcV0000002Z^><0Z[SS0P0000020:fli@030000002]^n@00000008000000P2/^^<0
0`000000[;SR00000002000000060;2kh@000000[[[R0000002^^N4000000P2/^>83000000040:jm
i0000000Z[_V0:ZkiP<0000000@0[;gV0000002^_nH0[[oV0P0000020:o1i`80000000@0]lKV0000
0000000000000P2da>H00`000000Z[oY00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX0P0000020:Vmj003
0000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`00000/0?ooo`007@3oool300000080
ZKgX00<000000:jniP0000000P0000020:bli@030000002Y^^D000000080000000@0ZK_V0000002^
_^H0[[kV0P0000020:Vji@030000002/]n400000008000000P2a_>800`000000Z[OR000000020000
00040:^hh`000000000000000080ZKOS00<000000:Vgi00000000P000000102]^^<000000:fkh`2]
^n<200000080[;GO00<000000:bdgP2/]=h00P0000020:bcgP030000002/]^0000000080000000@0
[[WQ0000002]]n00[KOP0`000000102[/mh000000:beh02/]N0200000080[[KO00@000000:beg`00
000000000`2[/mh010000000Z[?O0000000000030:fcg0040000002^/MX0000000000080Z:SF00<0
00000:JUe@2VYMD00P0000020:Zji0030000002/^^@000000080000000@0[;oX0000002[_>H0ZkcV
0`000000102Y^ND000000:fli@2]_>D200000080[;cU00<000000:bjh`2/^^<00P0000020:bih`03
0000002`^n4000000080000000H0[[WQ00000000000000000;2mh`0000020:jmi0<0000000@0Zk[U
0000002/_NH0[;gV0`0000000`2^_nL0000000000005000000040;O6iP000000]<CV0;C4iP800000
0P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX00000000
0000100000001P2Y_NP00000000000000000ZKgX00000080ZKgX0P0000020:Vmj0030000002Y_NP0
00000080000000<0ZKgX000000000000;03oool001`0oooo0P0000020:Vmj0040000002Y_NP00000
00000080[;kW00<000000:bli@2/_>D00P0000020:Vji@030000002Y^nH00000008000000P2Z_NP0
10000000ZK[U0000000000020;2ni0030000002a_>80/KcR008000000P2[]n8200000080[K_T00<0
00000:Vgh`2Y]n<00P0000020:^hh`030000002]^^<000000080000000@0[K[S0000002/]Ml0[;GO
0`000000102//mh000000:bcgP2//mh200000080/KcR00<000000:jih@0000000P0000020:^eh003
0000002[/mh000000080000000@0/;WO0000002^]]l0[[KO0P0000020:bcgP030000002[/mh0Zk?N
008000000P2/]=l00`000000[K?L00000002000000040:^]f@000000Z:SF0:RXeP<0000000@0ZKWU
0000002Z^^@0Z[[T0P0000020:c2j@030000002/_nP00000008000000P2V]N@00`000000ZKWU0000
0002000000040:bniP000000[;cU0:bli@<0000000@0ZKOS0000002/^N<0[;WS0P0000020;2khP80
00000P2__>@00`000000/;gS0000000200000080[kgT00<000000:^ji@0000000P0000020:fmiPD0
000000<0/L?W0000000000000P2ga^H3000000040;?3iP000000ZKgX0:Vmj08000000P2Y_NP00`00
0000ZKgX00000002000000060:Vmj000000000000000002Y_NP000000P2Y_NP3000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP30000
02/0oooo000E0?ooo`8000001P3oool00`000000ZKgX0:Vmj00200000080ZKgX00<000000:bni`00
00000P000000102Y^nL000000:Vji@2Y^^D200000080ZkcU00<000000:Zmj02Z_NP00P0000020:Fl
jP030000002`_^@000000080000000@0[[_S0000002[]n8000000P2]_NH00`000000[K_T00000002
000000040:ZghP000000ZkSS0:^hh`8000000P2^_^H00`000000[K[S0000000200000080ZkCO00<0
00000:bcgP0000000P000000102`_^@000000;6lhP2a_>8200000080[;SR00<000000:^eh02[]N00
0P0000020:jjhP030000002`^Ml000000080000000@0[KGN0000002//mh0[;?N0`000000102]]n00
00000:bdg`2/]=l200000080Z[7M00<000000:^]f@0000000P000000102X^ND000000:Vii@2Y^ND3
000000040:_2j`000000[<;Y0:c2j@8000000P2W]>800`000000Y[GT0:Jei00200000080Zk[U00<0
00000:bniP0000000P000000102Y]n<000000:Vgh`2Y]n<3000000060:bih`000000/;_R0000002^
^n<000000P2__>@200000080/KoU00<000000:nmi02__N@00P0000020:fki0030000002]_NH00000
0080000000@0[l3V00000000000000000P2b`^H2000000040;G5iP000000/l?V0;?3iP<0000000<0
ZKgX0000000000000`0000020:Vmj08000000P2Y_NP00`000000ZKgX00000002000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000:Vmj00300000004
0:Vmj0000000oooo000002X0oooo000D0?ooo`040000003oool0oooo000000D0oooo0`000000102Y
_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vki`0000000P0000020:^ji0030000002[_>D0
00000080000000<0Y[cZ000000000000100000000`2]_^H000000000000300000080[KgV0P000002
0:Vji@030000002Z]n8000000080000000@0[/3W0000002^_^H0[[kV0P0000020:Rhi@030000002[
]=l0ZkCO008000000P2^_nH00`000000/;kT00000002000000040:jli0000000[;SR0:bhhP<00000
00@0ZKWT0000002^^^80[[[R0P0000020:jih@030000002]]Mh000000080000000@0[KSQ0000002]
]n00[KOP0`000000102Y]>0000000:Zag@2Z/Md200000080Y[SV00<000000:Rii@0000000P000002
0:W2j`030000002[`^/000000080000000@0ZKCQ0000002W]>80YkCR0`000000102Y]>4000000:^j
i@2[^^D200000080ZKST00<000000:Vgh`0000000P000000102Z]n8000000:bih`2/^N<200000080
[[_S0`000000102__^D000000;6oi@2a_nD3000000030:jli0000000[K_T00<000000P2__^D20000
0080/KkT00H000000;;2iP000000]<;T0000002eaNH3000000060;73i`00000000000000002Y_NP0
00000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX000000020000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0D00000:P3o
ool001@0oooo00@000000?ooo`3oool00000103oool2000000030?ooo`000000ZKgX00<000000P2Y
_nT00`000000ZKgX00000002000000040:Nkj0000000Zk[T0:^ji08000000P2^`>L200000080YKcZ
00<000000:BljP2T_>X00P0000020:Vji@030000002Y^nH000000080000000@0Z[gW0000002Y^^D0
ZK[U0P0000020:c1j@030000002^`>L00000008000000P2Y_^P00`000000Z;SU0000000200000004
0:^nj0000000[[oV0:joiP8000000P2^_nH00`000000[[cT0000000200000080ZKWT00<000000:Vi
i00000000P000000102]^^@000000:jih@2^^N4200000080[;WS00<000000:fhh@0000000P000002
0:^ghP030000002Y]>0000000080000000@0Y[OU0000002V^>H0Y[SV0P0000020:S0j`030000002Y
`^/0ZL;[008000000P2Y/n000`000000ZKCQ00000002000000040:VagP000000ZKCQ0:Vdh@<00000
00@0[KWR0000002Y^>@0ZKST0P0000020:VfhP030000002Z]n8000000080000000H0[KcT00000000
000000000:nlh`0000020:nni@<0000000<0[koV0000002^_>@0100000001P2__><0000000000000
0000/KoT00000080/KkT0P0000020;C2i08000000P2canP2000000040:o3j@000000ZKgX0:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP2000000040:Vmj0000000
ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000001P2Y_NP00000000000000000ZKgX0000
0080ZKgX0P00000Y0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
0?ooo`80000000<0ZL7[0000000000000`0000020:Nmj@D0000000@0[/;X00000000000000000P2/
`>P00`000000YKcZ00000002000000040:Bhi`000000ZK[U0:Vji@8000000P2[_>D00`000000Z[gW
0000000200000080YKo/00@000000:c1j@00000000000P2/`NP00`000000ZKkX0:Vnj00200000080
X;WZ00<000000:^nj00000000P000000102/`NT000000:joiP2^_nH200000080Z[[U00<000000:Vi
i02Y^N@00P0000020:Vii@030000002]^^@000000080000000@0Z[WT0000002/^N<0[;WS0P000002
0:bih`030000002[]n80ZkOR008000000P2U]N@00`000000Y[OU00000002000000040:JmjP000000
Z<3[0:S0j`<0000000@0Z;?Q0000002Y/n00ZK?P0P0000020:V`g0030000002Y/Mh0000000800000
00@0[kWQ0000002]^N80[KWR0`000000102Y]^8000000:VfhP2Y]^8200000080[KkV0P0000020:bm
iP030000002__><00000008000000P2`_nD00`000000[koV00000002000000060:fli@0000000000
0000002a`ND000000P2a_n@30000000;0;BnhP00000000000000002gaN@000000;?7j0000000/<S[
0000002_`nT00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000
00<0ZKgX0000002Y_NP00`0000000`2Y_NP0000000000004000000060:Vmj000000000000000002Y
_NP000000P2Y_NP3000000030:Vmj0000000000002P0oooo000D0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00`3oool01@000000Yl7/0:O1k0000000Yko[00<000000P2T_>X0
10000000Y;k[0000000000020:c2jP030000002/`>P0[<3X008000000P2U^NL00`000000Y;SW0000
0002000000040:Zji@000000ZkcU0:^li@8000000P2V`>`00`000000YKo/0:Fok00200000080Zl;[
00<000000:c1j00000000P000000102R^>P000000:2ijP2P^NX200000080Z/7Z00<000000:c1j@00
00000P0000020:ZkiP030000002Z^^D000000080000000@0ZKWU0000002Y^ND0ZKWU0P0000020:Zj
i@D0000000<0Zk[T00000000000010000000102W]^<000000:Fei02U]N@200000080Yk_W1@000000
102X]>4000000:Rch@2X/n43000000040:R_g0000000ZK3L0:V`g08000000P2]^>400`000000[kWQ
00000002000000040:fhh@000000ZKKR0:VfhP<0000000H0Zk[U00000000000000000:_1j@000002
0:bmiP8000000P2a_n@00`000000/;oU0000000200000080[;kV0P0000020:bmiP030000002a`ND0
00000080000000H0/KoT0000002d_^8000000;O0h00000020;O5i08000000P2`b>/200000080ZkoX
00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vm
j08000000P2Y_NP200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3
000000040:Vmj0000000ZKgX0:Vmj0800000:03oool001@0oooo00@000000?ooo`3oool000000`3o
ool2000000H0oooo00@000000:O1k000000000000P2T_>X00`000000Y;cZ0:BljP0200000080Ykk[
00<000000:c2jP0000000P000000102Y^^D000000:Fii`2U^NL200000080Y;SW00<000000:Zji@00
00000P0000020:k2j0030000002V`>`000000080000000@0Y<3]0000002[`^/0Zl;[0P0000020:Vj
iPD0000000@0Xk_Y0000002Z`NX0Z/7Z0`0000000`2Z_NL000000000000300000080ZKWU1@000000
1P2Y^nL00000000000000000Z;[V00000080ZKWU0P0000020:Vji@030000002Y^>@0ZKST00D00000
00H0Z;OT00000000000000000:ZghP0000020:RdhP030000002X]>4000000080000000@0Z:kL0000
002X[m`0Z:oL0`000000102/]Ml000000:fhh@2]^>4200000080/;_R00<000000:fhh@0000000P00
00020:VehP8000000P2]_^H00`000000Zl7Y00000002000000030:Zji@000000/KoT00@0000000H0
/<3U00000000000000000:Zji@0000020:bmiP8000000P2``nP010000000/KoT0000000000020;O0
h0<0000000H0^/OT00000000000000000:c2jP0000020:^oj08000000P2Y_NP00`000000ZKgX0000
0002000000030:Vmj0000000000000@0000000H0ZKgX00000000000000000:Vmj00000020:Vmj080
000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000
000002L0oooo000E0?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`050000002T_>X0Y;cZ
0000002T_>X00`000000102V_NT000000:Nnj`2W_^/200000080ZK[V00<000000:Vji@0000000P00
00020:Fhi`040000002T^>L0000000000080[L7X00<000000:k2j02^`^P00P0000020:K1k0D00000
00H0Z;[V00000000000000000:Vii@0000020:Fhi`D000000P2Y_^P200000080Yk_X00<000000:Rj
iP0000000P000000102Y_>L000000:Vli`2Y_>L200000080Yk_X00<000000:RjiP0000000P000000
102Y^nL000000:Vji@2Y^^D3000000040:Nhi@000000YkKS0:Nfh`8000000P2/^^@00`000000Z[OR
0000000400000080YjoM00<000000:R^g00000000P0000020:Zdg`030000002/]Ml0000000800000
00@0[k[R0000002`^n80/;_R0P0000020:^bgP050000002Y]N8000000:jgg`0000000P2]_^H20000
0080Y[GT1@0000001P2b`ND000000;30i@000000[kcS00000080Z[[U0`000000102^_nH000000;33
j02``nP20000000:0:nmi@000000]l3P0000002l`Mh000000;[7i0000000_LKQ00000080[<;Z0`00
0000102Y_NP000000:Vmj02Y_NP200000080ZKgX0P0000020:Vmj0030000002Y_NP0000000800000
00@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000:Vmj003000000040:Vmj0000000ZKgX0:Vm
j0<0000000@0ZKgX0000002Y_NP0ZKgX0`00000V0?ooo`00703oool00`000000oooo0?ooo`050?oo
o`030000002T_>X0Y;cZ00<0000000<0Y;cZ0000002V_NT00`0000020:Vnj0040000002Y^^H00000
00000080ZKWU00<000000:Fhi`2U^>L00P0000020:Bmj`030000002]`NP000000080000000H0[/?Y
00000000000000000:Jji`0000020:Bij08000000P2X^ND00`000000ZKWU0000000200000080Z;cX
00<000000:Rmj00000000P000000102X_NP000000:Nkj02W^nP200000080Z;cX00<000000:Vli`00
00000P000000102X_NP000000:Nkj02W^nP200000080Z;_X00<000000:Vki`0000000P0000020:Nj
iP030000002W^>D000000080000000@0ZK_V0000002/^^@0[;[T0P0000001@2X]>4000000:N`g`2W
/=l000000080YjoM0P0000020:Rch0030000002Z]=l0Z[CO008000000P2^^>400`000000[k[R0000
0002000000040:b`f`000000Zk;N0:^bgP8000000P2^]ml3000000030:nfgP000000000000<00000
0P2]^^<00`000000//7U00000002000000060:nlh`00000000000000002]^N8000000P2^_nH30000
00030:^oj0000000[kgU00<0000000D0_<7N00000000000000000;g6h@03000000030:Vmj0000000
000000@0000000H0ZKgX00000000000000000:Vmj00000020:Vmj080000000@0ZKgX0000002Y_NP0
ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P0000000`2Y
_NP0000000000004000000030:Vmj0000000000002H0oooo000K0?ooo`800000203oool200000080
Y;cZ1@0000000`2Y`N/000000000000300000080ZK[U00<000000:Vii@0000000P0000000`2U_>X0
00000000000300000080[/;Y0P0000020:jli0030000002V^^L00000008000000P2T^>L010000000
Z;WU0000000000020:Vli`030000002X_>P0Z;cX008000000P2Y_NP00`000000Z;gX000000020000
00040:Flj@000000Z;cX0:Rlj08000000P2Y_NP00`000000Z;gX00000002000000040:Fjj0000000
Z;_X0:Rkj08000000P2W^nP00`000000Yk[V0:NjiP0200000080YKWW00<000000:VkiP0000000P00
00001P2Y^^H000000:Rdh@2X]>4000000:N`g`<0000000@0Yk?R0000002X/n00Z;?P0`000000102[
]n4000000:jhh@2^^>4200000080[[;K00<000000:b`f`0000000P0000020:jafP80000000<0];GJ
00000000000010000000102Y/Mh000000:fjh`2]^^<200000080/KgS0P0000020:nih@030000002]
^N800000008000000P2a_nD400000080[[cT0P0000020<74g08000000P2na=l200000080ZK[U00<0
00000:Vli`0000000P000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000ZKgX00<00000
00@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX0P000000102Y
_NP000000:Vmj02Y_NP3000000030:Vmj0000000000002D0oooo000K0?ooo`030000003oool0oooo
00T0oooo0P000000102T_>X000000:Bnk02T_^`200000080YL3]00<000000:FljP00000010000002
0:W1jP8000000P2V_NT00`000000Y[k[0000000200000080[KcU00@000000:jli000000000000P2V
^>H00`000000Y;SW0:Bhi`0200000080Z;cX00<000000:Vli`0000000P000000102Y_NP000000:Vm
j02Y_NP200000080Y[cY00<000000:Flj@0000000P000000102X_NT000000:Vmj02Y_NP200000080
Y[WW00<000000:Fjj00000000P000000102W_>P000000:Nkj02W^nP3000000040:FhiP000000YKWW
0:Fii`8000000P2X_>P00`000000ZK[V0000000400000080YKCT00<000000:NchP0000000P000000
102Y]^8000000:^gh@2[]n43000000040;2fgP000000[[;K0:jbf`8000000P2^[MH00`000000[[7J
00000006000000040;6bf@000000ZK7N0:VagP<0000000H0/K[P00000000000000000;2khP000002
0:nih@8000000P2b_>4010000000/KoU0000000000020:Rlj0<0000000X0[[kU00000031a=`00000
0<?6g0000000_/CO0000002n`mh000000P2Y^^D2000000040:^ki@000000ZKgX0:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000<0ZKgX000000000000
100000001`2Y_NP00000000000000000ZKgX0000002Y_NP00`000000102Y_NP000000:Vmj02Y_NP3
000002@0oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000:BljP0000000P0000020:Nn
j`040000002U`>d0000000000080Wkk_00<000000:W4k@0000000P0000020:G1k@040000002V_NT0
000000000080ZKkY00<000000:fli@2]_>D00P0000020:jkh`030000002V^>H000000080000000@0
Y;_Y0000002X_>P0Z;cX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002V_>T0
Y[cY0P0000020:BljP030000002X_NT000000080000000@0ZK[V0000002V^NL0Y[WW0P0000020:Jj
i`030000002W_>P00000008000000P2U]nH00`000000YKSV00000002000000040:Jji`000000Z;cX
0:Rlj08000000P2R]NH00`000000Y;GU0000000400000080Y[GT00<000000:VfhP0000000P000000
102/]n4000000;2fgP2`]]h3000000040:b]f0000000[ZgF0:j]ePD0000000D0];GJ0000002f/mL0
00000;6bf@03000000060;2cf`000000/K[P0000002e^]d000000P2`^n83000000040:njh@000000
/[cQ0;:lh@80000000H0/koS00000000000000000:Jlj@0000020:jni@8000000P33a]`200000080
_/?N0`0000000`2[]n8000000:^ki@03000000040:Vmj000000000000:Vmj0<0000000<0ZKgX0000
000000000`0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0`000000102Y_NP000000:Vm
j02Y_NP2000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX000000000000903oool001X0oooo
0P00000=0?ooo`040000002V_NT0Y[gY00000080Ykk[0P00000209nkk0030000002O_^l000000080
000000@0YLC`0000002U`Nd0YL7]0P0000020:S0j`030000002Y_^T000000080000000@0[K_T0000
002^^n<0[[_S0P0000020:Jlj@030000002T^nT000000080000000@0Z;gX0000002Y_NP0ZKgX0P00
00020:Vmj0D0000000<0Y[cY0000000000000`0000020:RjiPD0000000<0YkWV0000000000001000
0000102V^>D000000:FgiP2U]nH200000080Y[SV00<000000:Jji`0000000P000000102T]^D00000
0::eiP2R]NH200000080X[KW00<000000:>fiP0000000P2V]N@200000080ZKKR00<000000:bgh@00
00000P000000102[/mh000000:b]f02/[MP500000080];?H0P0000020;Jce`8000000P2c/mP01000
0000/;?K0000000000030;Fjg@80000000@0[[WR0000002_^^40[k[Q0`0000000`2f_^0000000000
00020;C0i0030000002V_>T000000080000000X0[[oV00000033a]`000000<C7g@000000_/?N0000
002l`=d000000P2[]n8200000080[[gT00<000000:Vmj00000000P0000001P2Y_NP0000000000000
0000ZKgX00000080ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0
ZKgX0`0000000`2Y_NP000000:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<000008`3oool001/0
oooo00<000000?ooo`3oool0303oool00`000000Y[gY00000002000000030:Vmj0000000000000<0
00000P2S`>d50000000309nmkP000000000000<000000P2U_NX00`000000[K_T0000000200000003
0:joi`000000000000<000000P2T_>X5000000060:Vmj000000000000000002Y_NP000000P2Y_NP2
00000080Y[WW00<000000:Bij00000000P000000102X^NH000000:Vii@2Y^ND200000080ZKcW00<0
00000:RjiP2X^^H01@000000102V]^@000000:JhiP2V^>H200000080Z;OT00<000000:Bfi@000000
0P000000102Q]>H000000::fi`2R]^L5000000040:FbhP000000ZKKR0:VfhP8000000P2Z]^800`00
0000Zk?N0000000400000080/k7F0`0000001P2f/mL000000;Jce`000000][?G00000080/k?H0P00
00020;Jef0060000002e^]d000000;RmgP000000[[WR0`0000001P2a^n4000000;Jnh0000000^<7Q
00000080]<3T0P0000020:BljP030000002^_nH000000080000000<0a<OM0000000000000P2l`=d3
000000040:njh@000000[[gT0:jmi08000000P2Y_NP2000000040:Vli`000000ZKgX0:Vmj0<00000
00@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX
0:Vmj08000000P2Y_NP5000000030:Vmj0000000000002<0oooo000K0?ooo`030000003oool0oooo
00d0oooo0P0000000`2Y_NP00000000000020:Vmj0030000002T_>X00000008000000P2Y_^T01000
0000X;c]0000000000020:6mk@030000002U`>d0000000@000000P2]`NP200000080[<7X00<00000
0:JmjP0000000P000000102T^>L000000:Rlj02X_>P200000080ZKgX00<000000:Vmj00000000P00
00020:VjiP040000002V^NL0000000000080Y;SW00<000000:RiiP0000000P0000020:Vli`030000
002Y_>L000000080000000@0Y[[W0000002V]^@0Y[KT1@000000102X]n<000000:Rgi02X]n@20000
0080Y;CT00<000000:6diP0000000P0000001P2Q[=l000000:2]h02P[N0000000:FbhP<0000000@0
ZKKR0000002Z]^80Z[KR1@0000001P2ZZmL00000000000000000][?G00000080][?G0P0000020;Jc
e`<0000000@0][?G0000002f]MP0][GH0P0000020;RmgP8000000P2^^>400`000000/K_Q00000002
000000050;S1h@00000000000000002d`N@01@0000020:k1i`8000000P32b=l2000000040;W1g`00
0000[k[Q0:njh@<0000000L0/KkT00000000000000000:Vli`000000ZKcW00<0000000@0ZKgX0000
002Y_NP0ZKgX0`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000@0000000L0ZKgX
00000000000000000:Vmj0000000ZKgX00<0000000<0ZKgX0000000000008P3oool001X0oooo0`00
000@0?ooo`050000002Y_NP0ZKgX0000002Y_NP00P0000020:Vmj0030000002Y_^T0ZKkY00800000
0P2R^n/010000000XKg]0000000000020:2kk0030000002O_>d00000008000000P2[`^X010000000
[<7X0000000000020:Fgi@030000002T^>L00000008000000P2Y_>L010000000ZKgX000000000002
0:VkiP030000002Y^^H0ZK[V008000000P2V^>H010000000Y;SW0000000000020:Rlj0030000002Y
_>L0ZKcW008000000P2W_NT00`000000Y[[W00000002000000040:Jgi@000000Z;OT0:Rgi0D00000
00@0ZKKR0000002T]>@0Y;CT0P0000020:>_h@030000002Q[=l0000000@000000P2W/N000`000000
ZKKR0000000400000080XZ?F0P0000000`2]ZmD000000;Jce`020;Jce`80000000H0]:oC0000002f
/mL000000;Jce`0000020;Jce`<0000000H0_L7L00000000000000000;Roh00000020:jhh@800000
0P2c_^82000000060;[3h@000000]<7T0000002d`^@000000P2T_>X3000000070:k2j0000000`/SO
0000002man8000000;W1g`0300000080/[gR0P000000102b_^<000000:Vli`2Y_>L200000080Z[cV
00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX0P000000102Y_NP0
00000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0`00
000Q0?ooo`00303oool3000000@0oooo0P0000050?ooo`030000003oool0oooo0100oooo00<00000
0:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002R^n/0X[_[0P00
00020:Blj`040000002P^n`0000000000080XKg]00<000000:_2jP2[`^X00P0000020:Zmi`040000
002U]nD0000000000080Z;SU00<000000:Vli`2Y_>L00P0000020:Vli`030000002Y^nH000000080
000000@0ZKWU0000002V^>H0Y[SV0P0000020:Bkj@030000002X_>P000000080000000@0ZKgX0000
002W_NT0YkgY0P0000020:6ei`030000002V]nD000000080000000@0YkSU0000002X]^<0Z;KS1@00
0000102V]><000000:>_h@2S[n42000000050::XfP000000Y:[K0:BZf`0000000P2W/N0300000003
0:JSd`000000Y:;D00<0000000X0YIk?0000002]ZmD0[J_E0000002f/mL000000;:WcP000000]:oC
0P0000030;Jce`80000000H0^KcK0000002m`M`000000;k9h`0000020;Roh0<0000000L0/;cS0000
002c_^8000000;C1i0000000^/?Q00<0000000H0]<;T00000000000000000:JmjP0000020:k2j080
00000P2man8200000080]l7R00@000000;:mhP00000000000P2b_^<3000000040:Zji@000000Z[cV
0:ZliP80000000<0ZKgX000000000000100000001`2Y_NP00000000000000000ZKgX0000002Y_NP0
0`000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000ZKgX00<0000000<0ZKgX00000000
00008@3oool000/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool04@3oool2000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX
0000000000000`0000000`2T_>X000000000000300000080XK_[00<000000:6mk@0000000P000000
102Y`N/000000:Zmi`2Z_NL200000080YkKS00<000000:Rhi@0000000P000000102Z_^P000000:Vl
i`2Y_>L200000080ZK[U00<000000:Vii@0000000P000000102V^nP000000:Bkj@2T^nT200000080
Z;gY00<000000:Vmj00000000P000000102T]nL000000:6ei`2Q]NL200000080YKOV00<000000:Nh
i@0000000P000000102X_>P000000:VjiP2Y^^H50000000609n[g`000000XZSJ0::XfP000000Y:[K
0`000000102XY]@000000:JSd`2VXm<2000000030:BJb`000000YIk?0080YIk?00@000000:f[e@00
000000000P2bYlh200000080]jg?00<000000;Jce`0000000P0000001@2i_=/00000000000000000
_/WS00<0000000@0]<3S0000002`_><0/;cS0P0000020;C1i08000000P2jaN8200000080]<?U00<0
00000:JmjP0000000P0000001P2^`NP00000000000000000^LKT00000080]l7R0P0000001P2d_N40
0000000000000000/kgQ00000080Z[[U0`0000000`2/_>D00000000000020:Vmj0030000002Y_NP0
00000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0
ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0D00000803oool000l0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo100000020:Vmj0800000
0P2Y_NP010000000ZKgX0000000000020:FljP030000002T_>X0000000@000000P2S_nd500000004
0:>jj@000000YkKS0:Nfh`8000000P2]_nL5000000030:Nki`000000000000<000000P2Y_>L50000
00030:BljP000000000000<000000P2Y^nL5000000040:6diP000000YKOV0:FgiP8000000P2U^NL0
0`000000Z;cX00000002000000060:>kjP000000XK;T0:6bi0000000Wj_O1@0000020:^[e`030000
002XY]@000000080000000H0Y9[<0000002TV//0Y9[;0000002UW/l3000000060:jOb0000000/ZO>
0000002eX/H000000P2g[Ll200000080][CG0P0000020;k4gP8000000P2fa>D00`000000]<3S0000
00020000000:0;;1i@00000000000000002ea>H000000;[5hP000000^LKT00000080]<?U0P000000
1P2X_>P00000000000000000[l7W00000080^LKT0`0000000`2d_n<00000000000020;Fmh0030000
002c_N4000000080000000H0[;WS00000000000000000:jli00000020:Vmj080000000@0ZKgW0000
002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP2000000030:Vmj0000000000000@0000000L0
ZKgX00000000000000000:Vmj0000000ZKgX00<000007`3oool000l0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`3oool2000001H0oooo00<000000:Vmj00000000P000000102Y
_NP000000:Vmj02Y_NP200000080ZKgX00@000000:FljP00000000000P2T_N/00`000000Y;o]0000
0002000000040:C0k@000000Xl3^0:?0kPD0000000H0Z[oX00000000000000000:g1j00000020:Rm
j@8000000P2U_>T00`000000Z;cX00000002000000040:Vmj0000000Y[cY0:Jlj@8000000P2T^^T0
0`000000Z;gX00000002000000060:Jji`000000XkCU0:>di@000000XKCV0`000000102U^>L00000
0:Fii`2U^NL200000080YKo/00<000000:>kjP0000001P0000020:B[g0030000002[ZmL0Zj_G0080
000000<0YIk?0000002TV/`00P2TV/`01P000000Y9[;000000000000ZiO2000000<0[Yo800@00000
0;FRaP2eX/H0]J;60P0000002P2m[//000000;Jde`000000_;OE0000002na=h000000<?5g0000002
0;K4i@8000000P2b`ND2000000040;;4i`000000]LCV0;G4iP8000000P2ia^@3000000030;?2i@00
000000000080Zk_U00<000000:o1i`0000000P0000001P2d`nD00000000000000000/[kS00000080
]KgP0P0000001P2c_N400000000000000000[kSP00000080[[cT0`0000000`2Y_>L000000:Vmi`03
000000030:Vmj0000000000000@0000000D0ZKgX000000000000ZKgX000000020:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP000000000000O0?ooo`002`3oool4000000<0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0E0?ooo`050000002Y_NP0ZKgX0000002Y
_NP00`000000102Y_NP000000:Vmj02Y_NP200000080YKcZ00<000000:Bmj`0000000P0000000`2T
`>d000000:C0k@0300000080Vkg`00@0000009Zlk`00000000000P2Z`^/00`000000[L7X00000002
000000040:JmjP000000YKcY0:Flj@8000000P2X_NP00`000000ZKgX00000002000000040:Jjj000
0000Y;[Y0:Bjj@8000000P2V_>T00`000000Y[[W0000000400000080XkSX00<000000:Fhi`000000
0P0000000`2W^nP00000000000030000000309V^i@0000000000008000000P2IZ>400`000000Y:_L
00000002000000060:JXe`000000YIk?0:FNc`000000Y9[<0`0000001P2UTL0000000:^G`P2[Ul80
00000:jOb08000000`2eX/H01@000000_Jk;0;f^b`2m[//0000000<0_;OE00<000000<?5g033aM`0
0`0000001`2b`ND00000000000000000//;V0000002ba>L00`000000102danP00000000000000002
0;S7iP80000000@0/L3U0000002[^nD0Zk_U0P0000020;72iP80000000@0/L3U0000002b_^<0/[kS
0`0000000`2e_n400000000000020;>lh@030000002_^>0000000080000000@0/KgS0000002Y_>L0
ZKcW0P0000020:ZliP80000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000:Vmj0030000
00040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX0000002Y_NP00`00000N0?ooo`002`3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo0P00000H0?ooo`030000002Y_NP0
00000080000000<0ZKgX0000000000000`0000000`2Y_NP000000000000300000080Y[k[1@000000
0`2T_^`000000000000300000080Ukca00<000000:[2j`0000000P0000000`2Z`^/000000:JmjP03
000000040:BljP000000Z;gX0:Rmj08000000P2Y_>L00`000000Y[[X00000002000000040:Jji`00
0000Y[cY0:Jlj@8000000P2Q^>T00`000000XkSX0000000400000080Y[WW0P000000102/^n@00000
0:6ciP2Q/nH:000000030:2[g`000000YZSG0080YZSG00H000000:FNc`00000000000:6?`@000002
0:FA`0030000002[Ul80ZiO2008000000P2bV[l02P000000]J;60000002nY/8000000;f^b`000000
`k370000002l]mD2000000080<?5g0000000aLGK0000002b`ND000000;:nh`0000020;;2iP800000
0P2bb>/200000080//OZ00@000000;S7iP00000000000P2a`>D3000000070;2oiP000000/L;V0000
002a`^H000000;70i@03000000060;2ni0000000]KoQ0000002d`><000000P2c_>42000000040;>l
h@00000000000;6mh`<0000000L0Z[[U00000000000000000:bli@000000ZKgX00<0000000@0ZKgX
0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX
0P000000102Y_NP0000000000000000M0?ooo`002`3oool5000000<0oooo0P0000040?ooo`030000
003oool0oooo01P0oooo00<000000:Vmj02Y_NP00P0000020:Vmj0040000002Y_NP0000000000080
ZKgX00<000000:Jlj@0000000P000000102Y_^P000000:Fmj`2U_N/200000080Y[k[00<0000009Zm
l0000000100000020:O4kPD0000000<0YKg[0000000000000`0000000`2X_NP00000000000030000
0080Y[WV1@000000102S^NP000000:6hj@2Q^>T200000080X[[Z00<000000:>jj@0000000P000000
0`2X_>P000000:bki00500000080UZOR00<0000009JWhP0000000P2FYn800`000000X:_O00000005
0000000509f?a@000000XHo10:6?`@0000000P2UTL02000000040:nD^P000000/YZo0;:J_`800000
0`2nY/801@000000`k370<>`a`33/<L000000080al3D0P0000001@35aM/00000000000000000/[kS
00<000000P2da>H2000000040:o6j`000000//OZ0;;7jP80000000H0]<SY00000000000000000:k1
i`0000020;2oiP8000000P2a`^H200000080[koV00@000000;2ni000000000000P2d`><300000003
0;6mh`000000/kcQ00<0000000H0/kkR00000000000000000:bih`0000020:bli@80000000@0ZKgX
0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP2000000030:Vmj0000000000000@00000
00@0ZKgX000000000000ZKgX0P00000M0?ooo`006@3oool00`000000oooo0?ooo`0I0?ooo`800000
00@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0040000002Y_NP0000000000080ZKgX00<000000:Vn
j00000000P000000102V_>T000000:Jnj`2V_^/200000080Vk[^00<0000009Rll@0000000P000000
102Ta?0000000:K1k@2V`Nd2000000040:Blj`000000Y;cZ0:BljP8000000P2W_NT00`000000Z;_W
00000002000000040:Rlj0000000Z;_W0:Rki`D0000000@0XKSY0000002R^^X0X[[Z0P0000020:2j
j`@000000P2X^>D00`000000WJgR0000000209JWhPL0000000D0Ui_F0000002HU<h0V9C>00000002
09f?a@050000002QSl40XHo10000002UTL000P0000030:nD^P80000000@0ZH:Z0000002nY/80_ZK2
0P0000020<>`a`80000000D0al3D0000003=am@0cLOD000000020<G6f`8000000P2e_=l010000000
]<CV0000000000020:o6j`<0000000<0/LO[0000000000000P2]`nX00`000000[/7W000000020000
00060;74j000000000000000002_`NL000000P2__nH2000000060:noiP00000000000000002`_nD0
00000P2a_N<200000080]L7S0P000000102b_N8000000:bih`2/^N<3000000030:jkh`000000ZKgX
00<0000000<0ZKgW000000000000100000001@2Y_NP000000000002Y_NP000000080ZKgX0`000000
0`2Y_NP000000:Vmj003000001`0oooo000I0?ooo`030000003oool0oooo01X0oooo00<000000:Vm
j00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P000000
0`2Y_NP0000000000003000000030:Vnj@000000000000<000000P2L_Nl5000000030:2nkP000000
Y;c[00<0000000@0Y;cZ0000002W_NT0YkgY0P0000020:Flj@030000002X_>P000000080000000@0
Z;_W0000002S^>P0XkSX1@0000000`2Q^^/0000000000003000000040:FljP000000Z;SU0:Rhi@D0
000000L0UZOR0000002FYn80UZOR0000002FX]d000000080Ui_F00@0000009RDcP2HU<h000000P2M
SlD01P000000XHo1000000000000Yhfj000000<0[iBj00@000000:V2ZP2YPZX0ZH:Z0P0000020<BY
_P8000000P3?_<P00`000000cLOD0<g7e002000000040<G6f`000000`lKL00000080]KcO0P000000
1@2ib>H00000000000000000[lGZ00<0000000<0/<CY0000000000000`0000020:c2j@80000000@0
[l?Y0000002_`NL0[l7W0`0000000`2^_nH00000000000020:k0i`030000002`_nD0000000800000
00L0[koV00000000000000000;?1i0000000/[gR00<0000000@0[[SP0000002^^n<0[[_S0P000002
0:Vli`80000000@0Z[cV0000002Y_NP0ZKgX0`0000000`2Y_NL000000:Vmj003000000040:Vmj000
0000ZKgX0:Vmj08000000P2Y_NP2000001/0oooo000H0?ooo`8000007@3oool2000000030:Vmj000
0000ZKgX00<0000000<0ZKgX0000000000000`0000020:Vmj08000000P2Y_NP010000000ZKgX0000
000000020:Vmj0030000002N^^`000000080000000@0X[k]0000002P`>l0X<3_1@0000000`2S_>/0
00000:BljP03000000040:FmjP000000YKcY0:Flj@8000000P2W_NT00`000000Z;_W000000020000
00040:Bhi`000000XkWX0:>ij0D0000000<0Wk[/0000000000000`0000001@2N/nH0000009V[h`2I
Zn<000000080UZOR00<0000009JWhP000000300000001@2OR;/000000:N=^P2WSKX000000080[iBj
00D000000:V2ZP2YPZX0ZH:Z000000030<BY_P030000003?_<P0ckc80080000000D0cLOD0000003@
c]P0d<kH000000020<?6g0<0000000<0_LOR0000000000000P2kc>L200000080/L?W0P000000102`
`>H000000:Znj02Z_^P3000000030:g2j@000000[l?Y00<0000000H0[L7X00000000000000000:k1
i`0000020:k0i`80000000H0[[oV00000000000000000:noiP0000020;?1i08000000P2`^n800`00
0000[[SP00000002000000070;6mhP00000000000000002Z^ND000000:ZliP03000000040:Vli`00
0000ZKgW0:Vmi`80000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP0000000000003000001/0
oooo000I0?ooo`030000003oool0oooo01d0oooo100000000`2Y_NP00000000000020:Vmj0030000
002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080
000000<0XkcZ0000002R_^d00`000000102N_^l0000009blk`2L_>l5000000030:Bok@0000000000
00<0000000@0Y;cZ0000002W_NT0YkgY0P0000020:Fkj0030000002T^>L000000080000000@0Y[[W
0000002Q^^/0XK[[0P0000001P2O]^P0000009jgjP2N]nX0000009jciPP0000000@0SJ?S00000029
VM`000000P2:SM000`000000RhG80000000209N6_`040000002OR;/0WhRk00000080Yhfj00@00000
0:nD^P00000000000`2YPZX00`000000a:Vn0<BY_P02000000040<nlb0000000f<S;0=S8b`800000
00D0d<kH000000000000`lKL000000020<7=h`8000000P31e>P2000000070;O9j0000000/L?W0000
002b`ND000000;30iP03000000040:foi`000000[L;Y0:g2j@8000000P2]`nX2000000040:c0j@00
0000[/7W0:k1i`<0000000<0[L7X0000000000000P2^_nH00`000000[koV00000002000000040;6o
i@00000000000;2khP8000000P2b^]l2000000040;Bmh@000000Z[WU0:Zii@80000000@0[;cU0000
002Y_>L0ZKcW0`0000000`2Z^nH0000000000003000000060:Vmj000000000000000002Y_NP00000
0P2Y_NP2000001X0oooo000H0?ooo`030000003oool0oooo01h0oooo00<000000:Vmj02Y_NP00P00
00020:Vmj0030000002Y_NP000000080000000<0ZKgX0000002Y_NP00`000000102Y_NP000000:Vm
j02Y_NP200000080ZKgX1@0000000`2V_^/00000000000030000000409Vll0000000X/7_0:;1k`80
00000P2P`>l00`000000Xkg[00000004000000030:FljP000000000000<000000P2U^NL00`000000
Y[[W00000002000000030::gj0000000WkKX00D000000P2E[^P00`000000UZWS0000000209JWhP08
0000002=Xn<0SJ?S00000029VM`0000008Z=d000000208^5b0030000002GQ[l0000000<0WhRk00H0
00000:N=^P000000000009e]V`0000020:V2ZP040000002iQYl0000000000080d[S100P000000=S8
b`3Hb</0f<S;0000003MeLl000000<kFg`<0000000D0`LgS0000002ne^`000000<7Dj00200000080
]lWX0P0000020;;1i@8000000P2``NH00`000000[KoW00000002000000070:k2j000000000000000
002[`NT000000:c0j@03000000060:g3jP00000000000000002/_nP000000P2^_nH2000000040:jo
iP000000/KoU0;6oi@<0000000<0[K_S0000002b^]l00P0000020;Bmh@<0000000<0[;[T0000002/
_>D00`0000001`2Z^ND00000000000000000[;gV0000002Y_NP00`000000102Y_NP000000:Vmj02Y
_NP3000000030:Vmj0000000000000P0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D00000
0P3oool001P0oooo0P00000P0?ooo`80000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0D00000
00<0ZKgX0000000000000`0000001P2Y_NP00000000000000000ZKgX00000080Y[cY0P000000102X
_^T0000009bkkP2L^nh50000000309o2l@000000000000<0000000@0X[k]0000002T_N/0Y;g[1@00
00000`2S^^T000000000000300000080Z;cW100000020:6diP030000002I/nT000000100000000H0
RhG80000002GQ[l0UhJo0000002OR;/30000000909EVV0000000WFfK09e]V`000000ZH:Z0000002i
QYl0000000<0d[S10P0000000`3Hb</000000=gEc`0300000080a=KX0P0000020;kFk080000000D0
^m;[00000000000000000;?6j003000000040;;2iP000000/<7V0;31iP80000000H0[l3W00000000
000000000:o3j00000020:_1j@8000000P2[`NX2000000040:_1j@000000[;oX0:boj0<0000000<0
[[oV0000002^_nH00`0000000`2/_^H0000000000003000000040;Fnh0000000000000000080];oR
100000001P2]^^<00000000000000000[;_U00000080[;gV0P0000020:Vmj0030000002Y_NP00000
0080000000@0ZKgX0000002Y_NP0ZKgX0P0000070?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool001P0oooo00<000000?ooo`3oool08@3oool4000000060:Vmj000
000000000000002Y_NP000000P2Y_NP200000080ZKgX00@000000:Vmj000000000000P2Y_NP00`00
0000ZKgX00000002000000030:Vmj0000000Z;kY00<0000000@0Wk[/0000002L_Nl0W;g_0P000002
09^ol@030000002J_O40000000H000000P2S_>/200000080X;W[00<000000:Jmj@0000000P000000
102U_>T000000::eiP0000020:6diP8000000P2E/>T00`000000Rjg/00000002092ak@030000002D
[^P000000080OIcV00@00000072:g@000000MX;A1`0000001@2AHiP0000009EVV02EIYP000000080
WFfK0P0000020;V6W`80000000H0d[S10000003Mb<@0gLS40000003MeLl200000080enKQ0P000000
1@2le^d00000000000000000_=K]008000000P2cd>l2000000040:g3jP000000//;V0;;2iP<00000
00<0/<7V0000000000000P2a`nL00`000000[l?X00000002000000070:Znj000000000000000002/
`>P000000:_1j@03000000040:Znj0000000[[oV0:joiP80000000D0[[oW00000000000000000:Vm
j002000000030:^ki@00000000000080]/7R00@000000;BohP00000000000P2]^n<200000080[K_T
00<000000:bki@0000000P000000102^_nL000000:Vmj02Y_NP2000000030:Vmj0000000000000@0
000000<0ZKgX0000000000001P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
0080oooo000H0?ooo`030000003oool0oooo0280oooo00@000000:Vmj000000000000P2Y_NP00`00
0000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P00
00020:Vmj0D0000000<0ZKgX0000000000000`0000000`2R_^d00000000000030000000309Rll@00
0000000000H0000000@0X;WZ0000002P^N/0X;W[0P0000020:Bok@030000002U_>T0000000@00000
00@0XkKV0000002E/>T0UK3Y3`00000208AZ[@030000002>Hi/000000080TF>H00@0000009EVV02E
IYP000000P2MKI/200000080^HJO00<000000=jVVP0000000P3Mb<@00`000000i][9000000020000
00030=OVh@000000cNGX0080000000D0_=K]00000000000000000;WEkP03000000030:[6kP000000
[L?Z00<0000000H0/LCX00000000000000000;33j00000020;73i`80000000H0[l?X000000000000
00000:boi`0000020:c0j08000000P2Y_NP5000000030:k0i`00000000000080[<3X00<000000:Vm
j00000000P000000102Y_NP000000;K1hP2f`N82000000060;C3i@00000000000000002]^n<00000
0P2]^n@2000000030:joiP000000000000@0000000D0ZKgX000000000000ZKgX000000020:Vmj0<0
000000<0ZKgX0000000000001@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
0040oooo000G0?ooo`<00000903oool01@000000ZKgX0:Vmj0000000ZKgX008000000P2Y_NP00`00
0000ZKgX00000002000000030:Vmj0000000000000<0000000H0ZKgX00000000000000000:Vmj000
00020:Vmj08000000P2Y_NP010000000XkcZ0000000000020:Jnj`L0000000@0W[k_0000002P_>d0
X;c]1@0000000`2R^^X00000000000030000000409fik0000000XKKW0:6fi`D0000000@0UjoX0000
002=/>h0SK3^1P0000002P1ST>L00000059hfP000000MX;A00000024JZd0000008iSV`000002095S
V0040000002EIYP0UFJH00000080WFfK00T000000;V6W`2iQYl0^HJO0000003NYYX000000=g8a000
00000P3Vf/T4000000030<gUj0000000`mk]008000000P2le^d2000000030;G=k0000000000000<0
00000P2Z_nT200000080[lCY00<000000;33j00000000P0000000`2ab>/00000000000020:c1j003
0000002/_nL000000080000000L0[KkW00000000000000000:Voj@000000Z[oY00<0000000@0[L?Z
0000002/`>P0[<3X0P000000102V_>T000000000002Y_NP3000000050;G:jP00000000000:k0i`00
00000P2]^n<3000000050:jmi@00000000000:jniP0000000P2]_^H3000000030:Vmj0000000ZKgX
00<0000000@0ZKgX0000002Y_NP0ZKgX0P0000050?ooo`040000003oool0oooo000000L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`000`3oool3000000@0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`0S0?ooo`030000002Y_NP0ZKgX0080000000<0ZKgX0000000000000`00
00020:Vmj08000000P2Y_NP010000000ZKgX0000000000020:Vmj0030000002Y_NP0000000800000
00@0ZKgX0000002Y_NP0ZKgX0P0000000`2V_>T000000000000300000080W;_^00<0000009Rkl000
000010000000102K^^h000000:6hj@2Q^>T200000080Yk_W00<000000:2kk000000010000000102O
]nT000000:>fiP2S]^H50000000609Vgk0000000Njkd07^^m0000000IZ7b100000001P1fP]400000
08AZ[@000000SV>K00000080TF>H00@0000009EVV02EIYP000000P2MKI/010000000^HJO0;V6W`00
00020=jVVP<0000000D0i][900000000000000000=Ghh`02000000040<?Nk@000000_=K]0;cFk@80
000000<0_=;[0000000000000P2a`NH00`000000Y[[W00000002000000040:g2j@000000[lCY0:o4
j@80000000D0[lO/00000000000000000:c4j`05000000060:joiP00000000000000002]`>P00000
0P2Y_nT2000000040:[2j`000000[L?Z0:g3jP<0000000<0Z[oY0000000000000`0000001`2X`^d0
0000000000000000[lK[0000002^`>L00`0000001`2^^n<00000000000000000/;kT0000002^_^H0
0`000000102^_ND000000:Vmj02Y_NP2000000030:Vmi`000000000000@0000000<0ZKgX00000000
0000103oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool0
00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0903oool2000000030:Vmj000000000000080ZKgX00<0
00000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj0000000
0P0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0000000<0Z;kY000000000000
0`00000209Zjk`030000002J_O00000000@0000000@0XkWX0000002W^nL0Yk_W0P00000209fik003
0000002G]^d0000000@0000000@0X;SY0000002L]NX0W;GZ3@0000001024JZd0000008iSV`000002
095SV0040000002EIYP0UFJH00000080WFfK00T000000;V6W`2iQYl000000=jVVP000000m;bA0000
003od7h01@0000001@36k>l00000000000000000_=K]0080000000@0_=;[0000002hc>T000000P2a
`NH2000000030:^oj0000000000000@0000000@0[lGZ000000000000/<KZ0`000000102Y_NP00000
0:^nj02[_^P200000080[/3W00<000000:g0j00000000P0000000`2Y`^`000000000000300000007
0:_1jP00000000000000002Y_NP000000:JmjP03000000030:_2j`000000000000<0000000H0ZK_V
00000000000000000;2mi00000020;2ni080000000@0[[_S0000002^_ND0[[gU0`0000001@2Y_>L0
00000000002Z^N@000000080ZKgX0`0000000`2Y_NP00000000000040?ooo`8000002@3oool30000
00<0oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`800000:03oool01@000000ZKgX0:Vmj0000000ZKgX00<0000000<0
ZKgX0000002Y_NP00`0000000`2Y_NP000000000000300000080ZKgX10000000102Y_NP000000000
000000020:Vmj0040000002X_NP0000000000080ZKgX00<0000009fjk000000010000000102E_O<0
000009Bil@2D^O45000000030:^kiP000000000000<0000000H0U;K^0000002L^>/0W;S[0000002P
^>T30000000409njk0000000Wk[/09njk0H000000P0AG]H300000080SV>K00<00000095SV0000000
0`2EIYP2000000090:adU0000000^HJO0000003NYYX000000?BlT@000000om1n00<0000000<0`?W/
0000000000000P2le^d2000000050;cFk@00000000000000002hc>T00`0000000`2^`nT000000000
00020:g7k@030000002^aN/000000080000000<0/LKZ0000000000000P2_`^P00`000000ZKgX0000
0002000000040:^oj0000000[/3W0:k0i`80000000H0[L?Z00000000000000000:W1j`0000020:[1
j`80000000@0ZKgX0000002Y_NP0ZKgX0P0000020:^nj080000000@0[KoW0000002Y_NP0ZKgX0P00
00020:Rli`030000002`_N@000000080000000<0/L3U0000002^^n<00`0000001`2`_N@000000000
00000000Z[GQ0000002Z^N@00`000000102Y_NL000000:Vmj02Y_NP2000001D0oooo00040?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo02L0oooo00<000000:Vmj02Y_NP00P0000020:Vmj0D0000000<0ZKgX
0000000000000P2Y_NP00`000000ZKgX00000002000000030:Vmj0000000000000<0000000@0ZKgX
0000002Y_NP0ZKgX0P0000020:Vmj0040000002Y_NP0000000000080X;[/00<0000009flkP000000
10000000102:]o<000000:Bij02T^NP200000080[KgV00<0000009bik00000001P00000209njk0D0
000000D0W[c]0000001iZ?00000005BHl@0600000080SV>K00<00000095SV00000000`2EIYP20000
00090:adU0000000^HJO0000003NYYX000000?BlT@000000om1n00@0000000D0^]ob000000000000
00000;cIkP0200000080^MC^0P0000001P2_bNd00000000000000000ZlO_00000080[LO]0P000000
1P2]aN`00000000000000000/LS[00000080[l;X0P0000000`2Y_nT0000000000004000000050:k4
jP00000000000:g2j@0000000P2Y`N/3000000030:Vmj0000000000000<0000000L0ZKgX00000000
000000000:joiP000000[KoW00<0000000@0Y[gY0000002X_>L0Z;cW0P000000102aa>P000000;70
i@2a`>D2000000060;2lh`00000000000000002`^n8000000P2Z]N4200000080[[_T1@0000000`2Z
^nH000000000000D0?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0X0?ooo`80000000H0ZKgX
00000000000000000:Vmj00000020:Vmj08000000P2Y_NP010000000ZKgX0000000000020:Vmj0D0
000000<0ZKgX0000002Y_NP00`0000000`2Y_NP0000000000003000000030:Vmj0000000000000<0
00000P2Q_^h7000000040:Bkj@000000[KgV0:fmiP80000000H0VkW]0000002B]^l0T[K_0000002K
^Nd30000000309jmkP000000W[k_00`0000000@0Q6Z]0000002>Hi/000000P2AHiP00`000000UFJH
09EVV002000000050:adU0000000^HJO0000003NYYX00P0000001@3od7h00000000000000000/Nof
0080000000D0/=_f00000000000000000;WLlP03000000030;7?k`00000000000080ZLO_00<00000
0:_7k`0000000P0000000`2[aNd00000000000020:g6k@030000002ab>/000000080000000<0[<7Y
0000000000000P2Y`^`00`000000Zl?[00000002000000030:k2j@000000000000<0000000L0ZKgX
00000000000000000:Vmj0000000ZKgX00<0000000@0Z[kX0000002^_nH0[[oV0P0000000`2]_nL0
000000000004000000030:K1k@000000000000<0000000D0[KkV000000000000/L3U000000020;2k
hP<0000000<0[[SQ0000002^^n@00P0000020:Zii0<0000000<0[;cV0000003oool04`3oool000<0
oooo0P0000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0Z0?ooo`050000002Y_NP0ZKgX0000002Y_NP00`000000102Y_NP000000:Vm
j02Y_NP2000000030:Vmj0000000000000<000000P2Y_NP400000080ZKgX0P0000020:Vmj0040000
002Y_NP0000000000080ZKgX00<000000:>kjP0000000P000000102W_^X0000008Vfm000000207n`
l`030000002T^nT000000080000000<0[[oV0000000000001@00000209ZjkP@000000P2I`O<00`00
0000V;_`00000002082XkPL0000000D0SV>K0000002AHiP0TF>H0000000209EVV080000000<0[7BD
0000000000000P3NYYX2000000030?o@OP00000000000080000000<0X=ol0000000000000P2[eoL2
000000050;;Cl@00000000000000002/a^d01@0000001@2YaNd00000000000000000Z/?/00D00000
00H0[LC[00000000000000000:[1jP0000020:W2k080000000H0Zl7Z00000000000000000:joiP00
00020:fni`80000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Znj02Z_^P300000005
0:k0i`00000000000:c3j`0000000P2T`>d3000000030:Jok0000000[L;Y00<0000000<0ZkcV0000
002a`>D00`000000102]^n@000000:jhh@2^^>42000000060;70i@00000000000000002/^^@00000
0P2/_>H2000001<0oooo00040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000103o
ool2000002d0oooo00<000000:Vmj00000000P0000000`2Y_NP0000000000003000000070:Vmj000
000000000000002Y_NP000000:Vmj003000000030:Vmj0000000ZKgX00<0000000@0ZKgX0000002Y
_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP200000080YkgY2@0000020:BljP80000000@0[/3W
0000002K^Nd0VkW]1@0000000`2K_O00000009o1l0080000000408Fdm0000000O[Oh07jgn0<00000
00D0SV>K0000002AHiP0TF>H0000000209EVV00:0000002/M9@0[7BD0:adU0000000gZJJ0000003d
_94000000?o@OPD0000000D0X<We00000000000000000:oAlP0200000080[lGZ0P000000102^a^/0
00000:W4k@2Ya>d200000080Z/7Z0P000000102/`n/000000:c4j`2/a>/200000080Z[kX00<00000
0:[1jP0000000P0000001@2Y`N/000000000002[_^L000000080[[oV0`0000000`2]_nL000000:Vm
j003000000030:Vmj0000000000000<0000000L0Z[kX00000000000000000:k4jP000000[<?[00<0
000000@0Y;k/0000002V_n`0Y[o/0P000000102Z^ND000000:^liP2[_>H2000000030:foi`000000
000000@0000000D0//GX000000000000[KkV000000020:bji0<0000000<0[[oV0000000000004P3o
ool001L0oooo00<000000?ooo`3oool0;03oool00`000000ZKgX0:Vmj002000000030:Vmj0000000
ZKgX00<000000P2Y_NP010000000ZKgX0000000000020:Vmj0030000002Y_NP000000080000000<0
ZKgX0000002Y_NP00`0000000`2Y_NP0000000000003000000060:Vmj000000000000000002Y_NP0
00000P2Y_NP7000000030:Bmj`000000[/3W00<0000000@0W;[]0000002C^?00TkS`100000020:;2
l0d0000000D0SV>K0000002AHiP0TF>H0000000209EVV0080000002/M9@0[7BD0:adU0000000gZJJ
0000003d_942000000040:W7k`000000YLK`0:G6l080000000D0[<_`00000000000000000;36jP03
000000030;77j`000000[/K[00<0000000L0Z[oX00000000000000000:c2jP000000[<?[00<00000
00<0[<3X0000000000000`0000001`2[`NT00000000000000000ZKgX0000002[_^L00`0000000`2^
`>L0000000000003000000060:Vmj000000000000000002Y_NP000000P2Y_^T2000000040:[2j`00
0000[/CZ0:k4jP80000000<0[<;Y000000000000100000000`2V]nH0000000000003000000030:bm
iP00000000000080ZL;/00<000000:[2k00000000P0000000`2]`nT000000:fniP03000000060:jo
iP00000000000000002^_nH000004P3oool001H0oooo00<000000?ooo`3oool0;P3oool200000003
0:Vmj0000000000000<0000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP00000000000030000
0080ZKgX100000020:Vmj08000000P2Y_NP010000000ZKgX0000000000020:Vmj0030000002Y_NP0
00000080000000@0ZKcW00000029[^h000000P1kZ_4400000080[L7Y1@0000000`2G^>l0000009jo
l003000000040:;3l0000000TK_c096kl`T0000000D0SV>K0000002AHiP0TF>H0000000209EVV008
0000002/M9@0[7BD0:adU0000000gZJJ0000003d_946000000030:_7kP00000000000080//S[0P00
0000102`bN`000000;77j`2aan/200000080[/?Y0P000000102/`^T000000:c2jP2/`^X200000006
0:g3j@00000000000000002/`>T000000P2/`>P2000000040:c0j0000000ZKgX0:Vmj08000000P2[
_nP2000000040:g3j@000000[<3X0:c0j080000000@0ZKgW0000002Y_NP0ZKgX0`0000000`2Y`^`0
000000000003000000050:k2j@00000000000:bji00000000P2U]nH3000000030:JhiP000000[;_U
00<0000000@0[LCZ0000002Y`^`0ZL;/0P0000000`2Y`N/0000000000003000000060:ZkiP000000
00000000002^_nH000000P2^_nH200000140oooo000F0?ooo`800000<03oool5000000030:Vmj000
0000000000<0000000<0ZKgX0000000000000P2Y_NP00`000000ZKgX00000002000000030:Vmj000
0000ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP200000080
ZKgX1`0000000`23[>l000000:Bnk003000000040:_0j@000000WKW/09fik0@000000P2P`_050000
000309Nkl0000000T;ge00H000000P2>Hi/010000000TF>H0000002EIYP2000000<0[7BD00@00000
0=jVVP000000m;bA0`0000001@2Yanl00000000000000000[LS]00<0000000<0[l_^0000002`bN`0
0`0000001`2`bnd00000000000000000Zl?[0000002/`^T00`0000000`2]aN/00000000000020:_2
j`030000002/`>T000000080000000<0[L?Y0000000000000`0000001`2Y_^T00000000000000000
Zl;[0000002]`nT00`0000000`2[_nP000000:Vmi`03000000070:Zoj@00000000000000002Y`N/0
00000:[1jP03000000030:jkh`000000[;[T00<0000000@0YKSV0000002V^>H0Y[SV0P0000000`2^
a>X0000000000004000000050:W2j`00000000000:VkiP0000000P2Y^N@2000000040:bliP000000
[[oV0:joiPH00000403oool001H0oooo00<000000?ooo`3oool0;03oool3000000040?ooo`000000
ZKgX0:Vmj08000000P2Y_NP010000000ZKgX0000000000020:Vmj0030000002Y_NP0000000800000
00<0ZKgX0000002Y_NP00`0000000`2Y_NP0000000000003000000030:Vmj0000000000000<00000
00L0ZKgX00000000000000000:Nmj@000000YkWV00P0000000<0Y;o]0000002[`>T00`0000000`2P
^>T0000009fjk@03000000040:6okP000000X;o_0:2ok`@000000P2L_o450000000308iSV`000000
TF>H0080000000<0VfJB0000002/M9@00P2/M9@3000000030?BlT@0000000000008000000P2Yanl2
000000030:c;l0000000000000<000000P2^co42000000030:W6kP000000000000<0000000D0[LO]
00000000000000000:_4k005000000060:_3j`00000000000000002[`^/000000P2[`>T200000004
0:W2k0000000Zl;[0:_2j`80000000<0Zl7Z0000000000000`0000020:Zji@80000000@0[L7X0000
002Y`N/0ZL7[0P000000102Z^nH000000:jkh`2^^n<200000080[;_T1@0000001@2V_n/000000000
002^`nX000000080[L?Z0`0000000`2Y_NP000000:VkiP03000000030:bji0000000[;cV00<00000
00@0[[oV000000000000[;cV0P00000@0?ooo`005P3oool00`000000oooo0?ooo`0Y0?ooo`<00000
1@3oool2000000040:Vmj0000000ZKgX0:Vmj080000000<0ZKgX0000000000000`0000020:Vmj0@0
00000P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP010000000ZKgX000000000002
0:Vmj0040000002W_NT0000000000080X[SY00<0000009>`jP0000000P2=/Nh400000080YkkZ1000
00020:Fmj`D0000000<0Wk[/0000002N^^`00`0000001@2X`N`00000000000000000OE6C00@00000
0P2KIY801`000000[7BD0:adU0000000eiZB0000003d_9400`0000001@2Ta?000000000000000000
Z<[a008000000P2Yd_D5000000030:[8l000000000000080Y[k[00@000000:W4k@00000000000P2[
a^h2000000040:W3k@000000ZL;/0:W2k08000000P2Z`n`00`000000Zl;[00000002000000030:W2
k0000000000000<0000000<0Z/;[0000000000000P2Y_>P00`000000ZK[V00000002000000030:jn
i@000000[L7X00<0000000<0ZKgX0000000000000`0000001`2^_>@00000000000000000[<;Z0000
002U_>X00`0000000`2X_n/000000:k3jP03000000030:foi`000000000000<0000000<0Yk[W0000
000000000`0000001`2^`NP00000000000000000[;kW0000002/_>H00`00000?0?ooo`005P3oool0
0`000000oooo0?ooo`0W0?ooo`8000002P3oool4000000030:Vmj000000000000080ZKgX00<00000
0:Vmj00000000P0000000`2Y_NP000000:Vmj003000000030:Vmj0000000ZKgX00<0000000@0ZKgX
0000002Y_NP0ZKgX0P0000000`2Y_NP0000000000003000000040:>kjP000000X[SY0::hj@D00000
00<0UKK^0000002S_nd00`0000000`2R_>`000000:BljP03000000040:S0j`000000X[c[0::lj`@0
00000P2U_N/2000000030:c0j000000000000080OE6C00<0000008mLTP0000000P2KIY801`000000
[7BD0:adU0000000eiZB0000003d_940100000001@2Ub?800000000000000000Ym7f00<0000000<0
ZL[a0000002ZbO000`0000000`2X_>P0000000000003000000070:_6kP00000000000000002Xa^l0
00000:W3k@03000000030:W4k@000000000000<0000000L0ZL;/00000000000000000:W3k@000000
ZL?/00<0000000@0Z<3[0000002Y_>P0ZKcX0P000000102Y_NP000000:jni@2^_^D2000000070:o5
jP00000000000000002W_>T000000:Rki`03000000040:g8k@00000000000:c2jP80000000@0YkkY
0000002X_n/0Z;o[0P0000001P2^_nH00000000000000000[KoW00000080YkcX0P000000102U_^/0
00000:k4jP2^a>X2000000040:c1j@000000[;kW0:bni`80000000@0ZKgX00000000000000003P3o
ool001D0oooo0P00000V0?ooo`<000003@3oool010000000ZKgX0000000000020:Vmj0040000002Y
_NP0000000000080ZKgX00<000000:Vmj00000000P0000000`2Y_NP0000000000003000000030:Vm
j0000000000000<0000000<0ZKgX0000000000000P2Y_NP00`000000ZKgX000000040000000409jh
j`000000V;C[09Rdj`@000000P2P_>d400000080Y/3/00<000000:S0j`0000000P0000000`2Q_>`0
000009nkk003000000030:S1k0000000[<3X008000000P1mDI<00`000000SebB0000000209]VTP05
0000002/M9@0[7BD0000003GVY801`0000020:C?mP80000000<0Z<Wa0000000000000`0000020:Zj
i@80000000@0[<?[0000002[a>`0ZlC/0P0000000`2Zb_0000000000000300000080YlG_0P000000
102WbO8000000:S5kP2XaNh2000000030:W4k@000000000000<0000000<0Z<G^0000000000001000
00000`2V_^X0000000000003000000050;7=kP00000000000:W3k00000000P2W_>T200000080Y/C_
1@0000000`2X`N`0000000000003000000050:W2j`00000000000:joi`0000000P2]_nL300000003
0:Flj@000000YKk[00<0000000<0Zl?[0000000000000`000000102Y_NP000000000002Y_NP20000
00h0oooo000E0?ooo`030000003oool0oooo0280oooo0`00000A0?ooo`030000002Y_NP0000000@0
000000<0ZKgX0000000000000`0000020:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y
_NP000000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000X;[/0000
00040000000309bejP000000W;O/00<0000000<0X;[[0000002O_>d01@0000020:Jok0@000000P2O
_>d600000080OE6C00<0000008mLTP0000000P2KIY801`000000[7BD0:adU0000000eiZB0000003f
^8H00`0000001@2Rc?D00000000000000000YlWa008000000P2Y^ND00`000000ZKWU000000020000
00030:c3j`000000[<?[00<0000000<0[=3c0000000000000P2VbO85000000030:C;m00000000000
00<0000000D0YLC`000000000000Yl_b000000020:S8l@8000000P2S`o000`000000Y<3]00000002
000000030:;:m@000000000000<0000000<0Z/W`0000000000000`0000001`2T`Nh0000000000000
0000YlC^0000002XaNl00`0000000`2U`nl0000000000003000000030:G0k0000000[[oW00<00000
00<0[L?Z0000000000000`0000001`2W_n/00000000000000000ZL;/0000002Y_nX00`0000000`2Y
_NP000000:Vmj002000000h0oooo000E0?ooo`800000803oool3000001D0oooo00D000000:Vmj02Y
_NP000000:Vmj00200000080ZKgX00<000000:Vmj00000000P0000000`2Y_NP000000:Vmj0030000
00030:Vmj0000000ZKgX00<0000000<0ZKgX0000000000000`0000000`2Y_NP00000000000030000
000409jhj`000000VkK[09^fj`@000000P2P^>T400000080X[g/00<000000:G0k@0000000P000000
0`2S_^d000000:6kk003000000030::okP000000YL7]00<000000P1mDI<00`000000SebB00000002
09]VTP070000002/M9@0[7BD0000003GVY8000000?JhQP0400000080YlOa0P000000102Y^^H00000
0:Vii@2Y^ND2000000030:_3j`000000000000L0000000L0Y/gd00000000000000000:?9l`000000
X/[d00<0000000<0X/Oc0000000000000`0000000`2Ra_<0000000000003000000030:C6l@000000
000000<0000000L0WlGc00000000000000000:;8l`000000Y<Wc00<0000000<0Y<3]0000002T`>d0
0`0000000`2W`^d0000000000003000000070:C1k@00000000000000002V`nh000000:?3l0050000
00060:g8k@00000000000000002Y`N/000000P2W_NT2000000030:W2k0000000000000<0000000<0
Ykk[0000000000000`0000000`3oool000000?ooo`0=0?ooo`005@3oool00`000000oooo0?ooo`0L
0?ooo`<000006@3oool010000000ZKgX0000000000020:Vmj0040000002Y_NP0000000000080ZKgX
100000020:Vmj0D0000000<0ZKgX0000000000000P2Y_NP010000000ZKgX0000000000020:Vmj003
0000002Y_>L0000000@0000000<0V[CZ0000002O]^P00`0000000`2S^^T000000:>kjP0500000080
Xko]100000020::nk@@0000000<0Y<7^0000000000000P1mDI<00`000000SebB0000000209]VTP07
0000002/M9@0[7BD0000003GVY8000000?JhQP02000000050:S5k`00000000000000002Y_>L01@00
00000`2Y`^`00000000000020:3Po080000000<0W]Ck0000000000000`0000000`2Ta_8000000000
0003000000070:?7l`00000000000000002S_^d0000009o0l003000000030:G5l0000000000000<0
000000<0Xkk/0000000000000`0000000`2TaO40000000000003000000030:Fnk0000000000000<0
000000H0YL3]00000000000000000:W2k00000020:S2k080000000<0Yl7]0000000000000`000000
0`2P^^/0000000000003000000030:S6k`000000000000L0000000@0ZL;/0000002W`N`0Yl7/0P00
00060?ooo`030000003oool0oooo00`0oooo0000103oool000000000000000030?ooo`<00000103o
ool2000000D0oooo00<000000?ooo`3oool06@3oool3000001d0oooo00<000000:Vmj00000001000
00001`2Y_NP00000000000000000ZKgX0000002Y_NP00`000000102Y_NP000000:Vmj02Y_NP20000
00040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P000000102X^nL0000009fe
j@2M]NT400000080XKSY00@000000:>jj@00000000000P2U_>X00`000000YKk[0000000200000003
0::nk@000000X;k^00<0000000<0XL?a0000002R`o001000000207eAT`030000002?G980000000<0
VfJB0P0000020=NJTP030000003f^8H000000080000000L0Zl3Y00000000000000000:K1k@000000
Yl;/00<0000000D0WMom00000000000000000:3Gn`02000000040:2lk@000000X/;`0:;2l0800000
00<0YlG_0000000000000`0000020:FmjP@000000P2U`Nh2000000040:Rmj0000000YKcZ0:FljP80
000000@0Y[o[0000002U`Nh0YL7^0P000000102X_NP000000:FljP2U_>X2000000030:Joj`000000
000000<000000P2V_n/5000000050:W2k000000000000:Vmj00000000P2X_NP2000000040:FljP00
0000YL7]0:G1k@80000000@0YKcY0000002U_^/0YKk[0P000000102Y`^`000000:W2k02Y`^`30000
00T0oooo00<000000?ooo`3oool02`3oool00080oooo00D000000?ooo`3oool0oooo000000030?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F
0?ooo`<000008@3oool01@000000ZKgX0:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`00
00000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`00
00000`2X_NP00000000000030000000309bdj0000000V[?Z00D0000000<0Y;cZ0000000000000`00
00020:RojP@000000P2P_^h400000080Wl7`0P00000207eAT`040000002?G980SebB00000080VfJB
0P0000020=NJTP040000003f^8H000000:g5k08000000P2W`^d<000000030:Flj@000000000000<0
000000<0Y/;]0000000000000P2Y_NP00`000000Z;gX00000002000000030:Nmj@000000Y[o[00<0
000000<0ZKgX0000002X_NP00`0000000`2W_NT0000000000003000000030:Vmj0000000000000<0
000000<0YkgY0000000000000P2X_NP00`000000YKcZ00000002000000030:Noj`000000ZL;[00<0
000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:FljP03000000030:Vmj0000000000000<0
000000<0Yko[0000000000000`00000<0?ooo`030000003oool0oooo00/0oooo00020?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool20000
01D0oooo0`00000U0?ooo`040000002Y_NP0000000000080ZKgX100000020:Vmj0@000000P2Y_NP2
000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P000000102V_>T00000
0:Jji`2V^^L400000080W;CY00<000000::jjP0000000P0000000`2T_>/000000:NnjP0300000003
0:S0j`000000Xkc[00<0000000<0Y[k[0000002R`>l00`0000001@2P_^h000000000001mDI<00000
0080SebB00<0000009]VTP2KIY800P0000000`3GVY8000000?JhQP03000000050:O5k`0000000000
0000002ScOH00P0000001P2/do@00000000000000000[L7X00000080ZKgX0P000000102W_NT00000
0:Fnj`2U_^/2000000040:Vmj0000000ZKgX0:Vmj080000000<0Z;gX0000000000000`0000000`2Y
_NP0000000000003000000070:Vmj000000000000000002Y_NP000000:Vmj003000000030:Vmj000
0000ZKgX00<0000000@0ZKgX0000002X_NP0Z;gX0P000000102W_NT000000:Noj`2W_n/200000003
0:Vmj0000000000000<0000000<0ZKgX0000000000000`0000001`2Y_NP00000000000000000ZKgX
0000002W_NT00`00000A0?ooo`030000003oool0oooo00/0oooo00020?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000001@0oooo0P00
000Y0?ooo`030000002Y_NP000000080000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vm
j003000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000000000000`0000000`2Y_NP000000000
0003000000030:>hj0000000WK;V00D000000P2T^nX400000080Yl7/100000020:JmjP@000000P2T
_>X40000000507eAT`000000SebB08mLTP0000000P2KIY82000000030=NJTP000000m[R600@00000
00D0Y<Sc00000000000000000:_>lP0200000080//OY00<000000:g1j00000000P0000000`2Y_NP0
000000000003000000030:Vmj0000000000000<0000000D0ZKgX000000000000ZKgX000000020:Vm
j080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00@0
00000:Vmj000000000000P2Y_NP5000000030:Vmj0000000000000<0000000D0ZKgX000000000000
ZKgX000000020:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP2
000001@0oooo00<000000?ooo`3oool02`3oool00080oooo00@000000?ooo`3oool0oooo10000003
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03`3oool3000002`0oooo0P00
00000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`00
00000`2Y_NP00000000000020:Vmj0040000002Y_NP0000000000080ZKgX00<000000:>ljP000000
100000000`2Q]^L000000:6hj003000000030:FljP000000YKk[00<0000000<0Y[o[0000002V_^/0
0`0000000`2X_NT000000:Vmj003000000060:NnjP00000000000000001mDI<000000P2?G9800`00
0000VfJB09]VTP02000000030=NJTP000000m[R60080000000<0YlG_0000000000000P2Yb_420000
00030;3:k@000000000000<0000000L0ZkoX00000000000000000:Vmj0000000ZKgX00<0000000<0
ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000ZKgX00<0000000<0
ZKgX0000000000000`0000000`2Y_NP0000000000003000000070:Vmj000000000000000002Y_NP0
00000:Vmj003000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP0
000000000003000000030:Vmj0000000000000<000005P3oool00`000000oooo0?ooo`0;0?ooo`00
00<0oooo0000000000000`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000<0
oooo0P00000=0?ooo`<00000<@3oool300000080ZKgX0P000000102Y_NP000000:Vmj02Y_NP20000
00040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP000000000
00030000000409nij`000000WKKZ09ffjP@000000P2T_>X400000080Z;kY100000020:BljP@00000
0P2Y_nT50000000507eAT`000000SebB08mLTP0000000P2KIY82000000030=NJTP000000m[R600<0
000000D0ZlS_00000000000000000:g<l00200000080[<O]00@000000:g4j`00000000000P2Y_NP0
10000000ZKgX0000000000020:Vmj0@000000P2Y_NP400000080ZKgX100000020:Vmj080000000@0
ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vm
j080000000<0ZKgX0000000000000`0000000`2Y_NP0000000000003000000070:Vmj00000000000
0000002Y_NP000000:Vmj003000001/0oooo00<000000?ooo`3oool02`3oool00080oooo00@00000
0?ooo`3oool0oooo1@0000030?ooo`800000103oool00`000000oooo0?ooo`090?ooo`<00000=03o
ool00`000000ZKgX00000002000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000000000000`00
00000`2Y_NP0000000000003000000030:Vmj000000000000080ZKgX00<000000:Vmi`0000001000
00000`2J]^/000000::kjP03000000030:BljP000000YkgY00<0000000<0ZKgX0000002V_>T00`00
00000`2T_N/000000:RnjP03000000030:W2k0000000ZL;/0080000000D0OE6C0000002?G980SebB
0000000209]VTP80000000<0eiZB0000003f^8H0100000020:g=l@80000000<0ZlS_000000000000
0`0000000`2Y_NP0000000000003000000070:Vmj000000000000000002Y_NP000000:Vmj0030000
00030:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj0030000
00030:Vmj0000000000000<0000000<0ZKgX0000000000000`0000001@2Y_NP000000000002Y_NP0
00000080ZKgX0P000000102Y_NP000000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj0800000
0P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo000D0?ooo`030000003o
ool0oooo00H0oooo0`00000h0?ooo`80000000<0ZKgX0000000000000`0000000`2Y_NP000000000
00020:Vmj0060000002Y_NP000000000002Y_NP000000P2Y_NP2000000040:Vmj0000000ZKgX0:Vm
j080000000@0Z;_W0000002M]^T0WKKY100000020:>kjP@000000P2X_NP400000080YKg[10000002
0:S2k0H0000000D0OE6C0000002?G980SebB0000000209]VTP050000003GVY80eiZB0000003f^8H0
0P0000001@2^cO000000000000000000[<[_0080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y
_NP000000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0ZKgX0000000000000`00
00000`2Y_NP0000000000003000000030:Vmj0000000000000<0000000L0ZKgX0000000000000000
0:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj00300000003
0:Vmj0000000000000<0000000<0ZKgX0000000000000`0000040?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool02P3oool001@0oooo00<000000?ooo`3oool00`3oool3000003d0oooo
00<000000:Vmj00000000P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0ZKgX00000000
00000`0000000`2Y_NP0000000000003000000030:Vmj0000000000000<0000000<0WkGX0000002M
]^X00`0000000`2T^nT000000:BljP03000000030:Rnj@000000ZKoY00<0000000<0YL7]0000002T
`>h00`0000000`2X`>/000000:W1j`0300000080OE6C00<0000008mLTP0000000P2KIY801@000000
eiZB0=NJTP000000m[R600<0000000L0[/__00000000000000000:^oj0000000ZKgX00<0000000<0
ZKgX0000000000000`0000000`2Y_NP0000000000003000000050:Vmj000000000000:Vmj0000000
0P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y
_NP000000:Vmj02Y_NP2000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`000000
1`2Y_NP00000000000000000ZKgX0000002Y_NP00`00000:0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool02P3oool001<0oooo0P0000020?ooo`<00000@@3oool4000000030:Vmj000
0000000000<0000000<0ZKgX0000000000000P2Y_NP010000000ZKgX0000000000020:Vmj0060000
002Y_NP000000000002V_>T000000P2V^^L400000080XKKW100000020:Blj`040000002X_^T00000
00000080ZL;/100000020:Bok@@000000P2Y_NP01P000000OE6C07eAT`000000SebB00000080VfJB
00<000000=NJTP3GVY800`0000000`2^b^h00000000000020:k2j@@000000P2Y_NP2000000040:Vm
j0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP000000:Vmj0030000
00030:Vmj0000000000000<0000000<0ZKgX0000000000000`0000000`2Y_NP00000000000030000
00050:Vmj000000000000:Vmj00000000P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000@0
ZKgX0000002Y_NP0ZKgX0P00000>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
2P3oool001<0oooo100000150?ooo`060000002Y_NP000000000002Y_NP000000P2Y_NP200000004
0:Vmj0000000ZKgX0:Vmj080000000<0ZKgX0000000000000`0000000`2Y_NP00000000000030000
00030:>hj0000000X[?U00<0000000<0Y[SV0000002U^nT01@0000001`2X`N`00000000000000000
ZL7[0000002U_n`00`0000000`2T_>X000000:Rmj@0400000080OE6C00<0000008mLTP0000000P2K
IY800`000000eiZB0=NJTP04000000070:o5jP00000000000000002[`NT000000:Znj00300000003
0:Vmj0000000ZKgX00<0000000<0ZKgX0000000000000`0000000`2Y_NP000000000000200000080
ZKgX0P000000102Y_NP000000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0ZKgX
0000002Y_NP00`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0000000<0ZKgX
0000000000000`00000A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02P3oool0
01<0oooo0P0000180?ooo`030000002Y_NP0000000@0000000<0ZKgX0000000000000`0000000`2Y
_NP00000000000020:Vmj0040000002Y_NP0000000000080ZKgX00<000000:>ljP0000000`000002
0:Fei0040000002V^>H0000000000080Y[cY100000020:W0j`@000000P2V_>T4000000040:Rnj@00
0000000000000080OE6C00<0000008mLTP0000000P2KIY800`000000eiZB0=NJTP0500000080[<C[
100000000`2Y_NP0000000000003000000070:Vmj000000000000000002Y_NP000000:Vmj0030000
00030:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP00000000000030000
00030:Vmj00000000000008000000P2Y_NP400000080ZKgX0P0000000`2Y_NP000000:Vmj0030000
01H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0:0?ooo`005@3oool00`000000
oooo0?ooo`160?ooo`050000002Y_NP0ZKgX0000002Y_NP00P0000020:Vmj0060000002Y_NP00000
0000002Y_NP000000P2Y_NP2000000030:Vmj0000000000000<0000000<0WkW[0000002M]^T01@00
00001`2Z^nH00000000000000000Z;gX0000002W_^X00`0000000`2Y_NP000000:Vmj00300000003
0:Jlj@000000Y;cZ008000000P2X`N`02`000000OE6C07eAT`000000SebB0000002KIY8000000;b4
V0000000eiZB00<0000000L0[LS]00000000000000000:Vmj0000000ZKgX008000000P2Y_NP01000
0000ZKgX0000000000020:Vmj0050000002Y_NP000000000002Y_NP01@0000000`2Y_NP000000000
0003000000070:Vmj000000000000000002Y_NP000000:Vmj003000000030:Vmj0000000ZKgX00<0
000000<0ZKgX0000002Y_NP00`0000000`2Y_NP0000000000002000001X0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0:0?ooo`005P3oool00`000000oooo0?ooo`160?ooo`@00000
00<0ZKgX0000000000000`0000000`2Y_NP0000000000003000000030:Vmj000000000000080ZKgX
00<000000:Vmi`000000100000000`2I]>X000000:Nii@0200000080[;gV00@000000:Rmj0000000
00000P2Y_NP400000080ZKgX100000000`2U_^/00000000000030000000407eAT`000000SebB08mL
TP80000000<0_8BH0000003GVY80100000000`2Y_NP0000000000003000000030:Vmj00000000000
00<0000000<0ZKgX0000000000000`0000000`2Y_NP00000000000020:Vmj0040000002Y_NP00000
00000080ZKgX00H000000:Vmj000000000000:Vmj00000020:Vmj080000000<0ZKgX000000000000
0`0000000`2Y_NP0000000000003000000040:Vmj00000000000000001l0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0:0?ooo`005`3oool00`000000oooo0?ooo`160?ooo`040000
002Y_NP0000000000080ZKgX00@000000:Vmj000000000000P2Y_NP01@000000ZKgX000000000000
ZKgX00D0000000@0ZK_W0000002L]NX0W;GZ100000000`2Y_>L0000000000003000000070:Znj000
000000000000002Y_NP000000:Vmj003000000030:Vmj0000000Y[cY008000000P2W_NT01@000000
ZL3[0000001mDI<000000080SebB0P000000102lQ9P000000000003f^8H400000080ZKgX00H00000
0:Vmj000000000000:Vmj00000020:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP0
000000000003000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`0000001@2Y_NP0
00000000002Y_NP000000080ZKgX0P000000102Y_NP000000:Vmj02Y_NP200000280oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`00603oool2000004L0oooo00<000000:Vm
j0000000100000000`2Y_NP0000000000003000000030:Vmj000000000000080ZKgX00<000000:Vm
j0000000100000000`2K]NX0000009Vej`03000000030:[6kP000000[LC[008000000P2Y_^T40000
0080ZKgX100000000`2X_>P00000000000040000000407eAT`000000SebB08mLTP80000000@0_8BH
000000000000m[R60P000000102Z_^P000000:Vmj02Y_NP2000000030:Vmj0000000000000<00000
00<0ZKgX0000000000000`0000001@2Y_NP000000000002Y_NP000000080ZKgX0P000000102Y_NP0
00000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0ZKgX0000000000000`000000
0`2Y_NP0000000000003000002D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`150?ooo`80000000<0ZKgX0000002Y_NP00`0000000`2Y
_NP000000:Vmj00200000080ZKgX00H000000:Vmj000000000000:Jkj00000020:Jji`@000000P2J
^^h4000000070:S1k000000000000000002X_NP000000:Vmj003000000030:Vnj@000000ZKgX0080
00000P2Y^^D00`000000Z[_V0000000300000080SebB0P000000102lQ9P000000000003f^8H60000
00050:Vmj000000000000:Vmj00000000P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0
ZKgX0000002Y_NP00`0000000`2Y_NP0000000000003000000030:Vmj0000000000000<0000000D0
ZKgX000000000000ZKgX000000020:Vmj0800000:`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo04H0oooo0`0000020:Vmj0@0000000<0
ZKgX0000000000000`0000000`2Y_NL0000000000003000000030:BhiP000000000000<0000000<0
Xkc[0000000000000P0000020:BljP@000000P2Y_^T4000000030:Rnj@000000000000<0000000@0
[;kW00000000000000000P2?G98010000000_8BH0;b4V02lQ9P3000000040:Vmj0000000ZKgX0:Vm
j080000000<0ZKgX0000000000000`0000000`2Y_NP0000000000003000000030:Vmj00000000000
008000000P2Y_NP2000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y
_NP000000:Vmj003000002h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?oo
o`00703oool00`000000oooo0?ooo`150?ooo`030000002Y_NP000000080000000<0ZKgX0000002Y
_NP00`0000000`2Y_NP000000:Vmj00200000080ZK_W00H000000:FhiP00000000000:Bhi`000002
0:Bgi`80000000<0Z[_V0000002U_>T00`0000000`2T_N/000000:Rnj@03000000030:W2k0000000
Z<;/008000000P2S_N`00`000000Z[gW000000040000000308mLTP000000000000<0_8BH1`000000
1@2Y_NP000000000002Y_NP000000080ZKgX0P0000000`2Y_NP000000:Vmj003000000030:Vmj000
0000ZKgX00<0000000<0ZKgX0000000000000P0000020:Vmj0@0000000<0ZKgX0000000000000`00
000a0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool001d0oooo00<00000
0?ooo`3oool0A@3oool2000000030:Vmj00000000000008000000P2Y_NP4000000030:Vmj0000000
000000<0000000<0YKWW0000000000000`0000000`2Y^ND000000000000200000080Y[gZ10000002
0:S2k0@0000000<0Y<3]0000000000000`0000000`2Zbo4000000000000300000003099VV`000000
_8BH0080_8BH0P0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0000000<0ZKgX
0000000000000P0000020:Vmj0@0000000L0ZKgX00000000000000000:Vmj0000000ZKgX00<00000
00<0ZKgX0000002Y_NP00P00000g0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
2@3oool001h0oooo0P0000170?ooo`040000002Y_NP000000:Vmj0<0000000<0ZKgX0000002Y_NP0
0P0000020:Jlj@060000002V^nP000000000002T_>X000000P2T^^T2000000030:^ki@000000[;gV
00<0000000<0YL7]0000002T`Nh00`0000000`2X`>/000000:W1j`0200000080Xk_Z10000000102/
b^l00000000000000002099VV`040000002lQ9P0_8BH0;b4V0D000000P2Y_NP2000000030:Vmj000
0000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj00200000080ZKgX1000
00000`2Y_NP0000000000003000003X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`090?ooo`00803oool00`000000oooo0?ooo`150?ooo`<000000P2Y_NP4000000030:Vmj0000000
000000<0000000<0Y;cZ0000000000000`0000000`2Q^NX000000:^ki@03000000030:k3j@000000
0000008000000P2T_nd4000000070:ZkiP00000000000000002Y_NP000000:O2k@02000000030:k3
j@00000000000080TVJK00@000000;b4V02lQ9P0_8BH0`0000001@2Y_NP00000000000000000ZKgX
00@000000P2Y_NP4000000030:Vmj0000000000000<0000000L0ZKgX00000000000000000:Vmj000
0000ZKgX00800000@03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo000Q
0?ooo`030000003oool0oooo04@0oooo00<000000:Vmj00000000P0000000`2Y_NP000000:Vmj003
000000030:Vmj00000000000008000000P2T^nX00`000000XK[[0000000300000080[<;Z0P000000
0`2^`^P0000000000003000000030:FhiP000000ZKWU008000000P2/_NH4000000030:k3j@000000
0000008000000P2BIY/01@000000_8BH0;b4V0000000lkjF00<000000P2Y_NP2000000030:Vmj000
0000ZKgX00<0000000<0ZKgX0000002Y_NP00P0000020:Vmj0050000002Y_NP000000000002Y_NP0
1@0000120?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool00280oooo00<0
00000?ooo`3oool0A03oool2000000030:Vmj00000000000008000000P2Y_NP2000000030:Vmj000
0000YKcZ00D0000000<0XKOX0000000000000`0000001@2]`NP000000000002^^^<000000080Y[SV
100000001`2[^nD00000000000000000[/K/0000002^a>X00P0000020:k3j@8000000P2BIY/01`00
0000_8BH0;b4V0000000lkjF0000002Y_NP00`0000000`2Y_NP0000000000002000000030:Vmj000
0000000000<0000000<0ZKgX0000000000000`0000000`2Y_NP00000000000180?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0203oool002<0oooo0P0000160?ooo`040000002Y_NP0
00000:Vmj0<0000000<0ZKgX0000000000000P0000020:BljP@0000000@0YKWW0000002U^nT0YK_Y
0P0000000`2]^^<000000:jjh`03000000030:JiiP000000YKWW008000000P2/and4000000030:k4
jP000000000000<000000P2BIY/00`000000_8BH0;b4V004000000070:Vmj000000000000000002Y
_NP000000:Vmj00200000080ZKgX00H000000:Vmj000000000000:Vmj00000020:Vmj0800000B`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0
oooo04@0oooo100000001P2Y_NP000000000002Y_NP000000:Vmj0<0000000<0X[[Z0000002Q^NT0
1@0000000`2Y^nL000000000000200000080[[_S100000001@2T`>d00000000000000000ZlK^00@0
00000P2]`nX3000000<0TVJK00D000000;b4V000000000000:Vmj00200000080ZKgX100000000`2Y
_NP0000000000003000000030:Vmj0000000000000<00000C@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo04@0oooo100000000`2Y_NP0
000000000003000000030:Vmi`0000000000008000000P2P]^P01`000000Z;gX000000000000Y[_X
0000002]^n@00`0000000`2^`NP000000000000200000080Z/;[0P0000000`2Z`n`000000:W2k003
000000040:_2j`000000000000000080TVJK0P000000103c_YH000000000002Y_NP3000000030:Vm
j0000000ZKgX008000000P2Y_NP010000000ZKgX00000000001C0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0203oool002L0oooo00<000000?ooo`3oool0A03oool01P000000ZKgX
000000000000ZKgX00000080ZKgX0P0000000`2Y^ND000000:6bi005000000030:Jmj@0000000000
00<0000000H0[L?Z000000000000[<7Y0000002Z_nP3000000030:k6k00000000000008000000P2Y
`^/2000000030:Vmj000000000000080TVJK0P000000103c_YH000000000000000020:Vmj0@00000
00<0ZKgX0000000000000`00001F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
203oool002P0oooo00<000000?ooo`3oool0A03oool00`000000ZKgX00000004000000030:Vmj000
00000000008000000P2U]N@01@000000YKWW000000000000Y<7^00D0000000<0Zl;[000000000000
0`000000102]and000000000002[aN`5000000030:Vmj00000000000008000000P2BIY/200000003
0?>nUP000000ZKgX00<0000000<0ZKgX0000002Y_NP00P00001L0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0203oool002T0oooo0P0000150?ooo`050000002Y_NP0ZKgX0000002Y
_NP00P0000000`2T^nX000000:Bhi`05000000030:W2k000000000000080Y<3]00H000000:C0kP00
000000000:Vmj00000020:[2j`80000000D0[<K]000000000000ZKgX000000020:Vmj080000000@0
ZKgX00000000000000000P2BIY/2000000040?>nUP00000000000:Vmj0D00000GP3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo000[0?ooo`030000003oool0oooo04<0oooo
100000000`2Y_NP00000000000030000000309njk000000000000080000000<0ZL7[000000000000
0`0000000`2T_>X0000000000003000000040:o3j@00000000000:^nj0D0000000<0ZKgX00000000
00000`000002099VV`030000003c_YH0lkjF00<00000I03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00L0oooo000/0?ooo`030000003oool0oooo04@0oooo0`0000000`2Y^nH00000
00000003000000030:Flj@000000ZL7[00<0000000<0ZK_V0000000000000P0000000`2T_>X00000
00000003000000050;;5j000000000000:Znj00000000P2Y_NP2000000030:Vmj000000000000080
000000@0TVJK000000000000lkjF0P00001W0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool002d0oooo00<000000?ooo`3oool0@`3oool00`000000ZKgX0000000200000003
0:Nki`000000YKSW00@000000P2Y^N@2000000030:bli@000000YKcY008000000P2T`>d01@000000
/LS[000000000000[/CZ00D0000000H0ZKgX000000000000ZKgX0000002Y_NP200000080YL?_0P00
001Y0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool002h0oooo0P000014
0?ooo`030000002V_NT0Y[gY00@0000000<0ZKgX0000000000000`0000000`2/^^@0000000000002
000000030:FljP000000000000<0000000@0[LO]000000000000ZKgX1@0000000`2Y_NP000000000
0003000000030?ooo`000000000000800000J@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00L0oooo000`0?ooo`030000003oool0oooo0480oooo0P0000000`2T_>X000000:BljP02
000000040:Jmj@000000Yk_X0:Nkj080000000<0[L?Y0000002^`NP00P0000020:Znj0@0000000L0
Z[kX00000000000000000:Vmj0000000ZKgX00800000M03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L0oooo000a0?ooo`030000003oool0oooo04<0oooo0`0000000`2T_>X00000
00000003000000030:Bnk000000000000080000000D0[<7Y00000000000000000:k3jP0400000080
Z[kX1000001g0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00380oooo
00<000000?ooo`3oool0@`3oool300000080YK[X100000000`2W_n/0000000000003000000060:W2
k000000000000:_3j`000000[<7Y0`00001l0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool003<0oooo00<000000?ooo`3oool0@P3oool00`000000YKSV0000000200000003
0:Nji`000000YkgY0080000000<0ZKoZ0000000000000`0000000`2Y`^`0000000000002000007l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`00=03oool2000004<0oooo
0P0000000`2W^>D0000000000002000000070:Vmj000000000000000002/`>P000000:W2k0020000
08@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`00=P3oool00`000000
oooo0?ooo`120?ooo`040000002Y_NP000000:Vmj08000000P2/_^L4000008L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`00=`3oool00`000000oooo0?ooo`120?ooo`<0
000000@0ZKgX0000000000000000R`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo000h0?ooo`030000003oool0oooo0480oooo0`00002?0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool003T0oooo0P0000120?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`00>`3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`00?03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0940oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`00?@3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`00?P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`00?`3oool2000003`0oooo00<000000?ooo`3oool0
U03oool01@000000oooo0?ooo`3oool0000000L0oooo00110?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0U03oool01@000000oooo0?ooo`3oool0000000L0oooo00120?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0U@3oool010000000oooo0?ooo`0000070?ooo`00
@`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`000000
1`3oool004@0oooo0P00000g0?ooo`030000003oool0oooo09H0oooo00@000000?ooo`3oool00000
1P3oool004H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2G0?ooo`030000003o
ool0000000H0oooo00170?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0V03oool2
000000H0oooo00180?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0U`3oool30000
00H0oooo00190?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0U03oool4000000T0
oooo001:0?ooo`800000<03oool00`000000oooo0?ooo`2A0?ooo`<000003@3oool004`0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`2=0?ooo`@00000403oool004d0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`290?ooo`@00000503oool004h0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`250?ooo`@00000603oool004l0oooo0P00000[0?ooo`03
0000003oool0oooo0880oooo0`00000L0?ooo`00D@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo07h0oooo1000000O0?ooo`00DP3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo07X0oooo1000000S0?ooo`00D`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo07H0oooo1000000W0?ooo`00E03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0780oooo1000000[0?ooo`00E@3oool2000002D0oooo00<000000?ooo`3oool0K`3oool3000002l0
oooo001G0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0J`3oool400000380oooo
001H0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0I`3oool4000003H0oooo001I
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0H`3oool4000003X0oooo001J0?oo
o`800000803oool00`000000oooo0?ooo`1P0?ooo`<00000?P3oool005`0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`1L0?ooo`@00000@@3oool005d0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1H0?ooo`@00000A@3oool005h0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1D0?ooo`@00000B@3oool005l0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1A0?ooo`<00000C@3oool00600oooo0P00000J0?ooo`030000003oool0oooo
04d0oooo1000001@0?ooo`00HP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04T0
oooo1000001D0?ooo`00H`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo
1000001H0?ooo`00I03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0480oooo0`00
001L0?ooo`00I@3oool2000001D0oooo00<000000?ooo`3oool0?P3oool4000005l0oooo001W0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0>P3oool4000006<0oooo001X0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0=P3oool4000006L0oooo001Y0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0<`3oool3000006/0oooo001Z0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0;`3oool4000006h0oooo001[0?ooo`8000003P3oool0
0`000000oooo0?ooo`0/0?ooo`@00000LP3oool006d0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0X0?ooo`@00000MP3oool006h0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0T0?ooo`@00000NP3oool006l0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0Q0?ooo`<00000OP3oool00700oooo0P0000090?ooo`030000003oool0oooo01d0oooo1000
00210?ooo`00LP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo10000025
0?ooo`00L`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo100000290?oo
o`00M03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo0`00002=0?ooo`00
M@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo1000002@0?ooo`00MP3o
ool2000000<0oooo00<000000?ooo`3oool02P3oool4000009@0oooo001h0?ooo`040000003oool0
oooo000000P0oooo1000002H0?ooo`00N@3oool00`000000oooo000000050?ooo`<00000W03oool0
07X0oooo0P0000000`3oool0000000000002000009l0oooo001k0?ooo`800000X`3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool009l0oooo0`00001n0?ooo`00X03oool00`000000
oooo0?ooo`1m0?ooo`00>P3oool3000000<0oooo0`0000030?ooo`<000000P3oool01@000000oooo
0000003oool000000080oooo0`0000040?ooo`8000000P3oool3000000<0oooo1@0000020?ooo`<0
0000203oool3000000@0oooo0`0000020?ooo`D0000000D0oooo00000000000000000?ooo`020000
0080oooo0P0000090?ooo`<000000`3oool300000080oooo0`0000040?ooo`<000000`3oool40000
0080oooo100000070?ooo`<000001@3oool2000000030?ooo`00000000000080000000@0oooo0000
00000000oooo0`0000040?ooo`8000000P3oool500000080oooo0`0000020?ooo`<0000000<0oooo
000000000000;@3oool003T0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3o
ool000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000002h0oooo000i0?ooo`060000003oool0oooo0?ooo`000000
oooo1@0000000`3oool000000?ooo`020?ooo`080000003oool000000?ooo`000000oooo0000003o
ool500000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`000000303oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0303oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo1@00
00020?ooo`<000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0/0?ooo`00>@3oool00`000000oooo00000004000000<0oooo00<0
00000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`040000003oool0oooo000000D0oooo0P0000050?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`060?ooo`<000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0
oooo0P0000030?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`070000003oool0oooo
0?ooo`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
1`3oool3000000<0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00@000000?ooo`3oool000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0/0?ooo`00>@3oool00`000000oooo
0?ooo`040?ooo`<000000`3oool300000080oooo0P0000000`3oool000000?ooo`020?ooo`<00000
0P3oool400000080oooo0P000000103oool000000000003oool3000000@0oooo0`0000090?ooo`04
0000003oool0oooo00000080oooo0`0000020?ooo`<000000`3oool400000080oooo100000090?oo
o`030000003oool0oooo0080oooo100000020?ooo`80000000<0oooo0000000000000P3oool30000
00<0oooo0P0000040?ooo`<000002@3oool00`000000oooo0?ooo`020?ooo`80000000@0oooo0000
00000000oooo100000030?ooo`<000000P3oool400000080oooo0`0000040?ooo`<000000P3oool4
000002l0oooo000i0?ooo`050000003oool0oooo0?ooo`0000006P3oool00`000000oooo0?ooo`0K
0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool02@3oool010000000oooo0?oo
o`00000L0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000503oool00`000000
oooo0?ooo`110?ooo`00>P3oool3000001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0=0?ooo`@000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo
0`00000K0?ooo`800000203oool5000001@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0j0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0700771, 0.0473795, \
0.00363043, 0.00363043}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9316024822911542`\)\), 
        ",", \(BackFocalLength \[Rule] 43.75324264754414`\), 
        ",", \(BackFocalPoint \[Rule] {153.25324264754414`, 0, 0}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] 0\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {109.5`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 5\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 5, 
            SurfaceNumber \[Rule] 2, ComponentNumber \[Rule] 3}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 50.17886731848154`\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {207.1154899597168`, 0, 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              
              TagBox[\(Move[
                  PlanoConvexLens[{f1, 100}, 50, 
                    9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                HoldForm], ",", 
              TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                HoldForm], ",", 
              TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                HoldForm], ",", 
              
              TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                    104}, {GraphicDesign \[Rule] Off}]\),
                HoldForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8719456015187742`, 
              12.028419839771795`}, {\(-0.019928708108396996`\), 
              0.8719456015187739`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
            HoldForm]}], ",", \(OpticalMedium \[Rule] Vacuum\), 
        ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"PointSpreadFunction", "\[Rule]", 
              RowBox[{"(", 
                
                TagBox[\(\[SkeletonIndicator]  
                    SurfaceGraphics  \[SkeletonIndicator]\),
                  False,
                  Editable->False], ")"}]}], "}"}]}], 
        ",", \(Plot2D \[Rule] False\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.2705121409329072`\), 
                  0.2705121409329072`}, {\(-0.2705121409329099`\), 
                  0.2705121409329099`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(SourceID \[Rule] 518\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0910321471583293`\), \
\(-0.8233477284578328`\)}, {\(-0.019928708108396996`\), \
\(-0.9316024822911542`\)}}\), 
        ",", \(TransverseMagnification \[Rule] \(-1.0910321471583293`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", \(WaveLength \[Rule] 0.532`\)}], 
      "}"}]], "Output",
  CellLabel->"Out[15]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
GPSF[sys3D, FindImagePoint->True, FocalFraction->0, Plot2D->False]\
\>", "Input",
  CellLabel->"In[16]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -93 0 ]
[.5 .82364 93 9 ]
[.1041 .21606 -24 -8.92748 ]
[.1041 .21606 0 .07252 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.58679 .02624 -15.3728 -9 ]
[.58679 .02624 2.62721 0 ]
[.74499 .06264 0 -6.19545 ]
[.74499 .06264 24 2.80455 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95162 .37907 0 -5.89608 ]
[.95162 .37907 18 3.10392 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01479 .32355 -12 -2.79174 ]
[.01479 .32355 0 6.20826 ]
[.0051 .38426 -18 -2.84327 ]
[.0051 .38426 0 6.15673 ]
[-0.00496 .44736 -18 -2.89705 ]
[-0.00496 .44736 0 6.10295 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Geometric Point Spread Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.11345 .22526 m
.11813 .22986 L
s
[(-0.2)] .1041 .21606 1 .98388 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.59438 .03695 m
.59817 .0423 L
s
[(0.2)] .58679 .02624 .70809 1 Mshowa
.125 Mabswid
.16898 .20352 m
.17173 .20634 L
s
.22573 .1813 m
.22842 .18417 L
s
.28374 .15858 m
.28638 .16151 L
s
.40374 .1116 m
.40624 .11463 L
s
.46582 .08729 m
.46825 .09038 L
s
.52935 .06241 m
.5317 .06557 L
s
.05912 .24654 m
.06197 .24925 L
s
.66096 .01088 m
.66315 .01415 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.73271 .06727 m
.72657 .06958 L
s
[(-0.2)] .74499 .06264 -1 .37677 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93909 .38296 m
.93282 .3849 L
s
[(0.2)] .95162 .37907 -1 .31024 Mshowa
.125 Mabswid
.76231 .11254 m
.75861 .1139 L
s
.79069 .15595 m
.78698 .15728 L
s
.81792 .19761 m
.8142 .1989 L
s
.86921 .27607 m
.86548 .27731 L
s
.89339 .31305 m
.88965 .31427 L
s
.91667 .34866 m
.91292 .34985 L
s
.70181 .02 m
.69814 .02142 L
s
.9607 .41602 m
.95694 .41716 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02706 .31889 m
.03319 .31657 L
s
[(50)] .01479 .32355 1 -0.37961 Mshowa
.01742 .37972 m
.02357 .37746 L
s
[(100)] .0051 .38426 1 -0.36816 Mshowa
.0074 .44295 m
.01358 .44075 L
s
[(150)] -0.00496 .44736 1 -0.35621 Mshowa
.125 Mabswid
.03451 .27187 m
.03818 .27045 L
s
.03267 .28349 m
.03634 .28208 L
s
.03081 .2952 m
.03449 .29379 L
s
.02894 .307 m
.03262 .3056 L
s
.02516 .33087 m
.02884 .32948 L
s
.02324 .34295 m
.02693 .34156 L
s
.02132 .35511 m
.02501 .35374 L
s
.01937 .36737 m
.02307 .366 L
s
.01544 .39217 m
.01914 .39082 L
s
.01346 .40472 m
.01716 .40337 L
s
.01145 .41736 m
.01515 .41603 L
s
.00943 .43011 m
.01314 .42878 L
s
.00535 .4559 m
.00906 .45459 L
s
.00328 .46895 m
.00699 .46764 L
s
.00119 .4821 m
.00491 .48081 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.663 .741 .908 r
.40025 .60008 .40509 .60458 .41322 .60215 .40839 .59763 Metetra
.663 .741 .908 r
.40839 .59763 .41322 .60215 .42137 .5997 .41656 .59517 Metetra
.673 .744 .904 r
.41656 .59517 .42137 .5997 .42956 .59683 .42476 .59249 Metetra
.673 .752 .91 r
.42476 .59249 .42956 .59683 .43778 .59394 .43299 .5898 Metetra
.663 .76 .922 r
.43299 .5898 .43778 .59394 .446 .59145 .44123 .5873 Metetra
.662 .76 .923 r
.44123 .5873 .446 .59145 .45426 .58897 .4495 .58481 Metetra
.671 .762 .919 r
.4495 .58481 .45426 .58897 .46253 .58649 .4578 .58213 Metetra
.673 .754 .912 r
.4578 .58213 .46253 .58649 .47083 .584 .46612 .57941 Metetra
.665 .743 .908 r
.46612 .57941 .47083 .584 .47916 .5815 .47446 .57687 Metetra
.664 .741 .908 r
.47446 .57687 .47916 .5815 .48751 .579 .48283 .57435 Metetra
.664 .741 .908 r
.48283 .57435 .48751 .579 .49589 .57648 .49123 .57182 Metetra
.664 .741 .908 r
.49123 .57182 .49589 .57648 .50429 .57396 .49965 .56929 Metetra
.664 .741 .908 r
.49965 .56929 .50429 .57396 .51272 .57143 .50809 .56674 Metetra
.664 .741 .908 r
.50809 .56674 .51272 .57143 .52118 .5689 .51657 .56419 Metetra
.664 .741 .908 r
.51657 .56419 .52118 .5689 .52966 .56635 .52506 .56163 Metetra
.664 .741 .908 r
.52506 .56163 .52966 .56635 .53817 .5638 .53359 .55907 Metetra
.664 .741 .908 r
.53359 .55907 .53817 .5638 .5467 .56124 .54214 .55649 Metetra
.664 .741 .908 r
.54214 .55649 .5467 .56124 .55526 .55867 .55072 .55391 Metetra
.664 .741 .908 r
.55072 .55391 .55526 .55867 .56385 .55609 .55932 .55132 Metetra
.664 .741 .908 r
.55932 .55132 .56385 .55609 .57247 .55351 .56796 .54872 Metetra
.664 .741 .908 r
.56796 .54872 .57247 .55351 .58111 .55092 .57661 .54611 Metetra
.664 .741 .908 r
.57661 .54611 .58111 .55092 .58977 .54832 .5853 .5435 Metetra
.664 .741 .908 r
.5853 .5435 .58977 .54832 .59847 .54571 .59401 .54087 Metetra
.664 .741 .908 r
.59401 .54087 .59847 .54571 .60719 .54309 .60275 .53824 Metetra
.664 .741 .908 r
.60275 .53824 .60719 .54309 .61594 .54047 .61152 .5356 Metetra
.664 .741 .908 r
.61152 .5356 .61594 .54047 .62472 .53783 .62032 .53295 Metetra
.664 .741 .908 r
.62032 .53295 .62472 .53783 .63352 .53519 .62914 .53029 Metetra
.664 .741 .908 r
.62914 .53029 .63352 .53519 .64235 .53254 .63799 .52763 Metetra
.664 .741 .908 r
.63799 .52763 .64235 .53254 .65121 .52989 .64687 .52496 Metetra
.664 .741 .908 r
.64687 .52496 .65121 .52989 .6601 .52722 .65578 .52227 Metetra
.664 .741 .908 r
.65578 .52227 .6601 .52722 .66902 .52454 .66471 .51958 Metetra
.664 .741 .908 r
.66471 .51958 .66902 .52454 .67796 .52186 .67368 .51688 Metetra
.664 .741 .908 r
.67368 .51688 .67796 .52186 .68694 .51917 .68267 .51418 Metetra
.664 .741 .908 r
.68267 .51418 .68694 .51917 .69594 .51647 .69169 .51146 Metetra
.664 .741 .908 r
.69169 .51146 .69594 .51647 .70497 .51376 .70074 .50874 Metetra
.664 .741 .908 r
.70074 .50874 .70497 .51376 .71403 .51104 .70982 .506 Metetra
.664 .741 .908 r
.70982 .506 .71403 .51104 .72311 .50832 .71893 .50326 Metetra
.664 .741 .908 r
.71893 .50326 .72311 .50832 .73223 .50558 .72806 .50051 Metetra
.664 .741 .908 r
.72806 .50051 .73223 .50558 .74138 .50284 .73723 .49775 Metetra
.664 .741 .908 r
.73723 .49775 .74138 .50284 .75055 .50008 .74643 .49498 Metetra
.664 .741 .908 r
.74643 .49498 .75055 .50008 .75976 .49732 .75565 .4922 Metetra
.664 .741 .908 r
.75565 .4922 .75976 .49732 .76899 .49455 .76491 .48941 Metetra
.664 .741 .908 r
.76491 .48941 .76899 .49455 .77826 .49177 .77419 .48662 Metetra
.664 .741 .908 r
.77419 .48662 .77826 .49177 .78755 .48898 .78351 .48381 Metetra
.664 .741 .908 r
.78351 .48381 .78755 .48898 .79688 .48619 .79286 .481 Metetra
.664 .741 .908 r
.79286 .481 .79688 .48619 .80623 .48338 .80223 .47818 Metetra
.664 .741 .908 r
.80223 .47818 .80623 .48338 .81562 .48057 .81164 .47534 Metetra
.664 .741 .908 r
.81164 .47534 .81562 .48057 .82503 .47774 .82108 .4725 Metetra
.664 .741 .908 r
.82108 .4725 .82503 .47774 .83448 .47491 .83054 .46965 Metetra
.664 .741 .908 r
.83054 .46965 .83448 .47491 .84395 .47206 .84004 .46679 Metetra
.664 .741 .908 r
.84004 .46679 .84395 .47206 .85346 .46921 .84957 .46392 Metetra
.664 .741 .908 r
.84957 .46392 .85346 .46921 .863 .46635 .85914 .46104 Metetra
.664 .741 .908 r
.85914 .46104 .863 .46635 .87257 .46348 .86873 .45815 Metetra
.664 .741 .908 r
.86873 .45815 .87257 .46348 .88217 .4606 .87835 .45526 Metetra
.662 .741 .908 r
.87835 .45526 .88217 .4606 .89181 .45771 .88801 .45238 Metetra
.655 .739 .912 r
.88801 .45238 .89181 .45771 .90147 .45481 .89773 .44968 Metetra
.655 .748 .919 r
.89773 .44968 .90147 .45481 .91117 .4519 .90747 .44695 Metetra
.662 .76 .923 r
.90747 .44695 .91117 .4519 .9209 .44898 .91723 .44402 Metetra
.662 .76 .923 r
.91723 .44402 .9209 .44898 .93066 .44608 .92701 .44108 Metetra
.653 .755 .925 r
.92701 .44108 .93066 .44608 .94052 .44359 .93686 .43836 Metetra
.654 .746 .918 r
.93686 .43836 .94052 .44359 .9504 .44108 .94674 .43561 Metetra
.663 .741 .908 r
.94674 .43561 .9504 .44108 .96026 .43812 .95663 .43264 Metetra
.663 .741 .908 r
.95663 .43264 .96026 .43812 .97016 .43516 .96655 .42965 Metetra
.663 .741 .908 r
.39538 .59555 .40025 .60008 .40839 .59763 .40354 .59308 Metetra
.663 .741 .908 r
.40354 .59308 .40839 .59763 .41656 .59517 .41173 .59061 Metetra
.664 .741 .908 r
.41173 .59061 .41656 .59517 .42476 .59249 .41994 .58812 Metetra
.663 .75 .915 r
.41994 .58812 .42476 .59249 .43299 .5898 .42817 .58563 Metetra
.662 .759 .922 r
.42817 .58563 .43299 .5898 .44123 .5873 .43643 .58313 Metetra
.662 .76 .923 r
.43643 .58313 .44123 .5873 .4495 .58481 .44472 .58063 Metetra
.68 .764 .915 r
.44472 .58063 .4495 .58481 .4578 .58213 .45303 .57774 Metetra
.682 .756 .908 r
.45303 .57774 .4578 .58213 .46612 .57941 .46138 .57479 Metetra
.666 .743 .908 r
.46138 .57479 .46612 .57941 .47446 .57687 .46974 .57221 Metetra
.664 .741 .908 r
.46974 .57221 .47446 .57687 .48283 .57435 .47812 .56968 Metetra
.664 .741 .908 r
.47812 .56968 .48283 .57435 .49123 .57182 .48653 .56713 Metetra
.664 .741 .908 r
.48653 .56713 .49123 .57182 .49965 .56929 .49497 .56459 Metetra
.664 .741 .908 r
.49497 .56459 .49965 .56929 .50809 .56674 .50344 .56203 Metetra
.664 .741 .908 r
.50344 .56203 .50809 .56674 .51657 .56419 .51193 .55946 Metetra
.664 .741 .908 r
.51193 .55946 .51657 .56419 .52506 .56163 .52044 .55689 Metetra
.664 .741 .908 r
.52044 .55689 .52506 .56163 .53359 .55907 .52898 .55431 Metetra
.664 .741 .908 r
.52898 .55431 .53359 .55907 .54214 .55649 .53755 .55172 Metetra
.664 .741 .908 r
.53755 .55172 .54214 .55649 .55072 .55391 .54615 .54912 Metetra
.664 .741 .908 r
.54615 .54912 .55072 .55391 .55932 .55132 .55477 .54651 Metetra
.664 .741 .908 r
.55477 .54651 .55932 .55132 .56796 .54872 .56342 .5439 Metetra
.664 .741 .908 r
.56342 .5439 .56796 .54872 .57661 .54611 .5721 .54128 Metetra
.664 .741 .908 r
.5721 .54128 .57661 .54611 .5853 .5435 .5808 .53865 Metetra
.664 .741 .908 r
.5808 .53865 .5853 .5435 .59401 .54087 .58953 .53601 Metetra
.664 .741 .908 r
.58953 .53601 .59401 .54087 .60275 .53824 .59829 .53336 Metetra
.664 .741 .908 r
.59829 .53336 .60275 .53824 .61152 .5356 .60708 .5307 Metetra
.664 .741 .908 r
.60708 .5307 .61152 .5356 .62032 .53295 .61589 .52804 Metetra
.664 .741 .908 r
.61589 .52804 .62032 .53295 .62914 .53029 .62473 .52537 Metetra
.664 .741 .908 r
.62473 .52537 .62914 .53029 .63799 .52763 .6336 .52269 Metetra
.664 .741 .908 r
.6336 .52269 .63799 .52763 .64687 .52496 .6425 .52 Metetra
.664 .741 .908 r
.6425 .52 .64687 .52496 .65578 .52227 .65143 .5173 Metetra
.664 .741 .908 r
.65143 .5173 .65578 .52227 .66471 .51958 .66038 .51459 Metetra
.664 .741 .908 r
.66038 .51459 .66471 .51958 .67368 .51688 .66937 .51188 Metetra
.664 .741 .908 r
.66937 .51188 .67368 .51688 .68267 .51418 .67838 .50916 Metetra
.664 .741 .908 r
.67838 .50916 .68267 .51418 .69169 .51146 .68742 .50642 Metetra
.664 .741 .908 r
.68742 .50642 .69169 .51146 .70074 .50874 .69649 .50368 Metetra
.664 .741 .908 r
.69649 .50368 .70074 .50874 .70982 .506 .70559 .50093 Metetra
.664 .741 .908 r
.70559 .50093 .70982 .506 .71893 .50326 .71472 .49817 Metetra
.664 .741 .908 r
.71472 .49817 .71893 .50326 .72806 .50051 .72387 .49541 Metetra
.664 .741 .908 r
.72387 .49541 .72806 .50051 .73723 .49775 .73306 .49263 Metetra
.664 .741 .908 r
.73306 .49263 .73723 .49775 .74643 .49498 .74228 .48984 Metetra
.664 .741 .908 r
.74228 .48984 .74643 .49498 .75565 .4922 .75152 .48705 Metetra
.664 .741 .908 r
.75152 .48705 .75565 .4922 .76491 .48941 .7608 .48425 Metetra
.664 .741 .908 r
.7608 .48425 .76491 .48941 .77419 .48662 .77011 .48143 Metetra
.664 .741 .908 r
.77011 .48143 .77419 .48662 .78351 .48381 .77944 .47861 Metetra
.664 .741 .908 r
.77944 .47861 .78351 .48381 .79286 .481 .78881 .47578 Metetra
.664 .741 .908 r
.78881 .47578 .79286 .481 .80223 .47818 .79821 .47294 Metetra
.664 .741 .908 r
.79821 .47294 .80223 .47818 .81164 .47534 .80764 .47009 Metetra
.664 .741 .908 r
.80764 .47009 .81164 .47534 .82108 .4725 .8171 .46723 Metetra
.664 .741 .908 r
.8171 .46723 .82108 .4725 .83054 .46965 .82659 .46436 Metetra
.664 .741 .908 r
.82659 .46436 .83054 .46965 .84004 .46679 .83611 .46149 Metetra
.664 .741 .908 r
.83611 .46149 .84004 .46679 .84957 .46392 .84566 .4586 Metetra
.664 .741 .908 r
.84566 .4586 .84957 .46392 .85914 .46104 .85525 .4557 Metetra
.664 .741 .908 r
.85525 .4557 .85914 .46104 .86873 .45815 .86486 .4528 Metetra
.664 .741 .908 r
.86486 .4528 .86873 .45815 .87835 .45526 .87451 .44988 Metetra
.661 .74 .909 r
.87451 .44988 .87835 .45526 .88801 .45238 .8842 .44701 Metetra
.646 .735 .914 r
.8842 .44701 .88801 .45238 .89773 .44968 .89396 .44452 Metetra
.646 .745 .921 r
.89396 .44452 .89773 .44968 .90747 .44695 .90375 .44197 Metetra
.662 .76 .923 r
.90375 .44197 .90747 .44695 .91723 .44402 .91353 .43902 Metetra
.662 .76 .923 r
.91353 .43902 .91723 .44402 .92701 .44108 .92334 .43606 Metetra
.662 .759 .922 r
.92334 .43606 .92701 .44108 .93686 .43836 .93319 .43309 Metetra
.663 .75 .915 r
.93319 .43309 .93686 .43836 .94674 .43561 .94307 .43011 Metetra
.663 .741 .908 r
.94307 .43011 .94674 .43561 .95663 .43264 .95298 .42712 Metetra
.663 .741 .908 r
.95298 .42712 .95663 .43264 .96655 .42965 .96292 .42412 Metetra
.655 .722 .898 r
.3905 .59057 .39538 .59555 .40354 .59308 .39867 .5883 Metetra
.655 .73 .905 r
.39867 .5883 .40354 .59308 .41173 .59061 .40686 .58602 Metetra
.654 .739 .912 r
.40686 .58602 .41173 .59061 .41994 .58812 .41508 .58373 Metetra
.653 .748 .919 r
.41508 .58373 .41994 .58812 .42817 .58563 .42332 .58144 Metetra
.671 .761 .918 r
.42332 .58144 .42817 .58563 .43643 .58313 .43161 .57875 Metetra
.672 .754 .912 r
.43161 .57875 .43643 .58313 .44472 .58063 .43991 .57603 Metetra
.665 .743 .908 r
.43991 .57603 .44472 .58063 .45303 .57774 .44824 .57346 Metetra
.664 .758 .92 r
.44824 .57346 .45303 .57774 .46138 .57479 .45659 .57091 Metetra
.678 .78 .927 r
.45659 .57091 .46138 .57479 .46974 .57221 .46498 .56801 Metetra
.681 .766 .916 r
.46498 .56801 .46974 .57221 .47812 .56968 .47339 .56504 Metetra
.666 .745 .909 r
.47339 .56504 .47812 .56968 .48653 .56713 .48182 .56242 Metetra
.664 .741 .908 r
.48182 .56242 .48653 .56713 .49497 .56459 .49027 .55986 Metetra
.664 .741 .908 r
.49027 .55986 .49497 .56459 .50344 .56203 .49875 .55728 Metetra
.664 .741 .908 r
.49875 .55728 .50344 .56203 .51193 .55946 .50726 .5547 Metetra
.664 .741 .908 r
.50726 .5547 .51193 .55946 .52044 .55689 .51579 .55212 Metetra
.664 .741 .908 r
.51579 .55212 .52044 .55689 .52898 .55431 .52435 .54952 Metetra
.664 .741 .908 r
.52435 .54952 .52898 .55431 .53755 .55172 .53294 .54691 Metetra
.664 .741 .908 r
.53294 .54691 .53755 .55172 .54615 .54912 .54155 .5443 Metetra
.664 .741 .908 r
.54155 .5443 .54615 .54912 .55477 .54651 .55019 .54168 Metetra
.664 .741 .908 r
.55019 .54168 .55477 .54651 .56342 .5439 .55886 .53905 Metetra
.664 .741 .908 r
.55886 .53905 .56342 .5439 .5721 .54128 .56755 .53641 Metetra
.664 .741 .908 r
.56755 .53641 .5721 .54128 .5808 .53865 .57628 .53377 Metetra
.664 .741 .908 r
.57628 .53377 .5808 .53865 .58953 .53601 .58502 .53111 Metetra
.664 .741 .908 r
.58502 .53111 .58953 .53601 .59829 .53336 .5938 .52845 Metetra
.664 .741 .908 r
.5938 .52845 .59829 .53336 .60708 .5307 .60261 .52578 Metetra
.664 .741 .908 r
.60261 .52578 .60708 .5307 .61589 .52804 .61144 .5231 Metetra
.664 .741 .908 r
.61144 .5231 .61589 .52804 .62473 .52537 .6203 .52041 Metetra
.664 .741 .908 r
.6203 .52041 .62473 .52537 .6336 .52269 .62919 .51772 Metetra
.664 .741 .908 r
.62919 .51772 .6336 .52269 .6425 .52 .63811 .51501 Metetra
.664 .741 .908 r
.63811 .51501 .6425 .52 .65143 .5173 .64705 .5123 Metetra
.664 .741 .908 r
.64705 .5123 .65143 .5173 .66038 .51459 .65603 .50957 Metetra
.664 .741 .908 r
.65603 .50957 .66038 .51459 .66937 .51188 .66503 .50684 Metetra
.664 .741 .908 r
.66503 .50684 .66937 .51188 .67838 .50916 .67406 .5041 Metetra
.664 .741 .908 r
.67406 .5041 .67838 .50916 .68742 .50642 .68312 .50136 Metetra
.664 .741 .908 r
.68312 .50136 .68742 .50642 .69649 .50368 .69221 .4986 Metetra
.664 .741 .908 r
.69221 .4986 .69649 .50368 .70559 .50093 .70133 .49583 Metetra
.664 .741 .908 r
.70133 .49583 .70559 .50093 .71472 .49817 .71048 .49306 Metetra
.664 .741 .908 r
.71048 .49306 .71472 .49817 .72387 .49541 .71966 .49027 Metetra
.664 .741 .908 r
.71966 .49027 .72387 .49541 .73306 .49263 .72887 .48748 Metetra
.664 .741 .908 r
.72887 .48748 .73306 .49263 .74228 .48984 .7381 .48468 Metetra
.664 .741 .908 r
.7381 .48468 .74228 .48984 .75152 .48705 .74737 .48187 Metetra
.664 .741 .908 r
.74737 .48187 .75152 .48705 .7608 .48425 .75667 .47905 Metetra
.664 .741 .908 r
.75667 .47905 .7608 .48425 .77011 .48143 .766 .47622 Metetra
.664 .741 .908 r
.766 .47622 .77011 .48143 .77944 .47861 .77535 .47338 Metetra
.664 .741 .908 r
.77535 .47338 .77944 .47861 .78881 .47578 .78474 .47053 Metetra
.664 .741 .908 r
.78474 .47053 .78881 .47578 .79821 .47294 .79416 .46767 Metetra
.664 .741 .908 r
.79416 .46767 .79821 .47294 .80764 .47009 .80361 .4648 Metetra
.664 .741 .908 r
.80361 .4648 .80764 .47009 .8171 .46723 .81309 .46193 Metetra
.664 .741 .908 r
.81309 .46193 .8171 .46723 .82659 .46436 .82261 .45904 Metetra
.664 .741 .908 r
.82261 .45904 .82659 .46436 .83611 .46149 .83215 .45615 Metetra
.664 .741 .908 r
.83215 .45615 .83611 .46149 .84566 .4586 .84173 .45324 Metetra
.664 .741 .908 r
.84173 .45324 .84566 .4586 .85525 .4557 .85133 .45033 Metetra
.661 .74 .909 r
.85133 .45033 .85525 .4557 .86486 .4528 .86098 .44747 Metetra
.646 .737 .915 r
.86098 .44747 .86486 .4528 .87451 .44988 .8707 .44497 Metetra
.646 .755 .929 r
.8707 .44497 .87451 .44988 .8842 .44701 .88044 .4424 Metetra
.66 .775 .935 r
.88044 .4424 .8842 .44701 .89396 .44452 .89018 .43947 Metetra
.661 .757 .921 r
.89018 .43947 .89396 .44452 .90375 .44197 .89996 .43655 Metetra
.655 .739 .912 r
.89996 .43655 .90375 .44197 .91353 .43902 .90979 .43379 Metetra
.655 .748 .918 r
.90979 .43379 .91353 .43902 .92334 .43606 .91964 .431 Metetra
.671 .763 .919 r
.91964 .431 .92334 .43606 .93319 .43309 .92949 .42779 Metetra
.672 .754 .912 r
.92949 .42779 .93319 .43309 .94307 .43011 .93936 .42457 Metetra
.672 .745 .905 r
.93936 .42457 .94307 .43011 .95298 .42712 .94927 .42134 Metetra
.672 .736 .899 r
.94927 .42134 .95298 .42712 .96292 .42412 .95921 .41811 Metetra
.645 .719 .902 r
.3856 .58556 .3905 .59057 .39867 .5883 .39377 .58349 Metetra
.645 .727 .909 r
.39377 .58349 .39867 .5883 .40686 .58602 .40197 .5814 Metetra
.644 .736 .916 r
.40197 .5814 .40686 .58602 .41508 .58373 .4102 .57931 Metetra
.643 .745 .923 r
.4102 .57931 .41508 .58373 .42332 .58144 .41845 .57722 Metetra
.679 .763 .914 r
.41845 .57722 .42332 .58144 .43161 .57875 .42675 .57433 Metetra
.682 .756 .907 r
.42675 .57433 .43161 .57875 .43991 .57603 .43508 .57138 Metetra
.648 .738 .915 r
.43508 .57138 .43991 .57603 .44824 .57346 .44342 .56917 Metetra
.642 .753 .929 r
.44342 .56917 .44824 .57346 .45659 .57091 .45178 .56703 Metetra
.693 .784 .921 r
.45178 .56703 .45659 .57091 .46498 .56801 .46019 .56379 Metetra
.699 .771 .907 r
.46019 .56379 .46498 .56801 .47339 .56504 .46863 .56039 Metetra
.669 .746 .908 r
.46863 .56039 .47339 .56504 .48182 .56242 .47707 .55768 Metetra
.664 .741 .908 r
.47707 .55768 .48182 .56242 .49027 .55986 .48554 .5551 Metetra
.664 .741 .908 r
.48554 .5551 .49027 .55986 .49875 .55728 .49404 .55251 Metetra
.664 .741 .908 r
.49404 .55251 .49875 .55728 .50726 .5547 .50256 .54992 Metetra
.664 .741 .908 r
.50256 .54992 .50726 .5547 .51579 .55212 .51111 .54732 Metetra
.664 .741 .908 r
.51111 .54732 .51579 .55212 .52435 .54952 .51969 .5447 Metetra
.664 .741 .908 r
.51969 .5447 .52435 .54952 .53294 .54691 .5283 .54208 Metetra
.664 .741 .908 r
.5283 .54208 .53294 .54691 .54155 .5443 .53693 .53946 Metetra
.664 .741 .908 r
.53693 .53946 .54155 .5443 .55019 .54168 .54558 .53682 Metetra
.664 .741 .908 r
.54558 .53682 .55019 .54168 .55886 .53905 .55427 .53417 Metetra
.664 .741 .908 r
.55427 .53417 .55886 .53905 .56755 .53641 .56298 .53152 Metetra
.664 .741 .908 r
.56298 .53152 .56755 .53641 .57628 .53377 .57172 .52886 Metetra
.664 .741 .908 r
.57172 .52886 .57628 .53377 .58502 .53111 .58049 .52619 Metetra
.664 .741 .908 r
.58049 .52619 .58502 .53111 .5938 .52845 .58929 .52351 Metetra
.664 .741 .908 r
.58929 .52351 .5938 .52845 .60261 .52578 .59811 .52083 Metetra
.664 .741 .908 r
.59811 .52083 .60261 .52578 .61144 .5231 .60696 .51813 Metetra
.664 .741 .908 r
.60696 .51813 .61144 .5231 .6203 .52041 .61584 .51543 Metetra
.664 .741 .908 r
.61584 .51543 .6203 .52041 .62919 .51772 .62475 .51272 Metetra
.664 .741 .908 r
.62475 .51272 .62919 .51772 .63811 .51501 .63369 .50999 Metetra
.664 .741 .908 r
.63369 .50999 .63811 .51501 .64705 .5123 .64265 .50726 Metetra
.664 .741 .908 r
.64265 .50726 .64705 .5123 .65603 .50957 .65164 .50453 Metetra
.664 .741 .908 r
.65164 .50453 .65603 .50957 .66503 .50684 .66067 .50178 Metetra
.664 .741 .908 r
.66067 .50178 .66503 .50684 .67406 .5041 .66972 .49902 Metetra
.664 .741 .908 r
.66972 .49902 .67406 .5041 .68312 .50136 .6788 .49626 Metetra
.664 .741 .908 r
.6788 .49626 .68312 .50136 .69221 .4986 .68791 .49348 Metetra
.664 .741 .908 r
.68791 .49348 .69221 .4986 .70133 .49583 .69705 .4907 Metetra
.664 .741 .908 r
.69705 .4907 .70133 .49583 .71048 .49306 .70622 .48791 Metetra
.664 .741 .908 r
.70622 .48791 .71048 .49306 .71966 .49027 .71542 .48511 Metetra
.664 .741 .908 r
.71542 .48511 .71966 .49027 .72887 .48748 .72464 .4823 Metetra
.664 .741 .908 r
.72464 .4823 .72887 .48748 .7381 .48468 .7339 .47948 Metetra
.664 .741 .908 r
.7339 .47948 .7381 .48468 .74737 .48187 .74319 .47665 Metetra
.664 .741 .908 r
.74319 .47665 .74737 .48187 .75667 .47905 .75251 .47381 Metetra
.664 .741 .908 r
.75251 .47381 .75667 .47905 .766 .47622 .76186 .47097 Metetra
.664 .741 .908 r
.76186 .47097 .766 .47622 .77535 .47338 .77124 .46811 Metetra
.664 .741 .908 r
.77124 .46811 .77535 .47338 .78474 .47053 .78065 .46525 Metetra
.664 .741 .908 r
.78065 .46525 .78474 .47053 .79416 .46767 .79009 .46237 Metetra
.664 .741 .908 r
.79009 .46237 .79416 .46767 .80361 .4648 .79956 .45949 Metetra
.664 .741 .908 r
.79956 .45949 .80361 .4648 .81309 .46193 .80907 .45659 Metetra
.664 .741 .908 r
.80907 .45659 .81309 .46193 .82261 .45904 .8186 .45369 Metetra
.664 .741 .908 r
.8186 .45369 .82261 .45904 .83215 .45615 .82817 .45078 Metetra
.664 .741 .908 r
.82817 .45078 .83215 .45615 .84173 .45324 .83777 .44786 Metetra
.664 .741 .908 r
.83777 .44786 .84173 .45324 .85133 .45033 .8474 .44492 Metetra
.658 .739 .91 r
.8474 .44492 .85133 .45033 .86098 .44747 .85707 .44212 Metetra
.627 .729 .921 r
.85707 .44212 .86098 .44747 .8707 .44497 .86686 .44004 Metetra
.631 .75 .934 r
.86686 .44004 .8707 .44497 .88044 .4424 .87666 .43779 Metetra
.679 .784 .929 r
.87666 .43779 .88044 .4424 .89018 .43947 .88638 .43439 Metetra
.676 .763 .916 r
.88638 .43439 .89018 .43947 .89996 .43655 .89614 .43107 Metetra
.646 .735 .914 r
.89614 .43107 .89996 .43655 .90979 .43379 .90602 .42852 Metetra
.647 .745 .92 r
.90602 .42852 .90979 .43379 .91964 .431 .91592 .4259 Metetra
.68 .766 .916 r
.91592 .4259 .91964 .431 .92949 .42779 .92577 .42245 Metetra
.68 .757 .909 r
.92577 .42245 .92949 .42779 .93936 .42457 .93564 .419 Metetra
.68 .748 .902 r
.93564 .419 .93936 .42457 .94927 .42134 .94554 .41553 Metetra
.68 .739 .896 r
.94554 .41553 .94927 .42134 .95921 .41811 .95547 .41205 Metetra
.643 .735 .915 r
.38065 .58092 .3856 .58556 .39377 .58349 .38883 .57885 Metetra
.643 .735 .916 r
.38883 .57885 .39377 .58349 .40197 .5814 .39705 .57677 Metetra
.652 .739 .913 r
.39705 .57677 .40197 .5814 .4102 .57931 .4053 .57448 Metetra
.653 .731 .907 r
.4053 .57448 .4102 .57931 .41845 .57722 .41357 .57219 Metetra
.672 .729 .893 r
.41357 .57219 .41845 .57722 .42675 .57433 .42189 .56945 Metetra
.673 .736 .897 r
.42189 .56945 .42675 .57433 .43508 .57138 .43023 .56667 Metetra
.647 .736 .914 r
.43023 .56667 .43508 .57138 .44342 .56917 .43858 .56448 Metetra
.643 .737 .917 r
.43858 .56448 .44342 .56917 .45178 .56703 .44695 .56236 Metetra
.678 .747 .903 r
.44695 .56236 .45178 .56703 .46019 .56379 .45538 .55944 Metetra
.684 .763 .911 r
.45538 .55944 .46019 .56379 .46863 .56039 .46382 .55639 Metetra
.673 .777 .928 r
.46382 .55639 .46863 .56039 .47707 .55768 .47229 .55356 Metetra
.671 .771 .925 r
.47229 .55356 .47707 .55768 .48554 .5551 .48078 .55077 Metetra
.664 .761 .922 r
.48078 .55077 .48554 .5551 .49404 .55251 .4893 .54812 Metetra
.663 .759 .921 r
.4893 .54812 .49404 .55251 .50256 .54992 .49784 .54551 Metetra
.67 .76 .918 r
.49784 .54551 .50256 .54992 .51111 .54732 .50641 .54274 Metetra
.672 .754 .912 r
.50641 .54274 .51111 .54732 .51969 .5447 .51501 .53991 Metetra
.666 .744 .909 r
.51501 .53991 .51969 .5447 .5283 .54208 .52363 .53723 Metetra
.664 .741 .908 r
.52363 .53723 .5283 .54208 .53693 .53946 .53228 .53458 Metetra
.664 .741 .908 r
.53228 .53458 .53693 .53946 .54558 .53682 .54095 .53193 Metetra
.664 .741 .908 r
.54095 .53193 .54558 .53682 .55427 .53417 .54966 .52927 Metetra
.664 .741 .908 r
.54966 .52927 .55427 .53417 .56298 .53152 .55839 .5266 Metetra
.664 .741 .908 r
.55839 .5266 .56298 .53152 .57172 .52886 .56714 .52393 Metetra
.664 .741 .908 r
.56714 .52393 .57172 .52886 .58049 .52619 .57593 .52124 Metetra
.664 .741 .908 r
.57593 .52124 .58049 .52619 .58929 .52351 .58475 .51855 Metetra
.664 .741 .908 r
.58475 .51855 .58929 .52351 .59811 .52083 .59359 .51584 Metetra
.664 .741 .908 r
.59359 .51584 .59811 .52083 .60696 .51813 .60246 .51313 Metetra
.664 .741 .908 r
.60246 .51313 .60696 .51813 .61584 .51543 .61136 .51041 Metetra
.664 .741 .908 r
.61136 .51041 .61584 .51543 .62475 .51272 .62028 .50769 Metetra
.664 .741 .908 r
.62028 .50769 .62475 .51272 .63369 .50999 .62924 .50495 Metetra
.664 .741 .908 r
.62924 .50495 .63369 .50999 .64265 .50726 .63822 .5022 Metetra
.664 .741 .908 r
.63822 .5022 .64265 .50726 .65164 .50453 .64724 .49945 Metetra
.664 .741 .908 r
.64724 .49945 .65164 .50453 .66067 .50178 .65628 .49668 Metetra
.664 .741 .908 r
.65628 .49668 .66067 .50178 .66972 .49902 .66535 .49391 Metetra
.664 .741 .908 r
.66535 .49391 .66972 .49902 .6788 .49626 .67445 .49113 Metetra
.664 .741 .908 r
.67445 .49113 .6788 .49626 .68791 .49348 .68358 .48834 Metetra
.664 .741 .908 r
.68358 .48834 .68791 .49348 .69705 .4907 .69274 .48554 Metetra
.664 .741 .908 r
.69274 .48554 .69705 .4907 .70622 .48791 .70193 .48273 Metetra
.664 .741 .908 r
.70193 .48273 .70622 .48791 .71542 .48511 .71115 .47991 Metetra
.664 .741 .908 r
.71115 .47991 .71542 .48511 .72464 .4823 .7204 .47709 Metetra
.664 .741 .908 r
.7204 .47709 .72464 .4823 .7339 .47948 .72968 .47425 Metetra
.664 .741 .908 r
.72968 .47425 .7339 .47948 .74319 .47665 .73899 .47141 Metetra
.664 .741 .908 r
.73899 .47141 .74319 .47665 .75251 .47381 .74833 .46855 Metetra
.664 .741 .908 r
.74833 .46855 .75251 .47381 .76186 .47097 .7577 .46569 Metetra
.664 .741 .908 r
.7577 .46569 .76186 .47097 .77124 .46811 .7671 .46281 Metetra
.664 .741 .908 r
.7671 .46281 .77124 .46811 .78065 .46525 .77653 .45993 Metetra
.664 .741 .908 r
.77653 .45993 .78065 .46525 .79009 .46237 .786 .45704 Metetra
.661 .74 .909 r
.786 .45704 .79009 .46237 .79956 .45949 .79549 .45419 Metetra
.655 .74 .912 r
.79549 .45419 .79956 .45949 .80907 .45659 .80504 .45149 Metetra
.656 .749 .918 r
.80504 .45149 .80907 .45659 .8186 .45369 .81461 .44873 Metetra
.663 .759 .921 r
.81461 .44873 .8186 .45369 .82817 .45078 .8242 .4458 Metetra
.661 .758 .922 r
.8242 .4458 .82817 .45078 .83777 .44786 .83383 .4429 Metetra
.654 .757 .926 r
.83383 .4429 .83777 .44786 .8474 .44492 .8435 .44015 Metetra
.65 .765 .933 r
.8435 .44015 .8474 .44492 .85707 .44212 .85321 .43745 Metetra
.639 .765 .94 r
.85321 .43745 .85707 .44212 .86686 .44004 .86298 .43496 Metetra
.647 .751 .925 r
.86298 .43496 .86686 .44004 .87666 .43779 .87278 .43235 Metetra
.681 .75 .904 r
.87278 .43235 .87666 .43779 .88638 .43439 .88252 .42891 Metetra
.678 .748 .904 r
.88252 .42891 .88638 .43439 .89614 .43107 .89229 .42553 Metetra
.654 .737 .91 r
.89229 .42553 .89614 .43107 .90602 .42852 .90217 .42276 Metetra
.655 .73 .904 r
.90217 .42276 .90602 .42852 .91592 .4259 .91208 .41996 Metetra
.672 .73 .893 r
.91208 .41996 .91592 .4259 .92577 .42245 .92197 .41668 Metetra
.673 .738 .899 r
.92197 .41668 .92577 .42245 .93564 .419 .93189 .41339 Metetra
.681 .748 .902 r
.93189 .41339 .93564 .419 .94554 .41553 .94182 .40989 Metetra
.68 .748 .902 r
.94182 .40989 .94554 .41553 .95547 .41205 .95177 .40637 Metetra
.643 .736 .916 r
.37567 .57629 .38065 .58092 .38883 .57885 .38387 .5742 Metetra
.643 .736 .916 r
.38387 .5742 .38883 .57885 .39705 .57677 .3921 .5721 Metetra
.662 .741 .909 r
.3921 .5721 .39705 .57677 .4053 .57448 .40037 .5696 Metetra
.663 .733 .902 r
.40037 .5696 .4053 .57448 .41357 .57219 .40867 .56708 Metetra
.664 .725 .894 r
.40867 .56708 .41357 .57219 .42189 .56945 .41699 .56451 Metetra
.664 .732 .9 r
.41699 .56451 .42189 .56945 .43023 .56667 .42535 .56193 Metetra
.646 .736 .915 r
.42535 .56193 .43023 .56667 .43858 .56448 .43371 .55975 Metetra
.643 .736 .916 r
.43371 .55975 .43858 .56448 .44695 .56236 .4421 .55761 Metetra
.663 .741 .908 r
.4421 .55761 .44695 .56236 .45538 .55944 .45053 .55505 Metetra
.665 .758 .92 r
.45053 .55505 .45538 .55944 .46382 .55639 .45899 .55241 Metetra
.678 .78 .927 r
.45899 .55241 .46382 .55639 .47229 .55356 .46748 .54946 Metetra
.681 .776 .922 r
.46748 .54946 .47229 .55356 .48078 .55077 .47599 .54643 Metetra
.666 .763 .922 r
.47599 .54643 .48078 .55077 .4893 .54812 .48453 .54374 Metetra
.663 .76 .922 r
.48453 .54374 .4893 .54812 .49784 .54551 .49309 .54111 Metetra
.677 .764 .916 r
.49309 .54111 .49784 .54551 .50641 .54274 .50168 .53816 Metetra
.681 .757 .909 r
.50168 .53816 .50641 .54274 .51501 .53991 .51029 .5351 Metetra
.668 .745 .908 r
.51029 .5351 .51501 .53991 .52363 .53723 .51893 .53234 Metetra
.664 .741 .908 r
.51893 .53234 .52363 .53723 .53228 .53458 .5276 .52968 Metetra
.664 .741 .908 r
.5276 .52968 .53228 .53458 .54095 .53193 .53629 .52701 Metetra
.664 .741 .908 r
.53629 .52701 .54095 .53193 .54966 .52927 .54501 .52434 Metetra
.664 .741 .908 r
.54501 .52434 .54966 .52927 .55839 .5266 .55376 .52165 Metetra
.664 .741 .908 r
.55376 .52165 .55839 .5266 .56714 .52393 .56254 .51896 Metetra
.664 .741 .908 r
.56254 .51896 .56714 .52393 .57593 .52124 .57134 .51626 Metetra
.664 .741 .908 r
.57134 .51626 .57593 .52124 .58475 .51855 .58018 .51355 Metetra
.664 .741 .908 r
.58018 .51355 .58475 .51855 .59359 .51584 .58904 .51083 Metetra
.664 .741 .908 r
.58904 .51083 .59359 .51584 .60246 .51313 .59793 .50811 Metetra
.664 .741 .908 r
.59793 .50811 .60246 .51313 .61136 .51041 .60684 .50537 Metetra
.664 .741 .908 r
.60684 .50537 .61136 .51041 .62028 .50769 .61579 .50263 Metetra
.664 .741 .908 r
.61579 .50263 .62028 .50769 .62924 .50495 .62477 .49987 Metetra
.664 .741 .908 r
.62477 .49987 .62924 .50495 .63822 .5022 .63377 .49711 Metetra
.664 .741 .908 r
.63377 .49711 .63822 .5022 .64724 .49945 .6428 .49434 Metetra
.664 .741 .908 r
.6428 .49434 .64724 .49945 .65628 .49668 .65186 .49156 Metetra
.664 .741 .908 r
.65186 .49156 .65628 .49668 .66535 .49391 .66096 .48877 Metetra
.664 .741 .908 r
.66096 .48877 .66535 .49391 .67445 .49113 .67008 .48597 Metetra
.664 .741 .908 r
.67008 .48597 .67445 .49113 .68358 .48834 .67923 .48316 Metetra
.664 .741 .908 r
.67923 .48316 .68358 .48834 .69274 .48554 .68841 .48035 Metetra
.664 .741 .908 r
.68841 .48035 .69274 .48554 .70193 .48273 .69762 .47752 Metetra
.664 .741 .908 r
.69762 .47752 .70193 .48273 .71115 .47991 .70686 .47469 Metetra
.664 .741 .908 r
.70686 .47469 .71115 .47991 .7204 .47709 .71613 .47184 Metetra
.664 .741 .908 r
.71613 .47184 .7204 .47709 .72968 .47425 .72543 .46899 Metetra
.664 .741 .908 r
.72543 .46899 .72968 .47425 .73899 .47141 .73476 .46613 Metetra
.664 .741 .908 r
.73476 .46613 .73899 .47141 .74833 .46855 .74412 .46326 Metetra
.664 .741 .908 r
.74412 .46326 .74833 .46855 .7577 .46569 .75351 .46038 Metetra
.664 .741 .908 r
.75351 .46038 .7577 .46569 .7671 .46281 .76293 .45749 Metetra
.664 .741 .908 r
.76293 .45749 .7671 .46281 .77653 .45993 .77239 .45458 Metetra
.664 .741 .908 r
.77239 .45458 .77653 .45993 .786 .45704 .78187 .45168 Metetra
.659 .74 .909 r
.78187 .45168 .786 .45704 .79549 .45419 .7914 .44887 Metetra
.646 .737 .915 r
.7914 .44887 .79549 .45419 .80504 .45149 .80098 .44636 Metetra
.649 .747 .921 r
.80098 .44636 .80504 .45149 .81461 .44873 .8106 .44376 Metetra
.663 .76 .922 r
.8106 .44376 .81461 .44873 .8242 .4458 .82021 .44081 Metetra
.659 .758 .923 r
.82021 .44081 .8242 .4458 .83383 .4429 .82986 .43793 Metetra
.644 .754 .929 r
.82986 .43793 .83383 .4429 .8435 .44015 .83958 .4354 Metetra
.645 .765 .936 r
.83958 .4354 .8435 .44015 .85321 .43745 .84933 .43279 Metetra
.659 .775 .935 r
.84933 .43279 .85321 .43745 .86298 .43496 .85908 .42984 Metetra
.664 .758 .92 r
.85908 .42984 .86298 .43496 .87278 .43235 .86886 .42682 Metetra
.681 .748 .902 r
.86886 .42682 .87278 .43235 .88252 .42891 .87862 .42337 Metetra
.679 .748 .903 r
.87862 .42337 .88252 .42891 .89229 .42553 .88842 .41994 Metetra
.663 .74 .908 r
.88842 .41994 .89229 .42553 .90217 .42276 .8983 .41694 Metetra
.663 .732 .901 r
.8983 .41694 .90217 .42276 .91208 .41996 .90821 .41392 Metetra
.664 .725 .894 r
.90821 .41392 .91208 .41996 .92197 .41668 .91815 .41085 Metetra
.665 .734 .901 r
.91815 .41085 .92197 .41668 .93189 .41339 .92812 .40775 Metetra
.681 .748 .902 r
.92812 .40775 .93189 .41339 .94182 .40989 .93807 .40423 Metetra
.681 .748 .902 r
.93807 .40423 .94182 .40989 .95177 .40637 .94805 .4007 Metetra
.652 .739 .913 r
.37066 .57163 .37567 .57629 .38387 .5742 .37889 .56933 Metetra
.653 .731 .906 r
.37889 .56933 .38387 .5742 .3921 .5721 .38714 .56703 Metetra
.647 .721 .903 r
.38714 .56703 .3921 .5721 .40037 .5696 .39541 .56486 Metetra
.646 .735 .914 r
.39541 .56486 .40037 .5696 .40867 .56708 .40371 .56269 Metetra
.662 .755 .919 r
.40371 .56269 .40867 .56708 .41699 .56451 .41205 .56015 Metetra
.663 .757 .92 r
.41205 .56015 .41699 .56451 .42535 .56193 .42042 .55757 Metetra
.643 .753 .929 r
.42042 .55757 .42535 .56193 .43371 .55975 .4288 .55538 Metetra
.641 .752 .93 r
.4288 .55538 .43371 .55975 .4421 .55761 .43721 .55323 Metetra
.668 .759 .919 r
.43721 .55323 .4421 .55761 .45053 .55505 .44566 .55052 Metetra
.672 .755 .913 r
.44566 .55052 .45053 .55505 .45899 .55241 .45414 .54772 Metetra
.666 .747 .91 r
.45414 .54772 .45899 .55241 .46748 .54946 .46264 .54503 Metetra
.665 .759 .92 r
.46264 .54503 .46748 .54946 .47599 .54643 .47117 .54236 Metetra
.669 .776 .93 r
.47117 .54236 .47599 .54643 .48453 .54374 .47972 .53956 Metetra
.671 .773 .926 r
.47972 .53956 .48453 .54374 .49309 .54111 .4883 .53673 Metetra
.68 .766 .916 r
.4883 .53673 .49309 .54111 .50168 .53816 .49691 .5337 Metetra
.682 .764 .913 r
.49691 .5337 .50168 .53816 .51029 .5351 .50555 .5306 Metetra
.674 .761 .916 r
.50555 .5306 .51029 .5351 .51893 .53234 .51421 .52768 Metetra
.672 .754 .912 r
.51421 .52768 .51893 .53234 .5276 .52968 .52289 .52481 Metetra
.666 .744 .909 r
.52289 .52481 .5276 .52968 .53629 .52701 .5316 .52207 Metetra
.664 .741 .908 r
.5316 .52207 .53629 .52701 .54501 .52434 .54034 .51938 Metetra
.664 .741 .908 r
.54034 .51938 .54501 .52434 .55376 .52165 .54911 .51668 Metetra
.664 .741 .908 r
.54911 .51668 .55376 .52165 .56254 .51896 .55791 .51397 Metetra
.664 .741 .908 r
.55791 .51397 .56254 .51896 .57134 .51626 .56673 .51125 Metetra
.664 .741 .908 r
.56673 .51125 .57134 .51626 .58018 .51355 .57558 .50853 Metetra
.664 .741 .908 r
.57558 .50853 .58018 .51355 .58904 .51083 .58446 .50579 Metetra
.664 .741 .908 r
.58446 .50579 .58904 .51083 .59793 .50811 .59337 .50305 Metetra
.664 .741 .908 r
.59337 .50305 .59793 .50811 .60684 .50537 .60231 .5003 Metetra
.664 .741 .908 r
.60231 .5003 .60684 .50537 .61579 .50263 .61127 .49754 Metetra
.664 .741 .908 r
.61127 .49754 .61579 .50263 .62477 .49987 .62027 .49477 Metetra
.664 .741 .908 r
.62027 .49477 .62477 .49987 .63377 .49711 .62929 .49199 Metetra
.664 .741 .908 r
.62929 .49199 .63377 .49711 .6428 .49434 .63834 .4892 Metetra
.664 .741 .908 r
.63834 .4892 .6428 .49434 .65186 .49156 .64742 .4864 Metetra
.664 .741 .908 r
.64742 .4864 .65186 .49156 .66096 .48877 .65654 .4836 Metetra
.664 .741 .908 r
.65654 .4836 .66096 .48877 .67008 .48597 .66568 .48078 Metetra
.664 .741 .908 r
.66568 .48078 .67008 .48597 .67923 .48316 .67485 .47796 Metetra
.664 .741 .908 r
.67485 .47796 .67923 .48316 .68841 .48035 .68405 .47513 Metetra
.664 .741 .908 r
.68405 .47513 .68841 .48035 .69762 .47752 .69328 .47228 Metetra
.664 .741 .908 r
.69328 .47228 .69762 .47752 .70686 .47469 .70254 .46943 Metetra
.664 .741 .908 r
.70254 .46943 .70686 .47469 .71613 .47184 .71183 .46657 Metetra
.664 .741 .908 r
.71183 .46657 .71613 .47184 .72543 .46899 .72115 .4637 Metetra
.664 .741 .908 r
.72115 .4637 .72543 .46899 .73476 .46613 .7305 .46082 Metetra
.664 .741 .908 r
.7305 .46082 .73476 .46613 .74412 .46326 .73989 .45793 Metetra
.664 .741 .908 r
.73989 .45793 .74412 .46326 .75351 .46038 .7493 .45503 Metetra
.664 .741 .908 r
.7493 .45503 .75351 .46038 .76293 .45749 .75874 .45212 Metetra
.661 .74 .909 r
.75874 .45212 .76293 .45749 .77239 .45458 .76823 .44926 Metetra
.655 .741 .912 r
.76823 .44926 .77239 .45458 .78187 .45168 .77775 .44654 Metetra
.652 .748 .92 r
.77775 .44654 .78187 .45168 .7914 .44887 .78731 .44386 Metetra
.643 .751 .927 r
.78731 .44386 .7914 .44887 .80098 .44636 .79692 .44137 Metetra
.645 .753 .927 r
.79692 .44137 .80098 .44636 .8106 .44376 .80656 .4388 Metetra
.654 .758 .927 r
.80656 .4388 .8106 .44376 .82021 .44081 .81621 .43604 Metetra
.654 .767 .933 r
.81621 .43604 .82021 .44081 .82986 .43793 .8259 .43323 Metetra
.659 .773 .934 r
.8259 .43323 .82986 .43793 .83958 .4354 .83561 .4303 Metetra
.66 .757 .922 r
.83561 .4303 .83958 .4354 .84933 .43279 .84536 .42738 Metetra
.655 .743 .914 r
.84536 .42738 .84933 .43279 .85908 .42984 .85515 .42457 Metetra
.658 .75 .918 r
.85515 .42457 .85908 .42984 .86886 .42682 .86496 .42167 Metetra
.681 .765 .915 r
.86496 .42167 .86886 .42682 .87862 .42337 .87475 .4182 Metetra
.679 .764 .915 r
.87475 .4182 .87862 .42337 .88842 .41994 .88457 .41475 Metetra
.663 .758 .921 r
.88457 .41475 .88842 .41994 .8983 .41694 .89447 .4117 Metetra
.664 .757 .92 r
.89447 .4117 .8983 .41694 .90821 .41392 .9044 .40862 Metetra
.679 .762 .914 r
.9044 .40862 .90821 .41392 .91815 .41085 .91432 .40515 Metetra
.678 .746 .902 r
.91432 .40515 .91815 .41085 .92812 .40775 .92427 .40167 Metetra
.673 .73 .893 r
.92427 .40167 .92812 .40775 .93807 .40423 .93428 .39833 Metetra
.673 .737 .899 r
.93428 .39833 .93807 .40423 .94805 .4007 .94431 .39498 Metetra
.662 .741 .908 r
.36563 .56694 .37066 .57163 .37889 .56933 .37388 .56442 Metetra
.662 .732 .902 r
.37388 .56442 .37889 .56933 .38714 .56703 .38215 .56189 Metetra
.628 .714 .908 r
.38215 .56189 .38714 .56703 .39541 .56486 .39042 .56011 Metetra
.624 .73 .923 r
.39042 .56011 .39541 .56486 .40371 .56269 .39873 .55835 Metetra
.66 .758 .922 r
.39873 .55835 .40371 .56269 .41205 .56015 .40708 .55582 Metetra
.663 .76 .922 r
.40708 .55582 .41205 .56015 .42042 .55757 .41547 .55323 Metetra
.643 .755 .93 r
.41547 .55323 .42042 .55757 .4288 .55538 .42386 .55103 Metetra
.641 .754 .931 r
.42386 .55103 .4288 .55538 .43721 .55323 .43229 .54886 Metetra
.676 .763 .916 r
.43229 .54886 .43721 .55323 .44566 .55052 .44076 .54595 Metetra
.681 .756 .908 r
.44076 .54595 .44566 .55052 .45414 .54772 .44926 .54292 Metetra
.652 .74 .914 r
.44926 .54292 .45414 .54772 .46264 .54503 .45778 .54054 Metetra
.644 .752 .927 r
.45778 .54054 .46264 .54503 .47117 .54236 .46631 .53829 Metetra
.673 .778 .929 r
.46631 .53829 .47117 .54236 .47972 .53956 .47489 .53538 Metetra
.681 .776 .923 r
.47489 .53538 .47972 .53956 .4883 .53673 .48349 .53232 Metetra
.682 .767 .916 r
.48349 .53232 .4883 .53673 .49691 .5337 .49212 .52922 Metetra
.682 .765 .914 r
.49212 .52922 .49691 .5337 .50555 .5306 .50078 .52611 Metetra
.681 .764 .914 r
.50078 .52611 .50555 .5306 .51421 .52768 .50946 .52301 Metetra
.681 .758 .909 r
.50946 .52301 .51421 .52768 .52289 .52481 .51816 .51991 Metetra
.669 .745 .908 r
.51816 .51991 .52289 .52481 .5316 .52207 .52689 .51709 Metetra
.664 .741 .908 r
.52689 .51709 .5316 .52207 .54034 .51938 .53565 .51439 Metetra
.664 .741 .908 r
.53565 .51439 .54034 .51938 .54911 .51668 .54443 .51167 Metetra
.664 .741 .908 r
.54443 .51167 .54911 .51668 .55791 .51397 .55325 .50895 Metetra
.664 .741 .908 r
.55325 .50895 .55791 .51397 .56673 .51125 .56209 .50621 Metetra
.664 .741 .908 r
.56209 .50621 .56673 .51125 .57558 .50853 .57096 .50347 Metetra
.664 .741 .908 r
.57096 .50347 .57558 .50853 .58446 .50579 .57986 .50072 Metetra
.664 .741 .908 r
.57986 .50072 .58446 .50579 .59337 .50305 .58878 .49796 Metetra
.664 .741 .908 r
.58878 .49796 .59337 .50305 .60231 .5003 .59774 .49519 Metetra
.664 .741 .908 r
.59774 .49519 .60231 .5003 .61127 .49754 .60673 .49241 Metetra
.664 .741 .908 r
.60673 .49241 .61127 .49754 .62027 .49477 .61574 .48963 Metetra
.664 .741 .908 r
.61574 .48963 .62027 .49477 .62929 .49199 .62478 .48683 Metetra
.664 .741 .908 r
.62478 .48683 .62929 .49199 .63834 .4892 .63386 .48403 Metetra
.664 .741 .908 r
.63386 .48403 .63834 .4892 .64742 .4864 .64296 .48122 Metetra
.664 .741 .908 r
.64296 .48122 .64742 .4864 .65654 .4836 .65209 .47839 Metetra
.664 .741 .908 r
.65209 .47839 .65654 .4836 .66568 .48078 .66125 .47556 Metetra
.664 .741 .908 r
.66125 .47556 .66568 .48078 .67485 .47796 .67044 .47272 Metetra
.664 .741 .908 r
.67044 .47272 .67485 .47796 .68405 .47513 .67966 .46987 Metetra
.664 .741 .908 r
.67966 .46987 .68405 .47513 .69328 .47228 .68891 .46701 Metetra
.664 .741 .908 r
.68891 .46701 .69328 .47228 .70254 .46943 .69819 .46414 Metetra
.664 .741 .908 r
.69819 .46414 .70254 .46943 .71183 .46657 .70751 .46126 Metetra
.664 .741 .908 r
.70751 .46126 .71183 .46657 .72115 .4637 .71685 .45838 Metetra
.664 .741 .908 r
.71685 .45838 .72115 .4637 .7305 .46082 .72622 .45548 Metetra
.664 .741 .908 r
.72622 .45548 .7305 .46082 .73989 .45793 .73563 .45257 Metetra
.664 .741 .908 r
.73563 .45257 .73989 .45793 .7493 .45503 .74506 .44965 Metetra
.664 .741 .908 r
.74506 .44965 .7493 .45503 .75874 .45212 .75453 .44673 Metetra
.659 .739 .91 r
.75453 .44673 .75874 .45212 .76823 .44926 .76404 .44391 Metetra
.646 .737 .916 r
.76404 .44391 .76823 .44926 .77775 .44654 .7736 .44139 Metetra
.645 .746 .923 r
.7736 .44139 .77775 .44654 .78731 .44386 .78319 .43886 Metetra
.643 .752 .928 r
.78319 .43886 .78731 .44386 .79692 .44137 .79283 .43635 Metetra
.643 .752 .928 r
.79283 .43635 .79692 .44137 .80656 .4388 .8025 .43382 Metetra
.644 .755 .93 r
.8025 .43382 .80656 .4388 .81621 .43604 .8122 .43126 Metetra
.649 .767 .935 r
.8122 .43126 .81621 .43604 .8259 .43323 .82192 .42853 Metetra
.678 .782 .928 r
.82192 .42853 .8259 .43323 .83561 .4303 .83161 .42513 Metetra
.673 .761 .916 r
.83161 .42513 .83561 .4303 .84536 .42738 .84135 .42186 Metetra
.646 .736 .915 r
.84135 .42186 .84536 .42738 .85515 .42457 .85118 .41926 Metetra
.65 .747 .92 r
.85118 .41926 .85515 .42457 .86496 .42167 .86104 .41653 Metetra
.681 .767 .916 r
.86104 .41653 .86496 .42167 .87475 .4182 .87086 .41304 Metetra
.679 .766 .917 r
.87086 .41304 .87475 .4182 .88457 .41475 .88071 .40957 Metetra
.663 .76 .922 r
.88071 .40957 .88457 .41475 .89447 .4117 .89063 .40651 Metetra
.665 .761 .922 r
.89063 .40651 .89447 .4117 .9044 .40862 .90059 .40338 Metetra
.696 .771 .91 r
.90059 .40338 .9044 .40862 .91432 .40515 .91048 .39944 Metetra
.694 .753 .897 r
.91048 .39944 .91432 .40515 .92427 .40167 .9204 .39552 Metetra
.665 .725 .894 r
.9204 .39552 .92427 .40167 .93428 .39833 .93045 .39238 Metetra
.665 .733 .901 r
.93045 .39238 .93428 .39833 .94431 .39498 .94054 .38923 Metetra
.664 .741 .908 r
.36056 .56222 .36563 .56694 .37388 .56442 .36883 .55966 Metetra
.664 .74 .907 r
.36883 .55966 .37388 .56442 .38215 .56189 .37712 .55709 Metetra
.641 .733 .915 r
.37712 .55709 .38215 .56189 .39042 .56011 .38542 .55499 Metetra
.642 .721 .905 r
.38542 .55499 .39042 .56011 .39873 .55835 .39375 .5529 Metetra
.647 .71 .893 r
.39375 .5529 .39873 .55835 .40708 .55582 .40211 .55068 Metetra
.647 .723 .904 r
.40211 .55068 .40708 .55582 .41547 .55323 .4105 .54845 Metetra
.652 .739 .914 r
.4105 .54845 .41547 .55323 .42386 .55103 .41891 .5461 Metetra
.652 .734 .909 r
.41891 .5461 .42386 .55103 .43229 .54886 .42736 .54373 Metetra
.678 .733 .892 r
.42736 .54373 .43229 .54886 .44076 .54595 .43585 .54075 Metetra
.681 .732 .889 r
.43585 .54075 .44076 .54595 .44926 .54292 .44437 .53768 Metetra
.651 .723 .901 r
.44437 .53768 .44926 .54292 .45778 .54054 .4529 .53533 Metetra
.645 .723 .905 r
.4529 .53533 .45778 .54054 .46631 .53829 .46145 .53312 Metetra
.668 .732 .897 r
.46145 .53312 .46631 .53829 .47489 .53538 .47004 .53034 Metetra
.674 .739 .899 r
.47004 .53034 .47489 .53538 .48349 .53232 .47866 .52742 Metetra
.662 .742 .909 r
.47866 .52742 .48349 .53232 .49212 .52922 .4873 .52478 Metetra
.656 .761 .926 r
.4873 .52478 .49212 .52922 .50078 .52611 .49597 .52222 Metetra
.674 .791 .937 r
.49597 .52222 .50078 .52611 .50946 .52301 .50467 .51923 Metetra
.68 .798 .938 r
.50467 .51923 .50946 .52301 .51816 .51991 .51339 .51608 Metetra
.678 .796 .938 r
.51339 .51608 .51816 .51991 .52689 .51709 .52215 .51297 Metetra
.679 .784 .929 r
.52215 .51297 .52689 .51709 .53565 .51439 .53092 .50987 Metetra
.674 .765 .92 r
.53092 .50987 .53565 .51439 .54443 .51167 .53973 .50689 Metetra
.671 .754 .913 r
.53973 .50689 .54443 .51167 .55325 .50895 .54856 .50396 Metetra
.666 .745 .909 r
.54856 .50396 .55325 .50895 .56209 .50621 .55742 .50114 Metetra
.664 .741 .908 r
.55742 .50114 .56209 .50621 .57096 .50347 .56631 .49839 Metetra
.664 .741 .908 r
.56631 .49839 .57096 .50347 .57986 .50072 .57523 .49562 Metetra
.664 .741 .908 r
.57523 .49562 .57986 .50072 .58878 .49796 .58417 .49284 Metetra
.664 .741 .908 r
.58417 .49284 .58878 .49796 .59774 .49519 .59315 .49006 Metetra
.664 .741 .908 r
.59315 .49006 .59774 .49519 .60673 .49241 .60215 .48726 Metetra
.664 .741 .908 r
.60215 .48726 .60673 .49241 .61574 .48963 .61119 .48446 Metetra
.664 .741 .908 r
.61119 .48446 .61574 .48963 .62478 .48683 .62025 .48165 Metetra
.664 .741 .908 r
.62025 .48165 .62478 .48683 .63386 .48403 .62934 .47883 Metetra
.664 .741 .908 r
.62934 .47883 .63386 .48403 .64296 .48122 .63846 .476 Metetra
.664 .741 .908 r
.63846 .476 .64296 .48122 .65209 .47839 .64761 .47316 Metetra
.664 .741 .908 r
.64761 .47316 .65209 .47839 .66125 .47556 .6568 .47031 Metetra
.664 .741 .908 r
.6568 .47031 .66125 .47556 .67044 .47272 .66601 .46745 Metetra
.664 .741 .908 r
.66601 .46745 .67044 .47272 .67966 .46987 .67525 .46458 Metetra
.664 .741 .908 r
.67525 .46458 .67966 .46987 .68891 .46701 .68452 .46171 Metetra
.664 .741 .908 r
.68452 .46171 .68891 .46701 .69819 .46414 .69382 .45882 Metetra
.664 .741 .908 r
.69382 .45882 .69819 .46414 .70751 .46126 .70316 .45592 Metetra
.664 .741 .908 r
.70316 .45592 .70751 .46126 .71685 .45838 .71252 .45302 Metetra
.661 .74 .909 r
.71252 .45302 .71685 .45838 .72622 .45548 .72192 .45017 Metetra
.656 .741 .913 r
.72192 .45017 .72622 .45548 .73563 .45257 .73136 .44744 Metetra
.652 .748 .92 r
.73136 .44744 .73563 .45257 .74506 .44965 .74083 .44476 Metetra
.645 .756 .93 r
.74083 .44476 .74506 .44965 .75453 .44673 .75035 .4422 Metetra
.641 .772 .943 r
.75035 .4422 .75453 .44673 .76404 .44391 .7599 .43965 Metetra
.636 .784 .952 r
.7599 .43965 .76404 .44391 .7736 .44139 .76949 .43714 Metetra
.643 .788 .951 r
.76949 .43714 .7736 .44139 .78319 .43886 .7791 .43447 Metetra
.665 .789 .941 r
.7791 .43447 .78319 .43886 .79283 .43635 .78872 .43136 Metetra
.664 .763 .923 r
.78872 .43136 .79283 .43635 .8025 .43382 .79837 .42833 Metetra
.653 .738 .912 r
.79837 .42833 .8025 .43382 .8122 .43126 .80807 .42558 Metetra
.659 .734 .905 r
.80807 .42558 .8122 .43126 .82192 .42853 .8178 .42269 Metetra
.68 .737 .894 r
.8178 .42269 .82192 .42853 .83161 .42513 .82752 .41922 Metetra
.675 .733 .894 r
.82752 .41922 .83161 .42513 .84135 .42186 .83727 .41588 Metetra
.646 .719 .902 r
.83727 .41588 .84135 .42186 .85118 .41926 .84713 .41329 Metetra
.65 .722 .901 r
.84713 .41329 .85118 .41926 .86104 .41653 .85702 .4106 Metetra
.673 .733 .896 r
.85702 .4106 .86104 .41653 .87086 .41304 .86688 .40727 Metetra
.674 .741 .901 r
.86688 .40727 .87086 .41304 .88071 .40957 .87677 .40393 Metetra
.678 .748 .904 r
.87677 .40393 .88071 .40957 .89063 .40651 .88667 .40045 Metetra
.678 .733 .892 r
.88667 .40045 .89063 .40651 .90059 .40338 .89661 .39696 Metetra
.681 .722 .881 r
.89661 .39696 .90059 .40338 .91048 .39944 .90657 .39333 Metetra
.681 .734 .891 r
.90657 .39333 .91048 .39944 .9204 .39552 .91655 .38971 Metetra
.664 .739 .906 r
.91655 .38971 .9204 .39552 .93045 .39238 .92663 .38658 Metetra
.664 .74 .907 r
.92663 .38658 .93045 .39238 .94054 .38923 .93675 .38345 Metetra
.664 .741 .908 r
.35547 .55748 .36056 .56222 .36883 .55966 .36375 .5549 Metetra
.664 .741 .908 r
.36375 .5549 .36883 .55966 .37712 .55709 .37206 .55231 Metetra
.661 .741 .909 r
.37206 .55231 .37712 .55709 .38542 .55499 .38039 .54979 Metetra
.661 .724 .896 r
.38039 .54979 .38542 .55499 .39375 .5529 .38875 .54725 Metetra
.631 .699 .894 r
.38875 .54725 .39375 .5529 .40211 .55068 .39711 .5454 Metetra
.627 .712 .907 r
.39711 .5454 .40211 .55068 .4105 .54845 .4055 .54358 Metetra
.659 .739 .909 r
.4055 .54358 .4105 .54845 .41891 .5461 .41394 .54106 Metetra
.662 .733 .903 r
.41394 .54106 .41891 .5461 .42736 .54373 .42241 .53846 Metetra
.678 .729 .889 r
.42241 .53846 .42736 .54373 .43585 .54075 .43092 .53544 Metetra
.68 .729 .887 r
.43092 .53544 .43585 .54075 .44437 .53768 .43945 .53235 Metetra
.651 .721 .899 r
.43945 .53235 .44437 .53768 .4529 .53533 .44799 .52999 Metetra
.645 .719 .902 r
.44799 .52999 .4529 .53533 .46145 .53312 .45656 .52776 Metetra
.661 .724 .895 r
.45656 .52776 .46145 .53312 .47004 .53034 .46516 .52514 Metetra
.665 .731 .899 r
.46516 .52514 .47004 .53034 .47866 .52742 .4738 .52242 Metetra
.637 .731 .917 r
.4738 .52242 .47866 .52742 .4873 .52478 .48245 .52032 Metetra
.623 .751 .938 r
.48245 .52032 .4873 .52478 .49597 .52222 .49113 .51839 Metetra
.665 .793 .943 r
.49113 .51839 .49597 .52222 .50467 .51923 .49985 .51555 Metetra
.68 .804 .942 r
.49985 .51555 .50467 .51923 .51339 .51608 .5086 .51239 Metetra
.692 .807 .936 r
.5086 .51239 .51339 .51608 .52215 .51297 .51737 .50896 Metetra
.698 .794 .924 r
.51737 .50896 .52215 .51297 .53092 .50987 .52617 .5054 Metetra
.686 .772 .917 r
.52617 .5054 .53092 .50987 .53973 .50689 .535 .50212 Metetra
.68 .758 .91 r
.535 .50212 .53973 .50689 .54856 .50396 .54385 .49896 Metetra
.67 .746 .908 r
.54385 .49896 .54856 .50396 .55742 .50114 .55272 .49604 Metetra
.664 .741 .908 r
.55272 .49604 .55742 .50114 .56631 .49839 .56163 .49327 Metetra
.664 .741 .908 r
.56163 .49327 .56631 .49839 .57523 .49562 .57057 .49049 Metetra
.664 .741 .908 r
.57057 .49049 .57523 .49562 .58417 .49284 .57953 .48769 Metetra
.664 .741 .908 r
.57953 .48769 .58417 .49284 .59315 .49006 .58853 .48489 Metetra
.664 .741 .908 r
.58853 .48489 .59315 .49006 .60215 .48726 .59755 .48208 Metetra
.664 .741 .908 r
.59755 .48208 .60215 .48726 .61119 .48446 .60661 .47926 Metetra
.664 .741 .908 r
.60661 .47926 .61119 .48446 .62025 .48165 .61569 .47643 Metetra
.664 .741 .908 r
.61569 .47643 .62025 .48165 .62934 .47883 .6248 .4736 Metetra
.664 .741 .908 r
.6248 .4736 .62934 .47883 .63846 .476 .63394 .47075 Metetra
.664 .741 .908 r
.63394 .47075 .63846 .476 .64761 .47316 .64311 .46789 Metetra
.664 .741 .908 r
.64311 .46789 .64761 .47316 .6568 .47031 .65232 .46503 Metetra
.664 .741 .908 r
.65232 .46503 .6568 .47031 .66601 .46745 .66155 .46215 Metetra
.664 .741 .908 r
.66155 .46215 .66601 .46745 .67525 .46458 .67081 .45927 Metetra
.664 .741 .908 r
.67081 .45927 .67525 .46458 .68452 .46171 .6801 .45637 Metetra
.664 .741 .908 r
.6801 .45637 .68452 .46171 .69382 .45882 .68943 .45347 Metetra
.664 .741 .908 r
.68943 .45347 .69382 .45882 .70316 .45592 .69878 .45055 Metetra
.664 .741 .908 r
.69878 .45055 .70316 .45592 .71252 .45302 .70817 .44763 Metetra
.658 .739 .91 r
.70817 .44763 .71252 .45302 .72192 .45017 .71759 .44484 Metetra
.646 .738 .916 r
.71759 .44484 .72192 .45017 .73136 .44744 .72706 .44232 Metetra
.639 .745 .925 r
.72706 .44232 .73136 .44744 .74083 .44476 .73658 .43991 Metetra
.623 .751 .938 r
.73658 .43991 .74083 .44476 .75035 .4422 .74615 .43778 Metetra
.624 .772 .951 r
.74615 .43778 .75035 .4422 .7599 .43965 .75575 .43553 Metetra
.634 .791 .958 r
.75575 .43553 .7599 .43965 .76949 .43714 .76537 .433 Metetra
.65 .797 .953 r
.76537 .433 .76949 .43714 .7791 .43447 .77499 .43014 Metetra
.694 .803 .932 r
.77499 .43014 .7791 .43447 .78872 .43136 .78458 .42634 Metetra
.687 .771 .915 r
.78458 .42634 .78872 .43136 .79837 .42833 .7942 .42273 Metetra
.662 .739 .907 r
.7942 .42273 .79837 .42833 .80807 .42558 .80392 .41974 Metetra
.666 .732 .899 r
.80392 .41974 .80807 .42558 .8178 .42269 .81365 .41665 Metetra
.68 .731 .889 r
.81365 .41665 .8178 .42269 .82752 .41922 .82339 .41316 Metetra
.675 .729 .891 r
.82339 .41316 .82752 .41922 .83727 .41588 .83316 .4098 Metetra
.646 .717 .9 r
.83316 .4098 .83727 .41588 .84713 .41329 .84305 .40719 Metetra
.649 .718 .899 r
.84305 .40719 .84713 .41329 .85702 .4106 .85296 .40451 Metetra
.665 .726 .895 r
.85296 .40451 .85702 .4106 .86688 .40727 .86286 .40139 Metetra
.668 .735 .901 r
.86286 .40139 .86688 .40727 .87677 .40393 .87279 .39818 Metetra
.694 .752 .896 r
.87279 .39818 .87677 .40393 .88667 .40045 .88268 .39424 Metetra
.691 .734 .884 r
.88268 .39424 .88667 .40045 .89661 .39696 .89259 .39033 Metetra
.665 .71 .881 r
.89259 .39033 .89661 .39696 .90657 .39333 .90262 .38714 Metetra
.666 .726 .894 r
.90262 .38714 .90657 .39333 .91655 .38971 .91269 .38393 Metetra
.664 .741 .908 r
.91269 .38393 .91655 .38971 .92663 .38658 .92279 .38078 Metetra
.664 .741 .908 r
.92279 .38078 .92663 .38658 .93675 .38345 .93294 .37762 Metetra
.664 .741 .908 r
.35035 .55271 .35547 .55748 .36375 .5549 .35865 .55012 Metetra
.664 .741 .908 r
.35865 .55012 .36375 .5549 .37206 .55231 .36697 .54752 Metetra
.664 .741 .908 r
.36697 .54752 .37206 .55231 .38039 .54979 .37532 .5449 Metetra
.664 .739 .906 r
.37532 .5449 .38039 .54979 .38875 .54725 .3837 .54229 Metetra
.634 .727 .916 r
.3837 .54229 .38875 .54725 .39711 .5454 .39208 .54031 Metetra
.632 .723 .913 r
.39208 .54031 .39711 .5454 .4055 .54358 .40048 .53837 Metetra
.646 .723 .904 r
.40048 .53837 .4055 .54358 .41394 .54106 .40893 .53612 Metetra
.647 .734 .912 r
.40893 .53612 .41394 .54106 .42241 .53846 .4174 .53383 Metetra
.678 .756 .91 r
.4174 .53383 .42241 .53846 .43092 .53544 .42593 .53084 Metetra
.682 .758 .909 r
.42593 .53084 .43092 .53544 .43945 .53235 .43448 .52773 Metetra
.649 .75 .923 r
.43448 .52773 .43945 .53235 .44799 .52999 .44304 .52535 Metetra
.642 .748 .926 r
.44304 .52535 .44799 .52999 .45656 .52776 .45163 .52311 Metetra
.659 .753 .919 r
.45163 .52311 .45656 .52776 .46516 .52514 .46025 .5205 Metetra
.663 .755 .919 r
.46025 .5205 .46516 .52514 .4738 .52242 .4689 .5178 Metetra
.644 .751 .927 r
.4689 .5178 .4738 .52242 .48245 .52032 .47757 .51549 Metetra
.639 .741 .923 r
.47757 .51549 .48245 .52032 .49113 .51839 .48627 .51329 Metetra
.666 .739 .904 r
.48627 .51329 .49113 .51839 .49985 .51555 .49501 .5105 Metetra
.674 .744 .903 r
.49501 .5105 .49985 .51555 .5086 .51239 .50378 .50751 Metetra
.682 .753 .905 r
.50378 .50751 .5086 .51239 .51737 .50896 .51257 .50432 Metetra
.685 .765 .912 r
.51257 .50432 .51737 .50896 .52617 .5054 .52139 .50105 Metetra
.677 .776 .925 r
.52139 .50105 .52617 .5054 .535 .50212 .53023 .49794 Metetra
.673 .783 .932 r
.53023 .49794 .535 .50212 .54385 .49896 .53911 .49491 Metetra
.676 .791 .936 r
.53911 .49491 .54385 .49896 .55272 .49604 .54801 .4918 Metetra
.678 .783 .929 r
.54801 .4918 .55272 .49604 .56163 .49327 .55693 .48864 Metetra
.674 .766 .92 r
.55693 .48864 .56163 .49327 .57057 .49049 .56589 .48558 Metetra
.671 .754 .913 r
.56589 .48558 .57057 .49049 .57953 .48769 .57487 .48259 Metetra
.667 .745 .909 r
.57487 .48259 .57953 .48769 .58853 .48489 .58388 .4797 Metetra
.664 .741 .908 r
.58388 .4797 .58853 .48489 .59755 .48208 .59292 .47687 Metetra
.664 .741 .908 r
.59292 .47687 .59755 .48208 .60661 .47926 .602 .47403 Metetra
.664 .741 .908 r
.602 .47403 .60661 .47926 .61569 .47643 .6111 .47119 Metetra
.664 .741 .908 r
.6111 .47119 .61569 .47643 .6248 .4736 .62023 .46833 Metetra
.664 .741 .908 r
.62023 .46833 .6248 .4736 .63394 .47075 .62939 .46547 Metetra
.664 .741 .908 r
.62939 .46547 .63394 .47075 .64311 .46789 .63859 .46259 Metetra
.664 .741 .908 r
.63859 .46259 .64311 .46789 .65232 .46503 .64781 .45971 Metetra
.664 .741 .908 r
.64781 .45971 .65232 .46503 .66155 .46215 .65706 .45682 Metetra
.664 .741 .908 r
.65706 .45682 .66155 .46215 .67081 .45927 .66634 .45391 Metetra
.66 .74 .909 r
.66634 .45391 .67081 .45927 .6801 .45637 .67566 .45108 Metetra
.656 .742 .913 r
.67566 .45108 .6801 .45637 .68943 .45347 .68501 .44834 Metetra
.652 .748 .92 r
.68501 .44834 .68943 .45347 .69878 .45055 .6944 .44567 Metetra
.646 .757 .93 r
.6944 .44567 .69878 .45055 .70817 .44763 .70383 .4431 Metetra
.645 .773 .941 r
.70383 .4431 .70817 .44763 .71759 .44484 .71329 .44048 Metetra
.647 .782 .946 r
.71329 .44048 .71759 .44484 .72706 .44232 .72278 .43779 Metetra
.644 .774 .943 r
.72278 .43779 .72706 .44232 .73658 .43991 .73231 .43517 Metetra
.637 .763 .939 r
.73231 .43517 .73658 .43991 .74615 .43778 .74188 .43272 Metetra
.643 .752 .928 r
.74188 .43272 .74615 .43778 .75575 .43553 .75149 .43018 Metetra
.652 .744 .917 r
.75149 .43018 .75575 .43553 .76537 .433 .76111 .42745 Metetra
.661 .74 .908 r
.76111 .42745 .76537 .433 .77499 .43014 .77075 .4245 Metetra
.683 .745 .898 r
.77075 .4245 .77499 .43014 .78458 .42634 .78038 .42095 Metetra
.679 .754 .908 r
.78038 .42095 .78458 .42634 .7942 .42273 .79005 .41751 Metetra
.663 .756 .92 r
.79005 .41751 .7942 .42273 .80392 .41974 .79979 .41447 Metetra
.667 .756 .917 r
.79979 .41447 .80392 .41974 .81365 .41665 .80954 .41134 Metetra
.681 .76 .911 r
.80954 .41134 .81365 .41665 .82339 .41316 .8193 .40782 Metetra
.675 .758 .913 r
.8193 .40782 .82339 .41316 .83316 .4098 .8291 .40444 Metetra
.644 .746 .923 r
.8291 .40444 .83316 .4098 .84305 .40719 .83901 .40182 Metetra
.649 .748 .922 r
.83901 .40182 .84305 .40719 .85296 .40451 .84895 .39907 Metetra
.678 .758 .911 r
.84895 .39907 .85296 .40451 .86286 .40139 .85884 .39559 Metetra
.679 .745 .901 r
.85884 .39559 .86286 .40139 .87279 .39818 .86876 .39207 Metetra
.689 .738 .888 r
.86876 .39207 .87279 .39818 .88268 .39424 .87868 .38822 Metetra
.688 .741 .892 r
.87868 .38822 .88268 .39424 .89259 .39033 .88864 .38441 Metetra
.664 .736 .904 r
.88864 .38441 .89259 .39033 .90262 .38714 .8987 .38127 Metetra
.664 .739 .906 r
.8987 .38127 .90262 .38714 .91269 .38393 .9088 .37811 Metetra
.664 .741 .908 r
.9088 .37811 .91269 .38393 .92279 .38078 .91893 .37494 Metetra
.664 .741 .908 r
.91893 .37494 .92279 .38078 .93294 .37762 .9291 .37176 Metetra
.664 .741 .908 r
.3452 .54792 .35035 .55271 .35865 .55012 .35351 .54531 Metetra
.664 .741 .908 r
.35351 .54531 .35865 .55012 .36697 .54752 .36185 .54269 Metetra
.664 .741 .908 r
.36185 .54269 .36697 .54752 .37532 .5449 .37022 .54006 Metetra
.664 .741 .908 r
.37022 .54006 .37532 .5449 .3837 .54229 .37861 .53743 Metetra
.643 .736 .916 r
.37861 .53743 .3837 .54229 .39208 .54031 .38701 .53523 Metetra
.642 .727 .91 r
.38701 .53523 .39208 .54031 .40048 .53837 .39544 .53306 Metetra
.629 .715 .908 r
.39544 .53306 .40048 .53837 .40893 .53612 .40389 .53117 Metetra
.626 .729 .921 r
.40389 .53117 .40893 .53612 .4174 .53383 .41237 .5293 Metetra
.675 .76 .915 r
.41237 .5293 .4174 .53383 .42593 .53084 .42091 .52634 Metetra
.682 .764 .913 r
.42091 .52634 .42593 .53084 .43448 .52773 .42948 .52322 Metetra
.648 .756 .928 r
.42948 .52322 .43448 .52773 .44304 .52535 .43806 .52083 Metetra
.641 .754 .93 r
.43806 .52083 .44304 .52535 .45163 .52311 .44666 .51857 Metetra
.659 .759 .924 r
.44666 .51857 .45163 .52311 .46025 .5205 .4553 .51595 Metetra
.663 .76 .922 r
.4553 .51595 .46025 .5205 .4689 .5178 .46397 .51323 Metetra
.66 .759 .923 r
.46397 .51323 .4689 .5178 .47757 .51549 .47267 .51057 Metetra
.66 .745 .913 r
.47267 .51057 .47757 .51549 .48627 .51329 .48139 .50792 Metetra
.664 .729 .898 r
.48139 .50792 .48627 .51329 .49501 .5105 .49014 .50517 Metetra
.665 .731 .899 r
.49014 .50517 .49501 .5105 .50378 .50751 .49893 .50237 Metetra
.666 .74 .905 r
.49893 .50237 .50378 .50751 .51257 .50432 .50774 .49954 Metetra
.667 .755 .916 r
.50774 .49954 .51257 .50432 .52139 .50105 .51658 .49668 Metetra
.664 .773 .931 r
.51658 .49668 .52139 .50105 .53023 .49794 .52544 .49385 Metetra
.662 .786 .94 r
.52544 .49385 .53023 .49794 .53911 .49491 .53434 .49102 Metetra
.684 .802 .937 r
.53434 .49102 .53911 .49491 .54801 .4918 .54326 .48769 Metetra
.697 .795 .926 r
.54326 .48769 .54801 .4918 .55693 .48864 .5522 .48408 Metetra
.687 .773 .917 r
.5522 .48408 .55693 .48864 .56589 .48558 .56117 .4807 Metetra
.68 .759 .911 r
.56117 .4807 .56589 .48558 .57487 .48259 .57017 .47747 Metetra
.67 .747 .908 r
.57017 .47747 .57487 .48259 .58388 .4797 .5792 .47447 Metetra
.664 .741 .908 r
.5792 .47447 .58388 .4797 .59292 .47687 .58827 .47163 Metetra
.664 .741 .908 r
.58827 .47163 .59292 .47687 .602 .47403 .59736 .46877 Metetra
.664 .741 .908 r
.59736 .46877 .602 .47403 .6111 .47119 .60648 .46591 Metetra
.664 .741 .908 r
.60648 .46591 .6111 .47119 .62023 .46833 .61563 .46304 Metetra
.664 .741 .908 r
.61563 .46304 .62023 .46833 .62939 .46547 .62482 .46015 Metetra
.664 .741 .908 r
.62482 .46015 .62939 .46547 .63859 .46259 .63403 .45726 Metetra
.664 .741 .908 r
.63403 .45726 .63859 .46259 .64781 .45971 .64327 .45436 Metetra
.664 .741 .908 r
.64327 .45436 .64781 .45971 .65706 .45682 .65255 .45145 Metetra
.664 .741 .908 r
.65255 .45145 .65706 .45682 .66634 .45391 .66185 .44853 Metetra
.657 .739 .91 r
.66185 .44853 .66634 .45391 .67566 .45108 .67119 .44577 Metetra
.646 .739 .917 r
.67119 .44577 .67566 .45108 .68501 .44834 .68058 .44324 Metetra
.638 .745 .926 r
.68058 .44324 .68501 .44834 .6944 .44567 .69001 .44085 Metetra
.623 .753 .939 r
.69001 .44085 .6944 .44567 .70383 .4431 .69948 .43871 Metetra
.633 .777 .95 r
.69948 .43871 .70383 .4431 .71329 .44048 .70898 .43628 Metetra
.656 .794 .949 r
.70898 .43628 .71329 .44048 .72278 .43779 .71848 .43335 Metetra
.657 .784 .942 r
.71848 .43335 .72278 .43779 .73231 .43517 .72801 .43042 Metetra
.658 .771 .933 r
.72801 .43042 .73231 .43517 .74188 .43272 .73758 .42751 Metetra
.66 .753 .919 r
.73758 .42751 .74188 .43272 .75149 .43018 .74718 .42458 Metetra
.662 .738 .907 r
.74718 .42458 .75149 .43018 .76111 .42745 .75681 .4216 Metetra
.663 .73 .9 r
.75681 .4216 .76111 .42745 .77075 .4245 .76647 .41859 Metetra
.667 .73 .897 r
.76647 .41859 .77075 .4245 .78038 .42095 .77616 .41546 Metetra
.666 .747 .911 r
.77616 .41546 .78038 .42095 .79005 .41751 .78588 .41235 Metetra
.663 .76 .922 r
.78588 .41235 .79005 .41751 .79979 .41447 .79564 .40929 Metetra
.666 .761 .921 r
.79564 .40929 .79979 .41447 .80954 .41134 .80542 .40613 Metetra
.681 .766 .916 r
.80542 .40613 .80954 .41134 .8193 .40782 .8152 .4026 Metetra
.675 .764 .918 r
.8152 .4026 .8193 .40782 .8291 .40444 .82503 .3992 Metetra
.643 .752 .928 r
.82503 .3992 .8291 .40444 .83901 .40182 .83497 .39655 Metetra
.65 .755 .926 r
.83497 .39655 .83901 .40182 .84895 .39907 .84492 .39373 Metetra
.695 .769 .909 r
.84492 .39373 .84895 .39907 .85884 .39559 .85479 .38979 Metetra
.692 .751 .896 r
.85479 .38979 .85884 .39559 .86876 .39207 .8647 .38586 Metetra
.681 .732 .889 r
.8647 .38586 .86876 .39207 .87868 .38822 .87467 .38222 Metetra
.681 .74 .896 r
.87467 .38222 .87868 .38822 .88864 .38441 .88467 .3786 Metetra
.664 .741 .908 r
.88467 .3786 .88864 .38441 .8987 .38127 .89476 .37543 Metetra
.664 .741 .908 r
.89476 .37543 .8987 .38127 .9088 .37811 .90488 .37225 Metetra
.664 .741 .908 r
.90488 .37225 .9088 .37811 .91893 .37494 .91504 .36906 Metetra
.664 .741 .908 r
.91504 .36906 .91893 .37494 .9291 .37176 .92523 .36586 Metetra
.664 .741 .908 r
.34002 .54309 .3452 .54792 .35351 .54531 .34835 .54047 Metetra
.664 .741 .908 r
.34835 .54047 .35351 .54531 .36185 .54269 .3567 .53783 Metetra
.664 .741 .908 r
.3567 .53783 .36185 .54269 .37022 .54006 .36509 .53519 Metetra
.664 .741 .908 r
.36509 .53519 .37022 .54006 .37861 .53743 .3735 .53254 Metetra
.645 .736 .916 r
.3735 .53254 .37861 .53743 .38701 .53523 .38192 .5303 Metetra
.643 .734 .915 r
.38192 .5303 .38701 .53523 .39544 .53306 .39036 .52807 Metetra
.632 .729 .918 r
.39036 .52807 .39544 .53306 .40389 .53117 .39883 .52607 Metetra
.631 .726 .915 r
.39883 .52607 .40389 .53117 .41237 .5293 .40732 .5241 Metetra
.669 .733 .898 r
.40732 .5241 .41237 .5293 .42091 .52634 .41588 .52127 Metetra
.674 .74 .9 r
.41588 .52127 .42091 .52634 .42948 .52322 .42446 .5183 Metetra
.649 .74 .916 r
.42446 .5183 .42948 .52322 .43806 .52083 .43305 .51592 Metetra
.643 .739 .919 r
.43305 .51592 .43806 .52083 .44666 .51857 .44167 .51365 Metetra
.66 .744 .912 r
.44167 .51365 .44666 .51857 .4553 .51595 .45033 .51101 Metetra
.663 .745 .911 r
.45033 .51101 .4553 .51595 .46397 .51323 .45902 .50828 Metetra
.663 .745 .911 r
.45902 .50828 .46397 .51323 .47267 .51057 .46773 .50553 Metetra
.663 .742 .909 r
.46773 .50553 .47267 .51057 .48139 .50792 .47648 .50278 Metetra
.658 .737 .908 r
.47648 .50278 .48139 .50792 .49014 .50517 .48525 .50015 Metetra
.656 .742 .914 r
.48525 .50015 .49014 .50517 .49893 .50237 .49405 .49756 Metetra
.661 .753 .918 r
.49405 .49756 .49893 .50237 .50774 .49954 .50287 .49484 Metetra
.663 .759 .921 r
.50287 .49484 .50774 .49954 .51658 .49668 .51173 .49205 Metetra
.662 .762 .924 r
.51173 .49205 .51658 .49668 .52544 .49385 .52062 .48926 Metetra
.662 .765 .926 r
.52062 .48926 .52544 .49385 .53434 .49102 .52953 .48645 Metetra
.678 .771 .921 r
.52953 .48645 .53434 .49102 .54326 .48769 .53848 .48329 Metetra
.686 .781 .923 r
.53848 .48329 .54326 .48769 .5522 .48408 .54745 .47993 Metetra
.683 .792 .932 r
.54745 .47993 .5522 .48408 .56117 .4807 .55644 .47662 Metetra
.681 .795 .935 r
.55644 .47662 .56117 .4807 .57017 .47747 .56546 .47333 Metetra
.674 .791 .937 r
.56546 .47333 .57017 .47747 .5792 .47447 .57452 .47019 Metetra
.669 .785 .935 r
.57452 .47019 .5792 .47447 .58827 .47163 .5836 .46715 Metetra
.674 .778 .928 r
.5836 .46715 .58827 .47163 .59736 .46877 .59271 .464 Metetra
.678 .767 .918 r
.59271 .464 .59736 .46877 .60648 .46591 .60184 .46077 Metetra
.671 .75 .91 r
.60184 .46077 .60648 .46591 .61563 .46304 .61101 .45771 Metetra
.664 .741 .908 r
.61101 .45771 .61563 .46304 .62482 .46015 .62021 .45481 Metetra
.656 .739 .911 r
.62021 .45481 .62482 .46015 .63403 .45726 .62945 .45207 Metetra
.648 .743 .919 r
.62945 .45207 .63403 .45726 .64327 .45436 .63873 .44951 Metetra
.65 .759 .929 r
.63873 .44951 .64327 .45436 .65255 .45145 .64803 .44686 Metetra
.653 .772 .936 r
.64803 .44686 .65255 .45145 .66185 .44853 .65737 .4441 Metetra
.646 .778 .943 r
.65737 .4441 .66185 .44853 .67119 .44577 .66674 .44144 Metetra
.637 .78 .95 r
.66674 .44144 .67119 .44577 .68058 .44324 .67615 .43894 Metetra
.635 .781 .952 r
.67615 .43894 .68058 .44324 .69001 .44085 .6856 .43646 Metetra
.632 .777 .95 r
.6856 .43646 .69001 .44085 .69948 .43871 .69508 .43403 Metetra
.645 .769 .939 r
.69508 .43403 .69948 .43871 .70898 .43628 .70459 .43139 Metetra
.662 .766 .927 r
.70459 .43139 .70898 .43628 .71848 .43335 .71412 .4284 Metetra
.662 .765 .926 r
.71412 .4284 .71848 .43335 .72801 .43042 .72367 .42539 Metetra
.662 .762 .924 r
.72367 .42539 .72801 .43042 .73758 .42751 .73326 .42238 Metetra
.665 .759 .921 r
.73326 .42238 .73758 .42751 .74718 .42458 .74287 .4193 Metetra
.67 .756 .915 r
.74287 .4193 .74718 .42458 .75681 .4216 .75251 .41608 Metetra
.669 .747 .909 r
.75251 .41608 .75681 .4216 .76647 .41859 .76219 .4129 Metetra
.663 .739 .906 r
.76219 .4129 .76647 .41859 .77616 .41546 .7719 .40985 Metetra
.663 .742 .909 r
.7719 .40985 .77616 .41546 .78588 .41235 .78165 .40678 Metetra
.663 .745 .911 r
.78165 .40678 .78588 .41235 .79564 .40929 .79143 .4037 Metetra
.667 .746 .91 r
.79143 .4037 .79564 .40929 .80542 .40613 .80124 .40053 Metetra
.681 .752 .905 r
.80124 .40053 .80542 .40613 .8152 .4026 .81105 .39697 Metetra
.676 .75 .906 r
.81105 .39697 .8152 .4026 .82503 .3992 .8209 .39353 Metetra
.652 .739 .913 r
.8209 .39353 .82503 .3992 .83497 .39655 .83084 .39068 Metetra
.658 .735 .906 r
.83084 .39068 .83497 .39655 .84492 .39373 .8408 .3877 Metetra
.69 .742 .891 r
.8408 .3877 .84492 .39373 .85479 .38979 .85071 .38382 Metetra
.689 .745 .894 r
.85071 .38382 .85479 .38979 .8647 .38586 .86065 .37996 Metetra
.68 .745 .9 r
.86065 .37996 .8647 .38586 .87467 .38222 .87065 .37634 Metetra
.679 .746 .901 r
.87065 .37634 .87467 .38222 .88467 .3786 .88068 .37274 Metetra
.664 .741 .908 r
.88068 .37274 .88467 .3786 .89476 .37543 .89079 .36955 Metetra
.664 .741 .908 r
.89079 .36955 .89476 .37543 .90488 .37225 .90094 .36636 Metetra
.664 .741 .908 r
.90094 .36636 .90488 .37225 .91504 .36906 .91112 .36315 Metetra
.664 .741 .908 r
.91112 .36315 .91504 .36906 .92523 .36586 .92134 .35993 Metetra
.664 .741 .908 r
.33481 .53824 .34002 .54309 .34835 .54047 .34315 .5356 Metetra
.664 .741 .908 r
.34315 .5356 .34835 .54047 .3567 .53783 .35152 .53295 Metetra
.664 .741 .908 r
.35152 .53295 .3567 .53783 .36509 .53519 .35992 .53029 Metetra
.664 .741 .908 r
.35992 .53029 .36509 .53519 .3735 .53254 .36835 .52763 Metetra
.645 .736 .916 r
.36835 .52763 .3735 .53254 .38192 .5303 .37678 .52537 Metetra
.643 .736 .916 r
.37678 .52537 .38192 .5303 .39036 .52807 .38525 .52313 Metetra
.641 .735 .917 r
.38525 .52313 .39036 .52807 .39883 .52607 .39374 .52092 Metetra
.642 .728 .911 r
.39374 .52092 .39883 .52607 .40732 .5241 .40225 .51871 Metetra
.662 .725 .896 r
.40225 .51871 .40732 .5241 .41588 .52127 .41082 .51603 Metetra
.665 .732 .899 r
.41082 .51603 .41588 .52127 .42446 .5183 .41941 .51326 Metetra
.647 .736 .914 r
.41941 .51326 .42446 .5183 .43305 .51592 .42802 .5109 Metetra
.643 .736 .916 r
.42802 .5109 .43305 .51592 .44167 .51365 .43666 .50861 Metetra
.66 .741 .91 r
.43666 .50861 .44167 .51365 .45033 .51101 .44533 .50596 Metetra
.663 .742 .908 r
.44533 .50596 .45033 .51101 .45902 .50828 .45404 .50321 Metetra
.663 .742 .908 r
.45404 .50321 .45902 .50828 .46773 .50553 .46277 .50045 Metetra
.663 .742 .908 r
.46277 .50045 .46773 .50553 .47648 .50278 .47153 .49768 Metetra
.651 .738 .913 r
.47153 .49768 .47648 .50278 .48525 .50015 .48032 .4952 Metetra
.645 .743 .92 r
.48032 .4952 .48525 .50015 .49405 .49756 .48913 .49281 Metetra
.658 .756 .922 r
.48913 .49281 .49405 .49756 .50287 .49484 .49798 .49013 Metetra
.663 .76 .922 r
.49798 .49013 .50287 .49484 .51173 .49205 .50686 .48733 Metetra
.663 .76 .922 r
.50686 .48733 .51173 .49205 .52062 .48926 .51577 .48452 Metetra
.663 .76 .922 r
.51577 .48452 .52062 .48926 .52953 .48645 .5247 .4817 Metetra
.665 .761 .921 r
.5247 .4817 .52953 .48645 .53848 .48329 .53366 .4788 Metetra
.666 .773 .929 r
.53366 .4788 .53848 .48329 .54745 .47993 .54266 .47587 Metetra
.674 .795 .939 r
.54266 .47587 .54745 .47993 .55644 .47662 .55168 .4727 Metetra
.68 .804 .941 r
.55168 .4727 .55644 .47662 .56546 .47333 .56072 .4694 Metetra
.678 .804 .942 r
.56072 .4694 .56546 .47333 .57452 .47019 .5698 .46611 Metetra
.678 .798 .939 r
.5698 .46611 .57452 .47019 .5836 .46715 .5789 .46284 Metetra
.689 .79 .928 r
.5789 .46284 .5836 .46715 .59271 .464 .58803 .45933 Metetra
.696 .778 .914 r
.58803 .45933 .59271 .464 .60184 .46077 .59717 .45564 Metetra
.679 .755 .908 r
.59717 .45564 .60184 .46077 .61101 .45771 .60636 .45235 Metetra
.664 .741 .908 r
.60636 .45235 .61101 .45771 .62021 .45481 .61558 .44943 Metetra
.647 .736 .914 r
.61558 .44943 .62021 .45481 .62945 .45207 .62485 .44689 Metetra
.627 .737 .926 r
.62485 .44689 .62945 .45207 .63873 .44951 .63416 .44475 Metetra
.633 .758 .938 r
.63416 .44475 .63873 .44951 .64803 .44686 .6435 .44243 Metetra
.641 .776 .946 r
.6435 .44243 .64803 .44686 .65737 .4441 .65287 .43987 Metetra
.637 .786 .953 r
.65287 .43987 .65737 .4441 .66674 .44144 .66227 .43733 Metetra
.634 .791 .957 r
.66227 .43733 .66674 .44144 .67615 .43894 .6717 .43481 Metetra
.641 .793 .955 r
.6717 .43481 .67615 .43894 .6856 .43646 .68117 .43214 Metetra
.654 .789 .947 r
.68117 .43214 .6856 .43646 .69508 .43403 .69066 .42925 Metetra
.659 .771 .932 r
.69066 .42925 .69508 .43403 .70459 .43139 .70017 .42631 Metetra
.663 .76 .922 r
.70017 .42631 .70459 .43139 .71412 .4284 .70972 .42329 Metetra
.663 .76 .922 r
.70972 .42329 .71412 .4284 .72367 .42539 .7193 .42027 Metetra
.663 .76 .922 r
.7193 .42027 .72367 .42539 .73326 .42238 .72891 .41724 Metetra
.668 .761 .92 r
.72891 .41724 .73326 .42238 .74287 .4193 .73854 .41408 Metetra
.679 .763 .914 r
.73854 .41408 .74287 .4193 .75251 .41608 .74819 .41062 Metetra
.675 .752 .909 r
.74819 .41062 .75251 .41608 .76219 .4129 .75788 .40725 Metetra
.663 .742 .908 r
.75788 .40725 .76219 .4129 .7719 .40985 .76762 .40418 Metetra
.663 .742 .908 r
.76762 .40418 .7719 .40985 .78165 .40678 .77739 .40109 Metetra
.663 .742 .908 r
.77739 .40109 .78165 .40678 .79143 .4037 .78719 .39799 Metetra
.667 .743 .907 r
.78719 .39799 .79143 .4037 .80124 .40053 .79702 .3948 Metetra
.681 .748 .902 r
.79702 .3948 .80124 .40053 .81105 .39697 .80686 .39123 Metetra
.678 .747 .903 r
.80686 .39123 .81105 .39697 .8209 .39353 .81673 .38772 Metetra
.661 .739 .908 r
.81673 .38772 .8209 .39353 .83084 .39068 .82667 .38463 Metetra
.664 .732 .9 r
.82667 .38463 .83084 .39068 .8408 .3877 .83664 .38146 Metetra
.681 .733 .889 r
.83664 .38146 .8408 .3877 .85071 .38382 .84659 .37779 Metetra
.682 .741 .896 r
.84659 .37779 .85071 .38382 .86065 .37996 .85658 .37412 Metetra
.681 .748 .902 r
.85658 .37412 .86065 .37996 .87065 .37634 .8666 .37047 Metetra
.68 .748 .903 r
.8666 .37047 .87065 .37634 .88068 .37274 .87666 .36685 Metetra
.664 .741 .908 r
.87666 .36685 .88068 .37274 .89079 .36955 .8868 .36364 Metetra
.664 .741 .908 r
.8868 .36364 .89079 .36955 .90094 .36636 .89697 .36042 Metetra
.664 .741 .908 r
.89697 .36042 .90094 .36636 .91112 .36315 .90718 .3572 Metetra
.664 .741 .908 r
.90718 .3572 .91112 .36315 .92134 .35993 .91743 .35396 Metetra
.664 .741 .908 r
.32956 .53336 .33481 .53824 .34315 .5356 .33793 .5307 Metetra
.664 .741 .908 r
.33793 .5307 .34315 .5356 .35152 .53295 .34632 .52804 Metetra
.664 .741 .908 r
.34632 .52804 .35152 .53295 .35992 .53029 .35473 .52537 Metetra
.664 .741 .908 r
.35473 .52537 .35992 .53029 .36835 .52763 .36317 .52269 Metetra
.652 .738 .913 r
.36317 .52269 .36835 .52763 .37678 .52537 .37163 .52025 Metetra
.652 .732 .908 r
.37163 .52025 .37678 .52537 .38525 .52313 .38012 .51783 Metetra
.645 .723 .906 r
.38012 .51783 .38525 .52313 .39374 .52092 .38862 .51555 Metetra
.644 .721 .904 r
.38862 .51555 .39374 .52092 .40225 .51871 .39716 .51327 Metetra
.642 .718 .903 r
.39716 .51327 .40225 .51871 .41082 .51603 .40572 .51105 Metetra
.64 .737 .919 r
.40572 .51105 .41082 .51603 .41941 .51326 .41431 .50882 Metetra
.654 .764 .93 r
.41431 .50882 .41941 .51326 .42802 .5109 .42295 .50625 Metetra
.658 .757 .923 r
.42295 .50625 .42802 .5109 .43666 .50861 .43161 .50361 Metetra
.662 .744 .911 r
.43161 .50361 .43666 .50861 .44533 .50596 .44031 .50087 Metetra
.663 .742 .908 r
.44031 .50087 .44533 .50596 .45404 .50321 .44903 .49811 Metetra
.663 .742 .908 r
.44903 .49811 .45404 .50321 .46277 .50045 .45778 .49533 Metetra
.663 .742 .908 r
.45778 .49533 .46277 .50045 .47153 .49768 .46656 .49255 Metetra
.649 .737 .914 r
.46656 .49255 .47153 .49768 .48032 .4952 .47536 .49009 Metetra
.643 .737 .917 r
.47536 .49009 .48032 .4952 .48913 .49281 .48419 .48773 Metetra
.658 .743 .913 r
.48419 .48773 .48913 .49281 .49798 .49013 .49306 .48505 Metetra
.663 .746 .911 r
.49306 .48505 .49798 .49013 .50686 .48733 .50196 .48223 Metetra
.658 .744 .913 r
.50196 .48223 .50686 .48733 .51577 .48452 .51088 .47952 Metetra
.656 .748 .918 r
.51088 .47952 .51577 .48452 .5247 .4817 .51984 .47685 Metetra
.66 .756 .921 r
.51984 .47685 .5247 .4817 .53366 .4788 .52882 .47407 Metetra
.662 .762 .924 r
.52882 .47407 .53366 .4788 .54266 .47587 .53784 .47121 Metetra
.67 .769 .924 r
.53784 .47121 .54266 .47587 .55168 .4727 .54688 .46818 Metetra
.674 .776 .927 r
.54688 .46818 .55168 .4727 .56072 .4694 .55595 .46502 Metetra
.669 .782 .934 r
.55595 .46502 .56072 .4694 .5698 .46611 .56505 .46196 Metetra
.664 .792 .943 r
.56505 .46196 .5698 .46611 .5789 .46284 .57418 .45896 Metetra
.67 .807 .949 r
.57418 .45896 .5789 .46284 .58803 .45933 .58334 .4558 Metetra
.673 .825 .956 r
.58334 .4558 .58803 .45933 .59717 .45564 .59252 .4525 Metetra
.656 .841 .971 r
.59252 .4525 .59717 .45564 .60636 .45235 .60173 .44939 Metetra
.64 .847 .979 r
.60173 .44939 .60636 .45235 .61558 .44943 .61098 .44646 Metetra
.628 .843 .982 r
.61098 .44646 .61558 .44943 .62485 .44689 .62027 .4437 Metetra
.62 .83 .981 r
.62027 .4437 .62485 .44689 .63416 .44475 .6296 .44113 Metetra
.637 .815 .968 r
.6296 .44113 .63416 .44475 .6435 .44243 .63895 .43843 Metetra
.651 .802 .955 r
.63895 .43843 .6435 .44243 .65287 .43987 .64833 .43557 Metetra
.65 .788 .948 r
.64833 .43557 .65287 .43987 .66227 .43733 .65775 .43276 Metetra
.647 .775 .942 r
.65775 .43276 .66227 .43733 .6717 .43481 .6672 .43005 Metetra
.654 .77 .934 r
.6672 .43005 .6717 .43481 .68117 .43214 .67668 .42722 Metetra
.662 .767 .927 r
.67668 .42722 .68117 .43214 .69066 .42925 .68619 .42421 Metetra
.665 .763 .923 r
.68619 .42421 .69066 .42925 .70017 .42631 .69572 .42113 Metetra
.67 .76 .918 r
.69572 .42113 .70017 .42631 .70972 .42329 .70528 .41792 Metetra
.668 .752 .913 r
.70528 .41792 .70972 .42329 .7193 .42027 .71487 .41476 Metetra
.663 .746 .911 r
.71487 .41476 .7193 .42027 .72891 .41724 .72451 .41171 Metetra
.668 .748 .91 r
.72451 .41171 .72891 .41724 .73854 .41408 .73417 .40852 Metetra
.681 .751 .905 r
.73417 .40852 .73854 .41408 .74819 .41062 .74383 .40499 Metetra
.676 .748 .905 r
.74383 .40499 .74819 .41062 .75788 .40725 .75354 .40157 Metetra
.663 .742 .908 r
.75354 .40157 .75788 .40725 .76762 .40418 .7633 .39847 Metetra
.663 .742 .908 r
.7633 .39847 .76762 .40418 .77739 .40109 .7731 .39537 Metetra
.663 .742 .908 r
.7731 .39537 .77739 .40109 .78719 .39799 .78293 .39225 Metetra
.664 .742 .908 r
.78293 .39225 .78719 .39799 .79702 .3948 .79279 .3891 Metetra
.668 .746 .909 r
.79279 .3891 .79702 .3948 .80686 .39123 .80267 .38586 Metetra
.67 .761 .918 r
.80267 .38586 .80686 .39123 .81673 .38772 .81259 .38253 Metetra
.684 .774 .919 r
.81259 .38253 .81673 .38772 .82667 .38463 .8225 .37885 Metetra
.683 .751 .903 r
.8225 .37885 .82667 .38463 .83664 .38146 .83245 .37516 Metetra
.679 .731 .889 r
.83245 .37516 .83664 .38146 .84659 .37779 .84244 .37152 Metetra
.679 .733 .891 r
.84244 .37152 .84659 .37779 .85658 .37412 .85245 .36789 Metetra
.674 .733 .895 r
.85245 .36789 .85658 .37412 .8666 .37047 .86252 .3644 Metetra
.673 .739 .9 r
.86252 .3644 .8666 .37047 .87666 .36685 .87262 .36092 Metetra
.664 .741 .908 r
.87262 .36092 .87666 .36685 .8868 .36364 .88278 .35769 Metetra
.664 .741 .908 r
.88278 .35769 .8868 .36364 .89697 .36042 .89298 .35445 Metetra
.664 .741 .908 r
.89298 .35445 .89697 .36042 .90718 .3572 .90322 .3512 Metetra
.664 .741 .908 r
.90322 .3512 .90718 .3572 .91743 .35396 .91349 .34794 Metetra
.664 .741 .908 r
.32429 .52845 .32956 .53336 .33793 .5307 .33267 .52578 Metetra
.664 .741 .908 r
.33267 .52578 .33793 .5307 .34632 .52804 .34108 .5231 Metetra
.664 .741 .908 r
.34108 .5231 .34632 .52804 .35473 .52537 .34951 .52041 Metetra
.664 .741 .908 r
.34951 .52041 .35473 .52537 .36317 .52269 .35797 .51772 Metetra
.661 .741 .909 r
.35797 .51772 .36317 .52269 .37163 .52025 .36645 .51506 Metetra
.661 .733 .903 r
.36645 .51506 .37163 .52025 .38012 .51783 .37496 .51241 Metetra
.646 .72 .902 r
.37496 .51241 .38012 .51783 .38862 .51555 .38348 .51009 Metetra
.644 .719 .902 r
.38348 .51009 .38862 .51555 .39716 .51327 .39203 .5078 Metetra
.615 .709 .912 r
.39203 .5078 .39716 .51327 .40572 .51105 .40059 .50613 Metetra
.605 .729 .933 r
.40059 .50613 .40572 .51105 .41431 .50882 .40918 .50454 Metetra
.666 .775 .931 r
.40918 .50454 .41431 .50882 .42295 .50625 .41784 .50169 Metetra
.677 .766 .918 r
.41784 .50169 .42295 .50625 .43161 .50361 .42653 .4986 Metetra
.666 .746 .91 r
.42653 .4986 .43161 .50361 .44031 .50087 .43525 .49576 Metetra
.663 .742 .908 r
.43525 .49576 .44031 .50087 .44903 .49811 .44399 .49298 Metetra
.663 .742 .908 r
.44399 .49298 .44903 .49811 .45778 .49533 .45276 .49019 Metetra
.663 .742 .908 r
.45276 .49019 .45778 .49533 .46656 .49255 .46156 .48739 Metetra
.649 .737 .914 r
.46156 .48739 .46656 .49255 .47536 .49009 .47038 .48491 Metetra
.644 .736 .916 r
.47038 .48491 .47536 .49009 .48419 .48773 .47923 .48254 Metetra
.658 .74 .911 r
.47923 .48254 .48419 .48773 .49306 .48505 .48811 .47984 Metetra
.663 .742 .908 r
.48811 .47984 .49306 .48505 .50196 .48223 .49703 .477 Metetra
.652 .738 .913 r
.49703 .477 .50196 .48223 .51088 .47952 .50597 .47442 Metetra
.646 .742 .919 r
.50597 .47442 .51088 .47952 .51984 .47685 .51494 .47196 Metetra
.657 .755 .922 r
.51494 .47196 .51984 .47685 .52882 .47407 .52395 .46923 Metetra
.663 .76 .922 r
.52395 .46923 .52882 .47407 .53784 .47121 .53298 .46636 Metetra
.664 .76 .922 r
.53298 .46636 .53784 .47121 .54688 .46818 .54205 .46344 Metetra
.665 .766 .925 r
.54205 .46344 .54688 .46818 .55595 .46502 .55114 .4605 Metetra
.653 .772 .936 r
.55114 .4605 .55595 .46502 .56505 .46196 .56027 .45777 Metetra
.642 .785 .95 r
.56027 .45777 .56505 .46196 .57418 .45896 .56943 .45519 Metetra
.638 .804 .963 r
.56943 .45519 .57418 .45896 .58334 .4558 .57862 .45257 Metetra
.629 .83 .978 r
.57862 .45257 .58334 .4558 .59252 .4525 .58784 .44992 Metetra
.619 .86 .988 r
.58784 .44992 .59252 .4525 .60173 .44939 .59709 .44712 Metetra
.617 .875 .99 r
.59709 .44712 .60173 .44939 .61098 .44646 .60637 .44417 Metetra
.627 .878 .988 r
.60637 .44417 .61098 .44646 .62027 .4437 .61568 .44108 Metetra
.648 .868 .982 r
.61568 .44108 .62027 .4437 .6296 .44113 .62501 .43783 Metetra
.664 .84 .967 r
.62501 .43783 .6296 .44113 .63895 .43843 .63437 .43454 Metetra
.672 .814 .951 r
.63437 .43454 .63895 .43843 .64833 .43557 .64376 .43122 Metetra
.667 .792 .941 r
.64376 .43122 .64833 .43557 .65775 .43276 .65319 .42805 Metetra
.659 .774 .934 r
.65319 .42805 .65775 .43276 .6672 .43005 .66266 .42509 Metetra
.661 .765 .927 r
.66266 .42509 .6672 .43005 .67668 .42722 .67216 .42211 Metetra
.663 .76 .922 r
.67216 .42211 .67668 .42722 .68619 .42421 .68168 .41908 Metetra
.669 .762 .92 r
.68168 .41908 .68619 .42421 .69572 .42113 .69124 .4159 Metetra
.679 .762 .914 r
.69124 .4159 .69572 .42113 .70528 .41792 .70081 .41245 Metetra
.674 .751 .909 r
.70081 .41245 .70528 .41792 .71487 .41476 .71042 .40912 Metetra
.663 .742 .908 r
.71042 .40912 .71487 .41476 .72451 .41171 .72007 .40605 Metetra
.668 .744 .906 r
.72007 .40605 .72451 .41171 .73417 .40852 .72976 .40283 Metetra
.681 .748 .902 r
.72976 .40283 .73417 .40852 .74383 .40499 .73945 .39929 Metetra
.676 .746 .904 r
.73945 .39929 .74383 .40499 .75354 .40157 .74918 .39584 Metetra
.663 .742 .908 r
.74918 .39584 .75354 .40157 .7633 .39847 .75896 .39273 Metetra
.663 .742 .908 r
.75896 .39273 .7633 .39847 .7731 .39537 .76878 .3896 Metetra
.663 .742 .908 r
.76878 .3896 .7731 .39537 .78293 .39225 .77863 .38647 Metetra
.661 .741 .909 r
.77863 .38647 .78293 .39225 .79279 .3891 .78853 .38339 Metetra
.65 .739 .915 r
.78853 .38339 .79279 .3891 .80267 .38586 .79848 .38057 Metetra
.659 .761 .926 r
.79848 .38057 .80267 .38586 .81259 .38253 .80844 .3775 Metetra
.71 .791 .915 r
.80844 .3775 .81259 .38253 .8225 .37885 .81832 .37312 Metetra
.704 .762 .897 r
.81832 .37312 .8225 .37885 .83245 .37516 .82824 .36882 Metetra
.679 .731 .889 r
.82824 .36882 .83245 .37516 .84244 .37152 .83825 .36516 Metetra
.678 .73 .89 r
.83825 .36516 .84244 .37152 .85245 .36789 .84829 .36153 Metetra
.665 .726 .895 r
.84829 .36153 .85245 .36789 .86252 .3644 .8584 .35824 Metetra
.666 .734 .901 r
.8584 .35824 .86252 .3644 .87262 .36092 .86855 .35495 Metetra
.664 .741 .908 r
.86855 .35495 .87262 .36092 .88278 .35769 .87874 .35171 Metetra
.664 .741 .908 r
.87874 .35171 .88278 .35769 .89298 .35445 .88897 .34845 Metetra
.664 .741 .908 r
.88897 .34845 .89298 .35445 .90322 .3512 .89923 .34517 Metetra
.664 .741 .908 r
.89923 .34517 .90322 .3512 .91349 .34794 .90953 .34189 Metetra
.664 .741 .908 r
.31899 .52351 .32429 .52845 .33267 .52578 .32738 .52083 Metetra
.664 .741 .908 r
.32738 .52083 .33267 .52578 .34108 .5231 .3358 .51813 Metetra
.664 .741 .908 r
.3358 .51813 .34108 .5231 .34951 .52041 .34425 .51543 Metetra
.664 .741 .908 r
.34425 .51543 .34951 .52041 .35797 .51772 .35273 .51272 Metetra
.664 .741 .908 r
.35273 .51272 .35797 .51772 .36645 .51506 .36123 .50999 Metetra
.664 .739 .906 r
.36123 .50999 .36645 .51506 .37496 .51241 .36976 .50726 Metetra
.652 .734 .909 r
.36976 .50726 .37496 .51241 .38348 .51009 .37831 .50478 Metetra
.651 .728 .905 r
.37831 .50478 .38348 .51009 .39203 .5078 .38688 .50231 Metetra
.608 .708 .915 r
.38688 .50231 .39203 .5078 .40059 .50613 .39545 .50075 Metetra
.6 .71 .921 r
.39545 .50075 .40059 .50613 .40918 .50454 .40404 .49932 Metetra
.664 .737 .904 r
.40404 .49932 .40918 .50454 .41784 .50169 .41272 .49653 Metetra
.675 .742 .901 r
.41272 .49653 .41784 .50169 .42653 .4986 .42143 .49346 Metetra
.66 .74 .909 r
.42143 .49346 .42653 .4986 .43525 .49576 .43016 .49075 Metetra
.656 .745 .915 r
.43016 .49075 .43525 .49576 .44399 .49298 .43891 .48811 Metetra
.661 .753 .918 r
.43891 .48811 .44399 .49298 .45276 .49019 .4477 .48534 Metetra
.663 .755 .918 r
.4477 .48534 .45276 .49019 .46156 .48739 .45652 .48253 Metetra
.648 .75 .924 r
.45652 .48253 .46156 .48739 .47038 .48491 .46536 .48003 Metetra
.642 .749 .926 r
.46536 .48003 .47038 .48491 .47923 .48254 .47422 .47764 Metetra
.657 .753 .921 r
.47422 .47764 .47923 .48254 .48811 .47984 .48313 .47493 Metetra
.663 .755 .919 r
.48313 .47493 .48811 .47984 .49703 .477 .49206 .47208 Metetra
.654 .752 .922 r
.49206 .47208 .49703 .477 .50597 .47442 .50103 .46941 Metetra
.65 .748 .921 r
.50103 .46941 .50597 .47442 .51494 .47196 .51002 .46682 Metetra
.654 .745 .917 r
.51002 .46682 .51494 .47196 .52395 .46923 .51904 .46415 Metetra
.656 .748 .918 r
.51904 .46415 .52395 .46923 .53298 .46636 .5281 .46142 Metetra
.655 .755 .923 r
.5281 .46142 .53298 .46636 .54205 .46344 .53718 .45868 Metetra
.655 .763 .929 r
.53718 .45868 .54205 .46344 .55114 .4605 .5463 .45594 Metetra
.655 .773 .936 r
.5463 .45594 .55114 .4605 .56027 .45777 .55545 .45316 Metetra
.656 .772 .934 r
.55545 .45316 .56027 .45777 .56943 .45519 .56463 .45035 Metetra
.653 .761 .929 r
.56463 .45035 .56943 .45519 .57862 .45257 .57384 .44763 Metetra
.65 .756 .928 r
.57384 .44763 .57862 .45257 .58784 .44992 .58308 .44497 Metetra
.656 .759 .925 r
.58308 .44497 .58784 .44992 .59709 .44712 .59235 .44215 Metetra
.662 .761 .923 r
.59235 .44215 .59709 .44712 .60637 .44417 .60166 .43918 Metetra
.668 .763 .921 r
.60166 .43918 .60637 .44417 .61568 .44108 .61099 .43607 Metetra
.675 .765 .918 r
.61099 .43607 .61568 .44108 .62501 .43783 .62034 .43279 Metetra
.672 .763 .919 r
.62034 .43279 .62501 .43783 .63437 .43454 .62973 .42958 Metetra
.668 .766 .924 r
.62973 .42958 .63437 .43454 .64376 .43122 .63915 .42645 Metetra
.668 .775 .93 r
.63915 .42645 .64376 .43122 .65319 .42805 .6486 .42329 Metetra
.669 .777 .931 r
.6486 .42329 .65319 .42805 .66266 .42509 .65809 .4201 Metetra
.669 .768 .924 r
.65809 .4201 .66266 .42509 .67216 .42211 .6676 .4169 Metetra
.67 .759 .918 r
.6676 .4169 .67216 .42211 .68168 .41908 .67714 .41368 Metetra
.672 .753 .912 r
.67714 .41368 .68168 .41908 .69124 .4159 .68672 .41041 Metetra
.675 .752 .909 r
.68672 .41041 .69124 .4159 .70081 .41245 .69632 .40706 Metetra
.671 .755 .913 r
.69632 .40706 .70081 .41245 .71042 .40912 .70595 .40378 Metetra
.663 .755 .919 r
.70595 .40378 .71042 .40912 .72007 .40605 .71563 .40069 Metetra
.668 .757 .917 r
.71563 .40069 .72007 .40605 .72976 .40283 .72534 .39746 Metetra
.681 .761 .912 r
.72534 .39746 .72976 .40283 .73945 .39929 .73505 .39389 Metetra
.677 .76 .914 r
.73505 .39389 .73945 .39929 .74918 .39584 .74481 .39043 Metetra
.663 .755 .918 r
.74481 .39043 .74918 .39584 .75896 .39273 .75462 .38729 Metetra
.665 .755 .918 r
.75462 .38729 .75896 .39273 .76878 .3896 .76446 .38411 Metetra
.67 .756 .915 r
.76446 .38411 .76878 .3896 .77863 .38647 .77432 .38079 Metetra
.666 .748 .911 r
.77432 .38079 .77863 .38647 .78853 .38339 .78423 .37754 Metetra
.652 .737 .912 r
.78423 .37754 .78853 .38339 .79848 .38057 .7942 .37465 Metetra
.662 .739 .907 r
.7942 .37465 .79848 .38057 .80844 .3775 .80418 .37149 Metetra
.711 .755 .886 r
.80418 .37149 .80844 .3775 .81832 .37312 .81407 .36691 Metetra
.706 .747 .883 r
.81407 .36691 .81832 .37312 .82824 .36882 .824 .36247 Metetra
.674 .729 .892 r
.824 .36247 .82824 .36882 .83825 .36516 .83405 .35895 Metetra
.673 .735 .897 r
.83405 .35895 .83825 .36516 .84829 .36153 .84413 .35545 Metetra
.664 .737 .905 r
.84413 .35545 .84829 .36153 .8584 .35824 .85428 .35221 Metetra
.664 .739 .906 r
.85428 .35221 .8584 .35824 .86855 .35495 .86446 .34895 Metetra
.664 .741 .908 r
.86446 .34895 .86855 .35495 .87874 .35171 .87467 .34568 Metetra
.664 .741 .908 r
.87467 .34568 .87874 .35171 .88897 .34845 .88492 .3424 Metetra
.664 .741 .908 r
.88492 .3424 .88897 .34845 .89923 .34517 .89521 .33911 Metetra
.664 .741 .908 r
.89521 .33911 .89923 .34517 .90953 .34189 .90553 .3358 Metetra
.664 .741 .908 r
.31365 .51855 .31899 .52351 .32738 .52083 .32207 .51584 Metetra
.664 .741 .908 r
.32207 .51584 .32738 .52083 .3358 .51813 .3305 .51313 Metetra
.664 .741 .908 r
.3305 .51313 .3358 .51813 .34425 .51543 .33897 .51041 Metetra
.664 .741 .908 r
.33897 .51041 .34425 .51543 .35273 .51272 .34746 .50769 Metetra
.664 .741 .908 r
.34746 .50769 .35273 .51272 .36123 .50999 .35598 .50495 Metetra
.664 .741 .908 r
.35598 .50495 .36123 .50999 .36976 .50726 .36453 .5022 Metetra
.661 .741 .909 r
.36453 .5022 .36976 .50726 .37831 .50478 .3731 .4995 Metetra
.661 .733 .903 r
.3731 .4995 .37831 .50478 .38688 .50231 .3817 .4968 Metetra
.61 .709 .915 r
.3817 .4968 .38688 .50231 .39545 .50075 .39028 .4952 Metetra
.601 .705 .916 r
.39028 .4952 .39545 .50075 .40404 .49932 .39889 .49375 Metetra
.656 .723 .898 r
.39889 .49375 .40404 .49932 .41272 .49653 .40757 .49112 Metetra
.666 .732 .899 r
.40757 .49112 .41272 .49653 .42143 .49346 .4163 .48826 Metetra
.65 .736 .912 r
.4163 .48826 .42143 .49346 .43016 .49075 .42503 .48575 Metetra
.646 .744 .92 r
.42503 .48575 .43016 .49075 .43891 .48811 .4338 .48332 Metetra
.659 .756 .922 r
.4338 .48332 .43891 .48811 .4477 .48534 .44261 .48058 Metetra
.663 .76 .922 r
.44261 .48058 .4477 .48534 .45652 .48253 .45144 .47775 Metetra
.647 .755 .928 r
.45144 .47775 .45652 .48253 .46536 .48003 .4603 .47524 Metetra
.642 .753 .93 r
.4603 .47524 .46536 .48003 .47422 .47764 .46919 .47283 Metetra
.657 .758 .924 r
.46919 .47283 .47422 .47764 .48313 .47493 .47811 .4701 Metetra
.663 .76 .922 r
.47811 .4701 .48313 .47493 .49206 .47208 .48707 .46723 Metetra
.661 .759 .923 r
.48707 .46723 .49206 .47208 .50103 .46941 .49605 .4644 Metetra
.66 .753 .919 r
.49605 .4644 .50103 .46941 .51002 .46682 .50506 .46157 Metetra
.651 .741 .915 r
.50506 .46157 .51002 .46682 .51904 .46415 .51411 .45894 Metetra
.646 .742 .919 r
.51411 .45894 .51904 .46415 .5281 .46142 .52318 .45642 Metetra
.645 .751 .926 r
.52318 .45642 .5281 .46142 .53718 .45868 .53229 .45389 Metetra
.644 .76 .933 r
.53229 .45389 .53718 .45868 .5463 .45594 .54143 .45135 Metetra
.663 .775 .933 r
.54143 .45135 .5463 .45594 .55545 .45316 .5506 .44839 Metetra
.676 .772 .923 r
.5506 .44839 .55545 .45316 .56463 .45035 .55979 .44512 Metetra
.668 .751 .913 r
.55979 .44512 .56463 .45035 .57384 .44763 .56902 .44206 Metetra
.661 .736 .906 r
.56902 .44206 .57384 .44763 .58308 .44497 .57828 .43916 Metetra
.662 .728 .899 r
.57828 .43916 .58308 .44497 .59235 .44215 .58757 .43621 Metetra
.663 .725 .895 r
.58757 .43621 .59235 .44215 .60166 .43918 .59689 .43323 Metetra
.664 .725 .895 r
.59689 .43323 .60166 .43918 .61099 .43607 .60624 .4302 Metetra
.666 .73 .897 r
.60624 .4302 .61099 .43607 .62034 .43279 .61563 .42713 Metetra
.659 .736 .907 r
.61563 .42713 .62034 .43279 .62973 .42958 .62505 .42422 Metetra
.649 .745 .919 r
.62505 .42422 .62973 .42958 .63915 .42645 .6345 .42152 Metetra
.661 .767 .929 r
.6345 .42152 .63915 .42645 .6486 .42329 .64399 .41851 Metetra
.679 .78 .927 r
.64399 .41851 .6486 .42329 .65809 .4201 .65348 .41508 Metetra
.679 .771 .92 r
.65348 .41508 .65809 .4201 .6676 .4169 .66301 .41163 Metetra
.679 .762 .914 r
.66301 .41163 .6676 .4169 .67714 .41368 .67257 .40817 Metetra
.674 .751 .909 r
.67257 .40817 .67714 .41368 .68672 .41041 .68216 .40482 Metetra
.666 .746 .91 r
.68216 .40482 .68672 .41041 .69632 .40706 .6918 .40166 Metetra
.665 .754 .917 r
.6918 .40166 .69632 .40706 .70595 .40378 .70146 .39852 Metetra
.663 .76 .922 r
.70146 .39852 .70595 .40378 .71563 .40069 .71117 .39541 Metetra
.668 .762 .92 r
.71117 .39541 .71563 .40069 .72534 .39746 .7209 .39216 Metetra
.681 .766 .915 r
.7209 .39216 .72534 .39746 .73505 .39389 .73064 .38857 Metetra
.677 .764 .917 r
.73064 .38857 .73505 .39389 .74481 .39043 .74042 .38509 Metetra
.663 .76 .922 r
.74042 .38509 .74481 .39043 .75462 .38729 .75025 .38193 Metetra
.666 .761 .921 r
.75025 .38193 .75462 .38729 .76446 .38411 .76012 .37868 Metetra
.679 .763 .915 r
.76012 .37868 .76446 .38411 .77432 .38079 .76999 .37511 Metetra
.675 .753 .91 r
.76999 .37511 .77432 .38079 .78423 .37754 .7799 .37162 Metetra
.661 .739 .908 r
.7799 .37162 .78423 .37754 .7942 .37465 .78988 .36849 Metetra
.669 .734 .898 r
.78988 .36849 .7942 .37465 .80418 .37149 .79987 .36511 Metetra
.709 .743 .878 r
.79987 .36511 .80418 .37149 .81407 .36691 .80978 .36052 Metetra
.704 .741 .88 r
.80978 .36052 .81407 .36691 .824 .36247 .81974 .35608 Metetra
.666 .726 .895 r
.81974 .35608 .824 .36247 .83405 .35895 .82983 .35277 Metetra
.666 .735 .901 r
.82983 .35277 .83405 .35895 .84413 .35545 .83996 .34945 Metetra
.664 .741 .908 r
.83996 .34945 .84413 .35545 .85428 .35221 .85013 .34618 Metetra
.664 .741 .908 r
.85013 .34618 .85428 .35221 .86446 .34895 .86034 .3429 Metetra
.664 .741 .908 r
.86034 .3429 .86446 .34895 .87467 .34568 .87058 .33961 Metetra
.664 .741 .908 r
.87058 .33961 .87467 .34568 .88492 .3424 .88085 .33631 Metetra
.664 .741 .908 r
.88085 .33631 .88492 .3424 .89521 .33911 .89117 .333 Metetra
.664 .741 .908 r
.89117 .333 .89521 .33911 .90553 .3358 .90152 .32967 Metetra
.664 .741 .908 r
.30829 .51355 .31365 .51855 .32207 .51584 .31672 .51083 Metetra
.664 .741 .908 r
.31672 .51083 .32207 .51584 .3305 .51313 .32517 .50811 Metetra
.664 .741 .908 r
.32517 .50811 .3305 .51313 .33897 .51041 .33365 .50537 Metetra
.664 .741 .908 r
.33365 .50537 .33897 .51041 .34746 .50769 .34216 .50263 Metetra
.664 .741 .908 r
.34216 .50263 .34746 .50769 .35598 .50495 .3507 .49987 Metetra
.664 .741 .908 r
.3507 .49987 .35598 .50495 .36453 .5022 .35926 .49711 Metetra
.664 .741 .908 r
.35926 .49711 .36453 .5022 .3731 .4995 .36785 .49434 Metetra
.664 .739 .906 r
.36785 .49434 .3731 .4995 .3817 .4968 .37647 .49156 Metetra
.622 .724 .92 r
.37647 .49156 .3817 .4968 .39028 .4952 .38508 .48966 Metetra
.617 .712 .913 r
.38508 .48966 .39028 .4952 .39889 .49375 .39371 .48789 Metetra
.645 .71 .894 r
.39371 .48789 .39889 .49375 .40757 .49112 .40241 .48551 Metetra
.65 .721 .9 r
.40241 .48551 .40757 .49112 .4163 .48826 .41113 .483 Metetra
.645 .733 .913 r
.41113 .483 .4163 .48826 .42503 .48575 .41988 .4806 Metetra
.643 .738 .918 r
.41988 .4806 .42503 .48575 .4338 .48332 .42867 .47821 Metetra
.659 .745 .914 r
.42867 .47821 .4338 .48332 .44261 .48058 .43749 .47547 Metetra
.663 .747 .912 r
.43749 .47547 .44261 .48058 .45144 .47775 .44634 .47262 Metetra
.648 .742 .918 r
.44634 .47262 .45144 .47775 .4603 .47524 .45522 .4701 Metetra
.643 .741 .92 r
.45522 .4701 .4603 .47524 .46919 .47283 .46413 .46767 Metetra
.658 .745 .915 r
.46413 .46767 .46919 .47283 .47811 .4701 .47307 .46493 Metetra
.663 .747 .912 r
.47307 .46493 .47811 .4701 .48707 .46723 .48204 .46204 Metetra
.654 .744 .916 r
.48204 .46204 .48707 .46723 .49605 .4644 .49104 .45936 Metetra
.649 .749 .923 r
.49104 .45936 .49605 .4644 .50506 .46157 .50008 .45676 Metetra
.648 .76 .93 r
.50008 .45676 .50506 .46157 .51411 .45894 .50914 .45415 Metetra
.649 .761 .931 r
.50914 .45415 .51411 .45894 .52318 .45642 .51823 .45152 Metetra
.649 .757 .928 r
.51823 .45152 .52318 .45642 .53229 .45389 .52736 .44888 Metetra
.649 .753 .925 r
.52736 .44888 .53229 .45389 .54143 .45135 .53652 .44623 Metetra
.657 .752 .92 r
.53652 .44623 .54143 .45135 .5506 .44839 .54571 .44341 Metetra
.662 .76 .923 r
.54571 .44341 .5506 .44839 .55979 .44512 .55493 .44047 Metetra
.657 .773 .935 r
.55493 .44047 .55979 .44512 .56902 .44206 .56418 .43759 Metetra
.653 .781 .942 r
.56418 .43759 .56902 .44206 .57828 .43916 .57347 .43476 Metetra
.656 .786 .944 r
.57347 .43476 .57828 .43916 .58757 .43621 .58279 .43185 Metetra
.659 .789 .944 r
.58279 .43185 .58757 .43621 .59689 .43323 .59213 .42884 Metetra
.663 .79 .942 r
.59213 .42884 .59689 .43323 .60624 .4302 .60151 .42575 Metetra
.667 .789 .939 r
.60151 .42575 .60624 .4302 .61563 .42713 .61091 .42257 Metetra
.665 .785 .938 r
.61091 .42257 .61563 .42713 .62505 .42422 .62035 .41944 Metetra
.662 .775 .933 r
.62035 .41944 .62505 .42422 .6345 .42152 .62982 .41638 Metetra
.668 .762 .92 r
.62982 .41638 .6345 .42152 .64399 .41851 .63932 .41318 Metetra
.675 .758 .913 r
.63932 .41318 .64399 .41851 .65348 .41508 .64884 .40982 Metetra
.675 .761 .916 r
.64884 .40982 .65348 .41508 .66301 .41163 .6584 .40645 Metetra
.675 .765 .919 r
.6584 .40645 .66301 .41163 .67257 .40817 .66798 .40307 Metetra
.675 .769 .921 r
.66798 .40307 .67257 .40817 .68216 .40482 .6776 .39967 Metetra
.676 .768 .92 r
.6776 .39967 .68216 .40482 .6918 .40166 .68725 .39624 Metetra
.672 .757 .914 r
.68725 .39624 .6918 .40166 .70146 .39852 .69693 .3929 Metetra
.663 .747 .912 r
.69693 .3929 .70146 .39852 .71117 .39541 .70666 .38977 Metetra
.668 .749 .91 r
.70666 .38977 .71117 .39541 .7209 .39216 .71641 .3865 Metetra
.681 .753 .906 r
.71641 .3865 .7209 .39216 .73064 .38857 .72618 .38289 Metetra
.676 .752 .908 r
.72618 .38289 .73064 .38857 .74042 .38509 .73598 .37939 Metetra
.663 .747 .912 r
.73598 .37939 .74042 .38509 .75025 .38193 .74584 .37622 Metetra
.667 .748 .911 r
.74584 .37622 .75025 .38193 .76012 .37868 .75572 .37293 Metetra
.681 .753 .906 r
.75572 .37293 .76012 .37868 .76999 .37511 .76562 .36927 Metetra
.68 .75 .904 r
.76562 .36927 .76999 .37511 .7799 .37162 .77554 .36563 Metetra
.675 .743 .902 r
.77554 .36563 .7799 .37162 .78988 .36849 .78551 .3621 Metetra
.679 .731 .89 r
.78551 .3621 .78988 .36849 .79987 .36511 .7955 .35843 Metetra
.698 .729 .875 r
.7955 .35843 .79987 .36511 .80978 .36052 .80547 .35413 Metetra
.695 .739 .885 r
.80547 .35413 .80978 .36052 .81974 .35608 .81548 .34995 Metetra
.664 .737 .904 r
.81548 .34995 .81974 .35608 .82983 .35277 .8256 .34669 Metetra
.664 .739 .906 r
.8256 .34669 .82983 .35277 .83996 .34945 .83576 .34341 Metetra
.664 .741 .908 r
.83576 .34341 .83996 .34945 .85013 .34618 .84596 .34012 Metetra
.664 .741 .908 r
.84596 .34012 .85013 .34618 .86034 .3429 .85619 .33682 Metetra
.664 .741 .908 r
.85619 .33682 .86034 .3429 .87058 .33961 .86646 .33351 Metetra
.664 .741 .908 r
.86646 .33351 .87058 .33961 .88085 .33631 .87676 .33018 Metetra
.664 .741 .908 r
.87676 .33018 .88085 .33631 .89117 .333 .8871 .32685 Metetra
.664 .741 .908 r
.8871 .32685 .89117 .333 .90152 .32967 .89748 .3235 Metetra
.664 .741 .908 r
.30289 .50853 .30829 .51355 .31672 .51083 .31134 .50579 Metetra
.664 .741 .908 r
.31134 .50579 .31672 .51083 .32517 .50811 .31981 .50305 Metetra
.664 .741 .908 r
.31981 .50305 .32517 .50811 .33365 .50537 .3283 .5003 Metetra
.664 .741 .908 r
.3283 .5003 .33365 .50537 .34216 .50263 .33683 .49754 Metetra
.664 .741 .908 r
.33683 .49754 .34216 .50263 .3507 .49987 .34538 .49477 Metetra
.664 .741 .908 r
.34538 .49477 .3507 .49987 .35926 .49711 .35396 .49199 Metetra
.664 .741 .908 r
.35396 .49199 .35926 .49711 .36785 .49434 .36257 .4892 Metetra
.664 .741 .908 r
.36257 .4892 .36785 .49434 .37647 .49156 .37121 .4864 Metetra
.64 .735 .917 r
.37121 .4864 .37647 .49156 .38508 .48966 .37985 .48411 Metetra
.638 .719 .907 r
.37985 .48411 .38508 .48966 .39371 .48789 .38852 .48188 Metetra
.633 .702 .895 r
.38852 .48188 .39371 .48789 .40241 .48551 .39721 .47978 Metetra
.631 .712 .905 r
.39721 .47978 .40241 .48551 .41113 .483 .40594 .4777 Metetra
.641 .732 .914 r
.40594 .4777 .41113 .483 .41988 .4806 .4147 .47536 Metetra
.643 .736 .916 r
.4147 .47536 .41988 .4806 .42867 .47821 .4235 .47296 Metetra
.659 .74 .91 r
.4235 .47296 .42867 .47821 .43749 .47547 .43234 .4702 Metetra
.663 .742 .908 r
.43234 .4702 .43749 .47547 .44634 .47262 .44122 .46734 Metetra
.649 .737 .914 r
.44122 .46734 .44634 .47262 .45522 .4701 .45011 .46479 Metetra
.643 .736 .916 r
.45011 .46479 .45522 .4701 .46413 .46767 .45904 .46235 Metetra
.658 .74 .911 r
.45904 .46235 .46413 .46767 .47307 .46493 .468 .45959 Metetra
.663 .742 .908 r
.468 .45959 .47307 .46493 .48204 .46204 .47699 .45668 Metetra
.641 .735 .917 r
.47699 .45668 .48204 .46204 .49104 .45936 .48601 .45428 Metetra
.627 .743 .93 r
.48601 .45428 .49104 .45936 .50008 .45676 .49505 .45212 Metetra
.647 .767 .937 r
.49505 .45212 .50008 .45676 .50914 .45415 .50414 .4495 Metetra
.658 .771 .933 r
.50414 .4495 .50914 .45415 .51823 .45152 .51326 .44663 Metetra
.659 .762 .926 r
.51326 .44663 .51823 .45152 .52736 .44888 .5224 .44375 Metetra
.66 .753 .919 r
.5224 .44375 .52736 .44888 .53652 .44623 .53158 .44086 Metetra
.644 .739 .918 r
.53158 .44086 .53652 .44623 .54571 .44341 .54079 .43832 Metetra
.631 .747 .931 r
.54079 .43832 .54571 .44341 .55493 .44047 .55004 .43603 Metetra
.634 .777 .95 r
.55004 .43603 .55493 .44047 .56418 .43759 .55932 .43356 Metetra
.636 .797 .96 r
.55932 .43356 .56418 .43759 .57347 .43476 .56864 .43094 Metetra
.644 .81 .963 r
.56864 .43094 .57347 .43476 .58279 .43185 .57798 .42811 Metetra
.653 .818 .963 r
.57798 .42811 .58279 .43185 .59213 .42884 .58735 .42509 Metetra
.663 .821 .959 r
.58735 .42509 .59213 .42884 .60151 .42575 .59675 .42187 Metetra
.674 .819 .953 r
.59675 .42187 .60151 .42575 .61091 .42257 .60618 .41845 Metetra
.682 .81 .944 r
.60618 .41845 .61091 .42257 .62035 .41944 .61563 .41488 Metetra
.691 .794 .929 r
.61563 .41488 .62035 .41944 .62982 .41638 .6251 .41112 Metetra
.681 .763 .913 r
.6251 .41112 .62982 .41638 .63932 .41318 .63461 .40761 Metetra
.666 .747 .91 r
.63461 .40761 .63932 .41318 .64884 .40982 .64417 .40445 Metetra
.666 .755 .917 r
.64417 .40445 .64884 .40982 .6584 .40645 .65376 .40129 Metetra
.666 .764 .924 r
.65376 .40129 .6584 .40645 .66798 .40307 .66338 .39811 Metetra
.676 .777 .926 r
.66338 .39811 .66798 .40307 .6776 .39967 .67302 .39467 Metetra
.694 .782 .919 r
.67302 .39467 .6776 .39967 .68725 .39624 .68267 .39078 Metetra
.684 .761 .91 r
.68267 .39078 .68725 .39624 .69693 .3929 .69236 .38712 Metetra
.663 .742 .908 r
.69236 .38712 .69693 .3929 .70666 .38977 .70211 .38397 Metetra
.668 .744 .907 r
.70211 .38397 .70666 .38977 .71641 .3865 .71189 .38067 Metetra
.681 .748 .902 r
.71189 .38067 .71641 .3865 .72618 .38289 .72167 .37705 Metetra
.676 .746 .904 r
.72167 .37705 .72618 .38289 .73598 .37939 .7315 .37352 Metetra
.663 .742 .908 r
.7315 .37352 .73598 .37939 .74584 .37622 .74139 .37033 Metetra
.667 .743 .907 r
.74139 .37033 .74584 .37622 .75572 .37293 .7513 .36702 Metetra
.681 .748 .902 r
.7513 .36702 .75572 .37293 .76562 .36927 .76121 .36334 Metetra
.683 .749 .901 r
.76121 .36334 .76562 .36927 .77554 .36563 .77116 .3596 Metetra
.692 .749 .895 r
.77116 .3596 .77554 .36563 .78551 .3621 .78111 .35558 Metetra
.689 .732 .884 r
.78111 .35558 .78551 .3621 .7955 .35843 .7911 .35159 Metetra
.683 .72 .877 r
.7911 .35159 .7955 .35843 .80547 .35413 .80113 .34772 Metetra
.682 .734 .89 r
.80113 .34772 .80547 .35413 .81548 .34995 .8112 .34391 Metetra
.664 .741 .908 r
.8112 .34391 .81548 .34995 .8256 .34669 .82135 .34063 Metetra
.664 .741 .908 r
.82135 .34063 .8256 .34669 .83576 .34341 .83153 .33733 Metetra
.664 .741 .908 r
.83153 .33733 .83576 .34341 .84596 .34012 .84176 .33402 Metetra
.664 .741 .908 r
.84176 .33402 .84596 .34012 .85619 .33682 .85201 .3307 Metetra
.664 .741 .908 r
.85201 .3307 .85619 .33682 .86646 .33351 .86231 .32736 Metetra
.664 .741 .908 r
.86231 .32736 .86646 .33351 .87676 .33018 .87264 .32402 Metetra
.664 .741 .908 r
.87264 .32402 .87676 .33018 .8871 .32685 .883 .32066 Metetra
.664 .741 .908 r
.883 .32066 .8871 .32685 .89748 .3235 .89341 .31729 Metetra
.664 .741 .908 r
.29746 .50347 .30289 .50853 .31134 .50579 .30592 .50072 Metetra
.664 .741 .908 r
.30592 .50072 .31134 .50579 .31981 .50305 .31441 .49796 Metetra
.664 .741 .908 r
.31441 .49796 .31981 .50305 .3283 .5003 .32292 .49519 Metetra
.664 .741 .908 r
.32292 .49519 .3283 .5003 .33683 .49754 .33147 .49241 Metetra
.664 .741 .908 r
.33147 .49241 .33683 .49754 .34538 .49477 .34004 .48963 Metetra
.664 .741 .908 r
.34004 .48963 .34538 .49477 .35396 .49199 .34863 .48683 Metetra
.664 .741 .908 r
.34863 .48683 .35396 .49199 .36257 .4892 .35726 .48403 Metetra
.664 .741 .908 r
.35726 .48403 .36257 .4892 .37121 .4864 .36591 .48122 Metetra
.652 .738 .913 r
.36591 .48122 .37121 .4864 .37985 .48411 .37458 .47865 Metetra
.651 .728 .906 r
.37458 .47865 .37985 .48411 .38852 .48188 .38328 .47612 Metetra
.623 .708 .907 r
.38328 .47612 .38852 .48188 .39721 .47978 .39198 .4742 Metetra
.616 .714 .915 r
.39198 .4742 .39721 .47978 .40594 .4777 .40071 .47239 Metetra
.638 .732 .916 r
.40071 .47239 .40594 .4777 .4147 .47536 .40949 .4701 Metetra
.643 .736 .916 r
.40949 .4701 .4147 .47536 .4235 .47296 .41831 .46768 Metetra
.654 .739 .912 r
.41831 .46768 .4235 .47296 .43234 .4702 .42717 .46502 Metetra
.657 .744 .914 r
.42717 .46502 .43234 .4702 .44122 .46734 .43605 .46228 Metetra
.651 .749 .921 r
.43605 .46228 .44122 .46734 .45011 .46479 .44497 .45965 Metetra
.65 .745 .919 r
.44497 .45965 .45011 .46479 .45904 .46235 .45391 .45704 Metetra
.65 .74 .915 r
.45391 .45704 .45904 .46235 .468 .45959 .46289 .45443 Metetra
.65 .746 .92 r
.46289 .45443 .468 .45959 .47699 .45668 .4719 .45181 Metetra
.634 .753 .934 r
.4719 .45181 .47699 .45668 .48601 .45428 .48093 .44948 Metetra
.625 .755 .94 r
.48093 .44948 .48601 .45428 .49505 .45212 .49 .44729 Metetra
.645 .761 .933 r
.49 .44729 .49505 .45212 .50414 .4495 .49911 .44471 Metetra
.655 .766 .931 r
.49911 .44471 .50414 .4495 .51326 .44663 .50824 .4419 Metetra
.659 .77 .932 r
.50824 .4419 .51326 .44663 .5224 .44375 .51741 .43899 Metetra
.662 .77 .93 r
.51741 .43899 .5224 .44375 .53158 .44086 .52661 .43601 Metetra
.641 .761 .935 r
.52661 .43601 .53158 .44086 .54079 .43832 .53585 .43346 Metetra
.625 .756 .941 r
.53585 .43346 .54079 .43832 .55004 .43603 .54512 .43121 Metetra
.629 .76 .941 r
.54512 .43121 .55004 .43603 .55932 .43356 .55442 .42888 Metetra
.631 .768 .945 r
.55442 .42888 .55932 .43356 .56864 .43094 .56376 .42647 Metetra
.645 .782 .947 r
.56376 .42647 .56864 .43094 .57798 .42811 .57313 .42373 Metetra
.659 .791 .945 r
.57313 .42373 .57798 .42811 .58735 .42509 .58252 .42069 Metetra
.673 .795 .94 r
.58252 .42069 .58735 .42509 .59675 .42187 .59195 .41735 Metetra
.687 .794 .931 r
.59195 .41735 .59675 .42187 .60618 .41845 .60139 .41368 Metetra
.69 .786 .923 r
.60139 .41368 .60618 .41845 .61563 .41488 .61086 .40993 Metetra
.694 .78 .918 r
.61086 .40993 .61563 .41488 .6251 .41112 .62036 .40609 Metetra
.681 .774 .921 r
.62036 .40609 .6251 .41112 .63461 .40761 .6299 .40256 Metetra
.662 .767 .928 r
.6299 .40256 .63461 .40761 .64417 .40445 .63948 .39946 Metetra
.664 .771 .929 r
.63948 .39946 .64417 .40445 .65376 .40129 .64909 .39628 Metetra
.669 .773 .928 r
.64909 .39628 .65376 .40129 .66338 .39811 .65873 .39301 Metetra
.678 .773 .922 r
.65873 .39301 .66338 .39811 .67302 .39467 .6684 .3895 Metetra
.693 .776 .915 r
.6684 .3895 .67302 .39467 .68267 .39078 .67807 .38559 Metetra
.688 .774 .917 r
.67807 .38559 .68267 .39078 .69236 .38712 .68779 .38182 Metetra
.675 .766 .919 r
.68779 .38182 .69236 .38712 .70211 .38397 .69754 .37834 Metetra
.675 .754 .91 r
.69754 .37834 .70211 .38397 .71189 .38067 .70733 .37486 Metetra
.675 .748 .905 r
.70733 .37486 .71189 .38067 .72167 .37705 .71716 .37136 Metetra
.674 .753 .91 r
.71716 .37136 .72167 .37705 .7315 .37352 .72701 .36789 Metetra
.669 .754 .914 r
.72701 .36789 .7315 .37352 .74139 .37033 .73691 .36452 Metetra
.672 .749 .909 r
.73691 .36452 .74139 .37033 .7513 .36702 .74684 .36107 Metetra
.681 .748 .902 r
.74684 .36107 .7513 .36702 .76121 .36334 .75678 .35738 Metetra
.685 .75 .901 r
.75678 .35738 .76121 .36334 .77116 .3596 .76675 .35355 Metetra
.702 .754 .892 r
.76675 .35355 .77116 .3596 .78111 .35558 .7767 .34921 Metetra
.696 .741 .886 r
.7767 .34921 .78111 .35558 .7911 .35159 .7867 .34499 Metetra
.674 .725 .888 r
.7867 .34499 .7911 .35159 .80113 .34772 .79678 .3414 Metetra
.673 .736 .897 r
.79678 .3414 .80113 .34772 .8112 .34391 .80689 .33784 Metetra
.664 .741 .908 r
.80689 .33784 .8112 .34391 .82135 .34063 .81707 .33453 Metetra
.664 .741 .908 r
.81707 .33453 .82135 .34063 .83153 .33733 .82728 .33121 Metetra
.664 .741 .908 r
.82728 .33121 .83153 .33733 .84176 .33402 .83753 .32788 Metetra
.664 .741 .908 r
.83753 .32788 .84176 .33402 .85201 .3307 .84781 .32453 Metetra
.664 .741 .908 r
.84781 .32453 .85201 .3307 .86231 .32736 .85813 .32118 Metetra
.664 .741 .908 r
.85813 .32118 .86231 .32736 .87264 .32402 .86849 .31781 Metetra
.664 .741 .908 r
.86849 .31781 .87264 .32402 .883 .32066 .87888 .31443 Metetra
.664 .741 .908 r
.87888 .31443 .883 .32066 .89341 .31729 .88931 .31104 Metetra
.664 .741 .908 r
.292 .49839 .29746 .50347 .30592 .50072 .30048 .49562 Metetra
.664 .741 .908 r
.30048 .49562 .30592 .50072 .31441 .49796 .30898 .49284 Metetra
.664 .741 .908 r
.30898 .49284 .31441 .49796 .32292 .49519 .31751 .49006 Metetra
.664 .741 .908 r
.31751 .49006 .32292 .49519 .33147 .49241 .32607 .48726 Metetra
.664 .741 .908 r
.32607 .48726 .33147 .49241 .34004 .48963 .33466 .48446 Metetra
.664 .741 .908 r
.33466 .48446 .34004 .48963 .34863 .48683 .34327 .48165 Metetra
.664 .741 .908 r
.34327 .48165 .34863 .48683 .35726 .48403 .35191 .47883 Metetra
.664 .741 .908 r
.35191 .47883 .35726 .48403 .36591 .48122 .36058 .476 Metetra
.661 .741 .909 r
.36058 .476 .36591 .48122 .37458 .47865 .36928 .47323 Metetra
.66 .733 .904 r
.36928 .47323 .37458 .47865 .38328 .47612 .378 .47046 Metetra
.615 .711 .913 r
.378 .47046 .38328 .47612 .39198 .4742 .38671 .46867 Metetra
.604 .713 .921 r
.38671 .46867 .39198 .4742 .40071 .47239 .39545 .46707 Metetra
.636 .732 .917 r
.39545 .46707 .40071 .47239 .40949 .4701 .40425 .4648 Metetra
.643 .736 .916 r
.40425 .4648 .40949 .4701 .41831 .46768 .41308 .46236 Metetra
.646 .737 .915 r
.41308 .46236 .41831 .46768 .42717 .46502 .42195 .45986 Metetra
.647 .744 .92 r
.42195 .45986 .42717 .46502 .43605 .46228 .43085 .45732 Metetra
.656 .755 .923 r
.43085 .45732 .43605 .46228 .44497 .45965 .43979 .45457 Metetra
.66 .752 .918 r
.43979 .45457 .44497 .45965 .45391 .45704 .44876 .45172 Metetra
.639 .737 .92 r
.44876 .45172 .45391 .45704 .46289 .45443 .45775 .44934 Metetra
.628 .743 .93 r
.45775 .44934 .46289 .45443 .4719 .45181 .46677 .44715 Metetra
.632 .763 .942 r
.46677 .44715 .4719 .45181 .48093 .44948 .47582 .4448 Metetra
.636 .764 .941 r
.47582 .4448 .48093 .44948 .49 .44729 .48491 .44237 Metetra
.642 .757 .932 r
.48491 .44237 .49 .44729 .49911 .44471 .49404 .43983 Metetra
.645 .76 .933 r
.49404 .43983 .49911 .44471 .50824 .4419 .5032 .43723 Metetra
.655 .773 .936 r
.5032 .43723 .50824 .4419 .51741 .43899 .51239 .43438 Metetra
.661 .778 .936 r
.51239 .43438 .51741 .43899 .52661 .43601 .52161 .43139 Metetra
.646 .774 .941 r
.52161 .43139 .52661 .43601 .53585 .43346 .53087 .42869 Metetra
.636 .765 .941 r
.53087 .42869 .53585 .43346 .54512 .43121 .54016 .42621 Metetra
.629 .753 .937 r
.54016 .42621 .54512 .43121 .55442 .42888 .54948 .42387 Metetra
.622 .752 .939 r
.54948 .42387 .55442 .42888 .56376 .42647 .55884 .42167 Metetra
.642 .768 .94 r
.55884 .42167 .56376 .42647 .57313 .42373 .56824 .41903 Metetra
.661 .779 .936 r
.56824 .41903 .57313 .42373 .58252 .42069 .57766 .41597 Metetra
.679 .784 .929 r
.57766 .41597 .58252 .42069 .59195 .41735 .5871 .4125 Metetra
.697 .784 .919 r
.5871 .4125 .59195 .41735 .60139 .41368 .59657 .40859 Metetra
.691 .774 .915 r
.59657 .40859 .60139 .41368 .61086 .40993 .60606 .4048 Metetra
.685 .771 .917 r
.60606 .4048 .61086 .40993 .62036 .40609 .61559 .40116 Metetra
.675 .777 .927 r
.61559 .40116 .62036 .40609 .6299 .40256 .62516 .39774 Metetra
.661 .778 .936 r
.62516 .39774 .6299 .40256 .63948 .39946 .63476 .39461 Metetra
.668 .78 .934 r
.63476 .39461 .63948 .39946 .64909 .39628 .6444 .39133 Metetra
.678 .78 .927 r
.6444 .39133 .64909 .39628 .65873 .39301 .65406 .38781 Metetra
.68 .772 .92 r
.65406 .38781 .65873 .39301 .6684 .3895 .66374 .38422 Metetra
.685 .77 .916 r
.66374 .38422 .6684 .3895 .67807 .38559 .67345 .38052 Metetra
.687 .78 .922 r
.67345 .38052 .67807 .38559 .68779 .38182 .68319 .37673 Metetra
.693 .782 .919 r
.68319 .37673 .68779 .38182 .69754 .37834 .69295 .37278 Metetra
.685 .762 .91 r
.69295 .37278 .69754 .37834 .70733 .37486 .70276 .36902 Metetra
.666 .745 .909 r
.70276 .36902 .70733 .37486 .71716 .37136 .71262 .36573 Metetra
.669 .755 .915 r
.71262 .36573 .71716 .37136 .72701 .36789 .7225 .36235 Metetra
.678 .763 .915 r
.7225 .36235 .72701 .36789 .73691 .36452 .73241 .35873 Metetra
.679 .754 .908 r
.73241 .35873 .73691 .36452 .74684 .36107 .74235 .35509 Metetra
.681 .748 .902 r
.74235 .35509 .74684 .36107 .75678 .35738 .75232 .35137 Metetra
.687 .75 .9 r
.75232 .35137 .75678 .35738 .76675 .35355 .76231 .34748 Metetra
.709 .757 .889 r
.76231 .34748 .76675 .35355 .7767 .34921 .77227 .34289 Metetra
.702 .746 .886 r
.77227 .34289 .7767 .34921 .7867 .34499 .78228 .33849 Metetra
.666 .727 .895 r
.78228 .33849 .7867 .34499 .79678 .3414 .7924 .33511 Metetra
.666 .735 .901 r
.7924 .33511 .79678 .3414 .80689 .33784 .80256 .33172 Metetra
.664 .741 .908 r
.80256 .33172 .80689 .33784 .81707 .33453 .81276 .32839 Metetra
.664 .741 .908 r
.81276 .32839 .81707 .33453 .82728 .33121 .823 .32505 Metetra
.664 .741 .908 r
.823 .32505 .82728 .33121 .83753 .32788 .83327 .32169 Metetra
.664 .741 .908 r
.83327 .32169 .83753 .32788 .84781 .32453 .84358 .31833 Metetra
.664 .741 .908 r
.84358 .31833 .84781 .32453 .85813 .32118 .85393 .31495 Metetra
.664 .741 .908 r
.85393 .31495 .85813 .32118 .86849 .31781 .86431 .31156 Metetra
.664 .741 .908 r
.86431 .31156 .86849 .31781 .87888 .31443 .87473 .30816 Metetra
.664 .741 .908 r
.87473 .30816 .87888 .31443 .88931 .31104 .88519 .30475 Metetra
.664 .741 .908 r
.28651 .49327 .292 .49839 .30048 .49562 .295 .49049 Metetra
.664 .741 .908 r
.295 .49049 .30048 .49562 .30898 .49284 .30352 .48769 Metetra
.664 .741 .908 r
.30352 .48769 .30898 .49284 .31751 .49006 .31207 .48489 Metetra
.664 .741 .908 r
.31207 .48489 .31751 .49006 .32607 .48726 .32064 .48208 Metetra
.664 .741 .908 r
.32064 .48208 .32607 .48726 .33466 .48446 .32925 .47926 Metetra
.664 .741 .908 r
.32925 .47926 .33466 .48446 .34327 .48165 .33788 .47643 Metetra
.664 .741 .908 r
.33788 .47643 .34327 .48165 .35191 .47883 .34654 .4736 Metetra
.664 .741 .908 r
.34654 .4736 .35191 .47883 .36058 .476 .35523 .47075 Metetra
.664 .741 .908 r
.35523 .47075 .36058 .476 .36928 .47323 .36394 .46789 Metetra
.664 .739 .906 r
.36394 .46789 .36928 .47323 .378 .47046 .37269 .46503 Metetra
.623 .724 .919 r
.37269 .46503 .378 .47046 .38671 .46867 .38142 .46304 Metetra
.615 .714 .916 r
.38142 .46304 .38671 .46867 .39545 .46707 .39018 .46121 Metetra
.629 .711 .905 r
.39018 .46121 .39545 .46707 .40425 .4648 .39899 .45912 Metetra
.631 .719 .91 r
.39899 .45912 .40425 .4648 .41308 .46236 .40783 .45695 Metetra
.641 .732 .915 r
.40783 .45695 .41308 .46236 .42195 .45986 .41671 .45455 Metetra
.643 .738 .918 r
.41671 .45455 .42195 .45986 .43085 .45732 .42563 .45208 Metetra
.653 .744 .916 r
.42563 .45208 .43085 .45732 .43979 .45457 .43458 .44937 Metetra
.657 .748 .917 r
.43458 .44937 .43979 .45457 .44876 .45172 .44357 .44658 Metetra
.636 .744 .926 r
.44357 .44658 .44876 .45172 .45775 .44934 .45258 .44421 Metetra
.627 .743 .93 r
.45258 .44421 .45775 .44934 .46677 .44715 .46161 .44201 Metetra
.633 .745 .929 r
.46161 .44201 .46677 .44715 .47582 .4448 .47069 .43969 Metetra
.635 .748 .93 r
.47069 .43969 .47582 .4448 .48491 .44237 .4798 .43731 Metetra
.648 .754 .927 r
.4798 .43731 .48491 .44237 .49404 .43983 .48894 .43464 Metetra
.656 .752 .921 r
.48894 .43464 .49404 .43983 .5032 .43723 .49812 .43181 Metetra
.645 .741 .919 r
.49812 .43181 .5032 .43723 .51239 .43438 .50733 .42923 Metetra
.636 .749 .93 r
.50733 .42923 .51239 .43438 .52161 .43139 .51658 .42679 Metetra
.622 .769 .95 r
.51658 .42679 .52161 .43139 .53087 .42869 .52585 .42452 Metetra
.608 .784 .966 r
.52585 .42452 .53087 .42869 .54016 .42621 .53517 .42237 Metetra
.62 .805 .971 r
.53517 .42237 .54016 .42621 .54948 .42387 .54452 .41991 Metetra
.637 .805 .963 r
.54452 .41991 .54948 .42387 .55884 .42167 .5539 .41719 Metetra
.652 .786 .946 r
.5539 .41719 .55884 .42167 .56824 .41903 .56331 .41429 Metetra
.661 .779 .936 r
.56331 .41429 .56824 .41903 .57766 .41597 .57276 .41121 Metetra
.668 .781 .933 r
.57276 .41121 .57766 .41597 .5871 .4125 .58223 .40797 Metetra
.675 .793 .938 r
.58223 .40797 .5871 .4125 .59657 .40859 .59173 .40453 Metetra
.684 .818 .947 r
.59173 .40453 .59657 .40859 .60606 .4048 .60126 .40084 Metetra
.698 .827 .944 r
.60126 .40084 .60606 .4048 .61559 .40116 .61081 .39683 Metetra
.693 .81 .937 r
.61081 .39683 .61559 .40116 .62516 .39774 .62039 .39293 Metetra
.686 .788 .928 r
.62039 .39293 .62516 .39774 .63476 .39461 .63 .38921 Metetra
.68 .763 .914 r
.63 .38921 .63476 .39461 .6444 .39133 .63965 .38563 Metetra
.67 .749 .91 r
.63965 .38563 .6444 .39133 .65406 .38781 .64934 .3823 Metetra
.676 .759 .913 r
.64934 .3823 .65406 .38781 .66374 .38422 .65905 .3788 Metetra
.687 .767 .912 r
.65905 .3788 .66374 .38422 .67345 .38052 .66879 .37501 Metetra
.689 .765 .91 r
.66879 .37501 .67345 .38052 .68319 .37673 .67855 .37115 Metetra
.693 .764 .906 r
.67855 .37115 .68319 .37673 .69295 .37278 .68833 .36717 Metetra
.686 .762 .909 r
.68833 .36717 .69295 .37278 .70276 .36902 .69816 .36336 Metetra
.669 .754 .914 r
.69816 .36336 .70276 .36902 .71262 .36573 .70804 .35998 Metetra
.672 .753 .911 r
.70804 .35998 .71262 .36573 .7225 .36235 .71795 .35651 Metetra
.681 .754 .906 r
.71795 .35651 .7225 .36235 .73241 .35873 .72788 .35279 Metetra
.683 .751 .903 r
.72788 .35279 .73241 .35873 .74235 .35509 .73783 .349 Metetra
.691 .749 .896 r
.73783 .349 .74235 .35509 .75232 .35137 .7478 .34497 Metetra
.692 .74 .888 r
.7478 .34497 .75232 .35137 .76231 .34748 .7578 .34086 Metetra
.7 .736 .879 r
.7578 .34086 .76231 .34748 .77227 .34289 .76781 .33646 Metetra
.695 .741 .887 r
.76781 .33646 .77227 .34289 .78228 .33849 .77785 .33223 Metetra
.663 .736 .904 r
.77785 .33223 .78228 .33849 .7924 .33511 .78801 .3289 Metetra
.664 .739 .906 r
.78801 .3289 .7924 .33511 .80256 .33172 .7982 .32556 Metetra
.664 .741 .908 r
.7982 .32556 .80256 .33172 .81276 .32839 .80843 .32221 Metetra
.664 .741 .908 r
.80843 .32221 .81276 .32839 .823 .32505 .81869 .31885 Metetra
.664 .741 .908 r
.81869 .31885 .823 .32505 .83327 .32169 .82899 .31547 Metetra
.664 .741 .908 r
.82899 .31547 .83327 .32169 .84358 .31833 .83932 .31208 Metetra
.664 .741 .908 r
.83932 .31208 .84358 .31833 .85393 .31495 .8497 .30868 Metetra
.664 .741 .908 r
.8497 .30868 .85393 .31495 .86431 .31156 .86011 .30527 Metetra
.664 .741 .908 r
.86011 .30527 .86431 .31156 .87473 .30816 .87055 .30185 Metetra
.664 .741 .908 r
.87055 .30185 .87473 .30816 .88519 .30475 .88104 .29841 Metetra
.664 .741 .908 r
.28098 .48812 .28651 .49327 .295 .49049 .28949 .48532 Metetra
.664 .741 .908 r
.28949 .48532 .295 .49049 .30352 .48769 .29803 .48252 Metetra
.664 .741 .908 r
.29803 .48252 .30352 .48769 .31207 .48489 .30659 .4797 Metetra
.664 .741 .908 r
.30659 .4797 .31207 .48489 .32064 .48208 .31518 .47687 Metetra
.664 .741 .908 r
.31518 .47687 .32064 .48208 .32925 .47926 .3238 .47403 Metetra
.664 .741 .908 r
.3238 .47403 .32925 .47926 .33788 .47643 .33245 .47119 Metetra
.664 .741 .908 r
.33245 .47119 .33788 .47643 .34654 .4736 .34113 .46833 Metetra
.664 .741 .908 r
.34113 .46833 .34654 .4736 .35523 .47075 .34983 .46547 Metetra
.664 .741 .908 r
.34983 .46547 .35523 .47075 .36394 .46789 .35857 .46259 Metetra
.664 .741 .908 r
.35857 .46259 .36394 .46789 .37269 .46503 .36733 .45971 Metetra
.64 .735 .917 r
.36733 .45971 .37269 .46503 .38142 .46304 .3761 .45734 Metetra
.637 .719 .908 r
.3761 .45734 .38142 .46304 .39018 .46121 .38489 .45505 Metetra
.617 .697 .901 r
.38489 .45505 .39018 .46121 .39899 .45912 .3937 .45321 Metetra
.611 .704 .911 r
.3937 .45321 .39899 .45912 .40783 .45695 .40254 .45147 Metetra
.636 .73 .916 r
.40254 .45147 .40783 .45695 .41671 .45455 .41144 .44915 Metetra
.643 .736 .916 r
.41144 .44915 .41671 .45455 .42563 .45208 .42037 .44666 Metetra
.646 .737 .915 r
.42037 .44666 .42563 .45208 .43458 .44937 .42934 .4441 Metetra
.647 .743 .92 r
.42934 .4441 .43458 .44937 .44357 .44658 .43834 .44151 Metetra
.64 .75 .928 r
.43834 .44151 .44357 .44658 .45258 .44421 .44737 .43903 Metetra
.638 .746 .926 r
.44737 .43903 .45258 .44421 .46161 .44201 .45643 .4366 Metetra
.63 .734 .923 r
.45643 .4366 .46161 .44201 .47069 .43969 .46552 .43434 Metetra
.625 .736 .926 r
.46552 .43434 .47069 .43969 .4798 .43731 .47465 .43217 Metetra
.658 .755 .922 r
.47465 .43217 .4798 .43731 .48894 .43464 .48382 .42927 Metetra
.675 .752 .909 r
.48382 .42927 .48894 .43464 .49812 .43181 .49302 .42597 Metetra
.629 .72 .913 r
.49302 .42597 .49812 .43181 .50733 .42923 .50225 .42374 Metetra
.592 .721 .934 r
.50225 .42374 .50733 .42923 .51658 .42679 .51151 .42218 Metetra
.576 .754 .962 r
.51151 .42218 .51658 .42679 .52585 .42452 .52081 .42067 Metetra
.554 .781 .983 r
.52081 .42067 .52585 .42452 .53517 .42237 .53015 .41918 Metetra
.618 .836 .984 r
.53015 .41918 .53517 .42237 .54452 .41991 .53952 .41652 Metetra
.679 .844 .962 r
.53952 .41652 .54452 .41991 .5539 .41719 .54892 .41288 Metetra
.672 .801 .944 r
.54892 .41288 .5539 .41719 .56331 .41429 .55836 .40952 Metetra
.661 .779 .936 r
.55836 .40952 .56331 .41429 .57276 .41121 .56783 .40642 Metetra
.648 .775 .941 r
.56783 .40642 .57276 .41121 .58223 .40797 .57733 .40359 Metetra
.628 .788 .958 r
.57733 .40359 .58223 .40797 .59173 .40453 .58688 .40105 Metetra
.669 .842 .966 r
.58688 .40105 .59173 .40453 .60126 .40084 .59644 .39752 Metetra
.724 .863 .947 r
.59644 .39752 .60126 .40084 .61081 .39683 .606 .39281 Metetra
.725 .832 .931 r
.606 .39281 .61081 .39683 .62039 .39293 .61558 .38812 Metetra
.721 .799 .912 r
.61558 .38812 .62039 .39293 .63 .38921 .62519 .38347 Metetra
.693 .756 .9 r
.62519 .38347 .63 .38921 .63965 .38563 .63485 .3795 Metetra
.652 .727 .905 r
.63485 .3795 .63965 .38563 .64934 .3823 .64458 .3766 Metetra
.667 .75 .912 r
.64458 .3766 .64934 .3823 .65905 .3788 .65433 .37329 Metetra
.695 .767 .907 r
.65433 .37329 .65905 .3788 .66879 .37501 .66408 .36925 Metetra
.691 .757 .902 r
.66408 .36925 .66879 .37501 .67855 .37115 .67386 .36529 Metetra
.684 .752 .903 r
.67386 .36529 .67855 .37115 .68833 .36717 .68368 .36152 Metetra
.683 .76 .91 r
.68368 .36152 .68833 .36717 .69816 .36336 .69354 .35778 Metetra
.678 .762 .915 r
.69354 .35778 .69816 .36336 .70804 .35998 .70343 .35415 Metetra
.679 .754 .908 r
.70343 .35415 .70804 .35998 .71795 .35651 .71335 .35049 Metetra
.681 .748 .902 r
.71335 .35049 .71795 .35651 .72788 .35279 .72331 .34675 Metetra
.687 .75 .9 r
.72331 .34675 .72788 .35279 .73783 .349 .73328 .34283 Metetra
.706 .753 .889 r
.73328 .34283 .73783 .349 .7478 .34497 .74325 .33832 Metetra
.7 .736 .879 r
.74325 .33832 .7478 .34497 .7578 .34086 .75325 .33391 Metetra
.684 .721 .877 r
.75325 .33391 .7578 .34086 .76781 .33646 .76331 .32995 Metetra
.682 .735 .891 r
.76331 .32995 .76781 .33646 .77785 .33223 .77341 .32608 Metetra
.664 .741 .908 r
.77341 .32608 .77785 .33223 .78801 .3289 .78359 .32273 Metetra
.664 .741 .908 r
.78359 .32273 .78801 .3289 .7982 .32556 .79381 .31937 Metetra
.664 .741 .908 r
.79381 .31937 .7982 .32556 .80843 .32221 .80406 .31599 Metetra
.664 .741 .908 r
.80406 .31599 .80843 .32221 .81869 .31885 .81435 .31261 Metetra
.664 .741 .908 r
.81435 .31261 .81869 .31885 .82899 .31547 .82468 .30921 Metetra
.664 .741 .908 r
.82468 .30921 .82899 .31547 .83932 .31208 .83504 .3058 Metetra
.664 .741 .908 r
.83504 .3058 .83932 .31208 .8497 .30868 .84544 .30238 Metetra
.664 .741 .908 r
.84544 .30238 .8497 .30868 .86011 .30527 .85587 .29894 Metetra
.664 .741 .908 r
.85587 .29894 .86011 .30527 .87055 .30185 .86635 .29549 Metetra
.664 .741 .908 r
.86635 .29549 .87055 .30185 .88104 .29841 .87686 .29204 Metetra
.664 .741 .908 r
.27542 .48295 .28098 .48812 .28949 .48532 .28395 .48013 Metetra
.664 .741 .908 r
.28395 .48013 .28949 .48532 .29803 .48252 .2925 .47731 Metetra
.664 .741 .908 r
.2925 .47731 .29803 .48252 .30659 .4797 .30108 .47447 Metetra
.664 .741 .908 r
.30108 .47447 .30659 .4797 .31518 .47687 .30969 .47163 Metetra
.664 .741 .908 r
.30969 .47163 .31518 .47687 .3238 .47403 .31833 .46877 Metetra
.664 .741 .908 r
.31833 .46877 .3238 .47403 .33245 .47119 .32699 .46591 Metetra
.664 .741 .908 r
.32699 .46591 .33245 .47119 .34113 .46833 .33569 .46304 Metetra
.664 .741 .908 r
.33569 .46304 .34113 .46833 .34983 .46547 .34441 .46015 Metetra
.664 .741 .908 r
.34441 .46015 .34983 .46547 .35857 .46259 .35316 .45726 Metetra
.664 .741 .908 r
.35316 .45726 .35857 .46259 .36733 .45971 .36194 .45436 Metetra
.652 .738 .913 r
.36194 .45436 .36733 .45971 .3761 .45734 .37074 .45171 Metetra
.65 .728 .906 r
.37074 .45171 .3761 .45734 .38489 .45505 .37956 .44911 Metetra
.612 .704 .91 r
.37956 .44911 .38489 .45505 .3937 .45321 .38838 .44733 Metetra
.602 .703 .915 r
.38838 .44733 .3937 .45321 .40254 .45147 .39723 .44574 Metetra
.63 .72 .912 r
.39723 .44574 .40254 .45147 .41144 .44915 .40614 .44355 Metetra
.638 .727 .913 r
.40614 .44355 .41144 .44915 .42037 .44666 .41509 .44118 Metetra
.637 .733 .917 r
.41509 .44118 .42037 .44666 .42934 .4441 .42407 .4388 Metetra
.636 .74 .923 r
.42407 .4388 .42934 .4441 .43834 .44151 .43308 .43642 Metetra
.645 .752 .927 r
.43308 .43642 .43834 .44151 .44737 .43903 .44213 .43383 Metetra
.649 .749 .923 r
.44213 .43383 .44737 .43903 .45643 .4366 .45122 .43115 Metetra
.631 .735 .922 r
.45122 .43115 .45643 .4366 .46552 .43434 .46033 .42886 Metetra
.622 .731 .925 r
.46033 .42886 .46552 .43434 .47465 .43217 .46947 .42676 Metetra
.646 .742 .919 r
.46947 .42676 .47465 .43217 .48382 .42927 .47865 .42412 Metetra
.659 .757 .923 r
.47865 .42412 .48382 .42927 .49302 .42597 .48788 .42118 Metetra
.602 .754 .951 r
.48788 .42118 .49302 .42597 .50225 .42374 .49712 .41929 Metetra
.552 .752 .97 r
.49712 .41929 .50225 .42374 .51151 .42218 .5064 .41806 Metetra
.542 .765 .98 r
.5064 .41806 .51151 .42218 .52081 .42067 .51572 .41683 Metetra
.532 .775 .987 r
.51572 .41683 .52081 .42067 .53015 .41918 .52508 .41559 Metetra
.596 .811 .982 r
.52508 .41559 .53015 .41918 .53952 .41652 .53449 .41336 Metetra
.638 .846 .98 r
.53449 .41336 .53952 .41652 .54892 .41288 .54392 .41032 Metetra
.622 .87 .989 r
.54392 .41032 .54892 .41288 .55836 .40952 .55339 .40725 Metetra
.613 .881 .99 r
.55339 .40725 .55836 .40952 .56783 .40642 .56289 .40414 Metetra
.615 .881 .99 r
.56289 .40414 .56783 .40642 .57733 .40359 .57242 .40099 Metetra
.628 .872 .988 r
.57242 .40099 .57733 .40359 .58688 .40105 .58199 .39781 Metetra
.69 .859 .963 r
.58199 .39781 .58688 .40105 .59644 .39752 .59157 .3938 Metetra
.736 .848 .933 r
.59157 .3938 .59644 .39752 .606 .39281 .60115 .3888 Metetra
.736 .836 .926 r
.60115 .3888 .606 .39281 .61558 .38812 .61076 .38379 Metetra
.735 .823 .919 r
.61076 .38379 .61558 .38812 .62519 .38347 .62039 .37877 Metetra
.71 .803 .923 r
.62039 .37877 .62519 .38347 .63485 .3795 .63006 .37442 Metetra
.666 .775 .931 r
.63006 .37442 .63485 .3795 .64458 .3766 .6398 .37112 Metetra
.679 .764 .915 r
.6398 .37112 .64458 .3766 .65433 .37329 .64956 .36751 Metetra
.698 .759 .899 r
.64956 .36751 .65433 .37329 .66408 .36925 .65933 .36336 Metetra
.691 .754 .9 r
.65933 .36336 .66408 .36925 .67386 .36529 .66914 .3594 Metetra
.676 .749 .906 r
.66914 .3594 .67386 .36529 .68368 .36152 .679 .35582 Metetra
.679 .759 .911 r
.679 .35582 .68368 .36152 .69354 .35778 .68888 .35216 Metetra
.687 .765 .911 r
.68888 .35216 .69354 .35778 .70343 .35415 .69879 .34828 Metetra
.686 .756 .905 r
.69879 .34828 .70343 .35415 .71335 .35049 .70873 .3444 Metetra
.686 .749 .899 r
.70873 .3444 .71335 .35049 .72331 .34675 .7187 .3405 Metetra
.691 .746 .893 r
.7187 .3405 .72331 .34675 .73328 .34283 .72869 .33641 Metetra
.71 .747 .881 r
.72869 .33641 .73328 .34283 .74325 .33832 .73867 .3317 Metetra
.703 .739 .879 r
.73867 .3317 .74325 .33832 .75325 .33391 .74868 .32718 Metetra
.674 .725 .888 r
.74868 .32718 .75325 .33391 .76331 .32995 .7588 .32351 Metetra
.673 .736 .897 r
.7588 .32351 .76331 .32995 .77341 .32608 .76894 .31988 Metetra
.664 .741 .908 r
.76894 .31988 .77341 .32608 .78359 .32273 .77915 .31651 Metetra
.664 .741 .908 r
.77915 .31651 .78359 .32273 .79381 .31937 .78939 .31313 Metetra
.664 .741 .908 r
.78939 .31313 .79381 .31937 .80406 .31599 .79967 .30973 Metetra
.664 .741 .908 r
.79967 .30973 .80406 .31599 .81435 .31261 .80998 .30632 Metetra
.664 .741 .908 r
.80998 .30632 .81435 .31261 .82468 .30921 .82034 .3029 Metetra
.664 .741 .908 r
.82034 .3029 .82468 .30921 .83504 .3058 .83072 .29947 Metetra
.664 .741 .908 r
.83072 .29947 .83504 .3058 .84544 .30238 .84115 .29603 Metetra
.664 .741 .908 r
.84115 .29603 .84544 .30238 .85587 .29894 .85161 .29257 Metetra
.664 .741 .908 r
.85161 .29257 .85587 .29894 .86635 .29549 .86211 .2891 Metetra
.664 .741 .908 r
.86211 .2891 .86635 .29549 .87686 .29204 .87265 .28562 Metetra
.664 .741 .908 r
.26983 .47774 .27542 .48295 .28395 .48013 .27837 .47491 Metetra
.664 .741 .908 r
.27837 .47491 .28395 .48013 .2925 .47731 .28694 .47206 Metetra
.664 .741 .908 r
.28694 .47206 .2925 .47731 .30108 .47447 .29554 .46921 Metetra
.664 .741 .908 r
.29554 .46921 .30108 .47447 .30969 .47163 .30417 .46635 Metetra
.664 .741 .908 r
.30417 .46635 .30969 .47163 .31833 .46877 .31282 .46348 Metetra
.664 .741 .908 r
.31282 .46348 .31833 .46877 .32699 .46591 .3215 .4606 Metetra
.664 .741 .908 r
.3215 .4606 .32699 .46591 .33569 .46304 .33021 .45771 Metetra
.664 .741 .908 r
.33021 .45771 .33569 .46304 .34441 .46015 .33895 .45481 Metetra
.664 .741 .908 r
.33895 .45481 .34441 .46015 .35316 .45726 .34772 .4519 Metetra
.664 .741 .908 r
.34772 .4519 .35316 .45726 .36194 .45436 .35652 .44898 Metetra
.66 .74 .909 r
.35652 .44898 .36194 .45436 .37074 .45171 .36534 .44613 Metetra
.66 .733 .904 r
.36534 .44613 .37074 .45171 .37956 .44911 .3742 .44328 Metetra
.614 .71 .914 r
.3742 .44328 .37956 .44911 .38838 .44733 .38303 .44144 Metetra
.602 .705 .916 r
.38303 .44144 .38838 .44733 .39723 .44574 .3919 .43984 Metetra
.622 .712 .91 r
.3919 .43984 .39723 .44574 .40614 .44355 .40081 .4378 Metetra
.628 .72 .913 r
.40081 .4378 .40614 .44355 .41509 .44118 .40977 .43564 Metetra
.627 .728 .92 r
.40977 .43564 .41509 .44118 .42407 .4388 .41876 .43347 Metetra
.625 .737 .927 r
.41876 .43347 .42407 .4388 .43308 .43642 .42778 .43129 Metetra
.649 .753 .925 r
.42778 .43129 .43308 .43642 .44213 .43383 .43686 .42859 Metetra
.659 .752 .919 r
.43686 .42859 .44213 .43383 .45122 .43115 .44597 .42567 Metetra
.634 .736 .921 r
.44597 .42567 .45122 .43115 .46033 .42886 .4551 .42329 Metetra
.622 .729 .923 r
.4551 .42329 .46033 .42886 .46947 .42676 .46426 .42117 Metetra
.619 .728 .924 r
.46426 .42117 .46947 .42676 .47865 .42412 .47345 .41909 Metetra
.613 .749 .942 r
.47345 .41909 .47865 .42412 .48788 .42118 .48269 .41703 Metetra
.566 .773 .976 r
.48269 .41703 .48788 .42118 .49712 .41929 .49195 .41547 Metetra
.531 .776 .987 r
.49195 .41547 .49712 .41929 .5064 .41806 .50125 .41423 Metetra
.531 .776 .987 r
.50125 .41423 .5064 .41806 .51572 .41683 .51059 .41298 Metetra
.531 .776 .987 r
.51059 .41298 .51572 .41683 .52508 .41559 .51998 .41173 Metetra
.54 .779 .986 r
.51998 .41173 .52508 .41559 .53449 .41336 .52941 .41036 Metetra
.511 .809 .999 r
.52941 .41036 .53449 .41336 .54392 .41032 .53888 .40889 Metetra
.49 .867 .979 r
.53888 .40889 .54392 .41032 .55339 .40725 .54839 .40657 Metetra
.508 .897 .949 r
.54839 .40657 .55339 .40725 .56289 .40414 .55793 .40344 Metetra
.587 .929 .954 r
.55793 .40344 .56289 .40414 .57242 .40099 .56748 .39951 Metetra
.694 .936 .964 r
.56748 .39951 .57242 .40099 .58199 .39781 .57706 .39471 Metetra
.73 .875 .949 r
.57706 .39471 .58199 .39781 .59157 .3938 .58665 .38982 Metetra
.736 .837 .927 r
.58665 .38982 .59157 .3938 .60115 .3888 .59627 .38479 Metetra
.736 .837 .927 r
.59627 .38479 .60115 .3888 .61076 .38379 .60591 .37976 Metetra
.736 .837 .927 r
.60591 .37976 .61076 .38379 .62039 .37877 .61557 .37472 Metetra
.724 .835 .933 r
.61557 .37472 .62039 .37877 .63006 .37442 .62526 .36998 Metetra
.703 .815 .934 r
.62526 .36998 .63006 .37442 .6398 .37112 .635 .36576 Metetra
.701 .777 .91 r
.635 .36576 .6398 .37112 .64956 .36751 .64476 .36155 Metetra
.697 .754 .895 r
.64476 .36155 .64956 .36751 .65933 .36336 .65456 .35738 Metetra
.688 .751 .899 r
.65456 .35738 .65933 .36336 .66914 .3594 .66439 .35346 Metetra
.667 .746 .909 r
.66439 .35346 .66914 .3594 .679 .35582 .67428 .35009 Metetra
.675 .758 .913 r
.67428 .35009 .679 .35582 .68888 .35216 .6842 .3465 Metetra
.695 .768 .908 r
.6842 .3465 .68888 .35216 .69879 .34828 .69412 .34238 Metetra
.694 .759 .902 r
.69412 .34238 .69879 .34828 .70873 .3444 .70407 .33824 Metetra
.693 .751 .895 r
.70407 .33824 .70873 .3444 .7187 .3405 .71405 .33409 Metetra
.697 .744 .888 r
.71405 .33409 .7187 .3405 .72869 .33641 .72405 .3298 Metetra
.709 .742 .877 r
.72405 .3298 .72869 .33641 .73867 .3317 .73406 .32507 Metetra
.702 .74 .881 r
.73406 .32507 .73867 .3317 .74868 .32718 .74411 .32058 Metetra
.667 .728 .895 r
.74411 .32058 .74868 .32718 .7588 .32351 .75426 .31711 Metetra
.666 .736 .902 r
.75426 .31711 .7588 .32351 .76894 .31988 .76445 .31365 Metetra
.664 .741 .908 r
.76445 .31365 .76894 .31988 .77915 .31651 .77468 .31025 Metetra
.664 .741 .908 r
.77468 .31025 .77915 .31651 .78939 .31313 .78494 .30685 Metetra
.664 .741 .908 r
.78494 .30685 .78939 .31313 .79967 .30973 .79525 .30343 Metetra
.664 .741 .908 r
.79525 .30343 .79967 .30973 .80998 .30632 .80559 .3 Metetra
.664 .741 .908 r
.80559 .3 .80998 .30632 .82034 .3029 .81597 .29656 Metetra
.664 .741 .908 r
.81597 .29656 .82034 .3029 .83072 .29947 .82638 .2931 Metetra
.664 .741 .908 r
.82638 .2931 .83072 .29947 .84115 .29603 .83683 .28963 Metetra
.664 .741 .908 r
.83683 .28963 .84115 .29603 .85161 .29257 .84732 .28615 Metetra
.664 .741 .908 r
.84732 .28615 .85161 .29257 .86211 .2891 .85785 .28266 Metetra
.664 .741 .908 r
.85785 .28266 .86211 .2891 .87265 .28562 .86842 .27915 Metetra
.664 .741 .908 r
.2642 .4725 .26983 .47774 .27837 .47491 .27276 .46965 Metetra
.664 .741 .908 r
.27276 .46965 .27837 .47491 .28694 .47206 .28135 .46679 Metetra
.664 .741 .908 r
.28135 .46679 .28694 .47206 .29554 .46921 .28996 .46392 Metetra
.664 .741 .908 r
.28996 .46392 .29554 .46921 .30417 .46635 .29861 .46104 Metetra
.664 .741 .908 r
.29861 .46104 .30417 .46635 .31282 .46348 .30728 .45815 Metetra
.664 .741 .908 r
.30728 .45815 .31282 .46348 .3215 .4606 .31598 .45526 Metetra
.664 .741 .908 r
.31598 .45526 .3215 .4606 .33021 .45771 .32471 .45235 Metetra
.664 .741 .908 r
.32471 .45235 .33021 .45771 .33895 .45481 .33346 .44943 Metetra
.664 .741 .908 r
.33346 .44943 .33895 .45481 .34772 .4519 .34225 .4465 Metetra
.664 .741 .908 r
.34225 .4465 .34772 .4519 .35652 .44898 .35107 .44357 Metetra
.664 .741 .908 r
.35107 .44357 .35652 .44898 .36534 .44613 .35991 .44062 Metetra
.664 .738 .906 r
.35991 .44062 .36534 .44613 .3742 .44328 .36878 .43766 Metetra
.618 .721 .919 r
.36878 .43766 .3742 .44328 .38303 .44144 .37764 .43568 Metetra
.607 .713 .919 r
.37764 .43568 .38303 .44144 .3919 .43984 .38653 .43393 Metetra
.61 .709 .915 r
.38653 .43393 .3919 .43984 .40081 .4378 .39545 .43212 Metetra
.61 .718 .922 r
.39545 .43212 .40081 .4378 .40977 .43564 .40441 .43029 Metetra
.627 .737 .927 r
.40441 .43029 .40977 .43564 .41876 .43347 .41342 .42807 Metetra
.634 .738 .924 r
.41342 .42807 .41876 .43347 .42778 .43129 .42247 .42571 Metetra
.643 .735 .916 r
.42247 .42571 .42778 .43129 .43686 .42859 .43156 .42315 Metetra
.646 .742 .919 r
.43156 .42315 .43686 .42859 .44597 .42567 .44068 .42051 Metetra
.632 .749 .932 r
.44068 .42051 .44597 .42567 .4551 .42329 .44983 .41812 Metetra
.626 .748 .935 r
.44983 .41812 .4551 .42329 .46426 .42117 .45901 .41585 Metetra
.593 .731 .94 r
.45901 .41585 .46426 .42117 .47345 .41909 .46822 .4142 Metetra
.565 .74 .958 r
.46822 .4142 .47345 .41909 .48269 .41703 .47746 .4129 Metetra
.543 .766 .98 r
.47746 .4129 .48269 .41703 .49195 .41547 .48674 .41162 Metetra
.531 .776 .987 r
.48674 .41162 .49195 .41547 .50125 .41423 .49607 .41037 Metetra
.473 .751 .99 r
.49607 .41037 .50125 .41423 .51059 .41298 .50543 .4098 Metetra
.381 .74 .991 r
.50543 .4098 .51059 .41298 .51998 .41173 .51484 .40972 Metetra
.246 .715 .944 r
.51484 .40972 .51998 .41173 .52941 .41036 .52429 .40982 Metetra
.035 .603 .77 r
.52429 .40982 .52941 .41036 .53888 .40889 .5338 .41007 Metetra
.5338 .41007 .53888 .40889 .54839 .40657 .54336 .40858 Metetra
.54336 .40858 .54839 .40657 .55793 .40344 .55294 .40544 Metetra
.383 .828 .705 r
.55294 .40544 .55793 .40344 .56748 .39951 .56253 .40064 Metetra
.655 .971 .84 r
.56253 .40064 .56748 .39951 .57706 .39471 .57213 .39409 Metetra
.752 .974 .924 r
.57213 .39409 .57706 .39471 .58665 .38982 .58174 .38768 Metetra
.776 .924 .934 r
.58174 .38768 .58665 .38982 .59627 .38479 .59137 .38145 Metetra
.762 .871 .928 r
.59137 .38145 .59627 .38479 .60591 .37976 .60102 .3757 Metetra
.736 .837 .927 r
.60102 .3757 .60591 .37976 .61557 .37472 .61071 .37063 Metetra
.735 .837 .927 r
.61071 .37063 .61557 .37472 .62526 .36998 .62043 .36557 Metetra
.733 .824 .921 r
.62043 .36557 .62526 .36998 .635 .36576 .63017 .36054 Metetra
.718 .789 .908 r
.63017 .36054 .635 .36576 .64476 .36155 .63994 .35586 Metetra
.694 .764 .906 r
.63994 .35586 .64476 .36155 .65456 .35738 .64977 .3518 Metetra
.689 .768 .912 r
.64977 .3518 .65456 .35738 .66439 .35346 .65963 .34785 Metetra
.679 .764 .915 r
.65963 .34785 .66439 .35346 .67428 .35009 .66953 .34416 Metetra
.681 .754 .906 r
.66953 .34416 .67428 .35009 .6842 .3465 .67946 .34038 Metetra
.688 .75 .899 r
.67946 .34038 .6842 .3465 .69412 .34238 .68942 .33641 Metetra
.693 .758 .901 r
.68942 .33641 .69412 .34238 .70407 .33824 .6994 .33228 Metetra
.707 .763 .896 r
.6994 .33228 .70407 .33824 .71405 .33409 .70938 .32775 Metetra
.705 .75 .887 r
.70938 .32775 .71405 .33409 .72405 .3298 .71939 .32319 Metetra
.705 .742 .88 r
.71939 .32319 .72405 .3298 .73406 .32507 .72943 .31856 Metetra
.698 .744 .887 r
.72943 .31856 .73406 .32507 .74411 .32058 .73951 .31417 Metetra
.663 .735 .903 r
.73951 .31417 .74411 .32058 .75426 .31711 .7497 .31078 Metetra
.664 .738 .906 r
.7497 .31078 .75426 .31711 .76445 .31365 .75992 .30737 Metetra
.664 .741 .908 r
.75992 .30737 .76445 .31365 .77468 .31025 .77017 .30396 Metetra
.664 .741 .908 r
.77017 .30396 .77468 .31025 .78494 .30685 .78047 .30053 Metetra
.664 .741 .908 r
.78047 .30053 .78494 .30685 .79525 .30343 .7908 .29709 Metetra
.664 .741 .908 r
.7908 .29709 .79525 .30343 .80559 .3 .80116 .29363 Metetra
.664 .741 .908 r
.80116 .29363 .80559 .3 .81597 .29656 .81157 .29017 Metetra
.664 .741 .908 r
.81157 .29017 .81597 .29656 .82638 .2931 .82201 .28669 Metetra
.664 .741 .908 r
.82201 .28669 .82638 .2931 .83683 .28963 .83249 .2832 Metetra
.664 .741 .908 r
.83249 .2832 .83683 .28963 .84732 .28615 .84301 .27969 Metetra
.664 .741 .908 r
.84301 .27969 .84732 .28615 .85785 .28266 .85356 .27618 Metetra
.664 .741 .908 r
.85356 .27618 .85785 .28266 .86842 .27915 .86416 .27265 Metetra
.664 .741 .908 r
.25854 .46723 .2642 .4725 .27276 .46965 .26712 .46436 Metetra
.664 .741 .908 r
.26712 .46436 .27276 .46965 .28135 .46679 .27572 .46149 Metetra
.664 .741 .908 r
.27572 .46149 .28135 .46679 .28996 .46392 .28435 .4586 Metetra
.664 .741 .908 r
.28435 .4586 .28996 .46392 .29861 .46104 .29301 .4557 Metetra
.664 .741 .908 r
.29301 .4557 .29861 .46104 .30728 .45815 .3017 .4528 Metetra
.664 .741 .908 r
.3017 .4528 .30728 .45815 .31598 .45526 .31042 .44988 Metetra
.664 .741 .908 r
.31042 .44988 .31598 .45526 .32471 .45235 .31916 .44695 Metetra
.664 .741 .908 r
.31916 .44695 .32471 .45235 .33346 .44943 .32794 .44402 Metetra
.664 .741 .908 r
.32794 .44402 .33346 .44943 .34225 .4465 .33674 .44107 Metetra
.664 .741 .908 r
.33674 .44107 .34225 .4465 .35107 .44357 .34558 .43812 Metetra
.664 .741 .908 r
.34558 .43812 .35107 .44357 .35991 .44062 .35444 .43516 Metetra
.664 .741 .908 r
.35444 .43516 .35991 .44062 .36878 .43766 .36333 .43218 Metetra
.627 .73 .922 r
.36333 .43218 .36878 .43766 .37764 .43568 .37222 .43 Metetra
.618 .721 .919 r
.37222 .43 .37764 .43568 .38653 .43393 .38113 .42801 Metetra
.595 .704 .919 r
.38113 .42801 .38653 .43393 .39545 .43212 .39005 .42648 Metetra
.585 .712 .93 r
.39005 .42648 .39545 .43212 .40441 .43029 .39901 .42508 Metetra
.637 .747 .928 r
.39901 .42508 .40441 .43029 .41342 .42807 .40805 .42263 Metetra
.654 .744 .916 r
.40805 .42263 .41342 .42807 .42247 .42571 .41713 .4198 Metetra
.628 .719 .912 r
.41713 .4198 .42247 .42571 .43156 .42315 .42622 .41757 Metetra
.614 .727 .926 r
.42622 .41757 .43156 .42315 .44068 .42051 .43535 .41558 Metetra
.627 .758 .941 r
.43535 .41558 .44068 .42051 .44983 .41812 .44452 .41324 Metetra
.635 .764 .941 r
.44452 .41324 .44983 .41812 .45901 .41585 .45372 .41073 Metetra
.569 .731 .951 r
.45372 .41073 .45901 .41585 .46822 .4142 .46294 .40942 Metetra
.514 .725 .969 r
.46294 .40942 .46822 .4142 .47746 .4129 .47219 .40877 Metetra
.522 .76 .983 r
.47219 .40877 .47746 .4129 .48674 .41162 .48149 .40775 Metetra
.531 .776 .987 r
.48149 .40775 .48674 .41162 .49607 .41037 .49084 .40648 Metetra
.355 .693 .982 r
.49084 .40648 .49607 .41037 .50543 .4098 .50022 .40708 Metetra
.063 .566 .886 r
.50022 .40708 .50543 .4098 .51484 .40972 .50964 .40905 Metetra
.2 0 0 r
.50964 .40905 .51484 .40972 .52429 .40982 .51913 .41108 Metetra
.374 0 0 r
.51913 .41108 .52429 .40982 .5338 .41007 .52867 .41317 Metetra
.24 0 0 r
.52867 .41317 .5338 .41007 .54336 .40858 .53828 .41257 Metetra
.053 0 0 r
.53828 .41257 .54336 .40858 .55294 .40544 .54791 .40942 Metetra
.54791 .40942 .55294 .40544 .56253 .40064 .55755 .40371 Metetra
.615 .925 .681 r
.55755 .40371 .56253 .40064 .57213 .39409 .56717 .39528 Metetra
.767 .997 .829 r
.56717 .39528 .57213 .39409 .58174 .38768 .5768 .3869 Metetra
.834 .97 .887 r
.5768 .3869 .58174 .38768 .59137 .38145 .58643 .37857 Metetra
.802 .895 .909 r
.58643 .37857 .59137 .38145 .60102 .3757 .5961 .3716 Metetra
.736 .837 .927 r
.5961 .3716 .60102 .3757 .61071 .37063 .60582 .36651 Metetra
.745 .839 .922 r
.60582 .36651 .61071 .37063 .62043 .36557 .61556 .36116 Metetra
.757 .83 .909 r
.61556 .36116 .62043 .36557 .63017 .36054 .62531 .35543 Metetra
.731 .797 .905 r
.62531 .35543 .63017 .36054 .63994 .35586 .6351 .35036 Metetra
.685 .77 .916 r
.6351 .35036 .63994 .35586 .64977 .3518 .64496 .3465 Metetra
.692 .781 .919 r
.64496 .3465 .64977 .3518 .65963 .34785 .65484 .34247 Metetra
.705 .783 .912 r
.65484 .34247 .65963 .34785 .66953 .34416 .66474 .33807 Metetra
.694 .753 .898 r
.66474 .33807 .66953 .34416 .67946 .34038 .67468 .33392 Metetra
.67 .733 .897 r
.67468 .33392 .67946 .34038 .68942 .33641 .68468 .33038 Metetra
.685 .754 .904 r
.68468 .33038 .68942 .33641 .6994 .33228 .6947 .32645 Metetra
.723 .775 .894 r
.6947 .32645 .6994 .33228 .70938 .32775 .70469 .32144 Metetra
.715 .756 .885 r
.70469 .32144 .70938 .32775 .71939 .32319 .71471 .31655 Metetra
.698 .74 .884 r
.71471 .31655 .71939 .32319 .72943 .31856 .72478 .31213 Metetra
.693 .746 .892 r
.72478 .31213 .72943 .31856 .73951 .31417 .7349 .3079 Metetra
.664 .741 .908 r
.7349 .3079 .73951 .31417 .7497 .31078 .74511 .30448 Metetra
.664 .741 .908 r
.74511 .30448 .7497 .31078 .75992 .30737 .75536 .30106 Metetra
.664 .741 .908 r
.75536 .30106 .75992 .30737 .77017 .30396 .76564 .29762 Metetra
.664 .741 .908 r
.76564 .29762 .77017 .30396 .78047 .30053 .77596 .29417 Metetra
.664 .741 .908 r
.77596 .29417 .78047 .30053 .7908 .29709 .78632 .2907 Metetra
.664 .741 .908 r
.78632 .2907 .7908 .29709 .80116 .29363 .79671 .28723 Metetra
.664 .741 .908 r
.79671 .28723 .80116 .29363 .81157 .29017 .80714 .28374 Metetra
.664 .741 .908 r
.80714 .28374 .81157 .29017 .82201 .28669 .81761 .28023 Metetra
.664 .741 .908 r
.81761 .28023 .82201 .28669 .83249 .2832 .82812 .27672 Metetra
.664 .741 .908 r
.82812 .27672 .83249 .2832 .84301 .27969 .83866 .27319 Metetra
.664 .741 .908 r
.83866 .27319 .84301 .27969 .85356 .27618 .84924 .26965 Metetra
.664 .741 .908 r
.84924 .26965 .85356 .27618 .86416 .27265 .85987 .2661 Metetra
.664 .741 .908 r
.25285 .46193 .25854 .46723 .26712 .46436 .26144 .45904 Metetra
.664 .741 .908 r
.26144 .45904 .26712 .46436 .27572 .46149 .27006 .45615 Metetra
.664 .741 .908 r
.27006 .45615 .27572 .46149 .28435 .4586 .27871 .45324 Metetra
.664 .741 .908 r
.27871 .45324 .28435 .4586 .29301 .4557 .28738 .45033 Metetra
.664 .741 .908 r
.28738 .45033 .29301 .4557 .3017 .4528 .29609 .4474 Metetra
.664 .741 .908 r
.29609 .4474 .3017 .4528 .31042 .44988 .30483 .44447 Metetra
.664 .741 .908 r
.30483 .44447 .31042 .44988 .31916 .44695 .31359 .44153 Metetra
.664 .741 .908 r
.31359 .44153 .31916 .44695 .32794 .44402 .32238 .43857 Metetra
.664 .741 .908 r
.32238 .43857 .32794 .44402 .33674 .44107 .3312 .43561 Metetra
.664 .741 .908 r
.3312 .43561 .33674 .44107 .34558 .43812 .34006 .43264 Metetra
.664 .741 .908 r
.34006 .43264 .34558 .43812 .35444 .43516 .34894 .42966 Metetra
.664 .741 .908 r
.34894 .42966 .35444 .43516 .36333 .43218 .35785 .42666 Metetra
.64 .734 .917 r
.35785 .42666 .36333 .43218 .37222 .43 .36676 .42419 Metetra
.635 .722 .911 r
.36676 .42419 .37222 .43 .38113 .42801 .3757 .42184 Metetra
.578 .689 .917 r
.3757 .42184 .38113 .42801 .39005 .42648 .38463 .42065 Metetra
.553 .694 .933 r
.38463 .42065 .39005 .42648 .39901 .42508 .39358 .4198 Metetra
.642 .747 .926 r
.39358 .4198 .39901 .42508 .40805 .42263 .40264 .41724 Metetra
.668 .751 .913 r
.40264 .41724 .40805 .42263 .41713 .4198 .41175 .41407 Metetra
.617 .723 .922 r
.41175 .41407 .41713 .4198 .42622 .41757 .42086 .41203 Metetra
.591 .722 .935 r
.42086 .41203 .42622 .41757 .43535 .41558 .42999 .41045 Metetra
.62 .749 .939 r
.42999 .41045 .43535 .41558 .44452 .41324 .43917 .40824 Metetra
.634 .76 .938 r
.43917 .40824 .44452 .41324 .45372 .41073 .4484 .40573 Metetra
.573 .74 .955 r
.4484 .40573 .45372 .41073 .46294 .40942 .45764 .4043 Metetra
.536 .721 .958 r
.45764 .4043 .46294 .40942 .47219 .40877 .46691 .40344 Metetra
.522 .706 .955 r
.46691 .40344 .47219 .40877 .48149 .40775 .47622 .40286 Metetra
.496 .716 .969 r
.47622 .40286 .48149 .40775 .49084 .40648 .48558 .40245 Metetra
.188 .592 .943 r
.48558 .40245 .49084 .40648 .50022 .40708 .49496 .40453 Metetra
0 .343 .702 r
.49496 .40453 .50022 .40708 .50964 .40905 .50439 .40843 Metetra
.824 .356 .09 r
.50439 .40843 .50964 .40905 .51913 .41108 .51386 .42291 Metetra
.799 .447 .39 r
.51386 .42291 .51913 .41108 .52867 .41317 .52347 .44646 Metetra
.618 .325 .45 r
.52347 .44646 .52867 .41317 .53828 .41257 .53323 .45641 Metetra
.507 .243 .448 r
.53323 .45641 .53828 .41257 .54791 .40942 .54304 .45328 Metetra
.372 .131 .414 r
.54304 .45328 .54791 .40942 .55755 .40371 .55276 .43702 Metetra
.016 0 .261 r
.55276 .43702 .55755 .40371 .56717 .39528 .56229 .40708 Metetra
.56229 .40708 .56717 .39528 .5768 .3869 .57182 .38616 Metetra
.883 .959 .845 r
.57182 .38616 .5768 .3869 .58643 .37857 .58146 .37585 Metetra
.842 .9 .879 r
.58146 .37585 .58643 .37857 .5961 .3716 .59113 .36736 Metetra
.766 .837 .907 r
.59113 .36736 .5961 .3716 .60582 .36651 .60086 .36137 Metetra
.754 .801 .89 r
.60086 .36137 .60582 .36651 .61556 .36116 .61062 .35553 Metetra
.742 .781 .884 r
.61062 .35553 .61556 .36116 .62531 .35543 .6204 .34996 Metetra
.725 .784 .899 r
.6204 .34996 .62531 .35543 .6351 .35036 .63022 .34499 Metetra
.687 .777 .92 r
.63022 .34499 .6351 .35036 .64496 .3465 .64011 .34109 Metetra
.698 .78 .915 r
.64011 .34109 .64496 .3465 .65484 .34247 .65002 .33687 Metetra
.719 .78 .9 r
.65002 .33687 .65484 .34247 .66474 .33807 .65992 .33202 Metetra
.701 .759 .897 r
.65992 .33202 .66474 .33807 .67468 .33392 .66988 .32763 Metetra
.658 .736 .907 r
.66988 .32763 .67468 .33392 .68468 .33038 .67992 .3244 Metetra
.682 .757 .908 r
.67992 .3244 .68468 .33038 .6947 .32645 .68997 .32054 Metetra
.74 .779 .884 r
.68997 .32054 .6947 .32645 .70469 .32144 .69995 .31493 Metetra
.725 .754 .875 r
.69995 .31493 .70469 .32144 .71471 .31655 .70998 .30965 Metetra
.686 .728 .882 r
.70998 .30965 .71471 .31655 .72478 .31213 .7201 .30556 Metetra
.683 .739 .893 r
.7201 .30556 .72478 .31213 .7349 .3079 .73026 .30158 Metetra
.664 .741 .908 r
.73026 .30158 .7349 .3079 .74511 .30448 .7405 .29815 Metetra
.664 .741 .908 r
.7405 .29815 .74511 .30448 .75536 .30106 .75077 .2947 Metetra
.664 .741 .908 r
.75077 .2947 .75536 .30106 .76564 .29762 .76108 .29124 Metetra
.664 .741 .908 r
.76108 .29124 .76564 .29762 .77596 .29417 .77142 .28776 Metetra
.664 .741 .908 r
.77142 .28776 .77596 .29417 .78632 .2907 .7818 .28427 Metetra
.664 .741 .908 r
.7818 .28427 .78632 .2907 .79671 .28723 .79222 .28077 Metetra
.664 .741 .908 r
.79222 .28077 .79671 .28723 .80714 .28374 .80268 .27726 Metetra
.664 .741 .908 r
.80268 .27726 .80714 .28374 .81761 .28023 .81318 .27374 Metetra
.664 .741 .908 r
.81318 .27374 .81761 .28023 .82812 .27672 .82371 .2702 Metetra
.664 .741 .908 r
.82371 .2702 .82812 .27672 .83866 .27319 .83429 .26665 Metetra
.664 .741 .908 r
.83429 .26665 .83866 .27319 .84924 .26965 .8449 .26308 Metetra
.664 .741 .908 r
.8449 .26308 .84924 .26965 .85987 .2661 .85555 .25951 Metetra
.664 .741 .908 r
.24712 .45659 .25285 .46193 .26144 .45904 .25573 .45369 Metetra
.664 .741 .908 r
.25573 .45369 .26144 .45904 .27006 .45615 .26436 .45078 Metetra
.664 .741 .908 r
.26436 .45078 .27006 .45615 .27871 .45324 .27303 .44786 Metetra
.664 .741 .908 r
.27303 .44786 .27871 .45324 .28738 .45033 .28172 .44492 Metetra
.664 .741 .908 r
.28172 .44492 .28738 .45033 .29609 .4474 .29045 .44198 Metetra
.664 .741 .908 r
.29045 .44198 .29609 .4474 .30483 .44447 .2992 .43903 Metetra
.664 .741 .908 r
.2992 .43903 .30483 .44447 .31359 .44153 .30798 .43607 Metetra
.664 .741 .908 r
.30798 .43607 .31359 .44153 .32238 .43857 .31679 .4331 Metetra
.664 .741 .908 r
.31679 .4331 .32238 .43857 .3312 .43561 .32563 .43012 Metetra
.664 .741 .908 r
.32563 .43012 .3312 .43561 .34006 .43264 .3345 .42712 Metetra
.664 .741 .908 r
.3345 .42712 .34006 .43264 .34894 .42966 .3434 .42412 Metetra
.664 .741 .908 r
.3434 .42412 .34894 .42966 .35785 .42666 .35233 .42111 Metetra
.656 .739 .911 r
.35233 .42111 .35785 .42666 .36676 .42419 .36128 .41826 Metetra
.654 .726 .901 r
.36128 .41826 .36676 .42419 .3757 .42184 .37026 .41545 Metetra
.556 .674 .917 r
.37026 .41545 .3757 .42184 .38463 .42065 .37918 .41466 Metetra
.512 .672 .936 r
.37918 .41466 .38463 .42065 .39358 .4198 .38811 .41447 Metetra
.641 .746 .925 r
.38811 .41447 .39358 .4198 .40264 .41724 .39719 .41189 Metetra
.678 .757 .911 r
.39719 .41189 .40264 .41724 .41175 .41407 .40633 .40847 Metetra
.611 .728 .928 r
.40633 .40847 .41175 .41407 .42086 .41203 .41545 .40651 Metetra
.577 .719 .94 r
.41545 .40651 .42086 .41203 .42999 .41045 .42459 .40514 Metetra
.609 .74 .938 r
.42459 .40514 .42999 .41045 .43917 .40824 .43379 .40314 Metetra
.623 .754 .94 r
.43379 .40314 .43917 .40824 .4484 .40573 .44303 .40084 Metetra
.601 .756 .952 r
.44303 .40084 .4484 .40573 .45764 .4043 .4523 .39888 Metetra
.596 .733 .94 r
.4523 .39888 .45764 .4043 .46691 .40344 .46161 .39711 Metetra
.502 .658 .93 r
.46161 .39711 .46691 .40344 .47622 .40286 .47093 .39713 Metetra
.397 .633 .949 r
.47093 .39713 .47622 .40286 .48558 .40245 .48028 .3983 Metetra
0 .442 .852 r
.48028 .3983 .48558 .40245 .49496 .40453 .48966 .4021 Metetra
.444 0 0 r
.48966 .4021 .49496 .40453 .50439 .40843 .4991 .40785 Metetra
.922 .554 .308 r
.4991 .40785 .50439 .40843 .51386 .42291 .50847 .44381 Metetra
.86 .547 .456 r
.50847 .44381 .51386 .42291 .52347 .44646 .51805 .5067 Metetra
.669 .394 .495 r
.51805 .5067 .52347 .44646 .53323 .45641 .52803 .53655 Metetra
.525 .28 .486 r
.52803 .53655 .53323 .45641 .54304 .45328 .53812 .53347 Metetra
.331 .125 .441 r
.53812 .53347 .54304 .45328 .55276 .43702 .54801 .49737 Metetra
0 0 .228 r
.54801 .49737 .55276 .43702 .56229 .40708 .55741 .42798 Metetra
.733 .717 .187 r
.55741 .42798 .56229 .40708 .57182 .38616 .56678 .38547 Metetra
.914 .944 .808 r
.56678 .38547 .57182 .38616 .58146 .37585 .57645 .37326 Metetra
.876 .897 .843 r
.57645 .37326 .58146 .37585 .59113 .36736 .58613 .363 Metetra
.807 .837 .873 r
.58613 .363 .59113 .36736 .60086 .36137 .59586 .35537 Metetra
.763 .774 .862 r
.59586 .35537 .60086 .36137 .61062 .35553 .60562 .34889 Metetra
.708 .738 .875 r
.60562 .34889 .61062 .35553 .6204 .34996 .61545 .34421 Metetra
.707 .769 .901 r
.61545 .34421 .6204 .34996 .63022 .34499 .62532 .33971 Metetra
.696 .785 .92 r
.62532 .33971 .63022 .34499 .64011 .34109 .63523 .33556 Metetra
.706 .779 .909 r
.63523 .33556 .64011 .34109 .65002 .33687 .64515 .3311 Metetra
.726 .777 .893 r
.64515 .3311 .65002 .33687 .65992 .33202 .65508 .32599 Metetra
.705 .762 .897 r
.65508 .32599 .65992 .33202 .66988 .32763 .66506 .32149 Metetra
.649 .739 .915 r
.66506 .32149 .66988 .32763 .67992 .3244 .67513 .31846 Metetra
.682 .76 .91 r
.67513 .31846 .67992 .3244 .68997 .32054 .68521 .31457 Metetra
.759 .783 .872 r
.68521 .31457 .68997 .32054 .69995 .31493 .69518 .30824 Metetra
.736 .753 .866 r
.69518 .30824 .69995 .31493 .70998 .30965 .70521 .30251 Metetra
.67 .716 .883 r
.70521 .30251 .70998 .30965 .7201 .30556 .71538 .29886 Metetra
.67 .731 .896 r
.71538 .29886 .7201 .30556 .73026 .30158 .72559 .29523 Metetra
.664 .741 .908 r
.72559 .29523 .73026 .30158 .7405 .29815 .73585 .29177 Metetra
.664 .741 .908 r
.73585 .29177 .7405 .29815 .75077 .2947 .74615 .2883 Metetra
.664 .741 .908 r
.74615 .2883 .75077 .2947 .76108 .29124 .75648 .28481 Metetra
.664 .741 .908 r
.75648 .28481 .76108 .29124 .77142 .28776 .76685 .28131 Metetra
.664 .741 .908 r
.76685 .28131 .77142 .28776 .7818 .28427 .77726 .2778 Metetra
.664 .741 .908 r
.77726 .2778 .7818 .28427 .79222 .28077 .78771 .27428 Metetra
.664 .741 .908 r
.78771 .27428 .79222 .28077 .80268 .27726 .7982 .27074 Metetra
.664 .741 .908 r
.7982 .27074 .80268 .27726 .81318 .27374 .80872 .2672 Metetra
.664 .741 .908 r
.80872 .2672 .81318 .27374 .82371 .2702 .81928 .26363 Metetra
.664 .741 .908 r
.81928 .26363 .82371 .2702 .83429 .26665 .82988 .26006 Metetra
.664 .741 .908 r
.82988 .26006 .83429 .26665 .8449 .26308 .84052 .25647 Metetra
.664 .741 .908 r
.84052 .25647 .8449 .26308 .85555 .25951 .8512 .25287 Metetra
.664 .741 .908 r
.24135 .45123 .24712 .45659 .25573 .45369 .24998 .44831 Metetra
.664 .741 .908 r
.24998 .44831 .25573 .45369 .26436 .45078 .25863 .44537 Metetra
.664 .741 .908 r
.25863 .44537 .26436 .45078 .27303 .44786 .26732 .44243 Metetra
.664 .741 .908 r
.26732 .44243 .27303 .44786 .28172 .44492 .27603 .43948 Metetra
.664 .741 .908 r
.27603 .43948 .28172 .44492 .29045 .44198 .28477 .43652 Metetra
.664 .741 .908 r
.28477 .43652 .29045 .44198 .2992 .43903 .29354 .43355 Metetra
.664 .741 .908 r
.29354 .43355 .2992 .43903 .30798 .43607 .30234 .43057 Metetra
.664 .741 .908 r
.30234 .43057 .30798 .43607 .31679 .4331 .31116 .42759 Metetra
.664 .741 .908 r
.31116 .42759 .31679 .4331 .32563 .43012 .32002 .42459 Metetra
.664 .741 .908 r
.32002 .42459 .32563 .43012 .3345 .42712 .32891 .42158 Metetra
.664 .741 .908 r
.32891 .42158 .3345 .42712 .3434 .42412 .33783 .41856 Metetra
.664 .741 .908 r
.33783 .41856 .3434 .42412 .35233 .42111 .34677 .41553 Metetra
.664 .741 .908 r
.34677 .41553 .35233 .42111 .36128 .41826 .35575 .41249 Metetra
.663 .735 .903 r
.35575 .41249 .36128 .41826 .37026 .41545 .36476 .40943 Metetra
.538 .682 .932 r
.36476 .40943 .37026 .41545 .37918 .41466 .37368 .40883 Metetra
.484 .667 .944 r
.37368 .40883 .37918 .41466 .38811 .41447 .38262 .40895 Metetra
.642 .741 .921 r
.38262 .40895 .38811 .41447 .39719 .41189 .39172 .40636 Metetra
.682 .752 .905 r
.39172 .40636 .39719 .41189 .40633 .40847 .40088 .40281 Metetra
.609 .726 .928 r
.40088 .40281 .40633 .40847 .41545 .40651 .41002 .40088 Metetra
.572 .714 .938 r
.41002 .40088 .41545 .40651 .42459 .40514 .41917 .3996 Metetra
.605 .73 .933 r
.41917 .3996 .42459 .40514 .43379 .40314 .42838 .39769 Metetra
.62 .74 .932 r
.42838 .39769 .43379 .40314 .44303 .40084 .43764 .39548 Metetra
.619 .744 .936 r
.43764 .39548 .44303 .40084 .4523 .39888 .44694 .39326 Metetra
.621 .735 .928 r
.44694 .39326 .4523 .39888 .46161 .39711 .45627 .39104 Metetra
.474 .657 .941 r
.45627 .39104 .46161 .39711 .47093 .39713 .4656 .39134 Metetra
.329 .595 .943 r
.4656 .39134 .47093 .39713 .48028 .3983 .47495 .39326 Metetra
0 .396 .84 r
.47495 .39326 .48028 .3983 .48966 .4021 .48433 .3979 Metetra
0 .168 .625 r
.48433 .3979 .48966 .4021 .4991 .40785 .49377 .40454 Metetra
.944 .593 .314 r
.49377 .40454 .4991 .40785 .50847 .44381 .50304 .4511 Metetra
.926 .608 .422 r
.50304 .4511 .50847 .44381 .51805 .5067 .5125 .53395 Metetra
.787 .473 .458 r
.5125 .53395 .51805 .5067 .52803 .53655 .52254 .57416 Metetra
.497 .221 .425 r
.52254 .57416 .52803 .53655 .53812 .53347 .53278 .57109 Metetra
0 0 .133 r
.53278 .57109 .53812 .53347 .54801 .49737 .54283 .52464 Metetra
.958 .782 .335 r
.54283 .52464 .54801 .49737 .55741 .42798 .55229 .43522 Metetra
1 .815 .496 r
.55229 .43522 .55741 .42798 .56678 .38547 .56167 .38203 Metetra
.9 .854 .788 r
.56167 .38203 .56678 .38547 .57645 .37326 .57137 .36889 Metetra
.867 .833 .811 r
.57137 .36889 .57645 .37326 .58613 .363 .58107 .35774 Metetra
.813 .806 .844 r
.58107 .35774 .58613 .363 .59586 .35537 .59081 .34931 Metetra
.77 .774 .856 r
.59081 .34931 .59586 .35537 .60562 .34889 .6006 .34249 Metetra
.696 .744 .889 r
.6006 .34249 .60562 .34889 .61545 .34421 .61047 .33824 Metetra
.698 .76 .9 r
.61047 .33824 .61545 .34421 .62532 .33971 .62037 .33396 Metetra
.699 .769 .906 r
.62037 .33396 .62532 .33971 .63523 .33556 .6303 .32968 Metetra
.709 .768 .899 r
.6303 .32968 .63523 .33556 .64515 .3311 .64025 .32508 Metetra
.728 .77 .886 r
.64025 .32508 .64515 .3311 .65508 .32599 .65019 .31984 Metetra
.706 .76 .894 r
.65019 .31984 .65508 .32599 .66506 .32149 .6602 .31527 Metetra
.644 .736 .916 r
.6602 .31527 .66506 .32149 .67513 .31846 .6703 .31233 Metetra
.682 .754 .906 r
.6703 .31233 .67513 .31846 .68521 .31457 .6804 .30841 Metetra
.766 .779 .864 r
.6804 .30841 .68521 .31457 .69518 .30824 .69039 .30172 Metetra
.744 .762 .868 r
.69039 .30172 .69518 .30824 .70521 .30251 .70043 .29576 Metetra
.663 .727 .897 r
.70043 .29576 .70521 .30251 .71538 .29886 .71064 .2923 Metetra
.663 .735 .903 r
.71064 .2923 .71538 .29886 .72559 .29523 .72089 .28883 Metetra
.664 .741 .908 r
.72089 .28883 .72559 .29523 .73585 .29177 .73118 .28535 Metetra
.664 .741 .908 r
.73118 .28535 .73585 .29177 .74615 .2883 .7415 .28185 Metetra
.664 .741 .908 r
.7415 .28185 .74615 .2883 .75648 .28481 .75186 .27834 Metetra
.664 .741 .908 r
.75186 .27834 .75648 .28481 .76685 .28131 .76226 .27482 Metetra
.664 .741 .908 r
.76226 .27482 .76685 .28131 .77726 .2778 .77269 .27129 Metetra
.664 .741 .908 r
.77269 .27129 .77726 .2778 .78771 .27428 .78317 .26774 Metetra
.664 .741 .908 r
.78317 .26774 .78771 .27428 .7982 .27074 .79368 .26418 Metetra
.664 .741 .908 r
.79368 .26418 .7982 .27074 .80872 .2672 .80423 .26061 Metetra
.664 .741 .908 r
.80423 .26061 .80872 .2672 .81928 .26363 .81482 .25702 Metetra
.664 .741 .908 r
.81482 .25702 .81928 .26363 .82988 .26006 .82545 .25342 Metetra
.664 .741 .908 r
.82545 .25342 .82988 .26006 .84052 .25647 .83611 .24981 Metetra
.664 .741 .908 r
.83611 .24981 .84052 .25647 .8512 .25287 .84682 .24619 Metetra
.664 .741 .908 r
.23555 .44583 .24135 .45123 .24998 .44831 .2442 .44289 Metetra
.664 .741 .908 r
.2442 .44289 .24998 .44831 .25863 .44537 .25287 .43994 Metetra
.664 .741 .908 r
.25287 .43994 .25863 .44537 .26732 .44243 .26157 .43698 Metetra
.664 .741 .908 r
.26157 .43698 .26732 .44243 .27603 .43948 .2703 .43401 Metetra
.664 .741 .908 r
.2703 .43401 .27603 .43948 .28477 .43652 .27905 .43103 Metetra
.664 .741 .908 r
.27905 .43103 .28477 .43652 .29354 .43355 .28784 .42805 Metetra
.664 .741 .908 r
.28784 .42805 .29354 .43355 .30234 .43057 .29666 .42505 Metetra
.664 .741 .908 r
.29666 .42505 .30234 .43057 .31116 .42759 .3055 .42204 Metetra
.664 .741 .908 r
.3055 .42204 .31116 .42759 .32002 .42459 .31438 .41902 Metetra
.664 .741 .908 r
.31438 .41902 .32002 .42459 .32891 .42158 .32328 .41599 Metetra
.664 .741 .908 r
.32328 .41599 .32891 .42158 .33783 .41856 .33222 .41295 Metetra
.664 .741 .908 r
.33222 .41295 .33783 .41856 .34677 .41553 .34119 .4099 Metetra
.664 .741 .908 r
.34119 .4099 .34677 .41553 .35575 .41249 .35018 .40685 Metetra
.664 .741 .908 r
.35018 .40685 .35575 .41249 .36476 .40943 .35921 .40378 Metetra
.531 .695 .944 r
.35921 .40378 .36476 .40943 .37368 .40883 .36815 .40316 Metetra
.478 .673 .95 r
.36815 .40316 .37368 .40883 .38262 .40895 .3771 .40326 Metetra
.642 .735 .917 r
.3771 .40326 .38262 .40895 .39172 .40636 .38621 .40065 Metetra
.681 .747 .901 r
.38621 .40065 .39172 .40636 .40088 .40281 .3954 .39708 Metetra
.609 .724 .927 r
.3954 .39708 .40088 .40281 .41002 .40088 .40455 .39513 Metetra
.573 .711 .936 r
.40455 .39513 .41002 .40088 .41917 .3996 .41372 .39383 Metetra
.607 .724 .928 r
.41372 .39383 .41917 .3996 .42838 .39769 .42295 .39191 Metetra
.622 .729 .923 r
.42295 .39191 .42838 .39769 .43764 .39548 .43223 .38968 Metetra
.622 .729 .923 r
.43223 .38968 .43764 .39548 .44694 .39326 .44154 .38744 Metetra
.622 .729 .923 r
.44154 .38744 .44694 .39326 .45627 .39104 .4509 .3852 Metetra
.466 .665 .948 r
.4509 .3852 .45627 .39104 .4656 .39134 .46024 .38549 Metetra
.33 .595 .942 r
.46024 .38549 .4656 .39134 .47495 .39326 .4696 .3874 Metetra
.043 .418 .864 r
.4696 .3874 .47495 .39326 .48433 .3979 .47899 .39202 Metetra
0 .255 .75 r
.47899 .39202 .48433 .3979 .49377 .40454 .48844 .39866 Metetra
.95 .599 .283 r
.48844 .39866 .49377 .40454 .50304 .4511 .49764 .44527 Metetra
.961 .641 .362 r
.49764 .44527 .50304 .4511 .5125 .53395 .50698 .52823 Metetra
.939 .569 .235 r
.50698 .52823 .5125 .53395 .52254 .57416 .51698 .56849 Metetra
.646 .762 .934 r
.51698 .56849 .52254 .57416 .53278 .57109 .52724 .56541 Metetra
.952 .746 .589 r
.52724 .56541 .53278 .57109 .54283 .52464 .53738 .51886 Metetra
.963 .721 .524 r
.53738 .51886 .54283 .52464 .55229 .43522 .54701 .42928 Metetra
.956 .737 .567 r
.54701 .42928 .55229 .43522 .56167 .38203 .55649 .376 Metetra
.865 .782 .768 r
.55649 .376 .56167 .38203 .57137 .36889 .56622 .36282 Metetra
.844 .783 .793 r
.56622 .36282 .57137 .36889 .58107 .35774 .57596 .35164 Metetra
.803 .779 .831 r
.57596 .35164 .58107 .35774 .59081 .34931 .58574 .34318 Metetra
.77 .773 .856 r
.58574 .34318 .59081 .34931 .6006 .34249 .59555 .33634 Metetra
.697 .754 .896 r
.59555 .33634 .6006 .34249 .61047 .33824 .60545 .33206 Metetra
.697 .754 .896 r
.60545 .33206 .61047 .33824 .62037 .33396 .61537 .32776 Metetra
.697 .754 .896 r
.61537 .32776 .62037 .33396 .6303 .32968 .62533 .32346 Metetra
.707 .757 .891 r
.62533 .32346 .6303 .32968 .64025 .32508 .6353 .31884 Metetra
.727 .763 .882 r
.6353 .31884 .64025 .32508 .65019 .31984 .64528 .31357 Metetra
.706 .757 .892 r
.64528 .31357 .65019 .31984 .6602 .31527 .6553 .30897 Metetra
.644 .735 .915 r
.6553 .30897 .6602 .31527 .6703 .31233 .66544 .30601 Metetra
.682 .749 .902 r
.66544 .30601 .6703 .31233 .6804 .30841 .67556 .30207 Metetra
.764 .774 .861 r
.67556 .30207 .6804 .30841 .69039 .30172 .68558 .29536 Metetra
.745 .769 .872 r
.68558 .29536 .69039 .30172 .70043 .29576 .69565 .28937 Metetra
.664 .741 .908 r
.69565 .28937 .70043 .29576 .71064 .2923 .70588 .28589 Metetra
.664 .741 .908 r
.70588 .28589 .71064 .2923 .72089 .28883 .71616 .28239 Metetra
.664 .741 .908 r
.71616 .28239 .72089 .28883 .73118 .28535 .72647 .27888 Metetra
.664 .741 .908 r
.72647 .27888 .73118 .28535 .7415 .28185 .73682 .27537 Metetra
.664 .741 .908 r
.73682 .27537 .7415 .28185 .75186 .27834 .7472 .27183 Metetra
.664 .741 .908 r
.7472 .27183 .75186 .27834 .76226 .27482 .75763 .26829 Metetra
.664 .741 .908 r
.75763 .26829 .76226 .27482 .77269 .27129 .76809 .26473 Metetra
.664 .741 .908 r
.76809 .26473 .77269 .27129 .78317 .26774 .77859 .26116 Metetra
.664 .741 .908 r
.77859 .26116 .78317 .26774 .79368 .26418 .78913 .25758 Metetra
.664 .741 .908 r
.78913 .25758 .79368 .26418 .80423 .26061 .79971 .25398 Metetra
.664 .741 .908 r
.79971 .25398 .80423 .26061 .81482 .25702 .81032 .25037 Metetra
.664 .741 .908 r
.81032 .25037 .81482 .25702 .82545 .25342 .82098 .24674 Metetra
.664 .741 .908 r
.82098 .24674 .82545 .25342 .83611 .24981 .83168 .24311 Metetra
.664 .741 .908 r
.83168 .24311 .83611 .24981 .84682 .24619 .84241 .23946 Metetra
.664 .741 .908 r
.22972 .44039 .23555 .44583 .2442 .44289 .23838 .43744 Metetra
.664 .741 .908 r
.23838 .43744 .2442 .44289 .25287 .43994 .24707 .43447 Metetra
.664 .741 .908 r
.24707 .43447 .25287 .43994 .26157 .43698 .25578 .43149 Metetra
.664 .741 .908 r
.25578 .43149 .26157 .43698 .2703 .43401 .26453 .42851 Metetra
.664 .741 .908 r
.26453 .42851 .2703 .43401 .27905 .43103 .2733 .42551 Metetra
.664 .741 .908 r
.2733 .42551 .27905 .43103 .28784 .42805 .28211 .4225 Metetra
.664 .741 .908 r
.28211 .4225 .28784 .42805 .29666 .42505 .29094 .41949 Metetra
.664 .741 .908 r
.29094 .41949 .29666 .42505 .3055 .42204 .29981 .41646 Metetra
.664 .741 .908 r
.29981 .41646 .3055 .42204 .31438 .41902 .3087 .41342 Metetra
.664 .741 .908 r
.3087 .41342 .31438 .41902 .32328 .41599 .31762 .41037 Metetra
.664 .741 .908 r
.31762 .41037 .32328 .41599 .33222 .41295 .32658 .40732 Metetra
.664 .741 .908 r
.32658 .40732 .33222 .41295 .34119 .4099 .33556 .40425 Metetra
.656 .739 .911 r
.33556 .40425 .34119 .4099 .35018 .40685 .34457 .40134 Metetra
.654 .745 .917 r
.34457 .40134 .35018 .40685 .35921 .40378 .3536 .39847 Metetra
.537 .714 .954 r
.3536 .39847 .35921 .40378 .36815 .40316 .36257 .39764 Metetra
.498 .689 .953 r
.36257 .39764 .36815 .40316 .3771 .40326 .37154 .3974 Metetra
.642 .731 .913 r
.37154 .3974 .3771 .40326 .38621 .40065 .38068 .39476 Metetra
.677 .741 .899 r
.38068 .39476 .38621 .40065 .3954 .39708 .38988 .39129 Metetra
.612 .724 .925 r
.38988 .39129 .3954 .39708 .40455 .39513 .39905 .38927 Metetra
.58 .711 .932 r
.39905 .38927 .40455 .39513 .41372 .39383 .40824 .38785 Metetra
.613 .719 .921 r
.40824 .38785 .41372 .39383 .42295 .39191 .41749 .38579 Metetra
.628 .72 .913 r
.41749 .38579 .42295 .39191 .43223 .38968 .42679 .38344 Metetra
.612 .71 .915 r
.42679 .38344 .43223 .38968 .44154 .38744 .43612 .38142 Metetra
.601 .715 .925 r
.43612 .38142 .44154 .38744 .4509 .3852 .44548 .3796 Metetra
.481 .683 .955 r
.44548 .3796 .4509 .3852 .46024 .38549 .45484 .37957 Metetra
.4 .631 .948 r
.45484 .37957 .46024 .38549 .4696 .3874 .46423 .38069 Metetra
.199 .485 .897 r
.46423 .38069 .4696 .3874 .47899 .39202 .47364 .38446 Metetra
.07 .371 .838 r
.47364 .38446 .47899 .39202 .48844 .39866 .4831 .39018 Metetra
.932 .561 .168 r
.4831 .39018 .48844 .39866 .49764 .44527 .49234 .42625 Metetra
.939 .625 .176 r
.49234 .42625 .49764 .44527 .50698 .52823 .50166 .48939 Metetra
.083 .065 .537 r
.50166 .48939 .50698 .52823 .51698 .56849 .51155 .51935 Metetra
.574 .4 .608 r
.51155 .51935 .51698 .56849 .52724 .56541 .5217 .5162 Metetra
.737 .518 .595 r
.5217 .5162 .52724 .56541 .53738 .51886 .53183 .47987 Metetra
.843 .602 .573 r
.53183 .47987 .53738 .51886 .54701 .42928 .54162 .41011 Metetra
.871 .651 .602 r
.54162 .41011 .54701 .42928 .55649 .376 .55125 .36736 Metetra
.822 .721 .754 r
.55125 .36736 .55649 .376 .56622 .36282 .56103 .35506 Metetra
.81 .737 .783 r
.56103 .35506 .56622 .36282 .57596 .35164 .57081 .3447 Metetra
.778 .751 .829 r
.57081 .3447 .57596 .35164 .58574 .34318 .58063 .33699 Metetra
.762 .771 .86 r
.58063 .33699 .58574 .34318 .59555 .33634 .59048 .33043 Metetra
.713 .769 .896 r
.59048 .33043 .59555 .33634 .60545 .33206 .60039 .32568 Metetra
.704 .751 .888 r
.60039 .32568 .60545 .33206 .61537 .32776 .61033 .32111 Metetra
.691 .738 .887 r
.61033 .32111 .61537 .32776 .62533 .32346 .62031 .31689 Metetra
.702 .745 .885 r
.62031 .31689 .62533 .32346 .6353 .31884 .63032 .31236 Metetra
.722 .755 .879 r
.63032 .31236 .6353 .31884 .64528 .31357 .64032 .30718 Metetra
.704 .753 .891 r
.64032 .30718 .64528 .31357 .6553 .30897 .65038 .3026 Metetra
.649 .735 .912 r
.65038 .3026 .6553 .30897 .66544 .30601 .66053 .29951 Metetra
.681 .743 .898 r
.66053 .29951 .66544 .30601 .67556 .30207 .67068 .29555 Metetra
.755 .767 .863 r
.67068 .29555 .67556 .30207 .68558 .29536 .68074 .28914 Metetra
.741 .774 .88 r
.68074 .28914 .68558 .29536 .69565 .28937 .69085 .28333 Metetra
.672 .759 .916 r
.69085 .28333 .69565 .28937 .70588 .28589 .7011 .2796 Metetra
.671 .75 .91 r
.7011 .2796 .70588 .28589 .71616 .28239 .71139 .27591 Metetra
.664 .741 .908 r
.71139 .27591 .71616 .28239 .72647 .27888 .72173 .27238 Metetra
.664 .741 .908 r
.72173 .27238 .72647 .27888 .73682 .27537 .7321 .26883 Metetra
.664 .741 .908 r
.7321 .26883 .73682 .27537 .7472 .27183 .74252 .26528 Metetra
.664 .741 .908 r
.74252 .26528 .7472 .27183 .75763 .26829 .75297 .26171 Metetra
.664 .741 .908 r
.75297 .26171 .75763 .26829 .76809 .26473 .76346 .25813 Metetra
.664 .741 .908 r
.76346 .25813 .76809 .26473 .77859 .26116 .77399 .25453 Metetra
.664 .741 .908 r
.77399 .25453 .77859 .26116 .78913 .25758 .78455 .25092 Metetra
.664 .741 .908 r
.78455 .25092 .78913 .25758 .79971 .25398 .79516 .2473 Metetra
.664 .741 .908 r
.79516 .2473 .79971 .25398 .81032 .25037 .8058 .24367 Metetra
.664 .741 .908 r
.8058 .24367 .81032 .25037 .82098 .24674 .81649 .24002 Metetra
.664 .741 .908 r
.81649 .24002 .82098 .24674 .83168 .24311 .82721 .23636 Metetra
.664 .741 .908 r
.82721 .23636 .83168 .24311 .84241 .23946 .83797 .23268 Metetra
.664 .741 .908 r
.22385 .43493 .22972 .44039 .23838 .43744 .23252 .43195 Metetra
.664 .741 .908 r
.23252 .43195 .23838 .43744 .24707 .43447 .24123 .42897 Metetra
.664 .741 .908 r
.24123 .42897 .24707 .43447 .25578 .43149 .24996 .42597 Metetra
.664 .741 .908 r
.24996 .42597 .25578 .43149 .26453 .42851 .25873 .42297 Metetra
.664 .741 .908 r
.25873 .42297 .26453 .42851 .2733 .42551 .26752 .41995 Metetra
.664 .741 .908 r
.26752 .41995 .2733 .42551 .28211 .4225 .27634 .41693 Metetra
.664 .741 .908 r
.27634 .41693 .28211 .4225 .29094 .41949 .28519 .41389 Metetra
.664 .741 .908 r
.28519 .41389 .29094 .41949 .29981 .41646 .29407 .41084 Metetra
.664 .741 .908 r
.29407 .41084 .29981 .41646 .3087 .41342 .30299 .40779 Metetra
.664 .741 .908 r
.30299 .40779 .3087 .41342 .31762 .41037 .31193 .40472 Metetra
.664 .741 .908 r
.31193 .40472 .31762 .41037 .32658 .40732 .3209 .40164 Metetra
.664 .741 .908 r
.3209 .40164 .32658 .40732 .33556 .40425 .3299 .39856 Metetra
.64 .734 .917 r
.3299 .39856 .33556 .40425 .34457 .40134 .33891 .39599 Metetra
.632 .746 .93 r
.33891 .39599 .34457 .40134 .3536 .39847 .34794 .39355 Metetra
.557 .739 .961 r
.34794 .39355 .3536 .39847 .36257 .39764 .35694 .39228 Metetra
.542 .716 .953 r
.35694 .39228 .36257 .39764 .37154 .3974 .36596 .39135 Metetra
.643 .725 .908 r
.36596 .39135 .37154 .3974 .38068 .39476 .37512 .38869 Metetra
.668 .733 .899 r
.37512 .38869 .38068 .39476 .38988 .39129 .38433 .38542 Metetra
.617 .725 .923 r
.38433 .38542 .38988 .39129 .39905 .38927 .39352 .38329 Metetra
.593 .713 .927 r
.39352 .38329 .39905 .38927 .40824 .38785 .40274 .38162 Metetra
.625 .716 .912 r
.40274 .38162 .40824 .38785 .41749 .38579 .41201 .37932 Metetra
.638 .713 .901 r
.41201 .37932 .41749 .38579 .42679 .38344 .42134 .37672 Metetra
.59 .687 .909 r
.42134 .37672 .42679 .38344 .43612 .38142 .43066 .37519 Metetra
.553 .69 .93 r
.43066 .37519 .43612 .38142 .44548 .3796 .44002 .37426 Metetra
.518 .712 .96 r
.44002 .37426 .44548 .3796 .45484 .37957 .44941 .37359 Metetra
.52 .687 .943 r
.44941 .37359 .45484 .37957 .46423 .38069 .45885 .3731 Metetra
.389 .563 .904 r
.45885 .3731 .46423 .38069 .47364 .38446 .46829 .37511 Metetra
.321 .47 .853 r
.46829 .37511 .47364 .38446 .4831 .39018 .47777 .37895 Metetra
0 0 .537 r
.47777 .37895 .4831 .39018 .49234 .42625 .4872 .39346 Metetra
.116 .102 .564 r
.4872 .39346 .49234 .42625 .50166 .48939 .4967 .4171 Metetra
.489 .318 .575 r
.4967 .4171 .50166 .48939 .51155 .51935 .50647 .42704 Metetra
.559 .363 .571 r
.50647 .42704 .51155 .51935 .5217 .5162 .51639 .4238 Metetra
.608 .399 .573 r
.51639 .4238 .5217 .5162 .53183 .47987 .52634 .40735 Metetra
.673 .455 .582 r
.52634 .40735 .53183 .47987 .54162 .41011 .53619 .3771 Metetra
.723 .525 .623 r
.53619 .3771 .54162 .41011 .55125 .36736 .54597 .35595 Metetra
.769 .661 .743 r
.54597 .35595 .55125 .36736 .56103 .35506 .55579 .34549 Metetra
.763 .688 .779 r
.55579 .34549 .56103 .35506 .57081 .3447 .56562 .33685 Metetra
.735 .716 .834 r
.56562 .33685 .57081 .3447 .58063 .33699 .57549 .33073 Metetra
.746 .766 .869 r
.57549 .33073 .58063 .33699 .59048 .33043 .58538 .32477 Metetra
.744 .787 .888 r
.58538 .32477 .59048 .33043 .60039 .32568 .59529 .31908 Metetra
.719 .749 .876 r
.59529 .31908 .60039 .32568 .61033 .32111 .60525 .31398 Metetra
.682 .721 .879 r
.60525 .31398 .61033 .32111 .62031 .31689 .61526 .30996 Metetra
.693 .732 .881 r
.61526 .30996 .62031 .31689 .63032 .31236 .62529 .30563 Metetra
.714 .746 .877 r
.62529 .30563 .63032 .31236 .64032 .30718 .63533 .30066 Metetra
.7 .749 .89 r
.63533 .30066 .64032 .30718 .65038 .3026 .64542 .29615 Metetra
.658 .738 .908 r
.64542 .29615 .65038 .3026 .66053 .29951 .65558 .29281 Metetra
.68 .738 .894 r
.65558 .29281 .66053 .29951 .67068 .29555 .66576 .28883 Metetra
.735 .757 .87 r
.66576 .28883 .67068 .29555 .68074 .28914 .67588 .28309 Metetra
.73 .778 .891 r
.67588 .28309 .68074 .28914 .69085 .28333 .68604 .27768 Metetra
.69 .782 .921 r
.68604 .27768 .69085 .28333 .7011 .2796 .6963 .27347 Metetra
.685 .763 .911 r
.6963 .27347 .7011 .2796 .71139 .27591 .70659 .26938 Metetra
.664 .741 .908 r
.70659 .26938 .71139 .27591 .72173 .27238 .71696 .26583 Metetra
.664 .741 .908 r
.71696 .26583 .72173 .27238 .7321 .26883 .72736 .26226 Metetra
.664 .741 .908 r
.72736 .26226 .7321 .26883 .74252 .26528 .7378 .25868 Metetra
.664 .741 .908 r
.7378 .25868 .74252 .26528 .75297 .26171 .74828 .25509 Metetra
.664 .741 .908 r
.74828 .25509 .75297 .26171 .76346 .25813 .75879 .25148 Metetra
.664 .741 .908 r
.75879 .25148 .76346 .25813 .77399 .25453 .76935 .24786 Metetra
.664 .741 .908 r
.76935 .24786 .77399 .25453 .78455 .25092 .77994 .24423 Metetra
.664 .741 .908 r
.77994 .24423 .78455 .25092 .79516 .2473 .79057 .24058 Metetra
.664 .741 .908 r
.79057 .24058 .79516 .2473 .8058 .24367 .80125 .23692 Metetra
.664 .741 .908 r
.80125 .23692 .8058 .24367 .81649 .24002 .81196 .23325 Metetra
.664 .741 .908 r
.81196 .23325 .81649 .24002 .82721 .23636 .82271 .22956 Metetra
.664 .741 .908 r
.82271 .22956 .82721 .23636 .83797 .23268 .8335 .22586 Metetra
.664 .741 .908 r
.21794 .42943 .22385 .43493 .23252 .43195 .22663 .42643 Metetra
.664 .741 .908 r
.22663 .42643 .23252 .43195 .24123 .42897 .23535 .42343 Metetra
.664 .741 .908 r
.23535 .42343 .24123 .42897 .24996 .42597 .24411 .42042 Metetra
.664 .741 .908 r
.24411 .42042 .24996 .42597 .25873 .42297 .25289 .41739 Metetra
.664 .741 .908 r
.25289 .41739 .25873 .42297 .26752 .41995 .2617 .41436 Metetra
.664 .741 .908 r
.2617 .41436 .26752 .41995 .27634 .41693 .27054 .41131 Metetra
.664 .741 .908 r
.27054 .41131 .27634 .41693 .28519 .41389 .27941 .40826 Metetra
.664 .741 .908 r
.27941 .40826 .28519 .41389 .29407 .41084 .28831 .40519 Metetra
.664 .741 .908 r
.28831 .40519 .29407 .41084 .30299 .40779 .29724 .40212 Metetra
.664 .741 .908 r
.29724 .40212 .30299 .40779 .31193 .40472 .3062 .39903 Metetra
.664 .741 .908 r
.3062 .39903 .31193 .40472 .3209 .40164 .31519 .39594 Metetra
.664 .741 .908 r
.31519 .39594 .3209 .40164 .3299 .39856 .32421 .39283 Metetra
.627 .73 .922 r
.32421 .39283 .3299 .39856 .33891 .39599 .33321 .39053 Metetra
.615 .737 .933 r
.33321 .39053 .33891 .39599 .34794 .39355 .34224 .38841 Metetra
.584 .741 .951 r
.34224 .38841 .34794 .39355 .35694 .39228 .35128 .38676 Metetra
.581 .725 .942 r
.35128 .38676 .35694 .39228 .36596 .39135 .36035 .38524 Metetra
.639 .723 .909 r
.36035 .38524 .36596 .39135 .37512 .38869 .36952 .38266 Metetra
.655 .732 .906 r
.36952 .38266 .37512 .38869 .38433 .38542 .37873 .37969 Metetra
.626 .734 .925 r
.37873 .37969 .38433 .38542 .39352 .38329 .38795 .37733 Metetra
.615 .723 .923 r
.38795 .37733 .39352 .38329 .40274 .38162 .3972 .37522 Metetra
.632 .713 .905 r
.3972 .37522 .40274 .38162 .41201 .37932 .4065 .37275 Metetra
.639 .711 .899 r
.4065 .37275 .41201 .37932 .42134 .37672 .41584 .3701 Metetra
.583 .689 .914 r
.41584 .3701 .42134 .37672 .43066 .37519 .42518 .36867 Metetra
.545 .677 .925 r
.42518 .36867 .43066 .37519 .44002 .37426 .43455 .3679 Metetra
.564 .692 .926 r
.43455 .3679 .44002 .37426 .44941 .37359 .44397 .36676 Metetra
.581 .683 .91 r
.44397 .36676 .44941 .37359 .45885 .3731 .45344 .36536 Metetra
.489 .611 .9 r
.45344 .36536 .45885 .3731 .46829 .37511 .46292 .36586 Metetra
.438 .54 .864 r
.46292 .36586 .46829 .37511 .47777 .37895 .47243 .36773 Metetra
.464 .51 .82 r
.47243 .36773 .47777 .37895 .4872 .39346 .48201 .36967 Metetra
.517 .415 .678 r
.48201 .36967 .4872 .39346 .4967 .4171 .49165 .37167 Metetra
.555 .387 .609 r
.49165 .37167 .4967 .4171 .50647 .42704 .50137 .37094 Metetra
.569 .387 .595 r
.50137 .37094 .50647 .42704 .51639 .4238 .51116 .36764 Metetra
.585 .399 .595 r
.51116 .36764 .51639 .4238 .52634 .40735 .52099 .36176 Metetra
.614 .429 .609 r
.52099 .36176 .52634 .40735 .53619 .3771 .53083 .35313 Metetra
.664 .511 .666 r
.53083 .35313 .53619 .3771 .54597 .35595 .54068 .34455 Metetra
.743 .65 .758 r
.54068 .34455 .54597 .35595 .55579 .34549 .55053 .33602 Metetra
.739 .682 .795 r
.55053 .33602 .55579 .34549 .56562 .33685 .56039 .32887 Metetra
.712 .706 .843 r
.56039 .32887 .56562 .33685 .57549 .33073 .5703 .32361 Metetra
.726 .735 .858 r
.5703 .32361 .57549 .33073 .58538 .32477 .58022 .31809 Metetra
.741 .754 .863 r
.58022 .31809 .58538 .32477 .59529 .31908 .59016 .31218 Metetra
.72 .742 .869 r
.59016 .31218 .59529 .31908 .60525 .31398 .60014 .30694 Metetra
.681 .725 .883 r
.60014 .30694 .60525 .31398 .61526 .30996 .61017 .30292 Metetra
.687 .728 .881 r
.61017 .30292 .61526 .30996 .62529 .30563 .62023 .29872 Metetra
.699 .737 .88 r
.62023 .29872 .62529 .30563 .63533 .30066 .63031 .29416 Metetra
.693 .749 .895 r
.63031 .29416 .63533 .30066 .64542 .29615 .64043 .28985 Metetra
.671 .749 .909 r
.64043 .28985 .64542 .29615 .65558 .29281 .65061 .28614 Metetra
.684 .742 .895 r
.65061 .28614 .65558 .29281 .66576 .28883 .6608 .28205 Metetra
.718 .751 .878 r
.6608 .28205 .66576 .28883 .67588 .28309 .67098 .27686 Metetra
.718 .77 .894 r
.67098 .27686 .67588 .28309 .68604 .27768 .68119 .2718 Metetra
.703 .779 .91 r
.68119 .2718 .68604 .27768 .6963 .27347 .69146 .26721 Metetra
.695 .763 .904 r
.69146 .26721 .6963 .27347 .70659 .26938 .70176 .26281 Metetra
.664 .741 .908 r
.70176 .26281 .70659 .26938 .71696 .26583 .71215 .25923 Metetra
.664 .741 .908 r
.71215 .25923 .71696 .26583 .72736 .26226 .72258 .25564 Metetra
.664 .741 .908 r
.72258 .25564 .72736 .26226 .7378 .25868 .73305 .25204 Metetra
.664 .741 .908 r
.73305 .25204 .7378 .25868 .74828 .25509 .74355 .24842 Metetra
.664 .741 .908 r
.74355 .24842 .74828 .25509 .75879 .25148 .7541 .24479 Metetra
.664 .741 .908 r
.7541 .24479 .75879 .25148 .76935 .24786 .76468 .24114 Metetra
.664 .741 .908 r
.76468 .24114 .76935 .24786 .77994 .24423 .7753 .23749 Metetra
.664 .741 .908 r
.7753 .23749 .77994 .24423 .79057 .24058 .78596 .23381 Metetra
.664 .741 .908 r
.78596 .23381 .79057 .24058 .80125 .23692 .79666 .23013 Metetra
.664 .741 .908 r
.79666 .23013 .80125 .23692 .81196 .23325 .8074 .22643 Metetra
.664 .741 .908 r
.8074 .22643 .81196 .23325 .82271 .22956 .81818 .22272 Metetra
.664 .741 .908 r
.81818 .22272 .82271 .22956 .8335 .22586 .829 .21899 Metetra
.664 .741 .908 r
.212 .42389 .21794 .42943 .22663 .42643 .22071 .42088 Metetra
.664 .741 .908 r
.22071 .42088 .22663 .42643 .23535 .42343 .22944 .41786 Metetra
.664 .741 .908 r
.22944 .41786 .23535 .42343 .24411 .42042 .23821 .41482 Metetra
.664 .741 .908 r
.23821 .41482 .24411 .42042 .25289 .41739 .24701 .41178 Metetra
.664 .741 .908 r
.24701 .41178 .25289 .41739 .2617 .41436 .25584 .40873 Metetra
.664 .741 .908 r
.25584 .40873 .2617 .41436 .27054 .41131 .2647 .40567 Metetra
.664 .741 .908 r
.2647 .40567 .27054 .41131 .27941 .40826 .27358 .40259 Metetra
.664 .741 .908 r
.27358 .40259 .27941 .40826 .28831 .40519 .2825 .39951 Metetra
.664 .741 .908 r
.2825 .39951 .28831 .40519 .29724 .40212 .29145 .39641 Metetra
.664 .741 .908 r
.29145 .39641 .29724 .40212 .3062 .39903 .30043 .39331 Metetra
.664 .741 .908 r
.30043 .39331 .3062 .39903 .31519 .39594 .30944 .39019 Metetra
.664 .741 .908 r
.30944 .39019 .31519 .39594 .32421 .39283 .31848 .38707 Metetra
.617 .727 .925 r
.31848 .38707 .32421 .39283 .33321 .39053 .32749 .38493 Metetra
.604 .73 .934 r
.32749 .38493 .33321 .39053 .34224 .38841 .33652 .38302 Metetra
.604 .739 .94 r
.33652 .38302 .34224 .38841 .35128 .38676 .34559 .38105 Metetra
.608 .728 .931 r
.34559 .38105 .35128 .38676 .36035 .38524 .35471 .37906 Metetra
.629 .719 .912 r
.35471 .37906 .36035 .38524 .36952 .38266 .36388 .37668 Metetra
.635 .729 .916 r
.36388 .37668 .36952 .38266 .37873 .37969 .37309 .37415 Metetra
.642 .748 .926 r
.37309 .37415 .37873 .37969 .38795 .37733 .38235 .37142 Metetra
.646 .736 .914 r
.38235 .37142 .38795 .37733 .3972 .37522 .39164 .3686 Metetra
.635 .709 .9 r
.39164 .3686 .3972 .37522 .4065 .37275 .40096 .36605 Metetra
.63 .704 .9 r
.40096 .36605 .4065 .37275 .41584 .3701 .41031 .3636 Metetra
.6 .701 .914 r
.41031 .3636 .41584 .3701 .42518 .36867 .41968 .36179 Metetra
.585 .683 .908 r
.41968 .36179 .42518 .36867 .43455 .3679 .42908 .36033 Metetra
.586 .661 .89 r
.42908 .36033 .43455 .3679 .44397 .36676 .43852 .35889 Metetra
.586 .653 .883 r
.43852 .35889 .44397 .36676 .45344 .36536 .448 .35748 Metetra
.554 .639 .889 r
.448 .35748 .45344 .36536 .46292 .36586 .45751 .35675 Metetra
.539 .598 .861 r
.45751 .35675 .46292 .36586 .47243 .36773 .46707 .35653 Metetra
.542 .554 .816 r
.46707 .35653 .47243 .36773 .48201 .36967 .47667 .35648 Metetra
.543 .521 .782 r
.47667 .35648 .48201 .36967 .49165 .37167 .48633 .35659 Metetra
.59 .525 .75 r
.48633 .35659 .49165 .37167 .50137 .37094 .49605 .35493 Metetra
.623 .535 .734 r
.49605 .35493 .50137 .37094 .51116 .36764 .50583 .3516 Metetra
.653 .552 .728 r
.50583 .3516 .51116 .36764 .52099 .36176 .51566 .34659 Metetra
.686 .579 .729 r
.51566 .34659 .52099 .36176 .53083 .35313 .5255 .33981 Metetra
.696 .604 .749 r
.5255 .33981 .53083 .35313 .54068 .34455 .53536 .33317 Metetra
.709 .636 .774 r
.53536 .33317 .54068 .34455 .55053 .33602 .54524 .3267 Metetra
.717 .677 .81 r
.54524 .3267 .55053 .33602 .56039 .32887 .55514 .32073 Metetra
.711 .703 .84 r
.55514 .32073 .56039 .32887 .5703 .32361 .56506 .31544 Metetra
.711 .703 .841 r
.56506 .31544 .5703 .32361 .58022 .31809 .57501 .31017 Metetra
.712 .71 .847 r
.57501 .31017 .58022 .31809 .59016 .31218 .58499 .30492 Metetra
.708 .728 .866 r
.58499 .30492 .59016 .31218 .60014 .30694 .595 .30002 Metetra
.69 .733 .884 r
.595 .30002 .60014 .30694 .61017 .30292 .60505 .29575 Metetra
.684 .724 .88 r
.60505 .29575 .61017 .30292 .62023 .29872 .61513 .2916 Metetra
.676 .723 .885 r
.61513 .2916 .62023 .29872 .63031 .29416 .62526 .2877 Metetra
.681 .748 .902 r
.62526 .2877 .63031 .29416 .64043 .28985 .63542 .28371 Metetra
.689 .763 .908 r
.63542 .28371 .64043 .28985 .65061 .28614 .64561 .27953 Metetra
.692 .748 .894 r
.64561 .27953 .65061 .28614 .6608 .28205 .65582 .27518 Metetra
.704 .745 .883 r
.65582 .27518 .6608 .28205 .67098 .27686 .66604 .27043 Metetra
.707 .761 .894 r
.66604 .27043 .67098 .27686 .68119 .2718 .6763 .26565 Metetra
.71 .773 .901 r
.6763 .26565 .68119 .2718 .69146 .26721 .68658 .26081 Metetra
.701 .762 .899 r
.68658 .26081 .69146 .26721 .70176 .26281 .6969 .25619 Metetra
.664 .741 .908 r
.6969 .25619 .70176 .26281 .71215 .25923 .70732 .25259 Metetra
.664 .741 .908 r
.70732 .25259 .71215 .25923 .72258 .25564 .71777 .24898 Metetra
.664 .741 .908 r
.71777 .24898 .72258 .25564 .73305 .25204 .72827 .24535 Metetra
.664 .741 .908 r
.72827 .24535 .73305 .25204 .74355 .24842 .7388 .24171 Metetra
.664 .741 .908 r
.7388 .24171 .74355 .24842 .7541 .24479 .74937 .23805 Metetra
.664 .741 .908 r
.74937 .23805 .7541 .24479 .76468 .24114 .75998 .23438 Metetra
.664 .741 .908 r
.75998 .23438 .76468 .24114 .7753 .23749 .77063 .2307 Metetra
.664 .741 .908 r
.77063 .2307 .7753 .23749 .78596 .23381 .78132 .227 Metetra
.664 .741 .908 r
.78132 .227 .78596 .23381 .79666 .23013 .79204 .22329 Metetra
.664 .741 .908 r
.79204 .22329 .79666 .23013 .8074 .22643 .80281 .21957 Metetra
.664 .741 .908 r
.80281 .21957 .8074 .22643 .81818 .22272 .81362 .21583 Metetra
.664 .741 .908 r
.81362 .21583 .81818 .22272 .829 .21899 .82447 .21208 Metetra
.664 .741 .908 r
.20602 .41832 .212 .42389 .22071 .42088 .21474 .41529 Metetra
.664 .741 .908 r
.21474 .41529 .22071 .42088 .22944 .41786 .2235 .41225 Metetra
.664 .741 .908 r
.2235 .41225 .22944 .41786 .23821 .41482 .23228 .4092 Metetra
.664 .741 .908 r
.23228 .4092 .23821 .41482 .24701 .41178 .2411 .40614 Metetra
.664 .741 .908 r
.2411 .40614 .24701 .41178 .25584 .40873 .24994 .40307 Metetra
.664 .741 .908 r
.24994 .40307 .25584 .40873 .2647 .40567 .25882 .39998 Metetra
.664 .741 .908 r
.25882 .39998 .2647 .40567 .27358 .40259 .26773 .39689 Metetra
.664 .741 .908 r
.26773 .39689 .27358 .40259 .2825 .39951 .27666 .39379 Metetra
.664 .741 .908 r
.27666 .39379 .2825 .39951 .29145 .39641 .28563 .39067 Metetra
.664 .741 .908 r
.28563 .39067 .29145 .39641 .30043 .39331 .29463 .38755 Metetra
.66 .74 .909 r
.29463 .38755 .30043 .39331 .30944 .39019 .30365 .38449 Metetra
.66 .743 .912 r
.30365 .38449 .30944 .39019 .31848 .38707 .3127 .38144 Metetra
.61 .732 .932 r
.3127 .38144 .31848 .38707 .32749 .38493 .32172 .37941 Metetra
.595 .731 .939 r
.32172 .37941 .32749 .38493 .33652 .38302 .33076 .37761 Metetra
.618 .744 .936 r
.33076 .37761 .33652 .38302 .34559 .38105 .33987 .37538 Metetra
.626 .737 .927 r
.33987 .37538 .34559 .38105 .35471 .37906 .34902 .37302 Metetra
.627 .724 .917 r
.34902 .37302 .35471 .37906 .36388 .37668 .3582 .37064 Metetra
.627 .725 .918 r
.3582 .37064 .36388 .37668 .37309 .37415 .36743 .36826 Metetra
.65 .739 .914 r
.36743 .36826 .37309 .37415 .38235 .37142 .37671 .36535 Metetra
.659 .736 .906 r
.37671 .36535 .38235 .37142 .39164 .3686 .38604 .36221 Metetra
.635 .718 .907 r
.38604 .36221 .39164 .3686 .40096 .36605 .39537 .35963 Metetra
.623 .713 .91 r
.39537 .35963 .40096 .36605 .41031 .3636 .40474 .3573 Metetra
.621 .717 .915 r
.40474 .3573 .41031 .3636 .41968 .36179 .41414 .35501 Metetra
.621 .701 .902 r
.41414 .35501 .41968 .36179 .42908 .36033 .42358 .35274 Metetra
.6 .668 .887 r
.42358 .35274 .42908 .36033 .43852 .35889 .43304 .35099 Metetra
.586 .653 .883 r
.43304 .35099 .43852 .35889 .448 .35748 .44253 .34955 Metetra
.586 .653 .883 r
.44253 .34955 .448 .35748 .45751 .35675 .45208 .34811 Metetra
.588 .634 .865 r
.45208 .34811 .45751 .35675 .46707 .35653 .46166 .34666 Metetra
.593 .608 .836 r
.46166 .34666 .46707 .35653 .47667 .35648 .47129 .34509 Metetra
.595 .579 .805 r
.47129 .34509 .47667 .35648 .48633 .35659 .48097 .34341 Metetra
.615 .562 .772 r
.48097 .34341 .48633 .35659 .49605 .35493 .49071 .34087 Metetra
.63 .56 .757 r
.49071 .34087 .49605 .35493 .50583 .3516 .50049 .33751 Metetra
.647 .569 .753 r
.50049 .33751 .50583 .3516 .51566 .34659 .51031 .33334 Metetra
.668 .59 .759 r
.51031 .33334 .51566 .34659 .5255 .33981 .52016 .32828 Metetra
.682 .622 .782 r
.52016 .32828 .5255 .33981 .53536 .33317 .53003 .32313 Metetra
.696 .654 .805 r
.53003 .32313 .53536 .33317 .54524 .3267 .53993 .31784 Metetra
.705 .684 .827 r
.53993 .31784 .54524 .3267 .55514 .32073 .54986 .31254 Metetra
.711 .703 .84 r
.54986 .31254 .55514 .32073 .56506 .31544 .5598 .30723 Metetra
.703 .7 .844 r
.5598 .30723 .56506 .31544 .57501 .31017 .56978 .30224 Metetra
.69 .703 .857 r
.56978 .30224 .57501 .31017 .58499 .30492 .57979 .29775 Metetra
.695 .728 .876 r
.57979 .29775 .58499 .30492 .595 .30002 .58983 .29329 Metetra
.695 .742 .888 r
.58983 .29329 .595 .30002 .60505 .29575 .5999 .28886 Metetra
.686 .735 .888 r
.5999 .28886 .60505 .29575 .61513 .2916 .61001 .28469 Metetra
.666 .728 .896 r
.61001 .28469 .61513 .2916 .62526 .2877 .62017 .28108 Metetra
.675 .741 .901 r
.62017 .28108 .62526 .2877 .63542 .28371 .63036 .27723 Metetra
.694 .754 .898 r
.63036 .27723 .63542 .28371 .64561 .27953 .64057 .27285 Metetra
.693 .748 .893 r
.64057 .27285 .64561 .27953 .65582 .27518 .6508 .26845 Metetra
.693 .746 .893 r
.6508 .26845 .65582 .27518 .66604 .27043 .66107 .26404 Metetra
.699 .761 .9 r
.66107 .26404 .66604 .27043 .6763 .26565 .67137 .25948 Metetra
.715 .775 .9 r
.67137 .25948 .6763 .26565 .68658 .26081 .68167 .25448 Metetra
.706 .767 .9 r
.68167 .25448 .68658 .26081 .6969 .25619 .69202 .24971 Metetra
.667 .749 .911 r
.69202 .24971 .6969 .25619 .70732 .25259 .70245 .24599 Metetra
.667 .745 .909 r
.70245 .24599 .70732 .25259 .71777 .24898 .71293 .24227 Metetra
.664 .741 .908 r
.71293 .24227 .71777 .24898 .72827 .24535 .72345 .23861 Metetra
.664 .741 .908 r
.72345 .23861 .72827 .24535 .7388 .24171 .73401 .23495 Metetra
.664 .741 .908 r
.73401 .23495 .7388 .24171 .74937 .23805 .74461 .23126 Metetra
.664 .741 .908 r
.74461 .23126 .74937 .23805 .75998 .23438 .75524 .22757 Metetra
.664 .741 .908 r
.75524 .22757 .75998 .23438 .77063 .2307 .76592 .22386 Metetra
.664 .741 .908 r
.76592 .22386 .77063 .2307 .78132 .227 .77664 .22014 Metetra
.664 .741 .908 r
.77664 .22014 .78132 .227 .79204 .22329 .78739 .2164 Metetra
.664 .741 .908 r
.78739 .2164 .79204 .22329 .80281 .21957 .79819 .21265 Metetra
.664 .741 .908 r
.79819 .21265 .80281 .21957 .81362 .21583 .80903 .20889 Metetra
.664 .741 .908 r
.80903 .20889 .81362 .21583 .82447 .21208 .81991 .20511 Metetra
.664 .741 .908 r
.2 .41272 .20602 .41832 .21474 .41529 .20874 .40967 Metetra
.664 .741 .908 r
.20874 .40967 .21474 .41529 .2235 .41225 .21751 .40661 Metetra
.664 .741 .908 r
.21751 .40661 .2235 .41225 .23228 .4092 .22632 .40354 Metetra
.664 .741 .908 r
.22632 .40354 .23228 .4092 .2411 .40614 .23515 .40046 Metetra
.664 .741 .908 r
.23515 .40046 .2411 .40614 .24994 .40307 .24401 .39737 Metetra
.664 .741 .908 r
.24401 .39737 .24994 .40307 .25882 .39998 .25291 .39426 Metetra
.664 .741 .908 r
.25291 .39426 .25882 .39998 .26773 .39689 .26183 .39115 Metetra
.664 .741 .908 r
.26183 .39115 .26773 .39689 .27666 .39379 .27078 .38803 Metetra
.664 .741 .908 r
.27078 .38803 .27666 .39379 .28563 .39067 .27977 .3849 Metetra
.664 .741 .908 r
.27977 .3849 .28563 .39067 .29463 .38755 .28879 .38175 Metetra
.652 .738 .913 r
.28879 .38175 .29463 .38755 .30365 .38449 .29781 .37886 Metetra
.65 .744 .919 r
.29781 .37886 .30365 .38449 .3127 .38144 .30687 .37602 Metetra
.606 .74 .939 r
.30687 .37602 .3127 .38144 .32172 .37941 .3159 .37401 Metetra
.594 .737 .944 r
.3159 .37401 .32172 .37941 .33076 .37761 .32496 .37219 Metetra
.627 .748 .934 r
.32496 .37219 .33076 .37761 .33987 .37538 .3341 .36977 Metetra
.636 .744 .926 r
.3341 .36977 .33987 .37538 .34902 .37302 .34328 .36716 Metetra
.637 .736 .92 r
.34328 .36716 .34902 .37302 .3582 .37064 .3525 .36454 Metetra
.637 .728 .914 r
.3525 .36454 .3582 .37064 .36743 .36826 .36175 .36191 Metetra
.646 .723 .904 r
.36175 .36191 .36743 .36826 .37671 .36535 .37104 .35907 Metetra
.65 .727 .906 r
.37104 .35907 .37671 .36535 .38604 .36221 .38038 .35615 Metetra
.631 .729 .918 r
.38038 .35615 .38604 .36221 .39537 .35963 .38973 .35361 Metetra
.622 .729 .923 r
.38973 .35361 .39537 .35963 .40474 .3573 .39912 .35126 Metetra
.647 .737 .915 r
.39912 .35126 .40474 .3573 .41414 .35501 .40856 .34837 Metetra
.658 .72 .895 r
.40856 .34837 .41414 .35501 .42358 .35274 .41804 .34517 Metetra
.615 .676 .885 r
.41804 .34517 .42358 .35274 .43304 .35099 .42753 .34304 Metetra
.586 .653 .883 r
.42753 .34304 .43304 .35099 .44253 .34955 .43704 .34158 Metetra
.586 .653 .883 r
.43704 .34158 .44253 .34955 .45208 .34811 .44659 .34011 Metetra
.586 .653 .883 r
.44659 .34011 .45208 .34811 .46166 .34666 .45619 .33864 Metetra
.626 .67 .872 r
.45619 .33864 .46166 .34666 .47129 .34509 .46585 .33616 Metetra
.652 .658 .843 r
.46585 .33616 .47129 .34509 .48097 .34341 .47557 .33285 Metetra
.645 .62 .811 r
.47557 .33285 .48097 .34341 .49071 .34087 .48532 .32951 Metetra
.642 .605 .797 r
.48532 .32951 .49071 .34087 .50049 .33751 .49511 .32612 Metetra
.643 .605 .796 r
.49511 .32612 .50049 .33751 .51031 .33334 .50493 .3227 Metetra
.647 .621 .81 r
.50493 .3227 .51031 .33334 .52016 .32828 .51479 .31924 Metetra
.678 .669 .834 r
.51479 .31924 .52016 .32828 .53003 .32313 .52468 .31494 Metetra
.711 .703 .84 r
.52468 .31494 .53003 .32313 .53993 .31784 .5346 .30963 Metetra
.711 .703 .84 r
.5346 .30963 .53993 .31784 .54986 .31254 .54454 .30431 Metetra
.711 .703 .84 r
.54454 .30431 .54986 .31254 .5598 .30723 .55451 .29898 Metetra
.693 .696 .848 r
.55451 .29898 .5598 .30723 .56978 .30224 .56451 .29431 Metetra
.662 .694 .869 r
.56451 .29431 .56978 .30224 .57979 .29775 .57456 .29073 Metetra
.676 .727 .888 r
.57456 .29073 .57979 .29775 .58983 .29329 .58463 .28683 Metetra
.697 .754 .895 r
.58463 .28683 .58983 .29329 .5999 .28886 .59473 .28238 Metetra
.69 .751 .898 r
.59473 .28238 .5999 .28886 .61001 .28469 .60487 .27811 Metetra
.675 .744 .902 r
.60487 .27811 .61001 .28469 .62017 .28108 .61505 .27424 Metetra
.678 .737 .895 r
.61505 .27424 .62017 .28108 .63036 .27723 .62526 .27028 Metetra
.684 .736 .89 r
.62526 .27028 .63036 .27723 .64057 .27285 .6355 .2661 Metetra
.685 .744 .896 r
.6355 .2661 .64057 .27285 .6508 .26845 .64577 .26191 Metetra
.686 .752 .902 r
.64577 .26191 .6508 .26845 .66107 .26404 .65607 .2577 Metetra
.693 .763 .905 r
.65607 .2577 .66107 .26404 .67137 .25948 .6664 .2533 Metetra
.715 .776 .9 r
.6664 .2533 .67137 .25948 .68167 .25448 .67674 .24827 Metetra
.708 .774 .904 r
.67674 .24827 .68167 .25448 .69202 .24971 .68711 .24343 Metetra
.676 .761 .915 r
.68711 .24343 .69202 .24971 .70245 .24599 .69756 .23945 Metetra
.674 .752 .91 r
.69756 .23945 .70245 .24599 .71293 .24227 .70806 .23551 Metetra
.664 .741 .908 r
.70806 .23551 .71293 .24227 .72345 .23861 .7186 .23183 Metetra
.664 .741 .908 r
.7186 .23183 .72345 .23861 .73401 .23495 .72919 .22814 Metetra
.664 .741 .908 r
.72919 .22814 .73401 .23495 .74461 .23126 .73981 .22443 Metetra
.664 .741 .908 r
.73981 .22443 .74461 .23126 .75524 .22757 .75048 .22071 Metetra
.664 .741 .908 r
.75048 .22071 .75524 .22757 .76592 .22386 .76118 .21698 Metetra
.664 .741 .908 r
.76118 .21698 .76592 .22386 .77664 .22014 .77193 .21323 Metetra
.664 .741 .908 r
.77193 .21323 .77664 .22014 .78739 .2164 .78271 .20947 Metetra
.664 .741 .908 r
.78271 .20947 .78739 .2164 .79819 .21265 .79354 .20569 Metetra
.664 .741 .908 r
.79354 .20569 .79819 .21265 .80903 .20889 .80441 .2019 Metetra
.664 .741 .908 r
.80441 .2019 .80903 .20889 .81991 .20511 .81531 .1981 Metetra
.664 .741 .908 r
.19394 .40708 .2 .41272 .20874 .40967 .2027 .40401 Metetra
.664 .741 .908 r
.2027 .40401 .20874 .40967 .21751 .40661 .21149 .40093 Metetra
.664 .741 .908 r
.21149 .40093 .21751 .40661 .22632 .40354 .22031 .39784 Metetra
.664 .741 .908 r
.22031 .39784 .22632 .40354 .23515 .40046 .22916 .39474 Metetra
.664 .741 .908 r
.22916 .39474 .23515 .40046 .24401 .39737 .23805 .39163 Metetra
.664 .741 .908 r
.23805 .39163 .24401 .39737 .25291 .39426 .24696 .38851 Metetra
.664 .741 .908 r
.24696 .38851 .25291 .39426 .26183 .39115 .2559 .38538 Metetra
.664 .741 .908 r
.2559 .38538 .26183 .39115 .27078 .38803 .26487 .38224 Metetra
.664 .741 .908 r
.26487 .38224 .27078 .38803 .27977 .3849 .27387 .37908 Metetra
.664 .741 .908 r
.27387 .37908 .27977 .3849 .28879 .38175 .28291 .37592 Metetra
.64 .735 .917 r
.28291 .37592 .28879 .38175 .29781 .37886 .29193 .37327 Metetra
.635 .743 .926 r
.29193 .37327 .29781 .37886 .30687 .37602 .30099 .37072 Metetra
.609 .747 .943 r
.30099 .37072 .30687 .37602 .3159 .37401 .31005 .36861 Metetra
.603 .742 .942 r
.31005 .36861 .3159 .37401 .32496 .37219 .31913 .3666 Metetra
.635 .745 .928 r
.31913 .3666 .32496 .37219 .3341 .36977 .3283 .36402 Metetra
.643 .742 .921 r
.3283 .36402 .3341 .36977 .34328 .36716 .3375 .36125 Metetra
.646 .738 .916 r
.3375 .36125 .34328 .36716 .3525 .36454 .34675 .3584 Metetra
.647 .731 .91 r
.34675 .3584 .3525 .36454 .36175 .36191 .35603 .35553 Metetra
.642 .721 .906 r
.35603 .35553 .36175 .36191 .37104 .35907 .36534 .35276 Metetra
.64 .724 .909 r
.36534 .35276 .37104 .35907 .38038 .35615 .37469 .35004 Metetra
.631 .729 .918 r
.37469 .35004 .38038 .35615 .38973 .35361 .38406 .3475 Metetra
.626 .728 .92 r
.38406 .3475 .38973 .35361 .39912 .35126 .39346 .34505 Metetra
.658 .735 .907 r
.39346 .34505 .39912 .35126 .40856 .34837 .40293 .34185 Metetra
.673 .731 .893 r
.40293 .34185 .40856 .34837 .41804 .34517 .41245 .33825 Metetra
.629 .703 .899 r
.41245 .33825 .41804 .34517 .42753 .34304 .42197 .33573 Metetra
.6 .68 .897 r
.42197 .33573 .42753 .34304 .43704 .34158 .4315 .33389 Metetra
.598 .668 .888 r
.4315 .33389 .43704 .34158 .44659 .34011 .44108 .3321 Metetra
.598 .659 .881 r
.44108 .3321 .44659 .34011 .45619 .33864 .4507 .33034 Metetra
.643 .67 .861 r
.4507 .33034 .45619 .33864 .46585 .33616 .46038 .32737 Metetra
.671 .67 .84 r
.46038 .32737 .46585 .33616 .47557 .33285 .47013 .32341 Metetra
.659 .65 .83 r
.47013 .32341 .47557 .33285 .48532 .32951 .47989 .31973 Metetra
.65 .64 .827 r
.47989 .31973 .48532 .32951 .49511 .32612 .48969 .31632 Metetra
.642 .636 .829 r
.48969 .31632 .49511 .32612 .50493 .3227 .49952 .31318 Metetra
.634 .639 .838 r
.49952 .31318 .50493 .3227 .51479 .31924 .50939 .31033 Metetra
.666 .668 .842 r
.50939 .31033 .51479 .31924 .52468 .31494 .5193 .30648 Metetra
.702 .694 .839 r
.5193 .30648 .52468 .31494 .5346 .30963 .52924 .30141 Metetra
.704 .701 .845 r
.52924 .30141 .5346 .30963 .54454 .30431 .5392 .29637 Metetra
.705 .709 .852 r
.5392 .29637 .54454 .30431 .55451 .29898 .5492 .29136 Metetra
.687 .713 .868 r
.5492 .29136 .55451 .29898 .56451 .29431 .55922 .28705 Metetra
.651 .71 .891 r
.55922 .28705 .56451 .29431 .57456 .29073 .5693 .28382 Metetra
.666 .729 .896 r
.5693 .28382 .57456 .29073 .58463 .28683 .5794 .28018 Metetra
.693 .747 .893 r
.5794 .28018 .58463 .28683 .59473 .28238 .58953 .2758 Metetra
.691 .749 .897 r
.58953 .2758 .59473 .28238 .60487 .27811 .59969 .27149 Metetra
.684 .747 .899 r
.59969 .27149 .60487 .27811 .61505 .27424 .60989 .26736 Metetra
.681 .738 .894 r
.60989 .26736 .61505 .27424 .62526 .27028 .62012 .26328 Metetra
.676 .733 .893 r
.62012 .26328 .62526 .27028 .6355 .2661 .63039 .2593 Metetra
.678 .741 .899 r
.63039 .2593 .6355 .2661 .64577 .26191 .6407 .25529 Metetra
.681 .749 .903 r
.6407 .25529 .64577 .26191 .65607 .2577 .65103 .2512 Metetra
.687 .757 .904 r
.65103 .2512 .65607 .2577 .6664 .2533 .6614 .24693 Metetra
.708 .769 .9 r
.6614 .24693 .6664 .2533 .67674 .24827 .67177 .24205 Metetra
.705 .774 .906 r
.67177 .24205 .67674 .24827 .68711 .24343 .68218 .23727 Metetra
.689 .772 .915 r
.68218 .23727 .68711 .24343 .69756 .23945 .69264 .23294 Metetra
.684 .759 .908 r
.69264 .23294 .69756 .23945 .70806 .23551 .70315 .22871 Metetra
.664 .741 .908 r
.70315 .22871 .70806 .23551 .7186 .23183 .71372 .225 Metetra
.664 .741 .908 r
.71372 .225 .7186 .23183 .72919 .22814 .72433 .22129 Metetra
.664 .741 .908 r
.72433 .22129 .72919 .22814 .73981 .22443 .73499 .21756 Metetra
.664 .741 .908 r
.73499 .21756 .73981 .22443 .75048 .22071 .74568 .21381 Metetra
.664 .741 .908 r
.74568 .21381 .75048 .22071 .76118 .21698 .75641 .21005 Metetra
.664 .741 .908 r
.75641 .21005 .76118 .21698 .77193 .21323 .76719 .20628 Metetra
.664 .741 .908 r
.76719 .20628 .77193 .21323 .78271 .20947 .778 .20249 Metetra
.664 .741 .908 r
.778 .20249 .78271 .20947 .79354 .20569 .78885 .19869 Metetra
.664 .741 .908 r
.78885 .19869 .79354 .20569 .80441 .2019 .79975 .19487 Metetra
.664 .741 .908 r
.79975 .19487 .80441 .2019 .81531 .1981 .81069 .19104 Metetra
.664 .741 .908 r
.18785 .40141 .19394 .40708 .2027 .40401 .19663 .39832 Metetra
.664 .741 .908 r
.19663 .39832 .2027 .40401 .21149 .40093 .20543 .39522 Metetra
.664 .741 .908 r
.20543 .39522 .21149 .40093 .22031 .39784 .21427 .39211 Metetra
.664 .741 .908 r
.21427 .39211 .22031 .39784 .22916 .39474 .22314 .38899 Metetra
.664 .741 .908 r
.22314 .38899 .22916 .39474 .23805 .39163 .23204 .38586 Metetra
.664 .741 .908 r
.23204 .38586 .23805 .39163 .24696 .38851 .24097 .38272 Metetra
.664 .741 .908 r
.24097 .38272 .24696 .38851 .2559 .38538 .24993 .37957 Metetra
.664 .741 .908 r
.24993 .37957 .2559 .38538 .26487 .38224 .25892 .3764 Metetra
.664 .741 .908 r
.25892 .3764 .26487 .38224 .27387 .37908 .26794 .37323 Metetra
.664 .741 .908 r
.26794 .37323 .27387 .37908 .28291 .37592 .27699 .37005 Metetra
.622 .729 .923 r
.27699 .37005 .28291 .37592 .29193 .37327 .28601 .36776 Metetra
.611 .74 .937 r
.28601 .36776 .29193 .37327 .30099 .37072 .29505 .36564 Metetra
.622 .761 .945 r
.29505 .36564 .30099 .37072 .31005 .36861 .30414 .36323 Metetra
.627 .752 .937 r
.30414 .36323 .31005 .36861 .31913 .3666 .31328 .36076 Metetra
.64 .739 .92 r
.31328 .36076 .31913 .3666 .3283 .36402 .32247 .35805 Metetra
.643 .736 .916 r
.32247 .35805 .3283 .36402 .3375 .36125 .33169 .35526 Metetra
.654 .739 .912 r
.33169 .35526 .3375 .36125 .34675 .3584 .34097 .35223 Metetra
.657 .734 .906 r
.34097 .35223 .34675 .3584 .35603 .35553 .35028 .3491 Metetra
.638 .72 .907 r
.35028 .3491 .35603 .35553 .36534 .35276 .35961 .34641 Metetra
.63 .721 .913 r
.35961 .34641 .36534 .35276 .37469 .35004 .36896 .3439 Metetra
.634 .73 .917 r
.36896 .3439 .37469 .35004 .38406 .3475 .37835 .34126 Metetra
.637 .728 .914 r
.37835 .34126 .38406 .3475 .39346 .34505 .38779 .33855 Metetra
.649 .724 .904 r
.38779 .33855 .39346 .34505 .40293 .34185 .39727 .33555 Metetra
.656 .734 .907 r
.39727 .33555 .40293 .34185 .41245 .33825 .40679 .33238 Metetra
.645 .747 .923 r
.40679 .33238 .41245 .33825 .42197 .33573 .41634 .32946 Metetra
.638 .731 .915 r
.41634 .32946 .42197 .33573 .4315 .33389 .42592 .32669 Metetra
.631 .697 .893 r
.42592 .32669 .4315 .33389 .44108 .3321 .43553 .32409 Metetra
.625 .671 .874 r
.43553 .32409 .44108 .3321 .4507 .33034 .44518 .32161 Metetra
.635 .657 .854 r
.44518 .32161 .4507 .33034 .46038 .32737 .45488 .31882 Metetra
.644 .666 .856 r
.45488 .31882 .46038 .32737 .47013 .32341 .46462 .31575 Metetra
.653 .695 .876 r
.46462 .31575 .47013 .32341 .47989 .31973 .4744 .31249 Metetra
.661 .711 .885 r
.4744 .31249 .47989 .31973 .48969 .31632 .48422 .30906 Metetra
.667 .713 .883 r
.48422 .30906 .48969 .31632 .49952 .31318 .49407 .30545 Metetra
.671 .701 .87 r
.49407 .30545 .49952 .31318 .50939 .31033 .50396 .30165 Metetra
.674 .678 .846 r
.50396 .30165 .50939 .31033 .5193 .30648 .51389 .29758 Metetra
.681 .676 .839 r
.51389 .29758 .5193 .30648 .52924 .30141 .52385 .29318 Metetra
.682 .694 .855 r
.52385 .29318 .52924 .30141 .5392 .29637 .53384 .2889 Metetra
.681 .716 .875 r
.53384 .2889 .5392 .29637 .5492 .29136 .54386 .2848 Metetra
.679 .744 .9 r
.54386 .2848 .5492 .29136 .55922 .28705 .55391 .28084 Metetra
.67 .755 .914 r
.55391 .28084 .55922 .28705 .5693 .28382 .56401 .27713 Metetra
.675 .74 .9 r
.56401 .27713 .5693 .28382 .5794 .28018 .57413 .27325 Metetra
.684 .737 .89 r
.57413 .27325 .5794 .28018 .58953 .2758 .58429 .26907 Metetra
.687 .745 .895 r
.58429 .26907 .58953 .2758 .59969 .27149 .59447 .26482 Metetra
.692 .749 .896 r
.59447 .26482 .59969 .27149 .60989 .26736 .60469 .26044 Metetra
.684 .739 .893 r
.60469 .26044 .60989 .26736 .62012 .26328 .61495 .25623 Metetra
.668 .73 .896 r
.61495 .25623 .62012 .26328 .63039 .2593 .62525 .25247 Metetra
.672 .739 .901 r
.62525 .25247 .63039 .2593 .6407 .25529 .63559 .2486 Metetra
.681 .748 .902 r
.63559 .2486 .6407 .25529 .65103 .2512 .64595 .24449 Metetra
.683 .749 .901 r
.64595 .24449 .65103 .2512 .6614 .24693 .65635 .24029 Metetra
.692 .756 .901 r
.65635 .24029 .6614 .24693 .67177 .24205 .66677 .23585 Metetra
.696 .773 .911 r
.66677 .23585 .67177 .24205 .68218 .23727 .67722 .23132 Metetra
.706 .787 .914 r
.67722 .23132 .68218 .23727 .69264 .23294 .68769 .22651 Metetra
.698 .768 .906 r
.68769 .22651 .69264 .23294 .70315 .22871 .6982 .22186 Metetra
.664 .741 .908 r
.6982 .22186 .70315 .22871 .71372 .225 .7088 .21813 Metetra
.664 .741 .908 r
.7088 .21813 .71372 .225 .72433 .22129 .71945 .21439 Metetra
.664 .741 .908 r
.71945 .21439 .72433 .22129 .73499 .21756 .73013 .21063 Metetra
.664 .741 .908 r
.73013 .21063 .73499 .21756 .74568 .21381 .74085 .20686 Metetra
.664 .741 .908 r
.74085 .20686 .74568 .21381 .75641 .21005 .75161 .20307 Metetra
.664 .741 .908 r
.75161 .20307 .75641 .21005 .76719 .20628 .76241 .19927 Metetra
.664 .741 .908 r
.76241 .19927 .76719 .20628 .778 .20249 .77325 .19546 Metetra
.664 .741 .908 r
.77325 .19546 .778 .20249 .78885 .19869 .78414 .19163 Metetra
.664 .741 .908 r
.78414 .19163 .78885 .19869 .79975 .19487 .79506 .18778 Metetra
.664 .741 .908 r
.79506 .18778 .79975 .19487 .81069 .19104 .80603 .18393 Metetra
.664 .741 .908 r
.18172 .3957 .18785 .40141 .19663 .39832 .19051 .39259 Metetra
.664 .741 .908 r
.19051 .39259 .19663 .39832 .20543 .39522 .19934 .38947 Metetra
.664 .741 .908 r
.19934 .38947 .20543 .39522 .21427 .39211 .20819 .38634 Metetra
.664 .741 .908 r
.20819 .38634 .21427 .39211 .22314 .38899 .21708 .3832 Metetra
.664 .741 .908 r
.21708 .3832 .22314 .38899 .23204 .38586 .22599 .38005 Metetra
.664 .741 .908 r
.22599 .38005 .23204 .38586 .24097 .38272 .23494 .37689 Metetra
.664 .741 .908 r
.23494 .37689 .24097 .38272 .24993 .37957 .24392 .37372 Metetra
.664 .741 .908 r
.24392 .37372 .24993 .37957 .25892 .3764 .25293 .37054 Metetra
.661 .741 .909 r
.25293 .37054 .25892 .3764 .26794 .37323 .26196 .36741 Metetra
.66 .743 .911 r
.26196 .36741 .26794 .37323 .27699 .37005 .27103 .36429 Metetra
.611 .731 .931 r
.27103 .36429 .27699 .37005 .28601 .36776 .28005 .36217 Metetra
.599 .735 .939 r
.28005 .36217 .28601 .36776 .29505 .36564 .28909 .36024 Metetra
.634 .754 .934 r
.28909 .36024 .29505 .36564 .30414 .36323 .29822 .35763 Metetra
.643 .749 .926 r
.29822 .35763 .30414 .36323 .31328 .36076 .30739 .35484 Metetra
.646 .739 .917 r
.30739 .35484 .31328 .36076 .32247 .35805 .31661 .35198 Metetra
.647 .735 .913 r
.31661 .35198 .32247 .35805 .33169 .35526 .32586 .34909 Metetra
.657 .735 .907 r
.32586 .34909 .33169 .35526 .34097 .35223 .33515 .34597 Metetra
.66 .733 .904 r
.33515 .34597 .34097 .35223 .35028 .3491 .34449 .34275 Metetra
.639 .725 .91 r
.34449 .34275 .35028 .3491 .35961 .34641 .35383 .34001 Metetra
.63 .721 .912 r
.35383 .34001 .35961 .34641 .36896 .3439 .3632 .33746 Metetra
.637 .722 .909 r
.3632 .33746 .36896 .3439 .37835 .34126 .37262 .33475 Metetra
.64 .722 .907 r
.37262 .33475 .37835 .34126 .38779 .33855 .38207 .33196 Metetra
.645 .721 .904 r
.38207 .33196 .38779 .33855 .39727 .33555 .39157 .32905 Metetra
.647 .726 .906 r
.39157 .32905 .39727 .33555 .40679 .33238 .4011 .32607 Metetra
.657 .736 .908 r
.4011 .32607 .40679 .33238 .41634 .32946 .41068 .32285 Metetra
.662 .728 .899 r
.41068 .32285 .41634 .32946 .42592 .32669 .4203 .31946 Metetra
.649 .705 .888 r
.4203 .31946 .42592 .32669 .43553 .32409 .42995 .31639 Metetra
.639 .687 .879 r
.42995 .31639 .43553 .32409 .44518 .32161 .43962 .31353 Metetra
.632 .674 .872 r
.43962 .31353 .44518 .32161 .45488 .31882 .44933 .31082 Metetra
.628 .676 .876 r
.44933 .31082 .45488 .31882 .46462 .31575 .45908 .30824 Metetra
.645 .697 .884 r
.45908 .30824 .46462 .31575 .4744 .31249 .46887 .30521 Metetra
.661 .711 .885 r
.46887 .30521 .4744 .31249 .48422 .30906 .47871 .30175 Metetra
.675 .716 .88 r
.47871 .30175 .48422 .30906 .49407 .30545 .48859 .29787 Metetra
.688 .713 .868 r
.48859 .29787 .49407 .30545 .50396 .30165 .4985 .29353 Metetra
.681 .696 .858 r
.4985 .29353 .50396 .30165 .51389 .29758 .50845 .28932 Metetra
.675 .691 .857 r
.50845 .28932 .51389 .29758 .52385 .29318 .51843 .28526 Metetra
.67 .699 .868 r
.51843 .28526 .52385 .29318 .53384 .2889 .52844 .28142 Metetra
.661 .709 .883 r
.52844 .28142 .53384 .2889 .54386 .2848 .53848 .27789 Metetra
.668 .73 .897 r
.53848 .27789 .54386 .2848 .55391 .28084 .54856 .27419 Metetra
.677 .743 .9 r
.54856 .27419 .55391 .28084 .56401 .27713 .55868 .27024 Metetra
.679 .736 .894 r
.55868 .27024 .56401 .27713 .57413 .27325 .56882 .26622 Metetra
.682 .734 .89 r
.56882 .26622 .57413 .27325 .58429 .26907 .57901 .26208 Metetra
.685 .737 .891 r
.57901 .26208 .58429 .26907 .59447 .26482 .58922 .25785 Metetra
.69 .74 .89 r
.58922 .25785 .59447 .26482 .60469 .26044 .59946 .25346 Metetra
.683 .739 .893 r
.59946 .25346 .60469 .26044 .61495 .25623 .60974 .24926 Metetra
.666 .733 .9 r
.60974 .24926 .61495 .25623 .62525 .25247 .62007 .24553 Metetra
.669 .736 .901 r
.62007 .24553 .62525 .25247 .63559 .2486 .63044 .24172 Metetra
.677 .742 .9 r
.63044 .24172 .63559 .2486 .64595 .24449 .64083 .23766 Metetra
.678 .745 .901 r
.64083 .23766 .64595 .24449 .65635 .24029 .65126 .23357 Metetra
.681 .751 .904 r
.65126 .23357 .65635 .24029 .66677 .23585 .66173 .2294 Metetra
.688 .763 .909 r
.66173 .2294 .66677 .23585 .67722 .23132 .67222 .22505 Metetra
.713 .779 .904 r
.67222 .22505 .67722 .23132 .68769 .22651 .68271 .21999 Metetra
.705 .769 .902 r
.68271 .21999 .68769 .22651 .6982 .22186 .69324 .21512 Metetra
.667 .748 .911 r
.69324 .21512 .6982 .22186 .7088 .21813 .70386 .21128 Metetra
.666 .745 .909 r
.70386 .21128 .7088 .21813 .71945 .21439 .71452 .20744 Metetra
.664 .741 .908 r
.71452 .20744 .71945 .21439 .73013 .21063 .72523 .20366 Metetra
.664 .741 .908 r
.72523 .20366 .73013 .21063 .74085 .20686 .73598 .19986 Metetra
.664 .741 .908 r
.73598 .19986 .74085 .20686 .75161 .20307 .74677 .19604 Metetra
.664 .741 .908 r
.74677 .19604 .75161 .20307 .76241 .19927 .7576 .19222 Metetra
.664 .741 .908 r
.7576 .19222 .76241 .19927 .77325 .19546 .76847 .18838 Metetra
.664 .741 .908 r
.76847 .18838 .77325 .19546 .78414 .19163 .77939 .18452 Metetra
.664 .741 .908 r
.77939 .18452 .78414 .19163 .79506 .18778 .79034 .18065 Metetra
.664 .741 .908 r
.79034 .18065 .79506 .18778 .80603 .18393 .80134 .17677 Metetra
.664 .741 .908 r
.17555 .38995 .18172 .3957 .19051 .39259 .18436 .38683 Metetra
.664 .741 .908 r
.18436 .38683 .19051 .39259 .19934 .38947 .1932 .38369 Metetra
.664 .741 .908 r
.1932 .38369 .19934 .38947 .20819 .38634 .20207 .38054 Metetra
.664 .741 .908 r
.20207 .38054 .20819 .38634 .21708 .3832 .21098 .37738 Metetra
.664 .741 .908 r
.21098 .37738 .21708 .3832 .22599 .38005 .21991 .37421 Metetra
.664 .741 .908 r
.21991 .37421 .22599 .38005 .23494 .37689 .22888 .37103 Metetra
.664 .741 .908 r
.22888 .37103 .23494 .37689 .24392 .37372 .23787 .36783 Metetra
.664 .741 .908 r
.23787 .36783 .24392 .37372 .25293 .37054 .2469 .36463 Metetra
.652 .738 .913 r
.2469 .36463 .25293 .37054 .26196 .36741 .25594 .36168 Metetra
.65 .745 .919 r
.25594 .36168 .26196 .36741 .27103 .36429 .265 .35876 Metetra
.618 .744 .936 r
.265 .35876 .27103 .36429 .28005 .36217 .27405 .35647 Metetra
.612 .736 .934 r
.27405 .35647 .28005 .36217 .28909 .36024 .28313 .3543 Metetra
.638 .736 .919 r
.28313 .3543 .28909 .36024 .29822 .35763 .29228 .35162 Metetra
.643 .736 .916 r
.29228 .35162 .29822 .35763 .30739 .35484 .30147 .34881 Metetra
.654 .739 .912 r
.30147 .34881 .30739 .35484 .31661 .35198 .31071 .34576 Metetra
.657 .734 .906 r
.31071 .34576 .31661 .35198 .32586 .34909 .32 .34262 Metetra
.652 .724 .902 r
.32 .34262 .32586 .34909 .33515 .34597 .32931 .33958 Metetra
.65 .728 .906 r
.32931 .33958 .33515 .34597 .34449 .34275 .33865 .33658 Metetra
.65 .736 .912 r
.33865 .33658 .34449 .34275 .35383 .34001 .34803 .33356 Metetra
.65 .727 .905 r
.34803 .33356 .35383 .34001 .3632 .33746 .35744 .33053 Metetra
.637 .707 .897 r
.35744 .33053 .3632 .33746 .37262 .33475 .36687 .32781 Metetra
.631 .705 .9 r
.36687 .32781 .37262 .33475 .38207 .33196 .37633 .32522 Metetra
.647 .718 .9 r
.37633 .32522 .38207 .33196 .39157 .32905 .38585 .32222 Metetra
.656 .719 .895 r
.38585 .32222 .39157 .32905 .4011 .32607 .39541 .319 Metetra
.659 .713 .888 r
.39541 .319 .4011 .32607 .41068 .32285 .40501 .31566 Metetra
.661 .711 .885 r
.40501 .31566 .41068 .32285 .4203 .31946 .41465 .31225 Metetra
.644 .705 .891 r
.41465 .31225 .4203 .31946 .42995 .31639 .42431 .30928 Metetra
.631 .704 .899 r
.42431 .30928 .42995 .31639 .43962 .31353 .434 .30663 Metetra
.634 .713 .904 r
.434 .30663 .43962 .31353 .44933 .31082 .44373 .30388 Metetra
.637 .713 .902 r
.44373 .30388 .44933 .31082 .45908 .30824 .4535 .30105 Metetra
.65 .71 .892 r
.4535 .30105 .45908 .30824 .46887 .30521 .46331 .29788 Metetra
.661 .711 .885 r
.46331 .29788 .46887 .30521 .47871 .30175 .47317 .2944 Metetra
.671 .715 .881 r
.47317 .2944 .47871 .30175 .48859 .29787 .48307 .29061 Metetra
.683 .722 .879 r
.48307 .29061 .48859 .29787 .4985 .29353 .493 .28648 Metetra
.686 .73 .884 r
.493 .28648 .4985 .29353 .50845 .28932 .50297 .28226 Metetra
.689 .732 .883 r
.50297 .28226 .50845 .28932 .51843 .28526 .51297 .27795 Metetra
.677 .721 .882 r
.51297 .27795 .51843 .28526 .52844 .28142 .523 .27395 Metetra
.661 .711 .885 r
.523 .27395 .52844 .28142 .53848 .27789 .53307 .27039 Metetra
.663 .712 .884 r
.53307 .27039 .53848 .27789 .54856 .27419 .54317 .26675 Metetra
.667 .716 .885 r
.54317 .26675 .54856 .27419 .55868 .27024 .55331 .26301 Metetra
.675 .726 .888 r
.55331 .26301 .55868 .27024 .56882 .26622 .56348 .25903 Metetra
.689 .733 .884 r
.56348 .25903 .56882 .26622 .57901 .26208 .57368 .25464 Metetra
.683 .724 .881 r
.57368 .25464 .57901 .26208 .58922 .25785 .58392 .25038 Metetra
.672 .719 .884 r
.58392 .25038 .58922 .25785 .59946 .25346 .5942 .24642 Metetra
.674 .735 .896 r
.5942 .24642 .59946 .25346 .60974 .24926 .60451 .24246 Metetra
.675 .744 .903 r
.60451 .24246 .60974 .24926 .62007 .24553 .61486 .23848 Metetra
.673 .735 .897 r
.61486 .23848 .62007 .24553 .63044 .24172 .62525 .23452 Metetra
.668 .73 .896 r
.62525 .23452 .63044 .24172 .64083 .23766 .63567 .23067 Metetra
.671 .739 .901 r
.63567 .23067 .64083 .23766 .65126 .23357 .64614 .22673 Metetra
.681 .748 .902 r
.64614 .22673 .65126 .23357 .66173 .2294 .65663 .22254 Metetra
.685 .75 .901 r
.65663 .22254 .66173 .2294 .67222 .22505 .66715 .2182 Metetra
.702 .757 .895 r
.66715 .2182 .67222 .22505 .68271 .21999 .67768 .21335 Metetra
.699 .764 .902 r
.67768 .21335 .68271 .21999 .69324 .21512 .68825 .20861 Metetra
.676 .761 .915 r
.68825 .20861 .69324 .21512 .70386 .21128 .69889 .20451 Metetra
.674 .752 .91 r
.69889 .20451 .70386 .21128 .71452 .20744 .70957 .20044 Metetra
.664 .741 .908 r
.70957 .20044 .71452 .20744 .72523 .20366 .7203 .19663 Metetra
.664 .741 .908 r
.7203 .19663 .72523 .20366 .73598 .19986 .73108 .19281 Metetra
.664 .741 .908 r
.73108 .19281 .73598 .19986 .74677 .19604 .7419 .18897 Metetra
.664 .741 .908 r
.7419 .18897 .74677 .19604 .7576 .19222 .75276 .18512 Metetra
.664 .741 .908 r
.75276 .18512 .7576 .19222 .76847 .18838 .76366 .18125 Metetra
.664 .741 .908 r
.76366 .18125 .76847 .18838 .77939 .18452 .7746 .17736 Metetra
.664 .741 .908 r
.7746 .17736 .77939 .18452 .79034 .18065 .78558 .17347 Metetra
.664 .741 .908 r
.78558 .17347 .79034 .18065 .80134 .17677 .79661 .16955 Metetra
.664 .741 .908 r
.16934 .38417 .17555 .38995 .18436 .38683 .17817 .38102 Metetra
.664 .741 .908 r
.17817 .38102 .18436 .38683 .1932 .38369 .18703 .37787 Metetra
.664 .741 .908 r
.18703 .37787 .1932 .38369 .20207 .38054 .19592 .3747 Metetra
.664 .741 .908 r
.19592 .3747 .20207 .38054 .21098 .37738 .20484 .37152 Metetra
.664 .741 .908 r
.20484 .37152 .21098 .37738 .21991 .37421 .21379 .36833 Metetra
.664 .741 .908 r
.21379 .36833 .21991 .37421 .22888 .37103 .22277 .36512 Metetra
.664 .741 .908 r
.22277 .36512 .22888 .37103 .23787 .36783 .23179 .36191 Metetra
.664 .741 .908 r
.23179 .36191 .23787 .36783 .2469 .36463 .24083 .35869 Metetra
.64 .735 .917 r
.24083 .35869 .2469 .36463 .25594 .36168 .24986 .35598 Metetra
.636 .743 .926 r
.24986 .35598 .25594 .36168 .265 .35876 .25892 .35334 Metetra
.628 .752 .936 r
.25892 .35334 .265 .35876 .27405 .35647 .26801 .35083 Metetra
.627 .744 .931 r
.26801 .35083 .27405 .35647 .28313 .3543 .27712 .34833 Metetra
.641 .737 .919 r
.27712 .34833 .28313 .3543 .29228 .35162 .2863 .34558 Metetra
.643 .736 .916 r
.2863 .34558 .29228 .35162 .30147 .34881 .29551 .34275 Metetra
.659 .74 .91 r
.29551 .34275 .30147 .34881 .31071 .34576 .30478 .33955 Metetra
.663 .737 .905 r
.30478 .33955 .31071 .34576 .32 .34262 .31409 .33624 Metetra
.649 .728 .907 r
.31409 .33624 .32 .34262 .32931 .33958 .32342 .33326 Metetra
.644 .729 .911 r
.32342 .33326 .32931 .33958 .33865 .33658 .33277 .33038 Metetra
.658 .739 .909 r
.33277 .33038 .33865 .33658 .34803 .33356 .34218 .32717 Metetra
.663 .734 .903 r
.34218 .32717 .34803 .33356 .35744 .33053 .35162 .32381 Metetra
.641 .717 .903 r
.35162 .32381 .35744 .33053 .36687 .32781 .36108 .32097 Metetra
.63 .71 .904 r
.36108 .32097 .36687 .32781 .37633 .32522 .37056 .31837 Metetra
.649 .717 .897 r
.37056 .31837 .37633 .32522 .38585 .32222 .38009 .3153 Metetra
.659 .718 .892 r
.38009 .3153 .38585 .32222 .39541 .319 .38968 .31197 Metetra
.659 .716 .89 r
.38968 .31197 .39541 .319 .40501 .31566 .3993 .30862 Metetra
.659 .716 .891 r
.3993 .30862 .40501 .31566 .41465 .31225 .40896 .30527 Metetra
.644 .713 .898 r
.40896 .30527 .41465 .31225 .42431 .30928 .41863 .30227 Metetra
.634 .709 .901 r
.41863 .30227 .42431 .30928 .434 .30663 .42834 .29952 Metetra
.641 .71 .897 r
.42834 .29952 .434 .30663 .44373 .30388 .43809 .29659 Metetra
.646 .707 .891 r
.43809 .29659 .44373 .30388 .4535 .30105 .44789 .29351 Metetra
.653 .702 .883 r
.44789 .29351 .4535 .30105 .46331 .29788 .45772 .29021 Metetra
.66 .701 .878 r
.45772 .29021 .46331 .29788 .47317 .2944 .4676 .2867 Metetra
.666 .704 .875 r
.4676 .2867 .47317 .2944 .48307 .29061 .47752 .28299 Metetra
.674 .71 .875 r
.47752 .28299 .48307 .29061 .493 .28648 .48747 .27907 Metetra
.679 .719 .879 r
.48747 .27907 .493 .28648 .50297 .28226 .49746 .27499 Metetra
.686 .726 .88 r
.49746 .27499 .50297 .28226 .51297 .27795 .50748 .27071 Metetra
.677 .725 .885 r
.50748 .27071 .51297 .27795 .523 .27395 .51753 .2667 Metetra
.664 .72 .891 r
.51753 .2667 .523 .27395 .53307 .27039 .52762 .26304 Metetra
.664 .718 .889 r
.52762 .26304 .53307 .27039 .54317 .26675 .53775 .25937 Metetra
.664 .718 .888 r
.53775 .25937 .54317 .26675 .55331 .26301 .54791 .25568 Metetra
.673 .724 .887 r
.54791 .25568 .55331 .26301 .56348 .25903 .55811 .25173 Metetra
.689 .731 .882 r
.55811 .25173 .56348 .25903 .57368 .25464 .56833 .2473 Metetra
.681 .727 .885 r
.56833 .2473 .57368 .25464 .58392 .25038 .57859 .24311 Metetra
.662 .724 .895 r
.57859 .24311 .58392 .25038 .5942 .24642 .5889 .23945 Metetra
.668 .736 .901 r
.5889 .23945 .5942 .24642 .60451 .24246 .59924 .23563 Metetra
.681 .746 .901 r
.59924 .23563 .60451 .24246 .61486 .23848 .60961 .23147 Metetra
.676 .74 .899 r
.60961 .23147 .61486 .23848 .62525 .23452 .62002 .22741 Metetra
.663 .732 .901 r
.62002 .22741 .62525 .23452 .63567 .23067 .63048 .22369 Metetra
.667 .739 .904 r
.63048 .22369 .63567 .23067 .64614 .22673 .64098 .21985 Metetra
.681 .748 .902 r
.64098 .21985 .64614 .22673 .65663 .22254 .6515 .21563 Metetra
.683 .749 .901 r
.6515 .21563 .65663 .22254 .66715 .2182 .66205 .21133 Metetra
.692 .754 .899 r
.66205 .21133 .66715 .2182 .67768 .21335 .67262 .20675 Metetra
.692 .765 .907 r
.67262 .20675 .67768 .21335 .68825 .20861 .68323 .20219 Metetra
.688 .771 .915 r
.68323 .20219 .68825 .20861 .69889 .20451 .69388 .19776 Metetra
.684 .758 .908 r
.69388 .19776 .69889 .20451 .70957 .20044 .70458 .1934 Metetra
.664 .741 .908 r
.70458 .1934 .70957 .20044 .7203 .19663 .71534 .18956 Metetra
.664 .741 .908 r
.71534 .18956 .7203 .19663 .73108 .19281 .72615 .18571 Metetra
.664 .741 .908 r
.72615 .18571 .73108 .19281 .7419 .18897 .73699 .18184 Metetra
.664 .741 .908 r
.73699 .18184 .7419 .18897 .75276 .18512 .74788 .17796 Metetra
.664 .741 .908 r
.74788 .17796 .75276 .18512 .76366 .18125 .75881 .17407 Metetra
.664 .741 .908 r
.75881 .17407 .76366 .18125 .7746 .17736 .76978 .17016 Metetra
.664 .741 .908 r
.76978 .17016 .7746 .17736 .78558 .17347 .7808 .16623 Metetra
.664 .741 .908 r
.7808 .16623 .78558 .17347 .79661 .16955 .79185 .16229 Metetra
.664 .741 .908 r
.16309 .37835 .16934 .38417 .17817 .38102 .17193 .37518 Metetra
.664 .741 .908 r
.17193 .37518 .17817 .38102 .18703 .37787 .18081 .37201 Metetra
.664 .741 .908 r
.18081 .37201 .18703 .37787 .19592 .3747 .18972 .36882 Metetra
.664 .741 .908 r
.18972 .36882 .19592 .3747 .20484 .37152 .19866 .36562 Metetra
.664 .741 .908 r
.19866 .36562 .20484 .37152 .21379 .36833 .20763 .36241 Metetra
.664 .741 .908 r
.20763 .36241 .21379 .36833 .22277 .36512 .21663 .35918 Metetra
.664 .741 .908 r
.21663 .35918 .22277 .36512 .23179 .36191 .22566 .35595 Metetra
.664 .741 .908 r
.22566 .35595 .23179 .36191 .24083 .35869 .23473 .35271 Metetra
.621 .729 .924 r
.23473 .35271 .24083 .35869 .24986 .35598 .24374 .35037 Metetra
.612 .741 .937 r
.24374 .35037 .24986 .35598 .25892 .35334 .25278 .34816 Metetra
.642 .767 .939 r
.25278 .34816 .25892 .35334 .26801 .35083 .26191 .34533 Metetra
.649 .757 .928 r
.26191 .34533 .26801 .35083 .27712 .34833 .27108 .34236 Metetra
.645 .739 .918 r
.27108 .34236 .27712 .34833 .2863 .34558 .28028 .33949 Metetra
.643 .736 .916 r
.28028 .33949 .2863 .34558 .29551 .34275 .28951 .33665 Metetra
.659 .74 .91 r
.28951 .33665 .29551 .34275 .30478 .33955 .2988 .33343 Metetra
.663 .742 .908 r
.2988 .33343 .30478 .33955 .31409 .33624 .30813 .33009 Metetra
.649 .737 .914 r
.30813 .33009 .31409 .33624 .32342 .33326 .31748 .32709 Metetra
.643 .736 .916 r
.31748 .32709 .32342 .33326 .33277 .33038 .32685 .3242 Metetra
.658 .74 .911 r
.32685 .3242 .33277 .33038 .34218 .32717 .33627 .32096 Metetra
.663 .742 .908 r
.33627 .32096 .34218 .32717 .35162 .32381 .34574 .31758 Metetra
.654 .739 .912 r
.34574 .31758 .35162 .32381 .36108 .32097 .35523 .31441 Metetra
.65 .727 .905 r
.35523 .31441 .36108 .32097 .37056 .31837 .36475 .31132 Metetra
.65 .712 .893 r
.36475 .31132 .37056 .31837 .38009 .3153 .37431 .30822 Metetra
.65 .712 .893 r
.37431 .30822 .38009 .3153 .38968 .31197 .3839 .30509 Metetra
.65 .719 .899 r
.3839 .30509 .38968 .31197 .3993 .30862 .39354 .30195 Metetra
.65 .727 .905 r
.39354 .30195 .3993 .30862 .40896 .30527 .4032 .2988 Metetra
.657 .737 .908 r
.4032 .2988 .40896 .30527 .41863 .30227 .41291 .29548 Metetra
.661 .728 .899 r
.41291 .29548 .41863 .30227 .42834 .29952 .42266 .29202 Metetra
.657 .705 .882 r
.42266 .29202 .42834 .29952 .43809 .29659 .43244 .28863 Metetra
.653 .69 .873 r
.43244 .28863 .43809 .29659 .44789 .29351 .44226 .28529 Metetra
.655 .685 .866 r
.44226 .28529 .44789 .29351 .45772 .29021 .45212 .28185 Metetra
.657 .683 .863 r
.45212 .28185 .45772 .29021 .4676 .2867 .46201 .27832 Metetra
.66 .684 .862 r
.46201 .27832 .4676 .2867 .47752 .28299 .47194 .2747 Metetra
.663 .688 .863 r
.47194 .2747 .47752 .28299 .48747 .27907 .48191 .27098 Metetra
.662 .694 .869 r
.48191 .27098 .48747 .27907 .49746 .27499 .49191 .26731 Metetra
.661 .706 .881 r
.49191 .26731 .49746 .27499 .50748 .27071 .50195 .26371 Metetra
.668 .73 .896 r
.50195 .26371 .50748 .27071 .51753 .2667 .51203 .25997 Metetra
.674 .743 .902 r
.51203 .25997 .51753 .2667 .52762 .26304 .52214 .25606 Metetra
.674 .735 .896 r
.52214 .25606 .52762 .26304 .53775 .25937 .53229 .25213 Metetra
.673 .727 .89 r
.53229 .25213 .53775 .25937 .54791 .25568 .54247 .24819 Metetra
.672 .72 .885 r
.54247 .24819 .54791 .25568 .55811 .25173 .55269 .24423 Metetra
.673 .72 .885 r
.55269 .24423 .55811 .25173 .56833 .2473 .56295 .24023 Metetra
.671 .734 .897 r
.56295 .24023 .56833 .2473 .57859 .24311 .57324 .23633 Metetra
.663 .742 .908 r
.57324 .23633 .57859 .24311 .5889 .23945 .58357 .23264 Metetra
.668 .744 .907 r
.58357 .23264 .5889 .23945 .59924 .23563 .59394 .2288 Metetra
.681 .748 .902 r
.59394 .2288 .59924 .23563 .60961 .23147 .60434 .22461 Metetra
.676 .746 .904 r
.60434 .22461 .60961 .23147 .62002 .22741 .61478 .22053 Metetra
.663 .742 .908 r
.61478 .22053 .62002 .22741 .63048 .22369 .62526 .21678 Metetra
.667 .743 .907 r
.62526 .21678 .63048 .22369 .64098 .21985 .63578 .21292 Metetra
.681 .748 .902 r
.63578 .21292 .64098 .21985 .6515 .21563 .64633 .20867 Metetra
.68 .748 .903 r
.64633 .20867 .6515 .21563 .66205 .21133 .65691 .20443 Metetra
.676 .749 .906 r
.65691 .20443 .66205 .21133 .67262 .20675 .66754 .2003 Metetra
.681 .768 .916 r
.66754 .2003 .67262 .20675 .68323 .20219 .67819 .19603 Metetra
.705 .787 .915 r
.67819 .19603 .68323 .20219 .69388 .19776 .68885 .1911 Metetra
.699 .769 .906 r
.68885 .1911 .69388 .19776 .70458 .1934 .69955 .1863 Metetra
.664 .741 .908 r
.69955 .1863 .70458 .1934 .71534 .18956 .71034 .18244 Metetra
.664 .741 .908 r
.71034 .18244 .71534 .18956 .72615 .18571 .72118 .17856 Metetra
.664 .741 .908 r
.72118 .17856 .72615 .18571 .73699 .18184 .73205 .17467 Metetra
.664 .741 .908 r
.73205 .17467 .73699 .18184 .74788 .17796 .74297 .17076 Metetra
.664 .741 .908 r
.74297 .17076 .74788 .17796 .75881 .17407 .75393 .16684 Metetra
.664 .741 .908 r
.75393 .16684 .75881 .17407 .76978 .17016 .76493 .1629 Metetra
.664 .741 .908 r
.76493 .1629 .76978 .17016 .7808 .16623 .77597 .15894 Metetra
.664 .741 .908 r
.77597 .15894 .7808 .16623 .79185 .16229 .78706 .15498 Metetra
.664 .741 .908 r
.1568 .3725 .16309 .37835 .17193 .37518 .16566 .36931 Metetra
.664 .741 .908 r
.16566 .36931 .17193 .37518 .18081 .37201 .17456 .36611 Metetra
.664 .741 .908 r
.17456 .36611 .18081 .37201 .18972 .36882 .18348 .3629 Metetra
.664 .741 .908 r
.18348 .3629 .18972 .36882 .19866 .36562 .19244 .35968 Metetra
.664 .741 .908 r
.19244 .35968 .19866 .36562 .20763 .36241 .20143 .35645 Metetra
.664 .741 .908 r
.20143 .35645 .20763 .36241 .21663 .35918 .21045 .35321 Metetra
.661 .741 .909 r
.21045 .35321 .21663 .35918 .22566 .35595 .21949 .35001 Metetra
.661 .743 .911 r
.21949 .35001 .22566 .35595 .23473 .35271 .22857 .34681 Metetra
.606 .729 .932 r
.22857 .34681 .23473 .35271 .24374 .35037 .23757 .34474 Metetra
.594 .736 .943 r
.23757 .34474 .24374 .35037 .25278 .34816 .2466 .34284 Metetra
.656 .766 .931 r
.2466 .34284 .25278 .34816 .26191 .34533 .25577 .33971 Metetra
.667 .759 .919 r
.25577 .33971 .26191 .34533 .27108 .34236 .265 .33633 Metetra
.65 .741 .915 r
.265 .33633 .27108 .34236 .28028 .33949 .27422 .33332 Metetra
.646 .735 .914 r
.27422 .33332 .28028 .33949 .28951 .33665 .28348 .33038 Metetra
.659 .736 .907 r
.28348 .33038 .28951 .33665 .2988 .33343 .29279 .32713 Metetra
.663 .737 .905 r
.29279 .32713 .2988 .33343 .30813 .33009 .30214 .32377 Metetra
.649 .733 .91 r
.30214 .32377 .30813 .33009 .31748 .32709 .31151 .32075 Metetra
.644 .731 .912 r
.31151 .32075 .31748 .32709 .32685 .3242 .32089 .31783 Metetra
.658 .735 .907 r
.32089 .31783 .32685 .3242 .33627 .32096 .33034 .31457 Metetra
.663 .737 .905 r
.33034 .31457 .33627 .32096 .34574 .31758 .33983 .31117 Metetra
.661 .736 .906 r
.33983 .31117 .34574 .31758 .35523 .31441 .34935 .3078 Metetra
.66 .73 .901 r
.34935 .3078 .35523 .31441 .36475 .31132 .3589 .30444 Metetra
.651 .719 .898 r
.3589 .30444 .36475 .31132 .37431 .30822 .36848 .30128 Metetra
.646 .716 .899 r
.36848 .30128 .37431 .30822 .3839 .30509 .37809 .29822 Metetra
.646 .719 .901 r
.37809 .29822 .3839 .30509 .39354 .30195 .38774 .29516 Metetra
.646 .723 .904 r
.38774 .29516 .39354 .30195 .4032 .2988 .39742 .29208 Metetra
.664 .732 .9 r
.39742 .29208 .4032 .2988 .41291 .29548 .40716 .28857 Metetra
.674 .73 .891 r
.40716 .28857 .41291 .29548 .42266 .29202 .41694 .28473 Metetra
.665 .715 .886 r
.41694 .28473 .42266 .29202 .43244 .28863 .42675 .2811 Metetra
.658 .706 .883 r
.42675 .2811 .43244 .28863 .44226 .28529 .43659 .27764 Metetra
.659 .704 .88 r
.43659 .27764 .44226 .28529 .45212 .28185 .44646 .27413 Metetra
.66 .703 .879 r
.44646 .27413 .45212 .28185 .46201 .27832 .45638 .27058 Metetra
.661 .703 .878 r
.45638 .27058 .46201 .27832 .47194 .2747 .46633 .26698 Metetra
.662 .705 .879 r
.46633 .26698 .47194 .2747 .48191 .27098 .47631 .26333 Metetra
.656 .706 .884 r
.47631 .26333 .48191 .27098 .49191 .26731 .48633 .25985 Metetra
.649 .709 .892 r
.48633 .25985 .49191 .26731 .50195 .26371 .49639 .25658 Metetra
.661 .725 .897 r
.49639 .25658 .50195 .26371 .51203 .25997 .50649 .25299 Metetra
.677 .736 .895 r
.50649 .25299 .51203 .25997 .52214 .25606 .51663 .24895 Metetra
.677 .733 .893 r
.51663 .24895 .52214 .25606 .53229 .25213 .5268 .2449 Metetra
.677 .73 .89 r
.5268 .2449 .53229 .25213 .54247 .24819 .537 .24084 Metetra
.672 .725 .889 r
.537 .24084 .54247 .24819 .55269 .24423 .54725 .23688 Metetra
.664 .723 .893 r
.54725 .23688 .55269 .24423 .56295 .24023 .55753 .23312 Metetra
.664 .732 .9 r
.55753 .23312 .56295 .24023 .57324 .23633 .56785 .22937 Metetra
.663 .737 .905 r
.56785 .22937 .57324 .23633 .58357 .23264 .5782 .22566 Metetra
.668 .739 .903 r
.5782 .22566 .58357 .23264 .59394 .2288 .5886 .22179 Metetra
.68 .743 .899 r
.5886 .22179 .59394 .2288 .60434 .22461 .59902 .21757 Metetra
.676 .742 .9 r
.59902 .21757 .60434 .22461 .61478 .22053 .60949 .21346 Metetra
.663 .737 .905 r
.60949 .21346 .61478 .22053 .62526 .21678 .62 .20969 Metetra
.666 .738 .904 r
.62 .20969 .62526 .21678 .63578 .21292 .63055 .20581 Metetra
.678 .743 .9 r
.63055 .20581 .63578 .21292 .64633 .20867 .64112 .20161 Metetra
.675 .744 .903 r
.64112 .20161 .64633 .20867 .65691 .20443 .65174 .19748 Metetra
.661 .743 .911 r
.65174 .19748 .65691 .20443 .66754 .2003 .66241 .19371 Metetra
.671 .761 .918 r
.66241 .19371 .66754 .2003 .67819 .19603 .67311 .1897 Metetra
.716 .787 .907 r
.67311 .1897 .67819 .19603 .68885 .1911 .68378 .18441 Metetra
.709 .773 .902 r
.68378 .18441 .68885 .1911 .69955 .1863 .6945 .17929 Metetra
.666 .747 .91 r
.6945 .17929 .69955 .1863 .71034 .18244 .70532 .17533 Metetra
.666 .744 .909 r
.70532 .17533 .71034 .18244 .72118 .17856 .71617 .17136 Metetra
.664 .741 .908 r
.71617 .17136 .72118 .17856 .73205 .17467 .72708 .16744 Metetra
.664 .741 .908 r
.72708 .16744 .73205 .17467 .74297 .17076 .73802 .1635 Metetra
.664 .741 .908 r
.73802 .1635 .74297 .17076 .75393 .16684 .74901 .15955 Metetra
.664 .741 .908 r
.74901 .15955 .75393 .16684 .76493 .1629 .76004 .15559 Metetra
.664 .741 .908 r
.76004 .15559 .76493 .1629 .77597 .15894 .77112 .15161 Metetra
.664 .741 .908 r
.77112 .15161 .77597 .15894 .78706 .15498 .78223 .14761 Metetra
.664 .741 .908 r
.15047 .3666 .1568 .3725 .16566 .36931 .15935 .3634 Metetra
.664 .741 .908 r
.15935 .3634 .16566 .36931 .17456 .36611 .16826 .36018 Metetra
.664 .741 .908 r
.16826 .36018 .17456 .36611 .18348 .3629 .17721 .35695 Metetra
.664 .741 .908 r
.17721 .35695 .18348 .3629 .19244 .35968 .18618 .35371 Metetra
.664 .741 .908 r
.18618 .35371 .19244 .35968 .20143 .35645 .19519 .35045 Metetra
.664 .741 .908 r
.19519 .35045 .20143 .35645 .21045 .35321 .20423 .34719 Metetra
.652 .738 .913 r
.20423 .34719 .21045 .35321 .21949 .35001 .21327 .34418 Metetra
.651 .745 .919 r
.21327 .34418 .21949 .35001 .22857 .34681 .22234 .34118 Metetra
.602 .739 .941 r
.22234 .34118 .22857 .34681 .23757 .34474 .23136 .33913 Metetra
.593 .737 .944 r
.23136 .33913 .23757 .34474 .2466 .34284 .24041 .3372 Metetra
.665 .758 .92 r
.24041 .3372 .2466 .34284 .25577 .33971 .24962 .33386 Metetra
.676 .754 .91 r
.24962 .33386 .25577 .33971 .265 .33633 .25888 .33024 Metetra
.66 .742 .911 r
.25888 .33024 .265 .33633 .27422 .33332 .26814 .32697 Metetra
.656 .733 .906 r
.26814 .32697 .27422 .33332 .28348 .33038 .27743 .32379 Metetra
.661 .727 .898 r
.27743 .32379 .28348 .33038 .29279 .32713 .28677 .32046 Metetra
.662 .726 .896 r
.28677 .32046 .29279 .32713 .30214 .32377 .29614 .31708 Metetra
.649 .721 .902 r
.29614 .31708 .30214 .32377 .31151 .32075 .30552 .31403 Metetra
.644 .72 .904 r
.30552 .31403 .31151 .32075 .32089 .31783 .31493 .31109 Metetra
.657 .724 .899 r
.31493 .31109 .32089 .31783 .33034 .31457 .32439 .30781 Metetra
.662 .726 .896 r
.32439 .30781 .33034 .31457 .33983 .31117 .3339 .30439 Metetra
.654 .723 .9 r
.3339 .30439 .33983 .31117 .34935 .3078 .34343 .30115 Metetra
.651 .727 .905 r
.34343 .30115 .34935 .3078 .3589 .30444 .35299 .29799 Metetra
.654 .736 .91 r
.35299 .29799 .3589 .30444 .36848 .30128 .36259 .29474 Metetra
.656 .734 .907 r
.36259 .29474 .36848 .30128 .37809 .29822 .37223 .29144 Metetra
.656 .727 .901 r
.37223 .29144 .37809 .29822 .38774 .29516 .38191 .28812 Metetra
.655 .719 .895 r
.38191 .28812 .38774 .29516 .39742 .29208 .39162 .28479 Metetra
.656 .712 .889 r
.39162 .28479 .39742 .29208 .40716 .28857 .40137 .28142 Metetra
.657 .718 .893 r
.40137 .28142 .40716 .28857 .41694 .28473 .41116 .27802 Metetra
.654 .732 .906 r
.41116 .27802 .41694 .28473 .42675 .2811 .42098 .2747 Metetra
.651 .742 .916 r
.42098 .2747 .42675 .2811 .43659 .27764 .43083 .27145 Metetra
.658 .752 .92 r
.43083 .27145 .43659 .27764 .44646 .27413 .44073 .26803 Metetra
.664 .758 .921 r
.44073 .26803 .44646 .27413 .45638 .27058 .45067 .26445 Metetra
.669 .76 .918 r
.45067 .26445 .45638 .27058 .46633 .26698 .46064 .26072 Metetra
.675 .758 .913 r
.46064 .26072 .46633 .26698 .47631 .26333 .47066 .25681 Metetra
.672 .749 .909 r
.47066 .25681 .47631 .26333 .48633 .25985 .48071 .25297 Metetra
.668 .736 .901 r
.48071 .25297 .48633 .25985 .49639 .25658 .49079 .24922 Metetra
.667 .721 .89 r
.49079 .24922 .49639 .25658 .50649 .25299 .50092 .24543 Metetra
.667 .716 .885 r
.50092 .24543 .50649 .25299 .51663 .24895 .51107 .24159 Metetra
.668 .724 .891 r
.51107 .24159 .51663 .24895 .5268 .2449 .52127 .23775 Metetra
.669 .731 .897 r
.52127 .23775 .5268 .2449 .537 .24084 .5315 .23389 Metetra
.671 .74 .902 r
.5315 .23389 .537 .24084 .54725 .23688 .54177 .22998 Metetra
.674 .743 .902 r
.54177 .22998 .54725 .23688 .55753 .23312 .55207 .22596 Metetra
.67 .734 .898 r
.55207 .22596 .55753 .23312 .56785 .22937 .56241 .22203 Metetra
.662 .726 .896 r
.56241 .22203 .56785 .22937 .5782 .22566 .5728 .21829 Metetra
.667 .728 .895 r
.5728 .21829 .5782 .22566 .5886 .22179 .58321 .2144 Metetra
.679 .732 .89 r
.58321 .2144 .5886 .22179 .59902 .21757 .59366 .21015 Metetra
.675 .731 .892 r
.59366 .21015 .59902 .21757 .60949 .21346 .60415 .20602 Metetra
.662 .726 .896 r
.60415 .20602 .60949 .21346 .62 .20969 .61469 .20222 Metetra
.664 .726 .896 r
.61469 .20222 .62 .20969 .63055 .20581 .62526 .19836 Metetra
.669 .73 .896 r
.62526 .19836 .63055 .20581 .64112 .20161 .63587 .19436 Metetra
.666 .736 .902 r
.63587 .19436 .64112 .20161 .65174 .19748 .64653 .19044 Metetra
.652 .739 .913 r
.64653 .19044 .65174 .19748 .66241 .19371 .65724 .18688 Metetra
.663 .751 .916 r
.65724 .18688 .66241 .19371 .67311 .1897 .66797 .18303 Metetra
.715 .776 .901 r
.66797 .18303 .67311 .1897 .68378 .18441 .67868 .17772 Metetra
.71 .775 .903 r
.67868 .17772 .68378 .18441 .6945 .17929 .68943 .17254 Metetra
.676 .761 .915 r
.68943 .17254 .6945 .17929 .70532 .17533 .70026 .16832 Metetra
.674 .753 .91 r
.70026 .16832 .70532 .17533 .71617 .17136 .71113 .16411 Metetra
.664 .741 .908 r
.71113 .16411 .71617 .17136 .72708 .16744 .72207 .16016 Metetra
.664 .741 .908 r
.72207 .16016 .72708 .16744 .73802 .1635 .73304 .1562 Metetra
.664 .741 .908 r
.73304 .1562 .73802 .1635 .74901 .15955 .74406 .15222 Metetra
.664 .741 .908 r
.74406 .15222 .74901 .15955 .76004 .15559 .75512 .14822 Metetra
.664 .741 .908 r
.75512 .14822 .76004 .15559 .77112 .15161 .76622 .14421 Metetra
.664 .741 .908 r
.76622 .14421 .77112 .15161 .78223 .14761 .77737 .14019 Metetra
.664 .741 .908 r
.1441 .36067 .15047 .3666 .15935 .3634 .153 .35744 Metetra
.664 .741 .908 r
.153 .35744 .15935 .3634 .16826 .36018 .16193 .3542 Metetra
.664 .741 .908 r
.16193 .3542 .16826 .36018 .17721 .35695 .17089 .35095 Metetra
.664 .741 .908 r
.17089 .35095 .17721 .35695 .18618 .35371 .17988 .34769 Metetra
.661 .741 .909 r
.17988 .34769 .18618 .35371 .19519 .35045 .1889 .34447 Metetra
.661 .743 .91 r
.1889 .34447 .19519 .35045 .20423 .34719 .19795 .34125 Metetra
.645 .74 .918 r
.19795 .34125 .20423 .34719 .21327 .34418 .207 .33837 Metetra
.643 .745 .923 r
.207 .33837 .21327 .34418 .22234 .34118 .21607 .33552 Metetra
.609 .742 .939 r
.21607 .33552 .22234 .34118 .23136 .33913 .22512 .33332 Metetra
.605 .735 .937 r
.22512 .33332 .23136 .33913 .24041 .3372 .2342 .3312 Metetra
.667 .747 .91 r
.2342 .3312 .24041 .3372 .24962 .33386 .24343 .32776 Metetra
.677 .747 .904 r
.24343 .32776 .24962 .33386 .25888 .33024 .25272 .32406 Metetra
.666 .743 .907 r
.25272 .32406 .25888 .33024 .26814 .32697 .26202 .32063 Metetra
.663 .737 .905 r
.26202 .32063 .26814 .32697 .27743 .32379 .27134 .31726 Metetra
.663 .731 .9 r
.27134 .31726 .27743 .32379 .28677 .32046 .2807 .31387 Metetra
.663 .73 .899 r
.2807 .31387 .28677 .32046 .29614 .31708 .29009 .31046 Metetra
.649 .725 .905 r
.29009 .31046 .29614 .31708 .30552 .31403 .29949 .3074 Metetra
.644 .724 .907 r
.29949 .3074 .30552 .31403 .31493 .31109 .30891 .30444 Metetra
.657 .728 .902 r
.30891 .30444 .31493 .31109 .32439 .30781 .3184 .30113 Metetra
.663 .73 .9 r
.3184 .30113 .32439 .30781 .3339 .30439 .32792 .29768 Metetra
.652 .726 .904 r
.32792 .29768 .3339 .30439 .34343 .30115 .33747 .2945 Metetra
.646 .727 .908 r
.33747 .2945 .34343 .30115 .35299 .29799 .34704 .29143 Metetra
.657 .734 .907 r
.34704 .29143 .35299 .29799 .36259 .29474 .35667 .28809 Metetra
.663 .734 .903 r
.35667 .28809 .36259 .29474 .37223 .29144 .36634 .28459 Metetra
.664 .729 .898 r
.36634 .28459 .37223 .29144 .38191 .28812 .37604 .28104 Metetra
.664 .722 .892 r
.37604 .28104 .38191 .28812 .39162 .28479 .38579 .27745 Metetra
.654 .712 .89 r
.38579 .27745 .39162 .28479 .40137 .28142 .39555 .27409 Metetra
.648 .71 .893 r
.39555 .27409 .40137 .28142 .41116 .27802 .40535 .27089 Metetra
.65 .718 .898 r
.40535 .27089 .41116 .27802 .42098 .2747 .41519 .26765 Metetra
.651 .721 .9 r
.41519 .26765 .42098 .2747 .43083 .27145 .42506 .26436 Metetra
.657 .723 .898 r
.42506 .26436 .43083 .27145 .44073 .26803 .43498 .26091 Metetra
.662 .725 .896 r
.43498 .26091 .44073 .26803 .45067 .26445 .44494 .25731 Metetra
.667 .727 .894 r
.44494 .25731 .45067 .26445 .46064 .26072 .45494 .25355 Metetra
.673 .729 .892 r
.45494 .25355 .46064 .26072 .47066 .25681 .46498 .24963 Metetra
.674 .729 .892 r
.46498 .24963 .47066 .25681 .48071 .25297 .47505 .24567 Metetra
.674 .727 .889 r
.47505 .24567 .48071 .25297 .49079 .24922 .48516 .24166 Metetra
.667 .717 .886 r
.48516 .24166 .49079 .24922 .50092 .24543 .49531 .23781 Metetra
.659 .713 .888 r
.49531 .23781 .50092 .24543 .51107 .24159 .50549 .23419 Metetra
.66 .721 .894 r
.50549 .23419 .51107 .24159 .52127 .23775 .5157 .23053 Metetra
.662 .728 .898 r
.5157 .23053 .52127 .23775 .5315 .23389 .52596 .22682 Metetra
.668 .736 .901 r
.52596 .22682 .5315 .23389 .54177 .22998 .53625 .22295 Metetra
.678 .742 .899 r
.53625 .22295 .54177 .22998 .55207 .22596 .54658 .21879 Metetra
.673 .736 .898 r
.54658 .21879 .55207 .22596 .56241 .22203 .55694 .21476 Metetra
.663 .73 .9 r
.55694 .21476 .56241 .22203 .5728 .21829 .56735 .21099 Metetra
.668 .732 .898 r
.56735 .21099 .5728 .21829 .58321 .2144 .5778 .20707 Metetra
.679 .736 .893 r
.5778 .20707 .58321 .2144 .59366 .21015 .58827 .2028 Metetra
.675 .735 .895 r
.58827 .2028 .59366 .21015 .60415 .20602 .59879 .19864 Metetra
.663 .73 .899 r
.59879 .19864 .60415 .20602 .61469 .20222 .60935 .19481 Metetra
.663 .73 .899 r
.60935 .19481 .61469 .20222 .62526 .19836 .61995 .19097 Metetra
.663 .731 .9 r
.61995 .19097 .62526 .19836 .63587 .19436 .63059 .18712 Metetra
.661 .736 .906 r
.63059 .18712 .63587 .19436 .64653 .19044 .64128 .18332 Metetra
.65 .737 .913 r
.64128 .18332 .64653 .19044 .65724 .18688 .65202 .17979 Metetra
.66 .742 .911 r
.65202 .17979 .65724 .18688 .66797 .18303 .66279 .17598 Metetra
.707 .762 .895 r
.66279 .17598 .66797 .18303 .67868 .17772 .67353 .17082 Metetra
.705 .768 .901 r
.67353 .17082 .67868 .17772 .68943 .17254 .68432 .16575 Metetra
.682 .764 .913 r
.68432 .16575 .68943 .17254 .70026 .16832 .69517 .16132 Metetra
.68 .757 .91 r
.69517 .16132 .70026 .16832 .71113 .16411 .70607 .15693 Metetra
.666 .746 .91 r
.70607 .15693 .71113 .16411 .72207 .16016 .71703 .15289 Metetra
.666 .744 .909 r
.71703 .15289 .72207 .16016 .73304 .1562 .72803 .14884 Metetra
.664 .741 .908 r
.72803 .14884 .73304 .1562 .74406 .15222 .73907 .14483 Metetra
.664 .741 .908 r
.73907 .14483 .74406 .15222 .75512 .14822 .75016 .14081 Metetra
.664 .741 .908 r
.75016 .14081 .75512 .14822 .76622 .14421 .7613 .13677 Metetra
.664 .741 .908 r
.7613 .13677 .76622 .14421 .77737 .14019 .77247 .13272 Metetra
.664 .741 .908 r
.13769 .3547 .1441 .36067 .153 .35744 .14661 .35145 Metetra
.664 .741 .908 r
.14661 .35145 .153 .35744 .16193 .3542 .15555 .34819 Metetra
.664 .741 .908 r
.15555 .34819 .16193 .3542 .17089 .35095 .16453 .34492 Metetra
.664 .741 .908 r
.16453 .34492 .17089 .35095 .17988 .34769 .17354 .34164 Metetra
.652 .738 .913 r
.17354 .34164 .17988 .34769 .1889 .34447 .18256 .33861 Metetra
.651 .746 .919 r
.18256 .33861 .1889 .34447 .19795 .34125 .1916 .33559 Metetra
.644 .752 .928 r
.1916 .33559 .19795 .34125 .207 .33837 .20066 .33272 Metetra
.643 .752 .928 r
.20066 .33272 .207 .33837 .21607 .33552 .20976 .32985 Metetra
.64 .752 .93 r
.20976 .32985 .21607 .33552 .22512 .33332 .21888 .32703 Metetra
.64 .73 .914 r
.21888 .32703 .22512 .33332 .2342 .3312 .22804 .32421 Metetra
.654 .712 .89 r
.22804 .32421 .2342 .3312 .24343 .32776 .23727 .32102 Metetra
.658 .722 .896 r
.23727 .32102 .24343 .32776 .25272 .32406 .24653 .31775 Metetra
.662 .738 .906 r
.24653 .31775 .25272 .32406 .26202 .32063 .25584 .31439 Metetra
.663 .742 .908 r
.25584 .31439 .26202 .32063 .27134 .31726 .26518 .31099 Metetra
.663 .742 .908 r
.26518 .31099 .27134 .31726 .2807 .31387 .27456 .30758 Metetra
.663 .742 .908 r
.27456 .30758 .2807 .31387 .29009 .31046 .28397 .30415 Metetra
.649 .737 .914 r
.28397 .30415 .29009 .31046 .29949 .3074 .29339 .30106 Metetra
.644 .736 .916 r
.29339 .30106 .29949 .3074 .30891 .30444 .30283 .29808 Metetra
.658 .74 .911 r
.30283 .29808 .30891 .30444 .3184 .30113 .31234 .29475 Metetra
.663 .742 .908 r
.31234 .29475 .3184 .30113 .32792 .29768 .32189 .29128 Metetra
.658 .74 .91 r
.32189 .29128 .32792 .29768 .33747 .2945 .33146 .28792 Metetra
.656 .734 .907 r
.33146 .28792 .33747 .2945 .34704 .29143 .34107 .2846 Metetra
.66 .728 .9 r
.34107 .2846 .34704 .29143 .35667 .28809 .35072 .28115 Metetra
.662 .726 .897 r
.35072 .28115 .35667 .28809 .36634 .28459 .36041 .27763 Metetra
.669 .728 .894 r
.36041 .27763 .36634 .28459 .37604 .28104 .37014 .27391 Metetra
.672 .725 .889 r
.37014 .27391 .37604 .28104 .38579 .27745 .37992 .27007 Metetra
.668 .716 .885 r
.37992 .27007 .38579 .27745 .39555 .27409 .38972 .26632 Metetra
.664 .704 .877 r
.38972 .26632 .39555 .27409 .40535 .27089 .39955 .26264 Metetra
.667 .692 .864 r
.39955 .26264 .40535 .27089 .41519 .26765 .40943 .25878 Metetra
.668 .677 .85 r
.40943 .25878 .41519 .26765 .42506 .26436 .41934 .25477 Metetra
.658 .657 .838 r
.41934 .25477 .42506 .26436 .43498 .26091 .42929 .25096 Metetra
.65 .646 .833 r
.42929 .25096 .43498 .26091 .44494 .25731 .43926 .24733 Metetra
.644 .643 .835 r
.43926 .24733 .44494 .25731 .45494 .25355 .44926 .24389 Metetra
.639 .649 .843 r
.44926 .24389 .45494 .25355 .46498 .24963 .4593 .24063 Metetra
.646 .669 .857 r
.4593 .24063 .46498 .24963 .47505 .24567 .46938 .23724 Metetra
.654 .687 .869 r
.46938 .23724 .47505 .24567 .48516 .24166 .4795 .23366 Metetra
.653 .7 .881 r
.4795 .23366 .48516 .24166 .49531 .23781 .48966 .23016 Metetra
.65 .71 .891 r
.48966 .23016 .49531 .23781 .50549 .23419 .49986 .22674 Metetra
.655 .719 .895 r
.49986 .22674 .50549 .23419 .5157 .23053 .5101 .22319 Metetra
.662 .726 .897 r
.5101 .22319 .5157 .23053 .52596 .22682 .52038 .21946 Metetra
.665 .727 .896 r
.52038 .21946 .52596 .22682 .53625 .22295 .53069 .21564 Metetra
.669 .731 .896 r
.53069 .21564 .53625 .22295 .54658 .21879 .54105 .21169 Metetra
.668 .738 .903 r
.54105 .21169 .54658 .21879 .55694 .21476 .55144 .20779 Metetra
.663 .742 .908 r
.55144 .20779 .55694 .21476 .56735 .21099 .56188 .204 Metetra
.668 .744 .906 r
.56188 .204 .56735 .21099 .5778 .20707 .57235 .20005 Metetra
.681 .748 .902 r
.57235 .20005 .5778 .20707 .58827 .2028 .58285 .19575 Metetra
.676 .746 .904 r
.58285 .19575 .58827 .2028 .59879 .19864 .59339 .19156 Metetra
.663 .742 .908 r
.59339 .19156 .59879 .19864 .60935 .19481 .60398 .18771 Metetra
.663 .742 .908 r
.60398 .18771 .60935 .19481 .61995 .19097 .61461 .18384 Metetra
.663 .742 .908 r
.61461 .18384 .61995 .19097 .63059 .18712 .62528 .17996 Metetra
.664 .742 .908 r
.62528 .17996 .63059 .18712 .64128 .18332 .63599 .17604 Metetra
.667 .74 .905 r
.63599 .17604 .64128 .18332 .65202 .17979 .64673 .17202 Metetra
.668 .726 .892 r
.64673 .17202 .65202 .17979 .66279 .17598 .65752 .16791 Metetra
.679 .722 .881 r
.65752 .16791 .66279 .17598 .67353 .17082 .66832 .16342 Metetra
.682 .744 .898 r
.66832 .16342 .67353 .17082 .68432 .16575 .67917 .15893 Metetra
.682 .765 .914 r
.67917 .15893 .68432 .16575 .69517 .16132 .69006 .15447 Metetra
.681 .764 .914 r
.69006 .15447 .69517 .16132 .70607 .15693 .70098 .15003 Metetra
.675 .761 .916 r
.70098 .15003 .70607 .15693 .71703 .15289 .71196 .14573 Metetra
.674 .753 .91 r
.71196 .14573 .71703 .15289 .72803 .14884 .72297 .14143 Metetra
.664 .741 .908 r
.72297 .14143 .72803 .14884 .73907 .14483 .73405 .13739 Metetra
.664 .741 .908 r
.73405 .13739 .73907 .14483 .75016 .14081 .74517 .13334 Metetra
.664 .741 .908 r
.74517 .13334 .75016 .14081 .7613 .13677 .75634 .12927 Metetra
.664 .741 .908 r
.75634 .12927 .7613 .13677 .77247 .13272 .76754 .12519 Metetra
.664 .741 .908 r
.13124 .3487 .13769 .3547 .14661 .35145 .14017 .34543 Metetra
.664 .741 .908 r
.14017 .34543 .14661 .35145 .15555 .34819 .14914 .34214 Metetra
.664 .741 .908 r
.14914 .34214 .15555 .34819 .16453 .34492 .15813 .33885 Metetra
.664 .741 .908 r
.15813 .33885 .16453 .34492 .17354 .34164 .16716 .33555 Metetra
.645 .736 .916 r
.16716 .33555 .17354 .34164 .18256 .33861 .17618 .33266 Metetra
.643 .742 .921 r
.17618 .33266 .18256 .33861 .1916 .33559 .18522 .3298 Metetra
.641 .747 .926 r
.18522 .3298 .1916 .33559 .20066 .33272 .19429 .32697 Metetra
.64 .75 .928 r
.19429 .32697 .20066 .33272 .20976 .32985 .2034 .32413 Metetra
.663 .757 .92 r
.2034 .32413 .20976 .32985 .21888 .32703 .21259 .32079 Metetra
.665 .741 .906 r
.21259 .32079 .21888 .32703 .22804 .32421 .22183 .31736 Metetra
.647 .716 .898 r
.22183 .31736 .22804 .32421 .23727 .32102 .23105 .31436 Metetra
.643 .721 .905 r
.23105 .31436 .23727 .32102 .24653 .31775 .2403 .31142 Metetra
.66 .738 .908 r
.2403 .31142 .24653 .31775 .25584 .31439 .24962 .3081 Metetra
.663 .742 .908 r
.24962 .3081 .25584 .31439 .26518 .31099 .25899 .30468 Metetra
.663 .742 .908 r
.25899 .30468 .26518 .31099 .27456 .30758 .26838 .30125 Metetra
.663 .742 .908 r
.26838 .30125 .27456 .30758 .28397 .30415 .27781 .2978 Metetra
.651 .738 .913 r
.27781 .2978 .28397 .30415 .29339 .30106 .28725 .29465 Metetra
.646 .735 .914 r
.28725 .29465 .29339 .30106 .30283 .29808 .29672 .29159 Metetra
.658 .737 .908 r
.29672 .29159 .30283 .29808 .31234 .29475 .30625 .28823 Metetra
.663 .738 .906 r
.30625 .28823 .31234 .29475 .32189 .29128 .31582 .28473 Metetra
.663 .738 .906 r
.31582 .28473 .32189 .29128 .33146 .28792 .32542 .28122 Metetra
.663 .734 .903 r
.32542 .28122 .33146 .28792 .34107 .2846 .33506 .2777 Metetra
.665 .729 .897 r
.33506 .2777 .34107 .2846 .35072 .28115 .34474 .2741 Metetra
.666 .725 .893 r
.34474 .2741 .35072 .28115 .36041 .27763 .35445 .27045 Metetra
.674 .724 .888 r
.35445 .27045 .36041 .27763 .37014 .27391 .36421 .26656 Metetra
.678 .721 .882 r
.36421 .26656 .37014 .27391 .37992 .27007 .37402 .26252 Metetra
.676 .715 .878 r
.37402 .26252 .37992 .27007 .38972 .26632 .38385 .25849 Metetra
.674 .707 .873 r
.38385 .25849 .38972 .26632 .39955 .26264 .39372 .25447 Metetra
.679 .701 .863 r
.39372 .25447 .39955 .26264 .40943 .25878 .40363 .25021 Metetra
.683 .692 .852 r
.40363 .25021 .40943 .25878 .41934 .25477 .41357 .24575 Metetra
.667 .675 .848 r
.41357 .24575 .41934 .25477 .42929 .25096 .42354 .24171 Metetra
.654 .665 .848 r
.42354 .24171 .42929 .25096 .43926 .24733 .43353 .23805 Metetra
.641 .659 .852 r
.43353 .23805 .43926 .24733 .44926 .24389 .44354 .23478 Metetra
.627 .658 .861 r
.44354 .23478 .44926 .24389 .4593 .24063 .45358 .23194 Metetra
.635 .673 .869 r
.45358 .23194 .4593 .24063 .46938 .23724 .46367 .22889 Metetra
.644 .687 .876 r
.46367 .22889 .46938 .23724 .4795 .23366 .47381 .2256 Metetra
.644 .696 .883 r
.47381 .2256 .4795 .23366 .48966 .23016 .48398 .22232 Metetra
.643 .703 .89 r
.48398 .22232 .48966 .23016 .49986 .22674 .4942 .21906 Metetra
.649 .711 .893 r
.4942 .21906 .49986 .22674 .5101 .22319 .50446 .21564 Metetra
.658 .719 .894 r
.50446 .21564 .5101 .22319 .52038 .21946 .51476 .21198 Metetra
.66 .723 .896 r
.51476 .21198 .52038 .21946 .53069 .21564 .5251 .20827 Metetra
.662 .728 .898 r
.5251 .20827 .53069 .21564 .54105 .21169 .53548 .20448 Metetra
.663 .734 .903 r
.53548 .20448 .54105 .21169 .55144 .20779 .5459 .20067 Metetra
.663 .738 .906 r
.5459 .20067 .55144 .20779 .56188 .204 .55636 .19685 Metetra
.668 .74 .904 r
.55636 .19685 .56188 .204 .57235 .20005 .56686 .19289 Metetra
.679 .744 .9 r
.56686 .19289 .57235 .20005 .58285 .19575 .57739 .18862 Metetra
.675 .745 .903 r
.57739 .18862 .58285 .19575 .59339 .19156 .58796 .18444 Metetra
.663 .742 .908 r
.58796 .18444 .59339 .19156 .60398 .18771 .59857 .18056 Metetra
.663 .742 .908 r
.59857 .18056 .60398 .18771 .61461 .18384 .60923 .17666 Metetra
.663 .742 .908 r
.60923 .17666 .61461 .18384 .62528 .17996 .61993 .17275 Metetra
.667 .743 .907 r
.61993 .17275 .62528 .17996 .63599 .17604 .63066 .16874 Metetra
.68 .746 .9 r
.63066 .16874 .63599 .17604 .64673 .17202 .64142 .16432 Metetra
.676 .733 .893 r
.64142 .16432 .64673 .17202 .65752 .16791 .65222 .15997 Metetra
.66 .72 .893 r
.65222 .15997 .65752 .16791 .66832 .16342 .66308 .15606 Metetra
.664 .74 .907 r
.66308 .15606 .66832 .16342 .67917 .15893 .67398 .15205 Metetra
.684 .765 .913 r
.67398 .15205 .67917 .15893 .69006 .15447 .6849 .14752 Metetra
.684 .763 .912 r
.6849 .14752 .69006 .15447 .70098 .15003 .69585 .14297 Metetra
.682 .76 .911 r
.69585 .14297 .70098 .15003 .71196 .14573 .70685 .13846 Metetra
.68 .754 .907 r
.70685 .13846 .71196 .14573 .72297 .14143 .71788 .13396 Metetra
.664 .741 .908 r
.71788 .13396 .72297 .14143 .73405 .13739 .72899 .1299 Metetra
.664 .741 .908 r
.72899 .1299 .73405 .13739 .74517 .13334 .74014 .12582 Metetra
.664 .741 .908 r
.74014 .12582 .74517 .13334 .75634 .12927 .75134 .12172 Metetra
.664 .741 .908 r
.75134 .12172 .75634 .12927 .76754 .12519 .76258 .11761 Metetra
.664 .741 .908 r
.12474 .34265 .13124 .3487 .14017 .34543 .1337 .33936 Metetra
.664 .741 .908 r
.1337 .33936 .14017 .34543 .14914 .34214 .14268 .33606 Metetra
.664 .741 .908 r
.14268 .33606 .14914 .34214 .15813 .33885 .15169 .33274 Metetra
.664 .741 .908 r
.15169 .33274 .15813 .33885 .16716 .33555 .16074 .32942 Metetra
.645 .736 .916 r
.16074 .32942 .16716 .33555 .17618 .33266 .16977 .32651 Metetra
.643 .736 .916 r
.16977 .32651 .17618 .33266 .18522 .3298 .17883 .32362 Metetra
.631 .732 .921 r
.17883 .32362 .18522 .3298 .19429 .32697 .1879 .32098 Metetra
.63 .739 .926 r
.1879 .32098 .19429 .32697 .2034 .32413 .197 .31835 Metetra
.67 .758 .917 r
.197 .31835 .2034 .32413 .21259 .32079 .20623 .31481 Metetra
.675 .754 .91 r
.20623 .31481 .21259 .32079 .22183 .31736 .21551 .31114 Metetra
.649 .739 .915 r
.21551 .31114 .22183 .31736 .23105 .31436 .22475 .30807 Metetra
.643 .736 .916 r
.22475 .30807 .23105 .31436 .2403 .31142 .23402 .30512 Metetra
.66 .741 .91 r
.23402 .30512 .2403 .31142 .24962 .3081 .24336 .30178 Metetra
.663 .742 .908 r
.24336 .30178 .24962 .3081 .25899 .30468 .25275 .29833 Metetra
.663 .742 .908 r
.25275 .29833 .25899 .30468 .26838 .30125 .26216 .29487 Metetra
.663 .742 .908 r
.26216 .29487 .26838 .30125 .27781 .2978 .27161 .2914 Metetra
.658 .74 .91 r
.27161 .2914 .27781 .2978 .28725 .29465 .28109 .28806 Metetra
.655 .734 .907 r
.28109 .28806 .28725 .29465 .29672 .29159 .29059 .28475 Metetra
.66 .727 .899 r
.29059 .28475 .29672 .29159 .30625 .28823 .30014 .2813 Metetra
.662 .726 .897 r
.30014 .2813 .30625 .28823 .31582 .28473 .30973 .27778 Metetra
.662 .726 .897 r
.30973 .27778 .31582 .28473 .32542 .28122 .31935 .27424 Metetra
.662 .726 .897 r
.31935 .27424 .32542 .28122 .33506 .2777 .32901 .2707 Metetra
.676 .73 .891 r
.32901 .2707 .33506 .2777 .34474 .2741 .33873 .26677 Metetra
.681 .723 .881 r
.33873 .26677 .34474 .2741 .35445 .27045 .34849 .26264 Metetra
.677 .708 .871 r
.34849 .26264 .35445 .27045 .36421 .26656 .35828 .25854 Metetra
.675 .702 .868 r
.35828 .25854 .36421 .26656 .37402 .26252 .3681 .25448 Metetra
.669 .7 .87 r
.3681 .25448 .37402 .26252 .38385 .25849 .37795 .25056 Metetra
.666 .703 .874 r
.37795 .25056 .38385 .25849 .39372 .25447 .38782 .24675 Metetra
.67 .711 .879 r
.38782 .24675 .39372 .25447 .40363 .25021 .39774 .24282 Metetra
.675 .723 .886 r
.39774 .24282 .40363 .25021 .41357 .24575 .40769 .23879 Metetra
.67 .736 .9 r
.40769 .23879 .41357 .24575 .42354 .24171 .41767 .23495 Metetra
.664 .741 .908 r
.41767 .23495 .42354 .24171 .43353 .23805 .42768 .23126 Metetra
.656 .739 .911 r
.42768 .23126 .43353 .23805 .44354 .23478 .43773 .22775 Metetra
.648 .729 .908 r
.43773 .22775 .44354 .23478 .45358 .23194 .4478 .22442 Metetra
.651 .715 .895 r
.4478 .22442 .45358 .23194 .46367 .22889 .45792 .22098 Metetra
.654 .705 .885 r
.45792 .22098 .46367 .22889 .47381 .2256 .46808 .21744 Metetra
.649 .696 .881 r
.46808 .21744 .47381 .2256 .48398 .22232 .47828 .21399 Metetra
.642 .69 .879 r
.47828 .21399 .48398 .22232 .4942 .21906 .48851 .2107 Metetra
.641 .689 .88 r
.48851 .2107 .4942 .21906 .50446 .21564 .49879 .20744 Metetra
.639 .694 .885 r
.49879 .20744 .50446 .21564 .51476 .21198 .50911 .20422 Metetra
.648 .711 .894 r
.50911 .20422 .51476 .21198 .5251 .20827 .51947 .20078 Metetra
.662 .726 .897 r
.51947 .20078 .5251 .20827 .53548 .20448 .52988 .19696 Metetra
.662 .726 .897 r
.52988 .19696 .53548 .20448 .5459 .20067 .54032 .19313 Metetra
.662 .726 .897 r
.54032 .19313 .5459 .20067 .55636 .19685 .5508 .18928 Metetra
.664 .727 .896 r
.5508 .18928 .55636 .19685 .56686 .19289 .56133 .18536 Metetra
.669 .731 .896 r
.56133 .18536 .56686 .19289 .57739 .18862 .57189 .1813 Metetra
.668 .738 .902 r
.57189 .1813 .57739 .18862 .58796 .18444 .58249 .17726 Metetra
.663 .742 .908 r
.58249 .17726 .58796 .18444 .59857 .18056 .59313 .17336 Metetra
.663 .742 .908 r
.59313 .17336 .59857 .18056 .60923 .17666 .60381 .16943 Metetra
.663 .742 .908 r
.60381 .16943 .60923 .17666 .61993 .17275 .61454 .1655 Metetra
.667 .743 .907 r
.61454 .1655 .61993 .17275 .63066 .16874 .6253 .16145 Metetra
.681 .748 .902 r
.6253 .16145 .63066 .16874 .64142 .16432 .63609 .15701 Metetra
.676 .746 .904 r
.63609 .15701 .64142 .16432 .65222 .15997 .64692 .15267 Metetra
.653 .738 .912 r
.64692 .15267 .65222 .15997 .66308 .15606 .65782 .14896 Metetra
.658 .748 .917 r
.65782 .14896 .66308 .15606 .67398 .15205 .66876 .14509 Metetra
.692 .767 .909 r
.66876 .14509 .67398 .15205 .6849 .14752 .67969 .1403 Metetra
.69 .759 .904 r
.67969 .1403 .6849 .14752 .69585 .14297 .69067 .13551 Metetra
.681 .748 .902 r
.69067 .13551 .69585 .14297 .70685 .13846 .70169 .13097 Metetra
.68 .748 .903 r
.70169 .13097 .70685 .13846 .71788 .13396 .71276 .12645 Metetra
.664 .741 .908 r
.71276 .12645 .71788 .13396 .72899 .1299 .7239 .12235 Metetra
.664 .741 .908 r
.7239 .12235 .72899 .1299 .74014 .12582 .73508 .11824 Metetra
.664 .741 .908 r
.73508 .11824 .74014 .12582 .75134 .12172 .7463 .11411 Metetra
.664 .741 .908 r
.7463 .11411 .75134 .12172 .76258 .11761 .75757 .10997 Metetra
.664 .741 .908 r
.11821 .33656 .12474 .34265 .1337 .33936 .12718 .33325 Metetra
.664 .741 .908 r
.12718 .33325 .1337 .33936 .14268 .33606 .13618 .32993 Metetra
.664 .741 .908 r
.13618 .32993 .14268 .33606 .15169 .33274 .14521 .32659 Metetra
.664 .741 .908 r
.14521 .32659 .15169 .33274 .16074 .32942 .15428 .32324 Metetra
.643 .736 .916 r
.15428 .32324 .16074 .32942 .16977 .32651 .16332 .32036 Metetra
.641 .737 .918 r
.16332 .32036 .16977 .32651 .17883 .32362 .17239 .31749 Metetra
.627 .734 .924 r
.17239 .31749 .17883 .32362 .1879 .32098 .18147 .31492 Metetra
.625 .737 .927 r
.18147 .31492 .1879 .32098 .197 .31835 .19058 .31236 Metetra
.676 .754 .91 r
.19058 .31236 .197 .31835 .20623 .31481 .19984 .30866 Metetra
.682 .75 .903 r
.19984 .30866 .20623 .31481 .21551 .31114 .20916 .30478 Metetra
.65 .736 .912 r
.20916 .30478 .21551 .31114 .22475 .30807 .21842 .30166 Metetra
.643 .733 .914 r
.21842 .30166 .22475 .30807 .23402 .30512 .22771 .29868 Metetra
.659 .737 .907 r
.22771 .29868 .23402 .30512 .24336 .30178 .23707 .29532 Metetra
.663 .738 .906 r
.23707 .29532 .24336 .30178 .25275 .29833 .24647 .29185 Metetra
.66 .738 .907 r
.24647 .29185 .25275 .29833 .26216 .29487 .2559 .28844 Metetra
.66 .74 .909 r
.2559 .28844 .26216 .29487 .27161 .2914 .26537 .28503 Metetra
.664 .744 .91 r
.26537 .28503 .27161 .2914 .28109 .28806 .27487 .28152 Metetra
.665 .739 .905 r
.27487 .28152 .28109 .28806 .29059 .28475 .28442 .27795 Metetra
.666 .732 .899 r
.28442 .27795 .29059 .28475 .30014 .2813 .294 .27435 Metetra
.666 .728 .896 r
.294 .27435 .30014 .2813 .30973 .27778 .30361 .27071 Metetra
.664 .725 .894 r
.30361 .27071 .30973 .27778 .31935 .27424 .31326 .2671 Metetra
.664 .723 .893 r
.31326 .2671 .31935 .27424 .32901 .2707 .32294 .26348 Metetra
.682 .727 .884 r
.32294 .26348 .32901 .2707 .33873 .26677 .33269 .25934 Metetra
.69 .724 .875 r
.33269 .25934 .33873 .26677 .34849 .26264 .34249 .25489 Metetra
.68 .712 .873 r
.34249 .25489 .34849 .26264 .35828 .25854 .3523 .25069 Metetra
.674 .708 .873 r
.3523 .25069 .35828 .25854 .3681 .25448 .36214 .24664 Metetra
.666 .706 .877 r
.36214 .24664 .3681 .25448 .37795 .25056 .372 .24283 Metetra
.66 .708 .883 r
.372 .24283 .37795 .25056 .38782 .24675 .38189 .23918 Metetra
.661 .714 .887 r
.38189 .23918 .38782 .24675 .39774 .24282 .39181 .23551 Metetra
.662 .723 .894 r
.39181 .23551 .39774 .24282 .40769 .23879 .40177 .23183 Metetra
.663 .735 .903 r
.40177 .23183 .40769 .23879 .41767 .23495 .41177 .22814 Metetra
.664 .741 .908 r
.41177 .22814 .41767 .23495 .42768 .23126 .4218 .22443 Metetra
.664 .741 .908 r
.4218 .22443 .42768 .23126 .43773 .22775 .43187 .22071 Metetra
.663 .735 .903 r
.43187 .22071 .43773 .22775 .4478 .22442 .44198 .21698 Metetra
.662 .723 .894 r
.44198 .21698 .4478 .22442 .45792 .22098 .45213 .21323 Metetra
.661 .714 .887 r
.45213 .21323 .45792 .22098 .46808 .21744 .46231 .20947 Metetra
.654 .706 .885 r
.46231 .20947 .46808 .21744 .47828 .21399 .47253 .20587 Metetra
.645 .698 .885 r
.47253 .20587 .47828 .21399 .48851 .2107 .48279 .20251 Metetra
.638 .694 .886 r
.48279 .20251 .48851 .2107 .49879 .20744 .49309 .1993 Metetra
.629 .693 .891 r
.49309 .1993 .49879 .20744 .50911 .20422 .50342 .19634 Metetra
.64 .706 .894 r
.50342 .19634 .50911 .20422 .51947 .20078 .51381 .19308 Metetra
.66 .72 .893 r
.51381 .19308 .51947 .20078 .52988 .19696 .52423 .18928 Metetra
.66 .721 .894 r
.52423 .18928 .52988 .19696 .54032 .19313 .5347 .18548 Metetra
.659 .723 .896 r
.5347 .18548 .54032 .19313 .5508 .18928 .54521 .18169 Metetra
.659 .726 .898 r
.54521 .18169 .5508 .18928 .56133 .18536 .55576 .17788 Metetra
.661 .73 .901 r
.55576 .17788 .56133 .18536 .57189 .1813 .56635 .17402 Metetra
.663 .739 .906 r
.56635 .17402 .57189 .1813 .58249 .17726 .57698 .17011 Metetra
.667 .745 .909 r
.57698 .17011 .58249 .17726 .59313 .17336 .58764 .16608 Metetra
.666 .742 .907 r
.58764 .16608 .59313 .17336 .60381 .16943 .59835 .16206 Metetra
.663 .738 .906 r
.59835 .16206 .60381 .16943 .61454 .1655 .60911 .15809 Metetra
.667 .74 .905 r
.60911 .15809 .61454 .1655 .6253 .16145 .6199 .15402 Metetra
.68 .745 .9 r
.6199 .15402 .6253 .16145 .63609 .15701 .63071 .14955 Metetra
.675 .743 .902 r
.63071 .14955 .63609 .15701 .64692 .15267 .64158 .14521 Metetra
.645 .732 .912 r
.64158 .14521 .64692 .15267 .65782 .14896 .65251 .14166 Metetra
.652 .741 .915 r
.65251 .14166 .65782 .14896 .66876 .14509 .66349 .13792 Metetra
.695 .763 .904 r
.66349 .13792 .66876 .14509 .67969 .1403 .67445 .133 Metetra
.693 .759 .902 r
.67445 .133 .67969 .1403 .69067 .13551 .68545 .12809 Metetra
.683 .752 .904 r
.68545 .12809 .69067 .13551 .70169 .13097 .6965 .12347 Metetra
.681 .75 .903 r
.6965 .12347 .70169 .13097 .71276 .12645 .7076 .11887 Metetra
.664 .741 .908 r
.7076 .11887 .71276 .12645 .7239 .12235 .71876 .11475 Metetra
.664 .741 .908 r
.71876 .11475 .7239 .12235 .73508 .11824 .72998 .11061 Metetra
.664 .741 .908 r
.72998 .11061 .73508 .11824 .7463 .11411 .74123 .10645 Metetra
.664 .741 .908 r
.74123 .10645 .7463 .11411 .75757 .10997 .75253 .10228 Metetra
.664 .741 .908 r
.11163 .33044 .11821 .33656 .12718 .33325 .12062 .32711 Metetra
.664 .741 .908 r
.12062 .32711 .12718 .33325 .13618 .32993 .12964 .32376 Metetra
.664 .741 .908 r
.12964 .32376 .13618 .32993 .14521 .32659 .13869 .3204 Metetra
.664 .741 .908 r
.13869 .3204 .14521 .32659 .15428 .32324 .14777 .31703 Metetra
.633 .733 .92 r
.14777 .31703 .15428 .32324 .16332 .32036 .1568 .31434 Metetra
.63 .74 .927 r
.1568 .31434 .16332 .32036 .17239 .31749 .16587 .31168 Metetra
.645 .752 .927 r
.16587 .31168 .17239 .31749 .18147 .31492 .17501 .30869 Metetra
.647 .739 .916 r
.17501 .30869 .18147 .31492 .19058 .31236 .18418 .30566 Metetra
.676 .732 .892 r
.18418 .30566 .19058 .31236 .19984 .30866 .19347 .30187 Metetra
.68 .731 .889 r
.19347 .30187 .19984 .30866 .20916 .30478 .20281 .29797 Metetra
.65 .722 .902 r
.20281 .29797 .20916 .30478 .21842 .30166 .21209 .29483 Metetra
.643 .72 .904 r
.21209 .29483 .21842 .30166 .22771 .29868 .2214 .29183 Metetra
.659 .725 .898 r
.2214 .29183 .22771 .29868 .23707 .29532 .23077 .28844 Metetra
.662 .726 .897 r
.23077 .28844 .23707 .29532 .24647 .29185 .2402 .28495 Metetra
.645 .721 .903 r
.2402 .28495 .24647 .29185 .2559 .28844 .24961 .28187 Metetra
.64 .731 .914 r
.24961 .28187 .2559 .28844 .26537 .28503 .25906 .2789 Metetra
.666 .754 .916 r
.25906 .2789 .26537 .28503 .27487 .28152 .26859 .27531 Metetra
.675 .755 .911 r
.26859 .27531 .27487 .28152 .28442 .27795 .27817 .27149 Metetra
.682 .749 .902 r
.27817 .27149 .28442 .27795 .294 .27435 .2878 .26747 Metetra
.683 .737 .891 r
.2878 .26747 .294 .27435 .30361 .27071 .29747 .26335 Metetra
.674 .72 .883 r
.29747 .26335 .30361 .27071 .31326 .2671 .30716 .2594 Metetra
.67 .709 .878 r
.30716 .2594 .31326 .2671 .32294 .26348 .31687 .25553 Metetra
.671 .703 .871 r
.31687 .25553 .32294 .26348 .33269 .25934 .32663 .25158 Metetra
.673 .71 .876 r
.32663 .25158 .33269 .25934 .34249 .25489 .33642 .24757 Metetra
.672 .723 .888 r
.33642 .24757 .34249 .25489 .3523 .25069 .34624 .24366 Metetra
.67 .733 .897 r
.34624 .24366 .3523 .25069 .36214 .24664 .35608 .23982 Metetra
.666 .739 .904 r
.35608 .23982 .36214 .24664 .372 .24283 .36596 .23608 Metetra
.664 .741 .908 r
.36596 .23608 .372 .24283 .38189 .23918 .37587 .2324 Metetra
.664 .741 .908 r
.37587 .2324 .38189 .23918 .39181 .23551 .38581 .22871 Metetra
.664 .741 .908 r
.38581 .22871 .39181 .23551 .40177 .23183 .3958 .225 Metetra
.664 .741 .908 r
.3958 .225 .40177 .23183 .41177 .22814 .40582 .22129 Metetra
.664 .741 .908 r
.40582 .22129 .41177 .22814 .4218 .22443 .41587 .21756 Metetra
.664 .741 .908 r
.41587 .21756 .4218 .22443 .43187 .22071 .42597 .21381 Metetra
.664 .741 .908 r
.42597 .21381 .43187 .22071 .44198 .21698 .4361 .21005 Metetra
.664 .741 .908 r
.4361 .21005 .44198 .21698 .45213 .21323 .44627 .20628 Metetra
.664 .741 .908 r
.44627 .20628 .45213 .21323 .46231 .20947 .45648 .20249 Metetra
.66 .74 .909 r
.45648 .20249 .46231 .20947 .47253 .20587 .46673 .19877 Metetra
.656 .735 .908 r
.46673 .19877 .47253 .20587 .48279 .20251 .47701 .19515 Metetra
.652 .727 .903 r
.47701 .19515 .48279 .20251 .49309 .1993 .48734 .19159 Metetra
.647 .715 .897 r
.48734 .19159 .49309 .1993 .50342 .19634 .4977 .18813 Metetra
.648 .701 .885 r
.4977 .18813 .50342 .19634 .51381 .19308 .50811 .18462 Metetra
.65 .695 .879 r
.50811 .18462 .51381 .19308 .52423 .18928 .51855 .18103 Metetra
.647 .701 .886 r
.51855 .18103 .52423 .18928 .5347 .18548 .52904 .17751 Metetra
.641 .708 .895 r
.52904 .17751 .5347 .18548 .54521 .18169 .53958 .17416 Metetra
.644 .724 .906 r
.53958 .17416 .54521 .18169 .55576 .17788 .55015 .17072 Metetra
.653 .74 .914 r
.55015 .17072 .55576 .17788 .56635 .17402 .56077 .16707 Metetra
.661 .751 .917 r
.56077 .16707 .56635 .17402 .57698 .17011 .57143 .16319 Metetra
.685 .761 .909 r
.57143 .16319 .57698 .17011 .58764 .16608 .58212 .15866 Metetra
.679 .744 .9 r
.58212 .15866 .58764 .16608 .59835 .16206 .59285 .15425 Metetra
.662 .726 .897 r
.59285 .15425 .59835 .16206 .60911 .15809 .60363 .15026 Metetra
.665 .727 .895 r
.60363 .15026 .60911 .15809 .6199 .15402 .61444 .14615 Metetra
.679 .732 .891 r
.61444 .14615 .6199 .15402 .63071 .14955 .62529 .14165 Metetra
.674 .73 .893 r
.62529 .14165 .63071 .14955 .64158 .14521 .63618 .13728 Metetra
.645 .719 .902 r
.63618 .13728 .64158 .14521 .65251 .14166 .64714 .13371 Metetra
.649 .72 .901 r
.64714 .13371 .65251 .14166 .66349 .13792 .65815 .13 Metetra
.676 .733 .893 r
.65815 .13 .66349 .13792 .67445 .133 .66916 .12551 Metetra
.679 .749 .904 r
.66916 .12551 .67445 .133 .68545 .12809 .68021 .12098 Metetra
.692 .768 .91 r
.68021 .12098 .68545 .12809 .6965 .12347 .69128 .1161 Metetra
.689 .759 .905 r
.69128 .1161 .6965 .12347 .7076 .11887 .7024 .11125 Metetra
.664 .741 .908 r
.7024 .11125 .7076 .11887 .71876 .11475 .71359 .10709 Metetra
.664 .741 .908 r
.71359 .10709 .71876 .11475 .72998 .11061 .72484 .10292 Metetra
.664 .741 .908 r
.72484 .10292 .72998 .11061 .74123 .10645 .73612 .09873 Metetra
.664 .741 .908 r
.73612 .09873 .74123 .10645 .75253 .10228 .74745 .09453 Metetra
.664 .741 .908 r
.10501 .32427 .11163 .33044 .12062 .32711 .11401 .32092 Metetra
.664 .741 .908 r
.11401 .32092 .12062 .32711 .12964 .32376 .12305 .31755 Metetra
.661 .741 .909 r
.12305 .31755 .12964 .32376 .13869 .3204 .13211 .31424 Metetra
.661 .743 .911 r
.13211 .31424 .13869 .3204 .14777 .31703 .1412 .31092 Metetra
.627 .736 .926 r
.1412 .31092 .14777 .31703 .1568 .31434 .15024 .30832 Metetra
.624 .739 .93 r
.15024 .30832 .1568 .31434 .16587 .31168 .15931 .30576 Metetra
.659 .753 .92 r
.15931 .30576 .16587 .31168 .17501 .30869 .1685 .30245 Metetra
.662 .744 .911 r
.1685 .30245 .17501 .30869 .18418 .30566 .17773 .29905 Metetra
.678 .736 .895 r
.17773 .29905 .18418 .30566 .19347 .30187 .18705 .29519 Metetra
.68 .736 .892 r
.18705 .29519 .19347 .30187 .20281 .29797 .1964 .29126 Metetra
.65 .727 .905 r
.1964 .29126 .20281 .29797 .21209 .29483 .2057 .2881 Metetra
.643 .725 .908 r
.2057 .2881 .21209 .29483 .2214 .29183 .21503 .28508 Metetra
.66 .73 .901 r
.21503 .28508 .2214 .29183 .23077 .28844 .22442 .28164 Metetra
.664 .73 .899 r
.22442 .28164 .23077 .28844 .2402 .28495 .23387 .27808 Metetra
.636 .721 .909 r
.23387 .27808 .2402 .28495 .24961 .28187 .24328 .27519 Metetra
.627 .724 .917 r
.24328 .27519 .24961 .28187 .25906 .2789 .25272 .27247 Metetra
.669 .746 .908 r
.25272 .27247 .25906 .2789 .26859 .27531 .26228 .26878 Metetra
.682 .747 .901 r
.26228 .26878 .26859 .27531 .27817 .27149 .2719 .26475 Metetra
.691 .744 .892 r
.2719 .26475 .27817 .27149 .2878 .26747 .28158 .26042 Metetra
.693 .736 .884 r
.28158 .26042 .2878 .26747 .29747 .26335 .29129 .25596 Metetra
.681 .723 .881 r
.29129 .25596 .29747 .26335 .30716 .2594 .30101 .25179 Metetra
.676 .715 .878 r
.30101 .25179 .30716 .2594 .31687 .25553 .31076 .24774 Metetra
.665 .707 .879 r
.31076 .24774 .31687 .25553 .32663 .25158 .32052 .24395 Metetra
.661 .711 .885 r
.32052 .24395 .32663 .25158 .33642 .24757 .3303 .2403 Metetra
.662 .723 .895 r
.3303 .2403 .33642 .24757 .34624 .24366 .34013 .23664 Metetra
.663 .732 .901 r
.34013 .23664 .34624 .24366 .35608 .23982 .34998 .23297 Metetra
.663 .739 .906 r
.34998 .23297 .35608 .23982 .36596 .23608 .35988 .22928 Metetra
.664 .741 .908 r
.35988 .22928 .36596 .23608 .37587 .2324 .36981 .22558 Metetra
.664 .741 .908 r
.36981 .22558 .37587 .2324 .38581 .22871 .37978 .22186 Metetra
.664 .741 .908 r
.37978 .22186 .38581 .22871 .3958 .225 .38979 .21813 Metetra
.664 .741 .908 r
.38979 .21813 .3958 .225 .40582 .22129 .39983 .21439 Metetra
.664 .741 .908 r
.39983 .21439 .40582 .22129 .41587 .21756 .40991 .21063 Metetra
.664 .741 .908 r
.40991 .21063 .41587 .21756 .42597 .21381 .42003 .20686 Metetra
.664 .741 .908 r
.42003 .20686 .42597 .21381 .4361 .21005 .43019 .20307 Metetra
.664 .741 .908 r
.43019 .20307 .4361 .21005 .44627 .20628 .44038 .19927 Metetra
.664 .741 .908 r
.44038 .19927 .44627 .20628 .45648 .20249 .45062 .19546 Metetra
.664 .741 .908 r
.45062 .19546 .45648 .20249 .46673 .19877 .46089 .19163 Metetra
.663 .739 .906 r
.46089 .19163 .46673 .19877 .47701 .19515 .4712 .18778 Metetra
.663 .732 .901 r
.4712 .18778 .47701 .19515 .48734 .19159 .48155 .18393 Metetra
.662 .723 .895 r
.48155 .18393 .48734 .19159 .4977 .18813 .49194 .18005 Metetra
.655 .709 .887 r
.49194 .18005 .4977 .18813 .50811 .18462 .50237 .17632 Metetra
.644 .699 .886 r
.50237 .17632 .50811 .18462 .51855 .18103 .51284 .17286 Metetra
.64 .702 .891 r
.51284 .17286 .51855 .18103 .52904 .17751 .52335 .16952 Metetra
.628 .703 .9 r
.52335 .16952 .52904 .17751 .53958 .17416 .53391 .16646 Metetra
.633 .715 .906 r
.53391 .16646 .53958 .17416 .55015 .17072 .54451 .16328 Metetra
.645 .729 .91 r
.54451 .16328 .55015 .17072 .56077 .16707 .55516 .15979 Metetra
.658 .74 .911 r
.55516 .15979 .56077 .16707 .57143 .16319 .56584 .15595 Metetra
.694 .756 .899 r
.56584 .15595 .57143 .16319 .58212 .15866 .57656 .15112 Metetra
.686 .744 .896 r
.57656 .15112 .58212 .15866 .59285 .15425 .58731 .14647 Metetra
.661 .728 .899 r
.58731 .14647 .59285 .15425 .60363 .15026 .59811 .14249 Metetra
.665 .731 .899 r
.59811 .14249 .60363 .15026 .61444 .14615 .60896 .13839 Metetra
.679 .737 .894 r
.60896 .13839 .61444 .14615 .62529 .14165 .61983 .13385 Metetra
.674 .735 .896 r
.61983 .13385 .62529 .14165 .63618 .13728 .63075 .12946 Metetra
.645 .724 .906 r
.63075 .12946 .63618 .13728 .64714 .13371 .64174 .12585 Metetra
.647 .725 .905 r
.64174 .12585 .64714 .13371 .65815 .13 .65277 .12216 Metetra
.664 .733 .901 r
.65277 .12216 .65815 .13 .66916 .12551 .66383 .118 Metetra
.668 .746 .909 r
.66383 .118 .66916 .12551 .68021 .12098 .67493 .11375 Metetra
.696 .767 .906 r
.67493 .11375 .68021 .12098 .69128 .1161 .68603 .10871 Metetra
.694 .762 .904 r
.68603 .10871 .69128 .1161 .7024 .11125 .69717 .10371 Metetra
.667 .747 .911 r
.69717 .10371 .7024 .11125 .71359 .10709 .70839 .09945 Metetra
.666 .745 .909 r
.70839 .09945 .71359 .10709 .72484 .10292 .71966 .09518 Metetra
.664 .741 .908 r
.71966 .09518 .72484 .10292 .73612 .09873 .73098 .09096 Metetra
.664 .741 .908 r
.73098 .09096 .73612 .09873 .74745 .09453 .74234 .08672 Metetra
.664 .741 .908 r
.09834 .31807 .10501 .32427 .11401 .32092 .10737 .31469 Metetra
.664 .741 .908 r
.10737 .31469 .11401 .32092 .12305 .31755 .11642 .3113 Metetra
.641 .735 .917 r
.11642 .3113 .12305 .31755 .13211 .31424 .12544 .30841 Metetra
.64 .751 .929 r
.12544 .30841 .13211 .31424 .1412 .31092 .1345 .30553 Metetra
.645 .768 .938 r
.1345 .30553 .1412 .31092 .15024 .30832 .1436 .30251 Metetra
.646 .754 .928 r
.1436 .30251 .15024 .30832 .15931 .30576 .15274 .29947 Metetra
.652 .74 .914 r
.15274 .29947 .15931 .30576 .1685 .30245 .16193 .2963 Metetra
.652 .746 .918 r
.16193 .2963 .1685 .30245 .17773 .29905 .17116 .2931 Metetra
.68 .76 .912 r
.17116 .2931 .17773 .29905 .18705 .29519 .18049 .28925 Metetra
.683 .762 .911 r
.18049 .28925 .18705 .29519 .1964 .29126 .18987 .2853 Metetra
.65 .754 .925 r
.18987 .2853 .1964 .29126 .2057 .2881 .19919 .28212 Metetra
.643 .752 .928 r
.19919 .28212 .2057 .2881 .21503 .28508 .20853 .27907 Metetra
.669 .759 .918 r
.20853 .27907 .21503 .28508 .22442 .28164 .21797 .27542 Metetra
.675 .754 .91 r
.21797 .27542 .22442 .28164 .23387 .27808 .22746 .27161 Metetra
.662 .743 .91 r
.22746 .27161 .23387 .27808 .24328 .27519 .23695 .2681 Metetra
.657 .722 .897 r
.23695 .2681 .24328 .27519 .25272 .27247 .24646 .26467 Metetra
.67 .706 .874 r
.24646 .26467 .25272 .27247 .26228 .26878 .25606 .26078 Metetra
.674 .702 .868 r
.25606 .26078 .26228 .26878 .2719 .26475 .26569 .25672 Metetra
.673 .702 .869 r
.26569 .25672 .2719 .26475 .28158 .26042 .27536 .2527 Metetra
.674 .711 .876 r
.27536 .2527 .28158 .26042 .29129 .25596 .28506 .24868 Metetra
.672 .724 .889 r
.28506 .24868 .29129 .25596 .30101 .25179 .29478 .24478 Metetra
.67 .733 .897 r
.29478 .24478 .30101 .25179 .31076 .24774 .30453 .24093 Metetra
.666 .739 .905 r
.30453 .24093 .31076 .24774 .32052 .24395 .31431 .2372 Metetra
.664 .741 .908 r
.31431 .2372 .32052 .24395 .3303 .2403 .32411 .23353 Metetra
.664 .741 .908 r
.32411 .23353 .3303 .2403 .34013 .23664 .33396 .22985 Metetra
.664 .741 .908 r
.33396 .22985 .34013 .23664 .34998 .23297 .34384 .22615 Metetra
.664 .741 .908 r
.34384 .22615 .34998 .23297 .35988 .22928 .35376 .22243 Metetra
.664 .741 .908 r
.35376 .22243 .35988 .22928 .36981 .22558 .36371 .2187 Metetra
.664 .741 .908 r
.36371 .2187 .36981 .22558 .37978 .22186 .3737 .21496 Metetra
.664 .741 .908 r
.3737 .21496 .37978 .22186 .38979 .21813 .38373 .21121 Metetra
.664 .741 .908 r
.38373 .21121 .38979 .21813 .39983 .21439 .3938 .20744 Metetra
.664 .741 .908 r
.3938 .20744 .39983 .21439 .40991 .21063 .4039 .20366 Metetra
.664 .741 .908 r
.4039 .20366 .40991 .21063 .42003 .20686 .41405 .19986 Metetra
.664 .741 .908 r
.41405 .19986 .42003 .20686 .43019 .20307 .42423 .19604 Metetra
.664 .741 .908 r
.42423 .19604 .43019 .20307 .44038 .19927 .43445 .19222 Metetra
.664 .741 .908 r
.43445 .19222 .44038 .19927 .45062 .19546 .44471 .18838 Metetra
.664 .741 .908 r
.44471 .18838 .45062 .19546 .46089 .19163 .455 .18452 Metetra
.664 .741 .908 r
.455 .18452 .46089 .19163 .4712 .18778 .46534 .18065 Metetra
.664 .741 .908 r
.46534 .18065 .4712 .18778 .48155 .18393 .47572 .17677 Metetra
.664 .741 .908 r
.47572 .17677 .48155 .18393 .49194 .18005 .48613 .17287 Metetra
.661 .74 .909 r
.48613 .17287 .49194 .18005 .50237 .17632 .49659 .16902 Metetra
.656 .736 .909 r
.49659 .16902 .50237 .17632 .51284 .17286 .50708 .1653 Metetra
.653 .727 .904 r
.50708 .1653 .51284 .17286 .52335 .16952 .51762 .16162 Metetra
.647 .715 .898 r
.51762 .16162 .52335 .16952 .53391 .16646 .5282 .15807 Metetra
.645 .701 .887 r
.5282 .15807 .53391 .16646 .54451 .16328 .53882 .15452 Metetra
.642 .69 .879 r
.53882 .15452 .54451 .16328 .55516 .15979 .54949 .15101 Metetra
.648 .692 .878 r
.54949 .15101 .55516 .15979 .56584 .15595 .5602 .14732 Metetra
.664 .704 .877 r
.5602 .14732 .56584 .15595 .57656 .15112 .57095 .14317 Metetra
.664 .724 .894 r
.57095 .14317 .57656 .15112 .58731 .14647 .58174 .13908 Metetra
.653 .739 .913 r
.58174 .13908 .58731 .14647 .59811 .14249 .59257 .13531 Metetra
.659 .749 .917 r
.59257 .13531 .59811 .14249 .60896 .13839 .60345 .13137 Metetra
.682 .764 .913 r
.60345 .13137 .60896 .13839 .61983 .13385 .61436 .1268 Metetra
.677 .762 .915 r
.61436 .1268 .61983 .13385 .63075 .12946 .62531 .12238 Metetra
.645 .75 .926 r
.62531 .12238 .63075 .12946 .64174 .12585 .63633 .11874 Metetra
.649 .752 .924 r
.63633 .11874 .64174 .12585 .65277 .12216 .64739 .11499 Metetra
.674 .761 .916 r
.64739 .11499 .65277 .12216 .66383 .118 .65847 .11057 Metetra
.674 .753 .91 r
.65847 .11057 .66383 .118 .67493 .11375 .66959 .10612 Metetra
.678 .749 .904 r
.66959 .10612 .67493 .11375 .68603 .10871 .68075 .10152 Metetra
.68 .765 .915 r
.68075 .10152 .68603 .10871 .69717 .10371 .69194 .0969 Metetra
.686 .781 .923 r
.69194 .0969 .69717 .10371 .70839 .09945 .70317 .09214 Metetra
.684 .764 .913 r
.70317 .09214 .70839 .09945 .71966 .09518 .71444 .08738 Metetra
.664 .741 .908 r
.71444 .08738 .71966 .09518 .73098 .09096 .72579 .08313 Metetra
.664 .741 .908 r
.72579 .08313 .73098 .09096 .74234 .08672 .73719 .07886 Metetra
.662 .741 .908 r
.09164 .31182 .09834 .31807 .10737 .31469 .10067 .30845 Metetra
.662 .742 .909 r
.10067 .30845 .10737 .31469 .11642 .3113 .10974 .30507 Metetra
.625 .733 .924 r
.10974 .30507 .11642 .3113 .12544 .30841 .11874 .30249 Metetra
.623 .744 .934 r
.11874 .30249 .12544 .30841 .1345 .30553 .12776 .29992 Metetra
.662 .766 .927 r
.12776 .29992 .1345 .30553 .1436 .30251 .13693 .29653 Metetra
.664 .754 .917 r
.13693 .29653 .1436 .30251 .15274 .29947 .14614 .29307 Metetra
.645 .736 .915 r
.14614 .29307 .15274 .29947 .16193 .2963 .15533 .29001 Metetra
.643 .74 .919 r
.15533 .29001 .16193 .2963 .17116 .2931 .16456 .287 Metetra
.677 .756 .91 r
.16456 .287 .17116 .2931 .18049 .28925 .1739 .28318 Metetra
.682 .759 .909 r
.1739 .28318 .18049 .28925 .18987 .2853 .18329 .27923 Metetra
.652 .752 .923 r
.18329 .27923 .18987 .2853 .19919 .28212 .19264 .27598 Metetra
.646 .749 .924 r
.19264 .27598 .19919 .28212 .20853 .27907 .20201 .27285 Metetra
.675 .755 .911 r
.20201 .27285 .20853 .27907 .21797 .27542 .21149 .26903 Metetra
.681 .751 .904 r
.21149 .26903 .21797 .27542 .22746 .27161 .22101 .26502 Metetra
.681 .746 .9 r
.22101 .26502 .22746 .27161 .23695 .2681 .23057 .26099 Metetra
.679 .729 .888 r
.23057 .26099 .23695 .2681 .24646 .26467 .24016 .25693 Metetra
.675 .71 .874 r
.24016 .25693 .24646 .26467 .25606 .26078 .24978 .25288 Metetra
.674 .706 .871 r
.24978 .25288 .25606 .26078 .26569 .25672 .25944 .24882 Metetra
.664 .704 .877 r
.25944 .24882 .26569 .25672 .27536 .2527 .2691 .24507 Metetra
.661 .711 .885 r
.2691 .24507 .27536 .2527 .28506 .24868 .27878 .24142 Metetra
.662 .724 .895 r
.27878 .24142 .28506 .24868 .29478 .24478 .2885 .23777 Metetra
.663 .732 .901 r
.2885 .23777 .29478 .24478 .30453 .24093 .29826 .2341 Metetra
.663 .739 .906 r
.29826 .2341 .30453 .24093 .31431 .2372 .30805 .23041 Metetra
.664 .741 .908 r
.30805 .23041 .31431 .2372 .32411 .23353 .31788 .22672 Metetra
.664 .741 .908 r
.31788 .22672 .32411 .23353 .33396 .22985 .32775 .223 Metetra
.664 .741 .908 r
.32775 .223 .33396 .22985 .34384 .22615 .33765 .21928 Metetra
.664 .741 .908 r
.33765 .21928 .34384 .22615 .35376 .22243 .34759 .21554 Metetra
.664 .741 .908 r
.34759 .21554 .35376 .22243 .36371 .2187 .35757 .21179 Metetra
.664 .741 .908 r
.35757 .21179 .36371 .2187 .3737 .21496 .36758 .20802 Metetra
.664 .741 .908 r
.36758 .20802 .3737 .21496 .38373 .21121 .37764 .20424 Metetra
.664 .741 .908 r
.37764 .20424 .38373 .21121 .3938 .20744 .38773 .20044 Metetra
.664 .741 .908 r
.38773 .20044 .3938 .20744 .4039 .20366 .39785 .19663 Metetra
.664 .741 .908 r
.39785 .19663 .4039 .20366 .41405 .19986 .40802 .19281 Metetra
.664 .741 .908 r
.40802 .19281 .41405 .19986 .42423 .19604 .41823 .18897 Metetra
.664 .741 .908 r
.41823 .18897 .42423 .19604 .43445 .19222 .42847 .18512 Metetra
.664 .741 .908 r
.42847 .18512 .43445 .19222 .44471 .18838 .43875 .18125 Metetra
.664 .741 .908 r
.43875 .18125 .44471 .18838 .455 .18452 .44908 .17736 Metetra
.664 .741 .908 r
.44908 .17736 .455 .18452 .46534 .18065 .45944 .17347 Metetra
.664 .741 .908 r
.45944 .17347 .46534 .18065 .47572 .17677 .46984 .16955 Metetra
.664 .741 .908 r
.46984 .16955 .47572 .17677 .48613 .17287 .48028 .16563 Metetra
.664 .741 .908 r
.48028 .16563 .48613 .17287 .49659 .16902 .49076 .16168 Metetra
.663 .739 .906 r
.49076 .16168 .49659 .16902 .50708 .1653 .50129 .15772 Metetra
.663 .732 .901 r
.50129 .15772 .50708 .1653 .51762 .16162 .51185 .15375 Metetra
.662 .724 .895 r
.51185 .15375 .51762 .16162 .5282 .15807 .52245 .14976 Metetra
.656 .709 .887 r
.52245 .14976 .5282 .15807 .53882 .15452 .5331 .14589 Metetra
.644 .696 .883 r
.5331 .14589 .53882 .15452 .54949 .15101 .54378 .14232 Metetra
.643 .695 .883 r
.54378 .14232 .54949 .15101 .5602 .14732 .55452 .13874 Metetra
.643 .698 .886 r
.55452 .13874 .5602 .14732 .57095 .14317 .5653 .13516 Metetra
.645 .717 .901 r
.5653 .13516 .57095 .14317 .58174 .13908 .57612 .13157 Metetra
.646 .734 .913 r
.57612 .13157 .58174 .13908 .59257 .13531 .58699 .12794 Metetra
.653 .742 .915 r
.58699 .12794 .59257 .13531 .60345 .13137 .5979 .12412 Metetra
.68 .758 .91 r
.5979 .12412 .60345 .13137 .61436 .1268 .60884 .11959 Metetra
.675 .758 .913 r
.60884 .11959 .61436 .1268 .62531 .12238 .61982 .11518 Metetra
.646 .748 .924 r
.61982 .11518 .62531 .12238 .63633 .11874 .63087 .11148 Metetra
.651 .749 .921 r
.63087 .11148 .63633 .11874 .64739 .11499 .64196 .10765 Metetra
.682 .759 .91 r
.64196 .10765 .64739 .11499 .65847 .11057 .65307 .10299 Metetra
.679 .752 .906 r
.65307 .10299 .65847 .11057 .66959 .10612 .66421 .09836 Metetra
.663 .741 .908 r
.66421 .09836 .66959 .10612 .68075 .10152 .67542 .09415 Metetra
.666 .755 .917 r
.67542 .09415 .68075 .10152 .69194 .0969 .68667 .08986 Metetra
.698 .78 .915 r
.68667 .08986 .69194 .0969 .70317 .09214 .69791 .08471 Metetra
.696 .767 .907 r
.69791 .08471 .70317 .09214 .71444 .08738 .70919 .07958 Metetra
.665 .744 .909 r
.70919 .07958 .71444 .08738 .72579 .08313 .72057 .07527 Metetra
.665 .743 .908 r
.72057 .07527 .72579 .08313 .73719 .07886 .732 .07094 Metetra
.652 .739 .913 r
.08488 .30554 .09164 .31182 .10067 .30845 .09391 .30237 Metetra
.653 .746 .918 r
.09391 .30237 .10067 .30845 .10974 .30507 .10296 .29919 Metetra
.646 .753 .927 r
.10296 .29919 .10974 .30507 .11874 .30249 .11203 .29615 Metetra
.646 .737 .916 r
.11203 .29615 .11874 .30249 .12776 .29992 .12114 .29311 Metetra
.661 .727 .898 r
.12114 .29311 .12776 .29992 .13693 .29653 .13033 .28966 Metetra
.662 .726 .897 r
.13033 .28966 .13693 .29653 .14614 .29307 .13955 .28618 Metetra
.645 .721 .904 r
.13955 .28618 .14614 .29307 .15533 .29001 .14876 .2831 Metetra
.643 .72 .904 r
.14876 .2831 .15533 .29001 .16456 .287 .158 .28006 Metetra
.667 .727 .895 r
.158 .28006 .16456 .287 .1739 .28318 .16734 .27642 Metetra
.671 .735 .898 r
.16734 .27642 .1739 .28318 .18329 .27923 .17673 .27268 Metetra
.666 .741 .906 r
.17673 .27268 .18329 .27923 .19264 .27598 .18613 .26905 Metetra
.664 .729 .898 r
.18613 .26905 .19264 .27598 .20201 .27285 .19557 .26544 Metetra
.667 .716 .885 r
.19557 .26544 .20201 .27285 .21149 .26903 .20505 .26169 Metetra
.669 .719 .887 r
.20505 .26169 .21149 .26903 .22101 .26502 .21457 .25789 Metetra
.677 .729 .889 r
.21457 .25789 .22101 .26502 .23057 .26099 .22414 .25388 Metetra
.679 .731 .889 r
.22414 .25388 .23057 .26099 .24016 .25693 .23376 .2498 Metetra
.673 .729 .892 r
.23376 .2498 .24016 .25693 .24978 .25288 .24338 .2459 Metetra
.671 .734 .897 r
.24338 .2459 .24978 .25288 .25944 .24882 .25304 .24205 Metetra
.666 .74 .905 r
.25304 .24205 .25944 .24882 .2691 .24507 .26271 .23833 Metetra
.664 .741 .908 r
.26271 .23833 .2691 .24507 .27878 .24142 .27242 .23466 Metetra
.664 .741 .908 r
.27242 .23466 .27878 .24142 .2885 .23777 .28216 .23098 Metetra
.664 .741 .908 r
.28216 .23098 .2885 .23777 .29826 .2341 .29194 .22729 Metetra
.664 .741 .908 r
.29194 .22729 .29826 .2341 .30805 .23041 .30175 .22358 Metetra
.664 .741 .908 r
.30175 .22358 .30805 .23041 .31788 .22672 .31161 .21985 Metetra
.664 .741 .908 r
.31161 .21985 .31788 .22672 .32775 .223 .32149 .21612 Metetra
.664 .741 .908 r
.32149 .21612 .32775 .223 .33765 .21928 .33142 .21237 Metetra
.664 .741 .908 r
.33142 .21237 .33765 .21928 .34759 .21554 .34138 .2086 Metetra
.664 .741 .908 r
.34138 .2086 .34759 .21554 .35757 .21179 .35138 .20482 Metetra
.664 .741 .908 r
.35138 .20482 .35757 .21179 .36758 .20802 .36142 .20103 Metetra
.664 .741 .908 r
.36142 .20103 .36758 .20802 .37764 .20424 .3715 .19722 Metetra
.664 .741 .908 r
.3715 .19722 .37764 .20424 .38773 .20044 .38161 .1934 Metetra
.664 .741 .908 r
.38161 .1934 .38773 .20044 .39785 .19663 .39176 .18956 Metetra
.664 .741 .908 r
.39176 .18956 .39785 .19663 .40802 .19281 .40195 .18571 Metetra
.664 .741 .908 r
.40195 .18571 .40802 .19281 .41823 .18897 .41218 .18184 Metetra
.664 .741 .908 r
.41218 .18184 .41823 .18897 .42847 .18512 .42245 .17796 Metetra
.664 .741 .908 r
.42245 .17796 .42847 .18512 .43875 .18125 .43276 .17407 Metetra
.664 .741 .908 r
.43276 .17407 .43875 .18125 .44908 .17736 .44311 .17016 Metetra
.664 .741 .908 r
.44311 .17016 .44908 .17736 .45944 .17347 .4535 .16623 Metetra
.664 .741 .908 r
.4535 .16623 .45944 .17347 .46984 .16955 .46392 .16229 Metetra
.664 .741 .908 r
.46392 .16229 .46984 .16955 .48028 .16563 .47439 .15833 Metetra
.664 .741 .908 r
.47439 .15833 .48028 .16563 .49076 .16168 .4849 .15436 Metetra
.664 .741 .908 r
.4849 .15436 .49076 .16168 .50129 .15772 .49545 .15038 Metetra
.664 .741 .908 r
.49545 .15038 .50129 .15772 .51185 .15375 .50603 .14638 Metetra
.664 .741 .908 r
.50603 .14638 .51185 .15375 .52245 .14976 .51666 .14236 Metetra
.661 .74 .909 r
.51666 .14236 .52245 .14976 .5331 .14589 .52734 .13839 Metetra
.655 .736 .909 r
.52734 .13839 .5331 .14589 .54378 .14232 .53805 .13455 Metetra
.652 .727 .904 r
.53805 .13455 .54378 .14232 .55452 .13874 .54881 .13077 Metetra
.644 .719 .902 r
.54881 .13077 .55452 .13874 .5653 .13516 .55961 .12717 Metetra
.647 .72 .902 r
.55961 .12717 .5653 .13516 .57612 .13157 .57046 .12349 Metetra
.654 .721 .898 r
.57046 .12349 .57612 .13157 .58699 .12794 .58135 .11959 Metetra
.655 .714 .892 r
.58135 .11959 .58699 .12794 .5979 .12412 .59229 .11565 Metetra
.659 .713 .888 r
.59229 .11565 .5979 .12412 .60884 .11959 .60326 .11156 Metetra
.66 .728 .9 r
.60326 .11156 .60884 .11959 .61982 .11518 .61428 .10747 Metetra
.655 .737 .91 r
.61428 .10747 .61982 .11518 .63087 .11148 .62535 .10351 Metetra
.658 .731 .903 r
.62535 .10351 .63087 .11148 .64196 .10765 .63646 .09944 Metetra
.679 .733 .891 r
.63646 .09944 .64196 .10765 .65307 .10299 .6476 .09475 Metetra
.677 .732 .892 r
.6476 .09475 .65307 .10299 .66421 .09836 .65877 .09009 Metetra
.662 .726 .897 r
.65877 .09009 .66421 .09836 .67542 .09415 .67001 .08585 Metetra
.663 .726 .896 r
.67001 .08585 .67542 .09415 .68667 .08986 .68129 .08156 Metetra
.677 .733 .893 r
.68129 .08156 .68667 .08986 .69791 .08471 .69259 .07685 Metetra
.679 .748 .904 r
.69259 .07685 .69791 .08471 .70919 .07958 .70393 .07214 Metetra
.674 .761 .916 r
.70393 .07214 .70919 .07958 .72057 .07527 .71533 .06755 Metetra
.674 .753 .911 r
.71533 .06755 .72057 .07527 .732 .07094 .72677 .06296 Metetra
.643 .736 .916 r
.07809 .29921 .08488 .30554 .09391 .30237 .0871 .29623 Metetra
.643 .743 .922 r
.0871 .29623 .09391 .30237 .10296 .29919 .09614 .29323 Metetra
.663 .755 .919 r
.09614 .29323 .10296 .29919 .11203 .29615 .10528 .2898 Metetra
.663 .743 .909 r
.10528 .2898 .11203 .29615 .12114 .29311 .11445 .28634 Metetra
.663 .73 .899 r
.11445 .28634 .12114 .29311 .13033 .28966 .12367 .28282 Metetra
.663 .729 .898 r
.12367 .28282 .13033 .28966 .13955 .28618 .13291 .27929 Metetra
.645 .723 .905 r
.13291 .27929 .13955 .28618 .14876 .2831 .14214 .27619 Metetra
.643 .722 .906 r
.14214 .27619 .14876 .2831 .158 .28006 .15139 .27313 Metetra
.661 .727 .898 r
.15139 .27313 .158 .28006 .16734 .27642 .16074 .2696 Metetra
.664 .733 .901 r
.16074 .2696 .16734 .27642 .17673 .27268 .17012 .266 Metetra
.678 .741 .899 r
.17012 .266 .17673 .27268 .18613 .26905 .17958 .26205 Metetra
.679 .732 .891 r
.17958 .26205 .18613 .26905 .19557 .26544 .18908 .25802 Metetra
.664 .716 .887 r
.18908 .25802 .19557 .26544 .20505 .26169 .19857 .25433 Metetra
.661 .718 .891 r
.19857 .25433 .20505 .26169 .21457 .25789 .20809 .25072 Metetra
.675 .728 .89 r
.20809 .25072 .21457 .25789 .22414 .25388 .21768 .24675 Metetra
.679 .731 .89 r
.21768 .24675 .22414 .25388 .23376 .2498 .22731 .24266 Metetra
.667 .729 .896 r
.22731 .24266 .23376 .2498 .24338 .2459 .23694 .23889 Metetra
.663 .732 .901 r
.23694 .23889 .24338 .2459 .25304 .24205 .24659 .23523 Metetra
.663 .739 .906 r
.24659 .23523 .25304 .24205 .26271 .23833 .25628 .23155 Metetra
.664 .741 .908 r
.25628 .23155 .26271 .23833 .27242 .23466 .26601 .22786 Metetra
.664 .741 .908 r
.26601 .22786 .27242 .23466 .28216 .23098 .27578 .22415 Metetra
.664 .741 .908 r
.27578 .22415 .28216 .23098 .29194 .22729 .28558 .22043 Metetra
.664 .741 .908 r
.28558 .22043 .29194 .22729 .30175 .22358 .29541 .21669 Metetra
.664 .741 .908 r
.29541 .21669 .30175 .22358 .31161 .21985 .30529 .21294 Metetra
.664 .741 .908 r
.30529 .21294 .31161 .21985 .32149 .21612 .3152 .20918 Metetra
.664 .741 .908 r
.3152 .20918 .32149 .21612 .33142 .21237 .32515 .2054 Metetra
.664 .741 .908 r
.32515 .2054 .33142 .21237 .34138 .2086 .33513 .20161 Metetra
.664 .741 .908 r
.33513 .20161 .34138 .2086 .35138 .20482 .34516 .19781 Metetra
.664 .741 .908 r
.34516 .19781 .35138 .20482 .36142 .20103 .35522 .19399 Metetra
.664 .741 .908 r
.35522 .19399 .36142 .20103 .3715 .19722 .36532 .19015 Metetra
.664 .741 .908 r
.36532 .19015 .3715 .19722 .38161 .1934 .37545 .1863 Metetra
.664 .741 .908 r
.37545 .1863 .38161 .1934 .39176 .18956 .38563 .18244 Metetra
.664 .741 .908 r
.38563 .18244 .39176 .18956 .40195 .18571 .39585 .17856 Metetra
.664 .741 .908 r
.39585 .17856 .40195 .18571 .41218 .18184 .4061 .17467 Metetra
.664 .741 .908 r
.4061 .17467 .41218 .18184 .42245 .17796 .41639 .17076 Metetra
.664 .741 .908 r
.41639 .17076 .42245 .17796 .43276 .17407 .42673 .16684 Metetra
.664 .741 .908 r
.42673 .16684 .43276 .17407 .44311 .17016 .4371 .1629 Metetra
.664 .741 .908 r
.4371 .1629 .44311 .17016 .4535 .16623 .44751 .15894 Metetra
.664 .741 .908 r
.44751 .15894 .4535 .16623 .46392 .16229 .45796 .15498 Metetra
.664 .741 .908 r
.45796 .15498 .46392 .16229 .47439 .15833 .46846 .15099 Metetra
.664 .741 .908 r
.46846 .15099 .47439 .15833 .4849 .15436 .47899 .14699 Metetra
.664 .741 .908 r
.47899 .14699 .4849 .15436 .49545 .15038 .48956 .14298 Metetra
.664 .741 .908 r
.48956 .14298 .49545 .15038 .50603 .14638 .50018 .13895 Metetra
.664 .741 .908 r
.50018 .13895 .50603 .14638 .51666 .14236 .51084 .1349 Metetra
.664 .741 .908 r
.51084 .1349 .51666 .14236 .52734 .13839 .52154 .13084 Metetra
.663 .739 .906 r
.52154 .13084 .52734 .13839 .53805 .13455 .53228 .12676 Metetra
.658 .731 .903 r
.53228 .12676 .53805 .13455 .54881 .13077 .54306 .12279 Metetra
.645 .721 .903 r
.54306 .12279 .54881 .13077 .55961 .12717 .55389 .11913 Metetra
.649 .721 .901 r
.55389 .11913 .55961 .12717 .57046 .12349 .56476 .11536 Metetra
.662 .724 .896 r
.56476 .11536 .57046 .12349 .58135 .11959 .57568 .11122 Metetra
.658 .717 .892 r
.57568 .11122 .58135 .11959 .59229 .11565 .58663 .10715 Metetra
.645 .708 .893 r
.58663 .10715 .59229 .11565 .60326 .11156 .59764 .10343 Metetra
.648 .722 .902 r
.59764 .10343 .60326 .11156 .61428 .10747 .6087 .09963 Metetra
.661 .737 .906 r
.6087 .09963 .61428 .10747 .62535 .10351 .61979 .09547 Metetra
.663 .733 .901 r
.61979 .09547 .62535 .10351 .63646 .09944 .63093 .09122 Metetra
.679 .734 .892 r
.63093 .09122 .63646 .09944 .6476 .09475 .64209 .0865 Metetra
.677 .734 .893 r
.64209 .0865 .6476 .09475 .65877 .09009 .65329 .08181 Metetra
.661 .727 .898 r
.65329 .08181 .65877 .09009 .67001 .08585 .66456 .07756 Metetra
.662 .728 .899 r
.66456 .07756 .67001 .08585 .68129 .08156 .67587 .07329 Metetra
.663 .73 .899 r
.67587 .07329 .68129 .08156 .69259 .07685 .68723 .06895 Metetra
.665 .743 .909 r
.68723 .06895 .69259 .07685 .70393 .07214 .69863 .06459 Metetra
.682 .763 .912 r
.69863 .06459 .70393 .07214 .71533 .06755 .71004 .05976 Metetra
.681 .755 .907 r
.71004 .05976 .71533 .06755 .72677 .06296 .7215 .05492 Metetra
.643 .736 .916 r
.07124 .29284 .07809 .29921 .0871 .29623 .08027 .28983 Metetra
.643 .736 .916 r
.08027 .28983 .0871 .29623 .09614 .29323 .08933 .28682 Metetra
.652 .739 .913 r
.08933 .28682 .09614 .29323 .10528 .2898 .09846 .28358 Metetra
.653 .746 .918 r
.09846 .28358 .10528 .2898 .11445 .28634 .10762 .28033 Metetra
.674 .759 .915 r
.10762 .28033 .11445 .28634 .12367 .28282 .11688 .27659 Metetra
.674 .752 .91 r
.11688 .27659 .12367 .28282 .13291 .27929 .12617 .27281 Metetra
.646 .738 .916 r
.12617 .27281 .13291 .27929 .14214 .27619 .13542 .26966 Metetra
.643 .736 .916 r
.13542 .26966 .14214 .27619 .15139 .27313 .14469 .26657 Metetra
.678 .745 .901 r
.14469 .26657 .15139 .27313 .16074 .2696 .15411 .26262 Metetra
.681 .733 .89 r
.15411 .26262 .16074 .2696 .17012 .266 .16356 .25853 Metetra
.67 .717 .883 r
.16356 .25853 .17012 .266 .17958 .26205 .17303 .25467 Metetra
.669 .72 .887 r
.17303 .25467 .17958 .26205 .18908 .25802 .18252 .25085 Metetra
.664 .725 .895 r
.18252 .25085 .18908 .25802 .19857 .25433 .19202 .24718 Metetra
.662 .726 .897 r
.19202 .24718 .19857 .25433 .20809 .25072 .20156 .24355 Metetra
.668 .728 .894 r
.20156 .24355 .20809 .25072 .21768 .24675 .21115 .23973 Metetra
.671 .734 .897 r
.21115 .23973 .21768 .24675 .22731 .24266 .22078 .23585 Metetra
.666 .74 .906 r
.22078 .23585 .22731 .24266 .23694 .23889 .23042 .23212 Metetra
.664 .741 .908 r
.23042 .23212 .23694 .23889 .24659 .23523 .2401 .22842 Metetra
.664 .741 .908 r
.2401 .22842 .24659 .23523 .25628 .23155 .24981 .22472 Metetra
.664 .741 .908 r
.24981 .22472 .25628 .23155 .26601 .22786 .25956 .221 Metetra
.664 .741 .908 r
.25956 .221 .26601 .22786 .27578 .22415 .26935 .21727 Metetra
.664 .741 .908 r
.26935 .21727 .27578 .22415 .28558 .22043 .27917 .21352 Metetra
.664 .741 .908 r
.27917 .21352 .28558 .22043 .29541 .21669 .28903 .20976 Metetra
.664 .741 .908 r
.28903 .20976 .29541 .21669 .30529 .21294 .29892 .20599 Metetra
.664 .741 .908 r
.29892 .20599 .30529 .21294 .3152 .20918 .30886 .2022 Metetra
.664 .741 .908 r
.30886 .2022 .3152 .20918 .32515 .2054 .31883 .19839 Metetra
.664 .741 .908 r
.31883 .19839 .32515 .2054 .33513 .20161 .32884 .19457 Metetra
.664 .741 .908 r
.32884 .19457 .33513 .20161 .34516 .19781 .33888 .19074 Metetra
.664 .741 .908 r
.33888 .19074 .34516 .19781 .35522 .19399 .34897 .1869 Metetra
.664 .741 .908 r
.34897 .1869 .35522 .19399 .36532 .19015 .35909 .18303 Metetra
.664 .741 .908 r
.35909 .18303 .36532 .19015 .37545 .1863 .36925 .17916 Metetra
.664 .741 .908 r
.36925 .17916 .37545 .1863 .38563 .18244 .37945 .17527 Metetra
.664 .741 .908 r
.37945 .17527 .38563 .18244 .39585 .17856 .38969 .17136 Metetra
.664 .741 .908 r
.38969 .17136 .39585 .17856 .4061 .17467 .39997 .16744 Metetra
.664 .741 .908 r
.39997 .16744 .4061 .17467 .41639 .17076 .41029 .1635 Metetra
.664 .741 .908 r
.41029 .1635 .41639 .17076 .42673 .16684 .42065 .15955 Metetra
.664 .741 .908 r
.42065 .15955 .42673 .16684 .4371 .1629 .43105 .15559 Metetra
.664 .741 .908 r
.43105 .15559 .4371 .1629 .44751 .15894 .44148 .15161 Metetra
.664 .741 .908 r
.44148 .15161 .44751 .15894 .45796 .15498 .45196 .14761 Metetra
.664 .741 .908 r
.45196 .14761 .45796 .15498 .46846 .15099 .46248 .1436 Metetra
.664 .741 .908 r
.46248 .1436 .46846 .15099 .47899 .14699 .47304 .13957 Metetra
.664 .741 .908 r
.47304 .13957 .47899 .14699 .48956 .14298 .48364 .13552 Metetra
.664 .741 .908 r
.48364 .13552 .48956 .14298 .50018 .13895 .49428 .13146 Metetra
.664 .741 .908 r
.49428 .13146 .50018 .13895 .51084 .1349 .50497 .12739 Metetra
.664 .741 .908 r
.50497 .12739 .51084 .1349 .52154 .13084 .51569 .1233 Metetra
.664 .741 .908 r
.51569 .1233 .52154 .13084 .53228 .12676 .52646 .11919 Metetra
.661 .74 .909 r
.52646 .11919 .53228 .12676 .54306 .12279 .53727 .11512 Metetra
.655 .736 .909 r
.53727 .11512 .54306 .12279 .55389 .11913 .54812 .11121 Metetra
.656 .729 .903 r
.54812 .11121 .55389 .11913 .56476 .11536 .55902 .10722 Metetra
.662 .726 .897 r
.55902 .10722 .56476 .11536 .57568 .11122 .56996 .10305 Metetra
.661 .725 .897 r
.56996 .10305 .57568 .11122 .58663 .10715 .58095 .0989 Metetra
.654 .721 .898 r
.58095 .0989 .58663 .10715 .59764 .10343 .59198 .09492 Metetra
.652 .713 .893 r
.59198 .09492 .59764 .10343 .6087 .09963 .60306 .09097 Metetra
.642 .706 .893 r
.60306 .09097 .6087 .09963 .61979 .09547 .61419 .08725 Metetra
.648 .722 .903 r
.61419 .08725 .61979 .09547 .63093 .09122 .62537 .08338 Metetra
.681 .748 .902 r
.62537 .08338 .63093 .09122 .64209 .0865 .63656 .07863 Metetra
.678 .747 .903 r
.63656 .07863 .64209 .0865 .65329 .08181 .6478 .07393 Metetra
.654 .738 .912 r
.6478 .07393 .65329 .08181 .66456 .07756 .6591 .06988 Metetra
.655 .746 .917 r
.6591 .06988 .66456 .07756 .67587 .07329 .67046 .06578 Metetra
.674 .761 .916 r
.67046 .06578 .67587 .07329 .68723 .06895 .68183 .06118 Metetra
.674 .753 .91 r
.68183 .06118 .68723 .06895 .69863 .06459 .69325 .05655 Metetra
.681 .748 .902 r
.69325 .05655 .69863 .06459 .71004 .05976 .7047 .05169 Metetra
.681 .748 .902 r
.7047 .05169 .71004 .05976 .7215 .05492 .71619 .04682 Metetra
.644 .737 .917 r
.06435 .28645 .07124 .29284 .08027 .28983 .0734 .28341 Metetra
.644 .737 .917 r
.0734 .28341 .08027 .28983 .08933 .28682 .08248 .28036 Metetra
.644 .736 .916 r
.08248 .28036 .08933 .28682 .09846 .28358 .09159 .27729 Metetra
.644 .743 .921 r
.09159 .27729 .09846 .28358 .10762 .28033 .10075 .27422 Metetra
.68 .759 .91 r
.10075 .27422 .10762 .28033 .11688 .27659 .11005 .27028 Metetra
.682 .753 .905 r
.11005 .27028 .11688 .27659 .12617 .27281 .11939 .26627 Metetra
.649 .738 .915 r
.11939 .26627 .12617 .27281 .13542 .26966 .12866 .26306 Metetra
.645 .735 .915 r
.12866 .26306 .13542 .26966 .14469 .26657 .13796 .25991 Metetra
.691 .746 .894 r
.13796 .25991 .14469 .26657 .15411 .26262 .14743 .25559 Metetra
.695 .737 .883 r
.14743 .25559 .15411 .26262 .16356 .25853 .15696 .25107 Metetra
.666 .717 .886 r
.15696 .25107 .16356 .25853 .17303 .25467 .16643 .2473 Metetra
.661 .719 .891 r
.16643 .2473 .17303 .25467 .18252 .25085 .17591 .24367 Metetra
.662 .726 .896 r
.17591 .24367 .18252 .25085 .19202 .24718 .18543 .24002 Metetra
.662 .727 .897 r
.18543 .24002 .19202 .24718 .20156 .24355 .19499 .23636 Metetra
.662 .727 .897 r
.19499 .23636 .20156 .24355 .21115 .23973 .20458 .23268 Metetra
.663 .732 .901 r
.20458 .23268 .21115 .23973 .22078 .23585 .2142 .22899 Metetra
.663 .739 .907 r
.2142 .22899 .22078 .23585 .23042 .23212 .22386 .22529 Metetra
.664 .741 .908 r
.22386 .22529 .23042 .23212 .2401 .22842 .23356 .22157 Metetra
.664 .741 .908 r
.23356 .22157 .2401 .22842 .24981 .22472 .2433 .21784 Metetra
.664 .741 .908 r
.2433 .21784 .24981 .22472 .25956 .221 .25307 .2141 Metetra
.664 .741 .908 r
.25307 .2141 .25956 .221 .26935 .21727 .26287 .21034 Metetra
.664 .741 .908 r
.26287 .21034 .26935 .21727 .27917 .21352 .27272 .20657 Metetra
.664 .741 .908 r
.27272 .20657 .27917 .21352 .28903 .20976 .2826 .20278 Metetra
.664 .741 .908 r
.2826 .20278 .28903 .20976 .29892 .20599 .29252 .19898 Metetra
.664 .741 .908 r
.29252 .19898 .29892 .20599 .30886 .2022 .30247 .19516 Metetra
.664 .741 .908 r
.30247 .19516 .30886 .2022 .31883 .19839 .31247 .19133 Metetra
.664 .741 .908 r
.31247 .19133 .31883 .19839 .32884 .19457 .3225 .18749 Metetra
.664 .741 .908 r
.3225 .18749 .32884 .19457 .33888 .19074 .33257 .18363 Metetra
.664 .741 .908 r
.33257 .18363 .33888 .19074 .34897 .1869 .34268 .17976 Metetra
.664 .741 .908 r
.34268 .17976 .34897 .1869 .35909 .18303 .35282 .17587 Metetra
.664 .741 .908 r
.35282 .17587 .35909 .18303 .36925 .17916 .36301 .17196 Metetra
.664 .741 .908 r
.36301 .17196 .36925 .17916 .37945 .17527 .37323 .16804 Metetra
.664 .741 .908 r
.37323 .16804 .37945 .17527 .38969 .17136 .3835 .16411 Metetra
.664 .741 .908 r
.3835 .16411 .38969 .17136 .39997 .16744 .3938 .16016 Metetra
.664 .741 .908 r
.3938 .16016 .39997 .16744 .41029 .1635 .40414 .1562 Metetra
.664 .741 .908 r
.40414 .1562 .41029 .1635 .42065 .15955 .41453 .15222 Metetra
.664 .741 .908 r
.41453 .15222 .42065 .15955 .43105 .15559 .42495 .14822 Metetra
.664 .741 .908 r
.42495 .14822 .43105 .15559 .44148 .15161 .43541 .14421 Metetra
.664 .741 .908 r
.43541 .14421 .44148 .15161 .45196 .14761 .44592 .14019 Metetra
.664 .741 .908 r
.44592 .14019 .45196 .14761 .46248 .1436 .45646 .13615 Metetra
.664 .741 .908 r
.45646 .13615 .46248 .1436 .47304 .13957 .46705 .13209 Metetra
.664 .741 .908 r
.46705 .13209 .47304 .13957 .48364 .13552 .47767 .12802 Metetra
.664 .741 .908 r
.47767 .12802 .48364 .13552 .49428 .13146 .48834 .12393 Metetra
.664 .741 .908 r
.48834 .12393 .49428 .13146 .50497 .12739 .49905 .11982 Metetra
.664 .741 .908 r
.49905 .11982 .50497 .12739 .51569 .1233 .50981 .1157 Metetra
.664 .741 .908 r
.50981 .1157 .51569 .1233 .52646 .11919 .5206 .11157 Metetra
.664 .741 .908 r
.5206 .11157 .52646 .11919 .53727 .11512 .53144 .10741 Metetra
.663 .739 .907 r
.53144 .10741 .53727 .11512 .54812 .11121 .54232 .10324 Metetra
.663 .732 .901 r
.54232 .10324 .54812 .11121 .55902 .10722 .55324 .09906 Metetra
.662 .727 .897 r
.55324 .09906 .55902 .10722 .56996 .10305 .56421 .09485 Metetra
.662 .727 .897 r
.56421 .09485 .56996 .10305 .58095 .0989 .57522 .09063 Metetra
.662 .726 .896 r
.57522 .09063 .58095 .0989 .59198 .09492 .58628 .0864 Metetra
.656 .717 .893 r
.58628 .0864 .59198 .09492 .60306 .09097 .59738 .08229 Metetra
.627 .701 .898 r
.59738 .08229 .60306 .09097 .61419 .08725 .60855 .07895 Metetra
.634 .716 .906 r
.60855 .07895 .61419 .08725 .62537 .08338 .61977 .07542 Metetra
.679 .746 .901 r
.61977 .07542 .62537 .08338 .63656 .07863 .63099 .07067 Metetra
.676 .746 .903 r
.63099 .07067 .63656 .07863 .6478 .07393 .64226 .06598 Metetra
.646 .735 .914 r
.64226 .06598 .6478 .07393 .6591 .06988 .65361 .06211 Metetra
.648 .742 .918 r
.65361 .06211 .6591 .06988 .67046 .06578 .665 .05816 Metetra
.681 .762 .912 r
.665 .05816 .67046 .06578 .68183 .06118 .6764 .05332 Metetra
.681 .755 .907 r
.6764 .05332 .68183 .06118 .69325 .05655 .68784 .04846 Metetra
.68 .748 .903 r
.68784 .04846 .69325 .05655 .7047 .05169 .69932 .04358 Metetra
.68 .749 .903 r
.69932 .04358 .7047 .05169 .71619 .04682 .71085 .03869 Metetra
.655 .755 .923 r
.05735 .28046 .06435 .28645 .0734 .28341 .06644 .27717 Metetra
.654 .747 .918 r
.06644 .27717 .0734 .28341 .08248 .28036 .07558 .27386 Metetra
.654 .739 .912 r
.07558 .27386 .08248 .28036 .09159 .27729 .08474 .27055 Metetra
.654 .732 .907 r
.08474 .27055 .09159 .27729 .10075 .27422 .09394 .26721 Metetra
.67 .729 .894 r
.09394 .26721 .10075 .27422 .11005 .27028 .10324 .26345 Metetra
.671 .735 .898 r
.10324 .26345 .11005 .27028 .11939 .26627 .11257 .25965 Metetra
.665 .741 .907 r
.11257 .25965 .11939 .26627 .12866 .26306 .12191 .25602 Metetra
.663 .728 .898 r
.12191 .25602 .12866 .26306 .13796 .25991 .13128 .25239 Metetra
.675 .717 .881 r
.13128 .25239 .13796 .25991 .14743 .25559 .14073 .24838 Metetra
.678 .729 .888 r
.14073 .24838 .14743 .25559 .15696 .25107 .15022 .2443 Metetra
.666 .74 .905 r
.15022 .2443 .15696 .25107 .16643 .2473 .1597 .24058 Metetra
.664 .741 .908 r
.1597 .24058 .16643 .2473 .17591 .24367 .1692 .23692 Metetra
.664 .741 .908 r
.1692 .23692 .17591 .24367 .18543 .24002 .17874 .23325 Metetra
.664 .741 .908 r
.17874 .23325 .18543 .24002 .19499 .23636 .18832 .22956 Metetra
.664 .741 .908 r
.18832 .22956 .19499 .23636 .20458 .23268 .19793 .22586 Metetra
.664 .741 .908 r
.19793 .22586 .20458 .23268 .2142 .22899 .20758 .22215 Metetra
.664 .741 .908 r
.20758 .22215 .2142 .22899 .22386 .22529 .21726 .21842 Metetra
.664 .741 .908 r
.21726 .21842 .22386 .22529 .23356 .22157 .22698 .21468 Metetra
.664 .741 .908 r
.22698 .21468 .23356 .22157 .2433 .21784 .23673 .21092 Metetra
.664 .741 .908 r
.23673 .21092 .2433 .21784 .25307 .2141 .24653 .20715 Metetra
.664 .741 .908 r
.24653 .20715 .25307 .2141 .26287 .21034 .25635 .20336 Metetra
.664 .741 .908 r
.25635 .20336 .26287 .21034 .27272 .20657 .26622 .19956 Metetra
.664 .741 .908 r
.26622 .19956 .27272 .20657 .2826 .20278 .27612 .19575 Metetra
.664 .741 .908 r
.27612 .19575 .2826 .20278 .29252 .19898 .28607 .19192 Metetra
.664 .741 .908 r
.28607 .19192 .29252 .19898 .30247 .19516 .29604 .18808 Metetra
.664 .741 .908 r
.29604 .18808 .30247 .19516 .31247 .19133 .30606 .18422 Metetra
.664 .741 .908 r
.30606 .18422 .31247 .19133 .3225 .18749 .31612 .18035 Metetra
.664 .741 .908 r
.31612 .18035 .3225 .18749 .33257 .18363 .32621 .17647 Metetra
.664 .741 .908 r
.32621 .17647 .33257 .18363 .34268 .17976 .33634 .17256 Metetra
.664 .741 .908 r
.33634 .17256 .34268 .17976 .35282 .17587 .34651 .16865 Metetra
.664 .741 .908 r
.34651 .16865 .35282 .17587 .36301 .17196 .35672 .16472 Metetra
.664 .741 .908 r
.35672 .16472 .36301 .17196 .37323 .16804 .36697 .16077 Metetra
.664 .741 .908 r
.36697 .16077 .37323 .16804 .3835 .16411 .37726 .15681 Metetra
.664 .741 .908 r
.37726 .15681 .3835 .16411 .3938 .16016 .38758 .15283 Metetra
.664 .741 .908 r
.38758 .15283 .3938 .16016 .40414 .1562 .39795 .14884 Metetra
.664 .741 .908 r
.39795 .14884 .40414 .1562 .41453 .15222 .40836 .14483 Metetra
.664 .741 .908 r
.40836 .14483 .41453 .15222 .42495 .14822 .41881 .14081 Metetra
.664 .741 .908 r
.41881 .14081 .42495 .14822 .43541 .14421 .4293 .13677 Metetra
.664 .741 .908 r
.4293 .13677 .43541 .14421 .44592 .14019 .43983 .13272 Metetra
.664 .741 .908 r
.43983 .13272 .44592 .14019 .45646 .13615 .4504 .12865 Metetra
.664 .741 .908 r
.4504 .12865 .45646 .13615 .46705 .13209 .46101 .12456 Metetra
.664 .741 .908 r
.46101 .12456 .46705 .13209 .47767 .12802 .47166 .12046 Metetra
.664 .741 .908 r
.47166 .12046 .47767 .12802 .48834 .12393 .48236 .11634 Metetra
.664 .741 .908 r
.48236 .11634 .48834 .12393 .49905 .11982 .4931 .1122 Metetra
.664 .741 .908 r
.4931 .1122 .49905 .11982 .50981 .1157 .50388 .10805 Metetra
.664 .741 .908 r
.50388 .10805 .50981 .1157 .5206 .11157 .5147 .10388 Metetra
.664 .741 .908 r
.5147 .10388 .5206 .11157 .53144 .10741 .52557 .0997 Metetra
.664 .741 .908 r
.52557 .0997 .53144 .10741 .54232 .10324 .53648 .0955 Metetra
.664 .741 .908 r
.53648 .0955 .54232 .10324 .55324 .09906 .54743 .09128 Metetra
.664 .741 .908 r
.54743 .09128 .55324 .09906 .56421 .09485 .55842 .08705 Metetra
.664 .741 .908 r
.55842 .08705 .56421 .09485 .57522 .09063 .56946 .0828 Metetra
.664 .741 .908 r
.56946 .0828 .57522 .09063 .58628 .0864 .58055 .07853 Metetra
.661 .74 .909 r
.58055 .07853 .58628 .0864 .59738 .08229 .59168 .07432 Metetra
.646 .732 .911 r
.59168 .07432 .59738 .08229 .60855 .07895 .60286 .07048 Metetra
.647 .718 .9 r
.60286 .07048 .60855 .07895 .61977 .07542 .61409 .06656 Metetra
.66 .713 .887 r
.61409 .06656 .61977 .07542 .63099 .07067 .62536 .06225 Metetra
.661 .727 .899 r
.62536 .06225 .63099 .07067 .64226 .06598 .63668 .05794 Metetra
.655 .737 .91 r
.63668 .05794 .64226 .06598 .65361 .06211 .64804 .05379 Metetra
.656 .73 .904 r
.64804 .05379 .65361 .06211 .665 .05816 .65946 .0496 Metetra
.67 .73 .895 r
.65946 .0496 .665 .05816 .6764 .05332 .6709 .04497 Metetra
.671 .737 .9 r
.6709 .04497 .6764 .05332 .68784 .04846 .68239 .04031 Metetra
.672 .745 .906 r
.68239 .04031 .68784 .04846 .69932 .04358 .69392 .03564 Metetra
.672 .753 .911 r
.69392 .03564 .69932 .04358 .71085 .03869 .70549 .03095 Metetra
.664 .757 .919 r
.05029 .27441 .05735 .28046 .06644 .27717 .05944 .27088 Metetra
.664 .749 .914 r
.05944 .27088 .06644 .27717 .07558 .27386 .06863 .26732 Metetra
.664 .742 .908 r
.06863 .26732 .07558 .27386 .08474 .27055 .07785 .26375 Metetra
.663 .734 .903 r
.07785 .26375 .08474 .27055 .09394 .26721 .0871 .26017 Metetra
.662 .727 .897 r
.0871 .26017 .09394 .26721 .10324 .26345 .09638 .25658 Metetra
.663 .733 .902 r
.09638 .25658 .10324 .26345 .11257 .25965 .1057 .25297 Metetra
.68 .744 .9 r
.1057 .25297 .11257 .25965 .12191 .25602 .11511 .24894 Metetra
.68 .733 .89 r
.11511 .24894 .12191 .25602 .13128 .25239 .12455 .24485 Metetra
.663 .715 .887 r
.12455 .24485 .13128 .25239 .14073 .24838 .13398 .24114 Metetra
.662 .725 .896 r
.13398 .24114 .14073 .24838 .15022 .2443 .14344 .23749 Metetra
.663 .739 .906 r
.14344 .23749 .15022 .2443 .1597 .24058 .15293 .23381 Metetra
.664 .741 .908 r
.15293 .23381 .1597 .24058 .1692 .23692 .16245 .23013 Metetra
.664 .741 .908 r
.16245 .23013 .1692 .23692 .17874 .23325 .17201 .22643 Metetra
.664 .741 .908 r
.17201 .22643 .17874 .23325 .18832 .22956 .18161 .22272 Metetra
.664 .741 .908 r
.18161 .22272 .18832 .22956 .19793 .22586 .19124 .21899 Metetra
.664 .741 .908 r
.19124 .21899 .19793 .22586 .20758 .22215 .20091 .21525 Metetra
.664 .741 .908 r
.20091 .21525 .20758 .22215 .21726 .21842 .21061 .2115 Metetra
.664 .741 .908 r
.21061 .2115 .21726 .21842 .22698 .21468 .22035 .20773 Metetra
.664 .741 .908 r
.22035 .20773 .22698 .21468 .23673 .21092 .23013 .20395 Metetra
.664 .741 .908 r
.23013 .20395 .23673 .21092 .24653 .20715 .23994 .20015 Metetra
.664 .741 .908 r
.23994 .20015 .24653 .20715 .25635 .20336 .24979 .19634 Metetra
.664 .741 .908 r
.24979 .19634 .25635 .20336 .26622 .19956 .25968 .19251 Metetra
.664 .741 .908 r
.25968 .19251 .26622 .19956 .27612 .19575 .2696 .18867 Metetra
.664 .741 .908 r
.2696 .18867 .27612 .19575 .28607 .19192 .27957 .18482 Metetra
.664 .741 .908 r
.27957 .18482 .28607 .19192 .29604 .18808 .28957 .18095 Metetra
.664 .741 .908 r
.28957 .18095 .29604 .18808 .30606 .18422 .29961 .17706 Metetra
.664 .741 .908 r
.29961 .17706 .30606 .18422 .31612 .18035 .30969 .17317 Metetra
.664 .741 .908 r
.30969 .17317 .31612 .18035 .32621 .17647 .3198 .16925 Metetra
.664 .741 .908 r
.3198 .16925 .32621 .17647 .33634 .17256 .32996 .16532 Metetra
.664 .741 .908 r
.32996 .16532 .33634 .17256 .34651 .16865 .34015 .16138 Metetra
.664 .741 .908 r
.34015 .16138 .34651 .16865 .35672 .16472 .35039 .15742 Metetra
.664 .741 .908 r
.35039 .15742 .35672 .16472 .36697 .16077 .36066 .15345 Metetra
.664 .741 .908 r
.36066 .15345 .36697 .16077 .37726 .15681 .37097 .14946 Metetra
.664 .741 .908 r
.37097 .14946 .37726 .15681 .38758 .15283 .38132 .14545 Metetra
.664 .741 .908 r
.38132 .14545 .38758 .15283 .39795 .14884 .39172 .14143 Metetra
.664 .741 .908 r
.39172 .14143 .39795 .14884 .40836 .14483 .40215 .13739 Metetra
.664 .741 .908 r
.40215 .13739 .40836 .14483 .41881 .14081 .41262 .13334 Metetra
.664 .741 .908 r
.41262 .13334 .41881 .14081 .4293 .13677 .42314 .12927 Metetra
.664 .741 .908 r
.42314 .12927 .4293 .13677 .43983 .13272 .43369 .12519 Metetra
.664 .741 .908 r
.43369 .12519 .43983 .13272 .4504 .12865 .44429 .12109 Metetra
.664 .741 .908 r
.44429 .12109 .4504 .12865 .46101 .12456 .45493 .11697 Metetra
.664 .741 .908 r
.45493 .11697 .46101 .12456 .47166 .12046 .46561 .11284 Metetra
.664 .741 .908 r
.46561 .11284 .47166 .12046 .48236 .11634 .47633 .10869 Metetra
.664 .741 .908 r
.47633 .10869 .48236 .11634 .4931 .1122 .4871 .10453 Metetra
.664 .741 .908 r
.4871 .10453 .4931 .1122 .50388 .10805 .49791 .10035 Metetra
.664 .741 .908 r
.49791 .10035 .50388 .10805 .5147 .10388 .50876 .09615 Metetra
.664 .741 .908 r
.50876 .09615 .5147 .10388 .52557 .0997 .51965 .09193 Metetra
.664 .741 .908 r
.51965 .09193 .52557 .0997 .53648 .0955 .53059 .0877 Metetra
.664 .741 .908 r
.53059 .0877 .53648 .0955 .54743 .09128 .54157 .08345 Metetra
.664 .741 .908 r
.54157 .08345 .54743 .09128 .55842 .08705 .55259 .07919 Metetra
.664 .741 .908 r
.55259 .07919 .55842 .08705 .56946 .0828 .56366 .07491 Metetra
.664 .741 .908 r
.56366 .07491 .56946 .0828 .58055 .07853 .57478 .07061 Metetra
.664 .741 .908 r
.57478 .07061 .58055 .07853 .59168 .07432 .58593 .06629 Metetra
.663 .739 .906 r
.58593 .06629 .59168 .07432 .60286 .07048 .59714 .06196 Metetra
.66 .724 .896 r
.59714 .06196 .60286 .07048 .61409 .06656 .60839 .05766 Metetra
.644 .707 .893 r
.60839 .05766 .61409 .06656 .62536 .06225 .6197 .05377 Metetra
.647 .721 .903 r
.6197 .05377 .62536 .06225 .63668 .05794 .63105 .04981 Metetra
.663 .74 .907 r
.63105 .04981 .63668 .05794 .64804 .05379 .64244 .04541 Metetra
.663 .733 .902 r
.64244 .04541 .64804 .05379 .65946 .0496 .65388 .04099 Metetra
.662 .727 .897 r
.65388 .04099 .65946 .0496 .6709 .04497 .66536 .03655 Metetra
.663 .734 .903 r
.66536 .03655 .6709 .04497 .68239 .04031 .67689 .0321 Metetra
.664 .742 .908 r
.67689 .0321 .68239 .04031 .69392 .03564 .68847 .02763 Metetra
.664 .749 .914 r
.68847 .02763 .69392 .03564 .70549 .03095 .70009 .02313 Metetra
.663 .741 .908 r
.04326 .26787 .05029 .27441 .05944 .27088 .05243 .26431 Metetra
.663 .741 .908 r
.05243 .26431 .05944 .27088 .06863 .26732 .06163 .26073 Metetra
.673 .744 .904 r
.06163 .26073 .06863 .26732 .07785 .26375 .0709 .25692 Metetra
.672 .736 .898 r
.0709 .25692 .07785 .26375 .0871 .26017 .08021 .25308 Metetra
.663 .727 .897 r
.08021 .25308 .0871 .26017 .09638 .25658 .08951 .24944 Metetra
.662 .726 .897 r
.08951 .24944 .09638 .25658 .1057 .25297 .09885 .24582 Metetra
.67 .728 .893 r
.09885 .24582 .1057 .25297 .11511 .24894 .10824 .24197 Metetra
.672 .735 .898 r
.10824 .24197 .11511 .24894 .12455 .24485 .11768 .23808 Metetra
.665 .741 .907 r
.11768 .23808 .12455 .24485 .13398 .24114 .12712 .23438 Metetra
.664 .741 .908 r
.12712 .23438 .13398 .24114 .14344 .23749 .1366 .2307 Metetra
.664 .741 .908 r
.1366 .2307 .14344 .23749 .15293 .23381 .14611 .227 Metetra
.664 .741 .908 r
.14611 .227 .15293 .23381 .16245 .23013 .15565 .22329 Metetra
.664 .741 .908 r
.15565 .22329 .16245 .23013 .17201 .22643 .16523 .21957 Metetra
.664 .741 .908 r
.16523 .21957 .17201 .22643 .18161 .22272 .17485 .21583 Metetra
.664 .741 .908 r
.17485 .21583 .18161 .22272 .19124 .21899 .1845 .21208 Metetra
.664 .741 .908 r
.1845 .21208 .19124 .21899 .20091 .21525 .19419 .20831 Metetra
.664 .741 .908 r
.19419 .20831 .20091 .21525 .21061 .2115 .20391 .20453 Metetra
.664 .741 .908 r
.20391 .20453 .21061 .2115 .22035 .20773 .21367 .20073 Metetra
.664 .741 .908 r
.21367 .20073 .22035 .20773 .23013 .20395 .22347 .19693 Metetra
.664 .741 .908 r
.22347 .19693 .23013 .20395 .23994 .20015 .23331 .1931 Metetra
.664 .741 .908 r
.23331 .1931 .23994 .20015 .24979 .19634 .24318 .18926 Metetra
.664 .741 .908 r
.24318 .18926 .24979 .19634 .25968 .19251 .25309 .18541 Metetra
.664 .741 .908 r
.25309 .18541 .25968 .19251 .2696 .18867 .26304 .18155 Metetra
.664 .741 .908 r
.26304 .18155 .2696 .18867 .27957 .18482 .27303 .17766 Metetra
.664 .741 .908 r
.27303 .17766 .27957 .18482 .28957 .18095 .28305 .17377 Metetra
.664 .741 .908 r
.28305 .17377 .28957 .18095 .29961 .17706 .29311 .16985 Metetra
.664 .741 .908 r
.29311 .16985 .29961 .17706 .30969 .17317 .30321 .16593 Metetra
.664 .741 .908 r
.30321 .16593 .30969 .17317 .3198 .16925 .31335 .16199 Metetra
.664 .741 .908 r
.31335 .16199 .3198 .16925 .32996 .16532 .32353 .15803 Metetra
.664 .741 .908 r
.32353 .15803 .32996 .16532 .34015 .16138 .33375 .15406 Metetra
.664 .741 .908 r
.33375 .15406 .34015 .16138 .35039 .15742 .34401 .15007 Metetra
.664 .741 .908 r
.34401 .15007 .35039 .15742 .36066 .15345 .3543 .14607 Metetra
.664 .741 .908 r
.3543 .14607 .36066 .15345 .37097 .14946 .36464 .14205 Metetra
.664 .741 .908 r
.36464 .14205 .37097 .14946 .38132 .14545 .37502 .13801 Metetra
.664 .741 .908 r
.37502 .13801 .38132 .14545 .39172 .14143 .38544 .13396 Metetra
.664 .741 .908 r
.38544 .13396 .39172 .14143 .40215 .13739 .3959 .1299 Metetra
.664 .741 .908 r
.3959 .1299 .40215 .13739 .41262 .13334 .4064 .12582 Metetra
.664 .741 .908 r
.4064 .12582 .41262 .13334 .42314 .12927 .41694 .12172 Metetra
.664 .741 .908 r
.41694 .12172 .42314 .12927 .43369 .12519 .42752 .11761 Metetra
.664 .741 .908 r
.42752 .11761 .43369 .12519 .44429 .12109 .43814 .11348 Metetra
.664 .741 .908 r
.43814 .11348 .44429 .12109 .45493 .11697 .44881 .10933 Metetra
.664 .741 .908 r
.44881 .10933 .45493 .11697 .46561 .11284 .45951 .10517 Metetra
.664 .741 .908 r
.45951 .10517 .46561 .11284 .47633 .10869 .47026 .10099 Metetra
.664 .741 .908 r
.47026 .10099 .47633 .10869 .4871 .10453 .48106 .09679 Metetra
.664 .741 .908 r
.48106 .09679 .4871 .10453 .49791 .10035 .49189 .09258 Metetra
.664 .741 .908 r
.49189 .09258 .49791 .10035 .50876 .09615 .50277 .08835 Metetra
.664 .741 .908 r
.50277 .08835 .50876 .09615 .51965 .09193 .51369 .08411 Metetra
.664 .741 .908 r
.51369 .08411 .51965 .09193 .53059 .0877 .52466 .07985 Metetra
.664 .741 .908 r
.52466 .07985 .53059 .0877 .54157 .08345 .53567 .07557 Metetra
.664 .741 .908 r
.53567 .07557 .54157 .08345 .55259 .07919 .54672 .07127 Metetra
.664 .741 .908 r
.54672 .07127 .55259 .07919 .56366 .07491 .55782 .06695 Metetra
.664 .741 .908 r
.55782 .06695 .56366 .07491 .57478 .07061 .56896 .06262 Metetra
.664 .741 .908 r
.56896 .06262 .57478 .07061 .58593 .06629 .58015 .05827 Metetra
.664 .741 .908 r
.58015 .05827 .58593 .06629 .59714 .06196 .59138 .05391 Metetra
.662 .741 .908 r
.59138 .05391 .59714 .06196 .60839 .05766 .60266 .04955 Metetra
.655 .737 .91 r
.60266 .04955 .60839 .05766 .6197 .05377 .61399 .04539 Metetra
.655 .73 .904 r
.61399 .04539 .6197 .05377 .63105 .04981 .62537 .04118 Metetra
.662 .726 .897 r
.62537 .04118 .63105 .04981 .64244 .04541 .63679 .03675 Metetra
.661 .726 .897 r
.63679 .03675 .64244 .04541 .65388 .04099 .64826 .03231 Metetra
.653 .723 .9 r
.64826 .03231 .65388 .04099 .66536 .03655 .65978 .02808 Metetra
.654 .73 .905 r
.65978 .02808 .66536 .03655 .67689 .0321 .67135 .02382 Metetra
.663 .741 .908 r
.67135 .02382 .67689 .0321 .68847 .02763 .68296 .01931 Metetra
.663 .741 .908 r
.68296 .01931 .68847 .02763 .70009 .02313 .69462 .01478 Metetra
.663 .741 .908 r
.03619 .26128 .04326 .26787 .05243 .26431 .04537 .2577 Metetra
.663 .741 .908 r
.04537 .2577 .05243 .26431 .06163 .26073 .05459 .2541 Metetra
.681 .746 .9 r
.05459 .2541 .06163 .26073 .0709 .25692 .06391 .25003 Metetra
.681 .739 .894 r
.06391 .25003 .0709 .25692 .08021 .25308 .07327 .24594 Metetra
.663 .727 .897 r
.07327 .24594 .08021 .25308 .08951 .24944 .08259 .24227 Metetra
.662 .726 .897 r
.08259 .24227 .08951 .24944 .09885 .24582 .09195 .23861 Metetra
.662 .726 .897 r
.09195 .23861 .09885 .24582 .10824 .24197 .10134 .23495 Metetra
.663 .733 .902 r
.10134 .23495 .10824 .24197 .11768 .23808 .11076 .23126 Metetra
.663 .74 .907 r
.11076 .23126 .11768 .23808 .12712 .23438 .12022 .22757 Metetra
.664 .741 .908 r
.12022 .22757 .12712 .23438 .1366 .2307 .12971 .22386 Metetra
.664 .741 .908 r
.12971 .22386 .1366 .2307 .14611 .227 .13924 .22014 Metetra
.664 .741 .908 r
.13924 .22014 .14611 .227 .15565 .22329 .1488 .2164 Metetra
.664 .741 .908 r
.1488 .2164 .15565 .22329 .16523 .21957 .1584 .21265 Metetra
.664 .741 .908 r
.1584 .21265 .16523 .21957 .17485 .21583 .16804 .20889 Metetra
.664 .741 .908 r
.16804 .20889 .17485 .21583 .1845 .21208 .17771 .20511 Metetra
.664 .741 .908 r
.17771 .20511 .1845 .21208 .19419 .20831 .18742 .20132 Metetra
.664 .741 .908 r
.18742 .20132 .19419 .20831 .20391 .20453 .19717 .19751 Metetra
.664 .741 .908 r
.19717 .19751 .20391 .20453 .21367 .20073 .20695 .19369 Metetra
.664 .741 .908 r
.20695 .19369 .21367 .20073 .22347 .19693 .21677 .18986 Metetra
.664 .741 .908 r
.21677 .18986 .22347 .19693 .23331 .1931 .22663 .18601 Metetra
.664 .741 .908 r
.22663 .18601 .23331 .1931 .24318 .18926 .23652 .18214 Metetra
.664 .741 .908 r
.23652 .18214 .24318 .18926 .25309 .18541 .24646 .17826 Metetra
.664 .741 .908 r
.24646 .17826 .25309 .18541 .26304 .18155 .25643 .17437 Metetra
.664 .741 .908 r
.25643 .17437 .26304 .18155 .27303 .17766 .26644 .17046 Metetra
.664 .741 .908 r
.26644 .17046 .27303 .17766 .28305 .17377 .27648 .16653 Metetra
.664 .741 .908 r
.27648 .16653 .28305 .17377 .29311 .16985 .28657 .16259 Metetra
.664 .741 .908 r
.28657 .16259 .29311 .16985 .30321 .16593 .29669 .15864 Metetra
.664 .741 .908 r
.29669 .15864 .30321 .16593 .31335 .16199 .30686 .15467 Metetra
.664 .741 .908 r
.30686 .15467 .31335 .16199 .32353 .15803 .31706 .15068 Metetra
.664 .741 .908 r
.31706 .15068 .32353 .15803 .33375 .15406 .3273 .14668 Metetra
.664 .741 .908 r
.3273 .14668 .33375 .15406 .34401 .15007 .33758 .14267 Metetra
.664 .741 .908 r
.33758 .14267 .34401 .15007 .3543 .14607 .3479 .13864 Metetra
.664 .741 .908 r
.3479 .13864 .3543 .14607 .36464 .14205 .35827 .13459 Metetra
.664 .741 .908 r
.35827 .13459 .36464 .14205 .37502 .13801 .36867 .13053 Metetra
.664 .741 .908 r
.36867 .13053 .37502 .13801 .38544 .13396 .37911 .12645 Metetra
.664 .741 .908 r
.37911 .12645 .38544 .13396 .3959 .1299 .3896 .12235 Metetra
.664 .741 .908 r
.3896 .12235 .3959 .1299 .4064 .12582 .40012 .11824 Metetra
.664 .741 .908 r
.40012 .11824 .4064 .12582 .41694 .12172 .41069 .11411 Metetra
.664 .741 .908 r
.41069 .11411 .41694 .12172 .42752 .11761 .4213 .10997 Metetra
.664 .741 .908 r
.4213 .10997 .42752 .11761 .43814 .11348 .43195 .10581 Metetra
.664 .741 .908 r
.43195 .10581 .43814 .11348 .44881 .10933 .44264 .10163 Metetra
.664 .741 .908 r
.44264 .10163 .44881 .10933 .45951 .10517 .45337 .09744 Metetra
.664 .741 .908 r
.45337 .09744 .45951 .10517 .47026 .10099 .46415 .09323 Metetra
.664 .741 .908 r
.46415 .09323 .47026 .10099 .48106 .09679 .47497 .08901 Metetra
.664 .741 .908 r
.47497 .08901 .48106 .09679 .49189 .09258 .48583 .08476 Metetra
.664 .741 .908 r
.48583 .08476 .49189 .09258 .50277 .08835 .49674 .0805 Metetra
.664 .741 .908 r
.49674 .0805 .50277 .08835 .51369 .08411 .50769 .07623 Metetra
.664 .741 .908 r
.50769 .07623 .51369 .08411 .52466 .07985 .51868 .07193 Metetra
.664 .741 .908 r
.51868 .07193 .52466 .07985 .53567 .07557 .52972 .06762 Metetra
.664 .741 .908 r
.52972 .06762 .53567 .07557 .54672 .07127 .5408 .06329 Metetra
.664 .741 .908 r
.5408 .06329 .54672 .07127 .55782 .06695 .55193 .05894 Metetra
.664 .741 .908 r
.55193 .05894 .55782 .06695 .56896 .06262 .5631 .05458 Metetra
.664 .741 .908 r
.5631 .05458 .56896 .06262 .58015 .05827 .57432 .0502 Metetra
.664 .741 .908 r
.57432 .0502 .58015 .05827 .59138 .05391 .58558 .0458 Metetra
.664 .741 .908 r
.58558 .0458 .59138 .05391 .60266 .04955 .59689 .04138 Metetra
.663 .74 .907 r
.59689 .04138 .60266 .04955 .61399 .04539 .60825 .03695 Metetra
.663 .733 .902 r
.60825 .03695 .61399 .04539 .62537 .04118 .61965 .03249 Metetra
.662 .726 .897 r
.61965 .03249 .62537 .04118 .63679 .03675 .6311 .02802 Metetra
.661 .726 .897 r
.6311 .02802 .63679 .03675 .64826 .03231 .6426 .02356 Metetra
.645 .719 .902 r
.6426 .02356 .64826 .03231 .65978 .02808 .65416 .01954 Metetra
.646 .727 .908 r
.65416 .01954 .65978 .02808 .67135 .02382 .66577 .01548 Metetra
.663 .741 .908 r
.66577 .01548 .67135 .02382 .68296 .01931 .67742 .01094 Metetra
.663 .741 .908 r
.67742 .01094 .68296 .01931 .69462 .01478 .68911 .00637 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.11345 .22526 m
.11813 .22986 L
s
[(-0.2)] .1041 .21606 1 .98388 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.59438 .03695 m
.59817 .0423 L
s
[(0.2)] .58679 .02624 .70809 1 Mshowa
.125 Mabswid
.16898 .20352 m
.17173 .20634 L
s
.22573 .1813 m
.22842 .18417 L
s
.28374 .15858 m
.28638 .16151 L
s
.40374 .1116 m
.40624 .11463 L
s
.46582 .08729 m
.46825 .09038 L
s
.52935 .06241 m
.5317 .06557 L
s
.05912 .24654 m
.06197 .24925 L
s
.66096 .01088 m
.66315 .01415 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[16]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00W`3oool2000000@0oooo00@0
00000?ooo`3oool0oooo1@00001b0?ooo`00WP3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000001T0oooo0P00001G0?ooo`00WP3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo01H0oooo1@00001G0?ooo`00WP3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo01<0oooo0P0000020?ooo`040000002Y_NP00000000005H0oooo002N0?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`<0000000@0oooo
00000000000000000P2Y_NP3000005D0oooo002N0?ooo`040000003oool0oooo000000L0oooo00D0
00000?ooo`3oool0oooo0000000?0?ooo`80000000@0oooo00000000000000000P2Y_NP00`000000
ZKgX0:Vmj003000005D0oooo002O0?ooo`8000002@3oool3000000d0oooo1P0000020:Fjj0030000
002Y_NP0ZKgX00@0000000<0ZKgX000000000000E03oool00;L0oooo1P0000020:FhiP030000002U
^^P0YK[X00<0000000<0ZKgX0000002Y_NP01@00001C0?ooo`00]@3oool500000080ZKWU00<00000
0:FhiP2U^>H00`000000102W^^L000000:Vmj02Y_NP300000080ZKoY0P00001C0?ooo`00/P3oool5
00000080ZKWU00<000000:Vii@2Y^ND00`000000102W^NH000000:Nji`2W^^L300000080ZKgX00<0
00000:Voj@2Y_nT00`00001B0?ooo`00[`3oool5000000030:VkiP000000ZKWU0080ZKWU0`000000
102Y^ND000000:NiiP2W^NH300000080ZK_W00<000000:Vmj02Y_NP00`000000102/`>T000000?oo
o`00001A0?ooo`00[@3oool4000000030:Vmj0000000ZK_V0080ZK_V00D000000:Vii@000000ZKWU
000000020:Vii@<0000000<0ZK[U0000002Y^nL00P2Y^nL500000080[<3Y0`00001A0?ooo`00Z`3o
ool2000000040?ooo`000000000000000080ZKgX00<000000:VkiP2Y^nH00P0000030:Vii@800000
00<0ZK_V0000002Y^^D00P2Y^^D01P000000ZK_W0000002[_>H000000:bni`@000000P2^_nL20000
0500oooo002X0?ooo`H000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Nji`000000ZKWU0:Vi
i@8000000`2Y^nH00`000000ZK[U0:Vji@0200000080ZkcV10000000102^_nL000000:joi`2^_nL2
000000h0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D00000<`3oool00:H0oooo0P000000
0`3oool00000000000020:Vmj0030000002Y_NP0ZKgX00<0000000@0YkcX0000002W^^L0Yk[W0`00
00020:Vmj0030000002Y^nH0ZK_V00<0000000T0Zk[U0000002[_>H000000:k1j0000000[[oW0000
002^_nL00`0000000`2^_nH000000000000<0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool00000<`3oool00:<0oooo1P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj000
0000YkcX0:Nlj0<000000P2U^>L00`000000ZKgX0:Vmj003000000040:Nji`000000Zk[U0:^ji@80
00000`2^`NP3000000040:joiP000000[[oV0:joiP<00000103oool500000080oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`0c0?ooo`00X03oool6000000040:Vmj0000000ZKgX
0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Bdi0030000002U^>L0YKSW00<0000000@0
YkcX0000002W^^L0Yk[W0`0000020:k3j@030000002^`NP0[/7X008000000P2^_nH300000080[/7X
00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0380
oooo002N0?ooo`D0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP000000080
00000P2X^ND00`000000Y;CT0:Bdi003000000040:VjiP000000YkcX0:Nlj0<000000P2U_N/00`00
0000[/?Y0:k3j@03000000040:c0j0000000[[oV00000080[/?Y00<000000:k1j02^`NP00P00000:
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`00V`3o
ool5000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgW
00<000000:Rii@2X^ND00`000000102X]^<000000:VjiP2Y^^H300000080YKcY00<000000:Fmj`2U
_N/00`000000102/`^X000000:c0j02/`>P2000000<0[/?Y0`0000000`2/`>T00000000000090?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`00V@3oool2
000000040?ooo`000000ZKgX00000080ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0
ZKgX0000002Y_NL0ZKgW0`000000102U]nH000000:Rfh`2X]^<300000080[KkW00<000000:Flj@2U
_>T00`000000102W_^X000000:c2jP2/`^X4000000060:Znj0000000[/?Y0000002/`^X000000P2/
`>T2000000X0oooo0P0000090?ooo`<00000=03oool009H0oooo0`0000000`3oool0000000000003
0:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000<0
YK_Y0000002U]nH00P2U]nH200000080[KkV00<000000:fni`2]_^L00`000000102W_>T000000:Nn
jP2W_^X300000080ZK[V0P0000000`2Z_^P00000000000020:c2jP<0000000<0Z[kX000000000000
B`3oool009@0oooo0P0000001P3oool00000000000000000ZKgX00000080ZKgX0P0000030:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002U^nT0000000@000000`2]_^H30000
00040:foi`000000YkcY0:Nlj@<000000P2Y^^H00`000000ZK[V0:VjiP03000000060:foi`000000
[<;Z0000002Z_^P000000P2Z_^P3000004X0oooo002A0?ooo`H000000P2Y_NP00`000000ZKgX0000
000200000080ZKgX00D000000:Vmj0000000ZKgX000000020:Vmj0<000000P2Y_NP00`000000ZKgX
0:Vmj002000000030:2ci@000000X[OW0080X[OW00D000000:fniP000000[[oV000000020:foi`<0
00000P2Y^^D00`000000ZK[V0:VjiP03000000040:fki0000000[KoW0:foi`8000000`2Z_^P20000
0080ZKgX00<000000?ooo`3oool0B03oool008l0oooo1@0000020:Vmj0030000002Y_NP0ZKgX0080
00000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX00<0
000000D0YkOT0000002P/nD0X;?U000000020::gi`8000000P2^_nH300000080[K_T00<000000:Vj
i@2Y^^D00`000000102Y^ND000000:fki02]^n@3000000040;;4j0000000Z[kX0:Znj08000000`2Y
_NP2000004T0oooo002<0?ooo`D000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000
ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000030:Vmj0<0000000<0ZKWU0000002W]n@0
0P2W]n@00`000000X;?U00000002000000060:Fhi`000000[[oV0000002]^n@000000`2]^n@30000
00040:Vii@000000ZKWU0:Vii@D000000P2ba>P300000080ZKgX00@000000:Vmj0000000ZKgX0P00
00180?ooo`00R@3oool500000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y
_NP300000080ZKgX00<000000:Vmj00000000P0000020:Vmj0050000002Y_NP000000:Vji@000000
0`2Y^ND00`000000YkOT00000002000000040:Bdi0000000YKSW0:Fhi`8000000`2]^n@01@000000
[K_T0000002]^n@000000080ZKWU0`0000000`2Z`NX000000;;7jP0400000080[l?Y00<000000:Vm
j02Y_NP00P0000030:Vmj0030000003oool0oooo04H0oooo001W0?ooo`8000007P3oool500000004
0:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP0
ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZK[U00<000000:Vii@0000000P000002
0:Jfi0030000002T]>@00000008000000P2Y^nH00`000000[K_T0:fki002000000<0[K_T0P000000
102Y_NP000000:[1jP2Z`NX300000080[lO/00<000000:o3j@2_`nT00`000000102Y_NP000000:Vm
j02Y_NP3000004L0oooo001V0?ooo`040000003oool0oooo000001X0oooo1@000000102Y_NP00000
0:Vmj02Y_NP300000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX00<0
000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y^^D000000:Vji@2Y^^D300000080YkSU00<00000
0:Jfi02V]^@00P0000020:Vli`030000002Y^nH0ZK_V00<0000000@0[K_T0000002]^n@0[K_T0P00
00020:Vmj0<000000P2^`nX00`000000[lO/0:o7k003000000040:Znj0000000ZKgX0:Vmj0<00000
00@0ZKgX0000003oool00000AP3oool006H0oooo00@000000?ooo`3oool00000603oool400000080
ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000
ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZK_V0000002Y^^D0ZK[U0`000002
0:Vii@030000002W^>D0YkSU00<0000000@0YKSV0000002Y_>L0ZKcW0`000000102X^nL000000:fk
i02]^n@3000000040:g0i`000000ZKgX00000080[KoW00<000000:k3jP2^`nX00`000000102Z_nT0
00000:Znj02Z_^P3000000040:Vmj0000000ZKgX0:Vmj0<00000AP3oool006H0oooo00@000000?oo
o`3oool000005@3oool400000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0
ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX
00<000000:VkiP0000000P0000020:Vii@030000002Y^ND0ZKWU00<0000000@0YKGT0000002U^>H0
YKSV0`000000102W_>P000000:Rki`2X^nL300000080[/;X00@000000:g0i`00000000000`2]_nL5
00000080Z[oY0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX0P0000150?ooo`00IP3oool0
10000000oooo0?ooo`00000C0?ooo`80000000<0oooo0000000000000`2Y_NP3000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP000000080
00000P2Y_NP00`000000ZKgX0:Vmj00200000080Yk[W00<000000:Vii@2Y^ND00`000000102X]n@0
00000:Fei02U]N@3000000040:RjiP000000YkcX0:Nlj0<000000P2V_n/00`000000[/;X0:k2j002
00000080[<3X00H000000:foi`000000//CW0000002a`nL4000000040:Vmj0000000ZKgX0:Vmj0<0
00000P2Y_NP00`000000ZKgX0:Vmj003000004@0oooo001V0?ooo`040000003oool0oooo00000100
oooo1P0000020:Vmj0050000002Y_NP000000:Vmj00000000P2Y_NP300000080ZKgX00<000000:Vm
j00000000P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj0030000
00040:Nlj0000000Yk[W0:Nji`<0000000@0ZKWU0000002X]n@0Z;OT0`0000020:Rfh`030000002X
^^H00000008000000P2U_n`00`000000Y[o[0:Joj`03000000040:c2jP000000[<3X0:c0j0800000
0P2ba>L3000000040;32i`000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00300000003
0:Vmj0000000000004@0oooo001W0?ooo`8000003`3oool2000000060?ooo`00000000000000002Y
_NP000000P2Y_NP2000000<0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`00
0000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002W_>P0YkcX0`00
0000102V^>H000000:Vii@2Y^ND300000080YkKT00<000000:Rfh`2X]^<00P0000020:c2j@030000
002U_n`0YKo/00<0000000@0Y/3/0000002/`^X0[<;Z0`000000102[_^P000000000000000020;74
j0030000002``^L00000008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX
0:Vmj0<00000@`3oool007D0oooo1P000000102Y_NP000000:Vmj02Y_NP300000080ZKgX00D00000
0:Vmj0000000ZKgX000000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP00000
0:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2U^>L00`000000Y[SV000000020000
0080YkSU00<000000:Nfi02W]^@00`000000102^`^P000000:c2j@2/`^T3000000040:Fok@000000
Y/3/0:K0k0<0000000@0ZK_V0000002[_^P000000P2]_nL00`000000/LCX0;74j00200000080[[oW
00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000oooo0000
0480oooo001b0?ooo`H000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj02Y
_NP00P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3
00000080ZKgX00<000000:Vmj00000000P0000020:Rki`030000002U^>L0YKSW008000000P2U^>H0
0`000000YkSU0:Nhi@03000000040:NmjP000000[/;X0:k2j0<0000000@0[L?Z0000002U_nd0YKo]
0`000000102U^NL000000:VkiP2Y^nH2000000<0[KoW0`000000102^`>L000000:joi`2^_nL30000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000120?ooo`00L03oool2
000000030?ooo`00000000000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0
ZKgX00<0000000@0ZKgX0000002Y_NP000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<0
00000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NL00`000000Z;_W0:Rk
i`03000000040:BhiP000000YKSV0:FhiP<0000000@0YK_Y0000002W_NX0YkgZ0`000000102^`nT0
00000:g3jP2]`nX300000080YKWW00<000000:Fii`0000000P0000020:fki0050000002]_nL00000
0;72iP0000000P2^`>L3000000040:joi`000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX
0`000000102Y_NP000000?ooo`0000110?ooo`00K@3oool6000000040:Vmj0000000ZKgX0:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP2000000<0ZKgX0P000002
0:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000
ZKgW0:Vmi`<0000000@0Y[[W0000002T^>H0Y;SV0`000000102U]nH000000:Fkj@2U^nT300000080
Z;oZ00<000000:k3j@0000000P0000020:bli@030000002U^NL0YKWW008000000P2V^>H00`000000
[K_T0:fki00200000080/L;V1@0000020:joi`<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vm
j0030000002Y_NP0000000800000@@3oool006/0oooo1@000000102Y_NP000000:Vmj02Y_NP30000
0080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP01@00
0000ZKgX0000002Y_NP000000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0YkcX0000002V^^L0Y[[W0`0000020:BbhP030000002U]nH000000080
00000P2W_NT00`000000Z;oZ0:RojP0200000080[KcT00<000000:bli@2/_>D00`000000102U^>H0
00000:JhiP2V^>H3000000070;73i`000000/L;V0000002``^L000000:joiP0400000080[/7X00<0
00000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP200000400oooo001X
0?ooo`D0000000@0ZKgX000000000000ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y
_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000YkcX
0000000200000080Y;7R00<000000:BbhP2T/^800P0000020:Vii0030000002W_NT0YkgY00<00000
00@0Z[_V0000002]_>@0[KcT0`000000102/^^@000000:FhiP2U^>H3000000040:JmjP000000/L?W
0;73i`<0000000@0/<;W00000000000000000P2^`^T00`000000[/7X0:k1j00200000080ZKgX00<0
00000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000003l0oooo001V0?ooo`@000000P2Y
_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vm
j02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX00000000000000000P2Y_NP00`00
0000ZKgX0000000200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX
008000000P2T/^800`000000Y;7R0:BahP03000000040:Vdh0000000ZKWT0:Vii0<0000000@0ZK[V
0000002Z^nH0Z[_V0`000000102]^n@000000:bji02/^^@3000000040:Fkj@000000Y[gZ0:JmjP<0
00000P2aa>P200000080[l?Y00<000000:k2j@2^`^T00`000000102/`>P000000:Vmj02Y_NP30000
00040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX000000000000?`3oool006<0oooo1@000000102Y
_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0000
000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj08000000P2Y_NP00`000000ZKgX0:Vm
j00200000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Ne
h`000000Y;;R0:BbhP<0000000@0YK7P0000002Y]>00ZKCP0`000000102__^D000000:VjiP2Y^^H3
000000040:Zji@000000[K_T0:fki0<000000P2/_^H00`000000YK_Y0000000200000080Z;oZ00D0
00000;74j0000000[l?Y000000020:o3j@<0000000@0[<;Z0000002/`>P0[<3X0`000000102Y_NP0
00000:Vmj02Y_NP3000000050:Vmj000000000000000002Y_NP00P00000n0?ooo`00H@3oool40000
0080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`00
0000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0050000002Y_NP00000
0:Vmj00000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX
0`000000102Y^ND000000:Neh`2W]N<3000000030:B`h@000000YK7P0080YK7P0P0000020;71iP03
0000002__^D00000008000000P2Y^ND00`000000Z[[U0000000200000080[[kV00<000000:bniP2/
_^H00P0000020:Nlj@030000002X_nX0Z;oZ008000000P2_`nT500000080[<;Z0`000000102Z_^P0
00000:Vmj02Y_NP3000000060:Vmj0000000ZKgX0000002Y_NP000000P2Y_NP3000003d0oooo001M
0?ooo`D000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P000002
0:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vm
j02Y_NP200000080ZKgX0`0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX
0000000200000080ZK_V00<000000:Vii@0000000P0000000`2U/n<000000:B`h@020:B`h@040000
002U/N000000000000<0/L7V0P0000020:fniP030000002Y^ND0ZKWU008000000P2Z_NL00`000000
[[kV0:jniP03000000040:fni`000000YkcY0:Nlj@<0000000L0ZKgX00000000000000000:k3j@00
0000[/?Y00@0000000@0Z[kX0000002Z_^P0Z[kX0`000000102Y_NP000000:Vmj02Y_NP300000004
0:Vmj0000000000000000080ZKgX00<000000?ooo`3oool0>`3oool005`0oooo10000000102Y_NP0
00000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`00
0000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX00000000
000000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vm
i`030000002Y^nH0ZK_V008000000P2U]nD01@000000YK?S0:Fch`000000Y;3Q00<000000P2X_NT0
1@000000/L7V0000002_`^P000000080[KkV0`000000102Y_>L000000:Zmi`2Z_NL3000000040:jo
iP000000[KkW0:fni`<0000000H0Z;ST0000002Y_NP000000:jni@0000020:k3j@<0000000@0[/7X
0000002Z_^P0Z[kX0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX0P0000020:Vmj0030000
002Y_NP0ZKgX00800000?03oool005T0oooo100000020:Vmj0030000002Y_NP00000008000000P2Y
_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y
_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX0P0000020:Vmj0030000002Y
_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmi`2Y_NL300000004
0:Nji`000000YKOU0:Fgi@D000000P2U^^P00`000000Z;gY0:Rmj@0200000080[l;X0`000000102Z
_NP000000:Vli`2Y_>L3000000040:Znj0000000[[oV0:joiP<0000000@0[K_T0000002X^>@0Z;ST
0P0000030:jni@8000000P2^`nT00`000000[/7X0000000200000080ZKgX00<000000:Vmj0000000
0P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000000000k0?ooo`00
EP3oool400000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX00800000
0P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000
002Y_NP0ZKgX008000000P2Y_NP01@000000ZKgX0000002Y_NP000000080ZKgX0`000000102Y_NP0
00000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0YkcX0000002W^^L0Yk[W0`00
00001@2P/nH000000::gi`2R]nL000000080YK[X0`0000001P2Y`>X00000000000000000Z[kX0000
0080Z[gX0`000000102Y_NP000000:Znj02Z_^P300000080[[kV00<000000:fki00000000P000002
0:fhh@050000002^_^D000000;C4iP0000000P2^`nT200000080[<3X00<000000:Vmj02Y_NP00P00
00020:Vmj0050000002Y_NP000000:Vmj00000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj080
0000>`3oool005@0oooo10000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vm
j0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000000000000020:Vm
j0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Nl
j00000000P0000020:>ci0030000002P/nH0000000D0000000@0YkgY00000000000000000P2Y_NL0
0`000000Z[kX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Znj0030000002^_^H0
[[kV008000000P2[^N@00`000000[KSQ0:fhh@0200000080]<CV1@0000020:c0j0<0000000@0ZKgX
0000002Y_NP0ZKgX0P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP00000
0000000j0?ooo`00D@3oool400000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y
_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P00
00020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX0P00
00020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<0
00000:Vmj02Y_NP00P0000020:BbhP030000002S/n@0Xk?T008000000P2T]ND00`000000Y;WW0:Bi
i`0200000080ZK[V00<000000:Vmi`2Y_NL00P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y
_NP00`000000Z[kX0:Znj003000000040:Zmi`000000ZkWT0:^ii0<0000000L0]<?U000000000000
00000;G6i`000000[L;Z00@0000000@0Z[kX0000002Y_NP0ZKgX0`0000001P2Y_NP0000000000000
0000ZKgX00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000003T0oooo001>0?ooo`<00000
00@0oooo0000002Y_NP000000P2Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj003
0000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y
_NP00P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vm
j0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Neh`00
0000Y;;R0:BbhP<0000000@0YK?R0000002T]ND0Y;GU0`000000102X^ND000000:VjiP2Y^^H30000
00040:^liP000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Zm
i`2Z_NL3000000060:Rmj@000000]<?U0000002ga^H000000P2ea^L3000000040:Zoj0000000Z[kX
0:Znj0<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX0000002Y_NP0
ZKgX0`0000000`2Y_NP000000000000i0?ooo`00C03oool7000000040:Vmj0000000000000000080
ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX
0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vm
j0000000000000000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP30000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKWU0000002W]N<0YkGS0`000000102V/N4000000:Fc
hP2U/n83000000040:Rii@000000Z;WU0:Rii@<0000000@0Zk_U0000002[_>H0ZkcV0`000000102Y
_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0Y[cY0000002X_NT0Z;gY
0P0000020;O6iP<0000000@0]LGV000000000000Z[oX0`0000001P2Y_NP00000000000000000ZKgX
00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000
>03oool001h0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000007@3oool2000000040?oo
o`000000000000000080ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000
ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP000000080
00000P2Y_NP00`000000ZKgX0000000200000080ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX0080
00000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:VkiP03
0000002Y^ND00000008000000P2U/n800`000000Y[7Q0000000200000080Z;ST00<000000:Rii@00
00000P0000020:Vji@030000002[^nD00000008000000P2/_^L00`000000ZKgX0000000200000004
0:Vmj0000000ZKgX0:Vmj0<0000000@0ZKcW0000002V_>T0Y[cY0`0000020:W0jP8000000P2gbNP0
0`000000]LGV0000000200000080ZKgX0P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP0
0`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0800000=`3oool0
01d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000J0?ooo`<0000000<0
oooo0000000000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0
ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj00200000080
ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y
_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmi`030000002Y^nH0
ZK_V008000000P2U]nD00`000000YK?R0:FchP0200000080Z;ST00<000000:Rhi02X^>@00P000002
0:Vii@030000002Y^^D0ZK[U008000000P2]_^H00`000000[;kW0:bni`0200000080ZKgX00<00000
0:Vmj00000000P0000020:VkiP030000002Y_>L00000008000000P2V_NT01@000000ZL3Z0000002[
`^/000000080]lWX0P0000000`2ba>L0000000000002000000040:Vmj0000000ZKgX0:Vmj0800000
0P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000
002Y_NP0ZKgX00800000=`3oool001H0oooo1@0000020?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool0603oool2000000050?ooo`00000000000000002Y_NP00`0000020:Vmj003
0000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj000
00000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX
00000000000000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<00000
00@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmi`2Y_NL3000000040:Jji`000000YKOU
0:Fgi@<0000000@0XkCT0000002X^>@0Z;ST0`000000102Y^ND000000:Vii@2Y^ND3000000040:^m
i`000000[KkV0:fniP<0000000@0[KkW0000002Y_NP0ZKgX0P0000020:VjiP030000002Y^nH0ZK_V
008000000P2Z_>H00`000000Y[gY0:Jmj@0200000080Zl;[0`0000001P2dbNX000000;;4i`000000
[l;X00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000000000f0?ooo`007@3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo01@0oooo0`0000000`3oool00000000000020:Vm
j08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vm
j0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vm
j00000000P0000020:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vm
j00000000P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX000000020000
00040:Nlj0000000Y[[W0:Jji`<0000000@0XK7T0000002S]>@0XkCT0`000000102Y^ND000000:Vi
i@2Y^ND3000000040:Vli`000000ZkgW0:^mi`<0000000@0[[oV0000002]_^L0[KkW0`000000102Y
^^H000000:VjiP2Y^^H3000000040:^ji@000000Z[cV0:ZliP<0000000H0ZKkY0000000000000000
0:k4jP0000020;C9jP<0000000H0[l;X00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX
0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0
0000=@3oool001d0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool00000
0180oooo0`0000001@3oool00000000000000000ZKgX00<000000P2Y_NP00`000000ZKgX00000002
000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP00000
0:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0<0000000@0ZKgX0000002Y
_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P000002
0:Vmj0030000002Y_NP0ZKgX008000000P2X_NP00`000000YkcX0000000200000080Xk7R00<00000
0:6ai00000000P0000020:Ffi0030000002Y^ND000000080000000@0ZK_W0000002Y_>L0ZKcW0`00
0000102[_^L000000:joiP2^_nH3000000040:bli@000000ZK[V0:VjiP<0000000@0ZKWU0000002[
^^D0Zk[U0`0000001P2/_^L00000000000000000[KoW00000080[/CZ0`0000001P2`aNX000000000
00000000[<3X00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX
0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000000000e0?ooo`007@3oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000403oool2000000040?oo
o`000000000000000080ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000
ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP000000080
00000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000000000000080ZKgX00<000000:Vm
j00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Rmj02X_NP200000080YK;R00<000000:>ahP2S
/N800P0000020:>ahP030000002U]^@0YKKT008000000P2Y^^D00`000000ZK_W0000000200000080
ZKgX00<000000:^ni`0000000P0000020:fli0030000002/_>D000000080000000@0ZKWU0000002Y
^ND0ZKWU0`0000020:fniP8000000P2^_nL00`000000[KoW0000000200000080/L?X0P000000102]
`^X000000000002/`>P3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX
0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000=03oool001h0
oooo0P0000090?ooo`<000003P3oool3000000050?ooo`00000000000000002Y_NP00`0000020:Vm
j0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP0
ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P000002
0:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj00000000P000002
0:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000
ZKgX0:Vmj0<0000000@0YkCR0000002U/^80YK;R0`000000102T/>4000000:>ahP2S/N8300000004
0:Rii@000000ZK[U0:Vji@8000000P2[_>L00`000000ZKgX0:Vmj00200000080Zk_U00<000000:fl
i02]_>@00P0000020:bki0030000002Y^ND00000008000000P2Z_>L01@000000[KkV0000002^_nH0
00000080[[oW0P0000020;71iP060000002a`nP000000;;3iP000000[L;Z0`0000020:Znj0030000
002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP30000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000000000000000<`3oool003P0oooo1P000002
0:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj00000000P000002
0:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vm
j02Y_NP3000000060:Vmj000000000000000002Y_NP000000P2Y_NP3000000040:Vmj0000000ZKgX
0:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P000002
0:Vmj0030000002Y_NP00000008000000P2Y]^<00`000000YkCR00000002000000040:B`h@000000
Y;3Q0:B`h@<0000000@0Z;ST0000002X^ND0Z;WU0`000000102[^nD000000:^li`2[_>L300000004
0:VjiP000000Zk_U0:^ki@<0000000@0[K_S0000002/^n@0[;_T0P0000020:Vli`030000002Z_>L0
Z[cW008000000P2^_nH3000000040:joiP000000/L7V0;71iP8000000P2b`nH2000000030:Zoj@00
000000000080Z[kX0P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000
0002000000030:Vmj0000000000000@0000000D0ZKgX00000000000000000:Vmj002000003<0oooo
000e0?ooo`@000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<00000
00@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000
ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj08000000P2Y_NP00`000000
ZKgX0000000200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP30000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vii0030000002Y
]^<0ZKKS008000000P2V/^400`000000Y;3Q0000000200000080Y[KT00<000000:Rhi00000000P00
00020:Zji@030000002[^nD000000080000000@0[;cU0000002Y^^H0ZK[V0`000000102Z^^D00000
0:fkh`2]^n<3000000040:fmiP000000ZKcW0:Vli`<0000000H0Z[kX00000000000000000:joiP00
00020:joiP<0000000L0/l7U00000000000000000;C4iP000000Z[oY00@0000000@0ZKgX0000002Y
_NP0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP200000080ZKgX00<000000:Vm
j00000000P000000102Y_NP000000:Vmj02Y_NP3000000P0oooo0P00000X0?ooo`00<`3oool30000
0080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`00
0000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP2
00000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P00
00020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<0
00000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vli`000000ZKWT0:Vii0<0
000000@0YkCR0000002V/^40Y[;Q0P0000020:Bch`030000002V]^@0Y[KT008000000P2Y^ND00`00
0000Z[[U0:Zji@0200000080[KgV00<000000:bli@0000000P0000020:Vii@030000002Z^^D00000
0080000000@0[[kV0000002]_NH0[KgV0`0000001P2Y_NP00000000000000000Z[gW00000080[[oV
0`0000001P2__nH000000;?1i@000000]/OW00000080]<CV0`000000102Y_NP000000:Vmj02Y_NP3
000000040:Vmj0000000ZKgX0:Vmj0<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj080
00000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`00000W0?ooo`00<03oool400000080ZKgX00<000000:Vmj00000000P000000102Y_NP0
00000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX
008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P000000102Y
_NP000000000000000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`00
0000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000
002Y_NP00000008000000P2Y_NP5000000040:Jgi@000000YkCR0:NdhP<0000000@0Y;;R0000002T
/n<0Y;?S0`000000102W^>D000000:Vii@2Y^ND3000000040:^liP000000[KgV0:fmiP8000000P2[
^nD00`000000ZKWU0:Vii@0200000080ZkgW00<000000:jniP0000000P000000102]_^L000000000
000000020:VkiP030000002Z_NL000000080000000@0[[oV0000002__nH0[koV0`0000001@2fanL0
0000000000000000//CW0080000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<0000000H0
ZKgX00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vm
j0030000002Y_NP0ZKgX008000001P3oool010000000oooo0?ooo`00000W0?ooo`00;P3oool30000
00030:Vmj000000000000080ZKgX0P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`00
0000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`00
00000`2Y_NP000000000000300000080ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y
_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vm
j02Y_NP3000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP3000000060:Nmj@000000YK[X0:Fj
j0000000Y[OU0`0000020:B_h0030000002T/^8000000080000000@0Y[GT0000002W^>D0YkSU0`00
0000102Y^^D000000:^liP2[_>H3000000040:bniP000000Zk_U0:^ki@<0000000@0ZKcW0000002[
_NL0ZkgW0P0000020:joiP8000000P2]_NH00`000000ZK_V0:VkiP0200000080ZkgV00<000000:jo
iP0000000P0000020;33j08000000P2dbNT00`000000//CW00000002000000040:Vmj0000000ZKgX
0:Vmj0<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX0000002Y_NP0
ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000000000D0oooo00@000000?oo
o`3oool000009`3oool002/0oooo100000020:VkiP030000002Y_NP000000080000000@0ZKgX0000
002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX00000002
00000080ZK_V00<000000:Vmj00000000P0000020:Vmj08000000P2Y_NL00`000000ZKgX00000002
00000080ZKgX00<000000:Vmj00000000P000000102Y_NL000000:Vmj02Y_NP200000080ZKgX00<0
00000:Vmj02Y_NP00P0000020:Vmi`030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000
0002000000040:Vli`000000000000000080ZKgX00<000000:Nmj@000000100000020::/gP030000
002T[n00Y:oP008000000P2W/n400`000000Y[GT0000000200000080Z;ST00<000000:Vji@000000
0P000000102[_NH000000:bniP2/_^H3000000040:VkiP000000ZKcW0:Vli`<0000000H0ZkkX0000
002^_nH000000:jniP0000020:fmiP<0000000@0Zk[U0000002[_NH0ZkgV0P0000020:k0i`050000
002``nP000000;;5j@0000000P2dbNT2000000040:o2j000000000000:Vmj0<0000000H0ZKgX0000
0000000000000:Vmj00000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP00000
0:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj08000001@3oool010000000oooo0?ooo`00000W
0?ooo`00:03oool400000080ZKWU00<000000:VkiP2Y^nH00P0000020:Zmj0030000002Y_NP00000
008000000P2Y_NL00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj08000000P2Y^^D0
0`000000ZK_V0:VkiP0200000080Z[gW0`000000102Y^nH000000:Vmi`2Y_NL200000080ZKgX00<0
00000:Vmj02Y_NP00P0000020:VkiP030000002Y_NL000000080000000@0ZKgX0000002Y_NP0ZKgX
0`000000102Y^nH000000:Vmi`2Y_NL200000080ZKgX1@0000020:Vii08000000P2[_>H00`000000
ZKgX0:Vmj002000000050:BXfP000000X:SL0:2Xg00000000P2R[=h3000000040:N_gP000000Yk?Q
0:Nch@8000000P2X]^<00`000000Z;ST0:Rhi00200000080Zk_U00<000000:^miP0000000P000002
0:Vii0030000002Y^nH000000080000000@0ZKgX0000002[_^P0ZkkX0P0000020:jniP<0000000@0
[;cU0000002[^^D0Zk[U0`000000102]_^H000000:k0i`2^`>L200000080//GY0`0000000`2`aNX0
00000:o2j00300000080ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y
_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000<0
ZKgX000000000000103oool010000000oooo0?ooo`00000W0?ooo`009P3oool400000080ZKWU00<0
00000:Vii@0000000P000000102/_>D000000:Zmj02Z_NP200000080ZKWU00<000000:Vmi`2Y_NL0
0P0000020:Vmj0030000002Y_NP00000008000000P2Y^^D00`000000ZK[U00000002000000040:^k
i@000000000000000080Z[[U00<000000:VkiP0000000P000000102Z_NL000000:Vmj02Y_NP30000
00040:Vii@000000ZK_V0:VkiP8000000P2Z_NL00`000000ZKgX0000000200000080ZKWU00<00000
0:VkiP0000000P000000102Z_NL000000000000000020:RehP030000002Y]^<000000080000000@0
[;WR0000002[_>H0ZkcV0`0000001P2WZ]T000000:BXfP2TZ=X000000:2Xg0<0000000@0YJ_K0000
002W[mh0YjoN0`000000102Z]n8000000:Rfh`2X]^<3000000040:^ii0000000Zk_U0:^ki@800000
0P2/^N<00`000000ZKWT0:Vii00200000080Zk_U00<000000:Vmj00000000P000000102[_>H00000
0000000000020:bni`030000002/_>D000000080000000@0[KgV0000002]_^H0[KkV0`0000001P2a
`NH00000000000000000]<KW00000080/<GZ0`0000001P2/`>P00000000000000000ZKgX00000080
ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y
_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000103oool2000002P0oooo000R
0?ooo`D000000P2Y^^D00`000000ZKWU0:Vii@0200000080Zk[T00<000000:bli@0000000P000002
0:Vgh`030000002Y^ND000000080000000@0Z[gW0000002Y_NP0ZKgX0P0000020:Vii@030000002Y
^^D0ZK[U008000000P2[^^@200000080[K_S00<000000:Zji@2Z^^D00P0000020:^ki@030000002Z
_NL00000008000000P2Y]^800`000000ZKWU00000002000000040:^ki@000000Z[gW0:Zmi`800000
0P2Y]^800`000000ZKWU0:Vii@0200000080Zk_U0P0000020:Zdh0030000002X]N80Z;GR00800000
0P2[]^400`000000[;WR00000002000000030:Z/f@000000Yj[I0080Yj[I00@000000:BXfP000000
00000P2SY]L00`000000YJ_K0000000200000080[;[S00<000000:ZghP0000000P000000102Z]n80
00000:^ii02[^N@3000000040:fjh`000000[;WS0:bih`<0000000@0[;SR0000002[^nD0Zk_U0P00
00020:Vii@8000000P2/_>D00`000000[;kW0:bni`0200000080ZkcV00<000000:fmiP0000000P00
00001P2^_nH000000;71iP000000]LCV00000080]<KW0`0000001P2]`^X00000000000000000Z[kX
00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P00
0000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000000000@0000000<0ZKgX000000000000
;P3oool00240oooo100000020:jmi0030000002Y^^D00000008000000P2Y^ND010000000Zk[T0000
000000020:jkh`030000002Y]n<0ZKOS008000000P2]^^<00`000000Z[gW0000000200000080ZKST
00<000000:Vii@0000000P000000102Y^ND000000:^ji00000020:bjh`030000002]^n<000000080
000000@0[;[T0000002[^nD0Zk_U0P0000020:Vdh0030000002Y]^80ZKKR008000000P2/^N<00`00
0000Zk_U0000000200000080Z[CQ00<000000:VfhP0000000P0000020:bih`80000000@0[;GO0000
002Z]>00Z[CP0`000000102Z/ml000000:^fh@2[]^42000000030:jafP000000ZZcI0080ZZcI00<0
00000:NZf@0000000P000000102TY=D000000:>Ve`2SY]L200000080[;[T00<000000:bjh`2/^^<0
0P0000020:Zhh`030000002Z]n8000000080000000@0[K_T0000002]^^<0[K[S0`000000102/^>80
00000:bhhP2/^>83000000060:jjhP00000000000000002/^>8000000P2/_>D3000000040:ZkiP00
0000ZkcV0:^liP8000000P2^_nH00`000000[[oV00000002000000050;G4iP00000000000000002e
a^L00`000000102Z_nT000000:Znj02Z_^P3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX
0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000H0ZKgX0000000000000000
0:Vmj00000020:Vmj0<0000000<0ZKgX000000000000;@3oool001h0oooo1@000000102^_^H00000
0:jmi02^_N@200000080ZK[U00<000000:Vii@2Y^ND00P0000020:jniP030000002^^n<000000080
000000@0[;OQ0000002]^^<0[K[S0P0000020:ZghP030000002Y^>@0ZKST008000000P2Y^ND50000
0080[;[S0P0000020:fkh`030000002/^^@00000008000000P2/]=h00`000000ZKCP000000020000
00040:bfh0000000[;WS0:bih`8000000P2]]n000`000000Z[CQ0:Zdh@0200000080[;GP00@00000
0:bih`00000000000`2/]Ml2000000030:^cgP000000Z[?O0080Z[?O0P0000001P2]/m`000000:ja
fP2^/MX000000:Z/f@<000000P2VYMD00`000000Y:CE00000002000000040:bji0000000[;[T0:bj
i0<0000000@0ZkcV0000002Z^><0Z[SS0P0000020:fli@030000002]^n@00000008000000P2/^^<0
0`000000[;SR00000002000000060;2kh@000000[[[R0000002^^N4000000P2/^>83000000040:jm
i0000000Z[_V0:ZkiP<0000000@0[;gV0000002^_nH0[[oV0P0000020:o1i`80000000@0]lKV0000
0000000000000P2da>H00`000000Z[oY00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX0P0000020:Vmj003
0000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`00000/0?ooo`007@3oool300000080
ZKgX00<000000:jniP0000000P0000020:bli@030000002Y^^D000000080000000@0ZK_V0000002^
_^H0[[kV0P0000020:Vji@030000002/]n400000008000000P2a_>800`000000Z[OR000000020000
00040:^hh`000000000000000080ZKOS00<000000:Vgi00000000P000000102]^^<000000:fkh`2]
^n<200000080[;GO00<000000:bdgP2/]=h00P0000020:bcgP030000002/]^0000000080000000@0
[[WQ0000002]]n00[KOP0`000000102[/mh000000:beh02/]N0200000080[[KO00@000000:beg`00
000000000`2[/mh010000000Z[?O0000000000030:fcg0040000002^/MX0000000000080Z:SF00<0
00000:JUe@2VYMD00P0000020:Zji0030000002/^^@000000080000000@0[;oX0000002[_>H0ZkcV
0`000000102Y^ND000000:fli@2]_>D200000080[;cU00<000000:bjh`2/^^<00P0000020:bih`03
0000002`^n4000000080000000H0[[WQ00000000000000000;2mh`0000020:jmi0<0000000@0Zk[U
0000002/_NH0[;gV0`0000000`2^_nL0000000000005000000040;O6iP000000]<CV0;C4iP800000
0P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX00000000
0000100000001P2Y_NP00000000000000000ZKgX00000080ZKgX0P0000020:Vmj0030000002Y_NP0
00000080000000<0ZKgX000000000000;03oool001`0oooo0P0000020:Vmj0040000002Y_NP00000
00000080[;kW00<000000:bli@2/_>D00P0000020:Vji@030000002Y^nH00000008000000P2Z_NP0
10000000ZK[U0000000000020;2ni0030000002a_>80/KcR008000000P2[]n8200000080[K_T00<0
00000:Vgh`2Y]n<00P0000020:^hh`030000002]^^<000000080000000@0[K[S0000002/]Ml0[;GO
0`000000102//mh000000:bcgP2//mh200000080/KcR00<000000:jih@0000000P0000020:^eh003
0000002[/mh000000080000000@0/;WO0000002^]]l0[[KO0P0000020:bcgP030000002[/mh0Zk?N
008000000P2/]=l00`000000[K?L00000002000000040:^]f@000000Z:SF0:RXeP<0000000@0ZKWU
0000002Z^^@0Z[[T0P0000020:c2j@030000002/_nP00000008000000P2V]N@00`000000ZKWU0000
0002000000040:bniP000000[;cU0:bli@<0000000@0ZKOS0000002/^N<0[;WS0P0000020;2khP80
00000P2__>@00`000000/;gS0000000200000080[kgT00<000000:^ji@0000000P0000020:fmiPD0
000000<0/L?W0000000000000P2ga^H3000000040;?3iP000000ZKgX0:Vmj08000000P2Y_NP00`00
0000ZKgX00000002000000060:Vmj000000000000000002Y_NP000000P2Y_NP3000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP30000
02/0oooo000E0?ooo`8000001P3oool00`000000ZKgX0:Vmj00200000080ZKgX00<000000:bni`00
00000P000000102Y^nL000000:Vji@2Y^^D200000080ZkcU00<000000:Zmj02Z_NP00P0000020:Fl
jP030000002`_^@000000080000000@0[[_S0000002[]n8000000P2]_NH00`000000[K_T00000002
000000040:ZghP000000ZkSS0:^hh`8000000P2^_^H00`000000[K[S0000000200000080ZkCO00<0
00000:bcgP0000000P000000102`_^@000000;6lhP2a_>8200000080[;SR00<000000:^eh02[]N00
0P0000020:jjhP030000002`^Ml000000080000000@0[KGN0000002//mh0[;?N0`000000102]]n00
00000:bdg`2/]=l200000080Z[7M00<000000:^]f@0000000P000000102X^ND000000:Vii@2Y^ND3
000000040:_2j`000000[<;Y0:c2j@8000000P2W]>800`000000Y[GT0:Jei00200000080Zk[U00<0
00000:bniP0000000P000000102Y]n<000000:Vgh`2Y]n<3000000060:bih`000000/;_R0000002^
^n<000000P2__>@200000080/KoU00<000000:nmi02__N@00P0000020:fki0030000002]_NH00000
0080000000@0[l3V00000000000000000P2b`^H2000000040;G5iP000000/l?V0;?3iP<0000000<0
ZKgX0000000000000`0000020:Vmj08000000P2Y_NP00`000000ZKgX00000002000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000:Vmj00300000004
0:Vmj0000000oooo000002X0oooo000D0?ooo`040000003oool0oooo000000D0oooo0`000000102Y
_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vki`0000000P0000020:^ji0030000002[_>D0
00000080000000<0Y[cZ000000000000100000000`2]_^H000000000000300000080[KgV0P000002
0:Vji@030000002Z]n8000000080000000@0[/3W0000002^_^H0[[kV0P0000020:Rhi@030000002[
]=l0ZkCO008000000P2^_nH00`000000/;kT00000002000000040:jli0000000[;SR0:bhhP<00000
00@0ZKWT0000002^^^80[[[R0P0000020:jih@030000002]]Mh000000080000000@0[KSQ0000002]
]n00[KOP0`000000102Y]>0000000:Zag@2Z/Md200000080Y[SV00<000000:Rii@0000000P000002
0:W2j`030000002[`^/000000080000000@0ZKCQ0000002W]>80YkCR0`000000102Y]>4000000:^j
i@2[^^D200000080ZKST00<000000:Vgh`0000000P000000102Z]n8000000:bih`2/^N<200000080
[[_S0`000000102__^D000000;6oi@2a_nD3000000030:jli0000000[K_T00<000000P2__^D20000
0080/KkT00H000000;;2iP000000]<;T0000002eaNH3000000060;73i`00000000000000002Y_NP0
00000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX000000020000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0D00000:P3o
ool001@0oooo00@000000?ooo`3oool00000103oool2000000030?ooo`000000ZKgX00<000000P2Y
_nT00`000000ZKgX00000002000000040:Nkj0000000Zk[T0:^ji08000000P2^`>L200000080YKcZ
00<000000:BljP2T_>X00P0000020:Vji@030000002Y^nH000000080000000@0Z[gW0000002Y^^D0
ZK[U0P0000020:c1j@030000002^`>L00000008000000P2Y_^P00`000000Z;SU0000000200000004
0:^nj0000000[[oV0:joiP8000000P2^_nH00`000000[[cT0000000200000080ZKWT00<000000:Vi
i00000000P000000102]^^@000000:jih@2^^N4200000080[;WS00<000000:fhh@0000000P000002
0:^ghP030000002Y]>0000000080000000@0Y[OU0000002V^>H0Y[SV0P0000020:S0j`030000002Y
`^/0ZL;[008000000P2Y/n000`000000ZKCQ00000002000000040:VagP000000ZKCQ0:Vdh@<00000
00@0[KWR0000002Y^>@0ZKST0P0000020:VfhP030000002Z]n8000000080000000H0[KcT00000000
000000000:nlh`0000020:nni@<0000000<0[koV0000002^_>@0100000001P2__><0000000000000
0000/KoT00000080/KkT0P0000020;C2i08000000P2canP2000000040:o3j@000000ZKgX0:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP2000000040:Vmj0000000
ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000001P2Y_NP00000000000000000ZKgX0000
0080ZKgX0P00000Y0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
0?ooo`80000000<0ZL7[0000000000000`0000020:Nmj@D0000000@0[/;X00000000000000000P2/
`>P00`000000YKcZ00000002000000040:Bhi`000000ZK[U0:Vji@8000000P2[_>D00`000000Z[gW
0000000200000080YKo/00@000000:c1j@00000000000P2/`NP00`000000ZKkX0:Vnj00200000080
X;WZ00<000000:^nj00000000P000000102/`NT000000:joiP2^_nH200000080Z[[U00<000000:Vi
i02Y^N@00P0000020:Vii@030000002]^^@000000080000000@0Z[WT0000002/^N<0[;WS0P000002
0:bih`030000002[]n80ZkOR008000000P2U]N@00`000000Y[OU00000002000000040:JmjP000000
Z<3[0:S0j`<0000000@0Z;?Q0000002Y/n00ZK?P0P0000020:V`g0030000002Y/Mh0000000800000
00@0[kWQ0000002]^N80[KWR0`000000102Y]^8000000:VfhP2Y]^8200000080[KkV0P0000020:bm
iP030000002__><00000008000000P2`_nD00`000000[koV00000002000000060:fli@0000000000
0000002a`ND000000P2a_n@30000000;0;BnhP00000000000000002gaN@000000;?7j0000000/<S[
0000002_`nT00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000
00<0ZKgX0000002Y_NP00`0000000`2Y_NP0000000000004000000060:Vmj000000000000000002Y
_NP000000P2Y_NP3000000030:Vmj0000000000002P0oooo000D0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00`3oool01@000000Yl7/0:O1k0000000Yko[00<000000P2T_>X0
10000000Y;k[0000000000020:c2jP030000002/`>P0[<3X008000000P2U^NL00`000000Y;SW0000
0002000000040:Zji@000000ZkcU0:^li@8000000P2V`>`00`000000YKo/0:Fok00200000080Zl;[
00<000000:c1j00000000P000000102R^>P000000:2ijP2P^NX200000080Z/7Z00<000000:c1j@00
00000P0000020:ZkiP030000002Z^^D000000080000000@0ZKWU0000002Y^ND0ZKWU0P0000020:Zj
i@D0000000<0Zk[T00000000000010000000102W]^<000000:Fei02U]N@200000080Yk_W1@000000
102X]>4000000:Rch@2X/n43000000040:R_g0000000ZK3L0:V`g08000000P2]^>400`000000[kWQ
00000002000000040:fhh@000000ZKKR0:VfhP<0000000H0Zk[U00000000000000000:_1j@000002
0:bmiP8000000P2a_n@00`000000/;oU0000000200000080[;kV0P0000020:bmiP030000002a`ND0
00000080000000H0/KoT0000002d_^8000000;O0h00000020;O5i08000000P2`b>/200000080ZkoX
00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vm
j08000000P2Y_NP200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3
000000040:Vmj0000000ZKgX0:Vmj0800000:03oool001@0oooo00@000000?ooo`3oool000000`3o
ool2000000H0oooo00@000000:O1k000000000000P2T_>X00`000000Y;cZ0:BljP0200000080Ykk[
00<000000:c2jP0000000P000000102Y^^D000000:Fii`2U^NL200000080Y;SW00<000000:Zji@00
00000P0000020:k2j0030000002V`>`000000080000000@0Y<3]0000002[`^/0Zl;[0P0000020:Vj
iPD0000000@0Xk_Y0000002Z`NX0Z/7Z0`0000000`2Z_NL000000000000300000080ZKWU1@000000
1P2Y^nL00000000000000000Z;[V00000080ZKWU0P0000020:Vji@030000002Y^>@0ZKST00D00000
00H0Z;OT00000000000000000:ZghP0000020:RdhP030000002X]>4000000080000000@0Z:kL0000
002X[m`0Z:oL0`000000102/]Ml000000:fhh@2]^>4200000080/;_R00<000000:fhh@0000000P00
00020:VehP8000000P2]_^H00`000000Zl7Y00000002000000030:Zji@000000/KoT00@0000000H0
/<3U00000000000000000:Zji@0000020:bmiP8000000P2``nP010000000/KoT0000000000020;O0
h0<0000000H0^/OT00000000000000000:c2jP0000020:^oj08000000P2Y_NP00`000000ZKgX0000
0002000000030:Vmj0000000000000@0000000H0ZKgX00000000000000000:Vmj00000020:Vmj080
000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000
000002L0oooo000E0?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`050000002T_>X0Y;cZ
0000002T_>X00`000000102V_NT000000:Nnj`2W_^/200000080ZK[V00<000000:Vji@0000000P00
00020:Fhi`040000002T^>L0000000000080[L7X00<000000:k2j02^`^P00P0000020:K1k0D00000
00H0Z;[V00000000000000000:Vii@0000020:Fhi`D000000P2Y_^P200000080Yk_X00<000000:Rj
iP0000000P000000102Y_>L000000:Vli`2Y_>L200000080Yk_X00<000000:RjiP0000000P000000
102Y^nL000000:Vji@2Y^^D3000000040:Nhi@000000YkKS0:Nfh`8000000P2/^^@00`000000Z[OR
0000000400000080YjoM00<000000:R^g00000000P0000020:Zdg`030000002/]Ml0000000800000
00@0[k[R0000002`^n80/;_R0P0000020:^bgP050000002Y]N8000000:jgg`0000000P2]_^H20000
0080Y[GT1@0000001P2b`ND000000;30i@000000[kcS00000080Z[[U0`000000102^_nH000000;33
j02``nP20000000:0:nmi@000000]l3P0000002l`Mh000000;[7i0000000_LKQ00000080[<;Z0`00
0000102Y_NP000000:Vmj02Y_NP200000080ZKgX0P0000020:Vmj0030000002Y_NP0000000800000
00@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000:Vmj003000000040:Vmj0000000ZKgX0:Vm
j0<0000000@0ZKgX0000002Y_NP0ZKgX0`00000V0?ooo`00703oool00`000000oooo0?ooo`050?oo
o`030000002T_>X0Y;cZ00<0000000<0Y;cZ0000002V_NT00`0000020:Vnj0040000002Y^^H00000
00000080ZKWU00<000000:Fhi`2U^>L00P0000020:Bmj`030000002]`NP000000080000000H0[/?Y
00000000000000000:Jji`0000020:Bij08000000P2X^ND00`000000ZKWU0000000200000080Z;cX
00<000000:Rmj00000000P000000102X_NP000000:Nkj02W^nP200000080Z;cX00<000000:Vli`00
00000P000000102X_NP000000:Nkj02W^nP200000080Z;_X00<000000:Vki`0000000P0000020:Nj
iP030000002W^>D000000080000000@0ZK_V0000002/^^@0[;[T0P0000001@2X]>4000000:N`g`2W
/=l000000080YjoM0P0000020:Rch0030000002Z]=l0Z[CO008000000P2^^>400`000000[k[R0000
0002000000040:b`f`000000Zk;N0:^bgP8000000P2^]ml3000000030:nfgP000000000000<00000
0P2]^^<00`000000//7U00000002000000060:nlh`00000000000000002]^N8000000P2^_nH30000
00030:^oj0000000[kgU00<0000000D0_<7N00000000000000000;g6h@03000000030:Vmj0000000
000000@0000000H0ZKgX00000000000000000:Vmj00000020:Vmj080000000@0ZKgX0000002Y_NP0
ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P0000000`2Y
_NP0000000000004000000030:Vmj0000000000002H0oooo000K0?ooo`800000203oool200000080
Y;cZ1@0000000`2Y`N/000000000000300000080ZK[U00<000000:Vii@0000000P0000000`2U_>X0
00000000000300000080[/;Y0P0000020:jli0030000002V^^L00000008000000P2T^>L010000000
Z;WU0000000000020:Vli`030000002X_>P0Z;cX008000000P2Y_NP00`000000Z;gX000000020000
00040:Flj@000000Z;cX0:Rlj08000000P2Y_NP00`000000Z;gX00000002000000040:Fjj0000000
Z;_X0:Rkj08000000P2W^nP00`000000Yk[V0:NjiP0200000080YKWW00<000000:VkiP0000000P00
00001P2Y^^H000000:Rdh@2X]>4000000:N`g`<0000000@0Yk?R0000002X/n00Z;?P0`000000102[
]n4000000:jhh@2^^>4200000080[[;K00<000000:b`f`0000000P0000020:jafP80000000<0];GJ
00000000000010000000102Y/Mh000000:fjh`2]^^<200000080/KgS0P0000020:nih@030000002]
^N800000008000000P2a_nD400000080[[cT0P0000020<74g08000000P2na=l200000080ZK[U00<0
00000:Vli`0000000P000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000ZKgX00<00000
00@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX0P000000102Y
_NP000000:Vmj02Y_NP3000000030:Vmj0000000000002D0oooo000K0?ooo`030000003oool0oooo
00T0oooo0P000000102T_>X000000:Bnk02T_^`200000080YL3]00<000000:FljP00000010000002
0:W1jP8000000P2V_NT00`000000Y[k[0000000200000080[KcU00@000000:jli000000000000P2V
^>H00`000000Y;SW0:Bhi`0200000080Z;cX00<000000:Vli`0000000P000000102Y_NP000000:Vm
j02Y_NP200000080Y[cY00<000000:Flj@0000000P000000102X_NT000000:Vmj02Y_NP200000080
Y[WW00<000000:Fjj00000000P000000102W_>P000000:Nkj02W^nP3000000040:FhiP000000YKWW
0:Fii`8000000P2X_>P00`000000ZK[V0000000400000080YKCT00<000000:NchP0000000P000000
102Y]^8000000:^gh@2[]n43000000040;2fgP000000[[;K0:jbf`8000000P2^[MH00`000000[[7J
00000006000000040;6bf@000000ZK7N0:VagP<0000000H0/K[P00000000000000000;2khP000002
0:nih@8000000P2b_>4010000000/KoU0000000000020:Rlj0<0000000X0[[kU00000031a=`00000
0<?6g0000000_/CO0000002n`mh000000P2Y^^D2000000040:^ki@000000ZKgX0:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000<0ZKgX000000000000
100000001`2Y_NP00000000000000000ZKgX0000002Y_NP00`000000102Y_NP000000:Vmj02Y_NP3
000002@0oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000:BljP0000000P0000020:Nn
j`040000002U`>d0000000000080Wkk_00<000000:W4k@0000000P0000020:G1k@040000002V_NT0
000000000080ZKkY00<000000:fli@2]_>D00P0000020:jkh`030000002V^>H000000080000000@0
Y;_Y0000002X_>P0Z;cX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002V_>T0
Y[cY0P0000020:BljP030000002X_NT000000080000000@0ZK[V0000002V^NL0Y[WW0P0000020:Jj
i`030000002W_>P00000008000000P2U]nH00`000000YKSV00000002000000040:Jji`000000Z;cX
0:Rlj08000000P2R]NH00`000000Y;GU0000000400000080Y[GT00<000000:VfhP0000000P000000
102/]n4000000;2fgP2`]]h3000000040:b]f0000000[ZgF0:j]ePD0000000D0];GJ0000002f/mL0
00000;6bf@03000000060;2cf`000000/K[P0000002e^]d000000P2`^n83000000040:njh@000000
/[cQ0;:lh@80000000H0/koS00000000000000000:Jlj@0000020:jni@8000000P33a]`200000080
_/?N0`0000000`2[]n8000000:^ki@03000000040:Vmj000000000000:Vmj0<0000000<0ZKgX0000
000000000`0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0`000000102Y_NP000000:Vm
j02Y_NP2000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX000000000000903oool001X0oooo
0P00000=0?ooo`040000002V_NT0Y[gY00000080Ykk[0P00000209nkk0030000002O_^l000000080
000000@0YLC`0000002U`Nd0YL7]0P0000020:S0j`030000002Y_^T000000080000000@0[K_T0000
002^^n<0[[_S0P0000020:Jlj@030000002T^nT000000080000000@0Z;gX0000002Y_NP0ZKgX0P00
00020:Vmj0D0000000<0Y[cY0000000000000`0000020:RjiPD0000000<0YkWV0000000000001000
0000102V^>D000000:FgiP2U]nH200000080Y[SV00<000000:Jji`0000000P000000102T]^D00000
0::eiP2R]NH200000080X[KW00<000000:>fiP0000000P2V]N@200000080ZKKR00<000000:bgh@00
00000P000000102[/mh000000:b]f02/[MP500000080];?H0P0000020;Jce`8000000P2c/mP01000
0000/;?K0000000000030;Fjg@80000000@0[[WR0000002_^^40[k[Q0`0000000`2f_^0000000000
00020;C0i0030000002V_>T000000080000000X0[[oV00000033a]`000000<C7g@000000_/?N0000
002l`=d000000P2[]n8200000080[[gT00<000000:Vmj00000000P0000001P2Y_NP0000000000000
0000ZKgX00000080ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0
ZKgX0`0000000`2Y_NP000000:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<000008`3oool001/0
oooo00<000000?ooo`3oool0303oool00`000000Y[gY00000002000000030:Vmj0000000000000<0
00000P2S`>d50000000309nmkP000000000000<000000P2U_NX00`000000[K_T0000000200000003
0:joi`000000000000<000000P2T_>X5000000060:Vmj000000000000000002Y_NP000000P2Y_NP2
00000080Y[WW00<000000:Bij00000000P000000102X^NH000000:Vii@2Y^ND200000080ZKcW00<0
00000:RjiP2X^^H01@000000102V]^@000000:JhiP2V^>H200000080Z;OT00<000000:Bfi@000000
0P000000102Q]>H000000::fi`2R]^L5000000040:FbhP000000ZKKR0:VfhP8000000P2Z]^800`00
0000Zk?N0000000400000080/k7F0`0000001P2f/mL000000;Jce`000000][?G00000080/k?H0P00
00020;Jef0060000002e^]d000000;RmgP000000[[WR0`0000001P2a^n4000000;Jnh0000000^<7Q
00000080]<3T0P0000020:BljP030000002^_nH000000080000000<0a<OM0000000000000P2l`=d3
000000040:njh@000000[[gT0:jmi08000000P2Y_NP2000000040:Vli`000000ZKgX0:Vmj0<00000
00@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX
0:Vmj08000000P2Y_NP5000000030:Vmj0000000000002<0oooo000K0?ooo`030000003oool0oooo
00d0oooo0P0000000`2Y_NP00000000000020:Vmj0030000002T_>X00000008000000P2Y_^T01000
0000X;c]0000000000020:6mk@030000002U`>d0000000@000000P2]`NP200000080[<7X00<00000
0:JmjP0000000P000000102T^>L000000:Rlj02X_>P200000080ZKgX00<000000:Vmj00000000P00
00020:VjiP040000002V^NL0000000000080Y;SW00<000000:RiiP0000000P0000020:Vli`030000
002Y_>L000000080000000@0Y[[W0000002V]^@0Y[KT1@000000102X]n<000000:Rgi02X]n@20000
0080Y;CT00<000000:6diP0000000P0000001P2Q[=l000000:2]h02P[N0000000:FbhP<0000000@0
ZKKR0000002Z]^80Z[KR1@0000001P2ZZmL00000000000000000][?G00000080][?G0P0000020;Jc
e`<0000000@0][?G0000002f]MP0][GH0P0000020;RmgP8000000P2^^>400`000000/K_Q00000002
000000050;S1h@00000000000000002d`N@01@0000020:k1i`8000000P32b=l2000000040;W1g`00
0000[k[Q0:njh@<0000000L0/KkT00000000000000000:Vli`000000ZKcW00<0000000@0ZKgX0000
002Y_NP0ZKgX0`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000@0000000L0ZKgX
00000000000000000:Vmj0000000ZKgX00<0000000<0ZKgX0000000000008P3oool001X0oooo0`00
000@0?ooo`050000002Y_NP0ZKgX0000002Y_NP00P0000020:Vmj0030000002Y_^T0ZKkY00800000
0P2R^n/010000000XKg]0000000000020:2kk0030000002O_>d00000008000000P2[`^X010000000
[<7X0000000000020:Fgi@030000002T^>L00000008000000P2Y_>L010000000ZKgX000000000002
0:VkiP030000002Y^^H0ZK[V008000000P2V^>H010000000Y;SW0000000000020:Rlj0030000002Y
_>L0ZKcW008000000P2W_NT00`000000Y[[W00000002000000040:Jgi@000000Z;OT0:Rgi0D00000
00@0ZKKR0000002T]>@0Y;CT0P0000020:>_h@030000002Q[=l0000000@000000P2W/N000`000000
ZKKR0000000400000080XZ?F0P0000000`2]ZmD000000;Jce`020;Jce`80000000H0]:oC0000002f
/mL000000;Jce`0000020;Jce`<0000000H0_L7L00000000000000000;Roh00000020:jhh@800000
0P2c_^82000000060;[3h@000000]<7T0000002d`^@000000P2T_>X3000000070:k2j0000000`/SO
0000002man8000000;W1g`0300000080/[gR0P000000102b_^<000000:Vli`2Y_>L200000080Z[cV
00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX0P000000102Y_NP0
00000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0`00
000Q0?ooo`00303oool3000000@0oooo0P0000050?ooo`030000003oool0oooo0100oooo00<00000
0:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002R^n/0X[_[0P00
00020:Blj`040000002P^n`0000000000080XKg]00<000000:_2jP2[`^X00P0000020:Zmi`040000
002U]nD0000000000080Z;SU00<000000:Vli`2Y_>L00P0000020:Vli`030000002Y^nH000000080
000000@0ZKWU0000002V^>H0Y[SV0P0000020:Bkj@030000002X_>P000000080000000@0ZKgX0000
002W_NT0YkgY0P0000020:6ei`030000002V]nD000000080000000@0YkSU0000002X]^<0Z;KS1@00
0000102V]><000000:>_h@2S[n42000000050::XfP000000Y:[K0:BZf`0000000P2W/N0300000003
0:JSd`000000Y:;D00<0000000X0YIk?0000002]ZmD0[J_E0000002f/mL000000;:WcP000000]:oC
0P0000030;Jce`80000000H0^KcK0000002m`M`000000;k9h`0000020;Roh0<0000000L0/;cS0000
002c_^8000000;C1i0000000^/?Q00<0000000H0]<;T00000000000000000:JmjP0000020:k2j080
00000P2man8200000080]l7R00@000000;:mhP00000000000P2b_^<3000000040:Zji@000000Z[cV
0:ZliP80000000<0ZKgX000000000000100000001`2Y_NP00000000000000000ZKgX0000002Y_NP0
0`000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000ZKgX00<0000000<0ZKgX00000000
00008@3oool000/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool04@3oool2000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX
0000000000000`0000000`2T_>X000000000000300000080XK_[00<000000:6mk@0000000P000000
102Y`N/000000:Zmi`2Z_NL200000080YkKS00<000000:Rhi@0000000P000000102Z_^P000000:Vl
i`2Y_>L200000080ZK[U00<000000:Vii@0000000P000000102V^nP000000:Bkj@2T^nT200000080
Z;gY00<000000:Vmj00000000P000000102T]nL000000:6ei`2Q]NL200000080YKOV00<000000:Nh
i@0000000P000000102X_>P000000:VjiP2Y^^H50000000609n[g`000000XZSJ0::XfP000000Y:[K
0`000000102XY]@000000:JSd`2VXm<2000000030:BJb`000000YIk?0080YIk?00@000000:f[e@00
000000000P2bYlh200000080]jg?00<000000;Jce`0000000P0000001@2i_=/00000000000000000
_/WS00<0000000@0]<3S0000002`_><0/;cS0P0000020;C1i08000000P2jaN8200000080]<?U00<0
00000:JmjP0000000P0000001P2^`NP00000000000000000^LKT00000080]l7R0P0000001P2d_N40
0000000000000000/kgQ00000080Z[[U0`0000000`2/_>D00000000000020:Vmj0030000002Y_NP0
00000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0
ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0D00000803oool000l0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo100000020:Vmj0800000
0P2Y_NP010000000ZKgX0000000000020:FljP030000002T_>X0000000@000000P2S_nd500000004
0:>jj@000000YkKS0:Nfh`8000000P2]_nL5000000030:Nki`000000000000<000000P2Y_>L50000
00030:BljP000000000000<000000P2Y^nL5000000040:6diP000000YKOV0:FgiP8000000P2U^NL0
0`000000Z;cX00000002000000060:>kjP000000XK;T0:6bi0000000Wj_O1@0000020:^[e`030000
002XY]@000000080000000H0Y9[<0000002TV//0Y9[;0000002UW/l3000000060:jOb0000000/ZO>
0000002eX/H000000P2g[Ll200000080][CG0P0000020;k4gP8000000P2fa>D00`000000]<3S0000
00020000000:0;;1i@00000000000000002ea>H000000;[5hP000000^LKT00000080]<?U0P000000
1P2X_>P00000000000000000[l7W00000080^LKT0`0000000`2d_n<00000000000020;Fmh0030000
002c_N4000000080000000H0[;WS00000000000000000:jli00000020:Vmj080000000@0ZKgW0000
002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP2000000030:Vmj0000000000000@0000000L0
ZKgX00000000000000000:Vmj0000000ZKgX00<000007`3oool000l0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`3oool2000001H0oooo00<000000:Vmj00000000P000000102Y
_NP000000:Vmj02Y_NP200000080ZKgX00@000000:FljP00000000000P2T_N/00`000000Y;o]0000
0002000000040:C0k@000000Xl3^0:?0kPD0000000H0Z[oX00000000000000000:g1j00000020:Rm
j@8000000P2U_>T00`000000Z;cX00000002000000040:Vmj0000000Y[cY0:Jlj@8000000P2T^^T0
0`000000Z;gX00000002000000060:Jji`000000XkCU0:>di@000000XKCV0`000000102U^>L00000
0:Fii`2U^NL200000080YKo/00<000000:>kjP0000001P0000020:B[g0030000002[ZmL0Zj_G0080
000000<0YIk?0000002TV/`00P2TV/`01P000000Y9[;000000000000ZiO2000000<0[Yo800@00000
0;FRaP2eX/H0]J;60P0000002P2m[//000000;Jde`000000_;OE0000002na=h000000<?5g0000002
0;K4i@8000000P2b`ND2000000040;;4i`000000]LCV0;G4iP8000000P2ia^@3000000030;?2i@00
000000000080Zk_U00<000000:o1i`0000000P0000001P2d`nD00000000000000000/[kS00000080
]KgP0P0000001P2c_N400000000000000000[kSP00000080[[cT0`0000000`2Y_>L000000:Vmi`03
000000030:Vmj0000000000000@0000000D0ZKgX000000000000ZKgX000000020:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP000000000000O0?ooo`002`3oool4000000<0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0E0?ooo`050000002Y_NP0ZKgX0000002Y
_NP00`000000102Y_NP000000:Vmj02Y_NP200000080YKcZ00<000000:Bmj`0000000P0000000`2T
`>d000000:C0k@0300000080Vkg`00@0000009Zlk`00000000000P2Z`^/00`000000[L7X00000002
000000040:JmjP000000YKcY0:Flj@8000000P2X_NP00`000000ZKgX00000002000000040:Jjj000
0000Y;[Y0:Bjj@8000000P2V_>T00`000000Y[[W0000000400000080XkSX00<000000:Fhi`000000
0P0000000`2W^nP00000000000030000000309V^i@0000000000008000000P2IZ>400`000000Y:_L
00000002000000060:JXe`000000YIk?0:FNc`000000Y9[<0`0000001P2UTL0000000:^G`P2[Ul80
00000:jOb08000000`2eX/H01@000000_Jk;0;f^b`2m[//0000000<0_;OE00<000000<?5g033aM`0
0`0000001`2b`ND00000000000000000//;V0000002ba>L00`000000102danP00000000000000002
0;S7iP80000000@0/L3U0000002[^nD0Zk_U0P0000020;72iP80000000@0/L3U0000002b_^<0/[kS
0`0000000`2e_n400000000000020;>lh@030000002_^>0000000080000000@0/KgS0000002Y_>L0
ZKcW0P0000020:ZliP80000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000:Vmj0030000
00040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX0000002Y_NP00`00000N0?ooo`002`3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo0P00000H0?ooo`030000002Y_NP0
00000080000000<0ZKgX0000000000000`0000000`2Y_NP000000000000300000080Y[k[1@000000
0`2T_^`000000000000300000080Ukca00<000000:[2j`0000000P0000000`2Z`^/000000:JmjP03
000000040:BljP000000Z;gX0:Rmj08000000P2Y_>L00`000000Y[[X00000002000000040:Jji`00
0000Y[cY0:Jlj@8000000P2Q^>T00`000000XkSX0000000400000080Y[WW0P000000102/^n@00000
0:6ciP2Q/nH:000000030:2[g`000000YZSG0080YZSG00H000000:FNc`00000000000:6?`@000002
0:FA`0030000002[Ul80ZiO2008000000P2bV[l02P000000]J;60000002nY/8000000;f^b`000000
`k370000002l]mD2000000080<?5g0000000aLGK0000002b`ND000000;:nh`0000020;;2iP800000
0P2bb>/200000080//OZ00@000000;S7iP00000000000P2a`>D3000000070;2oiP000000/L;V0000
002a`^H000000;70i@03000000060;2ni0000000]KoQ0000002d`><000000P2c_>42000000040;>l
h@00000000000;6mh`<0000000L0Z[[U00000000000000000:bli@000000ZKgX00<0000000@0ZKgX
0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX
0P000000102Y_NP0000000000000000M0?ooo`002`3oool5000000<0oooo0P0000040?ooo`030000
003oool0oooo01P0oooo00<000000:Vmj02Y_NP00P0000020:Vmj0040000002Y_NP0000000000080
ZKgX00<000000:Jlj@0000000P000000102Y_^P000000:Fmj`2U_N/200000080Y[k[00<0000009Zm
l0000000100000020:O4kPD0000000<0YKg[0000000000000`0000000`2X_NP00000000000030000
0080Y[WV1@000000102S^NP000000:6hj@2Q^>T200000080X[[Z00<000000:>jj@0000000P000000
0`2X_>P000000:bki00500000080UZOR00<0000009JWhP0000000P2FYn800`000000X:_O00000005
0000000509f?a@000000XHo10:6?`@0000000P2UTL02000000040:nD^P000000/YZo0;:J_`800000
0`2nY/801@000000`k370<>`a`33/<L000000080al3D0P0000001@35aM/00000000000000000/[kS
00<000000P2da>H2000000040:o6j`000000//OZ0;;7jP80000000H0]<SY00000000000000000:k1
i`0000020;2oiP8000000P2a`^H200000080[koV00@000000;2ni000000000000P2d`><300000003
0;6mh`000000/kcQ00<0000000H0/kkR00000000000000000:bih`0000020:bli@80000000@0ZKgX
0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP2000000030:Vmj0000000000000@00000
00@0ZKgX000000000000ZKgX0P00000M0?ooo`006@3oool00`000000oooo0?ooo`0I0?ooo`800000
00@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0040000002Y_NP0000000000080ZKgX00<000000:Vn
j00000000P000000102V_>T000000:Jnj`2V_^/200000080Vk[^00<0000009Rll@0000000P000000
102Ta?0000000:K1k@2V`Nd2000000040:Blj`000000Y;cZ0:BljP8000000P2W_NT00`000000Z;_W
00000002000000040:Rlj0000000Z;_W0:Rki`D0000000@0XKSY0000002R^^X0X[[Z0P0000020:2j
j`@000000P2X^>D00`000000WJgR0000000209JWhPL0000000D0Ui_F0000002HU<h0V9C>00000002
09f?a@050000002QSl40XHo10000002UTL000P0000030:nD^P80000000@0ZH:Z0000002nY/80_ZK2
0P0000020<>`a`80000000D0al3D0000003=am@0cLOD000000020<G6f`8000000P2e_=l010000000
]<CV0000000000020:o6j`<0000000<0/LO[0000000000000P2]`nX00`000000[/7W000000020000
00060;74j000000000000000002_`NL000000P2__nH2000000060:noiP00000000000000002`_nD0
00000P2a_N<200000080]L7S0P000000102b_N8000000:bih`2/^N<3000000030:jkh`000000ZKgX
00<0000000<0ZKgW000000000000100000001@2Y_NP000000000002Y_NP000000080ZKgX0`000000
0`2Y_NP000000:Vmj003000001`0oooo000I0?ooo`030000003oool0oooo01X0oooo00<000000:Vm
j00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P000000
0`2Y_NP0000000000003000000030:Vnj@000000000000<000000P2L_Nl5000000030:2nkP000000
Y;c[00<0000000@0Y;cZ0000002W_NT0YkgY0P0000020:Flj@030000002X_>P000000080000000@0
Z;_W0000002S^>P0XkSX1@0000000`2Q^^/0000000000003000000040:FljP000000Z;SU0:Rhi@D0
000000L0UZOR0000002FYn80UZOR0000002FX]d000000080Ui_F00@0000009RDcP2HU<h000000P2M
SlD01P000000XHo1000000000000Yhfj000000<0[iBj00@000000:V2ZP2YPZX0ZH:Z0P0000020<BY
_P8000000P3?_<P00`000000cLOD0<g7e002000000040<G6f`000000`lKL00000080]KcO0P000000
1@2ib>H00000000000000000[lGZ00<0000000<0/<CY0000000000000`0000020:c2j@80000000@0
[l?Y0000002_`NL0[l7W0`0000000`2^_nH00000000000020:k0i`030000002`_nD0000000800000
00L0[koV00000000000000000;?1i0000000/[gR00<0000000@0[[SP0000002^^n<0[[_S0P000002
0:Vli`80000000@0Z[cV0000002Y_NP0ZKgX0`0000000`2Y_NL000000:Vmj003000000040:Vmj000
0000ZKgX0:Vmj08000000P2Y_NP2000001/0oooo000H0?ooo`8000007@3oool2000000030:Vmj000
0000ZKgX00<0000000<0ZKgX0000000000000`0000020:Vmj08000000P2Y_NP010000000ZKgX0000
000000020:Vmj0030000002N^^`000000080000000@0X[k]0000002P`>l0X<3_1@0000000`2S_>/0
00000:BljP03000000040:FmjP000000YKcY0:Flj@8000000P2W_NT00`000000Z;_W000000020000
00040:Bhi`000000XkWX0:>ij0D0000000<0Wk[/0000000000000`0000001@2N/nH0000009V[h`2I
Zn<000000080UZOR00<0000009JWhP000000300000001@2OR;/000000:N=^P2WSKX000000080[iBj
00D000000:V2ZP2YPZX0ZH:Z000000030<BY_P030000003?_<P0ckc80080000000D0cLOD0000003@
c]P0d<kH000000020<?6g0<0000000<0_LOR0000000000000P2kc>L200000080/L?W0P000000102`
`>H000000:Znj02Z_^P3000000030:g2j@000000[l?Y00<0000000H0[L7X00000000000000000:k1
i`0000020:k0i`80000000H0[[oV00000000000000000:noiP0000020;?1i08000000P2`^n800`00
0000[[SP00000002000000070;6mhP00000000000000002Z^ND000000:ZliP03000000040:Vli`00
0000ZKgW0:Vmi`80000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP0000000000003000001/0
oooo000I0?ooo`030000003oool0oooo01d0oooo100000000`2Y_NP00000000000020:Vmj0030000
002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080
000000<0XkcZ0000002R_^d00`000000102N_^l0000009blk`2L_>l5000000030:Bok@0000000000
00<0000000@0Y;cZ0000002W_NT0YkgY0P0000020:Fkj0030000002T^>L000000080000000@0Y[[W
0000002Q^^/0XK[[0P0000001P2O]^P0000009jgjP2N]nX0000009jciPP0000000@0SJ?S00000029
VM`000000P2:SM000`000000RhG80000000209N6_`040000002OR;/0WhRk00000080Yhfj00@00000
0:nD^P00000000000`2YPZX00`000000a:Vn0<BY_P02000000040<nlb0000000f<S;0=S8b`800000
00D0d<kH000000000000`lKL000000020<7=h`8000000P31e>P2000000070;O9j0000000/L?W0000
002b`ND000000;30iP03000000040:foi`000000[L;Y0:g2j@8000000P2]`nX2000000040:c0j@00
0000[/7W0:k1i`<0000000<0[L7X0000000000000P2^_nH00`000000[koV00000002000000040;6o
i@00000000000;2khP8000000P2b^]l2000000040;Bmh@000000Z[WU0:Zii@80000000@0[;cU0000
002Y_>L0ZKcW0`0000000`2Z^nH0000000000003000000060:Vmj000000000000000002Y_NP00000
0P2Y_NP2000001X0oooo000H0?ooo`030000003oool0oooo01h0oooo00<000000:Vmj02Y_NP00P00
00020:Vmj0030000002Y_NP000000080000000<0ZKgX0000002Y_NP00`000000102Y_NP000000:Vm
j02Y_NP200000080ZKgX1@0000000`2V_^/00000000000030000000409Vll0000000X/7_0:;1k`80
00000P2P`>l00`000000Xkg[00000004000000030:FljP000000000000<000000P2U^NL00`000000
Y[[W00000002000000030::gj0000000WkKX00D000000P2E[^P00`000000UZWS0000000209JWhP08
0000002=Xn<0SJ?S00000029VM`0000008Z=d000000208^5b0030000002GQ[l0000000<0WhRk00H0
00000:N=^P000000000009e]V`0000020:V2ZP040000002iQYl0000000000080d[S100P000000=S8
b`3Hb</0f<S;0000003MeLl000000<kFg`<0000000D0`LgS0000002ne^`000000<7Dj00200000080
]lWX0P0000020;;1i@8000000P2``NH00`000000[KoW00000002000000070:k2j000000000000000
002[`NT000000:c0j@03000000060:g3jP00000000000000002/_nP000000P2^_nH2000000040:jo
iP000000/KoU0;6oi@<0000000<0[K_S0000002b^]l00P0000020;Bmh@<0000000<0[;[T0000002/
_>D00`0000001`2Z^ND00000000000000000[;gV0000002Y_NP00`000000102Y_NP000000:Vmj02Y
_NP3000000030:Vmj0000000000000P0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D00000
0P3oool001P0oooo0P00000P0?ooo`80000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0D00000
00<0ZKgX0000000000000`0000001P2Y_NP00000000000000000ZKgX00000080Y[cY0P000000102X
_^T0000009bkkP2L^nh50000000309o2l@000000000000<0000000@0X[k]0000002T_N/0Y;g[1@00
00000`2S^^T000000000000300000080Z;cW100000020:6diP030000002I/nT000000100000000H0
RhG80000002GQ[l0UhJo0000002OR;/30000000909EVV0000000WFfK09e]V`000000ZH:Z0000002i
QYl0000000<0d[S10P0000000`3Hb</000000=gEc`0300000080a=KX0P0000020;kFk080000000D0
^m;[00000000000000000;?6j003000000040;;2iP000000/<7V0;31iP80000000H0[l3W00000000
000000000:o3j00000020:_1j@8000000P2[`NX2000000040:_1j@000000[;oX0:boj0<0000000<0
[[oV0000002^_nH00`0000000`2/_^H0000000000003000000040;Fnh0000000000000000080];oR
100000001P2]^^<00000000000000000[;_U00000080[;gV0P0000020:Vmj0030000002Y_NP00000
0080000000@0ZKgX0000002Y_NP0ZKgX0P0000070?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool001P0oooo00<000000?ooo`3oool08@3oool4000000060:Vmj000
000000000000002Y_NP000000P2Y_NP200000080ZKgX00@000000:Vmj000000000000P2Y_NP00`00
0000ZKgX00000002000000030:Vmj0000000Z;kY00<0000000@0Wk[/0000002L_Nl0W;g_0P000002
09^ol@030000002J_O40000000H000000P2S_>/200000080X;W[00<000000:Jmj@0000000P000000
102U_>T000000::eiP0000020:6diP8000000P2E/>T00`000000Rjg/00000002092ak@030000002D
[^P000000080OIcV00@00000072:g@000000MX;A1`0000001@2AHiP0000009EVV02EIYP000000080
WFfK0P0000020;V6W`80000000H0d[S10000003Mb<@0gLS40000003MeLl200000080enKQ0P000000
1@2le^d00000000000000000_=K]008000000P2cd>l2000000040:g3jP000000//;V0;;2iP<00000
00<0/<7V0000000000000P2a`nL00`000000[l?X00000002000000070:Znj000000000000000002/
`>P000000:_1j@03000000040:Znj0000000[[oV0:joiP80000000D0[[oW00000000000000000:Vm
j002000000030:^ki@00000000000080]/7R00@000000;BohP00000000000P2]^n<200000080[K_T
00<000000:bki@0000000P000000102^_nL000000:Vmj02Y_NP2000000030:Vmj0000000000000@0
000000<0ZKgX0000000000001P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
0080oooo000H0?ooo`030000003oool0oooo0280oooo00@000000:Vmj000000000000P2Y_NP00`00
0000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P00
00020:Vmj0D0000000<0ZKgX0000000000000`0000000`2R_^d00000000000030000000309Rll@00
0000000000H0000000@0X;WZ0000002P^N/0X;W[0P0000020:Bok@030000002U_>T0000000@00000
00@0XkKV0000002E/>T0UK3Y3`00000208AZ[@030000002>Hi/000000080TF>H00@0000009EVV02E
IYP000000P2MKI/200000080^HJO00<000000=jVVP0000000P3Mb<@00`000000i][9000000020000
00030=OVh@000000cNGX0080000000D0_=K]00000000000000000;WEkP03000000030:[6kP000000
[L?Z00<0000000H0/LCX00000000000000000;33j00000020;73i`80000000H0[l?X000000000000
00000:boi`0000020:c0j08000000P2Y_NP5000000030:k0i`00000000000080[<3X00<000000:Vm
j00000000P000000102Y_NP000000;K1hP2f`N82000000060;C3i@00000000000000002]^n<00000
0P2]^n@2000000030:joiP000000000000@0000000D0ZKgX000000000000ZKgX000000020:Vmj0<0
000000<0ZKgX0000000000001@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
0040oooo000G0?ooo`<00000903oool01@000000ZKgX0:Vmj0000000ZKgX008000000P2Y_NP00`00
0000ZKgX00000002000000030:Vmj0000000000000<0000000H0ZKgX00000000000000000:Vmj000
00020:Vmj08000000P2Y_NP010000000XkcZ0000000000020:Jnj`L0000000@0W[k_0000002P_>d0
X;c]1@0000000`2R^^X00000000000030000000409fik0000000XKKW0:6fi`D0000000@0UjoX0000
002=/>h0SK3^1P0000002P1ST>L00000059hfP000000MX;A00000024JZd0000008iSV`000002095S
V0040000002EIYP0UFJH00000080WFfK00T000000;V6W`2iQYl0^HJO0000003NYYX000000=g8a000
00000P3Vf/T4000000030<gUj0000000`mk]008000000P2le^d2000000030;G=k0000000000000<0
00000P2Z_nT200000080[lCY00<000000;33j00000000P0000000`2ab>/00000000000020:c1j003
0000002/_nL000000080000000L0[KkW00000000000000000:Voj@000000Z[oY00<0000000@0[L?Z
0000002/`>P0[<3X0P000000102V_>T000000000002Y_NP3000000050;G:jP00000000000:k0i`00
00000P2]^n<3000000050:jmi@00000000000:jniP0000000P2]_^H3000000030:Vmj0000000ZKgX
00<0000000@0ZKgX0000002Y_NP0ZKgX0P0000050?ooo`040000003oool0oooo000000L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`000`3oool3000000@0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`0S0?ooo`030000002Y_NP0ZKgX0080000000<0ZKgX0000000000000`00
00020:Vmj08000000P2Y_NP010000000ZKgX0000000000020:Vmj0030000002Y_NP0000000800000
00@0ZKgX0000002Y_NP0ZKgX0P0000000`2V_>T000000000000300000080W;_^00<0000009Rkl000
000010000000102K^^h000000:6hj@2Q^>T200000080Yk_W00<000000:2kk000000010000000102O
]nT000000:>fiP2S]^H50000000609Vgk0000000Njkd07^^m0000000IZ7b100000001P1fP]400000
08AZ[@000000SV>K00000080TF>H00@0000009EVV02EIYP000000P2MKI/010000000^HJO0;V6W`00
00020=jVVP<0000000D0i][900000000000000000=Ghh`02000000040<?Nk@000000_=K]0;cFk@80
000000<0_=;[0000000000000P2a`NH00`000000Y[[W00000002000000040:g2j@000000[lCY0:o4
j@80000000D0[lO/00000000000000000:c4j`05000000060:joiP00000000000000002]`>P00000
0P2Y_nT2000000040:[2j`000000[L?Z0:g3jP<0000000<0Z[oY0000000000000`0000001`2X`^d0
0000000000000000[lK[0000002^`>L00`0000001`2^^n<00000000000000000/;kT0000002^_^H0
0`000000102^_ND000000:Vmj02Y_NP2000000030:Vmi`000000000000@0000000<0ZKgX00000000
0000103oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool0
00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0903oool2000000030:Vmj000000000000080ZKgX00<0
00000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj0000000
0P0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0000000<0Z;kY000000000000
0`00000209Zjk`030000002J_O00000000@0000000@0XkWX0000002W^nL0Yk_W0P00000209fik003
0000002G]^d0000000@0000000@0X;SY0000002L]NX0W;GZ3@0000001024JZd0000008iSV`000002
095SV0040000002EIYP0UFJH00000080WFfK00T000000;V6W`2iQYl000000=jVVP000000m;bA0000
003od7h01@0000001@36k>l00000000000000000_=K]0080000000@0_=;[0000002hc>T000000P2a
`NH2000000030:^oj0000000000000@0000000@0[lGZ000000000000/<KZ0`000000102Y_NP00000
0:^nj02[_^P200000080[/3W00<000000:g0j00000000P0000000`2Y`^`000000000000300000007
0:_1jP00000000000000002Y_NP000000:JmjP03000000030:_2j`000000000000<0000000H0ZK_V
00000000000000000;2mi00000020;2ni080000000@0[[_S0000002^_ND0[[gU0`0000001@2Y_>L0
00000000002Z^N@000000080ZKgX0`0000000`2Y_NP00000000000040?ooo`8000002@3oool30000
00<0oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`800000:03oool01@000000ZKgX0:Vmj0000000ZKgX00<0000000<0
ZKgX0000002Y_NP00`0000000`2Y_NP000000000000300000080ZKgX10000000102Y_NP000000000
000000020:Vmj0040000002X_NP0000000000080ZKgX00<0000009fjk000000010000000102E_O<0
000009Bil@2D^O45000000030:^kiP000000000000<0000000H0U;K^0000002L^>/0W;S[0000002P
^>T30000000409njk0000000Wk[/09njk0H000000P0AG]H300000080SV>K00<00000095SV0000000
0`2EIYP2000000090:adU0000000^HJO0000003NYYX000000?BlT@000000om1n00<0000000<0`?W/
0000000000000P2le^d2000000050;cFk@00000000000000002hc>T00`0000000`2^`nT000000000
00020:g7k@030000002^aN/000000080000000<0/LKZ0000000000000P2_`^P00`000000ZKgX0000
0002000000040:^oj0000000[/3W0:k0i`80000000H0[L?Z00000000000000000:W1j`0000020:[1
j`80000000@0ZKgX0000002Y_NP0ZKgX0P0000020:^nj080000000@0[KoW0000002Y_NP0ZKgX0P00
00020:Rli`030000002`_N@000000080000000<0/L3U0000002^^n<00`0000001`2`_N@000000000
00000000Z[GQ0000002Z^N@00`000000102Y_NL000000:Vmj02Y_NP2000001D0oooo00040?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo02L0oooo00<000000:Vmj02Y_NP00P0000020:Vmj0D0000000<0ZKgX
0000000000000P2Y_NP00`000000ZKgX00000002000000030:Vmj0000000000000<0000000@0ZKgX
0000002Y_NP0ZKgX0P0000020:Vmj0040000002Y_NP0000000000080X;[/00<0000009flkP000000
10000000102:]o<000000:Bij02T^NP200000080[KgV00<0000009bik00000001P00000209njk0D0
000000D0W[c]0000001iZ?00000005BHl@0600000080SV>K00<00000095SV00000000`2EIYP20000
00090:adU0000000^HJO0000003NYYX000000?BlT@000000om1n00@0000000D0^]ob000000000000
00000;cIkP0200000080^MC^0P0000001P2_bNd00000000000000000ZlO_00000080[LO]0P000000
1P2]aN`00000000000000000/LS[00000080[l;X0P0000000`2Y_nT0000000000004000000050:k4
jP00000000000:g2j@0000000P2Y`N/3000000030:Vmj0000000000000<0000000L0ZKgX00000000
000000000:joiP000000[KoW00<0000000@0Y[gY0000002X_>L0Z;cW0P000000102aa>P000000;70
i@2a`>D2000000060;2lh`00000000000000002`^n8000000P2Z]N4200000080[[_T1@0000000`2Z
^nH000000000000D0?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0X0?ooo`80000000H0ZKgX
00000000000000000:Vmj00000020:Vmj08000000P2Y_NP010000000ZKgX0000000000020:Vmj0D0
000000<0ZKgX0000002Y_NP00`0000000`2Y_NP0000000000003000000030:Vmj0000000000000<0
00000P2Q_^h7000000040:Bkj@000000[KgV0:fmiP80000000H0VkW]0000002B]^l0T[K_0000002K
^Nd30000000309jmkP000000W[k_00`0000000@0Q6Z]0000002>Hi/000000P2AHiP00`000000UFJH
09EVV002000000050:adU0000000^HJO0000003NYYX00P0000001@3od7h00000000000000000/Nof
0080000000D0/=_f00000000000000000;WLlP03000000030;7?k`00000000000080ZLO_00<00000
0:_7k`0000000P0000000`2[aNd00000000000020:g6k@030000002ab>/000000080000000<0[<7Y
0000000000000P2Y`^`00`000000Zl?[00000002000000030:k2j@000000000000<0000000L0ZKgX
00000000000000000:Vmj0000000ZKgX00<0000000@0Z[kX0000002^_nH0[[oV0P0000000`2]_nL0
000000000004000000030:K1k@000000000000<0000000D0[KkV000000000000/L3U000000020;2k
hP<0000000<0[[SQ0000002^^n@00P0000020:Zii0<0000000<0[;cV0000003oool04`3oool000<0
oooo0P0000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0Z0?ooo`050000002Y_NP0ZKgX0000002Y_NP00`000000102Y_NP000000:Vm
j02Y_NP2000000030:Vmj0000000000000<000000P2Y_NP400000080ZKgX0P0000020:Vmj0040000
002Y_NP0000000000080ZKgX00<000000:>kjP0000000P000000102W_^X0000008Vfm000000207n`
l`030000002T^nT000000080000000<0[[oV0000000000001@00000209ZjkP@000000P2I`O<00`00
0000V;_`00000002082XkPL0000000D0SV>K0000002AHiP0TF>H0000000209EVV080000000<0[7BD
0000000000000P3NYYX2000000030?o@OP00000000000080000000<0X=ol0000000000000P2[eoL2
000000050;;Cl@00000000000000002/a^d01@0000001@2YaNd00000000000000000Z/?/00D00000
00H0[LC[00000000000000000:[1jP0000020:W2k080000000H0Zl7Z00000000000000000:joiP00
00020:fni`80000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Znj02Z_^P300000005
0:k0i`00000000000:c3j`0000000P2T`>d3000000030:Jok0000000[L;Y00<0000000<0ZkcV0000
002a`>D00`000000102]^n@000000:jhh@2^^>42000000060;70i@00000000000000002/^^@00000
0P2/_>H2000001<0oooo00040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000103o
ool2000002d0oooo00<000000:Vmj00000000P0000000`2Y_NP0000000000003000000070:Vmj000
000000000000002Y_NP000000:Vmj003000000030:Vmj0000000ZKgX00<0000000@0ZKgX0000002Y
_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP200000080YkgY2@0000020:BljP80000000@0[/3W
0000002K^Nd0VkW]1@0000000`2K_O00000009o1l0080000000408Fdm0000000O[Oh07jgn0<00000
00D0SV>K0000002AHiP0TF>H0000000209EVV00:0000002/M9@0[7BD0:adU0000000gZJJ0000003d
_94000000?o@OPD0000000D0X<We00000000000000000:oAlP0200000080[lGZ0P000000102^a^/0
00000:W4k@2Ya>d200000080Z/7Z0P000000102/`n/000000:c4j`2/a>/200000080Z[kX00<00000
0:[1jP0000000P0000001@2Y`N/000000000002[_^L000000080[[oV0`0000000`2]_nL000000:Vm
j003000000030:Vmj0000000000000<0000000L0Z[kX00000000000000000:k4jP000000[<?[00<0
000000@0Y;k/0000002V_n`0Y[o/0P000000102Z^ND000000:^liP2[_>H2000000030:foi`000000
000000@0000000D0//GX000000000000[KkV000000020:bji0<0000000<0[[oV0000000000004P3o
ool001L0oooo00<000000?ooo`3oool0;03oool00`000000ZKgX0:Vmj002000000030:Vmj0000000
ZKgX00<000000P2Y_NP010000000ZKgX0000000000020:Vmj0030000002Y_NP000000080000000<0
ZKgX0000002Y_NP00`0000000`2Y_NP0000000000003000000060:Vmj000000000000000002Y_NP0
00000P2Y_NP7000000030:Bmj`000000[/3W00<0000000@0W;[]0000002C^?00TkS`100000020:;2
l0d0000000D0SV>K0000002AHiP0TF>H0000000209EVV0080000002/M9@0[7BD0:adU0000000gZJJ
0000003d_942000000040:W7k`000000YLK`0:G6l080000000D0[<_`00000000000000000;36jP03
000000030;77j`000000[/K[00<0000000L0Z[oX00000000000000000:c2jP000000[<?[00<00000
00<0[<3X0000000000000`0000001`2[`NT00000000000000000ZKgX0000002[_^L00`0000000`2^
`>L0000000000003000000060:Vmj000000000000000002Y_NP000000P2Y_^T2000000040:[2j`00
0000[/CZ0:k4jP80000000<0[<;Y000000000000100000000`2V]nH0000000000003000000030:bm
iP00000000000080ZL;/00<000000:[2k00000000P0000000`2]`nT000000:fniP03000000060:jo
iP00000000000000002^_nH000004P3oool001H0oooo00<000000?ooo`3oool0;P3oool200000003
0:Vmj0000000000000<0000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP00000000000030000
0080ZKgX100000020:Vmj08000000P2Y_NP010000000ZKgX0000000000020:Vmj0030000002Y_NP0
00000080000000@0ZKcW00000029[^h000000P1kZ_4400000080[L7Y1@0000000`2G^>l0000009jo
l003000000040:;3l0000000TK_c096kl`T0000000D0SV>K0000002AHiP0TF>H0000000209EVV008
0000002/M9@0[7BD0:adU0000000gZJJ0000003d_946000000030:_7kP00000000000080//S[0P00
0000102`bN`000000;77j`2aan/200000080[/?Y0P000000102/`^T000000:c2jP2/`^X200000006
0:g3j@00000000000000002/`>T000000P2/`>P2000000040:c0j0000000ZKgX0:Vmj08000000P2[
_nP2000000040:g3j@000000[<3X0:c0j080000000@0ZKgW0000002Y_NP0ZKgX0`0000000`2Y`^`0
000000000003000000050:k2j@00000000000:bji00000000P2U]nH3000000030:JhiP000000[;_U
00<0000000@0[LCZ0000002Y`^`0ZL;/0P0000000`2Y`N/0000000000003000000060:ZkiP000000
00000000002^_nH000000P2^_nH200000140oooo000F0?ooo`800000<03oool5000000030:Vmj000
0000000000<0000000<0ZKgX0000000000000P2Y_NP00`000000ZKgX00000002000000030:Vmj000
0000ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP200000080
ZKgX1`0000000`23[>l000000:Bnk003000000040:_0j@000000WKW/09fik0@000000P2P`_050000
000309Nkl0000000T;ge00H000000P2>Hi/010000000TF>H0000002EIYP2000000<0[7BD00@00000
0=jVVP000000m;bA0`0000001@2Yanl00000000000000000[LS]00<0000000<0[l_^0000002`bN`0
0`0000001`2`bnd00000000000000000Zl?[0000002/`^T00`0000000`2]aN/00000000000020:_2
j`030000002/`>T000000080000000<0[L?Y0000000000000`0000001`2Y_^T00000000000000000
Zl;[0000002]`nT00`0000000`2[_nP000000:Vmi`03000000070:Zoj@00000000000000002Y`N/0
00000:[1jP03000000030:jkh`000000[;[T00<0000000@0YKSV0000002V^>H0Y[SV0P0000000`2^
a>X0000000000004000000050:W2j`00000000000:VkiP0000000P2Y^N@2000000040:bliP000000
[[oV0:joiPH00000403oool001H0oooo00<000000?ooo`3oool0;03oool3000000040?ooo`000000
ZKgX0:Vmj08000000P2Y_NP010000000ZKgX0000000000020:Vmj0030000002Y_NP0000000800000
00<0ZKgX0000002Y_NP00`0000000`2Y_NP0000000000003000000030:Vmj0000000000000<00000
00L0ZKgX00000000000000000:Nmj@000000YkWV00P0000000<0Y;o]0000002[`>T00`0000000`2P
^>T0000009fjk@03000000040:6okP000000X;o_0:2ok`@000000P2L_o450000000308iSV`000000
TF>H0080000000<0VfJB0000002/M9@00P2/M9@3000000030?BlT@0000000000008000000P2Yanl2
000000030:c;l0000000000000<000000P2^co42000000030:W6kP000000000000<0000000D0[LO]
00000000000000000:_4k005000000060:_3j`00000000000000002[`^/000000P2[`>T200000004
0:W2k0000000Zl;[0:_2j`80000000<0Zl7Z0000000000000`0000020:Zji@80000000@0[L7X0000
002Y`N/0ZL7[0P000000102Z^nH000000:jkh`2^^n<200000080[;_T1@0000001@2V_n/000000000
002^`nX000000080[L?Z0`0000000`2Y_NP000000:VkiP03000000030:bji0000000[;cV00<00000
00@0[[oV000000000000[;cV0P00000@0?ooo`005P3oool00`000000oooo0?ooo`0Y0?ooo`<00000
1@3oool2000000040:Vmj0000000ZKgX0:Vmj080000000<0ZKgX0000000000000`0000020:Vmj0@0
00000P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP010000000ZKgX000000000002
0:Vmj0040000002W_NT0000000000080X[SY00<0000009>`jP0000000P2=/Nh400000080YkkZ1000
00020:Fmj`D0000000<0Wk[/0000002N^^`00`0000001@2X`N`00000000000000000OE6C00@00000
0P2KIY801`000000[7BD0:adU0000000eiZB0000003d_9400`0000001@2Ta?000000000000000000
Z<[a008000000P2Yd_D5000000030:[8l000000000000080Y[k[00@000000:W4k@00000000000P2[
a^h2000000040:W3k@000000ZL;/0:W2k08000000P2Z`n`00`000000Zl;[00000002000000030:W2
k0000000000000<0000000<0Z/;[0000000000000P2Y_>P00`000000ZK[V00000002000000030:jn
i@000000[L7X00<0000000<0ZKgX0000000000000`0000001`2^_>@00000000000000000[<;Z0000
002U_>X00`0000000`2X_n/000000:k3jP03000000030:foi`000000000000<0000000<0Yk[W0000
000000000`0000001`2^`NP00000000000000000[;kW0000002/_>H00`00000?0?ooo`005P3oool0
0`000000oooo0?ooo`0W0?ooo`8000002P3oool4000000030:Vmj000000000000080ZKgX00<00000
0:Vmj00000000P0000000`2Y_NP000000:Vmj003000000030:Vmj0000000ZKgX00<0000000@0ZKgX
0000002Y_NP0ZKgX0P0000000`2Y_NP0000000000003000000040:>kjP000000X[SY0::hj@D00000
00<0UKK^0000002S_nd00`0000000`2R_>`000000:BljP03000000040:S0j`000000X[c[0::lj`@0
00000P2U_N/2000000030:c0j000000000000080OE6C00<0000008mLTP0000000P2KIY801`000000
[7BD0:adU0000000eiZB0000003d_940100000001@2Ub?800000000000000000Ym7f00<0000000<0
ZL[a0000002ZbO000`0000000`2X_>P0000000000003000000070:_6kP00000000000000002Xa^l0
00000:W3k@03000000030:W4k@000000000000<0000000L0ZL;/00000000000000000:W3k@000000
ZL?/00<0000000@0Z<3[0000002Y_>P0ZKcX0P000000102Y_NP000000:jni@2^_^D2000000070:o5
jP00000000000000002W_>T000000:Rki`03000000040:g8k@00000000000:c2jP80000000@0YkkY
0000002X_n/0Z;o[0P0000001P2^_nH00000000000000000[KoW00000080YkcX0P000000102U_^/0
00000:k4jP2^a>X2000000040:c1j@000000[;kW0:bni`80000000@0ZKgX00000000000000003P3o
ool001D0oooo0P00000V0?ooo`<000003@3oool010000000ZKgX0000000000020:Vmj0040000002Y
_NP0000000000080ZKgX00<000000:Vmj00000000P0000000`2Y_NP0000000000003000000030:Vm
j0000000000000<0000000<0ZKgX0000000000000P2Y_NP00`000000ZKgX000000040000000409jh
j`000000V;C[09Rdj`@000000P2P_>d400000080Y/3/00<000000:S0j`0000000P0000000`2Q_>`0
000009nkk003000000030:S1k0000000[<3X008000000P1mDI<00`000000SebB0000000209]VTP05
0000002/M9@0[7BD0000003GVY801`0000020:C?mP80000000<0Z<Wa0000000000000`0000020:Zj
i@80000000@0[<?[0000002[a>`0ZlC/0P0000000`2Zb_0000000000000300000080YlG_0P000000
102WbO8000000:S5kP2XaNh2000000030:W4k@000000000000<0000000<0Z<G^0000000000001000
00000`2V_^X0000000000003000000050;7=kP00000000000:W3k00000000P2W_>T200000080Y/C_
1@0000000`2X`N`0000000000003000000050:W2j`00000000000:joi`0000000P2]_nL300000003
0:Flj@000000YKk[00<0000000<0Zl?[0000000000000`000000102Y_NP000000000002Y_NP20000
00h0oooo000E0?ooo`030000003oool0oooo0280oooo0`00000A0?ooo`030000002Y_NP0000000@0
000000<0ZKgX0000000000000`0000020:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y
_NP000000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000X;[/0000
00040000000309bejP000000W;O/00<0000000<0X;[[0000002O_>d01@0000020:Jok0@000000P2O
_>d600000080OE6C00<0000008mLTP0000000P2KIY801`000000[7BD0:adU0000000eiZB0000003f
^8H00`0000001@2Rc?D00000000000000000YlWa008000000P2Y^ND00`000000ZKWU000000020000
00030:c3j`000000[<?[00<0000000<0[=3c0000000000000P2VbO85000000030:C;m00000000000
00<0000000D0YLC`000000000000Yl_b000000020:S8l@8000000P2S`o000`000000Y<3]00000002
000000030:;:m@000000000000<0000000<0Z/W`0000000000000`0000001`2T`Nh0000000000000
0000YlC^0000002XaNl00`0000000`2U`nl0000000000003000000030:G0k0000000[[oW00<00000
00<0[L?Z0000000000000`0000001`2W_n/00000000000000000ZL;/0000002Y_nX00`0000000`2Y
_NP000000:Vmj002000000h0oooo000E0?ooo`800000803oool3000001D0oooo00D000000:Vmj02Y
_NP000000:Vmj00200000080ZKgX00<000000:Vmj00000000P0000000`2Y_NP000000:Vmj0030000
00030:Vmj0000000ZKgX00<0000000<0ZKgX0000000000000`0000000`2Y_NP00000000000030000
000409jhj`000000VkK[09^fj`@000000P2P^>T400000080X[g/00<000000:G0k@0000000P000000
0`2S_^d000000:6kk003000000030::okP000000YL7]00<000000P1mDI<00`000000SebB00000002
09]VTP070000002/M9@0[7BD0000003GVY8000000?JhQP0400000080YlOa0P000000102Y^^H00000
0:Vii@2Y^ND2000000030:_3j`000000000000L0000000L0Y/gd00000000000000000:?9l`000000
X/[d00<0000000<0X/Oc0000000000000`0000000`2Ra_<0000000000003000000030:C6l@000000
000000<0000000L0WlGc00000000000000000:;8l`000000Y<Wc00<0000000<0Y<3]0000002T`>d0
0`0000000`2W`^d0000000000003000000070:C1k@00000000000000002V`nh000000:?3l0050000
00060:g8k@00000000000000002Y`N/000000P2W_NT2000000030:W2k0000000000000<0000000<0
Ykk[0000000000000`0000000`3oool000000?ooo`0=0?ooo`005@3oool00`000000oooo0?ooo`0L
0?ooo`<000006@3oool010000000ZKgX0000000000020:Vmj0040000002Y_NP0000000000080ZKgX
100000020:Vmj0D0000000<0ZKgX0000000000000P2Y_NP010000000ZKgX0000000000020:Vmj003
0000002Y_>L0000000@0000000<0V[CZ0000002O]^P00`0000000`2S^^T000000:>kjP0500000080
Xko]100000020::nk@@0000000<0Y<7^0000000000000P1mDI<00`000000SebB0000000209]VTP07
0000002/M9@0[7BD0000003GVY8000000?JhQP02000000050:S5k`00000000000000002Y_>L01@00
00000`2Y`^`00000000000020:3Po080000000<0W]Ck0000000000000`0000000`2Ta_8000000000
0003000000070:?7l`00000000000000002S_^d0000009o0l003000000030:G5l0000000000000<0
000000<0Xkk/0000000000000`0000000`2TaO40000000000003000000030:Fnk0000000000000<0
000000H0YL3]00000000000000000:W2k00000020:S2k080000000<0Yl7]0000000000000`000000
0`2P^^/0000000000003000000030:S6k`000000000000L0000000@0ZL;/0000002W`N`0Yl7/0P00
00060?ooo`030000003oool0oooo00`0oooo0000103oool000000000000000030?ooo`<00000103o
ool2000000D0oooo00<000000?ooo`3oool06@3oool3000001d0oooo00<000000:Vmj00000001000
00001`2Y_NP00000000000000000ZKgX0000002Y_NP00`000000102Y_NP000000:Vmj02Y_NP20000
00040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P000000102X^nL0000009fe
j@2M]NT400000080XKSY00@000000:>jj@00000000000P2U_>X00`000000YKk[0000000200000003
0::nk@000000X;k^00<0000000<0XL?a0000002R`o001000000207eAT`030000002?G980000000<0
VfJB0P0000020=NJTP030000003f^8H000000080000000L0Zl3Y00000000000000000:K1k@000000
Yl;/00<0000000D0WMom00000000000000000:3Gn`02000000040:2lk@000000X/;`0:;2l0800000
00<0YlG_0000000000000`0000020:FmjP@000000P2U`Nh2000000040:Rmj0000000YKcZ0:FljP80
000000@0Y[o[0000002U`Nh0YL7^0P000000102X_NP000000:FljP2U_>X2000000030:Joj`000000
000000<000000P2V_n/5000000050:W2k000000000000:Vmj00000000P2X_NP2000000040:FljP00
0000YL7]0:G1k@80000000@0YKcY0000002U_^/0YKk[0P000000102Y`^`000000:W2k02Y`^`30000
00T0oooo00<000000?ooo`3oool02`3oool00080oooo00D000000?ooo`3oool0oooo000000030?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F
0?ooo`<000008@3oool01@000000ZKgX0:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`00
00000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`00
00000`2X_NP00000000000030000000309bdj0000000V[?Z00D0000000<0Y;cZ0000000000000`00
00020:RojP@000000P2P_^h400000080Wl7`0P00000207eAT`040000002?G980SebB00000080VfJB
0P0000020=NJTP040000003f^8H000000:g5k08000000P2W`^d<000000030:Flj@000000000000<0
000000<0Y/;]0000000000000P2Y_NP00`000000Z;gX00000002000000030:Nmj@000000Y[o[00<0
000000<0ZKgX0000002X_NP00`0000000`2W_NT0000000000003000000030:Vmj0000000000000<0
000000<0YkgY0000000000000P2X_NP00`000000YKcZ00000002000000030:Noj`000000ZL;[00<0
000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:FljP03000000030:Vmj0000000000000<0
000000<0Yko[0000000000000`00000<0?ooo`030000003oool0oooo00/0oooo00020?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool20000
01D0oooo0`00000U0?ooo`040000002Y_NP0000000000080ZKgX100000020:Vmj0@000000P2Y_NP2
000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P000000102V_>T00000
0:Jji`2V^^L400000080W;CY00<000000::jjP0000000P0000000`2T_>/000000:NnjP0300000003
0:S0j`000000Xkc[00<0000000<0Y[k[0000002R`>l00`0000001@2P_^h000000000001mDI<00000
0080SebB00<0000009]VTP2KIY800P0000000`3GVY8000000?JhQP03000000050:O5k`0000000000
0000002ScOH00P0000001P2/do@00000000000000000[L7X00000080ZKgX0P000000102W_NT00000
0:Fnj`2U_^/2000000040:Vmj0000000ZKgX0:Vmj080000000<0Z;gX0000000000000`0000000`2Y
_NP0000000000003000000070:Vmj000000000000000002Y_NP000000:Vmj003000000030:Vmj000
0000ZKgX00<0000000@0ZKgX0000002X_NP0Z;gX0P000000102W_NT000000:Noj`2W_n/200000003
0:Vmj0000000000000<0000000<0ZKgX0000000000000`0000001`2Y_NP00000000000000000ZKgX
0000002W_NT00`00000A0?ooo`030000003oool0oooo00/0oooo00020?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000001@0oooo0P00
000Y0?ooo`030000002Y_NP000000080000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vm
j003000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000000000000`0000000`2Y_NP000000000
0003000000030:>hj0000000WK;V00D000000P2T^nX400000080Yl7/100000020:JmjP@000000P2T
_>X40000000507eAT`000000SebB08mLTP0000000P2KIY82000000030=NJTP000000m[R600@00000
00D0Y<Sc00000000000000000:_>lP0200000080//OY00<000000:g1j00000000P0000000`2Y_NP0
000000000003000000030:Vmj0000000000000<0000000D0ZKgX000000000000ZKgX000000020:Vm
j080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00@0
00000:Vmj000000000000P2Y_NP5000000030:Vmj0000000000000<0000000D0ZKgX000000000000
ZKgX000000020:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP2
000001@0oooo00<000000?ooo`3oool02`3oool00080oooo00@000000?ooo`3oool0oooo10000003
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03`3oool3000002`0oooo0P00
00000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`00
00000`2Y_NP00000000000020:Vmj0040000002Y_NP0000000000080ZKgX00<000000:>ljP000000
100000000`2Q]^L000000:6hj003000000030:FljP000000YKk[00<0000000<0Y[o[0000002V_^/0
0`0000000`2X_NT000000:Vmj003000000060:NnjP00000000000000001mDI<000000P2?G9800`00
0000VfJB09]VTP02000000030=NJTP000000m[R60080000000<0YlG_0000000000000P2Yb_420000
00030;3:k@000000000000<0000000L0ZkoX00000000000000000:Vmj0000000ZKgX00<0000000<0
ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000ZKgX00<0000000<0
ZKgX0000000000000`0000000`2Y_NP0000000000003000000070:Vmj000000000000000002Y_NP0
00000:Vmj003000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP0
000000000003000000030:Vmj0000000000000<000005P3oool00`000000oooo0?ooo`0;0?ooo`00
00<0oooo0000000000000`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000<0
oooo0P00000=0?ooo`<00000<@3oool300000080ZKgX0P000000102Y_NP000000:Vmj02Y_NP20000
00040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP000000000
00030000000409nij`000000WKKZ09ffjP@000000P2T_>X400000080Z;kY100000020:BljP@00000
0P2Y_nT50000000507eAT`000000SebB08mLTP0000000P2KIY82000000030=NJTP000000m[R600<0
000000D0ZlS_00000000000000000:g<l00200000080[<O]00@000000:g4j`00000000000P2Y_NP0
10000000ZKgX0000000000020:Vmj0@000000P2Y_NP400000080ZKgX100000020:Vmj080000000@0
ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vm
j080000000<0ZKgX0000000000000`0000000`2Y_NP0000000000003000000070:Vmj00000000000
0000002Y_NP000000:Vmj003000001/0oooo00<000000?ooo`3oool02`3oool00080oooo00@00000
0?ooo`3oool0oooo1@0000030?ooo`800000103oool00`000000oooo0?ooo`090?ooo`<00000=03o
ool00`000000ZKgX00000002000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000000000000`00
00000`2Y_NP0000000000003000000030:Vmj000000000000080ZKgX00<000000:Vmi`0000001000
00000`2J]^/000000::kjP03000000030:BljP000000YkgY00<0000000<0ZKgX0000002V_>T00`00
00000`2T_N/000000:RnjP03000000030:W2k0000000ZL;/0080000000D0OE6C0000002?G980SebB
0000000209]VTP80000000<0eiZB0000003f^8H0100000020:g=l@80000000<0ZlS_000000000000
0`0000000`2Y_NP0000000000003000000070:Vmj000000000000000002Y_NP000000:Vmj0030000
00030:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj0030000
00030:Vmj0000000000000<0000000<0ZKgX0000000000000`0000001@2Y_NP000000000002Y_NP0
00000080ZKgX0P000000102Y_NP000000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj0800000
0P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo000D0?ooo`030000003o
ool0oooo00H0oooo0`00000h0?ooo`80000000<0ZKgX0000000000000`0000000`2Y_NP000000000
00020:Vmj0060000002Y_NP000000000002Y_NP000000P2Y_NP2000000040:Vmj0000000ZKgX0:Vm
j080000000@0Z;_W0000002M]^T0WKKY100000020:>kjP@000000P2X_NP400000080YKg[10000002
0:S2k0H0000000D0OE6C0000002?G980SebB0000000209]VTP050000003GVY80eiZB0000003f^8H0
0P0000001@2^cO000000000000000000[<[_0080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y
_NP000000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0ZKgX0000000000000`00
00000`2Y_NP0000000000003000000030:Vmj0000000000000<0000000L0ZKgX0000000000000000
0:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj00300000003
0:Vmj0000000000000<0000000<0ZKgX0000000000000`0000040?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool02P3oool001@0oooo00<000000?ooo`3oool00`3oool3000003d0oooo
00<000000:Vmj00000000P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0ZKgX00000000
00000`0000000`2Y_NP0000000000003000000030:Vmj0000000000000<0000000<0WkGX0000002M
]^X00`0000000`2T^nT000000:BljP03000000030:Rnj@000000ZKoY00<0000000<0YL7]0000002T
`>h00`0000000`2X`>/000000:W1j`0300000080OE6C00<0000008mLTP0000000P2KIY801@000000
eiZB0=NJTP000000m[R600<0000000L0[/__00000000000000000:^oj0000000ZKgX00<0000000<0
ZKgX0000000000000`0000000`2Y_NP0000000000003000000050:Vmj000000000000:Vmj0000000
0P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y
_NP000000:Vmj02Y_NP2000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`000000
1`2Y_NP00000000000000000ZKgX0000002Y_NP00`00000:0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool02P3oool001<0oooo0P0000020?ooo`<00000@@3oool4000000030:Vmj000
0000000000<0000000<0ZKgX0000000000000P2Y_NP010000000ZKgX0000000000020:Vmj0060000
002Y_NP000000000002V_>T000000P2V^^L400000080XKKW100000020:Blj`040000002X_^T00000
00000080ZL;/100000020:Bok@@000000P2Y_NP01P000000OE6C07eAT`000000SebB00000080VfJB
00<000000=NJTP3GVY800`0000000`2^b^h00000000000020:k2j@@000000P2Y_NP2000000040:Vm
j0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP000000:Vmj0030000
00030:Vmj0000000000000<0000000<0ZKgX0000000000000`0000000`2Y_NP00000000000030000
00050:Vmj000000000000:Vmj00000000P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000@0
ZKgX0000002Y_NP0ZKgX0P00000>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
2P3oool001<0oooo100000150?ooo`060000002Y_NP000000000002Y_NP000000P2Y_NP200000004
0:Vmj0000000ZKgX0:Vmj080000000<0ZKgX0000000000000`0000000`2Y_NP00000000000030000
00030:>hj0000000X[?U00<0000000<0Y[SV0000002U^nT01@0000001`2X`N`00000000000000000
ZL7[0000002U_n`00`0000000`2T_>X000000:Rmj@0400000080OE6C00<0000008mLTP0000000P2K
IY800`000000eiZB0=NJTP04000000070:o5jP00000000000000002[`NT000000:Znj00300000003
0:Vmj0000000ZKgX00<0000000<0ZKgX0000000000000`0000000`2Y_NP000000000000200000080
ZKgX0P000000102Y_NP000000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0ZKgX
0000002Y_NP00`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0000000<0ZKgX
0000000000000`00000A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02P3oool0
01<0oooo0P0000180?ooo`030000002Y_NP0000000@0000000<0ZKgX0000000000000`0000000`2Y
_NP00000000000020:Vmj0040000002Y_NP0000000000080ZKgX00<000000:>ljP0000000`000002
0:Fei0040000002V^>H0000000000080Y[cY100000020:W0j`@000000P2V_>T4000000040:Rnj@00
0000000000000080OE6C00<0000008mLTP0000000P2KIY800`000000eiZB0=NJTP0500000080[<C[
100000000`2Y_NP0000000000003000000070:Vmj000000000000000002Y_NP000000:Vmj0030000
00030:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP00000000000030000
00030:Vmj00000000000008000000P2Y_NP400000080ZKgX0P0000000`2Y_NP000000:Vmj0030000
01H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0:0?ooo`005@3oool00`000000
oooo0?ooo`160?ooo`050000002Y_NP0ZKgX0000002Y_NP00P0000020:Vmj0060000002Y_NP00000
0000002Y_NP000000P2Y_NP2000000030:Vmj0000000000000<0000000<0WkW[0000002M]^T01@00
00001`2Z^nH00000000000000000Z;gX0000002W_^X00`0000000`2Y_NP000000:Vmj00300000003
0:Jlj@000000Y;cZ008000000P2X`N`02`000000OE6C07eAT`000000SebB0000002KIY8000000;b4
V0000000eiZB00<0000000L0[LS]00000000000000000:Vmj0000000ZKgX008000000P2Y_NP01000
0000ZKgX0000000000020:Vmj0050000002Y_NP000000000002Y_NP01@0000000`2Y_NP000000000
0003000000070:Vmj000000000000000002Y_NP000000:Vmj003000000030:Vmj0000000ZKgX00<0
000000<0ZKgX0000002Y_NP00`0000000`2Y_NP0000000000002000001X0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0:0?ooo`005P3oool00`000000oooo0?ooo`160?ooo`@00000
00<0ZKgX0000000000000`0000000`2Y_NP0000000000003000000030:Vmj000000000000080ZKgX
00<000000:Vmi`000000100000000`2I]>X000000:Nii@0200000080[;gV00@000000:Rmj0000000
00000P2Y_NP400000080ZKgX100000000`2U_^/00000000000030000000407eAT`000000SebB08mL
TP80000000<0_8BH0000003GVY80100000000`2Y_NP0000000000003000000030:Vmj00000000000
00<0000000<0ZKgX0000000000000`0000000`2Y_NP00000000000020:Vmj0040000002Y_NP00000
00000080ZKgX00H000000:Vmj000000000000:Vmj00000020:Vmj080000000<0ZKgX000000000000
0`0000000`2Y_NP0000000000003000000040:Vmj00000000000000001l0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0:0?ooo`005`3oool00`000000oooo0?ooo`160?ooo`040000
002Y_NP0000000000080ZKgX00@000000:Vmj000000000000P2Y_NP01@000000ZKgX000000000000
ZKgX00D0000000@0ZK_W0000002L]NX0W;GZ100000000`2Y_>L0000000000003000000070:Znj000
000000000000002Y_NP000000:Vmj003000000030:Vmj0000000Y[cY008000000P2W_NT01@000000
ZL3[0000001mDI<000000080SebB0P000000102lQ9P000000000003f^8H400000080ZKgX00H00000
0:Vmj000000000000:Vmj00000020:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP0
000000000003000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`0000001@2Y_NP0
00000000002Y_NP000000080ZKgX0P000000102Y_NP000000:Vmj02Y_NP200000280oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`00603oool2000004L0oooo00<000000:Vm
j0000000100000000`2Y_NP0000000000003000000030:Vmj000000000000080ZKgX00<000000:Vm
j0000000100000000`2K]NX0000009Vej`03000000030:[6kP000000[LC[008000000P2Y_^T40000
0080ZKgX100000000`2X_>P00000000000040000000407eAT`000000SebB08mLTP80000000@0_8BH
000000000000m[R60P000000102Z_^P000000:Vmj02Y_NP2000000030:Vmj0000000000000<00000
00<0ZKgX0000000000000`0000001@2Y_NP000000000002Y_NP000000080ZKgX0P000000102Y_NP0
00000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0ZKgX0000000000000`000000
0`2Y_NP0000000000003000002D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`150?ooo`80000000<0ZKgX0000002Y_NP00`0000000`2Y
_NP000000:Vmj00200000080ZKgX00H000000:Vmj000000000000:Jkj00000020:Jji`@000000P2J
^^h4000000070:S1k000000000000000002X_NP000000:Vmj003000000030:Vnj@000000ZKgX0080
00000P2Y^^D00`000000Z[_V0000000300000080SebB0P000000102lQ9P000000000003f^8H60000
00050:Vmj000000000000:Vmj00000000P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0
ZKgX0000002Y_NP00`0000000`2Y_NP0000000000003000000030:Vmj0000000000000<0000000D0
ZKgX000000000000ZKgX000000020:Vmj0800000:`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00T0oooo000K0?ooo`030000003oool0oooo04H0oooo0`0000020:Vmj0@0000000<0
ZKgX0000000000000`0000000`2Y_NL0000000000003000000030:BhiP000000000000<0000000<0
Xkc[0000000000000P0000020:BljP@000000P2Y_^T4000000030:Rnj@000000000000<0000000@0
[;kW00000000000000000P2?G98010000000_8BH0;b4V02lQ9P3000000040:Vmj0000000ZKgX0:Vm
j080000000<0ZKgX0000000000000`0000000`2Y_NP0000000000003000000030:Vmj00000000000
008000000P2Y_NP2000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y
_NP000000:Vmj003000002h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?oo
o`00703oool00`000000oooo0?ooo`150?ooo`030000002Y_NP000000080000000<0ZKgX0000002Y
_NP00`0000000`2Y_NP000000:Vmj00200000080ZK_W00H000000:FhiP00000000000:Bhi`000002
0:Bgi`80000000<0Z[_V0000002U_>T00`0000000`2T_N/000000:Rnj@03000000030:W2k0000000
Z<;/008000000P2S_N`00`000000Z[gW000000040000000308mLTP000000000000<0_8BH1`000000
1@2Y_NP000000000002Y_NP000000080ZKgX0P0000000`2Y_NP000000:Vmj003000000030:Vmj000
0000ZKgX00<0000000<0ZKgX0000000000000P0000020:Vmj0@0000000<0ZKgX0000000000000`00
000a0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool001d0oooo00<00000
0?ooo`3oool0A@3oool2000000030:Vmj00000000000008000000P2Y_NP4000000030:Vmj0000000
000000<0000000<0YKWW0000000000000`0000000`2Y^ND000000000000200000080Y[gZ10000002
0:S2k0@0000000<0Y<3]0000000000000`0000000`2Zbo4000000000000300000003099VV`000000
_8BH0080_8BH0P0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0000000<0ZKgX
0000000000000P0000020:Vmj0@0000000L0ZKgX00000000000000000:Vmj0000000ZKgX00<00000
00<0ZKgX0000002Y_NP00P00000g0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
2@3oool001h0oooo0P0000170?ooo`040000002Y_NP000000:Vmj0<0000000<0ZKgX0000002Y_NP0
0P0000020:Jlj@060000002V^nP000000000002T_>X000000P2T^^T2000000030:^ki@000000[;gV
00<0000000<0YL7]0000002T`Nh00`0000000`2X`>/000000:W1j`0200000080Xk_Z10000000102/
b^l00000000000000002099VV`040000002lQ9P0_8BH0;b4V0D000000P2Y_NP2000000030:Vmj000
0000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj00200000080ZKgX1000
00000`2Y_NP0000000000003000003X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`090?ooo`00803oool00`000000oooo0?ooo`150?ooo`<000000P2Y_NP4000000030:Vmj0000000
000000<0000000<0Y;cZ0000000000000`0000000`2Q^NX000000:^ki@03000000030:k3j@000000
0000008000000P2T_nd4000000070:ZkiP00000000000000002Y_NP000000:O2k@02000000030:k3
j@00000000000080TVJK00@000000;b4V02lQ9P0_8BH0`0000001@2Y_NP00000000000000000ZKgX
00@000000P2Y_NP4000000030:Vmj0000000000000<0000000L0ZKgX00000000000000000:Vmj000
0000ZKgX00800000@03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo000Q
0?ooo`030000003oool0oooo04@0oooo00<000000:Vmj00000000P0000000`2Y_NP000000:Vmj003
000000030:Vmj00000000000008000000P2T^nX00`000000XK[[0000000300000080[<;Z0P000000
0`2^`^P0000000000003000000030:FhiP000000ZKWU008000000P2/_NH4000000030:k3j@000000
0000008000000P2BIY/01@000000_8BH0;b4V0000000lkjF00<000000P2Y_NP2000000030:Vmj000
0000ZKgX00<0000000<0ZKgX0000002Y_NP00P0000020:Vmj0050000002Y_NP000000000002Y_NP0
1@0000120?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool00280oooo00<0
00000?ooo`3oool0A03oool2000000030:Vmj00000000000008000000P2Y_NP2000000030:Vmj000
0000YKcZ00D0000000<0XKOX0000000000000`0000001@2]`NP000000000002^^^<000000080Y[SV
100000001`2[^nD00000000000000000[/K/0000002^a>X00P0000020:k3j@8000000P2BIY/01`00
0000_8BH0;b4V0000000lkjF0000002Y_NP00`0000000`2Y_NP0000000000002000000030:Vmj000
0000000000<0000000<0ZKgX0000000000000`0000000`2Y_NP00000000000180?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0203oool002<0oooo0P0000160?ooo`040000002Y_NP0
00000:Vmj0<0000000<0ZKgX0000000000000P0000020:BljP@0000000@0YKWW0000002U^nT0YK_Y
0P0000000`2]^^<000000:jjh`03000000030:JiiP000000YKWW008000000P2/and4000000030:k4
jP000000000000<000000P2BIY/00`000000_8BH0;b4V004000000070:Vmj000000000000000002Y
_NP000000:Vmj00200000080ZKgX00H000000:Vmj000000000000:Vmj00000020:Vmj0800000B`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo000U0?ooo`030000003oool0
oooo04@0oooo100000001P2Y_NP000000000002Y_NP000000:Vmj0<0000000<0X[[Z0000002Q^NT0
1@0000000`2Y^nL000000000000200000080[[_S100000001@2T`>d00000000000000000ZlK^00@0
00000P2]`nX3000000<0TVJK00D000000;b4V000000000000:Vmj00200000080ZKgX100000000`2Y
_NP0000000000003000000030:Vmj0000000000000<00000C@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo04@0oooo100000000`2Y_NP0
000000000003000000030:Vmi`0000000000008000000P2P]^P01`000000Z;gX000000000000Y[_X
0000002]^n@00`0000000`2^`NP000000000000200000080Z/;[0P0000000`2Z`n`000000:W2k003
000000040:_2j`000000000000000080TVJK0P000000103c_YH000000000002Y_NP3000000030:Vm
j0000000ZKgX008000000P2Y_NP010000000ZKgX00000000001C0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0203oool002L0oooo00<000000?ooo`3oool0A03oool01P000000ZKgX
000000000000ZKgX00000080ZKgX0P0000000`2Y^ND000000:6bi005000000030:Jmj@0000000000
00<0000000H0[L?Z000000000000[<7Y0000002Z_nP3000000030:k6k00000000000008000000P2Y
`^/2000000030:Vmj000000000000080TVJK0P000000103c_YH000000000000000020:Vmj0@00000
00<0ZKgX0000000000000`00001F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
203oool002P0oooo00<000000?ooo`3oool0A03oool00`000000ZKgX00000004000000030:Vmj000
00000000008000000P2U]N@01@000000YKWW000000000000Y<7^00D0000000<0Zl;[000000000000
0`000000102]and000000000002[aN`5000000030:Vmj00000000000008000000P2BIY/200000003
0?>nUP000000ZKgX00<0000000<0ZKgX0000002Y_NP00P00001L0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0203oool002T0oooo0P0000150?ooo`050000002Y_NP0ZKgX0000002Y
_NP00P0000000`2T^nX000000:Bhi`05000000030:W2k000000000000080Y<3]00H000000:C0kP00
000000000:Vmj00000020:[2j`80000000D0[<K]000000000000ZKgX000000020:Vmj080000000@0
ZKgX00000000000000000P2BIY/2000000040?>nUP00000000000:Vmj0D00000GP3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo000[0?ooo`030000003oool0oooo04<0oooo
100000000`2Y_NP00000000000030000000309njk000000000000080000000<0ZL7[000000000000
0`0000000`2T_>X0000000000003000000040:o3j@00000000000:^nj0D0000000<0ZKgX00000000
00000`000002099VV`030000003c_YH0lkjF00<00000I03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00L0oooo000/0?ooo`030000003oool0oooo04@0oooo0`0000000`2Y^nH00000
00000003000000030:Flj@000000ZL7[00<0000000<0ZK_V0000000000000P0000000`2T_>X00000
00000003000000050;;5j000000000000:Znj00000000P2Y_NP2000000030:Vmj000000000000080
000000@0TVJK000000000000lkjF0P00001W0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool002d0oooo00<000000?ooo`3oool0@`3oool00`000000ZKgX0000000200000003
0:Nki`000000YKSW00@000000P2Y^N@2000000030:bli@000000YKcY008000000P2T`>d01@000000
/LS[000000000000[/CZ00D0000000H0ZKgX000000000000ZKgX0000002Y_NP200000080YL?_0P00
001Y0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool002h0oooo0P000014
0?ooo`030000002V_NT0Y[gY00@0000000<0ZKgX0000000000000`0000000`2/^^@0000000000002
000000030:FljP000000000000<0000000@0[LO]000000000000ZKgX1@0000000`2Y_NP000000000
0003000000030?ooo`000000000000800000J@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00L0oooo000`0?ooo`030000003oool0oooo0480oooo0P0000000`2T_>X000000:BljP02
000000040:Jmj@000000Yk_X0:Nkj080000000<0[L?Y0000002^`NP00P0000020:Znj0@0000000L0
Z[kX00000000000000000:Vmj0000000ZKgX00800000M03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L0oooo000a0?ooo`030000003oool0oooo04<0oooo0`0000000`2T_>X00000
00000003000000030:Bnk000000000000080000000D0[<7Y00000000000000000:k3jP0400000080
Z[kX1000001g0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00380oooo
00<000000?ooo`3oool0@`3oool300000080YK[X100000000`2W_n/0000000000003000000060:W2
k000000000000:_3j`000000[<7Y0`00001l0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool003<0oooo00<000000?ooo`3oool0@P3oool00`000000YKSV0000000200000003
0:Nji`000000YkgY0080000000<0ZKoZ0000000000000`0000000`2Y`^`0000000000002000007l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`00=03oool2000004<0oooo
0P0000000`2W^>D0000000000002000000070:Vmj000000000000000002/`>P000000:W2k0020000
08@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`00=P3oool00`000000
oooo0?ooo`120?ooo`040000002Y_NP000000:Vmj08000000P2/_^L4000008L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`00=`3oool00`000000oooo0?ooo`120?ooo`<0
000000@0ZKgX0000000000000000R`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo000h0?ooo`030000003oool0oooo0480oooo0`00002?0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool003T0oooo0P0000120?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`00>`3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`00?03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0940oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`00?@3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`00?P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`00?`3oool2000003`0oooo00<000000?ooo`3oool0
U03oool01@000000oooo0?ooo`3oool0000000L0oooo00110?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0U03oool01@000000oooo0?ooo`3oool0000000L0oooo00120?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0U@3oool010000000oooo0?ooo`0000070?ooo`00
@`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`000000
1`3oool004@0oooo0P00000g0?ooo`030000003oool0oooo09H0oooo00@000000?ooo`3oool00000
1P3oool004H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2G0?ooo`030000003o
ool0000000H0oooo00170?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0V03oool2
000000H0oooo00180?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0U`3oool30000
00H0oooo00190?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0U03oool4000000T0
oooo001:0?ooo`800000<03oool00`000000oooo0?ooo`2A0?ooo`<000003@3oool004`0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`2=0?ooo`@00000403oool004d0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`290?ooo`@00000503oool004h0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`250?ooo`@00000603oool004l0oooo0P00000[0?ooo`03
0000003oool0oooo0880oooo0`00000L0?ooo`00D@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo07h0oooo1000000O0?ooo`00DP3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo07X0oooo1000000S0?ooo`00D`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo07H0oooo1000000W0?ooo`00E03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0780oooo1000000[0?ooo`00E@3oool2000002D0oooo00<000000?ooo`3oool0K`3oool3000002l0
oooo001G0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0J`3oool400000380oooo
001H0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0I`3oool4000003H0oooo001I
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0H`3oool4000003X0oooo001J0?oo
o`800000803oool00`000000oooo0?ooo`1P0?ooo`<00000?P3oool005`0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`1L0?ooo`@00000@@3oool005d0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1H0?ooo`@00000A@3oool005h0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1D0?ooo`@00000B@3oool005l0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1A0?ooo`<00000C@3oool00600oooo0P00000J0?ooo`030000003oool0oooo
04d0oooo1000001@0?ooo`00HP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04T0
oooo1000001D0?ooo`00H`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo
1000001H0?ooo`00I03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0480oooo0`00
001L0?ooo`00I@3oool2000001D0oooo00<000000?ooo`3oool0?P3oool4000005l0oooo001W0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0>P3oool4000006<0oooo001X0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0=P3oool4000006L0oooo001Y0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0<`3oool3000006/0oooo001Z0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0;`3oool4000006h0oooo001[0?ooo`8000003P3oool0
0`000000oooo0?ooo`0/0?ooo`@00000LP3oool006d0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0X0?ooo`@00000MP3oool006h0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0T0?ooo`@00000NP3oool006l0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0Q0?ooo`<00000OP3oool00700oooo0P0000090?ooo`030000003oool0oooo01d0oooo1000
00210?ooo`00LP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo10000025
0?ooo`00L`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo100000290?oo
o`00M03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo0`00002=0?ooo`00
M@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo1000002@0?ooo`00MP3o
ool2000000<0oooo00<000000?ooo`3oool02P3oool4000009@0oooo001h0?ooo`040000003oool0
oooo000000P0oooo1000002H0?ooo`00N@3oool00`000000oooo000000050?ooo`<00000W03oool0
07X0oooo0P0000000`3oool0000000000002000009l0oooo001k0?ooo`800000X`3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool009l0oooo0`00001n0?ooo`00X03oool00`000000
oooo0?ooo`1m0?ooo`00>P3oool3000000<0oooo0`0000030?ooo`<000000P3oool01@000000oooo
0000003oool000000080oooo0`0000040?ooo`8000000P3oool3000000<0oooo1@0000020?ooo`<0
0000203oool3000000@0oooo0`0000020?ooo`D0000000D0oooo00000000000000000?ooo`020000
0080oooo0P0000090?ooo`<000000`3oool300000080oooo0`0000040?ooo`<000000`3oool40000
0080oooo100000070?ooo`<000001@3oool2000000030?ooo`00000000000080000000@0oooo0000
00000000oooo0`0000040?ooo`8000000P3oool500000080oooo0`0000020?ooo`<0000000<0oooo
000000000000;@3oool003T0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00d0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3o
ool000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000002h0oooo000i0?ooo`060000003oool0oooo0?ooo`000000
oooo1@0000000`3oool000000?ooo`020?ooo`080000003oool000000?ooo`000000oooo0000003o
ool500000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`000000303oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0303oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo1@00
00020?ooo`<000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0/0?ooo`00>@3oool00`000000oooo00000004000000<0oooo00<0
00000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`040000003oool0oooo000000D0oooo0P0000050?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`060?ooo`<000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0
oooo0P0000030?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`070000003oool0oooo
0?ooo`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
1`3oool3000000<0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00@000000?ooo`3oool000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0/0?ooo`00>@3oool00`000000oooo
0?ooo`040?ooo`<000000`3oool300000080oooo0P0000000`3oool000000?ooo`020?ooo`<00000
0P3oool400000080oooo0P000000103oool000000000003oool3000000@0oooo0`0000090?ooo`04
0000003oool0oooo00000080oooo0`0000020?ooo`<000000`3oool400000080oooo100000090?oo
o`030000003oool0oooo0080oooo100000020?ooo`80000000<0oooo0000000000000P3oool30000
00<0oooo0P0000040?ooo`<000002@3oool00`000000oooo0?ooo`020?ooo`80000000@0oooo0000
00000000oooo100000030?ooo`<000000P3oool400000080oooo0`0000040?ooo`<000000P3oool4
000002l0oooo000i0?ooo`050000003oool0oooo0?ooo`0000006P3oool00`000000oooo0?ooo`0K
0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool02@3oool010000000oooo0?oo
o`00000L0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000503oool00`000000
oooo0?ooo`110?ooo`00>P3oool3000001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0=0?ooo`@000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo
0`00000K0?ooo`800000203oool5000001@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0j0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0700771, 0.0473795, \
0.00363043, 0.00363043}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9316024822911542`\)\), 
        ",", \(BackFocalLength \[Rule] 43.75324264754414`\), 
        ",", \(BackFocalPoint \[Rule] {153.25324264754414`, 0, 0}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] 0\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {109.5`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 5\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 5, 
            SurfaceNumber \[Rule] 2, ComponentNumber \[Rule] 3}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 50.17886731848154`\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {207.1154899597168`, 0, 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              
              TagBox[\(Move[
                  PlanoConvexLens[{f1, 100}, 50, 
                    9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                HoldForm], ",", 
              TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                HoldForm], ",", 
              TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                HoldForm], ",", 
              
              TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                    104}, {GraphicDesign \[Rule] Off}]\),
                HoldForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8719456015187742`, 
              12.028419839771795`}, {\(-0.019928708108396996`\), 
              0.8719456015187739`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
            HoldForm]}], ",", \(OpticalMedium \[Rule] Vacuum\), 
        ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"PointSpreadFunction", "\[Rule]", 
              RowBox[{"(", 
                
                TagBox[\(\[SkeletonIndicator]  
                    SurfaceGraphics  \[SkeletonIndicator]\),
                  False,
                  Editable->False], ")"}]}], "}"}]}], 
        ",", \(Plot2D \[Rule] False\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-0.2705121409329072`\), 
                  0.2705121409329072`}, {\(-0.2705121409329099`\), 
                  0.2705121409329099`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(SourceID \[Rule] 518\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0910321471583293`\), \
\(-0.8233477284578328`\)}, {\(-0.019928708108396996`\), \
\(-0.9316024822911542`\)}}\), 
        ",", \(TransverseMagnification \[Rule] \(-1.0910321471583293`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", \(WaveLength \[Rule] 0.532`\)}], 
      "}"}]], "Output",
  CellLabel->"Out[16]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
GeometricPointSpreadFunction[offaxis3D, FindImagePoint->True, \
FocalFraction->0, Plot2D->False]\
\>", "Input",
  CellLabel->"In[17]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32054e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -93 0 ]
[.5 .82364 93 9 ]
[.0553 .23527 -12 -8.78226 ]
[.0553 .23527 0 .21774 ]
[.21625 .17193 -5.81891 -9 ]
[.21625 .17193 .18109 0 ]
[.38785 .10443 -5.48528 -9 ]
[.38785 .10443 .51472 0 ]
[.57119 .03237 -5.15165 -9 ]
[.57119 .03237 .84835 0 ]
[.70256 -0.00233 0 -6.25961 ]
[.70256 -0.00233 12 2.74039 ]
[.78385 .12214 0 -6.13752 ]
[.78385 .12214 24 2.86248 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.92182 .33342 0 -5.93797 ]
[.92182 .33342 18 3.06203 ]
[.98087 .42386 0 -5.85538 ]
[.98087 .42386 6 3.14462 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01096 .34752 -6 -2.81206 ]
[.01096 .34752 0 6.18794 ]
[-0.00291 .43446 -6 -2.88604 ]
[-0.00291 .43446 0 6.11396 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Geometric Point Spread Function)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.0648 .24431 m
.06955 .24884 L
s
[(-1)] .0553 .23527 1 .95161 Mshowa
.22524 .18149 m
.22973 .18627 L
s
[(0)] .21625 .17193 .93964 1 Mshowa
.39622 .11454 m
.40041 .11959 L
s
[(1)] .38785 .10443 .82843 1 Mshowa
.57883 .04303 m
.58266 .04837 L
s
[(2)] .57119 .03237 .71722 1 Mshowa
.125 Mabswid
.09609 .23206 m
.09891 .23481 L
s
.12777 .21966 m
.13057 .22243 L
s
.15985 .20709 m
.16261 .2099 L
s
.19234 .19437 m
.19507 .19721 L
s
.25856 .16844 m
.26122 .17135 L
s
.29231 .15523 m
.29493 .15816 L
s
.3265 .14184 m
.32909 .14481 L
s
.36113 .12828 m
.36368 .13128 L
s
.43178 .10062 m
.43425 .10368 L
s
.46781 .08651 m
.47024 .08961 L
s
.50432 .07221 m
.50671 .07534 L
s
.54133 .05772 m
.54367 .06089 L
s
.61686 .02815 m
.6191 .03138 L
s
.6554 .01305 m
.6576 .01632 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69034 .00245 m
.68423 .00484 L
s
[(-1)] .70256 -0.00233 -1 .39103 Mshowa
.77152 .12662 m
.76535 .12887 L
s
[(-0.5)] .78385 .12214 -1 .36389 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.90932 .33742 m
.90307 .33941 L
s
[(0.5)] .92182 .33342 -1 .31955 Mshowa
.9683 .42764 m
.96202 .42953 L
s
[(1)] .98087 .42386 -1 .3012 Mshowa
.125 Mabswid
.70734 .02845 m
.70366 .02987 L
s
.72394 .05385 m
.72026 .05525 L
s
.74016 .07866 m
.73648 .08004 L
s
.75602 .10292 m
.75232 .10428 L
s
.78667 .14981 m
.78297 .15114 L
s
.80149 .17248 m
.79778 .17379 L
s
.816 .19466 m
.81228 .19596 L
s
.83019 .21637 m
.82646 .21765 L
s
.85767 .25841 m
.85394 .25967 L
s
.87099 .27878 m
.86725 .28002 L
s
.88403 .29873 m
.88029 .29995 L
s
.8968 .31827 m
.89306 .31948 L
s
.92159 .35618 m
.91783 .35737 L
s
.93361 .37458 m
.92985 .37575 L
s
.9454 .39261 m
.94164 .39377 L
s
.95696 .41029 m
.9532 .41144 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02325 .34291 m
.02939 .34061 L
s
[(1)] .01096 .34752 1 -0.3751 Mshowa
.00944 .43003 m
.01562 .42782 L
s
[(2)] -0.00291 .43446 1 -0.35866 Mshowa
.125 Mabswid
.03377 .2765 m
.03744 .27508 L
s
.03118 .29284 m
.03486 .29143 L
s
.02857 .30935 m
.03225 .30795 L
s
.02592 .32604 m
.02961 .32465 L
s
.02055 .35996 m
.02424 .35859 L
s
.01782 .37719 m
.02151 .37583 L
s
.01506 .39462 m
.01875 .39326 L
s
.01227 .41223 m
.01597 .41089 L
s
.00659 .44804 m
.0103 .44672 L
s
.00371 .46624 m
.00742 .46493 L
s
.00079 .48465 m
.00451 .48335 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.64 .69 .88 r
.40024 .60041 .40504 .60607 .41321 .60247 .40836 .59851 Metetra
.632 .759 .939 r
.40836 .59851 .41321 .60247 .4214 .59887 .41652 .59661 Metetra
.672 .855 .969 r
.41652 .59661 .4214 .59887 .42958 .59638 .42473 .5936 Metetra
.683 .83 .954 r
.42473 .5936 .42958 .59638 .43778 .59392 .43297 .59056 Metetra
.659 .797 .948 r
.43297 .59056 .43778 .59392 .446 .59145 .44121 .58804 Metetra
.657 .794 .948 r
.44121 .58804 .446 .59145 .45426 .58897 .44948 .58555 Metetra
.684 .8 .936 r
.44948 .58555 .45426 .58897 .46253 .58649 .45779 .58254 Metetra
.688 .776 .918 r
.45779 .58254 .46253 .58649 .47083 .584 .46612 .57946 Metetra
.667 .745 .909 r
.46612 .57946 .47083 .584 .47916 .5815 .47446 .57687 Metetra
.664 .741 .908 r
.47446 .57687 .47916 .5815 .48751 .579 .48283 .57435 Metetra
.664 .741 .908 r
.48283 .57435 .48751 .579 .49589 .57648 .49123 .57182 Metetra
.664 .741 .908 r
.49123 .57182 .49589 .57648 .50429 .57396 .49965 .56929 Metetra
.664 .741 .908 r
.49965 .56929 .50429 .57396 .51272 .57143 .50809 .56674 Metetra
.664 .741 .908 r
.50809 .56674 .51272 .57143 .52118 .5689 .51657 .56419 Metetra
.664 .741 .908 r
.51657 .56419 .52118 .5689 .52966 .56635 .52506 .56163 Metetra
.664 .741 .908 r
.52506 .56163 .52966 .56635 .53817 .5638 .53359 .55907 Metetra
.664 .741 .908 r
.53359 .55907 .53817 .5638 .5467 .56124 .54214 .55649 Metetra
.664 .741 .908 r
.54214 .55649 .5467 .56124 .55526 .55867 .55072 .55391 Metetra
.664 .741 .908 r
.55072 .55391 .55526 .55867 .56385 .55609 .55932 .55132 Metetra
.664 .741 .908 r
.55932 .55132 .56385 .55609 .57247 .55351 .56796 .54872 Metetra
.664 .741 .908 r
.56796 .54872 .57247 .55351 .58111 .55092 .57661 .54611 Metetra
.664 .741 .908 r
.57661 .54611 .58111 .55092 .58977 .54832 .5853 .5435 Metetra
.664 .741 .908 r
.5853 .5435 .58977 .54832 .59847 .54571 .59401 .54087 Metetra
.664 .741 .908 r
.59401 .54087 .59847 .54571 .60719 .54309 .60275 .53824 Metetra
.664 .741 .908 r
.60275 .53824 .60719 .54309 .61594 .54047 .61152 .5356 Metetra
.664 .741 .908 r
.61152 .5356 .61594 .54047 .62472 .53783 .62032 .53295 Metetra
.664 .741 .908 r
.62032 .53295 .62472 .53783 .63352 .53519 .62914 .53029 Metetra
.664 .741 .908 r
.62914 .53029 .63352 .53519 .64235 .53254 .63799 .52763 Metetra
.664 .741 .908 r
.63799 .52763 .64235 .53254 .65121 .52989 .64687 .52496 Metetra
.664 .741 .908 r
.64687 .52496 .65121 .52989 .6601 .52722 .65578 .52227 Metetra
.664 .741 .908 r
.65578 .52227 .6601 .52722 .66902 .52454 .66471 .51958 Metetra
.664 .741 .908 r
.66471 .51958 .66902 .52454 .67796 .52186 .67368 .51688 Metetra
.664 .741 .908 r
.67368 .51688 .67796 .52186 .68694 .51917 .68267 .51418 Metetra
.664 .741 .908 r
.68267 .51418 .68694 .51917 .69594 .51647 .69169 .51146 Metetra
.664 .741 .908 r
.69169 .51146 .69594 .51647 .70497 .51376 .70074 .50874 Metetra
.664 .741 .908 r
.70074 .50874 .70497 .51376 .71403 .51104 .70982 .506 Metetra
.664 .741 .908 r
.70982 .506 .71403 .51104 .72311 .50832 .71893 .50326 Metetra
.664 .741 .908 r
.71893 .50326 .72311 .50832 .73223 .50558 .72806 .50051 Metetra
.664 .741 .908 r
.72806 .50051 .73223 .50558 .74138 .50284 .73723 .49775 Metetra
.664 .741 .908 r
.73723 .49775 .74138 .50284 .75055 .50008 .74643 .49498 Metetra
.664 .741 .908 r
.74643 .49498 .75055 .50008 .75976 .49732 .75565 .4922 Metetra
.664 .741 .908 r
.75565 .4922 .75976 .49732 .76899 .49455 .76491 .48941 Metetra
.664 .741 .908 r
.76491 .48941 .76899 .49455 .77826 .49177 .77419 .48662 Metetra
.664 .741 .908 r
.77419 .48662 .77826 .49177 .78755 .48898 .78351 .48381 Metetra
.664 .741 .908 r
.78351 .48381 .78755 .48898 .79688 .48619 .79286 .481 Metetra
.664 .741 .908 r
.79286 .481 .79688 .48619 .80623 .48338 .80223 .47818 Metetra
.664 .741 .908 r
.80223 .47818 .80623 .48338 .81562 .48057 .81164 .47534 Metetra
.664 .741 .908 r
.81164 .47534 .81562 .48057 .82503 .47774 .82108 .4725 Metetra
.664 .741 .908 r
.82108 .4725 .82503 .47774 .83448 .47491 .83054 .46965 Metetra
.664 .741 .908 r
.83054 .46965 .83448 .47491 .84395 .47206 .84004 .46679 Metetra
.664 .741 .908 r
.84004 .46679 .84395 .47206 .85346 .46921 .84957 .46392 Metetra
.664 .741 .908 r
.84957 .46392 .85346 .46921 .863 .46635 .85914 .46104 Metetra
.664 .741 .908 r
.85914 .46104 .863 .46635 .87257 .46348 .86873 .45815 Metetra
.664 .741 .908 r
.86873 .45815 .87257 .46348 .88217 .4606 .87835 .45526 Metetra
.66 .74 .909 r
.87835 .45526 .88217 .4606 .89181 .45771 .88802 .45242 Metetra
.639 .734 .918 r
.88802 .45242 .89181 .45771 .90147 .45481 .89778 .4501 Metetra
.637 .76 .937 r
.89778 .4501 .90147 .45481 .91117 .4519 .90756 .44772 Metetra
.657 .794 .948 r
.90756 .44772 .91117 .4519 .9209 .44898 .91732 .44478 Metetra
.655 .794 .948 r
.91732 .44478 .9209 .44898 .93066 .44605 .92711 .44188 Metetra
.627 .784 .957 r
.92711 .44188 .93066 .44605 .94045 .44311 .93701 .43952 Metetra
.616 .812 .975 r
.93701 .43952 .94045 .44311 .95029 .44021 .94694 .43712 Metetra
.668 .861 .973 r
.94694 .43712 .95029 .44021 .96031 .43847 .95675 .43356 Metetra
.685 .775 .919 r
.95675 .43356 .96031 .43847 .97037 .43672 .9666 .43 Metetra
.553 .658 .905 r
.39541 .59471 .40024 .60041 .40836 .59851 .40349 .59452 Metetra
.508 .718 .967 r
.40349 .59452 .40836 .59851 .41652 .59661 .4116 .59433 Metetra
.702 .859 .957 r
.4116 .59433 .41652 .59661 .42473 .5936 .41985 .59081 Metetra
.712 .834 .94 r
.41985 .59081 .42473 .5936 .43297 .59056 .42813 .58718 Metetra
.661 .797 .948 r
.42813 .58718 .43297 .59056 .44121 .58804 .43639 .58461 Metetra
.657 .794 .948 r
.43639 .58461 .44121 .58804 .44948 .58555 .44468 .58211 Metetra
.708 .803 .924 r
.44468 .58211 .44948 .58555 .45779 .58254 .45302 .57856 Metetra
.712 .78 .905 r
.45302 .57856 .45779 .58254 .46612 .57946 .46138 .57489 Metetra
.67 .746 .908 r
.46138 .57489 .46612 .57946 .47446 .57687 .46974 .57221 Metetra
.664 .741 .908 r
.46974 .57221 .47446 .57687 .48283 .57435 .47812 .56968 Metetra
.664 .741 .908 r
.47812 .56968 .48283 .57435 .49123 .57182 .48653 .56713 Metetra
.664 .741 .908 r
.48653 .56713 .49123 .57182 .49965 .56929 .49497 .56459 Metetra
.664 .741 .908 r
.49497 .56459 .49965 .56929 .50809 .56674 .50344 .56203 Metetra
.664 .741 .908 r
.50344 .56203 .50809 .56674 .51657 .56419 .51193 .55946 Metetra
.664 .741 .908 r
.51193 .55946 .51657 .56419 .52506 .56163 .52044 .55689 Metetra
.664 .741 .908 r
.52044 .55689 .52506 .56163 .53359 .55907 .52898 .55431 Metetra
.664 .741 .908 r
.52898 .55431 .53359 .55907 .54214 .55649 .53755 .55172 Metetra
.664 .741 .908 r
.53755 .55172 .54214 .55649 .55072 .55391 .54615 .54912 Metetra
.664 .741 .908 r
.54615 .54912 .55072 .55391 .55932 .55132 .55477 .54651 Metetra
.664 .741 .908 r
.55477 .54651 .55932 .55132 .56796 .54872 .56342 .5439 Metetra
.664 .741 .908 r
.56342 .5439 .56796 .54872 .57661 .54611 .5721 .54128 Metetra
.664 .741 .908 r
.5721 .54128 .57661 .54611 .5853 .5435 .5808 .53865 Metetra
.664 .741 .908 r
.5808 .53865 .5853 .5435 .59401 .54087 .58953 .53601 Metetra
.664 .741 .908 r
.58953 .53601 .59401 .54087 .60275 .53824 .59829 .53336 Metetra
.664 .741 .908 r
.59829 .53336 .60275 .53824 .61152 .5356 .60708 .5307 Metetra
.664 .741 .908 r
.60708 .5307 .61152 .5356 .62032 .53295 .61589 .52804 Metetra
.664 .741 .908 r
.61589 .52804 .62032 .53295 .62914 .53029 .62473 .52537 Metetra
.664 .741 .908 r
.62473 .52537 .62914 .53029 .63799 .52763 .6336 .52269 Metetra
.664 .741 .908 r
.6336 .52269 .63799 .52763 .64687 .52496 .6425 .52 Metetra
.664 .741 .908 r
.6425 .52 .64687 .52496 .65578 .52227 .65143 .5173 Metetra
.664 .741 .908 r
.65143 .5173 .65578 .52227 .66471 .51958 .66038 .51459 Metetra
.664 .741 .908 r
.66038 .51459 .66471 .51958 .67368 .51688 .66937 .51188 Metetra
.664 .741 .908 r
.66937 .51188 .67368 .51688 .68267 .51418 .67838 .50916 Metetra
.664 .741 .908 r
.67838 .50916 .68267 .51418 .69169 .51146 .68742 .50642 Metetra
.664 .741 .908 r
.68742 .50642 .69169 .51146 .70074 .50874 .69649 .50368 Metetra
.664 .741 .908 r
.69649 .50368 .70074 .50874 .70982 .506 .70559 .50093 Metetra
.664 .741 .908 r
.70559 .50093 .70982 .506 .71893 .50326 .71472 .49817 Metetra
.664 .741 .908 r
.71472 .49817 .71893 .50326 .72806 .50051 .72387 .49541 Metetra
.664 .741 .908 r
.72387 .49541 .72806 .50051 .73723 .49775 .73306 .49263 Metetra
.664 .741 .908 r
.73306 .49263 .73723 .49775 .74643 .49498 .74228 .48984 Metetra
.664 .741 .908 r
.74228 .48984 .74643 .49498 .75565 .4922 .75152 .48705 Metetra
.664 .741 .908 r
.75152 .48705 .75565 .4922 .76491 .48941 .7608 .48425 Metetra
.664 .741 .908 r
.7608 .48425 .76491 .48941 .77419 .48662 .77011 .48143 Metetra
.664 .741 .908 r
.77011 .48143 .77419 .48662 .78351 .48381 .77944 .47861 Metetra
.664 .741 .908 r
.77944 .47861 .78351 .48381 .79286 .481 .78881 .47578 Metetra
.664 .741 .908 r
.78881 .47578 .79286 .481 .80223 .47818 .79821 .47294 Metetra
.664 .741 .908 r
.79821 .47294 .80223 .47818 .81164 .47534 .80764 .47009 Metetra
.664 .741 .908 r
.80764 .47009 .81164 .47534 .82108 .4725 .8171 .46723 Metetra
.664 .741 .908 r
.8171 .46723 .82108 .4725 .83054 .46965 .82659 .46436 Metetra
.664 .741 .908 r
.82659 .46436 .83054 .46965 .84004 .46679 .83611 .46149 Metetra
.664 .741 .908 r
.83611 .46149 .84004 .46679 .84957 .46392 .84566 .4586 Metetra
.664 .741 .908 r
.84566 .4586 .84957 .46392 .85914 .46104 .85525 .4557 Metetra
.664 .741 .908 r
.85525 .4557 .85914 .46104 .86873 .45815 .86486 .4528 Metetra
.664 .741 .908 r
.86486 .4528 .86873 .45815 .87835 .45526 .87451 .44988 Metetra
.657 .739 .91 r
.87451 .44988 .87835 .45526 .88802 .45242 .88421 .44711 Metetra
.612 .723 .924 r
.88421 .44711 .88802 .45242 .89778 .4501 .89405 .44537 Metetra
.61 .749 .943 r
.89405 .44537 .89778 .4501 .90756 .44772 .90393 .44351 Metetra
.657 .794 .948 r
.90393 .44351 .90756 .44772 .91732 .44478 .91371 .44056 Metetra
.653 .793 .949 r
.91371 .44056 .91732 .44478 .92711 .44188 .92354 .43767 Metetra
.594 .77 .964 r
.92354 .43767 .92711 .44188 .93701 .43952 .93354 .4359 Metetra
.585 .798 .981 r
.93354 .4359 .93701 .43952 .94694 .43712 .94357 .43401 Metetra
.754 .886 .939 r
.94357 .43401 .94694 .43712 .95675 .43356 .95317 .42863 Metetra
.749 .798 .892 r
.95317 .42863 .95675 .43356 .9666 .43 .9628 .42324 Metetra
.6 .722 .93 r
.39052 .59012 .39541 .59471 .40349 .59452 .39865 .58886 Metetra
.61 .682 .893 r
.39865 .58886 .40349 .59452 .4116 .59433 .40681 .5876 Metetra
.66 .666 .845 r
.40681 .5876 .4116 .59433 .41985 .59081 .41504 .58509 Metetra
.665 .699 .872 r
.41504 .58509 .41985 .59081 .42813 .58718 .42329 .58253 Metetra
.664 .74 .907 r
.42329 .58253 .42813 .58718 .43639 .58461 .43157 .58002 Metetra
.663 .743 .909 r
.43157 .58002 .43639 .58461 .44468 .58211 .43988 .57751 Metetra
.687 .749 .899 r
.43988 .57751 .44468 .58211 .45302 .57856 .44822 .57443 Metetra
.69 .77 .913 r
.44822 .57443 .45302 .57856 .46138 .57489 .45659 .57128 Metetra
.663 .79 .942 r
.45659 .57128 .46138 .57489 .46974 .57221 .46497 .56866 Metetra
.658 .792 .946 r
.46497 .56866 .46974 .57221 .47812 .56968 .47337 .56611 Metetra
.682 .797 .936 r
.47337 .56611 .47812 .56968 .48653 .56713 .48181 .56309 Metetra
.687 .776 .919 r
.48181 .56309 .48653 .56713 .49497 .56459 .49027 .55997 Metetra
.668 .747 .909 r
.49027 .55997 .49497 .56459 .50344 .56203 .49875 .55728 Metetra
.664 .741 .908 r
.49875 .55728 .50344 .56203 .51193 .55946 .50726 .5547 Metetra
.664 .741 .908 r
.50726 .5547 .51193 .55946 .52044 .55689 .51579 .55212 Metetra
.664 .741 .908 r
.51579 .55212 .52044 .55689 .52898 .55431 .52435 .54952 Metetra
.664 .741 .908 r
.52435 .54952 .52898 .55431 .53755 .55172 .53294 .54691 Metetra
.664 .741 .908 r
.53294 .54691 .53755 .55172 .54615 .54912 .54155 .5443 Metetra
.664 .741 .908 r
.54155 .5443 .54615 .54912 .55477 .54651 .55019 .54168 Metetra
.664 .741 .908 r
.55019 .54168 .55477 .54651 .56342 .5439 .55886 .53905 Metetra
.664 .741 .908 r
.55886 .53905 .56342 .5439 .5721 .54128 .56755 .53641 Metetra
.664 .741 .908 r
.56755 .53641 .5721 .54128 .5808 .53865 .57628 .53377 Metetra
.664 .741 .908 r
.57628 .53377 .5808 .53865 .58953 .53601 .58502 .53111 Metetra
.664 .741 .908 r
.58502 .53111 .58953 .53601 .59829 .53336 .5938 .52845 Metetra
.664 .741 .908 r
.5938 .52845 .59829 .53336 .60708 .5307 .60261 .52578 Metetra
.664 .741 .908 r
.60261 .52578 .60708 .5307 .61589 .52804 .61144 .5231 Metetra
.664 .741 .908 r
.61144 .5231 .61589 .52804 .62473 .52537 .6203 .52041 Metetra
.664 .741 .908 r
.6203 .52041 .62473 .52537 .6336 .52269 .62919 .51772 Metetra
.664 .741 .908 r
.62919 .51772 .6336 .52269 .6425 .52 .63811 .51501 Metetra
.664 .741 .908 r
.63811 .51501 .6425 .52 .65143 .5173 .64705 .5123 Metetra
.664 .741 .908 r
.64705 .5123 .65143 .5173 .66038 .51459 .65603 .50957 Metetra
.664 .741 .908 r
.65603 .50957 .66038 .51459 .66937 .51188 .66503 .50684 Metetra
.664 .741 .908 r
.66503 .50684 .66937 .51188 .67838 .50916 .67406 .5041 Metetra
.664 .741 .908 r
.67406 .5041 .67838 .50916 .68742 .50642 .68312 .50136 Metetra
.664 .741 .908 r
.68312 .50136 .68742 .50642 .69649 .50368 .69221 .4986 Metetra
.664 .741 .908 r
.69221 .4986 .69649 .50368 .70559 .50093 .70133 .49583 Metetra
.664 .741 .908 r
.70133 .49583 .70559 .50093 .71472 .49817 .71048 .49306 Metetra
.664 .741 .908 r
.71048 .49306 .71472 .49817 .72387 .49541 .71966 .49027 Metetra
.664 .741 .908 r
.71966 .49027 .72387 .49541 .73306 .49263 .72887 .48748 Metetra
.664 .741 .908 r
.72887 .48748 .73306 .49263 .74228 .48984 .7381 .48468 Metetra
.664 .741 .908 r
.7381 .48468 .74228 .48984 .75152 .48705 .74737 .48187 Metetra
.664 .741 .908 r
.74737 .48187 .75152 .48705 .7608 .48425 .75667 .47905 Metetra
.664 .741 .908 r
.75667 .47905 .7608 .48425 .77011 .48143 .766 .47622 Metetra
.664 .741 .908 r
.766 .47622 .77011 .48143 .77944 .47861 .77535 .47338 Metetra
.664 .741 .908 r
.77535 .47338 .77944 .47861 .78881 .47578 .78474 .47053 Metetra
.664 .741 .908 r
.78474 .47053 .78881 .47578 .79821 .47294 .79416 .46767 Metetra
.664 .741 .908 r
.79416 .46767 .79821 .47294 .80764 .47009 .80361 .4648 Metetra
.664 .741 .908 r
.80361 .4648 .80764 .47009 .8171 .46723 .81309 .46193 Metetra
.664 .741 .908 r
.81309 .46193 .8171 .46723 .82659 .46436 .82261 .45904 Metetra
.664 .741 .908 r
.82261 .45904 .82659 .46436 .83611 .46149 .83215 .45615 Metetra
.659 .74 .909 r
.83215 .45615 .83611 .46149 .84566 .4586 .84174 .45335 Metetra
.639 .736 .919 r
.84174 .45335 .84566 .4586 .85525 .4557 .8514 .45102 Metetra
.639 .762 .937 r
.8514 .45102 .85525 .4557 .86486 .4528 .86109 .44858 Metetra
.658 .792 .946 r
.86109 .44858 .86486 .4528 .87451 .44988 .87077 .44565 Metetra
.654 .791 .948 r
.87077 .44565 .87451 .44988 .88421 .44711 .88048 .44279 Metetra
.627 .777 .953 r
.88048 .44279 .88421 .44711 .89405 .44537 .89029 .44047 Metetra
.636 .754 .933 r
.89029 .44047 .89405 .44537 .90393 .44351 .90013 .43809 Metetra
.663 .743 .909 r
.90013 .43809 .90393 .44351 .91371 .44056 .90994 .43512 Metetra
.663 .743 .909 r
.90994 .43512 .91371 .44056 .92354 .43767 .91978 .43214 Metetra
.661 .739 .908 r
.91978 .43214 .92354 .43767 .93354 .4359 .92966 .42921 Metetra
.662 .698 .873 r
.92966 .42921 .93354 .4359 .94357 .43401 .93957 .42622 Metetra
.694 .682 .833 r
.93957 .42622 .94357 .43401 .95317 .42863 .94935 .42193 Metetra
.702 .717 .86 r
.94935 .42193 .95317 .42863 .9628 .42324 .95914 .41762 Metetra
.66 .74 .909 r
.3856 .58553 .39052 .59012 .39865 .58886 .39378 .58311 Metetra
.66 .697 .873 r
.39378 .58311 .39865 .58886 .40681 .5876 .40199 .58069 Metetra
.621 .647 .854 r
.40199 .58069 .40681 .5876 .41504 .58509 .4102 .57924 Metetra
.617 .68 .887 r
.4102 .57924 .41504 .58509 .42329 .58253 .41843 .57782 Metetra
.66 .738 .907 r
.41843 .57782 .42329 .58253 .43157 .58002 .42672 .57537 Metetra
.663 .742 .908 r
.42672 .57537 .43157 .58002 .43988 .57751 .43505 .57284 Metetra
.665 .742 .908 r
.43505 .57284 .43988 .57751 .44822 .57443 .44339 .57027 Metetra
.664 .764 .925 r
.44339 .57027 .44822 .57443 .45659 .57128 .45177 .56769 Metetra
.658 .791 .945 r
.45177 .56769 .45659 .57128 .46497 .56866 .46016 .56513 Metetra
.657 .794 .948 r
.46016 .56513 .46497 .56866 .47337 .56611 .46859 .56257 Metetra
.704 .803 .926 r
.46859 .56257 .47337 .56611 .48181 .56309 .47705 .55904 Metetra
.711 .782 .907 r
.47705 .55904 .48181 .56309 .49027 .55997 .48554 .55532 Metetra
.673 .749 .907 r
.48554 .55532 .49027 .55997 .49875 .55728 .49404 .55251 Metetra
.664 .741 .908 r
.49404 .55251 .49875 .55728 .50726 .5547 .50256 .54992 Metetra
.664 .741 .908 r
.50256 .54992 .50726 .5547 .51579 .55212 .51111 .54732 Metetra
.664 .741 .908 r
.51111 .54732 .51579 .55212 .52435 .54952 .51969 .5447 Metetra
.664 .741 .908 r
.51969 .5447 .52435 .54952 .53294 .54691 .5283 .54208 Metetra
.664 .741 .908 r
.5283 .54208 .53294 .54691 .54155 .5443 .53693 .53946 Metetra
.664 .741 .908 r
.53693 .53946 .54155 .5443 .55019 .54168 .54558 .53682 Metetra
.664 .741 .908 r
.54558 .53682 .55019 .54168 .55886 .53905 .55427 .53417 Metetra
.664 .741 .908 r
.55427 .53417 .55886 .53905 .56755 .53641 .56298 .53152 Metetra
.664 .741 .908 r
.56298 .53152 .56755 .53641 .57628 .53377 .57172 .52886 Metetra
.664 .741 .908 r
.57172 .52886 .57628 .53377 .58502 .53111 .58049 .52619 Metetra
.664 .741 .908 r
.58049 .52619 .58502 .53111 .5938 .52845 .58929 .52351 Metetra
.664 .741 .908 r
.58929 .52351 .5938 .52845 .60261 .52578 .59811 .52083 Metetra
.664 .741 .908 r
.59811 .52083 .60261 .52578 .61144 .5231 .60696 .51813 Metetra
.664 .741 .908 r
.60696 .51813 .61144 .5231 .6203 .52041 .61584 .51543 Metetra
.664 .741 .908 r
.61584 .51543 .6203 .52041 .62919 .51772 .62475 .51272 Metetra
.664 .741 .908 r
.62475 .51272 .62919 .51772 .63811 .51501 .63369 .50999 Metetra
.664 .741 .908 r
.63369 .50999 .63811 .51501 .64705 .5123 .64265 .50726 Metetra
.664 .741 .908 r
.64265 .50726 .64705 .5123 .65603 .50957 .65164 .50453 Metetra
.664 .741 .908 r
.65164 .50453 .65603 .50957 .66503 .50684 .66067 .50178 Metetra
.664 .741 .908 r
.66067 .50178 .66503 .50684 .67406 .5041 .66972 .49902 Metetra
.664 .741 .908 r
.66972 .49902 .67406 .5041 .68312 .50136 .6788 .49626 Metetra
.664 .741 .908 r
.6788 .49626 .68312 .50136 .69221 .4986 .68791 .49348 Metetra
.664 .741 .908 r
.68791 .49348 .69221 .4986 .70133 .49583 .69705 .4907 Metetra
.664 .741 .908 r
.69705 .4907 .70133 .49583 .71048 .49306 .70622 .48791 Metetra
.664 .741 .908 r
.70622 .48791 .71048 .49306 .71966 .49027 .71542 .48511 Metetra
.664 .741 .908 r
.71542 .48511 .71966 .49027 .72887 .48748 .72464 .4823 Metetra
.664 .741 .908 r
.72464 .4823 .72887 .48748 .7381 .48468 .7339 .47948 Metetra
.664 .741 .908 r
.7339 .47948 .7381 .48468 .74737 .48187 .74319 .47665 Metetra
.664 .741 .908 r
.74319 .47665 .74737 .48187 .75667 .47905 .75251 .47381 Metetra
.664 .741 .908 r
.75251 .47381 .75667 .47905 .766 .47622 .76186 .47097 Metetra
.664 .741 .908 r
.76186 .47097 .766 .47622 .77535 .47338 .77124 .46811 Metetra
.664 .741 .908 r
.77124 .46811 .77535 .47338 .78474 .47053 .78065 .46525 Metetra
.664 .741 .908 r
.78065 .46525 .78474 .47053 .79416 .46767 .79009 .46237 Metetra
.664 .741 .908 r
.79009 .46237 .79416 .46767 .80361 .4648 .79956 .45949 Metetra
.664 .741 .908 r
.79956 .45949 .80361 .4648 .81309 .46193 .80907 .45659 Metetra
.664 .741 .908 r
.80907 .45659 .81309 .46193 .82261 .45904 .8186 .45369 Metetra
.664 .741 .908 r
.8186 .45369 .82261 .45904 .83215 .45615 .82817 .45078 Metetra
.654 .738 .911 r
.82817 .45078 .83215 .45615 .84174 .45335 .83779 .44808 Metetra
.612 .725 .926 r
.83779 .44808 .84174 .45335 .8514 .45102 .84754 .44633 Metetra
.614 .753 .944 r
.84754 .44633 .8514 .45102 .86109 .44858 .8573 .44438 Metetra
.657 .794 .948 r
.8573 .44438 .86109 .44858 .87077 .44565 .867 .44143 Metetra
.657 .794 .948 r
.867 .44143 .87077 .44565 .88048 .44279 .87674 .43847 Metetra
.656 .79 .946 r
.87674 .43847 .88048 .44279 .89029 .44047 .88651 .43554 Metetra
.66 .763 .926 r
.88651 .43554 .89029 .44047 .90013 .43809 .89631 .4326 Metetra
.663 .742 .908 r
.89631 .4326 .90013 .43809 .90994 .43512 .90614 .42961 Metetra
.666 .743 .907 r
.90614 .42961 .90994 .43512 .91978 .43214 .916 .42653 Metetra
.705 .755 .891 r
.916 .42653 .91978 .43214 .92966 .42921 .92576 .42238 Metetra
.697 .71 .859 r
.92576 .42238 .92966 .42921 .93957 .42622 .93554 .41825 Metetra
.661 .662 .84 r
.93554 .41825 .93957 .42622 .94935 .42193 .94549 .41514 Metetra
.665 .699 .871 r
.94549 .41514 .94935 .42193 .95914 .41762 .95547 .41202 Metetra
.664 .741 .908 r
.38065 .58092 .3856 .58553 .39378 .58311 .38885 .57842 Metetra
.664 .738 .905 r
.38885 .57842 .39378 .58311 .40199 .58069 .39708 .5759 Metetra
.607 .719 .924 r
.39708 .5759 .40199 .58069 .4102 .57924 .4053 .57451 Metetra
.604 .721 .927 r
.4053 .57451 .4102 .57924 .41843 .57782 .41354 .57316 Metetra
.66 .74 .909 r
.41354 .57316 .41843 .57782 .42672 .57537 .42185 .5707 Metetra
.663 .742 .908 r
.42185 .5707 .42672 .57537 .43505 .57284 .43019 .56815 Metetra
.641 .735 .917 r
.43019 .56815 .43505 .57284 .44339 .57027 .43854 .56609 Metetra
.634 .757 .936 r
.43854 .56609 .44339 .57027 .45177 .56769 .44692 .56407 Metetra
.679 .795 .936 r
.44692 .56407 .45177 .56769 .46016 .56513 .45534 .5611 Metetra
.687 .778 .92 r
.45534 .5611 .46016 .56513 .46859 .56257 .46379 .55798 Metetra
.689 .755 .902 r
.46379 .55798 .46859 .56257 .47705 .55904 .47227 .55478 Metetra
.69 .769 .912 r
.47227 .55478 .47705 .55904 .48554 .55532 .48077 .55155 Metetra
.666 .787 .939 r
.48077 .55155 .48554 .55532 .49404 .55251 .48929 .54882 Metetra
.658 .79 .945 r
.48929 .54882 .49404 .55251 .50256 .54992 .49783 .54621 Metetra
.68 .795 .936 r
.49783 .54621 .50256 .54992 .51111 .54732 .50641 .54317 Metetra
.686 .777 .92 r
.50641 .54317 .51111 .54732 .51969 .5447 .51501 .54 Metetra
.669 .749 .91 r
.51501 .54 .51969 .5447 .5283 .54208 .52363 .53723 Metetra
.664 .741 .908 r
.52363 .53723 .5283 .54208 .53693 .53946 .53228 .53458 Metetra
.664 .741 .908 r
.53228 .53458 .53693 .53946 .54558 .53682 .54095 .53193 Metetra
.664 .741 .908 r
.54095 .53193 .54558 .53682 .55427 .53417 .54966 .52927 Metetra
.664 .741 .908 r
.54966 .52927 .55427 .53417 .56298 .53152 .55839 .5266 Metetra
.664 .741 .908 r
.55839 .5266 .56298 .53152 .57172 .52886 .56714 .52393 Metetra
.664 .741 .908 r
.56714 .52393 .57172 .52886 .58049 .52619 .57593 .52124 Metetra
.664 .741 .908 r
.57593 .52124 .58049 .52619 .58929 .52351 .58475 .51855 Metetra
.664 .741 .908 r
.58475 .51855 .58929 .52351 .59811 .52083 .59359 .51584 Metetra
.664 .741 .908 r
.59359 .51584 .59811 .52083 .60696 .51813 .60246 .51313 Metetra
.664 .741 .908 r
.60246 .51313 .60696 .51813 .61584 .51543 .61136 .51041 Metetra
.664 .741 .908 r
.61136 .51041 .61584 .51543 .62475 .51272 .62028 .50769 Metetra
.664 .741 .908 r
.62028 .50769 .62475 .51272 .63369 .50999 .62924 .50495 Metetra
.664 .741 .908 r
.62924 .50495 .63369 .50999 .64265 .50726 .63822 .5022 Metetra
.664 .741 .908 r
.63822 .5022 .64265 .50726 .65164 .50453 .64724 .49945 Metetra
.664 .741 .908 r
.64724 .49945 .65164 .50453 .66067 .50178 .65628 .49668 Metetra
.664 .741 .908 r
.65628 .49668 .66067 .50178 .66972 .49902 .66535 .49391 Metetra
.664 .741 .908 r
.66535 .49391 .66972 .49902 .6788 .49626 .67445 .49113 Metetra
.664 .741 .908 r
.67445 .49113 .6788 .49626 .68791 .49348 .68358 .48834 Metetra
.664 .741 .908 r
.68358 .48834 .68791 .49348 .69705 .4907 .69274 .48554 Metetra
.664 .741 .908 r
.69274 .48554 .69705 .4907 .70622 .48791 .70193 .48273 Metetra
.664 .741 .908 r
.70193 .48273 .70622 .48791 .71542 .48511 .71115 .47991 Metetra
.664 .741 .908 r
.71115 .47991 .71542 .48511 .72464 .4823 .7204 .47709 Metetra
.664 .741 .908 r
.7204 .47709 .72464 .4823 .7339 .47948 .72968 .47425 Metetra
.664 .741 .908 r
.72968 .47425 .7339 .47948 .74319 .47665 .73899 .47141 Metetra
.664 .741 .908 r
.73899 .47141 .74319 .47665 .75251 .47381 .74833 .46855 Metetra
.664 .741 .908 r
.74833 .46855 .75251 .47381 .76186 .47097 .7577 .46569 Metetra
.664 .741 .908 r
.7577 .46569 .76186 .47097 .77124 .46811 .7671 .46281 Metetra
.664 .741 .908 r
.7671 .46281 .77124 .46811 .78065 .46525 .77653 .45993 Metetra
.664 .741 .908 r
.77653 .45993 .78065 .46525 .79009 .46237 .786 .45704 Metetra
.658 .739 .91 r
.786 .45704 .79009 .46237 .79956 .45949 .7955 .45428 Metetra
.64 .738 .92 r
.7955 .45428 .79956 .45949 .80907 .45659 .80508 .45193 Metetra
.641 .763 .937 r
.80508 .45193 .80907 .45659 .8186 .45369 .81467 .44944 Metetra
.658 .79 .945 r
.81467 .44944 .8186 .45369 .82817 .45078 .82427 .44651 Metetra
.652 .788 .947 r
.82427 .44651 .82817 .45078 .83779 .44808 .8339 .4437 Metetra
.627 .773 .951 r
.8339 .4437 .83779 .44808 .84754 .44633 .84362 .44141 Metetra
.633 .751 .933 r
.84362 .44141 .84754 .44633 .8573 .44438 .85338 .43909 Metetra
.64 .739 .921 r
.85338 .43909 .8573 .44438 .867 .44143 .86316 .43669 Metetra
.642 .765 .937 r
.86316 .43669 .867 .44143 .87674 .43847 .87297 .43413 Metetra
.684 .8 .937 r
.87297 .43413 .87674 .43847 .88651 .43554 .8827 .43058 Metetra
.683 .772 .919 r
.8827 .43058 .88651 .43554 .89631 .4326 .89247 .42707 Metetra
.663 .742 .908 r
.89247 .42707 .89631 .4326 .90614 .42961 .90232 .42406 Metetra
.666 .743 .907 r
.90232 .42406 .90614 .42961 .916 .42653 .9122 .42096 Metetra
.708 .759 .892 r
.9122 .42096 .916 .42653 .92576 .42238 .92197 .41671 Metetra
.706 .755 .89 r
.92197 .41671 .92576 .42238 .93554 .41825 .93178 .41249 Metetra
.664 .735 .903 r
.93178 .41249 .93554 .41825 .94549 .41514 .94176 .40943 Metetra
.664 .738 .905 r
.94176 .40943 .94549 .41514 .95547 .41202 .95177 .40637 Metetra
.664 .741 .908 r
.37567 .57629 .38065 .58092 .38885 .57842 .38389 .57377 Metetra
.664 .741 .908 r
.38389 .57377 .38885 .57842 .39708 .5759 .39213 .57124 Metetra
.606 .725 .929 r
.39213 .57124 .39708 .5759 .4053 .57451 .40036 .56984 Metetra
.603 .724 .93 r
.40036 .56984 .4053 .57451 .41354 .57316 .40862 .56847 Metetra
.66 .741 .91 r
.40862 .56847 .41354 .57316 .42185 .5707 .41695 .56599 Metetra
.663 .742 .908 r
.41695 .56599 .42185 .5707 .43019 .56815 .4253 .56343 Metetra
.613 .727 .927 r
.4253 .56343 .43019 .56815 .43854 .56609 .43365 .56188 Metetra
.6 .747 .947 r
.43365 .56188 .43854 .56609 .44692 .56407 .44203 .56043 Metetra
.699 .798 .927 r
.44203 .56043 .44692 .56407 .45534 .5611 .45049 .55701 Metetra
.71 .781 .907 r
.45049 .55701 .45534 .5611 .46379 .55798 .45897 .5533 Metetra
.673 .748 .907 r
.45897 .5533 .46379 .55798 .47227 .55478 .46746 .55047 Metetra
.665 .763 .923 r
.46746 .55047 .47227 .55478 .48077 .55155 .47597 .54781 Metetra
.659 .789 .943 r
.47597 .54781 .48077 .55155 .48929 .54882 .48451 .54518 Metetra
.658 .794 .947 r
.48451 .54518 .48929 .54882 .49783 .54621 .49307 .54256 Metetra
.7 .803 .929 r
.49307 .54256 .49783 .54621 .50641 .54317 .50167 .53905 Metetra
.71 .784 .909 r
.50167 .53905 .50641 .54317 .51501 .54 .51029 .53528 Metetra
.676 .751 .908 r
.51029 .53528 .51501 .54 .52363 .53723 .51893 .53234 Metetra
.664 .741 .908 r
.51893 .53234 .52363 .53723 .53228 .53458 .5276 .52968 Metetra
.664 .741 .908 r
.5276 .52968 .53228 .53458 .54095 .53193 .53629 .52701 Metetra
.664 .741 .908 r
.53629 .52701 .54095 .53193 .54966 .52927 .54501 .52434 Metetra
.664 .741 .908 r
.54501 .52434 .54966 .52927 .55839 .5266 .55376 .52165 Metetra
.664 .741 .908 r
.55376 .52165 .55839 .5266 .56714 .52393 .56254 .51896 Metetra
.664 .741 .908 r
.56254 .51896 .56714 .52393 .57593 .52124 .57134 .51626 Metetra
.664 .741 .908 r
.57134 .51626 .57593 .52124 .58475 .51855 .58018 .51355 Metetra
.664 .741 .908 r
.58018 .51355 .58475 .51855 .59359 .51584 .58904 .51083 Metetra
.664 .741 .908 r
.58904 .51083 .59359 .51584 .60246 .51313 .59793 .50811 Metetra
.664 .741 .908 r
.59793 .50811 .60246 .51313 .61136 .51041 .60684 .50537 Metetra
.664 .741 .908 r
.60684 .50537 .61136 .51041 .62028 .50769 .61579 .50263 Metetra
.664 .741 .908 r
.61579 .50263 .62028 .50769 .62924 .50495 .62477 .49987 Metetra
.664 .741 .908 r
.62477 .49987 .62924 .50495 .63822 .5022 .63377 .49711 Metetra
.664 .741 .908 r
.63377 .49711 .63822 .5022 .64724 .49945 .6428 .49434 Metetra
.664 .741 .908 r
.6428 .49434 .64724 .49945 .65628 .49668 .65186 .49156 Metetra
.664 .741 .908 r
.65186 .49156 .65628 .49668 .66535 .49391 .66096 .48877 Metetra
.664 .741 .908 r
.66096 .48877 .66535 .49391 .67445 .49113 .67008 .48597 Metetra
.664 .741 .908 r
.67008 .48597 .67445 .49113 .68358 .48834 .67923 .48316 Metetra
.664 .741 .908 r
.67923 .48316 .68358 .48834 .69274 .48554 .68841 .48035 Metetra
.664 .741 .908 r
.68841 .48035 .69274 .48554 .70193 .48273 .69762 .47752 Metetra
.664 .741 .908 r
.69762 .47752 .70193 .48273 .71115 .47991 .70686 .47469 Metetra
.664 .741 .908 r
.70686 .47469 .71115 .47991 .7204 .47709 .71613 .47184 Metetra
.664 .741 .908 r
.71613 .47184 .7204 .47709 .72968 .47425 .72543 .46899 Metetra
.664 .741 .908 r
.72543 .46899 .72968 .47425 .73899 .47141 .73476 .46613 Metetra
.664 .741 .908 r
.73476 .46613 .73899 .47141 .74833 .46855 .74412 .46326 Metetra
.664 .741 .908 r
.74412 .46326 .74833 .46855 .7577 .46569 .75351 .46038 Metetra
.664 .741 .908 r
.75351 .46038 .7577 .46569 .7671 .46281 .76293 .45749 Metetra
.664 .741 .908 r
.76293 .45749 .7671 .46281 .77653 .45993 .77239 .45458 Metetra
.664 .741 .908 r
.77239 .45458 .77653 .45993 .786 .45704 .78187 .45168 Metetra
.651 .737 .912 r
.78187 .45168 .786 .45704 .7955 .45428 .79142 .44905 Metetra
.612 .727 .928 r
.79142 .44905 .7955 .45428 .80508 .45193 .80106 .44728 Metetra
.618 .756 .944 r
.80106 .44728 .80508 .45193 .81467 .44944 .81072 .44524 Metetra
.658 .794 .947 r
.81072 .44524 .81467 .44944 .82427 .44651 .82034 .4423 Metetra
.657 .793 .947 r
.82034 .4423 .82427 .44651 .8339 .4437 .83 .43935 Metetra
.656 .787 .944 r
.83 .43935 .8339 .4437 .84362 .44141 .83968 .43644 Metetra
.652 .758 .927 r
.83968 .43644 .84362 .44141 .85338 .43909 .84942 .4337 Metetra
.613 .725 .925 r
.84942 .4337 .85338 .43909 .86316 .43669 .85929 .43188 Metetra
.621 .755 .942 r
.85929 .43188 .86316 .43669 .87297 .43413 .86917 .42975 Metetra
.709 .808 .927 r
.86917 .42975 .87297 .43413 .8827 .43058 .87886 .42558 Metetra
.704 .779 .911 r
.87886 .42558 .8827 .43058 .89247 .42707 .8886 .42151 Metetra
.663 .742 .908 r
.8886 .42151 .89247 .42707 .90232 .42406 .89848 .41848 Metetra
.666 .743 .907 r
.89848 .41848 .90232 .42406 .9122 .42096 .90838 .41537 Metetra
.708 .759 .892 r
.90838 .41537 .9122 .42096 .92197 .41671 .91818 .41109 Metetra
.706 .758 .893 r
.91818 .41109 .92197 .41671 .93178 .41249 .92801 .40685 Metetra
.664 .741 .908 r
.92801 .40685 .93178 .41249 .94176 .40943 .93801 .40378 Metetra
.664 .741 .908 r
.93801 .40378 .94176 .40943 .95177 .40637 .94805 .4007 Metetra
.664 .741 .908 r
.37066 .57163 .37567 .57629 .38389 .57377 .3789 .56909 Metetra
.664 .741 .908 r
.3789 .56909 .38389 .57377 .39213 .57124 .38716 .56655 Metetra
.633 .733 .92 r
.38716 .56655 .39213 .57124 .40036 .56984 .39542 .56463 Metetra
.635 .713 .903 r
.39542 .56463 .40036 .56984 .40862 .56847 .40371 .56272 Metetra
.641 .696 .885 r
.40371 .56272 .40862 .56847 .41695 .56599 .41204 .56069 Metetra
.641 .712 .899 r
.41204 .56069 .41695 .56599 .4253 .56343 .42039 .55864 Metetra
.633 .731 .918 r
.42039 .55864 .4253 .56343 .43365 .56188 .42877 .5567 Metetra
.634 .716 .906 r
.42877 .5567 .43365 .56188 .44203 .56043 .43717 .55477 Metetra
.681 .713 .873 r
.43717 .55477 .44203 .56043 .45049 .55701 .44563 .55168 Metetra
.688 .727 .88 r
.44563 .55168 .45049 .55701 .45897 .5533 .45413 .54842 Metetra
.648 .734 .912 r
.45413 .54842 .45897 .5533 .46746 .55047 .46262 .54614 Metetra
.636 .755 .934 r
.46262 .54614 .46746 .55047 .47597 .54781 .47114 .54404 Metetra
.629 .781 .954 r
.47114 .54404 .47597 .54781 .48451 .54518 .47969 .54194 Metetra
.619 .805 .971 r
.47969 .54194 .48451 .54518 .49307 .54256 .48827 .53983 Metetra
.712 .851 .949 r
.48827 .53983 .49307 .54256 .50167 .53905 .49689 .53598 Metetra
.735 .837 .928 r
.49689 .53598 .50167 .53905 .51029 .53528 .50554 .53161 Metetra
.68 .8 .939 r
.50554 .53161 .51029 .53528 .51893 .53234 .51421 .5285 Metetra
.659 .788 .943 r
.51421 .5285 .51893 .53234 .5276 .52968 .52289 .52582 Metetra
.678 .793 .936 r
.52289 .52582 .5276 .52968 .53629 .52701 .53161 .52277 Metetra
.686 .777 .921 r
.53161 .52277 .53629 .52701 .54501 .52434 .54035 .51955 Metetra
.671 .75 .91 r
.54035 .51955 .54501 .52434 .55376 .52165 .54911 .51668 Metetra
.664 .741 .908 r
.54911 .51668 .55376 .52165 .56254 .51896 .55791 .51397 Metetra
.664 .741 .908 r
.55791 .51397 .56254 .51896 .57134 .51626 .56673 .51125 Metetra
.664 .741 .908 r
.56673 .51125 .57134 .51626 .58018 .51355 .57558 .50853 Metetra
.664 .741 .908 r
.57558 .50853 .58018 .51355 .58904 .51083 .58446 .50579 Metetra
.664 .741 .908 r
.58446 .50579 .58904 .51083 .59793 .50811 .59337 .50305 Metetra
.664 .741 .908 r
.59337 .50305 .59793 .50811 .60684 .50537 .60231 .5003 Metetra
.664 .741 .908 r
.60231 .5003 .60684 .50537 .61579 .50263 .61127 .49754 Metetra
.664 .741 .908 r
.61127 .49754 .61579 .50263 .62477 .49987 .62027 .49477 Metetra
.664 .741 .908 r
.62027 .49477 .62477 .49987 .63377 .49711 .62929 .49199 Metetra
.664 .741 .908 r
.62929 .49199 .63377 .49711 .6428 .49434 .63834 .4892 Metetra
.664 .741 .908 r
.63834 .4892 .6428 .49434 .65186 .49156 .64742 .4864 Metetra
.664 .741 .908 r
.64742 .4864 .65186 .49156 .66096 .48877 .65654 .4836 Metetra
.664 .741 .908 r
.65654 .4836 .66096 .48877 .67008 .48597 .66568 .48078 Metetra
.664 .741 .908 r
.66568 .48078 .67008 .48597 .67923 .48316 .67485 .47796 Metetra
.664 .741 .908 r
.67485 .47796 .67923 .48316 .68841 .48035 .68405 .47513 Metetra
.664 .741 .908 r
.68405 .47513 .68841 .48035 .69762 .47752 .69328 .47228 Metetra
.664 .741 .908 r
.69328 .47228 .69762 .47752 .70686 .47469 .70254 .46943 Metetra
.664 .741 .908 r
.70254 .46943 .70686 .47469 .71613 .47184 .71183 .46657 Metetra
.664 .741 .908 r
.71183 .46657 .71613 .47184 .72543 .46899 .72115 .4637 Metetra
.664 .741 .908 r
.72115 .4637 .72543 .46899 .73476 .46613 .7305 .46082 Metetra
.664 .741 .908 r
.7305 .46082 .73476 .46613 .74412 .46326 .73989 .45793 Metetra
.656 .739 .91 r
.73989 .45793 .74412 .46326 .75351 .46038 .74931 .45521 Metetra
.64 .74 .921 r
.74931 .45521 .75351 .46038 .76293 .45749 .7588 .45284 Metetra
.644 .765 .936 r
.7588 .45284 .76293 .45749 .77239 .45458 .7683 .4503 Metetra
.659 .788 .943 r
.7683 .4503 .77239 .45458 .78187 .45168 .77781 .44738 Metetra
.636 .78 .95 r
.77781 .44738 .78187 .45168 .79142 .44905 .78739 .44489 Metetra
.558 .756 .97 r
.78739 .44489 .79142 .44905 .80106 .44728 .79711 .44371 Metetra
.573 .794 .983 r
.79711 .44371 .80106 .44728 .81072 .44524 .80683 .44199 Metetra
.673 .849 .967 r
.80683 .44199 .81072 .44524 .82034 .4423 .81643 .43849 Metetra
.68 .823 .952 r
.81643 .43849 .82034 .4423 .83 .43935 .82606 .43497 Metetra
.683 .797 .935 r
.82606 .43497 .83 .43935 .83968 .43644 .83572 .43144 Metetra
.677 .768 .919 r
.83572 .43144 .83968 .43644 .84942 .4337 .84543 .4281 Metetra
.636 .727 .914 r
.84543 .4281 .84942 .4337 .85929 .43188 .85527 .42578 Metetra
.644 .712 .897 r
.85527 .42578 .85929 .43188 .86917 .42975 .86513 .42327 Metetra
.685 .717 .873 r
.86513 .42327 .86917 .42975 .87886 .42558 .8749 .41956 Metetra
.687 .734 .887 r
.8749 .41956 .87886 .42558 .8886 .42151 .8847 .41586 Metetra
.684 .748 .9 r
.8847 .41586 .8886 .42151 .89848 .41848 .89454 .41227 Metetra
.683 .727 .884 r
.89454 .41227 .89848 .41848 .90838 .41537 .90441 .40866 Metetra
.685 .712 .869 r
.90441 .40866 .90838 .41537 .91818 .41109 .91429 .40491 Metetra
.686 .731 .884 r
.91429 .40491 .91818 .41109 .92801 .40685 .92421 .40117 Metetra
.664 .741 .908 r
.92421 .40117 .92801 .40685 .93801 .40378 .93424 .39808 Metetra
.664 .741 .908 r
.93424 .39808 .93801 .40378 .94805 .4007 .94431 .39498 Metetra
.664 .741 .908 r
.36563 .56694 .37066 .57163 .3789 .56909 .37388 .56439 Metetra
.664 .741 .908 r
.37388 .56439 .3789 .56909 .38716 .56655 .38216 .56183 Metetra
.66 .74 .909 r
.38216 .56183 .38716 .56655 .39542 .56463 .39046 .55934 Metetra
.66 .718 .892 r
.39046 .55934 .39542 .56463 .40371 .56272 .39878 .55684 Metetra
.619 .684 .889 r
.39878 .55684 .40371 .56272 .41204 .56069 .4071 .55529 Metetra
.614 .701 .907 r
.4071 .55529 .41204 .56069 .42039 .55864 .41545 .55381 Metetra
.656 .737 .91 r
.41545 .55381 .42039 .55864 .42877 .5567 .42385 .55139 Metetra
.66 .72 .893 r
.42385 .55139 .42877 .5567 .43717 .55477 .43229 .54886 Metetra
.664 .701 .874 r
.43229 .54886 .43717 .55477 .44563 .55168 .44076 .54619 Metetra
.666 .716 .886 r
.44076 .54619 .44563 .55168 .45413 .54842 .44925 .54349 Metetra
.62 .725 .921 r
.44925 .54349 .45413 .54842 .46262 .54614 .45775 .54178 Metetra
.602 .745 .945 r
.45775 .54178 .46262 .54614 .47114 .54404 .46628 .54026 Metetra
.591 .77 .965 r
.46628 .54026 .47114 .54404 .47969 .54194 .47484 .53873 Metetra
.575 .794 .982 r
.47484 .53873 .47969 .54194 .48827 .53983 .48343 .53719 Metetra
.726 .858 .944 r
.48343 .53719 .48827 .53983 .49689 .53598 .49209 .533 Metetra
.758 .844 .917 r
.49209 .533 .49689 .53598 .50554 .53161 .50076 .52802 Metetra
.687 .807 .939 r
.50076 .52802 .50554 .53161 .51421 .5285 .50945 .52475 Metetra
.658 .793 .947 r
.50945 .52475 .51421 .5285 .52289 .52582 .51816 .52206 Metetra
.696 .802 .931 r
.51816 .52206 .52289 .52582 .53161 .52277 .52689 .51857 Metetra
.71 .786 .911 r
.52689 .51857 .53161 .52277 .54035 .51955 .53565 .51475 Metetra
.679 .753 .908 r
.53565 .51475 .54035 .51955 .54911 .51668 .54443 .51167 Metetra
.664 .741 .908 r
.54443 .51167 .54911 .51668 .55791 .51397 .55325 .50895 Metetra
.664 .741 .908 r
.55325 .50895 .55791 .51397 .56673 .51125 .56209 .50621 Metetra
.664 .741 .908 r
.56209 .50621 .56673 .51125 .57558 .50853 .57096 .50347 Metetra
.664 .741 .908 r
.57096 .50347 .57558 .50853 .58446 .50579 .57986 .50072 Metetra
.664 .741 .908 r
.57986 .50072 .58446 .50579 .59337 .50305 .58878 .49796 Metetra
.664 .741 .908 r
.58878 .49796 .59337 .50305 .60231 .5003 .59774 .49519 Metetra
.664 .741 .908 r
.59774 .49519 .60231 .5003 .61127 .49754 .60673 .49241 Metetra
.664 .741 .908 r
.60673 .49241 .61127 .49754 .62027 .49477 .61574 .48963 Metetra
.664 .741 .908 r
.61574 .48963 .62027 .49477 .62929 .49199 .62478 .48683 Metetra
.664 .741 .908 r
.62478 .48683 .62929 .49199 .63834 .4892 .63386 .48403 Metetra
.664 .741 .908 r
.63386 .48403 .63834 .4892 .64742 .4864 .64296 .48122 Metetra
.664 .741 .908 r
.64296 .48122 .64742 .4864 .65654 .4836 .65209 .47839 Metetra
.664 .741 .908 r
.65209 .47839 .65654 .4836 .66568 .48078 .66125 .47556 Metetra
.664 .741 .908 r
.66125 .47556 .66568 .48078 .67485 .47796 .67044 .47272 Metetra
.664 .741 .908 r
.67044 .47272 .67485 .47796 .68405 .47513 .67966 .46987 Metetra
.664 .741 .908 r
.67966 .46987 .68405 .47513 .69328 .47228 .68891 .46701 Metetra
.664 .741 .908 r
.68891 .46701 .69328 .47228 .70254 .46943 .69819 .46414 Metetra
.664 .741 .908 r
.69819 .46414 .70254 .46943 .71183 .46657 .70751 .46126 Metetra
.664 .741 .908 r
.70751 .46126 .71183 .46657 .72115 .4637 .71685 .45838 Metetra
.664 .741 .908 r
.71685 .45838 .72115 .4637 .7305 .46082 .72622 .45548 Metetra
.664 .741 .908 r
.72622 .45548 .7305 .46082 .73989 .45793 .73563 .45257 Metetra
.648 .736 .913 r
.73563 .45257 .73989 .45793 .74931 .45521 .74509 .45002 Metetra
.612 .729 .929 r
.74509 .45002 .74931 .45521 .7588 .45284 .75463 .44823 Metetra
.622 .76 .945 r
.75463 .44823 .7588 .45284 .7683 .4503 .7642 .44611 Metetra
.658 .793 .947 r
.7642 .44611 .7683 .4503 .77781 .44738 .77373 .44316 Metetra
.627 .782 .956 r
.77373 .44316 .77781 .44738 .78739 .44489 .78335 .44082 Metetra
.513 .742 .977 r
.78335 .44082 .78739 .44489 .79711 .44371 .79315 .44022 Metetra
.546 .789 .988 r
.79315 .44022 .79711 .44371 .80683 .44199 .80292 .43883 Metetra
.702 .862 .958 r
.80292 .43883 .80683 .44199 .81643 .43849 .8125 .4347 Metetra
.707 .833 .943 r
.8125 .4347 .81643 .43849 .82606 .43497 .8221 .43056 Metetra
.708 .805 .925 r
.8221 .43056 .82606 .43497 .83572 .43144 .83173 .42641 Metetra
.7 .776 .91 r
.83173 .42641 .83572 .43144 .84543 .4281 .8414 .42245 Metetra
.66 .737 .906 r
.8414 .42245 .84543 .4281 .85527 .42578 .85121 .4195 Metetra
.661 .714 .888 r
.85121 .4195 .85527 .42578 .86513 .42327 .86104 .41653 Metetra
.665 .701 .874 r
.86104 .41653 .86513 .42327 .8749 .41956 .8709 .41341 Metetra
.67 .724 .89 r
.8709 .41341 .8749 .41956 .8847 .41586 .88077 .41017 Metetra
.705 .755 .891 r
.88077 .41017 .8847 .41586 .89454 .41227 .89057 .40596 Metetra
.699 .731 .876 r
.89057 .40596 .89454 .41227 .90441 .40866 .9004 .4018 Metetra
.665 .7 .872 r
.9004 .4018 .90441 .40866 .91429 .40491 .91038 .39863 Metetra
.666 .72 .889 r
.91038 .39863 .91429 .40491 .92421 .40117 .92039 .39546 Metetra
.664 .741 .908 r
.92039 .39546 .92421 .40117 .93424 .39808 .93045 .39235 Metetra
.664 .741 .908 r
.93045 .39235 .93424 .39808 .94431 .39498 .94054 .38923 Metetra
.664 .741 .908 r
.36056 .56222 .36563 .56694 .37388 .56439 .36883 .55966 Metetra
.664 .741 .908 r
.36883 .55966 .37388 .56439 .38216 .56183 .37712 .55709 Metetra
.664 .741 .908 r
.37712 .55709 .38216 .56183 .39046 .55934 .38544 .5545 Metetra
.664 .738 .906 r
.38544 .5545 .39046 .55934 .39878 .55684 .39379 .55192 Metetra
.634 .727 .915 r
.39379 .55192 .39878 .55684 .4071 .55529 .40213 .54995 Metetra
.634 .711 .902 r
.40213 .54995 .4071 .55529 .41545 .55381 .41051 .54802 Metetra
.642 .697 .886 r
.41051 .54802 .41545 .55381 .42385 .55139 .41892 .54593 Metetra
.642 .71 .897 r
.41892 .54593 .42385 .55139 .43229 .54886 .42736 .54382 Metetra
.641 .727 .911 r
.42736 .54382 .43229 .54886 .44076 .54619 .43583 .5417 Metetra
.638 .75 .929 r
.43583 .5417 .44076 .54619 .44925 .54349 .44432 .53957 Metetra
.648 .779 .943 r
.44432 .53957 .44925 .54349 .45775 .54178 .45286 .53715 Metetra
.655 .75 .919 r
.45286 .53715 .45775 .54178 .46628 .54026 .46142 .53467 Metetra
.6 .693 .908 r
.46142 .53467 .46628 .54026 .47484 .53873 .46999 .53341 Metetra
.581 .698 .922 r
.46999 .53341 .47484 .53873 .48343 .53719 .47859 .53245 Metetra
.705 .76 .894 r
.47859 .53245 .48343 .53719 .49209 .533 .48726 .52871 Metetra
.736 .784 .892 r
.48726 .52871 .49209 .533 .50076 .52802 .49595 .52415 Metetra
.664 .79 .941 r
.49595 .52415 .50076 .52802 .50945 .52475 .50466 .52135 Metetra
.622 .803 .969 r
.50466 .52135 .50945 .52475 .51816 .52206 .51338 .51916 Metetra
.686 .844 .959 r
.51338 .51916 .51816 .52206 .52689 .51857 .52214 .51575 Metetra
.71 .853 .95 r
.52214 .51575 .52689 .51857 .53565 .51475 .53093 .51183 Metetra
.687 .845 .959 r
.53093 .51183 .53565 .51475 .54443 .51167 .53974 .50837 Metetra
.68 .825 .953 r
.53974 .50837 .54443 .51167 .55325 .50895 .54857 .50512 Metetra
.683 .801 .937 r
.54857 .50512 .55325 .50895 .56209 .50621 .55743 .50186 Metetra
.685 .777 .921 r
.55743 .50186 .56209 .50621 .57096 .50347 .56631 .49858 Metetra
.672 .752 .911 r
.56631 .49858 .57096 .50347 .57986 .50072 .57523 .49562 Metetra
.664 .741 .908 r
.57523 .49562 .57986 .50072 .58878 .49796 .58417 .49284 Metetra
.664 .741 .908 r
.58417 .49284 .58878 .49796 .59774 .49519 .59315 .49006 Metetra
.664 .741 .908 r
.59315 .49006 .59774 .49519 .60673 .49241 .60215 .48726 Metetra
.664 .741 .908 r
.60215 .48726 .60673 .49241 .61574 .48963 .61119 .48446 Metetra
.664 .741 .908 r
.61119 .48446 .61574 .48963 .62478 .48683 .62025 .48165 Metetra
.664 .741 .908 r
.62025 .48165 .62478 .48683 .63386 .48403 .62934 .47883 Metetra
.664 .741 .908 r
.62934 .47883 .63386 .48403 .64296 .48122 .63846 .476 Metetra
.664 .741 .908 r
.63846 .476 .64296 .48122 .65209 .47839 .64761 .47316 Metetra
.664 .741 .908 r
.64761 .47316 .65209 .47839 .66125 .47556 .6568 .47031 Metetra
.664 .741 .908 r
.6568 .47031 .66125 .47556 .67044 .47272 .66601 .46745 Metetra
.664 .741 .908 r
.66601 .46745 .67044 .47272 .67966 .46987 .67525 .46458 Metetra
.664 .741 .908 r
.67525 .46458 .67966 .46987 .68891 .46701 .68452 .46171 Metetra
.664 .741 .908 r
.68452 .46171 .68891 .46701 .69819 .46414 .69382 .45882 Metetra
.655 .738 .911 r
.69382 .45882 .69819 .46414 .70751 .46126 .70317 .45613 Metetra
.641 .741 .922 r
.70317 .45613 .70751 .46126 .71685 .45838 .71256 .45374 Metetra
.637 .763 .939 r
.71256 .45374 .71685 .45838 .72622 .45548 .72199 .45135 Metetra
.631 .785 .956 r
.72199 .45135 .72622 .45548 .73563 .45257 .73145 .44894 Metetra
.608 .803 .975 r
.73145 .44894 .73563 .45257 .74509 .45002 .74096 .44676 Metetra
.564 .806 .99 r
.74096 .44676 .74509 .45002 .75463 .44823 .75054 .44503 Metetra
.597 .823 .986 r
.75054 .44503 .75463 .44823 .7642 .44611 .76013 .4428 Metetra
.674 .844 .965 r
.76013 .4428 .7642 .44611 .77373 .44316 .76965 .43931 Metetra
.648 .809 .961 r
.76965 .43931 .77373 .44316 .78335 .44082 .77926 .43645 Metetra
.552 .746 .967 r
.77926 .43645 .78335 .44082 .79315 .44022 .78904 .43539 Metetra
.609 .749 .944 r
.78904 .43539 .79315 .44022 .80292 .43883 .7988 .4335 Metetra
.726 .771 .889 r
.7988 .4335 .80292 .43883 .8125 .4347 .80835 .42875 Metetra
.712 .744 .877 r
.80835 .42875 .8125 .4347 .8221 .43056 .81795 .42429 Metetra
.669 .717 .885 r
.81795 .42429 .8221 .43056 .83173 .42641 .82769 .4211 Metetra
.672 .755 .913 r
.82769 .4211 .83173 .42641 .8414 .42245 .83746 .41783 Metetra
.683 .79 .931 r
.83746 .41783 .8414 .42245 .85121 .4195 .84723 .41426 Metetra
.684 .764 .912 r
.84723 .41426 .85121 .4195 .86104 .41653 .85703 .41069 Metetra
.683 .741 .895 r
.85703 .41069 .86104 .41653 .8709 .41341 .86686 .4071 Metetra
.682 .724 .882 r
.86686 .4071 .8709 .41341 .88077 .41017 .87672 .40348 Metetra
.685 .714 .87 r
.87672 .40348 .88077 .41017 .89057 .40596 .88659 .39969 Metetra
.686 .729 .883 r
.88659 .39969 .89057 .40596 .9004 .4018 .89649 .39594 Metetra
.664 .735 .903 r
.89649 .39594 .9004 .4018 .91038 .39863 .90651 .39283 Metetra
.664 .738 .906 r
.90651 .39283 .91038 .39863 .92039 .39546 .91655 .38971 Metetra
.664 .741 .908 r
.91655 .38971 .92039 .39546 .93045 .39235 .92663 .38658 Metetra
.664 .741 .908 r
.92663 .38658 .93045 .39235 .94054 .38923 .93675 .38345 Metetra
.664 .741 .908 r
.35547 .55748 .36056 .56222 .36883 .55966 .36375 .5549 Metetra
.664 .741 .908 r
.36375 .5549 .36883 .55966 .37712 .55709 .37206 .55231 Metetra
.664 .741 .908 r
.37206 .55231 .37712 .55709 .38544 .5545 .3804 .54972 Metetra
.664 .741 .908 r
.3804 .54972 .38544 .5545 .39379 .55192 .38876 .54711 Metetra
.66 .74 .91 r
.38876 .54711 .39379 .55192 .40213 .54995 .39714 .54459 Metetra
.66 .719 .893 r
.39714 .54459 .40213 .54995 .41051 .54802 .40555 .54206 Metetra
.621 .686 .889 r
.40555 .54206 .41051 .54802 .41892 .54593 .41396 .54043 Metetra
.615 .701 .906 r
.41396 .54043 .41892 .54593 .42736 .54382 .42239 .53888 Metetra
.61 .723 .925 r
.42239 .53888 .42736 .54382 .43583 .5417 .43086 .53733 Metetra
.603 .746 .945 r
.43086 .53733 .43583 .5417 .44432 .53957 .43936 .53578 Metetra
.691 .796 .93 r
.43936 .53578 .44432 .53957 .45286 .53715 .44794 .53246 Metetra
.703 .76 .896 r
.44794 .53246 .45286 .53715 .46142 .53467 .45654 .52879 Metetra
.59 .68 .903 r
.45654 .52879 .46142 .53467 .46999 .53341 .46512 .52776 Metetra
.551 .674 .919 r
.46512 .52776 .46999 .53341 .47859 .53245 .47372 .52737 Metetra
.683 .742 .896 r
.47372 .52737 .47859 .53245 .48726 .52871 .4824 .5242 Metetra
.715 .773 .898 r
.4824 .5242 .48726 .52871 .49595 .52415 .49111 .52021 Metetra
.633 .779 .951 r
.49111 .52021 .49595 .52415 .50466 .52135 .49983 .51799 Metetra
.58 .792 .98 r
.49983 .51799 .50466 .52135 .51338 .51916 .50858 .51637 Metetra
.674 .848 .966 r
.50858 .51637 .51338 .51916 .52214 .51575 .51736 .51312 Metetra
.708 .863 .955 r
.51736 .51312 .52214 .51575 .53093 .51183 .52617 .50918 Metetra
.705 .862 .957 r
.52617 .50918 .53093 .51183 .53974 .50837 .535 .5053 Metetra
.707 .843 .947 r
.535 .5053 .53974 .50837 .54857 .50512 .54386 .50144 Metetra
.709 .815 .93 r
.54386 .50144 .54857 .50512 .55743 .50186 .55274 .49758 Metetra
.709 .788 .913 r
.55274 .49758 .55743 .50186 .56631 .49858 .56164 .4937 Metetra
.681 .756 .908 r
.56164 .4937 .56631 .49858 .57523 .49562 .57057 .49049 Metetra
.664 .741 .908 r
.57057 .49049 .57523 .49562 .58417 .49284 .57953 .48769 Metetra
.664 .741 .908 r
.57953 .48769 .58417 .49284 .59315 .49006 .58853 .48489 Metetra
.664 .741 .908 r
.58853 .48489 .59315 .49006 .60215 .48726 .59755 .48208 Metetra
.664 .741 .908 r
.59755 .48208 .60215 .48726 .61119 .48446 .60661 .47926 Metetra
.664 .741 .908 r
.60661 .47926 .61119 .48446 .62025 .48165 .61569 .47643 Metetra
.664 .741 .908 r
.61569 .47643 .62025 .48165 .62934 .47883 .6248 .4736 Metetra
.664 .741 .908 r
.6248 .4736 .62934 .47883 .63846 .476 .63394 .47075 Metetra
.664 .741 .908 r
.63394 .47075 .63846 .476 .64761 .47316 .64311 .46789 Metetra
.664 .741 .908 r
.64311 .46789 .64761 .47316 .6568 .47031 .65232 .46503 Metetra
.664 .741 .908 r
.65232 .46503 .6568 .47031 .66601 .46745 .66155 .46215 Metetra
.664 .741 .908 r
.66155 .46215 .66601 .46745 .67525 .46458 .67081 .45927 Metetra
.664 .741 .908 r
.67081 .45927 .67525 .46458 .68452 .46171 .6801 .45637 Metetra
.664 .741 .908 r
.6801 .45637 .68452 .46171 .69382 .45882 .68943 .45347 Metetra
.645 .735 .914 r
.68943 .45347 .69382 .45882 .70317 .45613 .6988 .45099 Metetra
.612 .732 .931 r
.6988 .45099 .70317 .45613 .71256 .45374 .70825 .44918 Metetra
.604 .755 .951 r
.70825 .44918 .71256 .45374 .72199 .45135 .71774 .44737 Metetra
.593 .78 .97 r
.71774 .44737 .72199 .45135 .73145 .44894 .72726 .44555 Metetra
.573 .803 .986 r
.72726 .44555 .73145 .44894 .74096 .44676 .73683 .44376 Metetra
.551 .816 .995 r
.73683 .44376 .74096 .44676 .75054 .44503 .74644 .44202 Metetra
.601 .836 .988 r
.74644 .44202 .75054 .44503 .76013 .4428 .75604 .43959 Metetra
.702 .859 .957 r
.75604 .43959 .76013 .4428 .76965 .43931 .76555 .43549 Metetra
.678 .822 .952 r
.76555 .43549 .76965 .43931 .77926 .43645 .77514 .43201 Metetra
.59 .76 .96 r
.77514 .43201 .77926 .43645 .78904 .43539 .7849 .43033 Metetra
.64 .753 .93 r
.7849 .43033 .78904 .43539 .7988 .4335 .79463 .42782 Metetra
.741 .764 .871 r
.79463 .42782 .7988 .4335 .80835 .42875 .80415 .42244 Metetra
.717 .735 .865 r
.80415 .42244 .80835 .42875 .81795 .42429 .81375 .41771 Metetra
.625 .689 .89 r
.81375 .41771 .81795 .42429 .82769 .4211 .82362 .41571 Metetra
.634 .739 .924 r
.82362 .41571 .82769 .4211 .83746 .41783 .8335 .41334 Metetra
.707 .806 .926 r
.8335 .41334 .83746 .41783 .84723 .41426 .84324 .40915 Metetra
.706 .779 .908 r
.84324 .40915 .84723 .41426 .85703 .41069 .853 .40494 Metetra
.704 .754 .891 r
.853 .40494 .85703 .41069 .86686 .4071 .8628 .40073 Metetra
.698 .73 .876 r
.8628 .40073 .86686 .4071 .87672 .40348 .87262 .3966 Metetra
.665 .701 .873 r
.87262 .3966 .87672 .40348 .88659 .39969 .88258 .3934 Metetra
.667 .721 .89 r
.88258 .3934 .88659 .39969 .89649 .39594 .89258 .39019 Metetra
.664 .741 .908 r
.89258 .39019 .89649 .39594 .90651 .39283 .90261 .38707 Metetra
.664 .741 .908 r
.90261 .38707 .90651 .39283 .91655 .38971 .91269 .38393 Metetra
.664 .741 .908 r
.91269 .38393 .91655 .38971 .92663 .38658 .92279 .38078 Metetra
.664 .741 .908 r
.92279 .38078 .92663 .38658 .93675 .38345 .93294 .37762 Metetra
.664 .741 .908 r
.35035 .55271 .35547 .55748 .36375 .5549 .35865 .55012 Metetra
.664 .741 .908 r
.35865 .55012 .36375 .5549 .37206 .55231 .36697 .54752 Metetra
.664 .741 .908 r
.36697 .54752 .37206 .55231 .3804 .54972 .37532 .5449 Metetra
.664 .741 .908 r
.37532 .5449 .3804 .54972 .38876 .54711 .3837 .54229 Metetra
.664 .741 .908 r
.3837 .54229 .38876 .54711 .39714 .54459 .3921 .53966 Metetra
.664 .738 .905 r
.3921 .53966 .39714 .54459 .40555 .54206 .40053 .53702 Metetra
.635 .726 .914 r
.40053 .53702 .40555 .54206 .41396 .54043 .40897 .53501 Metetra
.633 .711 .903 r
.40897 .53501 .41396 .54043 .42239 .53888 .41743 .53305 Metetra
.615 .69 .897 r
.41743 .53305 .42239 .53888 .43086 .53733 .42591 .53152 Metetra
.612 .69 .899 r
.42591 .53152 .43086 .53733 .43936 .53578 .43442 .53004 Metetra
.662 .71 .884 r
.43442 .53004 .43936 .53578 .44794 .53246 .44299 .52739 Metetra
.672 .738 .9 r
.44299 .52739 .44794 .53246 .45654 .52879 .4516 .52449 Metetra
.576 .743 .956 r
.4516 .52449 .45654 .52879 .46512 .52776 .46019 .52329 Metetra
.552 .727 .956 r
.46019 .52329 .46512 .52776 .47372 .52737 .46882 .52249 Metetra
.698 .755 .895 r
.46882 .52249 .47372 .52737 .4824 .5242 .47752 .5189 Metetra
.722 .745 .87 r
.47752 .5189 .4824 .5242 .49111 .52021 .48626 .5145 Metetra
.645 .709 .894 r
.48626 .5145 .49111 .52021 .49983 .51799 .49499 .51222 Metetra
.611 .696 .904 r
.49499 .51222 .49983 .51799 .50858 .51637 .50376 .51069 Metetra
.655 .715 .892 r
.50376 .51069 .50858 .51637 .51736 .51312 .51256 .50815 Metetra
.672 .748 .908 r
.51256 .50815 .51736 .51312 .52617 .50918 .52138 .50519 Metetra
.685 .794 .932 r
.52138 .50519 .52617 .50918 .535 .5053 .53024 .50188 Metetra
.69 .823 .947 r
.53024 .50188 .535 .5053 .54386 .50144 .53912 .4984 Metetra
.686 .842 .958 r
.53912 .4984 .54386 .50144 .55274 .49758 .54803 .49492 Metetra
.681 .861 .968 r
.54803 .49492 .55274 .49758 .56164 .4937 .55696 .49142 Metetra
.701 .885 .966 r
.55696 .49142 .56164 .4937 .57057 .49049 .56591 .48744 Metetra
.724 .851 .942 r
.56591 .48744 .57057 .49049 .57953 .48769 .57488 .48314 Metetra
.689 .775 .916 r
.57488 .48314 .57953 .48769 .58853 .48489 .58388 .4797 Metetra
.664 .741 .908 r
.58388 .4797 .58853 .48489 .59755 .48208 .59292 .47687 Metetra
.664 .741 .908 r
.59292 .47687 .59755 .48208 .60661 .47926 .602 .47403 Metetra
.664 .741 .908 r
.602 .47403 .60661 .47926 .61569 .47643 .6111 .47119 Metetra
.664 .741 .908 r
.6111 .47119 .61569 .47643 .6248 .4736 .62023 .46833 Metetra
.664 .741 .908 r
.62023 .46833 .6248 .4736 .63394 .47075 .62939 .46547 Metetra
.664 .741 .908 r
.62939 .46547 .63394 .47075 .64311 .46789 .63859 .46259 Metetra
.664 .741 .908 r
.63859 .46259 .64311 .46789 .65232 .46503 .64781 .45971 Metetra
.664 .741 .908 r
.64781 .45971 .65232 .46503 .66155 .46215 .65706 .45682 Metetra
.664 .741 .908 r
.65706 .45682 .66155 .46215 .67081 .45927 .66634 .45391 Metetra
.637 .732 .917 r
.66634 .45391 .67081 .45927 .6801 .45637 .67569 .45163 Metetra
.585 .739 .949 r
.67569 .45163 .6801 .45637 .68943 .45347 .68511 .45022 Metetra
.565 .806 .99 r
.68511 .45022 .68943 .45347 .6988 .45099 .69455 .44849 Metetra
.569 .848 .997 r
.69455 .44849 .6988 .45099 .70825 .44918 .70401 .44626 Metetra
.587 .834 .992 r
.70401 .44626 .70825 .44918 .71774 .44737 .7135 .44403 Metetra
.601 .818 .983 r
.7135 .44403 .71774 .44737 .72726 .44555 .72303 .44179 Metetra
.621 .804 .97 r
.72303 .44179 .72726 .44555 .73683 .44376 .73258 .43938 Metetra
.649 .784 .946 r
.73258 .43938 .73683 .44376 .74644 .44202 .74214 .43662 Metetra
.671 .748 .908 r
.74214 .43662 .74644 .44202 .75604 .43959 .75171 .43343 Metetra
.704 .732 .873 r
.75171 .43343 .75604 .43959 .76555 .43549 .76124 .42921 Metetra
.679 .72 .88 r
.76124 .42921 .76555 .43549 .77514 .43201 .77085 .42574 Metetra
.593 .685 .905 r
.77085 .42574 .77514 .43201 .7849 .43033 .78066 .42446 Metetra
.627 .715 .91 r
.78066 .42446 .7849 .43033 .79463 .42782 .79045 .42233 Metetra
.731 .769 .883 r
.79045 .42233 .79463 .42782 .80415 .42244 .80003 .41735 Metetra
.721 .782 .901 r
.80003 .41735 .80415 .42244 .81375 .41771 .80967 .41277 Metetra
.652 .765 .932 r
.80967 .41277 .81375 .41771 .82362 .41571 .81949 .40992 Metetra
.664 .736 .904 r
.81949 .40992 .82362 .41571 .8335 .41334 .82933 .40683 Metetra
.703 .726 .869 r
.82933 .40683 .8335 .41334 .84324 .40915 .83908 .40252 Metetra
.7 .722 .867 r
.83908 .40252 .84324 .40915 .853 .40494 .84886 .39827 Metetra
.686 .716 .871 r
.84886 .39827 .853 .40494 .8628 .40073 .85872 .39444 Metetra
.686 .729 .883 r
.85872 .39444 .8628 .40073 .87262 .3966 .86861 .39067 Metetra
.664 .734 .902 r
.86861 .39067 .87262 .3966 .88258 .3934 .87861 .38755 Metetra
.664 .738 .905 r
.87861 .38755 .88258 .3934 .89258 .39019 .88864 .38441 Metetra
.664 .741 .908 r
.88864 .38441 .89258 .39019 .90261 .38707 .8987 .38127 Metetra
.664 .741 .908 r
.8987 .38127 .90261 .38707 .91269 .38393 .9088 .37811 Metetra
.664 .741 .908 r
.9088 .37811 .91269 .38393 .92279 .38078 .91893 .37494 Metetra
.664 .741 .908 r
.91893 .37494 .92279 .38078 .93294 .37762 .9291 .37176 Metetra
.664 .741 .908 r
.3452 .54792 .35035 .55271 .35865 .55012 .35351 .54531 Metetra
.664 .741 .908 r
.35351 .54531 .35865 .55012 .36697 .54752 .36185 .54269 Metetra
.664 .741 .908 r
.36185 .54269 .36697 .54752 .37532 .5449 .37022 .54006 Metetra
.664 .741 .908 r
.37022 .54006 .37532 .5449 .3837 .54229 .37861 .53743 Metetra
.664 .741 .908 r
.37861 .53743 .3837 .54229 .3921 .53966 .38703 .53479 Metetra
.664 .741 .908 r
.38703 .53479 .3921 .53966 .40053 .53702 .39548 .53214 Metetra
.659 .74 .91 r
.39548 .53214 .40053 .53702 .40897 .53501 .40395 .52958 Metetra
.659 .72 .894 r
.40395 .52958 .40897 .53501 .41743 .53305 .41244 .52702 Metetra
.619 .685 .89 r
.41244 .52702 .41743 .53305 .42591 .53152 .42094 .5254 Metetra
.613 .681 .89 r
.42094 .5254 .42591 .53152 .43442 .53004 .42946 .52391 Metetra
.621 .684 .887 r
.42946 .52391 .43442 .53004 .44299 .52739 .43802 .52222 Metetra
.618 .72 .918 r
.43802 .52222 .44299 .52739 .4516 .52449 .44662 .52049 Metetra
.586 .762 .962 r
.44662 .52049 .4516 .52449 .46019 .52329 .45524 .51902 Metetra
.587 .75 .955 r
.45524 .51902 .46019 .52329 .46882 .52249 .46389 .51762 Metetra
.719 .761 .886 r
.46389 .51762 .46882 .52249 .47752 .5189 .47262 .51343 Metetra
.737 .743 .856 r
.47262 .51343 .47752 .5189 .48626 .5145 .48138 .50841 Metetra
.651 .699 .881 r
.48138 .50841 .48626 .5145 .49499 .51222 .49014 .50597 Metetra
.614 .68 .889 r
.49014 .50597 .49499 .51222 .50376 .51069 .49891 .50442 Metetra
.621 .683 .887 r
.49891 .50442 .50376 .51069 .51256 .50815 .50772 .5027 Metetra
.62 .713 .913 r
.50772 .5027 .51256 .50815 .52138 .50519 .51656 .50091 Metetra
.649 .773 .939 r
.51656 .50091 .52138 .50519 .53024 .50188 .52544 .49837 Metetra
.66 .813 .957 r
.52544 .49837 .53024 .50188 .53912 .4984 .53435 .49547 Metetra
.65 .84 .973 r
.53435 .49547 .53912 .4984 .54803 .49492 .54328 .49256 Metetra
.634 .866 .985 r
.54328 .49256 .54803 .49492 .55696 .49142 .55225 .48964 Metetra
.738 .914 .953 r
.55225 .48964 .55696 .49142 .56591 .48744 .56122 .48478 Metetra
.791 .875 .909 r
.56122 .48478 .56591 .48744 .57488 .48314 .57019 .47868 Metetra
.718 .787 .906 r
.57019 .47868 .57488 .48314 .58388 .4797 .5792 .47447 Metetra
.664 .741 .908 r
.5792 .47447 .58388 .4797 .59292 .47687 .58827 .47163 Metetra
.664 .741 .908 r
.58827 .47163 .59292 .47687 .602 .47403 .59736 .46877 Metetra
.664 .741 .908 r
.59736 .46877 .602 .47403 .6111 .47119 .60648 .46591 Metetra
.664 .741 .908 r
.60648 .46591 .6111 .47119 .62023 .46833 .61563 .46304 Metetra
.664 .741 .908 r
.61563 .46304 .62023 .46833 .62939 .46547 .62482 .46015 Metetra
.664 .741 .908 r
.62482 .46015 .62939 .46547 .63859 .46259 .63403 .45726 Metetra
.664 .741 .908 r
.63403 .45726 .63859 .46259 .64781 .45971 .64327 .45436 Metetra
.664 .741 .908 r
.64327 .45436 .64781 .45971 .65706 .45682 .65255 .45145 Metetra
.664 .741 .908 r
.65255 .45145 .65706 .45682 .66634 .45391 .66185 .44853 Metetra
.601 .718 .927 r
.66185 .44853 .66634 .45391 .67569 .45163 .67125 .44698 Metetra
.46 .689 .965 r
.67125 .44698 .67569 .45163 .68511 .45022 .68077 .44735 Metetra
.47 .787 .999 r
.68077 .44735 .68511 .45022 .69455 .44849 .69029 .44648 Metetra
.59 .882 .992 r
.69029 .44648 .69455 .44849 .70401 .44626 .69974 .44365 Metetra
.618 .861 .989 r
.69974 .44365 .70401 .44626 .7135 .44403 .70923 .4408 Metetra
.636 .836 .977 r
.70923 .4408 .7135 .44403 .72303 .44179 .71875 .43794 Metetra
.666 .816 .955 r
.71875 .43794 .72303 .44179 .73258 .43938 .72828 .43472 Metetra
.702 .79 .919 r
.72828 .43472 .73258 .43938 .74214 .43662 .73779 .43073 Metetra
.7 .741 .883 r
.73779 .43073 .74214 .43662 .75171 .43343 .74732 .42666 Metetra
.7 .713 .858 r
.74732 .42666 .75171 .43343 .76124 .42921 .75687 .42242 Metetra
.672 .702 .869 r
.75687 .42242 .76124 .42921 .77085 .42574 .76651 .41909 Metetra
.569 .661 .9 r
.76651 .41909 .77085 .42574 .78066 .42446 .77639 .41839 Metetra
.601 .698 .911 r
.77639 .41839 .78066 .42446 .79045 .42233 .78624 .41686 Metetra
.712 .765 .894 r
.78624 .41686 .79045 .42233 .80003 .41735 .7959 .41245 Metetra
.713 .789 .912 r
.7959 .41245 .80003 .41735 .80967 .41277 .80559 .40811 Metetra
.702 .797 .924 r
.80559 .40811 .80967 .41277 .81949 .40992 .81533 .40403 Metetra
.7 .747 .888 r
.81533 .40403 .81949 .40992 .82933 .40683 .8251 .39991 Metetra
.7 .713 .859 r
.8251 .39991 .82933 .40683 .83908 .40252 .83487 .39558 Metetra
.696 .712 .861 r
.83487 .39558 .83908 .40252 .84886 .39827 .84468 .39138 Metetra
.666 .702 .873 r
.84468 .39138 .84886 .39827 .85872 .39444 .85462 .38814 Metetra
.667 .722 .89 r
.85462 .38814 .85872 .39444 .86861 .39067 .8646 .3849 Metetra
.664 .741 .908 r
.8646 .3849 .86861 .39067 .87861 .38755 .87462 .38175 Metetra
.664 .741 .908 r
.87462 .38175 .87861 .38755 .88864 .38441 .88467 .3786 Metetra
.664 .741 .908 r
.88467 .3786 .88864 .38441 .8987 .38127 .89476 .37543 Metetra
.664 .741 .908 r
.89476 .37543 .8987 .38127 .9088 .37811 .90488 .37225 Metetra
.664 .741 .908 r
.90488 .37225 .9088 .37811 .91893 .37494 .91504 .36906 Metetra
.664 .741 .908 r
.91504 .36906 .91893 .37494 .9291 .37176 .92523 .36586 Metetra
.664 .741 .908 r
.34002 .54309 .3452 .54792 .35351 .54531 .34835 .54047 Metetra
.664 .741 .908 r
.34835 .54047 .35351 .54531 .36185 .54269 .3567 .53783 Metetra
.664 .741 .908 r
.3567 .53783 .36185 .54269 .37022 .54006 .36509 .53519 Metetra
.664 .741 .908 r
.36509 .53519 .37022 .54006 .37861 .53743 .3735 .53254 Metetra
.664 .741 .908 r
.3735 .53254 .37861 .53743 .38703 .53479 .38193 .52989 Metetra
.664 .741 .908 r
.38193 .52989 .38703 .53479 .39548 .53214 .3904 .52722 Metetra
.664 .741 .908 r
.3904 .52722 .39548 .53214 .40395 .52958 .39888 .52454 Metetra
.664 .737 .905 r
.39888 .52454 .40395 .52958 .41244 .52702 .4074 .52186 Metetra
.635 .725 .912 r
.4074 .52186 .41244 .52702 .42094 .5254 .41592 .51979 Metetra
.633 .707 .9 r
.41592 .51979 .42094 .5254 .42946 .52391 .42447 .51781 Metetra
.597 .677 .897 r
.42447 .51781 .42946 .52391 .43802 .52222 .43303 .51662 Metetra
.585 .692 .916 r
.43303 .51662 .43802 .52222 .44662 .52049 .44163 .51558 Metetra
.619 .733 .927 r
.44163 .51558 .44662 .52049 .45524 .51902 .45027 .51376 Metetra
.631 .722 .913 r
.45027 .51376 .45524 .51902 .46389 .51762 .45895 .51175 Metetra
.696 .721 .868 r
.45895 .51175 .46389 .51762 .47262 .51343 .46769 .50806 Metetra
.715 .743 .874 r
.46769 .50806 .47262 .51343 .48138 .50841 .47646 .50386 Metetra
.637 .756 .934 r
.47646 .50386 .48138 .50841 .49014 .50597 .48523 .50162 Metetra
.595 .752 .953 r
.48523 .50162 .49014 .50597 .49891 .50442 .49402 .50005 Metetra
.635 .765 .941 r
.49402 .50005 .49891 .50442 .50772 .5027 .50285 .4978 Metetra
.652 .748 .92 r
.50285 .4978 .50772 .5027 .51656 .50091 .51172 .49527 Metetra
.632 .712 .904 r
.51172 .49527 .51656 .50091 .52544 .49837 .52061 .49321 Metetra
.619 .727 .924 r
.52061 .49321 .52544 .49837 .53435 .49547 .52954 .49136 Metetra
.673 .79 .937 r
.52954 .49136 .53435 .49547 .54328 .49256 .5385 .48828 Metetra
.703 .79 .919 r
.5385 .48828 .54328 .49256 .55225 .48964 .54748 .4845 Metetra
.696 .753 .896 r
.54748 .4845 .55225 .48964 .56122 .48478 .55648 .48084 Metetra
.694 .805 .934 r
.55648 .48084 .56122 .48478 .57019 .47868 .56551 .47725 Metetra
.628 .911 .982 r
.56551 .47725 .57019 .47868 .5792 .47447 .57457 .47381 Metetra
.562 .917 .959 r
.57457 .47381 .5792 .47447 .58827 .47163 .58366 .47047 Metetra
.623 .922 .976 r
.58366 .47047 .58827 .47163 .59736 .46877 .59277 .46686 Metetra
.674 .903 .977 r
.59277 .46686 .59736 .46877 .60648 .46591 .60189 .46302 Metetra
.668 .854 .971 r
.60189 .46302 .60648 .46591 .61563 .46304 .61106 .45966 Metetra
.649 .826 .968 r
.61106 .45966 .61563 .46304 .62482 .46015 .62027 .45676 Metetra
.621 .817 .976 r
.62027 .45676 .62482 .46015 .63403 .45726 .62952 .45432 Metetra
.571 .824 .993 r
.62952 .45432 .63403 .45726 .64327 .45436 .63883 .45237 Metetra
.538 .86 .996 r
.63883 .45237 .64327 .45436 .65255 .45145 .64816 .45019 Metetra
.505 .878 .977 r
.64816 .45019 .65255 .45145 .66185 .44853 .65752 .44774 Metetra
.442 .863 .946 r
.65752 .44774 .66185 .44853 .67125 .44698 .66691 .4454 Metetra
.504 .865 .987 r
.66691 .4454 .67125 .44698 .68077 .44735 .67635 .4432 Metetra
.612 .781 .962 r
.67635 .4432 .68077 .44735 .69029 .44648 .68583 .44108 Metetra
.62 .728 .924 r
.68583 .44108 .69029 .44648 .69974 .44365 .69535 .43908 Metetra
.647 .775 .941 r
.69535 .43908 .69974 .44365 .70923 .4408 .70487 .43638 Metetra
.702 .8 .926 r
.70487 .43638 .70923 .4408 .71875 .43794 .71435 .43241 Metetra
.691 .751 .898 r
.71435 .43241 .71875 .43794 .72828 .43472 .72387 .42867 Metetra
.672 .726 .89 r
.72387 .42867 .72828 .43472 .73779 .43073 .73345 .4254 Metetra
.684 .758 .908 r
.73345 .4254 .73779 .43073 .74732 .42666 .74304 .42184 Metetra
.711 .788 .912 r
.74304 .42184 .74732 .42666 .75687 .42242 .75262 .41758 Metetra
.684 .78 .924 r
.75262 .41758 .75687 .42242 .76651 .41909 .76227 .41401 Metetra
.591 .735 .943 r
.76227 .41401 .76651 .41909 .77639 .41839 .7721 .41243 Metetra
.624 .713 .91 r
.7721 .41243 .77639 .41839 .78624 .41686 .78193 .41035 Metetra
.687 .72 .875 r
.78193 .41035 .78624 .41686 .7959 .41245 .79167 .40653 Metetra
.697 .745 .889 r
.79167 .40653 .7959 .41245 .80559 .40811 .80141 .40251 Metetra
.724 .767 .887 r
.80141 .40251 .80559 .40811 .81533 .40403 .81111 .3977 Metetra
.714 .738 .87 r
.81111 .3977 .81533 .40403 .8251 .39991 .82085 .39302 Metetra
.686 .71 .867 r
.82085 .39302 .8251 .39991 .83487 .39558 .83069 .38916 Metetra
.685 .726 .881 r
.83069 .38916 .83487 .39558 .84468 .39138 .84057 .38538 Metetra
.664 .733 .901 r
.84057 .38538 .84468 .39138 .85462 .38814 .85055 .38224 Metetra
.664 .737 .905 r
.85055 .38224 .85462 .38814 .8646 .3849 .86056 .37908 Metetra
.664 .741 .908 r
.86056 .37908 .8646 .3849 .87462 .38175 .8706 .37592 Metetra
.664 .741 .908 r
.8706 .37592 .87462 .38175 .88467 .3786 .88068 .37274 Metetra
.664 .741 .908 r
.88068 .37274 .88467 .3786 .89476 .37543 .89079 .36955 Metetra
.664 .741 .908 r
.89079 .36955 .89476 .37543 .90488 .37225 .90094 .36636 Metetra
.664 .741 .908 r
.90094 .36636 .90488 .37225 .91504 .36906 .91112 .36315 Metetra
.664 .741 .908 r
.91112 .36315 .91504 .36906 .92523 .36586 .92134 .35993 Metetra
.664 .741 .908 r
.33481 .53824 .34002 .54309 .34835 .54047 .34315 .5356 Metetra
.664 .741 .908 r
.34315 .5356 .34835 .54047 .3567 .53783 .35152 .53295 Metetra
.664 .741 .908 r
.35152 .53295 .3567 .53783 .36509 .53519 .35992 .53029 Metetra
.664 .741 .908 r
.35992 .53029 .36509 .53519 .3735 .53254 .36835 .52763 Metetra
.664 .741 .908 r
.36835 .52763 .3735 .53254 .38193 .52989 .3768 .52496 Metetra
.664 .741 .908 r
.3768 .52496 .38193 .52989 .3904 .52722 .38528 .52227 Metetra
.664 .741 .908 r
.38528 .52227 .3904 .52722 .39888 .52454 .39379 .51958 Metetra
.664 .741 .908 r
.39379 .51958 .39888 .52454 .4074 .52186 .40232 .51688 Metetra
.658 .74 .91 r
.40232 .51688 .4074 .52186 .41592 .51979 .41088 .51429 Metetra
.658 .72 .895 r
.41088 .51429 .41592 .51979 .42447 .51781 .41946 .51171 Metetra
.577 .67 .903 r
.41946 .51171 .42447 .51781 .43303 .51662 .42802 .5109 Metetra
.552 .675 .92 r
.42802 .5109 .43303 .51662 .44163 .51558 .43661 .51043 Metetra
.639 .73 .914 r
.43661 .51043 .44163 .51558 .45027 .51376 .44528 .50824 Metetra
.658 .722 .896 r
.44528 .50824 .45027 .51376 .45895 .51175 .45399 .50562 Metetra
.668 .705 .874 r
.45399 .50562 .45895 .51175 .46769 .50806 .46273 .50269 Metetra
.674 .734 .895 r
.46273 .50269 .46769 .50806 .47646 .50386 .4715 .49966 Metetra
.616 .767 .952 r
.4715 .49966 .47646 .50386 .48523 .50162 .48029 .49771 Metetra
.586 .772 .968 r
.48029 .49771 .48523 .50162 .49402 .50005 .4891 .49613 Metetra
.674 .797 .94 r
.4891 .49613 .49402 .50005 .50285 .4978 .49796 .49302 Metetra
.701 .766 .903 r
.49796 .49302 .50285 .4978 .51172 .49527 .50685 .48928 Metetra
.614 .694 .9 r
.50685 .48928 .51172 .49527 .52061 .49321 .51576 .48763 Metetra
.558 .688 .926 r
.51576 .48763 .52061 .49321 .52954 .49136 .5247 .48696 Metetra
.689 .782 .922 r
.5247 .48696 .52954 .49136 .5385 .48828 .53368 .48351 Metetra
.741 .779 .883 r
.53368 .48351 .5385 .48828 .54748 .4845 .54267 .47852 Metetra
.626 .701 .899 r
.54267 .47852 .54748 .4845 .55648 .48084 .55171 .47657 Metetra
.473 .713 .974 r
.55171 .47657 .55648 .48084 .56551 .47725 .5608 .47655 Metetra
.447 .865 .948 r
.5608 .47655 .56551 .47725 .57457 .47381 .56991 .47425 Metetra
.511 .913 .88 r
.56991 .47425 .57457 .47381 .58366 .47047 .57902 .4703 Metetra
.633 .954 .933 r
.57902 .4703 .58366 .47047 .59277 .46686 .58815 .46574 Metetra
.721 .947 .953 r
.58815 .46574 .59277 .46686 .60189 .46302 .59729 .46069 Metetra
.69 .888 .971 r
.59729 .46069 .60189 .46302 .61106 .45966 .60647 .45674 Metetra
.639 .847 .98 r
.60647 .45674 .61106 .45966 .62027 .45676 .6157 .45382 Metetra
.564 .822 .994 r
.6157 .45382 .62027 .45676 .62952 .45432 .625 .45195 Metetra
.421 .789 .995 r
.625 .45195 .62952 .45432 .63883 .45237 .63437 .45118 Metetra
.355 .804 .949 r
.63437 .45118 .63883 .45237 .64816 .45019 .64377 .44993 Metetra
.311 .799 .876 r
.64377 .44993 .64816 .45019 .65752 .44774 .65319 .44807 Metetra
.442 .879 .862 r
.65319 .44807 .65752 .44774 .66691 .4454 .66257 .44454 Metetra
.742 .966 .935 r
.66257 .44454 .66691 .4454 .67635 .4432 .67188 .43871 Metetra
.7 .795 .924 r
.67188 .43871 .67635 .4432 .68583 .44108 .6813 .43482 Metetra
.57 .675 .911 r
.6813 .43482 .68583 .44108 .69535 .43908 .6909 .43401 Metetra
.634 .75 .932 r
.6909 .43401 .69535 .43908 .70487 .43638 .70046 .43165 Metetra
.744 .798 .896 r
.70046 .43165 .70487 .43638 .71435 .43241 .7099 .42645 Metetra
.704 .741 .88 r
.7099 .42645 .71435 .43241 .72387 .42867 .71942 .42226 Metetra
.626 .696 .895 r
.71942 .42226 .72387 .42867 .73345 .4254 .72909 .42018 Metetra
.649 .752 .925 r
.72909 .42018 .73345 .4254 .74304 .42184 .73877 .41746 Metetra
.712 .809 .926 r
.73877 .41746 .74304 .42184 .75262 .41758 .74837 .41318 Metetra
.696 .805 .933 r
.74837 .41318 .75262 .41758 .76227 .41401 .75802 .40927 Metetra
.648 .775 .941 r
.75802 .40927 .76227 .41401 .7721 .41243 .76779 .40647 Metetra
.656 .728 .902 r
.76779 .40647 .7721 .41243 .78193 .41035 .77758 .40357 Metetra
.667 .704 .875 r
.77758 .40357 .78193 .41035 .79167 .40653 .78738 .40034 Metetra
.683 .731 .887 r
.78738 .40034 .79167 .40653 .80141 .40251 .79718 .39667 Metetra
.74 .764 .872 r
.79718 .39667 .80141 .40251 .81111 .3977 .80686 .39122 Metetra
.725 .739 .862 r
.80686 .39122 .81111 .3977 .82085 .39302 .81658 .38612 Metetra
.667 .703 .874 r
.81658 .38612 .82085 .39302 .83069 .38916 .8265 .38284 Metetra
.668 .723 .891 r
.8265 .38284 .83069 .38916 .84057 .38538 .83646 .37957 Metetra
.664 .741 .908 r
.83646 .37957 .84057 .38538 .85055 .38224 .84645 .3764 Metetra
.664 .741 .908 r
.84645 .3764 .85055 .38224 .86056 .37908 .85649 .37323 Metetra
.664 .741 .908 r
.85649 .37323 .86056 .37908 .8706 .37592 .86656 .37005 Metetra
.664 .741 .908 r
.86656 .37005 .8706 .37592 .88068 .37274 .87666 .36685 Metetra
.664 .741 .908 r
.87666 .36685 .88068 .37274 .89079 .36955 .8868 .36364 Metetra
.664 .741 .908 r
.8868 .36364 .89079 .36955 .90094 .36636 .89697 .36042 Metetra
.664 .741 .908 r
.89697 .36042 .90094 .36636 .91112 .36315 .90718 .3572 Metetra
.664 .741 .908 r
.90718 .3572 .91112 .36315 .92134 .35993 .91743 .35396 Metetra
.664 .741 .908 r
.32956 .53336 .33481 .53824 .34315 .5356 .33793 .5307 Metetra
.664 .741 .908 r
.33793 .5307 .34315 .5356 .35152 .53295 .34632 .52804 Metetra
.664 .741 .908 r
.34632 .52804 .35152 .53295 .35992 .53029 .35473 .52537 Metetra
.664 .741 .908 r
.35473 .52537 .35992 .53029 .36835 .52763 .36317 .52269 Metetra
.664 .741 .908 r
.36317 .52269 .36835 .52763 .3768 .52496 .37164 .52 Metetra
.664 .741 .908 r
.37164 .52 .3768 .52496 .38528 .52227 .38014 .5173 Metetra
.664 .741 .908 r
.38014 .5173 .38528 .52227 .39379 .51958 .38866 .51459 Metetra
.664 .741 .908 r
.38866 .51459 .39379 .51958 .40232 .51688 .39721 .51188 Metetra
.664 .741 .908 r
.39721 .51188 .40232 .51688 .41088 .51429 .40579 .50916 Metetra
.664 .737 .904 r
.40579 .50916 .41088 .51429 .41946 .51171 .41439 .50642 Metetra
.583 .706 .927 r
.41439 .50642 .41946 .51171 .42802 .5109 .42298 .50531 Metetra
.569 .688 .921 r
.42298 .50531 .42802 .5109 .43661 .51043 .43159 .5045 Metetra
.632 .699 .894 r
.43159 .5045 .43661 .51043 .44528 .50824 .44027 .50249 Metetra
.644 .711 .896 r
.44027 .50249 .44528 .50824 .45399 .50562 .44898 .50018 Metetra
.673 .731 .894 r
.44898 .50018 .45399 .50562 .46273 .50269 .45774 .49716 Metetra
.681 .731 .888 r
.45774 .49716 .46273 .50269 .4715 .49966 .46654 .49392 Metetra
.63 .708 .902 r
.46654 .49392 .4715 .49966 .48029 .49771 .47534 .4919 Metetra
.61 .699 .907 r
.47534 .4919 .48029 .49771 .4891 .49613 .48416 .49031 Metetra
.657 .715 .891 r
.48416 .49031 .4891 .49613 .49796 .49302 .49304 .48765 Metetra
.675 .738 .898 r
.49304 .48765 .49796 .49302 .50685 .48928 .50194 .48454 Metetra
.617 .746 .938 r
.50194 .48454 .50685 .48928 .51576 .48763 .51087 .48264 Metetra
.587 .726 .939 r
.51087 .48264 .51576 .48763 .5247 .48696 .51983 .4813 Metetra
.656 .724 .898 r
.51983 .4813 .5247 .48696 .53368 .48351 .52883 .47862 Metetra
.687 .763 .91 r
.52883 .47862 .53368 .48351 .54267 .47852 .53785 .47519 Metetra
.571 .801 .986 r
.53785 .47519 .54267 .47852 .55171 .47657 .54691 .47349 Metetra
.462 .77 .997 r
.54691 .47349 .55171 .47657 .5608 .47655 .55602 .47288 Metetra
.624 .803 .968 r
.55602 .47288 .5608 .47655 .56991 .47425 .56515 .47051 Metetra
.692 .818 .943 r
.56515 .47051 .56991 .47425 .57902 .4703 .5743 .46687 Metetra
.698 .835 .949 r
.5743 .46687 .57902 .4703 .58815 .46574 .58346 .46305 Metetra
.696 .872 .964 r
.58346 .46305 .58815 .46574 .59729 .46069 .59265 .4591 Metetra
.625 .907 .984 r
.59265 .4591 .59729 .46069 .60647 .45674 .60188 .45568 Metetra
.542 .899 .973 r
.60188 .45568 .60647 .45674 .6157 .45382 .61115 .45275 Metetra
.487 .875 .969 r
.61115 .45275 .6157 .45382 .625 .45195 .62046 .45032 Metetra
.478 .851 .987 r
.62046 .45032 .625 .45195 .63437 .45118 .62983 .44842 Metetra
.565 .834 .996 r
.62983 .44842 .63437 .45118 .64377 .44993 .63923 .44638 Metetra
.603 .809 .979 r
.63923 .44638 .64377 .44993 .65319 .44807 .64866 .44417 Metetra
.68 .816 .948 r
.64866 .44417 .65319 .44807 .66257 .44454 .65807 .44068 Metetra
.752 .835 .915 r
.65807 .44068 .66257 .44454 .67188 .43871 .66743 .43542 Metetra
.707 .853 .952 r
.66743 .43542 .67188 .43871 .6813 .43482 .67687 .43125 Metetra
.615 .814 .977 r
.67687 .43125 .6813 .43482 .6909 .43401 .68642 .42882 Metetra
.669 .759 .917 r
.68642 .42882 .6909 .43401 .70046 .43165 .69596 .42564 Metetra
.714 .744 .875 r
.69596 .42564 .70046 .43165 .7099 .42645 .70546 .42109 Metetra
.699 .763 .901 r
.70546 .42109 .7099 .42645 .71942 .42226 .71501 .41711 Metetra
.65 .756 .927 r
.71501 .41711 .71942 .42226 .72909 .42018 .72467 .41436 Metetra
.669 .736 .901 r
.72467 .41436 .72909 .42018 .73877 .41746 .73434 .41115 Metetra
.704 .732 .873 r
.73434 .41115 .73877 .41746 .74837 .41318 .74396 .40684 Metetra
.69 .727 .879 r
.74396 .40684 .74837 .41318 .75802 .40927 .75364 .40297 Metetra
.645 .711 .896 r
.75364 .40297 .75802 .40927 .76779 .40647 .76344 .40034 Metetra
.653 .722 .899 r
.76344 .40034 .76779 .40647 .77758 .40357 .77326 .3975 Metetra
.68 .735 .892 r
.77326 .3975 .77758 .40357 .78738 .40034 .78306 .39391 Metetra
.689 .727 .879 r
.78306 .39391 .78738 .40034 .79718 .39667 .79286 .39002 Metetra
.724 .733 .858 r
.79286 .39002 .79718 .39667 .80686 .39122 .80259 .38488 Metetra
.718 .742 .87 r
.80259 .38488 .80686 .39122 .81658 .38612 .81237 .38005 Metetra
.664 .732 .9 r
.81237 .38005 .81658 .38612 .8265 .38284 .82232 .37689 Metetra
.664 .737 .904 r
.82232 .37689 .8265 .38284 .83646 .37957 .83231 .37372 Metetra
.664 .741 .908 r
.83231 .37372 .83646 .37957 .84645 .3764 .84234 .37054 Metetra
.664 .741 .908 r
.84234 .37054 .84645 .3764 .85649 .37323 .8524 .36734 Metetra
.664 .741 .908 r
.8524 .36734 .85649 .37323 .86656 .37005 .86249 .36414 Metetra
.664 .741 .908 r
.86249 .36414 .86656 .37005 .87666 .36685 .87262 .36092 Metetra
.664 .741 .908 r
.87262 .36092 .87666 .36685 .8868 .36364 .88278 .35769 Metetra
.664 .741 .908 r
.88278 .35769 .8868 .36364 .89697 .36042 .89298 .35445 Metetra
.664 .741 .908 r
.89298 .35445 .89697 .36042 .90718 .3572 .90322 .3512 Metetra
.664 .741 .908 r
.90322 .3512 .90718 .3572 .91743 .35396 .91349 .34794 Metetra
.664 .741 .908 r
.32429 .52845 .32956 .53336 .33793 .5307 .33267 .52578 Metetra
.664 .741 .908 r
.33267 .52578 .33793 .5307 .34632 .52804 .34108 .5231 Metetra
.664 .741 .908 r
.34108 .5231 .34632 .52804 .35473 .52537 .34951 .52041 Metetra
.664 .741 .908 r
.34951 .52041 .35473 .52537 .36317 .52269 .35797 .51772 Metetra
.664 .741 .908 r
.35797 .51772 .36317 .52269 .37164 .52 .36645 .51501 Metetra
.664 .741 .908 r
.36645 .51501 .37164 .52 .38014 .5173 .37496 .5123 Metetra
.664 .741 .908 r
.37496 .5123 .38014 .5173 .38866 .51459 .3835 .50957 Metetra
.664 .741 .908 r
.3835 .50957 .38866 .51459 .39721 .51188 .39207 .50684 Metetra
.664 .741 .908 r
.39207 .50684 .39721 .51188 .40579 .50916 .40067 .5041 Metetra
.664 .741 .908 r
.40067 .5041 .40579 .50916 .41439 .50642 .40929 .50136 Metetra
.608 .725 .928 r
.40929 .50136 .41439 .50642 .42298 .50531 .4179 .49973 Metetra
.601 .702 .915 r
.4179 .49973 .42298 .50531 .43159 .5045 .42654 .49832 Metetra
.616 .686 .893 r
.42654 .49832 .43159 .5045 .44027 .50249 .43523 .49665 Metetra
.618 .699 .903 r
.43523 .49665 .44027 .50249 .44898 .50018 .44394 .49492 Metetra
.686 .743 .894 r
.44394 .49492 .44898 .50018 .45774 .49716 .45273 .49156 Metetra
.701 .735 .877 r
.45273 .49156 .45774 .49716 .46654 .49392 .46155 .4877 Metetra
.638 .695 .886 r
.46155 .4877 .46654 .49392 .47534 .4919 .47037 .48552 Metetra
.613 .68 .89 r
.47037 .48552 .47534 .4919 .48416 .49031 .47921 .48391 Metetra
.623 .684 .887 r
.47921 .48391 .48416 .49031 .49304 .48765 .48809 .48207 Metetra
.624 .715 .912 r
.48809 .48207 .49304 .48765 .50194 .48454 .497 .48014 Metetra
.636 .769 .943 r
.497 .48014 .50194 .48454 .51087 .48264 .50595 .4778 Metetra
.648 .754 .927 r
.50595 .4778 .51087 .48264 .51983 .4813 .51493 .47526 Metetra
.608 .693 .903 r
.51493 .47526 .51983 .4813 .52883 .47862 .52395 .47367 Metetra
.567 .722 .946 r
.52395 .47367 .52883 .47862 .53785 .47519 .533 .47262 Metetra
.553 .834 .998 r
.533 .47262 .53785 .47519 .54691 .47349 .54208 .47073 Metetra
.603 .843 .99 r
.54208 .47073 .54691 .47349 .55602 .47288 .5512 .46831 Metetra
.656 .772 .934 r
.5512 .46831 .55602 .47288 .56515 .47051 .56035 .46552 Metetra
.669 .758 .917 r
.56035 .46552 .56515 .47051 .5743 .46687 .56952 .46246 Metetra
.643 .776 .945 r
.56952 .46246 .5743 .46687 .58346 .46305 .57874 .45989 Metetra
.593 .822 .987 r
.57874 .45989 .58346 .46305 .59265 .4591 .58799 .45773 Metetra
.53 .883 .983 r
.58799 .45773 .59265 .4591 .60188 .45568 .59727 .45516 Metetra
.488 .891 .94 r
.59727 .45516 .60188 .45568 .61115 .45275 .60657 .45222 Metetra
.529 .909 .945 r
.60657 .45222 .61115 .45275 .62046 .45032 .6159 .4489 Metetra
.632 .919 .978 r
.6159 .4489 .62046 .45032 .62983 .44842 .62524 .44517 Metetra
.664 .843 .968 r
.62524 .44517 .62983 .44842 .63923 .44638 .63462 .44185 Metetra
.652 .779 .941 r
.63462 .44185 .63923 .44638 .64866 .44417 .64405 .43903 Metetra
.667 .758 .918 r
.64405 .43903 .64866 .44417 .65807 .44068 .6535 .43593 Metetra
.681 .78 .925 r
.6535 .43593 .65807 .44068 .66743 .43542 .66297 .43245 Metetra
.694 .868 .964 r
.66297 .43245 .66743 .43542 .67687 .43125 .67244 .42844 Metetra
.732 .884 .95 r
.67244 .42844 .67687 .43125 .68642 .42882 .6819 .42358 Metetra
.712 .771 .899 r
.6819 .42358 .68642 .42882 .69596 .42564 .69141 .41924 Metetra
.673 .717 .881 r
.69141 .41924 .69596 .42564 .70546 .42109 .701 .41588 Metetra
.683 .765 .913 r
.701 .41588 .70546 .42109 .71501 .41711 .7106 .41231 Metetra
.7 .788 .919 r
.7106 .41231 .71501 .41711 .72467 .41436 .72021 .40833 Metetra
.699 .741 .884 r
.72021 .40833 .72467 .41436 .73434 .41115 .72984 .40423 Metetra
.7 .713 .859 r
.72984 .40423 .73434 .41115 .74396 .40684 .73949 .39991 Metetra
.682 .706 .866 r
.73949 .39991 .74396 .40684 .75364 .40297 .7492 .39617 Metetra
.622 .686 .889 r
.7492 .39617 .75364 .40297 .76344 .40034 .75906 .39413 Metetra
.64 .715 .902 r
.75906 .39413 .76344 .40034 .77326 .3975 .76893 .3916 Metetra
.702 .751 .89 r
.76893 .3916 .77326 .3975 .78306 .39391 .77871 .38739 Metetra
.7 .729 .873 r
.77871 .38739 .78306 .39391 .79286 .39002 .7885 .3831 Metetra
.705 .719 .86 r
.7885 .3831 .79286 .39002 .80259 .38488 .7983 .37855 Metetra
.703 .738 .878 r
.7983 .37855 .80259 .38488 .81237 .38005 .80815 .37421 Metetra
.664 .741 .908 r
.80815 .37421 .81237 .38005 .82232 .37689 .81813 .37103 Metetra
.664 .741 .908 r
.81813 .37103 .82232 .37689 .83231 .37372 .82814 .36783 Metetra
.664 .741 .908 r
.82814 .36783 .83231 .37372 .84234 .37054 .83819 .36463 Metetra
.664 .741 .908 r
.83819 .36463 .84234 .37054 .8524 .36734 .84828 .36142 Metetra
.664 .741 .908 r
.84828 .36142 .8524 .36734 .86249 .36414 .8584 .35819 Metetra
.664 .741 .908 r
.8584 .35819 .86249 .36414 .87262 .36092 .86855 .35495 Metetra
.664 .741 .908 r
.86855 .35495 .87262 .36092 .88278 .35769 .87874 .35171 Metetra
.664 .741 .908 r
.87874 .35171 .88278 .35769 .89298 .35445 .88897 .34845 Metetra
.664 .741 .908 r
.88897 .34845 .89298 .35445 .90322 .3512 .89923 .34517 Metetra
.664 .741 .908 r
.89923 .34517 .90322 .3512 .91349 .34794 .90953 .34189 Metetra
.664 .741 .908 r
.31899 .52351 .32429 .52845 .33267 .52578 .32738 .52083 Metetra
.664 .741 .908 r
.32738 .52083 .33267 .52578 .34108 .5231 .3358 .51813 Metetra
.664 .741 .908 r
.3358 .51813 .34108 .5231 .34951 .52041 .34425 .51543 Metetra
.664 .741 .908 r
.34425 .51543 .34951 .52041 .35797 .51772 .35273 .51272 Metetra
.664 .741 .908 r
.35273 .51272 .35797 .51772 .36645 .51501 .36123 .50999 Metetra
.664 .741 .908 r
.36123 .50999 .36645 .51501 .37496 .5123 .36976 .50726 Metetra
.664 .741 .908 r
.36976 .50726 .37496 .5123 .3835 .50957 .37832 .50453 Metetra
.664 .741 .908 r
.37832 .50453 .3835 .50957 .39207 .50684 .3869 .50178 Metetra
.664 .741 .908 r
.3869 .50178 .39207 .50684 .40067 .5041 .39551 .49902 Metetra
.664 .741 .908 r
.39551 .49902 .40067 .5041 .40929 .50136 .40415 .49626 Metetra
.634 .733 .919 r
.40415 .49626 .40929 .50136 .4179 .49973 .4128 .49412 Metetra
.63 .712 .906 r
.4128 .49412 .4179 .49973 .42654 .49832 .42147 .4921 Metetra
.616 .686 .893 r
.42147 .4921 .42654 .49832 .43523 .49665 .43017 .49043 Metetra
.612 .685 .894 r
.43017 .49043 .43523 .49665 .44394 .49492 .43889 .48884 Metetra
.661 .707 .881 r
.43889 .48884 .44394 .49492 .45273 .49156 .44768 .48605 Metetra
.676 .733 .893 r
.44768 .48605 .45273 .49156 .46155 .4877 .45651 .48291 Metetra
.64 .751 .929 r
.45651 .48291 .46155 .4877 .47037 .48552 .46535 .48057 Metetra
.626 .741 .929 r
.46535 .48057 .47037 .48552 .47921 .48391 .47421 .4785 Metetra
.614 .719 .92 r
.47421 .4785 .47921 .48391 .48809 .48207 .48311 .47674 Metetra
.606 .72 .925 r
.48311 .47674 .48809 .48207 .497 .48014 .49203 .4751 Metetra
.645 .745 .922 r
.49203 .4751 .497 .48014 .50595 .4778 .501 .47263 Metetra
.663 .746 .912 r
.501 .47263 .50595 .4778 .51493 .47526 .51001 .46976 Metetra
.604 .714 .922 r
.51001 .46976 .51493 .47526 .52395 .47367 .51904 .46817 Metetra
.565 .699 .931 r
.51904 .46817 .52395 .47367 .533 .47262 .5281 .46727 Metetra
.615 .725 .924 r
.5281 .46727 .533 .47262 .54208 .47073 .53721 .46542 Metetra
.643 .737 .917 r
.53721 .46542 .54208 .47073 .5512 .46831 .54635 .46297 Metetra
.643 .737 .917 r
.54635 .46297 .5512 .46831 .56035 .46552 .55552 .4605 Metetra
.642 .75 .927 r
.55552 .4605 .56035 .46552 .56952 .46246 .56472 .45802 Metetra
.585 .757 .96 r
.56472 .45802 .56952 .46246 .57874 .45989 .57397 .45646 Metetra
.494 .77 .993 r
.57397 .45646 .57874 .45989 .58799 .45773 .58327 .45564 Metetra
.516 .847 .997 r
.58327 .45564 .58799 .45773 .59727 .45516 .59259 .45373 Metetra
.569 .896 .984 r
.59259 .45373 .59727 .45516 .60657 .45222 .60193 .45077 Metetra
.654 .924 .975 r
.60193 .45077 .60657 .45222 .6159 .4489 .61127 .44677 Metetra
.74 .912 .952 r
.61127 .44677 .6159 .4489 .62524 .44517 .6206 .44166 Metetra
.717 .843 .942 r
.6206 .44166 .62524 .44517 .63462 .44185 .62998 .43729 Metetra
.68 .788 .931 r
.62998 .43729 .63462 .44185 .64405 .43903 .63941 .43384 Metetra
.681 .762 .913 r
.63941 .43384 .64405 .43903 .6535 .43593 .64887 .43038 Metetra
.68 .749 .903 r
.64887 .43038 .6535 .43593 .66297 .43245 .65837 .42691 Metetra
.702 .756 .894 r
.65837 .42691 .66297 .43245 .67244 .42844 .66786 .42282 Metetra
.732 .763 .878 r
.66786 .42282 .67244 .42844 .6819 .42358 .67733 .41776 Metetra
.709 .75 .884 r
.67733 .41776 .6819 .42358 .69141 .41924 .68687 .4134 Metetra
.663 .734 .903 r
.68687 .4134 .69141 .41924 .701 .41588 .69649 .41033 Metetra
.679 .752 .906 r
.69649 .41033 .701 .41588 .7106 .41231 .70613 .40686 Metetra
.709 .766 .897 r
.70613 .40686 .7106 .41231 .72021 .40833 .71574 .40253 Metetra
.703 .752 .89 r
.71574 .40253 .72021 .40833 .72984 .40423 .72539 .39833 Metetra
.692 .745 .892 r
.72539 .39833 .72984 .40423 .73949 .39991 .73509 .39443 Metetra
.683 .759 .909 r
.73509 .39443 .73949 .39991 .7492 .39617 .74483 .39082 Metetra
.649 .752 .925 r
.74483 .39082 .7492 .39617 .75906 .39413 .75467 .38802 Metetra
.664 .729 .898 r
.75467 .38802 .75906 .39413 .76893 .3916 .76451 .38485 Metetra
.702 .723 .866 r
.76451 .38485 .76893 .3916 .77871 .38739 .7743 .38046 Metetra
.698 .717 .863 r
.7743 .38046 .77871 .38739 .7885 .3831 .78412 .37614 Metetra
.687 .712 .867 r
.78412 .37614 .7885 .3831 .7983 .37855 .79399 .37218 Metetra
.686 .732 .885 r
.79399 .37218 .7983 .37855 .80815 .37421 .8039 .36833 Metetra
.664 .741 .908 r
.8039 .36833 .80815 .37421 .81813 .37103 .81391 .36512 Metetra
.664 .741 .908 r
.81391 .36512 .81813 .37103 .82814 .36783 .82395 .36191 Metetra
.664 .741 .908 r
.82395 .36191 .82814 .36783 .83819 .36463 .83402 .35869 Metetra
.664 .741 .908 r
.83402 .35869 .83819 .36463 .84828 .36142 .84413 .35545 Metetra
.664 .741 .908 r
.84413 .35545 .84828 .36142 .8584 .35819 .85428 .35221 Metetra
.664 .741 .908 r
.85428 .35221 .8584 .35819 .86855 .35495 .86446 .34895 Metetra
.664 .741 .908 r
.86446 .34895 .86855 .35495 .87874 .35171 .87467 .34568 Metetra
.664 .741 .908 r
.87467 .34568 .87874 .35171 .88897 .34845 .88492 .3424 Metetra
.664 .741 .908 r
.88492 .3424 .88897 .34845 .89923 .34517 .89521 .33911 Metetra
.664 .741 .908 r
.89521 .33911 .89923 .34517 .90953 .34189 .90553 .3358 Metetra
.664 .741 .908 r
.31365 .51855 .31899 .52351 .32738 .52083 .32207 .51584 Metetra
.664 .741 .908 r
.32207 .51584 .32738 .52083 .3358 .51813 .3305 .51313 Metetra
.664 .741 .908 r
.3305 .51313 .3358 .51813 .34425 .51543 .33897 .51041 Metetra
.664 .741 .908 r
.33897 .51041 .34425 .51543 .35273 .51272 .34746 .50769 Metetra
.664 .741 .908 r
.34746 .50769 .35273 .51272 .36123 .50999 .35598 .50495 Metetra
.664 .741 .908 r
.35598 .50495 .36123 .50999 .36976 .50726 .36453 .5022 Metetra
.664 .741 .908 r
.36453 .5022 .36976 .50726 .37832 .50453 .3731 .49945 Metetra
.664 .741 .908 r
.3731 .49945 .37832 .50453 .3869 .50178 .3817 .49668 Metetra
.664 .741 .908 r
.3817 .49668 .3869 .50178 .39551 .49902 .39033 .49391 Metetra
.664 .741 .908 r
.39033 .49391 .39551 .49902 .40415 .49626 .39899 .49113 Metetra
.657 .74 .91 r
.39899 .49113 .40415 .49626 .4128 .49412 .40767 .48848 Metetra
.656 .72 .896 r
.40767 .48848 .4128 .49412 .42147 .4921 .41637 .48586 Metetra
.621 .688 .891 r
.41637 .48586 .42147 .4921 .43017 .49043 .42509 .48405 Metetra
.613 .681 .89 r
.42509 .48405 .43017 .49043 .43889 .48884 .43383 .48244 Metetra
.624 .685 .887 r
.43383 .48244 .43889 .48884 .44768 .48605 .44261 .48056 Metetra
.625 .718 .914 r
.44261 .48056 .44768 .48605 .45651 .48291 .45142 .47859 Metetra
.643 .774 .943 r
.45142 .47859 .45651 .48291 .46535 .48057 .46028 .4761 Metetra
.653 .771 .935 r
.46028 .4761 .46535 .48057 .47421 .4785 .46918 .47342 Metetra
.62 .735 .929 r
.46918 .47342 .47421 .4785 .48311 .47674 .47809 .47147 Metetra
.605 .723 .928 r
.47809 .47147 .48311 .47674 .49203 .4751 .48704 .46981 Metetra
.646 .737 .915 r
.48704 .46981 .49203 .4751 .501 .47263 .49602 .46733 Metetra
.663 .742 .909 r
.49602 .46733 .501 .47263 .51001 .46976 .50505 .46444 Metetra
.622 .729 .923 r
.50505 .46444 .51001 .46976 .51904 .46817 .5141 .46244 Metetra
.6 .705 .918 r
.5141 .46244 .51904 .46817 .5281 .46727 .52318 .46093 Metetra
.614 .689 .896 r
.52318 .46093 .5281 .46727 .53721 .46542 .5323 .4592 Metetra
.619 .696 .899 r
.5323 .4592 .53721 .46542 .54635 .46297 .54146 .45733 Metetra
.617 .717 .917 r
.54146 .45733 .54635 .46297 .55552 .4605 .55065 .45545 Metetra
.612 .74 .936 r
.55065 .45545 .55552 .4605 .56472 .45802 .55988 .45356 Metetra
.521 .731 .97 r
.55988 .45356 .56472 .45802 .57397 .45646 .56917 .45292 Metetra
.38 .712 .987 r
.56917 .45292 .57397 .45646 .58327 .45564 .57851 .4533 Metetra
.474 .818 .998 r
.57851 .4533 .58327 .45564 .59259 .45373 .58787 .45196 Metetra
.589 .891 .99 r
.58787 .45196 .59259 .45373 .60193 .45077 .59724 .44899 Metetra
.705 .922 .966 r
.59724 .44899 .60193 .45077 .61127 .44677 .6066 .44438 Metetra
.791 .904 .92 r
.6066 .44438 .61127 .44677 .6206 .44166 .61593 .43803 Metetra
.754 .846 .92 r
.61593 .43803 .6206 .44166 .62998 .43729 .62531 .43271 Metetra
.705 .794 .92 r
.62531 .43271 .62998 .43729 .63941 .43384 .63474 .42863 Metetra
.704 .769 .903 r
.63474 .42863 .63941 .43384 .64887 .43038 .64421 .42454 Metetra
.701 .746 .886 r
.64421 .42454 .64887 .43038 .65837 .42691 .6537 .42044 Metetra
.701 .725 .869 r
.6537 .42044 .65837 .42691 .66786 .42282 .66321 .41619 Metetra
.707 .723 .862 r
.66321 .41619 .66786 .42282 .67733 .41776 .67273 .41172 Metetra
.695 .739 .885 r
.67273 .41172 .67733 .41776 .68687 .4134 .6823 .40773 Metetra
.663 .742 .909 r
.6823 .40773 .68687 .4134 .69649 .41033 .69195 .40464 Metetra
.678 .747 .903 r
.69195 .40464 .69649 .41033 .70613 .40686 .70161 .40115 Metetra
.708 .757 .891 r
.70161 .40115 .70613 .40686 .71574 .40253 .71125 .3968 Metetra
.698 .754 .895 r
.71125 .3968 .71574 .40253 .72539 .39833 .72093 .39275 Metetra
.67 .751 .911 r
.72093 .39275 .72539 .39833 .73509 .39443 .7307 .38945 Metetra
.677 .778 .927 r
.7307 .38945 .73509 .39443 .74483 .39082 .74048 .38595 Metetra
.698 .791 .922 r
.74048 .38595 .74483 .39082 .75467 .38802 .75025 .38191 Metetra
.697 .743 .887 r
.75025 .38191 .75467 .38802 .76451 .38485 .76005 .37778 Metetra
.7 .714 .859 r
.76005 .37778 .76451 .38485 .7743 .38046 .76986 .37336 Metetra
.694 .711 .862 r
.76986 .37336 .7743 .38046 .78412 .37614 .7797 .36914 Metetra
.668 .704 .874 r
.7797 .36914 .78412 .37614 .79399 .37218 .78965 .36577 Metetra
.669 .725 .891 r
.78965 .36577 .79399 .37218 .8039 .36833 .79963 .36241 Metetra
.664 .741 .908 r
.79963 .36241 .8039 .36833 .81391 .36512 .80966 .35918 Metetra
.664 .741 .908 r
.80966 .35918 .81391 .36512 .82395 .36191 .81973 .35595 Metetra
.664 .741 .908 r
.81973 .35595 .82395 .36191 .83402 .35869 .82982 .35271 Metetra
.664 .741 .908 r
.82982 .35271 .83402 .35869 .84413 .35545 .83996 .34945 Metetra
.664 .741 .908 r
.83996 .34945 .84413 .35545 .85428 .35221 .85013 .34618 Metetra
.664 .741 .908 r
.85013 .34618 .85428 .35221 .86446 .34895 .86034 .3429 Metetra
.664 .741 .908 r
.86034 .3429 .86446 .34895 .87467 .34568 .87058 .33961 Metetra
.664 .741 .908 r
.87058 .33961 .87467 .34568 .88492 .3424 .88085 .33631 Metetra
.664 .741 .908 r
.88085 .33631 .88492 .3424 .89521 .33911 .89117 .333 Metetra
.664 .741 .908 r
.89117 .333 .89521 .33911 .90553 .3358 .90152 .32967 Metetra
.664 .741 .908 r
.30829 .51355 .31365 .51855 .32207 .51584 .31672 .51083 Metetra
.664 .741 .908 r
.31672 .51083 .32207 .51584 .3305 .51313 .32517 .50811 Metetra
.664 .741 .908 r
.32517 .50811 .3305 .51313 .33897 .51041 .33365 .50537 Metetra
.664 .741 .908 r
.33365 .50537 .33897 .51041 .34746 .50769 .34216 .50263 Metetra
.664 .741 .908 r
.34216 .50263 .34746 .50769 .35598 .50495 .3507 .49987 Metetra
.664 .741 .908 r
.3507 .49987 .35598 .50495 .36453 .5022 .35926 .49711 Metetra
.664 .741 .908 r
.35926 .49711 .36453 .5022 .3731 .49945 .36785 .49434 Metetra
.664 .741 .908 r
.36785 .49434 .3731 .49945 .3817 .49668 .37647 .49156 Metetra
.664 .741 .908 r
.37647 .49156 .3817 .49668 .39033 .49391 .38511 .48877 Metetra
.664 .741 .908 r
.38511 .48877 .39033 .49391 .39899 .49113 .39379 .48597 Metetra
.664 .741 .908 r
.39379 .48597 .39899 .49113 .40767 .48848 .40249 .48316 Metetra
.664 .736 .904 r
.40249 .48316 .40767 .48848 .41637 .48586 .41122 .48035 Metetra
.636 .721 .909 r
.41122 .48035 .41637 .48586 .42509 .48405 .41996 .47816 Metetra
.63 .705 .9 r
.41996 .47816 .42509 .48405 .43383 .48244 .42873 .47611 Metetra
.601 .68 .896 r
.42873 .47611 .43383 .48244 .44261 .48056 .43751 .4747 Metetra
.588 .693 .914 r
.43751 .4747 .44261 .48056 .45142 .47859 .44632 .47349 Metetra
.629 .737 .926 r
.44632 .47349 .45142 .47859 .46028 .4761 .45519 .47136 Metetra
.642 .758 .933 r
.45519 .47136 .46028 .4761 .46918 .47342 .4641 .46892 Metetra
.642 .769 .94 r
.4641 .46892 .46918 .47342 .47809 .47147 .47305 .46642 Metetra
.646 .747 .923 r
.47305 .46642 .47809 .47147 .48704 .46981 .48202 .4639 Metetra
.634 .71 .902 r
.48202 .4639 .48704 .46981 .49602 .46733 .49102 .4617 Metetra
.626 .719 .913 r
.49102 .4617 .49602 .46733 .50505 .46444 .50005 .45965 Metetra
.622 .752 .94 r
.50005 .45965 .50505 .46444 .5141 .46244 .50912 .45755 Metetra
.624 .749 .937 r
.50912 .45755 .5141 .46244 .52318 .46093 .51823 .45542 Metetra
.588 .711 .929 r
.51823 .45542 .52318 .46093 .5323 .4592 .52737 .45408 Metetra
.553 .714 .947 r
.52737 .45408 .5323 .4592 .54146 .45733 .53655 .45322 Metetra
.579 .771 .97 r
.53655 .45322 .54146 .45733 .55065 .45545 .54576 .45161 Metetra
.608 .795 .971 r
.54576 .45161 .55065 .45545 .55988 .45356 .55501 .44945 Metetra
.46 .724 .982 r
.55501 .44945 .55988 .45356 .56917 .45292 .56433 .44935 Metetra
.24 .634 .959 r
.56433 .44935 .56917 .45292 .57851 .4533 .57371 .45094 Metetra
.409 .787 .992 r
.57371 .45094 .57851 .4533 .58787 .45196 .58311 .45018 Metetra
.589 .891 .99 r
.58311 .45018 .58787 .45196 .59724 .44899 .59251 .44719 Metetra
.737 .927 .954 r
.59251 .44719 .59724 .44899 .6066 .44438 .60189 .44197 Metetra
.828 .902 .892 r
.60189 .44197 .6066 .44438 .61593 .43803 .61122 .43437 Metetra
.772 .848 .908 r
.61122 .43437 .61593 .43803 .62531 .43271 .62061 .42847 Metetra
.695 .809 .936 r
.62061 .42847 .62531 .43271 .63474 .42863 .63009 .42463 Metetra
.717 .826 .932 r
.63009 .42463 .63474 .42863 .64421 .42454 .63957 .42023 Metetra
.744 .819 .91 r
.63957 .42023 .64421 .42454 .6537 .42044 .64904 .41507 Metetra
.721 .771 .892 r
.64904 .41507 .6537 .42044 .66321 .41619 .65856 .4104 Metetra
.693 .748 .894 r
.65856 .4104 .66321 .41619 .67273 .41172 .66814 .40651 Metetra
.695 .772 .91 r
.66814 .40651 .67273 .41172 .6823 .40773 .67774 .40259 Metetra
.697 .776 .912 r
.67774 .40259 .6823 .40773 .69195 .40464 .68737 .39862 Metetra
.689 .74 .89 r
.68737 .39862 .69195 .40464 .70161 .40115 .69703 .3948 Metetra
.676 .725 .887 r
.69703 .3948 .70161 .40115 .71125 .3968 .70674 .3913 Metetra
.679 .758 .911 r
.70674 .3913 .71125 .3968 .72093 .39275 .71649 .38777 Metetra
.68 .78 .926 r
.71649 .38777 .72093 .39275 .7307 .38945 .72626 .38419 Metetra
.693 .774 .914 r
.72626 .38419 .7307 .38945 .74048 .38595 .73604 .38027 Metetra
.723 .768 .889 r
.73604 .38027 .74048 .38595 .75025 .38191 .74578 .37543 Metetra
.711 .737 .871 r
.74578 .37543 .75025 .38191 .76005 .37778 .75557 .37076 Metetra
.688 .712 .867 r
.75557 .37076 .76005 .37778 .76986 .37336 .76543 .36676 Metetra
.685 .725 .88 r
.76543 .36676 .76986 .37336 .7797 .36914 .77533 .3629 Metetra
.663 .729 .898 r
.77533 .3629 .7797 .36914 .78965 .36577 .78531 .35968 Metetra
.664 .736 .904 r
.78531 .35968 .78965 .36577 .79963 .36241 .79533 .35645 Metetra
.664 .741 .908 r
.79533 .35645 .79963 .36241 .80966 .35918 .80539 .35321 Metetra
.664 .741 .908 r
.80539 .35321 .80966 .35918 .81973 .35595 .81548 .34995 Metetra
.664 .741 .908 r
.81548 .34995 .81973 .35595 .82982 .35271 .8256 .34669 Metetra
.664 .741 .908 r
.8256 .34669 .82982 .35271 .83996 .34945 .83576 .34341 Metetra
.664 .741 .908 r
.83576 .34341 .83996 .34945 .85013 .34618 .84596 .34012 Metetra
.664 .741 .908 r
.84596 .34012 .85013 .34618 .86034 .3429 .85619 .33682 Metetra
.664 .741 .908 r
.85619 .33682 .86034 .3429 .87058 .33961 .86646 .33351 Metetra
.664 .741 .908 r
.86646 .33351 .87058 .33961 .88085 .33631 .87676 .33018 Metetra
.664 .741 .908 r
.87676 .33018 .88085 .33631 .89117 .333 .8871 .32685 Metetra
.664 .741 .908 r
.8871 .32685 .89117 .333 .90152 .32967 .89748 .3235 Metetra
.664 .741 .908 r
.30289 .50853 .30829 .51355 .31672 .51083 .31134 .50579 Metetra
.664 .741 .908 r
.31134 .50579 .31672 .51083 .32517 .50811 .31981 .50305 Metetra
.664 .741 .908 r
.31981 .50305 .32517 .50811 .33365 .50537 .3283 .5003 Metetra
.664 .741 .908 r
.3283 .5003 .33365 .50537 .34216 .50263 .33683 .49754 Metetra
.664 .741 .908 r
.33683 .49754 .34216 .50263 .3507 .49987 .34538 .49477 Metetra
.664 .741 .908 r
.34538 .49477 .3507 .49987 .35926 .49711 .35396 .49199 Metetra
.664 .741 .908 r
.35396 .49199 .35926 .49711 .36785 .49434 .36257 .4892 Metetra
.664 .741 .908 r
.36257 .4892 .36785 .49434 .37647 .49156 .37121 .4864 Metetra
.664 .741 .908 r
.37121 .4864 .37647 .49156 .38511 .48877 .37987 .4836 Metetra
.664 .741 .908 r
.37987 .4836 .38511 .48877 .39379 .48597 .38856 .48078 Metetra
.664 .741 .908 r
.38856 .48078 .39379 .48597 .40249 .48316 .39728 .47796 Metetra
.664 .741 .908 r
.39728 .47796 .40249 .48316 .41122 .48035 .40603 .47513 Metetra
.657 .739 .911 r
.40603 .47513 .41122 .48035 .41996 .47816 .4148 .47244 Metetra
.655 .721 .897 r
.4148 .47244 .41996 .47816 .42873 .47611 .4236 .46978 Metetra
.585 .675 .902 r
.4236 .46978 .42873 .47611 .43751 .4747 .43239 .46868 Metetra
.557 .675 .917 r
.43239 .46868 .43751 .4747 .44632 .47349 .4412 .46805 Metetra
.6 .715 .925 r
.4412 .46805 .44632 .47349 .45519 .47136 .45007 .4665 Metetra
.611 .744 .94 r
.45007 .4665 .45519 .47136 .4641 .46892 .45899 .46464 Metetra
.674 .788 .935 r
.45899 .46464 .4641 .46892 .47305 .46642 .46796 .46146 Metetra
.697 .765 .905 r
.46796 .46146 .47305 .46642 .48202 .4639 .47697 .45772 Metetra
.616 .695 .9 r
.47697 .45772 .48202 .4639 .49102 .4617 .48599 .45593 Metetra
.565 .691 .925 r
.48599 .45593 .49102 .4617 .50005 .45965 .49503 .45506 Metetra
.617 .761 .948 r
.49503 .45506 .50005 .45965 .50912 .45755 .50412 .45298 Metetra
.652 .773 .938 r
.50412 .45298 .50912 .45755 .51823 .45542 .51324 .45024 Metetra
.553 .712 .946 r
.51324 .45024 .51823 .45542 .52737 .45408 .5224 .44938 Metetra
.448 .689 .968 r
.5224 .44938 .52737 .45408 .53655 .45322 .5316 .44972 Metetra
.548 .791 .989 r
.5316 .44972 .53655 .45322 .54576 .45161 .54084 .44825 Metetra
.635 .828 .975 r
.54084 .44825 .54576 .45161 .55501 .44945 .55011 .44547 Metetra
.415 .71 .984 r
.55011 .44547 .55501 .44945 .56433 .44935 .55945 .44575 Metetra
.083 .533 .905 r
.55945 .44575 .56433 .44935 .57371 .45094 .56887 .44856 Metetra
.339 .75 .98 r
.56887 .44856 .57371 .45094 .58311 .45018 .57831 .44838 Metetra
.589 .891 .99 r
.57831 .44838 .58311 .45018 .59251 .44719 .58774 .44538 Metetra
.765 .929 .94 r
.58774 .44538 .59251 .44719 .60189 .44197 .59714 .43954 Metetra
.855 .897 .864 r
.59714 .43954 .60189 .44197 .61122 .43437 .60648 .43069 Metetra
.784 .849 .9 r
.60648 .43069 .61122 .43437 .62061 .42847 .61589 .42437 Metetra
.665 .808 .951 r
.61589 .42437 .62061 .42847 .63009 .42463 .62541 .42112 Metetra
.722 .85 .942 r
.62541 .42112 .63009 .42463 .63957 .42023 .63492 .41655 Metetra
.786 .852 .9 r
.63492 .41655 .63957 .42023 .64904 .41507 .64438 .41014 Metetra
.741 .794 .895 r
.64438 .41014 .64904 .41507 .65856 .4104 .6539 .40494 Metetra
.671 .754 .913 r
.6539 .40494 .65856 .4104 .66814 .40651 .66353 .40164 Metetra
.698 .787 .92 r
.66353 .40164 .66814 .40651 .67774 .40259 .67315 .39766 Metetra
.74 .797 .898 r
.67315 .39766 .67774 .40259 .68737 .39862 .68275 .39245 Metetra
.702 .741 .881 r
.68275 .39245 .68737 .39862 .69703 .3948 .69241 .38817 Metetra
.63 .699 .894 r
.69241 .38817 .69703 .3948 .70674 .3913 .70221 .38587 Metetra
.65 .752 .924 r
.70221 .38587 .70674 .3913 .71649 .38777 .71202 .38301 Metetra
.704 .799 .923 r
.71202 .38301 .71649 .38777 .72626 .38419 .72178 .37879 Metetra
.714 .777 .901 r
.72178 .37879 .72626 .38419 .73604 .38027 .73155 .37425 Metetra
.738 .762 .871 r
.73155 .37425 .73604 .38027 .74578 .37543 .74128 .36877 Metetra
.72 .735 .863 r
.74128 .36877 .74578 .37543 .75557 .37076 .75106 .36375 Metetra
.668 .705 .875 r
.75106 .36375 .75557 .37076 .76543 .36676 .76099 .36034 Metetra
.669 .726 .892 r
.76099 .36034 .76543 .36676 .77533 .3629 .77095 .35695 Metetra
.664 .741 .908 r
.77095 .35695 .77533 .3629 .78531 .35968 .78096 .35371 Metetra
.664 .741 .908 r
.78096 .35371 .78531 .35968 .79533 .35645 .79101 .35045 Metetra
.664 .741 .908 r
.79101 .35045 .79533 .35645 .80539 .35321 .80108 .34719 Metetra
.664 .741 .908 r
.80108 .34719 .80539 .35321 .81548 .34995 .8112 .34391 Metetra
.664 .741 .908 r
.8112 .34391 .81548 .34995 .8256 .34669 .82135 .34063 Metetra
.664 .741 .908 r
.82135 .34063 .8256 .34669 .83576 .34341 .83153 .33733 Metetra
.664 .741 .908 r
.83153 .33733 .83576 .34341 .84596 .34012 .84176 .33402 Metetra
.664 .741 .908 r
.84176 .33402 .84596 .34012 .85619 .33682 .85201 .3307 Metetra
.664 .741 .908 r
.85201 .3307 .85619 .33682 .86646 .33351 .86231 .32736 Metetra
.664 .741 .908 r
.86231 .32736 .86646 .33351 .87676 .33018 .87264 .32402 Metetra
.664 .741 .908 r
.87264 .32402 .87676 .33018 .8871 .32685 .883 .32066 Metetra
.664 .741 .908 r
.883 .32066 .8871 .32685 .89748 .3235 .89341 .31729 Metetra
.664 .741 .908 r
.29746 .50347 .30289 .50853 .31134 .50579 .30592 .50072 Metetra
.664 .741 .908 r
.30592 .50072 .31134 .50579 .31981 .50305 .31441 .49796 Metetra
.664 .741 .908 r
.31441 .49796 .31981 .50305 .3283 .5003 .32292 .49519 Metetra
.664 .741 .908 r
.32292 .49519 .3283 .5003 .33683 .49754 .33147 .49241 Metetra
.664 .741 .908 r
.33147 .49241 .33683 .49754 .34538 .49477 .34004 .48963 Metetra
.664 .741 .908 r
.34004 .48963 .34538 .49477 .35396 .49199 .34863 .48683 Metetra
.664 .741 .908 r
.34863 .48683 .35396 .49199 .36257 .4892 .35726 .48403 Metetra
.664 .741 .908 r
.35726 .48403 .36257 .4892 .37121 .4864 .36591 .48122 Metetra
.664 .741 .908 r
.36591 .48122 .37121 .4864 .37987 .4836 .37459 .47839 Metetra
.664 .741 .908 r
.37459 .47839 .37987 .4836 .38856 .48078 .3833 .47556 Metetra
.664 .741 .908 r
.3833 .47556 .38856 .48078 .39728 .47796 .39204 .47272 Metetra
.664 .741 .908 r
.39204 .47272 .39728 .47796 .40603 .47513 .40081 .46987 Metetra
.664 .741 .908 r
.40081 .46987 .40603 .47513 .4148 .47244 .4096 .46701 Metetra
.663 .735 .903 r
.4096 .46701 .4148 .47244 .4236 .46978 .41842 .46414 Metetra
.606 .71 .918 r
.41842 .46414 .4236 .46978 .43239 .46868 .42724 .46251 Metetra
.591 .685 .906 r
.42724 .46251 .43239 .46868 .4412 .46805 .43608 .46124 Metetra
.595 .665 .888 r
.43608 .46124 .4412 .46805 .45007 .4665 .44496 .45997 Metetra
.594 .674 .896 r
.44496 .45997 .45007 .4665 .45899 .46464 .45388 .45869 Metetra
.655 .717 .894 r
.45388 .45869 .45899 .46464 .46796 .46146 .46286 .45596 Metetra
.679 .742 .898 r
.46286 .45596 .46796 .46146 .47697 .45772 .47188 .45263 Metetra
.601 .734 .938 r
.47188 .45263 .47697 .45772 .48599 .45593 .48091 .45095 Metetra
.551 .72 .952 r
.48091 .45095 .48599 .45593 .49503 .45506 .48997 .45004 Metetra
.628 .747 .933 r
.48997 .45004 .49503 .45506 .50412 .45298 .49908 .44782 Metetra
.663 .753 .917 r
.49908 .44782 .50412 .45298 .51324 .45024 .50823 .44486 Metetra
.561 .709 .94 r
.50823 .44486 .51324 .45024 .5224 .44938 .5174 .4439 Metetra
.478 .669 .947 r
.5174 .4439 .5224 .44938 .5316 .44972 .52662 .4442 Metetra
.572 .709 .935 r
.52662 .4442 .5316 .44972 .54084 .44825 .53588 .44308 Metetra
.624 .743 .933 r
.53588 .44308 .54084 .44825 .55011 .44547 .54518 .44091 Metetra
.421 .685 .973 r
.54518 .44091 .55011 .44547 .55945 .44575 .55453 .44145 Metetra
.161 .551 .928 r
.55453 .44145 .55945 .44575 .56887 .44856 .56397 .44424 Metetra
.473 .723 .979 r
.56397 .44424 .56887 .44856 .57831 .44838 .57343 .44404 Metetra
.657 .793 .947 r
.57343 .44404 .57831 .44838 .58774 .44538 .58288 .44101 Metetra
.765 .817 .894 r
.58288 .44101 .58774 .44538 .59714 .43954 .59231 .43516 Metetra
.832 .821 .838 r
.59231 .43516 .59714 .43954 .60648 .43069 .60169 .4263 Metetra
.786 .82 .88 r
.60169 .4263 .60648 .43069 .61589 .42437 .61112 .41968 Metetra
.696 .792 .924 r
.61112 .41968 .61589 .42437 .62541 .42112 .62065 .41578 Metetra
.73 .776 .889 r
.62065 .41578 .62541 .42112 .63492 .41655 .63017 .41082 Metetra
.766 .771 .857 r
.63017 .41082 .63492 .41655 .64438 .41014 .63966 .40442 Metetra
.732 .764 .878 r
.63966 .40442 .64438 .41014 .6539 .40494 .64921 .39928 Metetra
.663 .745 .911 r
.64921 .39928 .6539 .40494 .66353 .40164 .65886 .39616 Metetra
.691 .762 .906 r
.65886 .39616 .66353 .40164 .67315 .39766 .66852 .39229 Metetra
.737 .78 .888 r
.66852 .39229 .67315 .39766 .68275 .39245 .67814 .38708 Metetra
.711 .774 .902 r
.67814 .38708 .68275 .39245 .69241 .38817 .68783 .38265 Metetra
.645 .747 .923 r
.68783 .38265 .69241 .38817 .70221 .38587 .69763 .3799 Metetra
.67 .74 .902 r
.69763 .3799 .70221 .38587 .71202 .38301 .70743 .37653 Metetra
.717 .739 .869 r
.70743 .37653 .71202 .38301 .72178 .37879 .71718 .37168 Metetra
.712 .719 .855 r
.71718 .37168 .72178 .37879 .73155 .37425 .72695 .36682 Metetra
.709 .709 .848 r
.72695 .36682 .73155 .37425 .74128 .36877 .73674 .36195 Metetra
.704 .726 .867 r
.73674 .36195 .74128 .36877 .75106 .36375 .74659 .35744 Metetra
.663 .728 .898 r
.74659 .35744 .75106 .36375 .76099 .36034 .75655 .3542 Metetra
.663 .735 .903 r
.75655 .3542 .76099 .36034 .77095 .35695 .76655 .35095 Metetra
.664 .741 .908 r
.76655 .35095 .77095 .35695 .78096 .35371 .77658 .34769 Metetra
.664 .741 .908 r
.77658 .34769 .78096 .35371 .79101 .35045 .78665 .34442 Metetra
.664 .741 .908 r
.78665 .34442 .79101 .35045 .80108 .34719 .79675 .34113 Metetra
.664 .741 .908 r
.79675 .34113 .80108 .34719 .8112 .34391 .80689 .33784 Metetra
.664 .741 .908 r
.80689 .33784 .8112 .34391 .82135 .34063 .81707 .33453 Metetra
.664 .741 .908 r
.81707 .33453 .82135 .34063 .83153 .33733 .82728 .33121 Metetra
.664 .741 .908 r
.82728 .33121 .83153 .33733 .84176 .33402 .83753 .32788 Metetra
.664 .741 .908 r
.83753 .32788 .84176 .33402 .85201 .3307 .84781 .32453 Metetra
.664 .741 .908 r
.84781 .32453 .85201 .3307 .86231 .32736 .85813 .32118 Metetra
.664 .741 .908 r
.85813 .32118 .86231 .32736 .87264 .32402 .86849 .31781 Metetra
.664 .741 .908 r
.86849 .31781 .87264 .32402 .883 .32066 .87888 .31443 Metetra
.664 .741 .908 r
.87888 .31443 .883 .32066 .89341 .31729 .88931 .31104 Metetra
.664 .741 .908 r
.292 .49839 .29746 .50347 .30592 .50072 .30048 .49562 Metetra
.664 .741 .908 r
.30048 .49562 .30592 .50072 .31441 .49796 .30898 .49284 Metetra
.664 .741 .908 r
.30898 .49284 .31441 .49796 .32292 .49519 .31751 .49006 Metetra
.664 .741 .908 r
.31751 .49006 .32292 .49519 .33147 .49241 .32607 .48726 Metetra
.664 .741 .908 r
.32607 .48726 .33147 .49241 .34004 .48963 .33466 .48446 Metetra
.664 .741 .908 r
.33466 .48446 .34004 .48963 .34863 .48683 .34327 .48165 Metetra
.664 .741 .908 r
.34327 .48165 .34863 .48683 .35726 .48403 .35191 .47883 Metetra
.664 .741 .908 r
.35191 .47883 .35726 .48403 .36591 .48122 .36058 .476 Metetra
.664 .741 .908 r
.36058 .476 .36591 .48122 .37459 .47839 .36928 .47316 Metetra
.664 .741 .908 r
.36928 .47316 .37459 .47839 .3833 .47556 .37801 .47031 Metetra
.664 .741 .908 r
.37801 .47031 .3833 .47556 .39204 .47272 .38676 .46745 Metetra
.664 .741 .908 r
.38676 .46745 .39204 .47272 .40081 .46987 .39555 .46458 Metetra
.664 .741 .908 r
.39555 .46458 .40081 .46987 .4096 .46701 .40436 .46171 Metetra
.664 .741 .908 r
.40436 .46171 .4096 .46701 .41842 .46414 .4132 .45882 Metetra
.649 .737 .914 r
.4132 .45882 .41842 .46414 .42724 .46251 .42206 .45625 Metetra
.646 .702 .888 r
.42206 .45625 .42724 .46251 .43608 .46124 .43095 .45377 Metetra
.592 .644 .871 r
.43095 .45377 .43608 .46124 .44496 .45997 .43984 .45261 Metetra
.57 .639 .879 r
.43984 .45261 .44496 .45997 .45388 .45869 .44875 .45191 Metetra
.613 .675 .885 r
.44875 .45191 .45388 .45869 .46286 .45596 .45773 .45019 Metetra
.629 .717 .91 r
.45773 .45019 .46286 .45596 .47188 .45263 .46675 .44804 Metetra
.595 .755 .954 r
.46675 .44804 .47188 .45263 .48091 .45095 .4758 .44632 Metetra
.582 .75 .957 r
.4758 .44632 .48091 .45095 .48997 .45004 .48488 .44481 Metetra
.64 .743 .924 r
.48488 .44481 .48997 .45004 .49908 .44782 .49402 .44235 Metetra
.663 .742 .909 r
.49402 .44235 .49908 .44782 .50823 .44486 .50318 .43937 Metetra
.584 .715 .933 r
.50318 .43937 .50823 .44486 .5174 .4439 .51238 .43803 Metetra
.528 .677 .932 r
.51238 .43803 .5174 .4439 .52662 .4442 .52161 .43771 Metetra
.559 .667 .91 r
.52161 .43771 .52662 .4442 .53588 .44308 .53088 .43702 Metetra
.568 .688 .921 r
.53088 .43702 .53588 .44308 .54518 .44091 .5402 .43605 Metetra
.415 .67 .966 r
.5402 .43605 .54518 .44091 .55453 .44145 .54958 .43679 Metetra
.261 .596 .95 r
.54958 .43679 .55453 .44145 .56397 .44424 .55903 .43896 Metetra
.525 .704 .952 r
.55903 .43896 .56397 .44424 .57343 .44404 .5685 .43845 Metetra
.661 .744 .911 r
.5685 .43845 .57343 .44404 .58288 .44101 .57797 .43541 Metetra
.746 .768 .871 r
.57797 .43541 .58288 .44101 .59231 .43516 .58744 .42983 Metetra
.809 .788 .833 r
.58744 .42983 .59231 .43516 .60169 .4263 .59685 .42155 Metetra
.787 .808 .869 r
.59685 .42155 .60169 .4263 .61112 .41968 .60631 .41469 Metetra
.738 .791 .895 r
.60631 .41469 .61112 .41968 .62065 .41578 .61583 .40954 Metetra
.736 .747 .861 r
.61583 .40954 .62065 .41578 .63017 .41082 .62536 .40411 Metetra
.741 .735 .846 r
.62536 .40411 .63017 .41082 .63966 .40442 .63489 .39829 Metetra
.718 .747 .875 r
.63489 .39829 .63966 .40442 .64921 .39928 .64448 .39351 Metetra
.663 .742 .909 r
.64448 .39351 .64921 .39928 .65886 .39616 .65416 .39036 Metetra
.683 .749 .902 r
.65416 .39036 .65886 .39616 .66852 .39229 .66385 .38669 Metetra
.716 .768 .893 r
.66385 .38669 .66852 .39229 .67814 .38708 .67353 .38207 Metetra
.712 .79 .913 r
.67353 .38207 .67814 .38708 .68783 .38265 .68324 .37764 Metetra
.695 .786 .921 r
.68324 .37764 .68783 .38265 .69763 .3799 .693 .37364 Metetra
.705 .743 .881 r
.693 .37364 .69763 .3799 .70743 .37653 .70277 .36921 Metetra
.726 .718 .843 r
.70277 .36921 .70743 .37653 .71718 .37168 .7125 .36373 Metetra
.709 .695 .835 r
.7125 .36373 .71718 .37168 .72695 .36682 .72228 .35871 Metetra
.671 .676 .846 r
.72228 .35871 .72695 .36682 .73674 .36195 .73217 .35504 Metetra
.674 .713 .878 r
.73217 .35504 .73674 .36195 .74659 .35744 .7421 .35145 Metetra
.664 .741 .908 r
.7421 .35145 .74659 .35744 .75655 .3542 .75209 .34819 Metetra
.664 .741 .908 r
.75209 .34819 .75655 .3542 .76655 .35095 .76211 .34492 Metetra
.664 .741 .908 r
.76211 .34492 .76655 .35095 .77658 .34769 .77217 .34164 Metetra
.664 .741 .908 r
.77217 .34164 .77658 .34769 .78665 .34442 .78227 .33834 Metetra
.664 .741 .908 r
.78227 .33834 .78665 .34442 .79675 .34113 .7924 .33504 Metetra
.664 .741 .908 r
.7924 .33504 .79675 .34113 .80689 .33784 .80256 .33172 Metetra
.664 .741 .908 r
.80256 .33172 .80689 .33784 .81707 .33453 .81276 .32839 Metetra
.664 .741 .908 r
.81276 .32839 .81707 .33453 .82728 .33121 .823 .32505 Metetra
.664 .741 .908 r
.823 .32505 .82728 .33121 .83753 .32788 .83327 .32169 Metetra
.664 .741 .908 r
.83327 .32169 .83753 .32788 .84781 .32453 .84358 .31833 Metetra
.664 .741 .908 r
.84358 .31833 .84781 .32453 .85813 .32118 .85393 .31495 Metetra
.664 .741 .908 r
.85393 .31495 .85813 .32118 .86849 .31781 .86431 .31156 Metetra
.664 .741 .908 r
.86431 .31156 .86849 .31781 .87888 .31443 .87473 .30816 Metetra
.664 .741 .908 r
.87473 .30816 .87888 .31443 .88931 .31104 .88519 .30475 Metetra
.664 .741 .908 r
.28651 .49327 .292 .49839 .30048 .49562 .295 .49049 Metetra
.664 .741 .908 r
.295 .49049 .30048 .49562 .30898 .49284 .30352 .48769 Metetra
.664 .741 .908 r
.30352 .48769 .30898 .49284 .31751 .49006 .31207 .48489 Metetra
.664 .741 .908 r
.31207 .48489 .31751 .49006 .32607 .48726 .32064 .48208 Metetra
.664 .741 .908 r
.32064 .48208 .32607 .48726 .33466 .48446 .32925 .47926 Metetra
.664 .741 .908 r
.32925 .47926 .33466 .48446 .34327 .48165 .33788 .47643 Metetra
.664 .741 .908 r
.33788 .47643 .34327 .48165 .35191 .47883 .34654 .4736 Metetra
.664 .741 .908 r
.34654 .4736 .35191 .47883 .36058 .476 .35523 .47075 Metetra
.664 .741 .908 r
.35523 .47075 .36058 .476 .36928 .47316 .36394 .46789 Metetra
.664 .741 .908 r
.36394 .46789 .36928 .47316 .37801 .47031 .37269 .46503 Metetra
.664 .741 .908 r
.37269 .46503 .37801 .47031 .38676 .46745 .38146 .46215 Metetra
.664 .741 .908 r
.38146 .46215 .38676 .46745 .39555 .46458 .39026 .45927 Metetra
.664 .741 .908 r
.39026 .45927 .39555 .46458 .40436 .46171 .39909 .45637 Metetra
.664 .741 .908 r
.39909 .45637 .40436 .46171 .4132 .45882 .40795 .45347 Metetra
.664 .741 .908 r
.40795 .45347 .4132 .45882 .42206 .45625 .41684 .45055 Metetra
.663 .729 .898 r
.41684 .45055 .42206 .45625 .43095 .45377 .42576 .44763 Metetra
.61 .696 .904 r
.42576 .44763 .43095 .45377 .43984 .45261 .43468 .44593 Metetra
.592 .671 .894 r
.43468 .44593 .43984 .45261 .44875 .45191 .44362 .44465 Metetra
.585 .649 .88 r
.44362 .44465 .44875 .45191 .45773 .45019 .45259 .4436 Metetra
.575 .668 .902 r
.45259 .4436 .45773 .45019 .46675 .44804 .4616 .44264 Metetra
.591 .72 .933 r
.4616 .44264 .46675 .44804 .4758 .44632 .47066 .44115 Metetra
.603 .734 .937 r
.47066 .44115 .4758 .44632 .48488 .44481 .47977 .4394 Metetra
.644 .739 .918 r
.47977 .4394 .48488 .44481 .49402 .44235 .48892 .43685 Metetra
.663 .742 .909 r
.48892 .43685 .49402 .44235 .50318 .43937 .49811 .43385 Metetra
.604 .722 .928 r
.49811 .43385 .50318 .43937 .51238 .43803 .50732 .43212 Metetra
.564 .692 .926 r
.50732 .43212 .51238 .43803 .52161 .43771 .51657 .43118 Metetra
.547 .662 .912 r
.51657 .43118 .52161 .43771 .53088 .43702 .52586 .43069 Metetra
.525 .66 .921 r
.52586 .43069 .53088 .43702 .5402 .43605 .53519 .43053 Metetra
.285 .571 .936 r
.53519 .43053 .5402 .43605 .54958 .43679 .5446 .43303 Metetra
0 .351 .776 r
.5446 .43303 .54958 .43679 .55903 .43896 .55408 .43776 Metetra
.06 .611 .829 r
.55408 .43776 .55903 .43896 .5685 .43845 .5636 .43848 Metetra
.426 .868 .889 r
.5636 .43848 .5685 .43845 .57797 .43541 .57312 .43543 Metetra
.757 .986 .9 r
.57312 .43543 .57797 .43541 .58744 .42983 .5826 .42858 Metetra
.897 .93 .83 r
.5826 .42858 .58744 .42983 .59685 .42155 .59201 .4177 Metetra
.836 .845 .852 r
.59201 .4177 .59685 .42155 .60631 .41469 .60145 .40904 Metetra
.756 .772 .866 r
.60145 .40904 .60631 .41469 .61583 .40954 .61097 .40304 Metetra
.739 .741 .853 r
.61097 .40304 .61583 .40954 .62536 .40411 .62052 .39736 Metetra
.726 .73 .854 r
.62052 .39736 .62536 .40411 .63489 .39829 .63009 .39213 Metetra
.707 .744 .88 r
.63009 .39213 .63489 .39829 .64448 .39351 .63972 .3877 Metetra
.663 .742 .909 r
.63972 .3877 .64448 .39351 .65416 .39036 .64942 .38453 Metetra
.68 .748 .903 r
.64942 .38453 .65416 .39036 .66385 .38669 .65914 .38092 Metetra
.708 .76 .893 r
.65914 .38092 .66385 .38669 .67353 .38207 .66885 .37649 Metetra
.718 .771 .894 r
.66885 .37649 .67353 .38207 .68324 .37764 .67858 .37179 Metetra
.733 .766 .88 r
.67858 .37179 .68324 .37764 .693 .37364 .6883 .36655 Metetra
.72 .723 .852 r
.6883 .36655 .693 .37364 .70277 .36921 .69805 .36139 Metetra
.708 .699 .84 r
.69805 .36139 .70277 .36921 .7125 .36373 .70784 .35646 Metetra
.7 .712 .858 r
.70784 .35646 .7125 .36373 .72228 .35871 .71767 .35196 Metetra
.663 .714 .886 r
.71767 .35196 .72228 .35871 .73217 .35504 .72762 .3487 Metetra
.663 .729 .898 r
.72762 .3487 .73217 .35504 .7421 .35145 .73759 .34543 Metetra
.664 .741 .908 r
.73759 .34543 .7421 .35145 .75209 .34819 .74761 .34214 Metetra
.664 .741 .908 r
.74761 .34214 .75209 .34819 .76211 .34492 .75765 .33885 Metetra
.664 .741 .908 r
.75765 .33885 .76211 .34492 .77217 .34164 .76774 .33555 Metetra
.664 .741 .908 r
.76774 .33555 .77217 .34164 .78227 .33834 .77785 .33223 Metetra
.664 .741 .908 r
.77785 .33223 .78227 .33834 .7924 .33504 .78801 .3289 Metetra
.664 .741 .908 r
.78801 .3289 .7924 .33504 .80256 .33172 .7982 .32556 Metetra
.664 .741 .908 r
.7982 .32556 .80256 .33172 .81276 .32839 .80843 .32221 Metetra
.664 .741 .908 r
.80843 .32221 .81276 .32839 .823 .32505 .81869 .31885 Metetra
.664 .741 .908 r
.81869 .31885 .823 .32505 .83327 .32169 .82899 .31547 Metetra
.664 .741 .908 r
.82899 .31547 .83327 .32169 .84358 .31833 .83932 .31208 Metetra
.664 .741 .908 r
.83932 .31208 .84358 .31833 .85393 .31495 .8497 .30868 Metetra
.664 .741 .908 r
.8497 .30868 .85393 .31495 .86431 .31156 .86011 .30527 Metetra
.664 .741 .908 r
.86011 .30527 .86431 .31156 .87473 .30816 .87055 .30185 Metetra
.664 .741 .908 r
.87055 .30185 .87473 .30816 .88519 .30475 .88104 .29841 Metetra
.664 .741 .908 r
.28098 .48812 .28651 .49327 .295 .49049 .28949 .48532 Metetra
.664 .741 .908 r
.28949 .48532 .295 .49049 .30352 .48769 .29803 .48252 Metetra
.664 .741 .908 r
.29803 .48252 .30352 .48769 .31207 .48489 .30659 .4797 Metetra
.664 .741 .908 r
.30659 .4797 .31207 .48489 .32064 .48208 .31518 .47687 Metetra
.664 .741 .908 r
.31518 .47687 .32064 .48208 .32925 .47926 .3238 .47403 Metetra
.664 .741 .908 r
.3238 .47403 .32925 .47926 .33788 .47643 .33245 .47119 Metetra
.664 .741 .908 r
.33245 .47119 .33788 .47643 .34654 .4736 .34113 .46833 Metetra
.664 .741 .908 r
.34113 .46833 .34654 .4736 .35523 .47075 .34983 .46547 Metetra
.664 .741 .908 r
.34983 .46547 .35523 .47075 .36394 .46789 .35857 .46259 Metetra
.664 .741 .908 r
.35857 .46259 .36394 .46789 .37269 .46503 .36733 .45971 Metetra
.664 .741 .908 r
.36733 .45971 .37269 .46503 .38146 .46215 .37612 .45682 Metetra
.664 .741 .908 r
.37612 .45682 .38146 .46215 .39026 .45927 .38494 .45391 Metetra
.664 .741 .908 r
.38494 .45391 .39026 .45927 .39909 .45637 .39379 .451 Metetra
.664 .741 .908 r
.39379 .451 .39909 .45637 .40795 .45347 .40267 .44808 Metetra
.664 .741 .908 r
.40267 .44808 .40795 .45347 .41684 .45055 .41158 .44515 Metetra
.664 .741 .908 r
.41158 .44515 .41684 .45055 .42576 .44763 .42051 .44221 Metetra
.649 .737 .914 r
.42051 .44221 .42576 .44763 .43468 .44593 .42947 .4396 Metetra
.644 .703 .89 r
.42947 .4396 .43468 .44593 .44362 .44465 .43846 .4371 Metetra
.563 .632 .878 r
.43846 .4371 .44362 .44465 .45259 .4436 .44743 .43654 Metetra
.515 .627 .9 r
.44743 .43654 .45259 .4436 .4616 .44264 .45643 .43676 Metetra
.575 .696 .924 r
.45643 .43676 .4616 .44264 .47066 .44115 .4655 .43564 Metetra
.605 .723 .928 r
.4655 .43564 .47066 .44115 .47977 .4394 .47462 .43388 Metetra
.644 .736 .916 r
.47462 .43388 .47977 .4394 .48892 .43685 .48379 .43131 Metetra
.663 .742 .909 r
.48379 .43131 .48892 .43685 .49811 .43385 .493 .4283 Metetra
.622 .729 .923 r
.493 .4283 .49811 .43385 .50732 .43212 .50223 .42617 Metetra
.597 .705 .919 r
.50223 .42617 .50732 .43212 .51657 .43118 .5115 .42461 Metetra
.542 .66 .913 r
.5115 .42461 .51657 .43118 .52586 .43069 .5208 .4242 Metetra
.49 .639 .921 r
.5208 .4242 .52586 .43069 .53519 .43053 .53015 .42464 Metetra
.034 .397 .853 r
.53015 .42464 .53519 .43053 .5446 .43303 .53958 .42976 Metetra
.61 .066 0 r
.53958 .42976 .5446 .43303 .55408 .43776 .54912 .43882 Metetra
.43 0 0 r
.54912 .43882 .55408 .43776 .5636 .43848 .55869 .44166 Metetra
.55869 .44166 .5636 .43848 .57312 .43543 .56825 .43859 Metetra
.651 .936 .676 r
.56825 .43859 .57312 .43543 .5826 .42858 .57775 .4296 Metetra
.948 .95 .736 r
.57775 .4296 .5826 .42858 .59201 .4177 .58713 .41434 Metetra
.882 .855 .811 r
.58713 .41434 .59201 .4177 .60145 .40904 .59656 .40301 Metetra
.767 .763 .849 r
.59656 .40301 .60145 .40904 .61097 .40304 .60609 .39637 Metetra
.741 .737 .849 r
.60609 .39637 .61097 .40304 .62052 .39736 .61565 .39057 Metetra
.709 .725 .862 r
.61565 .39057 .62052 .39736 .63009 .39213 .62527 .38593 Metetra
.695 .74 .886 r
.62527 .38593 .63009 .39213 .63972 .3877 .63493 .38185 Metetra
.663 .742 .909 r
.63493 .38185 .63972 .3877 .64942 .38453 .64466 .37867 Metetra
.68 .748 .903 r
.64466 .37867 .64942 .38453 .65914 .38092 .6544 .37503 Metetra
.708 .757 .891 r
.6544 .37503 .65914 .38092 .66885 .37649 .66414 .37058 Metetra
.728 .763 .881 r
.66414 .37058 .66885 .37649 .67858 .37179 .67387 .36546 Metetra
.761 .759 .851 r
.67387 .36546 .67858 .37179 .6883 .36655 .68355 .35897 Metetra
.729 .714 .836 r
.68355 .35897 .6883 .36655 .69805 .36139 .6933 .35328 Metetra
.672 .678 .847 r
.6933 .35328 .69805 .36139 .70784 .35646 .70317 .34955 Metetra
.674 .714 .879 r
.70317 .34955 .70784 .35646 .71767 .35196 .71308 .34593 Metetra
.664 .741 .908 r
.71308 .34593 .71767 .35196 .72762 .3487 .72305 .34265 Metetra
.664 .741 .908 r
.72305 .34265 .72762 .3487 .73759 .34543 .73305 .33936 Metetra
.664 .741 .908 r
.73305 .33936 .73759 .34543 .74761 .34214 .74309 .33606 Metetra
.664 .741 .908 r
.74309 .33606 .74761 .34214 .75765 .33885 .75316 .33274 Metetra
.664 .741 .908 r
.75316 .33274 .75765 .33885 .76774 .33555 .76327 .32942 Metetra
.664 .741 .908 r
.76327 .32942 .76774 .33555 .77785 .33223 .77341 .32608 Metetra
.664 .741 .908 r
.77341 .32608 .77785 .33223 .78801 .3289 .78359 .32273 Metetra
.664 .741 .908 r
.78359 .32273 .78801 .3289 .7982 .32556 .79381 .31937 Metetra
.664 .741 .908 r
.79381 .31937 .7982 .32556 .80843 .32221 .80406 .31599 Metetra
.664 .741 .908 r
.80406 .31599 .80843 .32221 .81869 .31885 .81435 .31261 Metetra
.664 .741 .908 r
.81435 .31261 .81869 .31885 .82899 .31547 .82468 .30921 Metetra
.664 .741 .908 r
.82468 .30921 .82899 .31547 .83932 .31208 .83504 .3058 Metetra
.664 .741 .908 r
.83504 .3058 .83932 .31208 .8497 .30868 .84544 .30238 Metetra
.664 .741 .908 r
.84544 .30238 .8497 .30868 .86011 .30527 .85587 .29894 Metetra
.664 .741 .908 r
.85587 .29894 .86011 .30527 .87055 .30185 .86635 .29549 Metetra
.664 .741 .908 r
.86635 .29549 .87055 .30185 .88104 .29841 .87686 .29204 Metetra
.664 .741 .908 r
.27542 .48295 .28098 .48812 .28949 .48532 .28395 .48013 Metetra
.664 .741 .908 r
.28395 .48013 .28949 .48532 .29803 .48252 .2925 .47731 Metetra
.664 .741 .908 r
.2925 .47731 .29803 .48252 .30659 .4797 .30108 .47447 Metetra
.664 .741 .908 r
.30108 .47447 .30659 .4797 .31518 .47687 .30969 .47163 Metetra
.664 .741 .908 r
.30969 .47163 .31518 .47687 .3238 .47403 .31833 .46877 Metetra
.664 .741 .908 r
.31833 .46877 .3238 .47403 .33245 .47119 .32699 .46591 Metetra
.664 .741 .908 r
.32699 .46591 .33245 .47119 .34113 .46833 .33569 .46304 Metetra
.664 .741 .908 r
.33569 .46304 .34113 .46833 .34983 .46547 .34441 .46015 Metetra
.664 .741 .908 r
.34441 .46015 .34983 .46547 .35857 .46259 .35316 .45726 Metetra
.664 .741 .908 r
.35316 .45726 .35857 .46259 .36733 .45971 .36194 .45436 Metetra
.664 .741 .908 r
.36194 .45436 .36733 .45971 .37612 .45682 .37075 .45145 Metetra
.664 .741 .908 r
.37075 .45145 .37612 .45682 .38494 .45391 .37959 .44853 Metetra
.664 .741 .908 r
.37959 .44853 .38494 .45391 .39379 .451 .38846 .4456 Metetra
.664 .741 .908 r
.38846 .4456 .39379 .451 .40267 .44808 .39735 .44266 Metetra
.664 .741 .908 r
.39735 .44266 .40267 .44808 .41158 .44515 .40628 .43971 Metetra
.664 .741 .908 r
.40628 .43971 .41158 .44515 .42051 .44221 .41524 .43675 Metetra
.664 .741 .908 r
.41524 .43675 .42051 .44221 .42947 .4396 .42422 .43378 Metetra
.663 .729 .898 r
.42422 .43378 .42947 .4396 .43846 .4371 .43324 .4308 Metetra
.582 .683 .91 r
.43324 .4308 .43846 .4371 .44743 .43654 .44224 .42963 Metetra
.548 .648 .9 r
.44224 .42963 .44743 .43654 .45643 .43676 .45126 .4292 Metetra
.585 .644 .875 r
.45126 .4292 .45643 .43676 .4655 .43564 .46034 .4281 Metetra
.599 .651 .873 r
.46034 .4281 .4655 .43564 .47462 .43388 .46947 .42669 Metetra
.601 .663 .883 r
.46947 .42669 .47462 .43388 .48379 .43131 .47864 .42519 Metetra
.597 .699 .914 r
.47864 .42519 .48379 .43131 .493 .4283 .48785 .42364 Metetra
.616 .766 .951 r
.48785 .42364 .493 .4283 .50223 .42617 .4971 .42148 Metetra
.637 .771 .944 r
.4971 .42148 .50223 .42617 .5115 .42461 .50639 .41892 Metetra
.53 .69 .941 r
.50639 .41892 .5115 .42461 .5208 .4242 .51571 .41844 Metetra
.423 .637 .945 r
.51571 .41844 .5208 .4242 .53015 .42464 .52508 .41947 Metetra
0 .106 .609 r
.52508 .41947 .53015 .42464 .53958 .42976 .53453 .42764 Metetra
.814 .33 0 r
.53453 .42764 .53958 .42976 .54912 .43882 .54411 .44185 Metetra
.619 .114 .027 r
.54411 .44185 .54912 .43882 .55869 .44166 .55374 .44721 Metetra
.19 0 0 r
.55374 .44721 .55869 .44166 .56825 .43859 .56336 .44413 Metetra
.586 .845 .489 r
.56336 .44413 .56825 .43859 .57775 .4296 .57289 .43259 Metetra
.971 .931 .644 r
.57289 .43259 .57775 .4296 .58713 .41434 .58224 .41214 Metetra
.926 .876 .768 r
.58224 .41214 .58713 .41434 .59656 .40301 .59165 .3977 Metetra
.79 .793 .854 r
.59165 .3977 .59656 .40301 .60609 .39637 .60119 .39043 Metetra
.747 .763 .866 r
.60119 .39043 .60609 .39637 .61565 .39057 .61078 .38466 Metetra
.682 .746 .9 r
.61078 .38466 .61565 .39057 .62527 .38593 .62045 .38099 Metetra
.698 .79 .921 r
.62045 .38099 .62527 .38593 .63493 .38185 .63014 .37691 Metetra
.721 .797 .911 r
.63014 .37691 .63493 .38185 .64466 .37867 .63984 .3722 Metetra
.714 .74 .872 r
.63984 .3722 .64466 .37867 .6544 .37503 .64956 .36744 Metetra
.707 .705 .846 r
.64956 .36744 .6544 .37503 .66414 .37058 .6593 .36259 Metetra
.712 .697 .834 r
.6593 .36259 .66414 .37058 .67387 .36546 .66905 .35741 Metetra
.728 .702 .825 r
.66905 .35741 .67387 .36546 .68355 .35897 .67879 .35155 Metetra
.715 .714 .848 r
.67879 .35155 .68355 .35897 .6933 .35328 .68859 .34643 Metetra
.662 .712 .885 r
.68859 .34643 .6933 .35328 .70317 .34955 .69851 .34316 Metetra
.663 .729 .898 r
.69851 .34316 .70317 .34955 .71308 .34593 .70847 .33987 Metetra
.664 .741 .908 r
.70847 .33987 .71308 .34593 .72305 .34265 .71846 .33656 Metetra
.664 .741 .908 r
.71846 .33656 .72305 .34265 .73305 .33936 .72848 .33325 Metetra
.664 .741 .908 r
.72848 .33325 .73305 .33936 .74309 .33606 .73855 .32993 Metetra
.664 .741 .908 r
.73855 .32993 .74309 .33606 .75316 .33274 .74864 .32659 Metetra
.664 .741 .908 r
.74864 .32659 .75316 .33274 .76327 .32942 .75878 .32324 Metetra
.664 .741 .908 r
.75878 .32324 .76327 .32942 .77341 .32608 .76894 .31988 Metetra
.664 .741 .908 r
.76894 .31988 .77341 .32608 .78359 .32273 .77915 .31651 Metetra
.664 .741 .908 r
.77915 .31651 .78359 .32273 .79381 .31937 .78939 .31313 Metetra
.664 .741 .908 r
.78939 .31313 .79381 .31937 .80406 .31599 .79967 .30973 Metetra
.664 .741 .908 r
.79967 .30973 .80406 .31599 .81435 .31261 .80998 .30632 Metetra
.664 .741 .908 r
.80998 .30632 .81435 .31261 .82468 .30921 .82034 .3029 Metetra
.664 .741 .908 r
.82034 .3029 .82468 .30921 .83504 .3058 .83072 .29947 Metetra
.664 .741 .908 r
.83072 .29947 .83504 .3058 .84544 .30238 .84115 .29603 Metetra
.664 .741 .908 r
.84115 .29603 .84544 .30238 .85587 .29894 .85161 .29257 Metetra
.664 .741 .908 r
.85161 .29257 .85587 .29894 .86635 .29549 .86211 .2891 Metetra
.664 .741 .908 r
.86211 .2891 .86635 .29549 .87686 .29204 .87265 .28562 Metetra
.664 .741 .908 r
.26983 .47774 .27542 .48295 .28395 .48013 .27837 .47491 Metetra
.664 .741 .908 r
.27837 .47491 .28395 .48013 .2925 .47731 .28694 .47206 Metetra
.664 .741 .908 r
.28694 .47206 .2925 .47731 .30108 .47447 .29554 .46921 Metetra
.664 .741 .908 r
.29554 .46921 .30108 .47447 .30969 .47163 .30417 .46635 Metetra
.664 .741 .908 r
.30417 .46635 .30969 .47163 .31833 .46877 .31282 .46348 Metetra
.664 .741 .908 r
.31282 .46348 .31833 .46877 .32699 .46591 .3215 .4606 Metetra
.664 .741 .908 r
.3215 .4606 .32699 .46591 .33569 .46304 .33021 .45771 Metetra
.664 .741 .908 r
.33021 .45771 .33569 .46304 .34441 .46015 .33895 .45481 Metetra
.664 .741 .908 r
.33895 .45481 .34441 .46015 .35316 .45726 .34772 .4519 Metetra
.664 .741 .908 r
.34772 .4519 .35316 .45726 .36194 .45436 .35652 .44898 Metetra
.664 .741 .908 r
.35652 .44898 .36194 .45436 .37075 .45145 .36535 .44605 Metetra
.664 .741 .908 r
.36535 .44605 .37075 .45145 .37959 .44853 .3742 .44311 Metetra
.664 .741 .908 r
.3742 .44311 .37959 .44853 .38846 .4456 .38309 .44017 Metetra
.664 .741 .908 r
.38309 .44017 .38846 .4456 .39735 .44266 .392 .43721 Metetra
.664 .741 .908 r
.392 .43721 .39735 .44266 .40628 .43971 .40095 .43424 Metetra
.664 .741 .908 r
.40095 .43424 .40628 .43971 .41524 .43675 .40992 .43126 Metetra
.664 .741 .908 r
.40992 .43126 .41524 .43675 .42422 .43378 .41893 .42828 Metetra
.664 .741 .908 r
.41893 .42828 .42422 .43378 .43324 .4308 .42796 .42528 Metetra
.64 .734 .917 r
.42796 .42528 .43324 .4308 .44224 .42963 .43701 .42281 Metetra
.632 .686 .883 r
.43701 .42281 .44224 .42963 .45126 .4292 .44609 .42055 Metetra
.595 .62 .846 r
.44609 .42055 .45126 .4292 .46034 .4281 .45519 .41926 Metetra
.578 .608 .846 r
.45519 .41926 .46034 .4281 .46947 .42669 .46431 .41842 Metetra
.525 .598 .869 r
.46431 .41842 .46947 .42669 .47864 .42519 .47346 .41868 Metetra
.458 .624 .924 r
.47346 .41868 .47864 .42519 .48785 .42364 .48265 .41955 Metetra
.594 .785 .972 r
.48265 .41955 .48785 .42364 .4971 .42148 .49193 .41757 Metetra
.691 .822 .945 r
.49193 .41757 .4971 .42148 .50639 .41892 .50125 .41377 Metetra
.527 .713 .957 r
.50125 .41377 .50639 .41892 .51571 .41844 .51059 .41312 Metetra
.347 .619 .952 r
.51059 .41312 .51571 .41844 .52508 .41947 .51998 .41475 Metetra
.658 .153 0 r
.51998 .41475 .52508 .41947 .53453 .42764 .52943 .42626 Metetra
.875 .442 .157 r
.52943 .42626 .53453 .42764 .54411 .44185 .53904 .44616 Metetra
.698 .24 .161 r
.53904 .44616 .54411 .44185 .55374 .44721 .54874 .45433 Metetra
.265 0 0 r
.54874 .45433 .55374 .44721 .56336 .44413 .55842 .45124 Metetra
.618 .823 .419 r
.55842 .45124 .56336 .44413 .57289 .43259 .56798 .43687 Metetra
.985 .9 .587 r
.56798 .43687 .57289 .43259 .58224 .41214 .57732 .41067 Metetra
.952 .873 .722 r
.57732 .41067 .58224 .41214 .59165 .3977 .58671 .39285 Metetra
.809 .812 .853 r
.58671 .39285 .59165 .3977 .60119 .39043 .59627 .38493 Metetra
.747 .78 .88 r
.59627 .38493 .60119 .39043 .61078 .38466 .6059 .3793 Metetra
.629 .751 .935 r
.6059 .3793 .61078 .38466 .62045 .38099 .61563 .37683 Metetra
.706 .827 .94 r
.61563 .37683 .62045 .38099 .63014 .37691 .62534 .37254 Metetra
.798 .834 .879 r
.62534 .37254 .63014 .37691 .63984 .3722 .63498 .36535 Metetra
.757 .742 .839 r
.63498 .36535 .63984 .3722 .64956 .36744 .64466 .35876 Metetra
.713 .681 .817 r
.64466 .35876 .64956 .36744 .6593 .36259 .65439 .35328 Metetra
.697 .661 .811 r
.65439 .35328 .6593 .36259 .66905 .35741 .66416 .34825 Metetra
.674 .655 .823 r
.66416 .34825 .66905 .35741 .67879 .35155 .67401 .34421 Metetra
.679 .704 .866 r
.67401 .34421 .67879 .35155 .68859 .34643 .68389 .34037 Metetra
.664 .741 .908 r
.68389 .34037 .68859 .34643 .69851 .34316 .69384 .33707 Metetra
.664 .741 .908 r
.69384 .33707 .69851 .34316 .70847 .33987 .70382 .33376 Metetra
.664 .741 .908 r
.70382 .33376 .70847 .33987 .71846 .33656 .71383 .33044 Metetra
.664 .741 .908 r
.71383 .33044 .71846 .33656 .72848 .33325 .72388 .32711 Metetra
.664 .741 .908 r
.72388 .32711 .72848 .33325 .73855 .32993 .73397 .32376 Metetra
.664 .741 .908 r
.73397 .32376 .73855 .32993 .74864 .32659 .74409 .3204 Metetra
.664 .741 .908 r
.74409 .3204 .74864 .32659 .75878 .32324 .75425 .31703 Metetra
.664 .741 .908 r
.75425 .31703 .75878 .32324 .76894 .31988 .76445 .31365 Metetra
.664 .741 .908 r
.76445 .31365 .76894 .31988 .77915 .31651 .77468 .31025 Metetra
.664 .741 .908 r
.77468 .31025 .77915 .31651 .78939 .31313 .78494 .30685 Metetra
.664 .741 .908 r
.78494 .30685 .78939 .31313 .79967 .30973 .79525 .30343 Metetra
.664 .741 .908 r
.79525 .30343 .79967 .30973 .80998 .30632 .80559 .3 Metetra
.664 .741 .908 r
.80559 .3 .80998 .30632 .82034 .3029 .81597 .29656 Metetra
.664 .741 .908 r
.81597 .29656 .82034 .3029 .83072 .29947 .82638 .2931 Metetra
.664 .741 .908 r
.82638 .2931 .83072 .29947 .84115 .29603 .83683 .28963 Metetra
.664 .741 .908 r
.83683 .28963 .84115 .29603 .85161 .29257 .84732 .28615 Metetra
.664 .741 .908 r
.84732 .28615 .85161 .29257 .86211 .2891 .85785 .28266 Metetra
.664 .741 .908 r
.85785 .28266 .86211 .2891 .87265 .28562 .86842 .27915 Metetra
.664 .741 .908 r
.2642 .4725 .26983 .47774 .27837 .47491 .27276 .46965 Metetra
.664 .741 .908 r
.27276 .46965 .27837 .47491 .28694 .47206 .28135 .46679 Metetra
.664 .741 .908 r
.28135 .46679 .28694 .47206 .29554 .46921 .28996 .46392 Metetra
.664 .741 .908 r
.28996 .46392 .29554 .46921 .30417 .46635 .29861 .46104 Metetra
.664 .741 .908 r
.29861 .46104 .30417 .46635 .31282 .46348 .30728 .45815 Metetra
.664 .741 .908 r
.30728 .45815 .31282 .46348 .3215 .4606 .31598 .45526 Metetra
.664 .741 .908 r
.31598 .45526 .3215 .4606 .33021 .45771 .32471 .45235 Metetra
.664 .741 .908 r
.32471 .45235 .33021 .45771 .33895 .45481 .33346 .44943 Metetra
.664 .741 .908 r
.33346 .44943 .33895 .45481 .34772 .4519 .34225 .4465 Metetra
.664 .741 .908 r
.34225 .4465 .34772 .4519 .35652 .44898 .35107 .44357 Metetra
.664 .741 .908 r
.35107 .44357 .35652 .44898 .36535 .44605 .35991 .44062 Metetra
.664 .741 .908 r
.35991 .44062 .36535 .44605 .3742 .44311 .36878 .43766 Metetra
.664 .741 .908 r
.36878 .43766 .3742 .44311 .38309 .44017 .37769 .4347 Metetra
.664 .741 .908 r
.37769 .4347 .38309 .44017 .392 .43721 .38662 .43172 Metetra
.664 .741 .908 r
.38662 .43172 .392 .43721 .40095 .43424 .39559 .42874 Metetra
.664 .741 .908 r
.39559 .42874 .40095 .43424 .40992 .43126 .40458 .42574 Metetra
.664 .741 .908 r
.40458 .42574 .40992 .43126 .41893 .42828 .4136 .42273 Metetra
.664 .741 .908 r
.4136 .42273 .41893 .42828 .42796 .42528 .42266 .41972 Metetra
.664 .741 .908 r
.42266 .41972 .42796 .42528 .43701 .42281 .43174 .41669 Metetra
.663 .722 .893 r
.43174 .41669 .43701 .42281 .44609 .42055 .44086 .41366 Metetra
.604 .675 .891 r
.44086 .41366 .44609 .42055 .45519 .41926 .44997 .41203 Metetra
.574 .653 .889 r
.44997 .41203 .45519 .41926 .46431 .41842 .45911 .41108 Metetra
.504 .617 .898 r
.45911 .41108 .46431 .41842 .47346 .41868 .46827 .41149 Metetra
.454 .598 .905 r
.46827 .41149 .47346 .41868 .48265 .41955 .47746 .41266 Metetra
.589 .672 .897 r
.47746 .41266 .48265 .41955 .49193 .41757 .48674 .41133 Metetra
.655 .72 .896 r
.48674 .41133 .49193 .41757 .50125 .41377 .49608 .40842 Metetra
.537 .71 .951 r
.49608 .40842 .50125 .41377 .51059 .41312 .50544 .40766 Metetra
.424 .654 .955 r
.50544 .40766 .51059 .41312 .51998 .41475 .51484 .40846 Metetra
.669 .203 0 r
.51484 .40846 .51998 .41475 .52943 .42626 .52429 .42226 Metetra
.903 .49 .144 r
.52429 .42226 .52943 .42626 .53904 .44616 .53391 .44716 Metetra
.757 .265 .061 r
.53391 .44716 .53904 .44616 .54874 .45433 .54364 .45779 Metetra
.009 0 0 r
.54364 .45779 .54874 .45433 .55842 .45124 .55337 .45469 Metetra
.929 .964 .666 r
.55337 .45469 .55842 .45124 .56798 .43687 .56297 .43782 Metetra
.988 .839 .606 r
.56297 .43782 .56798 .43687 .57732 .41067 .57231 .40659 Metetra
.93 .805 .7 r
.57231 .40659 .57732 .41067 .58671 .39285 .58172 .38642 Metetra
.773 .756 .837 r
.58172 .38642 .58671 .39285 .59627 .38493 .59132 .37929 Metetra
.744 .776 .879 r
.59132 .37929 .59627 .38493 .6059 .3793 .60097 .37373 Metetra
.67 .758 .917 r
.60097 .37373 .6059 .3793 .61563 .37683 .6107 .37033 Metetra
.72 .742 .869 r
.6107 .37033 .61563 .37683 .62534 .37254 .62042 .36533 Metetra
.772 .737 .821 r
.62042 .36533 .62534 .37254 .63498 .36535 .63008 .3578 Metetra
.753 .723 .824 r
.63008 .3578 .63498 .36535 .64466 .35876 .63977 .35102 Metetra
.72 .707 .838 r
.63977 .35102 .64466 .35876 .65439 .35328 .64952 .34561 Metetra
.703 .704 .848 r
.64952 .34561 .65439 .35328 .66416 .34825 .65933 .34088 Metetra
.661 .696 .872 r
.65933 .34088 .66416 .34825 .67401 .34421 .66923 .33758 Metetra
.663 .722 .893 r
.66923 .33758 .67401 .34421 .68389 .34037 .67917 .33427 Metetra
.664 .741 .908 r
.67917 .33427 .68389 .34037 .69384 .33707 .68913 .33095 Metetra
.664 .741 .908 r
.68913 .33095 .69384 .33707 .70382 .33376 .69914 .32762 Metetra
.664 .741 .908 r
.69914 .32762 .70382 .33376 .71383 .33044 .70918 .32427 Metetra
.664 .741 .908 r
.70918 .32427 .71383 .33044 .72388 .32711 .71925 .32092 Metetra
.664 .741 .908 r
.71925 .32092 .72388 .32711 .73397 .32376 .72937 .31755 Metetra
.664 .741 .908 r
.72937 .31755 .73397 .32376 .74409 .3204 .73951 .31417 Metetra
.664 .741 .908 r
.73951 .31417 .74409 .3204 .75425 .31703 .7497 .31078 Metetra
.664 .741 .908 r
.7497 .31078 .75425 .31703 .76445 .31365 .75992 .30737 Metetra
.664 .741 .908 r
.75992 .30737 .76445 .31365 .77468 .31025 .77017 .30396 Metetra
.664 .741 .908 r
.77017 .30396 .77468 .31025 .78494 .30685 .78047 .30053 Metetra
.664 .741 .908 r
.78047 .30053 .78494 .30685 .79525 .30343 .7908 .29709 Metetra
.664 .741 .908 r
.7908 .29709 .79525 .30343 .80559 .3 .80116 .29363 Metetra
.664 .741 .908 r
.80116 .29363 .80559 .3 .81597 .29656 .81157 .29017 Metetra
.664 .741 .908 r
.81157 .29017 .81597 .29656 .82638 .2931 .82201 .28669 Metetra
.664 .741 .908 r
.82201 .28669 .82638 .2931 .83683 .28963 .83249 .2832 Metetra
.664 .741 .908 r
.83249 .2832 .83683 .28963 .84732 .28615 .84301 .27969 Metetra
.664 .741 .908 r
.84301 .27969 .84732 .28615 .85785 .28266 .85356 .27618 Metetra
.664 .741 .908 r
.85356 .27618 .85785 .28266 .86842 .27915 .86416 .27265 Metetra
.664 .741 .908 r
.25854 .46723 .2642 .4725 .27276 .46965 .26712 .46436 Metetra
.664 .741 .908 r
.26712 .46436 .27276 .46965 .28135 .46679 .27572 .46149 Metetra
.664 .741 .908 r
.27572 .46149 .28135 .46679 .28996 .46392 .28435 .4586 Metetra
.664 .741 .908 r
.28435 .4586 .28996 .46392 .29861 .46104 .29301 .4557 Metetra
.664 .741 .908 r
.29301 .4557 .29861 .46104 .30728 .45815 .3017 .4528 Metetra
.664 .741 .908 r
.3017 .4528 .30728 .45815 .31598 .45526 .31042 .44988 Metetra
.664 .741 .908 r
.31042 .44988 .31598 .45526 .32471 .45235 .31916 .44695 Metetra
.664 .741 .908 r
.31916 .44695 .32471 .45235 .33346 .44943 .32794 .44402 Metetra
.664 .741 .908 r
.32794 .44402 .33346 .44943 .34225 .4465 .33674 .44107 Metetra
.664 .741 .908 r
.33674 .44107 .34225 .4465 .35107 .44357 .34558 .43812 Metetra
.664 .741 .908 r
.34558 .43812 .35107 .44357 .35991 .44062 .35444 .43516 Metetra
.664 .741 .908 r
.35444 .43516 .35991 .44062 .36878 .43766 .36333 .43218 Metetra
.664 .741 .908 r
.36333 .43218 .36878 .43766 .37769 .4347 .37226 .4292 Metetra
.664 .741 .908 r
.37226 .4292 .37769 .4347 .38662 .43172 .38121 .4262 Metetra
.664 .741 .908 r
.38121 .4262 .38662 .43172 .39559 .42874 .39019 .4232 Metetra
.664 .741 .908 r
.39019 .4232 .39559 .42874 .40458 .42574 .3992 .42018 Metetra
.664 .741 .908 r
.3992 .42018 .40458 .42574 .4136 .42273 .40825 .41716 Metetra
.664 .741 .908 r
.40825 .41716 .4136 .42273 .42266 .41972 .41732 .41412 Metetra
.664 .741 .908 r
.41732 .41412 .42266 .41972 .43174 .41669 .42642 .41108 Metetra
.664 .741 .908 r
.42642 .41108 .43174 .41669 .44086 .41366 .43556 .40802 Metetra
.617 .726 .924 r
.43556 .40802 .44086 .41366 .44997 .41203 .4447 .40597 Metetra
.595 .703 .918 r
.4447 .40597 .44997 .41203 .45911 .41108 .45386 .4044 Metetra
.55 .662 .911 r
.45386 .4044 .45911 .41108 .46827 .41149 .46305 .40379 Metetra
.533 .622 .886 r
.46305 .40379 .46827 .41149 .47746 .41266 .47228 .40372 Metetra
.554 .598 .852 r
.47228 .40372 .47746 .41266 .48674 .41133 .48155 .40339 Metetra
.555 .626 .877 r
.48155 .40339 .48674 .41133 .49608 .40842 .49088 .4029 Metetra
.542 .707 .947 r
.49088 .4029 .49608 .40842 .50544 .40766 .50025 .40209 Metetra
.557 .711 .943 r
.50025 .40209 .50544 .40766 .51484 .40846 .50968 .40104 Metetra
.667 .228 0 r
.50968 .40104 .51484 .40846 .52429 .42226 .51912 .41637 Metetra
.917 .522 .146 r
.51912 .41637 .52429 .42226 .53391 .44716 .52871 .44571 Metetra
.79 .291 0 r
.52871 .44571 .53391 .44716 .54364 .45779 .53847 .45856 Metetra
.332 .815 .803 r
.53847 .45856 .54364 .45779 .55337 .45469 .54824 .45544 Metetra
.969 .911 .7 r
.54824 .45544 .55337 .45469 .56297 .43782 .55788 .43632 Metetra
.974 .797 .602 r
.55788 .43632 .56297 .43782 .57231 .40659 .56724 .40059 Metetra
.914 .767 .685 r
.56724 .40059 .57231 .40659 .58172 .38642 .57667 .37885 Metetra
.719 .709 .84 r
.57667 .37885 .58172 .38642 .59132 .37929 .58633 .37354 Metetra
.742 .773 .878 r
.58633 .37354 .59132 .37929 .60097 .37373 .59601 .36799 Metetra
.751 .776 .874 r
.59601 .36799 .60097 .37373 .6107 .37033 .60571 .36211 Metetra
.73 .699 .82 r
.60571 .36211 .6107 .37033 .62042 .36533 .61541 .35605 Metetra
.725 .674 .8 r
.61541 .35605 .62042 .36533 .63008 .3578 .62513 .34973 Metetra
.726 .702 .827 r
.62513 .34973 .63008 .3578 .63977 .35102 .63487 .34394 Metetra
.71 .724 .861 r
.63487 .34394 .63977 .35102 .64952 .34561 .64468 .33912 Metetra
.699 .739 .882 r
.64468 .33912 .64952 .34561 .65933 .34088 .65453 .33478 Metetra
.664 .741 .908 r
.65453 .33478 .65933 .34088 .66923 .33758 .66445 .33146 Metetra
.664 .741 .908 r
.66445 .33146 .66923 .33758 .67917 .33427 .67441 .32813 Metetra
.664 .741 .908 r
.67441 .32813 .67917 .33427 .68913 .33095 .6844 .32479 Metetra
.664 .741 .908 r
.6844 .32479 .68913 .33095 .69914 .32762 .69443 .32144 Metetra
.664 .741 .908 r
.69443 .32144 .69914 .32762 .70918 .32427 .70449 .31807 Metetra
.664 .741 .908 r
.70449 .31807 .70918 .32427 .71925 .32092 .71459 .31469 Metetra
.664 .741 .908 r
.71459 .31469 .71925 .32092 .72937 .31755 .72473 .3113 Metetra
.664 .741 .908 r
.72473 .3113 .72937 .31755 .73951 .31417 .7349 .3079 Metetra
.664 .741 .908 r
.7349 .3079 .73951 .31417 .7497 .31078 .74511 .30448 Metetra
.664 .741 .908 r
.74511 .30448 .7497 .31078 .75992 .30737 .75536 .30106 Metetra
.664 .741 .908 r
.75536 .30106 .75992 .30737 .77017 .30396 .76564 .29762 Metetra
.664 .741 .908 r
.76564 .29762 .77017 .30396 .78047 .30053 .77596 .29417 Metetra
.664 .741 .908 r
.77596 .29417 .78047 .30053 .7908 .29709 .78632 .2907 Metetra
.664 .741 .908 r
.78632 .2907 .7908 .29709 .80116 .29363 .79671 .28723 Metetra
.664 .741 .908 r
.79671 .28723 .80116 .29363 .81157 .29017 .80714 .28374 Metetra
.664 .741 .908 r
.80714 .28374 .81157 .29017 .82201 .28669 .81761 .28023 Metetra
.664 .741 .908 r
.81761 .28023 .82201 .28669 .83249 .2832 .82812 .27672 Metetra
.664 .741 .908 r
.82812 .27672 .83249 .2832 .84301 .27969 .83866 .27319 Metetra
.664 .741 .908 r
.83866 .27319 .84301 .27969 .85356 .27618 .84924 .26965 Metetra
.664 .741 .908 r
.84924 .26965 .85356 .27618 .86416 .27265 .85987 .2661 Metetra
.664 .741 .908 r
.25285 .46193 .25854 .46723 .26712 .46436 .26144 .45904 Metetra
.664 .741 .908 r
.26144 .45904 .26712 .46436 .27572 .46149 .27006 .45615 Metetra
.664 .741 .908 r
.27006 .45615 .27572 .46149 .28435 .4586 .27871 .45324 Metetra
.664 .741 .908 r
.27871 .45324 .28435 .4586 .29301 .4557 .28738 .45033 Metetra
.664 .741 .908 r
.28738 .45033 .29301 .4557 .3017 .4528 .29609 .4474 Metetra
.664 .741 .908 r
.29609 .4474 .3017 .4528 .31042 .44988 .30483 .44447 Metetra
.664 .741 .908 r
.30483 .44447 .31042 .44988 .31916 .44695 .31359 .44153 Metetra
.664 .741 .908 r
.31359 .44153 .31916 .44695 .32794 .44402 .32238 .43857 Metetra
.664 .741 .908 r
.32238 .43857 .32794 .44402 .33674 .44107 .3312 .43561 Metetra
.664 .741 .908 r
.3312 .43561 .33674 .44107 .34558 .43812 .34006 .43264 Metetra
.664 .741 .908 r
.34006 .43264 .34558 .43812 .35444 .43516 .34894 .42966 Metetra
.664 .741 .908 r
.34894 .42966 .35444 .43516 .36333 .43218 .35785 .42666 Metetra
.664 .741 .908 r
.35785 .42666 .36333 .43218 .37226 .4292 .36679 .42366 Metetra
.664 .741 .908 r
.36679 .42366 .37226 .4292 .38121 .4262 .37576 .42065 Metetra
.664 .741 .908 r
.37576 .42065 .38121 .4262 .39019 .4232 .38476 .41762 Metetra
.664 .741 .908 r
.38476 .41762 .39019 .4232 .3992 .42018 .39379 .41459 Metetra
.664 .741 .908 r
.39379 .41459 .3992 .42018 .40825 .41716 .40285 .41155 Metetra
.664 .741 .908 r
.40285 .41155 .40825 .41716 .41732 .41412 .41195 .40849 Metetra
.664 .741 .908 r
.41195 .40849 .41732 .41412 .42642 .41108 .42107 .40543 Metetra
.664 .741 .908 r
.42107 .40543 .42642 .41108 .43556 .40802 .43022 .40236 Metetra
.637 .733 .918 r
.43022 .40236 .43556 .40802 .4447 .40597 .43939 .39988 Metetra
.625 .714 .91 r
.43939 .39988 .4447 .40597 .45386 .4044 .44859 .39768 Metetra
.59 .679 .902 r
.44859 .39768 .45386 .4044 .46305 .40379 .45781 .39627 Metetra
.574 .647 .884 r
.45781 .39627 .46305 .40379 .47228 .40372 .46706 .3953 Metetra
.536 .603 .868 r
.46706 .3953 .47228 .40372 .48155 .40339 .47634 .39528 Metetra
.501 .596 .881 r
.47634 .39528 .48155 .40339 .49088 .4029 .48566 .39587 Metetra
.543 .651 .905 r
.48566 .39587 .49088 .4029 .50025 .40209 .49504 .39541 Metetra
.579 .679 .909 r
.49504 .39541 .50025 .40209 .50968 .40104 .50448 .39418 Metetra
.81 .373 0 r
.50448 .39418 .50968 .40104 .51912 .41637 .5139 .41332 Metetra
.933 .562 .27 r
.5139 .41332 .51912 .41637 .52871 .44571 .52347 .45001 Metetra
.811 .396 .26 r
.52347 .45001 .52871 .44571 .53847 .45856 .53326 .46653 Metetra
.285 0 .034 r
.53326 .46653 .53847 .45856 .54824 .45544 .54309 .46341 Metetra
.875 .902 .487 r
.54309 .46341 .54824 .45544 .55788 .43632 .55279 .44058 Metetra
.998 .825 .54 r
.55279 .44058 .55788 .43632 .56724 .40059 .56218 .39745 Metetra
.954 .806 .658 r
.56218 .39745 .56724 .40059 .57667 .37885 .57161 .37184 Metetra
.72 .727 .855 r
.57161 .37184 .57667 .37885 .58633 .37354 .5813 .36668 Metetra
.741 .738 .848 r
.5813 .36668 .58633 .37354 .59601 .36799 .59099 .36073 Metetra
.761 .733 .827 r
.59099 .36073 .59601 .36799 .60571 .36211 .60068 .35371 Metetra
.736 .697 .814 r
.60068 .35371 .60571 .36211 .61541 .35605 .6104 .34729 Metetra
.711 .681 .818 r
.6104 .34729 .61541 .35605 .62513 .34973 .62016 .34184 Metetra
.708 .701 .841 r
.62016 .34184 .62513 .34973 .63487 .34394 .62995 .33682 Metetra
.691 .717 .869 r
.62995 .33682 .63487 .34394 .64468 .33912 .6398 .33259 Metetra
.685 .735 .888 r
.6398 .33259 .64468 .33912 .65453 .33478 .64969 .32865 Metetra
.664 .741 .908 r
.64969 .32865 .65453 .33478 .66445 .33146 .65964 .32531 Metetra
.664 .741 .908 r
.65964 .32531 .66445 .33146 .67441 .32813 .66962 .32195 Metetra
.664 .741 .908 r
.66962 .32195 .67441 .32813 .6844 .32479 .67964 .31859 Metetra
.664 .741 .908 r
.67964 .31859 .6844 .32479 .69443 .32144 .68969 .31521 Metetra
.664 .741 .908 r
.68969 .31521 .69443 .32144 .70449 .31807 .69978 .31182 Metetra
.664 .741 .908 r
.69978 .31182 .70449 .31807 .71459 .31469 .7099 .30842 Metetra
.664 .741 .908 r
.7099 .30842 .71459 .31469 .72473 .3113 .72007 .30501 Metetra
.664 .741 .908 r
.72007 .30501 .72473 .3113 .7349 .3079 .73026 .30158 Metetra
.664 .741 .908 r
.73026 .30158 .7349 .3079 .74511 .30448 .7405 .29815 Metetra
.664 .741 .908 r
.7405 .29815 .74511 .30448 .75536 .30106 .75077 .2947 Metetra
.664 .741 .908 r
.75077 .2947 .75536 .30106 .76564 .29762 .76108 .29124 Metetra
.664 .741 .908 r
.76108 .29124 .76564 .29762 .77596 .29417 .77142 .28776 Metetra
.664 .741 .908 r
.77142 .28776 .77596 .29417 .78632 .2907 .7818 .28427 Metetra
.664 .741 .908 r
.7818 .28427 .78632 .2907 .79671 .28723 .79222 .28077 Metetra
.664 .741 .908 r
.79222 .28077 .79671 .28723 .80714 .28374 .80268 .27726 Metetra
.664 .741 .908 r
.80268 .27726 .80714 .28374 .81761 .28023 .81318 .27374 Metetra
.664 .741 .908 r
.81318 .27374 .81761 .28023 .82812 .27672 .82371 .2702 Metetra
.664 .741 .908 r
.82371 .2702 .82812 .27672 .83866 .27319 .83429 .26665 Metetra
.664 .741 .908 r
.83429 .26665 .83866 .27319 .84924 .26965 .8449 .26308 Metetra
.664 .741 .908 r
.8449 .26308 .84924 .26965 .85987 .2661 .85555 .25951 Metetra
.664 .741 .908 r
.24712 .45659 .25285 .46193 .26144 .45904 .25573 .45369 Metetra
.664 .741 .908 r
.25573 .45369 .26144 .45904 .27006 .45615 .26436 .45078 Metetra
.664 .741 .908 r
.26436 .45078 .27006 .45615 .27871 .45324 .27303 .44786 Metetra
.664 .741 .908 r
.27303 .44786 .27871 .45324 .28738 .45033 .28172 .44492 Metetra
.664 .741 .908 r
.28172 .44492 .28738 .45033 .29609 .4474 .29045 .44198 Metetra
.664 .741 .908 r
.29045 .44198 .29609 .4474 .30483 .44447 .2992 .43903 Metetra
.664 .741 .908 r
.2992 .43903 .30483 .44447 .31359 .44153 .30798 .43607 Metetra
.664 .741 .908 r
.30798 .43607 .31359 .44153 .32238 .43857 .31679 .4331 Metetra
.664 .741 .908 r
.31679 .4331 .32238 .43857 .3312 .43561 .32563 .43012 Metetra
.664 .741 .908 r
.32563 .43012 .3312 .43561 .34006 .43264 .3345 .42712 Metetra
.664 .741 .908 r
.3345 .42712 .34006 .43264 .34894 .42966 .3434 .42412 Metetra
.664 .741 .908 r
.3434 .42412 .34894 .42966 .35785 .42666 .35233 .42111 Metetra
.664 .741 .908 r
.35233 .42111 .35785 .42666 .36679 .42366 .36129 .41809 Metetra
.664 .741 .908 r
.36129 .41809 .36679 .42366 .37576 .42065 .37028 .41506 Metetra
.664 .741 .908 r
.37028 .41506 .37576 .42065 .38476 .41762 .3793 .41202 Metetra
.664 .741 .908 r
.3793 .41202 .38476 .41762 .39379 .41459 .38835 .40896 Metetra
.664 .741 .908 r
.38835 .40896 .39379 .41459 .40285 .41155 .39743 .4059 Metetra
.664 .741 .908 r
.39743 .4059 .40285 .41155 .41195 .40849 .40654 .40283 Metetra
.664 .741 .908 r
.40654 .40283 .41195 .40849 .42107 .40543 .41568 .39975 Metetra
.664 .741 .908 r
.41568 .39975 .42107 .40543 .43022 .40236 .42486 .39665 Metetra
.655 .739 .911 r
.42486 .39665 .43022 .40236 .43939 .39988 .43406 .39375 Metetra
.651 .723 .901 r
.43406 .39375 .43939 .39988 .44859 .39768 .44329 .39092 Metetra
.618 .69 .895 r
.44329 .39092 .44859 .39768 .45781 .39627 .45253 .38889 Metetra
.601 .664 .883 r
.45253 .38889 .45781 .39627 .46706 .3953 .4618 .38728 Metetra
.543 .62 .879 r
.4618 .38728 .46706 .3953 .47634 .39528 .4711 .38701 Metetra
.503 .593 .877 r
.4711 .38701 .47634 .39528 .48566 .39587 .48043 .38758 Metetra
.52 .602 .876 r
.48043 .38758 .48566 .39587 .49504 .39541 .48981 .38781 Metetra
.525 .626 .894 r
.48981 .38781 .49504 .39541 .50448 .39418 .49926 .38779 Metetra
.892 .481 .07 r
.49926 .38779 .50448 .39418 .5139 .41332 .50862 .41263 Metetra
.934 .584 .337 r
.50862 .41263 .5139 .41332 .52347 .45001 .51815 .45916 Metetra
.806 .435 .355 r
.51815 .45916 .52347 .45001 .53326 .46653 .52798 .48064 Metetra
.405 .049 .245 r
.52798 .48064 .53326 .46653 .54309 .46341 .5379 .47751 Metetra
.702 .761 .264 r
.5379 .47751 .54309 .46341 .55279 .44058 .54768 .44971 Metetra
.998 .822 .481 r
.54768 .44971 .55279 .44058 .56218 .39745 .55709 .39668 Metetra
.979 .819 .615 r
.55709 .39668 .56218 .39745 .57161 .37184 .56652 .3653 Metetra
.756 .752 .849 r
.56652 .3653 .57161 .37184 .5813 .36668 .57621 .35888 Metetra
.748 .716 .822 r
.57621 .35888 .5813 .36668 .59099 .36073 .58592 .35219 Metetra
.747 .699 .806 r
.58592 .35219 .59099 .36073 .60068 .35371 .59563 .34515 Metetra
.73 .693 .815 r
.59563 .34515 .60068 .35371 .6104 .34729 .60537 .33895 Metetra
.7 .687 .834 r
.60537 .33895 .6104 .34729 .62016 .34184 .61517 .33409 Metetra
.693 .7 .852 r
.61517 .33409 .62016 .34184 .62995 .33682 .625 .32966 Metetra
.672 .71 .877 r
.625 .32966 .62995 .33682 .6398 .33259 .63489 .32602 Metetra
.67 .729 .894 r
.63489 .32602 .6398 .33259 .64969 .32865 .64482 .32247 Metetra
.664 .741 .908 r
.64482 .32247 .64969 .32865 .65964 .32531 .65479 .31911 Metetra
.664 .741 .908 r
.65479 .31911 .65964 .32531 .66962 .32195 .6648 .31573 Metetra
.664 .741 .908 r
.6648 .31573 .66962 .32195 .67964 .31859 .67484 .31235 Metetra
.664 .741 .908 r
.67484 .31235 .67964 .31859 .68969 .31521 .68492 .30895 Metetra
.664 .741 .908 r
.68492 .30895 .68969 .31521 .69978 .31182 .69503 .30554 Metetra
.664 .741 .908 r
.69503 .30554 .69978 .31182 .7099 .30842 .70518 .30211 Metetra
.664 .741 .908 r
.70518 .30211 .7099 .30842 .72007 .30501 .71537 .29868 Metetra
.664 .741 .908 r
.71537 .29868 .72007 .30501 .73026 .30158 .72559 .29523 Metetra
.664 .741 .908 r
.72559 .29523 .73026 .30158 .7405 .29815 .73585 .29177 Metetra
.664 .741 .908 r
.73585 .29177 .7405 .29815 .75077 .2947 .74615 .2883 Metetra
.664 .741 .908 r
.74615 .2883 .75077 .2947 .76108 .29124 .75648 .28481 Metetra
.664 .741 .908 r
.75648 .28481 .76108 .29124 .77142 .28776 .76685 .28131 Metetra
.664 .741 .908 r
.76685 .28131 .77142 .28776 .7818 .28427 .77726 .2778 Metetra
.664 .741 .908 r
.77726 .2778 .7818 .28427 .79222 .28077 .78771 .27428 Metetra
.664 .741 .908 r
.78771 .27428 .79222 .28077 .80268 .27726 .7982 .27074 Metetra
.664 .741 .908 r
.7982 .27074 .80268 .27726 .81318 .27374 .80872 .2672 Metetra
.664 .741 .908 r
.80872 .2672 .81318 .27374 .82371 .2702 .81928 .26363 Metetra
.664 .741 .908 r
.81928 .26363 .82371 .2702 .83429 .26665 .82988 .26006 Metetra
.664 .741 .908 r
.82988 .26006 .83429 .26665 .8449 .26308 .84052 .25647 Metetra
.664 .741 .908 r
.84052 .25647 .8449 .26308 .85555 .25951 .8512 .25287 Metetra
.664 .741 .908 r
.24135 .45123 .24712 .45659 .25573 .45369 .24998 .44831 Metetra
.664 .741 .908 r
.24998 .44831 .25573 .45369 .26436 .45078 .25863 .44537 Metetra
.664 .741 .908 r
.25863 .44537 .26436 .45078 .27303 .44786 .26732 .44243 Metetra
.664 .741 .908 r
.26732 .44243 .27303 .44786 .28172 .44492 .27603 .43948 Metetra
.664 .741 .908 r
.27603 .43948 .28172 .44492 .29045 .44198 .28477 .43652 Metetra
.664 .741 .908 r
.28477 .43652 .29045 .44198 .2992 .43903 .29354 .43355 Metetra
.664 .741 .908 r
.29354 .43355 .2992 .43903 .30798 .43607 .30234 .43057 Metetra
.664 .741 .908 r
.30234 .43057 .30798 .43607 .31679 .4331 .31116 .42759 Metetra
.664 .741 .908 r
.31116 .42759 .31679 .4331 .32563 .43012 .32002 .42459 Metetra
.664 .741 .908 r
.32002 .42459 .32563 .43012 .3345 .42712 .32891 .42158 Metetra
.664 .741 .908 r
.32891 .42158 .3345 .42712 .3434 .42412 .33783 .41856 Metetra
.664 .741 .908 r
.33783 .41856 .3434 .42412 .35233 .42111 .34677 .41553 Metetra
.664 .741 .908 r
.34677 .41553 .35233 .42111 .36129 .41809 .35575 .41249 Metetra
.664 .741 .908 r
.35575 .41249 .36129 .41809 .37028 .41506 .36476 .40943 Metetra
.664 .741 .908 r
.36476 .40943 .37028 .41506 .3793 .41202 .3738 .40637 Metetra
.664 .741 .908 r
.3738 .40637 .3793 .41202 .38835 .40896 .38287 .4033 Metetra
.664 .741 .908 r
.38287 .4033 .38835 .40896 .39743 .4059 .39197 .40022 Metetra
.664 .741 .908 r
.39197 .40022 .39743 .4059 .40654 .40283 .4011 .39713 Metetra
.664 .741 .908 r
.4011 .39713 .40654 .40283 .41568 .39975 .41026 .39403 Metetra
.664 .741 .908 r
.41026 .39403 .41568 .39975 .42486 .39665 .41945 .39091 Metetra
.664 .741 .908 r
.41945 .39091 .42486 .39665 .43406 .39375 .42868 .38779 Metetra
.663 .734 .902 r
.42868 .38779 .43406 .39375 .44329 .39092 .43794 .38465 Metetra
.639 .716 .903 r
.43794 .38465 .44329 .39092 .45253 .38889 .44721 .3821 Metetra
.625 .694 .894 r
.44721 .3821 .45253 .38889 .4618 .38728 .45651 .37987 Metetra
.559 .646 .893 r
.45651 .37987 .4618 .38728 .4711 .38701 .46582 .37914 Metetra
.514 .612 .888 r
.46582 .37914 .4711 .38701 .48043 .38758 .47517 .37938 Metetra
.508 .6 .88 r
.47517 .37938 .48043 .38758 .48981 .38781 .48456 .3798 Metetra
.498 .601 .887 r
.48456 .3798 .48981 .38781 .49926 .38779 .49401 .38035 Metetra
.915 .526 .123 r
.49401 .38035 .49926 .38779 .50862 .41263 .50331 .41045 Metetra
.946 .606 .345 r
.50331 .41045 .50862 .41263 .51815 .45916 .51275 .46656 Metetra
.843 .473 .352 r
.51275 .46656 .51815 .45916 .52798 .48064 .5226 .49292 Metetra
.378 .003 .195 r
.5226 .49292 .52798 .48064 .5379 .47751 .53259 .48979 Metetra
.884 .851 .395 r
.53259 .48979 .5379 .47751 .54768 .44971 .54247 .45708 Metetra
.999 .797 .493 r
.54247 .45708 .54768 .44971 .55709 .39668 .55195 .3944 Metetra
.971 .788 .6 r
.55195 .3944 .55709 .39668 .56652 .3653 .56139 .35771 Metetra
.758 .724 .822 r
.56139 .35771 .56652 .3653 .57621 .35888 .5711 .35066 Metetra
.748 .707 .813 r
.5711 .35066 .57621 .35888 .58592 .35219 .58082 .34374 Metetra
.742 .7 .811 r
.58082 .34374 .58592 .35219 .59563 .34515 .59056 .33699 Metetra
.725 .701 .828 r
.59056 .33699 .59563 .34515 .60537 .33895 .60033 .3312 Metetra
.688 .699 .855 r
.60033 .3312 .60537 .33895 .61517 .33409 .61016 .32694 Metetra
.682 .715 .874 r
.61016 .32694 .61517 .33409 .625 .32966 .62004 .32299 Metetra
.663 .724 .894 r
.62004 .32299 .625 .32966 .63489 .32602 .62996 .31962 Metetra
.663 .734 .902 r
.62996 .31962 .63489 .32602 .64482 .32247 .63992 .31625 Metetra
.664 .741 .908 r
.63992 .31625 .64482 .32247 .65479 .31911 .64992 .31287 Metetra
.664 .741 .908 r
.64992 .31287 .65479 .31911 .6648 .31573 .65995 .30947 Metetra
.664 .741 .908 r
.65995 .30947 .6648 .31573 .67484 .31235 .67001 .30606 Metetra
.664 .741 .908 r
.67001 .30606 .67484 .31235 .68492 .30895 .68012 .30264 Metetra
.664 .741 .908 r
.68012 .30264 .68492 .30895 .69503 .30554 .69025 .29921 Metetra
.664 .741 .908 r
.69025 .29921 .69503 .30554 .70518 .30211 .70043 .29576 Metetra
.664 .741 .908 r
.70043 .29576 .70518 .30211 .71537 .29868 .71064 .2923 Metetra
.664 .741 .908 r
.71064 .2923 .71537 .29868 .72559 .29523 .72089 .28883 Metetra
.664 .741 .908 r
.72089 .28883 .72559 .29523 .73585 .29177 .73118 .28535 Metetra
.664 .741 .908 r
.73118 .28535 .73585 .29177 .74615 .2883 .7415 .28185 Metetra
.664 .741 .908 r
.7415 .28185 .74615 .2883 .75648 .28481 .75186 .27834 Metetra
.664 .741 .908 r
.75186 .27834 .75648 .28481 .76685 .28131 .76226 .27482 Metetra
.664 .741 .908 r
.76226 .27482 .76685 .28131 .77726 .2778 .77269 .27129 Metetra
.664 .741 .908 r
.77269 .27129 .77726 .2778 .78771 .27428 .78317 .26774 Metetra
.664 .741 .908 r
.78317 .26774 .78771 .27428 .7982 .27074 .79368 .26418 Metetra
.664 .741 .908 r
.79368 .26418 .7982 .27074 .80872 .2672 .80423 .26061 Metetra
.664 .741 .908 r
.80423 .26061 .80872 .2672 .81928 .26363 .81482 .25702 Metetra
.664 .741 .908 r
.81482 .25702 .81928 .26363 .82988 .26006 .82545 .25342 Metetra
.664 .741 .908 r
.82545 .25342 .82988 .26006 .84052 .25647 .83611 .24981 Metetra
.664 .741 .908 r
.83611 .24981 .84052 .25647 .8512 .25287 .84682 .24619 Metetra
.664 .741 .908 r
.23555 .44583 .24135 .45123 .24998 .44831 .2442 .44289 Metetra
.664 .741 .908 r
.2442 .44289 .24998 .44831 .25863 .44537 .25287 .43994 Metetra
.664 .741 .908 r
.25287 .43994 .25863 .44537 .26732 .44243 .26157 .43698 Metetra
.664 .741 .908 r
.26157 .43698 .26732 .44243 .27603 .43948 .2703 .43401 Metetra
.664 .741 .908 r
.2703 .43401 .27603 .43948 .28477 .43652 .27905 .43103 Metetra
.664 .741 .908 r
.27905 .43103 .28477 .43652 .29354 .43355 .28784 .42805 Metetra
.664 .741 .908 r
.28784 .42805 .29354 .43355 .30234 .43057 .29666 .42505 Metetra
.664 .741 .908 r
.29666 .42505 .30234 .43057 .31116 .42759 .3055 .42204 Metetra
.664 .741 .908 r
.3055 .42204 .31116 .42759 .32002 .42459 .31438 .41902 Metetra
.664 .741 .908 r
.31438 .41902 .32002 .42459 .32891 .42158 .32328 .41599 Metetra
.664 .741 .908 r
.32328 .41599 .32891 .42158 .33783 .41856 .33222 .41295 Metetra
.664 .741 .908 r
.33222 .41295 .33783 .41856 .34677 .41553 .34119 .4099 Metetra
.664 .741 .908 r
.34119 .4099 .34677 .41553 .35575 .41249 .35018 .40685 Metetra
.664 .741 .908 r
.35018 .40685 .35575 .41249 .36476 .40943 .35921 .40378 Metetra
.664 .741 .908 r
.35921 .40378 .36476 .40943 .3738 .40637 .36827 .4007 Metetra
.664 .741 .908 r
.36827 .4007 .3738 .40637 .38287 .4033 .37736 .39761 Metetra
.664 .741 .908 r
.37736 .39761 .38287 .4033 .39197 .40022 .38647 .3945 Metetra
.664 .741 .908 r
.38647 .3945 .39197 .40022 .4011 .39713 .39562 .39139 Metetra
.664 .741 .908 r
.39562 .39139 .4011 .39713 .41026 .39403 .40481 .38827 Metetra
.664 .741 .908 r
.40481 .38827 .41026 .39403 .41945 .39091 .41402 .38514 Metetra
.664 .741 .908 r
.41402 .38514 .41945 .39091 .42868 .38779 .42326 .38199 Metetra
.664 .741 .908 r
.42326 .38199 .42868 .38779 .43794 .38465 .43254 .37884 Metetra
.655 .739 .911 r
.43254 .37884 .43794 .38465 .44721 .3821 .44184 .37588 Metetra
.65 .723 .902 r
.44184 .37588 .44721 .3821 .45651 .37987 .45118 .37301 Metetra
.584 .677 .904 r
.45118 .37301 .45651 .37987 .46582 .37914 .46052 .37166 Metetra
.541 .638 .896 r
.46052 .37166 .46582 .37914 .47517 .37938 .46988 .37126 Metetra
.52 .609 .882 r
.46988 .37126 .47517 .37938 .48456 .3798 .47928 .3714 Metetra
.503 .593 .877 r
.47928 .3714 .48456 .3798 .49401 .38035 .48874 .37193 Metetra
.929 .556 .157 r
.48874 .37193 .49401 .38035 .50331 .41045 .49796 .40683 Metetra
.953 .622 .352 r
.49796 .40683 .50331 .41045 .51275 .46656 .50728 .47229 Metetra
.872 .504 .349 r
.50728 .47229 .51275 .46656 .5226 .49292 .51713 .50344 Metetra
.343 0 .132 r
.51713 .50344 .5226 .49292 .53259 .48979 .5272 .5003 Metetra
.963 .867 .465 r
.5272 .5003 .53259 .48979 .54247 .45708 .53717 .46277 Metetra
.994 .777 .497 r
.53717 .46277 .54247 .45708 .55195 .3944 .54674 .39069 Metetra
.964 .766 .588 r
.54674 .39069 .55195 .3944 .56139 .35771 .55623 .34913 Metetra
.747 .699 .806 r
.55623 .34913 .56139 .35771 .5711 .35066 .56595 .34206 Metetra
.739 .696 .81 r
.56595 .34206 .5711 .35066 .58082 .34374 .5757 .33538 Metetra
.731 .699 .82 r
.5757 .33538 .58082 .34374 .59056 .33699 .58547 .32922 Metetra
.713 .708 .844 r
.58547 .32922 .59056 .33699 .60033 .3312 .59528 .32402 Metetra
.672 .711 .877 r
.59528 .32402 .60033 .3312 .61016 .32694 .60515 .32035 Metetra
.671 .73 .894 r
.60515 .32035 .61016 .32694 .62004 .32299 .61506 .31677 Metetra
.664 .741 .908 r
.61506 .31677 .62004 .32299 .62996 .31962 .62501 .31339 Metetra
.664 .741 .908 r
.62501 .31339 .62996 .31962 .63992 .31625 .63499 .30999 Metetra
.664 .741 .908 r
.63499 .30999 .63992 .31625 .64992 .31287 .64501 .30659 Metetra
.664 .741 .908 r
.64501 .30659 .64992 .31287 .65995 .30947 .65506 .30317 Metetra
.664 .741 .908 r
.65506 .30317 .65995 .30947 .67001 .30606 .66515 .29974 Metetra
.664 .741 .908 r
.66515 .29974 .67001 .30606 .68012 .30264 .67528 .29629 Metetra
.664 .741 .908 r
.67528 .29629 .68012 .30264 .69025 .29921 .68545 .29284 Metetra
.664 .741 .908 r
.68545 .29284 .69025 .29921 .70043 .29576 .69565 .28937 Metetra
.664 .741 .908 r
.69565 .28937 .70043 .29576 .71064 .2923 .70588 .28589 Metetra
.664 .741 .908 r
.70588 .28589 .71064 .2923 .72089 .28883 .71616 .28239 Metetra
.664 .741 .908 r
.71616 .28239 .72089 .28883 .73118 .28535 .72647 .27888 Metetra
.664 .741 .908 r
.72647 .27888 .73118 .28535 .7415 .28185 .73682 .27537 Metetra
.664 .741 .908 r
.73682 .27537 .7415 .28185 .75186 .27834 .7472 .27183 Metetra
.664 .741 .908 r
.7472 .27183 .75186 .27834 .76226 .27482 .75763 .26829 Metetra
.664 .741 .908 r
.75763 .26829 .76226 .27482 .77269 .27129 .76809 .26473 Metetra
.664 .741 .908 r
.76809 .26473 .77269 .27129 .78317 .26774 .77859 .26116 Metetra
.664 .741 .908 r
.77859 .26116 .78317 .26774 .79368 .26418 .78913 .25758 Metetra
.664 .741 .908 r
.78913 .25758 .79368 .26418 .80423 .26061 .79971 .25398 Metetra
.664 .741 .908 r
.79971 .25398 .80423 .26061 .81482 .25702 .81032 .25037 Metetra
.664 .741 .908 r
.81032 .25037 .81482 .25702 .82545 .25342 .82098 .24674 Metetra
.664 .741 .908 r
.82098 .24674 .82545 .25342 .83611 .24981 .83168 .24311 Metetra
.664 .741 .908 r
.83168 .24311 .83611 .24981 .84682 .24619 .84241 .23946 Metetra
.664 .741 .908 r
.22972 .44039 .23555 .44583 .2442 .44289 .23838 .43744 Metetra
.664 .741 .908 r
.23838 .43744 .2442 .44289 .25287 .43994 .24707 .43447 Metetra
.664 .741 .908 r
.24707 .43447 .25287 .43994 .26157 .43698 .25578 .43149 Metetra
.664 .741 .908 r
.25578 .43149 .26157 .43698 .2703 .43401 .26453 .42851 Metetra
.664 .741 .908 r
.26453 .42851 .2703 .43401 .27905 .43103 .2733 .42551 Metetra
.664 .741 .908 r
.2733 .42551 .27905 .43103 .28784 .42805 .28211 .4225 Metetra
.664 .741 .908 r
.28211 .4225 .28784 .42805 .29666 .42505 .29094 .41949 Metetra
.664 .741 .908 r
.29094 .41949 .29666 .42505 .3055 .42204 .29981 .41646 Metetra
.664 .741 .908 r
.29981 .41646 .3055 .42204 .31438 .41902 .3087 .41342 Metetra
.664 .741 .908 r
.3087 .41342 .31438 .41902 .32328 .41599 .31762 .41037 Metetra
.664 .741 .908 r
.31762 .41037 .32328 .41599 .33222 .41295 .32658 .40732 Metetra
.664 .741 .908 r
.32658 .40732 .33222 .41295 .34119 .4099 .33556 .40425 Metetra
.664 .741 .908 r
.33556 .40425 .34119 .4099 .35018 .40685 .34458 .40117 Metetra
.664 .741 .908 r
.34458 .40117 .35018 .40685 .35921 .40378 .35362 .39808 Metetra
.664 .741 .908 r
.35362 .39808 .35921 .40378 .36827 .4007 .3627 .39498 Metetra
.664 .741 .908 r
.3627 .39498 .36827 .4007 .37736 .39761 .37181 .39187 Metetra
.664 .741 .908 r
.37181 .39187 .37736 .39761 .38647 .3945 .38095 .38875 Metetra
.664 .741 .908 r
.38095 .38875 .38647 .3945 .39562 .39139 .39012 .38562 Metetra
.664 .741 .908 r
.39012 .38562 .39562 .39139 .40481 .38827 .39932 .38248 Metetra
.664 .741 .908 r
.39932 .38248 .40481 .38827 .41402 .38514 .40855 .37932 Metetra
.664 .741 .908 r
.40855 .37932 .41402 .38514 .42326 .38199 .41781 .37616 Metetra
.664 .741 .908 r
.41781 .37616 .42326 .38199 .43254 .37884 .42711 .37299 Metetra
.664 .741 .908 r
.42711 .37299 .43254 .37884 .44184 .37588 .43644 .3698 Metetra
.663 .734 .902 r
.43644 .3698 .44184 .37588 .45118 .37301 .4458 .3666 Metetra
.614 .706 .91 r
.4458 .3666 .45118 .37301 .46052 .37166 .45517 .36455 Metetra
.583 .67 .899 r
.45517 .36455 .46052 .37166 .46988 .37126 .46456 .36323 Metetra
.192 .43 .861 r
.46456 .36323 .46988 .37126 .47928 .3714 .4739 .36797 Metetra
.629 .086 0 r
.4739 .36797 .47928 .3714 .48874 .37193 .48327 .37717 Metetra
.885 .527 .364 r
.48327 .37717 .48874 .37193 .49796 .40683 .49248 .41184 Metetra
.918 .584 .394 r
.49248 .41184 .49796 .40683 .50728 .47229 .5018 .4692 Metetra
.907 .499 .183 r
.5018 .4692 .50728 .47229 .51713 .50344 .51164 .49617 Metetra
.652 .707 .887 r
.51164 .49617 .51713 .50344 .5272 .5003 .52173 .49301 Metetra
.928 .743 .631 r
.52173 .49301 .5272 .5003 .53717 .46277 .53179 .45962 Metetra
.97 .745 .544 r
.53179 .45962 .53717 .46277 .54674 .39069 .54154 .39564 Metetra
.999 .837 .536 r
.54154 .39564 .54674 .39069 .55623 .34913 .55115 .35428 Metetra
.831 .944 .584 r
.55115 .35428 .55623 .34913 .56595 .34206 .56084 .33845 Metetra
.88 .859 .815 r
.56084 .33845 .56595 .34206 .5757 .33538 .57055 .32709 Metetra
.711 .695 .833 r
.57055 .32709 .5757 .33538 .58547 .32922 .58036 .32183 Metetra
.698 .714 .862 r
.58036 .32183 .58547 .32922 .59528 .32402 .59021 .31729 Metetra
.663 .723 .894 r
.59021 .31729 .59528 .32402 .60515 .32035 .60011 .31391 Metetra
.663 .734 .902 r
.60011 .31391 .60515 .32035 .61506 .31677 .61004 .31052 Metetra
.664 .741 .908 r
.61004 .31052 .61506 .31677 .62501 .31339 .62002 .30711 Metetra
.664 .741 .908 r
.62002 .30711 .62501 .31339 .63499 .30999 .63002 .30369 Metetra
.664 .741 .908 r
.63002 .30369 .63499 .30999 .64501 .30659 .64007 .30026 Metetra
.664 .741 .908 r
.64007 .30026 .64501 .30659 .65506 .30317 .65015 .29682 Metetra
.664 .741 .908 r
.65015 .29682 .65506 .30317 .66515 .29974 .66026 .29337 Metetra
.664 .741 .908 r
.66026 .29337 .66515 .29974 .67528 .29629 .67041 .2899 Metetra
.664 .741 .908 r
.67041 .2899 .67528 .29629 .68545 .29284 .6806 .28642 Metetra
.664 .741 .908 r
.6806 .28642 .68545 .29284 .69565 .28937 .69083 .28293 Metetra
.664 .741 .908 r
.69083 .28293 .69565 .28937 .70588 .28589 .70109 .27942 Metetra
.664 .741 .908 r
.70109 .27942 .70588 .28589 .71616 .28239 .71139 .27591 Metetra
.664 .741 .908 r
.71139 .27591 .71616 .28239 .72647 .27888 .72173 .27238 Metetra
.664 .741 .908 r
.72173 .27238 .72647 .27888 .73682 .27537 .7321 .26883 Metetra
.664 .741 .908 r
.7321 .26883 .73682 .27537 .7472 .27183 .74252 .26528 Metetra
.664 .741 .908 r
.74252 .26528 .7472 .27183 .75763 .26829 .75297 .26171 Metetra
.664 .741 .908 r
.75297 .26171 .75763 .26829 .76809 .26473 .76346 .25813 Metetra
.664 .741 .908 r
.76346 .25813 .76809 .26473 .77859 .26116 .77399 .25453 Metetra
.664 .741 .908 r
.77399 .25453 .77859 .26116 .78913 .25758 .78455 .25092 Metetra
.664 .741 .908 r
.78455 .25092 .78913 .25758 .79971 .25398 .79516 .2473 Metetra
.664 .741 .908 r
.79516 .2473 .79971 .25398 .81032 .25037 .8058 .24367 Metetra
.664 .741 .908 r
.8058 .24367 .81032 .25037 .82098 .24674 .81649 .24002 Metetra
.664 .741 .908 r
.81649 .24002 .82098 .24674 .83168 .24311 .82721 .23636 Metetra
.664 .741 .908 r
.82721 .23636 .83168 .24311 .84241 .23946 .83797 .23268 Metetra
.664 .741 .908 r
.22385 .43493 .22972 .44039 .23838 .43744 .23252 .43195 Metetra
.664 .741 .908 r
.23252 .43195 .23838 .43744 .24707 .43447 .24123 .42897 Metetra
.664 .741 .908 r
.24123 .42897 .24707 .43447 .25578 .43149 .24996 .42597 Metetra
.664 .741 .908 r
.24996 .42597 .25578 .43149 .26453 .42851 .25873 .42297 Metetra
.664 .741 .908 r
.25873 .42297 .26453 .42851 .2733 .42551 .26752 .41995 Metetra
.664 .741 .908 r
.26752 .41995 .2733 .42551 .28211 .4225 .27634 .41693 Metetra
.664 .741 .908 r
.27634 .41693 .28211 .4225 .29094 .41949 .28519 .41389 Metetra
.664 .741 .908 r
.28519 .41389 .29094 .41949 .29981 .41646 .29407 .41084 Metetra
.664 .741 .908 r
.29407 .41084 .29981 .41646 .3087 .41342 .30299 .40779 Metetra
.664 .741 .908 r
.30299 .40779 .3087 .41342 .31762 .41037 .31193 .40472 Metetra
.664 .741 .908 r
.31193 .40472 .31762 .41037 .32658 .40732 .3209 .40164 Metetra
.664 .741 .908 r
.3209 .40164 .32658 .40732 .33556 .40425 .3299 .39856 Metetra
.664 .741 .908 r
.3299 .39856 .33556 .40425 .34458 .40117 .33894 .39546 Metetra
.664 .741 .908 r
.33894 .39546 .34458 .40117 .35362 .39808 .348 .39235 Metetra
.664 .741 .908 r
.348 .39235 .35362 .39808 .3627 .39498 .3571 .38923 Metetra
.664 .741 .908 r
.3571 .38923 .3627 .39498 .37181 .39187 .36622 .3861 Metetra
.664 .741 .908 r
.36622 .3861 .37181 .39187 .38095 .38875 .37538 .38296 Metetra
.664 .741 .908 r
.37538 .38296 .38095 .38875 .39012 .38562 .38457 .37981 Metetra
.664 .741 .908 r
.38457 .37981 .39012 .38562 .39932 .38248 .39379 .37665 Metetra
.664 .741 .908 r
.39379 .37665 .39932 .38248 .40855 .37932 .40305 .37348 Metetra
.664 .741 .908 r
.40305 .37348 .40855 .37932 .41781 .37616 .41233 .37029 Metetra
.664 .741 .908 r
.41233 .37029 .41781 .37616 .42711 .37299 .42165 .3671 Metetra
.664 .741 .908 r
.42165 .3671 .42711 .37299 .43644 .3698 .431 .36389 Metetra
.664 .741 .908 r
.431 .36389 .43644 .3698 .4458 .3666 .44038 .36067 Metetra
.646 .736 .914 r
.44038 .36067 .4458 .3666 .45517 .36455 .44978 .35786 Metetra
.636 .706 .897 r
.44978 .35786 .45517 .36455 .46456 .36323 .45922 .35529 Metetra
.636 .204 0 r
.45922 .35529 .46456 .36323 .4739 .36797 .46838 .36987 Metetra
.888 .505 .304 r
.46838 .36987 .4739 .36797 .48327 .37717 .4775 .39735 Metetra
.777 .45 .434 r
.4775 .39735 .48327 .37717 .49248 .41184 .48682 .42628 Metetra
.813 .471 .409 r
.48682 .42628 .49248 .41184 .5018 .4692 .49635 .45661 Metetra
0 .08 .637 r
.49635 .45661 .5018 .4692 .51164 .49617 .50622 .4699 Metetra
.597 .461 .666 r
.50622 .4699 .51164 .49617 .52173 .49301 .51627 .4667 Metetra
.743 .556 .641 r
.51627 .4667 .52173 .49301 .53179 .45962 .52635 .44696 Metetra
.897 .693 .618 r
.52635 .44696 .53179 .45962 .54154 .39564 .53631 .41005 Metetra
.853 .82 .34 r
.53631 .41005 .54154 .39564 .55115 .35428 .5461 .37444 Metetra
.5461 .37444 .55115 .35428 .56084 .33845 .55574 .34022 Metetra
.978 .914 .659 r
.55574 .34022 .56084 .33845 .57055 .32709 .56538 .3189 Metetra
.678 .686 .85 r
.56538 .3189 .57055 .32709 .58036 .32183 .57523 .31484 Metetra
.677 .721 .882 r
.57523 .31484 .58036 .32183 .59021 .31729 .58511 .31104 Metetra
.664 .741 .908 r
.58511 .31104 .59021 .31729 .60011 .31391 .59504 .30764 Metetra
.664 .741 .908 r
.59504 .30764 .60011 .31391 .61004 .31052 .605 .30422 Metetra
.664 .741 .908 r
.605 .30422 .61004 .31052 .62002 .30711 .61499 .30079 Metetra
.664 .741 .908 r
.61499 .30079 .62002 .30711 .63002 .30369 .62503 .29735 Metetra
.664 .741 .908 r
.62503 .29735 .63002 .30369 .64007 .30026 .63509 .2939 Metetra
.664 .741 .908 r
.63509 .2939 .64007 .30026 .65015 .29682 .6452 .29044 Metetra
.664 .741 .908 r
.6452 .29044 .65015 .29682 .66026 .29337 .65534 .28696 Metetra
.664 .741 .908 r
.65534 .28696 .66026 .29337 .67041 .2899 .66552 .28347 Metetra
.664 .741 .908 r
.66552 .28347 .67041 .2899 .6806 .28642 .67573 .27996 Metetra
.664 .741 .908 r
.67573 .27996 .6806 .28642 .69083 .28293 .68598 .27645 Metetra
.664 .741 .908 r
.68598 .27645 .69083 .28293 .70109 .27942 .69627 .27292 Metetra
.664 .741 .908 r
.69627 .27292 .70109 .27942 .71139 .27591 .70659 .26938 Metetra
.664 .741 .908 r
.70659 .26938 .71139 .27591 .72173 .27238 .71696 .26583 Metetra
.664 .741 .908 r
.71696 .26583 .72173 .27238 .7321 .26883 .72736 .26226 Metetra
.664 .741 .908 r
.72736 .26226 .7321 .26883 .74252 .26528 .7378 .25868 Metetra
.664 .741 .908 r
.7378 .25868 .74252 .26528 .75297 .26171 .74828 .25509 Metetra
.664 .741 .908 r
.74828 .25509 .75297 .26171 .76346 .25813 .75879 .25148 Metetra
.664 .741 .908 r
.75879 .25148 .76346 .25813 .77399 .25453 .76935 .24786 Metetra
.664 .741 .908 r
.76935 .24786 .77399 .25453 .78455 .25092 .77994 .24423 Metetra
.664 .741 .908 r
.77994 .24423 .78455 .25092 .79516 .2473 .79057 .24058 Metetra
.664 .741 .908 r
.79057 .24058 .79516 .2473 .8058 .24367 .80125 .23692 Metetra
.664 .741 .908 r
.80125 .23692 .8058 .24367 .81649 .24002 .81196 .23325 Metetra
.664 .741 .908 r
.81196 .23325 .81649 .24002 .82721 .23636 .82271 .22956 Metetra
.664 .741 .908 r
.82271 .22956 .82721 .23636 .83797 .23268 .8335 .22586 Metetra
.664 .741 .908 r
.21794 .42943 .22385 .43493 .23252 .43195 .22663 .42643 Metetra
.664 .741 .908 r
.22663 .42643 .23252 .43195 .24123 .42897 .23535 .42343 Metetra
.664 .741 .908 r
.23535 .42343 .24123 .42897 .24996 .42597 .24411 .42042 Metetra
.664 .741 .908 r
.24411 .42042 .24996 .42597 .25873 .42297 .25289 .41739 Metetra
.664 .741 .908 r
.25289 .41739 .25873 .42297 .26752 .41995 .2617 .41436 Metetra
.664 .741 .908 r
.2617 .41436 .26752 .41995 .27634 .41693 .27054 .41131 Metetra
.664 .741 .908 r
.27054 .41131 .27634 .41693 .28519 .41389 .27941 .40826 Metetra
.664 .741 .908 r
.27941 .40826 .28519 .41389 .29407 .41084 .28831 .40519 Metetra
.664 .741 .908 r
.28831 .40519 .29407 .41084 .30299 .40779 .29724 .40212 Metetra
.664 .741 .908 r
.29724 .40212 .30299 .40779 .31193 .40472 .3062 .39903 Metetra
.664 .741 .908 r
.3062 .39903 .31193 .40472 .3209 .40164 .31519 .39594 Metetra
.664 .741 .908 r
.31519 .39594 .3209 .40164 .3299 .39856 .32421 .39283 Metetra
.664 .741 .908 r
.32421 .39283 .3299 .39856 .33894 .39546 .33326 .38971 Metetra
.664 .741 .908 r
.33326 .38971 .33894 .39546 .348 .39235 .34235 .38658 Metetra
.664 .741 .908 r
.34235 .38658 .348 .39235 .3571 .38923 .35146 .38345 Metetra
.664 .741 .908 r
.35146 .38345 .3571 .38923 .36622 .3861 .36061 .3803 Metetra
.664 .741 .908 r
.36061 .3803 .36622 .3861 .37538 .38296 .36978 .37714 Metetra
.664 .741 .908 r
.36978 .37714 .37538 .38296 .38457 .37981 .37899 .37396 Metetra
.664 .741 .908 r
.37899 .37396 .38457 .37981 .39379 .37665 .38823 .37078 Metetra
.664 .741 .908 r
.38823 .37078 .39379 .37665 .40305 .37348 .39751 .36759 Metetra
.664 .741 .908 r
.39751 .36759 .40305 .37348 .41233 .37029 .40681 .36438 Metetra
.664 .741 .908 r
.40681 .36438 .41233 .37029 .42165 .3671 .41615 .36117 Metetra
.664 .741 .908 r
.41615 .36117 .42165 .3671 .431 .36389 .42552 .35794 Metetra
.664 .741 .908 r
.42552 .35794 .431 .36389 .44038 .36067 .43492 .3547 Metetra
.61 .723 .926 r
.43492 .3547 .44038 .36067 .44978 .35786 .44432 .35264 Metetra
.558 .735 .958 r
.44432 .35264 .44978 .35786 .45922 .35529 .45375 .35132 Metetra
.898 .48 .142 r
.45375 .35132 .45922 .35529 .46838 .36987 .46275 .37434 Metetra
.902 .554 .375 r
.46275 .37434 .46838 .36987 .4775 .39735 .47164 .41596 Metetra
.751 .416 .416 r
.47164 .41596 .4775 .39735 .48682 .42628 .48108 .43826 Metetra
.609 .225 .29 r
.48108 .43826 .48682 .42628 .49635 .45661 .49089 .44391 Metetra
.51 .515 .797 r
.49089 .44391 .49635 .45661 .50622 .4699 .50083 .44499 Metetra
.599 .467 .672 r
.50083 .44499 .50622 .4699 .51627 .4667 .51085 .44175 Metetra
.65 .5 .667 r
.51085 .44175 .51627 .4667 .52635 .44696 .5209 .43417 Metetra
.774 .65 .724 r
.5209 .43417 .52635 .44696 .53631 .41005 .53096 .422 Metetra
.832 .841 .375 r
.53096 .422 .53631 .41005 .5461 .37444 .54092 .39304 Metetra
.884 .798 .311 r
.54092 .39304 .5461 .37444 .55574 .34022 .55059 .34456 Metetra
.991 .883 .57 r
.55059 .34456 .55574 .34022 .56538 .3189 .56023 .31471 Metetra
.741 .842 .927 r
.56023 .31471 .56538 .3189 .57523 .31484 .57009 .30936 Metetra
.71 .785 .91 r
.57009 .30936 .57523 .31484 .58511 .31104 .57999 .30475 Metetra
.664 .741 .908 r
.57999 .30475 .58511 .31104 .59504 .30764 .58994 .30132 Metetra
.664 .741 .908 r
.58994 .30132 .59504 .30764 .605 .30422 .59992 .29788 Metetra
.664 .741 .908 r
.59992 .29788 .605 .30422 .61499 .30079 .60994 .29443 Metetra
.664 .741 .908 r
.60994 .29443 .61499 .30079 .62503 .29735 .61999 .29097 Metetra
.664 .741 .908 r
.61999 .29097 .62503 .29735 .63509 .2939 .63009 .28749 Metetra
.664 .741 .908 r
.63009 .28749 .63509 .2939 .6452 .29044 .64022 .28401 Metetra
.664 .741 .908 r
.64022 .28401 .6452 .29044 .65534 .28696 .65038 .2805 Metetra
.664 .741 .908 r
.65038 .2805 .65534 .28696 .66552 .28347 .66058 .27699 Metetra
.664 .741 .908 r
.66058 .27699 .66552 .28347 .67573 .27996 .67082 .27347 Metetra
.664 .741 .908 r
.67082 .27347 .67573 .27996 .68598 .27645 .6811 .26993 Metetra
.664 .741 .908 r
.6811 .26993 .68598 .27645 .69627 .27292 .69141 .26637 Metetra
.664 .741 .908 r
.69141 .26637 .69627 .27292 .70659 .26938 .70176 .26281 Metetra
.664 .741 .908 r
.70176 .26281 .70659 .26938 .71696 .26583 .71215 .25923 Metetra
.664 .741 .908 r
.71215 .25923 .71696 .26583 .72736 .26226 .72258 .25564 Metetra
.664 .741 .908 r
.72258 .25564 .72736 .26226 .7378 .25868 .73305 .25204 Metetra
.664 .741 .908 r
.73305 .25204 .7378 .25868 .74828 .25509 .74355 .24842 Metetra
.664 .741 .908 r
.74355 .24842 .74828 .25509 .75879 .25148 .7541 .24479 Metetra
.664 .741 .908 r
.7541 .24479 .75879 .25148 .76935 .24786 .76468 .24114 Metetra
.664 .741 .908 r
.76468 .24114 .76935 .24786 .77994 .24423 .7753 .23749 Metetra
.664 .741 .908 r
.7753 .23749 .77994 .24423 .79057 .24058 .78596 .23381 Metetra
.664 .741 .908 r
.78596 .23381 .79057 .24058 .80125 .23692 .79666 .23013 Metetra
.664 .741 .908 r
.79666 .23013 .80125 .23692 .81196 .23325 .8074 .22643 Metetra
.664 .741 .908 r
.8074 .22643 .81196 .23325 .82271 .22956 .81818 .22272 Metetra
.664 .741 .908 r
.81818 .22272 .82271 .22956 .8335 .22586 .829 .21899 Metetra
.664 .741 .908 r
.212 .42389 .21794 .42943 .22663 .42643 .22071 .42088 Metetra
.664 .741 .908 r
.22071 .42088 .22663 .42643 .23535 .42343 .22944 .41786 Metetra
.664 .741 .908 r
.22944 .41786 .23535 .42343 .24411 .42042 .23821 .41482 Metetra
.664 .741 .908 r
.23821 .41482 .24411 .42042 .25289 .41739 .24701 .41178 Metetra
.664 .741 .908 r
.24701 .41178 .25289 .41739 .2617 .41436 .25584 .40873 Metetra
.664 .741 .908 r
.25584 .40873 .2617 .41436 .27054 .41131 .2647 .40567 Metetra
.664 .741 .908 r
.2647 .40567 .27054 .41131 .27941 .40826 .27358 .40259 Metetra
.664 .741 .908 r
.27358 .40259 .27941 .40826 .28831 .40519 .2825 .39951 Metetra
.664 .741 .908 r
.2825 .39951 .28831 .40519 .29724 .40212 .29145 .39641 Metetra
.664 .741 .908 r
.29145 .39641 .29724 .40212 .3062 .39903 .30043 .39331 Metetra
.664 .741 .908 r
.30043 .39331 .3062 .39903 .31519 .39594 .30944 .39019 Metetra
.664 .741 .908 r
.30944 .39019 .31519 .39594 .32421 .39283 .31848 .38707 Metetra
.664 .741 .908 r
.31848 .38707 .32421 .39283 .33326 .38971 .32755 .38393 Metetra
.664 .741 .908 r
.32755 .38393 .33326 .38971 .34235 .38658 .33665 .38078 Metetra
.664 .741 .908 r
.33665 .38078 .34235 .38658 .35146 .38345 .34579 .37762 Metetra
.664 .741 .908 r
.34579 .37762 .35146 .38345 .36061 .3803 .35495 .37445 Metetra
.664 .741 .908 r
.35495 .37445 .36061 .3803 .36978 .37714 .36415 .37127 Metetra
.664 .741 .908 r
.36415 .37127 .36978 .37714 .37899 .37396 .37338 .36808 Metetra
.664 .741 .908 r
.37338 .36808 .37899 .37396 .38823 .37078 .38264 .36488 Metetra
.664 .741 .908 r
.38264 .36488 .38823 .37078 .39751 .36759 .39193 .36166 Metetra
.664 .741 .908 r
.39193 .36166 .39751 .36759 .40681 .36438 .40126 .35844 Metetra
.664 .741 .908 r
.40126 .35844 .40681 .36438 .41615 .36117 .41061 .3552 Metetra
.664 .741 .908 r
.41061 .3552 .41615 .36117 .42552 .35794 .42 .35196 Metetra
.664 .741 .908 r
.42 .35196 .42552 .35794 .43492 .3547 .42943 .3487 Metetra
.443 .652 .948 r
.42943 .3487 .43492 .3547 .44432 .35264 .43878 .34924 Metetra
0 .48 .848 r
.43878 .34924 .44432 .35264 .45375 .35132 .44813 .35222 Metetra
.901 .523 .305 r
.44813 .35222 .45375 .35132 .46275 .37434 .45698 .38197 Metetra
.898 .564 .405 r
.45698 .38197 .46275 .37434 .47164 .41596 .46569 .43248 Metetra
.706 .357 .384 r
.46569 .43248 .47164 .41596 .48108 .43826 .4753 .4471 Metetra
.624 .816 .401 r
.4753 .4471 .48108 .43826 .49089 .44391 .48542 .43107 Metetra
.741 .633 .74 r
.48542 .43107 .49089 .44391 .50083 .44499 .49545 .42165 Metetra
.602 .475 .68 r
.49545 .42165 .50083 .44499 .51085 .44175 .50543 .41837 Metetra
.499 .408 .684 r
.50543 .41837 .51085 .44175 .5209 .43417 .51544 .42125 Metetra
.103 .26 .74 r
.51544 .42125 .5209 .43417 .53096 .422 .52552 .43078 Metetra
.799 .878 .448 r
.52552 .43078 .53096 .422 .54092 .39304 .53562 .40954 Metetra
.963 .818 .388 r
.53562 .40954 .54092 .39304 .55059 .34456 .5454 .35208 Metetra
.986 .866 .503 r
.5454 .35208 .55059 .34456 .56023 .31471 .55509 .31543 Metetra
.834 .998 .832 r
.55509 .31543 .56023 .31471 .57009 .30936 .56494 .3057 Metetra
.803 .873 .898 r
.56494 .3057 .57009 .30936 .57999 .30475 .57483 .29841 Metetra
.664 .741 .908 r
.57483 .29841 .57999 .30475 .58994 .30132 .5848 .29496 Metetra
.664 .741 .908 r
.5848 .29496 .58994 .30132 .59992 .29788 .59481 .2915 Metetra
.664 .741 .908 r
.59481 .2915 .59992 .29788 .60994 .29443 .60485 .28803 Metetra
.664 .741 .908 r
.60485 .28803 .60994 .29443 .61999 .29097 .61493 .28454 Metetra
.664 .741 .908 r
.61493 .28454 .61999 .29097 .63009 .28749 .62505 .28104 Metetra
.664 .741 .908 r
.62505 .28104 .63009 .28749 .64022 .28401 .6352 .27753 Metetra
.664 .741 .908 r
.6352 .27753 .64022 .28401 .65038 .2805 .64539 .27401 Metetra
.664 .741 .908 r
.64539 .27401 .65038 .2805 .66058 .27699 .65562 .27047 Metetra
.664 .741 .908 r
.65562 .27047 .66058 .27699 .67082 .27347 .66588 .26692 Metetra
.664 .741 .908 r
.66588 .26692 .67082 .27347 .6811 .26993 .67619 .26336 Metetra
.664 .741 .908 r
.67619 .26336 .6811 .26993 .69141 .26637 .68652 .25978 Metetra
.664 .741 .908 r
.68652 .25978 .69141 .26637 .70176 .26281 .6969 .25619 Metetra
.664 .741 .908 r
.6969 .25619 .70176 .26281 .71215 .25923 .70732 .25259 Metetra
.664 .741 .908 r
.70732 .25259 .71215 .25923 .72258 .25564 .71777 .24898 Metetra
.664 .741 .908 r
.71777 .24898 .72258 .25564 .73305 .25204 .72827 .24535 Metetra
.664 .741 .908 r
.72827 .24535 .73305 .25204 .74355 .24842 .7388 .24171 Metetra
.664 .741 .908 r
.7388 .24171 .74355 .24842 .7541 .24479 .74937 .23805 Metetra
.664 .741 .908 r
.74937 .23805 .7541 .24479 .76468 .24114 .75998 .23438 Metetra
.664 .741 .908 r
.75998 .23438 .76468 .24114 .7753 .23749 .77063 .2307 Metetra
.664 .741 .908 r
.77063 .2307 .7753 .23749 .78596 .23381 .78132 .227 Metetra
.664 .741 .908 r
.78132 .227 .78596 .23381 .79666 .23013 .79204 .22329 Metetra
.664 .741 .908 r
.79204 .22329 .79666 .23013 .8074 .22643 .80281 .21957 Metetra
.664 .741 .908 r
.80281 .21957 .8074 .22643 .81818 .22272 .81362 .21583 Metetra
.664 .741 .908 r
.81362 .21583 .81818 .22272 .829 .21899 .82447 .21208 Metetra
.664 .741 .908 r
.20602 .41832 .212 .42389 .22071 .42088 .21474 .41529 Metetra
.664 .741 .908 r
.21474 .41529 .22071 .42088 .22944 .41786 .2235 .41225 Metetra
.664 .741 .908 r
.2235 .41225 .22944 .41786 .23821 .41482 .23228 .4092 Metetra
.664 .741 .908 r
.23228 .4092 .23821 .41482 .24701 .41178 .2411 .40614 Metetra
.664 .741 .908 r
.2411 .40614 .24701 .41178 .25584 .40873 .24994 .40307 Metetra
.664 .741 .908 r
.24994 .40307 .25584 .40873 .2647 .40567 .25882 .39998 Metetra
.664 .741 .908 r
.25882 .39998 .2647 .40567 .27358 .40259 .26773 .39689 Metetra
.664 .741 .908 r
.26773 .39689 .27358 .40259 .2825 .39951 .27666 .39379 Metetra
.664 .741 .908 r
.27666 .39379 .2825 .39951 .29145 .39641 .28563 .39067 Metetra
.664 .741 .908 r
.28563 .39067 .29145 .39641 .30043 .39331 .29463 .38755 Metetra
.664 .741 .908 r
.29463 .38755 .30043 .39331 .30944 .39019 .30365 .38441 Metetra
.664 .741 .908 r
.30365 .38441 .30944 .39019 .31848 .38707 .31271 .38127 Metetra
.664 .741 .908 r
.31271 .38127 .31848 .38707 .32755 .38393 .3218 .37811 Metetra
.664 .741 .908 r
.3218 .37811 .32755 .38393 .33665 .38078 .33092 .37494 Metetra
.664 .741 .908 r
.33092 .37494 .33665 .38078 .34579 .37762 .34008 .37176 Metetra
.664 .741 .908 r
.34008 .37176 .34579 .37762 .35495 .37445 .34926 .36857 Metetra
.664 .741 .908 r
.34926 .36857 .35495 .37445 .36415 .37127 .35848 .36537 Metetra
.664 .741 .908 r
.35848 .36537 .36415 .37127 .37338 .36808 .36773 .36216 Metetra
.664 .741 .908 r
.36773 .36216 .37338 .36808 .38264 .36488 .37701 .35894 Metetra
.664 .741 .908 r
.37701 .35894 .38264 .36488 .39193 .36166 .38632 .3557 Metetra
.664 .741 .908 r
.38632 .3557 .39193 .36166 .40126 .35844 .39567 .35246 Metetra
.664 .741 .908 r
.39567 .35246 .40126 .35844 .41061 .3552 .40504 .3492 Metetra
.664 .741 .908 r
.40504 .3492 .41061 .3552 .42 .35196 .41445 .34593 Metetra
.664 .741 .908 r
.41445 .34593 .42 .35196 .42943 .3487 .4239 .34265 Metetra
0 .044 .56 r
.4239 .34265 .42943 .3487 .43878 .34924 .43302 .35153 Metetra
.831 .407 .232 r
.43302 .35153 .43878 .34924 .44813 .35222 .44205 .3683 Metetra
.802 .467 .42 r
.44205 .3683 .44813 .35222 .45698 .38197 .45092 .39826 Metetra
.835 .505 .43 r
.45092 .39826 .45698 .38197 .46569 .43248 .45983 .43854 Metetra
.577 .113 .114 r
.45983 .43854 .46569 .43248 .4753 .4471 .46964 .44283 Metetra
.939 .789 .668 r
.46964 .44283 .4753 .4471 .48542 .43107 .47995 .41695 Metetra
.781 .639 .704 r
.47995 .41695 .48542 .43107 .49545 .42165 .49004 .40282 Metetra
.613 .508 .711 r
.49004 .40282 .49545 .42165 .50543 .41837 .50001 .39951 Metetra
.346 .34 .71 r
.50001 .39951 .50543 .41837 .51544 .42125 .50997 .40704 Metetra
0 0 .471 r
.50997 .40704 .51544 .42125 .52552 .43078 .52001 .42641 Metetra
.86 .842 .825 r
.52001 .42641 .52552 .43078 .53562 .40954 .53018 .41551 Metetra
1 .828 .517 r
.53018 .41551 .53562 .40954 .5454 .35208 .54017 .36833 Metetra
.806 .788 .288 r
.54017 .36833 .5454 .35208 .55509 .31543 .55001 .33145 Metetra
.55001 .33145 .55509 .31543 .56494 .3057 .55981 .30778 Metetra
.932 .97 .708 r
.55981 .30778 .56494 .3057 .57483 .29841 .56963 .29204 Metetra
.664 .741 .908 r
.56963 .29204 .57483 .29841 .5848 .29496 .57963 .28856 Metetra
.664 .741 .908 r
.57963 .28856 .5848 .29496 .59481 .2915 .58966 .28508 Metetra
.664 .741 .908 r
.58966 .28508 .59481 .2915 .60485 .28803 .59973 .28158 Metetra
.664 .741 .908 r
.59973 .28158 .60485 .28803 .61493 .28454 .60983 .27807 Metetra
.664 .741 .908 r
.60983 .27807 .61493 .28454 .62505 .28104 .61997 .27455 Metetra
.664 .741 .908 r
.61997 .27455 .62505 .28104 .6352 .27753 .63015 .27102 Metetra
.664 .741 .908 r
.63015 .27102 .6352 .27753 .64539 .27401 .64037 .26747 Metetra
.664 .741 .908 r
.64037 .26747 .64539 .27401 .65562 .27047 .65062 .26391 Metetra
.664 .741 .908 r
.65062 .26391 .65562 .27047 .66588 .26692 .66091 .26033 Metetra
.664 .741 .908 r
.66091 .26033 .66588 .26692 .67619 .26336 .67124 .25675 Metetra
.664 .741 .908 r
.67124 .25675 .67619 .26336 .68652 .25978 .6816 .25315 Metetra
.664 .741 .908 r
.6816 .25315 .68652 .25978 .6969 .25619 .69201 .24953 Metetra
.664 .741 .908 r
.69201 .24953 .6969 .25619 .70732 .25259 .70245 .24591 Metetra
.664 .741 .908 r
.70245 .24591 .70732 .25259 .71777 .24898 .71293 .24227 Metetra
.664 .741 .908 r
.71293 .24227 .71777 .24898 .72827 .24535 .72345 .23861 Metetra
.664 .741 .908 r
.72345 .23861 .72827 .24535 .7388 .24171 .73401 .23495 Metetra
.664 .741 .908 r
.73401 .23495 .7388 .24171 .74937 .23805 .74461 .23126 Metetra
.664 .741 .908 r
.74461 .23126 .74937 .23805 .75998 .23438 .75524 .22757 Metetra
.664 .741 .908 r
.75524 .22757 .75998 .23438 .77063 .2307 .76592 .22386 Metetra
.664 .741 .908 r
.76592 .22386 .77063 .2307 .78132 .227 .77664 .22014 Metetra
.664 .741 .908 r
.77664 .22014 .78132 .227 .79204 .22329 .78739 .2164 Metetra
.664 .741 .908 r
.78739 .2164 .79204 .22329 .80281 .21957 .79819 .21265 Metetra
.664 .741 .908 r
.79819 .21265 .80281 .21957 .81362 .21583 .80903 .20889 Metetra
.664 .741 .908 r
.80903 .20889 .81362 .21583 .82447 .21208 .81991 .20511 Metetra
.664 .741 .908 r
.2 .41272 .20602 .41832 .21474 .41529 .20874 .40967 Metetra
.664 .741 .908 r
.20874 .40967 .21474 .41529 .2235 .41225 .21751 .40661 Metetra
.664 .741 .908 r
.21751 .40661 .2235 .41225 .23228 .4092 .22632 .40354 Metetra
.664 .741 .908 r
.22632 .40354 .23228 .4092 .2411 .40614 .23515 .40046 Metetra
.664 .741 .908 r
.23515 .40046 .2411 .40614 .24994 .40307 .24401 .39737 Metetra
.664 .741 .908 r
.24401 .39737 .24994 .40307 .25882 .39998 .25291 .39426 Metetra
.664 .741 .908 r
.25291 .39426 .25882 .39998 .26773 .39689 .26183 .39115 Metetra
.664 .741 .908 r
.26183 .39115 .26773 .39689 .27666 .39379 .27078 .38803 Metetra
.664 .741 .908 r
.27078 .38803 .27666 .39379 .28563 .39067 .27977 .3849 Metetra
.664 .741 .908 r
.27977 .3849 .28563 .39067 .29463 .38755 .28879 .38175 Metetra
.664 .741 .908 r
.28879 .38175 .29463 .38755 .30365 .38441 .29783 .3786 Metetra
.664 .741 .908 r
.29783 .3786 .30365 .38441 .31271 .38127 .30691 .37543 Metetra
.664 .741 .908 r
.30691 .37543 .31271 .38127 .3218 .37811 .31602 .37225 Metetra
.664 .741 .908 r
.31602 .37225 .3218 .37811 .33092 .37494 .32516 .36906 Metetra
.664 .741 .908 r
.32516 .36906 .33092 .37494 .34008 .37176 .33433 .36586 Metetra
.664 .741 .908 r
.33433 .36586 .34008 .37176 .34926 .36857 .34354 .36265 Metetra
.664 .741 .908 r
.34354 .36265 .34926 .36857 .35848 .36537 .35277 .35943 Metetra
.664 .741 .908 r
.35277 .35943 .35848 .36537 .36773 .36216 .36204 .3562 Metetra
.664 .741 .908 r
.36204 .3562 .36773 .36216 .37701 .35894 .37134 .35296 Metetra
.664 .741 .908 r
.37134 .35296 .37701 .35894 .38632 .3557 .38067 .3497 Metetra
.664 .741 .908 r
.38067 .3497 .38632 .3557 .39567 .35246 .39004 .34643 Metetra
.664 .741 .908 r
.39004 .34643 .39567 .35246 .40504 .3492 .39944 .34316 Metetra
.664 .741 .908 r
.39944 .34316 .40504 .3492 .41445 .34593 .40887 .33987 Metetra
.664 .741 .908 r
.40887 .33987 .41445 .34593 .4239 .34265 .41833 .33656 Metetra
.909 .504 .129 r
.41833 .33656 .4239 .34265 .43302 .35153 .42695 .36183 Metetra
.875 .541 .415 r
.42695 .36183 .43302 .35153 .44205 .3683 .43524 .40631 Metetra
.672 .374 .46 r
.43524 .40631 .44205 .3683 .45092 .39826 .44444 .42698 Metetra
.546 .24 .4 r
.44444 .42698 .45092 .39826 .45983 .43854 .45421 .4297 Metetra
.781 .71 .785 r
.45421 .4297 .45983 .43854 .46964 .44283 .46428 .42033 Metetra
.76 .578 .652 r
.46428 .42033 .46964 .44283 .47995 .41695 .4745 .40109 Metetra
.736 .602 .708 r
.4745 .40109 .47995 .41695 .49004 .40282 .48456 .39011 Metetra
.634 .583 .78 r
.48456 .39011 .49004 .40282 .50001 .39951 .49453 .38677 Metetra
.372 .435 .797 r
.49453 .38677 .50001 .39951 .50997 .40704 .5045 .39109 Metetra
.049 .176 .676 r
.5045 .39109 .50997 .40704 .52001 .42641 .51452 .40373 Metetra
.497 .412 .69 r
.51452 .40373 .52001 .42641 .53018 .41551 .52467 .40649 Metetra
.781 .712 .787 r
.52467 .40649 .53018 .41551 .54017 .36833 .53487 .3971 Metetra
0 0 .184 r
.53487 .3971 .54017 .36833 .55001 .33145 .54495 .36957 Metetra
0 0 .086 r
.54495 .36957 .55001 .33145 .55981 .30778 .55469 .31794 Metetra
.919 .866 .431 r
.55469 .31794 .55981 .30778 .56963 .29204 .5644 .28562 Metetra
.664 .741 .908 r
.5644 .28562 .56963 .29204 .57963 .28856 .57442 .28212 Metetra
.664 .741 .908 r
.57442 .28212 .57963 .28856 .58966 .28508 .58448 .27861 Metetra
.664 .741 .908 r
.58448 .27861 .58966 .28508 .59973 .28158 .59457 .27509 Metetra
.664 .741 .908 r
.59457 .27509 .59973 .28158 .60983 .27807 .6047 .27156 Metetra
.664 .741 .908 r
.6047 .27156 .60983 .27807 .61997 .27455 .61486 .26802 Metetra
.664 .741 .908 r
.61486 .26802 .61997 .27455 .63015 .27102 .62507 .26446 Metetra
.664 .741 .908 r
.62507 .26446 .63015 .27102 .64037 .26747 .63531 .26088 Metetra
.664 .741 .908 r
.63531 .26088 .64037 .26747 .65062 .26391 .64559 .2573 Metetra
.664 .741 .908 r
.64559 .2573 .65062 .26391 .66091 .26033 .6559 .2537 Metetra
.664 .741 .908 r
.6559 .2537 .66091 .26033 .67124 .25675 .66626 .25009 Metetra
.664 .741 .908 r
.66626 .25009 .67124 .25675 .6816 .25315 .67665 .24647 Metetra
.664 .741 .908 r
.67665 .24647 .6816 .25315 .69201 .24953 .68708 .24283 Metetra
.664 .741 .908 r
.68708 .24283 .69201 .24953 .70245 .24591 .69755 .23918 Metetra
.664 .741 .908 r
.69755 .23918 .70245 .24591 .71293 .24227 .70806 .23551 Metetra
.664 .741 .908 r
.70806 .23551 .71293 .24227 .72345 .23861 .7186 .23183 Metetra
.664 .741 .908 r
.7186 .23183 .72345 .23861 .73401 .23495 .72919 .22814 Metetra
.664 .741 .908 r
.72919 .22814 .73401 .23495 .74461 .23126 .73981 .22443 Metetra
.664 .741 .908 r
.73981 .22443 .74461 .23126 .75524 .22757 .75048 .22071 Metetra
.664 .741 .908 r
.75048 .22071 .75524 .22757 .76592 .22386 .76118 .21698 Metetra
.664 .741 .908 r
.76118 .21698 .76592 .22386 .77664 .22014 .77193 .21323 Metetra
.664 .741 .908 r
.77193 .21323 .77664 .22014 .78739 .2164 .78271 .20947 Metetra
.664 .741 .908 r
.78271 .20947 .78739 .2164 .79819 .21265 .79354 .20569 Metetra
.664 .741 .908 r
.79354 .20569 .79819 .21265 .80903 .20889 .80441 .2019 Metetra
.664 .741 .908 r
.80441 .2019 .80903 .20889 .81991 .20511 .81531 .1981 Metetra
.664 .741 .908 r
.19394 .40708 .2 .41272 .20874 .40967 .2027 .40401 Metetra
.664 .741 .908 r
.2027 .40401 .20874 .40967 .21751 .40661 .21149 .40093 Metetra
.664 .741 .908 r
.21149 .40093 .21751 .40661 .22632 .40354 .22031 .39784 Metetra
.664 .741 .908 r
.22031 .39784 .22632 .40354 .23515 .40046 .22916 .39474 Metetra
.664 .741 .908 r
.22916 .39474 .23515 .40046 .24401 .39737 .23805 .39163 Metetra
.664 .741 .908 r
.23805 .39163 .24401 .39737 .25291 .39426 .24696 .38851 Metetra
.664 .741 .908 r
.24696 .38851 .25291 .39426 .26183 .39115 .2559 .38538 Metetra
.664 .741 .908 r
.2559 .38538 .26183 .39115 .27078 .38803 .26487 .38224 Metetra
.664 .741 .908 r
.26487 .38224 .27078 .38803 .27977 .3849 .27387 .37908 Metetra
.664 .741 .908 r
.27387 .37908 .27977 .3849 .28879 .38175 .28291 .37592 Metetra
.664 .741 .908 r
.28291 .37592 .28879 .38175 .29783 .3786 .29197 .37274 Metetra
.664 .741 .908 r
.29197 .37274 .29783 .3786 .30691 .37543 .30107 .36955 Metetra
.664 .741 .908 r
.30107 .36955 .30691 .37543 .31602 .37225 .3102 .36636 Metetra
.664 .741 .908 r
.3102 .36636 .31602 .37225 .32516 .36906 .31936 .36315 Metetra
.664 .741 .908 r
.31936 .36315 .32516 .36906 .33433 .36586 .32855 .35993 Metetra
.664 .741 .908 r
.32855 .35993 .33433 .36586 .34354 .36265 .33777 .3567 Metetra
.664 .741 .908 r
.33777 .3567 .34354 .36265 .35277 .35943 .34703 .35346 Metetra
.664 .741 .908 r
.34703 .35346 .35277 .35943 .36204 .3562 .35632 .3502 Metetra
.664 .741 .908 r
.35632 .3502 .36204 .3562 .37134 .35296 .36564 .34694 Metetra
.664 .741 .908 r
.36564 .34694 .37134 .35296 .38067 .3497 .37499 .34366 Metetra
.664 .741 .908 r
.37499 .34366 .38067 .3497 .39004 .34643 .38438 .34037 Metetra
.664 .741 .908 r
.38438 .34037 .39004 .34643 .39944 .34316 .39379 .33707 Metetra
.388 .625 .947 r
.39379 .33707 .39944 .34316 .40887 .33987 .40307 .33821 Metetra
.316 0 0 r
.40307 .33821 .40887 .33987 .41833 .33656 .41233 .34183 Metetra
.885 .533 .375 r
.41233 .34183 .41833 .33656 .42695 .36183 .42061 .37743 Metetra
.872 .552 .443 r
.42061 .37743 .42695 .36183 .43524 .40631 .42851 .43512 Metetra
.627 .315 .422 r
.42851 .43512 .43524 .40631 .44444 .42698 .43805 .44594 Metetra
.43805 .44594 .44444 .42698 .45421 .4297 .44854 .42185 Metetra
.881 .743 .705 r
.44854 .42185 .45421 .4297 .46428 .42033 .45885 .40239 Metetra
.764 .603 .678 r
.45885 .40239 .46428 .42033 .4745 .40109 .46902 .38667 Metetra
.727 .61 .727 r
.46902 .38667 .4745 .40109 .48456 .39011 .47907 .37736 Metetra
.634 .583 .78 r
.47907 .37736 .48456 .39011 .49453 .38677 .48905 .37399 Metetra
.446 .479 .8 r
.48905 .37399 .49453 .38677 .5045 .39109 .49901 .37659 Metetra
.178 .284 .736 r
.49901 .37659 .5045 .39109 .51452 .40373 .50902 .38563 Metetra
.117 .197 .671 r
.50902 .38563 .51452 .40373 .52467 .40649 .51913 .39847 Metetra
.69 .254 0 r
.51913 .39847 .52467 .40649 .53487 .3971 .5294 .41604 Metetra
0 0 .101 r
.5294 .41604 .53487 .3971 .54495 .36957 .53967 .39845 Metetra
.819 .734 .208 r
.53967 .39845 .54495 .36957 .55469 .31794 .54953 .33346 Metetra
.891 .816 .34 r
.54953 .33346 .55469 .31794 .5644 .28562 .55926 .29066 Metetra
.55 .845 .522 r
.55926 .29066 .5644 .28562 .57442 .28212 .56924 .28014 Metetra
.823 .943 .903 r
.56924 .28014 .57442 .28212 .58448 .27861 .57926 .27211 Metetra
.664 .741 .908 r
.57926 .27211 .58448 .27861 .59457 .27509 .58938 .26856 Metetra
.664 .741 .908 r
.58938 .26856 .59457 .27509 .6047 .27156 .59953 .265 Metetra
.664 .741 .908 r
.59953 .265 .6047 .27156 .61486 .26802 .60972 .26143 Metetra
.664 .741 .908 r
.60972 .26143 .61486 .26802 .62507 .26446 .61995 .25785 Metetra
.664 .741 .908 r
.61995 .25785 .62507 .26446 .63531 .26088 .63022 .25426 Metetra
.664 .741 .908 r
.63022 .25426 .63531 .26088 .64559 .2573 .64052 .25065 Metetra
.664 .741 .908 r
.64052 .25065 .64559 .2573 .6559 .2537 .65086 .24702 Metetra
.664 .741 .908 r
.65086 .24702 .6559 .2537 .66626 .25009 .66124 .24339 Metetra
.664 .741 .908 r
.66124 .24339 .66626 .25009 .67665 .24647 .67166 .23974 Metetra
.664 .741 .908 r
.67166 .23974 .67665 .24647 .68708 .24283 .68212 .23608 Metetra
.664 .741 .908 r
.68212 .23608 .68708 .24283 .69755 .23918 .69261 .2324 Metetra
.664 .741 .908 r
.69261 .2324 .69755 .23918 .70806 .23551 .70315 .22871 Metetra
.664 .741 .908 r
.70315 .22871 .70806 .23551 .7186 .23183 .71372 .225 Metetra
.664 .741 .908 r
.71372 .225 .7186 .23183 .72919 .22814 .72433 .22129 Metetra
.664 .741 .908 r
.72433 .22129 .72919 .22814 .73981 .22443 .73499 .21756 Metetra
.664 .741 .908 r
.73499 .21756 .73981 .22443 .75048 .22071 .74568 .21381 Metetra
.664 .741 .908 r
.74568 .21381 .75048 .22071 .76118 .21698 .75641 .21005 Metetra
.664 .741 .908 r
.75641 .21005 .76118 .21698 .77193 .21323 .76719 .20628 Metetra
.664 .741 .908 r
.76719 .20628 .77193 .21323 .78271 .20947 .778 .20249 Metetra
.664 .741 .908 r
.778 .20249 .78271 .20947 .79354 .20569 .78885 .19869 Metetra
.664 .741 .908 r
.78885 .19869 .79354 .20569 .80441 .2019 .79975 .19487 Metetra
.664 .741 .908 r
.79975 .19487 .80441 .2019 .81531 .1981 .81069 .19104 Metetra
.664 .741 .908 r
.18785 .40141 .19394 .40708 .2027 .40401 .19663 .39832 Metetra
.664 .741 .908 r
.19663 .39832 .2027 .40401 .21149 .40093 .20543 .39522 Metetra
.664 .741 .908 r
.20543 .39522 .21149 .40093 .22031 .39784 .21427 .39211 Metetra
.664 .741 .908 r
.21427 .39211 .22031 .39784 .22916 .39474 .22314 .38899 Metetra
.664 .741 .908 r
.22314 .38899 .22916 .39474 .23805 .39163 .23204 .38586 Metetra
.664 .741 .908 r
.23204 .38586 .23805 .39163 .24696 .38851 .24097 .38272 Metetra
.664 .741 .908 r
.24097 .38272 .24696 .38851 .2559 .38538 .24993 .37957 Metetra
.664 .741 .908 r
.24993 .37957 .2559 .38538 .26487 .38224 .25892 .3764 Metetra
.664 .741 .908 r
.25892 .3764 .26487 .38224 .27387 .37908 .26794 .37323 Metetra
.664 .741 .908 r
.26794 .37323 .27387 .37908 .28291 .37592 .27699 .37005 Metetra
.664 .741 .908 r
.27699 .37005 .28291 .37592 .29197 .37274 .28608 .36685 Metetra
.664 .741 .908 r
.28608 .36685 .29197 .37274 .30107 .36955 .29519 .36364 Metetra
.664 .741 .908 r
.29519 .36364 .30107 .36955 .3102 .36636 .30434 .36042 Metetra
.664 .741 .908 r
.30434 .36042 .3102 .36636 .31936 .36315 .31352 .3572 Metetra
.664 .741 .908 r
.31352 .3572 .31936 .36315 .32855 .35993 .32273 .35396 Metetra
.664 .741 .908 r
.32273 .35396 .32855 .35993 .33777 .3567 .33197 .3507 Metetra
.664 .741 .908 r
.33197 .3507 .33777 .3567 .34703 .35346 .34125 .34744 Metetra
.664 .741 .908 r
.34125 .34744 .34703 .35346 .35632 .3502 .35056 .34417 Metetra
.664 .741 .908 r
.35056 .34417 .35632 .3502 .36564 .34694 .3599 .34088 Metetra
.664 .741 .908 r
.3599 .34088 .36564 .34694 .37499 .34366 .36927 .33758 Metetra
.664 .741 .908 r
.36927 .33758 .37499 .34366 .38438 .34037 .37868 .33427 Metetra
.664 .741 .908 r
.37868 .33427 .38438 .34037 .39379 .33707 .38811 .33095 Metetra
.7 .218 0 r
.38811 .33095 .39379 .33707 .40307 .33821 .39694 .34365 Metetra
.837 .455 .327 r
.39694 .34365 .40307 .33821 .41233 .34183 .40555 .36551 Metetra
.788 .47 .45 r
.40555 .36551 .41233 .34183 .42061 .37743 .41385 .40165 Metetra
.815 .499 .455 r
.41385 .40165 .42061 .37743 .42851 .43512 .42211 .44786 Metetra
.483 .095 .229 r
.42211 .44786 .42851 .43512 .43805 .44594 .432 .44843 Metetra
.989 .849 .612 r
.432 .44843 .43805 .44594 .44854 .42185 .4428 .41559 Metetra
.915 .764 .679 r
.4428 .41559 .44854 .42185 .45885 .40239 .45326 .39155 Metetra
.836 .694 .707 r
.45326 .39155 .45885 .40239 .46902 .38667 .46349 .37453 Metetra
.755 .649 .744 r
.46349 .37453 .46902 .38667 .47907 .37736 .47356 .36458 Metetra
.634 .583 .78 r
.47356 .36458 .47907 .37736 .48905 .37399 .48354 .36119 Metetra
.419 .463 .8 r
.48354 .36119 .48905 .37399 .49901 .37659 .49349 .36436 Metetra
0 .203 .718 r
.49349 .36436 .49901 .37659 .50902 .38563 .50348 .37466 Metetra
0 0 .422 r
.50348 .37466 .50902 .38563 .51913 .39847 .51356 .39206 Metetra
.88 .462 .044 r
.51356 .39206 .51913 .39847 .5294 .41604 .52381 .41839 Metetra
.57 .925 .747 r
.52381 .41839 .5294 .41604 .53967 .39845 .53419 .41111 Metetra
.982 .83 .433 r
.53419 .41111 .53967 .39845 .54953 .33346 .5443 .35769 Metetra
.5443 .35769 .54953 .33346 .55926 .29066 .55423 .31433 Metetra
0 0 .064 r
.55423 .31433 .55926 .29066 .56924 .28014 .56411 .28533 Metetra
.902 .939 .574 r
.56411 .28533 .56924 .28014 .57926 .27211 .57401 .26555 Metetra
.664 .741 .908 r
.57401 .26555 .57926 .27211 .58938 .26856 .58415 .26198 Metetra
.664 .741 .908 r
.58415 .26198 .58938 .26856 .59953 .265 .59433 .2584 Metetra
.664 .741 .908 r
.59433 .2584 .59953 .265 .60972 .26143 .60455 .25481 Metetra
.664 .741 .908 r
.60455 .25481 .60972 .26143 .61995 .25785 .6148 .2512 Metetra
.664 .741 .908 r
.6148 .2512 .61995 .25785 .63022 .25426 .62509 .24758 Metetra
.664 .741 .908 r
.62509 .24758 .63022 .25426 .64052 .25065 .63542 .24395 Metetra
.664 .741 .908 r
.63542 .24395 .64052 .25065 .65086 .24702 .64579 .2403 Metetra
.664 .741 .908 r
.64579 .2403 .65086 .24702 .66124 .24339 .65619 .23664 Metetra
.664 .741 .908 r
.65619 .23664 .66124 .24339 .67166 .23974 .66664 .23297 Metetra
.664 .741 .908 r
.66664 .23297 .67166 .23974 .68212 .23608 .67712 .22928 Metetra
.664 .741 .908 r
.67712 .22928 .68212 .23608 .69261 .2324 .68764 .22558 Metetra
.664 .741 .908 r
.68764 .22558 .69261 .2324 .70315 .22871 .6982 .22186 Metetra
.664 .741 .908 r
.6982 .22186 .70315 .22871 .71372 .225 .7088 .21813 Metetra
.664 .741 .908 r
.7088 .21813 .71372 .225 .72433 .22129 .71945 .21439 Metetra
.664 .741 .908 r
.71945 .21439 .72433 .22129 .73499 .21756 .73013 .21063 Metetra
.664 .741 .908 r
.73013 .21063 .73499 .21756 .74568 .21381 .74085 .20686 Metetra
.664 .741 .908 r
.74085 .20686 .74568 .21381 .75641 .21005 .75161 .20307 Metetra
.664 .741 .908 r
.75161 .20307 .75641 .21005 .76719 .20628 .76241 .19927 Metetra
.664 .741 .908 r
.76241 .19927 .76719 .20628 .778 .20249 .77325 .19546 Metetra
.664 .741 .908 r
.77325 .19546 .778 .20249 .78885 .19869 .78414 .19163 Metetra
.664 .741 .908 r
.78414 .19163 .78885 .19869 .79975 .19487 .79506 .18778 Metetra
.664 .741 .908 r
.79506 .18778 .79975 .19487 .81069 .19104 .80603 .18393 Metetra
.664 .741 .908 r
.18172 .3957 .18785 .40141 .19663 .39832 .19051 .39259 Metetra
.664 .741 .908 r
.19051 .39259 .19663 .39832 .20543 .39522 .19934 .38947 Metetra
.664 .741 .908 r
.19934 .38947 .20543 .39522 .21427 .39211 .20819 .38634 Metetra
.664 .741 .908 r
.20819 .38634 .21427 .39211 .22314 .38899 .21708 .3832 Metetra
.664 .741 .908 r
.21708 .3832 .22314 .38899 .23204 .38586 .22599 .38005 Metetra
.664 .741 .908 r
.22599 .38005 .23204 .38586 .24097 .38272 .23494 .37689 Metetra
.664 .741 .908 r
.23494 .37689 .24097 .38272 .24993 .37957 .24392 .37372 Metetra
.664 .741 .908 r
.24392 .37372 .24993 .37957 .25892 .3764 .25293 .37054 Metetra
.664 .741 .908 r
.25293 .37054 .25892 .3764 .26794 .37323 .26197 .36734 Metetra
.664 .741 .908 r
.26197 .36734 .26794 .37323 .27699 .37005 .27104 .36414 Metetra
.664 .741 .908 r
.27104 .36414 .27699 .37005 .28608 .36685 .28014 .36092 Metetra
.664 .741 .908 r
.28014 .36092 .28608 .36685 .29519 .36364 .28928 .35769 Metetra
.664 .741 .908 r
.28928 .35769 .29519 .36364 .30434 .36042 .29844 .35445 Metetra
.664 .741 .908 r
.29844 .35445 .30434 .36042 .31352 .3572 .30764 .3512 Metetra
.664 .741 .908 r
.30764 .3512 .31352 .3572 .32273 .35396 .31687 .34794 Metetra
.664 .741 .908 r
.31687 .34794 .32273 .35396 .33197 .3507 .32613 .34467 Metetra
.664 .741 .908 r
.32613 .34467 .33197 .3507 .34125 .34744 .33543 .34139 Metetra
.664 .741 .908 r
.33543 .34139 .34125 .34744 .35056 .34417 .34476 .33809 Metetra
.664 .741 .908 r
.34476 .33809 .35056 .34417 .3599 .34088 .35412 .33478 Metetra
.664 .741 .908 r
.35412 .33478 .3599 .34088 .36927 .33758 .36351 .33146 Metetra
.664 .741 .908 r
.36351 .33146 .36927 .33758 .37868 .33427 .37294 .32813 Metetra
.664 .741 .908 r
.37294 .32813 .37868 .33427 .38811 .33095 .3824 .32479 Metetra
.921 .527 .171 r
.3824 .32479 .38811 .33095 .39694 .34365 .3906 .35189 Metetra
.885 .55 .41 r
.3906 .35189 .39694 .34365 .40555 .36551 .39832 .39697 Metetra
.748 .439 .46 r
.39832 .39697 .40555 .36551 .41385 .40165 .40679 .43024 Metetra
.724 .409 .445 r
.40679 .43024 .41385 .40165 .42211 .44786 .41577 .45579 Metetra
.41577 .45579 .42211 .44786 .432 .44843 .42604 .44553 Metetra
.959 .782 .621 r
.42604 .44553 .432 .44843 .4428 .41559 .43701 .40961 Metetra
.922 .766 .67 r
.43701 .40961 .4428 .41559 .45326 .39155 .44757 .38399 Metetra
.875 .75 .722 r
.44757 .38399 .45326 .39155 .46349 .37453 .45785 .36656 Metetra
.804 .736 .789 r
.45785 .36656 .46349 .37453 .47356 .36458 .46796 .3564 Metetra
.655 .686 .868 r
.46796 .3564 .47356 .36458 .48354 .36119 .47795 .35299 Metetra
.293 .505 .891 r
.47795 .35299 .48354 .36119 .49349 .36436 .48791 .35632 Metetra
0 .06 .61 r
.48791 .35632 .49349 .36436 .50348 .37466 .49788 .36697 Metetra
.757 .318 0 r
.49788 .36697 .50348 .37466 .51356 .39206 .50794 .38592 Metetra
.901 .494 .099 r
.50794 .38592 .51356 .39206 .52381 .41839 .51816 .41531 Metetra
0 .426 .785 r
.51816 .41531 .52381 .41839 .53419 .41111 .52859 .41891 Metetra
.968 .888 .511 r
.52859 .41891 .53419 .41111 .5443 .35769 .53896 .38634 Metetra
0 0 .014 r
.53896 .38634 .5443 .35769 .55423 .31433 .54911 .34588 Metetra
.54911 .34588 .55423 .31433 .56411 .28533 .55893 .29336 Metetra
.967 .873 .482 r
.55893 .29336 .56411 .28533 .57401 .26555 .56872 .25896 Metetra
.664 .741 .908 r
.56872 .25896 .57401 .26555 .58415 .26198 .57889 .25536 Metetra
.664 .741 .908 r
.57889 .25536 .58415 .26198 .59433 .2584 .58909 .25176 Metetra
.664 .741 .908 r
.58909 .25176 .59433 .2584 .60455 .25481 .59933 .24814 Metetra
.664 .741 .908 r
.59933 .24814 .60455 .25481 .6148 .2512 .60961 .24451 Metetra
.664 .741 .908 r
.60961 .24451 .6148 .2512 .62509 .24758 .61993 .24086 Metetra
.664 .741 .908 r
.61993 .24086 .62509 .24758 .63542 .24395 .63028 .2372 Metetra
.664 .741 .908 r
.63028 .2372 .63542 .24395 .64579 .2403 .64068 .23353 Metetra
.664 .741 .908 r
.64068 .23353 .64579 .2403 .65619 .23664 .65111 .22985 Metetra
.664 .741 .908 r
.65111 .22985 .65619 .23664 .66664 .23297 .66158 .22615 Metetra
.664 .741 .908 r
.66158 .22615 .66664 .23297 .67712 .22928 .67209 .22243 Metetra
.664 .741 .908 r
.67209 .22243 .67712 .22928 .68764 .22558 .68264 .2187 Metetra
.664 .741 .908 r
.68264 .2187 .68764 .22558 .6982 .22186 .69323 .21496 Metetra
.664 .741 .908 r
.69323 .21496 .6982 .22186 .7088 .21813 .70386 .21121 Metetra
.664 .741 .908 r
.70386 .21121 .7088 .21813 .71945 .21439 .71452 .20744 Metetra
.664 .741 .908 r
.71452 .20744 .71945 .21439 .73013 .21063 .72523 .20366 Metetra
.664 .741 .908 r
.72523 .20366 .73013 .21063 .74085 .20686 .73598 .19986 Metetra
.664 .741 .908 r
.73598 .19986 .74085 .20686 .75161 .20307 .74677 .19604 Metetra
.664 .741 .908 r
.74677 .19604 .75161 .20307 .76241 .19927 .7576 .19222 Metetra
.664 .741 .908 r
.7576 .19222 .76241 .19927 .77325 .19546 .76847 .18838 Metetra
.664 .741 .908 r
.76847 .18838 .77325 .19546 .78414 .19163 .77939 .18452 Metetra
.664 .741 .908 r
.77939 .18452 .78414 .19163 .79506 .18778 .79034 .18065 Metetra
.664 .741 .908 r
.79034 .18065 .79506 .18778 .80603 .18393 .80134 .17677 Metetra
.664 .741 .908 r
.17555 .38995 .18172 .3957 .19051 .39259 .18436 .38683 Metetra
.664 .741 .908 r
.18436 .38683 .19051 .39259 .19934 .38947 .1932 .38369 Metetra
.664 .741 .908 r
.1932 .38369 .19934 .38947 .20819 .38634 .20207 .38054 Metetra
.664 .741 .908 r
.20207 .38054 .20819 .38634 .21708 .3832 .21098 .37738 Metetra
.664 .741 .908 r
.21098 .37738 .21708 .3832 .22599 .38005 .21991 .37421 Metetra
.664 .741 .908 r
.21991 .37421 .22599 .38005 .23494 .37689 .22888 .37103 Metetra
.664 .741 .908 r
.22888 .37103 .23494 .37689 .24392 .37372 .23787 .36783 Metetra
.664 .741 .908 r
.23787 .36783 .24392 .37372 .25293 .37054 .2469 .36463 Metetra
.664 .741 .908 r
.2469 .36463 .25293 .37054 .26197 .36734 .25596 .36142 Metetra
.664 .741 .908 r
.25596 .36142 .26197 .36734 .27104 .36414 .26505 .35819 Metetra
.664 .741 .908 r
.26505 .35819 .27104 .36414 .28014 .36092 .27417 .35495 Metetra
.664 .741 .908 r
.27417 .35495 .28014 .36092 .28928 .35769 .28332 .35171 Metetra
.664 .741 .908 r
.28332 .35171 .28928 .35769 .29844 .35445 .29251 .34845 Metetra
.664 .741 .908 r
.29251 .34845 .29844 .35445 .30764 .3512 .30173 .34517 Metetra
.664 .741 .908 r
.30173 .34517 .30764 .3512 .31687 .34794 .31098 .34189 Metetra
.664 .741 .908 r
.31098 .34189 .31687 .34794 .32613 .34467 .32026 .3386 Metetra
.664 .741 .908 r
.32026 .3386 .32613 .34467 .33543 .34139 .32957 .33529 Metetra
.664 .741 .908 r
.32957 .33529 .33543 .34139 .34476 .33809 .33892 .33197 Metetra
.664 .741 .908 r
.33892 .33197 .34476 .33809 .35412 .33478 .3483 .32865 Metetra
.664 .741 .908 r
.3483 .32865 .35412 .33478 .36351 .33146 .35772 .32531 Metetra
.664 .741 .908 r
.35772 .32531 .36351 .33146 .37294 .32813 .36716 .32195 Metetra
.664 .741 .908 r
.36716 .32195 .37294 .32813 .3824 .32479 .37664 .31859 Metetra
.952 .609 .316 r
.37664 .31859 .3824 .32479 .3906 .35189 .38395 .36528 Metetra
.899 .588 .448 r
.38395 .36528 .3906 .35189 .39832 .39697 .39031 .44285 Metetra
.668 .375 .467 r
.39031 .44285 .39832 .39697 .40679 .43024 .39925 .46663 Metetra
.346 .075 .352 r
.39925 .46663 .40679 .43024 .41577 .45579 .40965 .45459 Metetra
.956 .855 .701 r
.40965 .45459 .41577 .45579 .42604 .44553 .42034 .43278 Metetra
.872 .687 .649 r
.42034 .43278 .42604 .44553 .43701 .40961 .43116 .40417 Metetra
.917 .782 .697 r
.43116 .40417 .43701 .40961 .44757 .38399 .44169 .38244 Metetra
.936 .886 .758 r
.44169 .38244 .44757 .38399 .45785 .36656 .45201 .36623 Metetra
.853 .974 .868 r
.45201 .36623 .45785 .36656 .46796 .3564 .46215 .35665 Metetra
.423 .868 .876 r
.46215 .35665 .46796 .3564 .47795 .35299 .47219 .35321 Metetra
.336 0 0 r
.47219 .35321 .47795 .35299 .48791 .35632 .48219 .35594 Metetra
.697 .159 0 r
.48219 .35594 .48791 .35632 .49788 .36697 .49219 .36533 Metetra
.806 .317 .002 r
.49219 .36533 .49788 .36697 .50794 .38592 .50228 .38031 Metetra
.852 .409 0 r
.50228 .38031 .50794 .38592 .51816 .41531 .51249 .4023 Metetra
0 .01 .585 r
.51249 .4023 .51816 .41531 .52859 .41891 .52291 .41751 Metetra
.435 0 0 r
.52291 .41751 .52859 .41891 .53896 .38634 .53347 .4229 Metetra
.009 0 .241 r
.53347 .4229 .53896 .38634 .54911 .34588 .54391 .39203 Metetra
.54391 .39203 .54911 .34588 .55893 .29336 .55371 .3066 Metetra
.973 .822 .409 r
.55371 .3066 .55893 .29336 .56872 .25896 .5634 .25231 Metetra
.664 .741 .908 r
.5634 .25231 .56872 .25896 .57889 .25536 .57359 .2487 Metetra
.664 .741 .908 r
.57359 .2487 .57889 .25536 .58909 .25176 .58382 .24507 Metetra
.664 .741 .908 r
.58382 .24507 .58909 .25176 .59933 .24814 .59408 .24142 Metetra
.664 .741 .908 r
.59408 .24142 .59933 .24814 .60961 .24451 .60439 .23777 Metetra
.664 .741 .908 r
.60439 .23777 .60961 .24451 .61993 .24086 .61473 .2341 Metetra
.664 .741 .908 r
.61473 .2341 .61993 .24086 .63028 .2372 .62511 .23041 Metetra
.664 .741 .908 r
.62511 .23041 .63028 .2372 .64068 .23353 .63553 .22672 Metetra
.664 .741 .908 r
.63553 .22672 .64068 .23353 .65111 .22985 .64599 .223 Metetra
.664 .741 .908 r
.64599 .223 .65111 .22985 .66158 .22615 .65649 .21928 Metetra
.664 .741 .908 r
.65649 .21928 .66158 .22615 .67209 .22243 .66702 .21554 Metetra
.664 .741 .908 r
.66702 .21554 .67209 .22243 .68264 .2187 .6776 .21179 Metetra
.664 .741 .908 r
.6776 .21179 .68264 .2187 .69323 .21496 .68822 .20802 Metetra
.664 .741 .908 r
.68822 .20802 .69323 .21496 .70386 .21121 .69887 .20424 Metetra
.664 .741 .908 r
.69887 .20424 .70386 .21121 .71452 .20744 .70957 .20044 Metetra
.664 .741 .908 r
.70957 .20044 .71452 .20744 .72523 .20366 .7203 .19663 Metetra
.664 .741 .908 r
.7203 .19663 .72523 .20366 .73598 .19986 .73108 .19281 Metetra
.664 .741 .908 r
.73108 .19281 .73598 .19986 .74677 .19604 .7419 .18897 Metetra
.664 .741 .908 r
.7419 .18897 .74677 .19604 .7576 .19222 .75276 .18512 Metetra
.664 .741 .908 r
.75276 .18512 .7576 .19222 .76847 .18838 .76366 .18125 Metetra
.664 .741 .908 r
.76366 .18125 .76847 .18838 .77939 .18452 .7746 .17736 Metetra
.664 .741 .908 r
.7746 .17736 .77939 .18452 .79034 .18065 .78558 .17347 Metetra
.664 .741 .908 r
.78558 .17347 .79034 .18065 .80134 .17677 .79661 .16955 Metetra
.664 .741 .908 r
.16934 .38417 .17555 .38995 .18436 .38683 .17817 .38102 Metetra
.664 .741 .908 r
.17817 .38102 .18436 .38683 .1932 .38369 .18703 .37787 Metetra
.664 .741 .908 r
.18703 .37787 .1932 .38369 .20207 .38054 .19592 .3747 Metetra
.664 .741 .908 r
.19592 .3747 .20207 .38054 .21098 .37738 .20484 .37152 Metetra
.664 .741 .908 r
.20484 .37152 .21098 .37738 .21991 .37421 .21379 .36833 Metetra
.664 .741 .908 r
.21379 .36833 .21991 .37421 .22888 .37103 .22277 .36512 Metetra
.664 .741 .908 r
.22277 .36512 .22888 .37103 .23787 .36783 .23179 .36191 Metetra
.664 .741 .908 r
.23179 .36191 .23787 .36783 .2469 .36463 .24083 .35869 Metetra
.664 .741 .908 r
.24083 .35869 .2469 .36463 .25596 .36142 .24991 .35545 Metetra
.664 .741 .908 r
.24991 .35545 .25596 .36142 .26505 .35819 .25902 .35221 Metetra
.664 .741 .908 r
.25902 .35221 .26505 .35819 .27417 .35495 .26816 .34895 Metetra
.664 .741 .908 r
.26816 .34895 .27417 .35495 .28332 .35171 .27733 .34568 Metetra
.664 .741 .908 r
.27733 .34568 .28332 .35171 .29251 .34845 .28654 .3424 Metetra
.664 .741 .908 r
.28654 .3424 .29251 .34845 .30173 .34517 .29577 .33911 Metetra
.664 .741 .908 r
.29577 .33911 .30173 .34517 .31098 .34189 .30504 .3358 Metetra
.664 .741 .908 r
.30504 .3358 .31098 .34189 .32026 .3386 .31434 .33249 Metetra
.664 .741 .908 r
.31434 .33249 .32026 .3386 .32957 .33529 .32368 .32916 Metetra
.664 .741 .908 r
.32368 .32916 .32957 .33529 .33892 .33197 .33305 .32582 Metetra
.664 .741 .908 r
.33305 .32582 .33892 .33197 .3483 .32865 .34245 .32247 Metetra
.664 .741 .908 r
.34245 .32247 .3483 .32865 .35772 .32531 .35188 .31911 Metetra
.664 .741 .908 r
.35188 .31911 .35772 .32531 .36716 .32195 .36135 .31573 Metetra
.664 .741 .908 r
.36135 .31573 .36716 .32195 .37664 .31859 .37085 .31235 Metetra
.957 .633 .363 r
.37085 .31235 .37664 .31859 .38395 .36528 .37733 .37531 Metetra
.923 .619 .449 r
.37733 .37531 .38395 .36528 .39031 .44285 .3824 .48066 Metetra
.642 .34 .444 r
.3824 .48066 .39031 .44285 .39925 .46663 .39176 .49658 Metetra
.39176 .49658 .39925 .46663 .40965 .45459 .40347 .45338 Metetra
.967 .813 .638 r
.40347 .45338 .40965 .45459 .42034 .43278 .41457 .42181 Metetra
.868 .703 .674 r
.41457 .42181 .42034 .43278 .43116 .40417 .42529 .39835 Metetra
.895 .785 .731 r
.42529 .39835 .43116 .40417 .44169 .38244 .43575 .38075 Metetra
.908 .908 .81 r
.43575 .38075 .44169 .38244 .45201 .36623 .44605 .36788 Metetra
.713 .986 .829 r
.44605 .36788 .45201 .36623 .46215 .35665 .45622 .35988 Metetra
.45622 .35988 .46215 .35665 .47219 .35321 .46632 .35643 Metetra
.352 0 0 r
.46632 .35643 .47219 .35321 .48219 .35594 .47638 .35753 Metetra
.596 .046 0 r
.47638 .35753 .48219 .35594 .49219 .36533 .48645 .36353 Metetra
.712 .176 0 r
.48645 .36353 .49219 .36533 .50228 .38031 .49658 .37433 Metetra
.757 .286 0 r
.49658 .37433 .50228 .38031 .51249 .4023 .5068 .39108 Metetra
.754 .369 0 r
.5068 .39108 .51249 .4023 .52291 .41751 .51718 .41608 Metetra
.919 .531 .242 r
.51718 .41608 .52291 .41751 .53347 .4229 .52779 .45296 Metetra
.067 0 .229 r
.52779 .45296 .53347 .4229 .54391 .39203 .53846 .43006 Metetra
.93 .756 .277 r
.53846 .43006 .54391 .39203 .55371 .3066 .54836 .31644 Metetra
.998 .794 .45 r
.54836 .31644 .55371 .3066 .5634 .25231 .55804 .24563 Metetra
.664 .741 .908 r
.55804 .24563 .5634 .25231 .57359 .2487 .56826 .24199 Metetra
.664 .741 .908 r
.56826 .24199 .57359 .2487 .58382 .24507 .57851 .23833 Metetra
.664 .741 .908 r
.57851 .23833 .58382 .24507 .59408 .24142 .5888 .23466 Metetra
.664 .741 .908 r
.5888 .23466 .59408 .24142 .60439 .23777 .59913 .23098 Metetra
.664 .741 .908 r
.59913 .23098 .60439 .23777 .61473 .2341 .6095 .22729 Metetra
.664 .741 .908 r
.6095 .22729 .61473 .2341 .62511 .23041 .61991 .22358 Metetra
.664 .741 .908 r
.61991 .22358 .62511 .23041 .63553 .22672 .63035 .21985 Metetra
.664 .741 .908 r
.63035 .21985 .63553 .22672 .64599 .223 .64084 .21612 Metetra
.664 .741 .908 r
.64084 .21612 .64599 .223 .65649 .21928 .65136 .21237 Metetra
.664 .741 .908 r
.65136 .21237 .65649 .21928 .66702 .21554 .66192 .2086 Metetra
.664 .741 .908 r
.66192 .2086 .66702 .21554 .6776 .21179 .67253 .20482 Metetra
.664 .741 .908 r
.67253 .20482 .6776 .21179 .68822 .20802 .68317 .20103 Metetra
.664 .741 .908 r
.68317 .20103 .68822 .20802 .69887 .20424 .69385 .19722 Metetra
.664 .741 .908 r
.69385 .19722 .69887 .20424 .70957 .20044 .70458 .1934 Metetra
.664 .741 .908 r
.70458 .1934 .70957 .20044 .7203 .19663 .71534 .18956 Metetra
.664 .741 .908 r
.71534 .18956 .7203 .19663 .73108 .19281 .72615 .18571 Metetra
.664 .741 .908 r
.72615 .18571 .73108 .19281 .7419 .18897 .73699 .18184 Metetra
.664 .741 .908 r
.73699 .18184 .7419 .18897 .75276 .18512 .74788 .17796 Metetra
.664 .741 .908 r
.74788 .17796 .75276 .18512 .76366 .18125 .75881 .17407 Metetra
.664 .741 .908 r
.75881 .17407 .76366 .18125 .7746 .17736 .76978 .17016 Metetra
.664 .741 .908 r
.76978 .17016 .7746 .17736 .78558 .17347 .7808 .16623 Metetra
.664 .741 .908 r
.7808 .16623 .78558 .17347 .79661 .16955 .79185 .16229 Metetra
.664 .741 .908 r
.16309 .37835 .16934 .38417 .17817 .38102 .17193 .37518 Metetra
.664 .741 .908 r
.17193 .37518 .17817 .38102 .18703 .37787 .18081 .37201 Metetra
.664 .741 .908 r
.18081 .37201 .18703 .37787 .19592 .3747 .18972 .36882 Metetra
.664 .741 .908 r
.18972 .36882 .19592 .3747 .20484 .37152 .19866 .36562 Metetra
.664 .741 .908 r
.19866 .36562 .20484 .37152 .21379 .36833 .20763 .36241 Metetra
.664 .741 .908 r
.20763 .36241 .21379 .36833 .22277 .36512 .21663 .35918 Metetra
.664 .741 .908 r
.21663 .35918 .22277 .36512 .23179 .36191 .22566 .35595 Metetra
.664 .741 .908 r
.22566 .35595 .23179 .36191 .24083 .35869 .23473 .35271 Metetra
.664 .741 .908 r
.23473 .35271 .24083 .35869 .24991 .35545 .24382 .34945 Metetra
.664 .741 .908 r
.24382 .34945 .24991 .35545 .25902 .35221 .25295 .34618 Metetra
.664 .741 .908 r
.25295 .34618 .25902 .35221 .26816 .34895 .26211 .3429 Metetra
.664 .741 .908 r
.26211 .3429 .26816 .34895 .27733 .34568 .2713 .33961 Metetra
.664 .741 .908 r
.2713 .33961 .27733 .34568 .28654 .3424 .28052 .33631 Metetra
.664 .741 .908 r
.28052 .33631 .28654 .3424 .29577 .33911 .28978 .333 Metetra
.664 .741 .908 r
.28978 .333 .29577 .33911 .30504 .3358 .29907 .32967 Metetra
.664 .741 .908 r
.29907 .32967 .30504 .3358 .31434 .33249 .30839 .32633 Metetra
.664 .741 .908 r
.30839 .32633 .31434 .33249 .32368 .32916 .31775 .32299 Metetra
.664 .741 .908 r
.31775 .32299 .32368 .32916 .33305 .32582 .32713 .31962 Metetra
.664 .741 .908 r
.32713 .31962 .33305 .32582 .34245 .32247 .33656 .31625 Metetra
.664 .741 .908 r
.33656 .31625 .34245 .32247 .35188 .31911 .34601 .31287 Metetra
.664 .741 .908 r
.34601 .31287 .35188 .31911 .36135 .31573 .3555 .30947 Metetra
.664 .741 .908 r
.3555 .30947 .36135 .31573 .37085 .31235 .36502 .30606 Metetra
.958 .641 .378 r
.36502 .30606 .37085 .31235 .37733 .37531 .37096 .37785 Metetra
.943 .642 .438 r
.37096 .37785 .37733 .37531 .3824 .48066 .37518 .49859 Metetra
.674 .321 .368 r
.37518 .49859 .3824 .48066 .39176 .49658 .38475 .51103 Metetra
.997 .834 .489 r
.38475 .51103 .39176 .49658 .40347 .45338 .39722 .45215 Metetra
.969 .796 .614 r
.39722 .45215 .40347 .45338 .41457 .42181 .40863 .41462 Metetra
.902 .754 .688 r
.40863 .41462 .41457 .42181 .42529 .39835 .41939 .39177 Metetra
.853 .776 .775 r
.41939 .39177 .42529 .39835 .43575 .38075 .42977 .37876 Metetra
.695 .925 .968 r
.42977 .37876 .43575 .38075 .44605 .36788 .43991 .37373 Metetra
.037 0 0 r
.43991 .37373 .44605 .36788 .45622 .35988 .45006 .36951 Metetra
.267 0 .031 r
.45006 .36951 .45622 .35988 .46632 .35643 .46023 .36604 Metetra
.308 0 .052 r
.46023 .36604 .46632 .35643 .47638 .35753 .47043 .36334 Metetra
.234 0 0 r
.47043 .36334 .47638 .35753 .48645 .36353 .48065 .36145 Metetra
.468 0 0 r
.48065 .36145 .48645 .36353 .49658 .37433 .49084 .36759 Metetra
.712 .246 0 r
.49084 .36759 .49658 .37433 .5068 .39108 .50106 .38366 Metetra
.898 .496 .079 r
.50106 .38366 .5068 .39108 .51718 .41608 .51138 .41463 Metetra
.938 .578 .298 r
.51138 .41463 .51718 .41608 .52779 .45296 .52195 .46734 Metetra
.52195 .46734 .52779 .45296 .53846 .43006 .53276 .44796 Metetra
.995 .759 .416 r
.53276 .44796 .53846 .43006 .54836 .31644 .54288 .31869 Metetra
.991 .759 .487 r
.54288 .31869 .54836 .31644 .55804 .24563 .55264 .23889 Metetra
.664 .741 .908 r
.55264 .23889 .55804 .24563 .56826 .24199 .56288 .23523 Metetra
.664 .741 .908 r
.56288 .23523 .56826 .24199 .57851 .23833 .57316 .23155 Metetra
.664 .741 .908 r
.57316 .23155 .57851 .23833 .5888 .23466 .58348 .22786 Metetra
.664 .741 .908 r
.58348 .22786 .5888 .23466 .59913 .23098 .59384 .22415 Metetra
.664 .741 .908 r
.59384 .22415 .59913 .23098 .6095 .22729 .60423 .22043 Metetra
.664 .741 .908 r
.60423 .22043 .6095 .22729 .61991 .22358 .61466 .21669 Metetra
.664 .741 .908 r
.61466 .21669 .61991 .22358 .63035 .21985 .62513 .21294 Metetra
.664 .741 .908 r
.62513 .21294 .63035 .21985 .64084 .21612 .63565 .20918 Metetra
.664 .741 .908 r
.63565 .20918 .64084 .21612 .65136 .21237 .6462 .2054 Metetra
.664 .741 .908 r
.6462 .2054 .65136 .21237 .66192 .2086 .65679 .20161 Metetra
.664 .741 .908 r
.65679 .20161 .66192 .2086 .67253 .20482 .66742 .19781 Metetra
.664 .741 .908 r
.66742 .19781 .67253 .20482 .68317 .20103 .67809 .19399 Metetra
.664 .741 .908 r
.67809 .19399 .68317 .20103 .69385 .19722 .6888 .19015 Metetra
.664 .741 .908 r
.6888 .19015 .69385 .19722 .70458 .1934 .69955 .1863 Metetra
.664 .741 .908 r
.69955 .1863 .70458 .1934 .71534 .18956 .71034 .18244 Metetra
.664 .741 .908 r
.71034 .18244 .71534 .18956 .72615 .18571 .72118 .17856 Metetra
.664 .741 .908 r
.72118 .17856 .72615 .18571 .73699 .18184 .73205 .17467 Metetra
.664 .741 .908 r
.73205 .17467 .73699 .18184 .74788 .17796 .74297 .17076 Metetra
.664 .741 .908 r
.74297 .17076 .74788 .17796 .75881 .17407 .75393 .16684 Metetra
.664 .741 .908 r
.75393 .16684 .75881 .17407 .76978 .17016 .76493 .1629 Metetra
.664 .741 .908 r
.76493 .1629 .76978 .17016 .7808 .16623 .77597 .15894 Metetra
.664 .741 .908 r
.77597 .15894 .7808 .16623 .79185 .16229 .78706 .15498 Metetra
.664 .741 .908 r
.1568 .3725 .16309 .37835 .17193 .37518 .16566 .36931 Metetra
.664 .741 .908 r
.16566 .36931 .17193 .37518 .18081 .37201 .17456 .36611 Metetra
.664 .741 .908 r
.17456 .36611 .18081 .37201 .18972 .36882 .18348 .3629 Metetra
.664 .741 .908 r
.18348 .3629 .18972 .36882 .19866 .36562 .19244 .35968 Metetra
.664 .741 .908 r
.19244 .35968 .19866 .36562 .20763 .36241 .20143 .35645 Metetra
.664 .741 .908 r
.20143 .35645 .20763 .36241 .21663 .35918 .21045 .35321 Metetra
.664 .741 .908 r
.21045 .35321 .21663 .35918 .22566 .35595 .2195 .34995 Metetra
.664 .741 .908 r
.2195 .34995 .22566 .35595 .23473 .35271 .22858 .34669 Metetra
.664 .741 .908 r
.22858 .34669 .23473 .35271 .24382 .34945 .2377 .34341 Metetra
.664 .741 .908 r
.2377 .34341 .24382 .34945 .25295 .34618 .24684 .34012 Metetra
.664 .741 .908 r
.24684 .34012 .25295 .34618 .26211 .3429 .25602 .33682 Metetra
.664 .741 .908 r
.25602 .33682 .26211 .3429 .2713 .33961 .26523 .33351 Metetra
.664 .741 .908 r
.26523 .33351 .2713 .33961 .28052 .33631 .27447 .33018 Metetra
.664 .741 .908 r
.27447 .33018 .28052 .33631 .28978 .333 .28375 .32685 Metetra
.664 .741 .908 r
.28375 .32685 .28978 .333 .29907 .32967 .29306 .3235 Metetra
.664 .741 .908 r
.29306 .3235 .29907 .32967 .30839 .32633 .3024 .32014 Metetra
.664 .741 .908 r
.3024 .32014 .30839 .32633 .31775 .32299 .31178 .31677 Metetra
.664 .741 .908 r
.31178 .31677 .31775 .32299 .32713 .31962 .32118 .31339 Metetra
.664 .741 .908 r
.32118 .31339 .32713 .31962 .33656 .31625 .33063 .30999 Metetra
.664 .741 .908 r
.33063 .30999 .33656 .31625 .34601 .31287 .3401 .30659 Metetra
.664 .741 .908 r
.3401 .30659 .34601 .31287 .3555 .30947 .34961 .30317 Metetra
.664 .741 .908 r
.34961 .30317 .3555 .30947 .36502 .30606 .35915 .29974 Metetra
.959 .643 .382 r
.35915 .29974 .36502 .30606 .37096 .37785 .36482 .37432 Metetra
.955 .655 .426 r
.36482 .37432 .37096 .37785 .37518 .49859 .3686 .50001 Metetra
.752 .266 .081 r
.3686 .50001 .37518 .49859 .38475 .51103 .37823 .51119 Metetra
.974 .762 .557 r
.37823 .51119 .38475 .51103 .39722 .45215 .39108 .44704 Metetra
.946 .757 .616 r
.39108 .44704 .39722 .45215 .40863 .41462 .40264 .40777 Metetra
.904 .761 .693 r
.40264 .40777 .40863 .41462 .41939 .39177 .41344 .38555 Metetra
.841 .786 .799 r
.41344 .38555 .41939 .39177 .42977 .37876 .42381 .3741 Metetra
.608 .799 .973 r
.42381 .3741 .42977 .37876 .43991 .37373 .43392 .37141 Metetra
.569 .879 .993 r
.43392 .37141 .43991 .37373 .45006 .36951 .44408 .36831 Metetra
.539 .902 .967 r
.44408 .36831 .45006 .36951 .46023 .36604 .45429 .36482 Metetra
.572 .915 .967 r
.45429 .36482 .46023 .36604 .47043 .36334 .46454 .36095 Metetra
.652 .906 .981 r
.46454 .36095 .47043 .36334 .48065 .36145 .47484 .35667 Metetra
0 .401 .825 r
.47484 .35667 .48065 .36145 .49084 .36759 .48507 .36119 Metetra
.707 .232 0 r
.48507 .36119 .49084 .36759 .50106 .38366 .49528 .37659 Metetra
.908 .511 .11 r
.49528 .37659 .50106 .38366 .51138 .41463 .50555 .40926 Metetra
.95 .596 .275 r
.50555 .40926 .51138 .41463 .52195 .46734 .51604 .46725 Metetra
.954 .928 .735 r
.51604 .46725 .52195 .46734 .53276 .44796 .52692 .44911 Metetra
.983 .728 .468 r
.52692 .44911 .53276 .44796 .54288 .31869 .5373 .31478 Metetra
.976 .735 .506 r
.5373 .31478 .54288 .31869 .55264 .23889 .54721 .23212 Metetra
.664 .741 .908 r
.54721 .23212 .55264 .23889 .56288 .23523 .55748 .22842 Metetra
.664 .741 .908 r
.55748 .22842 .56288 .23523 .57316 .23155 .56778 .22472 Metetra
.664 .741 .908 r
.56778 .22472 .57316 .23155 .58348 .22786 .57812 .221 Metetra
.664 .741 .908 r
.57812 .221 .58348 .22786 .59384 .22415 .5885 .21727 Metetra
.664 .741 .908 r
.5885 .21727 .59384 .22415 .60423 .22043 .59892 .21352 Metetra
.664 .741 .908 r
.59892 .21352 .60423 .22043 .61466 .21669 .60938 .20976 Metetra
.664 .741 .908 r
.60938 .20976 .61466 .21669 .62513 .21294 .61988 .20599 Metetra
.664 .741 .908 r
.61988 .20599 .62513 .21294 .63565 .20918 .63042 .2022 Metetra
.664 .741 .908 r
.63042 .2022 .63565 .20918 .6462 .2054 .641 .19839 Metetra
.664 .741 .908 r
.641 .19839 .6462 .2054 .65679 .20161 .65162 .19457 Metetra
.664 .741 .908 r
.65162 .19457 .65679 .20161 .66742 .19781 .66227 .19074 Metetra
.664 .741 .908 r
.66227 .19074 .66742 .19781 .67809 .19399 .67297 .1869 Metetra
.664 .741 .908 r
.67297 .1869 .67809 .19399 .6888 .19015 .68371 .18303 Metetra
.664 .741 .908 r
.68371 .18303 .6888 .19015 .69955 .1863 .69449 .17916 Metetra
.664 .741 .908 r
.69449 .17916 .69955 .1863 .71034 .18244 .70531 .17527 Metetra
.664 .741 .908 r
.70531 .17527 .71034 .18244 .72118 .17856 .71617 .17136 Metetra
.664 .741 .908 r
.71617 .17136 .72118 .17856 .73205 .17467 .72708 .16744 Metetra
.664 .741 .908 r
.72708 .16744 .73205 .17467 .74297 .17076 .73802 .1635 Metetra
.664 .741 .908 r
.73802 .1635 .74297 .17076 .75393 .16684 .74901 .15955 Metetra
.664 .741 .908 r
.74901 .15955 .75393 .16684 .76493 .1629 .76004 .15559 Metetra
.664 .741 .908 r
.76004 .15559 .76493 .1629 .77597 .15894 .77112 .15161 Metetra
.664 .741 .908 r
.77112 .15161 .77597 .15894 .78706 .15498 .78223 .14761 Metetra
.664 .741 .908 r
.15047 .3666 .1568 .3725 .16566 .36931 .15935 .3634 Metetra
.664 .741 .908 r
.15935 .3634 .16566 .36931 .17456 .36611 .16826 .36018 Metetra
.664 .741 .908 r
.16826 .36018 .17456 .36611 .18348 .3629 .17721 .35695 Metetra
.664 .741 .908 r
.17721 .35695 .18348 .3629 .19244 .35968 .18618 .35371 Metetra
.664 .741 .908 r
.18618 .35371 .19244 .35968 .20143 .35645 .19519 .35045 Metetra
.664 .741 .908 r
.19519 .35045 .20143 .35645 .21045 .35321 .20423 .34719 Metetra
.664 .741 .908 r
.20423 .34719 .21045 .35321 .2195 .34995 .21329 .34391 Metetra
.664 .741 .908 r
.21329 .34391 .2195 .34995 .22858 .34669 .2224 .34063 Metetra
.664 .741 .908 r
.2224 .34063 .22858 .34669 .2377 .34341 .23153 .33733 Metetra
.664 .741 .908 r
.23153 .33733 .2377 .34341 .24684 .34012 .24069 .33402 Metetra
.664 .741 .908 r
.24069 .33402 .24684 .34012 .25602 .33682 .24989 .3307 Metetra
.664 .741 .908 r
.24989 .3307 .25602 .33682 .26523 .33351 .25912 .32736 Metetra
.664 .741 .908 r
.25912 .32736 .26523 .33351 .27447 .33018 .26838 .32402 Metetra
.664 .741 .908 r
.26838 .32402 .27447 .33018 .28375 .32685 .27768 .32066 Metetra
.664 .741 .908 r
.27768 .32066 .28375 .32685 .29306 .3235 .28701 .31729 Metetra
.664 .741 .908 r
.28701 .31729 .29306 .3235 .3024 .32014 .29637 .31391 Metetra
.664 .741 .908 r
.29637 .31391 .3024 .32014 .31178 .31677 .30576 .31052 Metetra
.664 .741 .908 r
.30576 .31052 .31178 .31677 .32118 .31339 .31519 .30711 Metetra
.664 .741 .908 r
.31519 .30711 .32118 .31339 .33063 .30999 .32466 .30369 Metetra
.664 .741 .908 r
.32466 .30369 .33063 .30999 .3401 .30659 .33415 .30026 Metetra
.664 .741 .908 r
.33415 .30026 .3401 .30659 .34961 .30317 .34368 .29682 Metetra
.664 .741 .908 r
.34368 .29682 .34961 .30317 .35915 .29974 .35325 .29337 Metetra
.957 .632 .361 r
.35325 .29337 .35915 .29974 .36482 .37432 .35941 .35591 Metetra
.978 .679 .36 r
.35941 .35591 .36482 .37432 .3686 .50001 .36394 .46059 Metetra
.31 .219 .588 r
.36394 .46059 .3686 .50001 .37823 .51119 .37327 .47602 Metetra
.803 .579 .599 r
.37327 .47602 .37823 .51119 .39108 .44704 .38529 .43248 Metetra
.866 .675 .641 r
.38529 .43248 .39108 .44704 .40264 .40777 .39658 .40185 Metetra
.911 .777 .7 r
.39658 .40185 .40264 .40777 .41344 .38555 .40741 .38024 Metetra
.901 .798 .738 r
.40741 .38024 .41344 .38555 .42381 .3741 .41802 .36288 Metetra
.809 .687 .729 r
.41802 .36288 .42381 .3741 .43392 .37141 .42848 .34896 Metetra
.668 .523 .678 r
.42848 .34896 .43392 .37141 .44408 .36831 .43876 .34042 Metetra
.589 .448 .658 r
.43876 .34042 .44408 .36831 .45429 .36482 .44893 .3369 Metetra
.515 .398 .659 r
.44893 .3369 .45429 .36482 .46454 .36095 .45903 .33839 Metetra
.379 .336 .684 r
.45903 .33839 .46454 .36095 .47484 .35667 .4691 .34531 Metetra
0 .168 .703 r
.4691 .34531 .47484 .35667 .48507 .36119 .47923 .35572 Metetra
.723 .233 0 r
.47923 .35572 .48507 .36119 .49528 .37659 .48945 .37046 Metetra
.861 .427 .005 r
.48945 .37046 .49528 .37659 .50555 .40926 .49975 .39435 Metetra
.831 .484 0 r
.49975 .39435 .50555 .40926 .51604 .46725 .51022 .43143 Metetra
.721 .52 .617 r
.51022 .43143 .51604 .46725 .52692 .44911 .52107 .40888 Metetra
.896 .634 .533 r
.52107 .40888 .52692 .44911 .5373 .31478 .53163 .2958 Metetra
.922 .676 .549 r
.53163 .2958 .5373 .31478 .54721 .23212 .54174 .22529 Metetra
.664 .741 .908 r
.54174 .22529 .54721 .23212 .55748 .22842 .55203 .22157 Metetra
.664 .741 .908 r
.55203 .22157 .55748 .22842 .56778 .22472 .56236 .21784 Metetra
.664 .741 .908 r
.56236 .21784 .56778 .22472 .57812 .221 .57273 .2141 Metetra
.664 .741 .908 r
.57273 .2141 .57812 .221 .5885 .21727 .58314 .21034 Metetra
.664 .741 .908 r
.58314 .21034 .5885 .21727 .59892 .21352 .59358 .20657 Metetra
.664 .741 .908 r
.59358 .20657 .59892 .21352 .60938 .20976 .60407 .20278 Metetra
.664 .741 .908 r
.60407 .20278 .60938 .20976 .61988 .20599 .61459 .19898 Metetra
.664 .741 .908 r
.61459 .19898 .61988 .20599 .63042 .2022 .62516 .19516 Metetra
.664 .741 .908 r
.62516 .19516 .63042 .2022 .641 .19839 .63576 .19133 Metetra
.664 .741 .908 r
.63576 .19133 .641 .19839 .65162 .19457 .64641 .18749 Metetra
.664 .741 .908 r
.64641 .18749 .65162 .19457 .66227 .19074 .65709 .18363 Metetra
.664 .741 .908 r
.65709 .18363 .66227 .19074 .67297 .1869 .66782 .17976 Metetra
.664 .741 .908 r
.66782 .17976 .67297 .1869 .68371 .18303 .67859 .17587 Metetra
.664 .741 .908 r
.67859 .17587 .68371 .18303 .69449 .17916 .68939 .17196 Metetra
.664 .741 .908 r
.68939 .17196 .69449 .17916 .70531 .17527 .70024 .16804 Metetra
.664 .741 .908 r
.70024 .16804 .70531 .17527 .71617 .17136 .71113 .16411 Metetra
.664 .741 .908 r
.71113 .16411 .71617 .17136 .72708 .16744 .72207 .16016 Metetra
.664 .741 .908 r
.72207 .16016 .72708 .16744 .73802 .1635 .73304 .1562 Metetra
.664 .741 .908 r
.73304 .1562 .73802 .1635 .74901 .15955 .74406 .15222 Metetra
.664 .741 .908 r
.74406 .15222 .74901 .15955 .76004 .15559 .75512 .14822 Metetra
.664 .741 .908 r
.75512 .14822 .76004 .15559 .77112 .15161 .76622 .14421 Metetra
.664 .741 .908 r
.76622 .14421 .77112 .15161 .78223 .14761 .77737 .14019 Metetra
.664 .741 .908 r
.1441 .36067 .15047 .3666 .15935 .3634 .153 .35744 Metetra
.664 .741 .908 r
.153 .35744 .15935 .3634 .16826 .36018 .16193 .3542 Metetra
.664 .741 .908 r
.16193 .3542 .16826 .36018 .17721 .35695 .17089 .35095 Metetra
.664 .741 .908 r
.17089 .35095 .17721 .35695 .18618 .35371 .17988 .34769 Metetra
.664 .741 .908 r
.17988 .34769 .18618 .35371 .19519 .35045 .18891 .34442 Metetra
.664 .741 .908 r
.18891 .34442 .19519 .35045 .20423 .34719 .19796 .34113 Metetra
.664 .741 .908 r
.19796 .34113 .20423 .34719 .21329 .34391 .20705 .33784 Metetra
.664 .741 .908 r
.20705 .33784 .21329 .34391 .2224 .34063 .21617 .33453 Metetra
.664 .741 .908 r
.21617 .33453 .2224 .34063 .23153 .33733 .22532 .33121 Metetra
.664 .741 .908 r
.22532 .33121 .23153 .33733 .24069 .33402 .23451 .32788 Metetra
.664 .741 .908 r
.23451 .32788 .24069 .33402 .24989 .3307 .24372 .32453 Metetra
.664 .741 .908 r
.24372 .32453 .24989 .3307 .25912 .32736 .25297 .32118 Metetra
.664 .741 .908 r
.25297 .32118 .25912 .32736 .26838 .32402 .26225 .31781 Metetra
.664 .741 .908 r
.26225 .31781 .26838 .32402 .27768 .32066 .27157 .31443 Metetra
.664 .741 .908 r
.27157 .31443 .27768 .32066 .28701 .31729 .28092 .31104 Metetra
.664 .741 .908 r
.28092 .31104 .28701 .31729 .29637 .31391 .2903 .30764 Metetra
.664 .741 .908 r
.2903 .30764 .29637 .31391 .30576 .31052 .29971 .30422 Metetra
.664 .741 .908 r
.29971 .30422 .30576 .31052 .31519 .30711 .30916 .30079 Metetra
.664 .741 .908 r
.30916 .30079 .31519 .30711 .32466 .30369 .31865 .29735 Metetra
.664 .741 .908 r
.31865 .29735 .32466 .30369 .33415 .30026 .32816 .2939 Metetra
.664 .741 .908 r
.32816 .2939 .33415 .30026 .34368 .29682 .33771 .29044 Metetra
.664 .741 .908 r
.33771 .29044 .34368 .29682 .35325 .29337 .3473 .28696 Metetra
.953 .612 .322 r
.3473 .28696 .35325 .29337 .35941 .35591 .35412 .33526 Metetra
.974 .671 .299 r
.35412 .33526 .35941 .35591 .36394 .46059 .35965 .41565 Metetra
.235 .152 .553 r
.35965 .41565 .36394 .46059 .37327 .47602 .36855 .43724 Metetra
.683 .488 .617 r
.36855 .43724 .37327 .47602 .38529 .43248 .3794 .41974 Metetra
.843 .682 .682 r
.3794 .41974 .38529 .43248 .39658 .40185 .39036 .39852 Metetra
.942 .813 .688 r
.39036 .39852 .39658 .40185 .40741 .38024 .40134 .37473 Metetra
.92 .783 .694 r
.40134 .37473 .40741 .38024 .41802 .36288 .41219 .35219 Metetra
.866 .708 .685 r
.41219 .35219 .41802 .36288 .42848 .34896 .42292 .33068 Metetra
.732 .585 .691 r
.42292 .33068 .42848 .34896 .43876 .34042 .4333 .3185 Metetra
.601 .484 .691 r
.4333 .3185 .43876 .34042 .44893 .3369 .44345 .31494 Metetra
.421 .367 .692 r
.44345 .31494 .44893 .3369 .45903 .33839 .45343 .32002 Metetra
0 .115 .632 r
.45343 .32002 .45903 .33839 .4691 .34531 .46333 .33448 Metetra
0 0 .469 r
.46333 .33448 .4691 .34531 .47923 .35572 .47336 .35004 Metetra
.773 .298 0 r
.47336 .35004 .47923 .35572 .48945 .37046 .48354 .36693 Metetra
.76 .254 0 r
.48354 .36693 .48945 .37046 .49975 .39435 .49392 .38129 Metetra
0 .201 .716 r
.49392 .38129 .49975 .39435 .51022 .43143 .50448 .39195 Metetra
.74 .526 .604 r
.50448 .39195 .51022 .43143 .52107 .40888 .5153 .36307 Metetra
.86 .604 .549 r
.5153 .36307 .52107 .40888 .53163 .2958 .52597 .27455 Metetra
.896 .659 .571 r
.52597 .27455 .53163 .2958 .54174 .22529 .53623 .21842 Metetra
.664 .741 .908 r
.53623 .21842 .54174 .22529 .55203 .22157 .54655 .21468 Metetra
.664 .741 .908 r
.54655 .21468 .55203 .22157 .56236 .21784 .5569 .21092 Metetra
.664 .741 .908 r
.5569 .21092 .56236 .21784 .57273 .2141 .5673 .20715 Metetra
.664 .741 .908 r
.5673 .20715 .57273 .2141 .58314 .21034 .57773 .20336 Metetra
.664 .741 .908 r
.57773 .20336 .58314 .21034 .59358 .20657 .5882 .19956 Metetra
.664 .741 .908 r
.5882 .19956 .59358 .20657 .60407 .20278 .59871 .19575 Metetra
.664 .741 .908 r
.59871 .19575 .60407 .20278 .61459 .19898 .60927 .19192 Metetra
.664 .741 .908 r
.60927 .19192 .61459 .19898 .62516 .19516 .61986 .18808 Metetra
.664 .741 .908 r
.61986 .18808 .62516 .19516 .63576 .19133 .63049 .18422 Metetra
.664 .741 .908 r
.63049 .18422 .63576 .19133 .64641 .18749 .64116 .18035 Metetra
.664 .741 .908 r
.64116 .18035 .64641 .18749 .65709 .18363 .65188 .17647 Metetra
.664 .741 .908 r
.65188 .17647 .65709 .18363 .66782 .17976 .66263 .17256 Metetra
.664 .741 .908 r
.66263 .17256 .66782 .17976 .67859 .17587 .67342 .16865 Metetra
.664 .741 .908 r
.67342 .16865 .67859 .17587 .68939 .17196 .68426 .16472 Metetra
.664 .741 .908 r
.68426 .16472 .68939 .17196 .70024 .16804 .69514 .16077 Metetra
.664 .741 .908 r
.69514 .16077 .70024 .16804 .71113 .16411 .70606 .15681 Metetra
.664 .741 .908 r
.70606 .15681 .71113 .16411 .72207 .16016 .71702 .15283 Metetra
.664 .741 .908 r
.71702 .15283 .72207 .16016 .73304 .1562 .72803 .14884 Metetra
.664 .741 .908 r
.72803 .14884 .73304 .1562 .74406 .15222 .73907 .14483 Metetra
.664 .741 .908 r
.73907 .14483 .74406 .15222 .75512 .14822 .75016 .14081 Metetra
.664 .741 .908 r
.75016 .14081 .75512 .14822 .76622 .14421 .7613 .13677 Metetra
.664 .741 .908 r
.7613 .13677 .76622 .14421 .77737 .14019 .77247 .13272 Metetra
.664 .741 .908 r
.13769 .3547 .1441 .36067 .153 .35744 .14661 .35145 Metetra
.664 .741 .908 r
.14661 .35145 .153 .35744 .16193 .3542 .15555 .34819 Metetra
.664 .741 .908 r
.15555 .34819 .16193 .3542 .17089 .35095 .16453 .34492 Metetra
.664 .741 .908 r
.16453 .34492 .17089 .35095 .17988 .34769 .17354 .34164 Metetra
.664 .741 .908 r
.17354 .34164 .17988 .34769 .18891 .34442 .18259 .33834 Metetra
.664 .741 .908 r
.18259 .33834 .18891 .34442 .19796 .34113 .19166 .33504 Metetra
.664 .741 .908 r
.19166 .33504 .19796 .34113 .20705 .33784 .20077 .33172 Metetra
.664 .741 .908 r
.20077 .33172 .20705 .33784 .21617 .33453 .2099 .32839 Metetra
.664 .741 .908 r
.2099 .32839 .21617 .33453 .22532 .33121 .21907 .32505 Metetra
.664 .741 .908 r
.21907 .32505 .22532 .33121 .23451 .32788 .22828 .32169 Metetra
.664 .741 .908 r
.22828 .32169 .23451 .32788 .24372 .32453 .23751 .31833 Metetra
.664 .741 .908 r
.23751 .31833 .24372 .32453 .25297 .32118 .24678 .31495 Metetra
.664 .741 .908 r
.24678 .31495 .25297 .32118 .26225 .31781 .25608 .31156 Metetra
.664 .741 .908 r
.25608 .31156 .26225 .31781 .27157 .31443 .26542 .30816 Metetra
.664 .741 .908 r
.26542 .30816 .27157 .31443 .28092 .31104 .27479 .30475 Metetra
.664 .741 .908 r
.27479 .30475 .28092 .31104 .2903 .30764 .28419 .30132 Metetra
.664 .741 .908 r
.28419 .30132 .2903 .30764 .29971 .30422 .29362 .29788 Metetra
.664 .741 .908 r
.29362 .29788 .29971 .30422 .30916 .30079 .30309 .29443 Metetra
.664 .741 .908 r
.30309 .29443 .30916 .30079 .31865 .29735 .3126 .29097 Metetra
.664 .741 .908 r
.3126 .29097 .31865 .29735 .32816 .2939 .32213 .28749 Metetra
.664 .741 .908 r
.32213 .28749 .32816 .2939 .33771 .29044 .33171 .28401 Metetra
.664 .741 .908 r
.33171 .28401 .33771 .29044 .3473 .28696 .34131 .2805 Metetra
.923 .531 .179 r
.34131 .2805 .3473 .28696 .35412 .33526 .3492 .30828 Metetra
.788 .534 0 r
.3492 .30828 .35412 .33526 .35965 .41565 .35633 .35458 Metetra
.174 .083 .504 r
.35633 .35458 .35965 .41565 .36855 .43724 .36446 .38774 Metetra
.219 .132 .538 r
.36446 .38774 .36855 .43724 .3794 .41974 .37325 .4123 Metetra
.8 .756 .813 r
.37325 .4123 .3794 .41974 .39036 .39852 .38375 .40276 Metetra
.993 .863 .601 r
.38375 .40276 .39036 .39852 .40134 .37473 .39524 .36874 Metetra
.923 .77 .673 r
.39524 .36874 .40134 .37473 .41219 .35219 .40627 .34312 Metetra
.869 .731 .707 r
.40627 .34312 .41219 .35219 .42292 .33068 .41696 .3242 Metetra
.834 .784 .804 r
.41696 .3242 .42292 .33068 .4333 .3185 .42735 .31324 Metetra
.657 .795 .948 r
.42735 .31324 .4333 .3185 .44345 .31494 .43752 .30965 Metetra
.031 .462 .877 r
.43752 .30965 .44345 .31494 .45343 .32002 .44755 .31346 Metetra
.569 .086 0 r
.44755 .31346 .45343 .32002 .46333 .33448 .45749 .32527 Metetra
.703 .281 0 r
.45749 .32527 .46333 .33448 .47336 .35004 .46745 .34388 Metetra
.889 .472 .072 r
.46745 .34388 .47336 .35004 .48354 .36693 .47746 .37102 Metetra
.45 0 0 r
.47746 .37102 .48354 .36693 .49392 .38129 .48801 .37356 Metetra
.933 .753 .637 r
.48801 .37356 .49392 .38129 .50448 .39195 .49892 .34166 Metetra
.751 .521 .583 r
.49892 .34166 .50448 .39195 .5153 .36307 .50972 .30097 Metetra
.76 .519 .568 r
.50972 .30097 .5153 .36307 .52597 .27455 .52034 .2469 Metetra
.816 .596 .604 r
.52034 .2469 .52597 .27455 .53623 .21842 .53069 .2115 Metetra
.664 .741 .908 r
.53069 .2115 .53623 .21842 .54655 .21468 .54103 .20773 Metetra
.664 .741 .908 r
.54103 .20773 .54655 .21468 .5569 .21092 .55141 .20395 Metetra
.664 .741 .908 r
.55141 .20395 .5569 .21092 .5673 .20715 .56183 .20015 Metetra
.664 .741 .908 r
.56183 .20015 .5673 .20715 .57773 .20336 .57229 .19634 Metetra
.664 .741 .908 r
.57229 .19634 .57773 .20336 .5882 .19956 .58279 .19251 Metetra
.664 .741 .908 r
.58279 .19251 .5882 .19956 .59871 .19575 .59332 .18867 Metetra
.664 .741 .908 r
.59332 .18867 .59871 .19575 .60927 .19192 .6039 .18482 Metetra
.664 .741 .908 r
.6039 .18482 .60927 .19192 .61986 .18808 .61452 .18095 Metetra
.664 .741 .908 r
.61452 .18095 .61986 .18808 .63049 .18422 .62518 .17706 Metetra
.664 .741 .908 r
.62518 .17706 .63049 .18422 .64116 .18035 .63588 .17317 Metetra
.664 .741 .908 r
.63588 .17317 .64116 .18035 .65188 .17647 .64662 .16925 Metetra
.664 .741 .908 r
.64662 .16925 .65188 .17647 .66263 .17256 .6574 .16532 Metetra
.664 .741 .908 r
.6574 .16532 .66263 .17256 .67342 .16865 .66823 .16138 Metetra
.664 .741 .908 r
.66823 .16138 .67342 .16865 .68426 .16472 .67909 .15742 Metetra
.664 .741 .908 r
.67909 .15742 .68426 .16472 .69514 .16077 .69 .15345 Metetra
.664 .741 .908 r
.69 .15345 .69514 .16077 .70606 .15681 .70095 .14946 Metetra
.664 .741 .908 r
.70095 .14946 .70606 .15681 .71702 .15283 .71194 .14545 Metetra
.664 .741 .908 r
.71194 .14545 .71702 .15283 .72803 .14884 .72297 .14143 Metetra
.664 .741 .908 r
.72297 .14143 .72803 .14884 .73907 .14483 .73405 .13739 Metetra
.664 .741 .908 r
.73405 .13739 .73907 .14483 .75016 .14081 .74517 .13334 Metetra
.664 .741 .908 r
.74517 .13334 .75016 .14081 .7613 .13677 .75634 .12927 Metetra
.664 .741 .908 r
.75634 .12927 .7613 .13677 .77247 .13272 .76754 .12519 Metetra
.664 .741 .908 r
.13124 .3487 .13769 .3547 .14661 .35145 .14017 .34543 Metetra
.664 .741 .908 r
.14017 .34543 .14661 .35145 .15555 .34819 .14914 .34214 Metetra
.664 .741 .908 r
.14914 .34214 .15555 .34819 .16453 .34492 .15813 .33885 Metetra
.664 .741 .908 r
.15813 .33885 .16453 .34492 .17354 .34164 .16716 .33555 Metetra
.664 .741 .908 r
.16716 .33555 .17354 .34164 .18259 .33834 .17622 .33223 Metetra
.664 .741 .908 r
.17622 .33223 .18259 .33834 .19166 .33504 .18532 .3289 Metetra
.664 .741 .908 r
.18532 .3289 .19166 .33504 .20077 .33172 .19444 .32556 Metetra
.664 .741 .908 r
.19444 .32556 .20077 .33172 .2099 .32839 .2036 .32221 Metetra
.664 .741 .908 r
.2036 .32221 .2099 .32839 .21907 .32505 .21279 .31885 Metetra
.664 .741 .908 r
.21279 .31885 .21907 .32505 .22828 .32169 .22201 .31547 Metetra
.664 .741 .908 r
.22201 .31547 .22828 .32169 .23751 .31833 .23126 .31208 Metetra
.664 .741 .908 r
.23126 .31208 .23751 .31833 .24678 .31495 .24055 .30868 Metetra
.664 .741 .908 r
.24055 .30868 .24678 .31495 .25608 .31156 .24987 .30527 Metetra
.664 .741 .908 r
.24987 .30527 .25608 .31156 .26542 .30816 .25923 .30185 Metetra
.664 .741 .908 r
.25923 .30185 .26542 .30816 .27479 .30475 .26861 .29841 Metetra
.664 .741 .908 r
.26861 .29841 .27479 .30475 .28419 .30132 .27804 .29496 Metetra
.664 .741 .908 r
.27804 .29496 .28419 .30132 .29362 .29788 .28749 .2915 Metetra
.664 .741 .908 r
.28749 .2915 .29362 .29788 .30309 .29443 .29698 .28803 Metetra
.664 .741 .908 r
.29698 .28803 .30309 .29443 .3126 .29097 .30651 .28454 Metetra
.664 .741 .908 r
.30651 .28454 .3126 .29097 .32213 .28749 .31606 .28104 Metetra
.664 .741 .908 r
.31606 .28104 .32213 .28749 .33171 .28401 .32566 .27753 Metetra
.664 .741 .908 r
.32566 .27753 .33171 .28401 .34131 .2805 .33529 .27401 Metetra
.569 .08 0 r
.33529 .27401 .34131 .2805 .3492 .30828 .34414 .2843 Metetra
0 .028 .552 r
.34414 .2843 .3492 .30828 .35633 .35458 .35269 .30246 Metetra
0 0 .432 r
.35269 .30246 .35633 .35458 .36446 .38774 .36024 .34299 Metetra
0 0 .206 r
.36024 .34299 .36446 .38774 .37325 .4123 .36732 .39936 Metetra
.468 .503 .811 r
.36732 .39936 .37325 .4123 .38375 .40276 .37733 .40086 Metetra
.967 .789 .612 r
.37733 .40086 .38375 .40276 .39524 .36874 .38913 .36208 Metetra
.92 .761 .667 r
.38913 .36208 .39524 .36874 .40627 .34312 .40026 .3354 Metetra
.873 .755 .729 r
.40026 .3354 .40627 .34312 .41696 .3242 .41094 .31832 Metetra
.83 .803 .825 r
.41094 .31832 .41696 .3242 .42735 .31324 .42134 .30823 Metetra
.655 .806 .955 r
.42134 .30823 .42735 .31324 .43752 .30965 .43154 .30462 Metetra
.111 .529 .913 r
.43154 .30462 .43752 .30965 .44755 .31346 .4416 .30751 Metetra
0 .004 .504 r
.4416 .30751 .44755 .31346 .45749 .32527 .45159 .31743 Metetra
.781 .341 0 r
.45159 .31743 .45749 .32527 .46745 .34388 .4615 .33705 Metetra
.91 .511 .119 r
.4615 .33705 .46745 .34388 .47746 .37102 .47141 .36893 Metetra
.823 .942 .903 r
.47141 .36893 .47746 .37102 .48801 .37356 .48213 .36028 Metetra
.937 .702 .558 r
.48213 .36028 .48801 .37356 .49892 .34166 .49342 .29619 Metetra
.788 .551 .578 r
.49342 .29619 .49892 .34166 .50972 .30097 .50424 .24797 Metetra
.687 .47 .587 r
.50424 .24797 .50972 .30097 .52034 .2469 .51473 .2223 Metetra
.742 .559 .646 r
.51473 .2223 .52034 .2469 .53069 .2115 .5251 .20453 Metetra
.664 .741 .908 r
.5251 .20453 .53069 .2115 .54103 .20773 .53547 .20073 Metetra
.664 .741 .908 r
.53547 .20073 .54103 .20773 .55141 .20395 .54588 .19693 Metetra
.664 .741 .908 r
.54588 .19693 .55141 .20395 .56183 .20015 .55632 .1931 Metetra
.664 .741 .908 r
.55632 .1931 .56183 .20015 .57229 .19634 .56681 .18926 Metetra
.664 .741 .908 r
.56681 .18926 .57229 .19634 .58279 .19251 .57733 .18541 Metetra
.664 .741 .908 r
.57733 .18541 .58279 .19251 .59332 .18867 .5879 .18155 Metetra
.664 .741 .908 r
.5879 .18155 .59332 .18867 .6039 .18482 .5985 .17766 Metetra
.664 .741 .908 r
.5985 .17766 .6039 .18482 .61452 .18095 .60915 .17377 Metetra
.664 .741 .908 r
.60915 .17377 .61452 .18095 .62518 .17706 .61983 .16985 Metetra
.664 .741 .908 r
.61983 .16985 .62518 .17706 .63588 .17317 .63056 .16593 Metetra
.664 .741 .908 r
.63056 .16593 .63588 .17317 .64662 .16925 .64133 .16199 Metetra
.664 .741 .908 r
.64133 .16199 .64662 .16925 .6574 .16532 .65214 .15803 Metetra
.664 .741 .908 r
.65214 .15803 .6574 .16532 .66823 .16138 .66299 .15406 Metetra
.664 .741 .908 r
.66299 .15406 .66823 .16138 .67909 .15742 .67389 .15007 Metetra
.664 .741 .908 r
.67389 .15007 .67909 .15742 .69 .15345 .68482 .14607 Metetra
.664 .741 .908 r
.68482 .14607 .69 .15345 .70095 .14946 .6958 .14205 Metetra
.664 .741 .908 r
.6958 .14205 .70095 .14946 .71194 .14545 .70682 .13801 Metetra
.664 .741 .908 r
.70682 .13801 .71194 .14545 .72297 .14143 .71788 .13396 Metetra
.664 .741 .908 r
.71788 .13396 .72297 .14143 .73405 .13739 .72899 .1299 Metetra
.664 .741 .908 r
.72899 .1299 .73405 .13739 .74517 .13334 .74014 .12582 Metetra
.664 .741 .908 r
.74014 .12582 .74517 .13334 .75634 .12927 .75134 .12172 Metetra
.664 .741 .908 r
.75134 .12172 .75634 .12927 .76754 .12519 .76258 .11761 Metetra
.664 .741 .908 r
.12474 .34265 .13124 .3487 .14017 .34543 .1337 .33936 Metetra
.664 .741 .908 r
.1337 .33936 .14017 .34543 .14914 .34214 .14268 .33606 Metetra
.664 .741 .908 r
.14268 .33606 .14914 .34214 .15813 .33885 .15169 .33274 Metetra
.664 .741 .908 r
.15169 .33274 .15813 .33885 .16716 .33555 .16074 .32942 Metetra
.664 .741 .908 r
.16074 .32942 .16716 .33555 .17622 .33223 .16982 .32608 Metetra
.664 .741 .908 r
.16982 .32608 .17622 .33223 .18532 .3289 .17893 .32273 Metetra
.664 .741 .908 r
.17893 .32273 .18532 .3289 .19444 .32556 .18807 .31937 Metetra
.664 .741 .908 r
.18807 .31937 .19444 .32556 .2036 .32221 .19725 .31599 Metetra
.664 .741 .908 r
.19725 .31599 .2036 .32221 .21279 .31885 .20646 .31261 Metetra
.664 .741 .908 r
.20646 .31261 .21279 .31885 .22201 .31547 .2157 .30921 Metetra
.664 .741 .908 r
.2157 .30921 .22201 .31547 .23126 .31208 .22497 .3058 Metetra
.664 .741 .908 r
.22497 .3058 .23126 .31208 .24055 .30868 .23428 .30238 Metetra
.664 .741 .908 r
.23428 .30238 .24055 .30868 .24987 .30527 .24362 .29894 Metetra
.664 .741 .908 r
.24362 .29894 .24987 .30527 .25923 .30185 .25299 .29549 Metetra
.664 .741 .908 r
.25299 .29549 .25923 .30185 .26861 .29841 .2624 .29204 Metetra
.664 .741 .908 r
.2624 .29204 .26861 .29841 .27804 .29496 .27184 .28856 Metetra
.664 .741 .908 r
.27184 .28856 .27804 .29496 .28749 .2915 .28132 .28508 Metetra
.664 .741 .908 r
.28132 .28508 .28749 .2915 .29698 .28803 .29083 .28158 Metetra
.664 .741 .908 r
.29083 .28158 .29698 .28803 .30651 .28454 .30038 .27807 Metetra
.664 .741 .908 r
.30038 .27807 .30651 .28454 .31606 .28104 .30995 .27455 Metetra
.664 .741 .908 r
.30995 .27455 .31606 .28104 .32566 .27753 .31957 .27102 Metetra
.664 .741 .908 r
.31957 .27102 .32566 .27753 .33529 .27401 .32922 .26747 Metetra
.229 .537 .924 r
.32922 .26747 .33529 .27401 .34414 .2843 .33853 .27007 Metetra
.261 .344 .76 r
.33853 .27007 .34414 .2843 .35269 .30246 .34772 .27612 Metetra
0 0 .21 r
.34772 .27612 .35269 .30246 .36024 .34299 .3554 .31175 Metetra
.812 .565 .007 r
.3554 .31175 .36024 .34299 .36732 .39936 .36232 .36789 Metetra
.354 .273 .625 r
.36232 .36789 .36732 .39936 .37733 .40086 .37186 .3778 Metetra
.79 .597 .64 r
.37186 .3778 .37733 .40086 .38913 .36208 .38307 .35328 Metetra
.881 .736 .698 r
.38307 .35328 .38913 .36208 .40026 .3354 .39402 .33248 Metetra
.93 .851 .742 r
.39402 .33248 .40026 .3354 .41094 .31832 .40479 .31467 Metetra
.86 .871 .846 r
.40479 .31467 .41094 .31832 .42134 .30823 .41524 .30421 Metetra
.645 .843 .977 r
.41524 .30421 .42134 .30823 .43154 .30462 .42548 .30058 Metetra
0 .479 .855 r
.42548 .30058 .43154 .30462 .4416 .30751 .43555 .30378 Metetra
.656 .118 0 r
.43555 .30378 .4416 .30751 .45159 .31743 .44553 .31439 Metetra
.764 .254 0 r
.44553 .31439 .45159 .31743 .4615 .33705 .45556 .32805 Metetra
.672 .243 0 r
.45556 .32805 .4615 .33705 .47141 .36893 .46569 .34551 Metetra
.745 .569 .656 r
.46569 .34551 .47141 .36893 .48213 .36028 .47652 .32831 Metetra
.866 .621 .568 r
.47652 .32831 .48213 .36028 .49342 .29619 .48787 .26439 Metetra
.822 .592 .59 r
.48787 .26439 .49342 .29619 .50424 .24797 .49867 .22105 Metetra
.696 .521 .647 r
.49867 .22105 .50424 .24797 .51473 .2223 .50909 .20755 Metetra
.736 .619 .728 r
.50909 .20755 .51473 .2223 .5251 .20453 .51948 .19751 Metetra
.664 .741 .908 r
.51948 .19751 .5251 .20453 .53547 .20073 .52987 .19369 Metetra
.664 .741 .908 r
.52987 .19369 .53547 .20073 .54588 .19693 .5403 .18986 Metetra
.664 .741 .908 r
.5403 .18986 .54588 .19693 .55632 .1931 .55077 .18601 Metetra
.664 .741 .908 r
.55077 .18601 .55632 .1931 .56681 .18926 .56129 .18214 Metetra
.664 .741 .908 r
.56129 .18214 .56681 .18926 .57733 .18541 .57184 .17826 Metetra
.664 .741 .908 r
.57184 .17826 .57733 .18541 .5879 .18155 .58243 .17437 Metetra
.664 .741 .908 r
.58243 .17437 .5879 .18155 .5985 .17766 .59306 .17046 Metetra
.664 .741 .908 r
.59306 .17046 .5985 .17766 .60915 .17377 .60373 .16653 Metetra
.664 .741 .908 r
.60373 .16653 .60915 .17377 .61983 .16985 .61445 .16259 Metetra
.664 .741 .908 r
.61445 .16259 .61983 .16985 .63056 .16593 .6252 .15864 Metetra
.664 .741 .908 r
.6252 .15864 .63056 .16593 .64133 .16199 .636 .15467 Metetra
.664 .741 .908 r
.636 .15467 .64133 .16199 .65214 .15803 .64684 .15068 Metetra
.664 .741 .908 r
.64684 .15068 .65214 .15803 .66299 .15406 .65772 .14668 Metetra
.664 .741 .908 r
.65772 .14668 .66299 .15406 .67389 .15007 .66864 .14267 Metetra
.664 .741 .908 r
.66864 .14267 .67389 .15007 .68482 .14607 .67961 .13864 Metetra
.664 .741 .908 r
.67961 .13864 .68482 .14607 .6958 .14205 .69061 .13459 Metetra
.664 .741 .908 r
.69061 .13459 .6958 .14205 .70682 .13801 .70167 .13053 Metetra
.664 .741 .908 r
.70167 .13053 .70682 .13801 .71788 .13396 .71276 .12645 Metetra
.664 .741 .908 r
.71276 .12645 .71788 .13396 .72899 .1299 .7239 .12235 Metetra
.664 .741 .908 r
.7239 .12235 .72899 .1299 .74014 .12582 .73508 .11824 Metetra
.664 .741 .908 r
.73508 .11824 .74014 .12582 .75134 .12172 .7463 .11411 Metetra
.664 .741 .908 r
.7463 .11411 .75134 .12172 .76258 .11761 .75757 .10997 Metetra
.664 .741 .908 r
.11821 .33656 .12474 .34265 .1337 .33936 .12718 .33325 Metetra
.664 .741 .908 r
.12718 .33325 .1337 .33936 .14268 .33606 .13618 .32993 Metetra
.664 .741 .908 r
.13618 .32993 .14268 .33606 .15169 .33274 .14521 .32659 Metetra
.664 .741 .908 r
.14521 .32659 .15169 .33274 .16074 .32942 .15428 .32324 Metetra
.664 .741 .908 r
.15428 .32324 .16074 .32942 .16982 .32608 .16337 .31988 Metetra
.664 .741 .908 r
.16337 .31988 .16982 .32608 .17893 .32273 .1725 .31651 Metetra
.664 .741 .908 r
.1725 .31651 .17893 .32273 .18807 .31937 .18166 .31313 Metetra
.664 .741 .908 r
.18166 .31313 .18807 .31937 .19725 .31599 .19086 .30973 Metetra
.664 .741 .908 r
.19086 .30973 .19725 .31599 .20646 .31261 .20009 .30632 Metetra
.664 .741 .908 r
.20009 .30632 .20646 .31261 .2157 .30921 .20935 .3029 Metetra
.664 .741 .908 r
.20935 .3029 .2157 .30921 .22497 .3058 .21864 .29947 Metetra
.664 .741 .908 r
.21864 .29947 .22497 .3058 .23428 .30238 .22797 .29603 Metetra
.664 .741 .908 r
.22797 .29603 .23428 .30238 .24362 .29894 .23733 .29257 Metetra
.664 .741 .908 r
.23733 .29257 .24362 .29894 .25299 .29549 .24672 .2891 Metetra
.664 .741 .908 r
.24672 .2891 .25299 .29549 .2624 .29204 .25615 .28562 Metetra
.664 .741 .908 r
.25615 .28562 .2624 .29204 .27184 .28856 .26561 .28212 Metetra
.664 .741 .908 r
.26561 .28212 .27184 .28856 .28132 .28508 .27511 .27861 Metetra
.664 .741 .908 r
.27511 .27861 .28132 .28508 .29083 .28158 .28464 .27509 Metetra
.664 .741 .908 r
.28464 .27509 .29083 .28158 .30038 .27807 .2942 .27156 Metetra
.664 .741 .908 r
.2942 .27156 .30038 .27807 .30995 .27455 .3038 .26802 Metetra
.664 .741 .908 r
.3038 .26802 .30995 .27455 .31957 .27102 .31344 .26446 Metetra
.664 .741 .908 r
.31344 .26446 .31957 .27102 .32922 .26747 .32311 .26088 Metetra
.664 .741 .908 r
.32311 .26088 .32922 .26747 .33853 .27007 .33282 .2573 Metetra
.635 .586 .783 r
.33282 .2573 .33853 .27007 .34772 .27612 .34256 .2537 Metetra
0 0 .272 r
.34256 .2537 .34772 .27612 .3554 .31175 .35051 .28252 Metetra
.796 .548 0 r
.35051 .28252 .3554 .31175 .36232 .36789 .35754 .33337 Metetra
.174 .134 .569 r
.35754 .33337 .36232 .36789 .37186 .3778 .36656 .35183 Metetra
.622 .478 .666 r
.36656 .35183 .37186 .3778 .38307 .35328 .3769 .34586 Metetra
.852 .764 .765 r
.3769 .34586 .38307 .35328 .39402 .33248 .38761 .33208 Metetra
.959 .888 .717 r
.38761 .33208 .39402 .33248 .40479 .31467 .39854 .31198 Metetra
.883 .896 .835 r
.39854 .31198 .40479 .31467 .41524 .30421 .40908 .30042 Metetra
.641 .852 .981 r
.40908 .30042 .41524 .30421 .42548 .30058 .41935 .29676 Metetra
0 .368 .761 r
.41935 .29676 .42548 .30058 .43555 .30378 .42942 .30103 Metetra
.754 .238 0 r
.42942 .30103 .43555 .30378 .44553 .31439 .43934 .31389 Metetra
.562 0 0 r
.43934 .31389 .44553 .31439 .45556 .32805 .44956 .32045 Metetra
.548 .681 .926 r
.44956 .32045 .45556 .32805 .46569 .34551 .46005 .31917 Metetra
.782 .581 .628 r
.46005 .31917 .46569 .34551 .47652 .32831 .47102 .29327 Metetra
.846 .604 .572 r
.47102 .29327 .47652 .32831 .48787 .26439 .48234 .23462 Metetra
.81 .588 .601 r
.48234 .23462 .48787 .26439 .49867 .22105 .4931 .1981 Metetra
.599 .476 .684 r
.4931 .1981 .49867 .22105 .50909 .20755 .50344 .19428 Metetra
.635 .586 .783 r
.50344 .19428 .50909 .20755 .51948 .19751 .51382 .19045 Metetra
.664 .741 .908 r
.51382 .19045 .51948 .19751 .52987 .19369 .52423 .1866 Metetra
.664 .741 .908 r
.52423 .1866 .52987 .19369 .5403 .18986 .53469 .18274 Metetra
.664 .741 .908 r
.53469 .18274 .5403 .18986 .55077 .18601 .54519 .17886 Metetra
.664 .741 .908 r
.54519 .17886 .55077 .18601 .56129 .18214 .55573 .17497 Metetra
.664 .741 .908 r
.55573 .17497 .56129 .18214 .57184 .17826 .56631 .17106 Metetra
.664 .741 .908 r
.56631 .17106 .57184 .17826 .58243 .17437 .57692 .16714 Metetra
.664 .741 .908 r
.57692 .16714 .58243 .17437 .59306 .17046 .58758 .1632 Metetra
.664 .741 .908 r
.58758 .1632 .59306 .17046 .60373 .16653 .59828 .15925 Metetra
.664 .741 .908 r
.59828 .15925 .60373 .16653 .61445 .16259 .60903 .15528 Metetra
.664 .741 .908 r
.60903 .15528 .61445 .16259 .6252 .15864 .61981 .1513 Metetra
.664 .741 .908 r
.61981 .1513 .6252 .15864 .636 .15467 .63063 .1473 Metetra
.664 .741 .908 r
.63063 .1473 .636 .15467 .64684 .15068 .6415 .14329 Metetra
.664 .741 .908 r
.6415 .14329 .64684 .15068 .65772 .14668 .65241 .13926 Metetra
.664 .741 .908 r
.65241 .13926 .65772 .14668 .66864 .14267 .66336 .13521 Metetra
.664 .741 .908 r
.66336 .13521 .66864 .14267 .67961 .13864 .67436 .13115 Metetra
.664 .741 .908 r
.67436 .13115 .67961 .13864 .69061 .13459 .68539 .12708 Metetra
.664 .741 .908 r
.68539 .12708 .69061 .13459 .70167 .13053 .69647 .12298 Metetra
.664 .741 .908 r
.69647 .12298 .70167 .13053 .71276 .12645 .7076 .11887 Metetra
.664 .741 .908 r
.7076 .11887 .71276 .12645 .7239 .12235 .71876 .11475 Metetra
.664 .741 .908 r
.71876 .11475 .7239 .12235 .73508 .11824 .72998 .11061 Metetra
.664 .741 .908 r
.72998 .11061 .73508 .11824 .7463 .11411 .74123 .10645 Metetra
.664 .741 .908 r
.74123 .10645 .7463 .11411 .75757 .10997 .75253 .10228 Metetra
.664 .741 .908 r
.11163 .33044 .11821 .33656 .12718 .33325 .12062 .32711 Metetra
.664 .741 .908 r
.12062 .32711 .12718 .33325 .13618 .32993 .12964 .32376 Metetra
.664 .741 .908 r
.12964 .32376 .13618 .32993 .14521 .32659 .13869 .3204 Metetra
.664 .741 .908 r
.13869 .3204 .14521 .32659 .15428 .32324 .14777 .31703 Metetra
.664 .741 .908 r
.14777 .31703 .15428 .32324 .16337 .31988 .15688 .31365 Metetra
.664 .741 .908 r
.15688 .31365 .16337 .31988 .1725 .31651 .16603 .31025 Metetra
.664 .741 .908 r
.16603 .31025 .1725 .31651 .18166 .31313 .17521 .30685 Metetra
.664 .741 .908 r
.17521 .30685 .18166 .31313 .19086 .30973 .18443 .30343 Metetra
.664 .741 .908 r
.18443 .30343 .19086 .30973 .20009 .30632 .19367 .3 Metetra
.664 .741 .908 r
.19367 .3 .20009 .30632 .20935 .3029 .20295 .29656 Metetra
.664 .741 .908 r
.20295 .29656 .20935 .3029 .21864 .29947 .21226 .2931 Metetra
.664 .741 .908 r
.21226 .2931 .21864 .29947 .22797 .29603 .22161 .28963 Metetra
.664 .741 .908 r
.22161 .28963 .22797 .29603 .23733 .29257 .23099 .28615 Metetra
.664 .741 .908 r
.23099 .28615 .23733 .29257 .24672 .2891 .2404 .28266 Metetra
.664 .741 .908 r
.2404 .28266 .24672 .2891 .25615 .28562 .24985 .27915 Metetra
.664 .741 .908 r
.24985 .27915 .25615 .28562 .26561 .28212 .25934 .27564 Metetra
.664 .741 .908 r
.25934 .27564 .26561 .28212 .27511 .27861 .26885 .27211 Metetra
.664 .741 .908 r
.26885 .27211 .27511 .27861 .28464 .27509 .2784 .26856 Metetra
.664 .741 .908 r
.2784 .26856 .28464 .27509 .2942 .27156 .28799 .265 Metetra
.664 .741 .908 r
.28799 .265 .2942 .27156 .3038 .26802 .29761 .26143 Metetra
.664 .741 .908 r
.29761 .26143 .3038 .26802 .31344 .26446 .30727 .25785 Metetra
.664 .741 .908 r
.30727 .25785 .31344 .26446 .32311 .26088 .31696 .25426 Metetra
.664 .741 .908 r
.31696 .25426 .32311 .26088 .33282 .2573 .32669 .25065 Metetra
.664 .741 .908 r
.32669 .25065 .33282 .2573 .34256 .2537 .33645 .24702 Metetra
.725 .249 0 r
.33645 .24702 .34256 .2537 .35051 .28252 .34524 .26068 Metetra
0 0 .363 r
.34524 .26068 .35051 .28252 .35754 .33337 .35355 .2857 Metetra
.117 .058 .508 r
.35355 .2857 .35754 .33337 .36656 .35183 .36192 .31378 Metetra
0 0 .461 r
.36192 .31378 .36656 .35183 .3769 .34586 .37041 .34438 Metetra
.391 .827 .954 r
.37041 .34438 .3769 .34586 .38761 .33208 .38063 .34242 Metetra
.932 .908 .518 r
.38063 .34242 .38761 .33208 .39854 .31198 .39205 .31346 Metetra
.936 .96 .754 r
.39205 .31346 .39854 .31198 .40908 .30042 .40283 .29767 Metetra
.615 .885 .99 r
.40283 .29767 .40908 .30042 .41935 .29676 .41313 .29399 Metetra
.596 .031 0 r
.41313 .29399 .41935 .29676 .42942 .30103 .42308 .30245 Metetra
.857 .428 .203 r
.42308 .30245 .42942 .30103 .43934 .31389 .43276 .32417 Metetra
.152 0 0 r
.43276 .32417 .43934 .31389 .44956 .32045 .44335 .31881 Metetra
.977 .803 .6 r
.44335 .31881 .44956 .32045 .46005 .31917 .45472 .28067 Metetra
.771 .547 .595 r
.45472 .28067 .46005 .31917 .47102 .29327 .46584 .24499 Metetra
.729 .504 .587 r
.46584 .24499 .47102 .29327 .48234 .23462 .47674 .21231 Metetra
.78 .592 .645 r
.47674 .21231 .48234 .23462 .4931 .1981 .48734 .19104 Metetra
.664 .741 .908 r
.48734 .19104 .4931 .1981 .50344 .19428 .49771 .18719 Metetra
.664 .741 .908 r
.49771 .18719 .50344 .19428 .51382 .19045 .50811 .18333 Metetra
.664 .741 .908 r
.50811 .18333 .51382 .19045 .52423 .1866 .51856 .17946 Metetra
.664 .741 .908 r
.51856 .17946 .52423 .1866 .53469 .18274 .52904 .17557 Metetra
.664 .741 .908 r
.52904 .17557 .53469 .18274 .54519 .17886 .53957 .17166 Metetra
.664 .741 .908 r
.53957 .17166 .54519 .17886 .55573 .17497 .55013 .16774 Metetra
.664 .741 .908 r
.55013 .16774 .55573 .17497 .56631 .17106 .56073 .16381 Metetra
.664 .741 .908 r
.56073 .16381 .56631 .17106 .57692 .16714 .57138 .15986 Metetra
.664 .741 .908 r
.57138 .15986 .57692 .16714 .58758 .1632 .58207 .15589 Metetra
.664 .741 .908 r
.58207 .15589 .58758 .1632 .59828 .15925 .59279 .15191 Metetra
.664 .741 .908 r
.59279 .15191 .59828 .15925 .60903 .15528 .60356 .14792 Metetra
.664 .741 .908 r
.60356 .14792 .60903 .15528 .61981 .1513 .61437 .14391 Metetra
.664 .741 .908 r
.61437 .14391 .61981 .1513 .63063 .1473 .62523 .13988 Metetra
.664 .741 .908 r
.62523 .13988 .63063 .1473 .6415 .14329 .63612 .13584 Metetra
.664 .741 .908 r
.63612 .13584 .6415 .14329 .65241 .13926 .64706 .13178 Metetra
.664 .741 .908 r
.64706 .13178 .65241 .13926 .66336 .13521 .65804 .1277 Metetra
.664 .741 .908 r
.65804 .1277 .66336 .13521 .67436 .13115 .66907 .12361 Metetra
.664 .741 .908 r
.66907 .12361 .67436 .13115 .68539 .12708 .68013 .11951 Metetra
.664 .741 .908 r
.68013 .11951 .68539 .12708 .69647 .12298 .69124 .11539 Metetra
.664 .741 .908 r
.69124 .11539 .69647 .12298 .7076 .11887 .7024 .11125 Metetra
.664 .741 .908 r
.7024 .11125 .7076 .11887 .71876 .11475 .71359 .10709 Metetra
.664 .741 .908 r
.71359 .10709 .71876 .11475 .72998 .11061 .72484 .10292 Metetra
.664 .741 .908 r
.72484 .10292 .72998 .11061 .74123 .10645 .73612 .09873 Metetra
.664 .741 .908 r
.73612 .09873 .74123 .10645 .75253 .10228 .74745 .09453 Metetra
.664 .741 .908 r
.10501 .32427 .11163 .33044 .12062 .32711 .11401 .32092 Metetra
.664 .741 .908 r
.11401 .32092 .12062 .32711 .12964 .32376 .12305 .31755 Metetra
.664 .741 .908 r
.12305 .31755 .12964 .32376 .13869 .3204 .13212 .31417 Metetra
.664 .741 .908 r
.13212 .31417 .13869 .3204 .14777 .31703 .14122 .31078 Metetra
.664 .741 .908 r
.14122 .31078 .14777 .31703 .15688 .31365 .15035 .30737 Metetra
.664 .741 .908 r
.15035 .30737 .15688 .31365 .16603 .31025 .15952 .30396 Metetra
.664 .741 .908 r
.15952 .30396 .16603 .31025 .17521 .30685 .16872 .30053 Metetra
.664 .741 .908 r
.16872 .30053 .17521 .30685 .18443 .30343 .17795 .29709 Metetra
.664 .741 .908 r
.17795 .29709 .18443 .30343 .19367 .3 .18722 .29363 Metetra
.664 .741 .908 r
.18722 .29363 .19367 .3 .20295 .29656 .19651 .29017 Metetra
.664 .741 .908 r
.19651 .29017 .20295 .29656 .21226 .2931 .20585 .28669 Metetra
.664 .741 .908 r
.20585 .28669 .21226 .2931 .22161 .28963 .21521 .2832 Metetra
.664 .741 .908 r
.21521 .2832 .22161 .28963 .23099 .28615 .22461 .27969 Metetra
.664 .741 .908 r
.22461 .27969 .23099 .28615 .2404 .28266 .23405 .27618 Metetra
.664 .741 .908 r
.23405 .27618 .2404 .28266 .24985 .27915 .24351 .27265 Metetra
.664 .741 .908 r
.24351 .27265 .24985 .27915 .25934 .27564 .25302 .26911 Metetra
.664 .741 .908 r
.25302 .26911 .25934 .27564 .26885 .27211 .26255 .26555 Metetra
.664 .741 .908 r
.26255 .26555 .26885 .27211 .2784 .26856 .27213 .26198 Metetra
.664 .741 .908 r
.27213 .26198 .2784 .26856 .28799 .265 .28173 .2584 Metetra
.664 .741 .908 r
.28173 .2584 .28799 .265 .29761 .26143 .29138 .25481 Metetra
.664 .741 .908 r
.29138 .25481 .29761 .26143 .30727 .25785 .30106 .2512 Metetra
.664 .741 .908 r
.30106 .2512 .30727 .25785 .31696 .25426 .31077 .24758 Metetra
.664 .741 .908 r
.31077 .24758 .31696 .25426 .32669 .25065 .32052 .24395 Metetra
.664 .741 .908 r
.32052 .24395 .32669 .25065 .33645 .24702 .3303 .2403 Metetra
.411 .636 .948 r
.3303 .2403 .33645 .24702 .34524 .26068 .33987 .24095 Metetra
.437 .392 .71 r
.33987 .24095 .34524 .26068 .35355 .2857 .34933 .24434 Metetra
0 0 .425 r
.34933 .24434 .35355 .2857 .36192 .31378 .3572 .27878 Metetra
.771 .546 0 r
.3572 .27878 .36192 .31378 .37041 .34438 .36411 .33762 Metetra
0 .015 .527 r
.36411 .33762 .37041 .34438 .38063 .34242 .3738 .34734 Metetra
.992 .882 .602 r
.3738 .34734 .38063 .34242 .39205 .31346 .38546 .31537 Metetra
.946 .954 .733 r
.38546 .31537 .39205 .31346 .40283 .29767 .39638 .29816 Metetra
.417 .865 .861 r
.39638 .29816 .40283 .29767 .41313 .29399 .40673 .29446 Metetra
.708 .182 0 r
.40673 .29446 .41313 .29399 .42308 .30245 .41666 .3043 Metetra
.869 .454 .235 r
.41666 .3043 .42308 .30245 .43276 .32417 .42624 .329 Metetra
.885 .971 .658 r
.42624 .329 .43276 .32417 .44335 .31881 .43723 .31187 Metetra
.96 .731 .547 r
.43723 .31187 .44335 .31881 .45472 .28067 .44939 .24526 Metetra
.805 .575 .589 r
.44939 .24526 .45472 .28067 .46584 .24499 .46064 .20309 Metetra
.626 .437 .607 r
.46064 .20309 .46584 .24499 .47674 .21231 .47112 .19213 Metetra
.673 .54 .694 r
.47112 .19213 .47674 .21231 .48734 .19104 .48155 .18393 Metetra
.664 .741 .908 r
.48155 .18393 .48734 .19104 .49771 .18719 .49194 .18005 Metetra
.664 .741 .908 r
.49194 .18005 .49771 .18719 .50811 .18333 .50237 .17617 Metetra
.664 .741 .908 r
.50237 .17617 .50811 .18333 .51856 .17946 .51284 .17226 Metetra
.664 .741 .908 r
.51284 .17226 .51856 .17946 .52904 .17557 .52335 .16835 Metetra
.664 .741 .908 r
.52335 .16835 .52904 .17557 .53957 .17166 .5339 .16441 Metetra
.664 .741 .908 r
.5339 .16441 .53957 .17166 .55013 .16774 .54449 .16047 Metetra
.664 .741 .908 r
.54449 .16047 .55013 .16774 .56073 .16381 .55512 .1565 Metetra
.664 .741 .908 r
.55512 .1565 .56073 .16381 .57138 .15986 .5658 .15253 Metetra
.664 .741 .908 r
.5658 .15253 .57138 .15986 .58207 .15589 .57651 .14853 Metetra
.664 .741 .908 r
.57651 .14853 .58207 .15589 .59279 .15191 .58727 .14452 Metetra
.664 .741 .908 r
.58727 .14452 .59279 .15191 .60356 .14792 .59806 .1405 Metetra
.664 .741 .908 r
.59806 .1405 .60356 .14792 .61437 .14391 .6089 .13646 Metetra
.664 .741 .908 r
.6089 .13646 .61437 .14391 .62523 .13988 .61978 .1324 Metetra
.664 .741 .908 r
.61978 .1324 .62523 .13988 .63612 .13584 .63071 .12833 Metetra
.664 .741 .908 r
.63071 .12833 .63612 .13584 .64706 .13178 .64167 .12424 Metetra
.664 .741 .908 r
.64167 .12424 .64706 .13178 .65804 .1277 .65268 .12014 Metetra
.664 .741 .908 r
.65268 .12014 .65804 .1277 .66907 .12361 .66374 .11602 Metetra
.664 .741 .908 r
.66374 .11602 .66907 .12361 .68013 .11951 .67483 .11188 Metetra
.664 .741 .908 r
.67483 .11188 .68013 .11951 .69124 .11539 .68597 .10773 Metetra
.664 .741 .908 r
.68597 .10773 .69124 .11539 .7024 .11125 .69716 .10356 Metetra
.664 .741 .908 r
.69716 .10356 .7024 .11125 .71359 .10709 .70839 .09938 Metetra
.664 .741 .908 r
.70839 .09938 .71359 .10709 .72484 .10292 .71966 .09518 Metetra
.664 .741 .908 r
.71966 .09518 .72484 .10292 .73612 .09873 .73098 .09096 Metetra
.664 .741 .908 r
.73098 .09096 .73612 .09873 .74745 .09453 .74234 .08672 Metetra
.664 .741 .908 r
.09834 .31807 .10501 .32427 .11401 .32092 .10737 .31469 Metetra
.664 .741 .908 r
.10737 .31469 .11401 .32092 .12305 .31755 .11642 .3113 Metetra
.664 .741 .908 r
.11642 .3113 .12305 .31755 .13212 .31417 .12551 .3079 Metetra
.664 .741 .908 r
.12551 .3079 .13212 .31417 .14122 .31078 .13463 .30448 Metetra
.664 .741 .908 r
.13463 .30448 .14122 .31078 .15035 .30737 .14378 .30106 Metetra
.664 .741 .908 r
.14378 .30106 .15035 .30737 .15952 .30396 .15296 .29762 Metetra
.664 .741 .908 r
.15296 .29762 .15952 .30396 .16872 .30053 .16218 .29417 Metetra
.664 .741 .908 r
.16218 .29417 .16872 .30053 .17795 .29709 .17143 .2907 Metetra
.664 .741 .908 r
.17143 .2907 .17795 .29709 .18722 .29363 .18072 .28723 Metetra
.664 .741 .908 r
.18072 .28723 .18722 .29363 .19651 .29017 .19003 .28374 Metetra
.664 .741 .908 r
.19003 .28374 .19651 .29017 .20585 .28669 .19939 .28023 Metetra
.664 .741 .908 r
.19939 .28023 .20585 .28669 .21521 .2832 .20877 .27672 Metetra
.664 .741 .908 r
.20877 .27672 .21521 .2832 .22461 .27969 .21819 .27319 Metetra
.664 .741 .908 r
.21819 .27319 .22461 .27969 .23405 .27618 .22765 .26965 Metetra
.664 .741 .908 r
.22765 .26965 .23405 .27618 .24351 .27265 .23713 .2661 Metetra
.664 .741 .908 r
.23713 .2661 .24351 .27265 .25302 .26911 .24666 .26253 Metetra
.664 .741 .908 r
.24666 .26253 .25302 .26911 .26255 .26555 .25622 .25896 Metetra
.664 .741 .908 r
.25622 .25896 .26255 .26555 .27213 .26198 .26581 .25536 Metetra
.664 .741 .908 r
.26581 .25536 .27213 .26198 .28173 .2584 .27544 .25176 Metetra
.664 .741 .908 r
.27544 .25176 .28173 .2584 .29138 .25481 .2851 .24814 Metetra
.664 .741 .908 r
.2851 .24814 .29138 .25481 .30106 .2512 .2948 .24451 Metetra
.664 .741 .908 r
.2948 .24451 .30106 .2512 .31077 .24758 .30454 .24086 Metetra
.664 .741 .908 r
.30454 .24086 .31077 .24758 .32052 .24395 .31431 .2372 Metetra
.664 .741 .908 r
.31431 .2372 .32052 .24395 .3303 .2403 .32411 .23353 Metetra
.568 .707 .936 r
.32411 .23353 .3303 .2403 .33987 .24095 .33383 .23185 Metetra
.519 .612 .885 r
.33383 .23185 .33987 .24095 .34933 .24434 .34352 .23144 Metetra
.825 .457 0 r
.34352 .23144 .34933 .24434 .3572 .27878 .35179 .2574 Metetra
.882 .579 .067 r
.35179 .2574 .3572 .27878 .36411 .33762 .35921 .30371 Metetra
.128 .103 .559 r
.35921 .30371 .36411 .33762 .3738 .34734 .36832 .32317 Metetra
.592 .468 .68 r
.36832 .32317 .3738 .34734 .38546 .31537 .37869 .31949 Metetra
.37869 .31949 .38546 .31537 .39638 .29816 .38911 .3158 Metetra
.356 0 .201 r
.38911 .3158 .39638 .29816 .40673 .29446 .39957 .31209 Metetra
.356 0 .201 r
.39957 .31209 .40673 .29446 .41666 .3043 .41007 .30837 Metetra
.41007 .30837 .41666 .3043 .42624 .329 .42061 .30463 Metetra
.799 .598 .63 r
.42061 .30463 .42624 .329 .43723 .31187 .43188 .27763 Metetra
.84 .601 .578 r
.43188 .27763 .43723 .31187 .44939 .24526 .44377 .22355 Metetra
.842 .63 .616 r
.44377 .22355 .44939 .24526 .46064 .20309 .45488 .18985 Metetra
.704 .623 .764 r
.45488 .18985 .46064 .20309 .47112 .19213 .4653 .18267 Metetra
.711 .694 .833 r
.4653 .18267 .47112 .19213 .48155 .18393 .47572 .17677 Metetra
.664 .741 .908 r
.47572 .17677 .48155 .18393 .49194 .18005 .48613 .17287 Metetra
.664 .741 .908 r
.48613 .17287 .49194 .18005 .50237 .17617 .49659 .16895 Metetra
.664 .741 .908 r
.49659 .16895 .50237 .17617 .51284 .17226 .50708 .16502 Metetra
.664 .741 .908 r
.50708 .16502 .51284 .17226 .52335 .16835 .51762 .16107 Metetra
.664 .741 .908 r
.51762 .16107 .52335 .16835 .5339 .16441 .5282 .15711 Metetra
.664 .741 .908 r
.5282 .15711 .5339 .16441 .54449 .16047 .53881 .15314 Metetra
.664 .741 .908 r
.53881 .15314 .54449 .16047 .55512 .1565 .54947 .14915 Metetra
.664 .741 .908 r
.54947 .14915 .55512 .1565 .5658 .15253 .56017 .14514 Metetra
.664 .741 .908 r
.56017 .14514 .5658 .15253 .57651 .14853 .57091 .14112 Metetra
.664 .741 .908 r
.57091 .14112 .57651 .14853 .58727 .14452 .5817 .13708 Metetra
.664 .741 .908 r
.5817 .13708 .58727 .14452 .59806 .1405 .59252 .13303 Metetra
.664 .741 .908 r
.59252 .13303 .59806 .1405 .6089 .13646 .60339 .12896 Metetra
.664 .741 .908 r
.60339 .12896 .6089 .13646 .61978 .1324 .6143 .12487 Metetra
.664 .741 .908 r
.6143 .12487 .61978 .1324 .63071 .12833 .62525 .12077 Metetra
.664 .741 .908 r
.62525 .12077 .63071 .12833 .64167 .12424 .63625 .11666 Metetra
.664 .741 .908 r
.63625 .11666 .64167 .12424 .65268 .12014 .64729 .11252 Metetra
.664 .741 .908 r
.64729 .11252 .65268 .12014 .66374 .11602 .65837 .10837 Metetra
.664 .741 .908 r
.65837 .10837 .66374 .11602 .67483 .11188 .6695 .10421 Metetra
.664 .741 .908 r
.6695 .10421 .67483 .11188 .68597 .10773 .68067 .10002 Metetra
.664 .741 .908 r
.68067 .10002 .68597 .10773 .69716 .10356 .69188 .09582 Metetra
.664 .741 .908 r
.69188 .09582 .69716 .10356 .70839 .09938 .70314 .09161 Metetra
.664 .741 .908 r
.70314 .09161 .70839 .09938 .71966 .09518 .71444 .08738 Metetra
.664 .741 .908 r
.71444 .08738 .71966 .09518 .73098 .09096 .72579 .08313 Metetra
.664 .741 .908 r
.72579 .08313 .73098 .09096 .74234 .08672 .73719 .07886 Metetra
.664 .741 .908 r
.09164 .31182 .09834 .31807 .10737 .31469 .10068 .30842 Metetra
.664 .741 .908 r
.10068 .30842 .10737 .31469 .11642 .3113 .10975 .30501 Metetra
.664 .741 .908 r
.10975 .30501 .11642 .3113 .12551 .3079 .11885 .30158 Metetra
.664 .741 .908 r
.11885 .30158 .12551 .3079 .13463 .30448 .12799 .29815 Metetra
.664 .741 .908 r
.12799 .29815 .13463 .30448 .14378 .30106 .13716 .2947 Metetra
.664 .741 .908 r
.13716 .2947 .14378 .30106 .15296 .29762 .14636 .29124 Metetra
.664 .741 .908 r
.14636 .29124 .15296 .29762 .16218 .29417 .1556 .28776 Metetra
.664 .741 .908 r
.1556 .28776 .16218 .29417 .17143 .2907 .16487 .28427 Metetra
.664 .741 .908 r
.16487 .28427 .17143 .2907 .18072 .28723 .17417 .28077 Metetra
.664 .741 .908 r
.17417 .28077 .18072 .28723 .19003 .28374 .18351 .27726 Metetra
.664 .741 .908 r
.18351 .27726 .19003 .28374 .19939 .28023 .19288 .27374 Metetra
.664 .741 .908 r
.19288 .27374 .19939 .28023 .20877 .27672 .20229 .2702 Metetra
.664 .741 .908 r
.20229 .2702 .20877 .27672 .21819 .27319 .21173 .26665 Metetra
.664 .741 .908 r
.21173 .26665 .21819 .27319 .22765 .26965 .2212 .26308 Metetra
.664 .741 .908 r
.2212 .26308 .22765 .26965 .23713 .2661 .23071 .25951 Metetra
.664 .741 .908 r
.23071 .25951 .23713 .2661 .24666 .26253 .24025 .25592 Metetra
.664 .741 .908 r
.24025 .25592 .24666 .26253 .25622 .25896 .24983 .25231 Metetra
.664 .741 .908 r
.24983 .25231 .25622 .25896 .26581 .25536 .25945 .2487 Metetra
.664 .741 .908 r
.25945 .2487 .26581 .25536 .27544 .25176 .2691 .24507 Metetra
.664 .741 .908 r
.2691 .24507 .27544 .25176 .2851 .24814 .27878 .24142 Metetra
.664 .741 .908 r
.27878 .24142 .2851 .24814 .2948 .24451 .2885 .23777 Metetra
.664 .741 .908 r
.2885 .23777 .2948 .24451 .30454 .24086 .29826 .2341 Metetra
.664 .741 .908 r
.29826 .2341 .30454 .24086 .31431 .2372 .30805 .23041 Metetra
.664 .741 .908 r
.30805 .23041 .31431 .2372 .32411 .23353 .31788 .22672 Metetra
.662 .741 .909 r
.31788 .22672 .32411 .23353 .33383 .23185 .32774 .22305 Metetra
.653 .68 .863 r
.32774 .22305 .33383 .23185 .34352 .23144 .33764 .21941 Metetra
0 0 .32 r
.33764 .21941 .34352 .23144 .35179 .2574 .34634 .23695 Metetra
.749 .462 0 r
.34634 .23695 .35179 .2574 .35921 .30371 .35433 .27054 Metetra
0 0 .462 r
.35433 .27054 .35921 .30371 .36832 .32317 .36291 .29805 Metetra
0 0 .491 r
.36291 .29805 .36832 .32317 .37869 .31949 .37199 .32033 Metetra
.687 .157 0 r
.37199 .32033 .37869 .31949 .38911 .3158 .38188 .32936 Metetra
.3 0 .104 r
.38188 .32936 .38911 .3158 .39957 .31209 .39243 .32564 Metetra
.39243 .32564 .39957 .31209 .41007 .30837 .40351 .30914 Metetra
.984 .857 .635 r
.40351 .30914 .41007 .30837 .42061 .30463 .41503 .27931 Metetra
.827 .611 .611 r
.41503 .27931 .42061 .30463 .43188 .27763 .42658 .24414 Metetra
.81 .582 .592 r
.42658 .24414 .43188 .27763 .44377 .22355 .43814 .20278 Metetra
.813 .618 .638 r
.43814 .20278 .44377 .22355 .45488 .18985 .44907 .1775 Metetra
.641 .607 .8 r
.44907 .1775 .45488 .18985 .4653 .18267 .45944 .17352 Metetra
.658 .682 .862 r
.45944 .17352 .4653 .18267 .47572 .17677 .46984 .16955 Metetra
.664 .741 .908 r
.46984 .16955 .47572 .17677 .48613 .17287 .48028 .16563 Metetra
.664 .741 .908 r
.48028 .16563 .48613 .17287 .49659 .16895 .49076 .16168 Metetra
.664 .741 .908 r
.49076 .16168 .49659 .16895 .50708 .16502 .50129 .15772 Metetra
.664 .741 .908 r
.50129 .15772 .50708 .16502 .51762 .16107 .51185 .15375 Metetra
.664 .741 .908 r
.51185 .15375 .51762 .16107 .5282 .15711 .52245 .14976 Metetra
.664 .741 .908 r
.52245 .14976 .5282 .15711 .53881 .15314 .5331 .14576 Metetra
.664 .741 .908 r
.5331 .14576 .53881 .15314 .54947 .14915 .54378 .14174 Metetra
.664 .741 .908 r
.54378 .14174 .54947 .14915 .56017 .14514 .55451 .1377 Metetra
.664 .741 .908 r
.55451 .1377 .56017 .14514 .57091 .14112 .56528 .13365 Metetra
.664 .741 .908 r
.56528 .13365 .57091 .14112 .5817 .13708 .57609 .12959 Metetra
.664 .741 .908 r
.57609 .12959 .5817 .13708 .59252 .13303 .58694 .1255 Metetra
.664 .741 .908 r
.58694 .1255 .59252 .13303 .60339 .12896 .59784 .1214 Metetra
.664 .741 .908 r
.59784 .1214 .60339 .12896 .6143 .12487 .60878 .11729 Metetra
.664 .741 .908 r
.60878 .11729 .6143 .12487 .62525 .12077 .61976 .11316 Metetra
.664 .741 .908 r
.61976 .11316 .62525 .12077 .63625 .11666 .63078 .10901 Metetra
.664 .741 .908 r
.63078 .10901 .63625 .11666 .64729 .11252 .64185 .10485 Metetra
.664 .741 .908 r
.64185 .10485 .64729 .11252 .65837 .10837 .65296 .10067 Metetra
.664 .741 .908 r
.65296 .10067 .65837 .10837 .6695 .10421 .66412 .09647 Metetra
.664 .741 .908 r
.66412 .09647 .6695 .10421 .68067 .10002 .67532 .09226 Metetra
.664 .741 .908 r
.67532 .09226 .68067 .10002 .69188 .09582 .68657 .08803 Metetra
.664 .741 .908 r
.68657 .08803 .69188 .09582 .70314 .09161 .69786 .08378 Metetra
.664 .741 .908 r
.69786 .08378 .70314 .09161 .71444 .08738 .70919 .07952 Metetra
.664 .741 .908 r
.70919 .07952 .71444 .08738 .72579 .08313 .72057 .07524 Metetra
.664 .741 .908 r
.72057 .07524 .72579 .08313 .73719 .07886 .732 .07094 Metetra
.664 .741 .908 r
.08488 .30554 .09164 .31182 .10068 .30842 .09394 .30211 Metetra
.664 .741 .908 r
.09394 .30211 .10068 .30842 .10975 .30501 .10303 .29868 Metetra
.664 .741 .908 r
.10303 .29868 .10975 .30501 .11885 .30158 .11215 .29523 Metetra
.664 .741 .908 r
.11215 .29523 .11885 .30158 .12799 .29815 .12131 .29177 Metetra
.664 .741 .908 r
.12131 .29177 .12799 .29815 .13716 .2947 .1305 .2883 Metetra
.664 .741 .908 r
.1305 .2883 .13716 .2947 .14636 .29124 .13972 .28481 Metetra
.664 .741 .908 r
.13972 .28481 .14636 .29124 .1556 .28776 .14898 .28131 Metetra
.664 .741 .908 r
.14898 .28131 .1556 .28776 .16487 .28427 .15827 .2778 Metetra
.664 .741 .908 r
.15827 .2778 .16487 .28427 .17417 .28077 .16759 .27428 Metetra
.664 .741 .908 r
.16759 .27428 .17417 .28077 .18351 .27726 .17694 .27074 Metetra
.664 .741 .908 r
.17694 .27074 .18351 .27726 .19288 .27374 .18634 .2672 Metetra
.664 .741 .908 r
.18634 .2672 .19288 .27374 .20229 .2702 .19576 .26363 Metetra
.664 .741 .908 r
.19576 .26363 .20229 .2702 .21173 .26665 .20522 .26006 Metetra
.664 .741 .908 r
.20522 .26006 .21173 .26665 .2212 .26308 .21471 .25647 Metetra
.664 .741 .908 r
.21471 .25647 .2212 .26308 .23071 .25951 .22424 .25287 Metetra
.664 .741 .908 r
.22424 .25287 .23071 .25951 .24025 .25592 .23381 .24925 Metetra
.664 .741 .908 r
.23381 .24925 .24025 .25592 .24983 .25231 .24341 .24563 Metetra
.664 .741 .908 r
.24341 .24563 .24983 .25231 .25945 .2487 .25304 .24199 Metetra
.664 .741 .908 r
.25304 .24199 .25945 .2487 .2691 .24507 .26271 .23833 Metetra
.664 .741 .908 r
.26271 .23833 .2691 .24507 .27878 .24142 .27242 .23466 Metetra
.664 .741 .908 r
.27242 .23466 .27878 .24142 .2885 .23777 .28216 .23098 Metetra
.664 .741 .908 r
.28216 .23098 .2885 .23777 .29826 .2341 .29194 .22729 Metetra
.664 .741 .908 r
.29194 .22729 .29826 .2341 .30805 .23041 .30175 .22358 Metetra
.664 .741 .908 r
.30175 .22358 .30805 .23041 .31788 .22672 .31161 .21985 Metetra
.646 .736 .915 r
.31161 .21985 .31788 .22672 .32774 .22305 .32147 .21655 Metetra
.633 .745 .928 r
.32147 .21655 .32774 .22305 .33764 .21941 .33135 .21351 Metetra
.508 0 0 r
.33135 .21351 .33764 .21941 .34634 .23695 .34054 .22247 Metetra
0 0 .402 r
.34054 .22247 .34634 .23695 .35433 .27054 .34935 .24035 Metetra
0 0 .462 r
.34935 .24035 .35433 .27054 .36291 .29805 .35791 .26603 Metetra
0 0 .373 r
.35791 .26603 .36291 .29805 .37199 .32033 .36635 .29861 Metetra
.049 .122 .62 r
.36635 .29861 .37199 .32033 .38188 .32936 .37594 .31276 Metetra
.616 .542 .748 r
.37594 .31276 .38188 .32936 .39243 .32564 .38648 .30901 Metetra
.822 .648 .667 r
.38648 .30901 .39243 .32564 .40351 .30914 .3978 .2873 Metetra
.86 .641 .605 r
.3978 .2873 .40351 .30914 .41503 .27931 .40974 .24706 Metetra
.788 .569 .604 r
.40974 .24706 .41503 .27931 .42658 .24414 .42123 .21366 Metetra
.761 .554 .617 r
.42123 .21366 .42658 .24414 .43814 .20278 .43233 .18802 Metetra
.806 .653 .693 r
.43233 .18802 .43814 .20278 .44907 .1775 .44308 .17131 Metetra
.693 .785 .921 r
.44308 .17131 .44907 .1775 .45944 .17352 .45349 .16667 Metetra
.681 .76 .911 r
.45349 .16667 .45944 .17352 .46984 .16955 .46392 .16229 Metetra
.664 .741 .908 r
.46392 .16229 .46984 .16955 .48028 .16563 .47439 .15833 Metetra
.664 .741 .908 r
.47439 .15833 .48028 .16563 .49076 .16168 .4849 .15436 Metetra
.664 .741 .908 r
.4849 .15436 .49076 .16168 .50129 .15772 .49545 .15038 Metetra
.664 .741 .908 r
.49545 .15038 .50129 .15772 .51185 .15375 .50603 .14638 Metetra
.664 .741 .908 r
.50603 .14638 .51185 .15375 .52245 .14976 .51666 .14236 Metetra
.664 .741 .908 r
.51666 .14236 .52245 .14976 .5331 .14576 .52734 .13833 Metetra
.664 .741 .908 r
.52734 .13833 .5331 .14576 .54378 .14174 .53805 .13428 Metetra
.664 .741 .908 r
.53805 .13428 .54378 .14174 .55451 .1377 .5488 .13021 Metetra
.664 .741 .908 r
.5488 .13021 .55451 .1377 .56528 .13365 .5596 .12613 Metetra
.664 .741 .908 r
.5596 .12613 .56528 .13365 .57609 .12959 .57044 .12204 Metetra
.664 .741 .908 r
.57044 .12204 .57609 .12959 .58694 .1255 .58132 .11792 Metetra
.664 .741 .908 r
.58132 .11792 .58694 .1255 .59784 .1214 .59225 .1138 Metetra
.664 .741 .908 r
.59225 .1138 .59784 .1214 .60878 .11729 .60321 .10965 Metetra
.664 .741 .908 r
.60321 .10965 .60878 .11729 .61976 .11316 .61422 .10549 Metetra
.664 .741 .908 r
.61422 .10549 .61976 .11316 .63078 .10901 .62528 .10131 Metetra
.664 .741 .908 r
.62528 .10131 .63078 .10901 .64185 .10485 .63638 .09712 Metetra
.664 .741 .908 r
.63638 .09712 .64185 .10485 .65296 .10067 .64752 .09291 Metetra
.664 .741 .908 r
.64752 .09291 .65296 .10067 .66412 .09647 .6587 .08868 Metetra
.664 .741 .908 r
.6587 .08868 .66412 .09647 .67532 .09226 .66994 .08444 Metetra
.664 .741 .908 r
.66994 .08444 .67532 .09226 .68657 .08803 .68121 .08017 Metetra
.664 .741 .908 r
.68121 .08017 .68657 .08803 .69786 .08378 .69253 .0759 Metetra
.664 .741 .908 r
.69253 .0759 .69786 .08378 .70919 .07952 .7039 .0716 Metetra
.664 .741 .908 r
.7039 .0716 .70919 .07952 .72057 .07524 .71531 .06729 Metetra
.664 .741 .908 r
.71531 .06729 .72057 .07524 .732 .07094 .72677 .06296 Metetra
.664 .741 .908 r
.07809 .29921 .08488 .30554 .09394 .30211 .08716 .29576 Metetra
.664 .741 .908 r
.08716 .29576 .09394 .30211 .10303 .29868 .09627 .2923 Metetra
.664 .741 .908 r
.09627 .2923 .10303 .29868 .11215 .29523 .10541 .28883 Metetra
.664 .741 .908 r
.10541 .28883 .11215 .29523 .12131 .29177 .11458 .28535 Metetra
.664 .741 .908 r
.11458 .28535 .12131 .29177 .1305 .2883 .12379 .28185 Metetra
.664 .741 .908 r
.12379 .28185 .1305 .2883 .13972 .28481 .13303 .27834 Metetra
.664 .741 .908 r
.13303 .27834 .13972 .28481 .14898 .28131 .14231 .27482 Metetra
.664 .741 .908 r
.14231 .27482 .14898 .28131 .15827 .2778 .15162 .27129 Metetra
.664 .741 .908 r
.15162 .27129 .15827 .2778 .16759 .27428 .16096 .26774 Metetra
.664 .741 .908 r
.16096 .26774 .16759 .27428 .17694 .27074 .17033 .26418 Metetra
.664 .741 .908 r
.17033 .26418 .17694 .27074 .18634 .2672 .17974 .26061 Metetra
.664 .741 .908 r
.17974 .26061 .18634 .2672 .19576 .26363 .18919 .25702 Metetra
.664 .741 .908 r
.18919 .25702 .19576 .26363 .20522 .26006 .19867 .25342 Metetra
.664 .741 .908 r
.19867 .25342 .20522 .26006 .21471 .25647 .20818 .24981 Metetra
.664 .741 .908 r
.20818 .24981 .21471 .25647 .22424 .25287 .21773 .24619 Metetra
.664 .741 .908 r
.21773 .24619 .22424 .25287 .23381 .24925 .22732 .24255 Metetra
.664 .741 .908 r
.22732 .24255 .23381 .24925 .24341 .24563 .23694 .23889 Metetra
.664 .741 .908 r
.23694 .23889 .24341 .24563 .25304 .24199 .24659 .23523 Metetra
.664 .741 .908 r
.24659 .23523 .25304 .24199 .26271 .23833 .25628 .23155 Metetra
.664 .741 .908 r
.25628 .23155 .26271 .23833 .27242 .23466 .26601 .22786 Metetra
.664 .741 .908 r
.26601 .22786 .27242 .23466 .28216 .23098 .27578 .22415 Metetra
.664 .741 .908 r
.27578 .22415 .28216 .23098 .29194 .22729 .28558 .22043 Metetra
.664 .741 .908 r
.28558 .22043 .29194 .22729 .30175 .22358 .29541 .21669 Metetra
.664 .741 .908 r
.29541 .21669 .30175 .22358 .31161 .21985 .30529 .21294 Metetra
.625 .729 .921 r
.30529 .21294 .31161 .21985 .32147 .21655 .31514 .21008 Metetra
.595 .734 .941 r
.31514 .21008 .32147 .21655 .33135 .21351 .32499 .20776 Metetra
.312 .63 .962 r
.32499 .20776 .33135 .21351 .34054 .22247 .33467 .20891 Metetra
.353 .423 .795 r
.33467 .20891 .34054 .22247 .34935 .24035 .34427 .2126 Metetra
0 0 .483 r
.34427 .2126 .34935 .24035 .35791 .26603 .35288 .23559 Metetra
0 0 .215 r
.35288 .23559 .35791 .26603 .36635 .29861 .3608 .27542 Metetra
0 .023 .559 r
.3608 .27542 .36635 .29861 .37594 .31276 .37014 .29321 Metetra
.605 .508 .718 r
.37014 .29321 .37594 .31276 .38648 .30901 .38067 .28942 Metetra
.821 .63 .645 r
.38067 .28942 .38648 .30901 .3978 .2873 .39217 .264 Metetra
.87 .642 .591 r
.39217 .264 .3978 .2873 .40974 .24706 .40445 .2164 Metetra
.785 .57 .609 r
.40445 .2164 .40974 .24706 .42123 .21366 .41585 .18562 Metetra
.671 .501 .646 r
.41585 .18562 .42123 .21366 .43233 .18802 .42648 .17418 Metetra
.728 .629 .748 r
.42648 .17418 .43233 .18802 .44308 .17131 .43703 .16527 Metetra
.721 .799 .913 r
.43703 .16527 .44308 .17131 .45349 .16667 .44749 .15985 Metetra
.698 .768 .906 r
.44749 .15985 .45349 .16667 .46392 .16229 .45796 .15498 Metetra
.664 .741 .908 r
.45796 .15498 .46392 .16229 .47439 .15833 .46846 .15099 Metetra
.664 .741 .908 r
.46846 .15099 .47439 .15833 .4849 .15436 .47899 .14699 Metetra
.664 .741 .908 r
.47899 .14699 .4849 .15436 .49545 .15038 .48956 .14298 Metetra
.664 .741 .908 r
.48956 .14298 .49545 .15038 .50603 .14638 .50018 .13895 Metetra
.664 .741 .908 r
.50018 .13895 .50603 .14638 .51666 .14236 .51084 .1349 Metetra
.664 .741 .908 r
.51084 .1349 .51666 .14236 .52734 .13833 .52154 .13084 Metetra
.664 .741 .908 r
.52154 .13084 .52734 .13833 .53805 .13428 .53228 .12676 Metetra
.664 .741 .908 r
.53228 .12676 .53805 .13428 .5488 .13021 .54306 .12267 Metetra
.664 .741 .908 r
.54306 .12267 .5488 .13021 .5596 .12613 .55388 .11856 Metetra
.664 .741 .908 r
.55388 .11856 .5596 .12613 .57044 .12204 .56475 .11443 Metetra
.664 .741 .908 r
.56475 .11443 .57044 .12204 .58132 .11792 .57566 .11029 Metetra
.664 .741 .908 r
.57566 .11029 .58132 .11792 .59225 .1138 .58661 .10613 Metetra
.664 .741 .908 r
.58661 .10613 .59225 .1138 .60321 .10965 .59761 .10196 Metetra
.664 .741 .908 r
.59761 .10196 .60321 .10965 .61422 .10549 .60865 .09776 Metetra
.664 .741 .908 r
.60865 .09776 .61422 .10549 .62528 .10131 .61973 .09356 Metetra
.664 .741 .908 r
.61973 .09356 .62528 .10131 .63638 .09712 .63086 .08933 Metetra
.664 .741 .908 r
.63086 .08933 .63638 .09712 .64752 .09291 .64203 .08509 Metetra
.664 .741 .908 r
.64203 .08509 .64752 .09291 .6587 .08868 .65325 .08083 Metetra
.664 .741 .908 r
.65325 .08083 .6587 .08868 .66994 .08444 .66451 .07655 Metetra
.664 .741 .908 r
.66451 .07655 .66994 .08444 .68121 .08017 .67582 .07226 Metetra
.664 .741 .908 r
.67582 .07226 .68121 .08017 .69253 .0759 .68717 .06795 Metetra
.664 .741 .908 r
.68717 .06795 .69253 .0759 .7039 .0716 .69857 .06362 Metetra
.664 .741 .908 r
.69857 .06362 .7039 .0716 .71531 .06729 .71001 .05928 Metetra
.664 .741 .908 r
.71001 .05928 .71531 .06729 .72677 .06296 .7215 .05492 Metetra
.664 .741 .908 r
.07124 .29284 .07809 .29921 .08716 .29576 .08034 .28937 Metetra
.664 .741 .908 r
.08034 .28937 .08716 .29576 .09627 .2923 .08946 .28589 Metetra
.664 .741 .908 r
.08946 .28589 .09627 .2923 .10541 .28883 .09862 .28239 Metetra
.664 .741 .908 r
.09862 .28239 .10541 .28883 .11458 .28535 .10781 .27888 Metetra
.664 .741 .908 r
.10781 .27888 .11458 .28535 .12379 .28185 .11704 .27537 Metetra
.664 .741 .908 r
.11704 .27537 .12379 .28185 .13303 .27834 .1263 .27183 Metetra
.664 .741 .908 r
.1263 .27183 .13303 .27834 .14231 .27482 .13559 .26829 Metetra
.664 .741 .908 r
.13559 .26829 .14231 .27482 .15162 .27129 .14492 .26473 Metetra
.664 .741 .908 r
.14492 .26473 .15162 .27129 .16096 .26774 .15428 .26116 Metetra
.664 .741 .908 r
.15428 .26116 .16096 .26774 .17033 .26418 .16368 .25758 Metetra
.664 .741 .908 r
.16368 .25758 .17033 .26418 .17974 .26061 .17311 .25398 Metetra
.664 .741 .908 r
.17311 .25398 .17974 .26061 .18919 .25702 .18257 .25037 Metetra
.664 .741 .908 r
.18257 .25037 .18919 .25702 .19867 .25342 .19207 .24674 Metetra
.664 .741 .908 r
.19207 .24674 .19867 .25342 .20818 .24981 .20161 .24311 Metetra
.664 .741 .908 r
.20161 .24311 .20818 .24981 .21773 .24619 .21118 .23946 Metetra
.664 .741 .908 r
.21118 .23946 .21773 .24619 .22732 .24255 .22078 .23579 Metetra
.664 .741 .908 r
.22078 .23579 .22732 .24255 .23694 .23889 .23042 .23212 Metetra
.664 .741 .908 r
.23042 .23212 .23694 .23889 .24659 .23523 .2401 .22842 Metetra
.664 .741 .908 r
.2401 .22842 .24659 .23523 .25628 .23155 .24981 .22472 Metetra
.664 .741 .908 r
.24981 .22472 .25628 .23155 .26601 .22786 .25956 .221 Metetra
.664 .741 .908 r
.25956 .221 .26601 .22786 .27578 .22415 .26935 .21727 Metetra
.664 .741 .908 r
.26935 .21727 .27578 .22415 .28558 .22043 .27917 .21352 Metetra
.664 .741 .908 r
.27917 .21352 .28558 .22043 .29541 .21669 .28903 .20976 Metetra
.664 .741 .908 r
.28903 .20976 .29541 .21669 .30529 .21294 .29892 .20599 Metetra
.566 .707 .936 r
.29892 .20599 .30529 .21294 .31514 .21008 .30871 .20425 Metetra
.458 .703 .973 r
.30871 .20425 .31514 .21008 .32499 .20776 .31846 .20381 Metetra
.279 .686 .971 r
.31846 .20381 .32499 .20776 .33467 .20891 .32821 .20428 Metetra
.246 .64 .961 r
.32821 .20428 .33467 .20891 .34427 .2126 .33798 .20541 Metetra
.609 .13 0 r
.33798 .20541 .34427 .2126 .35288 .23559 .34719 .21731 Metetra
0 0 .397 r
.34719 .21731 .35288 .23559 .3608 .27542 .35604 .2384 Metetra
.391 .279 .605 r
.35604 .2384 .3608 .27542 .37014 .29321 .36575 .24678 Metetra
.556 .379 .597 r
.36575 .24678 .37014 .29321 .38067 .28942 .37617 .24293 Metetra
.65 .448 .597 r
.37617 .24293 .38067 .28942 .39217 .264 .38719 .22684 Metetra
.749 .533 .602 r
.38719 .22684 .39217 .264 .40445 .2164 .3987 .19796 Metetra
.797 .623 .665 r
.3987 .19796 .40445 .2164 .41585 .18562 .40972 .17824 Metetra
.796 .773 .832 r
.40972 .17824 .41585 .18562 .42648 .17418 .42031 .16931 Metetra
.808 .852 .882 r
.42031 .16931 .42648 .17418 .43703 .16527 .43087 .16104 Metetra
.789 .875 .91 r
.43087 .16104 .43703 .16527 .44749 .15985 .44142 .15368 Metetra
.74 .802 .902 r
.44142 .15368 .44749 .15985 .45796 .15498 .45196 .14761 Metetra
.664 .741 .908 r
.45196 .14761 .45796 .15498 .46846 .15099 .46248 .1436 Metetra
.664 .741 .908 r
.46248 .1436 .46846 .15099 .47899 .14699 .47304 .13957 Metetra
.664 .741 .908 r
.47304 .13957 .47899 .14699 .48956 .14298 .48364 .13552 Metetra
.664 .741 .908 r
.48364 .13552 .48956 .14298 .50018 .13895 .49428 .13146 Metetra
.664 .741 .908 r
.49428 .13146 .50018 .13895 .51084 .1349 .50497 .12739 Metetra
.664 .741 .908 r
.50497 .12739 .51084 .1349 .52154 .13084 .51569 .1233 Metetra
.664 .741 .908 r
.51569 .1233 .52154 .13084 .53228 .12676 .52646 .11919 Metetra
.664 .741 .908 r
.52646 .11919 .53228 .12676 .54306 .12267 .53727 .11507 Metetra
.664 .741 .908 r
.53727 .11507 .54306 .12267 .55388 .11856 .54812 .11093 Metetra
.664 .741 .908 r
.54812 .11093 .55388 .11856 .56475 .11443 .55902 .10677 Metetra
.664 .741 .908 r
.55902 .10677 .56475 .11443 .57566 .11029 .56996 .1026 Metetra
.664 .741 .908 r
.56996 .1026 .57566 .11029 .58661 .10613 .58094 .09841 Metetra
.664 .741 .908 r
.58094 .09841 .58661 .10613 .59761 .10196 .59196 .0942 Metetra
.664 .741 .908 r
.59196 .0942 .59761 .10196 .60865 .09776 .60303 .08998 Metetra
.664 .741 .908 r
.60303 .08998 .60865 .09776 .61973 .09356 .61415 .08574 Metetra
.664 .741 .908 r
.61415 .08574 .61973 .09356 .63086 .08933 .6253 .08149 Metetra
.664 .741 .908 r
.6253 .08149 .63086 .08933 .64203 .08509 .63651 .07721 Metetra
.664 .741 .908 r
.63651 .07721 .64203 .08509 .65325 .08083 .64775 .07292 Metetra
.664 .741 .908 r
.64775 .07292 .65325 .08083 .66451 .07655 .65904 .06862 Metetra
.664 .741 .908 r
.65904 .06862 .66451 .07655 .67582 .07226 .67038 .06429 Metetra
.664 .741 .908 r
.67038 .06429 .67582 .07226 .68717 .06795 .68177 .05995 Metetra
.664 .741 .908 r
.68177 .05995 .68717 .06795 .69857 .06362 .6932 .05559 Metetra
.664 .741 .908 r
.6932 .05559 .69857 .06362 .71001 .05928 .70467 .05121 Metetra
.664 .741 .908 r
.70467 .05121 .71001 .05928 .7215 .05492 .71619 .04682 Metetra
.664 .741 .908 r
.06435 .28642 .07124 .29284 .08034 .28937 .07347 .28293 Metetra
.664 .741 .908 r
.07347 .28293 .08034 .28937 .08946 .28589 .08261 .27942 Metetra
.664 .741 .908 r
.08261 .27942 .08946 .28589 .09862 .28239 .09179 .27591 Metetra
.664 .741 .908 r
.09179 .27591 .09862 .28239 .10781 .27888 .101 .27238 Metetra
.664 .741 .908 r
.101 .27238 .10781 .27888 .11704 .27537 .11024 .26883 Metetra
.664 .741 .908 r
.11024 .26883 .11704 .27537 .1263 .27183 .11952 .26528 Metetra
.664 .741 .908 r
.11952 .26528 .1263 .27183 .13559 .26829 .12883 .26171 Metetra
.664 .741 .908 r
.12883 .26171 .13559 .26829 .14492 .26473 .13818 .25813 Metetra
.664 .741 .908 r
.13818 .25813 .14492 .26473 .15428 .26116 .14756 .25453 Metetra
.664 .741 .908 r
.14756 .25453 .15428 .26116 .16368 .25758 .15698 .25092 Metetra
.664 .741 .908 r
.15698 .25092 .16368 .25758 .17311 .25398 .16643 .2473 Metetra
.664 .741 .908 r
.16643 .2473 .17311 .25398 .18257 .25037 .17591 .24367 Metetra
.664 .741 .908 r
.17591 .24367 .18257 .25037 .19207 .24674 .18543 .24002 Metetra
.664 .741 .908 r
.18543 .24002 .19207 .24674 .20161 .24311 .19499 .23636 Metetra
.664 .741 .908 r
.19499 .23636 .20161 .24311 .21118 .23946 .20458 .23268 Metetra
.664 .741 .908 r
.20458 .23268 .21118 .23946 .22078 .23579 .2142 .22899 Metetra
.664 .741 .908 r
.2142 .22899 .22078 .23579 .23042 .23212 .22386 .22529 Metetra
.664 .741 .908 r
.22386 .22529 .23042 .23212 .2401 .22842 .23356 .22157 Metetra
.664 .741 .908 r
.23356 .22157 .2401 .22842 .24981 .22472 .2433 .21784 Metetra
.664 .741 .908 r
.2433 .21784 .24981 .22472 .25956 .221 .25307 .2141 Metetra
.664 .741 .908 r
.25307 .2141 .25956 .221 .26935 .21727 .26287 .21034 Metetra
.664 .741 .908 r
.26287 .21034 .26935 .21727 .27917 .21352 .27272 .20657 Metetra
.66 .74 .909 r
.27272 .20657 .27917 .21352 .28903 .20976 .28259 .20286 Metetra
.659 .742 .912 r
.28259 .20286 .28903 .20976 .29892 .20599 .2925 .19918 Metetra
.496 .684 .95 r
.2925 .19918 .29892 .20599 .30871 .20425 .30223 .1985 Metetra
.295 .624 .961 r
.30223 .1985 .30871 .20425 .31846 .20381 .31187 .19974 Metetra
.37 .733 .989 r
.31187 .19974 .31846 .20381 .32821 .20428 .3217 .19943 Metetra
.504 .766 .99 r
.3217 .19943 .32821 .20428 .33798 .20541 .33165 .19801 Metetra
.357 .596 .937 r
.33165 .19801 .33798 .20541 .34719 .21731 .34149 .19933 Metetra
.403 .394 .735 r
.34149 .19933 .34719 .21731 .35604 .2384 .35127 .20295 Metetra
.522 .375 .623 r
.35127 .20295 .35604 .2384 .36575 .24678 .36135 .20271 Metetra
.557 .382 .6 r
.36135 .20271 .36575 .24678 .37617 .24293 .37167 .19881 Metetra
.591 .407 .601 r
.37167 .19881 .37617 .24293 .38719 .22684 .38221 .19124 Metetra
.644 .461 .621 r
.38221 .19124 .38719 .22684 .3987 .19796 .39294 .1798 Metetra
.698 .571 .708 r
.39294 .1798 .3987 .19796 .40972 .17824 .40356 .17064 Metetra
.738 .756 .867 r
.40356 .17064 .40972 .17824 .42031 .16931 .41408 .16423 Metetra
.788 .845 .894 r
.41408 .16423 .42031 .16931 .43087 .16104 .42466 .15669 Metetra
.83 .871 .875 r
.42466 .15669 .43087 .16104 .44142 .15368 .43531 .14758 Metetra
.771 .812 .885 r
.43531 .14758 .44142 .15368 .45196 .14761 .44591 .14039 Metetra
.669 .75 .911 r
.44591 .14039 .45196 .14761 .46248 .1436 .45646 .13623 Metetra
.667 .745 .909 r
.45646 .13623 .46248 .1436 .47304 .13957 .46705 .13209 Metetra
.664 .741 .908 r
.46705 .13209 .47304 .13957 .48364 .13552 .47767 .12802 Metetra
.664 .741 .908 r
.47767 .12802 .48364 .13552 .49428 .13146 .48834 .12393 Metetra
.664 .741 .908 r
.48834 .12393 .49428 .13146 .50497 .12739 .49905 .11982 Metetra
.664 .741 .908 r
.49905 .11982 .50497 .12739 .51569 .1233 .50981 .1157 Metetra
.664 .741 .908 r
.50981 .1157 .51569 .1233 .52646 .11919 .5206 .11157 Metetra
.664 .741 .908 r
.5206 .11157 .52646 .11919 .53727 .11507 .53144 .10741 Metetra
.664 .741 .908 r
.53144 .10741 .53727 .11507 .54812 .11093 .54232 .10324 Metetra
.664 .741 .908 r
.54232 .10324 .54812 .11093 .55902 .10677 .55324 .09906 Metetra
.664 .741 .908 r
.55324 .09906 .55902 .10677 .56996 .1026 .56421 .09485 Metetra
.664 .741 .908 r
.56421 .09485 .56996 .1026 .58094 .09841 .57522 .09063 Metetra
.664 .741 .908 r
.57522 .09063 .58094 .09841 .59196 .0942 .58628 .0864 Metetra
.664 .741 .908 r
.58628 .0864 .59196 .0942 .60303 .08998 .59737 .08214 Metetra
.664 .741 .908 r
.59737 .08214 .60303 .08998 .61415 .08574 .60852 .07787 Metetra
.664 .741 .908 r
.60852 .07787 .61415 .08574 .6253 .08149 .61971 .07358 Metetra
.664 .741 .908 r
.61971 .07358 .6253 .08149 .63651 .07721 .63094 .06928 Metetra
.664 .741 .908 r
.63094 .06928 .63651 .07721 .64775 .07292 .64222 .06496 Metetra
.664 .741 .908 r
.64222 .06496 .64775 .07292 .65904 .06862 .65354 .06062 Metetra
.664 .741 .908 r
.65354 .06062 .65904 .06862 .67038 .06429 .66491 .05626 Metetra
.664 .741 .908 r
.66491 .05626 .67038 .06429 .68177 .05995 .67632 .05189 Metetra
.664 .741 .908 r
.67632 .05189 .68177 .05995 .6932 .05559 .68778 .04749 Metetra
.664 .741 .908 r
.68778 .04749 .6932 .05559 .70467 .05121 .69929 .04308 Metetra
.664 .741 .908 r
.69929 .04308 .70467 .05121 .71619 .04682 .71085 .03865 Metetra
.664 .741 .908 r
.05742 .27996 .06435 .28642 .07347 .28293 .06655 .27645 Metetra
.664 .741 .908 r
.06655 .27645 .07347 .28293 .08261 .27942 .07571 .27292 Metetra
.664 .741 .908 r
.07571 .27292 .08261 .27942 .09179 .27591 .08491 .26938 Metetra
.664 .741 .908 r
.08491 .26938 .09179 .27591 .101 .27238 .09414 .26583 Metetra
.664 .741 .908 r
.09414 .26583 .101 .27238 .11024 .26883 .1034 .26226 Metetra
.664 .741 .908 r
.1034 .26226 .11024 .26883 .11952 .26528 .1127 .25868 Metetra
.664 .741 .908 r
.1127 .25868 .11952 .26528 .12883 .26171 .12203 .25509 Metetra
.664 .741 .908 r
.12203 .25509 .12883 .26171 .13818 .25813 .13139 .25148 Metetra
.664 .741 .908 r
.13139 .25148 .13818 .25813 .14756 .25453 .14079 .24786 Metetra
.664 .741 .908 r
.14079 .24786 .14756 .25453 .15698 .25092 .15023 .24423 Metetra
.664 .741 .908 r
.15023 .24423 .15698 .25092 .16643 .2473 .1597 .24058 Metetra
.664 .741 .908 r
.1597 .24058 .16643 .2473 .17591 .24367 .1692 .23692 Metetra
.664 .741 .908 r
.1692 .23692 .17591 .24367 .18543 .24002 .17874 .23325 Metetra
.664 .741 .908 r
.17874 .23325 .18543 .24002 .19499 .23636 .18832 .22956 Metetra
.664 .741 .908 r
.18832 .22956 .19499 .23636 .20458 .23268 .19793 .22586 Metetra
.664 .741 .908 r
.19793 .22586 .20458 .23268 .2142 .22899 .20758 .22215 Metetra
.664 .741 .908 r
.20758 .22215 .2142 .22899 .22386 .22529 .21726 .21842 Metetra
.664 .741 .908 r
.21726 .21842 .22386 .22529 .23356 .22157 .22698 .21468 Metetra
.664 .741 .908 r
.22698 .21468 .23356 .22157 .2433 .21784 .23673 .21092 Metetra
.664 .741 .908 r
.23673 .21092 .2433 .21784 .25307 .2141 .24653 .20715 Metetra
.664 .741 .908 r
.24653 .20715 .25307 .2141 .26287 .21034 .25635 .20336 Metetra
.664 .741 .908 r
.25635 .20336 .26287 .21034 .27272 .20657 .26622 .19956 Metetra
.606 .722 .927 r
.26622 .19956 .27272 .20657 .28259 .20286 .27602 .19705 Metetra
.555 .747 .966 r
.27602 .19705 .28259 .20286 .2925 .19918 .2858 .19524 Metetra
.407 .757 .994 r
.2858 .19524 .2925 .19918 .30223 .1985 .29556 .19451 Metetra
.334 .718 .983 r
.29556 .19451 .30223 .1985 .31187 .19974 .30532 .19446 Metetra
.577 .779 .975 r
.30532 .19446 .31187 .19974 .3217 .19943 .3153 .19213 Metetra
.667 .738 .903 r
.3153 .19213 .3217 .19943 .33165 .19801 .32544 .18812 Metetra
.609 .645 .861 r
.32544 .18812 .33165 .19801 .34149 .19933 .33553 .18546 Metetra
.565 .545 .791 r
.33553 .18546 .34149 .19933 .35127 .20295 .3456 .1839 Metetra
.584 .496 .721 r
.3456 .1839 .35127 .20295 .36135 .20271 .3558 .18112 Metetra
.599 .486 .696 r
.3558 .18112 .36135 .20271 .37167 .19881 .3661 .17718 Metetra
.618 .498 .694 r
.3661 .17718 .37167 .19881 .38221 .19124 .3765 .17209 Metetra
.649 .535 .711 r
.3765 .17209 .38221 .19124 .39294 .1798 .38699 .16577 Metetra
.659 .594 .772 r
.38699 .16577 .39294 .1798 .40356 .17064 .39745 .16055 Metetra
.647 .661 .849 r
.39745 .16055 .40356 .17064 .41408 .16423 .4079 .15667 Metetra
.714 .753 .883 r
.4079 .15667 .41408 .16423 .42466 .15669 .41844 .15112 Metetra
.792 .832 .882 r
.41844 .15112 .42466 .15669 .43531 .14758 .42909 .14325 Metetra
.781 .875 .916 r
.42909 .14325 .43531 .14758 .44591 .14039 .43973 .13606 Metetra
.745 .872 .939 r
.43973 .13606 .44591 .14039 .45646 .13623 .45037 .12996 Metetra
.715 .798 .916 r
.45037 .12996 .45646 .13623 .46705 .13209 .46101 .12456 Metetra
.664 .741 .908 r
.46101 .12456 .46705 .13209 .47767 .12802 .47166 .12046 Metetra
.664 .741 .908 r
.47166 .12046 .47767 .12802 .48834 .12393 .48236 .11634 Metetra
.664 .741 .908 r
.48236 .11634 .48834 .12393 .49905 .11982 .4931 .1122 Metetra
.664 .741 .908 r
.4931 .1122 .49905 .11982 .50981 .1157 .50388 .10805 Metetra
.664 .741 .908 r
.50388 .10805 .50981 .1157 .5206 .11157 .5147 .10388 Metetra
.664 .741 .908 r
.5147 .10388 .5206 .11157 .53144 .10741 .52557 .0997 Metetra
.664 .741 .908 r
.52557 .0997 .53144 .10741 .54232 .10324 .53648 .0955 Metetra
.664 .741 .908 r
.53648 .0955 .54232 .10324 .55324 .09906 .54743 .09128 Metetra
.664 .741 .908 r
.54743 .09128 .55324 .09906 .56421 .09485 .55842 .08705 Metetra
.664 .741 .908 r
.55842 .08705 .56421 .09485 .57522 .09063 .56946 .0828 Metetra
.664 .741 .908 r
.56946 .0828 .57522 .09063 .58628 .0864 .58055 .07853 Metetra
.664 .741 .908 r
.58055 .07853 .58628 .0864 .59737 .08214 .59168 .07425 Metetra
.664 .741 .908 r
.59168 .07425 .59737 .08214 .60852 .07787 .60285 .06994 Metetra
.664 .741 .908 r
.60285 .06994 .60852 .07787 .61971 .07358 .61407 .06562 Metetra
.664 .741 .908 r
.61407 .06562 .61971 .07358 .63094 .06928 .62533 .06129 Metetra
.664 .741 .908 r
.62533 .06129 .63094 .06928 .64222 .06496 .63664 .05693 Metetra
.664 .741 .908 r
.63664 .05693 .64222 .06496 .65354 .06062 .64799 .05256 Metetra
.664 .741 .908 r
.64799 .05256 .65354 .06062 .66491 .05626 .65939 .04817 Metetra
.664 .741 .908 r
.65939 .04817 .66491 .05626 .67632 .05189 .67084 .04376 Metetra
.664 .741 .908 r
.67084 .04376 .67632 .05189 .68778 .04749 .68233 .03934 Metetra
.664 .741 .908 r
.68233 .03934 .68778 .04749 .69929 .04308 .69387 .03489 Metetra
.664 .741 .908 r
.69387 .03489 .69929 .04308 .71085 .03865 .70546 .03043 Metetra
.664 .741 .908 r
.05044 .27347 .05742 .27996 .06655 .27645 .05959 .26993 Metetra
.664 .741 .908 r
.05959 .26993 .06655 .27645 .07571 .27292 .06877 .26637 Metetra
.664 .741 .908 r
.06877 .26637 .07571 .27292 .08491 .26938 .07798 .26281 Metetra
.664 .741 .908 r
.07798 .26281 .08491 .26938 .09414 .26583 .08723 .25923 Metetra
.664 .741 .908 r
.08723 .25923 .09414 .26583 .1034 .26226 .09651 .25564 Metetra
.664 .741 .908 r
.09651 .25564 .1034 .26226 .1127 .25868 .10583 .25204 Metetra
.664 .741 .908 r
.10583 .25204 .1127 .25868 .12203 .25509 .11518 .24842 Metetra
.664 .741 .908 r
.11518 .24842 .12203 .25509 .13139 .25148 .12456 .24479 Metetra
.664 .741 .908 r
.12456 .24479 .13139 .25148 .14079 .24786 .13398 .24114 Metetra
.664 .741 .908 r
.13398 .24114 .14079 .24786 .15023 .24423 .14344 .23749 Metetra
.664 .741 .908 r
.14344 .23749 .15023 .24423 .1597 .24058 .15293 .23381 Metetra
.664 .741 .908 r
.15293 .23381 .1597 .24058 .1692 .23692 .16245 .23013 Metetra
.664 .741 .908 r
.16245 .23013 .1692 .23692 .17874 .23325 .17201 .22643 Metetra
.664 .741 .908 r
.17201 .22643 .17874 .23325 .18832 .22956 .18161 .22272 Metetra
.664 .741 .908 r
.18161 .22272 .18832 .22956 .19793 .22586 .19124 .21899 Metetra
.664 .741 .908 r
.19124 .21899 .19793 .22586 .20758 .22215 .20091 .21525 Metetra
.664 .741 .908 r
.20091 .21525 .20758 .22215 .21726 .21842 .21061 .2115 Metetra
.664 .741 .908 r
.21061 .2115 .21726 .21842 .22698 .21468 .22035 .20773 Metetra
.664 .741 .908 r
.22035 .20773 .22698 .21468 .23673 .21092 .23013 .20395 Metetra
.664 .741 .908 r
.23013 .20395 .23673 .21092 .24653 .20715 .23994 .20015 Metetra
.663 .741 .908 r
.23994 .20015 .24653 .20715 .25635 .20336 .24979 .19635 Metetra
.663 .742 .909 r
.24979 .19635 .25635 .20336 .26622 .19956 .25968 .19255 Metetra
.541 .698 .941 r
.25968 .19255 .26622 .19956 .27602 .19705 .26939 .19117 Metetra
.417 .686 .974 r
.26939 .19117 .27602 .19705 .2858 .19524 .27905 .19114 Metetra
.423 .76 .996 r
.27905 .19114 .2858 .19524 .29556 .19451 .28884 .19028 Metetra
.477 .78 .997 r
.28884 .19028 .29556 .19451 .30532 .19446 .29872 .18891 Metetra
.682 .802 .939 r
.29872 .18891 .30532 .19446 .3153 .19213 .30887 .18459 Metetra
.741 .753 .862 r
.30887 .18459 .3153 .19213 .32544 .18812 .31919 .17814 Metetra
.718 .687 .819 r
.31919 .17814 .32544 .18812 .33553 .18546 .32954 .17167 Metetra
.687 .61 .764 r
.32954 .17167 .33553 .18546 .3456 .1839 .33992 .16518 Metetra
.632 .527 .717 r
.33992 .16518 .3456 .1839 .3558 .18112 .35024 .16 Metetra
.6 .49 .7 r
.35024 .16 .3558 .18112 .3661 .17718 .36052 .15602 Metetra
.577 .475 .702 r
.36052 .15602 .3661 .17718 .3765 .17209 .37077 .15327 Metetra
.553 .48 .727 r
.37077 .15327 .3765 .17209 .38699 .16577 .38102 .15181 Metetra
.559 .543 .794 r
.38102 .15181 .38699 .16577 .39745 .16055 .39132 .15035 Metetra
.558 .619 .869 r
.39132 .15035 .39745 .16055 .4079 .15667 .40167 .14888 Metetra
.645 .725 .906 r
.40167 .14888 .4079 .15667 .41844 .15112 .41217 .14526 Metetra
.755 .819 .902 r
.41217 .14526 .41844 .15112 .42909 .14325 .42281 .13868 Metetra
.778 .868 .915 r
.42281 .13868 .42909 .14325 .43973 .13606 .4335 .13156 Metetra
.801 .873 .9 r
.4335 .13156 .43973 .13606 .45037 .12996 .44422 .12361 Metetra
.752 .806 .895 r
.44422 .12361 .45037 .12996 .46101 .12456 .45493 .11701 Metetra
.664 .743 .908 r
.45493 .11701 .46101 .12456 .47166 .12046 .46561 .11285 Metetra
.664 .742 .908 r
.46561 .11285 .47166 .12046 .48236 .11634 .47633 .10869 Metetra
.664 .741 .908 r
.47633 .10869 .48236 .11634 .4931 .1122 .4871 .10453 Metetra
.664 .741 .908 r
.4871 .10453 .4931 .1122 .50388 .10805 .49791 .10035 Metetra
.664 .741 .908 r
.49791 .10035 .50388 .10805 .5147 .10388 .50876 .09615 Metetra
.664 .741 .908 r
.50876 .09615 .5147 .10388 .52557 .0997 .51965 .09193 Metetra
.664 .741 .908 r
.51965 .09193 .52557 .0997 .53648 .0955 .53059 .0877 Metetra
.664 .741 .908 r
.53059 .0877 .53648 .0955 .54743 .09128 .54157 .08345 Metetra
.664 .741 .908 r
.54157 .08345 .54743 .09128 .55842 .08705 .55259 .07919 Metetra
.664 .741 .908 r
.55259 .07919 .55842 .08705 .56946 .0828 .56366 .07491 Metetra
.664 .741 .908 r
.56366 .07491 .56946 .0828 .58055 .07853 .57478 .07061 Metetra
.664 .741 .908 r
.57478 .07061 .58055 .07853 .59168 .07425 .58593 .06629 Metetra
.664 .741 .908 r
.58593 .06629 .59168 .07425 .60285 .06994 .59714 .06196 Metetra
.664 .741 .908 r
.59714 .06196 .60285 .06994 .61407 .06562 .60838 .0576 Metetra
.664 .741 .908 r
.60838 .0576 .61407 .06562 .62533 .06129 .61968 .05323 Metetra
.664 .741 .908 r
.61968 .05323 .62533 .06129 .63664 .05693 .63102 .04885 Metetra
.664 .741 .908 r
.63102 .04885 .63664 .05693 .64799 .05256 .6424 .04444 Metetra
.664 .741 .908 r
.6424 .04444 .64799 .05256 .65939 .04817 .65383 .04002 Metetra
.664 .741 .908 r
.65383 .04002 .65939 .04817 .67084 .04376 .66531 .03558 Metetra
.664 .741 .908 r
.66531 .03558 .67084 .04376 .68233 .03934 .67684 .03112 Metetra
.664 .741 .908 r
.67684 .03112 .68233 .03934 .69387 .03489 .68841 .02664 Metetra
.664 .741 .908 r
.68841 .02664 .69387 .03489 .70546 .03043 .70003 .02215 Metetra
.664 .741 .908 r
.04341 .26692 .05044 .27347 .05959 .26993 .05258 .26336 Metetra
.664 .741 .908 r
.05258 .26336 .05959 .26993 .06877 .26637 .06178 .25978 Metetra
.664 .741 .908 r
.06178 .25978 .06877 .26637 .07798 .26281 .07101 .25619 Metetra
.664 .741 .908 r
.07101 .25619 .07798 .26281 .08723 .25923 .08028 .25259 Metetra
.664 .741 .908 r
.08028 .25259 .08723 .25923 .09651 .25564 .08958 .24898 Metetra
.664 .741 .908 r
.08958 .24898 .09651 .25564 .10583 .25204 .09891 .24535 Metetra
.664 .741 .908 r
.09891 .24535 .10583 .25204 .11518 .24842 .10828 .24171 Metetra
.664 .741 .908 r
.10828 .24171 .11518 .24842 .12456 .24479 .11768 .23805 Metetra
.664 .741 .908 r
.11768 .23805 .12456 .24479 .13398 .24114 .12712 .23438 Metetra
.664 .741 .908 r
.12712 .23438 .13398 .24114 .14344 .23749 .1366 .2307 Metetra
.664 .741 .908 r
.1366 .2307 .14344 .23749 .15293 .23381 .14611 .227 Metetra
.664 .741 .908 r
.14611 .227 .15293 .23381 .16245 .23013 .15565 .22329 Metetra
.664 .741 .908 r
.15565 .22329 .16245 .23013 .17201 .22643 .16523 .21957 Metetra
.664 .741 .908 r
.16523 .21957 .17201 .22643 .18161 .22272 .17485 .21583 Metetra
.664 .741 .908 r
.17485 .21583 .18161 .22272 .19124 .21899 .1845 .21208 Metetra
.664 .741 .908 r
.1845 .21208 .19124 .21899 .20091 .21525 .19419 .20831 Metetra
.664 .741 .908 r
.19419 .20831 .20091 .21525 .21061 .2115 .20391 .20453 Metetra
.664 .741 .908 r
.20391 .20453 .21061 .2115 .22035 .20773 .21367 .20073 Metetra
.664 .741 .908 r
.21367 .20073 .22035 .20773 .23013 .20395 .22347 .19693 Metetra
.664 .741 .908 r
.22347 .19693 .23013 .20395 .23994 .20015 .23331 .1931 Metetra
.645 .736 .915 r
.23331 .1931 .23994 .20015 .24979 .19635 .24314 .18971 Metetra
.636 .747 .928 r
.24314 .18971 .24979 .19635 .25968 .19255 .25299 .18651 Metetra
.566 .745 .961 r
.25299 .18651 .25968 .19255 .26939 .19117 .26278 .18452 Metetra
.531 .709 .953 r
.26278 .18452 .26939 .19117 .27905 .19114 .27256 .18319 Metetra
.622 .703 .903 r
.27256 .18319 .27905 .19114 .28884 .19028 .28253 .18026 Metetra
.652 .66 .845 r
.28253 .18026 .28884 .19028 .29872 .18891 .29261 .17631 Metetra
.656 .612 .794 r
.29261 .17631 .29872 .18891 .30887 .18459 .30279 .17164 Metetra
.666 .612 .785 r
.30279 .17164 .30887 .18459 .31919 .17814 .31304 .16643 Metetra
.675 .637 .804 r
.31304 .16643 .31919 .17814 .32954 .17167 .32332 .1612 Metetra
.685 .666 .826 r
.32332 .1612 .32954 .17167 .33992 .16518 .33363 .15596 Metetra
.675 .692 .858 r
.33363 .15596 .33992 .16518 .35024 .16 .34393 .15136 Metetra
.659 .702 .878 r
.34393 .15136 .35024 .16 .36052 .15602 .35423 .14736 Metetra
.636 .693 .886 r
.35423 .14736 .36052 .15602 .37077 .15327 .36454 .14396 Metetra
.61 .665 .879 r
.36454 .14396 .37077 .15327 .38102 .15181 .37486 .1412 Metetra
.607 .633 .85 r
.37486 .1412 .38102 .15181 .39132 .15035 .38523 .13842 Metetra
.604 .604 .825 r
.38523 .13842 .39132 .15035 .40167 .14888 .39565 .13564 Metetra
.615 .587 .799 r
.39565 .13564 .40167 .14888 .41217 .14526 .40613 .13232 Metetra
.636 .603 .799 r
.40613 .13232 .41217 .14526 .42281 .13868 .4167 .12827 Metetra
.679 .672 .836 r
.4167 .12827 .42281 .13868 .4335 .13156 .42733 .12318 Metetra
.737 .743 .856 r
.42733 .12318 .4335 .13156 .44422 .12361 .43805 .11648 Metetra
.73 .777 .891 r
.43805 .11648 .44422 .12361 .45493 .11701 .44878 .11044 Metetra
.691 .785 .923 r
.44878 .11044 .45493 .11701 .46561 .11285 .4595 .10562 Metetra
.681 .761 .912 r
.4595 .10562 .46561 .11285 .47633 .10869 .47026 .10099 Metetra
.664 .741 .908 r
.47026 .10099 .47633 .10869 .4871 .10453 .48106 .09679 Metetra
.664 .741 .908 r
.48106 .09679 .4871 .10453 .49791 .10035 .49189 .09258 Metetra
.664 .741 .908 r
.49189 .09258 .49791 .10035 .50876 .09615 .50277 .08835 Metetra
.664 .741 .908 r
.50277 .08835 .50876 .09615 .51965 .09193 .51369 .08411 Metetra
.664 .741 .908 r
.51369 .08411 .51965 .09193 .53059 .0877 .52466 .07985 Metetra
.664 .741 .908 r
.52466 .07985 .53059 .0877 .54157 .08345 .53567 .07557 Metetra
.664 .741 .908 r
.53567 .07557 .54157 .08345 .55259 .07919 .54672 .07127 Metetra
.664 .741 .908 r
.54672 .07127 .55259 .07919 .56366 .07491 .55782 .06695 Metetra
.664 .741 .908 r
.55782 .06695 .56366 .07491 .57478 .07061 .56896 .06262 Metetra
.664 .741 .908 r
.56896 .06262 .57478 .07061 .58593 .06629 .58015 .05827 Metetra
.664 .741 .908 r
.58015 .05827 .58593 .06629 .59714 .06196 .59138 .05391 Metetra
.664 .741 .908 r
.59138 .05391 .59714 .06196 .60838 .0576 .60266 .04952 Metetra
.664 .741 .908 r
.60266 .04952 .60838 .0576 .61968 .05323 .61399 .04512 Metetra
.664 .741 .908 r
.61399 .04512 .61968 .05323 .63102 .04885 .62536 .0407 Metetra
.664 .741 .908 r
.62536 .0407 .63102 .04885 .6424 .04444 .63677 .03626 Metetra
.664 .741 .908 r
.63677 .03626 .6424 .04444 .65383 .04002 .64824 .03181 Metetra
.664 .741 .908 r
.64824 .03181 .65383 .04002 .66531 .03558 .65975 .02733 Metetra
.664 .741 .908 r
.65975 .02733 .66531 .03558 .67684 .03112 .6713 .02284 Metetra
.664 .741 .908 r
.6713 .02284 .67684 .03112 .68841 .02664 .68291 .01833 Metetra
.664 .741 .908 r
.68291 .01833 .68841 .02664 .70003 .02215 .69456 .0138 Metetra
.664 .741 .908 r
.03634 .26033 .04341 .26692 .05258 .26336 .04552 .25675 Metetra
.664 .741 .908 r
.04552 .25675 .05258 .26336 .06178 .25978 .05474 .25315 Metetra
.664 .741 .908 r
.05474 .25315 .06178 .25978 .07101 .25619 .06399 .24953 Metetra
.664 .741 .908 r
.06399 .24953 .07101 .25619 .08028 .25259 .07327 .24591 Metetra
.664 .741 .908 r
.07327 .24591 .08028 .25259 .08958 .24898 .08259 .24227 Metetra
.664 .741 .908 r
.08259 .24227 .08958 .24898 .09891 .24535 .09195 .23861 Metetra
.664 .741 .908 r
.09195 .23861 .09891 .24535 .10828 .24171 .10134 .23495 Metetra
.664 .741 .908 r
.10134 .23495 .10828 .24171 .11768 .23805 .11076 .23126 Metetra
.664 .741 .908 r
.11076 .23126 .11768 .23805 .12712 .23438 .12022 .22757 Metetra
.664 .741 .908 r
.12022 .22757 .12712 .23438 .1366 .2307 .12971 .22386 Metetra
.664 .741 .908 r
.12971 .22386 .1366 .2307 .14611 .227 .13924 .22014 Metetra
.664 .741 .908 r
.13924 .22014 .14611 .227 .15565 .22329 .1488 .2164 Metetra
.664 .741 .908 r
.1488 .2164 .15565 .22329 .16523 .21957 .1584 .21265 Metetra
.664 .741 .908 r
.1584 .21265 .16523 .21957 .17485 .21583 .16804 .20889 Metetra
.664 .741 .908 r
.16804 .20889 .17485 .21583 .1845 .21208 .17771 .20511 Metetra
.664 .741 .908 r
.17771 .20511 .1845 .21208 .19419 .20831 .18742 .20132 Metetra
.664 .741 .908 r
.18742 .20132 .19419 .20831 .20391 .20453 .19717 .19751 Metetra
.664 .741 .908 r
.19717 .19751 .20391 .20453 .21367 .20073 .20695 .19369 Metetra
.664 .741 .908 r
.20695 .19369 .21367 .20073 .22347 .19693 .21677 .18986 Metetra
.664 .741 .908 r
.21677 .18986 .22347 .19693 .23331 .1931 .22663 .18601 Metetra
.626 .729 .921 r
.22663 .18601 .23331 .1931 .24314 .18971 .23644 .18301 Metetra
.605 .736 .938 r
.23644 .18301 .24314 .18971 .25299 .18651 .24626 .18042 Metetra
.601 .758 .953 r
.24626 .18042 .25299 .18651 .26278 .18452 .25612 .17781 Metetra
.605 .738 .939 r
.25612 .17781 .26278 .18452 .27256 .18319 .26603 .17519 Metetra
.697 .728 .874 r
.26603 .17519 .27256 .18319 .28253 .18026 .27618 .17019 Metetra
.719 .686 .817 r
.27618 .17019 .28253 .18026 .29261 .17631 .28648 .16367 Metetra
.664 .616 .791 r
.28648 .16367 .29261 .17631 .30279 .17164 .29669 .15864 Metetra
.635 .597 .794 r
.29669 .15864 .30279 .17164 .31304 .16643 .30686 .15467 Metetra
.642 .622 .815 r
.30686 .15467 .31304 .16643 .32332 .1612 .31706 .15068 Metetra
.649 .651 .839 r
.31706 .15068 .32332 .1612 .33363 .15596 .3273 .14668 Metetra
.656 .684 .865 r
.3273 .14668 .33363 .15596 .34393 .15136 .33758 .14267 Metetra
.659 .702 .878 r
.33758 .14267 .34393 .15136 .35423 .14736 .3479 .13864 Metetra
.659 .702 .878 r
.3479 .13864 .35423 .14736 .36454 .14396 .35827 .13459 Metetra
.656 .684 .865 r
.35827 .13459 .36454 .14396 .37486 .1412 .36867 .13053 Metetra
.649 .651 .839 r
.36867 .13053 .37486 .1412 .38523 .13842 .37911 .12645 Metetra
.642 .622 .815 r
.37911 .12645 .38523 .13842 .39565 .13564 .3896 .12235 Metetra
.605 .582 .801 r
.3896 .12235 .39565 .13564 .40613 .13232 .40008 .11933 Metetra
.559 .563 .814 r
.40008 .11933 .40613 .13232 .4167 .12827 .41054 .1178 Metetra
.615 .644 .856 r
.41054 .1178 .4167 .12827 .42733 .12318 .42113 .11475 Metetra
.703 .732 .873 r
.42113 .11475 .42733 .12318 .43805 .11648 .43184 .10929 Metetra
.711 .772 .9 r
.43184 .10929 .43805 .11648 .44878 .11044 .44258 .10381 Metetra
.714 .792 .913 r
.44258 .10381 .44878 .11044 .4595 .10562 .45335 .09832 Metetra
.697 .766 .905 r
.45335 .09832 .4595 .10562 .47026 .10099 .46415 .09323 Metetra
.664 .741 .908 r
.46415 .09323 .47026 .10099 .48106 .09679 .47497 .08901 Metetra
.664 .741 .908 r
.47497 .08901 .48106 .09679 .49189 .09258 .48583 .08476 Metetra
.664 .741 .908 r
.48583 .08476 .49189 .09258 .50277 .08835 .49674 .0805 Metetra
.664 .741 .908 r
.49674 .0805 .50277 .08835 .51369 .08411 .50769 .07623 Metetra
.664 .741 .908 r
.50769 .07623 .51369 .08411 .52466 .07985 .51868 .07193 Metetra
.664 .741 .908 r
.51868 .07193 .52466 .07985 .53567 .07557 .52972 .06762 Metetra
.664 .741 .908 r
.52972 .06762 .53567 .07557 .54672 .07127 .5408 .06329 Metetra
.664 .741 .908 r
.5408 .06329 .54672 .07127 .55782 .06695 .55193 .05894 Metetra
.664 .741 .908 r
.55193 .05894 .55782 .06695 .56896 .06262 .5631 .05458 Metetra
.664 .741 .908 r
.5631 .05458 .56896 .06262 .58015 .05827 .57432 .0502 Metetra
.664 .741 .908 r
.57432 .0502 .58015 .05827 .59138 .05391 .58558 .0458 Metetra
.664 .741 .908 r
.58558 .0458 .59138 .05391 .60266 .04952 .59689 .04138 Metetra
.664 .741 .908 r
.59689 .04138 .60266 .04952 .61399 .04512 .60825 .03695 Metetra
.664 .741 .908 r
.60825 .03695 .61399 .04512 .62536 .0407 .61965 .03249 Metetra
.664 .741 .908 r
.61965 .03249 .62536 .0407 .63677 .03626 .6311 .02802 Metetra
.664 .741 .908 r
.6311 .02802 .63677 .03626 .64824 .03181 .64259 .02353 Metetra
.664 .741 .908 r
.64259 .02353 .64824 .03181 .65975 .02733 .65414 .01902 Metetra
.664 .741 .908 r
.65414 .01902 .65975 .02733 .6713 .02284 .66573 .0145 Metetra
.664 .741 .908 r
.66573 .0145 .6713 .02284 .68291 .01833 .67736 .00995 Metetra
.664 .741 .908 r
.67736 .00995 .68291 .01833 .69456 .0138 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.0648 .24431 m
.06955 .24884 L
s
[(-1)] .0553 .23527 1 .95161 Mshowa
.22524 .18149 m
.22973 .18627 L
s
[(0)] .21625 .17193 .93964 1 Mshowa
.39622 .11454 m
.40041 .11959 L
s
[(1)] .38785 .10443 .82843 1 Mshowa
.57883 .04303 m
.58266 .04837 L
s
[(2)] .57119 .03237 .71722 1 Mshowa
.125 Mabswid
.09609 .23206 m
.09891 .23481 L
s
.12777 .21966 m
.13057 .22243 L
s
.15985 .20709 m
.16261 .2099 L
s
.19234 .19437 m
.19507 .19721 L
s
.25856 .16844 m
.26122 .17135 L
s
.29231 .15523 m
.29493 .15816 L
s
.3265 .14184 m
.32909 .14481 L
s
.36113 .12828 m
.36368 .13128 L
s
.43178 .10062 m
.43425 .10368 L
s
.46781 .08651 m
.47024 .08961 L
s
.50432 .07221 m
.50671 .07534 L
s
.54133 .05772 m
.54367 .06089 L
s
.61686 .02815 m
.6191 .03138 L
s
.6554 .01305 m
.6576 .01632 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[17]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00cP3oool3000004l0oooo003?0?ooo`030000003oool0oooo04h0oooo
00370?ooo`D000000`3oool00`000000oooo0?ooo`1>0?ooo`00c`3oool00`000000oooo0?ooo`1>
0?ooo`00c`3oool00`000000oooo0?ooo`1>0?ooo`00W`3oool5000001l0oooo0P0000090?ooo`80
0000D03oool00:00oooo00@000000?ooo`3oool00000703oool5000000X0oooo00<000000?ooo`3o
ool0CP3oool00:40oooo00<000000?ooo`3oool06P3oool5000000030:Vmj0000000000005X0oooo
002R0?ooo`030000003oool0oooo01H0oooo0`000000103oool000000:Vmj00000020:Vmj0<00000
F@3oool009l0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`L000000`2Y_NP5000005T0oooo
002O0?ooo`050000003oool0oooo0?ooo`0000004P3oool2000000040?ooo`000000000000000080
ZKgX00<000000:Vmj02Y_NP00P0000000`2Y_NP000000:Vmj002000005P0oooo002P0?ooo`<00000
403oool600000080ZKgX00<000000:Vmj02Y_NP00`0000000`2Y_NP000000:Vmj005000005L0oooo
002a0?ooo`D000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<00000
0P2Y_NP2000005L0oooo002^0?ooo`D000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj000
0000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj003000005H0oooo002/0?ooo`80000000@0
oooo0000002Y_NP000000`2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`000000
ZKgX0:Vmj003000000030:Vmj0000000000005H0oooo002Y0?ooo`<0000000<0oooo000000000000
0`2Y_NP01@000000ZKgX0000002Y_NP000000080ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00D0
00000P2Y_NP3000005D0oooo002V0?ooo`<0000000@0oooo00000000000000000P2Y_NP00`000000
ZKgX0:Vmj002000000<0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX00<0000000<0ZKgX0000002Y
_NP0100000020:Vmj0800000E03oool00:@0oooo0P000000103oool000000000000000020:Vmj003
0000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0P0000030:Vmj0<0000000@0ZKgX0000
002Y_NP0ZKgX10000000102Y_NP000000:Vmj02Y_NP2000005@0oooo002Q0?ooo`H0000000<0ZKgX
0000000000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP01@000000ZKgX0000
002Y_NP000000080ZKgX0`0000020:Vmj080000000D0ZKgX00000000000000000:Vmj002000005<0
oooo002O0?ooo`80000000<0oooo0000000000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vm
j0000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX0P0000000`2Y_NP0
00000:Vmj0020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`00001B0?ooo`00W03oool600000004
0:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP0
ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0P0000030:Vmj0050000002Y_NP000000:Vmj0000000
0P2Y_NP300000080ZKgX00<000000?ooo`3oool0D03oool009X0oooo1@000000102Y_NP000000:Vm
j02Y_NP300000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX00<00000
00@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP300000003
0:Vmj0000000ZKgX0080ZKgX0P00001A0?ooo`00U`3oool3000000040?ooo`000000ZKgX00000080
ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj00300000004
0:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX
0:Vmj08000000`2Y_NP010000000ZKgX0000002Y_NP200000500oooo002E0?ooo`8000000P3oool2
000000<0ZKgX0P0000000`2Y_NP000000:Vmj0020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`00
0000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP00000
0:Vmj02Y_NP4000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP200000500oooo001`0?ooo`<0
00007`3oool3000000060?ooo`00000000000000002Y_NP000000P2Y_NP2000000<0ZKgX00D00000
0:Vmj0000000ZKgX000000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000
002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj080000000T0ZKgX00000000
000000000:Vmj0000000ZKgX0000002Y_NP00P00001?0?ooo`00L@3oool00`000000oooo0?ooo`0K
0?ooo`<0000000H0oooo00000000000000000:Vmj00000020:Vmj0<000000P2Y_NP00`000000ZKgX
0:Vmj00200000080ZKgX0`0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX
0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00300000004
0:Vmj0000000ZKgX0:Vmj08000000`2Y_NP2000004h0oooo001a0?ooo`030000003oool0oooo01T0
oooo0P000000103oool000000000000000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`00
0000ZKgX0:Vmj003000000060:Vmj0000000ZKgX0000002Y_NP000000`2Y_NP200000080ZKgX00<0
00000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj02Y_NP0
0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000CP3oool00740
oooo00<000000?ooo`3oool05P3oool600000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj003
0000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0P0000030:Vmj0050000002Y_NP00000
0:Vmj00000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vm
j003000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj080
0000C@3oool00740oooo00<000000?ooo`3oool0503oool500000080ZKgX00<000000:Vmj02Y_NP0
0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`00
0000ZKgX0:Vmj00200000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<00000
0:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP500000080ZKgX0`0000020:Vmj0030000002Y
_NP0ZKgX00<00000C03oool00700oooo0P00000C0?ooo`D000000P2Y_NP00`000000ZKgX0:Vmj003
000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000
002Y_NP0ZKgX00<0000000H0ZKgX0000002Y_NP000000:Vmj00000020:Vmj0<000000P2Y_NP00`00
0000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX0000002Y_NP010000002
0:Vmj0030000002Y_NP0ZKgX00<0000000<0ZKgX000000000000C03oool00740oooo00<000000?oo
o`3oool03`3oool200000080oooo00<000000;;4i`0000000P2Y_NP3000000040:Vmj0000000ZKgX
0:Vmj0<000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj02Y_NP00`000000
102Y_NP000000:Vmj02Y_NP2000000<0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0
ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj02Y
_NP00`000000102Y_NP000000:Vmj02Y_NP3000004/0oooo00200?ooo`<000000P3oool200000080
//CW0`0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0:Vmj00200000080
ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX00@000000:Vm
j000000000000`2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX
0`0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP0
00000000001;0?ooo`00O@3oool3000000030?ooo`00000000000080000000@0]/[Y0000002ba>L0
00000P2^`^T00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP0
00000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj002
00000080ZKgX00D000000:Vmj0000000ZKgX000000020:Vmj0<000000P2Y_NP00`000000ZKgX0000
000200000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vm
j0000000ZKgX0:Vmj0<000003`3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002d0
oooo001k0?ooo`800000103oool00`000000]/GV000000020;K:j@<000000P2^`^T3000000040:Vm
j0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP00000
008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP3
00000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX00D000000P2Y_NP3
000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP2000000d0oooo00@000000?ooo`3oool00000
1`3oool01@000000oooo0?ooo`3oool0000002`0oooo001h0?ooo`<00000103oool3000000040;K5
iP000000000000000080/<S/0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX
0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00`000000
102Y_NP000000:Vmj02Y_NP3000000060:Vmj0000000ZKgX0000002Y_NP000000`2Y_NP300000004
0:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX0000002Y_NP010000000102Y_NP000000:Vmj02Y_NP3
00000080ZKgX00<000000:Vmj02Y_NP00P0000060?ooo`D000000P3oool010000000oooo0?ooo`00
000;0?ooo`030000003oool0oooo02X0oooo001f0?ooo`800000103oool300000080/k_O0P000002
0;[6i0050000002`b>`000000:Vnj00000000P2Y_NP300000080ZKgX00<000000:Vmj00000000P00
00020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP00000
0:Vmj02Y_NP300000080ZKgX00@000000:Vmj000000000000`2Y_NP01@000000ZKgX0000002Y_NP0
00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj00000000P00
00020:Vmj0030000002Y_NP0ZKgX00<0000000<0ZKgX000000000000303oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo02X0oooo001c0?ooo`<0000000<0oooo0000000000000`00
000209fTf`050000002c^ml000000;bnf`0000000P2ja^@2000000<0ZKkX0P0000020:Vmj0030000
002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`00
0000ZKgX0:Vmj00200000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<00000
0:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`00
000;0?ooo`040000003oool0oooo000000L0oooo1000000]0?ooo`00L@3oool2000000080?ooo`00
000000000000002JU<d0000008n@d000000309fTf`8000000P2l_]/300000080`<kU00<000000:Vn
j00000000P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y
_NP300000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0
ZKgX0000002Y_NP0ZKgX0`0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0`0000020:Vm
j0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y
_NP3000000030:Vmj0000000000000/0oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`0^0?ooo`00KP3oool6000000050:BOd0000000VYC=09ZDc@0000000P2?T=001`000000WJCK
0000002][=H000000;bnf`0000000P3=gnH00`000000`<kU0<3>i@0200000080ZKgX0`000000102Y
_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0
ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000@0
ZKgX0000002Y_NP000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj02Y_NP0
0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000
002Y_NP0ZKgX0`00000;0?ooo`800000203oool5000002`0oooo001[0?ooo`H0000000<0YZKF0000
002TWm000P2TWm001@000000VYC=09ZDc@000000Si3@008000000`2][=H010000000cMoV0<gOiP3=
gnH3000000040;O<jP000000ZKgX00000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000
002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP2000000<0ZKgX0P000002
0:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vm
j02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP2000004D0oooo001Y0?ooo`800000
00D0oooo000000000000YjoM000000030:JVeP030000002TWm00000000D000000P2RV/`02@000000
[JcF00000037g^X000000<gOiP000000_]o`000000020;O<jP8000000`2Y_NP200000080ZKgX00<0
00000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP00000008000000P2Y_NP01@00
0000ZKgX0000002Y_NP000000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP500000080ZKgX0`00
0000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj02Y_NP00P0000150?ooo`00IP3o
ool6000000050:Rch0000000YjoM0:N_g@0000000P2VY]H20000000509ZJd`000000WIK<09fFc000
00000`2RV/`200000080amkZ0`000000102ngo0000000000000000020:Znj0050000002Y_NP00000
0:Vmj00000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX
0`0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX
00<000000:Vmj02Y_NP00P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP0
00000:Vmj00400000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX00<0
000000<0ZKgX000000000000A03oool004<0oooo0P00000O0?ooo`D0000000<0Z;?P0000002X/n00
0P2X/n000`000000YjoM000000020000000509^Rf@000000VY[C09ZJd`0000000P2MU/`00`000000
XY[<000000020<7AiP8000000P37gnX200000080ZkoY00<000000:Znj02Z_^P00P0000020:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`00
0000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3
000000060:Vmj0000000ZKgX0000002Y_NP000000P2Y_NP300000080ZKgX00<000000:Vmj0000000
0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vm
j0000000ZKgX0:Vmj0<00000@`3oool00480oooo00@000000?ooo`3oool000006`3oool500000003
0:N_g@000000Z;?P0080Z;?P00<000000:Rch00000000P0000000`2LZ^40000009^Rf@0209^Rf@03
0000002JV]<000000080WIK<0P0000020<7AiP070000003:e>4000000<OOjP000000aLoR00000002
0:^oj@<000000P2Y_NP200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0
ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj000000000000000
0080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000
002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000000004<0oooo0012
0?ooo`040000003oool0oooo000001T0oooo100000000`2VY]H000000:N_g@020:N_g@030000002X
/n00Z;?P008000000P2R/N801@000000W:[Q09bZh@000000Vj;I00H0000000@0YKWW00000031dNH0
00000P3:e>4200000080aLoR0`0000020:Vmj0050000002Y_NP000000:Vmj00000000P2Y_NP20000
0080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000
ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP300000080
ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y
_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX
0`0000120?ooo`00@P3oool010000000oooo0?ooo`00000F0?ooo`<0000000@0oooo0000002TWm00
00000P2VY]H00`000000YjoM0:N_g@03000000040:Rch0000000X[7R0::ahPD0000000<0Sh_;0000
002>W]h00P2>W]h00`000000YKWW00000002000000040<[Dh@000000e=kO0=CNg`8000000P2mcNH0
0`000000ZKgX0:Vmj00200000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP30000
0080ZKgX00<000000:Vmj00000000P0000020:Vmj0050000002Y_NP000000:Vmj00000000P2Y_NP3
000000040:Vmj0000000ZKgX0:Vmj0D000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000
00@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000?ooo`0000110?ooo`00@P3oool010000000
oooo0?ooo`00000C0?ooo`@0000000<0oooo0000000000000`2TWm000`000000YZKF000000020000
0080[;7K00<000000:Rch00000000P0000001@2CNK<0000008ej^P2=N[X000000080Sh_;00<00000
08jNgP2>W]h00P0000020;K0hP<0000000@0e=kO00000039gnP000000P2mcNH3000000060:Vmj000
000000000000002Y_NP000000P2Y_NP300000080ZKgX00<000000:Vmj00000000P0000020:Vmj003
0000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj02Y
_NP00P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vm
j0<0000000<0ZKgX0000002Y_NP010000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000
ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0000000200000440oooo00120?ooo`040000003oool0
oooo00000140oooo0P0000020?ooo`<0000000<0XYS;0000002TWm000P2TWm0200000080[j[C00<0
00000:baf`2//M/00P0000001@2IOK<0000009=i/`2CNK<0000000<0SGZj00<0000008n;b`000000
0P000000102UZMT000000;K0hP0000020<WHi08000000P39gnP3000000040;;4i`000000ZKgX0000
0080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`00
0000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX
00<0000000@0ZKgX0000002Y_NP0ZKgX0`0000001P2Y_NP00000000000000000ZKgX00000080ZKgX
0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`00
0000ZKgX0000000200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0800000@03oool004<0
oooo0P00000?0?ooo`<000000P3oool2000000030:VMbP000000XYS;0080XYS;00@000000:BOd000
000000000`2_Z]<3000000050:66]`000000VGfc09Um/`0000000P2CNK<00`000000SGZj00000002
000000030:RHa@000000YJWI0080YJWI0P0000001039f>@000000<kJh@3>f^4200000080^<cY00<0
00000;;4i`0000000P0000020:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP30000
00040:Vmj0000000ZKgX0:Vmj0<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<00000
0P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000
002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj080
0000@03oool00580oooo0P0000040?ooo`030000002h[m4000000080ZIg:00<000000::Hb`2RV</0
0P0000020:bSc@050000002_Z]<000000:nL``0000000P2QQ[L010000000VGfc09Um/`00000209=i
/`80000000<0YXRf0000002XV<D00P2XV<D00`000000YJWI000000020;c1g@040000003>f^40c][Q
0<kJh@8000000P2hc>T200000080[/;Y0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP30000
00040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP200000080ZKgX00<000000:Vmj00000000P000002
0:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<00000
0:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000
00<0ZKgX000000000000?`3oool004l0oooo0`000000103oool000000?ooo`3oool2000000<0^:oA
00<000000:VMbP0000000P000000102ZW<P000000:bSc@2/Xld200000080[ic300P000000:66]`2Q
Q[L0XHJg0000002IOK<0000009=i/`8000000`2VR;H00`000000Z9S50:RHa@0200000080_<7M00D0
00000<_5e0000000c][Q000000020;ZQ_`8000000P2ab>/200000080Z:kL00<000000:Vmj0000000
0P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX
00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP01@000000ZKgX
0000002Y_NP000000080ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y
_NP0ZKgX1@0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y
_NP3000000050:Vmj000000000000000002Y_NP00P00000n0?ooo`00C@3oool2000000@0oooo0`00
00020;:jg`030000002h[m4000000080000000<0Yic;0000002ZW<P00P2ZW<P2000000030;N_d@00
0000[ic30080[ic300D000000:66]`2QQ[L0000009Um/`020000000309io/@000000YXRf0080YXRf
00L000000:RHa@000000/Y:e0000002l`Md0000000<0blGD00@000000;ZQ_`2jXKl0^Z6o0P000000
0`2ab>/00000000000030:R^g08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<00000
0:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj002
00000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`00
0000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000ZKgX00@0000000@0ZKgX0000002Y_NP0
ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000060:Vmj000000000000000002Y_NP000000P2Y
_NP2000003h0oooo001:0?ooo`<0000000<0oooo0000000000000`00000209Zll0030000002b^]l0
/[[O0080000000<0YZSH0000002WW</00P2WW</010000000ZYc80000000000030;N_d@050000002_
W<<0[ic30000002QQ[L00`0000001@2IO;80000009io/@2NOk40000000<0YXRf00D000000;:B]@2b
T[D0/Y:e000000030<_5e08000000P2jXKl010000000cZNa0<jW/@0000020:BKc0050000002X[]`0
00000;Jae@0000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0
ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000H0ZKgX
00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP0
00000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`00
00001P2Y_NP00000000000000000ZKgX00000080ZKgX0`0000000`2Y_NP000000000000m0?ooo`00
A`3oool4000000030?ooo`00000000000080V[c`00<0000009W2l`0000001@0000001@2O/nL00000
0:JXf02VZ=P000000080Yic;0P0000020;g0g0050000002g[m40]joA0000002_W<<00`0000001@2E
O[P0000009Ul/P2IO;8000000080WWna00<000000:J8]P2VR;H00P0000030;:B]@80000000@0blGD
0000002[P:D0Zh2U0P0000030<jW/@030000002TVl`0Y9_<008000000P2f/MD3000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP30000
00040:Vmj0000000ZKgX0:Vmj0<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<00000
00@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj00000000000
0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj00000020:Vmj0030000
002Y_NP00000008000000P2Y_NP00`000000ZKgX00000002000003`0oooo00150?ooo`8000000P3o
ool3000000040:2jj`000000V[c`09Zll0<0000000D0T;kf00000027]O<0QkGc0000000209nci`07
0000002VZ=P000000:NLb`000000[/g`000000020;g0g0D0000000D0T8_:0000002EO[P0UGjh0000
000209Ul/P080000002NOk40WWna0000002VR;H000000:AfWP0000020;:B]@040000003<WjX0c9nZ
000000<0Zh2U00H000000<jW/@3>Yk40cZNa0000003@WZ<2000000040;BO``000000][7E00000080
[8Za00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000
ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX00000000000000000P2Y_NP0
0`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0
0000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P000002
0:Vmj0030000002Y_NP00000008000000P2Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P000002
0:Vmj0030000003oool0oooo03X0oooo00120?ooo`<0000000@0oooo00000000000000000P2Y_NP0
0`000000X;[[0000000200000080X[o]3@0000001P2^cO000000000000000000Z[cW00000080VjGL
00H00000092;bP2@RlX0000009En^000000309Ul/P040000002NOk400000000000<0Y7JN0P000003
0<bOZP050000002[P:D0Zh2U0:^0Y@0000000`3>Yk400`000000d9jS000000030;BO``030000002/
R[40[8Za0080[8Za00@000000:Vmj02Y_NP000000P2Y_NP200000080ZKgX00<000000:Vmj02Y_NP0
0P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP200000080ZKgX00<000000:Vmj02Y_NP0
0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX
00<000000:Vmj02Y_NP00P0000000`2Y_NP00000000000020:Vmj08000000P2Y_NP00`000000ZKgX
0:Vmj00200000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vm
j0800000>`3oool00400oooo0P0000020?ooo`8000000P2Y_NP00`000000ZKgX0:Vmj00200000080
YKcZ0`0000001@2Y_NP0000008Zbl02:/_0000000080JZoi1`00000209?7n@040000002Z_>L0Z[cW
00000080VjGL00<00000092;bP0000000P2EO[P00`000000VGbb09Ul/P020000000309MXV@000000
Y7JN0080Y7JN0P0000020<bOZP8000000P2[P:D01@000000`XfM0000003>Yk4000000080d9jS00D0
00000;BO``2dWl<0]9o3000000040:b:/@030000002Y_NP0ZKgX00<0000000@0XYK80000002Y_NP0
ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3
000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP00000
0:Vmj02Y_NP3000000030:Vmj0000000ZKgX00@0000000@0ZKgX0000002Y_NP0ZKgX0`0000001P2Y
_NP00000000000000000ZKgX00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000030:Vm
j0000000000003X0oooo000m0?ooo`<0000000@0oooo00000000000000000P2Y_NP00`000000ZKgX
00000002000000040:Vmj0000000000000000080ZKgX00<000000:Vmj00000001@0000000`2>_oL0
00000000000?00000080UGjh00@0000009Ul/P00000000000P2GJ9T01@000000Y7JN0:AfWP2TMYh0
000000<0c9nZ0P0000020:^0Y@0=00000032SId000000<jW/@000000d9jS0000003GXId000000;BO
``000000X6nK000000020:b:/@0600000037UjD000000000002INJl000000P2RU/P3000000040:Vm
j0000000ZKgX0:Vmj0<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX
0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000060:Vmj0000000
00000000002Y_NP000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y
_NP0ZKgX0P00000j0?ooo`00>`3oool200000080oooo0P0000020:Vmj0030000002Y_NP0ZKgX0080
00000P2Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002K^>d0VkS]0080
00000P2X_NT01@000000OZoc07j_l`000000Biof00@0000000@0PLCm0000001KV>l000000P1WI;`4
0000000508iQV@000000UfRI09MXV@0000000`2TMYh01P000000c9nZ0<bOZP3<WjX000000<RAV`80
00000`32SId010000000d9jS0=2NX`0000020=NQW@040000002PKi/0X6nK00000080[8Za00<00000
0<NGY@0000000`2INJl200000080_9jj00<000000:Vmj00000000P000000102Y_NP0000000000000
00020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX00000002000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP30000
00040:Vmj000000000000:Vmj0<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<00000
00@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj00000000000
03T0oooo000H0?ooo`<000007@3oool3000000060?ooo`00000000000000002Y_NP000000P2Y_NP3
000000040:Vmj0000000000000000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y
_NP000000080000000@0Z;gX0000002X_NT0Z;gY1@00000207Fcn@D0000000H0FiS_0000001WI;`0
000008EOW`00000208iQV@040000002GJ9T0UfRI00000080Y7JN00D000000;n8VP000000c9nZ0000
00020<RAV`8000000`32SId010000000d9jS0=2NX`0000020=NQW@060000002PKi/0X6nK0000002/
R[4000000P37UjD200000080VGV_00<000000;bN^P2lW[X00P2lW[X00`000000ZKgX0:Vmj0020000
0080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`00
0000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3
000000040:Vmj0000000ZKgX0:Vmj0<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000
ZKgX0:Vmj0<00000>03oool001T0oooo00<000000?ooo`3oool06P3oool2000000040?ooo`000000
000000000080ZKgX00<000000:Vmj00000000P0000020:Vmj08000000P2Y_NP00`000000ZKgX0:Vm
j00200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002X_NP00000008000000P2Y
_NP00`000000T;C_0000000200000080V;_`1@000000101WI;`0000008EOW`00000208iQV@0;0000
002GJ9T0UfRI09MXV@000000Y7JN0000002oR9X000000<bOZP0000000P38TI/2000000<0`XfM00<0
00000=2NX`0000000`3GXId010000000X6nK0:1_V`2PKi/2000000040<NGY@000000ciJI00000080
VGV_00<000000;bN^P2lW[X00P2lW[X3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000
002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P00
00020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0000000200000080ZKgX0P00
00020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX00000002000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000000000h0?ooo`00
4@3oool5000000<0oooo00<000000?ooo`3oool05`3oool3000000060?ooo`00000000000000002Y
_NP000000P2Y_NP3000000040:Vmj0000000000000000080ZKgX00<000000:Vmj00000000P000000
102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX
0:Vmj00200000080Wk[[00<0000009Rkl02H^o000P00000205Y/b`050000001WI;`0000008EOW`00
00000P2>HIT010000000UfRI09MXV@2GJ9T200000080_hRJ00<000000<bOZP0000000P38TI/01000
0000`XfM0<:=W@32SId2000000040=2NX`000000ej6M0=NQW@8000000`2PKi/02P000000aiNU0<NG
Y@000000ciJI0000002INJl000000;:5Y@0000020;bN^P030000002mSjD000000080ZKgX0`000000
102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0
ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vm
j0D000000P2Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP00000
008000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<00000=`3oool0
01T0oooo00<000000?ooo`3oool0503oool300000080oooo0P0000020:Vmj0030000002Y_NP00000
008000000P2Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP00000
008000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX
0000002O^^/0Wk[[0`000000102R_^d000000000001JK</300000080QEnO00<0000008iQV@000000
0`2GJ9T2000000<0_hRJ00D000000<RAV`38TI/0b96K000000030<:=W@040000003?U9L000000000
0080ej6M0P0000030:1_V`0400000037UjD0aiNU00000080ciJI0P000000102bQJD000000;bN^P00
00020;f?Y@<000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<00000
00@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj00000000000
00@0000000L0ZKgX00000000000000000:Vmj0000000ZKgX00@0000000@0ZKgX0000002Y_NP0ZKgX
0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj003
0000002Y_NP000000080000000@0ZKgX0000000000000000203oool2000002`0oooo000I0?ooo`03
0000003oool0oooo0180oooo1`000000102Y_NP000000:Vmj02Y_NP3000000060:Vmj00000000000
0000002Y_NP000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX
0:Vmj00200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0000000800000
0P2U_>X800000080QEnO00<0000008iQV@0000000`2GJ9T2000000<0_hRJ00<000000<RAV`38TI/0
0P0000030<:=W@030000003?U9L0000000<0ej6M0P0000020:1_V`80000000<0aiNU0000003?UYT0
0P3?UYT01@000000/XFU0;:5Y@2bQJD000000080_HnU00@000000=2HVP00000000000P2Y_NP20000
0080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000
002Y_NP0ZKgX0`0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0`000000102Y_NP00000
0:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000
102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP200000080ZKgX
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00000[0?ooo`00603oool200000140oooo
0`000000103oool000000000000000020:Vmj0030000002Y_NP00000008000000P2Y_NP200000080
ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000
ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj0020000
0080ZKgX0`0000000`2Y_NP000000:N^g0060000000508EOW`000000SV6I08iQV@0000000P2GJ9T0
0`000000_hRJ0;n8VP020;n8VP0800000038TI/0b96K00000039TIX000000<:=W@0000020<nDU`04
0000003GXId0ej6M00000080cY>F00H000000:1_V`00000000000<NGY@0000030<nFV@050000002b
QJD0/XFU0;:5Y@0000000P2mSjD010000000d9RJ0000003UZ982000000040:Vmj0000000ZKgX0:Vm
j08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj00000000P0000020:Vm
j08000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX
000000000000ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0`0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0P00
00060?ooo`040000003oool0oooo000002/0oooo000I0?ooo`030000003oool0oooo00d0oooo0P00
00020?ooo`<0000000@0ZKgX0000002Y_NP0ZKgX0`0000001P2Y_NP00000000000000000ZKgX0000
0080ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj0020000
0080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000
0000000000000P2Y_NP01@000000ZKgX0:Vmj0000000YjkL00D0000000D0QEnO0000002>HIT0SV6I
0000000209MXV@040000002oR9X0_hRJ0;n8VP8000000P38TI/01@000000bI6J00000032SId00000
0080ciBG00@000000=NQW@3GXId000000P3>TiH010000000X6nK0000002jPIH2000000<0ciJI00<0
00000;:5Y@2bQJD00P0000020;f?Y@050000003@V9X000000>FXTP0000000P2Y_NP3000000040:Vm
j0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0<0000000@0ZKgX0000
002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX00000002
000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP00000
0:Vmj02Y_NP3000000060:Vmj000000000000000002Y_NP000000P2Y_NP3000000030:Vmj0000000
oooo00D0oooo00@000000?ooo`3oool00000:`3oool002H0oooo0`000000103oool0000000000000
00020:Vmj0D000000P2Y_NP200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y
_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080
ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj00:00000006
08EOW`000000SV6I08iQV@000000UfRI0P0000030;n8VP80000000L0b96K00000039TIX0bI6J0000
0032SId000000080ciBG0P000000103GXId000000<jCUP3>TiH200000080^X6F00@000000<nFV@3?
UYT0ciJI0P0000020;:5Y@80000000H0_HnU0000003@V9X0d9RJ0000003UZ983000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000001P2Y_NP00000000000000000ZKgX
00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P00
0000102Y_NP000000000002Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX00000000
0000100000001P2Y_NP00000000000000000ZKgX00000080ZKgX0`000000102Y_NP000000:Vmj02Y
_NP2000000D0oooo00@000000?ooo`3oool00000:`3oool002@0oooo0P0000020?ooo`<0000000@0
ZKgX00000000000000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj080
00000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj00000000P0000020:Vmj003
0000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`0000001P2Y_NP00000000000000000
ZKgX00000080ZKgX0`0000001P2Y_NP00000096dk`2A]>l0000008BLhP@0000000@0QEnO0000002>
HIT0SV6I0P0000020:IbV0050000002oR9X0_hRJ0000003NY9L00P0000020<VAVP0900000032SId0
00000<nDU`000000eiVC0000003GXId000000080cY>F0P0000020;Z1UP060000003?UYT0ciJI0<nF
V@000000dYNG0P0000020:mhUP80000000@0d9RJ0000003UZ980iJRB0`000000102Y_NP000000000
000000020:Vmj0030000002Y_NP000000080000000H0ZKgX00000000000000000:Vmj00000020:Vm
j0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj000
0000ZKgX00<000000P2Y_NP00`000000ZKgX0000000200000080ZKgX0P0000020:Vmj0030000002Y
_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP300000003
0:Vmj0000000000000@0oooo00@000000?ooo`3oool00000:`3oool00240oooo0`0000020?ooo`80
00000P2Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP000000080
00000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`00
0000ZKgX0:Vmj00200000080ZKgX1@0000020:Vmj08000000P2Y_NP00`000000ZKgX000000020000
0080ZKgX00<000000:Vmj00000002@0000000`25Gil0000008iQV@0200000080YW:H00D000000;n8
VP2oR9X000000=jTU`02000000<0bI6J00D000000<nDU`3?U9L000000=NIT`02000000<0cY>F0P00
00020;Z1UP060000003?UYT0ciJI0<nFV@000000dYNG0P0000020:mhUP80000000P0d9RJ0000003U
Z98000000>b]S0000000nKb100000080ZKgX1@0000020:Vmj08000000P2Y_NP00`000000ZKgX0000
000200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vm
j0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0<0000000@0ZKgX0000
002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`00
0000102Y_NP000000:Vmj02Y_NP2000000D0oooo0P00000/0?ooo`007P3oool300000080oooo0`00
0000102Y_NP000000000000000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0
ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0000000200000080
ZKgX00<000000:Vmj00000000P000000102Y_NP000000000000000020:Vmj0030000002Y_NP00000
0080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP0
10000000JJ;b0000001_I;D30000000306A7VP0000000000008000000`2VLYP00`000000_hRJ0000
00020=jTU`0300000039TIX0bI6J0080bI6J00@000000<nDU`3?U9L000000P3GVI<01@000000cY>F
0<jCUP3>TiH0000000<0^X6F00@000000<nFV@3?UYT000000P3BUiL200000080[gRF00T000000=2H
VP3@V9X000000>FXTP000000k:f<0000003i_8400`000000102Y_NP000000:Vmj02Y_NP300000004
0:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vm
j00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj000000000000:Vmj0<0000000H0
ZKgX00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vm
j0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000000000b
0?ooo`00703oool700000080ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`00
0000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3
000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P00
00020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX00000002000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0KfBe00000000000000000P1TAiX00`000000SV6H000000030:IbV003
0000002oR9X000000080gZBG00<000000<VAVP39TIX00P39TIX010000000ciBG0<nDU`0000020=NI
T`050000003>TiH0cY>F0<jCUP0000000P2jPIH01@000000f9ZB0000003?UYT000000080dYNG00D0
00000:mhUP2_N9H0[gRF000000020=2HVP060000003UZ98000000>b]S0000000nKb10`0000001P2Y
_NP00000000000000000ZKgX00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vm
j0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX00000002000000030:Vmj0000000000000@0
000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`00
0000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P000000102Y_NP00000
0:Vmj02Y_NP300000340oooo000I0?ooo`D000000P2Y_NP00`000000ZKgX0000000200000080ZKgX
00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y
_NP00P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP5000000040:Vmj000000000000000
0080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<00000
0:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP000000080000000<0ZKgX0000001YX_8010000002
06A7VP030000002>HIP0000000<0YW:H00<000000;n8VP0000000P3NY9L010000000bI6J0<VAVP39
TIX200000080ciBG00@000000=NIT`3GVI<000000`3>TiH020000000^X6F0;Z1UP000000f9ZB0000
003?UYT000000P3BUiL01@000000[gRF0:mhUP2_N9H000000080d9RJ00H000000>FXTP000000k:f<
0000003i_842000000060?o;L`000000ZKgX0:Vmj0000000ZKgX0`000000102Y_NP000000:Vmj02Y
_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP0
00000000000000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`000000
102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0
ZKgX0P0000020:Vmj0D0000000<0ZKgX000000000000<@3oool001P0oooo100000020:Vmj0040000
002Y_NP0000000000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP000000080
00000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000H0ZKgX0000
0000000000000:Vmj00000020:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<0
00000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj080
00000P2Y_NP00`000000ZKgX0000000500000080I4NJ00<0000008iQV0000000102VLYP200000080
gZBG00@000000<VAVP39TIX0bI6J0P000000103?U9L000000=NIT`3GVI<200000080cY>F0P000002
0;Z1UP050000003HVY8000000<nFV@0000000P3BUiL01@000000[gRF0:mhUP2_N9H000000080d9RJ
00X000000>FXTP00000000000?VlP@000000oL9l0000003obg<000000P2Y_NP200000080ZKgX00<0
00000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0L0
000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000
002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000
00L0ZKgX00000000000000000:Vmj0000000ZKgX00<0000000<0ZKgX000000000000<03oool001P0
oooo00@000000:Vmj02Y_NP000000P2Y_NP200000080ZKgX00<000000:Vmj00000000P0000020:Vm
j0040000002Y_NP0000000000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0
0000008000000P2Y_NP200000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0
00000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP00000008000000P2Y
_NP00`000000ZKgX00000002000000030:Vmj0000000000000<0000000<0XYK80000000000001000
00001@1TAiX0000008iQV02>HIP0000000<0YW:H00H000000=jTU`3NY9L000000=bTVP0000020<VA
VP80000000@0ciBG0000003GVI<0eiVC0P0000020<jCUP8000000P2jPIH010000000f9ZB0=RJTP00
00020=:GU`8000000P2_N9H01P000000`XBA0000003@V9X000000>FXTP80000000D0nKb10000003m
`W`000000?o;L`03000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX00000002
000000030:Vmj0000000000000P0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vm
j02Y_NP200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP300000004
0:Vmj0000000ZKgX0:Vmj0<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj08000000P2Y
_NP00`000000ZKgX00000002000002l0oooo000A0?ooo`8000001@3oool2000000060:Vmj0000000
00000000002Y_NP000000P2Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000
002Y_NP000000080000000<0ZKgX000000000000100000001P2Y_NP00000000000000000ZKgX0000
0080ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX000000020000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj08000000P2Y
_NP00`000000ZKgX000000020::Fb0D0000000D0I4NJ0000002>HIP0SV6H000000030:IbV0080000
003NY9L0gZBG0000003LY9X000000<VAVP0000020=>LW08000000P3GVI<200000080cY>F0P000002
0;Z1UP040000003HVY80f9ZB00000080dYNG0P0000020:mhUP0;00000032Q94000000000003UZ980
00000>b]S0000000nKb10000003m`W`00P000000103idVP000000:Vmj02Y_NP3000000040:Vmj000
0000ZKgX0:Vmj08000000P2Y_NP200000080ZKgX1@0000020:Vmj0030000002Y_NP0000000800000
00@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vm
j00000000P0000000`2Y_NP0000000000004000000060:Vmj000000000000000002Y_NP000000P2Y
_NP3000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000oooo0?ooo`0]0?ooo`00403o
ool010000000oooo0?ooo`0000040?ooo`030000003oool000000080ZKgX00<000000:Vmj0000000
0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP0
0000000000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0000000200000080
ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vm
j00000000P0000020:Vmj0D0000000H0ZKgX00000000000000000:Vmj00000020:Vmj0@0000000<0
XYK80000001_I;D00`0000001@1TAiX0000008iQV02>HIP0000000<0YW:H00P000000=jTU`3NY9L0
00000=bTVP000000bI6J00000080dibL0P0000020=NIT`080000003e^h`0000000000035S9P00000
0;Z1UP0000030=RJTP030000003BUiL0dYNG008000000P2_N9H02@000000`XBA000000000000iJRB
0000003/[H`000000?VlP@02000000040?o;L`00000000000?OON`80000000<0ZKgX000000000000
100000001@2Y_NP00000000000000000ZKgX00H0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vm
j0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y
_NP200000080ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX
0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0800000;P3oool00100
oooo00@000000?ooo`3oool000000`3oool01P000000oooo0?ooo`3oool000000:Vmj08000000P2Y
_NP00`000000ZKgX0:Vmj003000000030:Vmj0000000000000<000000P2Y_NP200000080ZKgX00<0
00000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj02Y_NP0
0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`0000001P2Y_NP0
0000000000000000ZKgX00000080ZKgX0P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP8
0000000506A7VP000000SV6H08iQV00000000P2VLYP2000000070=jTU`000000g:BJ0=bTVP000000
bI6J000000020=>LW08000000P3GVI<010000000mK^<0000000000020<F<V08000000`3HVY800`00
0000dYNG0=:GU`0200000080[gRF00T000000<:4T@32Q94000000>FXTP000000k:f<0000003i_840
0P0000001`3obg<000000000003ggg/000000>K`TP0000000P2Y_NP00`000000ZKgX000000020000
00030:Vmj0000000ZKgX00@0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y
_NP200000080ZKgX00<000000:Vmj00000000P0000000`2Y_NP0000000000004000000060:Vmj000
000000000000002Y_NP000000P2Y_NP200000080ZKgX00<000000:Vmj00000000P000000102Y_NP0
00000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX000000000000;@3oool0
0100oooo00@000000?ooo`3oool000000`3oool2000000<0oooo00D000000:Vmj02Y_NP000000:Vm
j00300000080ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX
0P0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX00000002000000040:Vm
j0000000ZKgX0:Vmj08000000P2Y_NP500000080ZKgX0P0000020:Vmj0030000002Y_NP000000080
000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP0ZKgX008000000P12F<840000
0080I4NJ00<0000008iQV00000000P2VLYP2000000030=jTU`000000g:BJ0080g:BJ00D000000=>L
W03CW9`0dibL000000020=NIT`030000003e^h`0mK^<008000000P35S9P2000000<0f9ZB00D00000
0=:GU`000000bHfC000000020:mhUP0900000032Q940`XBA0000003UZ98000000>b]S0000000nKb1
0080000000D0ol]c00000000000000000>K`TP0200000080ZKgX0P0000020:Vmj0D0000000@0ZKgX
0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj080
00000P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000
102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vm
j02Y_NP3000000030:Vmj0000000000000<00000;@3oool00100oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`030?ooo`D0000000H0ZKgX00000000000000000:Vmj00000020:Vm
j08000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00@000000:Vmj000000000000P2Y_NP0
0`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj00000000P000000102Y_NP0000000000000
00020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000
002Y_NP00000008000000P2Y_NP00`000000ZKgX00000002000000040:Vmj00000000000049H`P@0
00000P1TAiX01@000000SV6H0000002VLYP000000080dZ6U0P0000030=bTVP050000003CW9`0dibL
0=>LW00000000P3GVI<010000000mK^<0?FkS00000030<F<V08000000P3HVY82000000040=:GU`00
0000bHfC0<V=T`8000000`32Q9401P000000iJRB0000003/[H`000000?VlP@80000000<0ol]c0000
003ggg/00P0000001@3BlNL00000000000000000ZKgX00D000000P2Y_NP00`000000ZKgX00000002
000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX000000000000100000001`2Y_NP000000000
00000000ZKgX0000002Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX
0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP3000000060:Vm
j000000000000000002Y_NP000000P2Y_NP3000002/0oooo000@0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0103oool00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vm
j00000000P0000020:Vmj0040000002Y_NP0000000000080ZKgX00<000000:Vmj02Y_NP00P000002
0:Vmj0030000002Y_NP000000080000000<0ZKgX000000000000100000000`2Y_NP0000000000002
0:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000
ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00D000000:Vmj00000000000
049H`P050000000406A7VP000000SV6H08iQV08000000P3BXJD00`000000g:BJ0=bTVP020=bTVP05
0000003CW9`0dibL0=>LW00000000P3GVI<010000000mK^<0?FkS00000030<F<V08000000P3HVY80
10000000gIjA0000000000020<V=T`8000000`32Q94010000000iJRB0000003/[H`2000000050?g2
O000000000000000003ggg/00`0000000`2Y_NP0000000000004000000040:Vmj0000000ZKgX0:Vm
j08000000P2Y_NP00`000000ZKgX00000002000000060:Vmj000000000000000002Y_NP000000P2Y
_NP3000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX00000002000000040:Vm
j0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP00000000000030000
00060:Vmj000000000000000002Y_NP000000P2Y_NP3000000030:Vmj0000000oooo02/0oooo000A
0?ooo`800000103oool00`000000oooo0?ooo`050?ooo`80000000@0ZKgX0000002Y_NP0ZKgX0P00
00020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX00000002000000040:Vmj000
0000ZKgX0:Vmj08000000P2Y_NP200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000
002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080
000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP0000000000003000000030:Vmj00000000000
00L000000P2>HIP200000080dZ6U00@000000=bTVP3LY9X0g:BJ0P0000020=>LW08000000P3GVI<0
10000000mK^<0?FkS00000030<F<V0060000003HVY80f9ZB0=RJTP000000gIjA0P0000020<V=T`80
00000`32Q94010000000iJRB0000003/[H`2000000030?g2O00000000000008000000P2Y_NP50000
00040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX0000000000000`0000020:Vmj08000000P2Y_NP0
0`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX
0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`0000001P2Y_NP0
0000000000000000ZKgX00000080ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX
0000002Y_NP0ZKgX0P00000[0?ooo`005`3oool2000000L0oooo00<000000:Vmj00000000P000002
0:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0D0000000@0
ZKgX00000000000000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj080
00000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX0000
000000000`0000020:Vmj08000000P2Y_NP00`000000ZKgX0000000300000003049H`P0000000000
00@0000000<0SV6H0000000000000`3BXJD010000000g:BJ0=bTVP3LY9X200000080dibL0P000000
0`3GVI<000000?FkS0020?FkS00500000035S9P0aHbH0<F<V00000000`3HVY8010000000gIjA0000
000000020<V=T`8000000`32Q94200000080k:f<0P0000000`3m`W`000000000000600000080ZKgX
1@0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP2
00000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj000
0000ZKgX0:Vmj08000000P2Y_NP5000000060:Vmj000000000000000002Y_NP000000P2Y_NP30000
00040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000000
000Z0?ooo`005P3oool2000000T0oooo00@000000:Vmj02Y_NP000000P2Y_NP200000080ZKgX1@00
0000102Y_NP000000000000000020:Vmj0040000002Y_NP0000000000080ZKgX00<000000:Vmj02Y
_NP00P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vm
j0030000002Y_NP00000008000000P2Y_NP200000080ZKgX00<000000:Vmj00000000P000000102Y
_NP000000:Vmj02Y_NP200000080ZKgX2P0000001`2JP[L000000=:QY@3BXJD000000=:UZP000000
0P3LY9X020000000nm^R000000000000c9VQ0000003GVI<000000P3e^h`2000000<0aHbH00L00000
0=RJTP3HVY80f9ZB0000003MWY40000000<0bHfC0P0000020<:4T@030000003LVX`000000080k:f<
0P0000001@3m`W`00000000000000000jme^0080000000H0ZKgX00000000000000000:Vmj0000002
0:Vmj08000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000<0ZKgX000000000000
100000001P2Y_NP00000000000000000ZKgX00000080ZKgX0P000000102Y_NP000000:Vmj02Y_NP3
000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX0000002Y_NP00`000000102Y_NP000000:Vm
j02Y_NP2000002X0oooo000F0?ooo`030000003oool0oooo00T0oooo00<000000:Vmj00000000P00
0000102Y_NP000000000000000020:Vmj0040000002Y_NP0000000000080ZKgX00<000000:Vmj02Y
_NP00P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vm
j0030000002Y_NP000000080000000<0ZKgX000000000000100000001P2Y_NP00000000000000000
ZKgX00000080ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX
2@00000209Z2]`080000003BXJD0dZ6U0000003BYJX000000=bTVP0000020?_KXP8000000P3<VJ42
00000080mK^<0P0000030<F<V0040000003HVY80f9ZB00000080gIjA00D000000<V=T`39SI<0bHfC
000000030<:4T@060000003LVX`000000>b]S0000000nKb11@000000103[gFh00000000000000002
0:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y
_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP200000080
ZKgX0P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX
0000002Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0800000
0P2Y_NP5000000040:Vmj00000000000000002P0oooo000F0?ooo`030000003oool0oooo00X0oooo
0P0000000`2Y_NP00000000000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX
00000002000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX0000000200000003
0:Vmj0000000000000@0000000<0ZKgX0000000000000P2Y_NP00`000000ZKgX0:Vmj00200000080
ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vm
j00000000P0000001@2Y_NP000000000000000007@j200@000000`2JP[L200000080dZFZ00<00000
0=bTVP0000000P3kfj8200000080c9VQ0P0000020?FkS08000000P35S9P200000080f9ZB00@00000
0=fNT@3MWY4000000`39SI<01P000000`XBA0<:4T@32Q94000000=bJS0/0000000@0cMoU0000002Y
_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P000002
0:Vmj0030000002Y_NP000000080000000<0ZKgX000000000000100000001`2Y_NP0000000000000
0000ZKgX0000002Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vm
j08000000P2Y_NP00`000000ZKgX00000002000000030:Vmj0000000000000@0000000L0ZKgX0000
0000000000000:Vmj0000000ZKgX00<0000000<0ZKgX000000000000:03oool001H0oooo00<00000
0?ooo`3oool0303oool01@000000ZKgX0:Vmj0000000ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX
0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP0
0000000000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0000000200000004
0:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX
0:Vmj08000000P2Y_NP50000000301d>PP000000000000<000000P2JP[L2000000<0dZFZ0P000000
0`3kfj800000000000030<bIX@80000000/0mK^<0000003jcIT0n/fI00000035S9P000000<RDX000
0000f9ZB000000020=fNT@0500000039SI<0bHfC0<V=T`0000000`32Q945000000030?VlP@000000
00000080000000@0jme^0000003=gnD0cMoU0`000000102Y_NP000000:Vmj02Y_NP2000000040:Vm
j0000000ZKgX0:Vmj0<0000000<0ZKgX0000000000000`0000020:Vmj08000000P2Y_NP00`000000
ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX000000020000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000001P2Y_NP000000000
00000000ZKgX00000080ZKgX0`000000102Y_NP000000:Vmj02Y_NP2000000040:Vmj0000000ZKgX
0:Vmj0800000:03oool001H0oooo0P00000=0?ooo`030000002Y_NP0ZKgX008000000P2Y_NP00`00
0000ZKgX0000000200000080ZKgX00<000000:Vmj00000000P0000000`2Y_NP00000000000030000
0080ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P000002
0:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y
_NP000000080000000L0ZKgX00000000000000000:Vmj0000000ZKgX0080000000<07@j200000000
00000`0000000`2JP[L00000000000040=:UZPD000000`3<VJ4010000000mK^<0?FkS00000020?[=
V@8000000P38U:000`000000f9ZB000000020=fNT@0400000039SI<0bHfC0<V=T`D0000000<0g9Z<
0000000000000P0000000`3m`W`0000000000002000000050=Goe000000000000;G8j00000000P2Y
_NP3000000030:Vmj0000000ZKgX00<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<0
000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000
ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX00000002000000030:Vmj0000000000000@0000000<0
ZKgX0000000000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj0<00000
00<0ZKgX0000002Y_NP00`0000000`2Y_NP000000000000W0?ooo`005P3oool00`000000oooo0?oo
o`0=0?ooo`8000000P2Y_NP00`000000ZKgX00000002000000030:Vmj0000000000000<000000P2Y
_NP200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX
00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj000
00000P0000000`2Y_NP000000000000300000080ZKgX0P0000020:Vmj0030000002Y_NP0000000X0
000000<0WHZo0000003BYJX00`3BYJX2000000030=cNf0000000000000<0c9VQ00@000000?FkS03e
^h`000000P3jcIT200000080b9BP00H000000=RJTP000000gIjA0000003_/hh4000000<0`XBA00<0
00000=bJS00000000`0000000`3m`W`0000000000003000000030;gGk@000000]LSX00<0000000<0
ZKgX0000000000000`0000020:Vmj08000000P2Y_NP00`000000ZKgX00000002000000040:Vmj000
0000ZKgX0:Vmj0<0000000<0ZKgX0000002Y_NP00`000000102Y_NP000000:Vmj02Y_NP300000003
0:Vmj0000000000000<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj0<0000000@0ZKgX
0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj080
00000P2Y_NP00`000000ZKgX00000002000002H0oooo000E0?ooo`030000003oool0oooo0100oooo
100000020:Vmj08000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj080
00000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`00
0000ZKgX00000002000000030:Vmj0000000000000<000000P2Y_NP200000080ZKgX00<000000:Vm
j00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX2000000309f:_`030000003BYJX0
dZFZ0080000000@0g=kH0000003DcM<000000`3<VJ43000000<0n/fI0P0000020<RDX0040000003H
VY8000000=fNT@<0000000<0bHfC0000000000000`32Q94010000000g9Z<0000003UXXP700000080
_MO]0P0000020:fhh@8000000P2Y^N@00`000000ZK_V00000002000000040:Vmj0000000ZKgX0:Vm
j08000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP5
000000060:Vmj000000000000000002Y_NP000000P2Y_NP200000080ZKgX00<000000:Vmj0000000
0P000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000ZKgX00<0000000@0ZKgX0000002Y
_NP0ZKgX0`0000000`2Y_NP0000000000003000000030:Vmj0000000000000T0oooo0P0000040?oo
o`030000003oool0oooo0080oooo0`00000?0?ooo`005@3oool00`000000oooo0?ooo`0A0?ooo`03
0000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP00000
0080000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000
000000<000000P2Y_NP200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y
_NP200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP900000080WHZo
00@000000=:UZP000000mN>g0`0000001P3DcM<000000000003<VJ4000000>;hZ0H000000`38U:05
0000000:0>ncSP000000bHfC00000030QID000000<:4T@000000g9Z<00000080iJ:80P0000000`3n
`VX0000000000004000000060:f_f@00000000000000002b]]`000000P2Y^N@2000000040:^ji000
0000ZKgX0:Vmj0<0000000@0ZK_V0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080
000000H0ZKgX00000000000000000:Vmj00000020:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0`00
0000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P000000102Y_NP00000
0:Vmj02Y_NP200000080ZKgX1@0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0P000000
0`2Y_NP00000000000070?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`005@3oool2000001<0oooo00D000000:Vmj02Y_NP000000:Vmj00300000080ZKgX
00<000000:Vmj00000000P0000000`2Y_NP000000:Vmj00300000080ZKgX1@0000000`2Y_NP00000
000000020:Vmj0030000002Y_NP00000008000000P2Y_NP010000000ZKgX0000000000020:Vmj003
0000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000:Vmj0030000
00030:Vmj0000000000000@0000000@0UgN^0000002MR[l0WHZo0P0000001`3ehkL000000>kI_@00
0000gl6j0000003Eb<d0100000001P2INk00000006]M/@000000S:k]00000080b9BP0`0000020=fN
T@0;0000003_/hh000000<V=T`000000`8FE00000032Q94000000=bJS00000000P3UXXP20000000:
0?k2JP00000000000000003mhY4000000:f_f@000000][7E00000080/[KL0`0000000`2/]^000000
0:^ji003000000040:Vii0000000ZK_V0:VkiP<0000000<0ZKgX0000000000000`0000001P2Y_NP0
0000000000000000ZKgX00000080ZKgX0`0000000`2Y_NP000000:Vmj003000000040:Vmj0000000
ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP0000000000004000000070:Vm
j000000000000000002Y_NP000000:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX
0000002Y_NP00`0000060?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0303o
ool001D0oooo00<000000?ooo`3oool04`3oool00`000000ZKgX00000002000000040:Vmj0000000
ZKgX0:Vmj08000000P2Y_NP5000000060:Vmj000000000000000002Y_NP000000P2Y_NP200000080
ZKgX00@000000:Vmj000000000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vm
j00000000P0000000`2Y_NP000000:Vmj00300000080ZKgX1@0000000`2Y_NP00000000000020000
000301d>PP000000000000<0UgN^0`000000103ehkL000000>kI_@0000020=o1^P@0000000H0^iF`
0000002INk00VG^`0000001[GK4400000080b9BP00h000000=fNT@3MWY4000000>ncSP000000bHfC
00000030QID000000<:4T@000000g9Z<00000080iJ:80P0000000`3n`VX000000000000200000003
0?[YZ0000000][7E0080][7E0P000000102f]MP000000:bfh02/]^0200000080[[OO00<000000:Vi
i00000000P0000001P2[^^@00000000000000000ZKgX00000080ZKgX0P0000020:Vmj0030000002Y
_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP0000000800000
00<0ZKgX000000000000100000000`2Y_NP00000000000020:Vmj0030000002Y_NP0000000800000
00@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y
_NP0ZKgX0P0000020:Vmj0030000003oool0oooo00@0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0<0?ooo`005@3oool00`000000oooo0?ooo`0D0?ooo`030000002Y_NP0ZKgX
00D0000000H0ZKgX00000000000000000:Vmj00000020:Vmj08000000P2Y_NP00`000000ZKgX0000
0002000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX00000002000000040:Vm
j0000000ZKgX0:Vmj08000000P2Y_NP5000000060:Vmj000000000000000002Y_NP000000P2Y_NP2
00000080ZKgX0P000000100M3X800000020JS`00000209Mg[PD0000000@0k]Vm0000003O`KX00000
0P3N^k@010000000^iF`0;^E/000000209Uk/0<0000000<0S:k]00000038U:000P38U:000`000000
gIjA000000020>ncSP0900000039SI<000000<25U@000000`XBA0000003LVX`000000080iJ:80P00
00001P3n`VX000000000003mhY4000000?[YZ080000000D0][7E0000002k/]4000000;Jef0030000
00040;2bfP000000[[OO0:jgg`8000000P2/]N0200000080[kcS00<000000:Vmj00000000P000000
102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P0000000`2Y_NP000000000
000300000080ZKgX0P000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj080
000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP2000000040:Vmj0000000
ZKgX0:Vmj0<0000000<0ZKgX0000000000000`0000050?ooo`040000003oool0oooo000000L0oooo
1000000?0?ooo`005@3oool00`000000oooo0?ooo`0E0?ooo`8000000P2Y_NP010000000ZKgX0000
000000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj003
0000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0D0000000H0ZKgX0000
0000000000000:Vmj00000020:Vmj08000000P2Y_NP00`000000ZKgX00000002000000040:Vmj000
0000ZKgX0:Vmj080000000D07@j20000000P6Xl0000009Mg[P03000000060=[3``000000hKbb0000
003O`KX000000`3N^k@00`000000^iF`0;^E/00800000080b9BP0P0000000`3MWY4000000>ncSP02
0>ncSP0800000030QID0`8FE00000032Q94000000=bJS00000020>FRR080000000@0o/9Z00000000
0000oN:A0P0000000`3Qfm000000000000020;^bd@8000000P2i/m<00`000000/;;J000000020000
0080/K?J0P000000102`]mh000000:nlh`2__><2000000040:Vmj0000000ZKgX0:Vmj0<0000000<0
ZKgX0000000000000`0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0`0000000`2Y_NP0
00000:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX0000002Y_NP00`000000102Y
_NP000000:Vmj02Y_NP3000000030:Vmj0000000000000<0000000H0ZKgX00000000000000000:Vm
j00000020:Vmj0800000103oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0100
oooo000E0?ooo`8000005`3oool00`000000ZKgX0:Vmj00200000080ZKgX00@000000:Vmj0000000
00000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP50000
00060:Vmj000000000000000002Y_NP000000P2Y_NP200000080ZKgX00<000000:Vmj00000000P00
0000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj0000000100000001@0M3X800000
000000000000UgN^0080000000L0f/?30000003Q_;80hKbb0000003O`KX000000080g[^d10000000
102kUK00000009IbZ000000208=UZ080000000H0b9BP0000002nTJL000000=fNT@0000030>ncSP08
00000030QID0`8FE00000032Q94000000=bJS00000020>FRR0L0000000P0hM_@0000002m//l00000
0;^bd@000000_K??00000080^K?C0P0000020;>_e@040000002a/mX0000000000080/;ON0`000000
0`2b_N40000000000003000000060:Vhi000000000000000002Y_NP000000P2Y_NP200000080ZKgX
00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj000
00000P000000102Y_NP000000:Vmj02Y_NP2000000030:Vmj0000000000000@0000000L0ZKgX0000
0000000000000:Vmj0000000ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP00000
000000040?ooo`800000203oool5000000h0oooo000D0?ooo`030000003oool0oooo01P0oooo0P00
0000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P0000000`2Y_NP00000
00000003000000060:Vmj000000000000000002Y_NP000000P2Y_NP200000080ZKgX00<000000:Vm
j00000000P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P000000
0`2Y_NP000000000000300000080ZKgX100000000`0M3X80000000000003000000060=[3``000000
hKbb0000003[`ZX000000P3N^k@2000000030=fe[`000000^iF`0080000000@0UW:X00000023IJP0
PfFX10000000102nTJL000000=fNT@0000030>ncSP0;00000030QID0`8FE00000032Q94000000=bJ
S0000000iJ:80000003k^WL00`000000103Rc4l000000000000000030;fbc`040000002m/ll0_K??
0;fcc`80000000@0^[7@0000002c[mD0/joE0P0000020;Fce`80000000H0]KWL0000002b_N400000
0;>df@0000020:Vbg`8000000P2]]=d00`000000ZKgX00000002000000040:Vji@000000ZKgX0:Vm
j080000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP2000000030:Vmj000
0000000000@0000000<0ZKgX0000000000000P2Y_NP00`000000ZKgX00000002000000040:Vmj000
0000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP20000
0240oooo000<0?ooo`<000001@3oool00`000000oooo0?ooo`0I0?ooo`030000002Y_NP000000080
000000<0ZKgX0000000000000`0000020:Vmj08000000P2Y_NP010000000ZKgX0000000000020:Vm
j0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX00000002000000030:Vmj0000000ZKgX
00<0000000<0ZKgX0000000000000`0000020:Vmj08000000P2Y_NP00`000000ZKgX000000020000
00030:Vmj0000000000000<0000000D0001f000000000000f/?3000000020>6l/P030000003[`ZX0
000000<000000P3M]Jl2000000050:^5[@000000UW:X09IbZ00000000P23IJP2000000<0_Y6W0P00
00030>ncSP0;00000030QID0`8FE00000032Q94000000=bJS0000000iJ:80000003k^WL01P000000
1`2o//h000000;fbc`000000_kC@0000002m/ll00P0000020;Zad0<0000000L0]ZkA0000002e/mL0
00000;Vcd`000000]KWL008000000`2c]=T2000000040:bWdP000000[KCM0:fdg@80000000@0ZKKR
0000002Y^^D0ZK[U0`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000@0000000D0
ZKgX000000000000ZKgX000000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP0
00000:Vmj02Y_NP3000000030:Vmj0000000ZKgX00<0000000<0ZKgX000000000000100000000`2Y
_NP000000000000P0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0
oooo0P0000000`2Y_NP00000000000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y
_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P000002
0:Vmj0@000000P2Y_NP200000080ZKgX00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y
_NP200000080ZKgX00<000000:Vmj00000000P000000200/8Y4000000000002ONZX000000=[3``00
0000hKbb0`0000020>c5[0050000003M]Jl0gKF_0=fe[`0000000P2[QJd010000000UW:X09IbZ000
000208=UZ08000000`2nTJL200000080kk>>0P0000030<25U@070000003LVX`0g9Z<0000003UXXP0
00000?^jM`0500000080_k;>0P0000020;ndd080000000H0_k;>0000002j/M0000000;bbd0000002
0;J^d@8000000P2i/m<200000080^;CF00@000000;>df@00000000000P2/Ym83000000030;Nff@00
0000ZKKR00<000000P2/]^4400000080ZK[U0P000000102Y_NP000000:Vmj02Y_NP3000000030:Vm
j0000000ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000:Vmj00300000003
0:Vmj0000000000000<000000P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX0000
003oool07`3oool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0L0?ooo`05
0000002Y_NP0ZKgX0000002Y_NP00P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000
002Y_NP0ZKgX0P0000020:Vmj0D0000000L0ZKgX00000000000000000:Vmj0000000ZKgX00<00000
00@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y
_NP0ZKgX0P0000001@2Y_NP000000000000/8Y40000000<0WgZZ100000001@3[`ZX000000>c5[03/
aJ`000000080gKF_0P0000020:^5[@040000002FLZP0UW:X00000080PfFX0P0000030;jAY`040000
003_/hh0kk>>0>ncSP8000000`30QID00`000000g9Z<000000020>FRR080000000<0o/9Z00000000
00000P000000202o//h000000<:idP000000_kC@0000002o]m8000000P2o//h010000000_;;@0;bb
d02l/]02000000060;V/c0000000^K?C00000030^M8000000P2h]=H200000080/ZW?0P000000102j
/m<000000;Nff@2g]]T200000080[:gH00@000000:bfh@00000000000P2Y]^83000000030:bfh000
0000ZKgX00<0000000@0ZKcW0000002Y_NP0ZKgX0P0000020:Vmj0030000002Y_NP0000000800000
00<0ZKgX0000000000000`0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0`0000000`2Y
_NP000000:Vmj003000000040:Vmj0000000ZKgX0:Vmj08000007`3oool000d0oooo00<000000?oo
o`3oool0103oool2000001d0oooo00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP00000
0080000000<0ZKgX0000000000000`0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0P00
00020:Vmj0040000002Y_NP0000000000080ZKgX00<000000:Vmj00000000P000000102Y_NP00000
0:Vmj02Y_NP200000080ZKgX00<000000:Vmj00000000P0000000`2Y_NP000000000000200000003
02`RT@000000000000@0000000<0hKbb0000000000000P3/aJ`010000000jlRa0000000000020<n_
^P060000002[QJd0ZhF]0000002FLZP000000`23IJP01@000000_Y6W0;jAY`2nTJL0000000<0kk>>
0P0000030<25U@030000003LVX`000000080iJ:80P000000103n`VX000000000003oeXT200000080
`[WB0P0000030;ngdP80000000<0`[_C0000002l/]000P0000030;V/c00300000030^M80`;WB00<0
000000<0]ZkA0000002bZLl00P0000030;Zcd`80000000@0^[KF0000002/[MP0[:gH0P0000020;>f
f`80000000@0ZjgH0000002/]^00[;KP0P0000020:Vji@030000002Y_>L000000080000000<0ZKgX
0000000000000`0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0P0000020:Vmj0030000
002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP30000
00030:Vmj0000000000001h0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool07@3oool2000000030:Vmj0000000000000<000000P2Y_NP200000080ZKgX00@000000:Vmj000
000000000P2Y_NP00`000000ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP0
0`000000ZKgX00000002000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`000002
0:Vmj08000000P2Y_NP400000080WgZZ00H000000<ZHX`3:V:<000000>_2ZP0000020>c5[0030000
003[b;40000000<0cjnj00@000000:^5[@2[QJd000000P2FLZP00`000000PfFX0000000200000003
0;jAY`00000000000080kk>>00<000000>k0X`0000000`30QID00`000000g9Z<000000020>FRR080
000000X0o/9Z00000000000000000?K4UP000000`[WB00000031`=T000000P2o]m8200000080`[_C
0P0000020;Zbd@080000002i[<`0000000000030^M8000000<6meP0000020;J^d@8000000P2f/]D0
10000000^[?C0000000000020;ZfeP<0000000L0]K;G0000002c]]/000000;Fae@000000ZjgH00<0
000000@0];WM0000002Y^^D0ZK[U0P0000001P2[^N@00000000000000000ZK[U00000080ZKcW0P00
0000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y
_NP0ZKgX0`0000000`2Y_NP0000000000003000000030:Vmj0000000000000<000007P3oool000`0
oooo0P0000050?ooo`030000003oool0oooo0200oooo00D000000:Vmj02Y_NP000000:Vmj0030000
00040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX00000002000000030:Vmj0000000
ZKgX00<0000000<0ZKgX0000000000000`0000020:Vmj08000000P2Y_NP010000000ZKgX00000000
00020:Vmj0030000002Y_NP000000080000000<0ZKgX00000000000010000000100/8Y40000009mj
ZP0000020<ZHX`050000003[`ZX000000>c5[00000000P3[b;401@000000cjnj0<n_^P3?[kX00000
0080ZhF]00<0000009IbZ00000000`0000001@3=_<T000000000003BlNL000000080kk>>00<00000
0>k0X`0000000`30QID00`000000g9Z<000000020>FRR080000000D0o/9Z00000000000000000?K4
UP02000000<0`L3I0P0000001P2m_=T000000<:kd`000000`<KO00000080^[;A0P0000020<FldP04
00000031_MH0`KgF0<6meP80000000@0];CH0000002f/]D0][;E0P0000020<;2f@80000000@0^;WJ
0000002e/]L0]K;G0P0000020;Fae@80000000@0]KGI0000002d^Md0];WM0`0000001@2[]=l00000
0000002_^N4000000080ZK[U0`0000000`2[^N@000000:Vmj003000000040:Vmj0000000ZKgX0:Vm
j0<0000000<0ZKgX0000000000000`0000001`2Y_NP00000000000000000ZKgX0000002Y_NP00`00
0000102Y_NP000000:Vmj02Y_NP2000001d0oooo000=0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool08@3oool010000000ZKgX0000000000020:Vmj0030000002Y_NP0000000800000
00@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0D0000000<0ZKgX0000000000000P2Y_NP00`000000
ZKgX00000002000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P000002
0:Vmj0P0000000<0;2:A0000000000000`3:V:<3000000060>c5[0000000jlRa0000003Vc;`00000
0`3?[kX5000000030>oR`P000000cKc900H0000000H0kk>>0000003^`:<0k/2S00000030QID20000
00040=bJS0000000iJ:80>FRR080000000<0o/9Z0000003oeXT00P000000203hbIT0000000000031
`=T000000;RjfP000000_KcI0P0000020<36g`<0000000/0^;gN00000035_=8000000<cEh@000000
`KgF0000002f_Ml000000;Bdf003000000070;[3h@000000`/;I0000002ka>4000000;RifP030000
00070;Vge`000000]K7E0000002f^=X000000;Fef@0300000080^;cL0P0000000`2`]]d000000:ni
h@03000000040:^dg`000000ZkWT0:^ii08000000P2Y_NP5000000070:Vmj000000000000000002Y
_NP000000:Vmj003000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0`00
00000`2Y_NP000000?ooo`0L0?ooo`004`3oool00`000000oooo0?ooo`0R0?ooo`050000002Y_NP0
ZKgX0000002Y_NP00`0000000`2Y_NP0000000000003000000060:Vmj000000000000000002Y_NP0
00000P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP00`000000ZKgX000000020000
00030:Vmj0000000ZKgX00<0000000<0ZKgX0000000000000`0000020:Vmj0L000000P3:V:<01@00
0000mlVL0000003ng9T000000080jlRa00<000000>K<_03Vc;`01`000000103_h/8000000=no^000
00030<6V_P040000002RULL00000000000<0k/2S00H000000<25U@00000000000=bJS00000020>FR
R080000000T0o/9Z000000000000m/BF0000003hbIT000000?[AW@0000000P2h^]X200000080_LGP
0P000000102[`^X000000;RmgP2h_Mh200000080c=GQ0P0000020;Jmg`80000000@0]L7T0000002j
`n40^/?Q0P0000020;_4h@80000000@0];kQ0000002i]mL0^KOG0P0000020;JhfP8000000P2l`mh0
10000000^;cL0000000000020;2fg@8000000P2a]]`00`000000ZkCO00000002000000070:nkhP00
000000000000002Y_NP000000:Vmj003000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000
002Y_NP0ZKgX0`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000@000006`3oool0
01<0oooo0P00000T0?ooo`@000000P2Y_NP200000080ZKgX00@000000:Vmj000000000000P2Y_NP0
0`000000ZKgX00000002000000030:Vmj0000000ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0P00
00020:Vmj0D0000000L0ZKgX00000000000000000:Vmj0000000ZKgX00<0000000H0ZKgX00000000
0000000005Y5W`0000030<ZHX`8000000P3ng9T2000000050>_8/@000000i/bl0000003GbL`00P00
00000`2ak?L000000>SXc`0200000080gknh00@000000<6V_P31Y[h0`JJn0P0000000`2RULL00000
0>k0X`020>k0X`0600000030QID000000000003LVX`000000P3UXXP5000000030?K4UP0000000000
0080n]6M0`0000001`2h]ML000000;g5h0000000_/KQ0000002[`^X00`0000001@2ddo0000000000
00000000^<cY00<0000000<0[[oW0000002e`N@00`0000001`2gaN@00000000000000000/LW[0000
002d_^400`0000020;NmgP80000000@0]/KV0000002l`mh0_<?N0P0000001P2f_=h0000000000000
0000/kKK00000080/KKL0P0000020:nfg@80000000@0/kcP0000002Y_NP0ZKgX0P000000102Y_>L0
00000:Vmj02Y_NP3000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000000000000`0000001P2Y
_NP00000000000000000ZKgX00000080ZKgX0P00000K0?ooo`004`3oool00`000000oooo0?ooo`0T
0?ooo`030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vm
j02Y_NP200000080ZKgX1@0000000`2Y_NP0000000000003000000070:Vmj000000000000000002Y
_NP000000:Vmj00300000080ZKgX00@000000:Vmj000000000000P2Y_NP00`000000ZKgX00000002
0000000305Y5W`000000bYRS0080bYRS0P0000001`3ng9T000000?7@/03ad;0000000>K<_0000000
0P3GbL`00`000000f/K600000002000000060>oR`P000000gknh0000003F/K@000000P31Y[h00`00
0000XYG70::Ea`0200000080k/2S0P000000102mQYX000000=bJS00000020>FRR0D0000000L0m/BF
000000000000n]6M0000003dcZP000000080^;GG0P0000020;k6h@8000000P2Q`>l2000000060;;:
j`00000000000000002Y_NP000000P2^_nL200000080]L;T0P0000020;K:j@@000000P2[_NH01000
0000]kgN0000000000020;K6iP<0000000D0^LCS000000000000/[kS000000020;>ff`<0000000L0
/[OL0000002_]]d000000;Bhg0000000/kcP00<0000000<0ZK_V0000002Y_>L00`0000000`2Y_NP0
000000000003000000060:Vmj000000000000000002Y_NP000000P2Y_NP2000000040:Vmj0000000
ZKgX0:Vmj0<0000000<0ZKgX0000003oool06P3oool001<0oooo00<000000?ooo`3oool09@3oool2
000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000000000000`0000001P2Y_NP0000000000000
0000ZKgX00000080ZKgX0P0000020:Vmj0040000002Y_NP0000000000080ZKgX1@000000102Y_NP0
00000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj0<0000000/0;1F10000001JAIl0FTFO0000
003:V:<000000?O9W0000000o]bI000000020?7@/08000000P3GbL`01@000000f/K60=[6aP000000
iLRk008000000P3O_kP01`000000e[6d00000031Y[h000000;ZL^P0000000P2RULL20000000:0>k0
X`00000000000;f6VP000000g9Z<0000003UXXP000000?^jM`@0000000@0m/BF000000000000n]6M
0P0000000`3Ya:l00000000000020<G1eP8000000P2oan42000000030:jniP00000000000080/KgR
00<000000:Vmj00000000P0000002`2^_nL000000;G2i0000000]lCT0000002fb^T000000;K6iP00
0000YKo/00D0000000D0]<c/00000000000000000;76j@03000000030;;:k0000000/[kS00<00000
00@0/kWM0000002b]m`0/[OL0P0000020;Bhg08000000P2g_Mh400000080ZkWT0P000000102Y^nH0
00000:Vli`2Y_>L200000080ZKgX00<000000:Vmj00000000P0000000`2Y_NP000000:Vmj0030000
00040:Vmj0000000ZKgX0:Vmj08000006P3oool00180oooo00<000000?ooo`3oool0:03oool30000
0080ZKgX0P0000020:Vmj0040000002Y_NP0000000000080ZKgX00<000000:Vmj00000000P000000
102Y_NP000000:Vmj02Y_NP200000080ZKgX100000020:Vmj0D0000000<0ZKgX0000000000000`00
00000`2Y_NP00000000000030000000305Y5W`000000bYRS0080000000H0o]bI0000003ad;00lM2`
0000003Ya[<2000000070=O9c0000000f/K60000003Ub;/000000>[8/P02000000050=no^0000000
e[6d0=Ja]00000000`2jW;X700000080_HJJ0P0000000`3UXXP000000?^jM`03000000030?K4UP00
0000n<VI0080000000<0m<jX0000003Ya:l00P0000001@35`MH000000<o?fP000000_lOQ00800000
00@0[[kV0000002e^M`000000P2a_N82000000040:Vmj0000000[[oW0:joi`8000000P2ga>@20000
0080]/KV0P000000102Q/^@000000:K0k02V`>`200000080[/O]0P000000102]and000000;;:k02b
b^`200000080ZK[U00<000000;>ig@0000000P0000001`2c^]l00000000000000000^K_K0000002g
_Mh00P0000020:Zcg`<0000000<0[kWQ0000002Y^nH00`000000102Z^><000000:Vmj02Y_NP20000
00030:Vli`000000000000<0000000<0ZKgX000000000000100000000`2Y_NP000000000000I0?oo
o`004P3oool2000002T0oooo00<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP20000
0080ZKgX00<000000:Vmj00000000P0000000`2Y_NP000000:Vmj003000000030:Vmj00000000000
00<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj08000000P2Y_NP010000000ZKgX0000
000000020:Vmj0<0000000<0FTFO0000003:V:<00P000000103ng9T000000?7@/03ad;0200000080
il:a00<000000=[6aP0000000P3Ub;/200000080k<B[00D000000=Ja]03F/K@0e[6d000000020;ZL
^P80000000D0XYG700000000000003>g000000030;f6VP050000003UXXP0iJ:80000003k^WL01P00
00000`3jdId000000?C>Z00200000080k/jc00<000000<o?fP3?cmX00P0000001@2o`md000000000
00000000]KWL00<0000000<0];kQ0000000000000`0000001@2^_nH00000000000000000_<OS00<0
000000<0/kgQ0000002Q/^@00`0000001`2]`^T00000000000000000Zl3Y0000002]and00`000000
0`2V`>`0000000000003000000060;?0h`00000000000000002`^^4000000P2i^m/2000000060;Vm
g000000000000000002_]Md000000P2_^N42000000040:Zcg`000000Z[SS0:Zhh`<0000000D0ZK_V
000000000000Z[SS000000020:Vmj080000000@0ZKcW0000002Y_NP0ZKgX0`0000000`2Y_NP00000
0000000H0?ooo`004P3oool00`000000oooo0?ooo`0Y0?ooo`80000000<0ZKgX0000002Y_NP00`00
00000`2Y_NP000000000000300000080ZKgX100000020:Vmj0<0000000<0ZKgX0000002Y_NP00P00
00020:Vmj0030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP00000
0:Vmj02Y_NP300000080FTFO00T000000?O9W0000000o]bI0000003ad;0000000>W6/`0000000P3W
`[401`000000f/K60000003Ub;/000000>[8/P0000000P3/a:/01@000000e[6d0=Ja]0000000`iZ]
0080000000@0_9Ze0000002RULL0XYG70`0000030;f6VP050000003UXXP0iJ:80000003k^WL00`00
00000`3naWl0000000000003000000040>W4[`000000k/jc0>k>/`<0000000<0b/_J000000000000
0P2m_=T2000000060;VjfP000000];kQ0000002g_ml000000P2Y_NP2000000060;33i`0000000000
0000002mc>D000000P2c_N42000000060:fih`00000000000000002b`ND000000P2[`>T200000006
0:k2j000000000000000002O[n<000000P2S]nH200000080[[cT00<000000;2jh@0000000P000000
1@2m`ml000000000002f_=h000000080[kGM0`0000000`2b]]`000000:Zcg`03000000070:njhP00
000000000000002Z/ml000000:Zhh`03000000030:Vli`000000ZKcW00<0000000@0ZKgX0000002Y
_NP0ZKgX0P00000H0?ooo`004P3oool00`000000oooo0?ooo`0[0?ooo`@0000000<0ZKgX00000000
00000P2Y_NP00`000000ZKgX00000002000000030:Vmj0000000ZKgX00<0000000@0ZKgX0000002Y
_NP0ZKgX0P0000020:Vmj0040000002Y_NP0000000000080ZKgX1@0000000`2Y_NP000000000000=
000000030?7@/000000000000080il:a00D000000>K1/000000000000>G8^`0200000080k<B[00@0
00000>[3[@00000000000P33VZd01P000000_9Ze0;bJ]@2lV[D000000::Ea`<000000`2mQYX01@00
0000iJ:80>FRR0000000nkYg00<0000001D0o/Io00000000000000000?oCRP000000jLB_0000003^
c[<000000??O^0000000b/_J00000034`mT000000;flf@000000_KgJ0000002i^]X00`0000001@2g
_ml00000000000000000ZKkY008000000P2bbN/00`000000_LcU00000002000000030;2mh`000000
00000080]L7T00<000000;;1i@0000000P0000000`2a_^@00000000000020:jdg@030000002O[n<0
00000080000000@0YkSV0000002^_>@0[[cT0P0000001`2^^n<000000;g3g`000000^LCS0000002f
_=h00`000000102c]]/000000;:fg02b]]`2000000060:nggP00000000000000002b^^0000000P2Z
/ml2000000040:njhP000000ZKcW0:Vli`8000000P2Z^><5000000030:Vmj0000000000001L0oooo
000B0?ooo`030000003oool0oooo02/0oooo00<000000:Vmj02Y_NP00P0000020:Vmj0040000002Y
_NP0000000000080ZKgX1@0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<00000
00H0ZKgX00000000000000000:Vmj00000020:Vmj080000000@0ZKgX0000002Y_NP0ZKgX10000003
07N0c`070000003<`M0000000=N^[P000000jLJc000000020>O2/@070000003V`K0000000=jc[000
0000j/Rb000000020>c4Z`030000003Z`jd0000000<0`iZ]00@000000;bJ]@2lV[D0_9Ze0P000000
102LP[H000000000000000020;f6VP050000003UXXP0iJ:80000003k^WL00`0000001@3naWl00000
000000000000om>:0080000000D0k/jc0000003cgkP000000>gPa002000000030<C3f@0000000000
0080_KgJ0P0000020;flf08000000P2k`n02000000040:_1j@000000//W[0;;9j`80000000H0//KY
00000000000000000:foi`0000020;G1i080000000H0/l3S00000000000000000;>ff`0000020:jd
g@80000000@0YKKU0000002W^>H0YkSV0`0000000`2Z]=l000000:jkh`0200000080^LCS0P000002
0;>oh`030000002c]]/000000080000000D0/kSM000000000000]<7T000000020;:jh0<0000000<0
[kKN0000002_^^800`0000001`2Z/ml00000000000000000[k_R0000002Y_NP00`0000000`2Y_NP0
00000?ooo`0F0?ooo`004P3oool00`000000oooo0?ooo`0/0?ooo`80000000@0ZKgX0000002Y_NP0
ZKgX0P0000000`2Y_NP000000000000300000080ZKgX1@0000000`2Y_NP00000000000020:Vmj004
0000002Y_NP0000000000080ZKgX00<000000:Vmj00000000P0000000`2Y_NP000000:Vmj0030000
00090:Vmj0000000000003PQR@000000Mh3?0000003<`M0000000080ejj^0P0000020>O2/@030000
003V`K0000000080g[>/00D000000>[8/P000000k<B[000000020>[3[@0600000033VZd0`iZ]0000
0032TjH000000P2lV[D00`000000W8:f09b2]P0300000080_HJJ00D000000>FRR03UXXP000000?^j
M`03000000050?k6O`000000om9k0000003odhX00P0000005`3^c[<000000??O^0000000kN340000
003Qf/l000000<75g@000000_KgJ0000002l_m`000000;flf0000000a<GK0000002k`n0000000;g;
i@000000Zl7Y00<0000000<0/LGX0000000000000P2Y_NP00`000000[KoW00000002000000030;G4
i@00000000000080/[gR00<000000;>ff`0000000P0000000`2`^^40000000000003000000040:Nj
iP000000Z[CO0:Zdg`80000000D0/[kS00000000000000000;?<k002000000030;>oh`0000000000
0080/kWN0P0000000`2danP000000;C1i003000000040:jih@000000[kKN0:nfgP80000000H0/[_P
00000000000000000:nfgP0000020:nkhP80000000@0ZKgX0000002Y_NP0ZKgX0P0000070?ooo`<0
0000303oool00140oooo0`00000_0?ooo`@0000000L0ZKgX00000000000000000:Vmj0000000ZKgX
00<0000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP000000:Vmj02Y_NP200000080ZKgX00@0
00000:Vmj000000000000P2Y_NP5000000030:Vmj00000000000008000000P0h8HT00`000000c<7@
000000020=N^[P0;0000003M[:@000000000003W`[4000000>K1/0000000g[>/0000003O[jH00P00
00003P3/a:/000000>[3[@000000hKjd00000033VZd000000<:CYP000000_9Ze00000037Xk@00000
0P2LP[H200000080_HJJ00D000000>FRR03UXXP000000?^jM`06000000030?oCRP000000nLbJ00@0
000000<0kN340000003Qf/l00P0000001@31aMd00000000000000000_;oL008000000P34aM/20000
0080_L_U0P0000001P2a_n@00000000000000000/KgR00000080ZKgX0P0000001P2]`>L000000000
00000000/lW[00000080/[gR0P0000001`2d^ml000000;2jh@000000//k^0000002Ua_001P000000
0`2_^=l00000000000020;K9j@D0000000<0ZKcW0000002c^Mh00P0000020;C7j080000000@0[[gU
0000002^^N40[[WQ0`0000001@2d`N@000000000002^^^8000000080[kKN2@0000000`2Y_>L00000
000000070?ooo`030000003oool0oooo00/0oooo000A0?ooo`030000003oool0oooo0300oooo1000
00020:Vmj0030000002Y_NP000000080000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000000
0003000000030:Vmj0000000000000<0000000H0ZKgX00000000000000000:Vmj00000020:Vmj080
000000T0ZKgX000000000000;1F10000000h8HT000000<c1d00000000P3G[Zh01`000000gJbT0000
003b`Id000000>K1/00000000P3N/j`01`000000gjnV0000003eb9h000000>[3[@0000000P3Q_[@0
2@000000`iZ]00000032TjH000000;bJ]@000000aj>d0000000209b2]P80000000<0_HJJ00000000
00000P3UXXP01@000000nkYg000000000000o/Io00<0000000H0om>:000000000000o=JK0000003l
iYH2000000030>7Jc`000000e]SJ008000000P2lb^D200000080^/KS0P0000001@39f^H000000000
00000000^<GT008000000P2d^M`00`000000/KgR00000002000000050:Vki`00000000000:k3j@00
00000P2cbN/3000000030:^liP000000];_O008000000P2bc^h200000080Ukca00<0000009nfj000
00000P0000000`2f`n@000000;K9j@0200000080Y/?^1@0000001@2dc^d00000000000000000[l?Y
00D0000000L0ZkWS00000000000000000:noiP000000[[[R00<0000000D0]L;T000000000000]<7S
000000020:Vli`<0000000<0Z[;N0000003oool01P3oool00`000000oooo0?ooo`0;0?ooo`004@3o
ool00`000000oooo0?ooo`0_0?ooo`<0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0@00000
0P2Y_NP200000080ZKgX00@000000:Vmj000000000000P2Y_NP010000000ZKgX0000000000020:Vm
j0030000002Y_NP000000080000000<0ZKgX0000002Y_NP00P0000001@0/5H40000003PQR@0h8HT0
000000<0ejj^0P0000020?;1W@030000003V`K0000000080g[>/0P0000020?G8WP030000003Z`jd0
000000<0hKjd00D000000<:CYP32TjH0`Y>V000000020<NS]0030000002LP[H000000080000000<0
_HJJ0000000000000P3UXXP4000000050?k6O`00000000000000003odhX00P000000103leY/00000
0000003hkZ@2000000040=KHfP000000bLkN0<W>gP80000000D0//[/0000002ja^<000000;SIl@02
000000060;kAj000000000000000002c^Mh000000P2d^M`2000000070;FohP00000000000000002/
]n4000000:k3j@03000000030:K1k@000000000000<0000000D0]/o]00000000000000000:o7k005
0000000409Vbj@000000]/?T0;K3i080000000D0^<SV000000000000000009n`h`02000000040::m
k000000000000:k:kP<0000000@0ZKKS0000002Z/ml0Z[?O0P000000102_^n<000000:noiP2__nH2
000000070:Znj0000000]L;T0000002e`^@000000;C1h`03000000040:VYe`000000Z[;N0:ZbgP80
00001P3oool00`000000oooo0?ooo`0;0?ooo`004@3oool00`000000oooo0?ooo`0/0?ooo`<00000
0`3oool4000000070:Vmj000000000000000002Y_NP000000:Vmj003000000040:Vmj0000000ZKgX
0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0040000002Y_NP0000000000080ZKgX
2000000203PQR@060000003G[Zh0ejj^0000003M[:@000000P3b`Id200000080g[>/00L000000=n_
YP000000mLRN0000003mfI`0000000<0hKjd0P0000030<:CYP0300000037Xk@0aj>d0080000000<0
VWV^0000000000000P0000000`2hQId000000>FRR004000000030?k6O`00000000000080000000@0
nLbJ000000000000o>JF0P0000001`3blk`00000000000000000bLkN00000039dN40100000000`2h
fO4000000;OCkP0200000080/kkR00<000000;>igP0000000P0000001@2k`n0000000000002faNH0
00000080[;OQ0P0000020;;3iP80000000@0X;;U0000002V`>`0Y/3/0P0000001P2fbNT000000000
00000000[;?N00000080TJWV1@0000000`2ka>800000000000020;Nlg@D0000000D0[<7Y00000000
0000Z;cW000000020:Vfh`<0000000<0[kOO0000002_^n<00`0000000`2Y_NP00000000000020000
0080]L;T0P0000020;:ef`030000002YZML000000080000000<0/kOL0000000000001@3oool00`00
0000oooo0?ooo`0;0?ooo`004@3oool2000002X0oooo0`0000070?ooo`030000002Y_NP000000080
000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0
000000<0ZKgX0000000000000`0000001P2Y_NP00000000000000000ZKgX00000080ZKgX10000000
300h8HT000000:ilW@000000ejj^0000003M[:@000000?;1W@000000n<^M00000080g[>/00H00000
0=n_YP000000mLRN0000003mfI`2000000040>6n]0000000akG800000080`Y>V00H000000?39Z`00
000000000;fR_@00000209Yi[P8000000P2hQId00`000000iJ:800000003000000030?k6O`000000
om9k00<0000000D0o=JK00000000000000000?;c_002000000080<o9e@00000000000<WAh@000000
b=WV0000002Zc_<2000000040;OCkP000000]<CW00000080/kkR0P0000001`2c`N@000000;_3h000
0000^n;c0000002faNH00`0000001`2f_]l00000000000000000];gQ0000002P/^D00`0000000`2_
`^P00000000000020;>ff`030000002//mh000000080000000<0UjoW0000002P]nP00`0000001`2m
`mh000000;Nlg@000000][kP0000002[]n800`0000000`2ca^P0000000000003000000040:Bfi@00
0000[kOO0:ngg`80000000L0]<OY00000000000000000:Vmj0000000Z[kX00<0000000@0]<7T0000
002b]M/0/[GK0P0000001@2a[]D000000;>gg0000000_lcT008000000`3oool2000000d0oooo000A
0?ooo`030000003oool0oooo02H0oooo0`00000;0?ooo`030000002Y_NP0ZKgX00@000000P2Y_NP4
00000080ZKgX0P0000020:Vmj0040000002Y_NP0000000000080ZKgX00@000000:Vmj00000000000
0P2Y_NP00`000000ZKgX00000002000000030:Vmj00000000000008000000P2^O9d010000000ejj^
0000000000020?;1W@050000003hbid000000000003N/j`00P0000020?G8WPD000000P37]LP01P00
0000`Y>V0<:CYP000000l<V[00000080_J:m00<0000009Yi[P2JNJh00P0000020;R5W@80000000<0
nkYg0000000000000`0000001@3odW/00000000000000000o=JK00D0000000<0clWE0000003Dd]H0
0P0000020<SIiP80000000D0/Lo_00000000000000000;C4i`03000000030:joi`000000/l7T00H0
00000P2[`^X2000000040;k<i@000000];gQ0;Bmh@80000000H0[;WS00000000000000000;>mhP00
00020;>ff`80000000<0[KSQ0000000000000`0000020:?0kP040000002m`mh0000000000080][kP
0P0000001`2ec^`00000000000000000[LC[0000002R^^T01P0000001@2ec^d000000000002^aN/0
00000080ZKgX0P0000000`2Z_^P0000000000004000000030:Vbg`000000/JkE008000000P2oc>@2
000000@0oooo00<000000?ooo`3oool02`3oool000P0oooo1@0000030?ooo`030000003oool0oooo
02@0oooo0`00000?0?ooo`80000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj0030000
00040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP000000000
000300000080ZKgX0`0000000`0l9Xd00000000000030:ilW@030000003M[:@000000080l/6M0P00
00020?O@X`080000003O[jH000000?G8WP000000oMVL0000002<YNH2000000<0akG80P0000020?39
Z`040000002mX[d0_J:m00000080VWV^0P0000020;R5W@80000000<0nkYg0000000000001@000000
0`3ic9X000000000000300000080_/CN00<000000=CBeP0000000P3JiMd2000000030<GIj0000000
00000080]<_[0P0000000`2^`nT000000000000400000080]=[c1@0000000`2R_nh000000;k<i@03
000000030;30i@00000000000080/l[[00<000000;>mhP0000000P0000001@2d^ml000000000002]
d_<000000080Ul;e1@0000001@2iaN<00000000000000000]=Ga0080000000@0[/c_000000000000
[LC[0P000000102L^N`0000009k1l@2N`O43000000030:o<k`000000000000<0000000D0ZKgX0000
00000000ZKkX000000020:Vmj0D0000000H0`N;`00000000000000000:o6j`00000B0?ooo`002@3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0240oooo0`00000C0?ooo`030000
002Y_NP000000080000000<0ZKgX0000002Y_NP00`0000000`2Y_NP0000000000003000000030:Vm
j0000000000000<0000000<0ZKgX0000000000000P2Y_NP00`000000ZKgX00000002000000050:Vm
j0000000000003`VS@000000102^O9d01`000000gJbT0000003b`Id000000?S;W@0000000P3gd:<0
1P000000gjnV0000003eb9h000000?gIW0T0000000@0l<V[00000000000000000P2mX[d010000000
VWV^0000000000020;R5W@80000000<0nkYg0000000000002@0000001@2Y_^T000000;k4gP000000
`m7T0080000000<0f^GM0000003Ci^@00P0000001@31f>/00000000000000000[/W^0080000000@0
Z/;[0000002^an`000000P30eNX2000000030;?;k0000000TJcY00D0000000D0/lc]000000000000
00000:[@m005000000050:^oj000000000000000002cfo@01@000000102=__L0000009^ol@2K_o42
000000050;?Lm@00000000000000002^d_<01@0000000`2V`^d0000000000003000000070:C3k`00
000000000000002Wb_8000000:S3k@03000000030:Vnj0000000ZKkX00<0000000<0V<Gf00000000
00000`0000000`2[g?T000000000000300000140oooo000:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool07`3oool2000001L0oooo00<000000:Vmj02Y_NP0100000020:Vmj0800000
00@0ZKgX0000002Y_NP0ZKgX0P0000020:Vmj0040000002Y_NP0000000000080ZKgX00@000000:Vm
j000000000000P2Y_NP00`000000ZKgX00000003000000@0[WbM0P0000020?;1W@070000003hbid0
00000?O@X`000000m=Zc000000020?G8WP80000000@0T:7P00000023X>H0Pj3V100000001@3`bJ/0
00000000002T_N/000000080_J:m00@0000009Yi[P00000000000`2hQId010000000nkYg0000003h
_X/6000000040>gfZP000000ZKkY0:Vnj@80000000<0`m7T00000033kO000P0000000`3Ci^@00000
0<[Wj`02000000070;OGl@00000000000000002Vao0000000:[2j`03000000030<3EjP0000000000
00@0000000@0W[[/0000002Ua_00YLK`0P0000020:;FnP80000000@0W/gh0000002Vb?80Y/Sb0P00
00001@2Ie_`00000000000000000[=Sg00P0000000@0RlWl000000000000[=Wg0`0000000`2Xbo80
00000:O9l@03000000030:;0kP000000Xkg[00<0000000<0Z<_b0000000000000`0000000`2R`Nh0
000000000003000000050:O;lP00000000000000002Pb?@01@0000030?ooo`030000003oool0oooo
0100oooo000;0?ooo`030000003oool0oooo0080oooo0P00000M0?ooo`<000006P3oool200000003
0:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`000000102Y_NP000000:Vmj02Y_NP20000
00030:Vmj0000000000000<0000000<0ZKgX0000000000000`000000102Y_NP00000000000000003
0:ilW@030000003=U9T000000080l/6M00@000000?S;W@00000000000P3df[<90000000409>[iP00
0000UkS^09NhkP@0000000<0Xkk/0000000000000P0000000`2IMj`000000;R5W@020;R5W@040000
003k^WL000000?RnR`D0000000<0kOJZ0000000000000P0000000`2Xbo8000000000000200000003
0;c]m000000000000080000000<0_NWc0000000000000P2YeoL400000080[]3b1@00000209c7mPT0
000000<0VM7k0000000000001P0000001P2Hd_`00000000000000000Z<_b00000080X<Sd20000000
0`2Xbo80000000000003000000030:35l`000000000000<0000000D0Z<_b00000000000000000:O:
lP050000000409bol@000000Z<_b0:S;lP80000000@0Yl_b0000000000000000203oool00`000000
oooo0?ooo`0@0?ooo`00203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool06@3oool3000001h0oooo00<000000:Vmj00000000P0000000`2Y_NP000000000000300000003
0:Vmj0000000000000<0000000<0ZKgX0000000000000P2Y_NP00`000000ZKgX0000000200000003
0:Vmj0000000ZKgX00@0000000H0?2J=0000002^O9d0[WbM0000003=U9T3000000040?S;W@000000
mm2S00000080m=Zc10000000102GZn@0000009FVh@2EY^450000000309S1m0000000000000<00000
00D0PX?<0000002IMj`0VGN/000000030;R5WA00000000<0U^Cm0000000000000P0000000`2Wk?T0
00000000000500000003093EoP000000000000D0000000<0VKO]0000001e/?L030000000102GaoP0
00000000002KcOT50000000309o2l@000000000000@0000000D0X/Oc000000000000W;[]00000002
09k1l@80000000<0Z<[a0000000000000`0000000`2L^Nd0000000000003000000060:S:lP000000
00000000002X_NP000000P2L^N`5000000030:S;lP000000000000`0oooo00<000000?ooo`3oool0
3`3oool000P0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo01H0oooo
0`00000R0?ooo`030000002Y_NP0ZKgX0080000000@0ZKgX0000002Y_NP0ZKgX0P000000102Y_NP0
00000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj08000000P2Y_NP400000080ZKgX0P000000
200l9Xd000000:ilW@2^O9d000000<fDV@000000nL>>1@0000000`3df[<000000:Vji@0700000004
09b/hP000000XKOX0:6gj080000000@0VK_`0000002=^?<0SKSc0P0000000`22Pl`0000009Ug[002
00000080^8FM00<000000?C]_0000000400000000`2AiO/000000000000<00000080ZKgX1@000000
1@2E_O8000000000002U_>T000000080W;_^1@0000001@2Qb?@000000000002U_>T000000080W;[]
0P0000020:C3k`D0000000<0Y[cY0000000000000`0000001@2T`nl000000000002Y_NP000000080
YkcY0P000000102S_>/000000:?3k`2S`nl2000000040:Vmj0000000Z;gX0:Rmj0<0000000<0Xk_[
0000000000000`00000>0?ooo`030000003oool0oooo00l0oooo00090?ooo`<00000103oool00`00
0000oooo0?ooo`0C0?ooo`<000009P3oool2000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000
000000000`0000000`2Y_NP0000000000003000000070:Vmj000000000000000002Y_NP000000:Vm
j003000000060:Vmj0000000?2J=0000002^O9d000000P3=U9T010000000nL>>0000003oeGd20000
00080:Vmj000000000000000002U/n<0000009NTgP000002096Sh@D0000000<0[KgU000000000000
1@0000000`22Pl`0000009Ug[002000000050;R5W@000000m>fl0000003h_X/01@0000000`2L_Nl0
00000000000;00000080XmSj0P0000001`2NdOT00000000000000000ZKgX0000002Y_NP00`000000
0`2Y_NP000000:>kjP03000000030:Vmj0000000YKcY00<0000000<0Y;g/0000000000000`000000
0`2Y_NP0000000000003000000070:>mj`00000000000000002Y_NP000000:Vmj003000000030:Rm
j0000000Xkc[00<0000000<0ZKgX0000002Y_NP00`0000000`2X_NP0000000000003000000030:Vm
j0000000000000<0000000@0Z;gX00000000000000004`3oool00`000000oooo0?ooo`0?0?ooo`00
3`3oool00`000000oooo0?ooo`0A0?ooo`<00000:`3oool4000000030:Vmj000000000000080ZKgX
00@000000:Vmj000000000000P2Y_NP010000000ZKgX0000000000020:Vmj0040000002Y_NP00000
00000080ZKgX00T000000:Vmj0000000?2J=0000002^O9d000000<fDV@0000000P3i`hh500000080
Y[cY1`0000000`2H[>D000000:Ngi003000000040;;3i`000000WK7V09faiPD000000P2IMj`20000
00030?C]_0000000000000@0000000@0WKOZ000000000000Y;o]1@0000000`2Gd_`0000000000002
000000050;3Sn000000000000000002VdoL00P000000102Y_NP000000:Vmj02Y_NP2000000030:Vm
j0000000000000<0000000<0ZKgX0000000000000`0000001P2W_>T00000000000000000ZKgX0000
0080ZKgX0P000000102Y_NP000000:Nmj02W_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0
ZKgX0000000000000`0000000`2Y_NP0000000000003000000070:Vmj000000000000000002Y_NP0
00000:Vmj003000000030:Vmj0000000ZKgX00<000005P3oool00`000000oooo0?ooo`0?0?ooo`00
3`3oool2000000l0oooo0`00000^0?ooo`030000002Y_NP0ZKgX0080000000@0ZKgX0000002Y_NP0
ZKgX0P0000000`2Y_NP0000000000003000000030:Vmj0000000000000<0000000<0ZKgX00000000
0000100000002@0l9Xd000000:ilW@000000cIBI0000003i`hh000000?oEO@02000000080:Vmj000
000000000000002K]N/0000009N_i`00000209RZh`040000002H[>D0000000000080[<W_00<00000
0;;3i`0000000P0000000`2R]NH000000:2hj@030000000409Ug[000000000000?C]_080000000<0
kKjQ0000000000000P0000001@2T_>X000000000002[`^X000000080Y<Ka0`0000020;Sbl`H00000
00<0ZKgX0000000000000`0000000`2Y_NP00000000000020:Vmj0040000002Y_NP0000000000080
ZKgX00@000000:Vmj000000000000P2Y_NP00`000000ZKgX00000002000000030:Vmj00000000000
00<0000000<0ZKgX0000000000000`0000001@2Y_NP000000000002Y_NP000000080ZKgX0P000000
102Y_NP000000:Vmj02Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0ZKgX000000000000
0`00000I0?ooo`030000003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo00`0oooo0P00
000b0?ooo`80000000<0ZKgX0000000000000`0000000`2Y_NP00000000000020:Vmj0040000002Y
_NP0000000000080ZKgX00<000000:Vmj00000000P0000000`2Y_NP000000:Vmj0030000000803`V
S@00000000000<fDV@000000nL>>0000003oeGd300000080ZKcW2@0000000`2L__00000000000003
000000030:Fok0000000000000@0000000<001BS0000000000000`0000000`2nSZ@000000>fnX@05
000000030:O5k`000000Zl;Z00<0000000<0/]Gb0000000000000`000000102Y_NP000000:Vmj02Y
_NP2000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP0
000000000003000000030:Vmj0000000000000<0000000L0ZKgX00000000000000000:Vmj0000000
ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000
000000<0000000<0ZKgX0000000000000`0000001@2Y_NP000000000003oool0000001`0oooo00<0
00000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool02@3oool3000003H0oooo00D00000
0:Vmj02Y_NP000000:Vmj00200000080ZKgX00@000000:Vmj000000000000P2Y_NP010000000ZKgX
0000000000020:Vmj0@0000000<0ZKgX0000001?>9H00P0000020<fDV@030000003i`hh000000080
000000P0ZKgX00000000000000000:Nhi@000000UJcV00000080SZcZ100000020:C2kP@000000P2J
^Nd020000000YKcZ00000000000001BS0000002HMZX000000P2nSZ@00`000000kKjQ000000080000
0080/M7a1@0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0000000<0ZKgX0000
000000000`0000001@2Y_NP000000000002Y_NP000000080ZKgX0P000000102Y_NP000000:Vmj02Y
_NP2000000040:Vmj0000000ZKgX0:Vmj080000000<0ZKgX0000000000000`0000000`2Y_NP00000
00000003000000070:Vmj000000000000000002Y_NP000000:Vmj003000000030:Vmj0000000ZKgX
00<00000103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo000?0?ooo`03
0000003oool0oooo00H0oooo0`00000j0?ooo`@0000000<0ZKgX0000000000000`0000000`2Y_NP0
000000000003000000070:Vmj000000000000000002Y_NP000000:Vmj00300000080CcRF00D00000
0<fDV@3=U9T000000?W3SP05000000030:Rmj@000000YkSU00D0000000<0U[7Y0000002Q_>d00`00
00000`2WaNl0000009jlk@05000000060:Fnk000000000000000002HMZX000000P2nSZ@010000000
kKjQ00000000000209;=o0T0000000<0ZKgX0000000000000`0000001`2Y_NP00000000000000000
ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000ZKgX00<0000000<0
ZKgX0000000000000`0000000`2Y_NP0000000000003000000050:Vmj000000000000:Vmj0000000
0P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj080000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y
_NP0000000000003000000P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?oo
o`003`3oool00`000000oooo0?ooo`030?ooo`<00000?P3oool00`000000ZKgX0000000200000003
0:Vmj0000000ZKgX008000000P2Y_NP010000000ZKgX0000000000020:Vmj0040000002Y_NP00000
00000080ZKgX00H0000004lhUP1?>9H000000<fDV@0000020?W3SP8000000P2Y_NP4000000040:6d
iP000000VJkU09V^i@@000000P2Ta_4400000080WKS[00<0000009^hk00000001000000209QfZP04
0000002nSZ@000000>fnX@@0000000@0X;?V000000000000/Lk_0`0000000`2gbNL0000000000002
0:Vmj0040000002Y_NP0000000000080ZKgX00@000000:Vmj000000000000P2Y_NP4000000030:Vm
j0000000000000<0000000L0ZKgX00000000000000000:Vmj0000000ZKgX00<0000000<0ZKgX0000
002Y_NP00`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000000000<0000000<0ZKgX0000
000000000`0000000`2Y_NP000000000000=0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool03P3oool000h0oooo0`000000103oool000000000000000120?ooo`030000002Y_NP0ZKgX
00@0000000<0ZKgX0000000000000`0000000`2Y_NP00000000000030000000;0:Vmj00000000000
0000002Y_NP0000004lhUP000000cIBI0000003i`hh01@0000000`2Y_>L000000::hj00500000003
09n_h`000000WkOY00<0000000<0Xl3]0000002P_Nd01@0000000`2O]nT000000000000300000003
09QfZP000000_XjT00<0000000@0_LOR00000000000000000P2b`>D00`000000b]oX0<[Oj0020000
00030;36jP000000000000<0000000<0ZKgX0000000000000`0000001`2Y_NP00000000000000000
ZKgX0000002Y_NP00P0000020:Vmj0040000002Y_NP0000000000080ZKgX00@000000:Vmj0000000
00000P2Y_NP400000080ZKgX100000020:Vmj080000000<0ZKgX0000002Y_NP00`0000000`2Y_NP0
00000:Vmj00300000100oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`00
3P3oool4000004H0oooo0P0000000`2Y_NP000000:Vmj003000000030:Vmj0000000ZKgX00<00000
00<0ZKgX0000002Y_NP00P0000020:Vmj0080000002Y_NP0000004lhUP000000cIBI0000003i`hh2
00000080ZKgX1000000209j`i0030000002L[^<0000000<000000P2]^n@400000080W:kS00@00000
09n_h`00000000000P2/_>D30000000309QfZP000000_XjT00@000000P2cb^/00`000000//3U0000
0003000000050;WIl@00000000000:Vmj00000000P2Y_NP2000000040:Vmj0000000ZKgX0:Vmj080
000000@0ZKgX0000002Y_NP0ZKgX0P0000000`2Y_NP0000000000003000000030:Vmj00000000000
00<0000000L0ZKgX00000000000000000:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`00
00000`2Y_NP000000:Vmj00200000080ZKgX1000000D0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool03P3oool000h0oooo0P0000190?ooo`040000002Y_NP0000000000080ZKgX1000
00020:Vmj0@0000000<0ZKgX000000000000100000001@1?>9H000000<fDV@000000nL>>00@00000
00<0Z;gX0000002W^>D01@0000000`2L[n@000000:Vdh@03000000030;>lh0000000Xk7R00D00000
00@0Z;OT0000002/_>D0[;cU0`00000209QfZP040000003]_Z4000000:c:k`H0000000D0/n;g0000
0000000000000:Vmj005000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`000000
1@2Y_NP000000000002Y_NP000000080ZKgX0P000000102Y_NP000000:Vmj02Y_NP2000000040:Vm
j0000000ZKgX0:Vmj080000000<0ZKgX0000000000000`0000000`2Y_NP000000000000300000004
0:Vmj00000000000000001T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0>0?oo
o`00403oool00`000000oooo0?ooo`170?ooo`030000002Y_NP000000080000000<0ZKgX0000002Y
_NP00`0000000`2Y_NP000000:Vmj003000000030:Vmj0000000ZKgX008000000P1?>9H200000004
0?W3SP000000ZKgX0:Vmj0@000000P2Q]^L00`000000WJoT0000000300000080[kkT00@000000;>l
h000000000000P2Q]NH00`000000W;;X00000004000000030;?4i`000000000000H000000P2VeoT2
000000030:kLm`00000000000080[/7X0P000000102Y_NP000000:Vmj02Y_NP2000000040:Vmj000
0000ZKgX0:Vmj080000000<0ZKgX0000002Y_NP00`0000000`2Y_NP0000000000003000000030:Vm
j0000000000000<0000000<0ZKgX0000000000000`0000001@2Y_NP000000000002Y_NP000000080
ZKgX0P000000102Y_NP000000:Vmj02Y_NP2000001`0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0>0?ooo`004@3oool00`000000oooo0?ooo`170?ooo`80000000<0ZKgX0000002Y
_NP00P0000020:Vmj0@000000P2Y_NP4000000040:Vmj0000000CcRF04lhUP80000000L0nL>>0000
0000000000000:Vmj0000000X[_[00D0000000<0WJoT0000002N/^L01@0000000`2^^n<000000000
00030000000309K5m`000000000000<0000000@0Y[o[0000002V]><0Y[CS0P0000001@2Xd?@00000
000000000000[mOe0080000000L0]LWY00000000000000000:c0j@000000ZKgX00<0000000<0ZKgX
0000000000000`0000000`2Y_NP000000000000200000080ZKgX0P000000102Y_NP000000:Vmj02Y
_NP2000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000000
0003000000030:Vmj0000000000000<000007`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00h0oooo000B0?ooo`030000003oool0oooo04P0oooo0`0000001`2Y_NP0000000000000
0000ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj0040000000304lhUP000000nL>>00800000
00<0ZKgX0000000000000P00000209^ik@040000002I/nX0000009f_i08000000P2T]^D010000000
[;_T0000000000020:bki@@000000P2H`?<00`000000X/?`00000004000000040:K5l00000000000
0;3BlP<0000000<0]M3^0000000000000P2_a^/4000000070:Vmj000000000000000002Y_NP00000
0:Vmj003000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP00000
0000000200000080ZKgX100000001`2Y_NP00000000000000000ZKgX0000002Y_NP00`00000U0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool03@3oool001<0oooo0P0000180?ooo`03
0000002Y_NP000000080000000<0ZKgX0000000000000`0000000`2Y_NP000000000000200000080
ZKgX100000001`3i`hh00000000000000000ZKgX0000002Y_NP01`0000020:6bi0050000002T]^D0
00000000002[]=l00`0000000`2g_]l000000:?1k`050000000309j^h`000000000000<0000000<0
[l_^0000000000000P2deo82000000070:k=k`00000000000000002Y_NP000000:Vmj00200000080
ZKgX100000020:Vmj0@0000000<0ZKgX0000000000000`0000001`2Y_NP00000000000000000ZKgX
0000002Y_NP00`0000000`2Y_NP000000:Vmj00200000080ZKgX00@000000:Vmj00000000000:03o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo000E0?ooo`030000003oool0
oooo04H0oooo00<000000:Vmj02Y_NP00P000000102Y_NP000000:Vmj02Y_NP2000000030:Vmj000
0000ZKgX00<0000000<0ZKgX0000002Y_NP00`0000000`2Y_NP000000000000200000080ZKcW2@00
00000`2X^>D00000000000020;:hgP040000002g_]l0000000000080Y[;Q00H0000009f^h`000000
00000:Ngi00000020:boj0T0000000<0ZKgX0000000000000`0000001`2Y_NP00000000000000000
ZKgX0000002Y_NP00`0000000`2Y_NP000000:Vmj00200000080ZKgX00D000000:Vmj00000000000
0:Vmj005000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`00000[0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool03@3oool001H0oooo00<000000?ooo`3oool0AP3o
ool2000000030:Vmj0000000ZKgX00<0000000<0ZKgX0000000000000`0000000`2Y_NP000000000
000200000080ZKgX0P0000000`2Y_NP000000:Vmj003000000040:Rhi@000000Tj_W00000080SJc[
10000000102Q^>T000000;:hgP2b^=h2000000030;bnf`000000000000<0000000<0W;;W0000002W
]n@0100000001`2ef_<00000000000000000[L3X0000002Y_NP00P0000020:Vmj0040000002Y_NP0
000000000080ZKgX00D000000:Vmj000000000000:Vmj005000000030:Vmj0000000000000<00000
00<0ZKgX0000000000000P2Y_NP01P000000ZKgX000000000000ZKgX00000080ZKgX0P00000a0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool001L0oooo00<000000?ooo`3o
ool0A`3oool300000080ZKgX0P000000102Y_NP000000:Vmj02Y_NP2000000030:Vmj0000000ZKgX
00<0000000<0ZKgX0000002Y_NP00`0000000`2X_NP000000:Rhi@050000000309FajP000000W[_]
00D0000000<0^<;R0000000000000P2h_]h00`000000YKGT00000005000000030:oHm@0000000000
0080]LWY100000000`2Y_NP0000000000003000000030:Vmj0000000000000<0000000<0ZKgX0000
000000000P2Y_NP01P000000ZKgX000000000000ZKgX00000080ZKgX0P000000102Y_NP000000:Vm
j02Y_NP2000000030:Vmj0000000000000<00000=03oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00d0oooo000H0?ooo`800000A`3oool00`000000ZKgX00000002000000030:Vmj000
0000000000<0000000<0ZKgX0000000000000P0000020:Vmj0@000000P2Y_NP4000000040::diP00
0000V:gU09R]i@@0000000<0U/?f0000000000000`000000102b`ND000000;RngP2h_]h200000003
0:;7l`00000000000080Wlgh0P0000001`2bcNh00000000000000000[lK[0000002[_nP00P000002
0:Vmj0060000002Y_NP000000000002Y_NP000000P2Y_NP2000000030:Vmj0000000000000<00000
00<0ZKgX0000000000000`0000000`2Y_NP0000000000003000000030:Vmj0000000000003T0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`006P3oool00`000000oooo0?oo
o`150?ooo`80000000D0ZKgX000000000000ZKgX000000020:Vmj080000000<0ZKgX0000002Y_NP0
0`0000000`2Y_NP000000:Vmj003000000030:Vli`000000000000D0000000<0WZoS0000002N^>/0
0P00000209>nm0040000002=^_@000000;;1i@<0000000@0]lGU000000000000ZL[`0`000000102X
bo8000000000002]bnl5000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`000000
1@2Y_NP000000000002Y_NP000000080ZKgX0P000000102Y_NP000000:Vmj02Y_NP2000000030:Vm
j0000000ZKgX00<00000?03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo
000K0?ooo`030000003oool0oooo04H0oooo00<000000:Vmj0000000100000000`2Y_NP000000000
0003000000030:Vmj00000000000008000000P2Y_NP2000000040:Rhi0000000WZoS00000080W:kS
100000000`2/_>H000000000000500000080[[gU0P0000000`2lb>@00000000000020:o>l0800000
00<0Z<Wa0000000000000P2Y_NP01P000000ZKgX000000000000ZKgX00000080ZKgX0P000000102Y
_NP000000:Vmj02Y_NP2000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`000000
0`2Y_NP000000000000200000400oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=
0?ooo`00703oool00`000000oooo0?ooo`160?ooo`050000002Y_NP0ZKgX0000002Y_NP00P000000
102Y_NP000000:Vmj02Y_NP2000000030:Vmj0000000ZKgX00<0000000<0Z;gX0000002X^>@01@00
00000`2L/>H000000:VehP0200000080/l;U1`000000102d`^@0000000000032f>X3000000040:k<
l000000000000:Vmj0D0000000<0ZKgX0000000000000`0000000`2Y_NP000000000000300000005
0:Vmj000000000000:Vmj00000000P2Y_NP2000000030:Vmj0000000ZKgX00<00000A@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo000M0?ooo`800000A`3oool400000003
0:Vmj0000000000000<0000000<0ZKgX0000000000000`0000000`2Y_NP000000000000200000004
0::fi`000000WK3U09f`i@@0000000P0/<_^00000000000000000:Noj`000000VK7X00000080U;;/
0P0000000`2ifo400000000000020;cFk@80000000<0[L3X0000000000000P2Y_NP01P000000ZKgX
000000000000ZKgX00000080ZKgX0P0000000`2Y_NP000000:Vmj003000000030:Vmj00000000000
00<0000000<0ZKgX0000000000000P0000180?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0303oool001l0oooo00<000000?ooo`3oool0A@3oool010000000ZKgX0000000000020:Vm
j0050000002Y_NP000000000002Y_NP01@0000000`2Y_>L00000000000050000000309bik0000000
000000<0000000<0YLOa000000000000200000001@2ffO800000000000000000]LSX0080000000<0
ZkoX0000000000000`0000000`2Y_NP0000000000003000000030:Vmj00000000000008000000P2Y
_NP2000000030:Vmj0000000ZKgX00<00000C@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00`0oooo000P0?ooo`030000003oool0oooo04D0oooo00<000000:Vmj000000010000000
0`2Y_NP00000000000020:Vmj0060000002Y_NP000000000002X^>@000000P2N[n<4000000040:Bj
j@000000Xko]0:>ok@80000000<0W[W[0000000000000`0000000`2Qao@000000000000200000080
/lg]0P0000000`2_a^/00000000000020:Vmj0060000002Y_NP000000000002Y_NP000000P2Y_NP2
000000030:Vmj0000000000000<0000000<0ZKgX0000000000000P00001A0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0303oool00240oooo00<000000?ooo`3oool0A@3oool20000
00030:Vmj0000000ZKgX0080000000<0ZKgX0000000000000`0000000`2X_NP00000000000030000
00030:BbhP000000Y;GU00D0000000D0Z[OR000000000000YK_Y000000020:;1k`80000000<0Z<Wa
0000000000001P0000000`2Y_NP0000000000003000000030:Vmj0000000000000<0000000D0ZKgX
000000000000ZKgX000000020:Vmj0800000E@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00`0oooo000R0?ooo`800000A`3oool3000000070:Vmj000000000000000002Y_NP00000
0:Vmj002000000060::jjP000000X[KV0::fiP000000Y;;R0P000000102X^>@000000:Vcg`2Y/ml2
000000030;2jh@000000000000<0000000@0Z/?/000000000000Z/W`0`0000000`2Y_NP000000:Vm
j00200000080ZKgX00H000000:Vmj000000000000:Vmj00000020:Vmj080000000<0ZKgX00000000
00000`00001H0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool002@0oooo
00<000000?ooo`3oool0A@3oool300000080ZKgX100000000`2Y_>L0000000000005000000030:Nl
j0000000000000<0000000D0[[KO000000000000]LOX000000020:boj080000000<0/<CY00000000
00000P2/_nP4000000030:Vmj0000000000000<0000000<0ZKgX0000000000000`0000000`2Y_NP0
00000000001N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool002D0oooo
00<000000?ooo`3oool0A03oool00`000000ZKgX00000002000000030:Vmj0000000ZKgX00800000
0P2X]n@00`000000WZoS00000003000000040::kj`000000X[OW0::gi`80000000<0//c]00000000
00000`000000102``NH000000000002fb>P3000000030:^oj0000000ZKgX0080000000@0ZKgX0000
002Y_NP0ZKgX0P0000000`2Y_NP000000000000300000640oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0;0?ooo`009P3oool00`000000oooo0?ooo`140?ooo`80000000<0ZKgX0000
000000000P0000000`2X_NP0000000000003000000030:BbhP000000Y;KV00D0000000@0VKob0000
00000000[L__1@0000000`2dcNd00000000000020:o6j`@0000000<0ZKgX0000000000000`000000
0`2Y_NP000000000001V0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
02L0oooo0P0000160?ooo`040000002Y_NP000000:Vmj0<0000000<0X[_[0000002R]^L010000002
0:Vmj0@0000000<0X/7_0000000000000P2Xb_44000000070:k<k`00000000000000002Y_NP00000
0:Vmj002000000030:Vmj0000000000000<00000J@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo000Y0?ooo`030000003oool0oooo04@0oooo0`0000020:Vmj0@0000000<0
V[W^0000002X_NP00`0000000`2Y_NP000000:BljP02000000050:W3k000000000000000002Yb_40
100000020:Vmj0@0000000<0ZKgX000000000000K`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00/0oooo000Z0?ooo`030000003oool0oooo04@0oooo100000000`2Y_NP000000000
000400000080Z;gX100000001@2Z_NP00000000000000000/<GY0080000000<0ZkkX0000002Y_NP0
0`0000000`2Y_NP000000000000200000740oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0;0?ooo`00:`3oool00`000000oooo0?ooo`140?ooo`070000002Y_NP000000000002Y_>L0
000009^hk005000000030:Rlj00000000000008000000P2__nH2000000030;K7i`00000000000080
00000P2Y_NP2000007H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`00
;03oool2000004D0oooo00<000000:Vmj00000000`00000209jUfP070000002M[^<000000000002Y
_NP000000:Vnj003000000040;G=k000000000000;36j`D00000N@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00/0oooo000^0?ooo`030000003oool0oooo04<0oooo00@000000:Rm
j0000000Z;;O1@0000000`2Z/]l000000000000200000080Z<_b0P0000000`2_c>l000000000001o
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool002l0oooo00<000000?oo
o`3oool0@`3oool40000000309b^i0000000Z:[H0080000000<0]]G`0000000000001P0000210?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00300oooo00<000000?ooo`3o
ool0@`3oool6000000030;?Km000000000000080[]Cd0P0000260?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02P3oool00340oooo0P0000140?ooo`030000002=Z>L0000000L00000
R@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo000c0?ooo`030000003o
ool0oooo0480oooo00@000000:>`h@0000000000S`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00X0oooo000d0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo000e0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00X0oooo000f0?ooo`800000@@3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool003P0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool003T0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool003X0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool003/0oooo0P00000l
0?ooo`030000003oool0oooo09@0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`00?@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo09@0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`00?P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo09D0oooo00@00000
0?ooo`3oool000002`3oool003l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0000000/0oooo00100?ooo`800000=`3oool00`000000oooo0?ooo`2F0?oo
o`040000003oool0oooo000000X0oooo00120?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0000000:0?ooo`00@`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo09P0oooo0P00000:0?ooo`00A03oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo09P0oooo0`00000:0?ooo`00A@3oool200000340oooo00<000000?ooo`3oool0U03o
ool4000000d0oooo00170?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4
00000140oooo00180?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0S@3oool30000
01D0oooo00190?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0R@3oool4000001P0
oooo001:0?ooo`800000;03oool00`000000oooo0?ooo`250?ooo`@00000703oool004`0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`210?ooo`@00000803oool004d0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`1m0?ooo`@00000903oool004h0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`1i0?ooo`@00000:03oool004l0oooo0P00000W0?ooo`03
0000003oool0oooo07D0oooo1000000/0?ooo`00D@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo0780oooo0`00000`0?ooo`00DP3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo06h0oooo1000000c0?ooo`00D`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo06X0oooo1000000g0?ooo`00E03oool200000280oooo00<000000?ooo`3oool0IP3oool40000
03/0oooo001F0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0HP3oool4000003l0
oooo001G0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0GP3oool4000004<0oooo
001H0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0FP3oool4000004L0oooo001I
0?ooo`8000007@3oool00`000000oooo0?ooo`1G0?ooo`<00000B`3oool005/0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`1C0?ooo`@00000CP3oool005`0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`1?0?ooo`@00000DP3oool005d0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`1;0?ooo`@00000EP3oool005h0oooo0P00000H0?ooo`030000003o
ool0oooo04L0oooo1000001J0?ooo`00H03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04<0oooo1000001N0?ooo`00H@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
03l0oooo1000001R0?ooo`00HP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03`0
oooo0`00001V0?ooo`00H`3oool2000001<0oooo00<000000?ooo`3oool0>03oool4000006T0oooo
001U0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=03oool4000006d0oooo001V
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0<03oool400000740oooo001W0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0;@3oool4000007D0oooo001X0?ooo`80
00003@3oool00`000000oooo0?ooo`0Y0?ooo`@00000N@3oool006X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0U0?ooo`@00000O@3oool006/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0R0?ooo`<00000P@3oool006`0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0N0?ooo`@00000Q03oool006d0oooo0P0000080?ooo`030000003oool0oooo
01X0oooo100000280?ooo`00K`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0
oooo1000002<0?ooo`00L03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo
1000002@0?ooo`00L@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo1000
002D0?ooo`00LP3oool2000000<0oooo00<000000?ooo`3oool02P3oool4000009P0oooo001d0?oo
o`040000003oool0oooo000000T0oooo0`00002L0?ooo`00M@3oool00`000000oooo000000050?oo
o`@00000W`3oool007H0oooo0P0000000`3oool000000000000200000:<0oooo001g0?ooo`800000
Y`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool009/0oooo0`0000220?ooo`00
W03oool00`000000oooo0?ooo`210?ooo`00=P3oool3000000<0oooo0`0000030?ooo`<000000P3o
ool01@000000oooo0000003oool000000080oooo0`0000040?ooo`8000000P3oool3000000<0oooo
1@0000020?ooo`<00000203oool3000000@0oooo0`0000020?ooo`D0000000D0oooo000000000000
00000?ooo`0200000080oooo0P0000090?ooo`<000000`3oool300000080oooo0`0000040?ooo`<0
00000`3oool400000080oooo100000070?ooo`<000001@3oool2000000030?ooo`00000000000080
000000@0oooo000000000000oooo0`0000040?ooo`8000000P3oool500000080oooo0`0000020?oo
o`<0000000<0oooo000000000000<@3oool003D0oooo00L000000?ooo`3oool0oooo0000003oool0
000000D0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000380oooo000e0?ooo`060000003oool0
oooo0?ooo`000000oooo1@0000000`3oool000000?ooo`020?ooo`080000003oool000000?ooo`00
0000oooo0000003oool500000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo1@0000020?ooo`<000000P3oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo0000
00H0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0`0?ooo`00=@3oool00`000000oooo00000004
000000<0oooo00<000000?ooo`0000000`3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000030?ooo`040000003oool0oooo000000D0oooo0P0000050?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`<000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00X0oooo0P0000030?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool01`3oool3000000<0oooo00@000000?ooo`3oool000000P3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000001P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0`0?ooo`00=@3o
ool00`000000oooo0?ooo`040?ooo`<000000`3oool300000080oooo0P0000000`3oool000000?oo
o`020?ooo`<000000P3oool400000080oooo0P000000103oool000000000003oool3000000@0oooo
0`0000090?ooo`040000003oool0oooo00000080oooo0`0000020?ooo`<000000`3oool400000080
oooo100000090?ooo`030000003oool0oooo0080oooo100000020?ooo`80000000<0oooo00000000
00000P3oool3000000<0oooo0P0000040?ooo`<000002@3oool00`000000oooo0?ooo`020?ooo`80
000000@0oooo000000000000oooo100000030?ooo`<000000P3oool400000080oooo0`0000040?oo
o`<000000P3oool4000003<0oooo000e0?ooo`050000003oool0oooo0?ooo`0000006P3oool00`00
0000oooo0?ooo`0K0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool02@3oool0
10000000oooo0?ooo`00000L0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
503oool00`000000oooo0?ooo`150?ooo`00=P3oool3000001/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0=0?ooo`@000002P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00X0oooo0`00000K0?ooo`800000203oool5000001@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0n0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0537928, 0.0398483, \
0.00362084, 0.00362084}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-1.24805753933827`\)\), 
        ",", \(BackFocalLength \[Rule] 39.452587761207255`\), 
        ",", \(BackFocalPoint \[Rule] {57.81626618220312`, \
\(-14.804628830614078`\), 0}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-50.`\), \(-50.`\)}\), 
        ",", \(ExitPupilDistance \[Rule] 0\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {19.817114076226126`, \
\(-4.194675000244022`\), 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{0.9631599411418232`, \
\(-0.268929224480493`\), 0}, {0.26892922448049306`, 0.9631599411418234`, 
              0}, {0, 0, 1}}\), ",", \(FieldStopPosition \[Rule] 2\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 2, 
            SurfaceNumber \[Rule] 2, ComponentNumber \[Rule] 1}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 45.76341881553137`\), 
        ",", \(ImagePlaneTilt \[Rule] {0.9631599411418242`, \
\(-0.2689292244804903`\), 0}\), 
        ",", \(ImagePoint \[Rule] {97.20072220245461`, \(-25.801381038879075`\
\), 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[\(BiConvexLens[50, 50, 20]\),
                HoldForm], ",", 
              
              TagBox[\(Boundary[{0, \(-54\), \(-54\)}, {108, 54, 
                    54}, {GraphicDesign \[Rule] Off}]\),
                HoldForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8620987850631842`, 
              10.286236147872614`}, {\(-0.021851514285480263`\), 
              0.8992358849155792`}}\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          
          TagBox[\(Move[
              PointOfRays[{10, 10}], {\(-90.5`\), 
                30.`}, \(-18.33993103355537`\)]\),
            HoldForm]}], ",", \(OpticalMedium \[Rule] Vacuum\), 
        ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"PointSpreadFunction", "\[Rule]", 
              RowBox[{"(", 
                
                TagBox[\(\[SkeletonIndicator]  
                    SurfaceGraphics  \[SkeletonIndicator]\),
                  False,
                  Editable->False], ")"}]}], "}"}]}], 
        ",", \(Plot2D \[Rule] False\), ",", 
        RowBox[{"PointSpreadFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-1.1787570269687162`\), 
                  2.5707507379863888`}, {\(-1.0093112492044565`\), 
                  1.0093112492044565`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(SourceID \[Rule] 1212\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.1385342450167921`\), \
\(-19.264397093419163`\)}, {\(-0.021851514285480256`\), \
\(-1.24805753933827`\)}}\), 
        ",", \(TransverseMagnification \[Rule] \(-1.1385342450167921`\)\), 
        ",", \(WaveFrontID \[Rule] 1\), ",", \(WaveLength \[Rule] 0.532`\)}], 
      "}"}]], "Output",
  CellLabel->"Out[17]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
MTF[sys3D, FindImagePoint->True, FocalFraction->0, NumberOfPoints->128, \
GeometricPointSpreadFunction->True]\
\>", "Input",
  CellLabel->"In[187]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 1.29183 0.0147151 4.97235e-05 [
[.11245 .00222 -12 -9 ]
[.11245 .00222 12 0 ]
[.24163 .00222 -12 -9 ]
[.24163 .00222 12 0 ]
[.37082 .00222 -12 -9 ]
[.37082 .00222 12 0 ]
[.62918 .00222 -9 -9 ]
[.62918 .00222 9 0 ]
[.75837 .00222 -9 -9 ]
[.75837 .00222 9 0 ]
[.88755 .00222 -9 -9 ]
[.88755 .00222 9 0 ]
[.4875 .11416 -24 -4.5 ]
[.4875 .11416 0 4.5 ]
[.4875 .21361 -24 -4.5 ]
[.4875 .21361 0 4.5 ]
[.4875 .31306 -24 -4.5 ]
[.4875 .31306 0 4.5 ]
[.4875 .4125 -24 -4.5 ]
[.4875 .4125 0 4.5 ]
[.4875 .51195 -30 -4.5 ]
[.4875 .51195 0 4.5 ]
[.4875 .6114 -30 -4.5 ]
[.4875 .6114 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11245 .01472 m
.11245 .02097 L
s
[(-0.3)] .11245 .00222 0 1 Mshowa
.24163 .01472 m
.24163 .02097 L
s
[(-0.2)] .24163 .00222 0 1 Mshowa
.37082 .01472 m
.37082 .02097 L
s
[(-0.1)] .37082 .00222 0 1 Mshowa
.62918 .01472 m
.62918 .02097 L
s
[(0.1)] .62918 .00222 0 1 Mshowa
.75837 .01472 m
.75837 .02097 L
s
[(0.2)] .75837 .00222 0 1 Mshowa
.88755 .01472 m
.88755 .02097 L
s
[(0.3)] .88755 .00222 0 1 Mshowa
.125 Mabswid
.13829 .01472 m
.13829 .01847 L
s
.16412 .01472 m
.16412 .01847 L
s
.18996 .01472 m
.18996 .01847 L
s
.2158 .01472 m
.2158 .01847 L
s
.26747 .01472 m
.26747 .01847 L
s
.29331 .01472 m
.29331 .01847 L
s
.31914 .01472 m
.31914 .01847 L
s
.34498 .01472 m
.34498 .01847 L
s
.39665 .01472 m
.39665 .01847 L
s
.42249 .01472 m
.42249 .01847 L
s
.44833 .01472 m
.44833 .01847 L
s
.47416 .01472 m
.47416 .01847 L
s
.52584 .01472 m
.52584 .01847 L
s
.55167 .01472 m
.55167 .01847 L
s
.57751 .01472 m
.57751 .01847 L
s
.60335 .01472 m
.60335 .01847 L
s
.65502 .01472 m
.65502 .01847 L
s
.68086 .01472 m
.68086 .01847 L
s
.70669 .01472 m
.70669 .01847 L
s
.73253 .01472 m
.73253 .01847 L
s
.7842 .01472 m
.7842 .01847 L
s
.81004 .01472 m
.81004 .01847 L
s
.83588 .01472 m
.83588 .01847 L
s
.86171 .01472 m
.86171 .01847 L
s
.08661 .01472 m
.08661 .01847 L
s
.06078 .01472 m
.06078 .01847 L
s
.03494 .01472 m
.03494 .01847 L
s
.0091 .01472 m
.0091 .01847 L
s
.91339 .01472 m
.91339 .01847 L
s
.93922 .01472 m
.93922 .01847 L
s
.96506 .01472 m
.96506 .01847 L
s
.9909 .01472 m
.9909 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .11416 m
.50625 .11416 L
s
[(2000)] .4875 .11416 1 0 Mshowa
.5 .21361 m
.50625 .21361 L
s
[(4000)] .4875 .21361 1 0 Mshowa
.5 .31306 m
.50625 .31306 L
s
[(6000)] .4875 .31306 1 0 Mshowa
.5 .4125 m
.50625 .4125 L
s
[(8000)] .4875 .4125 1 0 Mshowa
.5 .51195 m
.50625 .51195 L
s
[(10000)] .4875 .51195 1 0 Mshowa
.5 .6114 m
.50625 .6114 L
s
[(12000)] .4875 .6114 1 0 Mshowa
.125 Mabswid
.5 .03958 m
.50375 .03958 L
s
.5 .06444 m
.50375 .06444 L
s
.5 .0893 m
.50375 .0893 L
s
.5 .13902 m
.50375 .13902 L
s
.5 .16389 m
.50375 .16389 L
s
.5 .18875 m
.50375 .18875 L
s
.5 .23847 m
.50375 .23847 L
s
.5 .26333 m
.50375 .26333 L
s
.5 .28819 m
.50375 .28819 L
s
.5 .33792 m
.50375 .33792 L
s
.5 .36278 m
.50375 .36278 L
s
.5 .38764 m
.50375 .38764 L
s
.5 .43736 m
.50375 .43736 L
s
.5 .46223 m
.50375 .46223 L
s
.5 .48709 m
.50375 .48709 L
s
.5 .53681 m
.50375 .53681 L
s
.5 .56167 m
.50375 .56167 L
s
.5 .58654 m
.50375 .58654 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Geometric Point Spread Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.03853 .01472 L
.05458 .01472 L
.06965 .01472 L
.08415 .01472 L
.09958 .01472 L
.11444 .01472 L
.13023 .01472 L
.13814 .01472 L
.14544 .01472 L
.14911 .01472 L
.1509 .01472 L
.15169 .01472 L
.1521 .01472 L
.15254 .01472 L
.153 .01472 L
.15343 .01472 L
.15427 .01472 L
.15613 .01472 L
.15719 .01472 L
.15771 .01472 L
.1582 .01472 L
.15863 .01472 L
.1591 .01472 L
.16007 .01472 L
.16104 .01472 L
.16196 .01472 L
.1628 .01472 L
.16325 .01472 L
.16368 .01472 L
.16414 .01472 L
.16438 .01472 L
.16465 .01472 L
.16554 .01472 L
.1665 .01472 L
.16755 .01472 L
.168 .01472 L
.16847 .01472 L
.16892 .01472 L
.16933 .01472 L
.17022 .01472 L
.1712 .01472 L
.17209 .01472 L
.17248 .01472 L
.17292 .01472 L
.17332 .01472 L
.1737 .01472 L
.17411 .01472 L
.17454 .01472 L
.17551 .01472 L
Mistroke
.17654 .01472 L
.17704 .01472 L
.17751 .01472 L
.17794 .01472 L
.1784 .01472 L
.17946 .01472 L
.18005 .01472 L
.18059 .01472 L
.18105 .01472 L
.18155 .01472 L
.18183 .01472 L
.1821 .01472 L
.1826 .01472 L
.18353 .01472 L
.18404 .01472 L
.18451 .01472 L
.18492 .01472 L
.18535 .01472 L
.18583 .01472 L
.18627 .01472 L
.18728 .01472 L
.18777 .01472 L
.18822 .01472 L
.18869 .01472 L
.18895 .01472 L
.1892 .01472 L
.18971 .01472 L
.19026 .01472 L
.19074 .01472 L
.19118 .01472 L
.19162 .01472 L
.19203 .01472 L
.19296 .01472 L
.19322 .01472 L
.19349 .01472 L
.19398 .01472 L
.19495 .01472 L
.19522 .01472 L
.1955 .01472 L
.196 .01472 L
.19648 .01472 L
.19674 .01472 L
.19698 .01472 L
.19746 .01472 L
.1979 .01472 L
.19827 .01472 L
.19867 .01472 L
.1991 .01472 L
.1995 .01472 L
.19993 .01472 L
Mistroke
.20033 .01472 L
.20077 .01472 L
.20124 .01472 L
.20303 .01472 L
.20403 .01472 L
.20494 .01472 L
.20597 .01472 L
.20693 .01472 L
.20879 .01472 L
.20984 .01472 L
.21081 .01472 L
.21194 .01472 L
.21299 .01472 L
.21477 .01472 L
.21571 .01472 L
.21672 .01472 L
.21777 .01472 L
.21877 .01472 L
.22065 .01472 L
.2224 .01472 L
.22433 .01472 L
.2253 .01472 L
.22635 .01472 L
.22824 .01472 L
.23002 .01472 L
.2319 .01472 L
.2335 .01472 L
.23526 .01472 L
.23727 .01472 L
.23918 .01472 L
.24088 .01472 L
.24273 .01473 L
.24475 .01473 L
.24689 .01474 L
.24871 .01474 L
.25072 .01475 L
.25271 .01476 L
.25459 .01478 L
.25813 .01482 L
.26011 .01485 L
.26194 .01488 L
.26394 .01493 L
.26609 .01499 L
.2682 .01507 L
.27013 .01515 L
.27393 .01537 L
.27738 .01564 L
.28103 .01603 L
.28465 .01652 L
.28853 .0172 L
Mistroke
.29552 .01885 L
.30363 .02151 L
.3113 .02466 L
.32593 .03146 L
.3415 .03809 L
.35648 .04341 L
.37089 .0485 L
.38623 .05521 L
.401 .06421 L
.40905 .07085 L
.4167 .07896 L
.42424 .08959 L
.43124 .10309 L
.43527 .11315 L
.43906 .1247 L
.44615 .15333 L
.44986 .17295 L
.45379 .19782 L
.46083 .25412 L
.47529 .41141 L
.48334 .50388 L
.48715 .5414 L
.49068 .56967 L
.49241 .58074 L
.49433 .59055 L
.49525 .59434 L
.49625 .59769 L
.4968 .59921 L
.4973 .6004 L
.49778 .60134 L
.49829 .60215 L
.49875 .60269 L
.49916 .60304 L
.49957 .60325 L
.49997 .60332 L
.50043 .60325 L
.50085 .60303 L
.50131 .60263 L
.5018 .60202 L
.50224 .60131 L
.50271 .60037 L
.50356 .59824 L
.50457 .59498 L
.5055 .59131 L
.50732 .58226 L
.50926 .57008 L
.51274 .54233 L
.52064 .45948 L
.52826 .36938 L
.5365 .27954 L
Mistroke
.54446 .21038 L
.55178 .16386 L
.55896 .13169 L
.56303 .11805 L
.56684 .10765 L
.5746 .09154 L
.58167 .081 L
.58895 .07277 L
.59687 .06582 L
.61242 .05591 L
.62739 .04916 L
.64179 .044 L
.65712 .03862 L
.67187 .03247 L
.68756 .02516 L
.69539 .02188 L
.70267 .01938 L
.7097 .01756 L
.71363 .0168 L
.7172 .01625 L
.72101 .0158 L
.72452 .01548 L
.72837 .01523 L
.73032 .01513 L
.73245 .01504 L
.73444 .01497 L
.73633 .01492 L
.73987 .01485 L
.74185 .01482 L
.74368 .0148 L
.74569 .01478 L
.74783 .01476 L
.74969 .01475 L
.75139 .01474 L
.75326 .01474 L
.75524 .01473 L
.75696 .01473 L
.75856 .01472 L
.76032 .01472 L
.7622 .01472 L
.76422 .01472 L
.76609 .01472 L
.76814 .01472 L
.76918 .01472 L
.77031 .01472 L
.77222 .01472 L
.77328 .01472 L
.77428 .01472 L
.77621 .01472 L
.77799 .01472 L
Mistroke
.7799 .01472 L
.78164 .01472 L
.7826 .01472 L
.78365 .01472 L
.78455 .01472 L
.78553 .01472 L
.78731 .01472 L
.78828 .01472 L
.78918 .01472 L
.7908 .01472 L
.79171 .01472 L
.79254 .01472 L
.79437 .01472 L
.7953 .01472 L
.79632 .01472 L
.79812 .01472 L
.79893 .01472 L
.79981 .01472 L
.80031 .01472 L
.80078 .01472 L
.8018 .01472 L
.80225 .01472 L
.80268 .01472 L
.80317 .01472 L
.80362 .01472 L
.80559 .01472 L
.80613 .01472 L
.8064 .01472 L
.8067 .01472 L
.80695 .01472 L
.80723 .01472 L
.80772 .01472 L
.80869 .01472 L
.80895 .01472 L
.80923 .01472 L
.80973 .01472 L
.8107 .01472 L
.81158 .01472 L
.81185 .01472 L
.81214 .01472 L
.81265 .01472 L
.81319 .01472 L
.81378 .01472 L
.81428 .01472 L
.81456 .01472 L
.81482 .01472 L
.81528 .01472 L
.81553 .01472 L
.81579 .01472 L
.81678 .01472 L
Mistroke
.81785 .01472 L
.81833 .01472 L
.8186 .01472 L
.81885 .01472 L
.8198 .01472 L
.82171 .01472 L
.82214 .01472 L
.82255 .01472 L
.82298 .01472 L
.82345 .01472 L
.82445 .01472 L
.82538 .01472 L
.82594 .01472 L
.82622 .01472 L
.82647 .01472 L
.82695 .01472 L
.8272 .01472 L
.82747 .01472 L
.8293 .01472 L
.83024 .01472 L
.8305 .01472 L
.83077 .01472 L
.83126 .01472 L
.83169 .01472 L
.83209 .01472 L
.833 .01472 L
.83463 .01472 L
.83557 .01472 L
.83604 .01472 L
.83631 .01472 L
.83656 .01472 L
.83835 .01472 L
.83927 .01472 L
.84027 .01472 L
.84078 .01472 L
.84105 .01472 L
.84134 .01472 L
.84161 .01472 L
.84186 .01472 L
.84235 .01472 L
.84337 .01472 L
.84433 .01472 L
.84613 .01472 L
.84655 .01472 L
.84699 .01472 L
.84741 .01472 L
.84779 .01472 L
.84862 .01472 L
.84953 .01472 L
.85145 .01472 L
Mistroke
.85321 .01472 L
.8684 .01472 L
.88301 .01472 L
.89856 .01472 L
.91353 .01472 L
.92792 .01472 L
.94325 .01472 L
.958 .01472 L
.97368 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[187]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001?ooooo0_l00004oooo
o`04o`000?ooooooooooooooo`Go00004Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`00037ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Booooo`;o00001?ooool0
1?l0003oooooooooooooool5o`0001;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0
000Xooooo`00:?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
4Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00013ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`0_ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool04?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00017o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo000Qoooo
o`Go00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Sooooo1Ol00002
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool02Oooool5o`0000;ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`0_ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool04?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
017ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Uooooo`00:?ooool01?l0
003oooooooooool00009ooooo`;o00004_ooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0_ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo013ooooo00Co0000oooooooooooo00002Oooool2o`0002Sooooo000Xoooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo02oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0@oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Aooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool09Oooool002Sooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo0000017ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo0000013ooooo00Co0000oooooooooooo00002?ooool2o`00037ooooo00Co
0000oooooooooooo00002?ooool2o`0001;ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo0000017ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000002Oooooo000Yooooo`;o00002Oooool3o`0001?ooooo0_l00009ooooo`?o00004_ooool2
o`0000[ooooo00?o0000ooooooooool0<?ooool2o`0000[ooooo00?o0000ooooooooool04Oooool2
o`0000Wooooo0ol0000Cooooo`;o00002Oooool3o`0002Sooooo002?ooooo`03o`000?oooooooooo
08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo
002?ooooo`03o`000?oooooooooo08kooooo000Aoooooogo00004_ooool001?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`Co00000_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo0ol00006ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04_ooool005oooooo0_l0000^ooooo`03o`000?oooooooooo
02_ooooo1?l0001Oooooo`00HOooool2o`0002cooooo00?o0000ooooooooool0:Oooool2o`0006?o
oooo001Sooooo`;o0000:_ooool00ol0003oooooooooo`0Wooooo`;o0000IOooool006Gooooo0_l0
000Xooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0IOooool006Oooooo0ol0000U
ooooo`;o00009?ooool3o`0006Sooooo001Zooooo`Co00008Oooool00ol0003oooooooooo`0Ooooo
o`Co0000Joooool006kooooo0_l0000Oooooo`03o`000?oooooooooo01cooooo0ol0001_ooooo`00
L?ooool2o`0001gooooo00?o0000ooooooooool06_ooool2o`0007;ooooo001booooo`;o00006ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07;ooooo001dooooo`;o00006Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo07?ooooo001fooooo`03o`000?oooooooooo
01Kooooo0_l0000Hooooo`03o`000?oooooooooo07Cooooo001gooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool05Oooool2o`0007Oooooo001hooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1gooooo`00NOooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0N?ooool007[ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07Wooooo001joooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1ioooo
o`00Noooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0N_ooool007cooooo00?o0000ooooooooool04?ooool2o`00017ooooo00?o0000ooooooooool0
Noooool007cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo07_ooooo001mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1looooo`00M?ooool5o`0000?ooooo0ol00003ooooo`;o00001?ooool2o`00
00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1looooo`00MOooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
OOooool007Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`000005ooooool0
003oooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0OOooool007Oooooo00Go0000ooooooooooooooooo`000002ooooo`;o
000000Goooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo0ol0000=
ooooo`03o`000?oooooooooo07kooooo001dooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`02o`000005ooooool0003oooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0O_ooool007Cooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo07kooooo001eooooo`?o00001?ooool2o`0000;ooooo00Co0000ooooool0
003o00001?ooool2o`0000Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1ooooo
o`00P?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0Ooooool0083ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo07oooooo0020ooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`03o`000?oo
oooooooo07oooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`20ooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0P?ooool0087ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo083ooooo0021ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`20ooooo`00POooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0POooool0087ooooo00?o0000
ooooooooool02oooool2o`0000_ooooo00?o0000ooooooooool0POooool008;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo087ooooo0022ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`21ooooo`00
P_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
POooool008;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo08;ooooo0022ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`22ooooo`00P_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0P_ooool008?ooooo00?o0000ooooooooool02Oooool2o`0000[o
oooo00?o0000ooooooooool0P_ooool008?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo08;ooooo0023ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`22ooooo`00Poooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Poooool007Kooooo0ol00003oooo
o`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0Poooool007Oooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
o`000?ooool00_l00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`23ooooo`00M?ooool5o`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo0ol00008ooooo`03
o`000?oooooooooo08?ooooo001dooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`23ooooo`00MOooool00ol0003oooooo`000003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Poooool007Kooooo
0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Poooool0
07Oooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0ol00003ooooo`;o00001Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo08Cooooo0024ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`24ooooo`00Q?ooool00ol0003ooooo
ooooo`08ooooo`;o00002?ooool00ol0003oooooooooo`24ooooo`00QOooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Q?ooool008Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Cooooo0025oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`24oooo
o`00QOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Q?ooool008Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo08Cooooo0025ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`24ooooo`00QOooool00ol0003oooooooooo`07ooooo`;o00001oooool0
0ol0003oooooooooo`25ooooo`00QOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0QOooool008Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo08Gooooo0026ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`25ooooo`00Q_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0QOooool008Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Gooooo0026oooo
o`03o`000?oooooooooo00Kooooo0_l00007ooooo`03o`000?oooooooooo08Gooooo0026ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`25ooooo`00
Q_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
QOooool008Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo08Gooooo001eooooo`?o00001?ooool2o`0000Cooooo0_l00002ooooo`04o`000?oooooo
0000o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`26ooooo`00M?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
ooooool0003ooooo00;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Q_ooool007Cooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo0000ooooo`02o`0000;ooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0Q_ooool007Cooooo1?l00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q_ooool007Cooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
08Kooooo001eooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`26ooooo`00M_ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool3
o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`26ooooo`00Qoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q_ooool008Oo
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool0Q_ooool008Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Kooooo
0027ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`26ooooo`00Qoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Qoooool008Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo08Oooooo0028ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`27ooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Qoooool008Sooooo00?o0000ooooooooool01?oo
ool2o`0000Gooooo00?o0000ooooooooool0Qoooool008Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo0028ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27ooooo`00R?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Qoooool008Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo
0028ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`27ooooo`00R?ooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`27
ooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Qoooool008Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo08Sooooo0029ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`28ooooo`00MOooool3o`0000Cooooo0_l00004ooooo`;o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`28ooooo`00M?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`28ooooo`00M?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo0000o`0000Cooooo
0ol00003ooooo`03o`000?oooooooooo08Sooooo001eooooo`?o00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo001dooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000ooooool0003o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo
001dooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo08Sooooo001eooooo`?o00001?ooool2o`0000Cooooo0_l00004oooo
o`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo0029ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`28ooooo`00
ROooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
R?ooool008[ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000ooooooooool0ROoo
ool008[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo08Wooooo002:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`29ooooo`00R_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0ROooool008[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo08Wooooo002:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`29ooooo`00R_ooool00ol0003oooooooooo`02
ooooo`;o00000oooool00ol0003oooooooooo`29ooooo`00R_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ROooool008[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Wooooo002:ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`29ooooo`00R_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ROoo
ool008_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo08[ooooo002;
ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`2:ooooo`00Roooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0R_ooool008_ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo08[ooooo002;ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`2:ooooo`00Koooool3o`0000Cooooo0_l00004
ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?oooooo
ooooooooool00000S?ooool0073ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`00002<ooooo`00L?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooo
oooooooo000008cooooo001`ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00_l00003ooooo`?o000000?oooooo`000?ooool0Roooool0073ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Go0000oooooooooooooooo
o`00002<ooooo`00Koooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_l00003oooo
o`05o`000?ooooooooooooooool00000S?ooool0073ooooo00?o0000ooooooooool00oooool2o`00
00Cooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`2;ooooo`00S?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo08_ooooo002<ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0Roooool0
08cooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`2<ooooo`00S?ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo08_ooooo002<ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool0Roooool008cooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`2;ooooo`00S?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
08_ooooo002=ooooo`05o`000?oooooo0000ooooool00000S_ooool008gooooo00?o0000ooooool0
00000_l0002>ooooo`00SOooool01Ol0003oooooo`000?oooooo000008kooooo002=ooooo`05o`00
0?oooooo0000ooooool00000S_ooool008gooooo00Go0000ooooool0003oooooo`00002>ooooo`00
SOooool01Ol0003oooooo`000?oooooo000008kooooo002=ooooo`05o`000?oooooo0000ooooool0
0000S_ooool008gooooo00?o0000ooooool000000_l0002>ooooo`00S_ooool3o`0008oooooo002>
ooooo`?o0000Soooool008kooooo0ol0002?ooooo`00Koooool3o`0000;ooooo1Ol00003ooooo`;o
00001?ooool2o`0000Cooooo0_l00004ooooo`?o0000Soooool0073ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo08kooooo001`
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`2>ooooo`00L?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool3o`0008kooooo001`ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08kooooo001_ooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0009Gooooo001`ooooo`03o`000?oooooo
oooo00;ooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l0002Fooooo`00oooooolQoooo
o`00V?ooool3o`0008Gooooo002Iooooo`03o`000?oooooooooo08Cooooo000cooooo`?o00000ooo
ool3o`0000?ooooo0ol00002ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000Cooooo
0_l00002ooooo`?o00000oooool5o`0000;ooooo0ol00008ooooo`?o00001?ooool3o`0000;ooooo
1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o
00000_ooool3o`0000Cooooo0ol00003ooooo`Co00000_ooool4o`0000Oooooo0ol00005ooooo`;o
000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool3o`0000Cooooo0_l00002oooo
o`Go00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`00000dooooo`00<_ooool01ol0003o
oooooooooooooooo0000ooooool000001Oooool03Ol0003ooooooooooooooooo0000ooooool0003o
ooooo`000?oooooo0000ooooool000001_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000=Ooo
ool003;ooooo00Ko0000ooooooooooooooooo`000?ooool5o`000003ooooool0003ooooo00;ooooo
00So0000ooooool0003oooooo`000?oooooo0000ooooo`Go00000_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool5o`0000;ooooo0ol00002ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo03?ooooo000b
ooooo`03o`000?oooooo000000Co00000oooool00ol0003oooooo`000003ooooo`09o`000?oooooo
0000ooooool0003oooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00001Oooool2o`00
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo0ol00002
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool02_ooool2o`0000?ooooo00Co0000oooooooooooo
00000_ooool2o`0000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`?o00000oooool01?l0003ooooooooo
ool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00006
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo03?ooooo000booooo`03o`000?oooooooooo00Cooooo0ol00003ooooo`?o00000_oo
ool2o`000003ooooool0003ooooo00;ooooo0ol00002ooooo`Co00000_ooool2o`000004ooooool0
003o0000ooooo`?o00001?ooool3o`0000Wooooo00Co0000oooooooooooo00000_ooool3o`0000;o
oooo0ol00003ooooo`Co00000_ooool4o`0000Wooooo00?o0000ooooooooool00_ooool4o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`?o00000oooool2o`0000Cooooo0ol00009ooooo`03
o`000?oooooooooo00;ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00002oooo
o`Co00000_ooool3o`0000Cooooo0ol00002ooooo`Co0000=_ooool003;ooooo00Go0000oooooooo
ooooooooo`00000Jooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00005?ooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool01ooo
ool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo04Sooooo000cooooo`?o00006ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo1?l0000:ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool3o`0001_ooooo0_l00008ooooo`Go00005?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo047ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.439135, -966.893, \
0.00306018, 79.5042}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00407725 0.0280925 0.561849 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.22767 -0.0125 -6 -9 ]
[.22767 -0.0125 6 0 ]
[.43153 -0.0125 -9 -9 ]
[.43153 -0.0125 9 0 ]
[.6354 -0.0125 -9 -9 ]
[.6354 -0.0125 9 0 ]
[.83926 -0.0125 -9 -9 ]
[.83926 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .14046 -18 -4.5 ]
[-0.0125 .14046 0 4.5 ]
[-0.0125 .25283 -18 -4.5 ]
[-0.0125 .25283 0 4.5 ]
[-0.0125 .3652 -18 -4.5 ]
[-0.0125 .3652 0 4.5 ]
[-0.0125 .47757 -18 -4.5 ]
[-0.0125 .47757 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -84 0 ]
[.5 .63053 84 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.22767 0 m
.22767 .00625 L
s
[(50)] .22767 -0.0125 0 1 Mshowa
.43153 0 m
.43153 .00625 L
s
[(100)] .43153 -0.0125 0 1 Mshowa
.6354 0 m
.6354 .00625 L
s
[(150)] .6354 -0.0125 0 1 Mshowa
.83926 0 m
.83926 .00625 L
s
[(200)] .83926 -0.0125 0 1 Mshowa
.125 Mabswid
.06458 0 m
.06458 .00375 L
s
.10535 0 m
.10535 .00375 L
s
.14613 0 m
.14613 .00375 L
s
.1869 0 m
.1869 .00375 L
s
.26844 0 m
.26844 .00375 L
s
.30922 0 m
.30922 .00375 L
s
.34999 0 m
.34999 .00375 L
s
.39076 0 m
.39076 .00375 L
s
.47231 0 m
.47231 .00375 L
s
.51308 0 m
.51308 .00375 L
s
.55385 0 m
.55385 .00375 L
s
.59462 0 m
.59462 .00375 L
s
.67617 0 m
.67617 .00375 L
s
.71694 0 m
.71694 .00375 L
s
.75771 0 m
.75771 .00375 L
s
.79849 0 m
.79849 .00375 L
s
.88003 0 m
.88003 .00375 L
s
.9208 0 m
.9208 .00375 L
s
.96158 0 m
.96158 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .14046 m
.00625 .14046 L
s
[(0.2)] -0.0125 .14046 1 0 Mshowa
0 .25283 m
.00625 .25283 L
s
[(0.4)] -0.0125 .25283 1 0 Mshowa
0 .3652 m
.00625 .3652 L
s
[(0.6)] -0.0125 .3652 1 0 Mshowa
0 .47757 m
.00625 .47757 L
s
[(0.8)] -0.0125 .47757 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(1)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.22767 .61178 m
.22767 .61803 L
s
.43153 .61178 m
.43153 .61803 L
s
.6354 .61178 m
.6354 .61803 L
s
.83926 .61178 m
.83926 .61803 L
s
.125 Mabswid
.06458 .61428 m
.06458 .61803 L
s
.10535 .61428 m
.10535 .61803 L
s
.14613 .61428 m
.14613 .61803 L
s
.1869 .61428 m
.1869 .61803 L
s
.26844 .61428 m
.26844 .61803 L
s
.30922 .61428 m
.30922 .61803 L
s
.34999 .61428 m
.34999 .61803 L
s
.39076 .61428 m
.39076 .61803 L
s
.47231 .61428 m
.47231 .61803 L
s
.51308 .61428 m
.51308 .61803 L
s
.55385 .61428 m
.55385 .61803 L
s
.59462 .61428 m
.59462 .61803 L
s
.67617 .61428 m
.67617 .61803 L
s
.71694 .61428 m
.71694 .61803 L
s
.75771 .61428 m
.75771 .61803 L
s
.79849 .61428 m
.79849 .61803 L
s
.88003 .61428 m
.88003 .61803 L
s
.9208 .61428 m
.9208 .61803 L
s
.96158 .61428 m
.96158 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .14046 m
1 .14046 L
s
.99375 .25283 m
1 .25283 L
s
.99375 .3652 m
1 .3652 L
s
.99375 .47757 m
1 .47757 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(Modulation Transfer Function)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .58994 m
.03097 .40264 L
.03462 .2764 L
.03567 .24788 L
.03667 .22548 L
.03757 .21106 L
.03853 .19577 L
.039 .19032 L
.03927 .18826 L
.03952 .18634 L
.04043 .17932 L
.04094 .1754 L
.04142 .17238 L
.04169 .17136 L
.04198 .17024 L
.04249 .16828 L
.04619 .15567 L
.05458 .12591 L
.0627 .09543 L
.06456 .08802 L
.06653 .08109 L
.06822 .07645 L
.07006 .07259 L
.07375 .06668 L
.07774 .06071 L
.08497 .05132 L
.08911 .04683 L
.09302 .04226 L
.09473 .04055 L
.09654 .03901 L
.09749 .03842 L
.09799 .0381 L
.09825 .03794 L
.09853 .03777 L
.09903 .03756 L
.09948 .03738 L
.10037 .03701 L
.10408 .03552 L
.10805 .03365 L
.10997 .03287 L
.11179 .03231 L
.11258 .03213 L
.11302 .03203 L
.11342 .03194 L
.11386 .03187 L
.11434 .0318 L
.11519 .03168 L
.11692 .0314 L
.11875 .03104 L
.12077 .0305 L
Mistroke
.12264 .02998 L
.12309 .02986 L
.12356 .02974 L
.12408 .02965 L
.12455 .02956 L
.125 .02948 L
.12548 .02939 L
.12594 .02932 L
.12635 .0293 L
.12712 .02926 L
.12795 .02923 L
.12842 .02921 L
.12886 .02922 L
.12971 .02923 L
.13015 .02924 L
.13063 .02925 L
.13108 .02925 L
.13149 .02923 L
.13243 .0292 L
.13293 .02919 L
.13321 .02918 L
.13346 .02916 L
.13371 .02913 L
.13398 .0291 L
.13446 .02904 L
.1354 .02893 L
.13744 .02864 L
.13788 .02857 L
.13836 .0285 L
.13881 .02847 L
.13922 .02844 L
.14013 .02837 L
.14037 .02835 L
.14063 .02833 L
.14111 .02832 L
.14152 .02833 L
.14197 .02835 L
.1424 .02836 L
.14287 .02837 L
.14331 .02838 L
.14371 .0284 L
.1445 .02845 L
.14494 .02848 L
.14543 .02851 L
.14588 .02853 L
.1463 .02853 L
.14731 .02854 L
.14778 .02854 L
.14823 .02854 L
.14861 .02852 L
Mistroke
.14903 .02848 L
.14991 .02841 L
.1517 .02825 L
.15271 .02815 L
.15299 .02813 L
.15328 .0281 L
.15356 .02811 L
.15381 .02812 L
.15477 .02815 L
.15528 .02817 L
.15556 .02818 L
.15582 .02819 L
.1563 .02818 L
.15683 .02816 L
.15731 .02814 L
.15776 .02813 L
.15821 .02812 L
.15864 .02814 L
.15958 .02821 L
.16042 .02827 L
.1609 .0283 L
.16133 .02831 L
.16233 .02833 L
.16281 .02833 L
.16326 .02834 L
.1637 .02831 L
.16417 .02829 L
.16517 .02822 L
.16543 .02821 L
.16571 .02819 L
.16597 .02819 L
.16622 .02819 L
.16717 .02819 L
.16758 .02819 L
.16801 .0282 L
.16842 .0282 L
.1688 .02821 L
.16972 .02823 L
.17017 .02824 L
.17058 .02825 L
.17101 .02824 L
.17147 .02821 L
.17243 .02816 L
.17287 .02814 L
.17334 .02813 L
.17378 .02815 L
.17419 .02817 L
.17512 .02821 L
.17557 .02823 L
.17599 .02824 L
Mistroke
.17647 .02825 L
.177 .02826 L
.17747 .02827 L
.17791 .02828 L
.1783 .02827 L
.17871 .02825 L
.1796 .0282 L
.18008 .02818 L
.18053 .02815 L
.18094 .02815 L
.18138 .02817 L
.1824 .02819 L
.1829 .02821 L
.18336 .02822 L
.18389 .02823 L
.18447 .02824 L
.18498 .02825 L
.18547 .02825 L
.18589 .02825 L
.18635 .02822 L
.18731 .02817 L
.18756 .02816 L
.18784 .02815 L
.18833 .02814 L
.18881 .02815 L
.18926 .02817 L
.19012 .0282 L
.19059 .02822 L
.19103 .02823 L
.1915 .02823 L
.19202 .02824 L
.19248 .02825 L
.19293 .02825 L
.19334 .02825 L
.1938 .02822 L
.19459 .02818 L
.19504 .02816 L
.19552 .02814 L
.19592 .02814 L
.19637 .02816 L
.19737 .02819 L
.19786 .02821 L
.19832 .02822 L
.19858 .02822 L
.19885 .02822 L
.19942 .02823 L
.19994 .02824 L
.20042 .02825 L
.20091 .02823 L
.20117 .02822 L
Mistroke
.20145 .02821 L
.20195 .02818 L
.20241 .02816 L
.20283 .02814 L
.20327 .02813 L
.20377 .02815 L
.20422 .02816 L
.20467 .02818 L
.20516 .0282 L
.20563 .02821 L
.20605 .02822 L
.20698 .02823 L
.20751 .02824 L
.208 .02824 L
.20839 .02823 L
.20881 .02821 L
.2097 .02816 L
.21019 .02814 L
.21064 .02813 L
.21105 .02814 L
.2115 .02816 L
.212 .02817 L
.21253 .02819 L
.21279 .0282 L
.21304 .02821 L
.2135 .02821 L
.21451 .02822 L
.21504 .02823 L
.21534 .02823 L
.21562 .02823 L
.21607 .02821 L
.21649 .02819 L
.21699 .02817 L
.21745 .02815 L
.21791 .02813 L
.21839 .02813 L
.21888 .02815 L
.21941 .02817 L
.21988 .02818 L
.22037 .0282 L
.22063 .02821 L
.22092 .02821 L
.22142 .02822 L
.22189 .02822 L
.2224 .02823 L
.22288 .02823 L
.22332 .02822 L
.22377 .0282 L
.22419 .02818 L
.22468 .02816 L
Mistroke
.22514 .02813 L
.22557 .02812 L
.22597 .02814 L
.22687 .02817 L
.22737 .02818 L
.22784 .0282 L
.22833 .02821 L
.22859 .02821 L
.22886 .02821 L
.22936 .02822 L
.22982 .02822 L
.23024 .02822 L
.2307 .02822 L
.2312 .02819 L
.23174 .02817 L
.23228 .02815 L
.23256 .02813 L
.23285 .02812 L
.23311 .02812 L
.23339 .02813 L
.23388 .02815 L
.23484 .02818 L
.23531 .0282 L
.23581 .0282 L
.23607 .02821 L
.23636 .02821 L
.23686 .02821 L
.23733 .02822 L
.23759 .02822 L
.23784 .02822 L
.23832 .02821 L
.23876 .02819 L
.23958 .02815 L
.24004 .02813 L
.24046 .02812 L
.24071 .02812 L
.24097 .02813 L
.24143 .02815 L
.24232 .02818 L
.24278 .02819 L
.24328 .0282 L
.24357 .0282 L
.24383 .02821 L
.24434 .02821 L
.24487 .02821 L
.24515 .02822 L
.24544 .02822 L
.2457 .02821 L
.24598 .02819 L
.24648 .02817 L
Mistroke
.24743 .02813 L
.2477 .02812 L
.24796 .02812 L
.24845 .02813 L
.24934 .02816 L
.24981 .02818 L
.2503 .02819 L
.25054 .0282 L
.25081 .0282 L
.25128 .0282 L
.25173 .02821 L
.25221 .02821 L
.25268 .02821 L
.25311 .02821 L
.25354 .02819 L
.25395 .02817 L
.25442 .02815 L
.25491 .02813 L
.25534 .02811 L
.25581 .02813 L
.25687 .02816 L
.25733 .02818 L
.25758 .02818 L
.25784 .02819 L
.25828 .0282 L
.25868 .0282 L
.25957 .02821 L
.25982 .02821 L
.26008 .02821 L
.26056 .0282 L
.26102 .02818 L
.26145 .02817 L
.26186 .02815 L
.2623 .02813 L
.26271 .02812 L
.26309 .02812 L
.26352 .02813 L
.26393 .02815 L
.26484 .02818 L
.26531 .02819 L
.26558 .02819 L
.26583 .0282 L
.26676 .0282 L
.2672 .0282 L
.2676 .02821 L
.26803 .0282 L
.2685 .02818 L
.26946 .02814 L
.26994 .02812 L
.27038 .02811 L
Mistroke
.27062 .02812 L
.27088 .02813 L
.27143 .02815 L
.27193 .02816 L
.27239 .02818 L
.2728 .02819 L
.27322 .02819 L
.27411 .0282 L
.27448 .0282 L
.27488 .0282 L
.27532 .0282 L
.27572 .02819 L
.27672 .02815 L
.2772 .02813 L
.27765 .02811 L
.27806 .02812 L
.27849 .02813 L
.2794 .02816 L
.27986 .02818 L
.28037 .02819 L
.28084 .02819 L
.28128 .02819 L
.28211 .0282 L
.28258 .0282 L
.283 .02819 L
.2835 .02817 L
.28396 .02816 L
.28445 .02814 L
.28471 .02813 L
.28499 .02812 L
.28546 .02811 L
.2859 .02813 L
.28686 .02816 L
.2873 .02817 L
.28777 .02819 L
.28801 .02819 L
.28827 .02819 L
.28874 .02819 L
.28918 .02819 L
.28966 .0282 L
.29011 .0282 L
.29052 .02819 L
.29094 .02817 L
.29133 .02816 L
.2918 .02814 L
.29222 .02812 L
.29263 .02811 L
.29301 .02811 L
.29341 .02813 L
.29384 .02814 L
Mistroke
.29475 .02817 L
.29501 .02818 L
.29525 .02819 L
.29572 .02819 L
.29656 .02819 L
.29703 .02819 L
.29746 .0282 L
.29793 .02819 L
.29818 .02818 L
.29845 .02817 L
.29937 .02814 L
.29989 .02812 L
.30016 .02811 L
.30045 .02811 L
.30144 .02814 L
.30198 .02816 L
.30225 .02817 L
.30249 .02818 L
.30295 .02819 L
.30345 .02819 L
.30449 .02819 L
.30474 .02819 L
.30502 .02819 L
.30531 .02819 L
.30559 .02818 L
.30663 .02814 L
.30714 .02812 L
.30762 .02811 L
.30804 .02812 L
.3085 .02813 L
.30946 .02816 L
.30971 .02817 L
.30998 .02818 L
.31046 .02818 L
.31096 .02819 L
.31151 .02819 L
.31201 .02819 L
.31249 .02819 L
.31292 .02818 L
.31339 .02817 L
.31446 .02813 L
.31472 .02812 L
.315 .02811 L
.31531 .02811 L
.31559 .02812 L
.31657 .02815 L
.31708 .02816 L
.31737 .02817 L
.31763 .02818 L
.31789 .02818 L
Mistroke
.31816 .02818 L
.31865 .02819 L
.31959 .02819 L
.31986 .02819 L
.32011 .02819 L
.32037 .02818 L
.32066 .02817 L
.32165 .02814 L
.32212 .02812 L
.32257 .0281 L
.32298 .02811 L
.32342 .02813 L
.32433 .02816 L
.32481 .02817 L
.32506 .02818 L
.32532 .02818 L
.32582 .02818 L
.32628 .02818 L
.32674 .02819 L
.32716 .02819 L
.32759 .02819 L
.328 .02817 L
.3289 .02814 L
.32937 .02813 L
.32963 .02812 L
.32988 .02811 L
.33031 .02811 L
.33079 .02812 L
.33184 .02816 L
.33209 .02816 L
.33236 .02817 L
.33284 .02818 L
.3331 .02818 L
.33335 .02818 L
.33381 .02818 L
.33435 .02819 L
.33486 .02819 L
.33529 .02818 L
.33574 .02816 L
.3367 .02813 L
.33719 .02811 L
.33747 .0281 L
.33772 .02811 L
.33821 .02812 L
.33867 .02814 L
.33918 .02815 L
.33971 .02817 L
.33999 .02818 L
.3403 .02818 L
.34058 .02818 L
Mistroke
.34084 .02818 L
.34129 .02818 L
.34177 .02818 L
.34222 .02819 L
.34263 .02818 L
.34312 .02817 L
.34364 .02815 L
.34459 .02812 L
.34507 .0281 L
.34534 .02811 L
.34559 .02812 L
.34664 .02815 L
.34711 .02817 L
.34756 .02818 L
.3478 .02818 L
.34807 .02818 L
.34854 .02818 L
.34902 .02818 L
.34947 .02818 L
.34987 .02818 L
.35031 .02817 L
.35123 .02814 L
.35173 .02813 L
.3522 .02811 L
.3526 .0281 L
.35304 .02812 L
.35396 .02815 L
.3544 .02816 L
.35481 .02817 L
.35518 .02818 L
.35559 .02818 L
.35648 .02818 L
.35697 .02818 L
.35744 .02818 L
.35788 .02817 L
.35835 .02815 L
.35918 .02813 L
.35945 .02812 L
.3597 .02811 L
.36017 .02811 L
.36044 .02811 L
.36068 .02812 L
.36123 .02814 L
.36171 .02815 L
.36216 .02817 L
.36263 .02818 L
.36287 .02818 L
.36314 .02818 L
.36417 .02818 L
.36445 .02818 L
Mistroke
.36475 .02818 L
.36501 .02818 L
.36529 .02817 L
.36627 .02814 L
.36679 .02812 L
.36707 .02811 L
.36733 .0281 L
.36782 .02811 L
.36808 .02812 L
.36836 .02813 L
.3693 .02816 L
.3698 .02817 L
.37027 .02818 L
.37069 .02818 L
.37115 .02818 L
.37161 .02818 L
.37205 .02818 L
.37255 .02818 L
.37301 .02816 L
.37385 .02813 L
.37432 .02812 L
.37475 .0281 L
.375 .0281 L
.37527 .02811 L
.37573 .02812 L
.37665 .02815 L
.37717 .02817 L
.37744 .02817 L
.37772 .02818 L
.37872 .02818 L
.37925 .02818 L
.37952 .02818 L
.37976 .02818 L
.38022 .02817 L
.38072 .02815 L
.38176 .02812 L
.38201 .02811 L
.38228 .0281 L
.38258 .0281 L
.38286 .02811 L
.38385 .02814 L
.38438 .02816 L
.38488 .02817 L
.38531 .02817 L
.38576 .02818 L
.38673 .02818 L
.3872 .02818 L
.38747 .02817 L
.38772 .02817 L
.38876 .02813 L
Mistroke
.38923 .02812 L
.38967 .0281 L
.38991 .0281 L
.39018 .02811 L
.39064 .02812 L
.3917 .02815 L
.39196 .02816 L
.39224 .02817 L
.39255 .02817 L
.39284 .02817 L
.39335 .02818 L
.3939 .02818 L
.39436 .02818 L
.39463 .02818 L
.39487 .02818 L
.39535 .02816 L
.39587 .02814 L
.39633 .02813 L
.39682 .02811 L
.39725 .0281 L
.39773 .02811 L
.39858 .02814 L
.39909 .02815 L
.39957 .02817 L
.39984 .02817 L
.40013 .02817 L
.40063 .02817 L
.40111 .02818 L
.40163 .02818 L
.40211 .02818 L
.40255 .02817 L
.40301 .02815 L
.40344 .02814 L
.40395 .02812 L
.40441 .02811 L
.4049 .0281 L
.40536 .02811 L
.40637 .02815 L
.4068 .02816 L
.40725 .02817 L
.40763 .02817 L
.40805 .02817 L
.40851 .02817 L
.409 .02818 L
.40946 .02818 L
.40989 .02817 L
.41085 .02814 L
.41138 .02812 L
.41189 .02811 L
.41236 .0281 L
Mistroke
.41262 .02811 L
.41286 .02812 L
.41375 .02814 L
.41424 .02816 L
.41469 .02817 L
.41517 .02817 L
.41542 .02817 L
.41569 .02817 L
.41626 .02817 L
.41654 .02817 L
.4168 .02817 L
.41729 .02817 L
.41754 .02817 L
.41782 .02816 L
.41881 .02812 L
.41908 .02812 L
.41936 .02811 L
.41962 .0281 L
.41986 .0281 L
.42033 .02811 L
.42076 .02813 L
.42175 .02816 L
.42201 .02817 L
.42226 .02817 L
.42252 .02817 L
.4228 .02817 L
.42378 .02817 L
.42405 .02817 L
.42434 .02817 L
.42458 .02817 L
.42484 .02817 L
.42513 .02816 L
.42544 .02815 L
.42599 .02813 L
.42647 .02812 L
.42674 .02811 L
.42699 .0281 L
.42725 .0281 L
.42755 .02811 L
.42806 .02812 L
.42859 .02814 L
.42909 .02815 L
.42953 .02817 L
.43002 .02817 L
.43047 .02817 L
.43094 .02817 L
.43135 .02817 L
.43179 .02817 L
.43225 .02817 L
.43269 .02816 L
Mistroke
.43368 .02813 L
.43415 .02811 L
.43459 .0281 L
.43483 .0281 L
.4351 .02811 L
.43556 .02812 L
.4364 .02815 L
.43684 .02816 L
.43732 .02817 L
.43759 .02817 L
.43784 .02817 L
.43833 .02817 L
.43884 .02817 L
.43911 .02817 L
.43939 .02817 L
.43966 .02817 L
.4399 .02816 L
.44037 .02815 L
.4413 .02812 L
.44181 .0281 L
.44206 .0281 L
.44234 .0281 L
.44283 .02812 L
.44329 .02813 L
.44383 .02815 L
.44433 .02816 L
.44461 .02817 L
.44491 .02817 L
.44544 .02817 L
.44643 .02817 L
.44692 .02817 L
.4472 .02817 L
.44747 .02816 L
.44844 .02813 L
.44891 .02812 L
.44934 .0281 L
.44979 .0281 L
.45021 .02811 L
.45113 .02814 L
.45159 .02816 L
.45207 .02817 L
.45232 .02817 L
.4526 .02817 L
.45309 .02817 L
.45359 .02817 L
.45407 .02817 L
.45434 .02817 L
.45462 .02817 L
.45489 .02816 L
.45513 .02815 L
Mistroke
.45611 .02812 L
.45659 .02811 L
.45704 .0281 L
.45745 .02811 L
.4579 .02812 L
.45883 .02815 L
.4592 .02816 L
.4596 .02817 L
.46004 .02817 L
.46045 .02817 L
.46092 .02817 L
.46143 .02817 L
.46191 .02817 L
.46235 .02816 L
.46324 .02813 L
.46409 .02811 L
.46453 .02809 L
.46501 .02811 L
.46586 .02813 L
.46634 .02815 L
.4666 .02816 L
.46685 .02817 L
.46733 .02817 L
.46777 .02817 L
.46857 .02817 L
.46901 .02817 L
.46942 .02817 L
.46987 .02816 L
.47036 .02814 L
.47122 .02812 L
.47171 .0281 L
.47198 .02809 L
.47224 .0281 L
.4732 .02813 L
.47365 .02814 L
.47413 .02816 L
.47459 .02817 L
.47501 .02817 L
.47595 .02817 L
.47644 .02817 L
.47672 .02817 L
.47698 .02817 L
.47747 .02816 L
.478 .02814 L
.47851 .02812 L
.47878 .02811 L
.47907 .02811 L
.47934 .0281 L
.47958 .0281 L
.48006 .02811 L
Mistroke
.4811 .02814 L
.48156 .02816 L
.48206 .02817 L
.48254 .02817 L
.48297 .02817 L
.48353 .02817 L
.4838 .02817 L
.48405 .02817 L
.48452 .02817 L
.48476 .02816 L
.48502 .02815 L
.48607 .02812 L
.48638 .02811 L
.48667 .0281 L
.48692 .02809 L
.4872 .0281 L
.48819 .02813 L
.48862 .02815 L
.4891 .02816 L
.48954 .02817 L
.48995 .02817 L
.49086 .02817 L
.49136 .02817 L
.49162 .02817 L
.49187 .02817 L
.49231 .02816 L
.4928 .02814 L
.4938 .02811 L
.49409 .0281 L
.49437 .02809 L
.49461 .0281 L
.49488 .02811 L
.49578 .02814 L
.49628 .02815 L
.49675 .02817 L
.49718 .02817 L
.49766 .02817 L
.49849 .02817 L
.50246 .02817 L
.51048 .02817 L
.526 .02817 L
.54095 .02817 L
.55531 .02817 L
.57061 .02817 L
.58533 .02818 L
.60099 .02818 L
.61607 .02818 L
.63057 .02818 L
.64601 .02818 L
.66086 .02818 L
Mistroke
.67666 .02818 L
.69187 .02818 L
.70651 .02818 L
.72208 .02818 L
.73708 .02818 L
.7515 .02819 L
.76685 .02819 L
.78162 .02819 L
.79733 .02819 L
.81246 .02819 L
.82701 .02819 L
.8425 .02819 L
.85741 .02819 L
.87326 .02819 L
.88853 .02819 L
.90322 .02819 L
.91884 .0282 L
.93389 .0282 L
.94836 .0282 L
.96376 .0282 L
.97619 .0282 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[187]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008oooool2o`0002cooooo0ol00004ooooo`;o00009oooool3o`0000Cooooo0_l00004oooo
o`;o00008oooool3o`0000?ooooo0ol00004ooooo`;o00008_ooool5o`0000?ooooo0_l00004oooo
o`;o0000;?ooool002;ooooo00Co0000oooooooooooo0000:_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Pooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000[ooooo`00
8_ooool01?l0003oooooooooool0000^ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00008oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo0000:oooool002;ooooo00Co0000oooooooooooo0000;_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0:Oooool0
02;ooooo00Co0000oooooooooooo0000:_ooool4o`0000?ooooo00Co0000oooooooooooo00009ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00008oooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00008Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000[ooooo`008_ooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00009_ooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0000Rooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`00027ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000:oooool002?ooooo0_l0000[ooooo`Go00000oooool2o`00
02Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0000Tooooo`04o`000?oooooooooo
ooooo`Go00000oooool2o`0002?ooooo0ol00004ooooo`;o00001?ooool2o`0002cooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000NooooooSo00002_ooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo0?Cooooo
00?o0000ooooooooool02?ooool001Oooooo0_l00005ooooo`03o`000?oooooooooo0?Cooooo00?o
0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`3dooooo`03o`000?oooooooooo00Sooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0OOooool00ol0003oooooooooo`08ooooo`005_ooool01?l0003oooooooooool0
0004ooooo`;o00006_oooooFo`0000Cooooo0_l0000:ooooo`005_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo01Oooooo0ol0003Jooooo`03o`000?oooooooooo00Sooooo000F
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05Oooool2o`000=gooooo00?o
0000ooooooooool02?ooool001Oooooo0_l00005ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0gOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo0=kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`3Oooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0goooool00ol0003oooooooooo`08ooooo`007_oo
ool2o`0001;ooooo00?o0000ooooooooool0goooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0hOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0>;ooooo00?o0000ooooooooool02?ooool001ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3Rooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0hoooool00ol0003ooooo
ooooo`08ooooo`007_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0>?ooooo00?o
0000ooooooooool02?ooool001kooooo0_l0000>ooooo`03o`000?oooooooooo0>?ooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0>Cooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3Tooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
iOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo0>Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`3Uooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0i_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000co
oooo00?o0000ooooooooool0iOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0i_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo0>Kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`3Wooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0ioooool00ol0003oooooooooo`08oooo
o`002oooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0ioooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`3Wooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01?ooool2o`0000[ooooo00?o0000ooooooooool0ioooool2
o`0000[ooooo000:ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo0>Sooooo00?o0000ooooooooool02?ooool0
00[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`3Xooooo`03o`000?oooooooooo00Sooooo000:
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0jOooool00ol0003oooooooooo`08ooooo`002ooo
ool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0jOoo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo0>Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3Zooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00002?ooool00ol0003o
ooooooooo`3Yooooo`;o00002_ooool001kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3Zooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0j_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0>[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3Zooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0j_ooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0>[ooooo00?o0000ooooooooool0
2?ooool001kooooo0_l00007ooooo`03o`000?oooooooooo0>[ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0>_ooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3[ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0joooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0>_ooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3[ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0joooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Oooooo00?o0000oooo
ooooool0j_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0joooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0>_ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3[ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0joooool00ol0003oooooooooo`08ooooo`002oooool2o`00
00Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3[ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0>_ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001oooool5o`00
00Cooooo0_l00007ooooo`03o`000?oooooooooo0>[ooooo0_l0000:ooooo`002_ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3[ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0>_ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00002Oooool2
o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooo
oooo00Sooooo000;ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0>cooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`;o00001_ooool00ol0003oooooooooo`3[ooooo`;o00002_ooool001kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>cooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3/ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0k?oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0>cooooo00?o0000ooooooooool02?ooool001kooooo0_l00006ooooo`03o`000?oooooooooo
0>_ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>co
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3/ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0k?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0>cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0000Kooooo00?o0000ooooooooool0joooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>cooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo
00Sooooo000;ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0>cooooo00?o0000ooooooooool02?ooool000[ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`08ooooo`002_ooool01?l0
003oooooooooool00007ooooo`Co00001Oooool2o`0000Kooooo00?o0000ooooooooool0joooool2
o`0000[ooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>cooooo00?o0000ooooooooool02?ooool0
00[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`08ooooo`002oooool2o`00
00[ooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0k?ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>co
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3/ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0k?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Kooooo00?o0000
ooooooooool0joooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0k?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0>cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0k?ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>cooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`;o00001_ooool00ol0003oooooooooo`3[ooooo`;o00002_ooool001kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0k?ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>cooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3/oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0k?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0>cooooo00?o0000ooooooooool02?ooool001kooooo0_l00005ooooo`03o`000?oo
oooooooo0>cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0>gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3]ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`08ooooo`002oooool2o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3]ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0kOooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0>gooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00002?ooool3o`00
00Gooooo0_l00005ooooo`03o`000?oooooooooo0>cooooo0_l0000:ooooo`002_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00002Oooool3
o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0kOooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>go
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3]ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00001Oooool00ol0003ooooooooo
o`3/ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3]
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0kOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0>gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool02?ooool0
01kooooo0_l00005ooooo`03o`000?oooooooooo0>cooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_ooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3^oooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0k_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool0
kOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0>kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3^ooooo`03o`000?oooooooooo00Sooooo000Fooooo`?o00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o0000ooooooooool02?ooool001Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>kooooo
00?o0000ooooooooool02?ooool001Oooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o
0000ooooooooool0kOooool2o`0000[ooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0m?ooool00ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool02?ooool001Kooooo0_l00006ooooo`03
o`000?oooooooooo0?Cooooo00?o0000ooooooooool02?ooool001Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo0?Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`08ooooo`007_oooooho`0000[ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0015ooooo`;o000000Goooooo`000?l0
003o0000ooooo`03o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000001?l00002oooo
o`Co00000oooool2o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`000003ooooool0003o0000
00Oooooo0ol00002ooooo`?o00001?ooool4o`000005ooooool0003o0000o`000?ooool01_l00002
ooooo`Go00000_ooool3o`0000;ooooo0ol00009ooooo`?o00001Oooool2o`000003ooooool0003o
000000;o000000Coooooo`000?l0003ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol0
0002ooooo`?o000000?oooooo`000?l00000<oooool004Gooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000dooooo`00
AOooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000002oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol0
0003ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004oooo
o`04o`000?ooooooooooooooo`Go00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0booooo`00AOooool01ol0003ooooooooooooooooo
0000ooooool000000oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00Co
0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00002_ooool3o`0000?ooooo00Co0000
oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooo
oooo00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`0booooo`00AOooool01Ol0003oooooo`000?oooooo000000;ooooo0ol0
0003ooooo`?o00000_ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooooooool00_oo
ool2o`0000?ooooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l00008ooooo`06o`000?oo
oooo0000ooooool0003ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000?o
oooo1?l00002ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`03
o`000?oooooooooo00;ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00002oooo
o`Co00000_ooool3o`0000Cooooo0ol00002ooooo`Co0000=Oooool004Gooooo0_l000000ooooooo
0000o`00000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Jooooo`05o`000?oooooo0000ooooool000006oooool00ol0003oooooooooo`0Doooo
o`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0Aoooool004Gooooo00Co0000oooo
oooooooooooo0_l00008ooooo`;o00002?ooool3o`0000[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Cooooo`Go00007?ooool2o`0001?ooooo1Ol0000Dooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0@?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-36.0042, -0.137062, \
0.992297, 0.00720095}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(ComponentNumber \[Rule] 4.`\), ",", \(Energy \[Rule] 100.`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalFraction \[Rule] 0\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrequencyCutoff \[Rule] {233.58412465573463`, 
            235.36524902675103`}\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(Full3D \[Rule] True\), 
        ",", \(GeometricPointSpreadFunction \[Rule] True\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {207.28232192993164`, 0, 0}\), 
        ",", \(ImageSampleSize \[Rule] {0.001427037620063491`, 
            0.0014162385259152998`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", 
        RowBox[{"ModulationTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-117.25187359687467`\), 
                  116.64118675522428`}, {\(-118.14594193271952`\), 
                  117.53059848515326`}}, "<>"]\),
            False,
            Editable->False]}], ",", \(NumberOfPoints \[Rule] 128\), 
        ",", \(NumberOfRays \[Rule] 4096\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(PointOfRays[{10, 10}, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(OpticalMedium \[Rule] Air\), ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"PointSpreadFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}], ",", 
              RowBox[{"ModulationTransferFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      Graphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], "}"}]}], 
        ",", \(PerfectModulationTransferFunction \[Rule] 
          PerfectModulationTransferFunction\), 
        ",", \(PerfectPhaseTransferFunction \[Rule] 
          PerfectPhaseTransferFunction\), ",", 
        RowBox[{"PhaseTransferFunction", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{\(-117.25187359687467`\), 
                  116.64118675522428`}, {\(-118.14594193271952`\), 
                  117.53059848515326`}}, "<>"]\),
            False,
            Editable->False]}], 
        ",", \(PointSpreadFunction \[Rule] 
          "CompiledFunction[-intensity data-]"\), 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(RayBoundary \[Rule] {{\(-0.271850666622095`\), 
              0.271850666622095`}, {\(-0.2697934391868646`\), 
              0.2697934391868646`}}\), 
        ",", \(RayTraceFunction \[Rule] 
          "RayTraceFunction[{f1, f2}, -raytrace code: 7545428 Bytes- ]"\), 
        ",", \(RotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}\), 
        ",", \(SmoothKernelSize \[Rule] 0.024191317607805556`\), 
        ",", \(SourceID \[Rule] 19474\), 
        ",", \(SurfaceNormalFunction \[Rule] \(({{1, 0, 0}, {0, 1, 0}, {0, 0, 
                  1}} &)\)\), ",", \(SurfaceNumber \[Rule] 1.`\), 
        ",", \(SymbolicValues \[Rule] {f1 \[Rule] 100.`, f2 \[Rule] 100.`}\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1.`\), 
        ",", \(WaveLength \[Rule] 0.532`\)}], "}"}]], "Output",
  CellLabel->"Out[187]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GPSF[sys, NumberOfPoints->512]", "Input",
  CellLabel->"In[185]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 2.41917 0.0141979 0.000688514 [
[.01617 .0017 -12 -9 ]
[.01617 .0017 12 0 ]
[.25808 .0017 -12 -9 ]
[.25808 .0017 12 0 ]
[.74192 .0017 -9 -9 ]
[.74192 .0017 9 0 ]
[.98383 .0017 -9 -9 ]
[.98383 .0017 9 0 ]
[.4875 .1519 -18 -4.5 ]
[.4875 .1519 0 4.5 ]
[.4875 .2896 -18 -4.5 ]
[.4875 .2896 0 4.5 ]
[.4875 .42731 -18 -4.5 ]
[.4875 .42731 0 4.5 ]
[.4875 .56501 -18 -4.5 ]
[.4875 .56501 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01617 .0142 m
.01617 .02045 L
s
[(-0.2)] .01617 .0017 0 1 Mshowa
.25808 .0142 m
.25808 .02045 L
s
[(-0.1)] .25808 .0017 0 1 Mshowa
.74192 .0142 m
.74192 .02045 L
s
[(0.1)] .74192 .0017 0 1 Mshowa
.98383 .0142 m
.98383 .02045 L
s
[(0.2)] .98383 .0017 0 1 Mshowa
.125 Mabswid
.06455 .0142 m
.06455 .01795 L
s
.11293 .0142 m
.11293 .01795 L
s
.16132 .0142 m
.16132 .01795 L
s
.2097 .0142 m
.2097 .01795 L
s
.30647 .0142 m
.30647 .01795 L
s
.35485 .0142 m
.35485 .01795 L
s
.40323 .0142 m
.40323 .01795 L
s
.45162 .0142 m
.45162 .01795 L
s
.54838 .0142 m
.54838 .01795 L
s
.59677 .0142 m
.59677 .01795 L
s
.64515 .0142 m
.64515 .01795 L
s
.69353 .0142 m
.69353 .01795 L
s
.7903 .0142 m
.7903 .01795 L
s
.83868 .0142 m
.83868 .01795 L
s
.88707 .0142 m
.88707 .01795 L
s
.93545 .0142 m
.93545 .01795 L
s
.25 Mabswid
0 .0142 m
1 .0142 L
s
.5 .1519 m
.50625 .1519 L
s
[(200)] .4875 .1519 1 0 Mshowa
.5 .2896 m
.50625 .2896 L
s
[(400)] .4875 .2896 1 0 Mshowa
.5 .42731 m
.50625 .42731 L
s
[(600)] .4875 .42731 1 0 Mshowa
.5 .56501 m
.50625 .56501 L
s
[(800)] .4875 .56501 1 0 Mshowa
.125 Mabswid
.5 .04862 m
.50375 .04862 L
s
.5 .08305 m
.50375 .08305 L
s
.5 .11748 m
.50375 .11748 L
s
.5 .18633 m
.50375 .18633 L
s
.5 .22075 m
.50375 .22075 L
s
.5 .25518 m
.50375 .25518 L
s
.5 .32403 m
.50375 .32403 L
s
.5 .35845 m
.50375 .35845 L
s
.5 .39288 m
.50375 .39288 L
s
.5 .46173 m
.50375 .46173 L
s
.5 .49616 m
.50375 .49616 L
s
.5 .53058 m
.50375 .53058 L
s
.5 .59943 m
.50375 .59943 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Geometric Point Spread Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02933 .04866 L
.03011 .05846 L
.03096 .06815 L
.03176 .07554 L
.0325 .08053 L
.03317 .08361 L
.0339 .08576 L
.03467 .08703 L
.03538 .08766 L
.03615 .08801 L
.03685 .08819 L
.03766 .08833 L
.03844 .08843 L
.0417 .08883 L
.04759 .08955 L
.07351 .09292 L
.09702 .09631 L
.12203 .10032 L
.14611 .10465 L
.1717 .10988 L
.19636 .11564 L
.22008 .12203 L
.24531 .12998 L
.26961 .13907 L
.29298 .14958 L
.31786 .16333 L
.3418 .18007 L
.36725 .20343 L
.37999 .2182 L
.39177 .23437 L
.41536 .27696 L
.42685 .30473 L
.43952 .34308 L
.45143 .38863 L
.46426 .44999 L
.47635 .51707 L
.48275 .55189 L
.48626 .56896 L
.48958 .58273 L
.49276 .59307 L
.49455 .59744 L
.4954 .59912 L
.4962 .60044 L
.49693 .60143 L
.49759 .60216 L
.49833 .60276 L
.49912 .60317 L
.49988 .60332 L
.50031 .6033 L
Mistroke
.50071 .60322 L
.50144 .60291 L
.50221 .60234 L
.50301 .60151 L
.50374 .60053 L
.50539 .59757 L
.50685 .59414 L
.50838 .58973 L
.51396 .56792 L
.53736 .44151 L
.5504 .38093 L
.56227 .33706 L
.58625 .2735 L
.59802 .25085 L
.6108 .2306 L
.63593 .20011 L
.66013 .17857 L
.68339 .16256 L
.70816 .14902 L
.732 .13842 L
.75735 .12907 L
.78177 .1215 L
.80525 .11524 L
.83024 .10945 L
.8543 .10458 L
.87987 .1 L
.90451 .09608 L
.92821 .09268 L
.94023 .09109 L
.94659 .09028 L
.95342 .08942 L
.95658 .08904 L
.95958 .08868 L
.96088 .08852 L
.96227 .08834 L
.96299 .08822 L
.96379 .08803 L
.96451 .08772 L
.96519 .08718 L
.96584 .08629 L
.96654 .08462 L
.96727 .08173 L
.96795 .07767 L
.96859 .07251 L
.96918 .06669 L
.97048 .05098 L
.97189 .03421 L
.97269 .02681 L
.97342 .02178 L
.97406 .01874 L
Mistroke
.97476 .0166 L
.9755 .01533 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[185]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`004_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000^ooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`?o0000J_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002oooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00003Oooool0017ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool0000]ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool0J?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
02gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000=ooooo`002_ooool5
o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Vooooo`Go00000_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo06Sooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool03Oooool0017ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0/oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0J?ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`0<ooooo`004Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
0000;Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo06Sooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`00000=ooooo`004Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool00000;Oooool01?l0003oooooooooool00008ooooo`;o0000J_ooool01?l0
003oooooooooool00008ooooo`;o0000;oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000003Oooool001;ooooo0_l00009ooooo`?o0000;oooool2o`0000[ooooo00?o
0000ooooooooool0JOooool2o`0000[ooooo00?o0000ooooooooool0;_ooool2o`0000Wooooo0ol0
000>ooooo`00TOooool00ol0003oooooooooo`2<ooooo`00TOooool00ol0003oooooooooo`2<oooo
o`00TOooool00ol0003oooooooooo`2<ooooo`00TOooool00ol0003oooooooooo`2<ooooo`004_oo
ooono`00013ooooo000Fooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooool0000Dooooo`006?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooo
oooo07Cooooo00?o0000ooooooooool05Oooool001Wooooo00?o0000ooooooooool0MOooool00ol0
003oooooooooo`1dooooo`03o`000?oooooooooo01Gooooo000Iooooo`03o`000?oooooooooo07Go
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0Eooooo`006Oooool00ol0003ooooo
ooooo`1eooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool05Oooool001Wooooo00?o
0000ooooooooool0MOooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo01Gooooo000J
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0E
ooooo`006_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool05_ooool001[ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`0Fooooo`006_ooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool05_ooool001[ooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Fooooo`006_ooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool05_ooool001[ooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo01Kooooo
000Jooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`0Fooooo`006oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool05_ooool001_ooooo0_l0001dooooo`03o`000?oooooooooo077ooooo0_l0000Ioooo
o`007Oooool6o`0006kooooo00?o0000ooooooooool0Joooool7o`0001[ooooo000Sooooo`co0000
H_ooool00ol0003oooooooooo`1Pooooo`_o00008Oooool002oooooo1Ol0001Mooooo`03o`000?oo
oooooooo05_ooooo1Ol0000/ooooo`00=?ooool3o`0005[ooooo00?o0000ooooooooool0F?ooool3
o`00037ooooo000gooooo`Go0000EOooool00ol0003oooooooooo`1Cooooo`Go0000=?ooool003co
oooo1_l0001?ooooo`03o`000?oooooooooo04gooooo1_l0000iooooo`00@_ooool5o`0004[ooooo
00?o0000ooooooooool0BOooool4o`0003oooooo0017ooooo`?o0000Aoooool00ol0003ooooooooo
o`16ooooo`?o0000@oooool004[ooooo0ol00014ooooo`03o`000?oooooooooo04?ooooo0ol00016
ooooo`00COooool3o`00047ooooo00?o0000ooooooooool0@?ooool3o`0004Wooooo001@ooooo`?o
0000?_ooool00ol0003oooooooooo`0looooo`Co0000C?ooool005?ooooo0ol0000kooooo`03o`00
0?oooooooooo03Wooooo0ol0001@ooooo`00E_ooool2o`0003Wooooo00?o0000ooooooooool0=_oo
ool3o`0005?ooooo001Hooooo`;o00008Oooool5o`0000?ooooo0_l00004ooooo`;o00001_ooool0
0ol0003oooooooooo`0dooooo`;o0000E_ooool005[ooooo0_l0000Pooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo03;ooooo0_l0001Hooooo`00G?ooool2o`0001oooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool0<?ooool2o`0005[ooooo001Nooooo`;o00007_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`;o0000;oooool2o`00
05cooooo001Pooooo`;o00006Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo02cooooo0_l0
001Nooooo`00H_ooool2o`0001Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Zooooo`;o
0000H?ooool006Cooooo00?o0000ooooooooool05Oooool3o`0000Cooooo0_l00004ooooo`;o0000
1_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo063ooooo001Uooooo`;o0000:_oo
ool00ol0003oooooooooo`0Wooooo`;o0000Hoooool006Oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06?ooooo001Xooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Tooooo`00JOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0IOooool006[ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Kooooo
001[ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`1Wooooo`00K?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0J?ooool006gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo06Wooooo001^ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`1Zooooo`00Koooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0J_ooool0073ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06_ooooo001aooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1/ooooo`00L_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0KOooool007;o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06ko
oooo001cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1_ooooo`00M?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0L?ooool007Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo073ooooo001eooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`1aooooo`00M_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0L_ooool007Kooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07;ooooo001gooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1cooooo`00Moooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0M?ooool0
07Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
07Cooooo001iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1eooooo`00NOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0M_ooool007[ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo07Kooooo001jooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1gooooo`00Noooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Moooool007_ooooo00?o0000ooooool0
00000_l00003ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1hooooo`00O?ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
07Sooooo001kooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Gooooo0_l0000Booooo`03o`000?oooooooooo07Sooooo001kooooo`04o`000?oooooo0000
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0NOooool007cooooo0ol00003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo07Wooooo001mooooo`;o00000oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1ioooo
o`00O_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool2o`0000Kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1jooooo`00O_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0N_ooool007kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07_ooooo001oooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1kooooo`00Ooooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Noooool007oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07co
oooo0020ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1looooo`00P?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0O?ooool0083ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo07gooooo0021ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1mooooo`00POooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0OOooool0087ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07kooooo0021ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1nooooo`00P_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0O_ooool0
08;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
07oooooo0022ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1oooooo`00Poooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0Ooooool008?ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo07oooooo0023ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`20ooooo`00Poooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0P?ooool008Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo083ooooo0024ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`20ooooo`00Q?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0P?oo
ool008Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo087ooooo0024ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`21ooooo`00QOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0POooool008Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo087ooooo0025ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`21ooooo`00QOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0P_ooool007cooooo0ol00004oooo
o`?o00000oooool2o`0000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`22oooo
o`00Noooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_l000001Ooo
oooo0000oooooooooooo000000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`22
ooooo`00Noooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_l00000
1Ooooooo0000oooooooooooo000000Gooooo0_l00008ooooo`03o`000?oooooooooo08;ooooo001k
ooooo`Co00000oooool00ol0003oooooooooo`02o`000005ooooool0003oooooooooool000001Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08;ooooo001kooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_l000001Ooooooo0000oooooooooooo000000Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`23ooooo`00O?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`000005ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Poooool007gooooo0_l00004ooooo`;o00000_ooool0
1?l0003oooooo`000?l00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Pooo
ool008Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo08?ooooo0027ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`23ooooo`00Qoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Poooool008Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo08Cooooo0028ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`24ooooo`00R?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q?ooool008Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Cooooo0028ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`24ooooo`00
ROooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
QOooool008Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo08Gooooo0029ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`25ooooo`00ROooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0QOooool008Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo08Gooooo002:ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`26ooooo`00R_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Q_ooool008[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Kooooo002:oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`26oooo
o`00Roooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Q_ooool008_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo08Kooooo002;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`27ooooo`00Roooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Qoooool008_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo08Oooooo002;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`27ooooo`00S?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Qoooool008cooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000008[ooooo002<ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00002:ooooo`00S?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000R_ooool007cooooo0ol00004ooooo`;o00001?oo
ool2o`000003ooooool0003ooooo00?ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Nooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02o`0000Cooooo00Go0000ooooooooooooooooo`00002:ooooo`00Noooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02
o`0000Cooooo00Co0000oooooooooooo0000Roooool007cooooo0ol00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`;o000000?oooooo`000?oo
ool0R_ooool007_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0008_ooooo
001kooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool0002;ooooo`00O?ooool3
o`0000Cooooo0_l00004ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo08Wooooo002>ooooo`06o`000?ooooooooooo`000?oooooo0000S?ooool008kooooo00Ko
0000oooooooooooo0000ooooool0002<ooooo`00Soooool01Ol0003oooooo`000?oooooo000008co
oooo002?ooooo`04o`000?oooooo0000o`0008gooooo002?ooooo`04o`000?oooooo0000o`0008go
oooo002?ooooo`?o0000S_ooool0093ooooo0_l0002>ooooo`00TOooool00ol0003oooooooooo`2<
ooooo`00TOooool00ol0003oooooooooo`2<ooooo`00TOooool00ol0003oooooooooo`2<ooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00V_ooool3o`0008?ooooo002Kooooo`03
o`000?oooooooooo08;ooooo000eooooo`?o00000oooool3o`0000?ooooo0ol00002ooooo`05o`00
0?oooooo0000ooooool000000_ooool3o`0000Cooooo0_l00002ooooo`?o00000oooool5o`0000;o
oooo0ol00008ooooo`?o00001?ooool3o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003ooooo
00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o00000_ooool3o`0000Cooooo0ol00003oooo
o`Co00000_ooool4o`0000Oooooo0ol00005ooooo`;o000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?ooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000;ooooo0ol00000
0ooooooo0000o`00000booooo`00=?ooool01ol0003ooooooooooooooooo0000ooooool000001Ooo
ool03Ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo0000ooooool000001_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003o
ooooooooool00002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo0000<oooool003Cooooo00Ko0000oooooooooooooooo
o`000?ooool5o`000003ooooool0003ooooo00;ooooo00So0000ooooool0003oooooo`000?oooooo
0000ooooo`Go00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool5o`0000;ooooo0ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo037ooooo000dooooo`03o`000?oooooo000000Co00000ooo
ool00ol0003oooooo`000003ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo0000
00?ooooo00Co0000oooooooooooo00001Oooool2o`0000Gooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo0ol00002ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool02_ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`07ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool01?l0003oooooooooool00006ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo037ooooo000dooooo`03o`00
0?oooooooooo00Cooooo0ol00003ooooo`?o00000_ooool2o`000003ooooool0003ooooo00;ooooo
0ol00002ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`?o00001?ooool3o`0000Wo
oooo00Co0000oooooooooooo00000_ooool3o`0000;ooooo0ol00003ooooo`Co00000_ooool4o`00
00Wooooo00?o0000ooooooooool00_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`?o00000oooool2o`0000Cooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo0_l000001?oo
oooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co00000_ooool3o`0000Cooooo0ol00002
ooooo`Co0000=?ooool003Cooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooo
oooo01_ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooo`0001cooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0000Dooooo`03
o`000?oooooooooo04Kooooo000eooooo`?o00006oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00gooooo1?l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2_ooool3o`0001_ooooo0_l00008ooooo`Go00005?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03oooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.237144, -69.8745, \
0.00163548, 5.74643}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(ComponentNumber \[Rule] 4.`\), 
        ",", \(Energy \[Rule] 99.99999999999757`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(Full3D \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {208.`, 0.`, 0.`}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", \(NumberOfPoints \[Rule] 512\), 
        ",", \(NumberOfRays \[Rule] 1064\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(WedgeOfRays[10, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(OpticalMedium \[Rule] Air\), 
        ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"PointSpreadFunction", "\[Rule]", 
              RowBox[{"(", 
                
                TagBox[\(\[SkeletonIndicator]  
                    Graphics  \[SkeletonIndicator]\),
                  False,
                  Editable->False], ")"}]}], "}"}]}], 
        ",", \(PointSpreadFunction \[Rule] 
          "CompiledFunction[-intensity data-]"\), 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(RayBoundary \[Rule] {\(-0.19404209732377797`\), 
            0.19404209732377975`}\), 
        ",", \(RayTraceFunction \[Rule] 
          "RayTraceFunction[{f1, f2}, -raytrace code: 2672860 Bytes- ]"\), 
        ",", \(RotationMatrix \[Rule] {{\(-1\), 0, 0}, {0, \(-1\), 0}, {0, 0, 
              1}}\), ",", \(SmoothKernelSize \[Rule] 0.0013991656871787939`\),
         ",", \(SourceID \[Rule] 19920\), 
        ",", \(SurfaceNormalFunction \[Rule] \(({{1, 0, 0}, {0, 1, 0}, {0, 0, 
                  1}} &)\)\), ",", \(SurfaceNumber \[Rule] 1.`\), 
        ",", \(SymbolicValues \[Rule] {f1 \[Rule] 100.`, f2 \[Rule] 100.`}\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1.`\), 
        ",", \(WaveLength \[Rule] 0.532`\)}], "}"}]], "Output",
  CellLabel->"Out[185]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["GPSF[sys, NumberOfPoints->512, FindImagePoint->True]", "Input",
  CellLabel->"In[186]:=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 13.3459 0.0103807 7.36416e-05 [
[.09962 -0.00212 -15 -9 ]
[.09962 -0.00212 15 0 ]
[.23308 -0.00212 -15 -9 ]
[.23308 -0.00212 15 0 ]
[.36654 -0.00212 -15 -9 ]
[.36654 -0.00212 15 0 ]
[.63346 -0.00212 -12 -9 ]
[.63346 -0.00212 12 0 ]
[.76692 -0.00212 -12 -9 ]
[.76692 -0.00212 12 0 ]
[.90038 -0.00212 -12 -9 ]
[.90038 -0.00212 12 0 ]
[.4875 .15766 -24 -4.5 ]
[.4875 .15766 0 4.5 ]
[.4875 .30495 -24 -4.5 ]
[.4875 .30495 0 4.5 ]
[.4875 .45223 -24 -4.5 ]
[.4875 .45223 0 4.5 ]
[.4875 .59951 -24 -4.5 ]
[.4875 .59951 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09962 .01038 m
.09962 .01663 L
s
[(-0.03)] .09962 -0.00212 0 1 Mshowa
.23308 .01038 m
.23308 .01663 L
s
[(-0.02)] .23308 -0.00212 0 1 Mshowa
.36654 .01038 m
.36654 .01663 L
s
[(-0.01)] .36654 -0.00212 0 1 Mshowa
.63346 .01038 m
.63346 .01663 L
s
[(0.01)] .63346 -0.00212 0 1 Mshowa
.76692 .01038 m
.76692 .01663 L
s
[(0.02)] .76692 -0.00212 0 1 Mshowa
.90038 .01038 m
.90038 .01663 L
s
[(0.03)] .90038 -0.00212 0 1 Mshowa
.125 Mabswid
.12631 .01038 m
.12631 .01413 L
s
.15301 .01038 m
.15301 .01413 L
s
.1797 .01038 m
.1797 .01413 L
s
.20639 .01038 m
.20639 .01413 L
s
.25977 .01038 m
.25977 .01413 L
s
.28647 .01038 m
.28647 .01413 L
s
.31316 .01038 m
.31316 .01413 L
s
.33985 .01038 m
.33985 .01413 L
s
.39323 .01038 m
.39323 .01413 L
s
.41992 .01038 m
.41992 .01413 L
s
.44662 .01038 m
.44662 .01413 L
s
.47331 .01038 m
.47331 .01413 L
s
.52669 .01038 m
.52669 .01413 L
s
.55338 .01038 m
.55338 .01413 L
s
.58008 .01038 m
.58008 .01413 L
s
.60677 .01038 m
.60677 .01413 L
s
.66015 .01038 m
.66015 .01413 L
s
.68684 .01038 m
.68684 .01413 L
s
.71353 .01038 m
.71353 .01413 L
s
.74023 .01038 m
.74023 .01413 L
s
.79361 .01038 m
.79361 .01413 L
s
.8203 .01038 m
.8203 .01413 L
s
.84699 .01038 m
.84699 .01413 L
s
.87369 .01038 m
.87369 .01413 L
s
.07293 .01038 m
.07293 .01413 L
s
.04624 .01038 m
.04624 .01413 L
s
.01955 .01038 m
.01955 .01413 L
s
.92707 .01038 m
.92707 .01413 L
s
.95376 .01038 m
.95376 .01413 L
s
.98045 .01038 m
.98045 .01413 L
s
.25 Mabswid
0 .01038 m
1 .01038 L
s
.5 .15766 m
.50625 .15766 L
s
[(2000)] .4875 .15766 1 0 Mshowa
.5 .30495 m
.50625 .30495 L
s
[(4000)] .4875 .30495 1 0 Mshowa
.5 .45223 m
.50625 .45223 L
s
[(6000)] .4875 .45223 1 0 Mshowa
.5 .59951 m
.50625 .59951 L
s
[(8000)] .4875 .59951 1 0 Mshowa
.125 Mabswid
.5 .0472 m
.50375 .0472 L
s
.5 .08402 m
.50375 .08402 L
s
.5 .12084 m
.50375 .12084 L
s
.5 .19448 m
.50375 .19448 L
s
.5 .23131 m
.50375 .23131 L
s
.5 .26813 m
.50375 .26813 L
s
.5 .34177 m
.50375 .34177 L
s
.5 .37859 m
.50375 .37859 L
s
.5 .41541 m
.50375 .41541 L
s
.5 .48905 m
.50375 .48905 L
s
.5 .52587 m
.50375 .52587 L
s
.5 .56269 m
.50375 .56269 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Geometric Point Spread Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02933 .29627 L
.03011 .38753 L
.03096 .48077 L
.03176 .55003 L
.0325 .5897 L
.03317 .60332 L
.0339 .59617 L
.03467 .56991 L
.03538 .53503 L
.03698 .45143 L
.03844 .39033 L
.03924 .36479 L
.04001 .34492 L
.0417 .31174 L
.04316 .29061 L
.04451 .27481 L
.04759 .24744 L
.05097 .22559 L
.05417 .20985 L
.06014 .18802 L
.06656 .17118 L
.07351 .15758 L
.08578 .14039 L
.09196 .13381 L
.09366 .1322 L
.09459 .13137 L
.09547 .13065 L
.09629 .1301 L
.09676 .12988 L
.09719 .12976 L
.09794 .1298 L
.09875 .13031 L
.09945 .13121 L
.10021 .13267 L
.10096 .13441 L
.10176 .13626 L
.1025 .13757 L
.10318 .1381 L
.10387 .13785 L
.10451 .13692 L
.10596 .13359 L
.10669 .13215 L
.1075 .13133 L
.10791 .13127 L
.10837 .13146 L
.10918 .13223 L
.10999 .13301 L
.11073 .13325 L
.11142 .1328 L
Mistroke
.11216 .13161 L
.11349 .12861 L
.1143 .12717 L
.11507 .12661 L
.11576 .12679 L
.1165 .1275 L
.11722 .12829 L
.11789 .12874 L
.11859 .12862 L
.11935 .1277 L
.12002 .1264 L
.12062 .12506 L
.12128 .12374 L
.12198 .12281 L
.12271 .12257 L
.12339 .12296 L
.1242 .12387 L
.12495 .12463 L
.12568 .12486 L
.12648 .12428 L
.12689 .12367 L
.12732 .12285 L
.12809 .1212 L
.12883 .11986 L
.12962 .11909 L
.13037 .11916 L
.13106 .11977 L
.13173 .12058 L
.13236 .12121 L
.13302 .12144 L
.13375 .12101 L
.14653 .11495 L
.15295 .11145 L
.15374 .11243 L
.15448 .11309 L
.15526 .11313 L
.15567 .11282 L
.15611 .11226 L
.15754 .10972 L
.15825 .10876 L
.15904 .10841 L
.15975 .10878 L
.16052 .10965 L
.16122 .11048 L
.16189 .11095 L
.16255 .11087 L
.16326 .11017 L
.16391 .10911 L
.1645 .10803 L
.16521 .10695 L
Mistroke
.16588 .10643 L
.16661 .10651 L
.16739 .10724 L
.16779 .10773 L
.16821 .10825 L
.16899 .10889 L
.16975 .10884 L
.17045 .10815 L
.17124 .10686 L
.17198 .10562 L
.17274 .10473 L
.17315 .10454 L
.17358 .10459 L
.17406 .10489 L
.1745 .10535 L
.17494 .10589 L
.17534 .10638 L
.17612 .10703 L
.17653 .10711 L
.17696 .10695 L
.17849 .10489 L
.17928 .10362 L
.17969 .10317 L
.18013 .10289 L
.18093 .10302 L
.18167 .10374 L
.1824 .10463 L
.18309 .10526 L
.18376 .10539 L
.18447 .10491 L
.18513 .10401 L
.18573 .10301 L
.18643 .10196 L
.18709 .10139 L
.18778 .10136 L
.18854 .10195 L
.18932 .10289 L
.19005 .10362 L
.19071 .10384 L
.19144 .10346 L
.19222 .10243 L
.19305 .1011 L
.19384 .10015 L
.19455 .09988 L
.19529 .10025 L
.19598 .10101 L
.19641 .10152 L
.19681 .10195 L
.19756 .10238 L
.1983 .10216 L
Mistroke
.19909 .10124 L
.19988 .10002 L
.20029 .09942 L
.20074 .09891 L
.20148 .09856 L
.20217 .09884 L
.20297 .09967 L
.20369 .10051 L
.20436 .10099 L
.20509 .10095 L
.20578 .10033 L
.20642 .09942 L
.20723 .09822 L
.20768 .09771 L
.2081 .09743 L
.20887 .09746 L
.20968 .09815 L
.21036 .09895 L
.21108 .09963 L
.21188 .09977 L
.21263 .09922 L
.21348 .09804 L
.21393 .09738 L
.21441 .09677 L
.21482 .09641 L
.21528 .09623 L
.21609 .09653 L
.21687 .09734 L
.21729 .09782 L
.21772 .09825 L
.21852 .09864 L
.21925 .09835 L
.22001 .09748 L
.22083 .09629 L
.22161 .09543 L
.22232 .09519 L
.22297 .09548 L
.22368 .09619 L
.22442 .09701 L
.22512 .0975 L
.22551 .09755 L
.22593 .09741 L
.22668 .09669 L
.22749 .09555 L
.22794 .09496 L
.22836 .09453 L
.22875 .09428 L
.22918 .09422 L
.22993 .0946 L
.23069 .09539 L
Mistroke
.23139 .09613 L
.23205 .09651 L
.23275 .09641 L
.23341 .09582 L
.23401 .09503 L
.23472 .09408 L
.23549 .09341 L
.23622 .09336 L
.23689 .09382 L
.23759 .09457 L
.23834 .0953 L
.23905 .09559 L
.2397 .09536 L
.2404 .09466 L
.24112 .09368 L
.24187 .09283 L
.2423 .09255 L
.24269 .09247 L
.24348 .09281 L
.24388 .09317 L
.24431 .09365 L
.24508 .0944 L
.24581 .0947 L
.24624 .09461 L
.24666 .09433 L
.24743 .09344 L
.24828 .09236 L
.24871 .09195 L
.24918 .09171 L
.24996 .09184 L
.2507 .09246 L
.25139 .09319 L
.25211 .09375 L
.25291 .0938 L
.25364 .09325 L
.25443 .09227 L
.25485 .09175 L
.2553 .0913 L
.25607 .09094 L
.2568 .09118 L
.25751 .09183 L
.25816 .0925 L
.25887 .093 L
.25965 .09299 L
.26046 .09233 L
.26122 .09139 L
.26194 .09062 L
.26261 .09026 L
.26322 .09035 L
.26388 .09084 L
Mistroke
.2646 .09156 L
.26537 .09219 L
.26609 .09232 L
.26674 .09197 L
.26748 .09117 L
.26817 .09034 L
.26893 .08972 L
.26974 .08966 L
.27015 .08988 L
.2706 .09026 L
.2714 .09106 L
.27219 .09158 L
.27291 .09155 L
.27359 .09106 L
.27422 .09035 L
.27498 .0895 L
.27567 .08905 L
.27635 .08906 L
.27707 .08954 L
.27785 .0903 L
.27859 .09085 L
.27939 .09093 L
.28012 .09046 L
.28091 .08959 L
.28132 .08914 L
.28176 .08873 L
.28251 .08842 L
.2833 .08869 L
.28403 .08933 L
.28471 .08996 L
.28512 .09023 L
.28558 .09036 L
.286 .09029 L
.2864 .09007 L
.28714 .08935 L
.28794 .08848 L
.28839 .08811 L
.28888 .08791 L
.28934 .08793 L
.28976 .08812 L
.29056 .08879 L
.291 .0892 L
.2914 .08952 L
.29216 .08977 L
.29256 .08969 L
.29298 .08943 L
.29369 .08874 L
.29447 .08792 L
.29516 .08746 L
.29591 .08745 L
Mistroke
.29661 .08789 L
.29725 .08847 L
.29805 .08907 L
.29879 .0892 L
.2996 .08876 L
.30005 .08832 L
.30046 .08788 L
.30122 .08718 L
.30164 .08696 L
.30204 .08691 L
.30276 .08719 L
.30352 .08782 L
.30421 .08839 L
.30486 .08868 L
.30561 .08853 L
.3063 .088 L
.3069 .08738 L
.30754 .0868 L
.30825 .08648 L
.3089 .08659 L
.30959 .08706 L
.31035 .08771 L
.31106 .08814 L
.31171 .08817 L
.31243 .08775 L
.31322 .08699 L
.31362 .08661 L
.31404 .08628 L
.31481 .08606 L
.31557 .08634 L
.316 .08666 L
.3164 .087 L
.31721 .08758 L
.31767 .08772 L
.31808 .08769 L
.31882 .08727 L
.31963 .08651 L
.3204 .08587 L
.3211 .08565 L
.32153 .08574 L
.322 .086 L
.32244 .08634 L
.32284 .08668 L
.3236 .08718 L
.32441 .08724 L
.32483 .08705 L
.32528 .08671 L
.32609 .08596 L
.32659 .08557 L
.32705 .08535 L
Mistroke
.32747 .0853 L
.32793 .08542 L
.3287 .08592 L
.32942 .08649 L
.33021 .08686 L
.33065 .08685 L
.33106 .08669 L
.33182 .08609 L
.33224 .0857 L
.33264 .08535 L
.33311 .08506 L
.33354 .08494 L
.33394 .08498 L
.33437 .08516 L
.3351 .08569 L
.33578 .08619 L
.3365 .08646 L
.33728 .08629 L
.33804 .08573 L
.33847 .08536 L
.33887 .08504 L
.33963 .08466 L
.34033 .08471 L
.3411 .08515 L
.34151 .08546 L
.34193 .08577 L
.34272 .0861 L
.34344 .08597 L
.34413 .08549 L
.34478 .08492 L
.34549 .08443 L
.34625 .08432 L
.34707 .0847 L
.34753 .08504 L
.34795 .08534 L
.34873 .08571 L
.34912 .08573 L
.34955 .08562 L
.3503 .08514 L
.3511 .0845 L
.35186 .0841 L
.35256 .08408 L
.35325 .0844 L
.354 .08492 L
.3547 .08532 L
.35533 .08541 L
.35608 .08511 L
.35689 .08447 L
.35766 .08392 L
.35836 .08374 L
Mistroke
.35902 .08393 L
.35964 .08433 L
.36038 .08484 L
.36105 .08509 L
.36175 .08499 L
.36242 .08461 L
.36312 .08407 L
.36388 .08364 L
.36464 .08356 L
.36534 .08382 L
.366 .08423 L
.36671 .08463 L
.36748 .08478 L
.36819 .08455 L
.36898 .084 L
.36942 .08368 L
.36982 .08343 L
.37022 .08329 L
.37064 .08327 L
.37106 .08338 L
.37152 .08362 L
.3723 .08416 L
.37273 .0844 L
.37313 .08453 L
.37392 .08442 L
.37468 .08395 L
.37544 .08339 L
.37613 .08309 L
.37683 .08312 L
.3775 .08343 L
.37825 .08389 L
.37895 .08418 L
.37956 .08421 L
.3802 .08399 L
.38085 .08359 L
.38156 .08315 L
.38233 .08289 L
.38303 .08297 L
.38385 .08338 L
.38461 .08381 L
.38533 .08401 L
.38598 .08389 L
.3867 .08348 L
.38747 .08295 L
.38817 .08265 L
.38894 .08273 L
.38974 .08317 L
.39048 .08363 L
.39119 .08381 L
.39182 .08368 L
Mistroke
.39256 .08324 L
.39325 .08278 L
.394 .0825 L
.3948 .08261 L
.39549 .08294 L
.39624 .08333 L
.39704 .08352 L
.3975 .08347 L
.39791 .08332 L
.39871 .0829 L
.39947 .08252 L
.40012 .08238 L
.40083 .08248 L
.40157 .08281 L
.40227 .08314 L
.40292 .08332 L
.40352 .08328 L
.40417 .08301 L
.40486 .0826 L
.40556 .08225 L
.40631 .08216 L
.40702 .08241 L
.40766 .08279 L
.40842 .08315 L
.40884 .08322 L
.40924 .08317 L
.40996 .08282 L
.41073 .08232 L
.41147 .08201 L
.41228 .08208 L
.41304 .08247 L
.41375 .08286 L
.41446 .08302 L
.4151 .08289 L
.41583 .08252 L
.41652 .08214 L
.41728 .08194 L
.41808 .08206 L
.41877 .08234 L
.41952 .08264 L
.42033 .08276 L
.42078 .08269 L
.42119 .08256 L
.42195 .08224 L
.42276 .08195 L
.42344 .08188 L
.4242 .08202 L
.42488 .08228 L
.42553 .08251 L
.42628 .08261 L
Mistroke
.42698 .08248 L
.42774 .08215 L
.42854 .0818 L
.4292 .08169 L
.4299 .08182 L
.43056 .08212 L
.43116 .08241 L
.43187 .08257 L
.43263 .08242 L
.43335 .08203 L
.43402 .08167 L
.43479 .08151 L
.43552 .08171 L
.43618 .08207 L
.4369 .08241 L
.43768 .08247 L
.43811 .08232 L
.4385 .08212 L
.43928 .08166 L
.43999 .08143 L
.44066 .08151 L
.44137 .08184 L
.44215 .08222 L
.44287 .08235 L
.44349 .08221 L
.44416 .08189 L
.4449 .08154 L
.44557 .08142 L
.44636 .08157 L
.44676 .08173 L
.4472 .08192 L
.44798 .08214 L
.4487 .08211 L
.44914 .08199 L
.44956 .08183 L
.45034 .08156 L
.45078 .08147 L
.45118 .08145 L
.45163 .0815 L
.4521 .08161 L
.4529 .08183 L
.45335 .08193 L
.45377 .08196 L
.45453 .0819 L
.45534 .08171 L
.45602 .08155 L
.45674 .08146 L
.45754 .0815 L
.45828 .08164 L
.45909 .0818 L
Mistroke
.45985 .08186 L
.46065 .08177 L
.46107 .08168 L
.46153 .08156 L
.46229 .0814 L
.46309 .08138 L
.46378 .0815 L
.46453 .0817 L
.46499 .0818 L
.46543 .08185 L
.46624 .08176 L
.46669 .08163 L
.46711 .08149 L
.4676 .08134 L
.46806 .08126 L
.46882 .08129 L
.46922 .0814 L
.46965 .08155 L
.4701 .08171 L
.47053 .08182 L
.47134 .08183 L
.47212 .0816 L
.47283 .08131 L
.47322 .0812 L
.47364 .08114 L
.47441 .08127 L
.47507 .08153 L
.47577 .08179 L
.47654 .08186 L
.47726 .08165 L
.47766 .08147 L
.4781 .08127 L
.4789 .08107 L
.47937 .0811 L
.4798 .08124 L
.4802 .08141 L
.48063 .08162 L
.48139 .08185 L
.4821 .0818 L
.48288 .08148 L
.48331 .08126 L
.48372 .0811 L
.4845 .08103 L
.4852 .08125 L
.4856 .08145 L
.48602 .08165 L
.48678 .08186 L
.48743 .08178 L
.48814 .08146 L
.4889 .0811 L
Mistroke
.48962 .08098 L
.49002 .08106 L
.49046 .08123 L
.49123 .08162 L
.49166 .08179 L
.49212 .08186 L
.49252 .08181 L
.49295 .08166 L
.49373 .08127 L
.49416 .08108 L
.49456 .08098 L
.49529 .08105 L
.49607 .08141 L
.49688 .08177 L
.49762 .08183 L
.49803 .08172 L
.49847 .08152 L
.49928 .08112 L
.50003 .08096 L
.50083 .08116 L
.50152 .08151 L
.50227 .08181 L
.50272 .08185 L
.50315 .08176 L
.50396 .08139 L
.50438 .08118 L
.50483 .08102 L
.50532 .08097 L
.50577 .08105 L
.5062 .08123 L
.50666 .08147 L
.50707 .08167 L
.5075 .08181 L
.50831 .0818 L
.50906 .08148 L
.50981 .08112 L
.51023 .081 L
.51063 .08099 L
.51135 .0812 L
.51211 .08158 L
.51279 .08183 L
.51343 .08183 L
.51413 .08158 L
.51489 .08121 L
.51565 .08102 L
.51608 .08105 L
.51648 .08117 L
.51693 .08138 L
.51736 .08159 L
.51815 .08186 L
Mistroke
.51885 .08181 L
.5196 .08151 L
.5204 .08117 L
.52114 .08107 L
.5218 .08123 L
.5225 .08155 L
.52328 .08183 L
.524 .08184 L
.52474 .08161 L
.52555 .08128 L
.52631 .08114 L
.52702 .08126 L
.52766 .08151 L
.52837 .08177 L
.52903 .08186 L
.52964 .08178 L
.53035 .08155 L
.5311 .08131 L
.53173 .08125 L
.53243 .08135 L
.53323 .08161 L
.53398 .08181 L
.53437 .08185 L
.5348 .08183 L
.53524 .08175 L
.53566 .08165 L
.53638 .08146 L
.53714 .08137 L
.53753 .08138 L
.53797 .08144 L
.53872 .08162 L
.53948 .08179 L
.54016 .08186 L
.54095 .08179 L
.5417 .08164 L
.54234 .08152 L
.54302 .08145 L
.54377 .08151 L
.54446 .08166 L
.54524 .08186 L
.54599 .08196 L
.5464 .08195 L
.54685 .08189 L
.54763 .08169 L
.54838 .0815 L
.54917 .08146 L
.54985 .08161 L
.5506 .08189 L
.55102 .08204 L
.55147 .08214 L
Mistroke
.55227 .08209 L
.55271 .08195 L
.55313 .08178 L
.55361 .08158 L
.55407 .08145 L
.55447 .08142 L
.5549 .08148 L
.55565 .08179 L
.5561 .08203 L
.55653 .08222 L
.55734 .08234 L
.55803 .08214 L
.55879 .08175 L
.55959 .08145 L
.56034 .08151 L
.56106 .08185 L
.5617 .08223 L
.56245 .08249 L
.56315 .0824 L
.56393 .08201 L
.56436 .08177 L
.56476 .0816 L
.56546 .08152 L
.56623 .08179 L
.56663 .08202 L
.56705 .08227 L
.56784 .08255 L
.5683 .08256 L
.56874 .08245 L
.56913 .08228 L
.56956 .08207 L
.57035 .08175 L
.57108 .08171 L
.57189 .08197 L
.57229 .08216 L
.57273 .08237 L
.57348 .08259 L
.57428 .08256 L
.57503 .08231 L
.57571 .08205 L
.57613 .08193 L
.57658 .08188 L
.57739 .08199 L
.57783 .08214 L
.57825 .08233 L
.57874 .08253 L
.5792 .08269 L
.5796 .08275 L
.58004 .08274 L
.58079 .08253 L
Mistroke
.58123 .08234 L
.58168 .08214 L
.58207 .08201 L
.5825 .08194 L
.5829 .08196 L
.58332 .08208 L
.58408 .08247 L
.58454 .08273 L
.58497 .08292 L
.58579 .083 L
.58656 .08271 L
.58727 .08229 L
.58805 .082 L
.58844 .08199 L
.58887 .08211 L
.58961 .08254 L
.59031 .08298 L
.59111 .08322 L
.59185 .08305 L
.5926 .08263 L
.59331 .08226 L
.59395 .08215 L
.59464 .08233 L
.59545 .08279 L
.59619 .08318 L
.59699 .08333 L
.5974 .08326 L
.59784 .08309 L
.59859 .08273 L
.59938 .08243 L
.60013 .08241 L
.60082 .08264 L
.60123 .08286 L
.60168 .08312 L
.60247 .08346 L
.60292 .08352 L
.60333 .08348 L
.60379 .08332 L
.60428 .08307 L
.60471 .08283 L
.60511 .08264 L
.60553 .08251 L
.60599 .0825 L
.60675 .08278 L
.60756 .08332 L
.60832 .08373 L
.60875 .08381 L
.60915 .08377 L
.60996 .08337 L
.61038 .08309 L
Mistroke
.61084 .08283 L
.61165 .08263 L
.61242 .08288 L
.61316 .08338 L
.61386 .08382 L
.61429 .08398 L
.61475 .084 L
.61519 .08389 L
.6156 .08371 L
.61641 .08323 L
.61717 .08292 L
.61756 .08289 L
.61799 .08296 L
.61845 .08316 L
.61888 .08342 L
.61933 .08371 L
.61976 .08397 L
.6202 .08415 L
.62069 .08423 L
.62145 .08404 L
.62188 .08381 L
.62228 .08357 L
.62299 .08318 L
.62374 .08307 L
.62414 .08317 L
.62457 .08339 L
.62533 .08395 L
.6258 .08428 L
.62624 .08448 L
.62663 .08455 L
.62706 .08448 L
.62779 .0841 L
.62859 .08356 L
.62899 .08336 L
.62942 .08326 L
.6302 .08345 L
.63098 .08397 L
.63171 .08449 L
.63237 .08476 L
.63309 .08471 L
.63384 .08434 L
.63452 .0839 L
.63527 .08357 L
.63607 .08362 L
.63676 .08399 L
.6374 .08447 L
.63811 .08493 L
.63886 .0851 L
.63929 .085 L
.63969 .0848 L
Mistroke
.64058 .08417 L
.64137 .08378 L
.64176 .08375 L
.6422 .08386 L
.64296 .08435 L
.64377 .08501 L
.64454 .08539 L
.64524 .08534 L
.64604 .0849 L
.64647 .08459 L
.64688 .08432 L
.64768 .08405 L
.64841 .0842 L
.64883 .08445 L
.64927 .0848 L
.65007 .08541 L
.65051 .08564 L
.65093 .08573 L
.65138 .08568 L
.65187 .08546 L
.65268 .08488 L
.6531 .08459 L
.65356 .08437 L
.65395 .08431 L
.65439 .08439 L
.65516 .08487 L
.6559 .08552 L
.65671 .08603 L
.65747 .08606 L
.65816 .08571 L
.65895 .08511 L
.65969 .0847 L
.66036 .08466 L
.66108 .085 L
.66186 .08565 L
.66259 .08622 L
.66336 .08647 L
.66376 .08641 L
.6642 .08621 L
.66498 .08562 L
.66572 .08511 L
.66639 .08494 L
.66712 .08519 L
.6678 .08573 L
.66852 .08639 L
.6692 .0868 L
.66981 .08685 L
.68255 .08767 L
.69542 .0886 L
.69609 .08816 L
Mistroke
.69682 .08751 L
.69751 .08703 L
.69815 .08692 L
.69889 .08726 L
.69968 .08803 L
.70034 .08871 L
.70106 .08916 L
.70185 .08912 L
.70259 .08861 L
.703 .08824 L
.70345 .08784 L
.70387 .08755 L
.70426 .08741 L
.70502 .08754 L
.70582 .0882 L
.70651 .08896 L
.70725 .08959 L
.70803 .08976 L
.70875 .08941 L
.70952 .08872 L
.70996 .08832 L
.71037 .08805 L
.7111 .0879 L
.71189 .08832 L
.71262 .08908 L
.71331 .08982 L
.71397 .09028 L
.71468 .09031 L
.71528 .08997 L
.71594 .08936 L
.71666 .08873 L
.71742 .08842 L
.71815 .08866 L
.71881 .08927 L
.71952 .09009 L
.72028 .09078 L
.721 .09097 L
.72165 .09071 L
.72243 .09002 L
.72286 .0896 L
.72326 .08927 L
.72397 .08899 L
.72475 .08927 L
.7255 .09001 L
.7263 .09095 L
.72674 .09135 L
.72717 .09159 L
.72797 .09152 L
.72872 .09094 L
.72942 .09024 L
Mistroke
.73019 .08969 L
.73062 .0896 L
.73101 .08969 L
.75568 .09365 L
.77943 .09665 L
.78012 .09766 L
.78086 .09843 L
.78167 .09861 L
.78241 .09813 L
.78312 .09735 L
.78387 .09656 L
.78459 .09623 L
.78524 .09645 L
.786 .09727 L
.78679 .09845 L
.78719 .099 L
.78761 .09946 L
.78807 .09975 L
.7885 .09979 L
.7893 .09932 L
.79006 .09846 L
.79073 .09774 L
.79147 .09736 L
.79189 .09742 L
.79229 .09768 L
.79273 .09816 L
.7932 .09883 L
.79365 .09952 L
.79414 .10023 L
.7946 .10073 L
.79503 .101 L
.79546 .10104 L
.79586 .10088 L
.79631 .1005 L
.79674 .10002 L
.79749 .09915 L
.79791 .09878 L
.7983 .09859 L
.79908 .09877 L
.79948 .09913 L
.7999 .09968 L
.8006 .10078 L
.80137 .10185 L
.80183 .10225 L
.80226 .10239 L
.80267 .10232 L
.8031 .10203 L
.80385 .10121 L
.80428 .10069 L
.80468 .10028 L
Mistroke
.80545 .09988 L
.80586 .09996 L
.8063 .10027 L
.8071 .10134 L
.80784 .10252 L
.80855 .10345 L
.80932 .10384 L
.81005 .10354 L
.81073 .10283 L
.81145 .10196 L
.81224 .10136 L
.81268 .10131 L
.81309 .1015 L
.81389 .1024 L
.81471 .10375 L
.81515 .10442 L
.81561 .10499 L
.81601 .1053 L
.81645 .10541 L
.81723 .10501 L
.81797 .10418 L
.81866 .10337 L
.81937 .10288 L
.82015 .10304 L
.82095 .10395 L
.82139 .10468 L
.8218 .10537 L
.82257 .10653 L
.8233 .10708 L
.82399 .10697 L
.82472 .1063 L
.82535 .10552 L
.82603 .10481 L
.82676 .10453 L
.82744 .10489 L
.82826 .10599 L
.829 .10728 L
.82979 .10845 L
.83054 .10895 L
.83121 .10878 L
.83194 .10807 L
.83273 .10709 L
.83313 .10669 L
.83357 .10643 L
.83435 .10654 L
.83507 .10734 L
.83574 .10847 L
.83647 .10976 L
.83716 .11065 L
.83779 .11098 L
Mistroke
.83853 .11071 L
.83931 .10986 L
.83999 .10904 L
.8407 .10847 L
.84149 .10855 L
.84221 .10933 L
.84299 .11067 L
.84343 .1115 L
.84384 .11218 L
.84457 .11303 L
.84536 .11316 L
.84609 .11262 L
.84677 .11179 L
.84759 .11091 L
.848 .11068 L
.84845 .11067 L
.84924 .11133 L
.84999 .11255 L
.85085 .11418 L
.85127 .11486 L
.85166 .11533 L
.85211 .11562 L
.8526 .11563 L
.85302 .11539 L
.85346 .11496 L
.85422 .11403 L
.85493 .11333 L
.85566 .11315 L
.85647 .11379 L
.85716 .11494 L
.8578 .11619 L
.85849 .11744 L
.85922 .11825 L
.86002 .11831 L
.86075 .11771 L
.86161 .11668 L
.86241 .11599 L
.86311 .11599 L
.86385 .11672 L
.86427 .11742 L
.86468 .11821 L
.86543 .11975 L
.86614 .12088 L
.86678 .12139 L
.86752 .12128 L
.86822 .12064 L
.86882 .11991 L
.86946 .11927 L
.87016 .11903 L
.87081 .1194 L
Mistroke
.87667 .12291 L
.88251 .12852 L
.88326 .12778 L
.88405 .12694 L
.88446 .12667 L
.88492 .1266 L
.88573 .12721 L
.88648 .12855 L
.88729 .13041 L
.88806 .13203 L
.88877 .13299 L
.88948 .13325 L
.89027 .1328 L
.89103 .132 L
.89142 .13162 L
.89185 .13134 L
.89261 .13138 L
.89333 .13218 L
.89403 .13357 L
.89467 .13511 L
.89527 .13649 L
.89592 .1376 L
.89662 .13811 L
.89729 .13781 L
.89803 .1367 L
.89873 .13516 L
.90005 .13212 L
.90082 .13081 L
.90126 .1303 L
.90165 .12998 L
.90239 .12973 L
.90316 .12985 L
.90385 .13019 L
.9045 .13063 L
.90597 .13186 L
.91227 .1382 L
.9236 .1529 L
.93005 .16409 L
.93616 .17768 L
.94164 .19371 L
.94471 .20509 L
.94759 .21803 L
.95038 .23356 L
.95339 .25515 L
.9551 .27083 L
.95673 .28921 L
.95819 .30999 L
.95979 .34022 L
.96066 .36212 L
.96149 .38773 L
Mistroke
.96303 .45196 L
.96391 .49719 L
.96484 .54636 L
.96563 .58174 L
.96608 .59561 L
.9665 .60265 L
.96725 .5972 L
.96794 .56911 L
.96873 .50983 L
.96949 .43297 L
.97106 .25245 L
.97192 .16736 L
.97273 .10628 L
.97314 .0826 L
.97358 .06225 L
.97407 .04522 L
.97453 .03388 L
.97534 .0212 L
.97574 .01746 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[186]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000>oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000cooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o0000;Oooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol0000=ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000_ooool5o`0000gooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`?o00008_ooool002;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00003?oo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`0Oooooo`006oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0:oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool02oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool07oooool002;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00003ooooo`;o00003Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0:oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0000Rooooo`008_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
2_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01oooooo000Rooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00[ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l0000]ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000_ooool2o`0000gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Oooooo`008oooool2o`0000[o
oooo0_l00003ooooo`?o00003_ooool2o`0000[ooooo0_l00003ooooo`?o00003Oooool2o`0000[o
oooo0_l00004ooooo`03o`000?oooooooooo02cooooo0_l0000:ooooo`;o00001?ooool00ol0003o
ooooooooo`0<ooooo`;o00002_ooool2o`0000?ooooo0ol0000>ooooo`;o00002_ooool2o`0000?o
oooo0ol0000Rooooo`00oooooolQooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool0
0ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`004Oooooomo`0001;o
oooo000Fooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
0_l0000Gooooo`005oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool05oooool001Oooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`1d
ooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oooooooooo07Gooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`0Gooooo`005oooool00ol0003oooooooooo`1eooooo`03
o`000?oooooooooo07Cooooo00?o0000ooooooooool05oooool001Oooooo00?o0000ooooooooool0
MOooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oo
oooooooo07Gooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0Gooooo`005oooool0
0ol0003oooooooooo`1eooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool05oooool0
01Oooooo00?o0000ooooooooool0MOooool2o`0007Gooooo00?o0000ooooooooool05oooool001Oo
oooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo01Oo
oooo000Gooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
ooooo`0Gooooo`005oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool05oooool001Oooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`1d
ooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oooooooooo07Gooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`0Gooooo`005oooool00ol0003oooooooooo`1eooooo`03
o`000?oooooooooo07Cooooo00?o0000ooooooooool05oooool001Oooooo00?o0000ooooooooool0
MOooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooool000000_l000000ooooooo0000o`000005o`000003ooooool0
003ooooo06kooooo00?o0000ooooooooool05oooool001Oooooo00?o0000ooooooooool0Boooool0
0ol0003oooooo`00001@o`000003ooooool0003ooooo04_ooooo00?o0000ooooooooool05oooool0
01Oooooo00?o0000ooooooooool0?OoooolEo`0002?ooooo00?o0000ooooooooool08Oooool00ol0
003oooooo`00000Bo`0003kooooo00?o0000ooooooooool05oooool001Sooooo00?o0000oooooooo
ool0<oooool?o`0003;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooo`000007o`0003Wo
oooo00?o0000ooooooooool05oooool001Sooooo00?o0000ooooooooool0;?ooool;o`0003gooooo
00?o0000ooooooooool0>oooool;o`0002kooooo00?o0000ooooooooool05oooool001Sooooo00?o
0000ooooooooool09oooool9o`0004Cooooo00?o0000ooooooooool0@oooool8o`0002Wooooo00?o
0000ooooooooool05oooool001Sooooo00?o0000ooooooooool08_ooool7o`0004_ooooo00?o0000
ooooooooool0BOooool7o`0002Cooooo00?o0000ooooooooool05oooool001Sooooo00?o0000oooo
ooooool07_ooool8o`0004kooooo00?o0000ooooooooool0C?ooool8o`00023ooooo00?o0000oooo
ooooool05oooool001Sooooo00?o0000ooooooooool07?ooool5o`0005?ooooo00?o0000oooooooo
ool0D_ooool4o`0001kooooo00?o0000ooooooooool05oooool001Sooooo00?o0000ooooooooool0
6_ooool2o`000003ooooool0003ooooo05Gooooo00?o0000ooooooooool0E?ooool5o`0001_ooooo
00?o0000ooooooooool05oooool001Sooooo00?o0000ooooooooool05oooool3o`0005[ooooo0_l0
001Hooooo`Go00006?ooool00ol0003oooooooooo`0Gooooo`006?ooool00ol0003oooooooooo`0E
ooooo`Co0000Foooool00ol0003oooooooooo`1Iooooo`04o`000?ooooooooooo`0001Oooooo00?o
0000ooooooooool05oooool001Sooooo00?o0000ooooooooool04oooool3o`0005kooooo00?o0000
ooooooooool0GOooool2o`0001Gooooo00?o0000ooooooooool05oooool001Sooooo00?o0000oooo
ooooool03_ooool6o`00063ooooo00?o0000ooooooooool0G_ooool3o`000003ooooool0003o0000
013ooooo00?o0000ooooooooool05oooool001Sooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03o`00067ooooo00?o0000ooooooooool0Goooool3o`0000;ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Gooooo`006?ooool00ol0003oooooooooo`0<ooooo`05o`00
0?ooooooooooooooool00000Hoooool00ol0003oooooooooo`1Pooooo`;o00000oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo000Hooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool05oooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1;ooooo`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool001Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1=ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Oooooo000Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Gooooo`006?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo053ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`?o0000J?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Oooooo000Hooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0COooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo000H
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0C_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01Oooooo000Hooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0D?ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo000Hooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05oooool001Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Gooooo`006?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo06_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Oooooo000Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0K?ooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool001So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`006?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06cooooo0_l0001]ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05oooool001Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1/ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Gooooo`006?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo000Hoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool001Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Gooooo`006?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Sooooo000Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?oo
ool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`006?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0K_ooool2o`0006oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Hooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo
000Iooooo`05o`000?ooooooooooooooool00000LOooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06?ooool001Wooooo00Go0000oooooooooooooooo
o`00001aooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Hooooo`006Oooool01Ol0003ooooooooooooooooo0000077ooooo00?o0000ooooooooool0
Koooool01Ol0003ooooooooooooooooo000001[ooooo000Iooooo`05o`000?ooooooooooooooool0
0000LOooool00ol0003oooooooooo`1_ooooo`05o`000?ooooooooooooooool000006_ooool001Wo
oooo00Go0000ooooooooooooooooo`00001aooooo`03o`000?oooooooooo06oooooo00Go0000oooo
ooooooooooooo`00000Jooooo`006Oooool01Ol0003ooooooooooooooooo0000077ooooo00?o0000
ooooooooool0Koooool01Ol0003ooooooooooooooooo000001[ooooo000Iooooo`05o`000?oooooo
ooooooooool00000LOooool00ol0003oooooooooo`1_ooooo`05o`000?ooooooooooooooool00000
6_ooool001Wooooo00Go0000ooooooooooooooooo`00001aooooo`;o0000L?ooool01Ol0003ooooo
oooooooooooo000001[ooooo000Iooooo`05o`000?ooooooooooooooool00000LOooool00ol0003o
ooooooooo`1_ooooo`05o`000?ooooooooooooooool000006_ooool001Wooooo00Go0000oooooooo
ooooooooo`00001aooooo`03o`000?oooooooooo06oooooo00Go0000ooooooooooooooooo`00000J
ooooo`006Oooool01Ol0003ooooooooooooooooo0000077ooooo00?o0000ooooooooool0Koooool0
1Ol0003ooooooooooooooooo000001[ooooo000Iooooo`05o`000?ooooooooooooooool00000LOoo
ool00ol0003oooooooooo`1`ooooo`04o`000?ooooooooooo`0001[ooooo000Iooooo`04o`000?oo
ooooooooo`0007;ooooo00?o0000ooooooooool0L?ooool01?l0003oooooooooool0000Jooooo`00
6Oooool01?l0003oooooooooool0001booooo`03o`000?oooooooooo073ooooo00Co0000oooooooo
oooo00006_ooool001Wooooo00Co0000oooooooooooo0000FOooool3o`0000?ooooo0_l00004oooo
o`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0L?ooool01?l0003oooooooooool0000J
ooooo`006Oooool01?l0003oooooooooool0001Jooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1`ooooo`04o`000?ooooooooooo`0001[ooooo000Iooooo`04
o`000?ooooooooooo`0005Oooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo073ooooo
00Co0000oooooooooooo00006_ooool001Wooooo00Co0000oooooooooooo0000Eoooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`?o0000L?ooool01?l0003oooooooooool0000Jooooo`00
6Oooool01?l0003oooooooooool0001Hooooo`03o`000?oooooo000000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0L?ooool01?l0003oooooooooool0000Jooooo`006Oooool01?l0003ooooooooo
ool0001Iooooo`;o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1`ooooo`04o`000?oooooo
ooooo`0001[ooooo000Iooooo`04o`000?ooooooooooo`0005[ooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`1`ooooo`04o`000?oo
ooooooooo`0001[ooooo000Iooooo`04o`000?ooooooooooo`0007;ooooo00?o0000ooooooooool0
L?ooool01?l0003oooooooooool0000Jooooo`006Oooool01?l0003oooooooooool0001booooo`03
o`000?oooooooooo073ooooo00Co0000oooooooooooo00006_ooool001Wooooo00?o0000ooooool0
0000Loooool00ol0003oooooooooo`1aooooo`03o`000?oooooo000001[ooooo000Iooooo`03o`00
0?oooooo000007?ooooo00?o0000ooooooooool0LOooool00ol0003oooooo`00000Jooooo`006Ooo
ool00ol0003oooooo`00001cooooo`03o`000?oooooooooo077ooooo00?o0000ooooool000006_oo
ool001Wooooo00?o0000ooooool00000Loooool2o`0007;ooooo00?o0000ooooool000006_ooool0
01Wooooo00?o0000ooooool00000Loooool00ol0003oooooooooo`1aooooo`03o`000?oooooo0000
01[ooooo000Iooooo`03o`000?oooooo000007?ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooo`00000Jooooo`006Oooool00ol0003oooooo`00001cooooo`03o`000?oooooooooo077ooooo
00?o0000ooooool000006_ooool001Wooooo00?o0000ooooool00000Loooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooo000001[ooooo000Iooooo`03o`000?oooooo000007?ooooo00?o0000
ooooooooool0LOooool00ol0003oooooo`00000Jooooo`006Oooool00ol0003oooooo`00001coooo
o`03o`000?oooooooooo077ooooo00?o0000ooooool000006_ooool001Wooooo00?o0000ooooool0
0000Loooool00ol0003oooooooooo`1aooooo`03o`000?oooooo000001[ooooo000Iooooo`03o`00
0?oooooo000007?ooooo00?o0000ooooooooool0LOooool00ol0003oooooo`00000Jooooo`006Ooo
ool00ol0003oooooo`00001cooooo`;o0000L_ooool00ol0003oooooo`00000Jooooo`006Oooool0
0ol0003oooooo`00001cooooo`03o`000?oooooooooo077ooooo00?o0000ooooool000006_ooool0
01Wooooo00?o0000ooooool00000Loooool00ol0003oooooooooo`1aooooo`03o`000?oooooo0000
01[ooooo000Iooooo`03o`000?oooooo000007?ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooo`00000Jooooo`006Oooool00ol0003oooooo`00001cooooo`03o`000?oooooooooo077ooooo
00?o0000ooooool000006_ooool001Wooooo00?o0000ooooool00000Loooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooo000001[ooooo000Iooooo`03o`000?oooooo000007?ooooo00?o0000
ooooooooool0LOooool00ol0003oooooo`00000Jooooo`006Oooool00ol0003oooooo`00001coooo
o`03o`000?oooooooooo077ooooo00?o0000ooooool000006_ooool001Wooooo00?o0000ooooool0
0000Loooool00ol0003oooooooooo`1aooooo`03o`000?oooooo000001[ooooo000Iooooo`03o`00
0?oooooo000007?ooooo0_l0001booooo`03o`000?oooooo000001[ooooo000Iooooo`03o`000?oo
oooo000007?ooooo00?o0000ooooooooool0LOooool00ol0003oooooo`00000Jooooo`006Oooool0
0ol0003oooooo`00001cooooo`03o`000?oooooooooo077ooooo00?o0000ooooool000006_ooool0
01Wooooo00?o0000ooooool00000Loooool00ol0003oooooooooo`1aooooo`03o`000?oooooo0000
01[ooooo000Iooooo`03o`000?oooooo000007?ooooo00?o0000ooooooooool0LOooool00ol0003o
ooooo`00000Jooooo`006Oooool00ol0003oooooo`00001cooooo`03o`000?oooooooooo077ooooo
00?o0000ooooool000006_ooool001Wooooo00?o0000ooooool00000Loooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooo000001[ooooo000Iooooo`03o`000?oooooo000005Wooooo0ol00004
ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooool000006_ooool001Wooooo00?o0000ooooool00000F?ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0LOooool00ol0003oooooo`00000Jooooo`00
6Oooool00ol0003oooooo`00001Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooo000001[ooooo000Iooooo`03o`000?oooooo
000005Sooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`?o0000LOooool00ol0003oooooo`00000Jooooo`00
6Oooool00ol0003oooooo`00001Hooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0LOooool00ol0003oooooo`00000Jooooo`006Oooool00ol0003oooooo`00001Ioooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0LOooool00ol0003ooooo
o`00000Jooooo`006Oooool00ol0003oooooo`00001Jooooo`;o00001?ooool2o`0000Cooooo0_l0
0004ooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo000001[ooooo000I
ooooo`03o`000?oooooo000007?ooooo00?o0000ooooooooool0LOooool00ol0003oooooo`00000J
ooooo`006Oooool00ol0003oooooo`00001cooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ool000006_ooool001Wooooo00?o0000ooooool00000Loooool00ol0003oooooooooo`1booooo`;o
00006_ooool001Wooooo00?o0000ooooool00000Loooool00ol0003oooooooooo`1booooo`;o0000
6_ooool001Wooooo00?o0000ooooool00000Loooool00ol0003oooooooooo`1booooo`;o00006_oo
ool001Wooooo00?o0000ooooool00000Loooool2o`0007?ooooo0_l0000Jooooo`006Oooool00ol0
003oooooo`00001cooooo`03o`000?oooooooooo07;ooooo0_l0000Jooooo`006Oooool2o`0007Co
oooo00?o0000ooooooooool0L_ooool2o`0001[ooooo000Iooooo`;o0000M?ooool00ol0003ooooo
ooooo`1booooo`;o00006_ooool001Wooooo0_l0001dooooo`03o`000?oooooooooo07;ooooo0_l0
000Jooooo`006Oooool2o`0007Cooooo00?o0000ooooooooool0L_ooool2o`0001[ooooo000Ioooo
o`;o0000M?ooool00ol0003oooooooooo`1booooo`;o00006_ooool001Wooooo0_l0001dooooo`03
o`000?oooooooooo07;ooooo0_l0000Jooooo`006Oooool2o`0007Cooooo00?o0000ooooooooool0
L_ooool2o`0001[ooooo000Iooooo`;o0000M?ooool2o`0007?ooooo0_l0000Jooooo`006Oooool2
o`0007Cooooo00?o0000ooooooooool0L_ooool2o`0001[ooooo000Iooooo`;o0000M?ooool00ol0
003oooooooooo`1booooo`;o00006_ooool001Wooooo0_l0001dooooo`03o`000?oooooooooo07;o
oooo0_l0000Jooooo`006Oooool2o`0007Cooooo00?o0000ooooooooool0L_ooool2o`0001[ooooo
000Iooooo`;o0000M?ooool00ol0003oooooooooo`1booooo`;o00006_ooool001Wooooo0_l0001d
ooooo`03o`000?oooooooooo07;ooooo0_l0000Jooooo`006Oooool2o`0007Cooooo00?o0000oooo
ooooool0L_ooool2o`0001[ooooo000Iooooo`;o0000M?ooool00ol0003oooooooooo`1booooo`;o
00006_ooool001Wooooo0_l0001dooooo`;o0000Loooool2o`0001[ooooo000Iooooo`;o0000M?oo
ool00ol0003oooooooooo`1booooo`;o00006_ooool001Wooooo0_l0001dooooo`03o`000?oooooo
oooo07;ooooo0_l0000Jooooo`006_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
07;ooooo0_l0000Jooooo`006_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07;o
oooo0_l0000Jooooo`006_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07;ooooo
0_l0000Jooooo`006_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0F?ooool3o`0000Cooooo0_l00004
ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`1Gooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`00
0?oooooooooo05Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0F?ooool3
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo0ol0001booooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`00
0?oooooooooo05Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo08kooooo001dooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`2>ooooo`00MOooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Go
oooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool009Sooooo0ol00025ooooo`00VOooool00ol0003ooooo
ooooo`24ooooo`00<oooool3o`0000?ooooo0ol00003ooooo`?o00000_ooool01Ol0003oooooo`00
0?oooooo000000;ooooo0ol00004ooooo`;o00000_ooool3o`0000?ooooo1Ol00002ooooo`?o0000
2?ooool3o`0000Cooooo0ol00002ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000;o
oooo0_l00009ooooo`?o00000oooool3o`0000;ooooo0ol00004ooooo`?o00000oooool4o`0000;o
oooo1?l00007ooooo`?o00001Oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0
003ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?oooooo`00
0?l00000=?ooool003;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Gooooo00go0000
ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`000?oooooo000000Kooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0003Gooooo000booooo`06o`000?ooooooooooooooool0003ooooo
1Ol000000ooooooo0000ooooo`02ooooo`08o`000?oooooo0000ooooool0003oooooo`000?ooool5
o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000003?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool03?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo1Ol00002
ooooo`?o00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`0cooooo`00<_ooool00ol0003oooooo`000004o`0000?ooooo00?o0000
ooooool000000oooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000003ooooo`04
o`000?ooooooooooo`0000Gooooo0_l00005ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`06ooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo
0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`07o`000?oooooooooooooo
ool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01ooo
ool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0cooooo`00<_ooool00ol0003ooooooooo
o`04ooooo`?o00000oooool3o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`?o00000_oo
ool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000Cooooo0ol00009ooooo`04o`00
0?ooooooooooo`0000;ooooo0ol00002ooooo`?o00000oooool4o`0000;ooooo1?l00009ooooo`03
o`000?oooooooooo00;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?o
oooo0_l00004ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?l0
003ooooo1?l00003ooooo`?o00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000_ooool4o`00
03Kooooo000booooo`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`0Koooo
o`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0
000Looooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00005?ooool00ol0003ooooo
ooooo`18ooooo`00<oooool3o`0001_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0=ooooo`Co00002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0ol0
000Kooooo`;o00002?ooool5o`0001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`11ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0428002, -656.269, \
0.000298259, 54.0528}},
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AngularMagnification \[Rule] \(-0.9301198876749336`\)\), 
        ",", \(BackFocalLength \[Rule] 43.791018699765594`\), 
        ",", \(BackFocalPoint \[Rule] {153.2910186997656`, 0, 0}\), 
        ",", \(ComponentNumber \[Rule] 4.`\), 
        ",", \(Energy \[Rule] 99.99999999999757`\), 
        ",", \(EntrancePupilBoundary \[Rule] {\(-30.150853892611842`\), \
\(-30.150853892611842`\)}\), 
        ",", \(EntrancePupilDistance \[Rule] \(-6.427218668532343`\)\), 
        ",", \(EntrancePupilOffset \[Rule] {0, 0}\), 
        ",", \(EntrancePupilPosition \[Rule] {96.92721866853235`, 0, 0}\), 
        ",", \(EntrancePupilRotationMatrix \[Rule] {{\(-1.`\), 0, 
              0}, {0, \(-1.`\), 0}, {0, 0, 1}}\), 
        ",", \(ExitPupilBoundary \[Rule] {\(-30.150853892611856`\), \
\(-30.150853892611856`\)}\), 
        ",", \(ExitPupilDistance \[Rule] \(-6.427218668532353`\)\), 
        ",", \(ExitPupilOffset \[Rule] {0, 0}\), 
        ",", \(ExitPupilPosition \[Rule] {103.07278133146765`, 0, 0}\), 
        ",", \(ExitPupilRotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 
              1}}\), ",", \(FieldStopPosition \[Rule] 3\), 
        ",", \(FieldStopSurface \[Rule] {IntersectionNumber \[Rule] 3, 
            SurfaceNumber \[Rule] 1, ComponentNumber \[Rule] 2}\), 
        ",", \(FindImagePoint \[Rule] True\), 
        ",", \(FocalLength \[Rule] 50.218237368297935`\), 
        ",", \(FrontFocalLength \[Rule] 43.79101869976556`\), 
        ",", \(FrontFocalPoint \[Rule] {46.70898130023444`, 0, 0}\), 
        ",", \(Full3D \[Rule] False\), 
        ",", \(ImagePlaneTilt \[Rule] {1.`, 0, 0}\), 
        ",", \(ImagePoint \[Rule] {206.0122947692871`, 0, 0}\), ",", 
        RowBox[{"ImagingOptics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  TagBox[\(Move[
                      PlanoConvexLens[{f1, 100}, 50, 
                        9, {CurvatureDirection \[Rule] Back}], 90.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[ApertureStop[50, 30], 100.`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  TagBox[\(Move[PlanoConvexLens[{f2, 100}, 50, 9], 100.5`]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm], ",", 
              TagBox[
                StyleBox[
                  
                  TagBox[\(Boundary[{0, \(-104\), \(-104\)}, {208, 104, 
                        104}, {GraphicDesign \[Rule] Off}]\),
                    HoldForm],
                  FontColor->RGBColor[0, 0.392187, 0]],
                DisplayForm]}], "}"}]}], 
        ",", \(LensABCDMatrix \[Rule] {{0.8720142520854434`, 
              12.031844948762183`}, {\(-0.019913084417241732`\), 
              0.8720142520854433`}}\), ",", \(NumberOfPoints \[Rule] 512\), 
        ",", \(NumberOfRays \[Rule] 1064\), ",", 
        RowBox[{"ObjectSource", "\[Rule]", 
          TagBox[
            StyleBox[
              TagBox[\(WedgeOfRays[10, NumberOfRays \[Rule] 5]\),
                HoldForm],
              FontColor->RGBColor[0, 0.392187, 0]],
            DisplayForm]}], ",", \(OpticalMedium \[Rule] Air\), 
        ",", "\<\"-Options-\"\>", ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"PointSpreadFunction", "\[Rule]", 
              RowBox[{"(", 
                
                TagBox[\(\[SkeletonIndicator]  
                    Graphics  \[SkeletonIndicator]\),
                  False,
                  Editable->False], ")"}]}], "}"}]}], 
        ",", \(PointSpreadFunction \[Rule] 
          "CompiledFunction[-intensity data-]"\), 
        ",", \(PrinciplePoints \[Rule] {{96.92721866853238`, 0, 
              0}, {103.07278133146767`, 0, 0}}\), 
        ",", \(PrinciplePointSeparation \[Rule] 6.145562662935291`\), 
        ",", \(RayBoundary \[Rule] {\(-0.03512182813290732`\), 
            0.03512182813290465`}\), 
        ",", \(RayTraceFunction \[Rule] 
          "RayTraceFunction[{f1, f2}, -raytrace code: 2669972 Bytes- ]"\), 
        ",", \(RotationMatrix \[Rule] {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}\), 
        ",", \(SmoothKernelSize \[Rule] 0.0002793820340576056`\), 
        ",", \(SourceID \[Rule] 19920\), 
        ",", \(SurfaceNormalFunction \[Rule] \(({{1, 0, 0}, {0, 1, 0}, {0, 0, 
                  1}} &)\)\), ",", \(SurfaceNumber \[Rule] 1.`\), 
        ",", \(SymbolicValues \[Rule] {f1 \[Rule] 100.`, f2 \[Rule] 100.`}\), 
        ",", \(SystemABCDMatrix \[Rule] {{\(-1.0894245630128663`\), \
\(-0.6676741734861054`\)}, {\(-0.01991308441724173`\), \(-0.9301198876749336`\
\)}}\), ",", \(TransverseMagnification \[Rule] \(-1.0894245630128663`\)\), 
        ",", \(WaveFrontID \[Rule] 1.`\), 
        ",", \(WaveLength \[Rule] 0.532`\)}], "}"}]], "Output",
  CellLabel->"Out[186]=",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Interference and Wavefront Calculations", "Section",
  CellTags->{"AOG0.", "6", "AOG6.", "AOG6.1"}],

Cell[CellGroupData[{

Cell["6.1 Overview", "Subsection",
  CellTags->{"AOG0.", "6.1", "AOG6.", "AOG6.1"}],

Cell[TextData[{
  StyleBox["Optica",
    FontSlant->"Italic"],
  " contains two tools used for interference and wavefront calculations. \
These functions are ",
  StyleBox["FindWaveFronts", "Input"],
  " and ",
  StyleBox["FindInterference", "Input"],
  ". Finally, at the end of this chapter, we introduce a method to calculate \
propagated optical wavefronts that uses Gaussian wavelets."
}], "Text",
  CellLabel->"In[3]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],

Cell[CellGroupData[{

Cell["?FindWaveFronts", "Input",
  CellLabel->"In[21]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],

Cell[BoxData[
    \("FindWaveFronts[system, options] is a function designed to find the \
optical path length function and wave intensity function on a last surface in \
the optical system. \n\nFindWaveFronts calculates the wavefront function and \
the intensity mapping function at the final surface. This information is used \
together by FindInterference to calculate the complex field as well as the \
interference at the surface. As input, FindWaveFronts uses an optical system \
containing one or more light sources. FindWaveFronts works equally well for \
both point sources and planar sources. In addition, the light source need \
only contain a small number of rays (since the actual number of rays is \
internally specified).\n\nIf a one-dimensional light source is used (ie. \
WedgeOfRays or LineOfRays), then one-dimensional wavefront and intensity \
functions are calculated. If a two-dimensional light source is used (ie. \
PointOfRays or GridOfRays), then two-dimensional wavefront and intensity \
functions are determined. FindWaveFronts is also a label used with the \
RenderedParameters option. See also: FindInterference, OpticalPathDifference, \
WaveFrontIntensity, and OpticalLengthFunction."\)], "Print",
  CellLabel->"From In[21]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[FindWaveFronts]", "Input",
  CellLabel->"In[22]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],

Cell[BoxData[
    \({NumberOfRays \[Rule] 32, IntensitySamplePoints \[Rule] 32, 
      InterpolationOrder \[Rule] 1, ZernikeFit \[Rule] False, 
      ZernikeOrder \[Rule] 10, RenderedParameters \[Rule] {All}, 
      PlotDomain \[Rule] RayBoundary, Plot2D \[Rule] False, 
      PlotPoints \[Rule] 32, 
      IntensityScaleFactor \[Rule] Automatic}\)], "Output",
  CellLabel->"Out[22]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?FindInterference", "Input",
  CellLabel->"In[23]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],

Cell[BoxData[
    \("FindInterference[system, options] is a function that determines the \
interference function between multiple wavefronts hitting the last optical \
surface in an optical system. \n\nAs input, FindInterference takes either an \
optical system containing multiple light sources or the output from one or \
more FindWaveFronts calculations. FindInterference calculates the \
interference function by adding together the complex fields from the \
individual wavefronts hitting the optical surface and multiplying by the \
complex conjugate to get the intensity distribution on the surface. \
FindInterference works equally well for both point sources and planar \
sources. In addition, the light source need only contain a small number of \
rays (since the actual number of rays is internally specified).\n\nIf \
one-dimensional light sources are used (ie. WedgeOfRays or LineOfRays), then \
a one-dimensional interference function is calculated. If two-dimensional \
light sources are used (ie. PointOfRays or GridOfRays), then a \
two-dimensional interference functions is determined. FindInterference is \
also a label used with the RenderedParameters option. See also: \
FindWaveFronts, InterferenceFunction, OpticalPathDifference, \
WaveFrontIntensity, and OpticalLengthFunction."\)], "Print",
  CellLabel->"From In[23]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[FindInterference]", "Input",
  CellLabel->"In[24]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],

Cell[BoxData[
    \({NumberOfRays \[Rule] 32, NumberOfPoints \[Rule] 128, 
      InterpolationOrder \[Rule] 1, ZernikeFit \[Rule] False, 
      ZernikeOrder \[Rule] 10, 
      RenderedParameters \[Rule] {OpticalPathDifference, 
          InterferenceFunction}, PlotDomain \[Rule] RayBoundary, 
      PlotPoints \[Rule] 64, Mesh \[Rule] False, 
      Plot2D \[Rule] False}\)], "Output",
  CellLabel->"Out[24]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6."}]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 One-Dimensional Wavefronts", "Subsection",
  CellTags->{"AOG0.", "6.2", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[CellGroupData[{

Cell["Example 1", "Subsubsection",
  CellTags->{"AOG0.", "6.2.1", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell["\<\
sys = {
MoveDirected[WedgeOfRays[10],{0,-50},{100,0},SideOfObject->After],
MoveDirected[WedgeOfRays[10],{0,50},{100,0},SideOfObject->After],
Move[Screen[100],100]};\
\>", "Input",
  CellLabel->"In[25]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[CellGroupData[{

Cell["DrawSystem[sys,PlotType->TopView];", "Input",
  CellLabel->"In[26]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.5 0.00952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .02381 m
.97619 .18254 L
.97619 .34127 L
.97619 .5 L
.97619 .65873 L
.97619 .81746 L
.97619 .97619 L
.97619 .97619 L
.97619 .81746 L
.97619 .65873 L
.97619 .5 L
.97619 .34127 L
.97619 .18254 L
.97619 .02381 L
.97619 .02381 L
s
.97619 .5 m
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
s
.97619 .97619 m
.97619 .95996 L
.97619 .91239 L
.97619 .83672 L
.97619 .7381 L
.97619 .62325 L
.97619 .5 L
.97619 .37675 L
.97619 .2619 L
.97619 .16328 L
.97619 .08761 L
.97619 .04004 L
.97619 .02381 L
.97619 .04004 L
.97619 .08761 L
.97619 .16328 L
.97619 .2619 L
.97619 .37675 L
.97619 .5 L
.97619 .62325 L
.97619 .7381 L
.97619 .83672 L
.97619 .91239 L
.97619 .95996 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .02381 m
.97619 .40021 L
s
% Start of user PostScript
0 -50. 100. -10.4777 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .40021 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .02381 m
.97619 .5 L
s
% Start of user PostScript
0 -50. 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .02381 m
.97619 .60892 L
s
% Start of user PostScript
0 -50. 100. 11.4364 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .60892 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .97619 m
.97619 .39108 L
s
% Start of user PostScript
0 50. 100. -11.4364 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .39108 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .97619 m
.97619 .5 L
s
% Start of user PostScript
0 50. 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .97619 m
.97619 .59979 L
s
% Start of user PostScript
0 50. 100. 10.4777 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .59979 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3oool200WZ2_l0oooo4@3oool00`000000oooo0?ooo`050?ooo`00
203oool300WZ2_l0oooo3P3oool00`000000oooo0?ooo`050?ooo`002@3oool400WZ2_l0oooo303o
ool00`000000oooo0?ooo`050?ooo`002`3oool500WZ2_l0oooo2@3oool00`000000oooo0?ooo`05
0?ooo`003@3oool500WZ2_l0oooo1`3oool00`000000oooo0?ooo`050?ooo`003P3oool700WZ2_l0
oooo103oool00`000000oooo0?ooo`050?ooo`00403oool400WZ2P030?ooo`09jPX02NX:0?l0oooo
0P3oool00`000000oooo0?ooo`050?ooo`004P3oool01@09jPX0oooo00WZ2P09jPX0oooo00<02NX:
oP3oool00`000000oooo0?ooo`050?ooo`004`3oool200WZ2P030?ooo`09jPX02NX:0080oooo0`09
jP[k0?ooo`030000003oool0oooo00D0oooo000E0?ooo`0300WZ2P3oool0oooo00802NX:0`3oool2
00WZ2_T0oooo00<000000?ooo`3oool01@3oool001H0oooo0P09jPX20?ooo`802NX:0`3oool300WZ
2_H0oooo00<000000?ooo`3oool01@3oool001P0oooo0P09jPX20?ooo`802NX:103oool200WZ2_@0
oooo00<000000?ooo`3oool01@3oool001X0oooo00@02NX:0?ooo`3oool0oooo0P09jPX40?ooo`<0
2NX:l@3oool00`000000oooo0?ooo`050?ooo`006`3oool200WZ2P<0oooo0P09jPX50?ooo`802NX:
k`3oool00`000000oooo0?ooo`050?ooo`007@3oool200WZ2P<0oooo0P09jPX50?ooo`<02NX:k03o
ool00`000000oooo0?ooo`050?ooo`007`3oool00`09jPX0oooo0?ooo`020?ooo`802NX:1P3oool2
00WZ2^X0oooo00<000000?ooo`3oool01@3oool00200oooo0P09jPX40?ooo`802NX:1P3oool300WZ
2^L0oooo00<000000?ooo`3oool01@3oool00280oooo0P09jPX40?ooo`802NX:1`3oool200WZ2^D0
oooo00<000000?ooo`3oool01@3oool002@0oooo00<02NX:0?ooo`3oool00`3oool200WZ2PL0oooo
0`09jP[R0?ooo`030000003oool0oooo00D0oooo000U0?ooo`802NX:1@3oool200WZ2PP0oooo0P09
jP[P0?ooo`030000003oool0oooo00D0oooo000W0?ooo`0300WZ2P3oool0oooo00@0oooo0P09jPX8
0?ooo`<02NX:g@3oool00`000000oooo0?ooo`050?ooo`00:03oool200WZ2PH0oooo0P09jPX90?oo
o`<02NX:fP3oool00`000000oooo0?ooo`050?ooo`00:P3oool200WZ2PH0oooo0P09jPX:0?ooo`80
2NX:f03oool00`000000oooo0?ooo`050?ooo`00;03oool00`09jPX0oooo0?ooo`050?ooo`802NX:
2P3oool300WZ2]D0oooo00<000000?ooo`3oool01@3oool002d0oooo0P09jPX70?ooo`802NX:2`3o
ool200WZ2]<0oooo00<000000?ooo`3oool01@3oool002l0oooo0P09jPX70?ooo`802NX:2`3oool3
00WZ2]00oooo00<000000?ooo`3oool01@3oool00340oooo00<02NX:0?ooo`3oool01P3oool200WZ
2P`0oooo0P09jP[>0?ooo`030000003oool0oooo00D0oooo000b0?ooo`802NX:203oool200WZ2P`0
oooo0`09jP[;0?ooo`030000003oool0oooo00D0oooo000d0?ooo`0300WZ2P3oool0oooo00L0oooo
0P09jPX=0?ooo`802NX:b@3oool00`000000oooo0?ooo`050?ooo`00=@3oool200WZ2PT0oooo0P09
jPX=0?ooo`<02NX:aP3oool00`000000oooo0?ooo`050?ooo`00=`3oool200WZ2PT0oooo0P09jPX>
0?ooo`802NX:a03oool00`000000oooo0?ooo`050?ooo`00>@3oool00`09jPX0oooo0?ooo`080?oo
o`802NX:3P3oool300WZ2/40oooo00<000000?ooo`3oool01@3oool003X0oooo0P09jPX:0?ooo`80
2NX:3`3oool200WZ2[l0oooo00<000000?ooo`3oool01@3oool003`0oooo0P09jPX:0?ooo`802NX:
3`3oool300WZ2[`0oooo00<000000?ooo`3oool01@3oool003h0oooo00<02NX:0?ooo`3oool02@3o
ool200WZ2Q00oooo0`09jPZi0?ooo`030000003oool0oooo00D0oooo000o0?ooo`802NX:2`3oool2
00WZ2Q40oooo0P09jPZg0?ooo`030000003oool0oooo00D0oooo00110?ooo`802NX:2`3oool200WZ
2Q40oooo0`09jPZd0?ooo`030000003oool0oooo00D0oooo00130?ooo`0300WZ2P3oool0oooo00X0
oooo0P09jPXB0?ooo`802NX:/P3oool00`000000oooo0?ooo`050?ooo`00A03oool200WZ2P`0oooo
0P09jPXB0?ooo`<02NX:[`3oool00`000000oooo0?ooo`050?ooo`00AP3oool00`09jPX0oooo0?oo
o`0;0?ooo`802NX:4`3oool200WZ2Zd0oooo00<000000?ooo`3oool01@3oool004L0oooo0P09jPX=
0?ooo`802NX:4`3oool300WZ2ZX0oooo00<000000?ooo`3oool01@3oool004T0oooo0P09jPX=0?oo
o`802NX:503oool200WZ2ZP0oooo00<000000?ooo`3oool01@3oool004/0oooo00<02NX:0?ooo`3o
ool0303oool200WZ2Q@0oooo0`09jPZU0?ooo`030000003oool0oooo00D0oooo001<0?ooo`802NX:
3P3oool200WZ2QD0oooo0P09jPZS0?ooo`030000003oool0oooo00D0oooo001>0?ooo`802NX:3P3o
ool200WZ2QD0oooo0`09jPZP0?ooo`030000003oool0oooo00D0oooo001@0?ooo`0300WZ2P3oool0
oooo00d0oooo0P09jPXF0?ooo`802NX:WP3oool00`000000oooo0?ooo`050?ooo`00D@3oool200WZ
2Pl0oooo0P09jPXF0?ooo`<02NX:V`3oool00`000000oooo0?ooo`050?ooo`00D`3oool00`09jPX0
oooo0?ooo`0>0?ooo`802NX:5`3oool300WZ2YP0oooo00<000000?ooo`3oool01@3oool005@0oooo
0P09jPX@0?ooo`802NX:603oool200WZ2YH0oooo00<000000?ooo`3oool01@3oool005H0oooo0P09
jPX@0?ooo`802NX:603oool300WZ2Y<0oooo00<000000?ooo`3oool01@3oool005P0oooo00<02NX:
0?ooo`3oool03`3oool200WZ2QT0oooo0P09jPZA0?ooo`030000003oool0oooo00D0oooo001I0?oo
o`802NX:4@3oool200WZ2QT0oooo0`09jPZ>0?ooo`030000003oool0oooo00D0oooo001K0?ooo`80
2NX:4@3oool200WZ2QX0oooo0P09jPZ<0?ooo`030000003oool0oooo00D0oooo001M0?ooo`0300WZ
2P3oool0oooo0100oooo0P09jPXJ0?ooo`<02NX:R@3oool00`000000oooo0?ooo`050?ooo`00GP3o
ool200WZ2Q80oooo0P09jPXK0?ooo`802NX:Q`3oool00`000000oooo0?ooo`050?ooo`00H03oool2
00WZ2Q80oooo0P09jPXK0?ooo`<02NX:Q03oool00`000000oooo0?ooo`050?ooo`00HP3oool00`09
jPX0oooo0?ooo`0A0?ooo`802NX:703oool200WZ2X80oooo00<000000?ooo`3oool01@3oool006<0
oooo0P09jPXC0?ooo`802NX:703oool300WZ2Wl0oooo00<000000?ooo`3oool01@3oool006D0oooo
00<02NX:0?ooo`3oool04P3oool200WZ2Qd0oooo0P09jPYm0?ooo`030000003oool0oooo00D0oooo
001V0?ooo`802NX:503oool200WZ2Qd0oooo0`09jPYj0?ooo`030000003oool0oooo00D0oooo001X
0?ooo`802NX:503oool200WZ2Qh0oooo0P09jPYh0?ooo`030000003oool0oooo00D0oooo001Z0?oo
o`0300WZ2P3oool0oooo01<0oooo0P09jPXN0?ooo`<02NX:M@3oool00`000000oooo0?ooo`050?oo
o`00J`3oool200WZ2QD0oooo0P09jPXO0?ooo`<02NX:LP3oool00`000000oooo0?ooo`050?ooo`00
K@3oool200WZ2QD0oooo0P09jPXP0?ooo`802NX:L03oool00`000000oooo0?ooo`050?ooo`00K`3o
ool00`09jPX0oooo0?ooo`0D0?ooo`802NX:803oool300WZ2Vd0oooo00<000000?ooo`3oool01@3o
ool00700oooo0P09jPXF0?ooo`802NX:8@3oool200WZ2V/0oooo00<000000?ooo`3oool01@3oool0
0780oooo00<02NX:0?ooo`3oool05@3oool200WZ2R40oooo0`09jPYX0?ooo`030000003oool0oooo
00D0oooo001c0?ooo`802NX:5`3oool200WZ2R80oooo0P09jPYV0?ooo`030000003oool0oooo00D0
oooo001e0?ooo`802NX:5`3oool200WZ2R80oooo0`09jPYS0?ooo`030000003oool0oooo00D0oooo
001g0?ooo`0300WZ2P3oool0oooo01H0oooo0P09jPXS0?ooo`802NX:H@3oool00`000000oooo0?oo
o`050?ooo`00N03oool200WZ2QP0oooo0P09jPXS0?ooo`<02NX:GP3oool00`000000oooo0?ooo`05
0?ooo`00NP3oool200WZ2QP0oooo0P09jPXT0?ooo`802NX:G03oool00`000000oooo0?ooo`050?oo
o`00O03oool00`09jPX0oooo0?ooo`0G0?ooo`802NX:903oool300WZ2UT0oooo00<000000?ooo`3o
ool01@3oool007d0oooo0P09jPXI0?ooo`802NX:9@3oool200WZ2UL0oooo00<000000?ooo`3oool0
1@3oool007l0oooo0P09jPXI0?ooo`802NX:9@3oool300WZ2U@0oooo00<000000?ooo`3oool01@3o
ool00840oooo00<02NX:0?ooo`3oool0603oool200WZ2RH0oooo0`09jPYA0?ooo`030000003oool0
oooo00D0oooo00220?ooo`802NX:6P3oool200WZ2RL0oooo0P09jPY?0?ooo`030000003oool0oooo
00D0oooo00240?ooo`0300WZ2P3oool0oooo01T0oooo0P09jPXW0?ooo`<02NX:C03oool00`000000
oooo0?ooo`050?ooo`00Q@3oool200WZ2Q/0oooo0P09jPXX0?ooo`802NX:BP3oool00`000000oooo
0?ooo`050?ooo`00Q`3oool200WZ2Q/0oooo0P09jPXX0?ooo`<02NX:A`3oool00`000000oooo0?oo
o`050?ooo`00R@3oool00`09jPX0oooo0?ooo`0J0?ooo`802NX::@3oool200WZ2TD0oooo00<00000
0?ooo`3oool01@3oool008X0oooo0P09jPXL0?ooo`802NX::@3oool300WZ2T80oooo00<000000?oo
o`3oool01@3oool008`0oooo0P09jPXL0?ooo`802NX::P3oool200WZ2T00oooo00<000000?ooo`3o
ool01@3oool008h0oooo00<02NX:0?ooo`3oool06`3oool200WZ2RX0oooo0`09jPXm0?ooo`030000
003oool0oooo00D0oooo002?0?ooo`802NX:7@3oool200WZ2R/0oooo0P09jPXk0?ooo`030000003o
ool0oooo00D0oooo002A0?ooo`0300WZ2P3oool0oooo01`0oooo0P09jPX[0?ooo`<02NX:>03oool0
0`000000oooo0?ooo`050?ooo`00TP3oool200WZ2Qh0oooo0P09jPX/0?ooo`802NX:=P3oool00`00
0000oooo0?ooo`050?ooo`00U03oool200WZ2Qh0oooo0P09jPX/0?ooo`<02NX:<`3oool00`000000
oooo0?ooo`050?ooo`00UP3oool00`09jPX0oooo0?ooo`0M0?ooo`802NX:;@3oool300WZ2S00oooo
00<000000?ooo`3oool01@3oool009L0oooo0P09jPXO0?ooo`802NX:;P3oool200WZ2Rh0oooo00<0
00000?ooo`3oool01@3oool009T0oooo0P09jPXO0?ooo`802NX:;P3oool300WZ2R/0oooo00<00000
0?ooo`3oool01@3oool009/0oooo00<02NX:0?ooo`3oool07P3oool200WZ2Rl0oooo0P09jPXY0?oo
o`030000003oool0oooo00D0oooo002L0?ooo`802NX:803oool200WZ2Rl0oooo0`09jPXV0?ooo`03
0000003oool0oooo00D0oooo002N0?ooo`0300WZ2P3oool0oooo01l0oooo0P09jPX`0?ooo`802NX:
903oool00`000000oooo0?ooo`050?ooo`00W`3oool200WZ2R40oooo0P09jPX`0?ooo`<02NX:8@3o
ool00`000000oooo0?ooo`050?ooo`00X@3oool200WZ2R40oooo0P09jPXa0?ooo`802NX:7`3oool0
0`000000oooo0?ooo`050?ooo`00X`3oool00`09jPX0oooo0?ooo`0P0?ooo`802NX:<@3oool300WZ
2Q`0oooo00<000000?ooo`3oool01@3oool00:@0oooo0P09jPXR0?ooo`802NX:<P3oool200WZ2QX0
oooo00<000000?ooo`3oool01@3oool00:H0oooo0P09jPXR0?ooo`802NX:<P3oool300WZ2QL0oooo
00<000000?ooo`3oool01@3oool00:P0oooo00<02NX:0?ooo`3oool08@3oool200WZ2S<0oooo0P09
jPXE0?ooo`030000003oool0oooo00D0oooo002Y0?ooo`802NX:8`3oool200WZ2S<0oooo0`09jPXB
0?ooo`030000003oool0oooo00D0oooo002[0?ooo`802NX:8`3oool200WZ2S@0oooo0`09jPX?0?oo
o`030000003oool0oooo00D0oooo002]0?ooo`0300WZ2P3oool0oooo0280oooo0P09jPXe0?ooo`80
2NX:3@3oool00`000000oooo0?ooo`050?ooo`00[P3oool200WZ2R@0oooo0P09jPXe0?ooo`<02NX:
2P3oool00`000000oooo0?ooo`050?ooo`00/03oool00`09jPX0oooo0?ooo`0S0?ooo`802NX:=P3o
ool200WZ2P030?ooo`09jPX02NX:00D0oooo00<000000?ooo`3oool01@3oool00;40oooo0P09jPXU
0?ooo`802NX:=P3oool500WZ2P80oooo0P0000070?ooo`00/`3oool200WZ2RD0oooo0P09jPXe0?oo
o`H02NX:0P0000070?ooo`00]@3oool00`09jPX0oooo0?ooo`0T0?ooo`802NX:<@3oool900WZ2P03
0000003oool0oooo00D0oooo002f0?ooo`802NX:9P3oool200WZ2S00oooo1`09jPX2000000L0oooo
002h0?ooo`802NX:9P3oool200WZ2S00oooo1009jPX00`3oool00000000000070?ooo`00^P3oool0
0`09jPX0oooo0?ooo`0U0?ooo`802NX:;@3oool01009jPX0oooo00WZ2P09jPX30?ooo`030000003o
ool0oooo00D0oooo002k0?ooo`802NX:9`3oool200WZ2RT0oooo0P09jPX00`3oool02NX:00WZ2P04
0?ooo`030000003oool0oooo00D0oooo002m0?ooo`0300WZ2P3oool0oooo02H0oooo0P09jPXU0?oo
o`802NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo002n0?ooo`80
2NX::03oool200WZ2R80oooo00<02NX:0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`00
`03oool200WZ2RP0oooo0P09jPXN0?ooo`802NX:303oool00`000000oooo0?ooo`050?ooo`00`P3o
ool00`09jPX0oooo0?ooo`0W0?ooo`802NX:6`3oool00`09jPX0oooo0?ooo`0<0?ooo`030000003o
ool0oooo00D0oooo00330?ooo`802NX::@3oool200WZ2QL0oooo0P09jPX?0?ooo`030000003oool0
oooo00D0oooo00350?ooo`802NX::@3oool200WZ2Q<0oooo0P09jPXA0?ooo`030000003oool0oooo
00D0oooo00370?ooo`0300WZ2P3oool0oooo02P0oooo0P09jPX@0?ooo`0300WZ2P3oool0oooo0140
oooo00<000000?ooo`3oool01@3oool00<P0oooo0P09jPXZ0?ooo`802NX:303oool200WZ2Q@0oooo
00<000000?ooo`3oool01@3oool00<X0oooo0P09jPXZ0?ooo`802NX:203oool200WZ2QH0oooo00<0
00000?ooo`3oool01@3oool00<`0oooo00<02NX:0?ooo`3oool0:@3oool200WZ2PD0oooo00<02NX:
0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00c@3oool200WZ2R/0oooo0P09jPX00`3o
ool02NX:00WZ2P0I0?ooo`030000003oool0oooo00D0oooo003?0?ooo`0300WZ2P3oool0oooo02T0
oooo0`09jPXJ0?ooo`030000003oool0oooo00D0oooo003@0?ooo`802NX::03oool01009jPX0oooo
0?ooo`3oool200WZ2QP0oooo00<000000?ooo`3oool01@3oool00=80oooo0P09jPXT0?ooo`802NX:
1P3oool200WZ2QH0oooo00<000000?ooo`3oool01@3oool00=@0oooo00<02NX:0?ooo`3oool0803o
ool00`09jPX0oooo0?ooo`080?ooo`802NX:503oool00`000000oooo0?ooo`050?ooo`00e@3oool2
00WZ2Qh0oooo0P09jPX=0?ooo`802NX:4P3oool00`000000oooo0?ooo`050?ooo`00e`3oool200WZ
2QX0oooo0P09jPXA0?ooo`802NX:403oool00`000000oooo0?ooo`050?ooo`00f@3oool00`09jPX0
oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo01<0oooo0P09jPX>0?ooo`030000003oool0oooo00D0
oooo003J0?ooo`802NX:503oool200WZ2QP0oooo0P09jPX<0?ooo`030000003oool0oooo00D0oooo
003L0?ooo`0300WZ2P3oool0oooo00l0oooo0P09jPXL0?ooo`802NX:2P3oool00`000000oooo0?oo
o`050?ooo`00g@3oool200WZ2Ph0oooo00<02NX:0?ooo`3oool07P3oool200WZ2P030?ooo`09jPX0
2NX:00D0oooo00<000000?ooo`3oool01@3oool00=l0oooo0P09jPX:0?ooo`802NX:8`3oool400WZ
2P@0oooo00<000000?ooo`3oool01@3oool00>40oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`0T0?ooo`D02NX:0P3oool00`000000oooo0?ooo`050?ooo`00hP3oool200WZ2P@0oooo
0P09jPXV0?ooo`L02NX:00<0oooo0000003oool01P3oool00>@0oooo1009jPX[0?ooo`@02NX:0P00
00070?ooo`00i@3oool200WZ2Rl0oooo00<02NX:0000000000001`3oool00><0oooo0P09jPX20?oo
o`802NX::@3oool500WZ2P030?ooo`000000oooo00H0oooo003Q0?ooo`802NX:1P3oool200WZ2RD0
oooo1P09jPX20?ooo`030000003oool0oooo00D0oooo003P0?ooo`0300WZ2P3oool0oooo00P0oooo
00<02NX:0?ooo`3oool08`3oool300WZ2P@0oooo00<000000?ooo`3oool01@3oool00=h0oooo0P09
jPX<0?ooo`802NX:8@3oool200WZ2P030?ooo`09jPX0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00=`0oooo0P09jPX@0?ooo`0300WZ2P3oool0oooo01`0oooo0P09jPX20?ooo`0300WZ2P3oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00=/0oooo00<02NX:0?ooo`3oool04@3oool200WZ
2QX0oooo0P09jPX;0?ooo`030000003oool0oooo00D0oooo003I0?ooo`802NX:5P3oool200WZ2QH0
oooo0P09jPX=0?ooo`030000003oool0oooo00D0oooo003H0?ooo`0300WZ2P3oool0oooo01P0oooo
00<02NX:0?ooo`3oool04@3oool200WZ2Pl0oooo00<000000?ooo`3oool01@3oool00=H0oooo0P09
jPXL0?ooo`802NX:3`3oool200WZ2Q40oooo00<000000?ooo`3oool01@3oool00=@0oooo0P09jPXP
0?ooo`802NX:2`3oool200WZ2Q<0oooo00<000000?ooo`3oool01@3oool00=<0oooo00<02NX:0?oo
o`3oool08P3oool00`09jPX0oooo0?ooo`060?ooo`802NX:5@3oool00`000000oooo0?ooo`050?oo
o`00d@3oool200WZ2RH0oooo0P09jPX40?ooo`802NX:5`3oool00`000000oooo0?ooo`050?ooo`00
c`3oool200WZ2RX0oooo00@02NX:0?ooo`09jPX02NX:6@3oool00`000000oooo0?ooo`050?ooo`00
cP3oool00`09jPX0oooo0?ooo`0Z0?ooo`<02NX:6P3oool00`000000oooo0?ooo`050?ooo`00c03o
ool200WZ2R/0oooo0P09jPX30?ooo`802NX:603oool00`000000oooo0?ooo`050?ooo`00b`3oool0
0`09jPX0oooo0?ooo`0Y0?ooo`802NX:1`3oool00`09jPX0oooo0?ooo`0E0?ooo`030000003oool0
oooo00D0oooo00390?ooo`802NX::P3oool200WZ2PX0oooo0P09jPXE0?ooo`030000003oool0oooo
00D0oooo00370?ooo`802NX::P3oool200WZ2Ph0oooo0P09jPXC0?ooo`030000003oool0oooo00D0
oooo00360?ooo`0300WZ2P3oool0oooo02P0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo0100oooo
00<000000?ooo`3oool01@3oool00<@0oooo0P09jPXY0?ooo`802NX:5@3oool200WZ2Q00oooo00<0
00000?ooo`3oool01@3oool00<80oooo0P09jPXY0?ooo`802NX:6@3oool200WZ2Ph0oooo00<00000
0?ooo`3oool01@3oool00<40oooo00<02NX:0?ooo`3oool09`3oool200WZ2Qd0oooo00<02NX:0?oo
o`3oool02`3oool00`000000oooo0?ooo`050?ooo`00_`3oool200WZ2RP0oooo0P09jPXP0?ooo`80
2NX:2`3oool00`000000oooo0?ooo`050?ooo`00_@3oool200WZ2RP0oooo0P09jPXT0?ooo`0300WZ
2P3oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00;`0oooo00<02NX:0?ooo`3oool09P3o
ool200WZ2RL0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00;X0oooo0P09jPXW0?ooo`802NX::`3oool400WZ2P@0oooo00<000000?ooo`3oool01@3oool0
0;T0oooo00<02NX:0?ooo`3oool09@3oool200WZ2Rl0oooo0`09jPX30?ooo`030000003oool0oooo
00D0oooo002g0?ooo`802NX:9P3oool200WZ2S40oooo1009jPX00`3oool00000000000070?ooo`00
]@3oool200WZ2RH0oooo0P09jPXa0?ooo`L02NX:0P0000070?ooo`00]03oool00`09jPX0oooo0?oo
o`0T0?ooo`802NX:<P3oool900WZ2P030000003oool0oooo00D0oooo002b0?ooo`802NX:9@3oool2
00WZ2SL0oooo0`09jPX20?ooo`8000001`3oool00;00oooo0P09jPXU0?ooo`802NX:=P3oool500WZ
2P<0oooo0P0000070?ooo`00[`3oool00`09jPX0oooo0?ooo`0S0?ooo`802NX:=P3oool200WZ2P80
oooo00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`00[@3oool200WZ2R@0oooo
0P09jPXe0?ooo`<02NX:2`3oool00`000000oooo0?ooo`050?ooo`00[03oool00`09jPX0oooo0?oo
o`0R0?ooo`802NX:=@3oool200WZ2Ph0oooo00<000000?ooo`3oool01@3oool00:X0oooo0P09jPXS
0?ooo`802NX:=03oool300WZ2Q00oooo00<000000?ooo`3oool01@3oool00:P0oooo0P09jPXS0?oo
o`802NX:<`3oool300WZ2Q<0oooo00<000000?ooo`3oool01@3oool00:L0oooo00<02NX:0?ooo`3o
ool08@3oool200WZ2S<0oooo0P09jPXF0?ooo`030000003oool0oooo00D0oooo002U0?ooo`802NX:
8P3oool200WZ2S80oooo0`09jPXH0?ooo`030000003oool0oooo00D0oooo002S0?ooo`802NX:8P3o
ool200WZ2S80oooo0P09jPXK0?ooo`030000003oool0oooo00D0oooo002R0?ooo`0300WZ2P3oool0
oooo0200oooo0P09jPXa0?ooo`<02NX:7@3oool00`000000oooo0?ooo`050?ooo`00X03oool200WZ
2R40oooo0P09jPXa0?ooo`802NX:803oool00`000000oooo0?ooo`050?ooo`00WP3oool200WZ2R40
oooo0P09jPX`0?ooo`<02NX:8P3oool00`000000oooo0?ooo`050?ooo`00W@3oool00`09jPX0oooo
0?ooo`0O0?ooo`802NX:<03oool200WZ2RD0oooo00<000000?ooo`3oool01@3oool009/0oooo0P09
jPXP0?ooo`802NX:;`3oool300WZ2RL0oooo00<000000?ooo`3oool01@3oool009X0oooo00<02NX:
0?ooo`3oool07P3oool200WZ2Rl0oooo0P09jPXZ0?ooo`030000003oool0oooo00D0oooo002H0?oo
o`802NX:7`3oool200WZ2Rh0oooo0`09jPX/0?ooo`030000003oool0oooo00D0oooo002F0?ooo`80
2NX:7`3oool200WZ2Rh0oooo0P09jPX_0?ooo`030000003oool0oooo00D0oooo002E0?ooo`0300WZ
2P3oool0oooo01d0oooo0P09jPX]0?ooo`<02NX:<@3oool00`000000oooo0?ooo`050?ooo`00T`3o
ool200WZ2Qh0oooo0P09jPX/0?ooo`<02NX:=03oool00`000000oooo0?ooo`050?ooo`00T@3oool2
00WZ2Qh0oooo0P09jPX/0?ooo`802NX:=`3oool00`000000oooo0?ooo`050?ooo`00T03oool00`09
jPX0oooo0?ooo`0L0?ooo`802NX::`3oool300WZ2ST0oooo00<000000?ooo`3oool01@3oool008h0
oooo0P09jPXM0?ooo`802NX::`3oool200WZ2S`0oooo00<000000?ooo`3oool01@3oool008d0oooo
00<02NX:0?ooo`3oool06`3oool200WZ2RX0oooo0`09jPXn0?ooo`030000003oool0oooo00D0oooo
002;0?ooo`802NX:703oool200WZ2RX0oooo0P09jPY10?ooo`030000003oool0oooo00D0oooo0029
0?ooo`802NX:703oool200WZ2RT0oooo0`09jPY30?ooo`030000003oool0oooo00D0oooo00280?oo
o`0300WZ2P3oool0oooo01X0oooo0P09jPXY0?ooo`802NX:AP3oool00`000000oooo0?ooo`050?oo
o`00QP3oool200WZ2Q/0oooo0P09jPXX0?ooo`<02NX:B03oool00`000000oooo0?ooo`050?ooo`00
Q03oool200WZ2Q/0oooo0P09jPXX0?ooo`802NX:B`3oool00`000000oooo0?ooo`050?ooo`00P`3o
ool00`09jPX0oooo0?ooo`0I0?ooo`802NX:9`3oool300WZ2Td0oooo00<000000?ooo`3oool01@3o
ool00840oooo0P09jPXJ0?ooo`802NX:9`3oool200WZ2U00oooo00<000000?ooo`3oool01@3oool0
0800oooo00<02NX:0?ooo`3oool0603oool200WZ2RH0oooo0`09jPYB0?ooo`030000003oool0oooo
00D0oooo001n0?ooo`802NX:6@3oool200WZ2RD0oooo0`09jPYE0?ooo`030000003oool0oooo00D0
oooo001l0?ooo`802NX:6@3oool200WZ2RD0oooo0P09jPYH0?ooo`030000003oool0oooo00D0oooo
001k0?ooo`0300WZ2P3oool0oooo01L0oooo0P09jPXT0?ooo`<02NX:FP3oool00`000000oooo0?oo
o`050?ooo`00N@3oool200WZ2QP0oooo0P09jPXT0?ooo`802NX:G@3oool00`000000oooo0?ooo`05
0?ooo`00M`3oool200WZ2QP0oooo0P09jPXS0?ooo`<02NX:G`3oool00`000000oooo0?ooo`050?oo
o`00MP3oool00`09jPX0oooo0?ooo`0F0?ooo`802NX:8`3oool200WZ2V80oooo00<000000?ooo`3o
ool01@3oool007@0oooo0P09jPXG0?ooo`802NX:8P3oool300WZ2V@0oooo00<000000?ooo`3oool0
1@3oool00780oooo0P09jPXG0?ooo`802NX:8P3oool200WZ2VL0oooo00<000000?ooo`3oool01@3o
ool00740oooo00<02NX:0?ooo`3oool05@3oool200WZ2R40oooo0`09jPYY0?ooo`030000003oool0
oooo00D0oooo001_0?ooo`802NX:5P3oool200WZ2R40oooo0P09jPY/0?ooo`030000003oool0oooo
00D0oooo001^0?ooo`0300WZ2P3oool0oooo01@0oooo0P09jPXP0?ooo`<02NX:KP3oool00`000000
oooo0?ooo`050?ooo`00K03oool200WZ2QD0oooo0P09jPXP0?ooo`802NX:L@3oool00`000000oooo
0?ooo`050?ooo`00JP3oool200WZ2QD0oooo0P09jPXO0?ooo`<02NX:L`3oool00`000000oooo0?oo
o`050?ooo`00J@3oool00`09jPX0oooo0?ooo`0C0?ooo`802NX:7P3oool300WZ2WH0oooo00<00000
0?ooo`3oool01@3oool006L0oooo0P09jPXD0?ooo`802NX:7P3oool200WZ2WT0oooo00<000000?oo
o`3oool01@3oool006D0oooo0P09jPXD0?ooo`802NX:7@3oool300WZ2W/0oooo00<000000?ooo`3o
ool01@3oool006@0oooo00<02NX:0?ooo`3oool04P3oool200WZ2Qd0oooo0P09jPYn0?ooo`030000
003oool0oooo00D0oooo001R0?ooo`802NX:4`3oool200WZ2Q`0oooo0`09jPZ00?ooo`030000003o
ool0oooo00D0oooo001Q0?ooo`0300WZ2P3oool0oooo0140oooo0P09jPXL0?ooo`802NX:P`3oool0
0`000000oooo0?ooo`050?ooo`00G`3oool200WZ2Q80oooo0P09jPXK0?ooo`<02NX:Q@3oool00`00
0000oooo0?ooo`050?ooo`00G@3oool200WZ2Q80oooo0P09jPXK0?ooo`802NX:R03oool00`000000
oooo0?ooo`050?ooo`00G03oool00`09jPX0oooo0?ooo`0@0?ooo`802NX:6P3oool300WZ2XX0oooo
00<000000?ooo`3oool01@3oool005X0oooo0P09jPXA0?ooo`802NX:6P3oool200WZ2Xd0oooo00<0
00000?ooo`3oool01@3oool005P0oooo0P09jPXA0?ooo`802NX:6@3oool300WZ2Xl0oooo00<00000
0?ooo`3oool01@3oool005L0oooo00<02NX:0?ooo`3oool03`3oool200WZ2QT0oooo0P09jPZB0?oo
o`030000003oool0oooo00D0oooo001E0?ooo`802NX:403oool200WZ2QP0oooo0`09jPZD0?ooo`03
0000003oool0oooo00D0oooo001C0?ooo`802NX:403oool200WZ2QP0oooo0P09jPZG0?ooo`030000
003oool0oooo00D0oooo001B0?ooo`0300WZ2P3oool0oooo00h0oooo0P09jPXG0?ooo`<02NX:V@3o
ool00`000000oooo0?ooo`050?ooo`00D03oool200WZ2Pl0oooo0P09jPXF0?ooo`<02NX:W03oool0
0`000000oooo0?ooo`050?ooo`00C`3oool00`09jPX0oooo0?ooo`0=0?ooo`802NX:5P3oool200WZ
2Yl0oooo00<000000?ooo`3oool01@3oool004d0oooo0P09jPX>0?ooo`802NX:5@3oool300WZ2Z40
oooo00<000000?ooo`3oool01@3oool004/0oooo0P09jPX>0?ooo`802NX:5@3oool200WZ2Z@0oooo
00<000000?ooo`3oool01@3oool004X0oooo00<02NX:0?ooo`3oool0303oool200WZ2Q@0oooo0`09
jPZV0?ooo`030000003oool0oooo00D0oooo00180?ooo`802NX:3@3oool200WZ2Q@0oooo0P09jPZY
0?ooo`030000003oool0oooo00D0oooo00160?ooo`802NX:3@3oool200WZ2Q<0oooo0`09jPZ[0?oo
o`030000003oool0oooo00D0oooo00150?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPXC0?ooo`80
2NX:[P3oool00`000000oooo0?ooo`050?ooo`00@`3oool200WZ2P`0oooo0P09jPXB0?ooo`<02NX:
/03oool00`000000oooo0?ooo`050?ooo`00@P3oool00`09jPX0oooo0?ooo`0:0?ooo`802NX:4P3o
ool200WZ2[<0oooo00<000000?ooo`3oool01@3oool00400oooo0P09jPX;0?ooo`802NX:4@3oool3
00WZ2[D0oooo00<000000?ooo`3oool01@3oool003h0oooo0P09jPX;0?ooo`802NX:4@3oool200WZ
2[P0oooo00<000000?ooo`3oool01@3oool003d0oooo00<02NX:0?ooo`3oool02@3oool200WZ2Q00
oooo0`09jPZj0?ooo`030000003oool0oooo00D0oooo000k0?ooo`802NX:2P3oool200WZ2Pl0oooo
0`09jPZm0?ooo`030000003oool0oooo00D0oooo000i0?ooo`802NX:2P3oool200WZ2Pl0oooo0P09
jP[00?ooo`030000003oool0oooo00D0oooo000h0?ooo`0300WZ2P3oool0oooo00P0oooo0P09jPX>
0?ooo`<02NX:`P3oool00`000000oooo0?ooo`050?ooo`00=P3oool200WZ2PT0oooo0P09jPX>0?oo
o`802NX:a@3oool00`000000oooo0?ooo`050?ooo`00=03oool200WZ2PT0oooo0P09jPX=0?ooo`<0
2NX:a`3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`09jPX0oooo0?ooo`070?ooo`802NX:
3@3oool200WZ2/X0oooo00<000000?ooo`3oool01@3oool00340oooo0P09jPX80?ooo`802NX:303o
ool300WZ2/`0oooo00<000000?ooo`3oool01@3oool00300oooo00<02NX:0?ooo`3oool01P3oool2
00WZ2P`0oooo0P09jP[?0?ooo`030000003oool0oooo00D0oooo000^0?ooo`802NX:1`3oool200WZ
2P/0oooo0`09jP[A0?ooo`030000003oool0oooo00D0oooo000/0?ooo`802NX:1`3oool200WZ2P/0
oooo0P09jP[D0?ooo`030000003oool0oooo00D0oooo000[0?ooo`0300WZ2P3oool0oooo00D0oooo
0P09jPX:0?ooo`<02NX:eP3oool00`000000oooo0?ooo`050?ooo`00:@3oool200WZ2PH0oooo0P09
jPX:0?ooo`802NX:f@3oool00`000000oooo0?ooo`050?ooo`009`3oool200WZ2PH0oooo0P09jPX9
0?ooo`<02NX:f`3oool00`000000oooo0?ooo`050?ooo`009P3oool00`09jPX0oooo0?ooo`040?oo
o`802NX:203oool300WZ2]h0oooo00<000000?ooo`3oool01@3oool002@0oooo0P09jPX50?ooo`80
2NX:203oool200WZ2^40oooo00<000000?ooo`3oool01@3oool002<0oooo00<02NX:0?ooo`3oool0
0`3oool200WZ2PL0oooo0`09jP[S0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`802NX:103o
ool200WZ2PL0oooo0P09jP[V0?ooo`030000003oool0oooo00D0oooo000O0?ooo`802NX:103oool2
00WZ2PH0oooo0`09jP[X0?ooo`030000003oool0oooo00D0oooo000N0?ooo`0300WZ2P3oool0oooo
0080oooo0P09jPX60?ooo`802NX:j`3oool00`000000oooo0?ooo`050?ooo`00703oool200WZ2P<0
oooo0P09jPX50?ooo`<02NX:k@3oool00`000000oooo0?ooo`050?ooo`006P3oool200WZ2P<0oooo
0P09jPX50?ooo`802NX:l03oool00`000000oooo0?ooo`050?ooo`006@3oool01009jPX0oooo0?oo
o`3oool200WZ2P@0oooo0`09jP[b0?ooo`030000003oool0oooo00D0oooo000G0?ooo`802NX:0P3o
ool200WZ2P@0oooo0P09jP[e0?ooo`030000003oool0oooo00D0oooo000E0?ooo`802NX:0P3oool2
00WZ2P<0oooo0`09jP[g0?ooo`030000003oool0oooo00D0oooo000D0?ooo`0300WZ2P3oool0oooo
00802NX:0`3oool200WZ2_X0oooo00<000000?ooo`3oool01@3oool00180oooo0P09jPX00`3oool0
2NX:00WZ2P020?ooo`<02NX:o03oool00`000000oooo0?ooo`050?ooo`004@3oool01@09jPX0oooo
00WZ2P09jPX0oooo00<02NX:o`3oool00`000000oooo0?ooo`050?ooo`003`3oool400WZ2P030?oo
o`09jPX02NX:0?l0oooo0`3oool00`000000oooo0?ooo`050?ooo`003@3oool700WZ2_l0oooo1@3o
ool00`000000oooo0?ooo`050?ooo`00303oool500WZ2_l0oooo203oool00`000000oooo0?ooo`05
0?ooo`002P3oool500WZ2_l0oooo2P3oool00`000000oooo0?ooo`050?ooo`00203oool400WZ2_l0
oooo3@3oool00`000000oooo0?ooo`050?ooo`001`3oool300WZ2_l0oooo3`3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`09jPX0oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.50052, -52.5005, 0.365857, \
0.365857}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["wavefront = FindWaveFronts[sys]", "Input",
  CellLabel->"In[27]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.479169 0.0434597 -6.41876 0.0598313 [
[.04457 -0.0125 -9 -9 ]
[.04457 -0.0125 9 0 ]
[.26187 -0.0125 -6 -9 ]
[.26187 -0.0125 6 0 ]
[.47917 -0.0125 -3 -9 ]
[.47917 -0.0125 3 0 ]
[.69647 -0.0125 -3 -9 ]
[.69647 -0.0125 3 0 ]
[.91377 -0.0125 -6 -9 ]
[.91377 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04303 -18 -4.5 ]
[-0.0125 .04303 0 4.5 ]
[-0.0125 .16269 -18 -4.5 ]
[-0.0125 .16269 0 4.5 ]
[-0.0125 .28235 -18 -4.5 ]
[-0.0125 .28235 0 4.5 ]
[-0.0125 .40202 -18 -4.5 ]
[-0.0125 .40202 0 4.5 ]
[-0.0125 .52168 -18 -4.5 ]
[-0.0125 .52168 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04457 0 m
.04457 .00625 L
s
[(-10)] .04457 -0.0125 0 1 Mshowa
.26187 0 m
.26187 .00625 L
s
[(-5)] .26187 -0.0125 0 1 Mshowa
.47917 0 m
.47917 .00625 L
s
[(0)] .47917 -0.0125 0 1 Mshowa
.69647 0 m
.69647 .00625 L
s
[(5)] .69647 -0.0125 0 1 Mshowa
.91377 0 m
.91377 .00625 L
s
[(10)] .91377 -0.0125 0 1 Mshowa
.125 Mabswid
.08803 0 m
.08803 .00375 L
s
.13149 0 m
.13149 .00375 L
s
.17495 0 m
.17495 .00375 L
s
.21841 0 m
.21841 .00375 L
s
.30533 0 m
.30533 .00375 L
s
.34879 0 m
.34879 .00375 L
s
.39225 0 m
.39225 .00375 L
s
.43571 0 m
.43571 .00375 L
s
.52263 0 m
.52263 .00375 L
s
.56609 0 m
.56609 .00375 L
s
.60955 0 m
.60955 .00375 L
s
.65301 0 m
.65301 .00375 L
s
.73993 0 m
.73993 .00375 L
s
.78339 0 m
.78339 .00375 L
s
.82685 0 m
.82685 .00375 L
s
.87031 0 m
.87031 .00375 L
s
.00111 0 m
.00111 .00375 L
s
.95723 0 m
.95723 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04303 m
.00625 .04303 L
s
[(108)] -0.0125 .04303 1 0 Mshowa
0 .16269 m
.00625 .16269 L
s
[(110)] -0.0125 .16269 1 0 Mshowa
0 .28235 m
.00625 .28235 L
s
[(112)] -0.0125 .28235 1 0 Mshowa
0 .40202 m
.00625 .40202 L
s
[(114)] -0.0125 .40202 1 0 Mshowa
0 .52168 m
.00625 .52168 L
s
[(116)] -0.0125 .52168 1 0 Mshowa
.125 Mabswid
0 .07294 m
.00375 .07294 L
s
0 .10286 m
.00375 .10286 L
s
0 .13278 m
.00375 .13278 L
s
0 .19261 m
.00375 .19261 L
s
0 .22252 m
.00375 .22252 L
s
0 .25244 m
.00375 .25244 L
s
0 .31227 m
.00375 .31227 L
s
0 .34218 m
.00375 .34218 L
s
0 .3721 m
.00375 .3721 L
s
0 .43193 m
.00375 .43193 L
s
0 .46185 m
.00375 .46185 L
s
0 .49176 m
.00375 .49176 L
s
0 .01311 m
.00375 .01311 L
s
0 .55159 m
.00375 .55159 L
s
0 .58151 m
.00375 .58151 L
s
0 .61143 m
.00375 .61143 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04457 .61178 m
.04457 .61803 L
s
.26187 .61178 m
.26187 .61803 L
s
.47917 .61178 m
.47917 .61803 L
s
.69647 .61178 m
.69647 .61803 L
s
.91377 .61178 m
.91377 .61803 L
s
.125 Mabswid
.08803 .61428 m
.08803 .61803 L
s
.13149 .61428 m
.13149 .61803 L
s
.17495 .61428 m
.17495 .61803 L
s
.21841 .61428 m
.21841 .61803 L
s
.30533 .61428 m
.30533 .61803 L
s
.34879 .61428 m
.34879 .61803 L
s
.39225 .61428 m
.39225 .61803 L
s
.43571 .61428 m
.43571 .61803 L
s
.52263 .61428 m
.52263 .61803 L
s
.56609 .61428 m
.56609 .61803 L
s
.60955 .61428 m
.60955 .61803 L
s
.65301 .61428 m
.65301 .61803 L
s
.73993 .61428 m
.73993 .61803 L
s
.78339 .61428 m
.78339 .61803 L
s
.82685 .61428 m
.82685 .61803 L
s
.87031 .61428 m
.87031 .61803 L
s
.00111 .61428 m
.00111 .61803 L
s
.95723 .61428 m
.95723 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04303 m
1 .04303 L
s
.99375 .16269 m
1 .16269 L
s
.99375 .28235 m
1 .28235 L
s
.99375 .40202 m
1 .40202 L
s
.99375 .52168 m
1 .52168 L
s
.125 Mabswid
.99625 .07294 m
1 .07294 L
s
.99625 .10286 m
1 .10286 L
s
.99625 .13278 m
1 .13278 L
s
.99625 .19261 m
1 .19261 L
s
.99625 .22252 m
1 .22252 L
s
.99625 .25244 m
1 .25244 L
s
.99625 .31227 m
1 .31227 L
s
.99625 .34218 m
1 .34218 L
s
.99625 .3721 m
1 .3721 L
s
.99625 .43193 m
1 .43193 L
s
.99625 .46185 m
1 .46185 L
s
.99625 .49176 m
1 .49176 L
s
.99625 .01311 m
1 .01311 L
s
.99625 .55159 m
1 .55159 L
s
.99625 .58151 m
1 .58151 L
s
.99625 .61143 m
1 .61143 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.47917 0 m
.47917 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.05216 .02916 Mdot
.08065 .04388 Mdot
.10926 .05888 Mdot
.13801 .07415 Mdot
.16689 .0897 Mdot
.19591 .10553 Mdot
.22508 .12164 Mdot
.25439 .13804 Mdot
.28385 .15474 Mdot
.31346 .17173 Mdot
.34323 .18901 Mdot
.37315 .2066 Mdot
.40324 .2245 Mdot
.43348 .2427 Mdot
.4639 .26122 Mdot
.49448 .28005 Mdot
.52524 .2992 Mdot
.55618 .31867 Mdot
.5873 .33848 Mdot
.6186 .35861 Mdot
.65009 .37908 Mdot
.68177 .39989 Mdot
.71365 .42105 Mdot
.74573 .44256 Mdot
.77801 .46442 Mdot
.81049 .48664 Mdot
.84319 .50923 Mdot
.87611 .53219 Mdot
.90924 .55552 Mdot
.9426 .57922 Mdot
.5 Mabswid
.02381 .01472 m
.05372 .02997 L
.08634 .04687 L
.11698 .06298 L
.14644 .07869 L
.1778 .09565 L
.20799 .1122 L
.24008 .13003 L
.27099 .14745 L
.30073 .16442 L
.33237 .18271 L
.36283 .20054 L
.39213 .21789 L
.42332 .23658 L
.45333 .25478 L
.48525 .27436 L
.51599 .29344 L
.54556 .31199 L
.57703 .33194 L
.60732 .35136 L
.63951 .37221 L
.67053 .39251 L
.70038 .41224 L
.73212 .43344 L
.76269 .45405 L
.79209 .47406 L
.82339 .49555 L
.85351 .51643 L
.88553 .53882 L
.91638 .56059 L
.94605 .5817 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`009`3oool3000000@0oooo0P00000`0?ooo`<00000<03oool2000003<0oooo0`00000`0?oo
o`<00000103oool2000001`0oooo000X0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000;P3oool01@000000oooo0?ooo`3oool0000002h0oooo00@000000?ooo`3oool00000<@3o
ool01@000000oooo0?ooo`3oool000000300oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000K0?ooo`00803oool5000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000X0?ooo`D000001@3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo0000
03D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000001/0oooo000X0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000<P3oool0
0`000000oooo0?ooo`0/0?ooo`040000003oool0oooo000003D0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001/0oooo000X0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000;P3oool4000002l0oooo00@000000?ooo`3oool0
0000<@3oool400000340oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000K0?oo
o`009`3oool2000000@0oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`0`0?oo
o`040000003oool0oooo00000340oooo00<000000?ooo`3oool0<@3oool2000000@0oooo00@00000
0?ooo`3oool000006`3oool002P0oooo00<000000?ooo`3oool00`3oool2000002l0oooo1@00000_
0?ooo`800000<P3oool500000300oooo00<000000?ooo`3oool00`3oool2000001`0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000N0?ooooP000002P3oool0
01h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`080?ooo`007P3oool2000000@0oooo0P00001^0?ooo`030000003oool0oooo07d0oooo
0P00000:0?ooo`007P3oool00`000000oooo0?ooo`050?ooo`800000K03oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00P0oooo000N0?oo
o`030000003oool0oooo00P0oooo0P00001Y0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool02@3oool3000006L0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`080?ooo`002P3oool3000000@0oooo0P0000030?ooo`<00000
1@3oool00`000000oooo0?ooo`090?ooo`80000000<0oooo000000000000I@3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo0080oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03P3oool2000006<0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`080?ooo`00
2`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo0?ooo`020?ooo`8000004@3oool200000640oooo00<000000?ooo`3oool0O@3oool20000
00X0oooo000;0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool30000
00D0oooo00<000000?ooo`3oool0403oool4000005l0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo0P00001M
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0203oool000X0oooo0P0000040?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01H0oooo0P00001K0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0203o
ool000/0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`0000050?ooo`030000003oool0
oooo01L0oooo0`00001I0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0203oool0
01h0oooo00<000000?ooo`3oool05`3oool2000000030?ooo`000000000005L0oooo00<000000?oo
o`3oool0OP3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0L0?ooo`80
0000E@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`8000007`3oool300000580oooo00<000000?ooo`3oool0O@3o
ool2000000X0oooo000N0?ooo`030000003oool0oooo01h0oooo0P0000000`3oool000000000001@
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?oo
o`3oool08`3oool2000004h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`080?oo
o`007P3oool00`000000oooo0?ooo`0U0?ooo`800000C03oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo02D0oooo1000001:0?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool09@3o
ool200000080oooo0P0000180?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0203o
ool001h0oooo00<000000?ooo`3oool0:`3oool2000004H0oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`080?ooo`007P3oool2000002h0oooo0P0000140?ooo`030000003oool0oooo
07d0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`0]0?ooo`<00000@`3oool00`000000
oooo0?ooo`1n0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo0300oooo
0P0000110?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0203oool001h0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0<`3oool3000003d0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0d0?oo
o`<00000?03oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo00P0oooo000N0?ooo`800000>@3oool2000003T0oooo00<000000?ooo`3oool0
O@3oool2000000X0oooo000N0?ooo`030000003oool0oooo03X0oooo0`00000f0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0>`3oool3
000003D0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`0n0?ooo`800000<`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo0400oooo0P00000a0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool0203oool000X0oooo0`0000030?ooo`<00000103oool2000000D0oooo
00<000000?ooo`3oool0@P3oool2000002l0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`120?ooo`<00000;P3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0480oooo
0P0000000`3oool000000000000/0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
203oool000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo0P0000180?ooo`800000:P3oool00`000000oooo0?ooo`1m0?ooo`800000
2P3oool000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool0203oool000X0oooo0P0000040?ooo`800000103o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo04X0oooo0P00000W0?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`1:0?ooo`@000009@3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo00P0oooo000N0?ooo`030000003oool0oooo04l0oooo0P00000R0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0D@3oool200000200
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`080?ooo`007P3oool200000580oooo
1000000N0?ooo`030000003oool0oooo07d0oooo0P00000:0?ooo`007P3oool00`000000oooo0?oo
o`1E0?ooo`800000703oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00P0oooo000N
0?ooo`030000003oool0oooo05L0oooo0P00000J0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0F03oool2000001T0oooo00<000000?oo
o`3oool0OP3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1H0?ooo`@0
00005`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo05h0oooo0P00000C0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0203oool0
01h0oooo0P00001Q0?ooo`8000004@3oool00`000000oooo0?ooo`1m0?ooo`8000002P3oool001h0
oooo00<000000?ooo`3oool0H03oool4000000l0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1T0?ooo`8000003@3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06H0oooo0P00
000;0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0203oool001h0oooo00<00000
0?ooo`3oool0I`3oool2000000X0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`1W0?ooo`@00000203oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000
K@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07d0oooo0P00000:0?ooo`007P3o
ool00`000000oooo0?ooo`1]0?ooo`800000103oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo00P0oooo000N0?ooo`030000003oool0oooo06l0oooo0P0000020?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0K`3oool50000
0800oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0L`3oool2000007l0
oooo00<000000?ooo`3oool0203oool000X0oooo0`0000030?ooo`<000000P3oool5000000@0oooo
00<000000?ooo`3oool0L`3oool010000000oooo00000000001m0?ooo`030000003oool0oooo00P0
oooo000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo07<0oooo00D000000?ooo`3oool0oooo0000001l0?oo
o`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`800000M03oool00`000000oooo0?ooo`04000007T0
oooo0P00000:0?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00800000
0P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool0203oool000X0oooo0P0000040?ooo`8000000`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`060?ooo`800000
MP3oool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo0`0000050?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203o
ool2000007@0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`080?ooo`<00000L`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo00/0oooo0P00001a0?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`1^0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000M03oool00`000000oooo
0?ooo`0>0?ooo`800000K@3oool2000000X0oooo000N0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool0403oool2000006`0oooo00<000000?ooo`3oool0203oool001h0oooo00<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`0@0?ooo`<00000J`3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01<0oooo0P00001Y0?oo
o`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool05P3oool2000006H0oooo00<000000?ooo`3oool0
203oool001h0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0G0?ooo`<00000I03o
ool00`000000oooo0?ooo`080?ooo`007P3oool2000007@0oooo00<000000?ooo`3oool05`3oool2
000000030?ooo`000000oooo0640oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo01/0oooo0P00001Q0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool07@3oool2000005l0oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`0O0?ooo`800000G@3oool00`000000oooo0?ooo`080?ooo`007P3oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01l0oooo1000001K0?ooo`030000003oool0
oooo00P0oooo000N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00P0
oooo000N0?ooo`800000M03oool00`000000oooo0?ooo`0U0?ooo`800000EP3oool2000000X0oooo
000N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool09`3oool2000005D0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0W
0?ooo`<00000E03oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo02X0oooo0P00001B0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo00P0oooo000:0?ooo`<000000`3oool3000000@0oooo0`0000040?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool0;@3oool2000004l0oooo00<000000?ooo`3oool0
203oool000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0_0?ooo`800000C@3o
ool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo0?ooo`D00000103oool2000007@0oooo00<000000?ooo`3oool0;`3oool3000004/0oooo0P00
000:0?ooo`002`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003oool0
oooo07<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo00P0oooo000:0?ooo`800000103oool2000000D0oooo0P0000050?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool0=03oool2000004P0oooo00<000000?ooo`3oool0203oool000/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0f0?ooo`<00000A@3oool00`000000
oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo03L0oooo
0P0000150?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool0>@3oool2000004<0oooo00<000000?ooo`3oool0203oool001h0oooo0P00001d
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0?`3oool2000000X0oooo000N0?oo
o`030000003oool0oooo07<0oooo00<000000?ooo`3oool0?03oool200000400oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`0o0?ooo`800000?@3oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo03l0oooo0`00000l0?ooo`030000003o
ool0oooo00P0oooo000N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool0@`3oool2000003T0oooo00<000000?ooo`3oool0203oool001h0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0203oool001h0oooo0P00001d0?ooo`030000003oool0oooo04H0oooo
0`00000d0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`170?ooo`<00000=03oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo04/0oooo0P00000a0?oo
o`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool0CP3oool2000002h0oooo00<000000?ooo`3oool0
203oool001h0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1?0?ooo`800000;@3o
ool00`000000oooo0?ooo`080?ooo`007P3oool2000007@0oooo00<000000?ooo`3oool0C`3oool3
000002/0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
0580oooo0P00000Z0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0E@3oool2000002L0oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`1G0?ooo`8000009@3oool00`000000oooo0?ooo`080?ooo`002P3oool3000000<0oooo0`000003
0?ooo`<000001@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo05L0oooo0`00000T
0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`1J0?ooo`8000008P3oool00`000000oooo0?ooo`080?ooo`002`3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool0oooo100000050?ooo`800000M03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo01d0oooo0P00000:0?ooo`002`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`000000203oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo05h0oooo0P00000N
0?ooo`030000003oool0oooo00P0oooo000:0?ooo`800000103oool2000000@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo05l0oooo0P00000M0?oo
o`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool2000000D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1O0?ooo`<0
0000703oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0680oooo0P00000J0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00P0oooo000N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0I@3oool2
000001L0oooo00<000000?ooo`3oool0203oool001h0oooo0P00001d0?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool04`3oool2000000X0oooo000N0?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool0I`3oool2000001D0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1W0?ooo`@000004`3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo06/0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo06`0oooo0P00000@0?ooo`030000003oool0oooo00P0oooo000N0?oo
o`030000003oool0oooo07<0oooo00<000000?ooo`3oool0KP3oool2000000h0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool001h0oooo0P00001d0?ooo`030000
003oool0oooo06l0oooo1000000:0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`1_0?ooo`8000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo000N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo
000N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool2000000X0oooo000N0?ooooP000002P3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool002X0oooo0`00001H0?ooo`<000005`3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo01@0oooo000[0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo01<0oooo000U0?ooo`<00000
0`3oool3000000@0oooo0P0000020?ooo`D000000P3oool3000000<0oooo100000000`3oool00000
00000003000000L0oooo0`0000040?ooo`@000000`3oool200000080oooo1P0000060?ooo`D00000
0P3oool300000080oooo0`000000103oool000000000003oool4000000<0oooo0P0000020?ooo`H0
00001`3oool00`000000oooo0?ooo`030?ooo`@0000000<0oooo0000000000000P0000020?ooo`@0
00000`3oool300000080oooo1@0000030?ooo`80000000@0oooo0000003oool0oooo0P0000030?oo
o`<000002@3oool4000000030?ooo`000000000000<0000000<0oooo0000000000000P0000040?oo
o`8000000`3oool4000000050?ooo`00000000000000003oool00P000000103oool0000000000000
00030?ooo`<000001@3oool00`000000oooo0?ooo`0B0?ooo`00903oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`060000
003oool0oooo0000003oool000001P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@0
00000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000/0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`000000
0`3oool00`000000oooo000000080?ooo`030000003oool0oooo0180oooo000T0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000103oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`020?ooo`D000000P3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo00<0oooo0`0000030?ooo`040000003oool0oooo00000080oooo0`000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool5000000L0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`<0
00000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo1@0000040?ooo`030000003oool0
oooo0180oooo000T0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`<00000
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000001@3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool0
1P000000oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`00903oool01P000000oooo0?ooo`3oool0
00000?ooo`@000000P3oool400000080oooo0`0000040?ooo`<000000`3oool2000000D0oooo00<0
00000?ooo`3oool0203oool010000000oooo0?ooo`0000020?ooo`8000000`3oool4000000<0oooo
0`0000090?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`@000000`3oool9000000<0oooo
0`0000090?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`<000000`3oool400000080oooo
0`0000040?ooo`040000003oool0oooo0?ooo`80000000@0oooo000000000000oooo100000030?oo
o`<000002@3oool300000080oooo0`0000040?ooo`@0000000<0oooo0000000000000P0000030?oo
o`8000000`3oool4000000<0oooo0`0000030?ooo`<000001@3oool00`000000oooo0?ooo`0B0?oo
o`00903oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`080?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo000U0?ooo`<000002@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo0`0000090?ooo`@000002@3oool00`00
0000oooo0?ooo`020?ooo`8000002P3oool3000001H0oooo00<000000?ooo`3oool00P3oool20000
00d0oooo00<000000?ooo`3oool01P3oool200000100oooo0`00000:0?ooo`030000003oool0oooo
0100oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0D0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.8555, 106.463, \
0.0930942, 0.0676209}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.479169 0.0434597 -3.17375 0.034859 [
[.04457 -0.0125 -9 -9 ]
[.04457 -0.0125 9 0 ]
[.26187 -0.0125 -6 -9 ]
[.26187 -0.0125 6 0 ]
[.47917 -0.0125 -3 -9 ]
[.47917 -0.0125 3 0 ]
[.69647 -0.0125 -3 -9 ]
[.69647 -0.0125 3 0 ]
[.91377 -0.0125 -6 -9 ]
[.91377 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0507 -24 -4.5 ]
[-0.0125 .0507 0 4.5 ]
[-0.0125 .13785 -12 -4.5 ]
[-0.0125 .13785 0 4.5 ]
[-0.0125 .22499 -24 -4.5 ]
[-0.0125 .22499 0 4.5 ]
[-0.0125 .31214 -18 -4.5 ]
[-0.0125 .31214 0 4.5 ]
[-0.0125 .39929 -30 -4.5 ]
[-0.0125 .39929 0 4.5 ]
[-0.0125 .48644 -18 -4.5 ]
[-0.0125 .48644 0 4.5 ]
[-0.0125 .57358 -30 -4.5 ]
[-0.0125 .57358 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04457 0 m
.04457 .00625 L
s
[(-10)] .04457 -0.0125 0 1 Mshowa
.26187 0 m
.26187 .00625 L
s
[(-5)] .26187 -0.0125 0 1 Mshowa
.47917 0 m
.47917 .00625 L
s
[(0)] .47917 -0.0125 0 1 Mshowa
.69647 0 m
.69647 .00625 L
s
[(5)] .69647 -0.0125 0 1 Mshowa
.91377 0 m
.91377 .00625 L
s
[(10)] .91377 -0.0125 0 1 Mshowa
.125 Mabswid
.08803 0 m
.08803 .00375 L
s
.13149 0 m
.13149 .00375 L
s
.17495 0 m
.17495 .00375 L
s
.21841 0 m
.21841 .00375 L
s
.30533 0 m
.30533 .00375 L
s
.34879 0 m
.34879 .00375 L
s
.39225 0 m
.39225 .00375 L
s
.43571 0 m
.43571 .00375 L
s
.52263 0 m
.52263 .00375 L
s
.56609 0 m
.56609 .00375 L
s
.60955 0 m
.60955 .00375 L
s
.65301 0 m
.65301 .00375 L
s
.73993 0 m
.73993 .00375 L
s
.78339 0 m
.78339 .00375 L
s
.82685 0 m
.82685 .00375 L
s
.87031 0 m
.87031 .00375 L
s
.00111 0 m
.00111 .00375 L
s
.95723 0 m
.95723 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0507 m
.00625 .0507 L
s
[(92.5)] -0.0125 .0507 1 0 Mshowa
0 .13785 m
.00625 .13785 L
s
[(95)] -0.0125 .13785 1 0 Mshowa
0 .22499 m
.00625 .22499 L
s
[(97.5)] -0.0125 .22499 1 0 Mshowa
0 .31214 m
.00625 .31214 L
s
[(100)] -0.0125 .31214 1 0 Mshowa
0 .39929 m
.00625 .39929 L
s
[(102.5)] -0.0125 .39929 1 0 Mshowa
0 .48644 m
.00625 .48644 L
s
[(105)] -0.0125 .48644 1 0 Mshowa
0 .57358 m
.00625 .57358 L
s
[(107.5)] -0.0125 .57358 1 0 Mshowa
.125 Mabswid
0 .06813 m
.00375 .06813 L
s
0 .08556 m
.00375 .08556 L
s
0 .10299 m
.00375 .10299 L
s
0 .12042 m
.00375 .12042 L
s
0 .15528 m
.00375 .15528 L
s
0 .17271 m
.00375 .17271 L
s
0 .19014 m
.00375 .19014 L
s
0 .20757 m
.00375 .20757 L
s
0 .24242 m
.00375 .24242 L
s
0 .25985 m
.00375 .25985 L
s
0 .27728 m
.00375 .27728 L
s
0 .29471 m
.00375 .29471 L
s
0 .32957 m
.00375 .32957 L
s
0 .347 m
.00375 .347 L
s
0 .36443 m
.00375 .36443 L
s
0 .38186 m
.00375 .38186 L
s
0 .41672 m
.00375 .41672 L
s
0 .43415 m
.00375 .43415 L
s
0 .45158 m
.00375 .45158 L
s
0 .46901 m
.00375 .46901 L
s
0 .50387 m
.00375 .50387 L
s
0 .5213 m
.00375 .5213 L
s
0 .53873 m
.00375 .53873 L
s
0 .55615 m
.00375 .55615 L
s
0 .03327 m
.00375 .03327 L
s
0 .01584 m
.00375 .01584 L
s
0 .59101 m
.00375 .59101 L
s
0 .60844 m
.00375 .60844 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04457 .61178 m
.04457 .61803 L
s
.26187 .61178 m
.26187 .61803 L
s
.47917 .61178 m
.47917 .61803 L
s
.69647 .61178 m
.69647 .61803 L
s
.91377 .61178 m
.91377 .61803 L
s
.125 Mabswid
.08803 .61428 m
.08803 .61803 L
s
.13149 .61428 m
.13149 .61803 L
s
.17495 .61428 m
.17495 .61803 L
s
.21841 .61428 m
.21841 .61803 L
s
.30533 .61428 m
.30533 .61803 L
s
.34879 .61428 m
.34879 .61803 L
s
.39225 .61428 m
.39225 .61803 L
s
.43571 .61428 m
.43571 .61803 L
s
.52263 .61428 m
.52263 .61803 L
s
.56609 .61428 m
.56609 .61803 L
s
.60955 .61428 m
.60955 .61803 L
s
.65301 .61428 m
.65301 .61803 L
s
.73993 .61428 m
.73993 .61803 L
s
.78339 .61428 m
.78339 .61803 L
s
.82685 .61428 m
.82685 .61803 L
s
.87031 .61428 m
.87031 .61803 L
s
.00111 .61428 m
.00111 .61803 L
s
.95723 .61428 m
.95723 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0507 m
1 .0507 L
s
.99375 .13785 m
1 .13785 L
s
.99375 .22499 m
1 .22499 L
s
.99375 .31214 m
1 .31214 L
s
.99375 .39929 m
1 .39929 L
s
.99375 .48644 m
1 .48644 L
s
.99375 .57358 m
1 .57358 L
s
.125 Mabswid
.99625 .06813 m
1 .06813 L
s
.99625 .08556 m
1 .08556 L
s
.99625 .10299 m
1 .10299 L
s
.99625 .12042 m
1 .12042 L
s
.99625 .15528 m
1 .15528 L
s
.99625 .17271 m
1 .17271 L
s
.99625 .19014 m
1 .19014 L
s
.99625 .20757 m
1 .20757 L
s
.99625 .24242 m
1 .24242 L
s
.99625 .25985 m
1 .25985 L
s
.99625 .27728 m
1 .27728 L
s
.99625 .29471 m
1 .29471 L
s
.99625 .32957 m
1 .32957 L
s
.99625 .347 m
1 .347 L
s
.99625 .36443 m
1 .36443 L
s
.99625 .38186 m
1 .38186 L
s
.99625 .41672 m
1 .41672 L
s
.99625 .43415 m
1 .43415 L
s
.99625 .45158 m
1 .45158 L
s
.99625 .46901 m
1 .46901 L
s
.99625 .50387 m
1 .50387 L
s
.99625 .5213 m
1 .5213 L
s
.99625 .53873 m
1 .53873 L
s
.99625 .55615 m
1 .55615 L
s
.99625 .03327 m
1 .03327 L
s
.99625 .01584 m
1 .01584 L
s
.99625 .59101 m
1 .59101 L
s
.99625 .60844 m
1 .60844 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.47917 0 m
.47917 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.01 w
.05216 .60332 Mdot
.08065 .58627 Mdot
.10926 .56902 Mdot
.13801 .55158 Mdot
.16689 .53394 Mdot
.19591 .51611 Mdot
.22508 .49809 Mdot
.25439 .47987 Mdot
.28385 .46148 Mdot
.31346 .4429 Mdot
.34323 .42414 Mdot
.37315 .4052 Mdot
.40324 .38608 Mdot
.43348 .36679 Mdot
.4639 .34733 Mdot
.49448 .3277 Mdot
.52524 .30791 Mdot
.55618 .28795 Mdot
.5873 .26782 Mdot
.6186 .24754 Mdot
.65009 .22711 Mdot
.68177 .20651 Mdot
.71365 .18577 Mdot
.74573 .16488 Mdot
.77801 .14385 Mdot
.81049 .12267 Mdot
.84319 .10135 Mdot
.87611 .07989 Mdot
.90924 .0583 Mdot
.9426 .03657 Mdot
.5 Mabswid
.02381 .60332 m
.03076 .60332 L
.03837 .60332 L
.04221 .60332 L
.04632 .60332 L
.04831 .60332 L
.05019 .60332 L
.05101 .60332 L
.05188 .60332 L
.05284 .60291 L
.05372 .60239 L
.08634 .58284 L
.11563 .56516 L
.14682 .54619 L
.17684 .52783 L
.20876 .50817 L
.2395 .48913 L
.26907 .47071 L
.30053 .45101 L
.33083 .43195 L
.36302 .41161 L
.39404 .39193 L
.42389 .37291 L
.45563 .35262 L
.4862 .33302 L
.5156 .31411 L
.54689 .29394 L
.57702 .27447 L
.60904 .25374 L
.63989 .23373 L
.66956 .21445 L
.70113 .19391 L
.73153 .17412 L
.76076 .15508 L
.79189 .1348 L
.82184 .11527 L
.85369 .0945 L
.88436 .07451 L
.91387 .05528 L
.94527 .03483 L
.9755 .01517 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00;@3oool3000000@0oooo0P00000`0?ooo`<00000<03oool2000003<0oooo0`00000`0?oo
o`<00000103oool2000001H0oooo000^0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000;P3oool01@000000oooo0?ooo`3oool0000002h0oooo00@000000?ooo`3oool00000<@3o
ool01@000000oooo0?ooo`3oool000000300oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000E0?ooo`009P3oool5000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000X0?ooo`D000001@3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo0000
03D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000001D0oooo000^0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000<P3oool0
0`000000oooo0?ooo`0/0?ooo`040000003oool0oooo000003D0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001D0oooo000^0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000;P3oool4000002l0oooo00@000000?ooo`3oool0
0000<@3oool400000340oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000E0?oo
o`00;@3oool2000000@0oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`0`0?oo
o`040000003oool0oooo00000340oooo00<000000?ooo`3oool0<@3oool2000000@0oooo00@00000
0?ooo`3oool000005@3oool002h0oooo00<000000?ooo`3oool00`3oool2000002l0oooo1@00000_
0?ooo`800000<P3oool500000300oooo00<000000?ooo`3oool00`3oool2000001H0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000T0?ooooP00000103oool0
02@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07L0oooo
0P0000050?ooo`030000003oool0oooo0080oooo000T0?ooo`800000M03oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo07@0oooo0P0000080?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo07<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo000T0?ooo`800000
M03oool00`000000oooo0?ooo`1_0?ooo`<000002`3oool2000000@0oooo000T0?ooo`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool0K`3oool2000000d0oooo00<000000?ooo`3oool00P3o
ool000X0oooo0P0000030?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`<000001@3oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo06d0oooo0P00000?0?ooo`030000003oool0
oooo0080oooo000<0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`05
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo06/0oooo0P00000A0?ooo`030000003oool0oooo0080oooo000=0?ooo`050000003oool0
oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`800000M03oool00`000000oooo0?oo
o`1Z0?ooo`030000003oool0oooo0100oooo0P0000040?ooo`002P3oool4000000@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool0J03oool2000001@0oooo00<000000?ooo`3oool00P3oool000T0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool4000000D0oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`1W0?ooo`8000005@3oool00`000000oooo0?oo
o`020?ooo`002@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`1U0?ooo`@000005@3oool00`000000oooo0?ooo`020?ooo`002P3oool3000000<0oooo0`00
00080?ooo`D00000103oool2000007@0oooo00<000000?ooo`3oool0H`3oool2000001P0oooo0P00
00040?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0680oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo0600oooo0P00000L0?ooo`030000003oool0oooo0080oooo000T0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool0G`3oool2000001d0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1M0?ooo`@00000
7@3oool00`000000oooo0?ooo`020?ooo`00903oool2000007@0oooo00<000000?ooo`3oool0G03o
ool00`000000oooo0?ooo`0N0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool0
02@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1I0?ooo`8000008`3oool00`00
0000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo05L0
oooo0P00000U0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000M03oool00`000000oooo
0?ooo`1F0?ooo`<00000903oool2000000@0oooo000T0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool0E03oool2000002P0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1A0?oo
o`800000:`3oool00`000000oooo0?ooo`020?ooo`00903oool2000007@0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`0Z0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`1>0?ooo`<00000;@3oool00`000000oooo0?ooo`020?ooo`005P3o
ool2000000@0oooo0`0000050?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0C@3o
ool010000000oooo00000000000]0?ooo`030000003oool0oooo0080oooo000H0?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`006@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`1:0?ooo`800000<P3oool00`000000oooo0?ooo`020?ooo`005P3oool4
000000D0oooo00<000000?ooo`3oool00P3oool2000007@0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0a0?ooo`800000103oool001D0oooo00H000000?ooo`3oool0oooo0000003o
ool4000000D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`170?ooo`800000=@3o
ool00`000000oooo0?ooo`020?ooo`005@3oool01`000000oooo0?ooo`3oool000000?ooo`000000
203oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo04D0oooo1000000e0?ooo`030000
003oool0oooo0080oooo000F0?ooo`<000000P3oool5000000@0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3o
ool002@0oooo0P00001d0?ooo`030000003oool0oooo0480oooo0P00000i0?ooo`800000103oool0
02@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`0o0?ooo`800000?@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo03h0oooo0`00000m0?ooo`030000003oool0oooo0080oooo
000T0?ooo`800000M03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03d0oooo0P00
00040?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo03/0oooo0P000011
0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0080oooo000T0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool0=`3oool3000004@0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0f0?ooo`<00000
A@3oool00`000000oooo0?ooo`020?ooo`00903oool2000007@0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`150?ooo`800000103oool002@0oooo00<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`0c0?ooo`800000B@3oool00`000000oooo0?ooo`020?ooo`00903oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo02l0
oooo0`00001<0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000M03oool00`000000oooo
0?ooo`0^0?ooo`<00000C03oool2000000@0oooo000T0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0080oooo000:
0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`000005
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0:`3oool200000540oooo00<00000
0?ooo`3oool00P3oool000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo02T0oooo0P00001C0?ooo`030000003oool0oooo0080oooo000=0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`800000M03oool00`00
0000oooo0?ooo`0W0?ooo`800000E03oool2000000@0oooo000:0?ooo`@00000103oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`0V0?ooo`<00000E@3oool00`000000oooo0?ooo`020?ooo`002@3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01@3oool4000000D0oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`0T0?ooo`800000F03oool00`000000oooo0?ooo`020?ooo`00
2@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool00P3oool000X0oooo0`0000020?ooo`D0
00001`3oool5000000@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0Q0?ooo`80
0000F`3oool00`000000oooo0?ooo`020?ooo`00903oool2000007@0oooo00<000000?ooo`3oool0
7`3oool2000005`0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo01h0oooo0`00001M0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0
oooo07<0oooo00<000000?ooo`3oool0703oool2000000030?ooo`000000000005d0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001d0?ooo`03
0000003oool0oooo01T0oooo0P00001R0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0G0?ooo`800000I@3o
ool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo01D0oooo1000001U0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000M03oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo06H0oooo0P0000040?ooo`00903oool00`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo0180oooo0P00001Z0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0403oool2000006`0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`0?0?ooo`<00000K03oool00`000000oooo0?ooo`020?ooo`00903oool2000007@0oooo00<00000
0?ooo`3oool03@3oool2000000030?ooo`000000000006/0oooo0P0000040?ooo`00903oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`020?ooo`00403oool3000000@0oooo0P0000040?ooo`8000001@3oool00`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo00X0oooo0P00001b0?ooo`030000003oool0oooo0080
oooo000A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203oool20000
07@0oooo00<000000?ooo`3oool00P3oool00140oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`070?ooo`<00000M03oool00`000000oooo0?ooo`020?ooo`004@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool2000007@0oooo00<000000?ooo`3oool01@3oool2000007H0oooo0P0000040?ooo`004@3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`020?ooo`00403oool2000000@0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool00P3oool2000007X0oooo00<000000?ooo`3oool00P3oool00140oooo00<000000?ooo`3oool0
0`3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0
0P00001l0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000M03oool00`000000oooo0?oo
o`02000007/0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`<00000OP3oool0
0`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0L@3oool300000800
oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001`0?ooo`8000000P3oool00`000000oooo
0?ooo`1m0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0K`3oool200000080oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1]
0?ooo`800000103oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo06`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo06X0oooo0P0000070?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001X0?ooo`<00000
2@3oool00`000000oooo0?ooo`1m0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0I`3o
ool2000000X0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00903oool0
0`000000oooo0?ooo`1U0?ooo`800000303oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo0080oooo000T0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000H`3oool2000000l0
oooo00<000000?ooo`3oool0O@3oool2000000@0oooo000T0?ooo`030000003oool0oooo0600oooo
0P00000A0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool000@0oooo0`00
00040?ooo`8000000P3oool5000000<0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<0
00000?ooo`3oool0G`3oool300000140oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?oo
o`020?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0G@3oool2000001@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00
1@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`800000G03oool2000001H0oooo00<000000?ooo`3o
ool0O@3oool2000000@0oooo00050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0F03oool3000001P0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00
1@3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo0?ooo`050?ooo`@000001@3oool00`000000oooo0?ooo`1H0?ooo`8000006@3oool00`00
0000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo00040?ooo`800000103oool01P000000
oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo05H0oooo0P00000K0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool00P3oool000D0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`0000080?oo
o`D00000103oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00903oool2000005@0oooo0P00000N0?ooo`03
0000003oool0oooo07d0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1A0?ooo`800000
803oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003o
ool0oooo0500oooo0`00000P0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0CP3oool2000002<0oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`020?ooo`00903oool2000004h0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1m0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0B`3oool2000002H0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo
0?ooo`190?ooo`<000009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo
000T0?ooo`030000003oool0oooo04P0oooo00@000000?ooo`00000000009`3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000A`3oool2000002/0oooo00<0
00000?ooo`3oool0O@3oool2000000@0oooo000T0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo0480oooo0`00000^0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool00P3oool002@0oooo00<000000?ooo`3oool0@@3oool3000002l0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00903o
ool2000003l0oooo0P00000c0?ooo`030000003oool0oooo07d0oooo0P0000040?ooo`00403oool3
000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`004@3oool00`00
0000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo03/0oooo0P00000f0?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool00P3oool00140oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool3000003H0oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`004@3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3oool2000003X0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`1m0?ooo`800000103oool00140oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`000000oooo00@000001@3oool00`000000oooo0?oo
o`0g0?ooo`800000>P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000@
0?ooo`800000103oool01P000000oooo0?ooo`000000oooo000000P0oooo00<000000?ooo`3oool0
=03oool3000003`0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`004@3o
ool00`000000oooo0?ooo`030?ooo`8000000P3oool5000000@0oooo00<000000?ooo`3oool0<`3o
ool3000003d0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00903oool2
00000380oooo0P0000100?ooo`030000003oool0oooo07d0oooo0P0000040?ooo`00903oool00`00
0000oooo0?ooo`0_0?ooo`800000@P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo02`0oooo
0`0000140?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00
000/0?ooo`040000003oool00000000004@0oooo00<000000?ooo`3oool0O@3oool2000000@0oooo
000T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo02P0oooo0P000019
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?oo
o`3oool09@3oool3000004/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?oo
o`00903oool00`000000oooo0?ooo`0U0?ooo`800000C03oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo0080oooo000T0?ooo`800000903oool2000004h0oooo00<000000?ooo`3oool0
O@3oool2000000@0oooo000T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0
oooo0200oooo0P00001A0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool0
02@0oooo00<000000?ooo`3oool07P3oool2000005<0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`020?ooo`00903oool2000001d0oooo1000001C0?ooo`030000003oool0oooo07d0
oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`0J0?ooo`800000E`3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo0080oooo00040?ooo`<00000103oool2000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?oo
o`0H0?ooo`800000F@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo0005
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0G0?ooo`800000
FP3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo00050?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo0P00000F0?ooo`@00000FP3oool00`000000oooo0?ooo`1m0?ooo`800000
103oool000D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`001@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
1@3oool4000000D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1M0?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool000@0oooo0P0000040?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0403oool300000600oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`020?ooo`001@3oool00`000000oooo0?ooo`030?ooo`8000000P3oool5000000L0oooo
1@0000040?ooo`030000003oool0oooo0100oooo0P00001Q0?ooo`030000003oool0oooo07h0oooo
00<000000?ooo`3oool00P3oool002@0oooo0P00000?0?ooo`800000H`3oool00`000000oooo0?oo
o`1m0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0303oool2000006D0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`090?oo
o`<00000I`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000T0?ooo`03
0000003oool0oooo00<0oooo2000001X0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool00P3oool002@0oooo0P00001d0?ooo`030000003oool0oooo07d0oooo0P0000040?ooo`00903o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool002@0oooon00000040?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00dP3o
ool3000004/0oooo003C0?ooo`030000003oool0oooo04X0oooo001W0?ooo`030000003oool00000
00<0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000020?ooo`<000000`3oool30000
00@0oooo0`0000020?ooo`<0000000<0oooo0000000000000P3oool2000000P0oooo1@0000001@3o
ool00000000000000000oooo008000000P3oool2000000<0oooo0`0000020?ooo`<0000000<0oooo
000000000000100000020?ooo`D000000`3oool2000000@0oooo00<000000?ooo`3oool0B@3oool0
06L0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00H00000
0?ooo`3oool000000?ooo`0000060?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0B@3oool0
06L0oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?ooo`0000000P3oool50000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
1@0000020?ooo`040000003oool0oooo00000080oooo0`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0000001:0?ooo`00IP3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo0`0000030?ooo`8000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000000L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000004X0
oooo001V0?ooo`050000003oool000000?ooo`0000000P3oool2000000<0oooo0P0000000`3oool0
0000000000020?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo00000000
00000P3oool300000080oooo100000020?ooo`@000002P3oool010000000oooo0?ooo`3oool40000
0080oooo100000030?ooo`<000000P3oool4000000<0oooo10000000103oool00000000000000003
0?ooo`@000000P3oool2000000030?ooo`000000000004T0oooo001V0?ooo`050000003oool00000
0?ooo`000000503oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0500oooo001V
0?ooo`H000004P3oool5000001@0oooo00<000000?ooo`3oool0203oool5000000P0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0500oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14.4141, 89.6421, \
0.0930942, 0.116063}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.479169 0.0434597 0.309017 3.18303e-05 [
[.04457 -0.0125 -9 -9 ]
[.04457 -0.0125 9 0 ]
[.26187 -0.0125 -6 -9 ]
[.26187 -0.0125 6 0 ]
[.47917 -0.0125 -3 -9 ]
[.47917 -0.0125 3 0 ]
[.69647 -0.0125 -3 -9 ]
[.69647 -0.0125 3 0 ]
[.91377 -0.0125 -6 -9 ]
[.91377 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07029 -30 -4.5 ]
[-0.0125 .07029 0 4.5 ]
[-0.0125 .14987 -30 -4.5 ]
[-0.0125 .14987 0 4.5 ]
[-0.0125 .22944 -30 -4.5 ]
[-0.0125 .22944 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38859 -24 -4.5 ]
[-0.0125 .38859 0 4.5 ]
[-0.0125 .46817 -24 -4.5 ]
[-0.0125 .46817 0 4.5 ]
[-0.0125 .54774 -24 -4.5 ]
[-0.0125 .54774 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04457 0 m
.04457 .00625 L
s
[(-10)] .04457 -0.0125 0 1 Mshowa
.26187 0 m
.26187 .00625 L
s
[(-5)] .26187 -0.0125 0 1 Mshowa
.47917 0 m
.47917 .00625 L
s
[(0)] .47917 -0.0125 0 1 Mshowa
.69647 0 m
.69647 .00625 L
s
[(5)] .69647 -0.0125 0 1 Mshowa
.91377 0 m
.91377 .00625 L
s
[(10)] .91377 -0.0125 0 1 Mshowa
.125 Mabswid
.08803 0 m
.08803 .00375 L
s
.13149 0 m
.13149 .00375 L
s
.17495 0 m
.17495 .00375 L
s
.21841 0 m
.21841 .00375 L
s
.30533 0 m
.30533 .00375 L
s
.34879 0 m
.34879 .00375 L
s
.39225 0 m
.39225 .00375 L
s
.43571 0 m
.43571 .00375 L
s
.52263 0 m
.52263 .00375 L
s
.56609 0 m
.56609 .00375 L
s
.60955 0 m
.60955 .00375 L
s
.65301 0 m
.65301 .00375 L
s
.73993 0 m
.73993 .00375 L
s
.78339 0 m
.78339 .00375 L
s
.82685 0 m
.82685 .00375 L
s
.87031 0 m
.87031 .00375 L
s
.00111 0 m
.00111 .00375 L
s
.95723 0 m
.95723 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07029 m
.00625 .07029 L
s
[(-7500)] -0.0125 .07029 1 0 Mshowa
0 .14987 m
.00625 .14987 L
s
[(-5000)] -0.0125 .14987 1 0 Mshowa
0 .22944 m
.00625 .22944 L
s
[(-2500)] -0.0125 .22944 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .38859 m
.00625 .38859 L
s
[(2500)] -0.0125 .38859 1 0 Mshowa
0 .46817 m
.00625 .46817 L
s
[(5000)] -0.0125 .46817 1 0 Mshowa
0 .54774 m
.00625 .54774 L
s
[(7500)] -0.0125 .54774 1 0 Mshowa
.125 Mabswid
0 .08621 m
.00375 .08621 L
s
0 .10212 m
.00375 .10212 L
s
0 .11804 m
.00375 .11804 L
s
0 .13395 m
.00375 .13395 L
s
0 .16578 m
.00375 .16578 L
s
0 .1817 m
.00375 .1817 L
s
0 .19761 m
.00375 .19761 L
s
0 .21353 m
.00375 .21353 L
s
0 .24536 m
.00375 .24536 L
s
0 .26127 m
.00375 .26127 L
s
0 .27719 m
.00375 .27719 L
s
0 .2931 m
.00375 .2931 L
s
0 .32493 m
.00375 .32493 L
s
0 .34085 m
.00375 .34085 L
s
0 .35676 m
.00375 .35676 L
s
0 .37268 m
.00375 .37268 L
s
0 .40451 m
.00375 .40451 L
s
0 .42042 m
.00375 .42042 L
s
0 .43634 m
.00375 .43634 L
s
0 .45225 m
.00375 .45225 L
s
0 .48408 m
.00375 .48408 L
s
0 .5 m
.00375 .5 L
s
0 .51591 m
.00375 .51591 L
s
0 .53183 m
.00375 .53183 L
s
0 .05437 m
.00375 .05437 L
s
0 .03846 m
.00375 .03846 L
s
0 .02254 m
.00375 .02254 L
s
0 .00663 m
.00375 .00663 L
s
0 .56366 m
.00375 .56366 L
s
0 .57957 m
.00375 .57957 L
s
0 .59549 m
.00375 .59549 L
s
0 .6114 m
.00375 .6114 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04457 .61178 m
.04457 .61803 L
s
.26187 .61178 m
.26187 .61803 L
s
.47917 .61178 m
.47917 .61803 L
s
.69647 .61178 m
.69647 .61803 L
s
.91377 .61178 m
.91377 .61803 L
s
.125 Mabswid
.08803 .61428 m
.08803 .61803 L
s
.13149 .61428 m
.13149 .61803 L
s
.17495 .61428 m
.17495 .61803 L
s
.21841 .61428 m
.21841 .61803 L
s
.30533 .61428 m
.30533 .61803 L
s
.34879 .61428 m
.34879 .61803 L
s
.39225 .61428 m
.39225 .61803 L
s
.43571 .61428 m
.43571 .61803 L
s
.52263 .61428 m
.52263 .61803 L
s
.56609 .61428 m
.56609 .61803 L
s
.60955 .61428 m
.60955 .61803 L
s
.65301 .61428 m
.65301 .61803 L
s
.73993 .61428 m
.73993 .61803 L
s
.78339 .61428 m
.78339 .61803 L
s
.82685 .61428 m
.82685 .61803 L
s
.87031 .61428 m
.87031 .61803 L
s
.00111 .61428 m
.00111 .61803 L
s
.95723 .61428 m
.95723 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07029 m
1 .07029 L
s
.99375 .14987 m
1 .14987 L
s
.99375 .22944 m
1 .22944 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38859 m
1 .38859 L
s
.99375 .46817 m
1 .46817 L
s
.99375 .54774 m
1 .54774 L
s
.125 Mabswid
.99625 .08621 m
1 .08621 L
s
.99625 .10212 m
1 .10212 L
s
.99625 .11804 m
1 .11804 L
s
.99625 .13395 m
1 .13395 L
s
.99625 .16578 m
1 .16578 L
s
.99625 .1817 m
1 .1817 L
s
.99625 .19761 m
1 .19761 L
s
.99625 .21353 m
1 .21353 L
s
.99625 .24536 m
1 .24536 L
s
.99625 .26127 m
1 .26127 L
s
.99625 .27719 m
1 .27719 L
s
.99625 .2931 m
1 .2931 L
s
.99625 .32493 m
1 .32493 L
s
.99625 .34085 m
1 .34085 L
s
.99625 .35676 m
1 .35676 L
s
.99625 .37268 m
1 .37268 L
s
.99625 .40451 m
1 .40451 L
s
.99625 .42042 m
1 .42042 L
s
.99625 .43634 m
1 .43634 L
s
.99625 .45225 m
1 .45225 L
s
.99625 .48408 m
1 .48408 L
s
.99625 .5 m
1 .5 L
s
.99625 .51591 m
1 .51591 L
s
.99625 .53183 m
1 .53183 L
s
.99625 .05437 m
1 .05437 L
s
.99625 .03846 m
1 .03846 L
s
.99625 .02254 m
1 .02254 L
s
.99625 .00663 m
1 .00663 L
s
.99625 .56366 m
1 .56366 L
s
.99625 .57957 m
1 .57957 L
s
.99625 .59549 m
1 .59549 L
s
.99625 .6114 m
1 .6114 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.47917 0 m
.47917 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.05216 .02916 Mdot
.08065 .04388 Mdot
.10926 .05888 Mdot
.13801 .07415 Mdot
.16689 .0897 Mdot
.19591 .10553 Mdot
.22508 .12164 Mdot
.25439 .13804 Mdot
.28385 .15474 Mdot
.31346 .17173 Mdot
.34323 .18901 Mdot
.37315 .2066 Mdot
.40324 .2245 Mdot
.43348 .2427 Mdot
.4639 .26122 Mdot
.49448 .28005 Mdot
.52524 .2992 Mdot
.55618 .31867 Mdot
.5873 .33848 Mdot
.6186 .35861 Mdot
.65009 .37908 Mdot
.68177 .39989 Mdot
.71365 .42105 Mdot
.74573 .44256 Mdot
.77801 .46442 Mdot
.81049 .48664 Mdot
.84319 .50923 Mdot
.87611 .53219 Mdot
.90924 .55552 Mdot
.9426 .57922 Mdot
.5 Mabswid
.02381 .01472 m
.05372 .02997 L
.08634 .04687 L
.11698 .06298 L
.14644 .07869 L
.1778 .09565 L
.20799 .1122 L
.24008 .13003 L
.27099 .14745 L
.30073 .16442 L
.33237 .18271 L
.36283 .20054 L
.39213 .21789 L
.42332 .23658 L
.45333 .25478 L
.48525 .27436 L
.51599 .29344 L
.54556 .31199 L
.57703 .33194 L
.60732 .35136 L
.63951 .37221 L
.67053 .39251 L
.70038 .41224 L
.73212 .43344 L
.76269 .45405 L
.79209 .47406 L
.82339 .49555 L
.85351 .51643 L
.88553 .53882 L
.91638 .56059 L
.94605 .5817 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00;@3oool3000000@0oooo0P00000`0?ooo`<00000<03oool2000003<0oooo0`00000`0?oo
o`<00000103oool2000001H0oooo000^0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000;P3oool01@000000oooo0?ooo`3oool0000002h0oooo00@000000?ooo`3oool00000<@3o
ool01@000000oooo0?ooo`3oool000000300oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000E0?ooo`009P3oool5000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000X0?ooo`D000001@3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo0000
03D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000001D0oooo000^0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000<P3oool0
0`000000oooo0?ooo`0/0?ooo`040000003oool0oooo000003D0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001D0oooo000^0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000;P3oool4000002l0oooo00@000000?ooo`3oool0
0000<@3oool400000340oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000E0?oo
o`00;@3oool2000000@0oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`0`0?oo
o`040000003oool0oooo00000340oooo00<000000?ooo`3oool0<@3oool2000000@0oooo00@00000
0?ooo`3oool000005@3oool002h0oooo00<000000?ooo`3oool00`3oool2000002l0oooo1@00000_
0?ooo`800000<P3oool500000300oooo00<000000?ooo`3oool00`3oool2000001H0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000T0?ooooP00000103oool0
02@0oooo0P0000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`00903oool00`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool002@0oooo
00<000000?ooo`3oool00`3oool2000006h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`020?ooo`00903oool00`000000oooo0?ooo`050?ooo`800000K03oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000203oool00`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo07d0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`080?oo
o`800000J@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000T0?ooo`03
0000003oool0oooo00T0oooo0`00001W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool02@3oool2000000030?ooo`000000000006D0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00903oool2000000l0oooo0P00
001S0?ooo`030000003oool0oooo07d0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`0@
0?ooo`800000H@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo0100oooo1000001O0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool00P3oool002@0oooo00<000000?ooo`3oool0503oool2000005d0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`020?ooo`00903oool2000001L0oooo0P00001K0?ooo`030000
003oool0oooo07d0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`0G0?ooo`<00000F@3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000;0?ooo`030000003oool0
oooo0080oooo0`0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool05`3oool2
000000030?ooo`000000000005L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`02
0?ooo`002`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
703oool2000005D0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`000`3o
ool5000000@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool2000001l0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1m0?ooo`800000103oool000`0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`<00000DP3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo0080oooo000=0?ooo`030000003oool0000000<000000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool07P3oool2
000000030?ooo`00000000000500oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`02
0?ooo`002@3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool08`3oool2000004h0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`002@3oool5000000030?oo
o`000000000000<000000`3oool2000000@0oooo0P0000050?ooo`8000009P3oool2000004`0oooo
00<000000?ooo`3oool0O@3oool2000000@0oooo000T0?ooo`030000003oool0oooo02D0oooo1000
001:0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool09@3oool200000080oooo0P0000180?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0:`3oool2000004H0oooo00<000000?oo
o`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00903oool2000002h0oooo0P0000140?ooo`03
0000003oool0oooo07d0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`0]0?ooo`<00000
@`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003o
ool0oooo0300oooo0P0000110?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00000d0?ooo`<00000?@3oool00`00
0000oooo0?ooo`1m0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0=03oool3000003`0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0h0?ooo`800000>@3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000>`3oool3000003H0oooo00<00000
0?ooo`3oool0O@3oool2000000@0oooo000:0?ooo`<00000103oool2000000@0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`0k0?ooo`<00000=@3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo0080oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0n0?ooo`800000<`3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo0080oooo00030?ooo`D000001@3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0400oooo0P00000a0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool00P3oool000d0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool2000004<0oooo0P00
000_0?ooo`030000003oool0oooo07d0oooo0P0000040?ooo`002@3oool4000000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0@P3oool3000002h0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`020?ooo`002@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0480oooo0P0000000`3oool000000000000/0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool00P3oool000T0oooo1@0000030?ooo`800000103oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo04L0oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool00P3oool002@0oooo0P00001:0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0O@3oool2000000@0oooo000T0?ooo`030000003oool0oooo04X0oooo0P00000W0?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0BP3o
ool4000002D0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00903oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`020?ooo`00903oool200000500oooo0P00000R0?ooo`030000003oool0oooo
07d0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1A0?ooo`800000803oool00`000000
oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo0540oooo
1000000N0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00
001F0?ooo`800000703oool00`000000oooo0?ooo`1m0?ooo`800000103oool002@0oooo00<00000
0?ooo`3oool0E`3oool2000001X0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`1H0?ooo`8000006@3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo05P0oooo1000000G0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001M0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0O@3oool2000000@0oooo000T0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo0080oooo00090?ooo`D000000P3oool3000000@0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`1N0?ooo`8000004`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo0080oooo000:0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1P0?ooo`8000004@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080
oooo00030?ooo`D000000`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000H@3oool40000
00l0oooo00<000000?ooo`3oool0O@3oool2000000@0oooo000<0?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0I03oool2000000d0oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`020?ooo`002@3oool01P000000oooo0?ooo`3oool000000?ooo`@000000`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0IP3oool2000000/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`00
2@3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0I`3oool2000000X0oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`002P3oool300000080oooo1@000003
0?ooo`800000103oool2000000D0oooo0P00001X0?ooo`@00000203oool00`000000oooo0?ooo`1m
0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo07h0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3o
ool0K03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0K@3oool2000000@0oooo00<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`020?ooo`00903oool200000700oooo0P0000020?ooo`030000003o
ool0oooo07d0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1_0?ooo`D00000P03oool0
0`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`800000O`3oool00`00
0000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`040000003oool000000000
07d0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001d0?ooo`050000003oool0oooo0?oo
o`000000N`3oool2000000@0oooo000T0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool01000001j0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001d0?ooo`030000003oool0
oooo00H0oooo0P00001e0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`080?ooo`800000M03oool00`000000oooo0?ooo`020?ooo`007@3oool2000000D0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`<00000L`3oool00`000000
oooo0?ooo`020?ooo`00703oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool02`3oool200000740oooo00<000000?ooo`3oool00P3oool001`0oooo
00@000000?ooo`3oool00000103ooooh000000@0oooo000L0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0>0?ooo`800000KP3oool00`000000
oooo0?ooo`020?ooo`00703oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool0403oool2000006`0oooo00<000000?ooo`3oool00P3oool001`0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0100
oooo0`00001[0?ooo`030000003oool0oooo0080oooo000M0?ooo`8000001@3oool2000007@0oooo
00<000000?ooo`3oool04`3oool2000006P0oooo0P0000040?ooo`00903oool00`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`020?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01H0oooo0P00001V
0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool05`3oool3000006@0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001d0?ooo`03
0000003oool0oooo01L0oooo0P0000000`3oool000000?ooo`1Q0?ooo`800000103oool002@0oooo
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0K0?ooo`800000H@3oool00`000000oooo
0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01d0oooo0P00
001O0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0080oooo000T0?oo
o`800000M03oool00`000000oooo0?ooo`0O0?ooo`800000G03oool2000000@0oooo000T0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool07`3oool4000005/0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool00P3o
ool002@0oooo0P00001d0?ooo`030000003oool0oooo02D0oooo0P00001F0?ooo`800000103oool0
00T0oooo1@0000020?ooo`<00000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool09`3oool2000005D0oooo00<000000?ooo`3oool00P3oool000X0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool09`3oool3000005@0oooo00<000000?ooo`3oool00P3oool000/0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo02X0
oooo0P00001B0?ooo`030000003oool0oooo0080oooo000<0?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0080oooo0P00001d0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0CP3oool20000
00@0oooo00090?ooo`060000003oool0oooo0?ooo`000000oooo100000030?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo02d0oooo0P00001?0?ooo`030000003oool0oooo0080oooo00090?ooo`070000003o
ool0oooo0?ooo`000000oooo000000060?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo02l0oooo0P00001=
0?ooo`030000003oool0oooo0080oooo000:0?ooo`<000000P3oool5000000<0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo02l0oooo0`00001<0?oo
o`030000003oool0oooo0080oooo000T0?ooo`800000M03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo04P0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`020?ooo`00903o
ool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo03@0oooo0P0000180?ooo`030000003o
ool0oooo0080oooo000T0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0=P3oool3
000004D0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001d0?ooo`030000003oool0oooo
03L0oooo0P0000140?ooo`800000103oool002@0oooo00<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`0i0?ooo`800000@`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`020?ooo`00903oool2000007@0oooo00<000000?ooo`3oool0?03oool2000003l0oooo0P00
00040?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo03l0oooo0P00000m0?ooo`030000003oool0oooo0080oooo000T0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool0?`3oool3000003`0oooo00<000000?ooo`3o
ool00P3oool002@0oooo0P00001d0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
>03oool2000000@0oooo000T0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0@`3o
ool2000003T0oooo00<000000?ooo`3oool00P3oool000X0oooo0`0000040?ooo`800000103oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00090?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo04H0
oooo0`00000e0?ooo`030000003oool0oooo0080oooo000=0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo0P00001d0?ooo`030000003oool0oooo04L0oooo0`00000c0?ooo`800000103oool0
00d0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`020?ooo`002@3o
ool4000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1;0?oo
o`800000<@3oool00`000000oooo0?ooo`020?ooo`002@3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0080oooo00090?ooo`D000000`3oool2000000@0oooo0P000004
0?ooo`8000001@3oool2000007@0oooo00<000000?ooo`3oool0CP3oool2000002d0oooo0P000004
0?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo04l0oooo0P00000]0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool0C`3oool3000002`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`1B0?ooo`800000:P3oool00`000000oooo0?ooo`020?ooo`00903o
ool2000007@0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0V0?ooo`800000103o
ool002@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1E0?ooo`8000009`3oool0
0`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
05L0oooo0P00000U0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool0E`3oool3000002@0oooo00<000000?ooo`3oool00P3oool002@0oooo
0P00001d0?ooo`030000003oool0oooo05X0oooo0P00000Q0?ooo`800000103oool002@0oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`1N0?ooo`8000007P3oool00`000000oooo0?ooo`020?oo
o`00903oool2000007@0oooo00<000000?ooo`3oool0G`3oool2000001`0oooo0P0000040?ooo`00
903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo05l0oooo0`00000L0?ooo`030000
003oool0oooo0080oooo000;0?ooo`030000003oool0oooo0080oooo0`0000040?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1R0?ooo`8000006P3o
ool00`000000oooo0?ooo`020?ooo`002`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool00P3oool000`0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool20000
07@0oooo00<000000?ooo`3oool0I@3oool2000001H0oooo0P0000040?ooo`00303oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo000=0?ooo`030000003oool00000
00<000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`1W0?ooo`8000005@3oool00`000000oooo0?oo
o`020?ooo`002@3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`1W0?ooo`@000004`3oool00`000000oooo0?ooo`020?ooo`002@3oool500000003
0?ooo`000000000000<000000`3oool2000000@0oooo0P0000050?ooo`800000M03oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0oooo00l0oooo0P0000040?ooo`00903oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo06`0oooo0P00000@0?ooo`030000003oool0oooo0080oooo
000T0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0KP3oool2000000h0oooo00<0
00000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001d0?oo
o`030000003oool0oooo06l0oooo1000000:0?ooo`800000103oool002@0oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`1_0?ooo`8000000P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo000T0?ooo`800000M03oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo00@0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`00903oool00`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07h0oooo
00<000000?ooo`3oool00P3oool002@0oooo0P0000090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0P00
00040?ooo`00903ooooh000000@0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
000f0?ooo`<00000RP3oool00`000000oooo0?ooo`0[0?ooo`<000005@3oool00`000000oooo0?oo
o`0D0?ooo`00=`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`00<@3oool3000000<0oooo0`0000040?oo
o`8000000P3oool500000080oooo0`0000030?ooo`@0000000<0oooo0000000000000`0000070?oo
o`<00000103oool4000000<0oooo0P0000020?ooo`H000001P3oool400000080oooo1@0000000`3o
ool0000000000003000000030?ooo`000000000000<000000P3oool300000080oooo0`0000040?oo
o`<000000P3oool3000000040?ooo`00000000000?ooo`<000000`3oool3000000T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000030?ooo`@000000`3oool00`000000oooo0?ooo`02
0?ooo`<000000P3oool500000080oooo0`0000020?ooo`<0000000@0oooo000000000000oooo1000
00030?ooo`8000000P3oool:000000D0oooo00<000000?ooo`3oool04P3oool00300oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0000
000<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool010000000oooo0?oo
o`0000040?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool00000
00H0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool04P3oool00300oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000000H0oooo0`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool3
000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`D000000P3oool01P000000
oooo0?ooo`000000oooo000000D0oooo1@0000080?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`000000oooo000000020?ooo`<000000`3oool00`000000oooo000000020?ooo`D000000`3o
ool010000000oooo0?ooo`3oool500000080oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000000P3oool3000000D0oooo00<0
00000?ooo`3oool04P3oool00300oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo0`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000
0`3oool010000000oooo0?ooo`0000050?ooo`060000003oool0oooo0000003oool00000203oool0
0`000000oooo0?ooo`0B0?ooo`00<03oool01P000000oooo0?ooo`3oool000000?ooo`@000000P3o
ool400000080oooo0`0000040?ooo`<000000`3oool2000000D0oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`0000020?ooo`8000000`3oool4000000<0oooo0`0000090?ooo`050000
003oool0oooo0000003oool00`0000040?ooo`@000000P3oool400000080oooo0`0000020?ooo`80
000000<0oooo0000000000000P3oool300000080oooo100000030?ooo`<000000`3oool3000000T0
oooo00<000000?ooo`3oool00P3oool6000000030?ooo`000000000000<0oooo0P0000000`3oool0
0000000000020?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`<000000P3oool4000000<0
oooo2@0000030?ooo`<000000`3oool4000000@0oooo00<000000?ooo`3oool04P3oool00300oooo
00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01<0oooo000a0?oo
o`<000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo0`0000090?oo
o`@000002@3oool00`000000oooo0?ooo`020?ooo`8000002P3oool4000000@0oooo00<000000?oo
o`3oool0103oool2000000@0oooo0P00000^0?ooo`030000003oool0oooo01P0oooo0`00000F0?oo
o`030000003oool0oooo0080oooo0P00000;0?ooo`030000003oool0oooo01@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14.4141, -11245, 0.0930942, \
127.107}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.520831 0.0434597 -6.41876 0.0598313 [
[.08623 -0.0125 -9 -9 ]
[.08623 -0.0125 9 0 ]
[.30353 -0.0125 -6 -9 ]
[.30353 -0.0125 6 0 ]
[.52083 -0.0125 -3 -9 ]
[.52083 -0.0125 3 0 ]
[.73813 -0.0125 -3 -9 ]
[.73813 -0.0125 3 0 ]
[.95543 -0.0125 -6 -9 ]
[.95543 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04303 -18 -4.5 ]
[-0.0125 .04303 0 4.5 ]
[-0.0125 .16269 -18 -4.5 ]
[-0.0125 .16269 0 4.5 ]
[-0.0125 .28235 -18 -4.5 ]
[-0.0125 .28235 0 4.5 ]
[-0.0125 .40202 -18 -4.5 ]
[-0.0125 .40202 0 4.5 ]
[-0.0125 .52168 -18 -4.5 ]
[-0.0125 .52168 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08623 0 m
.08623 .00625 L
s
[(-10)] .08623 -0.0125 0 1 Mshowa
.30353 0 m
.30353 .00625 L
s
[(-5)] .30353 -0.0125 0 1 Mshowa
.52083 0 m
.52083 .00625 L
s
[(0)] .52083 -0.0125 0 1 Mshowa
.73813 0 m
.73813 .00625 L
s
[(5)] .73813 -0.0125 0 1 Mshowa
.95543 0 m
.95543 .00625 L
s
[(10)] .95543 -0.0125 0 1 Mshowa
.125 Mabswid
.12969 0 m
.12969 .00375 L
s
.17315 0 m
.17315 .00375 L
s
.21661 0 m
.21661 .00375 L
s
.26007 0 m
.26007 .00375 L
s
.34699 0 m
.34699 .00375 L
s
.39045 0 m
.39045 .00375 L
s
.43391 0 m
.43391 .00375 L
s
.47737 0 m
.47737 .00375 L
s
.56429 0 m
.56429 .00375 L
s
.60775 0 m
.60775 .00375 L
s
.65121 0 m
.65121 .00375 L
s
.69467 0 m
.69467 .00375 L
s
.78159 0 m
.78159 .00375 L
s
.82505 0 m
.82505 .00375 L
s
.86851 0 m
.86851 .00375 L
s
.91197 0 m
.91197 .00375 L
s
.04277 0 m
.04277 .00375 L
s
.99889 0 m
.99889 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04303 m
.00625 .04303 L
s
[(108)] -0.0125 .04303 1 0 Mshowa
0 .16269 m
.00625 .16269 L
s
[(110)] -0.0125 .16269 1 0 Mshowa
0 .28235 m
.00625 .28235 L
s
[(112)] -0.0125 .28235 1 0 Mshowa
0 .40202 m
.00625 .40202 L
s
[(114)] -0.0125 .40202 1 0 Mshowa
0 .52168 m
.00625 .52168 L
s
[(116)] -0.0125 .52168 1 0 Mshowa
.125 Mabswid
0 .07294 m
.00375 .07294 L
s
0 .10286 m
.00375 .10286 L
s
0 .13278 m
.00375 .13278 L
s
0 .19261 m
.00375 .19261 L
s
0 .22252 m
.00375 .22252 L
s
0 .25244 m
.00375 .25244 L
s
0 .31227 m
.00375 .31227 L
s
0 .34218 m
.00375 .34218 L
s
0 .3721 m
.00375 .3721 L
s
0 .43193 m
.00375 .43193 L
s
0 .46185 m
.00375 .46185 L
s
0 .49176 m
.00375 .49176 L
s
0 .01311 m
.00375 .01311 L
s
0 .55159 m
.00375 .55159 L
s
0 .58151 m
.00375 .58151 L
s
0 .61143 m
.00375 .61143 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08623 .61178 m
.08623 .61803 L
s
.30353 .61178 m
.30353 .61803 L
s
.52083 .61178 m
.52083 .61803 L
s
.73813 .61178 m
.73813 .61803 L
s
.95543 .61178 m
.95543 .61803 L
s
.125 Mabswid
.12969 .61428 m
.12969 .61803 L
s
.17315 .61428 m
.17315 .61803 L
s
.21661 .61428 m
.21661 .61803 L
s
.26007 .61428 m
.26007 .61803 L
s
.34699 .61428 m
.34699 .61803 L
s
.39045 .61428 m
.39045 .61803 L
s
.43391 .61428 m
.43391 .61803 L
s
.47737 .61428 m
.47737 .61803 L
s
.56429 .61428 m
.56429 .61803 L
s
.60775 .61428 m
.60775 .61803 L
s
.65121 .61428 m
.65121 .61803 L
s
.69467 .61428 m
.69467 .61803 L
s
.78159 .61428 m
.78159 .61803 L
s
.82505 .61428 m
.82505 .61803 L
s
.86851 .61428 m
.86851 .61803 L
s
.91197 .61428 m
.91197 .61803 L
s
.04277 .61428 m
.04277 .61803 L
s
.99889 .61428 m
.99889 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04303 m
1 .04303 L
s
.99375 .16269 m
1 .16269 L
s
.99375 .28235 m
1 .28235 L
s
.99375 .40202 m
1 .40202 L
s
.99375 .52168 m
1 .52168 L
s
.125 Mabswid
.99625 .07294 m
1 .07294 L
s
.99625 .10286 m
1 .10286 L
s
.99625 .13278 m
1 .13278 L
s
.99625 .19261 m
1 .19261 L
s
.99625 .22252 m
1 .22252 L
s
.99625 .25244 m
1 .25244 L
s
.99625 .31227 m
1 .31227 L
s
.99625 .34218 m
1 .34218 L
s
.99625 .3721 m
1 .3721 L
s
.99625 .43193 m
1 .43193 L
s
.99625 .46185 m
1 .46185 L
s
.99625 .49176 m
1 .49176 L
s
.99625 .01311 m
1 .01311 L
s
.99625 .55159 m
1 .55159 L
s
.99625 .58151 m
1 .58151 L
s
.99625 .61143 m
1 .61143 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.52083 0 m
.52083 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.0574 .57922 Mdot
.09076 .55552 Mdot
.12389 .53219 Mdot
.15681 .50923 Mdot
.18951 .48664 Mdot
.22199 .46442 Mdot
.25427 .44256 Mdot
.28635 .42105 Mdot
.31823 .39989 Mdot
.34991 .37908 Mdot
.3814 .35861 Mdot
.4127 .33848 Mdot
.44382 .31867 Mdot
.47476 .2992 Mdot
.50552 .28005 Mdot
.5361 .26122 Mdot
.56652 .2427 Mdot
.59676 .2245 Mdot
.62685 .2066 Mdot
.65677 .18901 Mdot
.68654 .17173 Mdot
.71615 .15474 Mdot
.74561 .13804 Mdot
.77492 .12164 Mdot
.80409 .10553 Mdot
.83311 .0897 Mdot
.86199 .07415 Mdot
.89074 .05888 Mdot
.91935 .04388 Mdot
.94784 .02916 Mdot
.5 Mabswid
.02381 .60332 m
.05372 .58186 L
.08634 .55865 L
.11698 .53705 L
.14644 .51646 L
.1778 .49473 L
.20799 .474 L
.24008 .45218 L
.27099 .43135 L
.30073 .41151 L
.33237 .39061 L
.36283 .37068 L
.39213 .35171 L
.42332 .33172 L
.45333 .31268 L
.48525 .29266 L
.51599 .2736 L
.54556 .25546 L
.57703 .23638 L
.60732 .21822 L
.63951 .19916 L
.67053 .18102 L
.70038 .16379 L
.73212 .14569 L
.76269 .12848 L
.79209 .11215 L
.82339 .095 L
.85351 .07871 L
.88553 .06164 L
.91638 .04544 L
.94605 .03009 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00<@3oool3000000@0oooo0P00000`0?ooo`<00000<@3oool200000380oooo0`00000`0?oo
o`<00000103oool200000180oooo000b0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000;P3oool01@000000oooo0?ooo`3oool0000002l0oooo00@000000?ooo`3oool00000<03o
ool01@000000oooo0?ooo`3oool000000300oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000A0?ooo`00:P3oool5000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000X0?ooo`D000001@3oool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo0000
03@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000140oooo000b0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000<P3oool0
0`000000oooo0?ooo`0]0?ooo`040000003oool0oooo000003@0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000140oooo000b0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000;P3oool400000300oooo00@000000?ooo`3oool0
0000<03oool400000340oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000A0?oo
o`00<@3oool2000000@0oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`0a0?oo
o`040000003oool0oooo00000300oooo00<000000?ooo`3oool0<@3oool2000000@0oooo00@00000
0?ooo`3oool000004@3oool00380oooo00<000000?ooo`3oool00`3oool2000002l0oooo1@00000`
0?ooo`800000<@3oool500000300oooo00<000000?ooo`3oool00`3oool200000180oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000N0?ooooP000002P3oool0
01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`080?ooo`007P3oool2000007l0oooo00<000000?ooo`3oool0K03oool2000000@0oooo
0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo06X0oooo0P00
00070?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo000N0?oo
o`030000003oool0oooo07h0oooo00<000000?ooo`3oool0I`3oool2000000X0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1U0?ooo`80
0000303oool00`000000oooo0?ooo`080?ooo`002P3oool3000000@0oooo0P0000030?ooo`<00000
1@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo06<0oooo1000000<0?ooo`030000
003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`1Q0?ooo`800000403oool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo
0?ooo`020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?oo
o`800000O`3oool00`000000oooo0?ooo`1N0?ooo`<000004@3oool2000000X0oooo000;0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool3000000D0oooo00<000000?oo
o`3oool0OP3oool00`000000oooo0?ooo`1M0?ooo`<000004`3oool00`000000oooo0?ooo`080?oo
o`002`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0F`3oool2
000001H0oooo00<000000?ooo`3oool0203oool000X0oooo0P0000040?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo000;
0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo05L0oooo0`00000I0?ooo`030000003oool0oooo00P0oooo000N0?oo
o`030000003oool0oooo07h0oooo00<000000?ooo`3oool0EP3oool3000001X0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1D0?ooo`80
00007@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo0580oooo0P00000O0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000O`3o
ool00`000000oooo0?ooo`1@0?ooo`800000803oool2000000X0oooo000N0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0CP3oool400000240oooo00<000000?ooo`3oool0203oool0
01h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1<0?ooo`8000009@3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo04X0
oooo0P00000W0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07h0oooo
00<000000?ooo`3oool0B03oool3000002P0oooo00<000000?ooo`3oool0203oool001h0oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`160?ooo`80000000<0oooo000000000000:03o
ool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo04@0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000O`3oool00`00
0000oooo0?ooo`120?ooo`800000;P3oool2000000X0oooo000N0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool0@@3oool3000002l0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0o0?ooo`800000<P3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo03d0oooo0P00
000d0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0>`3oool2000003H0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?oo
o`3oool0OP3oool00`000000oooo0?ooo`0i0?ooo`@00000=P3oool00`000000oooo0?ooo`080?oo
o`007P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo03L0oooo0P00000j0?ooo`03
0000003oool0oooo00P0oooo000N0?ooo`800000O`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo03T0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo03@0oooo0P00000m0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0<`3oool3000003d0oooo00<000000?ooo`3oool0203oool0
01h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`0`0?ooo`800000@@3oool00`000000oooo0?ooo`080?ooo`002P3oool3000000<0oooo
0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02h0oooo
0P0000130?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07h0oooo
00<000000?ooo`3oool0;03oool2000004D0oooo00<000000?ooo`3oool0203oool000/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0Z0?ooo`@00000A@3oool00`000000oooo
0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool2000007l0oooo00<000000?ooo`3oool0:03oool2000004P0oooo
0P00000:0?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02H0oooo
0P00001;0?ooo`030000003oool0oooo00P0oooo000:0?ooo`800000103oool2000000@0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02D0oooo
0P00001<0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?oo
o`0S0?ooo`@00000C03oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo0240oooo0P00001@0?ooo`030000003oool0oooo00P0oooo000N0?oo
o`030000003oool0oooo07h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool07P3oool2000005<0oooo00<000000?ooo`3oool0203oool001h0oooo0P00001o0?ooo`030000
003oool0oooo01`0oooo1000001B0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0203o
ool001h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0I0?ooo`800000F03oool0
0`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo
01H0oooo0`00001J0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool05P3oool2000005/0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0D0?ooo`800000G@3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo0140oooo0P00001P0?ooo`030000003oool0oooo00P0oooo000N0?oo
o`800000O`3oool00`000000oooo0?ooo`0?0?ooo`800000H@3oool2000000X0oooo000N0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool03P3oool300000680oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0<0?ooo`800000
I@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo00X0oooo0P00001W0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool01`3oool3000006T0oooo00<000000?ooo`3oool0203oool0
01h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`070?ooo`800000JP3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00D0
oooo0P00001/0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000O`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo06/0oooo0P00000:0?ooo`007P3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo0080oooo0P00001_0?ooo`030000003oool0oooo00P0oooo000N
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool00P00001a0?ooo`030000003oool0
oooo00P0oooo000N0?ooo`030000003oool0oooo07h0oooo1@00001a0?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo07d0oooo0P00001e0?ooo`030000003oool0oooo00P0
oooo000:0?ooo`<000000`3oool300000080oooo1@0000040?ooo`030000003oool0oooo07/0oooo
0P0000000`3oool000000?ooo`1d0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo07X0oooo00D000000?ooo`3oool0oooo0000001e0?ooo`030000003oool0oooo00P0
oooo000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`800000N@3oool3000000<0oooo00<000000?ooo`3oool0LP3oool2000000X0oooo
000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo07L0oooo00@000000?ooo`00000000000`3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
MP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0
203oool000X0oooo0P0000040?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0M03oool2000000P0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`00
00050?ooo`030000003oool0oooo0780oooo0P00000:0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0L@3oool3000000X0oooo00<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1_0?oo
o`8000003@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo06h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo00P0oooo000N0?ooo`800000K@3oool200000100oooo00<000000?ooo`3oool0
LP3oool2000000X0oooo000N0?ooo`030000003oool0oooo06X0oooo0P00000B0?ooo`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0J@3oool3
00000180oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`1X0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo
0?ooo`1U0?ooo`8000005`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00P0oooo
000N0?ooo`030000003oool0oooo0680oooo0`00000I0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool0203oool001h0oooo0P00001S0?ooo`8000006P3oool00`000000oooo0?ooo`1b
0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0H03oool2000001`0oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`00
7P3oool00`000000oooo0?ooo`1M0?ooo`8000007`3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo05X0oooo0`00000Q0?ooo`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0FP3oool2
00000280oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`1H0?ooo`800000903oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo05H0oooo0P00000V0?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool0203oool001h0oooo0P00001F0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0LP3oool2000000X0oooo000N0?ooo`030000003oool0oooo05<0oooo0P00
000Y0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203oool001h0oooo00<00000
0?ooo`3oool0D@3oool4000002T0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1>0?ooo`80
0000;P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000:0?ooo`<00000
0`3oool3000000@0oooo0`0000040?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo04/0oooo0P00000a0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203o
ool000/0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool5000000@0oooo0P00
001:0?ooo`@00000<@3oool00`000000oooo0?ooo`1b0?ooo`8000002P3oool000/0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`160?ooo`800000=P3oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000:0?ooo`800000103oool20000
00D0oooo0P0000050?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04<0
oooo0P00000i0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool0@P3oool3000003T0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`007P3oool200000400oooo0P00000m
0?ooo`030000003oool0oooo0780oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?oo
o`007P3oool00`000000oooo0?ooo`0l0?ooo`800000@03oool00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo03X0oooo0`0000110?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0>@3o
ool010000000oooo0000000000110?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0
203oool001h0oooo00<000000?ooo`3oool0=`3oool2000004D0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`080?ooo`007P3oool2000003@0oooo0P0000190?ooo`030000003oool0oooo0780
oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`0b0?ooo`<00000B@3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000N
0?ooo`030000003oool0oooo02l0oooo0P00001=0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool0;03oool200000500oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`00
7P3oool00`000000oooo0?ooo`0[0?ooo`800000D@3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`800000:`3oool300000540oooo00<000000?ooo`3oool0LP3o
ool2000000X0oooo000N0?ooo`030000003oool0oooo02P0oooo0P00001D0?ooo`030000003oool0
oooo07<0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203oool001h0
oooo00<000000?ooo`3oool09@3oool2000005L0oooo00<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0S0?ooo`800000F@3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000:0?ooo`<000000`3oool3000000<0oooo0`00
00050?ooo`030000003oool0oooo0280oooo0`00001I0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`800000G03o
ool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3o
ool4000000D0oooo0P00000N0?ooo`800000G`3oool00`000000oooo0?ooo`1b0?ooo`8000002P3o
ool000/0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool0203oool000X0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01/0oooo0P00001Q0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`8000001@3oool00`000000oooo0?ooo`0I0?ooo`@00000H@3oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo01D0oooo0P00001W0?ooo`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool0203oool001h0oooo0P00000E0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0LP3oool2000000X0oooo000N0?ooo`030000003oool0oooo
01<0oooo0P00001Y0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203oool001h0
oooo00<000000?ooo`3oool04@3oool4000006T0oooo00<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06/0oooo
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?oo
o`0>0?ooo`800000KP3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000N
0?ooo`030000003oool0oooo00`0oooo0P00001`0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1`0?oo
o`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203oool001h0oooo0P00000:0?ooo`<0
0000LP3oool00`000000oooo0?ooo`1b0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0
203oool010000000oooo00000000001b0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203o
ool001h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo07<0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1g0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203oool001h0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`8000002P3oool001h0oooon000000:0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00:P3oool3000005P0oooo0`00000G0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0503oool002/0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool04`3oool002D0oooo0`0000030?oo
o`<00000103oool200000080oooo1@0000020?ooo`<000000`3oool4000000030?ooo`0000000000
00<000001`3oool3000000@0oooo100000030?ooo`8000000P3oool6000000H0oooo1@0000020?oo
o`<000000P3oool3000000040?ooo`00000000000?ooo`@000000`3oool200000080oooo1P000007
0?ooo`030000003oool0oooo00<0oooo100000000`3oool000000000000200000080oooo10000003
0?ooo`<000000P3oool5000000<0oooo0P000000103oool000000?ooo`3oool2000000<0oooo0`00
00090?ooo`@0000000<0oooo0000000000000`0000000`3oool0000000000002000000@0oooo0P00
00030?ooo`@0000000D0oooo00000000000000000?ooo`02000000040?ooo`0000000000000000<0
oooo0`0000050?ooo`030000003oool0oooo0180oooo000T0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00H000000?oo
o`3oool000000?ooo`0000060?ooo`060000003oool0oooo0000003oool000000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000002`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0000000P0oooo00<000000?ooo`3oool04P3oool002@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool0000000H0oooo0`0000040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo0080oooo1@0000020?ooo`060000003oool0oooo0000003o
ool000000`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool00`3oool3000000<0oooo00@000000?ooo`3oool000000P3oool300000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`020?ooo`D000001`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0080oooo0`0000030?ooo`030000003oool0oooo00<0oooo0`000003
0?ooo`060000003oool0oooo0000003oool000001@3oool5000000@0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0`0000020?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`060000
003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`060000
003oool0oooo0000003oool000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000070?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0180oooo000T0?ooo`060000003oool0oooo0?ooo`000000
oooo100000020?ooo`@000000P3oool3000000@0oooo0`0000030?ooo`8000001@3oool00`000000
oooo0?ooo`080?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`@000000`3oool30000
00T0oooo00<000000?ooo`3oool00`3oool300000080oooo100000030?ooo`T000000`3oool30000
00T0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0`0000030?ooo`@000000P3oool30000
00@0oooo00@000000?ooo`3oool0oooo0P000000103oool000000000003oool4000000<0oooo0`00
00090?ooo`<000000P3oool3000000@0oooo100000000`3oool0000000000002000000<0oooo0P00
00030?ooo`@000000`3oool3000000<0oooo0`0000050?ooo`030000003oool0oooo0180oooo000T
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool002D0oooo0`0000090?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03@3oool3000000T0oooo100000090?ooo`030000003o
ool0oooo0080oooo0P00000:0?ooo`<000005P3oool00`000000oooo0?ooo`020?ooo`8000003@3o
ool00`000000oooo0?ooo`060?ooo`800000403oool3000000X0oooo00<000000?ooo`3oool0403o
ool2000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14.8142, 106.463, \
0.0930942, 0.0676209}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.520831 0.0434597 -3.17375 0.049312 [
[.08623 -0.0125 -9 -9 ]
[.08623 -0.0125 9 0 ]
[.30353 -0.0125 -6 -9 ]
[.30353 -0.0125 6 0 ]
[.52083 -0.0125 -3 -9 ]
[.52083 -0.0125 3 0 ]
[.73813 -0.0125 -3 -9 ]
[.73813 -0.0125 3 0 ]
[.95543 -0.0125 -6 -9 ]
[.95543 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08084 -12 -4.5 ]
[-0.0125 .08084 0 4.5 ]
[-0.0125 .17946 -12 -4.5 ]
[-0.0125 .17946 0 4.5 ]
[-0.0125 .27808 -12 -4.5 ]
[-0.0125 .27808 0 4.5 ]
[-0.0125 .37671 -12 -4.5 ]
[-0.0125 .37671 0 4.5 ]
[-0.0125 .47533 -12 -4.5 ]
[-0.0125 .47533 0 4.5 ]
[-0.0125 .57396 -12 -4.5 ]
[-0.0125 .57396 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08623 0 m
.08623 .00625 L
s
[(-10)] .08623 -0.0125 0 1 Mshowa
.30353 0 m
.30353 .00625 L
s
[(-5)] .30353 -0.0125 0 1 Mshowa
.52083 0 m
.52083 .00625 L
s
[(0)] .52083 -0.0125 0 1 Mshowa
.73813 0 m
.73813 .00625 L
s
[(5)] .73813 -0.0125 0 1 Mshowa
.95543 0 m
.95543 .00625 L
s
[(10)] .95543 -0.0125 0 1 Mshowa
.125 Mabswid
.12969 0 m
.12969 .00375 L
s
.17315 0 m
.17315 .00375 L
s
.21661 0 m
.21661 .00375 L
s
.26007 0 m
.26007 .00375 L
s
.34699 0 m
.34699 .00375 L
s
.39045 0 m
.39045 .00375 L
s
.43391 0 m
.43391 .00375 L
s
.47737 0 m
.47737 .00375 L
s
.56429 0 m
.56429 .00375 L
s
.60775 0 m
.60775 .00375 L
s
.65121 0 m
.65121 .00375 L
s
.69467 0 m
.69467 .00375 L
s
.78159 0 m
.78159 .00375 L
s
.82505 0 m
.82505 .00375 L
s
.86851 0 m
.86851 .00375 L
s
.91197 0 m
.91197 .00375 L
s
.04277 0 m
.04277 .00375 L
s
.99889 0 m
.99889 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08084 m
.00625 .08084 L
s
[(66)] -0.0125 .08084 1 0 Mshowa
0 .17946 m
.00625 .17946 L
s
[(68)] -0.0125 .17946 1 0 Mshowa
0 .27808 m
.00625 .27808 L
s
[(70)] -0.0125 .27808 1 0 Mshowa
0 .37671 m
.00625 .37671 L
s
[(72)] -0.0125 .37671 1 0 Mshowa
0 .47533 m
.00625 .47533 L
s
[(74)] -0.0125 .47533 1 0 Mshowa
0 .57396 m
.00625 .57396 L
s
[(76)] -0.0125 .57396 1 0 Mshowa
.125 Mabswid
0 .10549 m
.00375 .10549 L
s
0 .13015 m
.00375 .13015 L
s
0 .15481 m
.00375 .15481 L
s
0 .20412 m
.00375 .20412 L
s
0 .22877 m
.00375 .22877 L
s
0 .25343 m
.00375 .25343 L
s
0 .30274 m
.00375 .30274 L
s
0 .3274 m
.00375 .3274 L
s
0 .35205 m
.00375 .35205 L
s
0 .40136 m
.00375 .40136 L
s
0 .42602 m
.00375 .42602 L
s
0 .45068 m
.00375 .45068 L
s
0 .49999 m
.00375 .49999 L
s
0 .52464 m
.00375 .52464 L
s
0 .5493 m
.00375 .5493 L
s
0 .05618 m
.00375 .05618 L
s
0 .03153 m
.00375 .03153 L
s
0 .00687 m
.00375 .00687 L
s
0 .59861 m
.00375 .59861 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08623 .61178 m
.08623 .61803 L
s
.30353 .61178 m
.30353 .61803 L
s
.52083 .61178 m
.52083 .61803 L
s
.73813 .61178 m
.73813 .61803 L
s
.95543 .61178 m
.95543 .61803 L
s
.125 Mabswid
.12969 .61428 m
.12969 .61803 L
s
.17315 .61428 m
.17315 .61803 L
s
.21661 .61428 m
.21661 .61803 L
s
.26007 .61428 m
.26007 .61803 L
s
.34699 .61428 m
.34699 .61803 L
s
.39045 .61428 m
.39045 .61803 L
s
.43391 .61428 m
.43391 .61803 L
s
.47737 .61428 m
.47737 .61803 L
s
.56429 .61428 m
.56429 .61803 L
s
.60775 .61428 m
.60775 .61803 L
s
.65121 .61428 m
.65121 .61803 L
s
.69467 .61428 m
.69467 .61803 L
s
.78159 .61428 m
.78159 .61803 L
s
.82505 .61428 m
.82505 .61803 L
s
.86851 .61428 m
.86851 .61803 L
s
.91197 .61428 m
.91197 .61803 L
s
.04277 .61428 m
.04277 .61803 L
s
.99889 .61428 m
.99889 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08084 m
1 .08084 L
s
.99375 .17946 m
1 .17946 L
s
.99375 .27808 m
1 .27808 L
s
.99375 .37671 m
1 .37671 L
s
.99375 .47533 m
1 .47533 L
s
.99375 .57396 m
1 .57396 L
s
.125 Mabswid
.99625 .10549 m
1 .10549 L
s
.99625 .13015 m
1 .13015 L
s
.99625 .15481 m
1 .15481 L
s
.99625 .20412 m
1 .20412 L
s
.99625 .22877 m
1 .22877 L
s
.99625 .25343 m
1 .25343 L
s
.99625 .30274 m
1 .30274 L
s
.99625 .3274 m
1 .3274 L
s
.99625 .35205 m
1 .35205 L
s
.99625 .40136 m
1 .40136 L
s
.99625 .42602 m
1 .42602 L
s
.99625 .45068 m
1 .45068 L
s
.99625 .49999 m
1 .49999 L
s
.99625 .52464 m
1 .52464 L
s
.99625 .5493 m
1 .5493 L
s
.99625 .05618 m
1 .05618 L
s
.99625 .03153 m
1 .03153 L
s
.99625 .00687 m
1 .00687 L
s
.99625 .59861 m
1 .59861 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .08084 m
1 .08084 L
s
.52083 0 m
.52083 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.01 w
.0574 .01472 Mdot
.09076 .03657 Mdot
.12389 .0583 Mdot
.15681 .07989 Mdot
.18951 .10135 Mdot
.22199 .12267 Mdot
.25427 .14385 Mdot
.28635 .16488 Mdot
.31823 .18577 Mdot
.34991 .20651 Mdot
.3814 .22711 Mdot
.4127 .24754 Mdot
.44382 .26782 Mdot
.47476 .28795 Mdot
.50552 .30791 Mdot
.5361 .3277 Mdot
.56652 .34733 Mdot
.59676 .36679 Mdot
.62685 .38608 Mdot
.65677 .4052 Mdot
.68654 .42414 Mdot
.71615 .4429 Mdot
.74561 .46148 Mdot
.77492 .47987 Mdot
.80409 .49809 Mdot
.83311 .51611 Mdot
.86199 .53394 Mdot
.89074 .55158 Mdot
.91935 .56902 Mdot
.94784 .58627 Mdot
.5 Mabswid
.02381 .01472 m
.03837 .01472 L
.04579 .01472 L
.04987 .01472 L
.05372 .01472 L
.05574 .01472 L
.0563 .01472 L
.05689 .01472 L
.05739 .01472 L
.05794 .01507 L
.06178 .01759 L
.06929 .02251 L
.08634 .03368 L
.11753 .05413 L
.14755 .07381 L
.17946 .09476 L
.21021 .11493 L
.23978 .13433 L
.27124 .15497 L
.30154 .17483 L
.33373 .19592 L
.36475 .21622 L
.39459 .23572 L
.42634 .25643 L
.45691 .27634 L
.48631 .29544 L
.5176 .31573 L
.54773 .3352 L
.57975 .35584 L
.6106 .37566 L
.64027 .39466 L
.67184 .41479 L
.70224 .43409 L
.73147 .45256 L
.76259 .47214 L
.79255 .49088 L
.8244 .5107 L
.85507 .52967 L
.88458 .5478 L
.91598 .56696 L
.94621 .58528 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00;P3oool3000000@0oooo0P00000`0?ooo`<00000<@3oool200000380oooo0`00000`0?oo
o`<00000103oool2000001D0oooo000_0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000;P3oool01@000000oooo0?ooo`3oool0000002l0oooo00@000000?ooo`3oool00000<03o
ool01@000000oooo0?ooo`3oool000000300oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000D0?ooo`009`3oool5000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000X0?ooo`D000001@3oool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo0000
03@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000001@0oooo000_0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000<P3oool0
0`000000oooo0?ooo`0]0?ooo`040000003oool0oooo000003@0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001@0oooo000_0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000;P3oool400000300oooo00@000000?ooo`3oool0
0000<03oool400000340oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000D0?oo
o`00;P3oool2000000@0oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`0a0?oo
o`040000003oool0oooo00000300oooo00<000000?ooo`3oool0<@3oool2000000@0oooo00@00000
0?ooo`3oool00000503oool002l0oooo00<000000?ooo`3oool00`3oool2000002l0oooo1@00000`
0?ooo`800000<@3oool500000300oooo00<000000?ooo`3oool00`3oool2000001D0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000K0?ooooP000003@3oool0
01/0oooo0P0000080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo0P00000=0?ooo`006`3oool00`000000
oooo0?ooo`1n0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool02`3oool001/0oooo
00<000000?ooo`3oool00`3oool900000780oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`@00000L03oool00`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00h0oooo0P00001^
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool02`3oool001/0oooo0P00000B0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3o
ool0LP3oool2000000d0oooo000K0?ooo`030000003oool0oooo0180oooo0`00001Y0?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool04`3o
ool2000006T0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool0
0`000000oooo0?ooo`0E0?ooo`800000I`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo00/0oooo000K0?ooo`030000003oool0oooo01L0oooo0P00001U0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool02`3oool001/0oooo
00<000000?ooo`3oool06P3oool200000680oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`0;0?ooo`006`3oool2000001`0oooo0P00001Q0?ooo`030000003oool0oooo0780oooo0P00
000=0?ooo`006`3oool00`000000oooo0?ooo`0K0?ooo`@00000G`3oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00/0oooo000=0?ooo`<0
00000`3oool3000000D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool02`3oool000`0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?oo
o`800000F`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00/0oooo000<0?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool08`3oool2000005T0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;
0?ooo`00303oool400000080oooo100000050?ooooP000003@3oool000`0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02H0oooo0P00001F0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00/0oooo000>0?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool0:@3oool2000005<0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0[0?ooo`800000D@3oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo
02/0oooo0`00001@0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool02`3oool001/0
oooo0P00000_0?ooo`800000CP3oool00`000000oooo0?ooo`1b0?ooo`8000003@3oool001/0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0<@3oool2000004/0oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;
0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000B03oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo03<0oooo0P0000000`3oool0
00000?ooo`160?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool02`3oool001/0oooo
0P00000h0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0LP3oool2000000d0oooo
000K0?ooo`030000003oool0oooo03P0oooo0P0000140?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?oo
o`3oool0>`3oool200000440oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;0?oo
o`006`3oool00`000000oooo0?ooo`0k0?ooo`@00000?`3oool00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00/0oooo000K0?ooo`800000@@3o
ool2000003`0oooo00<000000?ooo`3oool0LP3oool2000000d0oooo000K0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo00/0oooo000K0?ooo`030000003oool0oooo04<0oooo0P00000i0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0@`3oool3000003P0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;0?ooo`003@3oool3000000<0oooo
0`0000050?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo00/0oooo000<0?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A`3oool2000003D0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;0?ooo`00303oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`800000BP3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo0780oooo0P00000=0?ooo`00303oool4000000<0
oooo0`0000050?ooo`030000003oool0oooo04X0oooo0`00000a0?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0B`3oool300000300oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;0?ooo`003P3oool2000000<0oooo
0`0000050?ooo`030000003oool0oooo04l0oooo0P00000]0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00001C
0?ooo`<00000:@3oool00`000000oooo0?ooo`1b0?ooo`8000003@3oool001/0oooo00<000000?oo
o`3oool0D`3oool3000002P0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;0?oo
o`006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1G0?ooo`800000
9@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo00/0oooo000K0?ooo`030000003oool0oooo05X0oooo0P00000R0?ooo`030000003oool0
oooo07<0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00001K0?ooo`<000008@3oool00`00
0000oooo0?ooo`1b0?ooo`8000003@3oool001/0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool02`3oool001/0oooo
00<000000?ooo`3oool0GP3oool2000001h0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1Q
0?ooo`8000006`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00/0oooo000K0?oo
o`030000003oool0oooo0680oooo0`00000I0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool02`3oool001/0oooo0P00001S0?ooo`80000000<0oooo0000003oool05`3oool00`000000
oooo0?ooo`1b0?ooo`8000003@3oool001/0oooo00<000000?ooo`3oool0IP3oool2000001H0oooo
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`0;0?ooo`006`3oool00`000000oooo0?ooo`1Y0?ooo`8000004`3oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo00/0oooo000>0?ooo`030000003oool0oooo00<0oooo0P0000050?oo
o`030000003oool0oooo06X0oooo0`00000A0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool02`3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo06X0oooo0P0000000`3oool000000?ooo`0?0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool02`3oool000l0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0080oooo0P00001_0?ooo`8000003P3oool00`000000oooo0?ooo`1b0?oo
o`8000003@3oool000l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool02`3oool00100oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0740oooo0P00000;0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool02`3oool000`0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0LP3oool2000000X0oooo00<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`0;0?ooo`00303oool5000000<0oooo0P0000050?oo
o`030000003oool0oooo0780oooo0`0000090?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool02`3oool001/0oooo00<000000?ooo`3oool0M@3oool2000000L0oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool2000007P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1b0?ooo`8000003@3oool001/0oooo00<000000?ooo`3oool0N03o
ool3000000<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool0
0`000000oooo0?ooo`1i0?ooo`<000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo00/0oooo000K0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`000000M@3oool00`00
0000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1m0?ooo`800000M@3oool00`000000
oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`800000M03oool00`000000oooo
0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0000000800000L@3o
ool00`000000oooo0?ooo`0;0?ooo`006`3oool2000007l0oooo00<000000?ooo`3oool00P00001`
0?ooo`8000003@3oool001/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo06h0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`030?ooo`800000KP3oool00`000000oooo0?ooo`0;0?ooo`00
6`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
J`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo00H0oooo0`00001Z0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool01`3oool3000006T0oooo00<000000?ooo`3oool02`3oool0
01/0oooo0P00001o0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0I@3oool20000
00d0oooo000K0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool02`3oool2000006H0
oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02`3oool000h0oooo00@0
00000?ooo`3oool0oooo1@0000040?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
3P3oool300000680oooo00<000000?ooo`3oool02`3oool000h0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
3`3oool300000640oooo00<000000?ooo`3oool02`3oool000l0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00/0oooo000?0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool2000007l0oooo00<000000?ooo`3oool04`3oool2
000005d0oooo0P00000=0?ooo`00403oool00`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0E0?ooo`800000G03oool00`00
0000oooo0?ooo`0;0?ooo`00303oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool05P3oool2
000005/0oooo00<000000?ooo`3oool02`3oool000`0oooo1@0000020?ooo`<000001@3oool00`00
0000oooo0?ooo`1n0?ooo`030000003oool0oooo01H0oooo1000001I0?ooo`030000003oool0oooo
00/0oooo000K0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool06P3oool2000005L0
oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00
001o0?ooo`030000003oool0oooo01d0oooo0`00001B0?ooo`8000003@3oool001/0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`0N0?ooo`<00000DP3oool00`000000oooo0?ooo`0;
0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo0280oooo0P00001?0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool09@3o
ool2000004`0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00001o0?ooo`030000003oool0
oooo02D0oooo0`00001:0?ooo`8000003@3oool001/0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool02`3oool001/0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0Y0?ooo`800000B03oool00`000000
oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo02`0oooo0P0000150?ooo`030000003oool0oooo00/0oooo000K
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;03oool4000004<0oooo00<00000
0?ooo`3oool02`3oool001/0oooo0P00001o0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0?`3oool2000000d0oooo000K0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool0<@3oool200000400oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`0c0?ooo`<00000?@3oool00`000000oooo0?ooo`0;0?ooo`006`3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo03@0oooo0P00000m0?ooo`030000003o
ool0oooo00/0oooo000>0?ooo`030000003oool0oooo00<0oooo0`0000040?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0=P3oool2000003/0oooo00<000000?ooo`3oool02`3oool0
00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0>03oool2000003T0oooo00<000000?ooo`3oool02`3oool000l0
oooo00<000000?ooo`3oool01@0000040?ooo`800000O`3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo03D0oooo0P00000=0?ooo`003`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0k0?ooo`80
0000=P3oool00`000000oooo0?ooo`0;0?ooo`00403oool01P000000oooo0?ooo`000000oooo0000
00D0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0k0?ooo`@00000=03oool00`00
0000oooo0?ooo`0;0?ooo`00303oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000050?oo
o`030000003oool0oooo07h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo00/0oooo000<0?ooo`D00000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0@03oool200000340oooo00<000000?ooo`3o
ool02`3oool001/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`120?ooo`800000
;`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool2000007l0oooo00<000000?ooo`3oool0@P3o
ool3000002d0oooo0P00000=0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo04D0oooo0P00000/0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
00/0oooo000K0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0B03oool2000002T0
oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`190?ooo`800000:03oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo04T0oooo1000000V0?ooo`030000003oool0oooo00/0oooo000K
0?ooo`800000O`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0280oooo0P00000=
0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo04l0oooo0`00000Q0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool0D03oool300000200oooo00<000000?ooo`3oool0
2`3oool001/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1C0?ooo`8000007P3o
ool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo05D0oooo0P00000L0?ooo`030000003oool0oooo00/0oooo000K0?ooo`800000O`3oool00`00
0000oooo0?ooo`1G0?ooo`8000006@3oool2000000d0oooo000K0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool0E`3oool3000001T0oooo00<000000?ooo`3oool02`3oool001/0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1G0?ooo`80000000<0oooo000000000000
5`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`003P3oool0
0`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`003P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo05h0oooo0P00000C0?ooo`030000003oool0oooo00/0oooo000?0?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo05h0oooo1000000A0?ooo`030000003oool0oooo00/0oooo000?0?oo
o`030000003oool0oooo00@000001@3oool2000007l0oooo00<000000?ooo`3oool0HP3oool20000
00h0oooo0P00000=0?ooo`00403oool00`000000oooo000000080?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool0I03oool2000000d0oooo00<000000?ooo`3oool02`3oool000`0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`1U0?ooo`<000002`3oool00`000000oooo0?ooo`0;0?ooo`00
303oool5000000<0oooo0P0000050?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
I@3oool2000000030?ooo`000000oooo00T0oooo00<000000?ooo`3oool02`3oool001/0oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`1Y0?ooo`800000203oool00`000000oooo0?oo
o`0;0?ooo`006`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool2000007l0oooo00<000000?oo
o`3oool0K03oool00`000000oooo0?ooo`030?ooo`8000003@3oool001/0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02`3oool001/0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0;0?ooo`006`3ooooh000000d0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo00390?ooo`<00000E03oool00<X0oooo00<000000?ooo`3oool0D`3oool0
05h0oooo00<000000?ooo`0000000`3oool4000000<0oooo00<000000?ooo`3oool00P3oool30000
0080oooo0`0000030?ooo`<00000103oool300000080oooo0`0000000`3oool00000000000020?oo
o`800000203oool5000000050?ooo`00000000000000003oool00P0000020?ooo`8000000`3oool3
00000080oooo0`0000000`3oool000000000000400000080oooo1@0000030?ooo`800000103oool0
0`000000oooo0?ooo`1B0?ooo`00GP3oool00`000000oooo000000020?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00@000000?ooo`3oool0
00001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`1B0?ooo`00GP3oool00`000000oooo000000030?ooo`<000000`3oool00`00
0000oooo000000020?ooo`D000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool500000080oooo00@000000?ooo`3oool000000P3oool3000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000005<0
oooo001M0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000<0oooo
0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003o
ool0oooo0000003oool000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`000000D`3oool005d0oooo00D000000?ooo`000000oooo000000020?ooo`80
00000`3oool2000000030?ooo`00000000000080oooo0`0000030?ooo`030000003oool0oooo0080
oooo0P0000000`3oool00000000000020?ooo`<000000P3oool400000080oooo1000000:0?ooo`04
0000003oool0oooo0?ooo`@000000P3oool4000000<0oooo0`0000020?ooo`@000000`3oool40000
00040?ooo`0000000000000000<0oooo100000020?ooo`80000000<0oooo000000000000DP3oool0
05d0oooo00D000000?ooo`000000oooo0000000D0?ooo`040000003oool0oooo000001@0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0F@3oool005d0oooo1P00000B0?ooo`D00000503oool00`000000oooo0?ooo`08
0?ooo`D00000203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0F@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14.5349, 63.3686, \
0.0930942, 0.0820458}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.520831 0.0434597 0.309017 3.18303e-05 [
[.08623 -0.0125 -9 -9 ]
[.08623 -0.0125 9 0 ]
[.30353 -0.0125 -6 -9 ]
[.30353 -0.0125 6 0 ]
[.52083 -0.0125 -3 -9 ]
[.52083 -0.0125 3 0 ]
[.73813 -0.0125 -3 -9 ]
[.73813 -0.0125 3 0 ]
[.95543 -0.0125 -6 -9 ]
[.95543 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07029 -30 -4.5 ]
[-0.0125 .07029 0 4.5 ]
[-0.0125 .14987 -30 -4.5 ]
[-0.0125 .14987 0 4.5 ]
[-0.0125 .22944 -30 -4.5 ]
[-0.0125 .22944 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38859 -24 -4.5 ]
[-0.0125 .38859 0 4.5 ]
[-0.0125 .46817 -24 -4.5 ]
[-0.0125 .46817 0 4.5 ]
[-0.0125 .54774 -24 -4.5 ]
[-0.0125 .54774 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08623 0 m
.08623 .00625 L
s
[(-10)] .08623 -0.0125 0 1 Mshowa
.30353 0 m
.30353 .00625 L
s
[(-5)] .30353 -0.0125 0 1 Mshowa
.52083 0 m
.52083 .00625 L
s
[(0)] .52083 -0.0125 0 1 Mshowa
.73813 0 m
.73813 .00625 L
s
[(5)] .73813 -0.0125 0 1 Mshowa
.95543 0 m
.95543 .00625 L
s
[(10)] .95543 -0.0125 0 1 Mshowa
.125 Mabswid
.12969 0 m
.12969 .00375 L
s
.17315 0 m
.17315 .00375 L
s
.21661 0 m
.21661 .00375 L
s
.26007 0 m
.26007 .00375 L
s
.34699 0 m
.34699 .00375 L
s
.39045 0 m
.39045 .00375 L
s
.43391 0 m
.43391 .00375 L
s
.47737 0 m
.47737 .00375 L
s
.56429 0 m
.56429 .00375 L
s
.60775 0 m
.60775 .00375 L
s
.65121 0 m
.65121 .00375 L
s
.69467 0 m
.69467 .00375 L
s
.78159 0 m
.78159 .00375 L
s
.82505 0 m
.82505 .00375 L
s
.86851 0 m
.86851 .00375 L
s
.91197 0 m
.91197 .00375 L
s
.04277 0 m
.04277 .00375 L
s
.99889 0 m
.99889 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07029 m
.00625 .07029 L
s
[(-7500)] -0.0125 .07029 1 0 Mshowa
0 .14987 m
.00625 .14987 L
s
[(-5000)] -0.0125 .14987 1 0 Mshowa
0 .22944 m
.00625 .22944 L
s
[(-2500)] -0.0125 .22944 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .38859 m
.00625 .38859 L
s
[(2500)] -0.0125 .38859 1 0 Mshowa
0 .46817 m
.00625 .46817 L
s
[(5000)] -0.0125 .46817 1 0 Mshowa
0 .54774 m
.00625 .54774 L
s
[(7500)] -0.0125 .54774 1 0 Mshowa
.125 Mabswid
0 .08621 m
.00375 .08621 L
s
0 .10212 m
.00375 .10212 L
s
0 .11804 m
.00375 .11804 L
s
0 .13395 m
.00375 .13395 L
s
0 .16578 m
.00375 .16578 L
s
0 .1817 m
.00375 .1817 L
s
0 .19761 m
.00375 .19761 L
s
0 .21353 m
.00375 .21353 L
s
0 .24536 m
.00375 .24536 L
s
0 .26127 m
.00375 .26127 L
s
0 .27719 m
.00375 .27719 L
s
0 .2931 m
.00375 .2931 L
s
0 .32493 m
.00375 .32493 L
s
0 .34085 m
.00375 .34085 L
s
0 .35676 m
.00375 .35676 L
s
0 .37268 m
.00375 .37268 L
s
0 .40451 m
.00375 .40451 L
s
0 .42042 m
.00375 .42042 L
s
0 .43634 m
.00375 .43634 L
s
0 .45225 m
.00375 .45225 L
s
0 .48408 m
.00375 .48408 L
s
0 .5 m
.00375 .5 L
s
0 .51591 m
.00375 .51591 L
s
0 .53183 m
.00375 .53183 L
s
0 .05437 m
.00375 .05437 L
s
0 .03846 m
.00375 .03846 L
s
0 .02254 m
.00375 .02254 L
s
0 .00663 m
.00375 .00663 L
s
0 .56366 m
.00375 .56366 L
s
0 .57957 m
.00375 .57957 L
s
0 .59549 m
.00375 .59549 L
s
0 .6114 m
.00375 .6114 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.08623 .61178 m
.08623 .61803 L
s
.30353 .61178 m
.30353 .61803 L
s
.52083 .61178 m
.52083 .61803 L
s
.73813 .61178 m
.73813 .61803 L
s
.95543 .61178 m
.95543 .61803 L
s
.125 Mabswid
.12969 .61428 m
.12969 .61803 L
s
.17315 .61428 m
.17315 .61803 L
s
.21661 .61428 m
.21661 .61803 L
s
.26007 .61428 m
.26007 .61803 L
s
.34699 .61428 m
.34699 .61803 L
s
.39045 .61428 m
.39045 .61803 L
s
.43391 .61428 m
.43391 .61803 L
s
.47737 .61428 m
.47737 .61803 L
s
.56429 .61428 m
.56429 .61803 L
s
.60775 .61428 m
.60775 .61803 L
s
.65121 .61428 m
.65121 .61803 L
s
.69467 .61428 m
.69467 .61803 L
s
.78159 .61428 m
.78159 .61803 L
s
.82505 .61428 m
.82505 .61803 L
s
.86851 .61428 m
.86851 .61803 L
s
.91197 .61428 m
.91197 .61803 L
s
.04277 .61428 m
.04277 .61803 L
s
.99889 .61428 m
.99889 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07029 m
1 .07029 L
s
.99375 .14987 m
1 .14987 L
s
.99375 .22944 m
1 .22944 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38859 m
1 .38859 L
s
.99375 .46817 m
1 .46817 L
s
.99375 .54774 m
1 .54774 L
s
.125 Mabswid
.99625 .08621 m
1 .08621 L
s
.99625 .10212 m
1 .10212 L
s
.99625 .11804 m
1 .11804 L
s
.99625 .13395 m
1 .13395 L
s
.99625 .16578 m
1 .16578 L
s
.99625 .1817 m
1 .1817 L
s
.99625 .19761 m
1 .19761 L
s
.99625 .21353 m
1 .21353 L
s
.99625 .24536 m
1 .24536 L
s
.99625 .26127 m
1 .26127 L
s
.99625 .27719 m
1 .27719 L
s
.99625 .2931 m
1 .2931 L
s
.99625 .32493 m
1 .32493 L
s
.99625 .34085 m
1 .34085 L
s
.99625 .35676 m
1 .35676 L
s
.99625 .37268 m
1 .37268 L
s
.99625 .40451 m
1 .40451 L
s
.99625 .42042 m
1 .42042 L
s
.99625 .43634 m
1 .43634 L
s
.99625 .45225 m
1 .45225 L
s
.99625 .48408 m
1 .48408 L
s
.99625 .5 m
1 .5 L
s
.99625 .51591 m
1 .51591 L
s
.99625 .53183 m
1 .53183 L
s
.99625 .05437 m
1 .05437 L
s
.99625 .03846 m
1 .03846 L
s
.99625 .02254 m
1 .02254 L
s
.99625 .00663 m
1 .00663 L
s
.99625 .56366 m
1 .56366 L
s
.99625 .57957 m
1 .57957 L
s
.99625 .59549 m
1 .59549 L
s
.99625 .6114 m
1 .6114 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.52083 0 m
.52083 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.0574 .57922 Mdot
.09076 .55552 Mdot
.12389 .53219 Mdot
.15681 .50923 Mdot
.18951 .48664 Mdot
.22199 .46442 Mdot
.25427 .44256 Mdot
.28635 .42105 Mdot
.31823 .39989 Mdot
.34991 .37908 Mdot
.3814 .35861 Mdot
.4127 .33848 Mdot
.44382 .31867 Mdot
.47476 .2992 Mdot
.50552 .28005 Mdot
.5361 .26122 Mdot
.56652 .2427 Mdot
.59676 .2245 Mdot
.62685 .2066 Mdot
.65677 .18901 Mdot
.68654 .17173 Mdot
.71615 .15474 Mdot
.74561 .13804 Mdot
.77492 .12164 Mdot
.80409 .10553 Mdot
.83311 .0897 Mdot
.86199 .07415 Mdot
.89074 .05888 Mdot
.91935 .04388 Mdot
.94784 .02916 Mdot
.5 Mabswid
.02381 .60332 m
.05372 .58186 L
.08634 .55865 L
.11698 .53705 L
.14644 .51646 L
.1778 .49473 L
.20799 .474 L
.24008 .45218 L
.27099 .43135 L
.30073 .41151 L
.33237 .39061 L
.36283 .37068 L
.39213 .35171 L
.42332 .33172 L
.45333 .31268 L
.48525 .29266 L
.51599 .2736 L
.54556 .25546 L
.57703 .23638 L
.60732 .21822 L
.63951 .19916 L
.67053 .18102 L
.70038 .16379 L
.73212 .14569 L
.76269 .12848 L
.79209 .11215 L
.82339 .095 L
.85351 .07871 L
.88553 .06164 L
.91638 .04544 L
.94605 .03009 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00=`3oool3000000@0oooo0P00000`0?ooo`<00000<@3oool200000380oooo0`00000`0?oo
o`<00000103oool2000000`0oooo000h0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000;P3oool01@000000oooo0?ooo`3oool0000002l0oooo00@000000?ooo`3oool00000<03o
ool01@000000oooo0?ooo`3oool000000300oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000;0?ooo`00<03oool5000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000X0?ooo`D000001@3oool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo0000
03@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000/0oooo000h0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000<P3oool0
0`000000oooo0?ooo`0]0?ooo`040000003oool0oooo000003@0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000/0oooo000h0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000;P3oool400000300oooo00@000000?ooo`3oool0
0000<03oool400000340oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000;0?oo
o`00=`3oool2000000@0oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`0a0?oo
o`040000003oool0oooo00000300oooo00<000000?ooo`3oool0<@3oool2000000@0oooo00@00000
0?ooo`3oool000002`3oool003P0oooo00<000000?ooo`3oool00`3oool2000002l0oooo1@00000`
0?ooo`800000<@3oool500000300oooo00<000000?ooo`3oool00`3oool2000000`0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000T0?ooooP00000103oool0
02@0oooo0P0000080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`00903oool00`000000
oooo0?ooo`1n0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool002@0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1/0?ooo`8000001@3oool00`000000oooo
0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo06X0oooo0P00
00070?ooo`030000003oool0oooo0080oooo000T0?ooo`800000O`3oool00`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo06L0oooo0P00000:0?ooo`030000003oool0oooo0080oooo000T0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0I@3oool2000000`0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1S0?ooo`@00000
303oool00`000000oooo0?ooo`020?ooo`00903oool2000007l0oooo00<000000?ooo`3oool0H@3o
ool2000000l0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo05h0oooo0`00000B0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0G@3oool3000001<0oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1K0?ooo`8000005P3oool00`000000
oooo0?ooo`020?ooo`00903oool2000007l0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`0E0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?oo
o`1G0?ooo`<000006@3oool00`000000oooo0?ooo`020?ooo`002`3oool00`000000oooo0?ooo`02
0?ooo`<00000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0EP3oool3000001X0oooo00<000000?ooo`3oool00P3oool000/0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
E03oool2000001d0oooo00<000000?ooo`3oool00P3oool000<0oooo1@0000040?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo0P00001o0?ooo`030000003oool0oooo0580oooo0P00000N0?ooo`80
0000103oool000`0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo0500oooo0P00000Q0?ooo`030000003oool0oooo0080oooo000=0?ooo`03
0000003oool0000000<000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1>0?ooo`@000008@3oool0
0`000000oooo0?ooo`020?ooo`002@3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`1<0?ooo`8000009@3oool00`000000oooo0?ooo`020?ooo`00
2@3oool5000000030?ooo`000000000000<000000`3oool2000000@0oooo0P0000050?ooo`800000
O`3oool00`000000oooo0?ooo`1:0?ooo`8000009P3oool2000000@0oooo000T0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0B03oool3000002P0oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`160?ooo`80000000<0oooo
000000000000:03oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo04@0oooo0P00000]0?ooo`030000003oool0oooo0080oooo000T0?ooo`80
0000O`3oool00`000000oooo0?ooo`120?ooo`800000;P3oool2000000@0oooo000T0?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool0@@3oool3000002l0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0o0?ooo`800000<P3o
ool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo03d0oooo0P00000d0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000O`3oool00`00
0000oooo0?ooo`0k0?ooo`800000=@3oool2000000@0oooo000T0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool0>@3oool4000003H0oooo00<000000?ooo`3oool00P3oool002@0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0g0?ooo`800000>P3oool00`000000oooo
0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`00903oool2000007l0oooo00<00000
0?ooo`3oool0=03oool2000003`0oooo0P0000040?ooo`002P3oool3000000@0oooo0P0000040?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0c0?oo
o`<00000?@3oool00`000000oooo0?ooo`020?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool00P3oool000<0oooo1@0000050?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0`0?oo
o`800000@@3oool00`000000oooo0?ooo`020?ooo`003@3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`800000O`3oool00`000000oooo0?ooo`0^0?ooo`800000@P3oool2000000@0oooo0009
0?ooo`@000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02`0
oooo0P0000150?ooo`030000003oool0oooo0080oooo00090?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0Z0?ooo`@00000A@3oool0
0`000000oooo0?ooo`020?ooo`002@3oool5000000<0oooo0P0000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0X0?ooo`800000B@3oool00`00
0000oooo0?ooo`020?ooo`00903oool2000007l0oooo00<000000?ooo`3oool09P3oool2000004X0
oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02D0oooo
0P00001<0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool08`3oool4000004`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`0Q0?ooo`800000D03oool00`000000oooo0?ooo`02
0?ooo`00903oool2000007l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1?0?oo
o`800000103oool002@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0N0?ooo`80
0000D`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo01`0oooo1000001C0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000O`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05@0oooo0P0000040?ooo`00903oool0
0`000000oooo0?ooo`1n0?ooo`030000003oool0oooo01T0oooo0P00001H0?ooo`030000003oool0
oooo0080oooo000T0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool05P3oool30000
05X0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`0F0?ooo`800000F`3oool00`000000oooo0?ooo`020?ooo`00903oool2000007l0oooo
00<000000?ooo`3oool0503oool2000005`0oooo0P0000040?ooo`00903oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`020?ooo`002@3oool500000080oooo0`0000040?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`0A0?ooo`800000H03oool00`000000oooo0?ooo`02
0?ooo`002P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`0?0?ooo`800000HP3oool00`000000oooo0?ooo`020?ooo`00
0`3oool5000000<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool2000007l0oooo00<000000?oo
o`3oool03P3oool300000640oooo0P0000040?ooo`00303oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0303oool2000006D0oooo00<00000
0?ooo`3oool00P3oool000T0oooo00H000000?ooo`3oool0oooo0000003oool4000000<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool02P3oool2000006L0oooo00<000000?ooo`3oool00P3oool000T0oooo
00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool01`3o
ool3000006T0oooo00<000000?ooo`3oool00P3oool000X0oooo0`0000020?ooo`D000000`3oool2
000000@0oooo0P0000050?ooo`800000O`3oool00`000000oooo0?ooo`070?ooo`800000J@3oool2
000000@0oooo000T0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool01@3oool20000
06`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool00P3oool002@0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`800000K`3oool00`000000oooo
0?ooo`020?ooo`00903oool2000007l0oooo00<000000?ooo`3oool00P00001`0?ooo`800000103o
ool002@0oooo00<000000?ooo`3oool0OP3oool500000740oooo00<000000?ooo`3oool00P3oool0
02@0oooo00<000000?ooo`3oool0O@3oool2000007D0oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool0N`3oool2000000030?ooo`000000oooo07@0oooo00<000000?ooo`3o
ool00P3oool002@0oooo0P00001k0?ooo`050000003oool0oooo0?ooo`000000M03oool2000000@0
oooo000T0?ooo`030000003oool0oooo07P0oooo0`0000030?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0M`3oool010000000oooo0000
000000030?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool00P3oool002@0oooo0P00001e0?ooo`800000203oool00`000000oooo0?ooo`1b
0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0LP3oool2000000X0oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`020?ooo`007@3oool2000000D0oooo00<000000?ooo`3o
ool0L@3oool3000000X0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`00
703oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06l0oooo0P00000=0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool001`0oooo00@000000?ooo`3oool0
0000103ooooh000000@0oooo000L0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0K03oool200000100oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`00
703oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06X0oooo0P00000B0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool001`0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1Y0?ooo`<000004P3oool00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo0080oooo000M0?ooo`8000001@3oool2000006T0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`1b0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0I@3oool2000001L0oooo00<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1R0?ooo`<000006@3oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000H`3oool2000001X0
oooo00<000000?ooo`3oool0LP3oool2000000@0oooo000T0?ooo`030000003oool0oooo0600oooo
0P00000L0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool0G`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0G@3oool2000001l0oooo00<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`00903oool2000005/0oooo0`00000Q0?oo
o`030000003oool0oooo0780oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1J0?ooo`80
00008P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000
003oool0oooo05P0oooo0P00000T0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0EP3oool2000002H0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`020?ooo`00903oool2000005H0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`1b0?ooo`800000103oool000T0oooo1@0000020?ooo`<00000103oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo05<0oooo0P00000Y0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool00P3oool000X0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0540oooo1000000Y0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool00P3oool000/0oooo00<000000?ooo`3oool01@3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`020?ooo`00303oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000C`3oool20000
02h0oooo00<000000?ooo`3oool0LP3oool2000000@0oooo00090?ooo`060000003oool0oooo0?oo
o`000000oooo100000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`020?ooo`002@3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0B`3oool200000340oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`02
0?ooo`002P3oool300000080oooo1@0000030?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oool0B@3oool400000340oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?oo
o`00903oool2000004T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1b0?ooo`80
0000103oool002@0oooo00<000000?ooo`3oool0AP3oool2000003H0oooo00<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`00903oool0
0`000000oooo0?ooo`130?ooo`800000>@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo0080oooo000T0?ooo`800000@`3oool3000003T0oooo00<000000?ooo`3oool0LP3oool20000
00@0oooo000T0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo03l0oooo
0P00000m0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00
000o0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0LP3oool2000000@0oooo000T
0?ooo`030000003oool0oooo03`0oooo0P0000100?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0>P3oool300000440oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0i0?ooo`04
0000003oool0000000000440oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?oo
o`00903oool2000003P0oooo0P0000150?ooo`030000003oool0oooo0780oooo0P0000040?ooo`00
903oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`020?ooo`002P3oool3000000@0oooo0P0000040?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool00P3oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo03<0oooo0P0000190?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool00P3oool000d0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3o
ool2000003<0oooo0`0000190?ooo`030000003oool0oooo0780oooo0P0000040?ooo`003@3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo00090?ooo`@00000
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0_0?ooo`800000C@3oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo0080oooo00090?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool00P3oool000T0oooo1@0000030?ooo`800000103oool2000000@0oooo0P00
00050?ooo`800000;@3oool200000500oooo00<000000?ooo`3oool0LP3oool2000000@0oooo000T
0?ooo`030000003oool0oooo02/0oooo0P00001A0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0:P3oool300000540oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0X0?ooo`80
0000E03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000
:03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0780oooo0P0000040?ooo`00903o
ool00`000000oooo0?ooo`0U0?ooo`800000E`3oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo0080oooo000T0?ooo`030000003oool0oooo02<0oooo0P00001I0?ooo`030000003oool0
oooo07<0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool08P3oool30000
05T0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`00903oool200000240
oooo0P00001L0?ooo`030000003oool0oooo0780oooo0P0000040?ooo`00903oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0M0?ooo`800000G`3oool00`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000T0?oo
o`800000703oool200000640oooo00<000000?ooo`3oool0LP3oool2000000@0oooo000T0?ooo`03
0000003oool0oooo01T0oooo1000001Q0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool00P3oool000/0oooo00<000000?ooo`3oool00P3oool3000000@0oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`020?ooo`002`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool00P3oool000`0oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool2
000001H0oooo0P00001W0?ooo`030000003oool0oooo0780oooo0P0000040?ooo`00303oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000=0?ooo`030000003oool0
000000<000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool04`3oool2000006T0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`020?ooo`002@3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool4
000006T0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`020?ooo`002@3oool50000
00030?ooo`000000000000<000000`3oool2000000@0oooo0P0000050?ooo`8000004@3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo0780oooo0P0000040?ooo`00903oool00`000000
oooo0?ooo`0>0?ooo`800000KP3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo00`0oooo0P00001`0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00000:
0?ooo`<00000LP3oool00`000000oooo0?ooo`1b0?ooo`800000103oool002@0oooo00<000000?oo
o`3oool0203oool010000000oooo00000000001b0?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool00P3oool002@0oooo0P0000060?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
LP3oool2000000@0oooo000T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo0080oooo000T0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`020?ooo`00903oool2000000P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool2000000@0
oooo000T0?ooooP00000103oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool003H0
oooo0`00002:0?ooo`030000003oool0oooo02/0oooo0`00000E0?ooo`030000003oool0oooo01@0
oooo000g0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo000a0?ooo`<000000`3oool3000000@0oooo0P00
00020?ooo`D000000P3oool3000000<0oooo100000000`3oool0000000000003000000L0oooo0`00
00040?ooo`@000000`3oool200000080oooo1P0000060?ooo`@000000P3oool5000000030?ooo`00
0000000000<0000000<0oooo0000000000000`0000020?ooo`<000000P3oool3000000@0oooo0`00
00020?ooo`<0000000@0oooo000000000000oooo0`0000030?ooo`<000002@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000<0oooo100000030?ooo`030000003oool0oooo0080oooo
0`0000020?ooo`D000000P3oool300000080oooo0`000000103oool000000000003oool4000000<0
oooo0P0000020?ooo`X000001@3oool00`000000oooo0?ooo`0B0?ooo`00<03oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000`0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`040000003oool0oooo0000
00@0oooo00D000000?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000001P3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0B0?ooo`00<03oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
1P3oool3000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`<00000
0`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool0oooo1@0000020?ooo`030000003oool0oooo0080oooo1@0000020?ooo`060000003oool0
oooo0000003oool000001@3oool5000000P0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0000003oool000000080oooo0`0000030?ooo`030000003oool000000080oooo1@0000030?ooo`04
0000003oool0oooo0?ooo`D000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@0
00000?ooo`3oool000001@3oool010000000oooo0?ooo`0000020?ooo`<000001@3oool00`000000
oooo0?ooo`0B0?ooo`00<03oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool3
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
008000000`3oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000030?oo
o`040000003oool0oooo000000D0oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`030000
003oool0oooo0180oooo000`0?ooo`060000003oool0oooo0?ooo`000000oooo100000020?ooo`@0
00000P3oool3000000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`04
0000003oool0oooo00000080oooo0P0000030?ooo`@000000`3oool3000000T0oooo00D000000?oo
o`3oool000000?ooo`03000000@0oooo100000020?ooo`@000000P3oool300000080oooo0P000000
0`3oool00000000000020?ooo`<000000P3oool4000000<0oooo0`0000030?ooo`<000002@3oool0
0`000000oooo0?ooo`020?ooo`H0000000<0oooo0000000000000`3oool2000000030?ooo`000000
00000080oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000020?ooo`@000000`3oool9
000000<0oooo0`0000030?ooo`@00000103oool00`000000oooo0?ooo`0B0?ooo`00<03oool01@00
0000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`08
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04`3oool00340oooo0`00
00090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool3000000T0oooo1000
00090?ooo`030000003oool0oooo0080oooo0P00000:0?ooo`@00000103oool00`000000oooo0?oo
o`040?ooo`800000103oool2000002h0oooo00<000000?ooo`3oool0603oool3000001H0oooo00<0
00000?ooo`3oool00P3oool2000000/0oooo00<000000?ooo`3oool0503oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-15.3727, -11245, 0.0930942, \
127.107}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-10.477741155507537`\), 
                      11.43635881489974`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-10.477741155507537`\), 
                      11.43635881489974`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {107.52678245056468`, 
                117.36450138109524`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(RayBoundary \[Rule] {\(-10.477741155507537`\), 
                11.43635881489974`}\), ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-10.477741155507537`\), 
                      11.43635881489974`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\)}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.43635881489974`\), 
                      10.477741155507537`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.43635881489974`\), 
                      10.477741155507537`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {107.52678245056468`, 
                117.36450138109524`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(RayBoundary \[Rule] {\(-11.43635881489974`\), 
                10.477741155507537`}\), ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.43635881489974`\), 
                      10.477741155507537`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\)}], 
          "}"}]}], "}"}]], "Output",
  CellLabel->"Out[27]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["wavefront = FindWaveFronts[sys,PlotDomain->{-.1,.1}]", "Input",
  CellLabel->"In[28]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.76191 -735.446 6.58076 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0205 -36 -4.5 ]
[-0.0125 .0205 0 4.5 ]
[-0.0125 .15212 -36 -4.5 ]
[-0.0125 .15212 0 4.5 ]
[-0.0125 .28373 -30 -4.5 ]
[-0.0125 .28373 0 4.5 ]
[-0.0125 .41535 -36 -4.5 ]
[-0.0125 .41535 0 4.5 ]
[-0.0125 .54697 -36 -4.5 ]
[-0.0125 .54697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0205 m
.00625 .0205 L
s
[(111.76)] -0.0125 .0205 1 0 Mshowa
0 .15212 m
.00625 .15212 L
s
[(111.78)] -0.0125 .15212 1 0 Mshowa
0 .28373 m
.00625 .28373 L
s
[(111.8)] -0.0125 .28373 1 0 Mshowa
0 .41535 m
.00625 .41535 L
s
[(111.82)] -0.0125 .41535 1 0 Mshowa
0 .54697 m
.00625 .54697 L
s
[(111.84)] -0.0125 .54697 1 0 Mshowa
.125 Mabswid
0 .05341 m
.00375 .05341 L
s
0 .08631 m
.00375 .08631 L
s
0 .11922 m
.00375 .11922 L
s
0 .18502 m
.00375 .18502 L
s
0 .21793 m
.00375 .21793 L
s
0 .25083 m
.00375 .25083 L
s
0 .31664 m
.00375 .31664 L
s
0 .34954 m
.00375 .34954 L
s
0 .38245 m
.00375 .38245 L
s
0 .44825 m
.00375 .44825 L
s
0 .48116 m
.00375 .48116 L
s
0 .51406 m
.00375 .51406 L
s
0 .57987 m
.00375 .57987 L
s
0 .61277 m
.00375 .61277 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0205 m
1 .0205 L
s
.99375 .15212 m
1 .15212 L
s
.99375 .28373 m
1 .28373 L
s
.99375 .41535 m
1 .41535 L
s
.99375 .54697 m
1 .54697 L
s
.125 Mabswid
.99625 .05341 m
1 .05341 L
s
.99625 .08631 m
1 .08631 L
s
.99625 .11922 m
1 .11922 L
s
.99625 .18502 m
1 .18502 L
s
.99625 .21793 m
1 .21793 L
s
.99625 .25083 m
1 .25083 L
s
.99625 .31664 m
1 .31664 L
s
.99625 .34954 m
1 .34954 L
s
.99625 .38245 m
1 .38245 L
s
.99625 .44825 m
1 .44825 L
s
.99625 .48116 m
1 .48116 L
s
.99625 .51406 m
1 .51406 L
s
.99625 .57987 m
1 .57987 L
s
.99625 .61277 m
1 .61277 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.05372 .0332 L
.08634 .05336 L
.11698 .0723 L
.14644 .09051 L
.1778 .10989 L
.20799 .12855 L
.24008 .14838 L
.27099 .16748 L
.30073 .18586 L
.33237 .20542 L
.36283 .22424 L
.39213 .24235 L
.42332 .26162 L
.45333 .28018 L
.48525 .2999 L
.51599 .3189 L
.54556 .33717 L
.57703 .35662 L
.60732 .37535 L
.63951 .39524 L
.67053 .41441 L
.70038 .43286 L
.73212 .45248 L
.76269 .47137 L
.79209 .48954 L
.82339 .50888 L
.85351 .5275 L
.88553 .54729 L
.91638 .56635 L
.94605 .58469 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002X0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000;03oool2000002l0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000:P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000<0oooo000W0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool09P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo000P0?ooo`D000000P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0240oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0X0?oo
o`040000003oool0oooo000002d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`020?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo0080oooo000W0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000
000[0?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool00000203oool01@000000
oooo0?ooo`000000oooo00@00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo0080oooo000W0?ooo`040000003oool0oooo000000P0oooo0P00000Z0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00000^0?ooo`040000003oool0oooo0000
02d0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000002`0oooo
00@000000?ooo`3oool00000203oool2000000@0oooo000X0?ooo`8000002P3oool00`000000oooo
0?ooo`0Y0?ooo`8000002P3oool200000080oooo1@00000[0?ooo`800000;`3oool2000000X0oooo
0P0000020?ooo`D00000:@3oool2000000X0oooo00<000000?ooo`3oool00P3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool002L0oooom@0000040?ooo`009`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo0000103oool000000000000000030?ooo`<000000`3oool3000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2
000007<0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003oool0
oooo0700oooo00<000000?ooo`3oool0MP3oool2000000@0oooo00020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00@000001@3oool00`000000oooo0?ooo`050?ooo`800000L03oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo0080oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool01`3oool2000006h0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`00
00<0oooo000000000000103oool2000000@0oooo0P0000090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`D00000
0`3oool2000000D0oooo00<000000?ooo`3oool02P3oool2000006/0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0<0?ooo`800000J@3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0
oooo00h0oooo0P00001W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool0
02L0oooo00<000000?ooo`3oool0403oool2000006D0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0B0?ooo`800000H`3oool00`000000
oooo0?ooo`1f0?ooo`800000103oool002L0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<0
00000?ooo`3oool05@3oool200000600oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`020?ooo`009`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo05`0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?oo
o`009`3oool00`000000oooo0?ooo`0I0?ooo`800000G03oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003o
ool0oooo01`0oooo0P00001I0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3o
ool002L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo07H0oooo0P0000040?ooo`009`3oool00`000000
oooo0?ooo`0P0?ooo`800000E@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080
oooo000W0?ooo`030000003oool0oooo0280oooo0P00001C0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0903oool200000540oooo00<0
00000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0V
0?ooo`800000C`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?oo
o`030000003oool0oooo02P0oooo0P00001=0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool00P3oool002L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0
:`3oool2000004X0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0MP3o
ool2000000@0oooo000W0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
02l0oooo0P0000160?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0<P3oool2000004<0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`0000@0oooo0000000000000000
0`3oool3000000<0oooo0`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool3000000D0oooo00<000000?ooo`3oool0=03oool200000440oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=`3oool2000003h0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`3oool3000000D0oooo0P00000j0?ooo`800000?03oool00`000000oooo0?ooo`1f0?ooo`800000
103oool00080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03/0oooo0P00000j0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3o
ool000030?ooo`000000000000@0oooo0P0000040?ooo`8000002@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo
0P00000h0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool00080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo1@00
00020?ooo`<000001@3oool00`000000oooo0?ooo`0o0?ooo`800000=P3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?oo
o`030000003oool0oooo0480oooo0P00000c0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool00P3oool002L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool0AP3oool2000002l0oooo00<000000?ooo`3oool0MP3o
ool2000000@0oooo000W0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
04T0oooo0P00000/0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0B`3oool2000002X0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?oo
o`1>0?ooo`8000009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W
0?ooo`030000003oool0oooo0500oooo0P00000U0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3o
ool0D`3oool200000280oooo00<000000?ooo`3oool0MP3oool2000000@0oooo000W0?ooo`030000
003oool0oooo05D0oooo0P00000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0F03oool2
000001d0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`00
0000oooo0?ooo`1J0?ooo`8000006`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0080oooo000W0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo05d0oooo
0P00000H0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<0
00000?ooo`3oool0G`3oool2000001H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`020?ooo`009`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0MP3oool2000000@0oooo000W0?ooo`030000003oool0oooo0680oooo0P00000C0?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3o
ool0I03oool200000140oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`00
9`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1W0?ooo`8000003P3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00070?ooo`<000000`3oool3
000000<0oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0
oooo06T0oooo0P00000<0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool0
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1/0?ooo`8000002@3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`<000001@3oool20000
06l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1f0?ooo`800000103oool000P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo06l0oooo0P0000060?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool000L0oooo0P0000040?ooo`80
0000103oool2000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0740oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0080oooo00080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`<000001@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo
0?ooo`1c0?ooo`8000000P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo
000W0?ooo`030000003oool0oooo07D0oooo0`00001i0?ooo`030000003oool0oooo0080oooo000W
0?ooo`030000003oool0oooo07L0oooo0P00001h0?ooo`030000003oool0oooo0080oooo000W0?oo
o`030000003oool0oooo07L0oooo00@000000?ooo`0000000000MP3oool00`000000oooo0?ooo`02
0?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`040000003oool0oooo0?ooo`800000L`3oool2
000000@0oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool0103oool200000740oooo00<000000?ooo`3oool00P3oool002L0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool00P3oool002L0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`080?ooo`800000K@3oool00`000000oooo0?ooo`02
0?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0JP3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo00/0oooo0P00001Z0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool03@3oool2000006L0oooo0P0000040?ooo`009`3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo0100oooo0P00001U0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool04P3oool2000006<0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`0E0?ooo`800000H03oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo01L0oooo0P00001N0?ooo`030000003oool0oooo0080oooo000W
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool06P3oool2000005X0oooo0P0000040?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo01`0oooo0P00001I0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool07`3o
ool2000005H0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool00P3oool0
02L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0R0?ooo`800000D`3oool00`00
0000oooo0?ooo`020?ooo`0000@0oooo00000000000000000`3oool3000000<0oooo0`0000040?oo
o`030000003oool0oooo0080oooo0`0000020?ooo`D00000103oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo02@0oooo0P00001A0?ooo`030000003oool0oooo0080oooo00020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo0080oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`800000N03oool00`000000oooo0?ooo`0W0?ooo`800000C@3oool2000000@0oooo00020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0:@3oool2000004`0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`02
0?ooo`0000<0oooo000000000000103oool2000000@0oooo0P0000090?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`0/0?ooo`800000B@3oool00`000000oooo0?ooo`020?ooo`000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool3
000000<0oooo0`0000050?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0;P3oool2
000004L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0a0?ooo`800000A03oool00`000000
oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03<0oooo
0P0000120?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0n0?ooo`800000103oool002L0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`0f0?ooo`800000?`3oool00`000000oooo0?ooo`02
0?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo03T0oooo0P00000l0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool0?@3oool2000003P0oooo00<000000?ooo`3oool00P3oool0
02L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0o0?ooo`800000=P3oool00`00
0000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0<P3oool2000000@0oooo000W0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0@P3oool2000003<0oooo00<000000?ooo`3oool00P3oool002L0oooo00<0
00000?ooo`3oool0M`3oool00`000000oooo0?ooo`140?ooo`800000<@3oool00`000000oooo0?oo
o`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo04L0oooo0P00000^0?ooo`030000003oool0oooo0080oooo000W0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0B@3oool2000002`0oooo00<000000?ooo`3o
ool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`1<0?ooo`800000:@3oool00`000000oooo0?ooo`020?ooo`009`3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool09@3oool2
000000@0oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0C`3oool20000
02H0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool002L0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`1C0?ooo`8000008P3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo05D0oooo0P00000P0?ooo`030000003oool0oooo0080oooo0000103o
ool000000000000000030?ooo`<000000`3oool3000000@0oooo00<000000?ooo`3oool00P3oool3
000000@0oooo0`0000040?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0E`3oool2
000001h0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1I
0?ooo`800000703oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01P000000oooo0?ooo`3oool0
00000?ooo`D00000103oool2000007P0oooo00<000000?ooo`3oool0F`3oool2000001T0oooo0P00
00040?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0203oool300000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`020?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo05h0oooo0P00000G0?ooo`030000003o
ool0oooo0080oooo00000`3oool00000000000040?ooo`800000103oool2000000T0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`8000001@3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0600oooo0P00000E0?ooo`030000003oool0oooo0080oooo00020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`<000001@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0HP3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0H`3oool200000180oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`1V0?ooo`8000003`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool02`3oool2000000@0oooo000W
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0JP3oool2000000/0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`1/0?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`00
9`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo06h0oooo0P0000070?ooo`030000
003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0L03o
ool2000000D0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
02L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0080oooo000W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0>03oool010000000
oooo0?ooo`3oool2000000@0oooo000W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool002L0oooom@0000040?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00<P3oool3000005P0oooo0`00000G0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool0303oool003<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool02`3oool002d0oooo0`0000030?ooo`<00000103o
ool200000080oooo1@0000020?ooo`<000000`3oool4000000030?ooo`000000000000<000001`3o
ool3000000@0oooo100000030?ooo`8000000P3oool6000000H0oooo1@0000020?ooo`<000000P3o
ool3000000040?ooo`00000000000?ooo`@000000`3oool200000080oooo1P0000070?ooo`030000
003oool0oooo00<0oooo100000000`3oool000000000000200000080oooo100000030?ooo`<00000
0P3oool5000000<0oooo0P000000103oool000000?ooo`3oool2000000<0oooo0`0000090?ooo`@0
000000<0oooo0000000000000`0000000`3oool0000000000002000000@0oooo0P0000030?ooo`@0
000000D0oooo00000000000000000?ooo`02000000040?ooo`0000000000000000<0oooo0`000005
0?ooo`030000003oool0oooo00X0oooo000/0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool00000
0?ooo`0000060?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`00
00020?ooo`060000003oool0oooo0000003oool000002`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool0000000P0oooo00<000000?ooo`3oool02P3oool002`0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool0000000H0oooo0`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo0080oooo1@0000020?ooo`060000003oool0oooo0000003oool000000`3o
ool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool00`3oool3000000<0oooo00@000000?ooo`3oool000000P3oool300000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`D000001`3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0080oooo0`0000030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`060000
003oool0oooo0000003oool000001@3oool5000000@0oooo00<000000?ooo`3oool02P3oool002`0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0`0000020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo
0000003oool000000`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`060000003oool0oooo
0000003oool000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000070?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo000/0?ooo`060000003oool0oooo0?ooo`000000oooo10000002
0?ooo`@000000P3oool3000000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`08
0?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`@000000`3oool3000000T0oooo00<0
00000?ooo`3oool00`3oool300000080oooo100000030?ooo`T000000`3oool3000000T0oooo00<0
00000?ooo`3oool00`3oool2000000@0oooo0`0000030?ooo`@000000P3oool3000000@0oooo00@0
00000?ooo`3oool0oooo0P000000103oool000000000003oool4000000<0oooo0`0000090?ooo`<0
00000P3oool3000000@0oooo100000000`3oool0000000000002000000<0oooo0P0000030?ooo`@0
00000`3oool3000000<0oooo0`0000050?ooo`030000003oool0oooo00X0oooo000/0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool02`3oool002d0oooo0`0000090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03@3oool3000000T0oooo100000090?ooo`030000003oool0oooo0080
oooo0P00000:0?ooo`<000005P3oool00`000000oooo0?ooo`020?ooo`8000003@3oool00`000000
oooo0?ooo`060?ooo`800000403oool3000000X0oooo00<000000?ooo`3oool0403oool2000000@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.138513, 111.749, \
0.000857962, 0.000620831}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.76191 -370.171 3.67801 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02091 -36 -4.5 ]
[-0.0125 .02091 0 4.5 ]
[-0.0125 .11286 -42 -4.5 ]
[-0.0125 .11286 0 4.5 ]
[-0.0125 .20481 -30 -4.5 ]
[-0.0125 .20481 0 4.5 ]
[-0.0125 .29676 -42 -4.5 ]
[-0.0125 .29676 0 4.5 ]
[-0.0125 .38871 -36 -4.5 ]
[-0.0125 .38871 0 4.5 ]
[-0.0125 .48067 -42 -4.5 ]
[-0.0125 .48067 0 4.5 ]
[-0.0125 .57262 -30 -4.5 ]
[-0.0125 .57262 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02091 m
.00625 .02091 L
s
[(100.65)] -0.0125 .02091 1 0 Mshowa
0 .11286 m
.00625 .11286 L
s
[(100.675)] -0.0125 .11286 1 0 Mshowa
0 .20481 m
.00625 .20481 L
s
[(100.7)] -0.0125 .20481 1 0 Mshowa
0 .29676 m
.00625 .29676 L
s
[(100.725)] -0.0125 .29676 1 0 Mshowa
0 .38871 m
.00625 .38871 L
s
[(100.75)] -0.0125 .38871 1 0 Mshowa
0 .48067 m
.00625 .48067 L
s
[(100.775)] -0.0125 .48067 1 0 Mshowa
0 .57262 m
.00625 .57262 L
s
[(100.8)] -0.0125 .57262 1 0 Mshowa
.125 Mabswid
0 .0393 m
.00375 .0393 L
s
0 .05769 m
.00375 .05769 L
s
0 .07608 m
.00375 .07608 L
s
0 .09447 m
.00375 .09447 L
s
0 .13125 m
.00375 .13125 L
s
0 .14964 m
.00375 .14964 L
s
0 .16803 m
.00375 .16803 L
s
0 .18642 m
.00375 .18642 L
s
0 .2232 m
.00375 .2232 L
s
0 .24159 m
.00375 .24159 L
s
0 .25998 m
.00375 .25998 L
s
0 .27837 m
.00375 .27837 L
s
0 .31515 m
.00375 .31515 L
s
0 .33354 m
.00375 .33354 L
s
0 .35193 m
.00375 .35193 L
s
0 .37032 m
.00375 .37032 L
s
0 .4071 m
.00375 .4071 L
s
0 .42549 m
.00375 .42549 L
s
0 .44388 m
.00375 .44388 L
s
0 .46228 m
.00375 .46228 L
s
0 .49906 m
.00375 .49906 L
s
0 .51745 m
.00375 .51745 L
s
0 .53584 m
.00375 .53584 L
s
0 .55423 m
.00375 .55423 L
s
0 .00252 m
.00375 .00252 L
s
0 .59101 m
.00375 .59101 L
s
0 .6094 m
.00375 .6094 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02091 m
1 .02091 L
s
.99375 .11286 m
1 .11286 L
s
.99375 .20481 m
1 .20481 L
s
.99375 .29676 m
1 .29676 L
s
.99375 .38871 m
1 .38871 L
s
.99375 .48067 m
1 .48067 L
s
.99375 .57262 m
1 .57262 L
s
.125 Mabswid
.99625 .0393 m
1 .0393 L
s
.99625 .05769 m
1 .05769 L
s
.99625 .07608 m
1 .07608 L
s
.99625 .09447 m
1 .09447 L
s
.99625 .13125 m
1 .13125 L
s
.99625 .14964 m
1 .14964 L
s
.99625 .16803 m
1 .16803 L
s
.99625 .18642 m
1 .18642 L
s
.99625 .2232 m
1 .2232 L
s
.99625 .24159 m
1 .24159 L
s
.99625 .25998 m
1 .25998 L
s
.99625 .27837 m
1 .27837 L
s
.99625 .31515 m
1 .31515 L
s
.99625 .33354 m
1 .33354 L
s
.99625 .35193 m
1 .35193 L
s
.99625 .37032 m
1 .37032 L
s
.99625 .4071 m
1 .4071 L
s
.99625 .42549 m
1 .42549 L
s
.99625 .44388 m
1 .44388 L
s
.99625 .46228 m
1 .46228 L
s
.99625 .49906 m
1 .49906 L
s
.99625 .51745 m
1 .51745 L
s
.99625 .53584 m
1 .53584 L
s
.99625 .55423 m
1 .55423 L
s
.99625 .00252 m
1 .00252 L
s
.99625 .59101 m
1 .59101 L
s
.99625 .6094 m
1 .6094 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .60332 m
.05372 .58483 L
.08634 .56467 L
.11698 .54574 L
.14644 .52753 L
.1778 .50815 L
.20799 .48949 L
.24008 .46966 L
.27099 .45055 L
.30073 .43217 L
.33237 .41262 L
.36283 .39379 L
.39213 .37569 L
.42332 .35641 L
.45333 .33786 L
.48525 .31813 L
.51599 .29913 L
.54556 .28086 L
.57703 .26141 L
.60732 .24269 L
.63951 .22279 L
.67053 .20362 L
.70038 .18518 L
.73212 .16556 L
.76269 .14666 L
.79209 .12849 L
.82339 .10915 L
.85351 .09054 L
.88553 .07075 L
.91638 .05168 L
.94605 .03334 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00;P3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool3000002P0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<00000
:`3oool2000002h0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<00000
:03oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo000]0?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000080?ooo`06
0000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0W0?ooo`040000003oool0
oooo000002`0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo0080oooo000V0?ooo`D000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo01l0oooo1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo000002`0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02@0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`00;@3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool00000;03oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0903o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo000]0?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000080?ooo`05
0000003oool0oooo0000003oool01000000Z0?ooo`040000003oool0oooo000002`0oooo00@00000
0?ooo`3oool00000203oool01@000000oooo0?ooo`000000oooo00@000009`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo0080oooo000]0?ooo`040000003oool0oooo000000P0
oooo0P00000X0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00
000]0?ooo`040000003oool0oooo000002`0oooo00@000000?ooo`3oool00000203oool01P000000
oooo0?ooo`000000oooo000002X0oooo00@000000?ooo`3oool00000203oool2000000@0oooo000^
0?ooo`8000002P3oool00`000000oooo0?ooo`0W0?ooo`8000002P3oool200000080oooo1@00000Z
0?ooo`800000;P3oool2000000X0oooo0P0000020?ooo`D000009`3oool2000000X0oooo00<00000
0?ooo`3oool00P3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool002`0ooool00000040?ooo`00;03oool2000000@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`800000103oool002`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool000L0oooo0`0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3o
ool00P3oool3000000<0oooo0`0000040?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`020?ooo`00203oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000001`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000007L0oooo00<000000?ooo`3oool0
KP3oool2000000@0oooo00<000000?ooo`3oool00P3oool000P0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`040000003oool0oooo0?ooo`<00000M@3oool00`000000oooo0?ooo`1/
0?ooo`8000001@3oool2000000@0oooo00080?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`@000001P3oool01@000000oooo0?oo
o`3oool0000007L0oooo00<000000?ooo`3oool0JP3oool2000000P0oooo00<000000?ooo`3oool0
0P3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000L0oooo00<000000?ooo`3oool00`3oool4000000@0oooo00<000000?ooo`3o
ool0M@3oool00`000000oooo0?ooo`1X0?ooo`8000002P3oool00`000000oooo0?ooo`020?ooo`00
1`3oool2000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo06H0oooo0P00000<0?ooo`030000003oool0oooo0080oooo00080?ooo`03
0000003oool0oooo00<0oooo0P0000040?ooo`8000002P3oool200000080oooo1@0000030?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`800000MP3oool00`000000oooo0?ooo`1S0?ooo`800000
3P3oool2000000@0oooo000/0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0
oooo07D0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0080oooo000/0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0G`3oool20000
01<0oooo00<000000?ooo`3oool00P3oool002`0oooo0P00001f0?ooo`030000003oool0oooo05d0
oooo0P00000D0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool002`0oooo00<0
00000?ooo`3oool0M@3oool00`000000oooo0?ooo`1J0?ooo`800000603oool00`000000oooo0?oo
o`020?ooo`00;03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo05P0oooo0P00000J
0?ooo`030000003oool0oooo0080oooo000/0?ooo`800000MP3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01T0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`1e0?ooo`03
0000003oool0oooo05D0oooo0P00000M0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000
003oool0oooo07D0oooo00<000000?ooo`3oool0D`3oool2000001l0oooo00<000000?ooo`3oool0
0P3oool002`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`1@0?ooo`8000008P3oool00`000000oooo0?ooo`020?ooo`00;03oool20000
07H0oooo00<000000?ooo`3oool0CP3oool2000002<0oooo0P0000040?ooo`00;03oool00`000000
oooo0?ooo`1e0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`020?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0P0000040?ooo`03
0000003oool0oooo0080oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000040?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool0B`3oool2000002L0oooo00<000000?ooo`3o
ool00P3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000007L0oooo00<000000?ooo`3oool0
B@3oool2000002T0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`00001e
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0:03oool2000000@0oooo00020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00070?ooo`@000001@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
M`3oool00`000000oooo0?ooo`160?ooo`800000;03oool00`000000oooo0?ooo`020?ooo`000P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000<00000103oool00`000000
oooo0?ooo`1e0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`020?ooo`0000<0oooo000000000000103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?ooo`03
0?ooo`800000103oool2000000X0oooo0P0000020?ooo`D0000000<0oooo0000000000000`000003
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0@P3oool200000300oooo00<00000
0?ooo`3oool00P3oool002`0oooo0P00001f0?ooo`030000003oool0oooo0400oooo0P00000a0?oo
o`800000103oool002`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`0m0?ooo`800000=@3oool00`000000oooo0?ooo`020?ooo`00;03o
ool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo03/0oooo0P00000g0?ooo`030000003o
ool0oooo0080oooo000/0?ooo`800000MP3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo03H0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
03P0oooo0P00000j0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0=P3oool2000003`0oooo00<000000?ooo`3oool00P3oool002`0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool00P3oool002`0oooo0P00001f0?ooo`030000003oool0oooo03<0oooo0P00
000n0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0a
0?ooo`800000@@3oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`020?oo
o`00;03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo02h0oooo0P0000140?ooo`03
0000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
;03oool2000004H0oooo00<000000?ooo`3oool00P3oool002`0oooo0P00001f0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0A@3oool2000000@0oooo000/0?ooo`030000003oool0
oooo07D0oooo00<000000?ooo`3oool0:@3oool2000004T0oooo00<000000?ooo`3oool00P3oool0
00d0oooo0`0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo0080oooo000>0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool00P3oool000h0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3o
ool3000007D0oooo00<000000?ooo`3oool09@3oool2000004`0oooo0P0000040?ooo`003P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
8`3oool2000004l0oooo00<000000?ooo`3oool00P3oool000h0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3o
ool0oooo0000001g0?ooo`030000003oool0oooo0240oooo0P00001A0?ooo`030000003oool0oooo
0080oooo000=0?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo07D0oooo00<0
00000?ooo`3oool07`3oool2000005<0oooo00<000000?ooo`3oool00P3oool000h0oooo00<00000
0?ooo`3oool00`3oool2000000@0oooo0P0000080?ooo`D000000`3oool00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo01d0oooo0P00001E0?ooo`030000003oool0oooo0080oooo000/0?oo
o`800000MP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05@0oooo0P0000040?oo
o`00;03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo01X0oooo0P00001H0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
603oool2000005X0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool00P3o
ool002`0oooo0P00001f0?ooo`030000003oool0oooo01D0oooo0P00001L0?ooo`800000103oool0
02`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0M@3oool00`000000
oooo0?ooo`0B0?ooo`800000H03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo
0?ooo`1e0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`020?ooo`00;03oool2000007H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`1P0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0>
0?ooo`800000I03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo00`0oooo0P00001V0?ooo`030000003oool0oooo0080oooo000/0?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
2@3oool2000006T0oooo00<000000?ooo`3oool00P3oool002`0oooo0P00001f0?ooo`030000003o
ool0oooo00L0oooo0P00001Z0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool00P3oool0
00040?ooo`0000000000000000@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo0?ooo`D000000P3oool3000000@0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`040?ooo`800000KP3oool00`000000oooo0?ooo`020?ooo`000P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000`3oool01@00
0000oooo0?ooo`3oool0000007L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1^
0?ooo`030000003oool0oooo0080oooo00020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`3oool3000007D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1^0?ooo`800000103oool00080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000M`3oool00`00
0000oooo0?ooo`0200000780oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`0000000`3oool00`000000oooo00000003000000@0oooo00<000000?ooo`3oool0M@3oool3
000007@0oooo00<000000?ooo`3oool00P3oool000030?ooo`000000000000@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0M03oool2000007H0
oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3oool00`3oool2000000@0oooo
0P0000080?ooo`D000000P3oool300000080oooo1@0000030?ooo`800000L`3oool2000000030?oo
o`000000oooo07@0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`1`0?ooo`8000000`3o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0080oooo000/0?ooo`030000003oool0oooo06d0oooo0P0000060?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0K03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo
0P00001/0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L`3oool2000000@0oooo
000/0?ooo`030000003oool0oooo06T0oooo0P00000:0?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0I`3oool2000000`0oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?oo
o`00;03oool2000006D0oooo0P00000?0?ooo`030000003oool0oooo07<0oooo0P0000040?ooo`00
;03oool00`000000oooo0?ooo`1R0?ooo`8000004@3oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0080oooo000/0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0
oooo05l0oooo0P00000D0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool0
02`0oooo00<000000?ooo`3oool0G@3oool2000001H0oooo00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`020?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1c0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0FP3oool2000001T0oooo
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`001`3oool3000000@0oooo0P00
00040?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`00
00040?ooo`030000003oool0oooo05P0oooo0P00000K0?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00P3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000T0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`000000F@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00P3oool000P0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`3oool3000005D0oooo0P00000N0?ooo`030000003oool0oooo07<0oooo0P00
00040?ooo`00203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
0000E@3oool200000200oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00
203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo00000003000000@0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool000L0
oooo0P0000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000001`3oool00`000000oooo0?ooo`1@0?ooo`800000
8`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080oooo00080?ooo`030000003o
ool0oooo00<0oooo0P0000040?ooo`800000203oool5000000030?ooo`000000000000<000000`3o
ool200000500oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1c0?ooo`800000103o
ool002`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0C03oool20000
02L0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000
oooo0?ooo`1:0?ooo`800000:@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080
oooo000/0?ooo`030000003oool0oooo04P0oooo0P00000[0?ooo`030000003oool0oooo07@0oooo
00<000000?ooo`3oool00P3oool002`0oooo0P0000170?ooo`800000;@3oool00`000000oooo0?oo
o`1c0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0A03oool2000002l0oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?oo
o`00;03oool00`000000oooo0?ooo`110?ooo`800000<P3oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`800000@@3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo07<0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool0
0`000000oooo0?ooo`0m0?ooo`800000=P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0080oooo000/0?ooo`030000003oool0oooo03/0oooo0P00000h0?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo
0P00000i0?ooo`800000>`3oool00`000000oooo0?ooo`1c0?ooo`800000103oool002`0oooo00<0
00000?ooo`3oool0=P3oool2000003d0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`020?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<00000103o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000003D0oooo0P0000100?oo
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<00000<@3o
ool200000480oooo00<000000?ooo`3oool0L`3oool2000000@0oooo00020?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000380
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080
oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`0000040?oo
o`030000003oool0oooo02h0oooo0P0000150?ooo`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00P3oool000030?ooo`000000000000@0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000070?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000
003oool0000000L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3oool00`3o
ool2000000@0oooo0P0000080?ooo`D0000000<0oooo0000000000000`0000000`3oool000000000
0003000000<0oooo0P00000/0?ooo`800000B03oool00`000000oooo0?ooo`1c0?ooo`800000103o
ool002`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool002`0
oooo00<000000?ooo`3oool09`3oool2000004`0oooo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`0U0?ooo`800000CP3oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0080oooo000/0?ooo`800000903oool200000500oooo00<0
00000?ooo`3oool0L`3oool2000000@0oooo000/0?ooo`030000003oool0oooo0240oooo0P00001B
0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?oo
o`3oool07`3oool2000005@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?oo
o`00;03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool2000001d0oooo0P00001G0?ooo`030000
003oool0oooo07<0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`0H0?ooo`800000F`3oool00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo01H0
oooo0P00001M0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo
0P00000F0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0L`3oool2000000@0oooo
000=0?ooo`<00000103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`00
00040?ooo`030000003oool0oooo01<0oooo0P00001P0?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00P3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0140oooo0P00001R0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00P3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0080oooo000>0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000080?ooo`<00000103oool3000000h0oooo0P00001U0?ooo`030000003o
ool0oooo07<0oooo0P0000040?ooo`003P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0303oool2000006L0oooo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`020?ooo`003@3oool2000000@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`02
0?ooo`003P3oool00`000000oooo0?ooo`030?ooo`800000103oool2000000T0oooo0`0000040?oo
o`030000003oool0oooo00T0oooo0P00001Z0?ooo`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00P3oool002`0oooo0P0000080?ooo`800000K03oool00`000000oooo0?ooo`1c0?ooo`80
0000103oool002`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1/0?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0103o
ool2000006l0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00P3oool002`0oooo0P0000040?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03H0
oooo00@000000?ooo`3oool0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo000/0?oooo000000103oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00=L0oooo0`0000160?ooo`00f03oool00`000000oooo0?ooo`150?ooo`00K03o
ool00`000000oooo000000030?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`<000000P3o
ool3000000<0oooo0`0000040?ooo`<000000P3oool3000000030?ooo`00000000000080oooo0P00
00080?ooo`D0000000D0oooo00000000000000000?ooo`0200000080oooo0P0000030?ooo`<00000
0P3oool3000000030?ooo`000000000000@000000P3oool5000000<0oooo0P0000040?ooo`030000
003oool0oooo04@0oooo001/0?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000
103oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`060000003oool0oooo0000003oool000001P3oool010000000oooo0?ooo`000005
0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo04@0oooo001/0?ooo`030000003oool0000000<0oooo0`0000030?ooo`030000003o
ool000000080oooo1@0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`D000000P3oool010000000oooo0?ooo`0000020?ooo`<00000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000A@3oool0
06/0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`<000000`3oool20000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3o
ool000000?ooo`0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000150?ooo`00J`3oool01@000000oooo0000003oool000000080oooo0P000003
0?ooo`80000000<0oooo0000000000000P3oool3000000<0oooo00<000000?ooo`3oool00P3oool2
000000030?ooo`00000000000080oooo0`0000020?ooo`@000000P3oool4000000X0oooo00@00000
0?ooo`3oool0oooo100000020?ooo`@000000`3oool300000080oooo100000030?ooo`@0000000@0
oooo00000000000000000`3oool400000080oooo0P0000000`3oool00000000000140?ooo`00J`3o
ool01@000000oooo0000003oool0000001@0oooo00@000000?ooo`3oool00000503oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`1;0?ooo`00J`3oool600000180oooo1@00000D0?ooo`030000003oool0oooo00P0oooo
1@0000080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1;0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.144576, 100.628, \
0.000879774, 0.00113904}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.76191 4.53255 0.00350097 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06882 -30 -4.5 ]
[-0.0125 .06882 0 4.5 ]
[-0.0125 .15634 -30 -4.5 ]
[-0.0125 .15634 0 4.5 ]
[-0.0125 .24387 -30 -4.5 ]
[-0.0125 .24387 0 4.5 ]
[-0.0125 .33139 -30 -4.5 ]
[-0.0125 .33139 0 4.5 ]
[-0.0125 .41892 -30 -4.5 ]
[-0.0125 .41892 0 4.5 ]
[-0.0125 .50644 -30 -4.5 ]
[-0.0125 .50644 0 4.5 ]
[-0.0125 .59396 -30 -4.5 ]
[-0.0125 .59396 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06882 m
.00625 .06882 L
s
[(-1275)] -0.0125 .06882 1 0 Mshowa
0 .15634 m
.00625 .15634 L
s
[(-1250)] -0.0125 .15634 1 0 Mshowa
0 .24387 m
.00625 .24387 L
s
[(-1225)] -0.0125 .24387 1 0 Mshowa
0 .33139 m
.00625 .33139 L
s
[(-1200)] -0.0125 .33139 1 0 Mshowa
0 .41892 m
.00625 .41892 L
s
[(-1175)] -0.0125 .41892 1 0 Mshowa
0 .50644 m
.00625 .50644 L
s
[(-1150)] -0.0125 .50644 1 0 Mshowa
0 .59396 m
.00625 .59396 L
s
[(-1125)] -0.0125 .59396 1 0 Mshowa
.125 Mabswid
0 .08632 m
.00375 .08632 L
s
0 .10383 m
.00375 .10383 L
s
0 .12133 m
.00375 .12133 L
s
0 .13884 m
.00375 .13884 L
s
0 .17385 m
.00375 .17385 L
s
0 .19135 m
.00375 .19135 L
s
0 .20886 m
.00375 .20886 L
s
0 .22636 m
.00375 .22636 L
s
0 .26137 m
.00375 .26137 L
s
0 .27888 m
.00375 .27888 L
s
0 .29638 m
.00375 .29638 L
s
0 .31389 m
.00375 .31389 L
s
0 .3489 m
.00375 .3489 L
s
0 .3664 m
.00375 .3664 L
s
0 .38391 m
.00375 .38391 L
s
0 .40141 m
.00375 .40141 L
s
0 .43642 m
.00375 .43642 L
s
0 .45393 m
.00375 .45393 L
s
0 .47143 m
.00375 .47143 L
s
0 .48894 m
.00375 .48894 L
s
0 .52395 m
.00375 .52395 L
s
0 .54145 m
.00375 .54145 L
s
0 .55895 m
.00375 .55895 L
s
0 .57646 m
.00375 .57646 L
s
0 .05131 m
.00375 .05131 L
s
0 .03381 m
.00375 .03381 L
s
0 .0163 m
.00375 .0163 L
s
0 .61147 m
.00375 .61147 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06882 m
1 .06882 L
s
.99375 .15634 m
1 .15634 L
s
.99375 .24387 m
1 .24387 L
s
.99375 .33139 m
1 .33139 L
s
.99375 .41892 m
1 .41892 L
s
.99375 .50644 m
1 .50644 L
s
.99375 .59396 m
1 .59396 L
s
.125 Mabswid
.99625 .08632 m
1 .08632 L
s
.99625 .10383 m
1 .10383 L
s
.99625 .12133 m
1 .12133 L
s
.99625 .13884 m
1 .13884 L
s
.99625 .17385 m
1 .17385 L
s
.99625 .19135 m
1 .19135 L
s
.99625 .20886 m
1 .20886 L
s
.99625 .22636 m
1 .22636 L
s
.99625 .26137 m
1 .26137 L
s
.99625 .27888 m
1 .27888 L
s
.99625 .29638 m
1 .29638 L
s
.99625 .31389 m
1 .31389 L
s
.99625 .3489 m
1 .3489 L
s
.99625 .3664 m
1 .3664 L
s
.99625 .38391 m
1 .38391 L
s
.99625 .40141 m
1 .40141 L
s
.99625 .43642 m
1 .43642 L
s
.99625 .45393 m
1 .45393 L
s
.99625 .47143 m
1 .47143 L
s
.99625 .48894 m
1 .48894 L
s
.99625 .52395 m
1 .52395 L
s
.99625 .54145 m
1 .54145 L
s
.99625 .55895 m
1 .55895 L
s
.99625 .57646 m
1 .57646 L
s
.99625 .05131 m
1 .05131 L
s
.99625 .03381 m
1 .03381 L
s
.99625 .0163 m
1 .0163 L
s
.99625 .61147 m
1 .61147 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06882 m
1 .06882 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.05372 .0332 L
.08634 .05336 L
.11698 .0723 L
.14644 .09051 L
.1778 .10989 L
.20799 .12855 L
.24008 .14838 L
.27099 .16748 L
.30073 .18586 L
.33237 .20542 L
.36283 .22424 L
.39213 .24235 L
.42332 .26162 L
.45333 .28018 L
.48525 .2999 L
.51599 .3189 L
.54556 .33717 L
.57703 .35662 L
.60732 .37535 L
.63951 .39524 L
.67053 .41441 L
.70038 .43286 L
.73212 .45248 L
.76269 .47137 L
.79209 .48954 L
.82339 .50888 L
.85351 .5275 L
.88553 .54729 L
.91638 .56635 L
.94605 .58469 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00903oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002X0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000;@3oool200000300oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000:P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000D0oooo000S0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool09P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo000L0?ooo`D000000P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0240oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0Y0?oo
o`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`040?ooo`008`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02T0oooo00@000000?ooo`3oool00000;P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00@0oooo000S0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000
000/0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool01@000000
oooo0?ooo`000000oooo00@00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo000S0?ooo`040000003oool0oooo000000P0oooo0P00000Z0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00000_0?ooo`040000003oool0oooo0000
02h0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000002`0oooo
00@000000?ooo`3oool00000203oool2000000H0oooo000T0?ooo`8000002P3oool00`000000oooo
0?ooo`0Y0?ooo`8000002P3oool200000080oooo1@00000/0?ooo`800000<03oool2000000X0oooo
0P0000020?ooo`D00000:@3oool2000000X0oooo00<000000?ooo`3oool0103oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00280oooon@0000050?ooo`008P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`00
0000oooo0?ooo`030?ooo`800000M03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
00<0oooo000R0?ooo`8000001P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo07P0
oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`060?ooo`800000L@3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo00P0oooo0P00
001_0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool00280oooo0P00000<0?ooo`800000K03oool00`000000oooo0?ooo`1h0?oo
o`8000001@3oool00280oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0
3P3oool2000006T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`0@0?ooo`800000I`3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`8000004`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo07P0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`0C0?ooo`800000I03oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00080?ooo`<000000P3oool5000000<0
oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000T0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo0P00001Q0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000030?ooo`000000000000<0
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooon@0000050?ooo`002@3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo00000003000000D0oooo00<000000?ooo`3oool0
6P3oool2000005d0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00203o
ool2000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`00
0000203oool00`000000oooo0?ooo`0L0?ooo`800000F`3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D00000
00<0oooo0000000000000`0000040?ooo`030000003oool0oooo01h0oooo0P00001I0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo0P00000Q0?ooo`800000E`3o
ool00`000000oooo0?ooo`1h0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool08P3oool2
000005D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0U0?ooo`800000DP3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000:03oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo07P0oooo0P0000050?ooo`008P3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`030?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`800000CP3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo02/0oooo0P00001<0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3o
ool0;@3oool2000004X0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00
8P3oool200000300oooo0P0000180?ooo`030000003oool0oooo07P0oooo0P0000050?ooo`008P3o
ool00`000000oooo0?ooo`0a0?ooo`800000AP3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo
03@0oooo0P0000130?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280
oooo0P00000g0?ooo`800000@@3oool00`000000oooo0?ooo`1h0?ooo`8000001@3oool00280oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool00`3oool000P0oooo0`0000020?ooo`D000000P3oool3000000@0oooo0P00
00050?ooo`030000003oool0oooo03T0oooo0P00000n0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo00<0oooo00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool3000003`0oooo0P00000k0?ooo`030000003oool0oooo07L0oooo0`0000050?ooo`00
2@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo00000003000000<0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00203oool2000000<0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`100?ooo`800000=`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo0009
0?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D000000`3oool2000000D0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool00280oooo0P0000140?ooo`800000=03oool00`000000oooo0?ooo`1h0?oo
o`8000001@3oool00280oooo00<000000?ooo`3oool0A@3oool200000380oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`180?ooo`800000;`3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`800000B`3oool2000002d0oooo00<000000?ooo`3oool0N03oool2
000000D0oooo000R0?ooo`030000003oool0oooo04`0oooo0P00000[0?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0CP3oool2000002T0
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo
0?ooo`1@0?ooo`8000009`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo
000R0?ooo`800000D`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo07P0oooo0P00
00050?ooo`008P3oool00`000000oooo0?ooo`1C0?ooo`800000903oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo05L0oooo0P00000P0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo0P00001J0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0N03oool2000000D0oooo00080?ooo`<000000P3oool5
000000030?ooo`000000000000<000000P3oool3000000D0oooo00<000000?ooo`3oool0FP3oool2
000001d0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`002@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000030?ooo`00
0000000000<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo0009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo0`00001N0?ooo`8000006@3oool00`000000oooo0?ooo`1g
0?ooo`<000001@3oool000T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000`0000050?ooo`030000003oool0oooo0600oooo0P00000G
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000P0oooo0P0000030?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000P0oooo00<0
00000?ooo`3oool0HP3oool2000001D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`030?ooo`002@3oool00`000000oooo0?ooo`020?ooo`<000000`3oool300000080oooo1@000004
0?ooo`030000003oool0oooo06@0oooo0P00000C0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool00280oooo0P00001W0?ooo`8000004@3oool00`000000oooo0?ooo`1h0?oo
o`8000001@3oool00280oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0
J@3oool2000000h0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool20000
06h0oooo0P00000:0?ooo`030000003oool0oooo07P0oooo0P0000050?ooo`008P3oool00`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1`0?ooo`8000001`3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo0780oooo0P00
00050?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo0P00001e
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0N03oool2000000D0oooo000R0?oo
o`030000003oool0oooo07D0oooo0P0000020?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool00`3oool00280oooo00<000000?ooo`3oool0M`3oool3000007/0oooo00<000000?ooo`3o
ool00`3oool00280oooo00<000000?ooo`3oool0N@3oool2000007X0oooo00<000000?ooo`3oool0
0`3oool00280oooo0P00001j0?ooo`040000003oool00000000007L0oooo0P0000050?ooo`008P3o
ool00`000000oooo0?ooo`1i0?ooo`040000003oool0oooo0?ooo`800000MP3oool00`000000oooo
0?ooo`030?ooo`00203oool300000080oooo1@0000030?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00@0oooo0P00001c0?ooo`030000003oool0oooo00<0
oooo00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00001i
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0K@3oool3000000D0oooo00090?oo
o`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00P0oooo0P00001_0?ooo`030000003oool0oooo00<0oooo00080?ooo`8000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo0080
oooo0`0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`0;0?ooo`800000K03oool00`000000oooo0?ooo`030?ooo`008P3oool2000007X0oooo
00<000000?ooo`3oool03@3oool2000006T0oooo0P0000050?ooo`008P3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0100oooo0P00001W
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool04P3oool2000006D0oooo00<000000?ooo`3oool00`3oool00280oooo0P00001j0?ooo`03
0000003oool0oooo01@0oooo0P00001R0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`0F0?ooo`800000H@3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo01P0oooo0P00001O0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool06`3oool2000005`0oooo00<000000?ooo`3oool00`3oool00280
oooo0P00001j0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F03oool2000000D0
oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool07`3oool2000005P0oooo00<000000?ooo`3oool00`3oool00280oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool00`3oool00280oooo0P00001j0?ooo`030000003oool0oooo0280oooo0P00001D0?oo
o`8000001@3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0T0?ooo`80
0000D`3oool00`000000oooo0?ooo`030?ooo`00203oool3000000<0oooo0`0000040?ooo`030000
003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo02L0oooo
0P00001@0?ooo`030000003oool0oooo00<0oooo00000`3oool0000000000003000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool3000007T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`1;0?ooo`<000001@3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo02X0oooo0P00001=0?ooo`030000003oool0oooo00<0oooo00090?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000030000
00D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0/0?ooo`800000B`3oool00`00
0000oooo0?ooo`030?ooo`00203oool2000000@0oooo0P0000030?ooo`070000003oool0oooo0?oo
o`000000oooo000000080?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool0oooo1@0000000`3oool0000000000003000000@0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0_0?ooo`800000B03oool00`000000oooo0?ooo`03
0?ooo`008P3oool2000007X0oooo00<000000?ooo`3oool0<@3oool2000004D0oooo0P0000050?oo
o`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo03@0oooo0P0000130?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0=P3oool200000440oooo00<000000?ooo`3oool00`3o
ool00280oooo0P00001j0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0?@3oool2
000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0>@3oool20000
03h0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`0k0?ooo`800000?03oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`030?ooo`008P3oool2000007X0oooo00<000000?ooo`3oool0?P3oool2000003P0oooo0P00
00050?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo0440oooo0P00000f0?ooo`030000003oool0oooo00<0oooo000R0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000NP3o
ool00`000000oooo0?ooo`150?ooo`800000<@3oool2000000D0oooo00080?ooo`<000000`3oool3
000000<0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo04L0oooo0P00000`0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo04T0oooo0P00
000^0?ooo`030000003oool0oooo00<0oooo00000`3oool0000000000003000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo04/0oooo0P00
000/0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00
001i0?ooo`030000003oool0oooo04d0oooo0P00000X0?ooo`<000001@3oool000T0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`3oool4000000<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`030?ooo`00203oool2000000@0oooo0P0000030?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo0500oooo0P00000W0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`8000001@3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`030?ooo`008P3oool2000007X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0R0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1D
0?ooo`8000008`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`030?oo
o`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo05L0oooo0P00000P0?ooo`03
0000003oool0oooo00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?ooo`1I0?ooo`800000
7@3oool2000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0G03oool2000001/0oooo00<000000?ooo`3oool00`3oool0
0280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`1O0?ooo`800000603oool00`000000oooo0?ooo`030?ooo`008P3oool2000007X0oooo
00<000000?ooo`3oool0H@3oool2000001D0oooo0P0000050?ooo`008P3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo06@0oooo0P00000C
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool0IP3oool200000140oooo00<000000?ooo`3oool00`3oool00280oooo0P00001j0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool03@3oool2000000D0oooo000R0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0J@3oool2000000h0oooo00<000000?ooo`3oool0
0`3oool000P0oooo0`0000030?ooo`<000000P3oool500000080oooo0`0000050?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0J`3oool2000000`0oooo00<000000?ooo`3oool00`3o
ool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool3000007T0oooo00<0
00000?ooo`3oool0KP3oool2000000L0oooo0`0000050?ooo`002@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0L03oool2000000L0oooo00<00000
0?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`0000000`0000050?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool0LP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00080?oo
o`800000103oool2000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`<000000P3oool5000000@0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000103oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000D0oooo000R0?ooooT0
00001@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool003D0oooo0`00002:0?oo
o`030000003oool0oooo02/0oooo0`00000E0?ooo`030000003oool0oooo01D0oooo000f0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01@0oooo000`0?ooo`<000000`3oool3000000@0oooo0P0000020?ooo`D00000
0P3oool3000000<0oooo100000000`3oool0000000000003000000L0oooo0`0000040?ooo`@00000
0`3oool200000080oooo1P0000060?ooo`@000000P3oool5000000030?ooo`000000000000<00000
00<0oooo0000000000000`0000020?ooo`<000000P3oool3000000@0oooo0`0000020?ooo`<00000
00@0oooo000000000000oooo0`0000030?ooo`<000002@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000<0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D0
00000P3oool300000080oooo0`000000103oool000000000003oool4000000<0oooo0P0000020?oo
o`X000001@3oool00`000000oooo0?ooo`0C0?ooo`00;`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo00D00000
0?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000001P3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0C0?ooo`00;`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3oool3000000@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo1@00
00020?ooo`030000003oool0oooo0080oooo1@0000020?ooo`060000003oool0oooo0000003oool0
00001@3oool5000000P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
0080oooo0`0000030?ooo`030000003oool000000080oooo1@0000030?ooo`040000003oool0oooo
0?ooo`D000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool0
00001@3oool010000000oooo0?ooo`0000020?ooo`<000001@3oool00`000000oooo0?ooo`0C0?oo
o`00;`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool300000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo008000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`040000003oool0
oooo000000D0oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`030000003oool0oooo01<0
oooo000_0?ooo`060000003oool0oooo0?ooo`000000oooo100000020?ooo`@000000P3oool30000
00@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo
00000080oooo0P0000030?ooo`@000000`3oool3000000T0oooo00D000000?ooo`3oool000000?oo
o`03000000@0oooo100000020?ooo`@000000P3oool300000080oooo0P0000000`3oool000000000
00020?ooo`<000000P3oool4000000<0oooo0`0000030?ooo`<000002@3oool00`000000oooo0?oo
o`020?ooo`H0000000<0oooo0000000000000`3oool2000000030?ooo`00000000000080oooo0`00
00040?ooo`030000003oool0oooo0080oooo0`0000020?ooo`@000000`3oool9000000<0oooo0`00
00030?ooo`@00000103oool00`000000oooo0?ooo`0C0?ooo`00;`3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00300oooo0`0000090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool3000000T0oooo100000090?ooo`030000
003oool0oooo0080oooo0P00000:0?ooo`@00000103oool00`000000oooo0?ooo`040?ooo`800000
103oool2000002h0oooo00<000000?ooo`3oool0603oool3000001H0oooo00<000000?ooo`3oool0
0P3oool2000000/0oooo00<000000?ooo`3oool05@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.134655, -1308.63, \
0.000849626, 1.15564}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.76191 -735.446 6.58076 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0205 -36 -4.5 ]
[-0.0125 .0205 0 4.5 ]
[-0.0125 .15212 -36 -4.5 ]
[-0.0125 .15212 0 4.5 ]
[-0.0125 .28373 -30 -4.5 ]
[-0.0125 .28373 0 4.5 ]
[-0.0125 .41535 -36 -4.5 ]
[-0.0125 .41535 0 4.5 ]
[-0.0125 .54697 -36 -4.5 ]
[-0.0125 .54697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0205 m
.00625 .0205 L
s
[(111.76)] -0.0125 .0205 1 0 Mshowa
0 .15212 m
.00625 .15212 L
s
[(111.78)] -0.0125 .15212 1 0 Mshowa
0 .28373 m
.00625 .28373 L
s
[(111.8)] -0.0125 .28373 1 0 Mshowa
0 .41535 m
.00625 .41535 L
s
[(111.82)] -0.0125 .41535 1 0 Mshowa
0 .54697 m
.00625 .54697 L
s
[(111.84)] -0.0125 .54697 1 0 Mshowa
.125 Mabswid
0 .05341 m
.00375 .05341 L
s
0 .08631 m
.00375 .08631 L
s
0 .11922 m
.00375 .11922 L
s
0 .18502 m
.00375 .18502 L
s
0 .21793 m
.00375 .21793 L
s
0 .25083 m
.00375 .25083 L
s
0 .31664 m
.00375 .31664 L
s
0 .34954 m
.00375 .34954 L
s
0 .38245 m
.00375 .38245 L
s
0 .44825 m
.00375 .44825 L
s
0 .48116 m
.00375 .48116 L
s
0 .51406 m
.00375 .51406 L
s
0 .57987 m
.00375 .57987 L
s
0 .61277 m
.00375 .61277 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0205 m
1 .0205 L
s
.99375 .15212 m
1 .15212 L
s
.99375 .28373 m
1 .28373 L
s
.99375 .41535 m
1 .41535 L
s
.99375 .54697 m
1 .54697 L
s
.125 Mabswid
.99625 .05341 m
1 .05341 L
s
.99625 .08631 m
1 .08631 L
s
.99625 .11922 m
1 .11922 L
s
.99625 .18502 m
1 .18502 L
s
.99625 .21793 m
1 .21793 L
s
.99625 .25083 m
1 .25083 L
s
.99625 .31664 m
1 .31664 L
s
.99625 .34954 m
1 .34954 L
s
.99625 .38245 m
1 .38245 L
s
.99625 .44825 m
1 .44825 L
s
.99625 .48116 m
1 .48116 L
s
.99625 .51406 m
1 .51406 L
s
.99625 .57987 m
1 .57987 L
s
.99625 .61277 m
1 .61277 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .60332 m
.05372 .58483 L
.08634 .56467 L
.11698 .54574 L
.14644 .52753 L
.1778 .50815 L
.20799 .48949 L
.24008 .46966 L
.27099 .45055 L
.30073 .43217 L
.33237 .41262 L
.36283 .39379 L
.39213 .37569 L
.42332 .35641 L
.45333 .33786 L
.48525 .31813 L
.51599 .29913 L
.54556 .28086 L
.57703 .26141 L
.60732 .24269 L
.63951 .22279 L
.67053 .20362 L
.70038 .18518 L
.73212 .16556 L
.76269 .14666 L
.79209 .12849 L
.82339 .10915 L
.85351 .09054 L
.88553 .07075 L
.91638 .05168 L
.94605 .03334 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002X0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000;03oool2000002l0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000:P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000<0oooo000W0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool09P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo000P0?ooo`D000000P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0240oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0X0?oo
o`040000003oool0oooo000002d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`020?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo0080oooo000W0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000
000[0?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool00000203oool01@000000
oooo0?ooo`000000oooo00@00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo0080oooo000W0?ooo`040000003oool0oooo000000P0oooo0P00000Z0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00000^0?ooo`040000003oool0oooo0000
02d0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000002`0oooo
00@000000?ooo`3oool00000203oool2000000@0oooo000X0?ooo`8000002P3oool00`000000oooo
0?ooo`0Y0?ooo`8000002P3oool200000080oooo1@00000[0?ooo`800000;`3oool2000000X0oooo
0P0000020?ooo`D00000:@3oool2000000X0oooo00<000000?ooo`3oool00P3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool002L0oooom@0000040?ooo`009`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo0000103oool000000000000000030?ooo`<000000`3oool3000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`1a0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P00001h0?ooo`030000003oool0
oooo0700oooo00<000000?ooo`3oool00`3oool2000000@0oooo00020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00@000001@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo06h0oooo0P0000070?oo
o`030000003oool0oooo0080oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`1/0?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`00
00<0oooo000000000000103oool2000000@0oooo0P0000090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`D00000
0`3oool2000000D0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1Y0?ooo`800000
303oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo06L0oooo0P00000>0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0I03oool20000
0140oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`1R0?ooo`8000004P3oool2000000@0oooo000W0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo
000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0G`3oool2000001H0oooo00<0
00000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1M
0?ooo`800000603oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo05`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?oo
o`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo05X0oooo0P00000K0?ooo`03
0000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0E`3oool2000001h0oooo00<000000?ooo`3oool00P3o
ool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1E0?ooo`800000803oool0
0`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool07`3oool2000000@0oooo000W0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool0DP3oool2000002<0oooo00<000000?ooo`3oool00P3oool002L0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1@0?ooo`8000009@3oool00`000000oooo
0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo04d0oooo0P00000X0?ooo`030000003oool0oooo0080oooo000W0?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool0B`3oool2000002X0oooo00<000000?oo
o`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`180?ooo`800000;@3oool00`000000oooo0?ooo`020?ooo`009`3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04H0oooo0P00000^0?ooo`800000103o
ool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`130?ooo`800000<P3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0440oooo0P00000d0?ooo`030000003oool0oooo0080
oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0080oooo0000103oool000000000000000030?ooo`<00000
0`3oool3000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<00000
1@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03h0oooo0P00000g0?ooo`030000
003oool0oooo0080oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0?03oool2000003T0oooo
00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo0080oooo00020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`<00000
1@3oool2000007P0oooo00<000000?ooo`3oool0>@3oool2000003/0oooo0P0000040?ooo`000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3o
ool000030?ooo`000000000000@0oooo0P0000040?ooo`8000002@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0080oooo
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`D000000P3oool3000000D0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`0e0?ooo`800000@03oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`02
0?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0380oooo0P0000130?oo
o`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0<03oool2000004D0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0]0?ooo`800000A`3o
ool2000000@0oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0:`3oool2
000004X0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0X0?ooo`800000C@3oool00`000000
oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo02H0oooo
0P00001?0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0080oooo000W
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool08`3oool200000580oooo00<00000
0?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0Q0?oo
o`800000E03oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0D`3oool2000000@0oooo000W0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool07P3oool2000005L0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`0K0?ooo`800000FP3oool00`000000oooo0?ooo`020?ooo`009`3oool00`00
0000oooo0?ooo`1g0?ooo`030000003oool0oooo01T0oooo0P00001L0?ooo`030000003oool0oooo
0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool05P3oool2000005l0oooo00<000000?ooo`3oool00P3oool002L0oooo00<0
00000?ooo`3oool0M`3oool00`000000oooo0?ooo`0D0?ooo`800000H@3oool00`000000oooo0?oo
o`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0H03oool2000000@0oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool04@3oool2000006@0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`0?0?ooo`800000IP3oool00`000000oooo0?ooo`020?ooo`00
9`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo00`0oooo0P00001Y0?ooo`030000003oool0oooo0080oooo00070?ooo`<000000`3oool3
000000<0oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool02P3oool2000006/0oooo00<000000?ooo`3oool00P3oool0
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0080oooo00080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo00L0oooo0P00001^0?ooo`030000003oool0oooo0080oooo00080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`<000001@3oool20000
07P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1]0?ooo`800000103oool000P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0103oool200000740oooo00<000000?ooo`3oool00P3oool000L0oooo0P0000040?ooo`80
0000103oool2000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
0080oooo00080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`<000001@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo00800000M@3oool00`000000oooo0?ooo`020?ooo`009`3o
ool00`000000oooo0?ooo`1g0?ooo`<00000M`3oool00`000000oooo0?ooo`020?ooo`009`3oool0
0`000000oooo0?ooo`1f0?ooo`800000N@3oool00`000000oooo0?ooo`020?ooo`009`3oool00`00
0000oooo0?ooo`1d0?ooo`80000000<0oooo0000003oool0N03oool00`000000oooo0?ooo`020?oo
o`009`3oool00`000000oooo0?ooo`1b0?ooo`8000000`3oool00`000000oooo0?ooo`1f0?ooo`80
0000103oool002L0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0K`3o
ool2000000H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000
oooo0?ooo`1[0?ooo`8000002P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080
oooo000W0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo06P0oooo0P00
000=0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<00000
0?ooo`3oool0IP3oool2000000l0oooo00<000000?ooo`3oool0MP3oool2000000@0oooo000W0?oo
o`030000003oool0oooo06D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo06<0oooo0P00000B0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0
H@3oool2000001@0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1N0?ooo`8000005`3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
05`0oooo0P00000I0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0F@3oool2000001`0oooo
00<000000?ooo`3oool0MP3oool2000000@0oooo000W0?ooo`030000003oool0oooo05L0oooo0P00
000N0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0E03oool200000240oooo00<000000?oo
o`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1B0?ooo`80
00008`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo0080oooo0000103oool000000000000000030?ooo`<000000`3oool3000000@0oooo
00<000000?ooo`3oool00P3oool300000080oooo1@0000040?ooo`030000003oool0oooo04l0oooo
0P00000V0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool00080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0C@3oool2000002P0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`00
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool2000004d0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1f0?ooo`800000103oool00080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
0`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0BP3oool2000002/0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04P0
oooo0P00000]0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool000030?oo
o`000000000000@0oooo0P0000040?ooo`8000002@3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`<0
00000`3oool3000000D0oooo00<000000?ooo`3oool0A@3oool200000300oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3o
ool00`000000oooo0?ooo`120?ooo`800000<`3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0080oooo000W0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1f0?ooo`800000103oool002L0
oooo00<000000?ooo`3oool0?P3oool2000003L0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0l0?ooo`800000>@3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo03X0oooo0P00
000k0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<00000
0?ooo`3oool0>03oool2000003d0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`02
0?ooo`009`3oool00`000000oooo0?ooo`0f0?ooo`800000?`3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo03<0oooo0P0000120?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool0<@3oool2000004@0oooo00<000000?ooo`3oool0MP3o
ool2000000@0oooo000W0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
02h0oooo0P0000170?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0:`3oool2000004X0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`020?ooo`009`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0W0?oo
o`800000CP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1f0?ooo`80
0000103oool002L0oooo00<000000?ooo`3oool0903oool200000540oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0R0?ooo`800000D`3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo0080oooo000W0?ooo`030000003oool0oooo01l0oooo0P00001F0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool07@3oool2000005P0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`0000@0oooo000000000000
00000`3oool3000000<0oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000040?ooo`<0
0000103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`800000F`3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo0?ooo`00
0000oooo1@0000040?ooo`8000006@3oool2000005d0oooo00<000000?ooo`3oool0MP3oool20000
00@0oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`<000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0080oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000050?oo
o`030000003oool0oooo01D0oooo0P00001P0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool00P3oool000030?ooo`000000000000@0oooo0P0000040?ooo`8000002@3oool01@000000
oooo0?ooo`3oool0000000<0oooo0P0000050?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`<0
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo0140oooo0P00001T0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool03P3oool2
000006L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`00
0000oooo0?ooo`0<0?ooo`800000J@3oool00`000000oooo0?ooo`1f0?ooo`800000103oool002L0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool02@3oool2000006`0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?oo
o`070?ooo`800000KP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W
0?ooo`030000003oool0oooo00D0oooo0P00001`0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool00`3oool200000780oooo00<000000?oo
o`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0780oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`00
9`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0h0?ooo`040000003o
ool0oooo0?ooo`800000103oool002L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`009`3ooooe000000@0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
000b0?ooo`<00000F03oool3000001L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`0<0?ooo`00<`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`0;0?ooo`00;@3oool3000000<0oooo0`0000040?oo
o`8000000P3oool500000080oooo0`0000030?ooo`@0000000<0oooo0000000000000`0000070?oo
o`<00000103oool4000000<0oooo0P0000020?ooo`H000001P3oool500000080oooo0`0000020?oo
o`<0000000@0oooo000000000000oooo100000030?ooo`8000000P3oool6000000L0oooo00<00000
0?ooo`3oool00`3oool4000000030?ooo`0000000000008000000P3oool4000000<0oooo0`000002
0?ooo`D000000`3oool2000000040?ooo`000000oooo0?ooo`8000000`3oool3000000T0oooo1000
00000`3oool0000000000003000000030?ooo`000000000000800000103oool2000000<0oooo1000
00001@3oool00000000000000000oooo0080000000@0oooo00000000000000000`3oool3000000D0
oooo00<000000?ooo`3oool02P3oool002`0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000
oooo000000H0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0000
0080oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`000000203oool00`000000oooo0?ooo`0:0?ooo`00;03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000001P3oool3000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool00P3oool500000080oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`030?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`<000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0080oooo1@0000070?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool00`3oool3000000<0oooo00H00000
0?ooo`3oool000000?ooo`0000050?ooo`D00000103oool00`000000oooo0?ooo`0:0?ooo`00;03o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool300000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000203o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000050?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000L0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool002`0oooo00H000000?ooo`3oool0oooo0000003oool400000080
oooo100000020?ooo`<00000103oool3000000<0oooo0P0000050?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool000000P3oool2000000<0oooo100000030?ooo`<000002@3oool00`00
0000oooo0?ooo`030?ooo`<000000P3oool4000000<0oooo2@0000030?ooo`<000002@3oool00`00
0000oooo0?ooo`030?ooo`800000103oool3000000<0oooo100000020?ooo`<00000103oool01000
0000oooo0?ooo`3oool2000000040?ooo`00000000000?ooo`@000000`3oool3000000T0oooo0`00
00020?ooo`<00000103oool4000000030?ooo`0000000000008000000`3oool2000000<0oooo1000
00030?ooo`<000000`3oool3000000D0oooo00<000000?ooo`3oool02P3oool002`0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0;0?ooo`00;@3oool3000000T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0=0?ooo`<000002@3oool4000000T0oooo00<000000?ooo`3oool00P3o
ool2000000X0oooo0`00000F0?ooo`030000003oool0oooo0080oooo0P00000=0?ooo`030000003o
ool0oooo00H0oooo0P00000@0?ooo`<000002P3oool00`000000oooo0?ooo`0@0?ooo`800000103o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0303o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.138513, 111.749, \
0.000857962, 0.000620831}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.76191 -364.993 5.15922 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07302 -30 -4.5 ]
[-0.0125 .07302 0 4.5 ]
[-0.0125 .17621 -30 -4.5 ]
[-0.0125 .17621 0 4.5 ]
[-0.0125 .27939 -24 -4.5 ]
[-0.0125 .27939 0 4.5 ]
[-0.0125 .38257 -30 -4.5 ]
[-0.0125 .38257 0 4.5 ]
[-0.0125 .48576 -30 -4.5 ]
[-0.0125 .48576 0 4.5 ]
[-0.0125 .58894 -30 -4.5 ]
[-0.0125 .58894 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07302 m
.00625 .07302 L
s
[(70.76)] -0.0125 .07302 1 0 Mshowa
0 .17621 m
.00625 .17621 L
s
[(70.78)] -0.0125 .17621 1 0 Mshowa
0 .27939 m
.00625 .27939 L
s
[(70.8)] -0.0125 .27939 1 0 Mshowa
0 .38257 m
.00625 .38257 L
s
[(70.82)] -0.0125 .38257 1 0 Mshowa
0 .48576 m
.00625 .48576 L
s
[(70.84)] -0.0125 .48576 1 0 Mshowa
0 .58894 m
.00625 .58894 L
s
[(70.86)] -0.0125 .58894 1 0 Mshowa
.125 Mabswid
0 .09882 m
.00375 .09882 L
s
0 .12461 m
.00375 .12461 L
s
0 .15041 m
.00375 .15041 L
s
0 .202 m
.00375 .202 L
s
0 .2278 m
.00375 .2278 L
s
0 .25359 m
.00375 .25359 L
s
0 .30519 m
.00375 .30519 L
s
0 .33098 m
.00375 .33098 L
s
0 .35678 m
.00375 .35678 L
s
0 .40837 m
.00375 .40837 L
s
0 .43417 m
.00375 .43417 L
s
0 .45996 m
.00375 .45996 L
s
0 .51155 m
.00375 .51155 L
s
0 .53735 m
.00375 .53735 L
s
0 .56315 m
.00375 .56315 L
s
0 .04723 m
.00375 .04723 L
s
0 .02143 m
.00375 .02143 L
s
0 .61474 m
.00375 .61474 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07302 m
1 .07302 L
s
.99375 .17621 m
1 .17621 L
s
.99375 .27939 m
1 .27939 L
s
.99375 .38257 m
1 .38257 L
s
.99375 .48576 m
1 .48576 L
s
.99375 .58894 m
1 .58894 L
s
.125 Mabswid
.99625 .09882 m
1 .09882 L
s
.99625 .12461 m
1 .12461 L
s
.99625 .15041 m
1 .15041 L
s
.99625 .202 m
1 .202 L
s
.99625 .2278 m
1 .2278 L
s
.99625 .25359 m
1 .25359 L
s
.99625 .30519 m
1 .30519 L
s
.99625 .33098 m
1 .33098 L
s
.99625 .35678 m
1 .35678 L
s
.99625 .40837 m
1 .40837 L
s
.99625 .43417 m
1 .43417 L
s
.99625 .45996 m
1 .45996 L
s
.99625 .51155 m
1 .51155 L
s
.99625 .53735 m
1 .53735 L
s
.99625 .56315 m
1 .56315 L
s
.99625 .04723 m
1 .04723 L
s
.99625 .02143 m
1 .02143 L
s
.99625 .61474 m
1 .61474 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .07302 m
1 .07302 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.05372 .0332 L
.08634 .05336 L
.11698 .0723 L
.14644 .09051 L
.1778 .10989 L
.20799 .12855 L
.24008 .14838 L
.27099 .16748 L
.30073 .18586 L
.33237 .20542 L
.36283 .22424 L
.39213 .24235 L
.42332 .26162 L
.45333 .28018 L
.48525 .2999 L
.51599 .3189 L
.54556 .33717 L
.57703 .35662 L
.60732 .37535 L
.63951 .39524 L
.67053 .41441 L
.70038 .43286 L
.73212 .45248 L
.76269 .47137 L
.79209 .48954 L
.82339 .50888 L
.85351 .5275 L
.88553 .54729 L
.91638 .56635 L
.94605 .58469 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00903oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002X0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000;@3oool200000300oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000:P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000D0oooo000S0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool09P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo000L0?ooo`D000000P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0240oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0Y0?oo
o`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`040?ooo`008`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02T0oooo00@000000?ooo`3oool00000;P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00@0oooo000S0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000
000/0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool01@000000
oooo0?ooo`000000oooo00@00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo000S0?ooo`040000003oool0oooo000000P0oooo0P00000Z0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00000_0?ooo`040000003oool0oooo0000
02h0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000002`0oooo
00@000000?ooo`3oool00000203oool2000000H0oooo000T0?ooo`8000002P3oool00`000000oooo
0?ooo`0Y0?ooo`8000002P3oool200000080oooo1@00000/0?ooo`800000<03oool2000000X0oooo
0P0000020?ooo`D00000:@3oool2000000X0oooo00<000000?ooo`3oool0103oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00280oooon@0000050?ooo`008P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`00
0000oooo0?ooo`030?ooo`800000M03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
00<0oooo000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`8000001`3oool200000740oooo
00<000000?ooo`3oool0N03oool2000000D0oooo000R0?ooo`030000003oool0oooo00P0oooo0P00
001_0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool02`3oool2000006`0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo06T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00
8P3oool00`000000oooo0?ooo`0>0?ooo`800000J@3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00<0oooo000R0?ooo`8000004@3oool2000006L0oooo00<000000?ooo`3oool0N03o
ool2000000D0oooo000R0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo
01<0oooo0P00001T0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool00`3oool000<0oooo00<000000?ooo`3oool00`3oool2000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo
0?ooo`0F0?ooo`800000H@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo
00030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000002@3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0100000050?ooooT000001@3oool000D0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0703oool20000
05/0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000003o
ool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07P3oool2
000005T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000
000000000`0000030?ooo`800000203oool5000000<0oooo0P0000050?ooo`030000003oool0oooo
0200oooo0P00001G0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool08P3oool2000005D0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool2000002H0oooo0P00
001B0?ooo`030000003oool0oooo07P0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`03
0?ooo`008P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`80
0000CP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000
003oool0oooo02/0oooo0P00001<0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
0`3oool00280oooo00<000000?ooo`3oool0;@3oool2000004X0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`030?ooo`008P3oool200000300oooo0P0000180?ooo`030000003oool0
oooo07P0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`0a0?ooo`800000AP3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0
oooo000R0?ooo`030000003oool0oooo03@0oooo0P0000130?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0=P3oool200000440oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`03
0?ooo`008P3oool00`000000oooo0?ooo`0i0?ooo`800000?P3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo00<0oooo000R0?ooo`800000?03oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo07P0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`0l0?ooo`800000
>`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00030?ooo`030000003oool0oooo
00<0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool30000
00D0oooo00<000000?ooo`3oool0@03oool2000003L0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`030?ooo`000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`<00000@`3o
ool2000003@0oooo00<000000?ooo`3oool0M`3oool3000000D0oooo00040?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0?ooo`<00000
1@3oool00`000000oooo0?ooo`150?ooo`800000<P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00<0oooo00050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
2@3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
0`3oool000030?ooo`000000oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`050?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0B03oool2000002l0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`030?ooo`0000<0oooo0000000000000`0000030?ooo`800000203oool500000080
oooo0`0000050?ooo`030000003oool0oooo04X0oooo0P00000]0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0C03oool2000002/0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?oo
o`1>0?ooo`800000:@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R
0?ooo`800000D@3oool2000002L0oooo00<000000?ooo`3oool0N03oool2000000D0oooo000R0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo05<0oooo0P00000T0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
0`3oool00280oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0E`3oool2
00000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool20000
05X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1h0?ooo`8000001@3oool00280
oooo00<000000?ooo`3oool0FP3oool2000001d0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?oo
o`1M0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`030?ooo`008P3oool00`000000oooo0?ooo`1N0?ooo`8000006@3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo0600oooo0P00000G0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo0P00001S0?ooo`80
00005@3oool00`000000oooo0?ooo`1h0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool0
I03oool2000001<0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`1V0?ooo`8000004@3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo
00<0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo
06T0oooo0P00000>0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000T0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`002P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0K03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool00`3oool000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00H0oooo0`0000050?ooo`<00000K@3oool2000000X0oooo00<000000?ooo`3oool0M`3o
ool3000000D0oooo000;0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0700oooo0P0000070?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool00`3oool000L0oooo1@0000030?ooo`8000002@3oool3000000D0
oooo00<000000?ooo`3oool0LP3oool2000000D0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?oo
o`1e0?ooo`8000000P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R
0?ooo`800000N03oool3000007X0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1i0?oo
o`800000NP3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`04
0000003oool00000000007P0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3o
ool0N@3oool010000000oooo0?ooo`3oool2000007H0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`040?ooo`800000L`3oool00`000000oooo0?ooo`030?ooo`008P3oool2000007X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1_0?ooo`8000001@3oool00280oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06l0oooo00<00000
0?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?oo
o`800000K`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`030?ooo`00
8P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00/0oooo0P00001/0?ooo`030000
003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool03@3o
ool2000006X0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool00`3oool0
0280oooo0P00001j0?ooo`030000003oool0oooo0100oooo0P00001V0?ooo`8000001@3oool00280
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0B0?ooo`800000I@3oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo01@0oooo
0P00001S0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool05P3oool200000640oooo00<000000?ooo`3oool00`3oool000<0oooo00<00000
0?ooo`3oool00`3oool2000000@0oooo00<000000?ooo`3oool00P3oool300000080oooo1@000004
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0603oool2000005l0oooo00<00000
0?ooo`3oool00`3oool000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000007
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo00<0oooo00040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`<0
0000N@3oool00`000000oooo0?ooo`0K0?ooo`800000FP3oool3000000D0oooo00040?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`<000001@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo00<0oooo00050?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo00000`3oool000000?ooo`020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool07`3oool2000005P0oooo00<000000?ooo`3oool00`3oool000030?ooo`00
0000000000<000000`3oool2000000T0oooo0`0000030?ooo`<000001@3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0280oooo0P00001E
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool0903oool2000005<0oooo00<000000?ooo`3oool00`3oool00280oooo0P00001j0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0C`3oool2000000D0oooo000R0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool09`3oool200000500oooo00<000000?ooo`3oool0
0`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`0Z0?ooo`800000C@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo02`0oooo0P00001;0?ooo`030000003oool0oooo
00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000NP3oool00`000000oooo
0?ooo`0_0?ooo`800000A`3oool2000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0<@3oool2000004H0oooo00<000000?ooo`3oool00`3oool00280oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0d0?oo
o`800000@`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo03H0oooo0P0000110?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?ooo`0i0?ooo`800000?@3o
ool2000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0>`3oool2
000003`0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0n0?ooo`800000>@3oool00`000000
oooo0?ooo`030?ooo`000`3oool00`000000oooo0?ooo`030?ooo`800000103oool00`000000oooo
0?ooo`020?ooo`<00000103oool3000000@0oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00`3oool000<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0@@3oool2000003H0oooo00<000000?ooo`3oool00`3oool000@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool0oooo0000003oool5
000000@0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool00`3oool000@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00H0oooo0`0000020?ooo`040000003oool0oooo000000D0oooo0`00
001i0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0<03oool3000000D0oooo0005
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo04D0oooo0P00000b0?ooo`030000003oool0oooo00<0oooo00000`3oool000000?oo
o`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool01@000000oooo
0?ooo`3oool0000000<0oooo0P0000050?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0A`3oool200000300oooo00<000000?ooo`3oool00`3oool000030?ooo`000000000000<00000
0`3oool2000000T0oooo0`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`190?ooo`800000;P3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo04/0oooo0P00000/0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0C@3oool2
000002X0oooo00<000000?ooo`3oool00`3oool00280oooo0P00001j0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool09P3oool2000000D0oooo000R0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0D03oool2000002L0oooo00<000000?ooo`3oool00`3oool00280oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00280oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`1D0?ooo`8000008`3oool00`000000oooo0?ooo`03
0?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`030?ooo`008P3oool2000007X0oooo00<000000?ooo`3o
ool0E`3oool2000001l0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo05T0oooo0P00000N0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0G03oool2
000001/0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1O0?ooo`800000603oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0640oooo
0P00000F0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0180oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo06@0oooo0P00000C0?ooo`030000003oool0oooo00<0oooo000R0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool0IP3oool200000140oooo00<000000?oo
o`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1X0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool000<0oooo00<000000?ooo`3oool0
0`3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0`0000050?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0J@3oool2000000h0oooo00<000000?ooo`3oool0
0`3oool000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`1[0?ooo`800000303oool00`000000oooo0?ooo`030?oo
o`00103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`<00000N@3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00L0oooo0`0000050?ooo`00103oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool300000080oooo1000
00050?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0KP3oool2000000T0oooo00<0
00000?ooo`3oool00`3oool000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`050?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0L03oool2000000L0oooo00<000000?ooo`3oool00`3oool000030?oo
o`000000oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00000`3oool0000000000003000000<0oooo0P0000090?ooo`<00000103oool2000000D0
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00280oooon@0000050?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00d@3oool3000004`0oooo003B0?ooo`030000003oool0oooo04/0oooo001V0?oo
o`030000003oool0000000<0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000020?oo
o`<000000`3oool3000000@0oooo0`0000020?ooo`<0000000<0oooo0000000000000P3oool20000
00P0oooo1@0000001@3oool00000000000000000oooo008000000P3oool2000000<0oooo0`000002
0?ooo`<0000000<0oooo000000000000100000020?ooo`D000000`3oool2000000@0oooo00<00000
0?ooo`3oool0BP3oool006H0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`000004
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`040000003oool0oooo000000D0
oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0BP3oool006H0oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?oo
o`0000000P3oool500000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo1@0000020?ooo`040000003oool0oooo00000080oooo0`0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0000001;0?ooo`00
I@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo0`0000030?ooo`800000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?oo
o`000000oooo000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000004/0oooo001U0?ooo`050000003oool000000?ooo`0000000P3oool2000000<0
oooo0P0000000`3oool00000000000020?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`80
000000<0oooo0000000000000P3oool300000080oooo100000020?ooo`@000002P3oool010000000
oooo0?ooo`3oool400000080oooo100000030?ooo`<000000P3oool4000000<0oooo10000000103o
ool000000000000000030?ooo`@000000P3oool2000000030?ooo`000000000004X0oooo001U0?oo
o`050000003oool000000?ooo`000000503oool010000000oooo0?ooo`00000D0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0540oooo001U0?ooo`H000004P3oool5000001@0oooo00<000000?ooo`3oool0203oool5
000000P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0540oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.134655, 70.7363, \
0.000849626, 0.000784197}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.76191 4.53255 0.00350097 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06882 -30 -4.5 ]
[-0.0125 .06882 0 4.5 ]
[-0.0125 .15634 -30 -4.5 ]
[-0.0125 .15634 0 4.5 ]
[-0.0125 .24387 -30 -4.5 ]
[-0.0125 .24387 0 4.5 ]
[-0.0125 .33139 -30 -4.5 ]
[-0.0125 .33139 0 4.5 ]
[-0.0125 .41892 -30 -4.5 ]
[-0.0125 .41892 0 4.5 ]
[-0.0125 .50644 -30 -4.5 ]
[-0.0125 .50644 0 4.5 ]
[-0.0125 .59396 -30 -4.5 ]
[-0.0125 .59396 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06882 m
.00625 .06882 L
s
[(-1275)] -0.0125 .06882 1 0 Mshowa
0 .15634 m
.00625 .15634 L
s
[(-1250)] -0.0125 .15634 1 0 Mshowa
0 .24387 m
.00625 .24387 L
s
[(-1225)] -0.0125 .24387 1 0 Mshowa
0 .33139 m
.00625 .33139 L
s
[(-1200)] -0.0125 .33139 1 0 Mshowa
0 .41892 m
.00625 .41892 L
s
[(-1175)] -0.0125 .41892 1 0 Mshowa
0 .50644 m
.00625 .50644 L
s
[(-1150)] -0.0125 .50644 1 0 Mshowa
0 .59396 m
.00625 .59396 L
s
[(-1125)] -0.0125 .59396 1 0 Mshowa
.125 Mabswid
0 .08632 m
.00375 .08632 L
s
0 .10383 m
.00375 .10383 L
s
0 .12133 m
.00375 .12133 L
s
0 .13884 m
.00375 .13884 L
s
0 .17385 m
.00375 .17385 L
s
0 .19135 m
.00375 .19135 L
s
0 .20886 m
.00375 .20886 L
s
0 .22636 m
.00375 .22636 L
s
0 .26137 m
.00375 .26137 L
s
0 .27888 m
.00375 .27888 L
s
0 .29638 m
.00375 .29638 L
s
0 .31389 m
.00375 .31389 L
s
0 .3489 m
.00375 .3489 L
s
0 .3664 m
.00375 .3664 L
s
0 .38391 m
.00375 .38391 L
s
0 .40141 m
.00375 .40141 L
s
0 .43642 m
.00375 .43642 L
s
0 .45393 m
.00375 .45393 L
s
0 .47143 m
.00375 .47143 L
s
0 .48894 m
.00375 .48894 L
s
0 .52395 m
.00375 .52395 L
s
0 .54145 m
.00375 .54145 L
s
0 .55895 m
.00375 .55895 L
s
0 .57646 m
.00375 .57646 L
s
0 .05131 m
.00375 .05131 L
s
0 .03381 m
.00375 .03381 L
s
0 .0163 m
.00375 .0163 L
s
0 .61147 m
.00375 .61147 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06882 m
1 .06882 L
s
.99375 .15634 m
1 .15634 L
s
.99375 .24387 m
1 .24387 L
s
.99375 .33139 m
1 .33139 L
s
.99375 .41892 m
1 .41892 L
s
.99375 .50644 m
1 .50644 L
s
.99375 .59396 m
1 .59396 L
s
.125 Mabswid
.99625 .08632 m
1 .08632 L
s
.99625 .10383 m
1 .10383 L
s
.99625 .12133 m
1 .12133 L
s
.99625 .13884 m
1 .13884 L
s
.99625 .17385 m
1 .17385 L
s
.99625 .19135 m
1 .19135 L
s
.99625 .20886 m
1 .20886 L
s
.99625 .22636 m
1 .22636 L
s
.99625 .26137 m
1 .26137 L
s
.99625 .27888 m
1 .27888 L
s
.99625 .29638 m
1 .29638 L
s
.99625 .31389 m
1 .31389 L
s
.99625 .3489 m
1 .3489 L
s
.99625 .3664 m
1 .3664 L
s
.99625 .38391 m
1 .38391 L
s
.99625 .40141 m
1 .40141 L
s
.99625 .43642 m
1 .43642 L
s
.99625 .45393 m
1 .45393 L
s
.99625 .47143 m
1 .47143 L
s
.99625 .48894 m
1 .48894 L
s
.99625 .52395 m
1 .52395 L
s
.99625 .54145 m
1 .54145 L
s
.99625 .55895 m
1 .55895 L
s
.99625 .57646 m
1 .57646 L
s
.99625 .05131 m
1 .05131 L
s
.99625 .03381 m
1 .03381 L
s
.99625 .0163 m
1 .0163 L
s
.99625 .61147 m
1 .61147 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06882 m
1 .06882 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .60332 m
.05372 .58483 L
.08634 .56467 L
.11698 .54574 L
.14644 .52753 L
.1778 .50815 L
.20799 .48949 L
.24008 .46966 L
.27099 .45055 L
.30073 .43217 L
.33237 .41262 L
.36283 .39379 L
.39213 .37569 L
.42332 .35641 L
.45333 .33786 L
.48525 .31813 L
.51599 .29913 L
.54556 .28086 L
.57703 .26141 L
.60732 .24269 L
.63951 .22279 L
.67053 .20362 L
.70038 .18518 L
.73212 .16556 L
.76269 .14666 L
.79209 .12849 L
.82339 .10915 L
.85351 .09054 L
.88553 .07075 L
.91638 .05168 L
.94605 .03334 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00903oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002X0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000;@3oool200000300oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000:P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000D0oooo000S0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool09P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo000L0?ooo`D000000P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0240oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0Y0?oo
o`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`040?ooo`008`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02T0oooo00@000000?ooo`3oool00000;P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00@0oooo000S0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000
000/0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool01@000000
oooo0?ooo`000000oooo00@00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo000S0?ooo`040000003oool0oooo000000P0oooo0P00000Z0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00000_0?ooo`040000003oool0oooo0000
02h0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000002`0oooo
00@000000?ooo`3oool00000203oool2000000H0oooo000T0?ooo`8000002P3oool00`000000oooo
0?ooo`0Y0?ooo`8000002P3oool200000080oooo1@00000/0?ooo`800000<03oool2000000X0oooo
0P0000020?ooo`D00000:@3oool2000000X0oooo00<000000?ooo`3oool0103oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00280oooon@0000050?ooo`008P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo0780oooo0P0000050?ooo`030000003oool0oooo
00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0
oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo06l0oooo
0P0000080?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0K@3oool2000000X0oooo00<000000?ooo`3oool00`3oool00280oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool00280oooo0P00001j0?ooo`030000003oool0oooo06X0oooo0P00000<0?oo
o`8000001@3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1X0?ooo`80
00003`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo06D0oooo0P00000B0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?ooo`1S0?ooo`8000004`3oool2
000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00080?ooo`<000000P3oool5000000<0
oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`1P0?ooo`8000005`3oool00`000000oooo0?ooo`030?ooo`002@3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1N0?oo
o`8000006@3oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000000000000`0000030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3ooooi000000D0oooo00090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000<000001@3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`00203o
ool2000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`00
0000203oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo05P0oooo0P00000O0?ooo`03
0000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D00000
00<0oooo0000000000000`0000040?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
EP3oool200000240oooo00<000000?ooo`3oool00`3oool00280oooo0P00001j0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0803oool2000000D0oooo000R0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0D`3oool2000002@0oooo00<000000?ooo`3oool00`3oool0
0280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`1@0?ooo`8000009`3oool00`000000oooo0?ooo`030?ooo`008P3oool2000007X0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0V0?ooo`8000001@3oool00280oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1<
0?ooo`800000:`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo04X0oooo0P00000]0?ooo`030000003oool0oooo00<0oooo000R0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0B03oool2000002l0oooo00<000000?ooo`3o
ool00`3oool00280oooo0P00001j0?ooo`030000003oool0oooo04H0oooo0P00000`0?ooo`800000
1@3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`140?ooo`800000<`3o
ool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo0440oooo0P00000f0?ooo`030000003oool0oooo
00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03D0
oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`030?ooo`00203oool300000080oooo1@00
00020?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0m0?ooo`800000>P3oool00`000000oooo0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`02
0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool00`3oool000030?ooo`000000000000<00000
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`<00000N@3oool00`000000oooo0?ooo`0j0?ooo`80
0000>`3oool3000000D0oooo00090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`0h0?ooo`800000?`3oool00`000000oooo0?ooo`030?ooo`00
2@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`0000030?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool00`3oool000P0oooo0P0000030?ooo`07
0000003oool0oooo0?ooo`000000oooo000000060?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`0e0?ooo`800000@P3oool00`000000oooo0?oo
o`030?ooo`002@3oool00`000000oooo0?ooo`020?ooo`<000000P3oool5000000<0oooo0P000005
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool2000004@0oooo00<00000
0?ooo`3oool00`3oool00280oooo0P00001j0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0@`3oool2000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0<03oool2000004L0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`0^0?ooo`800000B@3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`030?ooo`008P3oool2000007X0oooo00<000000?ooo`3oool0:`3oool2
000004/0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
02T0oooo0P00001>0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00<0
oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool09P3oool200000540oooo
00<000000?ooo`3oool00`3oool00280oooo0P00001j0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0D03oool2000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool08`3oool2000005@0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0Q0?ooo`800000EP3oool00`000000oooo0?ooo`030?oo
o`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo01h0oooo0P00001I0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000NP3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05P0oooo0P0000050?ooo`00203oool3
00000080oooo1@0000000`3oool000000000000300000080oooo0`0000050?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool06`3oool2000005`0oooo00<000000?ooo`3oool00`3oool0
00T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo
00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`030?ooo`002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<00000N@3oool00`000000oooo0?ooo`0G
0?ooo`800000GP3oool3000000D0oooo00090?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo000000030?ooo`030000003oool0000000<000001@3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo01D0oooo0P00001R0?ooo`030000003oool0oooo00<0oooo00080?oo
o`8000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0000
00080?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool04`3oool2000006@0oooo00<0
00000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0`000002
0?ooo`D00000103oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0140oooo0P00001V
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?ooo`0?0?oo
o`800000I`3oool2000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0303oool2000006/0oooo00<000000?ooo`3oool0
0`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0:0?ooo`800000K@3o
ool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`030?ooo`008P3oool20000
07X0oooo00<000000?ooo`3oool01`3oool2000006l0oooo0P0000050?ooo`008P3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00@0oooo
0P00001c0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00<0oooo000R
0?ooo`800000NP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07<0oooo0P000005
0?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00800000M`3oool00`00
0000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`<00000N@3oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1h0?ooo`800000N`3oool00`000000oooo
0?ooo`030?ooo`008P3oool2000007L0oooo0P0000000`3oool000000?ooo`1i0?ooo`8000001@3o
ool00280oooo00<000000?ooo`3oool0M03oool2000000<0oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`030?ooo`00203oool300000080oooo1@0000030?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1a0?ooo`8000001P3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00<0oooo00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1_0?ooo`800000203oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool3000006h0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1g0?ooo`<000001@3oool000T0oooo
00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06`0oooo0P00000;
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000P0oooo0P0000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00P3o
ool3000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1Y0?ooo`8000003P3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000J@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07P0oooo0P0000050?ooo`008P3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1U0?ooo`8000004P3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo
000R0?ooo`800000H`3oool2000001D0oooo00<000000?ooo`3oool0N03oool2000000D0oooo000R
0?ooo`030000003oool0oooo0600oooo0P00000G0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3o
ool0G@3oool2000001X0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00
8P3oool00`000000oooo0?ooo`1K0?ooo`800000703oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00<0oooo000R0?ooo`800000F`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo07P0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1H0?ooo`8000007`3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo
05H0oooo0P00000Q0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool00`3oool00280oooo0P00001D0?ooo`800000903oool00`000000oooo
0?ooo`1h0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000P0oooo0`000003
0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`03
0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C`3oool2
000002P0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000
000000000`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0`00001=0?ooo`800000:P3oool00`00
0000oooo0?ooo`1g0?ooo`<000001@3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1;0?ooo`800000;03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0
oooo00090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
00000003000000D0oooo00<000000?ooo`3oool0B@3oool2000002h0oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`030?ooo`00203oool2000000@0oooo0P0000030?ooo`070000003o
ool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0oooo04L0oooo0P00000`0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`3oool5000000030?ooo`000000000000<00000103oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`030?ooo`008P3oool2000004D0oooo0P00000c0?ooo`030000003oool0oooo07P0oooo
0P0000050?ooo`008P3oool00`000000oooo0?ooo`120?ooo`800000=@3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?oo
o`030000003oool0oooo03l0oooo0P00000h0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool00`3oool00280oooo0P00000o0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0N03oool2000000D0oooo000R0?ooo`030000003oool0oooo03`0oooo0P00000k0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3o
ool00280oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo0P00000i0?ooo`800000?`3oool00`00
0000oooo0?ooo`1h0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo
00<000000?ooo`3oool0=@3oool200000480oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0c0?ooo`800000A03oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?oo
o`800000<@3oool2000004L0oooo00<000000?ooo`3oool0N03oool2000000D0oooo00080?ooo`<0
00000`3oool3000000<0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`0^0?ooo`80
0000B@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0/0?ooo`800000B`3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00000`3oool0000000000003000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`800000C@3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0080oooo0`00000X0?ooo`800000C`3oool00`000000oooo0?ooo`1g0?ooo`<000001@3oool000T0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool4000000<0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00203oool2000000@0oooo0P0000030?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0U
0?ooo`800000DP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00090?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`8000001@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`030?ooo`008P3oool2000002@0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`1h0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool08@3oool2000005H0
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0N0?ooo`800000F@3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`8000007@3oool2000005/0oooo00<00000
0?ooo`3oool0N03oool2000000D0oooo000R0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`03
0000003oool0oooo01T0oooo0P00001N0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool00`3oool00280oooo00<000000?ooo`3oool05`3oool200000600oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool2
000001D0oooo0P00001S0?ooo`030000003oool0oooo07P0oooo0P0000050?ooo`008P3oool00`00
0000oooo0?ooo`0B0?ooo`800000I@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
00<0oooo000R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo00l0oooo
0P00001X0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo0P00
000>0?ooo`800000JP3oool00`000000oooo0?ooo`1h0?ooo`8000001@3oool00280oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool000P0oooo0`0000030?ooo`<000000P3oool500000080oooo0`0000050?oo
o`030000003oool0oooo00X0oooo0P00001]0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool00`3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`06
0000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo00<0oooo00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool30000
00L0oooo0P00001`0?ooo`030000003oool0oooo07L0oooo0`0000050?ooo`002@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P00001b0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`0000050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0
oooo00080?ooo`800000103oool2000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`<000000P3oool5000000@0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000103oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000D0oooo
000R0?ooooT000001@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool003D0oooo
0`00002:0?ooo`030000003oool0oooo02/0oooo0`00000E0?ooo`030000003oool0oooo01D0oooo
000f0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01@0oooo000`0?ooo`<000000`3oool3000000@0oooo0P000002
0?ooo`D000000P3oool3000000<0oooo100000000`3oool0000000000003000000L0oooo0`000004
0?ooo`@000000`3oool200000080oooo1P0000060?ooo`@000000P3oool5000000030?ooo`000000
000000<0000000<0oooo0000000000000`0000020?ooo`<000000P3oool3000000@0oooo0`000002
0?ooo`<0000000@0oooo000000000000oooo0`0000030?ooo`<000002@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0000000<0oooo100000030?ooo`030000003oool0oooo0080oooo0`00
00020?ooo`D000000P3oool300000080oooo0`000000103oool000000000003oool4000000<0oooo
0P0000020?ooo`X000001@3oool00`000000oooo0?ooo`0C0?ooo`00;`3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0C0?ooo`00;`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3o
ool3000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`<000000`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool0oooo1@0000020?ooo`030000003oool0oooo0080oooo1@0000020?ooo`060000003oool0oooo
0000003oool000001@3oool5000000P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000
003oool000000080oooo0`0000030?ooo`030000003oool000000080oooo1@0000030?ooo`040000
003oool0oooo0?ooo`D000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@00000
0?ooo`3oool000001@3oool010000000oooo0?ooo`0000020?ooo`<000001@3oool00`000000oooo
0?ooo`0C0?ooo`00;`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool30000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`04
0000003oool0oooo000000D0oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`030000003o
ool0oooo01<0oooo000_0?ooo`060000003oool0oooo0?ooo`000000oooo100000020?ooo`@00000
0P3oool3000000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`040000
003oool0oooo00000080oooo0P0000030?ooo`@000000`3oool3000000T0oooo00D000000?ooo`3o
ool000000?ooo`03000000@0oooo100000020?ooo`@000000P3oool300000080oooo0P0000000`3o
ool00000000000020?ooo`<000000P3oool4000000<0oooo0`0000030?ooo`<000002@3oool00`00
0000oooo0?ooo`020?ooo`H0000000<0oooo0000000000000`3oool2000000030?ooo`0000000000
0080oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000020?ooo`@000000`3oool90000
00<0oooo0`0000030?ooo`@00000103oool00`000000oooo0?ooo`0C0?ooo`00;`3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`09
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00300oooo0`000009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool3000000T0oooo10000009
0?ooo`030000003oool0oooo0080oooo0P00000:0?ooo`@00000103oool00`000000oooo0?ooo`04
0?ooo`800000103oool2000002h0oooo00<000000?ooo`3oool0603oool3000001H0oooo00<00000
0?ooo`3oool00P3oool2000000/0oooo00<000000?ooo`3oool05@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.134655, -1308.63, \
0.000849626, 1.15564}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-10.477741155507537`\), 
                      11.43635881489974`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-10.477741155507537`\), 
                      11.43635881489974`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {107.52678245056468`, 
                117.36450138109524`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(PlotDomain \[Rule] {\(-0.1`\), 0.1`}\), 
            ",", \(RayBoundary \[Rule] {\(-10.477741155507537`\), 
                11.43635881489974`}\), ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-10.477741155507537`\), 
                      11.43635881489974`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\)}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.43635881489974`\), 
                      10.477741155507537`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.43635881489974`\), 
                      10.477741155507537`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {107.52678245056468`, 
                117.36450138109524`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(PlotDomain \[Rule] {\(-0.1`\), 0.1`}\), 
            ",", \(RayBoundary \[Rule] {\(-11.43635881489974`\), 
                10.477741155507537`}\), ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.43635881489974`\), 
                      10.477741155507537`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\)}], 
          "}"}]}], "}"}]], "Output",
  CellLabel->"Out[28]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["wavefront = FindWaveFronts[sys,PlotDomain->{-.1,.1}]", "Input",
  CellLabel->"In[29]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.76191 -735.446 6.58076 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0205 -36 -4.5 ]
[-0.0125 .0205 0 4.5 ]
[-0.0125 .15212 -36 -4.5 ]
[-0.0125 .15212 0 4.5 ]
[-0.0125 .28373 -30 -4.5 ]
[-0.0125 .28373 0 4.5 ]
[-0.0125 .41535 -36 -4.5 ]
[-0.0125 .41535 0 4.5 ]
[-0.0125 .54697 -36 -4.5 ]
[-0.0125 .54697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0205 m
.00625 .0205 L
s
[(111.76)] -0.0125 .0205 1 0 Mshowa
0 .15212 m
.00625 .15212 L
s
[(111.78)] -0.0125 .15212 1 0 Mshowa
0 .28373 m
.00625 .28373 L
s
[(111.8)] -0.0125 .28373 1 0 Mshowa
0 .41535 m
.00625 .41535 L
s
[(111.82)] -0.0125 .41535 1 0 Mshowa
0 .54697 m
.00625 .54697 L
s
[(111.84)] -0.0125 .54697 1 0 Mshowa
.125 Mabswid
0 .05341 m
.00375 .05341 L
s
0 .08631 m
.00375 .08631 L
s
0 .11922 m
.00375 .11922 L
s
0 .18502 m
.00375 .18502 L
s
0 .21793 m
.00375 .21793 L
s
0 .25083 m
.00375 .25083 L
s
0 .31664 m
.00375 .31664 L
s
0 .34954 m
.00375 .34954 L
s
0 .38245 m
.00375 .38245 L
s
0 .44825 m
.00375 .44825 L
s
0 .48116 m
.00375 .48116 L
s
0 .51406 m
.00375 .51406 L
s
0 .57987 m
.00375 .57987 L
s
0 .61277 m
.00375 .61277 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0205 m
1 .0205 L
s
.99375 .15212 m
1 .15212 L
s
.99375 .28373 m
1 .28373 L
s
.99375 .41535 m
1 .41535 L
s
.99375 .54697 m
1 .54697 L
s
.125 Mabswid
.99625 .05341 m
1 .05341 L
s
.99625 .08631 m
1 .08631 L
s
.99625 .11922 m
1 .11922 L
s
.99625 .18502 m
1 .18502 L
s
.99625 .21793 m
1 .21793 L
s
.99625 .25083 m
1 .25083 L
s
.99625 .31664 m
1 .31664 L
s
.99625 .34954 m
1 .34954 L
s
.99625 .38245 m
1 .38245 L
s
.99625 .44825 m
1 .44825 L
s
.99625 .48116 m
1 .48116 L
s
.99625 .51406 m
1 .51406 L
s
.99625 .57987 m
1 .57987 L
s
.99625 .61277 m
1 .61277 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.05372 .0332 L
.08634 .05336 L
.11698 .0723 L
.14644 .09051 L
.1778 .10989 L
.20799 .12855 L
.24008 .14838 L
.27099 .16748 L
.30073 .18586 L
.33237 .20542 L
.36283 .22424 L
.39213 .24235 L
.42332 .26162 L
.45333 .28018 L
.48525 .2999 L
.51599 .3189 L
.54556 .33717 L
.57703 .35662 L
.60732 .37535 L
.63951 .39524 L
.67053 .41441 L
.70038 .43286 L
.73212 .45248 L
.76269 .47137 L
.79209 .48954 L
.82339 .50888 L
.85351 .5275 L
.88553 .54729 L
.91638 .56635 L
.94605 .58469 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002X0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000;03oool2000002l0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000:P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000<0oooo000W0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool09P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo000P0?ooo`D000000P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0240oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0X0?oo
o`040000003oool0oooo000002d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`020?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo0080oooo000W0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000
000[0?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool00000203oool01@000000
oooo0?ooo`000000oooo00@00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo0080oooo000W0?ooo`040000003oool0oooo000000P0oooo0P00000Z0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00000^0?ooo`040000003oool0oooo0000
02d0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000002`0oooo
00@000000?ooo`3oool00000203oool2000000@0oooo000X0?ooo`8000002P3oool00`000000oooo
0?ooo`0Y0?ooo`8000002P3oool200000080oooo1@00000[0?ooo`800000;`3oool2000000X0oooo
0P0000020?ooo`D00000:@3oool2000000X0oooo00<000000?ooo`3oool00P3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool002L0oooom@0000040?ooo`009`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo0000103oool000000000000000030?ooo`<000000`3oool3000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2
000007<0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003oool0
oooo0700oooo00<000000?ooo`3oool0MP3oool2000000@0oooo00020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00@000001@3oool00`000000oooo0?ooo`050?ooo`800000L03oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo0080oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool01`3oool2000006h0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`00
00<0oooo000000000000103oool2000000@0oooo0P0000090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`D00000
0`3oool2000000D0oooo00<000000?ooo`3oool02P3oool2000006/0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0<0?ooo`800000J@3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0
oooo00h0oooo0P00001W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool0
02L0oooo00<000000?ooo`3oool0403oool2000006D0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0B0?ooo`800000H`3oool00`000000
oooo0?ooo`1f0?ooo`800000103oool002L0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<0
00000?ooo`3oool05@3oool200000600oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`020?ooo`009`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo05`0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?oo
o`009`3oool00`000000oooo0?ooo`0I0?ooo`800000G03oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003o
ool0oooo01`0oooo0P00001I0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3o
ool002L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo07H0oooo0P0000040?ooo`009`3oool00`000000
oooo0?ooo`0P0?ooo`800000E@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080
oooo000W0?ooo`030000003oool0oooo0280oooo0P00001C0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0903oool200000540oooo00<0
00000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0V
0?ooo`800000C`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?oo
o`030000003oool0oooo02P0oooo0P00001=0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool00P3oool002L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0
:`3oool2000004X0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0MP3o
ool2000000@0oooo000W0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
02l0oooo0P0000160?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0<P3oool2000004<0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`0000@0oooo0000000000000000
0`3oool3000000<0oooo0`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool3000000D0oooo00<000000?ooo`3oool0=03oool200000440oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=`3oool2000003h0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`3oool3000000D0oooo0P00000j0?ooo`800000?03oool00`000000oooo0?ooo`1f0?ooo`800000
103oool00080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03/0oooo0P00000j0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3o
ool000030?ooo`000000000000@0oooo0P0000040?ooo`8000002@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo
0P00000h0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool00080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo1@00
00020?ooo`<000001@3oool00`000000oooo0?ooo`0o0?ooo`800000=P3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?oo
o`030000003oool0oooo0480oooo0P00000c0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool00P3oool002L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool0AP3oool2000002l0oooo00<000000?ooo`3oool0MP3o
ool2000000@0oooo000W0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
04T0oooo0P00000/0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0B`3oool2000002X0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?oo
o`1>0?ooo`8000009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W
0?ooo`030000003oool0oooo0500oooo0P00000U0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3o
ool0D`3oool200000280oooo00<000000?ooo`3oool0MP3oool2000000@0oooo000W0?ooo`030000
003oool0oooo05D0oooo0P00000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0F03oool2
000001d0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`00
0000oooo0?ooo`1J0?ooo`8000006`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0080oooo000W0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo05d0oooo
0P00000H0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<0
00000?ooo`3oool0G`3oool2000001H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`020?ooo`009`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0MP3oool2000000@0oooo000W0?ooo`030000003oool0oooo0680oooo0P00000C0?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3o
ool0I03oool200000140oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`00
9`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1W0?ooo`8000003P3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00070?ooo`<000000`3oool3
000000<0oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0
oooo06T0oooo0P00000<0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool0
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1/0?ooo`8000002@3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`<000001@3oool20000
06l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1f0?ooo`800000103oool000P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo06l0oooo0P0000060?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool000L0oooo0P0000040?ooo`80
0000103oool2000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0740oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0080oooo00080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`<000001@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo
0?ooo`1c0?ooo`8000000P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo
000W0?ooo`030000003oool0oooo07D0oooo0`00001i0?ooo`030000003oool0oooo0080oooo000W
0?ooo`030000003oool0oooo07L0oooo0P00001h0?ooo`030000003oool0oooo0080oooo000W0?oo
o`030000003oool0oooo07L0oooo00@000000?ooo`0000000000MP3oool00`000000oooo0?ooo`02
0?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`040000003oool0oooo0?ooo`800000L`3oool2
000000@0oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool0103oool200000740oooo00<000000?ooo`3oool00P3oool002L0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool00P3oool002L0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`080?ooo`800000K@3oool00`000000oooo0?ooo`02
0?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0JP3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo00/0oooo0P00001Z0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool03@3oool2000006L0oooo0P0000040?ooo`009`3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo0100oooo0P00001U0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool04P3oool2000006<0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`0E0?ooo`800000H03oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo01L0oooo0P00001N0?ooo`030000003oool0oooo0080oooo000W
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool06P3oool2000005X0oooo0P0000040?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo01`0oooo0P00001I0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool07`3o
ool2000005H0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool00P3oool0
02L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0R0?ooo`800000D`3oool00`00
0000oooo0?ooo`020?ooo`0000@0oooo00000000000000000`3oool3000000<0oooo0`0000040?oo
o`030000003oool0oooo0080oooo0`0000020?ooo`D00000103oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo02@0oooo0P00001A0?ooo`030000003oool0oooo0080oooo00020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo0080oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`800000N03oool00`000000oooo0?ooo`0W0?ooo`800000C@3oool2000000@0oooo00020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0:@3oool2000004`0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`02
0?ooo`0000<0oooo000000000000103oool2000000@0oooo0P0000090?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`0/0?ooo`800000B@3oool00`000000oooo0?ooo`020?ooo`000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool3
000000<0oooo0`0000050?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0;P3oool2
000004L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0a0?ooo`800000A03oool00`000000
oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03<0oooo
0P0000120?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0n0?ooo`800000103oool002L0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`0f0?ooo`800000?`3oool00`000000oooo0?ooo`02
0?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo03T0oooo0P00000l0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool0?@3oool2000003P0oooo00<000000?ooo`3oool00P3oool0
02L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0o0?ooo`800000=P3oool00`00
0000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0<P3oool2000000@0oooo000W0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0@P3oool2000003<0oooo00<000000?ooo`3oool00P3oool002L0oooo00<0
00000?ooo`3oool0M`3oool00`000000oooo0?ooo`140?ooo`800000<@3oool00`000000oooo0?oo
o`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo04L0oooo0P00000^0?ooo`030000003oool0oooo0080oooo000W0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0B@3oool2000002`0oooo00<000000?ooo`3o
ool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`1<0?ooo`800000:@3oool00`000000oooo0?ooo`020?ooo`009`3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool09@3oool2
000000@0oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0C`3oool20000
02H0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool002L0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`1C0?ooo`8000008P3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo05D0oooo0P00000P0?ooo`030000003oool0oooo0080oooo0000103o
ool000000000000000030?ooo`<000000`3oool3000000@0oooo00<000000?ooo`3oool00P3oool3
000000@0oooo0`0000040?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0E`3oool2
000001h0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1I
0?ooo`800000703oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01P000000oooo0?ooo`3oool0
00000?ooo`D00000103oool2000007P0oooo00<000000?ooo`3oool0F`3oool2000001T0oooo0P00
00040?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0203oool300000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`020?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo05h0oooo0P00000G0?ooo`030000003o
ool0oooo0080oooo00000`3oool00000000000040?ooo`800000103oool2000000T0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`8000001@3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0600oooo0P00000E0?ooo`030000003oool0oooo0080oooo00020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`<000001@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0HP3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0H`3oool200000180oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`1V0?ooo`8000003`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool02`3oool2000000@0oooo000W
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0JP3oool2000000/0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`1/0?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`00
9`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo06h0oooo0P0000070?ooo`030000
003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0L03o
ool2000000D0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
02L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0080oooo000W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0>03oool010000000
oooo0?ooo`3oool2000000@0oooo000W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool002L0oooom@0000040?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00<P3oool3000005P0oooo0`00000G0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool0303oool003<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool02`3oool002d0oooo0`0000030?ooo`<00000103o
ool200000080oooo1@0000020?ooo`<000000`3oool4000000030?ooo`000000000000<000001`3o
ool3000000@0oooo100000030?ooo`8000000P3oool6000000H0oooo1@0000020?ooo`<000000P3o
ool3000000040?ooo`00000000000?ooo`@000000`3oool200000080oooo1P0000070?ooo`030000
003oool0oooo00<0oooo100000000`3oool000000000000200000080oooo100000030?ooo`<00000
0P3oool5000000<0oooo0P000000103oool000000?ooo`3oool2000000<0oooo0`0000090?ooo`@0
000000<0oooo0000000000000`0000000`3oool0000000000002000000@0oooo0P0000030?ooo`@0
000000D0oooo00000000000000000?ooo`02000000040?ooo`0000000000000000<0oooo0`000005
0?ooo`030000003oool0oooo00X0oooo000/0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool00000
0?ooo`0000060?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`00
00020?ooo`060000003oool0oooo0000003oool000002`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003o
ool0000000P0oooo00<000000?ooo`3oool02P3oool002`0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool0000000H0oooo0`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo0080oooo1@0000020?ooo`060000003oool0oooo0000003oool000000`3o
ool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool00`3oool3000000<0oooo00@000000?ooo`3oool000000P3oool300000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`D000001`3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0080oooo0`0000030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`060000
003oool0oooo0000003oool000001@3oool5000000@0oooo00<000000?ooo`3oool02P3oool002`0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0`0000020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo
0000003oool000000`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`060000003oool0oooo
0000003oool000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000070?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo000/0?ooo`060000003oool0oooo0?ooo`000000oooo10000002
0?ooo`@000000P3oool3000000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`08
0?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`@000000`3oool3000000T0oooo00<0
00000?ooo`3oool00`3oool300000080oooo100000030?ooo`T000000`3oool3000000T0oooo00<0
00000?ooo`3oool00`3oool2000000@0oooo0`0000030?ooo`@000000P3oool3000000@0oooo00@0
00000?ooo`3oool0oooo0P000000103oool000000000003oool4000000<0oooo0`0000090?ooo`<0
00000P3oool3000000@0oooo100000000`3oool0000000000002000000<0oooo0P0000030?ooo`@0
00000`3oool3000000<0oooo0`0000050?ooo`030000003oool0oooo00X0oooo000/0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool02`3oool002d0oooo0`0000090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03@3oool3000000T0oooo100000090?ooo`030000003oool0oooo0080
oooo0P00000:0?ooo`<000005P3oool00`000000oooo0?ooo`020?ooo`8000003@3oool00`000000
oooo0?ooo`060?ooo`800000403oool3000000X0oooo00<000000?ooo`3oool0403oool2000000@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.138513, 111.749, \
0.000857962, 0.000620831}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.76191 -370.171 3.67801 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02091 -36 -4.5 ]
[-0.0125 .02091 0 4.5 ]
[-0.0125 .11286 -42 -4.5 ]
[-0.0125 .11286 0 4.5 ]
[-0.0125 .20481 -30 -4.5 ]
[-0.0125 .20481 0 4.5 ]
[-0.0125 .29676 -42 -4.5 ]
[-0.0125 .29676 0 4.5 ]
[-0.0125 .38871 -36 -4.5 ]
[-0.0125 .38871 0 4.5 ]
[-0.0125 .48067 -42 -4.5 ]
[-0.0125 .48067 0 4.5 ]
[-0.0125 .57262 -30 -4.5 ]
[-0.0125 .57262 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02091 m
.00625 .02091 L
s
[(100.65)] -0.0125 .02091 1 0 Mshowa
0 .11286 m
.00625 .11286 L
s
[(100.675)] -0.0125 .11286 1 0 Mshowa
0 .20481 m
.00625 .20481 L
s
[(100.7)] -0.0125 .20481 1 0 Mshowa
0 .29676 m
.00625 .29676 L
s
[(100.725)] -0.0125 .29676 1 0 Mshowa
0 .38871 m
.00625 .38871 L
s
[(100.75)] -0.0125 .38871 1 0 Mshowa
0 .48067 m
.00625 .48067 L
s
[(100.775)] -0.0125 .48067 1 0 Mshowa
0 .57262 m
.00625 .57262 L
s
[(100.8)] -0.0125 .57262 1 0 Mshowa
.125 Mabswid
0 .0393 m
.00375 .0393 L
s
0 .05769 m
.00375 .05769 L
s
0 .07608 m
.00375 .07608 L
s
0 .09447 m
.00375 .09447 L
s
0 .13125 m
.00375 .13125 L
s
0 .14964 m
.00375 .14964 L
s
0 .16803 m
.00375 .16803 L
s
0 .18642 m
.00375 .18642 L
s
0 .2232 m
.00375 .2232 L
s
0 .24159 m
.00375 .24159 L
s
0 .25998 m
.00375 .25998 L
s
0 .27837 m
.00375 .27837 L
s
0 .31515 m
.00375 .31515 L
s
0 .33354 m
.00375 .33354 L
s
0 .35193 m
.00375 .35193 L
s
0 .37032 m
.00375 .37032 L
s
0 .4071 m
.00375 .4071 L
s
0 .42549 m
.00375 .42549 L
s
0 .44388 m
.00375 .44388 L
s
0 .46228 m
.00375 .46228 L
s
0 .49906 m
.00375 .49906 L
s
0 .51745 m
.00375 .51745 L
s
0 .53584 m
.00375 .53584 L
s
0 .55423 m
.00375 .55423 L
s
0 .00252 m
.00375 .00252 L
s
0 .59101 m
.00375 .59101 L
s
0 .6094 m
.00375 .6094 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02091 m
1 .02091 L
s
.99375 .11286 m
1 .11286 L
s
.99375 .20481 m
1 .20481 L
s
.99375 .29676 m
1 .29676 L
s
.99375 .38871 m
1 .38871 L
s
.99375 .48067 m
1 .48067 L
s
.99375 .57262 m
1 .57262 L
s
.125 Mabswid
.99625 .0393 m
1 .0393 L
s
.99625 .05769 m
1 .05769 L
s
.99625 .07608 m
1 .07608 L
s
.99625 .09447 m
1 .09447 L
s
.99625 .13125 m
1 .13125 L
s
.99625 .14964 m
1 .14964 L
s
.99625 .16803 m
1 .16803 L
s
.99625 .18642 m
1 .18642 L
s
.99625 .2232 m
1 .2232 L
s
.99625 .24159 m
1 .24159 L
s
.99625 .25998 m
1 .25998 L
s
.99625 .27837 m
1 .27837 L
s
.99625 .31515 m
1 .31515 L
s
.99625 .33354 m
1 .33354 L
s
.99625 .35193 m
1 .35193 L
s
.99625 .37032 m
1 .37032 L
s
.99625 .4071 m
1 .4071 L
s
.99625 .42549 m
1 .42549 L
s
.99625 .44388 m
1 .44388 L
s
.99625 .46228 m
1 .46228 L
s
.99625 .49906 m
1 .49906 L
s
.99625 .51745 m
1 .51745 L
s
.99625 .53584 m
1 .53584 L
s
.99625 .55423 m
1 .55423 L
s
.99625 .00252 m
1 .00252 L
s
.99625 .59101 m
1 .59101 L
s
.99625 .6094 m
1 .6094 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .60332 m
.05372 .58483 L
.08634 .56467 L
.11698 .54574 L
.14644 .52753 L
.1778 .50815 L
.20799 .48949 L
.24008 .46966 L
.27099 .45055 L
.30073 .43217 L
.33237 .41262 L
.36283 .39379 L
.39213 .37569 L
.42332 .35641 L
.45333 .33786 L
.48525 .31813 L
.51599 .29913 L
.54556 .28086 L
.57703 .26141 L
.60732 .24269 L
.63951 .22279 L
.67053 .20362 L
.70038 .18518 L
.73212 .16556 L
.76269 .14666 L
.79209 .12849 L
.82339 .10915 L
.85351 .09054 L
.88553 .07075 L
.91638 .05168 L
.94605 .03334 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00;P3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool3000002P0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<00000
:`3oool2000002h0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<00000
:03oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo000]0?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000080?ooo`06
0000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0W0?ooo`040000003oool0
oooo000002`0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo0080oooo000V0?ooo`D000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo01l0oooo1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo000002`0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02@0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`00;@3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool00000;03oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0903o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo000]0?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000080?ooo`05
0000003oool0oooo0000003oool01000000Z0?ooo`040000003oool0oooo000002`0oooo00@00000
0?ooo`3oool00000203oool01@000000oooo0?ooo`000000oooo00@000009`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo0080oooo000]0?ooo`040000003oool0oooo000000P0
oooo0P00000X0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00
000]0?ooo`040000003oool0oooo000002`0oooo00@000000?ooo`3oool00000203oool01P000000
oooo0?ooo`000000oooo000002X0oooo00@000000?ooo`3oool00000203oool2000000@0oooo000^
0?ooo`8000002P3oool00`000000oooo0?ooo`0W0?ooo`8000002P3oool200000080oooo1@00000Z
0?ooo`800000;P3oool2000000X0oooo0P0000020?ooo`D000009`3oool2000000X0oooo00<00000
0?ooo`3oool00P3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool002`0ooool00000040?ooo`00;03oool2000000@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`800000103oool002`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool000L0oooo0`0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3o
ool00P3oool3000000<0oooo0`0000040?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`020?ooo`00203oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000001`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000007L0oooo00<000000?ooo`3oool0
KP3oool2000000@0oooo00<000000?ooo`3oool00P3oool000P0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`040000003oool0oooo0?ooo`<00000M@3oool00`000000oooo0?ooo`1/
0?ooo`8000001@3oool2000000@0oooo00080?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`@000001P3oool01@000000oooo0?oo
o`3oool0000007L0oooo00<000000?ooo`3oool0JP3oool2000000P0oooo00<000000?ooo`3oool0
0P3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000L0oooo00<000000?ooo`3oool00`3oool4000000@0oooo00<000000?ooo`3o
ool0M@3oool00`000000oooo0?ooo`1X0?ooo`8000002P3oool00`000000oooo0?ooo`020?ooo`00
1`3oool2000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo06H0oooo0P00000<0?ooo`030000003oool0oooo0080oooo00080?ooo`03
0000003oool0oooo00<0oooo0P0000040?ooo`8000002P3oool200000080oooo1@0000030?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`800000MP3oool00`000000oooo0?ooo`1S0?ooo`800000
3P3oool2000000@0oooo000/0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0
oooo07D0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0080oooo000/0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0G`3oool20000
01<0oooo00<000000?ooo`3oool00P3oool002`0oooo0P00001f0?ooo`030000003oool0oooo05d0
oooo0P00000D0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool002`0oooo00<0
00000?ooo`3oool0M@3oool00`000000oooo0?ooo`1J0?ooo`800000603oool00`000000oooo0?oo
o`020?ooo`00;03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo05P0oooo0P00000J
0?ooo`030000003oool0oooo0080oooo000/0?ooo`800000MP3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01T0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`1e0?ooo`03
0000003oool0oooo05D0oooo0P00000M0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000
003oool0oooo07D0oooo00<000000?ooo`3oool0D`3oool2000001l0oooo00<000000?ooo`3oool0
0P3oool002`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`1@0?ooo`8000008P3oool00`000000oooo0?ooo`020?ooo`00;03oool20000
07H0oooo00<000000?ooo`3oool0CP3oool2000002<0oooo0P0000040?ooo`00;03oool00`000000
oooo0?ooo`1e0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`020?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0P0000040?ooo`03
0000003oool0oooo0080oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000040?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool0B`3oool2000002L0oooo00<000000?ooo`3o
ool00P3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000007L0oooo00<000000?ooo`3oool0
B@3oool2000002T0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`00001e
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0:03oool2000000@0oooo00020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00070?ooo`@000001@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
M`3oool00`000000oooo0?ooo`160?ooo`800000;03oool00`000000oooo0?ooo`020?ooo`000P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000<00000103oool00`000000
oooo0?ooo`1e0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`020?ooo`0000<0oooo000000000000103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?ooo`03
0?ooo`800000103oool2000000X0oooo0P0000020?ooo`D0000000<0oooo0000000000000`000003
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0@P3oool200000300oooo00<00000
0?ooo`3oool00P3oool002`0oooo0P00001f0?ooo`030000003oool0oooo0400oooo0P00000a0?oo
o`800000103oool002`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`0m0?ooo`800000=@3oool00`000000oooo0?ooo`020?ooo`00;03o
ool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo03/0oooo0P00000g0?ooo`030000003o
ool0oooo0080oooo000/0?ooo`800000MP3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo03H0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
03P0oooo0P00000j0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0=P3oool2000003`0oooo00<000000?ooo`3oool00P3oool002`0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool00P3oool002`0oooo0P00001f0?ooo`030000003oool0oooo03<0oooo0P00
000n0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0a
0?ooo`800000@@3oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`020?oo
o`00;03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo02h0oooo0P0000140?ooo`03
0000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
;03oool2000004H0oooo00<000000?ooo`3oool00P3oool002`0oooo0P00001f0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0A@3oool2000000@0oooo000/0?ooo`030000003oool0
oooo07D0oooo00<000000?ooo`3oool0:@3oool2000004T0oooo00<000000?ooo`3oool00P3oool0
00d0oooo0`0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo0080oooo000>0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool00P3oool000h0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3o
ool3000007D0oooo00<000000?ooo`3oool09@3oool2000004`0oooo0P0000040?ooo`003P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
8`3oool2000004l0oooo00<000000?ooo`3oool00P3oool000h0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3o
ool0oooo0000001g0?ooo`030000003oool0oooo0240oooo0P00001A0?ooo`030000003oool0oooo
0080oooo000=0?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo07D0oooo00<0
00000?ooo`3oool07`3oool2000005<0oooo00<000000?ooo`3oool00P3oool000h0oooo00<00000
0?ooo`3oool00`3oool2000000@0oooo0P0000080?ooo`D000000`3oool00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo01d0oooo0P00001E0?ooo`030000003oool0oooo0080oooo000/0?oo
o`800000MP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05@0oooo0P0000040?oo
o`00;03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo01X0oooo0P00001H0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
603oool2000005X0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool00P3o
ool002`0oooo0P00001f0?ooo`030000003oool0oooo01D0oooo0P00001L0?ooo`800000103oool0
02`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0M@3oool00`000000
oooo0?ooo`0B0?ooo`800000H03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo
0?ooo`1e0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`020?ooo`00;03oool2000007H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`1P0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0>
0?ooo`800000I03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo00`0oooo0P00001V0?ooo`030000003oool0oooo0080oooo000/0?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
2@3oool2000006T0oooo00<000000?ooo`3oool00P3oool002`0oooo0P00001f0?ooo`030000003o
ool0oooo00L0oooo0P00001Z0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool00P3oool0
00040?ooo`0000000000000000@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo0?ooo`D000000P3oool3000000@0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`040?ooo`800000KP3oool00`000000oooo0?ooo`020?ooo`000P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000`3oool01@00
0000oooo0?ooo`3oool0000007L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1^
0?ooo`030000003oool0oooo0080oooo00020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`3oool3000007D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1^0?ooo`800000103oool00080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000M`3oool00`00
0000oooo0?ooo`0200000780oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`0000000`3oool00`000000oooo00000003000000@0oooo00<000000?ooo`3oool0M@3oool3
000007@0oooo00<000000?ooo`3oool00P3oool000030?ooo`000000000000@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0M03oool2000007H0
oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3oool00`3oool2000000@0oooo
0P0000080?ooo`D000000P3oool300000080oooo1@0000030?ooo`800000L`3oool2000000030?oo
o`000000oooo07@0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`1`0?ooo`8000000`3o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0080oooo000/0?ooo`030000003oool0oooo06d0oooo0P0000060?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0K03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo
0P00001/0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L`3oool2000000@0oooo
000/0?ooo`030000003oool0oooo06T0oooo0P00000:0?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0I`3oool2000000`0oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?oo
o`00;03oool2000006D0oooo0P00000?0?ooo`030000003oool0oooo07<0oooo0P0000040?ooo`00
;03oool00`000000oooo0?ooo`1R0?ooo`8000004@3oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0080oooo000/0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0
oooo05l0oooo0P00000D0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool0
02`0oooo00<000000?ooo`3oool0G@3oool2000001H0oooo00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`020?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1c0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0FP3oool2000001T0oooo
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`001`3oool3000000@0oooo0P00
00040?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`00
00040?ooo`030000003oool0oooo05P0oooo0P00000K0?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00P3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000T0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`000000F@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00P3oool000P0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`3oool3000005D0oooo0P00000N0?ooo`030000003oool0oooo07<0oooo0P00
00040?ooo`00203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
0000E@3oool200000200oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00
203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo00000003000000@0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool000L0
oooo0P0000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000001`3oool00`000000oooo0?ooo`1@0?ooo`800000
8`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080oooo00080?ooo`030000003o
ool0oooo00<0oooo0P0000040?ooo`800000203oool5000000030?ooo`000000000000<000000`3o
ool200000500oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1c0?ooo`800000103o
ool002`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0C03oool20000
02L0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000
oooo0?ooo`1:0?ooo`800000:@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080
oooo000/0?ooo`030000003oool0oooo04P0oooo0P00000[0?ooo`030000003oool0oooo07@0oooo
00<000000?ooo`3oool00P3oool002`0oooo0P0000170?ooo`800000;@3oool00`000000oooo0?oo
o`1c0?ooo`800000103oool002`0oooo00<000000?ooo`3oool0A03oool2000002l0oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?oo
o`00;03oool00`000000oooo0?ooo`110?ooo`800000<P3oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo0080oooo000/0?ooo`800000@@3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo07<0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool0
0`000000oooo0?ooo`0m0?ooo`800000=P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0080oooo000/0?ooo`030000003oool0oooo03/0oooo0P00000h0?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo
0P00000i0?ooo`800000>`3oool00`000000oooo0?ooo`1c0?ooo`800000103oool002`0oooo00<0
00000?ooo`3oool0=P3oool2000003d0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`020?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<00000103o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000003D0oooo0P0000100?oo
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<00000<@3o
ool200000480oooo00<000000?ooo`3oool0L`3oool2000000@0oooo00020?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000380
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080
oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`0000040?oo
o`030000003oool0oooo02h0oooo0P0000150?ooo`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00P3oool000030?ooo`000000000000@0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000070?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000
003oool0000000L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3oool00`3o
ool2000000@0oooo0P0000080?ooo`D0000000<0oooo0000000000000`0000000`3oool000000000
0003000000<0oooo0P00000/0?ooo`800000B03oool00`000000oooo0?ooo`1c0?ooo`800000103o
ool002`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool002`0
oooo00<000000?ooo`3oool09`3oool2000004`0oooo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`0U0?ooo`800000CP3oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0080oooo000/0?ooo`800000903oool200000500oooo00<0
00000?ooo`3oool0L`3oool2000000@0oooo000/0?ooo`030000003oool0oooo0240oooo0P00001B
0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?oo
o`3oool07`3oool2000005@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?oo
o`00;03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool2000001d0oooo0P00001G0?ooo`030000
003oool0oooo07<0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`0H0?ooo`800000F`3oool00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0080oooo000/0?ooo`030000003oool0oooo01H0
oooo0P00001M0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo
0P00000F0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0L`3oool2000000@0oooo
000=0?ooo`<00000103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`00
00040?ooo`030000003oool0oooo01<0oooo0P00001P0?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool00P3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0140oooo0P00001R0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool00P3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo0080oooo000>0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000080?ooo`<00000103oool3000000h0oooo0P00001U0?ooo`030000003o
ool0oooo07<0oooo0P0000040?ooo`003P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0303oool2000006L0oooo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`020?ooo`003@3oool2000000@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`02
0?ooo`003P3oool00`000000oooo0?ooo`030?ooo`800000103oool2000000T0oooo0`0000040?oo
o`030000003oool0oooo00T0oooo0P00001Z0?ooo`030000003oool0oooo07@0oooo00<000000?oo
o`3oool00P3oool002`0oooo0P0000080?ooo`800000K03oool00`000000oooo0?ooo`1c0?ooo`80
0000103oool002`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1/0?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool002`0oooo00<000000?ooo`3oool0103o
ool2000006l0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00;03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`020?ooo`00;03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool00P3oool002`0oooo0P0000040?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03H0
oooo00@000000?ooo`3oool0oooo0P0000040?ooo`00;03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo000/0?oooo000000103oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00=L0oooo0`0000160?ooo`00f03oool00`000000oooo0?ooo`150?ooo`00K03o
ool00`000000oooo000000030?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`<000000P3o
ool3000000<0oooo0`0000040?ooo`<000000P3oool3000000030?ooo`00000000000080oooo0P00
00080?ooo`D0000000D0oooo00000000000000000?ooo`0200000080oooo0P0000030?ooo`<00000
0P3oool3000000030?ooo`000000000000@000000P3oool5000000<0oooo0P0000040?ooo`030000
003oool0oooo04@0oooo001/0?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000
103oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`060000003oool0oooo0000003oool000001P3oool010000000oooo0?ooo`000005
0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo04@0oooo001/0?ooo`030000003oool0000000<0oooo0`0000030?ooo`030000003o
ool000000080oooo1@0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`D000000P3oool010000000oooo0?ooo`0000020?ooo`<00000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000A@3oool0
06/0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`<000000`3oool20000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3o
ool000000?ooo`0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000150?ooo`00J`3oool01@000000oooo0000003oool000000080oooo0P000003
0?ooo`80000000<0oooo0000000000000P3oool3000000<0oooo00<000000?ooo`3oool00P3oool2
000000030?ooo`00000000000080oooo0`0000020?ooo`@000000P3oool4000000X0oooo00@00000
0?ooo`3oool0oooo100000020?ooo`@000000`3oool300000080oooo100000030?ooo`@0000000@0
oooo00000000000000000`3oool400000080oooo0P0000000`3oool00000000000140?ooo`00J`3o
ool01@000000oooo0000003oool0000001@0oooo00@000000?ooo`3oool00000503oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`1;0?ooo`00J`3oool600000180oooo1@00000D0?ooo`030000003oool0oooo00P0oooo
1@0000080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1;0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.144576, 100.628, \
0.000879774, 0.00113904}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.76191 4.53255 0.00350097 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06882 -30 -4.5 ]
[-0.0125 .06882 0 4.5 ]
[-0.0125 .15634 -30 -4.5 ]
[-0.0125 .15634 0 4.5 ]
[-0.0125 .24387 -30 -4.5 ]
[-0.0125 .24387 0 4.5 ]
[-0.0125 .33139 -30 -4.5 ]
[-0.0125 .33139 0 4.5 ]
[-0.0125 .41892 -30 -4.5 ]
[-0.0125 .41892 0 4.5 ]
[-0.0125 .50644 -30 -4.5 ]
[-0.0125 .50644 0 4.5 ]
[-0.0125 .59396 -30 -4.5 ]
[-0.0125 .59396 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06882 m
.00625 .06882 L
s
[(-1275)] -0.0125 .06882 1 0 Mshowa
0 .15634 m
.00625 .15634 L
s
[(-1250)] -0.0125 .15634 1 0 Mshowa
0 .24387 m
.00625 .24387 L
s
[(-1225)] -0.0125 .24387 1 0 Mshowa
0 .33139 m
.00625 .33139 L
s
[(-1200)] -0.0125 .33139 1 0 Mshowa
0 .41892 m
.00625 .41892 L
s
[(-1175)] -0.0125 .41892 1 0 Mshowa
0 .50644 m
.00625 .50644 L
s
[(-1150)] -0.0125 .50644 1 0 Mshowa
0 .59396 m
.00625 .59396 L
s
[(-1125)] -0.0125 .59396 1 0 Mshowa
.125 Mabswid
0 .08632 m
.00375 .08632 L
s
0 .10383 m
.00375 .10383 L
s
0 .12133 m
.00375 .12133 L
s
0 .13884 m
.00375 .13884 L
s
0 .17385 m
.00375 .17385 L
s
0 .19135 m
.00375 .19135 L
s
0 .20886 m
.00375 .20886 L
s
0 .22636 m
.00375 .22636 L
s
0 .26137 m
.00375 .26137 L
s
0 .27888 m
.00375 .27888 L
s
0 .29638 m
.00375 .29638 L
s
0 .31389 m
.00375 .31389 L
s
0 .3489 m
.00375 .3489 L
s
0 .3664 m
.00375 .3664 L
s
0 .38391 m
.00375 .38391 L
s
0 .40141 m
.00375 .40141 L
s
0 .43642 m
.00375 .43642 L
s
0 .45393 m
.00375 .45393 L
s
0 .47143 m
.00375 .47143 L
s
0 .48894 m
.00375 .48894 L
s
0 .52395 m
.00375 .52395 L
s
0 .54145 m
.00375 .54145 L
s
0 .55895 m
.00375 .55895 L
s
0 .57646 m
.00375 .57646 L
s
0 .05131 m
.00375 .05131 L
s
0 .03381 m
.00375 .03381 L
s
0 .0163 m
.00375 .0163 L
s
0 .61147 m
.00375 .61147 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06882 m
1 .06882 L
s
.99375 .15634 m
1 .15634 L
s
.99375 .24387 m
1 .24387 L
s
.99375 .33139 m
1 .33139 L
s
.99375 .41892 m
1 .41892 L
s
.99375 .50644 m
1 .50644 L
s
.99375 .59396 m
1 .59396 L
s
.125 Mabswid
.99625 .08632 m
1 .08632 L
s
.99625 .10383 m
1 .10383 L
s
.99625 .12133 m
1 .12133 L
s
.99625 .13884 m
1 .13884 L
s
.99625 .17385 m
1 .17385 L
s
.99625 .19135 m
1 .19135 L
s
.99625 .20886 m
1 .20886 L
s
.99625 .22636 m
1 .22636 L
s
.99625 .26137 m
1 .26137 L
s
.99625 .27888 m
1 .27888 L
s
.99625 .29638 m
1 .29638 L
s
.99625 .31389 m
1 .31389 L
s
.99625 .3489 m
1 .3489 L
s
.99625 .3664 m
1 .3664 L
s
.99625 .38391 m
1 .38391 L
s
.99625 .40141 m
1 .40141 L
s
.99625 .43642 m
1 .43642 L
s
.99625 .45393 m
1 .45393 L
s
.99625 .47143 m
1 .47143 L
s
.99625 .48894 m
1 .48894 L
s
.99625 .52395 m
1 .52395 L
s
.99625 .54145 m
1 .54145 L
s
.99625 .55895 m
1 .55895 L
s
.99625 .57646 m
1 .57646 L
s
.99625 .05131 m
1 .05131 L
s
.99625 .03381 m
1 .03381 L
s
.99625 .0163 m
1 .0163 L
s
.99625 .61147 m
1 .61147 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06882 m
1 .06882 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.05372 .0332 L
.08634 .05336 L
.11698 .0723 L
.14644 .09051 L
.1778 .10989 L
.20799 .12855 L
.24008 .14838 L
.27099 .16748 L
.30073 .18586 L
.33237 .20542 L
.36283 .22424 L
.39213 .24235 L
.42332 .26162 L
.45333 .28018 L
.48525 .2999 L
.51599 .3189 L
.54556 .33717 L
.57703 .35662 L
.60732 .37535 L
.63951 .39524 L
.67053 .41441 L
.70038 .43286 L
.73212 .45248 L
.76269 .47137 L
.79209 .48954 L
.82339 .50888 L
.85351 .5275 L
.88553 .54729 L
.91638 .56635 L
.94605 .58469 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00903oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002X0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000;@3oool200000300oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000:P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000D0oooo000S0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool09P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo000L0?ooo`D000000P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0240oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0Y0?oo
o`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`040?ooo`008`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02T0oooo00@000000?ooo`3oool00000;P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00@0oooo000S0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000
000/0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool01@000000
oooo0?ooo`000000oooo00@00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo000S0?ooo`040000003oool0oooo000000P0oooo0P00000Z0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00000_0?ooo`040000003oool0oooo0000
02h0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000002`0oooo
00@000000?ooo`3oool00000203oool2000000H0oooo000T0?ooo`8000002P3oool00`000000oooo
0?ooo`0Y0?ooo`8000002P3oool200000080oooo1@00000/0?ooo`800000<03oool2000000X0oooo
0P0000020?ooo`D00000:@3oool2000000X0oooo00<000000?ooo`3oool0103oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00280oooon@0000050?ooo`008P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`00
0000oooo0?ooo`030?ooo`800000M03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
00<0oooo000R0?ooo`8000001P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo07P0
oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`060?ooo`800000L@3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo00P0oooo0P00
001_0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool00280oooo0P00000<0?ooo`800000K03oool00`000000oooo0?ooo`1h0?oo
o`8000001@3oool00280oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0
3P3oool2000006T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`0@0?ooo`800000I`3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`8000004`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo07P0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`0C0?ooo`800000I03oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00080?ooo`<000000P3oool5000000<0
oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000T0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo0P00001Q0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000030?ooo`000000000000<0
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooon@0000050?ooo`002@3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo00000003000000D0oooo00<000000?ooo`3oool0
6P3oool2000005d0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00203o
ool2000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`00
0000203oool00`000000oooo0?ooo`0L0?ooo`800000F`3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D00000
00<0oooo0000000000000`0000040?ooo`030000003oool0oooo01h0oooo0P00001I0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo0P00000Q0?ooo`800000E`3o
ool00`000000oooo0?ooo`1h0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool08P3oool2
000005D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0U0?ooo`800000DP3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000:03oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo07P0oooo0P0000050?ooo`008P3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`030?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`800000CP3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo02/0oooo0P00001<0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3o
ool0;@3oool2000004X0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00
8P3oool200000300oooo0P0000180?ooo`030000003oool0oooo07P0oooo0P0000050?ooo`008P3o
ool00`000000oooo0?ooo`0a0?ooo`800000AP3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo
03@0oooo0P0000130?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280
oooo0P00000g0?ooo`800000@@3oool00`000000oooo0?ooo`1h0?ooo`8000001@3oool00280oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool00`3oool000P0oooo0`0000020?ooo`D000000P3oool3000000@0oooo0P00
00050?ooo`030000003oool0oooo03T0oooo0P00000n0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo00<0oooo00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool3000003`0oooo0P00000k0?ooo`030000003oool0oooo07L0oooo0`0000050?ooo`00
2@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo00000003000000<0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00203oool2000000<0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`100?ooo`800000=`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo0009
0?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D000000`3oool2000000D0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool00280oooo0P0000140?ooo`800000=03oool00`000000oooo0?ooo`1h0?oo
o`8000001@3oool00280oooo00<000000?ooo`3oool0A@3oool200000380oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`180?ooo`800000;`3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`800000B`3oool2000002d0oooo00<000000?ooo`3oool0N03oool2
000000D0oooo000R0?ooo`030000003oool0oooo04`0oooo0P00000[0?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0CP3oool2000002T0
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo
0?ooo`1@0?ooo`8000009`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo
000R0?ooo`800000D`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo07P0oooo0P00
00050?ooo`008P3oool00`000000oooo0?ooo`1C0?ooo`800000903oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo05L0oooo0P00000P0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo0P00001J0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0N03oool2000000D0oooo00080?ooo`<000000P3oool5
000000030?ooo`000000000000<000000P3oool3000000D0oooo00<000000?ooo`3oool0FP3oool2
000001d0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`002@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000030?ooo`00
0000000000<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo0009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo0`00001N0?ooo`8000006@3oool00`000000oooo0?ooo`1g
0?ooo`<000001@3oool000T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000`0000050?ooo`030000003oool0oooo0600oooo0P00000G
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000P0oooo0P0000030?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000P0oooo00<0
00000?ooo`3oool0HP3oool2000001D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`030?ooo`002@3oool00`000000oooo0?ooo`020?ooo`<000000`3oool300000080oooo1@000004
0?ooo`030000003oool0oooo06@0oooo0P00000C0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool00280oooo0P00001W0?ooo`8000004@3oool00`000000oooo0?ooo`1h0?oo
o`8000001@3oool00280oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0
J@3oool2000000h0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool20000
06h0oooo0P00000:0?ooo`030000003oool0oooo07P0oooo0P0000050?ooo`008P3oool00`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1`0?ooo`8000001`3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo0780oooo0P00
00050?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo0P00001e
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0N03oool2000000D0oooo000R0?oo
o`030000003oool0oooo07D0oooo0P0000020?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool00`3oool00280oooo00<000000?ooo`3oool0M`3oool3000007/0oooo00<000000?ooo`3o
ool00`3oool00280oooo00<000000?ooo`3oool0N@3oool2000007X0oooo00<000000?ooo`3oool0
0`3oool00280oooo0P00001j0?ooo`040000003oool00000000007L0oooo0P0000050?ooo`008P3o
ool00`000000oooo0?ooo`1i0?ooo`040000003oool0oooo0?ooo`800000MP3oool00`000000oooo
0?ooo`030?ooo`00203oool300000080oooo1@0000030?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00@0oooo0P00001c0?ooo`030000003oool0oooo00<0
oooo00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00001i
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0K@3oool3000000D0oooo00090?oo
o`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00P0oooo0P00001_0?ooo`030000003oool0oooo00<0oooo00080?ooo`8000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo0080
oooo0`0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`0;0?ooo`800000K03oool00`000000oooo0?ooo`030?ooo`008P3oool2000007X0oooo
00<000000?ooo`3oool03@3oool2000006T0oooo0P0000050?ooo`008P3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0100oooo0P00001W
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool04P3oool2000006D0oooo00<000000?ooo`3oool00`3oool00280oooo0P00001j0?ooo`03
0000003oool0oooo01@0oooo0P00001R0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`0F0?ooo`800000H@3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo01P0oooo0P00001O0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool06`3oool2000005`0oooo00<000000?ooo`3oool00`3oool00280
oooo0P00001j0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F03oool2000000D0
oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool07`3oool2000005P0oooo00<000000?ooo`3oool00`3oool00280oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool00`3oool00280oooo0P00001j0?ooo`030000003oool0oooo0280oooo0P00001D0?oo
o`8000001@3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0T0?ooo`80
0000D`3oool00`000000oooo0?ooo`030?ooo`00203oool3000000<0oooo0`0000040?ooo`030000
003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo02L0oooo
0P00001@0?ooo`030000003oool0oooo00<0oooo00000`3oool0000000000003000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool3000007T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`1;0?ooo`<000001@3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo02X0oooo0P00001=0?ooo`030000003oool0oooo00<0oooo00090?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000030000
00D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0/0?ooo`800000B`3oool00`00
0000oooo0?ooo`030?ooo`00203oool2000000@0oooo0P0000030?ooo`070000003oool0oooo0?oo
o`000000oooo000000080?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool0oooo1@0000000`3oool0000000000003000000@0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0_0?ooo`800000B03oool00`000000oooo0?ooo`03
0?ooo`008P3oool2000007X0oooo00<000000?ooo`3oool0<@3oool2000004D0oooo0P0000050?oo
o`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo03@0oooo0P0000130?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0=P3oool200000440oooo00<000000?ooo`3oool00`3o
ool00280oooo0P00001j0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0?@3oool2
000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0>@3oool20000
03h0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`0k0?ooo`800000?03oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`030?ooo`008P3oool2000007X0oooo00<000000?ooo`3oool0?P3oool2000003P0oooo0P00
00050?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo0440oooo0P00000f0?ooo`030000003oool0oooo00<0oooo000R0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000NP3o
ool00`000000oooo0?ooo`150?ooo`800000<@3oool2000000D0oooo00080?ooo`<000000`3oool3
000000<0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo04L0oooo0P00000`0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo04T0oooo0P00
000^0?ooo`030000003oool0oooo00<0oooo00000`3oool0000000000003000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo04/0oooo0P00
000/0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00
001i0?ooo`030000003oool0oooo04d0oooo0P00000X0?ooo`<000001@3oool000T0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`3oool4000000<0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`030?ooo`00203oool2000000@0oooo0P0000030?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo0500oooo0P00000W0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`8000001@3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`030?ooo`008P3oool2000007X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0R0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1D
0?ooo`8000008`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`030?oo
o`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo05L0oooo0P00000P0?ooo`03
0000003oool0oooo00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?ooo`1I0?ooo`800000
7@3oool2000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0G03oool2000001/0oooo00<000000?ooo`3oool00`3oool0
0280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`1O0?ooo`800000603oool00`000000oooo0?ooo`030?ooo`008P3oool2000007X0oooo
00<000000?ooo`3oool0H@3oool2000001D0oooo0P0000050?ooo`008P3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo06@0oooo0P00000C
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool0IP3oool200000140oooo00<000000?ooo`3oool00`3oool00280oooo0P00001j0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool03@3oool2000000D0oooo000R0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0J@3oool2000000h0oooo00<000000?ooo`3oool0
0`3oool000P0oooo0`0000030?ooo`<000000P3oool500000080oooo0`0000050?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0J`3oool2000000`0oooo00<000000?ooo`3oool00`3o
ool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool3000007T0oooo00<0
00000?ooo`3oool0KP3oool2000000L0oooo0`0000050?ooo`002@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0L03oool2000000L0oooo00<00000
0?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`0000000`0000050?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool0LP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00080?oo
o`800000103oool2000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`<000000P3oool5000000@0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000103oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000D0oooo000R0?ooooT0
00001@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool003D0oooo0`00002:0?oo
o`030000003oool0oooo02/0oooo0`00000E0?ooo`030000003oool0oooo01D0oooo000f0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01@0oooo000`0?ooo`<000000`3oool3000000@0oooo0P0000020?ooo`D00000
0P3oool3000000<0oooo100000000`3oool0000000000003000000L0oooo0`0000040?ooo`@00000
0`3oool200000080oooo1P0000060?ooo`@000000P3oool5000000030?ooo`000000000000<00000
00<0oooo0000000000000`0000020?ooo`<000000P3oool3000000@0oooo0`0000020?ooo`<00000
00@0oooo000000000000oooo0`0000030?ooo`<000002@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000<0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D0
00000P3oool300000080oooo0`000000103oool000000000003oool4000000<0oooo0P0000020?oo
o`X000001@3oool00`000000oooo0?ooo`0C0?ooo`00;`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo00D00000
0?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000001P3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0C0?ooo`00;`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3oool3000000@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo1@00
00020?ooo`030000003oool0oooo0080oooo1@0000020?ooo`060000003oool0oooo0000003oool0
00001@3oool5000000P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool00000
0080oooo0`0000030?ooo`030000003oool000000080oooo1@0000030?ooo`040000003oool0oooo
0?ooo`D000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool0
00001@3oool010000000oooo0?ooo`0000020?ooo`<000001@3oool00`000000oooo0?ooo`0C0?oo
o`00;`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool300000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo008000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`040000003oool0
oooo000000D0oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`030000003oool0oooo01<0
oooo000_0?ooo`060000003oool0oooo0?ooo`000000oooo100000020?ooo`@000000P3oool30000
00@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo
00000080oooo0P0000030?ooo`@000000`3oool3000000T0oooo00D000000?ooo`3oool000000?oo
o`03000000@0oooo100000020?ooo`@000000P3oool300000080oooo0P0000000`3oool000000000
00020?ooo`<000000P3oool4000000<0oooo0`0000030?ooo`<000002@3oool00`000000oooo0?oo
o`020?ooo`H0000000<0oooo0000000000000`3oool2000000030?ooo`00000000000080oooo0`00
00040?ooo`030000003oool0oooo0080oooo0`0000020?ooo`@000000`3oool9000000<0oooo0`00
00030?ooo`@00000103oool00`000000oooo0?ooo`0C0?ooo`00;`3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00300oooo0`0000090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool3000000T0oooo100000090?ooo`030000
003oool0oooo0080oooo0P00000:0?ooo`@00000103oool00`000000oooo0?ooo`040?ooo`800000
103oool2000002h0oooo00<000000?ooo`3oool0603oool3000001H0oooo00<000000?ooo`3oool0
0P3oool2000000/0oooo00<000000?ooo`3oool05@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.134655, -1308.63, \
0.000849626, 1.15564}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.76191 -735.446 6.58076 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0205 -36 -4.5 ]
[-0.0125 .0205 0 4.5 ]
[-0.0125 .15212 -36 -4.5 ]
[-0.0125 .15212 0 4.5 ]
[-0.0125 .28373 -30 -4.5 ]
[-0.0125 .28373 0 4.5 ]
[-0.0125 .41535 -36 -4.5 ]
[-0.0125 .41535 0 4.5 ]
[-0.0125 .54697 -36 -4.5 ]
[-0.0125 .54697 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0205 m
.00625 .0205 L
s
[(111.76)] -0.0125 .0205 1 0 Mshowa
0 .15212 m
.00625 .15212 L
s
[(111.78)] -0.0125 .15212 1 0 Mshowa
0 .28373 m
.00625 .28373 L
s
[(111.8)] -0.0125 .28373 1 0 Mshowa
0 .41535 m
.00625 .41535 L
s
[(111.82)] -0.0125 .41535 1 0 Mshowa
0 .54697 m
.00625 .54697 L
s
[(111.84)] -0.0125 .54697 1 0 Mshowa
.125 Mabswid
0 .05341 m
.00375 .05341 L
s
0 .08631 m
.00375 .08631 L
s
0 .11922 m
.00375 .11922 L
s
0 .18502 m
.00375 .18502 L
s
0 .21793 m
.00375 .21793 L
s
0 .25083 m
.00375 .25083 L
s
0 .31664 m
.00375 .31664 L
s
0 .34954 m
.00375 .34954 L
s
0 .38245 m
.00375 .38245 L
s
0 .44825 m
.00375 .44825 L
s
0 .48116 m
.00375 .48116 L
s
0 .51406 m
.00375 .51406 L
s
0 .57987 m
.00375 .57987 L
s
0 .61277 m
.00375 .61277 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0205 m
1 .0205 L
s
.99375 .15212 m
1 .15212 L
s
.99375 .28373 m
1 .28373 L
s
.99375 .41535 m
1 .41535 L
s
.99375 .54697 m
1 .54697 L
s
.125 Mabswid
.99625 .05341 m
1 .05341 L
s
.99625 .08631 m
1 .08631 L
s
.99625 .11922 m
1 .11922 L
s
.99625 .18502 m
1 .18502 L
s
.99625 .21793 m
1 .21793 L
s
.99625 .25083 m
1 .25083 L
s
.99625 .31664 m
1 .31664 L
s
.99625 .34954 m
1 .34954 L
s
.99625 .38245 m
1 .38245 L
s
.99625 .44825 m
1 .44825 L
s
.99625 .48116 m
1 .48116 L
s
.99625 .51406 m
1 .51406 L
s
.99625 .57987 m
1 .57987 L
s
.99625 .61277 m
1 .61277 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .60332 m
.05372 .58483 L
.08634 .56467 L
.11698 .54574 L
.14644 .52753 L
.1778 .50815 L
.20799 .48949 L
.24008 .46966 L
.27099 .45055 L
.30073 .43217 L
.33237 .41262 L
.36283 .39379 L
.39213 .37569 L
.42332 .35641 L
.45333 .33786 L
.48525 .31813 L
.51599 .29913 L
.54556 .28086 L
.57703 .26141 L
.60732 .24269 L
.63951 .22279 L
.67053 .20362 L
.70038 .18518 L
.73212 .16556 L
.76269 .14666 L
.79209 .12849 L
.82339 .10915 L
.85351 .09054 L
.88553 .07075 L
.91638 .05168 L
.94605 .03334 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002X0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000;03oool2000002l0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000:P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000<0oooo000W0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool09P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo000P0?ooo`D000000P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0240oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0X0?oo
o`040000003oool0oooo000002d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`020?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02P0oooo00@000000?ooo`3oool00000;@3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo0080oooo000W0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000
000[0?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool00000203oool01@000000
oooo0?ooo`000000oooo00@00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo0080oooo000W0?ooo`040000003oool0oooo000000P0oooo0P00000Z0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00000^0?ooo`040000003oool0oooo0000
02d0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000002`0oooo
00@000000?ooo`3oool00000203oool2000000@0oooo000X0?ooo`8000002P3oool00`000000oooo
0?ooo`0Y0?ooo`8000002P3oool200000080oooo1@00000[0?ooo`800000;`3oool2000000X0oooo
0P0000020?ooo`D00000:@3oool2000000X0oooo00<000000?ooo`3oool00P3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool002L0oooom@0000040?ooo`009`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo0000103oool000000000000000030?ooo`<000000`3oool3000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool00080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`1a0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P00001h0?ooo`030000003oool0
oooo0700oooo00<000000?ooo`3oool00`3oool2000000@0oooo00020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00@000001@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo06h0oooo0P0000070?oo
o`030000003oool0oooo0080oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`1/0?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`00
00<0oooo000000000000103oool2000000@0oooo0P0000090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`D00000
0`3oool2000000D0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1Y0?ooo`800000
303oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo06L0oooo0P00000>0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0I03oool20000
0140oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`1R0?ooo`8000004P3oool2000000@0oooo000W0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo
000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0G`3oool2000001H0oooo00<0
00000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1M
0?ooo`800000603oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo05`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?oo
o`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo05X0oooo0P00000K0?ooo`03
0000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0E`3oool2000001h0oooo00<000000?ooo`3oool00P3o
ool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1E0?ooo`800000803oool0
0`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool07`3oool2000000@0oooo000W0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool0DP3oool2000002<0oooo00<000000?ooo`3oool00P3oool002L0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1@0?ooo`8000009@3oool00`000000oooo
0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo04d0oooo0P00000X0?ooo`030000003oool0oooo0080oooo000W0?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool0B`3oool2000002X0oooo00<000000?oo
o`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`180?ooo`800000;@3oool00`000000oooo0?ooo`020?ooo`009`3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04H0oooo0P00000^0?ooo`800000103o
ool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`130?ooo`800000<P3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0440oooo0P00000d0?ooo`030000003oool0oooo0080
oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0080oooo0000103oool000000000000000030?ooo`<00000
0`3oool3000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<00000
1@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03h0oooo0P00000g0?ooo`030000
003oool0oooo0080oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0?03oool2000003T0oooo
00<000000?ooo`3oool00P3oool00080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo0080oooo00020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`<00000
1@3oool2000007P0oooo00<000000?ooo`3oool0>@3oool2000003/0oooo0P0000040?ooo`000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3o
ool000030?ooo`000000000000@0oooo0P0000040?ooo`8000002@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0080oooo
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`D000000P3oool3000000D0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`0e0?ooo`800000@03oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`02
0?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0380oooo0P0000130?oo
o`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0<03oool2000004D0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0]0?ooo`800000A`3o
ool2000000@0oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0:`3oool2
000004X0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0X0?ooo`800000C@3oool00`000000
oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo02H0oooo
0P00001?0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0080oooo000W
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool08`3oool200000580oooo00<00000
0?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0Q0?oo
o`800000E03oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0D`3oool2000000@0oooo000W0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool07P3oool2000005L0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`0K0?ooo`800000FP3oool00`000000oooo0?ooo`020?ooo`009`3oool00`00
0000oooo0?ooo`1g0?ooo`030000003oool0oooo01T0oooo0P00001L0?ooo`030000003oool0oooo
0080oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool05P3oool2000005l0oooo00<000000?ooo`3oool00P3oool002L0oooo00<0
00000?ooo`3oool0M`3oool00`000000oooo0?ooo`0D0?ooo`800000H@3oool00`000000oooo0?oo
o`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0H03oool2000000@0oooo000W0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool04@3oool2000006@0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`0?0?ooo`800000IP3oool00`000000oooo0?ooo`020?ooo`00
9`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo00`0oooo0P00001Y0?ooo`030000003oool0oooo0080oooo00070?ooo`<000000`3oool3
000000<0oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool02P3oool2000006/0oooo00<000000?ooo`3oool00P3oool0
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0080oooo00080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo00L0oooo0P00001^0?ooo`030000003oool0oooo0080oooo00080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`<000001@3oool20000
07P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1]0?ooo`800000103oool000P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0103oool200000740oooo00<000000?ooo`3oool00P3oool000L0oooo0P0000040?ooo`80
0000103oool2000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
0080oooo00080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`<000001@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo00800000M@3oool00`000000oooo0?ooo`020?ooo`009`3o
ool00`000000oooo0?ooo`1g0?ooo`<00000M`3oool00`000000oooo0?ooo`020?ooo`009`3oool0
0`000000oooo0?ooo`1f0?ooo`800000N@3oool00`000000oooo0?ooo`020?ooo`009`3oool00`00
0000oooo0?ooo`1d0?ooo`80000000<0oooo0000003oool0N03oool00`000000oooo0?ooo`020?oo
o`009`3oool00`000000oooo0?ooo`1b0?ooo`8000000`3oool00`000000oooo0?ooo`1f0?ooo`80
0000103oool002L0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0K`3o
ool2000000H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000
oooo0?ooo`1[0?ooo`8000002P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080
oooo000W0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo06P0oooo0P00
000=0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<00000
0?ooo`3oool0IP3oool2000000l0oooo00<000000?ooo`3oool0MP3oool2000000@0oooo000W0?oo
o`030000003oool0oooo06D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo06<0oooo0P00000B0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0
H@3oool2000001@0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1N0?ooo`8000005`3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
05`0oooo0P00000I0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0F@3oool2000001`0oooo
00<000000?ooo`3oool0MP3oool2000000@0oooo000W0?ooo`030000003oool0oooo05L0oooo0P00
000N0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0E03oool200000240oooo00<000000?oo
o`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`1B0?ooo`80
00008`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo0080oooo0000103oool000000000000000030?ooo`<000000`3oool3000000@0oooo
00<000000?ooo`3oool00P3oool300000080oooo1@0000040?ooo`030000003oool0oooo04l0oooo
0P00000V0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool00080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0C@3oool2000002P0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`00
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool2000004d0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1f0?ooo`800000103oool00080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
0`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0BP3oool2000002/0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04P0
oooo0P00000]0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool000030?oo
o`000000000000@0oooo0P0000040?ooo`8000002@3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`<0
00000`3oool3000000D0oooo00<000000?ooo`3oool0A@3oool200000300oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3o
ool00`000000oooo0?ooo`120?ooo`800000<`3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0080oooo000W0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1f0?ooo`800000103oool002L0
oooo00<000000?ooo`3oool0?P3oool2000003L0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0l0?ooo`800000>@3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo03X0oooo0P00
000k0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<00000
0?ooo`3oool0>03oool2000003d0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`02
0?ooo`009`3oool00`000000oooo0?ooo`0f0?ooo`800000?`3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo03<0oooo0P0000120?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool0<@3oool2000004@0oooo00<000000?ooo`3oool0MP3o
ool2000000@0oooo000W0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0oooo
02h0oooo0P0000170?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool0:`3oool2000004X0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`020?ooo`009`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0W0?oo
o`800000CP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1f0?ooo`80
0000103oool002L0oooo00<000000?ooo`3oool0903oool200000540oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`0R0?ooo`800000D`3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo0080oooo000W0?ooo`030000003oool0oooo01l0oooo0P00001F0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool07@3oool2000005P0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`0000@0oooo000000000000
00000`3oool3000000<0oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000040?ooo`<0
0000103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`020?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`800000F`3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo0?ooo`00
0000oooo1@0000040?ooo`8000006@3oool2000005d0oooo00<000000?ooo`3oool0MP3oool20000
00@0oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`<000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0080oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000050?oo
o`030000003oool0oooo01D0oooo0P00001P0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool00P3oool000030?ooo`000000000000@0oooo0P0000040?ooo`8000002@3oool01@000000
oooo0?ooo`3oool0000000<0oooo0P0000050?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`<0
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W0?ooo`030000
003oool0oooo0140oooo0P00001T0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool03P3oool2
000006L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`00
0000oooo0?ooo`0<0?ooo`800000J@3oool00`000000oooo0?ooo`1f0?ooo`800000103oool002L0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool02@3oool2000006`0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?oo
o`070?ooo`800000KP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo000W
0?ooo`030000003oool0oooo00D0oooo0P00001`0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool00P3oool002L0oooo00<000000?ooo`3oool00`3oool200000780oooo00<000000?oo
o`3oool0M`3oool00`000000oooo0?ooo`020?ooo`009`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0780oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`00
9`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool002L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0h0?ooo`040000003o
ool0oooo0?ooo`800000103oool002L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`009`3ooooe000000@0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
000b0?ooo`<00000F03oool3000001L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`0<0?ooo`00<`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`0;0?ooo`00;@3oool3000000<0oooo0`0000040?oo
o`8000000P3oool500000080oooo0`0000030?ooo`@0000000<0oooo0000000000000`0000070?oo
o`<00000103oool4000000<0oooo0P0000020?ooo`H000001P3oool500000080oooo0`0000020?oo
o`<0000000@0oooo000000000000oooo100000030?ooo`8000000P3oool6000000L0oooo00<00000
0?ooo`3oool00`3oool4000000030?ooo`0000000000008000000P3oool4000000<0oooo0`000002
0?ooo`D000000`3oool2000000040?ooo`000000oooo0?ooo`8000000`3oool3000000T0oooo1000
00000`3oool0000000000003000000030?ooo`000000000000800000103oool2000000<0oooo1000
00001@3oool00000000000000000oooo0080000000@0oooo00000000000000000`3oool3000000D0
oooo00<000000?ooo`3oool02P3oool002`0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000
oooo000000H0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0000
0080oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`000000203oool00`000000oooo0?ooo`0:0?ooo`00;03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000001P3oool3000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool00P3oool500000080oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`030?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`<000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0080oooo1@0000070?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool00`3oool3000000<0oooo00H00000
0?ooo`3oool000000?ooo`0000050?ooo`D00000103oool00`000000oooo0?ooo`0:0?ooo`00;03o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool300000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000203o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000050?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000L0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool002`0oooo00H000000?ooo`3oool0oooo0000003oool400000080
oooo100000020?ooo`<00000103oool3000000<0oooo0P0000050?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool000000P3oool2000000<0oooo100000030?ooo`<000002@3oool00`00
0000oooo0?ooo`030?ooo`<000000P3oool4000000<0oooo2@0000030?ooo`<000002@3oool00`00
0000oooo0?ooo`030?ooo`800000103oool3000000<0oooo100000020?ooo`<00000103oool01000
0000oooo0?ooo`3oool2000000040?ooo`00000000000?ooo`@000000`3oool3000000T0oooo0`00
00020?ooo`<00000103oool4000000030?ooo`0000000000008000000`3oool2000000<0oooo1000
00030?ooo`<000000`3oool3000000D0oooo00<000000?ooo`3oool02P3oool002`0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0;0?ooo`00;@3oool3000000T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0=0?ooo`<000002@3oool4000000T0oooo00<000000?ooo`3oool00P3o
ool2000000X0oooo0`00000F0?ooo`030000003oool0oooo0080oooo0P00000=0?ooo`030000003o
ool0oooo00H0oooo0P00000@0?ooo`<000002P3oool00`000000oooo0?ooo`0@0?ooo`800000103o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0303o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.138513, 111.749, \
0.000857962, 0.000620831}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.76191 -364.993 5.15922 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07302 -30 -4.5 ]
[-0.0125 .07302 0 4.5 ]
[-0.0125 .17621 -30 -4.5 ]
[-0.0125 .17621 0 4.5 ]
[-0.0125 .27939 -24 -4.5 ]
[-0.0125 .27939 0 4.5 ]
[-0.0125 .38257 -30 -4.5 ]
[-0.0125 .38257 0 4.5 ]
[-0.0125 .48576 -30 -4.5 ]
[-0.0125 .48576 0 4.5 ]
[-0.0125 .58894 -30 -4.5 ]
[-0.0125 .58894 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07302 m
.00625 .07302 L
s
[(70.76)] -0.0125 .07302 1 0 Mshowa
0 .17621 m
.00625 .17621 L
s
[(70.78)] -0.0125 .17621 1 0 Mshowa
0 .27939 m
.00625 .27939 L
s
[(70.8)] -0.0125 .27939 1 0 Mshowa
0 .38257 m
.00625 .38257 L
s
[(70.82)] -0.0125 .38257 1 0 Mshowa
0 .48576 m
.00625 .48576 L
s
[(70.84)] -0.0125 .48576 1 0 Mshowa
0 .58894 m
.00625 .58894 L
s
[(70.86)] -0.0125 .58894 1 0 Mshowa
.125 Mabswid
0 .09882 m
.00375 .09882 L
s
0 .12461 m
.00375 .12461 L
s
0 .15041 m
.00375 .15041 L
s
0 .202 m
.00375 .202 L
s
0 .2278 m
.00375 .2278 L
s
0 .25359 m
.00375 .25359 L
s
0 .30519 m
.00375 .30519 L
s
0 .33098 m
.00375 .33098 L
s
0 .35678 m
.00375 .35678 L
s
0 .40837 m
.00375 .40837 L
s
0 .43417 m
.00375 .43417 L
s
0 .45996 m
.00375 .45996 L
s
0 .51155 m
.00375 .51155 L
s
0 .53735 m
.00375 .53735 L
s
0 .56315 m
.00375 .56315 L
s
0 .04723 m
.00375 .04723 L
s
0 .02143 m
.00375 .02143 L
s
0 .61474 m
.00375 .61474 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07302 m
1 .07302 L
s
.99375 .17621 m
1 .17621 L
s
.99375 .27939 m
1 .27939 L
s
.99375 .38257 m
1 .38257 L
s
.99375 .48576 m
1 .48576 L
s
.99375 .58894 m
1 .58894 L
s
.125 Mabswid
.99625 .09882 m
1 .09882 L
s
.99625 .12461 m
1 .12461 L
s
.99625 .15041 m
1 .15041 L
s
.99625 .202 m
1 .202 L
s
.99625 .2278 m
1 .2278 L
s
.99625 .25359 m
1 .25359 L
s
.99625 .30519 m
1 .30519 L
s
.99625 .33098 m
1 .33098 L
s
.99625 .35678 m
1 .35678 L
s
.99625 .40837 m
1 .40837 L
s
.99625 .43417 m
1 .43417 L
s
.99625 .45996 m
1 .45996 L
s
.99625 .51155 m
1 .51155 L
s
.99625 .53735 m
1 .53735 L
s
.99625 .56315 m
1 .56315 L
s
.99625 .04723 m
1 .04723 L
s
.99625 .02143 m
1 .02143 L
s
.99625 .61474 m
1 .61474 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .07302 m
1 .07302 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.05372 .0332 L
.08634 .05336 L
.11698 .0723 L
.14644 .09051 L
.1778 .10989 L
.20799 .12855 L
.24008 .14838 L
.27099 .16748 L
.30073 .18586 L
.33237 .20542 L
.36283 .22424 L
.39213 .24235 L
.42332 .26162 L
.45333 .28018 L
.48525 .2999 L
.51599 .3189 L
.54556 .33717 L
.57703 .35662 L
.60732 .37535 L
.63951 .39524 L
.67053 .41441 L
.70038 .43286 L
.73212 .45248 L
.76269 .47137 L
.79209 .48954 L
.82339 .50888 L
.85351 .5275 L
.88553 .54729 L
.91638 .56635 L
.94605 .58469 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00903oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002X0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000;@3oool200000300oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000:P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000D0oooo000S0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool09P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo000L0?ooo`D000000P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0240oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0Y0?oo
o`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`040?ooo`008`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02T0oooo00@000000?ooo`3oool00000;P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00@0oooo000S0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000
000/0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool01@000000
oooo0?ooo`000000oooo00@00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo000S0?ooo`040000003oool0oooo000000P0oooo0P00000Z0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00000_0?ooo`040000003oool0oooo0000
02h0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000002`0oooo
00@000000?ooo`3oool00000203oool2000000H0oooo000T0?ooo`8000002P3oool00`000000oooo
0?ooo`0Y0?ooo`8000002P3oool200000080oooo1@00000/0?ooo`800000<03oool2000000X0oooo
0P0000020?ooo`D00000:@3oool2000000X0oooo00<000000?ooo`3oool0103oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00280oooon@0000050?ooo`008P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`00
0000oooo0?ooo`030?ooo`800000M03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
00<0oooo000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`8000001`3oool200000740oooo
00<000000?ooo`3oool0N03oool2000000D0oooo000R0?ooo`030000003oool0oooo00P0oooo0P00
001_0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool02`3oool2000006`0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo06T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00
8P3oool00`000000oooo0?ooo`0>0?ooo`800000J@3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00<0oooo000R0?ooo`8000004@3oool2000006L0oooo00<000000?ooo`3oool0N03o
ool2000000D0oooo000R0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo
01<0oooo0P00001T0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool00`3oool000<0oooo00<000000?ooo`3oool00`3oool2000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo
0?ooo`0F0?ooo`800000H@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo
00030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000002@3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0100000050?ooooT000001@3oool000D0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0703oool20000
05/0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000003o
ool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07P3oool2
000005T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000
000000000`0000030?ooo`800000203oool5000000<0oooo0P0000050?ooo`030000003oool0oooo
0200oooo0P00001G0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool08P3oool2000005D0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool2000002H0oooo0P00
001B0?ooo`030000003oool0oooo07P0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`03
0?ooo`008P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`80
0000CP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000
003oool0oooo02/0oooo0P00001<0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
0`3oool00280oooo00<000000?ooo`3oool0;@3oool2000004X0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`030?ooo`008P3oool200000300oooo0P0000180?ooo`030000003oool0
oooo07P0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`0a0?ooo`800000AP3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0
oooo000R0?ooo`030000003oool0oooo03@0oooo0P0000130?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0=P3oool200000440oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`03
0?ooo`008P3oool00`000000oooo0?ooo`0i0?ooo`800000?P3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo00<0oooo000R0?ooo`800000?03oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo07P0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`0l0?ooo`800000
>`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00030?ooo`030000003oool0oooo
00<0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool30000
00D0oooo00<000000?ooo`3oool0@03oool2000003L0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`030?ooo`000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`<00000@`3o
ool2000003@0oooo00<000000?ooo`3oool0M`3oool3000000D0oooo00040?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0?ooo`<00000
1@3oool00`000000oooo0?ooo`150?ooo`800000<P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00<0oooo00050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
2@3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
0`3oool000030?ooo`000000oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`050?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0B03oool2000002l0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`030?ooo`0000<0oooo0000000000000`0000030?ooo`800000203oool500000080
oooo0`0000050?ooo`030000003oool0oooo04X0oooo0P00000]0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0C03oool2000002/0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?oo
o`1>0?ooo`800000:@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R
0?ooo`800000D@3oool2000002L0oooo00<000000?ooo`3oool0N03oool2000000D0oooo000R0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo05<0oooo0P00000T0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
0`3oool00280oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0E`3oool2
00000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool20000
05X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1h0?ooo`8000001@3oool00280
oooo00<000000?ooo`3oool0FP3oool2000001d0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?oo
o`1M0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`030?ooo`008P3oool00`000000oooo0?ooo`1N0?ooo`8000006@3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo0600oooo0P00000G0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo0P00001S0?ooo`80
00005@3oool00`000000oooo0?ooo`1h0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool0
I03oool2000001<0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`1V0?ooo`8000004@3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo
00<0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo
06T0oooo0P00000>0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000T0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`002P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0K03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool00`3oool000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00H0oooo0`0000050?ooo`<00000K@3oool2000000X0oooo00<000000?ooo`3oool0M`3o
ool3000000D0oooo000;0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0700oooo0P0000070?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool00`3oool000L0oooo1@0000030?ooo`8000002@3oool3000000D0
oooo00<000000?ooo`3oool0LP3oool2000000D0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?oo
o`1e0?ooo`8000000P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R
0?ooo`800000N03oool3000007X0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1i0?oo
o`800000NP3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`04
0000003oool00000000007P0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3o
ool0N@3oool010000000oooo0?ooo`3oool2000007H0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`040?ooo`800000L`3oool00`000000oooo0?ooo`030?ooo`008P3oool2000007X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1_0?ooo`8000001@3oool00280oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06l0oooo00<00000
0?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?oo
o`800000K`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`030?ooo`00
8P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00/0oooo0P00001/0?ooo`030000
003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool03@3o
ool2000006X0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool00`3oool0
0280oooo0P00001j0?ooo`030000003oool0oooo0100oooo0P00001V0?ooo`8000001@3oool00280
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0B0?ooo`800000I@3oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo01@0oooo
0P00001S0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool05P3oool200000640oooo00<000000?ooo`3oool00`3oool000<0oooo00<00000
0?ooo`3oool00`3oool2000000@0oooo00<000000?ooo`3oool00P3oool300000080oooo1@000004
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0603oool2000005l0oooo00<00000
0?ooo`3oool00`3oool000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000007
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo00<0oooo00040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`<0
0000N@3oool00`000000oooo0?ooo`0K0?ooo`800000FP3oool3000000D0oooo00040?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`<000001@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo00<0oooo00050?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo00000`3oool000000?ooo`020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool07`3oool2000005P0oooo00<000000?ooo`3oool00`3oool000030?ooo`00
0000000000<000000`3oool2000000T0oooo0`0000030?ooo`<000001@3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0280oooo0P00001E
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool0903oool2000005<0oooo00<000000?ooo`3oool00`3oool00280oooo0P00001j0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0C`3oool2000000D0oooo000R0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool09`3oool200000500oooo00<000000?ooo`3oool0
0`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`0Z0?ooo`800000C@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo02`0oooo0P00001;0?ooo`030000003oool0oooo
00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000NP3oool00`000000oooo
0?ooo`0_0?ooo`800000A`3oool2000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0<@3oool2000004H0oooo00<000000?ooo`3oool00`3oool00280oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0d0?oo
o`800000@`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo03H0oooo0P0000110?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?ooo`0i0?ooo`800000?@3o
ool2000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0>`3oool2
000003`0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0n0?ooo`800000>@3oool00`000000
oooo0?ooo`030?ooo`000`3oool00`000000oooo0?ooo`030?ooo`800000103oool00`000000oooo
0?ooo`020?ooo`<00000103oool3000000@0oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00`3oool000<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0@@3oool2000003H0oooo00<000000?ooo`3oool00`3oool000@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool0oooo0000003oool5
000000@0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool00`3oool000@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00H0oooo0`0000020?ooo`040000003oool0oooo000000D0oooo0`00
001i0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0<03oool3000000D0oooo0005
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo04D0oooo0P00000b0?ooo`030000003oool0oooo00<0oooo00000`3oool000000?oo
o`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool01@000000oooo
0?ooo`3oool0000000<0oooo0P0000050?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0A`3oool200000300oooo00<000000?ooo`3oool00`3oool000030?ooo`000000000000<00000
0`3oool2000000T0oooo0`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`190?ooo`800000;P3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo04/0oooo0P00000/0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0C@3oool2
000002X0oooo00<000000?ooo`3oool00`3oool00280oooo0P00001j0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool09P3oool2000000D0oooo000R0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0D03oool2000002L0oooo00<000000?ooo`3oool00`3oool00280oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00280oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`1D0?ooo`8000008`3oool00`000000oooo0?ooo`03
0?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`030?ooo`008P3oool2000007X0oooo00<000000?ooo`3o
ool0E`3oool2000001l0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo05T0oooo0P00000N0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0G03oool2
000001/0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1O0?ooo`800000603oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0640oooo
0P00000F0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0180oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo06@0oooo0P00000C0?ooo`030000003oool0oooo00<0oooo000R0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool0IP3oool200000140oooo00<000000?oo
o`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1X0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool000<0oooo00<000000?ooo`3oool0
0`3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0`0000050?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0J@3oool2000000h0oooo00<000000?ooo`3oool0
0`3oool000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`1[0?ooo`800000303oool00`000000oooo0?ooo`030?oo
o`00103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`<00000N@3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00L0oooo0`0000050?ooo`00103oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool300000080oooo1000
00050?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0KP3oool2000000T0oooo00<0
00000?ooo`3oool00`3oool000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`050?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0L03oool2000000L0oooo00<000000?ooo`3oool00`3oool000030?oo
o`000000oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00000`3oool0000000000003000000<0oooo0P0000090?ooo`<00000103oool2000000D0
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00280oooon@0000050?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00d@3oool3000004`0oooo003B0?ooo`030000003oool0oooo04/0oooo001V0?oo
o`030000003oool0000000<0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000020?oo
o`<000000`3oool3000000@0oooo0`0000020?ooo`<0000000<0oooo0000000000000P3oool20000
00P0oooo1@0000001@3oool00000000000000000oooo008000000P3oool2000000<0oooo0`000002
0?ooo`<0000000<0oooo000000000000100000020?ooo`D000000`3oool2000000@0oooo00<00000
0?ooo`3oool0BP3oool006H0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`000004
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`040000003oool0oooo000000D0
oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0BP3oool006H0oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?oo
o`0000000P3oool500000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo1@0000020?ooo`040000003oool0oooo00000080oooo0`0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0000001;0?ooo`00
I@3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo0`0000030?ooo`800000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?oo
o`000000oooo000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000004/0oooo001U0?ooo`050000003oool000000?ooo`0000000P3oool2000000<0
oooo0P0000000`3oool00000000000020?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`80
000000<0oooo0000000000000P3oool300000080oooo100000020?ooo`@000002P3oool010000000
oooo0?ooo`3oool400000080oooo100000030?ooo`<000000P3oool4000000<0oooo10000000103o
ool000000000000000030?ooo`@000000P3oool2000000030?ooo`000000000004X0oooo001U0?oo
o`050000003oool000000?ooo`000000503oool010000000oooo0?ooo`00000D0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0540oooo001U0?ooo`H000004P3oool5000001@0oooo00<000000?ooo`3oool0203oool5
000000P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0540oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.134655, 70.7363, \
0.000849626, 0.000784197}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.76191 4.53255 0.00350097 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06882 -30 -4.5 ]
[-0.0125 .06882 0 4.5 ]
[-0.0125 .15634 -30 -4.5 ]
[-0.0125 .15634 0 4.5 ]
[-0.0125 .24387 -30 -4.5 ]
[-0.0125 .24387 0 4.5 ]
[-0.0125 .33139 -30 -4.5 ]
[-0.0125 .33139 0 4.5 ]
[-0.0125 .41892 -30 -4.5 ]
[-0.0125 .41892 0 4.5 ]
[-0.0125 .50644 -30 -4.5 ]
[-0.0125 .50644 0 4.5 ]
[-0.0125 .59396 -30 -4.5 ]
[-0.0125 .59396 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06882 m
.00625 .06882 L
s
[(-1275)] -0.0125 .06882 1 0 Mshowa
0 .15634 m
.00625 .15634 L
s
[(-1250)] -0.0125 .15634 1 0 Mshowa
0 .24387 m
.00625 .24387 L
s
[(-1225)] -0.0125 .24387 1 0 Mshowa
0 .33139 m
.00625 .33139 L
s
[(-1200)] -0.0125 .33139 1 0 Mshowa
0 .41892 m
.00625 .41892 L
s
[(-1175)] -0.0125 .41892 1 0 Mshowa
0 .50644 m
.00625 .50644 L
s
[(-1150)] -0.0125 .50644 1 0 Mshowa
0 .59396 m
.00625 .59396 L
s
[(-1125)] -0.0125 .59396 1 0 Mshowa
.125 Mabswid
0 .08632 m
.00375 .08632 L
s
0 .10383 m
.00375 .10383 L
s
0 .12133 m
.00375 .12133 L
s
0 .13884 m
.00375 .13884 L
s
0 .17385 m
.00375 .17385 L
s
0 .19135 m
.00375 .19135 L
s
0 .20886 m
.00375 .20886 L
s
0 .22636 m
.00375 .22636 L
s
0 .26137 m
.00375 .26137 L
s
0 .27888 m
.00375 .27888 L
s
0 .29638 m
.00375 .29638 L
s
0 .31389 m
.00375 .31389 L
s
0 .3489 m
.00375 .3489 L
s
0 .3664 m
.00375 .3664 L
s
0 .38391 m
.00375 .38391 L
s
0 .40141 m
.00375 .40141 L
s
0 .43642 m
.00375 .43642 L
s
0 .45393 m
.00375 .45393 L
s
0 .47143 m
.00375 .47143 L
s
0 .48894 m
.00375 .48894 L
s
0 .52395 m
.00375 .52395 L
s
0 .54145 m
.00375 .54145 L
s
0 .55895 m
.00375 .55895 L
s
0 .57646 m
.00375 .57646 L
s
0 .05131 m
.00375 .05131 L
s
0 .03381 m
.00375 .03381 L
s
0 .0163 m
.00375 .0163 L
s
0 .61147 m
.00375 .61147 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06882 m
1 .06882 L
s
.99375 .15634 m
1 .15634 L
s
.99375 .24387 m
1 .24387 L
s
.99375 .33139 m
1 .33139 L
s
.99375 .41892 m
1 .41892 L
s
.99375 .50644 m
1 .50644 L
s
.99375 .59396 m
1 .59396 L
s
.125 Mabswid
.99625 .08632 m
1 .08632 L
s
.99625 .10383 m
1 .10383 L
s
.99625 .12133 m
1 .12133 L
s
.99625 .13884 m
1 .13884 L
s
.99625 .17385 m
1 .17385 L
s
.99625 .19135 m
1 .19135 L
s
.99625 .20886 m
1 .20886 L
s
.99625 .22636 m
1 .22636 L
s
.99625 .26137 m
1 .26137 L
s
.99625 .27888 m
1 .27888 L
s
.99625 .29638 m
1 .29638 L
s
.99625 .31389 m
1 .31389 L
s
.99625 .3489 m
1 .3489 L
s
.99625 .3664 m
1 .3664 L
s
.99625 .38391 m
1 .38391 L
s
.99625 .40141 m
1 .40141 L
s
.99625 .43642 m
1 .43642 L
s
.99625 .45393 m
1 .45393 L
s
.99625 .47143 m
1 .47143 L
s
.99625 .48894 m
1 .48894 L
s
.99625 .52395 m
1 .52395 L
s
.99625 .54145 m
1 .54145 L
s
.99625 .55895 m
1 .55895 L
s
.99625 .57646 m
1 .57646 L
s
.99625 .05131 m
1 .05131 L
s
.99625 .03381 m
1 .03381 L
s
.99625 .0163 m
1 .0163 L
s
.99625 .61147 m
1 .61147 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06882 m
1 .06882 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .60332 m
.05372 .58483 L
.08634 .56467 L
.11698 .54574 L
.14644 .52753 L
.1778 .50815 L
.20799 .48949 L
.24008 .46966 L
.27099 .45055 L
.30073 .43217 L
.33237 .41262 L
.36283 .39379 L
.39213 .37569 L
.42332 .35641 L
.45333 .33786 L
.48525 .31813 L
.51599 .29913 L
.54556 .28086 L
.57703 .26141 L
.60732 .24269 L
.63951 .22279 L
.67053 .20362 L
.70038 .18518 L
.73212 .16556 L
.76269 .14666 L
.79209 .12849 L
.82339 .10915 L
.85351 .09054 L
.88553 .07075 L
.91638 .05168 L
.94605 .03334 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00903oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002X0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000;@3oool200000300oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000:P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000D0oooo000S0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool09P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo000L0?ooo`D000000P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0240oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0Y0?oo
o`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`040?ooo`008`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02T0oooo00@000000?ooo`3oool00000;P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00@0oooo000S0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000
000/0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool01@000000
oooo0?ooo`000000oooo00@00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo000S0?ooo`040000003oool0oooo000000P0oooo0P00000Z0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00000_0?ooo`040000003oool0oooo0000
02h0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000002`0oooo
00@000000?ooo`3oool00000203oool2000000H0oooo000T0?ooo`8000002P3oool00`000000oooo
0?ooo`0Y0?ooo`8000002P3oool200000080oooo1@00000/0?ooo`800000<03oool2000000X0oooo
0P0000020?ooo`D00000:@3oool2000000X0oooo00<000000?ooo`3oool0103oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00280oooon@0000050?ooo`008P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo0780oooo0P0000050?ooo`030000003oool0oooo
00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00@0
oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo06l0oooo
0P0000080?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0K@3oool2000000X0oooo00<000000?ooo`3oool00`3oool00280oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool00280oooo0P00001j0?ooo`030000003oool0oooo06X0oooo0P00000<0?oo
o`8000001@3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1X0?ooo`80
00003`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo06D0oooo0P00000B0?ooo`030000003o
ool0oooo00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?ooo`1S0?ooo`8000004`3oool2
000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00080?ooo`<000000P3oool5000000<0
oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`1P0?ooo`8000005`3oool00`000000oooo0?ooo`030?ooo`002@3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1N0?oo
o`8000006@3oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000000000000`0000030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3ooooi000000D0oooo00090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000<000001@3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`00203o
ool2000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`00
0000203oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo05P0oooo0P00000O0?ooo`03
0000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D00000
00<0oooo0000000000000`0000040?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
EP3oool200000240oooo00<000000?ooo`3oool00`3oool00280oooo0P00001j0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0803oool2000000D0oooo000R0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0D`3oool2000002@0oooo00<000000?ooo`3oool00`3oool0
0280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`1@0?ooo`8000009`3oool00`000000oooo0?ooo`030?ooo`008P3oool2000007X0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0V0?ooo`8000001@3oool00280oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1<
0?ooo`800000:`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo04X0oooo0P00000]0?ooo`030000003oool0oooo00<0oooo000R0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0B03oool2000002l0oooo00<000000?ooo`3o
ool00`3oool00280oooo0P00001j0?ooo`030000003oool0oooo04H0oooo0P00000`0?ooo`800000
1@3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`140?ooo`800000<`3o
ool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`030?ooo`008P3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo0440oooo0P00000f0?ooo`030000003oool0oooo
00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03D0
oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`030?ooo`00203oool300000080oooo1@00
00020?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0m0?ooo`800000>P3oool00`000000oooo0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`02
0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool00`3oool000030?ooo`000000000000<00000
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`<00000N@3oool00`000000oooo0?ooo`0j0?ooo`80
0000>`3oool3000000D0oooo00090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`0h0?ooo`800000?`3oool00`000000oooo0?ooo`030?ooo`00
2@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`0000030?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool00`3oool000P0oooo0P0000030?ooo`07
0000003oool0oooo0?ooo`000000oooo000000060?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`0e0?ooo`800000@P3oool00`000000oooo0?oo
o`030?ooo`002@3oool00`000000oooo0?ooo`020?ooo`<000000P3oool5000000<0oooo0P000005
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool2000004@0oooo00<00000
0?ooo`3oool00`3oool00280oooo0P00001j0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0@`3oool2000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0<03oool2000004L0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`0^0?ooo`800000B@3oool00`000000oooo0?ooo`030?ooo`008P3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`030?ooo`008P3oool2000007X0oooo00<000000?ooo`3oool0:`3oool2
000004/0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
02T0oooo0P00001>0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00<0
oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool09P3oool200000540oooo
00<000000?ooo`3oool00`3oool00280oooo0P00001j0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0D03oool2000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool08`3oool2000005@0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0Q0?ooo`800000EP3oool00`000000oooo0?ooo`030?oo
o`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo01h0oooo0P00001I0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000NP3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05P0oooo0P0000050?ooo`00203oool3
00000080oooo1@0000000`3oool000000000000300000080oooo0`0000050?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool06`3oool2000005`0oooo00<000000?ooo`3oool00`3oool0
00T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo
00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`030?ooo`002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<00000N@3oool00`000000oooo0?ooo`0G
0?ooo`800000GP3oool3000000D0oooo00090?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo000000030?ooo`030000003oool0000000<000001@3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo01D0oooo0P00001R0?ooo`030000003oool0oooo00<0oooo00080?oo
o`8000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0000
00080?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool04`3oool2000006@0oooo00<0
00000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0`000002
0?ooo`D00000103oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0140oooo0P00001V
0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000NP3oool00`000000oooo0?ooo`0?0?oo
o`800000I`3oool2000000D0oooo000R0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0303oool2000006/0oooo00<000000?ooo`3oool0
0`3oool00280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0:0?ooo`800000K@3o
ool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`030?ooo`008P3oool20000
07X0oooo00<000000?ooo`3oool01`3oool2000006l0oooo0P0000050?ooo`008P3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00@0oooo
0P00001c0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00<0oooo000R
0?ooo`800000NP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07<0oooo0P000005
0?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00800000M`3oool00`00
0000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`<00000N@3oool00`000000
oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1h0?ooo`800000N`3oool00`000000oooo
0?ooo`030?ooo`008P3oool2000007L0oooo0P0000000`3oool000000?ooo`1i0?ooo`8000001@3o
ool00280oooo00<000000?ooo`3oool0M03oool2000000<0oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`030?ooo`00203oool300000080oooo1@0000030?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1a0?ooo`8000001P3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00<0oooo00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`1_0?ooo`800000203oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool3000006h0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1g0?ooo`<000001@3oool000T0oooo
00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06`0oooo0P00000;
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000P0oooo0P0000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00P3o
ool3000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1Y0?ooo`8000003P3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000J@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07P0oooo0P0000050?ooo`008P3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`1U0?ooo`8000004P3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo
000R0?ooo`800000H`3oool2000001D0oooo00<000000?ooo`3oool0N03oool2000000D0oooo000R
0?ooo`030000003oool0oooo0600oooo0P00000G0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3o
ool0G@3oool2000001X0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00
8P3oool00`000000oooo0?ooo`1K0?ooo`800000703oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00<0oooo000R0?ooo`800000F`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo07P0oooo0P0000050?ooo`008P3oool00`000000oooo0?ooo`1H0?ooo`8000007`3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo
05H0oooo0P00000Q0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool00`3oool00280oooo0P00001D0?ooo`800000903oool00`000000oooo
0?ooo`1h0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000P0oooo0`000003
0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`03
0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C`3oool2
000002P0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000
000000000`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0`00001=0?ooo`800000:P3oool00`00
0000oooo0?ooo`1g0?ooo`<000001@3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1;0?ooo`800000;03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0
oooo00090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
00000003000000D0oooo00<000000?ooo`3oool0B@3oool2000002h0oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`030?ooo`00203oool2000000@0oooo0P0000030?ooo`070000003o
ool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0oooo04L0oooo0P00000`0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`3oool5000000030?ooo`000000000000<00000103oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`030?ooo`008P3oool2000004D0oooo0P00000c0?ooo`030000003oool0oooo07P0oooo
0P0000050?ooo`008P3oool00`000000oooo0?ooo`120?ooo`800000=@3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?oo
o`030000003oool0oooo03l0oooo0P00000h0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool00`3oool00280oooo0P00000o0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0N03oool2000000D0oooo000R0?ooo`030000003oool0oooo03`0oooo0P00000k0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3o
ool00280oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo0P00000i0?ooo`800000?`3oool00`00
0000oooo0?ooo`1h0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo
00<000000?ooo`3oool0=@3oool200000480oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0c0?ooo`800000A03oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?oo
o`800000<@3oool2000004L0oooo00<000000?ooo`3oool0N03oool2000000D0oooo00080?ooo`<0
00000`3oool3000000<0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`0^0?ooo`80
0000B@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0/0?ooo`800000B`3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00000`3oool0000000000003000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`800000C@3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0080oooo0`00000X0?ooo`800000C`3oool00`000000oooo0?ooo`1g0?ooo`<000001@3oool000T0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool4000000<0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`00203oool2000000@0oooo0P0000030?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0U
0?ooo`800000DP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo00090?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`8000001@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`030?ooo`008P3oool2000002@0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`1h0?ooo`8000001@3oool00280oooo00<000000?ooo`3oool08@3oool2000005H0
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0N0?ooo`800000F@3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`8000007@3oool2000005/0oooo00<00000
0?ooo`3oool0N03oool2000000D0oooo000R0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`03
0000003oool0oooo01T0oooo0P00001N0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool00`3oool00280oooo00<000000?ooo`3oool05`3oool200000600oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`030?ooo`008P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`030?ooo`008P3oool2
000001D0oooo0P00001S0?ooo`030000003oool0oooo07P0oooo0P0000050?ooo`008P3oool00`00
0000oooo0?ooo`0B0?ooo`800000I@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
00<0oooo000R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`030000003oool0oooo00l0oooo
0P00001X0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00`3oool00280oooo0P00
000>0?ooo`800000JP3oool00`000000oooo0?ooo`1h0?ooo`8000001@3oool00280oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00`3oool000P0oooo0`0000030?ooo`<000000P3oool500000080oooo0`0000050?oo
o`030000003oool0oooo00X0oooo0P00001]0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool00`3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`06
0000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo00<0oooo00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool30000
00L0oooo0P00001`0?ooo`030000003oool0oooo07L0oooo0`0000050?ooo`002@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P00001b0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`0000050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00<0
oooo00080?ooo`800000103oool2000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`<000000P3oool5000000@0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00<0oooo000R0?ooo`800000103oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000D0oooo
000R0?ooooT000001@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool003D0oooo
0`00002:0?ooo`030000003oool0oooo02/0oooo0`00000E0?ooo`030000003oool0oooo01D0oooo
000f0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01@0oooo000`0?ooo`<000000`3oool3000000@0oooo0P000002
0?ooo`D000000P3oool3000000<0oooo100000000`3oool0000000000003000000L0oooo0`000004
0?ooo`@000000`3oool200000080oooo1P0000060?ooo`@000000P3oool5000000030?ooo`000000
000000<0000000<0oooo0000000000000`0000020?ooo`<000000P3oool3000000@0oooo0`000002
0?ooo`<0000000@0oooo000000000000oooo0`0000030?ooo`<000002@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0000000<0oooo100000030?ooo`030000003oool0oooo0080oooo0`00
00020?ooo`D000000P3oool300000080oooo0`000000103oool000000000003oool4000000<0oooo
0P0000020?ooo`X000001@3oool00`000000oooo0?ooo`0C0?ooo`00;`3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000001P3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0C0?ooo`00;`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3o
ool3000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`<000000`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool0oooo1@0000020?ooo`030000003oool0oooo0080oooo1@0000020?ooo`060000003oool0oooo
0000003oool000001@3oool5000000P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000
003oool000000080oooo0`0000030?ooo`030000003oool000000080oooo1@0000030?ooo`040000
003oool0oooo0?ooo`D000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@00000
0?ooo`3oool000001@3oool010000000oooo0?ooo`0000020?ooo`<000001@3oool00`000000oooo
0?ooo`0C0?ooo`00;`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool30000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`04
0000003oool0oooo000000D0oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`030000003o
ool0oooo01<0oooo000_0?ooo`060000003oool0oooo0?ooo`000000oooo100000020?ooo`@00000
0P3oool3000000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`040000
003oool0oooo00000080oooo0P0000030?ooo`@000000`3oool3000000T0oooo00D000000?ooo`3o
ool000000?ooo`03000000@0oooo100000020?ooo`@000000P3oool300000080oooo0P0000000`3o
ool00000000000020?ooo`<000000P3oool4000000<0oooo0`0000030?ooo`<000002@3oool00`00
0000oooo0?ooo`020?ooo`H0000000<0oooo0000000000000`3oool2000000030?ooo`0000000000
0080oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000020?ooo`@000000`3oool90000
00<0oooo0`0000030?ooo`@00000103oool00`000000oooo0?ooo`0C0?ooo`00;`3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`09
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00300oooo0`000009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool3000000T0oooo10000009
0?ooo`030000003oool0oooo0080oooo0P00000:0?ooo`@00000103oool00`000000oooo0?ooo`04
0?ooo`800000103oool2000002h0oooo00<000000?ooo`3oool0603oool3000001H0oooo00<00000
0?ooo`3oool00P3oool2000000/0oooo00<000000?ooo`3oool05@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.134655, -1308.63, \
0.000849626, 1.15564}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-10.477741155507537`\), 
                      11.43635881489974`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-10.477741155507537`\), 
                      11.43635881489974`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {107.52678245056468`, 
                117.36450138109524`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(PlotDomain \[Rule] {\(-0.1`\), 0.1`}\), 
            ",", \(RayBoundary \[Rule] {\(-10.477741155507537`\), 
                11.43635881489974`}\), ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-10.477741155507537`\), 
                      11.43635881489974`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\)}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.43635881489974`\), 
                      10.477741155507537`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.43635881489974`\), 
                      10.477741155507537`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {107.52678245056468`, 
                117.36450138109524`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(PlotDomain \[Rule] {\(-0.1`\), 0.1`}\), 
            ",", \(RayBoundary \[Rule] {\(-11.43635881489974`\), 
                10.477741155507537`}\), ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.43635881489974`\), 
                      10.477741155507537`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\)}], 
          "}"}]}], "}"}]], "Output",
  CellLabel->"Out[29]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindInterference[wavefront,PlotDomain->{-.005,.005}];", "Input",
  CellLabel->"In[30]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 95.2381 0.0101333 0.00174242 [
[.11905 -0.0125 -18 -9 ]
[.11905 -0.0125 18 0 ]
[.30952 -0.0125 -18 -9 ]
[.30952 -0.0125 18 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -15 -9 ]
[.69048 -0.0125 15 0 ]
[.88095 -0.0125 -15 -9 ]
[.88095 -0.0125 15 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01013 -6 -4.5 ]
[-0.0125 .01013 0 4.5 ]
[-0.0125 .09725 -12 -4.5 ]
[-0.0125 .09725 0 4.5 ]
[-0.0125 .18437 -18 -4.5 ]
[-0.0125 .18437 0 4.5 ]
[-0.0125 .2715 -18 -4.5 ]
[-0.0125 .2715 0 4.5 ]
[-0.0125 .35862 -18 -4.5 ]
[-0.0125 .35862 0 4.5 ]
[-0.0125 .44574 -18 -4.5 ]
[-0.0125 .44574 0 4.5 ]
[-0.0125 .53286 -18 -4.5 ]
[-0.0125 .53286 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -66 0 ]
[.5 .63053 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-0.004)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-0.002)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(0.002)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(0.004)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01013 m
.00625 .01013 L
s
[(0)] -0.0125 .01013 1 0 Mshowa
0 .09725 m
.00625 .09725 L
s
[(50)] -0.0125 .09725 1 0 Mshowa
0 .18437 m
.00625 .18437 L
s
[(100)] -0.0125 .18437 1 0 Mshowa
0 .2715 m
.00625 .2715 L
s
[(150)] -0.0125 .2715 1 0 Mshowa
0 .35862 m
.00625 .35862 L
s
[(200)] -0.0125 .35862 1 0 Mshowa
0 .44574 m
.00625 .44574 L
s
[(250)] -0.0125 .44574 1 0 Mshowa
0 .53286 m
.00625 .53286 L
s
[(300)] -0.0125 .53286 1 0 Mshowa
.125 Mabswid
0 .02756 m
.00375 .02756 L
s
0 .04498 m
.00375 .04498 L
s
0 .06241 m
.00375 .06241 L
s
0 .07983 m
.00375 .07983 L
s
0 .11468 m
.00375 .11468 L
s
0 .1321 m
.00375 .1321 L
s
0 .14953 m
.00375 .14953 L
s
0 .16695 m
.00375 .16695 L
s
0 .2018 m
.00375 .2018 L
s
0 .21922 m
.00375 .21922 L
s
0 .23665 m
.00375 .23665 L
s
0 .25407 m
.00375 .25407 L
s
0 .28892 m
.00375 .28892 L
s
0 .30634 m
.00375 .30634 L
s
0 .32377 m
.00375 .32377 L
s
0 .34119 m
.00375 .34119 L
s
0 .37604 m
.00375 .37604 L
s
0 .39347 m
.00375 .39347 L
s
0 .41089 m
.00375 .41089 L
s
0 .42831 m
.00375 .42831 L
s
0 .46316 m
.00375 .46316 L
s
0 .48059 m
.00375 .48059 L
s
0 .49801 m
.00375 .49801 L
s
0 .51543 m
.00375 .51543 L
s
0 .55028 m
.00375 .55028 L
s
0 .56771 m
.00375 .56771 L
s
0 .58513 m
.00375 .58513 L
s
0 .60256 m
.00375 .60256 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01013 m
1 .01013 L
s
.99375 .09725 m
1 .09725 L
s
.99375 .18437 m
1 .18437 L
s
.99375 .2715 m
1 .2715 L
s
.99375 .35862 m
1 .35862 L
s
.99375 .44574 m
1 .44574 L
s
.99375 .53286 m
1 .53286 L
s
.125 Mabswid
.99625 .02756 m
1 .02756 L
s
.99625 .04498 m
1 .04498 L
s
.99625 .06241 m
1 .06241 L
s
.99625 .07983 m
1 .07983 L
s
.99625 .11468 m
1 .11468 L
s
.99625 .1321 m
1 .1321 L
s
.99625 .14953 m
1 .14953 L
s
.99625 .16695 m
1 .16695 L
s
.99625 .2018 m
1 .2018 L
s
.99625 .21922 m
1 .21922 L
s
.99625 .23665 m
1 .23665 L
s
.99625 .25407 m
1 .25407 L
s
.99625 .28892 m
1 .28892 L
s
.99625 .30634 m
1 .30634 L
s
.99625 .32377 m
1 .32377 L
s
.99625 .34119 m
1 .34119 L
s
.99625 .37604 m
1 .37604 L
s
.99625 .39347 m
1 .39347 L
s
.99625 .41089 m
1 .41089 L
s
.99625 .42831 m
1 .42831 L
s
.99625 .46316 m
1 .46316 L
s
.99625 .48059 m
1 .48059 L
s
.99625 .49801 m
1 .49801 L
s
.99625 .51543 m
1 .51543 L
s
.99625 .55028 m
1 .55028 L
s
.99625 .56771 m
1 .56771 L
s
.99625 .58513 m
1 .58513 L
s
.99625 .60256 m
1 .60256 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Interference Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .06426 m
.03111 .25857 L
.03491 .38162 L
.03692 .44291 L
.03907 .50106 L
.0411 .54595 L
.04294 .57648 L
.04383 .58727 L
.0443 .59187 L
.0448 .59592 L
.04523 .59874 L
.04546 .59996 L
.04571 .60107 L
.04594 .60189 L
.04614 .60248 L
.04635 .60292 L
.04655 .60318 L
.04679 .60332 L
.04692 .6033 L
.04704 .60324 L
.04726 .60297 L
.0475 .60249 L
.04771 .60189 L
.04791 .60118 L
.04836 .59905 L
.04885 .59593 L
.04929 .59235 L
.05029 .5818 L
.05115 .57012 L
.05208 .55476 L
.05377 .52027 L
.05751 .41986 L
.06148 .29307 L
.0652 .17652 L
.06861 .08879 L
.07039 .05476 L
.07129 .04132 L
.07227 .02964 L
.07277 .02487 L
.07325 .0212 L
.07352 .01952 L
.07381 .01798 L
.07404 .01692 L
.07431 .016 L
.07456 .01535 L
.07479 .01495 L
.07503 .01474 L
.07517 .01472 L
.0753 .01476 L
.07552 .01497 L
Mistroke
.07576 .0154 L
.07599 .01601 L
.07621 .01674 L
.07671 .01911 L
.07717 .02208 L
.07821 .03151 L
.07913 .04289 L
.08009 .05788 L
.08361 .13513 L
.0908 .35733 L
.0948 .47737 L
.0967 .52403 L
.09845 .55876 L
.09931 .57249 L
.10026 .58483 L
.10122 .59415 L
.10174 .5979 L
.10197 .59926 L
.10223 .60053 L
.10244 .6014 L
.10267 .60215 L
.10291 .60274 L
.10313 .60311 L
.10335 .60329 L
.10356 .60331 L
.10375 .60318 L
.10395 .6029 L
.10418 .60242 L
.10442 .60169 L
.10468 .60068 L
.10492 .59954 L
.10581 .59349 L
.1063 .58897 L
.10675 .58405 L
.10778 .57035 L
.10965 .53688 L
.11316 .44926 L
.12057 .21486 L
.12238 .16115 L
.12429 .11102 L
.12605 .07242 L
.1277 .0446 L
.12854 .03369 L
.12944 .0247 L
.12996 .02083 L
.13044 .01803 L
.13065 .01708 L
.13088 .01625 L
.13112 .01554 L
.13135 .01508 L
Mistroke
.13159 .01479 L
.13182 .01472 L
.13194 .01475 L
.13207 .01486 L
.13232 .01521 L
.13255 .01574 L
.13279 .0165 L
.13322 .01841 L
.13378 .02184 L
.13431 .02607 L
.13529 .03654 L
.13617 .04869 L
.13714 .06486 L
.13909 .10582 L
.14258 .20128 L
.14658 .32923 L
.15022 .44308 L
.15203 .49264 L
.154 .5381 L
.1549 .5554 L
.15586 .57107 L
.1567 .58237 L
.15758 .59171 L
.15802 .59538 L
.1585 .5986 L
.15872 .59976 L
.15894 .60081 L
.15915 .60164 L
.15935 .60225 L
.1596 .60283 L
.15973 .60304 L
.15987 .6032 L
.1601 .60332 L
.16023 .6033 L
.16035 .60322 L
.16058 .60293 L
.16079 .60251 L
.16103 .60182 L
.16126 .60097 L
.16168 .59894 L
.16212 .59611 L
.16291 .58929 L
.16386 .57835 L
.16472 .56589 L
.16662 .53014 L
.16836 .48863 L
.1723 .37313 L
.17617 .24778 L
.17978 .14052 L
.18156 .09635 L
Mistroke
.18325 .0622 L
.18418 .04696 L
.1852 .0336 L
.18564 .0288 L
.18612 .02446 L
.18652 .02137 L
.18697 .01865 L
.18721 .01745 L
.18744 .01653 L
.18766 .01582 L
.18789 .01526 L
.18812 .0149 L
.18834 .01474 L
.18853 .01473 L
.18874 .01488 L
.18897 .01523 L
.18911 .01551 L
.18923 .01583 L
.18947 .01664 L
.18974 .01776 L
.19022 .02041 L
.19066 .02354 L
.19151 .03155 L
.19243 .04305 L
.19411 .07105 L
.19589 .10952 L
.19785 .16089 L
.20182 .28339 L
.20578 .41055 L
.20751 .46151 L
.20941 .51075 L
.21113 .54774 L
.21297 .57766 L
.21399 .58948 L
.21491 .59714 L
.21536 .59975 L
.2156 .60084 L
.21584 .60178 L
.21606 .60242 L
.2163 .60293 L
.21652 .60321 L
.21672 .60332 L
.21696 .60325 L
.21709 .60313 L
.21721 .60296 L
.21744 .60249 L
.21766 .60187 L
.21792 .60092 L
.21815 .59983 L
.21869 .59666 L
Mistroke
.21912 .59334 L
.2196 .58894 L
.22055 .57772 L
.22237 .54834 L
.22406 .51222 L
.23142 .29306 L
.23517 .1757 L
.23714 .12182 L
.23924 .0745 L
.2411 .04301 L
.24216 .03008 L
.24265 .02544 L
.24316 .02145 L
.24359 .01876 L
.24382 .01762 L
.24407 .01661 L
.24429 .01586 L
.2445 .01535 L
.24471 .01498 L
.2449 .01478 L
.24513 .01472 L
.24537 .01486 L
.24558 .01515 L
.2458 .01564 L
.24605 .01637 L
.24631 .01739 L
.24678 .01986 L
.24726 .02321 L
.24777 .02767 L
.2487 .03796 L
.24969 .05219 L
.25079 .07153 L
.25459 .16344 L
.26217 .4028 L
.26566 .50106 L
.26764 .54496 L
.2686 .56238 L
.26948 .57572 L
.27035 .58654 L
.2713 .59531 L
.27183 .59878 L
.27206 .59999 L
.27231 .60112 L
.27253 .60191 L
.27277 .60257 L
.2729 .60285 L
.27302 .60304 L
.27326 .60328 L
.2735 .6033 L
.27364 .60323 L
Mistroke
.27376 .60309 L
.27401 .60268 L
.27424 .6021 L
.2745 .60117 L
.27475 .6001 L
.2753 .59688 L
.27575 .59347 L
.27625 .58891 L
.27724 .57715 L
.27917 .54527 L
.28093 .50677 L
.28488 .39554 L
.2888 .26925 L
.29242 .15848 L
.29423 .11102 L
.29593 .07369 L
.2977 .04368 L
.29864 .03185 L
.29914 .02687 L
.29966 .02248 L
.30015 .01925 L
.3006 .01706 L
.30081 .01626 L
.30105 .01558 L
.30127 .01512 L
.30147 .01485 L
.30171 .01472 L
.30193 .01478 L
.30217 .01506 L
.30231 .01531 L
.30243 .01559 L
.30268 .01633 L
.30295 .01739 L
.30345 .02001 L
.30397 .02374 L
.30445 .02796 L
.30552 .04023 L
.30651 .05496 L
.30744 .0716 L
.31124 .16362 L
.31473 .27109 L
.3186 .39593 L
.32221 .49855 L
.32399 .53911 L
.32568 .56923 L
.32661 .58204 L
.3271 .58762 L
.32762 .59263 L
.32806 .59611 L
.32854 .59916 L
Mistroke
.32875 .60024 L
.32898 .60122 L
.32919 .60196 L
.32939 .60252 L
.32951 .60278 L
.32964 .60301 L
.32987 .60326 L
.33 .60331 L
.33014 .60331 L
.33038 .60313 L
.33061 .60277 L
.33082 .60227 L
.33105 .60154 L
.3313 .60054 L
.33186 .59747 L
.33239 .59354 L
.33338 .58354 L
.33433 .57096 L
.3352 .55675 L
.33718 .51623 L
.3407 .42098 L
.34459 .29683 L
.34855 .17295 L
.35029 .12556 L
.35219 .08151 L
.35308 .06421 L
.35403 .04836 L
.35485 .03699 L
.35575 .02722 L
.35627 .02276 L
.35676 .0195 L
.35722 .01717 L
.35745 .01629 L
.35758 .01587 L
.35771 .01554 L
.35794 .01507 L
.35815 .01481 L
.35838 .01472 L
.35863 .01483 L
.35885 .01511 L
.35908 .01559 L
.3593 .01623 L
.35949 .01695 L
.35993 .01906 L
.36042 .02217 L
.36139 .03094 L
.36229 .04196 L
.36313 .05466 L
.36503 .09126 L
.36707 .14111 L
Mistroke
.37489 .38478 L
.37881 .4974 L
.38053 .53689 L
.38144 .55457 L
.38243 .57079 L
.38337 .58344 L
.38424 .59239 L
.38467 .59585 L
.38507 .59849 L
.38549 .60063 L
.38571 .60152 L
.38594 .60226 L
.38607 .60258 L
.38619 .60284 L
.38643 .60318 L
.38668 .60332 L
.38682 .6033 L
.38695 .60321 L
.38719 .6029 L
.38741 .60243 L
.38766 .60167 L
.3879 .60075 L
.38834 .5985 L
.38875 .59579 L
.38968 .5875 L
.39064 .57575 L
.39168 .55965 L
.39357 .52217 L
.39709 .42891 L
.40079 .31155 L
.40485 .18324 L
.40672 .13115 L
.40872 .0839 L
.40969 .06484 L
.41061 .04941 L
.4115 .03704 L
.41233 .02785 L
.4132 .02077 L
.41366 .0181 L
.41392 .01694 L
.41416 .01609 L
.4144 .01542 L
.41463 .015 L
.41477 .01484 L
.41489 .01475 L
.41502 .01472 L
.41515 .01474 L
.41539 .01495 L
.41561 .01532 L
.41585 .01593 L
Mistroke
.4161 .01679 L
.41651 .0187 L
.41696 .02143 L
.41776 .02812 L
.41872 .03896 L
.41958 .05149 L
.42146 .0864 L
.42319 .12728 L
.42711 .24179 L
.43094 .36575 L
.43453 .47337 L
.43621 .51557 L
.43797 .55232 L
.43889 .56795 L
.4399 .58195 L
.44081 .59172 L
.44123 .59518 L
.44167 .59818 L
.4419 .59952 L
.44216 .60076 L
.4424 .60168 L
.44262 .60235 L
.44274 .60265 L
.44288 .60291 L
.44302 .60312 L
.44315 .60325 L
.44328 .60331 L
.44341 .60331 L
.44365 .60315 L
.4439 .60278 L
.44404 .60248 L
.44416 .60214 L
.44439 .60138 L
.44464 .60033 L
.44507 .59798 L
.44553 .59477 L
.44641 .58657 L
.44735 .57488 L
.44904 .54661 L
.45097 .50436 L
.45306 .44845 L
.45687 .33007 L
.46054 .21213 L
.46249 .1548 L
.46459 .10116 L
.46659 .06039 L
.46746 .04629 L
.46842 .03372 L
.46886 .02897 L
.46933 .02465 L
Mistroke
.46973 .02153 L
.47017 .01881 L
.47043 .01752 L
.47067 .01655 L
.4709 .01582 L
.47114 .01524 L
.47135 .0149 L
.47156 .01474 L
.47178 .01473 L
.47201 .01492 L
.47224 .0153 L
.47237 .0156 L
.4725 .01593 L
.47277 .01686 L
.47301 .01793 L
.47345 .02042 L
.47393 .02389 L
.47495 .03391 L
.47602 .04826 L
.47784 .0808 L
.47982 .12693 L
.48748 .36237 L
.49102 .46893 L
.49288 .51621 L
.49485 .55666 L
.49585 .5727 L
.49695 .58662 L
.49743 .59144 L
.49795 .59572 L
.49844 .5989 L
.49888 .60106 L
.49912 .60191 L
.49937 .60259 L
.4996 .60303 L
.49982 .60326 L
.49995 .60331 L
.50007 .60331 L
.5002 .60325 L
.50034 .60311 L
.50058 .60272 L
.50071 .60241 L
.50083 .60206 L
.5013 .60025 L
.50173 .59792 L
.50222 .59443 L
.50269 .59033 L
.50356 .58071 L
.50451 .56719 L
.50645 .53109 L
.50993 .442 L
Mistroke
.51754 .20145 L
.52103 .1059 L
.52301 .0644 L
.52397 .04832 L
.52485 .0363 L
.5253 .03109 L
.52579 .02624 L
.52622 .02272 L
.52668 .01958 L
.52718 .01709 L
.52745 .01611 L
.52758 .01572 L
.5277 .01542 L
.52794 .01499 L
.52815 .01477 L
.52839 .01472 L
.52852 .01478 L
.52864 .0149 L
.52877 .01508 L
.52889 .0153 L
.52916 .01599 L
.5294 .01681 L
.52965 .01791 L
.53009 .02035 L
.53057 .02381 L
.53163 .03434 L
.53263 .04761 L
.53461 .08337 L
.53648 .12723 L
.53999 .22867 L
.54725 .45737 L
.54918 .50807 L
.55099 .54735 L
.55288 .57807 L
.55389 .58965 L
.55445 .59464 L
.55497 .59823 L
.55521 .59959 L
.55544 .60068 L
.55565 .60151 L
.55587 .60222 L
.55611 .60279 L
.55633 .60313 L
.55657 .60331 L
.5567 .60331 L
.55683 .60326 L
.55705 .60302 L
.55726 .60263 L
.55745 .60214 L
.55766 .60146 L
Mistroke
.55812 .59938 L
.55855 .59676 L
.55946 .58916 L
.56045 .5775 L
.56247 .54406 L
.56437 .50167 L
.56612 .4552 L
.57006 .33334 L
.57394 .20886 L
.57583 .15346 L
.57755 .10895 L
.57922 .07264 L
.58103 .04242 L
.58202 .03031 L
.58246 .02606 L
.58294 .02215 L
.58336 .01938 L
.58382 .01712 L
.58407 .01619 L
.5843 .01554 L
.58453 .01507 L
.58475 .01481 L
.58498 .01472 L
.58511 .01475 L
.58524 .01484 L
.58546 .01515 L
.5857 .01567 L
.58591 .01632 L
.58611 .01706 L
.58656 .01928 L
.58705 .02251 L
.58749 .02617 L
.58849 .03691 L
.58935 .04876 L
.59028 .06429 L
.59197 .09905 L
.59571 .20003 L
.59968 .32701 L
.60341 .44349 L
.60682 .53074 L
.60861 .56446 L
.60951 .57771 L
.61049 .58915 L
.61099 .59379 L
.61147 .59734 L
.61174 .59895 L
.61203 .60042 L
.61227 .60141 L
.61253 .60226 L
.61278 .60284 L
Mistroke
.61301 .60317 L
.61325 .60332 L
.61339 .6033 L
.61352 .60323 L
.61374 .60296 L
.61398 .60245 L
.61422 .60178 L
.61443 .60099 L
.61488 .59875 L
.6153 .59605 L
.61624 .58771 L
.61707 .57783 L
.61795 .56495 L
.61981 .52983 L
.62184 .48071 L
.6295 .243 L
.63303 .13845 L
.63489 .09289 L
.63686 .05467 L
.63786 .03989 L
.63839 .03337 L
.63896 .02742 L
.63948 .02295 L
.63996 .01969 L
.64019 .01842 L
.64044 .01724 L
.64065 .01639 L
.64089 .01567 L
.64103 .01535 L
.64115 .01511 L
.64139 .01481 L
.64161 .01472 L
.64185 .01481 L
.64197 .01494 L
.6421 .01513 L
.64233 .01564 L
.64248 .01605 L
.64261 .0165 L
.64286 .01753 L
.64332 .01995 L
.64374 .02286 L
.6447 .03172 L
.64557 .04259 L
.64652 .05712 L
.64822 .09028 L
.65212 .19278 L
.65583 .31074 L
.65989 .43871 L
.66177 .49048 L
.66377 .53709 L
Mistroke
.66475 .5558 L
.66566 .57082 L
.66655 .58277 L
.66738 .59154 L
.66784 .59536 L
.66826 .5982 L
.66872 .60063 L
.66898 .60164 L
.66922 .60238 L
.66945 .60289 L
.6697 .60321 L
.66994 .60332 L
.67015 .60324 L
.67028 .60311 L
.6704 .60293 L
.67053 .60268 L
.67067 .60235 L
.67091 .60163 L
.67116 .60061 L
.67162 .59822 L
.67204 .5954 L
.67297 .58687 L
.67383 .5763 L
.67465 .56404 L
.67648 .52921 L
.67842 .48241 L
.68191 .38002 L
.68905 .1555 L
.69084 .10908 L
.69271 .06875 L
.6937 .05166 L
.69477 .03651 L
.69525 .03106 L
.69575 .02608 L
.69618 .02252 L
.69666 .01937 L
.69715 .01696 L
.69742 .01601 L
.69755 .01565 L
.69767 .01536 L
.6979 .01495 L
.69812 .01475 L
.69835 .01473 L
.69848 .0148 L
.6986 .01492 L
.69885 .01533 L
.69908 .01593 L
.69934 .01681 L
.69962 .01802 L
.70018 .02135 L
Mistroke
.7007 .02539 L
.70159 .03446 L
.70256 .04743 L
.70451 .08257 L
.70821 .17642 L
.71217 .30066 L
.71593 .42051 L
.71791 .47716 L
.72001 .52833 L
.72188 .56403 L
.72294 .57954 L
.72393 .59065 L
.7244 .5947 L
.72485 .59784 L
.72524 .60006 L
.72547 .60105 L
.72568 .60183 L
.72593 .60253 L
.72615 .60297 L
.72639 .60325 L
.72653 .60331 L
.72665 .60331 L
.72686 .60318 L
.72709 .60286 L
.72733 .60231 L
.72756 .60162 L
.72805 .59946 L
.7285 .59669 L
.729 .59281 L
.72953 .58774 L
.73141 .56228 L
.73307 .53038 L
.73491 .48649 L
.74252 .25173 L
.74601 .14686 L
.74799 .09726 L
.74983 .06022 L
.75077 .04516 L
.75166 .0336 L
.75216 .02835 L
.75269 .0236 L
.75317 .02018 L
.75362 .01772 L
.75385 .01674 L
.7541 .0159 L
.75424 .01552 L
.75438 .01523 L
.7545 .01502 L
.75463 .01486 L
.75477 .01475 L
Mistroke
.7549 .01472 L
.75504 .01475 L
.75518 .01485 L
.75543 .0152 L
.75557 .0155 L
.7557 .01583 L
.75614 .01745 L
.75639 .01868 L
.75663 .02003 L
.75714 .02365 L
.75761 .0278 L
.75856 .03849 L
.75959 .0535 L
.76147 .08915 L
.76498 .17986 L
.77241 .41552 L
.77432 .47092 L
.77614 .51689 L
.77791 .55355 L
.77956 .5792 L
.78041 .58897 L
.78131 .59665 L
.78156 .59826 L
.78183 .59975 L
.78207 .60085 L
.78232 .60179 L
.78254 .60245 L
.78279 .60296 L
.78301 .60323 L
.78323 .60332 L
.78347 .60322 L
.78361 .60306 L
.78374 .60286 L
.78397 .60233 L
.78422 .60156 L
.78465 .59968 L
.78513 .59684 L
.78564 .59294 L
.78618 .58772 L
.78717 .57571 L
.78898 .54557 L
.79096 .5018 L
.79494 .38809 L
.79896 .25828 L
.80261 .14823 L
.80443 .10207 L
.8064 .06156 L
.80731 .04684 L
.80826 .03413 L
.80908 .02573 L
Mistroke
.80955 .02198 L
.80998 .01919 L
.81045 .01691 L
.8107 .01604 L
.81083 .01567 L
.81097 .01534 L
.8111 .01509 L
.81122 .01492 L
.81146 .01473 L
.81167 .01474 L
.8119 .01493 L
.81211 .01527 L
.81234 .01581 L
.81255 .01649 L
.81274 .01724 L
.81321 .01965 L
.81366 .02266 L
.81464 .03175 L
.81555 .04309 L
.8176 .07848 L
.81943 .11992 L
.82114 .16582 L
.82503 .28665 L
.82853 .39932 L
.83051 .45819 L
.83235 .50653 L
.83434 .54948 L
.83615 .57842 L
.83714 .58981 L
.83759 .5939 L
.83808 .59744 L
.83832 .59892 L
.83859 .60031 L
.83884 .60135 L
.83906 .60211 L
.83919 .60246 L
.83933 .60277 L
.83948 .60302 L
.83962 .60319 L
.83975 .60329 L
.83989 .60332 L
.84014 .6032 L
.84035 .60292 L
.84058 .60242 L
.84083 .60169 L
.84106 .60082 L
.84147 .59879 L
.8419 .59595 L
.8429 .58696 L
.84381 .57583 L
Mistroke
.84558 .54638 L
.84726 .51009 L
.85452 .29336 L
.8582 .17809 L
.86015 .12456 L
.86225 .07666 L
.86328 .0576 L
.86425 .04253 L
.86513 .03165 L
.86563 .0266 L
.86609 .02278 L
.86652 .01982 L
.86699 .01737 L
.86725 .01636 L
.86749 .01565 L
.86771 .01515 L
.86795 .01483 L
.86816 .01472 L
.86838 .01477 L
.86859 .01498 L
.86878 .01531 L
.869 .01587 L
.86925 .01667 L
.86969 .01868 L
.87013 .02138 L
.8706 .02506 L
.87146 .03373 L
.87249 .04729 L
.87342 .06268 L
.87739 .15483 L
.88488 .39016 L
.88866 .49817 L
.8903 .53595 L
.89209 .56835 L
.89308 .58206 L
.894 .59178 L
.89445 .59552 L
.89487 .59835 L
.89531 .60064 L
.89554 .60157 L
.8958 .60235 L
.89592 .60266 L
.89606 .60292 L
.8963 .60323 L
.89645 .60331 L
.89659 .60331 L
.89672 .60325 L
.89686 .60312 L
.89698 .60295 L
.89711 .6027 L
Mistroke
.89738 .602 L
.89763 .60111 L
.89786 .60009 L
.89834 .59737 L
.89878 .5942 L
.89976 .58466 L
.90067 .57284 L
.90163 .55735 L
.90337 .52254 L
.9073 .41717 L
.91444 .19001 L
.91811 .09328 L
.91916 .07137 L
.92017 .05355 L
.92116 .0391 L
.92205 .02879 L
.9225 .02467 L
.92298 .02101 L
.92344 .01831 L
.92386 .01649 L
.92409 .01575 L
.92431 .01525 L
.92455 .01488 L
.92468 .01477 L
.9248 .01472 L
.92504 .01478 L
.92518 .01491 L
.92531 .01509 L
.92554 .01558 L
.92579 .01631 L
.9262 .01801 L
.92664 .02051 L
.92744 .02679 L
.92839 .03714 L
.92927 .04929 L
.93112 .08295 L
.93284 .12285 L
.93675 .2359 L
.94412 .46706 L
.94606 .51628 L
.94708 .53851 L
.94815 .55886 L
.9491 .57373 L
.95013 .58675 L
.95059 .5913 L
.95108 .5954 L
.95154 .5985 L
.95196 .60066 L
.95221 .60163 L
.95244 .60235 L
Mistroke
.95269 .60289 L
.95283 .6031 L
.95295 .60323 L
.95317 .60332 L
.9534 .60322 L
.95365 .60291 L
.95387 .60243 L
.954 .60207 L
.95415 .60161 L
.9544 .6006 L
.95488 .59806 L
.95544 .59406 L
.95596 .58938 L
.95684 .57938 L
.9578 .56539 L
.95976 .52828 L
.96342 .43292 L
.96736 .3082 L
.97108 .19034 L
.97514 .08488 L
.97619 .06426 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[30]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00<@3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000040?oo
o`<00000503oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000020?oo
o`D000007@3oool200000280oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000P3oool5000001@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`800000103oool3000001X0oooo000`0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000703oool010000000oooo0?ooo`00000P0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000001<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06@3oool002T0oooo
1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`000000oooo00D00000303oool500000080oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01<0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0000003oool01@00000J0?ooo`00<03oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo0180
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool06`3oool010000000oooo0?ooo`00000P0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`0I0?oo
o`00<03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0000000D0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool06P3oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool04@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0000000K0?ooo`00<03oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool2
000001@0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo
00000200oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000
6`3oool00340oooo0P00000:0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool04`3o
ool2000000X0oooo0P0000040?ooo`8000000`3oool3000001h0oooo0P00000R0?ooo`8000002P3o
ool2000000@0oooo0P0000030?ooo`<000005@3oool2000000X0oooo0P0000040?ooo`8000001@3o
ool00`000000oooo0?ooo`0I0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`005`3oool2000000D0oooon000000:0?ooo`005P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool001H0oooo00@00000
0?ooo`3oool00000103oool2000007T0oooo00<000000?ooo`3oool0N03oool2000000X0oooo000F
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03`3oool2000000`0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
00050?ooo`030000003oool0oooo00@0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?oo
o`080?ooo`005P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00l0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
000<0?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`800000303oool2000000`0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool200000140oooo00<0
00000?ooo`3oool0203oool001H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0?0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
000<0?ooo`800000303oool2000000D0oooo00<000000?ooo`3oool0103oool2000000`0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
000A0?ooo`030000003oool0oooo00P0oooo000G0?ooo`8000001@3oool200000100oooo0P00000<
0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<
0?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`800000303oool2000000`0oooo0P00000<
0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool200000100oooo0P00000:
0?ooo`007P3oool00`000000oooo0?ooo`0?0?ooo`800000303oool2000000`0oooo0P00000<0?oo
o`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000D0oooo00<000000?oo
o`3oool0103oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?oo
o`800000303oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo00l0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`80
0000303oool2000000`0oooo0P00000<0?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`80
0000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`80
0000303oool200000140oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
3`3oool2000000`0oooo0P00000<0?ooo`8000002`3oool00`000000oooo0000000<0?ooo`800000
303oool2000000`0oooo0P00000<0?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`800000
303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000
303oool200000140oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool03`3o
ool2000000/0oooo00<000000?ooo`0000002`3oool00`000000oooo0000000;0?ooo`030000003o
ool0000000/0oooo00<000000?ooo`000000303oool2000000`0oooo0P00000;0?ooo`030000003o
ool0000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000;0?ooo`800000303o
ool2000000`0oooo00<000000?ooo`0000002P3oool00`000000oooo0000000;0?ooo`030000003o
ool0000000`0oooo00<000000?ooo`0000002`3oool200000140oooo00<000000?ooo`3oool0203o
ool001h0oooo0P00000@0?ooo`8000002`3oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0000000/0oooo00<000000?ooo`0000002`3oool00`000000oooo0000000;0?ooo`030000003o
ool0000000/0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000000;0?oo
o`8000002`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0000000/0oooo00<00000
0?ooo`000000303oool00`000000oooo0000000;0?ooo`030000003oool0000000l0oooo0P00000:
0?ooo`007P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000/0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0000000;0?ooo`040000003oool0oooo000000X0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`0000002P3oool00`000000oooo0000000;0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0000000<0?ooo`03
0000003oool0000000X0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`080?oo
o`007P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0000000;0?ooo`040000003oool0oooo000000X0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0000000;0?oo
o`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?oo
o`080?ooo`007P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000X0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0000000;0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000403oool00`00
0000oooo0?ooo`080?ooo`007P3oool2000000l0oooo00@000000?ooo`3oool000002P3oool01000
0000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000?0?oo
o`8000002P3oool001h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`04
0000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3o
ool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`007P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3o
ool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool001h0
oooo0P0000040?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000002P3oool01000
0000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo0080oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo
0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00100oooo0`0000040?ooo`8000001@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000002P3oool01000
0000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool000l0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00P0oooo000C0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
203oool001<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000
103oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3o
ool000002P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo0080oooo0P00000:0?ooo`003`3oool4000000<0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo000000090?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3o
ool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`003`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002@3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`0000090?ooo`050000003oool0oooo0?ooo`0000002P3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002P3oool01000
0000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo000?0?oo
o`D000000`3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`0000002@3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?oo
o`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000X0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00002@3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00D000000?ooo`3oool0oooo000000090?ooo`040000003oool0oooo000000X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000@0oooo00<000000?oo
o`3oool0203oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3o
ool000002@3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo
0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0080oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000090?ooo`040000003oool0
oooo000000T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`00
00002@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000090?ooo`040000
003oool0oooo000000T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`050000
003oool0oooo0?ooo`0000002@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000oooo0?ooo`000009
0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000T0oooo
00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000oooo0?oo
o`0000090?ooo`050000003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`00000:0?oo
o`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?oo
o`3oool0000000T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1`3oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002@3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00D000000?ooo`3oool0oooo000000090?ooo`050000003o
ool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00D000000?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool000002@3oool01@000000
oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0
oooo0?ooo`0000002@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool001h0oooo0P0000050?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`040000003oool0oooo000000T0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002@3oool0
1@000000oooo0?ooo`3oool0000000X0oooo00D000000?ooo`3oool0oooo000000080?ooo`050000
003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000X0oooo00D000000?oo
o`3oool0oooo000000090?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3o
ool2000000X0oooo000N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000002@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00D000000?ooo`3oool0oooo000000090?ooo`05
0000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000203oool01@000000oooo
0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000P0oooo
00D000000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`0000002@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool01@000000oooo
0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool00000
00T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool0000000X0oooo00D000000?ooo`3oool0oooo000000090?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000203oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`07
0?ooo`050000003oool0oooo0?ooo`000000203oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`007P3oool2000000D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00D000000?ooo`3oool0oooo000000080?ooo`050000003oool0oooo0?ooo`000000
2@3oool00`000000oooo0?ooo`030?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool001h0oooo0P0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0
oooo000000090?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool00`3oool2000000X0oooo000N0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo000:0?ooo`<00000103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo000;0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00<0oooo0P00000:0?ooo`002`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`00
2`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`002P3oool2000000@0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00<0oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`080?ooo`007P3oool2000000D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool001h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool001h0oooo0P0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool2000000X0oooo
000N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000001P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo0P00000:0?ooo`007P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`080?ooo`007P3oool2000000H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0203oool000X0oooo0`0000030?ooo`<00000103o
ool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0203oool000/0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`002`3oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08
0?ooo`002`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool2000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`8000002P3o
ool000/0oooo00@000000?ooo`3oool0oooo100000030?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool000X0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`002`3oool010000000oooo0?ooo`3oool5000000<0oooo0P0000050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo000N0?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0P00000:
0?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`007P3oool20000
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool2000000X0oooo000N0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
01h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo000N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`007P3oool2000000L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool2
000000X0oooo000N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000001`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00090?ooo`D000000`3oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`002P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P0000070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`00303oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`002P3oool3000000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0203oool001h0oooo0P0000070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool2000000X0oooo000N0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0
oooo000N0?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`8000002P3oool001h0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000001`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`8000002P3oool000T0oooo1@0000020?ooo`<00000103oool2000000D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo000:0?ooo`060000
003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo000;0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`080?ooo`00303oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool2000000X0oooo00090?ooo`060000003o
ool0oooo0?ooo`000000oooo100000030?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000002@3oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0
oooo00090?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0000000T0oooo
00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`08
0?ooo`002P3oool300000080oooo1@0000030?ooo`8000001@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`00000:0?ooo`050000003o
ool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000090?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo000N0?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000X0oooo00@0
00000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3o
ool0oooo000000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool2000000X0oooo000N0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3o
ool0oooo000000090?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`00
0000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`000000
203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`050000003oool0
oooo0?ooo`0000002P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000P0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`00
00002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo000000020?ooo`030000003oool0
oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
2@3oool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool000002@3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`0000090?ooo`050000003oool0oooo0?ooo`0000002@3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`0000090?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?ooo`050000003oool0oooo
0?ooo`0000002@3oool01@000000oooo0000003oool0000000X0oooo00@000000?ooo`3oool00000
2P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000
oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
00090?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000T0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`0000090?ooo`050000003oool0oooo0?ooo`0000002P3oool200000003
0?ooo`000000oooo00T0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0
000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00P0oooo000N0?ooo`800000203oool010000000oooo0?ooo`0000090?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000:0?ooo`050000003o
ool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000P0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`070?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?oo
o`00000:0?ooo`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000:0?ooo`05
0000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool2000000030?ooo`000000oooo00T0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`0000090?ooo`050000003oool0oooo0?ooo`000000
2P3oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002P3oool01000
0000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002@3oool01@000000oooo0?ooo`3oool00000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`080?ooo`007P3o
ool2000000P0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?ooo`05
0000003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo0P0000000`3oool000000?ooo`090?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000203oool2000000X0oooo
000N0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000002P3oool010000000oooo
0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`00000:0?ooo`80000000<0oooo0000003oool02@3oool01000
0000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool0203oool000X0oooo0`0000040?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo0P0000000`3oool000000?ooo`090?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`080?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`800000
00<0oooo0000003oool02@3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0203oool000d0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0P00
00080?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3o
ool000002P3oool2000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`0000080?ooo`8000002P3oool000/0oooo0P00
00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool2000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00P0oooo000=0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3o
ool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`80000000<0oooo0000003o
ool02@3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool0203oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool2000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00P0oooo000:0?ooo`<00000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
000:0?ooo`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo
0?ooo`00000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0203oool001h0
oooo0P0000080?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool2000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000080?ooo`8000002P3oool001h0
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo0P0000000`3oool000000?ooo`090?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?oo
o`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool2000000030?ooo`00
0000oooo00T0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo
000000/0oooo0P00000;0?ooo`030000003oool0000000/0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0000000/0oooo0P0000000`3oool00000
0?ooo`090?ooo`030000003oool0000000/0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`0000002`3oool0
0`000000oooo0000000;0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000T0oooo00<000000?ooo`0000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000/0oooo0P00000;0?ooo`03
0000003oool0000000/0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0000000/0oooo0P0000000`3oool000000?ooo`0:0?ooo`8000002`3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002`3oool2000000`0oooo0P00000;0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool00000203oool2000000X0oooo000N0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`0000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000/0oooo0P00
000<0?ooo`8000002`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0000000/0oooo
00<000000?ooo`0000002`3oool2000000030?ooo`000000oooo00X0oooo0P00000<0?ooo`800000
2`3oool00`000000oooo0000000;0?ooo`040000003oool0oooo000000/0oooo0P00000<0?ooo`80
00002`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000:0?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`000000303oool2000000`0oooo0P00000;
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`000000303oool2000000/0oooo0`00
000<0?ooo`800000303oool2000000/0oooo00<000000?ooo`000000303oool00`000000oooo0000
000;0?ooo`800000303oool2000000/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0000000:0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00P0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
000<0?ooo`8000002`3oool3000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000;0?ooo`030000003oool0000000X0oooo00<0
00000?ooo`3oool0203oool001h0oooo0P0000090?ooo`800000303oool2000000`0oooo0P00000<
0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<
0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<
0?ooo`800000303oool2000000T0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`080?oo
o`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?oo
o`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?oo
o`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000X0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool0203oool2000000`0oooo0P00000<0?ooo`80
0000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`80
0000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`80
0000303oool2000000`0oooo0P00000:0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo00P0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000
303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000
303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000
2P3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`080?ooo`800000303o
ool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303o
ool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303o
ool2000000`0oooo0P00000<0?ooo`800000303oool2000000X0oooo00<000000?ooo`3oool0203o
ool001h0oooo0P0000090?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2
000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2
000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2
000000T0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`007P3ooooh000000X0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003E0?ooo`<00000B03oool00=H0oooo00<000000?ooo`3oool0A`3oool005L0oooo1@00
00001@3oool00000000000000000oooo008000000P3oool2000000<0oooo0`0000020?ooo`<00000
0`3oool500000080oooo0`0000020?ooo`<00000103oool300000080oooo0`000000103oool00000
0000003oool3000000<0oooo0`0000080?ooo`D0000000D0oooo00000000000000000?ooo`020000
0080oooo0P0000030?ooo`<000000P3oool3000000030?ooo`000000000000@000000P3oool50000
00<0oooo0P0000040?ooo`030000003oool0oooo04H0oooo001I0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo0000000=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
1P000000oooo0?ooo`000000oooo000000H0oooo00@000000?ooo`3oool000001@3oool01@000000
oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`16
0?ooo`00F@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool500000080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3o
ool500000080oooo00<000000?ooo`3oool00P3oool500000080oooo00H000000?ooo`3oool00000
0?ooo`0000050?ooo`D000002@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool500000080oooo00@000000?ooo`3oool000000P3oool3
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000004L0oooo001I0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000D0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo008000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo
00H000000?ooo`3oool000000?ooo`0000070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000170?ooo`00F@3oool010000000oooo0?ooo`3oool40000
0080oooo100000030?ooo`<000000P3oool2000000030?ooo`00000000000080oooo100000020?oo
o`<000000P3oool2000000030?ooo`00000000000080oooo0`0000020?ooo`@000000`3oool30000
00<0oooo0`00000:0?ooo`040000003oool0oooo0?ooo`@000000P3oool4000000<0oooo0`000002
0?ooo`@000000`3oool4000000040?ooo`0000000000000000<0oooo100000020?ooo`80000000<0
oooo000000000000AP3oool005T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo04d0oooo001G0?ooo`D00000203oool00`000000oooo0?ooo`0A0?oo
o`800000:`3oool5000000P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo04d0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00654138, -33.8891, \
4.24814*^-5, 2.32197}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindInterference[sys,PlotDomain->{-.005,.005}];", "Input",
  CellLabel->"In[31]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 95.2381 84.7797 0.0700193 [
[.11905 -0.0125 -18 -9 ]
[.11905 -0.0125 18 0 ]
[.30952 -0.0125 -18 -9 ]
[.30952 -0.0125 18 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -15 -9 ]
[.69048 -0.0125 15 0 ]
[.88095 -0.0125 -15 -9 ]
[.88095 -0.0125 15 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05632 -30 -4.5 ]
[-0.0125 .05632 0 4.5 ]
[-0.0125 .19636 -30 -4.5 ]
[-0.0125 .19636 0 4.5 ]
[-0.0125 .3364 -30 -4.5 ]
[-0.0125 .3364 0 4.5 ]
[-0.0125 .47644 -30 -4.5 ]
[-0.0125 .47644 0 4.5 ]
[-0.0125 .61648 -30 -4.5 ]
[-0.0125 .61648 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-0.004)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-0.002)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(0.002)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(0.004)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05632 m
.00625 .05632 L
s
[(-1210)] -0.0125 .05632 1 0 Mshowa
0 .19636 m
.00625 .19636 L
s
[(-1208)] -0.0125 .19636 1 0 Mshowa
0 .3364 m
.00625 .3364 L
s
[(-1206)] -0.0125 .3364 1 0 Mshowa
0 .47644 m
.00625 .47644 L
s
[(-1204)] -0.0125 .47644 1 0 Mshowa
0 .61648 m
.00625 .61648 L
s
[(-1202)] -0.0125 .61648 1 0 Mshowa
.125 Mabswid
0 .09133 m
.00375 .09133 L
s
0 .12634 m
.00375 .12634 L
s
0 .16135 m
.00375 .16135 L
s
0 .23137 m
.00375 .23137 L
s
0 .26638 m
.00375 .26638 L
s
0 .30139 m
.00375 .30139 L
s
0 .37141 m
.00375 .37141 L
s
0 .40642 m
.00375 .40642 L
s
0 .44143 m
.00375 .44143 L
s
0 .51145 m
.00375 .51145 L
s
0 .54646 m
.00375 .54646 L
s
0 .58147 m
.00375 .58147 L
s
0 .02131 m
.00375 .02131 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05632 m
1 .05632 L
s
.99375 .19636 m
1 .19636 L
s
.99375 .3364 m
1 .3364 L
s
.99375 .47644 m
1 .47644 L
s
.99375 .61648 m
1 .61648 L
s
.125 Mabswid
.99625 .09133 m
1 .09133 L
s
.99625 .12634 m
1 .12634 L
s
.99625 .16135 m
1 .16135 L
s
.99625 .23137 m
1 .23137 L
s
.99625 .26638 m
1 .26638 L
s
.99625 .30139 m
1 .30139 L
s
.99625 .37141 m
1 .37141 L
s
.99625 .40642 m
1 .40642 L
s
.99625 .44143 m
1 .44143 L
s
.99625 .51145 m
1 .51145 L
s
.99625 .54646 m
1 .54646 L
s
.99625 .58147 m
1 .58147 L
s
.99625 .02131 m
1 .02131 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.03853 .02381 L
.05458 .03373 L
.06965 .04305 L
.08415 .05201 L
.09958 .06155 L
.11444 .07073 L
.13023 .08048 L
.14544 .08989 L
.16007 .09893 L
.17564 .10855 L
.19063 .11782 L
.20504 .12672 L
.22039 .13621 L
.23516 .14534 L
.25087 .15504 L
.26599 .16439 L
.28054 .17339 L
.29603 .18296 L
.31093 .19217 L
.32678 .20196 L
.34204 .21139 L
.35672 .22047 L
.37234 .23012 L
.38739 .23942 L
.40185 .24836 L
.41725 .25788 L
.43208 .26704 L
.44783 .27678 L
.46301 .28616 L
.47761 .29518 L
.49315 .30478 L
.50811 .31403 L
.52249 .32292 L
.5378 .33238 L
.55254 .34149 L
.56821 .35118 L
.58331 .3605 L
.59783 .36948 L
.61328 .37903 L
.62815 .38822 L
.64396 .39799 L
.65919 .4074 L
.67385 .41646 L
.68943 .42609 L
.70445 .43537 L
.71888 .44429 L
.73425 .45379 L
.74904 .46293 L
.76476 .47265 L
Mistroke
.77991 .48201 L
.79448 .49101 L
.80998 .5006 L
.82491 .50982 L
.84077 .51962 L
.85605 .52907 L
.87076 .53816 L
.8864 .54782 L
.90146 .55713 L
.91595 .56609 L
.93137 .57562 L
.94621 .58479 L
.96198 .59454 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[31]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00=`3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000040?oo
o`<00000503oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000020?oo
o`D000007@3oool200000280oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000P3oool5000001@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`800000103oool3000001@0oooo000f0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000703oool010000000oooo0?ooo`00000P0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000001<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04`3oool002l0oooo
1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`000000oooo00D00000303oool500000080oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01<0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0000003oool01@00000D0?ooo`00=P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo0180
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool06`3oool010000000oooo0?ooo`00000P0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`0C0?oo
o`00=P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0000000D0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool06P3oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool04@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0000000E0?ooo`00=P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool2
000001@0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo
00000200oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000
5@3oool003L0oooo0P00000:0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool04`3o
ool2000000X0oooo0P0000040?ooo`8000000`3oool3000001h0oooo0P00000R0?ooo`8000002P3o
ool2000000@0oooo0P0000030?ooo`<000005@3oool2000000X0oooo0P0000040?ooo`8000001@3o
ool00`000000oooo0?ooo`0C0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00903ooooh000000@0oooo000T0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo0080oooo000T0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo07P0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`060?ooo`800000L03oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo
00P0oooo0P00001^0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool02P3oool2000006`0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0<0?ooo`800000JP3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo00h0oooo0P00
001X0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool000X0oooo0`000002
0?ooo`D000000P3oool3000000@0oooo0P0000050?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000;0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool000<0oooo1@000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04P3oool2000006@0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`002`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`8000005@3oool200000680oooo00<000000?ooo`3oool0N03oool2000000@0oooo000;
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0F0?ooo`800000H03oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000:0?ooo`8000000`3oool01@000000oooo
0?ooo`3oool000000080oooo0P0000040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool00P3oool000/0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3o
ool00`3oool2000000D0oooo00<000000?ooo`3oool06@3oool2000005d0oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0M0?ooo`800000F@3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo
01l0oooo0P00001G0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0
oooo0P00000R0?ooo`800000E@3oool00`000000oooo0?ooo`1h0?ooo`800000103oool002@0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0903oool200000580oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0V
0?ooo`800000D03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo02P0oooo0P00001>0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool00P3oool002@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0;03oool2000004X0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0^0?ooo`800000B03oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000<@3oool20000
04H0oooo00<000000?ooo`3oool0N03oool2000000@0oooo000T0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo03<0oooo0P0000130?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0=`3oool2000003l0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0i0?ooo`80
0000?@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000
003oool0oooo03/0oooo0P00000k0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0?@3oool2000003T0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`020?ooo`00903oool200000400oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1h0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0@P3oool2000003@0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?oo
o`140?ooo`800000<P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T
0?ooo`030000003oool0oooo04H0oooo0P00000`0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00P3oool000X0oooo0`0000020?ooo`D000000`3oool2000000<0oooo0`0000050?oo
o`030000003oool0oooo04P0oooo0P00000^0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool00P3oool000/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo04X0oooo0P00000/0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3o
ool000<0oooo1@0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool2000004d0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1h0?ooo`800000103oool000/0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0`0000050?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo0080oooo000;0?ooo`050000003oool0oooo0?ooo`000000
0`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1>0?ooo`800000:03oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo0080oooo000:0?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00P3oool000/0oooo00<000000?ooo`3oool00P3oool3000000@0oooo0P0000030?oo
o`<000001@3oool00`000000oooo0?ooo`1A0?ooo`8000009@3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo05<0oooo0P00000S0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0
E@3oool200000240oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool20000
05X0oooo0P00000M0?ooo`030000003oool0oooo07P0oooo0P0000040?ooo`00903oool00`000000
oooo0?ooo`1K0?ooo`8000006`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo05d0oooo0P00000I0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0H03oool2000001H0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`1R0?ooo`800000503oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo06@0oooo0P00000B0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
0P3oool002@0oooo0P00001X0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0N03o
ool2000000@0oooo000T0?ooo`030000003oool0oooo06P0oooo0P00000>0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0JP3oool20000
00`0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000
oooo0?ooo`1/0?ooo`8000002P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo06l0oooo0P00
00070?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3o
ool0L`3oool2000000<0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00
903oool2000007H0oooo0P0000000`3oool000000?ooo`1i0?ooo`800000103oool002@0oooo00<0
00000?ooo`3oool0M`3oool2000007/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0N03oool2000007X0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?oo
o`3oool0N03oool010000000oooo00000000001h0?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo07P0oooo00@000000?ooo`3oool0oooo0P00001f0?ooo`030000003oool0
oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool00`3oool20000
07@0oooo00<000000?ooo`3oool00P3oool000X0oooo0`0000020?ooo`D000000`3oool2000000<0
oooo0`0000050?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo0080oooo000;0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`020?ooo`000`3oool5000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool01`3o
ool200000700oooo00<000000?ooo`3oool00P3oool000/0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`0000050?ooo`800000N@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06`0oooo0P0000040?ooo`002`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
000000080?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool02P3oool2000006d0oooo
00<000000?ooo`3oool00P3oool000X0oooo0P0000030?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0<0?ooo`800000J`3oool00`000000oooo0?ooo`020?ooo`00
2`3oool00`000000oooo0?ooo`020?ooo`<00000103oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool03P3oool2000006T0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool00P3oool0
02@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0B0?ooo`800000I@3oool00`00
0000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01@0
oooo0P00001S0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000N@3oool00`000000oooo
0?ooo`0F0?ooo`800000H03oool2000000@0oooo000T0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0080oooo000T
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool06@3oool2000005h0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0M0?ooo`800000
FP3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo01l0oooo0P00001H0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool08@3oool2000005H0oooo00<000000?ooo`3oool00P3oool0
02@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0S0?ooo`800000E03oool00`00
0000oooo0?ooo`020?ooo`00903oool2000007T0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`1@0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0X
0?ooo`800000C`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo02X0oooo0P00001=0?ooo`030000003oool0oooo0080oooo000T0?ooo`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool0;03oool2000004/0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0^0?ooo`800000
B@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo0300oooo0P0000170?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool0<P3oool2000004D0oooo00<000000?ooo`3oool00P3oool0
02@0oooo0P00001i0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0@@3oool20000
00@0oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0080oooo
000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0=`3oool200000400oooo00<0
00000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0i
0?ooo`800000?P3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo03/0oooo0P00000l0?ooo`030000003oool0oooo0080oooo000:0?ooo`<0
00000P3oool5000000<0oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo03d0oooo0P00000j0?ooo`030000003oool0oooo0080oooo000;0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0o0?oo
o`800000>03oool00`000000oooo0?ooo`020?ooo`000`3oool5000000<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool01@0000040?oo
o`800000N@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03@0oooo0P0000040?oo
o`002`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool00P3oool000/0
oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00H00000
0?ooo`3oool000000?ooo`0000050?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
@`3oool2000003@0oooo00<000000?ooo`3oool00P3oool000X0oooo0P0000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`8000001@3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`020?ooo`002`3oool00`000000oooo0?ooo`020?ooo`<00000103oool2000000D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo04H0oooo
0P00000a0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0B03oool2000002l0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`1:0?ooo`800000;@3oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`00
903oool2000007T0oooo00<000000?ooo`3oool0CP3oool2000002P0oooo0P0000040?ooo`00903o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0500oooo0P00000W0?ooo`030000003o
ool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0DP3oool2
000002D0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1E0?ooo`8000008P3oool00`000000
oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`020?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo05T0oooo0P00000N
0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool0F`3oool2000001`0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001i0?ooo`03
0000003oool0oooo05d0oooo0P00000I0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`1O0?ooo`800000603oool00`000000oooo0?ooo`020?ooo`00903o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`00903oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo06@0
oooo0P00000C0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0IP3oool200000140oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`1X0?ooo`8000003`3oool00`000000oooo0?oo
o`020?ooo`00903oool2000007T0oooo00<000000?ooo`3oool0JP3oool2000000`0oooo0P000004
0?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo06`0oooo0P00000;0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0KP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo000T0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0L03o
ool2000000L0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
02@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool000X0oooo0`0000020?ooo`D000000`3oool200000080
oooo1@0000040?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`020?ooo`002`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool000<0oooo1@0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00@0oooon00000040?ooo`002`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo000;0?oo
o`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool0oP3oool000X0oooo0P0000030?ooo`050000003oool0
oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool0oP3oool000/0oooo00<000000?ooo`3oool00P3oool3000000@0oooo0P0000030?ooo`<00000
5`3oool3000008X0oooo00<000000?ooo`3oool0:`3oool3000001D0oooo00<000000?ooo`3oool0
503oool003L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool04`3oool00340oooo0`0000030?ooo`<00000103oool2
00000080oooo1@0000020?ooo`<000000`3oool4000000030?ooo`000000000000<000001`3oool3
000000@0oooo100000030?ooo`8000000P3oool6000000H0oooo100000020?ooo`D0000000<0oooo
0000000000000`0000000`3oool000000000000300000080oooo0`0000020?ooo`<00000103oool3
00000080oooo0`000000103oool000000000003oool3000000<0oooo0`0000090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000`3oool4000000<0oooo00<000000?ooo`3oool00P3o
ool300000080oooo1@0000020?ooo`<000000P3oool3000000040?ooo`00000000000?ooo`@00000
0`3oool200000080oooo2P0000050?ooo`030000003oool0oooo0180oooo000`0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000
303oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00@000000?ooo`3oool0
0000103oool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0180oooo000`0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`<00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0`00
00030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`3oool500000080oooo00<000000?ooo`3oool00P3oool500000080oooo00H000000?oo
o`3oool000000?ooo`0000050?ooo`D00000203oool00`000000oooo0?ooo`020?ooo`050000003o
ool000000?ooo`0000000P3oool3000000<0oooo00<000000?ooo`0000000P3oool5000000<0oooo
00@000000?ooo`3oool0oooo1@0000020?ooo`060000003oool0oooo0000003oool000000`3oool0
10000000oooo0?ooo`0000050?ooo`040000003oool0oooo00000080oooo0`0000050?ooo`030000
003oool0oooo0180oooo000`0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?oo
o`<000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool00P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3o
ool0oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0
oooo00@000000?ooo`3oool000001@3oool01P000000oooo0?ooo`000000oooo000000P0oooo00<0
00000?ooo`3oool04P3oool00300oooo00H000000?ooo`3oool0oooo0000003oool400000080oooo
100000020?ooo`<00000103oool3000000<0oooo0P0000050?ooo`030000003oool0oooo00P0oooo
00@000000?ooo`3oool000000P3oool2000000<0oooo100000030?ooo`<000002@3oool01@000000
oooo0?ooo`000000oooo00<00000103oool400000080oooo100000020?ooo`<000000P3oool20000
00030?ooo`00000000000080oooo0`0000020?ooo`@000000`3oool3000000<0oooo0`0000090?oo
o`030000003oool0oooo0080oooo1P0000000`3oool00000000000030?ooo`80000000<0oooo0000
000000000P3oool3000000@0oooo00<000000?ooo`3oool00P3oool300000080oooo100000030?oo
o`T000000`3oool3000000<0oooo100000040?ooo`030000003oool0oooo0180oooo000`0?ooo`05
0000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00P0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`00<@3oool3
000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`<000002@3oool4
000000T0oooo00<000000?ooo`3oool00P3oool2000000X0oooo100000040?ooo`030000003oool0
oooo00@0oooo0P0000040?ooo`800000;P3oool00`000000oooo0?ooo`0H0?ooo`<000005P3oool0
0`000000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`0D0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00679627, -1211.5, \
4.24814*^-5, 0.0577818}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 95.2381 84.7797 0.0700193 [
[.11905 -0.0125 -18 -9 ]
[.11905 -0.0125 18 0 ]
[.30952 -0.0125 -18 -9 ]
[.30952 -0.0125 18 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -15 -9 ]
[.69048 -0.0125 15 0 ]
[.88095 -0.0125 -15 -9 ]
[.88095 -0.0125 15 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05632 -30 -4.5 ]
[-0.0125 .05632 0 4.5 ]
[-0.0125 .19636 -30 -4.5 ]
[-0.0125 .19636 0 4.5 ]
[-0.0125 .3364 -30 -4.5 ]
[-0.0125 .3364 0 4.5 ]
[-0.0125 .47644 -30 -4.5 ]
[-0.0125 .47644 0 4.5 ]
[-0.0125 .61648 -30 -4.5 ]
[-0.0125 .61648 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-0.004)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-0.002)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(0.002)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(0.004)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05632 m
.00625 .05632 L
s
[(-1210)] -0.0125 .05632 1 0 Mshowa
0 .19636 m
.00625 .19636 L
s
[(-1208)] -0.0125 .19636 1 0 Mshowa
0 .3364 m
.00625 .3364 L
s
[(-1206)] -0.0125 .3364 1 0 Mshowa
0 .47644 m
.00625 .47644 L
s
[(-1204)] -0.0125 .47644 1 0 Mshowa
0 .61648 m
.00625 .61648 L
s
[(-1202)] -0.0125 .61648 1 0 Mshowa
.125 Mabswid
0 .09133 m
.00375 .09133 L
s
0 .12634 m
.00375 .12634 L
s
0 .16135 m
.00375 .16135 L
s
0 .23137 m
.00375 .23137 L
s
0 .26638 m
.00375 .26638 L
s
0 .30139 m
.00375 .30139 L
s
0 .37141 m
.00375 .37141 L
s
0 .40642 m
.00375 .40642 L
s
0 .44143 m
.00375 .44143 L
s
0 .51145 m
.00375 .51145 L
s
0 .54646 m
.00375 .54646 L
s
0 .58147 m
.00375 .58147 L
s
0 .02131 m
.00375 .02131 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05632 m
1 .05632 L
s
.99375 .19636 m
1 .19636 L
s
.99375 .3364 m
1 .3364 L
s
.99375 .47644 m
1 .47644 L
s
.99375 .61648 m
1 .61648 L
s
.125 Mabswid
.99625 .09133 m
1 .09133 L
s
.99625 .12634 m
1 .12634 L
s
.99625 .16135 m
1 .16135 L
s
.99625 .23137 m
1 .23137 L
s
.99625 .26638 m
1 .26638 L
s
.99625 .30139 m
1 .30139 L
s
.99625 .37141 m
1 .37141 L
s
.99625 .40642 m
1 .40642 L
s
.99625 .44143 m
1 .44143 L
s
.99625 .51145 m
1 .51145 L
s
.99625 .54646 m
1 .54646 L
s
.99625 .58147 m
1 .58147 L
s
.99625 .02131 m
1 .02131 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .60332 m
.03853 .59422 L
.05458 .5843 L
.06965 .57499 L
.08415 .56603 L
.09958 .55649 L
.11444 .54731 L
.13023 .53755 L
.14544 .52815 L
.16007 .5191 L
.17564 .50948 L
.19063 .50022 L
.20504 .49131 L
.22039 .48182 L
.23516 .4727 L
.25087 .46299 L
.26599 .45364 L
.28054 .44465 L
.29603 .43508 L
.31093 .42587 L
.32678 .41608 L
.34204 .40664 L
.35672 .39757 L
.37234 .38791 L
.38739 .37862 L
.40185 .36968 L
.41725 .36016 L
.43208 .351 L
.44783 .34126 L
.46301 .33188 L
.47761 .32285 L
.49315 .31325 L
.50811 .30401 L
.52249 .29512 L
.5378 .28565 L
.55254 .27654 L
.56821 .26686 L
.58331 .25753 L
.59783 .24856 L
.61328 .23901 L
.62815 .22981 L
.64396 .22004 L
.65919 .21063 L
.67385 .20157 L
.68943 .19194 L
.70445 .18266 L
.71888 .17374 L
.73425 .16424 L
.74904 .1551 L
.76476 .14539 L
Mistroke
.77991 .13602 L
.79448 .12702 L
.80998 .11744 L
.82491 .10821 L
.84077 .09841 L
.85605 .08896 L
.87076 .07988 L
.8864 .07021 L
.90146 .0609 L
.91595 .05195 L
.93137 .04242 L
.94621 .03325 L
.96198 .0235 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[31]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00=`3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000040?oo
o`<00000503oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000020?oo
o`D000007@3oool200000280oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000P3oool5000001@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`800000103oool3000001@0oooo000f0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000703oool010000000oooo0?ooo`00000P0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000001<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04`3oool002l0oooo
1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`000000oooo00D00000303oool500000080oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01<0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0000003oool01@00000D0?ooo`00=P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo0180
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool06`3oool010000000oooo0?ooo`00000P0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`0C0?oo
o`00=P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0000000D0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool06P3oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool04@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0000000E0?ooo`00=P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool2
000001@0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo
00000200oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000
5@3oool003L0oooo0P00000:0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool04`3o
ool2000000X0oooo0P0000040?ooo`8000000`3oool3000001h0oooo0P00000R0?ooo`8000002P3o
ool2000000@0oooo0P0000030?ooo`<000005@3oool2000000X0oooo0P0000040?ooo`8000001@3o
ool00`000000oooo0?ooo`0C0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00903ooooh000000@0oooo000T0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0LP3oool2000000D0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool002@0oooo0P00001i0?ooo`030000003oool0oooo06l0oooo0P0000070?ooo`800000103o
ool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1^0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`1]0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1[0?ooo`800000303oool00`000000
oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo06T0oooo
0P00000>0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0I`3oool200000100oooo00<000000?ooo`3oool00P3oool000X0oooo0`000002
0?ooo`D000000P3oool3000000@0oooo0P0000050?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool0I@3oool200000180oooo00<000000?ooo`3oool00P3oool000/0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`000`3oool5000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`002`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`800000N@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01<0oooo0P00
00040?ooo`002`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`1P0?ooo`8000005`3oool00`000000oooo0?ooo`020?ooo`002P3oool2000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`800000103oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool0GP3oool2000001T0oooo00<000000?oo
o`3oool00P3oool000/0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3o
ool00`3oool2000000D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1L0?ooo`80
00006`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo05X0oooo0P00000M0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool0F03oool2000001l0oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool002@0
oooo0P00001i0?ooo`030000003oool0oooo05@0oooo0P00000R0?ooo`800000103oool002@0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`1A0?ooo`8000009P3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo04l0oooo0P00000X0?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool0C@3oool2000002X0oooo00<000000?oo
o`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`190?ooo`800000;P3o
ool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo04L0oooo0P00000`0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000N@3oool00`00
0000oooo0?ooo`150?ooo`800000<@3oool2000000@0oooo000T0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@P3oool2000003D0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0n0?oo
o`800000>@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo03`0oooo0P00000k0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool0>P3oool2000003d0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0h0?ooo`800000?`3o
ool00`000000oooo0?ooo`020?ooo`00903oool2000007T0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0n0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`0c0?ooo`800000A03oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo0340oooo0P0000160?ooo`030000003oool0oooo0080oooo000T
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0;`3oool2000004P0oooo00<00000
0?ooo`3oool00P3oool000X0oooo0`0000020?ooo`D000000`3oool2000000<0oooo0`0000050?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool0;@3oool2000004X0oooo00<000000?oo
o`3oool00P3oool000/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool0:`3oool2000004`0oooo00<000000?ooo`3oool00P3o
ool000<0oooo1@0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool2000007T0oooo
00<000000?ooo`3oool0:@3oool2000004d0oooo0P0000040?ooo`002`3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`03000000D0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool00P3oool000/0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0080oooo000:0?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0500oooo00<00000
0?ooo`3oool00P3oool000/0oooo00<000000?ooo`3oool00P3oool3000000@0oooo0P0000030?oo
o`<000001@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02@0oooo0P00001C0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool08P3oool2000005D0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0P0?ooo`800000E`3oool00`000000oooo0?ooo`020?ooo`00903o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01h0oooo0P00001I0?ooo`030000003o
ool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0703oool2
000005/0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001i0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0FP3oool2000000@0oooo000T0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0603oool2000005l0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0E0?ooo`800000HP3oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01<0oooo0P00001T0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool04@3oool2000006H0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
0P3oool002@0oooo0P00001i0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0IP3o
ool2000000@0oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool03@3oool2
000006X0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`0;0?ooo`800000K03oool00`000000oooo0?ooo`020?ooo`00903oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00T0oooo0P00001^0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool01P3oool200000740oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0780oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`020?ooo`800000M@3oool00`000000oooo0?ooo`020?ooo`00
903oool2000007T0oooo00<000000?ooo`3oool00P00001f0?ooo`800000103oool002@0oooo00<0
00000?ooo`3oool0N03oool3000007T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo07H0oooo0`00001k0?ooo`030000003oool0oooo0080oooo000T0?ooo`03
0000003oool0oooo07@0oooo0P0000020?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0LP3oool2000000@0oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`020?ooo`002P3oool300000080oooo1@0000030?ooo`8000000`3o
ool3000000D0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool00P3oool000/0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo00030?ooo`D000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0KP3oool2000000P0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`020?ooo`002`3oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo00000003000000D0oooo0P00001^0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0N03oool2000000@0oooo000;0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
000000P0oooo00<000000?ooo`3oool0J`3oool2000000/0oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`020?ooo`002P3oool2000000<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1Y0?ooo`8000003@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000;
0?ooo`030000003oool0oooo0080oooo0`0000040?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool0I`3oool2000000l0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00
903oool00`000000oooo0?ooo`1S0?ooo`8000004`3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo0080oooo000T0?ooo`030000003oool0oooo0640oooo0P00000E0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001P0?ooo`8000005`3oool0
0`000000oooo0?ooo`1h0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool0G03oool2000001X0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`020?ooo`00903oool00`000000oooo0?ooo`1H0?ooo`8000007P3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo05H0oooo0P00000P0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3o
ool0E03oool200000280oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00
903oool00`000000oooo0?ooo`1B0?ooo`800000903oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo0080oooo000T0?ooo`800000D@3oool2000002H0oooo00<000000?ooo`3oool0N03o
ool2000000@0oooo000T0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo
04d0oooo0P00000Y0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool0B@3oool2000002d0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`020?ooo`00903oool00`000000oooo0?ooo`170?ooo`800000;`3oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo04D0oooo0P00000a0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool00P3oool002@0oooo0P0000140?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
N03oool2000000@0oooo000T0?ooo`030000003oool0oooo0440oooo0P00000e0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool0
02@0oooo00<000000?ooo`3oool0?P3oool2000003P0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0l0?ooo`800000>P3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo03X0oooo
0P00000l0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool000X0oooo0`00
00020?ooo`D000000`3oool2000000@0oooo0`0000040?ooo`030000003oool0oooo03P0oooo0P00
000n0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool000/0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`800000@03oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo0080oooo00030?ooo`D000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool000000?ooo`05000000@0oooo
0P00000f0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0N03oool2000000@0oooo
000;0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`002`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool01P000000
oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool0<P3oool2000004@0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`002P3oool2000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000<0oooo0P0000050?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo0080oooo000;0?ooo`030000003oool0oooo0080oooo0`0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02l0oooo0P0000170?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0;@3oool20000
04T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000
oooo0?ooo`0[0?ooo`800000B`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T
0?ooo`800000:03oool2000004l0oooo00<000000?ooo`3oool0N03oool2000000@0oooo000T0?oo
o`030000003oool0oooo02D0oooo0P00001A0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool00P3oool002@0oooo00<000000?ooo`3oool08`3oool2000005<0oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903o
ool00`000000oooo0?ooo`0P0?ooo`800000EP3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo0080oooo000T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo01`0oooo0P00001J0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool06P3oool2000005`0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool2000001T0oooo0P00
001N0?ooo`030000003oool0oooo07P0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`0E0?ooo`800000H@3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo0080oooo000T0?ooo`030000003oool0oooo0140oooo0P00001U0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool03`3oool2
000006L0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool00`00
0000oooo0?ooo`0=0?ooo`800000J@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
0080oooo000T0?ooo`800000303oool2000006/0oooo00<000000?ooo`3oool0N03oool2000000@0
oooo000T0?ooo`030000003oool0oooo00T0oooo0P00001]0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool01@3oool200000740oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0740oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`00
903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`020?ooo`002P3oool300000080oooo1@0000030?ooo`8000000P3o
ool5000000@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo0080oooo000;0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`000`3oool5000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0103ooooh000000@0oooo000;0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool000/0oooo
00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`3n0?ooo`002P3oool2000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`3n0?ooo`002`3oool00`000000oooo0?ooo`020?ooo`<00000103oool2000000<0oooo0`00000G
0?ooo`<00000RP3oool00`000000oooo0?ooo`0[0?ooo`<000005@3oool00`000000oooo0?ooo`0D
0?ooo`00=`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`00<@3oool3000000<0oooo0`0000040?ooo`80
00000P3oool500000080oooo0`0000030?ooo`@0000000<0oooo0000000000000`0000070?ooo`<0
0000103oool4000000<0oooo0P0000020?ooo`H000001P3oool400000080oooo1@0000000`3oool0
000000000003000000030?ooo`000000000000<000000P3oool300000080oooo0`0000040?ooo`<0
00000P3oool3000000040?ooo`00000000000?ooo`<000000`3oool3000000T0oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000030?ooo`@000000`3oool00`000000oooo0?ooo`020?oo
o`<000000P3oool500000080oooo0`0000020?ooo`<0000000@0oooo000000000000oooo10000003
0?ooo`8000000P3oool:000000D0oooo00<000000?ooo`3oool04P3oool00300oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0000000<
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`00
00040?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000H0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04P3oool00300oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
00H0oooo0`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool30000
00<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`D000000P3oool01P000000oooo
0?ooo`000000oooo000000D0oooo1@0000080?ooo`030000003oool0oooo0080oooo00D000000?oo
o`000000oooo000000020?ooo`<000000`3oool00`000000oooo000000020?ooo`D000000`3oool0
10000000oooo0?ooo`3oool500000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`04
0000003oool0oooo000000D0oooo00@000000?ooo`3oool000000P3oool3000000D0oooo00<00000
0?ooo`3oool04P3oool00300oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
0`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`02000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0000003o
ool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000`3o
ool010000000oooo0?ooo`0000050?ooo`060000003oool0oooo0000003oool00000203oool00`00
0000oooo0?ooo`0B0?ooo`00<03oool01P000000oooo0?ooo`3oool000000?ooo`@000000P3oool4
00000080oooo0`0000040?ooo`<000000`3oool2000000D0oooo00<000000?ooo`3oool0203oool0
10000000oooo0?ooo`0000020?ooo`8000000`3oool4000000<0oooo0`0000090?ooo`050000003o
ool0oooo0000003oool00`0000040?ooo`@000000P3oool400000080oooo0`0000020?ooo`800000
00<0oooo0000000000000P3oool300000080oooo100000030?ooo`<000000`3oool3000000T0oooo
00<000000?ooo`3oool00P3oool6000000030?ooo`000000000000<0oooo0P0000000`3oool00000
000000020?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`<000000P3oool4000000<0oooo
2@0000030?ooo`<000000`3oool4000000@0oooo00<000000?ooo`3oool04P3oool00300oooo00D0
00000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
203oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01<0oooo000a0?ooo`<0
00002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo0`0000090?ooo`@0
00002@3oool00`000000oooo0?ooo`020?ooo`8000002P3oool4000000@0oooo00<000000?ooo`3o
ool0103oool2000000@0oooo0P00000^0?ooo`030000003oool0oooo01P0oooo0`00000F0?ooo`03
0000003oool0oooo0080oooo0P00000;0?ooo`030000003oool0oooo01@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00679627, -1211.5, \
4.24814*^-5, 0.0577818}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 95.2381 0.0101333 0.00174242 [
[.11905 -0.0125 -18 -9 ]
[.11905 -0.0125 18 0 ]
[.30952 -0.0125 -18 -9 ]
[.30952 -0.0125 18 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -15 -9 ]
[.69048 -0.0125 15 0 ]
[.88095 -0.0125 -15 -9 ]
[.88095 -0.0125 15 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01013 -6 -4.5 ]
[-0.0125 .01013 0 4.5 ]
[-0.0125 .09725 -12 -4.5 ]
[-0.0125 .09725 0 4.5 ]
[-0.0125 .18437 -18 -4.5 ]
[-0.0125 .18437 0 4.5 ]
[-0.0125 .2715 -18 -4.5 ]
[-0.0125 .2715 0 4.5 ]
[-0.0125 .35862 -18 -4.5 ]
[-0.0125 .35862 0 4.5 ]
[-0.0125 .44574 -18 -4.5 ]
[-0.0125 .44574 0 4.5 ]
[-0.0125 .53286 -18 -4.5 ]
[-0.0125 .53286 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -66 0 ]
[.5 .63053 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-0.004)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-0.002)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(0.002)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(0.004)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01013 m
.00625 .01013 L
s
[(0)] -0.0125 .01013 1 0 Mshowa
0 .09725 m
.00625 .09725 L
s
[(50)] -0.0125 .09725 1 0 Mshowa
0 .18437 m
.00625 .18437 L
s
[(100)] -0.0125 .18437 1 0 Mshowa
0 .2715 m
.00625 .2715 L
s
[(150)] -0.0125 .2715 1 0 Mshowa
0 .35862 m
.00625 .35862 L
s
[(200)] -0.0125 .35862 1 0 Mshowa
0 .44574 m
.00625 .44574 L
s
[(250)] -0.0125 .44574 1 0 Mshowa
0 .53286 m
.00625 .53286 L
s
[(300)] -0.0125 .53286 1 0 Mshowa
.125 Mabswid
0 .02756 m
.00375 .02756 L
s
0 .04498 m
.00375 .04498 L
s
0 .06241 m
.00375 .06241 L
s
0 .07983 m
.00375 .07983 L
s
0 .11468 m
.00375 .11468 L
s
0 .1321 m
.00375 .1321 L
s
0 .14953 m
.00375 .14953 L
s
0 .16695 m
.00375 .16695 L
s
0 .2018 m
.00375 .2018 L
s
0 .21922 m
.00375 .21922 L
s
0 .23665 m
.00375 .23665 L
s
0 .25407 m
.00375 .25407 L
s
0 .28892 m
.00375 .28892 L
s
0 .30634 m
.00375 .30634 L
s
0 .32377 m
.00375 .32377 L
s
0 .34119 m
.00375 .34119 L
s
0 .37604 m
.00375 .37604 L
s
0 .39347 m
.00375 .39347 L
s
0 .41089 m
.00375 .41089 L
s
0 .42831 m
.00375 .42831 L
s
0 .46316 m
.00375 .46316 L
s
0 .48059 m
.00375 .48059 L
s
0 .49801 m
.00375 .49801 L
s
0 .51543 m
.00375 .51543 L
s
0 .55028 m
.00375 .55028 L
s
0 .56771 m
.00375 .56771 L
s
0 .58513 m
.00375 .58513 L
s
0 .60256 m
.00375 .60256 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01013 m
1 .01013 L
s
.99375 .09725 m
1 .09725 L
s
.99375 .18437 m
1 .18437 L
s
.99375 .2715 m
1 .2715 L
s
.99375 .35862 m
1 .35862 L
s
.99375 .44574 m
1 .44574 L
s
.99375 .53286 m
1 .53286 L
s
.125 Mabswid
.99625 .02756 m
1 .02756 L
s
.99625 .04498 m
1 .04498 L
s
.99625 .06241 m
1 .06241 L
s
.99625 .07983 m
1 .07983 L
s
.99625 .11468 m
1 .11468 L
s
.99625 .1321 m
1 .1321 L
s
.99625 .14953 m
1 .14953 L
s
.99625 .16695 m
1 .16695 L
s
.99625 .2018 m
1 .2018 L
s
.99625 .21922 m
1 .21922 L
s
.99625 .23665 m
1 .23665 L
s
.99625 .25407 m
1 .25407 L
s
.99625 .28892 m
1 .28892 L
s
.99625 .30634 m
1 .30634 L
s
.99625 .32377 m
1 .32377 L
s
.99625 .34119 m
1 .34119 L
s
.99625 .37604 m
1 .37604 L
s
.99625 .39347 m
1 .39347 L
s
.99625 .41089 m
1 .41089 L
s
.99625 .42831 m
1 .42831 L
s
.99625 .46316 m
1 .46316 L
s
.99625 .48059 m
1 .48059 L
s
.99625 .49801 m
1 .49801 L
s
.99625 .51543 m
1 .51543 L
s
.99625 .55028 m
1 .55028 L
s
.99625 .56771 m
1 .56771 L
s
.99625 .58513 m
1 .58513 L
s
.99625 .60256 m
1 .60256 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Interference Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .06426 m
.03111 .25857 L
.03491 .38162 L
.03692 .44291 L
.03907 .50106 L
.0411 .54595 L
.04294 .57648 L
.04383 .58727 L
.0443 .59187 L
.0448 .59592 L
.04523 .59874 L
.04546 .59996 L
.04571 .60107 L
.04594 .60189 L
.04614 .60248 L
.04635 .60292 L
.04655 .60318 L
.04679 .60332 L
.04692 .6033 L
.04704 .60324 L
.04726 .60297 L
.0475 .60249 L
.04771 .60189 L
.04791 .60118 L
.04836 .59905 L
.04885 .59593 L
.04929 .59235 L
.05029 .5818 L
.05115 .57012 L
.05208 .55476 L
.05377 .52027 L
.05751 .41986 L
.06148 .29307 L
.0652 .17652 L
.06861 .08879 L
.07039 .05476 L
.07129 .04132 L
.07227 .02964 L
.07277 .02487 L
.07325 .0212 L
.07352 .01952 L
.07381 .01798 L
.07404 .01692 L
.07431 .016 L
.07456 .01535 L
.07479 .01495 L
.07503 .01474 L
.07517 .01472 L
.0753 .01476 L
.07552 .01497 L
Mistroke
.07576 .0154 L
.07599 .01601 L
.07621 .01674 L
.07671 .01911 L
.07717 .02208 L
.07821 .03151 L
.07913 .04289 L
.08009 .05788 L
.08361 .13513 L
.0908 .35733 L
.0948 .47737 L
.0967 .52403 L
.09845 .55876 L
.09931 .57249 L
.10026 .58483 L
.10122 .59415 L
.10174 .5979 L
.10197 .59926 L
.10223 .60053 L
.10244 .6014 L
.10267 .60215 L
.10291 .60274 L
.10313 .60311 L
.10335 .60329 L
.10356 .60331 L
.10375 .60318 L
.10395 .6029 L
.10418 .60242 L
.10442 .60169 L
.10468 .60068 L
.10492 .59954 L
.10581 .59349 L
.1063 .58897 L
.10675 .58405 L
.10778 .57035 L
.10965 .53688 L
.11316 .44926 L
.12057 .21486 L
.12238 .16115 L
.12429 .11102 L
.12605 .07242 L
.1277 .0446 L
.12854 .03369 L
.12944 .0247 L
.12996 .02083 L
.13044 .01803 L
.13065 .01708 L
.13088 .01625 L
.13112 .01554 L
.13135 .01508 L
Mistroke
.13159 .01479 L
.13182 .01472 L
.13194 .01475 L
.13207 .01486 L
.13232 .01521 L
.13255 .01574 L
.13279 .0165 L
.13322 .01841 L
.13378 .02184 L
.13431 .02607 L
.13529 .03654 L
.13617 .04869 L
.13714 .06486 L
.13909 .10582 L
.14258 .20128 L
.14658 .32923 L
.15022 .44308 L
.15203 .49264 L
.154 .5381 L
.1549 .5554 L
.15586 .57107 L
.1567 .58237 L
.15758 .59171 L
.15802 .59538 L
.1585 .5986 L
.15872 .59976 L
.15894 .60081 L
.15915 .60164 L
.15935 .60225 L
.1596 .60283 L
.15973 .60304 L
.15987 .6032 L
.1601 .60332 L
.16023 .6033 L
.16035 .60322 L
.16058 .60293 L
.16079 .60251 L
.16103 .60182 L
.16126 .60097 L
.16168 .59894 L
.16212 .59611 L
.16291 .58929 L
.16386 .57835 L
.16472 .56589 L
.16662 .53014 L
.16836 .48863 L
.1723 .37313 L
.17617 .24778 L
.17978 .14052 L
.18156 .09635 L
Mistroke
.18325 .0622 L
.18418 .04696 L
.1852 .0336 L
.18564 .0288 L
.18612 .02446 L
.18652 .02137 L
.18697 .01865 L
.18721 .01745 L
.18744 .01653 L
.18766 .01582 L
.18789 .01526 L
.18812 .0149 L
.18834 .01474 L
.18853 .01473 L
.18874 .01488 L
.18897 .01523 L
.18911 .01551 L
.18923 .01583 L
.18947 .01664 L
.18974 .01776 L
.19022 .02041 L
.19066 .02354 L
.19151 .03155 L
.19243 .04305 L
.19411 .07105 L
.19589 .10952 L
.19785 .16089 L
.20182 .28339 L
.20578 .41055 L
.20751 .46151 L
.20941 .51075 L
.21113 .54774 L
.21297 .57766 L
.21399 .58948 L
.21491 .59714 L
.21536 .59975 L
.2156 .60084 L
.21584 .60178 L
.21606 .60242 L
.2163 .60293 L
.21652 .60321 L
.21672 .60332 L
.21696 .60325 L
.21709 .60313 L
.21721 .60296 L
.21744 .60249 L
.21766 .60187 L
.21792 .60092 L
.21815 .59983 L
.21869 .59666 L
Mistroke
.21912 .59334 L
.2196 .58894 L
.22055 .57772 L
.22237 .54834 L
.22406 .51222 L
.23142 .29306 L
.23517 .1757 L
.23714 .12182 L
.23924 .0745 L
.2411 .04301 L
.24216 .03008 L
.24265 .02544 L
.24316 .02145 L
.24359 .01876 L
.24382 .01762 L
.24407 .01661 L
.24429 .01586 L
.2445 .01535 L
.24471 .01498 L
.2449 .01478 L
.24513 .01472 L
.24537 .01486 L
.24558 .01515 L
.2458 .01564 L
.24605 .01637 L
.24631 .01739 L
.24678 .01986 L
.24726 .02321 L
.24777 .02767 L
.2487 .03796 L
.24969 .05219 L
.25079 .07153 L
.25459 .16344 L
.26217 .4028 L
.26566 .50106 L
.26764 .54496 L
.2686 .56238 L
.26948 .57572 L
.27035 .58654 L
.2713 .59531 L
.27183 .59878 L
.27206 .59999 L
.27231 .60112 L
.27253 .60191 L
.27277 .60257 L
.2729 .60285 L
.27302 .60304 L
.27326 .60328 L
.2735 .6033 L
.27364 .60323 L
Mistroke
.27376 .60309 L
.27401 .60268 L
.27424 .6021 L
.2745 .60117 L
.27475 .6001 L
.2753 .59688 L
.27575 .59347 L
.27625 .58891 L
.27724 .57715 L
.27917 .54527 L
.28093 .50677 L
.28488 .39554 L
.2888 .26925 L
.29242 .15848 L
.29423 .11102 L
.29593 .07369 L
.2977 .04368 L
.29864 .03185 L
.29914 .02687 L
.29966 .02248 L
.30015 .01925 L
.3006 .01706 L
.30081 .01626 L
.30105 .01558 L
.30127 .01512 L
.30147 .01485 L
.30171 .01472 L
.30193 .01478 L
.30217 .01506 L
.30231 .01531 L
.30243 .01559 L
.30268 .01633 L
.30295 .01739 L
.30345 .02001 L
.30397 .02374 L
.30445 .02796 L
.30552 .04023 L
.30651 .05496 L
.30744 .0716 L
.31124 .16362 L
.31473 .27109 L
.3186 .39593 L
.32221 .49855 L
.32399 .53911 L
.32568 .56923 L
.32661 .58204 L
.3271 .58762 L
.32762 .59263 L
.32806 .59611 L
.32854 .59916 L
Mistroke
.32875 .60024 L
.32898 .60122 L
.32919 .60196 L
.32939 .60252 L
.32951 .60278 L
.32964 .60301 L
.32987 .60326 L
.33 .60331 L
.33014 .60331 L
.33038 .60313 L
.33061 .60277 L
.33082 .60227 L
.33105 .60154 L
.3313 .60054 L
.33186 .59747 L
.33239 .59354 L
.33338 .58354 L
.33433 .57096 L
.3352 .55675 L
.33718 .51623 L
.3407 .42098 L
.34459 .29683 L
.34855 .17295 L
.35029 .12556 L
.35219 .08151 L
.35308 .06421 L
.35403 .04836 L
.35485 .03699 L
.35575 .02722 L
.35627 .02276 L
.35676 .0195 L
.35722 .01717 L
.35745 .01629 L
.35758 .01587 L
.35771 .01554 L
.35794 .01507 L
.35815 .01481 L
.35838 .01472 L
.35863 .01483 L
.35885 .01511 L
.35908 .01559 L
.3593 .01623 L
.35949 .01695 L
.35993 .01906 L
.36042 .02217 L
.36139 .03094 L
.36229 .04196 L
.36313 .05466 L
.36503 .09126 L
.36707 .14111 L
Mistroke
.37489 .38478 L
.37881 .4974 L
.38053 .53689 L
.38144 .55457 L
.38243 .57079 L
.38337 .58344 L
.38424 .59239 L
.38467 .59585 L
.38507 .59849 L
.38549 .60063 L
.38571 .60152 L
.38594 .60226 L
.38607 .60258 L
.38619 .60284 L
.38643 .60318 L
.38668 .60332 L
.38682 .6033 L
.38695 .60321 L
.38719 .6029 L
.38741 .60243 L
.38766 .60167 L
.3879 .60075 L
.38834 .5985 L
.38875 .59579 L
.38968 .5875 L
.39064 .57575 L
.39168 .55965 L
.39357 .52217 L
.39709 .42891 L
.40079 .31155 L
.40485 .18324 L
.40672 .13115 L
.40872 .0839 L
.40969 .06484 L
.41061 .04941 L
.4115 .03704 L
.41233 .02785 L
.4132 .02077 L
.41366 .0181 L
.41392 .01694 L
.41416 .01609 L
.4144 .01542 L
.41463 .015 L
.41477 .01484 L
.41489 .01475 L
.41502 .01472 L
.41515 .01474 L
.41539 .01495 L
.41561 .01532 L
.41585 .01593 L
Mistroke
.4161 .01679 L
.41651 .0187 L
.41696 .02143 L
.41776 .02812 L
.41872 .03896 L
.41958 .05149 L
.42146 .0864 L
.42319 .12728 L
.42711 .24179 L
.43094 .36575 L
.43453 .47337 L
.43621 .51557 L
.43797 .55232 L
.43889 .56795 L
.4399 .58195 L
.44081 .59172 L
.44123 .59518 L
.44167 .59818 L
.4419 .59952 L
.44216 .60076 L
.4424 .60168 L
.44262 .60235 L
.44274 .60265 L
.44288 .60291 L
.44302 .60312 L
.44315 .60325 L
.44328 .60331 L
.44341 .60331 L
.44365 .60315 L
.4439 .60278 L
.44404 .60248 L
.44416 .60214 L
.44439 .60138 L
.44464 .60033 L
.44507 .59798 L
.44553 .59477 L
.44641 .58657 L
.44735 .57488 L
.44904 .54661 L
.45097 .50436 L
.45306 .44845 L
.45687 .33007 L
.46054 .21213 L
.46249 .1548 L
.46459 .10116 L
.46659 .06039 L
.46746 .04629 L
.46842 .03372 L
.46886 .02897 L
.46933 .02465 L
Mistroke
.46973 .02153 L
.47017 .01881 L
.47043 .01752 L
.47067 .01655 L
.4709 .01582 L
.47114 .01524 L
.47135 .0149 L
.47156 .01474 L
.47178 .01473 L
.47201 .01492 L
.47224 .0153 L
.47237 .0156 L
.4725 .01593 L
.47277 .01686 L
.47301 .01793 L
.47345 .02042 L
.47393 .02389 L
.47495 .03391 L
.47602 .04826 L
.47784 .0808 L
.47982 .12693 L
.48748 .36237 L
.49102 .46893 L
.49288 .51621 L
.49485 .55666 L
.49585 .5727 L
.49695 .58662 L
.49743 .59144 L
.49795 .59572 L
.49844 .5989 L
.49888 .60106 L
.49912 .60191 L
.49937 .60259 L
.4996 .60303 L
.49982 .60326 L
.49995 .60331 L
.50007 .60331 L
.5002 .60325 L
.50034 .60311 L
.50058 .60272 L
.50071 .60241 L
.50083 .60206 L
.5013 .60025 L
.50173 .59792 L
.50222 .59443 L
.50269 .59033 L
.50356 .58071 L
.50451 .56719 L
.50645 .53109 L
.50993 .442 L
Mistroke
.51754 .20145 L
.52103 .1059 L
.52301 .0644 L
.52397 .04832 L
.52485 .0363 L
.5253 .03109 L
.52579 .02624 L
.52622 .02272 L
.52668 .01958 L
.52718 .01709 L
.52745 .01611 L
.52758 .01572 L
.5277 .01542 L
.52794 .01499 L
.52815 .01477 L
.52839 .01472 L
.52852 .01478 L
.52864 .0149 L
.52877 .01508 L
.52889 .0153 L
.52916 .01599 L
.5294 .01681 L
.52965 .01791 L
.53009 .02035 L
.53057 .02381 L
.53163 .03434 L
.53263 .04761 L
.53461 .08337 L
.53648 .12723 L
.53999 .22867 L
.54725 .45737 L
.54918 .50807 L
.55099 .54735 L
.55288 .57807 L
.55389 .58965 L
.55445 .59464 L
.55497 .59823 L
.55521 .59959 L
.55544 .60068 L
.55565 .60151 L
.55587 .60222 L
.55611 .60279 L
.55633 .60313 L
.55657 .60331 L
.5567 .60331 L
.55683 .60326 L
.55705 .60302 L
.55726 .60263 L
.55745 .60214 L
.55766 .60146 L
Mistroke
.55812 .59938 L
.55855 .59676 L
.55946 .58916 L
.56045 .5775 L
.56247 .54406 L
.56437 .50167 L
.56612 .4552 L
.57006 .33334 L
.57394 .20886 L
.57583 .15346 L
.57755 .10895 L
.57922 .07264 L
.58103 .04242 L
.58202 .03031 L
.58246 .02606 L
.58294 .02215 L
.58336 .01938 L
.58382 .01712 L
.58407 .01619 L
.5843 .01554 L
.58453 .01507 L
.58475 .01481 L
.58498 .01472 L
.58511 .01475 L
.58524 .01484 L
.58546 .01515 L
.5857 .01567 L
.58591 .01632 L
.58611 .01706 L
.58656 .01928 L
.58705 .02251 L
.58749 .02617 L
.58849 .03691 L
.58935 .04876 L
.59028 .06429 L
.59197 .09905 L
.59571 .20003 L
.59968 .32701 L
.60341 .44349 L
.60682 .53074 L
.60861 .56446 L
.60951 .57771 L
.61049 .58915 L
.61099 .59379 L
.61147 .59734 L
.61174 .59895 L
.61203 .60042 L
.61227 .60141 L
.61253 .60226 L
.61278 .60284 L
Mistroke
.61301 .60317 L
.61325 .60332 L
.61339 .6033 L
.61352 .60323 L
.61374 .60296 L
.61398 .60245 L
.61422 .60178 L
.61443 .60099 L
.61488 .59875 L
.6153 .59605 L
.61624 .58771 L
.61707 .57783 L
.61795 .56495 L
.61981 .52983 L
.62184 .48071 L
.6295 .243 L
.63303 .13845 L
.63489 .09289 L
.63686 .05467 L
.63786 .03989 L
.63839 .03337 L
.63896 .02742 L
.63948 .02295 L
.63996 .01969 L
.64019 .01842 L
.64044 .01724 L
.64065 .01639 L
.64089 .01567 L
.64103 .01535 L
.64115 .01511 L
.64139 .01481 L
.64161 .01472 L
.64185 .01481 L
.64197 .01494 L
.6421 .01513 L
.64233 .01564 L
.64248 .01605 L
.64261 .0165 L
.64286 .01753 L
.64332 .01995 L
.64374 .02286 L
.6447 .03172 L
.64557 .04259 L
.64652 .05712 L
.64822 .09028 L
.65212 .19278 L
.65583 .31074 L
.65989 .43871 L
.66177 .49048 L
.66377 .53709 L
Mistroke
.66475 .5558 L
.66566 .57082 L
.66655 .58277 L
.66738 .59154 L
.66784 .59536 L
.66826 .5982 L
.66872 .60063 L
.66898 .60164 L
.66922 .60238 L
.66945 .60289 L
.6697 .60321 L
.66994 .60332 L
.67015 .60324 L
.67028 .60311 L
.6704 .60293 L
.67053 .60268 L
.67067 .60235 L
.67091 .60163 L
.67116 .60061 L
.67162 .59822 L
.67204 .5954 L
.67297 .58687 L
.67383 .5763 L
.67465 .56404 L
.67648 .52921 L
.67842 .48241 L
.68191 .38002 L
.68905 .1555 L
.69084 .10908 L
.69271 .06875 L
.6937 .05166 L
.69477 .03651 L
.69525 .03106 L
.69575 .02608 L
.69618 .02252 L
.69666 .01937 L
.69715 .01696 L
.69742 .01601 L
.69755 .01565 L
.69767 .01536 L
.6979 .01495 L
.69812 .01475 L
.69835 .01473 L
.69848 .0148 L
.6986 .01492 L
.69885 .01533 L
.69908 .01593 L
.69934 .01681 L
.69962 .01802 L
.70018 .02135 L
Mistroke
.7007 .02539 L
.70159 .03446 L
.70256 .04743 L
.70451 .08257 L
.70821 .17642 L
.71217 .30066 L
.71593 .42051 L
.71791 .47716 L
.72001 .52833 L
.72188 .56403 L
.72294 .57954 L
.72393 .59065 L
.7244 .5947 L
.72485 .59784 L
.72524 .60006 L
.72547 .60105 L
.72568 .60183 L
.72593 .60253 L
.72615 .60297 L
.72639 .60325 L
.72653 .60331 L
.72665 .60331 L
.72686 .60318 L
.72709 .60286 L
.72733 .60231 L
.72756 .60162 L
.72805 .59946 L
.7285 .59669 L
.729 .59281 L
.72953 .58774 L
.73141 .56228 L
.73307 .53038 L
.73491 .48649 L
.74252 .25173 L
.74601 .14686 L
.74799 .09726 L
.74983 .06022 L
.75077 .04516 L
.75166 .0336 L
.75216 .02835 L
.75269 .0236 L
.75317 .02018 L
.75362 .01772 L
.75385 .01674 L
.7541 .0159 L
.75424 .01552 L
.75438 .01523 L
.7545 .01502 L
.75463 .01486 L
.75477 .01475 L
Mistroke
.7549 .01472 L
.75504 .01475 L
.75518 .01485 L
.75543 .0152 L
.75557 .0155 L
.7557 .01583 L
.75614 .01745 L
.75639 .01868 L
.75663 .02003 L
.75714 .02365 L
.75761 .0278 L
.75856 .03849 L
.75959 .0535 L
.76147 .08915 L
.76498 .17986 L
.77241 .41552 L
.77432 .47092 L
.77614 .51689 L
.77791 .55355 L
.77956 .5792 L
.78041 .58897 L
.78131 .59665 L
.78156 .59826 L
.78183 .59975 L
.78207 .60085 L
.78232 .60179 L
.78254 .60245 L
.78279 .60296 L
.78301 .60323 L
.78323 .60332 L
.78347 .60322 L
.78361 .60306 L
.78374 .60286 L
.78397 .60233 L
.78422 .60156 L
.78465 .59968 L
.78513 .59684 L
.78564 .59294 L
.78618 .58772 L
.78717 .57571 L
.78898 .54557 L
.79096 .5018 L
.79494 .38809 L
.79896 .25828 L
.80261 .14823 L
.80443 .10207 L
.8064 .06156 L
.80731 .04684 L
.80826 .03413 L
.80908 .02573 L
Mistroke
.80955 .02198 L
.80998 .01919 L
.81045 .01691 L
.8107 .01604 L
.81083 .01567 L
.81097 .01534 L
.8111 .01509 L
.81122 .01492 L
.81146 .01473 L
.81167 .01474 L
.8119 .01493 L
.81211 .01527 L
.81234 .01581 L
.81255 .01649 L
.81274 .01724 L
.81321 .01965 L
.81366 .02266 L
.81464 .03175 L
.81555 .04309 L
.8176 .07848 L
.81943 .11992 L
.82114 .16582 L
.82503 .28665 L
.82853 .39932 L
.83051 .45819 L
.83235 .50653 L
.83434 .54948 L
.83615 .57842 L
.83714 .58981 L
.83759 .5939 L
.83808 .59744 L
.83832 .59892 L
.83859 .60031 L
.83884 .60135 L
.83906 .60211 L
.83919 .60246 L
.83933 .60277 L
.83948 .60302 L
.83962 .60319 L
.83975 .60329 L
.83989 .60332 L
.84014 .6032 L
.84035 .60292 L
.84058 .60242 L
.84083 .60169 L
.84106 .60082 L
.84147 .59879 L
.8419 .59595 L
.8429 .58696 L
.84381 .57583 L
Mistroke
.84558 .54638 L
.84726 .51009 L
.85452 .29336 L
.8582 .17809 L
.86015 .12456 L
.86225 .07666 L
.86328 .0576 L
.86425 .04253 L
.86513 .03165 L
.86563 .0266 L
.86609 .02278 L
.86652 .01982 L
.86699 .01737 L
.86725 .01636 L
.86749 .01565 L
.86771 .01515 L
.86795 .01483 L
.86816 .01472 L
.86838 .01477 L
.86859 .01498 L
.86878 .01531 L
.869 .01587 L
.86925 .01667 L
.86969 .01868 L
.87013 .02138 L
.8706 .02506 L
.87146 .03373 L
.87249 .04729 L
.87342 .06268 L
.87739 .15483 L
.88488 .39016 L
.88866 .49817 L
.8903 .53595 L
.89209 .56835 L
.89308 .58206 L
.894 .59178 L
.89445 .59552 L
.89487 .59835 L
.89531 .60064 L
.89554 .60157 L
.8958 .60235 L
.89592 .60266 L
.89606 .60292 L
.8963 .60323 L
.89645 .60331 L
.89659 .60331 L
.89672 .60325 L
.89686 .60312 L
.89698 .60295 L
.89711 .6027 L
Mistroke
.89738 .602 L
.89763 .60111 L
.89786 .60009 L
.89834 .59737 L
.89878 .5942 L
.89976 .58466 L
.90067 .57284 L
.90163 .55735 L
.90337 .52254 L
.9073 .41717 L
.91444 .19001 L
.91811 .09328 L
.91916 .07137 L
.92017 .05355 L
.92116 .0391 L
.92205 .02879 L
.9225 .02467 L
.92298 .02101 L
.92344 .01831 L
.92386 .01649 L
.92409 .01575 L
.92431 .01525 L
.92455 .01488 L
.92468 .01477 L
.9248 .01472 L
.92504 .01478 L
.92518 .01491 L
.92531 .01509 L
.92554 .01558 L
.92579 .01631 L
.9262 .01801 L
.92664 .02051 L
.92744 .02679 L
.92839 .03714 L
.92927 .04929 L
.93112 .08295 L
.93284 .12285 L
.93675 .2359 L
.94412 .46706 L
.94606 .51628 L
.94708 .53851 L
.94815 .55886 L
.9491 .57373 L
.95013 .58675 L
.95059 .5913 L
.95108 .5954 L
.95154 .5985 L
.95196 .60066 L
.95221 .60163 L
.95244 .60235 L
Mistroke
.95269 .60289 L
.95283 .6031 L
.95295 .60323 L
.95317 .60332 L
.9534 .60322 L
.95365 .60291 L
.95387 .60243 L
.954 .60207 L
.95415 .60161 L
.9544 .6006 L
.95488 .59806 L
.95544 .59406 L
.95596 .58938 L
.95684 .57938 L
.9578 .56539 L
.95976 .52828 L
.96342 .43292 L
.96736 .3082 L
.97108 .19034 L
.97514 .08488 L
.97619 .06426 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[31]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00<@3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000040?oo
o`<00000503oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000020?oo
o`D000007@3oool200000280oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000P3oool5000001@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`800000103oool3000001X0oooo000`0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000703oool010000000oooo0?ooo`00000P0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000001<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06@3oool002T0oooo
1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`000000oooo00D00000303oool500000080oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01<0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0000003oool01@00000J0?ooo`00<03oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo0180
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool06`3oool010000000oooo0?ooo`00000P0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`0I0?oo
o`00<03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0000000D0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool06P3oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool04@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0000000K0?ooo`00<03oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool2
000001@0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo
00000200oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000
6`3oool00340oooo0P00000:0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool04`3o
ool2000000X0oooo0P0000040?ooo`8000000`3oool3000001h0oooo0P00000R0?ooo`8000002P3o
ool2000000@0oooo0P0000030?ooo`<000005@3oool2000000X0oooo0P0000040?ooo`8000001@3o
ool00`000000oooo0?ooo`0I0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`005`3oool2000000D0oooon000000:0?ooo`005P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool001H0oooo00@00000
0?ooo`3oool00000103oool2000007T0oooo00<000000?ooo`3oool0N03oool2000000X0oooo000F
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03`3oool2000000`0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
00050?ooo`030000003oool0oooo00@0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?oo
o`080?ooo`005P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00l0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
000<0?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`800000303oool2000000`0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool200000140oooo00<0
00000?ooo`3oool0203oool001H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0?0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
000<0?ooo`800000303oool2000000D0oooo00<000000?ooo`3oool0103oool2000000`0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
000A0?ooo`030000003oool0oooo00P0oooo000G0?ooo`8000001@3oool200000100oooo0P00000<
0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<
0?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`800000303oool2000000`0oooo0P00000<
0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool200000100oooo0P00000:
0?ooo`007P3oool00`000000oooo0?ooo`0?0?ooo`800000303oool2000000`0oooo0P00000<0?oo
o`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000D0oooo00<000000?oo
o`3oool0103oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?oo
o`800000303oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo00l0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`80
0000303oool2000000`0oooo0P00000<0?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`80
0000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`80
0000303oool200000140oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
3`3oool2000000`0oooo0P00000<0?ooo`8000002`3oool00`000000oooo0000000<0?ooo`800000
303oool2000000`0oooo0P00000<0?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`800000
303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000
303oool200000140oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool03`3o
ool2000000/0oooo00<000000?ooo`0000002`3oool00`000000oooo0000000;0?ooo`030000003o
ool0000000/0oooo00<000000?ooo`000000303oool2000000`0oooo0P00000;0?ooo`030000003o
ool0000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000;0?ooo`800000303o
ool2000000`0oooo00<000000?ooo`0000002P3oool00`000000oooo0000000;0?ooo`030000003o
ool0000000`0oooo00<000000?ooo`0000002`3oool200000140oooo00<000000?ooo`3oool0203o
ool001h0oooo0P00000@0?ooo`8000002`3oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0000000/0oooo00<000000?ooo`0000002`3oool00`000000oooo0000000;0?ooo`030000003o
ool0000000/0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000000;0?oo
o`8000002`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0000000/0oooo00<00000
0?ooo`000000303oool00`000000oooo0000000;0?ooo`030000003oool0000000l0oooo0P00000:
0?ooo`007P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000/0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0000000;0?ooo`040000003oool0oooo000000X0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`0000002P3oool00`000000oooo0000000;0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0000000<0?ooo`03
0000003oool0000000X0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`080?oo
o`007P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0000000;0?ooo`040000003oool0oooo000000X0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0000000;0?oo
o`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?oo
o`080?ooo`007P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000X0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0000000;0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000403oool00`00
0000oooo0?ooo`080?ooo`007P3oool2000000l0oooo00@000000?ooo`3oool000002P3oool01000
0000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000?0?oo
o`8000002P3oool001h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`04
0000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3o
ool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`007P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3o
ool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool001h0
oooo0P0000040?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000002P3oool01000
0000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo0080oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo
0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00100oooo0`0000040?ooo`8000001@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000002P3oool01000
0000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool000l0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00P0oooo000C0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
203oool001<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000
103oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3o
ool000002P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo0080oooo0P00000:0?ooo`003`3oool4000000<0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo000000090?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3o
ool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`003`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002@3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`0000090?ooo`050000003oool0oooo0?ooo`0000002P3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002P3oool01000
0000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo000?0?oo
o`D000000`3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`0000002@3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?oo
o`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000X0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00002@3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00D000000?ooo`3oool0oooo000000090?ooo`040000003oool0oooo000000X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000@0oooo00<000000?oo
o`3oool0203oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3o
ool000002@3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo
0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0080oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000090?ooo`040000003oool0
oooo000000T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`00
00002@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000090?ooo`040000
003oool0oooo000000T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`050000
003oool0oooo0?ooo`0000002@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000oooo0?ooo`000009
0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000T0oooo
00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000oooo0?oo
o`0000090?ooo`050000003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`00000:0?oo
o`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?oo
o`3oool0000000T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1`3oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002@3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00D000000?ooo`3oool0oooo000000090?ooo`050000003o
ool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00D000000?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool000002@3oool01@000000
oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0
oooo0?ooo`0000002@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool001h0oooo0P0000050?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`040000003oool0oooo000000T0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002@3oool0
1@000000oooo0?ooo`3oool0000000X0oooo00D000000?ooo`3oool0oooo000000080?ooo`050000
003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000X0oooo00D000000?oo
o`3oool0oooo000000090?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3o
ool2000000X0oooo000N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000002@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00D000000?ooo`3oool0oooo000000090?ooo`05
0000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000203oool01@000000oooo
0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000P0oooo
00D000000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`0000002@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool01@000000oooo
0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool00000
00T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool0000000X0oooo00D000000?ooo`3oool0oooo000000090?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000203oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`07
0?ooo`050000003oool0oooo0?ooo`000000203oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`007P3oool2000000D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00D000000?ooo`3oool0oooo000000080?ooo`050000003oool0oooo0?ooo`000000
2@3oool00`000000oooo0?ooo`030?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool001h0oooo0P0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0
oooo000000090?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool00`3oool2000000X0oooo000N0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo000:0?ooo`<00000103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo000;0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00<0oooo0P00000:0?ooo`002`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`00
2`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`002P3oool2000000@0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00<0oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`080?ooo`007P3oool2000000D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool001h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool001h0oooo0P0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool2000000X0oooo
000N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000001P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo0P00000:0?ooo`007P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`080?ooo`007P3oool2000000H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0203oool000X0oooo0`0000030?ooo`<00000103o
ool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0203oool000/0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`002`3oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08
0?ooo`002`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool2000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`8000002P3o
ool000/0oooo00@000000?ooo`3oool0oooo100000030?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool000X0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`002`3oool010000000oooo0?ooo`3oool5000000<0oooo0P0000050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo000N0?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0P00000:
0?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`007P3oool20000
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool2000000X0oooo000N0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
01h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo000N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`007P3oool2000000L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool2
000000X0oooo000N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000001`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00090?ooo`D000000`3oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`002P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P0000070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`00303oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`002P3oool3000000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0203oool001h0oooo0P0000070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool2000000X0oooo000N0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0
oooo000N0?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`8000002P3oool001h0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000001`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`8000002P3oool000T0oooo1@0000020?ooo`<00000103oool2000000D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo000:0?ooo`060000
003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo000;0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`080?ooo`00303oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool2000000X0oooo00090?ooo`060000003o
ool0oooo0?ooo`000000oooo100000030?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000002@3oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0
oooo00090?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0000000T0oooo
00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`08
0?ooo`002P3oool300000080oooo1@0000030?ooo`8000001@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`00000:0?ooo`050000003o
ool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000090?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo000N0?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000X0oooo00@0
00000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3o
ool0oooo000000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool2000000X0oooo000N0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3o
ool0oooo000000090?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`00
0000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`000000
203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`050000003oool0
oooo0?ooo`0000002P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000P0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`00
00002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000000T0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo000000020?ooo`030000003oool0
oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
2@3oool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool000002@3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`0000090?ooo`050000003oool0oooo0?ooo`0000002@3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`0000090?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?ooo`050000003oool0oooo
0?ooo`0000002@3oool01@000000oooo0000003oool0000000X0oooo00@000000?ooo`3oool00000
2P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000
oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
00090?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000T0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`0000090?ooo`050000003oool0oooo0?ooo`0000002P3oool200000003
0?ooo`000000oooo00T0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0
000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00P0oooo000N0?ooo`800000203oool010000000oooo0?ooo`0000090?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000:0?ooo`050000003o
ool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000P0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`070?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?oo
o`00000:0?ooo`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000:0?ooo`05
0000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool2000000030?ooo`000000oooo00T0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`0000090?ooo`050000003oool0oooo0?ooo`000000
2P3oool01@000000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3oool000002P3oool01000
0000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002@3oool01@000000oooo0?ooo`3oool00000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`080?ooo`007P3o
ool2000000P0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?ooo`05
0000003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo0P0000000`3oool000000?ooo`090?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000203oool2000000X0oooo
000N0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000002P3oool010000000oooo
0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`00000:0?ooo`80000000<0oooo0000003oool02@3oool01000
0000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool0203oool000X0oooo0`0000040?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo0P0000000`3oool000000?ooo`090?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`080?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`800000
00<0oooo0000003oool02@3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0203oool000d0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0P00
00080?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3o
ool000002P3oool2000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`0000080?ooo`8000002P3oool000/0oooo0P00
00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool2000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00P0oooo000=0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3o
ool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@0
00000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`80000000<0oooo0000003o
ool02@3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool0203oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool2000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00P0oooo000:0?ooo`<00000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0
oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
000:0?ooo`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo
0?ooo`00000:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0203oool001h0
oooo0P0000080?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@00000
0?ooo`3oool000002P3oool2000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool00000
2P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`0000080?ooo`8000002P3oool001h0
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`040000003oool0oooo000000X0oooo0P0000000`3oool000000?ooo`090?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?oo
o`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
00X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003o
ool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?oo
o`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool2000000030?ooo`00
0000oooo00T0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`04
0000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo
000000/0oooo0P00000;0?ooo`030000003oool0000000/0oooo00@000000?ooo`3oool000002P3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0000000/0oooo0P0000000`3oool00000
0?ooo`090?ooo`030000003oool0000000/0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`0000002`3oool0
0`000000oooo0000000;0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000T0oooo00<000000?ooo`0000002P3o
ool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000/0oooo0P00000;0?ooo`03
0000003oool0000000/0oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0000000/0oooo0P0000000`3oool000000?ooo`0:0?ooo`8000002`3oool0
10000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0
00002`3oool2000000`0oooo0P00000;0?ooo`040000003oool0oooo000000X0oooo00@000000?oo
o`3oool00000203oool2000000X0oooo000N0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`0000002P3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000/0oooo0P00
000<0?ooo`8000002`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0000000/0oooo
00<000000?ooo`0000002`3oool2000000030?ooo`000000oooo00X0oooo0P00000<0?ooo`800000
2`3oool00`000000oooo0000000;0?ooo`040000003oool0oooo000000/0oooo0P00000<0?ooo`80
00002`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000:0?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`000000303oool2000000`0oooo0P00000;
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`000000303oool2000000/0oooo0`00
000<0?ooo`800000303oool2000000/0oooo00<000000?ooo`000000303oool00`000000oooo0000
000;0?ooo`800000303oool2000000/0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0000000:0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00P0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
000<0?ooo`8000002`3oool3000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00
000<0?ooo`800000303oool2000000`0oooo0P00000;0?ooo`030000003oool0000000X0oooo00<0
00000?ooo`3oool0203oool001h0oooo0P0000090?ooo`800000303oool2000000`0oooo0P00000<
0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<
0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<
0?ooo`800000303oool2000000T0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`080?oo
o`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?oo
o`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?oo
o`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000X0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool0203oool2000000`0oooo0P00000<0?ooo`80
0000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`80
0000303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`80
0000303oool2000000`0oooo0P00000:0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo00P0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000
303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000
303oool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000
2P3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`080?ooo`800000303o
ool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303o
ool2000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303o
ool2000000`0oooo0P00000<0?ooo`800000303oool2000000X0oooo00<000000?ooo`3oool0203o
ool001h0oooo0P0000090?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2
000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2
000000`0oooo0P00000<0?ooo`800000303oool2000000`0oooo0P00000<0?ooo`800000303oool2
000000T0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`007P3ooooh000000X0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003E0?ooo`<00000B03oool00=H0oooo00<000000?ooo`3oool0A`3oool005L0oooo1@00
00001@3oool00000000000000000oooo008000000P3oool2000000<0oooo0`0000020?ooo`<00000
0`3oool500000080oooo0`0000020?ooo`<00000103oool300000080oooo0`000000103oool00000
0000003oool3000000<0oooo0`0000080?ooo`D0000000D0oooo00000000000000000?ooo`020000
0080oooo0P0000030?ooo`<000000P3oool3000000030?ooo`000000000000@000000P3oool50000
00<0oooo0P0000040?ooo`030000003oool0oooo04H0oooo001I0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo0000000=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
1P000000oooo0?ooo`000000oooo000000H0oooo00@000000?ooo`3oool000001@3oool01@000000
oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`16
0?ooo`00F@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool500000080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3o
ool500000080oooo00<000000?ooo`3oool00P3oool500000080oooo00H000000?ooo`3oool00000
0?ooo`0000050?ooo`D000002@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool500000080oooo00@000000?ooo`3oool000000P3oool3
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000004L0oooo001I0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000D0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo008000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo
00H000000?ooo`3oool000000?ooo`0000070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000170?ooo`00F@3oool010000000oooo0?ooo`3oool40000
0080oooo100000030?ooo`<000000P3oool2000000030?ooo`00000000000080oooo100000020?oo
o`<000000P3oool2000000030?ooo`00000000000080oooo0`0000020?ooo`@000000`3oool30000
00<0oooo0`00000:0?ooo`040000003oool0oooo0?ooo`@000000P3oool4000000<0oooo0`000002
0?ooo`@000000`3oool4000000040?ooo`0000000000000000<0oooo100000020?ooo`80000000<0
oooo000000000000AP3oool005T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo04d0oooo001G0?ooo`D00000203oool00`000000oooo0?ooo`0A0?oo
o`800000:`3oool5000000P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo04d0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00654138, -33.8891, \
4.24814*^-5, 2.32197}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2", "Subsubsection",
  CellTags->{"AOG0.", "6.2.2", "AOG6.", "AOG6.2", "AOG6.2.2"}],

Cell["\<\
sys = {
MoveDirected[WedgeOfRays[2],{0,-2},{100,0},SideOfObject->After],
MoveDirected[LineOfRays[5],{0,2},{100,0},SideOfObject->After],
Move[Screen[100],100]};\
\>", "Input",
  CellLabel->"In[32]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],

Cell[CellGroupData[{

Cell["DrawSystem[sys,PlotType->TopView];", "Input",
  CellLabel->"In[33]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9995 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0242854 0.00951905 0.49975 0.00951905 [
[ 0 0 0 0 ]
[ 1 .9995 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .0238 m
.97619 .18245 L
.97619 .3411 L
.97619 .49975 L
.97619 .6584 L
.97619 .81705 L
.97619 .9757 L
.97619 .9757 L
.97619 .81705 L
.97619 .6584 L
.97619 .49975 L
.97619 .3411 L
.97619 .18245 L
.97619 .0238 L
.97619 .0238 L
s
.97619 .49975 m
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
s
.97619 .9757 m
.97619 .95949 L
.97619 .91194 L
.97619 .8363 L
.97619 .73773 L
.97619 .62294 L
.97619 .49975 L
.97619 .37656 L
.97619 .26177 L
.97619 .1632 L
.97619 .08756 L
.97619 .04002 L
.97619 .0238 L
.97619 .04002 L
.97619 .08756 L
.97619 .1632 L
.97619 .26177 L
.97619 .37656 L
.97619 .49975 L
.97619 .62294 L
.97619 .73773 L
.97619 .8363 L
.97619 .91194 L
.97619 .95949 L
.97619 .9757 L
s
.039 .916 .04 r
.02429 .48071 m
.97619 .48313 L
s
% Start of user PostScript
0 -2. 100. -1.7456 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .48313 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .48071 m
.97619 .49975 L
s
% Start of user PostScript
0 -2. 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .49975 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .48071 m
.97619 .51638 L
s
% Start of user PostScript
0 -2. 100. 1.74681 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .51638 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .495 m
.97619 .47595 L
s
% Start of user PostScript
-0.04999 -0.4995 100. -2.5005 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .47595 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .51879 m
.97619 .49975 L
s
% Start of user PostScript
0 2. 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .49975 Mdot
.039 .916 .04 r
.5 Mabswid
.02476 .54258 m
.97619 .52355 L
s
% Start of user PostScript
0.04999 4.4995 100. 2.5005 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .52355 Mdot
0 0 m
1 0 L
1 .9995 L
0 .9995 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{288, 287.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00017b000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo4@3oool300WZ2PD0oooo00<000000?ooo`3oool01@3o
ool00?l0oooo4P3oool600WZ2P030?ooo`000000oooo00H0oooo003o0?ooo`80oooo5P09jPX20000
00L0oooo003C0?ooobh02NX:403oool600WZ2P8000001`3oool000H0ooooo`09jPXB00WZ2P800000
1`3oool001D0ooooA009jPXO0?ooobh02NX:J`3oool500WZ2P030?ooo`000000000000L0oooo000`
0?ooof002NX:P03oool200WZ2PH0oooo00<000000?ooo`3oool01@3oool001d0oooo;@09jPX20?oo
oa/02NX::@3ooolg00WZ2TT0oooo0`09jPX50?ooo`030000003oool0oooo00D0oooo00060?oooaL0
2NX:BP3ooolK00WZ2TD0oooo=`09jPXC0?ooo`H02NX:00<0oooo0000003oool01P3oool00880oooo
7009jPYP0?oooaT02NX:0P0000070?ooo`00WP3ooolK00WZ2QX0oooo;P09jPX@0?ooo`D02NX:00<0
oooo0000000000001`3oool00:H0oooo;`09jPXk0?ooo`802NX:1P3oool00`000000oooo0?ooo`05
0?ooo`00N03oool^00WZ2Rl0oooo6`09jPXP0?ooo`<02NX:1@3oool00`000000oooo0?ooo`050?oo
o`00BP3oool^00WZ2WP0oooo6`09jPX60?ooo`H02NX:0P0000070?ooo`007@3oool]00WZ2/40oooo
3009jPX2000000L0oooo00060?oooaL02NX:m03oool600WZ2P8000001`3oool00?d0oooo6P09jPX2
000000L0oooo00360?ooocL02NX:503oool500WZ2P80oooo00<000000?ooo`3oool01@3oool008l0
oooo=`09jPY:0?ooo`802NX:1P3oool00`000000oooo0?ooo`050?ooo`00F@3ooolf00WZ2XT0oooo
00<000000?ooo`3oool01@3oool00280oooo=`09jPZo0?ooo`030000003oool0oooo00D0oooo0007
0?oooa/02NX:mP3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo
00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo
0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<00000
0?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`03
0000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oo
oaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00
o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3o
ool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo
00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo
0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<00000
0?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`03
0000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oo
oaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00
o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3o
ool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo
00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo
0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<00000
0?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`03
0000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oo
oaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00
o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3o
ool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo
00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo
0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<00000
0?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`03
0000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oo
oaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00
o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3o
ool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo
00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo
0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<00000
0?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`03
0000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oo
oaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00
o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3o
ool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo
00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo
0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<00000
0?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`03
0000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oo
oaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00
o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3o
ool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo
00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo
0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<00000
0?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`03
0000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oo
oaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00
o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3o
ool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo
00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo
0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<00000
0?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`03
0000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3o
ool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oo
oaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00
o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3o
ool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo
00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo
0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<00000
0?ooo`3oool01@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {286.812, 0}} -> {-2.55983, -52.5005, \
0.366096, 0.366096}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["wavefront = FindWaveFronts[sys]", "Input",
  CellLabel->"In[34]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499834 0.2727 -842.718 8.4273 [
[.09078 -0.0125 -12 -9 ]
[.09078 -0.0125 12 0 ]
[.22713 -0.0125 -6 -9 ]
[.22713 -0.0125 6 0 ]
[.36348 -0.0125 -12 -9 ]
[.36348 -0.0125 12 0 ]
[.49983 -0.0125 -3 -9 ]
[.49983 -0.0125 3 0 ]
[.63618 -0.0125 -9 -9 ]
[.63618 -0.0125 9 0 ]
[.77253 -0.0125 -3 -9 ]
[.77253 -0.0125 3 0 ]
[.90888 -0.0125 -9 -9 ]
[.90888 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01199 -18 -4.5 ]
[-0.0125 .01199 0 4.5 ]
[-0.0125 .09626 -36 -4.5 ]
[-0.0125 .09626 0 4.5 ]
[-0.0125 .18053 -36 -4.5 ]
[-0.0125 .18053 0 4.5 ]
[-0.0125 .26481 -36 -4.5 ]
[-0.0125 .26481 0 4.5 ]
[-0.0125 .34908 -36 -4.5 ]
[-0.0125 .34908 0 4.5 ]
[-0.0125 .43335 -36 -4.5 ]
[-0.0125 .43335 0 4.5 ]
[-0.0125 .51763 -36 -4.5 ]
[-0.0125 .51763 0 4.5 ]
[-0.0125 .6019 -36 -4.5 ]
[-0.0125 .6019 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09078 0 m
.09078 .00625 L
s
[(-1.5)] .09078 -0.0125 0 1 Mshowa
.22713 0 m
.22713 .00625 L
s
[(-1)] .22713 -0.0125 0 1 Mshowa
.36348 0 m
.36348 .00625 L
s
[(-0.5)] .36348 -0.0125 0 1 Mshowa
.49983 0 m
.49983 .00625 L
s
[(0)] .49983 -0.0125 0 1 Mshowa
.63618 0 m
.63618 .00625 L
s
[(0.5)] .63618 -0.0125 0 1 Mshowa
.77253 0 m
.77253 .00625 L
s
[(1)] .77253 -0.0125 0 1 Mshowa
.90888 0 m
.90888 .00625 L
s
[(1.5)] .90888 -0.0125 0 1 Mshowa
.125 Mabswid
.11805 0 m
.11805 .00375 L
s
.14532 0 m
.14532 .00375 L
s
.17259 0 m
.17259 .00375 L
s
.19986 0 m
.19986 .00375 L
s
.2544 0 m
.2544 .00375 L
s
.28167 0 m
.28167 .00375 L
s
.30894 0 m
.30894 .00375 L
s
.33621 0 m
.33621 .00375 L
s
.39075 0 m
.39075 .00375 L
s
.41802 0 m
.41802 .00375 L
s
.44529 0 m
.44529 .00375 L
s
.47256 0 m
.47256 .00375 L
s
.5271 0 m
.5271 .00375 L
s
.55437 0 m
.55437 .00375 L
s
.58164 0 m
.58164 .00375 L
s
.60891 0 m
.60891 .00375 L
s
.66345 0 m
.66345 .00375 L
s
.69072 0 m
.69072 .00375 L
s
.71799 0 m
.71799 .00375 L
s
.74526 0 m
.74526 .00375 L
s
.7998 0 m
.7998 .00375 L
s
.82707 0 m
.82707 .00375 L
s
.85434 0 m
.85434 .00375 L
s
.88161 0 m
.88161 .00375 L
s
.06351 0 m
.06351 .00375 L
s
.03624 0 m
.03624 .00375 L
s
.00897 0 m
.00897 .00375 L
s
.93615 0 m
.93615 .00375 L
s
.96342 0 m
.96342 .00375 L
s
.99069 0 m
.99069 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01199 m
.00625 .01199 L
s
[(100)] -0.0125 .01199 1 0 Mshowa
0 .09626 m
.00625 .09626 L
s
[(100.01)] -0.0125 .09626 1 0 Mshowa
0 .18053 m
.00625 .18053 L
s
[(100.02)] -0.0125 .18053 1 0 Mshowa
0 .26481 m
.00625 .26481 L
s
[(100.03)] -0.0125 .26481 1 0 Mshowa
0 .34908 m
.00625 .34908 L
s
[(100.04)] -0.0125 .34908 1 0 Mshowa
0 .43335 m
.00625 .43335 L
s
[(100.05)] -0.0125 .43335 1 0 Mshowa
0 .51763 m
.00625 .51763 L
s
[(100.06)] -0.0125 .51763 1 0 Mshowa
0 .6019 m
.00625 .6019 L
s
[(100.07)] -0.0125 .6019 1 0 Mshowa
.125 Mabswid
0 .02884 m
.00375 .02884 L
s
0 .0457 m
.00375 .0457 L
s
0 .06255 m
.00375 .06255 L
s
0 .07941 m
.00375 .07941 L
s
0 .11312 m
.00375 .11312 L
s
0 .12997 m
.00375 .12997 L
s
0 .14682 m
.00375 .14682 L
s
0 .16368 m
.00375 .16368 L
s
0 .19739 m
.00375 .19739 L
s
0 .21424 m
.00375 .21424 L
s
0 .2311 m
.00375 .2311 L
s
0 .24795 m
.00375 .24795 L
s
0 .28166 m
.00375 .28166 L
s
0 .29852 m
.00375 .29852 L
s
0 .31537 m
.00375 .31537 L
s
0 .33223 m
.00375 .33223 L
s
0 .36593 m
.00375 .36593 L
s
0 .38279 m
.00375 .38279 L
s
0 .39964 m
.00375 .39964 L
s
0 .4165 m
.00375 .4165 L
s
0 .45021 m
.00375 .45021 L
s
0 .46706 m
.00375 .46706 L
s
0 .48392 m
.00375 .48392 L
s
0 .50077 m
.00375 .50077 L
s
0 .53448 m
.00375 .53448 L
s
0 .55134 m
.00375 .55134 L
s
0 .56819 m
.00375 .56819 L
s
0 .58504 m
.00375 .58504 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09078 .61178 m
.09078 .61803 L
s
.22713 .61178 m
.22713 .61803 L
s
.36348 .61178 m
.36348 .61803 L
s
.49983 .61178 m
.49983 .61803 L
s
.63618 .61178 m
.63618 .61803 L
s
.77253 .61178 m
.77253 .61803 L
s
.90888 .61178 m
.90888 .61803 L
s
.125 Mabswid
.11805 .61428 m
.11805 .61803 L
s
.14532 .61428 m
.14532 .61803 L
s
.17259 .61428 m
.17259 .61803 L
s
.19986 .61428 m
.19986 .61803 L
s
.2544 .61428 m
.2544 .61803 L
s
.28167 .61428 m
.28167 .61803 L
s
.30894 .61428 m
.30894 .61803 L
s
.33621 .61428 m
.33621 .61803 L
s
.39075 .61428 m
.39075 .61803 L
s
.41802 .61428 m
.41802 .61803 L
s
.44529 .61428 m
.44529 .61803 L
s
.47256 .61428 m
.47256 .61803 L
s
.5271 .61428 m
.5271 .61803 L
s
.55437 .61428 m
.55437 .61803 L
s
.58164 .61428 m
.58164 .61803 L
s
.60891 .61428 m
.60891 .61803 L
s
.66345 .61428 m
.66345 .61803 L
s
.69072 .61428 m
.69072 .61803 L
s
.71799 .61428 m
.71799 .61803 L
s
.74526 .61428 m
.74526 .61803 L
s
.7998 .61428 m
.7998 .61803 L
s
.82707 .61428 m
.82707 .61803 L
s
.85434 .61428 m
.85434 .61803 L
s
.88161 .61428 m
.88161 .61803 L
s
.06351 .61428 m
.06351 .61803 L
s
.03624 .61428 m
.03624 .61803 L
s
.00897 .61428 m
.00897 .61803 L
s
.93615 .61428 m
.93615 .61803 L
s
.96342 .61428 m
.96342 .61803 L
s
.99069 .61428 m
.99069 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01199 m
1 .01199 L
s
.99375 .09626 m
1 .09626 L
s
.99375 .18053 m
1 .18053 L
s
.99375 .26481 m
1 .26481 L
s
.99375 .34908 m
1 .34908 L
s
.99375 .43335 m
1 .43335 L
s
.99375 .51763 m
1 .51763 L
s
.99375 .6019 m
1 .6019 L
s
.125 Mabswid
.99625 .02884 m
1 .02884 L
s
.99625 .0457 m
1 .0457 L
s
.99625 .06255 m
1 .06255 L
s
.99625 .07941 m
1 .07941 L
s
.99625 .11312 m
1 .11312 L
s
.99625 .12997 m
1 .12997 L
s
.99625 .14682 m
1 .14682 L
s
.99625 .16368 m
1 .16368 L
s
.99625 .19739 m
1 .19739 L
s
.99625 .21424 m
1 .21424 L
s
.99625 .2311 m
1 .2311 L
s
.99625 .24795 m
1 .24795 L
s
.99625 .28166 m
1 .28166 L
s
.99625 .29852 m
1 .29852 L
s
.99625 .31537 m
1 .31537 L
s
.99625 .33223 m
1 .33223 L
s
.99625 .36593 m
1 .36593 L
s
.99625 .38279 m
1 .38279 L
s
.99625 .39964 m
1 .39964 L
s
.99625 .4165 m
1 .4165 L
s
.99625 .45021 m
1 .45021 L
s
.99625 .46706 m
1 .46706 L
s
.99625 .48392 m
1 .48392 L
s
.99625 .50077 m
1 .50077 L
s
.99625 .53448 m
1 .53448 L
s
.99625 .55134 m
1 .55134 L
s
.99625 .56819 m
1 .56819 L
s
.99625 .58504 m
1 .58504 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.49983 0 m
.49983 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.05452 .01766 Mdot
.08522 .02168 Mdot
.11593 .02677 Mdot
.14664 .03292 Mdot
.17735 .04014 Mdot
.20806 .04843 Mdot
.23877 .05779 Mdot
.26948 .06822 Mdot
.30019 .07972 Mdot
.3309 .09229 Mdot
.36161 .10592 Mdot
.39233 .12063 Mdot
.42304 .1364 Mdot
.45376 .15325 Mdot
.48447 .17116 Mdot
.51519 .19014 Mdot
.54591 .21019 Mdot
.57664 .23132 Mdot
.60736 .25351 Mdot
.63808 .27677 Mdot
.66881 .3011 Mdot
.69954 .3265 Mdot
.73027 .35298 Mdot
.761 .38052 Mdot
.79174 .40913 Mdot
.82247 .43882 Mdot
.85321 .46958 Mdot
.88395 .5014 Mdot
.9147 .5343 Mdot
.94544 .56828 Mdot
.5 Mabswid
.02381 .01472 m
.05372 .01759 L
.08634 .02187 L
.11698 .02698 L
.14644 .03288 L
.1778 .04027 L
.20799 .04842 L
.24008 .05824 L
.27099 .06879 L
.30073 .07994 L
.33237 .09294 L
.36283 .10651 L
.39213 .12053 L
.42332 .13655 L
.45333 .15301 L
.48525 .17164 L
.51599 .19066 L
.54556 .20996 L
.57703 .2316 L
.60732 .25348 L
.63951 .2779 L
.67053 .30253 L
.70038 .32723 L
.73212 .35464 L
.76269 .3821 L
.79209 .40948 L
.82339 .43974 L
.85351 .46989 L
.88553 .50309 L
.91638 .53616 L
.94605 .56897 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00>03oool3000000@0oooo00<000000?ooo`3oool00P3oool3000001T0oooo0`00000J0?oo
o`800000103oool00`000000oooo0?ooo`020?ooo`<000005P3oool2000001X0oooo0P0000040?oo
o`030000003oool0oooo0080oooo0`00000I0?ooo`<000006@3oool3000000@0oooo00<000000?oo
o`3oool00P3oool300000140oooo000i0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3o
ool0oooo0000000I0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool000001`3oool0
1@000000oooo0?ooo`3oool0000001@0oooo00@000000?ooo`3oool00000603oool010000000oooo
0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000006@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`00<@3oool50000
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`D000000`3oool00`00
0000oooo0?ooo`0A0?ooo`D000000P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo0180oooo00@000000?ooo`3oool00000603oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00h0oooo000i0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
4P3oool010000000oooo0?ooo`00000H0?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool03P3oool003T0oooo00<000000?ooo`3oool01`3oool4000001X0oooo00<000000?ooo`3o
ool0603oool010000000oooo0?ooo`0000070?ooo`@000005@3oool010000000oooo0?ooo`00000H
0?ooo`040000003oool0oooo000000L0oooo1000000J0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01`3oool400000140oooo000h0?ooo`8000002@3oool00`000000oooo0?ooo`0J
0?ooo`8000006P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo01H0oooo00@0
00000?ooo`3oool00000603oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo01X0
oooo0P00000J0?ooo`8000002@3oool00`000000oooo0?ooo`0B0?ooo`00>@3oool00`000000oooo
0?ooo`070?ooo`D000006@3oool00`000000oooo0?ooo`0I0?ooo`800000203oool5000001D0oooo
0P00000J0?ooo`800000203oool5000001T0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`070?ooo`D00000403oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool001<0oooo0`0000040?ooo`800000103oool2000000D0oooon00000010?ooo`00503o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo000000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000010?ooo`00503oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo07T0oooo0@0000010?ooo`00503oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool2000000@0oooo1@00001`
0?ooo`030000003oool0oooo07P0oooo0P0000010?ooo`00503oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`080?ooo`L00000J@3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool001<0oooo0P000004
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0:0?ooo`8000000`3oool800000640oooo00<000000?ooo`3oool0N@3oool100000040oooo
000D0?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`0A0?ooo`800000103oool6000005/0oooo00<000000?ooo`3oool0N@3oool100000040oooo000W
0?ooo`8000006P3oool200000080oooo1@00001F0?ooo`030000003oool0oooo07P0oooo0P000001
0?ooo`009`3oool00`000000oooo0?ooo`0P0?ooo`@00000E03oool00`000000oooo0?ooo`1i0?oo
o`4000000@3oool002L0oooo00<000000?ooo`3oool0903oool6000004h0oooo00<000000?ooo`3o
ool0N@3oool100000040oooo000W0?ooo`030000003oool0oooo02P0oooo1000001<0?ooo`030000
003oool0oooo07T0oooo0@0000010?ooo`009`3oool2000002d0oooo0`0000000`3oool000000000
00160?ooo`030000003oool0oooo07P0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`0_
0?ooo`@00000A@3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo00<000000?oo
o`3oool0<`3oool400000440oooo00<000000?ooo`3oool0N@3oool100000040oooo000W0?ooo`03
0000003oool0oooo03L0oooo0`00000n0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`00
9`3oool2000003P0oooo0P000000103oool0000000000000000k0?ooo`030000003oool0oooo07P0
oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`0m0?ooo`@00000=`3oool00`000000oooo
0?ooo`1i0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0?`3oool4000003D0oooo00<0
00000?ooo`3oool0N@3oool100000040oooo000W0?ooo`030000003oool0oooo04<0oooo0`00000b
0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`009`3oool2000004L0oooo0`00000_0?oo
o`030000003oool0oooo07P0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`160?ooo`80
000000<0oooo000000000000;@3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool000040?oo
o`0000000000000000@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`030?ooo`80
00000`3oool3000000D0oooo00<000000?ooo`3oool0B`3oool2000002/0oooo00<000000?ooo`3o
ool0N@3oool100000040oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1=0?ooo`<00000:03oool00`000000oooo0?ooo`1i
0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`040?ooo`800000C`3oool3000002L0oooo00<000000?ooo`3oool0N03oool200000040oooo
00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1A0?ooo`<00000903oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool00080
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo05@0oooo0`00000Q0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`0000<0oooo
000000000000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool2000000H0oooo00<000000?ooo`3oool0EP3oool3000001l0
oooo00<000000?ooo`3oool0N@3oool100000040oooo00020?ooo`030000003oool0oooo00<0oooo
0P0000040?ooo`8000002P3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1F0?ooo`80000000@0oooo0000000000000000703oool00`000000oooo0?ooo`1i0?ooo`40
00000@3oool002L0oooo0P00001M0?ooo`8000006P3oool00`000000oooo0?ooo`1h0?ooo`800000
0@3oool002L0oooo00<000000?ooo`3oool0G@3oool3000001P0oooo00<000000?ooo`3oool0N@3o
ool100000040oooo000W0?ooo`030000003oool0oooo05d0oooo0P0000000`3oool000000000000F
0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1R0?oo
o`800000503oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo0P00001U0?ooo`80
00004P3oool00`000000oooo0?ooo`1h0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0
I@3oool300000100oooo00<000000?ooo`3oool0N@3oool100000040oooo000W0?ooo`030000003o
ool0oooo06D0oooo0P0000000`3oool000000000000>0?ooo`030000003oool0oooo07T0oooo0@00
00010?ooo`009`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0N@3oool100000040oooo000W0?ooo`800000K03oool2000000/0oooo00<000000?oo
o`3oool0N03oool200000040oooo000W0?ooo`030000003oool0oooo06`0oooo0`0000090?ooo`03
0000003oool0oooo07T0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1/0?ooo`800000
00<0oooo0000003oool01`3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo00<0
00000?ooo`3oool0L03oool2000000H0oooo00<000000?ooo`3oool0N@3oool100000040oooo000W
0?ooo`800000L`3oool2000000@0oooo00<000000?ooo`3oool0N03oool200000040oooo000W0?oo
o`030000003oool0oooo07@0oooo00D000000?ooo`3oool0oooo0000001k0?ooo`4000000@3oool0
00040?ooo`0000000000000000@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`8000000P3oool5000000@0oooo00<000000?ooo`3oool0M03oool3000000030?ooo`000000
oooo07X0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0M03oool2000000030?ooo`000000000007/0
oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00@0oooo0P00001i0?ooo`800000N@3oool200000040oooo00020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0000007T0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00<00000MP3oool100000040oooo00000`3oool00000000000040?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1h0?ooo`040000003oool0oooo0?oo
o`800000MP3oool100000040oooo00020?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`80
00002P3oool2000000<0oooo0`0000050?ooo`800000N@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0780oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo00@0oooo0P00001c0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`060?ooo`800000L@3oool100000040oooo000W0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool0203oool2000006l0oooo0@0000010?ooo`009`3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00P0oooo0`00001^0?ooo`4000000@3oool002L0
oooo0P00001i0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0JP3oool200000040
oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0303oool2000006/0oooo
0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00h0oooo0P00
001Y0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo06H0oooo0@0000010?ooo`009`3oool2000007T0oooo00<000000?oo
o`3oool0403oool3000006D0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo0100oooo0P0000000`3oool000000?ooo`1T0?ooo`4000000@3oool002L0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0D0?ooo`800000H`3oool100000040oooo
000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1P0?ooo`4000000@3oool002L0oooo0P00001i0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0GP3oool200000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool05`3oool3000005l0oooo0@0000010?ooo`0000@0oooo0000000000000000103oool20000
00@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<000001@3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo01L0oooo0P0000000`3oool000000?ooo`1M0?oo
o`4000000@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo05/0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0080oooo0P00001i0?ooo`030000003oool0oooo01`0oooo0P00001J0?oo
o`8000000@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool2000000D0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05P0oooo0@00
00010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo05L0
oooo0@0000010?ooo`0000<0oooo000000000000103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0O0?ooo`<00000E`3o
ool100000040oooo00020?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`8000002P3oool2
000000<0oooo0`0000050?ooo`800000N@3oool00`000000oooo0?ooo`0O0?ooo`80000000<0oooo
0000003oool0E03oool200000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`1C0?ooo`4000000@3oool002L0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0T0?ooo`800000D`3oool100000040oooo000W0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1@0?ooo`400000
0@3oool002L0oooo0P00001i0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0CP3o
ool200000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool09`3oool2
00000500oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
02L0oooo0`00001?0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo04`0oooo0@0000010?ooo`009`3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0B`3oool100000040oooo
000W0?ooo`800000N@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo04T0oooo0P00
00010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0B@3oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool0;P3oool2000004T0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo02h0oooo0`0000180?ooo`4000000@3oool002L0oooo0P00001i0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0A03oool200000040oooo0000103oool000000000
000000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo
0`0000040?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`140?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0<`3oool20000
04@0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000203oool01@000000oooo0?ooo`000000oooo00D00000103o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@@3o
ool100000040oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool000000P3oool00`00
0000oooo0?ooo`030?ooo`800000N@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
03l0oooo0P0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0000000D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0f0?ooo`800000@@3o
ool100000040oooo00000`3oool00000000000040?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`8000001@3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo03H0oooo0`0000100?ooo`4000000@3oool00080oooo
00<000000?ooo`3oool00`3oool2000000@0oooo0P00000:0?ooo`8000001@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0m0?ooo`4000000@3oool002L0oooo0P00001i0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0>`3oool200000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`4000000@3oool002L0oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03X0oooo0@0000010?oo
o`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03d0oooo0P00000j0?ooo`40
00000@3oool002L0oooo0P00001i0?ooo`030000003oool0oooo03d0oooo0`00000h0?ooo`800000
0@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo03H0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0=@3oool100000040oooo000W0?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0d0?ooo`4000000@3oool002L0
oooo0P00001i0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0<P3oool200000040
oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0b0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`150?ooo`800000<P3oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool0A@3oool200000380oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0;`3oool100000040oooo000W0?ooo`80
0000N@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02d0oooo0P0000010?ooo`00
00@0oooo0000000000000000103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo00<0
oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0;@3oool100000040oooo00020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0/0?ooo`4000000@3oool00080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0[0?ooo`4000000@3oool00080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`800000N@3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02T0oooo0P0000010?ooo`000P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000203o
ool01@000000oooo0?ooo`000000oooo00@000001@3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo04d0oooo0P00000Z0?ooo`4000000@3oool000030?ooo`000000000000@0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000
003oool00000203oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo04d0oooo0P00000Z
0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P00000:0?oo
o`8000000P3oool5000000@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo02L0oooo0@0000010?ooo`009`3oool2000007T0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`0U0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02D0oooo0@0000010?ooo`009`3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0903o
ool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0S0?ooo`4000000@3oool002L0oooo0P00001i0?ooo`030000003oool0oooo
05@0oooo0P00000R0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`1D0?ooo`8000008`3oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0P0?ooo`4000000@3oool002L0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01l0oooo0@00
00010?ooo`009`3oool2000007T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0M
0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo01d0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0703oool100000040oooo000W0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0K0?ooo`400000
0@3oool002L0oooo0P00001i0?ooo`030000003oool0oooo05`0oooo0P00000J0?ooo`8000000@3o
ool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1L0?ooo`8000006`3oool1
00000040oooo0000103oool000000000000000040?ooo`800000103oool2000000@0oooo00<00000
0?ooo`3oool00`3oool2000000<0oooo0`0000050?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`0I0?ooo`4000000@3oool00080oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01P0oooo0@0000010?ooo`00
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool05`3o
ool100000040oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool0100000050?ooo`80
0000N@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01D0oooo0P0000010?ooo`00
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000P0oooo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01D0oooo0@0000010?ooo`0000<0oooo
000000000000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool00080oooo
00<000000?ooo`3oool00`3oool2000000@0oooo0P00000:0?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1S0?ooo`800000503oool100000040oooo
000W0?ooo`800000N@3oool00`000000oooo0?ooo`1S0?ooo`8000004`3oool200000040oooo000W
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0A
0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo0100oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool03`3oool100000040oooo000W0?ooo`800000
N@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00d0oooo0P0000010?ooo`009`3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool03@3o
ool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`0<0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`009`3oool2000007T0
oooo00<000000?ooo`3oool0J`3oool2000000/0oooo0P0000010?ooo`009`3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo06/0oooo0P00000<0?ooo`4000000@3oool002L0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00T0oooo0@00
00010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool0203oool100000040oooo000W0?ooo`800000N@3oool00`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo00H0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool01P3oool100000040oooo0000103oool00000
0000000000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool01P3oool100000040oooo00020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool01@3oool100000040oooo00020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00`3oool2000007T0oooo00<000000?ooo`3oool0
LP3oool00`000000oooo0?ooo`030?ooo`8000000@3oool00080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`030?ooo`4000000@3oool00080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0N@3oool100000040oooo00000`3oool00000000000040?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo000000010?ooo`000P3oool00`000000
oooo0?ooo`030?ooo`800000103oool2000000X0oooo0P0000020?ooo`D00000103ooooh00000040
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000c0?ooo`<00000F03oool30000
01L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0;0?ooo`00=03oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0J@3oool00`000000
oooo0?ooo`0:0?ooo`00;P3oool3000000<0oooo0`0000040?ooo`8000000P3oool500000080oooo
0`0000030?ooo`@0000000<0oooo0000000000000`0000070?ooo`<00000103oool4000000<0oooo
0P0000020?ooo`H000001P3oool500000080oooo0`0000020?ooo`<0000000@0oooo000000000000
oooo100000030?ooo`8000000P3oool6000000L0oooo00<000000?ooo`3oool00`3oool400000003
0?ooo`0000000000008000000P3oool4000000<0oooo0`0000020?ooo`D000000`3oool200000004
0?ooo`000000oooo0?ooo`8000000`3oool3000000T0oooo100000000`3oool00000000000030000
00030?ooo`000000000000800000103oool2000000<0oooo100000001@3oool00000000000000000
oooo0080000000@0oooo00000000000000000`3oool3000000D0oooo00<000000?ooo`3oool02@3o
ool002d0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000H0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool0
00000?ooo`00000;0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`000000203oool00`000000oooo
0?ooo`090?ooo`00;@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3oool30000
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00P3oool5
00000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo000000D0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`<000000`3oool01000
0000oooo0?ooo`0000020?ooo`<000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
1@0000070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool3000000<0
oooo00<000000?ooo`3oool00`3oool3000000<0oooo00H000000?ooo`3oool000000?ooo`000005
0?ooo`D00000103oool00`000000oooo0?ooo`090?ooo`00;@3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool300000080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000
003oool0oooo000000D0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo00@00000
0?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000030?ooo`060000003oool0oooo0000003oool000000`3oool0
0`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
02d0oooo00H000000?ooo`3oool0oooo0000003oool400000080oooo100000020?ooo`<00000103o
ool3000000<0oooo0P0000050?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000
0P3oool2000000<0oooo100000030?ooo`<000002@3oool00`000000oooo0?ooo`030?ooo`<00000
0P3oool4000000<0oooo2@0000030?ooo`<000002@3oool00`000000oooo0?ooo`030?ooo`800000
103oool3000000<0oooo100000020?ooo`<00000103oool010000000oooo0?ooo`3oool200000004
0?ooo`00000000000?ooo`@000000`3oool3000000T0oooo0`0000020?ooo`<00000103oool40000
00030?ooo`0000000000008000000`3oool2000000<0oooo100000030?ooo`<000000`3oool30000
00D0oooo00<000000?ooo`3oool02@3oool002d0oooo00D000000?ooo`3oool0oooo000000080?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0:
0?ooo`00;P3oool3000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?oo
o`<000002@3oool4000000T0oooo00<000000?ooo`3oool00P3oool2000000X0oooo0`00000F0?oo
o`030000003oool0oooo0080oooo0P00000=0?ooo`030000003oool0oooo00H0oooo0P00000@0?oo
o`<000002P3oool00`000000oooo0?ooo`0@0?ooo`800000103oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool02`3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.41744, 99.9928, \
0.0148362, 0.000480088}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499834 0.2727 -435.258 4.35647 [
[.09078 -0.0125 -12 -9 ]
[.09078 -0.0125 12 0 ]
[.22713 -0.0125 -6 -9 ]
[.22713 -0.0125 6 0 ]
[.36348 -0.0125 -12 -9 ]
[.36348 -0.0125 12 0 ]
[.49983 -0.0125 -3 -9 ]
[.49983 -0.0125 3 0 ]
[.63618 -0.0125 -9 -9 ]
[.63618 -0.0125 9 0 ]
[.77253 -0.0125 -3 -9 ]
[.77253 -0.0125 3 0 ]
[.90888 -0.0125 -9 -9 ]
[.90888 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04049 -30 -4.5 ]
[-0.0125 .04049 0 4.5 ]
[-0.0125 .12761 -30 -4.5 ]
[-0.0125 .12761 0 4.5 ]
[-0.0125 .21474 -30 -4.5 ]
[-0.0125 .21474 0 4.5 ]
[-0.0125 .30187 -30 -4.5 ]
[-0.0125 .30187 0 4.5 ]
[-0.0125 .389 -18 -4.5 ]
[-0.0125 .389 0 4.5 ]
[-0.0125 .47613 -36 -4.5 ]
[-0.0125 .47613 0 4.5 ]
[-0.0125 .56326 -36 -4.5 ]
[-0.0125 .56326 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09078 0 m
.09078 .00625 L
s
[(-1.5)] .09078 -0.0125 0 1 Mshowa
.22713 0 m
.22713 .00625 L
s
[(-1)] .22713 -0.0125 0 1 Mshowa
.36348 0 m
.36348 .00625 L
s
[(-0.5)] .36348 -0.0125 0 1 Mshowa
.49983 0 m
.49983 .00625 L
s
[(0)] .49983 -0.0125 0 1 Mshowa
.63618 0 m
.63618 .00625 L
s
[(0.5)] .63618 -0.0125 0 1 Mshowa
.77253 0 m
.77253 .00625 L
s
[(1)] .77253 -0.0125 0 1 Mshowa
.90888 0 m
.90888 .00625 L
s
[(1.5)] .90888 -0.0125 0 1 Mshowa
.125 Mabswid
.11805 0 m
.11805 .00375 L
s
.14532 0 m
.14532 .00375 L
s
.17259 0 m
.17259 .00375 L
s
.19986 0 m
.19986 .00375 L
s
.2544 0 m
.2544 .00375 L
s
.28167 0 m
.28167 .00375 L
s
.30894 0 m
.30894 .00375 L
s
.33621 0 m
.33621 .00375 L
s
.39075 0 m
.39075 .00375 L
s
.41802 0 m
.41802 .00375 L
s
.44529 0 m
.44529 .00375 L
s
.47256 0 m
.47256 .00375 L
s
.5271 0 m
.5271 .00375 L
s
.55437 0 m
.55437 .00375 L
s
.58164 0 m
.58164 .00375 L
s
.60891 0 m
.60891 .00375 L
s
.66345 0 m
.66345 .00375 L
s
.69072 0 m
.69072 .00375 L
s
.71799 0 m
.71799 .00375 L
s
.74526 0 m
.74526 .00375 L
s
.7998 0 m
.7998 .00375 L
s
.82707 0 m
.82707 .00375 L
s
.85434 0 m
.85434 .00375 L
s
.88161 0 m
.88161 .00375 L
s
.06351 0 m
.06351 .00375 L
s
.03624 0 m
.03624 .00375 L
s
.00897 0 m
.00897 .00375 L
s
.93615 0 m
.93615 .00375 L
s
.96342 0 m
.96342 .00375 L
s
.99069 0 m
.99069 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04049 m
.00625 .04049 L
s
[(99.92)] -0.0125 .04049 1 0 Mshowa
0 .12761 m
.00625 .12761 L
s
[(99.94)] -0.0125 .12761 1 0 Mshowa
0 .21474 m
.00625 .21474 L
s
[(99.96)] -0.0125 .21474 1 0 Mshowa
0 .30187 m
.00625 .30187 L
s
[(99.98)] -0.0125 .30187 1 0 Mshowa
0 .389 m
.00625 .389 L
s
[(100)] -0.0125 .389 1 0 Mshowa
0 .47613 m
.00625 .47613 L
s
[(100.02)] -0.0125 .47613 1 0 Mshowa
0 .56326 m
.00625 .56326 L
s
[(100.04)] -0.0125 .56326 1 0 Mshowa
.125 Mabswid
0 .06227 m
.00375 .06227 L
s
0 .08405 m
.00375 .08405 L
s
0 .10583 m
.00375 .10583 L
s
0 .1494 m
.00375 .1494 L
s
0 .17118 m
.00375 .17118 L
s
0 .19296 m
.00375 .19296 L
s
0 .23653 m
.00375 .23653 L
s
0 .25831 m
.00375 .25831 L
s
0 .28009 m
.00375 .28009 L
s
0 .32366 m
.00375 .32366 L
s
0 .34544 m
.00375 .34544 L
s
0 .36722 m
.00375 .36722 L
s
0 .41078 m
.00375 .41078 L
s
0 .43257 m
.00375 .43257 L
s
0 .45435 m
.00375 .45435 L
s
0 .49791 m
.00375 .49791 L
s
0 .5197 m
.00375 .5197 L
s
0 .54148 m
.00375 .54148 L
s
0 .0187 m
.00375 .0187 L
s
0 .58504 m
.00375 .58504 L
s
0 .60683 m
.00375 .60683 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09078 .61178 m
.09078 .61803 L
s
.22713 .61178 m
.22713 .61803 L
s
.36348 .61178 m
.36348 .61803 L
s
.49983 .61178 m
.49983 .61803 L
s
.63618 .61178 m
.63618 .61803 L
s
.77253 .61178 m
.77253 .61803 L
s
.90888 .61178 m
.90888 .61803 L
s
.125 Mabswid
.11805 .61428 m
.11805 .61803 L
s
.14532 .61428 m
.14532 .61803 L
s
.17259 .61428 m
.17259 .61803 L
s
.19986 .61428 m
.19986 .61803 L
s
.2544 .61428 m
.2544 .61803 L
s
.28167 .61428 m
.28167 .61803 L
s
.30894 .61428 m
.30894 .61803 L
s
.33621 .61428 m
.33621 .61803 L
s
.39075 .61428 m
.39075 .61803 L
s
.41802 .61428 m
.41802 .61803 L
s
.44529 .61428 m
.44529 .61803 L
s
.47256 .61428 m
.47256 .61803 L
s
.5271 .61428 m
.5271 .61803 L
s
.55437 .61428 m
.55437 .61803 L
s
.58164 .61428 m
.58164 .61803 L
s
.60891 .61428 m
.60891 .61803 L
s
.66345 .61428 m
.66345 .61803 L
s
.69072 .61428 m
.69072 .61803 L
s
.71799 .61428 m
.71799 .61803 L
s
.74526 .61428 m
.74526 .61803 L
s
.7998 .61428 m
.7998 .61803 L
s
.82707 .61428 m
.82707 .61803 L
s
.85434 .61428 m
.85434 .61803 L
s
.88161 .61428 m
.88161 .61803 L
s
.06351 .61428 m
.06351 .61803 L
s
.03624 .61428 m
.03624 .61803 L
s
.00897 .61428 m
.00897 .61803 L
s
.93615 .61428 m
.93615 .61803 L
s
.96342 .61428 m
.96342 .61803 L
s
.99069 .61428 m
.99069 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04049 m
1 .04049 L
s
.99375 .12761 m
1 .12761 L
s
.99375 .21474 m
1 .21474 L
s
.99375 .30187 m
1 .30187 L
s
.99375 .389 m
1 .389 L
s
.99375 .47613 m
1 .47613 L
s
.99375 .56326 m
1 .56326 L
s
.125 Mabswid
.99625 .06227 m
1 .06227 L
s
.99625 .08405 m
1 .08405 L
s
.99625 .10583 m
1 .10583 L
s
.99625 .1494 m
1 .1494 L
s
.99625 .17118 m
1 .17118 L
s
.99625 .19296 m
1 .19296 L
s
.99625 .23653 m
1 .23653 L
s
.99625 .25831 m
1 .25831 L
s
.99625 .28009 m
1 .28009 L
s
.99625 .32366 m
1 .32366 L
s
.99625 .34544 m
1 .34544 L
s
.99625 .36722 m
1 .36722 L
s
.99625 .41078 m
1 .41078 L
s
.99625 .43257 m
1 .43257 L
s
.99625 .45435 m
1 .45435 L
s
.99625 .49791 m
1 .49791 L
s
.99625 .5197 m
1 .5197 L
s
.99625 .54148 m
1 .54148 L
s
.99625 .0187 m
1 .0187 L
s
.99625 .58504 m
1 .58504 L
s
.99625 .60683 m
1 .60683 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.49983 0 m
.49983 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.01 w
.05452 .60332 Mdot
.08522 .59972 Mdot
.11593 .59501 Mdot
.14664 .5892 Mdot
.17735 .58228 Mdot
.20806 .57425 Mdot
.23877 .56513 Mdot
.26948 .55489 Mdot
.30019 .54355 Mdot
.3309 .53111 Mdot
.36161 .51756 Mdot
.39233 .50291 Mdot
.42304 .48715 Mdot
.45376 .47029 Mdot
.48447 .45232 Mdot
.51519 .43325 Mdot
.54591 .41307 Mdot
.57664 .39179 Mdot
.60736 .36941 Mdot
.63808 .34592 Mdot
.66881 .32133 Mdot
.69954 .29563 Mdot
.73027 .26883 Mdot
.761 .24093 Mdot
.79174 .21192 Mdot
.82247 .18181 Mdot
.85321 .1506 Mdot
.88395 .11828 Mdot
.9147 .08486 Mdot
.94544 .05034 Mdot
.5 Mabswid
.02381 .60332 m
.03837 .60332 L
.04579 .60332 L
.04987 .60332 L
.05187 .60332 L
.05275 .60332 L
.05372 .60332 L
.0547 .6033 L
.05524 .60323 L
.05574 .60317 L
.05794 .60292 L
.06178 .60247 L
.06929 .60159 L
.08634 .59955 L
.11636 .59493 L
.14827 .58883 L
.17902 .58184 L
.20858 .5741 L
.24005 .5647 L
.27035 .55457 L
.30254 .5426 L
.33356 .52994 L
.3634 .51671 L
.39515 .50146 L
.42572 .48568 L
.45512 .46949 L
.48641 .45112 L
.51654 .43237 L
.54856 .41124 L
.57941 .38978 L
.60908 .36809 L
.64065 .34386 L
.67105 .31945 L
.70028 .29499 L
.7314 .2678 L
.76136 .24059 L
.79321 .21048 L
.82388 .18038 L
.85339 .15041 L
.88479 .11737 L
.91502 .0845 L
.94714 .04837 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00>03oool3000000@0oooo00<000000?ooo`3oool00P3oool3000001T0oooo0`00000J0?oo
o`800000103oool00`000000oooo0?ooo`020?ooo`<000005P3oool2000001X0oooo0P0000040?oo
o`030000003oool0oooo0080oooo0`00000I0?ooo`<000006@3oool3000000@0oooo00<000000?oo
o`3oool00P3oool300000140oooo000i0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3o
ool0oooo0000000I0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool000001`3oool0
1@000000oooo0?ooo`3oool0000001@0oooo00@000000?ooo`3oool00000603oool010000000oooo
0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000006@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`00<@3oool50000
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`D000000`3oool00`00
0000oooo0?ooo`0A0?ooo`D000000P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo0180oooo00@000000?ooo`3oool00000603oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00h0oooo000i0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
4P3oool010000000oooo0?ooo`00000H0?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool03P3oool003T0oooo00<000000?ooo`3oool01`3oool4000001X0oooo00<000000?ooo`3o
ool0603oool010000000oooo0?ooo`0000070?ooo`@000005@3oool010000000oooo0?ooo`00000H
0?ooo`040000003oool0oooo000000L0oooo1000000J0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01`3oool400000140oooo000h0?ooo`8000002@3oool00`000000oooo0?ooo`0J
0?ooo`8000006P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo01H0oooo00@0
00000?ooo`3oool00000603oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo01X0
oooo0P00000J0?ooo`8000002@3oool00`000000oooo0?ooo`0B0?ooo`00>@3oool00`000000oooo
0?ooo`070?ooo`D000006@3oool00`000000oooo0?ooo`0I0?ooo`800000203oool5000001D0oooo
0P00000J0?ooo`800000203oool5000001T0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`070?ooo`D00000403oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool002L0oooon00000010?ooo`009`3oool00`000000oooo000000060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo000000010?ooo`009`3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`009`3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00`3oool10000
0040oooo000W0?ooo`800000N@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080
oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool0103oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000L0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`8000000`3oool5000000@0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00H0oooo0@000001
0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`002P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`07
0?ooo`4000000@3oool000L0oooo100000020?ooo`@00000203oool4000000@0oooo00<000000?oo
o`3oool00`3oool2000007T0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`070?oo
o`8000000@3oool000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool01@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0K@3oool00`000000oooo
0?ooo`090?ooo`4000000@3oool000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00<000000?ooo`3oool01@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0J`3oool2
000000`0oooo0@0000010?ooo`001`3oool3000000<0oooo0`0000090?ooo`<000000`3oool30000
00D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1[0?ooo`800000303oool10000
0040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`0;0?ooo`4000000@3oool002L0oooo0P00001i0?ooo`030000003oool0oooo06X0oooo
00<000000?ooo`3oool02`3oool200000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0J@3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool002L0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00h0oooo0@000001
0?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool03`3oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`0@0?ooo`4000000@3oool002L0oooo0P00001i0?ooo`030000
003oool0oooo06<0oooo0`00000B0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`1S0?ooo`800000503oool100000040oooo000W0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0B0?ooo`4000000@3oool0
02L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
01<0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool0503oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0E0?ooo`4000000@3oool002L0oooo0P00
001i0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool05@3oool200000040oooo000W
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0G
0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo01P0oooo0@0000010?ooo`001`3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo0P0000050?ooo`<00000103oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo05`0oooo0P00000K0?ooo`4000000@3oool000T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo05`0oooo0P00000K0?ooo`400000
0@3oool000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0000000@00000103oool2000007T0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`0J0?ooo`8000000@3oool000L0oooo100000020?ooo`@00000203oool4000000050?ooo`000000
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0703oool100000040oooo00060?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo01d0oooo0@0000010?ooo`001P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000`3oool2
000000D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01h0oooo0@0000010?ooo`001`3oool3000000<0oooo0`0000090?ooo`<000001@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0O0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0200oooo0@0000010?ooo`009`3oool2000007T0oooo
00<000000?ooo`3oool0E03oool200000280oooo0P0000010?ooo`009`3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo05@0oooo0P00000S0?ooo`4000000@3oool002L0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo02<0oooo0@000001
0?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool0903oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`0U0?ooo`4000000@3oool002L0oooo0P00001i0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool09@3oool200000040oooo000W0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0W0?ooo`4000000@3o
ool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1=0?ooo`800000:P3oool1
00000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0C@3oool20000
02X0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0:P3oool100000040oooo000W0?ooo`800000N@3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo02X0oooo0P0000010?ooo`009`3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0;03oool100000040oooo000W
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0]
0?ooo`4000000@3oool000L0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`800000103oool3000000D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo02h0oooo0@0000010?ooo`002@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0_0?oo
o`4000000@3oool000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo04D0oooo0P00000b0?ooo`4000000@3oool000L0oooo100000020?ooo`@00000
203oool4000000030?ooo`0000000000008000001@3oool2000007T0oooo00<000000?ooo`3oool0
A03oool300000340oooo0P0000010?ooo`001P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`050?ooo`070000003oool0oooo0?ooo`000000oooo00000008
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0c
0?ooo`4000000@3oool000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
=03oool100000040oooo00070?ooo`<000000`3oool3000000T0oooo0`0000040?ooo`8000001@3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=@3o
ool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0f0?ooo`4000000@3oool002L0oooo0P00001i0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0=P3oool200000040oooo000W0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool0?@3oool2000003X0oooo0@0000010?ooo`009`3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo03d0oooo0P00000j0?ooo`4000000@3oool002L0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03X0oooo0@00
00010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0>`3oool100000040oooo000W0?ooo`800000N@3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo03/0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0?@3oool100000040oooo000W0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0n0?ooo`400000
0@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0f0?ooo`800000@@3o
ool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0=@3oool3
00000440oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0@P3oool100000040oooo000W0?ooo`800000N@3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo0480oooo0P0000010?ooo`009`3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0A03oool100000040oooo
000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`150?ooo`4000000@3oool000L0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`800000103oool3000000D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0^
0?ooo`<00000B03oool100000040oooo00090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0^0?ooo`800000B@3oool100000040oooo000:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000030?oo
o`030000003oool0oooo0080oooo0P00001i0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0B03oool200000040oooo00070?ooo`@000000P3oool4000000P0oooo100000020?ooo`<0
00001@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0BP3oool100000040oooo00060?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`030000003oool0oooo00D0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0B`3oool100000040oooo00060?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`030000003oool0oooo00D0oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0C03oool100000040oooo00070?ooo`<000000`3oool3000000T0
oooo0`0000030?ooo`<000001@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0C@3oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool09`3oool200000500oooo0@0000010?ooo`009`3oool2000007T0oooo00<0
00000?ooo`3oool09P3oool3000004l0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0D@3oool100000040oooo000W0?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool08`3oool2000005@0oooo0@0000010?oo
o`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0E03oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`1E0?ooo`4000000@3oool002L0oooo0P00001i0?ooo`030000003o
ool0oooo01l0oooo0P00001G0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`0N0?ooo`<00000F03oool100000040oooo000W0?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1I0?ooo`4000000@3oool002L0
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0K0?ooo`800000G03oool100000040
oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1L0?ooo`4000000@3oool002L0oooo0P00001i0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0G03oool200000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool05`3oool200000600oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo01H0oooo0`00001P0?ooo`4000000@3oool001<0oooo0`0000040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0D0?ooo`80
0000H`3oool100000040oooo000D0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1S0?ooo`4000000@3oool001@0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06@0oooo0@000001
0?ooo`00503oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool2000007T0oooo00<000000?ooo`3oool0403oool2000006H0oooo0P00
00010?ooo`00503oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00l0oooo
0`00001W0?ooo`4000000@3oool001<0oooo0P0000040?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00d0
oooo0P00001Z0?ooo`4000000@3oool001@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool02`3oool2000006`0oooo
0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0K03oool100000040oooo000W0?ooo`800000N@3oool00`000000oooo0?ooo`08
0?ooo`800000KP3oool200000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool01`3oool3000006l0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0L03oool100000040oooo000W0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`400000
0@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0780oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`040000003oool0
oooo0?ooo`<00000M@3oool100000040oooo000W0?ooo`800000N@3oool010000000oooo0?ooo`3o
ool2000007D0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`040000003oool0
0000000007P0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`800000NP3oool1
00000040oooo000W0?ooo`030000003oool0oooo07H0oooo0`00001k0?ooo`4000000@3oool002L0
oooo00<000000?ooo`3oool0M03oool200000080oooo00<000000?ooo`3oool0N@3oool100000040
oooo000W0?ooo`800000M03oool300000080oooo00<000000?ooo`3oool0N03oool200000040oooo
000W0?ooo`030000003oool0oooo0740oooo0P0000050?ooo`030000003oool0oooo07T0oooo0@00
00010?ooo`009`3oool00`000000oooo0?ooo`1_0?ooo`8000001`3oool00`000000oooo0?ooo`1i
0?ooo`4000000@3oool000040?ooo`0000000000000000@0oooo0P0000040?ooo`800000103oool0
0`000000oooo0?ooo`030?ooo`8000000P3oool5000000@0oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`000P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0K03oool2000000X0oooo00<000000?ooo`3oool0N@3oool100000040oooo00020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool2000006/0oooo1000000:
0?ooo`030000003oool0oooo07P0oooo0P0000010?ooo`000P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0J@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`000P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000203oool01P000000
oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1W
0?ooo`8000003`3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool000030?ooo`0000000000
00@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06D0
oooo0P00000A0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`000P3oool00`000000oooo
0?ooo`030?ooo`800000103oool2000000X0oooo0P0000030?ooo`<000001@3oool00`000000oooo
0?ooo`1S0?ooo`@000004@3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07T0oooo0@00
00010?ooo`009`3oool200000640oooo0P00000F0?ooo`030000003oool0oooo07P0oooo0P000001
0?ooo`009`3oool00`000000oooo0?ooo`1M0?ooo`<00000603oool00`000000oooo0?ooo`1i0?oo
o`4000000@3oool002L0oooo00<000000?ooo`3oool0F`3oool4000001T0oooo00<000000?ooo`3o
ool0N@3oool100000040oooo000W0?ooo`030000003oool0oooo05P0oooo0`00000M0?ooo`030000
003oool0oooo07T0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1F0?ooo`800000803o
ool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo0P00001E0?ooo`@00000803oool0
0`000000oooo0?ooo`1h0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0DP3oool20000
02@0oooo00<000000?ooo`3oool0N@3oool100000040oooo000W0?ooo`030000003oool0oooo0500
oooo0P00000V0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`009`3oool00`000000oooo
0?ooo`1>0?ooo`800000:03oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo00<0
00000?ooo`3oool0B`3oool5000002P0oooo00<000000?ooo`3oool0N@3oool100000040oooo000W
0?ooo`800000BP3oool2000002d0oooo00<000000?ooo`3oool0N03oool200000040oooo000W0?oo
o`030000003oool0oooo04H0oooo0`00000_0?ooo`030000003oool0oooo07T0oooo0@0000010?oo
o`009`3oool00`000000oooo0?ooo`140?ooo`@00000<03oool00`000000oooo0?ooo`1i0?ooo`40
00000@3oool000040?ooo`0000000000000000@0oooo0P0000040?ooo`800000103oool00`000000
oooo0?ooo`030?ooo`800000103oool3000000@0oooo00<000000?ooo`3oool0?`3oool5000003@0
oooo00<000000?ooo`3oool0N@3oool100000040oooo00020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0n0?ooo`<00000=`3oool0
0`000000oooo0?ooo`1i0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3oool00000
0?ooo`05000000@0oooo00<000000?ooo`3oool0>P3oool4000003X0oooo00<000000?ooo`3oool0
N@3oool100000040oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool000000P3oool0
0`000000oooo0?ooo`030?ooo`800000>03oool3000003h0oooo00<000000?ooo`3oool0N03oool2
00000040oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`0d0?ooo`D00000?`3oool00`000000oooo0?ooo`1i0?ooo`400000
0@3oool000030?ooo`000000000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P0000050?ooo`030000003oool0oooo
0300oooo100000140?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`000P3oool00`000000
oooo0?ooo`030?ooo`800000103oool2000000X0oooo0P0000050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0;@3oool5000004H0oooo00<000000?ooo`3oool0N@3oool100000040
oooo000W0?ooo`030000003oool0oooo02L0oooo1P00001;0?ooo`030000003oool0oooo07T0oooo
0@0000010?ooo`009`3oool2000002D0oooo0`0000000`3oool000000000001>0?ooo`030000003o
ool0oooo07P0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`0P0?ooo`@00000E03oool0
0`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool06@3oool20000
00030?ooo`000000000000@00000EP3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0
oooo00<000000?ooo`3oool05P3oool6000005`0oooo00<000000?ooo`3oool0N@3oool100000040
oooo000W0?ooo`030000003oool0oooo00X0oooo0P0000000`3oool000000000000700000680oooo
00<000000?ooo`3oool0N@3oool100000040oooo000W0?ooo`030000003oool0oooo00<0oooo2P00
00040?ooo`800000I@3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo0P00001i
0?ooo`030000003oool0oooo07P0oooo0P0000010?ooo`009`3oool00`000000oooo000000060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo000000010?oo
o`009`3ooooh00000040oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003E0?oo
o`<00000B03oool00=H0oooo00<000000?ooo`3oool0A`3oool006X0oooo00<000000?ooo`000000
0`3oool4000000<0oooo00<000000?ooo`3oool00P3oool300000080oooo0`0000030?ooo`<00000
103oool300000080oooo0`0000000`3oool00000000000020?ooo`800000203oool5000000050?oo
o`00000000000000003oool00P0000020?ooo`8000000`3oool300000080oooo0`0000000`3oool0
00000000000400000080oooo1@0000030?ooo`800000103oool00`000000oooo0?ooo`160?ooo`00
JP3oool00`000000oooo000000020?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01P000000
oooo0?ooo`000000oooo000000H0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`160?ooo`00
JP3oool00`000000oooo000000030?ooo`<000000`3oool00`000000oooo000000020?ooo`D00000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool5
00000080oooo00@000000?ooo`3oool000000P3oool3000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000004L0oooo001Y0?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000P3oool3000000<0oooo0P0000030?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0000003oool000001`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000A`3o
ool006T0oooo00D000000?ooo`000000oooo000000020?ooo`8000000`3oool2000000030?ooo`00
000000000080oooo0`0000030?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000000
00020?ooo`<000000P3oool400000080oooo1000000:0?ooo`040000003oool0oooo0?ooo`@00000
0P3oool4000000<0oooo0`0000020?ooo`@000000`3oool4000000040?ooo`0000000000000000<0
oooo100000020?ooo`80000000<0oooo000000000000AP3oool006T0oooo00D000000?ooo`000000
oooo0000000D0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0C@3oool006T0
oooo1P00000B0?ooo`D00000503oool00`000000oooo0?ooo`080?ooo`D00000203oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.41744, 99.8995, \
0.0148362, 0.000928698}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499834 0.2727 0.309017 0.00448332 [
[.09078 -0.0125 -12 -9 ]
[.09078 -0.0125 12 0 ]
[.22713 -0.0125 -6 -9 ]
[.22713 -0.0125 6 0 ]
[.36348 -0.0125 -12 -9 ]
[.36348 -0.0125 12 0 ]
[.49983 -0.0125 -3 -9 ]
[.49983 -0.0125 3 0 ]
[.63618 -0.0125 -9 -9 ]
[.63618 -0.0125 9 0 ]
[.77253 -0.0125 -3 -9 ]
[.77253 -0.0125 3 0 ]
[.90888 -0.0125 -9 -9 ]
[.90888 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04002 -18 -4.5 ]
[-0.0125 .04002 0 4.5 ]
[-0.0125 .12968 -18 -4.5 ]
[-0.0125 .12968 0 4.5 ]
[-0.0125 .21935 -18 -4.5 ]
[-0.0125 .21935 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .39868 -12 -4.5 ]
[-0.0125 .39868 0 4.5 ]
[-0.0125 .48835 -12 -4.5 ]
[-0.0125 .48835 0 4.5 ]
[-0.0125 .57802 -12 -4.5 ]
[-0.0125 .57802 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09078 0 m
.09078 .00625 L
s
[(-1.5)] .09078 -0.0125 0 1 Mshowa
.22713 0 m
.22713 .00625 L
s
[(-1)] .22713 -0.0125 0 1 Mshowa
.36348 0 m
.36348 .00625 L
s
[(-0.5)] .36348 -0.0125 0 1 Mshowa
.49983 0 m
.49983 .00625 L
s
[(0)] .49983 -0.0125 0 1 Mshowa
.63618 0 m
.63618 .00625 L
s
[(0.5)] .63618 -0.0125 0 1 Mshowa
.77253 0 m
.77253 .00625 L
s
[(1)] .77253 -0.0125 0 1 Mshowa
.90888 0 m
.90888 .00625 L
s
[(1.5)] .90888 -0.0125 0 1 Mshowa
.125 Mabswid
.11805 0 m
.11805 .00375 L
s
.14532 0 m
.14532 .00375 L
s
.17259 0 m
.17259 .00375 L
s
.19986 0 m
.19986 .00375 L
s
.2544 0 m
.2544 .00375 L
s
.28167 0 m
.28167 .00375 L
s
.30894 0 m
.30894 .00375 L
s
.33621 0 m
.33621 .00375 L
s
.39075 0 m
.39075 .00375 L
s
.41802 0 m
.41802 .00375 L
s
.44529 0 m
.44529 .00375 L
s
.47256 0 m
.47256 .00375 L
s
.5271 0 m
.5271 .00375 L
s
.55437 0 m
.55437 .00375 L
s
.58164 0 m
.58164 .00375 L
s
.60891 0 m
.60891 .00375 L
s
.66345 0 m
.66345 .00375 L
s
.69072 0 m
.69072 .00375 L
s
.71799 0 m
.71799 .00375 L
s
.74526 0 m
.74526 .00375 L
s
.7998 0 m
.7998 .00375 L
s
.82707 0 m
.82707 .00375 L
s
.85434 0 m
.85434 .00375 L
s
.88161 0 m
.88161 .00375 L
s
.06351 0 m
.06351 .00375 L
s
.03624 0 m
.03624 .00375 L
s
.00897 0 m
.00897 .00375 L
s
.93615 0 m
.93615 .00375 L
s
.96342 0 m
.96342 .00375 L
s
.99069 0 m
.99069 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04002 m
.00625 .04002 L
s
[(-60)] -0.0125 .04002 1 0 Mshowa
0 .12968 m
.00625 .12968 L
s
[(-40)] -0.0125 .12968 1 0 Mshowa
0 .21935 m
.00625 .21935 L
s
[(-20)] -0.0125 .21935 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .39868 m
.00625 .39868 L
s
[(20)] -0.0125 .39868 1 0 Mshowa
0 .48835 m
.00625 .48835 L
s
[(40)] -0.0125 .48835 1 0 Mshowa
0 .57802 m
.00625 .57802 L
s
[(60)] -0.0125 .57802 1 0 Mshowa
.125 Mabswid
0 .06243 m
.00375 .06243 L
s
0 .08485 m
.00375 .08485 L
s
0 .10727 m
.00375 .10727 L
s
0 .1521 m
.00375 .1521 L
s
0 .17452 m
.00375 .17452 L
s
0 .19693 m
.00375 .19693 L
s
0 .24177 m
.00375 .24177 L
s
0 .26418 m
.00375 .26418 L
s
0 .2866 m
.00375 .2866 L
s
0 .33143 m
.00375 .33143 L
s
0 .35385 m
.00375 .35385 L
s
0 .37627 m
.00375 .37627 L
s
0 .4211 m
.00375 .4211 L
s
0 .44352 m
.00375 .44352 L
s
0 .46593 m
.00375 .46593 L
s
0 .51077 m
.00375 .51077 L
s
0 .53318 m
.00375 .53318 L
s
0 .5556 m
.00375 .5556 L
s
0 .0176 m
.00375 .0176 L
s
0 .60043 m
.00375 .60043 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09078 .61178 m
.09078 .61803 L
s
.22713 .61178 m
.22713 .61803 L
s
.36348 .61178 m
.36348 .61803 L
s
.49983 .61178 m
.49983 .61803 L
s
.63618 .61178 m
.63618 .61803 L
s
.77253 .61178 m
.77253 .61803 L
s
.90888 .61178 m
.90888 .61803 L
s
.125 Mabswid
.11805 .61428 m
.11805 .61803 L
s
.14532 .61428 m
.14532 .61803 L
s
.17259 .61428 m
.17259 .61803 L
s
.19986 .61428 m
.19986 .61803 L
s
.2544 .61428 m
.2544 .61803 L
s
.28167 .61428 m
.28167 .61803 L
s
.30894 .61428 m
.30894 .61803 L
s
.33621 .61428 m
.33621 .61803 L
s
.39075 .61428 m
.39075 .61803 L
s
.41802 .61428 m
.41802 .61803 L
s
.44529 .61428 m
.44529 .61803 L
s
.47256 .61428 m
.47256 .61803 L
s
.5271 .61428 m
.5271 .61803 L
s
.55437 .61428 m
.55437 .61803 L
s
.58164 .61428 m
.58164 .61803 L
s
.60891 .61428 m
.60891 .61803 L
s
.66345 .61428 m
.66345 .61803 L
s
.69072 .61428 m
.69072 .61803 L
s
.71799 .61428 m
.71799 .61803 L
s
.74526 .61428 m
.74526 .61803 L
s
.7998 .61428 m
.7998 .61803 L
s
.82707 .61428 m
.82707 .61803 L
s
.85434 .61428 m
.85434 .61803 L
s
.88161 .61428 m
.88161 .61803 L
s
.06351 .61428 m
.06351 .61803 L
s
.03624 .61428 m
.03624 .61803 L
s
.00897 .61428 m
.00897 .61803 L
s
.93615 .61428 m
.93615 .61803 L
s
.96342 .61428 m
.96342 .61803 L
s
.99069 .61428 m
.99069 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04002 m
1 .04002 L
s
.99375 .12968 m
1 .12968 L
s
.99375 .21935 m
1 .21935 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .39868 m
1 .39868 L
s
.99375 .48835 m
1 .48835 L
s
.99375 .57802 m
1 .57802 L
s
.125 Mabswid
.99625 .06243 m
1 .06243 L
s
.99625 .08485 m
1 .08485 L
s
.99625 .10727 m
1 .10727 L
s
.99625 .1521 m
1 .1521 L
s
.99625 .17452 m
1 .17452 L
s
.99625 .19693 m
1 .19693 L
s
.99625 .24177 m
1 .24177 L
s
.99625 .26418 m
1 .26418 L
s
.99625 .2866 m
1 .2866 L
s
.99625 .33143 m
1 .33143 L
s
.99625 .35385 m
1 .35385 L
s
.99625 .37627 m
1 .37627 L
s
.99625 .4211 m
1 .4211 L
s
.99625 .44352 m
1 .44352 L
s
.99625 .46593 m
1 .46593 L
s
.99625 .51077 m
1 .51077 L
s
.99625 .53318 m
1 .53318 L
s
.99625 .5556 m
1 .5556 L
s
.99625 .0176 m
1 .0176 L
s
.99625 .60043 m
1 .60043 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.49983 0 m
.49983 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.05452 .01766 Mdot
.08522 .02168 Mdot
.11593 .02677 Mdot
.14664 .03292 Mdot
.17735 .04014 Mdot
.20806 .04843 Mdot
.23877 .05779 Mdot
.26948 .06822 Mdot
.30019 .07972 Mdot
.3309 .09229 Mdot
.36161 .10592 Mdot
.39233 .12063 Mdot
.42304 .1364 Mdot
.45376 .15325 Mdot
.48447 .17116 Mdot
.51519 .19014 Mdot
.54591 .21019 Mdot
.57664 .23132 Mdot
.60736 .25351 Mdot
.63808 .27677 Mdot
.66881 .3011 Mdot
.69954 .3265 Mdot
.73027 .35298 Mdot
.761 .38052 Mdot
.79174 .40913 Mdot
.82247 .43882 Mdot
.85321 .46958 Mdot
.88395 .5014 Mdot
.9147 .5343 Mdot
.94544 .56828 Mdot
.5 Mabswid
.02381 .01472 m
.05372 .01759 L
.08634 .02187 L
.11698 .02698 L
.14644 .03288 L
.1778 .04027 L
.20799 .04842 L
.24008 .05824 L
.27099 .06879 L
.30073 .07994 L
.33237 .09294 L
.36283 .10651 L
.39213 .12053 L
.42332 .13655 L
.45333 .15301 L
.48525 .17164 L
.51599 .19066 L
.54556 .20996 L
.57703 .2316 L
.60732 .25348 L
.63951 .2779 L
.67053 .30253 L
.70038 .32723 L
.73212 .35464 L
.76269 .3821 L
.79209 .40948 L
.82339 .43974 L
.85351 .46989 L
.88553 .50309 L
.91638 .53616 L
.94605 .56897 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00;`3oool3000000@0oooo00<000000?ooo`3oool00P3oool3000001T0oooo0`00000J0?oo
o`800000103oool00`000000oooo0?ooo`020?ooo`<000005P3oool2000001X0oooo0P0000040?oo
o`030000003oool0oooo0080oooo0`00000I0?ooo`<000006@3oool3000000@0oooo00<000000?oo
o`3oool00P3oool3000001X0oooo000`0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3o
ool0oooo0000000I0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool000001`3oool0
1@000000oooo0?ooo`3oool0000001@0oooo00@000000?ooo`3oool00000603oool010000000oooo
0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000006@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`00:03oool50000
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`D000000`3oool00`00
0000oooo0?ooo`0A0?ooo`D000000P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo0180oooo00@000000?ooo`3oool00000603oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01L0oooo000`0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
4P3oool010000000oooo0?ooo`00000H0?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool05`3oool00300oooo00<000000?ooo`3oool01`3oool4000001X0oooo00<000000?ooo`3o
ool0603oool010000000oooo0?ooo`0000070?ooo`@000005@3oool010000000oooo0?ooo`00000H
0?ooo`040000003oool0oooo000000L0oooo1000000J0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01`3oool4000001X0oooo000_0?ooo`8000002@3oool00`000000oooo0?ooo`0J
0?ooo`8000006P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo01H0oooo00@0
00000?ooo`3oool00000603oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo01X0
oooo0P00000J0?ooo`8000002@3oool00`000000oooo0?ooo`0K0?ooo`00<03oool00`000000oooo
0?ooo`070?ooo`D000006@3oool00`000000oooo0?ooo`0I0?ooo`800000203oool5000001D0oooo
0P00000J0?ooo`800000203oool5000001T0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`070?ooo`D000006@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool001h0oooon000000:0?ooo`007P3oool00`000000oooo000000060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000:0?ooo`007P3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool0
01h0oooo00<000000?ooo`3oool00`3oool500000700oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`080?ooo`007P3oool2000000T0oooo1`00001Y0?ooo`030000003oool0oooo07P0
oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`0:0?ooo`8000000`3oool800000640oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?oo
o`0A0?ooo`800000103oool6000005/0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`080?ooo`00403oool3000000@0oooo0P0000050?ooo`030000003oool0oooo01T0oooo0P000002
0?ooo`D00000EP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00P0oooo000?0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0200oooo1000001D0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203o
ool000T0oooo1@0000000`3oool000000?ooo`020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`H00000CP3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo00P0oooo000?0?ooo`@000000`3oool010000000oooo0?ooo`00
00040?ooo`800000:@3oool4000004`0oooo00<000000?ooo`3oool0N03oool2000000X0oooo000?
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0/0?ooo`<0000000<0oooo000000000000AP3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00P0oooo000@0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0_0?ooo`@00000A@3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00P0oooo000A0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0<`3oool4
00000440oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`0g0?ooo`<00000?P3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
00P0oooo000N0?ooo`800000>03oool2000000040?ooo`0000000000000003/0oooo00<000000?oo
o`3oool0N03oool2000000X0oooo000N0?ooo`030000003oool0oooo03d0oooo1000000g0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
?`3oool4000003D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`130?ooo`<00000<P3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00P0oooo000N0?ooo`030000003oool0oooo04H0oooo0`00000_0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0AP3oool20000
00030?ooo`000000000002d0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?oo
o`007P3oool2000004`0oooo0P00000[0?ooo`030000003oool0oooo07P0oooo0P00000:0?ooo`00
7P3oool00`000000oooo0?ooo`1=0?ooo`<00000:03oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo04h0oooo0`00000W0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0D@3oool3
000002@0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`1D0?ooo`<000008@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
00P0oooo000N0?ooo`800000E`3oool3000001l0oooo00<000000?ooo`3oool0N03oool2000000X0
oooo000N0?ooo`030000003oool0oooo05H0oooo0P000000103oool0000000000000000L0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
G03oool2000001X0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`004@3o
ool3000000<0oooo0P0000050?ooo`030000003oool0oooo05d0oooo0`00000H0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0203oool00180oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0G@3oool2000000030?ooo`00
0000000001H0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`002@3oool5
000000030?ooo`000000000000<000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0680oooo0P00000D0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203o
ool000l0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000040?ooo`800000
I@3oool200000180oooo00<000000?ooo`3oool0N03oool2000000X0oooo000@0?ooo`030000003o
ool0000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1U0?ooo`<00000
403oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00P0oooo000A0?ooo`8000000`3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06D0oooo0P0000000`3oool00000
0000000>0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool00180oooo00<0
00000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<00000
0?ooo`3oool0J`3oool2000000/0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`08
0?ooo`007P3oool2000006d0oooo0`0000090?ooo`030000003oool0oooo07P0oooo0P00000:0?oo
o`007P3oool00`000000oooo0?ooo`1/0?ooo`80000000<0oooo0000003oool01`3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo0700oooo
0P0000060?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<0
00000?ooo`3oool0LP3oool2000000@0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`080?ooo`007P3oool00`000000oooo0?ooo`1d0?ooo`050000003oool0oooo0?ooo`000000N`3o
ool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1d0?ooo`<0000000<0oooo
0000003oool0NP3oool00`000000oooo0?ooo`080?ooo`007P3oool2000007D0oooo0P0000000`3o
ool000000000001j0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0N03oool2000007X0
oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0N03oool00`000000oooo
0000001i0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool00`00001f0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo07P0oooo00@000000?ooo`3oool0oooo0P00001f0?ooo`030000003oool0oooo00P0oooo000N
0?ooo`800000N@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0780oooo0P00000:
0?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00@0oooo0P00001c0?oo
o`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool01P3oool200000740oooo00<000000?ooo`3oool0203oool000l0oooo1@0000030?ooo`800000
1@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00P0oooo0P00001_0?ooo`030000
003oool0oooo00P0oooo000@0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00P0oooo0`00001^0?ooo`03
0000003oool0oooo00P0oooo00090?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo06/0oooo00<000000?ooo`3oool0203oool00180oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo0P00001i0?ooo`030000003oool0oooo00`0
oooo0P00001Z0?ooo`8000002P3oool000l0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0>0?oo
o`800000J@3oool00`000000oooo0?ooo`080?ooo`003`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`080?ooo`00403oool30000
00@0oooo0P0000050?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0403oool30000
06H0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`0@0?ooo`80000000<0oooo0000003oool0I03oool00`000000oooo0?ooo`080?ooo`00
7P3oool2000007T0oooo00<000000?ooo`3oool0503oool200000680oooo0P00000:0?ooo`007P3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo01L0oooo0`00001O0?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool05`3oool200000003
0?ooo`000000oooo05d0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
203oool001h0oooo0P00001i0?ooo`030000003oool0oooo01`0oooo0P00001J0?ooo`8000002P3o
ool001h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0203oool001h0
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0O0?ooo`<00000E`3oool00`000000
oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01l0oooo
0P0000000`3oool000000?ooo`1E0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000N@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0580oooo0P00000:0?ooo`007P3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02@0oooo0P00001C0?ooo`030000003oool0
oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00P0
oooo000G0?ooo`8000001@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02L0oooo
0P00001@0?ooo`030000003oool0oooo00P0oooo000F0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0W0?ooo`<00000C`3oool00`000000oooo
0?ooo`080?ooo`005P3oool010000000oooo0?ooo`0000040?ooooP000002P3oool001H0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`005P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo00P0oooo000F0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0203oool001L0oooo0P0000050?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0;P3oool2000004T0oooo00<000000?ooo`3oool0203oool001h0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0^0?ooo`<00000B03oool00`000000oooo0?ooo`08
0?ooo`007P3oool2000007T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`140?oo
o`8000002P3oool001h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0c0?ooo`800000A03oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`080?ooo`007P3oool20000
07T0oooo00<000000?ooo`3oool0=P3oool200000400oooo0P00000:0?ooo`007P3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo03H0oooo0`0000100?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00P0oooo000N
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00P0oooo000N0?ooo`80
0000N@3oool00`000000oooo0?ooo`0m0?ooo`800000>@3oool2000000X0oooo000N0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool0?@3oool3000003T0oooo00<000000?ooo`3oool0
203oool001h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0203oool000l0oooo1@0000030?ooo`8000001@3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`080?ooo`00403oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0203oool00140oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`800000N@3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo0380oooo0P00000:0?ooo`004P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`080?ooo`003`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo04D0oooo0P00000b0?ooo`030000003oool0oooo00P0oooo000?0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool0A@3oool200000380oooo00<000000?ooo`3oool0203oool00100oooo
0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`080?ooo`007P3oool2000007T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0/
0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`1=0?ooo`800000:P3oool00`000000oooo0?ooo`080?ooo`007P3oool2
000007T0oooo00<000000?ooo`3oool0C@3oool2000002T0oooo0P00000:0?ooo`007P3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`08
0?ooo`007P3oool2000007T0oooo00<000000?ooo`3oool0E03oool200000280oooo0P00000:0?oo
o`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo05@0oooo0P00000S0?ooo`03
0000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00P0oooo000A0?ooo`<000000`3o
ool2000000D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0203oool00180oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool000l0oooo1@000002
0?ooo`040000003oool0oooo000000@0oooo0P00001i0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool0703oool2000000X0oooo000?0?ooo`040000003oool0oooo000000<0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`00403oool00`000000oooo0000
00030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0203oool00140oooo0P00
00030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`1L0?ooo`8000006`3oool00`000000oooo0?ooo`080?ooo`004P3oool00`000000oooo0?oo
o`020?ooo`8000001@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo05`0oooo0P00
000K0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo000N0?oo
o`800000N@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01L0oooo0P00000:0?oo
o`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`007P3oool20000
07T0oooo00<000000?ooo`3oool0H`3oool2000001<0oooo0P00000:0?ooo`007P3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo06<0oooo0P00000D0?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo000N
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool0J03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo000N0?ooo`80
0000N@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00`0oooo0P00000:0?ooo`00
7P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo06/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`00403oool3
000000@0oooo0P0000050?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0J`3oool2
000000`0oooo00<000000?ooo`3oool0203oool000l0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`1[0?ooo`800000303oool00`000000oooo0?ooo`080?ooo`003`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo06d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`003`3o
ool4000000<0oooo00@000000?ooo`3oool00000103oool2000007T0oooo00<000000?ooo`3oool0
KP3oool00`000000oooo0?ooo`070?ooo`8000002P3oool000l0oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo000@0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`004@3o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo000N0?ooo`800000N@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo
00<0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`0000002P3oool001h0oooon000000:0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00<03oool3000008X0oooo00<000000?ooo`3oool0:`3oool3000001D0oooo00<0
00000?ooo`3oool06P3oool00340oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06@3oool002/0oooo0`0000030?oo
o`<00000103oool200000080oooo1@0000020?ooo`<000000`3oool4000000030?ooo`0000000000
00<000001`3oool3000000@0oooo100000030?ooo`8000000P3oool6000000H0oooo100000020?oo
o`D0000000<0oooo0000000000000`0000000`3oool000000000000300000080oooo0`0000020?oo
o`<00000103oool300000080oooo0`000000103oool000000000003oool3000000<0oooo0`000009
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool4000000<0oooo00<00000
0?ooo`3oool00P3oool300000080oooo1@0000020?ooo`<000000P3oool3000000040?ooo`000000
00000?ooo`@000000`3oool200000080oooo2P0000050?ooo`030000003oool0oooo01P0oooo000Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`000000303oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00@0
00000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo000Z0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000060?ooo`<00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`3oool500000080oooo00<000000?ooo`3oool00P3oool500000080
oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`D00000203oool00`000000oooo0?ooo`02
0?ooo`050000003oool000000?ooo`0000000P3oool3000000<0oooo00<000000?ooo`0000000P3o
ool5000000<0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`060000003oool0oooo0000003o
ool000000`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo00000080oooo0`00
00050?ooo`030000003oool0oooo01P0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`<000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0000000<0oooo00@000000?ooo`3oool000001@3oool01P000000oooo0?ooo`000000oooo
000000P0oooo00<000000?ooo`3oool0603oool002X0oooo00H000000?ooo`3oool0oooo0000003o
ool400000080oooo100000020?ooo`<00000103oool3000000<0oooo0P0000050?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`3oool000000P3oool2000000<0oooo100000030?ooo`<00000
2@3oool01@000000oooo0?ooo`000000oooo00<00000103oool400000080oooo100000020?ooo`<0
00000P3oool2000000030?ooo`00000000000080oooo0`0000020?ooo`@000000`3oool3000000<0
oooo0`0000090?ooo`030000003oool0oooo0080oooo1P0000000`3oool00000000000030?ooo`80
000000<0oooo0000000000000P3oool3000000@0oooo00<000000?ooo`3oool00P3oool300000080
oooo100000030?ooo`T000000`3oool3000000<0oooo100000040?ooo`030000003oool0oooo01P0
oooo000Z0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00P0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I
0?ooo`00:`3oool3000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?oo
o`<000002@3oool4000000T0oooo00<000000?ooo`3oool00P3oool2000000X0oooo100000040?oo
o`030000003oool0oooo00@0oooo0P0000040?ooo`800000;P3oool00`000000oooo0?ooo`0H0?oo
o`<000005P3oool00`000000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`0J0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.28391, -79.8366, \
0.0148362, 0.902422}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.190438 -588.413 5.88604 [
[.11912 -0.0125 -6 -9 ]
[.11912 -0.0125 6 0 ]
[.30956 -0.0125 -6 -9 ]
[.30956 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69044 -0.0125 -3 -9 ]
[.69044 -0.0125 3 0 ]
[.88088 -0.0125 -3 -9 ]
[.88088 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07359 -30 -4.5 ]
[-0.0125 .07359 0 4.5 ]
[-0.0125 .19131 -18 -4.5 ]
[-0.0125 .19131 0 4.5 ]
[-0.0125 .30903 -36 -4.5 ]
[-0.0125 .30903 0 4.5 ]
[-0.0125 .42675 -36 -4.5 ]
[-0.0125 .42675 0 4.5 ]
[-0.0125 .54447 -36 -4.5 ]
[-0.0125 .54447 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11912 0 m
.11912 .00625 L
s
[(-2)] .11912 -0.0125 0 1 Mshowa
.30956 0 m
.30956 .00625 L
s
[(-1)] .30956 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69044 0 m
.69044 .00625 L
s
[(1)] .69044 -0.0125 0 1 Mshowa
.88088 0 m
.88088 .00625 L
s
[(2)] .88088 -0.0125 0 1 Mshowa
.125 Mabswid
.15721 0 m
.15721 .00375 L
s
.1953 0 m
.1953 .00375 L
s
.23339 0 m
.23339 .00375 L
s
.27147 0 m
.27147 .00375 L
s
.34765 0 m
.34765 .00375 L
s
.38574 0 m
.38574 .00375 L
s
.42382 0 m
.42382 .00375 L
s
.46191 0 m
.46191 .00375 L
s
.53809 0 m
.53809 .00375 L
s
.57618 0 m
.57618 .00375 L
s
.61426 0 m
.61426 .00375 L
s
.65235 0 m
.65235 .00375 L
s
.72853 0 m
.72853 .00375 L
s
.76661 0 m
.76661 .00375 L
s
.8047 0 m
.8047 .00375 L
s
.84279 0 m
.84279 .00375 L
s
.08104 0 m
.08104 .00375 L
s
.04295 0 m
.04295 .00375 L
s
.00486 0 m
.00486 .00375 L
s
.91896 0 m
.91896 .00375 L
s
.95705 0 m
.95705 .00375 L
s
.99514 0 m
.99514 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07359 m
.00625 .07359 L
s
[(99.98)] -0.0125 .07359 1 0 Mshowa
0 .19131 m
.00625 .19131 L
s
[(100)] -0.0125 .19131 1 0 Mshowa
0 .30903 m
.00625 .30903 L
s
[(100.02)] -0.0125 .30903 1 0 Mshowa
0 .42675 m
.00625 .42675 L
s
[(100.04)] -0.0125 .42675 1 0 Mshowa
0 .54447 m
.00625 .54447 L
s
[(100.06)] -0.0125 .54447 1 0 Mshowa
.125 Mabswid
0 .10302 m
.00375 .10302 L
s
0 .13245 m
.00375 .13245 L
s
0 .16188 m
.00375 .16188 L
s
0 .22074 m
.00375 .22074 L
s
0 .25017 m
.00375 .25017 L
s
0 .2796 m
.00375 .2796 L
s
0 .33846 m
.00375 .33846 L
s
0 .36789 m
.00375 .36789 L
s
0 .39732 m
.00375 .39732 L
s
0 .45618 m
.00375 .45618 L
s
0 .48561 m
.00375 .48561 L
s
0 .51504 m
.00375 .51504 L
s
0 .04416 m
.00375 .04416 L
s
0 .01473 m
.00375 .01473 L
s
0 .5739 m
.00375 .5739 L
s
0 .60333 m
.00375 .60333 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11912 .61178 m
.11912 .61803 L
s
.30956 .61178 m
.30956 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69044 .61178 m
.69044 .61803 L
s
.88088 .61178 m
.88088 .61803 L
s
.125 Mabswid
.15721 .61428 m
.15721 .61803 L
s
.1953 .61428 m
.1953 .61803 L
s
.23339 .61428 m
.23339 .61803 L
s
.27147 .61428 m
.27147 .61803 L
s
.34765 .61428 m
.34765 .61803 L
s
.38574 .61428 m
.38574 .61803 L
s
.42382 .61428 m
.42382 .61803 L
s
.46191 .61428 m
.46191 .61803 L
s
.53809 .61428 m
.53809 .61803 L
s
.57618 .61428 m
.57618 .61803 L
s
.61426 .61428 m
.61426 .61803 L
s
.65235 .61428 m
.65235 .61803 L
s
.72853 .61428 m
.72853 .61803 L
s
.76661 .61428 m
.76661 .61803 L
s
.8047 .61428 m
.8047 .61803 L
s
.84279 .61428 m
.84279 .61803 L
s
.08104 .61428 m
.08104 .61803 L
s
.04295 .61428 m
.04295 .61803 L
s
.00486 .61428 m
.00486 .61803 L
s
.91896 .61428 m
.91896 .61803 L
s
.95705 .61428 m
.95705 .61803 L
s
.99514 .61428 m
.99514 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07359 m
1 .07359 L
s
.99375 .19131 m
1 .19131 L
s
.99375 .30903 m
1 .30903 L
s
.99375 .42675 m
1 .42675 L
s
.99375 .54447 m
1 .54447 L
s
.125 Mabswid
.99625 .10302 m
1 .10302 L
s
.99625 .13245 m
1 .13245 L
s
.99625 .16188 m
1 .16188 L
s
.99625 .22074 m
1 .22074 L
s
.99625 .25017 m
1 .25017 L
s
.99625 .2796 m
1 .2796 L
s
.99625 .33846 m
1 .33846 L
s
.99625 .36789 m
1 .36789 L
s
.99625 .39732 m
1 .39732 L
s
.99625 .45618 m
1 .45618 L
s
.99625 .48561 m
1 .48561 L
s
.99625 .51504 m
1 .51504 L
s
.99625 .04416 m
1 .04416 L
s
.99625 .01473 m
1 .01473 L
s
.99625 .5739 m
1 .5739 L
s
.99625 .60333 m
1 .60333 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .07359 m
1 .07359 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.05453 .58433 Mdot
.08525 .56534 Mdot
.11598 .54636 Mdot
.1467 .52737 Mdot
.17742 .50838 Mdot
.20814 .4894 Mdot
.23886 .47041 Mdot
.26959 .45142 Mdot
.30031 .43243 Mdot
.33103 .41345 Mdot
.36175 .39446 Mdot
.39247 .37547 Mdot
.4232 .35649 Mdot
.45392 .3375 Mdot
.48464 .31851 Mdot
.51536 .29952 Mdot
.54608 .28054 Mdot
.5768 .26155 Mdot
.60753 .24256 Mdot
.63825 .22357 Mdot
.66897 .20459 Mdot
.69969 .1856 Mdot
.73041 .16661 Mdot
.76114 .14763 Mdot
.79186 .12864 Mdot
.82258 .10965 Mdot
.8533 .09066 Mdot
.88402 .07168 Mdot
.91475 .05269 Mdot
.94547 .0337 Mdot
.5 Mabswid
.02381 .60332 m
.05372 .58483 L
.08634 .56467 L
.11698 .54574 L
.14644 .52753 L
.1778 .50815 L
.20799 .48949 L
.24008 .46966 L
.27099 .45055 L
.30073 .43217 L
.33237 .41262 L
.36283 .39379 L
.39213 .37569 L
.42332 .35641 L
.45333 .33786 L
.48525 .31813 L
.51599 .29913 L
.54556 .28086 L
.57703 .26141 L
.60732 .24269 L
.63951 .22279 L
.67053 .20362 L
.70038 .18518 L
.73212 .16556 L
.76269 .14666 L
.79209 .12849 L
.82339 .10915 L
.85351 .09054 L
.88553 .07075 L
.91638 .05168 L
.94605 .03334 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00A03oool5000002/0oooo0`00000Z0?ooo`800000;@3oool3000002/0oooo1@00000M0?oo
o`00A@3oool010000000oooo0?ooo`00000/0?ooo`030000003oool0oooo02P0oooo00@000000?oo
o`3oool00000;@3oool00`000000oooo0?ooo`0[0?ooo`040000003oool0oooo000001d0oooo000n
0?ooo`D000000`3oool00`000000oooo0?ooo`0T0?ooo`D000000`3oool00`000000oooo0?ooo`0X
0?ooo`040000003oool0oooo000002d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0M0?ooo`00A`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02P0oooo00@00000
0?ooo`3oool00000;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01`0oooo0014
0?ooo`050000003oool0oooo0?ooo`000000;03oool00`000000oooo0?ooo`0X0?ooo`040000003o
ool0oooo000002d0oooo00<000000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool0000001d0
oooo00140?ooo`050000003oool0oooo0?ooo`000000:`3oool2000002X0oooo00@000000?ooo`3o
ool00000;03oool2000002`0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`00A@3oool30000
02d0oooo00<000000?ooo`3oool0:@3oool2000002h0oooo00<000000?ooo`3oool0:`3oool30000
01h0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000W0?oo
ooP000000@3oool002L0oooo0P0000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0P0000010?ooo`00
9`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`009`3o
ool2000007T0oooo00<000000?ooo`3oool0LP3oool2000000@0oooo0P0000010?ooo`009`3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool01@3oool1
00000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0K`3oool20000
00P0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo06h0
oooo00<000000?ooo`3oool0203oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`090?ooo`4000000@3oool002L0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`1[0?ooo`800000303oool100000040oooo000W
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0J@3oool4000000`0oooo0@000001
0?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo06L0oooo0P00000@0?oo
o`4000000@3oool002L0oooo0P00001i0?ooo`030000003oool0oooo06D0oooo0P00000A0?ooo`80
00000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1S0?ooo`800000
503oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0HP3o
ool3000001@0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0600oooo0P00000G0?ooo`4000000@3oool000L0oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`020?ooo`800000103oool3000000D0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo01L0oooo0@0000010?ooo`002@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0H0?ooo`4000000@3oool000X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo05`0oooo0P00000K0?ooo`4000000@3oool000L0oooo
100000020?ooo`@00000203oool400000080oooo0`0000050?ooooP000000@3oool000H0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool0F@3oool2000001h0oooo0@0000010?ooo`001P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`1G0?ooo`800000803oool100000040oooo00070?ooo`<00000
0`3oool3000000T0oooo0`0000030?ooo`<000001@3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool0803oool100000040oooo000W0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool0E03oool2000002<0oooo0@0000010?ooo`009`3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo05<0oooo0`00000S0?ooo`4000000@3oool0
02L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1A0?ooo`8000009P3oool10000
0040oooo000W0?ooo`800000N@3oool00`000000oooo0?ooo`1?0?ooo`8000009`3oool200000040
oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0C@3oool2000002X0oooo
0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo04`0oooo0`00
000Z0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1:
0?ooo`800000;@3oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`0]0?ooo`4000000@3oool002L0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`170?ooo`800000<03oool100000040oooo000W0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool0A@3oool200000380oooo0@0000010?ooo`009`3o
ool2000007T0oooo00<000000?ooo`3oool0A03oool300000340oooo0P0000010?ooo`009`3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0480oooo0P00000e0?ooo`4000000@3oool0
02L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`100?ooo`800000=`3oool10000
0040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0g0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`0m0?ooo`800000>P3oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0?03oool3000003X0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo03X0oooo0P00000m0?ooo`4000000@3oool002L0oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03d0oooo0@0000010?oo
o`009`3oool2000007T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0m0?ooo`80
00000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0f0?ooo`800000
@@3oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0=03o
ool400000440oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0380oooo0P0000150?ooo`4000000@3oool001<0oooo0`0000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0`0?ooo`800000A`3oool10000
0040oooo000D0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0;P3oool2
000004T0oooo0@0000010?ooo`00503oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo02d0oooo0`0000190?ooo`4000000@3oool001@0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0P00001i0?ooo`030000
003oool0oooo02/0oooo0P00001;0?ooo`8000000@3oool001@0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04`0oooo0@0000010?ooo`00
4`3oool2000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1=0?oo
o`4000000@3oool001@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool09`3oool200000500oooo0@0000010?ooo`00
9`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02H0oooo0`00001@0?ooo`400000
0@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0T0?ooo`800000D`3o
ool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool08P3oool2
000005D0oooo0@0000010?ooo`009`3oool2000007T0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`1D0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`0O0?ooo`800000F03oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool07P3oool3000005P0oooo0@0000010?ooo`009`3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo01`0oooo0P00001K0?ooo`4000000@3oool002L0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0J0?ooo`800000G@3oool100000040oooo000W0?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool05`3oool3000005l0oooo0@0000010?oo
o`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01L0oooo0P00001P0?ooo`40
00000@3oool002L0oooo0P00001i0?ooo`030000003oool0oooo01D0oooo0P00001Q0?ooo`800000
0@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0680oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0180oooo0P00001U0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`0@0?ooo`800000I`3oool100000040oooo000W0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool03`3oool3000006L0oooo0@0000010?ooo`009`3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo00d0oooo0P00001Z0?ooo`4000000@3oool002L0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`0;0?ooo`800000K03oool100000040oooo000W
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/
0?ooo`4000000@3oool002L0oooo0P00001i0?ooo`030000003oool0oooo00P0oooo0P00001^0?oo
o`8000000@3oool002L0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`070?ooo`<0
0000K`3oool100000040oooo000W0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
1@3oool200000780oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00<0oooo0P00001d0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0N03oool0
10000000oooo0?ooo`3oool2000007H0oooo0@0000010?ooo`0000@0oooo0000000000000000103o
ool2000000@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`D00000103o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00<00000MP3oool100000040oooo0002
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1h0?ooo`<00000N@3oool100000040oooo00020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0103oool2000007T0oooo00<000000?ooo`3oool0N03o
ool200000040oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1f0?ooo`<00000N`3oool100000040oooo00020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo07@0oooo0P0000020?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`0000<0oooo
000000000000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0L`3oool300000080oooo00<000000?ooo`3oool0N@3oool100000040oooo00020?ooo`03
0000003oool0oooo00<0oooo0P0000040?ooo`8000002P3oool2000000<0oooo0`0000050?ooo`03
0000003oool0oooo0740oooo0P0000050?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`00
9`3oool00`000000oooo0?ooo`1_0?ooo`8000001`3oool00`000000oooo0?ooo`1i0?ooo`400000
0@3oool002L0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo07T0oooo0@0000010?ooo`009`3oool2000006d0oooo0P00000:0?ooo`030000003oool0
oooo07P0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`1[0?ooo`<000002P3oool00`00
0000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0J@3oool2000000d0
oooo00<000000?ooo`3oool0N@3oool100000040oooo000W0?ooo`030000003oool0oooo06P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo00<0
00000?ooo`3oool0I@3oool300000100oooo00<000000?ooo`3oool0N@3oool100000040oooo000W
0?ooo`030000003oool0oooo06D0oooo0P00000A0?ooo`030000003oool0oooo07T0oooo0@000001
0?ooo`009`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0N@3oool100000040oooo000W0?ooo`030000003oool0oooo0680oooo0P00000D0?ooo`03
0000003oool0oooo07T0oooo0@0000010?ooo`009`3oool200000640oooo0P00000F0?ooo`030000
003oool0oooo07P0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`1M0?ooo`<00000603o
ool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0G@3oool2
000001T0oooo00<000000?ooo`3oool0N@3oool100000040oooo000W0?ooo`030000003oool0oooo
05/0oooo0P00000K0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`009`3oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0N@3oool100000040
oooo000W0?ooo`030000003oool0oooo05P0oooo0P00000N0?ooo`030000003oool0oooo07T0oooo
0@0000010?ooo`009`3oool00`000000oooo0?ooo`1F0?ooo`800000803oool00`000000oooo0?oo
o`1i0?ooo`4000000@3oool002L0oooo0P00001F0?ooo`<00000803oool00`000000oooo0?ooo`1h
0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0D`3oool2000002<0oooo00<000000?oo
o`3oool0N@3oool100000040oooo000W0?ooo`030000003oool0oooo0540oooo0P00000U0?ooo`03
0000003oool0oooo07T0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0N@3oool100000040oooo000W0?ooo`030000003o
ool0oooo04h0oooo0P00000X0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`0000@0oooo
0000000000000000103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P00
00040?ooo`<00000103oool00`000000oooo0?ooo`1<0?ooo`@00000:03oool00`000000oooo0?oo
o`1i0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo04X0oooo0P00000/0?ooo`030000003oool0oooo07T0
oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000203oool01@000000oooo0?ooo`000000oooo00D00000103oool2
000004T0oooo0P00000^0?ooo`030000003oool0oooo07P0oooo0P0000010?ooo`000P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000203o
ool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`160?ooo`800000<03oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool00080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000050?ooo`030000003oool0
oooo04D0oooo0`00000`0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`0000<0oooo0000
00000000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000`3oool2000000D0oooo00<000000?ooo`3oool0@`3oool2000003<0oooo
00<000000?ooo`3oool0N@3oool100000040oooo00020?ooo`030000003oool0oooo00<0oooo0P00
00040?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0N@3oool100000040oooo000W
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1i
0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0?`3oool2000003L0oooo00<000000?oo
o`3oool0N@3oool100000040oooo000W0?ooo`800000?`3oool3000003L0oooo00<000000?ooo`3o
ool0N03oool200000040oooo000W0?ooo`030000003oool0oooo03`0oooo0P00000j0?ooo`030000
003oool0oooo07T0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0j0?ooo`800000?03o
ool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`009`3oool00`00
0000oooo0?ooo`0g0?ooo`800000?`3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0
oooo00<000000?ooo`3oool0=P3oool3000003l0oooo00<000000?ooo`3oool0N@3oool100000040
oooo000W0?ooo`030000003oool0oooo03@0oooo0P0000120?ooo`030000003oool0oooo07T0oooo
0@0000010?ooo`009`3oool00`000000oooo0?ooo`0b0?ooo`800000A03oool00`000000oooo0?oo
o`1i0?ooo`4000000@3oool002L0oooo0P00000a0?ooo`800000AP3oool00`000000oooo0?ooo`1h
0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0;`3oool3000004H0oooo00<000000?oo
o`3oool0N@3oool100000040oooo000W0?ooo`030000003oool0oooo02d0oooo0P0000190?ooo`03
0000003oool0oooo07T0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool0N@3oool100000040oooo000W0?ooo`030000003o
ool0oooo02X0oooo0P00001<0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`009`3oool0
0`000000oooo0?ooo`0X0?ooo`800000CP3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool0
02L0oooo00<000000?ooo`3oool09`3oool3000004h0oooo00<000000?ooo`3oool0N@3oool10000
0040oooo000W0?ooo`8000009P3oool200000540oooo00<000000?ooo`3oool0N03oool200000040
oooo000W0?ooo`030000003oool0oooo02<0oooo0P00001C0?ooo`030000003oool0oooo07T0oooo
0@0000010?ooo`009`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool0N@3oool100000040oooo000W0?ooo`030000003oool0oooo0200oooo0P00001F
0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0O0?oo
o`<00000EP3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool000040?ooo`00000000000000
00@0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3oool30000
00D0oooo00<000000?ooo`3oool07@3oool2000005T0oooo00<000000?ooo`3oool0N@3oool10000
0040oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`1i0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`030000003oool0oooo0080oooo0P00000J0?ooo`<00000G03oool00`000000oooo0?ooo`1h
0?ooo`8000000@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3oool000000?ooo`04000000D0oooo
00<000000?ooo`3oool06@3oool2000005d0oooo00<000000?ooo`3oool0N@3oool100000040oooo
00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000203oool00`000000oooo0?ooo`0G
0?ooo`800000G`3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool000030?ooo`0000000000
00@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`800000
H@3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00`3o
ool2000000@0oooo0P00000:0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool04`3o
ool2000006<0oooo00<000000?ooo`3oool0N@3oool100000040oooo000W0?ooo`030000003oool0
oooo0140oooo0P00001U0?ooo`030000003oool0oooo07T0oooo0@0000010?ooo`009`3oool00`00
0000oooo0?ooo`0@0?ooo`<00000I@3oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0
oooo00<000000?ooo`3oool03P3oool2000006P0oooo00<000000?ooo`3oool0N@3oool100000040
oooo000W0?ooo`8000003@3oool2000006X0oooo00<000000?ooo`3oool0N03oool200000040oooo
000W0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?oo
o`1i0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool02@3oool3000006`0oooo00<00000
0?ooo`3oool0N@3oool100000040oooo000W0?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`0000000000K03oool00`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo00<000000?oo
o`3oool01P3oool200000700oooo00<000000?ooo`3oool0N@3oool100000040oooo000W0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1i0?ooo`40
00000@3oool002L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo07T0oooo0@0000010?ooo`009`3oool2000000@0oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`1h0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`1i0?ooo`4000000@3oool002L0oooo0P0000090?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo0P0000010?ooo`009`3ooooh00000040oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo000c0?ooo`<00000F03oool3000001L0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`0;0?ooo`00=03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0:0?ooo`00;P3oool3000000<0oooo
0`0000040?ooo`8000000P3oool500000080oooo0`0000030?ooo`@0000000<0oooo000000000000
0`0000070?ooo`<00000103oool4000000<0oooo0P0000020?ooo`H000001P3oool500000080oooo
0`0000020?ooo`<0000000@0oooo000000000000oooo100000030?ooo`8000000P3oool6000000L0
oooo00<000000?ooo`3oool00`3oool4000000030?ooo`0000000000008000000P3oool4000000<0
oooo0`0000020?ooo`D000000`3oool2000000040?ooo`000000oooo0?ooo`8000000`3oool30000
00T0oooo100000000`3oool0000000000003000000030?ooo`000000000000800000103oool20000
00<0oooo100000001@3oool00000000000000000oooo0080000000@0oooo00000000000000000`3o
ool3000000D0oooo00<000000?ooo`3oool02@3oool002d0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000203oool01P000000oooo
0?ooo`000000oooo000000H0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003o
ool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo
00<000000?ooo`000000203oool00`000000oooo0?ooo`090?ooo`00;@3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`0000001P3oool3000000@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool00P3oool500000080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`030?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`<000000P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0080oooo1@0000070?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool00`3oool3000000<0
oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`D00000103oool00`000000oooo0?ooo`09
0?ooo`00;@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool300000080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00H00000
0?ooo`3oool000000?ooo`0000050?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`06
0000003oool0oooo0000003oool000000`3oool00`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02@3oool002d0oooo00H000000?ooo`3oool0oooo0000003o
ool400000080oooo100000020?ooo`<00000103oool3000000<0oooo0P0000050?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`3oool000000P3oool2000000<0oooo100000030?ooo`<00000
2@3oool00`000000oooo0?ooo`030?ooo`<000000P3oool4000000<0oooo2@0000030?ooo`<00000
2@3oool00`000000oooo0?ooo`030?ooo`800000103oool3000000<0oooo100000020?ooo`<00000
103oool010000000oooo0?ooo`3oool2000000040?ooo`00000000000?ooo`@000000`3oool30000
00T0oooo0`0000020?ooo`<00000103oool4000000030?ooo`0000000000008000000`3oool20000
00<0oooo100000030?ooo`<000000`3oool3000000D0oooo00<000000?ooo`3oool02@3oool002d0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0:0?ooo`00;P3oool3000000T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0=0?ooo`<000002@3oool4000000T0oooo00<000000?oo
o`3oool00P3oool2000000X0oooo0`00000F0?ooo`030000003oool0oooo0080oooo0P00000=0?oo
o`030000003oool0oooo00H0oooo0P00000@0?ooo`<000002P3oool00`000000oooo0?ooo`0@0?oo
o`800000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool02`3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.46255, 99.9592, \
0.0212449, 0.000687363}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.190438 -4.72245e+13 4.19183e+12 [
[.11912 -0.01609 -6 -9 ]
[.11912 -0.01609 6 0 ]
[.30956 -0.01609 -6 -9 ]
[.30956 -0.01609 6 0 ]
[.5 -0.01609 -3 -9 ]
[.5 -0.01609 3 0 ]
[.69044 -0.01609 -3 -9 ]
[.69044 -0.01609 3 0 ]
[.88088 -0.01609 -3 -9 ]
[.88088 -0.01609 3 0 ]
[ 0 -0.00119 -0.125 0 ]
[-0.0125 .00625 -42 -4.5 ]
[-0.0125 .00625 0 4.5 ]
[-0.0125 .08816 -42 -4.5 ]
[-0.0125 .08816 0 4.5 ]
[-0.0125 .17751 -42 -4.5 ]
[-0.0125 .17751 0 4.5 ]
[-0.0125 .25942 -42 -4.5 ]
[-0.0125 .25942 0 4.5 ]
[-0.0125 .34133 -42 -4.5 ]
[-0.0125 .34133 0 4.5 ]
[-0.0125 .43069 -42 -4.5 ]
[-0.0125 .43069 0 4.5 ]
[-0.0125 .51259 -42 -4.5 ]
[-0.0125 .51259 0 4.5 ]
[-0.0125 .5945 -42 -4.5 ]
[-0.0125 .5945 0 4.5 ]
[ 0 -0.00119 -0.125 0 ]
[ 0 .61684 .125 0 ]
[ 1 -0.00119 .125 0 ]
[.5 .63173 -57 0 ]
[.5 .63173 57 9 ]
[ 0 -0.00119 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11912 -0.00119 m
.11912 .00625 L
s
[(-2)] .11912 -0.01609 0 1 Mshowa
.30956 -0.00119 m
.30956 .00625 L
s
[(-1)] .30956 -0.01609 0 1 Mshowa
.5 -0.00119 m
.5 .00625 L
s
[(0)] .5 -0.01609 0 1 Mshowa
.69044 -0.00119 m
.69044 .00625 L
s
[(1)] .69044 -0.01609 0 1 Mshowa
.88088 -0.00119 m
.88088 .00625 L
s
[(2)] .88088 -0.01609 0 1 Mshowa
.125 Mabswid
.15721 -0.00119 m
.15721 .00625 L
s
.1953 -0.00119 m
.1953 .00625 L
s
.23339 -0.00119 m
.23339 .00625 L
s
.27147 -0.00119 m
.27147 .00625 L
s
.34765 -0.00119 m
.34765 .00625 L
s
.38574 -0.00119 m
.38574 .00625 L
s
.42382 -0.00119 m
.42382 .00625 L
s
.46191 -0.00119 m
.46191 .00625 L
s
.53809 -0.00119 m
.53809 .00625 L
s
.57618 -0.00119 m
.57618 .00625 L
s
.61426 -0.00119 m
.61426 .00625 L
s
.65235 -0.00119 m
.65235 .00625 L
s
.72853 -0.00119 m
.72853 .00625 L
s
.76661 -0.00119 m
.76661 .00625 L
s
.8047 -0.00119 m
.8047 .00625 L
s
.84279 -0.00119 m
.84279 .00625 L
s
.08104 -0.00119 m
.08104 .00625 L
s
.04295 -0.00119 m
.04295 .00625 L
s
.00486 -0.00119 m
.00486 .00625 L
s
.91896 -0.00119 m
.91896 .00625 L
s
.95705 -0.00119 m
.95705 .00625 L
s
.99514 -0.00119 m
.99514 .00625 L
s
.25 Mabswid
0 -0.00119 m
1 -0.00119 L
s
0 .00625 m
.00625 .00625 L
s
[(11.2658)] -0.0125 .00625 1 0 Mshowa
0 .08816 m
.00625 .08816 L
s
[(11.2658)] -0.0125 .08816 1 0 Mshowa
0 .17751 m
.00625 .17751 L
s
[(11.2658)] -0.0125 .17751 1 0 Mshowa
0 .25942 m
.00625 .25942 L
s
[(11.2658)] -0.0125 .25942 1 0 Mshowa
0 .34133 m
.00625 .34133 L
s
[(11.2658)] -0.0125 .34133 1 0 Mshowa
0 .43069 m
.00625 .43069 L
s
[(11.2658)] -0.0125 .43069 1 0 Mshowa
0 .51259 m
.00625 .51259 L
s
[(11.2658)] -0.0125 .51259 1 0 Mshowa
0 .5945 m
.00625 .5945 L
s
[(11.2658)] -0.0125 .5945 1 0 Mshowa
.125 Mabswid
0 .02114 m
.00375 .02114 L
s
0 .03604 m
.00375 .03604 L
s
0 .05838 m
.00375 .05838 L
s
0 .07327 m
.00375 .07327 L
s
0 .10305 m
.00375 .10305 L
s
0 .11795 m
.00375 .11795 L
s
0 .14028 m
.00375 .14028 L
s
0 .15518 m
.00375 .15518 L
s
0 .19241 m
.00375 .19241 L
s
0 .2073 m
.00375 .2073 L
s
0 .22964 m
.00375 .22964 L
s
0 .24453 m
.00375 .24453 L
s
0 .27432 m
.00375 .27432 L
s
0 .28921 m
.00375 .28921 L
s
0 .31155 m
.00375 .31155 L
s
0 .32644 m
.00375 .32644 L
s
0 .35622 m
.00375 .35622 L
s
0 .37112 m
.00375 .37112 L
s
0 .39345 m
.00375 .39345 L
s
0 .40835 m
.00375 .40835 L
s
0 .44558 m
.00375 .44558 L
s
0 .46047 m
.00375 .46047 L
s
0 .48281 m
.00375 .48281 L
s
0 .4977 m
.00375 .4977 L
s
0 .52749 m
.00375 .52749 L
s
0 .54238 m
.00375 .54238 L
s
0 .56472 m
.00375 .56472 L
s
0 .57961 m
.00375 .57961 L
s
0 .60939 m
.00375 .60939 L
s
.25 Mabswid
0 -0.00119 m
0 .61684 L
s
.11912 .60939 m
.11912 .61684 L
s
.30956 .60939 m
.30956 .61684 L
s
.5 .60939 m
.5 .61684 L
s
.69044 .60939 m
.69044 .61684 L
s
.88088 .60939 m
.88088 .61684 L
s
.125 Mabswid
.15721 .60939 m
.15721 .61684 L
s
.1953 .60939 m
.1953 .61684 L
s
.23339 .60939 m
.23339 .61684 L
s
.27147 .60939 m
.27147 .61684 L
s
.34765 .60939 m
.34765 .61684 L
s
.38574 .60939 m
.38574 .61684 L
s
.42382 .60939 m
.42382 .61684 L
s
.46191 .60939 m
.46191 .61684 L
s
.53809 .60939 m
.53809 .61684 L
s
.57618 .60939 m
.57618 .61684 L
s
.61426 .60939 m
.61426 .61684 L
s
.65235 .60939 m
.65235 .61684 L
s
.72853 .60939 m
.72853 .61684 L
s
.76661 .60939 m
.76661 .61684 L
s
.8047 .60939 m
.8047 .61684 L
s
.84279 .60939 m
.84279 .61684 L
s
.08104 .60939 m
.08104 .61684 L
s
.04295 .60939 m
.04295 .61684 L
s
.00486 .60939 m
.00486 .61684 L
s
.91896 .60939 m
.91896 .61684 L
s
.95705 .60939 m
.95705 .61684 L
s
.99514 .60939 m
.99514 .61684 L
s
.25 Mabswid
0 .61684 m
1 .61684 L
s
.99375 .00625 m
1 .00625 L
s
.99375 .08816 m
1 .08816 L
s
.99375 .17751 m
1 .17751 L
s
.99375 .25942 m
1 .25942 L
s
.99375 .34133 m
1 .34133 L
s
.99375 .43069 m
1 .43069 L
s
.99375 .51259 m
1 .51259 L
s
.99375 .5945 m
1 .5945 L
s
.125 Mabswid
.99625 .02114 m
1 .02114 L
s
.99625 .03604 m
1 .03604 L
s
.99625 .05838 m
1 .05838 L
s
.99625 .07327 m
1 .07327 L
s
.99625 .10305 m
1 .10305 L
s
.99625 .11795 m
1 .11795 L
s
.99625 .14028 m
1 .14028 L
s
.99625 .15518 m
1 .15518 L
s
.99625 .19241 m
1 .19241 L
s
.99625 .2073 m
1 .2073 L
s
.99625 .22964 m
1 .22964 L
s
.99625 .24453 m
1 .24453 L
s
.99625 .27432 m
1 .27432 L
s
.99625 .28921 m
1 .28921 L
s
.99625 .31155 m
1 .31155 L
s
.99625 .32644 m
1 .32644 L
s
.99625 .35622 m
1 .35622 L
s
.99625 .37112 m
1 .37112 L
s
.99625 .39345 m
1 .39345 L
s
.99625 .40835 m
1 .40835 L
s
.99625 .44558 m
1 .44558 L
s
.99625 .46047 m
1 .46047 L
s
.99625 .48281 m
1 .48281 L
s
.99625 .4977 m
1 .4977 L
s
.99625 .52749 m
1 .52749 L
s
.99625 .54238 m
1 .54238 L
s
.99625 .56472 m
1 .56472 L
s
.99625 .57961 m
1 .57961 L
s
.99625 .60939 m
1 .60939 L
s
.25 Mabswid
1 -0.00119 m
1 .61684 L
s
.5 -0.00119 m
.5 .61684 L
s
[(WaveFront Intensity)] .5 .63173 0 -1 Mshowa
.01 w
.05453 .53493 Mdot
.08525 .0137 Mdot
.11598 .53493 Mdot
.1467 .26687 Mdot
.17742 .26687 Mdot
.20814 .40835 Mdot
.23886 .33388 Mdot
.26959 .26687 Mdot
.30031 .26687 Mdot
.33103 .33388 Mdot
.36175 .26687 Mdot
.39247 .40835 Mdot
.4232 .33388 Mdot
.45392 .26687 Mdot
.48464 .26687 Mdot
.51536 .33388 Mdot
.54608 .40835 Mdot
.5768 .2073 Mdot
.60753 .33388 Mdot
.63825 .33388 Mdot
.66897 .40835 Mdot
.69969 .14028 Mdot
.73041 .40835 Mdot
.76114 .33388 Mdot
.79186 .2073 Mdot
.82258 .53493 Mdot
.8533 .14028 Mdot
.88402 .60195 Mdot
.91475 .26687 Mdot
.94547 .0137 Mdot
.5 Mabswid
.02381 .53493 m
.03837 .53493 L
.04579 .53493 L
.04987 .53493 L
.05187 .53493 L
.05372 .53493 L
.0547 .53493 L
.0552 .52004 L
.05574 .51259 L
.05794 .47536 L
.06178 .40835 L
.06929 .28176 L
.07819 .13284 L
.08209 .06582 L
.08316 .05093 L
.08429 .02859 L
.08485 .02114 L
.08537 .0137 L
.08634 .02859 L
.09404 .16262 L
.10137 .28921 L
.10923 .42324 L
.11319 .49025 L
.11427 .50515 L
.11487 .51259 L
.11543 .52749 L
.11596 .53493 L
.11653 .52749 L
.11753 .52004 L
.13308 .38601 L
.14045 .31899 L
.14407 .28921 L
.14565 .27432 L
.14654 .26687 L
.14738 .26687 L
.14908 .26687 L
.15088 .26687 L
.15465 .26687 L
.16269 .26687 L
.17055 .26687 L
.17281 .26687 L
.17495 .26687 L
.17687 .26687 L
.1774 .26687 L
.17795 .26687 L
.17895 .27432 L
.17989 .28176 L
.18091 .28176 L
.18187 .28921 L
.18277 .28921 L
Mistroke
.18365 .29665 L
.18446 .29665 L
.18538 .3041 L
.18626 .3041 L
.18721 .31155 L
.18822 .31899 L
.18908 .31899 L
.19003 .32644 L
.19105 .32644 L
.19162 .33388 L
.19214 .33388 L
.19315 .34133 L
.1941 .34133 L
.19492 .34878 L
.19582 .34878 L
.19676 .35622 L
.19764 .36367 L
.19846 .36367 L
.19921 .36367 L
.20003 .37112 L
.2009 .37856 L
.20179 .37856 L
.20273 .38601 L
.20362 .38601 L
.20443 .39345 L
.20538 .39345 L
.20592 .4009 L
.20641 .4009 L
.20732 .4009 L
.20828 .40835 L
.20922 .40835 L
.20976 .4009 L
.21025 .4009 L
.21113 .4009 L
.21211 .4009 L
.21299 .39345 L
.21381 .39345 L
.21467 .39345 L
.21561 .39345 L
.21657 .38601 L
.21758 .38601 L
.21852 .38601 L
.21939 .37856 L
.21992 .37856 L
.22042 .37856 L
.22136 .37856 L
.22237 .37112 L
.22294 .37112 L
.22347 .37112 L
.22428 .37112 L
Mistroke
.22516 .36367 L
.22599 .36367 L
.22675 .36367 L
.22763 .36367 L
.2286 .35622 L
.22951 .35622 L
.23036 .35622 L
.23131 .34878 L
.23221 .34878 L
.23303 .34878 L
.23389 .34878 L
.23483 .34133 L
.2357 .34133 L
.23663 .34133 L
.23766 .33388 L
.23867 .33388 L
.2396 .33388 L
.24009 .33388 L
.24063 .32644 L
.24119 .32644 L
.24172 .32644 L
.24262 .32644 L
.24357 .32644 L
.24407 .31899 L
.24461 .31899 L
.24556 .31899 L
.24649 .31899 L
.24737 .31899 L
.24838 .31155 L
.2493 .31155 L
.25017 .31155 L
.25097 .3041 L
.25184 .3041 L
.25277 .3041 L
.25378 .3041 L
.25469 .29665 L
.2552 .29665 L
.25575 .29665 L
.25676 .29665 L
.25769 .28921 L
.25869 .28921 L
.25963 .28921 L
.26049 .28921 L
.26102 .28921 L
.26159 .28176 L
.26216 .28176 L
.26278 .28176 L
.26332 .28176 L
.2639 .28176 L
.26444 .28176 L
Mistroke
.26494 .27432 L
.26593 .27432 L
.26645 .27432 L
.26701 .27432 L
.26803 .26687 L
.26897 .26687 L
.28426 .26687 L
.29095 .26687 L
.29448 .26687 L
.29825 .26687 L
.29933 .26687 L
.30034 .26687 L
.30125 .26687 L
.30224 .27432 L
.30318 .27432 L
.30417 .27432 L
.30502 .27432 L
.30595 .28176 L
.3069 .28176 L
.30777 .28176 L
.30878 .28176 L
.30973 .28921 L
.31061 .28921 L
.31143 .28921 L
.31232 .29665 L
.31327 .29665 L
.3142 .29665 L
.31517 .29665 L
.31569 .3041 L
.31625 .3041 L
.31723 .3041 L
.31816 .3041 L
.31916 .31155 L
.3201 .31155 L
.32095 .31155 L
.32148 .31155 L
.32204 .31155 L
.32304 .31899 L
.3236 .31899 L
.32412 .31899 L
.32473 .31899 L
.32531 .31899 L
.32581 .31899 L
.32635 .32644 L
.3273 .32644 L
.32783 .32644 L
.3284 .32644 L
.32894 .32644 L
.32943 .33388 L
.33036 .33388 L
Mistroke
.33123 .33388 L
.33219 .33388 L
.33321 .32644 L
.33373 .32644 L
.33429 .32644 L
.3353 .32644 L
.33629 .31899 L
.33721 .31899 L
.338 .31899 L
.33886 .31899 L
.33979 .31155 L
.34067 .31155 L
.34161 .31155 L
.34259 .31155 L
.34343 .3041 L
.34435 .3041 L
.34488 .3041 L
.34544 .3041 L
.34598 .3041 L
.34647 .29665 L
.34741 .29665 L
.3484 .29665 L
.34891 .29665 L
.34946 .29665 L
.35045 .28921 L
.35106 .28921 L
.35163 .28921 L
.35215 .28921 L
.35271 .28921 L
.35365 .28176 L
.35464 .28176 L
.35557 .28176 L
.35643 .28176 L
.35743 .27432 L
.35796 .27432 L
.35852 .27432 L
.35945 .27432 L
.35999 .27432 L
.36048 .26687 L
.36146 .26687 L
.362 .26687 L
.36251 .26687 L
.3634 .27432 L
.36438 .28176 L
.36492 .28176 L
.36544 .28176 L
.36642 .28921 L
.36692 .28921 L
.36746 .29665 L
.36806 .29665 L
Mistroke
.36861 .29665 L
.36961 .3041 L
.37013 .3041 L
.37068 .31155 L
.3717 .31155 L
.37264 .31899 L
.37354 .31899 L
.37438 .32644 L
.3753 .32644 L
.37629 .33388 L
.37725 .34133 L
.37814 .34133 L
.37912 .34878 L
.37961 .34878 L
.38016 .34878 L
.38106 .35622 L
.38204 .36367 L
.38297 .36367 L
.38382 .37112 L
.38464 .37112 L
.38541 .37856 L
.38626 .37856 L
.38716 .38601 L
.3881 .38601 L
.389 .39345 L
.3898 .39345 L
.39067 .4009 L
.39163 .4009 L
.3925 .40835 L
.39351 .40835 L
.39446 .4009 L
.39534 .4009 L
.39616 .4009 L
.39705 .4009 L
.398 .39345 L
.39855 .39345 L
.39905 .39345 L
.3996 .39345 L
.40018 .38601 L
.40116 .38601 L
.40224 .38601 L
.40319 .38601 L
.40373 .37856 L
.40422 .37856 L
.4051 .37856 L
.40607 .37856 L
.40708 .37112 L
.40763 .37112 L
.40815 .37112 L
.40908 .37112 L
Mistroke
.41008 .36367 L
.41064 .36367 L
.41125 .36367 L
.41178 .36367 L
.41236 .36367 L
.41292 .35622 L
.41344 .35622 L
.41444 .35622 L
.41546 .35622 L
.4164 .34878 L
.41689 .34878 L
.41743 .34878 L
.418 .34878 L
.41852 .34878 L
.41947 .34133 L
.42 .34133 L
.4205 .34133 L
.42139 .34133 L
.42236 .33388 L
.4233 .33388 L
.42416 .33388 L
.42511 .32644 L
.42611 .32644 L
.42692 .32644 L
.42779 .32644 L
.42874 .31899 L
.42963 .31899 L
.43066 .31899 L
.43125 .31899 L
.43179 .31155 L
.43278 .31155 L
.43383 .31155 L
.43477 .31155 L
.43565 .3041 L
.43662 .3041 L
.43765 .3041 L
.43818 .3041 L
.43873 .29665 L
.43974 .29665 L
.44035 .29665 L
.44093 .29665 L
.44145 .29665 L
.44201 .28921 L
.44251 .28921 L
.44306 .28921 L
.44417 .28921 L
.44466 .28921 L
.44519 .28921 L
.44615 .28176 L
.44715 .28176 L
Mistroke
.44768 .28176 L
.44823 .28176 L
.44872 .28176 L
.44926 .27432 L
.45021 .27432 L
.45113 .27432 L
.45212 .27432 L
.45306 .26687 L
.45391 .26687 L
.46982 .26687 L
.47757 .26687 L
.48124 .26687 L
.48461 .26687 L
.4855 .26687 L
.48633 .26687 L
.48719 .27432 L
.48814 .27432 L
.4891 .27432 L
.48998 .28176 L
.491 .28176 L
.49196 .28176 L
.49279 .28176 L
.49368 .28921 L
.49452 .28921 L
.49528 .28921 L
.49617 .28921 L
.49714 .29665 L
.49805 .29665 L
.49889 .29665 L
.49978 .29665 L
.50072 .3041 L
.50162 .3041 L
.50243 .3041 L
.50339 .3041 L
.50393 .31155 L
.50443 .31155 L
.5054 .31155 L
.50631 .31155 L
.50718 .31899 L
.50812 .31899 L
.50907 .31899 L
.50957 .31899 L
.51011 .31899 L
.51067 .32644 L
.51119 .32644 L
.51221 .32644 L
.51322 .32644 L
.51414 .33388 L
.51507 .33388 L
.51593 .33388 L
Mistroke
.51689 .33388 L
.51791 .34133 L
.51842 .34133 L
.51898 .34133 L
.51999 .34878 L
.52098 .34878 L
.52189 .34878 L
.52274 .34878 L
.52354 .35622 L
.52441 .35622 L
.52536 .35622 L
.52629 .36367 L
.52727 .36367 L
.52818 .36367 L
.52903 .36367 L
.53004 .37112 L
.53096 .37112 L
.53195 .37112 L
.53251 .37856 L
.53302 .37856 L
.53395 .37856 L
.53482 .37856 L
.53573 .38601 L
.53673 .38601 L
.53725 .38601 L
.53782 .38601 L
.53835 .38601 L
.53885 .39345 L
.53979 .39345 L
.54079 .39345 L
.54136 .39345 L
.54197 .4009 L
.54255 .4009 L
.54308 .4009 L
.54409 .4009 L
.54459 .40835 L
.54515 .40835 L
.54617 .40835 L
.5471 .4009 L
.54922 .38601 L
.55307 .36367 L
.56028 .31899 L
.56864 .25942 L
.56968 .25198 L
.57064 .24453 L
.57164 .24453 L
.57217 .23708 L
.57274 .23708 L
.57375 .22964 L
.5747 .22219 L
Mistroke
.57557 .21475 L
.57648 .2073 L
.57731 .2073 L
.57823 .21475 L
.57906 .21475 L
.57983 .22219 L
.58075 .22219 L
.58158 .22964 L
.58254 .22964 L
.58346 .23708 L
.58436 .23708 L
.58532 .24453 L
.58614 .24453 L
.58705 .25198 L
.58802 .25198 L
.58856 .25942 L
.58907 .25942 L
.58999 .25942 L
.59096 .26687 L
.59196 .26687 L
.59287 .27432 L
.59337 .27432 L
.59392 .27432 L
.59491 .28176 L
.59583 .28921 L
.59682 .28921 L
.59766 .29665 L
.59858 .29665 L
.59914 .29665 L
.59966 .3041 L
.60066 .3041 L
.60121 .31155 L
.60172 .31155 L
.60232 .31155 L
.60289 .31155 L
.60338 .31899 L
.60391 .31899 L
.60484 .32644 L
.60537 .32644 L
.60592 .32644 L
.60692 .33388 L
.60787 .33388 L
.60889 .33388 L
.61076 .33388 L
.61426 .33388 L
.62213 .33388 L
.62946 .33388 L
.63304 .33388 L
.63633 .33388 L
.63804 .33388 L
Mistroke
.6389 .33388 L
.63984 .34133 L
.64078 .34133 L
.64179 .34133 L
.64275 .34133 L
.64361 .34878 L
.64411 .34878 L
.64465 .34878 L
.6456 .34878 L
.64662 .35622 L
.6472 .35622 L
.64775 .35622 L
.64873 .35622 L
.64963 .36367 L
.65012 .36367 L
.65066 .36367 L
.65165 .36367 L
.65218 .37112 L
.65275 .37112 L
.65379 .37112 L
.65481 .37112 L
.65574 .37856 L
.65675 .37856 L
.65733 .37856 L
.65786 .37856 L
.65842 .38601 L
.65901 .38601 L
.66009 .38601 L
.66109 .38601 L
.66202 .39345 L
.66303 .39345 L
.66355 .39345 L
.66411 .39345 L
.66505 .4009 L
.66592 .4009 L
.66646 .4009 L
.66696 .4009 L
.66792 .40835 L
.66888 .40835 L
.66942 .4009 L
.66992 .4009 L
.67083 .39345 L
.6718 .38601 L
.67533 .35622 L
.68324 .28176 L
.69068 .22219 L
.69393 .19241 L
.69747 .16262 L
.69842 .14773 L
.69943 .14028 L
Mistroke
.70029 .14773 L
.70123 .15518 L
.7048 .18496 L
.71266 .25198 L
.71958 .31155 L
.72686 .37856 L
.72866 .39345 L
.72965 .4009 L
.73058 .40835 L
.73111 .40835 L
.73169 .40835 L
.7327 .4009 L
.73372 .4009 L
.73466 .4009 L
.73552 .39345 L
.73632 .39345 L
.7372 .39345 L
.73814 .38601 L
.73913 .38601 L
.74006 .38601 L
.74091 .38601 L
.74182 .37856 L
.74235 .37856 L
.74292 .37856 L
.74342 .37856 L
.74395 .37856 L
.74496 .37112 L
.74588 .37112 L
.74639 .37112 L
.74695 .37112 L
.74794 .36367 L
.74855 .36367 L
.74912 .36367 L
.74963 .36367 L
.7502 .36367 L
.75114 .35622 L
.75213 .35622 L
.75306 .35622 L
.75392 .34878 L
.75494 .34878 L
.75587 .34878 L
.75689 .34133 L
.75741 .34133 L
.75797 .34133 L
.75846 .34133 L
.75899 .34133 L
.75994 .33388 L
.76095 .33388 L
.76153 .33388 L
.76207 .32644 L
Mistroke
.76304 .32644 L
.76393 .31899 L
.76443 .31899 L
.76496 .31899 L
.76594 .31155 L
.7668 .31155 L
.76776 .3041 L
.76875 .3041 L
.76969 .29665 L
.77056 .29665 L
.77136 .28921 L
.77224 .28921 L
.77317 .28176 L
.77418 .28176 L
.77511 .27432 L
.77562 .27432 L
.77617 .27432 L
.77718 .26687 L
.77812 .26687 L
.77912 .25942 L
.77997 .25942 L
.78091 .25198 L
.78148 .25198 L
.78202 .24453 L
.78302 .24453 L
.78359 .24453 L
.78411 .23708 L
.78468 .23708 L
.78529 .23708 L
.78583 .22964 L
.7864 .22964 L
.78695 .22964 L
.78745 .22219 L
.78839 .22219 L
.7894 .21475 L
.79034 .21475 L
.79087 .21475 L
.79137 .2073 L
.79227 .21475 L
.79324 .22219 L
.79673 .25942 L
.8046 .34133 L
.81201 .42324 L
.8188 .4977 L
.81968 .50515 L
.82063 .51259 L
.82152 .52004 L
.82233 .53493 L
.82324 .52749 L
.82411 .51259 L
Mistroke
.82504 .50515 L
.82605 .49025 L
.83387 .39345 L
.84118 .29665 L
.84802 .2073 L
.85156 .16262 L
.85258 .14773 L
.85354 .14028 L
.85441 .15518 L
.85535 .17007 L
.86341 .28921 L
.87196 .42324 L
.87971 .53493 L
.88155 .56472 L
.88255 .57961 L
.88349 .5945 L
.8845 .5945 L
.88504 .5945 L
.88561 .58706 L
.88757 .56472 L
.89497 .48281 L
.91122 .3041 L
.92658 .17007 L
.93469 .10305 L
.93912 .06582 L
.94018 .05838 L
.94129 .05093 L
.94224 .04348 L
.94278 .03604 L
.94328 .02859 L
.94421 .02114 L
.94506 .0137 L
.94604 .02114 L
.94696 .02859 L
.95092 .05838 L
.95934 .12539 L
.97417 .25198 L
.97619 .26687 L
Mfstroke
0 -0.00119 m
1 -0.00119 L
1 .61684 L
0 .61684 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00B@3oool5000002X0oooo0`00000Y0?ooo`800000;03oool3000002X0
oooo1@00000L0?ooo`00BP3oool010000000oooo0?ooo`00000[0?ooo`030000003oool0oooo02L0
oooo00@000000?ooo`3oool00000;03oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo
000001`0oooo00130?ooo`D000000`3oool00`000000oooo0?ooo`0S0?ooo`D000000`3oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000002`0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0L0?ooo`00C03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02L0oooo00@000000?ooo`3oool00000;03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo01/0oooo00190?ooo`050000003oool0oooo0?ooo`000000:`3oool00`000000oooo0?ooo`0W
0?ooo`040000003oool0oooo000002`0oooo00<000000?ooo`3oool0:@3oool01@000000oooo0?oo
o`3oool0000001`0oooo00190?ooo`050000003oool0oooo0?ooo`000000:P3oool2000002T0oooo
00@000000?ooo`3oool00000:`3oool2000002/0oooo00D000000?ooo`3oool0oooo0000000L0?oo
o`00BP3oool3000002`0oooo00<000000?ooo`3oool0:03oool2000002d0oooo00<000000?ooo`3o
ool0:P3oool3000001d0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo0000103oool000000000000000030?ooo`<00000103oool010000000oooo0?ooo`3oool5
00000080oooo0`0000030?ooo`<000000`3oool3000000D0oooolP0000010?ooo`000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`800000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`8000000@3oool00080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3o
ool2000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool200000040oooo00020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`04000000H0oooo00<00000
0?ooo`3oool00`0000050?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0MP3oool1
00000040oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001@3oool400000080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0100oooo0P00001S0?ooo`030000003oool0oooo06T0oooo
0P00000;0?ooo`4000000@3oool000030?ooo`000000000000@0oooo0P0000090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0100oooo0P00001S0?ooo`03
0000003oool0oooo06T0oooo0P00000;0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`<00000103oool200000080oooo1@0000020?ooo`<00000
1@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
J@3oool00`000000oooo0?ooo`090?ooo`8000000@3oool002d0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo06T0oooo0P00000;0?ooo`4000000@3o
ool002d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo06T0oooo0P00000;0?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1Q0?ooo`030000003oool0oooo06T0oooo0P00000:0?ooo`8000000@3oool002d0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo06T0
oooo0P00000;0?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`0000002`3oool100000040oooo
000]0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?oo
o`1X0?ooo`040000003oool0oooo000000X0oooo0@0000010?ooo`00;@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0J03oool010000000oooo0?oo
o`00000:0?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo06P0oooo00@000000?ooo`3oool000002P3oool100000040oooo
000]0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?oo
o`1X0?ooo`040000003oool0oooo000000T0oooo0P0000010?ooo`00;@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool000000680oooo00<000000?ooo`3oool0J03oool010000000oooo0?oo
o`00000:0?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool0403oool00`000000oooo0000
001R0?ooo`030000003oool0oooo06P0oooo00@000000?ooo`3oool000002P3oool100000040oooo
000]0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000HP3oool00`000000oooo0?oo
o`1X0?ooo`040000003oool0oooo000000T0oooo0P0000010?ooo`0000@0oooo0000000000000000
0`3oool3000000@0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`<000000`3oool3000000<0
oooo0`0000050?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000HP3oool00`000000
oooo0?ooo`1X0?ooo`040000003oool0oooo000000X0oooo0@0000010?ooo`000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000HP3oool00`000000oooo0?ooo`1X
0?ooo`050000003oool0oooo0?ooo`0000002@3oool100000040oooo00020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool00`000000oooo0000001R0?ooo`030000003oool0oooo06P0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@000001P3oool00`000000oooo0?oo
o`03000000D0oooo0P00000A0?ooo`030000003oool000000680oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo0P0000010?ooo`000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00L000000?ooo`3oool0oooo0000
003oool0000000D0oooo100000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`0@0?ooo`030000003oool000000680oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`0000<0oooo000000000000
103oool2000000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0403oool00`000000oooo0000001R0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`4000000@3oool00080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`<00000103oool200000080oooo1@0000020?ooo`<0
00001@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool000000680oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`00
;@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo00000680oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo0P0000010?ooo`00
;@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo00000680oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`00
;@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo00000680oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`00
;@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo00000680oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P0000010?ooo`00
;@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo00000680oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`00
;@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo00000680oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`00
;@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo00000680oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`00
;@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000000H@3oool00`000000
oooo0?ooo`1V0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool100000040
oooo000]0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000001Q0?ooo`03
0000003oool0oooo02d0oooo0P00000S0?ooo`8000004P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo0@0000010?ooo`00;@3oool00`000000oooo0?ooo`0?0?ooo`050000
003oool0oooo0?ooo`000000H@3oool00`000000oooo0?ooo`0]0?ooo`8000008`3oool200000180
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`8000000@3oool002d0oooo
00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool000000640oooo00<000000?ooo`3o
ool0;@3oool2000002@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo0@0000010?ooo`00;@3oool00`000000oooo0?ooo`0?0?ooo`050000
003oool0oooo0?ooo`000000H@3oool00`000000oooo0?ooo`0]0?ooo`800000903oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool100000040
oooo000]0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000001Q0?ooo`03
0000003oool0oooo02d0oooo0P00000T0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`8000000@3oool002d0oooo00<000000?ooo`3oool0
3`3oool01@000000oooo0?ooo`3oool000000640oooo00<000000?ooo`3oool0;@3oool2000002<0
oooo0P00000A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool100000040
oooo000]0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000001Q0?ooo`03
0000003oool0oooo02d0oooo0P00000S0?ooo`8000004@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000@0oooo00000000000000000`3oool3000000@0
oooo00@000000?ooo`3oool0oooo1@0000020?ooo`<000000`3oool3000000<0oooo0`0000050?oo
o`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000001Q0?ooo`030000003oool0
oooo02d0oooo0P00000S0?ooo`8000004@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00D0
00000?ooo`3oool0oooo0000001Q0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`000000
8P3oool200000140oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`400000
0@3oool00080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool000000280oooo
0P00000A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool100000040oooo
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`04000000H0oooo00<000000?ooo`3oool00`0000050?ooo`8000003`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0;03oool010000000oooo0?oo
o`00000R0?ooo`8000004@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
0P0000010?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000D0oooo100000020?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0G`3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo00000280oooo0P00000A
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3o
ool00000000000040?ooo`8000002@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo00000280oooo0P00000A0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool100000040oooo00020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0203oool3000000@0oooo0P0000020?ooo`D000000P3o
ool3000000D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo05l0oooo00<000000?ooo`3oool0;03oool010000000oooo0?ooo`00000R0?ooo`800000
403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P0000010?ooo`00;@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo00000280oooo0P00000@0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0103oool100000040oooo000]0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo02`0oooo00@000000?ooo`3oool000008P3oool200000100oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`040?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool03`3o
ool2000001/0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`8000003@3oool00`000000oooo
0000000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool100000040oooo
000]0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo00l0oooo0P00000K0?ooo`050000003oool0oooo0?ooo`000000
4P3oool2000000d0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00<0oooo0P0000010?ooo`00;@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01T0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
0@0000010?ooo`00;@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`0@0?ooo`8000006P3oool01@000000oooo0?oo
o`3oool000000180oooo0P00000=0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`040?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0403o
ool2000001X0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`8000003@3oool00`000000oooo
0000000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool100000040oooo
000]0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo0100oooo0P00000J0?ooo`050000003oool0oooo0?ooo`000000
4P3oool2000000d0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo0@0000010?ooo`00;@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0000001X0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`8000003@3oool00`000000oooo
0000000>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool200000040oooo
000]0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000006P3oool01@000000oooo0?oo
o`3oool000000180oooo0P00000<0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`040?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
3`3oool010000000oooo0?ooo`00000I0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`00
0000oooo0000000<0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool03`3oool01000
0000oooo0?ooo`00000H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool0
10000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool03`3o
ool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3P3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000h0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`8000000@3oool000040?ooo`00000000000000
00<0oooo0`0000040?ooo`040000003oool0oooo0?ooo`D000000P3oool3000000<0oooo0`000003
0?ooo`<000001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000001P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000/0oooo
00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0
oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03@3oool200000080oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000>
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool100000040oooo00020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool0
oooo0080oooo0P00000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0GP3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`8000000@3oool00080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00@000001P3oool00`000000oooo0?ooo`03000000D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000
2`3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P3oool100000040oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool400000080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`070?ooo`X00000503oool9000000d0oooo0P00000E0?ooo`T000000P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo0P00000F0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0303oool2000000<0oooo00<000000?ooo`3oool02@3oool0
1@000000oooo0?ooo`3oool0000000/0oooo0P00000>0?ooo`030000003oool0oooo0080oooo0@00
00010?ooo`0000<0oooo000000000000103oool2000000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo0P0000060?ooo`800000503oool2000000D0oooo0P00000=0?ooo`800000
5@3oool2000000D0oooo0P0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`8000004`3oool100000040oooo00020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool3000000@0oooo0P0000020?ooo`D000000P3oool3000000D0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02P3oool2000001@0oooo0P0000070?ooo`80000000<0oooo0000003oool0
3`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2@3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0403oool200000040
oooo000]0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00X0oooo0P00000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`0000003`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool04@3oool100000040oooo000]0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo0P00
00000`3oool000000?ooo`0A0?ooo`8000002@3oool3000000l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo0@0000010?ooo`00;@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool02@3o
ool2000000l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0140oooo0@0000010?ooo`00;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00l0oooo0P00000:0?ooo`800000203oool200000080oooo00<000000?ooo`3oool03`3oool2
000000/0oooo0P00000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0A0?ooo`8000000@3oool002d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0>0?ooo`800000303oool2000000H0oooo0P0000030?ooo`800000403oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo0@0000010?ooo`00;@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0180oooo0@0000010?ooo`00;@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`8000003P3oool2000000h0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool2000000h0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo
0@0000010?ooo`00;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`8000003@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool100000040oooo000]
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<
0?ooo`8000003P3oool3000000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0140oooo0P0000010?ooo`00;@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0000000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0180oooo0@0000010?ooo`00;@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo00X0oooo0P00000?0?ooo`040000003oool00000000000/0oooo00<00000
0?ooo`3oool01`3oool200000140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`8000001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`4000000@3oool002d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04P3oool100000040oooo000]0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo0P00000;
0?ooo`030000003oool0oooo0140oooo100000080?ooo`030000003oool0oooo00T0oooo0P00000@
0?ooo`030000003oool0oooo008000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool04P3oool200000040oooo0000103oool00000000000000003
0?ooo`<00000103oool010000000oooo0?ooo`3oool500000080oooo0`0000030?ooo`<000000`3o
ool3000000D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`800000503o
ool2000000X0oooo00<000000?ooo`3oool01`3oool200000140oooo00<000000?ooo`3oool00`00
00090?ooo`030000003oool0oooo00P0oooo2@0000090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool2000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool100000040oooo0002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`800000
503oool2000000X0oooo00<000000?ooo`3oool01`3oool200000140oooo00<000000?ooo`3oool0
0`0000080?ooo`030000003oool0oooo00T0oooo0P0000050?ooo`8000002@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo
0@0000010?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`8000003@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`800000
8@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo0P0000070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0180oooo0P0000010?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0100000060?ooo`030000003oool0oooo00<000001@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0C0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`@00000
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`050?ooo`8000008P3oool00`000000oooo0?ooo`060?ooo`8000004P3oool00`000000
oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`0B0?ooo`8000001P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0C0?ooo`4000000@3oool000030?ooo`000000000000@0oooo0P0000090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo0@0000010?oo
o`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo0`0000040?ooo`80
00000P3oool500000080oooo0`0000050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo0P00000C0?ooo`03
0000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo0P00000;0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0180oooo0P0000010?ooo`00;@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`400000
0@3oool002d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0303oool2000000D0oooo0P00000T0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000d0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3o
ool100000040oooo000]0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool2
000002D0oooo0P0000040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo0P0000040?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0180oooo0P0000010?ooo`00;@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01H0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool002d0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo00@000000?oo
o`3oool0oooo0P00000E0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`030000003oool0
oooo01L0oooo0P0000020?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000
000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01@0oooo0@0000010?ooo`00;@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool01@000000oooo0?ooo`3o
ool0000001H0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000J0?ooo`040000
003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01@0oooo0@0000010?ooo`00;@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0000
02P0oooo00<000000?ooo`3oool00P00000F0?ooo`030000003oool0oooo00H0oooo0P0000000`3o
ool000000?ooo`0I0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool00P00000?
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01@0oooo0@0000010?ooo`00;@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?oo
o`040000003oool0oooo000002P0oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0000001X0oooo00@000000?ooo`3oool000003@3oool00`000000oooo
0000000@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01@0oooo0@0000010?ooo`00;@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0>0?ooo`040000003oool00000000002T0oooo00<000000?ooo`0000005`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0000001/0oooo00<000000?ooo`0000003@3oool300000100oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool04`3oool200000040oooo000]0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`000000:P3oool00`000000oooo0000000G0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`0000006`3oool00`000000oooo0000000=0?ooo`8000004@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0D0?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool3000002X0oooo0`00000G
0?ooo`030000003oool0oooo00P0oooo0P00000K0?ooo`<000003@3oool200000140oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0503oool100000040oooo000]0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo0P00000[0?oo
o`800000603oool00`000000oooo0?ooo`080?ooo`800000703oool2000000`0oooo0P00000C0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01<0oooo0P0000010?ooo`00;@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`80
0000:`3oool2000001P0oooo00<000000?ooo`3oool0203oool2000001`0oooo0P00000<0?ooo`80
00004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo0@0000010?ooo`0000@0
oooo00000000000000000`3oool3000000@0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`<0
00000`3oool3000000<0oooo0`0000050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0E0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo04T0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool100000040oooo00020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`190?ooo`050000003oool0
oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo0@00
00010?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0100000060?ooo`030000003oool0oooo00<000001@3oool2000000`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0B@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0D0?ooo`8000000@3oool00080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`@00000
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`190?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01D0oooo0@0000010?ooo`0000<0oooo000000000000103oool2000000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000F@3oool00`000000oooo0?oo
o`190?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01D0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00P0oooo0`0000040?ooo`8000000P3oool500000080oooo0`0000050?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000005T0oooo
00<000000?ooo`3oool0BP3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0503oool200000040oooo000]0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000005T0oooo00<000000?ooo`3o
ool0BP3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05@3oool100000040oooo000]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02@3oool01@000000oooo0?ooo`3oool0000005T0oooo00<000000?ooo`3oool0BP3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool1
00000040oooo000]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool01@00
0000oooo0?ooo`3oool0000005T0oooo00<000000?ooo`3oool0BP3oool010000000oooo0?ooo`00
000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool100000040oooo000]
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00
001I0?ooo`030000003oool0oooo04X0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01@0oooo0P0000010?ooo`00;@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000F@3oool00`000000oooo
0?ooo`1:0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0F0?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0:0?ooo`040000003oool0oooo000005T0oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool100000040
oooo000]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0000001J0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`0000002`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01H0oooo0@0000010?ooo`00;@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000FP3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0F0?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0B`3oool2000000/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`8000000@3oool002d0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000005X0oooo00<000000?oo
o`3oool0B`3oool2000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?oo
o`4000000@3oool002d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000005X0oooo00<000000?ooo`3oool0B`3oool2000000/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0F0?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0
B`3oool2000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`400000
0@3oool002d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0000005X0oooo00<000000?ooo`3oool0B`3oool2000000/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0E0?ooo`8000000@3oool000040?ooo`0000000000000000<0oooo0`00
00040?ooo`040000003oool0oooo0?ooo`D000000P3oool3000000<0oooo0`0000030?ooo`<00000
1@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000
FP3oool00`000000oooo0?ooo`1;0?ooo`8000002`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01H0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000<0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02`3oool2000005/0oooo00<000000?ooo`3oool0B`3oool2000000/0
oooo00D000000?ooo`3oool0oooo0000000I0?ooo`4000000@3oool00080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo0P00001K0?ooo`030000003oool0oooo
04/0oooo0P00000<0?ooo`040000003oool0oooo000001T0oooo0@0000010?ooo`000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0100000060?oo
o`030000003oool0oooo00<000001@3oool2000000/0oooo00<000000?ooo`3oool02`3oool20000
05/0oooo00<000000?ooo`3oool0B`3oool2000000`0oooo00@000000?ooo`3oool00000603oool2
00000040oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001@3oool400000080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool2000005/0oooo
00<000000?ooo`3oool0B`3oool2000000`0oooo00@000000?ooo`3oool000006@3oool100000040
oooo00000`3oool00000000000040?ooo`8000002@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo0P00001K0?oo
o`030000003oool0oooo04/0oooo0P00000<0?ooo`040000003oool0oooo000001T0oooo0@000001
0?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo0`0000040?oo
o`8000000P3oool500000080oooo0`0000050?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02`3oool2000005/0oooo00<000000?ooo`3oool0B`3oool2000000`0oooo00@000000?oo
o`3oool00000603oool200000040oooo000]0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02`3oool2000005/0oooo00<000000?ooo`3oool0B`3oool2000000`0oooo00@000000?oo
o`3oool000006@3oool100000040oooo000]0?ooo`030000003oool0oooo0080oooo2@00000=0?oo
o`800000F`3oool00`000000oooo0?ooo`1;0?ooo`800000303oool010000000oooo0?ooo`00000I
0?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool02@3oool2000000d0oooo0P00001K0?oo
o`030000003oool0oooo04/0oooo0P00000<0?ooo`040000003oool0oooo000001T0oooo0@000001
0?ooo`00;@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo05T0oooo00@000000?oo
o`3oool00000603oool200000040oooo000]0?ooo`030000003oool0oooo07D0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0000000J0?ooo`4000000@3oool002d0oooo00<000000?ooo`3o
ool0M@3oool00`000000oooo0?ooo`1J0?ooo`8000006P3oool100000040oooo000]0?ooo`030000
003oool0oooo07D0oooo00<000000?ooo`3oool0FP3oool2000001X0oooo0@0000010?ooo`00;@3o
ool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo05X0oooo0P00000J0?ooo`4000000@3o
ool002d0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1J0?ooo`8000006@3oool2
00000040oooo000]0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0FP3oool20000
01X0oooo0@0000010?ooo`00;@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo05X0
oooo0P00000J0?ooo`4000000@3oool002d0oooo00<000000?ooo`3oool0M@3oool00`000000oooo
0?ooo`1J0?ooo`8000006P3oool100000040oooo000]0?ooo`030000003oool0oooo07D0oooo00<0
00000?ooo`3oool0FP3oool2000001T0oooo0P0000010?ooo`0000@0oooo00000000000000000`3o
ool3000000@0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`<000000`3oool3000000<0oooo
0`0000050?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0FP3oool2000001X0oooo
0@0000010?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool0FP3oool2000001X0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`800000MP3oool00`000000
oooo0?ooo`1J0?ooo`8000006@3oool200000040oooo00020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`04000000H0oooo00<000000?ooo`3oool0
0`0000050?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0MP3oool100000040oooo
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000001@3oool400000080oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo07D0oooo00<000000?ooo`3oool0FP3oool2000001X0oooo0@0000010?oo
o`0000<0oooo000000000000103oool2000000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1J0?ooo`8000006P3oool1
00000040oooo00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool30000
00@0oooo0P0000020?ooo`D000000P3oool3000000D0oooo0P0000080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo0P0000010?ooo`00;@3oool2000000P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool200000040
oooo000]0?oooo8000000@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00=P0
oooo0`0000150?ooo`00f@3oool00`000000oooo0?ooo`140?ooo`00K@3oool00`000000oooo0000
00030?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`<000000P3oool3000000<0oooo0`00
00040?ooo`<000000P3oool3000000030?ooo`00000000000080oooo0P0000080?ooo`D0000000D0
oooo00000000000000000?ooo`0200000080oooo0P0000030?ooo`<000000P3oool3000000030?oo
o`000000000000@000000P3oool5000000<0oooo0P0000040?ooo`030000003oool0oooo04<0oooo
001]0?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000103oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000001P3oool010000000oooo0?ooo`0000050?ooo`050000003oool0
oooo0?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo04<0oooo
001]0?ooo`030000003oool0000000<0oooo0`0000030?ooo`030000003oool000000080oooo1@00
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`D000000P3oool010000000oooo0?ooo`0000020?ooo`<00000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000A03oool006`0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`<000000`3oool2000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`000007
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo00000014
0?ooo`00K03oool01@000000oooo0000003oool000000080oooo0P0000030?ooo`80000000<0oooo
0000000000000P3oool3000000<0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000
00000080oooo0`0000020?ooo`@000000P3oool4000000X0oooo00@000000?ooo`3oool0oooo1000
00020?ooo`@000000`3oool300000080oooo100000030?ooo`@0000000@0oooo0000000000000000
0`3oool400000080oooo0P0000000`3oool00000000000130?ooo`00K03oool01@000000oooo0000
003oool0000001@0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1:0?ooo`00
K03oool600000180oooo1@00000D0?ooo`030000003oool0oooo00P0oooo1@0000080?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1:0?ooo`00o`3o
oolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.6031, 11.2658, 0.0217121, \
9.86396*^-16}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.190438 0.309017 0.00313137 [
[.11912 -0.0125 -6 -9 ]
[.11912 -0.0125 6 0 ]
[.30956 -0.0125 -6 -9 ]
[.30956 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69044 -0.0125 -3 -9 ]
[.69044 -0.0125 3 0 ]
[.88088 -0.0125 -3 -9 ]
[.88088 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07416 -18 -4.5 ]
[-0.0125 .07416 0 4.5 ]
[-0.0125 .15245 -18 -4.5 ]
[-0.0125 .15245 0 4.5 ]
[-0.0125 .23073 -18 -4.5 ]
[-0.0125 .23073 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .3873 -12 -4.5 ]
[-0.0125 .3873 0 4.5 ]
[-0.0125 .46559 -12 -4.5 ]
[-0.0125 .46559 0 4.5 ]
[-0.0125 .54387 -12 -4.5 ]
[-0.0125 .54387 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11912 0 m
.11912 .00625 L
s
[(-2)] .11912 -0.0125 0 1 Mshowa
.30956 0 m
.30956 .00625 L
s
[(-1)] .30956 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69044 0 m
.69044 .00625 L
s
[(1)] .69044 -0.0125 0 1 Mshowa
.88088 0 m
.88088 .00625 L
s
[(2)] .88088 -0.0125 0 1 Mshowa
.125 Mabswid
.15721 0 m
.15721 .00375 L
s
.1953 0 m
.1953 .00375 L
s
.23339 0 m
.23339 .00375 L
s
.27147 0 m
.27147 .00375 L
s
.34765 0 m
.34765 .00375 L
s
.38574 0 m
.38574 .00375 L
s
.42382 0 m
.42382 .00375 L
s
.46191 0 m
.46191 .00375 L
s
.53809 0 m
.53809 .00375 L
s
.57618 0 m
.57618 .00375 L
s
.61426 0 m
.61426 .00375 L
s
.65235 0 m
.65235 .00375 L
s
.72853 0 m
.72853 .00375 L
s
.76661 0 m
.76661 .00375 L
s
.8047 0 m
.8047 .00375 L
s
.84279 0 m
.84279 .00375 L
s
.08104 0 m
.08104 .00375 L
s
.04295 0 m
.04295 .00375 L
s
.00486 0 m
.00486 .00375 L
s
.91896 0 m
.91896 .00375 L
s
.95705 0 m
.95705 .00375 L
s
.99514 0 m
.99514 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07416 m
.00625 .07416 L
s
[(-75)] -0.0125 .07416 1 0 Mshowa
0 .15245 m
.00625 .15245 L
s
[(-50)] -0.0125 .15245 1 0 Mshowa
0 .23073 m
.00625 .23073 L
s
[(-25)] -0.0125 .23073 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .3873 m
.00625 .3873 L
s
[(25)] -0.0125 .3873 1 0 Mshowa
0 .46559 m
.00625 .46559 L
s
[(50)] -0.0125 .46559 1 0 Mshowa
0 .54387 m
.00625 .54387 L
s
[(75)] -0.0125 .54387 1 0 Mshowa
.125 Mabswid
0 .08982 m
.00375 .08982 L
s
0 .10548 m
.00375 .10548 L
s
0 .12113 m
.00375 .12113 L
s
0 .13679 m
.00375 .13679 L
s
0 .16811 m
.00375 .16811 L
s
0 .18376 m
.00375 .18376 L
s
0 .19942 m
.00375 .19942 L
s
0 .21508 m
.00375 .21508 L
s
0 .24639 m
.00375 .24639 L
s
0 .26205 m
.00375 .26205 L
s
0 .2777 m
.00375 .2777 L
s
0 .29336 m
.00375 .29336 L
s
0 .32467 m
.00375 .32467 L
s
0 .34033 m
.00375 .34033 L
s
0 .35599 m
.00375 .35599 L
s
0 .37164 m
.00375 .37164 L
s
0 .40296 m
.00375 .40296 L
s
0 .41862 m
.00375 .41862 L
s
0 .43427 m
.00375 .43427 L
s
0 .44993 m
.00375 .44993 L
s
0 .48124 m
.00375 .48124 L
s
0 .4969 m
.00375 .4969 L
s
0 .51256 m
.00375 .51256 L
s
0 .52821 m
.00375 .52821 L
s
0 .05851 m
.00375 .05851 L
s
0 .04285 m
.00375 .04285 L
s
0 .02719 m
.00375 .02719 L
s
0 .01154 m
.00375 .01154 L
s
0 .55953 m
.00375 .55953 L
s
0 .57518 m
.00375 .57518 L
s
0 .59084 m
.00375 .59084 L
s
0 .6065 m
.00375 .6065 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11912 .61178 m
.11912 .61803 L
s
.30956 .61178 m
.30956 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69044 .61178 m
.69044 .61803 L
s
.88088 .61178 m
.88088 .61803 L
s
.125 Mabswid
.15721 .61428 m
.15721 .61803 L
s
.1953 .61428 m
.1953 .61803 L
s
.23339 .61428 m
.23339 .61803 L
s
.27147 .61428 m
.27147 .61803 L
s
.34765 .61428 m
.34765 .61803 L
s
.38574 .61428 m
.38574 .61803 L
s
.42382 .61428 m
.42382 .61803 L
s
.46191 .61428 m
.46191 .61803 L
s
.53809 .61428 m
.53809 .61803 L
s
.57618 .61428 m
.57618 .61803 L
s
.61426 .61428 m
.61426 .61803 L
s
.65235 .61428 m
.65235 .61803 L
s
.72853 .61428 m
.72853 .61803 L
s
.76661 .61428 m
.76661 .61803 L
s
.8047 .61428 m
.8047 .61803 L
s
.84279 .61428 m
.84279 .61803 L
s
.08104 .61428 m
.08104 .61803 L
s
.04295 .61428 m
.04295 .61803 L
s
.00486 .61428 m
.00486 .61803 L
s
.91896 .61428 m
.91896 .61803 L
s
.95705 .61428 m
.95705 .61803 L
s
.99514 .61428 m
.99514 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07416 m
1 .07416 L
s
.99375 .15245 m
1 .15245 L
s
.99375 .23073 m
1 .23073 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .3873 m
1 .3873 L
s
.99375 .46559 m
1 .46559 L
s
.99375 .54387 m
1 .54387 L
s
.125 Mabswid
.99625 .08982 m
1 .08982 L
s
.99625 .10548 m
1 .10548 L
s
.99625 .12113 m
1 .12113 L
s
.99625 .13679 m
1 .13679 L
s
.99625 .16811 m
1 .16811 L
s
.99625 .18376 m
1 .18376 L
s
.99625 .19942 m
1 .19942 L
s
.99625 .21508 m
1 .21508 L
s
.99625 .24639 m
1 .24639 L
s
.99625 .26205 m
1 .26205 L
s
.99625 .2777 m
1 .2777 L
s
.99625 .29336 m
1 .29336 L
s
.99625 .32467 m
1 .32467 L
s
.99625 .34033 m
1 .34033 L
s
.99625 .35599 m
1 .35599 L
s
.99625 .37164 m
1 .37164 L
s
.99625 .40296 m
1 .40296 L
s
.99625 .41862 m
1 .41862 L
s
.99625 .43427 m
1 .43427 L
s
.99625 .44993 m
1 .44993 L
s
.99625 .48124 m
1 .48124 L
s
.99625 .4969 m
1 .4969 L
s
.99625 .51256 m
1 .51256 L
s
.99625 .52821 m
1 .52821 L
s
.99625 .05851 m
1 .05851 L
s
.99625 .04285 m
1 .04285 L
s
.99625 .02719 m
1 .02719 L
s
.99625 .01154 m
1 .01154 L
s
.99625 .55953 m
1 .55953 L
s
.99625 .57518 m
1 .57518 L
s
.99625 .59084 m
1 .59084 L
s
.99625 .6065 m
1 .6065 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.05453 .58433 Mdot
.08525 .56534 Mdot
.11598 .54636 Mdot
.1467 .52737 Mdot
.17742 .50838 Mdot
.20814 .4894 Mdot
.23886 .47041 Mdot
.26959 .45142 Mdot
.30031 .43243 Mdot
.33103 .41345 Mdot
.36175 .39446 Mdot
.39247 .37547 Mdot
.4232 .35649 Mdot
.45392 .3375 Mdot
.48464 .31851 Mdot
.51536 .29952 Mdot
.54608 .28054 Mdot
.5768 .26155 Mdot
.60753 .24256 Mdot
.63825 .22357 Mdot
.66897 .20459 Mdot
.69969 .1856 Mdot
.73041 .16661 Mdot
.76114 .14763 Mdot
.79186 .12864 Mdot
.82258 .10965 Mdot
.8533 .09066 Mdot
.88402 .07168 Mdot
.91475 .05269 Mdot
.94547 .0337 Mdot
.5 Mabswid
.02381 .60332 m
.05372 .58483 L
.08634 .56467 L
.11698 .54574 L
.14644 .52753 L
.1778 .50815 L
.20799 .48949 L
.24008 .46966 L
.27099 .45055 L
.30073 .43217 L
.33237 .41262 L
.36283 .39379 L
.39213 .37569 L
.42332 .35641 L
.45333 .33786 L
.48525 .31813 L
.51599 .29913 L
.54556 .28086 L
.57703 .26141 L
.60732 .24269 L
.63951 .22279 L
.67053 .20362 L
.70038 .18518 L
.73212 .16556 L
.76269 .14666 L
.79209 .12849 L
.82339 .10915 L
.85351 .09054 L
.88553 .07075 L
.91638 .05168 L
.94605 .03334 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00>`3oool5000002/0oooo0`00000Z0?ooo`800000;@3oool3000002/0oooo1@00000V0?oo
o`00?03oool010000000oooo0?ooo`00000/0?ooo`030000003oool0oooo02P0oooo00@000000?oo
o`3oool00000;@3oool00`000000oooo0?ooo`0[0?ooo`040000003oool0oooo000002H0oooo000e
0?ooo`D000000`3oool00`000000oooo0?ooo`0T0?ooo`D000000`3oool00`000000oooo0?ooo`0X
0?ooo`040000003oool0oooo000002d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0V0?ooo`00?P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02P0oooo00@00000
0?ooo`3oool00000;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02D0oooo000k
0?ooo`050000003oool0oooo0?ooo`000000;03oool00`000000oooo0?ooo`0X0?ooo`040000003o
ool0oooo000002d0oooo00<000000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool0000002H0
oooo000k0?ooo`050000003oool0oooo0?ooo`000000:`3oool2000002X0oooo00@000000?ooo`3o
ool00000;03oool2000002`0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`00?03oool30000
02d0oooo00<000000?ooo`3oool0:@3oool2000002h0oooo00<000000?ooo`3oool0:`3oool30000
02L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000N0?oo
ooP000002P3oool001h0oooo0P0000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0P00000:0?ooo`00
7P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
203oool001h0oooo0P00001i0?ooo`030000003oool0oooo0780oooo0P0000040?ooo`8000002P3o
ool001h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`1_0?ooo`800000203oool00`000000oooo0?ooo`080?ooo`007P3oool2000007T0
oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`070?ooo`8000002P3oool001h0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`1[0?ooo`800000303oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo06T0oooo1000000<0?ooo`030000003oool0oooo00P0oooo000N0?oo
o`800000N@3oool00`000000oooo0?ooo`1W0?ooo`8000003`3oool2000000X0oooo000N0?ooo`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool0I@3oool200000180oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1S0?ooo`800000
503oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo0680oooo0`00000D0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000N@3oool0
0`000000oooo0?ooo`1P0?ooo`8000005P3oool2000000X0oooo000A0?ooo`030000003oool0oooo
0080oooo0`0000050?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0G`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo000A0?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo00090?ooo`D0
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`1L0?ooo`8000006`3oool00`000000oooo0?ooo`080?ooo`00
4P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P00001i0?ooo`030000
003oool0oooo05/0oooo0`00000J0?ooo`8000002P3oool001<0oooo00<000000?ooo`0000000`00
00050?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0F@3oool2000001h0oooo00<0
00000?ooo`3oool0203oool000l0oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1G0?ooo`800000803oool00`000000oooo
0?ooo`080?ooo`003`3oool5000000030?ooo`000000000000<00000103oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`080?ooo`007P3oool2000007T0oooo00<000000?ooo`3oool0E03oool200000280oooo0P00000:
0?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo05<0oooo0`00000S0?oo
o`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0D@3oool2000002H0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`1?0?ooo`800000:03oool00`000000oooo0?ooo`080?ooo`007P3o
ool2000007T0oooo00<000000?ooo`3oool0C@3oool2000002T0oooo0P00000:0?ooo`007P3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo04`0oooo0`00000Z0?ooo`030000003oool0
oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0BP3oool20000
02d0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0203oool001h0oooo
0P00001i0?ooo`030000003oool0oooo04L0oooo0P00000_0?ooo`8000002P3oool001h0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`150?ooo`800000<P3oool00`000000oooo0?oo
o`080?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo04@0oooo0`00000b
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000N@3oool00`000000oooo0?ooo`120?oo
o`800000=03oool2000000X0oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0@03oool2000003L0oooo00<000000?ooo`3oool0203oool00100oooo0`0000040?ooo`800000
1@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`080?ooo`003`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03d0
oooo0P00000j0?ooo`030000003oool0oooo00P0oooo00090?ooo`D000001@3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0080oooo0P00001i0?ooo`030000003oool0oooo03`0
oooo0`00000i0?ooo`8000002P3oool001<0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0>P3oool2000003d0
oooo00<000000?ooo`3oool0203oool000l0oooo100000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0203oool000l0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo00P0oooo000?0?ooo`D000000`3oool2000000D0oooo
0P00001i0?ooo`030000003oool0oooo03H0oooo0P0000100?ooo`8000002P3oool001h0oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`0d0?ooo`@00000@@3oool00`000000oooo0?oo
o`080?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0380oooo0P000015
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool0<03oool2000004L0oooo00<000000?ooo`3oool0203oool001h0oooo0P00001i0?ooo`03
0000003oool0oooo02h0oooo0P0000180?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0]0?ooo`<00000B@3oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02/0oooo0P00001<0?ooo`030000003o
ool0oooo00P0oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000N@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo04`0oooo0P00000:0?ooo`007P3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo02L0oooo0P00001@0?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool09P3oool300000500oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`0T0?ooo`800000D`3oool00`000000oooo0?ooo`080?ooo`007P3oool2000007T0oooo00<00000
0?ooo`3oool08P3oool2000005@0oooo0P00000:0?ooo`003`3oool500000080oooo0`0000050?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo00P0oooo000@0?ooo`060000003oool0oooo0000003oool000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool07`3oool2
000005P0oooo00<000000?ooo`3oool0203oool000T0oooo1@0000030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
01h0oooo0`00001H0?ooo`030000003oool0oooo00P0oooo000B0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool2000007T0oooo00<000000?ooo`3oool0703oool2000005X0
oooo0P00000:0?ooo`003`3oool01P000000oooo0?ooo`3oool000000?ooo`@000001@3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo01X0oooo0P00001M0?ooo`030000003oool0oooo
00P0oooo000?0?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool05`3oool3000005l0oooo00<000000?ooo`3oool0203oool0
0100oooo0`0000020?ooo`D00000103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
01L0oooo0P00001P0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000N@3oool00`000000
oooo0?ooo`0E0?ooo`800000H@3oool2000000X0oooo000N0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00P0oooo
000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool04P3oool2000006D0oooo00<0
00000?ooo`3oool0203oool001h0oooo0P00001i0?ooo`030000003oool0oooo0100oooo0P00001V
0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0?0?oo
o`<00000I`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo00d0oooo0P00001Z0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool02`3oool2000006`0oooo00<000000?ooo`3oool0
203oool001h0oooo0P00001i0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0J`3o
ool2000000X0oooo000N0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0203oool2
000006l0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`070?ooo`<00000K`3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00D0oooo0P00001b0?ooo`030000003oool0oooo00P0
oooo000N0?ooo`800000N@3oool00`000000oooo0?ooo`030?ooo`800000L`3oool2000000X0oooo
000N0?ooo`030000003oool0oooo07P0oooo00@000000?ooo`3oool0oooo0P00001f0?ooo`030000
003oool0oooo00P0oooo000G0?ooo`8000001@3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00<00000MP3oool00`000000oooo0?ooo`080?ooo`005P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo07P0oooo0`00001i0?ooo`030000003oool0oooo00P0oooo000F
0?ooo`040000003oool0oooo000000@0oooon000000:0?ooo`005P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo07H0oooo0`00001k0?ooo`030000003oool0oooo00P0oooo000F
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0M03oool200000080oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`005P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo07<0oooo0`0000020?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0203oool001L0oooo0P0000050?ooo`800000LP3oool2000000D0oooo00<00000
0?ooo`3oool0N03oool2000000X0oooo000N0?ooo`030000003oool0oooo06l0oooo0P0000070?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool0KP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool0K03oool2000000X0oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`080?ooo`007P3oool2000006`0oooo0`00000:0?ooo`030000003o
ool0oooo07P0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`8000003@3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo06D0oooo0`00000@0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0203oool001h0oooo0P00001V0?ooo`8000004@3oool00`000000oooo
0?ooo`1h0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<00000
0?ooo`3oool0HP3oool2000001@0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`1P0?ooo`8000005P3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo00P0oooo000N0?ooo`800000GP3oool3000001P0oooo00<000000?ooo`3o
ool0N03oool2000000X0oooo000?0?ooo`D000000P3oool3000000D0oooo00<000000?ooo`3oool0
G@3oool2000001T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`00403o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1K0?ooo`8000006`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00P0
oooo000A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool2000005/0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1h0?ooo`8000002P3oool00180oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05P0oooo0P00
000N0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool000l0oooo00H00000
0?ooo`3oool0oooo0000003oool4000000D0oooo00<000000?ooo`3oool0EP3oool200000200oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`003`3oool01`000000oooo0?oo
o`3oool000000?ooo`000000203oool00`000000oooo0?ooo`1E0?ooo`<00000803oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00P0oooo000@0?ooo`<000000P3oool5000000@0oooo
0P00001D0?ooo`8000008`3oool00`000000oooo0?ooo`1h0?ooo`8000002P3oool001h0oooo00<0
00000?ooo`3oool0D@3oool2000002D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`080?ooo`007P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1>0?oo
o`800000:03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00P0oooo000N0?ooo`80
0000C@3oool4000002P0oooo00<000000?ooo`3oool0N03oool2000000X0oooo000N0?ooo`030000
003oool0oooo04X0oooo0P00000/0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
203oool001h0oooo00<000000?ooo`3oool0B03oool2000002h0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`160?ooo`800000<03oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000AP3oool30000
0300oooo00<000000?ooo`3oool0N03oool2000000X0oooo000N0?ooo`030000003oool0oooo04<0
oooo0P00000c0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo0P000010
0?ooo`800000=`3oool00`000000oooo0?ooo`1h0?ooo`8000002P3oool00100oooo0`0000040?oo
o`8000001@3oool00`000000oooo0?ooo`0n0?ooo`<00000=`3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo00P0oooo000?0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo03`0oooo0P00000j0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0203oool001<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo0P00000l0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0203oool001<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`800000>P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo07P0oooo0P00000:0?ooo`003`3oool4000000<0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0g0?ooo`800000?`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo00P0oooo000?0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0f0?ooo`<00000?`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo00P0oooo000?0?ooo`D000000`3oool2000000D0oooo00<000000?ooo`3oool0=03oool20000
0480oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`007P3oool2000003<0
oooo0P0000140?ooo`030000003oool0oooo07P0oooo0P00000:0?ooo`007P3oool00`000000oooo
0?ooo`0`0?ooo`800000AP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00P0oooo
000N0?ooo`030000003oool0oooo02l0oooo0`0000160?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0203oool001h0oooo0P00000^0?ooo`800000B@3oool00`000000oooo0?ooo`1h
0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool0:P3oool2000004`0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`00
7P3oool00`000000oooo0?ooo`0X0?ooo`800000CP3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`800000:03oool3000004h0oooo00<000000?ooo`3oool0N03o
ool2000000X0oooo000N0?ooo`030000003oool0oooo02D0oooo0P00001A0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool08`3oool20000
05<0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`080?ooo`007P3oool200000240oooo0P00001F0?ooo`030000003oool0oooo07P0oooo
0P00000:0?ooo`007P3oool00`000000oooo0?ooo`0O0?ooo`<00000EP3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo00P0oooo000A0?ooo`030000003oool0oooo0080oooo0`000005
0?ooo`030000003oool0oooo01d0oooo0P00001I0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool0203oool00140oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0203oool00180oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`8000006P3oool3000005`0oooo00<000000?ooo`3oool0N03oool20000
00X0oooo000B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0I0?ooo`800000G@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00P0
oooo000C0?ooo`030000003oool0000000<000001@3oool00`000000oooo0?ooo`0G0?ooo`800000
G`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00P0oooo000?0?ooo`070000003o
ool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0oooo01D0oooo0P00001Q0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool000l0oooo1@0000000`3oool00000
00000003000000@0oooo0P00000D0?ooo`800000H`3oool00`000000oooo0?ooo`1h0?ooo`800000
2P3oool001h0oooo00<000000?ooo`3oool04@3oool2000006D0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0@0?ooo`<00000I@3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo
00h0oooo0P00001X0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool001h0
oooo0P00000=0?ooo`800000JP3oool00`000000oooo0?ooo`1h0?ooo`8000002P3oool001h0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool02@3oool3000006`0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`08
0?ooo`040000003oool00000000006`0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`080?ooo`007P3oool2000000L0oooo0P00001`0?ooo`030000003oool0oooo07P0oooo0P00000:
0?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0740oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`080?ooo`00
7P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`080?ooo`007P3oool2000007T0oooo00<000000?ooo`3oool0N03o
ool2000000X0oooo000N0?ooo`8000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`8000002P3oool0
01h0oooon000000:0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool3
000008X0oooo00<000000?ooo`3oool0:`3oool3000001D0oooo00<000000?ooo`3oool06P3oool0
0340oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool06@3oool002/0oooo0`0000030?ooo`<00000103oool200000080
oooo1@0000020?ooo`<000000`3oool4000000030?ooo`000000000000<000001`3oool3000000@0
oooo100000030?ooo`8000000P3oool6000000H0oooo100000020?ooo`D0000000<0oooo00000000
00000`0000000`3oool000000000000300000080oooo0`0000020?ooo`<00000103oool300000080
oooo0`000000103oool000000000003oool3000000<0oooo0`0000090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000`3oool4000000<0oooo00<000000?ooo`3oool00P3oool30000
0080oooo1@0000020?ooo`<000000P3oool3000000040?ooo`00000000000?ooo`@000000`3oool2
00000080oooo2P0000050?ooo`030000003oool0oooo01P0oooo000Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000303oool0
0`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000103o
ool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000060?ooo`06
0000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01P0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?oo
o`<00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0`0000030?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`3oool500000080oooo00<000000?ooo`3oool00P3oool500000080oooo00H000000?ooo`3oool0
00000?ooo`0000050?ooo`D00000203oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`0000000P3oool3000000<0oooo00<000000?ooo`0000000P3oool5000000<0oooo00@00000
0?ooo`3oool0oooo1@0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000
oooo0?ooo`0000050?ooo`040000003oool0oooo00000080oooo0`0000050?ooo`030000003oool0
oooo01P0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`<00000
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P00
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo00@0
00000?ooo`3oool000001@3oool01P000000oooo0?ooo`000000oooo000000P0oooo00<000000?oo
o`3oool0603oool002X0oooo00H000000?ooo`3oool0oooo0000003oool400000080oooo10000002
0?ooo`<00000103oool3000000<0oooo0P0000050?ooo`030000003oool0oooo00P0oooo00@00000
0?ooo`3oool000000P3oool2000000<0oooo100000030?ooo`<000002@3oool01@000000oooo0?oo
o`000000oooo00<00000103oool400000080oooo100000020?ooo`<000000P3oool2000000030?oo
o`00000000000080oooo0`0000020?ooo`@000000`3oool3000000<0oooo0`0000090?ooo`030000
003oool0oooo0080oooo1P0000000`3oool00000000000030?ooo`80000000<0oooo000000000000
0P3oool3000000@0oooo00<000000?ooo`3oool00P3oool300000080oooo100000030?ooo`T00000
0`3oool3000000<0oooo100000040?ooo`030000003oool0oooo01P0oooo000Z0?ooo`050000003o
ool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo
00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`00:`3oool3000000T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`<000002@3oool4000000T0
oooo00<000000?ooo`3oool00P3oool2000000X0oooo100000040?ooo`030000003oool0oooo00@0
oooo0P0000040?ooo`800000;P3oool00`000000oooo0?ooo`0H0?ooo`<000005P3oool00`000000
oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`0J0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.27135, -114.306, \
0.0212449, 1.29204}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-1.745595305830854`\), 
                      1.7468145106328996`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-1.745595305830854`\), 
                      1.7468145106328996`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {100.00032360821847`, 
                100.07016847680974`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(RayBoundary \[Rule] {\(-1.745595305830854`\), 
                1.7468145106328996`}\), ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-1.745595305830854`\), 
                      1.7468145106328996`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\)}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-2.5004999500099974`\), 
                      2.5004999500099983`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-2.5004999500099974`\), 
                      2.5004999500099983`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {99.9699980003999`, 
                100.06999800039989`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(RayBoundary \[Rule] {\(-2.5004999500099974`\), 
                2.5004999500099983`}\), ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-2.5004999500099974`\), 
                      2.5004999500099983`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\)}], 
          "}"}]}], "}"}]], "Output",
  CellLabel->"Out[34]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindInterference[wavefront,PlotDomain->{-.1,.1}];", "Input",
  CellLabel->"In[35]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.7619 -0.17879 0.00438363 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08423 -12 -4.5 ]
[-0.0125 .08423 0 4.5 ]
[-0.0125 .1719 -12 -4.5 ]
[-0.0125 .1719 0 4.5 ]
[-0.0125 .25957 -18 -4.5 ]
[-0.0125 .25957 0 4.5 ]
[-0.0125 .34725 -18 -4.5 ]
[-0.0125 .34725 0 4.5 ]
[-0.0125 .43492 -18 -4.5 ]
[-0.0125 .43492 0 4.5 ]
[-0.0125 .52259 -18 -4.5 ]
[-0.0125 .52259 0 4.5 ]
[-0.0125 .61026 -18 -4.5 ]
[-0.0125 .61026 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -66 0 ]
[.5 .63053 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-0.1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.05)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08423 m
.00625 .08423 L
s
[(60)] -0.0125 .08423 1 0 Mshowa
0 .1719 m
.00625 .1719 L
s
[(80)] -0.0125 .1719 1 0 Mshowa
0 .25957 m
.00625 .25957 L
s
[(100)] -0.0125 .25957 1 0 Mshowa
0 .34725 m
.00625 .34725 L
s
[(120)] -0.0125 .34725 1 0 Mshowa
0 .43492 m
.00625 .43492 L
s
[(140)] -0.0125 .43492 1 0 Mshowa
0 .52259 m
.00625 .52259 L
s
[(160)] -0.0125 .52259 1 0 Mshowa
0 .61026 m
.00625 .61026 L
s
[(180)] -0.0125 .61026 1 0 Mshowa
.125 Mabswid
0 .01847 m
.00375 .01847 L
s
0 .04039 m
.00375 .04039 L
s
0 .06231 m
.00375 .06231 L
s
0 .10615 m
.00375 .10615 L
s
0 .12806 m
.00375 .12806 L
s
0 .14998 m
.00375 .14998 L
s
0 .19382 m
.00375 .19382 L
s
0 .21574 m
.00375 .21574 L
s
0 .23766 m
.00375 .23766 L
s
0 .28149 m
.00375 .28149 L
s
0 .30341 m
.00375 .30341 L
s
0 .32533 m
.00375 .32533 L
s
0 .36916 m
.00375 .36916 L
s
0 .39108 m
.00375 .39108 L
s
0 .413 m
.00375 .413 L
s
0 .45684 m
.00375 .45684 L
s
0 .47875 m
.00375 .47875 L
s
0 .50067 m
.00375 .50067 L
s
0 .54451 m
.00375 .54451 L
s
0 .56643 m
.00375 .56643 L
s
0 .58835 m
.00375 .58835 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08423 m
1 .08423 L
s
.99375 .1719 m
1 .1719 L
s
.99375 .25957 m
1 .25957 L
s
.99375 .34725 m
1 .34725 L
s
.99375 .43492 m
1 .43492 L
s
.99375 .52259 m
1 .52259 L
s
.99375 .61026 m
1 .61026 L
s
.125 Mabswid
.99625 .01847 m
1 .01847 L
s
.99625 .04039 m
1 .04039 L
s
.99625 .06231 m
1 .06231 L
s
.99625 .10615 m
1 .10615 L
s
.99625 .12806 m
1 .12806 L
s
.99625 .14998 m
1 .14998 L
s
.99625 .19382 m
1 .19382 L
s
.99625 .21574 m
1 .21574 L
s
.99625 .23766 m
1 .23766 L
s
.99625 .28149 m
1 .28149 L
s
.99625 .30341 m
1 .30341 L
s
.99625 .32533 m
1 .32533 L
s
.99625 .36916 m
1 .36916 L
s
.99625 .39108 m
1 .39108 L
s
.99625 .413 m
1 .413 L
s
.99625 .45684 m
1 .45684 L
s
.99625 .47875 m
1 .47875 L
s
.99625 .50067 m
1 .50067 L
s
.99625 .54451 m
1 .54451 L
s
.99625 .56643 m
1 .56643 L
s
.99625 .58835 m
1 .58835 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Interference Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .07641 m
.03111 .24835 L
.03491 .35552 L
.03907 .46532 L
.04094 .50751 L
.04294 .54548 L
.04392 .56082 L
.04483 .57329 L
.04572 .58339 L
.04655 .59103 L
.04742 .5971 L
.04789 .5995 L
.04838 .60143 L
.04863 .60214 L
.04876 .60245 L
.0489 .60273 L
.04904 .60295 L
.04916 .6031 L
.0494 .60329 L
.04963 .60332 L
.04988 .60319 L
.05011 .60291 L
.05033 .60252 L
.05053 .60204 L
.05074 .60141 L
.05113 .59994 L
.0516 .59767 L
.05202 .59509 L
.05294 .58784 L
.05381 .57896 L
.05564 .55429 L
.05757 .51981 L
.06105 .44043 L
.06819 .24342 L
.07215 .14119 L
.07389 .10328 L
.07579 .06842 L
.07668 .05475 L
.07763 .04224 L
.07845 .03322 L
.07935 .02542 L
.07987 .0218 L
.08036 .01912 L
.08082 .01715 L
.08105 .01638 L
.08131 .0157 L
.08154 .01524 L
.08176 .01495 L
.082 .01476 L
.08223 .01474 L
Mistroke
.08245 .01485 L
.08265 .01507 L
.08286 .01543 L
.0831 .01596 L
.08333 .01664 L
.08359 .01756 L
.08411 .01998 L
.08505 .02611 L
.08613 .03617 L
.08715 .04825 L
.08899 .07645 L
.09096 .11471 L
.09879 .3188 L
.10271 .42659 L
.10633 .51177 L
.10815 .54583 L
.10985 .5712 L
.11078 .58209 L
.11163 .59015 L
.11257 .59689 L
.11306 .59948 L
.11331 .60053 L
.11358 .60149 L
.11384 .6022 L
.11407 .60271 L
.1143 .60305 L
.11453 .60326 L
.11474 .60332 L
.11494 .60326 L
.11516 .60308 L
.11539 .60274 L
.11564 .60222 L
.11591 .60145 L
.1164 .59956 L
.11688 .59709 L
.11732 .59426 L
.11812 .58783 L
.11901 .57881 L
.12079 .55462 L
.1227 .52089 L
.12445 .48365 L
.12839 .38339 L
.13226 .27438 L
.13587 .17686 L
.13764 .13403 L
.13957 .09337 L
.14127 .06363 L
.14306 .03929 L
.14402 .02961 L
.14453 .02543 L
Mistroke
.14507 .02169 L
.14557 .01896 L
.14603 .01705 L
.14625 .01634 L
.14649 .0157 L
.14671 .01525 L
.14692 .01496 L
.14715 .01478 L
.14738 .01474 L
.14761 .01484 L
.14782 .01505 L
.148 .01535 L
.14821 .01579 L
.14862 .01702 L
.14908 .01889 L
.14956 .02151 L
.15044 .02781 L
.15144 .03747 L
.15236 .04864 L
.15445 .08139 L
.15826 .16338 L
.16568 .3669 L
.16941 .46459 L
.17282 .53697 L
.1746 .56544 L
.17551 .57708 L
.17648 .58724 L
.17699 .59163 L
.17745 .59502 L
.17793 .59788 L
.17836 .59999 L
.17887 .6018 L
.17914 .60247 L
.17927 .60274 L
.17942 .60297 L
.17967 .60323 L
.17981 .6033 L
.17994 .60332 L
.18018 .60322 L
.18042 .60298 L
.18066 .60258 L
.18091 .60198 L
.18137 .60044 L
.18182 .59838 L
.18224 .59602 L
.18318 .58893 L
.18417 .57896 L
.18583 .55684 L
.18765 .52536 L
.19135 .44216 L
Mistroke
.1953 .33492 L
.19906 .22946 L
.20313 .12704 L
.20504 .0879 L
.20706 .05453 L
.20878 .03359 L
.20976 .02504 L
.2102 .022 L
.21068 .01933 L
.21116 .01722 L
.21138 .01649 L
.21161 .01583 L
.21176 .01551 L
.21189 .01526 L
.21201 .01507 L
.21215 .01491 L
.21239 .01475 L
.21252 .01473 L
.21264 .01475 L
.21288 .01491 L
.21311 .01522 L
.21331 .01561 L
.21354 .01616 L
.21404 .01791 L
.2145 .02012 L
.21531 .02535 L
.2162 .03311 L
.218 .05497 L
.21991 .08639 L
.22166 .12183 L
.2256 .21937 L
.23308 .42785 L
.23502 .47713 L
.23685 .51801 L
.23864 .55121 L
.24028 .57515 L
.24114 .58491 L
.24206 .59305 L
.2425 .59616 L
.24298 .59888 L
.24325 .60015 L
.2435 .60112 L
.24375 .60194 L
.24399 .60251 L
.24423 .60295 L
.24436 .60312 L
.24449 .60323 L
.24471 .60331 L
.24496 .60324 L
.24509 .60313 L
Mistroke
.24523 .60296 L
.24537 .60271 L
.24551 .60243 L
.24575 .60179 L
.24602 .60092 L
.24653 .5986 L
.24703 .59571 L
.24794 .58847 L
.24881 .57948 L
.24977 .56725 L
.25171 .53548 L
.2552 .45846 L
.2628 .24431 L
.2663 .15057 L
.26828 .10521 L
.27012 .07005 L
.27195 .04291 L
.27298 .03152 L
.27391 .02366 L
.27442 .02037 L
.2749 .018 L
.27517 .01694 L
.27542 .01614 L
.27568 .01549 L
.27582 .01523 L
.27596 .01501 L
.27621 .01478 L
.27635 .01473 L
.27648 .01474 L
.27672 .01488 L
.27684 .01501 L
.27698 .01521 L
.27721 .01567 L
.27745 .01633 L
.2779 .01798 L
.27835 .02022 L
.27884 .02326 L
.27971 .03039 L
.28074 .04156 L
.28168 .05418 L
.28373 .08912 L
.28567 .1305 L
.29293 .32913 L
.2966 .43251 L
.29855 .48156 L
.30065 .52709 L
.30266 .56184 L
.30449 .58493 L
.30537 .59282 L
.30584 .59611 L
Mistroke
.30634 .59895 L
.30658 .60009 L
.30681 .60101 L
.30704 .60176 L
.30725 .60232 L
.30744 .60273 L
.30765 .60305 L
.30786 .60324 L
.30809 .60331 L
.30834 .60321 L
.30856 .60296 L
.30868 .60277 L
.30881 .60252 L
.30908 .60185 L
.30931 .60109 L
.30956 .6001 L
.31002 .59785 L
.31094 .59153 L
.31178 .58368 L
.3137 .55862 L
.31573 .52246 L
.31946 .43471 L
.32293 .33751 L
.33031 .13444 L
.33225 .09243 L
.33435 .05593 L
.33531 .04276 L
.33633 .03147 L
.3372 .02407 L
.33769 .02081 L
.33816 .01838 L
.33839 .01738 L
.33865 .01648 L
.33886 .01586 L
.3391 .01534 L
.33924 .0151 L
.33938 .01493 L
.3395 .01482 L
.33964 .01475 L
.33987 .01475 L
.34 .01482 L
.34012 .01493 L
.34037 .01528 L
.3406 .01577 L
.3408 .01634 L
.34103 .01709 L
.34153 .01931 L
.34199 .02199 L
.3428 .02812 L
.34369 .03697 L
Mistroke
.3455 .06127 L
.34741 .09568 L
.34916 .13393 L
.3531 .23735 L
.35699 .34998 L
.3606 .44955 L
.36409 .52895 L
.36605 .56246 L
.36782 .5847 L
.36874 .59294 L
.36924 .59644 L
.36971 .59907 L
.37011 .60082 L
.37031 .60154 L
.37054 .60218 L
.37078 .60272 L
.37102 .60307 L
.37124 .60326 L
.37145 .60331 L
.37167 .60321 L
.37192 .60295 L
.37215 .60255 L
.37236 .60204 L
.37284 .60038 L
.37309 .59929 L
.37336 .5979 L
.37441 .5905 L
.37538 .58087 L
.37737 .55355 L
.37925 .51903 L
.38276 .43605 L
.39002 .22932 L
.3937 .13348 L
.39565 .09132 L
.39775 .05511 L
.39878 .04126 L
.39976 .03069 L
.40064 .02343 L
.40113 .02028 L
.40159 .01798 L
.40182 .01707 L
.40206 .01626 L
.40229 .01565 L
.40251 .01522 L
.4027 .01495 L
.40291 .01478 L
.40313 .01473 L
.40334 .01481 L
.40358 .01506 L
.4038 .01546 L
Mistroke
.40401 .01594 L
.40423 .0166 L
.40473 .0186 L
.40519 .02107 L
.40607 .02745 L
.40701 .03669 L
.40872 .05941 L
.41075 .09568 L
.41262 .13655 L
.42011 .34339 L
.42389 .44796 L
.42732 .52656 L
.42923 .55997 L
.43103 .58329 L
.43202 .59242 L
.43249 .59582 L
.43293 .59842 L
.4334 .60062 L
.43366 .60152 L
.43393 .60229 L
.43406 .60259 L
.43421 .60286 L
.43435 .60306 L
.43448 .60319 L
.43473 .6033 L
.43486 .60329 L
.43499 .60323 L
.43522 .60301 L
.43543 .60267 L
.43566 .60214 L
.43591 .6014 L
.43642 .59934 L
.43689 .59681 L
.43779 .5902 L
.43864 .5819 L
.44052 .55661 L
.44257 .51938 L
.44632 .43026 L
.4503 .31798 L
.45403 .21092 L
.45744 .12428 L
.4592 .08743 L
.46111 .05486 L
.46216 .04083 L
.46313 .0304 L
.46407 .02285 L
.46459 .01969 L
.46506 .01749 L
.4655 .01601 L
.46575 .01542 L
Mistroke
.46598 .01503 L
.46622 .01479 L
.46645 .01473 L
.46657 .01475 L
.46671 .01483 L
.46695 .0151 L
.46716 .01548 L
.46739 .01603 L
.46786 .01763 L
.46829 .01966 L
.46869 .02205 L
.46968 .02981 L
.47059 .03928 L
.47263 .06845 L
.47448 .10346 L
.4762 .14229 L
.48012 .24642 L
.48749 .45459 L
.48943 .50071 L
.49153 .54271 L
.49249 .55869 L
.49351 .57313 L
.49446 .58422 L
.49533 .5922 L
.49577 .5954 L
.49625 .59829 L
.4967 .60041 L
.49712 .60187 L
.49737 .6025 L
.4976 .60293 L
.49782 .60317 L
.49804 .60329 L
.49816 .6033 L
.4983 .60325 L
.49843 .60315 L
.49856 .60301 L
.49879 .60264 L
.49903 .60208 L
.49926 .60138 L
.49948 .6006 L
.49996 .59836 L
.50084 .59257 L
.50164 .58543 L
.50249 .57595 L
.50427 .55013 L
.50618 .51401 L
.50964 .4311 L
.51742 .2097 L
.52131 .11283 L
.5232 .07533 L
Mistroke
.52492 .04838 L
.52578 .03766 L
.52671 .02829 L
.52714 .0248 L
.52759 .02165 L
.52802 .01924 L
.5284 .01748 L
.52885 .016 L
.52909 .01542 L
.52932 .01504 L
.52953 .01481 L
.52973 .01473 L
.52995 .01476 L
.53018 .01495 L
.53041 .01528 L
.53066 .01582 L
.53089 .01649 L
.5311 .01724 L
.5316 .01949 L
.53213 .02263 L
.53307 .0302 L
.53393 .03921 L
.53585 .06642 L
.53764 .09953 L
.53932 .13685 L
.54658 .33705 L
.55026 .4397 L
.55221 .48796 L
.55431 .53236 L
.55632 .56584 L
.55727 .57824 L
.55815 .58761 L
.55903 .59483 L
.5595 .59776 L
.56 .60021 L
.56022 .60109 L
.56047 .60188 L
.5607 .60247 L
.56092 .60287 L
.56111 .60312 L
.56132 .60327 L
.56154 .60329 L
.56175 .60318 L
.56199 .60289 L
.56211 .60269 L
.56224 .60241 L
.5627 .60108 L
.56295 .60008 L
.56323 .59878 L
.56373 .59589 L
Mistroke
.5647 .5882 L
.5656 .57885 L
.56731 .55517 L
.5691 .52264 L
.57631 .33774 L
.58033 .22183 L
.58398 .12793 L
.5858 .08917 L
.58777 .0553 L
.58868 .04294 L
.58964 .0322 L
.59046 .02501 L
.59093 .02174 L
.59136 .01926 L
.59183 .01717 L
.59208 .01632 L
.59234 .01562 L
.59247 .01536 L
.5926 .01513 L
.59284 .01485 L
.59307 .01473 L
.59328 .01475 L
.59349 .01491 L
.59369 .01517 L
.5939 .01559 L
.59413 .01618 L
.59461 .01787 L
.59504 .01996 L
.59601 .02663 L
.59707 .03684 L
.59898 .06294 L
.60077 .09516 L
.60273 .13834 L
.6067 .24348 L
.61068 .35867 L
.61431 .45786 L
.61611 .50045 L
.61807 .54001 L
.61992 .56942 L
.62081 .58055 L
.62164 .5889 L
.6226 .59627 L
.6231 .5991 L
.62336 .60027 L
.62363 .60131 L
.62388 .60205 L
.6241 .60257 L
.62432 .60295 L
.62453 .60319 L
.62477 .60329 L
Mistroke
.625 .60324 L
.62525 .60301 L
.62538 .60282 L
.62551 .60257 L
.62574 .60204 L
.62597 .60133 L
.62639 .59968 L
.62684 .59734 L
.62733 .59413 L
.62821 .58668 L
.62903 .57783 L
.63102 .54918 L
.63289 .51356 L
.6364 .42905 L
.64367 .22189 L
.64735 .12729 L
.6493 .08615 L
.65038 .06695 L
.6514 .05125 L
.65236 .03891 L
.65341 .02825 L
.65387 .02451 L
.65436 .02118 L
.65482 .01868 L
.65524 .01692 L
.65547 .01618 L
.65571 .01557 L
.65595 .01512 L
.65609 .01494 L
.65622 .01482 L
.65645 .01472 L
.65666 .01477 L
.6569 .01498 L
.65713 .01534 L
.65734 .0158 L
.65756 .01641 L
.65795 .01787 L
.65838 .01992 L
.65884 .02279 L
.65977 .03032 L
.66075 .0408 L
.6625 .06576 L
.66439 .10076 L
.66645 .14727 L
.67412 .36142 L
.67766 .45796 L
.6815 .54163 L
.68253 .55867 L
.68361 .57391 L
.68461 .58531 L
Mistroke
.68554 .59351 L
.68599 .59658 L
.68642 .59896 L
.68665 .60006 L
.68691 .60107 L
.68714 .60182 L
.68736 .60238 L
.6876 .60285 L
.68772 .60303 L
.68786 .60317 L
.688 .60326 L
.68814 .60329 L
.68826 .60327 L
.68839 .60321 L
.68863 .60295 L
.68877 .60274 L
.68889 .6025 L
.68913 .60191 L
.68935 .6012 L
.6898 .59934 L
.69023 .59708 L
.69119 .59006 L
.69212 .58076 L
.69313 .56814 L
.69495 .53889 L
.69661 .50556 L
.70412 .30519 L
.7079 .19754 L
.71134 .11299 L
.71312 .07738 L
.71505 .04704 L
.71612 .03438 L
.71709 .02543 L
.71758 .02199 L
.71803 .01936 L
.7185 .01725 L
.71875 .01639 L
.71902 .01566 L
.71925 .0152 L
.71938 .01501 L
.7195 .01487 L
.71975 .01473 L
.71989 .01473 L
.72002 .01477 L
.72023 .01496 L
.72047 .01532 L
.72071 .01586 L
.72094 .01652 L
.72147 .01864 L
.72195 .02125 L
Mistroke
.72303 .02949 L
.72397 .03926 L
.72499 .05249 L
.72683 .08305 L
.73059 .16719 L
.73457 .27717 L
.74173 .47562 L
.74361 .51782 L
.7454 .55116 L
.74639 .56635 L
.74747 .58009 L
.74844 .58991 L
.74935 .59665 L
.74985 .59939 L
.75031 .60127 L
.75056 .60201 L
.75082 .60263 L
.75095 .60286 L
.7511 .60306 L
.75123 .60319 L
.75135 .60326 L
.7516 .60327 L
.75182 .60314 L
.75206 .60282 L
.75219 .6026 L
.75232 .6023 L
.75255 .60168 L
.75279 .60085 L
.75324 .59891 L
.75367 .5965 L
.75413 .59328 L
.75507 .58495 L
.75676 .56413 L
.7587 .53124 L
.76047 .49421 L
.76443 .39252 L
.76837 .27862 L
.772 .17486 L
.77554 .09102 L
.77732 .05886 L
.77832 .04431 L
.77928 .03308 L
.7802 .02469 L
.78072 .02106 L
.7812 .01842 L
.78161 .01675 L
.78184 .01602 L
.78206 .01548 L
.78228 .01507 L
.78249 .01483 L
Mistroke
.78272 .01472 L
.78296 .01478 L
.78321 .01502 L
.78343 .01541 L
.78356 .01569 L
.78369 .01605 L
.78394 .01684 L
.78441 .01888 L
.78485 .02136 L
.78585 .0292 L
.78691 .0407 L
.78869 .06695 L
.79061 .10401 L
.79407 .18959 L
.80186 .41736 L
.80375 .46765 L
.80576 .51476 L
.80749 .54861 L
.80937 .57674 L
.81039 .58794 L
.81083 .59192 L
.81132 .5956 L
.81175 .59826 L
.81221 .60049 L
.81247 .60145 L
.8127 .60214 L
.81294 .60268 L
.81316 .60303 L
.81335 .60322 L
.81357 .60329 L
.8138 .6032 L
.81401 .60298 L
.81421 .60265 L
.81439 .60224 L
.8148 .60095 L
.81522 .59911 L
.81567 .59651 L
.81659 .58939 L
.81759 .57884 L
.81853 .56631 L
.8203 .53658 L
.82426 .44494 L
.83153 .2329 L
.83522 .13387 L
.83717 .09052 L
.83825 .07024 L
.83927 .05364 L
.84023 .04053 L
.84128 .02919 L
.84175 .02521 L
Mistroke
.84224 .02166 L
.8427 .01899 L
.84312 .01711 L
.84335 .01632 L
.84359 .01565 L
.84383 .01516 L
.84397 .01497 L
.84409 .01483 L
.84433 .01472 L
.84454 .01476 L
.84478 .01497 L
.84501 .01534 L
.84522 .01581 L
.84544 .01645 L
.84583 .01797 L
.84625 .02012 L
.84672 .02312 L
.8477 .03153 L
.84864 .0421 L
.85039 .06839 L
.85227 .10521 L
.85433 .15394 L
.86201 .37557 L
.86556 .4728 L
.86743 .51613 L
.8694 .55375 L
.87041 .56917 L
.87151 .58295 L
.87199 .58792 L
.87251 .59249 L
.873 .59606 L
.87345 .59873 L
.87394 .60094 L
.8742 .60182 L
.87433 .60219 L
.87447 .60252 L
.87471 .60295 L
.87493 .60319 L
.87506 .60326 L
.8752 .60328 L
.87544 .60317 L
.87566 .60293 L
.87589 .6025 L
.87611 .60195 L
.87631 .60132 L
.8768 .59926 L
.87726 .59666 L
.87814 .58999 L
.8791 .58008 L
.88104 .5522 L
Mistroke
.88284 .51785 L
.88453 .47931 L
.89186 .27059 L
.89559 .16499 L
.89756 .11668 L
.89966 .07377 L
.90072 .05616 L
.90171 .04225 L
.90267 .03133 L
.9031 .02738 L
.90356 .02366 L
.90397 .02091 L
.9044 .01852 L
.90465 .01744 L
.90487 .01662 L
.90508 .01598 L
.9053 .01544 L
.90554 .01502 L
.90576 .01479 L
.906 .01472 L
.90613 .01475 L
.90626 .01483 L
.90649 .01511 L
.9067 .0155 L
.90693 .01609 L
.90717 .01688 L
.90766 .01902 L
.90812 .02169 L
.90898 .02837 L
.90991 .03798 L
.91091 .0511 L
.91272 .08145 L
.91438 .11626 L
.92184 .32256 L
.92559 .43121 L
.92901 .51535 L
.9309 .55171 L
.93269 .57791 L
.93367 .58851 L
.93458 .59583 L
.93505 .59868 L
.93558 .60103 L
.93584 .6019 L
.93598 .60227 L
.93612 .6026 L
.93625 .60284 L
.93639 .60304 L
.93664 .60324 L
.93689 .60327 L
.93712 .60312 L
Mistroke
.93723 .60298 L
.93737 .60277 L
.93763 .60219 L
.93787 .6015 L
.93812 .60057 L
.93858 .59841 L
.93905 .59551 L
.9395 .59214 L
.94034 .58422 L
.94223 .55913 L
.94429 .5212 L
.94801 .43062 L
.95198 .31543 L
.95575 .20443 L
.95774 .15123 L
.95984 .10209 L
.96172 .06599 L
.96271 .05041 L
.96378 .03667 L
.96476 .02689 L
.96566 .02043 L
.96609 .01817 L
.96632 .01721 L
.96656 .01635 L
.96677 .01575 L
.967 .01525 L
.96721 .01494 L
.96741 .01476 L
.96763 .01472 L
.96787 .01483 L
.9681 .0151 L
.9683 .01547 L
.96854 .01608 L
.9688 .01693 L
.96927 .019 L
.96976 .02189 L
.97029 .02575 L
.97123 .03467 L
.97289 .05663 L
.97472 .08913 L
.97619 .12072 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[35]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`007P3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000002X0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000;@3oool200000300oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`<00000:P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000/0oooo000M0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool09P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00X0oooo000F0?ooo`D000000P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0240oooo1@0000020?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0Y0?oo
o`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`0:0?ooo`007@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02T0oooo00@000000?ooo`3oool00000;P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00X0oooo000M0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0:03oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000
000/0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000203oool01@000000
oooo0?ooo`000000oooo00@00000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00X0oooo000M0?ooo`040000003oool0oooo000000P0oooo0P00000Z0?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00000_0?ooo`040000003oool0oooo0000
02h0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000002`0oooo
00@000000?ooo`3oool00000203oool2000000`0oooo000N0?ooo`8000002P3oool00`000000oooo
0?ooo`0Y0?ooo`8000002P3oool200000080oooo1@00000/0?ooo`800000<03oool2000000X0oooo
0P0000020?ooo`D00000:@3oool2000000X0oooo00<000000?ooo`3oool02P3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001`0oooon@00000;0?ooo`00703o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`090?ooo`00703oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`8000003P3oool00`00
0000oooo0?ooo`0<0?ooo`8000003P3oool2000000h0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`8000003@3oool2000000L0oooo00<000000?ooo`3oool02@3oool001`0
oooo0P00000B0?ooo`8000003P3oool2000000h0oooo0P00000>0?ooo`8000003P3oool2000000h0
oooo00<000000?ooo`3oool0303oool2000000L0oooo00<000000?ooo`3oool0103oool2000000h0
oooo00<000000?ooo`3oool0303oool2000000h0oooo0P00000=0?ooo`8000003P3oool00`000000
oooo0?ooo`0<0?ooo`8000003@3oool2000000H0oooo0P00000;0?ooo`00703oool00`000000oooo
0?ooo`0A0?ooo`8000003P3oool2000000h0oooo0P00000>0?ooo`8000003P3oool2000000d0oooo
0`00000=0?ooo`8000001`3oool00`000000oooo0?ooo`040?ooo`8000003@3oool2000000h0oooo
0P00000>0?ooo`8000003@3oool2000000h0oooo0P00000=0?ooo`8000003@3oool2000000L0oooo
00<000000?ooo`3oool02@3oool001`0oooo00<000000?ooo`3oool04@3oool2000000h0oooo0P00
000>0?ooo`030000003oool0000000d0oooo0P00000>0?ooo`8000003@3oool00`000000oooo0000
000=0?ooo`8000001`3oool00`000000oooo0?ooo`040?ooo`8000003@3oool00`000000oooo0000
000=0?ooo`8000003P3oool2000000d0oooo0P00000=0?ooo`030000003oool0000000d0oooo0P00
000=0?ooo`8000001`3oool00`000000oooo0?ooo`090?ooo`00703oool00`000000oooo0?ooo`0A
0?ooo`8000003P3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<00000
0?ooo`0000003@3oool2000000d0oooo00<000000?ooo`0000003@3oool2000000L0oooo00<00000
0?ooo`3oool0103oool2000000d0oooo00<000000?ooo`0000003@3oool2000000h0oooo0P00000=
0?ooo`030000003oool0000000`0oooo00<000000?ooo`0000003@3oool2000000d0oooo0P000007
0?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`0000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<000000?oo
o`0000003@3oool2000000d0oooo00<000000?ooo`0000003@3oool2000000L0oooo00<000000?oo
o`3oool0103oool2000000d0oooo00<000000?ooo`0000003@3oool2000000d0oooo00<000000?oo
o`0000003@3oool00`000000oooo0000000<0?ooo`030000003oool0000000d0oooo0P00000=0?oo
o`8000001`3oool00`000000oooo0?ooo`090?ooo`00703oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`03
0000003oool0000000`0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`03
0000003oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000=0?ooo`03
0000003oool0000000d0oooo00<000000?ooo`000000303oool00`000000oooo0000000=0?ooo`03
0000003oool0000000`0oooo00<000000?ooo`000000303oool00`000000oooo0000000=0?ooo`80
00001`3oool00`000000oooo0?ooo`090?ooo`00703oool200000180oooo00<000000?ooo`000000
3@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`000000
303oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`000000
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000d0oooo00<000000?ooo`000000
3@3oool00`000000oooo0000000<0?ooo`030000003oool0000000d0oooo00<000000?ooo`000000
303oool00`000000oooo0000000<0?ooo`030000003oool0000000d0oooo0P0000060?ooo`800000
2`3oool001`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000=0?ooo`030000003o
ool0000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000<0?ooo`030000003o
ool0000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo000000060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000<0?ooo`040000003o
ool0oooo000000`0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000<0?ooo`030000
003oool0000000`0oooo00@000000?ooo`3oool000002`3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
00003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`00
0000303oool00`000000oooo0000000=0?ooo`030000003oool0000000`0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000d0oooo00<000000?oo
o`000000303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00<0
00000?ooo`000000303oool00`000000oooo0000000<0?ooo`040000003oool0oooo000000/0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`090?ooo`00703oool00`000000oooo
0?ooo`0@0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool000003@3oool00`00
0000oooo0000000=0?ooo`030000003oool0000000`0oooo00@000000?ooo`3oool00000303oool0
0`000000oooo0000000<0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`00000<0?ooo`030000003oool0000000`0oooo00@000000?ooo`3oool0
0000303oool010000000oooo0?ooo`00000<0?ooo`030000003oool0000000`0oooo00<000000?oo
o`000000303oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool02@3oool001`0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00
000<0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`000000303oool010000000oooo
0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`000000303oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000303o
ool00`000000oooo0000000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool0
0000303oool00`000000oooo0000000<0?ooo`040000003oool0oooo000000/0oooo00@000000?oo
o`3oool000002`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00T0oooo000L
0?ooo`8000004@3oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000d0oooo
00<000000?ooo`000000303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo0000
00`0oooo00<000000?ooo`000000303oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool00000303oool00`000000oooo0000000<0?ooo`040000003o
ool0oooo000000`0oooo00@000000?ooo`3oool00000303oool00`000000oooo0000000<0?ooo`04
0000003oool0oooo000000/0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`00
00050?ooo`8000002`3oool001`0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00
000<0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`000000303oool010000000oooo
0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`000000303oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000303o
ool00`000000oooo0000000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool0
0000303oool00`000000oooo0000000<0?ooo`040000003oool0oooo000000/0oooo00@000000?oo
o`3oool000002`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00T0oooo000L
0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool00000303oool01@000000oooo0?oo
o`3oool0000000`0oooo00<000000?ooo`000000303oool010000000oooo0?ooo`00000<0?ooo`04
0000003oool0oooo000000`0oooo00<000000?ooo`000000303oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000303oool00`000000oooo0000
000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool00`000000
oooo0000000<0?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool000002`3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo00T0oooo000>0?ooo`<00000103oool2
000000D0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000<0?ooo`050000003o
ool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool00000303o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00002`3oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@00000
0?ooo`3oool00000303oool00`000000oooo0000000<0?ooo`040000003oool0oooo000000/0oooo
00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
00T0oooo000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00
000<0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000/0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000`0oooo00@000000?oo
o`3oool00000303oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000`0oooo
00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool02@3oool000d0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo000000@0oooo0`0000030?ooo`030000003oool0oooo00X0oooo00@0
00000?ooo`3oool00000303oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`00
000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000002`3oool01@000000oooo0?ooo`3oool0
000000/0oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000;0?ooo`040000
003oool0oooo000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo
000000/0oooo00@000000?ooo`3oool00000103oool3000000/0oooo000=0?ooo`@000000`3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3o
ool010000000oooo0?ooo`00000<0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000
oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0
oooo000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000;0?ooo`050000003oool0oooo
0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool00000
2`3oool01@000000oooo0?ooo`3oool0000000X0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`040000003oool0oooo000000/0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`090?ooo`003@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000`0oooo
00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@00
0000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000002`3oool01@000000oooo0?oo
o`3oool0000000/0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`00000;
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool02@3oool000h0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`00000<0?ooo`050000003oool0oooo0?ooo`00
00002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3o
ool010000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000
oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo00T0oooo000?0?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000002`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`05
0000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`00000;0?ooo`050000003oool0
oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000
oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`09
0?ooo`00703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?oo
o`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo0000
00/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo
0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo
0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000X0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo00T0oooo000L0?ooo`800000103oool00`000000oooo0?ooo`0:0?ooo`05
0000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool010000000oooo
0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`000000
2P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`8000002`3oool001`0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo
0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo
0?ooo`0000002`3oool010000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0
000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`000000
2P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000X0oooo
00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000/0oooo
00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@00
0000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo00T0oooo000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool0
1@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?oo
o`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000
003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000002`3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000/0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo
0?ooo`3oool0000000/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`00
703oool2000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`050000
003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000
003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?oo
o`3oool01P3oool2000000/0oooo000L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`00
00002P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`00703oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool001`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool00000
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo
0?ooo`0000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000L0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000003oool0
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`090?ooo`00703oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool001`0oooo0P0000050?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo00L0oooo0P00000;0?ooo`00703oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool00000
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool001`0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo000>0?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000=0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`003@3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool00000103oool3000000@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool3000000/0oooo000>0?ooo`<000000`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`003@3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool00000
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool000d0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
000>0?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`00703oool2000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool2000000/0oooo000L0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`00703oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool001`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`00703oool2000000H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool2000000/0oooo
000L0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`00703o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool001`0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`00703oool2000000H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool2000000/0oooo000L0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`00703oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool000P0oooo0`0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00090?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool000T0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0`0000050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo0`00000;0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool000P0oooo0P0000040?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00090?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool001`0oooo0P0000060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`8000002`3oool001`0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`00703oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool001`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`00703oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
000L0?ooo`8000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`8000002`3oool001`0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`00703oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo000L0?ooo`8000001`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`8000002`3oool001`0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`00203oool300000080oooo1@00
00030?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool000T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`<000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`<000002`3oool000T0oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool000T0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool000P0oooo
0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`002@3oool00`00
0000oooo0?ooo`020?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`00703oool2000000L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool2000000/0oooo000L0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`00703oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02@3oool001`0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00L000000?ooo`3oool0oooo0000
003oool0000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`070000003oool0oooo0?ooo`000000oooo000000090?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00
703oool2000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`070000
003oool0oooo0?ooo`000000oooo000000090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02@3oool2000000/0oooo000L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`070000003oool0oooo0?ooo`000000oooo00000009
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`00703oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool01`000000oooo0?ooo`3oool000000?ooo`0000002@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool001`0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo0000003oool0
00002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00H000000?ooo`3oool000000?ooo`0000090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00703oool2000000P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo0000
003oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo0P00000;
0?ooo`00703oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool01P000000oooo0?ooo`000000oooo000000T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`060000003oool0
oooo0000003oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool000P0oooo0`0000040?ooo`<000000`3oool2000000D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00H0
00000?ooo`3oool000000?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo0000
003oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool000T0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`040000003oool0
oooo000000@0oooo0`0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool01P000000oooo0?ooo`000000oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`<000002`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo
0000003oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3oool000000?ooo`0000090?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00
203oool2000000D0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3o
ool000000?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P000005
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`060000003oool0oooo0000003oool000002@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool001`0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3oool000000?ooo`0000090?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00703oool20000
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo
0000003oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo0P00000;0?ooo`00703o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool01P000000oooo0?ooo`000000oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`060000003oool0oooo0000003oool000002P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
1@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool001`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3oool00000
0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`00703oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01P00
0000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo000L0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3o
ool000000?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000
003oool0oooo0?ooo`000000303oool2000000/0oooo000L0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002`3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`060000003oool0oooo0000003oool000002P3oool01@000000oooo0?ooo`3oool0000000/0
oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
1@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool02@3oool001`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`050000003oool0
oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`090?oo
o`00703oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002`3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3o
ool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`00
00002P3oool01P000000oooo0?ooo`000000oooo000000X0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo00T0oooo000L0?ooo`03
0000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo
0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`06
0000003oool0oooo0000003oool000002P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`030000003oool0oooo00T0oooo000L0?ooo`8000002@3oool01@000000oooo0?ooo`3oool0
000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000
oooo0?ooo`3oool0000000X0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`050000003o
ool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002`3oool01000
0000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?oo
o`3oool0000000`0oooo0P00000;0?ooo`00703oool00`000000oooo0?ooo`080?ooo`050000003o
ool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3o
ool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`00
00002P3oool01P000000oooo0?ooo`000000oooo000000X0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000X0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000/0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo
0?ooo`090?ooo`00703oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000
2`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`00000;0?ooo`050000003o
ool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000X0oooo00H000000?ooo`3o
ool000000?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?oo
o`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?oo
o`0000002`3oool010000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000002P3o
ool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool02@3oool000P0oooo0`00
00030?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0203oool01@000000oooo0?oo
o`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?oo
o`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000002`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`06
0000003oool0oooo0000003oool000002P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000
oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000002`3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo00T0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool00000
00/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000002`3oool01@000000
oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`060000003oool0
oooo0000003oool000002P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3o
ool0000000/0oooo00@000000?ooo`3oool000002`3oool01@000000oooo0?ooo`3oool0000000X0
oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo00T0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000
oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000002`3oool01@000000oooo0?ooo`3o
ool0000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`060000003oool0oooo0000003o
ool000002P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000/0
oooo00@000000?ooo`3oool000002`3oool01@000000oooo0?ooo`3oool0000000X0oooo00D00000
0?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo00T0oooo00090?ooo`040000003oool0
oooo0?ooo`@000000`3oool010000000oooo0?ooo`0000040?ooo`<00000203oool01@000000oooo
0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo
0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool00000
2`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`050000003oool000000?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000
oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000002`3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`<000002`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0203oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo
00@000000?ooo`3oool000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`050000003oool000000?ooo`0000002P3oool01@000000oooo0?oo
o`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo0000
00/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000/0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000
oooo0?ooo`090?ooo`00203oool2000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0000003o
ool0000000X0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`00
00002`3oool010000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool0
10000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool01@000000oooo
0?ooo`3oool0000000d0oooo00<000000?ooo`3oool02@3oool000T0oooo00<000000?ooo`3oool0
0`3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0
000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000/0oooo
00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01000
0000oooo00000000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?oo
o`00000<0?ooo`040000003oool0oooo000000/0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`040000003oool0oooo000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003o
ool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`090?ooo`00703oool00`000000oooo0?oo
o`080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool01@000000
oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0
oooo000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000`0
oooo00@000000?ooo`00000000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00@00000
0?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000/0
oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`00000;0?ooo`050000003oool0
oooo0?ooo`0000003@3oool00`000000oooo0?ooo`090?ooo`00703oool2000000T0oooo00@00000
0?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000/0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`000000
00002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool00000303oool0
10000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool0
00002`3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000d0oooo0P00000;
0?ooo`00703oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000`0oooo00@00000
0?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?ooo`050000003oool0oooo0?ooo`00
00002`3oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000/0oooo00@00000
0?ooo`3oool00000303oool010000000oooo00000000000;0?ooo`050000003oool0oooo0?ooo`00
00002`3oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@00000
0?ooo`3oool000002`3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000/0
oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`090?ooo`00703oool00`000000
oooo0?ooo`080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool000003@3oool0
0`000000oooo0000000<0?ooo`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?oo
o`00000<0?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool00000303oool01000
0000oooo00000000000<0?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool00000
303oool010000000oooo0?ooo`00000<0?ooo`030000003oool0000000`0oooo00@000000?ooo`3o
ool000002`3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000h0oooo00<0
00000?ooo`3oool02@3oool001`0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00
000<0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`000000303oool010000000oooo
0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool000002`3oool0
10000000oooo0?ooo`00000<0?ooo`040000003oool00000000000`0oooo00@000000?ooo`3oool0
0000303oool00`000000oooo0000000<0?ooo`040000003oool0oooo000000`0oooo00<000000?oo
o`000000303oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000/0oooo00@0
00000?ooo`3oool000003P3oool00`000000oooo0?ooo`090?ooo`00703oool00`000000oooo0?oo
o`080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool000003@3oool00`000000
oooo0000000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool0
10000000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`000000
0000303oool010000000oooo0?ooo`00000<0?ooo`030000003oool0000000`0oooo00@000000?oo
o`3oool00000303oool00`000000oooo0000000<0?ooo`040000003oool0oooo000000/0oooo00@0
00000?ooo`3oool000002`3oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo00T0
oooo000L0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000003@3oool00`000000
oooo0000000=0?ooo`030000003oool0000000`0oooo00@000000?ooo`3oool00000303oool01000
0000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool00000
303oool010000000oooo00000000000<0?ooo`040000003oool0oooo000000`0oooo00<000000?oo
o`000000303oool010000000oooo0?ooo`00000<0?ooo`030000003oool0000000`0oooo00@00000
0?ooo`3oool00000303oool00`000000oooo0000000;0?ooo`040000003oool0oooo000000h0oooo
00<000000?ooo`3oool02@3oool001`0oooo0P0000090?ooo`040000003oool0oooo000000d0oooo
00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000`0oooo
00@000000?ooo`3oool00000303oool00`000000oooo0000000<0?ooo`040000003oool0oooo0000
00`0oooo00@000000?ooo`0000000000303oool010000000oooo0?ooo`00000<0?ooo`030000003o
ool0000000`0oooo00@000000?ooo`3oool00000303oool00`000000oooo0000000<0?ooo`040000
003oool0oooo000000`0oooo00<000000?ooo`000000303oool00`000000oooo0000000=0?ooo`80
00002`3oool001`0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000=0?ooo`03
0000003oool0000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000<0?ooo`04
0000003oool0oooo000000`0oooo00<000000?ooo`000000303oool010000000oooo0?ooo`00000<
0?ooo`040000003oool00000000000`0oooo00<000000?ooo`0000003@3oool00`000000oooo0000
000<0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`000000303oool010000000oooo
0?ooo`00000<0?ooo`030000003oool0000000`0oooo00<000000?ooo`0000003P3oool00`000000
oooo0?ooo`090?ooo`00703oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000d0
oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0
oooo0P00000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`000000303oool010000000
oooo00000000000<0?ooo`030000003oool0000000d0oooo00<000000?ooo`000000303oool00`00
0000oooo0000000=0?ooo`030000003oool0000000`0oooo00<000000?ooo`0000003@3oool00`00
0000oooo0000000<0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool02@3oool001`0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0
oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`8000003@3oool00`000000
oooo0000000=0?ooo`030000003oool0000000d0oooo0`00000<0?ooo`030000003oool0000000d0
oooo00<000000?ooo`000000303oool00`000000oooo0000000=0?ooo`030000003oool0000000`0
oooo00<000000?ooo`0000003@3oool00`000000oooo0000000<0?ooo`030000003oool0000000h0
oooo00<000000?ooo`3oool02@3oool001`0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0000000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo
0000000=0?ooo`8000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo
0P00000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`0000003@3oool2000000d0oooo
00<000000?ooo`0000003@3oool2000000d0oooo00<000000?ooo`000000303oool00`000000oooo
0000000>0?ooo`030000003oool0oooo00T0oooo000L0?ooo`8000002P3oool2000000h0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo0P00
000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`0000003@3oool2000000d0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`8000003@3oool00`000000oooo0000
000=0?ooo`8000003@3oool2000000d0oooo00<000000?ooo`0000003@3oool2000000/0oooo000L
0?ooo`030000003oool0oooo00T0oooo0P00000>0?ooo`030000003oool0000000d0oooo00<00000
0?ooo`0000003@3oool00`000000oooo0000000=0?ooo`8000003P3oool2000000d0oooo00<00000
0?ooo`0000003@3oool2000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=
0?ooo`8000003@3oool00`000000oooo0000000=0?ooo`8000003@3oool2000000d0oooo00<00000
0?ooo`0000003P3oool00`000000oooo0?ooo`090?ooo`00703oool00`000000oooo0?ooo`090?oo
o`8000003P3oool2000000h0oooo0P00000>0?ooo`8000003P3oool2000000h0oooo0P00000=0?oo
o`8000003P3oool2000000h0oooo0P00000=0?ooo`8000003P3oool2000000h0oooo0P00000=0?oo
o`8000003@3oool2000000d0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`090?oo
o`00203oool3000000<0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`80
00003P3oool2000000h0oooo0P00000>0?ooo`8000003P3oool2000000h0oooo0P00000=0?ooo`80
00003P3oool2000000h0oooo0P00000=0?ooo`8000003P3oool2000000h0oooo0P00000=0?ooo`80
00003@3oool2000000h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`00
2@3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo0P00000?0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0303oool20000
00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00T0oooo00090?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo0`00001i0?ooo`030000003oool0oooo07L0oooo0`00000;
0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`<000000`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool000T0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3o
oooi000000/0oooo00080?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool00000o`3oool90?ooo`002@3oool00`000000oooo0?ooo`020?ooo`<00000103o
ool200000?l0oooo2P3oool00?l0oooo8@3oool00=@0oooo0`0000190?ooo`00e@3oool00`000000
oooo0?ooo`180?ooo`00EP3oool5000000050?ooo`00000000000000003oool00P0000020?ooo`80
00000`3oool300000080oooo0`0000030?ooo`D000000P3oool300000080oooo0`0000040?ooo`<0
00000P3oool3000000040?ooo`00000000000?ooo`<000000`3oool3000000P0oooo1@0000001@3o
ool00000000000000000oooo008000000P3oool2000000<0oooo0`0000020?ooo`<0000000<0oooo
000000000000100000020?ooo`D000000`3oool2000000@0oooo00<000000?ooo`3oool0A`3oool0
05P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0
oooo0000003oool000001P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000001P3oool010000000
oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo04L0oooo001H0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`D000000P3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`D00000
0P3oool01P000000oooo0?ooo`000000oooo000000D0oooo1@0000090?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`D000000P3oool0
10000000oooo0?ooo`0000020?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000B03oool005P0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000020?ooo`8000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool00P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000000L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000004P0oooo001H0?oo
o`040000003oool0oooo0?ooo`@000000P3oool4000000<0oooo0`0000020?ooo`80000000<0oooo
0000000000000P3oool400000080oooo0`0000020?ooo`80000000<0oooo0000000000000P3oool3
00000080oooo100000030?ooo`<000000`3oool3000000X0oooo00@000000?ooo`3oool0oooo1000
00020?ooo`@000000`3oool300000080oooo100000030?ooo`@0000000@0oooo0000000000000000
0`3oool400000080oooo0P0000000`3oool00000000000170?ooo`00F03oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0CP3oool005H0oooo1@000008
0?ooo`030000003oool0oooo0140oooo0P00000[0?ooo`D00000203oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0CP3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.129558, 29.6271, \
0.000849628, 0.922944}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3", "Subsubsection",
  CellTags->{"AOG0.", "6.2.3", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell["\<\
This example shows how to create each wave-front separately and interfere \
them together afterwards.\
\>", "Text",
  AspectRatioFixed->True,
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(outerradius =  .5\ 106\)], "Input",
  CellLabel->"In[36]:=",
  AspectRatioFixed->True,
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[BoxData[
    \(53.`\)], "Output",
  CellLabel->"Out[36]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]
}, Open  ]],

Cell[BoxData[
    \(\(Piston = 
        ComponentRendering[{Move[
              CylindricalLensSurface[40, {1.9999\ 40, 120}, 
                ComponentMedium \[Rule] FusedSilica, PlotPoints \[Rule] 50], 
              outerradius - 40], 
            CylindricalLensSurface[outerradius, {1.999\ outerradius, 120}, 
              ComponentMedium \[Rule] FusedSilica, PlotPoints \[Rule] 50]}, 
          Labels \[Rule] {"\<\>"}, PlotPoints \[Rule] 50];\)\)], "Input",
  CellLabel->"In[37]:=",
  AspectRatioFixed->True,
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[BoxData[{
    \(\(Clear[H, L1, L2, CL];\)\), "\n", 
    \(\(H = Window[{5. \ 25.4, 4\ 25.4}, 1.5, "\<H\>"];\)\), "\n", 
    \(\(L1 = 
        PlanoConvexLens[450, 145, 15.5, "\<L1\>", 
          CurvatureDirection \[Rule] Back];\)\), "\n", 
    \(\(L2 = 
        PlanoConvexLens[450, 145, 15.5, "\<L2\>", 
          CurvatureDirection \[Rule] Back];\)\), "\n", 
    \(\(CL = 
        PlanoConvexCylindricalLens[100, {50, 60}, 8.89, "\<CL\>", 
          CurvatureDirection \[Rule] Back];\)\)}], "Input",
  CellLabel->"In[38]:=",
  AspectRatioFixed->True,
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[BoxData[
    \(\(reference\  = \ 
        Move[WedgeOfRays[7. , WaveLength \[Rule]  .532], {422, 0}, 
          180];\)\)], "Input",
  CellLabel->"In[61]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[BoxData[
    \(\(HOE = 
        Move[{Window[60, 1.5, "\<HOE\>"], 
            Move[CircleGraphic[{57, 85}], {\(-1.5\), 5.5}], 
            CircleGraphic[4]}, {0, 
            0}, \(-\((ArcTan[\(-30. \), 48. ] - ArcTan[\(-45. \), 28. ])\)\)/
            Degree];\)\)], "Input",
  CellLabel->"In[65]:=",
  AspectRatioFixed->True,
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[BoxData[{
    \(\(in = 24.5;\)\), "\n", 
    \(\(mm = 1;\)\), "\n", 
    \(\(L = 
        PlanoConvexLens[100, 25, 5, CurvatureDirection -> Back];\)\), "\n", 
    \(\(M = Mirror[1\ in, 6, GraphicDesign \[Rule] Solid];\)\)}], "Input",
  CellLabel->"In[45]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell["\<\
planesource = {Move[WedgeOfRays[10],{-640+115,185}],
\t\t\tMove[L,{-640+115+100,185}],
\t\t\tMoveReflected[M,{-640+115+100,185},{-640+115+100+100,185},{-425,0}],
\t\t\tMoveReflected[M,{-640+115+100,185},{-640+115+100+100+75,185},{-425,0}]};\
\
\>", "Input",
  CellLabel->"In[49]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell["\<\
planesource = {Move[WedgeOfRays[10],{-640+115,185}],
\t\t\tMove[L,{-640+115+100,185}],
\t\t\tMoveReflected[M,{-640+115+100,185},{-640+115+100+100+75,185},{-425,0}]};\
\
\>", "Input",
  CellLabel->"In[50]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell["\<\
sys1 = Flatten[{planesource,
\t\t\tMove[HOE,-425,MoveRelative->False]}];\
\>", "Input",
  CellLabel->"In[66]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell["\<\
sys2 = {\treference,
\t\t\tMove[Piston,20],
\t\t\tMove[{Move[Baffle[{25,120},Labels\[Rule]\"\"],{0,.5 65+12.5}],
\t\t\tMove[Baffle[{25,120},Labels\[Rule]\"\"],{0,-.5 65-12.5}]},5],
\t\t\tMove[H,-4.5],
\t\t\tMove[L1,-30,180],
\t\t\tMove[L2,-80],
\t\t\tMove[CL,-375],
\t\t\tMove[HOE,-425,MoveRelative->False]};\
\>", "Input",
  CellLabel->"In[69]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(imagingoptics = 
        DrawSystem[{sys1, sys2}, PlotType \[Rule] TopView, 
          PlotPoints \[Rule] 50];\)\)], "Input",
  CellLabel->"In[70]:=",
  AspectRatioFixed->True,
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .31202 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.551793 0.00100568 0.104842 0.00100568 [
[.17913 .05017 -6 -4.5 ]
[.17913 .05017 6 4.5 ]
[.3177 .25827 -3 -4.5 ]
[.3177 .25827 3 4.5 ]
[.54802 .01648 -3 -4.5 ]
[.54802 .01648 3 4.5 ]
[.51383 .20225 -6 -4.5 ]
[.51383 .20225 6 4.5 ]
[.12689 .25382 -3 -4.5 ]
[.12689 .25382 3 4.5 ]
[.47913 .00743 -6 -4.5 ]
[.47913 .00743 6 4.5 ]
[.14911 .05608 -12 -4.5 ]
[.14911 .05608 12 4.5 ]
[.14911 .05608 -12 -4.5 ]
[.14911 .05608 12 4.5 ]
[ 0 0 0 0 ]
[ 1 .31202 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.12438 .27832 m
.12787 .27832 L
.12816 .27958 L
.12438 .27958 L
.12438 .27832 L
F
.12438 .27958 m
.12816 .27958 L
.12843 .28084 L
.12438 .28084 L
.12438 .27958 L
F
.12438 .28084 m
.12843 .28084 L
.12866 .28209 L
.12438 .28209 L
.12438 .28084 L
F
.12438 .28209 m
.12866 .28209 L
.12886 .28335 L
.12438 .28335 L
.12438 .28209 L
F
.12438 .28335 m
.12886 .28335 L
.12903 .28461 L
.12438 .28461 L
.12438 .28335 L
F
.12438 .28461 m
.12903 .28461 L
.12916 .28586 L
.12438 .28586 L
.12438 .28461 L
F
.12438 .28586 m
.12916 .28586 L
.12927 .28712 L
.12438 .28712 L
.12438 .28586 L
F
.12438 .28712 m
.12927 .28712 L
.12935 .28838 L
.12438 .28838 L
.12438 .28712 L
F
.12438 .28838 m
.12935 .28838 L
.12939 .28964 L
.12438 .28964 L
.12438 .28838 L
F
.12438 .28964 m
.12939 .28964 L
.12941 .29089 L
.12438 .29089 L
.12438 .28964 L
F
.12438 .29089 m
.12941 .29089 L
.12939 .29215 L
.12438 .29215 L
.12438 .29089 L
F
.12438 .29215 m
.12939 .29215 L
.12935 .29341 L
.12438 .29341 L
.12438 .29215 L
F
.12438 .29341 m
.12935 .29341 L
.12927 .29466 L
.12438 .29466 L
.12438 .29341 L
F
.12438 .29466 m
.12927 .29466 L
.12916 .29592 L
.12438 .29592 L
.12438 .29466 L
F
.12438 .29592 m
.12916 .29592 L
.12903 .29718 L
.12438 .29718 L
.12438 .29592 L
F
.12438 .29718 m
.12903 .29718 L
.12886 .29844 L
.12438 .29844 L
.12438 .29718 L
F
.12438 .29844 m
.12886 .29844 L
.12866 .29969 L
.12438 .29969 L
.12438 .29844 L
F
.12438 .29969 m
.12866 .29969 L
.12843 .30095 L
.12438 .30095 L
.12438 .29969 L
F
.12438 .30095 m
.12843 .30095 L
.12816 .30221 L
.12438 .30221 L
.12438 .30095 L
F
.12438 .30221 m
.12816 .30221 L
.12787 .30346 L
.12438 .30346 L
.12438 .30221 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.12438 .27832 m
.12438 .27958 L
.12438 .28084 L
.12438 .28209 L
.12438 .28335 L
.12438 .28461 L
.12438 .28586 L
.12438 .28712 L
.12438 .28838 L
.12438 .28964 L
.12438 .29089 L
.12438 .29215 L
.12438 .29341 L
.12438 .29466 L
.12438 .29592 L
.12438 .29718 L
.12438 .29844 L
.12438 .29969 L
.12438 .30095 L
.12438 .30221 L
.12438 .30346 L
.12787 .30346 L
.12816 .30221 L
.12843 .30095 L
.12866 .29969 L
.12886 .29844 L
.12903 .29718 L
.12916 .29592 L
.12927 .29466 L
.12935 .29341 L
.12939 .29215 L
.12941 .29089 L
.12939 .28964 L
.12935 .28838 L
.12927 .28712 L
.12916 .28586 L
.12903 .28461 L
.12886 .28335 L
.12866 .28209 L
.12843 .28084 L
.12816 .27958 L
.12787 .27832 L
.12438 .27832 L
s
.5 g
.12438 .29089 m
.12787 .29089 L
.12816 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12816 .29089 L
.12843 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12843 .29089 L
.12866 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12866 .29089 L
.12886 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12886 .29089 L
.12903 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12903 .29089 L
.12916 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12916 .29089 L
.12927 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12927 .29089 L
.12935 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12935 .29089 L
.12939 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12939 .29089 L
.12941 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12941 .29089 L
.12939 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12939 .29089 L
.12935 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12935 .29089 L
.12927 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12927 .29089 L
.12916 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12916 .29089 L
.12903 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12903 .29089 L
.12886 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12886 .29089 L
.12866 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12866 .29089 L
.12843 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12843 .29089 L
.12816 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12816 .29089 L
.12787 .29089 L
.12438 .29089 L
.12438 .29089 L
F
0 g
.12438 .29089 m
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12787 .29089 L
.12816 .29089 L
.12843 .29089 L
.12866 .29089 L
.12886 .29089 L
.12903 .29089 L
.12916 .29089 L
.12927 .29089 L
.12935 .29089 L
.12939 .29089 L
.12941 .29089 L
.12939 .29089 L
.12935 .29089 L
.12927 .29089 L
.12916 .29089 L
.12903 .29089 L
.12886 .29089 L
.12866 .29089 L
.12843 .29089 L
.12816 .29089 L
.12787 .29089 L
.12438 .29089 L
s
.12438 .30346 m
.12787 .30346 L
.12787 .30343 L
.12438 .30343 L
.12438 .30346 L
s
.12438 .30343 m
.12787 .30343 L
.12787 .30331 L
.12438 .30331 L
.12438 .30343 L
s
.12438 .30331 m
.12787 .30331 L
.12787 .30312 L
.12438 .30312 L
.12438 .30331 L
s
.12438 .30312 m
.12787 .30312 L
.12787 .30285 L
.12438 .30285 L
.12438 .30312 L
s
.12438 .30285 m
.12787 .30285 L
.12787 .30251 L
.12438 .30251 L
.12438 .30285 L
s
.12438 .30251 m
.12787 .30251 L
.12787 .30209 L
.12438 .30209 L
.12438 .30251 L
s
.12438 .30209 m
.12787 .30209 L
.12787 .30161 L
.12438 .30161 L
.12438 .30209 L
s
.12438 .30161 m
.12787 .30161 L
.12787 .30106 L
.12438 .30106 L
.12438 .30161 L
s
.12438 .30106 m
.12787 .30106 L
.12787 .30045 L
.12438 .30045 L
.12438 .30106 L
s
.12438 .30045 m
.12787 .30045 L
.12787 .29978 L
.12438 .29978 L
.12438 .30045 L
s
.12438 .29978 m
.12787 .29978 L
.12787 .29906 L
.12438 .29906 L
.12438 .29978 L
s
.12438 .29906 m
.12787 .29906 L
.12787 .29828 L
.12438 .29828 L
.12438 .29906 L
s
.12438 .29828 m
.12787 .29828 L
.12787 .29746 L
.12438 .29746 L
.12438 .29828 L
s
.12438 .29746 m
.12787 .29746 L
.12787 .2966 L
.12438 .2966 L
.12438 .29746 L
s
.12438 .2966 m
.12787 .2966 L
.12787 .2957 L
.12438 .2957 L
.12438 .2966 L
s
.12438 .2957 m
.12787 .2957 L
.12787 .29478 L
.12438 .29478 L
.12438 .2957 L
s
.12438 .29478 m
.12787 .29478 L
.12787 .29383 L
.12438 .29383 L
.12438 .29478 L
s
.12438 .29383 m
.12787 .29383 L
.12787 .29286 L
.12438 .29286 L
.12438 .29383 L
s
.12438 .29286 m
.12787 .29286 L
.12787 .29188 L
.12438 .29188 L
.12438 .29286 L
s
.12438 .29188 m
.12787 .29188 L
.12787 .29089 L
.12438 .29089 L
.12438 .29188 L
s
.12438 .29089 m
.12787 .29089 L
.12787 .28991 L
.12438 .28991 L
.12438 .29089 L
s
.12438 .28991 m
.12787 .28991 L
.12787 .28893 L
.12438 .28893 L
.12438 .28991 L
s
.12438 .28893 m
.12787 .28893 L
.12787 .28796 L
.12438 .28796 L
.12438 .28893 L
s
.12438 .28796 m
.12787 .28796 L
.12787 .28701 L
.12438 .28701 L
.12438 .28796 L
s
.12438 .28701 m
.12787 .28701 L
.12787 .28608 L
.12438 .28608 L
.12438 .28701 L
s
.12438 .28608 m
.12787 .28608 L
.12787 .28519 L
.12438 .28519 L
.12438 .28608 L
s
.12438 .28519 m
.12787 .28519 L
.12787 .28432 L
.12438 .28432 L
.12438 .28519 L
s
.12438 .28432 m
.12787 .28432 L
.12787 .2835 L
.12438 .2835 L
.12438 .28432 L
s
.12438 .2835 m
.12787 .2835 L
.12787 .28273 L
.12438 .28273 L
.12438 .2835 L
s
.12438 .28273 m
.12787 .28273 L
.12787 .282 L
.12438 .282 L
.12438 .28273 L
s
.12438 .282 m
.12787 .282 L
.12787 .28133 L
.12438 .28133 L
.12438 .282 L
s
.12438 .28133 m
.12787 .28133 L
.12787 .28072 L
.12438 .28072 L
.12438 .28133 L
s
.12438 .28072 m
.12787 .28072 L
.12787 .28017 L
.12438 .28017 L
.12438 .28072 L
s
.12438 .28017 m
.12787 .28017 L
.12787 .27969 L
.12438 .27969 L
.12438 .28017 L
s
.12438 .27969 m
.12787 .27969 L
.12787 .27928 L
.12438 .27928 L
.12438 .27969 L
s
.12438 .27928 m
.12787 .27928 L
.12787 .27894 L
.12438 .27894 L
.12438 .27928 L
s
.12438 .27894 m
.12787 .27894 L
.12787 .27867 L
.12438 .27867 L
.12438 .27894 L
s
.12438 .27867 m
.12787 .27867 L
.12787 .27848 L
.12438 .27848 L
.12438 .27867 L
s
.12438 .27848 m
.12787 .27848 L
.12787 .27836 L
.12438 .27836 L
.12438 .27848 L
s
.12438 .27836 m
.12787 .27836 L
.12787 .27832 L
.12438 .27832 L
.12438 .27836 L
s
.12438 .27832 m
.12787 .27832 L
.12787 .27836 L
.12438 .27836 L
.12438 .27832 L
s
.12438 .27836 m
.12787 .27836 L
.12787 .27848 L
.12438 .27848 L
.12438 .27836 L
s
.12438 .27848 m
.12787 .27848 L
.12787 .27867 L
.12438 .27867 L
.12438 .27848 L
s
.12438 .27867 m
.12787 .27867 L
.12787 .27894 L
.12438 .27894 L
.12438 .27867 L
s
.12438 .27894 m
.12787 .27894 L
.12787 .27928 L
.12438 .27928 L
.12438 .27894 L
s
.12438 .27928 m
.12787 .27928 L
.12787 .27969 L
.12438 .27969 L
.12438 .27928 L
s
.12438 .27969 m
.12787 .27969 L
.12787 .28017 L
.12438 .28017 L
.12438 .27969 L
s
.12438 .28017 m
.12787 .28017 L
.12787 .28072 L
.12438 .28072 L
.12438 .28017 L
s
.12438 .28072 m
.12787 .28072 L
.12787 .28133 L
.12438 .28133 L
.12438 .28072 L
s
.12438 .28133 m
.12787 .28133 L
.12787 .282 L
.12438 .282 L
.12438 .28133 L
s
.12438 .282 m
.12787 .282 L
.12787 .28273 L
.12438 .28273 L
.12438 .282 L
s
.12438 .28273 m
.12787 .28273 L
.12787 .2835 L
.12438 .2835 L
.12438 .28273 L
s
.12438 .2835 m
.12787 .2835 L
.12787 .28432 L
.12438 .28432 L
.12438 .2835 L
s
.12438 .28432 m
.12787 .28432 L
.12787 .28519 L
.12438 .28519 L
.12438 .28432 L
s
.12438 .28519 m
.12787 .28519 L
.12787 .28608 L
.12438 .28608 L
.12438 .28519 L
s
.12438 .28608 m
.12787 .28608 L
.12787 .28701 L
.12438 .28701 L
.12438 .28608 L
s
.12438 .28701 m
.12787 .28701 L
.12787 .28796 L
.12438 .28796 L
.12438 .28701 L
s
.12438 .28796 m
.12787 .28796 L
.12787 .28893 L
.12438 .28893 L
.12438 .28796 L
s
.12438 .28893 m
.12787 .28893 L
.12787 .28991 L
.12438 .28991 L
.12438 .28893 L
s
.12438 .28991 m
.12787 .28991 L
.12787 .29089 L
.12438 .29089 L
.12438 .28991 L
s
.12438 .29089 m
.12787 .29089 L
.12787 .29188 L
.12438 .29188 L
.12438 .29089 L
s
.12438 .29188 m
.12787 .29188 L
.12787 .29286 L
.12438 .29286 L
.12438 .29188 L
s
.12438 .29286 m
.12787 .29286 L
.12787 .29383 L
.12438 .29383 L
.12438 .29286 L
s
.12438 .29383 m
.12787 .29383 L
.12787 .29478 L
.12438 .29478 L
.12438 .29383 L
s
.12438 .29478 m
.12787 .29478 L
.12787 .2957 L
.12438 .2957 L
.12438 .29478 L
s
.12438 .2957 m
.12787 .2957 L
.12787 .2966 L
.12438 .2966 L
.12438 .2957 L
s
.12438 .2966 m
.12787 .2966 L
.12787 .29746 L
.12438 .29746 L
.12438 .2966 L
s
.12438 .29746 m
.12787 .29746 L
.12787 .29828 L
.12438 .29828 L
.12438 .29746 L
s
.12438 .29828 m
.12787 .29828 L
.12787 .29906 L
.12438 .29906 L
.12438 .29828 L
s
.12438 .29906 m
.12787 .29906 L
.12787 .29978 L
.12438 .29978 L
.12438 .29906 L
s
.12438 .29978 m
.12787 .29978 L
.12787 .30045 L
.12438 .30045 L
.12438 .29978 L
s
.12438 .30045 m
.12787 .30045 L
.12787 .30106 L
.12438 .30106 L
.12438 .30045 L
s
.12438 .30106 m
.12787 .30106 L
.12787 .30161 L
.12438 .30161 L
.12438 .30106 L
s
.12438 .30161 m
.12787 .30161 L
.12787 .30209 L
.12438 .30209 L
.12438 .30161 L
s
.12438 .30209 m
.12787 .30209 L
.12787 .30251 L
.12438 .30251 L
.12438 .30209 L
s
.12438 .30251 m
.12787 .30251 L
.12787 .30285 L
.12438 .30285 L
.12438 .30251 L
s
.12438 .30285 m
.12787 .30285 L
.12787 .30312 L
.12438 .30312 L
.12438 .30285 L
s
.12438 .30312 m
.12787 .30312 L
.12787 .30331 L
.12438 .30331 L
.12438 .30312 L
s
.12438 .30331 m
.12787 .30331 L
.12787 .30343 L
.12438 .30343 L
.12438 .30331 L
s
.12438 .30343 m
.12787 .30343 L
.12787 .30346 L
.12438 .30346 L
.12438 .30343 L
s
.5 g
.30037 .29089 m
.29988 .29202 L
.29989 .29202 L
.30037 .29089 L
.30037 .29089 L
F
.29988 .29202 m
.2994 .29316 L
.2994 .29315 L
.29989 .29202 L
.29988 .29202 L
F
.2994 .29316 m
.29891 .29429 L
.29891 .29428 L
.2994 .29315 L
.2994 .29316 L
F
.29891 .29429 m
.29842 .29542 L
.29843 .29541 L
.29891 .29428 L
.29891 .29429 L
F
.29842 .29542 m
.29794 .29655 L
.29794 .29653 L
.29843 .29541 L
.29842 .29542 L
F
.29794 .29655 m
.29745 .29768 L
.29746 .29766 L
.29794 .29653 L
.29794 .29655 L
F
.29745 .29768 m
.29696 .29881 L
.29697 .29879 L
.29746 .29766 L
.29745 .29768 L
F
.29696 .29881 m
.29647 .29995 L
.29649 .29992 L
.29697 .29879 L
.29696 .29881 L
F
.29647 .29995 m
.29599 .30108 L
.296 .30105 L
.29649 .29992 L
.29647 .29995 L
F
.29599 .30108 m
.2955 .30221 L
.29552 .30217 L
.296 .30105 L
.29599 .30108 L
F
.30037 .29089 m
.29989 .29202 L
.29989 .29201 L
.30037 .29089 L
.30037 .29089 L
F
.29989 .29202 m
.2994 .29315 L
.29941 .29313 L
.29989 .29201 L
.29989 .29202 L
F
.2994 .29315 m
.29891 .29428 L
.29893 .29425 L
.29941 .29313 L
.2994 .29315 L
F
.29891 .29428 m
.29843 .29541 L
.29845 .29536 L
.29893 .29425 L
.29891 .29428 L
F
.29843 .29541 m
.29794 .29653 L
.29797 .29648 L
.29845 .29536 L
.29843 .29541 L
F
.29794 .29653 m
.29746 .29766 L
.29748 .2976 L
.29797 .29648 L
.29794 .29653 L
F
.29746 .29766 m
.29697 .29879 L
.297 .29872 L
.29748 .2976 L
.29746 .29766 L
F
.29697 .29879 m
.29649 .29992 L
.29652 .29983 L
.297 .29872 L
.29697 .29879 L
F
.29649 .29992 m
.296 .30105 L
.29604 .30095 L
.29652 .29983 L
.29649 .29992 L
F
.296 .30105 m
.29552 .30217 L
.29556 .30207 L
.29604 .30095 L
.296 .30105 L
F
.30037 .29089 m
.29989 .29201 L
.2999 .29199 L
.30037 .29089 L
.30037 .29089 L
F
.29989 .29201 m
.29941 .29313 L
.29942 .29309 L
.2999 .29199 L
.29989 .29201 L
F
.29941 .29313 m
.29893 .29425 L
.29895 .29419 L
.29942 .29309 L
.29941 .29313 L
F
.29893 .29425 m
.29845 .29536 L
.29848 .29529 L
.29895 .29419 L
.29893 .29425 L
F
.29845 .29536 m
.29797 .29648 L
.298 .29639 L
.29848 .29529 L
.29845 .29536 L
F
.29797 .29648 m
.29748 .2976 L
.29753 .29749 L
.298 .29639 L
.29797 .29648 L
F
.29748 .2976 m
.297 .29872 L
.29706 .2986 L
.29753 .29749 L
.29748 .2976 L
F
.297 .29872 m
.29652 .29983 L
.29658 .2997 L
.29706 .2986 L
.297 .29872 L
F
.29652 .29983 m
.29604 .30095 L
.29611 .3008 L
.29658 .2997 L
.29652 .29983 L
F
.29604 .30095 m
.29556 .30207 L
.29563 .3019 L
.29611 .3008 L
.29604 .30095 L
F
.30037 .29089 m
.2999 .29199 L
.29991 .29197 L
.30037 .29089 L
.30037 .29089 L
F
.2999 .29199 m
.29942 .29309 L
.29945 .29305 L
.29991 .29197 L
.2999 .29199 L
F
.29942 .29309 m
.29895 .29419 L
.29898 .29412 L
.29945 .29305 L
.29942 .29309 L
F
.29895 .29419 m
.29848 .29529 L
.29852 .2952 L
.29898 .29412 L
.29895 .29419 L
F
.29848 .29529 m
.298 .29639 L
.29806 .29627 L
.29852 .2952 L
.29848 .29529 L
F
.298 .29639 m
.29753 .29749 L
.29759 .29735 L
.29806 .29627 L
.298 .29639 L
F
.29753 .29749 m
.29706 .2986 L
.29713 .29843 L
.29759 .29735 L
.29753 .29749 L
F
.29706 .2986 m
.29658 .2997 L
.29667 .2995 L
.29713 .29843 L
.29706 .2986 L
F
.29658 .2997 m
.29611 .3008 L
.2962 .30058 L
.29667 .2995 L
.29658 .2997 L
F
.29611 .3008 m
.29563 .3019 L
.29574 .30165 L
.2962 .30058 L
.29611 .3008 L
F
.30037 .29089 m
.29991 .29197 L
.29992 .29194 L
.30037 .29089 L
.30037 .29089 L
F
.29991 .29197 m
.29945 .29305 L
.29947 .29298 L
.29992 .29194 L
.29991 .29197 L
F
.29945 .29305 m
.29898 .29412 L
.29902 .29403 L
.29947 .29298 L
.29945 .29305 L
F
.29898 .29412 m
.29852 .2952 L
.29857 .29507 L
.29902 .29403 L
.29898 .29412 L
F
.29852 .2952 m
.29806 .29627 L
.29812 .29612 L
.29857 .29507 L
.29852 .2952 L
F
.29806 .29627 m
.29759 .29735 L
.29767 .29717 L
.29812 .29612 L
.29806 .29627 L
F
.29759 .29735 m
.29713 .29843 L
.29722 .29821 L
.29767 .29717 L
.29759 .29735 L
F
.29713 .29843 m
.29667 .2995 L
.29677 .29926 L
.29722 .29821 L
.29713 .29843 L
F
.29667 .2995 m
.2962 .30058 L
.29632 .3003 L
.29677 .29926 L
.29667 .2995 L
F
.2962 .30058 m
.29574 .30165 L
.29587 .30135 L
.29632 .3003 L
.2962 .30058 L
F
.30037 .29089 m
.29992 .29194 L
.29994 .2919 L
.30037 .29089 L
.30037 .29089 L
F
.29992 .29194 m
.29947 .29298 L
.2995 .29291 L
.29994 .2919 L
.29992 .29194 L
F
.29947 .29298 m
.29902 .29403 L
.29907 .29392 L
.2995 .29291 L
.29947 .29298 L
F
.29902 .29403 m
.29857 .29507 L
.29864 .29493 L
.29907 .29392 L
.29902 .29403 L
F
.29857 .29507 m
.29812 .29612 L
.2982 .29593 L
.29864 .29493 L
.29857 .29507 L
F
.29812 .29612 m
.29767 .29717 L
.29777 .29694 L
.2982 .29593 L
.29812 .29612 L
F
.29767 .29717 m
.29722 .29821 L
.29733 .29795 L
.29777 .29694 L
.29767 .29717 L
F
.29722 .29821 m
.29677 .29926 L
.2969 .29896 L
.29733 .29795 L
.29722 .29821 L
F
.29677 .29926 m
.29632 .3003 L
.29647 .29997 L
.2969 .29896 L
.29677 .29926 L
F
.29632 .3003 m
.29587 .30135 L
.29603 .30098 L
.29647 .29997 L
.29632 .3003 L
F
.30037 .29089 m
.29994 .2919 L
.29996 .29186 L
.30037 .29089 L
.30037 .29089 L
F
.29994 .2919 m
.2995 .29291 L
.29954 .29282 L
.29996 .29186 L
.29994 .2919 L
F
.2995 .29291 m
.29907 .29392 L
.29913 .29379 L
.29954 .29282 L
.2995 .29291 L
F
.29907 .29392 m
.29864 .29493 L
.29871 .29475 L
.29913 .29379 L
.29907 .29392 L
F
.29864 .29493 m
.2982 .29593 L
.2983 .29572 L
.29871 .29475 L
.29864 .29493 L
F
.2982 .29593 m
.29777 .29694 L
.29788 .29668 L
.2983 .29572 L
.2982 .29593 L
F
.29777 .29694 m
.29733 .29795 L
.29746 .29765 L
.29788 .29668 L
.29777 .29694 L
F
.29733 .29795 m
.2969 .29896 L
.29705 .29861 L
.29746 .29765 L
.29733 .29795 L
F
.2969 .29896 m
.29647 .29997 L
.29663 .29958 L
.29705 .29861 L
.2969 .29896 L
F
.29647 .29997 m
.29603 .30098 L
.29622 .30054 L
.29663 .29958 L
.29647 .29997 L
F
.30037 .29089 m
.29996 .29186 L
.29998 .29181 L
.30037 .29089 L
.30037 .29089 L
F
.29996 .29186 m
.29954 .29282 L
.29958 .29272 L
.29998 .29181 L
.29996 .29186 L
F
.29954 .29282 m
.29913 .29379 L
.29919 .29364 L
.29958 .29272 L
.29954 .29282 L
F
.29913 .29379 m
.29871 .29475 L
.2988 .29455 L
.29919 .29364 L
.29913 .29379 L
F
.29871 .29475 m
.2983 .29572 L
.2984 .29547 L
.2988 .29455 L
.29871 .29475 L
F
.2983 .29572 m
.29788 .29668 L
.29801 .29639 L
.2984 .29547 L
.2983 .29572 L
F
.29788 .29668 m
.29746 .29765 L
.29761 .2973 L
.29801 .29639 L
.29788 .29668 L
F
.29746 .29765 m
.29705 .29861 L
.29722 .29822 L
.29761 .2973 L
.29746 .29765 L
F
.29705 .29861 m
.29663 .29958 L
.29682 .29913 L
.29722 .29822 L
.29705 .29861 L
F
.29663 .29958 m
.29622 .30054 L
.29643 .30005 L
.29682 .29913 L
.29663 .29958 L
F
.30037 .29089 m
.29998 .29181 L
.3 .29175 L
.30037 .29089 L
.30037 .29089 L
F
.29998 .29181 m
.29958 .29272 L
.29963 .29261 L
.3 .29175 L
.29998 .29181 L
F
.29958 .29272 m
.29919 .29364 L
.29926 .29347 L
.29963 .29261 L
.29958 .29272 L
F
.29919 .29364 m
.2988 .29455 L
.29889 .29433 L
.29926 .29347 L
.29919 .29364 L
F
.2988 .29455 m
.2984 .29547 L
.29852 .2952 L
.29889 .29433 L
.2988 .29455 L
F
.2984 .29547 m
.29801 .29639 L
.29815 .29606 L
.29852 .2952 L
.2984 .29547 L
F
.29801 .29639 m
.29761 .2973 L
.29778 .29692 L
.29815 .29606 L
.29801 .29639 L
F
.29761 .2973 m
.29722 .29822 L
.29741 .29778 L
.29778 .29692 L
.29761 .2973 L
F
.29722 .29822 m
.29682 .29913 L
.29704 .29864 L
.29741 .29778 L
.29722 .29822 L
F
.29682 .29913 m
.29643 .30005 L
.29667 .2995 L
.29704 .29864 L
.29682 .29913 L
F
.30037 .29089 m
.3 .29175 L
.30003 .29169 L
.30037 .29089 L
.30037 .29089 L
F
.3 .29175 m
.29963 .29261 L
.29968 .29249 L
.30003 .29169 L
.3 .29175 L
F
.29963 .29261 m
.29926 .29347 L
.29934 .29329 L
.29968 .29249 L
.29963 .29261 L
F
.29926 .29347 m
.29889 .29433 L
.29899 .29409 L
.29934 .29329 L
.29926 .29347 L
F
.29889 .29433 m
.29852 .2952 L
.29865 .29489 L
.29899 .29409 L
.29889 .29433 L
F
.29852 .2952 m
.29815 .29606 L
.29831 .29569 L
.29865 .29489 L
.29852 .2952 L
F
.29815 .29606 m
.29778 .29692 L
.29796 .29649 L
.29831 .29569 L
.29815 .29606 L
F
.29778 .29692 m
.29741 .29778 L
.29762 .29729 L
.29796 .29649 L
.29778 .29692 L
F
.29741 .29778 m
.29704 .29864 L
.29727 .29809 L
.29762 .29729 L
.29741 .29778 L
F
.29704 .29864 m
.29667 .2995 L
.29693 .29889 L
.29727 .29809 L
.29704 .29864 L
F
.30037 .29089 m
.30003 .29169 L
.30006 .29163 L
.30037 .29089 L
.30037 .29089 L
F
.30003 .29169 m
.29968 .29249 L
.29974 .29236 L
.30006 .29163 L
.30003 .29169 L
F
.29968 .29249 m
.29934 .29329 L
.29942 .2931 L
.29974 .29236 L
.29968 .29249 L
F
.29934 .29329 m
.29899 .29409 L
.29911 .29383 L
.29942 .2931 L
.29934 .29329 L
F
.29899 .29409 m
.29865 .29489 L
.29879 .29457 L
.29911 .29383 L
.29899 .29409 L
F
.29865 .29489 m
.29831 .29569 L
.29847 .2953 L
.29879 .29457 L
.29865 .29489 L
F
.29831 .29569 m
.29796 .29649 L
.29816 .29604 L
.29847 .2953 L
.29831 .29569 L
F
.29796 .29649 m
.29762 .29729 L
.29784 .29677 L
.29816 .29604 L
.29796 .29649 L
F
.29762 .29729 m
.29727 .29809 L
.29752 .29751 L
.29784 .29677 L
.29762 .29729 L
F
.29727 .29809 m
.29693 .29889 L
.29721 .29824 L
.29752 .29751 L
.29727 .29809 L
F
.30037 .29089 m
.30006 .29163 L
.30009 .29156 L
.30037 .29089 L
.30037 .29089 L
F
.30006 .29163 m
.29974 .29236 L
.2998 .29222 L
.30009 .29156 L
.30006 .29163 L
F
.29974 .29236 m
.29942 .2931 L
.29951 .29289 L
.2998 .29222 L
.29974 .29236 L
F
.29942 .2931 m
.29911 .29383 L
.29923 .29355 L
.29951 .29289 L
.29942 .2931 L
F
.29911 .29383 m
.29879 .29457 L
.29894 .29422 L
.29923 .29355 L
.29911 .29383 L
F
.29879 .29457 m
.29847 .2953 L
.29865 .29488 L
.29894 .29422 L
.29879 .29457 L
F
.29847 .2953 m
.29816 .29604 L
.29837 .29555 L
.29865 .29488 L
.29847 .2953 L
F
.29816 .29604 m
.29784 .29677 L
.29808 .29621 L
.29837 .29555 L
.29816 .29604 L
F
.29784 .29677 m
.29752 .29751 L
.29779 .29688 L
.29808 .29621 L
.29784 .29677 L
F
.29752 .29751 m
.29721 .29824 L
.29751 .29754 L
.29779 .29688 L
.29752 .29751 L
F
.30037 .29089 m
.30009 .29156 L
.30012 .29148 L
.30037 .29089 L
.30037 .29089 L
F
.30009 .29156 m
.2998 .29222 L
.29986 .29208 L
.30012 .29148 L
.30009 .29156 L
F
.2998 .29222 m
.29951 .29289 L
.29961 .29267 L
.29986 .29208 L
.2998 .29222 L
F
.29951 .29289 m
.29923 .29355 L
.29935 .29326 L
.29961 .29267 L
.29951 .29289 L
F
.29923 .29355 m
.29894 .29422 L
.2991 .29385 L
.29935 .29326 L
.29923 .29355 L
F
.29894 .29422 m
.29865 .29488 L
.29884 .29444 L
.2991 .29385 L
.29894 .29422 L
F
.29865 .29488 m
.29837 .29555 L
.29859 .29503 L
.29884 .29444 L
.29865 .29488 L
F
.29837 .29555 m
.29808 .29621 L
.29834 .29562 L
.29859 .29503 L
.29837 .29555 L
F
.29808 .29621 m
.29779 .29688 L
.29808 .29621 L
.29834 .29562 L
.29808 .29621 L
F
.29779 .29688 m
.29751 .29754 L
.29783 .29681 L
.29808 .29621 L
.29779 .29688 L
F
.30037 .29089 m
.30012 .29148 L
.30015 .29141 L
.30037 .29089 L
.30037 .29089 L
F
.30012 .29148 m
.29986 .29208 L
.29993 .29192 L
.30015 .29141 L
.30012 .29148 L
F
.29986 .29208 m
.29961 .29267 L
.29971 .29243 L
.29993 .29192 L
.29986 .29208 L
F
.29961 .29267 m
.29935 .29326 L
.29949 .29295 L
.29971 .29243 L
.29961 .29267 L
F
.29935 .29326 m
.2991 .29385 L
.29927 .29346 L
.29949 .29295 L
.29935 .29326 L
F
.2991 .29385 m
.29884 .29444 L
.29904 .29398 L
.29927 .29346 L
.2991 .29385 L
F
.29884 .29444 m
.29859 .29503 L
.29882 .29449 L
.29904 .29398 L
.29884 .29444 L
F
.29859 .29503 m
.29834 .29562 L
.2986 .295 L
.29882 .29449 L
.29859 .29503 L
F
.29834 .29562 m
.29808 .29621 L
.29838 .29552 L
.2986 .295 L
.29834 .29562 L
F
.29808 .29621 m
.29783 .29681 L
.29816 .29603 L
.29838 .29552 L
.29808 .29621 L
F
.30037 .29089 m
.30015 .29141 L
.30019 .29133 L
.30037 .29089 L
.30037 .29089 L
F
.30015 .29141 m
.29993 .29192 L
.3 .29176 L
.30019 .29133 L
.30015 .29141 L
F
.29993 .29192 m
.29971 .29243 L
.29981 .29219 L
.3 .29176 L
.29993 .29192 L
F
.29971 .29243 m
.29949 .29295 L
.29963 .29263 L
.29981 .29219 L
.29971 .29243 L
F
.29949 .29295 m
.29927 .29346 L
.29944 .29306 L
.29963 .29263 L
.29949 .29295 L
F
.29927 .29346 m
.29904 .29398 L
.29925 .29349 L
.29944 .29306 L
.29927 .29346 L
F
.29904 .29398 m
.29882 .29449 L
.29907 .29392 L
.29925 .29349 L
.29904 .29398 L
F
.29882 .29449 m
.2986 .295 L
.29888 .29436 L
.29907 .29392 L
.29882 .29449 L
F
.2986 .295 m
.29838 .29552 L
.29869 .29479 L
.29888 .29436 L
.2986 .295 L
F
.29838 .29552 m
.29816 .29603 L
.29851 .29522 L
.29869 .29479 L
.29838 .29552 L
F
.30037 .29089 m
.30019 .29133 L
.30022 .29124 L
.30037 .29089 L
.30037 .29089 L
F
.30019 .29133 m
.3 .29176 L
.30007 .29159 L
.30022 .29124 L
.30019 .29133 L
F
.3 .29176 m
.29981 .29219 L
.29992 .29194 L
.30007 .29159 L
.3 .29176 L
F
.29981 .29219 m
.29963 .29263 L
.29977 .29229 L
.29992 .29194 L
.29981 .29219 L
F
.29963 .29263 m
.29944 .29306 L
.29962 .29264 L
.29977 .29229 L
.29963 .29263 L
F
.29944 .29306 m
.29925 .29349 L
.29947 .29299 L
.29962 .29264 L
.29944 .29306 L
F
.29925 .29349 m
.29907 .29392 L
.29932 .29334 L
.29947 .29299 L
.29925 .29349 L
F
.29907 .29392 m
.29888 .29436 L
.29917 .29369 L
.29932 .29334 L
.29907 .29392 L
F
.29888 .29436 m
.29869 .29479 L
.29902 .29404 L
.29917 .29369 L
.29888 .29436 L
F
.29869 .29479 m
.29851 .29522 L
.29887 .29439 L
.29902 .29404 L
.29869 .29479 L
F
.30037 .29089 m
.30022 .29124 L
.30026 .29116 L
.30037 .29089 L
.30037 .29089 L
F
.30022 .29124 m
.30007 .29159 L
.30014 .29142 L
.30026 .29116 L
.30022 .29124 L
F
.30007 .29159 m
.29992 .29194 L
.30003 .29169 L
.30014 .29142 L
.30007 .29159 L
F
.29992 .29194 m
.29977 .29229 L
.29992 .29195 L
.30003 .29169 L
.29992 .29194 L
F
.29977 .29229 m
.29962 .29264 L
.2998 .29221 L
.29992 .29195 L
.29977 .29229 L
F
.29962 .29264 m
.29947 .29299 L
.29969 .29248 L
.2998 .29221 L
.29962 .29264 L
F
.29947 .29299 m
.29932 .29334 L
.29958 .29274 L
.29969 .29248 L
.29947 .29299 L
F
.29932 .29334 m
.29917 .29369 L
.29946 .29301 L
.29958 .29274 L
.29932 .29334 L
F
.29917 .29369 m
.29902 .29404 L
.29935 .29327 L
.29946 .29301 L
.29917 .29369 L
F
.29902 .29404 m
.29887 .29439 L
.29923 .29353 L
.29935 .29327 L
.29902 .29404 L
F
.30037 .29089 m
.30026 .29116 L
.3003 .29107 L
.30037 .29089 L
.30037 .29089 L
F
.30026 .29116 m
.30014 .29142 L
.30022 .29125 L
.3003 .29107 L
.30026 .29116 L
F
.30014 .29142 m
.30003 .29169 L
.30014 .29142 L
.30022 .29125 L
.30014 .29142 L
F
.30003 .29169 m
.29992 .29195 L
.30007 .2916 L
.30014 .29142 L
.30003 .29169 L
F
.29992 .29195 m
.2998 .29221 L
.29999 .29178 L
.30007 .2916 L
.29992 .29195 L
F
.2998 .29221 m
.29969 .29248 L
.29991 .29196 L
.29999 .29178 L
.2998 .29221 L
F
.29969 .29248 m
.29958 .29274 L
.29984 .29213 L
.29991 .29196 L
.29969 .29248 L
F
.29958 .29274 m
.29946 .29301 L
.29976 .29231 L
.29984 .29213 L
.29958 .29274 L
F
.29946 .29301 m
.29935 .29327 L
.29969 .29249 L
.29976 .29231 L
.29946 .29301 L
F
.29935 .29327 m
.29923 .29353 L
.29961 .29266 L
.29969 .29249 L
.29935 .29327 L
F
.30037 .29089 m
.3003 .29107 L
.30033 .29098 L
.30037 .29089 L
.30037 .29089 L
F
.3003 .29107 m
.30022 .29125 L
.3003 .29107 L
.30033 .29098 L
.3003 .29107 L
F
.30022 .29125 m
.30014 .29142 L
.30026 .29116 L
.3003 .29107 L
.30022 .29125 L
F
.30014 .29142 m
.30007 .2916 L
.30022 .29125 L
.30026 .29116 L
.30014 .29142 L
F
.30007 .2916 m
.29999 .29178 L
.30018 .29134 L
.30022 .29125 L
.30007 .2916 L
F
.29999 .29178 m
.29991 .29196 L
.30014 .29143 L
.30018 .29134 L
.29999 .29178 L
F
.29991 .29196 m
.29984 .29213 L
.3001 .29151 L
.30014 .29143 L
.29991 .29196 L
F
.29984 .29213 m
.29976 .29231 L
.30007 .2916 L
.3001 .29151 L
.29984 .29213 L
F
.29976 .29231 m
.29969 .29249 L
.30003 .29169 L
.30007 .2916 L
.29976 .29231 L
F
.29969 .29249 m
.29961 .29266 L
.29999 .29178 L
.30003 .29169 L
.29969 .29249 L
F
.30037 .29089 m
.30033 .29098 L
.30037 .29089 L
.30037 .29089 L
.30037 .29089 L
F
.30033 .29098 m
.3003 .29107 L
.30037 .29089 L
.30037 .29089 L
.30033 .29098 L
F
.3003 .29107 m
.30026 .29116 L
.30037 .29089 L
.30037 .29089 L
.3003 .29107 L
F
.30026 .29116 m
.30022 .29125 L
.30037 .29089 L
.30037 .29089 L
.30026 .29116 L
F
.30022 .29125 m
.30018 .29134 L
.30037 .29089 L
.30037 .29089 L
.30022 .29125 L
F
.30018 .29134 m
.30014 .29143 L
.30037 .29089 L
.30037 .29089 L
.30018 .29134 L
F
.30014 .29143 m
.3001 .29151 L
.30037 .29089 L
.30037 .29089 L
.30014 .29143 L
F
.3001 .29151 m
.30007 .2916 L
.30037 .29089 L
.30037 .29089 L
.3001 .29151 L
F
.30007 .2916 m
.30003 .29169 L
.30037 .29089 L
.30037 .29089 L
.30007 .2916 L
F
.30003 .29169 m
.29999 .29178 L
.30037 .29089 L
.30037 .29089 L
.30003 .29169 L
F
.30037 .29089 m
.30037 .29089 L
.30041 .2908 L
.30037 .29089 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30045 .29072 L
.30041 .2908 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30049 .29063 L
.30045 .29072 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30053 .29054 L
.30049 .29063 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30056 .29045 L
.30053 .29054 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.3006 .29036 L
.30056 .29045 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30064 .29027 L
.3006 .29036 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30068 .29018 L
.30064 .29027 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30072 .29009 L
.30068 .29018 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30075 .29001 L
.30072 .29009 L
.30037 .29089 L
F
.30037 .29089 m
.30041 .2908 L
.30045 .29072 L
.30037 .29089 L
.30037 .29089 L
F
.30041 .2908 m
.30045 .29072 L
.30052 .29054 L
.30045 .29072 L
.30041 .2908 L
F
.30045 .29072 m
.30049 .29063 L
.3006 .29036 L
.30052 .29054 L
.30045 .29072 L
F
.30049 .29063 m
.30053 .29054 L
.30068 .29019 L
.3006 .29036 L
.30049 .29063 L
F
.30053 .29054 m
.30056 .29045 L
.30075 .29001 L
.30068 .29019 L
.30053 .29054 L
F
.30056 .29045 m
.3006 .29036 L
.30083 .28983 L
.30075 .29001 L
.30056 .29045 L
F
.3006 .29036 m
.30064 .29027 L
.30091 .28965 L
.30083 .28983 L
.3006 .29036 L
F
.30064 .29027 m
.30068 .29018 L
.30098 .28948 L
.30091 .28965 L
.30064 .29027 L
F
.30068 .29018 m
.30072 .29009 L
.30106 .2893 L
.30098 .28948 L
.30068 .29018 L
F
.30072 .29009 m
.30075 .29001 L
.30113 .28912 L
.30106 .2893 L
.30072 .29009 L
F
.30037 .29089 m
.30045 .29072 L
.30049 .29063 L
.30037 .29089 L
.30037 .29089 L
F
.30045 .29072 m
.30052 .29054 L
.3006 .29036 L
.30049 .29063 L
.30045 .29072 L
F
.30052 .29054 m
.3006 .29036 L
.30071 .2901 L
.3006 .29036 L
.30052 .29054 L
F
.3006 .29036 m
.30068 .29019 L
.30083 .28984 L
.30071 .2901 L
.3006 .29036 L
F
.30068 .29019 m
.30075 .29001 L
.30094 .28957 L
.30083 .28984 L
.30068 .29019 L
F
.30075 .29001 m
.30083 .28983 L
.30105 .28931 L
.30094 .28957 L
.30075 .29001 L
F
.30083 .28983 m
.30091 .28965 L
.30117 .28904 L
.30105 .28931 L
.30083 .28983 L
F
.30091 .28965 m
.30098 .28948 L
.30128 .28878 L
.30117 .28904 L
.30091 .28965 L
F
.30098 .28948 m
.30106 .2893 L
.3014 .28852 L
.30128 .28878 L
.30098 .28948 L
F
.30106 .2893 m
.30113 .28912 L
.30151 .28825 L
.3014 .28852 L
.30106 .2893 L
F
.30037 .29089 m
.30049 .29063 L
.30052 .29054 L
.30037 .29089 L
.30037 .29089 L
F
.30049 .29063 m
.3006 .29036 L
.30067 .29019 L
.30052 .29054 L
.30049 .29063 L
F
.3006 .29036 m
.30071 .2901 L
.30082 .28984 L
.30067 .29019 L
.3006 .29036 L
F
.30071 .2901 m
.30083 .28984 L
.30097 .28949 L
.30082 .28984 L
.30071 .2901 L
F
.30083 .28984 m
.30094 .28957 L
.30112 .28914 L
.30097 .28949 L
.30083 .28984 L
F
.30094 .28957 m
.30105 .28931 L
.30128 .2888 L
.30112 .28914 L
.30094 .28957 L
F
.30105 .28931 m
.30117 .28904 L
.30143 .28845 L
.30128 .2888 L
.30105 .28931 L
F
.30117 .28904 m
.30128 .28878 L
.30158 .2881 L
.30143 .28845 L
.30117 .28904 L
F
.30128 .28878 m
.3014 .28852 L
.30173 .28775 L
.30158 .2881 L
.30128 .28878 L
F
.3014 .28852 m
.30151 .28825 L
.30188 .2874 L
.30173 .28775 L
.3014 .28852 L
F
.30037 .29089 m
.30052 .29054 L
.30056 .29046 L
.30037 .29089 L
.30037 .29089 L
F
.30052 .29054 m
.30067 .29019 L
.30074 .29003 L
.30056 .29046 L
.30052 .29054 L
F
.30067 .29019 m
.30082 .28984 L
.30093 .28959 L
.30074 .29003 L
.30067 .29019 L
F
.30082 .28984 m
.30097 .28949 L
.30112 .28916 L
.30093 .28959 L
.30082 .28984 L
F
.30097 .28949 m
.30112 .28914 L
.3013 .28873 L
.30112 .28916 L
.30097 .28949 L
F
.30112 .28914 m
.30128 .2888 L
.30149 .2883 L
.3013 .28873 L
.30112 .28914 L
F
.30128 .2888 m
.30143 .28845 L
.30168 .28786 L
.30149 .2883 L
.30128 .2888 L
F
.30143 .28845 m
.30158 .2881 L
.30186 .28743 L
.30168 .28786 L
.30143 .28845 L
F
.30158 .2881 m
.30173 .28775 L
.30205 .287 L
.30186 .28743 L
.30158 .2881 L
F
.30173 .28775 m
.30188 .2874 L
.30224 .28656 L
.30205 .287 L
.30173 .28775 L
F
.30037 .29089 m
.30056 .29046 L
.30059 .29038 L
.30037 .29089 L
.30037 .29089 L
F
.30056 .29046 m
.30074 .29003 L
.30081 .28987 L
.30059 .29038 L
.30056 .29046 L
F
.30074 .29003 m
.30093 .28959 L
.30104 .28935 L
.30081 .28987 L
.30074 .29003 L
F
.30093 .28959 m
.30112 .28916 L
.30126 .28884 L
.30104 .28935 L
.30093 .28959 L
F
.30112 .28916 m
.3013 .28873 L
.30148 .28832 L
.30126 .28884 L
.30112 .28916 L
F
.3013 .28873 m
.30149 .2883 L
.3017 .28781 L
.30148 .28832 L
.3013 .28873 L
F
.30149 .2883 m
.30168 .28786 L
.30192 .2873 L
.3017 .28781 L
.30149 .2883 L
F
.30168 .28786 m
.30186 .28743 L
.30214 .28678 L
.30192 .2873 L
.30168 .28786 L
F
.30186 .28743 m
.30205 .287 L
.30236 .28627 L
.30214 .28678 L
.30186 .28743 L
F
.30205 .287 m
.30224 .28656 L
.30258 .28576 L
.30236 .28627 L
.30205 .287 L
F
.30037 .29089 m
.30059 .29038 L
.30063 .2903 L
.30037 .29089 L
.30037 .29089 L
F
.30059 .29038 m
.30081 .28987 L
.30088 .28971 L
.30063 .2903 L
.30059 .29038 L
F
.30081 .28987 m
.30104 .28935 L
.30114 .28912 L
.30088 .28971 L
.30081 .28987 L
F
.30104 .28935 m
.30126 .28884 L
.30139 .28853 L
.30114 .28912 L
.30104 .28935 L
F
.30126 .28884 m
.30148 .28832 L
.30164 .28794 L
.30139 .28853 L
.30126 .28884 L
F
.30148 .28832 m
.3017 .28781 L
.3019 .28735 L
.30164 .28794 L
.30148 .28832 L
F
.3017 .28781 m
.30192 .2873 L
.30215 .28675 L
.3019 .28735 L
.3017 .28781 L
F
.30192 .2873 m
.30214 .28678 L
.30241 .28616 L
.30215 .28675 L
.30192 .2873 L
F
.30214 .28678 m
.30236 .28627 L
.30266 .28557 L
.30241 .28616 L
.30214 .28678 L
F
.30236 .28627 m
.30258 .28576 L
.30292 .28498 L
.30266 .28557 L
.30236 .28627 L
F
.30037 .29089 m
.30063 .2903 L
.30066 .29023 L
.30037 .29089 L
.30037 .29089 L
F
.30063 .2903 m
.30088 .28971 L
.30094 .28956 L
.30066 .29023 L
.30063 .2903 L
F
.30088 .28971 m
.30114 .28912 L
.30123 .2889 L
.30094 .28956 L
.30088 .28971 L
F
.30114 .28912 m
.30139 .28853 L
.30152 .28823 L
.30123 .2889 L
.30114 .28912 L
F
.30139 .28853 m
.30164 .28794 L
.3018 .28757 L
.30152 .28823 L
.30139 .28853 L
F
.30164 .28794 m
.3019 .28735 L
.30209 .2869 L
.3018 .28757 L
.30164 .28794 L
F
.3019 .28735 m
.30215 .28675 L
.30238 .28624 L
.30209 .2869 L
.3019 .28735 L
F
.30215 .28675 m
.30241 .28616 L
.30266 .28557 L
.30238 .28624 L
.30215 .28675 L
F
.30241 .28616 m
.30266 .28557 L
.30295 .28491 L
.30266 .28557 L
.30241 .28616 L
F
.30266 .28557 m
.30292 .28498 L
.30324 .28424 L
.30295 .28491 L
.30266 .28557 L
F
.30037 .29089 m
.30066 .29023 L
.30069 .29016 L
.30037 .29089 L
.30037 .29089 L
F
.30066 .29023 m
.30094 .28956 L
.301 .28942 L
.30069 .29016 L
.30066 .29023 L
F
.30094 .28956 m
.30123 .2889 L
.30132 .28869 L
.301 .28942 L
.30094 .28956 L
F
.30123 .2889 m
.30152 .28823 L
.30164 .28795 L
.30132 .28869 L
.30123 .2889 L
F
.30152 .28823 m
.3018 .28757 L
.30195 .28722 L
.30164 .28795 L
.30152 .28823 L
F
.3018 .28757 m
.30209 .2869 L
.30227 .28648 L
.30195 .28722 L
.3018 .28757 L
F
.30209 .2869 m
.30238 .28624 L
.30259 .28575 L
.30227 .28648 L
.30209 .2869 L
F
.30238 .28624 m
.30266 .28557 L
.3029 .28501 L
.30259 .28575 L
.30238 .28624 L
F
.30266 .28557 m
.30295 .28491 L
.30322 .28428 L
.3029 .28501 L
.30266 .28557 L
F
.30295 .28491 m
.30324 .28424 L
.30354 .28354 L
.30322 .28428 L
.30295 .28491 L
F
.30037 .29089 m
.30069 .29016 L
.30072 .29009 L
.30037 .29089 L
.30037 .29089 L
F
.30069 .29016 m
.301 .28942 L
.30106 .28929 L
.30072 .29009 L
.30069 .29016 L
F
.301 .28942 m
.30132 .28869 L
.30141 .28849 L
.30106 .28929 L
.301 .28942 L
F
.30132 .28869 m
.30164 .28795 L
.30175 .28769 L
.30141 .28849 L
.30132 .28869 L
F
.30164 .28795 m
.30195 .28722 L
.30209 .28689 L
.30175 .28769 L
.30164 .28795 L
F
.30195 .28722 m
.30227 .28648 L
.30244 .28609 L
.30209 .28689 L
.30195 .28722 L
F
.30227 .28648 m
.30259 .28575 L
.30278 .28529 L
.30244 .28609 L
.30227 .28648 L
F
.30259 .28575 m
.3029 .28501 L
.30313 .28449 L
.30278 .28529 L
.30259 .28575 L
F
.3029 .28501 m
.30322 .28428 L
.30347 .28369 L
.30313 .28449 L
.3029 .28501 L
F
.30322 .28428 m
.30354 .28354 L
.30382 .28289 L
.30347 .28369 L
.30322 .28428 L
F
.30037 .29089 m
.30072 .29009 L
.30074 .29003 L
.30037 .29089 L
.30037 .29089 L
F
.30072 .29009 m
.30106 .28929 L
.30111 .28917 L
.30074 .29003 L
.30072 .29009 L
F
.30106 .28929 m
.30141 .28849 L
.30148 .28831 L
.30111 .28917 L
.30106 .28929 L
F
.30141 .28849 m
.30175 .28769 L
.30185 .28745 L
.30148 .28831 L
.30141 .28849 L
F
.30175 .28769 m
.30209 .28689 L
.30222 .28659 L
.30185 .28745 L
.30175 .28769 L
F
.30209 .28689 m
.30244 .28609 L
.30259 .28573 L
.30222 .28659 L
.30209 .28689 L
F
.30244 .28609 m
.30278 .28529 L
.30297 .28487 L
.30259 .28573 L
.30244 .28609 L
F
.30278 .28529 m
.30313 .28449 L
.30334 .28401 L
.30297 .28487 L
.30278 .28529 L
F
.30313 .28449 m
.30347 .28369 L
.30371 .28315 L
.30334 .28401 L
.30313 .28449 L
F
.30347 .28369 m
.30382 .28289 L
.30408 .28229 L
.30371 .28315 L
.30347 .28369 L
F
.30037 .29089 m
.30074 .29003 L
.30077 .28998 L
.30037 .29089 L
.30037 .29089 L
F
.30074 .29003 m
.30111 .28917 L
.30116 .28906 L
.30077 .28998 L
.30074 .29003 L
F
.30111 .28917 m
.30148 .28831 L
.30155 .28815 L
.30116 .28906 L
.30111 .28917 L
F
.30148 .28831 m
.30185 .28745 L
.30195 .28723 L
.30155 .28815 L
.30148 .28831 L
F
.30185 .28745 m
.30222 .28659 L
.30234 .28632 L
.30195 .28723 L
.30185 .28745 L
F
.30222 .28659 m
.30259 .28573 L
.30274 .2854 L
.30234 .28632 L
.30222 .28659 L
F
.30259 .28573 m
.30297 .28487 L
.30313 .28449 L
.30274 .2854 L
.30259 .28573 L
F
.30297 .28487 m
.30334 .28401 L
.30353 .28357 L
.30313 .28449 L
.30297 .28487 L
F
.30334 .28401 m
.30371 .28315 L
.30392 .28265 L
.30353 .28357 L
.30334 .28401 L
F
.30371 .28315 m
.30408 .28229 L
.30431 .28174 L
.30392 .28265 L
.30371 .28315 L
F
.30037 .29089 m
.30077 .28998 L
.30079 .28993 L
.30037 .29089 L
.30037 .29089 L
F
.30077 .28998 m
.30116 .28906 L
.3012 .28896 L
.30079 .28993 L
.30077 .28998 L
F
.30116 .28906 m
.30155 .28815 L
.30162 .288 L
.3012 .28896 L
.30116 .28906 L
F
.30155 .28815 m
.30195 .28723 L
.30203 .28703 L
.30162 .288 L
.30155 .28815 L
F
.30195 .28723 m
.30234 .28632 L
.30245 .28607 L
.30203 .28703 L
.30195 .28723 L
F
.30234 .28632 m
.30274 .2854 L
.30286 .2851 L
.30245 .28607 L
.30234 .28632 L
F
.30274 .2854 m
.30313 .28449 L
.30328 .28414 L
.30286 .2851 L
.30274 .2854 L
F
.30313 .28449 m
.30353 .28357 L
.3037 .28317 L
.30328 .28414 L
.30313 .28449 L
F
.30353 .28357 m
.30392 .28265 L
.30411 .28221 L
.3037 .28317 L
.30353 .28357 L
F
.30392 .28265 m
.30431 .28174 L
.30453 .28125 L
.30411 .28221 L
.30392 .28265 L
F
.30037 .29089 m
.30079 .28993 L
.30081 .28988 L
.30037 .29089 L
.30037 .29089 L
F
.30079 .28993 m
.3012 .28896 L
.30124 .28888 L
.30081 .28988 L
.30079 .28993 L
F
.3012 .28896 m
.30162 .288 L
.30167 .28787 L
.30124 .28888 L
.3012 .28896 L
F
.30162 .288 m
.30203 .28703 L
.30211 .28686 L
.30167 .28787 L
.30162 .288 L
F
.30203 .28703 m
.30245 .28607 L
.30254 .28585 L
.30211 .28686 L
.30203 .28703 L
F
.30245 .28607 m
.30286 .2851 L
.30298 .28484 L
.30254 .28585 L
.30245 .28607 L
F
.30286 .2851 m
.30328 .28414 L
.30341 .28384 L
.30298 .28484 L
.30286 .2851 L
F
.30328 .28414 m
.3037 .28317 L
.30384 .28283 L
.30341 .28384 L
.30328 .28414 L
F
.3037 .28317 m
.30411 .28221 L
.30428 .28182 L
.30384 .28283 L
.3037 .28317 L
F
.30411 .28221 m
.30453 .28125 L
.30471 .28081 L
.30428 .28182 L
.30411 .28221 L
F
.30037 .29089 m
.30081 .28988 L
.30082 .28985 L
.30037 .29089 L
.30037 .29089 L
F
.30081 .28988 m
.30124 .28888 L
.30127 .2888 L
.30082 .28985 L
.30081 .28988 L
F
.30124 .28888 m
.30167 .28787 L
.30172 .28776 L
.30127 .2888 L
.30124 .28888 L
F
.30167 .28787 m
.30211 .28686 L
.30217 .28671 L
.30172 .28776 L
.30167 .28787 L
F
.30211 .28686 m
.30254 .28585 L
.30262 .28567 L
.30217 .28671 L
.30211 .28686 L
F
.30254 .28585 m
.30298 .28484 L
.30307 .28462 L
.30262 .28567 L
.30254 .28585 L
F
.30298 .28484 m
.30341 .28384 L
.30352 .28358 L
.30307 .28462 L
.30298 .28484 L
F
.30341 .28384 m
.30384 .28283 L
.30397 .28253 L
.30352 .28358 L
.30341 .28384 L
F
.30384 .28283 m
.30428 .28182 L
.30442 .28148 L
.30397 .28253 L
.30384 .28283 L
F
.30428 .28182 m
.30471 .28081 L
.30487 .28044 L
.30442 .28148 L
.30428 .28182 L
F
.30037 .29089 m
.30082 .28985 L
.30084 .28982 L
.30037 .29089 L
.30037 .29089 L
F
.30082 .28985 m
.30127 .2888 L
.3013 .28874 L
.30084 .28982 L
.30082 .28985 L
F
.30127 .2888 m
.30172 .28776 L
.30176 .28766 L
.3013 .28874 L
.30127 .2888 L
F
.30172 .28776 m
.30217 .28671 L
.30223 .28659 L
.30176 .28766 L
.30172 .28776 L
F
.30217 .28671 m
.30262 .28567 L
.30269 .28551 L
.30223 .28659 L
.30217 .28671 L
F
.30262 .28567 m
.30307 .28462 L
.30315 .28444 L
.30269 .28551 L
.30262 .28567 L
F
.30307 .28462 m
.30352 .28358 L
.30362 .28336 L
.30315 .28444 L
.30307 .28462 L
F
.30352 .28358 m
.30397 .28253 L
.30408 .28228 L
.30362 .28336 L
.30352 .28358 L
F
.30397 .28253 m
.30442 .28148 L
.30454 .28121 L
.30408 .28228 L
.30397 .28253 L
F
.30442 .28148 m
.30487 .28044 L
.30501 .28013 L
.30454 .28121 L
.30442 .28148 L
F
.30037 .29089 m
.30084 .28982 L
.30085 .28979 L
.30037 .29089 L
.30037 .29089 L
F
.30084 .28982 m
.3013 .28874 L
.30132 .28869 L
.30085 .28979 L
.30084 .28982 L
F
.3013 .28874 m
.30176 .28766 L
.30179 .28759 L
.30132 .28869 L
.3013 .28874 L
F
.30176 .28766 m
.30223 .28659 L
.30227 .28649 L
.30179 .28759 L
.30176 .28766 L
F
.30223 .28659 m
.30269 .28551 L
.30274 .28539 L
.30227 .28649 L
.30223 .28659 L
F
.30269 .28551 m
.30315 .28444 L
.30321 .28429 L
.30274 .28539 L
.30269 .28551 L
F
.30315 .28444 m
.30362 .28336 L
.30369 .28319 L
.30321 .28429 L
.30315 .28444 L
F
.30362 .28336 m
.30408 .28228 L
.30416 .28209 L
.30369 .28319 L
.30362 .28336 L
F
.30408 .28228 m
.30454 .28121 L
.30464 .28099 L
.30416 .28209 L
.30408 .28228 L
F
.30454 .28121 m
.30501 .28013 L
.30511 .27989 L
.30464 .28099 L
.30454 .28121 L
F
.30037 .29089 m
.30085 .28979 L
.30085 .28978 L
.30037 .29089 L
.30037 .29089 L
F
.30085 .28979 m
.30132 .28869 L
.30133 .28866 L
.30085 .28978 L
.30085 .28979 L
F
.30132 .28869 m
.30179 .28759 L
.30182 .28754 L
.30133 .28866 L
.30132 .28869 L
F
.30179 .28759 m
.30227 .28649 L
.3023 .28642 L
.30182 .28754 L
.30179 .28759 L
F
.30227 .28649 m
.30274 .28539 L
.30278 .28531 L
.3023 .28642 L
.30227 .28649 L
F
.30274 .28539 m
.30321 .28429 L
.30326 .28419 L
.30278 .28531 L
.30274 .28539 L
F
.30321 .28429 m
.30369 .28319 L
.30374 .28307 L
.30326 .28419 L
.30321 .28429 L
F
.30369 .28319 m
.30416 .28209 L
.30422 .28195 L
.30374 .28307 L
.30369 .28319 L
F
.30416 .28209 m
.30464 .28099 L
.3047 .28083 L
.30422 .28195 L
.30416 .28209 L
F
.30464 .28099 m
.30511 .27989 L
.30518 .27972 L
.3047 .28083 L
.30464 .28099 L
F
.30037 .29089 m
.30085 .28978 L
.30086 .28977 L
.30037 .29089 L
.30037 .29089 L
F
.30085 .28978 m
.30133 .28866 L
.30134 .28864 L
.30086 .28977 L
.30085 .28978 L
F
.30133 .28866 m
.30182 .28754 L
.30183 .28751 L
.30134 .28864 L
.30133 .28866 L
F
.30182 .28754 m
.3023 .28642 L
.30231 .28638 L
.30183 .28751 L
.30182 .28754 L
F
.3023 .28642 m
.30278 .28531 L
.3028 .28525 L
.30231 .28638 L
.3023 .28642 L
F
.30278 .28531 m
.30326 .28419 L
.30329 .28412 L
.3028 .28525 L
.30278 .28531 L
F
.30326 .28419 m
.30374 .28307 L
.30377 .283 L
.30329 .28412 L
.30326 .28419 L
F
.30374 .28307 m
.30422 .28195 L
.30426 .28187 L
.30377 .283 L
.30374 .28307 L
F
.30422 .28195 m
.3047 .28083 L
.30474 .28074 L
.30426 .28187 L
.30422 .28195 L
F
.3047 .28083 m
.30518 .27972 L
.30523 .27961 L
.30474 .28074 L
.3047 .28083 L
F
.30037 .29089 m
.30086 .28977 L
.30086 .28976 L
.30037 .29089 L
.30037 .29089 L
F
.30086 .28977 m
.30134 .28864 L
.30135 .28863 L
.30086 .28976 L
.30086 .28977 L
F
.30134 .28864 m
.30183 .28751 L
.30183 .2875 L
.30135 .28863 L
.30134 .28864 L
F
.30183 .28751 m
.30231 .28638 L
.30232 .28637 L
.30183 .2875 L
.30183 .28751 L
F
.30231 .28638 m
.3028 .28525 L
.30281 .28524 L
.30232 .28637 L
.30231 .28638 L
F
.3028 .28525 m
.30329 .28412 L
.3033 .2841 L
.30281 .28524 L
.3028 .28525 L
F
.30329 .28412 m
.30377 .283 L
.30378 .28297 L
.3033 .2841 L
.30329 .28412 L
F
.30377 .283 m
.30426 .28187 L
.30427 .28184 L
.30378 .28297 L
.30377 .283 L
F
.30426 .28187 m
.30474 .28074 L
.30476 .28071 L
.30427 .28184 L
.30426 .28187 L
F
.30474 .28074 m
.30523 .27961 L
.30524 .27958 L
.30476 .28071 L
.30474 .28074 L
F
.30037 .29089 m
.30086 .28976 L
.30086 .28977 L
.30037 .29089 L
.30037 .29089 L
F
.30086 .28976 m
.30135 .28863 L
.30134 .28864 L
.30086 .28977 L
.30086 .28976 L
F
.30135 .28863 m
.30183 .2875 L
.30183 .28751 L
.30134 .28864 L
.30135 .28863 L
F
.30183 .2875 m
.30232 .28637 L
.30231 .28638 L
.30183 .28751 L
.30183 .2875 L
F
.30232 .28637 m
.30281 .28524 L
.3028 .28525 L
.30231 .28638 L
.30232 .28637 L
F
.30281 .28524 m
.3033 .2841 L
.30329 .28412 L
.3028 .28525 L
.30281 .28524 L
F
.3033 .2841 m
.30378 .28297 L
.30377 .283 L
.30329 .28412 L
.3033 .2841 L
F
.30378 .28297 m
.30427 .28184 L
.30426 .28187 L
.30377 .283 L
.30378 .28297 L
F
.30427 .28184 m
.30476 .28071 L
.30474 .28074 L
.30426 .28187 L
.30427 .28184 L
F
.30476 .28071 m
.30524 .27958 L
.30523 .27961 L
.30474 .28074 L
.30476 .28071 L
F
.30037 .29089 m
.30086 .28977 L
.30085 .28978 L
.30037 .29089 L
.30037 .29089 L
F
.30086 .28977 m
.30134 .28864 L
.30133 .28866 L
.30085 .28978 L
.30086 .28977 L
F
.30134 .28864 m
.30183 .28751 L
.30182 .28754 L
.30133 .28866 L
.30134 .28864 L
F
.30183 .28751 m
.30231 .28638 L
.3023 .28642 L
.30182 .28754 L
.30183 .28751 L
F
.30231 .28638 m
.3028 .28525 L
.30278 .28531 L
.3023 .28642 L
.30231 .28638 L
F
.3028 .28525 m
.30329 .28412 L
.30326 .28419 L
.30278 .28531 L
.3028 .28525 L
F
.30329 .28412 m
.30377 .283 L
.30374 .28307 L
.30326 .28419 L
.30329 .28412 L
F
.30377 .283 m
.30426 .28187 L
.30422 .28195 L
.30374 .28307 L
.30377 .283 L
F
.30426 .28187 m
.30474 .28074 L
.3047 .28083 L
.30422 .28195 L
.30426 .28187 L
F
.30474 .28074 m
.30523 .27961 L
.30518 .27972 L
.3047 .28083 L
.30474 .28074 L
F
.30037 .29089 m
.30085 .28978 L
.30085 .28979 L
.30037 .29089 L
.30037 .29089 L
F
.30085 .28978 m
.30133 .28866 L
.30132 .28869 L
.30085 .28979 L
.30085 .28978 L
F
.30133 .28866 m
.30182 .28754 L
.30179 .28759 L
.30132 .28869 L
.30133 .28866 L
F
.30182 .28754 m
.3023 .28642 L
.30227 .28649 L
.30179 .28759 L
.30182 .28754 L
F
.3023 .28642 m
.30278 .28531 L
.30274 .28539 L
.30227 .28649 L
.3023 .28642 L
F
.30278 .28531 m
.30326 .28419 L
.30321 .28429 L
.30274 .28539 L
.30278 .28531 L
F
.30326 .28419 m
.30374 .28307 L
.30369 .28319 L
.30321 .28429 L
.30326 .28419 L
F
.30374 .28307 m
.30422 .28195 L
.30416 .28209 L
.30369 .28319 L
.30374 .28307 L
F
.30422 .28195 m
.3047 .28083 L
.30464 .28099 L
.30416 .28209 L
.30422 .28195 L
F
.3047 .28083 m
.30518 .27972 L
.30511 .27989 L
.30464 .28099 L
.3047 .28083 L
F
.30037 .29089 m
.30085 .28979 L
.30084 .28982 L
.30037 .29089 L
.30037 .29089 L
F
.30085 .28979 m
.30132 .28869 L
.3013 .28874 L
.30084 .28982 L
.30085 .28979 L
F
.30132 .28869 m
.30179 .28759 L
.30176 .28766 L
.3013 .28874 L
.30132 .28869 L
F
.30179 .28759 m
.30227 .28649 L
.30223 .28659 L
.30176 .28766 L
.30179 .28759 L
F
.30227 .28649 m
.30274 .28539 L
.30269 .28551 L
.30223 .28659 L
.30227 .28649 L
F
.30274 .28539 m
.30321 .28429 L
.30315 .28444 L
.30269 .28551 L
.30274 .28539 L
F
.30321 .28429 m
.30369 .28319 L
.30362 .28336 L
.30315 .28444 L
.30321 .28429 L
F
.30369 .28319 m
.30416 .28209 L
.30408 .28228 L
.30362 .28336 L
.30369 .28319 L
F
.30416 .28209 m
.30464 .28099 L
.30454 .28121 L
.30408 .28228 L
.30416 .28209 L
F
.30464 .28099 m
.30511 .27989 L
.30501 .28013 L
.30454 .28121 L
.30464 .28099 L
F
.30037 .29089 m
.30084 .28982 L
.30082 .28985 L
.30037 .29089 L
.30037 .29089 L
F
.30084 .28982 m
.3013 .28874 L
.30127 .2888 L
.30082 .28985 L
.30084 .28982 L
F
.3013 .28874 m
.30176 .28766 L
.30172 .28776 L
.30127 .2888 L
.3013 .28874 L
F
.30176 .28766 m
.30223 .28659 L
.30217 .28671 L
.30172 .28776 L
.30176 .28766 L
F
.30223 .28659 m
.30269 .28551 L
.30262 .28567 L
.30217 .28671 L
.30223 .28659 L
F
.30269 .28551 m
.30315 .28444 L
.30307 .28462 L
.30262 .28567 L
.30269 .28551 L
F
.30315 .28444 m
.30362 .28336 L
.30352 .28358 L
.30307 .28462 L
.30315 .28444 L
F
.30362 .28336 m
.30408 .28228 L
.30397 .28253 L
.30352 .28358 L
.30362 .28336 L
F
.30408 .28228 m
.30454 .28121 L
.30442 .28148 L
.30397 .28253 L
.30408 .28228 L
F
.30454 .28121 m
.30501 .28013 L
.30487 .28044 L
.30442 .28148 L
.30454 .28121 L
F
.30037 .29089 m
.30082 .28985 L
.30081 .28988 L
.30037 .29089 L
.30037 .29089 L
F
.30082 .28985 m
.30127 .2888 L
.30124 .28888 L
.30081 .28988 L
.30082 .28985 L
F
.30127 .2888 m
.30172 .28776 L
.30167 .28787 L
.30124 .28888 L
.30127 .2888 L
F
.30172 .28776 m
.30217 .28671 L
.30211 .28686 L
.30167 .28787 L
.30172 .28776 L
F
.30217 .28671 m
.30262 .28567 L
.30254 .28585 L
.30211 .28686 L
.30217 .28671 L
F
.30262 .28567 m
.30307 .28462 L
.30298 .28484 L
.30254 .28585 L
.30262 .28567 L
F
.30307 .28462 m
.30352 .28358 L
.30341 .28384 L
.30298 .28484 L
.30307 .28462 L
F
.30352 .28358 m
.30397 .28253 L
.30384 .28283 L
.30341 .28384 L
.30352 .28358 L
F
.30397 .28253 m
.30442 .28148 L
.30428 .28182 L
.30384 .28283 L
.30397 .28253 L
F
.30442 .28148 m
.30487 .28044 L
.30471 .28081 L
.30428 .28182 L
.30442 .28148 L
F
.30037 .29089 m
.30081 .28988 L
.30079 .28993 L
.30037 .29089 L
.30037 .29089 L
F
.30081 .28988 m
.30124 .28888 L
.3012 .28896 L
.30079 .28993 L
.30081 .28988 L
F
.30124 .28888 m
.30167 .28787 L
.30162 .288 L
.3012 .28896 L
.30124 .28888 L
F
.30167 .28787 m
.30211 .28686 L
.30203 .28703 L
.30162 .288 L
.30167 .28787 L
F
.30211 .28686 m
.30254 .28585 L
.30245 .28607 L
.30203 .28703 L
.30211 .28686 L
F
.30254 .28585 m
.30298 .28484 L
.30286 .2851 L
.30245 .28607 L
.30254 .28585 L
F
.30298 .28484 m
.30341 .28384 L
.30328 .28414 L
.30286 .2851 L
.30298 .28484 L
F
.30341 .28384 m
.30384 .28283 L
.3037 .28317 L
.30328 .28414 L
.30341 .28384 L
F
.30384 .28283 m
.30428 .28182 L
.30411 .28221 L
.3037 .28317 L
.30384 .28283 L
F
.30428 .28182 m
.30471 .28081 L
.30453 .28125 L
.30411 .28221 L
.30428 .28182 L
F
.30037 .29089 m
.30079 .28993 L
.30077 .28998 L
.30037 .29089 L
.30037 .29089 L
F
.30079 .28993 m
.3012 .28896 L
.30116 .28906 L
.30077 .28998 L
.30079 .28993 L
F
.3012 .28896 m
.30162 .288 L
.30155 .28815 L
.30116 .28906 L
.3012 .28896 L
F
.30162 .288 m
.30203 .28703 L
.30195 .28723 L
.30155 .28815 L
.30162 .288 L
F
.30203 .28703 m
.30245 .28607 L
.30234 .28632 L
.30195 .28723 L
.30203 .28703 L
F
.30245 .28607 m
.30286 .2851 L
.30274 .2854 L
.30234 .28632 L
.30245 .28607 L
F
.30286 .2851 m
.30328 .28414 L
.30313 .28449 L
.30274 .2854 L
.30286 .2851 L
F
.30328 .28414 m
.3037 .28317 L
.30353 .28357 L
.30313 .28449 L
.30328 .28414 L
F
.3037 .28317 m
.30411 .28221 L
.30392 .28265 L
.30353 .28357 L
.3037 .28317 L
F
.30411 .28221 m
.30453 .28125 L
.30431 .28174 L
.30392 .28265 L
.30411 .28221 L
F
.30037 .29089 m
.30077 .28998 L
.30074 .29003 L
.30037 .29089 L
.30037 .29089 L
F
.30077 .28998 m
.30116 .28906 L
.30111 .28917 L
.30074 .29003 L
.30077 .28998 L
F
.30116 .28906 m
.30155 .28815 L
.30148 .28831 L
.30111 .28917 L
.30116 .28906 L
F
.30155 .28815 m
.30195 .28723 L
.30185 .28745 L
.30148 .28831 L
.30155 .28815 L
F
.30195 .28723 m
.30234 .28632 L
.30222 .28659 L
.30185 .28745 L
.30195 .28723 L
F
.30234 .28632 m
.30274 .2854 L
.30259 .28573 L
.30222 .28659 L
.30234 .28632 L
F
.30274 .2854 m
.30313 .28449 L
.30297 .28487 L
.30259 .28573 L
.30274 .2854 L
F
.30313 .28449 m
.30353 .28357 L
.30334 .28401 L
.30297 .28487 L
.30313 .28449 L
F
.30353 .28357 m
.30392 .28265 L
.30371 .28315 L
.30334 .28401 L
.30353 .28357 L
F
.30392 .28265 m
.30431 .28174 L
.30408 .28229 L
.30371 .28315 L
.30392 .28265 L
F
.30037 .29089 m
.30074 .29003 L
.30072 .29009 L
.30037 .29089 L
.30037 .29089 L
F
.30074 .29003 m
.30111 .28917 L
.30106 .28929 L
.30072 .29009 L
.30074 .29003 L
F
.30111 .28917 m
.30148 .28831 L
.30141 .28849 L
.30106 .28929 L
.30111 .28917 L
F
.30148 .28831 m
.30185 .28745 L
.30175 .28769 L
.30141 .28849 L
.30148 .28831 L
F
.30185 .28745 m
.30222 .28659 L
.30209 .28689 L
.30175 .28769 L
.30185 .28745 L
F
.30222 .28659 m
.30259 .28573 L
.30244 .28609 L
.30209 .28689 L
.30222 .28659 L
F
.30259 .28573 m
.30297 .28487 L
.30278 .28529 L
.30244 .28609 L
.30259 .28573 L
F
.30297 .28487 m
.30334 .28401 L
.30313 .28449 L
.30278 .28529 L
.30297 .28487 L
F
.30334 .28401 m
.30371 .28315 L
.30347 .28369 L
.30313 .28449 L
.30334 .28401 L
F
.30371 .28315 m
.30408 .28229 L
.30382 .28289 L
.30347 .28369 L
.30371 .28315 L
F
.30037 .29089 m
.30072 .29009 L
.30069 .29016 L
.30037 .29089 L
.30037 .29089 L
F
.30072 .29009 m
.30106 .28929 L
.301 .28942 L
.30069 .29016 L
.30072 .29009 L
F
.30106 .28929 m
.30141 .28849 L
.30132 .28869 L
.301 .28942 L
.30106 .28929 L
F
.30141 .28849 m
.30175 .28769 L
.30164 .28795 L
.30132 .28869 L
.30141 .28849 L
F
.30175 .28769 m
.30209 .28689 L
.30195 .28722 L
.30164 .28795 L
.30175 .28769 L
F
.30209 .28689 m
.30244 .28609 L
.30227 .28648 L
.30195 .28722 L
.30209 .28689 L
F
.30244 .28609 m
.30278 .28529 L
.30259 .28575 L
.30227 .28648 L
.30244 .28609 L
F
.30278 .28529 m
.30313 .28449 L
.3029 .28501 L
.30259 .28575 L
.30278 .28529 L
F
.30313 .28449 m
.30347 .28369 L
.30322 .28428 L
.3029 .28501 L
.30313 .28449 L
F
.30347 .28369 m
.30382 .28289 L
.30354 .28354 L
.30322 .28428 L
.30347 .28369 L
F
.30037 .29089 m
.30069 .29016 L
.30066 .29023 L
.30037 .29089 L
.30037 .29089 L
F
.30069 .29016 m
.301 .28942 L
.30094 .28956 L
.30066 .29023 L
.30069 .29016 L
F
.301 .28942 m
.30132 .28869 L
.30123 .2889 L
.30094 .28956 L
.301 .28942 L
F
.30132 .28869 m
.30164 .28795 L
.30152 .28823 L
.30123 .2889 L
.30132 .28869 L
F
.30164 .28795 m
.30195 .28722 L
.3018 .28757 L
.30152 .28823 L
.30164 .28795 L
F
.30195 .28722 m
.30227 .28648 L
.30209 .2869 L
.3018 .28757 L
.30195 .28722 L
F
.30227 .28648 m
.30259 .28575 L
.30238 .28624 L
.30209 .2869 L
.30227 .28648 L
F
.30259 .28575 m
.3029 .28501 L
.30266 .28557 L
.30238 .28624 L
.30259 .28575 L
F
.3029 .28501 m
.30322 .28428 L
.30295 .28491 L
.30266 .28557 L
.3029 .28501 L
F
.30322 .28428 m
.30354 .28354 L
.30324 .28424 L
.30295 .28491 L
.30322 .28428 L
F
.30037 .29089 m
.30066 .29023 L
.30063 .2903 L
.30037 .29089 L
.30037 .29089 L
F
.30066 .29023 m
.30094 .28956 L
.30088 .28971 L
.30063 .2903 L
.30066 .29023 L
F
.30094 .28956 m
.30123 .2889 L
.30114 .28912 L
.30088 .28971 L
.30094 .28956 L
F
.30123 .2889 m
.30152 .28823 L
.30139 .28853 L
.30114 .28912 L
.30123 .2889 L
F
.30152 .28823 m
.3018 .28757 L
.30164 .28794 L
.30139 .28853 L
.30152 .28823 L
F
.3018 .28757 m
.30209 .2869 L
.3019 .28735 L
.30164 .28794 L
.3018 .28757 L
F
.30209 .2869 m
.30238 .28624 L
.30215 .28675 L
.3019 .28735 L
.30209 .2869 L
F
.30238 .28624 m
.30266 .28557 L
.30241 .28616 L
.30215 .28675 L
.30238 .28624 L
F
.30266 .28557 m
.30295 .28491 L
.30266 .28557 L
.30241 .28616 L
.30266 .28557 L
F
.30295 .28491 m
.30324 .28424 L
.30292 .28498 L
.30266 .28557 L
.30295 .28491 L
F
.30037 .29089 m
.30063 .2903 L
.30059 .29038 L
.30037 .29089 L
.30037 .29089 L
F
.30063 .2903 m
.30088 .28971 L
.30081 .28987 L
.30059 .29038 L
.30063 .2903 L
F
.30088 .28971 m
.30114 .28912 L
.30104 .28935 L
.30081 .28987 L
.30088 .28971 L
F
.30114 .28912 m
.30139 .28853 L
.30126 .28884 L
.30104 .28935 L
.30114 .28912 L
F
.30139 .28853 m
.30164 .28794 L
.30148 .28832 L
.30126 .28884 L
.30139 .28853 L
F
.30164 .28794 m
.3019 .28735 L
.3017 .28781 L
.30148 .28832 L
.30164 .28794 L
F
.3019 .28735 m
.30215 .28675 L
.30192 .2873 L
.3017 .28781 L
.3019 .28735 L
F
.30215 .28675 m
.30241 .28616 L
.30214 .28678 L
.30192 .2873 L
.30215 .28675 L
F
.30241 .28616 m
.30266 .28557 L
.30236 .28627 L
.30214 .28678 L
.30241 .28616 L
F
.30266 .28557 m
.30292 .28498 L
.30258 .28576 L
.30236 .28627 L
.30266 .28557 L
F
.30037 .29089 m
.30059 .29038 L
.30056 .29046 L
.30037 .29089 L
.30037 .29089 L
F
.30059 .29038 m
.30081 .28987 L
.30074 .29003 L
.30056 .29046 L
.30059 .29038 L
F
.30081 .28987 m
.30104 .28935 L
.30093 .28959 L
.30074 .29003 L
.30081 .28987 L
F
.30104 .28935 m
.30126 .28884 L
.30112 .28916 L
.30093 .28959 L
.30104 .28935 L
F
.30126 .28884 m
.30148 .28832 L
.3013 .28873 L
.30112 .28916 L
.30126 .28884 L
F
.30148 .28832 m
.3017 .28781 L
.30149 .2883 L
.3013 .28873 L
.30148 .28832 L
F
.3017 .28781 m
.30192 .2873 L
.30168 .28786 L
.30149 .2883 L
.3017 .28781 L
F
.30192 .2873 m
.30214 .28678 L
.30186 .28743 L
.30168 .28786 L
.30192 .2873 L
F
.30214 .28678 m
.30236 .28627 L
.30205 .287 L
.30186 .28743 L
.30214 .28678 L
F
.30236 .28627 m
.30258 .28576 L
.30224 .28656 L
.30205 .287 L
.30236 .28627 L
F
.30037 .29089 m
.30056 .29046 L
.30052 .29054 L
.30037 .29089 L
.30037 .29089 L
F
.30056 .29046 m
.30074 .29003 L
.30067 .29019 L
.30052 .29054 L
.30056 .29046 L
F
.30074 .29003 m
.30093 .28959 L
.30082 .28984 L
.30067 .29019 L
.30074 .29003 L
F
.30093 .28959 m
.30112 .28916 L
.30097 .28949 L
.30082 .28984 L
.30093 .28959 L
F
.30112 .28916 m
.3013 .28873 L
.30112 .28914 L
.30097 .28949 L
.30112 .28916 L
F
.3013 .28873 m
.30149 .2883 L
.30128 .2888 L
.30112 .28914 L
.3013 .28873 L
F
.30149 .2883 m
.30168 .28786 L
.30143 .28845 L
.30128 .2888 L
.30149 .2883 L
F
.30168 .28786 m
.30186 .28743 L
.30158 .2881 L
.30143 .28845 L
.30168 .28786 L
F
.30186 .28743 m
.30205 .287 L
.30173 .28775 L
.30158 .2881 L
.30186 .28743 L
F
.30205 .287 m
.30224 .28656 L
.30188 .2874 L
.30173 .28775 L
.30205 .287 L
F
.30037 .29089 m
.30052 .29054 L
.30049 .29063 L
.30037 .29089 L
.30037 .29089 L
F
.30052 .29054 m
.30067 .29019 L
.3006 .29036 L
.30049 .29063 L
.30052 .29054 L
F
.30067 .29019 m
.30082 .28984 L
.30071 .2901 L
.3006 .29036 L
.30067 .29019 L
F
.30082 .28984 m
.30097 .28949 L
.30083 .28984 L
.30071 .2901 L
.30082 .28984 L
F
.30097 .28949 m
.30112 .28914 L
.30094 .28957 L
.30083 .28984 L
.30097 .28949 L
F
.30112 .28914 m
.30128 .2888 L
.30105 .28931 L
.30094 .28957 L
.30112 .28914 L
F
.30128 .2888 m
.30143 .28845 L
.30117 .28904 L
.30105 .28931 L
.30128 .2888 L
F
.30143 .28845 m
.30158 .2881 L
.30128 .28878 L
.30117 .28904 L
.30143 .28845 L
F
.30158 .2881 m
.30173 .28775 L
.3014 .28852 L
.30128 .28878 L
.30158 .2881 L
F
.30173 .28775 m
.30188 .2874 L
.30151 .28825 L
.3014 .28852 L
.30173 .28775 L
F
.30037 .29089 m
.30049 .29063 L
.30045 .29072 L
.30037 .29089 L
.30037 .29089 L
F
.30049 .29063 m
.3006 .29036 L
.30052 .29054 L
.30045 .29072 L
.30049 .29063 L
F
.3006 .29036 m
.30071 .2901 L
.3006 .29036 L
.30052 .29054 L
.3006 .29036 L
F
.30071 .2901 m
.30083 .28984 L
.30068 .29019 L
.3006 .29036 L
.30071 .2901 L
F
.30083 .28984 m
.30094 .28957 L
.30075 .29001 L
.30068 .29019 L
.30083 .28984 L
F
.30094 .28957 m
.30105 .28931 L
.30083 .28983 L
.30075 .29001 L
.30094 .28957 L
F
.30105 .28931 m
.30117 .28904 L
.30091 .28965 L
.30083 .28983 L
.30105 .28931 L
F
.30117 .28904 m
.30128 .28878 L
.30098 .28948 L
.30091 .28965 L
.30117 .28904 L
F
.30128 .28878 m
.3014 .28852 L
.30106 .2893 L
.30098 .28948 L
.30128 .28878 L
F
.3014 .28852 m
.30151 .28825 L
.30113 .28912 L
.30106 .2893 L
.3014 .28852 L
F
.30037 .29089 m
.30045 .29072 L
.30041 .2908 L
.30037 .29089 L
.30037 .29089 L
F
.30045 .29072 m
.30052 .29054 L
.30045 .29072 L
.30041 .2908 L
.30045 .29072 L
F
.30052 .29054 m
.3006 .29036 L
.30049 .29063 L
.30045 .29072 L
.30052 .29054 L
F
.3006 .29036 m
.30068 .29019 L
.30053 .29054 L
.30049 .29063 L
.3006 .29036 L
F
.30068 .29019 m
.30075 .29001 L
.30056 .29045 L
.30053 .29054 L
.30068 .29019 L
F
.30075 .29001 m
.30083 .28983 L
.3006 .29036 L
.30056 .29045 L
.30075 .29001 L
F
.30083 .28983 m
.30091 .28965 L
.30064 .29027 L
.3006 .29036 L
.30083 .28983 L
F
.30091 .28965 m
.30098 .28948 L
.30068 .29018 L
.30064 .29027 L
.30091 .28965 L
F
.30098 .28948 m
.30106 .2893 L
.30072 .29009 L
.30068 .29018 L
.30098 .28948 L
F
.30106 .2893 m
.30113 .28912 L
.30075 .29001 L
.30072 .29009 L
.30106 .2893 L
F
.30037 .29089 m
.30041 .2908 L
.30037 .29089 L
.30037 .29089 L
.30037 .29089 L
F
.30041 .2908 m
.30045 .29072 L
.30037 .29089 L
.30037 .29089 L
.30041 .2908 L
F
.30045 .29072 m
.30049 .29063 L
.30037 .29089 L
.30037 .29089 L
.30045 .29072 L
F
.30049 .29063 m
.30053 .29054 L
.30037 .29089 L
.30037 .29089 L
.30049 .29063 L
F
.30053 .29054 m
.30056 .29045 L
.30037 .29089 L
.30037 .29089 L
.30053 .29054 L
F
.30056 .29045 m
.3006 .29036 L
.30037 .29089 L
.30037 .29089 L
.30056 .29045 L
F
.3006 .29036 m
.30064 .29027 L
.30037 .29089 L
.30037 .29089 L
.3006 .29036 L
F
.30064 .29027 m
.30068 .29018 L
.30037 .29089 L
.30037 .29089 L
.30064 .29027 L
F
.30068 .29018 m
.30072 .29009 L
.30037 .29089 L
.30037 .29089 L
.30068 .29018 L
F
.30072 .29009 m
.30075 .29001 L
.30037 .29089 L
.30037 .29089 L
.30072 .29009 L
F
.30037 .29089 m
.30037 .29089 L
.30033 .29098 L
.30037 .29089 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.3003 .29107 L
.30033 .29098 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30026 .29116 L
.3003 .29107 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30022 .29125 L
.30026 .29116 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30018 .29134 L
.30022 .29125 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30014 .29143 L
.30018 .29134 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.3001 .29151 L
.30014 .29143 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30007 .2916 L
.3001 .29151 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30003 .29169 L
.30007 .2916 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.29999 .29178 L
.30003 .29169 L
.30037 .29089 L
F
.30037 .29089 m
.30033 .29098 L
.3003 .29107 L
.30037 .29089 L
.30037 .29089 L
F
.30033 .29098 m
.3003 .29107 L
.30022 .29125 L
.3003 .29107 L
.30033 .29098 L
F
.3003 .29107 m
.30026 .29116 L
.30014 .29142 L
.30022 .29125 L
.3003 .29107 L
F
.30026 .29116 m
.30022 .29125 L
.30007 .2916 L
.30014 .29142 L
.30026 .29116 L
F
.30022 .29125 m
.30018 .29134 L
.29999 .29178 L
.30007 .2916 L
.30022 .29125 L
F
.30018 .29134 m
.30014 .29143 L
.29991 .29196 L
.29999 .29178 L
.30018 .29134 L
F
.30014 .29143 m
.3001 .29151 L
.29984 .29213 L
.29991 .29196 L
.30014 .29143 L
F
.3001 .29151 m
.30007 .2916 L
.29976 .29231 L
.29984 .29213 L
.3001 .29151 L
F
.30007 .2916 m
.30003 .29169 L
.29969 .29249 L
.29976 .29231 L
.30007 .2916 L
F
.30003 .29169 m
.29999 .29178 L
.29961 .29266 L
.29969 .29249 L
.30003 .29169 L
F
.30037 .29089 m
.3003 .29107 L
.30026 .29116 L
.30037 .29089 L
.30037 .29089 L
F
.3003 .29107 m
.30022 .29125 L
.30014 .29142 L
.30026 .29116 L
.3003 .29107 L
F
.30022 .29125 m
.30014 .29142 L
.30003 .29169 L
.30014 .29142 L
.30022 .29125 L
F
.30014 .29142 m
.30007 .2916 L
.29992 .29195 L
.30003 .29169 L
.30014 .29142 L
F
.30007 .2916 m
.29999 .29178 L
.2998 .29221 L
.29992 .29195 L
.30007 .2916 L
F
.29999 .29178 m
.29991 .29196 L
.29969 .29248 L
.2998 .29221 L
.29999 .29178 L
F
.29991 .29196 m
.29984 .29213 L
.29958 .29274 L
.29969 .29248 L
.29991 .29196 L
F
.29984 .29213 m
.29976 .29231 L
.29946 .29301 L
.29958 .29274 L
.29984 .29213 L
F
.29976 .29231 m
.29969 .29249 L
.29935 .29327 L
.29946 .29301 L
.29976 .29231 L
F
.29969 .29249 m
.29961 .29266 L
.29923 .29353 L
.29935 .29327 L
.29969 .29249 L
F
.30037 .29089 m
.30026 .29116 L
.30022 .29124 L
.30037 .29089 L
.30037 .29089 L
F
.30026 .29116 m
.30014 .29142 L
.30007 .29159 L
.30022 .29124 L
.30026 .29116 L
F
.30014 .29142 m
.30003 .29169 L
.29992 .29194 L
.30007 .29159 L
.30014 .29142 L
F
.30003 .29169 m
.29992 .29195 L
.29977 .29229 L
.29992 .29194 L
.30003 .29169 L
F
.29992 .29195 m
.2998 .29221 L
.29962 .29264 L
.29977 .29229 L
.29992 .29195 L
F
.2998 .29221 m
.29969 .29248 L
.29947 .29299 L
.29962 .29264 L
.2998 .29221 L
F
.29969 .29248 m
.29958 .29274 L
.29932 .29334 L
.29947 .29299 L
.29969 .29248 L
F
.29958 .29274 m
.29946 .29301 L
.29917 .29369 L
.29932 .29334 L
.29958 .29274 L
F
.29946 .29301 m
.29935 .29327 L
.29902 .29404 L
.29917 .29369 L
.29946 .29301 L
F
.29935 .29327 m
.29923 .29353 L
.29887 .29439 L
.29902 .29404 L
.29935 .29327 L
F
.30037 .29089 m
.30022 .29124 L
.30019 .29133 L
.30037 .29089 L
.30037 .29089 L
F
.30022 .29124 m
.30007 .29159 L
.3 .29176 L
.30019 .29133 L
.30022 .29124 L
F
.30007 .29159 m
.29992 .29194 L
.29981 .29219 L
.3 .29176 L
.30007 .29159 L
F
.29992 .29194 m
.29977 .29229 L
.29963 .29263 L
.29981 .29219 L
.29992 .29194 L
F
.29977 .29229 m
.29962 .29264 L
.29944 .29306 L
.29963 .29263 L
.29977 .29229 L
F
.29962 .29264 m
.29947 .29299 L
.29925 .29349 L
.29944 .29306 L
.29962 .29264 L
F
.29947 .29299 m
.29932 .29334 L
.29907 .29392 L
.29925 .29349 L
.29947 .29299 L
F
.29932 .29334 m
.29917 .29369 L
.29888 .29436 L
.29907 .29392 L
.29932 .29334 L
F
.29917 .29369 m
.29902 .29404 L
.29869 .29479 L
.29888 .29436 L
.29917 .29369 L
F
.29902 .29404 m
.29887 .29439 L
.29851 .29522 L
.29869 .29479 L
.29902 .29404 L
F
.30037 .29089 m
.30019 .29133 L
.30015 .29141 L
.30037 .29089 L
.30037 .29089 L
F
.30019 .29133 m
.3 .29176 L
.29993 .29192 L
.30015 .29141 L
.30019 .29133 L
F
.3 .29176 m
.29981 .29219 L
.29971 .29243 L
.29993 .29192 L
.3 .29176 L
F
.29981 .29219 m
.29963 .29263 L
.29949 .29295 L
.29971 .29243 L
.29981 .29219 L
F
.29963 .29263 m
.29944 .29306 L
.29927 .29346 L
.29949 .29295 L
.29963 .29263 L
F
.29944 .29306 m
.29925 .29349 L
.29904 .29398 L
.29927 .29346 L
.29944 .29306 L
F
.29925 .29349 m
.29907 .29392 L
.29882 .29449 L
.29904 .29398 L
.29925 .29349 L
F
.29907 .29392 m
.29888 .29436 L
.2986 .295 L
.29882 .29449 L
.29907 .29392 L
F
.29888 .29436 m
.29869 .29479 L
.29838 .29552 L
.2986 .295 L
.29888 .29436 L
F
.29869 .29479 m
.29851 .29522 L
.29816 .29603 L
.29838 .29552 L
.29869 .29479 L
F
.30037 .29089 m
.30015 .29141 L
.30012 .29148 L
.30037 .29089 L
.30037 .29089 L
F
.30015 .29141 m
.29993 .29192 L
.29986 .29208 L
.30012 .29148 L
.30015 .29141 L
F
.29993 .29192 m
.29971 .29243 L
.29961 .29267 L
.29986 .29208 L
.29993 .29192 L
F
.29971 .29243 m
.29949 .29295 L
.29935 .29326 L
.29961 .29267 L
.29971 .29243 L
F
.29949 .29295 m
.29927 .29346 L
.2991 .29385 L
.29935 .29326 L
.29949 .29295 L
F
.29927 .29346 m
.29904 .29398 L
.29884 .29444 L
.2991 .29385 L
.29927 .29346 L
F
.29904 .29398 m
.29882 .29449 L
.29859 .29503 L
.29884 .29444 L
.29904 .29398 L
F
.29882 .29449 m
.2986 .295 L
.29834 .29562 L
.29859 .29503 L
.29882 .29449 L
F
.2986 .295 m
.29838 .29552 L
.29808 .29621 L
.29834 .29562 L
.2986 .295 L
F
.29838 .29552 m
.29816 .29603 L
.29783 .29681 L
.29808 .29621 L
.29838 .29552 L
F
.30037 .29089 m
.30012 .29148 L
.30009 .29156 L
.30037 .29089 L
.30037 .29089 L
F
.30012 .29148 m
.29986 .29208 L
.2998 .29222 L
.30009 .29156 L
.30012 .29148 L
F
.29986 .29208 m
.29961 .29267 L
.29951 .29289 L
.2998 .29222 L
.29986 .29208 L
F
.29961 .29267 m
.29935 .29326 L
.29923 .29355 L
.29951 .29289 L
.29961 .29267 L
F
.29935 .29326 m
.2991 .29385 L
.29894 .29422 L
.29923 .29355 L
.29935 .29326 L
F
.2991 .29385 m
.29884 .29444 L
.29865 .29488 L
.29894 .29422 L
.2991 .29385 L
F
.29884 .29444 m
.29859 .29503 L
.29837 .29555 L
.29865 .29488 L
.29884 .29444 L
F
.29859 .29503 m
.29834 .29562 L
.29808 .29621 L
.29837 .29555 L
.29859 .29503 L
F
.29834 .29562 m
.29808 .29621 L
.29779 .29688 L
.29808 .29621 L
.29834 .29562 L
F
.29808 .29621 m
.29783 .29681 L
.29751 .29754 L
.29779 .29688 L
.29808 .29621 L
F
.30037 .29089 m
.30009 .29156 L
.30006 .29163 L
.30037 .29089 L
.30037 .29089 L
F
.30009 .29156 m
.2998 .29222 L
.29974 .29236 L
.30006 .29163 L
.30009 .29156 L
F
.2998 .29222 m
.29951 .29289 L
.29942 .2931 L
.29974 .29236 L
.2998 .29222 L
F
.29951 .29289 m
.29923 .29355 L
.29911 .29383 L
.29942 .2931 L
.29951 .29289 L
F
.29923 .29355 m
.29894 .29422 L
.29879 .29457 L
.29911 .29383 L
.29923 .29355 L
F
.29894 .29422 m
.29865 .29488 L
.29847 .2953 L
.29879 .29457 L
.29894 .29422 L
F
.29865 .29488 m
.29837 .29555 L
.29816 .29604 L
.29847 .2953 L
.29865 .29488 L
F
.29837 .29555 m
.29808 .29621 L
.29784 .29677 L
.29816 .29604 L
.29837 .29555 L
F
.29808 .29621 m
.29779 .29688 L
.29752 .29751 L
.29784 .29677 L
.29808 .29621 L
F
.29779 .29688 m
.29751 .29754 L
.29721 .29824 L
.29752 .29751 L
.29779 .29688 L
F
.30037 .29089 m
.30006 .29163 L
.30003 .29169 L
.30037 .29089 L
.30037 .29089 L
F
.30006 .29163 m
.29974 .29236 L
.29968 .29249 L
.30003 .29169 L
.30006 .29163 L
F
.29974 .29236 m
.29942 .2931 L
.29934 .29329 L
.29968 .29249 L
.29974 .29236 L
F
.29942 .2931 m
.29911 .29383 L
.29899 .29409 L
.29934 .29329 L
.29942 .2931 L
F
.29911 .29383 m
.29879 .29457 L
.29865 .29489 L
.29899 .29409 L
.29911 .29383 L
F
.29879 .29457 m
.29847 .2953 L
.29831 .29569 L
.29865 .29489 L
.29879 .29457 L
F
.29847 .2953 m
.29816 .29604 L
.29796 .29649 L
.29831 .29569 L
.29847 .2953 L
F
.29816 .29604 m
.29784 .29677 L
.29762 .29729 L
.29796 .29649 L
.29816 .29604 L
F
.29784 .29677 m
.29752 .29751 L
.29727 .29809 L
.29762 .29729 L
.29784 .29677 L
F
.29752 .29751 m
.29721 .29824 L
.29693 .29889 L
.29727 .29809 L
.29752 .29751 L
F
.30037 .29089 m
.30003 .29169 L
.3 .29175 L
.30037 .29089 L
.30037 .29089 L
F
.30003 .29169 m
.29968 .29249 L
.29963 .29261 L
.3 .29175 L
.30003 .29169 L
F
.29968 .29249 m
.29934 .29329 L
.29926 .29347 L
.29963 .29261 L
.29968 .29249 L
F
.29934 .29329 m
.29899 .29409 L
.29889 .29433 L
.29926 .29347 L
.29934 .29329 L
F
.29899 .29409 m
.29865 .29489 L
.29852 .2952 L
.29889 .29433 L
.29899 .29409 L
F
.29865 .29489 m
.29831 .29569 L
.29815 .29606 L
.29852 .2952 L
.29865 .29489 L
F
.29831 .29569 m
.29796 .29649 L
.29778 .29692 L
.29815 .29606 L
.29831 .29569 L
F
.29796 .29649 m
.29762 .29729 L
.29741 .29778 L
.29778 .29692 L
.29796 .29649 L
F
.29762 .29729 m
.29727 .29809 L
.29704 .29864 L
.29741 .29778 L
.29762 .29729 L
F
.29727 .29809 m
.29693 .29889 L
.29667 .2995 L
.29704 .29864 L
.29727 .29809 L
F
.30037 .29089 m
.3 .29175 L
.29998 .29181 L
.30037 .29089 L
.30037 .29089 L
F
.3 .29175 m
.29963 .29261 L
.29958 .29272 L
.29998 .29181 L
.3 .29175 L
F
.29963 .29261 m
.29926 .29347 L
.29919 .29364 L
.29958 .29272 L
.29963 .29261 L
F
.29926 .29347 m
.29889 .29433 L
.2988 .29455 L
.29919 .29364 L
.29926 .29347 L
F
.29889 .29433 m
.29852 .2952 L
.2984 .29547 L
.2988 .29455 L
.29889 .29433 L
F
.29852 .2952 m
.29815 .29606 L
.29801 .29639 L
.2984 .29547 L
.29852 .2952 L
F
.29815 .29606 m
.29778 .29692 L
.29761 .2973 L
.29801 .29639 L
.29815 .29606 L
F
.29778 .29692 m
.29741 .29778 L
.29722 .29822 L
.29761 .2973 L
.29778 .29692 L
F
.29741 .29778 m
.29704 .29864 L
.29682 .29913 L
.29722 .29822 L
.29741 .29778 L
F
.29704 .29864 m
.29667 .2995 L
.29643 .30005 L
.29682 .29913 L
.29704 .29864 L
F
.30037 .29089 m
.29998 .29181 L
.29996 .29186 L
.30037 .29089 L
.30037 .29089 L
F
.29998 .29181 m
.29958 .29272 L
.29954 .29282 L
.29996 .29186 L
.29998 .29181 L
F
.29958 .29272 m
.29919 .29364 L
.29913 .29379 L
.29954 .29282 L
.29958 .29272 L
F
.29919 .29364 m
.2988 .29455 L
.29871 .29475 L
.29913 .29379 L
.29919 .29364 L
F
.2988 .29455 m
.2984 .29547 L
.2983 .29572 L
.29871 .29475 L
.2988 .29455 L
F
.2984 .29547 m
.29801 .29639 L
.29788 .29668 L
.2983 .29572 L
.2984 .29547 L
F
.29801 .29639 m
.29761 .2973 L
.29746 .29765 L
.29788 .29668 L
.29801 .29639 L
F
.29761 .2973 m
.29722 .29822 L
.29705 .29861 L
.29746 .29765 L
.29761 .2973 L
F
.29722 .29822 m
.29682 .29913 L
.29663 .29958 L
.29705 .29861 L
.29722 .29822 L
F
.29682 .29913 m
.29643 .30005 L
.29622 .30054 L
.29663 .29958 L
.29682 .29913 L
F
.30037 .29089 m
.29996 .29186 L
.29994 .2919 L
.30037 .29089 L
.30037 .29089 L
F
.29996 .29186 m
.29954 .29282 L
.2995 .29291 L
.29994 .2919 L
.29996 .29186 L
F
.29954 .29282 m
.29913 .29379 L
.29907 .29392 L
.2995 .29291 L
.29954 .29282 L
F
.29913 .29379 m
.29871 .29475 L
.29864 .29493 L
.29907 .29392 L
.29913 .29379 L
F
.29871 .29475 m
.2983 .29572 L
.2982 .29593 L
.29864 .29493 L
.29871 .29475 L
F
.2983 .29572 m
.29788 .29668 L
.29777 .29694 L
.2982 .29593 L
.2983 .29572 L
F
.29788 .29668 m
.29746 .29765 L
.29733 .29795 L
.29777 .29694 L
.29788 .29668 L
F
.29746 .29765 m
.29705 .29861 L
.2969 .29896 L
.29733 .29795 L
.29746 .29765 L
F
.29705 .29861 m
.29663 .29958 L
.29647 .29997 L
.2969 .29896 L
.29705 .29861 L
F
.29663 .29958 m
.29622 .30054 L
.29603 .30098 L
.29647 .29997 L
.29663 .29958 L
F
.30037 .29089 m
.29994 .2919 L
.29992 .29194 L
.30037 .29089 L
.30037 .29089 L
F
.29994 .2919 m
.2995 .29291 L
.29947 .29298 L
.29992 .29194 L
.29994 .2919 L
F
.2995 .29291 m
.29907 .29392 L
.29902 .29403 L
.29947 .29298 L
.2995 .29291 L
F
.29907 .29392 m
.29864 .29493 L
.29857 .29507 L
.29902 .29403 L
.29907 .29392 L
F
.29864 .29493 m
.2982 .29593 L
.29812 .29612 L
.29857 .29507 L
.29864 .29493 L
F
.2982 .29593 m
.29777 .29694 L
.29767 .29717 L
.29812 .29612 L
.2982 .29593 L
F
.29777 .29694 m
.29733 .29795 L
.29722 .29821 L
.29767 .29717 L
.29777 .29694 L
F
.29733 .29795 m
.2969 .29896 L
.29677 .29926 L
.29722 .29821 L
.29733 .29795 L
F
.2969 .29896 m
.29647 .29997 L
.29632 .3003 L
.29677 .29926 L
.2969 .29896 L
F
.29647 .29997 m
.29603 .30098 L
.29587 .30135 L
.29632 .3003 L
.29647 .29997 L
F
.30037 .29089 m
.29992 .29194 L
.29991 .29197 L
.30037 .29089 L
.30037 .29089 L
F
.29992 .29194 m
.29947 .29298 L
.29945 .29305 L
.29991 .29197 L
.29992 .29194 L
F
.29947 .29298 m
.29902 .29403 L
.29898 .29412 L
.29945 .29305 L
.29947 .29298 L
F
.29902 .29403 m
.29857 .29507 L
.29852 .2952 L
.29898 .29412 L
.29902 .29403 L
F
.29857 .29507 m
.29812 .29612 L
.29806 .29627 L
.29852 .2952 L
.29857 .29507 L
F
.29812 .29612 m
.29767 .29717 L
.29759 .29735 L
.29806 .29627 L
.29812 .29612 L
F
.29767 .29717 m
.29722 .29821 L
.29713 .29843 L
.29759 .29735 L
.29767 .29717 L
F
.29722 .29821 m
.29677 .29926 L
.29667 .2995 L
.29713 .29843 L
.29722 .29821 L
F
.29677 .29926 m
.29632 .3003 L
.2962 .30058 L
.29667 .2995 L
.29677 .29926 L
F
.29632 .3003 m
.29587 .30135 L
.29574 .30165 L
.2962 .30058 L
.29632 .3003 L
F
.30037 .29089 m
.29991 .29197 L
.2999 .29199 L
.30037 .29089 L
.30037 .29089 L
F
.29991 .29197 m
.29945 .29305 L
.29942 .29309 L
.2999 .29199 L
.29991 .29197 L
F
.29945 .29305 m
.29898 .29412 L
.29895 .29419 L
.29942 .29309 L
.29945 .29305 L
F
.29898 .29412 m
.29852 .2952 L
.29848 .29529 L
.29895 .29419 L
.29898 .29412 L
F
.29852 .2952 m
.29806 .29627 L
.298 .29639 L
.29848 .29529 L
.29852 .2952 L
F
.29806 .29627 m
.29759 .29735 L
.29753 .29749 L
.298 .29639 L
.29806 .29627 L
F
.29759 .29735 m
.29713 .29843 L
.29706 .2986 L
.29753 .29749 L
.29759 .29735 L
F
.29713 .29843 m
.29667 .2995 L
.29658 .2997 L
.29706 .2986 L
.29713 .29843 L
F
.29667 .2995 m
.2962 .30058 L
.29611 .3008 L
.29658 .2997 L
.29667 .2995 L
F
.2962 .30058 m
.29574 .30165 L
.29563 .3019 L
.29611 .3008 L
.2962 .30058 L
F
.30037 .29089 m
.2999 .29199 L
.29989 .29201 L
.30037 .29089 L
.30037 .29089 L
F
.2999 .29199 m
.29942 .29309 L
.29941 .29313 L
.29989 .29201 L
.2999 .29199 L
F
.29942 .29309 m
.29895 .29419 L
.29893 .29425 L
.29941 .29313 L
.29942 .29309 L
F
.29895 .29419 m
.29848 .29529 L
.29845 .29536 L
.29893 .29425 L
.29895 .29419 L
F
.29848 .29529 m
.298 .29639 L
.29797 .29648 L
.29845 .29536 L
.29848 .29529 L
F
.298 .29639 m
.29753 .29749 L
.29748 .2976 L
.29797 .29648 L
.298 .29639 L
F
.29753 .29749 m
.29706 .2986 L
.297 .29872 L
.29748 .2976 L
.29753 .29749 L
F
.29706 .2986 m
.29658 .2997 L
.29652 .29983 L
.297 .29872 L
.29706 .2986 L
F
.29658 .2997 m
.29611 .3008 L
.29604 .30095 L
.29652 .29983 L
.29658 .2997 L
F
.29611 .3008 m
.29563 .3019 L
.29556 .30207 L
.29604 .30095 L
.29611 .3008 L
F
.30037 .29089 m
.29989 .29201 L
.29989 .29202 L
.30037 .29089 L
.30037 .29089 L
F
.29989 .29201 m
.29941 .29313 L
.2994 .29315 L
.29989 .29202 L
.29989 .29201 L
F
.29941 .29313 m
.29893 .29425 L
.29891 .29428 L
.2994 .29315 L
.29941 .29313 L
F
.29893 .29425 m
.29845 .29536 L
.29843 .29541 L
.29891 .29428 L
.29893 .29425 L
F
.29845 .29536 m
.29797 .29648 L
.29794 .29653 L
.29843 .29541 L
.29845 .29536 L
F
.29797 .29648 m
.29748 .2976 L
.29746 .29766 L
.29794 .29653 L
.29797 .29648 L
F
.29748 .2976 m
.297 .29872 L
.29697 .29879 L
.29746 .29766 L
.29748 .2976 L
F
.297 .29872 m
.29652 .29983 L
.29649 .29992 L
.29697 .29879 L
.297 .29872 L
F
.29652 .29983 m
.29604 .30095 L
.296 .30105 L
.29649 .29992 L
.29652 .29983 L
F
.29604 .30095 m
.29556 .30207 L
.29552 .30217 L
.296 .30105 L
.29604 .30095 L
F
.30037 .29089 m
.29989 .29202 L
.29988 .29202 L
.30037 .29089 L
.30037 .29089 L
F
.29989 .29202 m
.2994 .29315 L
.2994 .29316 L
.29988 .29202 L
.29989 .29202 L
F
.2994 .29315 m
.29891 .29428 L
.29891 .29429 L
.2994 .29316 L
.2994 .29315 L
F
.29891 .29428 m
.29843 .29541 L
.29842 .29542 L
.29891 .29429 L
.29891 .29428 L
F
.29843 .29541 m
.29794 .29653 L
.29794 .29655 L
.29842 .29542 L
.29843 .29541 L
F
.29794 .29653 m
.29746 .29766 L
.29745 .29768 L
.29794 .29655 L
.29794 .29653 L
F
.29746 .29766 m
.29697 .29879 L
.29696 .29881 L
.29745 .29768 L
.29746 .29766 L
F
.29697 .29879 m
.29649 .29992 L
.29647 .29995 L
.29696 .29881 L
.29697 .29879 L
F
.29649 .29992 m
.296 .30105 L
.29599 .30108 L
.29647 .29995 L
.29649 .29992 L
F
.296 .30105 m
.29552 .30217 L
.2955 .30221 L
.29599 .30108 L
.296 .30105 L
F
0 g
.2955 .30221 m
.29552 .30217 L
.29556 .30207 L
.29563 .3019 L
.29574 .30165 L
.29587 .30135 L
.29603 .30098 L
.29622 .30054 L
.29643 .30005 L
.29667 .2995 L
.29693 .29889 L
.29721 .29824 L
.29751 .29754 L
.29783 .29681 L
.29816 .29603 L
.29851 .29522 L
.29887 .29439 L
.29923 .29353 L
.29961 .29266 L
.29999 .29178 L
.30037 .29089 L
.30075 .29001 L
.30113 .28912 L
.30151 .28825 L
.30188 .2874 L
.30224 .28656 L
.30258 .28576 L
.30292 .28498 L
.30324 .28424 L
.30354 .28354 L
.30382 .28289 L
.30408 .28229 L
.30431 .28174 L
.30453 .28125 L
.30471 .28081 L
.30487 .28044 L
.30501 .28013 L
.30511 .27989 L
.30518 .27972 L
.30523 .27961 L
.30524 .27958 L
.30523 .27961 L
.30518 .27972 L
.30511 .27989 L
.30501 .28013 L
.30487 .28044 L
.30471 .28081 L
.30453 .28125 L
.30431 .28174 L
.30408 .28229 L
Mistroke
.30382 .28289 L
.30354 .28354 L
.30324 .28424 L
.30292 .28498 L
.30258 .28576 L
.30224 .28656 L
.30188 .2874 L
.30151 .28825 L
.30113 .28912 L
.30075 .29001 L
.30037 .29089 L
.29999 .29178 L
.29961 .29266 L
.29923 .29353 L
.29887 .29439 L
.29851 .29522 L
.29816 .29603 L
.29783 .29681 L
.29751 .29754 L
.29721 .29824 L
.29693 .29889 L
.29667 .2995 L
.29643 .30005 L
.29622 .30054 L
.29603 .30098 L
.29587 .30135 L
.29574 .30165 L
.29563 .3019 L
.29556 .30207 L
.29552 .30217 L
.2955 .30221 L
Mfstroke
.5 g
.30591 .29328 m
.30543 .29441 L
.30543 .29441 L
.30591 .29328 L
.30591 .29328 L
F
.30543 .29441 m
.30494 .29554 L
.30494 .29554 L
.30543 .29441 L
.30543 .29441 L
F
.30494 .29554 m
.30445 .29667 L
.30446 .29666 L
.30494 .29554 L
.30494 .29554 L
F
.30445 .29667 m
.30397 .29781 L
.30397 .29779 L
.30446 .29666 L
.30445 .29667 L
F
.30397 .29781 m
.30348 .29894 L
.30349 .29892 L
.30397 .29779 L
.30397 .29781 L
F
.30348 .29894 m
.30299 .30007 L
.303 .30005 L
.30349 .29892 L
.30348 .29894 L
F
.30299 .30007 m
.3025 .3012 L
.30251 .30118 L
.303 .30005 L
.30299 .30007 L
F
.3025 .3012 m
.30202 .30233 L
.30203 .3023 L
.30251 .30118 L
.3025 .3012 L
F
.30202 .30233 m
.30153 .30346 L
.30154 .30343 L
.30203 .3023 L
.30202 .30233 L
F
.30153 .30346 m
.30104 .30459 L
.30106 .30456 L
.30154 .30343 L
.30153 .30346 L
F
.30591 .29328 m
.30543 .29441 L
.30543 .2944 L
.30591 .29328 L
.30591 .29328 L
F
.30543 .29441 m
.30494 .29554 L
.30495 .29551 L
.30543 .2944 L
.30543 .29441 L
F
.30494 .29554 m
.30446 .29666 L
.30447 .29663 L
.30495 .29551 L
.30494 .29554 L
F
.30446 .29666 m
.30397 .29779 L
.30399 .29775 L
.30447 .29663 L
.30446 .29666 L
F
.30397 .29779 m
.30349 .29892 L
.30351 .29887 L
.30399 .29775 L
.30397 .29779 L
F
.30349 .29892 m
.303 .30005 L
.30303 .29999 L
.30351 .29887 L
.30349 .29892 L
F
.303 .30005 m
.30251 .30118 L
.30255 .3011 L
.30303 .29999 L
.303 .30005 L
F
.30251 .30118 m
.30203 .3023 L
.30206 .30222 L
.30255 .3011 L
.30251 .30118 L
F
.30203 .3023 m
.30154 .30343 L
.30158 .30334 L
.30206 .30222 L
.30203 .3023 L
F
.30154 .30343 m
.30106 .30456 L
.3011 .30446 L
.30158 .30334 L
.30154 .30343 L
F
.30591 .29328 m
.30543 .2944 L
.30544 .29438 L
.30591 .29328 L
.30591 .29328 L
F
.30543 .2944 m
.30495 .29551 L
.30497 .29548 L
.30544 .29438 L
.30543 .2944 L
F
.30495 .29551 m
.30447 .29663 L
.30449 .29658 L
.30497 .29548 L
.30495 .29551 L
F
.30447 .29663 m
.30399 .29775 L
.30402 .29768 L
.30449 .29658 L
.30447 .29663 L
F
.30399 .29775 m
.30351 .29887 L
.30355 .29878 L
.30402 .29768 L
.30399 .29775 L
F
.30351 .29887 m
.30303 .29999 L
.30307 .29988 L
.30355 .29878 L
.30351 .29887 L
F
.30303 .29999 m
.30255 .3011 L
.3026 .30098 L
.30307 .29988 L
.30303 .29999 L
F
.30255 .3011 m
.30206 .30222 L
.30212 .30208 L
.3026 .30098 L
.30255 .3011 L
F
.30206 .30222 m
.30158 .30334 L
.30165 .30318 L
.30212 .30208 L
.30206 .30222 L
F
.30158 .30334 m
.3011 .30446 L
.30118 .30428 L
.30165 .30318 L
.30158 .30334 L
F
.30591 .29328 m
.30544 .29438 L
.30545 .29436 L
.30591 .29328 L
.30591 .29328 L
F
.30544 .29438 m
.30497 .29548 L
.30499 .29543 L
.30545 .29436 L
.30544 .29438 L
F
.30497 .29548 m
.30449 .29658 L
.30452 .29651 L
.30499 .29543 L
.30497 .29548 L
F
.30449 .29658 m
.30402 .29768 L
.30406 .29758 L
.30452 .29651 L
.30449 .29658 L
F
.30402 .29768 m
.30355 .29878 L
.3036 .29866 L
.30406 .29758 L
.30402 .29768 L
F
.30355 .29878 m
.30307 .29988 L
.30313 .29974 L
.3036 .29866 L
.30355 .29878 L
F
.30307 .29988 m
.3026 .30098 L
.30267 .30081 L
.30313 .29974 L
.30307 .29988 L
F
.3026 .30098 m
.30212 .30208 L
.30221 .30189 L
.30267 .30081 L
.3026 .30098 L
F
.30212 .30208 m
.30165 .30318 L
.30174 .30296 L
.30221 .30189 L
.30212 .30208 L
F
.30165 .30318 m
.30118 .30428 L
.30128 .30404 L
.30174 .30296 L
.30165 .30318 L
F
.30591 .29328 m
.30545 .29436 L
.30546 .29432 L
.30591 .29328 L
.30591 .29328 L
F
.30545 .29436 m
.30499 .29543 L
.30501 .29537 L
.30546 .29432 L
.30545 .29436 L
F
.30499 .29543 m
.30452 .29651 L
.30456 .29642 L
.30501 .29537 L
.30499 .29543 L
F
.30452 .29651 m
.30406 .29758 L
.30411 .29746 L
.30456 .29642 L
.30452 .29651 L
F
.30406 .29758 m
.3036 .29866 L
.30366 .29851 L
.30411 .29746 L
.30406 .29758 L
F
.3036 .29866 m
.30313 .29974 L
.30321 .29955 L
.30366 .29851 L
.3036 .29866 L
F
.30313 .29974 m
.30267 .30081 L
.30276 .3006 L
.30321 .29955 L
.30313 .29974 L
F
.30267 .30081 m
.30221 .30189 L
.30231 .30164 L
.30276 .3006 L
.30267 .30081 L
F
.30221 .30189 m
.30174 .30296 L
.30186 .30269 L
.30231 .30164 L
.30221 .30189 L
F
.30174 .30296 m
.30128 .30404 L
.30141 .30373 L
.30186 .30269 L
.30174 .30296 L
F
.30591 .29328 m
.30546 .29432 L
.30548 .29429 L
.30591 .29328 L
.30591 .29328 L
F
.30546 .29432 m
.30501 .29537 L
.30505 .2953 L
.30548 .29429 L
.30546 .29432 L
F
.30501 .29537 m
.30456 .29642 L
.30461 .2963 L
.30505 .2953 L
.30501 .29537 L
F
.30456 .29642 m
.30411 .29746 L
.30418 .29731 L
.30461 .2963 L
.30456 .29642 L
F
.30411 .29746 m
.30366 .29851 L
.30374 .29832 L
.30418 .29731 L
.30411 .29746 L
F
.30366 .29851 m
.30321 .29955 L
.30331 .29933 L
.30374 .29832 L
.30366 .29851 L
F
.30321 .29955 m
.30276 .3006 L
.30288 .30034 L
.30331 .29933 L
.30321 .29955 L
F
.30276 .3006 m
.30231 .30164 L
.30244 .30135 L
.30288 .30034 L
.30276 .3006 L
F
.30231 .30164 m
.30186 .30269 L
.30201 .30235 L
.30244 .30135 L
.30231 .30164 L
F
.30186 .30269 m
.30141 .30373 L
.30157 .30336 L
.30201 .30235 L
.30186 .30269 L
F
.30591 .29328 m
.30548 .29429 L
.3055 .29424 L
.30591 .29328 L
.30591 .29328 L
F
.30548 .29429 m
.30505 .2953 L
.30508 .29521 L
.3055 .29424 L
.30548 .29429 L
F
.30505 .2953 m
.30461 .2963 L
.30467 .29617 L
.30508 .29521 L
.30505 .2953 L
F
.30461 .2963 m
.30418 .29731 L
.30425 .29714 L
.30467 .29617 L
.30461 .2963 L
F
.30418 .29731 m
.30374 .29832 L
.30384 .2981 L
.30425 .29714 L
.30418 .29731 L
F
.30374 .29832 m
.30331 .29933 L
.30342 .29907 L
.30384 .2981 L
.30374 .29832 L
F
.30331 .29933 m
.30288 .30034 L
.30301 .30003 L
.30342 .29907 L
.30331 .29933 L
F
.30288 .30034 m
.30244 .30135 L
.30259 .301 L
.30301 .30003 L
.30288 .30034 L
F
.30244 .30135 m
.30201 .30235 L
.30218 .30196 L
.30259 .301 L
.30244 .30135 L
F
.30201 .30235 m
.30157 .30336 L
.30176 .30293 L
.30218 .30196 L
.30201 .30235 L
F
.30591 .29328 m
.3055 .29424 L
.30552 .29419 L
.30591 .29328 L
.30591 .29328 L
F
.3055 .29424 m
.30508 .29521 L
.30513 .29511 L
.30552 .29419 L
.3055 .29424 L
F
.30508 .29521 m
.30467 .29617 L
.30473 .29603 L
.30513 .29511 L
.30508 .29521 L
F
.30467 .29617 m
.30425 .29714 L
.30434 .29694 L
.30473 .29603 L
.30467 .29617 L
F
.30425 .29714 m
.30384 .2981 L
.30394 .29786 L
.30434 .29694 L
.30425 .29714 L
F
.30384 .2981 m
.30342 .29907 L
.30355 .29877 L
.30394 .29786 L
.30384 .2981 L
F
.30342 .29907 m
.30301 .30003 L
.30316 .29969 L
.30355 .29877 L
.30342 .29907 L
F
.30301 .30003 m
.30259 .301 L
.30276 .3006 L
.30316 .29969 L
.30301 .30003 L
F
.30259 .301 m
.30218 .30196 L
.30237 .30152 L
.30276 .3006 L
.30259 .301 L
F
.30218 .30196 m
.30176 .30293 L
.30197 .30243 L
.30237 .30152 L
.30218 .30196 L
F
.30591 .29328 m
.30552 .29419 L
.30554 .29414 L
.30591 .29328 L
.30591 .29328 L
F
.30552 .29419 m
.30513 .29511 L
.30517 .295 L
.30554 .29414 L
.30552 .29419 L
F
.30513 .29511 m
.30473 .29603 L
.3048 .29586 L
.30517 .295 L
.30513 .29511 L
F
.30473 .29603 m
.30434 .29694 L
.30443 .29672 L
.3048 .29586 L
.30473 .29603 L
F
.30434 .29694 m
.30394 .29786 L
.30406 .29758 L
.30443 .29672 L
.30434 .29694 L
F
.30394 .29786 m
.30355 .29877 L
.30369 .29844 L
.30406 .29758 L
.30394 .29786 L
F
.30355 .29877 m
.30316 .29969 L
.30332 .2993 L
.30369 .29844 L
.30355 .29877 L
F
.30316 .29969 m
.30276 .3006 L
.30295 .30016 L
.30332 .2993 L
.30316 .29969 L
F
.30276 .3006 m
.30237 .30152 L
.30258 .30102 L
.30295 .30016 L
.30276 .3006 L
F
.30237 .30152 m
.30197 .30243 L
.30221 .30188 L
.30258 .30102 L
.30237 .30152 L
F
.30591 .29328 m
.30554 .29414 L
.30557 .29408 L
.30591 .29328 L
.30591 .29328 L
F
.30554 .29414 m
.30517 .295 L
.30523 .29488 L
.30557 .29408 L
.30554 .29414 L
F
.30517 .295 m
.3048 .29586 L
.30488 .29568 L
.30523 .29488 L
.30517 .295 L
F
.3048 .29586 m
.30443 .29672 L
.30454 .29648 L
.30488 .29568 L
.3048 .29586 L
F
.30443 .29672 m
.30406 .29758 L
.30419 .29728 L
.30454 .29648 L
.30443 .29672 L
F
.30406 .29758 m
.30369 .29844 L
.30385 .29808 L
.30419 .29728 L
.30406 .29758 L
F
.30369 .29844 m
.30332 .2993 L
.3035 .29888 L
.30385 .29808 L
.30369 .29844 L
F
.30332 .2993 m
.30295 .30016 L
.30316 .29968 L
.3035 .29888 L
.30332 .2993 L
F
.30295 .30016 m
.30258 .30102 L
.30281 .30048 L
.30316 .29968 L
.30295 .30016 L
F
.30258 .30102 m
.30221 .30188 L
.30247 .30128 L
.30281 .30048 L
.30258 .30102 L
F
.30591 .29328 m
.30557 .29408 L
.3056 .29401 L
.30591 .29328 L
.30591 .29328 L
F
.30557 .29408 m
.30523 .29488 L
.30528 .29475 L
.3056 .29401 L
.30557 .29408 L
F
.30523 .29488 m
.30488 .29568 L
.30497 .29548 L
.30528 .29475 L
.30523 .29488 L
F
.30488 .29568 m
.30454 .29648 L
.30465 .29622 L
.30497 .29548 L
.30488 .29568 L
F
.30454 .29648 m
.30419 .29728 L
.30433 .29695 L
.30465 .29622 L
.30454 .29648 L
F
.30419 .29728 m
.30385 .29808 L
.30402 .29769 L
.30433 .29695 L
.30419 .29728 L
F
.30385 .29808 m
.3035 .29888 L
.3037 .29842 L
.30402 .29769 L
.30385 .29808 L
F
.3035 .29888 m
.30316 .29968 L
.30338 .29916 L
.3037 .29842 L
.3035 .29888 L
F
.30316 .29968 m
.30281 .30048 L
.30307 .29989 L
.30338 .29916 L
.30316 .29968 L
F
.30281 .30048 m
.30247 .30128 L
.30275 .30063 L
.30307 .29989 L
.30281 .30048 L
F
.30591 .29328 m
.3056 .29401 L
.30563 .29394 L
.30591 .29328 L
.30591 .29328 L
F
.3056 .29401 m
.30528 .29475 L
.30534 .29461 L
.30563 .29394 L
.3056 .29401 L
F
.30528 .29475 m
.30497 .29548 L
.30506 .29527 L
.30534 .29461 L
.30528 .29475 L
F
.30497 .29548 m
.30465 .29622 L
.30477 .29594 L
.30506 .29527 L
.30497 .29548 L
F
.30465 .29622 m
.30433 .29695 L
.30448 .29661 L
.30477 .29594 L
.30465 .29622 L
F
.30433 .29695 m
.30402 .29769 L
.3042 .29727 L
.30448 .29661 L
.30433 .29695 L
F
.30402 .29769 m
.3037 .29842 L
.30391 .29794 L
.3042 .29727 L
.30402 .29769 L
F
.3037 .29842 m
.30338 .29916 L
.30362 .2986 L
.30391 .29794 L
.3037 .29842 L
F
.30338 .29916 m
.30307 .29989 L
.30334 .29927 L
.30362 .2986 L
.30338 .29916 L
F
.30307 .29989 m
.30275 .30063 L
.30305 .29993 L
.30334 .29927 L
.30307 .29989 L
F
.30591 .29328 m
.30563 .29394 L
.30566 .29387 L
.30591 .29328 L
.30591 .29328 L
F
.30563 .29394 m
.30534 .29461 L
.30541 .29446 L
.30566 .29387 L
.30563 .29394 L
F
.30534 .29461 m
.30506 .29527 L
.30515 .29505 L
.30541 .29446 L
.30534 .29461 L
F
.30506 .29527 m
.30477 .29594 L
.3049 .29564 L
.30515 .29505 L
.30506 .29527 L
F
.30477 .29594 m
.30448 .29661 L
.30464 .29624 L
.3049 .29564 L
.30477 .29594 L
F
.30448 .29661 m
.3042 .29727 L
.30439 .29683 L
.30464 .29624 L
.30448 .29661 L
F
.3042 .29727 m
.30391 .29794 L
.30413 .29742 L
.30439 .29683 L
.3042 .29727 L
F
.30391 .29794 m
.30362 .2986 L
.30388 .29801 L
.30413 .29742 L
.30391 .29794 L
F
.30362 .2986 m
.30334 .29927 L
.30362 .2986 L
.30388 .29801 L
.30362 .2986 L
F
.30334 .29927 m
.30305 .29993 L
.30337 .29919 L
.30362 .2986 L
.30334 .29927 L
F
.30591 .29328 m
.30566 .29387 L
.30569 .29379 L
.30591 .29328 L
.30591 .29328 L
F
.30566 .29387 m
.30541 .29446 L
.30547 .29431 L
.30569 .29379 L
.30566 .29387 L
F
.30541 .29446 m
.30515 .29505 L
.30525 .29482 L
.30547 .29431 L
.30541 .29446 L
F
.30515 .29505 m
.3049 .29564 L
.30503 .29533 L
.30525 .29482 L
.30515 .29505 L
F
.3049 .29564 m
.30464 .29624 L
.30481 .29585 L
.30503 .29533 L
.3049 .29564 L
F
.30464 .29624 m
.30439 .29683 L
.30459 .29636 L
.30481 .29585 L
.30464 .29624 L
F
.30439 .29683 m
.30413 .29742 L
.30437 .29688 L
.30459 .29636 L
.30439 .29683 L
F
.30413 .29742 m
.30388 .29801 L
.30414 .29739 L
.30437 .29688 L
.30413 .29742 L
F
.30388 .29801 m
.30362 .2986 L
.30392 .2979 L
.30414 .29739 L
.30388 .29801 L
F
.30362 .2986 m
.30337 .29919 L
.3037 .29842 L
.30392 .2979 L
.30362 .2986 L
F
.30591 .29328 m
.30569 .29379 L
.30573 .29371 L
.30591 .29328 L
.30591 .29328 L
F
.30569 .29379 m
.30547 .29431 L
.30554 .29415 L
.30573 .29371 L
.30569 .29379 L
F
.30547 .29431 m
.30525 .29482 L
.30535 .29458 L
.30554 .29415 L
.30547 .29431 L
F
.30525 .29482 m
.30503 .29533 L
.30517 .29501 L
.30535 .29458 L
.30525 .29482 L
F
.30503 .29533 m
.30481 .29585 L
.30498 .29544 L
.30517 .29501 L
.30503 .29533 L
F
.30481 .29585 m
.30459 .29636 L
.3048 .29588 L
.30498 .29544 L
.30481 .29585 L
F
.30459 .29636 m
.30437 .29688 L
.30461 .29631 L
.3048 .29588 L
.30459 .29636 L
F
.30437 .29688 m
.30414 .29739 L
.30442 .29674 L
.30461 .29631 L
.30437 .29688 L
F
.30414 .29739 m
.30392 .2979 L
.30424 .29718 L
.30442 .29674 L
.30414 .29739 L
F
.30392 .2979 m
.3037 .29842 L
.30405 .29761 L
.30424 .29718 L
.30392 .2979 L
F
.30591 .29328 m
.30573 .29371 L
.30576 .29363 L
.30591 .29328 L
.30591 .29328 L
F
.30573 .29371 m
.30554 .29415 L
.30561 .29398 L
.30576 .29363 L
.30573 .29371 L
F
.30554 .29415 m
.30535 .29458 L
.30546 .29433 L
.30561 .29398 L
.30554 .29415 L
F
.30535 .29458 m
.30517 .29501 L
.30531 .29468 L
.30546 .29433 L
.30535 .29458 L
F
.30517 .29501 m
.30498 .29544 L
.30516 .29503 L
.30531 .29468 L
.30517 .29501 L
F
.30498 .29544 m
.3048 .29588 L
.30501 .29538 L
.30516 .29503 L
.30498 .29544 L
F
.3048 .29588 m
.30461 .29631 L
.30486 .29573 L
.30501 .29538 L
.3048 .29588 L
F
.30461 .29631 m
.30442 .29674 L
.30471 .29608 L
.30486 .29573 L
.30461 .29631 L
F
.30442 .29674 m
.30424 .29718 L
.30456 .29643 L
.30471 .29608 L
.30442 .29674 L
F
.30424 .29718 m
.30405 .29761 L
.30441 .29678 L
.30456 .29643 L
.30424 .29718 L
F
.30591 .29328 m
.30576 .29363 L
.3058 .29354 L
.30591 .29328 L
.30591 .29328 L
F
.30576 .29363 m
.30561 .29398 L
.30569 .29381 L
.3058 .29354 L
.30576 .29363 L
F
.30561 .29398 m
.30546 .29433 L
.30557 .29407 L
.30569 .29381 L
.30561 .29398 L
F
.30546 .29433 m
.30531 .29468 L
.30546 .29434 L
.30557 .29407 L
.30546 .29433 L
F
.30531 .29468 m
.30516 .29503 L
.30535 .2946 L
.30546 .29434 L
.30531 .29468 L
F
.30516 .29503 m
.30501 .29538 L
.30523 .29486 L
.30535 .2946 L
.30516 .29503 L
F
.30501 .29538 m
.30486 .29573 L
.30512 .29513 L
.30523 .29486 L
.30501 .29538 L
F
.30486 .29573 m
.30471 .29608 L
.305 .29539 L
.30512 .29513 L
.30486 .29573 L
F
.30471 .29608 m
.30456 .29643 L
.30489 .29566 L
.305 .29539 L
.30471 .29608 L
F
.30456 .29643 m
.30441 .29678 L
.30478 .29592 L
.30489 .29566 L
.30456 .29643 L
F
.30591 .29328 m
.3058 .29354 L
.30584 .29346 L
.30591 .29328 L
.30591 .29328 L
F
.3058 .29354 m
.30569 .29381 L
.30576 .29363 L
.30584 .29346 L
.3058 .29354 L
F
.30569 .29381 m
.30557 .29407 L
.30569 .29381 L
.30576 .29363 L
.30569 .29381 L
F
.30557 .29407 m
.30546 .29434 L
.30561 .29399 L
.30569 .29381 L
.30557 .29407 L
F
.30546 .29434 m
.30535 .2946 L
.30553 .29416 L
.30561 .29399 L
.30546 .29434 L
F
.30535 .2946 m
.30523 .29486 L
.30546 .29434 L
.30553 .29416 L
.30535 .2946 L
F
.30523 .29486 m
.30512 .29513 L
.30538 .29452 L
.30546 .29434 L
.30523 .29486 L
F
.30512 .29513 m
.305 .29539 L
.3053 .2947 L
.30538 .29452 L
.30512 .29513 L
F
.305 .29539 m
.30489 .29566 L
.30523 .29487 L
.3053 .2947 L
.305 .29539 L
F
.30489 .29566 m
.30478 .29592 L
.30515 .29505 L
.30523 .29487 L
.30489 .29566 L
F
.30591 .29328 m
.30584 .29346 L
.30588 .29337 L
.30591 .29328 L
.30591 .29328 L
F
.30584 .29346 m
.30576 .29363 L
.30584 .29346 L
.30588 .29337 L
.30584 .29346 L
F
.30576 .29363 m
.30569 .29381 L
.3058 .29355 L
.30584 .29346 L
.30576 .29363 L
F
.30569 .29381 m
.30561 .29399 L
.30576 .29363 L
.3058 .29355 L
.30569 .29381 L
F
.30561 .29399 m
.30553 .29416 L
.30572 .29372 L
.30576 .29363 L
.30561 .29399 L
F
.30553 .29416 m
.30546 .29434 L
.30568 .29381 L
.30572 .29372 L
.30553 .29416 L
F
.30546 .29434 m
.30538 .29452 L
.30565 .2939 L
.30568 .29381 L
.30546 .29434 L
F
.30538 .29452 m
.3053 .2947 L
.30561 .29399 L
.30565 .2939 L
.30538 .29452 L
F
.3053 .2947 m
.30523 .29487 L
.30557 .29408 L
.30561 .29399 L
.3053 .2947 L
F
.30523 .29487 m
.30515 .29505 L
.30553 .29417 L
.30557 .29408 L
.30523 .29487 L
F
.30591 .29328 m
.30588 .29337 L
.30591 .29328 L
.30591 .29328 L
.30591 .29328 L
F
.30588 .29337 m
.30584 .29346 L
.30591 .29328 L
.30591 .29328 L
.30588 .29337 L
F
.30584 .29346 m
.3058 .29355 L
.30591 .29328 L
.30591 .29328 L
.30584 .29346 L
F
.3058 .29355 m
.30576 .29363 L
.30591 .29328 L
.30591 .29328 L
.3058 .29355 L
F
.30576 .29363 m
.30572 .29372 L
.30591 .29328 L
.30591 .29328 L
.30576 .29363 L
F
.30572 .29372 m
.30568 .29381 L
.30591 .29328 L
.30591 .29328 L
.30572 .29372 L
F
.30568 .29381 m
.30565 .2939 L
.30591 .29328 L
.30591 .29328 L
.30568 .29381 L
F
.30565 .2939 m
.30561 .29399 L
.30591 .29328 L
.30591 .29328 L
.30565 .2939 L
F
.30561 .29399 m
.30557 .29408 L
.30591 .29328 L
.30591 .29328 L
.30561 .29399 L
F
.30557 .29408 m
.30553 .29417 L
.30591 .29328 L
.30591 .29328 L
.30557 .29408 L
F
.30591 .29328 m
.30591 .29328 L
.30595 .29319 L
.30591 .29328 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30599 .2931 L
.30595 .29319 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30603 .29301 L
.30599 .2931 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30607 .29292 L
.30603 .29301 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30611 .29284 L
.30607 .29292 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30614 .29275 L
.30611 .29284 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30618 .29266 L
.30614 .29275 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30622 .29257 L
.30618 .29266 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30626 .29248 L
.30622 .29257 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.3063 .29239 L
.30626 .29248 L
.30591 .29328 L
F
.30591 .29328 m
.30595 .29319 L
.30599 .2931 L
.30591 .29328 L
.30591 .29328 L
F
.30595 .29319 m
.30599 .2931 L
.30607 .29293 L
.30599 .2931 L
.30595 .29319 L
F
.30599 .2931 m
.30603 .29301 L
.30614 .29275 L
.30607 .29293 L
.30599 .2931 L
F
.30603 .29301 m
.30607 .29292 L
.30622 .29257 L
.30614 .29275 L
.30603 .29301 L
F
.30607 .29292 m
.30611 .29284 L
.3063 .29239 L
.30622 .29257 L
.30607 .29292 L
F
.30611 .29284 m
.30614 .29275 L
.30637 .29222 L
.3063 .29239 L
.30611 .29284 L
F
.30614 .29275 m
.30618 .29266 L
.30645 .29204 L
.30637 .29222 L
.30614 .29275 L
F
.30618 .29266 m
.30622 .29257 L
.30652 .29186 L
.30645 .29204 L
.30618 .29266 L
F
.30622 .29257 m
.30626 .29248 L
.3066 .29169 L
.30652 .29186 L
.30622 .29257 L
F
.30626 .29248 m
.3063 .29239 L
.30668 .29151 L
.3066 .29169 L
.30626 .29248 L
F
.30591 .29328 m
.30599 .2931 L
.30603 .29302 L
.30591 .29328 L
.30591 .29328 L
F
.30599 .2931 m
.30607 .29293 L
.30614 .29275 L
.30603 .29302 L
.30599 .2931 L
F
.30607 .29293 m
.30614 .29275 L
.30626 .29249 L
.30614 .29275 L
.30607 .29293 L
F
.30614 .29275 m
.30622 .29257 L
.30637 .29222 L
.30626 .29249 L
.30614 .29275 L
F
.30622 .29257 m
.3063 .29239 L
.30648 .29196 L
.30637 .29222 L
.30622 .29257 L
F
.3063 .29239 m
.30637 .29222 L
.3066 .29169 L
.30648 .29196 L
.3063 .29239 L
F
.30637 .29222 m
.30645 .29204 L
.30671 .29143 L
.3066 .29169 L
.30637 .29222 L
F
.30645 .29204 m
.30652 .29186 L
.30682 .29117 L
.30671 .29143 L
.30645 .29204 L
F
.30652 .29186 m
.3066 .29169 L
.30694 .2909 L
.30682 .29117 L
.30652 .29186 L
F
.3066 .29169 m
.30668 .29151 L
.30705 .29064 L
.30694 .2909 L
.3066 .29169 L
F
.30591 .29328 m
.30603 .29302 L
.30606 .29293 L
.30591 .29328 L
.30591 .29328 L
F
.30603 .29302 m
.30614 .29275 L
.30622 .29258 L
.30606 .29293 L
.30603 .29302 L
F
.30614 .29275 m
.30626 .29249 L
.30637 .29223 L
.30622 .29258 L
.30614 .29275 L
F
.30626 .29249 m
.30637 .29222 L
.30652 .29188 L
.30637 .29223 L
.30626 .29249 L
F
.30637 .29222 m
.30648 .29196 L
.30667 .29153 L
.30652 .29188 L
.30637 .29222 L
F
.30648 .29196 m
.3066 .29169 L
.30682 .29118 L
.30667 .29153 L
.30648 .29196 L
F
.3066 .29169 m
.30671 .29143 L
.30697 .29083 L
.30682 .29118 L
.3066 .29169 L
F
.30671 .29143 m
.30682 .29117 L
.30712 .29048 L
.30697 .29083 L
.30671 .29143 L
F
.30682 .29117 m
.30694 .2909 L
.30727 .29013 L
.30712 .29048 L
.30682 .29117 L
F
.30694 .2909 m
.30705 .29064 L
.30742 .28978 L
.30727 .29013 L
.30694 .2909 L
F
.30591 .29328 m
.30606 .29293 L
.3061 .29285 L
.30591 .29328 L
.30591 .29328 L
F
.30606 .29293 m
.30622 .29258 L
.30629 .29241 L
.3061 .29285 L
.30606 .29293 L
F
.30622 .29258 m
.30637 .29223 L
.30647 .29198 L
.30629 .29241 L
.30622 .29258 L
F
.30637 .29223 m
.30652 .29188 L
.30666 .29155 L
.30647 .29198 L
.30637 .29223 L
F
.30652 .29188 m
.30667 .29153 L
.30685 .29111 L
.30666 .29155 L
.30652 .29188 L
F
.30667 .29153 m
.30682 .29118 L
.30703 .29068 L
.30685 .29111 L
.30667 .29153 L
F
.30682 .29118 m
.30697 .29083 L
.30722 .29025 L
.30703 .29068 L
.30682 .29118 L
F
.30697 .29083 m
.30712 .29048 L
.30741 .28982 L
.30722 .29025 L
.30697 .29083 L
F
.30712 .29048 m
.30727 .29013 L
.30759 .28938 L
.30741 .28982 L
.30712 .29048 L
F
.30727 .29013 m
.30742 .28978 L
.30778 .28895 L
.30759 .28938 L
.30727 .29013 L
F
.30591 .29328 m
.3061 .29285 L
.30614 .29277 L
.30591 .29328 L
.30591 .29328 L
F
.3061 .29285 m
.30629 .29241 L
.30636 .29225 L
.30614 .29277 L
.3061 .29285 L
F
.30629 .29241 m
.30647 .29198 L
.30658 .29174 L
.30636 .29225 L
.30629 .29241 L
F
.30647 .29198 m
.30666 .29155 L
.3068 .29122 L
.30658 .29174 L
.30647 .29198 L
F
.30666 .29155 m
.30685 .29111 L
.30702 .29071 L
.3068 .29122 L
.30666 .29155 L
F
.30685 .29111 m
.30703 .29068 L
.30724 .2902 L
.30702 .29071 L
.30685 .29111 L
F
.30703 .29068 m
.30722 .29025 L
.30746 .28968 L
.30724 .2902 L
.30703 .29068 L
F
.30722 .29025 m
.30741 .28982 L
.30768 .28917 L
.30746 .28968 L
.30722 .29025 L
F
.30741 .28982 m
.30759 .28938 L
.3079 .28866 L
.30768 .28917 L
.30741 .28982 L
F
.30759 .28938 m
.30778 .28895 L
.30813 .28814 L
.3079 .28866 L
.30759 .28938 L
F
.30591 .29328 m
.30614 .29277 L
.30617 .29269 L
.30591 .29328 L
.30591 .29328 L
F
.30614 .29277 m
.30636 .29225 L
.30642 .2921 L
.30617 .29269 L
.30614 .29277 L
F
.30636 .29225 m
.30658 .29174 L
.30668 .29151 L
.30642 .2921 L
.30636 .29225 L
F
.30658 .29174 m
.3068 .29122 L
.30693 .29091 L
.30668 .29151 L
.30658 .29174 L
F
.3068 .29122 m
.30702 .29071 L
.30719 .29032 L
.30693 .29091 L
.3068 .29122 L
F
.30702 .29071 m
.30724 .2902 L
.30744 .28973 L
.30719 .29032 L
.30702 .29071 L
F
.30724 .2902 m
.30746 .28968 L
.3077 .28914 L
.30744 .28973 L
.30724 .2902 L
F
.30746 .28968 m
.30768 .28917 L
.30795 .28855 L
.3077 .28914 L
.30746 .28968 L
F
.30768 .28917 m
.3079 .28866 L
.30821 .28796 L
.30795 .28855 L
.30768 .28917 L
F
.3079 .28866 m
.30813 .28814 L
.30846 .28737 L
.30821 .28796 L
.3079 .28866 L
F
.30591 .29328 m
.30617 .29269 L
.3062 .29261 L
.30591 .29328 L
.30591 .29328 L
F
.30617 .29269 m
.30642 .2921 L
.30649 .29195 L
.3062 .29261 L
.30617 .29269 L
F
.30642 .2921 m
.30668 .29151 L
.30677 .29128 L
.30649 .29195 L
.30642 .2921 L
F
.30668 .29151 m
.30693 .29091 L
.30706 .29062 L
.30677 .29128 L
.30668 .29151 L
F
.30693 .29091 m
.30719 .29032 L
.30735 .28995 L
.30706 .29062 L
.30693 .29091 L
F
.30719 .29032 m
.30744 .28973 L
.30763 .28929 L
.30735 .28995 L
.30719 .29032 L
F
.30744 .28973 m
.3077 .28914 L
.30792 .28862 L
.30763 .28929 L
.30744 .28973 L
F
.3077 .28914 m
.30795 .28855 L
.30821 .28796 L
.30792 .28862 L
.3077 .28914 L
F
.30795 .28855 m
.30821 .28796 L
.30849 .28729 L
.30821 .28796 L
.30795 .28855 L
F
.30821 .28796 m
.30846 .28737 L
.30878 .28663 L
.30849 .28729 L
.30821 .28796 L
F
.30591 .29328 m
.3062 .29261 L
.30623 .29254 L
.30591 .29328 L
.30591 .29328 L
F
.3062 .29261 m
.30649 .29195 L
.30655 .29181 L
.30623 .29254 L
.3062 .29261 L
F
.30649 .29195 m
.30677 .29128 L
.30686 .29107 L
.30655 .29181 L
.30649 .29195 L
F
.30677 .29128 m
.30706 .29062 L
.30718 .29034 L
.30686 .29107 L
.30677 .29128 L
F
.30706 .29062 m
.30735 .28995 L
.3075 .28961 L
.30718 .29034 L
.30706 .29062 L
F
.30735 .28995 m
.30763 .28929 L
.30781 .28887 L
.3075 .28961 L
.30735 .28995 L
F
.30763 .28929 m
.30792 .28862 L
.30813 .28814 L
.30781 .28887 L
.30763 .28929 L
F
.30792 .28862 m
.30821 .28796 L
.30845 .2874 L
.30813 .28814 L
.30792 .28862 L
F
.30821 .28796 m
.30849 .28729 L
.30876 .28667 L
.30845 .2874 L
.30821 .28796 L
F
.30849 .28729 m
.30878 .28663 L
.30908 .28593 L
.30876 .28667 L
.30849 .28729 L
F
.30591 .29328 m
.30623 .29254 L
.30626 .29248 L
.30591 .29328 L
.30591 .29328 L
F
.30623 .29254 m
.30655 .29181 L
.3066 .29168 L
.30626 .29248 L
.30623 .29254 L
F
.30655 .29181 m
.30686 .29107 L
.30695 .29088 L
.3066 .29168 L
.30655 .29181 L
F
.30686 .29107 m
.30718 .29034 L
.30729 .29008 L
.30695 .29088 L
.30686 .29107 L
F
.30718 .29034 m
.3075 .28961 L
.30764 .28928 L
.30729 .29008 L
.30718 .29034 L
F
.3075 .28961 m
.30781 .28887 L
.30798 .28848 L
.30764 .28928 L
.3075 .28961 L
F
.30781 .28887 m
.30813 .28814 L
.30833 .28768 L
.30798 .28848 L
.30781 .28887 L
F
.30813 .28814 m
.30845 .2874 L
.30867 .28688 L
.30833 .28768 L
.30813 .28814 L
F
.30845 .2874 m
.30876 .28667 L
.30901 .28608 L
.30867 .28688 L
.30845 .2874 L
F
.30876 .28667 m
.30908 .28593 L
.30936 .28528 L
.30901 .28608 L
.30876 .28667 L
F
.30591 .29328 m
.30626 .29248 L
.30628 .29242 L
.30591 .29328 L
.30591 .29328 L
F
.30626 .29248 m
.3066 .29168 L
.30666 .29156 L
.30628 .29242 L
.30626 .29248 L
F
.3066 .29168 m
.30695 .29088 L
.30703 .2907 L
.30666 .29156 L
.3066 .29168 L
F
.30695 .29088 m
.30729 .29008 L
.3074 .28984 L
.30703 .2907 L
.30695 .29088 L
F
.30729 .29008 m
.30764 .28928 L
.30777 .28898 L
.3074 .28984 L
.30729 .29008 L
F
.30764 .28928 m
.30798 .28848 L
.30814 .28812 L
.30777 .28898 L
.30764 .28928 L
F
.30798 .28848 m
.30833 .28768 L
.30851 .28726 L
.30814 .28812 L
.30798 .28848 L
F
.30833 .28768 m
.30867 .28688 L
.30888 .2864 L
.30851 .28726 L
.30833 .28768 L
F
.30867 .28688 m
.30901 .28608 L
.30925 .28554 L
.30888 .2864 L
.30867 .28688 L
F
.30901 .28608 m
.30936 .28528 L
.30962 .28468 L
.30925 .28554 L
.30901 .28608 L
F
.30591 .29328 m
.30628 .29242 L
.30631 .29236 L
.30591 .29328 L
.30591 .29328 L
F
.30628 .29242 m
.30666 .29156 L
.3067 .29145 L
.30631 .29236 L
.30628 .29242 L
F
.30666 .29156 m
.30703 .2907 L
.3071 .29053 L
.3067 .29145 L
.30666 .29156 L
F
.30703 .2907 m
.3074 .28984 L
.30749 .28962 L
.3071 .29053 L
.30703 .2907 L
F
.3074 .28984 m
.30777 .28898 L
.30789 .2887 L
.30749 .28962 L
.3074 .28984 L
F
.30777 .28898 m
.30814 .28812 L
.30828 .28779 L
.30789 .2887 L
.30777 .28898 L
F
.30814 .28812 m
.30851 .28726 L
.30867 .28687 L
.30828 .28779 L
.30814 .28812 L
F
.30851 .28726 m
.30888 .2864 L
.30907 .28596 L
.30867 .28687 L
.30851 .28726 L
F
.30888 .2864 m
.30925 .28554 L
.30946 .28504 L
.30907 .28596 L
.30888 .2864 L
F
.30925 .28554 m
.30962 .28468 L
.30986 .28413 L
.30946 .28504 L
.30925 .28554 L
F
.30591 .29328 m
.30631 .29236 L
.30633 .29231 L
.30591 .29328 L
.30591 .29328 L
F
.30631 .29236 m
.3067 .29145 L
.30675 .29135 L
.30633 .29231 L
.30631 .29236 L
F
.3067 .29145 m
.3071 .29053 L
.30716 .29039 L
.30675 .29135 L
.3067 .29145 L
F
.3071 .29053 m
.30749 .28962 L
.30758 .28942 L
.30716 .29039 L
.3071 .29053 L
F
.30749 .28962 m
.30789 .2887 L
.30799 .28846 L
.30758 .28942 L
.30749 .28962 L
F
.30789 .2887 m
.30828 .28779 L
.30841 .28749 L
.30799 .28846 L
.30789 .2887 L
F
.30828 .28779 m
.30867 .28687 L
.30882 .28653 L
.30841 .28749 L
.30828 .28779 L
F
.30867 .28687 m
.30907 .28596 L
.30924 .28556 L
.30882 .28653 L
.30867 .28687 L
F
.30907 .28596 m
.30946 .28504 L
.30965 .2846 L
.30924 .28556 L
.30907 .28596 L
F
.30946 .28504 m
.30986 .28413 L
.31007 .28363 L
.30965 .2846 L
.30946 .28504 L
F
.30591 .29328 m
.30633 .29231 L
.30635 .29227 L
.30591 .29328 L
.30591 .29328 L
F
.30633 .29231 m
.30675 .29135 L
.30678 .29126 L
.30635 .29227 L
.30633 .29231 L
F
.30675 .29135 m
.30716 .29039 L
.30722 .29025 L
.30678 .29126 L
.30675 .29135 L
F
.30716 .29039 m
.30758 .28942 L
.30765 .28925 L
.30722 .29025 L
.30716 .29039 L
F
.30758 .28942 m
.30799 .28846 L
.30808 .28824 L
.30765 .28925 L
.30758 .28942 L
F
.30799 .28846 m
.30841 .28749 L
.30852 .28723 L
.30808 .28824 L
.30799 .28846 L
F
.30841 .28749 m
.30882 .28653 L
.30895 .28622 L
.30852 .28723 L
.30841 .28749 L
F
.30882 .28653 m
.30924 .28556 L
.30939 .28521 L
.30895 .28622 L
.30882 .28653 L
F
.30924 .28556 m
.30965 .2846 L
.30982 .28421 L
.30939 .28521 L
.30924 .28556 L
F
.30965 .2846 m
.31007 .28363 L
.31026 .2832 L
.30982 .28421 L
.30965 .2846 L
F
.30591 .29328 m
.30635 .29227 L
.30636 .29223 L
.30591 .29328 L
.30591 .29328 L
F
.30635 .29227 m
.30678 .29126 L
.30681 .29119 L
.30636 .29223 L
.30635 .29227 L
F
.30678 .29126 m
.30722 .29025 L
.30726 .29014 L
.30681 .29119 L
.30678 .29126 L
F
.30722 .29025 m
.30765 .28925 L
.30771 .2891 L
.30726 .29014 L
.30722 .29025 L
F
.30765 .28925 m
.30808 .28824 L
.30816 .28805 L
.30771 .2891 L
.30765 .28925 L
F
.30808 .28824 m
.30852 .28723 L
.30862 .28701 L
.30816 .28805 L
.30808 .28824 L
F
.30852 .28723 m
.30895 .28622 L
.30907 .28596 L
.30862 .28701 L
.30852 .28723 L
F
.30895 .28622 m
.30939 .28521 L
.30952 .28492 L
.30907 .28596 L
.30895 .28622 L
F
.30939 .28521 m
.30982 .28421 L
.30997 .28387 L
.30952 .28492 L
.30939 .28521 L
F
.30982 .28421 m
.31026 .2832 L
.31042 .28283 L
.30997 .28387 L
.30982 .28421 L
F
.30591 .29328 m
.30636 .29223 L
.30638 .2922 L
.30591 .29328 L
.30591 .29328 L
F
.30636 .29223 m
.30681 .29119 L
.30684 .29113 L
.30638 .2922 L
.30636 .29223 L
F
.30681 .29119 m
.30726 .29014 L
.3073 .29005 L
.30684 .29113 L
.30681 .29119 L
F
.30726 .29014 m
.30771 .2891 L
.30777 .28897 L
.3073 .29005 L
.30726 .29014 L
F
.30771 .2891 m
.30816 .28805 L
.30823 .2879 L
.30777 .28897 L
.30771 .2891 L
F
.30816 .28805 m
.30862 .28701 L
.30869 .28682 L
.30823 .2879 L
.30816 .28805 L
F
.30862 .28701 m
.30907 .28596 L
.30916 .28575 L
.30869 .28682 L
.30862 .28701 L
F
.30907 .28596 m
.30952 .28492 L
.30962 .28467 L
.30916 .28575 L
.30907 .28596 L
F
.30952 .28492 m
.30997 .28387 L
.31008 .28359 L
.30962 .28467 L
.30952 .28492 L
F
.30997 .28387 m
.31042 .28283 L
.31055 .28252 L
.31008 .28359 L
.30997 .28387 L
F
.30591 .29328 m
.30638 .2922 L
.30639 .29218 L
.30591 .29328 L
.30591 .29328 L
F
.30638 .2922 m
.30684 .29113 L
.30686 .29108 L
.30639 .29218 L
.30638 .2922 L
F
.30684 .29113 m
.3073 .29005 L
.30734 .28998 L
.30686 .29108 L
.30684 .29113 L
F
.3073 .29005 m
.30777 .28897 L
.30781 .28888 L
.30734 .28998 L
.3073 .29005 L
F
.30777 .28897 m
.30823 .2879 L
.30828 .28778 L
.30781 .28888 L
.30777 .28897 L
F
.30823 .2879 m
.30869 .28682 L
.30876 .28668 L
.30828 .28778 L
.30823 .2879 L
F
.30869 .28682 m
.30916 .28575 L
.30923 .28558 L
.30876 .28668 L
.30869 .28682 L
F
.30916 .28575 m
.30962 .28467 L
.3097 .28448 L
.30923 .28558 L
.30916 .28575 L
F
.30962 .28467 m
.31008 .28359 L
.31018 .28338 L
.3097 .28448 L
.30962 .28467 L
F
.31008 .28359 m
.31055 .28252 L
.31065 .28228 L
.31018 .28338 L
.31008 .28359 L
F
.30591 .29328 m
.30639 .29218 L
.3064 .29216 L
.30591 .29328 L
.30591 .29328 L
F
.30639 .29218 m
.30686 .29108 L
.30688 .29104 L
.3064 .29216 L
.30639 .29218 L
F
.30686 .29108 m
.30734 .28998 L
.30736 .28993 L
.30688 .29104 L
.30686 .29108 L
F
.30734 .28998 m
.30781 .28888 L
.30784 .28881 L
.30736 .28993 L
.30734 .28998 L
F
.30781 .28888 m
.30828 .28778 L
.30832 .28769 L
.30784 .28881 L
.30781 .28888 L
F
.30828 .28778 m
.30876 .28668 L
.3088 .28657 L
.30832 .28769 L
.30828 .28778 L
F
.30876 .28668 m
.30923 .28558 L
.30928 .28546 L
.3088 .28657 L
.30876 .28668 L
F
.30923 .28558 m
.3097 .28448 L
.30976 .28434 L
.30928 .28546 L
.30923 .28558 L
F
.3097 .28448 m
.31018 .28338 L
.31025 .28322 L
.30976 .28434 L
.3097 .28448 L
F
.31018 .28338 m
.31065 .28228 L
.31073 .2821 L
.31025 .28322 L
.31018 .28338 L
F
.30591 .29328 m
.3064 .29216 L
.3064 .29215 L
.30591 .29328 L
.30591 .29328 L
F
.3064 .29216 m
.30688 .29104 L
.30689 .29102 L
.3064 .29215 L
.3064 .29216 L
F
.30688 .29104 m
.30736 .28993 L
.30737 .2899 L
.30689 .29102 L
.30688 .29104 L
F
.30736 .28993 m
.30784 .28881 L
.30786 .28877 L
.30737 .2899 L
.30736 .28993 L
F
.30784 .28881 m
.30832 .28769 L
.30834 .28764 L
.30786 .28877 L
.30784 .28881 L
F
.30832 .28769 m
.3088 .28657 L
.30883 .28651 L
.30834 .28764 L
.30832 .28769 L
F
.3088 .28657 m
.30928 .28546 L
.30931 .28538 L
.30883 .28651 L
.3088 .28657 L
F
.30928 .28546 m
.30976 .28434 L
.3098 .28426 L
.30931 .28538 L
.30928 .28546 L
F
.30976 .28434 m
.31025 .28322 L
.31029 .28313 L
.3098 .28426 L
.30976 .28434 L
F
.31025 .28322 m
.31073 .2821 L
.31077 .282 L
.31029 .28313 L
.31025 .28322 L
F
.30591 .29328 m
.3064 .29215 L
.3064 .29215 L
.30591 .29328 L
.30591 .29328 L
F
.3064 .29215 m
.30689 .29102 L
.30689 .29102 L
.3064 .29215 L
.3064 .29215 L
F
.30689 .29102 m
.30737 .2899 L
.30738 .28988 L
.30689 .29102 L
.30689 .29102 L
F
.30737 .2899 m
.30786 .28877 L
.30786 .28875 L
.30738 .28988 L
.30737 .2899 L
F
.30786 .28877 m
.30834 .28764 L
.30835 .28762 L
.30786 .28875 L
.30786 .28877 L
F
.30834 .28764 m
.30883 .28651 L
.30884 .28649 L
.30835 .28762 L
.30834 .28764 L
F
.30883 .28651 m
.30931 .28538 L
.30932 .28536 L
.30884 .28649 L
.30883 .28651 L
F
.30931 .28538 m
.3098 .28426 L
.30981 .28423 L
.30932 .28536 L
.30931 .28538 L
F
.3098 .28426 m
.31029 .28313 L
.3103 .2831 L
.30981 .28423 L
.3098 .28426 L
F
.31029 .28313 m
.31077 .282 L
.31079 .28196 L
.3103 .2831 L
.31029 .28313 L
F
.30591 .29328 m
.3064 .29215 L
.3064 .29215 L
.30591 .29328 L
.30591 .29328 L
F
.3064 .29215 m
.30689 .29102 L
.30689 .29102 L
.3064 .29215 L
.3064 .29215 L
F
.30689 .29102 m
.30738 .28988 L
.30737 .2899 L
.30689 .29102 L
.30689 .29102 L
F
.30738 .28988 m
.30786 .28875 L
.30786 .28877 L
.30737 .2899 L
.30738 .28988 L
F
.30786 .28875 m
.30835 .28762 L
.30834 .28764 L
.30786 .28877 L
.30786 .28875 L
F
.30835 .28762 m
.30884 .28649 L
.30883 .28651 L
.30834 .28764 L
.30835 .28762 L
F
.30884 .28649 m
.30932 .28536 L
.30931 .28538 L
.30883 .28651 L
.30884 .28649 L
F
.30932 .28536 m
.30981 .28423 L
.3098 .28426 L
.30931 .28538 L
.30932 .28536 L
F
.30981 .28423 m
.3103 .2831 L
.31029 .28313 L
.3098 .28426 L
.30981 .28423 L
F
.3103 .2831 m
.31079 .28196 L
.31077 .282 L
.31029 .28313 L
.3103 .2831 L
F
.30591 .29328 m
.3064 .29215 L
.3064 .29216 L
.30591 .29328 L
.30591 .29328 L
F
.3064 .29215 m
.30689 .29102 L
.30688 .29104 L
.3064 .29216 L
.3064 .29215 L
F
.30689 .29102 m
.30737 .2899 L
.30736 .28993 L
.30688 .29104 L
.30689 .29102 L
F
.30737 .2899 m
.30786 .28877 L
.30784 .28881 L
.30736 .28993 L
.30737 .2899 L
F
.30786 .28877 m
.30834 .28764 L
.30832 .28769 L
.30784 .28881 L
.30786 .28877 L
F
.30834 .28764 m
.30883 .28651 L
.3088 .28657 L
.30832 .28769 L
.30834 .28764 L
F
.30883 .28651 m
.30931 .28538 L
.30928 .28546 L
.3088 .28657 L
.30883 .28651 L
F
.30931 .28538 m
.3098 .28426 L
.30976 .28434 L
.30928 .28546 L
.30931 .28538 L
F
.3098 .28426 m
.31029 .28313 L
.31025 .28322 L
.30976 .28434 L
.3098 .28426 L
F
.31029 .28313 m
.31077 .282 L
.31073 .2821 L
.31025 .28322 L
.31029 .28313 L
F
.30591 .29328 m
.3064 .29216 L
.30639 .29218 L
.30591 .29328 L
.30591 .29328 L
F
.3064 .29216 m
.30688 .29104 L
.30686 .29108 L
.30639 .29218 L
.3064 .29216 L
F
.30688 .29104 m
.30736 .28993 L
.30734 .28998 L
.30686 .29108 L
.30688 .29104 L
F
.30736 .28993 m
.30784 .28881 L
.30781 .28888 L
.30734 .28998 L
.30736 .28993 L
F
.30784 .28881 m
.30832 .28769 L
.30828 .28778 L
.30781 .28888 L
.30784 .28881 L
F
.30832 .28769 m
.3088 .28657 L
.30876 .28668 L
.30828 .28778 L
.30832 .28769 L
F
.3088 .28657 m
.30928 .28546 L
.30923 .28558 L
.30876 .28668 L
.3088 .28657 L
F
.30928 .28546 m
.30976 .28434 L
.3097 .28448 L
.30923 .28558 L
.30928 .28546 L
F
.30976 .28434 m
.31025 .28322 L
.31018 .28338 L
.3097 .28448 L
.30976 .28434 L
F
.31025 .28322 m
.31073 .2821 L
.31065 .28228 L
.31018 .28338 L
.31025 .28322 L
F
.30591 .29328 m
.30639 .29218 L
.30638 .2922 L
.30591 .29328 L
.30591 .29328 L
F
.30639 .29218 m
.30686 .29108 L
.30684 .29113 L
.30638 .2922 L
.30639 .29218 L
F
.30686 .29108 m
.30734 .28998 L
.3073 .29005 L
.30684 .29113 L
.30686 .29108 L
F
.30734 .28998 m
.30781 .28888 L
.30777 .28897 L
.3073 .29005 L
.30734 .28998 L
F
.30781 .28888 m
.30828 .28778 L
.30823 .2879 L
.30777 .28897 L
.30781 .28888 L
F
.30828 .28778 m
.30876 .28668 L
.30869 .28682 L
.30823 .2879 L
.30828 .28778 L
F
.30876 .28668 m
.30923 .28558 L
.30916 .28575 L
.30869 .28682 L
.30876 .28668 L
F
.30923 .28558 m
.3097 .28448 L
.30962 .28467 L
.30916 .28575 L
.30923 .28558 L
F
.3097 .28448 m
.31018 .28338 L
.31008 .28359 L
.30962 .28467 L
.3097 .28448 L
F
.31018 .28338 m
.31065 .28228 L
.31055 .28252 L
.31008 .28359 L
.31018 .28338 L
F
.30591 .29328 m
.30638 .2922 L
.30636 .29223 L
.30591 .29328 L
.30591 .29328 L
F
.30638 .2922 m
.30684 .29113 L
.30681 .29119 L
.30636 .29223 L
.30638 .2922 L
F
.30684 .29113 m
.3073 .29005 L
.30726 .29014 L
.30681 .29119 L
.30684 .29113 L
F
.3073 .29005 m
.30777 .28897 L
.30771 .2891 L
.30726 .29014 L
.3073 .29005 L
F
.30777 .28897 m
.30823 .2879 L
.30816 .28805 L
.30771 .2891 L
.30777 .28897 L
F
.30823 .2879 m
.30869 .28682 L
.30862 .28701 L
.30816 .28805 L
.30823 .2879 L
F
.30869 .28682 m
.30916 .28575 L
.30907 .28596 L
.30862 .28701 L
.30869 .28682 L
F
.30916 .28575 m
.30962 .28467 L
.30952 .28492 L
.30907 .28596 L
.30916 .28575 L
F
.30962 .28467 m
.31008 .28359 L
.30997 .28387 L
.30952 .28492 L
.30962 .28467 L
F
.31008 .28359 m
.31055 .28252 L
.31042 .28283 L
.30997 .28387 L
.31008 .28359 L
F
.30591 .29328 m
.30636 .29223 L
.30635 .29227 L
.30591 .29328 L
.30591 .29328 L
F
.30636 .29223 m
.30681 .29119 L
.30678 .29126 L
.30635 .29227 L
.30636 .29223 L
F
.30681 .29119 m
.30726 .29014 L
.30722 .29025 L
.30678 .29126 L
.30681 .29119 L
F
.30726 .29014 m
.30771 .2891 L
.30765 .28925 L
.30722 .29025 L
.30726 .29014 L
F
.30771 .2891 m
.30816 .28805 L
.30808 .28824 L
.30765 .28925 L
.30771 .2891 L
F
.30816 .28805 m
.30862 .28701 L
.30852 .28723 L
.30808 .28824 L
.30816 .28805 L
F
.30862 .28701 m
.30907 .28596 L
.30895 .28622 L
.30852 .28723 L
.30862 .28701 L
F
.30907 .28596 m
.30952 .28492 L
.30939 .28521 L
.30895 .28622 L
.30907 .28596 L
F
.30952 .28492 m
.30997 .28387 L
.30982 .28421 L
.30939 .28521 L
.30952 .28492 L
F
.30997 .28387 m
.31042 .28283 L
.31026 .2832 L
.30982 .28421 L
.30997 .28387 L
F
.30591 .29328 m
.30635 .29227 L
.30633 .29231 L
.30591 .29328 L
.30591 .29328 L
F
.30635 .29227 m
.30678 .29126 L
.30675 .29135 L
.30633 .29231 L
.30635 .29227 L
F
.30678 .29126 m
.30722 .29025 L
.30716 .29039 L
.30675 .29135 L
.30678 .29126 L
F
.30722 .29025 m
.30765 .28925 L
.30758 .28942 L
.30716 .29039 L
.30722 .29025 L
F
.30765 .28925 m
.30808 .28824 L
.30799 .28846 L
.30758 .28942 L
.30765 .28925 L
F
.30808 .28824 m
.30852 .28723 L
.30841 .28749 L
.30799 .28846 L
.30808 .28824 L
F
.30852 .28723 m
.30895 .28622 L
.30882 .28653 L
.30841 .28749 L
.30852 .28723 L
F
.30895 .28622 m
.30939 .28521 L
.30924 .28556 L
.30882 .28653 L
.30895 .28622 L
F
.30939 .28521 m
.30982 .28421 L
.30965 .2846 L
.30924 .28556 L
.30939 .28521 L
F
.30982 .28421 m
.31026 .2832 L
.31007 .28363 L
.30965 .2846 L
.30982 .28421 L
F
.30591 .29328 m
.30633 .29231 L
.30631 .29236 L
.30591 .29328 L
.30591 .29328 L
F
.30633 .29231 m
.30675 .29135 L
.3067 .29145 L
.30631 .29236 L
.30633 .29231 L
F
.30675 .29135 m
.30716 .29039 L
.3071 .29053 L
.3067 .29145 L
.30675 .29135 L
F
.30716 .29039 m
.30758 .28942 L
.30749 .28962 L
.3071 .29053 L
.30716 .29039 L
F
.30758 .28942 m
.30799 .28846 L
.30789 .2887 L
.30749 .28962 L
.30758 .28942 L
F
.30799 .28846 m
.30841 .28749 L
.30828 .28779 L
.30789 .2887 L
.30799 .28846 L
F
.30841 .28749 m
.30882 .28653 L
.30867 .28687 L
.30828 .28779 L
.30841 .28749 L
F
.30882 .28653 m
.30924 .28556 L
.30907 .28596 L
.30867 .28687 L
.30882 .28653 L
F
.30924 .28556 m
.30965 .2846 L
.30946 .28504 L
.30907 .28596 L
.30924 .28556 L
F
.30965 .2846 m
.31007 .28363 L
.30986 .28413 L
.30946 .28504 L
.30965 .2846 L
F
.30591 .29328 m
.30631 .29236 L
.30628 .29242 L
.30591 .29328 L
.30591 .29328 L
F
.30631 .29236 m
.3067 .29145 L
.30666 .29156 L
.30628 .29242 L
.30631 .29236 L
F
.3067 .29145 m
.3071 .29053 L
.30703 .2907 L
.30666 .29156 L
.3067 .29145 L
F
.3071 .29053 m
.30749 .28962 L
.3074 .28984 L
.30703 .2907 L
.3071 .29053 L
F
.30749 .28962 m
.30789 .2887 L
.30777 .28898 L
.3074 .28984 L
.30749 .28962 L
F
.30789 .2887 m
.30828 .28779 L
.30814 .28812 L
.30777 .28898 L
.30789 .2887 L
F
.30828 .28779 m
.30867 .28687 L
.30851 .28726 L
.30814 .28812 L
.30828 .28779 L
F
.30867 .28687 m
.30907 .28596 L
.30888 .2864 L
.30851 .28726 L
.30867 .28687 L
F
.30907 .28596 m
.30946 .28504 L
.30925 .28554 L
.30888 .2864 L
.30907 .28596 L
F
.30946 .28504 m
.30986 .28413 L
.30962 .28468 L
.30925 .28554 L
.30946 .28504 L
F
.30591 .29328 m
.30628 .29242 L
.30626 .29248 L
.30591 .29328 L
.30591 .29328 L
F
.30628 .29242 m
.30666 .29156 L
.3066 .29168 L
.30626 .29248 L
.30628 .29242 L
F
.30666 .29156 m
.30703 .2907 L
.30695 .29088 L
.3066 .29168 L
.30666 .29156 L
F
.30703 .2907 m
.3074 .28984 L
.30729 .29008 L
.30695 .29088 L
.30703 .2907 L
F
.3074 .28984 m
.30777 .28898 L
.30764 .28928 L
.30729 .29008 L
.3074 .28984 L
F
.30777 .28898 m
.30814 .28812 L
.30798 .28848 L
.30764 .28928 L
.30777 .28898 L
F
.30814 .28812 m
.30851 .28726 L
.30833 .28768 L
.30798 .28848 L
.30814 .28812 L
F
.30851 .28726 m
.30888 .2864 L
.30867 .28688 L
.30833 .28768 L
.30851 .28726 L
F
.30888 .2864 m
.30925 .28554 L
.30901 .28608 L
.30867 .28688 L
.30888 .2864 L
F
.30925 .28554 m
.30962 .28468 L
.30936 .28528 L
.30901 .28608 L
.30925 .28554 L
F
.30591 .29328 m
.30626 .29248 L
.30623 .29254 L
.30591 .29328 L
.30591 .29328 L
F
.30626 .29248 m
.3066 .29168 L
.30655 .29181 L
.30623 .29254 L
.30626 .29248 L
F
.3066 .29168 m
.30695 .29088 L
.30686 .29107 L
.30655 .29181 L
.3066 .29168 L
F
.30695 .29088 m
.30729 .29008 L
.30718 .29034 L
.30686 .29107 L
.30695 .29088 L
F
.30729 .29008 m
.30764 .28928 L
.3075 .28961 L
.30718 .29034 L
.30729 .29008 L
F
.30764 .28928 m
.30798 .28848 L
.30781 .28887 L
.3075 .28961 L
.30764 .28928 L
F
.30798 .28848 m
.30833 .28768 L
.30813 .28814 L
.30781 .28887 L
.30798 .28848 L
F
.30833 .28768 m
.30867 .28688 L
.30845 .2874 L
.30813 .28814 L
.30833 .28768 L
F
.30867 .28688 m
.30901 .28608 L
.30876 .28667 L
.30845 .2874 L
.30867 .28688 L
F
.30901 .28608 m
.30936 .28528 L
.30908 .28593 L
.30876 .28667 L
.30901 .28608 L
F
.30591 .29328 m
.30623 .29254 L
.3062 .29261 L
.30591 .29328 L
.30591 .29328 L
F
.30623 .29254 m
.30655 .29181 L
.30649 .29195 L
.3062 .29261 L
.30623 .29254 L
F
.30655 .29181 m
.30686 .29107 L
.30677 .29128 L
.30649 .29195 L
.30655 .29181 L
F
.30686 .29107 m
.30718 .29034 L
.30706 .29062 L
.30677 .29128 L
.30686 .29107 L
F
.30718 .29034 m
.3075 .28961 L
.30735 .28995 L
.30706 .29062 L
.30718 .29034 L
F
.3075 .28961 m
.30781 .28887 L
.30763 .28929 L
.30735 .28995 L
.3075 .28961 L
F
.30781 .28887 m
.30813 .28814 L
.30792 .28862 L
.30763 .28929 L
.30781 .28887 L
F
.30813 .28814 m
.30845 .2874 L
.30821 .28796 L
.30792 .28862 L
.30813 .28814 L
F
.30845 .2874 m
.30876 .28667 L
.30849 .28729 L
.30821 .28796 L
.30845 .2874 L
F
.30876 .28667 m
.30908 .28593 L
.30878 .28663 L
.30849 .28729 L
.30876 .28667 L
F
.30591 .29328 m
.3062 .29261 L
.30617 .29269 L
.30591 .29328 L
.30591 .29328 L
F
.3062 .29261 m
.30649 .29195 L
.30642 .2921 L
.30617 .29269 L
.3062 .29261 L
F
.30649 .29195 m
.30677 .29128 L
.30668 .29151 L
.30642 .2921 L
.30649 .29195 L
F
.30677 .29128 m
.30706 .29062 L
.30693 .29091 L
.30668 .29151 L
.30677 .29128 L
F
.30706 .29062 m
.30735 .28995 L
.30719 .29032 L
.30693 .29091 L
.30706 .29062 L
F
.30735 .28995 m
.30763 .28929 L
.30744 .28973 L
.30719 .29032 L
.30735 .28995 L
F
.30763 .28929 m
.30792 .28862 L
.3077 .28914 L
.30744 .28973 L
.30763 .28929 L
F
.30792 .28862 m
.30821 .28796 L
.30795 .28855 L
.3077 .28914 L
.30792 .28862 L
F
.30821 .28796 m
.30849 .28729 L
.30821 .28796 L
.30795 .28855 L
.30821 .28796 L
F
.30849 .28729 m
.30878 .28663 L
.30846 .28737 L
.30821 .28796 L
.30849 .28729 L
F
.30591 .29328 m
.30617 .29269 L
.30614 .29277 L
.30591 .29328 L
.30591 .29328 L
F
.30617 .29269 m
.30642 .2921 L
.30636 .29225 L
.30614 .29277 L
.30617 .29269 L
F
.30642 .2921 m
.30668 .29151 L
.30658 .29174 L
.30636 .29225 L
.30642 .2921 L
F
.30668 .29151 m
.30693 .29091 L
.3068 .29122 L
.30658 .29174 L
.30668 .29151 L
F
.30693 .29091 m
.30719 .29032 L
.30702 .29071 L
.3068 .29122 L
.30693 .29091 L
F
.30719 .29032 m
.30744 .28973 L
.30724 .2902 L
.30702 .29071 L
.30719 .29032 L
F
.30744 .28973 m
.3077 .28914 L
.30746 .28968 L
.30724 .2902 L
.30744 .28973 L
F
.3077 .28914 m
.30795 .28855 L
.30768 .28917 L
.30746 .28968 L
.3077 .28914 L
F
.30795 .28855 m
.30821 .28796 L
.3079 .28866 L
.30768 .28917 L
.30795 .28855 L
F
.30821 .28796 m
.30846 .28737 L
.30813 .28814 L
.3079 .28866 L
.30821 .28796 L
F
.30591 .29328 m
.30614 .29277 L
.3061 .29285 L
.30591 .29328 L
.30591 .29328 L
F
.30614 .29277 m
.30636 .29225 L
.30629 .29241 L
.3061 .29285 L
.30614 .29277 L
F
.30636 .29225 m
.30658 .29174 L
.30647 .29198 L
.30629 .29241 L
.30636 .29225 L
F
.30658 .29174 m
.3068 .29122 L
.30666 .29155 L
.30647 .29198 L
.30658 .29174 L
F
.3068 .29122 m
.30702 .29071 L
.30685 .29111 L
.30666 .29155 L
.3068 .29122 L
F
.30702 .29071 m
.30724 .2902 L
.30703 .29068 L
.30685 .29111 L
.30702 .29071 L
F
.30724 .2902 m
.30746 .28968 L
.30722 .29025 L
.30703 .29068 L
.30724 .2902 L
F
.30746 .28968 m
.30768 .28917 L
.30741 .28982 L
.30722 .29025 L
.30746 .28968 L
F
.30768 .28917 m
.3079 .28866 L
.30759 .28938 L
.30741 .28982 L
.30768 .28917 L
F
.3079 .28866 m
.30813 .28814 L
.30778 .28895 L
.30759 .28938 L
.3079 .28866 L
F
.30591 .29328 m
.3061 .29285 L
.30606 .29293 L
.30591 .29328 L
.30591 .29328 L
F
.3061 .29285 m
.30629 .29241 L
.30622 .29258 L
.30606 .29293 L
.3061 .29285 L
F
.30629 .29241 m
.30647 .29198 L
.30637 .29223 L
.30622 .29258 L
.30629 .29241 L
F
.30647 .29198 m
.30666 .29155 L
.30652 .29188 L
.30637 .29223 L
.30647 .29198 L
F
.30666 .29155 m
.30685 .29111 L
.30667 .29153 L
.30652 .29188 L
.30666 .29155 L
F
.30685 .29111 m
.30703 .29068 L
.30682 .29118 L
.30667 .29153 L
.30685 .29111 L
F
.30703 .29068 m
.30722 .29025 L
.30697 .29083 L
.30682 .29118 L
.30703 .29068 L
F
.30722 .29025 m
.30741 .28982 L
.30712 .29048 L
.30697 .29083 L
.30722 .29025 L
F
.30741 .28982 m
.30759 .28938 L
.30727 .29013 L
.30712 .29048 L
.30741 .28982 L
F
.30759 .28938 m
.30778 .28895 L
.30742 .28978 L
.30727 .29013 L
.30759 .28938 L
F
.30591 .29328 m
.30606 .29293 L
.30603 .29302 L
.30591 .29328 L
.30591 .29328 L
F
.30606 .29293 m
.30622 .29258 L
.30614 .29275 L
.30603 .29302 L
.30606 .29293 L
F
.30622 .29258 m
.30637 .29223 L
.30626 .29249 L
.30614 .29275 L
.30622 .29258 L
F
.30637 .29223 m
.30652 .29188 L
.30637 .29222 L
.30626 .29249 L
.30637 .29223 L
F
.30652 .29188 m
.30667 .29153 L
.30648 .29196 L
.30637 .29222 L
.30652 .29188 L
F
.30667 .29153 m
.30682 .29118 L
.3066 .29169 L
.30648 .29196 L
.30667 .29153 L
F
.30682 .29118 m
.30697 .29083 L
.30671 .29143 L
.3066 .29169 L
.30682 .29118 L
F
.30697 .29083 m
.30712 .29048 L
.30682 .29117 L
.30671 .29143 L
.30697 .29083 L
F
.30712 .29048 m
.30727 .29013 L
.30694 .2909 L
.30682 .29117 L
.30712 .29048 L
F
.30727 .29013 m
.30742 .28978 L
.30705 .29064 L
.30694 .2909 L
.30727 .29013 L
F
.30591 .29328 m
.30603 .29302 L
.30599 .2931 L
.30591 .29328 L
.30591 .29328 L
F
.30603 .29302 m
.30614 .29275 L
.30607 .29293 L
.30599 .2931 L
.30603 .29302 L
F
.30614 .29275 m
.30626 .29249 L
.30614 .29275 L
.30607 .29293 L
.30614 .29275 L
F
.30626 .29249 m
.30637 .29222 L
.30622 .29257 L
.30614 .29275 L
.30626 .29249 L
F
.30637 .29222 m
.30648 .29196 L
.3063 .29239 L
.30622 .29257 L
.30637 .29222 L
F
.30648 .29196 m
.3066 .29169 L
.30637 .29222 L
.3063 .29239 L
.30648 .29196 L
F
.3066 .29169 m
.30671 .29143 L
.30645 .29204 L
.30637 .29222 L
.3066 .29169 L
F
.30671 .29143 m
.30682 .29117 L
.30652 .29186 L
.30645 .29204 L
.30671 .29143 L
F
.30682 .29117 m
.30694 .2909 L
.3066 .29169 L
.30652 .29186 L
.30682 .29117 L
F
.30694 .2909 m
.30705 .29064 L
.30668 .29151 L
.3066 .29169 L
.30694 .2909 L
F
.30591 .29328 m
.30599 .2931 L
.30595 .29319 L
.30591 .29328 L
.30591 .29328 L
F
.30599 .2931 m
.30607 .29293 L
.30599 .2931 L
.30595 .29319 L
.30599 .2931 L
F
.30607 .29293 m
.30614 .29275 L
.30603 .29301 L
.30599 .2931 L
.30607 .29293 L
F
.30614 .29275 m
.30622 .29257 L
.30607 .29292 L
.30603 .29301 L
.30614 .29275 L
F
.30622 .29257 m
.3063 .29239 L
.30611 .29284 L
.30607 .29292 L
.30622 .29257 L
F
.3063 .29239 m
.30637 .29222 L
.30614 .29275 L
.30611 .29284 L
.3063 .29239 L
F
.30637 .29222 m
.30645 .29204 L
.30618 .29266 L
.30614 .29275 L
.30637 .29222 L
F
.30645 .29204 m
.30652 .29186 L
.30622 .29257 L
.30618 .29266 L
.30645 .29204 L
F
.30652 .29186 m
.3066 .29169 L
.30626 .29248 L
.30622 .29257 L
.30652 .29186 L
F
.3066 .29169 m
.30668 .29151 L
.3063 .29239 L
.30626 .29248 L
.3066 .29169 L
F
.30591 .29328 m
.30595 .29319 L
.30591 .29328 L
.30591 .29328 L
.30591 .29328 L
F
.30595 .29319 m
.30599 .2931 L
.30591 .29328 L
.30591 .29328 L
.30595 .29319 L
F
.30599 .2931 m
.30603 .29301 L
.30591 .29328 L
.30591 .29328 L
.30599 .2931 L
F
.30603 .29301 m
.30607 .29292 L
.30591 .29328 L
.30591 .29328 L
.30603 .29301 L
F
.30607 .29292 m
.30611 .29284 L
.30591 .29328 L
.30591 .29328 L
.30607 .29292 L
F
.30611 .29284 m
.30614 .29275 L
.30591 .29328 L
.30591 .29328 L
.30611 .29284 L
F
.30614 .29275 m
.30618 .29266 L
.30591 .29328 L
.30591 .29328 L
.30614 .29275 L
F
.30618 .29266 m
.30622 .29257 L
.30591 .29328 L
.30591 .29328 L
.30618 .29266 L
F
.30622 .29257 m
.30626 .29248 L
.30591 .29328 L
.30591 .29328 L
.30622 .29257 L
F
.30626 .29248 m
.3063 .29239 L
.30591 .29328 L
.30591 .29328 L
.30626 .29248 L
F
.30591 .29328 m
.30591 .29328 L
.30588 .29337 L
.30591 .29328 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30584 .29346 L
.30588 .29337 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.3058 .29355 L
.30584 .29346 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30576 .29363 L
.3058 .29355 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30572 .29372 L
.30576 .29363 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30568 .29381 L
.30572 .29372 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30565 .2939 L
.30568 .29381 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30561 .29399 L
.30565 .2939 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30557 .29408 L
.30561 .29399 L
.30591 .29328 L
F
.30591 .29328 m
.30591 .29328 L
.30553 .29417 L
.30557 .29408 L
.30591 .29328 L
F
.30591 .29328 m
.30588 .29337 L
.30584 .29346 L
.30591 .29328 L
.30591 .29328 L
F
.30588 .29337 m
.30584 .29346 L
.30576 .29363 L
.30584 .29346 L
.30588 .29337 L
F
.30584 .29346 m
.3058 .29355 L
.30569 .29381 L
.30576 .29363 L
.30584 .29346 L
F
.3058 .29355 m
.30576 .29363 L
.30561 .29399 L
.30569 .29381 L
.3058 .29355 L
F
.30576 .29363 m
.30572 .29372 L
.30553 .29416 L
.30561 .29399 L
.30576 .29363 L
F
.30572 .29372 m
.30568 .29381 L
.30546 .29434 L
.30553 .29416 L
.30572 .29372 L
F
.30568 .29381 m
.30565 .2939 L
.30538 .29452 L
.30546 .29434 L
.30568 .29381 L
F
.30565 .2939 m
.30561 .29399 L
.3053 .2947 L
.30538 .29452 L
.30565 .2939 L
F
.30561 .29399 m
.30557 .29408 L
.30523 .29487 L
.3053 .2947 L
.30561 .29399 L
F
.30557 .29408 m
.30553 .29417 L
.30515 .29505 L
.30523 .29487 L
.30557 .29408 L
F
.30591 .29328 m
.30584 .29346 L
.3058 .29354 L
.30591 .29328 L
.30591 .29328 L
F
.30584 .29346 m
.30576 .29363 L
.30569 .29381 L
.3058 .29354 L
.30584 .29346 L
F
.30576 .29363 m
.30569 .29381 L
.30557 .29407 L
.30569 .29381 L
.30576 .29363 L
F
.30569 .29381 m
.30561 .29399 L
.30546 .29434 L
.30557 .29407 L
.30569 .29381 L
F
.30561 .29399 m
.30553 .29416 L
.30535 .2946 L
.30546 .29434 L
.30561 .29399 L
F
.30553 .29416 m
.30546 .29434 L
.30523 .29486 L
.30535 .2946 L
.30553 .29416 L
F
.30546 .29434 m
.30538 .29452 L
.30512 .29513 L
.30523 .29486 L
.30546 .29434 L
F
.30538 .29452 m
.3053 .2947 L
.305 .29539 L
.30512 .29513 L
.30538 .29452 L
F
.3053 .2947 m
.30523 .29487 L
.30489 .29566 L
.305 .29539 L
.3053 .2947 L
F
.30523 .29487 m
.30515 .29505 L
.30478 .29592 L
.30489 .29566 L
.30523 .29487 L
F
.30591 .29328 m
.3058 .29354 L
.30576 .29363 L
.30591 .29328 L
.30591 .29328 L
F
.3058 .29354 m
.30569 .29381 L
.30561 .29398 L
.30576 .29363 L
.3058 .29354 L
F
.30569 .29381 m
.30557 .29407 L
.30546 .29433 L
.30561 .29398 L
.30569 .29381 L
F
.30557 .29407 m
.30546 .29434 L
.30531 .29468 L
.30546 .29433 L
.30557 .29407 L
F
.30546 .29434 m
.30535 .2946 L
.30516 .29503 L
.30531 .29468 L
.30546 .29434 L
F
.30535 .2946 m
.30523 .29486 L
.30501 .29538 L
.30516 .29503 L
.30535 .2946 L
F
.30523 .29486 m
.30512 .29513 L
.30486 .29573 L
.30501 .29538 L
.30523 .29486 L
F
.30512 .29513 m
.305 .29539 L
.30471 .29608 L
.30486 .29573 L
.30512 .29513 L
F
.305 .29539 m
.30489 .29566 L
.30456 .29643 L
.30471 .29608 L
.305 .29539 L
F
.30489 .29566 m
.30478 .29592 L
.30441 .29678 L
.30456 .29643 L
.30489 .29566 L
F
.30591 .29328 m
.30576 .29363 L
.30573 .29371 L
.30591 .29328 L
.30591 .29328 L
F
.30576 .29363 m
.30561 .29398 L
.30554 .29415 L
.30573 .29371 L
.30576 .29363 L
F
.30561 .29398 m
.30546 .29433 L
.30535 .29458 L
.30554 .29415 L
.30561 .29398 L
F
.30546 .29433 m
.30531 .29468 L
.30517 .29501 L
.30535 .29458 L
.30546 .29433 L
F
.30531 .29468 m
.30516 .29503 L
.30498 .29544 L
.30517 .29501 L
.30531 .29468 L
F
.30516 .29503 m
.30501 .29538 L
.3048 .29588 L
.30498 .29544 L
.30516 .29503 L
F
.30501 .29538 m
.30486 .29573 L
.30461 .29631 L
.3048 .29588 L
.30501 .29538 L
F
.30486 .29573 m
.30471 .29608 L
.30442 .29674 L
.30461 .29631 L
.30486 .29573 L
F
.30471 .29608 m
.30456 .29643 L
.30424 .29718 L
.30442 .29674 L
.30471 .29608 L
F
.30456 .29643 m
.30441 .29678 L
.30405 .29761 L
.30424 .29718 L
.30456 .29643 L
F
.30591 .29328 m
.30573 .29371 L
.30569 .29379 L
.30591 .29328 L
.30591 .29328 L
F
.30573 .29371 m
.30554 .29415 L
.30547 .29431 L
.30569 .29379 L
.30573 .29371 L
F
.30554 .29415 m
.30535 .29458 L
.30525 .29482 L
.30547 .29431 L
.30554 .29415 L
F
.30535 .29458 m
.30517 .29501 L
.30503 .29533 L
.30525 .29482 L
.30535 .29458 L
F
.30517 .29501 m
.30498 .29544 L
.30481 .29585 L
.30503 .29533 L
.30517 .29501 L
F
.30498 .29544 m
.3048 .29588 L
.30459 .29636 L
.30481 .29585 L
.30498 .29544 L
F
.3048 .29588 m
.30461 .29631 L
.30437 .29688 L
.30459 .29636 L
.3048 .29588 L
F
.30461 .29631 m
.30442 .29674 L
.30414 .29739 L
.30437 .29688 L
.30461 .29631 L
F
.30442 .29674 m
.30424 .29718 L
.30392 .2979 L
.30414 .29739 L
.30442 .29674 L
F
.30424 .29718 m
.30405 .29761 L
.3037 .29842 L
.30392 .2979 L
.30424 .29718 L
F
.30591 .29328 m
.30569 .29379 L
.30566 .29387 L
.30591 .29328 L
.30591 .29328 L
F
.30569 .29379 m
.30547 .29431 L
.30541 .29446 L
.30566 .29387 L
.30569 .29379 L
F
.30547 .29431 m
.30525 .29482 L
.30515 .29505 L
.30541 .29446 L
.30547 .29431 L
F
.30525 .29482 m
.30503 .29533 L
.3049 .29564 L
.30515 .29505 L
.30525 .29482 L
F
.30503 .29533 m
.30481 .29585 L
.30464 .29624 L
.3049 .29564 L
.30503 .29533 L
F
.30481 .29585 m
.30459 .29636 L
.30439 .29683 L
.30464 .29624 L
.30481 .29585 L
F
.30459 .29636 m
.30437 .29688 L
.30413 .29742 L
.30439 .29683 L
.30459 .29636 L
F
.30437 .29688 m
.30414 .29739 L
.30388 .29801 L
.30413 .29742 L
.30437 .29688 L
F
.30414 .29739 m
.30392 .2979 L
.30362 .2986 L
.30388 .29801 L
.30414 .29739 L
F
.30392 .2979 m
.3037 .29842 L
.30337 .29919 L
.30362 .2986 L
.30392 .2979 L
F
.30591 .29328 m
.30566 .29387 L
.30563 .29394 L
.30591 .29328 L
.30591 .29328 L
F
.30566 .29387 m
.30541 .29446 L
.30534 .29461 L
.30563 .29394 L
.30566 .29387 L
F
.30541 .29446 m
.30515 .29505 L
.30506 .29527 L
.30534 .29461 L
.30541 .29446 L
F
.30515 .29505 m
.3049 .29564 L
.30477 .29594 L
.30506 .29527 L
.30515 .29505 L
F
.3049 .29564 m
.30464 .29624 L
.30448 .29661 L
.30477 .29594 L
.3049 .29564 L
F
.30464 .29624 m
.30439 .29683 L
.3042 .29727 L
.30448 .29661 L
.30464 .29624 L
F
.30439 .29683 m
.30413 .29742 L
.30391 .29794 L
.3042 .29727 L
.30439 .29683 L
F
.30413 .29742 m
.30388 .29801 L
.30362 .2986 L
.30391 .29794 L
.30413 .29742 L
F
.30388 .29801 m
.30362 .2986 L
.30334 .29927 L
.30362 .2986 L
.30388 .29801 L
F
.30362 .2986 m
.30337 .29919 L
.30305 .29993 L
.30334 .29927 L
.30362 .2986 L
F
.30591 .29328 m
.30563 .29394 L
.3056 .29401 L
.30591 .29328 L
.30591 .29328 L
F
.30563 .29394 m
.30534 .29461 L
.30528 .29475 L
.3056 .29401 L
.30563 .29394 L
F
.30534 .29461 m
.30506 .29527 L
.30497 .29548 L
.30528 .29475 L
.30534 .29461 L
F
.30506 .29527 m
.30477 .29594 L
.30465 .29622 L
.30497 .29548 L
.30506 .29527 L
F
.30477 .29594 m
.30448 .29661 L
.30433 .29695 L
.30465 .29622 L
.30477 .29594 L
F
.30448 .29661 m
.3042 .29727 L
.30402 .29769 L
.30433 .29695 L
.30448 .29661 L
F
.3042 .29727 m
.30391 .29794 L
.3037 .29842 L
.30402 .29769 L
.3042 .29727 L
F
.30391 .29794 m
.30362 .2986 L
.30338 .29916 L
.3037 .29842 L
.30391 .29794 L
F
.30362 .2986 m
.30334 .29927 L
.30307 .29989 L
.30338 .29916 L
.30362 .2986 L
F
.30334 .29927 m
.30305 .29993 L
.30275 .30063 L
.30307 .29989 L
.30334 .29927 L
F
.30591 .29328 m
.3056 .29401 L
.30557 .29408 L
.30591 .29328 L
.30591 .29328 L
F
.3056 .29401 m
.30528 .29475 L
.30523 .29488 L
.30557 .29408 L
.3056 .29401 L
F
.30528 .29475 m
.30497 .29548 L
.30488 .29568 L
.30523 .29488 L
.30528 .29475 L
F
.30497 .29548 m
.30465 .29622 L
.30454 .29648 L
.30488 .29568 L
.30497 .29548 L
F
.30465 .29622 m
.30433 .29695 L
.30419 .29728 L
.30454 .29648 L
.30465 .29622 L
F
.30433 .29695 m
.30402 .29769 L
.30385 .29808 L
.30419 .29728 L
.30433 .29695 L
F
.30402 .29769 m
.3037 .29842 L
.3035 .29888 L
.30385 .29808 L
.30402 .29769 L
F
.3037 .29842 m
.30338 .29916 L
.30316 .29968 L
.3035 .29888 L
.3037 .29842 L
F
.30338 .29916 m
.30307 .29989 L
.30281 .30048 L
.30316 .29968 L
.30338 .29916 L
F
.30307 .29989 m
.30275 .30063 L
.30247 .30128 L
.30281 .30048 L
.30307 .29989 L
F
.30591 .29328 m
.30557 .29408 L
.30554 .29414 L
.30591 .29328 L
.30591 .29328 L
F
.30557 .29408 m
.30523 .29488 L
.30517 .295 L
.30554 .29414 L
.30557 .29408 L
F
.30523 .29488 m
.30488 .29568 L
.3048 .29586 L
.30517 .295 L
.30523 .29488 L
F
.30488 .29568 m
.30454 .29648 L
.30443 .29672 L
.3048 .29586 L
.30488 .29568 L
F
.30454 .29648 m
.30419 .29728 L
.30406 .29758 L
.30443 .29672 L
.30454 .29648 L
F
.30419 .29728 m
.30385 .29808 L
.30369 .29844 L
.30406 .29758 L
.30419 .29728 L
F
.30385 .29808 m
.3035 .29888 L
.30332 .2993 L
.30369 .29844 L
.30385 .29808 L
F
.3035 .29888 m
.30316 .29968 L
.30295 .30016 L
.30332 .2993 L
.3035 .29888 L
F
.30316 .29968 m
.30281 .30048 L
.30258 .30102 L
.30295 .30016 L
.30316 .29968 L
F
.30281 .30048 m
.30247 .30128 L
.30221 .30188 L
.30258 .30102 L
.30281 .30048 L
F
.30591 .29328 m
.30554 .29414 L
.30552 .29419 L
.30591 .29328 L
.30591 .29328 L
F
.30554 .29414 m
.30517 .295 L
.30513 .29511 L
.30552 .29419 L
.30554 .29414 L
F
.30517 .295 m
.3048 .29586 L
.30473 .29603 L
.30513 .29511 L
.30517 .295 L
F
.3048 .29586 m
.30443 .29672 L
.30434 .29694 L
.30473 .29603 L
.3048 .29586 L
F
.30443 .29672 m
.30406 .29758 L
.30394 .29786 L
.30434 .29694 L
.30443 .29672 L
F
.30406 .29758 m
.30369 .29844 L
.30355 .29877 L
.30394 .29786 L
.30406 .29758 L
F
.30369 .29844 m
.30332 .2993 L
.30316 .29969 L
.30355 .29877 L
.30369 .29844 L
F
.30332 .2993 m
.30295 .30016 L
.30276 .3006 L
.30316 .29969 L
.30332 .2993 L
F
.30295 .30016 m
.30258 .30102 L
.30237 .30152 L
.30276 .3006 L
.30295 .30016 L
F
.30258 .30102 m
.30221 .30188 L
.30197 .30243 L
.30237 .30152 L
.30258 .30102 L
F
.30591 .29328 m
.30552 .29419 L
.3055 .29424 L
.30591 .29328 L
.30591 .29328 L
F
.30552 .29419 m
.30513 .29511 L
.30508 .29521 L
.3055 .29424 L
.30552 .29419 L
F
.30513 .29511 m
.30473 .29603 L
.30467 .29617 L
.30508 .29521 L
.30513 .29511 L
F
.30473 .29603 m
.30434 .29694 L
.30425 .29714 L
.30467 .29617 L
.30473 .29603 L
F
.30434 .29694 m
.30394 .29786 L
.30384 .2981 L
.30425 .29714 L
.30434 .29694 L
F
.30394 .29786 m
.30355 .29877 L
.30342 .29907 L
.30384 .2981 L
.30394 .29786 L
F
.30355 .29877 m
.30316 .29969 L
.30301 .30003 L
.30342 .29907 L
.30355 .29877 L
F
.30316 .29969 m
.30276 .3006 L
.30259 .301 L
.30301 .30003 L
.30316 .29969 L
F
.30276 .3006 m
.30237 .30152 L
.30218 .30196 L
.30259 .301 L
.30276 .3006 L
F
.30237 .30152 m
.30197 .30243 L
.30176 .30293 L
.30218 .30196 L
.30237 .30152 L
F
.30591 .29328 m
.3055 .29424 L
.30548 .29429 L
.30591 .29328 L
.30591 .29328 L
F
.3055 .29424 m
.30508 .29521 L
.30505 .2953 L
.30548 .29429 L
.3055 .29424 L
F
.30508 .29521 m
.30467 .29617 L
.30461 .2963 L
.30505 .2953 L
.30508 .29521 L
F
.30467 .29617 m
.30425 .29714 L
.30418 .29731 L
.30461 .2963 L
.30467 .29617 L
F
.30425 .29714 m
.30384 .2981 L
.30374 .29832 L
.30418 .29731 L
.30425 .29714 L
F
.30384 .2981 m
.30342 .29907 L
.30331 .29933 L
.30374 .29832 L
.30384 .2981 L
F
.30342 .29907 m
.30301 .30003 L
.30288 .30034 L
.30331 .29933 L
.30342 .29907 L
F
.30301 .30003 m
.30259 .301 L
.30244 .30135 L
.30288 .30034 L
.30301 .30003 L
F
.30259 .301 m
.30218 .30196 L
.30201 .30235 L
.30244 .30135 L
.30259 .301 L
F
.30218 .30196 m
.30176 .30293 L
.30157 .30336 L
.30201 .30235 L
.30218 .30196 L
F
.30591 .29328 m
.30548 .29429 L
.30546 .29432 L
.30591 .29328 L
.30591 .29328 L
F
.30548 .29429 m
.30505 .2953 L
.30501 .29537 L
.30546 .29432 L
.30548 .29429 L
F
.30505 .2953 m
.30461 .2963 L
.30456 .29642 L
.30501 .29537 L
.30505 .2953 L
F
.30461 .2963 m
.30418 .29731 L
.30411 .29746 L
.30456 .29642 L
.30461 .2963 L
F
.30418 .29731 m
.30374 .29832 L
.30366 .29851 L
.30411 .29746 L
.30418 .29731 L
F
.30374 .29832 m
.30331 .29933 L
.30321 .29955 L
.30366 .29851 L
.30374 .29832 L
F
.30331 .29933 m
.30288 .30034 L
.30276 .3006 L
.30321 .29955 L
.30331 .29933 L
F
.30288 .30034 m
.30244 .30135 L
.30231 .30164 L
.30276 .3006 L
.30288 .30034 L
F
.30244 .30135 m
.30201 .30235 L
.30186 .30269 L
.30231 .30164 L
.30244 .30135 L
F
.30201 .30235 m
.30157 .30336 L
.30141 .30373 L
.30186 .30269 L
.30201 .30235 L
F
.30591 .29328 m
.30546 .29432 L
.30545 .29436 L
.30591 .29328 L
.30591 .29328 L
F
.30546 .29432 m
.30501 .29537 L
.30499 .29543 L
.30545 .29436 L
.30546 .29432 L
F
.30501 .29537 m
.30456 .29642 L
.30452 .29651 L
.30499 .29543 L
.30501 .29537 L
F
.30456 .29642 m
.30411 .29746 L
.30406 .29758 L
.30452 .29651 L
.30456 .29642 L
F
.30411 .29746 m
.30366 .29851 L
.3036 .29866 L
.30406 .29758 L
.30411 .29746 L
F
.30366 .29851 m
.30321 .29955 L
.30313 .29974 L
.3036 .29866 L
.30366 .29851 L
F
.30321 .29955 m
.30276 .3006 L
.30267 .30081 L
.30313 .29974 L
.30321 .29955 L
F
.30276 .3006 m
.30231 .30164 L
.30221 .30189 L
.30267 .30081 L
.30276 .3006 L
F
.30231 .30164 m
.30186 .30269 L
.30174 .30296 L
.30221 .30189 L
.30231 .30164 L
F
.30186 .30269 m
.30141 .30373 L
.30128 .30404 L
.30174 .30296 L
.30186 .30269 L
F
.30591 .29328 m
.30545 .29436 L
.30544 .29438 L
.30591 .29328 L
.30591 .29328 L
F
.30545 .29436 m
.30499 .29543 L
.30497 .29548 L
.30544 .29438 L
.30545 .29436 L
F
.30499 .29543 m
.30452 .29651 L
.30449 .29658 L
.30497 .29548 L
.30499 .29543 L
F
.30452 .29651 m
.30406 .29758 L
.30402 .29768 L
.30449 .29658 L
.30452 .29651 L
F
.30406 .29758 m
.3036 .29866 L
.30355 .29878 L
.30402 .29768 L
.30406 .29758 L
F
.3036 .29866 m
.30313 .29974 L
.30307 .29988 L
.30355 .29878 L
.3036 .29866 L
F
.30313 .29974 m
.30267 .30081 L
.3026 .30098 L
.30307 .29988 L
.30313 .29974 L
F
.30267 .30081 m
.30221 .30189 L
.30212 .30208 L
.3026 .30098 L
.30267 .30081 L
F
.30221 .30189 m
.30174 .30296 L
.30165 .30318 L
.30212 .30208 L
.30221 .30189 L
F
.30174 .30296 m
.30128 .30404 L
.30118 .30428 L
.30165 .30318 L
.30174 .30296 L
F
.30591 .29328 m
.30544 .29438 L
.30543 .2944 L
.30591 .29328 L
.30591 .29328 L
F
.30544 .29438 m
.30497 .29548 L
.30495 .29551 L
.30543 .2944 L
.30544 .29438 L
F
.30497 .29548 m
.30449 .29658 L
.30447 .29663 L
.30495 .29551 L
.30497 .29548 L
F
.30449 .29658 m
.30402 .29768 L
.30399 .29775 L
.30447 .29663 L
.30449 .29658 L
F
.30402 .29768 m
.30355 .29878 L
.30351 .29887 L
.30399 .29775 L
.30402 .29768 L
F
.30355 .29878 m
.30307 .29988 L
.30303 .29999 L
.30351 .29887 L
.30355 .29878 L
F
.30307 .29988 m
.3026 .30098 L
.30255 .3011 L
.30303 .29999 L
.30307 .29988 L
F
.3026 .30098 m
.30212 .30208 L
.30206 .30222 L
.30255 .3011 L
.3026 .30098 L
F
.30212 .30208 m
.30165 .30318 L
.30158 .30334 L
.30206 .30222 L
.30212 .30208 L
F
.30165 .30318 m
.30118 .30428 L
.3011 .30446 L
.30158 .30334 L
.30165 .30318 L
F
.30591 .29328 m
.30543 .2944 L
.30543 .29441 L
.30591 .29328 L
.30591 .29328 L
F
.30543 .2944 m
.30495 .29551 L
.30494 .29554 L
.30543 .29441 L
.30543 .2944 L
F
.30495 .29551 m
.30447 .29663 L
.30446 .29666 L
.30494 .29554 L
.30495 .29551 L
F
.30447 .29663 m
.30399 .29775 L
.30397 .29779 L
.30446 .29666 L
.30447 .29663 L
F
.30399 .29775 m
.30351 .29887 L
.30349 .29892 L
.30397 .29779 L
.30399 .29775 L
F
.30351 .29887 m
.30303 .29999 L
.303 .30005 L
.30349 .29892 L
.30351 .29887 L
F
.30303 .29999 m
.30255 .3011 L
.30251 .30118 L
.303 .30005 L
.30303 .29999 L
F
.30255 .3011 m
.30206 .30222 L
.30203 .3023 L
.30251 .30118 L
.30255 .3011 L
F
.30206 .30222 m
.30158 .30334 L
.30154 .30343 L
.30203 .3023 L
.30206 .30222 L
F
.30158 .30334 m
.3011 .30446 L
.30106 .30456 L
.30154 .30343 L
.30158 .30334 L
F
.30591 .29328 m
.30543 .29441 L
.30543 .29441 L
.30591 .29328 L
.30591 .29328 L
F
.30543 .29441 m
.30494 .29554 L
.30494 .29554 L
.30543 .29441 L
.30543 .29441 L
F
.30494 .29554 m
.30446 .29666 L
.30445 .29667 L
.30494 .29554 L
.30494 .29554 L
F
.30446 .29666 m
.30397 .29779 L
.30397 .29781 L
.30445 .29667 L
.30446 .29666 L
F
.30397 .29779 m
.30349 .29892 L
.30348 .29894 L
.30397 .29781 L
.30397 .29779 L
F
.30349 .29892 m
.303 .30005 L
.30299 .30007 L
.30348 .29894 L
.30349 .29892 L
F
.303 .30005 m
.30251 .30118 L
.3025 .3012 L
.30299 .30007 L
.303 .30005 L
F
.30251 .30118 m
.30203 .3023 L
.30202 .30233 L
.3025 .3012 L
.30251 .30118 L
F
.30203 .3023 m
.30154 .30343 L
.30153 .30346 L
.30202 .30233 L
.30203 .3023 L
F
.30154 .30343 m
.30106 .30456 L
.30104 .30459 L
.30153 .30346 L
.30154 .30343 L
F
0 g
.30104 .30459 m
.30106 .30456 L
.3011 .30446 L
.30118 .30428 L
.30128 .30404 L
.30141 .30373 L
.30157 .30336 L
.30176 .30293 L
.30197 .30243 L
.30221 .30188 L
.30247 .30128 L
.30275 .30063 L
.30305 .29993 L
.30337 .29919 L
.3037 .29842 L
.30405 .29761 L
.30441 .29678 L
.30478 .29592 L
.30515 .29505 L
.30553 .29417 L
.30591 .29328 L
.3063 .29239 L
.30668 .29151 L
.30705 .29064 L
.30742 .28978 L
.30778 .28895 L
.30813 .28814 L
.30846 .28737 L
.30878 .28663 L
.30908 .28593 L
.30936 .28528 L
.30962 .28468 L
.30986 .28413 L
.31007 .28363 L
.31026 .2832 L
.31042 .28283 L
.31055 .28252 L
.31065 .28228 L
.31073 .2821 L
.31077 .282 L
.31079 .28196 L
.31077 .282 L
.31073 .2821 L
.31065 .28228 L
.31055 .28252 L
.31042 .28283 L
.31026 .2832 L
.31007 .28363 L
.30986 .28413 L
.30962 .28468 L
Mistroke
.30936 .28528 L
.30908 .28593 L
.30878 .28663 L
.30846 .28737 L
.30813 .28814 L
.30778 .28895 L
.30742 .28978 L
.30705 .29064 L
.30668 .29151 L
.3063 .29239 L
.30591 .29328 L
.30553 .29417 L
.30515 .29505 L
.30478 .29592 L
.30441 .29678 L
.30405 .29761 L
.3037 .29842 L
.30337 .29919 L
.30305 .29993 L
.30275 .30063 L
.30247 .30128 L
.30221 .30188 L
.30197 .30243 L
.30176 .30293 L
.30157 .30336 L
.30141 .30373 L
.30128 .30404 L
.30118 .30428 L
.3011 .30446 L
.30106 .30456 L
.30104 .30459 L
Mfstroke
.5 g
.2955 .30221 m
.30104 .30459 L
.30106 .30456 L
.29552 .30217 L
.2955 .30221 L
F
.29552 .30217 m
.30106 .30456 L
.3011 .30446 L
.29556 .30207 L
.29552 .30217 L
F
.29556 .30207 m
.3011 .30446 L
.30118 .30428 L
.29563 .3019 L
.29556 .30207 L
F
.29563 .3019 m
.30118 .30428 L
.30128 .30404 L
.29574 .30165 L
.29563 .3019 L
F
.29574 .30165 m
.30128 .30404 L
.30141 .30373 L
.29587 .30135 L
.29574 .30165 L
F
.29587 .30135 m
.30141 .30373 L
.30157 .30336 L
.29603 .30098 L
.29587 .30135 L
F
.29603 .30098 m
.30157 .30336 L
.30176 .30293 L
.29622 .30054 L
.29603 .30098 L
F
.29622 .30054 m
.30176 .30293 L
.30197 .30243 L
.29643 .30005 L
.29622 .30054 L
F
.29643 .30005 m
.30197 .30243 L
.30221 .30188 L
.29667 .2995 L
.29643 .30005 L
F
.29667 .2995 m
.30221 .30188 L
.30247 .30128 L
.29693 .29889 L
.29667 .2995 L
F
.29693 .29889 m
.30247 .30128 L
.30275 .30063 L
.29721 .29824 L
.29693 .29889 L
F
.29721 .29824 m
.30275 .30063 L
.30305 .29993 L
.29751 .29754 L
.29721 .29824 L
F
.29751 .29754 m
.30305 .29993 L
.30337 .29919 L
.29783 .29681 L
.29751 .29754 L
F
.29783 .29681 m
.30337 .29919 L
.3037 .29842 L
.29816 .29603 L
.29783 .29681 L
F
.29816 .29603 m
.3037 .29842 L
.30405 .29761 L
.29851 .29522 L
.29816 .29603 L
F
.29851 .29522 m
.30405 .29761 L
.30441 .29678 L
.29887 .29439 L
.29851 .29522 L
F
.29887 .29439 m
.30441 .29678 L
.30478 .29592 L
.29923 .29353 L
.29887 .29439 L
F
.29923 .29353 m
.30478 .29592 L
.30515 .29505 L
.29961 .29266 L
.29923 .29353 L
F
.29961 .29266 m
.30515 .29505 L
.30553 .29417 L
.29999 .29178 L
.29961 .29266 L
F
.29999 .29178 m
.30553 .29417 L
.30591 .29328 L
.30037 .29089 L
.29999 .29178 L
F
.30037 .29089 m
.30591 .29328 L
.3063 .29239 L
.30075 .29001 L
.30037 .29089 L
F
.30075 .29001 m
.3063 .29239 L
.30668 .29151 L
.30113 .28912 L
.30075 .29001 L
F
.30113 .28912 m
.30668 .29151 L
.30705 .29064 L
.30151 .28825 L
.30113 .28912 L
F
.30151 .28825 m
.30705 .29064 L
.30742 .28978 L
.30188 .2874 L
.30151 .28825 L
F
.30188 .2874 m
.30742 .28978 L
.30778 .28895 L
.30224 .28656 L
.30188 .2874 L
F
.30224 .28656 m
.30778 .28895 L
.30813 .28814 L
.30258 .28576 L
.30224 .28656 L
F
.30258 .28576 m
.30813 .28814 L
.30846 .28737 L
.30292 .28498 L
.30258 .28576 L
F
.30292 .28498 m
.30846 .28737 L
.30878 .28663 L
.30324 .28424 L
.30292 .28498 L
F
.30324 .28424 m
.30878 .28663 L
.30908 .28593 L
.30354 .28354 L
.30324 .28424 L
F
.30354 .28354 m
.30908 .28593 L
.30936 .28528 L
.30382 .28289 L
.30354 .28354 L
F
.30382 .28289 m
.30936 .28528 L
.30962 .28468 L
.30408 .28229 L
.30382 .28289 L
F
.30408 .28229 m
.30962 .28468 L
.30986 .28413 L
.30431 .28174 L
.30408 .28229 L
F
.30431 .28174 m
.30986 .28413 L
.31007 .28363 L
.30453 .28125 L
.30431 .28174 L
F
.30453 .28125 m
.31007 .28363 L
.31026 .2832 L
.30471 .28081 L
.30453 .28125 L
F
.30471 .28081 m
.31026 .2832 L
.31042 .28283 L
.30487 .28044 L
.30471 .28081 L
F
.30487 .28044 m
.31042 .28283 L
.31055 .28252 L
.30501 .28013 L
.30487 .28044 L
F
.30501 .28013 m
.31055 .28252 L
.31065 .28228 L
.30511 .27989 L
.30501 .28013 L
F
.30511 .27989 m
.31065 .28228 L
.31073 .2821 L
.30518 .27972 L
.30511 .27989 L
F
.30518 .27972 m
.31073 .2821 L
.31077 .282 L
.30523 .27961 L
.30518 .27972 L
F
.30523 .27961 m
.31077 .282 L
.31079 .28196 L
.30524 .27958 L
.30523 .27961 L
F
.30524 .27958 m
.31079 .28196 L
.31077 .282 L
.30523 .27961 L
.30524 .27958 L
F
.30523 .27961 m
.31077 .282 L
.31073 .2821 L
.30518 .27972 L
.30523 .27961 L
F
.30518 .27972 m
.31073 .2821 L
.31065 .28228 L
.30511 .27989 L
.30518 .27972 L
F
.30511 .27989 m
.31065 .28228 L
.31055 .28252 L
.30501 .28013 L
.30511 .27989 L
F
.30501 .28013 m
.31055 .28252 L
.31042 .28283 L
.30487 .28044 L
.30501 .28013 L
F
.30487 .28044 m
.31042 .28283 L
.31026 .2832 L
.30471 .28081 L
.30487 .28044 L
F
.30471 .28081 m
.31026 .2832 L
.31007 .28363 L
.30453 .28125 L
.30471 .28081 L
F
.30453 .28125 m
.31007 .28363 L
.30986 .28413 L
.30431 .28174 L
.30453 .28125 L
F
.30431 .28174 m
.30986 .28413 L
.30962 .28468 L
.30408 .28229 L
.30431 .28174 L
F
.30408 .28229 m
.30962 .28468 L
.30936 .28528 L
.30382 .28289 L
.30408 .28229 L
F
.30382 .28289 m
.30936 .28528 L
.30908 .28593 L
.30354 .28354 L
.30382 .28289 L
F
.30354 .28354 m
.30908 .28593 L
.30878 .28663 L
.30324 .28424 L
.30354 .28354 L
F
.30324 .28424 m
.30878 .28663 L
.30846 .28737 L
.30292 .28498 L
.30324 .28424 L
F
.30292 .28498 m
.30846 .28737 L
.30813 .28814 L
.30258 .28576 L
.30292 .28498 L
F
.30258 .28576 m
.30813 .28814 L
.30778 .28895 L
.30224 .28656 L
.30258 .28576 L
F
.30224 .28656 m
.30778 .28895 L
.30742 .28978 L
.30188 .2874 L
.30224 .28656 L
F
.30188 .2874 m
.30742 .28978 L
.30705 .29064 L
.30151 .28825 L
.30188 .2874 L
F
.30151 .28825 m
.30705 .29064 L
.30668 .29151 L
.30113 .28912 L
.30151 .28825 L
F
.30113 .28912 m
.30668 .29151 L
.3063 .29239 L
.30075 .29001 L
.30113 .28912 L
F
.30075 .29001 m
.3063 .29239 L
.30591 .29328 L
.30037 .29089 L
.30075 .29001 L
F
.30037 .29089 m
.30591 .29328 L
.30553 .29417 L
.29999 .29178 L
.30037 .29089 L
F
.29999 .29178 m
.30553 .29417 L
.30515 .29505 L
.29961 .29266 L
.29999 .29178 L
F
.29961 .29266 m
.30515 .29505 L
.30478 .29592 L
.29923 .29353 L
.29961 .29266 L
F
.29923 .29353 m
.30478 .29592 L
.30441 .29678 L
.29887 .29439 L
.29923 .29353 L
F
.29887 .29439 m
.30441 .29678 L
.30405 .29761 L
.29851 .29522 L
.29887 .29439 L
F
.29851 .29522 m
.30405 .29761 L
.3037 .29842 L
.29816 .29603 L
.29851 .29522 L
F
.29816 .29603 m
.3037 .29842 L
.30337 .29919 L
.29783 .29681 L
.29816 .29603 L
F
.29783 .29681 m
.30337 .29919 L
.30305 .29993 L
.29751 .29754 L
.29783 .29681 L
F
.29751 .29754 m
.30305 .29993 L
.30275 .30063 L
.29721 .29824 L
.29751 .29754 L
F
.29721 .29824 m
.30275 .30063 L
.30247 .30128 L
.29693 .29889 L
.29721 .29824 L
F
.29693 .29889 m
.30247 .30128 L
.30221 .30188 L
.29667 .2995 L
.29693 .29889 L
F
.29667 .2995 m
.30221 .30188 L
.30197 .30243 L
.29643 .30005 L
.29667 .2995 L
F
.29643 .30005 m
.30197 .30243 L
.30176 .30293 L
.29622 .30054 L
.29643 .30005 L
F
.29622 .30054 m
.30176 .30293 L
.30157 .30336 L
.29603 .30098 L
.29622 .30054 L
F
.29603 .30098 m
.30157 .30336 L
.30141 .30373 L
.29587 .30135 L
.29603 .30098 L
F
.29587 .30135 m
.30141 .30373 L
.30128 .30404 L
.29574 .30165 L
.29587 .30135 L
F
.29574 .30165 m
.30128 .30404 L
.30118 .30428 L
.29563 .3019 L
.29574 .30165 L
F
.29563 .3019 m
.30118 .30428 L
.3011 .30446 L
.29556 .30207 L
.29563 .3019 L
F
.29556 .30207 m
.3011 .30446 L
.30106 .30456 L
.29552 .30217 L
.29556 .30207 L
F
.29552 .30217 m
.30106 .30456 L
.30104 .30459 L
.2955 .30221 L
.29552 .30217 L
F
.13765 .07775 m
.13901 .07841 L
.13768 .08112 L
.13633 .08046 L
.13765 .07775 L
F
.13633 .08046 m
.13768 .08112 L
.13635 .08383 L
.135 .08317 L
.13633 .08046 L
F
.135 .08317 m
.13635 .08383 L
.13502 .08654 L
.13367 .08588 L
.135 .08317 L
F
.13367 .08588 m
.13502 .08654 L
.1337 .08925 L
.13234 .08859 L
.13367 .08588 L
F
.13234 .08859 m
.1337 .08925 L
.13237 .09196 L
.13102 .0913 L
.13234 .08859 L
F
.13102 .0913 m
.13237 .09196 L
.13104 .09467 L
.12969 .094 L
.13102 .0913 L
F
.12969 .094 m
.13104 .09467 L
.12971 .09738 L
.12836 .09671 L
.12969 .094 L
F
.12836 .09671 m
.12971 .09738 L
.12839 .10009 L
.12703 .09942 L
.12836 .09671 L
F
.12703 .09942 m
.12839 .10009 L
.12706 .1028 L
.12571 .10213 L
.12703 .09942 L
F
.12571 .10213 m
.12706 .1028 L
.12573 .10551 L
.12438 .10484 L
.12571 .10213 L
F
.12438 .10484 m
.12573 .10551 L
.1244 .10822 L
.12305 .10755 L
.12438 .10484 L
F
.12305 .10755 m
.1244 .10822 L
.12308 .11092 L
.12172 .11026 L
.12305 .10755 L
F
.12172 .11026 m
.12308 .11092 L
.12175 .11363 L
.1204 .11297 L
.12172 .11026 L
F
.1204 .11297 m
.12175 .11363 L
.12042 .11634 L
.11907 .11568 L
.1204 .11297 L
F
.11907 .11568 m
.12042 .11634 L
.11909 .11905 L
.11774 .11839 L
.11907 .11568 L
F
.11774 .11839 m
.11909 .11905 L
.11777 .12176 L
.11641 .1211 L
.11774 .11839 L
F
.11641 .1211 m
.11777 .12176 L
.11644 .12447 L
.11509 .12381 L
.11641 .1211 L
F
.11509 .12381 m
.11644 .12447 L
.11511 .12718 L
.11376 .12652 L
.11509 .12381 L
F
.11376 .12652 m
.11511 .12718 L
.11378 .12989 L
.11243 .12923 L
.11376 .12652 L
F
.11243 .12923 m
.11378 .12989 L
.11246 .1326 L
.1111 .13194 L
.11243 .12923 L
F
0 g
.13765 .07775 m
.13633 .08046 L
.135 .08317 L
.13367 .08588 L
.13234 .08859 L
.13102 .0913 L
.12969 .094 L
.12836 .09671 L
.12703 .09942 L
.12571 .10213 L
.12438 .10484 L
.12305 .10755 L
.12172 .11026 L
.1204 .11297 L
.11907 .11568 L
.11774 .11839 L
.11641 .1211 L
.11509 .12381 L
.11376 .12652 L
.11243 .12923 L
.1111 .13194 L
.11246 .1326 L
.11378 .12989 L
.11511 .12718 L
.11644 .12447 L
.11777 .12176 L
.11909 .11905 L
.12042 .11634 L
.12175 .11363 L
.12308 .11092 L
.1244 .10822 L
.12573 .10551 L
.12706 .1028 L
.12839 .10009 L
.12971 .09738 L
.13104 .09467 L
.13237 .09196 L
.1337 .08925 L
.13502 .08654 L
.13635 .08383 L
.13768 .08112 L
.13901 .07841 L
.13765 .07775 L
s
.5 g
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
0 g
.12438 .10484 m
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
s
.1111 .13194 m
.11246 .1326 L
.1125 .13252 L
.11114 .13185 L
.1111 .13194 L
s
.11114 .13185 m
.1125 .13252 L
.11262 .13227 L
.11127 .1316 L
.11114 .13185 L
s
.11127 .1316 m
.11262 .13227 L
.11282 .13185 L
.11147 .13119 L
.11127 .1316 L
s
.11147 .13119 m
.11282 .13185 L
.11311 .13127 L
.11175 .13061 L
.11147 .13119 L
s
.11175 .13061 m
.11311 .13127 L
.11347 .13054 L
.11211 .12987 L
.11175 .13061 L
s
.11211 .12987 m
.11347 .13054 L
.1139 .12965 L
.11255 .12898 L
.11211 .12987 L
s
.11255 .12898 m
.1139 .12965 L
.11441 .12861 L
.11306 .12794 L
.11255 .12898 L
s
.11306 .12794 m
.11441 .12861 L
.11499 .12742 L
.11364 .12676 L
.11306 .12794 L
s
.11364 .12676 m
.11499 .12742 L
.11564 .12611 L
.11428 .12544 L
.11364 .12676 L
s
.11428 .12544 m
.11564 .12611 L
.11635 .12466 L
.11499 .124 L
.11428 .12544 L
s
.11499 .124 m
.11635 .12466 L
.11711 .1231 L
.11576 .12244 L
.11499 .124 L
s
.11576 .12244 m
.11711 .1231 L
.11793 .12143 L
.11657 .12077 L
.11576 .12244 L
s
.11657 .12077 m
.11793 .12143 L
.1188 .11966 L
.11744 .119 L
.11657 .12077 L
s
.11744 .119 m
.1188 .11966 L
.11971 .11781 L
.11835 .11714 L
.11744 .119 L
s
.11835 .11714 m
.11971 .11781 L
.12065 .11587 L
.1193 .11521 L
.11835 .11714 L
s
.1193 .11521 m
.12065 .11587 L
.12163 .11388 L
.12028 .11321 L
.1193 .11521 L
s
.12028 .11321 m
.12163 .11388 L
.12263 .11183 L
.12128 .11117 L
.12028 .11321 L
s
.12128 .11117 m
.12263 .11183 L
.12366 .10974 L
.1223 .10908 L
.12128 .11117 L
s
.1223 .10908 m
.12366 .10974 L
.12469 .10763 L
.12334 .10697 L
.1223 .10908 L
s
.12334 .10697 m
.12469 .10763 L
.12573 .10551 L
.12438 .10484 L
.12334 .10697 L
s
.12438 .10484 m
.12573 .10551 L
.12677 .10338 L
.12542 .10272 L
.12438 .10484 L
s
.12542 .10272 m
.12677 .10338 L
.12781 .10127 L
.12645 .1006 L
.12542 .10272 L
s
.12645 .1006 m
.12781 .10127 L
.12883 .09918 L
.12748 .09852 L
.12645 .1006 L
s
.12748 .09852 m
.12883 .09918 L
.12983 .09713 L
.12848 .09647 L
.12748 .09852 L
s
.12848 .09647 m
.12983 .09713 L
.13081 .09514 L
.12946 .09447 L
.12848 .09647 L
s
.12946 .09447 m
.13081 .09514 L
.13176 .09321 L
.1304 .09254 L
.12946 .09447 L
s
.1304 .09254 m
.13176 .09321 L
.13267 .09135 L
.13131 .09069 L
.1304 .09254 L
s
.13131 .09069 m
.13267 .09135 L
.13354 .08958 L
.13218 .08892 L
.13131 .09069 L
s
.13218 .08892 m
.13354 .08958 L
.13435 .08791 L
.133 .08725 L
.13218 .08892 L
s
.133 .08725 m
.13435 .08791 L
.13512 .08635 L
.13376 .08568 L
.133 .08725 L
s
.13376 .08568 m
.13512 .08635 L
.13583 .0849 L
.13447 .08424 L
.13376 .08568 L
s
.13447 .08424 m
.13583 .0849 L
.13647 .08359 L
.13512 .08292 L
.13447 .08424 L
s
.13512 .08292 m
.13647 .08359 L
.13705 .08241 L
.1357 .08174 L
.13512 .08292 L
s
.1357 .08174 m
.13705 .08241 L
.13756 .08137 L
.13621 .0807 L
.1357 .08174 L
s
.13621 .0807 m
.13756 .08137 L
.138 .08048 L
.13664 .07981 L
.13621 .0807 L
s
.13664 .07981 m
.138 .08048 L
.13836 .07974 L
.137 .07908 L
.13664 .07981 L
s
.137 .07908 m
.13836 .07974 L
.13864 .07916 L
.13729 .0785 L
.137 .07908 L
s
.13729 .0785 m
.13864 .07916 L
.13884 .07875 L
.13749 .07808 L
.13729 .0785 L
s
.13749 .07808 m
.13884 .07875 L
.13897 .0785 L
.13761 .07783 L
.13749 .07808 L
s
.13761 .07783 m
.13897 .0785 L
.13901 .07841 L
.13765 .07775 L
.13761 .07783 L
s
.13765 .07775 m
.13901 .07841 L
.13897 .0785 L
.13761 .07783 L
.13765 .07775 L
s
.13761 .07783 m
.13897 .0785 L
.13884 .07875 L
.13749 .07808 L
.13761 .07783 L
s
.13749 .07808 m
.13884 .07875 L
.13864 .07916 L
.13729 .0785 L
.13749 .07808 L
s
.13729 .0785 m
.13864 .07916 L
.13836 .07974 L
.137 .07908 L
.13729 .0785 L
s
.137 .07908 m
.13836 .07974 L
.138 .08048 L
.13664 .07981 L
.137 .07908 L
s
.13664 .07981 m
.138 .08048 L
.13756 .08137 L
.13621 .0807 L
.13664 .07981 L
s
.13621 .0807 m
.13756 .08137 L
.13705 .08241 L
.1357 .08174 L
.13621 .0807 L
s
.1357 .08174 m
.13705 .08241 L
.13647 .08359 L
.13512 .08292 L
.1357 .08174 L
s
.13512 .08292 m
.13647 .08359 L
.13583 .0849 L
.13447 .08424 L
.13512 .08292 L
s
.13447 .08424 m
.13583 .0849 L
.13512 .08635 L
.13376 .08568 L
.13447 .08424 L
s
.13376 .08568 m
.13512 .08635 L
.13435 .08791 L
.133 .08725 L
.13376 .08568 L
s
.133 .08725 m
.13435 .08791 L
.13354 .08958 L
.13218 .08892 L
.133 .08725 L
s
.13218 .08892 m
.13354 .08958 L
.13267 .09135 L
.13131 .09069 L
.13218 .08892 L
s
.13131 .09069 m
.13267 .09135 L
.13176 .09321 L
.1304 .09254 L
.13131 .09069 L
s
.1304 .09254 m
.13176 .09321 L
.13081 .09514 L
.12946 .09447 L
.1304 .09254 L
s
.12946 .09447 m
.13081 .09514 L
.12983 .09713 L
.12848 .09647 L
.12946 .09447 L
s
.12848 .09647 m
.12983 .09713 L
.12883 .09918 L
.12748 .09852 L
.12848 .09647 L
s
.12748 .09852 m
.12883 .09918 L
.12781 .10127 L
.12645 .1006 L
.12748 .09852 L
s
.12645 .1006 m
.12781 .10127 L
.12677 .10338 L
.12542 .10272 L
.12645 .1006 L
s
.12542 .10272 m
.12677 .10338 L
.12573 .10551 L
.12438 .10484 L
.12542 .10272 L
s
.12438 .10484 m
.12573 .10551 L
.12469 .10763 L
.12334 .10697 L
.12438 .10484 L
s
.12334 .10697 m
.12469 .10763 L
.12366 .10974 L
.1223 .10908 L
.12334 .10697 L
s
.1223 .10908 m
.12366 .10974 L
.12263 .11183 L
.12128 .11117 L
.1223 .10908 L
s
.12128 .11117 m
.12263 .11183 L
.12163 .11388 L
.12028 .11321 L
.12128 .11117 L
s
.12028 .11321 m
.12163 .11388 L
.12065 .11587 L
.1193 .11521 L
.12028 .11321 L
s
.1193 .11521 m
.12065 .11587 L
.11971 .11781 L
.11835 .11714 L
.1193 .11521 L
s
.11835 .11714 m
.11971 .11781 L
.1188 .11966 L
.11744 .119 L
.11835 .11714 L
s
.11744 .119 m
.1188 .11966 L
.11793 .12143 L
.11657 .12077 L
.11744 .119 L
s
.11657 .12077 m
.11793 .12143 L
.11711 .1231 L
.11576 .12244 L
.11657 .12077 L
s
.11576 .12244 m
.11711 .1231 L
.11635 .12466 L
.11499 .124 L
.11576 .12244 L
s
.11499 .124 m
.11635 .12466 L
.11564 .12611 L
.11428 .12544 L
.11499 .124 L
s
.11428 .12544 m
.11564 .12611 L
.11499 .12742 L
.11364 .12676 L
.11428 .12544 L
s
.11364 .12676 m
.11499 .12742 L
.11441 .12861 L
.11306 .12794 L
.11364 .12676 L
s
.11306 .12794 m
.11441 .12861 L
.1139 .12965 L
.11255 .12898 L
.11306 .12794 L
s
.11255 .12898 m
.1139 .12965 L
.11347 .13054 L
.11211 .12987 L
.11255 .12898 L
s
.11211 .12987 m
.11347 .13054 L
.11311 .13127 L
.11175 .13061 L
.11211 .12987 L
s
.11175 .13061 m
.11311 .13127 L
.11282 .13185 L
.11147 .13119 L
.11175 .13061 L
s
.11147 .13119 m
.11282 .13185 L
.11262 .13227 L
.11127 .1316 L
.11147 .13119 L
s
.11127 .1316 m
.11262 .13227 L
.1125 .13252 L
.11114 .13185 L
.11127 .1316 L
s
.11114 .13185 m
.1125 .13252 L
.11246 .1326 L
.1111 .13194 L
.11114 .13185 L
s
.5 g
.62481 .06462 m
.62352 .05157 L
.60192 .05689 L
.60767 .06864 L
.62481 .06462 L
F
.60767 .06864 m
.60192 .05689 L
.5932 .06222 L
.60107 .07266 L
.60767 .06864 L
F
.60107 .07266 m
.5932 .06222 L
.58712 .06755 L
.59648 .07668 L
.60107 .07266 L
F
.59648 .07668 m
.58712 .06755 L
.58255 .07288 L
.59302 .08071 L
.59648 .07668 L
F
.59302 .08071 m
.58255 .07288 L
.57904 .0782 L
.59037 .08473 L
.59302 .08071 L
F
.59037 .08473 m
.57904 .0782 L
.57635 .08353 L
.58834 .08875 L
.59037 .08473 L
F
.58834 .08875 m
.57635 .08353 L
.57436 .08886 L
.58683 .09277 L
.58834 .08875 L
F
.58683 .09277 m
.57436 .08886 L
.57298 .09419 L
.58579 .0968 L
.58683 .09277 L
F
.58579 .0968 m
.57298 .09419 L
.57217 .09951 L
.58518 .10082 L
.58579 .0968 L
F
.58518 .10082 m
.57217 .09951 L
.57191 .10484 L
.58498 .10484 L
.58518 .10082 L
F
.58498 .10484 m
.57191 .10484 L
.57217 .11017 L
.58518 .10886 L
.58498 .10484 L
F
.58518 .10886 m
.57217 .11017 L
.57298 .1155 L
.58579 .11289 L
.58518 .10886 L
F
.58579 .11289 m
.57298 .1155 L
.57436 .12082 L
.58683 .11691 L
.58579 .11289 L
F
.58683 .11691 m
.57436 .12082 L
.57635 .12615 L
.58834 .12093 L
.58683 .11691 L
F
.58834 .12093 m
.57635 .12615 L
.57904 .13148 L
.59037 .12495 L
.58834 .12093 L
F
.59037 .12495 m
.57904 .13148 L
.58255 .13681 L
.59302 .12898 L
.59037 .12495 L
F
.59302 .12898 m
.58255 .13681 L
.58712 .14213 L
.59648 .133 L
.59302 .12898 L
F
.59648 .133 m
.58712 .14213 L
.5932 .14746 L
.60107 .13702 L
.59648 .133 L
F
.60107 .13702 m
.5932 .14746 L
.60192 .15279 L
.60767 .14104 L
.60107 .13702 L
F
.60767 .14104 m
.60192 .15279 L
.62352 .15812 L
.62481 .14507 L
.60767 .14104 L
F
0 g
.62481 .06462 m
.60767 .06864 L
.60107 .07266 L
.59648 .07668 L
.59302 .08071 L
.59037 .08473 L
.58834 .08875 L
.58683 .09277 L
.58579 .0968 L
.58518 .10082 L
.58498 .10484 L
.58518 .10886 L
.58579 .11289 L
.58683 .11691 L
.58834 .12093 L
.59037 .12495 L
.59302 .12898 L
.59648 .133 L
.60107 .13702 L
.60767 .14104 L
.62481 .14507 L
.62352 .15812 L
.60192 .15279 L
.5932 .14746 L
.58712 .14213 L
.58255 .13681 L
.57904 .13148 L
.57635 .12615 L
.57436 .12082 L
.57298 .1155 L
.57217 .11017 L
.57191 .10484 L
.57217 .09951 L
.57298 .09419 L
.57436 .08886 L
.57635 .08353 L
.57904 .0782 L
.58255 .07288 L
.58712 .06755 L
.5932 .06222 L
.60192 .05689 L
.62352 .05157 L
.62481 .06462 L
s
.5 g
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
0 g
.58498 .10484 m
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
s
.62481 .06462 m
.62352 .05157 L
.60192 .05689 L
.60767 .06864 L
.62481 .06462 L
s
.60767 .06864 m
.60192 .05689 L
.5932 .06222 L
.60107 .07266 L
.60767 .06864 L
s
.60107 .07266 m
.5932 .06222 L
.58712 .06755 L
.59648 .07668 L
.60107 .07266 L
s
.59648 .07668 m
.58712 .06755 L
.58255 .07288 L
.59302 .08071 L
.59648 .07668 L
s
.59302 .08071 m
.58255 .07288 L
.57904 .0782 L
.59037 .08473 L
.59302 .08071 L
s
.59037 .08473 m
.57904 .0782 L
.57635 .08353 L
.58834 .08875 L
.59037 .08473 L
s
.58834 .08875 m
.57635 .08353 L
.57436 .08886 L
.58683 .09277 L
.58834 .08875 L
s
.58683 .09277 m
.57436 .08886 L
.57298 .09419 L
.58579 .0968 L
.58683 .09277 L
s
.58579 .0968 m
.57298 .09419 L
.57217 .09951 L
.58518 .10082 L
.58579 .0968 L
s
.58518 .10082 m
.57217 .09951 L
.57191 .10484 L
.58498 .10484 L
.58518 .10082 L
s
.58498 .10484 m
.57191 .10484 L
.57217 .11017 L
.58518 .10886 L
.58498 .10484 L
s
.58518 .10886 m
.57217 .11017 L
.57298 .1155 L
.58579 .11289 L
.58518 .10886 L
s
.58579 .11289 m
.57298 .1155 L
.57436 .12082 L
.58683 .11691 L
.58579 .11289 L
s
.58683 .11691 m
.57436 .12082 L
.57635 .12615 L
.58834 .12093 L
.58683 .11691 L
s
.58834 .12093 m
.57635 .12615 L
.57904 .13148 L
.59037 .12495 L
.58834 .12093 L
s
.59037 .12495 m
.57904 .13148 L
.58255 .13681 L
.59302 .12898 L
.59037 .12495 L
s
.59302 .12898 m
.58255 .13681 L
.58712 .14213 L
.59648 .133 L
.59302 .12898 L
s
.59648 .133 m
.58712 .14213 L
.5932 .14746 L
.60107 .13702 L
.59648 .133 L
s
.60107 .13702 m
.5932 .14746 L
.60192 .15279 L
.60767 .14104 L
.60107 .13702 L
s
.60767 .14104 m
.60192 .15279 L
.62352 .15812 L
.62481 .14507 L
.60767 .14104 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.62352 .15812 L
.62481 .14507 L
.62481 .14507 L
s
.62481 .14507 m
.62352 .15812 L
.60192 .15279 L
.60767 .14104 L
.62481 .14507 L
s
.60767 .14104 m
.60192 .15279 L
.5932 .14746 L
.60107 .13702 L
.60767 .14104 L
s
.60107 .13702 m
.5932 .14746 L
.58712 .14213 L
.59648 .133 L
.60107 .13702 L
s
.59648 .133 m
.58712 .14213 L
.58255 .13681 L
.59302 .12898 L
.59648 .133 L
s
.59302 .12898 m
.58255 .13681 L
.57904 .13148 L
.59037 .12495 L
.59302 .12898 L
s
.59037 .12495 m
.57904 .13148 L
.57635 .12615 L
.58834 .12093 L
.59037 .12495 L
s
.58834 .12093 m
.57635 .12615 L
.57436 .12082 L
.58683 .11691 L
.58834 .12093 L
s
.58683 .11691 m
.57436 .12082 L
.57298 .1155 L
.58579 .11289 L
.58683 .11691 L
s
.58579 .11289 m
.57298 .1155 L
.57217 .11017 L
.58518 .10886 L
.58579 .11289 L
s
.58518 .10886 m
.57217 .11017 L
.57191 .10484 L
.58498 .10484 L
.58518 .10886 L
s
.58498 .10484 m
.57191 .10484 L
.57217 .09951 L
.58518 .10082 L
.58498 .10484 L
s
.58518 .10082 m
.57217 .09951 L
.57298 .09419 L
.58579 .0968 L
.58518 .10082 L
s
.58579 .0968 m
.57298 .09419 L
.57436 .08886 L
.58683 .09277 L
.58579 .0968 L
s
.58683 .09277 m
.57436 .08886 L
.57635 .08353 L
.58834 .08875 L
.58683 .09277 L
s
.58834 .08875 m
.57635 .08353 L
.57904 .0782 L
.59037 .08473 L
.58834 .08875 L
s
.59037 .08473 m
.57904 .0782 L
.58255 .07288 L
.59302 .08071 L
.59037 .08473 L
s
.59302 .08071 m
.58255 .07288 L
.58712 .06755 L
.59648 .07668 L
.59302 .08071 L
s
.59648 .07668 m
.58712 .06755 L
.5932 .06222 L
.60107 .07266 L
.59648 .07668 L
s
.60107 .07266 m
.5932 .06222 L
.60192 .05689 L
.60767 .06864 L
.60107 .07266 L
s
.60767 .06864 m
.60192 .05689 L
.62352 .05157 L
.62481 .06462 L
.60767 .06864 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.62481 .06462 m
.62352 .05157 L
.62352 .05157 L
.62481 .06462 L
.62481 .06462 L
s
.5 g
.55682 .13753 m
.55682 .16267 L
.55682 .16267 L
.55682 .13753 L
.55682 .13753 L
F
0 g
.55682 .13753 m
.55682 .16267 L
.55682 .16267 L
.55682 .13753 L
.55682 .13753 L
s
.5 g
.55682 .04702 m
.55682 .07216 L
.55682 .07216 L
.55682 .04702 L
.55682 .04702 L
F
0 g
.55682 .04702 m
.55682 .07216 L
.55682 .07216 L
.55682 .04702 L
.55682 .04702 L
s
.5 g
.54727 .04098 m
.54878 .04098 L
.54878 .04737 L
.54727 .04737 L
.54727 .04098 L
F
.54727 .04737 m
.54878 .04737 L
.54878 .05375 L
.54727 .05375 L
.54727 .04737 L
F
.54727 .05375 m
.54878 .05375 L
.54878 .06014 L
.54727 .06014 L
.54727 .05375 L
F
.54727 .06014 m
.54878 .06014 L
.54878 .06653 L
.54727 .06653 L
.54727 .06014 L
F
.54727 .06653 m
.54878 .06653 L
.54878 .07291 L
.54727 .07291 L
.54727 .06653 L
F
.54727 .07291 m
.54878 .07291 L
.54878 .0793 L
.54727 .0793 L
.54727 .07291 L
F
.54727 .0793 m
.54878 .0793 L
.54878 .08568 L
.54727 .08568 L
.54727 .0793 L
F
.54727 .08568 m
.54878 .08568 L
.54878 .09207 L
.54727 .09207 L
.54727 .08568 L
F
.54727 .09207 m
.54878 .09207 L
.54878 .09846 L
.54727 .09846 L
.54727 .09207 L
F
.54727 .09846 m
.54878 .09846 L
.54878 .10484 L
.54727 .10484 L
.54727 .09846 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .11123 L
.54727 .11123 L
.54727 .10484 L
F
.54727 .11123 m
.54878 .11123 L
.54878 .11761 L
.54727 .11761 L
.54727 .11123 L
F
.54727 .11761 m
.54878 .11761 L
.54878 .124 L
.54727 .124 L
.54727 .11761 L
F
.54727 .124 m
.54878 .124 L
.54878 .13039 L
.54727 .13039 L
.54727 .124 L
F
.54727 .13039 m
.54878 .13039 L
.54878 .13677 L
.54727 .13677 L
.54727 .13039 L
F
.54727 .13677 m
.54878 .13677 L
.54878 .14316 L
.54727 .14316 L
.54727 .13677 L
F
.54727 .14316 m
.54878 .14316 L
.54878 .14954 L
.54727 .14954 L
.54727 .14316 L
F
.54727 .14954 m
.54878 .14954 L
.54878 .15593 L
.54727 .15593 L
.54727 .14954 L
F
.54727 .15593 m
.54878 .15593 L
.54878 .16232 L
.54727 .16232 L
.54727 .15593 L
F
.54727 .16232 m
.54878 .16232 L
.54878 .1687 L
.54727 .1687 L
.54727 .16232 L
F
0 g
.54727 .04098 m
.54727 .04737 L
.54727 .05375 L
.54727 .06014 L
.54727 .06653 L
.54727 .07291 L
.54727 .0793 L
.54727 .08568 L
.54727 .09207 L
.54727 .09846 L
.54727 .10484 L
.54727 .11123 L
.54727 .11761 L
.54727 .124 L
.54727 .13039 L
.54727 .13677 L
.54727 .14316 L
.54727 .14954 L
.54727 .15593 L
.54727 .16232 L
.54727 .1687 L
.54878 .1687 L
.54878 .16232 L
.54878 .15593 L
.54878 .14954 L
.54878 .14316 L
.54878 .13677 L
.54878 .13039 L
.54878 .124 L
.54878 .11761 L
.54878 .11123 L
.54878 .10484 L
.54878 .09846 L
.54878 .09207 L
.54878 .08568 L
.54878 .0793 L
.54878 .07291 L
.54878 .06653 L
.54878 .06014 L
.54878 .05375 L
.54878 .04737 L
.54878 .04098 L
.54727 .04098 L
s
.5 g
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
0 g
.54727 .10484 m
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04737 L
.54727 .04737 L
.54727 .04098 L
s
.54727 .04737 m
.54878 .04737 L
.54878 .05375 L
.54727 .05375 L
.54727 .04737 L
s
.54727 .05375 m
.54878 .05375 L
.54878 .06014 L
.54727 .06014 L
.54727 .05375 L
s
.54727 .06014 m
.54878 .06014 L
.54878 .06653 L
.54727 .06653 L
.54727 .06014 L
s
.54727 .06653 m
.54878 .06653 L
.54878 .07291 L
.54727 .07291 L
.54727 .06653 L
s
.54727 .07291 m
.54878 .07291 L
.54878 .0793 L
.54727 .0793 L
.54727 .07291 L
s
.54727 .0793 m
.54878 .0793 L
.54878 .08568 L
.54727 .08568 L
.54727 .0793 L
s
.54727 .08568 m
.54878 .08568 L
.54878 .09207 L
.54727 .09207 L
.54727 .08568 L
s
.54727 .09207 m
.54878 .09207 L
.54878 .09846 L
.54727 .09846 L
.54727 .09207 L
s
.54727 .09846 m
.54878 .09846 L
.54878 .10484 L
.54727 .10484 L
.54727 .09846 L
s
.54727 .10484 m
.54878 .10484 L
.54878 .11123 L
.54727 .11123 L
.54727 .10484 L
s
.54727 .11123 m
.54878 .11123 L
.54878 .11761 L
.54727 .11761 L
.54727 .11123 L
s
.54727 .11761 m
.54878 .11761 L
.54878 .124 L
.54727 .124 L
.54727 .11761 L
s
.54727 .124 m
.54878 .124 L
.54878 .13039 L
.54727 .13039 L
.54727 .124 L
s
.54727 .13039 m
.54878 .13039 L
.54878 .13677 L
.54727 .13677 L
.54727 .13039 L
s
.54727 .13677 m
.54878 .13677 L
.54878 .14316 L
.54727 .14316 L
.54727 .13677 L
s
.54727 .14316 m
.54878 .14316 L
.54878 .14954 L
.54727 .14954 L
.54727 .14316 L
s
.54727 .14954 m
.54878 .14954 L
.54878 .15593 L
.54727 .15593 L
.54727 .14954 L
s
.54727 .15593 m
.54878 .15593 L
.54878 .16232 L
.54727 .16232 L
.54727 .15593 L
s
.54727 .16232 m
.54878 .16232 L
.54878 .1687 L
.54727 .1687 L
.54727 .16232 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .16232 L
.54727 .16232 L
.54727 .1687 L
s
.54727 .16232 m
.54878 .16232 L
.54878 .15593 L
.54727 .15593 L
.54727 .16232 L
s
.54727 .15593 m
.54878 .15593 L
.54878 .14954 L
.54727 .14954 L
.54727 .15593 L
s
.54727 .14954 m
.54878 .14954 L
.54878 .14316 L
.54727 .14316 L
.54727 .14954 L
s
.54727 .14316 m
.54878 .14316 L
.54878 .13677 L
.54727 .13677 L
.54727 .14316 L
s
.54727 .13677 m
.54878 .13677 L
.54878 .13039 L
.54727 .13039 L
.54727 .13677 L
s
.54727 .13039 m
.54878 .13039 L
.54878 .124 L
.54727 .124 L
.54727 .13039 L
s
.54727 .124 m
.54878 .124 L
.54878 .11761 L
.54727 .11761 L
.54727 .124 L
s
.54727 .11761 m
.54878 .11761 L
.54878 .11123 L
.54727 .11123 L
.54727 .11761 L
s
.54727 .11123 m
.54878 .11123 L
.54878 .10484 L
.54727 .10484 L
.54727 .11123 L
s
.54727 .10484 m
.54878 .10484 L
.54878 .09846 L
.54727 .09846 L
.54727 .10484 L
s
.54727 .09846 m
.54878 .09846 L
.54878 .09207 L
.54727 .09207 L
.54727 .09846 L
s
.54727 .09207 m
.54878 .09207 L
.54878 .08568 L
.54727 .08568 L
.54727 .09207 L
s
.54727 .08568 m
.54878 .08568 L
.54878 .0793 L
.54727 .0793 L
.54727 .08568 L
s
.54727 .0793 m
.54878 .0793 L
.54878 .07291 L
.54727 .07291 L
.54727 .0793 L
s
.54727 .07291 m
.54878 .07291 L
.54878 .06653 L
.54727 .06653 L
.54727 .07291 L
s
.54727 .06653 m
.54878 .06653 L
.54878 .06014 L
.54727 .06014 L
.54727 .06653 L
s
.54727 .06014 m
.54878 .06014 L
.54878 .05375 L
.54727 .05375 L
.54727 .06014 L
s
.54727 .05375 m
.54878 .05375 L
.54878 .04737 L
.54727 .04737 L
.54727 .05375 L
s
.54727 .04737 m
.54878 .04737 L
.54878 .04098 L
.54727 .04098 L
.54727 .04737 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.5 g
.52162 .17775 m
.51764 .17775 L
.51539 .17046 L
.52162 .17046 L
.52162 .17775 L
F
.52162 .17046 m
.51539 .17046 L
.5134 .16317 L
.52162 .16317 L
.52162 .17046 L
F
.52162 .16317 m
.5134 .16317 L
.51165 .15588 L
.52162 .15588 L
.52162 .16317 L
F
.52162 .15588 m
.51165 .15588 L
.51015 .14859 L
.52162 .14859 L
.52162 .15588 L
F
.52162 .14859 m
.51015 .14859 L
.50888 .1413 L
.52162 .1413 L
.52162 .14859 L
F
.52162 .1413 m
.50888 .1413 L
.50785 .13401 L
.52162 .13401 L
.52162 .1413 L
F
.52162 .13401 m
.50785 .13401 L
.50706 .12672 L
.52162 .12672 L
.52162 .13401 L
F
.52162 .12672 m
.50706 .12672 L
.50649 .11942 L
.52162 .11942 L
.52162 .12672 L
F
.52162 .11942 m
.50649 .11942 L
.50615 .11213 L
.52162 .11213 L
.52162 .11942 L
F
.52162 .11213 m
.50615 .11213 L
.50603 .10484 L
.52162 .10484 L
.52162 .11213 L
F
.52162 .10484 m
.50603 .10484 L
.50615 .09755 L
.52162 .09755 L
.52162 .10484 L
F
.52162 .09755 m
.50615 .09755 L
.50649 .09026 L
.52162 .09026 L
.52162 .09755 L
F
.52162 .09026 m
.50649 .09026 L
.50706 .08297 L
.52162 .08297 L
.52162 .09026 L
F
.52162 .08297 m
.50706 .08297 L
.50785 .07568 L
.52162 .07568 L
.52162 .08297 L
F
.52162 .07568 m
.50785 .07568 L
.50888 .06839 L
.52162 .06839 L
.52162 .07568 L
F
.52162 .06839 m
.50888 .06839 L
.51015 .06109 L
.52162 .06109 L
.52162 .06839 L
F
.52162 .06109 m
.51015 .06109 L
.51165 .0538 L
.52162 .0538 L
.52162 .06109 L
F
.52162 .0538 m
.51165 .0538 L
.5134 .04651 L
.52162 .04651 L
.52162 .0538 L
F
.52162 .04651 m
.5134 .04651 L
.51539 .03922 L
.52162 .03922 L
.52162 .04651 L
F
.52162 .03922 m
.51539 .03922 L
.51764 .03193 L
.52162 .03193 L
.52162 .03922 L
F
0 g
.52162 .17775 m
.52162 .17046 L
.52162 .16317 L
.52162 .15588 L
.52162 .14859 L
.52162 .1413 L
.52162 .13401 L
.52162 .12672 L
.52162 .11942 L
.52162 .11213 L
.52162 .10484 L
.52162 .09755 L
.52162 .09026 L
.52162 .08297 L
.52162 .07568 L
.52162 .06839 L
.52162 .06109 L
.52162 .0538 L
.52162 .04651 L
.52162 .03922 L
.52162 .03193 L
.51764 .03193 L
.51539 .03922 L
.5134 .04651 L
.51165 .0538 L
.51015 .06109 L
.50888 .06839 L
.50785 .07568 L
.50706 .08297 L
.50649 .09026 L
.50615 .09755 L
.50603 .10484 L
.50615 .11213 L
.50649 .11942 L
.50706 .12672 L
.50785 .13401 L
.50888 .1413 L
.51015 .14859 L
.51165 .15588 L
.5134 .16317 L
.51539 .17046 L
.51764 .17775 L
.52162 .17775 L
s
.5 g
.52162 .10484 m
.51764 .10484 L
.51539 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.51539 .10484 L
.5134 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.5134 .10484 L
.51165 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.51165 .10484 L
.51015 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.51015 .10484 L
.50888 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50888 .10484 L
.50785 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50785 .10484 L
.50706 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50706 .10484 L
.50649 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50649 .10484 L
.50615 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50615 .10484 L
.50603 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50603 .10484 L
.50615 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50615 .10484 L
.50649 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50649 .10484 L
.50706 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50706 .10484 L
.50785 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50785 .10484 L
.50888 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50888 .10484 L
.51015 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.51015 .10484 L
.51165 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.51165 .10484 L
.5134 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.5134 .10484 L
.51539 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.51539 .10484 L
.51764 .10484 L
.52162 .10484 L
.52162 .10484 L
F
0 g
.52162 .10484 m
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.51764 .10484 L
.51539 .10484 L
.5134 .10484 L
.51165 .10484 L
.51015 .10484 L
.50888 .10484 L
.50785 .10484 L
.50706 .10484 L
.50649 .10484 L
.50615 .10484 L
.50603 .10484 L
.50615 .10484 L
.50649 .10484 L
.50706 .10484 L
.50785 .10484 L
.50888 .10484 L
.51015 .10484 L
.51165 .10484 L
.5134 .10484 L
.51539 .10484 L
.51764 .10484 L
.52162 .10484 L
s
.52162 .03193 m
.51764 .03193 L
.51764 .03215 L
.52162 .03215 L
.52162 .03193 L
s
.52162 .03215 m
.51764 .03215 L
.51764 .03283 L
.52162 .03283 L
.52162 .03215 L
s
.52162 .03283 m
.51764 .03283 L
.51764 .03394 L
.52162 .03394 L
.52162 .03283 L
s
.52162 .03394 m
.51764 .03394 L
.51764 .0355 L
.52162 .0355 L
.52162 .03394 L
s
.52162 .0355 m
.51764 .0355 L
.51764 .03748 L
.52162 .03748 L
.52162 .0355 L
s
.52162 .03748 m
.51764 .03748 L
.51764 .03988 L
.52162 .03988 L
.52162 .03748 L
s
.52162 .03988 m
.51764 .03988 L
.51764 .04267 L
.52162 .04267 L
.52162 .03988 L
s
.52162 .04267 m
.51764 .04267 L
.51764 .04585 L
.52162 .04585 L
.52162 .04267 L
s
.52162 .04585 m
.51764 .04585 L
.51764 .0494 L
.52162 .0494 L
.52162 .04585 L
s
.52162 .0494 m
.51764 .0494 L
.51764 .05329 L
.52162 .05329 L
.52162 .0494 L
s
.52162 .05329 m
.51764 .05329 L
.51764 .05749 L
.52162 .05749 L
.52162 .05329 L
s
.52162 .05749 m
.51764 .05749 L
.51764 .06199 L
.52162 .06199 L
.52162 .05749 L
s
.52162 .06199 m
.51764 .06199 L
.51764 .06675 L
.52162 .06675 L
.52162 .06199 L
s
.52162 .06675 m
.51764 .06675 L
.51764 .07174 L
.52162 .07174 L
.52162 .06675 L
s
.52162 .07174 m
.51764 .07174 L
.51764 .07694 L
.52162 .07694 L
.52162 .07174 L
s
.52162 .07694 m
.51764 .07694 L
.51764 .08231 L
.52162 .08231 L
.52162 .07694 L
s
.52162 .08231 m
.51764 .08231 L
.51764 .08782 L
.52162 .08782 L
.52162 .08231 L
s
.52162 .08782 m
.51764 .08782 L
.51764 .09344 L
.52162 .09344 L
.52162 .08782 L
s
.52162 .09344 m
.51764 .09344 L
.51764 .09912 L
.52162 .09912 L
.52162 .09344 L
s
.52162 .09912 m
.51764 .09912 L
.51764 .10484 L
.52162 .10484 L
.52162 .09912 L
s
.52162 .10484 m
.51764 .10484 L
.51764 .11056 L
.52162 .11056 L
.52162 .10484 L
s
.52162 .11056 m
.51764 .11056 L
.51764 .11625 L
.52162 .11625 L
.52162 .11056 L
s
.52162 .11625 m
.51764 .11625 L
.51764 .12186 L
.52162 .12186 L
.52162 .11625 L
s
.52162 .12186 m
.51764 .12186 L
.51764 .12737 L
.52162 .12737 L
.52162 .12186 L
s
.52162 .12737 m
.51764 .12737 L
.51764 .13274 L
.52162 .13274 L
.52162 .12737 L
s
.52162 .13274 m
.51764 .13274 L
.51764 .13794 L
.52162 .13794 L
.52162 .13274 L
s
.52162 .13794 m
.51764 .13794 L
.51764 .14294 L
.52162 .14294 L
.52162 .13794 L
s
.52162 .14294 m
.51764 .14294 L
.51764 .1477 L
.52162 .1477 L
.52162 .14294 L
s
.52162 .1477 m
.51764 .1477 L
.51764 .15219 L
.52162 .15219 L
.52162 .1477 L
s
.52162 .15219 m
.51764 .15219 L
.51764 .1564 L
.52162 .1564 L
.52162 .15219 L
s
.52162 .1564 m
.51764 .1564 L
.51764 .16028 L
.52162 .16028 L
.52162 .1564 L
s
.52162 .16028 m
.51764 .16028 L
.51764 .16383 L
.52162 .16383 L
.52162 .16028 L
s
.52162 .16383 m
.51764 .16383 L
.51764 .16701 L
.52162 .16701 L
.52162 .16383 L
s
.52162 .16701 m
.51764 .16701 L
.51764 .16981 L
.52162 .16981 L
.52162 .16701 L
s
.52162 .16981 m
.51764 .16981 L
.51764 .1722 L
.52162 .1722 L
.52162 .16981 L
s
.52162 .1722 m
.51764 .1722 L
.51764 .17419 L
.52162 .17419 L
.52162 .1722 L
s
.52162 .17419 m
.51764 .17419 L
.51764 .17574 L
.52162 .17574 L
.52162 .17419 L
s
.52162 .17574 m
.51764 .17574 L
.51764 .17686 L
.52162 .17686 L
.52162 .17574 L
s
.52162 .17686 m
.51764 .17686 L
.51764 .17753 L
.52162 .17753 L
.52162 .17686 L
s
.52162 .17753 m
.51764 .17753 L
.51764 .17775 L
.52162 .17775 L
.52162 .17753 L
s
.52162 .17775 m
.51764 .17775 L
.51764 .17753 L
.52162 .17753 L
.52162 .17775 L
s
.52162 .17753 m
.51764 .17753 L
.51764 .17686 L
.52162 .17686 L
.52162 .17753 L
s
.52162 .17686 m
.51764 .17686 L
.51764 .17574 L
.52162 .17574 L
.52162 .17686 L
s
.52162 .17574 m
.51764 .17574 L
.51764 .17419 L
.52162 .17419 L
.52162 .17574 L
s
.52162 .17419 m
.51764 .17419 L
.51764 .1722 L
.52162 .1722 L
.52162 .17419 L
s
.52162 .1722 m
.51764 .1722 L
.51764 .16981 L
.52162 .16981 L
.52162 .1722 L
s
.52162 .16981 m
.51764 .16981 L
.51764 .16701 L
.52162 .16701 L
.52162 .16981 L
s
.52162 .16701 m
.51764 .16701 L
.51764 .16383 L
.52162 .16383 L
.52162 .16701 L
s
.52162 .16383 m
.51764 .16383 L
.51764 .16028 L
.52162 .16028 L
.52162 .16383 L
s
.52162 .16028 m
.51764 .16028 L
.51764 .1564 L
.52162 .1564 L
.52162 .16028 L
s
.52162 .1564 m
.51764 .1564 L
.51764 .15219 L
.52162 .15219 L
.52162 .1564 L
s
.52162 .15219 m
.51764 .15219 L
.51764 .1477 L
.52162 .1477 L
.52162 .15219 L
s
.52162 .1477 m
.51764 .1477 L
.51764 .14294 L
.52162 .14294 L
.52162 .1477 L
s
.52162 .14294 m
.51764 .14294 L
.51764 .13794 L
.52162 .13794 L
.52162 .14294 L
s
.52162 .13794 m
.51764 .13794 L
.51764 .13274 L
.52162 .13274 L
.52162 .13794 L
s
.52162 .13274 m
.51764 .13274 L
.51764 .12737 L
.52162 .12737 L
.52162 .13274 L
s
.52162 .12737 m
.51764 .12737 L
.51764 .12186 L
.52162 .12186 L
.52162 .12737 L
s
.52162 .12186 m
.51764 .12186 L
.51764 .11625 L
.52162 .11625 L
.52162 .12186 L
s
.52162 .11625 m
.51764 .11625 L
.51764 .11056 L
.52162 .11056 L
.52162 .11625 L
s
.52162 .11056 m
.51764 .11056 L
.51764 .10484 L
.52162 .10484 L
.52162 .11056 L
s
.52162 .10484 m
.51764 .10484 L
.51764 .09912 L
.52162 .09912 L
.52162 .10484 L
s
.52162 .09912 m
.51764 .09912 L
.51764 .09344 L
.52162 .09344 L
.52162 .09912 L
s
.52162 .09344 m
.51764 .09344 L
.51764 .08782 L
.52162 .08782 L
.52162 .09344 L
s
.52162 .08782 m
.51764 .08782 L
.51764 .08231 L
.52162 .08231 L
.52162 .08782 L
s
.52162 .08231 m
.51764 .08231 L
.51764 .07694 L
.52162 .07694 L
.52162 .08231 L
s
.52162 .07694 m
.51764 .07694 L
.51764 .07174 L
.52162 .07174 L
.52162 .07694 L
s
.52162 .07174 m
.51764 .07174 L
.51764 .06675 L
.52162 .06675 L
.52162 .07174 L
s
.52162 .06675 m
.51764 .06675 L
.51764 .06199 L
.52162 .06199 L
.52162 .06675 L
s
.52162 .06199 m
.51764 .06199 L
.51764 .05749 L
.52162 .05749 L
.52162 .06199 L
s
.52162 .05749 m
.51764 .05749 L
.51764 .05329 L
.52162 .05329 L
.52162 .05749 L
s
.52162 .05329 m
.51764 .05329 L
.51764 .0494 L
.52162 .0494 L
.52162 .05329 L
s
.52162 .0494 m
.51764 .0494 L
.51764 .04585 L
.52162 .04585 L
.52162 .0494 L
s
.52162 .04585 m
.51764 .04585 L
.51764 .04267 L
.52162 .04267 L
.52162 .04585 L
s
.52162 .04267 m
.51764 .04267 L
.51764 .03988 L
.52162 .03988 L
.52162 .04267 L
s
.52162 .03988 m
.51764 .03988 L
.51764 .03748 L
.52162 .03748 L
.52162 .03988 L
s
.52162 .03748 m
.51764 .03748 L
.51764 .0355 L
.52162 .0355 L
.52162 .03748 L
s
.52162 .0355 m
.51764 .0355 L
.51764 .03394 L
.52162 .03394 L
.52162 .0355 L
s
.52162 .03394 m
.51764 .03394 L
.51764 .03283 L
.52162 .03283 L
.52162 .03394 L
s
.52162 .03283 m
.51764 .03283 L
.51764 .03215 L
.52162 .03215 L
.52162 .03283 L
s
.52162 .03215 m
.51764 .03215 L
.51764 .03193 L
.52162 .03193 L
.52162 .03215 L
s
.5 g
.47134 .03193 m
.47532 .03193 L
.47757 .03922 L
.47134 .03922 L
.47134 .03193 L
F
.47134 .03922 m
.47757 .03922 L
.47956 .04651 L
.47134 .04651 L
.47134 .03922 L
F
.47134 .04651 m
.47956 .04651 L
.48131 .0538 L
.47134 .0538 L
.47134 .04651 L
F
.47134 .0538 m
.48131 .0538 L
.48281 .06109 L
.47134 .06109 L
.47134 .0538 L
F
.47134 .06109 m
.48281 .06109 L
.48408 .06839 L
.47134 .06839 L
.47134 .06109 L
F
.47134 .06839 m
.48408 .06839 L
.48511 .07568 L
.47134 .07568 L
.47134 .06839 L
F
.47134 .07568 m
.48511 .07568 L
.4859 .08297 L
.47134 .08297 L
.47134 .07568 L
F
.47134 .08297 m
.4859 .08297 L
.48647 .09026 L
.47134 .09026 L
.47134 .08297 L
F
.47134 .09026 m
.48647 .09026 L
.48681 .09755 L
.47134 .09755 L
.47134 .09026 L
F
.47134 .09755 m
.48681 .09755 L
.48693 .10484 L
.47134 .10484 L
.47134 .09755 L
F
.47134 .10484 m
.48693 .10484 L
.48681 .11213 L
.47134 .11213 L
.47134 .10484 L
F
.47134 .11213 m
.48681 .11213 L
.48647 .11942 L
.47134 .11942 L
.47134 .11213 L
F
.47134 .11942 m
.48647 .11942 L
.4859 .12672 L
.47134 .12672 L
.47134 .11942 L
F
.47134 .12672 m
.4859 .12672 L
.48511 .13401 L
.47134 .13401 L
.47134 .12672 L
F
.47134 .13401 m
.48511 .13401 L
.48408 .1413 L
.47134 .1413 L
.47134 .13401 L
F
.47134 .1413 m
.48408 .1413 L
.48281 .14859 L
.47134 .14859 L
.47134 .1413 L
F
.47134 .14859 m
.48281 .14859 L
.48131 .15588 L
.47134 .15588 L
.47134 .14859 L
F
.47134 .15588 m
.48131 .15588 L
.47956 .16317 L
.47134 .16317 L
.47134 .15588 L
F
.47134 .16317 m
.47956 .16317 L
.47757 .17046 L
.47134 .17046 L
.47134 .16317 L
F
.47134 .17046 m
.47757 .17046 L
.47532 .17775 L
.47134 .17775 L
.47134 .17046 L
F
0 g
.47134 .03193 m
.47134 .03922 L
.47134 .04651 L
.47134 .0538 L
.47134 .06109 L
.47134 .06839 L
.47134 .07568 L
.47134 .08297 L
.47134 .09026 L
.47134 .09755 L
.47134 .10484 L
.47134 .11213 L
.47134 .11942 L
.47134 .12672 L
.47134 .13401 L
.47134 .1413 L
.47134 .14859 L
.47134 .15588 L
.47134 .16317 L
.47134 .17046 L
.47134 .17775 L
.47532 .17775 L
.47757 .17046 L
.47956 .16317 L
.48131 .15588 L
.48281 .14859 L
.48408 .1413 L
.48511 .13401 L
.4859 .12672 L
.48647 .11942 L
.48681 .11213 L
.48693 .10484 L
.48681 .09755 L
.48647 .09026 L
.4859 .08297 L
.48511 .07568 L
.48408 .06839 L
.48281 .06109 L
.48131 .0538 L
.47956 .04651 L
.47757 .03922 L
.47532 .03193 L
.47134 .03193 L
s
.5 g
.47134 .10484 m
.47532 .10484 L
.47757 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.47757 .10484 L
.47956 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.47956 .10484 L
.48131 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48131 .10484 L
.48281 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48281 .10484 L
.48408 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48408 .10484 L
.48511 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48511 .10484 L
.4859 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.4859 .10484 L
.48647 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48647 .10484 L
.48681 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48681 .10484 L
.48693 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48693 .10484 L
.48681 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48681 .10484 L
.48647 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48647 .10484 L
.4859 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.4859 .10484 L
.48511 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48511 .10484 L
.48408 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48408 .10484 L
.48281 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48281 .10484 L
.48131 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48131 .10484 L
.47956 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.47956 .10484 L
.47757 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.47757 .10484 L
.47532 .10484 L
.47134 .10484 L
.47134 .10484 L
F
0 g
.47134 .10484 m
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47532 .10484 L
.47757 .10484 L
.47956 .10484 L
.48131 .10484 L
.48281 .10484 L
.48408 .10484 L
.48511 .10484 L
.4859 .10484 L
.48647 .10484 L
.48681 .10484 L
.48693 .10484 L
.48681 .10484 L
.48647 .10484 L
.4859 .10484 L
.48511 .10484 L
.48408 .10484 L
.48281 .10484 L
.48131 .10484 L
.47956 .10484 L
.47757 .10484 L
.47532 .10484 L
.47134 .10484 L
s
.47134 .17775 m
.47532 .17775 L
.47532 .17753 L
.47134 .17753 L
.47134 .17775 L
s
.47134 .17753 m
.47532 .17753 L
.47532 .17686 L
.47134 .17686 L
.47134 .17753 L
s
.47134 .17686 m
.47532 .17686 L
.47532 .17574 L
.47134 .17574 L
.47134 .17686 L
s
.47134 .17574 m
.47532 .17574 L
.47532 .17419 L
.47134 .17419 L
.47134 .17574 L
s
.47134 .17419 m
.47532 .17419 L
.47532 .1722 L
.47134 .1722 L
.47134 .17419 L
s
.47134 .1722 m
.47532 .1722 L
.47532 .16981 L
.47134 .16981 L
.47134 .1722 L
s
.47134 .16981 m
.47532 .16981 L
.47532 .16701 L
.47134 .16701 L
.47134 .16981 L
s
.47134 .16701 m
.47532 .16701 L
.47532 .16383 L
.47134 .16383 L
.47134 .16701 L
s
.47134 .16383 m
.47532 .16383 L
.47532 .16028 L
.47134 .16028 L
.47134 .16383 L
s
.47134 .16028 m
.47532 .16028 L
.47532 .1564 L
.47134 .1564 L
.47134 .16028 L
s
.47134 .1564 m
.47532 .1564 L
.47532 .15219 L
.47134 .15219 L
.47134 .1564 L
s
.47134 .15219 m
.47532 .15219 L
.47532 .1477 L
.47134 .1477 L
.47134 .15219 L
s
.47134 .1477 m
.47532 .1477 L
.47532 .14294 L
.47134 .14294 L
.47134 .1477 L
s
.47134 .14294 m
.47532 .14294 L
.47532 .13794 L
.47134 .13794 L
.47134 .14294 L
s
.47134 .13794 m
.47532 .13794 L
.47532 .13274 L
.47134 .13274 L
.47134 .13794 L
s
.47134 .13274 m
.47532 .13274 L
.47532 .12737 L
.47134 .12737 L
.47134 .13274 L
s
.47134 .12737 m
.47532 .12737 L
.47532 .12186 L
.47134 .12186 L
.47134 .12737 L
s
.47134 .12186 m
.47532 .12186 L
.47532 .11625 L
.47134 .11625 L
.47134 .12186 L
s
.47134 .11625 m
.47532 .11625 L
.47532 .11056 L
.47134 .11056 L
.47134 .11625 L
s
.47134 .11056 m
.47532 .11056 L
.47532 .10484 L
.47134 .10484 L
.47134 .11056 L
s
.47134 .10484 m
.47532 .10484 L
.47532 .09912 L
.47134 .09912 L
.47134 .10484 L
s
.47134 .09912 m
.47532 .09912 L
.47532 .09344 L
.47134 .09344 L
.47134 .09912 L
s
.47134 .09344 m
.47532 .09344 L
.47532 .08782 L
.47134 .08782 L
.47134 .09344 L
s
.47134 .08782 m
.47532 .08782 L
.47532 .08231 L
.47134 .08231 L
.47134 .08782 L
s
.47134 .08231 m
.47532 .08231 L
.47532 .07694 L
.47134 .07694 L
.47134 .08231 L
s
.47134 .07694 m
.47532 .07694 L
.47532 .07174 L
.47134 .07174 L
.47134 .07694 L
s
.47134 .07174 m
.47532 .07174 L
.47532 .06675 L
.47134 .06675 L
.47134 .07174 L
s
.47134 .06675 m
.47532 .06675 L
.47532 .06199 L
.47134 .06199 L
.47134 .06675 L
s
.47134 .06199 m
.47532 .06199 L
.47532 .05749 L
.47134 .05749 L
.47134 .06199 L
s
.47134 .05749 m
.47532 .05749 L
.47532 .05329 L
.47134 .05329 L
.47134 .05749 L
s
.47134 .05329 m
.47532 .05329 L
.47532 .0494 L
.47134 .0494 L
.47134 .05329 L
s
.47134 .0494 m
.47532 .0494 L
.47532 .04585 L
.47134 .04585 L
.47134 .0494 L
s
.47134 .04585 m
.47532 .04585 L
.47532 .04267 L
.47134 .04267 L
.47134 .04585 L
s
.47134 .04267 m
.47532 .04267 L
.47532 .03988 L
.47134 .03988 L
.47134 .04267 L
s
.47134 .03988 m
.47532 .03988 L
.47532 .03748 L
.47134 .03748 L
.47134 .03988 L
s
.47134 .03748 m
.47532 .03748 L
.47532 .0355 L
.47134 .0355 L
.47134 .03748 L
s
.47134 .0355 m
.47532 .0355 L
.47532 .03394 L
.47134 .03394 L
.47134 .0355 L
s
.47134 .03394 m
.47532 .03394 L
.47532 .03283 L
.47134 .03283 L
.47134 .03394 L
s
.47134 .03283 m
.47532 .03283 L
.47532 .03215 L
.47134 .03215 L
.47134 .03283 L
s
.47134 .03215 m
.47532 .03215 L
.47532 .03193 L
.47134 .03193 L
.47134 .03215 L
s
.47134 .03193 m
.47532 .03193 L
.47532 .03215 L
.47134 .03215 L
.47134 .03193 L
s
.47134 .03215 m
.47532 .03215 L
.47532 .03283 L
.47134 .03283 L
.47134 .03215 L
s
.47134 .03283 m
.47532 .03283 L
.47532 .03394 L
.47134 .03394 L
.47134 .03283 L
s
.47134 .03394 m
.47532 .03394 L
.47532 .0355 L
.47134 .0355 L
.47134 .03394 L
s
.47134 .0355 m
.47532 .0355 L
.47532 .03748 L
.47134 .03748 L
.47134 .0355 L
s
.47134 .03748 m
.47532 .03748 L
.47532 .03988 L
.47134 .03988 L
.47134 .03748 L
s
.47134 .03988 m
.47532 .03988 L
.47532 .04267 L
.47134 .04267 L
.47134 .03988 L
s
.47134 .04267 m
.47532 .04267 L
.47532 .04585 L
.47134 .04585 L
.47134 .04267 L
s
.47134 .04585 m
.47532 .04585 L
.47532 .0494 L
.47134 .0494 L
.47134 .04585 L
s
.47134 .0494 m
.47532 .0494 L
.47532 .05329 L
.47134 .05329 L
.47134 .0494 L
s
.47134 .05329 m
.47532 .05329 L
.47532 .05749 L
.47134 .05749 L
.47134 .05329 L
s
.47134 .05749 m
.47532 .05749 L
.47532 .06199 L
.47134 .06199 L
.47134 .05749 L
s
.47134 .06199 m
.47532 .06199 L
.47532 .06675 L
.47134 .06675 L
.47134 .06199 L
s
.47134 .06675 m
.47532 .06675 L
.47532 .07174 L
.47134 .07174 L
.47134 .06675 L
s
.47134 .07174 m
.47532 .07174 L
.47532 .07694 L
.47134 .07694 L
.47134 .07174 L
s
.47134 .07694 m
.47532 .07694 L
.47532 .08231 L
.47134 .08231 L
.47134 .07694 L
s
.47134 .08231 m
.47532 .08231 L
.47532 .08782 L
.47134 .08782 L
.47134 .08231 L
s
.47134 .08782 m
.47532 .08782 L
.47532 .09344 L
.47134 .09344 L
.47134 .08782 L
s
.47134 .09344 m
.47532 .09344 L
.47532 .09912 L
.47134 .09912 L
.47134 .09344 L
s
.47134 .09912 m
.47532 .09912 L
.47532 .10484 L
.47134 .10484 L
.47134 .09912 L
s
.47134 .10484 m
.47532 .10484 L
.47532 .11056 L
.47134 .11056 L
.47134 .10484 L
s
.47134 .11056 m
.47532 .11056 L
.47532 .11625 L
.47134 .11625 L
.47134 .11056 L
s
.47134 .11625 m
.47532 .11625 L
.47532 .12186 L
.47134 .12186 L
.47134 .11625 L
s
.47134 .12186 m
.47532 .12186 L
.47532 .12737 L
.47134 .12737 L
.47134 .12186 L
s
.47134 .12737 m
.47532 .12737 L
.47532 .13274 L
.47134 .13274 L
.47134 .12737 L
s
.47134 .13274 m
.47532 .13274 L
.47532 .13794 L
.47134 .13794 L
.47134 .13274 L
s
.47134 .13794 m
.47532 .13794 L
.47532 .14294 L
.47134 .14294 L
.47134 .13794 L
s
.47134 .14294 m
.47532 .14294 L
.47532 .1477 L
.47134 .1477 L
.47134 .14294 L
s
.47134 .1477 m
.47532 .1477 L
.47532 .15219 L
.47134 .15219 L
.47134 .1477 L
s
.47134 .15219 m
.47532 .15219 L
.47532 .1564 L
.47134 .1564 L
.47134 .15219 L
s
.47134 .1564 m
.47532 .1564 L
.47532 .16028 L
.47134 .16028 L
.47134 .1564 L
s
.47134 .16028 m
.47532 .16028 L
.47532 .16383 L
.47134 .16383 L
.47134 .16028 L
s
.47134 .16383 m
.47532 .16383 L
.47532 .16701 L
.47134 .16701 L
.47134 .16383 L
s
.47134 .16701 m
.47532 .16701 L
.47532 .16981 L
.47134 .16981 L
.47134 .16701 L
s
.47134 .16981 m
.47532 .16981 L
.47532 .1722 L
.47134 .1722 L
.47134 .16981 L
s
.47134 .1722 m
.47532 .1722 L
.47532 .17419 L
.47134 .17419 L
.47134 .1722 L
s
.47134 .17419 m
.47532 .17419 L
.47532 .17574 L
.47134 .17574 L
.47134 .17419 L
s
.47134 .17574 m
.47532 .17574 L
.47532 .17686 L
.47134 .17686 L
.47134 .17574 L
s
.47134 .17686 m
.47532 .17686 L
.47532 .17753 L
.47134 .17753 L
.47134 .17686 L
s
.47134 .17753 m
.47532 .17753 L
.47532 .17775 L
.47134 .17775 L
.47134 .17753 L
s
.5 g
.17466 .0797 m
.17714 .0797 L
.17844 .08221 L
.17466 .08221 L
.17466 .0797 L
F
.17466 .08221 m
.17844 .08221 L
.17957 .08473 L
.17466 .08473 L
.17466 .08221 L
F
.17466 .08473 m
.17957 .08473 L
.18054 .08724 L
.17466 .08724 L
.17466 .08473 L
F
.17466 .08724 m
.18054 .08724 L
.18137 .08976 L
.17466 .08976 L
.17466 .08724 L
F
.17466 .08976 m
.18137 .08976 L
.18207 .09227 L
.17466 .09227 L
.17466 .08976 L
F
.17466 .09227 m
.18207 .09227 L
.18262 .09479 L
.17466 .09479 L
.17466 .09227 L
F
.17466 .09479 m
.18262 .09479 L
.18305 .0973 L
.17466 .0973 L
.17466 .09479 L
F
.17466 .0973 m
.18305 .0973 L
.18336 .09981 L
.17466 .09981 L
.17466 .0973 L
F
.17466 .09981 m
.18336 .09981 L
.18354 .10233 L
.17466 .10233 L
.17466 .09981 L
F
.17466 .10233 m
.18354 .10233 L
.1836 .10484 L
.17466 .10484 L
.17466 .10233 L
F
.17466 .10484 m
.1836 .10484 L
.18354 .10736 L
.17466 .10736 L
.17466 .10484 L
F
.17466 .10736 m
.18354 .10736 L
.18336 .10987 L
.17466 .10987 L
.17466 .10736 L
F
.17466 .10987 m
.18336 .10987 L
.18305 .11238 L
.17466 .11238 L
.17466 .10987 L
F
.17466 .11238 m
.18305 .11238 L
.18262 .1149 L
.17466 .1149 L
.17466 .11238 L
F
.17466 .1149 m
.18262 .1149 L
.18207 .11741 L
.17466 .11741 L
.17466 .1149 L
F
.17466 .11741 m
.18207 .11741 L
.18137 .11993 L
.17466 .11993 L
.17466 .11741 L
F
.17466 .11993 m
.18137 .11993 L
.18054 .12244 L
.17466 .12244 L
.17466 .11993 L
F
.17466 .12244 m
.18054 .12244 L
.17957 .12496 L
.17466 .12496 L
.17466 .12244 L
F
.17466 .12496 m
.17957 .12496 L
.17844 .12747 L
.17466 .12747 L
.17466 .12496 L
F
.17466 .12747 m
.17844 .12747 L
.17714 .12998 L
.17466 .12998 L
.17466 .12747 L
F
0 g
.17466 .0797 m
.17466 .08221 L
.17466 .08473 L
.17466 .08724 L
.17466 .08976 L
.17466 .09227 L
.17466 .09479 L
.17466 .0973 L
.17466 .09981 L
.17466 .10233 L
.17466 .10484 L
.17466 .10736 L
.17466 .10987 L
.17466 .11238 L
.17466 .1149 L
.17466 .11741 L
.17466 .11993 L
.17466 .12244 L
.17466 .12496 L
.17466 .12747 L
.17466 .12998 L
.17714 .12998 L
.17844 .12747 L
.17957 .12496 L
.18054 .12244 L
.18137 .11993 L
.18207 .11741 L
.18262 .1149 L
.18305 .11238 L
.18336 .10987 L
.18354 .10736 L
.1836 .10484 L
.18354 .10233 L
.18336 .09981 L
.18305 .0973 L
.18262 .09479 L
.18207 .09227 L
.18137 .08976 L
.18054 .08724 L
.17957 .08473 L
.17844 .08221 L
.17714 .0797 L
.17466 .0797 L
s
.5 g
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
0 g
.17466 .10484 m
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
s
.17466 .0797 m
.17714 .0797 L
.17844 .08221 L
.17466 .08221 L
.17466 .0797 L
s
.17466 .08221 m
.17844 .08221 L
.17957 .08473 L
.17466 .08473 L
.17466 .08221 L
s
.17466 .08473 m
.17957 .08473 L
.18054 .08724 L
.17466 .08724 L
.17466 .08473 L
s
.17466 .08724 m
.18054 .08724 L
.18137 .08976 L
.17466 .08976 L
.17466 .08724 L
s
.17466 .08976 m
.18137 .08976 L
.18207 .09227 L
.17466 .09227 L
.17466 .08976 L
s
.17466 .09227 m
.18207 .09227 L
.18262 .09479 L
.17466 .09479 L
.17466 .09227 L
s
.17466 .09479 m
.18262 .09479 L
.18305 .0973 L
.17466 .0973 L
.17466 .09479 L
s
.17466 .0973 m
.18305 .0973 L
.18336 .09981 L
.17466 .09981 L
.17466 .0973 L
s
.17466 .09981 m
.18336 .09981 L
.18354 .10233 L
.17466 .10233 L
.17466 .09981 L
s
.17466 .10233 m
.18354 .10233 L
.1836 .10484 L
.17466 .10484 L
.17466 .10233 L
s
.17466 .10484 m
.1836 .10484 L
.18354 .10736 L
.17466 .10736 L
.17466 .10484 L
s
.17466 .10736 m
.18354 .10736 L
.18336 .10987 L
.17466 .10987 L
.17466 .10736 L
s
.17466 .10987 m
.18336 .10987 L
.18305 .11238 L
.17466 .11238 L
.17466 .10987 L
s
.17466 .11238 m
.18305 .11238 L
.18262 .1149 L
.17466 .1149 L
.17466 .11238 L
s
.17466 .1149 m
.18262 .1149 L
.18207 .11741 L
.17466 .11741 L
.17466 .1149 L
s
.17466 .11741 m
.18207 .11741 L
.18137 .11993 L
.17466 .11993 L
.17466 .11741 L
s
.17466 .11993 m
.18137 .11993 L
.18054 .12244 L
.17466 .12244 L
.17466 .11993 L
s
.17466 .12244 m
.18054 .12244 L
.17957 .12496 L
.17466 .12496 L
.17466 .12244 L
s
.17466 .12496 m
.17957 .12496 L
.17844 .12747 L
.17466 .12747 L
.17466 .12496 L
s
.17466 .12747 m
.17844 .12747 L
.17714 .12998 L
.17466 .12998 L
.17466 .12747 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17844 .12747 L
.17466 .12747 L
.17466 .12998 L
s
.17466 .12747 m
.17844 .12747 L
.17957 .12496 L
.17466 .12496 L
.17466 .12747 L
s
.17466 .12496 m
.17957 .12496 L
.18054 .12244 L
.17466 .12244 L
.17466 .12496 L
s
.17466 .12244 m
.18054 .12244 L
.18137 .11993 L
.17466 .11993 L
.17466 .12244 L
s
.17466 .11993 m
.18137 .11993 L
.18207 .11741 L
.17466 .11741 L
.17466 .11993 L
s
.17466 .11741 m
.18207 .11741 L
.18262 .1149 L
.17466 .1149 L
.17466 .11741 L
s
.17466 .1149 m
.18262 .1149 L
.18305 .11238 L
.17466 .11238 L
.17466 .1149 L
s
.17466 .11238 m
.18305 .11238 L
.18336 .10987 L
.17466 .10987 L
.17466 .11238 L
s
.17466 .10987 m
.18336 .10987 L
.18354 .10736 L
.17466 .10736 L
.17466 .10987 L
s
.17466 .10736 m
.18354 .10736 L
.1836 .10484 L
.17466 .10484 L
.17466 .10736 L
s
.17466 .10484 m
.1836 .10484 L
.18354 .10233 L
.17466 .10233 L
.17466 .10484 L
s
.17466 .10233 m
.18354 .10233 L
.18336 .09981 L
.17466 .09981 L
.17466 .10233 L
s
.17466 .09981 m
.18336 .09981 L
.18305 .0973 L
.17466 .0973 L
.17466 .09981 L
s
.17466 .0973 m
.18305 .0973 L
.18262 .09479 L
.17466 .09479 L
.17466 .0973 L
s
.17466 .09479 m
.18262 .09479 L
.18207 .09227 L
.17466 .09227 L
.17466 .09479 L
s
.17466 .09227 m
.18207 .09227 L
.18137 .08976 L
.17466 .08976 L
.17466 .09227 L
s
.17466 .08976 m
.18137 .08976 L
.18054 .08724 L
.17466 .08724 L
.17466 .08976 L
s
.17466 .08724 m
.18054 .08724 L
.17957 .08473 L
.17466 .08473 L
.17466 .08724 L
s
.17466 .08473 m
.17957 .08473 L
.17844 .08221 L
.17466 .08221 L
.17466 .08473 L
s
.17466 .08221 m
.17844 .08221 L
.17714 .0797 L
.17466 .0797 L
.17466 .08221 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.5 g
.13765 .07775 m
.13901 .07841 L
.13768 .08112 L
.13633 .08046 L
.13765 .07775 L
F
.13633 .08046 m
.13768 .08112 L
.13635 .08383 L
.135 .08317 L
.13633 .08046 L
F
.135 .08317 m
.13635 .08383 L
.13502 .08654 L
.13367 .08588 L
.135 .08317 L
F
.13367 .08588 m
.13502 .08654 L
.1337 .08925 L
.13234 .08859 L
.13367 .08588 L
F
.13234 .08859 m
.1337 .08925 L
.13237 .09196 L
.13102 .0913 L
.13234 .08859 L
F
.13102 .0913 m
.13237 .09196 L
.13104 .09467 L
.12969 .094 L
.13102 .0913 L
F
.12969 .094 m
.13104 .09467 L
.12971 .09738 L
.12836 .09671 L
.12969 .094 L
F
.12836 .09671 m
.12971 .09738 L
.12839 .10009 L
.12703 .09942 L
.12836 .09671 L
F
.12703 .09942 m
.12839 .10009 L
.12706 .1028 L
.12571 .10213 L
.12703 .09942 L
F
.12571 .10213 m
.12706 .1028 L
.12573 .10551 L
.12438 .10484 L
.12571 .10213 L
F
.12438 .10484 m
.12573 .10551 L
.1244 .10822 L
.12305 .10755 L
.12438 .10484 L
F
.12305 .10755 m
.1244 .10822 L
.12308 .11092 L
.12172 .11026 L
.12305 .10755 L
F
.12172 .11026 m
.12308 .11092 L
.12175 .11363 L
.1204 .11297 L
.12172 .11026 L
F
.1204 .11297 m
.12175 .11363 L
.12042 .11634 L
.11907 .11568 L
.1204 .11297 L
F
.11907 .11568 m
.12042 .11634 L
.11909 .11905 L
.11774 .11839 L
.11907 .11568 L
F
.11774 .11839 m
.11909 .11905 L
.11777 .12176 L
.11641 .1211 L
.11774 .11839 L
F
.11641 .1211 m
.11777 .12176 L
.11644 .12447 L
.11509 .12381 L
.11641 .1211 L
F
.11509 .12381 m
.11644 .12447 L
.11511 .12718 L
.11376 .12652 L
.11509 .12381 L
F
.11376 .12652 m
.11511 .12718 L
.11378 .12989 L
.11243 .12923 L
.11376 .12652 L
F
.11243 .12923 m
.11378 .12989 L
.11246 .1326 L
.1111 .13194 L
.11243 .12923 L
F
0 g
.13765 .07775 m
.13633 .08046 L
.135 .08317 L
.13367 .08588 L
.13234 .08859 L
.13102 .0913 L
.12969 .094 L
.12836 .09671 L
.12703 .09942 L
.12571 .10213 L
.12438 .10484 L
.12305 .10755 L
.12172 .11026 L
.1204 .11297 L
.11907 .11568 L
.11774 .11839 L
.11641 .1211 L
.11509 .12381 L
.11376 .12652 L
.11243 .12923 L
.1111 .13194 L
.11246 .1326 L
.11378 .12989 L
.11511 .12718 L
.11644 .12447 L
.11777 .12176 L
.11909 .11905 L
.12042 .11634 L
.12175 .11363 L
.12308 .11092 L
.1244 .10822 L
.12573 .10551 L
.12706 .1028 L
.12839 .10009 L
.12971 .09738 L
.13104 .09467 L
.13237 .09196 L
.1337 .08925 L
.13502 .08654 L
.13635 .08383 L
.13768 .08112 L
.13901 .07841 L
.13765 .07775 L
s
.5 g
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
.12438 .10484 m
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
.12438 .10484 L
F
0 g
.12438 .10484 m
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12438 .10484 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12573 .10551 L
.12438 .10484 L
s
.1111 .13194 m
.11246 .1326 L
.1125 .13252 L
.11114 .13185 L
.1111 .13194 L
s
.11114 .13185 m
.1125 .13252 L
.11262 .13227 L
.11127 .1316 L
.11114 .13185 L
s
.11127 .1316 m
.11262 .13227 L
.11282 .13185 L
.11147 .13119 L
.11127 .1316 L
s
.11147 .13119 m
.11282 .13185 L
.11311 .13127 L
.11175 .13061 L
.11147 .13119 L
s
.11175 .13061 m
.11311 .13127 L
.11347 .13054 L
.11211 .12987 L
.11175 .13061 L
s
.11211 .12987 m
.11347 .13054 L
.1139 .12965 L
.11255 .12898 L
.11211 .12987 L
s
.11255 .12898 m
.1139 .12965 L
.11441 .12861 L
.11306 .12794 L
.11255 .12898 L
s
.11306 .12794 m
.11441 .12861 L
.11499 .12742 L
.11364 .12676 L
.11306 .12794 L
s
.11364 .12676 m
.11499 .12742 L
.11564 .12611 L
.11428 .12544 L
.11364 .12676 L
s
.11428 .12544 m
.11564 .12611 L
.11635 .12466 L
.11499 .124 L
.11428 .12544 L
s
.11499 .124 m
.11635 .12466 L
.11711 .1231 L
.11576 .12244 L
.11499 .124 L
s
.11576 .12244 m
.11711 .1231 L
.11793 .12143 L
.11657 .12077 L
.11576 .12244 L
s
.11657 .12077 m
.11793 .12143 L
.1188 .11966 L
.11744 .119 L
.11657 .12077 L
s
.11744 .119 m
.1188 .11966 L
.11971 .11781 L
.11835 .11714 L
.11744 .119 L
s
.11835 .11714 m
.11971 .11781 L
.12065 .11587 L
.1193 .11521 L
.11835 .11714 L
s
.1193 .11521 m
.12065 .11587 L
.12163 .11388 L
.12028 .11321 L
.1193 .11521 L
s
.12028 .11321 m
.12163 .11388 L
.12263 .11183 L
.12128 .11117 L
.12028 .11321 L
s
.12128 .11117 m
.12263 .11183 L
.12366 .10974 L
.1223 .10908 L
.12128 .11117 L
s
.1223 .10908 m
.12366 .10974 L
.12469 .10763 L
.12334 .10697 L
.1223 .10908 L
s
.12334 .10697 m
.12469 .10763 L
.12573 .10551 L
.12438 .10484 L
.12334 .10697 L
s
.12438 .10484 m
.12573 .10551 L
.12677 .10338 L
.12542 .10272 L
.12438 .10484 L
s
.12542 .10272 m
.12677 .10338 L
.12781 .10127 L
.12645 .1006 L
.12542 .10272 L
s
.12645 .1006 m
.12781 .10127 L
.12883 .09918 L
.12748 .09852 L
.12645 .1006 L
s
.12748 .09852 m
.12883 .09918 L
.12983 .09713 L
.12848 .09647 L
.12748 .09852 L
s
.12848 .09647 m
.12983 .09713 L
.13081 .09514 L
.12946 .09447 L
.12848 .09647 L
s
.12946 .09447 m
.13081 .09514 L
.13176 .09321 L
.1304 .09254 L
.12946 .09447 L
s
.1304 .09254 m
.13176 .09321 L
.13267 .09135 L
.13131 .09069 L
.1304 .09254 L
s
.13131 .09069 m
.13267 .09135 L
.13354 .08958 L
.13218 .08892 L
.13131 .09069 L
s
.13218 .08892 m
.13354 .08958 L
.13435 .08791 L
.133 .08725 L
.13218 .08892 L
s
.133 .08725 m
.13435 .08791 L
.13512 .08635 L
.13376 .08568 L
.133 .08725 L
s
.13376 .08568 m
.13512 .08635 L
.13583 .0849 L
.13447 .08424 L
.13376 .08568 L
s
.13447 .08424 m
.13583 .0849 L
.13647 .08359 L
.13512 .08292 L
.13447 .08424 L
s
.13512 .08292 m
.13647 .08359 L
.13705 .08241 L
.1357 .08174 L
.13512 .08292 L
s
.1357 .08174 m
.13705 .08241 L
.13756 .08137 L
.13621 .0807 L
.1357 .08174 L
s
.13621 .0807 m
.13756 .08137 L
.138 .08048 L
.13664 .07981 L
.13621 .0807 L
s
.13664 .07981 m
.138 .08048 L
.13836 .07974 L
.137 .07908 L
.13664 .07981 L
s
.137 .07908 m
.13836 .07974 L
.13864 .07916 L
.13729 .0785 L
.137 .07908 L
s
.13729 .0785 m
.13864 .07916 L
.13884 .07875 L
.13749 .07808 L
.13729 .0785 L
s
.13749 .07808 m
.13884 .07875 L
.13897 .0785 L
.13761 .07783 L
.13749 .07808 L
s
.13761 .07783 m
.13897 .0785 L
.13901 .07841 L
.13765 .07775 L
.13761 .07783 L
s
.13765 .07775 m
.13901 .07841 L
.13897 .0785 L
.13761 .07783 L
.13765 .07775 L
s
.13761 .07783 m
.13897 .0785 L
.13884 .07875 L
.13749 .07808 L
.13761 .07783 L
s
.13749 .07808 m
.13884 .07875 L
.13864 .07916 L
.13729 .0785 L
.13749 .07808 L
s
.13729 .0785 m
.13864 .07916 L
.13836 .07974 L
.137 .07908 L
.13729 .0785 L
s
.137 .07908 m
.13836 .07974 L
.138 .08048 L
.13664 .07981 L
.137 .07908 L
s
.13664 .07981 m
.138 .08048 L
.13756 .08137 L
.13621 .0807 L
.13664 .07981 L
s
.13621 .0807 m
.13756 .08137 L
.13705 .08241 L
.1357 .08174 L
.13621 .0807 L
s
.1357 .08174 m
.13705 .08241 L
.13647 .08359 L
.13512 .08292 L
.1357 .08174 L
s
.13512 .08292 m
.13647 .08359 L
.13583 .0849 L
.13447 .08424 L
.13512 .08292 L
s
.13447 .08424 m
.13583 .0849 L
.13512 .08635 L
.13376 .08568 L
.13447 .08424 L
s
.13376 .08568 m
.13512 .08635 L
.13435 .08791 L
.133 .08725 L
.13376 .08568 L
s
.133 .08725 m
.13435 .08791 L
.13354 .08958 L
.13218 .08892 L
.133 .08725 L
s
.13218 .08892 m
.13354 .08958 L
.13267 .09135 L
.13131 .09069 L
.13218 .08892 L
s
.13131 .09069 m
.13267 .09135 L
.13176 .09321 L
.1304 .09254 L
.13131 .09069 L
s
.1304 .09254 m
.13176 .09321 L
.13081 .09514 L
.12946 .09447 L
.1304 .09254 L
s
.12946 .09447 m
.13081 .09514 L
.12983 .09713 L
.12848 .09647 L
.12946 .09447 L
s
.12848 .09647 m
.12983 .09713 L
.12883 .09918 L
.12748 .09852 L
.12848 .09647 L
s
.12748 .09852 m
.12883 .09918 L
.12781 .10127 L
.12645 .1006 L
.12748 .09852 L
s
.12645 .1006 m
.12781 .10127 L
.12677 .10338 L
.12542 .10272 L
.12645 .1006 L
s
.12542 .10272 m
.12677 .10338 L
.12573 .10551 L
.12438 .10484 L
.12542 .10272 L
s
.12438 .10484 m
.12573 .10551 L
.12469 .10763 L
.12334 .10697 L
.12438 .10484 L
s
.12334 .10697 m
.12469 .10763 L
.12366 .10974 L
.1223 .10908 L
.12334 .10697 L
s
.1223 .10908 m
.12366 .10974 L
.12263 .11183 L
.12128 .11117 L
.1223 .10908 L
s
.12128 .11117 m
.12263 .11183 L
.12163 .11388 L
.12028 .11321 L
.12128 .11117 L
s
.12028 .11321 m
.12163 .11388 L
.12065 .11587 L
.1193 .11521 L
.12028 .11321 L
s
.1193 .11521 m
.12065 .11587 L
.11971 .11781 L
.11835 .11714 L
.1193 .11521 L
s
.11835 .11714 m
.11971 .11781 L
.1188 .11966 L
.11744 .119 L
.11835 .11714 L
s
.11744 .119 m
.1188 .11966 L
.11793 .12143 L
.11657 .12077 L
.11744 .119 L
s
.11657 .12077 m
.11793 .12143 L
.11711 .1231 L
.11576 .12244 L
.11657 .12077 L
s
.11576 .12244 m
.11711 .1231 L
.11635 .12466 L
.11499 .124 L
.11576 .12244 L
s
.11499 .124 m
.11635 .12466 L
.11564 .12611 L
.11428 .12544 L
.11499 .124 L
s
.11428 .12544 m
.11564 .12611 L
.11499 .12742 L
.11364 .12676 L
.11428 .12544 L
s
.11364 .12676 m
.11499 .12742 L
.11441 .12861 L
.11306 .12794 L
.11364 .12676 L
s
.11306 .12794 m
.11441 .12861 L
.1139 .12965 L
.11255 .12898 L
.11306 .12794 L
s
.11255 .12898 m
.1139 .12965 L
.11347 .13054 L
.11211 .12987 L
.11255 .12898 L
s
.11211 .12987 m
.11347 .13054 L
.11311 .13127 L
.11175 .13061 L
.11211 .12987 L
s
.11175 .13061 m
.11311 .13127 L
.11282 .13185 L
.11147 .13119 L
.11175 .13061 L
s
.11147 .13119 m
.11282 .13185 L
.11262 .13227 L
.11127 .1316 L
.11147 .13119 L
s
.11127 .1316 m
.11262 .13227 L
.1125 .13252 L
.11114 .13185 L
.11127 .1316 L
s
.11114 .13185 m
.1125 .13252 L
.11246 .1326 L
.1111 .13194 L
.11114 .13185 L
s
.11366 .05815 m
.16513 .08337 L
.12752 .16014 L
.07604 .13492 L
.11366 .05815 L
s
.12618 .10573 m
.12611 .10587 L
.12602 .106 L
.12593 .10612 L
.12582 .10624 L
.12571 .10635 L
.12559 .10645 L
.12546 .10654 L
.12532 .10662 L
.12518 .10669 L
.12503 .10674 L
.12488 .10679 L
.12472 .10682 L
.12457 .10684 L
.12441 .10685 L
.12425 .10685 L
.12409 .10683 L
.12394 .1068 L
.12379 .10676 L
.12364 .10671 L
.12349 .10665 L
.12335 .10657 L
.12322 .10649 L
.1231 .10639 L
.12298 .10629 L
.12287 .10617 L
.12277 .10605 L
.12268 .10592 L
.1226 .10578 L
.12253 .10564 L
.12247 .10549 L
.12243 .10534 L
.1224 .10519 L
.12238 .10503 L
.12237 .10487 L
.12237 .10472 L
.12239 .10456 L
.12241 .1044 L
.12246 .10425 L
.12251 .1041 L
.12257 .10396 L
.12265 .10382 L
.12273 .10369 L
.12283 .10356 L
.12293 .10344 L
.12305 .10333 L
.12317 .10323 L
.1233 .10314 L
.12344 .10306 L
.12358 .103 L
Mistroke
.12373 .10294 L
.12388 .10289 L
.12403 .10286 L
.12419 .10284 L
.12435 .10283 L
.1245 .10283 L
.12466 .10285 L
.12482 .10288 L
.12497 .10292 L
.12512 .10297 L
.12526 .10304 L
.1254 .10311 L
.12553 .1032 L
.12566 .10329 L
.12578 .1034 L
.12589 .10351 L
.12599 .10363 L
.12608 .10376 L
.12616 .1039 L
.12622 .10404 L
.12628 .10419 L
.12633 .10434 L
.12636 .1045 L
.12638 .10465 L
.12639 .10481 L
.12639 .10497 L
.12637 .10513 L
.12634 .10528 L
.1263 .10543 L
.12625 .10558 L
.12618 .10573 L
Mfstroke
.11366 .05815 m
.16513 .08337 L
.12752 .16014 L
.07604 .13492 L
.11366 .05815 L
s
.12618 .10573 m
.12611 .10587 L
.12602 .106 L
.12593 .10612 L
.12582 .10624 L
.12571 .10635 L
.12559 .10645 L
.12546 .10654 L
.12532 .10662 L
.12518 .10669 L
.12503 .10674 L
.12488 .10679 L
.12472 .10682 L
.12457 .10684 L
.12441 .10685 L
.12425 .10685 L
.12409 .10683 L
.12394 .1068 L
.12379 .10676 L
.12364 .10671 L
.12349 .10665 L
.12335 .10657 L
.12322 .10649 L
.1231 .10639 L
.12298 .10629 L
.12287 .10617 L
.12277 .10605 L
.12268 .10592 L
.1226 .10578 L
.12253 .10564 L
.12247 .10549 L
.12243 .10534 L
.1224 .10519 L
.12238 .10503 L
.12237 .10487 L
.12237 .10472 L
.12239 .10456 L
.12241 .1044 L
.12246 .10425 L
.12251 .1041 L
.12257 .10396 L
.12265 .10382 L
.12273 .10369 L
.12283 .10356 L
.12293 .10344 L
.12305 .10333 L
.12317 .10323 L
.1233 .10314 L
.12344 .10306 L
.12358 .103 L
Mistroke
.12373 .10294 L
.12388 .10289 L
.12403 .10286 L
.12419 .10284 L
.12435 .10283 L
.1245 .10283 L
.12466 .10285 L
.12482 .10288 L
.12497 .10292 L
.12512 .10297 L
.12526 .10304 L
.1254 .10311 L
.12553 .1032 L
.12566 .10329 L
.12578 .1034 L
.12589 .10351 L
.12599 .10363 L
.12608 .10376 L
.12616 .1039 L
.12622 .10404 L
.12628 .10419 L
.12633 .10434 L
.12636 .1045 L
.12638 .10465 L
.12639 .10481 L
.12639 .10497 L
.12637 .10513 L
.12634 .10528 L
.1263 .10543 L
.12625 .10558 L
.12618 .10573 L
Mfstroke
.039 .916 .04 r
.02381 .29089 m
.12438 .28209 L
s
% Start of user PostScript
-525. 185. -425. 176.251 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12438 .28209 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29089 m
.12438 .29089 L
s
% Start of user PostScript
-525. 185. -425. 185. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12438 .29089 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29089 m
.12438 .29969 L
s
% Start of user PostScript
-525. 185. -425. 193.749 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12438 .29969 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .10484 m
.59253 .12831 L
s
% Start of user PostScript
422. 0 40.5104 23.3329 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59253 .12831 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .10484 m
.58498 .10484 L
s
% Start of user PostScript
422. 0 33. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.58498 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .10484 m
.59253 .08138 L
s
% Start of user PostScript
422. 0 40.5104 -23.3329 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59253 .08138 Mdot
.039 .916 .04 r
.5 Mabswid
.12438 .28209 m
.12862 .28185 L
s
% Start of user PostScript
-425. 176.251 -420.785 176.009 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12862 .28185 Mdot
.039 .916 .04 r
.5 Mabswid
.12438 .29089 m
.12941 .29089 L
s
% Start of user PostScript
-425. 185. -420. 185. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12941 .29089 Mdot
.039 .916 .04 r
.5 Mabswid
.12438 .29969 m
.12862 .29994 L
s
% Start of user PostScript
-425. 193.749 -420.785 193.991 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12862 .29994 Mdot
.039 .916 .04 r
.5 Mabswid
.59253 .12831 m
.57917 .13171 L
s
% Start of user PostScript
40.5104 23.3329 27.2274 26.7183 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57917 .13171 Mdot
.039 .916 .04 r
.5 Mabswid
.58498 .10484 m
.57191 .10484 L
s
% Start of user PostScript
33. 0 20. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57191 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.59253 .08138 m
.57917 .07797 L
s
% Start of user PostScript
40.5104 -23.3329 27.2274 -26.7183 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57917 .07797 Mdot
.039 .916 .04 r
.5 Mabswid
.12862 .28185 m
.30398 .28252 L
s
% Start of user PostScript
-420.785 176.009 -246.416 176.677 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30398 .28252 Mdot
.039 .916 .04 r
.5 Mabswid
.12941 .29089 m
.30037 .29089 L
s
% Start of user PostScript
-420. 185. -250. 185. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30037 .29089 Mdot
.039 .916 .04 r
.5 Mabswid
.12862 .29994 m
.29676 .29929 L
s
% Start of user PostScript
-420.785 193.991 -253.596 193.351 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.29676 .29929 Mdot
.039 .916 .04 r
.5 Mabswid
.57917 .13171 m
.54878 .13521 L
s
% Start of user PostScript
27.2274 26.7183 -3. 30.1995 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54878 .13521 Mdot
.039 .916 .04 r
.5 Mabswid
.57191 .10484 m
.54878 .10484 L
s
% Start of user PostScript
20. 0 -3. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54878 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.57917 .07797 m
.54878 .07447 L
s
% Start of user PostScript
27.2274 -26.7183 -3. -30.1995 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54878 .07447 Mdot
.039 .916 .04 r
.5 Mabswid
.30398 .28252 m
.12896 .09892 L
s
% Start of user PostScript
-246.416 176.677 -420.444 -5.88966 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12896 .09892 Mdot
.039 .916 .04 r
.5 Mabswid
.30037 .29089 m
.12548 .10601 L
s
% Start of user PostScript
-250. 185. -423.9 1.16328 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12548 .10601 Mdot
.039 .916 .04 r
.5 Mabswid
.29676 .29929 m
.122 .11313 L
s
% Start of user PostScript
-253.596 193.351 -427.365 8.23643 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.122 .11313 Mdot
.039 .916 .04 r
.5 Mabswid
.54878 .13521 m
.54727 .13533 L
s
% Start of user PostScript
-3. 30.1995 -4.5 30.3128 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54727 .13533 Mdot
.039 .916 .04 r
.5 Mabswid
.54878 .10484 m
.54727 .10484 L
s
% Start of user PostScript
-3. 0 -4.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54727 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.54878 .07447 m
.54727 .07436 L
s
% Start of user PostScript
-3. -30.1995 -4.5 -30.3128 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54727 .07436 Mdot
.039 .916 .04 r
.5 Mabswid
.12896 .09892 m
.12776 .09794 L
s
% Start of user PostScript
-420.444 -5.88966 -421.636 -6.86505 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12776 .09794 Mdot
.039 .916 .04 r
.5 Mabswid
.12548 .10601 m
.12429 .10503 L
s
% Start of user PostScript
-423.9 1.16328 -425.09 0.184436 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12429 .10503 Mdot
.039 .916 .04 r
.5 Mabswid
.122 .11313 m
.1208 .11214 L
s
% Start of user PostScript
-427.365 8.23643 -428.554 7.25414 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1208 .11214 Mdot
.039 .916 .04 r
.5 Mabswid
.54727 .13533 m
.52162 .13828 L
s
% Start of user PostScript
-4.5 30.3128 -30. 33.2496 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.52162 .13828 Mdot
.039 .916 .04 r
.5 Mabswid
.54727 .10484 m
.52162 .10484 L
s
% Start of user PostScript
-4.5 0 -30. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.52162 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.54727 .07436 m
.52162 .0714 L
s
% Start of user PostScript
-4.5 -30.3128 -30. -33.2496 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.52162 .0714 Mdot
.039 .916 .04 r
.5 Mabswid
.12776 .09794 m
.12776 .09794 L
s
% Start of user PostScript
-421.636 -6.86505 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.12776 .09794 Mdot
.039 .916 .04 r
.5 Mabswid
.12429 .10503 m
.12429 .10503 L
s
% Start of user PostScript
-425.09 0.184436 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.12429 .10503 Mdot
.039 .916 .04 r
.5 Mabswid
.1208 .11214 m
.1208 .11214 L
s
% Start of user PostScript
-428.554 7.25414 MAarrowzero1
% End of user PostScript
0 0 0 r
2 Mabswid
.1208 .11214 Mdot
.039 .916 .04 r
.5 Mabswid
.52162 .13828 m
.50857 .13927 L
s
% Start of user PostScript
-30. 33.2496 -42.9766 34.2295 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50857 .13927 Mdot
.039 .916 .04 r
.5 Mabswid
.52162 .10484 m
.50603 .10484 L
s
% Start of user PostScript
-30. 0 -45.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50603 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.52162 .0714 m
.50857 .07042 L
s
% Start of user PostScript
-30. -33.2496 -42.9766 -34.2295 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50857 .07042 Mdot
.039 .916 .04 r
.5 Mabswid
.50857 .13927 m
.48425 .14019 L
s
% Start of user PostScript
-42.9766 34.2295 -67.1613 35.1476 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48425 .14019 Mdot
.039 .916 .04 r
.5 Mabswid
.50603 .10484 m
.48693 .10484 L
s
% Start of user PostScript
-45.5 0 -64.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48693 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.50857 .07042 m
.48425 .06949 L
s
% Start of user PostScript
-42.9766 -34.2295 -67.1613 -35.1476 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48425 .06949 Mdot
.039 .916 .04 r
.5 Mabswid
.48425 .14019 m
.47134 .13984 L
s
% Start of user PostScript
-67.1613 35.1476 -80. 34.7993 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.47134 .13984 Mdot
.039 .916 .04 r
.5 Mabswid
.48693 .10484 m
.47134 .10484 L
s
% Start of user PostScript
-64.5 0 -80. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.47134 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.48425 .06949 m
.47134 .06984 L
s
% Start of user PostScript
-67.1613 -35.1476 -80. -34.7993 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.47134 .06984 Mdot
.039 .916 .04 r
.5 Mabswid
.47134 .13984 m
.1783 .12775 L
s
% Start of user PostScript
-80. 34.7993 -371.38 22.7815 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1783 .12775 Mdot
.039 .916 .04 r
.5 Mabswid
.47134 .10484 m
.1836 .10484 L
s
% Start of user PostScript
-80. 0 -366.11 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1836 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.47134 .06984 m
.1783 .08193 L
s
% Start of user PostScript
-80. -34.7993 -371.38 -22.7815 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1783 .08193 Mdot
.039 .916 .04 r
.5 Mabswid
.1783 .12775 m
.17466 .12706 L
s
% Start of user PostScript
-371.38 22.7815 -375. 22.0963 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.17466 .12706 Mdot
.039 .916 .04 r
.5 Mabswid
.1836 .10484 m
.17466 .10484 L
s
% Start of user PostScript
-366.11 0 -375. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.17466 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.1783 .08193 m
.17466 .08262 L
s
% Start of user PostScript
-371.38 -22.7815 -375. -22.0963 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.17466 .08262 Mdot
.039 .916 .04 r
.5 Mabswid
.17466 .12706 m
.12267 .11175 L
s
% Start of user PostScript
-375. 22.0963 -426.694 6.86619 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12267 .11175 Mdot
.039 .916 .04 r
.5 Mabswid
.17466 .10484 m
.12606 .10484 L
s
% Start of user PostScript
-375. 0 -423.33 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12606 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.17466 .08262 m
.13058 .09561 L
s
% Start of user PostScript
-375. -22.0963 -418.83 -9.18301 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.13058 .09561 Mdot
.039 .916 .04 r
.5 Mabswid
.12267 .11175 m
.12125 .11123 L
s
% Start of user PostScript
-426.694 6.86619 -428.114 6.35629 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12125 .11123 Mdot
.039 .916 .04 r
.5 Mabswid
.12606 .10484 m
.1245 .10459 L
s
% Start of user PostScript
-423.33 0 -424.876 -0.252484 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1245 .10459 Mdot
.039 .916 .04 r
.5 Mabswid
.13058 .09561 m
.1289 .09562 L
s
% Start of user PostScript
-418.83 -9.18301 -420.505 -9.17407 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1289 .09562 Mdot
[(CL)] .17913 .05017 0 0 Mshowa
[(M)] .3177 .25827 0 0 Mshowa
[(H)] .54802 .01648 0 0 Mshowa
[(L1)] .51383 .20225 0 0 Mshowa
[(L)] .12689 .25382 0 0 Mshowa
[(L2)] .47913 .00743 0 0 Mshowa
[(HOE1)] .14911 .05608 0 0 Mshowa
[(HOE2)] .14911 .05608 0 0 Mshowa
0 0 m
1 0 L
1 .31202 L
0 .31202 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 89.8125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000FB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00Q03oool5000000030?ooo`000000000000800000TP3oool008D0oooo
00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo0900oooo00250?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool3000000040?ooo`00000000000000
0800oooo00250?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool01@000000
oooo0?ooo`3oool000000840oooo00250?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02P3oool01@000000oooo0?ooo`3oool000000840oooo00250?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000303oool500000840oooo00240?ooo`<00000103oool2000000d0
oooo00D000000?ooo`3oool0oooo000000210?ooo`00VP3oool01@000000oooo0?ooo`3oool00000
0840oooo002I0?ooo`<0000000@0oooo0000000000000000P03oool008L0oooo0P00000;0?ooo`80
0000RP3oool008L0oooo0P00000;0?ooo`800000RP3oool008L0oooo0`0000090?ooo`<000001P3o
ool200000880oooo000b0?ooo`<000000P3oool5000004/0oooo0`0000090?ooo`<000001P3oool2
00000880oooo000Q0?ooo`<0000000@0oooo00000000000000000P3oool2000000<0oooo1@000000
0`3oool000000000000200000080oooo00<000000?ooo`3oool0B@3oool3000000T0oooo0`000006
0?ooo`80000000<0oooo0000003oool0O`3oool00280oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`3oool000000?ooo`000000oooo0080
0000CP3oool3000000T0oooo0`0000060?ooo`80000000<0oooo0000003oool03`3oool2000006h0
oooo000R0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`040000003oool0oooo
000000D0oooo0`00001>0?ooo`80000000<0Ogmo0000003oool01P3oool010000000Ogmo00000000
00060?ooo`80000000<0oooo0000003oool0303oool30000000307moO`000000oooo06d0oooo000R
0?ooo`D0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`03000000@0oooo0P00001>
0?ooo`80000000<0Ogmo0000003oool01P3oool010000000Ogmo0000000000060?ooo`80000000<0
oooo0000003oool02@3oool3000000@0Ogmo00<000000?ooo`3oool0K03oool00280oooo00@00000
0?ooo`000000oooo0`0000040?ooo`030000003oool0oooo008000000`3oool010000000oooo0000
0000001>0?ooo`80000000@0Ogmo0000003oool0oooo0`09jPX20?ooo`040000001oOgl000000000
00H0oooo0P0000000`3oool000000?ooo`080?ooo`030000001oOgl0000000H0Ogmo00<000000?oo
o`3oool0J`3oool00280oooo0P0000020?ooo`040000003oool0000000000080oooo00H000000?oo
o`3oool0oooo0000003oool8000004d0oooo0P00000;00WZ2P80000000@0oooo00WZ2P09jPX02NX:
0P3oool2000000030?ooo`000000oooo00L0oooo0P00000207moO`040000001oOgl0Ogmo07moO`<0
0000K@3oool00240oooo0`000000103oool000000000000000020?ooo`8000000`3oool500000080
oooo0P0000150?ooo`/02NX:00<0000000WZ2P09jPX04`09jPX0103oool000000?ooo`3oool300WZ
2P80oooo0P0000000`1oOgl0000007moO`0400000700oooo000R0?ooo`030000003oool0oooo00L0
oooo0P00000=0?ooo`@02NX::P3ooolD00WZ2PX0oooo0P0000000`1oOgl02NX:00WZ2P0600WZ2P03
00000009jPX02NX:00P02NX:00<0000000WZ2P09jPX01P09jPX20000000407moO`000000Ogmo0000
07@0oooo000R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P0000080?ooo`L0
2NX:5@3ooolE00WZ2Qh0oooo0P00000207moO`030000003oool0oooo00D02NX:00<0Ogmo00WZ2P09
jPX01`09jPX00`0000002NX:00WZ2P0400WZ2P<0000000@0Ogmo0000001oOgl00000103oool300WZ
2Vh0oooo000Q0?ooo`030000003oool0oooo00H0oooo0P0000030?ooo`802NX:00<000000?ooo`3o
ool00P00000800WZ2P80oooo5009jPXc0?ooo`8000000P1oOgl00`000000oooo0?ooo`030?ooo`03
0000001oOgl02NX:008000000P3oool500WZ2P030000003oool02NX:01402NX:K`3oool00240oooo
00<000000?ooo`3oool01P3oool200000080oooo0`09jPX00`3oool000000?ooo`0<00WZ2TL0oooo
0P00000207moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00P0000060?ooo`030000
0009jPX0oooo00<0oooo0`09jPX00`000000Ogmo00WZ2P0;00WZ2Vd0oooo000P0?ooo`030000003o
ool0oooo00H0oooo0P0000000`3oool02NX:00WZ2P0200WZ2P050?ooo`09jPX02NX:00WZ2P3oool0
0`0000030?ooo`@02NX:B03oool200000080Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo
07moO`02000000H0oooo0P0000060?ooo`0500WZ2P1oOgl0000007moO`0000001`09jPX30?oooa80
2NX:F`3oool00200oooo00<000000?ooo`3oool01P3oool2000000H02NX:00@000000?ooo`3oool0
oooo0`00001?0?ooo`8000000P1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo0080
00001P3oool2000000H0oooo100000020?ooo`<02NX:0P3oool200WZ2Q@0oooo4@09jPY:0?ooo`00
7`3oool00`000000oooo0?ooo`060?ooo`8000002009jPX30?ooo`<00000C`3oool200000080Ogmo
00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`02000000H0oooo0P0000050?ooo`<00000
00<0Ogmo0000003oool00`3oool00`09jPX0oooo0?ooo`0W0?oooa802NX:>03oool001l0oooo00<0
00000?ooo`3oool01@3oool3000000H02NX:00<000000?ooo`3oool00P3oool3000000<0oooo1@09
jPY70?ooo`8000000P1oOgl00`000000oooo00WZ2P0200WZ2P040?ooo`09jPX02NX:00WZ2P800000
00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P@0oooo1009jPX2000000050?ooo`09jPX02NX:00WZ
2P3oool00`09jPXh0?oooa802NX:9P3oool001l0oooo00<000000?ooo`3oool01@3oool2000000L0
2NX:00<000000?ooo`3oool00P3oool2000000P02NX:B03oool2000001@02NX:00<0000000WZ2P09
jPX03`09jPY;0?oooa402NX:5@3oool001h0oooo00<000000?ooo`3oool01@3oool3000005l02NX:
00<0000000WZ2P09jPX04P09jPX00`0000002NX:00WZ2P1d00WZ2P`0oooo000N0?ooo`030000003o
ool0oooo00D0oooo0`00000600WZ2P030000003oool0oooo0080oooo1000000700WZ2TP0oooo0P00
00000`1oOgl02NX:00WZ2P0700WZ2P0307moO`09jPX02NX:00L02NX:00<000000?ooo`09jPX01@09
jPX00`0000002NX:00WZ2P0700WZ2Td0oooo3`09jPXE0?ooo`007@3oool00`000000oooo0?ooo`06
0?ooo`8000002009jPX50?ooo`<00000103oool400WZ2TL0oooo0P00000207moO`030000003oool0
oooo00802NX:00@0oooo00000009jPX02NX:0P0000020?ooo`802NX:0P3oool200WZ2PD0oooo0`09
jPX200000080oooo0P09jPX20?ooo`802NX:?@3oool?00WZ2R@0oooo000M0?ooo`030000003oool0
oooo00H0oooo0P00000800WZ2PD0oooo0`00001?0?ooo`8000000P1oOgl00`000000oooo0?ooo`03
0?ooo`030000001oOgl0Ogmo008000001P3oool2000000D0oooo0P0000000`1oOgl000000000000f
0?ooo`l02NX:<`3oool001`0oooo00<000000?ooo`3oool01P3oool2000000X02NX:103oool30000
04l0oooo0P00000207moO`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00P0000060?oo
o`8000001@3oool01@000000Ogmo0000001oOgl0000000<0oooo0P09jPX20?ooo`802NX:7P3oool?
00WZ2T80oooo000L0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool02NX:00WZ2P0600WZ
2P80oooo0`09jPX0103oool000000000000000020?ooo`D02NX:B03oool200000080Ogmo00<00000
0?ooo`3oool00`3oool00`000000Ogmo07moO`02000000H0oooo0P0000060?ooo`050000001oOgl0
00000000003oool02009jPX?0?ooo`l02NX:D@3oool001/0oooo00<000000?ooo`3oool01P3oool2
00000080oooo1`09jPX50?ooo`d02NX:AP3oool200000080Ogmo00<000000?ooo`3oool00`3oool0
0`000000Ogmo07moO`02000000H0oooo0P0000050?ooo`802NX:00<0000007moO`0000002009jPX0
0`3oool02NX:00WZ2P0=00WZ2V00oooo000K0?ooo`030000003oool0oooo00D0oooo0P0000030?oo
o`H02NX:00<0oooo00WZ2P3oool00`3oool3000000H02NX:103ooolD00WZ2S80oooo0P00000207mo
O`030000003oool0oooo00<0oooo00<0000007moO`1oOgl00P0000020?ooo`802NX:00@0oooo00WZ
2P09jPX02NX:0P3oool400WZ2P8000002`09jPY_0?ooo`006P3oool2000000L0oooo0P0000040?oo
o`<02NX:00D000000?ooo`09jPX0oooo00WZ2P080?ooo`D02NX:5`3ooolE00WZ2Qd0oooo0P000002
07moO`030000003oool02NX:00802NX:00D0oooo00WZ2P09jPX02NX:0000000800WZ2P0300000009
jPX02NX:01802NX:KP3oool001`0oooo0P00000;0?ooo`802NX:00L0000000WZ2P3oool0oooo00WZ
2P3oool02NX:00P0oooo0`09jPX00`3oool02NX:0?ooo`0Z0?oooa@02NX:2@3oool2000001@02NX:
00<0000000WZ2P09jPX01@09jPX0103oool0000007moO`00000207moO`800000L`3oool001h0oooo
0P00000:0?ooo`0400WZ2P000000oooo00WZ2P80oooo00<02NX:0?ooo`09jPX02@3oool00`09jPX0
oooo0?ooo`0o0?ooo`X02NX:00<0000000WZ2P09jPX01`09jPX00`0000002NX:00WZ2P0800WZ2P03
0000003oool000000080oooo1009jPX00`3oool0000007moO`0207moO`030000001oOgl0000000<0
0000K`3oool00200oooo0P0000080?ooo`050000003oool0oooo0?ooo`09jPX00P3oool00`09jPX0
oooo00WZ2P1C0?ooo`80000000<0Ogmo00WZ2P09jPX01`09jPX00`1oOgl000000000000400WZ2P80
oooo0P09jPX00`3oool000000?ooo`070?ooo`030000001oOgl000000080Ogmo00@0000007moO`1o
Ogl0Ogmo0P00001]0?ooo`008P3oool2000000H0oooo00<000000?ooo`3oool00P3oool01P09jPX0
oooo0?ooo`09jPX0oooo00WZ2U80oooo0P0000000`1oOgl000000?ooo`020?ooo`802NX:0P3oool2
00WZ2P8000001P3oool2000000030?ooo`000000oooo00P0oooo0P0000000`1oOgl0000007moO`04
07moO`030000003oool0oooo06/0oooo000T0?ooo`8000000`3oool00`000000oooo0?ooo`040?oo
o`0600WZ2P3oool0oooo00WZ2P3oool02NX:D@3oool20000000307moO`000000oooo00H0oooo00@0
000007moO`00000000001P3oool2000000030?ooo`000000oooo00X0oooo0`00000407moO`030000
003oool0oooo06/0oooo000V0?ooo`80000000<0oooo0000003oool01P3oool01P09jPX0oooo0?oo
o`09jPX0oooo00WZ2U00oooo0P0000000`1oOgl000000?ooo`060?ooo`040000001oOgl000000000
00H0oooo0P0000000`3oool000000?ooo`0=0?ooo`@00000KP3oool002P0oooo00<000000?ooo`3o
ool01`3oool01P09jPX0oooo0?ooo`09jPX0oooo00WZ2Tl0oooo0P0000000`1oOgl000000?ooo`06
0?ooo`040000001oOgl00000000000H0oooo0P0000000`3oool000000?ooo`0@0?ooo`030000003o
ool0oooo06`0oooo000c0?ooo`0600WZ2P3oool0oooo00WZ2P3oool02NX:CP3oool3000000T0oooo
0`0000060?ooo`80000000<0oooo0000003oool0O`3oool003@0oooo00H02NX:0?ooo`3oool02NX:
0?ooo`09jPY=0?ooo`<000002@3oool3000000H0oooo0P0000220?ooo`00=@3oool00`09jPX0oooo
00WZ2P020?ooo`0300WZ2P3oool0oooo04X0oooo0`0000090?ooo`<000001P3oool200000880oooo
000f0?ooo`0300WZ2P3oool02NX:0080oooo00<02NX:0?ooo`3oool0B@3oool3000000T0oooo0`00
002:0?ooo`00=P3oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo04P0oooo0P00
000;0?ooo`800000RP3oool003L0oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?oo
o`3P0?ooo`00>03oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo0=l0oooo000i
0?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0gP3oool003X0oooo00@02NX:
0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`3M0?ooo`00>`3oool01009jPX0oooo0?ooo`09
jPX20?ooo`0300WZ2P3oool0oooo04T0oooo1@0000020?ooo`<00000R@3oool003`0oooo00@02NX:
0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`190?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0R03oool003d0oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo
0?ooo`180?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0R03oool003h0oooo00@0
2NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`170?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0R03oool003l0oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo
0?ooo`160?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0R03oool00400oooo00@0
2NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`150?ooo`030000003oool0oooo00<0oooo
0P00002:0?ooo`00@@3oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo04<0oooo
0`0000050?ooo`030000003oool0oooo08P0oooo00120?ooo`0400WZ2P3oool0oooo00WZ2P80oooo
00<02NX:0?ooo`3oool0e@3oool004<0oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo
0?ooo`3D0?ooo`00A03oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0oooo0=<0oooo
00150?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0dP3oool004H0oooo00<0
2NX:0?ooo`09jPX00`3oool00`09jPX0oooo0?ooo`3A0?ooo`00A`3oool00`09jPX0oooo00WZ2P03
0?ooo`0300WZ2P3oool0oooo0=00oooo00170?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00<02NX:
0?ooo`3oool0c`3oool002D0oooo1@00000N0?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00<02NX:
0?ooo`3oool0cP3oool002H0oooo00@000000?ooo`3oool000007`3oool01009jPX0oooo0?ooo`09
jPX30?ooo`0300WZ2P3oool0oooo00D0oooo0`0000030?ooo`<00000_`3oool002H0oooo00<00000
0?ooo`3oool08@3oool01009jPX0oooo0?ooo`09jPX30?ooo`0300WZ2P3oool0oooo00D0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`2n0?ooo`009P3oool00`000000oooo0?oo
o`0R0?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00<02NX:0?ooo`3oool0103oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0;h0oooo000V0?ooo`030000003oool0oooo02<0oooo
00@02NX:0?ooo`3oool02NX:0`3oool00`09jPX0oooo0?ooo`030?ooo`070000003oool000000?oo
o`000000oooo000000300?ooo`009P3oool00`000000oooo0?ooo`0T0?ooo`0400WZ2P3oool0oooo
00WZ2P<0oooo00<02NX:0?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`000000
`03oool002D0oooo0`00000V0?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00@02NX:0?ooo`3oool0
oooo0P0000030?ooo`800000`03oool004l0oooo00@02NX:0?ooo`3oool02NX:0`3oool00`09jPX0
oooo00000002000000<0oooo0`00002o0?ooo`00D03oool400WZ2P<0oooo00<02NX:0?ooo`3oool0
aP3oool001l0oooo1P09jPX20?ooo`800000:03oool800WZ2P030000003oool0oooo0<@0oooo000P
0?ooocP02NX:00@0000000WZ2P3oool00000a03oool001T0oooo3P09jPX3000002H0oooo1`09jPX0
103oool000000000001oOgo50?ooo`00403oool900WZ2PH0oooo2009jPX3000002L0oooo1`09jPX0
0`000000Ogmo000000350?ooo`002`3ooom<00WZ2P0400000009jPX0Ogmo00000<D0oooo000C0?oo
oa@02NX:0P00000W0?ooo`L02NX:00<0000007moO`000000aP3oool001l0oooo=`09jPX010000000
2NX:07moO`0000360?ooo`007`3oool700WZ2P040?ooo`0000000000000002H0oooo1@09jPX0103o
ool0000007moO`0000370?ooo`00803oool200WZ2Rd0oooo0P09jP[?0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {88.8125, 0}} -> {-566.99, -113.029, 3.59226, \
3.59226}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["wave2 = FindWaveFronts[sys2];", "Input",
  CellLabel->"In[71]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.586398 0.0550687 -64.3947 0.0740712 [
[.03571 -0.0125 -9 -9 ]
[.03571 -0.0125 9 0 ]
[.17338 -0.0125 -12 -9 ]
[.17338 -0.0125 12 0 ]
[.31105 -0.0125 -6 -9 ]
[.31105 -0.0125 6 0 ]
[.44873 -0.0125 -12 -9 ]
[.44873 -0.0125 12 0 ]
[.5864 -0.0125 -3 -9 ]
[.5864 -0.0125 3 0 ]
[.72407 -0.0125 -9 -9 ]
[.72407 -0.0125 9 0 ]
[.86174 -0.0125 -3 -9 ]
[.86174 -0.0125 3 0 ]
[.99941 -0.0125 -9 -9 ]
[.99941 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04722 -18 -4.5 ]
[-0.0125 .04722 0 4.5 ]
[-0.0125 .19536 -18 -4.5 ]
[-0.0125 .19536 0 4.5 ]
[-0.0125 .34351 -18 -4.5 ]
[-0.0125 .34351 0 4.5 ]
[-0.0125 .49165 -18 -4.5 ]
[-0.0125 .49165 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03571 0 m
.03571 .00625 L
s
[(-10)] .03571 -0.0125 0 1 Mshowa
.17338 0 m
.17338 .00625 L
s
[(-7.5)] .17338 -0.0125 0 1 Mshowa
.31105 0 m
.31105 .00625 L
s
[(-5)] .31105 -0.0125 0 1 Mshowa
.44873 0 m
.44873 .00625 L
s
[(-2.5)] .44873 -0.0125 0 1 Mshowa
.5864 0 m
.5864 .00625 L
s
[(0)] .5864 -0.0125 0 1 Mshowa
.72407 0 m
.72407 .00625 L
s
[(2.5)] .72407 -0.0125 0 1 Mshowa
.86174 0 m
.86174 .00625 L
s
[(5)] .86174 -0.0125 0 1 Mshowa
.99941 0 m
.99941 .00625 L
s
[(7.5)] .99941 -0.0125 0 1 Mshowa
.125 Mabswid
.06325 0 m
.06325 .00375 L
s
.09078 0 m
.09078 .00375 L
s
.11831 0 m
.11831 .00375 L
s
.14585 0 m
.14585 .00375 L
s
.20092 0 m
.20092 .00375 L
s
.22845 0 m
.22845 .00375 L
s
.25599 0 m
.25599 .00375 L
s
.28352 0 m
.28352 .00375 L
s
.33859 0 m
.33859 .00375 L
s
.36612 0 m
.36612 .00375 L
s
.39366 0 m
.39366 .00375 L
s
.42119 0 m
.42119 .00375 L
s
.47626 0 m
.47626 .00375 L
s
.5038 0 m
.5038 .00375 L
s
.53133 0 m
.53133 .00375 L
s
.55886 0 m
.55886 .00375 L
s
.61393 0 m
.61393 .00375 L
s
.64147 0 m
.64147 .00375 L
s
.669 0 m
.669 .00375 L
s
.69654 0 m
.69654 .00375 L
s
.7516 0 m
.7516 .00375 L
s
.77914 0 m
.77914 .00375 L
s
.80667 0 m
.80667 .00375 L
s
.83421 0 m
.83421 .00375 L
s
.88928 0 m
.88928 .00375 L
s
.91681 0 m
.91681 .00375 L
s
.94434 0 m
.94434 .00375 L
s
.97188 0 m
.97188 .00375 L
s
.00818 0 m
.00818 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04722 m
.00625 .04722 L
s
[(870)] -0.0125 .04722 1 0 Mshowa
0 .19536 m
.00625 .19536 L
s
[(872)] -0.0125 .19536 1 0 Mshowa
0 .34351 m
.00625 .34351 L
s
[(874)] -0.0125 .34351 1 0 Mshowa
0 .49165 m
.00625 .49165 L
s
[(876)] -0.0125 .49165 1 0 Mshowa
.125 Mabswid
0 .08426 m
.00375 .08426 L
s
0 .12129 m
.00375 .12129 L
s
0 .15833 m
.00375 .15833 L
s
0 .2324 m
.00375 .2324 L
s
0 .26944 m
.00375 .26944 L
s
0 .30647 m
.00375 .30647 L
s
0 .38054 m
.00375 .38054 L
s
0 .41758 m
.00375 .41758 L
s
0 .45461 m
.00375 .45461 L
s
0 .01019 m
.00375 .01019 L
s
0 .52869 m
.00375 .52869 L
s
0 .56572 m
.00375 .56572 L
s
0 .60276 m
.00375 .60276 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.03571 .61178 m
.03571 .61803 L
s
.17338 .61178 m
.17338 .61803 L
s
.31105 .61178 m
.31105 .61803 L
s
.44873 .61178 m
.44873 .61803 L
s
.5864 .61178 m
.5864 .61803 L
s
.72407 .61178 m
.72407 .61803 L
s
.86174 .61178 m
.86174 .61803 L
s
.99941 .61178 m
.99941 .61803 L
s
.125 Mabswid
.06325 .61428 m
.06325 .61803 L
s
.09078 .61428 m
.09078 .61803 L
s
.11831 .61428 m
.11831 .61803 L
s
.14585 .61428 m
.14585 .61803 L
s
.20092 .61428 m
.20092 .61803 L
s
.22845 .61428 m
.22845 .61803 L
s
.25599 .61428 m
.25599 .61803 L
s
.28352 .61428 m
.28352 .61803 L
s
.33859 .61428 m
.33859 .61803 L
s
.36612 .61428 m
.36612 .61803 L
s
.39366 .61428 m
.39366 .61803 L
s
.42119 .61428 m
.42119 .61803 L
s
.47626 .61428 m
.47626 .61803 L
s
.5038 .61428 m
.5038 .61803 L
s
.53133 .61428 m
.53133 .61803 L
s
.55886 .61428 m
.55886 .61803 L
s
.61393 .61428 m
.61393 .61803 L
s
.64147 .61428 m
.64147 .61803 L
s
.669 .61428 m
.669 .61803 L
s
.69654 .61428 m
.69654 .61803 L
s
.7516 .61428 m
.7516 .61803 L
s
.77914 .61428 m
.77914 .61803 L
s
.80667 .61428 m
.80667 .61803 L
s
.83421 .61428 m
.83421 .61803 L
s
.88928 .61428 m
.88928 .61803 L
s
.91681 .61428 m
.91681 .61803 L
s
.94434 .61428 m
.94434 .61803 L
s
.97188 .61428 m
.97188 .61803 L
s
.00818 .61428 m
.00818 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04722 m
1 .04722 L
s
.99375 .19536 m
1 .19536 L
s
.99375 .34351 m
1 .34351 L
s
.99375 .49165 m
1 .49165 L
s
.125 Mabswid
.99625 .08426 m
1 .08426 L
s
.99625 .12129 m
1 .12129 L
s
.99625 .15833 m
1 .15833 L
s
.99625 .2324 m
1 .2324 L
s
.99625 .26944 m
1 .26944 L
s
.99625 .30647 m
1 .30647 L
s
.99625 .38054 m
1 .38054 L
s
.99625 .41758 m
1 .41758 L
s
.99625 .45461 m
1 .45461 L
s
.99625 .01019 m
1 .01019 L
s
.99625 .52869 m
1 .52869 L
s
.99625 .56572 m
1 .56572 L
s
.99625 .60276 m
1 .60276 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5864 0 m
.5864 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.94714 .59626 Mdot
.91857 .58841 Mdot
.89059 .5799 Mdot
.86323 .57083 Mdot
.83644 .56125 Mdot
.81017 .5512 Mdot
.78435 .54072 Mdot
.7589 .52981 Mdot
.73373 .51846 Mdot
.70876 .50667 Mdot
.6839 .49441 Mdot
.65906 .48166 Mdot
.63414 .46837 Mdot
.60906 .45449 Mdot
.58372 .43998 Mdot
.55801 .42477 Mdot
.53184 .40878 Mdot
.5051 .39193 Mdot
.47765 .37412 Mdot
.44937 .35524 Mdot
.42012 .33514 Mdot
.38972 .31369 Mdot
.358 .29068 Mdot
.32476 .26592 Mdot
.28974 .23915 Mdot
.25269 .21007 Mdot
.21328 .17833 Mdot
.17116 .14349 Mdot
.12588 .10505 Mdot
.07696 .06237 Mdot
.5 Mabswid
.02381 .01472 m
.05372 .04153 L
.08634 .07055 L
.11698 .09728 L
.14644 .1225 L
.1778 .14898 L
.20799 .17395 L
.24008 .19991 L
.27099 .22443 L
.30073 .24755 L
.33237 .27159 L
.36283 .29419 L
.39213 .31538 L
.42332 .33734 L
.45333 .35788 L
.48525 .37905 L
.51599 .39879 L
.54556 .41716 L
.57703 .43602 L
.60732 .4535 L
.63951 .47123 L
.67053 .48755 L
.70038 .50254 L
.73212 .5177 L
.76269 .53144 L
.79209 .54386 L
.82339 .55626 L
.85351 .56735 L
.88553 .57822 L
.91638 .58774 L
.94605 .59596 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[71]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00803oool3000000@0oooo0P00000G0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool3000001T0oooo0`00000H0?ooo`D000000`3oool00`000000oooo0?ooo`020?oo
o`<000005`3oool2000001T0oooo1@0000030?ooo`030000003oool0oooo0080oooo0`00000I0?oo
o`<000006P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`0000080?oo
o`008@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001H0oooo00<000000?oo
o`3oool01`3oool01@000000oooo0?ooo`3oool0000001L0oooo00D000000?ooo`3oool0oooo0000
000H0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`04
0000003oool0oooo000001T0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3o
ool0000001L0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`030000003oool0oooo00L0oooo
00D000000?ooo`3oool0oooo000000070?ooo`006@3oool5000000<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000>0?ooo`D00000103oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00l0oooo1@0000050?ooo`030000003oool0oooo00l0oooo1@0000030?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`00000J0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool04`3oool010000000oooo0?ooo`00000K0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000H
0?ooo`030000003oool0oooo00D0oooo1000000H0?ooo`@00000603oool01@000000oooo0?ooo`3o
ool0000000L0oooo1000000F0?ooo`040000003oool0oooo000001P0oooo00D000000?ooo`3oool0
oooo000000070?ooo`@00000603oool4000001`0oooo00<000000?ooo`3oool01@3oool4000000P0
oooo000P0?ooo`800000103oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo0?oo
o`0000001`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool00000603o
ool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0I0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`090?ooo`00
8@3oool00`000000oooo0?ooo`030?ooo`8000005@3oool5000000L0oooo1@00000G0?ooo`D00000
603oool3000000P0oooo1@00000F0?ooo`8000006P3oool3000000P0oooo1@00000G0?ooo`D00000
5`3oool5000000L0oooo1@0000070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`006P3ooooh000000h0oooo000J0?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo000J
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0H`3oool2000000h0oooo000J0?oo
o`030000003oool0oooo0080oooo0P0000290?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0303oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
303oool001X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`240?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool0
01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool0303oool000D0oooo0`0000040?ooo`030000003oool0oooo00<0
oooo0P0000060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo00040?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool02P3oool200000840oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?oo
o`00103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00<0oooo0P00000=0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0HP3oool3000000h0oooo00050?ooo`<000001@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo07d0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`00103oool01@00
0000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo00`0oooo00040?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`0<0?ooo`001@3oool300000080oooo1@0000030?ooo`8000001P3oool00`000000oooo
0?ooo`0?0?ooo`800000O03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo
000J0?ooo`030000003oool0oooo00l0oooo0`00001k0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0303oool001X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo06<0oooo0P00000>0?ooo`006P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo07<0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`0I0?ooo`800000LP3oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo01/0oooo
0P00001`0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<0
00000?ooo`3oool06`3oool200000700oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`0<0?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`800000KP3oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo0240oooo0P00001Z0?ooo`030000
003oool0oooo06<0oooo0P00000>0?ooo`006P3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`0V0?ooo`800000I@3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo02H0oooo1000
001S0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo06<0oooo0P00000>0?ooo`00
6P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`0`0?ooo`<00000FP3oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo0340
oooo0P00001J0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool000D0oooo
0`0000040?ooo`040000003oool0oooo0?ooo`D000001@3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`00
103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo03@0oooo0P00001G0?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool0303oool000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?oo
o`001@3oool3000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`80
0000>03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0680oooo0`00000>0?ooo`00
103oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03P0oooo0P00001C0?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool0303oool000@0oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
00`0oooo00050?ooo`<000000P3oool500000080oooo0`0000060?ooo`030000003oool0oooo03X0
oooo0P00001A0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo
00<000000?ooo`3oool0>P3oool4000004l0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<
0?ooo`006P3oool00`000000oooo0?ooo`100?ooo`800000B`3oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1S0?ooo`800000
3P3oool001X0oooo00<000000?ooo`3oool0@`3oool2000004P0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`130?ooo`<00000A`3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
00`0oooo000J0?ooo`030000003oool0oooo04L0oooo0P0000140?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0B`3oool200000400oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`1<0?oo
o`800000?`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`03
0000003oool0oooo04`0oooo0`00000n0?ooo`030000003oool0oooo06<0oooo0P00000>0?ooo`00
6P3oool00`000000oooo0?ooo`1?0?ooo`800000?03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0
oooo0580oooo0P00000i0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool0
01X0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0E03oool2000003L0
oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo
0?ooo`1D0?ooo`@00000=@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo
000J0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1S0?oo
o`8000003P3oool001X0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0
G03oool2000002l0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3o
ool00`000000oooo0?ooo`1L0?ooo`<00000;P3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo00`0oooo000J0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo
0600oooo0P00000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0
oooo00<000000?ooo`3oool0HP3oool2000002T0oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`0<0?ooo`001@3oool3000000@0oooo00<000000?ooo`3oool00`3oool3000000D0oooo
00<000000?ooo`3oool0I03oool2000002L0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`0<0?ooo`00103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo0`00000V0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0303oool000@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00D000001@3oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`001@3o
ool3000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`800000
J@3oool2000002<0oooo00<000000?ooo`3oool0HP3oool3000000h0oooo00040?ooo`050000003o
ool0oooo0?ooo`0000001@3oool01P000000oooo0?ooo`000000oooo000000H0oooo00<000000?oo
o`3oool0JP3oool200000240oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?oo
o`00103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`3o
ool2000000H0oooo00<000000?ooo`3oool0J`3oool200000200oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`0<0?ooo`001@3oool300000080oooo1@0000040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0J`3oool4000001h0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000
oooo0?ooo`1`0?ooo`8000006`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0
oooo000J0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo0780oooo0P00
000I0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<00000
0?ooo`3oool0LP3oool4000001L0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<
0?ooo`006P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0H`3oool2000000h0oooo000J0?ooo`030000003oool0oooo07L0oooo0P00000D0?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0
N@3oool200000180oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3o
ool00`000000oooo0?ooo`1i0?ooo`<000004@3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo00`0oooo000J0?ooo`030000003oool0oooo07`0oooo0P00000?0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0
oooo00<000000?ooo`3oool0O`3oool2000000`0oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`1o0?ooo`<000002`3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J
0?ooo`030000003oool0oooo08<0oooo0P0000080?ooo`030000003oool0oooo06<0oooo0P00000>
0?ooo`006P3oool00`000000oooo0?ooo`250?ooo`<000001@3oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo08H0oooo0`0000040?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0
R@3oool200000080oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3o
ool00`000000oooo0?ooo`2;0?ooo`<00000IP3oool00`000000oooo0?ooo`0<0?ooo`006P3oool0
0`000000oooo0?ooo`2<0?ooo`800000IP3oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`00
0000oooo0?ooo`2<0?ooo`@00000I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo00800000HP3oool00`000000oooo0?ooo`0<0?ooo`00
6P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo0080oooo0`00001N0?ooo`8000003P3oool001X0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`020?ooo`80000000<0oooo000000000000G@3oool00`000000oooo0?ooo`0<
0?ooo`006P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00L0oooo0P00001K0?oo
o`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool02@3oool2000005T0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`090?ooo`@00000E`3oool00`000000oooo0?ooo`0<0?ooo`006P3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00d0oooo0P00001E0?ooo`030000003o
ool0oooo00`0oooo000J0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool03`3oool2
000005<0oooo00<000000?ooo`3oool0303oool000D0oooo0`0000040?ooo`030000003oool0oooo
0080oooo0`0000060?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool03`3oool30000
0580oooo00<000000?ooo`3oool0303oool000@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool04P3oool200000500oooo00<000000?ooo`3oool0303oool0
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00`3oool2000008h0oooo00<000000?ooo`3oool0503oool2000004`0oooo0`00
000>0?ooo`001@3oool3000000D0oooo00<000000?ooo`3oool0100000060?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool05@3oool3000004`0oooo00<000000?ooo`3oool0303oool0
00@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000T0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0E0?ooo`80000000<0oooo000000000000BP3oool0
0`000000oooo0?ooo`0<0?ooo`00103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
6P3oool2000004P0oooo00<000000?ooo`3oool0303oool000D0oooo0`0000020?ooo`D000000`3o
ool2000000H0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0K0?ooo`<00000AP3o
ool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo01/0oooo0P0000000`3oool000000?ooo`140?ooo`030000003oool0oooo00`0oooo000J0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool07`3oool400000440oooo00<000000?oo
o`3oool0303oool001X0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Q0?ooo`80
0000@@3oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo02<0oooo0`00000n0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool09P3oool3000003X0oooo0P00000>0?ooo`006P3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo1000000i0?ooo`030000003oool0
oooo00`0oooo000J0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:`3oool30000
03H0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0^0?ooo`800000=03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo02h0oooo1000000b0?ooo`030000003oool0oooo00`0oooo
000J0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0<P3oool3000002l0oooo00<0
00000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0d
0?ooo`@00000;03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03@0oooo0P0000020?ooo`800000:P3oool00`000000oooo0?ooo`0<0?oo
o`006P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03X0oooo0`00000W0?ooo`03
0000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
>`3oool4000002@0oooo0P00000>0?ooo`006P3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo03l0oooo1000000Q0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0@@3oool300000200oooo00<000000?ooo`3oool0303oool0
01X0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`140?ooo`<000007@3oool00`00
0000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04L0
oooo0`00000J0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0B03oool6000001H0oooo00<000000?ooo`3oool0303oool001X0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`1>0?ooo`@000004P3oool00`000000oooo0?oo
o`0<0?ooo`006P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04l0oooo0P000000
103oool0000000000000000?0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0E@3oool4000000/0oooo00<000000?ooo`3oool0303oool0
01X0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1F0?ooo`80000000<0oooo0000
000000000P0000070?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0G@3oool2000000@0oooo0P00000>0?ooo`006P3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0303oool001X0oooon000000>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`009P3oool3000005P0oooo0`00000G0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0603oool002L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool05`3oool00240oooo0`0000030?oo
o`<00000103oool200000080oooo1@0000020?ooo`<000000`3oool4000000030?ooo`0000000000
00<000001`3oool3000000@0oooo100000030?ooo`8000000P3oool6000000H0oooo1@0000020?oo
o`<000000P3oool3000000040?ooo`00000000000?ooo`@000000`3oool200000080oooo1P000007
0?ooo`030000003oool0oooo00<0oooo100000000`3oool000000000000200000080oooo10000003
0?ooo`<000000P3oool5000000<0oooo0P000000103oool000000?ooo`3oool2000000<0oooo0`00
00090?ooo`@0000000<0oooo0000000000000`0000000`3oool0000000000002000000@0oooo0P00
00030?ooo`@0000000D0oooo00000000000000000?ooo`02000000040?ooo`0000000000000000<0
oooo0`0000050?ooo`030000003oool0oooo01H0oooo000P0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00H000000?oo
o`3oool000000?ooo`0000060?ooo`060000003oool0oooo0000003oool000000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000002`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?oo
o`030000003oool0000000P0oooo00<000000?ooo`3oool05P3oool00200oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool0000000H0oooo0`0000040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo0080oooo1@0000020?ooo`060000003oool0oooo0000003o
ool000000`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool00`3oool3000000<0oooo00@000000?ooo`3oool000000P3oool300000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`020?ooo`D000001`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0080oooo0`0000030?ooo`030000003oool0oooo00<0oooo0`000003
0?ooo`060000003oool0oooo0000003oool000001@3oool5000000@0oooo00<000000?ooo`3oool0
5P3oool00200oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0`0000020?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`060000
003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`060000
003oool0oooo0000003oool000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000070?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01H0oooo000P0?ooo`060000003oool0oooo0?ooo`000000
oooo100000020?ooo`@000000P3oool3000000@0oooo0`0000030?ooo`8000001@3oool00`000000
oooo0?ooo`080?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`@000000`3oool30000
00T0oooo00<000000?ooo`3oool00`3oool300000080oooo100000030?ooo`T000000`3oool30000
00T0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0`0000030?ooo`@000000P3oool30000
00@0oooo00@000000?ooo`3oool0oooo0P000000103oool000000000003oool4000000<0oooo0`00
00090?ooo`<000000P3oool3000000@0oooo100000000`3oool0000000000002000000<0oooo0P00
00030?ooo`@000000`3oool3000000<0oooo0`0000050?ooo`030000003oool0oooo01H0oooo000P
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool05`3oool00240oooo0`0000090?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03@3oool3000000T0oooo100000090?ooo`030000003o
ool0oooo0080oooo0P00000:0?ooo`<000005P3oool00`000000oooo0?ooo`020?ooo`8000003@3o
ool00`000000oooo0?ooo`060?ooo`800000403oool3000000X0oooo00<000000?ooo`3oool0403o
ool2000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01P0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.5612, 868.702, 0.073469, \
0.054621}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.586398 0.0550687 -0.501863 0.00893731 [
[.03571 -0.0125 -9 -9 ]
[.03571 -0.0125 9 0 ]
[.17338 -0.0125 -12 -9 ]
[.17338 -0.0125 12 0 ]
[.31105 -0.0125 -6 -9 ]
[.31105 -0.0125 6 0 ]
[.44873 -0.0125 -12 -9 ]
[.44873 -0.0125 12 0 ]
[.5864 -0.0125 -3 -9 ]
[.5864 -0.0125 3 0 ]
[.72407 -0.0125 -9 -9 ]
[.72407 -0.0125 9 0 ]
[.86174 -0.0125 -3 -9 ]
[.86174 -0.0125 3 0 ]
[.99941 -0.0125 -9 -9 ]
[.99941 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03438 -12 -4.5 ]
[-0.0125 .03438 0 4.5 ]
[-0.0125 .12375 -12 -4.5 ]
[-0.0125 .12375 0 4.5 ]
[-0.0125 .21312 -12 -4.5 ]
[-0.0125 .21312 0 4.5 ]
[-0.0125 .3025 -12 -4.5 ]
[-0.0125 .3025 0 4.5 ]
[-0.0125 .39187 -18 -4.5 ]
[-0.0125 .39187 0 4.5 ]
[-0.0125 .48124 -18 -4.5 ]
[-0.0125 .48124 0 4.5 ]
[-0.0125 .57061 -18 -4.5 ]
[-0.0125 .57061 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03571 0 m
.03571 .00625 L
s
[(-10)] .03571 -0.0125 0 1 Mshowa
.17338 0 m
.17338 .00625 L
s
[(-7.5)] .17338 -0.0125 0 1 Mshowa
.31105 0 m
.31105 .00625 L
s
[(-5)] .31105 -0.0125 0 1 Mshowa
.44873 0 m
.44873 .00625 L
s
[(-2.5)] .44873 -0.0125 0 1 Mshowa
.5864 0 m
.5864 .00625 L
s
[(0)] .5864 -0.0125 0 1 Mshowa
.72407 0 m
.72407 .00625 L
s
[(2.5)] .72407 -0.0125 0 1 Mshowa
.86174 0 m
.86174 .00625 L
s
[(5)] .86174 -0.0125 0 1 Mshowa
.99941 0 m
.99941 .00625 L
s
[(7.5)] .99941 -0.0125 0 1 Mshowa
.125 Mabswid
.06325 0 m
.06325 .00375 L
s
.09078 0 m
.09078 .00375 L
s
.11831 0 m
.11831 .00375 L
s
.14585 0 m
.14585 .00375 L
s
.20092 0 m
.20092 .00375 L
s
.22845 0 m
.22845 .00375 L
s
.25599 0 m
.25599 .00375 L
s
.28352 0 m
.28352 .00375 L
s
.33859 0 m
.33859 .00375 L
s
.36612 0 m
.36612 .00375 L
s
.39366 0 m
.39366 .00375 L
s
.42119 0 m
.42119 .00375 L
s
.47626 0 m
.47626 .00375 L
s
.5038 0 m
.5038 .00375 L
s
.53133 0 m
.53133 .00375 L
s
.55886 0 m
.55886 .00375 L
s
.61393 0 m
.61393 .00375 L
s
.64147 0 m
.64147 .00375 L
s
.669 0 m
.669 .00375 L
s
.69654 0 m
.69654 .00375 L
s
.7516 0 m
.7516 .00375 L
s
.77914 0 m
.77914 .00375 L
s
.80667 0 m
.80667 .00375 L
s
.83421 0 m
.83421 .00375 L
s
.88928 0 m
.88928 .00375 L
s
.91681 0 m
.91681 .00375 L
s
.94434 0 m
.94434 .00375 L
s
.97188 0 m
.97188 .00375 L
s
.00818 0 m
.00818 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03438 m
.00625 .03438 L
s
[(60)] -0.0125 .03438 1 0 Mshowa
0 .12375 m
.00625 .12375 L
s
[(70)] -0.0125 .12375 1 0 Mshowa
0 .21312 m
.00625 .21312 L
s
[(80)] -0.0125 .21312 1 0 Mshowa
0 .3025 m
.00625 .3025 L
s
[(90)] -0.0125 .3025 1 0 Mshowa
0 .39187 m
.00625 .39187 L
s
[(100)] -0.0125 .39187 1 0 Mshowa
0 .48124 m
.00625 .48124 L
s
[(110)] -0.0125 .48124 1 0 Mshowa
0 .57061 m
.00625 .57061 L
s
[(120)] -0.0125 .57061 1 0 Mshowa
.125 Mabswid
0 .05225 m
.00375 .05225 L
s
0 .07013 m
.00375 .07013 L
s
0 .088 m
.00375 .088 L
s
0 .10587 m
.00375 .10587 L
s
0 .14162 m
.00375 .14162 L
s
0 .1595 m
.00375 .1595 L
s
0 .17737 m
.00375 .17737 L
s
0 .19525 m
.00375 .19525 L
s
0 .231 m
.00375 .231 L
s
0 .24887 m
.00375 .24887 L
s
0 .26675 m
.00375 .26675 L
s
0 .28462 m
.00375 .28462 L
s
0 .32037 m
.00375 .32037 L
s
0 .33824 m
.00375 .33824 L
s
0 .35612 m
.00375 .35612 L
s
0 .37399 m
.00375 .37399 L
s
0 .40974 m
.00375 .40974 L
s
0 .42762 m
.00375 .42762 L
s
0 .44549 m
.00375 .44549 L
s
0 .46337 m
.00375 .46337 L
s
0 .49912 m
.00375 .49912 L
s
0 .51699 m
.00375 .51699 L
s
0 .53487 m
.00375 .53487 L
s
0 .55274 m
.00375 .55274 L
s
0 .0165 m
.00375 .0165 L
s
0 .58849 m
.00375 .58849 L
s
0 .60636 m
.00375 .60636 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.03571 .61178 m
.03571 .61803 L
s
.17338 .61178 m
.17338 .61803 L
s
.31105 .61178 m
.31105 .61803 L
s
.44873 .61178 m
.44873 .61803 L
s
.5864 .61178 m
.5864 .61803 L
s
.72407 .61178 m
.72407 .61803 L
s
.86174 .61178 m
.86174 .61803 L
s
.99941 .61178 m
.99941 .61803 L
s
.125 Mabswid
.06325 .61428 m
.06325 .61803 L
s
.09078 .61428 m
.09078 .61803 L
s
.11831 .61428 m
.11831 .61803 L
s
.14585 .61428 m
.14585 .61803 L
s
.20092 .61428 m
.20092 .61803 L
s
.22845 .61428 m
.22845 .61803 L
s
.25599 .61428 m
.25599 .61803 L
s
.28352 .61428 m
.28352 .61803 L
s
.33859 .61428 m
.33859 .61803 L
s
.36612 .61428 m
.36612 .61803 L
s
.39366 .61428 m
.39366 .61803 L
s
.42119 .61428 m
.42119 .61803 L
s
.47626 .61428 m
.47626 .61803 L
s
.5038 .61428 m
.5038 .61803 L
s
.53133 .61428 m
.53133 .61803 L
s
.55886 .61428 m
.55886 .61803 L
s
.61393 .61428 m
.61393 .61803 L
s
.64147 .61428 m
.64147 .61803 L
s
.669 .61428 m
.669 .61803 L
s
.69654 .61428 m
.69654 .61803 L
s
.7516 .61428 m
.7516 .61803 L
s
.77914 .61428 m
.77914 .61803 L
s
.80667 .61428 m
.80667 .61803 L
s
.83421 .61428 m
.83421 .61803 L
s
.88928 .61428 m
.88928 .61803 L
s
.91681 .61428 m
.91681 .61803 L
s
.94434 .61428 m
.94434 .61803 L
s
.97188 .61428 m
.97188 .61803 L
s
.00818 .61428 m
.00818 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03438 m
1 .03438 L
s
.99375 .12375 m
1 .12375 L
s
.99375 .21312 m
1 .21312 L
s
.99375 .3025 m
1 .3025 L
s
.99375 .39187 m
1 .39187 L
s
.99375 .48124 m
1 .48124 L
s
.99375 .57061 m
1 .57061 L
s
.125 Mabswid
.99625 .05225 m
1 .05225 L
s
.99625 .07013 m
1 .07013 L
s
.99625 .088 m
1 .088 L
s
.99625 .10587 m
1 .10587 L
s
.99625 .14162 m
1 .14162 L
s
.99625 .1595 m
1 .1595 L
s
.99625 .17737 m
1 .17737 L
s
.99625 .19525 m
1 .19525 L
s
.99625 .231 m
1 .231 L
s
.99625 .24887 m
1 .24887 L
s
.99625 .26675 m
1 .26675 L
s
.99625 .28462 m
1 .28462 L
s
.99625 .32037 m
1 .32037 L
s
.99625 .33824 m
1 .33824 L
s
.99625 .35612 m
1 .35612 L
s
.99625 .37399 m
1 .37399 L
s
.99625 .40974 m
1 .40974 L
s
.99625 .42762 m
1 .42762 L
s
.99625 .44549 m
1 .44549 L
s
.99625 .46337 m
1 .46337 L
s
.99625 .49912 m
1 .49912 L
s
.99625 .51699 m
1 .51699 L
s
.99625 .53487 m
1 .53487 L
s
.99625 .55274 m
1 .55274 L
s
.99625 .0165 m
1 .0165 L
s
.99625 .58849 m
1 .58849 L
s
.99625 .60636 m
1 .60636 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5864 0 m
.5864 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.01 w
.07696 .01472 Mdot
.12588 .05937 Mdot
.17116 .1046 Mdot
.21328 .14993 Mdot
.25269 .19492 Mdot
.28974 .23918 Mdot
.32476 .28232 Mdot
.358 .32398 Mdot
.38972 .36381 Mdot
.42012 .40147 Mdot
.44937 .43667 Mdot
.47765 .46911 Mdot
.5051 .49853 Mdot
.53184 .52468 Mdot
.55801 .54736 Mdot
.58372 .56638 Mdot
.60906 .58159 Mdot
.63414 .59286 Mdot
.65906 .60011 Mdot
.6839 .60332 Mdot
.70876 .6025 Mdot
.73373 .59772 Mdot
.7589 .58914 Mdot
.78435 .57699 Mdot
.81017 .56159 Mdot
.83644 .54341 Mdot
.86323 .52307 Mdot
.89059 .50141 Mdot
.91857 .47959 Mdot
.94714 .45931 Mdot
.5 Mabswid
.02381 .01472 m
.03837 .01472 L
.05372 .01472 L
.06124 .01472 L
.06929 .01472 L
.07167 .01472 L
.07391 .01472 L
.07489 .01472 L
.07593 .01472 L
.07647 .01472 L
.07707 .01481 L
.07761 .01531 L
.07812 .01577 L
.08634 .02328 L
.11636 .05068 L
.14827 .08174 L
.17902 .11305 L
.20858 .14487 L
.24005 .18049 L
.27035 .21601 L
.30254 .25495 L
.33356 .29335 L
.3634 .33076 L
.39515 .37053 L
.42572 .40821 L
.45512 .44326 L
.48641 .4785 L
.51654 .50971 L
.54856 .53917 L
.57941 .56319 L
.60908 .5816 L
.62439 .58848 L
.64065 .59475 L
.64791 .59687 L
.65172 .59797 L
.65573 .59914 L
.65743 .59964 L
.65837 .59991 L
.65925 .60014 L
.65976 .6002 L
.6603 .60027 L
.66125 .6004 L
.66311 .60064 L
.66988 .60151 L
.67783 .60254 L
.67982 .60279 L
.68172 .60304 L
.68254 .60314 L
.68341 .60326 L
.68438 .6033 L
Mistroke
.68527 .60327 L
.68901 .60315 L
.69302 .60302 L
.69747 .60287 L
.70156 .60273 L
.70544 .60261 L
.7074 .60254 L
.70793 .60252 L
.70851 .6025 L
.70905 .60244 L
.70954 .60235 L
.71817 .6007 L
.72629 .59914 L
.72986 .59846 L
.73175 .5981 L
.73275 .59791 L
.73329 .59781 L
.73379 .5977 L
.73472 .59739 L
.73573 .59704 L
.7375 .59644 L
.74097 .59525 L
.7486 .59265 L
.76468 .58638 L
.79495 .57067 L
.82712 .54986 L
.85811 .52695 L
.88793 .50351 L
.91965 .47882 L
.9502 .45761 L
.97619 .44316 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[71]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00803oool3000000@0oooo0P00000G0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool3000001T0oooo0`00000H0?ooo`D000000`3oool00`000000oooo0?ooo`020?oo
o`<000005`3oool2000001T0oooo1@0000030?ooo`030000003oool0oooo0080oooo0`00000I0?oo
o`<000006P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`0000080?oo
o`008@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001H0oooo00<000000?oo
o`3oool01`3oool01@000000oooo0?ooo`3oool0000001L0oooo00D000000?ooo`3oool0oooo0000
000H0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`04
0000003oool0oooo000001T0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3o
ool0000001L0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`030000003oool0oooo00L0oooo
00D000000?ooo`3oool0oooo000000070?ooo`006@3oool5000000<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000>0?ooo`D00000103oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00l0oooo1@0000050?ooo`030000003oool0oooo00l0oooo1@0000030?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`00000J0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool04`3oool010000000oooo0?ooo`00000K0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000H
0?ooo`030000003oool0oooo00D0oooo1000000H0?ooo`@00000603oool01@000000oooo0?ooo`3o
ool0000000L0oooo1000000F0?ooo`040000003oool0oooo000001P0oooo00D000000?ooo`3oool0
oooo000000070?ooo`@00000603oool4000001`0oooo00<000000?ooo`3oool01@3oool4000000P0
oooo000P0?ooo`800000103oool010000000oooo0?ooo`00000D0?ooo`050000003oool0oooo0?oo
o`0000001`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool00000603o
ool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0I0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`090?ooo`00
8@3oool00`000000oooo0?ooo`030?ooo`8000005@3oool5000000L0oooo1@00000G0?ooo`D00000
603oool3000000P0oooo1@00000F0?ooo`8000006P3oool3000000P0oooo1@00000G0?ooo`D00000
5`3oool5000000L0oooo1@0000070?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`006P3ooooh000000h0oooo000J0?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo000J
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<
0?ooo`006P3oool00`000000oooo0?ooo`020?ooo`l00000O03oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo00l0oooo0`00001k0?ooo`03
0000003oool0oooo06<0oooo0P00000>0?ooo`006P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`002`3o
ool3000000@0oooo0P0000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000:0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo
000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000050?ooo`80
00005P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0680oooo0`00000>0?ooo`00
2P3oool4000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`00
2P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3o
ool0303oool000/0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo00`0oooo000<0?ooo`800000103oool2000000H0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
303oool001X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo06<0oooo0P00000>0?ooo`006P3oool00`000000oooo0?ooo`0K0?ooo`800000L03oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo
01/0oooo0P00001`0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo06<0oooo0P00000>0?ooo`006P3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`0<0?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?oo
o`006P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool0H`3oool2000000h0oooo000J0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo00`0oooo000J0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo
02H0oooo0P00001U0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0
oooo00<000000?ooo`3oool09P3oool2000006D0oooo00<000000?ooo`3oool0H`3oool2000000h0
oooo000J0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000<0?ooo`030000003oool0oooo00<0oooo0P00
00060?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo00`0oooo000<0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`003@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00`3oool2000002`0oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`1R0?ooo`<000003P3oool000d0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool000h0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000:
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo00`0oooo000:0?ooo`D000000`3oool2000000H0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303o
ool001X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0
oooo06<0oooo0P00000>0?ooo`006P3oool00`000000oooo0?ooo`0`0?ooo`<00000FP3oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo0340
oooo0P00001J0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo06<0oooo0P00000>0?ooo`006P3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<
0?ooo`006P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`00
6P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
H`3oool2000000h0oooo000J0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo00`0oooo000J0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0
oooo000J0?ooo`030000003oool0oooo03X0oooo0P00001A0?ooo`030000003oool0oooo06<0oooo
0P00000>0?ooo`006P3oool00`000000oooo0?ooo`0j0?ooo`<00000D03oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo00`0oooo000;0?ooo`<00000103oool2000000H0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0303oool000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool0303oool000X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000000D0oooo0P00000o0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0HP3oool3000000h0oooo000;0?ooo`<000000`3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000:0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000:0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
00`0oooo000;0?ooo`<00000103oool2000000H0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo06<0oooo
0P00000>0?ooo`006P3oool00`000000oooo0?ooo`130?ooo`800000B03oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo04<0oooo0P000018
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0303oool001X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo06<0oooo0P00000>0?ooo`006P3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0H`3oool2000000h0oooo000J0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo
000J0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo04`0oooo0P00000o
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?oo
o`3oool0C03oool2000003l0oooo00<000000?ooo`3oool0H`3oool2000000h0oooo000J0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo00`0oooo000;0?ooo`8000001@3oool2000000H0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
303oool000d0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool0303oool000h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`800000D@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0680oooo
0`00000>0?ooo`002`3oool400000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`0<0?ooo`002P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0I03oool00`000000oooo0?ooo`0<0?ooo`002P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`002`3oool3000000@0
oooo0P0000060?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo05@0oooo
0P00000g0?ooo`030000003oool0oooo06<0oooo0P00000>0?ooo`006P3oool00`000000oooo0?oo
o`1D0?ooo`800000=`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1S0?ooo`80
00003P3oool001X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303o
ool001X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo06<0
oooo0P00000>0?ooo`006P3oool00`000000oooo0?ooo`1L0?ooo`800000;`3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo05`0oooo0P00
000_0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo06<0oooo0P00000>0?ooo`006P3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`00
1@3oool3000000@0oooo0P0000040?ooo`8000001P3oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?ooo`001P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0I03oool00`000000oooo0?ooo`0<0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1R0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0<0?oo
o`001P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000001@3oool2000006<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1R
0?ooo`<000003P3oool000H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool000D0oooo0P000004
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`1T0?ooo`8000009`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo
00060?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`8000001P3oool00`000000oooo0?oo
o`1T0?ooo`8000009`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1S
0?ooo`8000003P3oool001X0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3o
ool0303oool001X0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06<0oooo0P00000>0?ooo`006P3oool0
0`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`1[0?ooo`800000803oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo06/0
oooo0P00000P0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0303oool001X0oooo
00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05d0oooo
0P0000050?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo06d0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`8000001P3oool2000000h0oooo000J
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05P0oooo0P00000:0?oo
o`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`1F0?ooo`800000303oool00`000000oooo0?ooo`0<0?ooo`00
6P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
E@3oool3000000/0oooo0P00000>0?ooo`006P3oool00`000000oooo0?ooo`1b0?ooo`8000006@3o
ool00`000000oooo0?ooo`1C0?ooo`8000003`3oool00`000000oooo0?ooo`0<0?ooo`001@3oool3
000000<0oooo0`0000040?ooo`8000001P3oool00`000000oooo0?ooo`1b0?ooo`8000006@3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool0
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`001P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0C`3oool2
000001<0oooo00<000000?ooo`3oool0303oool000H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo0P00001f0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0CP3oool300000140oooo0`00000>0?ooo`001P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00`0oooo00050?ooo`800000103oool20000
00@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0B`3oool2000001L0oooo00<000000?ooo`3oool0303oool0
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`8000001P3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo07T0
oooo0P00000B0?ooo`030000003oool0oooo04P0oooo0P00000I0?ooo`8000003P3oool001X0oooo
00<000000?ooo`3oool0N@3oool200000180oooo00<000000?ooo`3oool0A`3oool3000001X0oooo
00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0<0?ooo`006P3oool00`000000oooo0?ooo`1l0?ooo`8000003`3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?oo
o`3oool0OP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0703oool2000000h0oooo000J0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0303oool001X0oooo00<000000?ooo`3oool0O`3oool2000000`0oooo00<000000?ooo`3oool0
@@3oool200000240oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0O`3o
ool3000000/0oooo00<000000?ooo`3oool0@03oool300000240oooo00<000000?ooo`3oool0303o
ool001X0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`00
0000oooo0?ooo`230?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0R0?ooo`8000003P3oool001X0oooo00<000000?ooo`3oool0Q03oool2000000L0
oooo00<000000?ooo`3oool0?03oool2000002H0oooo00<000000?ooo`3oool0303oool001X0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03/0oooo
0P00000W0?ooo`030000003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo08H0oooo0P00
00050?ooo`030000003oool0oooo03X0oooo0`00000W0?ooo`030000003oool0oooo00`0oooo000J
0?ooo`030000003oool0oooo08H0oooo100000030?ooo`030000003oool0oooo03P0oooo0P00000Y
0?ooo`8000003P3oool001X0oooo00<000000?ooo`3oool0RP3oool010000000oooo0?ooo`00000i
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0303oool000D0oooo0`0000020?oo
o`D000000`3oool2000000H0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0000000f0?oo
o`<00000;@3oool00`000000oooo0?ooo`0<0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`2<
0?ooo`800000=@3oool3000002h0oooo00<000000?ooo`3oool0303oool000H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0S03oool400000380oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0<
0?ooo`001P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`800000SP3oool010000000oooo0?ooo`00000_0?ooo`800000<03o
ool3000000h0oooo00060?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0S@3oool010000000oooo
0?ooo`3oool2000002/0oooo0P00000d0?ooo`030000003oool0oooo00`0oooo00050?ooo`800000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo0`00000X0?ooo`<00000=03oool00`00
0000oooo0?ooo`0<0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`<00000103oool2000000H0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo00000000
0000903oool2000003L0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`070?ooo`8000007P3oool4000003P0oooo0P00000>0?ooo`006P3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00T0oooo0P00000J0?ooo`@00000>`3o
ool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo00T0oooo1P00000B0?ooo`@00000?`3oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo00l0oooo1@0000000`3oool00000000000040?oo
o`P00000@@3oool00`000000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo00l0oooo0P0000030?ooo`T00000A`3oool00`000000oooo0?ooo`0<0?ooo`00
6P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo06<0oooo0P00000>0?ooo`006P3o
ool00`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0<0?ooo`006P3ooooh000000h0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo00380?ooo`<00000E@3oool00<T0oooo00<000000?ooo`3oool0E03oool0
05d0oooo00<000000?ooo`0000000`3oool4000000<0oooo00<000000?ooo`3oool00P3oool30000
0080oooo0`0000030?ooo`<00000103oool300000080oooo0`0000000`3oool00000000000020?oo
o`800000203oool5000000050?ooo`00000000000000003oool00P0000020?ooo`8000000`3oool3
00000080oooo0`0000000`3oool000000000000400000080oooo1@0000030?ooo`800000103oool0
0`000000oooo0?ooo`1C0?ooo`00G@3oool00`000000oooo000000020?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00@000000?ooo`3oool0
00001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`1C0?ooo`00G@3oool00`000000oooo000000030?ooo`<000000`3oool00`00
0000oooo000000020?ooo`D000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool500000080oooo00@000000?ooo`3oool000000P3oool3000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000005@0
oooo001L0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000<0oooo
0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003o
ool0oooo0000003oool000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`000000E03oool005`0oooo00D000000?ooo`000000oooo000000020?ooo`80
00000`3oool2000000030?ooo`00000000000080oooo0`0000030?ooo`030000003oool0oooo0080
oooo0P0000000`3oool00000000000020?ooo`<000000P3oool400000080oooo1000000:0?ooo`04
0000003oool0oooo0?ooo`@000000P3oool4000000<0oooo0`0000020?ooo`@000000`3oool40000
00040?ooo`0000000000000000<0oooo100000020?ooo`80000000<0oooo000000000000D`3oool0
05`0oooo00D000000?ooo`000000oooo0000000D0?ooo`040000003oool0oooo000001@0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0FP3oool005`0oooo1P00000B0?ooo`D00000503oool00`000000oooo0?ooo`08
0?ooo`D00000203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0FP3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.5612, 50.6805, 0.073469, \
0.452692}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.586398 0.0550687 0.309017 3.94059e-05 [
[.03571 -0.0125 -9 -9 ]
[.03571 -0.0125 9 0 ]
[.17338 -0.0125 -12 -9 ]
[.17338 -0.0125 12 0 ]
[.31105 -0.0125 -6 -9 ]
[.31105 -0.0125 6 0 ]
[.44873 -0.0125 -12 -9 ]
[.44873 -0.0125 12 0 ]
[.5864 -0.0125 -3 -9 ]
[.5864 -0.0125 3 0 ]
[.72407 -0.0125 -9 -9 ]
[.72407 -0.0125 9 0 ]
[.86174 -0.0125 -3 -9 ]
[.86174 -0.0125 3 0 ]
[.99941 -0.0125 -9 -9 ]
[.99941 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07258 -30 -4.5 ]
[-0.0125 .07258 0 4.5 ]
[-0.0125 .15139 -30 -4.5 ]
[-0.0125 .15139 0 4.5 ]
[-0.0125 .23021 -30 -4.5 ]
[-0.0125 .23021 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38783 -24 -4.5 ]
[-0.0125 .38783 0 4.5 ]
[-0.0125 .46664 -24 -4.5 ]
[-0.0125 .46664 0 4.5 ]
[-0.0125 .54545 -24 -4.5 ]
[-0.0125 .54545 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03571 0 m
.03571 .00625 L
s
[(-10)] .03571 -0.0125 0 1 Mshowa
.17338 0 m
.17338 .00625 L
s
[(-7.5)] .17338 -0.0125 0 1 Mshowa
.31105 0 m
.31105 .00625 L
s
[(-5)] .31105 -0.0125 0 1 Mshowa
.44873 0 m
.44873 .00625 L
s
[(-2.5)] .44873 -0.0125 0 1 Mshowa
.5864 0 m
.5864 .00625 L
s
[(0)] .5864 -0.0125 0 1 Mshowa
.72407 0 m
.72407 .00625 L
s
[(2.5)] .72407 -0.0125 0 1 Mshowa
.86174 0 m
.86174 .00625 L
s
[(5)] .86174 -0.0125 0 1 Mshowa
.99941 0 m
.99941 .00625 L
s
[(7.5)] .99941 -0.0125 0 1 Mshowa
.125 Mabswid
.06325 0 m
.06325 .00375 L
s
.09078 0 m
.09078 .00375 L
s
.11831 0 m
.11831 .00375 L
s
.14585 0 m
.14585 .00375 L
s
.20092 0 m
.20092 .00375 L
s
.22845 0 m
.22845 .00375 L
s
.25599 0 m
.25599 .00375 L
s
.28352 0 m
.28352 .00375 L
s
.33859 0 m
.33859 .00375 L
s
.36612 0 m
.36612 .00375 L
s
.39366 0 m
.39366 .00375 L
s
.42119 0 m
.42119 .00375 L
s
.47626 0 m
.47626 .00375 L
s
.5038 0 m
.5038 .00375 L
s
.53133 0 m
.53133 .00375 L
s
.55886 0 m
.55886 .00375 L
s
.61393 0 m
.61393 .00375 L
s
.64147 0 m
.64147 .00375 L
s
.669 0 m
.669 .00375 L
s
.69654 0 m
.69654 .00375 L
s
.7516 0 m
.7516 .00375 L
s
.77914 0 m
.77914 .00375 L
s
.80667 0 m
.80667 .00375 L
s
.83421 0 m
.83421 .00375 L
s
.88928 0 m
.88928 .00375 L
s
.91681 0 m
.91681 .00375 L
s
.94434 0 m
.94434 .00375 L
s
.97188 0 m
.97188 .00375 L
s
.00818 0 m
.00818 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07258 m
.00625 .07258 L
s
[(-6000)] -0.0125 .07258 1 0 Mshowa
0 .15139 m
.00625 .15139 L
s
[(-4000)] -0.0125 .15139 1 0 Mshowa
0 .23021 m
.00625 .23021 L
s
[(-2000)] -0.0125 .23021 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .38783 m
.00625 .38783 L
s
[(2000)] -0.0125 .38783 1 0 Mshowa
0 .46664 m
.00625 .46664 L
s
[(4000)] -0.0125 .46664 1 0 Mshowa
0 .54545 m
.00625 .54545 L
s
[(6000)] -0.0125 .54545 1 0 Mshowa
.125 Mabswid
0 .09228 m
.00375 .09228 L
s
0 .11199 m
.00375 .11199 L
s
0 .13169 m
.00375 .13169 L
s
0 .1711 m
.00375 .1711 L
s
0 .1908 m
.00375 .1908 L
s
0 .2105 m
.00375 .2105 L
s
0 .24991 m
.00375 .24991 L
s
0 .26961 m
.00375 .26961 L
s
0 .28931 m
.00375 .28931 L
s
0 .32872 m
.00375 .32872 L
s
0 .34842 m
.00375 .34842 L
s
0 .36813 m
.00375 .36813 L
s
0 .40753 m
.00375 .40753 L
s
0 .42723 m
.00375 .42723 L
s
0 .44694 m
.00375 .44694 L
s
0 .48634 m
.00375 .48634 L
s
0 .50605 m
.00375 .50605 L
s
0 .52575 m
.00375 .52575 L
s
0 .05288 m
.00375 .05288 L
s
0 .03318 m
.00375 .03318 L
s
0 .01347 m
.00375 .01347 L
s
0 .56516 m
.00375 .56516 L
s
0 .58486 m
.00375 .58486 L
s
0 .60456 m
.00375 .60456 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.03571 .61178 m
.03571 .61803 L
s
.17338 .61178 m
.17338 .61803 L
s
.31105 .61178 m
.31105 .61803 L
s
.44873 .61178 m
.44873 .61803 L
s
.5864 .61178 m
.5864 .61803 L
s
.72407 .61178 m
.72407 .61803 L
s
.86174 .61178 m
.86174 .61803 L
s
.99941 .61178 m
.99941 .61803 L
s
.125 Mabswid
.06325 .61428 m
.06325 .61803 L
s
.09078 .61428 m
.09078 .61803 L
s
.11831 .61428 m
.11831 .61803 L
s
.14585 .61428 m
.14585 .61803 L
s
.20092 .61428 m
.20092 .61803 L
s
.22845 .61428 m
.22845 .61803 L
s
.25599 .61428 m
.25599 .61803 L
s
.28352 .61428 m
.28352 .61803 L
s
.33859 .61428 m
.33859 .61803 L
s
.36612 .61428 m
.36612 .61803 L
s
.39366 .61428 m
.39366 .61803 L
s
.42119 .61428 m
.42119 .61803 L
s
.47626 .61428 m
.47626 .61803 L
s
.5038 .61428 m
.5038 .61803 L
s
.53133 .61428 m
.53133 .61803 L
s
.55886 .61428 m
.55886 .61803 L
s
.61393 .61428 m
.61393 .61803 L
s
.64147 .61428 m
.64147 .61803 L
s
.669 .61428 m
.669 .61803 L
s
.69654 .61428 m
.69654 .61803 L
s
.7516 .61428 m
.7516 .61803 L
s
.77914 .61428 m
.77914 .61803 L
s
.80667 .61428 m
.80667 .61803 L
s
.83421 .61428 m
.83421 .61803 L
s
.88928 .61428 m
.88928 .61803 L
s
.91681 .61428 m
.91681 .61803 L
s
.94434 .61428 m
.94434 .61803 L
s
.97188 .61428 m
.97188 .61803 L
s
.00818 .61428 m
.00818 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07258 m
1 .07258 L
s
.99375 .15139 m
1 .15139 L
s
.99375 .23021 m
1 .23021 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38783 m
1 .38783 L
s
.99375 .46664 m
1 .46664 L
s
.99375 .54545 m
1 .54545 L
s
.125 Mabswid
.99625 .09228 m
1 .09228 L
s
.99625 .11199 m
1 .11199 L
s
.99625 .13169 m
1 .13169 L
s
.99625 .1711 m
1 .1711 L
s
.99625 .1908 m
1 .1908 L
s
.99625 .2105 m
1 .2105 L
s
.99625 .24991 m
1 .24991 L
s
.99625 .26961 m
1 .26961 L
s
.99625 .28931 m
1 .28931 L
s
.99625 .32872 m
1 .32872 L
s
.99625 .34842 m
1 .34842 L
s
.99625 .36813 m
1 .36813 L
s
.99625 .40753 m
1 .40753 L
s
.99625 .42723 m
1 .42723 L
s
.99625 .44694 m
1 .44694 L
s
.99625 .48634 m
1 .48634 L
s
.99625 .50605 m
1 .50605 L
s
.99625 .52575 m
1 .52575 L
s
.99625 .05288 m
1 .05288 L
s
.99625 .03318 m
1 .03318 L
s
.99625 .01347 m
1 .01347 L
s
.99625 .56516 m
1 .56516 L
s
.99625 .58486 m
1 .58486 L
s
.99625 .60456 m
1 .60456 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5864 0 m
.5864 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.94714 .59626 Mdot
.91857 .58841 Mdot
.89059 .5799 Mdot
.86323 .57083 Mdot
.83644 .56125 Mdot
.81017 .5512 Mdot
.78435 .54072 Mdot
.7589 .52981 Mdot
.73373 .51846 Mdot
.70876 .50667 Mdot
.6839 .49441 Mdot
.65906 .48166 Mdot
.63414 .46837 Mdot
.60906 .45449 Mdot
.58372 .43998 Mdot
.55801 .42477 Mdot
.53184 .40878 Mdot
.5051 .39193 Mdot
.47765 .37412 Mdot
.44937 .35524 Mdot
.42012 .33514 Mdot
.38972 .31369 Mdot
.358 .29068 Mdot
.32476 .26592 Mdot
.28974 .23915 Mdot
.25269 .21007 Mdot
.21328 .17833 Mdot
.17116 .14349 Mdot
.12588 .10505 Mdot
.07696 .06237 Mdot
.5 Mabswid
.02381 .01472 m
.05372 .04153 L
.08634 .07055 L
.11698 .09728 L
.14644 .1225 L
.1778 .14898 L
.20799 .17395 L
.24008 .19991 L
.27099 .22443 L
.30073 .24755 L
.33237 .27159 L
.36283 .29419 L
.39213 .31538 L
.42332 .33734 L
.45333 .35788 L
.48525 .37905 L
.51599 .39879 L
.54556 .41716 L
.57703 .43602 L
.60732 .4535 L
.63951 .47123 L
.67053 .48755 L
.70038 .50254 L
.73212 .5177 L
.76269 .53144 L
.79209 .54386 L
.82339 .55626 L
.85351 .56735 L
.88553 .57822 L
.91638 .58774 L
.94605 .59596 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[71]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`009`3oool3000000@0oooo0P00000G0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool3000001T0oooo0`00000H0?ooo`D000000`3oool00`000000oooo0?ooo`020?oo
o`<000005P3oool2000001P0oooo1@0000030?ooo`030000003oool0oooo0080oooo0`00000I0?oo
o`<000006P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`0000030?oo
o`00:03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001H0oooo00<000000?oo
o`3oool01`3oool01@000000oooo0?ooo`3oool0000001L0oooo00D000000?ooo`3oool0oooo0000
000H0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`04
0000003oool0oooo000001P0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3o
ool0000001L0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`030000003oool0oooo00L0oooo
00D000000?ooo`3oool0oooo000000020?ooo`00803oool5000000<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000>0?ooo`D00000103oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00l0oooo1@0000050?ooo`030000003oool0oooo00l0oooo1@0000030?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`00000I0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00X0oooo0@0000010?ooo`40oooo000X0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0180oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool1
0?ooo`00:03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001P0oooo00<00000
0?ooo`3oool01@3oool4000001P0oooo1000000H0?ooo`050000003oool0oooo0?ooo`0000001`3o
ool4000001D0oooo00@000000?ooo`3oool000005`3oool01@000000oooo0?ooo`3oool0000000L0
oooo1000000H0?ooo`@00000703oool00`000000oooo0?ooo`050?ooo`@000000`3oool002L0oooo
0P0000040?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool01@000000oooo0?ooo`3oool0
000000L0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00000G0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo
00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00@0oooo000X0?ooo`030000
003oool0oooo00<0oooo0P00000E0?ooo`D000001`3oool5000001L0oooo1@00000H0?ooo`<00000
203oool5000001D0oooo0P00000I0?ooo`<00000203oool5000001L0oooo1@00000G0?ooo`D00000
1`3oool500000080oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo000Q0?ooooH000002@3oool00240oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00240oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo000Q0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`070?oo
o`008@3oool00`000000oooo0?ooo`020?ooo`800000R03oool00`000000oooo0?ooo`1R0?ooo`80
00002@3oool00240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`250?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`240?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool01`3o
ool00240oooo00<000000?ooo`3oool01P3oool2000008@0oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`070?ooo`008@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0840oooo00<000000?ooo`3oool0HP3oool2000000T0oooo000Q0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00L0
oooo000Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo00L0oooo000Q0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00L0oooo000Q
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo00L0oooo000Q0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`1R0?ooo`8000002@3oool00240oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool01`3oool00240oooo00<000000?ooo`3oool03`3oool2000007/0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`070?ooo`001`3oool3000000@0oooo0P0000040?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool03`3oool2000007/0oooo00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`070?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
06<0oooo00<000000?ooo`3oool01`3oool000D0000000<0oooo0000003oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`8000004`3oool2000007P0oooo00<000000?ooo`3oool0H@3o
ool3000000T0oooo00060?ooo`@000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`070?ooo`00
1P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00L0oooo00070?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool000P0oooo0P00
00040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00L0oooo000Q
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1R
0?ooo`8000002@3oool00240oooo00<000000?ooo`3oool06@3oool200000740oooo00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`070?ooo`008@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo06h0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`070?ooo`00
8@3oool00`000000oooo0?ooo`0K0?ooo`800000K`3oool00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo00L0oooo000Q0?ooo`030000003oool0oooo01/0oooo0`00001^0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0680oooo0P0000090?ooo`008@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`070?ooo`008@3oool00`000000oooo0?ooo`0P0?ooo`800000JP3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo00L0oooo000Q0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00L0oooo
000Q0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo00L0oooo000Q0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`1R0?ooo`8000002@3oool00240oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool01`3oool000P0oooo0`0000030?ooo`800000103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo02H0oooo0P00001T0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02H0oooo0P00001T0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool0
00D0000000<0oooo0000000000000`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000:@3oool200000680oooo
00<000000?ooo`3oool0H@3oool3000000T0oooo00060?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo06<0oooo00<000000?ooo`3oool01`3oool000L0oooo00<000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`070?ooo`00203oool2000000<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0;03oool2000005h0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`070?oo
o`002@3oool00`000000oooo0?ooo`020?ooo`800000103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo00L0oooo000Q0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`1R0?ooo`8000002@3oool00240oooo00<000000?ooo`3oool0<03o
ool2000005X0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`070?ooo`008@3oool0
0`000000oooo0?ooo`0`0?ooo`<00000F@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo00L0oooo000Q0?ooo`030000003oool0oooo0300oooo0P0000000`3oool000000?ooo`1G0?oo
o`030000003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool01`3oool00240oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0680oooo0P0000090?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`070?ooo`008@3oool0
0`000000oooo0?ooo`0g0?ooo`800000D`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo00L0oooo000Q0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0D03oool00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo00L0oooo000Q0?ooo`030000003oool0oooo03X0
oooo0P00001@0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool00240oooo
00<000000?ooo`3oool0>P3oool3000004l0oooo00<000000?ooo`3oool0HP3oool2000000T0oooo
000Q0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo00L0oooo00060?ooo`D000000`3oool2000000@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`070?ooo`001`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo03l0oooo0P00001;0?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool01`3oool000D000000`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool2000004<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1Q0?ooo`<00000
2@3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo00L0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`130?ooo`800000A`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00L0
oooo00070?ooo`<00000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`130?ooo`<00000AP3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00L0oooo
000Q0?ooo`030000003oool0oooo04H0oooo0P0000140?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0680oooo0P0000090?ooo`008@3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`070?oo
o`008@3oool00`000000oooo0?ooo`1:0?ooo`800000@03oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo00L0oooo000Q0?ooo`030000003oool0oooo04/0oooo0P00000o0?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0B`3o
ool3000003h0oooo00<000000?ooo`3oool0HP3oool2000000T0oooo000Q0?ooo`030000003oool0
oooo04h0oooo0P00000l0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool0
0240oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
06<0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0D@3oool2000003T0
oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`070?ooo`008@3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`070?ooo`008@3oool00`000000oooo0?ooo`1D0?ooo`800000=P3oool00`000000oooo0?oo
o`1R0?ooo`8000002@3oool00240oooo00<000000?ooo`3oool0E03oool3000003D0oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`070?ooo`008@3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`070?oo
o`006P3oool2000000D0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool001T0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1I0?ooo`800000<@3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo00L0oooo000I0?ooo`040000003oool0oooo000000@0oooomP0000090?ooo`00
6@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05/0oooo0P00000_0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool001T0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1K0?ooo`@00000;@3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo00L0oooo000I0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool01`3oool001X0oooo0P0000050?ooo`030000003oool0oooo0600oooo0P00000Z0?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0680oooo0P0000090?ooo`008@3oool0
0`000000oooo0?ooo`1S0?ooo`8000009`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo00L0oooo000Q0?ooo`030000003oool0oooo06<0oooo0`00000V0?ooo`030000003oool0oooo
06<0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool00240oooo
00<000000?ooo`3oool0I`3oool2000002<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`070?ooo`008@3oool00`000000oooo0?ooo`1Y0?ooo`8000008@3oool00`000000oooo0?oo
o`1R0?ooo`8000002@3oool00240oooo00<000000?ooo`3oool0JP3oool200000200oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`070?ooo`008@3oool00`000000oooo0?ooo`1Z0?oo
o`@000007P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00L0oooo000Q0?ooo`03
0000003oool0oooo06h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo00L0oooo000Q0?ooo`030000003oool0oooo06l0oooo0P00000K0?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0680oooo0P0000090?ooo`008@3oool0
0`000000oooo0?ooo`1a0?ooo`8000006@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo00L0oooo00060?ooo`D000000`3oool2000000@0oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`1a0?ooo`@000005`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
00L0oooo00070?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
1`3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool2000007L0oooo0P00000D0?oo
o`030000003oool0oooo0640oooo0`0000090?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0N03oool200000180oooo00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`070?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0N03oool300000140oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`070?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0N`3oool2000000l0oooo00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`070?ooo`001`3oool3000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0OP3oool2000000`0oooo00<00000
0?ooo`3oool0HP3oool2000000T0oooo000Q0?ooo`030000003oool0oooo07h0oooo0`00000;0?oo
o`030000003oool0oooo06<0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool01`3oool00240oooo00<000000?ooo`3oool0PP3oool2000000P0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`070?ooo`008@3oool00`000000oooo0?ooo`240?ooo`<000001@3o
ool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00L0oooo000Q0?ooo`030000003oool0
oooo08D0oooo0`0000040?ooo`030000003oool0oooo0680oooo0P0000090?ooo`008@3oool00`00
0000oooo0?ooo`280?ooo`8000000P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
00L0oooo000Q0?ooo`030000003oool0oooo08X0oooo0`00001U0?ooo`030000003oool0oooo00L0
oooo000Q0?ooo`030000003oool0oooo08/0oooo0`00001T0?ooo`030000003oool0oooo00L0oooo
000Q0?ooo`030000003oool0oooo08/0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003o
ool0oooo00L0oooo000Q0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool00P00001P
0?ooo`8000002@3oool00240oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`020?oo
o`800000G`3oool00`000000oooo0?ooo`070?ooo`00203oool3000000<0oooo0P0000040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`020?ooo`<0
0000GP3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`050?ooo`800000G03oool0
0`000000oooo0?ooo`070?ooo`001P3oool500000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`070?ooo`800000FP3oool00`000000oooo0?ooo`070?ooo`001P3o
ool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`800000S@3oool00`000000oooo0?ooo`08
0?ooo`800000E`3oool3000000T0oooo00070?ooo`030000003oool0000000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`080?ooo`@00000E`3oool00`000000oooo
0?ooo`070?ooo`00203oool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`0<0?ooo`800000E@3oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000
oooo0?ooo`020?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool03P3oool2000005<0oooo00<000000?ooo`3oool01`3oool00240oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0>0?ooo`@00000D03oool2000000T0oooo
000Q0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool04P3oool2000004l0oooo00<0
00000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0D
0?ooo`<00000C03oool00`000000oooo0?ooo`070?ooo`008@3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo01@0oooo0P0000000`3oool000000000001:0?ooo`030000003oool0oooo
00L0oooo000Q0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool06@3oool2000004P0
oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`0K0?ooo`800000A@3oool2000000T0oooo000Q0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool06`3oool4000004@0oooo00<000000?ooo`3oool01`3oool00240oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`0O0?ooo`800000@P3oool00`000000oooo0?ooo`07
0?ooo`008@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0240oooo0P0000100?oo
o`030000003oool0oooo00L0oooo000Q0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool08@3oool4000003h0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03X0oooo0P0000090?ooo`008@3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02H0oooo0`00000j0?ooo`030000003o
ool0oooo00L0oooo00070?ooo`<00000103oool2000000@0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02L0oooo0`00000i0?ooo`030000003oool0
oooo00L0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo02X0oooo0`00000f0?ooo`030000003oool0oooo00L0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo02d0oooo0`00000c0?ooo`030000003oool0oooo00L0oooo0006
0?ooo`@000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool2000008d0oooo00<000000?ooo`3oool0;@3oool200000003
0?ooo`000000000002l0oooo0`0000090?ooo`001P3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0<P3oool3000002h0oooo00<00000
0?ooo`3oool01`3oool000L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo03<0oooo1000000/0?ooo`030000003oool0oooo00L0oooo
00080?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo03L0oooo0`00000Y0?ooo`030000003oool0oooo00L0oooo000Q
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0>P3oool4000002D0oooo00<00000
0?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0j0?oo
o`8000000P3oool300000240oooo0P0000090?ooo`008@3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo0400oooo1000000O0?ooo`030000003oool0oooo00L0oooo000Q0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0@03oool200000080oooo0`00000L0?ooo`030000
003oool0oooo00L0oooo000Q0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0A`3o
ool3000001T0oooo00<000000?ooo`3oool01`3oool00240oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`170?ooo`80000000@0oooo00000000000000005P3oool00`000000oooo0?oo
o`070?ooo`008@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo04d0oooo1000000A
0?ooo`8000002@3oool00240oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`1>0?oo
o`80000000@0oooo00000000000000003`3oool00`000000oooo0?ooo`070?ooo`008@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo05@0oooo1000000;0?ooo`030000003oool0oooo
00L0oooo000Q0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0E@3oool200000003
0?ooo`0000000000008000001`3oool00`000000oooo0?ooo`070?ooo`008@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo05`0oooo0P0000040?ooo`8000002@3oool00240oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00L0oooo000Q
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`07
0?ooo`008@3oool00`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`008@3oooof000000T0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo000b0?ooo`<00000RP3oool00`000000oooo0?ooo`0[0?oo
o`<000005@3oool00`000000oooo0?ooo`0H0?ooo`00<`3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0G0?ooo`00
;@3oool3000000<0oooo0`0000040?ooo`8000000P3oool500000080oooo0`0000030?ooo`@00000
00<0oooo0000000000000`0000070?ooo`<00000103oool4000000<0oooo0P0000020?ooo`H00000
1P3oool400000080oooo1@0000000`3oool0000000000003000000030?ooo`000000000000<00000
0P3oool300000080oooo0`0000040?ooo`<000000P3oool3000000040?ooo`00000000000?ooo`<0
00000`3oool3000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`@0
00000`3oool00`000000oooo0?ooo`020?ooo`<000000P3oool500000080oooo0`0000020?ooo`<0
000000@0oooo000000000000oooo100000030?ooo`8000000P3oool:000000D0oooo00<000000?oo
o`3oool05P3oool002`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`060000003oool0oooo0000003o
ool000000`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000001`3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool002`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000000H0oooo0`0000040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000oooo0?oo
o`020?ooo`D000000P3oool01P000000oooo0?ooo`000000oooo000000D0oooo1@0000080?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`000000oooo000000020?ooo`<000000`3oool00`00
0000oooo000000020?ooo`D000000`3oool010000000oooo0?ooo`3oool500000080oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3o
ool000000P3oool3000000D0oooo00<000000?ooo`3oool05P3oool002`0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo0`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`060000003o
ool0oooo0000003oool00000203oool00`000000oooo0?ooo`0F0?ooo`00;03oool01P000000oooo
0?ooo`3oool000000?ooo`@000000P3oool400000080oooo0`0000040?ooo`<000000`3oool20000
00D0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000020?ooo`8000000`3oool4
000000<0oooo0`0000090?ooo`050000003oool0oooo0000003oool00`0000040?ooo`@000000P3o
ool400000080oooo0`0000020?ooo`80000000<0oooo0000000000000P3oool300000080oooo1000
00030?ooo`<000000`3oool3000000T0oooo00<000000?ooo`3oool00P3oool6000000030?ooo`00
0000000000<0oooo0P0000000`3oool00000000000020?ooo`<00000103oool00`000000oooo0?oo
o`020?ooo`<000000P3oool4000000<0oooo2@0000030?ooo`<000000`3oool4000000@0oooo00<0
00000?ooo`3oool05P3oool002`0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01L0oooo000]0?ooo`<000002@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00d0oooo0`0000090?ooo`@000002@3oool00`000000oooo0?ooo`020?ooo`800000
2P3oool4000000@0oooo00<000000?ooo`3oool0103oool2000000@0oooo0P00000^0?ooo`030000
003oool0oooo01P0oooo0`00000F0?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`030000
003oool0oooo01P0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.0984, -9160.64, \
0.0740951, 103.546}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["wave1 = FindWaveFronts[sys1];", "Input",
  CellLabel->"In[72]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.486878 0.0605726 -56.6979 0.106959 [
[.03258 -0.0125 -12 -9 ]
[.03258 -0.0125 12 0 ]
[.18401 -0.0125 -6 -9 ]
[.18401 -0.0125 6 0 ]
[.33545 -0.0125 -12 -9 ]
[.33545 -0.0125 12 0 ]
[.48688 -0.0125 -3 -9 ]
[.48688 -0.0125 3 0 ]
[.63831 -0.0125 -9 -9 ]
[.63831 -0.0125 9 0 ]
[.78974 -0.0125 -3 -9 ]
[.78974 -0.0125 3 0 ]
[.94117 -0.0125 -9 -9 ]
[.94117 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09737 -18 -4.5 ]
[-0.0125 .09737 0 4.5 ]
[-0.0125 .20433 -18 -4.5 ]
[-0.0125 .20433 0 4.5 ]
[-0.0125 .31129 -18 -4.5 ]
[-0.0125 .31129 0 4.5 ]
[-0.0125 .41825 -18 -4.5 ]
[-0.0125 .41825 0 4.5 ]
[-0.0125 .52521 -18 -4.5 ]
[-0.0125 .52521 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03258 0 m
.03258 .00625 L
s
[(-7.5)] .03258 -0.0125 0 1 Mshowa
.18401 0 m
.18401 .00625 L
s
[(-5)] .18401 -0.0125 0 1 Mshowa
.33545 0 m
.33545 .00625 L
s
[(-2.5)] .33545 -0.0125 0 1 Mshowa
.48688 0 m
.48688 .00625 L
s
[(0)] .48688 -0.0125 0 1 Mshowa
.63831 0 m
.63831 .00625 L
s
[(2.5)] .63831 -0.0125 0 1 Mshowa
.78974 0 m
.78974 .00625 L
s
[(5)] .78974 -0.0125 0 1 Mshowa
.94117 0 m
.94117 .00625 L
s
[(7.5)] .94117 -0.0125 0 1 Mshowa
.125 Mabswid
.06287 0 m
.06287 .00375 L
s
.09316 0 m
.09316 .00375 L
s
.12344 0 m
.12344 .00375 L
s
.15373 0 m
.15373 .00375 L
s
.2143 0 m
.2143 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.27487 0 m
.27487 .00375 L
s
.30516 0 m
.30516 .00375 L
s
.36573 0 m
.36573 .00375 L
s
.39602 0 m
.39602 .00375 L
s
.4263 0 m
.4263 .00375 L
s
.45659 0 m
.45659 .00375 L
s
.51716 0 m
.51716 .00375 L
s
.54745 0 m
.54745 .00375 L
s
.57774 0 m
.57774 .00375 L
s
.60802 0 m
.60802 .00375 L
s
.6686 0 m
.6686 .00375 L
s
.69888 0 m
.69888 .00375 L
s
.72917 0 m
.72917 .00375 L
s
.75945 0 m
.75945 .00375 L
s
.82003 0 m
.82003 .00375 L
s
.85031 0 m
.85031 .00375 L
s
.8806 0 m
.8806 .00375 L
s
.91089 0 m
.91089 .00375 L
s
.0023 0 m
.0023 .00375 L
s
.97146 0 m
.97146 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09737 m
.00625 .09737 L
s
[(531)] -0.0125 .09737 1 0 Mshowa
0 .20433 m
.00625 .20433 L
s
[(532)] -0.0125 .20433 1 0 Mshowa
0 .31129 m
.00625 .31129 L
s
[(533)] -0.0125 .31129 1 0 Mshowa
0 .41825 m
.00625 .41825 L
s
[(534)] -0.0125 .41825 1 0 Mshowa
0 .52521 m
.00625 .52521 L
s
[(535)] -0.0125 .52521 1 0 Mshowa
.125 Mabswid
0 .11876 m
.00375 .11876 L
s
0 .14015 m
.00375 .14015 L
s
0 .16155 m
.00375 .16155 L
s
0 .18294 m
.00375 .18294 L
s
0 .22572 m
.00375 .22572 L
s
0 .24711 m
.00375 .24711 L
s
0 .26851 m
.00375 .26851 L
s
0 .2899 m
.00375 .2899 L
s
0 .33268 m
.00375 .33268 L
s
0 .35407 m
.00375 .35407 L
s
0 .37546 m
.00375 .37546 L
s
0 .39686 m
.00375 .39686 L
s
0 .43964 m
.00375 .43964 L
s
0 .46103 m
.00375 .46103 L
s
0 .48242 m
.00375 .48242 L
s
0 .50382 m
.00375 .50382 L
s
0 .07598 m
.00375 .07598 L
s
0 .05459 m
.00375 .05459 L
s
0 .0332 m
.00375 .0332 L
s
0 .0118 m
.00375 .0118 L
s
0 .5466 m
.00375 .5466 L
s
0 .56799 m
.00375 .56799 L
s
0 .58938 m
.00375 .58938 L
s
0 .61077 m
.00375 .61077 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.03258 .61178 m
.03258 .61803 L
s
.18401 .61178 m
.18401 .61803 L
s
.33545 .61178 m
.33545 .61803 L
s
.48688 .61178 m
.48688 .61803 L
s
.63831 .61178 m
.63831 .61803 L
s
.78974 .61178 m
.78974 .61803 L
s
.94117 .61178 m
.94117 .61803 L
s
.125 Mabswid
.06287 .61428 m
.06287 .61803 L
s
.09316 .61428 m
.09316 .61803 L
s
.12344 .61428 m
.12344 .61803 L
s
.15373 .61428 m
.15373 .61803 L
s
.2143 .61428 m
.2143 .61803 L
s
.24459 .61428 m
.24459 .61803 L
s
.27487 .61428 m
.27487 .61803 L
s
.30516 .61428 m
.30516 .61803 L
s
.36573 .61428 m
.36573 .61803 L
s
.39602 .61428 m
.39602 .61803 L
s
.4263 .61428 m
.4263 .61803 L
s
.45659 .61428 m
.45659 .61803 L
s
.51716 .61428 m
.51716 .61803 L
s
.54745 .61428 m
.54745 .61803 L
s
.57774 .61428 m
.57774 .61803 L
s
.60802 .61428 m
.60802 .61803 L
s
.6686 .61428 m
.6686 .61803 L
s
.69888 .61428 m
.69888 .61803 L
s
.72917 .61428 m
.72917 .61803 L
s
.75945 .61428 m
.75945 .61803 L
s
.82003 .61428 m
.82003 .61803 L
s
.85031 .61428 m
.85031 .61803 L
s
.8806 .61428 m
.8806 .61803 L
s
.91089 .61428 m
.91089 .61803 L
s
.0023 .61428 m
.0023 .61803 L
s
.97146 .61428 m
.97146 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09737 m
1 .09737 L
s
.99375 .20433 m
1 .20433 L
s
.99375 .31129 m
1 .31129 L
s
.99375 .41825 m
1 .41825 L
s
.99375 .52521 m
1 .52521 L
s
.125 Mabswid
.99625 .11876 m
1 .11876 L
s
.99625 .14015 m
1 .14015 L
s
.99625 .16155 m
1 .16155 L
s
.99625 .18294 m
1 .18294 L
s
.99625 .22572 m
1 .22572 L
s
.99625 .24711 m
1 .24711 L
s
.99625 .26851 m
1 .26851 L
s
.99625 .2899 m
1 .2899 L
s
.99625 .33268 m
1 .33268 L
s
.99625 .35407 m
1 .35407 L
s
.99625 .37546 m
1 .37546 L
s
.99625 .39686 m
1 .39686 L
s
.99625 .43964 m
1 .43964 L
s
.99625 .46103 m
1 .46103 L
s
.99625 .48242 m
1 .48242 L
s
.99625 .50382 m
1 .50382 L
s
.99625 .07598 m
1 .07598 L
s
.99625 .05459 m
1 .05459 L
s
.99625 .0332 m
1 .0332 L
s
.99625 .0118 m
1 .0118 L
s
.99625 .5466 m
1 .5466 L
s
.99625 .56799 m
1 .56799 L
s
.99625 .58938 m
1 .58938 L
s
.99625 .61077 m
1 .61077 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .09737 m
1 .09737 L
s
.48688 0 m
.48688 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.05154 .58635 Mdot
.07987 .569 Mdot
.10875 .55129 Mdot
.13815 .53325 Mdot
.16801 .51492 Mdot
.1983 .49631 Mdot
.22897 .47745 Mdot
.25998 .45837 Mdot
.29128 .4391 Mdot
.32285 .41965 Mdot
.35463 .40006 Mdot
.3866 .38035 Mdot
.4187 .36054 Mdot
.45091 .34065 Mdot
.48317 .32072 Mdot
.51546 .30076 Mdot
.54774 .28081 Mdot
.57997 .26087 Mdot
.6121 .24098 Mdot
.6441 .22116 Mdot
.67593 .20143 Mdot
.70756 .18182 Mdot
.73894 .16236 Mdot
.77003 .14306 Mdot
.80079 .12395 Mdot
.83119 .10505 Mdot
.86118 .0864 Mdot
.89072 .06801 Mdot
.91976 .04992 Mdot
.94827 .03214 Mdot
.5 Mabswid
.02381 .60332 m
.05372 .58501 L
.08634 .56503 L
.11698 .54624 L
.14644 .52816 L
.1778 .5089 L
.20799 .49035 L
.24008 .47061 L
.27099 .45159 L
.30073 .43327 L
.33237 .41378 L
.36283 .395 L
.39213 .37693 L
.42332 .35769 L
.45333 .33915 L
.48525 .31944 L
.51599 .30044 L
.54556 .28215 L
.57703 .26269 L
.60732 .24394 L
.63951 .224 L
.67053 .20478 L
.70038 .18628 L
.73212 .16658 L
.76269 .14761 L
.79209 .12935 L
.82339 .1099 L
.85351 .09117 L
.88553 .07124 L
.91638 .05202 L
.94605 .03352 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`008P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`00000L0?oo
o`<00000703oool5000000<0oooo00<000000?ooo`3oool00P3oool3000001X0oooo0P00000L0?oo
o`D000000`3oool00`000000oooo0?ooo`020?ooo`<00000703oool3000001h0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000004P3oool00280oooo00<000000?ooo`3o
ool01`3oool01@000000oooo0?ooo`3oool0000001X0oooo00D000000?ooo`3oool0oooo0000000L
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`040000
003oool0oooo000001`0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0
000001X0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo0000000A0?ooo`006P3oool5000000@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0B0?ooo`D000001@3oool00`000000oooo0?ooo`0C0?ooo`D000000`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000
7@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo000S0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00000N0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool002@0oooo00<000000?ooo`3oool01@3o
ool4000001/0oooo1000000L0?ooo`050000003oool0oooo0?ooo`0000001`3oool4000001T0oooo
00@000000?ooo`3oool000006`3oool01@000000oooo0?ooo`3oool0000000L0oooo1000000K0?oo
o`@00000803oool00`000000oooo0?ooo`050?ooo`@000004P3oool00200oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`00
000K0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01d0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo01<0
oooo000P0?ooo`D000001`3oool5000001X0oooo1@00000L0?ooo`<00000203oool5000001T0oooo
0P00000M0?ooo`<00000203oool5000001X0oooo1@00000K0?ooo`D000001`3oool500000140oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000N0?ooooP00000
2P3oool001h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000MP3oool00`00
0000oooo0?ooo`1e0?ooo`800000103oool2000000X0oooo000N0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0LP3oool2000000P0oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool001h0oooo00<00000
0?ooo`3oool0M@3oool00`000000oooo0?ooo`1_0?ooo`8000002`3oool00`000000oooo0?ooo`08
0?ooo`007P3oool2000007H0oooo00<000000?ooo`3oool0KP3oool3000000X0oooo0P00000:0?oo
o`007P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1e0?ooo`030000
003oool0oooo06/0oooo0P00000?0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0J@3oool200000140oooo00<000000?ooo`3oool0203o
ool001h0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1X0?ooo`8000004P3oool0
0`000000oooo0?ooo`080?ooo`007P3oool2000007H0oooo00<000000?ooo`3oool0IP3oool40000
0140oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo06@0
oooo0P00000F0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07D0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo
000N0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0H03oool3000001T0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1O
0?ooo`<000006P3oool00`000000oooo0?ooo`080?ooo`007P3oool2000007H0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`0J0?ooo`8000002P3oool001h0oooo00<000000?ooo`3o
ool0M@3oool00`000000oooo0?ooo`1L0?ooo`8000007P3oool00`000000oooo0?ooo`080?ooo`00
7P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo05X0oooo0P00000P0?ooo`030000
003oool0oooo00P0oooo000:0?ooo`<000000`3oool3000000<0oooo0`0000050?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0F@3oool200000240oooo00<000000?ooo`3oool0203o
ool000T0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0E`3oool400000240
oooo00<000000?ooo`3oool0203oool000d0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool000d0oooo00@000000?ooo`3oool0
oooo0P0000040?ooo`030000003oool0oooo00@0oooon000000:0?ooo`002@3oool4000000H0oooo
00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool0DP3oool2000002P0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool000000080oooo0P0000060?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0D@3oool3000002P0oooo00<000000?ooo`3oool0203oool000T0oooo
1@0000020?ooo`<00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07D0oooo
00<000000?ooo`3oool0C`3oool2000002/0oooo00<000000?ooo`3oool0203oool001h0oooo00<0
00000?ooo`3oool0M@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0203oool001h0oooo0P00001f0?ooo`030000003oool0oooo04`0oooo0P00000]
0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1:0?oo
o`800000<03oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1e0?ooo`03
0000003oool0oooo04X0oooo0P00000`0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo07D0oooo00<000000?ooo`3oool0B03oool200000380oooo00<000000?ooo`3oool0
203oool001h0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`160?ooo`800000=03o
ool00`000000oooo0?ooo`080?ooo`007P3oool2000007H0oooo00<000000?ooo`3oool0A03oool2
000003D0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
0480oooo0`00000g0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0@03oool2000000030?ooo`000000000003L0oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`0m0?ooo`800000?@3oool00`000000oooo0?ooo`080?ooo`007P3oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo03/0oooo0P00000o0?ooo`030000003oool0
oooo00P0oooo000N0?ooo`800000MP3oool00`000000oooo0?ooo`0k0?ooo`800000?P3oool20000
00X0oooo000N0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0>@3oool200000440
oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0M@3oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0203oool001h0oooo00<0
00000?ooo`3oool0M@3oool00`000000oooo0?ooo`0f0?ooo`800000A03oool00`000000oooo0?oo
o`080?ooo`007P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo03<0oooo0`000016
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000MP3oool00`000000oooo0?ooo`0c0?oo
o`800000AP3oool2000000X0oooo000N0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool0<@3oool2000004T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`0_0?ooo`800000B`3oool00`000000oooo0?ooo`080?ooo`002P3o
ool3000000<0oooo0`0000020?ooo`D00000103oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`002@3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0[0?ooo`<0
0000CP3oool00`000000oooo0?ooo`080?ooo`003@3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000001P3oool2000007H0oooo00<000000?ooo`3oool0:P3oool3000004h0
oooo0P00000:0?ooo`003@3oool010000000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`080?ooo`002@3oool4000000H0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
9`3oool2000005<0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool00`3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool09@3oool2000005D0oooo00<000000?ooo`3o
ool0203oool000T0oooo1@0000020?ooo`<000000`3oool3000000D0oooo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`0S0?ooo`800000E`3oool00`000000oooo0?ooo`080?ooo`007P3o
ool2000007H0oooo00<000000?ooo`3oool08P3oool3000005H0oooo0P00000:0?ooo`007P3oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
01l0oooo0P00001K0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool07@3oool2000005d0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0L0?ooo`800000GP3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo01X0oooo1000
001N0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000MP3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo05l0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo01L0oooo0P00001S0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
503oool2000006H0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`0C0?ooo`<00000IP3oool00`000000oooo0?ooo`080?ooo`007P3oool2
000007H0oooo00<000000?ooo`3oool04@3oool2000006P0oooo0P00000:0?ooo`007P3oool00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo00l0oooo0P00001[0?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool03@3oool2000006d0
oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0M@3oool00`000000oooo
0?ooo`0;0?ooo`<00000KP3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?oo
o`1e0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`0000000000KP3oool00`000000oooo
0?ooo`080?ooo`007P3oool2000007H0oooo00<000000?ooo`3oool0203oool200000740oooo0P00
000:0?ooo`007P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00H0oooo0P00001d
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00P0oooo000:0?ooo`<0
00000`3oool3000000<0oooo0`0000050?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool00`3oool3000007H0oooo00<000000?ooo`3oool0203oool000T0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo07D0oooo00<000000?ooo`3oool00P3oool010000000oooo00000000001f
0?ooo`030000003oool0oooo00P0oooo000=0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo00<000000?oo
o`3oool00P00001j0?ooo`030000003oool0oooo00P0oooo000=0?ooo`040000003oool0oooo0?oo
o`800000103oool2000000D0oooo0P00001f0?ooo`030000003oool0000007/0oooo0P00000:0?oo
o`002@3oool4000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo07D0oooo0P00001m0?ooo`030000003oool0oooo00P0oooo00090?ooo`030000
003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`800000OP3oool00`000000oooo0?ooo`080?oo
o`002@3oool500000080oooo0`0000030?ooo`<000001@3oool00`000000oooo0?ooo`1b0?ooo`@0
0000OP3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`800000
0`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000K`3o
ool2000000D0oooo00<000000?ooo`3oool0N`3oool2000000X0oooo000N0?ooo`030000003oool0
oooo06`0oooo0P0000070?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0203oool0
01h0oooo00<000000?ooo`3oool0J`3oool3000000L0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`80000000<0oooo00000000
00001`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1l0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`800000J03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo07/0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1T0?ooo`<000003P3oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo
06@0oooo0P00000?0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0203oool001h0
oooo00<000000?ooo`3oool0HP3oool200000140oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1P0?ooo`8000004`3oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000H03oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo07/0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1L
0?ooo`<000005P3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0oooo000N0?oo
o`030000003oool0oooo05/0oooo0`00000G0?ooo`030000003oool0oooo07`0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
F03oool2000001/0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`1F0?ooo`8000007@3oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo00P0oooo000N0?ooo`800000E@3oool2000001l0oooo00<000000?ooo`3oool0N`3oool2
000000X0oooo000N0?ooo`030000003oool0oooo05<0oooo0`00000O0?ooo`030000003oool0oooo
07`0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0D@3oool200000280
oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`080?ooo`002P3oool3000000<0oooo
0`0000040?ooo`<00000103oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`080?ooo`002@3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0CP3oool2000002D0oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`080?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@00000
103oool2000004d0oooo0P00000W0?ooo`030000003oool0oooo07/0oooo0P00000:0?ooo`003@3o
ool010000000oooo0?ooo`3oool200000080oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`1;0?ooo`<000009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0
oooo00090?ooo`@000001P3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?oo
o`3oool0B@3oool2000002X0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`080?oo
o`002@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
00D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
07`0oooo00<000000?ooo`3oool0203oool000T0oooo1@0000020?ooo`<000001@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo04H0oooo0P00000]0?ooo`030000003oool0oooo07`0
oooo00<000000?ooo`3oool0203oool001h0oooo0P0000150?ooo`800000;`3oool00`000000oooo
0?ooo`1k0?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0@`3oool3000002l0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`11
0?ooo`800000<P3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0oooo000N0?oo
o`030000003oool0oooo03l0oooo0P00000d0?ooo`030000003oool0oooo07`0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
?03oool2000003L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`080?ooo`007P3o
ool2000003/0oooo1000000g0?ooo`030000003oool0oooo07/0oooo0P00000:0?ooo`007P3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0g0?ooo`800000?03oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo03D0
oooo0P00000n0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool0=03oool3000003h0oooo00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`080?ooo`007P3oool2000003<0oooo0P0000110?ooo`030000003oool0oooo07/0oooo0P00
000:0?ooo`007P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0_0?oo
o`800000A03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo02d0oooo0P0000160?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool0;03oool3000004H0oooo00<000000?ooo`3oool0
O03oool00`000000oooo0?ooo`080?ooo`007P3oool2000002/0oooo0P0000190?ooo`030000003o
ool0oooo07/0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`0X0?ooo`800000B`3oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
00P0oooo000:0?ooo`<000000`3oool3000000<0oooo0`0000050?ooo`030000003oool0oooo02D0
oooo0`00001=0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0203oool000T0oooo
00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo0P0000000`3oool000000000001=0?oo
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool0203oool000d0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P00000S0?ooo`03
0000003oool0oooo0500oooo00<000000?ooo`3oool0N`3oool2000000X0oooo000=0?ooo`040000
003oool0oooo0?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0200
oooo0P00001C0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0203oool000T0oooo
100000060?ooo`030000003oool0000000<000001@3oool00`000000oooo0?ooo`0N0?ooo`800000
E@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003o
ool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00<000000?ooo`3o
ool07@3oool3000005D0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`080?ooo`00
2@3oool500000080oooo0`0000020?ooo`D00000103oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0O03o
ool00`000000oooo0?ooo`080?ooo`007P3oool2000001X0oooo0P00001J0?ooo`030000003oool0
oooo07/0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`0G0?ooo`800000G03oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo01D0
oooo1000001L0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool04`3oool200000600oooo00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0A0?ooo`800000HP3oool00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000004@3oool2000006<0oooo00<00000
0?ooo`3oool0N`3oool2000000X0oooo000N0?ooo`030000003oool0oooo00h0oooo1000001S0?oo
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool0303oool2000006L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`080?ooo`00
7P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0
O03oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`090?ooo`800000JP3o
ool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000002@3oool3
000006X0oooo00<000000?ooo`3oool0N`3oool2000000X0oooo000N0?ooo`030000003oool0oooo
00H0oooo0P00001]0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0203oool001h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo07`0
oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0203oool001h0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo07`0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000001P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo0P00000:0?ooo`007P3ooooh000000X0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo000Z0?ooo`<00000F03oool3000001L0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0D0?ooo`00:`3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool3000000<0oooo0`0000040?ooo`8000000P3oool500000080oooo0`0000030?ooo`@00000
00<0oooo0000000000000`0000070?ooo`<00000103oool4000000<0oooo0P0000020?ooo`H00000
1P3oool500000080oooo0`0000020?ooo`<0000000@0oooo000000000000oooo100000030?ooo`80
00000P3oool6000000L0oooo00<000000?ooo`3oool00`3oool4000000030?ooo`00000000000080
00000P3oool4000000<0oooo0`0000020?ooo`D000000`3oool2000000040?ooo`000000oooo0?oo
o`8000000`3oool3000000T0oooo100000000`3oool0000000000003000000030?ooo`0000000000
00800000103oool2000000<0oooo100000001@3oool00000000000000000oooo0080000000@0oooo
00000000000000000`3oool3000000D0oooo00<000000?ooo`3oool04P3oool002@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
203oool01P000000oooo0?ooo`000000oooo000000H0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`00000;0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00
00020?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0000000<0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`0B0?ooo`00903o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3oool3000000@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00P3oool500000080oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`030?ooo`<000000`3oool010000000oooo0?ooo`000002
0?ooo`<000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo1@0000070?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3o
ool00`3oool3000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`D00000103oool0
0`000000oooo0?ooo`0B0?ooo`00903oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool300000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
00000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo000000D0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool00000103o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool002@0oooo00H000000?oo
o`3oool0oooo0000003oool400000080oooo100000020?ooo`<00000103oool3000000<0oooo0P00
00050?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000P3oool2000000<0oooo
100000030?ooo`<000002@3oool00`000000oooo0?ooo`030?ooo`<000000P3oool4000000<0oooo
2@0000030?ooo`<000002@3oool00`000000oooo0?ooo`030?ooo`800000103oool3000000<0oooo
100000020?ooo`<00000103oool010000000oooo0?ooo`3oool2000000040?ooo`00000000000?oo
o`@000000`3oool3000000T0oooo0`0000020?ooo`<00000103oool4000000030?ooo`0000000000
008000000`3oool2000000<0oooo100000030?ooo`<000000`3oool3000000D0oooo00<000000?oo
o`3oool04P3oool002@0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`009@3oool30000
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`<000002@3oool40000
00T0oooo00<000000?ooo`3oool00P3oool2000000X0oooo0`00000F0?ooo`030000003oool0oooo
0080oooo0P00000=0?ooo`030000003oool0oooo00H0oooo0P00000@0?ooo`<000002P3oool00`00
0000oooo0?ooo`0@0?ooo`800000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0503oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.0684, 529.633, \
0.0667933, 0.0378261}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.486878 0.0605726 -3.56261 0.0376008 [
[.03258 -0.0125 -12 -9 ]
[.03258 -0.0125 12 0 ]
[.18401 -0.0125 -6 -9 ]
[.18401 -0.0125 6 0 ]
[.33545 -0.0125 -12 -9 ]
[.33545 -0.0125 12 0 ]
[.48688 -0.0125 -3 -9 ]
[.48688 -0.0125 3 0 ]
[.63831 -0.0125 -9 -9 ]
[.63831 -0.0125 9 0 ]
[.78974 -0.0125 -3 -9 ]
[.78974 -0.0125 3 0 ]
[.94117 -0.0125 -9 -9 ]
[.94117 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00947 -12 -4.5 ]
[-0.0125 .00947 0 4.5 ]
[-0.0125 .10347 -24 -4.5 ]
[-0.0125 .10347 0 4.5 ]
[-0.0125 .19747 -18 -4.5 ]
[-0.0125 .19747 0 4.5 ]
[-0.0125 .29148 -30 -4.5 ]
[-0.0125 .29148 0 4.5 ]
[-0.0125 .38548 -18 -4.5 ]
[-0.0125 .38548 0 4.5 ]
[-0.0125 .47948 -30 -4.5 ]
[-0.0125 .47948 0 4.5 ]
[-0.0125 .57348 -18 -4.5 ]
[-0.0125 .57348 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03258 0 m
.03258 .00625 L
s
[(-7.5)] .03258 -0.0125 0 1 Mshowa
.18401 0 m
.18401 .00625 L
s
[(-5)] .18401 -0.0125 0 1 Mshowa
.33545 0 m
.33545 .00625 L
s
[(-2.5)] .33545 -0.0125 0 1 Mshowa
.48688 0 m
.48688 .00625 L
s
[(0)] .48688 -0.0125 0 1 Mshowa
.63831 0 m
.63831 .00625 L
s
[(2.5)] .63831 -0.0125 0 1 Mshowa
.78974 0 m
.78974 .00625 L
s
[(5)] .78974 -0.0125 0 1 Mshowa
.94117 0 m
.94117 .00625 L
s
[(7.5)] .94117 -0.0125 0 1 Mshowa
.125 Mabswid
.06287 0 m
.06287 .00375 L
s
.09316 0 m
.09316 .00375 L
s
.12344 0 m
.12344 .00375 L
s
.15373 0 m
.15373 .00375 L
s
.2143 0 m
.2143 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.27487 0 m
.27487 .00375 L
s
.30516 0 m
.30516 .00375 L
s
.36573 0 m
.36573 .00375 L
s
.39602 0 m
.39602 .00375 L
s
.4263 0 m
.4263 .00375 L
s
.45659 0 m
.45659 .00375 L
s
.51716 0 m
.51716 .00375 L
s
.54745 0 m
.54745 .00375 L
s
.57774 0 m
.57774 .00375 L
s
.60802 0 m
.60802 .00375 L
s
.6686 0 m
.6686 .00375 L
s
.69888 0 m
.69888 .00375 L
s
.72917 0 m
.72917 .00375 L
s
.75945 0 m
.75945 .00375 L
s
.82003 0 m
.82003 .00375 L
s
.85031 0 m
.85031 .00375 L
s
.8806 0 m
.8806 .00375 L
s
.91089 0 m
.91089 .00375 L
s
.0023 0 m
.0023 .00375 L
s
.97146 0 m
.97146 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00947 m
.00625 .00947 L
s
[(95)] -0.0125 .00947 1 0 Mshowa
0 .10347 m
.00625 .10347 L
s
[(97.5)] -0.0125 .10347 1 0 Mshowa
0 .19747 m
.00625 .19747 L
s
[(100)] -0.0125 .19747 1 0 Mshowa
0 .29148 m
.00625 .29148 L
s
[(102.5)] -0.0125 .29148 1 0 Mshowa
0 .38548 m
.00625 .38548 L
s
[(105)] -0.0125 .38548 1 0 Mshowa
0 .47948 m
.00625 .47948 L
s
[(107.5)] -0.0125 .47948 1 0 Mshowa
0 .57348 m
.00625 .57348 L
s
[(110)] -0.0125 .57348 1 0 Mshowa
.125 Mabswid
0 .02827 m
.00375 .02827 L
s
0 .04707 m
.00375 .04707 L
s
0 .06587 m
.00375 .06587 L
s
0 .08467 m
.00375 .08467 L
s
0 .12227 m
.00375 .12227 L
s
0 .14107 m
.00375 .14107 L
s
0 .15987 m
.00375 .15987 L
s
0 .17867 m
.00375 .17867 L
s
0 .21627 m
.00375 .21627 L
s
0 .23507 m
.00375 .23507 L
s
0 .25387 m
.00375 .25387 L
s
0 .27267 m
.00375 .27267 L
s
0 .31028 m
.00375 .31028 L
s
0 .32908 m
.00375 .32908 L
s
0 .34788 m
.00375 .34788 L
s
0 .36668 m
.00375 .36668 L
s
0 .40428 m
.00375 .40428 L
s
0 .42308 m
.00375 .42308 L
s
0 .44188 m
.00375 .44188 L
s
0 .46068 m
.00375 .46068 L
s
0 .49828 m
.00375 .49828 L
s
0 .51708 m
.00375 .51708 L
s
0 .53588 m
.00375 .53588 L
s
0 .55468 m
.00375 .55468 L
s
0 .59228 m
.00375 .59228 L
s
0 .61108 m
.00375 .61108 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.03258 .61178 m
.03258 .61803 L
s
.18401 .61178 m
.18401 .61803 L
s
.33545 .61178 m
.33545 .61803 L
s
.48688 .61178 m
.48688 .61803 L
s
.63831 .61178 m
.63831 .61803 L
s
.78974 .61178 m
.78974 .61803 L
s
.94117 .61178 m
.94117 .61803 L
s
.125 Mabswid
.06287 .61428 m
.06287 .61803 L
s
.09316 .61428 m
.09316 .61803 L
s
.12344 .61428 m
.12344 .61803 L
s
.15373 .61428 m
.15373 .61803 L
s
.2143 .61428 m
.2143 .61803 L
s
.24459 .61428 m
.24459 .61803 L
s
.27487 .61428 m
.27487 .61803 L
s
.30516 .61428 m
.30516 .61803 L
s
.36573 .61428 m
.36573 .61803 L
s
.39602 .61428 m
.39602 .61803 L
s
.4263 .61428 m
.4263 .61803 L
s
.45659 .61428 m
.45659 .61803 L
s
.51716 .61428 m
.51716 .61803 L
s
.54745 .61428 m
.54745 .61803 L
s
.57774 .61428 m
.57774 .61803 L
s
.60802 .61428 m
.60802 .61803 L
s
.6686 .61428 m
.6686 .61803 L
s
.69888 .61428 m
.69888 .61803 L
s
.72917 .61428 m
.72917 .61803 L
s
.75945 .61428 m
.75945 .61803 L
s
.82003 .61428 m
.82003 .61803 L
s
.85031 .61428 m
.85031 .61803 L
s
.8806 .61428 m
.8806 .61803 L
s
.91089 .61428 m
.91089 .61803 L
s
.0023 .61428 m
.0023 .61803 L
s
.97146 .61428 m
.97146 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00947 m
1 .00947 L
s
.99375 .10347 m
1 .10347 L
s
.99375 .19747 m
1 .19747 L
s
.99375 .29148 m
1 .29148 L
s
.99375 .38548 m
1 .38548 L
s
.99375 .47948 m
1 .47948 L
s
.99375 .57348 m
1 .57348 L
s
.125 Mabswid
.99625 .02827 m
1 .02827 L
s
.99625 .04707 m
1 .04707 L
s
.99625 .06587 m
1 .06587 L
s
.99625 .08467 m
1 .08467 L
s
.99625 .12227 m
1 .12227 L
s
.99625 .14107 m
1 .14107 L
s
.99625 .15987 m
1 .15987 L
s
.99625 .17867 m
1 .17867 L
s
.99625 .21627 m
1 .21627 L
s
.99625 .23507 m
1 .23507 L
s
.99625 .25387 m
1 .25387 L
s
.99625 .27267 m
1 .27267 L
s
.99625 .31028 m
1 .31028 L
s
.99625 .32908 m
1 .32908 L
s
.99625 .34788 m
1 .34788 L
s
.99625 .36668 m
1 .36668 L
s
.99625 .40428 m
1 .40428 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .44188 m
1 .44188 L
s
.99625 .46068 m
1 .46068 L
s
.99625 .49828 m
1 .49828 L
s
.99625 .51708 m
1 .51708 L
s
.99625 .53588 m
1 .53588 L
s
.99625 .55468 m
1 .55468 L
s
.99625 .59228 m
1 .59228 L
s
.99625 .61108 m
1 .61108 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.48688 0 m
.48688 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.01 w
.05154 .60332 Mdot
.07987 .51494 Mdot
.10875 .43655 Mdot
.13815 .36709 Mdot
.16801 .30567 Mdot
.1983 .25154 Mdot
.22897 .20409 Mdot
.25998 .16278 Mdot
.29128 .12719 Mdot
.32285 .09695 Mdot
.35463 .07176 Mdot
.3866 .05138 Mdot
.4187 .03561 Mdot
.45091 .02431 Mdot
.48317 .01737 Mdot
.51546 .01472 Mdot
.54774 .01633 Mdot
.57997 .02221 Mdot
.6121 .03242 Mdot
.6441 .04703 Mdot
.67593 .06618 Mdot
.70756 .09003 Mdot
.73894 .1188 Mdot
.77003 .15277 Mdot
.80079 .19226 Mdot
.83119 .23768 Mdot
.86118 .28951 Mdot
.89072 .34831 Mdot
.91976 .41479 Mdot
.94827 .48974 Mdot
.5 Mabswid
.02381 .60332 m
.03076 .60332 L
.03837 .60332 L
.04221 .60332 L
.04632 .60332 L
.04831 .60332 L
.04929 .60332 L
.05019 .60332 L
.05101 .60332 L
.05188 .60224 L
.05276 .59951 L
.05372 .59651 L
.08634 .49737 L
.11753 .41581 L
.14755 .34776 L
.17946 .2852 L
.21021 .23312 L
.23978 .18969 L
.27124 .14997 L
.30154 .11737 L
.33373 .08833 L
.36475 .06531 L
.39459 .04745 L
.42634 .03293 L
.44215 .02738 L
.45691 .02302 L
.4711 .01997 L
.479 .01827 L
.48067 .01791 L
.48247 .01752 L
.48297 .01741 L
.4835 .01734 L
.48445 .01726 L
.48631 .01711 L
.49013 .0168 L
.49418 .01646 L
.50275 .01576 L
.51028 .01514 L
.51245 .01496 L
.51352 .01488 L
.5145 .01479 L
.51539 .01472 L
.51634 .01476 L
.51833 .01486 L
.53361 .01562 L
.54104 .01599 L
.54429 .01615 L
.54601 .01624 L
.54695 .01629 L
.54783 .01634 L
Mistroke
.54885 .01653 L
.54978 .0167 L
.55158 .01703 L
.55514 .01768 L
.56299 .01911 L
.56975 .02035 L
.57716 .0217 L
.57906 .02205 L
.58109 .02257 L
.58474 .02373 L
.59274 .02627 L
.60705 .03082 L
.63911 .04475 L
.67 .06261 L
.69972 .08411 L
.73133 .11182 L
.76177 .14374 L
.79104 .17973 L
.8222 .22425 L
.85219 .27398 L
.88408 .33511 L
.9148 .40344 L
.94434 .47943 L
.97579 .57294 L
.97619 .57416 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`00000L0?oo
o`<00000703oool5000000<0oooo00<000000?ooo`3oool00P3oool3000001X0oooo0P00000L0?oo
o`D000000`3oool00`000000oooo0?ooo`020?ooo`<00000703oool3000001h0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`<00000303oool002P0oooo00<000000?ooo`3o
ool01`3oool01@000000oooo0?ooo`3oool0000001X0oooo00D000000?ooo`3oool0oooo0000000L
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`040000
003oool0oooo000001`0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0
000001X0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`00803oool5000000@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0B0?ooo`D000001@3oool00`000000oooo0?ooo`0C0?ooo`D000000`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000
7@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo000Y0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00000N0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool002X0oooo00<000000?ooo`3oool01@3o
ool4000001/0oooo1000000L0?ooo`050000003oool0oooo0?ooo`0000001`3oool4000001T0oooo
00@000000?ooo`3oool000006`3oool01@000000oooo0?ooo`3oool0000000L0oooo1000000K0?oo
o`@00000803oool00`000000oooo0?ooo`050?ooo`@00000303oool002H0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`00
000K0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01d0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00d0
oooo000V0?ooo`D000001`3oool5000001X0oooo1@00000L0?ooo`<00000203oool5000001T0oooo
0P00000M0?ooo`<00000203oool5000001X0oooo1@00000K0?ooo`D000001`3oool5000000/0oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000F0?ooo`800000103oool300000?l0
oooo0P3oool001P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooooP0
0000103oool001T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo000F0?ooo`@000001@3oool00`000000oooo0?ooo`020?ooo`800000MP3o
ool00`000000oooo0?ooo`1k0?ooo`800000103oool001D0oooo00H000000?ooo`3oool0oooo0000
003oool4000000D0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`020?ooo`H00000
103oool2000006h0oooo00<000000?ooo`3oool00P3oool001D0oooo00L000000?ooo`3oool0oooo
0000003oool0000000P0oooo00<000000?ooo`3oool0LP3oool800000080oooo0P0000020?ooo`X0
0000JP3oool00`000000oooo0?ooo`020?ooo`005P3oool300000080oooo1@0000040?ooo`030000
003oool0oooo06`0oooo1P0000020?ooo`800000503oool4000006H0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0J@3oool5000000L0oooo00<000000?ooo`3oool0503o
ool600000680oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001X0?ooo`800000303oool0
0`000000oooo0?ooo`0J0?ooo`@00000G@3oool2000000@0oooo000T0?ooo`030000003oool0oooo
06@0oooo0`00000>0?ooo`030000003oool0oooo01`0oooo0`00001M0?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo0680oooo1000000?0?ooo`030000003oool0oooo01l0
oooo0P00001K0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo05l0oooo
0`00000C0?ooo`030000003oool0oooo0240oooo0P00001I0?ooo`030000003oool0oooo0080oooo
000T0?ooo`800000GP3oool2000001H0oooo00<000000?ooo`3oool08`3oool2000005H0oooo0P00
00040?ooo`00903oool00`000000oooo0?ooo`1L0?ooo`8000005`3oool00`000000oooo0?ooo`0S
0?ooo`@00000E@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1J0?oo
o`@000005`3oool00`000000oooo0?ooo`0W0?ooo`800000D`3oool00`000000oooo0?ooo`020?oo
o`00903oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0:@3oool200000540oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02/0oooo0P00001?0?ooo`030000
003oool0oooo0080oooo000T0?ooo`800000E`3oool2000001d0oooo00<000000?ooo`3oool0:`3o
ool3000004d0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1D0?ooo`8000007`3oool0
0`000000oooo0?ooo`0[0?ooo`80000000<0oooo000000000000C03oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`1C0?ooo`<000007`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3o
ool0D@3oool200000280oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0b0?ooo`800000B03oool00`000000oooo0?ooo`020?ooo`00903o
ool200000500oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo04@0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0<`3oool3000004H0oooo00<000000?ooo`3oool00P3oool0
00X0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool30000
00D0oooo00<000000?ooo`3oool0C03oool2000002L0oooo00<000000?ooo`3oool0<`3oool20000
00030?ooo`000000oooo04@0oooo00<000000?ooo`3oool00P3oool000`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`1<0?ooo`8000009`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool00P3oool000d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo0P00001<0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`100?ooo`800000103oool000X0oooo
100000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo0080oooo00090?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`050?ooo`@000001@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo0080oooo00090?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0080oooo000:0?ooo`<000000P3oool5000000L0oooo1@0000040?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0k0?ooo`800000
?`3oool00`000000oooo0?ooo`020?ooo`00903oool2000004P0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0k0?ooo`800000?P3oool2000000@0oooo000T0?ooo`030000003oool0
oooo04@0oooo0`00000^0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`140?ooo`800000;`3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000@`3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=`3oool2000000@0oooo000T
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0480oooo0`00000g0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`130?ooo`800000=`3oool00`000000oooo0?ooo`020?ooo`00
903oool200000400oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo03@0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`0l0?ooo`<00000=P3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0?03oool2000003L0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`020?ooo`00903oool2000003`0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo0300oooo0P0000040?ooo`00903oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo0080oooo000@0?ooo`<00000103oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00P3oool00140oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo04X0oooo0P00
000`0?ooo`030000003oool0oooo0080oooo000A0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000>@3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo04X0oooo0P00000_0?ooo`800000103oool00140oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`004@3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0e0?ooo`800000?P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool00P3oool00100oooo0P0000040?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0e0?ooo`800000?P3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00P3oool0
0140oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00000e0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0Z0?ooo`800000103oool002@0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`020?oo
o`00903oool200000380oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1B0?ooo`80
00009`3oool2000000@0oooo000T0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`1B0?ooo`800000:03oool00`000000oooo0?ooo`020?ooo`00903o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00000^0?ooo`800000AP3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo02@0oooo0P0000040?ooo`00903oool00`000000
oooo0?ooo`0]0?ooo`800000AP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo000T
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool002@0oooo0P00000/0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0P0?oo
o`800000103oool002@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`00
103oool3000000@0oooo0P0000020?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`<00000
1@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo00050?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0080oooo00050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo05T0oooo0P00000Q0?ooo`030000003oool0oooo
0080oooo00050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo0P00000Y0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool0F@3oool200000200oooo0P0000040?ooo`001@3oool00`000000
oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`05
0?ooo`@000001@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo00040?oo
o`800000103oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3o
ool000D0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`0000080?ooo`D00000103oool0
0`000000oooo0?ooo`0V0?ooo`800000C@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00000W0?ooo`800000C@3oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo01`0oooo0P0000040?ooo`00903oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0G03oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`020?ooo`00903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo000T0?oo
o`8000009@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool06P3oool2000000@0oooo000T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`00903o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1P0?ooo`8000006P3oool0
0`000000oooo0?ooo`020?ooo`00903oool200000280oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`1P0?ooo`8000006@3oool2000000@0oooo000T0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo000T
0?ooo`8000007`3oool2000005D0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0E
0?ooo`800000103oool002@0oooo00<000000?ooo`3oool07P3oool2000005D0oooo00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo000@0?ooo`<0
0000103oool2000000<0oooo0`0000050?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool00P3oool00140oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0080oooo000A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00140
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
0080oooo0P00000N0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`0C0?ooo`800000103oool00140oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`000000oooo00@000001@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0080oooo000@0?ooo`800000103oool01P000000oooo0?ooo`000000oooo000000P0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`004@3oool00`000000oooo0?ooo`030?oo
o`8000000P3oool5000000@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?oo
o`00903oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000
703oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0
4@3oool2000000@0oooo000T0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo06P0oooo0P00000B0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1X0?ooo`8000004P3oool00`00
0000oooo0?ooo`020?ooo`00903oool2000001X0oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`1Y0?ooo`030000003oool0oooo00l0oooo0P0000040?ooo`00903oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0J@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool05`3oool2000005`0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo01L0oooo0P00001L0?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`020?ooo`00903oool2000001T0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00d0oooo0P0000040?ooo`00
903oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
J`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1[0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0080oooo000T0?ooo`8000005`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo06`0
oooo00<000000?ooo`3oool0303oool2000000@0oooo000T0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00P3oool000@0oooo0`0000040?ooo`800000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool00P3oool000D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool000D0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool2000001D0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo00X0oooo0P0000040?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool000D0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00D0oooo100000050?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1_0?ooo`800000
2`3oool00`000000oooo0?ooo`020?ooo`00103oool2000000@0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0K`3oool2000000/0
oooo00<000000?ooo`3oool00P3oool000D0oooo00<000000?ooo`3oool00`3oool200000080oooo
1@0000070?ooo`D00000103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05l0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo
000T0?ooo`8000004`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool0203oool2000000@0oooo000T0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo0700oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?oo
o`00903oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo000T0?ooo`800000
4@3oool2000006<0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`070?ooo`800000
103oool002@0oooo00<000000?ooo`3oool0403oool2000006<0oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo000T0?ooo`800000403oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool01@3oool2000000@0oooo000T0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000T0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00000>0?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`040?ooo`800000
103oool002@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`00403oool3
000000<0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo000A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo0P00000=0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`020?ooo`800000103oool00140oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1V0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`004@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`020?ooo`00403oool20000
00@0oooo0P0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool0
0140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`020?ooo`00903oool2000000/0oooo00<000000?ooo`3oool0J03oool00`000000
oooo0?ooo`1k0?ooo`800000103oool002@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1X0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool02@3oool2000006X0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`020?ooo`00903oool00`000000oooo0?ooo`030?ooo`P00000JP3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07D0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`020?ooo`00903oool2000000H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`800000103oool002@0oooon00000040?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00dP3oool3000004/0oooo003C0?ooo`030000
003oool0oooo04X0oooo001W0?ooo`030000003oool0000000<0oooo100000030?ooo`030000003o
ool0oooo0080oooo0`0000020?ooo`<000000`3oool3000000@0oooo0`0000020?ooo`<0000000<0
oooo0000000000000P3oool2000000P0oooo1@0000001@3oool00000000000000000oooo00800000
0P3oool2000000<0oooo0`0000020?ooo`<0000000<0oooo000000000000100000020?ooo`D00000
0`3oool2000000@0oooo00<000000?ooo`3oool0B@3oool006L0oooo00<000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000060?oo
o`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0B@3oool006L0oooo00<000000?ooo`0000000`3o
ool3000000<0oooo00<000000?ooo`0000000P3oool500000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo1@0000020?ooo`040000003oool0oooo
00000080oooo0`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0000001:0?ooo`00IP3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo0`0000030?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00000P3oool01P000000oooo0?ooo`000000oooo000000L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0000004X0oooo001V0?ooo`050000003oool00000
0?ooo`0000000P3oool2000000<0oooo0P0000000`3oool00000000000020?ooo`<000000`3oool0
0`000000oooo0?ooo`020?ooo`80000000<0oooo0000000000000P3oool300000080oooo10000002
0?ooo`@000002P3oool010000000oooo0?ooo`3oool400000080oooo100000030?ooo`<000000P3o
ool4000000<0oooo10000000103oool000000000000000030?ooo`@000000P3oool2000000030?oo
o`000000000004T0oooo001V0?ooo`050000003oool000000?ooo`000000503oool010000000oooo
0?ooo`00000D0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0500oooo001V0?ooo`H000004P3oool5000001@0oooo
00<000000?ooo`3oool0203oool5000000P0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0500oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.4691, 93.4473, \
0.0667933, 0.1076}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.486878 0.0605726 0.309017 5.69022e-05 [
[.03258 -0.0125 -12 -9 ]
[.03258 -0.0125 12 0 ]
[.18401 -0.0125 -6 -9 ]
[.18401 -0.0125 6 0 ]
[.33545 -0.0125 -12 -9 ]
[.33545 -0.0125 12 0 ]
[.48688 -0.0125 -3 -9 ]
[.48688 -0.0125 3 0 ]
[.63831 -0.0125 -9 -9 ]
[.63831 -0.0125 9 0 ]
[.78974 -0.0125 -3 -9 ]
[.78974 -0.0125 3 0 ]
[.94117 -0.0125 -9 -9 ]
[.94117 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08141 -30 -4.5 ]
[-0.0125 .08141 0 4.5 ]
[-0.0125 .19521 -30 -4.5 ]
[-0.0125 .19521 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .42282 -24 -4.5 ]
[-0.0125 .42282 0 4.5 ]
[-0.0125 .53663 -24 -4.5 ]
[-0.0125 .53663 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03258 0 m
.03258 .00625 L
s
[(-7.5)] .03258 -0.0125 0 1 Mshowa
.18401 0 m
.18401 .00625 L
s
[(-5)] .18401 -0.0125 0 1 Mshowa
.33545 0 m
.33545 .00625 L
s
[(-2.5)] .33545 -0.0125 0 1 Mshowa
.48688 0 m
.48688 .00625 L
s
[(0)] .48688 -0.0125 0 1 Mshowa
.63831 0 m
.63831 .00625 L
s
[(2.5)] .63831 -0.0125 0 1 Mshowa
.78974 0 m
.78974 .00625 L
s
[(5)] .78974 -0.0125 0 1 Mshowa
.94117 0 m
.94117 .00625 L
s
[(7.5)] .94117 -0.0125 0 1 Mshowa
.125 Mabswid
.06287 0 m
.06287 .00375 L
s
.09316 0 m
.09316 .00375 L
s
.12344 0 m
.12344 .00375 L
s
.15373 0 m
.15373 .00375 L
s
.2143 0 m
.2143 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.27487 0 m
.27487 .00375 L
s
.30516 0 m
.30516 .00375 L
s
.36573 0 m
.36573 .00375 L
s
.39602 0 m
.39602 .00375 L
s
.4263 0 m
.4263 .00375 L
s
.45659 0 m
.45659 .00375 L
s
.51716 0 m
.51716 .00375 L
s
.54745 0 m
.54745 .00375 L
s
.57774 0 m
.57774 .00375 L
s
.60802 0 m
.60802 .00375 L
s
.6686 0 m
.6686 .00375 L
s
.69888 0 m
.69888 .00375 L
s
.72917 0 m
.72917 .00375 L
s
.75945 0 m
.75945 .00375 L
s
.82003 0 m
.82003 .00375 L
s
.85031 0 m
.85031 .00375 L
s
.8806 0 m
.8806 .00375 L
s
.91089 0 m
.91089 .00375 L
s
.0023 0 m
.0023 .00375 L
s
.97146 0 m
.97146 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08141 m
.00625 .08141 L
s
[(-4000)] -0.0125 .08141 1 0 Mshowa
0 .19521 m
.00625 .19521 L
s
[(-2000)] -0.0125 .19521 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .42282 m
.00625 .42282 L
s
[(2000)] -0.0125 .42282 1 0 Mshowa
0 .53663 m
.00625 .53663 L
s
[(4000)] -0.0125 .53663 1 0 Mshowa
.125 Mabswid
0 .10986 m
.00375 .10986 L
s
0 .13831 m
.00375 .13831 L
s
0 .16676 m
.00375 .16676 L
s
0 .22366 m
.00375 .22366 L
s
0 .25211 m
.00375 .25211 L
s
0 .28057 m
.00375 .28057 L
s
0 .33747 m
.00375 .33747 L
s
0 .36592 m
.00375 .36592 L
s
0 .39437 m
.00375 .39437 L
s
0 .45127 m
.00375 .45127 L
s
0 .47972 m
.00375 .47972 L
s
0 .50817 m
.00375 .50817 L
s
0 .05296 m
.00375 .05296 L
s
0 .02451 m
.00375 .02451 L
s
0 .56508 m
.00375 .56508 L
s
0 .59353 m
.00375 .59353 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.03258 .61178 m
.03258 .61803 L
s
.18401 .61178 m
.18401 .61803 L
s
.33545 .61178 m
.33545 .61803 L
s
.48688 .61178 m
.48688 .61803 L
s
.63831 .61178 m
.63831 .61803 L
s
.78974 .61178 m
.78974 .61803 L
s
.94117 .61178 m
.94117 .61803 L
s
.125 Mabswid
.06287 .61428 m
.06287 .61803 L
s
.09316 .61428 m
.09316 .61803 L
s
.12344 .61428 m
.12344 .61803 L
s
.15373 .61428 m
.15373 .61803 L
s
.2143 .61428 m
.2143 .61803 L
s
.24459 .61428 m
.24459 .61803 L
s
.27487 .61428 m
.27487 .61803 L
s
.30516 .61428 m
.30516 .61803 L
s
.36573 .61428 m
.36573 .61803 L
s
.39602 .61428 m
.39602 .61803 L
s
.4263 .61428 m
.4263 .61803 L
s
.45659 .61428 m
.45659 .61803 L
s
.51716 .61428 m
.51716 .61803 L
s
.54745 .61428 m
.54745 .61803 L
s
.57774 .61428 m
.57774 .61803 L
s
.60802 .61428 m
.60802 .61803 L
s
.6686 .61428 m
.6686 .61803 L
s
.69888 .61428 m
.69888 .61803 L
s
.72917 .61428 m
.72917 .61803 L
s
.75945 .61428 m
.75945 .61803 L
s
.82003 .61428 m
.82003 .61803 L
s
.85031 .61428 m
.85031 .61803 L
s
.8806 .61428 m
.8806 .61803 L
s
.91089 .61428 m
.91089 .61803 L
s
.0023 .61428 m
.0023 .61803 L
s
.97146 .61428 m
.97146 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08141 m
1 .08141 L
s
.99375 .19521 m
1 .19521 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .42282 m
1 .42282 L
s
.99375 .53663 m
1 .53663 L
s
.125 Mabswid
.99625 .10986 m
1 .10986 L
s
.99625 .13831 m
1 .13831 L
s
.99625 .16676 m
1 .16676 L
s
.99625 .22366 m
1 .22366 L
s
.99625 .25211 m
1 .25211 L
s
.99625 .28057 m
1 .28057 L
s
.99625 .33747 m
1 .33747 L
s
.99625 .36592 m
1 .36592 L
s
.99625 .39437 m
1 .39437 L
s
.99625 .45127 m
1 .45127 L
s
.99625 .47972 m
1 .47972 L
s
.99625 .50817 m
1 .50817 L
s
.99625 .05296 m
1 .05296 L
s
.99625 .02451 m
1 .02451 L
s
.99625 .56508 m
1 .56508 L
s
.99625 .59353 m
1 .59353 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.48688 0 m
.48688 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.05154 .58635 Mdot
.07987 .569 Mdot
.10875 .55129 Mdot
.13815 .53325 Mdot
.16801 .51492 Mdot
.1983 .49631 Mdot
.22897 .47745 Mdot
.25998 .45837 Mdot
.29128 .4391 Mdot
.32285 .41965 Mdot
.35463 .40006 Mdot
.3866 .38035 Mdot
.4187 .36054 Mdot
.45091 .34065 Mdot
.48317 .32072 Mdot
.51546 .30076 Mdot
.54774 .28081 Mdot
.57997 .26087 Mdot
.6121 .24098 Mdot
.6441 .22116 Mdot
.67593 .20143 Mdot
.70756 .18182 Mdot
.73894 .16236 Mdot
.77003 .14306 Mdot
.80079 .12395 Mdot
.83119 .10505 Mdot
.86118 .0864 Mdot
.89072 .06801 Mdot
.91976 .04992 Mdot
.94827 .03214 Mdot
.5 Mabswid
.02381 .60332 m
.05372 .58501 L
.08634 .56503 L
.11698 .54624 L
.14644 .52816 L
.1778 .5089 L
.20799 .49035 L
.24008 .47061 L
.27099 .45159 L
.30073 .43327 L
.33237 .41378 L
.36283 .395 L
.39213 .37693 L
.42332 .35769 L
.45333 .33915 L
.48525 .31944 L
.51599 .30044 L
.54556 .28215 L
.57703 .26269 L
.60732 .24394 L
.63951 .224 L
.67053 .20478 L
.70038 .18628 L
.73212 .16658 L
.76269 .14761 L
.79209 .12935 L
.82339 .1099 L
.85351 .09117 L
.88553 .07124 L
.91638 .05202 L
.94605 .03352 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`00000L0?oo
o`<00000703oool5000000<0oooo00<000000?ooo`3oool00P3oool3000001X0oooo0P00000L0?oo
o`D000000`3oool00`000000oooo0?ooo`020?ooo`<00000703oool3000001h0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`<00000303oool002P0oooo00<000000?ooo`3o
ool01`3oool01@000000oooo0?ooo`3oool0000001X0oooo00D000000?ooo`3oool0oooo0000000L
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`040000
003oool0oooo000001`0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0
000001X0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`00803oool5000000@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0B0?ooo`D000001@3oool00`000000oooo0?ooo`0C0?ooo`D000000`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000
7@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo000Y0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`00000N0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool002X0oooo00<000000?ooo`3oool01@3o
ool4000001/0oooo1000000L0?ooo`050000003oool0oooo0?ooo`0000001`3oool4000001T0oooo
00@000000?ooo`3oool000006`3oool01@000000oooo0?ooo`3oool0000000L0oooo1000000K0?oo
o`@00000803oool00`000000oooo0?ooo`050?ooo`@00000303oool002H0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`00
000K0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01d0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00d0
oooo000V0?ooo`D000001`3oool5000001X0oooo1@00000L0?ooo`<00000203oool5000001T0oooo
0P00000M0?ooo`<00000203oool5000001X0oooo1@00000K0?ooo`D000001`3oool5000000/0oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000T0?ooooP00000
103oool002@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo
07D0oooo00<000000?ooo`3oool0M@3oool2000000D0oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo
0?ooo`1b0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`00903oool2000007H0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`070?ooo`800000103oool002@0oooo00<00000
0?ooo`3oool0M@3oool00`000000oooo0?ooo`1_0?ooo`8000002`3oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo06h0oooo0`00000;0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool0K@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000
003oool0oooo07D0oooo00<000000?ooo`3oool0J`3oool2000000l0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1Y0?ooo`8000004@3o
ool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1e0?ooo`030000003oool0
oooo06P0oooo0P00000B0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000MP3oool00`00
0000oooo0?ooo`1V0?ooo`@000004@3oool2000000@0oooo000T0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0I03oool2000001H0oooo00<000000?ooo`3oool00P3oool002@0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?oo
o`1P0?ooo`<000006@3oool00`000000oooo0?ooo`020?ooo`002`3oool3000000<0oooo0P000004
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1O
0?ooo`<000006P3oool00`000000oooo0?ooo`020?ooo`00303oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool00P3oool000<0oooo1@0000000`3oool000000000
000300000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1L0?oo
o`8000007P3oool00`000000oooo0?ooo`020?ooo`002@3oool010000000oooo0?ooo`0000030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`800000MP3oool00`000000oooo0?ooo`1J0?ooo`8000007`3oool2000000@0oooo
000:0?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0M@3oool00`00
0000oooo0?ooo`1I0?ooo`8000008@3oool00`000000oooo0?ooo`020?ooo`002`3oool2000000<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1G0?ooo`@000008@3o
ool00`000000oooo0?ooo`020?ooo`00303oool00`000000oooo0?ooo`020?ooo`800000103oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo
07D0oooo00<000000?ooo`3oool0E03oool2000002H0oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1B0?ooo`800000:03oool00`000000
oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0540oooo
0`00000X0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000MP3oool00`000000oooo0?oo
o`1?0?ooo`800000:P3oool2000000@0oooo000T0?ooo`030000003oool0oooo07D0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo07D0oooo00<000000?ooo`3oool0C03oool2000002h0oooo00<000000?oo
o`3oool00P3oool002@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1:0?ooo`80
0000<03oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1e0?ooo`030000
003oool0oooo04X0oooo0P00000`0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0B03oool200000380oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`160?ooo`800000=03oool0
0`000000oooo0?ooo`020?ooo`00903oool2000007H0oooo00<000000?ooo`3oool0A03oool20000
03D0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0480
oooo0`00000g0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07D0oooo
00<000000?ooo`3oool0@03oool2000000030?ooo`000000000003L0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`0m0?ooo`800000?@3oool00`000000oooo0?ooo`020?ooo`00903oool00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo03/0oooo0P00000o0?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0>`3oool2000003l0
oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001f0?ooo`030000003oool0oooo03T0oooo
0P0000100?ooo`800000103oool002@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0M@3oool00`000000oooo0?ooo`0f0?ooo`800000A03oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo03<0oooo0`0000160?oo
o`030000003oool0oooo0080oooo00090?ooo`D000000`3oool2000000@0oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo03<0oooo0P0000170?ooo`03
0000003oool0oooo0080oooo000:0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0M@3oool00`000000oooo0?ooo`0a0?ooo`800000B@3oool00`000000oooo0?oo
o`020?ooo`000`3oool5000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1e0?ooo`030000003oool0oooo02l0oooo0P00001;0?ooo`030000003oool0oooo0080
oooo000<0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool2000007H0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`1:0?ooo`800000103oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool0:`3oool3000004h0oooo00<000000?ooo`3oool00P3oool000T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0:P3o
ool3000004l0oooo00<000000?ooo`3oool00P3oool000X0oooo0`0000040?ooo`800000103oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo
07D0oooo00<000000?ooo`3oool09`3oool2000005<0oooo00<000000?ooo`3oool00P3oool002@0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0U0?ooo`800000E@3oool00`000000
oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo02<0oooo
0P00001G0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000MP3oool00`000000oooo0?oo
o`0R0?ooo`<00000EP3oool2000000@0oooo000T0?ooo`030000003oool0oooo07D0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo07D0oooo00<000000?ooo`3oool07`3oool2000005/0oooo00<000000?oo
o`3oool00P3oool002@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0M0?ooo`80
0000G@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1e0?ooo`030000
003oool0oooo01`0oooo0P00001N0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool06P3oool4000005h0oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001f0?ooo`030000003oool0oooo
01L0oooo0P00001R0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0M@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool00P3oool002@0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0D0?ooo`800000IP3oool00`000000oooo
0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo01<0oooo0`00
001V0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07D0oooo00<00000
0?ooo`3oool04@3oool2000006T0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?oo
o`3oool0M@3oool00`000000oooo0?ooo`0?0?ooo`800000J`3oool00`000000oooo0?ooo`020?oo
o`00903oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00d0oooo0P00001]0?ooo`03
0000003oool0oooo0080oooo000T0?ooo`800000MP3oool00`000000oooo0?ooo`0;0?ooo`<00000
K@3oool2000000@0oooo000T0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool02P3o
ool010000000oooo00000000001^0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0203oool200000780oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`060?ooo`800000M03oool0
0`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`007@3oool2000000D0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`030?ooo`<00000MP3oool00`000000
oooo0?ooo`020?ooo`00703oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool00P3oool010000000oooo00000000001f0?ooo`030000003oool0oooo
0080oooo000L0?ooo`040000003oool0oooo000000@0oooon00000040?ooo`00703oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo07D0oooo00<000000?ooo`000000O03oool00`00
0000oooo0?ooo`020?ooo`00703oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
07D0oooo0P00001m0?ooo`030000003oool0oooo0080oooo000L0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0M03oool2000007h0oooo00<000000?ooo`3oool00P3oool001d0
oooo0P0000050?ooo`030000003oool0oooo0780oooo1000001n0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo0700oooo0P0000030?ooo`030000003oool0oooo07`0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0KP3oool2000000D0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`020?ooo`00903oool2000006d0oooo0P000007
0?ooo`030000003oool0oooo07/0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1[0?oo
o`<000001`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0080oooo000T0?ooo`03
0000003oool0oooo06T0oooo0P0000000`3oool00000000000070?ooo`030000003oool0oooo07`0
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07`0oooo00<0
00000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0I03oool3000000h0oooo00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1T0?oo
o`8000003`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0080oooo000T0?ooo`80
0000H`3oool200000140oooo00<000000?ooo`3oool0N`3oool2000000@0oooo000T0?ooo`030000
003oool0oooo0600oooo0P00000C0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0G03oool3
000001H0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`020?ooo`00903oool00`00
0000oooo0?ooo`1K0?ooo`<000005`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1l0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo05P0oooo
0P00000K0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00
001G0?ooo`8000007@3oool00`000000oooo0?ooo`1k0?ooo`800000103oool002@0oooo00<00000
0?ooo`3oool0E03oool2000001l0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`1C0?ooo`<000007`3oool00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo0540oooo0P00000R0?ooo`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0
D03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
0P3oool000T0oooo1@0000030?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003o
ool0oooo04h0oooo0P00000U0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool00P3o
ool000X0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1<0?oo
o`8000009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0080oooo000;0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo0P00001<0?ooo`<000009`3oool00`000000oooo0?oo
o`1k0?ooo`800000103oool000`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo04T0oooo0P00000Z0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool00P3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo0080oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`160?ooo`800000;@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
0080oooo000:0?ooo`<00000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000
oooo0?ooo`140?ooo`800000;`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo04<0oooo0`00000_0?ooo`030000003oool0oooo07`0oooo
00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0@@3oool200000380oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`020?ooo`00903oool200000400oooo0P00000d
0?ooo`030000003oool0oooo07/0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`020?oo
o`00903oool00`000000oooo0?ooo`0l0?ooo`800000=`3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo03X0oooo1000000g0?ooo`030000
003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0=`3oool2000003`0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0e0?ooo`800000?P3oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000=@3oool3000003h0
oooo00<000000?ooo`3oool0N`3oool2000000@0oooo000T0?ooo`030000003oool0oooo0380oooo
0P0000110?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo07`0oooo00<0
00000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0;`3oool2000004@0oooo00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0]0?oo
o`800000AP3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0080oooo000T0?ooo`03
0000003oool0oooo02`0oooo0`0000160?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0:P3oool2000004T0oooo00<000000?ooo`3oool0
O03oool00`000000oooo0?ooo`020?ooo`00903oool2000002T0oooo0P00001;0?ooo`030000003o
ool0oooo07/0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`020?ooo`00903oool00`00
0000oooo0?ooo`0U0?ooo`<00000C@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo02<0oooo0P0000000`3oool000000000001=0?ooo`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
0P3oool000/0oooo0`0000030?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003o
ool0oooo0200oooo0P00001C0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool00P3o
ool000`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0
oooo0P00001E0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool000T0oooo
1@0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`8000007P3oool3000005D0oooo00<000000?ooo`3oool0N`3oool2
000000@0oooo00090?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool00P3oool000X0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`02
0?ooo`002`3oool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06@3oool2000005X0oooo
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`020?ooo`00303oool00`000000oooo0?oo
o`020?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo01L0oooo0P00
001L0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool05@3oool4000005`0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`0C0?ooo`800000H03oool00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo0080oooo000T0?ooo`8000004P3oool200000680oooo00<000000?ooo`3o
ool0N`3oool2000000@0oooo000T0?ooo`030000003oool0oooo0100oooo0P00001S0?ooo`030000
003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool03P3o
ool4000006<0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`020?ooo`00903oool0
0`000000oooo0?ooo`0<0?ooo`800000I`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo0080oooo000T0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo00T0
oooo0P00001Z0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool002@0oooo
00<000000?ooo`3oool0203oool3000006X0oooo00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`020?ooo`00903oool2000000L0oooo0P00001]0?ooo`030000003oool0oooo07/0oooo0P00
00040?ooo`00903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06d0oooo00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo06h0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`020?oo
o`00903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1e0?ooo`030000
003oool0oooo07`0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool002@0oooon00000040?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=P3o
ool3000008X0oooo00<000000?ooo`3oool0:`3oool3000001D0oooo00<000000?ooo`3oool0503o
ool003L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool04`3oool00340oooo0`0000030?ooo`<00000103oool20000
0080oooo1@0000020?ooo`<000000`3oool4000000030?ooo`000000000000<000001`3oool30000
00@0oooo100000030?ooo`8000000P3oool6000000H0oooo100000020?ooo`D0000000<0oooo0000
000000000`0000000`3oool000000000000300000080oooo0`0000020?ooo`<00000103oool30000
0080oooo0`000000103oool000000000003oool3000000<0oooo0`0000090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000000`3oool4000000<0oooo00<000000?ooo`3oool00P3oool3
00000080oooo1@0000020?ooo`<000000P3oool3000000040?ooo`00000000000?ooo`@000000`3o
ool200000080oooo2P0000050?ooo`030000003oool0oooo0180oooo000`0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000303o
ool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000
103oool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000060?oo
o`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0180oooo000`0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`<00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0`000003
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`3oool500000080oooo00<000000?ooo`3oool00P3oool500000080oooo00H000000?ooo`3o
ool000000?ooo`0000050?ooo`D00000203oool00`000000oooo0?ooo`020?ooo`050000003oool0
00000?ooo`0000000P3oool3000000<0oooo00<000000?ooo`0000000P3oool5000000<0oooo00@0
00000?ooo`3oool0oooo1@0000020?ooo`060000003oool0oooo0000003oool000000`3oool01000
0000oooo0?ooo`0000050?ooo`040000003oool0oooo00000080oooo0`0000050?ooo`030000003o
ool0oooo0180oooo000`0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`<0
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo
00@000000?ooo`3oool000001@3oool01P000000oooo0?ooo`000000oooo000000P0oooo00<00000
0?ooo`3oool04P3oool00300oooo00H000000?ooo`3oool0oooo0000003oool400000080oooo1000
00020?ooo`<00000103oool3000000<0oooo0P0000050?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool000000P3oool2000000<0oooo100000030?ooo`<000002@3oool01@000000oooo
0?ooo`000000oooo00<00000103oool400000080oooo100000020?ooo`<000000P3oool200000003
0?ooo`00000000000080oooo0`0000020?ooo`@000000`3oool3000000<0oooo0`0000090?ooo`03
0000003oool0oooo0080oooo1P0000000`3oool00000000000030?ooo`80000000<0oooo00000000
00000P3oool3000000@0oooo00<000000?ooo`3oool00P3oool300000080oooo100000030?ooo`T0
00000`3oool3000000<0oooo100000040?ooo`030000003oool0oooo0180oooo000`0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`00<@3oool30000
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`<000002@3oool40000
00T0oooo00<000000?ooo`3oool00P3oool2000000X0oooo100000040?ooo`030000003oool0oooo
00@0oooo0P0000040?ooo`800000;P3oool00`000000oooo0?ooo`0H0?ooo`<000005P3oool00`00
0000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`0D0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.4691, -6290.32, \
0.0667933, 71.1017}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindInterference[Join[wave1,wave2]];", "Input",
  CellLabel->"In[73]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.518324 0.0646861 0.0146766 0.00134787 [
[.00084 -0.0125 -6 -9 ]
[.00084 -0.0125 6 0 ]
[.13021 -0.0125 -6 -9 ]
[.13021 -0.0125 6 0 ]
[.25958 -0.0125 -6 -9 ]
[.25958 -0.0125 6 0 ]
[.38895 -0.0125 -6 -9 ]
[.38895 -0.0125 6 0 ]
[.51832 -0.0125 -3 -9 ]
[.51832 -0.0125 3 0 ]
[.6477 -0.0125 -3 -9 ]
[.6477 -0.0125 3 0 ]
[.77707 -0.0125 -3 -9 ]
[.77707 -0.0125 3 0 ]
[.90644 -0.0125 -3 -9 ]
[.90644 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01468 -6 -4.5 ]
[-0.0125 .01468 0 4.5 ]
[-0.0125 .14946 -18 -4.5 ]
[-0.0125 .14946 0 4.5 ]
[-0.0125 .28425 -18 -4.5 ]
[-0.0125 .28425 0 4.5 ]
[-0.0125 .41904 -18 -4.5 ]
[-0.0125 .41904 0 4.5 ]
[-0.0125 .55382 -18 -4.5 ]
[-0.0125 .55382 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -66 0 ]
[.5 .63053 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00084 0 m
.00084 .00625 L
s
[(-8)] .00084 -0.0125 0 1 Mshowa
.13021 0 m
.13021 .00625 L
s
[(-6)] .13021 -0.0125 0 1 Mshowa
.25958 0 m
.25958 .00625 L
s
[(-4)] .25958 -0.0125 0 1 Mshowa
.38895 0 m
.38895 .00625 L
s
[(-2)] .38895 -0.0125 0 1 Mshowa
.51832 0 m
.51832 .00625 L
s
[(0)] .51832 -0.0125 0 1 Mshowa
.6477 0 m
.6477 .00625 L
s
[(2)] .6477 -0.0125 0 1 Mshowa
.77707 0 m
.77707 .00625 L
s
[(4)] .77707 -0.0125 0 1 Mshowa
.90644 0 m
.90644 .00625 L
s
[(6)] .90644 -0.0125 0 1 Mshowa
.125 Mabswid
.03318 0 m
.03318 .00375 L
s
.06552 0 m
.06552 .00375 L
s
.09786 0 m
.09786 .00375 L
s
.16255 0 m
.16255 .00375 L
s
.19489 0 m
.19489 .00375 L
s
.22724 0 m
.22724 .00375 L
s
.29192 0 m
.29192 .00375 L
s
.32427 0 m
.32427 .00375 L
s
.35661 0 m
.35661 .00375 L
s
.42129 0 m
.42129 .00375 L
s
.45364 0 m
.45364 .00375 L
s
.48598 0 m
.48598 .00375 L
s
.55067 0 m
.55067 .00375 L
s
.58301 0 m
.58301 .00375 L
s
.61535 0 m
.61535 .00375 L
s
.68004 0 m
.68004 .00375 L
s
.71238 0 m
.71238 .00375 L
s
.74473 0 m
.74473 .00375 L
s
.80941 0 m
.80941 .00375 L
s
.84175 0 m
.84175 .00375 L
s
.8741 0 m
.8741 .00375 L
s
.93878 0 m
.93878 .00375 L
s
.97113 0 m
.97113 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01468 m
.00625 .01468 L
s
[(0)] -0.0125 .01468 1 0 Mshowa
0 .14946 m
.00625 .14946 L
s
[(100)] -0.0125 .14946 1 0 Mshowa
0 .28425 m
.00625 .28425 L
s
[(200)] -0.0125 .28425 1 0 Mshowa
0 .41904 m
.00625 .41904 L
s
[(300)] -0.0125 .41904 1 0 Mshowa
0 .55382 m
.00625 .55382 L
s
[(400)] -0.0125 .55382 1 0 Mshowa
.125 Mabswid
0 .04163 m
.00375 .04163 L
s
0 .06859 m
.00375 .06859 L
s
0 .09555 m
.00375 .09555 L
s
0 .12251 m
.00375 .12251 L
s
0 .17642 m
.00375 .17642 L
s
0 .20338 m
.00375 .20338 L
s
0 .23034 m
.00375 .23034 L
s
0 .25729 m
.00375 .25729 L
s
0 .31121 m
.00375 .31121 L
s
0 .33816 m
.00375 .33816 L
s
0 .36512 m
.00375 .36512 L
s
0 .39208 m
.00375 .39208 L
s
0 .44599 m
.00375 .44599 L
s
0 .47295 m
.00375 .47295 L
s
0 .49991 m
.00375 .49991 L
s
0 .52687 m
.00375 .52687 L
s
0 .58078 m
.00375 .58078 L
s
0 .60774 m
.00375 .60774 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00084 .61178 m
.00084 .61803 L
s
.13021 .61178 m
.13021 .61803 L
s
.25958 .61178 m
.25958 .61803 L
s
.38895 .61178 m
.38895 .61803 L
s
.51832 .61178 m
.51832 .61803 L
s
.6477 .61178 m
.6477 .61803 L
s
.77707 .61178 m
.77707 .61803 L
s
.90644 .61178 m
.90644 .61803 L
s
.125 Mabswid
.03318 .61428 m
.03318 .61803 L
s
.06552 .61428 m
.06552 .61803 L
s
.09786 .61428 m
.09786 .61803 L
s
.16255 .61428 m
.16255 .61803 L
s
.19489 .61428 m
.19489 .61803 L
s
.22724 .61428 m
.22724 .61803 L
s
.29192 .61428 m
.29192 .61803 L
s
.32427 .61428 m
.32427 .61803 L
s
.35661 .61428 m
.35661 .61803 L
s
.42129 .61428 m
.42129 .61803 L
s
.45364 .61428 m
.45364 .61803 L
s
.48598 .61428 m
.48598 .61803 L
s
.55067 .61428 m
.55067 .61803 L
s
.58301 .61428 m
.58301 .61803 L
s
.61535 .61428 m
.61535 .61803 L
s
.68004 .61428 m
.68004 .61803 L
s
.71238 .61428 m
.71238 .61803 L
s
.74473 .61428 m
.74473 .61803 L
s
.80941 .61428 m
.80941 .61803 L
s
.84175 .61428 m
.84175 .61803 L
s
.8741 .61428 m
.8741 .61803 L
s
.93878 .61428 m
.93878 .61803 L
s
.97113 .61428 m
.97113 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01468 m
1 .01468 L
s
.99375 .14946 m
1 .14946 L
s
.99375 .28425 m
1 .28425 L
s
.99375 .41904 m
1 .41904 L
s
.99375 .55382 m
1 .55382 L
s
.125 Mabswid
.99625 .04163 m
1 .04163 L
s
.99625 .06859 m
1 .06859 L
s
.99625 .09555 m
1 .09555 L
s
.99625 .12251 m
1 .12251 L
s
.99625 .17642 m
1 .17642 L
s
.99625 .20338 m
1 .20338 L
s
.99625 .23034 m
1 .23034 L
s
.99625 .25729 m
1 .25729 L
s
.99625 .31121 m
1 .31121 L
s
.99625 .33816 m
1 .33816 L
s
.99625 .36512 m
1 .36512 L
s
.99625 .39208 m
1 .39208 L
s
.99625 .44599 m
1 .44599 L
s
.99625 .47295 m
1 .47295 L
s
.99625 .49991 m
1 .49991 L
s
.99625 .52687 m
1 .52687 L
s
.99625 .58078 m
1 .58078 L
s
.99625 .60774 m
1 .60774 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.51832 0 m
.51832 .61803 L
s
[(Interference Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .02515 m
.02403 .37828 L
.02423 .05275 L
.02447 .30876 L
.02469 .02379 L
.02489 .21691 L
.02508 .09224 L
.02529 .02192 L
.02551 .22103 L
.02573 .48514 L
.02596 .18034 L
.02619 .4791 L
.02639 .3918 L
.02663 .32056 L
.02677 .15396 L
.02689 .3276 L
.02714 .47214 L
.02736 .02403 L
.02759 .47647 L
.0278 .47298 L
.02804 .12104 L
.02828 .0843 L
.02853 .10931 L
.02876 .32821 L
.02889 .48227 L
.02901 .07207 L
.02915 .11334 L
.02928 .43912 L
.0295 .10069 L
.02974 .48794 L
.02994 .17225 L
.03016 .48121 L
.0304 .14123 L
.03053 .03689 L
.03065 .40663 L
.03087 .41414 L
.03111 .22909 L
.03123 .36445 L
.03137 .44741 L
.03161 .14686 L
.03185 .23555 L
.03206 .12987 L
.0323 .4575 L
.03243 .12067 L
.03256 .39564 L
.03269 .36939 L
.03281 .33439 L
.03295 .46142 L
.03308 .28013 L
.0333 .46348 L
Mistroke
.03354 .0238 L
.03376 .13477 L
.03396 .235 L
.03419 .42535 L
.03433 .06844 L
.03445 .48778 L
.03468 .15194 L
.03491 .48625 L
.03505 .17789 L
.03517 .29793 L
.03541 .36268 L
.03554 .02348 L
.03566 .47149 L
.0358 .15981 L
.03594 .12902 L
.03618 .2923 L
.0364 .08297 L
.03664 .41013 L
.03677 .4701 L
.0369 .05985 L
.03702 .48326 L
.03716 .25134 L
.0374 .04107 L
.03755 .24024 L
.03769 .14838 L
.03782 .31926 L
.03796 .48685 L
.03809 .31191 L
.03824 .45816 L
.03839 .29699 L
.03854 .25939 L
.03867 .49078 L
.0388 .03224 L
.03894 .05144 L
.03907 .35685 L
.03929 .3628 L
.03952 .11136 L
.03974 .25828 L
.03994 .11251 L
.04016 .0395 L
.0404 .10781 L
.04053 .31276 L
.04066 .03091 L
.04089 .47521 L
.04102 .17771 L
.04114 .48152 L
.04128 .227 L
.04142 .0955 L
.04165 .35502 L
.04178 .45345 L
Mistroke
.04191 .07105 L
.04214 .42909 L
.04235 .34507 L
.0426 .12618 L
.04283 .38318 L
.04305 .20647 L
.04325 .37666 L
.04348 .27053 L
.04369 .22277 L
.04389 .42334 L
.04408 .49066 L
.04428 .15467 L
.0445 .1168 L
.04471 .16789 L
.04494 .38483 L
.04516 .23188 L
.04536 .37591 L
.04559 .10329 L
.04573 .48164 L
.04585 .02771 L
.04607 .21507 L
.04631 .09904 L
.04653 .08364 L
.04676 .48591 L
.04701 .36201 L
.04724 .3216 L
.04745 .31957 L
.04765 .12891 L
.04787 .48296 L
.04808 .43685 L
.04831 .10525 L
.04856 .31196 L
.04877 .47644 L
.049 .02117 L
.04925 .05856 L
.04939 .19962 L
.04951 .37683 L
.04976 .20419 L
.04999 .2706 L
.05021 .29033 L
.05041 .40702 L
.05064 .1231 L
.05085 .30442 L
.05105 .31452 L
.05123 .45267 L
.05143 .0224 L
.05165 .03837 L
.05186 .0352 L
.05209 .42238 L
.05231 .47752 L
Mistroke
.05251 .02952 L
.05274 .48044 L
.05287 .06839 L
.05299 .49488 L
.05321 .34554 L
.05345 .29331 L
.05368 .42344 L
.05392 .47576 L
.05416 .08624 L
.05438 .19599 L
.05459 .23025 L
.05479 .34066 L
.05501 .0208 L
.05523 .03596 L
.05546 .48101 L
.0557 .34674 L
.05591 .14969 L
.05614 .43934 L
.05639 .4878 L
.05653 .47462 L
.05666 .0234 L
.0569 .10339 L
.05714 .44174 L
.05734 .04534 L
.05755 .02852 L
.05778 .47196 L
.058 .46969 L
.0582 .02076 L
.05838 .09067 L
.05858 .26453 L
.05879 .37896 L
.05901 .35176 L
.05924 .085 L
.05946 .17341 L
.05965 .31757 L
.05989 .18834 L
.06002 .10207 L
.06014 .24656 L
.06036 .48452 L
.0606 .02242 L
.06082 .45585 L
.06107 .41846 L
.06131 .03593 L
.06153 .02831 L
.06174 .05317 L
.06194 .48156 L
.06217 .08787 L
.06238 .15192 L
.06261 .332 L
.06283 .3854 L
Mistroke
.06305 .41233 L
.0633 .48719 L
.06343 .19582 L
.06355 .48961 L
.06369 .44253 L
.06382 .02501 L
.06405 .46176 L
.06429 .39268 L
.06451 .37069 L
.06471 .03779 L
.06493 .06091 L
.06517 .29883 L
.0654 .33996 L
.06565 .22533 L
.06586 .10437 L
.06609 .45522 L
.06631 .33196 L
.06651 .24608 L
.06674 .41467 L
.06695 .37541 L
.06715 .27471 L
.06734 .46127 L
.06754 .03904 L
.06775 .02875 L
.06798 .48955 L
.06823 .48269 L
.06847 .02746 L
.06869 .11901 L
.0689 .06884 L
.0691 .33493 L
.06931 .49304 L
.06954 .02169 L
.06977 .49557 L
.07002 .46944 L
.07023 .34603 L
.07046 .24812 L
.07071 .30855 L
.07085 .43899 L
.07098 .13142 L
.07122 .0352 L
.07146 .47208 L
.07166 .11928 L
.07188 .31883 L
.07211 .33136 L
.07232 .32415 L
.07252 .34897 L
.07271 .48083 L
.07292 .40709 L
.07312 .02168 L
.07333 .02289 L
Mistroke
.07357 .49424 L
.07378 .48751 L
.07398 .03718 L
.07421 .48051 L
.07434 .22239 L
.07446 .45791 L
.07469 .19465 L
.07492 .38939 L
.07515 .2064 L
.07528 .47371 L
.0754 .19397 L
.07562 .02321 L
.07586 .49311 L
.07607 .44496 L
.07626 .07767 L
.07648 .05225 L
.07671 .46518 L
.07695 .04267 L
.07708 .4328 L
.0772 .034 L
.07745 .01962 L
.07759 .08018 L
.07771 .4655 L
.07794 .25777 L
.07819 .43541 L
.07842 .06911 L
.07863 .051 L
.07883 .38396 L
.07905 .39131 L
.07925 .35575 L
.07943 .49839 L
.07965 .49438 L
.07989 .08977 L
.08011 .36556 L
.08032 .01947 L
.08055 .46559 L
.08077 .48726 L
.08097 .0984 L
.08118 .30516 L
.08141 .08845 L
.08166 .08516 L
.08187 .40422 L
.0821 .024 L
.08235 .22059 L
.08257 .03884 L
.08269 .3984 L
.08283 .02455 L
.08296 .26576 L
.08309 .31724 L
.08333 .20603 L
Mistroke
.08354 .2837 L
.08379 .45352 L
.08403 .09874 L
.08424 .03752 L
.08447 .09409 L
.08468 .02299 L
.08487 .29413 L
.0851 .49831 L
.08535 .30896 L
.08558 .37825 L
.08579 .49021 L
.08602 .14325 L
.08627 .4768 L
.0865 .03975 L
.08671 .27727 L
.08696 .49303 L
.0871 .43965 L
.08723 .03433 L
.08746 .49633 L
.08758 .23482 L
.08772 .46148 L
.08784 .04311 L
.08798 .41685 L
.08822 .28922 L
.08835 .02445 L
.08848 .46164 L
.08862 .16354 L
.08876 .21704 L
.08889 .3072 L
.08903 .50022 L
.08916 .0599 L
.08928 .4539 L
.08951 .39161 L
.08975 .3183 L
.08998 .48247 L
.09023 .4607 L
.09046 .09448 L
.09068 .09788 L
.09089 .17395 L
.09109 .17243 L
.09132 .45892 L
.09153 .26557 L
.09176 .38439 L
.09201 .47929 L
.09222 .19915 L
.09245 .49094 L
.0927 .43225 L
.09283 .10007 L
.09296 .34582 L
.09308 .01886 L
Mistroke
.09322 .45779 L
.09344 .07534 L
.09366 .22989 L
.09386 .31669 L
.09408 .39008 L
.09432 .10545 L
.09455 .38012 L
.0948 .10834 L
.09501 .02823 L
.09524 .34956 L
.09546 .35269 L
.09566 .24146 L
.09587 .42452 L
.0961 .01934 L
.09632 .0799 L
.09651 .35817 L
.0967 .50171 L
.0969 .01873 L
.09713 .34412 L
.09738 .14765 L
.09762 .39258 L
.09784 .38129 L
.09805 .42915 L
.09825 .02064 L
.09848 .2552 L
.09869 .06472 L
.09892 .49763 L
.09917 .35415 L
.09938 .06762 L
.09961 .48859 L
.09986 .3193 L
.1 .08657 L
.10013 .44672 L
.10037 .45115 L
.10061 .17459 L
.10081 .31792 L
.10103 .37049 L
.10124 .19652 L
.10147 .49672 L
.10168 .48718 L
.10188 .12194 L
.10208 .30587 L
.10227 .48856 L
.10248 .44662 L
.10271 .29578 L
.10291 .19265 L
.10313 .0958 L
.10326 .23474 L
.10338 .07703 L
.10362 .34792 L
Mistroke
.10384 .37665 L
.10407 .01903 L
.1043 .36538 L
.10443 .06528 L
.10455 .20109 L
.10477 .31243 L
.10501 .27994 L
.10521 .5032 L
.10541 .06683 L
.10563 .14938 L
.10586 .21195 L
.10609 .43534 L
.10622 .26376 L
.10635 .42806 L
.1066 .49452 L
.10673 .30323 L
.10686 .25987 L
.10709 .09549 L
.10734 .07797 L
.10755 .39959 L
.10778 .01823 L
.10799 .1157 L
.10822 .10828 L
.10844 .04737 L
.10863 .50385 L
.10886 .24812 L
.10911 .47612 L
.10934 .01956 L
.10956 .01873 L
.10978 .02817 L
.10999 .26872 L
.11017 .10341 L
.11038 .4498 L
.1106 .48701 L
.11083 .15506 L
.11103 .29299 L
.11124 .2533 L
.11149 .02855 L
.11172 .3819 L
.11184 .44463 L
.11197 .23334 L
.11211 .01849 L
.11224 .49146 L
.11247 .02841 L
.11269 .01818 L
.11293 .50186 L
.11318 .44913 L
.11339 .17199 L
.11361 .43747 L
.11382 .2142 L
Mistroke
.11402 .50299 L
.11424 .24025 L
.11449 .50179 L
.11472 .0549 L
.11494 .19747 L
.11517 .04323 L
.11541 .16799 L
.11564 .14968 L
.11585 .01987 L
.1161 .21591 L
.11624 .43471 L
.11637 .16344 L
.11661 .31976 L
.11673 .01827 L
.11686 .40138 L
.11699 .14684 L
.11712 .08322 L
.11736 .50438 L
.1175 .20214 L
.11762 .40059 L
.11776 .48284 L
.11791 .50121 L
.11803 .02288 L
.11817 .2433 L
.1183 .39898 L
.11842 .40237 L
.11865 .05243 L
.11889 .49362 L
.11912 .15918 L
.11937 .39335 L
.1196 .08403 L
.11982 .07979 L
.12004 .03158 L
.12023 .48609 L
.12046 .4078 L
.12067 .50587 L
.1209 .05983 L
.12115 .37767 L
.12136 .49316 L
.12159 .20606 L
.12184 .44544 L
.12198 .49037 L
.12211 .03999 L
.12235 .32064 L
.12259 .0966 L
.12278 .4677 L
.123 .44633 L
.12323 .06042 L
.12345 .17539 L
.12363 .03326 L
Mistroke
.12383 .40195 L
.12405 .29712 L
.12424 .33147 L
.12446 .42361 L
.12469 .02225 L
.12491 .03147 L
.1251 .43512 L
.12534 .23744 L
.12547 .42951 L
.12559 .35002 L
.12581 .19118 L
.12604 .27477 L
.12627 .49162 L
.12652 .38765 L
.12676 .31989 L
.12698 .43859 L
.12719 .50551 L
.12739 .206 L
.12762 .05534 L
.12783 .38156 L
.12806 .01769 L
.12831 .39024 L
.12852 .41482 L
.12875 .46333 L
.129 .37681 L
.12914 .06246 L
.12927 .50298 L
.12951 .19313 L
.12975 .50621 L
.12994 .06031 L
.13016 .1289 L
.13039 .0259 L
.13061 .1144 L
.1308 .09954 L
.13102 .06306 L
.13122 .40481 L
.13141 .46786 L
.13162 .39437 L
.13186 .38452 L
.13208 .49535 L
.13227 .07521 L
.1325 .10154 L
.13275 .06675 L
.13299 .31051 L
.13321 .12782 L
.13345 .46131 L
.13367 .33006 L
.13388 .26976 L
.13409 .1209 L
.13433 .49557 L
Mistroke
.13455 .50531 L
.13479 .12117 L
.13492 .50584 L
.13505 .07821 L
.13526 .49027 L
.13548 .50064 L
.13566 .41335 L
.13587 .23414 L
.13609 .28562 L
.13633 .31941 L
.13654 .4136 L
.13676 .38244 L
.13689 .32275 L
.13702 .48582 L
.13727 .01915 L
.1374 .38851 L
.13755 .43646 L
.13769 .42463 L
.13781 .2143 L
.13806 .43596 L
.1382 .06765 L
.13832 .48971 L
.13856 .06239 L
.13881 .4042 L
.13905 .16574 L
.13918 .10176 L
.13931 .2559 L
.13954 .5047 L
.13978 .02434 L
.14 .03588 L
.1402 .49163 L
.14043 .50663 L
.14067 .03334 L
.1409 .16883 L
.14103 .27639 L
.14115 .044 L
.1414 .20679 L
.14154 .4926 L
.14167 .01816 L
.14188 .12714 L
.14212 .20554 L
.14236 .10467 L
.14259 .02549 L
.14272 .47262 L
.14287 .48632 L
.143 .03257 L
.14312 .46126 L
.14336 .29159 L
.1436 .48735 L
.14373 .06108 L
Mistroke
.14387 .43238 L
.14412 .41932 L
.14426 .20105 L
.14441 .34689 L
.14454 .18526 L
.14469 .3882 L
.14481 .03323 L
.14494 .50783 L
.14517 .08275 L
.14531 .50465 L
.14545 .44884 L
.14557 .37824 L
.14571 .30098 L
.14595 .15149 L
.14608 .51033 L
.14621 .13946 L
.14645 .38007 L
.14667 .5052 L
.14689 .47434 L
.14713 .31684 L
.14733 .13574 L
.14754 .01938 L
.14778 .34795 L
.14799 .1732 L
.14813 .22043 L
.14825 .17065 L
.14849 .47178 L
.14872 .02796 L
.14886 .50487 L
.14898 .14161 L
.1492 .06576 L
.14944 .34871 L
.14965 .03089 L
.14985 .48089 L
.15007 .35242 L
.1503 .44473 L
.15055 .40224 L
.15069 .11113 L
.15082 .39788 L
.15106 .07111 L
.15118 .42637 L
.15131 .02528 L
.15154 .1123 L
.15179 .16734 L
.15202 .07355 L
.15223 .08113 L
.15243 .42484 L
.15265 .21217 L
.15286 .27845 L
.15304 .24831 L
Mistroke
.15326 .3875 L
.1535 .0401 L
.15372 .07946 L
.15393 .3554 L
.15414 .50157 L
.15434 .12465 L
.15456 .24756 L
.15479 .07879 L
.15504 .24363 L
.15527 .04302 L
.15548 .28129 L
.15571 .05175 L
.15583 .24535 L
.15596 .27373 L
.15619 .01834 L
.15644 .2292 L
.15658 .46158 L
.15671 .15272 L
.15695 .39902 L
.15717 .49414 L
.15729 .14799 L
.15742 .44077 L
.15766 .15673 L
.15787 .49007 L
.15811 .06082 L
.15835 .51113 L
.15858 .30975 L
.1588 .51287 L
.15899 .18868 L
.15921 .45271 L
.15943 .30245 L
.15968 .50884 L
.15991 .47438 L
.16003 .01797 L
.16017 .40514 L
.16042 .36258 L
.16065 .49225 L
.16089 .15292 L
.1611 .16105 L
.16133 .01788 L
.16147 .23635 L
.1616 .37696 L
.16184 .01673 L
.16198 .31341 L
.16211 .14473 L
.16225 .02542 L
.1624 .01772 L
.16264 .45334 L
.16287 .12911 L
.16301 .47103 L
Mistroke
.16313 .37831 L
.16326 .28719 L
.1634 .02665 L
.16363 .40034 L
.16376 .06994 L
.16388 .14674 L
.1641 .04245 L
.16434 .48957 L
.16456 .45849 L
.16476 .13055 L
.16497 .471 L
.1652 .21649 L
.16545 .50498 L
.16559 .23967 L
.16572 .28359 L
.16595 .12942 L
.16609 .27094 L
.16621 .01629 L
.16643 .12843 L
.16668 .1646 L
.16691 .06717 L
.16713 .07869 L
.16733 .37671 L
.16754 .11997 L
.16774 .41106 L
.16793 .39572 L
.16815 .50607 L
.16838 .0371 L
.16861 .0203 L
.16881 .50114 L
.16902 .32797 L
.16922 .38132 L
.16944 .4854 L
.16968 .03341 L
.16991 .23757 L
.17016 .23677 L
.17037 .41149 L
.17059 .50331 L
.17084 .06577 L
.17107 .23662 L
.1712 .49557 L
.17133 .02423 L
.17147 .42691 L
.17159 .04578 L
.17183 .47749 L
.17205 .17972 L
.17217 .45681 L
.1723 .09609 L
.17254 .19199 L
.17277 .33276 L
Mistroke
.17298 .01812 L
.17323 .44675 L
.17345 .47266 L
.17365 .07832 L
.17386 .50942 L
.17409 .48447 L
.1743 .18618 L
.17455 .21098 L
.17478 .21932 L
.1749 .06154 L
.17504 .34417 L
.17528 .25374 L
.17551 .43252 L
.17576 .10772 L
.17596 .47117 L
.17619 .51587 L
.17633 .15872 L
.17646 .38978 L
.17671 .21612 L
.17685 .09069 L
.17697 .29555 L
.17711 .01617 L
.17726 .02145 L
.17739 .4891 L
.17753 .14035 L
.17767 .34549 L
.17779 .02831 L
.17802 .08097 L
.17826 .43241 L
.17849 .24114 L
.17862 .23651 L
.17874 .49779 L
.17897 .37139 L
.1792 .49417 L
.17941 .10937 L
.17961 .44472 L
.17982 .08094 L
.18005 .35586 L
.18029 .5168 L
.18042 .01892 L
.18054 .33729 L
.18079 .05731 L
.18093 .46137 L
.18106 .01968 L
.18128 .01613 L
.18153 .50544 L
.18176 .30102 L
.18197 .49117 L
.18217 .28511 L
.18239 .5037 L
Mistroke
.18259 .13934 L
.18277 .25208 L
.18299 .51609 L
.18323 .19082 L
.18345 .29748 L
.18366 .23775 L
.18389 .50231 L
.18411 .32783 L
.18431 .51109 L
.18452 .20394 L
.18475 .48191 L
.185 .02361 L
.18521 .50608 L
.18544 .37573 L
.18569 .29051 L
.18591 .41689 L
.18603 .5144 L
.18616 .02093 L
.1863 .35852 L
.18643 .08599 L
.18667 .48009 L
.18688 .14679 L
.18712 .5186 L
.18737 .11308 L
.18758 .24972 L
.18781 .26016 L
.18802 .48023 L
.18821 .50938 L
.18844 .47833 L
.18868 .10777 L
.18892 .38081 L
.18913 .01766 L
.18936 .06372 L
.1896 .44577 L
.18984 .21454 L
.19005 .47605 L
.19029 .01632 L
.19043 .32874 L
.19056 .13024 L
.1908 .5173 L
.19092 .38632 L
.19105 .19042 L
.19118 .46436 L
.19132 .1872 L
.19156 .45012 L
.19169 .19066 L
.19182 .51399 L
.19195 .17811 L
.1921 .06771 L
.19223 .51938 L
Mistroke
.19237 .13867 L
.1925 .43542 L
.19262 .13697 L
.19284 .06291 L
.19309 .38653 L
.19331 .46808 L
.19356 .0172 L
.1938 .30282 L
.19401 .0447 L
.19423 .15308 L
.19443 .02193 L
.19465 .02808 L
.19486 .32347 L
.1951 .04912 L
.19534 .51541 L
.19555 .03379 L
.19578 .1874 L
.19603 .17704 L
.19617 .5196 L
.1963 .07017 L
.19654 .51217 L
.19678 .38195 L
.19699 .48142 L
.1972 .20285 L
.19741 .47666 L
.19764 .47472 L
.19784 .0453 L
.19802 .18674 L
.19822 .1333 L
.19844 .19051 L
.19865 .51254 L
.19888 .38371 L
.1991 .5143 L
.1993 .3162 L
.19953 .05663 L
.19966 .47105 L
.19978 .4588 L
.2 .51795 L
.20024 .21382 L
.20047 .08304 L
.20072 .51863 L
.20095 .19063 L
.20117 .45711 L
.20139 .45703 L
.20158 .4694 L
.20181 .44088 L
.20202 .34622 L
.20226 .51945 L
.2025 .05242 L
.20271 .35985 L
Mistroke
.20294 .14186 L
.20319 .51335 L
.20333 .14555 L
.20346 .511 L
.2037 .08112 L
.20394 .39215 L
.20414 .43869 L
.20436 .51979 L
.20459 .49172 L
.2048 .34631 L
.205 .43772 L
.20518 .52106 L
.2054 .12618 L
.2056 .52145 L
.20581 .30102 L
.20604 .48112 L
.20626 .18945 L
.20646 .5121 L
.20669 .42312 L
.20682 .10293 L
.20694 .41718 L
.20716 .2821 L
.2074 .52304 L
.20763 .4444 L
.20775 .10726 L
.20788 .33998 L
.20812 .48328 L
.20833 .49073 L
.20854 .01614 L
.20874 .22018 L
.20896 .02436 L
.20919 .11646 L
.20942 .41106 L
.20955 .11166 L
.20968 .09144 L
.20992 .29339 L
.21006 .50285 L
.21019 .19217 L
.21042 .14399 L
.21066 .45029 L
.21089 .50884 L
.21111 .19725 L
.21131 .49834 L
.21152 .02454 L
.21172 .41054 L
.21191 .17483 L
.21212 .11411 L
.21236 .0212 L
.21258 .09451 L
.21279 .32612 L
Mistroke
.21302 .47206 L
.21324 .11797 L
.21344 .36823 L
.21365 .06791 L
.21388 .0153 L
.21413 .50929 L
.21434 .02962 L
.21457 .01712 L
.21482 .51496 L
.21505 .50777 L
.21517 .50364 L
.2153 .0159 L
.21543 .46686 L
.21556 .01636 L
.2158 .14703 L
.21602 .13929 L
.21625 .03119 L
.2165 .47562 L
.21671 .08869 L
.21694 .01719 L
.21715 .49101 L
.21734 .43879 L
.21757 .4905 L
.21782 .01929 L
.21805 .07723 L
.21826 .3192 L
.21849 .35141 L
.21873 .08129 L
.21897 .15564 L
.21918 .33816 L
.21942 .16723 L
.21956 .12623 L
.21969 .25169 L
.21993 .51696 L
.22006 .03883 L
.22018 .04219 L
.22031 .4981 L
.22045 .02419 L
.22069 .31524 L
.22082 .19258 L
.22095 .04702 L
.22108 .37917 L
.22123 .52133 L
.22136 .10452 L
.2215 .52411 L
.22163 .06994 L
.22175 .02615 L
.22197 .01645 L
.22222 .41327 L
.22244 .36402 L
Mistroke
.22269 .1605 L
.22293 .01921 L
.22314 .37673 L
.22336 .4009 L
.22356 .51889 L
.22378 .45394 L
.22399 .02733 L
.22423 .02765 L
.22447 .52685 L
.22468 .01525 L
.22491 .0212 L
.22504 .46477 L
.22518 .02052 L
.22531 .52438 L
.22543 .40519 L
.22566 .50389 L
.22591 .05351 L
.22612 .27862 L
.22633 .03121 L
.22654 .40254 L
.22677 .33533 L
.227 .14867 L
.22722 .52493 L
.22745 .52097 L
.2277 .0226 L
.22792 .2808 L
.22812 .01511 L
.22835 .0358 L
.22857 .20638 L
.22877 .01649 L
.22895 .14103 L
.22915 .08901 L
.22937 .31384 L
.22959 .32472 L
.22984 .27219 L
.23008 .49751 L
.2303 .11179 L
.23051 .17078 L
.23071 .02761 L
.23094 .08634 L
.23115 .51895 L
.23138 .49982 L
.23163 .02066 L
.23184 .51793 L
.23207 .48875 L
.23232 .07012 L
.23246 .25972 L
.23258 .04889 L
.23283 .51783 L
.23306 .40546 L
Mistroke
.23326 .0876 L
.23348 .4531 L
.23371 .44969 L
.23393 .28364 L
.23413 .52913 L
.23431 .3677 L
.23451 .51811 L
.23472 .10151 L
.23494 .13817 L
.23514 .10365 L
.23538 .50988 L
.2356 .12833 L
.23583 .10559 L
.23608 .4658 L
.23631 .30412 L
.23652 .43883 L
.23676 .48618 L
.23699 .52987 L
.23719 .1815 L
.23741 .49616 L
.23765 .11855 L
.23777 .01687 L
.2379 .52843 L
.23814 .36155 L
.23836 .53017 L
.23857 .0155 L
.23879 .22708 L
.23898 .3203 L
.23919 .09761 L
.23941 .01883 L
.23965 .22152 L
.23986 .37839 L
.24008 .527 L
.2402 .28299 L
.24034 .41677 L
.24058 .37556 L
.24072 .27594 L
.24086 .0528 L
.241 .34037 L
.24113 .01677 L
.24137 .483 L
.24151 .01586 L
.24164 .44366 L
.24187 .53093 L
.24212 .02566 L
.24236 .45045 L
.2425 .0375 L
.24262 .20729 L
.24285 .25287 L
.2431 .47729 L
Mistroke
.24331 .38236 L
.24352 .42205 L
.24374 .53141 L
.24398 .23621 L
.24421 .16899 L
.24434 .28276 L
.24447 .53027 L
.24471 .01685 L
.24485 .44622 L
.24498 .01676 L
.2452 .45927 L
.24543 .20878 L
.24568 .24013 L
.2459 .22119 L
.24604 .40362 L
.24618 .3766 L
.24633 .37994 L
.24647 .01509 L
.2466 .51438 L
.24672 .42209 L
.24686 .15846 L
.247 .02276 L
.24713 .37025 L
.24727 .02245 L
.2474 .49144 L
.24752 .47853 L
.24775 .43685 L
.248 .03652 L
.24824 .40801 L
.24837 .10047 L
.24849 .07288 L
.24872 .0457 L
.24896 .45592 L
.24918 .02003 L
.24938 .36054 L
.2496 .05491 L
.24984 .32342 L
.24997 .30098 L
.25009 .0628 L
.25022 .42002 L
.25036 .01491 L
.2506 .09637 L
.25074 .46521 L
.25086 .07768 L
.2511 .0242 L
.25132 .53242 L
.25156 .04249 L
.2518 .0178 L
.25203 .04544 L
.25217 .53293 L
Mistroke
.25229 .45254 L
.25251 .48848 L
.25275 .53327 L
.25296 .01655 L
.25316 .05828 L
.25338 .35162 L
.25361 .32893 L
.25386 .08439 L
.254 .29423 L
.25413 .05256 L
.25437 .24115 L
.25449 .40232 L
.25462 .26195 L
.25485 .42565 L
.25509 .01505 L
.25533 .01506 L
.25554 .5338 L
.25574 .31099 L
.25596 .36063 L
.25615 .08881 L
.25635 .42671 L
.25659 .53432 L
.25681 .34765 L
.25703 .03092 L
.25723 .12657 L
.25745 .33714 L
.25768 .3788 L
.2579 .38981 L
.2581 .53212 L
.25832 .2748 L
.25853 .30303 L
.25876 .41739 L
.25889 .01531 L
.25902 .08418 L
.25926 .49149 L
.25938 .50937 L
.25952 .02402 L
.25975 .17732 L
.25998 .04599 L
.26011 .48667 L
.26024 .36439 L
.26048 .10446 L
.26061 .37958 L
.26074 .53535 L
.26087 .01514 L
.26102 .31605 L
.26124 .52888 L
.26148 .43634 L
.2617 .53339 L
.26191 .16025 L
Mistroke
.26214 .26806 L
.26227 .07885 L
.26239 .2536 L
.26264 .52181 L
.26277 .05216 L
.2629 .34636 L
.26312 .02107 L
.26335 .02168 L
.26355 .05063 L
.26377 .33671 L
.264 .25055 L
.26413 .13792 L
.26425 .29477 L
.26449 .32738 L
.26471 .01515 L
.26491 .34864 L
.26513 .03544 L
.26532 .27223 L
.26553 .0426 L
.26575 .24881 L
.26599 .05543 L
.26621 .3404 L
.26642 .0209 L
.26666 .25215 L
.26688 .06129 L
.26709 .44032 L
.26731 .03904 L
.26755 .33825 L
.26767 .50907 L
.26781 .08517 L
.26804 .01568 L
.26827 .34699 L
.26849 .5157 L
.2687 .08638 L
.26889 .24909 L
.26909 .06496 L
.26932 .08942 L
.26956 .02055 L
.26978 .13117 L
.26999 .07553 L
.27023 .51258 L
.27035 .47607 L
.27049 .06871 L
.27073 .33525 L
.27095 .03124 L
.27109 .52236 L
.27122 .09834 L
.27146 .04669 L
.27159 .52391 L
.27172 .2507 L
Mistroke
.27185 .34481 L
.272 .02208 L
.27222 .18069 L
.27246 .01963 L
.27269 .06086 L
.2729 .33911 L
.27313 .29152 L
.27326 .4408 L
.27339 .21264 L
.27363 .1256 L
.27377 .41175 L
.2739 .02821 L
.27413 .02294 L
.27425 .1196 L
.27439 .51278 L
.27452 .12796 L
.27466 .52379 L
.2749 .03722 L
.27513 .08406 L
.27535 .48452 L
.27558 .52459 L
.27583 .0766 L
.27597 .52307 L
.27611 .04242 L
.27625 .46111 L
.2764 .53486 L
.27653 .03962 L
.27665 .0652 L
.27679 .50771 L
.27693 .36233 L
.27706 .46856 L
.2772 .23256 L
.27733 .46215 L
.27746 .24604 L
.27769 .32947 L
.27793 .01908 L
.27817 .05954 L
.27838 .43499 L
.27862 .28681 L
.27887 .12799 L
.27908 .26558 L
.27928 .02187 L
.27951 .39622 L
.27974 .24586 L
.27988 .2697 L
.28 .52503 L
.28014 .02348 L
.28028 .40016 L
.28052 .04824 L
.28066 .53426 L
Mistroke
.28079 .22942 L
.28103 .02225 L
.28125 .48778 L
.28137 .32676 L
.2815 .0788 L
.28174 .33603 L
.28197 .20538 L
.28218 .44883 L
.28241 .49026 L
.28265 .08314 L
.28287 .44967 L
.28306 .53492 L
.28328 .03627 L
.28351 .02779 L
.28364 .52667 L
.28377 .50783 L
.2839 .01693 L
.28404 .41199 L
.28428 .21671 L
.28441 .30767 L
.28454 .53766 L
.28477 .50313 L
.28499 .09534 L
.28524 .53855 L
.28547 .49158 L
.2856 .04472 L
.28572 .02877 L
.28595 .06597 L
.28619 .18972 L
.28633 .29203 L
.28646 .01472 L
.28667 .53697 L
.2869 .5361 L
.28714 .38432 L
.28737 .53367 L
.2875 .14985 L
.28764 .49967 L
.28789 .41016 L
.28803 .21421 L
.28818 .01832 L
.2883 .1751 L
.28844 .3125 L
.28869 .01932 L
.28883 .51591 L
.28896 .17014 L
.28919 .19554 L
.28944 .06176 L
.28967 .0196 L
.28981 .4672 L
.28993 .53416 L
Mistroke
.29015 .09442 L
.29039 .09018 L
.2906 .54264 L
.2908 .54149 L
.29101 .01813 L
.29125 .03274 L
.29149 .23606 L
.29163 .23416 L
.29176 .03921 L
.292 .06887 L
.29214 .53973 L
.29226 .54013 L
.29248 .38253 L
.29273 .52175 L
.29296 .53746 L
.29318 .08049 L
.29338 .01482 L
.29359 .542 L
.2938 .43078 L
.29398 .44427 L
.2942 .08124 L
.29444 .08052 L
.29466 .52983 L
.29487 .22242 L
.29508 .16305 L
.29528 .24752 L
.2955 .23869 L
.29573 .29775 L
.29598 .01938 L
.29621 .07116 L
.29642 .21628 L
.29665 .01618 L
.29677 .08127 L
.2969 .48278 L
.29713 .28457 L
.29738 .52367 L
.29752 .11864 L
.29765 .54412 L
.29789 .5318 L
.29811 .04305 L
.29823 .09646 L
.29836 .5324 L
.2986 .54452 L
.29881 .10641 L
.29904 .21087 L
.29929 .01613 L
.29951 .20274 L
.29973 .21335 L
.29992 .15691 L
.30014 .4702 L
Mistroke
.30036 .45008 L
.30059 .18185 L
.30084 .45146 L
.30096 .50833 L
.3011 .09978 L
.30135 .46597 L
.30158 .28831 L
.30183 .51711 L
.30207 .53743 L
.30228 .0151 L
.30242 .53607 L
.30254 .40627 L
.30269 .5455 L
.30283 .02539 L
.30296 .30164 L
.30308 .46894 L
.30321 .41951 L
.30335 .21922 L
.3036 .54487 L
.30372 .44578 L
.30386 .07014 L
.3041 .25572 L
.30433 .02669 L
.30456 .13236 L
.30468 .02765 L
.30481 .27379 L
.30505 .34958 L
.30527 .08787 L
.30548 .24322 L
.30568 .26906 L
.3059 .28844 L
.30613 .40893 L
.30636 .4727 L
.3065 .015 L
.30662 .09203 L
.30687 .5387 L
.30701 .01482 L
.30714 .23429 L
.30736 .0148 L
.30761 .30766 L
.30784 .16508 L
.30806 .47105 L
.30826 .3464 L
.30847 .15144 L
.30868 .39691 L
.30886 .01778 L
.30908 .54182 L
.30931 .54273 L
.30954 .1899 L
.30974 .52955 L
Mistroke
.30996 .17216 L
.31015 .10027 L
.31037 .50634 L
.31061 .48635 L
.31084 .38788 L
.31109 .52882 L
.3113 .07355 L
.31153 .31434 L
.31178 .02285 L
.31201 .1083 L
.31213 .06142 L
.31226 .28768 L
.3124 .27896 L
.31252 .01853 L
.31276 .02446 L
.31298 .53734 L
.3131 .51298 L
.31323 .06879 L
.31347 .03854 L
.3137 .1589 L
.31391 .1502 L
.31415 .41701 L
.31438 .11402 L
.31459 .54297 L
.31479 .5483 L
.315 .03724 L
.31523 .39173 L
.31547 .03348 L
.3157 .44762 L
.31582 .20365 L
.31596 .24308 L
.3162 .54121 L
.31643 .3445 L
.31668 .54596 L
.31689 .26885 L
.31712 .51056 L
.31725 .06129 L
.31738 .49487 L
.31763 .45477 L
.31818 .35994 L
.31843 .01568 L
.31857 .54503 L
.3187 .20675 L
.31894 .20224 L
.31905 .16204 L
.31919 .12699 L
.31942 .10479 L
.31955 .54963 L
.31967 .53113 L
.31991 .5489 L
Mistroke
.32013 .14654 L
.32034 .5151 L
.32054 .49591 L
.32076 .07969 L
.32099 .01736 L
.32112 .35719 L
.32124 .42898 L
.32137 .38549 L
.32151 .22472 L
.32175 .13303 L
.32188 .54718 L
.322 .41838 L
.32223 .53043 L
.32244 .06868 L
.32269 .18385 L
.32292 .04963 L
.32312 .03297 L
.32334 .53092 L
.32357 .16727 L
.32378 .53229 L
.32398 .51907 L
.32417 .15728 L
.32438 .54778 L
.32458 .54948 L
.3248 .03967 L
.32503 .35934 L
.32525 .1283 L
.32545 .06045 L
.32568 .04805 L
.32581 .20447 L
.32593 .24028 L
.32615 .36743 L
.32639 .43091 L
.32663 .49602 L
.32685 .2677 L
.32707 .32002 L
.32728 .18849 L
.3275 .33362 L
.32774 .40309 L
.32786 .52828 L
.32799 .35402 L
.32823 .53071 L
.32843 .45078 L
.32865 .20288 L
.32889 .11684 L
.32911 .40626 L
.32932 .03837 L
.32951 .3457 L
.32974 .25083 L
.32994 .53486 L
Mistroke
.33017 .03821 L
.33042 .29601 L
.33054 .4713 L
.33068 .3315 L
.33092 .24625 L
.33116 .22398 L
.33139 .55275 L
.33159 .47518 L
.33182 .22604 L
.33196 .42837 L
.33208 .0645 L
.33233 .02371 L
.33246 .45225 L
.33259 .55135 L
.33273 .05507 L
.33287 .54765 L
.33311 .53673 L
.33334 .1617 L
.33358 .42867 L
.33372 .20755 L
.33385 .0313 L
.33407 .55075 L
.33428 .27511 L
.33451 .55345 L
.33476 .40046 L
.335 .17423 L
.33513 .06432 L
.33526 .32421 L
.3355 .28977 L
.33572 .18225 L
.33595 .54711 L
.33616 .20754 L
.33636 .51807 L
.33656 .25372 L
.33679 .52556 L
.33703 .51332 L
.33723 .55181 L
.33746 .10912 L
.33759 .3272 L
.33772 .37896 L
.33797 .0554 L
.33821 .02112 L
.33844 .52606 L
.33868 .49158 L
.33882 .02818 L
.33895 .3411 L
.33908 .40979 L
.33921 .22522 L
.33934 .20432 L
.33949 .19575 L
Mistroke
.33971 .5453 L
.33996 .55466 L
.34019 .2247 L
.34039 .51079 L
.34064 .55441 L
.34078 .02548 L
.3409 .10626 L
.34114 .01812 L
.34138 .14868 L
.34161 .12332 L
.34186 .03299 L
.3421 .04725 L
.34231 .46223 L
.34253 .28251 L
.34272 .462 L
.34295 .32821 L
.34316 .51577 L
.3434 .50636 L
.34364 .54482 L
.34385 .21782 L
.34408 .54419 L
.34433 .29227 L
.34447 .2379 L
.3446 .49513 L
.34484 .54337 L
.34508 .48516 L
.34527 .42537 L
.34549 .1939 L
.34572 .55488 L
.34594 .091 L
.34614 .09977 L
.34632 .54209 L
.34652 .55276 L
.34673 .26075 L
.34695 .12553 L
.34718 .06491 L
.3474 .41684 L
.34759 .30781 L
.34783 .03872 L
.34796 .43252 L
.34808 .45772 L
.3483 .06047 L
.34853 .23716 L
.34876 .55675 L
.34901 .33384 L
.34923 .22379 L
.34947 .0335 L
.3497 .12381 L
.34991 .06383 L
.35012 .47188 L
Mistroke
.35032 .41797 L
.35055 .14845 L
.3508 .40318 L
.35101 .52679 L
.35124 .42825 L
.35149 .54468 L
.35163 .01974 L
.35175 .20191 L
.352 .4617 L
.35223 .18865 L
.35243 .14462 L
.35265 .45635 L
.35288 .46614 L
.3531 .31993 L
.3533 .31516 L
.35348 .39284 L
.35368 .43695 L
.35389 .47092 L
.35411 .01881 L
.35434 .22932 L
.35456 .22963 L
.35475 .12127 L
.35499 .02582 L
.35512 .25034 L
.35524 .27512 L
.35546 .22413 L
.35569 .44877 L
.35592 .49556 L
.35605 .46768 L
.35617 .46171 L
.3564 .12511 L
.35663 .01512 L
.35684 .24937 L
.35703 .1053 L
.35725 .55793 L
.35748 .32605 L
.35772 .01577 L
.35785 .24729 L
.35797 .27496 L
.35822 .4305 L
.35836 .28468 L
.35848 .12003 L
.35871 .52437 L
.35896 .54806 L
.35919 .13128 L
.3594 .51898 L
.3596 .3819 L
.35981 .53471 L
.36002 .55273 L
.3602 .04761 L
Mistroke
.36042 .49567 L
.36065 .1732 L
.36088 .44412 L
.36108 .32262 L
.36132 .54985 L
.36154 .12955 L
.36173 .38795 L
.36195 .04502 L
.36218 .45219 L
.36242 .3894 L
.36263 .13031 L
.36286 .56016 L
.36311 .53258 L
.36334 .17348 L
.36346 .07538 L
.36359 .42947 L
.36373 .35731 L
.36386 .0972 L
.36409 .42256 L
.36431 .01752 L
.36455 .19034 L
.3648 .03226 L
.36501 .08647 L
.36523 .45751 L
.36544 .11674 L
.36564 .51535 L
.36586 .1549 L
.36611 .21979 L
.36634 .0539 L
.36655 .15729 L
.36678 .24908 L
.36703 .22321 L
.36726 .55538 L
.36747 .44643 L
.36772 .33724 L
.36786 .13275 L
.36799 .42644 L
.36822 .14828 L
.36836 .52863 L
.36848 .47304 L
.36898 .29824 L
.36912 .07895 L
.36924 .28592 L
.36938 .55949 L
.36952 .07486 L
.36977 .20766 L
.36991 .54632 L
.37004 .33312 L
.37028 .22075 L
.37051 .38998 L
Mistroke
.37072 .47111 L
.37096 .46564 L
.37118 .25558 L
.37138 .34328 L
.37161 .56247 L
.37175 .25502 L
.37187 .19086 L
.3721 .47835 L
.37234 .38043 L
.37246 .39349 L
.37259 .56231 L
.37273 .01775 L
.37286 .18144 L
.3731 .01933 L
.37323 .30044 L
.37336 .41237 L
.37359 .02914 L
.3738 .33099 L
.37405 .3793 L
.37428 .01647 L
.37448 .04672 L
.3747 .43573 L
.37493 .01506 L
.37515 .39054 L
.37535 .2999 L
.37553 .21716 L
.37573 .31499 L
.37595 .01658 L
.37617 .50196 L
.37637 .50368 L
.37661 .43675 L
.37683 .29643 L
.37706 .50344 L
.37731 .56236 L
.37755 .37344 L
.37776 .47345 L
.378 .54812 L
.37823 .02156 L
.37843 .04904 L
.37865 .41061 L
.37889 .17079 L
.37902 .55142 L
.37914 .52619 L
.37937 .19328 L
.3796 .47746 L
.3798 .27023 L
.38002 .16744 L
.38021 .20497 L
.38042 .10221 L
.38064 .42864 L
Mistroke
.38088 .18288 L
.3811 .35871 L
.38131 .30618 L
.38155 .39048 L
.38167 .38556 L
.38181 .01521 L
.38205 .1226 L
.38227 .43736 L
.3824 .56311 L
.38253 .23069 L
.38277 .39532 L
.38291 .01712 L
.38303 .02434 L
.38317 .51278 L
.38331 .0164 L
.38356 .01732 L
.3837 .53348 L
.38382 .5483 L
.38406 .40525 L
.38431 .52526 L
.38453 .09746 L
.38474 .01791 L
.38496 .53421 L
.38521 .52634 L
.38544 .24083 L
.38557 .54041 L
.38569 .55124 L
.38594 .56463 L
.38608 .0417 L
.3862 .03663 L
.38642 .42577 L
.38665 .06865 L
.3869 .09488 L
.38713 .31774 L
.38726 .03612 L
.3874 .52668 L
.38753 .382 L
.38766 .33175 L
.38789 .55912 L
.38814 .55597 L
.38826 .39908 L
.3884 .03756 L
.38865 .16085 L
.3888 .07245 L
.38895 .54359 L
.38908 .5022 L
.38922 .0474 L
.38934 .09083 L
.38947 .5255 L
.38972 .48912 L
Mistroke
.38995 .18167 L
.39017 .56292 L
.39041 .41208 L
.39054 .50194 L
.39067 .45594 L
.3908 .14948 L
.39092 .30575 L
.39106 .06354 L
.39119 .32983 L
.39141 .50613 L
.39164 .33456 L
.39184 .08221 L
.39206 .55519 L
.3923 .16003 L
.39243 .50049 L
.39256 .43114 L
.39278 .26048 L
.39302 .56666 L
.39325 .10047 L
.39338 .39324 L
.3935 .27905 L
.39373 .47654 L
.39396 .43768 L
.39417 .55269 L
.39437 .2487 L
.39459 .56219 L
.39482 .06596 L
.39507 .04452 L
.39521 .55655 L
.39534 .52785 L
.39558 .42321 L
.39571 .56088 L
.39583 .54922 L
.39606 .02895 L
.3963 .06834 L
.39654 .5667 L
.39675 .41248 L
.39695 .55621 L
.39717 .27527 L
.39737 .4117 L
.39756 .13926 L
.39777 .53105 L
.39801 .10005 L
.39823 .56606 L
.39844 .56864 L
.39865 .47286 L
.39885 .55357 L
.39907 .33756 L
.3993 .51969 L
.39955 .43298 L
Mistroke
.39978 .01825 L
.39999 .02419 L
.40022 .54183 L
.40034 .56775 L
.40047 .48248 L
.4007 .21775 L
.40095 .22088 L
.40109 .49821 L
.40122 .20607 L
.40146 .54833 L
.40168 .17523 L
.4018 .33584 L
.40193 .08183 L
.40217 .47042 L
.40238 .29866 L
.40261 .50319 L
.40286 .34239 L
.40309 .1857 L
.4033 .02262 L
.40349 .39733 L
.40371 .0956 L
.40393 .44191 L
.40418 .43294 L
.40441 .23409 L
.40453 .20479 L
.40467 .045 L
.40491 .01678 L
.40514 .53314 L
.40539 .56828 L
.4056 .56908 L
.40583 .03293 L
.40596 .51105 L
.4061 .54858 L
.40634 .5697 L
.40648 .15251 L
.40661 .05287 L
.40675 .37609 L
.4069 .06708 L
.40703 .0255 L
.40717 .55092 L
.4073 .46153 L
.40742 .52329 L
.40765 .18909 L
.4079 .06337 L
.40813 .41408 L
.40826 .1565 L
.40838 .29775 L
.4086 .06624 L
.40884 .24464 L
.40903 .57071 L
Mistroke
.40924 .51265 L
.40947 .20405 L
.40969 .5547 L
.40992 .05578 L
.41006 .35048 L
.41018 .30086 L
.41043 .3171 L
.41057 .48896 L
.41069 .41379 L
.41092 .14903 L
.41117 .07267 L
.4114 .3547 L
.41161 .08555 L
.41181 .34856 L
.41203 .06096 L
.41223 .19789 L
.41241 .34291 L
.41263 .57082 L
.41287 .23831 L
.41309 .51351 L
.4133 .52278 L
.41351 .26096 L
.41374 .46131 L
.41396 .49103 L
.41416 .56573 L
.41439 .11509 L
.41464 .09198 L
.41485 .13596 L
.41508 .43217 L
.41533 .43495 L
.41556 .21423 L
.41567 .06487 L
.41581 .35062 L
.41594 .50889 L
.41607 .3337 L
.41631 .55879 L
.41653 .40483 L
.41665 .54312 L
.41678 .3322 L
.41701 .56908 L
.41725 .04913 L
.41746 .14804 L
.4177 .0203 L
.41793 .55497 L
.41814 .40119 L
.41834 .52731 L
.41855 .53128 L
.41878 .03688 L
.41902 .01657 L
.41925 .55457 L
Mistroke
.41937 .55472 L
.41951 .37215 L
.41975 .47275 L
.41998 .18128 L
.42022 .04473 L
.42043 .07086 L
.42066 .4545 L
.42079 .19319 L
.42093 .10675 L
.42118 .04509 L
.42131 .50611 L
.42144 .56872 L
.42158 .12872 L
.42173 .56736 L
.42186 .52212 L
.422 .01559 L
.42213 .21511 L
.42226 .14819 L
.42249 .26649 L
.42273 .3813 L
.42296 .16042 L
.42321 .06228 L
.42345 .40103 L
.42366 .0965 L
.42388 .0172 L
.42408 .42377 L
.4243 .0286 L
.42452 .07555 L
.42464 .01598 L
.42477 .04961 L
.425 .46085 L
.42525 .56562 L
.42539 .2209 L
.42551 .16254 L
.42574 .20397 L
.42599 .02038 L
.42622 .56717 L
.42643 .48982 L
.42663 .51515 L
.42685 .57154 L
.42705 .48705 L
.42724 .19812 L
.42744 .57195 L
.42765 .57419 L
.42786 .53613 L
.42809 .14059 L
.42833 .25846 L
.42855 .10864 L
.42879 .2993 L
.42903 .37137 L
Mistroke
.42924 .55289 L
.42944 .16129 L
.42966 .48477 L
.42989 .11173 L
.43012 .41911 L
.43025 .53062 L
.43037 .32341 L
.43059 .57577 L
.43083 .04744 L
.43104 .02524 L
.43123 .36972 L
.43145 .16774 L
.43168 .45749 L
.43191 .10063 L
.43204 .01574 L
.43217 .0489 L
.43241 .18364 L
.43255 .08706 L
.43268 .08912 L
.43291 .57636 L
.43315 .43703 L
.43338 .13765 L
.4336 .04085 L
.4338 .44008 L
.43401 .29149 L
.4342 .13195 L
.4344 .02993 L
.43463 .55918 L
.43486 .08568 L
.43508 .04431 L
.43528 .08386 L
.43551 .54577 L
.43573 .47676 L
.43593 .41751 L
.43614 .50553 L
.43637 .05232 L
.43662 .27571 L
.43683 .2943 L
.43706 .2537 L
.43731 .0586 L
.43754 .57658 L
.43765 .44913 L
.43779 .57004 L
.43792 .34231 L
.43805 .23754 L
.43829 .5089 L
.4385 .57507 L
.43874 .14415 L
.43899 .06091 L
.4392 .06417 L
Mistroke
.43943 .55658 L
.43964 .5756 L
.43983 .0353 L
.44006 .56471 L
.4403 .37192 L
.44052 .52892 L
.44075 .07626 L
.441 .3159 L
.44123 .22027 L
.44137 .56855 L
.4415 .3719 L
.44175 .46977 L
.44188 .43404 L
.44201 .08316 L
.44226 .4276 L
.4424 .24206 L
.44255 .56294 L
.44267 .56624 L
.44281 .24419 L
.44304 .26909 L
.44317 .42877 L
.44329 .22788 L
.44353 .02198 L
.44367 .37729 L
.4438 .32421 L
.44402 .54381 L
.44426 .46476 L
.44449 .20751 L
.4447 .15329 L
.44494 .55018 L
.44516 .30545 L
.44536 .57701 L
.44558 .3299 L
.44582 .49618 L
.44595 .57396 L
.44607 .51771 L
.44631 .02167 L
.44653 .25086 L
.44673 .08267 L
.44695 .34774 L
.44717 .57246 L
.44741 .14606 L
.44762 .0528 L
.44784 .47994 L
.44805 .45632 L
.44824 .0799 L
.44848 .49844 L
.4486 .57752 L
.44874 .35518 L
.44897 .4806 L
Mistroke
.4492 .443 L
.44933 .39695 L
.44946 .08858 L
.4497 .53831 L
.44983 .26673 L
.44996 .33772 L
.45009 .02919 L
.45024 .5642 L
.45049 .41084 L
.45072 .12015 L
.45095 .30636 L
.45116 .26629 L
.45138 .50935 L
.45163 .57175 L
.45176 .5779 L
.45189 .34149 L
.45214 .57912 L
.45227 .52339 L
.45239 .58003 L
.45262 .03668 L
.45286 .23555 L
.453 .0493 L
.45313 .07496 L
.45334 .18107 L
.45358 .29896 L
.45382 .55901 L
.45405 .01709 L
.45418 .04265 L
.45432 .51582 L
.45445 .58092 L
.45458 .50073 L
.45481 .1809 L
.45506 .53354 L
.45518 .55339 L
.45532 .24947 L
.45557 .54773 L
.45571 .0358 L
.45587 .57798 L
.45599 .58108 L
.45614 .22027 L
.45626 .4273 L
.45639 .22137 L
.45663 .56891 L
.45687 .02421 L
.45709 .02299 L
.45732 .57584 L
.45746 .45942 L
.45758 .55308 L
.45771 .46674 L
.45783 .57153 L
Mistroke
.45797 .38699 L
.4581 .25544 L
.45832 .05022 L
.45856 .5221 L
.45876 .04135 L
.45898 .26802 L
.45922 .28773 L
.45935 .11229 L
.45947 .35534 L
.4597 .01977 L
.45993 .58089 L
.46017 .03643 L
.4603 .01594 L
.46042 .16667 L
.46064 .05407 L
.46088 .57963 L
.46109 .57354 L
.46129 .2814 L
.4615 .21749 L
.46173 .57243 L
.46198 .38188 L
.46212 .56586 L
.46225 .54867 L
.46249 .08809 L
.46262 .23245 L
.46274 .01797 L
.46297 .43876 L
.46321 .04982 L
.46344 .5825 L
.46366 .58258 L
.46386 .18762 L
.46407 .23203 L
.46428 .02674 L
.46446 .35456 L
.46468 .4701 L
.46491 .10646 L
.46514 .05012 L
.46534 .07178 L
.46556 .13705 L
.46576 .58274 L
.46597 .54037 L
.46621 .05232 L
.46644 .57801 L
.46669 .32931 L
.4669 .15422 L
.46713 .5808 L
.46738 .46301 L
.46761 .35431 L
.46785 .58344 L
.46799 .2393 L
Mistroke
.46813 .12303 L
.46835 .01744 L
.46858 .56522 L
.46871 .53514 L
.46884 .58069 L
.46907 .08661 L
.46928 .14485 L
.46951 .09113 L
.46972 .06761 L
.46991 .52376 L
.47014 .0432 L
.47039 .41894 L
.47062 .08281 L
.47083 .07067 L
.47106 .57801 L
.47131 .23323 L
.47154 .48863 L
.47175 .55609 L
.472 .4924 L
.47214 .47942 L
.47227 .44447 L
.47251 .24088 L
.47264 .37244 L
.47276 .07652 L
.473 .35428 L
.47313 .44415 L
.47326 .27765 L
.47348 .01724 L
.47373 .40356 L
.47387 .02316 L
.47399 .03968 L
.47414 .48616 L
.47428 .5348 L
.47453 .4716 L
.47466 .53293 L
.47479 .54514 L
.47503 .12253 L
.47526 .54133 L
.47546 .11954 L
.47568 .36865 L
.47592 .09522 L
.47604 .38494 L
.47617 .17768 L
.47641 .43203 L
.47663 .58508 L
.47684 .52695 L
.47706 .56737 L
.47725 .02406 L
.47745 .23842 L
.47768 .01645 L
Mistroke
.47792 .56567 L
.47814 .19017 L
.47835 .54026 L
.47859 .33684 L
.47871 .11178 L
.47885 .36694 L
.47908 .11808 L
.47931 .05072 L
.47944 .26265 L
.47957 .24838 L
.47981 .15466 L
.47995 .02068 L
.48007 .09147 L
.48021 .04719 L
.48035 .58289 L
.4806 .26487 L
.48074 .58069 L
.48087 .57118 L
.4811 .0425 L
.48135 .35532 L
.48157 .05569 L
.48178 .2781 L
.482 .05304 L
.48225 .2471 L
.48248 .16257 L
.48261 .3391 L
.48273 .08591 L
.48286 .07299 L
.483 .42569 L
.48325 .12895 L
.48346 .17386 L
.4837 .43135 L
.48395 .5466 L
.48417 .29766 L
.4843 .19217 L
.48445 .10387 L
.48458 .31773 L
.4847 .12531 L
.48494 .51919 L
.48519 .41021 L
.48543 .01667 L
.48557 .22342 L
.4857 .10003 L
.48585 .56041 L
.48599 .15406 L
.48612 .14911 L
.48627 .08355 L
.48639 .02214 L
.48653 .03077 L
.48677 .48961 L
Mistroke
.48701 .04493 L
.48722 .03912 L
.48746 .5865 L
.48759 .56262 L
.48772 .56253 L
.48785 .58053 L
.48797 .25699 L
.48811 .54284 L
.48824 .5533 L
.48846 .58726 L
.4887 .08494 L
.4889 .58617 L
.48912 .57258 L
.48935 .01729 L
.48949 .02523 L
.48961 .15759 L
.48983 .05859 L
.49007 .53954 L
.49031 .01773 L
.49054 .28291 L
.49076 .47786 L
.49097 .03884 L
.49119 .16214 L
.49144 .2605 L
.49156 .53608 L
.49169 .50376 L
.49193 .06062 L
.49215 .19305 L
.49239 .33037 L
.49262 .02054 L
.49283 .18039 L
.49302 .17444 L
.49323 .01745 L
.49345 .01673 L
.49366 .34655 L
.49388 .02069 L
.49401 .03282 L
.49414 .36856 L
.49438 .40132 L
.49452 .56649 L
.49464 .36152 L
.49486 .5206 L
.4951 .04885 L
.49533 .13455 L
.49554 .02124 L
.49578 .57912 L
.49601 .29624 L
.49626 .58422 L
.4964 .41946 L
.49653 .51442 L
Mistroke
.49666 .43953 L
.49678 .58862 L
.49692 .52366 L
.49706 .05315 L
.4972 .04848 L
.49733 .02907 L
.49757 .53534 L
.49779 .45977 L
.49803 .04703 L
.49825 .19222 L
.49845 .14415 L
.49869 .40668 L
.49883 .5297 L
.49895 .29948 L
.49918 .58761 L
.49942 .02552 L
.49965 .44613 L
.4999 .02257 L
.50013 .54831 L
.50035 .4592 L
.50061 .34831 L
.50085 .23232 L
.50097 .55998 L
.5011 .57916 L
.50124 .15265 L
.50137 .16692 L
.50159 .14874 L
.50182 .12105 L
.50202 .44788 L
.50224 .48886 L
.50247 .0175 L
.5026 .01739 L
.50272 .34697 L
.50295 .02731 L
.50317 .05872 L
.50337 .26015 L
.50359 .28928 L
.50378 .01728 L
.50398 .36815 L
.5042 .31654 L
.50444 .16404 L
.50466 .37963 L
.50487 .01654 L
.50511 .58855 L
.50533 .33338 L
.50554 .55212 L
.50576 .59013 L
.506 .02374 L
.50612 .16776 L
.50626 .06802 L
Mistroke
.50649 .45374 L
.50671 .56116 L
.50694 .58624 L
.50715 .50337 L
.50734 .35283 L
.50754 .585 L
.50777 .52444 L
.50801 .06035 L
.50823 .32058 L
.50844 .03284 L
.50868 .56275 L
.5088 .53907 L
.50894 .58993 L
.50918 .0175 L
.5094 .13301 L
.50953 .01648 L
.50966 .07261 L
.50991 .32442 L
.51006 .08717 L
.51019 .27898 L
.51032 .08076 L
.51045 .14844 L
.51067 .38597 L
.51091 .16148 L
.51114 .03604 L
.51135 .13522 L
.51158 .15466 L
.51171 .17107 L
.51184 .02045 L
.51208 .49374 L
.51222 .20905 L
.51235 .4236 L
.51257 .11994 L
.51278 .38501 L
.51301 .01853 L
.51326 .34641 L
.51339 .55197 L
.51352 .39472 L
.51377 .49696 L
.51401 .08782 L
.51423 .01653 L
.51446 .27248 L
.51468 .1412 L
.51487 .56151 L
.51508 .46774 L
.5153 .59043 L
.51554 .04829 L
.51575 .58127 L
.51597 .53188 L
.51696 .29384 L
Mistroke
.51709 .19283 L
.51724 .1125 L
.51738 .33985 L
.51751 .1599 L
.51775 .47528 L
.51787 .55209 L
.51801 .58464 L
.51825 .01735 L
.51848 .06185 L
.5186 .07983 L
.51874 .0293 L
.51899 .58785 L
.51922 .36578 L
.51946 .30327 L
.51969 .58764 L
.5199 .23009 L
.52013 .42433 L
.52034 .06276 L
.52057 .44048 L
.52082 .0335 L
.52095 .28089 L
.52108 .16589 L
.52133 .5454 L
.52157 .15375 L
.5218 .11515 L
.5222 .0622 L
.52243 .03689 L
.52264 .07343 L
.52287 .0202 L
.52307 .49947 L
.5233 .31463 L
.52354 .10765 L
.52378 .42583 L
.52401 .34574 L
.52413 .59029 L
.52427 .57753 L
.52451 .03325 L
.52474 .23204 L
.52498 .44381 L
.52519 .44669 L
.52542 .58524 L
.52555 .57739 L
.52568 .59233 L
.52593 .01671 L
.52606 .04586 L
.52619 .0474 L
.52633 .03515 L
.52648 .53059 L
.52661 .39825 L
.52675 .57752 L
Mistroke
.52688 .5543 L
.527 .12942 L
.52723 .43686 L
.52747 .22723 L
.5277 .01668 L
.52783 .03408 L
.52795 .45326 L
.52818 .46651 L
.52841 .02866 L
.52862 .42125 L
.52882 .09635 L
.52903 .01736 L
.52927 .27271 L
.5295 .59357 L
.52963 .59068 L
.52975 .30255 L
.53 .12969 L
.53014 .0172 L
.53027 .154 L
.5305 .02884 L
.53074 .59371 L
.53097 .34606 L
.53119 .5809 L
.53139 .03463 L
.5316 .07621 L
.5318 .58669 L
.53199 .49661 L
.53221 .59224 L
.53244 .15562 L
.53266 .12087 L
.53287 .59298 L
.53311 .25015 L
.53332 .33923 L
.53352 .17731 L
.53373 .02013 L
.53397 .26859 L
.53421 .27165 L
.53442 .59435 L
.53465 .43176 L
.5349 .34669 L
.53513 .57283 L
.53525 .11571 L
.53538 .08009 L
.53552 .2349 L
.53565 .09231 L
.53589 .58285 L
.5361 .45628 L
.53622 .02249 L
.53635 .02083 L
.53659 .44594 L
Mistroke
.53682 .57519 L
.53703 .39378 L
.53726 .54397 L
.5375 .04706 L
.53773 .03341 L
.53794 .26543 L
.53814 .36473 L
.53835 .02968 L
.5386 .54135 L
.53882 .4615 L
.53895 .58481 L
.53908 .59501 L
.53933 .02395 L
.53956 .22637 L
.5398 .39829 L
.54001 .52582 L
.54024 .57245 L
.54037 .59491 L
.54051 .53308 L
.54075 .13143 L
.54089 .28095 L
.54102 .08369 L
.54116 .33231 L
.54131 .4987 L
.54144 .57745 L
.54158 .35275 L
.54171 .36804 L
.54183 .59151 L
.54206 .39641 L
.54231 .27359 L
.54254 .52573 L
.54279 .01705 L
.54302 .42039 L
.54324 .28055 L
.54346 .08799 L
.54365 .59007 L
.54388 .50382 L
.54409 .56646 L
.54433 .40995 L
.54457 .29829 L
.54478 .02885 L
.54501 .14398 L
.54526 .55255 L
.54549 .47101 L
.54563 .3082 L
.54576 .43393 L
.54601 .15504 L
.54621 .57295 L
.54643 .55647 L
.54665 .59434 L
Mistroke
.54687 .27679 L
.54707 .45646 L
.54725 .36159 L
.54745 .1212 L
.54767 .12837 L
.54788 .44759 L
.54809 .1242 L
.54833 .58718 L
.54854 .37236 L
.54877 .45545 L
.54902 .21102 L
.54925 .0232 L
.54947 .35939 L
.54971 .01852 L
.54993 .02137 L
.55013 .58242 L
.55035 .44009 L
.55059 .51848 L
.55071 .38507 L
.55085 .30253 L
.55108 .58815 L
.5513 .49247 L
.55151 .01686 L
.55174 .08831 L
.55192 .03612 L
.55213 .50989 L
.55235 .57752 L
.55259 .16527 L
.55282 .20399 L
.55302 .45166 L
.55326 .37647 L
.55339 .56417 L
.55352 .55163 L
.55376 .30871 L
.55398 .50354 L
.55412 .56086 L
.55424 .52051 L
.55438 .46022 L
.55452 .57327 L
.55465 .5062 L
.55478 .49232 L
.55503 .32781 L
.55527 .19226 L
.5554 .03092 L
.55554 .04802 L
.55566 .3507 L
.55579 .49893 L
.55602 .31008 L
.55625 .34453 L
.55649 .04181 L
Mistroke
.55672 .07658 L
.55692 .40576 L
.55715 .50479 L
.55736 .32944 L
.55759 .46752 L
.55783 .18698 L
.55808 .30839 L
.5582 .01879 L
.55834 .02282 L
.55858 .32958 L
.5588 .19332 L
.55903 .19859 L
.55924 .06212 L
.55943 .13454 L
.55964 .32307 L
.55986 .30529 L
.5601 .03249 L
.56031 .56296 L
.56053 .58056 L
.56066 .44979 L
.5608 .48863 L
.56104 .11738 L
.56129 .25976 L
.56151 .20282 L
.56165 .28244 L
.56178 .07204 L
.56202 .58177 L
.56216 .58294 L
.56228 .22796 L
.56242 .27559 L
.56256 .56557 L
.56279 .57073 L
.56303 .23877 L
.56326 .14546 L
.56347 .58125 L
.56371 .13445 L
.56385 .06927 L
.56398 .35995 L
.56421 .07717 L
.56446 .52307 L
.56468 .55685 L
.56493 .06435 L
.56517 .06902 L
.56539 .05668 L
.5656 .42357 L
.5658 .0175 L
.56602 .01699 L
.56623 .38365 L
.56647 .1318 L
.56671 .38206 L
Mistroke
.56692 .04165 L
.56715 .02268 L
.5674 .59624 L
.56754 .54637 L
.56767 .54663 L
.56791 .12738 L
.56815 .0202 L
.56835 .55104 L
.56856 .30515 L
.56879 .40484 L
.56901 .03235 L
.56921 .59395 L
.56939 .59486 L
.56959 .02035 L
.5698 .45946 L
.57002 .57031 L
.57025 .59561 L
.57047 .44849 L
.57066 .39795 L
.5709 .15237 L
.57103 .32756 L
.57115 .55676 L
.57137 .44336 L
.5716 .59329 L
.57183 .55768 L
.57208 .06999 L
.57232 .4042 L
.57254 .1117 L
.57275 .05579 L
.57295 .30945 L
.57317 .31477 L
.57339 .02522 L
.57362 .1022 L
.57387 .56812 L
.57408 .26492 L
.57431 .44491 L
.57456 .28755 L
.5747 .24682 L
.57482 .59137 L
.57507 .0854 L
.5753 .02934 L
.5755 .34063 L
.57572 .02067 L
.57595 .01723 L
.57616 .4741 L
.57636 .01706 L
.57655 .0205 L
.57675 .46921 L
.57696 .03917 L
.57718 .51784 L
Mistroke
.57741 .51833 L
.57762 .46392 L
.57782 .51709 L
.57805 .45242 L
.57818 .59864 L
.57831 .11017 L
.57853 .03275 L
.57876 .02694 L
.57899 .01985 L
.57924 .58299 L
.57948 .57259 L
.5797 .42207 L
.57989 .5688 L
.58011 .36499 L
.58034 .21433 L
.58055 .18643 L
.58078 .07329 L
.58103 .31682 L
.58124 .17299 L
.58147 .16148 L
.58172 .28682 L
.58186 .33558 L
.58199 .01893 L
.58223 .51269 L
.58247 .57608 L
.58267 .28201 L
.58289 .59396 L
.58312 .59916 L
.58333 .17319 L
.58353 .59578 L
.58371 .59937 L
.58393 .0782 L
.58413 .59582 L
.58434 .16635 L
.58457 .17377 L
.58479 .07691 L
.58499 .18004 L
.58521 .10282 L
.58544 .06306 L
.58557 .21996 L
.58569 .57488 L
.58593 .55475 L
.58616 .59932 L
.5864 .11857 L
.58664 .05529 L
.58685 .55147 L
.58708 .59261 L
.58732 .15358 L
.58745 .5905 L
.58758 .58751 L
Mistroke
.58782 .35892 L
.58804 .42575 L
.58827 .46416 L
.58851 .56024 L
.58873 .59239 L
.58895 .0302 L
.58914 .24195 L
.58934 .45816 L
.58957 .58004 L
.58981 .08497 L
.58995 .21161 L
.59007 .59495 L
.5903 .55169 L
.59054 .48863 L
.59067 .56789 L
.59082 .2702 L
.59096 .23802 L
.59109 .55831 L
.59133 .10732 L
.59147 .1784 L
.59159 .6004 L
.59184 .13557 L
.59207 .2718 L
.59231 .16881 L
.59244 .08622 L
.59258 .11331 L
.59281 .08194 L
.59306 .34633 L
.59329 .4759 L
.5935 .02267 L
.59373 .17135 L
.59394 .52568 L
.59417 .52232 L
.59441 .29122 L
.59454 .58304 L
.59467 .51742 L
.59492 .36425 L
.59516 .05202 L
.59538 .30227 L
.59561 .44315 L
.59582 .42 L
.59601 .59768 L
.59622 .0185 L
.59645 .06617 L
.59669 .08367 L
.59689 .58542 L
.59712 .57424 L
.59724 .15863 L
.59738 .12025 L
.59763 .588 L
Mistroke
.59787 .19479 L
.5981 .4173 L
.59834 .03645 L
.59848 .04268 L
.59861 .32229 L
.59874 .41522 L
.59887 .54031 L
.599 .50189 L
.59915 .6008 L
.59937 .5574 L
.59962 .44976 L
.59984 .50559 L
.60005 .12947 L
.6003 .58706 L
.60043 .58318 L
.60056 .22878 L
.6008 .36294 L
.60104 .47384 L
.60127 .53671 L
.60152 .01778 L
.60176 .08897 L
.60197 .1395 L
.60219 .58893 L
.60239 .23938 L
.60262 .24566 L
.60282 .42043 L
.60306 .51319 L
.6033 .37133 L
.60351 .35976 L
.60374 .30794 L
.60399 .59501 L
.60413 .60138 L
.60426 .20952 L
.60451 .58106 L
.60474 .55201 L
.60494 .46555 L
.60512 .52783 L
.60532 .3238 L
.60553 .31482 L
.60575 .16268 L
.60598 .3569 L
.60619 .34977 L
.60638 .54774 L
.60662 .43563 L
.60675 .06731 L
.60687 .48086 L
.60709 .47848 L
.60732 .43168 L
.60754 .05427 L
.60774 .25417 L
Mistroke
.60796 .0387 L
.6082 .01722 L
.60843 .01735 L
.60857 .19362 L
.60869 .57293 L
.60891 .25564 L
.60915 .4315 L
.60939 .46214 L
.60961 .03513 L
.60981 .38797 L
.61003 .11259 L
.61026 .11735 L
.61039 .40395 L
.61052 .46242 L
.61065 .10936 L
.61077 .44875 L
.61091 .54164 L
.61104 .5186 L
.61127 .40051 L
.61148 .14278 L
.61172 .15838 L
.61196 .10536 L
.61218 .39151 L
.61238 .08006 L
.6126 .34883 L
.61282 .44255 L
.61301 .34693 L
.6132 .59878 L
.61342 .06386 L
.61362 .51736 L
.61386 .55853 L
.61399 .30917 L
.61411 .12186 L
.61434 .45938 L
.61458 .32836 L
.61479 .38575 L
.61499 .59163 L
.61521 .22978 L
.61545 .22992 L
.61568 .07309 L
.61581 .08831 L
.61593 .60196 L
.61618 .27764 L
.61632 .34938 L
.61645 .58372 L
.61666 .01835 L
.6169 .01851 L
.61714 .28493 L
.61737 .06743 L
.6175 .1024 L
Mistroke
.61764 .08431 L
.61778 .33369 L
.6179 .49971 L
.61813 .4616 L
.61838 .54173 L
.61851 .44981 L
.61865 .32407 L
.61889 .58889 L
.61905 .26359 L
.61919 .15423 L
.61932 .55709 L
.61946 .55842 L
.6197 .39293 L
.61982 .363 L
.61995 .07566 L
.6201 .16206 L
.62023 .02002 L
.62036 .48226 L
.62049 .5942 L
.62061 .09071 L
.62075 .01716 L
.62099 .28199 L
.62123 .4563 L
.62146 .02884 L
.62167 .51766 L
.62187 .05518 L
.62209 .51229 L
.62233 .39994 L
.62257 .33452 L
.62282 .02328 L
.62303 .58529 L
.62326 .60226 L
.62338 .04469 L
.62351 .12743 L
.62375 .05979 L
.62398 .16091 L
.6242 .50697 L
.62443 .3619 L
.62456 .04316 L
.62468 .44427 L
.62493 .04391 L
.62507 .09538 L
.62519 .57251 L
.62542 .58376 L
.62563 .02991 L
.62587 .0703 L
.62611 .16252 L
.62633 .37084 L
.62653 .01743 L
.62675 .42864 L
Mistroke
.62699 .31911 L
.62722 .42274 L
.62747 .02175 L
.62761 .01751 L
.62774 .27381 L
.62787 .59061 L
.62799 .16737 L
.62812 .06981 L
.62826 .21898 L
.6285 .01718 L
.62864 .09032 L
.62876 .5578 L
.6289 .58465 L
.62905 .3164 L
.6293 .05488 L
.62943 .14507 L
.62956 .58114 L
.6298 .59501 L
.63005 .15551 L
.63029 .03135 L
.63052 .02755 L
.63073 .50216 L
.63095 .10802 L
.63119 .10371 L
.6314 .43494 L
.63165 .04001 L
.63188 .05814 L
.6321 .60223 L
.6323 .29015 L
.63252 .57159 L
.63275 .52334 L
.63298 .36004 L
.63311 .0173 L
.63323 .60271 L
.63345 .09042 L
.63369 .02377 L
.63381 .59047 L
.63394 .40466 L
.63418 .33816 L
.63433 .40324 L
.63446 .16394 L
.63459 .32933 L
.63472 .59864 L
.63497 .41869 L
.6352 .60119 L
.63533 .37524 L
.63546 .19495 L
.6356 .34156 L
.63573 .60291 L
.63586 .17431 L
Mistroke
.63599 .01855 L
.63624 .1035 L
.63639 .3223 L
.63653 .22211 L
.63666 .14428 L
.63679 .39828 L
.63702 .60112 L
.63716 .30965 L
.63728 .22663 L
.63753 .03851 L
.63766 .18523 L
.63779 .58419 L
.63801 .11846 L
.63826 .28036 L
.63849 .04375 L
.6387 .60275 L
.63893 .26705 L
.63915 .35106 L
.63937 .60017 L
.63962 .45881 L
.63984 .17407 L
.64007 .01921 L
.64029 .60115 L
.64049 .50587 L
.64072 .58708 L
.64097 .30623 L
.6411 .59774 L
.64124 .59093 L
.64138 .16553 L
.6415 .39609 L
.64174 .37716 L
.64196 .37193 L
.64208 .20185 L
.64221 .58274 L
.64245 .5827 L
.64269 .45529 L
.64292 .59595 L
.64306 .23673 L
.64318 .3513 L
.64332 .45587 L
.64345 .55056 L
.6437 .58587 L
.64383 .36482 L
.64397 .20651 L
.64411 .31731 L
.64425 .1311 L
.64438 .32592 L
.64451 .5846 L
.64474 .47192 L
.64487 .04037 L
Mistroke
.645 .53532 L
.64524 .32314 L
.64538 .51758 L
.64551 .32695 L
.64573 .03504 L
.64598 .03339 L
.64621 .09762 L
.64642 .4904 L
.64667 .57793 L
.64679 .01769 L
.64692 .23076 L
.64716 .29515 L
.64738 .53457 L
.64752 .21857 L
.64765 .1239 L
.64789 .148 L
.64802 .50854 L
.64814 .23558 L
.64828 .02542 L
.64842 .02667 L
.64865 .44151 L
.64889 .45379 L
.64911 .52568 L
.64932 .40217 L
.64955 .60265 L
.64968 .22778 L
.6498 .35145 L
.65004 .16891 L
.65018 .42687 L
.65031 .35858 L
.65053 .12746 L
.65076 .39621 L
.65096 .15406 L
.65118 .53113 L
.65141 .35697 L
.65154 .01921 L
.65166 .59991 L
.6519 .5327 L
.65212 .0171 L
.65232 .37614 L
.65254 .14599 L
.65273 .3354 L
.65293 .02511 L
.65315 .50097 L
.65339 .545 L
.65362 .38229 L
.65382 .55472 L
.65406 .54462 L
.65429 .46361 L
.6545 .55864 L
Mistroke
.65472 .22544 L
.65496 .26976 L
.65508 .28683 L
.65521 .58632 L
.65545 .60248 L
.65567 .08464 L
.65589 .33142 L
.6561 .1202 L
.65629 .05946 L
.6565 .5438 L
.65673 .04055 L
.65696 .02603 L
.65719 .33888 L
.65739 .01754 L
.65764 .06904 L
.65776 .45574 L
.6579 .60267 L
.65814 .60195 L
.65836 .13446 L
.6585 .02086 L
.65862 .47944 L
.65887 .45059 L
.659 .60032 L
.65912 .04779 L
.65926 .05055 L
.65941 .03116 L
.65963 .53115 L
.65987 .49516 L
.6601 .53307 L
.66031 .3309 L
.66054 .58034 L
.66067 .39645 L
.66079 .15165 L
.66104 .01872 L
.66118 .1216 L
.6613 .60016 L
.66153 .17833 L
.66174 .57378 L
.66197 .54265 L
.66222 .60332 L
.66234 .02724 L
.66248 .20552 L
.66273 .1487 L
.66297 .32048 L
.66319 .38098 L
.6634 .59218 L
.66362 .12495 L
.66384 .6014 L
.66403 .59788 L
.66426 .12322 L
Mistroke
.6645 .0432 L
.66471 .24439 L
.66493 .29396 L
.66505 .46975 L
.66519 .13373 L
.66544 .30044 L
.66569 .2324 L
.66591 .23325 L
.66615 .32446 L
.66629 .58387 L
.66642 .21714 L
.66656 .02094 L
.66668 .60203 L
.66682 .41011 L
.66696 .2896 L
.66719 .10384 L
.66743 .18595 L
.66764 .06671 L
.66787 .36294 L
.66801 .58421 L
.66814 .16838 L
.66826 .45712 L
.66839 .41164 L
.66861 .09252 L
.66886 .06177 L
.6691 .05112 L
.66933 .58089 L
.66958 .47445 L
.66971 .26966 L
.66985 .04472 L
.67008 .20271 L
.67021 .60013 L
.67033 .05035 L
.67055 .57648 L
.67078 .18721 L
.67099 .59515 L
.67122 .02601 L
.67143 .49606 L
.67162 .37844 L
.67185 .06671 L
.6721 .05648 L
.67233 .48546 L
.67254 .01812 L
.67277 .48483 L
.67301 .50931 L
.67324 .4589 L
.67345 .50299 L
.6737 .46204 L
.67384 .60288 L
.67397 .13498 L
Mistroke
.67421 .01858 L
.67434 .42441 L
.67446 .11691 L
.67459 .33778 L
.67472 .60089 L
.67496 .54059 L
.6751 .10936 L
.67522 .43037 L
.67536 .60173 L
.67551 .60191 L
.67563 .04733 L
.67577 .08783 L
.6759 .59187 L
.67602 .01702 L
.67625 .48218 L
.67649 .56179 L
.67671 .02002 L
.67694 .25858 L
.67719 .23674 L
.67742 .58935 L
.67763 .16502 L
.67783 .19976 L
.67805 .552 L
.67826 .3318 L
.6785 .59641 L
.67874 .59726 L
.67895 .33112 L
.67918 .57816 L
.67943 .60123 L
.67957 .42537 L
.67969 .07157 L
.67994 .05 L
.68017 .41958 L
.68039 .12451 L
.68059 .16847 L
.68082 .18443 L
.68103 .20832 L
.68123 .3273 L
.68142 .01725 L
.68162 .06455 L
.68183 .56159 L
.68204 .22161 L
.68227 .60262 L
.68249 .05485 L
.68269 .03258 L
.68292 .43197 L
.68305 .48809 L
.68317 .18269 L
.68339 .48646 L
.68363 .14935 L
Mistroke
.68386 .22657 L
.68411 .12294 L
.68434 .49161 L
.68456 .05848 L
.68477 .60124 L
.68497 .59755 L
.6852 .04582 L
.68541 .55548 L
.68564 .13987 L
.68589 .15919 L
.6861 .58485 L
.68633 .1272 L
.68657 .22373 L
.68671 .02613 L
.68684 .51361 L
.68709 .47449 L
.68732 .56593 L
.68752 .59459 L
.68774 .04895 L
.68797 .56098 L
.68818 .02451 L
.68838 .02563 L
.68856 .26195 L
.68876 .09724 L
.68898 .21992 L
.68919 .55221 L
.68942 .38572 L
.68964 .35806 L
.68984 .3062 L
.69005 .15234 L
.69029 .07754 L
.69042 .53446 L
.69054 .06546 L
.69078 .02782 L
.691 .59399 L
.69125 .59507 L
.69148 .24742 L
.69169 .60288 L
.69194 .55435 L
.69216 .12816 L
.69229 .44346 L
.69242 .0172 L
.69266 .17433 L
.69289 .51609 L
.6931 .52955 L
.69333 .02578 L
.69357 .0839 L
.69378 .0584 L
.69397 .0655 L
.69419 .43117 L
Mistroke
.6944 .6026 L
.69463 .01709 L
.69488 .02687 L
.695 .59109 L
.69514 .12691 L
.69538 .01701 L
.69561 .55505 L
.69585 .56418 L
.69606 .5951 L
.69629 .02535 L
.69642 .22274 L
.69655 .54762 L
.6968 .34256 L
.69694 .01697 L
.69706 .60241 L
.6972 .34158 L
.69735 .19261 L
.69759 .02038 L
.69782 .5895 L
.69806 .60209 L
.6982 .39302 L
.69833 .15692 L
.69855 .32938 L
.69876 .56444 L
.69899 .01974 L
.69924 .07423 L
.69948 .26415 L
.69961 .26942 L
.69974 .05838 L
.69998 .44448 L
.7002 .08068 L
.70043 .54913 L
.70064 .1499 L
.70083 .47869 L
.70104 .24207 L
.70126 .38368 L
.7015 .03992 L
.70171 .12097 L
.70193 .51589 L
.70206 .0916 L
.70219 .16204 L
.70244 .24779 L
.70268 .54361 L
.70291 .04923 L
.70305 .20069 L
.70317 .53152 L
.70342 .22119 L
.70355 .07093 L
.70368 .53034 L
.70381 .08714 L
Mistroke
.70396 .01713 L
.70418 .60231 L
.70443 .42818 L
.70463 .60127 L
.70486 .01879 L
.705 .25582 L
.70513 .45595 L
.70525 .26534 L
.70538 .50577 L
.70561 .13592 L
.70585 .21972 L
.70609 .58408 L
.70634 .54955 L
.70657 .05599 L
.70678 .4588 L
.70702 .10793 L
.70725 .47605 L
.7075 .5911 L
.70763 .40449 L
.70776 .1453 L
.70797 .01791 L
.70817 .05906 L
.70838 .20473 L
.70861 .24268 L
.70884 .39062 L
.70908 .06512 L
.70931 .52268 L
.70951 .36639 L
.70964 .24901 L
.70977 .05786 L
.71002 .21611 L
.71016 .55775 L
.7103 .59747 L
.71043 .02564 L
.71057 .23622 L
.7107 .55415 L
.71082 .23699 L
.71096 .59316 L
.71109 .12441 L
.71132 .27997 L
.71145 .51945 L
.71157 .23799 L
.7118 .32761 L
.71201 .58811 L
.71224 .02965 L
.71248 .01688 L
.71261 .59527 L
.71274 .1567 L
.71299 .05062 L
.71323 .11994 L
Mistroke
.71345 .41172 L
.7137 .12414 L
.71382 .5693 L
.71395 .311 L
.71419 .01826 L
.71441 .55158 L
.71455 .0552 L
.71467 .52234 L
.71491 .52071 L
.71504 .02517 L
.71517 .60215 L
.7153 .22455 L
.71545 .04936 L
.71567 .60197 L
.71591 .3293 L
.71613 .28999 L
.71634 .08549 L
.71657 .59415 L
.7167 .03441 L
.71682 .59663 L
.71707 .47746 L
.7172 .05168 L
.71733 .58037 L
.71755 .04571 L
.71778 .58507 L
.71798 .60195 L
.7182 .13638 L
.71843 .60001 L
.71856 .1227 L
.71868 .59442 L
.71891 .19534 L
.71914 .54259 L
.71934 .41124 L
.71956 .03128 L
.71977 .15548 L
.71995 .08752 L
.72017 .37037 L
.72041 .02451 L
.72064 .59828 L
.72084 .47895 L
.72106 .0235 L
.7213 .54686 L
.72153 .02024 L
.72173 .01917 L
.72198 .34719 L
.7221 .07944 L
.72223 .34989 L
.72247 .38389 L
.72269 .57252 L
.7229 .45232 L
Mistroke
.72312 .01929 L
.72331 .46811 L
.72351 .43214 L
.72374 .022 L
.72398 .44441 L
.7242 .03414 L
.72441 .02319 L
.72465 .24658 L
.72477 .18214 L
.72491 .20128 L
.72515 .59475 L
.72537 .18907 L
.72551 .58715 L
.72563 .03283 L
.72587 .50907 L
.72601 .30432 L
.72613 .44659 L
.72627 .4552 L
.72642 .15901 L
.72666 .02265 L
.7268 .44845 L
.72693 .14164 L
.72716 .35637 L
.72741 .59069 L
.72763 .10147 L
.72784 .06048 L
.72807 .46638 L
.72831 .0512 L
.72854 .55489 L
.72868 .14863 L
.7288 .57947 L
.72905 .55179 L
.72918 .07552 L
.72932 .5262 L
.72956 .58475 L
.7298 .02449 L
.73003 .60111 L
.73024 .47116 L
.73037 .24965 L
.73052 .01743 L
.73065 .54107 L
.73077 .0173 L
.73101 .56818 L
.73126 .54553 L
.73138 .06773 L
.73152 .55645 L
.73177 .57664 L
.73192 .53733 L
.73207 .21091 L
.7322 .37848 L
Mistroke
.73234 .58633 L
.73257 .01968 L
.73279 .42962 L
.73303 .02138 L
.73317 .43601 L
.7333 .08111 L
.73353 .36459 L
.73367 .45417 L
.73379 .28251 L
.73392 .46506 L
.73404 .43335 L
.73418 .52353 L
.73431 .04306 L
.73454 .3073 L
.73477 .18368 L
.73497 .26942 L
.73519 .01811 L
.73543 .57097 L
.73564 .15851 L
.73578 .5781 L
.73591 .06648 L
.73614 .59266 L
.73638 .11309 L
.73651 .36281 L
.73663 .0699 L
.73686 .59712 L
.7371 .06411 L
.73731 .28993 L
.73751 .08024 L
.73773 .48123 L
.73796 .07919 L
.73821 .31603 L
.73835 .59969 L
.73848 .0183 L
.73872 .45755 L
.73884 .01714 L
.73897 .5493 L
.7392 .03364 L
.73945 .12909 L
.73968 .53051 L
.73989 .59277 L
.7401 .60031 L
.74031 .38058 L
.74052 .41307 L
.7407 .40736 L
.74092 .57877 L
.74116 .16979 L
.74138 .59752 L
.74159 .5951 L
.7418 .42479 L
Mistroke
.742 .57571 L
.74222 .17646 L
.74245 .53796 L
.7427 .18297 L
.74293 .36933 L
.74314 .23631 L
.74337 .26166 L
.7436 .41934 L
.74381 .24609 L
.74404 .3655 L
.74428 .01877 L
.7445 .14179 L
.74469 .01649 L
.74491 .26382 L
.74514 .32416 L
.74527 .40347 L
.7454 .45482 L
.74553 .32827 L
.74567 .01703 L
.74591 .51071 L
.74604 .31557 L
.74617 .3763 L
.7464 .21893 L
.74662 .59314 L
.74674 .19205 L
.74687 .52107 L
.7471 .10188 L
.74723 .53692 L
.74737 .09038 L
.7475 .42165 L
.74762 .03114 L
.74786 .59273 L
.7481 .35018 L
.74822 .33754 L
.74836 .50982 L
.7486 .10709 L
.74875 .02341 L
.7489 .24187 L
.74902 .32078 L
.74916 .03512 L
.74939 .54115 L
.74952 .04239 L
.74964 .41829 L
.74989 .07243 L
.75003 .23088 L
.75015 .3271 L
.75037 .5625 L
.7506 .02356 L
.75084 .37898 L
.75107 .01764 L
Mistroke
.75131 .54707 L
.75143 .06451 L
.75157 .58403 L
.7518 .03741 L
.75203 .12239 L
.75216 .43259 L
.75229 .06173 L
.75252 .53221 L
.75266 .11725 L
.75278 .59694 L
.75292 .02868 L
.75306 .253 L
.7533 .55965 L
.75344 .01983 L
.75357 .56435 L
.7538 .1625 L
.75405 .59879 L
.75427 .44864 L
.75447 .57325 L
.7547 .14273 L
.75494 .56658 L
.75517 .07698 L
.75539 .0202 L
.75563 .57966 L
.75575 .1416 L
.75588 .50359 L
.75611 .55789 L
.75635 .10369 L
.75657 .55669 L
.75678 .45724 L
.75699 .51053 L
.75719 .09701 L
.75741 .28134 L
.75764 .51666 L
.75786 .21034 L
.75806 .31744 L
.75825 .36765 L
.75845 .08502 L
.75869 .58085 L
.7589 .53019 L
.75915 .3845 L
.75938 .34825 L
.7596 .15016 L
.7598 .39123 L
.76001 .34034 L
.76025 .18438 L
.76048 .46878 L
.76062 .17511 L
.76074 .59782 L
.76096 .43474 L
Mistroke
.76119 .06714 L
.76131 .56827 L
.76145 .05525 L
.76168 .54782 L
.76183 .13401 L
.76196 .3258 L
.76209 .04174 L
.76222 .55335 L
.76247 .3691 L
.7627 .43755 L
.76283 .20773 L
.76295 .59895 L
.76309 .13955 L
.76322 .44007 L
.76335 .07631 L
.76349 .41306 L
.76373 .46937 L
.76388 .20673 L
.76402 .10018 L
.76415 .37053 L
.76429 .08596 L
.76452 .34411 L
.76465 .29553 L
.76477 .04872 L
.76502 .29186 L
.76516 .52375 L
.76528 .26419 L
.76551 .02927 L
.76575 .41038 L
.76598 .05144 L
.7662 .11296 L
.76642 .50758 L
.76666 .17188 L
.76686 .50401 L
.76708 .23427 L
.76731 .37593 L
.76745 .21086 L
.76757 .05944 L
.7678 .59161 L
.76802 .34449 L
.76823 .44731 L
.76845 .15408 L
.76864 .53944 L
.76884 .41015 L
.76906 .59753 L
.7693 .02057 L
.76953 .3773 L
.76973 .18061 L
.76997 .31176 L
.77009 .0342 L
Mistroke
.77023 .53439 L
.77046 .08305 L
.77069 .46635 L
.77081 .29482 L
.77095 .4012 L
.77119 .12791 L
.77132 .53501 L
.77145 .2955 L
.77158 .47809 L
.77173 .09971 L
.77197 .27159 L
.77211 .53327 L
.77224 .19693 L
.77247 .32026 L
.77272 .02167 L
.77294 .18606 L
.77315 .10486 L
.77338 .5875 L
.77363 .0863 L
.77376 .56981 L
.77388 .0875 L
.77411 .24102 L
.77435 .10318 L
.77449 .59812 L
.77462 .05766 L
.77483 .02516 L
.77506 .54379 L
.77531 .02444 L
.77554 .50157 L
.77567 .17655 L
.77581 .59796 L
.77594 .01874 L
.77606 .48758 L
.77629 .26547 L
.77654 .59054 L
.77667 .09558 L
.77681 .59631 L
.77705 .2078 L
.7772 .04857 L
.77735 .22154 L
.77748 .30832 L
.77762 .04082 L
.77774 .34136 L
.77788 .21769 L
.77812 .5341 L
.77835 .11611 L
.77857 .01724 L
.77881 .58165 L
.77894 .01803 L
.77906 .48226 L
Mistroke
.7792 .13417 L
.77932 .11271 L
.77946 .27395 L
.77959 .3411 L
.77981 .58099 L
.78004 .08023 L
.78026 .05938 L
.78046 .08674 L
.7807 .51045 L
.78083 .07232 L
.78095 .25223 L
.78118 .59697 L
.78142 .10067 L
.78165 .14075 L
.78178 .57101 L
.7819 .21721 L
.78212 .07565 L
.78236 .29204 L
.78257 .09991 L
.78276 .28256 L
.78298 .29635 L
.78321 .03222 L
.78345 .50986 L
.78358 .18415 L
.7837 .06302 L
.78395 .41476 L
.78409 .32638 L
.78422 .5481 L
.78444 .2347 L
.78469 .44938 L
.78492 .51796 L
.78514 .57041 L
.78534 .34126 L
.78555 .28541 L
.78575 .01731 L
.78594 .54531 L
.78616 .55052 L
.78639 .27302 L
.78662 .08749 L
.78682 .39961 L
.78703 .53477 L
.78723 .35648 L
.78745 .40479 L
.78769 .47617 L
.78792 .02572 L
.78816 .59682 L
.78837 .50869 L
.7886 .52489 L
.78885 .23493 L
.78908 .58304 L
Mistroke
.7892 .45189 L
.78933 .07727 L
.78947 .47395 L
.7896 .02356 L
.78984 .55864 L
.79005 .56377 L
.79018 .41664 L
.79031 .07195 L
.79054 .57614 L
.79077 .50327 L
.79098 .56844 L
.79122 .05329 L
.79145 .1279 L
.79165 .12967 L
.79186 .26908 L
.79209 .04001 L
.79231 .01711 L
.79255 .56792 L
.79278 .35441 L
.7929 .01821 L
.79304 .59488 L
.79328 .03243 L
.79351 .38819 L
.79376 .21811 L
.79396 .48574 L
.79419 .08853 L
.79432 .39713 L
.79446 .14655 L
.79471 .52425 L
.79484 .05249 L
.79497 .35174 L
.79511 .12055 L
.79526 .5169 L
.79539 .01763 L
.79553 .5251 L
.79566 .04024 L
.79579 .43743 L
.79602 .53351 L
.79626 .11669 L
.79649 .50702 L
.79674 .0171 L
.79698 .46611 L
.7972 .51828 L
.79741 .52425 L
.79761 .01644 L
.79784 .20481 L
.79805 .10316 L
.79828 .58085 L
.79853 .01604 L
.79874 .07579 L
Mistroke
.79897 .14744 L
.7991 .59051 L
.79924 .07824 L
.79937 .58724 L
.79949 .24277 L
.79972 .02363 L
.79997 .58409 L
.80018 .59207 L
.80038 .14494 L
.8006 .20841 L
.80083 .58603 L
.80108 .0972 L
.80132 .5928 L
.80153 .52585 L
.80176 .46798 L
.80198 .36795 L
.80218 .53749 L
.80241 .47941 L
.80262 .47254 L
.80283 .50138 L
.80301 .23859 L
.80321 .58612 L
.80343 .5952 L
.80366 .28514 L
.80379 .15893 L
.80391 .52931 L
.80413 .5907 L
.80436 .20271 L
.80457 .43681 L
.80477 .40652 L
.80499 .37811 L
.80522 .5545 L
.80545 .08364 L
.80558 .44133 L
.80571 .54299 L
.80595 .18983 L
.80609 .30064 L
.80622 .05753 L
.80645 .34786 L
.80669 .19386 L
.80692 .07074 L
.80714 .03156 L
.80734 .32579 L
.80755 .39595 L
.80775 .57337 L
.80794 .12825 L
.80816 .13365 L
.80839 .23018 L
.80861 .43451 L
.80882 .12066 L
Mistroke
.80905 .58075 L
.80927 .5947 L
.80947 .13143 L
.80968 .05369 L
.80992 .52437 L
.81016 .04435 L
.81037 .20444 L
.8106 .03505 L
.81085 .50529 L
.81108 .13203 L
.8112 .034 L
.81133 .59383 L
.81147 .01967 L
.8116 .54646 L
.81183 .26801 L
.81205 .29246 L
.81229 .01755 L
.81254 .59457 L
.81275 .36476 L
.81297 .43045 L
.81317 .1959 L
.81338 .54852 L
.81362 .02481 L
.81386 .27865 L
.81409 .4278 L
.8143 .05255 L
.81452 .17888 L
.81477 .56314 L
.815 .35138 L
.81521 .59348 L
.81546 .03109 L
.8156 .58306 L
.81573 .25416 L
.81597 .02326 L
.81609 .19491 L
.81622 .57038 L
.81635 .11962 L
.81648 .35917 L
.81672 .53066 L
.81686 .01776 L
.81698 .33221 L
.81712 .34197 L
.81727 .49609 L
.81739 .4802 L
.81753 .09635 L
.81766 .58472 L
.81778 .51921 L
.81801 .38975 L
.81825 .02157 L
.81848 .09549 L
Mistroke
.81873 .55544 L
.81896 .21992 L
.81918 .37883 L
.8194 .55633 L
.81959 .06325 L
.81982 .12778 L
.82003 .024 L
.82026 .12171 L
.82051 .57677 L
.82072 .43301 L
.82095 .5845 L
.8212 .05535 L
.82134 .55211 L
.82146 .40999 L
.82171 .08818 L
.82194 .40339 L
.82214 .10989 L
.82236 .21824 L
.82259 .06736 L
.8228 .29396 L
.823 .46613 L
.82319 .49727 L
.82339 .29544 L
.8236 .02749 L
.82382 .05476 L
.82405 .02952 L
.82426 .02948 L
.82446 .59308 L
.82469 .45213 L
.82482 .01716 L
.82495 .18885 L
.82517 .16392 L
.8254 .52276 L
.82563 .5931 L
.82588 .01931 L
.82612 .22239 L
.82634 .09975 L
.82655 .01642 L
.82675 .58757 L
.82697 .54484 L
.82719 .55174 L
.82742 .52821 L
.82767 .02185 L
.82788 .19652 L
.82811 .02936 L
.82836 .55319 L
.8285 .05391 L
.82862 .2049 L
.82887 .51226 L
.8291 .19861 L
Mistroke
.8293 .51927 L
.82952 .43128 L
.82975 .56965 L
.82997 .37785 L
.83017 .08532 L
.83035 .17885 L
.83056 .01834 L
.83076 .54672 L
.83098 .58737 L
.83121 .53098 L
.83143 .5921 L
.83162 .03002 L
.83186 .25835 L
.83199 .55956 L
.83211 .31842 L
.83233 .35007 L
.83256 .04007 L
.83279 .03751 L
.83292 .53303 L
.83305 .57484 L
.83327 .59074 L
.8335 .34402 L
.8337 .26838 L
.83391 .01585 L
.83414 .1398 L
.83435 .02833 L
.83459 .25846 L
.83472 .54498 L
.83484 .22106 L
.83509 .30524 L
.83523 .31356 L
.83535 .01627 L
.83558 .04872 L
.83583 .59114 L
.83606 .47328 L
.83627 .59167 L
.83647 .04195 L
.83669 .0562 L
.83689 .58088 L
.83707 .11572 L
.83729 .31582 L
.83753 .01892 L
.83775 .01975 L
.83796 .42583 L
.83819 .11253 L
.83841 .20661 L
.8386 .46085 L
.83882 .1567 L
.83905 .46626 L
.8393 .28847 L
Mistroke
.83951 .58796 L
.83974 .46057 L
.84021 .20245 L
.84034 .58625 L
.84048 .01641 L
.84073 .58628 L
.84096 .5305 L
.84118 .59054 L
.84141 .3168 L
.84155 .11371 L
.84167 .43861 L
.84188 .11843 L
.84208 .42293 L
.84229 .56422 L
.84253 .35744 L
.84277 .05771 L
.843 .22655 L
.84321 .06439 L
.84343 .05816 L
.84367 .27134 L
.8439 .27533 L
.84404 .58632 L
.84416 .50638 L
.8443 .02652 L
.84443 .45593 L
.84456 .57527 L
.84469 .06106 L
.84493 .12407 L
.84507 .5908 L
.8452 .3955 L
.84534 .09249 L
.84549 .33464 L
.84572 .34748 L
.84585 .01599 L
.84597 .06914 L
.84621 .48701 L
.84635 .30869 L
.84647 .05224 L
.8467 .20095 L
.84694 .02027 L
.84717 .01683 L
.84738 .39798 L
.84762 .22485 L
.84784 .41134 L
.84804 .18837 L
.84826 .01535 L
.8485 .10991 L
.84863 .57269 L
.84875 .5828 L
.84899 .51425 L
Mistroke
.84921 .58326 L
.84942 .05445 L
.84964 .06123 L
.84983 .17159 L
.85003 .28684 L
.85025 .51427 L
.85049 .29137 L
.85072 .45425 L
.85092 .25392 L
.85116 .55584 L
.85128 .58115 L
.85142 .09211 L
.85166 .01622 L
.85188 .07968 L
.85201 .08003 L
.85214 .57254 L
.85238 .51615 L
.85252 .0328 L
.85264 .08051 L
.85278 .58918 L
.85292 .01836 L
.85317 .36829 L
.85331 .40686 L
.85343 .06193 L
.85367 .01691 L
.85392 .3888 L
.85414 .1503 L
.85435 .25813 L
.85457 .32157 L
.85482 .0153 L
.85495 .32431 L
.85507 .52545 L
.8553 .49702 L
.85555 .46987 L
.85568 .03724 L
.85581 .35348 L
.85603 .01532 L
.85626 .04581 L
.85651 .44195 L
.85673 .38985 L
.85698 .51584 L
.85712 .03228 L
.85725 .4046 L
.85749 .5718 L
.85761 .58488 L
.85774 .16334 L
.85788 .34243 L
.85803 .0694 L
.85818 .51467 L
.85831 .46512 L
Mistroke
.85843 .32382 L
.85856 .01648 L
.85869 .52543 L
.85882 .53557 L
.85906 .31764 L
.85919 .0476 L
.85932 .25928 L
.85954 .17896 L
.85978 .48437 L
.86 .07618 L
.8602 .52825 L
.86042 .57377 L
.86066 .56446 L
.86078 .40571 L
.86091 .02925 L
.86105 .56038 L
.86118 .35358 L
.86142 .14075 L
.86156 .20314 L
.86168 .53533 L
.86192 .58786 L
.86213 .26347 L
.86237 .45717 L
.86262 .43499 L
.86285 .35755 L
.86298 .01523 L
.8631 .07922 L
.86333 .018 L
.86356 .04876 L
.86377 .31189 L
.86397 .1771 L
.86419 .03215 L
.86442 .01534 L
.86467 .36453 L
.86481 .36953 L
.86494 .02214 L
.86517 .0608 L
.86531 .53147 L
.86543 .58832 L
.86565 .57279 L
.8659 .34554 L
.86613 .27159 L
.86635 .58754 L
.86655 .01781 L
.86676 .34962 L
.86696 .31722 L
.86715 .58674 L
.86737 .31756 L
.8676 .49468 L
.86783 .29703 L
Mistroke
.86803 .15571 L
.86824 .58613 L
.86844 .01693 L
.86866 .25218 L
.8689 .10927 L
.86913 .04594 L
.86938 .20676 L
.86959 .14479 L
.86981 .16578 L
.87352 .45074 L
.87377 .4429 L
.8739 .13168 L
.87404 .30392 L
.87419 .1352 L
.87432 .35121 L
.87445 .58768 L
.87459 .0601 L
.87472 .14651 L
.87486 .52298 L
.87499 .04691 L
.87512 .04185 L
.87535 .09522 L
.8756 .56427 L
.87584 .55266 L
.87598 .07162 L
.87611 .01928 L
.87634 .0305 L
.87659 .05205 L
.87681 .21809 L
.87702 .31846 L
.87724 .03415 L
.87748 .09712 L
.87772 .0221 L
.87785 .27116 L
.87797 .29164 L
.8782 .12647 L
.87842 .12654 L
.87865 .47169 L
.87889 .2276 L
.87902 .01622 L
.87916 .43259 L
.87929 .58154 L
.87941 .5805 L
.87955 .0781 L
.87968 .03564 L
.87982 .56837 L
.87997 .02581 L
.8801 .12471 L
.88023 .19158 L
.88036 .55989 L
Mistroke
.8805 .15878 L
.88063 .01526 L
.88077 .49804 L
.88091 .52935 L
.88103 .43915 L
.88126 .55439 L
.88151 .33722 L
.88174 .45124 L
.88196 .33525 L
.88219 .2625 L
.88244 .53108 L
.88266 .02292 L
.88286 .55578 L
.88308 .11972 L
.88332 .08319 L
.88345 .49445 L
.88357 .57259 L
.88371 .33372 L
.88385 .13354 L
.8841 .23724 L
.88423 .58427 L
.88436 .41399 L
.8846 .37578 L
.88482 .51546 L
.88494 .54724 L
.88507 .4994 L
.88531 .45735 L
.88544 .35774 L
.88557 .07767 L
.8858 .23935 L
.88593 .01755 L
.88607 .43734 L
.8862 .57457 L
.88632 .56112 L
.88655 .58214 L
.88677 .1504 L
.88701 .13562 L
.88714 .53792 L
.88727 .58639 L
.88748 .01966 L
.88768 .46874 L
.88789 .0153 L
.88813 .05389 L
.88835 .29179 L
.8886 .12946 L
.88883 .3565 L
.88904 .2628 L
.88929 .52974 L
.88952 .43739 L
.88965 .56101 L
Mistroke
.88979 .03721 L
.88991 .02446 L
.89005 .18078 L
.89017 .41479 L
.89031 .5264 L
.89056 .31738 L
.8907 .2619 L
.89084 .54518 L
.89097 .3813 L
.89111 .01563 L
.89133 .18209 L
.89146 .01591 L
.89158 .01869 L
.89183 .09932 L
.89196 .56149 L
.89209 .57285 L
.8923 .08042 L
.89253 .01535 L
.89278 .04887 L
.893 .10621 L
.89324 .06318 L
.89336 .03338 L
.8935 .18741 L
.89373 .13076 L
.89395 .11734 L
.89409 .06956 L
.89421 .26149 L
.89445 .25218 L
.89458 .57426 L
.89471 .58368 L
.89484 .22159 L
.89499 .24004 L
.89523 .3988 L
.89537 .52147 L
.89549 .33862 L
.89572 .49875 L
.89597 .30632 L
.89619 .56796 L
.8964 .07873 L
.89662 .42863 L
.89686 .33224 L
.8971 .42714 L
.89731 .43185 L
.89755 .43934 L
.89767 .47259 L
.8978 .54726 L
.89803 .40855 L
.89827 .43654 L
.89849 .09419 L
.8987 .53375 L
Mistroke
.8989 .01547 L
.89909 .1261 L
.89931 .07226 L
.89951 .39887 L
.89973 .07477 L
.89993 .35911 L
.90014 .11988 L
.90037 .32759 L
.90061 .46862 L
.90082 .25824 L
.90106 .47485 L
.9013 .34111 L
.90151 .09031 L
.90171 .25953 L
.90193 .07097 L
.90216 .20108 L
.9023 .02767 L
.90242 .07664 L
.90255 .4918 L
.90269 .29858 L
.90293 .27342 L
.90307 .02478 L
.90319 .15422 L
.90343 .11499 L
.90365 .29234 L
.90389 .04237 L
.90413 .09379 L
.90436 .34818 L
.90449 .05909 L
.90461 .02371 L
.90486 .05838 L
.90499 .54046 L
.90512 .57975 L
.90534 .39145 L
.90559 .54871 L
.90582 .39882 L
.90604 .05197 L
.90617 .06974 L
.90631 .57787 L
.90644 .40044 L
.90656 .30689 L
.90679 .48235 L
.90704 .28977 L
.90717 .07919 L
.9073 .18098 L
.90755 .41441 L
.9077 .14841 L
.90784 .26738 L
.90797 .50732 L
.90811 .35939 L
Mistroke
.90834 .55536 L
.90855 .05654 L
.90878 .17012 L
.90902 .27605 L
.90922 .01986 L
.90943 .52893 L
.90966 .14544 L
.90988 .45335 L
.91001 .23054 L
.91013 .29336 L
.91027 .05911 L
.91041 .20278 L
.91065 .02079 L
.91078 .23672 L
.91091 .31238 L
.91114 .0159 L
.91136 .58062 L
.91148 .58366 L
.91161 .51653 L
.91184 .46286 L
.91197 .5654 L
.91211 .38303 L
.91224 .14769 L
.91236 .20491 L
.91259 .57966 L
.91284 .57925 L
.91296 .5844 L
.9131 .38118 L
.91334 .45753 L
.91349 .04319 L
.91363 .47825 L
.91376 .54037 L
.9139 .48163 L
.91413 .45567 L
.91426 .57047 L
.91438 .55411 L
.91463 .53445 L
.91476 .48149 L
.91489 .40581 L
.91512 .56286 L
.91534 .04979 L
.91556 .56834 L
.91581 .58078 L
.91605 .56321 L
.91617 .53824 L
.91631 .55548 L
.91654 .53495 L
.91676 .01595 L
.9169 .1354 L
.91703 .22411 L
Mistroke
.91726 .03586 L
.9174 .23839 L
.91752 .23067 L
.91766 .53167 L
.9178 .33375 L
.91804 .41464 L
.91818 .05933 L
.91831 .02688 L
.91854 .35796 L
.91879 .41202 L
.91901 .30465 L
.91921 .55302 L
.91944 .2512 L
.91968 .09707 L
.91991 .03581 L
.92013 .5762 L
.92037 .43144 L
.92049 .34733 L
.92062 .55382 L
.92085 .01773 L
.92109 .07637 L
.92131 .57236 L
.92152 .07943 L
.92173 .44165 L
.92193 .58012 L
.92215 .0222 L
.92238 .2539 L
.9226 .45293 L
.9228 .39021 L
.92299 .36367 L
.92319 .01797 L
.92343 .26563 L
.92364 .26005 L
.92389 .24628 L
.92412 .01482 L
.92434 .58439 L
.92454 .35003 L
.92476 .32854 L
.92499 .02051 L
.92522 .22107 L
.92535 .05855 L
.92547 .13074 L
.92569 .55529 L
.92593 .19899 L
.92605 .20165 L
.92618 .4411 L
.92642 .18645 L
.92657 .57514 L
.9267 .2714 L
.92683 .27612 L
Mistroke
.92696 .04295 L
.92721 .04046 L
.92744 .42472 L
.92757 .17034 L
.92769 .23361 L
.92783 .02995 L
.92797 .21606 L
.92809 .3429 L
.92823 .58231 L
.92848 .56853 L
.92863 .09645 L
.92877 .1513 L
.92889 .23901 L
.92903 .56037 L
.92926 .16402 L
.92939 .37244 L
.92952 .33186 L
.92976 .31769 L
.9299 .58443 L
.93003 .57783 L
.93025 .17512 L
.9305 .11346 L
.93073 .09809 L
.93094 .43633 L
.93116 .03183 L
.9314 .30684 L
.9316 .01516 L
.93182 .57651 L
.93206 .49921 L
.93219 .58225 L
.93231 .5782 L
.93254 .31604 L
.93276 .15436 L
.93297 .20531 L
.93319 .29851 L
.93338 .2373 L
.93359 .09068 L
.93381 .37794 L
.93404 .56803 L
.93427 .18908 L
.93447 .58425 L
.93472 .52905 L
.93484 .49208 L
.93497 .57363 L
.93521 .51067 L
.93543 .01523 L
.93556 .02884 L
.93569 .24723 L
.93593 .07176 L
.93607 .32786 L
Mistroke
.93619 .35376 L
.93633 .58375 L
.93647 .12491 L
.93672 .1835 L
.93686 .02997 L
.93698 .08635 L
.93722 .06394 L
.93747 .0492 L
.93769 .58328 L
.9379 .09771 L
.93812 .56074 L
.93837 .57825 L
.9385 .49469 L
.93862 .5246 L
.93885 .38019 L
.9391 .3363 L
.93923 .58353 L
.93936 .5579 L
.93957 .017 L
.93981 .19953 L
.94005 .3294 L
.94028 .57064 L
.94041 .56243 L
.94055 .12052 L
.9408 .09832 L
.94094 .1309 L
.94109 .56093 L
.94122 .49872 L
.94136 .06738 L
.94161 .03132 L
.94175 .24428 L
.94188 .3921 L
.94212 .07642 L
.94237 .01731 L
.9426 .43811 L
.94282 .01715 L
.94307 .08013 L
.94331 .57445 L
.94352 .04683 L
.94373 .02417 L
.94395 .57629 L
.94418 .05393 L
.94442 .33196 L
.94455 .24832 L
.94467 .46906 L
.9449 .34868 L
.94512 .34914 L
.94525 .45409 L
.94538 .35382 L
.94562 .55213 L
Mistroke
.94577 .39681 L
.94591 .16313 L
.94603 .30545 L
.94616 .18324 L
.9464 .57965 L
.94661 .21165 L
.94686 .47989 L
.9471 .33996 L
.94731 .49343 L
.94751 .33187 L
.94773 .11195 L
.94797 .30707 L
.9482 .48853 L
.94833 .52934 L
.94845 .32002 L
.94868 .1018 L
.94891 .3967 L
.94903 .2631 L
.94916 .35568 L
.9494 .01829 L
.94955 .27334 L
.94968 .49002 L
.94981 .35428 L
.94994 .46988 L
.95019 .22104 L
.95042 .20351 L
.95055 .10487 L
.95068 .29329 L
.95082 .04364 L
.95095 .01549 L
.95108 .01684 L
.95121 .06692 L
.95146 .0671 L
.9516 .01556 L
.95172 .01487 L
.95186 .16048 L
.95202 .58282 L
.95225 .07376 L
.95238 .11713 L
.9525 .02102 L
.95275 .11498 L
.95289 .01487 L
.95301 .02655 L
.95393 .08759 L
.95415 .52989 L
.95436 .06109 L
.95461 .35069 L
.95483 .22307 L
.95505 .58161 L
.95524 .58264 L
Mistroke
.95546 .1368 L
.95568 .52424 L
.95592 .0834 L
.95615 .51602 L
.95635 .29148 L
.95657 .13239 L
.95682 .0156 L
.95694 .05079 L
.95708 .02251 L
.95732 .23111 L
.95755 .3656 L
.95768 .31465 L
.95781 .53051 L
.95794 .55214 L
.95806 .37726 L
.95829 .15853 L
.95854 .54167 L
.95866 .58077 L
.95879 .51959 L
.95904 .50812 L
.95918 .5591 L
.95933 .10909 L
.95945 .16256 L
.95959 .01808 L
.95984 .18448 L
.96006 .39194 L
.96019 .27226 L
.96032 .43244 L
.96057 .09628 L
.9608 .41186 L
.96104 .57161 L
.96125 .43747 L
.96148 .21892 L
.96172 .01504 L
.96195 .57854 L
.9622 .52772 L
.96233 .46953 L
.96246 .58332 L
.9627 .08049 L
.96283 .11216 L
.96295 .01482 L
.96317 .54858 L
.9634 .01962 L
.96361 .35346 L
.96384 .28589 L
.96405 .02327 L
.96424 .0181 L
.96447 .57788 L
.96471 .45387 L
.96494 .03642 L
Mistroke
.96516 .31217 L
.96538 .25281 L
.96563 .56325 L
.96586 .11028 L
.96607 .53309 L
.96632 .25031 L
.96646 .51192 L
.96659 .51975 L
.96682 .03872 L
.96695 .09243 L
.96708 .01626 L
.9672 .02477 L
.96734 .02504 L
.96758 .24954 L
.96771 .12226 L
.96784 .21567 L
.96797 .04429 L
.96812 .22713 L
.96825 .17154 L
.96839 .41259 L
.96852 .44488 L
.96864 .21889 L
.96887 .31923 L
.96911 .58388 L
.96932 .20774 L
.96955 .5498 L
.9698 .20995 L
.97002 .36347 L
.97024 .01624 L
.97043 .01639 L
.97065 .58216 L
.97087 .29749 L
.9711 .41165 L
.97134 .05601 L
.97155 .40003 L
.97178 .13217 L
.97202 .45708 L
.97216 .22265 L
.97228 .307 L
.97253 .57723 L
.97276 .10756 L
.97298 .58336 L
.97317 .58025 L
.9734 .02105 L
.97361 .44163 L
.97381 .52917 L
.97399 .23992 L
.97419 .4027 L
.9744 .55577 L
.97462 .09401 L
Mistroke
.97484 .54716 L
.97506 .28375 L
.97526 .21046 L
.97549 .49725 L
.97562 .51752 L
.97574 .303 L
.97596 .43289 L
.97619 .38915 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[73]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`007`3oool3000001d0oooo0`00000N0?ooo`<000006`3oool5000001X0oooo0P00000L0?oo
o`D000007@3oool3000001`0oooo0`00000Q0?ooo`007P3oool01@000000oooo0?ooo`3oool00000
01/0oooo00D000000?ooo`3oool0oooo0000000N0?ooo`030000003oool0oooo01/0oooo00@00000
0?ooo`3oool000006@3oool010000000oooo0?ooo`00000L0?ooo`040000003oool0oooo000001h0
oooo00<000000?ooo`3oool06P3oool01@000000oooo0?ooo`3oool000000200oooo000H0?ooo`D0
000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`0C0?ooo`D0000000<0oooo0000003o
ool00P3oool00`000000oooo0?ooo`0C0?ooo`D0000000<0oooo0000000000000`00000E0?ooo`D0
00000`3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo000001d0oooo00<000000?oo
o`3oool06`3oool5000001/0oooo00D000000?ooo`3oool0oooo0000000P0?ooo`007`3oool30000
01`0oooo1000000L0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0603oool0
10000000oooo0?ooo`00000N0?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3oool00000
703oool400000240oooo000N0?ooo`050000003oool0oooo0?ooo`0000006`3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0000001`0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`04
0000003oool0oooo000001/0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003oool0
000001`0oooo00<000000?ooo`3oool08P3oool001h0oooo00D000000?ooo`3oool0oooo0000000L
0?ooo`030000003oool0oooo01h0oooo0P00000L0?ooo`050000003oool0oooo0?ooo`0000006@3o
ool010000000oooo0?ooo`00000K0?ooo`050000003oool0oooo0?ooo`0000007@3oool2000001d0
oooo00<000000?ooo`3oool08@3oool001l0oooo0`00000N0?ooo`8000007`3oool00`000000oooo
0?ooo`0K0?ooo`<000006`3oool2000001d0oooo0`00000O0?ooo`030000003oool0oooo01`0oooo
0P00000Q0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
7P3ooooh000000X0oooo000G0?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo000F0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00P0oooo000F0?ooo`040000003oool0
oooo000000@0oooo0P00000c0?ooo`040000003oool0000000000080oooo00<000000?ooo`000000
100000050?ooo`8000000P3oool2000000/0oooo00<000000?ooo`3oool00P3oool200000240oooo
00<000000?ooo`3oool0C`3oool2000000030?ooo`000000000000<0oooo0P0000000`3oool00000
000000050?ooo`040000003oool00000000000<0oooo00@000000?ooo`3oool000001`3oool20000
00X0oooo000F0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`02000000030?ooo`0000000000008000000P3oool00`000000oooo000000020000
0080oooo0`0000001@3oool00000000000000000oooo008000000P3oool00`000000oooo00000003
00000080oooo200000020?ooo`T0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`02
000000030?ooo`000000oooo00@000000`3oool200000080oooo0`0000000`3oool000000?ooo`03
0?ooo`040000003oool000000?ooo`<0000000D0oooo00000000000000000?ooo`05000000030?oo
o`00000000000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`050000003oool000000000003oool00P0000000`3oool0000000000002000000030?oo
o`0000000000008000000P3oool300000080oooo0P0000001@3oool00000000000000000oooo00L0
000000<0oooo0000003oool0103oool010000000oooo0000003oool2000000<0oooo0P0000000`3o
ool000000000000A00000080oooo0P0000000`3oool000000?ooo`04000000030?ooo`0000000000
00@000001P3oool00`000000oooo0?ooo`080?ooo`005P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool4000000030?ooo`000000
000000<0000000@0oooo000000000000oooo10000000103oool000000000003oool300000080oooo
2P0000020?ooo`L0000000<0oooo0000000000004@0000000`3oool000000?ooo`020?ooo`800000
0P3oool2000000030?ooo`000000oooo00@000000`3oool200000080oooo0`0000001P3oool00000
0?ooo`3oool000000?ooo`<0000000<0oooo0000000000003`0000001`3oool000000?ooo`000000
oooo0000003oool01@0000020?ooo`050000003oool000000000003oool01`0000000`3oool00000
00000002000000030?ooo`0000000000008000000P3oool6000000030?ooo`000000000000P00000
0P3oool3000000030?ooo`000000000000<0000000D0oooo00000000000000000?ooo`0C00000080
oooo0P0000000`3oool0000000000004000000030?ooo`000000000000@000001P3oool00`000000
oooo0?ooo`080?ooo`005P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo100000000`3oool000000000000<000000030?ooo`00000000000080000000@0oooo00000000
0000oooo100000000`3oool000000000000800000080oooo1`0000000`3oool000000000000A0000
00040?ooo`000000oooo0?ooo`<000000P3oool2000000030?ooo`000000oooo00@000000`3oool3
000000030?ooo`000000000000<000000P3oool00`000000oooo0000000F000000050?ooo`000000
oooo0000003oool01@0000020?ooo`050000003oool000000000003oool01`0000000`3oool00000
00000007000000030?ooo`0000000000010000000P3oool3000000030?ooo`000000000000<00000
00<0oooo0000000000005P0000000`3oool0000000000007000000030?ooo`000000000000@00000
1P3oool00`000000oooo0?ooo`080?ooo`005`3oool2000000D0oooo00<000000?ooo`3oool00`3o
oolC000000030?ooo`000000000000D0000000<0oooo0000000000000P0000000`3oool000000000
000800000080oooo1`0000000`3oool000000000000A000000040?ooo`000000oooo0?ooo`<00000
0P3oool2000000030?ooo`000000oooo00@000000P3oool4000000030?ooo`000000000000<00000
0P3ooolM000000030?ooo`000000000000@0000000<0oooo0000003oool00P0000000`3oool00000
00000005000000030?ooo`000000000000L0000000<0oooo000000000000400000000`3oool00000
00000002000000030?ooo`000000000001`0000000<0oooo0000000000001`0000000`3oool00000
00000004000000H0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3o
oolC000000030?ooo`000000000000D0000000<0oooo0000000000000P0000000`3oool000000000
000800000080oooo1`0000000`3oool000000000000D000000050?ooo`00000000000000003oool0
0`0000000`3oool000000?ooo`0400000080oooo100000000`3oool0000000000003000000030?oo
o`000000000001`0000000<0oooo000000000000100000000`3oool000000?ooo`0:000000030?oo
o`000000000001X0000000<0oooo0000000000008@0000000`3oool0000000000007000000030?oo
o`000000000000@000001P3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?oo
o`030?oooa<0000000<0oooo0000000000001@0000000`3oool0000000000002000000030?ooo`00
0000000000P000000P3oool7000000030?ooo`000000000001P0000000L0oooo0000000000000000
0?ooo`000000oooo00D0000000<0oooo0000000000000P0000000`3oool000000000000300000003
0?ooo`000000000001`0000000<0oooo000000000000100000000`3oool000000000000:00000003
0?ooo`000000000001X0000000<0oooo0000000000008@0000000`3oool000000000000700000003
0?ooo`000000000000@000001P3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000@0oooo
4`0000000`3oool0000000000005000000030?ooo`000000000000d000000P3oool7000000030?oo
o`000000000001P0000000L0oooo00000000000000000?ooo`000000oooo00D0000000<0oooo0000
000000000P0000000`3oool0000000000003000000030?ooo`000000000001`0000000<0oooo0000
00000000100000000`3oool000000000001;000000030?ooo`000000000000L0000000<0oooo0000
00000000100000050?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool00`3ooolC00000003
0?ooo`000000000000D0000000<0oooo0000000000003P0000000`3oool000000000000500000003
0?ooo`000000000001P0000000<0oooo0000000000000`0000000`3oool000000000000300000003
0?ooo`00000000000080000000<0oooo0000000000000`0000000`3oool000000000000L00000003
0?ooo`000000000000@0000000<0oooo000000000000E@0000000`3oool0000000000004000000H0
oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3ooolC000000030?oo
o`000000000000D0000000<0oooo0000000000003P0000000`3oool0000000000005000000030?oo
o`000000000001P0000000<0oooo0000000000000`0000000`3oool0000000000003000000030?oo
o`00000000000080000000<0oooo0000000000000`0000000`3oool000000000000L000000030?oo
o`000000000000@0000000<0oooo000000000000E@0000000`3oool0000000000004000000H0oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3ooolC000000030?ooo`00
0000000000D0000000<0oooo0000000000005P0000000`3oool000000000000H000000030?ooo`00
0000000000<0000000<0oooo0000000000000`0000000`3oool0000000000002000000030?ooo`00
000000000280000000<0oooo000000000000100000000`3oool000000000001E000000030?ooo`00
0000000000@000001P3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`03
0?oooa<0000000<0oooo0000000000001@0000000`3oool000000000000F000000030?ooo`000000
000001P0000000<0oooo0000000000000`0000000`3oool0000000000008000000030?ooo`000000
00000280000000<0oooo000000000000100000000`3oool000000000001E000000030?ooo`000000
000000@000001P3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?oo
oa<0000000<0oooo0000000000001@0000000`3oool000000000000F000000030?ooo`0000000000
01P0000000<0oooo0000000000000`0000000`3oool000000000000]000000030?ooo`0000000000
00@0000000<0oooo000000000000E@0000000`3oool0000000000004000000H0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool00`3ooolC000000030?ooo`000000000001h0
000000<0oooo000000000000600000000`3oool0000000000003000000030?ooo`000000000002d0
000000<0oooo000000000000100000000`3oool000000000001E000000030?ooo`000000000000@0
00001P3oool00`000000oooo0?ooo`080?ooo`007P3oool2000000@0oooo4`0000000`3oool00000
0000000N000000030?ooo`000000000001P0000000<0oooo0000000000000`0000000`3oool00000
0000000d000000030?ooo`000000000005D0000000<0oooo000000000000100000050?ooo`800000
2P3oool001h0oooo00<000000?ooo`3oool00`3ooolC000000030?ooo`000000000001h0000000<0
oooo000000000000600000000`3oool000000000000j000000030?ooo`000000000005D0000000<0
oooo000000000000100000060?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo00<0oooo=00000000`3oool000000000000H000000030?ooo`000000000003X0000000<0oooo
000000000000E@0000000`3oool0000000000004000000H0oooo00<000000?ooo`3oool0203oool0
01h0oooo00<000000?ooo`3oool00`3ooold000000030?ooo`000000000001P0000000<0oooo0000
00000000TP0000000`3oool0000000000004000000H0oooo00<000000?ooo`3oool0203oool001h0
oooo00<000000?ooo`3oool00`3ooom?000000030?ooo`00000000000980000000<0oooo00000000
0000100000060?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00<0oooo
i00000000`3oool0000000000004000000H0oooo00<000000?ooo`3oool0203oool001h0oooo0P00
00040?ooon@0000000<0oooo0000000000001@0000040?ooo`8000002P3oool001h0oooo00<00000
0?ooo`3oool00`3ooooT000000030?ooo`000000000000D000001@3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`030?ooon`000001@3oool00`000000oooo0?ooo`080?oo
o`007P3oool00`000000oooo0?ooo`030?ooon`000001@3oool00`000000oooo0?ooo`080?ooo`00
7P3oool00`000000oooo0?ooo`030?ooon`000001@3oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`030?ooon`000001@3oool00`000000oooo0?ooo`080?ooo`007P3oool0
0`000000oooo0?ooo`030?ooon`000001@3oool00`000000oooo0?ooo`080?ooo`007P3oool20000
00@0ooook00000040?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool00`3oooo/000000D0
oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3oooo/000000D0oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3oooo/000000D0oooo00<0
00000?ooo`3oool0203oool000X0oooo0`0000040?ooo`800000103oool2000000D0oooo00<00000
0?ooo`3oool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool000/0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool000/0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool000/0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo0P0000040?ooon`00000103oool2000000X0oooo000;0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00<0ooook00000050?ooo`030000003oool0oooo00P0oooo000:0?ooo`800000103oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oooo/
000000D0oooo00<000000?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool00`3oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo00P0oooo
000N0?ooo`800000103oooo/000000@0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`03
0?ooon`000001@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?oo
on`000001@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?ooon`0
00001@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?ooon`00000
1@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?ooon`000001@3o
ool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?ooon`000001@3oool0
0`000000oooo0?ooo`080?ooo`007P3oool2000000@0ooook00000040?ooo`8000002P3oool001h0
oooo00<000000?ooo`3oool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<0
00000?ooo`3oool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<00000
0?ooo`3oool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?oo
o`3oool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo0P0000040?ooon`00000
103oool2000000X0oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003o
ool0oooo00P0oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0
oooo00P0oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo00P0oooo
000N0?ooo`800000103oooo/000000@0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`03
0?ooon`000001@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?oo
on`000001@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?ooon`0
00001@3oool00`000000oooo0?ooo`080?ooo`002@3oool5000000<0oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`030?ooon`000001@3oool00`000000oooo0?ooo`080?ooo`002P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooon`000001@3oool00`000000oooo0?ooo`080?oo
o`002`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooon`000001@3oool00`000000oooo0?ooo`08
0?ooo`00303oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`800000103oooo/000000@0oooo0P00000:0?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo00P0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oooo/000000D0oooo00<00000
0?ooo`3oool0203oool000X0oooo0`0000040?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
0`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3o
ooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo0P0000040?ooon`00000103oool2
000000X0oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo00P0oooo
000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo00P0oooo000N
0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo00P0oooo000N0?oo
o`800000103oooo/000000@0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`030?ooon`0
00001@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?ooon`00000
1@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?ooon`000001@3o
ool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?ooon`000001@3oool0
0`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?ooon`000001@3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`030?ooon`000001@3oool00`000000
oooo0?ooo`080?ooo`007P3oool2000000@0ooook00000040?ooo`8000002P3oool001h0oooo00<0
00000?ooo`3oool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<00000
0?ooo`3oool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?oo
o`3oool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
0`3oooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3o
ooo/000000D0oooo00<000000?ooo`3oool0203oool001h0oooo0P0000040?ooon`00000103oool2
000000X0oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo00<0ooook00000050?ooo`030000003oool0oooo00P0oooo
000:0?ooo`<00000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo00<0ooook000
00050?ooo`030000003oool0oooo00P0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oooo/000000D0oooo00<000000?ooo`3oool0203oool000d0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0P0000040?oo
on`00000103oool2000000X0oooo000;0?ooo`8000000`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oooo/000000D0oooo00<00000
0?ooo`3oool0203oool000d0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oooo/000000D0oooo00<0
00000?ooo`3oool0203oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooon`0
00001@3oool00`000000oooo0?ooo`080?ooo`002P3oool3000000@0oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`030?ooon`000001@3oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`030?ooon`000001@3oool00`000000oooo0?ooo`080?ooo`007P3oool0
0`000000oooo0?ooo`030?ooon`000001@3oool00`000000oooo0?ooo`080?ooo`007P3oool20000
00@0ooook00000040?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool00`3oooo/000000D0
oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3oooo/000000D0oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3oooo/000000D0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3oooo/000000D0oooo00<00000
0?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool00`3oooo/000000D0oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool00`3oooo/000000D0oooo00<000000?ooo`3o
ool0203oool001h0oooo0P0000040?ooon`00000103oool2000000X0oooo000N0?ooo`030000003o
ool0oooo00<0ooook00000050?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo00<0ooook00000050?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo
00<0oooo100000000`3oool000000?ooo`02000000030?ooo`00000000000>0000001@3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`060?ooo`050000003oool000000?oo
o`0000000P3ooooR000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool02P3oool010000000oooo0?ooo`3oool6000000030?ooo`000000000000h0000000<0oooo0000
00000000]00000000`3oool000000000000@000000D0oooo00<000000?ooo`3oool0203oool001h0
oooo0P00000B0?ooo`<0000000<0oooo0000003oool03P0000000`3oool000000000002d00000003
0?ooo`000000000001000000103oool2000000X0oooo000N0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`0000003@0000000`3oool000000000002d000000030?ooo`000000000001000000
1@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0K0?ooo`@0000000<0
oooo0000000000000P3oool010000000oooo0000003ooond000000030?ooo`000000000001000000
1@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0Q0?ooo`040000003o
ool0oooo000000<0oooo2@0000000`3oool000000000002X000000030?ooo`000000000001000000
1@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0X0?ooo`T0000000<0
oooo000000000000Z00000000`3oool000000000000@000000D0oooo00<000000?ooo`3oool0203o
ool001h0oooo00<000000?ooo`3oool0:`3oool6000000<0oooo1P0000000`3oool0000000000002
000000030?ooo`000000000009X0000000<0oooo000000000000400000050?ooo`030000003oool0
oooo00P0oooo000N0?ooo`030000003oool0oooo0300oooo00@000000?ooo`3oool0oooo0P000000
1@3oool00000000000000000oooo00@0000000<0oooo000000000000VP0000000`3oool000000000
000@000000D0oooo00<000000?ooo`3oool0203oool001h0oooo0P00000e0?ooo`030000003oool0
oooo00<0000000<0oooo0000000000000P0000020?ooogT0000000<0oooo0000000000007`000000
0`3oool000000000000@000000@0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`0g0?oo
o`<0000000<0oooo0000000000000P0000020?ooogT0000000<0oooo0000000000007`0000000`3o
ool000000000000@000000D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool0?03oool2000000<0ooooN@0000000`3oool000000000000O000000030?ooo`00000000000100
00001@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`130?ooo`030000
003oool0000000@0000000D0oooo00000000000000000?ooo`1[000000030?ooo`000000000001l0
000000<0oooo000000000000400000050?ooo`030000003oool0oooo00P0oooo000;0?ooo`<00000
0`3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo04D0oooo1@0000001@3oool00000
000000000000oooo06/0000000<0oooo0000000000007`0000000`3oool000000000000@000000D0
oooo00<000000?ooo`3oool0203oool000`0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1;0?oo
o`<0000000<0oooo0000000000000`0000000`3oool000000000001S000000030?ooo`0000000000
01l0000000<0oooo000000000000400000050?ooo`030000003oool0oooo00P0oooo00090?ooo`D0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`05000000030?ooo`000000000006<0000000<0oooo
0000000000007P0000020?oooa8000001@3oool00`000000oooo0?ooo`080?ooo`002@3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool200000580oooo0`0000000`3oool000000?ooo`1S000000030?ooo`000000000001h00000
0P3ooolB000000@0oooo0P00000:0?ooo`002P3oool00`000000oooo000000030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0000001X0000000<0oooo000000000000A@0000000`3oool000000000000N00000080
oooo4@0000060?ooo`030000003oool0oooo00P0oooo000;0?ooo`8000000`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0F@3ooolI0000
00030?ooo`000000000004D0000000<0oooo0000000000007P0000020?oooa4000001P3oool00`00
0000oooo0?ooo`080?ooo`00303oool00`000000oooo0?ooo`020?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool0GP3ooolD000000030?ooo`000000000003D0000000<0oooo00000000
00003@0000000`3oool000000000000N00000080oooo4@0000060?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo0680oooo0P0000020?ooo``0000000<0oooo000000000000
=@0000000`3oool000000000000=000000030?ooo`000000000001h000000P3ooolA000000H0oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0I`3oool;000000030?ooo`00
000000000140000000<0oooo0000000000002P0000000`3oool000000000000D000000030?ooo`00
0000000000d0000000<0oooo0000000000000P0000000`3oool000000000000G000000040?ooo`00
0000oooo0?oooa4000001P3oool00`000000oooo0?ooo`080?ooo`007P3oool2000006h0oooo1@00
00000`3oool000000000000A000000030?ooo`000000000000X0000000<0oooo0000000000005000
00000`3oool000000000000=000000030?ooo`00000000000080000000<0oooo0000000000005`00
0000103oool000000?ooo`3oool3000000030?ooo`000000000000<0000000<0oooo000000000000
1@0000050?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0K`3oool3000000030?ooo`00
000000000080000000<0oooo0000003oool0300000020?ooo`/0000000<0oooo0000000000005000
00000`3oool000000000000;000000030?ooo`000000oooo00@0000000<0oooo0000000000005000
00001@3oool000000000003oool0000000<0oooo0P0000000`3oool000000000000300000080oooo
0P000000103oool000000000000000060?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo07D0oooo0P0000000`3oool000000?ooo`0<000000<0oooo2P0000000`3oool00000
0000000D000000030?ooo`000000000000/0000000<0oooo0000003oool0100000000`3oool00000
0000000500000080oooo1P0000000`3oool000000?ooo`0400000080oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0000000P00000103oool:000000030?ooo`000000000001@0000000<0oooo0000000000001@00
00000`3oool0000000000003000000030?ooo`000000oooo00@0000000<0oooo0000000000001@00
00020?ooo`H000009@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1m
0?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool00`3oool2000000030?ooo`00
0000000000D0000000<0oooo0000000000000P0000000`3oool000000000000?000000030?ooo`00
0000000000D0000000<0oooo0000000000000P3oool010000000oooo0000003oool4000000060?oo
o`00000000000?ooo`000000oooo0P00000]0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo07d0oooo00<000000?ooo`3oool0303oool4000000040?ooo`00000000000?oo
o`80000000<0oooo0000003oool00`0000000`3oool0000000000008000000050?ooo`0000000000
0?ooo`0000000P3oool2000000030?ooo`000000oooo008000000P3oool00`000000oooo0000000j
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool05`3oool00`000000oooo00000002000000030?ooo`000000oooo00<0000000H0oooo0000
003oool0oooo0000003oool2000000030?ooo`000000oooo04L0oooo00<000000?ooo`3oool0203o
ool001h0oooo0P00001n0?ooo`030000003oool0oooo07<0oooo0P00000:0?ooo`007P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo000N0?ooooP000002P3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00=D0oooo0`0000180?ooo`00eP3oool00`000000
oooo0?ooo`170?ooo`00E`3oool5000000050?ooo`00000000000000003oool00P0000020?ooo`80
00000`3oool300000080oooo0`0000030?ooo`D000000P3oool300000080oooo0`0000040?ooo`<0
00000P3oool3000000040?ooo`00000000000?ooo`<000000`3oool3000000P0oooo1@0000001@3o
ool00000000000000000oooo008000000P3oool2000000<0oooo0`0000020?ooo`<0000000<0oooo
000000000000100000020?ooo`D000000`3oool2000000@0oooo00<000000?ooo`3oool0AP3oool0
05T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0
oooo0000003oool000001P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000001P3oool010000000
oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo04H0oooo001I0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`D000000P3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`D00000
0P3oool01P000000oooo0?ooo`000000oooo000000D0oooo1@0000090?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`D000000P3oool0
10000000oooo0?ooo`0000020?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000A`3oool005T0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000020?ooo`8000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool00P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000000L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000004L0oooo001I0?oo
o`040000003oool0oooo0?ooo`@000000P3oool4000000<0oooo0`0000020?ooo`80000000<0oooo
0000000000000P3oool400000080oooo0`0000020?ooo`80000000<0oooo0000000000000P3oool3
00000080oooo100000030?ooo`<000000`3oool3000000X0oooo00@000000?ooo`3oool0oooo1000
00020?ooo`@000000`3oool300000080oooo100000030?ooo`@0000000@0oooo0000000000000000
0`3oool400000080oooo0P0000000`3oool00000000000160?ooo`00F@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0C@3oool005L0oooo1@000008
0?ooo`030000003oool0oooo0140oooo0P00000[0?ooo`D00000203oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.91422, -47.1799, \
0.0625458, 3.00166}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindInterference[Join[wave1,wave2],PlotDomain->{0,.01}];", "Input",
  CellLabel->"In[74]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 95.2381 0.0127814 0.00137823 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -15 -9 ]
[.21429 -0.0125 15 0 ]
[.40476 -0.0125 -15 -9 ]
[.40476 -0.0125 15 0 ]
[.59524 -0.0125 -15 -9 ]
[.59524 -0.0125 15 0 ]
[.78571 -0.0125 -15 -9 ]
[.78571 -0.0125 15 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01278 -6 -4.5 ]
[-0.0125 .01278 0 4.5 ]
[-0.0125 .1506 -18 -4.5 ]
[-0.0125 .1506 0 4.5 ]
[-0.0125 .28843 -18 -4.5 ]
[-0.0125 .28843 0 4.5 ]
[-0.0125 .42625 -18 -4.5 ]
[-0.0125 .42625 0 4.5 ]
[-0.0125 .56407 -18 -4.5 ]
[-0.0125 .56407 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -66 0 ]
[.5 .63053 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.002)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.004)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.006)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.008)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.01)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01278 m
.00625 .01278 L
s
[(0)] -0.0125 .01278 1 0 Mshowa
0 .1506 m
.00625 .1506 L
s
[(100)] -0.0125 .1506 1 0 Mshowa
0 .28843 m
.00625 .28843 L
s
[(200)] -0.0125 .28843 1 0 Mshowa
0 .42625 m
.00625 .42625 L
s
[(300)] -0.0125 .42625 1 0 Mshowa
0 .56407 m
.00625 .56407 L
s
[(400)] -0.0125 .56407 1 0 Mshowa
.125 Mabswid
0 .04035 m
.00375 .04035 L
s
0 .06791 m
.00375 .06791 L
s
0 .09548 m
.00375 .09548 L
s
0 .12304 m
.00375 .12304 L
s
0 .17817 m
.00375 .17817 L
s
0 .20573 m
.00375 .20573 L
s
0 .2333 m
.00375 .2333 L
s
0 .26086 m
.00375 .26086 L
s
0 .31599 m
.00375 .31599 L
s
0 .34356 m
.00375 .34356 L
s
0 .37112 m
.00375 .37112 L
s
0 .39869 m
.00375 .39869 L
s
0 .45382 m
.00375 .45382 L
s
0 .48138 m
.00375 .48138 L
s
0 .50895 m
.00375 .50895 L
s
0 .53651 m
.00375 .53651 L
s
0 .59164 m
.00375 .59164 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01278 m
1 .01278 L
s
.99375 .1506 m
1 .1506 L
s
.99375 .28843 m
1 .28843 L
s
.99375 .42625 m
1 .42625 L
s
.99375 .56407 m
1 .56407 L
s
.125 Mabswid
.99625 .04035 m
1 .04035 L
s
.99625 .06791 m
1 .06791 L
s
.99625 .09548 m
1 .09548 L
s
.99625 .12304 m
1 .12304 L
s
.99625 .17817 m
1 .17817 L
s
.99625 .20573 m
1 .20573 L
s
.99625 .2333 m
1 .2333 L
s
.99625 .26086 m
1 .26086 L
s
.99625 .31599 m
1 .31599 L
s
.99625 .34356 m
1 .34356 L
s
.99625 .37112 m
1 .37112 L
s
.99625 .39869 m
1 .39869 L
s
.99625 .45382 m
1 .45382 L
s
.99625 .48138 m
1 .48138 L
s
.99625 .50895 m
1 .50895 L
s
.99625 .53651 m
1 .53651 L
s
.99625 .59164 m
1 .59164 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(Interference Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .54899 m
.03111 .38221 L
.03491 .27549 L
.03907 .16418 L
.04094 .12067 L
.04294 .08089 L
.04483 .05105 L
.04655 .03126 L
.04746 .0238 L
.04793 .02086 L
.04843 .01829 L
.04886 .01664 L
.04911 .01593 L
.04933 .01543 L
.04954 .01508 L
.04976 .01483 L
.04997 .01472 L
.05017 .01473 L
.05042 .01489 L
.05056 .01505 L
.05068 .01525 L
.05092 .01573 L
.05117 .0164 L
.0516 .01795 L
.05207 .02023 L
.05312 .02741 L
.0541 .03669 L
.05607 .06266 L
.05794 .09546 L
.06145 .17451 L
.06869 .37383 L
.07236 .46891 L
.0743 .51208 L
.0764 .55064 L
.07737 .56527 L
.0784 .57825 L
.07935 .58794 L
.08023 .59487 L
.08065 .59749 L
.08106 .59952 L
.08128 .60045 L
.08152 .60131 L
.08174 .60196 L
.08194 .60244 L
.08217 .60284 L
.08242 .60313 L
.08266 .60324 L
.0828 .60323 L
.08292 .60318 L
.08314 .60299 L
Mistroke
.08338 .60263 L
.08361 .60215 L
.08382 .60157 L
.08432 .59972 L
.08478 .59743 L
.08582 .59017 L
.08674 .58144 L
.08771 .56994 L
.08938 .54468 L
.09123 .50998 L
.09887 .31372 L
.1024 .21548 L
.10624 .12119 L
.10833 .07972 L
.11026 .04959 L
.11121 .03796 L
.1121 .02912 L
.11304 .02211 L
.11353 .01931 L
.11381 .01803 L
.11406 .01704 L
.11428 .01633 L
.11452 .0157 L
.11477 .01521 L
.115 .0149 L
.11522 .01474 L
.11546 .01472 L
.11566 .01483 L
.11588 .01506 L
.11601 .01527 L
.11613 .01551 L
.11637 .01607 L
.11662 .01685 L
.1169 .01789 L
.1174 .02029 L
.11786 .02309 L
.11878 .03036 L
.11979 .04092 L
.12185 .07 L
.12375 .10527 L
.1255 .14367 L
.12944 .24547 L
.13331 .35445 L
.13692 .45062 L
.1404 .52746 L
.14235 .56035 L
.14412 .58265 L
.14503 .59109 L
.14553 .59479 L
.146 .59766 L
Mistroke
.14643 .59978 L
.14683 .60128 L
.14705 .60195 L
.14727 .60246 L
.14749 .60286 L
.14774 .60313 L
.14787 .60321 L
.148 .60325 L
.14813 .60323 L
.14825 .60318 L
.14848 .60297 L
.14872 .60259 L
.14885 .60234 L
.14898 .60201 L
.14922 .60131 L
.14977 .59911 L
.15028 .59636 L
.15076 .59313 L
.15167 .58543 L
.15349 .56355 L
.15543 .53176 L
.15891 .45618 L
.16605 .2613 L
.17002 .1566 L
.17175 .11687 L
.17365 .07958 L
.1755 .05062 L
.17638 .03959 L
.17722 .03097 L
.17767 .02701 L
.17817 .02333 L
.17858 .02075 L
.17903 .01845 L
.17952 .01657 L
.17979 .01582 L
.17992 .01552 L
.18004 .01529 L
.18027 .01495 L
.18049 .01477 L
.18072 .01472 L
.18085 .01475 L
.18097 .01482 L
.18121 .01509 L
.18133 .01528 L
.18147 .01554 L
.18193 .01681 L
.18219 .01778 L
.18247 .01902 L
.18297 .02178 L
.18396 .02915 L
Mistroke
.18486 .03805 L
.18666 .06202 L
.18837 .09157 L
.19563 .26989 L
.1993 .37324 L
.20335 .47743 L
.2052 .51745 L
.20719 .55315 L
.20815 .56729 L
.20907 .57868 L
.20995 .58772 L
.21079 .59438 L
.21124 .59725 L
.21174 .59973 L
.21195 .60062 L
.21218 .60142 L
.2124 .60204 L
.2126 .60249 L
.21283 .60289 L
.21307 .60315 L
.2133 .60325 L
.21352 .60322 L
.21364 .60314 L
.21377 .60301 L
.214 .60267 L
.21413 .60242 L
.21425 .60214 L
.21453 .60136 L
.21495 .59975 L
.2154 .59753 L
.2162 .59224 L
.21706 .58468 L
.218 .57424 L
.21994 .54598 L
.22171 .51312 L
.22566 .41973 L
.23322 .21064 L
.23668 .12542 L
.23864 .08544 L
.24048 .05523 L
.24229 .03326 L
.24282 .02845 L
.24331 .02454 L
.2438 .02132 L
.24424 .01895 L
.24472 .01697 L
.24498 .01615 L
.24523 .01554 L
.24545 .01513 L
.24567 .01487 L
Mistroke
.2459 .01473 L
.24614 .01474 L
.24639 .01491 L
.24653 .01509 L
.24665 .01529 L
.2469 .0158 L
.24713 .01644 L
.24765 .01839 L
.24821 .02134 L
.24913 .02794 L
.24999 .03613 L
.25196 .06166 L
.25387 .095 L
.25593 .13895 L
.26371 .34788 L
.2676 .45168 L
.26949 .49592 L
.27121 .53076 L
.27288 .55891 L
.27469 .58208 L
.27569 .59132 L
.27613 .59456 L
.27661 .59754 L
.27703 .59965 L
.27749 .60138 L
.27774 .6021 L
.27797 .6026 L
.2782 .60297 L
.27842 .60318 L
.27863 .60326 L
.27886 .60321 L
.27908 .60303 L
.27928 .60274 L
.2795 .6023 L
.27975 .60167 L
.28024 .5999 L
.28072 .59752 L
.28124 .59428 L
.28217 .58665 L
.28311 .57676 L
.28399 .56541 L
.28565 .53924 L
.28943 .45911 L
.29291 .36748 L
.29675 .25939 L
.30035 .16395 L
.3038 .08852 L
.30573 .05625 L
.3075 .03436 L
.3084 .02624 L
Mistroke
.3089 .02268 L
.30936 .01992 L
.3098 .01787 L
.31003 .01699 L
.31027 .01622 L
.31047 .0157 L
.3107 .01525 L
.3109 .01496 L
.31109 .01479 L
.31133 .01472 L
.31147 .01475 L
.3116 .01482 L
.31183 .01507 L
.31208 .0155 L
.3123 .01602 L
.31251 .01663 L
.31298 .01846 L
.31349 .02109 L
.31396 .02411 L
.31501 .03301 L
.3159 .04283 L
.31686 .0555 L
.31858 .08366 L
.3225 .16899 L
.33034 .38427 L
.33427 .48401 L
.336 .52071 L
.3379 .55431 L
.33878 .56717 L
.33972 .57893 L
.34054 .58729 L
.34143 .59445 L
.34195 .59767 L
.34243 .60001 L
.34289 .60166 L
.34315 .60233 L
.34338 .60278 L
.34361 .60309 L
.34382 .60324 L
.34406 .60326 L
.3443 .60313 L
.34452 .60288 L
.34471 .60253 L
.34493 .60203 L
.34517 .60135 L
.34565 .59946 L
.34617 .59676 L
.3471 .59015 L
.34809 .58054 L
.34919 .56707 L
Mistroke
.35115 .53593 L
.35299 .49937 L
.36032 .30875 L
.36404 .20566 L
.366 .15569 L
.3681 .10845 L
.37014 .07033 L
.37199 .04363 L
.37288 .0337 L
.37385 .02524 L
.37429 .02217 L
.37476 .01949 L
.37516 .01767 L
.3756 .01617 L
.37585 .01556 L
.37608 .01515 L
.37633 .01485 L
.37645 .01476 L
.37659 .01472 L
.37682 .01476 L
.37695 .01485 L
.37707 .01497 L
.3773 .0153 L
.37753 .01579 L
.37774 .01636 L
.37796 .0171 L
.37837 .01878 L
.37885 .02134 L
.37929 .02421 L
.38026 .0324 L
.38132 .04403 L
.38324 .07204 L
.38699 .14895 L
.39096 .25267 L
.39812 .44897 L
.40179 .52987 L
.40385 .56385 L
.40477 .57577 L
.40574 .58621 L
.40624 .59067 L
.40672 .59426 L
.40718 .59718 L
.4076 .59937 L
.40801 .60101 L
.40821 .60168 L
.40843 .60226 L
.40865 .60271 L
.40886 .60302 L
.40911 .60323 L
.40933 .60327 L
Mistroke
.40957 .60317 L
.4097 .60306 L
.40983 .60289 L
.41007 .60246 L
.41029 .60192 L
.4108 .60021 L
.41134 .59759 L
.41183 .5946 L
.41234 .59078 L
.41325 .58227 L
.41505 .55928 L
.41698 .52643 L
.42045 .44941 L
.4283 .23406 L
.43224 .13419 L
.43396 .09745 L
.43586 .06381 L
.43674 .05092 L
.43769 .03914 L
.43851 .03075 L
.4394 .02357 L
.43992 .02034 L
.4404 .018 L
.44086 .01634 L
.44112 .01566 L
.44135 .01521 L
.44158 .0149 L
.44179 .01475 L
.44203 .01472 L
.44227 .01485 L
.44249 .0151 L
.44268 .01544 L
.4429 .01594 L
.44314 .01662 L
.44362 .0185 L
.44414 .0212 L
.44507 .02781 L
.44606 .03742 L
.44716 .05088 L
.44913 .08204 L
.45097 .11859 L
.45829 .30931 L
.46202 .41247 L
.46399 .46246 L
.46608 .50967 L
.46812 .5478 L
.46997 .57447 L
.47087 .58439 L
.47183 .59284 L
.47228 .59589 L
Mistroke
.47275 .59856 L
.47315 .60036 L
.47359 .60185 L
.47383 .60246 L
.47406 .60287 L
.47418 .60303 L
.47431 .60316 L
.47445 .60324 L
.47458 .60328 L
.47481 .60323 L
.47503 .60305 L
.47527 .6027 L
.47552 .60217 L
.47573 .6016 L
.47595 .60085 L
.47635 .59916 L
.47684 .59658 L
.47727 .5937 L
.47825 .58546 L
.47931 .57379 L
.48123 .54572 L
.48498 .46865 L
.48896 .36484 L
.49612 .16849 L
.49979 .08767 L
.50185 .05378 L
.50277 .04191 L
.50374 .03154 L
.50424 .02711 L
.50472 .02355 L
.50518 .02065 L
.5056 .01849 L
.50601 .01689 L
.50621 .01624 L
.50643 .01567 L
.50666 .01523 L
.50686 .01494 L
.50711 .01475 L
.50733 .01472 L
.50758 .01484 L
.5077 .01497 L
.50783 .01515 L
.50807 .01559 L
.5083 .01615 L
.5088 .01791 L
.50935 .02056 L
.51034 .02745 L
.51125 .03603 L
.51311 .05991 L
.51483 .08923 L
Mistroke
.51875 .17659 L
.52614 .38008 L
.52991 .47676 L
.53189 .51957 L
.53399 .55651 L
.53586 .58107 L
.53693 .59112 L
.53744 .59489 L
.53793 .59784 L
.53836 .59995 L
.53859 .60086 L
.53884 .60167 L
.53905 .60223 L
.53927 .6027 L
.53948 .60301 L
.53967 .6032 L
.5399 .60329 L
.54015 .60322 L
.54035 .60305 L
.54058 .60272 L
.54082 .60221 L
.54108 .60148 L
.54155 .59971 L
.54204 .59725 L
.54256 .59394 L
.54348 .58625 L
.54448 .57552 L
.54558 .56087 L
.54939 .48967 L
.557 .28794 L
.56051 .19201 L
.56433 .10272 L
.56641 .06524 L
.56741 .05041 L
.56833 .03907 L
.56921 .03009 L
.57017 .02266 L
.57069 .01959 L
.57118 .01742 L
.57164 .01594 L
.57187 .01542 L
.57199 .01519 L
.57213 .01501 L
.57237 .01478 L
.5726 .01472 L
.57285 .01481 L
.57299 .01493 L
.57312 .0151 L
.57335 .01551 L
.57357 .01603 L
Mistroke
.57406 .01765 L
.57447 .01951 L
.57491 .02205 L
.57582 .02879 L
.57681 .03861 L
.57786 .05181 L
.57977 .08218 L
.5838 .17004 L
.58761 .2722 L
.59489 .46884 L
.59864 .54591 L
.60054 .57363 L
.60161 .58552 L
.60214 .59023 L
.60262 .59396 L
.60312 .59714 L
.60356 .59945 L
.60406 .60138 L
.60433 .60216 L
.60446 .60244 L
.60459 .60271 L
.60482 .60304 L
.60506 .60325 L
.60528 .60329 L
.60549 .60322 L
.60573 .60297 L
.60596 .60261 L
.60621 .60202 L
.60646 .6013 L
.60688 .59966 L
.60733 .5974 L
.60814 .59199 L
.609 .58427 L
.60996 .57354 L
.61187 .54547 L
.61363 .51274 L
.61757 .41958 L
.62507 .21187 L
.62885 .11936 L
.6305 .08621 L
.63229 .05666 L
.63328 .04333 L
.6342 .03322 L
.63508 .02555 L
.636 .01963 L
.63647 .0175 L
.63673 .01659 L
.63698 .01588 L
.63721 .01538 L
.63745 .01499 L
Mistroke
.63768 .01478 L
.63789 .01472 L
.63814 .01479 L
.63837 .01501 L
.6385 .0152 L
.63862 .01542 L
.6389 .01605 L
.63914 .01681 L
.63942 .01782 L
.63996 .02047 L
.64044 .02345 L
.64096 .02735 L
.6419 .03623 L
.64367 .0588 L
.64573 .09417 L
.64763 .13429 L
.65507 .33263 L
.65881 .43436 L
.66223 .51362 L
.66398 .54628 L
.6659 .57417 L
.66695 .58569 L
.66746 .59029 L
.66792 .59386 L
.66837 .59678 L
.66885 .59933 L
.66912 .60047 L
.66936 .60135 L
.66961 .60207 L
.66985 .6026 L
.67007 .60297 L
.67031 .60321 L
.67053 .6033 L
.67074 .60326 L
.67096 .60309 L
.6712 .60275 L
.67132 .60252 L
.67145 .60223 L
.67169 .60158 L
.67213 .59998 L
.67259 .59775 L
.67341 .59235 L
.67437 .58373 L
.67527 .57359 L
.67731 .54338 L
.68119 .46257 L
.6847 .37061 L
.68864 .25987 L
.69226 .16366 L
.6958 .08662 L
Mistroke
.69758 .057 L
.69858 .04351 L
.69954 .033 L
.70046 .02505 L
.70094 .02175 L
.70146 .01892 L
.70189 .01711 L
.70212 .01635 L
.70237 .0157 L
.7026 .01524 L
.70281 .01495 L
.70301 .01478 L
.70322 .01472 L
.70346 .0148 L
.70369 .01502 L
.70381 .0152 L
.70395 .01544 L
.70419 .016 L
.70467 .01756 L
.7051 .01953 L
.70558 .02226 L
.70611 .02597 L
.70717 .03567 L
.70908 .06029 L
.71084 .09021 L
.71478 .1787 L
.72229 .38558 L
.72607 .48177 L
.7295 .54968 L
.73042 .56371 L
.73142 .57663 L
.73228 .58583 L
.73322 .59375 L
.73374 .59711 L
.73423 .59959 L
.73474 .60154 L
.73502 .60231 L
.73515 .60259 L
.73529 .60283 L
.73553 .60314 L
.73575 .60329 L
.736 .60329 L
.73613 .60322 L
.73626 .60311 L
.73649 .60279 L
.73671 .60238 L
.73694 .60178 L
.73719 .60099 L
.73767 .59894 L
.73813 .59643 L
Mistroke
.73899 .59023 L
.73991 .58141 L
.74092 .56942 L
.74272 .5418 L
.74439 .51011 L
.75183 .31959 L
.75899 .13024 L
.76088 .091 L
.76267 .06036 L
.76366 .04655 L
.76473 .0342 L
.76571 .02552 L
.76662 .01972 L
.76712 .01745 L
.76758 .01596 L
.76782 .01541 L
.76796 .01517 L
.76809 .01499 L
.76822 .01485 L
.76835 .01477 L
.76849 .01472 L
.76862 .01473 L
.76885 .01485 L
.76909 .01513 L
.7693 .0155 L
.76952 .01604 L
.77003 .01775 L
.77051 .01997 L
.77139 .02573 L
.7722 .03279 L
.77402 .05476 L
.77588 .08515 L
.77761 .11981 L
.78152 .21596 L
.78891 .42065 L
.79268 .51001 L
.79481 .54946 L
.79582 .56481 L
.79676 .57697 L
.79768 .58664 L
.79852 .59359 L
.79896 .59654 L
.79945 .59915 L
.79971 .60032 L
.79996 .60122 L
.80019 .60194 L
.80044 .60254 L
.80068 .60295 L
.8009 .6032 L
.80111 .6033 L
Mistroke
.80134 .60329 L
.80158 .60311 L
.80181 .6028 L
.80206 .6023 L
.80233 .60158 L
.80287 .59952 L
.80338 .59687 L
.80433 .59004 L
.8052 .58172 L
.80616 .57034 L
.80811 .54062 L
.81159 .46797 L
.81921 .26149 L
.82272 .16805 L
.82654 .08456 L
.82862 .0513 L
.82963 .03874 L
.83054 .02955 L
.83099 .02578 L
.83149 .02232 L
.83191 .01984 L
.83238 .01768 L
.83262 .0168 L
.83287 .01602 L
.83302 .01567 L
.83315 .0154 L
.83328 .01517 L
.8334 .015 L
.83363 .01479 L
.83375 .01473 L
.83388 .01472 L
.8341 .0148 L
.83434 .01504 L
.83457 .01541 L
.83478 .01589 L
.83502 .01656 L
.83527 .01743 L
.83578 .01976 L
.83625 .02248 L
.83715 .02936 L
.838 .03778 L
.83989 .06293 L
.84194 .09933 L
.84968 .29466 L
.85353 .40204 L
.85713 .49129 L
.8589 .52786 L
.86058 .5567 L
.86151 .56989 L
.86252 .58188 L
Mistroke
.86344 .59055 L
.86429 .59662 L
.86479 .5993 L
.86525 .60117 L
.8655 .60191 L
.86576 .60255 L
.86589 .6028 L
.86604 .60301 L
.86617 .60316 L
.8663 .60326 L
.86654 .60332 L
.86676 .60324 L
.867 .60299 L
.86713 .6028 L
.86726 .60255 L
.86749 .60202 L
.86774 .60128 L
.86818 .59954 L
.86863 .59723 L
.86912 .5941 L
.87002 .58675 L
.8717 .56744 L
.87365 .53666 L
.87542 .50182 L
.87938 .40525 L
.88695 .19575 L
.89042 .11297 L
.89239 .07511 L
.89423 .04731 L
.89517 .0363 L
.89605 .02788 L
.89654 .02411 L
.89707 .02071 L
.89755 .01828 L
.898 .01659 L
.89823 .01593 L
.89847 .01538 L
.8987 .01502 L
.89892 .01481 L
.89915 .01472 L
.89928 .01474 L
.89941 .0148 L
.89954 .0149 L
.89966 .01504 L
.8998 .01525 L
.89993 .0155 L
.90018 .0161 L
.90044 .01691 L
.90091 .01884 L
.90142 .02158 L
Mistroke
.90198 .02539 L
.90296 .03409 L
.9039 .04463 L
.90565 .0701 L
.9096 .15082 L
.91683 .34646 L
.92086 .45415 L
.92452 .53344 L
.92635 .56336 L
.92731 .57597 L
.92833 .5868 L
.92922 .59411 L
.92973 .59733 L
.9302 .59971 L
.93063 .60138 L
.93084 .60199 L
.93103 .60245 L
.93125 .60287 L
.93149 .60317 L
.9317 .6033 L
.93192 .60332 L
.93213 .6032 L
.93237 .60293 L
.93262 .60248 L
.93284 .60192 L
.93325 .60056 L
.93369 .59861 L
.93421 .59565 L
.93469 .59222 L
.9356 .58414 L
.93726 .56403 L
.93906 .53496 L
.94282 .45355 L
.9468 .34735 L
.95397 .15296 L
.95765 .07612 L
.95871 .05902 L
.95971 .04519 L
.96061 .03495 L
.9616 .026 L
.96205 .02276 L
.96254 .01988 L
.963 .01773 L
.96342 .01627 L
.96365 .01567 L
.96387 .01524 L
.96411 .01491 L
.96424 .0148 L
.96436 .01474 L
.96461 .01474 L
Mistroke
.96475 .01481 L
.96487 .01492 L
.96511 .01524 L
.96536 .01575 L
.96557 .01632 L
.96577 .01695 L
.96621 .01876 L
.96701 .02336 L
.96795 .03087 L
.96884 .04009 L
.97065 .0649 L
.97258 .09948 L
.97605 .17888 L
.97619 .18234 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[74]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00803oool200000240oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000P3oool5000001@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`800000103oool3000001@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000`3oool3000001D0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000`3oool3000001P0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?oo
o`<000002P3oool001l0oooo00@000000?ooo`3oool000007`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00000C0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0503oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02@3o
ool001l0oooo00@000000?ooo`3oool000007`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0C0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?oo
o`000000oooo00D000004`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0140oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`090?ooo`007`3oool010000000oooo0?oo
o`00000O0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000P3oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool01@000000oooo0?ooo`000000oooo00@00000503oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool3000001L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00T0oooo
000O0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`0A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0000001@0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000005`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00T0oooo000O0?ooo`040000003oool0oooo0000
01l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000503o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool0503oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo0P00000;
0?ooo`00803oool200000240oooo0P00000:0?ooo`800000103oool2000000<0oooo0`00000E0?oo
o`8000002P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo01<0oooo0P00000:0?oo
o`800000103oool2000000@0oooo0P00000E0?ooo`8000002P3oool2000000@0oooo0P0000030?oo
o`<00000603oool2000000X0oooo0P0000040?ooo`030000003oool0oooo00T0oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000D0?ooo`8000001@3ooooh0000
00d0oooo000C0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0;0?ooo`004`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0?@0oooo00<000000?ooo`3oool02`3oool001<0oooo00@000000?ooo`3oool00000103oool20000
00X0oooo0P00000>0?ooo`8000003P3oool2000000l0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`8000003P3oool2000000l0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool20000
00H0oooo0P00000=0?ooo`004`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00T0oooo0P00000>0?ooo`8000003P3oool2000000h0oooo0P00000>0?ooo`8000003`3oool00`00
0000oooo0?ooo`0=0?ooo`8000003P3oool2000000h0oooo0P00000>0?ooo`8000003P3oool20000
00l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`8000003P3oool20000
00L0oooo00<000000?ooo`3oool02`3oool001<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`090?ooo`8000003P3oool2000000h0oooo0P00000>0?ooo`8000003P3oool20000
00h0oooo00<000000?ooo`0000003P3oool2000000h0oooo0P00000>0?ooo`8000003P3oool20000
00h0oooo0P00000>0?ooo`8000003P3oool3000000h0oooo0P00000>0?ooo`8000001`3oool00`00
0000oooo0?ooo`0;0?ooo`00503oool2000000D0oooo00<000000?ooo`3oool02@3oool2000000h0
oooo0P00000>0?ooo`8000003P3oool2000000h0oooo00<000000?ooo`0000003@3oool00`000000
oooo0000000>0?ooo`8000003P3oool2000000h0oooo0P00000>0?ooo`8000003P3oool2000000h0
oooo00<000000?ooo`0000003@3oool00`000000oooo0000000>0?ooo`8000003P3oool2000000L0
oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0203oool00`000000oooo
0000000>0?ooo`8000003P3oool2000000h0oooo0P00000>0?ooo`030000003oool0000000d0oooo
00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000h0oooo
0P00000>0?ooo`8000003P3oool2000000h0oooo00<000000?ooo`0000003@3oool00`000000oooo
0000000=0?ooo`030000003oool0000000h0oooo0P0000070?ooo`030000003oool0oooo00/0oooo
000K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000003P3oool2000000h0oooo0P00
000>0?ooo`8000003P3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0000000>0?ooo`8000003P3oool00`000000oooo0000
000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo0000
000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`0000001`3oool00`000000oooo0?oo
o`0;0?ooo`006`3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000d0oooo00@00000
0?ooo`3oool000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0000000>0?ooo`030000003oool0000000d0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<0
00000?ooo`0000003@3oool00`000000oooo000000070?ooo`030000003oool0oooo00/0oooo000K
0?ooo`8000002@3oool00`000000oooo0000000=0?ooo`040000003oool0oooo000000d0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<0
00000?ooo`0000003@3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0000000d0oooo
00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo
00<000000?ooo`0000001P3oool2000000d0oooo000K0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`0000003@3oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0000000=0?ooo`030000003oool00000
00d0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`040000003oool0oooo
000000`0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0000000=0?ooo`030000003o
ool0000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0000000=0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000
303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000d0oooo00<000000?oo
o`0000003@3oool00`000000oooo0000000=0?ooo`040000003oool0oooo000000`0oooo00@00000
0?ooo`3oool00000303oool010000000oooo0?ooo`00000=0?ooo`030000003oool0000000d0oooo
00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo
00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?oo
o`080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool010000000
oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool000003@3o
ool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00@000000?ooo`3oool00000
303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?oo
o`3oool000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<00000
0?ooo`0000003@3oool00`000000oooo000000070?ooo`030000003oool0oooo00/0oooo000K0?oo
o`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00
000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool010000000
oooo0?ooo`00000<0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`0000003@3oool0
10000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool0
0000303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000d0oooo00<00000
0?ooo`0000003@3oool00`000000oooo0000000=0?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00
000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool010000000
oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo0000
000<0?ooo`030000003oool0000000d0oooo00@000000?ooo`3oool00000303oool010000000oooo
0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool0
10000000oooo0?ooo`00000=0?ooo`030000003oool0000000`0oooo00D000000?ooo`3oool0oooo
0000000<0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool02`3oool001/0oooo
0P0000090?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool01000
0000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000
303oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`0000003@3oool010000000
oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303o
ool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`00
0000303oool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool000001@3oool2
000000d0oooo000K0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000303oool0
10000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool0
0000303oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool010000000oooo
0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool0
10000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool02`3oool001/0
oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo
000000`0oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?ooo`050000
003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?oo
o`3oool000002`3oool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool00000
303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`040000003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo
0000000<0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool02`3oool001/0oooo
00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo0000
00`0oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?ooo`050000003o
ool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3o
ool000002`3oool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool00000303o
ool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`05
0000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`00000<0?ooo`050000003oool0
oooo0?ooo`000000303oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00/0oooo
000K0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000303oool010000000oooo
0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo
00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`000000303oool01000
0000oooo0?ooo`00000<0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?oo
o`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?oo
o`0000002`3oool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`080?ooo`040000003oool0
oooo000000`0oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?ooo`05
0000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo
0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000003oool0oooo
0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool00000
00`0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`00
0000oooo0?ooo`080?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303o
ool010000000oooo0?ooo`00000<0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000
oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0
oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0
000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`000000
2`3oool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`0;0?ooo`006`3oool2000000T0oooo00@000000?ooo`3oool00000303oool01000
0000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool00000
00/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3o
ool01@000000oooo0?ooo`3oool0000000`0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`05
0000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`000000303oool010000000oooo
0?ooo`0000050?ooo`8000003@3oool001/0oooo00<000000?ooo`3oool0203oool010000000oooo
0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000
003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`000000303oool01@000000oooo0?oo
o`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?oo
o`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000
000<0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool02`3oool001/0oooo00<0
00000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`050000003oool0oooo0?ooo`000000303oool01@000000oooo0?ooo`3oool0
000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`000000
2`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`050000003oool0oooo0?ooo`000000303oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000
oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool01`3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000
003oool0oooo0?ooo`000000303oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?oo
o`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?oo
o`0000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?oo
o`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool01`3oool01@000000
oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0
oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`000000
2`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000<0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?oo
o`3oool01`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000
003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo
0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool01@000000oooo
0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`05
0000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`05
0000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00/0oooo000K0?oo
o`800000203oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000
003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000001@3oool2
000000d0oooo000K0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3o
ool0000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`00
00002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool01@00
0000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?oo
o`3oool0000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000
003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0;0?ooo`006`3o
ool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`05
0000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00/0oooo00070?ooo`<00000103oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool01@000000oooo0?oo
o`3oool0000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool02`3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool01@00
0000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`08
0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`00203oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00/0oooo00080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`800000203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3o
ool0000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool2000000d0oooo00080?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0203oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool0
00L0oooo0P0000040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00/0oooo00080?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00/0oooo000K0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000d0oooo000K0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool0
01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool001/0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool001/0oooo0P000008
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool2000000d0oooo000K0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00/0oooo000K0?ooo`8000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00P0oooo0P00000=0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;
0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`00
6`3oool2000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`800000
3@3oool001/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool0
01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02`3oool000H0oooo1@0000030?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02`3oool000L0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool0
00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02`3oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`8000003@3oool000H0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`001P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00/0oooo00070?ooo`<00000103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00/0oooo000K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0
oooo000K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo000K0?ooo`8000001`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00T0oooo0P00000=0?ooo`006`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;
0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`00
6`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`006`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0;0?ooo`006`3oool2000000H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`8000003@3oool001/0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool001/0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool001/0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool001/0oooo0P0000060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool2000000d0oooo000K0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo000K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0
oooo000K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo000K0?ooo`8000001P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00T0oooo0P00000=0?ooo`006`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;
0?ooo`006`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`00
6`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`001`3oool3000000@0oooo0P0000040?ooo`8000001@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo000:0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo0P00000=0?ooo`00203oool2000000<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo000:0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool000L0oooo
0`0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool001/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool001/0oooo0P0000050?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02P3oool2000000d0oooo000K0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0203oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
1@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool00000
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo000K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool01@000000
oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0
000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo000K0?ooo`8000001@3oool00`000000oooo
0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`05
0000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000002P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo0P00000=0?ooo`006`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?oo
o`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`006`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00P0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`00
00002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`09
0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000003o
ool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`080?ooo`050000003oool0oooo0?ooo`000000303oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool00000
00/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo
0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo
00/0oooo000K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool01@000000
oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool00000303oool01@000000oooo0?ooo`3o
ool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`00
00002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003o
ool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`0;0?ooo`006`3oool2000000D0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool0
0000303oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool0
1@000000oooo0?ooo`3oool0000000d0oooo0P00000=0?ooo`006`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`040000003o
ool0oooo000000`0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?oo
o`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo
0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool0
0000303oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo
00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000h0
oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`090?ooo`050000003oool0oooo0?ooo`000000303oool010000000oooo0?ooo`00000<0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000
oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?oo
o`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`00000<0?ooo`050000003o
ool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`0;
0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00D000000?oo
o`3oool0oooo0000000<0?ooo`040000003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool00000
00/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`040000003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
00000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000`0oooo
00@000000?ooo`3oool00000303oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?oo
o`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?oo
o`000000303oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool00000303o
ool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`05
0000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000h0oooo00<00000
0?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?oo
o`050000003oool0oooo0?ooo`000000303oool010000000oooo0?ooo`00000<0?ooo`040000003o
ool0oooo000000`0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?oo
o`0000002`3oool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool000002`3o
ool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool00000303oool010000000
oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000h0
oooo00<000000?ooo`3oool02`3oool001/0oooo0P0000040?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo
000000`0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`000000
2`3oool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool000002`3oool01@00
0000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool00000303oool010000000oooo0?oo
o`00000<0?ooo`040000003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000d0oooo0P00
000=0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00@00000
0?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool0
1@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool00000303oool010000000oooo
0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool0
10000000oooo0?ooo`00000<0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000oooo
0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo
00/0oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000
oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303o
ool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`05
0000003oool0oooo0?ooo`000000303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0
oooo000000`0oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?ooo`04
0000003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`040000003oool0
oooo000000/0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo00/0oooo
000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool01@00
0000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003o
ool0oooo000000d0oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?oo
o`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool010000000oooo0?oo
o`00000<0?ooo`050000003oool0oooo0?ooo`000000303oool010000000oooo0?ooo`00000;0?oo
o`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`00
0000oooo0?ooo`0@0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303o
ool010000000oooo0?ooo`00000<0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000
oooo0?ooo`3oool0000000`0oooo00<000000?ooo`0000003@3oool010000000oooo0?ooo`00000<
0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool010000000oooo
0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool000003P3oool00`000000oooo
0?ooo`0;0?ooo`00203oool3000000<0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`0@0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool010000000
oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool000003@3o
ool00`000000oooo0000000=0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool0
0000303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@00000
0?ooo`3oool00000303oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`000000
3@3oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo00/0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000<0?ooo`040000003oool0
oooo000000`0oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?ooo`04
0000003oool0oooo000000d0oooo00<000000?ooo`0000003@3oool010000000oooo0?ooo`00000<
0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool010000000oooo
0?ooo`00000<0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`0000003@3oool00`00
0000oooo0000000=0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool02`3oool0
00H0oooo1@0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool200000140oooo00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?ooo`04
0000003oool0oooo000000`0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0000000=
0?ooo`030000003oool0000000d0oooo00<000000?ooo`0000003@3oool010000000oooo0?ooo`00
000<0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool00000303oool010000000
oooo0?ooo`00000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`0000003@3oool01000
0000oooo0?ooo`00000=0?ooo`8000003@3oool000H0oooo00@000000?ooo`3oool000000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?oo
o`3oool00000303oool010000000oooo0?ooo`00000=0?ooo`030000003oool0000000d0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`040000003oool0oooo000000`0oooo
00@000000?ooo`3oool00000303oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo
000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`040000003oool0
oooo000000h0oooo00<000000?ooo`3oool02`3oool000L0oooo00<000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo000000`0oooo00@000000?oo
o`3oool00000303oool010000000oooo0?ooo`00000=0?ooo`030000003oool0000000d0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00@0
00000?ooo`3oool00000303oool010000000oooo0?ooo`00000=0?ooo`030000003oool0000000d0
oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`040000003oool0oooo0000
00h0oooo00<000000?ooo`3oool02`3oool000P0oooo0P0000030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`040000003oool0
oooo000000d0oooo0P00000>0?ooo`030000003oool0000000d0oooo00<000000?ooo`0000003@3o
ool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`0000003@3o
ool00`000000oooo0000000=0?ooo`040000003oool0oooo000000`0oooo00@000000?ooo`3oool0
00003@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`00
00003@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000
003oool0oooo0080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0000000h0oooo0P00000>0?ooo`030000003oool0000000d0oooo00<000000?ooo`000000
3@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`000000
3@3oool00`000000oooo0000000>0?ooo`8000003@3oool010000000oooo0?ooo`00000=0?ooo`03
0000003oool0000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`03
0000003oool0000000l0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0
403oool00`000000oooo0000000>0?ooo`8000003P3oool00`000000oooo0000000=0?ooo`030000
003oool0000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000
003oool0000000d0oooo00<000000?ooo`0000003P3oool2000000h0oooo00<000000?ooo`000000
3@3oool00`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`000000
3@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003o
ool0oooo0140oooo0P00000>0?ooo`8000003P3oool00`000000oooo0000000=0?ooo`030000003o
ool0000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003o
ool0000000h0oooo0P00000>0?ooo`8000003P3oool00`000000oooo0000000=0?ooo`030000003o
ool0000000d0oooo00<000000?ooo`0000003@3oool00`000000oooo0000000=0?ooo`030000003o
ool0000000l0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00000B0?ooo`8000003P3oool2
000000h0oooo0P00000>0?ooo`030000003oool0000000d0oooo00<000000?ooo`0000003@3oool0
0`000000oooo0000000>0?ooo`8000003P3oool2000000h0oooo0P00000>0?ooo`8000003P3oool0
0`000000oooo0000000=0?ooo`030000003oool0000000d0oooo00<000000?ooo`0000003P3oool2
000000h0oooo0P00000=0?ooo`006`3oool00`000000oooo0?ooo`0A0?ooo`8000003P3oool20000
00h0oooo0P00000>0?ooo`8000003P3oool2000000h0oooo0`00000>0?ooo`8000003P3oool20000
00h0oooo0P00000>0?ooo`8000003P3oool2000000h0oooo0P00000?0?ooo`8000003P3oool20000
00l0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool04@3oool2000000h0
oooo0P00000>0?ooo`8000003P3oool2000000l0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`8000003P3oool2000000h0oooo0P00000>0?ooo`8000003P3oool2000000l0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`8000003`3oool00`000000
oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0A0?ooo`8000003P3oool2000000h0oooo
0P00000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00d0oooo0P00000>0?ooo`8000003P3oool2000000l0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?oo
o`3d0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool001/0oooon000000=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00dP3oool3000004/0oooo003C0?ooo`030000003oool0oooo04X0oooo001D0?ooo`D0
000000D0oooo00000000000000000?ooo`0200000080oooo0P0000030?ooo`<000000P3oool30000
00<0oooo1@0000020?ooo`<000000P3oool3000000@0oooo0`0000020?ooo`<0000000@0oooo0000
00000000oooo0`0000030?ooo`<00000203oool5000000050?ooo`00000000000000003oool00P00
00020?ooo`8000000`3oool300000080oooo0`0000000`3oool000000000000400000080oooo1@00
00030?ooo`800000103oool00`000000oooo0?ooo`190?ooo`00EP3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00H000000?ooo`3oool000000?ooo`0000060?ooo`040000003oool0oooo000000D0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
B@3oool005H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo1@0000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
oooo1@0000020?ooo`030000003oool0oooo0080oooo1@0000020?ooo`060000003oool0oooo0000
003oool000001@3oool5000000T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo1@0000020?ooo`040000003oool0oooo00000080oooo
0`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0000001:0?ooo`00EP3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo0P0000050?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo
000000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?oo
o`060000003oool0oooo0000003oool000001`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000BP3oool005H0oooo00@000000?ooo`3oool0oooo1000
00020?ooo`@000000`3oool300000080oooo0P0000000`3oool00000000000020?ooo`@000000P3o
ool300000080oooo0P0000000`3oool00000000000020?ooo`<000000P3oool4000000<0oooo0`00
00030?ooo`<000002P3oool010000000oooo0?ooo`3oool400000080oooo100000030?ooo`<00000
0P3oool4000000<0oooo10000000103oool000000000000000030?ooo`@000000P3oool200000003
0?ooo`000000000004T0oooo001F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`1@0?ooo`00E03oool5000000P0oooo00<000000?ooo`3oool04@3o
ool2000002/0oooo1@0000080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1@0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00141415, -44.7655, \
4.24814*^-5, 2.93554}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 4", "Subsubsection",
  CellTags->{"AOG0.", "6.2.4", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell["\<\
This example shows how to create and interfere two wave-fronts \
simultaneously.\
\>", "Text",
  AspectRatioFixed->True,
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(outerradius =  .5\ 106\)], "Input",
  CellLabel->"In[3]:=",
  AspectRatioFixed->True,
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[BoxData[
    \(53.`\)], "Output",
  CellLabel->"Out[3]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}]
}, Open  ]],

Cell[BoxData[
    \(\(Piston = 
        ComponentRendering[{Move[
              CylindricalLensSurface[40, {1.9999\ 40, 120}, 
                ComponentMedium \[Rule] FusedSilica, PlotPoints \[Rule] 50], 
              outerradius - 40], 
            CylindricalLensSurface[outerradius, {1.999\ outerradius, 120}, 
              ComponentMedium \[Rule] FusedSilica, PlotPoints \[Rule] 50]}, 
          Labels \[Rule] {"\<\>"}, PlotPoints \[Rule] 50];\)\)], "Input",
  CellLabel->"In[4]:=",
  AspectRatioFixed->True,
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[BoxData[{
    \(\(Clear[H, L1, L2, CL];\)\), "\n", 
    \(\(H = Window[{5. \ 25.4, 4\ 25.4}, 1.5, "\<H\>"];\)\), "\n", 
    \(\(L1 = 
        PlanoConvexLens[450, 145, 15.5, "\<L1\>", 
          CurvatureDirection \[Rule] Back];\)\), "\n", 
    \(\(L2 = 
        PlanoConvexLens[450, 145, 15.5, "\<L2\>", 
          CurvatureDirection \[Rule] Back];\)\), "\n", 
    \(\(CL = 
        PlanoConvexCylindricalLens[100, {50, 60}, 8.89, "\<CL\>", 
          CurvatureDirection \[Rule] Back];\)\)}], "Input",
  CellLabel->"In[5]:=",
  AspectRatioFixed->True,
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[BoxData[
    \(\(reference\  = \ 
        Move[WedgeOfRays[7. , WaveLength \[Rule]  .532], {422, 0}, 
          180];\)\)], "Input",
  CellLabel->"In[10]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[BoxData[
    \(\(HOE = 
        Move[{Window[60, 1.5, "\<HOE\>"], 
            Move[CircleGraphic[{57, 85}], {\(-1.5\), 5.5}], 
            CircleGraphic[4]}, {0, 
            0}, \(-\((ArcTan[\(-30. \), 48. ] - ArcTan[\(-45. \), 28. ])\)\)/
            Degree];\)\)], "Input",
  CellLabel->"In[11]:=",
  AspectRatioFixed->True,
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[BoxData[{
    \(\(in = 24.5;\)\), "\n", 
    \(\(mm = 1;\)\), "\n", 
    \(\(L = 
        PlanoConvexLens[100, 25, 5, CurvatureDirection -> Back];\)\), "\n", 
    \(\(M = Mirror[1\ in, 6, GraphicDesign \[Rule] Solid];\)\)}], "Input",
  CellLabel->"In[12]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell["\<\
planesource = {Move[WedgeOfRays[10],{-640+115,185}],
\t\t\tMove[L,{-640+115+100,185}],
\t\t\tMoveReflected[M,{-640+115+100,185},{-640+115+100+100+75,185},{-475,0}]};\
\
\>", "Input",
  CellLabel->"In[16]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell["\<\
combinedsys = 
\t\t{\treference,
\t\t\tMove[Piston,20],
\t\t\tMove[{Move[Baffle[{25,120},Labels\[Rule]\"\"],{0,.5 65+12.5}],
\t\t\tMove[Baffle[{25,120},Labels\[Rule]\"\"],{0,-.5 65-12.5}]},5],
\t\t\tMove[H,-4.5],
\t\t\tMove[L1,{-30,0},180],
\t\t\tMove[L2,{-80,0},0],
\t\t\tMove[CL,-375],
\t\t\tplanesource,
\t\t\tMove[HOE,-475,MoveRelative->False]};\
\>", "Input",
  CellLabel->"In[17]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell["\<\
combinedsys = 
\t\t{\treference,
\t\t\tplanesource,
\t\t\tMove[Piston,20],
\t\t\tMove[{Move[Baffle[{25,120},Labels\[Rule]\"\"],{0,.5 65+12.5}],
\t\t\tMove[Baffle[{25,120},Labels\[Rule]\"\"],{0,-.5 65-12.5}]},5],
\t\t\tMove[H,-4.5],
\t\t\tMove[L1,{-30,0},180],
\t\t\tMove[L2,{-80,0},0],
\t\t\tMove[CL,-375],
\t\t\tMove[HOE,-475,MoveRelative->False]};\
\>", "Input",
  CellLabel->"In[18]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DrawSystem[combinedsys, PlotType \[Rule] TopView, 
        PlotPoints \[Rule] 50];\)\)], "Input",
  CellLabel->"In[19]:=",
  AspectRatioFixed->True,
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .31195 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.551793 0.00100568 0.104839 0.00100568 [
[.31563 .25725 -3 -4.5 ]
[.31563 .25725 3 4.5 ]
[.12689 .25382 -3 -4.5 ]
[.12689 .25382 3 4.5 ]
[.54802 .01648 -3 -4.5 ]
[.54802 .01648 3 4.5 ]
[.51383 .20225 -6 -4.5 ]
[.51383 .20225 6 4.5 ]
[.47913 .00743 -6 -4.5 ]
[.47913 .00743 6 4.5 ]
[.09883 .05608 -9 -4.5 ]
[.09883 .05608 9 4.5 ]
[.17913 .05017 -6 -4.5 ]
[.17913 .05017 6 4.5 ]
[ 0 0 0 0 ]
[ 1 .31195 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.12438 .27832 m
.12787 .27832 L
.12816 .27958 L
.12438 .27958 L
.12438 .27832 L
F
.12438 .27958 m
.12816 .27958 L
.12843 .28083 L
.12438 .28083 L
.12438 .27958 L
F
.12438 .28083 m
.12843 .28083 L
.12866 .28209 L
.12438 .28209 L
.12438 .28083 L
F
.12438 .28209 m
.12866 .28209 L
.12886 .28335 L
.12438 .28335 L
.12438 .28209 L
F
.12438 .28335 m
.12886 .28335 L
.12903 .2846 L
.12438 .2846 L
.12438 .28335 L
F
.12438 .2846 m
.12903 .2846 L
.12916 .28586 L
.12438 .28586 L
.12438 .2846 L
F
.12438 .28586 m
.12916 .28586 L
.12927 .28712 L
.12438 .28712 L
.12438 .28586 L
F
.12438 .28712 m
.12927 .28712 L
.12935 .28838 L
.12438 .28838 L
.12438 .28712 L
F
.12438 .28838 m
.12935 .28838 L
.12939 .28963 L
.12438 .28963 L
.12438 .28838 L
F
.12438 .28963 m
.12939 .28963 L
.12941 .29089 L
.12438 .29089 L
.12438 .28963 L
F
.12438 .29089 m
.12941 .29089 L
.12939 .29215 L
.12438 .29215 L
.12438 .29089 L
F
.12438 .29215 m
.12939 .29215 L
.12935 .2934 L
.12438 .2934 L
.12438 .29215 L
F
.12438 .2934 m
.12935 .2934 L
.12927 .29466 L
.12438 .29466 L
.12438 .2934 L
F
.12438 .29466 m
.12927 .29466 L
.12916 .29592 L
.12438 .29592 L
.12438 .29466 L
F
.12438 .29592 m
.12916 .29592 L
.12903 .29718 L
.12438 .29718 L
.12438 .29592 L
F
.12438 .29718 m
.12903 .29718 L
.12886 .29843 L
.12438 .29843 L
.12438 .29718 L
F
.12438 .29843 m
.12886 .29843 L
.12866 .29969 L
.12438 .29969 L
.12438 .29843 L
F
.12438 .29969 m
.12866 .29969 L
.12843 .30095 L
.12438 .30095 L
.12438 .29969 L
F
.12438 .30095 m
.12843 .30095 L
.12816 .3022 L
.12438 .3022 L
.12438 .30095 L
F
.12438 .3022 m
.12816 .3022 L
.12787 .30346 L
.12438 .30346 L
.12438 .3022 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.12438 .27832 m
.12438 .27958 L
.12438 .28083 L
.12438 .28209 L
.12438 .28335 L
.12438 .2846 L
.12438 .28586 L
.12438 .28712 L
.12438 .28838 L
.12438 .28963 L
.12438 .29089 L
.12438 .29215 L
.12438 .2934 L
.12438 .29466 L
.12438 .29592 L
.12438 .29718 L
.12438 .29843 L
.12438 .29969 L
.12438 .30095 L
.12438 .3022 L
.12438 .30346 L
.12787 .30346 L
.12816 .3022 L
.12843 .30095 L
.12866 .29969 L
.12886 .29843 L
.12903 .29718 L
.12916 .29592 L
.12927 .29466 L
.12935 .2934 L
.12939 .29215 L
.12941 .29089 L
.12939 .28963 L
.12935 .28838 L
.12927 .28712 L
.12916 .28586 L
.12903 .2846 L
.12886 .28335 L
.12866 .28209 L
.12843 .28083 L
.12816 .27958 L
.12787 .27832 L
.12438 .27832 L
s
.5 g
.12438 .29089 m
.12787 .29089 L
.12816 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12816 .29089 L
.12843 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12843 .29089 L
.12866 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12866 .29089 L
.12886 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12886 .29089 L
.12903 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12903 .29089 L
.12916 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12916 .29089 L
.12927 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12927 .29089 L
.12935 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12935 .29089 L
.12939 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12939 .29089 L
.12941 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12941 .29089 L
.12939 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12939 .29089 L
.12935 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12935 .29089 L
.12927 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12927 .29089 L
.12916 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12916 .29089 L
.12903 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12903 .29089 L
.12886 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12886 .29089 L
.12866 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12866 .29089 L
.12843 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12843 .29089 L
.12816 .29089 L
.12438 .29089 L
.12438 .29089 L
F
.12438 .29089 m
.12816 .29089 L
.12787 .29089 L
.12438 .29089 L
.12438 .29089 L
F
0 g
.12438 .29089 m
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12438 .29089 L
.12787 .29089 L
.12816 .29089 L
.12843 .29089 L
.12866 .29089 L
.12886 .29089 L
.12903 .29089 L
.12916 .29089 L
.12927 .29089 L
.12935 .29089 L
.12939 .29089 L
.12941 .29089 L
.12939 .29089 L
.12935 .29089 L
.12927 .29089 L
.12916 .29089 L
.12903 .29089 L
.12886 .29089 L
.12866 .29089 L
.12843 .29089 L
.12816 .29089 L
.12787 .29089 L
.12438 .29089 L
s
.12438 .30346 m
.12787 .30346 L
.12787 .30342 L
.12438 .30342 L
.12438 .30346 L
s
.12438 .30342 m
.12787 .30342 L
.12787 .30331 L
.12438 .30331 L
.12438 .30342 L
s
.12438 .30331 m
.12787 .30331 L
.12787 .30311 L
.12438 .30311 L
.12438 .30331 L
s
.12438 .30311 m
.12787 .30311 L
.12787 .30285 L
.12438 .30285 L
.12438 .30311 L
s
.12438 .30285 m
.12787 .30285 L
.12787 .3025 L
.12438 .3025 L
.12438 .30285 L
s
.12438 .3025 m
.12787 .3025 L
.12787 .30209 L
.12438 .30209 L
.12438 .3025 L
s
.12438 .30209 m
.12787 .30209 L
.12787 .30161 L
.12438 .30161 L
.12438 .30209 L
s
.12438 .30161 m
.12787 .30161 L
.12787 .30106 L
.12438 .30106 L
.12438 .30161 L
s
.12438 .30106 m
.12787 .30106 L
.12787 .30045 L
.12438 .30045 L
.12438 .30106 L
s
.12438 .30045 m
.12787 .30045 L
.12787 .29978 L
.12438 .29978 L
.12438 .30045 L
s
.12438 .29978 m
.12787 .29978 L
.12787 .29905 L
.12438 .29905 L
.12438 .29978 L
s
.12438 .29905 m
.12787 .29905 L
.12787 .29828 L
.12438 .29828 L
.12438 .29905 L
s
.12438 .29828 m
.12787 .29828 L
.12787 .29746 L
.12438 .29746 L
.12438 .29828 L
s
.12438 .29746 m
.12787 .29746 L
.12787 .2966 L
.12438 .2966 L
.12438 .29746 L
s
.12438 .2966 m
.12787 .2966 L
.12787 .2957 L
.12438 .2957 L
.12438 .2966 L
s
.12438 .2957 m
.12787 .2957 L
.12787 .29477 L
.12438 .29477 L
.12438 .2957 L
s
.12438 .29477 m
.12787 .29477 L
.12787 .29382 L
.12438 .29382 L
.12438 .29477 L
s
.12438 .29382 m
.12787 .29382 L
.12787 .29286 L
.12438 .29286 L
.12438 .29382 L
s
.12438 .29286 m
.12787 .29286 L
.12787 .29188 L
.12438 .29188 L
.12438 .29286 L
s
.12438 .29188 m
.12787 .29188 L
.12787 .29089 L
.12438 .29089 L
.12438 .29188 L
s
.12438 .29089 m
.12787 .29089 L
.12787 .2899 L
.12438 .2899 L
.12438 .29089 L
s
.12438 .2899 m
.12787 .2899 L
.12787 .28892 L
.12438 .28892 L
.12438 .2899 L
s
.12438 .28892 m
.12787 .28892 L
.12787 .28796 L
.12438 .28796 L
.12438 .28892 L
s
.12438 .28796 m
.12787 .28796 L
.12787 .28701 L
.12438 .28701 L
.12438 .28796 L
s
.12438 .28701 m
.12787 .28701 L
.12787 .28608 L
.12438 .28608 L
.12438 .28701 L
s
.12438 .28608 m
.12787 .28608 L
.12787 .28518 L
.12438 .28518 L
.12438 .28608 L
s
.12438 .28518 m
.12787 .28518 L
.12787 .28432 L
.12438 .28432 L
.12438 .28518 L
s
.12438 .28432 m
.12787 .28432 L
.12787 .2835 L
.12438 .2835 L
.12438 .28432 L
s
.12438 .2835 m
.12787 .2835 L
.12787 .28273 L
.12438 .28273 L
.12438 .2835 L
s
.12438 .28273 m
.12787 .28273 L
.12787 .282 L
.12438 .282 L
.12438 .28273 L
s
.12438 .282 m
.12787 .282 L
.12787 .28133 L
.12438 .28133 L
.12438 .282 L
s
.12438 .28133 m
.12787 .28133 L
.12787 .28072 L
.12438 .28072 L
.12438 .28133 L
s
.12438 .28072 m
.12787 .28072 L
.12787 .28017 L
.12438 .28017 L
.12438 .28072 L
s
.12438 .28017 m
.12787 .28017 L
.12787 .27969 L
.12438 .27969 L
.12438 .28017 L
s
.12438 .27969 m
.12787 .27969 L
.12787 .27928 L
.12438 .27928 L
.12438 .27969 L
s
.12438 .27928 m
.12787 .27928 L
.12787 .27893 L
.12438 .27893 L
.12438 .27928 L
s
.12438 .27893 m
.12787 .27893 L
.12787 .27867 L
.12438 .27867 L
.12438 .27893 L
s
.12438 .27867 m
.12787 .27867 L
.12787 .27847 L
.12438 .27847 L
.12438 .27867 L
s
.12438 .27847 m
.12787 .27847 L
.12787 .27836 L
.12438 .27836 L
.12438 .27847 L
s
.12438 .27836 m
.12787 .27836 L
.12787 .27832 L
.12438 .27832 L
.12438 .27836 L
s
.12438 .27832 m
.12787 .27832 L
.12787 .27836 L
.12438 .27836 L
.12438 .27832 L
s
.12438 .27836 m
.12787 .27836 L
.12787 .27847 L
.12438 .27847 L
.12438 .27836 L
s
.12438 .27847 m
.12787 .27847 L
.12787 .27867 L
.12438 .27867 L
.12438 .27847 L
s
.12438 .27867 m
.12787 .27867 L
.12787 .27893 L
.12438 .27893 L
.12438 .27867 L
s
.12438 .27893 m
.12787 .27893 L
.12787 .27928 L
.12438 .27928 L
.12438 .27893 L
s
.12438 .27928 m
.12787 .27928 L
.12787 .27969 L
.12438 .27969 L
.12438 .27928 L
s
.12438 .27969 m
.12787 .27969 L
.12787 .28017 L
.12438 .28017 L
.12438 .27969 L
s
.12438 .28017 m
.12787 .28017 L
.12787 .28072 L
.12438 .28072 L
.12438 .28017 L
s
.12438 .28072 m
.12787 .28072 L
.12787 .28133 L
.12438 .28133 L
.12438 .28072 L
s
.12438 .28133 m
.12787 .28133 L
.12787 .282 L
.12438 .282 L
.12438 .28133 L
s
.12438 .282 m
.12787 .282 L
.12787 .28273 L
.12438 .28273 L
.12438 .282 L
s
.12438 .28273 m
.12787 .28273 L
.12787 .2835 L
.12438 .2835 L
.12438 .28273 L
s
.12438 .2835 m
.12787 .2835 L
.12787 .28432 L
.12438 .28432 L
.12438 .2835 L
s
.12438 .28432 m
.12787 .28432 L
.12787 .28518 L
.12438 .28518 L
.12438 .28432 L
s
.12438 .28518 m
.12787 .28518 L
.12787 .28608 L
.12438 .28608 L
.12438 .28518 L
s
.12438 .28608 m
.12787 .28608 L
.12787 .28701 L
.12438 .28701 L
.12438 .28608 L
s
.12438 .28701 m
.12787 .28701 L
.12787 .28796 L
.12438 .28796 L
.12438 .28701 L
s
.12438 .28796 m
.12787 .28796 L
.12787 .28892 L
.12438 .28892 L
.12438 .28796 L
s
.12438 .28892 m
.12787 .28892 L
.12787 .2899 L
.12438 .2899 L
.12438 .28892 L
s
.12438 .2899 m
.12787 .2899 L
.12787 .29089 L
.12438 .29089 L
.12438 .2899 L
s
.12438 .29089 m
.12787 .29089 L
.12787 .29188 L
.12438 .29188 L
.12438 .29089 L
s
.12438 .29188 m
.12787 .29188 L
.12787 .29286 L
.12438 .29286 L
.12438 .29188 L
s
.12438 .29286 m
.12787 .29286 L
.12787 .29382 L
.12438 .29382 L
.12438 .29286 L
s
.12438 .29382 m
.12787 .29382 L
.12787 .29477 L
.12438 .29477 L
.12438 .29382 L
s
.12438 .29477 m
.12787 .29477 L
.12787 .2957 L
.12438 .2957 L
.12438 .29477 L
s
.12438 .2957 m
.12787 .2957 L
.12787 .2966 L
.12438 .2966 L
.12438 .2957 L
s
.12438 .2966 m
.12787 .2966 L
.12787 .29746 L
.12438 .29746 L
.12438 .2966 L
s
.12438 .29746 m
.12787 .29746 L
.12787 .29828 L
.12438 .29828 L
.12438 .29746 L
s
.12438 .29828 m
.12787 .29828 L
.12787 .29905 L
.12438 .29905 L
.12438 .29828 L
s
.12438 .29905 m
.12787 .29905 L
.12787 .29978 L
.12438 .29978 L
.12438 .29905 L
s
.12438 .29978 m
.12787 .29978 L
.12787 .30045 L
.12438 .30045 L
.12438 .29978 L
s
.12438 .30045 m
.12787 .30045 L
.12787 .30106 L
.12438 .30106 L
.12438 .30045 L
s
.12438 .30106 m
.12787 .30106 L
.12787 .30161 L
.12438 .30161 L
.12438 .30106 L
s
.12438 .30161 m
.12787 .30161 L
.12787 .30209 L
.12438 .30209 L
.12438 .30161 L
s
.12438 .30209 m
.12787 .30209 L
.12787 .3025 L
.12438 .3025 L
.12438 .30209 L
s
.12438 .3025 m
.12787 .3025 L
.12787 .30285 L
.12438 .30285 L
.12438 .3025 L
s
.12438 .30285 m
.12787 .30285 L
.12787 .30311 L
.12438 .30311 L
.12438 .30285 L
s
.12438 .30311 m
.12787 .30311 L
.12787 .30331 L
.12438 .30331 L
.12438 .30311 L
s
.12438 .30331 m
.12787 .30331 L
.12787 .30342 L
.12438 .30342 L
.12438 .30331 L
s
.12438 .30342 m
.12787 .30342 L
.12787 .30346 L
.12438 .30346 L
.12438 .30342 L
s
.5 g
.30037 .29089 m
.29996 .29205 L
.29996 .29205 L
.30037 .29089 L
.30037 .29089 L
F
.29996 .29205 m
.29954 .29321 L
.29954 .2932 L
.29996 .29205 L
.29996 .29205 L
F
.29954 .29321 m
.29913 .29437 L
.29913 .29436 L
.29954 .2932 L
.29954 .29321 L
F
.29913 .29437 m
.29871 .29553 L
.29871 .29551 L
.29913 .29436 L
.29913 .29437 L
F
.29871 .29553 m
.29829 .29669 L
.2983 .29667 L
.29871 .29551 L
.29871 .29553 L
F
.29829 .29669 m
.29788 .29785 L
.29789 .29783 L
.2983 .29667 L
.29829 .29669 L
F
.29788 .29785 m
.29746 .29901 L
.29747 .29898 L
.29789 .29783 L
.29788 .29785 L
F
.29746 .29901 m
.29705 .30017 L
.29706 .30014 L
.29747 .29898 L
.29746 .29901 L
F
.29705 .30017 m
.29663 .30133 L
.29664 .3013 L
.29706 .30014 L
.29705 .30017 L
F
.29663 .30133 m
.29622 .30249 L
.29623 .30245 L
.29664 .3013 L
.29663 .30133 L
F
.30037 .29089 m
.29996 .29205 L
.29996 .29204 L
.30037 .29089 L
.30037 .29089 L
F
.29996 .29205 m
.29954 .2932 L
.29955 .29318 L
.29996 .29204 L
.29996 .29205 L
F
.29954 .2932 m
.29913 .29436 L
.29914 .29433 L
.29955 .29318 L
.29954 .2932 L
F
.29913 .29436 m
.29871 .29551 L
.29873 .29547 L
.29914 .29433 L
.29913 .29436 L
F
.29871 .29551 m
.2983 .29667 L
.29832 .29662 L
.29873 .29547 L
.29871 .29551 L
F
.2983 .29667 m
.29789 .29783 L
.29791 .29776 L
.29832 .29662 L
.2983 .29667 L
F
.29789 .29783 m
.29747 .29898 L
.2975 .29891 L
.29791 .29776 L
.29789 .29783 L
F
.29747 .29898 m
.29706 .30014 L
.29709 .30005 L
.2975 .29891 L
.29747 .29898 L
F
.29706 .30014 m
.29664 .3013 L
.29668 .3012 L
.29709 .30005 L
.29706 .30014 L
F
.29664 .3013 m
.29623 .30245 L
.29627 .30234 L
.29668 .3012 L
.29664 .3013 L
F
.30037 .29089 m
.29996 .29204 L
.29997 .29202 L
.30037 .29089 L
.30037 .29089 L
F
.29996 .29204 m
.29955 .29318 L
.29956 .29315 L
.29997 .29202 L
.29996 .29204 L
F
.29955 .29318 m
.29914 .29433 L
.29916 .29427 L
.29956 .29315 L
.29955 .29318 L
F
.29914 .29433 m
.29873 .29547 L
.29876 .2954 L
.29916 .29427 L
.29914 .29433 L
F
.29873 .29547 m
.29832 .29662 L
.29835 .29653 L
.29876 .2954 L
.29873 .29547 L
F
.29832 .29662 m
.29791 .29776 L
.29795 .29766 L
.29835 .29653 L
.29832 .29662 L
F
.29791 .29776 m
.2975 .29891 L
.29754 .29878 L
.29795 .29766 L
.29791 .29776 L
F
.2975 .29891 m
.29709 .30005 L
.29714 .29991 L
.29754 .29878 L
.2975 .29891 L
F
.29709 .30005 m
.29668 .3012 L
.29674 .30104 L
.29714 .29991 L
.29709 .30005 L
F
.29668 .3012 m
.29627 .30234 L
.29633 .30217 L
.29674 .30104 L
.29668 .3012 L
F
.30037 .29089 m
.29997 .29202 L
.29998 .29199 L
.30037 .29089 L
.30037 .29089 L
F
.29997 .29202 m
.29956 .29315 L
.29958 .2931 L
.29998 .29199 L
.29997 .29202 L
F
.29956 .29315 m
.29916 .29427 L
.29919 .2942 L
.29958 .2931 L
.29956 .29315 L
F
.29916 .29427 m
.29876 .2954 L
.29879 .2953 L
.29919 .2942 L
.29916 .29427 L
F
.29876 .2954 m
.29835 .29653 L
.2984 .29641 L
.29879 .2953 L
.29876 .2954 L
F
.29835 .29653 m
.29795 .29766 L
.298 .29751 L
.2984 .29641 L
.29835 .29653 L
F
.29795 .29766 m
.29754 .29878 L
.29761 .29861 L
.298 .29751 L
.29795 .29766 L
F
.29754 .29878 m
.29714 .29991 L
.29721 .29971 L
.29761 .29861 L
.29754 .29878 L
F
.29714 .29991 m
.29674 .30104 L
.29682 .30082 L
.29721 .29971 L
.29714 .29991 L
F
.29674 .30104 m
.29633 .30217 L
.29642 .30192 L
.29682 .30082 L
.29674 .30104 L
F
.30037 .29089 m
.29998 .29199 L
.29999 .29196 L
.30037 .29089 L
.30037 .29089 L
F
.29998 .29199 m
.29958 .2931 L
.2996 .29303 L
.29999 .29196 L
.29998 .29199 L
F
.29958 .2931 m
.29919 .2942 L
.29922 .2941 L
.2996 .29303 L
.29958 .2931 L
F
.29919 .2942 m
.29879 .2953 L
.29884 .29518 L
.29922 .2941 L
.29919 .2942 L
F
.29879 .2953 m
.2984 .29641 L
.29845 .29625 L
.29884 .29518 L
.29879 .2953 L
F
.2984 .29641 m
.298 .29751 L
.29807 .29732 L
.29845 .29625 L
.2984 .29641 L
F
.298 .29751 m
.29761 .29861 L
.29768 .29839 L
.29807 .29732 L
.298 .29751 L
F
.29761 .29861 m
.29721 .29971 L
.2973 .29946 L
.29768 .29839 L
.29761 .29861 L
F
.29721 .29971 m
.29682 .30082 L
.29692 .30053 L
.2973 .29946 L
.29721 .29971 L
F
.29682 .30082 m
.29642 .30192 L
.29653 .3016 L
.29692 .30053 L
.29682 .30082 L
F
.30037 .29089 m
.29999 .29196 L
.3 .29192 L
.30037 .29089 L
.30037 .29089 L
F
.29999 .29196 m
.2996 .29303 L
.29963 .29296 L
.3 .29192 L
.29999 .29196 L
F
.2996 .29303 m
.29922 .2941 L
.29926 .29399 L
.29963 .29296 L
.2996 .29303 L
F
.29922 .2941 m
.29884 .29518 L
.29889 .29502 L
.29926 .29399 L
.29922 .2941 L
F
.29884 .29518 m
.29845 .29625 L
.29852 .29606 L
.29889 .29502 L
.29884 .29518 L
F
.29845 .29625 m
.29807 .29732 L
.29815 .29709 L
.29852 .29606 L
.29845 .29625 L
F
.29807 .29732 m
.29768 .29839 L
.29778 .29812 L
.29815 .29709 L
.29807 .29732 L
F
.29768 .29839 m
.2973 .29946 L
.29741 .29916 L
.29778 .29812 L
.29768 .29839 L
F
.2973 .29946 m
.29692 .30053 L
.29704 .30019 L
.29741 .29916 L
.2973 .29946 L
F
.29692 .30053 m
.29653 .3016 L
.29667 .30122 L
.29704 .30019 L
.29692 .30053 L
F
.30037 .29089 m
.3 .29192 L
.30002 .29188 L
.30037 .29089 L
.30037 .29089 L
F
.3 .29192 m
.29963 .29296 L
.29966 .29287 L
.30002 .29188 L
.3 .29192 L
F
.29963 .29296 m
.29926 .29399 L
.29931 .29386 L
.29966 .29287 L
.29963 .29296 L
F
.29926 .29399 m
.29889 .29502 L
.29895 .29485 L
.29931 .29386 L
.29926 .29399 L
F
.29889 .29502 m
.29852 .29606 L
.2986 .29583 L
.29895 .29485 L
.29889 .29502 L
F
.29852 .29606 m
.29815 .29709 L
.29825 .29682 L
.2986 .29583 L
.29852 .29606 L
F
.29815 .29709 m
.29778 .29812 L
.29789 .29781 L
.29825 .29682 L
.29815 .29709 L
F
.29778 .29812 m
.29741 .29916 L
.29754 .2988 L
.29789 .29781 L
.29778 .29812 L
F
.29741 .29916 m
.29704 .30019 L
.29718 .29979 L
.29754 .2988 L
.29741 .29916 L
F
.29704 .30019 m
.29667 .30122 L
.29683 .30078 L
.29718 .29979 L
.29704 .30019 L
F
.30037 .29089 m
.30002 .29188 L
.30004 .29183 L
.30037 .29089 L
.30037 .29089 L
F
.30002 .29188 m
.29966 .29287 L
.2997 .29277 L
.30004 .29183 L
.30002 .29188 L
F
.29966 .29287 m
.29931 .29386 L
.29936 .2937 L
.2997 .29277 L
.29966 .29287 L
F
.29931 .29386 m
.29895 .29485 L
.29903 .29464 L
.29936 .2937 L
.29931 .29386 L
F
.29895 .29485 m
.2986 .29583 L
.29869 .29558 L
.29903 .29464 L
.29895 .29485 L
F
.2986 .29583 m
.29825 .29682 L
.29835 .29652 L
.29869 .29558 L
.2986 .29583 L
F
.29825 .29682 m
.29789 .29781 L
.29802 .29746 L
.29835 .29652 L
.29825 .29682 L
F
.29789 .29781 m
.29754 .2988 L
.29768 .2984 L
.29802 .29746 L
.29789 .29781 L
F
.29754 .2988 m
.29718 .29979 L
.29735 .29933 L
.29768 .2984 L
.29754 .2988 L
F
.29718 .29979 m
.29683 .30078 L
.29701 .30027 L
.29735 .29933 L
.29718 .29979 L
F
.30037 .29089 m
.30004 .29183 L
.30006 .29177 L
.30037 .29089 L
.30037 .29089 L
F
.30004 .29183 m
.2997 .29277 L
.29974 .29265 L
.30006 .29177 L
.30004 .29183 L
F
.2997 .29277 m
.29936 .2937 L
.29942 .29354 L
.29974 .29265 L
.2997 .29277 L
F
.29936 .2937 m
.29903 .29464 L
.29911 .29442 L
.29942 .29354 L
.29936 .2937 L
F
.29903 .29464 m
.29869 .29558 L
.29879 .2953 L
.29911 .29442 L
.29903 .29464 L
F
.29869 .29558 m
.29835 .29652 L
.29848 .29618 L
.29879 .2953 L
.29869 .29558 L
F
.29835 .29652 m
.29802 .29746 L
.29816 .29706 L
.29848 .29618 L
.29835 .29652 L
F
.29802 .29746 m
.29768 .2984 L
.29784 .29795 L
.29816 .29706 L
.29802 .29746 L
F
.29768 .2984 m
.29735 .29933 L
.29753 .29883 L
.29784 .29795 L
.29768 .2984 L
F
.29735 .29933 m
.29701 .30027 L
.29721 .29971 L
.29753 .29883 L
.29735 .29933 L
F
.30037 .29089 m
.30006 .29177 L
.30008 .29171 L
.30037 .29089 L
.30037 .29089 L
F
.30006 .29177 m
.29974 .29265 L
.29978 .29253 L
.30008 .29171 L
.30006 .29177 L
F
.29974 .29265 m
.29942 .29354 L
.29949 .29335 L
.29978 .29253 L
.29974 .29265 L
F
.29942 .29354 m
.29911 .29442 L
.2992 .29417 L
.29949 .29335 L
.29942 .29354 L
F
.29911 .29442 m
.29879 .2953 L
.2989 .29499 L
.2992 .29417 L
.29911 .29442 L
F
.29879 .2953 m
.29848 .29618 L
.29861 .29581 L
.2989 .29499 L
.29879 .2953 L
F
.29848 .29618 m
.29816 .29706 L
.29832 .29663 L
.29861 .29581 L
.29848 .29618 L
F
.29816 .29706 m
.29784 .29795 L
.29802 .29745 L
.29832 .29663 L
.29816 .29706 L
F
.29784 .29795 m
.29753 .29883 L
.29773 .29827 L
.29802 .29745 L
.29784 .29795 L
F
.29753 .29883 m
.29721 .29971 L
.29743 .29909 L
.29773 .29827 L
.29753 .29883 L
F
.30037 .29089 m
.30008 .29171 L
.3001 .29164 L
.30037 .29089 L
.30037 .29089 L
F
.30008 .29171 m
.29978 .29253 L
.29983 .2924 L
.3001 .29164 L
.30008 .29171 L
F
.29978 .29253 m
.29949 .29335 L
.29956 .29315 L
.29983 .2924 L
.29978 .29253 L
F
.29949 .29335 m
.2992 .29417 L
.29929 .2939 L
.29956 .29315 L
.29949 .29335 L
F
.2992 .29417 m
.2989 .29499 L
.29902 .29466 L
.29929 .2939 L
.2992 .29417 L
F
.2989 .29499 m
.29861 .29581 L
.29875 .29541 L
.29902 .29466 L
.2989 .29499 L
F
.29861 .29581 m
.29832 .29663 L
.29848 .29616 L
.29875 .29541 L
.29861 .29581 L
F
.29832 .29663 m
.29802 .29745 L
.29821 .29692 L
.29848 .29616 L
.29832 .29663 L
F
.29802 .29745 m
.29773 .29827 L
.29794 .29767 L
.29821 .29692 L
.29802 .29745 L
F
.29773 .29827 m
.29743 .29909 L
.29767 .29842 L
.29794 .29767 L
.29773 .29827 L
F
.30037 .29089 m
.3001 .29164 L
.30013 .29157 L
.30037 .29089 L
.30037 .29089 L
F
.3001 .29164 m
.29983 .2924 L
.29988 .29225 L
.30013 .29157 L
.3001 .29164 L
F
.29983 .2924 m
.29956 .29315 L
.29964 .29294 L
.29988 .29225 L
.29983 .2924 L
F
.29956 .29315 m
.29929 .2939 L
.2994 .29362 L
.29964 .29294 L
.29956 .29315 L
F
.29929 .2939 m
.29902 .29466 L
.29915 .2943 L
.2994 .29362 L
.29929 .2939 L
F
.29902 .29466 m
.29875 .29541 L
.29891 .29498 L
.29915 .2943 L
.29902 .29466 L
F
.29875 .29541 m
.29848 .29616 L
.29866 .29566 L
.29891 .29498 L
.29875 .29541 L
F
.29848 .29616 m
.29821 .29692 L
.29842 .29634 L
.29866 .29566 L
.29848 .29616 L
F
.29821 .29692 m
.29794 .29767 L
.29817 .29703 L
.29842 .29634 L
.29821 .29692 L
F
.29794 .29767 m
.29767 .29842 L
.29793 .29771 L
.29817 .29703 L
.29794 .29767 L
F
.30037 .29089 m
.30013 .29157 L
.30015 .2915 L
.30037 .29089 L
.30037 .29089 L
F
.30013 .29157 m
.29988 .29225 L
.29994 .2921 L
.30015 .2915 L
.30013 .29157 L
F
.29988 .29225 m
.29964 .29294 L
.29972 .29271 L
.29994 .2921 L
.29988 .29225 L
F
.29964 .29294 m
.2994 .29362 L
.2995 .29331 L
.29972 .29271 L
.29964 .29294 L
F
.2994 .29362 m
.29915 .2943 L
.29929 .29392 L
.2995 .29331 L
.2994 .29362 L
F
.29915 .2943 m
.29891 .29498 L
.29907 .29453 L
.29929 .29392 L
.29915 .2943 L
F
.29891 .29498 m
.29866 .29566 L
.29885 .29513 L
.29907 .29453 L
.29891 .29498 L
F
.29866 .29566 m
.29842 .29634 L
.29864 .29574 L
.29885 .29513 L
.29866 .29566 L
F
.29842 .29634 m
.29817 .29703 L
.29842 .29634 L
.29864 .29574 L
.29842 .29634 L
F
.29817 .29703 m
.29793 .29771 L
.2982 .29695 L
.29842 .29634 L
.29817 .29703 L
F
.30037 .29089 m
.30015 .2915 L
.30018 .29142 L
.30037 .29089 L
.30037 .29089 L
F
.30015 .2915 m
.29994 .2921 L
.29999 .29194 L
.30018 .29142 L
.30015 .2915 L
F
.29994 .2921 m
.29972 .29271 L
.29981 .29247 L
.29999 .29194 L
.29994 .2921 L
F
.29972 .29271 m
.2995 .29331 L
.29962 .293 L
.29981 .29247 L
.29972 .29271 L
F
.2995 .29331 m
.29929 .29392 L
.29943 .29352 L
.29962 .293 L
.2995 .29331 L
F
.29929 .29392 m
.29907 .29453 L
.29924 .29405 L
.29943 .29352 L
.29929 .29392 L
F
.29907 .29453 m
.29885 .29513 L
.29905 .29458 L
.29924 .29405 L
.29907 .29453 L
F
.29885 .29513 m
.29864 .29574 L
.29886 .2951 L
.29905 .29458 L
.29885 .29513 L
F
.29864 .29574 m
.29842 .29634 L
.29867 .29563 L
.29886 .2951 L
.29864 .29574 L
F
.29842 .29634 m
.2982 .29695 L
.29849 .29616 L
.29867 .29563 L
.29842 .29634 L
F
.30037 .29089 m
.30018 .29142 L
.30021 .29133 L
.30037 .29089 L
.30037 .29089 L
F
.30018 .29142 m
.29999 .29194 L
.30005 .29178 L
.30021 .29133 L
.30018 .29142 L
F
.29999 .29194 m
.29981 .29247 L
.2999 .29222 L
.30005 .29178 L
.29999 .29194 L
F
.29981 .29247 m
.29962 .293 L
.29974 .29267 L
.2999 .29222 L
.29981 .29247 L
F
.29962 .293 m
.29943 .29352 L
.29958 .29311 L
.29974 .29267 L
.29962 .293 L
F
.29943 .29352 m
.29924 .29405 L
.29942 .29355 L
.29958 .29311 L
.29943 .29352 L
F
.29924 .29405 m
.29905 .29458 L
.29926 .294 L
.29942 .29355 L
.29924 .29405 L
F
.29905 .29458 m
.29886 .2951 L
.2991 .29444 L
.29926 .294 L
.29905 .29458 L
F
.29886 .2951 m
.29867 .29563 L
.29894 .29488 L
.2991 .29444 L
.29886 .2951 L
F
.29867 .29563 m
.29849 .29616 L
.29878 .29533 L
.29894 .29488 L
.29867 .29563 L
F
.30037 .29089 m
.30021 .29133 L
.30024 .29125 L
.30037 .29089 L
.30037 .29089 L
F
.30021 .29133 m
.30005 .29178 L
.30012 .29161 L
.30024 .29125 L
.30021 .29133 L
F
.30005 .29178 m
.2999 .29222 L
.29999 .29197 L
.30012 .29161 L
.30005 .29178 L
F
.2999 .29222 m
.29974 .29267 L
.29986 .29232 L
.29999 .29197 L
.2999 .29222 L
F
.29974 .29267 m
.29958 .29311 L
.29973 .29268 L
.29986 .29232 L
.29974 .29267 L
F
.29958 .29311 m
.29942 .29355 L
.2996 .29304 L
.29973 .29268 L
.29958 .29311 L
F
.29942 .29355 m
.29926 .294 L
.29947 .2934 L
.2996 .29304 L
.29942 .29355 L
F
.29926 .294 m
.2991 .29444 L
.29934 .29376 L
.29947 .2934 L
.29926 .294 L
F
.2991 .29444 m
.29894 .29488 L
.29922 .29412 L
.29934 .29376 L
.2991 .29444 L
F
.29894 .29488 m
.29878 .29533 L
.29909 .29447 L
.29922 .29412 L
.29894 .29488 L
F
.30037 .29089 m
.30024 .29125 L
.30028 .29116 L
.30037 .29089 L
.30037 .29089 L
F
.30024 .29125 m
.30012 .29161 L
.30018 .29143 L
.30028 .29116 L
.30024 .29125 L
F
.30012 .29161 m
.29999 .29197 L
.30008 .2917 L
.30018 .29143 L
.30012 .29161 L
F
.29999 .29197 m
.29986 .29232 L
.29998 .29197 L
.30008 .2917 L
.29999 .29197 L
F
.29986 .29232 m
.29973 .29268 L
.29989 .29224 L
.29998 .29197 L
.29986 .29232 L
F
.29973 .29268 m
.2996 .29304 L
.29979 .29251 L
.29989 .29224 L
.29973 .29268 L
F
.2996 .29304 m
.29947 .2934 L
.29969 .29279 L
.29979 .29251 L
.2996 .29304 L
F
.29947 .2934 m
.29934 .29376 L
.2996 .29306 L
.29969 .29279 L
.29947 .2934 L
F
.29934 .29376 m
.29922 .29412 L
.2995 .29333 L
.2996 .29306 L
.29934 .29376 L
F
.29922 .29412 m
.29909 .29447 L
.2994 .2936 L
.2995 .29333 L
.29922 .29412 L
F
.30037 .29089 m
.30028 .29116 L
.30031 .29107 L
.30037 .29089 L
.30037 .29089 L
F
.30028 .29116 m
.30018 .29143 L
.30024 .29125 L
.30031 .29107 L
.30028 .29116 L
F
.30018 .29143 m
.30008 .2917 L
.30018 .29143 L
.30024 .29125 L
.30018 .29143 L
F
.30008 .2917 m
.29998 .29197 L
.30011 .29162 L
.30018 .29143 L
.30008 .2917 L
F
.29998 .29197 m
.29989 .29224 L
.30005 .2918 L
.30011 .29162 L
.29998 .29197 L
F
.29989 .29224 m
.29979 .29251 L
.29998 .29198 L
.30005 .2918 L
.29989 .29224 L
F
.29979 .29251 m
.29969 .29279 L
.29992 .29216 L
.29998 .29198 L
.29979 .29251 L
F
.29969 .29279 m
.2996 .29306 L
.29985 .29234 L
.29992 .29216 L
.29969 .29279 L
F
.2996 .29306 m
.2995 .29333 L
.29979 .29252 L
.29985 .29234 L
.2996 .29306 L
F
.2995 .29333 m
.2994 .2936 L
.29972 .2927 L
.29979 .29252 L
.2995 .29333 L
F
.30037 .29089 m
.30031 .29107 L
.30034 .29098 L
.30037 .29089 L
.30037 .29089 L
F
.30031 .29107 m
.30024 .29125 L
.30031 .29107 L
.30034 .29098 L
.30031 .29107 L
F
.30024 .29125 m
.30018 .29143 L
.30027 .29116 L
.30031 .29107 L
.30024 .29125 L
F
.30018 .29143 m
.30011 .29162 L
.30024 .29125 L
.30027 .29116 L
.30018 .29143 L
F
.30011 .29162 m
.30005 .2918 L
.30021 .29135 L
.30024 .29125 L
.30011 .29162 L
F
.30005 .2918 m
.29998 .29198 L
.30018 .29144 L
.30021 .29135 L
.30005 .2918 L
F
.29998 .29198 m
.29992 .29216 L
.30014 .29153 L
.30018 .29144 L
.29998 .29198 L
F
.29992 .29216 m
.29985 .29234 L
.30011 .29162 L
.30014 .29153 L
.29992 .29216 L
F
.29985 .29234 m
.29979 .29252 L
.30008 .29171 L
.30011 .29162 L
.29985 .29234 L
F
.29979 .29252 m
.29972 .2927 L
.30005 .2918 L
.30008 .29171 L
.29979 .29252 L
F
.30037 .29089 m
.30034 .29098 L
.30037 .29089 L
.30037 .29089 L
.30037 .29089 L
F
.30034 .29098 m
.30031 .29107 L
.30037 .29089 L
.30037 .29089 L
.30034 .29098 L
F
.30031 .29107 m
.30027 .29116 L
.30037 .29089 L
.30037 .29089 L
.30031 .29107 L
F
.30027 .29116 m
.30024 .29125 L
.30037 .29089 L
.30037 .29089 L
.30027 .29116 L
F
.30024 .29125 m
.30021 .29135 L
.30037 .29089 L
.30037 .29089 L
.30024 .29125 L
F
.30021 .29135 m
.30018 .29144 L
.30037 .29089 L
.30037 .29089 L
.30021 .29135 L
F
.30018 .29144 m
.30014 .29153 L
.30037 .29089 L
.30037 .29089 L
.30018 .29144 L
F
.30014 .29153 m
.30011 .29162 L
.30037 .29089 L
.30037 .29089 L
.30014 .29153 L
F
.30011 .29162 m
.30008 .29171 L
.30037 .29089 L
.30037 .29089 L
.30011 .29162 L
F
.30008 .29171 m
.30005 .2918 L
.30037 .29089 L
.30037 .29089 L
.30008 .29171 L
F
.30037 .29089 m
.30037 .29089 L
.3004 .2908 L
.30037 .29089 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30044 .29071 L
.3004 .2908 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30047 .29062 L
.30044 .29071 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.3005 .29053 L
.30047 .29062 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30054 .29044 L
.3005 .29053 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30057 .29034 L
.30054 .29044 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.3006 .29025 L
.30057 .29034 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30063 .29016 L
.3006 .29025 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30067 .29007 L
.30063 .29016 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.3007 .28998 L
.30067 .29007 L
.30037 .29089 L
F
.30037 .29089 m
.3004 .2908 L
.30044 .29071 L
.30037 .29089 L
.30037 .29089 L
F
.3004 .2908 m
.30044 .29071 L
.3005 .29053 L
.30044 .29071 L
.3004 .2908 L
F
.30044 .29071 m
.30047 .29062 L
.30057 .29035 L
.3005 .29053 L
.30044 .29071 L
F
.30047 .29062 m
.3005 .29053 L
.30063 .29016 L
.30057 .29035 L
.30047 .29062 L
F
.3005 .29053 m
.30054 .29044 L
.3007 .28998 L
.30063 .29016 L
.3005 .29053 L
F
.30054 .29044 m
.30057 .29034 L
.30076 .2898 L
.3007 .28998 L
.30054 .29044 L
F
.30057 .29034 m
.3006 .29025 L
.30083 .28962 L
.30076 .2898 L
.30057 .29034 L
F
.3006 .29025 m
.30063 .29016 L
.30089 .28944 L
.30083 .28962 L
.3006 .29025 L
F
.30063 .29016 m
.30067 .29007 L
.30096 .28926 L
.30089 .28944 L
.30063 .29016 L
F
.30067 .29007 m
.3007 .28998 L
.30102 .28908 L
.30096 .28926 L
.30067 .29007 L
F
.30037 .29089 m
.30044 .29071 L
.30047 .29062 L
.30037 .29089 L
.30037 .29089 L
F
.30044 .29071 m
.3005 .29053 L
.30057 .29035 L
.30047 .29062 L
.30044 .29071 L
F
.3005 .29053 m
.30057 .29035 L
.30066 .29008 L
.30057 .29035 L
.3005 .29053 L
F
.30057 .29035 m
.30063 .29016 L
.30076 .28981 L
.30066 .29008 L
.30057 .29035 L
F
.30063 .29016 m
.3007 .28998 L
.30086 .28954 L
.30076 .28981 L
.30063 .29016 L
F
.3007 .28998 m
.30076 .2898 L
.30095 .28927 L
.30086 .28954 L
.3007 .28998 L
F
.30076 .2898 m
.30083 .28962 L
.30105 .28899 L
.30095 .28927 L
.30076 .2898 L
F
.30083 .28962 m
.30089 .28944 L
.30115 .28872 L
.30105 .28899 L
.30083 .28962 L
F
.30089 .28944 m
.30096 .28926 L
.30125 .28845 L
.30115 .28872 L
.30089 .28944 L
F
.30096 .28926 m
.30102 .28908 L
.30134 .28818 L
.30125 .28845 L
.30096 .28926 L
F
.30037 .29089 m
.30047 .29062 L
.3005 .29053 L
.30037 .29089 L
.30037 .29089 L
F
.30047 .29062 m
.30057 .29035 L
.30063 .29017 L
.3005 .29053 L
.30047 .29062 L
F
.30057 .29035 m
.30066 .29008 L
.30076 .28981 L
.30063 .29017 L
.30057 .29035 L
F
.30066 .29008 m
.30076 .28981 L
.30089 .28946 L
.30076 .28981 L
.30066 .29008 L
F
.30076 .28981 m
.30086 .28954 L
.30101 .2891 L
.30089 .28946 L
.30076 .28981 L
F
.30086 .28954 m
.30095 .28927 L
.30114 .28874 L
.30101 .2891 L
.30086 .28954 L
F
.30095 .28927 m
.30105 .28899 L
.30127 .28838 L
.30114 .28874 L
.30095 .28927 L
F
.30105 .28899 m
.30115 .28872 L
.3014 .28802 L
.30127 .28838 L
.30105 .28899 L
F
.30115 .28872 m
.30125 .28845 L
.30153 .28766 L
.3014 .28802 L
.30115 .28872 L
F
.30125 .28845 m
.30134 .28818 L
.30166 .28731 L
.30153 .28766 L
.30125 .28845 L
F
.30037 .29089 m
.3005 .29053 L
.30053 .29045 L
.30037 .29089 L
.30037 .29089 L
F
.3005 .29053 m
.30063 .29017 L
.30069 .29 L
.30053 .29045 L
.3005 .29053 L
F
.30063 .29017 m
.30076 .28981 L
.30085 .28956 L
.30069 .29 L
.30063 .29017 L
F
.30076 .28981 m
.30089 .28946 L
.30101 .28911 L
.30085 .28956 L
.30076 .28981 L
F
.30089 .28946 m
.30101 .2891 L
.30117 .28867 L
.30101 .28911 L
.30089 .28946 L
F
.30101 .2891 m
.30114 .28874 L
.30133 .28823 L
.30117 .28867 L
.30101 .2891 L
F
.30114 .28874 m
.30127 .28838 L
.30149 .28778 L
.30133 .28823 L
.30114 .28874 L
F
.30127 .28838 m
.3014 .28802 L
.30164 .28734 L
.30149 .28778 L
.30127 .28838 L
F
.3014 .28802 m
.30153 .28766 L
.3018 .2869 L
.30164 .28734 L
.3014 .28802 L
F
.30153 .28766 m
.30166 .28731 L
.30196 .28645 L
.3018 .2869 L
.30153 .28766 L
F
.30037 .29089 m
.30053 .29045 L
.30056 .29036 L
.30037 .29089 L
.30037 .29089 L
F
.30053 .29045 m
.30069 .29 L
.30075 .28984 L
.30056 .29036 L
.30053 .29045 L
F
.30069 .29 m
.30085 .28956 L
.30094 .28931 L
.30075 .28984 L
.30069 .29 L
F
.30085 .28956 m
.30101 .28911 L
.30113 .28878 L
.30094 .28931 L
.30085 .28956 L
F
.30101 .28911 m
.30117 .28867 L
.30132 .28826 L
.30113 .28878 L
.30101 .28911 L
F
.30117 .28867 m
.30133 .28823 L
.3015 .28773 L
.30132 .28826 L
.30117 .28867 L
F
.30133 .28823 m
.30149 .28778 L
.30169 .2872 L
.3015 .28773 L
.30133 .28823 L
F
.30149 .28778 m
.30164 .28734 L
.30188 .28668 L
.30169 .2872 L
.30149 .28778 L
F
.30164 .28734 m
.3018 .2869 L
.30207 .28615 L
.30188 .28668 L
.30164 .28734 L
F
.3018 .2869 m
.30196 .28645 L
.30226 .28562 L
.30207 .28615 L
.3018 .2869 L
F
.30037 .29089 m
.30056 .29036 L
.30059 .29028 L
.30037 .29089 L
.30037 .29089 L
F
.30056 .29036 m
.30075 .28984 L
.30081 .28968 L
.30059 .29028 L
.30056 .29036 L
F
.30075 .28984 m
.30094 .28931 L
.30102 .28907 L
.30081 .28968 L
.30075 .28984 L
F
.30094 .28931 m
.30113 .28878 L
.30124 .28847 L
.30102 .28907 L
.30094 .28931 L
F
.30113 .28878 m
.30132 .28826 L
.30146 .28786 L
.30124 .28847 L
.30113 .28878 L
F
.30132 .28826 m
.3015 .28773 L
.30167 .28725 L
.30146 .28786 L
.30132 .28826 L
F
.3015 .28773 m
.30169 .2872 L
.30189 .28665 L
.30167 .28725 L
.3015 .28773 L
F
.30169 .2872 m
.30188 .28668 L
.30211 .28604 L
.30189 .28665 L
.30169 .2872 L
F
.30188 .28668 m
.30207 .28615 L
.30233 .28544 L
.30211 .28604 L
.30188 .28668 L
F
.30207 .28615 m
.30226 .28562 L
.30254 .28483 L
.30233 .28544 L
.30207 .28615 L
F
.30037 .29089 m
.30059 .29028 L
.30062 .29021 L
.30037 .29089 L
.30037 .29089 L
F
.30059 .29028 m
.30081 .28968 L
.30086 .28953 L
.30062 .29021 L
.30059 .29028 L
F
.30081 .28968 m
.30102 .28907 L
.3011 .28885 L
.30086 .28953 L
.30081 .28968 L
F
.30102 .28907 m
.30124 .28847 L
.30135 .28816 L
.3011 .28885 L
.30102 .28907 L
F
.30124 .28847 m
.30146 .28786 L
.30159 .28748 L
.30135 .28816 L
.30124 .28847 L
F
.30146 .28786 m
.30167 .28725 L
.30184 .2868 L
.30159 .28748 L
.30146 .28786 L
F
.30167 .28725 m
.30189 .28665 L
.30208 .28612 L
.30184 .2868 L
.30167 .28725 L
F
.30189 .28665 m
.30211 .28604 L
.30233 .28544 L
.30208 .28612 L
.30189 .28665 L
F
.30211 .28604 m
.30233 .28544 L
.30257 .28475 L
.30233 .28544 L
.30211 .28604 L
F
.30233 .28544 m
.30254 .28483 L
.30281 .28407 L
.30257 .28475 L
.30233 .28544 L
F
.30037 .29089 m
.30062 .29021 L
.30064 .29014 L
.30037 .29089 L
.30037 .29089 L
F
.30062 .29021 m
.30086 .28953 L
.30091 .28938 L
.30064 .29014 L
.30062 .29021 L
F
.30086 .28953 m
.3011 .28885 L
.30118 .28863 L
.30091 .28938 L
.30086 .28953 L
F
.3011 .28885 m
.30135 .28816 L
.30145 .28788 L
.30118 .28863 L
.3011 .28885 L
F
.30135 .28816 m
.30159 .28748 L
.30172 .28712 L
.30145 .28788 L
.30135 .28816 L
F
.30159 .28748 m
.30184 .2868 L
.30199 .28637 L
.30172 .28712 L
.30159 .28748 L
F
.30184 .2868 m
.30208 .28612 L
.30226 .28562 L
.30199 .28637 L
.30184 .2868 L
F
.30208 .28612 m
.30233 .28544 L
.30253 .28486 L
.30226 .28562 L
.30208 .28612 L
F
.30233 .28544 m
.30257 .28475 L
.3028 .28411 L
.30253 .28486 L
.30233 .28544 L
F
.30257 .28475 m
.30281 .28407 L
.30307 .28336 L
.3028 .28411 L
.30257 .28475 L
F
.30037 .29089 m
.30064 .29014 L
.30067 .29007 L
.30037 .29089 L
.30037 .29089 L
F
.30064 .29014 m
.30091 .28938 L
.30096 .28925 L
.30067 .29007 L
.30064 .29014 L
F
.30091 .28938 m
.30118 .28863 L
.30125 .28843 L
.30096 .28925 L
.30091 .28938 L
F
.30118 .28863 m
.30145 .28788 L
.30155 .28761 L
.30125 .28843 L
.30118 .28863 L
F
.30145 .28788 m
.30172 .28712 L
.30184 .28679 L
.30155 .28761 L
.30145 .28788 L
F
.30172 .28712 m
.30199 .28637 L
.30214 .28597 L
.30184 .28679 L
.30172 .28712 L
F
.30199 .28637 m
.30226 .28562 L
.30243 .28515 L
.30214 .28597 L
.30199 .28637 L
F
.30226 .28562 m
.30253 .28486 L
.30272 .28433 L
.30243 .28515 L
.30226 .28562 L
F
.30253 .28486 m
.3028 .28411 L
.30302 .28351 L
.30272 .28433 L
.30253 .28486 L
F
.3028 .28411 m
.30307 .28336 L
.30331 .28269 L
.30302 .28351 L
.3028 .28411 L
F
.30037 .29089 m
.30067 .29007 L
.30069 .29001 L
.30037 .29089 L
.30037 .29089 L
F
.30067 .29007 m
.30096 .28925 L
.301 .28913 L
.30069 .29001 L
.30067 .29007 L
F
.30096 .28925 m
.30125 .28843 L
.30132 .28824 L
.301 .28913 L
.30096 .28925 L
F
.30125 .28843 m
.30155 .28761 L
.30164 .28736 L
.30132 .28824 L
.30125 .28843 L
F
.30155 .28761 m
.30184 .28679 L
.30195 .28648 L
.30164 .28736 L
.30155 .28761 L
F
.30184 .28679 m
.30214 .28597 L
.30227 .2856 L
.30195 .28648 L
.30184 .28679 L
F
.30214 .28597 m
.30243 .28515 L
.30258 .28472 L
.30227 .2856 L
.30214 .28597 L
F
.30243 .28515 m
.30272 .28433 L
.3029 .28384 L
.30258 .28472 L
.30243 .28515 L
F
.30272 .28433 m
.30302 .28351 L
.30322 .28295 L
.3029 .28384 L
.30272 .28433 L
F
.30302 .28351 m
.30331 .28269 L
.30353 .28207 L
.30322 .28295 L
.30302 .28351 L
F
.30037 .29089 m
.30069 .29001 L
.30071 .28995 L
.30037 .29089 L
.30037 .29089 L
F
.30069 .29001 m
.301 .28913 L
.30104 .28901 L
.30071 .28995 L
.30069 .29001 L
F
.301 .28913 m
.30132 .28824 L
.30138 .28808 L
.30104 .28901 L
.301 .28913 L
F
.30132 .28824 m
.30164 .28736 L
.30172 .28714 L
.30138 .28808 L
.30132 .28824 L
F
.30164 .28736 m
.30195 .28648 L
.30205 .2862 L
.30172 .28714 L
.30164 .28736 L
F
.30195 .28648 m
.30227 .2856 L
.30239 .28526 L
.30205 .2862 L
.30195 .28648 L
F
.30227 .2856 m
.30258 .28472 L
.30273 .28432 L
.30239 .28526 L
.30227 .2856 L
F
.30258 .28472 m
.3029 .28384 L
.30306 .28338 L
.30273 .28432 L
.30258 .28472 L
F
.3029 .28384 m
.30322 .28295 L
.3034 .28245 L
.30306 .28338 L
.3029 .28384 L
F
.30322 .28295 m
.30353 .28207 L
.30373 .28151 L
.3034 .28245 L
.30322 .28295 L
F
.30037 .29089 m
.30071 .28995 L
.30073 .2899 L
.30037 .29089 L
.30037 .29089 L
F
.30071 .28995 m
.30104 .28901 L
.30108 .28891 L
.30073 .2899 L
.30071 .28995 L
F
.30104 .28901 m
.30138 .28808 L
.30144 .28792 L
.30108 .28891 L
.30104 .28901 L
F
.30138 .28808 m
.30172 .28714 L
.30179 .28693 L
.30144 .28792 L
.30138 .28808 L
F
.30172 .28714 m
.30205 .2862 L
.30214 .28595 L
.30179 .28693 L
.30172 .28714 L
F
.30205 .2862 m
.30239 .28526 L
.3025 .28496 L
.30214 .28595 L
.30205 .2862 L
F
.30239 .28526 m
.30273 .28432 L
.30285 .28397 L
.3025 .28496 L
.30239 .28526 L
F
.30273 .28432 m
.30306 .28338 L
.30321 .28298 L
.30285 .28397 L
.30273 .28432 L
F
.30306 .28338 m
.3034 .28245 L
.30356 .28199 L
.30321 .28298 L
.30306 .28338 L
F
.3034 .28245 m
.30373 .28151 L
.30392 .281 L
.30356 .28199 L
.3034 .28245 L
F
.30037 .29089 m
.30073 .2899 L
.30074 .28986 L
.30037 .29089 L
.30037 .29089 L
F
.30073 .2899 m
.30108 .28891 L
.30111 .28882 L
.30074 .28986 L
.30073 .2899 L
F
.30108 .28891 m
.30144 .28792 L
.30148 .28779 L
.30111 .28882 L
.30108 .28891 L
F
.30144 .28792 m
.30179 .28693 L
.30185 .28676 L
.30148 .28779 L
.30144 .28792 L
F
.30179 .28693 m
.30214 .28595 L
.30222 .28572 L
.30185 .28676 L
.30179 .28693 L
F
.30214 .28595 m
.3025 .28496 L
.30259 .28469 L
.30222 .28572 L
.30214 .28595 L
F
.3025 .28496 m
.30285 .28397 L
.30296 .28366 L
.30259 .28469 L
.3025 .28496 L
F
.30285 .28397 m
.30321 .28298 L
.30333 .28262 L
.30296 .28366 L
.30285 .28397 L
F
.30321 .28298 m
.30356 .28199 L
.3037 .28159 L
.30333 .28262 L
.30321 .28298 L
F
.30356 .28199 m
.30392 .281 L
.30407 .28056 L
.3037 .28159 L
.30356 .28199 L
F
.30037 .29089 m
.30074 .28986 L
.30076 .28982 L
.30037 .29089 L
.30037 .29089 L
F
.30074 .28986 m
.30111 .28882 L
.30114 .28875 L
.30076 .28982 L
.30074 .28986 L
F
.30111 .28882 m
.30148 .28779 L
.30152 .28768 L
.30114 .28875 L
.30111 .28882 L
F
.30148 .28779 m
.30185 .28676 L
.30191 .2866 L
.30152 .28768 L
.30148 .28779 L
F
.30185 .28676 m
.30222 .28572 L
.30229 .28553 L
.30191 .2866 L
.30185 .28676 L
F
.30222 .28572 m
.30259 .28469 L
.30268 .28446 L
.30229 .28553 L
.30222 .28572 L
F
.30259 .28469 m
.30296 .28366 L
.30306 .28339 L
.30268 .28446 L
.30259 .28469 L
F
.30296 .28366 m
.30333 .28262 L
.30344 .28232 L
.30306 .28339 L
.30296 .28366 L
F
.30333 .28262 m
.3037 .28159 L
.30383 .28125 L
.30344 .28232 L
.30333 .28262 L
F
.3037 .28159 m
.30407 .28056 L
.30421 .28018 L
.30383 .28125 L
.3037 .28159 L
F
.30037 .29089 m
.30076 .28982 L
.30077 .28979 L
.30037 .29089 L
.30037 .29089 L
F
.30076 .28982 m
.30114 .28875 L
.30116 .28868 L
.30077 .28979 L
.30076 .28982 L
F
.30114 .28875 m
.30152 .28768 L
.30156 .28758 L
.30116 .28868 L
.30114 .28875 L
F
.30152 .28768 m
.30191 .2866 L
.30195 .28648 L
.30156 .28758 L
.30152 .28768 L
F
.30191 .2866 m
.30229 .28553 L
.30235 .28538 L
.30195 .28648 L
.30191 .2866 L
F
.30229 .28553 m
.30268 .28446 L
.30274 .28427 L
.30235 .28538 L
.30229 .28553 L
F
.30268 .28446 m
.30306 .28339 L
.30314 .28317 L
.30274 .28427 L
.30268 .28446 L
F
.30306 .28339 m
.30344 .28232 L
.30353 .28207 L
.30314 .28317 L
.30306 .28339 L
F
.30344 .28232 m
.30383 .28125 L
.30393 .28096 L
.30353 .28207 L
.30344 .28232 L
F
.30383 .28125 m
.30421 .28018 L
.30432 .27986 L
.30393 .28096 L
.30383 .28125 L
F
.30037 .29089 m
.30077 .28979 L
.30078 .28976 L
.30037 .29089 L
.30037 .29089 L
F
.30077 .28979 m
.30116 .28868 L
.30118 .28863 L
.30078 .28976 L
.30077 .28979 L
F
.30116 .28868 m
.30156 .28758 L
.30158 .28751 L
.30118 .28863 L
.30116 .28868 L
F
.30156 .28758 m
.30195 .28648 L
.30199 .28638 L
.30158 .28751 L
.30156 .28758 L
F
.30195 .28648 m
.30235 .28538 L
.30239 .28525 L
.30199 .28638 L
.30195 .28648 L
F
.30235 .28538 m
.30274 .28427 L
.3028 .28412 L
.30239 .28525 L
.30235 .28538 L
F
.30274 .28427 m
.30314 .28317 L
.3032 .283 L
.3028 .28412 L
.30274 .28427 L
F
.30314 .28317 m
.30353 .28207 L
.3036 .28187 L
.3032 .283 L
.30314 .28317 L
F
.30353 .28207 m
.30393 .28096 L
.30401 .28074 L
.3036 .28187 L
.30353 .28207 L
F
.30393 .28096 m
.30432 .27986 L
.30441 .27961 L
.30401 .28074 L
.30393 .28096 L
F
.30037 .29089 m
.30078 .28976 L
.30078 .28974 L
.30037 .29089 L
.30037 .29089 L
F
.30078 .28976 m
.30118 .28863 L
.30119 .2886 L
.30078 .28974 L
.30078 .28976 L
F
.30118 .28863 m
.30158 .28751 L
.3016 .28745 L
.30119 .2886 L
.30118 .28863 L
F
.30158 .28751 m
.30199 .28638 L
.30201 .28631 L
.3016 .28745 L
.30158 .28751 L
F
.30199 .28638 m
.30239 .28525 L
.30242 .28516 L
.30201 .28631 L
.30199 .28638 L
F
.30239 .28525 m
.3028 .28412 L
.30283 .28402 L
.30242 .28516 L
.30239 .28525 L
F
.3028 .28412 m
.3032 .283 L
.30325 .28287 L
.30283 .28402 L
.3028 .28412 L
F
.3032 .283 m
.3036 .28187 L
.30366 .28173 L
.30325 .28287 L
.3032 .283 L
F
.3036 .28187 m
.30401 .28074 L
.30407 .28058 L
.30366 .28173 L
.3036 .28187 L
F
.30401 .28074 m
.30441 .27961 L
.30448 .27944 L
.30407 .28058 L
.30401 .28074 L
F
.30037 .29089 m
.30078 .28974 L
.30079 .28973 L
.30037 .29089 L
.30037 .29089 L
F
.30078 .28974 m
.30119 .2886 L
.3012 .28858 L
.30079 .28973 L
.30078 .28974 L
F
.30119 .2886 m
.3016 .28745 L
.30161 .28742 L
.3012 .28858 L
.30119 .2886 L
F
.3016 .28745 m
.30201 .28631 L
.30203 .28627 L
.30161 .28742 L
.3016 .28745 L
F
.30201 .28631 m
.30242 .28516 L
.30244 .28511 L
.30203 .28627 L
.30201 .28631 L
F
.30242 .28516 m
.30283 .28402 L
.30286 .28395 L
.30244 .28511 L
.30242 .28516 L
F
.30283 .28402 m
.30325 .28287 L
.30327 .2828 L
.30286 .28395 L
.30283 .28402 L
F
.30325 .28287 m
.30366 .28173 L
.30369 .28164 L
.30327 .2828 L
.30325 .28287 L
F
.30366 .28173 m
.30407 .28058 L
.3041 .28048 L
.30369 .28164 L
.30366 .28173 L
F
.30407 .28058 m
.30448 .27944 L
.30451 .27933 L
.3041 .28048 L
.30407 .28058 L
F
.30037 .29089 m
.30079 .28973 L
.30079 .28973 L
.30037 .29089 L
.30037 .29089 L
F
.30079 .28973 m
.3012 .28858 L
.3012 .28857 L
.30079 .28973 L
.30079 .28973 L
F
.3012 .28858 m
.30161 .28742 L
.30162 .28741 L
.3012 .28857 L
.3012 .28858 L
F
.30161 .28742 m
.30203 .28627 L
.30203 .28625 L
.30162 .28741 L
.30161 .28742 L
F
.30203 .28627 m
.30244 .28511 L
.30245 .28509 L
.30203 .28625 L
.30203 .28627 L
F
.30244 .28511 m
.30286 .28395 L
.30287 .28393 L
.30245 .28509 L
.30244 .28511 L
F
.30286 .28395 m
.30327 .2828 L
.30328 .28277 L
.30287 .28393 L
.30286 .28395 L
F
.30327 .2828 m
.30369 .28164 L
.3037 .28161 L
.30328 .28277 L
.30327 .2828 L
F
.30369 .28164 m
.3041 .28048 L
.30411 .28045 L
.3037 .28161 L
.30369 .28164 L
F
.3041 .28048 m
.30451 .27933 L
.30453 .27929 L
.30411 .28045 L
.3041 .28048 L
F
.30037 .29089 m
.30079 .28973 L
.30079 .28973 L
.30037 .29089 L
.30037 .29089 L
F
.30079 .28973 m
.3012 .28857 L
.3012 .28858 L
.30079 .28973 L
.30079 .28973 L
F
.3012 .28857 m
.30162 .28741 L
.30161 .28742 L
.3012 .28858 L
.3012 .28857 L
F
.30162 .28741 m
.30203 .28625 L
.30203 .28627 L
.30161 .28742 L
.30162 .28741 L
F
.30203 .28625 m
.30245 .28509 L
.30244 .28511 L
.30203 .28627 L
.30203 .28625 L
F
.30245 .28509 m
.30287 .28393 L
.30286 .28395 L
.30244 .28511 L
.30245 .28509 L
F
.30287 .28393 m
.30328 .28277 L
.30327 .2828 L
.30286 .28395 L
.30287 .28393 L
F
.30328 .28277 m
.3037 .28161 L
.30369 .28164 L
.30327 .2828 L
.30328 .28277 L
F
.3037 .28161 m
.30411 .28045 L
.3041 .28048 L
.30369 .28164 L
.3037 .28161 L
F
.30411 .28045 m
.30453 .27929 L
.30451 .27933 L
.3041 .28048 L
.30411 .28045 L
F
.30037 .29089 m
.30079 .28973 L
.30078 .28974 L
.30037 .29089 L
.30037 .29089 L
F
.30079 .28973 m
.3012 .28858 L
.30119 .2886 L
.30078 .28974 L
.30079 .28973 L
F
.3012 .28858 m
.30161 .28742 L
.3016 .28745 L
.30119 .2886 L
.3012 .28858 L
F
.30161 .28742 m
.30203 .28627 L
.30201 .28631 L
.3016 .28745 L
.30161 .28742 L
F
.30203 .28627 m
.30244 .28511 L
.30242 .28516 L
.30201 .28631 L
.30203 .28627 L
F
.30244 .28511 m
.30286 .28395 L
.30283 .28402 L
.30242 .28516 L
.30244 .28511 L
F
.30286 .28395 m
.30327 .2828 L
.30325 .28287 L
.30283 .28402 L
.30286 .28395 L
F
.30327 .2828 m
.30369 .28164 L
.30366 .28173 L
.30325 .28287 L
.30327 .2828 L
F
.30369 .28164 m
.3041 .28048 L
.30407 .28058 L
.30366 .28173 L
.30369 .28164 L
F
.3041 .28048 m
.30451 .27933 L
.30448 .27944 L
.30407 .28058 L
.3041 .28048 L
F
.30037 .29089 m
.30078 .28974 L
.30078 .28976 L
.30037 .29089 L
.30037 .29089 L
F
.30078 .28974 m
.30119 .2886 L
.30118 .28863 L
.30078 .28976 L
.30078 .28974 L
F
.30119 .2886 m
.3016 .28745 L
.30158 .28751 L
.30118 .28863 L
.30119 .2886 L
F
.3016 .28745 m
.30201 .28631 L
.30199 .28638 L
.30158 .28751 L
.3016 .28745 L
F
.30201 .28631 m
.30242 .28516 L
.30239 .28525 L
.30199 .28638 L
.30201 .28631 L
F
.30242 .28516 m
.30283 .28402 L
.3028 .28412 L
.30239 .28525 L
.30242 .28516 L
F
.30283 .28402 m
.30325 .28287 L
.3032 .283 L
.3028 .28412 L
.30283 .28402 L
F
.30325 .28287 m
.30366 .28173 L
.3036 .28187 L
.3032 .283 L
.30325 .28287 L
F
.30366 .28173 m
.30407 .28058 L
.30401 .28074 L
.3036 .28187 L
.30366 .28173 L
F
.30407 .28058 m
.30448 .27944 L
.30441 .27961 L
.30401 .28074 L
.30407 .28058 L
F
.30037 .29089 m
.30078 .28976 L
.30077 .28979 L
.30037 .29089 L
.30037 .29089 L
F
.30078 .28976 m
.30118 .28863 L
.30116 .28868 L
.30077 .28979 L
.30078 .28976 L
F
.30118 .28863 m
.30158 .28751 L
.30156 .28758 L
.30116 .28868 L
.30118 .28863 L
F
.30158 .28751 m
.30199 .28638 L
.30195 .28648 L
.30156 .28758 L
.30158 .28751 L
F
.30199 .28638 m
.30239 .28525 L
.30235 .28538 L
.30195 .28648 L
.30199 .28638 L
F
.30239 .28525 m
.3028 .28412 L
.30274 .28427 L
.30235 .28538 L
.30239 .28525 L
F
.3028 .28412 m
.3032 .283 L
.30314 .28317 L
.30274 .28427 L
.3028 .28412 L
F
.3032 .283 m
.3036 .28187 L
.30353 .28207 L
.30314 .28317 L
.3032 .283 L
F
.3036 .28187 m
.30401 .28074 L
.30393 .28096 L
.30353 .28207 L
.3036 .28187 L
F
.30401 .28074 m
.30441 .27961 L
.30432 .27986 L
.30393 .28096 L
.30401 .28074 L
F
.30037 .29089 m
.30077 .28979 L
.30076 .28982 L
.30037 .29089 L
.30037 .29089 L
F
.30077 .28979 m
.30116 .28868 L
.30114 .28875 L
.30076 .28982 L
.30077 .28979 L
F
.30116 .28868 m
.30156 .28758 L
.30152 .28768 L
.30114 .28875 L
.30116 .28868 L
F
.30156 .28758 m
.30195 .28648 L
.30191 .2866 L
.30152 .28768 L
.30156 .28758 L
F
.30195 .28648 m
.30235 .28538 L
.30229 .28553 L
.30191 .2866 L
.30195 .28648 L
F
.30235 .28538 m
.30274 .28427 L
.30268 .28446 L
.30229 .28553 L
.30235 .28538 L
F
.30274 .28427 m
.30314 .28317 L
.30306 .28339 L
.30268 .28446 L
.30274 .28427 L
F
.30314 .28317 m
.30353 .28207 L
.30344 .28232 L
.30306 .28339 L
.30314 .28317 L
F
.30353 .28207 m
.30393 .28096 L
.30383 .28125 L
.30344 .28232 L
.30353 .28207 L
F
.30393 .28096 m
.30432 .27986 L
.30421 .28018 L
.30383 .28125 L
.30393 .28096 L
F
.30037 .29089 m
.30076 .28982 L
.30074 .28986 L
.30037 .29089 L
.30037 .29089 L
F
.30076 .28982 m
.30114 .28875 L
.30111 .28882 L
.30074 .28986 L
.30076 .28982 L
F
.30114 .28875 m
.30152 .28768 L
.30148 .28779 L
.30111 .28882 L
.30114 .28875 L
F
.30152 .28768 m
.30191 .2866 L
.30185 .28676 L
.30148 .28779 L
.30152 .28768 L
F
.30191 .2866 m
.30229 .28553 L
.30222 .28572 L
.30185 .28676 L
.30191 .2866 L
F
.30229 .28553 m
.30268 .28446 L
.30259 .28469 L
.30222 .28572 L
.30229 .28553 L
F
.30268 .28446 m
.30306 .28339 L
.30296 .28366 L
.30259 .28469 L
.30268 .28446 L
F
.30306 .28339 m
.30344 .28232 L
.30333 .28262 L
.30296 .28366 L
.30306 .28339 L
F
.30344 .28232 m
.30383 .28125 L
.3037 .28159 L
.30333 .28262 L
.30344 .28232 L
F
.30383 .28125 m
.30421 .28018 L
.30407 .28056 L
.3037 .28159 L
.30383 .28125 L
F
.30037 .29089 m
.30074 .28986 L
.30073 .2899 L
.30037 .29089 L
.30037 .29089 L
F
.30074 .28986 m
.30111 .28882 L
.30108 .28891 L
.30073 .2899 L
.30074 .28986 L
F
.30111 .28882 m
.30148 .28779 L
.30144 .28792 L
.30108 .28891 L
.30111 .28882 L
F
.30148 .28779 m
.30185 .28676 L
.30179 .28693 L
.30144 .28792 L
.30148 .28779 L
F
.30185 .28676 m
.30222 .28572 L
.30214 .28595 L
.30179 .28693 L
.30185 .28676 L
F
.30222 .28572 m
.30259 .28469 L
.3025 .28496 L
.30214 .28595 L
.30222 .28572 L
F
.30259 .28469 m
.30296 .28366 L
.30285 .28397 L
.3025 .28496 L
.30259 .28469 L
F
.30296 .28366 m
.30333 .28262 L
.30321 .28298 L
.30285 .28397 L
.30296 .28366 L
F
.30333 .28262 m
.3037 .28159 L
.30356 .28199 L
.30321 .28298 L
.30333 .28262 L
F
.3037 .28159 m
.30407 .28056 L
.30392 .281 L
.30356 .28199 L
.3037 .28159 L
F
.30037 .29089 m
.30073 .2899 L
.30071 .28995 L
.30037 .29089 L
.30037 .29089 L
F
.30073 .2899 m
.30108 .28891 L
.30104 .28901 L
.30071 .28995 L
.30073 .2899 L
F
.30108 .28891 m
.30144 .28792 L
.30138 .28808 L
.30104 .28901 L
.30108 .28891 L
F
.30144 .28792 m
.30179 .28693 L
.30172 .28714 L
.30138 .28808 L
.30144 .28792 L
F
.30179 .28693 m
.30214 .28595 L
.30205 .2862 L
.30172 .28714 L
.30179 .28693 L
F
.30214 .28595 m
.3025 .28496 L
.30239 .28526 L
.30205 .2862 L
.30214 .28595 L
F
.3025 .28496 m
.30285 .28397 L
.30273 .28432 L
.30239 .28526 L
.3025 .28496 L
F
.30285 .28397 m
.30321 .28298 L
.30306 .28338 L
.30273 .28432 L
.30285 .28397 L
F
.30321 .28298 m
.30356 .28199 L
.3034 .28245 L
.30306 .28338 L
.30321 .28298 L
F
.30356 .28199 m
.30392 .281 L
.30373 .28151 L
.3034 .28245 L
.30356 .28199 L
F
.30037 .29089 m
.30071 .28995 L
.30069 .29001 L
.30037 .29089 L
.30037 .29089 L
F
.30071 .28995 m
.30104 .28901 L
.301 .28913 L
.30069 .29001 L
.30071 .28995 L
F
.30104 .28901 m
.30138 .28808 L
.30132 .28824 L
.301 .28913 L
.30104 .28901 L
F
.30138 .28808 m
.30172 .28714 L
.30164 .28736 L
.30132 .28824 L
.30138 .28808 L
F
.30172 .28714 m
.30205 .2862 L
.30195 .28648 L
.30164 .28736 L
.30172 .28714 L
F
.30205 .2862 m
.30239 .28526 L
.30227 .2856 L
.30195 .28648 L
.30205 .2862 L
F
.30239 .28526 m
.30273 .28432 L
.30258 .28472 L
.30227 .2856 L
.30239 .28526 L
F
.30273 .28432 m
.30306 .28338 L
.3029 .28384 L
.30258 .28472 L
.30273 .28432 L
F
.30306 .28338 m
.3034 .28245 L
.30322 .28295 L
.3029 .28384 L
.30306 .28338 L
F
.3034 .28245 m
.30373 .28151 L
.30353 .28207 L
.30322 .28295 L
.3034 .28245 L
F
.30037 .29089 m
.30069 .29001 L
.30067 .29007 L
.30037 .29089 L
.30037 .29089 L
F
.30069 .29001 m
.301 .28913 L
.30096 .28925 L
.30067 .29007 L
.30069 .29001 L
F
.301 .28913 m
.30132 .28824 L
.30125 .28843 L
.30096 .28925 L
.301 .28913 L
F
.30132 .28824 m
.30164 .28736 L
.30155 .28761 L
.30125 .28843 L
.30132 .28824 L
F
.30164 .28736 m
.30195 .28648 L
.30184 .28679 L
.30155 .28761 L
.30164 .28736 L
F
.30195 .28648 m
.30227 .2856 L
.30214 .28597 L
.30184 .28679 L
.30195 .28648 L
F
.30227 .2856 m
.30258 .28472 L
.30243 .28515 L
.30214 .28597 L
.30227 .2856 L
F
.30258 .28472 m
.3029 .28384 L
.30272 .28433 L
.30243 .28515 L
.30258 .28472 L
F
.3029 .28384 m
.30322 .28295 L
.30302 .28351 L
.30272 .28433 L
.3029 .28384 L
F
.30322 .28295 m
.30353 .28207 L
.30331 .28269 L
.30302 .28351 L
.30322 .28295 L
F
.30037 .29089 m
.30067 .29007 L
.30064 .29014 L
.30037 .29089 L
.30037 .29089 L
F
.30067 .29007 m
.30096 .28925 L
.30091 .28938 L
.30064 .29014 L
.30067 .29007 L
F
.30096 .28925 m
.30125 .28843 L
.30118 .28863 L
.30091 .28938 L
.30096 .28925 L
F
.30125 .28843 m
.30155 .28761 L
.30145 .28788 L
.30118 .28863 L
.30125 .28843 L
F
.30155 .28761 m
.30184 .28679 L
.30172 .28712 L
.30145 .28788 L
.30155 .28761 L
F
.30184 .28679 m
.30214 .28597 L
.30199 .28637 L
.30172 .28712 L
.30184 .28679 L
F
.30214 .28597 m
.30243 .28515 L
.30226 .28562 L
.30199 .28637 L
.30214 .28597 L
F
.30243 .28515 m
.30272 .28433 L
.30253 .28486 L
.30226 .28562 L
.30243 .28515 L
F
.30272 .28433 m
.30302 .28351 L
.3028 .28411 L
.30253 .28486 L
.30272 .28433 L
F
.30302 .28351 m
.30331 .28269 L
.30307 .28336 L
.3028 .28411 L
.30302 .28351 L
F
.30037 .29089 m
.30064 .29014 L
.30062 .29021 L
.30037 .29089 L
.30037 .29089 L
F
.30064 .29014 m
.30091 .28938 L
.30086 .28953 L
.30062 .29021 L
.30064 .29014 L
F
.30091 .28938 m
.30118 .28863 L
.3011 .28885 L
.30086 .28953 L
.30091 .28938 L
F
.30118 .28863 m
.30145 .28788 L
.30135 .28816 L
.3011 .28885 L
.30118 .28863 L
F
.30145 .28788 m
.30172 .28712 L
.30159 .28748 L
.30135 .28816 L
.30145 .28788 L
F
.30172 .28712 m
.30199 .28637 L
.30184 .2868 L
.30159 .28748 L
.30172 .28712 L
F
.30199 .28637 m
.30226 .28562 L
.30208 .28612 L
.30184 .2868 L
.30199 .28637 L
F
.30226 .28562 m
.30253 .28486 L
.30233 .28544 L
.30208 .28612 L
.30226 .28562 L
F
.30253 .28486 m
.3028 .28411 L
.30257 .28475 L
.30233 .28544 L
.30253 .28486 L
F
.3028 .28411 m
.30307 .28336 L
.30281 .28407 L
.30257 .28475 L
.3028 .28411 L
F
.30037 .29089 m
.30062 .29021 L
.30059 .29028 L
.30037 .29089 L
.30037 .29089 L
F
.30062 .29021 m
.30086 .28953 L
.30081 .28968 L
.30059 .29028 L
.30062 .29021 L
F
.30086 .28953 m
.3011 .28885 L
.30102 .28907 L
.30081 .28968 L
.30086 .28953 L
F
.3011 .28885 m
.30135 .28816 L
.30124 .28847 L
.30102 .28907 L
.3011 .28885 L
F
.30135 .28816 m
.30159 .28748 L
.30146 .28786 L
.30124 .28847 L
.30135 .28816 L
F
.30159 .28748 m
.30184 .2868 L
.30167 .28725 L
.30146 .28786 L
.30159 .28748 L
F
.30184 .2868 m
.30208 .28612 L
.30189 .28665 L
.30167 .28725 L
.30184 .2868 L
F
.30208 .28612 m
.30233 .28544 L
.30211 .28604 L
.30189 .28665 L
.30208 .28612 L
F
.30233 .28544 m
.30257 .28475 L
.30233 .28544 L
.30211 .28604 L
.30233 .28544 L
F
.30257 .28475 m
.30281 .28407 L
.30254 .28483 L
.30233 .28544 L
.30257 .28475 L
F
.30037 .29089 m
.30059 .29028 L
.30056 .29036 L
.30037 .29089 L
.30037 .29089 L
F
.30059 .29028 m
.30081 .28968 L
.30075 .28984 L
.30056 .29036 L
.30059 .29028 L
F
.30081 .28968 m
.30102 .28907 L
.30094 .28931 L
.30075 .28984 L
.30081 .28968 L
F
.30102 .28907 m
.30124 .28847 L
.30113 .28878 L
.30094 .28931 L
.30102 .28907 L
F
.30124 .28847 m
.30146 .28786 L
.30132 .28826 L
.30113 .28878 L
.30124 .28847 L
F
.30146 .28786 m
.30167 .28725 L
.3015 .28773 L
.30132 .28826 L
.30146 .28786 L
F
.30167 .28725 m
.30189 .28665 L
.30169 .2872 L
.3015 .28773 L
.30167 .28725 L
F
.30189 .28665 m
.30211 .28604 L
.30188 .28668 L
.30169 .2872 L
.30189 .28665 L
F
.30211 .28604 m
.30233 .28544 L
.30207 .28615 L
.30188 .28668 L
.30211 .28604 L
F
.30233 .28544 m
.30254 .28483 L
.30226 .28562 L
.30207 .28615 L
.30233 .28544 L
F
.30037 .29089 m
.30056 .29036 L
.30053 .29045 L
.30037 .29089 L
.30037 .29089 L
F
.30056 .29036 m
.30075 .28984 L
.30069 .29 L
.30053 .29045 L
.30056 .29036 L
F
.30075 .28984 m
.30094 .28931 L
.30085 .28956 L
.30069 .29 L
.30075 .28984 L
F
.30094 .28931 m
.30113 .28878 L
.30101 .28911 L
.30085 .28956 L
.30094 .28931 L
F
.30113 .28878 m
.30132 .28826 L
.30117 .28867 L
.30101 .28911 L
.30113 .28878 L
F
.30132 .28826 m
.3015 .28773 L
.30133 .28823 L
.30117 .28867 L
.30132 .28826 L
F
.3015 .28773 m
.30169 .2872 L
.30149 .28778 L
.30133 .28823 L
.3015 .28773 L
F
.30169 .2872 m
.30188 .28668 L
.30164 .28734 L
.30149 .28778 L
.30169 .2872 L
F
.30188 .28668 m
.30207 .28615 L
.3018 .2869 L
.30164 .28734 L
.30188 .28668 L
F
.30207 .28615 m
.30226 .28562 L
.30196 .28645 L
.3018 .2869 L
.30207 .28615 L
F
.30037 .29089 m
.30053 .29045 L
.3005 .29053 L
.30037 .29089 L
.30037 .29089 L
F
.30053 .29045 m
.30069 .29 L
.30063 .29017 L
.3005 .29053 L
.30053 .29045 L
F
.30069 .29 m
.30085 .28956 L
.30076 .28981 L
.30063 .29017 L
.30069 .29 L
F
.30085 .28956 m
.30101 .28911 L
.30089 .28946 L
.30076 .28981 L
.30085 .28956 L
F
.30101 .28911 m
.30117 .28867 L
.30101 .2891 L
.30089 .28946 L
.30101 .28911 L
F
.30117 .28867 m
.30133 .28823 L
.30114 .28874 L
.30101 .2891 L
.30117 .28867 L
F
.30133 .28823 m
.30149 .28778 L
.30127 .28838 L
.30114 .28874 L
.30133 .28823 L
F
.30149 .28778 m
.30164 .28734 L
.3014 .28802 L
.30127 .28838 L
.30149 .28778 L
F
.30164 .28734 m
.3018 .2869 L
.30153 .28766 L
.3014 .28802 L
.30164 .28734 L
F
.3018 .2869 m
.30196 .28645 L
.30166 .28731 L
.30153 .28766 L
.3018 .2869 L
F
.30037 .29089 m
.3005 .29053 L
.30047 .29062 L
.30037 .29089 L
.30037 .29089 L
F
.3005 .29053 m
.30063 .29017 L
.30057 .29035 L
.30047 .29062 L
.3005 .29053 L
F
.30063 .29017 m
.30076 .28981 L
.30066 .29008 L
.30057 .29035 L
.30063 .29017 L
F
.30076 .28981 m
.30089 .28946 L
.30076 .28981 L
.30066 .29008 L
.30076 .28981 L
F
.30089 .28946 m
.30101 .2891 L
.30086 .28954 L
.30076 .28981 L
.30089 .28946 L
F
.30101 .2891 m
.30114 .28874 L
.30095 .28927 L
.30086 .28954 L
.30101 .2891 L
F
.30114 .28874 m
.30127 .28838 L
.30105 .28899 L
.30095 .28927 L
.30114 .28874 L
F
.30127 .28838 m
.3014 .28802 L
.30115 .28872 L
.30105 .28899 L
.30127 .28838 L
F
.3014 .28802 m
.30153 .28766 L
.30125 .28845 L
.30115 .28872 L
.3014 .28802 L
F
.30153 .28766 m
.30166 .28731 L
.30134 .28818 L
.30125 .28845 L
.30153 .28766 L
F
.30037 .29089 m
.30047 .29062 L
.30044 .29071 L
.30037 .29089 L
.30037 .29089 L
F
.30047 .29062 m
.30057 .29035 L
.3005 .29053 L
.30044 .29071 L
.30047 .29062 L
F
.30057 .29035 m
.30066 .29008 L
.30057 .29035 L
.3005 .29053 L
.30057 .29035 L
F
.30066 .29008 m
.30076 .28981 L
.30063 .29016 L
.30057 .29035 L
.30066 .29008 L
F
.30076 .28981 m
.30086 .28954 L
.3007 .28998 L
.30063 .29016 L
.30076 .28981 L
F
.30086 .28954 m
.30095 .28927 L
.30076 .2898 L
.3007 .28998 L
.30086 .28954 L
F
.30095 .28927 m
.30105 .28899 L
.30083 .28962 L
.30076 .2898 L
.30095 .28927 L
F
.30105 .28899 m
.30115 .28872 L
.30089 .28944 L
.30083 .28962 L
.30105 .28899 L
F
.30115 .28872 m
.30125 .28845 L
.30096 .28926 L
.30089 .28944 L
.30115 .28872 L
F
.30125 .28845 m
.30134 .28818 L
.30102 .28908 L
.30096 .28926 L
.30125 .28845 L
F
.30037 .29089 m
.30044 .29071 L
.3004 .2908 L
.30037 .29089 L
.30037 .29089 L
F
.30044 .29071 m
.3005 .29053 L
.30044 .29071 L
.3004 .2908 L
.30044 .29071 L
F
.3005 .29053 m
.30057 .29035 L
.30047 .29062 L
.30044 .29071 L
.3005 .29053 L
F
.30057 .29035 m
.30063 .29016 L
.3005 .29053 L
.30047 .29062 L
.30057 .29035 L
F
.30063 .29016 m
.3007 .28998 L
.30054 .29044 L
.3005 .29053 L
.30063 .29016 L
F
.3007 .28998 m
.30076 .2898 L
.30057 .29034 L
.30054 .29044 L
.3007 .28998 L
F
.30076 .2898 m
.30083 .28962 L
.3006 .29025 L
.30057 .29034 L
.30076 .2898 L
F
.30083 .28962 m
.30089 .28944 L
.30063 .29016 L
.3006 .29025 L
.30083 .28962 L
F
.30089 .28944 m
.30096 .28926 L
.30067 .29007 L
.30063 .29016 L
.30089 .28944 L
F
.30096 .28926 m
.30102 .28908 L
.3007 .28998 L
.30067 .29007 L
.30096 .28926 L
F
.30037 .29089 m
.3004 .2908 L
.30037 .29089 L
.30037 .29089 L
.30037 .29089 L
F
.3004 .2908 m
.30044 .29071 L
.30037 .29089 L
.30037 .29089 L
.3004 .2908 L
F
.30044 .29071 m
.30047 .29062 L
.30037 .29089 L
.30037 .29089 L
.30044 .29071 L
F
.30047 .29062 m
.3005 .29053 L
.30037 .29089 L
.30037 .29089 L
.30047 .29062 L
F
.3005 .29053 m
.30054 .29044 L
.30037 .29089 L
.30037 .29089 L
.3005 .29053 L
F
.30054 .29044 m
.30057 .29034 L
.30037 .29089 L
.30037 .29089 L
.30054 .29044 L
F
.30057 .29034 m
.3006 .29025 L
.30037 .29089 L
.30037 .29089 L
.30057 .29034 L
F
.3006 .29025 m
.30063 .29016 L
.30037 .29089 L
.30037 .29089 L
.3006 .29025 L
F
.30063 .29016 m
.30067 .29007 L
.30037 .29089 L
.30037 .29089 L
.30063 .29016 L
F
.30067 .29007 m
.3007 .28998 L
.30037 .29089 L
.30037 .29089 L
.30067 .29007 L
F
.30037 .29089 m
.30037 .29089 L
.30034 .29098 L
.30037 .29089 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30031 .29107 L
.30034 .29098 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30027 .29116 L
.30031 .29107 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30024 .29125 L
.30027 .29116 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30021 .29135 L
.30024 .29125 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30018 .29144 L
.30021 .29135 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30014 .29153 L
.30018 .29144 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30011 .29162 L
.30014 .29153 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30008 .29171 L
.30011 .29162 L
.30037 .29089 L
F
.30037 .29089 m
.30037 .29089 L
.30005 .2918 L
.30008 .29171 L
.30037 .29089 L
F
.30037 .29089 m
.30034 .29098 L
.30031 .29107 L
.30037 .29089 L
.30037 .29089 L
F
.30034 .29098 m
.30031 .29107 L
.30024 .29125 L
.30031 .29107 L
.30034 .29098 L
F
.30031 .29107 m
.30027 .29116 L
.30018 .29143 L
.30024 .29125 L
.30031 .29107 L
F
.30027 .29116 m
.30024 .29125 L
.30011 .29162 L
.30018 .29143 L
.30027 .29116 L
F
.30024 .29125 m
.30021 .29135 L
.30005 .2918 L
.30011 .29162 L
.30024 .29125 L
F
.30021 .29135 m
.30018 .29144 L
.29998 .29198 L
.30005 .2918 L
.30021 .29135 L
F
.30018 .29144 m
.30014 .29153 L
.29992 .29216 L
.29998 .29198 L
.30018 .29144 L
F
.30014 .29153 m
.30011 .29162 L
.29985 .29234 L
.29992 .29216 L
.30014 .29153 L
F
.30011 .29162 m
.30008 .29171 L
.29979 .29252 L
.29985 .29234 L
.30011 .29162 L
F
.30008 .29171 m
.30005 .2918 L
.29972 .2927 L
.29979 .29252 L
.30008 .29171 L
F
.30037 .29089 m
.30031 .29107 L
.30028 .29116 L
.30037 .29089 L
.30037 .29089 L
F
.30031 .29107 m
.30024 .29125 L
.30018 .29143 L
.30028 .29116 L
.30031 .29107 L
F
.30024 .29125 m
.30018 .29143 L
.30008 .2917 L
.30018 .29143 L
.30024 .29125 L
F
.30018 .29143 m
.30011 .29162 L
.29998 .29197 L
.30008 .2917 L
.30018 .29143 L
F
.30011 .29162 m
.30005 .2918 L
.29989 .29224 L
.29998 .29197 L
.30011 .29162 L
F
.30005 .2918 m
.29998 .29198 L
.29979 .29251 L
.29989 .29224 L
.30005 .2918 L
F
.29998 .29198 m
.29992 .29216 L
.29969 .29279 L
.29979 .29251 L
.29998 .29198 L
F
.29992 .29216 m
.29985 .29234 L
.2996 .29306 L
.29969 .29279 L
.29992 .29216 L
F
.29985 .29234 m
.29979 .29252 L
.2995 .29333 L
.2996 .29306 L
.29985 .29234 L
F
.29979 .29252 m
.29972 .2927 L
.2994 .2936 L
.2995 .29333 L
.29979 .29252 L
F
.30037 .29089 m
.30028 .29116 L
.30024 .29125 L
.30037 .29089 L
.30037 .29089 L
F
.30028 .29116 m
.30018 .29143 L
.30012 .29161 L
.30024 .29125 L
.30028 .29116 L
F
.30018 .29143 m
.30008 .2917 L
.29999 .29197 L
.30012 .29161 L
.30018 .29143 L
F
.30008 .2917 m
.29998 .29197 L
.29986 .29232 L
.29999 .29197 L
.30008 .2917 L
F
.29998 .29197 m
.29989 .29224 L
.29973 .29268 L
.29986 .29232 L
.29998 .29197 L
F
.29989 .29224 m
.29979 .29251 L
.2996 .29304 L
.29973 .29268 L
.29989 .29224 L
F
.29979 .29251 m
.29969 .29279 L
.29947 .2934 L
.2996 .29304 L
.29979 .29251 L
F
.29969 .29279 m
.2996 .29306 L
.29934 .29376 L
.29947 .2934 L
.29969 .29279 L
F
.2996 .29306 m
.2995 .29333 L
.29922 .29412 L
.29934 .29376 L
.2996 .29306 L
F
.2995 .29333 m
.2994 .2936 L
.29909 .29447 L
.29922 .29412 L
.2995 .29333 L
F
.30037 .29089 m
.30024 .29125 L
.30021 .29133 L
.30037 .29089 L
.30037 .29089 L
F
.30024 .29125 m
.30012 .29161 L
.30005 .29178 L
.30021 .29133 L
.30024 .29125 L
F
.30012 .29161 m
.29999 .29197 L
.2999 .29222 L
.30005 .29178 L
.30012 .29161 L
F
.29999 .29197 m
.29986 .29232 L
.29974 .29267 L
.2999 .29222 L
.29999 .29197 L
F
.29986 .29232 m
.29973 .29268 L
.29958 .29311 L
.29974 .29267 L
.29986 .29232 L
F
.29973 .29268 m
.2996 .29304 L
.29942 .29355 L
.29958 .29311 L
.29973 .29268 L
F
.2996 .29304 m
.29947 .2934 L
.29926 .294 L
.29942 .29355 L
.2996 .29304 L
F
.29947 .2934 m
.29934 .29376 L
.2991 .29444 L
.29926 .294 L
.29947 .2934 L
F
.29934 .29376 m
.29922 .29412 L
.29894 .29488 L
.2991 .29444 L
.29934 .29376 L
F
.29922 .29412 m
.29909 .29447 L
.29878 .29533 L
.29894 .29488 L
.29922 .29412 L
F
.30037 .29089 m
.30021 .29133 L
.30018 .29142 L
.30037 .29089 L
.30037 .29089 L
F
.30021 .29133 m
.30005 .29178 L
.29999 .29194 L
.30018 .29142 L
.30021 .29133 L
F
.30005 .29178 m
.2999 .29222 L
.29981 .29247 L
.29999 .29194 L
.30005 .29178 L
F
.2999 .29222 m
.29974 .29267 L
.29962 .293 L
.29981 .29247 L
.2999 .29222 L
F
.29974 .29267 m
.29958 .29311 L
.29943 .29352 L
.29962 .293 L
.29974 .29267 L
F
.29958 .29311 m
.29942 .29355 L
.29924 .29405 L
.29943 .29352 L
.29958 .29311 L
F
.29942 .29355 m
.29926 .294 L
.29905 .29458 L
.29924 .29405 L
.29942 .29355 L
F
.29926 .294 m
.2991 .29444 L
.29886 .2951 L
.29905 .29458 L
.29926 .294 L
F
.2991 .29444 m
.29894 .29488 L
.29867 .29563 L
.29886 .2951 L
.2991 .29444 L
F
.29894 .29488 m
.29878 .29533 L
.29849 .29616 L
.29867 .29563 L
.29894 .29488 L
F
.30037 .29089 m
.30018 .29142 L
.30015 .2915 L
.30037 .29089 L
.30037 .29089 L
F
.30018 .29142 m
.29999 .29194 L
.29994 .2921 L
.30015 .2915 L
.30018 .29142 L
F
.29999 .29194 m
.29981 .29247 L
.29972 .29271 L
.29994 .2921 L
.29999 .29194 L
F
.29981 .29247 m
.29962 .293 L
.2995 .29331 L
.29972 .29271 L
.29981 .29247 L
F
.29962 .293 m
.29943 .29352 L
.29929 .29392 L
.2995 .29331 L
.29962 .293 L
F
.29943 .29352 m
.29924 .29405 L
.29907 .29453 L
.29929 .29392 L
.29943 .29352 L
F
.29924 .29405 m
.29905 .29458 L
.29885 .29513 L
.29907 .29453 L
.29924 .29405 L
F
.29905 .29458 m
.29886 .2951 L
.29864 .29574 L
.29885 .29513 L
.29905 .29458 L
F
.29886 .2951 m
.29867 .29563 L
.29842 .29634 L
.29864 .29574 L
.29886 .2951 L
F
.29867 .29563 m
.29849 .29616 L
.2982 .29695 L
.29842 .29634 L
.29867 .29563 L
F
.30037 .29089 m
.30015 .2915 L
.30013 .29157 L
.30037 .29089 L
.30037 .29089 L
F
.30015 .2915 m
.29994 .2921 L
.29988 .29225 L
.30013 .29157 L
.30015 .2915 L
F
.29994 .2921 m
.29972 .29271 L
.29964 .29294 L
.29988 .29225 L
.29994 .2921 L
F
.29972 .29271 m
.2995 .29331 L
.2994 .29362 L
.29964 .29294 L
.29972 .29271 L
F
.2995 .29331 m
.29929 .29392 L
.29915 .2943 L
.2994 .29362 L
.2995 .29331 L
F
.29929 .29392 m
.29907 .29453 L
.29891 .29498 L
.29915 .2943 L
.29929 .29392 L
F
.29907 .29453 m
.29885 .29513 L
.29866 .29566 L
.29891 .29498 L
.29907 .29453 L
F
.29885 .29513 m
.29864 .29574 L
.29842 .29634 L
.29866 .29566 L
.29885 .29513 L
F
.29864 .29574 m
.29842 .29634 L
.29817 .29703 L
.29842 .29634 L
.29864 .29574 L
F
.29842 .29634 m
.2982 .29695 L
.29793 .29771 L
.29817 .29703 L
.29842 .29634 L
F
.30037 .29089 m
.30013 .29157 L
.3001 .29164 L
.30037 .29089 L
.30037 .29089 L
F
.30013 .29157 m
.29988 .29225 L
.29983 .2924 L
.3001 .29164 L
.30013 .29157 L
F
.29988 .29225 m
.29964 .29294 L
.29956 .29315 L
.29983 .2924 L
.29988 .29225 L
F
.29964 .29294 m
.2994 .29362 L
.29929 .2939 L
.29956 .29315 L
.29964 .29294 L
F
.2994 .29362 m
.29915 .2943 L
.29902 .29466 L
.29929 .2939 L
.2994 .29362 L
F
.29915 .2943 m
.29891 .29498 L
.29875 .29541 L
.29902 .29466 L
.29915 .2943 L
F
.29891 .29498 m
.29866 .29566 L
.29848 .29616 L
.29875 .29541 L
.29891 .29498 L
F
.29866 .29566 m
.29842 .29634 L
.29821 .29692 L
.29848 .29616 L
.29866 .29566 L
F
.29842 .29634 m
.29817 .29703 L
.29794 .29767 L
.29821 .29692 L
.29842 .29634 L
F
.29817 .29703 m
.29793 .29771 L
.29767 .29842 L
.29794 .29767 L
.29817 .29703 L
F
.30037 .29089 m
.3001 .29164 L
.30008 .29171 L
.30037 .29089 L
.30037 .29089 L
F
.3001 .29164 m
.29983 .2924 L
.29978 .29253 L
.30008 .29171 L
.3001 .29164 L
F
.29983 .2924 m
.29956 .29315 L
.29949 .29335 L
.29978 .29253 L
.29983 .2924 L
F
.29956 .29315 m
.29929 .2939 L
.2992 .29417 L
.29949 .29335 L
.29956 .29315 L
F
.29929 .2939 m
.29902 .29466 L
.2989 .29499 L
.2992 .29417 L
.29929 .2939 L
F
.29902 .29466 m
.29875 .29541 L
.29861 .29581 L
.2989 .29499 L
.29902 .29466 L
F
.29875 .29541 m
.29848 .29616 L
.29832 .29663 L
.29861 .29581 L
.29875 .29541 L
F
.29848 .29616 m
.29821 .29692 L
.29802 .29745 L
.29832 .29663 L
.29848 .29616 L
F
.29821 .29692 m
.29794 .29767 L
.29773 .29827 L
.29802 .29745 L
.29821 .29692 L
F
.29794 .29767 m
.29767 .29842 L
.29743 .29909 L
.29773 .29827 L
.29794 .29767 L
F
.30037 .29089 m
.30008 .29171 L
.30006 .29177 L
.30037 .29089 L
.30037 .29089 L
F
.30008 .29171 m
.29978 .29253 L
.29974 .29265 L
.30006 .29177 L
.30008 .29171 L
F
.29978 .29253 m
.29949 .29335 L
.29942 .29354 L
.29974 .29265 L
.29978 .29253 L
F
.29949 .29335 m
.2992 .29417 L
.29911 .29442 L
.29942 .29354 L
.29949 .29335 L
F
.2992 .29417 m
.2989 .29499 L
.29879 .2953 L
.29911 .29442 L
.2992 .29417 L
F
.2989 .29499 m
.29861 .29581 L
.29848 .29618 L
.29879 .2953 L
.2989 .29499 L
F
.29861 .29581 m
.29832 .29663 L
.29816 .29706 L
.29848 .29618 L
.29861 .29581 L
F
.29832 .29663 m
.29802 .29745 L
.29784 .29795 L
.29816 .29706 L
.29832 .29663 L
F
.29802 .29745 m
.29773 .29827 L
.29753 .29883 L
.29784 .29795 L
.29802 .29745 L
F
.29773 .29827 m
.29743 .29909 L
.29721 .29971 L
.29753 .29883 L
.29773 .29827 L
F
.30037 .29089 m
.30006 .29177 L
.30004 .29183 L
.30037 .29089 L
.30037 .29089 L
F
.30006 .29177 m
.29974 .29265 L
.2997 .29277 L
.30004 .29183 L
.30006 .29177 L
F
.29974 .29265 m
.29942 .29354 L
.29936 .2937 L
.2997 .29277 L
.29974 .29265 L
F
.29942 .29354 m
.29911 .29442 L
.29903 .29464 L
.29936 .2937 L
.29942 .29354 L
F
.29911 .29442 m
.29879 .2953 L
.29869 .29558 L
.29903 .29464 L
.29911 .29442 L
F
.29879 .2953 m
.29848 .29618 L
.29835 .29652 L
.29869 .29558 L
.29879 .2953 L
F
.29848 .29618 m
.29816 .29706 L
.29802 .29746 L
.29835 .29652 L
.29848 .29618 L
F
.29816 .29706 m
.29784 .29795 L
.29768 .2984 L
.29802 .29746 L
.29816 .29706 L
F
.29784 .29795 m
.29753 .29883 L
.29735 .29933 L
.29768 .2984 L
.29784 .29795 L
F
.29753 .29883 m
.29721 .29971 L
.29701 .30027 L
.29735 .29933 L
.29753 .29883 L
F
.30037 .29089 m
.30004 .29183 L
.30002 .29188 L
.30037 .29089 L
.30037 .29089 L
F
.30004 .29183 m
.2997 .29277 L
.29966 .29287 L
.30002 .29188 L
.30004 .29183 L
F
.2997 .29277 m
.29936 .2937 L
.29931 .29386 L
.29966 .29287 L
.2997 .29277 L
F
.29936 .2937 m
.29903 .29464 L
.29895 .29485 L
.29931 .29386 L
.29936 .2937 L
F
.29903 .29464 m
.29869 .29558 L
.2986 .29583 L
.29895 .29485 L
.29903 .29464 L
F
.29869 .29558 m
.29835 .29652 L
.29825 .29682 L
.2986 .29583 L
.29869 .29558 L
F
.29835 .29652 m
.29802 .29746 L
.29789 .29781 L
.29825 .29682 L
.29835 .29652 L
F
.29802 .29746 m
.29768 .2984 L
.29754 .2988 L
.29789 .29781 L
.29802 .29746 L
F
.29768 .2984 m
.29735 .29933 L
.29718 .29979 L
.29754 .2988 L
.29768 .2984 L
F
.29735 .29933 m
.29701 .30027 L
.29683 .30078 L
.29718 .29979 L
.29735 .29933 L
F
.30037 .29089 m
.30002 .29188 L
.3 .29192 L
.30037 .29089 L
.30037 .29089 L
F
.30002 .29188 m
.29966 .29287 L
.29963 .29296 L
.3 .29192 L
.30002 .29188 L
F
.29966 .29287 m
.29931 .29386 L
.29926 .29399 L
.29963 .29296 L
.29966 .29287 L
F
.29931 .29386 m
.29895 .29485 L
.29889 .29502 L
.29926 .29399 L
.29931 .29386 L
F
.29895 .29485 m
.2986 .29583 L
.29852 .29606 L
.29889 .29502 L
.29895 .29485 L
F
.2986 .29583 m
.29825 .29682 L
.29815 .29709 L
.29852 .29606 L
.2986 .29583 L
F
.29825 .29682 m
.29789 .29781 L
.29778 .29812 L
.29815 .29709 L
.29825 .29682 L
F
.29789 .29781 m
.29754 .2988 L
.29741 .29916 L
.29778 .29812 L
.29789 .29781 L
F
.29754 .2988 m
.29718 .29979 L
.29704 .30019 L
.29741 .29916 L
.29754 .2988 L
F
.29718 .29979 m
.29683 .30078 L
.29667 .30122 L
.29704 .30019 L
.29718 .29979 L
F
.30037 .29089 m
.3 .29192 L
.29999 .29196 L
.30037 .29089 L
.30037 .29089 L
F
.3 .29192 m
.29963 .29296 L
.2996 .29303 L
.29999 .29196 L
.3 .29192 L
F
.29963 .29296 m
.29926 .29399 L
.29922 .2941 L
.2996 .29303 L
.29963 .29296 L
F
.29926 .29399 m
.29889 .29502 L
.29884 .29518 L
.29922 .2941 L
.29926 .29399 L
F
.29889 .29502 m
.29852 .29606 L
.29845 .29625 L
.29884 .29518 L
.29889 .29502 L
F
.29852 .29606 m
.29815 .29709 L
.29807 .29732 L
.29845 .29625 L
.29852 .29606 L
F
.29815 .29709 m
.29778 .29812 L
.29768 .29839 L
.29807 .29732 L
.29815 .29709 L
F
.29778 .29812 m
.29741 .29916 L
.2973 .29946 L
.29768 .29839 L
.29778 .29812 L
F
.29741 .29916 m
.29704 .30019 L
.29692 .30053 L
.2973 .29946 L
.29741 .29916 L
F
.29704 .30019 m
.29667 .30122 L
.29653 .3016 L
.29692 .30053 L
.29704 .30019 L
F
.30037 .29089 m
.29999 .29196 L
.29998 .29199 L
.30037 .29089 L
.30037 .29089 L
F
.29999 .29196 m
.2996 .29303 L
.29958 .2931 L
.29998 .29199 L
.29999 .29196 L
F
.2996 .29303 m
.29922 .2941 L
.29919 .2942 L
.29958 .2931 L
.2996 .29303 L
F
.29922 .2941 m
.29884 .29518 L
.29879 .2953 L
.29919 .2942 L
.29922 .2941 L
F
.29884 .29518 m
.29845 .29625 L
.2984 .29641 L
.29879 .2953 L
.29884 .29518 L
F
.29845 .29625 m
.29807 .29732 L
.298 .29751 L
.2984 .29641 L
.29845 .29625 L
F
.29807 .29732 m
.29768 .29839 L
.29761 .29861 L
.298 .29751 L
.29807 .29732 L
F
.29768 .29839 m
.2973 .29946 L
.29721 .29971 L
.29761 .29861 L
.29768 .29839 L
F
.2973 .29946 m
.29692 .30053 L
.29682 .30082 L
.29721 .29971 L
.2973 .29946 L
F
.29692 .30053 m
.29653 .3016 L
.29642 .30192 L
.29682 .30082 L
.29692 .30053 L
F
.30037 .29089 m
.29998 .29199 L
.29997 .29202 L
.30037 .29089 L
.30037 .29089 L
F
.29998 .29199 m
.29958 .2931 L
.29956 .29315 L
.29997 .29202 L
.29998 .29199 L
F
.29958 .2931 m
.29919 .2942 L
.29916 .29427 L
.29956 .29315 L
.29958 .2931 L
F
.29919 .2942 m
.29879 .2953 L
.29876 .2954 L
.29916 .29427 L
.29919 .2942 L
F
.29879 .2953 m
.2984 .29641 L
.29835 .29653 L
.29876 .2954 L
.29879 .2953 L
F
.2984 .29641 m
.298 .29751 L
.29795 .29766 L
.29835 .29653 L
.2984 .29641 L
F
.298 .29751 m
.29761 .29861 L
.29754 .29878 L
.29795 .29766 L
.298 .29751 L
F
.29761 .29861 m
.29721 .29971 L
.29714 .29991 L
.29754 .29878 L
.29761 .29861 L
F
.29721 .29971 m
.29682 .30082 L
.29674 .30104 L
.29714 .29991 L
.29721 .29971 L
F
.29682 .30082 m
.29642 .30192 L
.29633 .30217 L
.29674 .30104 L
.29682 .30082 L
F
.30037 .29089 m
.29997 .29202 L
.29996 .29204 L
.30037 .29089 L
.30037 .29089 L
F
.29997 .29202 m
.29956 .29315 L
.29955 .29318 L
.29996 .29204 L
.29997 .29202 L
F
.29956 .29315 m
.29916 .29427 L
.29914 .29433 L
.29955 .29318 L
.29956 .29315 L
F
.29916 .29427 m
.29876 .2954 L
.29873 .29547 L
.29914 .29433 L
.29916 .29427 L
F
.29876 .2954 m
.29835 .29653 L
.29832 .29662 L
.29873 .29547 L
.29876 .2954 L
F
.29835 .29653 m
.29795 .29766 L
.29791 .29776 L
.29832 .29662 L
.29835 .29653 L
F
.29795 .29766 m
.29754 .29878 L
.2975 .29891 L
.29791 .29776 L
.29795 .29766 L
F
.29754 .29878 m
.29714 .29991 L
.29709 .30005 L
.2975 .29891 L
.29754 .29878 L
F
.29714 .29991 m
.29674 .30104 L
.29668 .3012 L
.29709 .30005 L
.29714 .29991 L
F
.29674 .30104 m
.29633 .30217 L
.29627 .30234 L
.29668 .3012 L
.29674 .30104 L
F
.30037 .29089 m
.29996 .29204 L
.29996 .29205 L
.30037 .29089 L
.30037 .29089 L
F
.29996 .29204 m
.29955 .29318 L
.29954 .2932 L
.29996 .29205 L
.29996 .29204 L
F
.29955 .29318 m
.29914 .29433 L
.29913 .29436 L
.29954 .2932 L
.29955 .29318 L
F
.29914 .29433 m
.29873 .29547 L
.29871 .29551 L
.29913 .29436 L
.29914 .29433 L
F
.29873 .29547 m
.29832 .29662 L
.2983 .29667 L
.29871 .29551 L
.29873 .29547 L
F
.29832 .29662 m
.29791 .29776 L
.29789 .29783 L
.2983 .29667 L
.29832 .29662 L
F
.29791 .29776 m
.2975 .29891 L
.29747 .29898 L
.29789 .29783 L
.29791 .29776 L
F
.2975 .29891 m
.29709 .30005 L
.29706 .30014 L
.29747 .29898 L
.2975 .29891 L
F
.29709 .30005 m
.29668 .3012 L
.29664 .3013 L
.29706 .30014 L
.29709 .30005 L
F
.29668 .3012 m
.29627 .30234 L
.29623 .30245 L
.29664 .3013 L
.29668 .3012 L
F
.30037 .29089 m
.29996 .29205 L
.29996 .29205 L
.30037 .29089 L
.30037 .29089 L
F
.29996 .29205 m
.29954 .2932 L
.29954 .29321 L
.29996 .29205 L
.29996 .29205 L
F
.29954 .2932 m
.29913 .29436 L
.29913 .29437 L
.29954 .29321 L
.29954 .2932 L
F
.29913 .29436 m
.29871 .29551 L
.29871 .29553 L
.29913 .29437 L
.29913 .29436 L
F
.29871 .29551 m
.2983 .29667 L
.29829 .29669 L
.29871 .29553 L
.29871 .29551 L
F
.2983 .29667 m
.29789 .29783 L
.29788 .29785 L
.29829 .29669 L
.2983 .29667 L
F
.29789 .29783 m
.29747 .29898 L
.29746 .29901 L
.29788 .29785 L
.29789 .29783 L
F
.29747 .29898 m
.29706 .30014 L
.29705 .30017 L
.29746 .29901 L
.29747 .29898 L
F
.29706 .30014 m
.29664 .3013 L
.29663 .30133 L
.29705 .30017 L
.29706 .30014 L
F
.29664 .3013 m
.29623 .30245 L
.29622 .30249 L
.29663 .30133 L
.29664 .3013 L
F
0 g
.29622 .30249 m
.29623 .30245 L
.29627 .30234 L
.29633 .30217 L
.29642 .30192 L
.29653 .3016 L
.29667 .30122 L
.29683 .30078 L
.29701 .30027 L
.29721 .29971 L
.29743 .29909 L
.29767 .29842 L
.29793 .29771 L
.2982 .29695 L
.29849 .29616 L
.29878 .29533 L
.29909 .29447 L
.2994 .2936 L
.29972 .2927 L
.30005 .2918 L
.30037 .29089 L
.3007 .28998 L
.30102 .28908 L
.30134 .28818 L
.30166 .28731 L
.30196 .28645 L
.30226 .28562 L
.30254 .28483 L
.30281 .28407 L
.30307 .28336 L
.30331 .28269 L
.30353 .28207 L
.30373 .28151 L
.30392 .281 L
.30407 .28056 L
.30421 .28018 L
.30432 .27986 L
.30441 .27961 L
.30448 .27944 L
.30451 .27933 L
.30453 .27929 L
.30451 .27933 L
.30448 .27944 L
.30441 .27961 L
.30432 .27986 L
.30421 .28018 L
.30407 .28056 L
.30392 .281 L
.30373 .28151 L
.30353 .28207 L
Mistroke
.30331 .28269 L
.30307 .28336 L
.30281 .28407 L
.30254 .28483 L
.30226 .28562 L
.30196 .28645 L
.30166 .28731 L
.30134 .28818 L
.30102 .28908 L
.3007 .28998 L
.30037 .29089 L
.30005 .2918 L
.29972 .2927 L
.2994 .2936 L
.29909 .29447 L
.29878 .29533 L
.29849 .29616 L
.2982 .29695 L
.29793 .29771 L
.29767 .29842 L
.29743 .29909 L
.29721 .29971 L
.29701 .30027 L
.29683 .30078 L
.29667 .30122 L
.29653 .3016 L
.29642 .30192 L
.29633 .30217 L
.29627 .30234 L
.29623 .30245 L
.29622 .30249 L
Mfstroke
.5 g
.30605 .29293 m
.30564 .29409 L
.30564 .29408 L
.30605 .29293 L
.30605 .29293 L
F
.30564 .29409 m
.30522 .29525 L
.30522 .29524 L
.30564 .29408 L
.30564 .29409 L
F
.30522 .29525 m
.30481 .2964 L
.30481 .29639 L
.30522 .29524 L
.30522 .29525 L
F
.30481 .2964 m
.30439 .29756 L
.3044 .29755 L
.30481 .29639 L
.30481 .2964 L
F
.30439 .29756 m
.30397 .29872 L
.30398 .29871 L
.3044 .29755 L
.30439 .29756 L
F
.30397 .29872 m
.30356 .29988 L
.30357 .29986 L
.30398 .29871 L
.30397 .29872 L
F
.30356 .29988 m
.30314 .30104 L
.30315 .30102 L
.30357 .29986 L
.30356 .29988 L
F
.30314 .30104 m
.30273 .3022 L
.30274 .30217 L
.30315 .30102 L
.30314 .30104 L
F
.30273 .3022 m
.30231 .30336 L
.30232 .30333 L
.30274 .30217 L
.30273 .3022 L
F
.30231 .30336 m
.3019 .30452 L
.30191 .30449 L
.30232 .30333 L
.30231 .30336 L
F
.30605 .29293 m
.30564 .29408 L
.30564 .29407 L
.30605 .29293 L
.30605 .29293 L
F
.30564 .29408 m
.30522 .29524 L
.30523 .29522 L
.30564 .29407 L
.30564 .29408 L
F
.30522 .29524 m
.30481 .29639 L
.30482 .29636 L
.30523 .29522 L
.30522 .29524 L
F
.30481 .29639 m
.3044 .29755 L
.30441 .29751 L
.30482 .29636 L
.30481 .29639 L
F
.3044 .29755 m
.30398 .29871 L
.304 .29865 L
.30441 .29751 L
.3044 .29755 L
F
.30398 .29871 m
.30357 .29986 L
.30359 .2998 L
.304 .29865 L
.30398 .29871 L
F
.30357 .29986 m
.30315 .30102 L
.30318 .30094 L
.30359 .2998 L
.30357 .29986 L
F
.30315 .30102 m
.30274 .30217 L
.30277 .30209 L
.30318 .30094 L
.30315 .30102 L
F
.30274 .30217 m
.30232 .30333 L
.30236 .30323 L
.30277 .30209 L
.30274 .30217 L
F
.30232 .30333 m
.30191 .30449 L
.30195 .30438 L
.30236 .30323 L
.30232 .30333 L
F
.30605 .29293 m
.30564 .29407 L
.30565 .29405 L
.30605 .29293 L
.30605 .29293 L
F
.30564 .29407 m
.30523 .29522 L
.30524 .29518 L
.30565 .29405 L
.30564 .29407 L
F
.30523 .29522 m
.30482 .29636 L
.30484 .29631 L
.30524 .29518 L
.30523 .29522 L
F
.30482 .29636 m
.30441 .29751 L
.30444 .29744 L
.30484 .29631 L
.30482 .29636 L
F
.30441 .29751 m
.304 .29865 L
.30403 .29856 L
.30444 .29744 L
.30441 .29751 L
F
.304 .29865 m
.30359 .2998 L
.30363 .29969 L
.30403 .29856 L
.304 .29865 L
F
.30359 .2998 m
.30318 .30094 L
.30322 .30082 L
.30363 .29969 L
.30359 .2998 L
F
.30318 .30094 m
.30277 .30209 L
.30282 .30195 L
.30322 .30082 L
.30318 .30094 L
F
.30277 .30209 m
.30236 .30323 L
.30242 .30307 L
.30282 .30195 L
.30277 .30209 L
F
.30236 .30323 m
.30195 .30438 L
.30201 .3042 L
.30242 .30307 L
.30236 .30323 L
F
.30605 .29293 m
.30565 .29405 L
.30566 .29403 L
.30605 .29293 L
.30605 .29293 L
F
.30565 .29405 m
.30524 .29518 L
.30526 .29513 L
.30566 .29403 L
.30565 .29405 L
F
.30524 .29518 m
.30484 .29631 L
.30487 .29623 L
.30526 .29513 L
.30524 .29518 L
F
.30484 .29631 m
.30444 .29744 L
.30447 .29734 L
.30487 .29623 L
.30484 .29631 L
F
.30444 .29744 m
.30403 .29856 L
.30408 .29844 L
.30447 .29734 L
.30444 .29744 L
F
.30403 .29856 m
.30363 .29969 L
.30368 .29954 L
.30408 .29844 L
.30403 .29856 L
F
.30363 .29969 m
.30322 .30082 L
.30329 .30065 L
.30368 .29954 L
.30363 .29969 L
F
.30322 .30082 m
.30282 .30195 L
.30289 .30175 L
.30329 .30065 L
.30322 .30082 L
F
.30282 .30195 m
.30242 .30307 L
.3025 .30285 L
.30289 .30175 L
.30282 .30195 L
F
.30242 .30307 m
.30201 .3042 L
.3021 .30396 L
.3025 .30285 L
.30242 .30307 L
F
.30605 .29293 m
.30566 .29403 L
.30567 .294 L
.30605 .29293 L
.30605 .29293 L
F
.30566 .29403 m
.30526 .29513 L
.30528 .29507 L
.30567 .294 L
.30566 .29403 L
F
.30526 .29513 m
.30487 .29623 L
.3049 .29614 L
.30528 .29507 L
.30526 .29513 L
F
.30487 .29623 m
.30447 .29734 L
.30452 .29721 L
.3049 .29614 L
.30487 .29623 L
F
.30447 .29734 m
.30408 .29844 L
.30413 .29828 L
.30452 .29721 L
.30447 .29734 L
F
.30408 .29844 m
.30368 .29954 L
.30375 .29935 L
.30413 .29828 L
.30408 .29844 L
F
.30368 .29954 m
.30329 .30065 L
.30336 .30043 L
.30375 .29935 L
.30368 .29954 L
F
.30329 .30065 m
.30289 .30175 L
.30298 .3015 L
.30336 .30043 L
.30329 .30065 L
F
.30289 .30175 m
.3025 .30285 L
.3026 .30257 L
.30298 .3015 L
.30289 .30175 L
F
.3025 .30285 m
.3021 .30396 L
.30221 .30364 L
.3026 .30257 L
.3025 .30285 L
F
.30605 .29293 m
.30567 .294 L
.30568 .29396 L
.30605 .29293 L
.30605 .29293 L
F
.30567 .294 m
.30528 .29507 L
.30531 .29499 L
.30568 .29396 L
.30567 .294 L
F
.30528 .29507 m
.3049 .29614 L
.30494 .29603 L
.30531 .29499 L
.30528 .29507 L
F
.3049 .29614 m
.30452 .29721 L
.30457 .29706 L
.30494 .29603 L
.3049 .29614 L
F
.30452 .29721 m
.30413 .29828 L
.3042 .29809 L
.30457 .29706 L
.30452 .29721 L
F
.30413 .29828 m
.30375 .29935 L
.30383 .29913 L
.3042 .29809 L
.30413 .29828 L
F
.30375 .29935 m
.30336 .30043 L
.30346 .30016 L
.30383 .29913 L
.30375 .29935 L
F
.30336 .30043 m
.30298 .3015 L
.30309 .30119 L
.30346 .30016 L
.30336 .30043 L
F
.30298 .3015 m
.3026 .30257 L
.30272 .30223 L
.30309 .30119 L
.30298 .3015 L
F
.3026 .30257 m
.30221 .30364 L
.30235 .30326 L
.30272 .30223 L
.3026 .30257 L
F
.30605 .29293 m
.30568 .29396 L
.3057 .29391 L
.30605 .29293 L
.30605 .29293 L
F
.30568 .29396 m
.30531 .29499 L
.30534 .2949 L
.3057 .29391 L
.30568 .29396 L
F
.30531 .29499 m
.30494 .29603 L
.30499 .29589 L
.30534 .2949 L
.30531 .29499 L
F
.30494 .29603 m
.30457 .29706 L
.30464 .29688 L
.30499 .29589 L
.30494 .29603 L
F
.30457 .29706 m
.3042 .29809 L
.30428 .29787 L
.30464 .29688 L
.30457 .29706 L
F
.3042 .29809 m
.30383 .29913 L
.30393 .29886 L
.30428 .29787 L
.3042 .29809 L
F
.30383 .29913 m
.30346 .30016 L
.30357 .29985 L
.30393 .29886 L
.30383 .29913 L
F
.30346 .30016 m
.30309 .30119 L
.30322 .30084 L
.30357 .29985 L
.30346 .30016 L
F
.30309 .30119 m
.30272 .30223 L
.30286 .30183 L
.30322 .30084 L
.30309 .30119 L
F
.30272 .30223 m
.30235 .30326 L
.30251 .30281 L
.30286 .30183 L
.30272 .30223 L
F
.30605 .29293 m
.3057 .29391 L
.30572 .29386 L
.30605 .29293 L
.30605 .29293 L
F
.3057 .29391 m
.30534 .2949 L
.30538 .2948 L
.30572 .29386 L
.3057 .29391 L
F
.30534 .2949 m
.30499 .29589 L
.30504 .29574 L
.30538 .2948 L
.30534 .2949 L
F
.30499 .29589 m
.30464 .29688 L
.30471 .29668 L
.30504 .29574 L
.30499 .29589 L
F
.30464 .29688 m
.30428 .29787 L
.30437 .29762 L
.30471 .29668 L
.30464 .29688 L
F
.30428 .29787 m
.30393 .29886 L
.30404 .29856 L
.30437 .29762 L
.30428 .29787 L
F
.30393 .29886 m
.30357 .29985 L
.3037 .29949 L
.30404 .29856 L
.30393 .29886 L
F
.30357 .29985 m
.30322 .30084 L
.30336 .30043 L
.3037 .29949 L
.30357 .29985 L
F
.30322 .30084 m
.30286 .30183 L
.30303 .30137 L
.30336 .30043 L
.30322 .30084 L
F
.30286 .30183 m
.30251 .30281 L
.30269 .30231 L
.30303 .30137 L
.30286 .30183 L
F
.30605 .29293 m
.30572 .29386 L
.30574 .29381 L
.30605 .29293 L
.30605 .29293 L
F
.30572 .29386 m
.30538 .2948 L
.30542 .29469 L
.30574 .29381 L
.30572 .29386 L
F
.30538 .2948 m
.30504 .29574 L
.3051 .29557 L
.30542 .29469 L
.30538 .2948 L
F
.30504 .29574 m
.30471 .29668 L
.30479 .29645 L
.3051 .29557 L
.30504 .29574 L
F
.30471 .29668 m
.30437 .29762 L
.30447 .29733 L
.30479 .29645 L
.30471 .29668 L
F
.30437 .29762 m
.30404 .29856 L
.30416 .29822 L
.30447 .29733 L
.30437 .29762 L
F
.30404 .29856 m
.3037 .29949 L
.30384 .2991 L
.30416 .29822 L
.30404 .29856 L
F
.3037 .29949 m
.30336 .30043 L
.30352 .29998 L
.30384 .2991 L
.3037 .29949 L
F
.30336 .30043 m
.30303 .30137 L
.30321 .30086 L
.30352 .29998 L
.30336 .30043 L
F
.30303 .30137 m
.30269 .30231 L
.30289 .30174 L
.30321 .30086 L
.30303 .30137 L
F
.30605 .29293 m
.30574 .29381 L
.30576 .29375 L
.30605 .29293 L
.30605 .29293 L
F
.30574 .29381 m
.30542 .29469 L
.30546 .29457 L
.30576 .29375 L
.30574 .29381 L
F
.30542 .29469 m
.3051 .29557 L
.30517 .29539 L
.30546 .29457 L
.30542 .29469 L
F
.3051 .29557 m
.30479 .29645 L
.30488 .29621 L
.30517 .29539 L
.3051 .29557 L
F
.30479 .29645 m
.30447 .29733 L
.30458 .29703 L
.30488 .29621 L
.30479 .29645 L
F
.30447 .29733 m
.30416 .29822 L
.30429 .29785 L
.30458 .29703 L
.30447 .29733 L
F
.30416 .29822 m
.30384 .2991 L
.304 .29867 L
.30429 .29785 L
.30416 .29822 L
F
.30384 .2991 m
.30352 .29998 L
.3037 .29949 L
.304 .29867 L
.30384 .2991 L
F
.30352 .29998 m
.30321 .30086 L
.30341 .30031 L
.3037 .29949 L
.30352 .29998 L
F
.30321 .30086 m
.30289 .30174 L
.30311 .30113 L
.30341 .30031 L
.30321 .30086 L
F
.30605 .29293 m
.30576 .29375 L
.30578 .29368 L
.30605 .29293 L
.30605 .29293 L
F
.30576 .29375 m
.30546 .29457 L
.30551 .29443 L
.30578 .29368 L
.30576 .29375 L
F
.30546 .29457 m
.30517 .29539 L
.30524 .29519 L
.30551 .29443 L
.30546 .29457 L
F
.30517 .29539 m
.30488 .29621 L
.30497 .29594 L
.30524 .29519 L
.30517 .29539 L
F
.30488 .29621 m
.30458 .29703 L
.3047 .29669 L
.30497 .29594 L
.30488 .29621 L
F
.30458 .29703 m
.30429 .29785 L
.30443 .29744 L
.3047 .29669 L
.30458 .29703 L
F
.30429 .29785 m
.304 .29867 L
.30416 .2982 L
.30443 .29744 L
.30429 .29785 L
F
.304 .29867 m
.3037 .29949 L
.30389 .29895 L
.30416 .2982 L
.304 .29867 L
F
.3037 .29949 m
.30341 .30031 L
.30362 .2997 L
.30389 .29895 L
.3037 .29949 L
F
.30341 .30031 m
.30311 .30113 L
.30335 .30046 L
.30362 .2997 L
.30341 .30031 L
F
.30605 .29293 m
.30578 .29368 L
.30581 .29361 L
.30605 .29293 L
.30605 .29293 L
F
.30578 .29368 m
.30551 .29443 L
.30556 .29429 L
.30581 .29361 L
.30578 .29368 L
F
.30551 .29443 m
.30524 .29519 L
.30532 .29497 L
.30556 .29429 L
.30551 .29443 L
F
.30524 .29519 m
.30497 .29594 L
.30508 .29565 L
.30532 .29497 L
.30524 .29519 L
F
.30497 .29594 m
.3047 .29669 L
.30483 .29633 L
.30508 .29565 L
.30497 .29594 L
F
.3047 .29669 m
.30443 .29744 L
.30459 .29702 L
.30483 .29633 L
.3047 .29669 L
F
.30443 .29744 m
.30416 .2982 L
.30434 .2977 L
.30459 .29702 L
.30443 .29744 L
F
.30416 .2982 m
.30389 .29895 L
.3041 .29838 L
.30434 .2977 L
.30416 .2982 L
F
.30389 .29895 m
.30362 .2997 L
.30385 .29906 L
.3041 .29838 L
.30389 .29895 L
F
.30362 .2997 m
.30335 .30046 L
.30361 .29974 L
.30385 .29906 L
.30362 .2997 L
F
.30605 .29293 m
.30581 .29361 L
.30584 .29353 L
.30605 .29293 L
.30605 .29293 L
F
.30581 .29361 m
.30556 .29429 L
.30562 .29414 L
.30584 .29353 L
.30581 .29361 L
F
.30556 .29429 m
.30532 .29497 L
.3054 .29474 L
.30562 .29414 L
.30556 .29429 L
F
.30532 .29497 m
.30508 .29565 L
.30518 .29535 L
.3054 .29474 L
.30532 .29497 L
F
.30508 .29565 m
.30483 .29633 L
.30497 .29596 L
.30518 .29535 L
.30508 .29565 L
F
.30483 .29633 m
.30459 .29702 L
.30475 .29656 L
.30497 .29596 L
.30483 .29633 L
F
.30459 .29702 m
.30434 .2977 L
.30453 .29717 L
.30475 .29656 L
.30459 .29702 L
F
.30434 .2977 m
.3041 .29838 L
.30432 .29777 L
.30453 .29717 L
.30434 .2977 L
F
.3041 .29838 m
.30385 .29906 L
.3041 .29838 L
.30432 .29777 L
.3041 .29838 L
F
.30385 .29906 m
.30361 .29974 L
.30388 .29899 L
.3041 .29838 L
.30385 .29906 L
F
.30605 .29293 m
.30584 .29353 L
.30586 .29345 L
.30605 .29293 L
.30605 .29293 L
F
.30584 .29353 m
.30562 .29414 L
.30568 .29398 L
.30586 .29345 L
.30584 .29353 L
F
.30562 .29414 m
.3054 .29474 L
.30549 .29451 L
.30568 .29398 L
.30562 .29414 L
F
.3054 .29474 m
.30518 .29535 L
.3053 .29503 L
.30549 .29451 L
.3054 .29474 L
F
.30518 .29535 m
.30497 .29596 L
.30511 .29556 L
.3053 .29503 L
.30518 .29535 L
F
.30497 .29596 m
.30475 .29656 L
.30492 .29608 L
.30511 .29556 L
.30497 .29596 L
F
.30475 .29656 m
.30453 .29717 L
.30473 .29661 L
.30492 .29608 L
.30475 .29656 L
F
.30453 .29717 m
.30432 .29777 L
.30454 .29714 L
.30473 .29661 L
.30453 .29717 L
F
.30432 .29777 m
.3041 .29838 L
.30435 .29766 L
.30454 .29714 L
.30432 .29777 L
F
.3041 .29838 m
.30388 .29899 L
.30417 .29819 L
.30435 .29766 L
.3041 .29838 L
F
.30605 .29293 m
.30586 .29345 L
.30589 .29337 L
.30605 .29293 L
.30605 .29293 L
F
.30586 .29345 m
.30568 .29398 L
.30573 .29381 L
.30589 .29337 L
.30586 .29345 L
F
.30568 .29398 m
.30549 .29451 L
.30558 .29426 L
.30573 .29381 L
.30568 .29398 L
F
.30549 .29451 m
.3053 .29503 L
.30542 .2947 L
.30558 .29426 L
.30549 .29451 L
F
.3053 .29503 m
.30511 .29556 L
.30526 .29514 L
.30542 .2947 L
.3053 .29503 L
F
.30511 .29556 m
.30492 .29608 L
.3051 .29559 L
.30526 .29514 L
.30511 .29556 L
F
.30492 .29608 m
.30473 .29661 L
.30494 .29603 L
.3051 .29559 L
.30492 .29608 L
F
.30473 .29661 m
.30454 .29714 L
.30478 .29648 L
.30494 .29603 L
.30473 .29661 L
F
.30454 .29714 m
.30435 .29766 L
.30462 .29692 L
.30478 .29648 L
.30454 .29714 L
F
.30435 .29766 m
.30417 .29819 L
.30446 .29736 L
.30462 .29692 L
.30435 .29766 L
F
.30605 .29293 m
.30589 .29337 L
.30592 .29328 L
.30605 .29293 L
.30605 .29293 L
F
.30589 .29337 m
.30573 .29381 L
.3058 .29364 L
.30592 .29328 L
.30589 .29337 L
F
.30573 .29381 m
.30558 .29426 L
.30567 .294 L
.3058 .29364 L
.30573 .29381 L
F
.30558 .29426 m
.30542 .2947 L
.30554 .29436 L
.30567 .294 L
.30558 .29426 L
F
.30542 .2947 m
.30526 .29514 L
.30541 .29472 L
.30554 .29436 L
.30542 .2947 L
F
.30526 .29514 m
.3051 .29559 L
.30528 .29508 L
.30541 .29472 L
.30526 .29514 L
F
.3051 .29559 m
.30494 .29603 L
.30515 .29543 L
.30528 .29508 L
.3051 .29559 L
F
.30494 .29603 m
.30478 .29648 L
.30503 .29579 L
.30515 .29543 L
.30494 .29603 L
F
.30478 .29648 m
.30462 .29692 L
.3049 .29615 L
.30503 .29579 L
.30478 .29648 L
F
.30462 .29692 m
.30446 .29736 L
.30477 .29651 L
.3049 .29615 L
.30462 .29692 L
F
.30605 .29293 m
.30592 .29328 L
.30596 .2932 L
.30605 .29293 L
.30605 .29293 L
F
.30592 .29328 m
.3058 .29364 L
.30586 .29347 L
.30596 .2932 L
.30592 .29328 L
F
.3058 .29364 m
.30567 .294 L
.30576 .29374 L
.30586 .29347 L
.3058 .29364 L
F
.30567 .294 m
.30554 .29436 L
.30566 .29401 L
.30576 .29374 L
.30567 .294 L
F
.30554 .29436 m
.30541 .29472 L
.30557 .29428 L
.30566 .29401 L
.30554 .29436 L
F
.30541 .29472 m
.30528 .29508 L
.30547 .29455 L
.30557 .29428 L
.30541 .29472 L
F
.30528 .29508 m
.30515 .29543 L
.30537 .29482 L
.30547 .29455 L
.30528 .29508 L
F
.30515 .29543 m
.30503 .29579 L
.30528 .29509 L
.30537 .29482 L
.30515 .29543 L
F
.30503 .29579 m
.3049 .29615 L
.30518 .29536 L
.30528 .29509 L
.30503 .29579 L
F
.3049 .29615 m
.30477 .29651 L
.30508 .29563 L
.30518 .29536 L
.3049 .29615 L
F
.30605 .29293 m
.30596 .2932 L
.30599 .29311 L
.30605 .29293 L
.30605 .29293 L
F
.30596 .2932 m
.30586 .29347 L
.30592 .29329 L
.30599 .29311 L
.30596 .2932 L
F
.30586 .29347 m
.30576 .29374 L
.30586 .29347 L
.30592 .29329 L
.30586 .29347 L
F
.30576 .29374 m
.30566 .29401 L
.30579 .29365 L
.30586 .29347 L
.30576 .29374 L
F
.30566 .29401 m
.30557 .29428 L
.30573 .29383 L
.30579 .29365 L
.30566 .29401 L
F
.30557 .29428 m
.30547 .29455 L
.30566 .29401 L
.30573 .29383 L
.30557 .29428 L
F
.30547 .29455 m
.30537 .29482 L
.3056 .2942 L
.30566 .29401 L
.30547 .29455 L
F
.30537 .29482 m
.30528 .29509 L
.30553 .29438 L
.3056 .2942 L
.30537 .29482 L
F
.30528 .29509 m
.30518 .29536 L
.30547 .29456 L
.30553 .29438 L
.30528 .29509 L
F
.30518 .29536 m
.30508 .29563 L
.3054 .29474 L
.30547 .29456 L
.30518 .29536 L
F
.30605 .29293 m
.30599 .29311 L
.30602 .29302 L
.30605 .29293 L
.30605 .29293 L
F
.30599 .29311 m
.30592 .29329 L
.30599 .29311 L
.30602 .29302 L
.30599 .29311 L
F
.30592 .29329 m
.30586 .29347 L
.30595 .2932 L
.30599 .29311 L
.30592 .29329 L
F
.30586 .29347 m
.30579 .29365 L
.30592 .29329 L
.30595 .2932 L
.30586 .29347 L
F
.30579 .29365 m
.30573 .29383 L
.30589 .29338 L
.30592 .29329 L
.30579 .29365 L
F
.30573 .29383 m
.30566 .29401 L
.30586 .29347 L
.30589 .29338 L
.30573 .29383 L
F
.30566 .29401 m
.3056 .2942 L
.30582 .29356 L
.30586 .29347 L
.30566 .29401 L
F
.3056 .2942 m
.30553 .29438 L
.30579 .29365 L
.30582 .29356 L
.3056 .2942 L
F
.30553 .29438 m
.30547 .29456 L
.30576 .29374 L
.30579 .29365 L
.30553 .29438 L
F
.30547 .29456 m
.3054 .29474 L
.30573 .29384 L
.30576 .29374 L
.30547 .29456 L
F
.30605 .29293 m
.30602 .29302 L
.30605 .29293 L
.30605 .29293 L
.30605 .29293 L
F
.30602 .29302 m
.30599 .29311 L
.30605 .29293 L
.30605 .29293 L
.30602 .29302 L
F
.30599 .29311 m
.30595 .2932 L
.30605 .29293 L
.30605 .29293 L
.30599 .29311 L
F
.30595 .2932 m
.30592 .29329 L
.30605 .29293 L
.30605 .29293 L
.30595 .2932 L
F
.30592 .29329 m
.30589 .29338 L
.30605 .29293 L
.30605 .29293 L
.30592 .29329 L
F
.30589 .29338 m
.30586 .29347 L
.30605 .29293 L
.30605 .29293 L
.30589 .29338 L
F
.30586 .29347 m
.30582 .29356 L
.30605 .29293 L
.30605 .29293 L
.30586 .29347 L
F
.30582 .29356 m
.30579 .29365 L
.30605 .29293 L
.30605 .29293 L
.30582 .29356 L
F
.30579 .29365 m
.30576 .29374 L
.30605 .29293 L
.30605 .29293 L
.30579 .29365 L
F
.30576 .29374 m
.30573 .29384 L
.30605 .29293 L
.30605 .29293 L
.30576 .29374 L
F
.30605 .29293 m
.30605 .29293 L
.30609 .29283 L
.30605 .29293 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30612 .29274 L
.30609 .29283 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30615 .29265 L
.30612 .29274 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30618 .29256 L
.30615 .29265 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30622 .29247 L
.30618 .29256 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30625 .29238 L
.30622 .29247 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30628 .29229 L
.30625 .29238 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30631 .2922 L
.30628 .29229 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30635 .29211 L
.30631 .2922 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30638 .29202 L
.30635 .29211 L
.30605 .29293 L
F
.30605 .29293 m
.30609 .29283 L
.30612 .29274 L
.30605 .29293 L
.30605 .29293 L
F
.30609 .29283 m
.30612 .29274 L
.30618 .29256 L
.30612 .29274 L
.30609 .29283 L
F
.30612 .29274 m
.30615 .29265 L
.30625 .29238 L
.30618 .29256 L
.30612 .29274 L
F
.30615 .29265 m
.30618 .29256 L
.30631 .2922 L
.30625 .29238 L
.30615 .29265 L
F
.30618 .29256 m
.30622 .29247 L
.30638 .29202 L
.30631 .2922 L
.30618 .29256 L
F
.30622 .29247 m
.30625 .29238 L
.30644 .29184 L
.30638 .29202 L
.30622 .29247 L
F
.30625 .29238 m
.30628 .29229 L
.30651 .29166 L
.30644 .29184 L
.30625 .29238 L
F
.30628 .29229 m
.30631 .2922 L
.30657 .29147 L
.30651 .29166 L
.30628 .29229 L
F
.30631 .2922 m
.30635 .29211 L
.30664 .29129 L
.30657 .29147 L
.30631 .2922 L
F
.30635 .29211 m
.30638 .29202 L
.3067 .29111 L
.30664 .29129 L
.30635 .29211 L
F
.30605 .29293 m
.30612 .29274 L
.30615 .29265 L
.30605 .29293 L
.30605 .29293 L
F
.30612 .29274 m
.30618 .29256 L
.30625 .29238 L
.30615 .29265 L
.30612 .29274 L
F
.30618 .29256 m
.30625 .29238 L
.30634 .29211 L
.30625 .29238 L
.30618 .29256 L
F
.30625 .29238 m
.30631 .2922 L
.30644 .29184 L
.30634 .29211 L
.30625 .29238 L
F
.30631 .2922 m
.30638 .29202 L
.30654 .29157 L
.30644 .29184 L
.30631 .2922 L
F
.30638 .29202 m
.30644 .29184 L
.30663 .2913 L
.30654 .29157 L
.30638 .29202 L
F
.30644 .29184 m
.30651 .29166 L
.30673 .29103 L
.30663 .2913 L
.30644 .29184 L
F
.30651 .29166 m
.30657 .29147 L
.30683 .29076 L
.30673 .29103 L
.30651 .29166 L
F
.30657 .29147 m
.30664 .29129 L
.30693 .29049 L
.30683 .29076 L
.30657 .29147 L
F
.30664 .29129 m
.3067 .29111 L
.30702 .29022 L
.30693 .29049 L
.30664 .29129 L
F
.30605 .29293 m
.30615 .29265 L
.30618 .29257 L
.30605 .29293 L
.30605 .29293 L
F
.30615 .29265 m
.30625 .29238 L
.30631 .29221 L
.30618 .29257 L
.30615 .29265 L
F
.30625 .29238 m
.30634 .29211 L
.30644 .29185 L
.30631 .29221 L
.30625 .29238 L
F
.30634 .29211 m
.30644 .29184 L
.30657 .29149 L
.30644 .29185 L
.30634 .29211 L
F
.30644 .29184 m
.30654 .29157 L
.30669 .29113 L
.30657 .29149 L
.30644 .29184 L
F
.30654 .29157 m
.30663 .2913 L
.30682 .29078 L
.30669 .29113 L
.30654 .29157 L
F
.30663 .2913 m
.30673 .29103 L
.30695 .29042 L
.30682 .29078 L
.30663 .2913 L
F
.30673 .29103 m
.30683 .29076 L
.30708 .29006 L
.30695 .29042 L
.30673 .29103 L
F
.30683 .29076 m
.30693 .29049 L
.30721 .2897 L
.30708 .29006 L
.30683 .29076 L
F
.30693 .29049 m
.30702 .29022 L
.30734 .28934 L
.30721 .2897 L
.30693 .29049 L
F
.30605 .29293 m
.30618 .29257 L
.30621 .29248 L
.30605 .29293 L
.30605 .29293 L
F
.30618 .29257 m
.30631 .29221 L
.30637 .29204 L
.30621 .29248 L
.30618 .29257 L
F
.30631 .29221 m
.30644 .29185 L
.30653 .29159 L
.30637 .29204 L
.30631 .29221 L
F
.30644 .29185 m
.30657 .29149 L
.30669 .29115 L
.30653 .29159 L
.30644 .29185 L
F
.30657 .29149 m
.30669 .29113 L
.30685 .29071 L
.30669 .29115 L
.30657 .29149 L
F
.30669 .29113 m
.30682 .29078 L
.30701 .29026 L
.30685 .29071 L
.30669 .29113 L
F
.30682 .29078 m
.30695 .29042 L
.30717 .28982 L
.30701 .29026 L
.30682 .29078 L
F
.30695 .29042 m
.30708 .29006 L
.30732 .28937 L
.30717 .28982 L
.30695 .29042 L
F
.30708 .29006 m
.30721 .2897 L
.30748 .28893 L
.30732 .28937 L
.30708 .29006 L
F
.30721 .2897 m
.30734 .28934 L
.30764 .28849 L
.30748 .28893 L
.30721 .2897 L
F
.30605 .29293 m
.30621 .29248 L
.30624 .2924 L
.30605 .29293 L
.30605 .29293 L
F
.30621 .29248 m
.30637 .29204 L
.30643 .29187 L
.30624 .2924 L
.30621 .29248 L
F
.30637 .29204 m
.30653 .29159 L
.30662 .29135 L
.30643 .29187 L
.30637 .29204 L
F
.30653 .29159 m
.30669 .29115 L
.30681 .29082 L
.30662 .29135 L
.30653 .29159 L
F
.30669 .29115 m
.30685 .29071 L
.307 .29029 L
.30681 .29082 L
.30669 .29115 L
F
.30685 .29071 m
.30701 .29026 L
.30718 .28977 L
.307 .29029 L
.30685 .29071 L
F
.30701 .29026 m
.30717 .28982 L
.30737 .28924 L
.30718 .28977 L
.30701 .29026 L
F
.30717 .28982 m
.30732 .28937 L
.30756 .28871 L
.30737 .28924 L
.30717 .28982 L
F
.30732 .28937 m
.30748 .28893 L
.30775 .28819 L
.30756 .28871 L
.30732 .28937 L
F
.30748 .28893 m
.30764 .28849 L
.30794 .28766 L
.30775 .28819 L
.30748 .28893 L
F
.30605 .29293 m
.30624 .2924 L
.30627 .29232 L
.30605 .29293 L
.30605 .29293 L
F
.30624 .2924 m
.30643 .29187 L
.30649 .29171 L
.30627 .29232 L
.30624 .2924 L
F
.30643 .29187 m
.30662 .29135 L
.3067 .29111 L
.30649 .29171 L
.30643 .29187 L
F
.30662 .29135 m
.30681 .29082 L
.30692 .2905 L
.3067 .29111 L
.30662 .29135 L
F
.30681 .29082 m
.307 .29029 L
.30714 .2899 L
.30692 .2905 L
.30681 .29082 L
F
.307 .29029 m
.30718 .28977 L
.30736 .28929 L
.30714 .2899 L
.307 .29029 L
F
.30718 .28977 m
.30737 .28924 L
.30757 .28868 L
.30736 .28929 L
.30718 .28977 L
F
.30737 .28924 m
.30756 .28871 L
.30779 .28808 L
.30757 .28868 L
.30737 .28924 L
F
.30756 .28871 m
.30775 .28819 L
.30801 .28747 L
.30779 .28808 L
.30756 .28871 L
F
.30775 .28819 m
.30794 .28766 L
.30822 .28687 L
.30801 .28747 L
.30775 .28819 L
F
.30605 .29293 m
.30627 .29232 L
.3063 .29224 L
.30605 .29293 L
.30605 .29293 L
F
.30627 .29232 m
.30649 .29171 L
.30654 .29156 L
.3063 .29224 L
.30627 .29232 L
F
.30649 .29171 m
.3067 .29111 L
.30679 .29088 L
.30654 .29156 L
.30649 .29171 L
F
.3067 .29111 m
.30692 .2905 L
.30703 .2902 L
.30679 .29088 L
.3067 .29111 L
F
.30692 .2905 m
.30714 .2899 L
.30727 .28952 L
.30703 .2902 L
.30692 .2905 L
F
.30714 .2899 m
.30736 .28929 L
.30752 .28884 L
.30727 .28952 L
.30714 .2899 L
F
.30736 .28929 m
.30757 .28868 L
.30776 .28815 L
.30752 .28884 L
.30736 .28929 L
F
.30757 .28868 m
.30779 .28808 L
.30801 .28747 L
.30776 .28815 L
.30757 .28868 L
F
.30779 .28808 m
.30801 .28747 L
.30825 .28679 L
.30801 .28747 L
.30779 .28808 L
F
.30801 .28747 m
.30822 .28687 L
.3085 .28611 L
.30825 .28679 L
.30801 .28747 L
F
.30605 .29293 m
.3063 .29224 L
.30632 .29217 L
.30605 .29293 L
.30605 .29293 L
F
.3063 .29224 m
.30654 .29156 L
.30659 .29142 L
.30632 .29217 L
.3063 .29224 L
F
.30654 .29156 m
.30679 .29088 L
.30686 .29067 L
.30659 .29142 L
.30654 .29156 L
F
.30679 .29088 m
.30703 .2902 L
.30713 .28991 L
.30686 .29067 L
.30679 .29088 L
F
.30703 .2902 m
.30727 .28952 L
.3074 .28916 L
.30713 .28991 L
.30703 .2902 L
F
.30727 .28952 m
.30752 .28884 L
.30767 .28841 L
.3074 .28916 L
.30727 .28952 L
F
.30752 .28884 m
.30776 .28815 L
.30794 .28765 L
.30767 .28841 L
.30752 .28884 L
F
.30776 .28815 m
.30801 .28747 L
.30821 .2869 L
.30794 .28765 L
.30776 .28815 L
F
.30801 .28747 m
.30825 .28679 L
.30848 .28615 L
.30821 .2869 L
.30801 .28747 L
F
.30825 .28679 m
.3085 .28611 L
.30875 .28539 L
.30848 .28615 L
.30825 .28679 L
F
.30605 .29293 m
.30632 .29217 L
.30635 .29211 L
.30605 .29293 L
.30605 .29293 L
F
.30632 .29217 m
.30659 .29142 L
.30664 .29129 L
.30635 .29211 L
.30632 .29217 L
F
.30659 .29142 m
.30686 .29067 L
.30693 .29047 L
.30664 .29129 L
.30659 .29142 L
F
.30686 .29067 m
.30713 .28991 L
.30723 .28965 L
.30693 .29047 L
.30686 .29067 L
F
.30713 .28991 m
.3074 .28916 L
.30752 .28883 L
.30723 .28965 L
.30713 .28991 L
F
.3074 .28916 m
.30767 .28841 L
.30782 .28801 L
.30752 .28883 L
.3074 .28916 L
F
.30767 .28841 m
.30794 .28765 L
.30811 .28719 L
.30782 .28801 L
.30767 .28841 L
F
.30794 .28765 m
.30821 .2869 L
.3084 .28636 L
.30811 .28719 L
.30794 .28765 L
F
.30821 .2869 m
.30848 .28615 L
.3087 .28554 L
.3084 .28636 L
.30821 .2869 L
F
.30848 .28615 m
.30875 .28539 L
.30899 .28472 L
.3087 .28554 L
.30848 .28615 L
F
.30605 .29293 m
.30635 .29211 L
.30637 .29204 L
.30605 .29293 L
.30605 .29293 L
F
.30635 .29211 m
.30664 .29129 L
.30668 .29116 L
.30637 .29204 L
.30635 .29211 L
F
.30664 .29129 m
.30693 .29047 L
.307 .29028 L
.30668 .29116 L
.30664 .29129 L
F
.30693 .29047 m
.30723 .28965 L
.30732 .2894 L
.307 .29028 L
.30693 .29047 L
F
.30723 .28965 m
.30752 .28883 L
.30763 .28852 L
.30732 .2894 L
.30723 .28965 L
F
.30752 .28883 m
.30782 .28801 L
.30795 .28763 L
.30763 .28852 L
.30752 .28883 L
F
.30782 .28801 m
.30811 .28719 L
.30826 .28675 L
.30795 .28763 L
.30782 .28801 L
F
.30811 .28719 m
.3084 .28636 L
.30858 .28587 L
.30826 .28675 L
.30811 .28719 L
F
.3084 .28636 m
.3087 .28554 L
.3089 .28499 L
.30858 .28587 L
.3084 .28636 L
F
.3087 .28554 m
.30899 .28472 L
.30921 .28411 L
.3089 .28499 L
.3087 .28554 L
F
.30605 .29293 m
.30637 .29204 L
.30639 .29199 L
.30605 .29293 L
.30605 .29293 L
F
.30637 .29204 m
.30668 .29116 L
.30672 .29105 L
.30639 .29199 L
.30637 .29204 L
F
.30668 .29116 m
.307 .29028 L
.30706 .29011 L
.30672 .29105 L
.30668 .29116 L
F
.307 .29028 m
.30732 .2894 L
.3074 .28917 L
.30706 .29011 L
.307 .29028 L
F
.30732 .2894 m
.30763 .28852 L
.30773 .28823 L
.3074 .28917 L
.30732 .2894 L
F
.30763 .28852 m
.30795 .28763 L
.30807 .2873 L
.30773 .28823 L
.30763 .28852 L
F
.30795 .28763 m
.30826 .28675 L
.30841 .28636 L
.30807 .2873 L
.30795 .28763 L
F
.30826 .28675 m
.30858 .28587 L
.30874 .28542 L
.30841 .28636 L
.30826 .28675 L
F
.30858 .28587 m
.3089 .28499 L
.30908 .28448 L
.30874 .28542 L
.30858 .28587 L
F
.3089 .28499 m
.30921 .28411 L
.30941 .28354 L
.30908 .28448 L
.3089 .28499 L
F
.30605 .29293 m
.30639 .29199 L
.30641 .29194 L
.30605 .29293 L
.30605 .29293 L
F
.30639 .29199 m
.30672 .29105 L
.30676 .29095 L
.30641 .29194 L
.30639 .29199 L
F
.30672 .29105 m
.30706 .29011 L
.30712 .28996 L
.30676 .29095 L
.30672 .29105 L
F
.30706 .29011 m
.3074 .28917 L
.30747 .28897 L
.30712 .28996 L
.30706 .29011 L
F
.3074 .28917 m
.30773 .28823 L
.30782 .28798 L
.30747 .28897 L
.3074 .28917 L
F
.30773 .28823 m
.30807 .2873 L
.30818 .28699 L
.30782 .28798 L
.30773 .28823 L
F
.30807 .2873 m
.30841 .28636 L
.30853 .286 L
.30818 .28699 L
.30807 .2873 L
F
.30841 .28636 m
.30874 .28542 L
.30889 .28501 L
.30853 .286 L
.30841 .28636 L
F
.30874 .28542 m
.30908 .28448 L
.30924 .28403 L
.30889 .28501 L
.30874 .28542 L
F
.30908 .28448 m
.30941 .28354 L
.3096 .28304 L
.30924 .28403 L
.30908 .28448 L
F
.30605 .29293 m
.30641 .29194 L
.30642 .29189 L
.30605 .29293 L
.30605 .29293 L
F
.30641 .29194 m
.30676 .29095 L
.30679 .29086 L
.30642 .29189 L
.30641 .29194 L
F
.30676 .29095 m
.30712 .28996 L
.30716 .28983 L
.30679 .29086 L
.30676 .29095 L
F
.30712 .28996 m
.30747 .28897 L
.30753 .28879 L
.30716 .28983 L
.30712 .28996 L
F
.30747 .28897 m
.30782 .28798 L
.3079 .28776 L
.30753 .28879 L
.30747 .28897 L
F
.30782 .28798 m
.30818 .28699 L
.30827 .28673 L
.3079 .28776 L
.30782 .28798 L
F
.30818 .28699 m
.30853 .286 L
.30864 .28569 L
.30827 .28673 L
.30818 .28699 L
F
.30853 .286 m
.30889 .28501 L
.30901 .28466 L
.30864 .28569 L
.30853 .286 L
F
.30889 .28501 m
.30924 .28403 L
.30939 .28363 L
.30901 .28466 L
.30889 .28501 L
F
.30924 .28403 m
.3096 .28304 L
.30976 .28259 L
.30939 .28363 L
.30924 .28403 L
F
.30605 .29293 m
.30642 .29189 L
.30644 .29185 L
.30605 .29293 L
.30605 .29293 L
F
.30642 .29189 m
.30679 .29086 L
.30682 .29078 L
.30644 .29185 L
.30642 .29189 L
F
.30679 .29086 m
.30716 .28983 L
.3072 .28971 L
.30682 .29078 L
.30679 .29086 L
F
.30716 .28983 m
.30753 .28879 L
.30759 .28864 L
.3072 .28971 L
.30716 .28983 L
F
.30753 .28879 m
.3079 .28776 L
.30797 .28757 L
.30759 .28864 L
.30753 .28879 L
F
.3079 .28776 m
.30827 .28673 L
.30836 .2865 L
.30797 .28757 L
.3079 .28776 L
F
.30827 .28673 m
.30864 .28569 L
.30874 .28543 L
.30836 .2865 L
.30827 .28673 L
F
.30864 .28569 m
.30901 .28466 L
.30912 .28435 L
.30874 .28543 L
.30864 .28569 L
F
.30901 .28466 m
.30939 .28363 L
.30951 .28328 L
.30912 .28435 L
.30901 .28466 L
F
.30939 .28363 m
.30976 .28259 L
.30989 .28221 L
.30951 .28328 L
.30939 .28363 L
F
.30605 .29293 m
.30644 .29185 L
.30645 .29182 L
.30605 .29293 L
.30605 .29293 L
F
.30644 .29185 m
.30682 .29078 L
.30684 .29072 L
.30645 .29182 L
.30644 .29185 L
F
.30682 .29078 m
.3072 .28971 L
.30724 .28962 L
.30684 .29072 L
.30682 .29078 L
F
.3072 .28971 m
.30759 .28864 L
.30763 .28851 L
.30724 .28962 L
.3072 .28971 L
F
.30759 .28864 m
.30797 .28757 L
.30803 .28741 L
.30763 .28851 L
.30759 .28864 L
F
.30797 .28757 m
.30836 .2865 L
.30842 .28631 L
.30803 .28741 L
.30797 .28757 L
F
.30836 .2865 m
.30874 .28543 L
.30882 .2852 L
.30842 .28631 L
.30836 .2865 L
F
.30874 .28543 m
.30912 .28435 L
.30921 .2841 L
.30882 .2852 L
.30874 .28543 L
F
.30912 .28435 m
.30951 .28328 L
.30961 .283 L
.30921 .2841 L
.30912 .28435 L
F
.30951 .28328 m
.30989 .28221 L
.31 .2819 L
.30961 .283 L
.30951 .28328 L
F
.30605 .29293 m
.30645 .29182 L
.30646 .2918 L
.30605 .29293 L
.30605 .29293 L
F
.30645 .29182 m
.30684 .29072 L
.30686 .29067 L
.30646 .2918 L
.30645 .29182 L
F
.30684 .29072 m
.30724 .28962 L
.30726 .28954 L
.30686 .29067 L
.30684 .29072 L
F
.30724 .28962 m
.30763 .28851 L
.30767 .28841 L
.30726 .28954 L
.30724 .28962 L
F
.30763 .28851 m
.30803 .28741 L
.30807 .28729 L
.30767 .28841 L
.30763 .28851 L
F
.30803 .28741 m
.30842 .28631 L
.30848 .28616 L
.30807 .28729 L
.30803 .28741 L
F
.30842 .28631 m
.30882 .2852 L
.30888 .28503 L
.30848 .28616 L
.30842 .28631 L
F
.30882 .2852 m
.30921 .2841 L
.30929 .2839 L
.30888 .28503 L
.30882 .2852 L
F
.30921 .2841 m
.30961 .283 L
.30969 .28278 L
.30929 .2839 L
.30921 .2841 L
F
.30961 .283 m
.31 .2819 L
.31009 .28165 L
.30969 .28278 L
.30961 .283 L
F
.30605 .29293 m
.30646 .2918 L
.30646 .29178 L
.30605 .29293 L
.30605 .29293 L
F
.30646 .2918 m
.30686 .29067 L
.30687 .29063 L
.30646 .29178 L
.30646 .2918 L
F
.30686 .29067 m
.30726 .28954 L
.30728 .28949 L
.30687 .29063 L
.30686 .29067 L
F
.30726 .28954 m
.30767 .28841 L
.30769 .28834 L
.30728 .28949 L
.30726 .28954 L
F
.30767 .28841 m
.30807 .28729 L
.3081 .2872 L
.30769 .28834 L
.30767 .28841 L
F
.30807 .28729 m
.30848 .28616 L
.30852 .28605 L
.3081 .2872 L
.30807 .28729 L
F
.30848 .28616 m
.30888 .28503 L
.30893 .28491 L
.30852 .28605 L
.30848 .28616 L
F
.30888 .28503 m
.30929 .2839 L
.30934 .28376 L
.30893 .28491 L
.30888 .28503 L
F
.30929 .2839 m
.30969 .28278 L
.30975 .28262 L
.30934 .28376 L
.30929 .2839 L
F
.30969 .28278 m
.31009 .28165 L
.31016 .28147 L
.30975 .28262 L
.30969 .28278 L
F
.30605 .29293 m
.30646 .29178 L
.30647 .29177 L
.30605 .29293 L
.30605 .29293 L
F
.30646 .29178 m
.30687 .29063 L
.30688 .29061 L
.30647 .29177 L
.30646 .29178 L
F
.30687 .29063 m
.30728 .28949 L
.3073 .28946 L
.30688 .29061 L
.30687 .29063 L
F
.30728 .28949 m
.30769 .28834 L
.30771 .2883 L
.3073 .28946 L
.30728 .28949 L
F
.30769 .28834 m
.3081 .2872 L
.30812 .28714 L
.30771 .2883 L
.30769 .28834 L
F
.3081 .2872 m
.30852 .28605 L
.30854 .28599 L
.30812 .28714 L
.3081 .2872 L
F
.30852 .28605 m
.30893 .28491 L
.30895 .28483 L
.30854 .28599 L
.30852 .28605 L
F
.30893 .28491 m
.30934 .28376 L
.30937 .28368 L
.30895 .28483 L
.30893 .28491 L
F
.30934 .28376 m
.30975 .28262 L
.30978 .28252 L
.30937 .28368 L
.30934 .28376 L
F
.30975 .28262 m
.31016 .28147 L
.3102 .28136 L
.30978 .28252 L
.30975 .28262 L
F
.30605 .29293 m
.30647 .29177 L
.30647 .29177 L
.30605 .29293 L
.30605 .29293 L
F
.30647 .29177 m
.30688 .29061 L
.30688 .29061 L
.30647 .29177 L
.30647 .29177 L
F
.30688 .29061 m
.3073 .28946 L
.3073 .28945 L
.30688 .29061 L
.30688 .29061 L
F
.3073 .28946 m
.30771 .2883 L
.30771 .28829 L
.3073 .28945 L
.3073 .28946 L
F
.30771 .2883 m
.30812 .28714 L
.30813 .28713 L
.30771 .28829 L
.30771 .2883 L
F
.30812 .28714 m
.30854 .28599 L
.30855 .28597 L
.30813 .28713 L
.30812 .28714 L
F
.30854 .28599 m
.30895 .28483 L
.30896 .28481 L
.30855 .28597 L
.30854 .28599 L
F
.30895 .28483 m
.30937 .28368 L
.30938 .28365 L
.30896 .28481 L
.30895 .28483 L
F
.30937 .28368 m
.30978 .28252 L
.30979 .28249 L
.30938 .28365 L
.30937 .28368 L
F
.30978 .28252 m
.3102 .28136 L
.31021 .28133 L
.30979 .28249 L
.30978 .28252 L
F
.30605 .29293 m
.30647 .29177 L
.30647 .29177 L
.30605 .29293 L
.30605 .29293 L
F
.30647 .29177 m
.30688 .29061 L
.30688 .29061 L
.30647 .29177 L
.30647 .29177 L
F
.30688 .29061 m
.3073 .28945 L
.3073 .28946 L
.30688 .29061 L
.30688 .29061 L
F
.3073 .28945 m
.30771 .28829 L
.30771 .2883 L
.3073 .28946 L
.3073 .28945 L
F
.30771 .28829 m
.30813 .28713 L
.30812 .28714 L
.30771 .2883 L
.30771 .28829 L
F
.30813 .28713 m
.30855 .28597 L
.30854 .28599 L
.30812 .28714 L
.30813 .28713 L
F
.30855 .28597 m
.30896 .28481 L
.30895 .28483 L
.30854 .28599 L
.30855 .28597 L
F
.30896 .28481 m
.30938 .28365 L
.30937 .28368 L
.30895 .28483 L
.30896 .28481 L
F
.30938 .28365 m
.30979 .28249 L
.30978 .28252 L
.30937 .28368 L
.30938 .28365 L
F
.30979 .28249 m
.31021 .28133 L
.3102 .28136 L
.30978 .28252 L
.30979 .28249 L
F
.30605 .29293 m
.30647 .29177 L
.30646 .29178 L
.30605 .29293 L
.30605 .29293 L
F
.30647 .29177 m
.30688 .29061 L
.30687 .29063 L
.30646 .29178 L
.30647 .29177 L
F
.30688 .29061 m
.3073 .28946 L
.30728 .28949 L
.30687 .29063 L
.30688 .29061 L
F
.3073 .28946 m
.30771 .2883 L
.30769 .28834 L
.30728 .28949 L
.3073 .28946 L
F
.30771 .2883 m
.30812 .28714 L
.3081 .2872 L
.30769 .28834 L
.30771 .2883 L
F
.30812 .28714 m
.30854 .28599 L
.30852 .28605 L
.3081 .2872 L
.30812 .28714 L
F
.30854 .28599 m
.30895 .28483 L
.30893 .28491 L
.30852 .28605 L
.30854 .28599 L
F
.30895 .28483 m
.30937 .28368 L
.30934 .28376 L
.30893 .28491 L
.30895 .28483 L
F
.30937 .28368 m
.30978 .28252 L
.30975 .28262 L
.30934 .28376 L
.30937 .28368 L
F
.30978 .28252 m
.3102 .28136 L
.31016 .28147 L
.30975 .28262 L
.30978 .28252 L
F
.30605 .29293 m
.30646 .29178 L
.30646 .2918 L
.30605 .29293 L
.30605 .29293 L
F
.30646 .29178 m
.30687 .29063 L
.30686 .29067 L
.30646 .2918 L
.30646 .29178 L
F
.30687 .29063 m
.30728 .28949 L
.30726 .28954 L
.30686 .29067 L
.30687 .29063 L
F
.30728 .28949 m
.30769 .28834 L
.30767 .28841 L
.30726 .28954 L
.30728 .28949 L
F
.30769 .28834 m
.3081 .2872 L
.30807 .28729 L
.30767 .28841 L
.30769 .28834 L
F
.3081 .2872 m
.30852 .28605 L
.30848 .28616 L
.30807 .28729 L
.3081 .2872 L
F
.30852 .28605 m
.30893 .28491 L
.30888 .28503 L
.30848 .28616 L
.30852 .28605 L
F
.30893 .28491 m
.30934 .28376 L
.30929 .2839 L
.30888 .28503 L
.30893 .28491 L
F
.30934 .28376 m
.30975 .28262 L
.30969 .28278 L
.30929 .2839 L
.30934 .28376 L
F
.30975 .28262 m
.31016 .28147 L
.31009 .28165 L
.30969 .28278 L
.30975 .28262 L
F
.30605 .29293 m
.30646 .2918 L
.30645 .29182 L
.30605 .29293 L
.30605 .29293 L
F
.30646 .2918 m
.30686 .29067 L
.30684 .29072 L
.30645 .29182 L
.30646 .2918 L
F
.30686 .29067 m
.30726 .28954 L
.30724 .28962 L
.30684 .29072 L
.30686 .29067 L
F
.30726 .28954 m
.30767 .28841 L
.30763 .28851 L
.30724 .28962 L
.30726 .28954 L
F
.30767 .28841 m
.30807 .28729 L
.30803 .28741 L
.30763 .28851 L
.30767 .28841 L
F
.30807 .28729 m
.30848 .28616 L
.30842 .28631 L
.30803 .28741 L
.30807 .28729 L
F
.30848 .28616 m
.30888 .28503 L
.30882 .2852 L
.30842 .28631 L
.30848 .28616 L
F
.30888 .28503 m
.30929 .2839 L
.30921 .2841 L
.30882 .2852 L
.30888 .28503 L
F
.30929 .2839 m
.30969 .28278 L
.30961 .283 L
.30921 .2841 L
.30929 .2839 L
F
.30969 .28278 m
.31009 .28165 L
.31 .2819 L
.30961 .283 L
.30969 .28278 L
F
.30605 .29293 m
.30645 .29182 L
.30644 .29185 L
.30605 .29293 L
.30605 .29293 L
F
.30645 .29182 m
.30684 .29072 L
.30682 .29078 L
.30644 .29185 L
.30645 .29182 L
F
.30684 .29072 m
.30724 .28962 L
.3072 .28971 L
.30682 .29078 L
.30684 .29072 L
F
.30724 .28962 m
.30763 .28851 L
.30759 .28864 L
.3072 .28971 L
.30724 .28962 L
F
.30763 .28851 m
.30803 .28741 L
.30797 .28757 L
.30759 .28864 L
.30763 .28851 L
F
.30803 .28741 m
.30842 .28631 L
.30836 .2865 L
.30797 .28757 L
.30803 .28741 L
F
.30842 .28631 m
.30882 .2852 L
.30874 .28543 L
.30836 .2865 L
.30842 .28631 L
F
.30882 .2852 m
.30921 .2841 L
.30912 .28435 L
.30874 .28543 L
.30882 .2852 L
F
.30921 .2841 m
.30961 .283 L
.30951 .28328 L
.30912 .28435 L
.30921 .2841 L
F
.30961 .283 m
.31 .2819 L
.30989 .28221 L
.30951 .28328 L
.30961 .283 L
F
.30605 .29293 m
.30644 .29185 L
.30642 .29189 L
.30605 .29293 L
.30605 .29293 L
F
.30644 .29185 m
.30682 .29078 L
.30679 .29086 L
.30642 .29189 L
.30644 .29185 L
F
.30682 .29078 m
.3072 .28971 L
.30716 .28983 L
.30679 .29086 L
.30682 .29078 L
F
.3072 .28971 m
.30759 .28864 L
.30753 .28879 L
.30716 .28983 L
.3072 .28971 L
F
.30759 .28864 m
.30797 .28757 L
.3079 .28776 L
.30753 .28879 L
.30759 .28864 L
F
.30797 .28757 m
.30836 .2865 L
.30827 .28673 L
.3079 .28776 L
.30797 .28757 L
F
.30836 .2865 m
.30874 .28543 L
.30864 .28569 L
.30827 .28673 L
.30836 .2865 L
F
.30874 .28543 m
.30912 .28435 L
.30901 .28466 L
.30864 .28569 L
.30874 .28543 L
F
.30912 .28435 m
.30951 .28328 L
.30939 .28363 L
.30901 .28466 L
.30912 .28435 L
F
.30951 .28328 m
.30989 .28221 L
.30976 .28259 L
.30939 .28363 L
.30951 .28328 L
F
.30605 .29293 m
.30642 .29189 L
.30641 .29194 L
.30605 .29293 L
.30605 .29293 L
F
.30642 .29189 m
.30679 .29086 L
.30676 .29095 L
.30641 .29194 L
.30642 .29189 L
F
.30679 .29086 m
.30716 .28983 L
.30712 .28996 L
.30676 .29095 L
.30679 .29086 L
F
.30716 .28983 m
.30753 .28879 L
.30747 .28897 L
.30712 .28996 L
.30716 .28983 L
F
.30753 .28879 m
.3079 .28776 L
.30782 .28798 L
.30747 .28897 L
.30753 .28879 L
F
.3079 .28776 m
.30827 .28673 L
.30818 .28699 L
.30782 .28798 L
.3079 .28776 L
F
.30827 .28673 m
.30864 .28569 L
.30853 .286 L
.30818 .28699 L
.30827 .28673 L
F
.30864 .28569 m
.30901 .28466 L
.30889 .28501 L
.30853 .286 L
.30864 .28569 L
F
.30901 .28466 m
.30939 .28363 L
.30924 .28403 L
.30889 .28501 L
.30901 .28466 L
F
.30939 .28363 m
.30976 .28259 L
.3096 .28304 L
.30924 .28403 L
.30939 .28363 L
F
.30605 .29293 m
.30641 .29194 L
.30639 .29199 L
.30605 .29293 L
.30605 .29293 L
F
.30641 .29194 m
.30676 .29095 L
.30672 .29105 L
.30639 .29199 L
.30641 .29194 L
F
.30676 .29095 m
.30712 .28996 L
.30706 .29011 L
.30672 .29105 L
.30676 .29095 L
F
.30712 .28996 m
.30747 .28897 L
.3074 .28917 L
.30706 .29011 L
.30712 .28996 L
F
.30747 .28897 m
.30782 .28798 L
.30773 .28823 L
.3074 .28917 L
.30747 .28897 L
F
.30782 .28798 m
.30818 .28699 L
.30807 .2873 L
.30773 .28823 L
.30782 .28798 L
F
.30818 .28699 m
.30853 .286 L
.30841 .28636 L
.30807 .2873 L
.30818 .28699 L
F
.30853 .286 m
.30889 .28501 L
.30874 .28542 L
.30841 .28636 L
.30853 .286 L
F
.30889 .28501 m
.30924 .28403 L
.30908 .28448 L
.30874 .28542 L
.30889 .28501 L
F
.30924 .28403 m
.3096 .28304 L
.30941 .28354 L
.30908 .28448 L
.30924 .28403 L
F
.30605 .29293 m
.30639 .29199 L
.30637 .29204 L
.30605 .29293 L
.30605 .29293 L
F
.30639 .29199 m
.30672 .29105 L
.30668 .29116 L
.30637 .29204 L
.30639 .29199 L
F
.30672 .29105 m
.30706 .29011 L
.307 .29028 L
.30668 .29116 L
.30672 .29105 L
F
.30706 .29011 m
.3074 .28917 L
.30732 .2894 L
.307 .29028 L
.30706 .29011 L
F
.3074 .28917 m
.30773 .28823 L
.30763 .28852 L
.30732 .2894 L
.3074 .28917 L
F
.30773 .28823 m
.30807 .2873 L
.30795 .28763 L
.30763 .28852 L
.30773 .28823 L
F
.30807 .2873 m
.30841 .28636 L
.30826 .28675 L
.30795 .28763 L
.30807 .2873 L
F
.30841 .28636 m
.30874 .28542 L
.30858 .28587 L
.30826 .28675 L
.30841 .28636 L
F
.30874 .28542 m
.30908 .28448 L
.3089 .28499 L
.30858 .28587 L
.30874 .28542 L
F
.30908 .28448 m
.30941 .28354 L
.30921 .28411 L
.3089 .28499 L
.30908 .28448 L
F
.30605 .29293 m
.30637 .29204 L
.30635 .29211 L
.30605 .29293 L
.30605 .29293 L
F
.30637 .29204 m
.30668 .29116 L
.30664 .29129 L
.30635 .29211 L
.30637 .29204 L
F
.30668 .29116 m
.307 .29028 L
.30693 .29047 L
.30664 .29129 L
.30668 .29116 L
F
.307 .29028 m
.30732 .2894 L
.30723 .28965 L
.30693 .29047 L
.307 .29028 L
F
.30732 .2894 m
.30763 .28852 L
.30752 .28883 L
.30723 .28965 L
.30732 .2894 L
F
.30763 .28852 m
.30795 .28763 L
.30782 .28801 L
.30752 .28883 L
.30763 .28852 L
F
.30795 .28763 m
.30826 .28675 L
.30811 .28719 L
.30782 .28801 L
.30795 .28763 L
F
.30826 .28675 m
.30858 .28587 L
.3084 .28636 L
.30811 .28719 L
.30826 .28675 L
F
.30858 .28587 m
.3089 .28499 L
.3087 .28554 L
.3084 .28636 L
.30858 .28587 L
F
.3089 .28499 m
.30921 .28411 L
.30899 .28472 L
.3087 .28554 L
.3089 .28499 L
F
.30605 .29293 m
.30635 .29211 L
.30632 .29217 L
.30605 .29293 L
.30605 .29293 L
F
.30635 .29211 m
.30664 .29129 L
.30659 .29142 L
.30632 .29217 L
.30635 .29211 L
F
.30664 .29129 m
.30693 .29047 L
.30686 .29067 L
.30659 .29142 L
.30664 .29129 L
F
.30693 .29047 m
.30723 .28965 L
.30713 .28991 L
.30686 .29067 L
.30693 .29047 L
F
.30723 .28965 m
.30752 .28883 L
.3074 .28916 L
.30713 .28991 L
.30723 .28965 L
F
.30752 .28883 m
.30782 .28801 L
.30767 .28841 L
.3074 .28916 L
.30752 .28883 L
F
.30782 .28801 m
.30811 .28719 L
.30794 .28765 L
.30767 .28841 L
.30782 .28801 L
F
.30811 .28719 m
.3084 .28636 L
.30821 .2869 L
.30794 .28765 L
.30811 .28719 L
F
.3084 .28636 m
.3087 .28554 L
.30848 .28615 L
.30821 .2869 L
.3084 .28636 L
F
.3087 .28554 m
.30899 .28472 L
.30875 .28539 L
.30848 .28615 L
.3087 .28554 L
F
.30605 .29293 m
.30632 .29217 L
.3063 .29224 L
.30605 .29293 L
.30605 .29293 L
F
.30632 .29217 m
.30659 .29142 L
.30654 .29156 L
.3063 .29224 L
.30632 .29217 L
F
.30659 .29142 m
.30686 .29067 L
.30679 .29088 L
.30654 .29156 L
.30659 .29142 L
F
.30686 .29067 m
.30713 .28991 L
.30703 .2902 L
.30679 .29088 L
.30686 .29067 L
F
.30713 .28991 m
.3074 .28916 L
.30727 .28952 L
.30703 .2902 L
.30713 .28991 L
F
.3074 .28916 m
.30767 .28841 L
.30752 .28884 L
.30727 .28952 L
.3074 .28916 L
F
.30767 .28841 m
.30794 .28765 L
.30776 .28815 L
.30752 .28884 L
.30767 .28841 L
F
.30794 .28765 m
.30821 .2869 L
.30801 .28747 L
.30776 .28815 L
.30794 .28765 L
F
.30821 .2869 m
.30848 .28615 L
.30825 .28679 L
.30801 .28747 L
.30821 .2869 L
F
.30848 .28615 m
.30875 .28539 L
.3085 .28611 L
.30825 .28679 L
.30848 .28615 L
F
.30605 .29293 m
.3063 .29224 L
.30627 .29232 L
.30605 .29293 L
.30605 .29293 L
F
.3063 .29224 m
.30654 .29156 L
.30649 .29171 L
.30627 .29232 L
.3063 .29224 L
F
.30654 .29156 m
.30679 .29088 L
.3067 .29111 L
.30649 .29171 L
.30654 .29156 L
F
.30679 .29088 m
.30703 .2902 L
.30692 .2905 L
.3067 .29111 L
.30679 .29088 L
F
.30703 .2902 m
.30727 .28952 L
.30714 .2899 L
.30692 .2905 L
.30703 .2902 L
F
.30727 .28952 m
.30752 .28884 L
.30736 .28929 L
.30714 .2899 L
.30727 .28952 L
F
.30752 .28884 m
.30776 .28815 L
.30757 .28868 L
.30736 .28929 L
.30752 .28884 L
F
.30776 .28815 m
.30801 .28747 L
.30779 .28808 L
.30757 .28868 L
.30776 .28815 L
F
.30801 .28747 m
.30825 .28679 L
.30801 .28747 L
.30779 .28808 L
.30801 .28747 L
F
.30825 .28679 m
.3085 .28611 L
.30822 .28687 L
.30801 .28747 L
.30825 .28679 L
F
.30605 .29293 m
.30627 .29232 L
.30624 .2924 L
.30605 .29293 L
.30605 .29293 L
F
.30627 .29232 m
.30649 .29171 L
.30643 .29187 L
.30624 .2924 L
.30627 .29232 L
F
.30649 .29171 m
.3067 .29111 L
.30662 .29135 L
.30643 .29187 L
.30649 .29171 L
F
.3067 .29111 m
.30692 .2905 L
.30681 .29082 L
.30662 .29135 L
.3067 .29111 L
F
.30692 .2905 m
.30714 .2899 L
.307 .29029 L
.30681 .29082 L
.30692 .2905 L
F
.30714 .2899 m
.30736 .28929 L
.30718 .28977 L
.307 .29029 L
.30714 .2899 L
F
.30736 .28929 m
.30757 .28868 L
.30737 .28924 L
.30718 .28977 L
.30736 .28929 L
F
.30757 .28868 m
.30779 .28808 L
.30756 .28871 L
.30737 .28924 L
.30757 .28868 L
F
.30779 .28808 m
.30801 .28747 L
.30775 .28819 L
.30756 .28871 L
.30779 .28808 L
F
.30801 .28747 m
.30822 .28687 L
.30794 .28766 L
.30775 .28819 L
.30801 .28747 L
F
.30605 .29293 m
.30624 .2924 L
.30621 .29248 L
.30605 .29293 L
.30605 .29293 L
F
.30624 .2924 m
.30643 .29187 L
.30637 .29204 L
.30621 .29248 L
.30624 .2924 L
F
.30643 .29187 m
.30662 .29135 L
.30653 .29159 L
.30637 .29204 L
.30643 .29187 L
F
.30662 .29135 m
.30681 .29082 L
.30669 .29115 L
.30653 .29159 L
.30662 .29135 L
F
.30681 .29082 m
.307 .29029 L
.30685 .29071 L
.30669 .29115 L
.30681 .29082 L
F
.307 .29029 m
.30718 .28977 L
.30701 .29026 L
.30685 .29071 L
.307 .29029 L
F
.30718 .28977 m
.30737 .28924 L
.30717 .28982 L
.30701 .29026 L
.30718 .28977 L
F
.30737 .28924 m
.30756 .28871 L
.30732 .28937 L
.30717 .28982 L
.30737 .28924 L
F
.30756 .28871 m
.30775 .28819 L
.30748 .28893 L
.30732 .28937 L
.30756 .28871 L
F
.30775 .28819 m
.30794 .28766 L
.30764 .28849 L
.30748 .28893 L
.30775 .28819 L
F
.30605 .29293 m
.30621 .29248 L
.30618 .29257 L
.30605 .29293 L
.30605 .29293 L
F
.30621 .29248 m
.30637 .29204 L
.30631 .29221 L
.30618 .29257 L
.30621 .29248 L
F
.30637 .29204 m
.30653 .29159 L
.30644 .29185 L
.30631 .29221 L
.30637 .29204 L
F
.30653 .29159 m
.30669 .29115 L
.30657 .29149 L
.30644 .29185 L
.30653 .29159 L
F
.30669 .29115 m
.30685 .29071 L
.30669 .29113 L
.30657 .29149 L
.30669 .29115 L
F
.30685 .29071 m
.30701 .29026 L
.30682 .29078 L
.30669 .29113 L
.30685 .29071 L
F
.30701 .29026 m
.30717 .28982 L
.30695 .29042 L
.30682 .29078 L
.30701 .29026 L
F
.30717 .28982 m
.30732 .28937 L
.30708 .29006 L
.30695 .29042 L
.30717 .28982 L
F
.30732 .28937 m
.30748 .28893 L
.30721 .2897 L
.30708 .29006 L
.30732 .28937 L
F
.30748 .28893 m
.30764 .28849 L
.30734 .28934 L
.30721 .2897 L
.30748 .28893 L
F
.30605 .29293 m
.30618 .29257 L
.30615 .29265 L
.30605 .29293 L
.30605 .29293 L
F
.30618 .29257 m
.30631 .29221 L
.30625 .29238 L
.30615 .29265 L
.30618 .29257 L
F
.30631 .29221 m
.30644 .29185 L
.30634 .29211 L
.30625 .29238 L
.30631 .29221 L
F
.30644 .29185 m
.30657 .29149 L
.30644 .29184 L
.30634 .29211 L
.30644 .29185 L
F
.30657 .29149 m
.30669 .29113 L
.30654 .29157 L
.30644 .29184 L
.30657 .29149 L
F
.30669 .29113 m
.30682 .29078 L
.30663 .2913 L
.30654 .29157 L
.30669 .29113 L
F
.30682 .29078 m
.30695 .29042 L
.30673 .29103 L
.30663 .2913 L
.30682 .29078 L
F
.30695 .29042 m
.30708 .29006 L
.30683 .29076 L
.30673 .29103 L
.30695 .29042 L
F
.30708 .29006 m
.30721 .2897 L
.30693 .29049 L
.30683 .29076 L
.30708 .29006 L
F
.30721 .2897 m
.30734 .28934 L
.30702 .29022 L
.30693 .29049 L
.30721 .2897 L
F
.30605 .29293 m
.30615 .29265 L
.30612 .29274 L
.30605 .29293 L
.30605 .29293 L
F
.30615 .29265 m
.30625 .29238 L
.30618 .29256 L
.30612 .29274 L
.30615 .29265 L
F
.30625 .29238 m
.30634 .29211 L
.30625 .29238 L
.30618 .29256 L
.30625 .29238 L
F
.30634 .29211 m
.30644 .29184 L
.30631 .2922 L
.30625 .29238 L
.30634 .29211 L
F
.30644 .29184 m
.30654 .29157 L
.30638 .29202 L
.30631 .2922 L
.30644 .29184 L
F
.30654 .29157 m
.30663 .2913 L
.30644 .29184 L
.30638 .29202 L
.30654 .29157 L
F
.30663 .2913 m
.30673 .29103 L
.30651 .29166 L
.30644 .29184 L
.30663 .2913 L
F
.30673 .29103 m
.30683 .29076 L
.30657 .29147 L
.30651 .29166 L
.30673 .29103 L
F
.30683 .29076 m
.30693 .29049 L
.30664 .29129 L
.30657 .29147 L
.30683 .29076 L
F
.30693 .29049 m
.30702 .29022 L
.3067 .29111 L
.30664 .29129 L
.30693 .29049 L
F
.30605 .29293 m
.30612 .29274 L
.30609 .29283 L
.30605 .29293 L
.30605 .29293 L
F
.30612 .29274 m
.30618 .29256 L
.30612 .29274 L
.30609 .29283 L
.30612 .29274 L
F
.30618 .29256 m
.30625 .29238 L
.30615 .29265 L
.30612 .29274 L
.30618 .29256 L
F
.30625 .29238 m
.30631 .2922 L
.30618 .29256 L
.30615 .29265 L
.30625 .29238 L
F
.30631 .2922 m
.30638 .29202 L
.30622 .29247 L
.30618 .29256 L
.30631 .2922 L
F
.30638 .29202 m
.30644 .29184 L
.30625 .29238 L
.30622 .29247 L
.30638 .29202 L
F
.30644 .29184 m
.30651 .29166 L
.30628 .29229 L
.30625 .29238 L
.30644 .29184 L
F
.30651 .29166 m
.30657 .29147 L
.30631 .2922 L
.30628 .29229 L
.30651 .29166 L
F
.30657 .29147 m
.30664 .29129 L
.30635 .29211 L
.30631 .2922 L
.30657 .29147 L
F
.30664 .29129 m
.3067 .29111 L
.30638 .29202 L
.30635 .29211 L
.30664 .29129 L
F
.30605 .29293 m
.30609 .29283 L
.30605 .29293 L
.30605 .29293 L
.30605 .29293 L
F
.30609 .29283 m
.30612 .29274 L
.30605 .29293 L
.30605 .29293 L
.30609 .29283 L
F
.30612 .29274 m
.30615 .29265 L
.30605 .29293 L
.30605 .29293 L
.30612 .29274 L
F
.30615 .29265 m
.30618 .29256 L
.30605 .29293 L
.30605 .29293 L
.30615 .29265 L
F
.30618 .29256 m
.30622 .29247 L
.30605 .29293 L
.30605 .29293 L
.30618 .29256 L
F
.30622 .29247 m
.30625 .29238 L
.30605 .29293 L
.30605 .29293 L
.30622 .29247 L
F
.30625 .29238 m
.30628 .29229 L
.30605 .29293 L
.30605 .29293 L
.30625 .29238 L
F
.30628 .29229 m
.30631 .2922 L
.30605 .29293 L
.30605 .29293 L
.30628 .29229 L
F
.30631 .2922 m
.30635 .29211 L
.30605 .29293 L
.30605 .29293 L
.30631 .2922 L
F
.30635 .29211 m
.30638 .29202 L
.30605 .29293 L
.30605 .29293 L
.30635 .29211 L
F
.30605 .29293 m
.30605 .29293 L
.30602 .29302 L
.30605 .29293 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30599 .29311 L
.30602 .29302 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30595 .2932 L
.30599 .29311 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30592 .29329 L
.30595 .2932 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30589 .29338 L
.30592 .29329 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30586 .29347 L
.30589 .29338 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30582 .29356 L
.30586 .29347 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30579 .29365 L
.30582 .29356 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30576 .29374 L
.30579 .29365 L
.30605 .29293 L
F
.30605 .29293 m
.30605 .29293 L
.30573 .29384 L
.30576 .29374 L
.30605 .29293 L
F
.30605 .29293 m
.30602 .29302 L
.30599 .29311 L
.30605 .29293 L
.30605 .29293 L
F
.30602 .29302 m
.30599 .29311 L
.30592 .29329 L
.30599 .29311 L
.30602 .29302 L
F
.30599 .29311 m
.30595 .2932 L
.30586 .29347 L
.30592 .29329 L
.30599 .29311 L
F
.30595 .2932 m
.30592 .29329 L
.30579 .29365 L
.30586 .29347 L
.30595 .2932 L
F
.30592 .29329 m
.30589 .29338 L
.30573 .29383 L
.30579 .29365 L
.30592 .29329 L
F
.30589 .29338 m
.30586 .29347 L
.30566 .29401 L
.30573 .29383 L
.30589 .29338 L
F
.30586 .29347 m
.30582 .29356 L
.3056 .2942 L
.30566 .29401 L
.30586 .29347 L
F
.30582 .29356 m
.30579 .29365 L
.30553 .29438 L
.3056 .2942 L
.30582 .29356 L
F
.30579 .29365 m
.30576 .29374 L
.30547 .29456 L
.30553 .29438 L
.30579 .29365 L
F
.30576 .29374 m
.30573 .29384 L
.3054 .29474 L
.30547 .29456 L
.30576 .29374 L
F
.30605 .29293 m
.30599 .29311 L
.30596 .2932 L
.30605 .29293 L
.30605 .29293 L
F
.30599 .29311 m
.30592 .29329 L
.30586 .29347 L
.30596 .2932 L
.30599 .29311 L
F
.30592 .29329 m
.30586 .29347 L
.30576 .29374 L
.30586 .29347 L
.30592 .29329 L
F
.30586 .29347 m
.30579 .29365 L
.30566 .29401 L
.30576 .29374 L
.30586 .29347 L
F
.30579 .29365 m
.30573 .29383 L
.30557 .29428 L
.30566 .29401 L
.30579 .29365 L
F
.30573 .29383 m
.30566 .29401 L
.30547 .29455 L
.30557 .29428 L
.30573 .29383 L
F
.30566 .29401 m
.3056 .2942 L
.30537 .29482 L
.30547 .29455 L
.30566 .29401 L
F
.3056 .2942 m
.30553 .29438 L
.30528 .29509 L
.30537 .29482 L
.3056 .2942 L
F
.30553 .29438 m
.30547 .29456 L
.30518 .29536 L
.30528 .29509 L
.30553 .29438 L
F
.30547 .29456 m
.3054 .29474 L
.30508 .29563 L
.30518 .29536 L
.30547 .29456 L
F
.30605 .29293 m
.30596 .2932 L
.30592 .29328 L
.30605 .29293 L
.30605 .29293 L
F
.30596 .2932 m
.30586 .29347 L
.3058 .29364 L
.30592 .29328 L
.30596 .2932 L
F
.30586 .29347 m
.30576 .29374 L
.30567 .294 L
.3058 .29364 L
.30586 .29347 L
F
.30576 .29374 m
.30566 .29401 L
.30554 .29436 L
.30567 .294 L
.30576 .29374 L
F
.30566 .29401 m
.30557 .29428 L
.30541 .29472 L
.30554 .29436 L
.30566 .29401 L
F
.30557 .29428 m
.30547 .29455 L
.30528 .29508 L
.30541 .29472 L
.30557 .29428 L
F
.30547 .29455 m
.30537 .29482 L
.30515 .29543 L
.30528 .29508 L
.30547 .29455 L
F
.30537 .29482 m
.30528 .29509 L
.30503 .29579 L
.30515 .29543 L
.30537 .29482 L
F
.30528 .29509 m
.30518 .29536 L
.3049 .29615 L
.30503 .29579 L
.30528 .29509 L
F
.30518 .29536 m
.30508 .29563 L
.30477 .29651 L
.3049 .29615 L
.30518 .29536 L
F
.30605 .29293 m
.30592 .29328 L
.30589 .29337 L
.30605 .29293 L
.30605 .29293 L
F
.30592 .29328 m
.3058 .29364 L
.30573 .29381 L
.30589 .29337 L
.30592 .29328 L
F
.3058 .29364 m
.30567 .294 L
.30558 .29426 L
.30573 .29381 L
.3058 .29364 L
F
.30567 .294 m
.30554 .29436 L
.30542 .2947 L
.30558 .29426 L
.30567 .294 L
F
.30554 .29436 m
.30541 .29472 L
.30526 .29514 L
.30542 .2947 L
.30554 .29436 L
F
.30541 .29472 m
.30528 .29508 L
.3051 .29559 L
.30526 .29514 L
.30541 .29472 L
F
.30528 .29508 m
.30515 .29543 L
.30494 .29603 L
.3051 .29559 L
.30528 .29508 L
F
.30515 .29543 m
.30503 .29579 L
.30478 .29648 L
.30494 .29603 L
.30515 .29543 L
F
.30503 .29579 m
.3049 .29615 L
.30462 .29692 L
.30478 .29648 L
.30503 .29579 L
F
.3049 .29615 m
.30477 .29651 L
.30446 .29736 L
.30462 .29692 L
.3049 .29615 L
F
.30605 .29293 m
.30589 .29337 L
.30586 .29345 L
.30605 .29293 L
.30605 .29293 L
F
.30589 .29337 m
.30573 .29381 L
.30568 .29398 L
.30586 .29345 L
.30589 .29337 L
F
.30573 .29381 m
.30558 .29426 L
.30549 .29451 L
.30568 .29398 L
.30573 .29381 L
F
.30558 .29426 m
.30542 .2947 L
.3053 .29503 L
.30549 .29451 L
.30558 .29426 L
F
.30542 .2947 m
.30526 .29514 L
.30511 .29556 L
.3053 .29503 L
.30542 .2947 L
F
.30526 .29514 m
.3051 .29559 L
.30492 .29608 L
.30511 .29556 L
.30526 .29514 L
F
.3051 .29559 m
.30494 .29603 L
.30473 .29661 L
.30492 .29608 L
.3051 .29559 L
F
.30494 .29603 m
.30478 .29648 L
.30454 .29714 L
.30473 .29661 L
.30494 .29603 L
F
.30478 .29648 m
.30462 .29692 L
.30435 .29766 L
.30454 .29714 L
.30478 .29648 L
F
.30462 .29692 m
.30446 .29736 L
.30417 .29819 L
.30435 .29766 L
.30462 .29692 L
F
.30605 .29293 m
.30586 .29345 L
.30584 .29353 L
.30605 .29293 L
.30605 .29293 L
F
.30586 .29345 m
.30568 .29398 L
.30562 .29414 L
.30584 .29353 L
.30586 .29345 L
F
.30568 .29398 m
.30549 .29451 L
.3054 .29474 L
.30562 .29414 L
.30568 .29398 L
F
.30549 .29451 m
.3053 .29503 L
.30518 .29535 L
.3054 .29474 L
.30549 .29451 L
F
.3053 .29503 m
.30511 .29556 L
.30497 .29596 L
.30518 .29535 L
.3053 .29503 L
F
.30511 .29556 m
.30492 .29608 L
.30475 .29656 L
.30497 .29596 L
.30511 .29556 L
F
.30492 .29608 m
.30473 .29661 L
.30453 .29717 L
.30475 .29656 L
.30492 .29608 L
F
.30473 .29661 m
.30454 .29714 L
.30432 .29777 L
.30453 .29717 L
.30473 .29661 L
F
.30454 .29714 m
.30435 .29766 L
.3041 .29838 L
.30432 .29777 L
.30454 .29714 L
F
.30435 .29766 m
.30417 .29819 L
.30388 .29899 L
.3041 .29838 L
.30435 .29766 L
F
.30605 .29293 m
.30584 .29353 L
.30581 .29361 L
.30605 .29293 L
.30605 .29293 L
F
.30584 .29353 m
.30562 .29414 L
.30556 .29429 L
.30581 .29361 L
.30584 .29353 L
F
.30562 .29414 m
.3054 .29474 L
.30532 .29497 L
.30556 .29429 L
.30562 .29414 L
F
.3054 .29474 m
.30518 .29535 L
.30508 .29565 L
.30532 .29497 L
.3054 .29474 L
F
.30518 .29535 m
.30497 .29596 L
.30483 .29633 L
.30508 .29565 L
.30518 .29535 L
F
.30497 .29596 m
.30475 .29656 L
.30459 .29702 L
.30483 .29633 L
.30497 .29596 L
F
.30475 .29656 m
.30453 .29717 L
.30434 .2977 L
.30459 .29702 L
.30475 .29656 L
F
.30453 .29717 m
.30432 .29777 L
.3041 .29838 L
.30434 .2977 L
.30453 .29717 L
F
.30432 .29777 m
.3041 .29838 L
.30385 .29906 L
.3041 .29838 L
.30432 .29777 L
F
.3041 .29838 m
.30388 .29899 L
.30361 .29974 L
.30385 .29906 L
.3041 .29838 L
F
.30605 .29293 m
.30581 .29361 L
.30578 .29368 L
.30605 .29293 L
.30605 .29293 L
F
.30581 .29361 m
.30556 .29429 L
.30551 .29443 L
.30578 .29368 L
.30581 .29361 L
F
.30556 .29429 m
.30532 .29497 L
.30524 .29519 L
.30551 .29443 L
.30556 .29429 L
F
.30532 .29497 m
.30508 .29565 L
.30497 .29594 L
.30524 .29519 L
.30532 .29497 L
F
.30508 .29565 m
.30483 .29633 L
.3047 .29669 L
.30497 .29594 L
.30508 .29565 L
F
.30483 .29633 m
.30459 .29702 L
.30443 .29744 L
.3047 .29669 L
.30483 .29633 L
F
.30459 .29702 m
.30434 .2977 L
.30416 .2982 L
.30443 .29744 L
.30459 .29702 L
F
.30434 .2977 m
.3041 .29838 L
.30389 .29895 L
.30416 .2982 L
.30434 .2977 L
F
.3041 .29838 m
.30385 .29906 L
.30362 .2997 L
.30389 .29895 L
.3041 .29838 L
F
.30385 .29906 m
.30361 .29974 L
.30335 .30046 L
.30362 .2997 L
.30385 .29906 L
F
.30605 .29293 m
.30578 .29368 L
.30576 .29375 L
.30605 .29293 L
.30605 .29293 L
F
.30578 .29368 m
.30551 .29443 L
.30546 .29457 L
.30576 .29375 L
.30578 .29368 L
F
.30551 .29443 m
.30524 .29519 L
.30517 .29539 L
.30546 .29457 L
.30551 .29443 L
F
.30524 .29519 m
.30497 .29594 L
.30488 .29621 L
.30517 .29539 L
.30524 .29519 L
F
.30497 .29594 m
.3047 .29669 L
.30458 .29703 L
.30488 .29621 L
.30497 .29594 L
F
.3047 .29669 m
.30443 .29744 L
.30429 .29785 L
.30458 .29703 L
.3047 .29669 L
F
.30443 .29744 m
.30416 .2982 L
.304 .29867 L
.30429 .29785 L
.30443 .29744 L
F
.30416 .2982 m
.30389 .29895 L
.3037 .29949 L
.304 .29867 L
.30416 .2982 L
F
.30389 .29895 m
.30362 .2997 L
.30341 .30031 L
.3037 .29949 L
.30389 .29895 L
F
.30362 .2997 m
.30335 .30046 L
.30311 .30113 L
.30341 .30031 L
.30362 .2997 L
F
.30605 .29293 m
.30576 .29375 L
.30574 .29381 L
.30605 .29293 L
.30605 .29293 L
F
.30576 .29375 m
.30546 .29457 L
.30542 .29469 L
.30574 .29381 L
.30576 .29375 L
F
.30546 .29457 m
.30517 .29539 L
.3051 .29557 L
.30542 .29469 L
.30546 .29457 L
F
.30517 .29539 m
.30488 .29621 L
.30479 .29645 L
.3051 .29557 L
.30517 .29539 L
F
.30488 .29621 m
.30458 .29703 L
.30447 .29733 L
.30479 .29645 L
.30488 .29621 L
F
.30458 .29703 m
.30429 .29785 L
.30416 .29822 L
.30447 .29733 L
.30458 .29703 L
F
.30429 .29785 m
.304 .29867 L
.30384 .2991 L
.30416 .29822 L
.30429 .29785 L
F
.304 .29867 m
.3037 .29949 L
.30352 .29998 L
.30384 .2991 L
.304 .29867 L
F
.3037 .29949 m
.30341 .30031 L
.30321 .30086 L
.30352 .29998 L
.3037 .29949 L
F
.30341 .30031 m
.30311 .30113 L
.30289 .30174 L
.30321 .30086 L
.30341 .30031 L
F
.30605 .29293 m
.30574 .29381 L
.30572 .29386 L
.30605 .29293 L
.30605 .29293 L
F
.30574 .29381 m
.30542 .29469 L
.30538 .2948 L
.30572 .29386 L
.30574 .29381 L
F
.30542 .29469 m
.3051 .29557 L
.30504 .29574 L
.30538 .2948 L
.30542 .29469 L
F
.3051 .29557 m
.30479 .29645 L
.30471 .29668 L
.30504 .29574 L
.3051 .29557 L
F
.30479 .29645 m
.30447 .29733 L
.30437 .29762 L
.30471 .29668 L
.30479 .29645 L
F
.30447 .29733 m
.30416 .29822 L
.30404 .29856 L
.30437 .29762 L
.30447 .29733 L
F
.30416 .29822 m
.30384 .2991 L
.3037 .29949 L
.30404 .29856 L
.30416 .29822 L
F
.30384 .2991 m
.30352 .29998 L
.30336 .30043 L
.3037 .29949 L
.30384 .2991 L
F
.30352 .29998 m
.30321 .30086 L
.30303 .30137 L
.30336 .30043 L
.30352 .29998 L
F
.30321 .30086 m
.30289 .30174 L
.30269 .30231 L
.30303 .30137 L
.30321 .30086 L
F
.30605 .29293 m
.30572 .29386 L
.3057 .29391 L
.30605 .29293 L
.30605 .29293 L
F
.30572 .29386 m
.30538 .2948 L
.30534 .2949 L
.3057 .29391 L
.30572 .29386 L
F
.30538 .2948 m
.30504 .29574 L
.30499 .29589 L
.30534 .2949 L
.30538 .2948 L
F
.30504 .29574 m
.30471 .29668 L
.30464 .29688 L
.30499 .29589 L
.30504 .29574 L
F
.30471 .29668 m
.30437 .29762 L
.30428 .29787 L
.30464 .29688 L
.30471 .29668 L
F
.30437 .29762 m
.30404 .29856 L
.30393 .29886 L
.30428 .29787 L
.30437 .29762 L
F
.30404 .29856 m
.3037 .29949 L
.30357 .29985 L
.30393 .29886 L
.30404 .29856 L
F
.3037 .29949 m
.30336 .30043 L
.30322 .30084 L
.30357 .29985 L
.3037 .29949 L
F
.30336 .30043 m
.30303 .30137 L
.30286 .30183 L
.30322 .30084 L
.30336 .30043 L
F
.30303 .30137 m
.30269 .30231 L
.30251 .30281 L
.30286 .30183 L
.30303 .30137 L
F
.30605 .29293 m
.3057 .29391 L
.30568 .29396 L
.30605 .29293 L
.30605 .29293 L
F
.3057 .29391 m
.30534 .2949 L
.30531 .29499 L
.30568 .29396 L
.3057 .29391 L
F
.30534 .2949 m
.30499 .29589 L
.30494 .29603 L
.30531 .29499 L
.30534 .2949 L
F
.30499 .29589 m
.30464 .29688 L
.30457 .29706 L
.30494 .29603 L
.30499 .29589 L
F
.30464 .29688 m
.30428 .29787 L
.3042 .29809 L
.30457 .29706 L
.30464 .29688 L
F
.30428 .29787 m
.30393 .29886 L
.30383 .29913 L
.3042 .29809 L
.30428 .29787 L
F
.30393 .29886 m
.30357 .29985 L
.30346 .30016 L
.30383 .29913 L
.30393 .29886 L
F
.30357 .29985 m
.30322 .30084 L
.30309 .30119 L
.30346 .30016 L
.30357 .29985 L
F
.30322 .30084 m
.30286 .30183 L
.30272 .30223 L
.30309 .30119 L
.30322 .30084 L
F
.30286 .30183 m
.30251 .30281 L
.30235 .30326 L
.30272 .30223 L
.30286 .30183 L
F
.30605 .29293 m
.30568 .29396 L
.30567 .294 L
.30605 .29293 L
.30605 .29293 L
F
.30568 .29396 m
.30531 .29499 L
.30528 .29507 L
.30567 .294 L
.30568 .29396 L
F
.30531 .29499 m
.30494 .29603 L
.3049 .29614 L
.30528 .29507 L
.30531 .29499 L
F
.30494 .29603 m
.30457 .29706 L
.30452 .29721 L
.3049 .29614 L
.30494 .29603 L
F
.30457 .29706 m
.3042 .29809 L
.30413 .29828 L
.30452 .29721 L
.30457 .29706 L
F
.3042 .29809 m
.30383 .29913 L
.30375 .29935 L
.30413 .29828 L
.3042 .29809 L
F
.30383 .29913 m
.30346 .30016 L
.30336 .30043 L
.30375 .29935 L
.30383 .29913 L
F
.30346 .30016 m
.30309 .30119 L
.30298 .3015 L
.30336 .30043 L
.30346 .30016 L
F
.30309 .30119 m
.30272 .30223 L
.3026 .30257 L
.30298 .3015 L
.30309 .30119 L
F
.30272 .30223 m
.30235 .30326 L
.30221 .30364 L
.3026 .30257 L
.30272 .30223 L
F
.30605 .29293 m
.30567 .294 L
.30566 .29403 L
.30605 .29293 L
.30605 .29293 L
F
.30567 .294 m
.30528 .29507 L
.30526 .29513 L
.30566 .29403 L
.30567 .294 L
F
.30528 .29507 m
.3049 .29614 L
.30487 .29623 L
.30526 .29513 L
.30528 .29507 L
F
.3049 .29614 m
.30452 .29721 L
.30447 .29734 L
.30487 .29623 L
.3049 .29614 L
F
.30452 .29721 m
.30413 .29828 L
.30408 .29844 L
.30447 .29734 L
.30452 .29721 L
F
.30413 .29828 m
.30375 .29935 L
.30368 .29954 L
.30408 .29844 L
.30413 .29828 L
F
.30375 .29935 m
.30336 .30043 L
.30329 .30065 L
.30368 .29954 L
.30375 .29935 L
F
.30336 .30043 m
.30298 .3015 L
.30289 .30175 L
.30329 .30065 L
.30336 .30043 L
F
.30298 .3015 m
.3026 .30257 L
.3025 .30285 L
.30289 .30175 L
.30298 .3015 L
F
.3026 .30257 m
.30221 .30364 L
.3021 .30396 L
.3025 .30285 L
.3026 .30257 L
F
.30605 .29293 m
.30566 .29403 L
.30565 .29405 L
.30605 .29293 L
.30605 .29293 L
F
.30566 .29403 m
.30526 .29513 L
.30524 .29518 L
.30565 .29405 L
.30566 .29403 L
F
.30526 .29513 m
.30487 .29623 L
.30484 .29631 L
.30524 .29518 L
.30526 .29513 L
F
.30487 .29623 m
.30447 .29734 L
.30444 .29744 L
.30484 .29631 L
.30487 .29623 L
F
.30447 .29734 m
.30408 .29844 L
.30403 .29856 L
.30444 .29744 L
.30447 .29734 L
F
.30408 .29844 m
.30368 .29954 L
.30363 .29969 L
.30403 .29856 L
.30408 .29844 L
F
.30368 .29954 m
.30329 .30065 L
.30322 .30082 L
.30363 .29969 L
.30368 .29954 L
F
.30329 .30065 m
.30289 .30175 L
.30282 .30195 L
.30322 .30082 L
.30329 .30065 L
F
.30289 .30175 m
.3025 .30285 L
.30242 .30307 L
.30282 .30195 L
.30289 .30175 L
F
.3025 .30285 m
.3021 .30396 L
.30201 .3042 L
.30242 .30307 L
.3025 .30285 L
F
.30605 .29293 m
.30565 .29405 L
.30564 .29407 L
.30605 .29293 L
.30605 .29293 L
F
.30565 .29405 m
.30524 .29518 L
.30523 .29522 L
.30564 .29407 L
.30565 .29405 L
F
.30524 .29518 m
.30484 .29631 L
.30482 .29636 L
.30523 .29522 L
.30524 .29518 L
F
.30484 .29631 m
.30444 .29744 L
.30441 .29751 L
.30482 .29636 L
.30484 .29631 L
F
.30444 .29744 m
.30403 .29856 L
.304 .29865 L
.30441 .29751 L
.30444 .29744 L
F
.30403 .29856 m
.30363 .29969 L
.30359 .2998 L
.304 .29865 L
.30403 .29856 L
F
.30363 .29969 m
.30322 .30082 L
.30318 .30094 L
.30359 .2998 L
.30363 .29969 L
F
.30322 .30082 m
.30282 .30195 L
.30277 .30209 L
.30318 .30094 L
.30322 .30082 L
F
.30282 .30195 m
.30242 .30307 L
.30236 .30323 L
.30277 .30209 L
.30282 .30195 L
F
.30242 .30307 m
.30201 .3042 L
.30195 .30438 L
.30236 .30323 L
.30242 .30307 L
F
.30605 .29293 m
.30564 .29407 L
.30564 .29408 L
.30605 .29293 L
.30605 .29293 L
F
.30564 .29407 m
.30523 .29522 L
.30522 .29524 L
.30564 .29408 L
.30564 .29407 L
F
.30523 .29522 m
.30482 .29636 L
.30481 .29639 L
.30522 .29524 L
.30523 .29522 L
F
.30482 .29636 m
.30441 .29751 L
.3044 .29755 L
.30481 .29639 L
.30482 .29636 L
F
.30441 .29751 m
.304 .29865 L
.30398 .29871 L
.3044 .29755 L
.30441 .29751 L
F
.304 .29865 m
.30359 .2998 L
.30357 .29986 L
.30398 .29871 L
.304 .29865 L
F
.30359 .2998 m
.30318 .30094 L
.30315 .30102 L
.30357 .29986 L
.30359 .2998 L
F
.30318 .30094 m
.30277 .30209 L
.30274 .30217 L
.30315 .30102 L
.30318 .30094 L
F
.30277 .30209 m
.30236 .30323 L
.30232 .30333 L
.30274 .30217 L
.30277 .30209 L
F
.30236 .30323 m
.30195 .30438 L
.30191 .30449 L
.30232 .30333 L
.30236 .30323 L
F
.30605 .29293 m
.30564 .29408 L
.30564 .29409 L
.30605 .29293 L
.30605 .29293 L
F
.30564 .29408 m
.30522 .29524 L
.30522 .29525 L
.30564 .29409 L
.30564 .29408 L
F
.30522 .29524 m
.30481 .29639 L
.30481 .2964 L
.30522 .29525 L
.30522 .29524 L
F
.30481 .29639 m
.3044 .29755 L
.30439 .29756 L
.30481 .2964 L
.30481 .29639 L
F
.3044 .29755 m
.30398 .29871 L
.30397 .29872 L
.30439 .29756 L
.3044 .29755 L
F
.30398 .29871 m
.30357 .29986 L
.30356 .29988 L
.30397 .29872 L
.30398 .29871 L
F
.30357 .29986 m
.30315 .30102 L
.30314 .30104 L
.30356 .29988 L
.30357 .29986 L
F
.30315 .30102 m
.30274 .30217 L
.30273 .3022 L
.30314 .30104 L
.30315 .30102 L
F
.30274 .30217 m
.30232 .30333 L
.30231 .30336 L
.30273 .3022 L
.30274 .30217 L
F
.30232 .30333 m
.30191 .30449 L
.3019 .30452 L
.30231 .30336 L
.30232 .30333 L
F
0 g
.3019 .30452 m
.30191 .30449 L
.30195 .30438 L
.30201 .3042 L
.3021 .30396 L
.30221 .30364 L
.30235 .30326 L
.30251 .30281 L
.30269 .30231 L
.30289 .30174 L
.30311 .30113 L
.30335 .30046 L
.30361 .29974 L
.30388 .29899 L
.30417 .29819 L
.30446 .29736 L
.30477 .29651 L
.30508 .29563 L
.3054 .29474 L
.30573 .29384 L
.30605 .29293 L
.30638 .29202 L
.3067 .29111 L
.30702 .29022 L
.30734 .28934 L
.30764 .28849 L
.30794 .28766 L
.30822 .28687 L
.3085 .28611 L
.30875 .28539 L
.30899 .28472 L
.30921 .28411 L
.30941 .28354 L
.3096 .28304 L
.30976 .28259 L
.30989 .28221 L
.31 .2819 L
.31009 .28165 L
.31016 .28147 L
.3102 .28136 L
.31021 .28133 L
.3102 .28136 L
.31016 .28147 L
.31009 .28165 L
.31 .2819 L
.30989 .28221 L
.30976 .28259 L
.3096 .28304 L
.30941 .28354 L
.30921 .28411 L
Mistroke
.30899 .28472 L
.30875 .28539 L
.3085 .28611 L
.30822 .28687 L
.30794 .28766 L
.30764 .28849 L
.30734 .28934 L
.30702 .29022 L
.3067 .29111 L
.30638 .29202 L
.30605 .29293 L
.30573 .29384 L
.3054 .29474 L
.30508 .29563 L
.30477 .29651 L
.30446 .29736 L
.30417 .29819 L
.30388 .29899 L
.30361 .29974 L
.30335 .30046 L
.30311 .30113 L
.30289 .30174 L
.30269 .30231 L
.30251 .30281 L
.30235 .30326 L
.30221 .30364 L
.3021 .30396 L
.30201 .3042 L
.30195 .30438 L
.30191 .30449 L
.3019 .30452 L
Mfstroke
.5 g
.29622 .30249 m
.3019 .30452 L
.30191 .30449 L
.29623 .30245 L
.29622 .30249 L
F
.29623 .30245 m
.30191 .30449 L
.30195 .30438 L
.29627 .30234 L
.29623 .30245 L
F
.29627 .30234 m
.30195 .30438 L
.30201 .3042 L
.29633 .30217 L
.29627 .30234 L
F
.29633 .30217 m
.30201 .3042 L
.3021 .30396 L
.29642 .30192 L
.29633 .30217 L
F
.29642 .30192 m
.3021 .30396 L
.30221 .30364 L
.29653 .3016 L
.29642 .30192 L
F
.29653 .3016 m
.30221 .30364 L
.30235 .30326 L
.29667 .30122 L
.29653 .3016 L
F
.29667 .30122 m
.30235 .30326 L
.30251 .30281 L
.29683 .30078 L
.29667 .30122 L
F
.29683 .30078 m
.30251 .30281 L
.30269 .30231 L
.29701 .30027 L
.29683 .30078 L
F
.29701 .30027 m
.30269 .30231 L
.30289 .30174 L
.29721 .29971 L
.29701 .30027 L
F
.29721 .29971 m
.30289 .30174 L
.30311 .30113 L
.29743 .29909 L
.29721 .29971 L
F
.29743 .29909 m
.30311 .30113 L
.30335 .30046 L
.29767 .29842 L
.29743 .29909 L
F
.29767 .29842 m
.30335 .30046 L
.30361 .29974 L
.29793 .29771 L
.29767 .29842 L
F
.29793 .29771 m
.30361 .29974 L
.30388 .29899 L
.2982 .29695 L
.29793 .29771 L
F
.2982 .29695 m
.30388 .29899 L
.30417 .29819 L
.29849 .29616 L
.2982 .29695 L
F
.29849 .29616 m
.30417 .29819 L
.30446 .29736 L
.29878 .29533 L
.29849 .29616 L
F
.29878 .29533 m
.30446 .29736 L
.30477 .29651 L
.29909 .29447 L
.29878 .29533 L
F
.29909 .29447 m
.30477 .29651 L
.30508 .29563 L
.2994 .2936 L
.29909 .29447 L
F
.2994 .2936 m
.30508 .29563 L
.3054 .29474 L
.29972 .2927 L
.2994 .2936 L
F
.29972 .2927 m
.3054 .29474 L
.30573 .29384 L
.30005 .2918 L
.29972 .2927 L
F
.30005 .2918 m
.30573 .29384 L
.30605 .29293 L
.30037 .29089 L
.30005 .2918 L
F
.30037 .29089 m
.30605 .29293 L
.30638 .29202 L
.3007 .28998 L
.30037 .29089 L
F
.3007 .28998 m
.30638 .29202 L
.3067 .29111 L
.30102 .28908 L
.3007 .28998 L
F
.30102 .28908 m
.3067 .29111 L
.30702 .29022 L
.30134 .28818 L
.30102 .28908 L
F
.30134 .28818 m
.30702 .29022 L
.30734 .28934 L
.30166 .28731 L
.30134 .28818 L
F
.30166 .28731 m
.30734 .28934 L
.30764 .28849 L
.30196 .28645 L
.30166 .28731 L
F
.30196 .28645 m
.30764 .28849 L
.30794 .28766 L
.30226 .28562 L
.30196 .28645 L
F
.30226 .28562 m
.30794 .28766 L
.30822 .28687 L
.30254 .28483 L
.30226 .28562 L
F
.30254 .28483 m
.30822 .28687 L
.3085 .28611 L
.30281 .28407 L
.30254 .28483 L
F
.30281 .28407 m
.3085 .28611 L
.30875 .28539 L
.30307 .28336 L
.30281 .28407 L
F
.30307 .28336 m
.30875 .28539 L
.30899 .28472 L
.30331 .28269 L
.30307 .28336 L
F
.30331 .28269 m
.30899 .28472 L
.30921 .28411 L
.30353 .28207 L
.30331 .28269 L
F
.30353 .28207 m
.30921 .28411 L
.30941 .28354 L
.30373 .28151 L
.30353 .28207 L
F
.30373 .28151 m
.30941 .28354 L
.3096 .28304 L
.30392 .281 L
.30373 .28151 L
F
.30392 .281 m
.3096 .28304 L
.30976 .28259 L
.30407 .28056 L
.30392 .281 L
F
.30407 .28056 m
.30976 .28259 L
.30989 .28221 L
.30421 .28018 L
.30407 .28056 L
F
.30421 .28018 m
.30989 .28221 L
.31 .2819 L
.30432 .27986 L
.30421 .28018 L
F
.30432 .27986 m
.31 .2819 L
.31009 .28165 L
.30441 .27961 L
.30432 .27986 L
F
.30441 .27961 m
.31009 .28165 L
.31016 .28147 L
.30448 .27944 L
.30441 .27961 L
F
.30448 .27944 m
.31016 .28147 L
.3102 .28136 L
.30451 .27933 L
.30448 .27944 L
F
.30451 .27933 m
.3102 .28136 L
.31021 .28133 L
.30453 .27929 L
.30451 .27933 L
F
.30453 .27929 m
.31021 .28133 L
.3102 .28136 L
.30451 .27933 L
.30453 .27929 L
F
.30451 .27933 m
.3102 .28136 L
.31016 .28147 L
.30448 .27944 L
.30451 .27933 L
F
.30448 .27944 m
.31016 .28147 L
.31009 .28165 L
.30441 .27961 L
.30448 .27944 L
F
.30441 .27961 m
.31009 .28165 L
.31 .2819 L
.30432 .27986 L
.30441 .27961 L
F
.30432 .27986 m
.31 .2819 L
.30989 .28221 L
.30421 .28018 L
.30432 .27986 L
F
.30421 .28018 m
.30989 .28221 L
.30976 .28259 L
.30407 .28056 L
.30421 .28018 L
F
.30407 .28056 m
.30976 .28259 L
.3096 .28304 L
.30392 .281 L
.30407 .28056 L
F
.30392 .281 m
.3096 .28304 L
.30941 .28354 L
.30373 .28151 L
.30392 .281 L
F
.30373 .28151 m
.30941 .28354 L
.30921 .28411 L
.30353 .28207 L
.30373 .28151 L
F
.30353 .28207 m
.30921 .28411 L
.30899 .28472 L
.30331 .28269 L
.30353 .28207 L
F
.30331 .28269 m
.30899 .28472 L
.30875 .28539 L
.30307 .28336 L
.30331 .28269 L
F
.30307 .28336 m
.30875 .28539 L
.3085 .28611 L
.30281 .28407 L
.30307 .28336 L
F
.30281 .28407 m
.3085 .28611 L
.30822 .28687 L
.30254 .28483 L
.30281 .28407 L
F
.30254 .28483 m
.30822 .28687 L
.30794 .28766 L
.30226 .28562 L
.30254 .28483 L
F
.30226 .28562 m
.30794 .28766 L
.30764 .28849 L
.30196 .28645 L
.30226 .28562 L
F
.30196 .28645 m
.30764 .28849 L
.30734 .28934 L
.30166 .28731 L
.30196 .28645 L
F
.30166 .28731 m
.30734 .28934 L
.30702 .29022 L
.30134 .28818 L
.30166 .28731 L
F
.30134 .28818 m
.30702 .29022 L
.3067 .29111 L
.30102 .28908 L
.30134 .28818 L
F
.30102 .28908 m
.3067 .29111 L
.30638 .29202 L
.3007 .28998 L
.30102 .28908 L
F
.3007 .28998 m
.30638 .29202 L
.30605 .29293 L
.30037 .29089 L
.3007 .28998 L
F
.30037 .29089 m
.30605 .29293 L
.30573 .29384 L
.30005 .2918 L
.30037 .29089 L
F
.30005 .2918 m
.30573 .29384 L
.3054 .29474 L
.29972 .2927 L
.30005 .2918 L
F
.29972 .2927 m
.3054 .29474 L
.30508 .29563 L
.2994 .2936 L
.29972 .2927 L
F
.2994 .2936 m
.30508 .29563 L
.30477 .29651 L
.29909 .29447 L
.2994 .2936 L
F
.29909 .29447 m
.30477 .29651 L
.30446 .29736 L
.29878 .29533 L
.29909 .29447 L
F
.29878 .29533 m
.30446 .29736 L
.30417 .29819 L
.29849 .29616 L
.29878 .29533 L
F
.29849 .29616 m
.30417 .29819 L
.30388 .29899 L
.2982 .29695 L
.29849 .29616 L
F
.2982 .29695 m
.30388 .29899 L
.30361 .29974 L
.29793 .29771 L
.2982 .29695 L
F
.29793 .29771 m
.30361 .29974 L
.30335 .30046 L
.29767 .29842 L
.29793 .29771 L
F
.29767 .29842 m
.30335 .30046 L
.30311 .30113 L
.29743 .29909 L
.29767 .29842 L
F
.29743 .29909 m
.30311 .30113 L
.30289 .30174 L
.29721 .29971 L
.29743 .29909 L
F
.29721 .29971 m
.30289 .30174 L
.30269 .30231 L
.29701 .30027 L
.29721 .29971 L
F
.29701 .30027 m
.30269 .30231 L
.30251 .30281 L
.29683 .30078 L
.29701 .30027 L
F
.29683 .30078 m
.30251 .30281 L
.30235 .30326 L
.29667 .30122 L
.29683 .30078 L
F
.29667 .30122 m
.30235 .30326 L
.30221 .30364 L
.29653 .3016 L
.29667 .30122 L
F
.29653 .3016 m
.30221 .30364 L
.3021 .30396 L
.29642 .30192 L
.29653 .3016 L
F
.29642 .30192 m
.3021 .30396 L
.30201 .3042 L
.29633 .30217 L
.29642 .30192 L
F
.29633 .30217 m
.30201 .3042 L
.30195 .30438 L
.29627 .30234 L
.29633 .30217 L
F
.29627 .30234 m
.30195 .30438 L
.30191 .30449 L
.29623 .30245 L
.29627 .30234 L
F
.29623 .30245 m
.30191 .30449 L
.3019 .30452 L
.29622 .30249 L
.29623 .30245 L
F
.62481 .06461 m
.62352 .05156 L
.60192 .05689 L
.60767 .06864 L
.62481 .06461 L
F
.60767 .06864 m
.60192 .05689 L
.5932 .06222 L
.60107 .07266 L
.60767 .06864 L
F
.60107 .07266 m
.5932 .06222 L
.58712 .06755 L
.59648 .07668 L
.60107 .07266 L
F
.59648 .07668 m
.58712 .06755 L
.58255 .07287 L
.59302 .0807 L
.59648 .07668 L
F
.59302 .0807 m
.58255 .07287 L
.57904 .0782 L
.59037 .08473 L
.59302 .0807 L
F
.59037 .08473 m
.57904 .0782 L
.57635 .08353 L
.58834 .08875 L
.59037 .08473 L
F
.58834 .08875 m
.57635 .08353 L
.57436 .08886 L
.58683 .09277 L
.58834 .08875 L
F
.58683 .09277 m
.57436 .08886 L
.57298 .09418 L
.58579 .09679 L
.58683 .09277 L
F
.58579 .09679 m
.57298 .09418 L
.57217 .09951 L
.58518 .10082 L
.58579 .09679 L
F
.58518 .10082 m
.57217 .09951 L
.57191 .10484 L
.58498 .10484 L
.58518 .10082 L
F
.58498 .10484 m
.57191 .10484 L
.57217 .11017 L
.58518 .10886 L
.58498 .10484 L
F
.58518 .10886 m
.57217 .11017 L
.57298 .11549 L
.58579 .11288 L
.58518 .10886 L
F
.58579 .11288 m
.57298 .11549 L
.57436 .12082 L
.58683 .11691 L
.58579 .11288 L
F
.58683 .11691 m
.57436 .12082 L
.57635 .12615 L
.58834 .12093 L
.58683 .11691 L
F
.58834 .12093 m
.57635 .12615 L
.57904 .13148 L
.59037 .12495 L
.58834 .12093 L
F
.59037 .12495 m
.57904 .13148 L
.58255 .1368 L
.59302 .12897 L
.59037 .12495 L
F
.59302 .12897 m
.58255 .1368 L
.58712 .14213 L
.59648 .133 L
.59302 .12897 L
F
.59648 .133 m
.58712 .14213 L
.5932 .14746 L
.60107 .13702 L
.59648 .133 L
F
.60107 .13702 m
.5932 .14746 L
.60192 .15279 L
.60767 .14104 L
.60107 .13702 L
F
.60767 .14104 m
.60192 .15279 L
.62352 .15811 L
.62481 .14506 L
.60767 .14104 L
F
0 g
.62481 .06461 m
.60767 .06864 L
.60107 .07266 L
.59648 .07668 L
.59302 .0807 L
.59037 .08473 L
.58834 .08875 L
.58683 .09277 L
.58579 .09679 L
.58518 .10082 L
.58498 .10484 L
.58518 .10886 L
.58579 .11288 L
.58683 .11691 L
.58834 .12093 L
.59037 .12495 L
.59302 .12897 L
.59648 .133 L
.60107 .13702 L
.60767 .14104 L
.62481 .14506 L
.62352 .15811 L
.60192 .15279 L
.5932 .14746 L
.58712 .14213 L
.58255 .1368 L
.57904 .13148 L
.57635 .12615 L
.57436 .12082 L
.57298 .11549 L
.57217 .11017 L
.57191 .10484 L
.57217 .09951 L
.57298 .09418 L
.57436 .08886 L
.57635 .08353 L
.57904 .0782 L
.58255 .07287 L
.58712 .06755 L
.5932 .06222 L
.60192 .05689 L
.62352 .05156 L
.62481 .06461 L
s
.5 g
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
.58498 .10484 m
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
.58498 .10484 L
F
0 g
.58498 .10484 m
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.58498 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.57191 .10484 L
.58498 .10484 L
s
.62481 .06461 m
.62352 .05156 L
.60192 .05689 L
.60767 .06864 L
.62481 .06461 L
s
.60767 .06864 m
.60192 .05689 L
.5932 .06222 L
.60107 .07266 L
.60767 .06864 L
s
.60107 .07266 m
.5932 .06222 L
.58712 .06755 L
.59648 .07668 L
.60107 .07266 L
s
.59648 .07668 m
.58712 .06755 L
.58255 .07287 L
.59302 .0807 L
.59648 .07668 L
s
.59302 .0807 m
.58255 .07287 L
.57904 .0782 L
.59037 .08473 L
.59302 .0807 L
s
.59037 .08473 m
.57904 .0782 L
.57635 .08353 L
.58834 .08875 L
.59037 .08473 L
s
.58834 .08875 m
.57635 .08353 L
.57436 .08886 L
.58683 .09277 L
.58834 .08875 L
s
.58683 .09277 m
.57436 .08886 L
.57298 .09418 L
.58579 .09679 L
.58683 .09277 L
s
.58579 .09679 m
.57298 .09418 L
.57217 .09951 L
.58518 .10082 L
.58579 .09679 L
s
.58518 .10082 m
.57217 .09951 L
.57191 .10484 L
.58498 .10484 L
.58518 .10082 L
s
.58498 .10484 m
.57191 .10484 L
.57217 .11017 L
.58518 .10886 L
.58498 .10484 L
s
.58518 .10886 m
.57217 .11017 L
.57298 .11549 L
.58579 .11288 L
.58518 .10886 L
s
.58579 .11288 m
.57298 .11549 L
.57436 .12082 L
.58683 .11691 L
.58579 .11288 L
s
.58683 .11691 m
.57436 .12082 L
.57635 .12615 L
.58834 .12093 L
.58683 .11691 L
s
.58834 .12093 m
.57635 .12615 L
.57904 .13148 L
.59037 .12495 L
.58834 .12093 L
s
.59037 .12495 m
.57904 .13148 L
.58255 .1368 L
.59302 .12897 L
.59037 .12495 L
s
.59302 .12897 m
.58255 .1368 L
.58712 .14213 L
.59648 .133 L
.59302 .12897 L
s
.59648 .133 m
.58712 .14213 L
.5932 .14746 L
.60107 .13702 L
.59648 .133 L
s
.60107 .13702 m
.5932 .14746 L
.60192 .15279 L
.60767 .14104 L
.60107 .13702 L
s
.60767 .14104 m
.60192 .15279 L
.62352 .15811 L
.62481 .14506 L
.60767 .14104 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.62352 .15811 L
.62481 .14506 L
.62481 .14506 L
s
.62481 .14506 m
.62352 .15811 L
.60192 .15279 L
.60767 .14104 L
.62481 .14506 L
s
.60767 .14104 m
.60192 .15279 L
.5932 .14746 L
.60107 .13702 L
.60767 .14104 L
s
.60107 .13702 m
.5932 .14746 L
.58712 .14213 L
.59648 .133 L
.60107 .13702 L
s
.59648 .133 m
.58712 .14213 L
.58255 .1368 L
.59302 .12897 L
.59648 .133 L
s
.59302 .12897 m
.58255 .1368 L
.57904 .13148 L
.59037 .12495 L
.59302 .12897 L
s
.59037 .12495 m
.57904 .13148 L
.57635 .12615 L
.58834 .12093 L
.59037 .12495 L
s
.58834 .12093 m
.57635 .12615 L
.57436 .12082 L
.58683 .11691 L
.58834 .12093 L
s
.58683 .11691 m
.57436 .12082 L
.57298 .11549 L
.58579 .11288 L
.58683 .11691 L
s
.58579 .11288 m
.57298 .11549 L
.57217 .11017 L
.58518 .10886 L
.58579 .11288 L
s
.58518 .10886 m
.57217 .11017 L
.57191 .10484 L
.58498 .10484 L
.58518 .10886 L
s
.58498 .10484 m
.57191 .10484 L
.57217 .09951 L
.58518 .10082 L
.58498 .10484 L
s
.58518 .10082 m
.57217 .09951 L
.57298 .09418 L
.58579 .09679 L
.58518 .10082 L
s
.58579 .09679 m
.57298 .09418 L
.57436 .08886 L
.58683 .09277 L
.58579 .09679 L
s
.58683 .09277 m
.57436 .08886 L
.57635 .08353 L
.58834 .08875 L
.58683 .09277 L
s
.58834 .08875 m
.57635 .08353 L
.57904 .0782 L
.59037 .08473 L
.58834 .08875 L
s
.59037 .08473 m
.57904 .0782 L
.58255 .07287 L
.59302 .0807 L
.59037 .08473 L
s
.59302 .0807 m
.58255 .07287 L
.58712 .06755 L
.59648 .07668 L
.59302 .0807 L
s
.59648 .07668 m
.58712 .06755 L
.5932 .06222 L
.60107 .07266 L
.59648 .07668 L
s
.60107 .07266 m
.5932 .06222 L
.60192 .05689 L
.60767 .06864 L
.60107 .07266 L
s
.60767 .06864 m
.60192 .05689 L
.62352 .05156 L
.62481 .06461 L
.60767 .06864 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.62481 .06461 m
.62352 .05156 L
.62352 .05156 L
.62481 .06461 L
.62481 .06461 L
s
.5 g
.55682 .13752 m
.55682 .16267 L
.55682 .16267 L
.55682 .13752 L
.55682 .13752 L
F
0 g
.55682 .13752 m
.55682 .16267 L
.55682 .16267 L
.55682 .13752 L
.55682 .13752 L
s
.5 g
.55682 .04701 m
.55682 .07215 L
.55682 .07215 L
.55682 .04701 L
.55682 .04701 L
F
0 g
.55682 .04701 m
.55682 .07215 L
.55682 .07215 L
.55682 .04701 L
.55682 .04701 L
s
.5 g
.54727 .04098 m
.54878 .04098 L
.54878 .04736 L
.54727 .04736 L
.54727 .04098 L
F
.54727 .04736 m
.54878 .04736 L
.54878 .05375 L
.54727 .05375 L
.54727 .04736 L
F
.54727 .05375 m
.54878 .05375 L
.54878 .06014 L
.54727 .06014 L
.54727 .05375 L
F
.54727 .06014 m
.54878 .06014 L
.54878 .06652 L
.54727 .06652 L
.54727 .06014 L
F
.54727 .06652 m
.54878 .06652 L
.54878 .07291 L
.54727 .07291 L
.54727 .06652 L
F
.54727 .07291 m
.54878 .07291 L
.54878 .07929 L
.54727 .07929 L
.54727 .07291 L
F
.54727 .07929 m
.54878 .07929 L
.54878 .08568 L
.54727 .08568 L
.54727 .07929 L
F
.54727 .08568 m
.54878 .08568 L
.54878 .09207 L
.54727 .09207 L
.54727 .08568 L
F
.54727 .09207 m
.54878 .09207 L
.54878 .09845 L
.54727 .09845 L
.54727 .09207 L
F
.54727 .09845 m
.54878 .09845 L
.54878 .10484 L
.54727 .10484 L
.54727 .09845 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .11122 L
.54727 .11122 L
.54727 .10484 L
F
.54727 .11122 m
.54878 .11122 L
.54878 .11761 L
.54727 .11761 L
.54727 .11122 L
F
.54727 .11761 m
.54878 .11761 L
.54878 .124 L
.54727 .124 L
.54727 .11761 L
F
.54727 .124 m
.54878 .124 L
.54878 .13038 L
.54727 .13038 L
.54727 .124 L
F
.54727 .13038 m
.54878 .13038 L
.54878 .13677 L
.54727 .13677 L
.54727 .13038 L
F
.54727 .13677 m
.54878 .13677 L
.54878 .14316 L
.54727 .14316 L
.54727 .13677 L
F
.54727 .14316 m
.54878 .14316 L
.54878 .14954 L
.54727 .14954 L
.54727 .14316 L
F
.54727 .14954 m
.54878 .14954 L
.54878 .15593 L
.54727 .15593 L
.54727 .14954 L
F
.54727 .15593 m
.54878 .15593 L
.54878 .16231 L
.54727 .16231 L
.54727 .15593 L
F
.54727 .16231 m
.54878 .16231 L
.54878 .1687 L
.54727 .1687 L
.54727 .16231 L
F
0 g
.54727 .04098 m
.54727 .04736 L
.54727 .05375 L
.54727 .06014 L
.54727 .06652 L
.54727 .07291 L
.54727 .07929 L
.54727 .08568 L
.54727 .09207 L
.54727 .09845 L
.54727 .10484 L
.54727 .11122 L
.54727 .11761 L
.54727 .124 L
.54727 .13038 L
.54727 .13677 L
.54727 .14316 L
.54727 .14954 L
.54727 .15593 L
.54727 .16231 L
.54727 .1687 L
.54878 .1687 L
.54878 .16231 L
.54878 .15593 L
.54878 .14954 L
.54878 .14316 L
.54878 .13677 L
.54878 .13038 L
.54878 .124 L
.54878 .11761 L
.54878 .11122 L
.54878 .10484 L
.54878 .09845 L
.54878 .09207 L
.54878 .08568 L
.54878 .07929 L
.54878 .07291 L
.54878 .06652 L
.54878 .06014 L
.54878 .05375 L
.54878 .04736 L
.54878 .04098 L
.54727 .04098 L
s
.5 g
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
.54727 .10484 m
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
.54727 .10484 L
F
0 g
.54727 .10484 m
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54727 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54878 .10484 L
.54727 .10484 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04736 L
.54727 .04736 L
.54727 .04098 L
s
.54727 .04736 m
.54878 .04736 L
.54878 .05375 L
.54727 .05375 L
.54727 .04736 L
s
.54727 .05375 m
.54878 .05375 L
.54878 .06014 L
.54727 .06014 L
.54727 .05375 L
s
.54727 .06014 m
.54878 .06014 L
.54878 .06652 L
.54727 .06652 L
.54727 .06014 L
s
.54727 .06652 m
.54878 .06652 L
.54878 .07291 L
.54727 .07291 L
.54727 .06652 L
s
.54727 .07291 m
.54878 .07291 L
.54878 .07929 L
.54727 .07929 L
.54727 .07291 L
s
.54727 .07929 m
.54878 .07929 L
.54878 .08568 L
.54727 .08568 L
.54727 .07929 L
s
.54727 .08568 m
.54878 .08568 L
.54878 .09207 L
.54727 .09207 L
.54727 .08568 L
s
.54727 .09207 m
.54878 .09207 L
.54878 .09845 L
.54727 .09845 L
.54727 .09207 L
s
.54727 .09845 m
.54878 .09845 L
.54878 .10484 L
.54727 .10484 L
.54727 .09845 L
s
.54727 .10484 m
.54878 .10484 L
.54878 .11122 L
.54727 .11122 L
.54727 .10484 L
s
.54727 .11122 m
.54878 .11122 L
.54878 .11761 L
.54727 .11761 L
.54727 .11122 L
s
.54727 .11761 m
.54878 .11761 L
.54878 .124 L
.54727 .124 L
.54727 .11761 L
s
.54727 .124 m
.54878 .124 L
.54878 .13038 L
.54727 .13038 L
.54727 .124 L
s
.54727 .13038 m
.54878 .13038 L
.54878 .13677 L
.54727 .13677 L
.54727 .13038 L
s
.54727 .13677 m
.54878 .13677 L
.54878 .14316 L
.54727 .14316 L
.54727 .13677 L
s
.54727 .14316 m
.54878 .14316 L
.54878 .14954 L
.54727 .14954 L
.54727 .14316 L
s
.54727 .14954 m
.54878 .14954 L
.54878 .15593 L
.54727 .15593 L
.54727 .14954 L
s
.54727 .15593 m
.54878 .15593 L
.54878 .16231 L
.54727 .16231 L
.54727 .15593 L
s
.54727 .16231 m
.54878 .16231 L
.54878 .1687 L
.54727 .1687 L
.54727 .16231 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .1687 L
.54727 .1687 L
.54727 .1687 L
s
.54727 .1687 m
.54878 .1687 L
.54878 .16231 L
.54727 .16231 L
.54727 .1687 L
s
.54727 .16231 m
.54878 .16231 L
.54878 .15593 L
.54727 .15593 L
.54727 .16231 L
s
.54727 .15593 m
.54878 .15593 L
.54878 .14954 L
.54727 .14954 L
.54727 .15593 L
s
.54727 .14954 m
.54878 .14954 L
.54878 .14316 L
.54727 .14316 L
.54727 .14954 L
s
.54727 .14316 m
.54878 .14316 L
.54878 .13677 L
.54727 .13677 L
.54727 .14316 L
s
.54727 .13677 m
.54878 .13677 L
.54878 .13038 L
.54727 .13038 L
.54727 .13677 L
s
.54727 .13038 m
.54878 .13038 L
.54878 .124 L
.54727 .124 L
.54727 .13038 L
s
.54727 .124 m
.54878 .124 L
.54878 .11761 L
.54727 .11761 L
.54727 .124 L
s
.54727 .11761 m
.54878 .11761 L
.54878 .11122 L
.54727 .11122 L
.54727 .11761 L
s
.54727 .11122 m
.54878 .11122 L
.54878 .10484 L
.54727 .10484 L
.54727 .11122 L
s
.54727 .10484 m
.54878 .10484 L
.54878 .09845 L
.54727 .09845 L
.54727 .10484 L
s
.54727 .09845 m
.54878 .09845 L
.54878 .09207 L
.54727 .09207 L
.54727 .09845 L
s
.54727 .09207 m
.54878 .09207 L
.54878 .08568 L
.54727 .08568 L
.54727 .09207 L
s
.54727 .08568 m
.54878 .08568 L
.54878 .07929 L
.54727 .07929 L
.54727 .08568 L
s
.54727 .07929 m
.54878 .07929 L
.54878 .07291 L
.54727 .07291 L
.54727 .07929 L
s
.54727 .07291 m
.54878 .07291 L
.54878 .06652 L
.54727 .06652 L
.54727 .07291 L
s
.54727 .06652 m
.54878 .06652 L
.54878 .06014 L
.54727 .06014 L
.54727 .06652 L
s
.54727 .06014 m
.54878 .06014 L
.54878 .05375 L
.54727 .05375 L
.54727 .06014 L
s
.54727 .05375 m
.54878 .05375 L
.54878 .04736 L
.54727 .04736 L
.54727 .05375 L
s
.54727 .04736 m
.54878 .04736 L
.54878 .04098 L
.54727 .04098 L
.54727 .04736 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.54727 .04098 m
.54878 .04098 L
.54878 .04098 L
.54727 .04098 L
.54727 .04098 L
s
.5 g
.52162 .17775 m
.51764 .17775 L
.51539 .17046 L
.52162 .17046 L
.52162 .17775 L
F
.52162 .17046 m
.51539 .17046 L
.5134 .16317 L
.52162 .16317 L
.52162 .17046 L
F
.52162 .16317 m
.5134 .16317 L
.51165 .15588 L
.52162 .15588 L
.52162 .16317 L
F
.52162 .15588 m
.51165 .15588 L
.51015 .14859 L
.52162 .14859 L
.52162 .15588 L
F
.52162 .14859 m
.51015 .14859 L
.50888 .14129 L
.52162 .14129 L
.52162 .14859 L
F
.52162 .14129 m
.50888 .14129 L
.50785 .134 L
.52162 .134 L
.52162 .14129 L
F
.52162 .134 m
.50785 .134 L
.50706 .12671 L
.52162 .12671 L
.52162 .134 L
F
.52162 .12671 m
.50706 .12671 L
.50649 .11942 L
.52162 .11942 L
.52162 .12671 L
F
.52162 .11942 m
.50649 .11942 L
.50615 .11213 L
.52162 .11213 L
.52162 .11942 L
F
.52162 .11213 m
.50615 .11213 L
.50603 .10484 L
.52162 .10484 L
.52162 .11213 L
F
.52162 .10484 m
.50603 .10484 L
.50615 .09755 L
.52162 .09755 L
.52162 .10484 L
F
.52162 .09755 m
.50615 .09755 L
.50649 .09026 L
.52162 .09026 L
.52162 .09755 L
F
.52162 .09026 m
.50649 .09026 L
.50706 .08297 L
.52162 .08297 L
.52162 .09026 L
F
.52162 .08297 m
.50706 .08297 L
.50785 .07567 L
.52162 .07567 L
.52162 .08297 L
F
.52162 .07567 m
.50785 .07567 L
.50888 .06838 L
.52162 .06838 L
.52162 .07567 L
F
.52162 .06838 m
.50888 .06838 L
.51015 .06109 L
.52162 .06109 L
.52162 .06838 L
F
.52162 .06109 m
.51015 .06109 L
.51165 .0538 L
.52162 .0538 L
.52162 .06109 L
F
.52162 .0538 m
.51165 .0538 L
.5134 .04651 L
.52162 .04651 L
.52162 .0538 L
F
.52162 .04651 m
.5134 .04651 L
.51539 .03922 L
.52162 .03922 L
.52162 .04651 L
F
.52162 .03922 m
.51539 .03922 L
.51764 .03193 L
.52162 .03193 L
.52162 .03922 L
F
0 g
.52162 .17775 m
.52162 .17046 L
.52162 .16317 L
.52162 .15588 L
.52162 .14859 L
.52162 .14129 L
.52162 .134 L
.52162 .12671 L
.52162 .11942 L
.52162 .11213 L
.52162 .10484 L
.52162 .09755 L
.52162 .09026 L
.52162 .08297 L
.52162 .07567 L
.52162 .06838 L
.52162 .06109 L
.52162 .0538 L
.52162 .04651 L
.52162 .03922 L
.52162 .03193 L
.51764 .03193 L
.51539 .03922 L
.5134 .04651 L
.51165 .0538 L
.51015 .06109 L
.50888 .06838 L
.50785 .07567 L
.50706 .08297 L
.50649 .09026 L
.50615 .09755 L
.50603 .10484 L
.50615 .11213 L
.50649 .11942 L
.50706 .12671 L
.50785 .134 L
.50888 .14129 L
.51015 .14859 L
.51165 .15588 L
.5134 .16317 L
.51539 .17046 L
.51764 .17775 L
.52162 .17775 L
s
.5 g
.52162 .10484 m
.51764 .10484 L
.51539 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.51539 .10484 L
.5134 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.5134 .10484 L
.51165 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.51165 .10484 L
.51015 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.51015 .10484 L
.50888 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50888 .10484 L
.50785 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50785 .10484 L
.50706 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50706 .10484 L
.50649 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50649 .10484 L
.50615 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50615 .10484 L
.50603 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50603 .10484 L
.50615 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50615 .10484 L
.50649 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50649 .10484 L
.50706 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50706 .10484 L
.50785 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50785 .10484 L
.50888 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.50888 .10484 L
.51015 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.51015 .10484 L
.51165 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.51165 .10484 L
.5134 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.5134 .10484 L
.51539 .10484 L
.52162 .10484 L
.52162 .10484 L
F
.52162 .10484 m
.51539 .10484 L
.51764 .10484 L
.52162 .10484 L
.52162 .10484 L
F
0 g
.52162 .10484 m
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.52162 .10484 L
.51764 .10484 L
.51539 .10484 L
.5134 .10484 L
.51165 .10484 L
.51015 .10484 L
.50888 .10484 L
.50785 .10484 L
.50706 .10484 L
.50649 .10484 L
.50615 .10484 L
.50603 .10484 L
.50615 .10484 L
.50649 .10484 L
.50706 .10484 L
.50785 .10484 L
.50888 .10484 L
.51015 .10484 L
.51165 .10484 L
.5134 .10484 L
.51539 .10484 L
.51764 .10484 L
.52162 .10484 L
s
.52162 .03193 m
.51764 .03193 L
.51764 .03215 L
.52162 .03215 L
.52162 .03193 L
s
.52162 .03215 m
.51764 .03215 L
.51764 .03282 L
.52162 .03282 L
.52162 .03215 L
s
.52162 .03282 m
.51764 .03282 L
.51764 .03394 L
.52162 .03394 L
.52162 .03282 L
s
.52162 .03394 m
.51764 .03394 L
.51764 .0355 L
.52162 .0355 L
.52162 .03394 L
s
.52162 .0355 m
.51764 .0355 L
.51764 .03748 L
.52162 .03748 L
.52162 .0355 L
s
.52162 .03748 m
.51764 .03748 L
.51764 .03987 L
.52162 .03987 L
.52162 .03748 L
s
.52162 .03987 m
.51764 .03987 L
.51764 .04267 L
.52162 .04267 L
.52162 .03987 L
s
.52162 .04267 m
.51764 .04267 L
.51764 .04585 L
.52162 .04585 L
.52162 .04267 L
s
.52162 .04585 m
.51764 .04585 L
.51764 .0494 L
.52162 .0494 L
.52162 .04585 L
s
.52162 .0494 m
.51764 .0494 L
.51764 .05328 L
.52162 .05328 L
.52162 .0494 L
s
.52162 .05328 m
.51764 .05328 L
.51764 .05749 L
.52162 .05749 L
.52162 .05328 L
s
.52162 .05749 m
.51764 .05749 L
.51764 .06198 L
.52162 .06198 L
.52162 .05749 L
s
.52162 .06198 m
.51764 .06198 L
.51764 .06674 L
.52162 .06674 L
.52162 .06198 L
s
.52162 .06674 m
.51764 .06674 L
.51764 .07174 L
.52162 .07174 L
.52162 .06674 L
s
.52162 .07174 m
.51764 .07174 L
.51764 .07694 L
.52162 .07694 L
.52162 .07174 L
s
.52162 .07694 m
.51764 .07694 L
.51764 .08231 L
.52162 .08231 L
.52162 .07694 L
s
.52162 .08231 m
.51764 .08231 L
.51764 .08782 L
.52162 .08782 L
.52162 .08231 L
s
.52162 .08782 m
.51764 .08782 L
.51764 .09343 L
.52162 .09343 L
.52162 .08782 L
s
.52162 .09343 m
.51764 .09343 L
.51764 .09912 L
.52162 .09912 L
.52162 .09343 L
s
.52162 .09912 m
.51764 .09912 L
.51764 .10484 L
.52162 .10484 L
.52162 .09912 L
s
.52162 .10484 m
.51764 .10484 L
.51764 .11056 L
.52162 .11056 L
.52162 .10484 L
s
.52162 .11056 m
.51764 .11056 L
.51764 .11624 L
.52162 .11624 L
.52162 .11056 L
s
.52162 .11624 m
.51764 .11624 L
.51764 .12186 L
.52162 .12186 L
.52162 .11624 L
s
.52162 .12186 m
.51764 .12186 L
.51764 .12737 L
.52162 .12737 L
.52162 .12186 L
s
.52162 .12737 m
.51764 .12737 L
.51764 .13274 L
.52162 .13274 L
.52162 .12737 L
s
.52162 .13274 m
.51764 .13274 L
.51764 .13794 L
.52162 .13794 L
.52162 .13274 L
s
.52162 .13794 m
.51764 .13794 L
.51764 .14294 L
.52162 .14294 L
.52162 .13794 L
s
.52162 .14294 m
.51764 .14294 L
.51764 .1477 L
.52162 .1477 L
.52162 .14294 L
s
.52162 .1477 m
.51764 .1477 L
.51764 .15219 L
.52162 .15219 L
.52162 .1477 L
s
.52162 .15219 m
.51764 .15219 L
.51764 .1564 L
.52162 .1564 L
.52162 .15219 L
s
.52162 .1564 m
.51764 .1564 L
.51764 .16028 L
.52162 .16028 L
.52162 .1564 L
s
.52162 .16028 m
.51764 .16028 L
.51764 .16383 L
.52162 .16383 L
.52162 .16028 L
s
.52162 .16383 m
.51764 .16383 L
.51764 .16701 L
.52162 .16701 L
.52162 .16383 L
s
.52162 .16701 m
.51764 .16701 L
.51764 .1698 L
.52162 .1698 L
.52162 .16701 L
s
.52162 .1698 m
.51764 .1698 L
.51764 .1722 L
.52162 .1722 L
.52162 .1698 L
s
.52162 .1722 m
.51764 .1722 L
.51764 .17418 L
.52162 .17418 L
.52162 .1722 L
s
.52162 .17418 m
.51764 .17418 L
.51764 .17574 L
.52162 .17574 L
.52162 .17418 L
s
.52162 .17574 m
.51764 .17574 L
.51764 .17685 L
.52162 .17685 L
.52162 .17574 L
s
.52162 .17685 m
.51764 .17685 L
.51764 .17753 L
.52162 .17753 L
.52162 .17685 L
s
.52162 .17753 m
.51764 .17753 L
.51764 .17775 L
.52162 .17775 L
.52162 .17753 L
s
.52162 .17775 m
.51764 .17775 L
.51764 .17753 L
.52162 .17753 L
.52162 .17775 L
s
.52162 .17753 m
.51764 .17753 L
.51764 .17685 L
.52162 .17685 L
.52162 .17753 L
s
.52162 .17685 m
.51764 .17685 L
.51764 .17574 L
.52162 .17574 L
.52162 .17685 L
s
.52162 .17574 m
.51764 .17574 L
.51764 .17418 L
.52162 .17418 L
.52162 .17574 L
s
.52162 .17418 m
.51764 .17418 L
.51764 .1722 L
.52162 .1722 L
.52162 .17418 L
s
.52162 .1722 m
.51764 .1722 L
.51764 .1698 L
.52162 .1698 L
.52162 .1722 L
s
.52162 .1698 m
.51764 .1698 L
.51764 .16701 L
.52162 .16701 L
.52162 .1698 L
s
.52162 .16701 m
.51764 .16701 L
.51764 .16383 L
.52162 .16383 L
.52162 .16701 L
s
.52162 .16383 m
.51764 .16383 L
.51764 .16028 L
.52162 .16028 L
.52162 .16383 L
s
.52162 .16028 m
.51764 .16028 L
.51764 .1564 L
.52162 .1564 L
.52162 .16028 L
s
.52162 .1564 m
.51764 .1564 L
.51764 .15219 L
.52162 .15219 L
.52162 .1564 L
s
.52162 .15219 m
.51764 .15219 L
.51764 .1477 L
.52162 .1477 L
.52162 .15219 L
s
.52162 .1477 m
.51764 .1477 L
.51764 .14294 L
.52162 .14294 L
.52162 .1477 L
s
.52162 .14294 m
.51764 .14294 L
.51764 .13794 L
.52162 .13794 L
.52162 .14294 L
s
.52162 .13794 m
.51764 .13794 L
.51764 .13274 L
.52162 .13274 L
.52162 .13794 L
s
.52162 .13274 m
.51764 .13274 L
.51764 .12737 L
.52162 .12737 L
.52162 .13274 L
s
.52162 .12737 m
.51764 .12737 L
.51764 .12186 L
.52162 .12186 L
.52162 .12737 L
s
.52162 .12186 m
.51764 .12186 L
.51764 .11624 L
.52162 .11624 L
.52162 .12186 L
s
.52162 .11624 m
.51764 .11624 L
.51764 .11056 L
.52162 .11056 L
.52162 .11624 L
s
.52162 .11056 m
.51764 .11056 L
.51764 .10484 L
.52162 .10484 L
.52162 .11056 L
s
.52162 .10484 m
.51764 .10484 L
.51764 .09912 L
.52162 .09912 L
.52162 .10484 L
s
.52162 .09912 m
.51764 .09912 L
.51764 .09343 L
.52162 .09343 L
.52162 .09912 L
s
.52162 .09343 m
.51764 .09343 L
.51764 .08782 L
.52162 .08782 L
.52162 .09343 L
s
.52162 .08782 m
.51764 .08782 L
.51764 .08231 L
.52162 .08231 L
.52162 .08782 L
s
.52162 .08231 m
.51764 .08231 L
.51764 .07694 L
.52162 .07694 L
.52162 .08231 L
s
.52162 .07694 m
.51764 .07694 L
.51764 .07174 L
.52162 .07174 L
.52162 .07694 L
s
.52162 .07174 m
.51764 .07174 L
.51764 .06674 L
.52162 .06674 L
.52162 .07174 L
s
.52162 .06674 m
.51764 .06674 L
.51764 .06198 L
.52162 .06198 L
.52162 .06674 L
s
.52162 .06198 m
.51764 .06198 L
.51764 .05749 L
.52162 .05749 L
.52162 .06198 L
s
.52162 .05749 m
.51764 .05749 L
.51764 .05328 L
.52162 .05328 L
.52162 .05749 L
s
.52162 .05328 m
.51764 .05328 L
.51764 .0494 L
.52162 .0494 L
.52162 .05328 L
s
.52162 .0494 m
.51764 .0494 L
.51764 .04585 L
.52162 .04585 L
.52162 .0494 L
s
.52162 .04585 m
.51764 .04585 L
.51764 .04267 L
.52162 .04267 L
.52162 .04585 L
s
.52162 .04267 m
.51764 .04267 L
.51764 .03987 L
.52162 .03987 L
.52162 .04267 L
s
.52162 .03987 m
.51764 .03987 L
.51764 .03748 L
.52162 .03748 L
.52162 .03987 L
s
.52162 .03748 m
.51764 .03748 L
.51764 .0355 L
.52162 .0355 L
.52162 .03748 L
s
.52162 .0355 m
.51764 .0355 L
.51764 .03394 L
.52162 .03394 L
.52162 .0355 L
s
.52162 .03394 m
.51764 .03394 L
.51764 .03282 L
.52162 .03282 L
.52162 .03394 L
s
.52162 .03282 m
.51764 .03282 L
.51764 .03215 L
.52162 .03215 L
.52162 .03282 L
s
.52162 .03215 m
.51764 .03215 L
.51764 .03193 L
.52162 .03193 L
.52162 .03215 L
s
.5 g
.47134 .03193 m
.47532 .03193 L
.47757 .03922 L
.47134 .03922 L
.47134 .03193 L
F
.47134 .03922 m
.47757 .03922 L
.47956 .04651 L
.47134 .04651 L
.47134 .03922 L
F
.47134 .04651 m
.47956 .04651 L
.48131 .0538 L
.47134 .0538 L
.47134 .04651 L
F
.47134 .0538 m
.48131 .0538 L
.48281 .06109 L
.47134 .06109 L
.47134 .0538 L
F
.47134 .06109 m
.48281 .06109 L
.48408 .06838 L
.47134 .06838 L
.47134 .06109 L
F
.47134 .06838 m
.48408 .06838 L
.48511 .07567 L
.47134 .07567 L
.47134 .06838 L
F
.47134 .07567 m
.48511 .07567 L
.4859 .08297 L
.47134 .08297 L
.47134 .07567 L
F
.47134 .08297 m
.4859 .08297 L
.48647 .09026 L
.47134 .09026 L
.47134 .08297 L
F
.47134 .09026 m
.48647 .09026 L
.48681 .09755 L
.47134 .09755 L
.47134 .09026 L
F
.47134 .09755 m
.48681 .09755 L
.48693 .10484 L
.47134 .10484 L
.47134 .09755 L
F
.47134 .10484 m
.48693 .10484 L
.48681 .11213 L
.47134 .11213 L
.47134 .10484 L
F
.47134 .11213 m
.48681 .11213 L
.48647 .11942 L
.47134 .11942 L
.47134 .11213 L
F
.47134 .11942 m
.48647 .11942 L
.4859 .12671 L
.47134 .12671 L
.47134 .11942 L
F
.47134 .12671 m
.4859 .12671 L
.48511 .134 L
.47134 .134 L
.47134 .12671 L
F
.47134 .134 m
.48511 .134 L
.48408 .14129 L
.47134 .14129 L
.47134 .134 L
F
.47134 .14129 m
.48408 .14129 L
.48281 .14859 L
.47134 .14859 L
.47134 .14129 L
F
.47134 .14859 m
.48281 .14859 L
.48131 .15588 L
.47134 .15588 L
.47134 .14859 L
F
.47134 .15588 m
.48131 .15588 L
.47956 .16317 L
.47134 .16317 L
.47134 .15588 L
F
.47134 .16317 m
.47956 .16317 L
.47757 .17046 L
.47134 .17046 L
.47134 .16317 L
F
.47134 .17046 m
.47757 .17046 L
.47532 .17775 L
.47134 .17775 L
.47134 .17046 L
F
0 g
.47134 .03193 m
.47134 .03922 L
.47134 .04651 L
.47134 .0538 L
.47134 .06109 L
.47134 .06838 L
.47134 .07567 L
.47134 .08297 L
.47134 .09026 L
.47134 .09755 L
.47134 .10484 L
.47134 .11213 L
.47134 .11942 L
.47134 .12671 L
.47134 .134 L
.47134 .14129 L
.47134 .14859 L
.47134 .15588 L
.47134 .16317 L
.47134 .17046 L
.47134 .17775 L
.47532 .17775 L
.47757 .17046 L
.47956 .16317 L
.48131 .15588 L
.48281 .14859 L
.48408 .14129 L
.48511 .134 L
.4859 .12671 L
.48647 .11942 L
.48681 .11213 L
.48693 .10484 L
.48681 .09755 L
.48647 .09026 L
.4859 .08297 L
.48511 .07567 L
.48408 .06838 L
.48281 .06109 L
.48131 .0538 L
.47956 .04651 L
.47757 .03922 L
.47532 .03193 L
.47134 .03193 L
s
.5 g
.47134 .10484 m
.47532 .10484 L
.47757 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.47757 .10484 L
.47956 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.47956 .10484 L
.48131 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48131 .10484 L
.48281 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48281 .10484 L
.48408 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48408 .10484 L
.48511 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48511 .10484 L
.4859 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.4859 .10484 L
.48647 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48647 .10484 L
.48681 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48681 .10484 L
.48693 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48693 .10484 L
.48681 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48681 .10484 L
.48647 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48647 .10484 L
.4859 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.4859 .10484 L
.48511 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48511 .10484 L
.48408 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48408 .10484 L
.48281 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48281 .10484 L
.48131 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.48131 .10484 L
.47956 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.47956 .10484 L
.47757 .10484 L
.47134 .10484 L
.47134 .10484 L
F
.47134 .10484 m
.47757 .10484 L
.47532 .10484 L
.47134 .10484 L
.47134 .10484 L
F
0 g
.47134 .10484 m
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47134 .10484 L
.47532 .10484 L
.47757 .10484 L
.47956 .10484 L
.48131 .10484 L
.48281 .10484 L
.48408 .10484 L
.48511 .10484 L
.4859 .10484 L
.48647 .10484 L
.48681 .10484 L
.48693 .10484 L
.48681 .10484 L
.48647 .10484 L
.4859 .10484 L
.48511 .10484 L
.48408 .10484 L
.48281 .10484 L
.48131 .10484 L
.47956 .10484 L
.47757 .10484 L
.47532 .10484 L
.47134 .10484 L
s
.47134 .17775 m
.47532 .17775 L
.47532 .17753 L
.47134 .17753 L
.47134 .17775 L
s
.47134 .17753 m
.47532 .17753 L
.47532 .17685 L
.47134 .17685 L
.47134 .17753 L
s
.47134 .17685 m
.47532 .17685 L
.47532 .17574 L
.47134 .17574 L
.47134 .17685 L
s
.47134 .17574 m
.47532 .17574 L
.47532 .17418 L
.47134 .17418 L
.47134 .17574 L
s
.47134 .17418 m
.47532 .17418 L
.47532 .1722 L
.47134 .1722 L
.47134 .17418 L
s
.47134 .1722 m
.47532 .1722 L
.47532 .1698 L
.47134 .1698 L
.47134 .1722 L
s
.47134 .1698 m
.47532 .1698 L
.47532 .16701 L
.47134 .16701 L
.47134 .1698 L
s
.47134 .16701 m
.47532 .16701 L
.47532 .16383 L
.47134 .16383 L
.47134 .16701 L
s
.47134 .16383 m
.47532 .16383 L
.47532 .16028 L
.47134 .16028 L
.47134 .16383 L
s
.47134 .16028 m
.47532 .16028 L
.47532 .1564 L
.47134 .1564 L
.47134 .16028 L
s
.47134 .1564 m
.47532 .1564 L
.47532 .15219 L
.47134 .15219 L
.47134 .1564 L
s
.47134 .15219 m
.47532 .15219 L
.47532 .1477 L
.47134 .1477 L
.47134 .15219 L
s
.47134 .1477 m
.47532 .1477 L
.47532 .14294 L
.47134 .14294 L
.47134 .1477 L
s
.47134 .14294 m
.47532 .14294 L
.47532 .13794 L
.47134 .13794 L
.47134 .14294 L
s
.47134 .13794 m
.47532 .13794 L
.47532 .13274 L
.47134 .13274 L
.47134 .13794 L
s
.47134 .13274 m
.47532 .13274 L
.47532 .12737 L
.47134 .12737 L
.47134 .13274 L
s
.47134 .12737 m
.47532 .12737 L
.47532 .12186 L
.47134 .12186 L
.47134 .12737 L
s
.47134 .12186 m
.47532 .12186 L
.47532 .11624 L
.47134 .11624 L
.47134 .12186 L
s
.47134 .11624 m
.47532 .11624 L
.47532 .11056 L
.47134 .11056 L
.47134 .11624 L
s
.47134 .11056 m
.47532 .11056 L
.47532 .10484 L
.47134 .10484 L
.47134 .11056 L
s
.47134 .10484 m
.47532 .10484 L
.47532 .09912 L
.47134 .09912 L
.47134 .10484 L
s
.47134 .09912 m
.47532 .09912 L
.47532 .09343 L
.47134 .09343 L
.47134 .09912 L
s
.47134 .09343 m
.47532 .09343 L
.47532 .08782 L
.47134 .08782 L
.47134 .09343 L
s
.47134 .08782 m
.47532 .08782 L
.47532 .08231 L
.47134 .08231 L
.47134 .08782 L
s
.47134 .08231 m
.47532 .08231 L
.47532 .07694 L
.47134 .07694 L
.47134 .08231 L
s
.47134 .07694 m
.47532 .07694 L
.47532 .07174 L
.47134 .07174 L
.47134 .07694 L
s
.47134 .07174 m
.47532 .07174 L
.47532 .06674 L
.47134 .06674 L
.47134 .07174 L
s
.47134 .06674 m
.47532 .06674 L
.47532 .06198 L
.47134 .06198 L
.47134 .06674 L
s
.47134 .06198 m
.47532 .06198 L
.47532 .05749 L
.47134 .05749 L
.47134 .06198 L
s
.47134 .05749 m
.47532 .05749 L
.47532 .05328 L
.47134 .05328 L
.47134 .05749 L
s
.47134 .05328 m
.47532 .05328 L
.47532 .0494 L
.47134 .0494 L
.47134 .05328 L
s
.47134 .0494 m
.47532 .0494 L
.47532 .04585 L
.47134 .04585 L
.47134 .0494 L
s
.47134 .04585 m
.47532 .04585 L
.47532 .04267 L
.47134 .04267 L
.47134 .04585 L
s
.47134 .04267 m
.47532 .04267 L
.47532 .03987 L
.47134 .03987 L
.47134 .04267 L
s
.47134 .03987 m
.47532 .03987 L
.47532 .03748 L
.47134 .03748 L
.47134 .03987 L
s
.47134 .03748 m
.47532 .03748 L
.47532 .0355 L
.47134 .0355 L
.47134 .03748 L
s
.47134 .0355 m
.47532 .0355 L
.47532 .03394 L
.47134 .03394 L
.47134 .0355 L
s
.47134 .03394 m
.47532 .03394 L
.47532 .03282 L
.47134 .03282 L
.47134 .03394 L
s
.47134 .03282 m
.47532 .03282 L
.47532 .03215 L
.47134 .03215 L
.47134 .03282 L
s
.47134 .03215 m
.47532 .03215 L
.47532 .03193 L
.47134 .03193 L
.47134 .03215 L
s
.47134 .03193 m
.47532 .03193 L
.47532 .03215 L
.47134 .03215 L
.47134 .03193 L
s
.47134 .03215 m
.47532 .03215 L
.47532 .03282 L
.47134 .03282 L
.47134 .03215 L
s
.47134 .03282 m
.47532 .03282 L
.47532 .03394 L
.47134 .03394 L
.47134 .03282 L
s
.47134 .03394 m
.47532 .03394 L
.47532 .0355 L
.47134 .0355 L
.47134 .03394 L
s
.47134 .0355 m
.47532 .0355 L
.47532 .03748 L
.47134 .03748 L
.47134 .0355 L
s
.47134 .03748 m
.47532 .03748 L
.47532 .03987 L
.47134 .03987 L
.47134 .03748 L
s
.47134 .03987 m
.47532 .03987 L
.47532 .04267 L
.47134 .04267 L
.47134 .03987 L
s
.47134 .04267 m
.47532 .04267 L
.47532 .04585 L
.47134 .04585 L
.47134 .04267 L
s
.47134 .04585 m
.47532 .04585 L
.47532 .0494 L
.47134 .0494 L
.47134 .04585 L
s
.47134 .0494 m
.47532 .0494 L
.47532 .05328 L
.47134 .05328 L
.47134 .0494 L
s
.47134 .05328 m
.47532 .05328 L
.47532 .05749 L
.47134 .05749 L
.47134 .05328 L
s
.47134 .05749 m
.47532 .05749 L
.47532 .06198 L
.47134 .06198 L
.47134 .05749 L
s
.47134 .06198 m
.47532 .06198 L
.47532 .06674 L
.47134 .06674 L
.47134 .06198 L
s
.47134 .06674 m
.47532 .06674 L
.47532 .07174 L
.47134 .07174 L
.47134 .06674 L
s
.47134 .07174 m
.47532 .07174 L
.47532 .07694 L
.47134 .07694 L
.47134 .07174 L
s
.47134 .07694 m
.47532 .07694 L
.47532 .08231 L
.47134 .08231 L
.47134 .07694 L
s
.47134 .08231 m
.47532 .08231 L
.47532 .08782 L
.47134 .08782 L
.47134 .08231 L
s
.47134 .08782 m
.47532 .08782 L
.47532 .09343 L
.47134 .09343 L
.47134 .08782 L
s
.47134 .09343 m
.47532 .09343 L
.47532 .09912 L
.47134 .09912 L
.47134 .09343 L
s
.47134 .09912 m
.47532 .09912 L
.47532 .10484 L
.47134 .10484 L
.47134 .09912 L
s
.47134 .10484 m
.47532 .10484 L
.47532 .11056 L
.47134 .11056 L
.47134 .10484 L
s
.47134 .11056 m
.47532 .11056 L
.47532 .11624 L
.47134 .11624 L
.47134 .11056 L
s
.47134 .11624 m
.47532 .11624 L
.47532 .12186 L
.47134 .12186 L
.47134 .11624 L
s
.47134 .12186 m
.47532 .12186 L
.47532 .12737 L
.47134 .12737 L
.47134 .12186 L
s
.47134 .12737 m
.47532 .12737 L
.47532 .13274 L
.47134 .13274 L
.47134 .12737 L
s
.47134 .13274 m
.47532 .13274 L
.47532 .13794 L
.47134 .13794 L
.47134 .13274 L
s
.47134 .13794 m
.47532 .13794 L
.47532 .14294 L
.47134 .14294 L
.47134 .13794 L
s
.47134 .14294 m
.47532 .14294 L
.47532 .1477 L
.47134 .1477 L
.47134 .14294 L
s
.47134 .1477 m
.47532 .1477 L
.47532 .15219 L
.47134 .15219 L
.47134 .1477 L
s
.47134 .15219 m
.47532 .15219 L
.47532 .1564 L
.47134 .1564 L
.47134 .15219 L
s
.47134 .1564 m
.47532 .1564 L
.47532 .16028 L
.47134 .16028 L
.47134 .1564 L
s
.47134 .16028 m
.47532 .16028 L
.47532 .16383 L
.47134 .16383 L
.47134 .16028 L
s
.47134 .16383 m
.47532 .16383 L
.47532 .16701 L
.47134 .16701 L
.47134 .16383 L
s
.47134 .16701 m
.47532 .16701 L
.47532 .1698 L
.47134 .1698 L
.47134 .16701 L
s
.47134 .1698 m
.47532 .1698 L
.47532 .1722 L
.47134 .1722 L
.47134 .1698 L
s
.47134 .1722 m
.47532 .1722 L
.47532 .17418 L
.47134 .17418 L
.47134 .1722 L
s
.47134 .17418 m
.47532 .17418 L
.47532 .17574 L
.47134 .17574 L
.47134 .17418 L
s
.47134 .17574 m
.47532 .17574 L
.47532 .17685 L
.47134 .17685 L
.47134 .17574 L
s
.47134 .17685 m
.47532 .17685 L
.47532 .17753 L
.47134 .17753 L
.47134 .17685 L
s
.47134 .17753 m
.47532 .17753 L
.47532 .17775 L
.47134 .17775 L
.47134 .17753 L
s
.5 g
.17466 .0797 m
.17714 .0797 L
.17844 .08221 L
.17466 .08221 L
.17466 .0797 L
F
.17466 .08221 m
.17844 .08221 L
.17957 .08473 L
.17466 .08473 L
.17466 .08221 L
F
.17466 .08473 m
.17957 .08473 L
.18054 .08724 L
.17466 .08724 L
.17466 .08473 L
F
.17466 .08724 m
.18054 .08724 L
.18137 .08975 L
.17466 .08975 L
.17466 .08724 L
F
.17466 .08975 m
.18137 .08975 L
.18207 .09227 L
.17466 .09227 L
.17466 .08975 L
F
.17466 .09227 m
.18207 .09227 L
.18262 .09478 L
.17466 .09478 L
.17466 .09227 L
F
.17466 .09478 m
.18262 .09478 L
.18305 .0973 L
.17466 .0973 L
.17466 .09478 L
F
.17466 .0973 m
.18305 .0973 L
.18336 .09981 L
.17466 .09981 L
.17466 .0973 L
F
.17466 .09981 m
.18336 .09981 L
.18354 .10232 L
.17466 .10232 L
.17466 .09981 L
F
.17466 .10232 m
.18354 .10232 L
.1836 .10484 L
.17466 .10484 L
.17466 .10232 L
F
.17466 .10484 m
.1836 .10484 L
.18354 .10735 L
.17466 .10735 L
.17466 .10484 L
F
.17466 .10735 m
.18354 .10735 L
.18336 .10987 L
.17466 .10987 L
.17466 .10735 L
F
.17466 .10987 m
.18336 .10987 L
.18305 .11238 L
.17466 .11238 L
.17466 .10987 L
F
.17466 .11238 m
.18305 .11238 L
.18262 .1149 L
.17466 .1149 L
.17466 .11238 L
F
.17466 .1149 m
.18262 .1149 L
.18207 .11741 L
.17466 .11741 L
.17466 .1149 L
F
.17466 .11741 m
.18207 .11741 L
.18137 .11992 L
.17466 .11992 L
.17466 .11741 L
F
.17466 .11992 m
.18137 .11992 L
.18054 .12244 L
.17466 .12244 L
.17466 .11992 L
F
.17466 .12244 m
.18054 .12244 L
.17957 .12495 L
.17466 .12495 L
.17466 .12244 L
F
.17466 .12495 m
.17957 .12495 L
.17844 .12747 L
.17466 .12747 L
.17466 .12495 L
F
.17466 .12747 m
.17844 .12747 L
.17714 .12998 L
.17466 .12998 L
.17466 .12747 L
F
0 g
.17466 .0797 m
.17466 .08221 L
.17466 .08473 L
.17466 .08724 L
.17466 .08975 L
.17466 .09227 L
.17466 .09478 L
.17466 .0973 L
.17466 .09981 L
.17466 .10232 L
.17466 .10484 L
.17466 .10735 L
.17466 .10987 L
.17466 .11238 L
.17466 .1149 L
.17466 .11741 L
.17466 .11992 L
.17466 .12244 L
.17466 .12495 L
.17466 .12747 L
.17466 .12998 L
.17714 .12998 L
.17844 .12747 L
.17957 .12495 L
.18054 .12244 L
.18137 .11992 L
.18207 .11741 L
.18262 .1149 L
.18305 .11238 L
.18336 .10987 L
.18354 .10735 L
.1836 .10484 L
.18354 .10232 L
.18336 .09981 L
.18305 .0973 L
.18262 .09478 L
.18207 .09227 L
.18137 .08975 L
.18054 .08724 L
.17957 .08473 L
.17844 .08221 L
.17714 .0797 L
.17466 .0797 L
s
.5 g
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
.17466 .10484 m
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
.17466 .10484 L
F
0 g
.17466 .10484 m
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.17466 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.1836 .10484 L
.17466 .10484 L
s
.17466 .0797 m
.17714 .0797 L
.17844 .08221 L
.17466 .08221 L
.17466 .0797 L
s
.17466 .08221 m
.17844 .08221 L
.17957 .08473 L
.17466 .08473 L
.17466 .08221 L
s
.17466 .08473 m
.17957 .08473 L
.18054 .08724 L
.17466 .08724 L
.17466 .08473 L
s
.17466 .08724 m
.18054 .08724 L
.18137 .08975 L
.17466 .08975 L
.17466 .08724 L
s
.17466 .08975 m
.18137 .08975 L
.18207 .09227 L
.17466 .09227 L
.17466 .08975 L
s
.17466 .09227 m
.18207 .09227 L
.18262 .09478 L
.17466 .09478 L
.17466 .09227 L
s
.17466 .09478 m
.18262 .09478 L
.18305 .0973 L
.17466 .0973 L
.17466 .09478 L
s
.17466 .0973 m
.18305 .0973 L
.18336 .09981 L
.17466 .09981 L
.17466 .0973 L
s
.17466 .09981 m
.18336 .09981 L
.18354 .10232 L
.17466 .10232 L
.17466 .09981 L
s
.17466 .10232 m
.18354 .10232 L
.1836 .10484 L
.17466 .10484 L
.17466 .10232 L
s
.17466 .10484 m
.1836 .10484 L
.18354 .10735 L
.17466 .10735 L
.17466 .10484 L
s
.17466 .10735 m
.18354 .10735 L
.18336 .10987 L
.17466 .10987 L
.17466 .10735 L
s
.17466 .10987 m
.18336 .10987 L
.18305 .11238 L
.17466 .11238 L
.17466 .10987 L
s
.17466 .11238 m
.18305 .11238 L
.18262 .1149 L
.17466 .1149 L
.17466 .11238 L
s
.17466 .1149 m
.18262 .1149 L
.18207 .11741 L
.17466 .11741 L
.17466 .1149 L
s
.17466 .11741 m
.18207 .11741 L
.18137 .11992 L
.17466 .11992 L
.17466 .11741 L
s
.17466 .11992 m
.18137 .11992 L
.18054 .12244 L
.17466 .12244 L
.17466 .11992 L
s
.17466 .12244 m
.18054 .12244 L
.17957 .12495 L
.17466 .12495 L
.17466 .12244 L
s
.17466 .12495 m
.17957 .12495 L
.17844 .12747 L
.17466 .12747 L
.17466 .12495 L
s
.17466 .12747 m
.17844 .12747 L
.17714 .12998 L
.17466 .12998 L
.17466 .12747 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17714 .12998 L
.17466 .12998 L
.17466 .12998 L
s
.17466 .12998 m
.17714 .12998 L
.17844 .12747 L
.17466 .12747 L
.17466 .12998 L
s
.17466 .12747 m
.17844 .12747 L
.17957 .12495 L
.17466 .12495 L
.17466 .12747 L
s
.17466 .12495 m
.17957 .12495 L
.18054 .12244 L
.17466 .12244 L
.17466 .12495 L
s
.17466 .12244 m
.18054 .12244 L
.18137 .11992 L
.17466 .11992 L
.17466 .12244 L
s
.17466 .11992 m
.18137 .11992 L
.18207 .11741 L
.17466 .11741 L
.17466 .11992 L
s
.17466 .11741 m
.18207 .11741 L
.18262 .1149 L
.17466 .1149 L
.17466 .11741 L
s
.17466 .1149 m
.18262 .1149 L
.18305 .11238 L
.17466 .11238 L
.17466 .1149 L
s
.17466 .11238 m
.18305 .11238 L
.18336 .10987 L
.17466 .10987 L
.17466 .11238 L
s
.17466 .10987 m
.18336 .10987 L
.18354 .10735 L
.17466 .10735 L
.17466 .10987 L
s
.17466 .10735 m
.18354 .10735 L
.1836 .10484 L
.17466 .10484 L
.17466 .10735 L
s
.17466 .10484 m
.1836 .10484 L
.18354 .10232 L
.17466 .10232 L
.17466 .10484 L
s
.17466 .10232 m
.18354 .10232 L
.18336 .09981 L
.17466 .09981 L
.17466 .10232 L
s
.17466 .09981 m
.18336 .09981 L
.18305 .0973 L
.17466 .0973 L
.17466 .09981 L
s
.17466 .0973 m
.18305 .0973 L
.18262 .09478 L
.17466 .09478 L
.17466 .0973 L
s
.17466 .09478 m
.18262 .09478 L
.18207 .09227 L
.17466 .09227 L
.17466 .09478 L
s
.17466 .09227 m
.18207 .09227 L
.18137 .08975 L
.17466 .08975 L
.17466 .09227 L
s
.17466 .08975 m
.18137 .08975 L
.18054 .08724 L
.17466 .08724 L
.17466 .08975 L
s
.17466 .08724 m
.18054 .08724 L
.17957 .08473 L
.17466 .08473 L
.17466 .08724 L
s
.17466 .08473 m
.17957 .08473 L
.17844 .08221 L
.17466 .08221 L
.17466 .08473 L
s
.17466 .08221 m
.17844 .08221 L
.17714 .0797 L
.17466 .0797 L
.17466 .08221 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.17466 .0797 m
.17714 .0797 L
.17714 .0797 L
.17466 .0797 L
.17466 .0797 L
s
.5 g
.08737 .07775 m
.08872 .07841 L
.0874 .08112 L
.08604 .08046 L
.08737 .07775 L
F
.08604 .08046 m
.0874 .08112 L
.08607 .08383 L
.08471 .08316 L
.08604 .08046 L
F
.08471 .08316 m
.08607 .08383 L
.08474 .08654 L
.08339 .08587 L
.08471 .08316 L
F
.08339 .08587 m
.08474 .08654 L
.08341 .08925 L
.08206 .08858 L
.08339 .08587 L
F
.08206 .08858 m
.08341 .08925 L
.08209 .09196 L
.08073 .09129 L
.08206 .08858 L
F
.08073 .09129 m
.08209 .09196 L
.08076 .09467 L
.0794 .094 L
.08073 .09129 L
F
.0794 .094 m
.08076 .09467 L
.07943 .09737 L
.07808 .09671 L
.0794 .094 L
F
.07808 .09671 m
.07943 .09737 L
.0781 .10008 L
.07675 .09942 L
.07808 .09671 L
F
.07675 .09942 m
.0781 .10008 L
.07678 .10279 L
.07542 .10213 L
.07675 .09942 L
F
.07542 .10213 m
.07678 .10279 L
.07545 .1055 L
.07409 .10484 L
.07542 .10213 L
F
.07409 .10484 m
.07545 .1055 L
.07412 .10821 L
.07277 .10755 L
.07409 .10484 L
F
.07277 .10755 m
.07412 .10821 L
.07279 .11092 L
.07144 .11026 L
.07277 .10755 L
F
.07144 .11026 m
.07279 .11092 L
.07147 .11363 L
.07011 .11297 L
.07144 .11026 L
F
.07011 .11297 m
.07147 .11363 L
.07014 .11634 L
.06878 .11568 L
.07011 .11297 L
F
.06878 .11568 m
.07014 .11634 L
.06881 .11905 L
.06746 .11839 L
.06878 .11568 L
F
.06746 .11839 m
.06881 .11905 L
.06748 .12176 L
.06613 .12109 L
.06746 .11839 L
F
.06613 .12109 m
.06748 .12176 L
.06616 .12447 L
.0648 .1238 L
.06613 .12109 L
F
.0648 .1238 m
.06616 .12447 L
.06483 .12718 L
.06347 .12651 L
.0648 .1238 L
F
.06347 .12651 m
.06483 .12718 L
.0635 .12989 L
.06215 .12922 L
.06347 .12651 L
F
.06215 .12922 m
.0635 .12989 L
.06217 .1326 L
.06082 .13193 L
.06215 .12922 L
F
0 g
.08737 .07775 m
.08604 .08046 L
.08471 .08316 L
.08339 .08587 L
.08206 .08858 L
.08073 .09129 L
.0794 .094 L
.07808 .09671 L
.07675 .09942 L
.07542 .10213 L
.07409 .10484 L
.07277 .10755 L
.07144 .11026 L
.07011 .11297 L
.06878 .11568 L
.06746 .11839 L
.06613 .12109 L
.0648 .1238 L
.06347 .12651 L
.06215 .12922 L
.06082 .13193 L
.06217 .1326 L
.0635 .12989 L
.06483 .12718 L
.06616 .12447 L
.06748 .12176 L
.06881 .11905 L
.07014 .11634 L
.07147 .11363 L
.07279 .11092 L
.07412 .10821 L
.07545 .1055 L
.07678 .10279 L
.0781 .10008 L
.07943 .09737 L
.08076 .09467 L
.08209 .09196 L
.08341 .08925 L
.08474 .08654 L
.08607 .08383 L
.0874 .08112 L
.08872 .07841 L
.08737 .07775 L
s
.5 g
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
.07409 .10484 m
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
.07409 .10484 L
F
0 g
.07409 .10484 m
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07409 .10484 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07545 .1055 L
.07409 .10484 L
s
.06082 .13193 m
.06217 .1326 L
.06221 .13251 L
.06086 .13185 L
.06082 .13193 L
s
.06086 .13185 m
.06221 .13251 L
.06234 .13226 L
.06098 .1316 L
.06086 .13185 L
s
.06098 .1316 m
.06234 .13226 L
.06254 .13185 L
.06119 .13118 L
.06098 .1316 L
s
.06119 .13118 m
.06254 .13185 L
.06282 .13127 L
.06147 .13061 L
.06119 .13118 L
s
.06147 .13061 m
.06282 .13127 L
.06318 .13053 L
.06183 .12987 L
.06147 .13061 L
s
.06183 .12987 m
.06318 .13053 L
.06362 .12964 L
.06227 .12898 L
.06183 .12987 L
s
.06227 .12898 m
.06362 .12964 L
.06413 .1286 L
.06277 .12794 L
.06227 .12898 L
s
.06277 .12794 m
.06413 .1286 L
.06471 .12742 L
.06335 .12676 L
.06277 .12794 L
s
.06335 .12676 m
.06471 .12742 L
.06535 .1261 L
.064 .12544 L
.06335 .12676 L
s
.064 .12544 m
.06535 .1261 L
.06606 .12466 L
.06471 .124 L
.064 .12544 L
s
.06471 .124 m
.06606 .12466 L
.06683 .1231 L
.06547 .12243 L
.06471 .124 L
s
.06547 .12243 m
.06683 .1231 L
.06765 .12143 L
.06629 .12076 L
.06547 .12243 L
s
.06629 .12076 m
.06765 .12143 L
.06851 .11966 L
.06716 .11899 L
.06629 .12076 L
s
.06716 .11899 m
.06851 .11966 L
.06942 .1178 L
.06807 .11714 L
.06716 .11899 L
s
.06807 .11714 m
.06942 .1178 L
.07037 .11587 L
.06901 .11521 L
.06807 .11714 L
s
.06901 .11521 m
.07037 .11587 L
.07135 .11387 L
.06999 .11321 L
.06901 .11521 L
s
.06999 .11321 m
.07135 .11387 L
.07235 .11183 L
.07099 .11116 L
.06999 .11321 L
s
.07099 .11116 m
.07235 .11183 L
.07337 .10974 L
.07202 .10908 L
.07099 .11116 L
s
.07202 .10908 m
.07337 .10974 L
.07441 .10763 L
.07305 .10696 L
.07202 .10908 L
s
.07305 .10696 m
.07441 .10763 L
.07545 .1055 L
.07409 .10484 L
.07305 .10696 L
s
.07409 .10484 m
.07545 .1055 L
.07649 .10338 L
.07514 .10271 L
.07409 .10484 L
s
.07514 .10271 m
.07649 .10338 L
.07752 .10126 L
.07617 .1006 L
.07514 .10271 L
s
.07617 .1006 m
.07752 .10126 L
.07855 .09918 L
.07719 .09851 L
.07617 .1006 L
s
.07719 .09851 m
.07855 .09918 L
.07955 .09713 L
.0782 .09647 L
.07719 .09851 L
s
.0782 .09647 m
.07955 .09713 L
.08053 .09513 L
.07917 .09447 L
.0782 .09647 L
s
.07917 .09447 m
.08053 .09513 L
.08147 .0932 L
.08012 .09254 L
.07917 .09447 L
s
.08012 .09254 m
.08147 .0932 L
.08238 .09135 L
.08103 .09068 L
.08012 .09254 L
s
.08103 .09068 m
.08238 .09135 L
.08325 .08958 L
.0819 .08891 L
.08103 .09068 L
s
.0819 .08891 m
.08325 .08958 L
.08407 .08791 L
.08272 .08724 L
.0819 .08891 L
s
.08272 .08724 m
.08407 .08791 L
.08484 .08634 L
.08348 .08568 L
.08272 .08724 L
s
.08348 .08568 m
.08484 .08634 L
.08554 .0849 L
.08419 .08424 L
.08348 .08568 L
s
.08419 .08424 m
.08554 .0849 L
.08619 .08358 L
.08483 .08292 L
.08419 .08424 L
s
.08483 .08292 m
.08619 .08358 L
.08677 .0824 L
.08541 .08174 L
.08483 .08292 L
s
.08541 .08174 m
.08677 .0824 L
.08728 .08136 L
.08592 .0807 L
.08541 .08174 L
s
.08592 .0807 m
.08728 .08136 L
.08771 .08047 L
.08636 .07981 L
.08592 .0807 L
s
.08636 .07981 m
.08771 .08047 L
.08807 .07974 L
.08672 .07907 L
.08636 .07981 L
s
.08672 .07907 m
.08807 .07974 L
.08836 .07916 L
.087 .07849 L
.08672 .07907 L
s
.087 .07849 m
.08836 .07916 L
.08856 .07874 L
.08721 .07808 L
.087 .07849 L
s
.08721 .07808 m
.08856 .07874 L
.08868 .07849 L
.08733 .07783 L
.08721 .07808 L
s
.08733 .07783 m
.08868 .07849 L
.08872 .07841 L
.08737 .07775 L
.08733 .07783 L
s
.08737 .07775 m
.08872 .07841 L
.08868 .07849 L
.08733 .07783 L
.08737 .07775 L
s
.08733 .07783 m
.08868 .07849 L
.08856 .07874 L
.08721 .07808 L
.08733 .07783 L
s
.08721 .07808 m
.08856 .07874 L
.08836 .07916 L
.087 .07849 L
.08721 .07808 L
s
.087 .07849 m
.08836 .07916 L
.08807 .07974 L
.08672 .07907 L
.087 .07849 L
s
.08672 .07907 m
.08807 .07974 L
.08771 .08047 L
.08636 .07981 L
.08672 .07907 L
s
.08636 .07981 m
.08771 .08047 L
.08728 .08136 L
.08592 .0807 L
.08636 .07981 L
s
.08592 .0807 m
.08728 .08136 L
.08677 .0824 L
.08541 .08174 L
.08592 .0807 L
s
.08541 .08174 m
.08677 .0824 L
.08619 .08358 L
.08483 .08292 L
.08541 .08174 L
s
.08483 .08292 m
.08619 .08358 L
.08554 .0849 L
.08419 .08424 L
.08483 .08292 L
s
.08419 .08424 m
.08554 .0849 L
.08484 .08634 L
.08348 .08568 L
.08419 .08424 L
s
.08348 .08568 m
.08484 .08634 L
.08407 .08791 L
.08272 .08724 L
.08348 .08568 L
s
.08272 .08724 m
.08407 .08791 L
.08325 .08958 L
.0819 .08891 L
.08272 .08724 L
s
.0819 .08891 m
.08325 .08958 L
.08238 .09135 L
.08103 .09068 L
.0819 .08891 L
s
.08103 .09068 m
.08238 .09135 L
.08147 .0932 L
.08012 .09254 L
.08103 .09068 L
s
.08012 .09254 m
.08147 .0932 L
.08053 .09513 L
.07917 .09447 L
.08012 .09254 L
s
.07917 .09447 m
.08053 .09513 L
.07955 .09713 L
.0782 .09647 L
.07917 .09447 L
s
.0782 .09647 m
.07955 .09713 L
.07855 .09918 L
.07719 .09851 L
.0782 .09647 L
s
.07719 .09851 m
.07855 .09918 L
.07752 .10126 L
.07617 .1006 L
.07719 .09851 L
s
.07617 .1006 m
.07752 .10126 L
.07649 .10338 L
.07514 .10271 L
.07617 .1006 L
s
.07514 .10271 m
.07649 .10338 L
.07545 .1055 L
.07409 .10484 L
.07514 .10271 L
s
.07409 .10484 m
.07545 .1055 L
.07441 .10763 L
.07305 .10696 L
.07409 .10484 L
s
.07305 .10696 m
.07441 .10763 L
.07337 .10974 L
.07202 .10908 L
.07305 .10696 L
s
.07202 .10908 m
.07337 .10974 L
.07235 .11183 L
.07099 .11116 L
.07202 .10908 L
s
.07099 .11116 m
.07235 .11183 L
.07135 .11387 L
.06999 .11321 L
.07099 .11116 L
s
.06999 .11321 m
.07135 .11387 L
.07037 .11587 L
.06901 .11521 L
.06999 .11321 L
s
.06901 .11521 m
.07037 .11587 L
.06942 .1178 L
.06807 .11714 L
.06901 .11521 L
s
.06807 .11714 m
.06942 .1178 L
.06851 .11966 L
.06716 .11899 L
.06807 .11714 L
s
.06716 .11899 m
.06851 .11966 L
.06765 .12143 L
.06629 .12076 L
.06716 .11899 L
s
.06629 .12076 m
.06765 .12143 L
.06683 .1231 L
.06547 .12243 L
.06629 .12076 L
s
.06547 .12243 m
.06683 .1231 L
.06606 .12466 L
.06471 .124 L
.06547 .12243 L
s
.06471 .124 m
.06606 .12466 L
.06535 .1261 L
.064 .12544 L
.06471 .124 L
s
.064 .12544 m
.06535 .1261 L
.06471 .12742 L
.06335 .12676 L
.064 .12544 L
s
.06335 .12676 m
.06471 .12742 L
.06413 .1286 L
.06277 .12794 L
.06335 .12676 L
s
.06277 .12794 m
.06413 .1286 L
.06362 .12964 L
.06227 .12898 L
.06277 .12794 L
s
.06227 .12898 m
.06362 .12964 L
.06318 .13053 L
.06183 .12987 L
.06227 .12898 L
s
.06183 .12987 m
.06318 .13053 L
.06282 .13127 L
.06147 .13061 L
.06183 .12987 L
s
.06147 .13061 m
.06282 .13127 L
.06254 .13185 L
.06119 .13118 L
.06147 .13061 L
s
.06119 .13118 m
.06254 .13185 L
.06234 .13226 L
.06098 .1316 L
.06119 .13118 L
s
.06098 .1316 m
.06234 .13226 L
.06221 .13251 L
.06086 .13185 L
.06098 .1316 L
s
.06086 .13185 m
.06221 .13251 L
.06217 .1326 L
.06082 .13193 L
.06086 .13185 L
s
.06337 .05815 m
.11485 .08337 L
.07724 .16014 L
.02576 .13491 L
.06337 .05815 L
s
.0759 .10572 m
.07582 .10586 L
.07574 .106 L
.07564 .10612 L
.07554 .10624 L
.07542 .10635 L
.0753 .10645 L
.07517 .10654 L
.07503 .10662 L
.07489 .10668 L
.07475 .10674 L
.07459 .10679 L
.07444 .10682 L
.07428 .10684 L
.07413 .10685 L
.07397 .10685 L
.07381 .10683 L
.07365 .1068 L
.0735 .10676 L
.07335 .10671 L
.07321 .10665 L
.07307 .10657 L
.07294 .10648 L
.07281 .10639 L
.07269 .10628 L
.07258 .10617 L
.07249 .10605 L
.0724 .10592 L
.07232 .10578 L
.07225 .10564 L
.07219 .10549 L
.07215 .10534 L
.07211 .10518 L
.07209 .10503 L
.07208 .10487 L
.07209 .10471 L
.0721 .10456 L
.07213 .1044 L
.07217 .10425 L
.07222 .1041 L
.07229 .10395 L
.07236 .10381 L
.07245 .10368 L
.07254 .10356 L
.07265 .10344 L
.07276 .10333 L
.07289 .10323 L
.07302 .10314 L
.07315 .10306 L
.07329 .10299 L
Mistroke
.07344 .10294 L
.07359 .10289 L
.07375 .10286 L
.0739 .10284 L
.07406 .10283 L
.07422 .10283 L
.07438 .10285 L
.07453 .10288 L
.07469 .10292 L
.07483 .10297 L
.07498 .10303 L
.07512 .10311 L
.07525 .10319 L
.07538 .10329 L
.07549 .10339 L
.0756 .10351 L
.0757 .10363 L
.07579 .10376 L
.07587 .1039 L
.07594 .10404 L
.076 .10419 L
.07604 .10434 L
.07608 .10449 L
.0761 .10465 L
.0761 .10481 L
.0761 .10497 L
.07608 .10512 L
.07606 .10528 L
.07602 .10543 L
.07596 .10558 L
.0759 .10572 L
Mfstroke
.039 .916 .04 r
.97619 .10484 m
.59253 .1283 L
s
% Start of user PostScript
422. 0 40.5104 23.3329 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59253 .1283 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .10484 m
.58498 .10484 L
s
% Start of user PostScript
422. 0 33. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.58498 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.97619 .10484 m
.59253 .08137 L
s
% Start of user PostScript
422. 0 40.5104 -23.3329 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59253 .08137 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29089 m
.12438 .28209 L
s
% Start of user PostScript
-525. 185. -425. 176.251 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12438 .28209 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29089 m
.12438 .29089 L
s
% Start of user PostScript
-525. 185. -425. 185. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12438 .29089 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .29089 m
.12438 .29969 L
s
% Start of user PostScript
-525. 185. -425. 193.749 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12438 .29969 Mdot
.039 .916 .04 r
.5 Mabswid
.59253 .1283 m
.57917 .13171 L
s
% Start of user PostScript
40.5104 23.3329 27.2274 26.7183 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57917 .13171 Mdot
.039 .916 .04 r
.5 Mabswid
.58498 .10484 m
.57191 .10484 L
s
% Start of user PostScript
33. 0 20. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57191 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.59253 .08137 m
.57917 .07797 L
s
% Start of user PostScript
40.5104 -23.3329 27.2274 -26.7183 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57917 .07797 Mdot
.039 .916 .04 r
.5 Mabswid
.12438 .28209 m
.12862 .28185 L
s
% Start of user PostScript
-425. 176.251 -420.785 176.009 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12862 .28185 Mdot
.039 .916 .04 r
.5 Mabswid
.12438 .29089 m
.12941 .29089 L
s
% Start of user PostScript
-425. 185. -420. 185. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12941 .29089 Mdot
.039 .916 .04 r
.5 Mabswid
.12438 .29969 m
.12862 .29993 L
s
% Start of user PostScript
-425. 193.749 -420.785 193.991 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.12862 .29993 Mdot
.039 .916 .04 r
.5 Mabswid
.57917 .13171 m
.54878 .13521 L
s
% Start of user PostScript
27.2274 26.7183 -3. 30.1995 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54878 .13521 Mdot
.039 .916 .04 r
.5 Mabswid
.57191 .10484 m
.54878 .10484 L
s
% Start of user PostScript
20. 0 -3. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54878 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.57917 .07797 m
.54878 .07447 L
s
% Start of user PostScript
27.2274 -26.7183 -3. -30.1995 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54878 .07447 Mdot
.039 .916 .04 r
.5 Mabswid
.12862 .28185 m
.30337 .28252 L
s
% Start of user PostScript
-420.785 176.009 -247.017 176.674 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30337 .28252 Mdot
.039 .916 .04 r
.5 Mabswid
.12941 .29089 m
.30037 .29089 L
s
% Start of user PostScript
-420. 185. -250. 185. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.30037 .29089 Mdot
.039 .916 .04 r
.5 Mabswid
.12862 .29993 m
.29736 .29929 L
s
% Start of user PostScript
-420.785 193.991 -252.991 193.348 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.29736 .29929 Mdot
.039 .916 .04 r
.5 Mabswid
.54878 .13521 m
.54727 .13532 L
s
% Start of user PostScript
-3. 30.1995 -4.5 30.3128 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54727 .13532 Mdot
.039 .916 .04 r
.5 Mabswid
.54878 .10484 m
.54727 .10484 L
s
% Start of user PostScript
-3. 0 -4.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54727 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.54878 .07447 m
.54727 .07435 L
s
% Start of user PostScript
-3. -30.1995 -4.5 -30.3128 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.54727 .07435 Mdot
.039 .916 .04 r
.5 Mabswid
.30337 .28252 m
.07857 .09912 L
s
% Start of user PostScript
-247.017 176.674 -470.544 -5.68458 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.07857 .09912 Mdot
.039 .916 .04 r
.5 Mabswid
.30037 .29089 m
.07529 .10582 L
s
% Start of user PostScript
-250. 185. -473.809 0.979011 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.07529 .10582 Mdot
.039 .916 .04 r
.5 Mabswid
.29736 .29929 m
.072 .11254 L
s
% Start of user PostScript
-252.991 193.348 -477.08 7.6547 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.072 .11254 Mdot
.039 .916 .04 r
.5 Mabswid
.54727 .13532 m
.52162 .13828 L
s
% Start of user PostScript
-4.5 30.3128 -30. 33.2496 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.52162 .13828 Mdot
.039 .916 .04 r
.5 Mabswid
.54727 .10484 m
.52162 .10484 L
s
% Start of user PostScript
-4.5 0 -30. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.52162 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.54727 .07435 m
.52162 .0714 L
s
% Start of user PostScript
-4.5 -30.3128 -30. -33.2496 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.52162 .0714 Mdot
.039 .916 .04 r
.5 Mabswid
.07857 .09912 m
.07732 .09825 L
s
% Start of user PostScript
-470.544 -5.68458 -471.792 -6.54784 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.07732 .09825 Mdot
.039 .916 .04 r
.5 Mabswid
.07529 .10582 m
.07404 .10495 L
s
% Start of user PostScript
-473.809 0.979011 -475.055 0.112323 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.07404 .10495 Mdot
.039 .916 .04 r
.5 Mabswid
.072 .11254 m
.07075 .11166 L
s
% Start of user PostScript
-477.08 7.6547 -478.324 6.78459 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.07075 .11166 Mdot
.039 .916 .04 r
.5 Mabswid
.52162 .13828 m
.50857 .13926 L
s
% Start of user PostScript
-30. 33.2496 -42.9766 34.2295 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50857 .13926 Mdot
.039 .916 .04 r
.5 Mabswid
.52162 .10484 m
.50603 .10484 L
s
% Start of user PostScript
-30. 0 -45.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50603 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.52162 .0714 m
.50857 .07041 L
s
% Start of user PostScript
-30. -33.2496 -42.9766 -34.2295 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.50857 .07041 Mdot
.039 .916 .04 r
.5 Mabswid
.50857 .13926 m
.48425 .14019 L
s
% Start of user PostScript
-42.9766 34.2295 -67.1613 35.1476 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48425 .14019 Mdot
.039 .916 .04 r
.5 Mabswid
.50603 .10484 m
.48693 .10484 L
s
% Start of user PostScript
-45.5 0 -64.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48693 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.50857 .07041 m
.48425 .06949 L
s
% Start of user PostScript
-42.9766 -34.2295 -67.1613 -35.1476 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.48425 .06949 Mdot
.039 .916 .04 r
.5 Mabswid
.48425 .14019 m
.47134 .13984 L
s
% Start of user PostScript
-67.1613 35.1476 -80. 34.7993 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.47134 .13984 Mdot
.039 .916 .04 r
.5 Mabswid
.48693 .10484 m
.47134 .10484 L
s
% Start of user PostScript
-64.5 0 -80. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.47134 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.48425 .06949 m
.47134 .06984 L
s
% Start of user PostScript
-67.1613 -35.1476 -80. -34.7993 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.47134 .06984 Mdot
.039 .916 .04 r
.5 Mabswid
.47134 .13984 m
.1783 .12775 L
s
% Start of user PostScript
-80. 34.7993 -371.38 22.7815 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1783 .12775 Mdot
.039 .916 .04 r
.5 Mabswid
.47134 .10484 m
.1836 .10484 L
s
% Start of user PostScript
-80. 0 -366.11 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1836 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.47134 .06984 m
.1783 .08193 L
s
% Start of user PostScript
-80. -34.7993 -371.38 -22.7815 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.1783 .08193 Mdot
.039 .916 .04 r
.5 Mabswid
.1783 .12775 m
.17466 .12706 L
s
% Start of user PostScript
-371.38 22.7815 -375. 22.0963 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.17466 .12706 Mdot
.039 .916 .04 r
.5 Mabswid
.1836 .10484 m
.17466 .10484 L
s
% Start of user PostScript
-366.11 0 -375. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.17466 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.1783 .08193 m
.17466 .08262 L
s
% Start of user PostScript
-371.38 -22.7815 -375. -22.0963 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.17466 .08262 Mdot
.039 .916 .04 r
.5 Mabswid
.17466 .12706 m
.07873 .0988 L
s
% Start of user PostScript
-375. 22.0963 -470.387 -6.00657 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.07873 .0988 Mdot
.039 .916 .04 r
.5 Mabswid
.17466 .10484 m
.07577 .10484 L
s
% Start of user PostScript
-375. 0 -473.33 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.07577 .10484 Mdot
.039 .916 .04 r
.5 Mabswid
.17466 .08262 m
.07181 .11292 L
s
% Start of user PostScript
-375. -22.0963 -477.266 8.03334 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.07181 .11292 Mdot
.039 .916 .04 r
.5 Mabswid
.07873 .0988 m
.0773 .09829 L
s
% Start of user PostScript
-470.387 -6.00657 -471.807 -6.51647 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.0773 .09829 Mdot
.039 .916 .04 r
.5 Mabswid
.07577 .10484 m
.07422 .10458 L
s
% Start of user PostScript
-473.33 0 -474.876 -0.252484 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.07422 .10458 Mdot
.039 .916 .04 r
.5 Mabswid
.07181 .11292 m
.07013 .11293 L
s
% Start of user PostScript
-477.266 8.03334 -478.941 8.04229 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.07013 .11293 Mdot
[(M)] .31563 .25725 0 0 Mshowa
[(L)] .12689 .25382 0 0 Mshowa
[(H)] .54802 .01648 0 0 Mshowa
[(L1)] .51383 .20225 0 0 Mshowa
[(L2)] .47913 .00743 0 0 Mshowa
[(HOE)] .09883 .05608 0 0 Mshowa
[(CL)] .17913 .05017 0 0 Mshowa
0 0 m
1 0 L
1 .31195 L
0 .31195 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 89.8125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000FB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00Q03oool5000000030?ooo`000000000000800000TP3oool008D0oooo
00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo0900oooo00250?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool3000000040?ooo`00000000000000
0800oooo00250?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool01@000000
oooo0?ooo`3oool000000840oooo00250?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02P3oool01@000000oooo0?ooo`3oool000000840oooo00250?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000303oool500000840oooo00240?ooo`<00000103oool2000000d0
oooo00D000000?ooo`3oool0oooo000000210?ooo`00VP3oool01@000000oooo0?ooo`3oool00000
0840oooo002I0?ooo`<0000000@0oooo0000000000000000P03oool008L0oooo0P00000;0?ooo`80
0000RP3oool008L0oooo0P00000;0?ooo`800000RP3oool008L0oooo0`0000090?ooo`<000001P3o
ool200000880oooo000b0?ooo`<000000P3oool5000004/0oooo0`0000090?ooo`<000001P3oool2
00000880oooo000F0?ooo`<0000000@0oooo00000000000000000P3oool2000000<0oooo1@000008
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00001;0?ooo`<00000
2@3oool3000000H0oooo0P0000000`3oool000000?ooo`1o0?ooo`005`3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000070?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0C03oool3000000T0oooo0`0000060?oo
o`80000000<0oooo0000003oool03`3oool2000006h0oooo000G0?ooo`070000003oool0oooo0?oo
o`000000oooo000000040?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1<0?ooo`80000000<0Ogmo0000003oool01P3oool010000000Ogmo0000
000000060?ooo`80000000<0oooo0000003oool0303oool30000000307moO`000000oooo06d0oooo
000F0?ooo`H0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`03000000P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1<0?ooo`80000000<0Ogmo0000003oool01P3o
ool010000000Ogmo0000000000060?ooo`80000000<0oooo0000003oool02@3oool3000000@0Ogmo
00<000000?ooo`3oool0K03oool001H0oooo10000000103oool000000?ooo`0000040?ooo`040000
003oool0oooo000000/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
04`0oooo0P000000101oOgl000000?ooo`3oool300WZ2P80oooo00@0000007moO`00000000001P3o
ool2000000030?ooo`000000oooo00P0oooo00<0000007moO`0000001P1oOgl00`000000oooo0?oo
o`1[0?ooo`005@3oool00`000000oooo000000020?ooo`8000000P3oool010000000oooo0?ooo`00
00030?ooo`040000003oool0oooo000000T0oooo10000000103oool0000000000000001=0?ooo`80
00002`09jPX200000080oooo0`09jPX01@3oool000000000003oool0000000P0oooo0P00000207mo
O`040000001oOgl0Ogmo07moO`<00000K@3oool001D0oooo100000000`3oool00000000000020000
00030?ooo`000000000000<0oooo1@00000B0?ooo`802NX:@03oool;00WZ2P0300000009jPX02NX:
01<02NX:00@0oooo0000003oool0oooo0`09jPX20?ooo`80000000<0Ogmo0000001oOgl01000001`
0?ooo`00503oool00`000000oooo0?ooo`070?ooo`8000006@3oool600WZ2RX0oooo5009jPX:0?oo
o`80000000<0Ogmo00WZ2P09jPX01P09jPX00`0000002NX:00WZ2P0800WZ2P0300000009jPX02NX:
00H02NX:0P000000101oOgl0000007moO`00001d0?ooo`00503oool00`000000oooo0?ooo`090?oo
o`8000005P3oool700WZ2QD0oooo5@09jPXN0?ooo`8000000P1oOgl00`000000oooo0?ooo`0500WZ
2P0307moO`09jPX02NX:00L02NX:00<0000000WZ2P09jPX01009jPX30000000407moO`000000Ogmo
000000@0oooo0`09jPY^0?ooo`004`3oool00`000000oooo0?ooo`060?ooo`800000103oool20000
0140oooo00<0000000WZ2P09jPX01P09jPX20?oooa@02NX:<`3oool200000080Ogmo00<000000?oo
o`3oool00`3oool00`000000Ogmo00WZ2P0200000080oooo1@09jPX00`000000oooo00WZ2P0A00WZ
2Vl0oooo000C0?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`030000003oool0oooo00`0
oooo3@09jPY70?ooo`8000000P1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo0080
00001P3oool00`0000002NX:0?ooo`030?ooo`<02NX:00<0000007moO`09jPX02`09jPY]0?ooo`00
4P3oool00`000000oooo0?ooo`060?ooo`8000001`3oool00`000000oooo0?ooo`090?ooo`<02NX:
00<0oooo0000000000000P0000030?ooo`@02NX:B03oool200000080Ogmo00<000000?ooo`3oool0
0`3oool00`000000Ogmo07moO`02000000H0oooo0P0000060?ooo`0500WZ2P1oOgl0000007moO`00
00001`09jPX30?oooa802NX:F`3oool00180oooo00<000000?ooo`3oool01P3oool2000000H0oooo
00<000000?ooo`3oool01P3oool400WZ2PD0oooo0`00001?0?ooo`8000000P1oOgl00`000000oooo
0?ooo`030?ooo`030000001oOgl0Ogmo008000001P3oool2000000H0oooo100000020?ooo`<02NX:
0P3oool200WZ2Q@0oooo4@09jPY:0?ooo`004@3oool00`000000oooo0?ooo`060?ooo`8000001`3o
ool00`000000oooo0?ooo`020?ooo`@02NX:2@3oool3000004l0oooo0P00000207moO`030000003o
ool0oooo00<0oooo00<0000007moO`1oOgl00P0000060?ooo`8000001@3oool30000000307moO`00
0000oooo00<0oooo00<02NX:0?ooo`3oool09`3ooolB00WZ2SP0oooo000A0?ooo`030000003oool0
oooo00D0oooo0P00000800WZ2P80oooo0`09jPX=0?ooo`<000000`3oool500WZ2TL0oooo0P000002
07moO`030000003oool02NX:00802NX:00@0oooo00WZ2P09jPX02NX:0P0000001@3oool02NX:00WZ
2P09jPX0oooo00<02NX:103oool400WZ2P80000000D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2SP0
oooo4P09jPXV0?ooo`004@3oool00`000000oooo0?ooo`050?ooo`<000002@09jPX@0?ooo`800000
2009jPY80?ooo`8000005009jPX00`0000002NX:00WZ2P0?00WZ2T/0oooo4@09jPXE0?ooo`00403o
ool00`000000oooo0?ooo`060?ooo`800000K@09jPX00`0000002NX:00WZ2P0B00WZ2P0300000009
jPX02NX:07@02NX:303oool00100oooo00<000000?ooo`3oool01P3oool00`0000002NX:00WZ2P0;
00WZ2Pd0oooo1000000700WZ2TP0oooo0P0000000`1oOgl02NX:00WZ2P0700WZ2P0307moO`09jPX0
2NX:00L02NX:00<000000?ooo`09jPX01@09jPX00`0000002NX:00WZ2P0700WZ2Td0oooo3`09jPXE
0?ooo`003`3oool00`000000oooo0?ooo`050?ooo`8000002P09jPX40?ooo`<02NX:2`3oool30000
00@0oooo1009jPY70?ooo`8000000P1oOgl00`000000oooo0?ooo`0200WZ2P040?ooo`0000002NX:
00WZ2P8000000P3oool200WZ2P80oooo0P09jPX50?ooo`<02NX:0P0000020?ooo`802NX:0P3oool2
00WZ2Sd0oooo3`09jPXT0?ooo`003`3oool00`000000oooo0?ooo`050?ooo`<000002009jPX80?oo
o`@02NX:1`3oool3000004l0oooo0P00000207moO`030000003oool0oooo00<0oooo00<0000007mo
O`1oOgl00P0000060?ooo`8000001@3oool20000000307moO`000000000003H0oooo3`09jPXc0?oo
o`003P3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo00WZ2P09jPX01P09jPX<0?ooo`<0
2NX:103oool3000004l0oooo0P00000207moO`030000003oool0oooo00<0oooo00<0000007moO`1o
Ogl00P0000060?ooo`8000001@3oool01@000000Ogmo0000001oOgl0000000<0oooo0P09jPX20?oo
o`802NX:7P3oool?00WZ2T80oooo000>0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`L0
2NX:00<0oooo00WZ2P3oool03@3oool300WZ2P040?ooo`000000000000000080oooo1@09jPY80?oo
o`8000000P1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo008000001P3oool20000
00H0oooo00D0000007moO`00000000000?ooo`0800WZ2Pl0oooo3`09jPYA0?ooo`003@3oool00`00
0000oooo0?ooo`060?ooo`8000000`3oool700WZ2P030?ooo`09jPX0oooo00l0oooo3@09jPY60?oo
o`8000000P1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo008000001P3oool20000
00D0oooo0P09jPX00`000000Ogmo0000000800WZ2P030?ooo`09jPX02NX:00d02NX:H03oool000d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`D02NX:00<0oooo00WZ2P3o
ool00P09jPX>0?ooo`<000001P09jPX40?oooa@02NX:<P3oool200000080Ogmo00<000000?ooo`3o
ool00`3oool00`000000Ogmo07moO`0200000080oooo0P09jPX0103oool02NX:00WZ2P09jPX20?oo
o`D02NX:00<0000000WZ2P09jPX02@09jPY_0?ooo`00303oool2000000L0oooo0P0000050?ooo`<0
2NX:0P3oool00`09jPX0oooo00WZ2P020?ooo`0300WZ2P3oool0oooo0100oooo1@09jPXG0?oooaD0
2NX:7@3oool200000080Ogmo00<000000?ooo`09jPX00P09jPX01@3oool02NX:00WZ2P09jPX00000
00P02NX:00<0000000WZ2P09jPX04P09jPY^0?ooo`003P3oool2000000d0oooo00<02NX:0?ooo`3o
ool00P3oool01P09jPX0oooo00WZ2P09jPX0oooo00WZ2Q80oooo0`09jPX00`3oool02NX:0?ooo`0Z
0?oooa@02NX:2@3oool2000001@02NX:00<0000000WZ2P09jPX01@09jPX0103oool0000007moO`00
000207moO`800000L`3oool00100oooo0P00000;0?ooo`030000003oool0oooo00<0oooo00H02NX:
0?ooo`3oool02NX:0?ooo`09jPXC0?ooo`0300WZ2P3oool0oooo03l0oooo2P09jPX00`0000002NX:
00WZ2P0700WZ2P0300000009jPX02NX:00P02NX:00<000000?ooo`09jPX01P09jPX00`3oool00000
07moO`0207moO`030000001oOgl0000000<00000K`3oool00180oooo0P0000080?ooo`030000003o
ool0oooo00D0oooo00D02NX:0?ooo`3oool02NX:0?ooo`0200WZ2U`0oooo0P0000000`1oOgl02NX:
00WZ2P0700WZ2P0307moO`000000000000@02NX:0P3oool200WZ2P030?ooo`000000oooo0080oooo
0P09jPX30?ooo`030000001oOgl000000080Ogmo00@0000007moO`1oOgl0Ogmo0P00001]0?ooo`00
503oool2000000H0oooo00<000000?ooo`3oool01P3oool200WZ2P050?ooo`09jPX0oooo0?ooo`09
jPX0F`3oool20000000307moO`000000oooo0080oooo0P09jPX20?ooo`802NX:0P0000060?ooo`80
000000<0oooo0000003oool0203oool20000000307moO`000000Ogmo00@0Ogmo00<000000?ooo`3o
ool0J`3oool001H0oooo0P0000030?ooo`030000003oool0oooo00T0oooo00<02NX:0?ooo`09jPX0
0P3oool00`09jPX0oooo0?ooo`1H0?ooo`80000000<0Ogmo0000003oool01P3oool010000000Ogmo
0000000000060?ooo`80000000<0oooo0000003oool02P3oool3000000@0Ogmo00<000000?ooo`3o
ool0J`3oool001P0oooo0P0000000`3oool000000?ooo`0;0?ooo`0500WZ2P3oool02NX:00WZ2P3o
ool00P09jPYH0?ooo`80000000<0Ogmo0000003oool01P3oool010000000Ogmo0000000000060?oo
o`80000000<0oooo0000003oool03@3oool4000006h0oooo000J0?ooo`030000003oool0oooo00`0
oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`1E0?ooo`80000000<0Ogmo0000
003oool01P3oool010000000Ogmo0000000000060?ooo`80000000<0oooo0000003oool0403oool0
0`000000oooo0?ooo`1/0?ooo`00:P3oool01009jPX0oooo0?ooo`09jPX20?ooo`0300WZ2P3oool0
oooo05@0oooo0`0000090?ooo`<000001P3oool2000000030?ooo`000000oooo07l0oooo000[0?oo
o`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?ooo`3oool0D`3oool3000000T0oooo0`000006
0?ooo`800000PP3oool002`0oooo0P09jPX0103oool02NX:0?ooo`3oool200WZ2U<0oooo0`000009
0?ooo`<000001P3oool200000880oooo000^0?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:
0?ooo`3oool0D03oool3000000T0oooo0`00002:0?ooo`00;`3oool01009jPX0oooo0?ooo`09jPX2
0?ooo`0300WZ2P3oool0oooo04l0oooo0P00000;0?ooo`800000RP3oool00300oooo00@02NX:0?oo
o`3oool02NX:0P3oool00`09jPX0oooo0?ooo`3W0?ooo`00<@3oool01009jPX0oooo0?ooo`09jPX2
0?ooo`802NX:i`3oool00380oooo0P09jPX00`3oool02NX:0?ooo`020?ooo`0300WZ2P3oool0oooo
0>@0oooo000d0?ooo`0400WZ2P3oool02NX:00WZ2P80oooo00<02NX:0?ooo`3oool0h`3oool003D0
oooo00@02NX:0?ooo`3oool02NX:0P3oool00`09jPX0oooo0?ooo`1?0?ooo`D000000P3oool30000
08T0oooo000f0?ooo`0400WZ2P3oool0oooo00WZ2P80oooo0P09jPY@0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0R03oool003L0oooo00@02NX:0?ooo`3oool02NX:0`3oool0
0`09jPX0oooo0?ooo`1=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0R03oool0
03P0oooo0P09jPX00`3oool02NX:00WZ2P020?ooo`0300WZ2P3oool0oooo04`0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`280?ooo`00>P3oool01009jPX0oooo0?ooo`09jPX20?oo
o`0300WZ2P3oool0oooo04/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`280?oo
o`00>`3oool01009jPX0oooo0?ooo`09jPX20?ooo`802NX:B`3oool00`000000oooo0?ooo`030?oo
o`800000RP3oool003`0oooo00@02NX:0?ooo`3oool02NX:0`3oool00`09jPX0oooo0?ooo`170?oo
o`<000001@3oool00`000000oooo0?ooo`280?ooo`00?@3oool01009jPX0oooo0?ooo`09jPX30?oo
o`0300WZ2P3oool0oooo0=T0oooo000n0?ooo`802NX:00<0oooo00WZ2P09jPX00P3oool00`09jPX0
oooo0?ooo`3H0?ooo`00@03oool01009jPX0oooo0?ooo`09jPX20?ooo`802NX:f03oool00440oooo
00@02NX:0?ooo`3oool02NX:0`3oool00`09jPX0oooo0?ooo`3E0?ooo`00@P3oool01009jPX0oooo
0?ooo`09jPX30?ooo`0300WZ2P3oool0oooo0=@0oooo00130?ooo`0400WZ2P3oool0oooo00WZ2P<0
oooo0P09jP[D0?ooo`00A03oool200WZ2P030?ooo`09jPX02NX:00<0oooo00<02NX:0?ooo`3oool0
d@3oool002D0oooo1@00000L0?ooo`0400WZ2P3oool0oooo00WZ2P<0oooo00<02NX:0?ooo`3oool0
d03oool002H0oooo00@000000?ooo`3oool000007@3oool01009jPX0oooo0?ooo`09jPX30?ooo`03
00WZ2P3oool0oooo00H0oooo0`0000030?ooo`<00000`03oool002H0oooo00<000000?ooo`3oool0
7`3oool01009jPX0oooo0?ooo`09jPX30?ooo`802NX:1`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0;l0oooo000V0?ooo`030000003oool0oooo0200oooo00@02NX:0?ooo`3o
ool02NX:103oool00`09jPX0oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0_`3oool002H0oooo00<000000?ooo`3oool08@3oool00`09jPX0oooo0?ooo`0200WZ
2P<0oooo00<02NX:0?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`000000`@3o
ool002H0oooo00<000000?ooo`3oool08P3oool200WZ2P80oooo00D02NX:0?ooo`3oool0oooo00WZ
2P040?ooo`070000003oool000000?ooo`000000oooo000000310?ooo`009@3oool3000002D0oooo
00@02NX:0?ooo`3oool02NX:0`3oool200WZ2P80oooo0P0000030?ooo`800000`@3oool004h0oooo
00@02NX:0?ooo`3oool02NX:103oool01009jPX000000000000000030?ooo`<00000`03oool004l0
oooo00<02NX:0?ooo`09jPX00P09jPX30?ooo`0300WZ2P3oool0oooo0<H0oooo000O0?ooo`H02NX:
0P3oool2000002L0oooo00<02NX:0?ooo`09jPX01P09jPX00`000000oooo0?ooo`340?ooo`00803o
oolh00WZ2P0400000009jPX0000000000<@0oooo000I0?ooo`h02NX:0`00000V0?ooo`L02NX:00@0
oooo0000000000000000a@3oool00100oooo2@09jPX60?ooo`P02NX:0`00000V0?ooo`P02NX:00<0
000007moO`000000a@3oool000/0ooooC009jPX00`0000002NX:07moO`360?ooo`004`3ooolD00WZ
2P8000009`3oool700WZ2P030000001oOgl000000<H0oooo000O0?ooocL02NX:00@0000000WZ2P1o
Ogl00000aP3oool001l0oooo1`09jPX0103oool0000000000000000V0?ooo`D02NX:0P3oool207mo
OlL0oooo000P0?ooo`802NX:;@3oool200WZ2/l0oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {88.8125, 0}} -> {-566.872, -113.022, 3.59144, \
3.59144}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindWaveFronts[combinedsys]", "Input",
  CellLabel->"In[20]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.450093 0.0587438 -73.178 0.0792938 [
[.00951 -0.0125 -12 -9 ]
[.00951 -0.0125 12 0 ]
[.15637 -0.0125 -6 -9 ]
[.15637 -0.0125 6 0 ]
[.30323 -0.0125 -12 -9 ]
[.30323 -0.0125 12 0 ]
[.45009 -0.0125 -3 -9 ]
[.45009 -0.0125 3 0 ]
[.59695 -0.0125 -9 -9 ]
[.59695 -0.0125 9 0 ]
[.74381 -0.0125 -3 -9 ]
[.74381 -0.0125 3 0 ]
[.89067 -0.0125 -9 -9 ]
[.89067 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01019 -18 -4.5 ]
[-0.0125 .01019 0 4.5 ]
[-0.0125 .08948 -18 -4.5 ]
[-0.0125 .08948 0 4.5 ]
[-0.0125 .16878 -18 -4.5 ]
[-0.0125 .16878 0 4.5 ]
[-0.0125 .24807 -18 -4.5 ]
[-0.0125 .24807 0 4.5 ]
[-0.0125 .32737 -18 -4.5 ]
[-0.0125 .32737 0 4.5 ]
[-0.0125 .40666 -18 -4.5 ]
[-0.0125 .40666 0 4.5 ]
[-0.0125 .48595 -18 -4.5 ]
[-0.0125 .48595 0 4.5 ]
[-0.0125 .56525 -18 -4.5 ]
[-0.0125 .56525 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00951 0 m
.00951 .00625 L
s
[(-7.5)] .00951 -0.0125 0 1 Mshowa
.15637 0 m
.15637 .00625 L
s
[(-5)] .15637 -0.0125 0 1 Mshowa
.30323 0 m
.30323 .00625 L
s
[(-2.5)] .30323 -0.0125 0 1 Mshowa
.45009 0 m
.45009 .00625 L
s
[(0)] .45009 -0.0125 0 1 Mshowa
.59695 0 m
.59695 .00625 L
s
[(2.5)] .59695 -0.0125 0 1 Mshowa
.74381 0 m
.74381 .00625 L
s
[(5)] .74381 -0.0125 0 1 Mshowa
.89067 0 m
.89067 .00625 L
s
[(7.5)] .89067 -0.0125 0 1 Mshowa
.125 Mabswid
.03889 0 m
.03889 .00375 L
s
.06826 0 m
.06826 .00375 L
s
.09763 0 m
.09763 .00375 L
s
.127 0 m
.127 .00375 L
s
.18575 0 m
.18575 .00375 L
s
.21512 0 m
.21512 .00375 L
s
.24449 0 m
.24449 .00375 L
s
.27386 0 m
.27386 .00375 L
s
.33261 0 m
.33261 .00375 L
s
.36198 0 m
.36198 .00375 L
s
.39135 0 m
.39135 .00375 L
s
.42072 0 m
.42072 .00375 L
s
.47947 0 m
.47947 .00375 L
s
.50884 0 m
.50884 .00375 L
s
.53821 0 m
.53821 .00375 L
s
.56758 0 m
.56758 .00375 L
s
.62632 0 m
.62632 .00375 L
s
.6557 0 m
.6557 .00375 L
s
.68507 0 m
.68507 .00375 L
s
.71444 0 m
.71444 .00375 L
s
.77318 0 m
.77318 .00375 L
s
.80256 0 m
.80256 .00375 L
s
.83193 0 m
.83193 .00375 L
s
.8613 0 m
.8613 .00375 L
s
.92004 0 m
.92004 .00375 L
s
.94942 0 m
.94942 .00375 L
s
.97879 0 m
.97879 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01019 m
.00625 .01019 L
s
[(923)] -0.0125 .01019 1 0 Mshowa
0 .08948 m
.00625 .08948 L
s
[(924)] -0.0125 .08948 1 0 Mshowa
0 .16878 m
.00625 .16878 L
s
[(925)] -0.0125 .16878 1 0 Mshowa
0 .24807 m
.00625 .24807 L
s
[(926)] -0.0125 .24807 1 0 Mshowa
0 .32737 m
.00625 .32737 L
s
[(927)] -0.0125 .32737 1 0 Mshowa
0 .40666 m
.00625 .40666 L
s
[(928)] -0.0125 .40666 1 0 Mshowa
0 .48595 m
.00625 .48595 L
s
[(929)] -0.0125 .48595 1 0 Mshowa
0 .56525 m
.00625 .56525 L
s
[(930)] -0.0125 .56525 1 0 Mshowa
.125 Mabswid
0 .02605 m
.00375 .02605 L
s
0 .04191 m
.00375 .04191 L
s
0 .05777 m
.00375 .05777 L
s
0 .07363 m
.00375 .07363 L
s
0 .10534 m
.00375 .10534 L
s
0 .1212 m
.00375 .1212 L
s
0 .13706 m
.00375 .13706 L
s
0 .15292 m
.00375 .15292 L
s
0 .18464 m
.00375 .18464 L
s
0 .2005 m
.00375 .2005 L
s
0 .21635 m
.00375 .21635 L
s
0 .23221 m
.00375 .23221 L
s
0 .26393 m
.00375 .26393 L
s
0 .27979 m
.00375 .27979 L
s
0 .29565 m
.00375 .29565 L
s
0 .31151 m
.00375 .31151 L
s
0 .34322 m
.00375 .34322 L
s
0 .35908 m
.00375 .35908 L
s
0 .37494 m
.00375 .37494 L
s
0 .3908 m
.00375 .3908 L
s
0 .42252 m
.00375 .42252 L
s
0 .43838 m
.00375 .43838 L
s
0 .45424 m
.00375 .45424 L
s
0 .47009 m
.00375 .47009 L
s
0 .50181 m
.00375 .50181 L
s
0 .51767 m
.00375 .51767 L
s
0 .53353 m
.00375 .53353 L
s
0 .54939 m
.00375 .54939 L
s
0 .58111 m
.00375 .58111 L
s
0 .59696 m
.00375 .59696 L
s
0 .61282 m
.00375 .61282 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00951 .61178 m
.00951 .61803 L
s
.15637 .61178 m
.15637 .61803 L
s
.30323 .61178 m
.30323 .61803 L
s
.45009 .61178 m
.45009 .61803 L
s
.59695 .61178 m
.59695 .61803 L
s
.74381 .61178 m
.74381 .61803 L
s
.89067 .61178 m
.89067 .61803 L
s
.125 Mabswid
.03889 .61428 m
.03889 .61803 L
s
.06826 .61428 m
.06826 .61803 L
s
.09763 .61428 m
.09763 .61803 L
s
.127 .61428 m
.127 .61803 L
s
.18575 .61428 m
.18575 .61803 L
s
.21512 .61428 m
.21512 .61803 L
s
.24449 .61428 m
.24449 .61803 L
s
.27386 .61428 m
.27386 .61803 L
s
.33261 .61428 m
.33261 .61803 L
s
.36198 .61428 m
.36198 .61803 L
s
.39135 .61428 m
.39135 .61803 L
s
.42072 .61428 m
.42072 .61803 L
s
.47947 .61428 m
.47947 .61803 L
s
.50884 .61428 m
.50884 .61803 L
s
.53821 .61428 m
.53821 .61803 L
s
.56758 .61428 m
.56758 .61803 L
s
.62632 .61428 m
.62632 .61803 L
s
.6557 .61428 m
.6557 .61803 L
s
.68507 .61428 m
.68507 .61803 L
s
.71444 .61428 m
.71444 .61803 L
s
.77318 .61428 m
.77318 .61803 L
s
.80256 .61428 m
.80256 .61803 L
s
.83193 .61428 m
.83193 .61803 L
s
.8613 .61428 m
.8613 .61803 L
s
.92004 .61428 m
.92004 .61803 L
s
.94942 .61428 m
.94942 .61803 L
s
.97879 .61428 m
.97879 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01019 m
1 .01019 L
s
.99375 .08948 m
1 .08948 L
s
.99375 .16878 m
1 .16878 L
s
.99375 .24807 m
1 .24807 L
s
.99375 .32737 m
1 .32737 L
s
.99375 .40666 m
1 .40666 L
s
.99375 .48595 m
1 .48595 L
s
.99375 .56525 m
1 .56525 L
s
.125 Mabswid
.99625 .02605 m
1 .02605 L
s
.99625 .04191 m
1 .04191 L
s
.99625 .05777 m
1 .05777 L
s
.99625 .07363 m
1 .07363 L
s
.99625 .10534 m
1 .10534 L
s
.99625 .1212 m
1 .1212 L
s
.99625 .13706 m
1 .13706 L
s
.99625 .15292 m
1 .15292 L
s
.99625 .18464 m
1 .18464 L
s
.99625 .2005 m
1 .2005 L
s
.99625 .21635 m
1 .21635 L
s
.99625 .23221 m
1 .23221 L
s
.99625 .26393 m
1 .26393 L
s
.99625 .27979 m
1 .27979 L
s
.99625 .29565 m
1 .29565 L
s
.99625 .31151 m
1 .31151 L
s
.99625 .34322 m
1 .34322 L
s
.99625 .35908 m
1 .35908 L
s
.99625 .37494 m
1 .37494 L
s
.99625 .3908 m
1 .3908 L
s
.99625 .42252 m
1 .42252 L
s
.99625 .43838 m
1 .43838 L
s
.99625 .45424 m
1 .45424 L
s
.99625 .47009 m
1 .47009 L
s
.99625 .50181 m
1 .50181 L
s
.99625 .51767 m
1 .51767 L
s
.99625 .53353 m
1 .53353 L
s
.99625 .54939 m
1 .54939 L
s
.99625 .58111 m
1 .58111 L
s
.99625 .59696 m
1 .59696 L
s
.99625 .61282 m
1 .61282 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.45009 0 m
.45009 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.06085 .02374 Mdot
.09401 .03287 Mdot
.12438 .04214 Mdot
.15272 .05157 Mdot
.17956 .0612 Mdot
.2053 .07107 Mdot
.23025 .08124 Mdot
.25463 .09173 Mdot
.27863 .10259 Mdot
.3024 .11385 Mdot
.32605 .12555 Mdot
.34968 .13773 Mdot
.3734 .15042 Mdot
.39728 .16368 Mdot
.4214 .17754 Mdot
.44585 .19206 Mdot
.4707 .2073 Mdot
.49606 .22333 Mdot
.52202 .24024 Mdot
.5487 .25812 Mdot
.57624 .2771 Mdot
.60481 .29733 Mdot
.63461 .31902 Mdot
.66591 .34242 Mdot
.69904 .36784 Mdot
.73445 .39573 Mdot
.77272 .42667 Mdot
.81465 .46147 Mdot
.86136 .50128 Mdot
.91443 .54774 Mdot
.5 Mabswid
.02381 .01472 m
.05372 .022 L
.08634 .03076 L
.11698 .03988 L
.14644 .04948 L
.1778 .06057 L
.20799 .07217 L
.24008 .08547 L
.27099 .09913 L
.30073 .11306 L
.33237 .12881 L
.36283 .14477 L
.39213 .16082 L
.42332 .17868 L
.45333 .19665 L
.48525 .2165 L
.51599 .23631 L
.54556 .25601 L
.57703 .27765 L
.60732 .29917 L
.63951 .32269 L
.67053 .34597 L
.70038 .36889 L
.73212 .3939 L
.76269 .41857 L
.79209 .44275 L
.82339 .46892 L
.85351 .49459 L
.88553 .52244 L
.91638 .54949 L
.94605 .5762 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`00000L0?oo
o`<000006P3oool5000000<0oooo00<000000?ooo`3oool00P3oool3000001T0oooo0P00000J0?oo
o`D000000`3oool00`000000oooo0?ooo`020?ooo`<00000703oool3000001`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000007`3oool001`0oooo00<000000?ooo`3o
ool01`3oool01@000000oooo0?ooo`3oool0000001X0oooo00D000000?ooo`3oool0oooo0000000J
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`040000
003oool0oooo000001X0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0
000001X0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo0000000N0?ooo`00503oool5000000@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0B0?ooo`D000001@3oool00`000000oooo0?ooo`0A0?ooo`D000000`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool00000
6`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo000M0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`00000L0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0703oool001h0oooo00<000000?ooo`3oool01@3o
ool4000001/0oooo1000000J0?ooo`050000003oool0oooo0?ooo`0000001`3oool4000001P0oooo
00@000000?ooo`3oool000006@3oool01@000000oooo0?ooo`3oool0000000L0oooo1000000K0?oo
o`@000007P3oool00`000000oooo0?ooo`050?ooo`@000007`3oool001X0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00
000I0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01/0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0200
oooo000J0?ooo`D000001`3oool5000001X0oooo1@00000J0?ooo`<00000203oool5000001P0oooo
0P00000K0?ooo`<00000203oool5000001X0oooo1@00000I0?ooo`D000001`3oool5000001h0oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000:0?ooo`800000
0`3oool500000080oooo0`0000050?ooooP000002P3oool000`0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo000=0?ooo`050000003oool0oooo0?ooo`000000
1`3oool00`000000oooo0?ooo`020?ooo`800000K@3oool00`000000oooo0?ooo`240?ooo`800000
2P3oool000X0oooo100000040?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003o
ool0oooo00<0oooo0`00001V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0203o
ool000T0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo0`00001S0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0203oool000T0oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo1000001O0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool0203oool000X0oooo0`0000030?ooo`<000000`3oool3000000D0oooo0P00000<0?ooo`H00000
F`3oool00`000000oooo0?ooo`240?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool04@3o
ool4000005L0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`080?ooo`007P3oool0
0`000000oooo0?ooo`0C0?ooo`@00000E@3oool00`000000oooo0?ooo`250?ooo`030000003oool0
oooo00P0oooo000N0?ooo`030000003oool0oooo01L0oooo0`00001B0?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`3oool0203oool001h0oooo0P00000K0?ooo`<00000C`3oool00`000000
oooo0?ooo`240?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool06`3oool5000004`0oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?oo
o`0P0?ooo`@00000B03oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo00P0oooo000N
0?ooo`030000003oool0oooo0280oooo100000160?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0203oool001h0oooo0P00000W0?ooo`D00000@@3oool00`000000oooo0?ooo`240?oo
o`8000002P3oool001h0oooo00<000000?ooo`3oool0:@3oool300000400oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0/0?ooo`<00000
?@3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003o
ool0oooo02l0oooo0`00000j0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0203o
ool001h0oooo0P00000`0?ooo`80000000<0oooo000000000000>03oool00`000000oooo0?ooo`24
0?ooo`8000002P3oool000X0oooo0P0000030?ooo`D000000`3oool3000000@0oooo00<000000?oo
o`3oool0=03oool3000003D0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`080?oo
o`00303oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03D0oooo0`00000d0?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`3oool0203oool000d0oooo00D000000?ooo`3oool0oooo000000030?oo
o`D00000103oool00`000000oooo0?ooo`0h0?ooo`800000<P3oool00`000000oooo0?ooo`250?oo
o`030000003oool0oooo00P0oooo000:0?ooo`@00000103oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo0P00000k0?ooo`<00000;`3oool00`000000oooo0?ooo`240?oo
o`8000002P3oool000T0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00H00000
0?ooo`3oool000000?ooo`0000050?ooo`030000003oool0oooo03/0oooo1@00000/0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0203oool000T0oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`030000003oool0oooo
0400oooo0P00000Z0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0203oool000X0
oooo0`0000030?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0440
oooo0`00000X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0203oool001h0oooo
0P0000120?ooo`80000000<0oooo0000003oool09P3oool00`000000oooo0?ooo`240?ooo`800000
2P3oool001h0oooo00<000000?ooo`3oool0A@3oool4000002<0oooo00<000000?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`170?ooo`8000008`3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo
04T0oooo0`00000P0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0203oool001h0
oooo0P00001=0?ooo`<000007@3oool00`000000oooo0?ooo`240?ooo`8000002P3oool001h0oooo
00<000000?ooo`3oool0C@3oool4000001/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1A0?ooo`8000006@3oool00`000000oooo0?oo
o`250?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo05<0oooo0P00000G
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0203oool001h0oooo0P00001D0?oo
o`@000005@3oool00`000000oooo0?ooo`240?ooo`8000002P3oool001h0oooo00<000000?ooo`3o
ool0E`3oool2000001<0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`080?ooo`00
7P3oool00`000000oooo0?ooo`1I0?ooo`8000004@3oool00`000000oooo0?ooo`250?ooo`030000
003oool0oooo00P0oooo000N0?ooo`800000FP3oool300000100oooo00<000000?ooo`3oool0Q03o
ool2000000X0oooo000N0?ooo`030000003oool0oooo05T0oooo0P0000000`3oool000000000000>
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0203oool000X0oooo0P0000030?oo
o`D000000P3oool3000000D0oooo00<000000?ooo`3oool0GP3oool2000000`0oooo00<000000?oo
o`3oool0Q@3oool00`000000oooo0?ooo`080?ooo`00303oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
05h0oooo0`00000;0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0203oool000d0
oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0080oooo0P00001O0?oo
o`80000000<0oooo0000000000002@3oool00`000000oooo0?ooo`240?ooo`8000002P3oool000X0
oooo100000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1S0?ooo`8000001`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo00P0
oooo00090?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool00000
00<000001@3oool00`000000oooo0?ooo`1T0?ooo`8000001P3oool00`000000oooo0?ooo`250?oo
o`030000003oool0oooo00P0oooo00090?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0I03oool4000000@0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`080?ooo`002P3oool3000000<0oooo0`0000020?oo
o`D00000103oool2000006T0oooo0P0000020?ooo`030000003oool0oooo08@0oooo0P00000:0?oo
o`007P3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0000008L0oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool0JP3oool3000008L0oooo00<000000?ooo`3oool0
203oool001h0oooo00<000000?ooo`3oool0JP3oool5000008D0oooo00<000000?ooo`3oool0203o
ool001h0oooo0P00001]0?ooo`040000003oool0oooo000008<0oooo0P00000:0?ooo`007P3oool0
0`000000oooo0?ooo`1/0?ooo`040000003oool0oooo0?ooo`800000PP3oool00`000000oooo0?oo
o`080?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0080oooo0`000020
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool00P3oool2000000030?ooo`000000oooo07h0oooo00<000000?ooo`3oool0203oool001h0
oooo0P00001]0?ooo`030000003oool0oooo00H0oooo0P00001l0?ooo`8000002P3oool001h0oooo
00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`080?ooo`<00000NP3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1/
0?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`1h0?ooo`030000003oool0
oooo00P0oooo000N0?ooo`800000K@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
07D0oooo0P00000:0?ooo`002P3oool2000000<0oooo1@0000020?ooo`<000001@3oool00`000000
oooo0?ooo`1/0?ooo`030000003oool0oooo00d0oooo0P00001f0?ooo`030000003oool0oooo00P0
oooo000<0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0>0?ooo`80
0000M@3oool00`000000oooo0?ooo`080?ooo`003@3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool03P3oool4000007<0oooo00<000000?ooo`3oool0203oool000X0oooo100000040?ooo`03
0000003oool0oooo00@000001@3oool2000006d0oooo00<000000?ooo`3oool04P3oool200000700
oooo0P00000:0?ooo`002@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`00
0000oooo000000080?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`1^0?ooo`030000003oool0oooo00P0oooo00090?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0K03o
ool00`000000oooo0?ooo`0E0?ooo`800000KP3oool00`000000oooo0?ooo`080?ooo`002P3oool3
000000<0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo01D0oooo0`00001]0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000K@3oool00`00
0000oooo0?ooo`0H0?ooo`800000JP3oool2000000X0oooo000N0?ooo`030000003oool0oooo06`0
oooo00<000000?ooo`3oool06P3oool2000006T0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`0L0?ooo`<00000IP3oool00`000000oooo0?ooo`080?ooo`007P3oool2000006d0oooo00<00000
0?ooo`3oool0703oool2000000030?ooo`000000oooo06<0oooo0P00000:0?ooo`007P3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`080?ooo`007P3oool2000006d0oooo00<000000?ooo`3oool08`3oool2000005l0oooo0P00
000:0?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo02<0oooo0`00001O
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool09`3oool2000005`0oooo00<000000?ooo`3o
ool0203oool001h0oooo0P00001]0?ooo`030000003oool0oooo02T0oooo0P00001I0?ooo`800000
2P3oool000X0oooo0P0000030?ooo`D000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0:P3oool2000005T0oooo00<000000?ooo`3oool0203o
ool000`0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo02X0oooo1000001G0?ooo`030000
003oool0oooo00P0oooo000=0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo00P0oooo000:0?ooo`@00000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo0P00001]0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0DP3oool2000000X0oooo00090?ooo`070000003oool0oooo0?ooo`000000oooo
000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo0300oooo0P00001C0?ooo`030000003oool0oooo00P0oooo
00090?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`080?ooo`002P3oool3000000<0oooo
0`0000020?ooo`D00000103oool2000006d0oooo00<000000?ooo`3oool0<P3oool200000500oooo
0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0380oooo1000
001?0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00P0oooo000N0?oo
o`030000003oool0oooo06`0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo00P0oooo000N0?ooo`800000K@3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo04T0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo03X0oooo0P0000190?ooo`030000003o
ool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0>P3oool3
000004P0oooo00<000000?ooo`3oool0203oool001h0oooo0P00001]0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0A03oool2000000X0oooo000N0?ooo`030000003oool0oooo06`0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0?`3oool2000004@0oooo
00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0203oool001h0oooo0P00001]
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0?`3oool2000000X0oooo000N0?oo
o`030000003oool0oooo06`0oooo00<000000?ooo`3oool0@`3oool200000400oooo00<000000?oo
o`3oool0203oool000X0oooo0P0000030?ooo`D000000P3oool3000000D0oooo00<000000?ooo`3o
ool0K03oool00`000000oooo0?ooo`130?ooo`<00000?`3oool00`000000oooo0?ooo`080?ooo`00
303oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo00P0oooo000=0?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000@0oooo0P00001]0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0>P3oool2000000X0oooo000:0?ooo`@00000103oool010000000
oooo0?ooo`3oool3000000D0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0203oool000T0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo00P0oooo00090?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1/0?ooo`030000003oool0oooo04X0oooo0P00000i0?ooo`030000003oool0oooo00P0oooo000:
0?ooo`<000000`3oool3000000<0oooo0`0000050?ooo`800000K@3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo03D0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1/0?oo
o`030000003oool0oooo04`0oooo0P00000g0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool0C03oool4000003D0oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0203oool001h0oooo0P00001]0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool0<03oool2000000X0oooo000N0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00P0
oooo000N0?ooo`800000K@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo02`0oooo
0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo05H0oooo0`00
000/0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool0E`3oool2000002`0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?oo
o`3oool0K03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0203oool001h0oooo0P00001]0?ooo`030000003oool0oooo05T0oooo0P00000Y0?ooo`80
00002P3oool000X0oooo0P0000030?ooo`D000000P3oool2000000H0oooo00<000000?ooo`3oool0
K03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
203oool000`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo05`0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`003@3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1/0?ooo`030000
003oool0oooo05d0oooo0P00000V0?ooo`030000003oool0oooo00P0oooo000:0?ooo`@00000103o
ool010000000oooo0?ooo`3oool4000000@0oooo0P00001]0?ooo`030000003oool0oooo05l0oooo
00<000000?ooo`3oool08P3oool2000000X0oooo00090?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1/0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`080?ooo`002@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`1Q0?ooo`8000008P3oool00`000000oooo0?ooo`080?ooo`002P3oool3000000<0
oooo0`0000030?ooo`<000001@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0680
oooo0P00000Q0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000K@3oool00`000000oooo
0?ooo`1R0?ooo`<000007`3oool2000000X0oooo000N0?ooo`030000003oool0oooo06`0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo000N
0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo000N0?ooo`80
0000K@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo01T0oooo0P00000:0?ooo`00
7P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06T0oooo0P00000J0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0J`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00P0oooo000N0?ooo`800000K@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
01@0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`080?ooo`007P3oool2000006d0oooo00<000000?ooo`3oool0K`3oool300000180oooo0P00
000:0?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06l0oooo0P000000
0`3oool000000?ooo`0A0?ooo`030000003oool0oooo00P0oooo000:0?ooo`800000103oool30000
00@0oooo0P0000050?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo000<0?ooo`040000003oool0oooo0000
00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00P0oooo000=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`800000K@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0
oooo00`0oooo0P00000:0?ooo`002P3oool4000000<0oooo0P0000030?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0203oool000T0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1/0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`080?ooo`002@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0K03oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool000X0oooo
0`0000030?ooo`<00000103oool2000000D0oooo0P00001]0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0203oool2000000X0oooo000N0?ooo`030000003oool0oooo06`0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo000N
0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo000N0?ooo`80
0000K@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`00
7P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`007P3oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0203oool0
01h0oooo0`0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`3oool2000000X0oooo000N0?ooooP000002P3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool002X0oooo0`00001H0?ooo`<000005`3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo01@0oooo000[0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo01<0oooo000U0?ooo`<0
00000`3oool3000000@0oooo0P0000020?ooo`D000000P3oool3000000<0oooo100000000`3oool0
000000000003000000L0oooo0`0000040?ooo`@000000`3oool200000080oooo1P0000060?ooo`D0
00000P3oool300000080oooo0`000000103oool000000000003oool4000000<0oooo0P0000020?oo
o`H000001`3oool00`000000oooo0?ooo`030?ooo`@0000000<0oooo0000000000000P0000020?oo
o`@000000`3oool300000080oooo1@0000030?ooo`80000000@0oooo0000003oool0oooo0P000003
0?ooo`<000002@3oool4000000030?ooo`000000000000<0000000<0oooo0000000000000P000004
0?ooo`8000000`3oool4000000050?ooo`00000000000000003oool00P000000103oool000000000
000000030?ooo`<000001@3oool00`000000oooo0?ooo`0B0?ooo`00903oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`06
0000003oool0oooo0000003oool000001P3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000/0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000080?ooo`030000003oool0oooo0180oooo000T0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000103oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`020?ooo`D000000P3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`040000003oool0oooo00000080oooo0`00
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool5000000L0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`030?oo
o`<000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo1@0000040?ooo`030000003o
ool0oooo0180oooo000T0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`<0
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000001@3oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3o
ool01P000000oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`0000040?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`00903oool01P000000oooo0?ooo`3o
ool000000?ooo`@000000P3oool400000080oooo0`0000040?ooo`<000000`3oool2000000D0oooo
00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000020?ooo`8000000`3oool4000000<0
oooo0`0000090?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`@000000`3oool9000000<0
oooo0`0000090?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`<000000`3oool400000080
oooo0`0000040?ooo`040000003oool0oooo0?ooo`80000000@0oooo000000000000oooo10000003
0?ooo`<000002@3oool300000080oooo0`0000040?ooo`@0000000<0oooo0000000000000P000003
0?ooo`8000000`3oool4000000<0oooo0`0000030?ooo`<000001@3oool00`000000oooo0?ooo`0B
0?ooo`00903oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`080?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo000U0?ooo`<000002@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo0`0000090?ooo`@000002@3oool0
0`000000oooo0?ooo`020?ooo`8000002P3oool3000001H0oooo00<000000?ooo`3oool00P3oool2
000000d0oooo00<000000?ooo`3oool01P3oool200000100oooo0`00000:0?ooo`030000003oool0
oooo0100oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0D0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.75561, 922.255, \
0.0688727, 0.0510235}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.450093 0.0587438 -0.350209 0.00733599 [
[.00951 -0.0125 -12 -9 ]
[.00951 -0.0125 12 0 ]
[.15637 -0.0125 -6 -9 ]
[.15637 -0.0125 6 0 ]
[.30323 -0.0125 -12 -9 ]
[.30323 -0.0125 12 0 ]
[.45009 -0.0125 -3 -9 ]
[.45009 -0.0125 3 0 ]
[.59695 -0.0125 -9 -9 ]
[.59695 -0.0125 9 0 ]
[.74381 -0.0125 -3 -9 ]
[.74381 -0.0125 3 0 ]
[.89067 -0.0125 -9 -9 ]
[.89067 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08995 -12 -4.5 ]
[-0.0125 .08995 0 4.5 ]
[-0.0125 .23667 -12 -4.5 ]
[-0.0125 .23667 0 4.5 ]
[-0.0125 .38339 -18 -4.5 ]
[-0.0125 .38339 0 4.5 ]
[-0.0125 .53011 -18 -4.5 ]
[-0.0125 .53011 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00951 0 m
.00951 .00625 L
s
[(-7.5)] .00951 -0.0125 0 1 Mshowa
.15637 0 m
.15637 .00625 L
s
[(-5)] .15637 -0.0125 0 1 Mshowa
.30323 0 m
.30323 .00625 L
s
[(-2.5)] .30323 -0.0125 0 1 Mshowa
.45009 0 m
.45009 .00625 L
s
[(0)] .45009 -0.0125 0 1 Mshowa
.59695 0 m
.59695 .00625 L
s
[(2.5)] .59695 -0.0125 0 1 Mshowa
.74381 0 m
.74381 .00625 L
s
[(5)] .74381 -0.0125 0 1 Mshowa
.89067 0 m
.89067 .00625 L
s
[(7.5)] .89067 -0.0125 0 1 Mshowa
.125 Mabswid
.03889 0 m
.03889 .00375 L
s
.06826 0 m
.06826 .00375 L
s
.09763 0 m
.09763 .00375 L
s
.127 0 m
.127 .00375 L
s
.18575 0 m
.18575 .00375 L
s
.21512 0 m
.21512 .00375 L
s
.24449 0 m
.24449 .00375 L
s
.27386 0 m
.27386 .00375 L
s
.33261 0 m
.33261 .00375 L
s
.36198 0 m
.36198 .00375 L
s
.39135 0 m
.39135 .00375 L
s
.42072 0 m
.42072 .00375 L
s
.47947 0 m
.47947 .00375 L
s
.50884 0 m
.50884 .00375 L
s
.53821 0 m
.53821 .00375 L
s
.56758 0 m
.56758 .00375 L
s
.62632 0 m
.62632 .00375 L
s
.6557 0 m
.6557 .00375 L
s
.68507 0 m
.68507 .00375 L
s
.71444 0 m
.71444 .00375 L
s
.77318 0 m
.77318 .00375 L
s
.80256 0 m
.80256 .00375 L
s
.83193 0 m
.83193 .00375 L
s
.8613 0 m
.8613 .00375 L
s
.92004 0 m
.92004 .00375 L
s
.94942 0 m
.94942 .00375 L
s
.97879 0 m
.97879 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08995 m
.00625 .08995 L
s
[(60)] -0.0125 .08995 1 0 Mshowa
0 .23667 m
.00625 .23667 L
s
[(80)] -0.0125 .23667 1 0 Mshowa
0 .38339 m
.00625 .38339 L
s
[(100)] -0.0125 .38339 1 0 Mshowa
0 .53011 m
.00625 .53011 L
s
[(120)] -0.0125 .53011 1 0 Mshowa
.125 Mabswid
0 .12663 m
.00375 .12663 L
s
0 .16331 m
.00375 .16331 L
s
0 .19999 m
.00375 .19999 L
s
0 .27335 m
.00375 .27335 L
s
0 .31003 m
.00375 .31003 L
s
0 .34671 m
.00375 .34671 L
s
0 .42007 m
.00375 .42007 L
s
0 .45675 m
.00375 .45675 L
s
0 .49343 m
.00375 .49343 L
s
0 .05327 m
.00375 .05327 L
s
0 .01659 m
.00375 .01659 L
s
0 .56679 m
.00375 .56679 L
s
0 .60347 m
.00375 .60347 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00951 .61178 m
.00951 .61803 L
s
.15637 .61178 m
.15637 .61803 L
s
.30323 .61178 m
.30323 .61803 L
s
.45009 .61178 m
.45009 .61803 L
s
.59695 .61178 m
.59695 .61803 L
s
.74381 .61178 m
.74381 .61803 L
s
.89067 .61178 m
.89067 .61803 L
s
.125 Mabswid
.03889 .61428 m
.03889 .61803 L
s
.06826 .61428 m
.06826 .61803 L
s
.09763 .61428 m
.09763 .61803 L
s
.127 .61428 m
.127 .61803 L
s
.18575 .61428 m
.18575 .61803 L
s
.21512 .61428 m
.21512 .61803 L
s
.24449 .61428 m
.24449 .61803 L
s
.27386 .61428 m
.27386 .61803 L
s
.33261 .61428 m
.33261 .61803 L
s
.36198 .61428 m
.36198 .61803 L
s
.39135 .61428 m
.39135 .61803 L
s
.42072 .61428 m
.42072 .61803 L
s
.47947 .61428 m
.47947 .61803 L
s
.50884 .61428 m
.50884 .61803 L
s
.53821 .61428 m
.53821 .61803 L
s
.56758 .61428 m
.56758 .61803 L
s
.62632 .61428 m
.62632 .61803 L
s
.6557 .61428 m
.6557 .61803 L
s
.68507 .61428 m
.68507 .61803 L
s
.71444 .61428 m
.71444 .61803 L
s
.77318 .61428 m
.77318 .61803 L
s
.80256 .61428 m
.80256 .61803 L
s
.83193 .61428 m
.83193 .61803 L
s
.8613 .61428 m
.8613 .61803 L
s
.92004 .61428 m
.92004 .61803 L
s
.94942 .61428 m
.94942 .61803 L
s
.97879 .61428 m
.97879 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08995 m
1 .08995 L
s
.99375 .23667 m
1 .23667 L
s
.99375 .38339 m
1 .38339 L
s
.99375 .53011 m
1 .53011 L
s
.125 Mabswid
.99625 .12663 m
1 .12663 L
s
.99625 .16331 m
1 .16331 L
s
.99625 .19999 m
1 .19999 L
s
.99625 .27335 m
1 .27335 L
s
.99625 .31003 m
1 .31003 L
s
.99625 .34671 m
1 .34671 L
s
.99625 .42007 m
1 .42007 L
s
.99625 .45675 m
1 .45675 L
s
.99625 .49343 m
1 .49343 L
s
.99625 .05327 m
1 .05327 L
s
.99625 .01659 m
1 .01659 L
s
.99625 .56679 m
1 .56679 L
s
.99625 .60347 m
1 .60347 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .08995 m
1 .08995 L
s
.45009 0 m
.45009 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.01 w
.06085 .25829 Mdot
.09401 .32934 Mdot
.12438 .39186 Mdot
.15272 .44524 Mdot
.17956 .48955 Mdot
.2053 .52527 Mdot
.23025 .55316 Mdot
.25463 .57406 Mdot
.27863 .58881 Mdot
.3024 .59817 Mdot
.32605 .60282 Mdot
.34968 .60332 Mdot
.3734 .60014 Mdot
.39728 .59364 Mdot
.4214 .58408 Mdot
.44585 .57165 Mdot
.4707 .55647 Mdot
.49606 .53858 Mdot
.52202 .51795 Mdot
.5487 .49453 Mdot
.57624 .46818 Mdot
.60481 .43876 Mdot
.63461 .40605 Mdot
.66591 .36987 Mdot
.69904 .33 Mdot
.73445 .28629 Mdot
.77272 .23868 Mdot
.81465 .18725 Mdot
.86136 .13231 Mdot
.91443 .07448 Mdot
.5 Mabswid
.02381 .25829 m
.03837 .25829 L
.04579 .25829 L
.05372 .25829 L
.05589 .25829 L
.05794 .25829 L
.05978 .25829 L
.06029 .25829 L
.06082 .25829 L
.06178 .26029 L
.06929 .27637 L
.08634 .3129 L
.11563 .37384 L
.14682 .43414 L
.17684 .48506 L
.20876 .52914 L
.2395 .56109 L
.26907 .58293 L
.2843 .59104 L
.29275 .59437 L
.30053 .59743 L
.3015 .59781 L
.30203 .59802 L
.30254 .59819 L
.30351 .59839 L
.30441 .59856 L
.30636 .59895 L
.3085 .59937 L
.31711 .60106 L
.32074 .60177 L
.32459 .60253 L
.32556 .60272 L
.3261 .60282 L
.3266 .60283 L
.32774 .60285 L
.32882 .60287 L
.33273 .60296 L
.33981 .60311 L
.3437 .60319 L
.34738 .60327 L
.34839 .60329 L
.34895 .6033 L
.34946 .60331 L
.35003 .60327 L
.35064 .60319 L
.35173 .60304 L
.35568 .60251 L
.3634 .60148 L
.36726 .60096 L
.36929 .60069 L
Mistroke
.37146 .6004 L
.37253 .60025 L
.37354 .6001 L
.37445 .59985 L
.37543 .59959 L
.37911 .59858 L
.39346 .59468 L
.40893 .58902 L
.42525 .58212 L
.45468 .56626 L
.48602 .54566 L
.51618 .52259 L
.54825 .49493 L
.57913 .4652 L
.60885 .43432 L
.64046 .39929 L
.6709 .36386 L
.70017 .32861 L
.73133 .29014 L
.76133 .25286 L
.79322 .21354 L
.82393 .17634 L
.85348 .14159 L
.88492 .10664 L
.91519 .07374 L
.94736 .04262 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`00000L0?oo
o`<000006P3oool5000000<0oooo00<000000?ooo`3oool00P3oool3000001T0oooo0P00000J0?oo
o`D000000`3oool00`000000oooo0?ooo`020?ooo`<00000703oool3000001`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000007`3oool001`0oooo00<000000?ooo`3o
ool01`3oool01@000000oooo0?ooo`3oool0000001X0oooo00D000000?ooo`3oool0oooo0000000J
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`040000
003oool0oooo000001X0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0
000001X0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo0000000N0?ooo`00503oool5000000@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0B0?ooo`D000001@3oool00`000000oooo0?ooo`0A0?ooo`D000000`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool00000
6`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo000M0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`00000L0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0703oool001h0oooo00<000000?ooo`3oool01@3o
ool4000001/0oooo1000000J0?ooo`050000003oool0oooo0?ooo`0000001`3oool4000001P0oooo
00@000000?ooo`3oool000006@3oool01@000000oooo0?ooo`3oool0000000L0oooo1000000K0?oo
o`@000007P3oool00`000000oooo0?ooo`050?ooo`@000007`3oool001X0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00
000I0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01/0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0200
oooo000J0?ooo`D000001`3oool5000001X0oooo1@00000J0?ooo`<00000203oool5000001P0oooo
0P00000K0?ooo`<00000203oool5000001X0oooo1@00000I0?ooo`D000001`3oool5000001h0oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000N0?ooooP00000
2P3oool001h0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`007P3oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0203oool0
01h0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool001h0oooo0P00001]0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool00`3oool2000000X0oooo000N0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo
000N0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool0N`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo000N0?oo
o`030000003oool0oooo06`0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo06`0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00P0oooo000N0?ooo`800000K@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
00`0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo07@0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0780oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1/
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06l0oooo0P00000D0?oo
o`030000003oool0oooo00P0oooo000@0?ooo`<00000103oool2000000D0oooo00<000000?ooo`3o
ool0K03oool00`000000oooo0?ooo`1_0?ooo`800000503oool00`000000oooo0?ooo`080?ooo`00
3`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`080?ooo`003`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`003`3oool4000000<0oooo00@000000?oo
o`3oool00000103ooooh000000X0oooo000?0?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`00403oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0203oool00140oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo06T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`00
7P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`007P3oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo
06H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`007P3oool2000006d0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0L0?ooo`8000002P3oool001h0oooo
00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1R0?ooo`<00000803oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0680oooo0P00
000Q0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00P0oooo000N0?oo
o`030000003oool0oooo06`0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo06`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo00P0oooo000N0?ooo`800000K@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo
02@0oooo0P00000:0?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1/
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo05L0oooo0P00000/0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000
003oool0oooo06`0oooo00<000000?ooo`3oool0E`3oool2000002`0oooo00<000000?ooo`3oool0
203oool001h0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0203oool001h0oooo0P00001]0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0;03oool2000000X0oooo000N0?ooo`030000003oool0oooo
06`0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00P0oooo
000N0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00P0oooo000N0?oo
o`030000003oool0oooo06`0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00P0oooo000@0?ooo`<00000103oool2000000D0oooo00<000000?ooo`3o
ool0K03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0203oool000l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0203oool000l0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000000@0oooo0P00001]0?ooo`030000003oool0oooo04`0oooo0`00000e
0?ooo`8000002P3oool00100oooo0`0000030?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0K03oool00`000000oooo0?ooo`1<0?ooo`800000=`3oool00`000000oooo0?ooo`08
0?ooo`003`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`080?ooo`003`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`080?ooo`00403oool3000000@0oooo0P00
00050?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00<0oooo2P00001O
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`0;0?ooo`800000G`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`8000003P3oool00`000000oooo0?ooo`1L0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool0>`3oool2000000X0oooo000N0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool0@`3oool200000400oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo04<0oooo
0P0000100?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0203oool001h0oooo0P00000B0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`120?ooo`800000
2P3oool001h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`080?ooo`007P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0C0?ooo`800000E`3oool00`000000oooo
0?ooo`0j0?ooo`800000B@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?oo
o`0C0?ooo`800000E`3oool00`000000oooo0?ooo`0j0?ooo`800000B@3oool00`000000oooo0?oo
o`080?ooo`007P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00P0oooo000N0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool0203oool001h0oooo0P00000G0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`190?ooo`80
00002P3oool001h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00P0
oooo000N0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`0b0?ooo`800000D@3oool00`000000oooo0?ooo`080?ooo`002P3oool3000000@0oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool0<P3oool200000540oooo00<000000?ooo`3oool0203oool000/0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool2000001/0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0540
oooo0P00000:0?ooo`002`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
00P0oooo000;0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo01/0oooo0P00001?0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`080?ooo`002P3oool20000
00@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo01/0oooo0P00001?0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`030?ooo`800000103oool2
000000D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0Z0?ooo`800000F@3oool00`000000
oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0:P3oool2000005T0oooo00<000000?ooo`3oool0203oool001h0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`080?ooo`007P3oool200000200oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo05T0oooo0P00000:
0?ooo`007P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00P0oooo000N0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
G@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo00P0oooo000N0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0S0?ooo`800000H03oool00`000000oooo0?ooo`080?ooo`007P3oool00`00
0000oooo0?ooo`0R0?ooo`800000B03oool00`000000oooo0?ooo`0S0?ooo`800000H03oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0R0?ooo`800000B03oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo00P0oooo000N0?ooo`8000009@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0HP3oool2000000X0oooo000N0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01`0oooo0P00001W0?ooo`03
0000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0K0?ooo`<00000I`3oool00`000000oooo0?ooo`080?ooo`007P3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0Y0?ooo`800000@@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0203oool001h0oooo
00<000000?ooo`3oool0:@3oool200000440oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo00P0oooo000N0?ooo`800000:`3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo01@0oooo0`00001]0?ooo`8000002P3oool001h0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01<0oooo00@00000
0?ooo`0000000000KP3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0740oooo00<000000?oo
o`3oool0203oool001h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`080?ooo`00
7P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
3P3oool2000007D0oooo00<000000?ooo`3oool0203oool000X0oooo0`0000020?ooo`D000000`3o
ool2000000D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo00h0oooo0P00001e0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo02l0oooo0P00000k0?ooo`030000003oool0oooo00`0oooo0P00001g0?ooo`030000
003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02l0oooo0P00000k0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`080?ooo`002`3o
ool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`800000<P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0M`3oool2000000X0oooo000;0?ooo`050000003oool0oooo0?ooo`000000
0`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00P0oooo0P00001k0?ooo`03
0000003oool0oooo00P0oooo000:0?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0203oool2000007/0oooo00<000000?ooo`3oool0203oool000/0
oooo00<000000?ooo`3oool00P3oool3000000@0oooo0P0000050?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo00D0oooo0P00001n0?ooo`030000003oool0oooo00P0oooo
000N0?ooo`030000003oool0oooo03D0oooo0P00000e0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`0e
0?ooo`<00000=03oool00`000000oooo0?ooo`020?ooo`800000P@3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`0h0?ooo`800000<P3oool00`000000oooo0?ooo`040000
0840oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0000008D0oooo00<000000?ooo`3oool0203oool001h0oooo
0P00000l0?ooo`030000003oool0oooo02h0oooo0P0000250?ooo`8000002P3oool001h0oooo00<0
00000?ooo`3oool0>`3oool2000002d0oooo0`0000270?ooo`030000003oool0oooo00P0oooo000N
0?ooo`030000003oool0oooo03/0oooo0`00000[0?ooo`@00000Q`3oool00`000000oooo0?ooo`08
0?ooo`007P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo02H0oooo0P0000030?oo
o`030000003oool0oooo08D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3o
ool0?`3oool2000002<0oooo0`0000050?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool0203oool001h0oooo00<000000?ooo`3oool0@@3oool2000001h0oooo1@0000060?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0@@3o
ool4000001T0oooo0`00000;0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0203o
ool001h0oooo00<000000?ooo`3oool0A@3oool4000001@0oooo0`00000<0?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0A`3oool80000
00@0oooo0P0000000`3oool0000000000005000000l0oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`080?ooo`007P3oool2000004h0oooo2@0000030?ooo`8000004@3oool00`000000
oooo0?ooo`240?ooo`8000002P3oool001h0oooo00<000000?ooo`3oool0K03oool00`000000oooo
0?ooo`250?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0000000L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool001h0oooon000000:0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00c03oool300000540oooo003=0?ooo`030000003oool0oooo0500oooo001Q0?oo
o`030000003oool0000000<0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000020?oo
o`<000000`3oool3000000@0oooo0`0000020?ooo`<0000000<0oooo0000000000000P3oool20000
00P0oooo1@0000001@3oool00000000000000000oooo008000000P3oool2000000<0oooo0`000002
0?ooo`<0000000<0oooo000000000000100000020?ooo`D000000`3oool2000000@0oooo00<00000
0?ooo`3oool0C`3oool00640oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`000004
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`040000003oool0oooo000000D0
oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0C`3oool00640oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?oo
o`0000000P3oool500000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo1@0000020?ooo`040000003oool0oooo00000080oooo0`0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0000001@0?ooo`00
H03oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo0`0000030?ooo`800000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?oo
o`000000oooo000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool000000500oooo001P0?ooo`050000003oool000000?ooo`0000000P3oool2000000<0
oooo0P0000000`3oool00000000000020?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`80
000000<0oooo0000000000000P3oool300000080oooo100000020?ooo`@000002P3oool010000000
oooo0?ooo`3oool400000080oooo100000030?ooo`<000000P3oool4000000<0oooo10000000103o
ool000000000000000030?ooo`@000000P3oool2000000030?ooo`000000000004l0oooo001P0?oo
o`050000003oool000000?ooo`000000503oool010000000oooo0?ooo`00000D0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo05H0oooo001P0?ooo`H000004P3oool5000001@0oooo00<000000?ooo`3oool0203oool5
000000P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo05H0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.75561, 41.0706, \
0.0688727, 0.551506}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.450093 0.0587438 0.309017 4.21843e-05 [
[.00951 -0.0125 -12 -9 ]
[.00951 -0.0125 12 0 ]
[.15637 -0.0125 -6 -9 ]
[.15637 -0.0125 6 0 ]
[.30323 -0.0125 -12 -9 ]
[.30323 -0.0125 12 0 ]
[.45009 -0.0125 -3 -9 ]
[.45009 -0.0125 3 0 ]
[.59695 -0.0125 -9 -9 ]
[.59695 -0.0125 9 0 ]
[.74381 -0.0125 -3 -9 ]
[.74381 -0.0125 3 0 ]
[.89067 -0.0125 -9 -9 ]
[.89067 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05591 -30 -4.5 ]
[-0.0125 .05591 0 4.5 ]
[-0.0125 .14028 -30 -4.5 ]
[-0.0125 .14028 0 4.5 ]
[-0.0125 .22465 -30 -4.5 ]
[-0.0125 .22465 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .39339 -24 -4.5 ]
[-0.0125 .39339 0 4.5 ]
[-0.0125 .47775 -24 -4.5 ]
[-0.0125 .47775 0 4.5 ]
[-0.0125 .56212 -24 -4.5 ]
[-0.0125 .56212 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00951 0 m
.00951 .00625 L
s
[(-7.5)] .00951 -0.0125 0 1 Mshowa
.15637 0 m
.15637 .00625 L
s
[(-5)] .15637 -0.0125 0 1 Mshowa
.30323 0 m
.30323 .00625 L
s
[(-2.5)] .30323 -0.0125 0 1 Mshowa
.45009 0 m
.45009 .00625 L
s
[(0)] .45009 -0.0125 0 1 Mshowa
.59695 0 m
.59695 .00625 L
s
[(2.5)] .59695 -0.0125 0 1 Mshowa
.74381 0 m
.74381 .00625 L
s
[(5)] .74381 -0.0125 0 1 Mshowa
.89067 0 m
.89067 .00625 L
s
[(7.5)] .89067 -0.0125 0 1 Mshowa
.125 Mabswid
.03889 0 m
.03889 .00375 L
s
.06826 0 m
.06826 .00375 L
s
.09763 0 m
.09763 .00375 L
s
.127 0 m
.127 .00375 L
s
.18575 0 m
.18575 .00375 L
s
.21512 0 m
.21512 .00375 L
s
.24449 0 m
.24449 .00375 L
s
.27386 0 m
.27386 .00375 L
s
.33261 0 m
.33261 .00375 L
s
.36198 0 m
.36198 .00375 L
s
.39135 0 m
.39135 .00375 L
s
.42072 0 m
.42072 .00375 L
s
.47947 0 m
.47947 .00375 L
s
.50884 0 m
.50884 .00375 L
s
.53821 0 m
.53821 .00375 L
s
.56758 0 m
.56758 .00375 L
s
.62632 0 m
.62632 .00375 L
s
.6557 0 m
.6557 .00375 L
s
.68507 0 m
.68507 .00375 L
s
.71444 0 m
.71444 .00375 L
s
.77318 0 m
.77318 .00375 L
s
.80256 0 m
.80256 .00375 L
s
.83193 0 m
.83193 .00375 L
s
.8613 0 m
.8613 .00375 L
s
.92004 0 m
.92004 .00375 L
s
.94942 0 m
.94942 .00375 L
s
.97879 0 m
.97879 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05591 m
.00625 .05591 L
s
[(-6000)] -0.0125 .05591 1 0 Mshowa
0 .14028 m
.00625 .14028 L
s
[(-4000)] -0.0125 .14028 1 0 Mshowa
0 .22465 m
.00625 .22465 L
s
[(-2000)] -0.0125 .22465 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .39339 m
.00625 .39339 L
s
[(2000)] -0.0125 .39339 1 0 Mshowa
0 .47775 m
.00625 .47775 L
s
[(4000)] -0.0125 .47775 1 0 Mshowa
0 .56212 m
.00625 .56212 L
s
[(6000)] -0.0125 .56212 1 0 Mshowa
.125 Mabswid
0 .077 m
.00375 .077 L
s
0 .0981 m
.00375 .0981 L
s
0 .11919 m
.00375 .11919 L
s
0 .16137 m
.00375 .16137 L
s
0 .18246 m
.00375 .18246 L
s
0 .20356 m
.00375 .20356 L
s
0 .24574 m
.00375 .24574 L
s
0 .26683 m
.00375 .26683 L
s
0 .28792 m
.00375 .28792 L
s
0 .33011 m
.00375 .33011 L
s
0 .3512 m
.00375 .3512 L
s
0 .37229 m
.00375 .37229 L
s
0 .41448 m
.00375 .41448 L
s
0 .43557 m
.00375 .43557 L
s
0 .45666 m
.00375 .45666 L
s
0 .49885 m
.00375 .49885 L
s
0 .51994 m
.00375 .51994 L
s
0 .54103 m
.00375 .54103 L
s
0 .03482 m
.00375 .03482 L
s
0 .01373 m
.00375 .01373 L
s
0 .58321 m
.00375 .58321 L
s
0 .60431 m
.00375 .60431 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00951 .61178 m
.00951 .61803 L
s
.15637 .61178 m
.15637 .61803 L
s
.30323 .61178 m
.30323 .61803 L
s
.45009 .61178 m
.45009 .61803 L
s
.59695 .61178 m
.59695 .61803 L
s
.74381 .61178 m
.74381 .61803 L
s
.89067 .61178 m
.89067 .61803 L
s
.125 Mabswid
.03889 .61428 m
.03889 .61803 L
s
.06826 .61428 m
.06826 .61803 L
s
.09763 .61428 m
.09763 .61803 L
s
.127 .61428 m
.127 .61803 L
s
.18575 .61428 m
.18575 .61803 L
s
.21512 .61428 m
.21512 .61803 L
s
.24449 .61428 m
.24449 .61803 L
s
.27386 .61428 m
.27386 .61803 L
s
.33261 .61428 m
.33261 .61803 L
s
.36198 .61428 m
.36198 .61803 L
s
.39135 .61428 m
.39135 .61803 L
s
.42072 .61428 m
.42072 .61803 L
s
.47947 .61428 m
.47947 .61803 L
s
.50884 .61428 m
.50884 .61803 L
s
.53821 .61428 m
.53821 .61803 L
s
.56758 .61428 m
.56758 .61803 L
s
.62632 .61428 m
.62632 .61803 L
s
.6557 .61428 m
.6557 .61803 L
s
.68507 .61428 m
.68507 .61803 L
s
.71444 .61428 m
.71444 .61803 L
s
.77318 .61428 m
.77318 .61803 L
s
.80256 .61428 m
.80256 .61803 L
s
.83193 .61428 m
.83193 .61803 L
s
.8613 .61428 m
.8613 .61803 L
s
.92004 .61428 m
.92004 .61803 L
s
.94942 .61428 m
.94942 .61803 L
s
.97879 .61428 m
.97879 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05591 m
1 .05591 L
s
.99375 .14028 m
1 .14028 L
s
.99375 .22465 m
1 .22465 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .39339 m
1 .39339 L
s
.99375 .47775 m
1 .47775 L
s
.99375 .56212 m
1 .56212 L
s
.125 Mabswid
.99625 .077 m
1 .077 L
s
.99625 .0981 m
1 .0981 L
s
.99625 .11919 m
1 .11919 L
s
.99625 .16137 m
1 .16137 L
s
.99625 .18246 m
1 .18246 L
s
.99625 .20356 m
1 .20356 L
s
.99625 .24574 m
1 .24574 L
s
.99625 .26683 m
1 .26683 L
s
.99625 .28792 m
1 .28792 L
s
.99625 .33011 m
1 .33011 L
s
.99625 .3512 m
1 .3512 L
s
.99625 .37229 m
1 .37229 L
s
.99625 .41448 m
1 .41448 L
s
.99625 .43557 m
1 .43557 L
s
.99625 .45666 m
1 .45666 L
s
.99625 .49885 m
1 .49885 L
s
.99625 .51994 m
1 .51994 L
s
.99625 .54103 m
1 .54103 L
s
.99625 .03482 m
1 .03482 L
s
.99625 .01373 m
1 .01373 L
s
.99625 .58321 m
1 .58321 L
s
.99625 .60431 m
1 .60431 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.45009 0 m
.45009 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.06085 .02374 Mdot
.09401 .03287 Mdot
.12438 .04214 Mdot
.15272 .05157 Mdot
.17956 .0612 Mdot
.2053 .07107 Mdot
.23025 .08124 Mdot
.25463 .09173 Mdot
.27863 .10259 Mdot
.3024 .11385 Mdot
.32605 .12555 Mdot
.34968 .13773 Mdot
.3734 .15042 Mdot
.39728 .16368 Mdot
.4214 .17754 Mdot
.44585 .19206 Mdot
.4707 .2073 Mdot
.49606 .22333 Mdot
.52202 .24024 Mdot
.5487 .25812 Mdot
.57624 .2771 Mdot
.60481 .29733 Mdot
.63461 .31902 Mdot
.66591 .34242 Mdot
.69904 .36784 Mdot
.73445 .39573 Mdot
.77272 .42667 Mdot
.81465 .46147 Mdot
.86136 .50128 Mdot
.91443 .54774 Mdot
.5 Mabswid
.02381 .01472 m
.05372 .022 L
.08634 .03076 L
.11698 .03988 L
.14644 .04948 L
.1778 .06057 L
.20799 .07217 L
.24008 .08547 L
.27099 .09913 L
.30073 .11306 L
.33237 .12881 L
.36283 .14477 L
.39213 .16082 L
.42332 .17868 L
.45333 .19665 L
.48525 .2165 L
.51599 .23631 L
.54556 .25601 L
.57703 .27765 L
.60732 .29917 L
.63951 .32269 L
.67053 .34597 L
.70038 .36889 L
.73212 .3939 L
.76269 .41857 L
.79209 .44275 L
.82339 .46892 L
.85351 .49459 L
.88553 .52244 L
.91638 .54949 L
.94605 .5762 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`008P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`00000L0?oo
o`<000006P3oool5000000<0oooo00<000000?ooo`3oool00P3oool3000001T0oooo0P00000J0?oo
o`D000000`3oool00`000000oooo0?ooo`020?ooo`<00000703oool3000001`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000006@3oool00280oooo00<000000?ooo`3o
ool01`3oool01@000000oooo0?ooo`3oool0000001X0oooo00D000000?ooo`3oool0oooo0000000J
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`040000
003oool0oooo000001X0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0
000001X0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo0000000H0?ooo`006P3oool5000000@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0B0?ooo`D000001@3oool00`000000oooo0?ooo`0A0?ooo`D000000`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool00000
6`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo000S0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`00000L0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool05P3oool002@0oooo00<000000?ooo`3oool01@3o
ool4000001/0oooo1000000J0?ooo`050000003oool0oooo0?ooo`0000001`3oool4000001P0oooo
00@000000?ooo`3oool000006@3oool01@000000oooo0?ooo`3oool0000000L0oooo1000000K0?oo
o`@000007P3oool00`000000oooo0?ooo`050?ooo`@000006@3oool00200oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00
000I0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01/0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo01X0
oooo000P0?ooo`D000001`3oool5000001X0oooo1@00000J0?ooo`<00000203oool5000001P0oooo
0P00000K0?ooo`<00000203oool5000001X0oooo1@00000I0?ooo`D000001`3oool5000001P0oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000T0?ooooP00000
103oool002@0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`00903oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool00P3oool0
02@0oooo0P0000040?ooo`<00000IP3oool00`000000oooo0?ooo`240?ooo`800000103oool002@0
oooo00<000000?ooo`3oool01P3oool3000006<0oooo00<000000?ooo`3oool0Q@3oool00`000000
oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`090?ooo`@00000G`3oool00`000000oooo
0?ooo`250?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo00/0oooo1P00
001K0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool04@3oool4000005L0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`02
0?ooo`00903oool2000001@0oooo1000001E0?ooo`030000003oool0oooo08@0oooo0P0000040?oo
o`00903oool00`000000oooo0?ooo`0G0?ooo`<00000DP3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo01X0oooo0`00001?0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool00P3oool000X0oooo0`0000040?ooo`800000103o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo01/0oooo1@00001<0?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool00P3oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0200oooo100000180?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`3oool00P3oool000<0oooo1@0000000`3oool000000?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo0P00000S0?ooo`@00000AP3oool00`000000oooo0?oo
o`240?ooo`800000103oool000T0oooo100000030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02H0
oooo1@0000110?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool00P3oool000T0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0Y0?ooo`<00000@03oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0080oooo000:0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0;03oool3000003d0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`020?ooo`002`3oool2000000@0oooo0P0000040?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool0;`3oool3000003X0oooo00<000000?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0_0?ooo`80000000<0oooo
000000000000>03oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0080oooo000T0?oo
o`800000=@3oool3000003D0oooo00<000000?ooo`3oool0Q03oool2000000@0oooo000T0?ooo`03
0000003oool0oooo03D0oooo0`00000d0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0>03oool200000380oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0j0?ooo`<00000;`3o
ool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0
oooo03/0oooo1@00000/0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool00P3oool0
02@0oooo0P0000110?ooo`800000:P3oool00`000000oooo0?ooo`240?ooo`800000103oool002@0
oooo00<000000?ooo`3oool0@@3oool3000002P0oooo00<000000?ooo`3oool0Q@3oool00`000000
oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`110?ooo`80000000<0oooo0000003oool0
9P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003o
ool0oooo04D0oooo1000000S0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0A`3oool2000002<0oooo00<000000?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`020?ooo`00903oool2000004X0oooo0`00000P0?ooo`030000003oool0oooo
08@0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1<0?ooo`<000007@3oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo04d0oooo
1000000K0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool00P3oool000/0oooo0`00
00030?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0540oooo0P00
000I0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool00P3oool000`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05<0oooo0P00000G0?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool00P3oool000<0oooo1@0000000`3oool00000
0000000300000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo0P00001D0?ooo`@000005@3oool00`000000oooo0?ooo`24
0?ooo`800000103oool000T0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1G0?ooo`8000004`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0080
oooo000:0?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0F@3oool2
00000140oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`020?ooo`002`3oool20000
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0F@3oool300000100oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`020?ooo`00303oool00`000000oooo0?ooo`020?ooo`800000103o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo05T0oooo0P0000000`3oool000000000
000>0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0GP3oool2000000`0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`02
0?ooo`00903oool2000005l0oooo0`00000;0?ooo`030000003oool0oooo08@0oooo0P0000040?oo
o`00903oool00`000000oooo0?ooo`1N0?ooo`80000000<0oooo0000000000002@3oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo06<0oooo
0P0000070?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool0I03oool2000000H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?oo
o`020?ooo`00903oool00`000000oooo0?ooo`1T0?ooo`@00000103oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000J@3oool200000080oooo00<000000?oo
o`3oool0Q03oool2000000@0oooo000T0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`00
0000Q`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1Z0?ooo`<00000
Q`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1Z0?ooo`D00000Q@3o
ool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1/0?ooo`040000003oool0
oooo000008@0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001]0?ooo`040000003oool0
oooo0?ooo`800000P@3oool2000000@0oooo000T0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool00P3oool300000800oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?oo
o`3oool0K03oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool0OP3oool00`00
0000oooo0?ooo`020?ooo`002@3oool5000000<0oooo0P0000040?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`060?ooo`800000O@3oool00`000000
oooo0?ooo`020?ooo`002P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo0080oooo00030?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`80
0000K@3oool00`000000oooo0?ooo`080?ooo`<00000N@3oool2000000@0oooo000<0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo00P0oooo0P0000000`3oool000000?ooo`1h0?ooo`030000003oool0oooo0080oooo00090?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`020?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0K03o
ool00`000000oooo0?ooo`0=0?ooo`800000MP3oool00`000000oooo0?ooo`020?ooo`002P3oool3
000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0K03oool0
0`000000oooo0?ooo`0>0?ooo`800000M@3oool00`000000oooo0?ooo`020?ooo`00903oool20000
06d0oooo00<000000?ooo`3oool03P3oool400000780oooo0P0000040?ooo`00903oool00`000000
oooo0?ooo`1/0?ooo`030000003oool0oooo0180oooo0P00001a0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo06`0oooo00<0
00000?ooo`3oool05@3oool2000006h0oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0K03oool00`000000oooo0?ooo`0E0?ooo`<00000K@3oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo01P0oooo0P00001[0?oo
o`030000003oool0oooo0080oooo000T0?ooo`800000K@3oool00`000000oooo0?ooo`0J0?ooo`80
0000J03oool2000000@0oooo000T0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0703oool3000006H0oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0L0?ooo`80000000<0oooo
0000003oool0I03oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1/0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`020?oo
o`00903oool2000006d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1P0?ooo`80
0000103oool002@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0K03o
ool00`000000oooo0?ooo`0S0?ooo`800000H03oool00`000000oooo0?ooo`020?ooo`007@3oool2
000000D0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0S0?ooo`<00000G`3oool0
0`000000oooo0?ooo`020?ooo`00703oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo0080oooo000L0?ooo`040000003oool0oooo000000@0oooon00000040?ooo`00703oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0:@3oool2
000005X0oooo00<000000?ooo`3oool00P3oool001`0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo02X0oooo0P00001I0?ooo`030000003oool0
oooo0080oooo000L0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0K03oool0
0`000000oooo0?ooo`0Z0?ooo`@00000E`3oool00`000000oooo0?ooo`020?ooo`007@3oool20000
00D0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001]0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0DP3oool2000000@0oooo000T0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool0<03oool2000005<0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool0K03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0b
0?ooo`800000D@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1/0?oo
o`030000003oool0oooo0380oooo1000001?0?ooo`030000003oool0oooo0080oooo000T0?ooo`80
0000K@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo04/0oooo0P0000040?ooo`00
903oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1/0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`020?ooo`00903oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo
03X0oooo0P0000190?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo06`0
oooo00<000000?ooo`3oool0>P3oool3000004P0oooo00<000000?ooo`3oool00P3oool002@0oooo
0P00001]0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0A03oool2000000@0oooo
000T0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo0080oooo00090?ooo`D000000`3oool2000000@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo03l0oooo0P000014
0?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool00P3oool000/0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`020?ooo`00303oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
0P00001]0?ooo`030000003oool0oooo04<0oooo0P00000o0?ooo`800000103oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool0@`3oool3000003l0oooo00<000000?ooo`3oool00P3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo000:0?ooo`<00000
103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1/0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`020?ooo`00903o
ool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`020?ooo`00903oool2000006d0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0h0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`1:0?ooo`800000>@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000
oooo0?ooo`1/0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo04`0oooo
0P00000g0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo06`0oooo00<0
00000?ooo`3oool0C03oool4000003D0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001]
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0<@3oool2000000@0oooo000T0?oo
o`030000003oool0oooo06`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000
003oool0oooo06`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo0080oooo000T0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo0080oooo000T0?ooo`800000K@3oool00`000000oooo0?ooo`1F0?ooo`<00000:`3oool20000
00@0oooo000T0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0E`3oool2000002`0
oooo00<000000?ooo`3oool00P3oool000/0oooo0`0000030?ooo`800000103oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0080oooo000<0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo05T0oooo0P00000Z0?oo
o`030000003oool0oooo0080oooo00090?ooo`D000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`1/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`020?ooo`002@3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000K@3oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo02D0oooo0P0000040?ooo`002P3oool00`000000
oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0G@3o
ool2000002H0oooo00<000000?ooo`3oool00P3oool000/0oooo0P0000030?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0080oooo000<0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000
103oool2000000D0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0K03o
ool00`000000oooo0?ooo`1Q0?ooo`8000008P3oool00`000000oooo0?ooo`020?ooo`00903oool2
000006d0oooo00<000000?ooo`3oool0HP3oool200000200oooo0P0000040?ooo`00903oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo0680oooo0`00000P0?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo
000T0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000K@3oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo01T0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1/0?oo
o`030000003oool0oooo06T0oooo0P00000J0?ooo`030000003oool0oooo0080oooo000T0?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0
K03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0080oooo000T0?ooo`800000K@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0
oooo01<0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000
oooo0?ooo`1/0?ooo`030000003oool0oooo06l0oooo0`00000C0?ooo`030000003oool0oooo0080
oooo000:0?ooo`<00000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo06l0oooo0P0000000`3oool000000?ooo`0A0?ooo`030000
003oool0oooo0080oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00P3oool000T0oooo100000030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000K@3oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00`0oooo0P0000040?ooo`002@3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0
MP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo000:0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool000/0oooo0P0000040?ooo`80
0000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000
003oool0oooo06`0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo000T0?ooo`800000K@3oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo00L0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo07/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00903oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`00903oool2000006d0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?oo
o`020?ooo`800000103oool002@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool002@0oooon00000040?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00=P3oool3000008X0oooo00<000000?ooo`3oool0:`3oool3000001D0oooo00<000000?oo
o`3oool0503oool003L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00340oooo0`0000030?ooo`<00000
103oool200000080oooo1@0000020?ooo`<000000`3oool4000000030?ooo`000000000000<00000
1`3oool3000000@0oooo100000030?ooo`8000000P3oool6000000H0oooo100000020?ooo`D00000
00<0oooo0000000000000`0000000`3oool000000000000300000080oooo0`0000020?ooo`<00000
103oool300000080oooo0`000000103oool000000000003oool3000000<0oooo0`0000090?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool4000000<0oooo00<000000?ooo`3o
ool00P3oool300000080oooo1@0000020?ooo`<000000P3oool3000000040?ooo`00000000000?oo
o`@000000`3oool200000080oooo2P0000050?ooo`030000003oool0oooo0180oooo000`0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?oo
o`000000303oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00@000000?oo
o`3oool00000103oool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo
000000060?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0180oooo000`0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000060?ooo`<00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo0`0000030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`3oool500000080oooo00<000000?ooo`3oool00P3oool500000080oooo00H0
00000?ooo`3oool000000?ooo`0000050?ooo`D00000203oool00`000000oooo0?ooo`020?ooo`05
0000003oool000000?ooo`0000000P3oool3000000<0oooo00<000000?ooo`0000000P3oool50000
00<0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`060000003oool0oooo0000003oool00000
0`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo00000080oooo0`0000050?oo
o`030000003oool0oooo0180oooo000`0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`<000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`3oool0oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
000000<0oooo00@000000?ooo`3oool000001@3oool01P000000oooo0?ooo`000000oooo000000P0
oooo00<000000?ooo`3oool04P3oool00300oooo00H000000?ooo`3oool0oooo0000003oool40000
0080oooo100000020?ooo`<00000103oool3000000<0oooo0P0000050?ooo`030000003oool0oooo
00P0oooo00@000000?ooo`3oool000000P3oool2000000<0oooo100000030?ooo`<000002@3oool0
1@000000oooo0?ooo`000000oooo00<00000103oool400000080oooo100000020?ooo`<000000P3o
ool2000000030?ooo`00000000000080oooo0`0000020?ooo`@000000`3oool3000000<0oooo0`00
00090?ooo`030000003oool0oooo0080oooo1P0000000`3oool00000000000030?ooo`80000000<0
oooo0000000000000P3oool3000000@0oooo00<000000?ooo`3oool00P3oool300000080oooo1000
00030?ooo`T000000`3oool3000000<0oooo100000040?ooo`030000003oool0oooo0180oooo000`
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`00
<@3oool3000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`<00000
2@3oool4000000T0oooo00<000000?ooo`3oool00P3oool2000000X0oooo100000040?ooo`030000
003oool0oooo00@0oooo0P0000040?ooo`800000;P3oool00`000000oooo0?ooo`0H0?ooo`<00000
5P3oool00`000000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`0D0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.1688, -8484.98, \
0.0688727, 95.9088}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.491544 0.0641471 -97.6841 0.172027 [
[.10666 -0.0125 -6 -9 ]
[.10666 -0.0125 6 0 ]
[.23496 -0.0125 -6 -9 ]
[.23496 -0.0125 6 0 ]
[.36325 -0.0125 -6 -9 ]
[.36325 -0.0125 6 0 ]
[.49154 -0.0125 -3 -9 ]
[.49154 -0.0125 3 0 ]
[.61984 -0.0125 -3 -9 ]
[.61984 -0.0125 3 0 ]
[.74813 -0.0125 -3 -9 ]
[.74813 -0.0125 3 0 ]
[.87643 -0.0125 -3 -9 ]
[.87643 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02715 -18 -4.5 ]
[-0.0125 .02715 0 4.5 ]
[-0.0125 .11316 -30 -4.5 ]
[-0.0125 .11316 0 4.5 ]
[-0.0125 .19918 -18 -4.5 ]
[-0.0125 .19918 0 4.5 ]
[-0.0125 .28519 -30 -4.5 ]
[-0.0125 .28519 0 4.5 ]
[-0.0125 .3712 -18 -4.5 ]
[-0.0125 .3712 0 4.5 ]
[-0.0125 .45722 -30 -4.5 ]
[-0.0125 .45722 0 4.5 ]
[-0.0125 .54323 -18 -4.5 ]
[-0.0125 .54323 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10666 0 m
.10666 .00625 L
s
[(-6)] .10666 -0.0125 0 1 Mshowa
.23496 0 m
.23496 .00625 L
s
[(-4)] .23496 -0.0125 0 1 Mshowa
.36325 0 m
.36325 .00625 L
s
[(-2)] .36325 -0.0125 0 1 Mshowa
.49154 0 m
.49154 .00625 L
s
[(0)] .49154 -0.0125 0 1 Mshowa
.61984 0 m
.61984 .00625 L
s
[(2)] .61984 -0.0125 0 1 Mshowa
.74813 0 m
.74813 .00625 L
s
[(4)] .74813 -0.0125 0 1 Mshowa
.87643 0 m
.87643 .00625 L
s
[(6)] .87643 -0.0125 0 1 Mshowa
.125 Mabswid
.13874 0 m
.13874 .00375 L
s
.17081 0 m
.17081 .00375 L
s
.20288 0 m
.20288 .00375 L
s
.26703 0 m
.26703 .00375 L
s
.2991 0 m
.2991 .00375 L
s
.33118 0 m
.33118 .00375 L
s
.39532 0 m
.39532 .00375 L
s
.4274 0 m
.4274 .00375 L
s
.45947 0 m
.45947 .00375 L
s
.52362 0 m
.52362 .00375 L
s
.55569 0 m
.55569 .00375 L
s
.58776 0 m
.58776 .00375 L
s
.65191 0 m
.65191 .00375 L
s
.68399 0 m
.68399 .00375 L
s
.71606 0 m
.71606 .00375 L
s
.78021 0 m
.78021 .00375 L
s
.81228 0 m
.81228 .00375 L
s
.84435 0 m
.84435 .00375 L
s
.9085 0 m
.9085 .00375 L
s
.94057 0 m
.94057 .00375 L
s
.97265 0 m
.97265 .00375 L
s
.07459 0 m
.07459 .00375 L
s
.04251 0 m
.04251 .00375 L
s
.01044 0 m
.01044 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02715 m
.00625 .02715 L
s
[(568)] -0.0125 .02715 1 0 Mshowa
0 .11316 m
.00625 .11316 L
s
[(568.5)] -0.0125 .11316 1 0 Mshowa
0 .19918 m
.00625 .19918 L
s
[(569)] -0.0125 .19918 1 0 Mshowa
0 .28519 m
.00625 .28519 L
s
[(569.5)] -0.0125 .28519 1 0 Mshowa
0 .3712 m
.00625 .3712 L
s
[(570)] -0.0125 .3712 1 0 Mshowa
0 .45722 m
.00625 .45722 L
s
[(570.5)] -0.0125 .45722 1 0 Mshowa
0 .54323 m
.00625 .54323 L
s
[(571)] -0.0125 .54323 1 0 Mshowa
.125 Mabswid
0 .04435 m
.00375 .04435 L
s
0 .06156 m
.00375 .06156 L
s
0 .07876 m
.00375 .07876 L
s
0 .09596 m
.00375 .09596 L
s
0 .13037 m
.00375 .13037 L
s
0 .14757 m
.00375 .14757 L
s
0 .16477 m
.00375 .16477 L
s
0 .18198 m
.00375 .18198 L
s
0 .21638 m
.00375 .21638 L
s
0 .23358 m
.00375 .23358 L
s
0 .25079 m
.00375 .25079 L
s
0 .26799 m
.00375 .26799 L
s
0 .30239 m
.00375 .30239 L
s
0 .3196 m
.00375 .3196 L
s
0 .3368 m
.00375 .3368 L
s
0 .354 m
.00375 .354 L
s
0 .38841 m
.00375 .38841 L
s
0 .40561 m
.00375 .40561 L
s
0 .42281 m
.00375 .42281 L
s
0 .44002 m
.00375 .44002 L
s
0 .47442 m
.00375 .47442 L
s
0 .49162 m
.00375 .49162 L
s
0 .50883 m
.00375 .50883 L
s
0 .52603 m
.00375 .52603 L
s
0 .00995 m
.00375 .00995 L
s
0 .56043 m
.00375 .56043 L
s
0 .57764 m
.00375 .57764 L
s
0 .59484 m
.00375 .59484 L
s
0 .61204 m
.00375 .61204 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.10666 .61178 m
.10666 .61803 L
s
.23496 .61178 m
.23496 .61803 L
s
.36325 .61178 m
.36325 .61803 L
s
.49154 .61178 m
.49154 .61803 L
s
.61984 .61178 m
.61984 .61803 L
s
.74813 .61178 m
.74813 .61803 L
s
.87643 .61178 m
.87643 .61803 L
s
.125 Mabswid
.13874 .61428 m
.13874 .61803 L
s
.17081 .61428 m
.17081 .61803 L
s
.20288 .61428 m
.20288 .61803 L
s
.26703 .61428 m
.26703 .61803 L
s
.2991 .61428 m
.2991 .61803 L
s
.33118 .61428 m
.33118 .61803 L
s
.39532 .61428 m
.39532 .61803 L
s
.4274 .61428 m
.4274 .61803 L
s
.45947 .61428 m
.45947 .61803 L
s
.52362 .61428 m
.52362 .61803 L
s
.55569 .61428 m
.55569 .61803 L
s
.58776 .61428 m
.58776 .61803 L
s
.65191 .61428 m
.65191 .61803 L
s
.68399 .61428 m
.68399 .61803 L
s
.71606 .61428 m
.71606 .61803 L
s
.78021 .61428 m
.78021 .61803 L
s
.81228 .61428 m
.81228 .61803 L
s
.84435 .61428 m
.84435 .61803 L
s
.9085 .61428 m
.9085 .61803 L
s
.94057 .61428 m
.94057 .61803 L
s
.97265 .61428 m
.97265 .61803 L
s
.07459 .61428 m
.07459 .61803 L
s
.04251 .61428 m
.04251 .61803 L
s
.01044 .61428 m
.01044 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02715 m
1 .02715 L
s
.99375 .11316 m
1 .11316 L
s
.99375 .19918 m
1 .19918 L
s
.99375 .28519 m
1 .28519 L
s
.99375 .3712 m
1 .3712 L
s
.99375 .45722 m
1 .45722 L
s
.99375 .54323 m
1 .54323 L
s
.125 Mabswid
.99625 .04435 m
1 .04435 L
s
.99625 .06156 m
1 .06156 L
s
.99625 .07876 m
1 .07876 L
s
.99625 .09596 m
1 .09596 L
s
.99625 .13037 m
1 .13037 L
s
.99625 .14757 m
1 .14757 L
s
.99625 .16477 m
1 .16477 L
s
.99625 .18198 m
1 .18198 L
s
.99625 .21638 m
1 .21638 L
s
.99625 .23358 m
1 .23358 L
s
.99625 .25079 m
1 .25079 L
s
.99625 .26799 m
1 .26799 L
s
.99625 .30239 m
1 .30239 L
s
.99625 .3196 m
1 .3196 L
s
.99625 .3368 m
1 .3368 L
s
.99625 .354 m
1 .354 L
s
.99625 .38841 m
1 .38841 L
s
.99625 .40561 m
1 .40561 L
s
.99625 .42281 m
1 .42281 L
s
.99625 .44002 m
1 .44002 L
s
.99625 .47442 m
1 .47442 L
s
.99625 .49162 m
1 .49162 L
s
.99625 .50883 m
1 .50883 L
s
.99625 .52603 m
1 .52603 L
s
.99625 .00995 m
1 .00995 L
s
.99625 .56043 m
1 .56043 L
s
.99625 .57764 m
1 .57764 L
s
.99625 .59484 m
1 .59484 L
s
.99625 .61204 m
1 .61204 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.49154 0 m
.49154 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.05128 .5866 Mdot
.07941 .56946 Mdot
.10814 .55193 Mdot
.13744 .53403 Mdot
.16724 .5158 Mdot
.19751 .49726 Mdot
.2282 .47845 Mdot
.25925 .45939 Mdot
.29064 .44011 Mdot
.3223 .42064 Mdot
.3542 .40101 Mdot
.3863 .38124 Mdot
.41856 .36135 Mdot
.45092 .34139 Mdot
.48334 .32136 Mdot
.51579 .30131 Mdot
.54823 .28125 Mdot
.5806 .26121 Mdot
.61287 .24121 Mdot
.64499 .22129 Mdot
.67693 .20147 Mdot
.70863 .18178 Mdot
.74006 .16224 Mdot
.77117 .14288 Mdot
.80192 .12372 Mdot
.83225 .1048 Mdot
.86214 .08614 Mdot
.89152 .06778 Mdot
.92036 .04973 Mdot
.9486 .03203 Mdot
.5 Mabswid
.02381 .60332 m
.05372 .58512 L
.08634 .56523 L
.11698 .54653 L
.14644 .52852 L
.1778 .50933 L
.20799 .49084 L
.24008 .47116 L
.27099 .45218 L
.30073 .43391 L
.33237 .41445 L
.36283 .39569 L
.39213 .37765 L
.42332 .35842 L
.45333 .33989 L
.48525 .32018 L
.51599 .30119 L
.54556 .2829 L
.57703 .26342 L
.60732 .24465 L
.63951 .22469 L
.67053 .20544 L
.70038 .18691 L
.73212 .16717 L
.76269 .14815 L
.79209 .12984 L
.82339 .11033 L
.85351 .09153 L
.88553 .07152 L
.91638 .05222 L
.94605 .03363 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00?`3oool3000001h0oooo0`00000K0?ooo`D000006@3oool2000001`0oooo1@00000M0?oo
o`<00000703oool300000280oooo000n0?ooo`050000003oool0oooo0?ooo`0000007P3oool00`00
0000oooo0?ooo`0K0?ooo`040000003oool0oooo000001P0oooo00@000000?ooo`3oool00000703o
ool010000000oooo0?ooo`00000N0?ooo`030000003oool0oooo01X0oooo00D000000?ooo`3oool0
oooo0000000Q0?ooo`00>03oool5000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0
4`3oool5000000030?ooo`000000000000<000005@3oool5000000<0oooo00<000000?ooo`3oool0
603oool010000000oooo0?ooo`00000M0?ooo`030000003oool0oooo01/0oooo1@00000K0?ooo`05
0000003oool0oooo0?ooo`0000008@3oool003h0oooo1000000L0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`00000N0?ooo`030000003oool0
oooo01X0oooo00@000000?ooo`3oool00000703oool400000280oooo000n0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`000000703oool01@000000oooo0?ooo`3oool0000001P0oooo00@0
00000?ooo`3oool000006`3oool01@000000oooo0?ooo`3oool0000001`0oooo00<000000?ooo`00
0000703oool00`000000oooo0?ooo`0S0?ooo`00?`3oool00`000000oooo0?ooo`0N0?ooo`800000
703oool01@000000oooo0?ooo`3oool0000001P0oooo00@000000?ooo`3oool000006`3oool01@00
0000oooo0?ooo`3oool0000001d0oooo0P00000M0?ooo`030000003oool0oooo0280oooo00100?oo
o`8000007`3oool00`000000oooo0?ooo`0K0?ooo`<000006P3oool2000001d0oooo0`00000O0?oo
o`030000003oool0oooo01`0oooo0P00000R0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00903ooooh000000@0oooo000T0?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001g0?ooo`030000003oool0oooo07X0oooo
0P0000040?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo07@0oooo0P00
00050?ooo`030000003oool0oooo0080oooo000@0?ooo`<000000`3oool3000000<0oooo0`000005
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo000?0?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0740oooo0P0000080?ooo`030000003oool0oooo0080oooo000C
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`800000M`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00L0oooo0P000004
0?ooo`004`3oool00`000000oooo00000003000000<0oooo0`0000050?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0KP3oool2000000/0oooo00<000000?ooo`3oool00P3oool000l0
oooo100000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0K@3oool3000000/0oooo00<000000?oo
o`3oool00P3oool000l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
06`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`003`3oool5000000<0
oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo06X0
oooo0P00000?0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000M`3oool00`000000oooo
0?ooo`1X0?ooo`800000403oool2000000@0oooo000T0?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool0I`3oool200000180oooo00<000000?ooo`3oool00P3oool002@0oooo00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`1U0?ooo`@000004P3oool00`000000oooo0?ooo`02
0?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo06<0oooo0P00000F0?oo
o`030000003oool0oooo0080oooo000T0?ooo`800000M`3oool00`000000oooo0?ooo`1R0?ooo`03
0000003oool0oooo01D0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0600oooo0P00000I0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0GP3oool4000001T0oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001g0?ooo`030000003oool0oooo
05/0oooo0P00000M0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`1I0?ooo`800000803oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo05P0oooo0P00000Q0?ooo`030000003oool0oooo0080oooo
000T0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0EP3oool400000240oooo00<0
00000?ooo`3oool00P3oool002@0oooo0P00001g0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool08P3oool2000000@0oooo000T0?ooo`030000003oool0oooo07H0oooo00<000000?oo
o`3oool0D`3oool2000002H0oooo00<000000?ooo`3oool00P3oool000@0oooo0`0000030?ooo`<0
00000`3oool3000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`1A0?ooo`800000:03oool00`000000oooo0?ooo`020?ooo`00
0`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000030?oo
o`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0D03oool3000002P0oooo00<000000?ooo`3oool00P3oool0
00L0oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
04h0oooo0P00000[0?ooo`030000003oool0oooo0080oooo00070?ooo`030000003oool0000000<0
00000`3oool3000000`0oooo00<000000?ooo`3oool00P3oool2000007L0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`0Z0?ooo`800000103oool000<0oooo100000020?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000070?ooo`@000001@3oool00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo04/0oooo0P00000^0?ooo`030000003oool0oooo0080
oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo04T0oooo0P00000`0?ooo`030000003oool0oooo0080oooo00030?ooo`D00000
0`3oool2000000<0oooo0`0000080?ooo`D00000103oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo04T0oooo0P00000`0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000M`3o
ool00`000000oooo0?ooo`170?ooo`800000<@3oool2000000@0oooo000T0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0A@3oool2000003@0oooo00<000000?ooo`3oool00P3oool0
02@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`130?ooo`800000=P3oool00`00
0000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0440
oooo0`00000g0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000M`3oool00`000000oooo
0?ooo`0o0?ooo`80000000<0oooo000000000000=P3oool2000000@0oooo000T0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0080oooo000T0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0?03oool2
000003d0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0j0?ooo`800000?`3oool00`000000oooo0?ooo`020?ooo`00903oool2000007L0
oooo00<000000?ooo`3oool0>P3oool2000003h0oooo0P0000040?ooo`00903oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo03P0oooo0P0000110?ooo`030000003oool0oooo0080oooo
000T0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0=@3oool2000004@0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`0b0?ooo`<00000AP3oool00`000000oooo0?ooo`020?oo
o`00903oool2000007L0oooo00<000000?ooo`3oool0<P3oool2000004H0oooo0P0000040?ooo`00
403oool3000000<0oooo0`0000030?ooo`8000001P3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0300oooo0P0000190?ooo`030000003oool0oooo0080oooo000?0?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo02h0oooo0P00001;0?ooo`03
0000003oool0oooo0080oooo000C0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0080oooo000C0?ooo`030000003o
ool0000000<000000`3oool4000000@0oooo0P00001g0?ooo`030000003oool0oooo02/0oooo0P00
001=0?ooo`800000103oool000l0oooo100000020?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0:@3o
ool4000004h0oooo00<000000?ooo`3oool00P3oool000l0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`020?ooo`003`3oool5000000<0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo02H0oooo0P00001C0?ooo`030000003oool0oooo0080oooo000T0?oo
o`800000M`3oool00`000000oooo0?ooo`0T0?ooo`800000E03oool2000000@0oooo000T0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool08`3oool2000005H0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0Q0?ooo`@00000
EP3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`020?ooo`00903oool2
000007L0oooo00<000000?ooo`3oool07P3oool2000005X0oooo0P0000040?ooo`00903oool00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo01`0oooo0P00001M0?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool06`3oool2000005h0
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`0I0?ooo`@00000GP3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`020?ooo`00903oool2000007L0oooo00<000000?ooo`3oool05P3oool200000680oooo0P000004
0?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo01<0oooo0P00001V0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000
003oool0oooo07H0oooo00<000000?ooo`3oool04P3oool3000006H0oooo00<000000?ooo`3oool0
0P3oool002@0oooo0P00001g0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0IP3o
ool2000000@0oooo000T0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool03`3oool2
000006X0oooo00<000000?ooo`3oool00P3oool000@0oooo0`0000030?ooo`<000000`3oool20000
00D0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0=0?ooo`800000K03oool00`000000oooo0?ooo`020?ooo`000`3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool02`3oool2000006h0oooo00<000000?ooo`3oool00P3oool000L0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00P3oool2000007L0oooo00<000000?ooo`3oool02P3oool3000006d0oooo0P000004
0?ooo`001`3oool00`000000oooo00000003000000<0oooo1000000;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`080?ooo`800000L@3oool00`00
0000oooo0?ooo`020?ooo`000`3oool400000080oooo00<000000?ooo`3oool00`3oool01@000000
oooo0?ooo`3oool0000000L0oooo100000050?ooo`030000003oool0oooo07H0oooo00<000000?oo
o`3oool01P3oool2000007<0oooo00<000000?ooo`3oool00P3oool000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0103oool20000
07D0oooo00<000000?ooo`3oool00P3oool000<0oooo1@0000030?ooo`8000000`3oool3000000P0
oooo1@0000040?ooo`800000M`3oool00`000000oooo0?ooo`020?ooo`<00000M@3oool2000000@0
oooo000T0?ooo`030000003oool0oooo07H0oooo00H000000?ooo`3oool0oooo0000003oool20000
07H0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0MP3oool010000000
oooo00000000001j0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07H0
oooo0P00001l0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool2000007D0oooo0`00
001l0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0L`3oool4000007d0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0L@3oool2000000<0oooo00<000000?oo
o`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1_0?ooo`80
00001@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000
K`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07X0oooo0P0000040?ooo`00903o
ool00`000000oooo0?ooo`1/0?ooo`800000203oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo0080oooo000T0?ooo`030000003oool0oooo06X0oooo100000080?ooo`030000003oool0
oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0
oooo0P00001X0?ooo`8000003@3oool00`000000oooo0?ooo`1j0?ooo`800000103oool002@0oooo
00<000000?ooo`3oool0I@3oool2000000l0oooo00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`020?ooo`00403oool3000000@0oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<0
00000?ooo`3oool0I03oool200000100oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`020?ooo`003`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0680oooo1000000@0?ooo`030000
003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool001<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool200000640oooo
0P00000D0?ooo`030000003oool0oooo07X0oooo0P0000040?ooo`004`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1k0?ooo`030000
003oool0oooo0080oooo000?0?ooo`@000001P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0G@3oool2000001L0oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`020?ooo`003`3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05/0
oooo0`00000H0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool000l0oooo
1@0000000`3oool0000000000003000000<0oooo0P0000050?ooo`030000003oool0oooo05X0oooo
00@000000?ooo`0000000000603oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080
oooo000T0?ooo`800000F@3oool2000001`0oooo00<000000?ooo`3oool0NP3oool2000000@0oooo
000T0?ooo`030000003oool0oooo05H0oooo0P00000N0?ooo`030000003oool0oooo07/0oooo00<0
00000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0E03oool200000200oooo00<00000
0?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1C0?oo
o`<00000803oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?ooo`80
0000DP3oool2000002<0oooo00<000000?ooo`3oool0NP3oool2000000@0oooo000T0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1k0?ooo`030000
003oool0oooo0080oooo000T0?ooo`030000003oool0oooo04h0oooo0P00000V0?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0C03oool2
000002P0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool20000
04`0oooo0`00000X0?ooo`030000003oool0oooo07X0oooo0P0000040?ooo`00903oool00`000000
oooo0?ooo`190?ooo`800000:`3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo04H0oooo0P00
000^0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo0P000015
0?ooo`800000<03oool00`000000oooo0?ooo`1j0?ooo`800000103oool002@0oooo00<000000?oo
o`3oool0@`3oool300000300oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?oo
o`00103oool3000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo00<000000?ooo`3o
ool00P3oool3000000D0oooo00<000000?ooo`3oool0@@3oool2000003<0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`020?ooo`000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0o0?ooo`800000=@3oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo0080oooo00070?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`020?ooo`001`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0P00000m
0?ooo`800000>03oool00`000000oooo0?ooo`1j0?ooo`800000103oool000<0oooo100000060?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool4000000D0oooo00<00000
0?ooo`3oool0>P3oool4000003P0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`02
0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3o
ool000<0oooo1@0000000`3oool0000000000003000000<0oooo0P0000080?ooo`D00000103oool0
0`000000oooo0?ooo`0g0?ooo`800000?@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0
oooo0080oooo000T0?ooo`800000=`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
07X0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`0d0?ooo`<00000?`3oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo0380oooo
0P0000000`3oool000000000000o0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00000`0?ooo`800000A@3oool0
0`000000oooo0?ooo`1j0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0;@3oool20000
04L0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000
oooo0?ooo`0/0?ooo`<00000A`3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080
oooo000T0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000:`3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo07X0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`0X
0?ooo`800000C03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo02H0oooo0P00001>0?ooo`030000003oool0oooo07/0oooo00<000000?oo
o`3oool00P3oool002@0oooo00<000000?ooo`3oool0903oool4000004h0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0R0?ooo`800000
DP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?ooo`8000008@3o
ool2000005@0oooo00<000000?ooo`3oool0NP3oool2000000@0oooo000@0?ooo`<00000103oool0
0`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`0N0?ooo`800000EP3oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000?0?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool07@3oool3000005H0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`02
0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0N`3oool00`000000oooo0?ooo`020?ooo`004`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000001`0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`1j0?ooo`800000103oool000l0oooo100000060?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0I0?ooo`800000F`3oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000?0?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`8000001P3oool00`000000oooo0?ooo`0G0?ooo`80
0000G@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000?0?ooo`D00000
00<0oooo0000000000000`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
5@3oool4000005d0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903o
ool2000001@0oooo0P00001Q0?ooo`030000003oool0oooo07X0oooo0P0000040?ooo`00903oool0
0`000000oooo0?ooo`0A0?ooo`800000H`3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0
oooo0080oooo000T0?ooo`030000003oool0oooo0100oooo0P00001T0?ooo`030000003oool0oooo
07/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool03P3oool4000006@0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool2000000d0oooo
0P00001X0?ooo`030000003oool0oooo07X0oooo0P0000040?ooo`00903oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`020?ooo`00903oool00`000000oooo0?ooo`090?ooo`800000J`3oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo00P0oooo0`00001[0?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3o
ool01P3oool2000006h0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00
903oool2000000H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1j0?ooo`800000
103oool002@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool0
02@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo
0080oooo000T0?ooo`<000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool2000000@0oooo000T0?ooooP00000103oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00300oooo0`00001H0?ooo`<000005`3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo00h0oooo000a0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00d0oooo
000[0?ooo`<000000`3oool3000000@0oooo0P0000020?ooo`D000000P3oool3000000<0oooo1000
00000`3oool0000000000003000000L0oooo0`0000040?ooo`@000000`3oool200000080oooo1P00
00060?ooo`D000000P3oool300000080oooo0`000000103oool000000000003oool4000000<0oooo
0P0000020?ooo`H000001`3oool00`000000oooo0?ooo`030?ooo`@0000000<0oooo000000000000
0P0000020?ooo`@000000`3oool300000080oooo1@0000030?ooo`80000000@0oooo0000003oool0
oooo0P0000030?ooo`<000002@3oool4000000030?ooo`000000000000<0000000<0oooo00000000
00000P0000040?ooo`8000000`3oool4000000050?ooo`00000000000000003oool00P000000103o
ool000000000000000030?ooo`<000001@3oool00`000000oooo0?ooo`0<0?ooo`00:P3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00080?ooo`060000003oool0oooo0000003oool000001P3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000/0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000080?ooo`030000003oool0oooo00`0oooo000Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000103oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`020?ooo`D000000P3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000001@3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`040000003oool0oooo0000
0080oooo0`0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool5000000L0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo
0?ooo`030?ooo`<000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo1@0000040?oo
o`030000003oool0oooo00`0oooo000Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`<000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool00000
1@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`000004
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`00:P3oool01P000000
oooo0?ooo`3oool000000?ooo`@000000P3oool400000080oooo0`0000040?ooo`<000000`3oool2
000000D0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000020?ooo`8000000`3o
ool4000000<0oooo0`0000090?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`@000000`3o
ool9000000<0oooo0`0000090?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`<000000`3o
ool400000080oooo0`0000040?ooo`040000003oool0oooo0?ooo`80000000@0oooo000000000000
oooo100000030?ooo`<000002@3oool300000080oooo0`0000040?ooo`@0000000<0oooo00000000
00000P0000030?ooo`8000000`3oool4000000<0oooo0`0000030?ooo`<000001@3oool00`000000
oooo0?ooo`0<0?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo000[0?ooo`<0
00002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo0`0000090?ooo`@0
00002@3oool00`000000oooo0?ooo`020?ooo`8000002P3oool3000001H0oooo00<000000?ooo`3o
ool00P3oool2000000d0oooo00<000000?ooo`3oool01P3oool200000100oooo0`00000:0?ooo`03
0000003oool0oooo0100oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0>0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.95848, 567.557, \
0.0630714, 0.0235187}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.491544 0.0641471 -3.23173 0.0655696 [
[.10666 -0.0125 -6 -9 ]
[.10666 -0.0125 6 0 ]
[.23496 -0.0125 -6 -9 ]
[.23496 -0.0125 6 0 ]
[.36325 -0.0125 -6 -9 ]
[.36325 -0.0125 6 0 ]
[.49154 -0.0125 -3 -9 ]
[.49154 -0.0125 3 0 ]
[.61984 -0.0125 -3 -9 ]
[.61984 -0.0125 3 0 ]
[.74813 -0.0125 -3 -9 ]
[.74813 -0.0125 3 0 ]
[.87643 -0.0125 -3 -9 ]
[.87643 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04675 -12 -4.5 ]
[-0.0125 .04675 0 4.5 ]
[-0.0125 .17789 -12 -4.5 ]
[-0.0125 .17789 0 4.5 ]
[-0.0125 .30903 -12 -4.5 ]
[-0.0125 .30903 0 4.5 ]
[-0.0125 .44017 -12 -4.5 ]
[-0.0125 .44017 0 4.5 ]
[-0.0125 .57131 -12 -4.5 ]
[-0.0125 .57131 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10666 0 m
.10666 .00625 L
s
[(-6)] .10666 -0.0125 0 1 Mshowa
.23496 0 m
.23496 .00625 L
s
[(-4)] .23496 -0.0125 0 1 Mshowa
.36325 0 m
.36325 .00625 L
s
[(-2)] .36325 -0.0125 0 1 Mshowa
.49154 0 m
.49154 .00625 L
s
[(0)] .49154 -0.0125 0 1 Mshowa
.61984 0 m
.61984 .00625 L
s
[(2)] .61984 -0.0125 0 1 Mshowa
.74813 0 m
.74813 .00625 L
s
[(4)] .74813 -0.0125 0 1 Mshowa
.87643 0 m
.87643 .00625 L
s
[(6)] .87643 -0.0125 0 1 Mshowa
.125 Mabswid
.13874 0 m
.13874 .00375 L
s
.17081 0 m
.17081 .00375 L
s
.20288 0 m
.20288 .00375 L
s
.26703 0 m
.26703 .00375 L
s
.2991 0 m
.2991 .00375 L
s
.33118 0 m
.33118 .00375 L
s
.39532 0 m
.39532 .00375 L
s
.4274 0 m
.4274 .00375 L
s
.45947 0 m
.45947 .00375 L
s
.52362 0 m
.52362 .00375 L
s
.55569 0 m
.55569 .00375 L
s
.58776 0 m
.58776 .00375 L
s
.65191 0 m
.65191 .00375 L
s
.68399 0 m
.68399 .00375 L
s
.71606 0 m
.71606 .00375 L
s
.78021 0 m
.78021 .00375 L
s
.81228 0 m
.81228 .00375 L
s
.84435 0 m
.84435 .00375 L
s
.9085 0 m
.9085 .00375 L
s
.94057 0 m
.94057 .00375 L
s
.97265 0 m
.97265 .00375 L
s
.07459 0 m
.07459 .00375 L
s
.04251 0 m
.04251 .00375 L
s
.01044 0 m
.01044 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04675 m
.00625 .04675 L
s
[(50)] -0.0125 .04675 1 0 Mshowa
0 .17789 m
.00625 .17789 L
s
[(52)] -0.0125 .17789 1 0 Mshowa
0 .30903 m
.00625 .30903 L
s
[(54)] -0.0125 .30903 1 0 Mshowa
0 .44017 m
.00625 .44017 L
s
[(56)] -0.0125 .44017 1 0 Mshowa
0 .57131 m
.00625 .57131 L
s
[(58)] -0.0125 .57131 1 0 Mshowa
.125 Mabswid
0 .07953 m
.00375 .07953 L
s
0 .11232 m
.00375 .11232 L
s
0 .1451 m
.00375 .1451 L
s
0 .21067 m
.00375 .21067 L
s
0 .24346 m
.00375 .24346 L
s
0 .27624 m
.00375 .27624 L
s
0 .34181 m
.00375 .34181 L
s
0 .3746 m
.00375 .3746 L
s
0 .40738 m
.00375 .40738 L
s
0 .47295 m
.00375 .47295 L
s
0 .50574 m
.00375 .50574 L
s
0 .53852 m
.00375 .53852 L
s
0 .01396 m
.00375 .01396 L
s
0 .60409 m
.00375 .60409 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.10666 .61178 m
.10666 .61803 L
s
.23496 .61178 m
.23496 .61803 L
s
.36325 .61178 m
.36325 .61803 L
s
.49154 .61178 m
.49154 .61803 L
s
.61984 .61178 m
.61984 .61803 L
s
.74813 .61178 m
.74813 .61803 L
s
.87643 .61178 m
.87643 .61803 L
s
.125 Mabswid
.13874 .61428 m
.13874 .61803 L
s
.17081 .61428 m
.17081 .61803 L
s
.20288 .61428 m
.20288 .61803 L
s
.26703 .61428 m
.26703 .61803 L
s
.2991 .61428 m
.2991 .61803 L
s
.33118 .61428 m
.33118 .61803 L
s
.39532 .61428 m
.39532 .61803 L
s
.4274 .61428 m
.4274 .61803 L
s
.45947 .61428 m
.45947 .61803 L
s
.52362 .61428 m
.52362 .61803 L
s
.55569 .61428 m
.55569 .61803 L
s
.58776 .61428 m
.58776 .61803 L
s
.65191 .61428 m
.65191 .61803 L
s
.68399 .61428 m
.68399 .61803 L
s
.71606 .61428 m
.71606 .61803 L
s
.78021 .61428 m
.78021 .61803 L
s
.81228 .61428 m
.81228 .61803 L
s
.84435 .61428 m
.84435 .61803 L
s
.9085 .61428 m
.9085 .61803 L
s
.94057 .61428 m
.94057 .61803 L
s
.97265 .61428 m
.97265 .61803 L
s
.07459 .61428 m
.07459 .61803 L
s
.04251 .61428 m
.04251 .61803 L
s
.01044 .61428 m
.01044 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04675 m
1 .04675 L
s
.99375 .17789 m
1 .17789 L
s
.99375 .30903 m
1 .30903 L
s
.99375 .44017 m
1 .44017 L
s
.99375 .57131 m
1 .57131 L
s
.125 Mabswid
.99625 .07953 m
1 .07953 L
s
.99625 .11232 m
1 .11232 L
s
.99625 .1451 m
1 .1451 L
s
.99625 .21067 m
1 .21067 L
s
.99625 .24346 m
1 .24346 L
s
.99625 .27624 m
1 .27624 L
s
.99625 .34181 m
1 .34181 L
s
.99625 .3746 m
1 .3746 L
s
.99625 .40738 m
1 .40738 L
s
.99625 .47295 m
1 .47295 L
s
.99625 .50574 m
1 .50574 L
s
.99625 .53852 m
1 .53852 L
s
.99625 .01396 m
1 .01396 L
s
.99625 .60409 m
1 .60409 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.49154 0 m
.49154 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.01 w
.05128 .60332 Mdot
.07941 .51367 Mdot
.10814 .43449 Mdot
.13744 .3646 Mdot
.16724 .303 Mdot
.19751 .24888 Mdot
.2282 .20157 Mdot
.25925 .16049 Mdot
.29064 .12518 Mdot
.3223 .09525 Mdot
.3542 .07038 Mdot
.3863 .05032 Mdot
.41856 .03485 Mdot
.45092 .02382 Mdot
.48334 .01714 Mdot
.51579 .01472 Mdot
.54823 .01654 Mdot
.5806 .02262 Mdot
.61287 .03301 Mdot
.64499 .04781 Mdot
.67693 .06716 Mdot
.70863 .09126 Mdot
.74006 .12034 Mdot
.77117 .1547 Mdot
.80192 .19472 Mdot
.83225 .24084 Mdot
.86214 .2936 Mdot
.89152 .35366 Mdot
.92036 .42178 Mdot
.9486 .4989 Mdot
.5 Mabswid
.02381 .60332 m
.03076 .60332 L
.03837 .60332 L
.04221 .60332 L
.04632 .60332 L
.04831 .60332 L
.04929 .60332 L
.05019 .60332 L
.05101 .60332 L
.05188 .60139 L
.05276 .59861 L
.05372 .59554 L
.08634 .49457 L
.11753 .41209 L
.14755 .3437 L
.17946 .28115 L
.21021 .22931 L
.23978 .18625 L
.27124 .147 L
.30154 .11488 L
.33373 .08634 L
.36475 .06379 L
.39459 .04634 L
.42634 .0322 L
.44215 .02681 L
.45691 .02259 L
.4711 .01966 L
.479 .01803 L
.48067 .01769 L
.48247 .01732 L
.48297 .01721 L
.4835 .01712 L
.48445 .01705 L
.48631 .01691 L
.49013 .01663 L
.49418 .01633 L
.50275 .01569 L
.51028 .01513 L
.51245 .01496 L
.51352 .01488 L
.5145 .01481 L
.51539 .01475 L
.51634 .01475 L
.51728 .0148 L
.51833 .01486 L
.53361 .01572 L
.54091 .01613 L
.5445 .01633 L
.54625 .01643 L
.54701 .01647 L
Mistroke
.54783 .01652 L
.54877 .01664 L
.54965 .01681 L
.5516 .01717 L
.5557 .01794 L
.56289 .01929 L
.5706 .02074 L
.57469 .02151 L
.57694 .02193 L
.57906 .02233 L
.58004 .02251 L
.58107 .02277 L
.5822 .02313 L
.58325 .02347 L
.58707 .0247 L
.59453 .0271 L
.61085 .03236 L
.64011 .04556 L
.67128 .06374 L
.70127 .08566 L
.73316 .11395 L
.76388 .14665 L
.79342 .18367 L
.82487 .22961 L
.85513 .28124 L
.8873 .34503 L
.9183 .41691 L
.94812 .49759 L
.97619 .58617 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00=P3oool3000001h0oooo0`00000K0?ooo`D000006@3oool2000001`0oooo1@00000M0?oo
o`<00000703oool3000002/0oooo000e0?ooo`050000003oool0oooo0?ooo`0000007P3oool00`00
0000oooo0?ooo`0K0?ooo`040000003oool0oooo000001P0oooo00@000000?ooo`3oool00000703o
ool010000000oooo0?ooo`00000N0?ooo`030000003oool0oooo01X0oooo00D000000?ooo`3oool0
oooo0000000Z0?ooo`00;`3oool5000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0
4`3oool5000000030?ooo`000000000000<000005@3oool5000000<0oooo00<000000?ooo`3oool0
603oool010000000oooo0?ooo`00000M0?ooo`030000003oool0oooo01/0oooo1@00000K0?ooo`05
0000003oool0oooo0?ooo`000000:P3oool003D0oooo1000000L0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`00000N0?ooo`030000003oool0
oooo01X0oooo00@000000?ooo`3oool00000703oool4000002/0oooo000e0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`000000703oool01@000000oooo0?ooo`3oool0000001P0oooo00@0
00000?ooo`3oool000006`3oool01@000000oooo0?ooo`3oool0000001`0oooo00<000000?ooo`00
0000703oool00`000000oooo0?ooo`0/0?ooo`00=P3oool00`000000oooo0?ooo`0N0?ooo`800000
703oool01@000000oooo0?ooo`3oool0000001P0oooo00@000000?ooo`3oool000006`3oool01@00
0000oooo0?ooo`3oool0000001d0oooo0P00000M0?ooo`030000003oool0oooo02/0oooo000g0?oo
o`8000007`3oool00`000000oooo0?ooo`0K0?ooo`<000006P3oool2000001d0oooo0`00000O0?oo
o`030000003oool0oooo01`0oooo0P00000[0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`006`3ooooh000000d0oooo000K0?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`1k0?ooo`030000003oool0oooo00/0oooo000K0?ooo`800000M`3oool010000000oooo0?oo
o`3oool6000000@0oooo0P00001]0?ooo`8000003@3oool001/0oooo00<000000?ooo`3oool0LP3o
ool800000080oooo0P0000020?ooo`X00000JP3oool00`000000oooo0?ooo`0;0?ooo`006`3oool0
0`000000oooo0?ooo`1/0?ooo`H000000P3oool3000001<0oooo1000001V0?ooo`030000003oool0
oooo00/0oooo000K0?ooo`030000003oool0oooo06T0oooo1@0000080?ooo`030000003oool0oooo
01<0oooo1P00001R0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo06L0
oooo0P00000=0?ooo`030000003oool0oooo01T0oooo1000001N0?ooo`030000003oool0oooo00/0
oooo000K0?ooo`030000003oool0oooo06@0oooo0`00000?0?ooo`030000003oool0oooo01/0oooo
0P00001N0?ooo`030000003oool0oooo00/0oooo000=0?ooo`<00000103oool2000000D0oooo00<0
00000?ooo`3oool0HP3oool400000100oooo00<000000?ooo`3oool07@3oool3000005/0oooo00<0
00000?ooo`3oool02`3oool000`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0G`3oool3000001@0oooo00<000000?ooo`3oool0
803oool2000005T0oooo00<000000?ooo`3oool02`3oool00100oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`800000GP3oool2000001L0oooo00<000000?ooo`3oool0
8P3oool3000005D0oooo0P00000=0?ooo`00403oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0F`3oool3000001P0oooo00<000000?ooo`3oool0
8`3oool3000005D0oooo00<000000?ooo`3oool02`3oool000`0oooo100000030?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0FP3oool010000000oooo00000000000H0?ooo`03
0000003oool0oooo02H0oooo0P00001C0?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1H0?ooo`80
0000703oool00`000000oooo0?ooo`0X0?ooo`800000D@3oool00`000000oooo0?ooo`0;0?ooo`00
303oool5000000<0oooo0P0000050?ooo`030000003oool0oooo05H0oooo0P00000N0?ooo`030000
003oool0oooo02X0oooo0P00001?0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0[0?ooo`800000CP3o
ool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`1D0?ooo`800000803oool0
0`000000oooo0?ooo`0[0?ooo`<00000C@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`00
0000oooo0?ooo`1B0?ooo`@00000803oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00001B0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`180?ooo`8000003@3oool001/0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?oo
o`1>0?ooo`8000009P3oool00`000000oooo0?ooo`0a0?ooo`800000B03oool00`000000oooo0?oo
o`0;0?ooo`006`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0<P3oool2000004L0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?oo
o`3oool0C03oool2000002P0oooo00<000000?ooo`3oool0<P3oool3000004H0oooo00<000000?oo
o`3oool02`3oool001/0oooo00<000000?ooo`3oool0B`3oool3000002P0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0;0?ooo`006`3oool2000004T0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03l0oooo0P00000=0?ooo`006`3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0j0?ooo`800000?`3oool00`000000
oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`140?ooo`<00000;`3oool00`000000oooo
0?ooo`0j0?ooo`800000?`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?oo
o`140?ooo`800000<03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0;
0?ooo`006`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00/0oooo000K0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0;0?ooo`006`3oool200000440oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03H0oooo0P00000=0?ooo`006`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`120?ooo`800000=`3oool00`00
0000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000=`3oool00`000000
oooo0?ooo`120?ooo`800000=`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo
0?ooo`0l0?ooo`800000>03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool02`3oool000d0oooo0`0000020?ooo`D00000103oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo00/0oooo000<0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
2`3oool00100oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool02`3oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`800000>`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool0<03oool2000000d0oooo000<0?ooo`@000000P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0;0?ooo`00303oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo00/0oooo000<0?ooo`D000000P3oool3000000D0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo04T0oooo0P00000`
0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`190?ooo`800000<03oool00`000000oooo0?ooo`0;0?oo
o`006`3oool00`000000oooo0?ooo`0e0?ooo`800000?`3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0
=@3oool2000003l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02`3o
ool001/0oooo0P00000e0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0Z0?ooo`8000003@3oool001/0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00/0
oooo000K0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02`3oool001/0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool02`3oool001/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo0540oooo0P00000X0?ooo`030000003oool0oooo00/0oooo000K0?ooo`800000
<03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0540oooo0P00000W0?ooo`800000
3@3oool001/0oooo00<000000?ooo`3oool0;@3oool2000004L0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0
oooo02d0oooo0P0000170?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00/0oooo000K0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02`3oool001/0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool02`3oool001/0oooo0P00000[0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0Q0?ooo`8000003@3oool001/0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02`3o
ool001/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo05P0oooo0P00000Q0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1H0?ooo`8000008@3oool00`00
0000oooo0?ooo`0;0?ooo`003@3oool3000000@0oooo0`0000040?ooo`030000003oool0oooo02H0
oooo0P00001>0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0;0?ooo`00303oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0V0?ooo`800000CP3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool02`3oool00100oooo00<000000?ooo`000000
100000040?ooo`8000009`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool07@3oool2000000d0oooo000@0?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00/0oooo000<
0?ooo`@000000`3oool00`000000oooo000000050?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool02`3oool000`0oooo00<000000?ooo`3oool01@3oool2000000D0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo05`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0;0?ooo`00303oool5000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0G03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1M0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00/0oooo000K0?ooo`8000008`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool06@3oool2000000d0oooo000K0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool0H03oool2000001T0oooo00<000000?ooo`3oool02`3oool001/0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0600oooo0P00000I
0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo01h0oooo0`00001E0?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?oo
o`006`3oool00`000000oooo0?ooo`0N0?ooo`800000EP3oool00`000000oooo0?ooo`1Q0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool2000001l0oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01D0oooo0P00000=0?ooo`006`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0HP3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo
000K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool001/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00/0oooo000K0?ooo`800000703oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool04P3oool2000000d0oooo000K0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1V0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00/0oooo000K0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`1W0?ooo`8000004P3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0I`3oool200000180
oooo00<000000?ooo`3oool02`3oool000d0oooo0`0000030?ooo`<000001@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00/0oooo000<0?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool2000005d0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0
oooo000@0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool2000001P0oooo
0P00001M0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool03P3oool2000000d0oooo
000@0?ooo`030000003oool0000000<000001@3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00/0oooo000<0?ooo`@000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool000`0
oooo1@0000030?ooo`8000001@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0
oooo000K0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`1Z0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool001/0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo06/0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02`3oool001/0oooo0P00000E0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool0K03oool00`000000oooo0?ooo`0;0?ooo`8000003@3oool001/0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00/0oooo000K0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool0
01/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
06d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1^0?ooo`8000002`3oool00`000000oooo
0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool0KP3oool2000000/0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00000B
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`09
0?ooo`8000003@3oool001/0oooo00<000000?ooo`3oool0403oool2000006@0oooo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo000K0?ooo`03
0000003oool0oooo0100oooo0P00001T0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3o
ool001/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0700oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02`3oool001/0oooo0P00000@0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`060?ooo`8000003@3oool001/0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02`3oool001/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo0780oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`00
3@3oool3000000<0oooo0`0000050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3oool000`0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo000@0?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00/0oooo000@0?ooo`030000003oool0oooo00<000001@3oool2000000d0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00<0oooo0P00
000=0?ooo`00303oool400000080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0;0?ooo`00303oool500000080oooo0`0000050?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo07D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?oo
o`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0;0?ooo`006`3o
ool00`000000oooo0?ooo`090?ooo`800000J`3oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo00/0oooo000K0?ooo`800000103oool8000006/0oooo00<000000?ooo`3oool0NP3oool2
000000d0oooo000K0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo000000070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0
oooo000K0?ooooP000003@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00<T0
oooo0`00001D0?ooo`00bP3oool00`000000oooo0?ooo`1C0?ooo`00GP3oool00`000000oooo0000
00030?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`<000000P3oool3000000<0oooo0`00
00040?ooo`<000000P3oool3000000030?ooo`00000000000080oooo0P0000080?ooo`D0000000D0
oooo00000000000000000?ooo`0200000080oooo0P0000030?ooo`<000000P3oool3000000030?oo
o`000000000000@000000P3oool5000000<0oooo0P0000040?ooo`030000003oool0oooo0580oooo
001N0?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000103oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000001P3oool010000000oooo0?ooo`0000050?ooo`050000003oool0
oooo0?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0580oooo
001N0?ooo`030000003oool0000000<0oooo0`0000030?ooo`030000003oool000000080oooo1@00
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`D000000P3oool010000000oooo0?ooo`0000020?ooo`<00000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000D`3oool005d0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`<000000`3oool2000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`000007
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0000001C
0?ooo`00G@3oool01@000000oooo0000003oool000000080oooo0P0000030?ooo`80000000<0oooo
0000000000000P3oool3000000<0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000
00000080oooo0`0000020?ooo`@000000P3oool4000000X0oooo00@000000?ooo`3oool0oooo1000
00020?ooo`@000000`3oool300000080oooo100000030?ooo`@0000000@0oooo0000000000000000
0`3oool400000080oooo0P0000000`3oool000000000001B0?ooo`00G@3oool01@000000oooo0000
003oool0000001@0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00
G@3oool600000180oooo1@00000D0?ooo`030000003oool0oooo00P0oooo1@0000080?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1I0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.39084, 48.541, 0.0630714, \
0.0617031}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.491544 0.0641471 0.309017 9.15183e-05 [
[.10666 -0.0125 -6 -9 ]
[.10666 -0.0125 6 0 ]
[.23496 -0.0125 -6 -9 ]
[.23496 -0.0125 6 0 ]
[.36325 -0.0125 -6 -9 ]
[.36325 -0.0125 6 0 ]
[.49154 -0.0125 -3 -9 ]
[.49154 -0.0125 3 0 ]
[.61984 -0.0125 -3 -9 ]
[.61984 -0.0125 3 0 ]
[.74813 -0.0125 -3 -9 ]
[.74813 -0.0125 3 0 ]
[.87643 -0.0125 -3 -9 ]
[.87643 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03446 -30 -4.5 ]
[-0.0125 .03446 0 4.5 ]
[-0.0125 .12598 -30 -4.5 ]
[-0.0125 .12598 0 4.5 ]
[-0.0125 .2175 -30 -4.5 ]
[-0.0125 .2175 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40054 -24 -4.5 ]
[-0.0125 .40054 0 4.5 ]
[-0.0125 .49205 -24 -4.5 ]
[-0.0125 .49205 0 4.5 ]
[-0.0125 .58357 -24 -4.5 ]
[-0.0125 .58357 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10666 0 m
.10666 .00625 L
s
[(-6)] .10666 -0.0125 0 1 Mshowa
.23496 0 m
.23496 .00625 L
s
[(-4)] .23496 -0.0125 0 1 Mshowa
.36325 0 m
.36325 .00625 L
s
[(-2)] .36325 -0.0125 0 1 Mshowa
.49154 0 m
.49154 .00625 L
s
[(0)] .49154 -0.0125 0 1 Mshowa
.61984 0 m
.61984 .00625 L
s
[(2)] .61984 -0.0125 0 1 Mshowa
.74813 0 m
.74813 .00625 L
s
[(4)] .74813 -0.0125 0 1 Mshowa
.87643 0 m
.87643 .00625 L
s
[(6)] .87643 -0.0125 0 1 Mshowa
.125 Mabswid
.13874 0 m
.13874 .00375 L
s
.17081 0 m
.17081 .00375 L
s
.20288 0 m
.20288 .00375 L
s
.26703 0 m
.26703 .00375 L
s
.2991 0 m
.2991 .00375 L
s
.33118 0 m
.33118 .00375 L
s
.39532 0 m
.39532 .00375 L
s
.4274 0 m
.4274 .00375 L
s
.45947 0 m
.45947 .00375 L
s
.52362 0 m
.52362 .00375 L
s
.55569 0 m
.55569 .00375 L
s
.58776 0 m
.58776 .00375 L
s
.65191 0 m
.65191 .00375 L
s
.68399 0 m
.68399 .00375 L
s
.71606 0 m
.71606 .00375 L
s
.78021 0 m
.78021 .00375 L
s
.81228 0 m
.81228 .00375 L
s
.84435 0 m
.84435 .00375 L
s
.9085 0 m
.9085 .00375 L
s
.94057 0 m
.94057 .00375 L
s
.97265 0 m
.97265 .00375 L
s
.07459 0 m
.07459 .00375 L
s
.04251 0 m
.04251 .00375 L
s
.01044 0 m
.01044 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03446 m
.00625 .03446 L
s
[(-3000)] -0.0125 .03446 1 0 Mshowa
0 .12598 m
.00625 .12598 L
s
[(-2000)] -0.0125 .12598 1 0 Mshowa
0 .2175 m
.00625 .2175 L
s
[(-1000)] -0.0125 .2175 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40054 m
.00625 .40054 L
s
[(1000)] -0.0125 .40054 1 0 Mshowa
0 .49205 m
.00625 .49205 L
s
[(2000)] -0.0125 .49205 1 0 Mshowa
0 .58357 m
.00625 .58357 L
s
[(3000)] -0.0125 .58357 1 0 Mshowa
.125 Mabswid
0 .05277 m
.00375 .05277 L
s
0 .07107 m
.00375 .07107 L
s
0 .08937 m
.00375 .08937 L
s
0 .10768 m
.00375 .10768 L
s
0 .14428 m
.00375 .14428 L
s
0 .16259 m
.00375 .16259 L
s
0 .18089 m
.00375 .18089 L
s
0 .1992 m
.00375 .1992 L
s
0 .2358 m
.00375 .2358 L
s
0 .25411 m
.00375 .25411 L
s
0 .27241 m
.00375 .27241 L
s
0 .29071 m
.00375 .29071 L
s
0 .32732 m
.00375 .32732 L
s
0 .34562 m
.00375 .34562 L
s
0 .36393 m
.00375 .36393 L
s
0 .38223 m
.00375 .38223 L
s
0 .41884 m
.00375 .41884 L
s
0 .43714 m
.00375 .43714 L
s
0 .45545 m
.00375 .45545 L
s
0 .47375 m
.00375 .47375 L
s
0 .51036 m
.00375 .51036 L
s
0 .52866 m
.00375 .52866 L
s
0 .54696 m
.00375 .54696 L
s
0 .56527 m
.00375 .56527 L
s
0 .01616 m
.00375 .01616 L
s
0 .60188 m
.00375 .60188 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.10666 .61178 m
.10666 .61803 L
s
.23496 .61178 m
.23496 .61803 L
s
.36325 .61178 m
.36325 .61803 L
s
.49154 .61178 m
.49154 .61803 L
s
.61984 .61178 m
.61984 .61803 L
s
.74813 .61178 m
.74813 .61803 L
s
.87643 .61178 m
.87643 .61803 L
s
.125 Mabswid
.13874 .61428 m
.13874 .61803 L
s
.17081 .61428 m
.17081 .61803 L
s
.20288 .61428 m
.20288 .61803 L
s
.26703 .61428 m
.26703 .61803 L
s
.2991 .61428 m
.2991 .61803 L
s
.33118 .61428 m
.33118 .61803 L
s
.39532 .61428 m
.39532 .61803 L
s
.4274 .61428 m
.4274 .61803 L
s
.45947 .61428 m
.45947 .61803 L
s
.52362 .61428 m
.52362 .61803 L
s
.55569 .61428 m
.55569 .61803 L
s
.58776 .61428 m
.58776 .61803 L
s
.65191 .61428 m
.65191 .61803 L
s
.68399 .61428 m
.68399 .61803 L
s
.71606 .61428 m
.71606 .61803 L
s
.78021 .61428 m
.78021 .61803 L
s
.81228 .61428 m
.81228 .61803 L
s
.84435 .61428 m
.84435 .61803 L
s
.9085 .61428 m
.9085 .61803 L
s
.94057 .61428 m
.94057 .61803 L
s
.97265 .61428 m
.97265 .61803 L
s
.07459 .61428 m
.07459 .61803 L
s
.04251 .61428 m
.04251 .61803 L
s
.01044 .61428 m
.01044 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03446 m
1 .03446 L
s
.99375 .12598 m
1 .12598 L
s
.99375 .2175 m
1 .2175 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40054 m
1 .40054 L
s
.99375 .49205 m
1 .49205 L
s
.99375 .58357 m
1 .58357 L
s
.125 Mabswid
.99625 .05277 m
1 .05277 L
s
.99625 .07107 m
1 .07107 L
s
.99625 .08937 m
1 .08937 L
s
.99625 .10768 m
1 .10768 L
s
.99625 .14428 m
1 .14428 L
s
.99625 .16259 m
1 .16259 L
s
.99625 .18089 m
1 .18089 L
s
.99625 .1992 m
1 .1992 L
s
.99625 .2358 m
1 .2358 L
s
.99625 .25411 m
1 .25411 L
s
.99625 .27241 m
1 .27241 L
s
.99625 .29071 m
1 .29071 L
s
.99625 .32732 m
1 .32732 L
s
.99625 .34562 m
1 .34562 L
s
.99625 .36393 m
1 .36393 L
s
.99625 .38223 m
1 .38223 L
s
.99625 .41884 m
1 .41884 L
s
.99625 .43714 m
1 .43714 L
s
.99625 .45545 m
1 .45545 L
s
.99625 .47375 m
1 .47375 L
s
.99625 .51036 m
1 .51036 L
s
.99625 .52866 m
1 .52866 L
s
.99625 .54696 m
1 .54696 L
s
.99625 .56527 m
1 .56527 L
s
.99625 .01616 m
1 .01616 L
s
.99625 .60188 m
1 .60188 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.49154 0 m
.49154 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.05128 .5866 Mdot
.07941 .56946 Mdot
.10814 .55193 Mdot
.13744 .53403 Mdot
.16724 .5158 Mdot
.19751 .49726 Mdot
.2282 .47845 Mdot
.25925 .45939 Mdot
.29064 .44011 Mdot
.3223 .42064 Mdot
.3542 .40101 Mdot
.3863 .38124 Mdot
.41856 .36135 Mdot
.45092 .34139 Mdot
.48334 .32136 Mdot
.51579 .30131 Mdot
.54823 .28125 Mdot
.5806 .26121 Mdot
.61287 .24121 Mdot
.64499 .22129 Mdot
.67693 .20147 Mdot
.70863 .18178 Mdot
.74006 .16224 Mdot
.77117 .14288 Mdot
.80192 .12372 Mdot
.83225 .1048 Mdot
.86214 .08614 Mdot
.89152 .06778 Mdot
.92036 .04973 Mdot
.9486 .03203 Mdot
.5 Mabswid
.02381 .60332 m
.05372 .58512 L
.08634 .56523 L
.11698 .54653 L
.14644 .52852 L
.1778 .50933 L
.20799 .49084 L
.24008 .47116 L
.27099 .45218 L
.30073 .43391 L
.33237 .41445 L
.36283 .39569 L
.39213 .37765 L
.42332 .35842 L
.45333 .33989 L
.48525 .32018 L
.51599 .30119 L
.54556 .2829 L
.57703 .26342 L
.60732 .24465 L
.63951 .22469 L
.67053 .20544 L
.70038 .18691 L
.73212 .16717 L
.76269 .14815 L
.79209 .12984 L
.82339 .11033 L
.85351 .09153 L
.88553 .07152 L
.91638 .05222 L
.94605 .03363 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00?`3oool3000001h0oooo0`00000K0?ooo`D000006@3oool2000001`0oooo1@00000M0?oo
o`<00000703oool300000280oooo000n0?ooo`050000003oool0oooo0?ooo`0000007P3oool00`00
0000oooo0?ooo`0K0?ooo`040000003oool0oooo000001P0oooo00@000000?ooo`3oool00000703o
ool010000000oooo0?ooo`00000N0?ooo`030000003oool0oooo01X0oooo00D000000?ooo`3oool0
oooo0000000Q0?ooo`00>03oool5000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0
4`3oool5000000030?ooo`000000000000<000005@3oool5000000<0oooo00<000000?ooo`3oool0
603oool010000000oooo0?ooo`00000M0?ooo`030000003oool0oooo01/0oooo1@00000K0?ooo`05
0000003oool0oooo0?ooo`0000008@3oool003h0oooo1000000L0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`00000N0?ooo`030000003oool0
oooo01X0oooo00@000000?ooo`3oool00000703oool400000280oooo000n0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`000000703oool01@000000oooo0?ooo`3oool0000001P0oooo00@0
00000?ooo`3oool000006`3oool01@000000oooo0?ooo`3oool0000001`0oooo00<000000?ooo`00
0000703oool00`000000oooo0?ooo`0S0?ooo`00?`3oool00`000000oooo0?ooo`0N0?ooo`800000
703oool01@000000oooo0?ooo`3oool0000001P0oooo00@000000?ooo`3oool000006`3oool01@00
0000oooo0?ooo`3oool0000001d0oooo0P00000M0?ooo`030000003oool0oooo0280oooo00100?oo
o`8000007`3oool00`000000oooo0?ooo`0K0?ooo`<000006P3oool2000001d0oooo0`00000O0?oo
o`030000003oool0oooo01`0oooo0P00000R0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00903ooooh000000@0oooo000T0?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool0M03oool2000000D0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001g
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0103oool2000000@0oooo000T0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0L@3oool2000000P0oooo00<000000?oo
o`3oool00P3oool000X0oooo0`0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo06h0oooo0P00000;0?ooo`030000003o
ool0oooo0080oooo00030?ooo`D000001@3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`80
0000M`3oool00`000000oooo0?ooo`1]0?ooo`<000002P3oool2000000@0oooo000;0?ooo`800000
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`003@3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0JP3oool2000000l0oooo
00<000000?ooo`3oool00P3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0J03oool200000140oooo00<00000
0?ooo`3oool00P3oool000X0oooo0`0000040?ooo`800000103oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0I`3oool200000180oooo00<000000?oo
o`3oool00P3oool002@0oooo0P00001g0?ooo`030000003oool0oooo06D0oooo1000000A0?ooo`80
0000103oool002@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1S0?ooo`800000
5P3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00903oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0600oooo0P00000I0?ooo`030000003oool0
oooo0080oooo000T0?ooo`800000M`3oool00`000000oooo0?ooo`1N0?ooo`@00000603oool20000
00@0oooo000T0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool0F`3oool2000001h0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`1I0?ooo`800000803oool00`000000oooo0?oo
o`020?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo05P0oooo0P00000Q
0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000M`3oool00`000000oooo0?ooo`1F0?oo
o`@00000803oool2000000@0oooo000T0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000
003oool0oooo07H0oooo00<000000?ooo`3oool0D`3oool2000002H0oooo00<000000?ooo`3oool0
0P3oool002@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1A0?ooo`800000:03o
ool00`000000oooo0?ooo`020?ooo`00903oool2000007L0oooo00<000000?ooo`3oool0D03oool3
000002L0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
04h0oooo0P00000[0?ooo`030000003oool0oooo0080oooo00090?ooo`D000000`3oool2000000@0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`002P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B`3o
ool2000002h0oooo00<000000?ooo`3oool00P3oool000<0oooo1@0000030?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`190?ooo`80
0000<03oool00`000000oooo0?ooo`020?ooo`00303oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo0P00001g0?ooo`030000003oool0oooo04T0oooo0P00000_0?ooo`800000103oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0A`3oool200000380oooo00<000000?ooo`3oool00P3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool0A@3oool2000003@0oooo00<000000?ooo`3oool00P3oool000X0oooo0`000004
0?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0@`3oool2000003H0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001g0?oo
o`030000003oool0oooo0440oooo0`00000f0?ooo`800000103oool002@0oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`0o0?ooo`80000000<0oooo000000000000=`3oool00`000000
oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo03`0oooo0P00000m0?ooo`030000003oool0oooo0080oooo000T
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0>P3oool2000003l0oooo00<00000
0?ooo`3oool00P3oool002@0oooo0P00001g0?ooo`030000003oool0oooo03X0oooo0P00000n0?oo
o`800000103oool002@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0h0?ooo`80
0000@@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`020?ooo`00903o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03D0oooo0P0000140?ooo`030000003o
ool0oooo0080oooo000T0?ooo`800000M`3oool00`000000oooo0?ooo`0b0?ooo`<00000A@3oool2
000000@0oooo000T0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0<P3oool20000
04L0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`0`0?ooo`800000B@3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo02h0oooo0P00001;0?ooo`030000003oool0oooo0080oooo
000T0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000M`3oool00`000000oooo0?ooo`0[
0?ooo`800000C@3oool2000000@0oooo000T0?ooo`030000003oool0oooo07H0oooo00<000000?oo
o`3oool0:@3oool4000004h0oooo00<000000?ooo`3oool00P3oool000X0oooo0`0000040?ooo`80
0000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0080oooo000;0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0V
0?ooo`800000D`3oool00`000000oooo0?ooo`020?ooo`000`3oool5000000<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool2000007L0oooo00<000000?ooo`3oool0903oool2000005@0oooo
0P0000040?ooo`002`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool08`3oool2000005H0oooo00<000000?ooo`3oool00P3oool000/0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo0240oooo1000001F0?ooo`030000003oool0oooo0080oooo000:0?ooo`800000103oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`020?ooo`002`3oool00`000000oooo0?ooo`030?ooo`800000
103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
7P3oool2000005/0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001g0?ooo`030000003o
ool0oooo01`0oooo0P00001L0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`0K0?ooo`800000GP3oool00`000000oooo0?ooo`020?ooo`00903oool00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo01T0oooo1000001N0?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000M`3oool00`000000oooo
0?ooo`0F0?ooo`800000HP3oool2000000@0oooo000T0?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0080oooo000T
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool04`3oool2000006H0oooo00<00000
0?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0B0?oo
o`<00000IP3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`020?ooo`00
903oool2000007L0oooo00<000000?ooo`3oool03`3oool2000006T0oooo0P0000040?ooo`00903o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00d0oooo0P00001/0?ooo`030000003o
ool0oooo0080oooo000T0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool02`3oool2
000006h0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0:0?ooo`<00000KP3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo00P0oooo0P00001a0?ooo`030000003oool0oooo0080
oooo000T0?ooo`800000M`3oool00`000000oooo0?ooo`060?ooo`800000LP3oool2000000@0oooo
000T0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0103oool2000007D0oooo00<0
00000?ooo`3oool00P3oool001d0oooo0P0000050?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool00P3oool3000007H0oooo00<000000?ooo`3oool00P3oool001`0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`1f0?ooo`060000003oool0oooo0?ooo`000000oooo
0P00001f0?ooo`030000003oool0oooo0080oooo000L0?ooo`040000003oool0oooo000000@0oooo
n00000040?ooo`00703oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07H0oooo
0P00001l0?ooo`030000003oool0oooo0080oooo000L0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo
000L0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0M03oool3000007d0oooo
00<000000?ooo`3oool00P3oool001d0oooo0P0000050?ooo`030000003oool0oooo07<0oooo1000
001m0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000LP3oool2000000<0oooo00<00000
0?ooo`3oool0NP3oool2000000@0oooo000T0?ooo`030000003oool0oooo06l0oooo0P0000050?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3o
ool0KP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0K03oool2000000P0oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`020?ooo`00903oool2000006/0oooo100000080?ooo`030000003o
ool0oooo07X0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool00`00
0000oooo0?ooo`1W0?ooo`8000003@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo06D0oooo0P00000?0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0I03oool200000100oooo
00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool2000006<0oooo1000
000@0?ooo`030000003oool0oooo07X0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`1P
0?ooo`800000503oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1k0?oo
o`030000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo05d0oooo0P00000G0?ooo`03
0000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo0P00001L0?ooo`<00000
603oool00`000000oooo0?ooo`1j0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0FP3o
ool010000000oooo00000000000H0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
0P3oool000X0oooo0`0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003o
ool0oooo05P0oooo0P00000L0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3o
ool000/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`80
00007P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000;0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0E03oool200000200oooo00<00000
0?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`002`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`800000E03oool300000200oooo00<000000?ooo`3oool0NP3oool2000000@0oooo
000;0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0D@3oool20000
02<0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`002P3oool2000000@0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool00P3oool000/0oooo00<000000?ooo`3oool00`3oool2
000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1>0?ooo`8000009P3oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000C@3oool20000
02P0oooo00<000000?ooo`3oool0NP3oool2000000@0oooo000T0?ooo`030000003oool0oooo04/0
oooo0`00000X0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo
00<000000?ooo`3oool0B@3oool2000002/0oooo00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`020?ooo`00903oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`16
0?ooo`800000;P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?oo
o`800000A@3oool200000300oooo00<000000?ooo`3oool0NP3oool2000000@0oooo000T0?ooo`03
0000003oool0oooo04<0oooo0`00000`0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3o
ool00P3oool002@0oooo00<000000?ooo`3oool0@@3oool2000003<0oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0o0?ooo`800000=@3o
ool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?ooo`800000?`3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo07X0oooo0P0000040?ooo`00903oool00`00
0000oooo0?ooo`0l0?ooo`800000>03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo03X0oooo1000000h0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool0=`3oool2000003d0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`020?ooo`00903oool2000003L0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1j
0?ooo`800000103oool002@0oooo00<000000?ooo`3oool0=03oool3000003l0oooo00<000000?oo
o`3oool0N`3oool00`000000oooo0?ooo`020?ooo`002@3oool5000000<0oooo0P0000040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool0<P3oool2000000030?ooo`000000000003l0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`002P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000;0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo0P00000`0?ooo`800000A@3oool00`000000oooo0?ooo`1j0?ooo`80
0000103oool000`0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02d0oooo0P0000170?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02`0
oooo0`0000170?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000:
0?ooo`<00000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`02
0?ooo`00903oool2000002T0oooo0P00001<0?ooo`030000003oool0oooo07X0oooo0P0000040?oo
o`00903oool00`000000oooo0?ooo`0V0?ooo`800000CP3oool00`000000oooo0?ooo`1k0?ooo`03
0000003oool0oooo0080oooo000T0?ooo`030000003oool0oooo02@0oooo1000001>0?ooo`030000
003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool08P3o
ool200000580oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool2
00000240oooo0P00001D0?ooo`030000003oool0oooo07X0oooo0P0000040?ooo`00903oool00`00
0000oooo0?ooo`0N0?ooo`800000EP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo
0080oooo000T0?ooo`030000003oool0oooo01d0oooo0`00001F0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool00P3oool002@0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo07/0oooo00<0
00000?ooo`3oool00P3oool002@0oooo0P00000J0?ooo`800000F`3oool00`000000oooo0?ooo`1j
0?ooo`800000103oool002@0oooo00<000000?ooo`3oool05`3oool2000005d0oooo00<000000?oo
o`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo0?ooo`0E0?ooo`@0
0000G@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0080oooo000T0?ooo`030000
003oool0oooo01<0oooo0P00001Q0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
0P3oool002@0oooo0P00000B0?ooo`800000H`3oool00`000000oooo0?ooo`1j0?ooo`800000103o
ool002@0oooo00<000000?ooo`3oool0403oool2000006@0oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`020?ooo`002P3oool3000000@0oooo0P0000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool03P3oool4000006@0oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`020?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0303oool2000006P0oooo00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`020?ooo`003@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo
0080oooo000;0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool2000000X0oooo0P00001[0?ooo`030000003o
ool0oooo07X0oooo0P0000040?ooo`003@3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo0`00001[0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3o
ool00P3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00H0oooo0P00001^0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3o
ool000X0oooo0`0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0
oooo0080oooo000T0?ooo`8000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
07X0oooo0P0000040?ooo`00903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`00903oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0
00000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`00903ooooh000000@0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo000f0?ooo`<00000RP3oool00`000000oooo0?oo
o`0[0?ooo`<000005@3oool00`000000oooo0?ooo`0D0?ooo`00=`3oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`00<@3oool3000000<0oooo0`0000040?ooo`8000000P3oool500000080oooo0`0000030?oo
o`@0000000<0oooo0000000000000`0000070?ooo`<00000103oool4000000<0oooo0P0000020?oo
o`H000001P3oool400000080oooo1@0000000`3oool0000000000003000000030?ooo`0000000000
00<000000P3oool300000080oooo0`0000040?ooo`<000000P3oool3000000040?ooo`0000000000
0?ooo`<000000`3oool3000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000003
0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`<000000P3oool500000080oooo0`000002
0?ooo`<0000000@0oooo000000000000oooo100000030?ooo`8000000P3oool:000000D0oooo00<0
00000?ooo`3oool04P3oool00300oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`00
00001`3oool01@000000oooo0?ooo`3oool0000000H0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00300oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool0000000H0oooo0`0000040?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000
oooo0?ooo`020?ooo`D000000P3oool01P000000oooo0?ooo`000000oooo000000D0oooo1@000008
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000020?ooo`<000000`3o
ool00`000000oooo000000020?ooo`D000000`3oool010000000oooo0?ooo`3oool500000080oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo000000D0oooo00@00000
0?ooo`3oool000000P3oool3000000D0oooo00<000000?ooo`3oool04P3oool00300oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0`0000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000050?ooo`06
0000003oool0oooo0000003oool00000203oool00`000000oooo0?ooo`0B0?ooo`00<03oool01P00
0000oooo0?ooo`3oool000000?ooo`@000000P3oool400000080oooo0`0000040?ooo`<000000`3o
ool2000000D0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000020?ooo`800000
0`3oool4000000<0oooo0`0000090?ooo`050000003oool0oooo0000003oool00`0000040?ooo`@0
00000P3oool400000080oooo0`0000020?ooo`80000000<0oooo0000000000000P3oool300000080
oooo100000030?ooo`<000000`3oool3000000T0oooo00<000000?ooo`3oool00P3oool600000003
0?ooo`000000000000<0oooo0P0000000`3oool00000000000020?ooo`<00000103oool00`000000
oooo0?ooo`020?ooo`<000000P3oool4000000<0oooo2@0000030?ooo`<000000`3oool4000000@0
oooo00<000000?ooo`3oool04P3oool00300oooo00D000000?ooo`3oool0oooo000000080?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01<0oooo000a0?ooo`<000002@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00d0oooo0`0000090?ooo`@000002@3oool00`000000oooo0?ooo`020?oo
o`8000002P3oool4000000@0oooo00<000000?ooo`3oool0103oool2000000@0oooo0P00000^0?oo
o`030000003oool0oooo01P0oooo0`00000F0?ooo`030000003oool0oooo0080oooo0P00000;0?oo
o`030000003oool0oooo01@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.95848, -3911.05, \
0.0630714, 44.208}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-7.256663245138756`\), 
                      8.955795666423587`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-7.256663245138756`\), 
                      8.955795666423587`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {923.0570666149966`, 
                930.4801445977803`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(RayBoundary \[Rule] {\(-7.256663245138756`\), 
                8.955795666423587`}\), ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-7.256663245138756`\), 
                      8.955795666423587`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\)}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-7.291598286604544`\), 
                      7.555233492754599`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-7.291598286604544`\), 
                      7.555233492754599`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {567.9277081790177`, 
                571.3492892123908`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(RayBoundary \[Rule] {\(-7.291598286604544`\), 
                7.555233492754599`}\), ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-7.291598286604544`\), 
                      7.555233492754599`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\)}], 
          "}"}]}], "}"}]], "Output",
  CellLabel->"Out[20]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindInterference[combinedsys,PlotDomain->{0,.01}];", "Input",
  CellLabel->"In[21]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 95.2381 186.9 0.0689417 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -15 -9 ]
[.21429 -0.0125 15 0 ]
[.40476 -0.0125 -15 -9 ]
[.40476 -0.0125 15 0 ]
[.59524 -0.0125 -15 -9 ]
[.59524 -0.0125 15 0 ]
[.78571 -0.0125 -15 -9 ]
[.78571 -0.0125 15 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06842 -30 -4.5 ]
[-0.0125 .06842 0 4.5 ]
[-0.0125 .2063 -30 -4.5 ]
[-0.0125 .2063 0 4.5 ]
[-0.0125 .34419 -30 -4.5 ]
[-0.0125 .34419 0 4.5 ]
[-0.0125 .48207 -30 -4.5 ]
[-0.0125 .48207 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.002)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.004)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.006)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.008)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.01)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06842 m
.00625 .06842 L
s
[(-2710)] -0.0125 .06842 1 0 Mshowa
0 .2063 m
.00625 .2063 L
s
[(-2708)] -0.0125 .2063 1 0 Mshowa
0 .34419 m
.00625 .34419 L
s
[(-2706)] -0.0125 .34419 1 0 Mshowa
0 .48207 m
.00625 .48207 L
s
[(-2704)] -0.0125 .48207 1 0 Mshowa
.125 Mabswid
0 .10289 m
.00375 .10289 L
s
0 .13736 m
.00375 .13736 L
s
0 .17183 m
.00375 .17183 L
s
0 .24077 m
.00375 .24077 L
s
0 .27524 m
.00375 .27524 L
s
0 .30971 m
.00375 .30971 L
s
0 .37866 m
.00375 .37866 L
s
0 .41313 m
.00375 .41313 L
s
0 .4476 m
.00375 .4476 L
s
0 .51654 m
.00375 .51654 L
s
0 .55101 m
.00375 .55101 L
s
0 .58548 m
.00375 .58548 L
s
0 .03395 m
.00375 .03395 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06842 m
1 .06842 L
s
.99375 .2063 m
1 .2063 L
s
.99375 .34419 m
1 .34419 L
s
.99375 .48207 m
1 .48207 L
s
.125 Mabswid
.99625 .10289 m
1 .10289 L
s
.99625 .13736 m
1 .13736 L
s
.99625 .17183 m
1 .17183 L
s
.99625 .24077 m
1 .24077 L
s
.99625 .27524 m
1 .27524 L
s
.99625 .30971 m
1 .30971 L
s
.99625 .37866 m
1 .37866 L
s
.99625 .41313 m
1 .41313 L
s
.99625 .4476 m
1 .4476 L
s
.99625 .51654 m
1 .51654 L
s
.99625 .55101 m
1 .55101 L
s
.99625 .58548 m
1 .58548 L
s
.99625 .03395 m
1 .03395 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06842 m
1 .06842 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.03853 .02381 L
.05458 .03373 L
.06965 .04305 L
.08415 .05201 L
.09958 .06155 L
.11444 .07073 L
.13023 .08048 L
.14544 .08989 L
.16007 .09893 L
.17564 .10855 L
.19063 .11782 L
.20504 .12672 L
.22039 .13621 L
.23516 .14534 L
.25087 .15504 L
.26599 .16439 L
.28054 .17339 L
.29603 .18296 L
.31093 .19217 L
.32678 .20196 L
.34204 .21139 L
.35672 .22047 L
.37234 .23012 L
.38739 .23942 L
.40185 .24836 L
.41725 .25788 L
.43208 .26704 L
.44783 .27678 L
.46301 .28616 L
.47761 .29518 L
.49315 .30478 L
.50811 .31403 L
.52249 .32292 L
.5378 .33238 L
.55254 .34149 L
.56821 .35118 L
.58331 .3605 L
.59783 .36948 L
.61328 .37903 L
.62815 .38822 L
.64396 .39799 L
.65919 .4074 L
.67385 .41646 L
.68943 .42609 L
.70445 .43537 L
.71888 .44429 L
.73425 .45379 L
.74904 .46293 L
.76476 .47265 L
Mistroke
.77991 .48201 L
.79448 .49101 L
.80998 .5006 L
.82491 .50982 L
.84077 .51962 L
.85605 .52907 L
.87076 .53816 L
.8864 .54782 L
.90146 .55713 L
.91595 .56609 L
.93137 .57562 L
.94621 .58479 L
.96198 .59454 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`009P3oool200000240oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000P3oool5000001@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`800000103oool3000001@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000`3oool3000001D0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000`3oool3000001P0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?oo
o`<00000103oool002D0oooo00@000000?ooo`3oool000007`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00000C0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0503oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool002D0oooo00@000000?ooo`3oool000007`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0C0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?oo
o`000000oooo00D000004`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0140oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`009@3oool010000000oooo0?oo
o`00000O0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000P3oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool01@000000oooo0?ooo`000000oooo00@00000503oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool3000001L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo
000U0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`0A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0000001@0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000005`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo000U0?ooo`040000003oool0oooo0000
01l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000503o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool0503oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo0P000005
0?ooo`009P3oool200000240oooo0P00000:0?ooo`800000103oool2000000<0oooo0`00000E0?oo
o`8000002P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo01<0oooo0P00000:0?oo
o`800000103oool2000000@0oooo0P00000E0?ooo`8000002P3oool2000000@0oooo0P0000030?oo
o`<00000603oool2000000X0oooo0P0000040?ooo`030000003oool0oooo00<0oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000Q0?ooooP000001`3oool00240
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo
0?ooo`3d0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0kP3oool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0>d0oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`03
0000003oool0oooo00H0oooo0P00003/0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000
003oool0oooo00P0oooo0P00003Z0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`8000002`3o
ool200000>L0oooo0P0000070?ooo`008@3oool00`000000oooo0?ooo`0<0?ooo`800000iP3oool0
0`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`0>0?ooo`800000i03oool00`00
0000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0>40
oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`3P0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo0180oooo0P00
003P0?ooo`030000003oool0oooo00D0oooo00060?ooo`D000000`3oool00`000000oooo0?ooo`02
0?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0503oool200000=h0oooo00<00000
0?ooo`3oool01@3oool000L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0F0?ooo`800000g03oool00`000000oooo0?ooo`050?ooo`001@0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3I0?ooo`030000003o
ool0oooo00D0oooo00090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooon00000070?ooo`001P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3F0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`030000003oool0oooo00800000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`050?ooo`001`3oool30000
0080oooo1@0000030?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo
01d0oooo0P00003E0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo01l0
oooo0P00003C0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo0240oooo
0P00003A0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`0T
0?ooo`800000cP3oool00`000000oooo0?ooo`050?ooo`008@3oool2000002L0oooo0P00003;0?oo
o`8000001`3oool00240oooo00<000000?ooo`3oool0:03oool200000<X0oooo00<000000?ooo`3o
ool01@3oool00240oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`370?ooo`030000
003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0aP3o
ool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`0/0?ooo`800000aP3oool0
0`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`0^0?ooo`800000a03oool00`00
0000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`800000`P3oool00`000000
oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool0<`3oool200000;l0oooo00<0
00000?ooo`3oool01@3oool00240oooo0P00000f0?ooo`030000003oool0oooo0;/0oooo0P000007
0?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0;/0oooo00<000000?oo
o`3oool01@3oool00240oooo00<000000?ooo`3oool0=`3oool200000;/0oooo00<000000?ooo`3o
ool01@3oool00240oooo00<000000?ooo`3oool0>@3oool200000;T0oooo00<000000?ooo`3oool0
1@3oool00240oooo00<000000?ooo`3oool0>`3oool200000;L0oooo00<000000?ooo`3oool01@3o
ool00240oooo00<000000?ooo`3oool0?@3oool200000;D0oooo00<000000?ooo`3oool01@3oool0
0240oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo
00D0oooo000Q0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0/@3oool00`000000
oooo0?ooo`050?ooo`008@3oool200000480oooo00<000000?ooo`3oool0[`3oool2000000L0oooo
000Q0?ooo`030000003oool0oooo0480oooo0P00002`0?ooo`030000003oool0oooo00D0oooo000Q
0?ooo`030000003oool0oooo04@0oooo0P00002^0?ooo`030000003oool0oooo00D0oooo000Q0?oo
o`030000003oool0oooo04H0oooo0P00002/0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`03
0000003oool0oooo04P0oooo0P00002Z0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000
003oool0oooo04X0oooo0P00002X0?ooo`030000003oool0oooo00D0oooo00060?ooo`D000000`3o
ool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00D0oooo00070?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0:@0
oooo00<000000?ooo`3oool01@3oool000D000000`3oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0CP3oool200000:@0oooo00<000000?ooo`3oool01@3oool000T0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00`0000050?ooo`800000D@3oool00`000000oooo0?ooo`2P0?ooo`8000001`3oool000H0oooo
00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0540oooo0P00002Q0?oo
o`030000003oool0oooo00D0oooo00060?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo05<0oooo0P00002O0?ooo`030000003oool0oooo00D0oooo0007
0?ooo`<000000P3oool5000000<0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`1E
0?ooo`800000W@3oool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo09X0oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000
003oool0oooo05T0oooo0P00002I0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003o
ool0oooo05/0oooo0P00002G0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`800000GP3oool2
000009@0oooo0P0000070?ooo`008@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
0980oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool0H03oool200000980
oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool0HP3oool200000900oooo
00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool0I03oool2000008h0oooo00<0
00000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`1X0?ooo`80
0000RP3oool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`1Z0?ooo`800000
R03oool00`000000oooo0?ooo`050?ooo`008@3oool2000006d0oooo0P0000250?ooo`8000001`3o
ool00240oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`230?ooo`030000003oool0
oooo00D0oooo000Q0?ooo`030000003oool0oooo06l0oooo0P0000230?ooo`030000003oool0oooo
00D0oooo000Q0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0P03oool00`000000
oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo07l0oooo
00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool0L`3oool2000007l0oooo00<0
00000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool0M@3oool2000007d0oooo00<00000
0?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool0M`3oool2000007/0oooo00<000000?oo
o`3oool01@3oool00240oooo0P00001j0?ooo`030000003oool0oooo07L0oooo0P0000070?ooo`00
8@3oool00`000000oooo0?ooo`1j0?ooo`800000N03oool00`000000oooo0?ooo`050?ooo`008@3o
ool00`000000oooo0?ooo`1l0?ooo`800000MP3oool00`000000oooo0?ooo`050?ooo`008@3oool0
0`000000oooo0?ooo`1n0?ooo`800000M03oool00`000000oooo0?ooo`050?ooo`008@3oool00`00
0000oooo0?ooo`200?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool01@3oool00240
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00D0
oooo00060?ooo`D000000`3oool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000D0oooo
00<000000?ooo`3oool0PP3oool200000700oooo00<000000?ooo`3oool01@3oool000L0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003o
ool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08@0oooo00<000000?oo
o`3oool0K@3oool00`000000oooo0?ooo`050?ooo`001@0000030?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`250?ooo`800000K@3oool00`000000oooo0?ooo`050?oo
o`002@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo00000003000000D0oooo0P0000280?ooo`800000JP3oool2000000L0oooo00060?ooo`05
0000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
000000P0oooo00<000000?ooo`3oool0R@3oool2000006T0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`050?ooo`001`3oool300000080oooo1@0000030?ooo`800000
103oool2000000D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo08d0oooo0P00001U0?ooo`030000003o
ool0oooo00D0oooo000Q0?ooo`030000003oool0oooo08l0oooo0P00001S0?ooo`030000003oool0
oooo00D0oooo000Q0?ooo`030000003oool0oooo0940oooo0P00001Q0?ooo`030000003oool0oooo
00D0oooo000Q0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`050?ooo`008@3oool2000009D0oooo0P00001M0?ooo`8000001`3oool00240oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00D0oooo000Q
0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`05
0?ooo`008@3oool00`000000oooo0?ooo`2H0?ooo`800000FP3oool00`000000oooo0?ooo`050?oo
o`008@3oool00`000000oooo0?ooo`2J0?ooo`800000F03oool00`000000oooo0?ooo`050?ooo`00
8@3oool00`000000oooo0?ooo`2L0?ooo`800000EP3oool00`000000oooo0?ooo`050?ooo`008@3o
ool00`000000oooo0?ooo`2N0?ooo`800000E03oool00`000000oooo0?ooo`050?ooo`008@3oool0
0`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool01@3oool0
0240oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
00D0oooo000Q0?ooo`800000X`3oool00`000000oooo0?ooo`1>0?ooo`8000001`3oool00240oooo
00<000000?ooo`3oool0X`3oool2000004l0oooo00<000000?ooo`3oool01@3oool00240oooo00<0
00000?ooo`3oool0Y@3oool2000004d0oooo00<000000?ooo`3oool01@3oool00240oooo00<00000
0?ooo`3oool0Y`3oool2000004/0oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?oo
o`3oool0Z@3oool2000004T0oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3o
ool0Z`3oool2000004L0oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool0
[@3oool2000004D0oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool0[`3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo000Q0?ooo`800000/@3oool0
0`000000oooo0?ooo`100?ooo`8000001`3oool00240oooo00<000000?ooo`3oool0/@3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo0;80
oooo0P0000100?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo0;@0oooo
0P00000n0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo0;H0oooo0P00
000l0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo0;P0oooo0P00000j
0?ooo`030000003oool0oooo00D0oooo00060?ooo`D000000`3oool00`000000oooo0?ooo`030?oo
o`800000103oool3000000@0oooo00<000000?ooo`3oool0^P3oool2000003P0oooo00<000000?oo
o`3oool01@3oool000L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool000D000000`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo00000004
000000@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00D0oooo00090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool200000;l0oooo0P00000c
0?ooo`8000001`3oool000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0
oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003oool0oooo0<00
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`050?ooo`001P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo0?ooo`8000001@3oool00`000000oooo0?ooo`310?ooo`800000<@3oool00`000000oooo0?oo
o`050?ooo`001`3oool300000080oooo1@0000030?ooo`8000001@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0<<0oooo0P00000_0?ooo`030000003oool0oooo00D0oooo000Q0?oo
o`030000003oool0oooo0<D0oooo0P00000]0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`050?ooo`00
8@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
1@3oool00240oooo00<000000?ooo`3oool0b@3oool2000002T0oooo00<000000?ooo`3oool01@3o
ool00240oooo0P00003<0?ooo`8000009P3oool2000000L0oooo000Q0?ooo`030000003oool0oooo
0<d0oooo0P00000U0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo0<l0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo
0?ooo`3@0?ooo`8000008P3oool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?oo
o`3B0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool00240oooo00<00000
0?ooo`3oool0d`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00D0oooo000Q0?oo
o`030000003oool0oooo0=@0oooo0P00000N0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`03
0000003oool0oooo0=H0oooo0P00000L0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000
003oool0oooo0=P0oooo0P00000J0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`800000f`3o
ool2000001L0oooo0P0000070?ooo`008@3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool0g@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo0=h0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo
0?ooo`3O0?ooo`8000004`3oool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?oo
o`3Q0?ooo`8000004@3oool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`3S
0?ooo`8000003`3oool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`3U0?oo
o`8000003@3oool00`000000oooo0?ooo`050?ooo`008@3oool200000>P0oooo0P00000:0?ooo`80
00001`3oool00240oooo00<000000?ooo`3oool0j@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo0>X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`3[0?ooo`8000001`3oool0
0`000000oooo0?ooo`050?ooo`008@3oool00`000000oooo0?ooo`3]0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool0kP3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo000Q0?ooo`030000003oool0oooo0?@0oooo
00<000000?ooo`3oool01@3oool00240oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`008@3ooooh000000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
000c0?ooo`<00000RP3oool00`000000oooo0?ooo`0[0?ooo`<000005@3oool00`000000oooo0?oo
o`0G0?ooo`00=03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`00;P3oool3000000<0oooo0`0000040?oo
o`8000000P3oool500000080oooo0`0000030?ooo`@0000000<0oooo0000000000000`0000070?oo
o`<00000103oool4000000<0oooo0P0000020?ooo`H000001P3oool400000080oooo1@0000000`3o
ool0000000000003000000030?ooo`000000000000<000000P3oool300000080oooo0`0000040?oo
o`<000000P3oool3000000040?ooo`00000000000?ooo`<000000`3oool3000000T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000030?ooo`@000000`3oool00`000000oooo0?ooo`02
0?ooo`<000000P3oool500000080oooo0`0000020?ooo`<0000000@0oooo000000000000oooo1000
00030?ooo`8000000P3oool:000000D0oooo00<000000?ooo`3oool05@3oool002d0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0000
000<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool010000000oooo0?oo
o`0000040?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool00000
00H0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool05@3oool002d0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000000H0oooo0`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool3
000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`D000000P3oool01P000000
oooo0?ooo`000000oooo000000D0oooo1@0000080?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`000000oooo000000020?ooo`<000000`3oool00`000000oooo000000020?ooo`D000000`3o
ool010000000oooo0?ooo`3oool500000080oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000000P3oool3000000D0oooo00<0
00000?ooo`3oool05@3oool002d0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo0`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000
0`3oool010000000oooo0?ooo`0000050?ooo`060000003oool0oooo0000003oool00000203oool0
0`000000oooo0?ooo`0E0?ooo`00;@3oool01P000000oooo0?ooo`3oool000000?ooo`@000000P3o
ool400000080oooo0`0000040?ooo`<000000`3oool2000000D0oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`0000020?ooo`8000000`3oool4000000<0oooo0`0000090?ooo`050000
003oool0oooo0000003oool00`0000040?ooo`@000000P3oool400000080oooo0`0000020?ooo`80
000000<0oooo0000000000000P3oool300000080oooo100000030?ooo`<000000`3oool3000000T0
oooo00<000000?ooo`3oool00P3oool6000000030?ooo`000000000000<0oooo0P0000000`3oool0
0000000000020?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`<000000P3oool4000000<0
oooo2@0000030?ooo`<000000`3oool4000000@0oooo00<000000?ooo`3oool05@3oool002d0oooo
00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo000^0?oo
o`<000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo0`0000090?oo
o`@000002@3oool00`000000oooo0?ooo`020?ooo`8000002P3oool4000000@0oooo00<000000?oo
o`3oool0103oool2000000@0oooo0P00000^0?ooo`030000003oool0oooo01P0oooo0`00000F0?oo
o`030000003oool0oooo0080oooo0P00000;0?ooo`030000003oool0oooo01L0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00166904, -2711.7, \
4.24814*^-5, 0.058685}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 95.2381 -10.201 0.135877 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -15 -9 ]
[.21429 -0.0125 15 0 ]
[.40476 -0.0125 -15 -9 ]
[.40476 -0.0125 15 0 ]
[.59524 -0.0125 -15 -9 ]
[.59524 -0.0125 15 0 ]
[.78571 -0.0125 -15 -9 ]
[.78571 -0.0125 15 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12564 -12 -4.5 ]
[-0.0125 .12564 0 4.5 ]
[-0.0125 .26151 -12 -4.5 ]
[-0.0125 .26151 0 4.5 ]
[-0.0125 .39739 -12 -4.5 ]
[-0.0125 .39739 0 4.5 ]
[-0.0125 .53327 -12 -4.5 ]
[-0.0125 .53327 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.002)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.004)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.006)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.008)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.01)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12564 m
.00625 .12564 L
s
[(76)] -0.0125 .12564 1 0 Mshowa
0 .26151 m
.00625 .26151 L
s
[(77)] -0.0125 .26151 1 0 Mshowa
0 .39739 m
.00625 .39739 L
s
[(78)] -0.0125 .39739 1 0 Mshowa
0 .53327 m
.00625 .53327 L
s
[(79)] -0.0125 .53327 1 0 Mshowa
.125 Mabswid
0 .15281 m
.00375 .15281 L
s
0 .17999 m
.00375 .17999 L
s
0 .20716 m
.00375 .20716 L
s
0 .23434 m
.00375 .23434 L
s
0 .28869 m
.00375 .28869 L
s
0 .31586 m
.00375 .31586 L
s
0 .34304 m
.00375 .34304 L
s
0 .37021 m
.00375 .37021 L
s
0 .42456 m
.00375 .42456 L
s
0 .45174 m
.00375 .45174 L
s
0 .47892 m
.00375 .47892 L
s
0 .50609 m
.00375 .50609 L
s
0 .09846 m
.00375 .09846 L
s
0 .07129 m
.00375 .07129 L
s
0 .04411 m
.00375 .04411 L
s
0 .01693 m
.00375 .01693 L
s
0 .56044 m
.00375 .56044 L
s
0 .58762 m
.00375 .58762 L
s
0 .61479 m
.00375 .61479 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12564 m
1 .12564 L
s
.99375 .26151 m
1 .26151 L
s
.99375 .39739 m
1 .39739 L
s
.99375 .53327 m
1 .53327 L
s
.125 Mabswid
.99625 .15281 m
1 .15281 L
s
.99625 .17999 m
1 .17999 L
s
.99625 .20716 m
1 .20716 L
s
.99625 .23434 m
1 .23434 L
s
.99625 .28869 m
1 .28869 L
s
.99625 .31586 m
1 .31586 L
s
.99625 .34304 m
1 .34304 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .42456 m
1 .42456 L
s
.99625 .45174 m
1 .45174 L
s
.99625 .47892 m
1 .47892 L
s
.99625 .50609 m
1 .50609 L
s
.99625 .09846 m
1 .09846 L
s
.99625 .07129 m
1 .07129 L
s
.99625 .04411 m
1 .04411 L
s
.99625 .01693 m
1 .01693 L
s
.99625 .56044 m
1 .56044 L
s
.99625 .58762 m
1 .58762 L
s
.99625 .61479 m
1 .61479 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .12564 m
1 .12564 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .60332 m
.03853 .59422 L
.05458 .5843 L
.06965 .57499 L
.08415 .56603 L
.09958 .55649 L
.11444 .54731 L
.13023 .53755 L
.14544 .52815 L
.16007 .5191 L
.17564 .50948 L
.19063 .50022 L
.20504 .49131 L
.22039 .48182 L
.23516 .4727 L
.25087 .46299 L
.26599 .45364 L
.28054 .44465 L
.29603 .43508 L
.31093 .42587 L
.32678 .41608 L
.34204 .40664 L
.35672 .39757 L
.37234 .38791 L
.38739 .37862 L
.40185 .36968 L
.41725 .36016 L
.43208 .351 L
.44783 .34126 L
.46301 .33188 L
.47761 .32285 L
.49315 .31325 L
.50811 .30401 L
.52249 .29512 L
.5378 .28565 L
.55254 .27654 L
.56821 .26686 L
.58331 .25753 L
.59783 .24856 L
.61328 .23901 L
.62815 .22981 L
.64396 .22004 L
.65919 .21063 L
.67385 .20157 L
.68943 .19194 L
.70445 .18266 L
.71888 .17374 L
.73425 .16424 L
.74904 .1551 L
.76476 .14539 L
Mistroke
.77991 .13602 L
.79448 .12702 L
.80998 .11744 L
.82491 .10821 L
.84077 .09841 L
.85605 .08896 L
.87076 .07988 L
.8864 .07021 L
.90146 .0609 L
.91595 .05195 L
.93137 .04242 L
.94621 .03325 L
.96198 .0235 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`007@3oool200000240oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000P3oool5000001@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`800000103oool3000001@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000`3oool3000001D0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000`3oool3000001P0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?oo
o`<000003@3oool001`0oooo00@000000?ooo`3oool000007`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00000C0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0503oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0303o
ool001`0oooo00@000000?ooo`3oool000007`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0C0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?oo
o`000000oooo00D000004`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0140oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0<0?ooo`00703oool010000000oooo0?oo
o`00000O0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000P3oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool01@000000oooo0?ooo`000000oooo00@00000503oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool3000001L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00`0oooo
000L0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`0A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0000001@0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000005`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00`0oooo000L0?ooo`040000003oool0oooo0000
01l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000503o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool0503oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo0P00000>
0?ooo`007@3oool200000240oooo0P00000:0?ooo`800000103oool2000000<0oooo0`00000E0?oo
o`8000002P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo01<0oooo0P00000:0?oo
o`800000103oool2000000@0oooo0P00000E0?ooo`8000002P3oool2000000@0oooo0P0000030?oo
o`<00000603oool2000000X0oooo0P0000040?ooo`030000003oool0oooo00`0oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000H0?ooooP00000403oool001P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo
0?ooo`3d0?ooo`030000003oool0oooo00h0oooo000H0?ooo`030000003oool0oooo0>d0oooo0P00
00050?ooo`030000003oool0oooo00h0oooo000H0?ooo`800000k@3oool00`000000oooo0?ooo`04
0?ooo`800000403oool001P0oooo00<000000?ooo`3oool0jP3oool2000000P0oooo00<000000?oo
o`3oool03P3oool001P0oooo00<000000?ooo`3oool0j@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00h0oooo000H0?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`3V0?ooo`800000303o
ool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`3T0?ooo`8000003P3oool0
0`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`3R0?ooo`800000403oool00`00
0000oooo0?ooo`0>0?ooo`00603oool200000>40oooo0P00000A0?ooo`800000403oool001P0oooo
00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo
000H0?ooo`030000003oool0oooo0=h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0>0?ooo`00603oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0f`3oool2000001L0oooo00<000000?oo
o`3oool03P3oool001P0oooo00<000000?ooo`3oool0f@3oool2000001T0oooo00<000000?ooo`3o
ool03P3oool001P0oooo0P00003H0?ooo`8000006P3oool200000100oooo000H0?ooo`030000003o
ool0oooo0=D0oooo0P00000M0?ooo`030000003oool0oooo00h0oooo000H0?ooo`030000003oool0
oooo0=<0oooo0P00000O0?ooo`030000003oool0oooo00h0oooo000H0?ooo`030000003oool0oooo
0=80oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000
oooo0?ooo`3A0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03P3oool001P0oooo
00<000000?ooo`3oool0c`3oool2000002<0oooo00<000000?ooo`3oool03P3oool001P0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00h0oooo000H
0?ooo`800000c@3oool2000002D0oooo0P00000@0?ooo`00603oool00`000000oooo0?ooo`3:0?oo
o`800000:03oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`380?ooo`80
0000:P3oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`370?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool03P3oool000/0oooo00<000000?ooo`3oool00P3o
ool3000000D0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00h0oooo000;0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0<@0oooo0P00000^0?ooo`030000003oool0oooo00h0oooo000<
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`320?ooo`800000<03oool00`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo0?ooo`04
000000D0oooon000000@0?ooo`003@3oool00`000000oooo000000080?ooo`030000003oool0oooo
0;l0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0>0?ooo`002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2m0?oo
o`800000=@3oool00`000000oooo0?ooo`0>0?ooo`002@3oool5000000<0oooo0P0000050?ooo`03
0000003oool0oooo0;`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0>0?ooo`00
603oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
3P3oool001P0oooo00<000000?ooo`3oool0^@3oool2000003T0oooo00<000000?ooo`3oool03P3o
ool001P0oooo0P00002h0?ooo`800000>P3oool200000100oooo000H0?ooo`030000003oool0oooo
0;D0oooo0P00000m0?ooo`030000003oool0oooo00h0oooo000H0?ooo`030000003oool0oooo0;<0
oooo0P00000o0?ooo`030000003oool0oooo00h0oooo000H0?ooo`030000003oool0oooo0;80oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?oo
o`2a0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001P0oooo00<00000
0?ooo`3oool0/03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000H0?oo
o`030000003oool0oooo0:h0oooo0P0000140?ooo`030000003oool0oooo00h0oooo000H0?ooo`80
0000[@3oool2000004D0oooo0P00000@0?ooo`00603oool00`000000oooo0?ooo`2Z0?ooo`800000
B03oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`2X0?ooo`800000BP3o
ool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`2V0?ooo`800000C03oool0
0`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`2T0?ooo`800000CP3oool00`00
0000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0XP3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00h0oooo000H0?ooo`800000XP3oool00`000000oooo0?oo
o`1?0?ooo`800000403oool001P0oooo00<000000?ooo`3oool0W`3oool2000005<0oooo00<00000
0?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0W@3oool2000005D0oooo00<000000?oo
o`3oool03P3oool001P0oooo00<000000?ooo`3oool0V`3oool2000005L0oooo00<000000?ooo`3o
ool03P3oool001P0oooo00<000000?ooo`3oool0V@3oool2000005T0oooo00<000000?ooo`3oool0
3P3oool001P0oooo00<000000?ooo`3oool0U`3oool2000005/0oooo00<000000?ooo`3oool03P3o
ool001P0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo00h0oooo000H0?ooo`800000UP3oool00`000000oooo0?ooo`1K0?ooo`800000403oool001P0
oooo00<000000?ooo`3oool0T`3oool2000005l0oooo00<000000?ooo`3oool03P3oool001P0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00h0oooo
000H0?ooo`030000003oool0oooo0900oooo0P00001R0?ooo`030000003oool0oooo00h0oooo000;
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`800000I03oool00`000000oooo0?ooo`0>0?ooo`002`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S03oool2000006H0oooo00<000000?oo
o`3oool03P3oool000`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`80
0000S03oool00`000000oooo0?ooo`1U0?ooo`800000403oool000`0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`0>0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0R03oool2000006X0oooo00<000000?ooo`3oool03P3o
ool000T0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`260?ooo`800000K03oool00`000000oooo0?ooo`0>0?ooo`002@3o
ool5000000030?ooo`000000000000<00000103oool00`000000oooo0?ooo`240?ooo`800000KP3o
ool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`230?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0P@3oool20000
0740oooo00<000000?ooo`3oool03P3oool001P0oooo0P0000210?ooo`030000003oool0oooo0700
oooo0P00000@0?ooo`00603oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0O@3oool2000007D0oooo00<0
00000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0N`3oool2000007L0oooo00<00000
0?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0N@3oool2000007T0oooo00<000000?oo
o`3oool03P3oool001P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo00h0oooo000H0?ooo`030000003oool0oooo07H0oooo0P00001l0?ooo`030000
003oool0oooo00h0oooo000H0?ooo`800000M@3oool2000007d0oooo0P00000@0?ooo`00603oool0
0`000000oooo0?ooo`1b0?ooo`800000P03oool00`000000oooo0?ooo`0>0?ooo`00603oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool03P3oool001P0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00h0
oooo000H0?ooo`030000003oool0oooo06h0oooo0P0000240?ooo`030000003oool0oooo00h0oooo
000H0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0>0?ooo`00603oool2000006`0oooo0P0000260?ooo`800000403oool001P0oooo00<000000?oo
o`3oool0J@3oool2000008T0oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3o
ool0I`3oool2000008/0oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00h0oooo000H0?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0>0?ooo`00603oool0
0`000000oooo0?ooo`1S0?ooo`800000S`3oool00`000000oooo0?ooo`0>0?ooo`00603oool00`00
0000oooo0?ooo`1Q0?ooo`800000T@3oool00`000000oooo0?ooo`0>0?ooo`00603oool200000600
oooo0P00002B0?ooo`800000403oool001P0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`2C0?ooo`030000003oool0oooo00h0oooo000H0?ooo`030000003oool0oooo05`0oooo0P00
002F0?ooo`030000003oool0oooo00h0oooo000H0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool0UP3oool00`000000oooo0?ooo`0>0?ooo`002`3oool00`000000oooo0?ooo`020?oo
o`<000001@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo09L0oooo00<000000?oo
o`3oool03P3oool000/0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0F03oool2000009X0oooo00<000000?ooo`3oool03P3oool000`0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
05H0oooo0P00002L0?ooo`030000003oool0oooo00h0oooo000<0?ooo`040000003oool0oooo0?oo
o`<000001@3oool2000005D0oooo0P00002M0?ooo`800000403oool000d0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0580oooo0P00002P0?ooo`03
0000003oool0oooo00h0oooo00090?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0D03oool200000:80oooo00<000000?oo
o`3oool03P3oool000T0oooo1@0000020?ooo`<000001@3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0:80oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0
C@3oool200000:D0oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00h0oooo000H0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0>0?ooo`00603oool20000
04X0oooo0P00002X0?ooo`800000403oool001P0oooo00<000000?ooo`3oool0A`3oool200000:/0
oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0A@3oool200000:d0oooo
00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`2]0?ooo`030000003oool0oooo00h0oooo000H0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool0[P3oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`110?oo
o`800000/@3oool00`000000oooo0?ooo`0>0?ooo`00603oool200000440oooo00<000000?ooo`3o
ool0/03oool200000100oooo000H0?ooo`030000003oool0oooo03h0oooo0P00002d0?ooo`030000
003oool0oooo00h0oooo000H0?ooo`030000003oool0oooo03`0oooo0P00002f0?ooo`030000003o
ool0oooo00h0oooo000H0?ooo`030000003oool0oooo03X0oooo0P00002h0?ooo`030000003oool0
oooo00h0oooo000H0?ooo`030000003oool0oooo03P0oooo0P00002j0?ooo`030000003oool0oooo
00h0oooo000H0?ooo`030000003oool0oooo03H0oooo0P00002l0?ooo`030000003oool0oooo00h0
oooo000H0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0_03oool00`000000oooo
0?ooo`0>0?ooo`00603oool2000003D0oooo00<000000?ooo`3oool0_03oool200000100oooo000H
0?ooo`030000003oool0oooo0380oooo0P0000300?ooo`030000003oool0oooo00h0oooo000H0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0>0?oo
o`00603oool00`000000oooo0?ooo`0_0?ooo`800000``3oool00`000000oooo0?ooo`0>0?ooo`00
603oool00`000000oooo0?ooo`0]0?ooo`800000a@3oool00`000000oooo0?ooo`0>0?ooo`00603o
ool00`000000oooo0?ooo`0[0?ooo`800000a`3oool00`000000oooo0?ooo`0>0?ooo`00603oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03P3oool0
01P0oooo0P00000Z0?ooo`030000003oool0oooo0<L0oooo0P00000@0?ooo`00603oool00`000000
oooo0?ooo`0W0?ooo`800000b`3oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo
0?ooo`0U0?ooo`800000c@3oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?oo
o`0S0?ooo`800000c`3oool00`000000oooo0?ooo`0>0?ooo`002`3oool00`000000oooo0?ooo`02
0?ooo`8000001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0<l0oooo00<00000
0?ooo`3oool03P3oool000/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0200oooo0P00003B0?ooo`030000003oool0oooo00h0oooo000<0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool200000200oooo00<000000?ooo`3o
ool0d@3oool200000100oooo000<0?ooo`040000003oool0oooo0?ooo`@00000103oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool03P3oool000d0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo
0P00003F0?ooo`030000003oool0oooo00h0oooo00090?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool200000=P0
oooo00<000000?ooo`3oool03P3oool000T0oooo1@0000020?ooo`<000001@3oool00`000000oooo
0?ooo`0H0?ooo`800000fP3oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool03P3oool001P0oooo00<00000
0?ooo`3oool05@3oool200000=d0oooo00<000000?ooo`3oool03P3oool001P0oooo0P00000E0?oo
o`030000003oool0oooo0=`0oooo0P00000@0?ooo`00603oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0=h0oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0
4@3oool200000>40oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool03`3o
ool200000><0oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool03@3oool2
00000>D0oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool02`3oool20000
0>L0oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool02@3oool200000>T0
oooo00<000000?ooo`3oool03P3oool001P0oooo0P0000090?ooo`030000003oool0oooo0>P0oooo
0P00000@0?ooo`00603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0>X0oooo00<0
00000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool01@3oool200000>d0oooo00<00000
0?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3]0?oo
o`030000003oool0oooo00h0oooo000H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0kP3oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`3d0?ooo`030000
003oool0oooo00h0oooo000H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3o
ool001P0oooon000000@0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00:P3o
ool3000008X0oooo00<000000?ooo`3oool0:`3oool3000001D0oooo00<000000?ooo`3oool0803o
ool002/0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool07`3oool002D0oooo0`0000030?ooo`<00000103oool20000
0080oooo1@0000020?ooo`<000000`3oool4000000030?ooo`000000000000<000001`3oool30000
00@0oooo100000030?ooo`8000000P3oool6000000H0oooo100000020?ooo`D0000000<0oooo0000
000000000`0000000`3oool000000000000300000080oooo0`0000020?ooo`<00000103oool30000
0080oooo0`000000103oool000000000003oool3000000<0oooo0`0000090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000000`3oool4000000<0oooo00<000000?ooo`3oool00P3oool3
00000080oooo1@0000020?ooo`<000000P3oool3000000040?ooo`00000000000?ooo`@000000`3o
ool200000080oooo2P0000050?ooo`030000003oool0oooo01h0oooo000T0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`000000303o
ool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000
103oool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000060?oo
o`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01h0oooo000T0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`<00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0`000003
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`3oool500000080oooo00<000000?ooo`3oool00P3oool500000080oooo00H000000?ooo`3o
ool000000?ooo`0000050?ooo`D00000203oool00`000000oooo0?ooo`020?ooo`050000003oool0
00000?ooo`0000000P3oool3000000<0oooo00<000000?ooo`0000000P3oool5000000<0oooo00@0
00000?ooo`3oool0oooo1@0000020?ooo`060000003oool0oooo0000003oool000000`3oool01000
0000oooo0?ooo`0000050?ooo`040000003oool0oooo00000080oooo0`0000050?ooo`030000003o
ool0oooo01h0oooo000T0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`<0
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo
00@000000?ooo`3oool000001@3oool01P000000oooo0?ooo`000000oooo000000P0oooo00<00000
0?ooo`3oool07P3oool002@0oooo00H000000?ooo`3oool0oooo0000003oool400000080oooo1000
00020?ooo`<00000103oool3000000<0oooo0P0000050?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool000000P3oool2000000<0oooo100000030?ooo`<000002@3oool01@000000oooo
0?ooo`000000oooo00<00000103oool400000080oooo100000020?ooo`<000000P3oool200000003
0?ooo`00000000000080oooo0`0000020?ooo`@000000`3oool3000000<0oooo0`0000090?ooo`03
0000003oool0oooo0080oooo1P0000000`3oool00000000000030?ooo`80000000<0oooo00000000
00000P3oool3000000@0oooo00<000000?ooo`3oool00P3oool300000080oooo100000030?ooo`T0
00000`3oool3000000<0oooo100000040?ooo`030000003oool0oooo01h0oooo000T0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`009@3oool30000
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`<000002@3oool40000
00T0oooo00<000000?ooo`3oool00P3oool2000000X0oooo100000040?ooo`030000003oool0oooo
00@0oooo0P0000040?ooo`800000;P3oool00`000000oooo0?ooo`0H0?ooo`<000005P3oool00`00
0000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`0P0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0012867, 74.7152, \
4.24814*^-5, 0.0297758}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 95.2381 -0.0175093 0.00186758 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -15 -9 ]
[.21429 -0.0125 15 0 ]
[.40476 -0.0125 -15 -9 ]
[.40476 -0.0125 15 0 ]
[.59524 -0.0125 -15 -9 ]
[.59524 -0.0125 15 0 ]
[.78571 -0.0125 -15 -9 ]
[.78571 -0.0125 15 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07587 -12 -4.5 ]
[-0.0125 .07587 0 4.5 ]
[-0.0125 .16925 -18 -4.5 ]
[-0.0125 .16925 0 4.5 ]
[-0.0125 .26263 -18 -4.5 ]
[-0.0125 .26263 0 4.5 ]
[-0.0125 .35601 -18 -4.5 ]
[-0.0125 .35601 0 4.5 ]
[-0.0125 .44939 -18 -4.5 ]
[-0.0125 .44939 0 4.5 ]
[-0.0125 .54276 -18 -4.5 ]
[-0.0125 .54276 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -66 0 ]
[.5 .63053 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.002)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.004)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.006)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.008)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.01)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07587 m
.00625 .07587 L
s
[(50)] -0.0125 .07587 1 0 Mshowa
0 .16925 m
.00625 .16925 L
s
[(100)] -0.0125 .16925 1 0 Mshowa
0 .26263 m
.00625 .26263 L
s
[(150)] -0.0125 .26263 1 0 Mshowa
0 .35601 m
.00625 .35601 L
s
[(200)] -0.0125 .35601 1 0 Mshowa
0 .44939 m
.00625 .44939 L
s
[(250)] -0.0125 .44939 1 0 Mshowa
0 .54276 m
.00625 .54276 L
s
[(300)] -0.0125 .54276 1 0 Mshowa
.125 Mabswid
0 .09455 m
.00375 .09455 L
s
0 .11322 m
.00375 .11322 L
s
0 .1319 m
.00375 .1319 L
s
0 .15057 m
.00375 .15057 L
s
0 .18792 m
.00375 .18792 L
s
0 .2066 m
.00375 .2066 L
s
0 .22528 m
.00375 .22528 L
s
0 .24395 m
.00375 .24395 L
s
0 .2813 m
.00375 .2813 L
s
0 .29998 m
.00375 .29998 L
s
0 .31866 m
.00375 .31866 L
s
0 .33733 m
.00375 .33733 L
s
0 .37468 m
.00375 .37468 L
s
0 .39336 m
.00375 .39336 L
s
0 .41203 m
.00375 .41203 L
s
0 .43071 m
.00375 .43071 L
s
0 .46806 m
.00375 .46806 L
s
0 .48674 m
.00375 .48674 L
s
0 .50541 m
.00375 .50541 L
s
0 .52409 m
.00375 .52409 L
s
0 .05719 m
.00375 .05719 L
s
0 .03852 m
.00375 .03852 L
s
0 .01984 m
.00375 .01984 L
s
0 .00117 m
.00375 .00117 L
s
0 .56144 m
.00375 .56144 L
s
0 .58012 m
.00375 .58012 L
s
0 .59879 m
.00375 .59879 L
s
0 .61747 m
.00375 .61747 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07587 m
1 .07587 L
s
.99375 .16925 m
1 .16925 L
s
.99375 .26263 m
1 .26263 L
s
.99375 .35601 m
1 .35601 L
s
.99375 .44939 m
1 .44939 L
s
.99375 .54276 m
1 .54276 L
s
.125 Mabswid
.99625 .09455 m
1 .09455 L
s
.99625 .11322 m
1 .11322 L
s
.99625 .1319 m
1 .1319 L
s
.99625 .15057 m
1 .15057 L
s
.99625 .18792 m
1 .18792 L
s
.99625 .2066 m
1 .2066 L
s
.99625 .22528 m
1 .22528 L
s
.99625 .24395 m
1 .24395 L
s
.99625 .2813 m
1 .2813 L
s
.99625 .29998 m
1 .29998 L
s
.99625 .31866 m
1 .31866 L
s
.99625 .33733 m
1 .33733 L
s
.99625 .37468 m
1 .37468 L
s
.99625 .39336 m
1 .39336 L
s
.99625 .41203 m
1 .41203 L
s
.99625 .43071 m
1 .43071 L
s
.99625 .46806 m
1 .46806 L
s
.99625 .48674 m
1 .48674 L
s
.99625 .50541 m
1 .50541 L
s
.99625 .52409 m
1 .52409 L
s
.99625 .05719 m
1 .05719 L
s
.99625 .03852 m
1 .03852 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .00117 m
1 .00117 L
s
.99625 .56144 m
1 .56144 L
s
.99625 .58012 m
1 .58012 L
s
.99625 .59879 m
1 .59879 L
s
.99625 .61747 m
1 .61747 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .07587 m
1 .07587 L
s
[(Interference Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .54593 m
.02551 .56853 L
.02736 .58712 L
.0283 .59389 L
.02882 .59685 L
.0293 .59914 L
.02976 .60083 L
.03 .60155 L
.03025 .60217 L
.03046 .6026 L
.0307 .60295 L
.03091 .60317 L
.03111 .60329 L
.03123 .60332 L
.03137 .60332 L
.0316 .60322 L
.03175 .6031 L
.03188 .60295 L
.03214 .60256 L
.03238 .60206 L
.03261 .60149 L
.03311 .5998 L
.03354 .59798 L
.03401 .59554 L
.03495 .58926 L
.03598 .58033 L
.03708 .56847 L
.03907 .54138 L
.04309 .46764 L
.04689 .3808 L
.05413 .20299 L
.0578 .12406 L
.05974 .08893 L
.06184 .05781 L
.06281 .04602 L
.06384 .03555 L
.06478 .02769 L
.06567 .02202 L
.0665 .01815 L
.06696 .01662 L
.06738 .01562 L
.06762 .01522 L
.06785 .01495 L
.06809 .01479 L
.06821 .01475 L
.06835 .01475 L
.06858 .01483 L
.06882 .01504 L
.06905 .01535 L
.06926 .01574 L
Mistroke
.06973 .01695 L
.07016 .01845 L
.07113 .02322 L
.07202 .02934 L
.07286 .03656 L
.07474 .05774 L
.07677 .08782 L
.08055 .16024 L
.08453 .25291 L
.09172 .42855 L
.09572 .51137 L
.09762 .54299 L
.09937 .56684 L
.10118 .58555 L
.10214 .59281 L
.10262 .59579 L
.10315 .59846 L
.10361 .60031 L
.10403 .60162 L
.10443 .60252 L
.10463 .60285 L
.10485 .60311 L
.1051 .60327 L
.10532 .60331 L
.10545 .60328 L
.10558 .60322 L
.10583 .60301 L
.10605 .60269 L
.1063 .60224 L
.10673 .60112 L
.10721 .59942 L
.10766 .59736 L
.10852 .59235 L
.10944 .58528 L
.11044 .57569 L
.11223 .55366 L
.1139 .52817 L
.12131 .37052 L
.12844 .19587 L
.1324 .1126 L
.13413 .08258 L
.13603 .05535 L
.13692 .04481 L
.13787 .03521 L
.1387 .02835 L
.13959 .02246 L
.14011 .01976 L
.1406 .01778 L
.14106 .01635 L
.1413 .0158 L
Mistroke
.14155 .01532 L
.14179 .01502 L
.142 .01483 L
.14224 .01474 L
.14247 .01478 L
.14269 .01491 L
.14289 .01511 L
.14311 .01544 L
.14334 .0159 L
.14383 .01724 L
.14435 .01922 L
.14528 .02417 L
.14629 .03149 L
.14739 .04183 L
.14936 .06612 L
.1512 .09494 L
.15856 .25343 L
.16638 .44332 L
.17029 .5214 L
.17201 .5488 L
.17391 .57307 L
.17478 .58196 L
.17572 .58987 L
.17661 .59569 L
.17742 .5996 L
.17788 .60116 L
.17829 .60224 L
.17853 .60268 L
.17875 .60299 L
.17887 .60311 L
.17901 .60321 L
.17924 .6033 L
.17947 .60326 L
.1796 .6032 L
.17973 .6031 L
.17997 .60281 L
.18011 .60259 L
.18024 .60235 L
.18071 .60118 L
.18116 .59963 L
.18165 .59744 L
.18211 .59492 L
.18298 .58905 L
.18491 .57048 L
.18658 .54874 L
.18839 .51986 L
.19615 .34999 L
.20363 .16921 L
.20739 .09494 L
.20903 .06895 L
Mistroke
.21082 .04603 L
.2118 .03589 L
.21272 .02823 L
.21359 .02248 L
.21407 .01998 L
.21451 .01811 L
.21498 .01657 L
.21524 .01592 L
.21548 .01544 L
.21571 .0151 L
.21592 .01489 L
.21615 .01476 L
.21639 .01475 L
.21653 .0148 L
.21666 .01488 L
.21681 .01501 L
.21695 .0152 L
.21721 .01562 L
.21748 .01623 L
.21799 .01778 L
.21847 .01973 L
.21941 .02499 L
.22044 .03278 L
.22231 .05231 L
.22413 .07752 L
.22582 .1058 L
.23324 .27016 L
.24037 .4431 L
.24433 .52204 L
.24607 .54953 L
.24796 .57363 L
.24886 .5826 L
.24981 .59046 L
.25071 .5962 L
.25152 .59996 L
.25176 .60077 L
.252 .60152 L
.25222 .60205 L
.25245 .60252 L
.2527 .6029 L
.25293 .60314 L
.25307 .60323 L
.2532 .60328 L
.25332 .60329 L
.25345 .60326 L
.25369 .60312 L
.25391 .60289 L
.25403 .60272 L
.25416 .6025 L
.2544 .60201 L
Mistroke
.25485 .60072 L
.25527 .59916 L
.25616 .59462 L
.25712 .58795 L
.25884 .57135 L
.26088 .54438 L
.26274 .51363 L
.27028 .34684 L
.27753 .17137 L
.28127 .09699 L
.28319 .06679 L
.28419 .05344 L
.28525 .04141 L
.28616 .03268 L
.28717 .02507 L
.28761 .02237 L
.28808 .01993 L
.28852 .01807 L
.28893 .01672 L
.28914 .01615 L
.28938 .01563 L
.28961 .01523 L
.28986 .01494 L
.29008 .01479 L
.29032 .01474 L
.29054 .0148 L
.29074 .01494 L
.29095 .01519 L
.29115 .0155 L
.29159 .01649 L
.29197 .01771 L
.29239 .01935 L
.29331 .02429 L
.29415 .03035 L
.29606 .04924 L
.29774 .07155 L
.29951 .10028 L
.30671 .25696 L
.31436 .44288 L
.3179 .51436 L
.31976 .54499 L
.32173 .571 L
.32273 .58139 L
.32383 .59057 L
.32431 .59383 L
.32482 .5968 L
.32531 .59908 L
.32576 .60076 L
.32625 .6021 L
.3265 .6026 L
Mistroke
.32664 .60281 L
.32678 .60299 L
.32692 .60312 L
.32704 .6032 L
.32729 .60327 L
.32751 .60323 L
.32775 .60306 L
.32796 .60281 L
.3282 .60242 L
.32861 .60144 L
.32911 .5998 L
.32957 .59785 L
.33047 .59265 L
.33144 .58528 L
.33317 .56743 L
.33504 .542 L
.3371 .5072 L
.3447 .33656 L
.35201 .16098 L
.3558 .08817 L
.3577 .05974 L
.35877 .04656 L
.35978 .03611 L
.36072 .02826 L
.36121 .02483 L
.36173 .02173 L
.36216 .01956 L
.36264 .01764 L
.36308 .01631 L
.36329 .01581 L
.36349 .01543 L
.36374 .01507 L
.36387 .01493 L
.364 .01483 L
.36413 .01476 L
.36426 .01473 L
.36449 .01477 L
.36472 .01492 L
.36493 .01515 L
.36516 .01551 L
.3654 .01601 L
.36591 .01746 L
.36638 .0193 L
.36745 .02519 L
.3684 .03238 L
.36943 .04222 L
.37131 .06526 L
.37481 .1244 L
.38253 .30229 L
.38637 .39677 L
Mistroke
.38996 .47714 L
.39341 .53957 L
.39534 .56636 L
.39711 .58482 L
.39801 .59184 L
.3985 .59499 L
.39897 .5975 L
.3994 .59945 L
.39987 .6011 L
.40008 .60168 L
.4003 .6022 L
.4005 .60259 L
.40069 .60287 L
.40094 .60312 L
.40116 .60324 L
.4014 .60325 L
.40153 .60321 L
.40166 .60313 L
.40187 .60293 L
.4021 .6026 L
.40234 .60213 L
.40256 .60159 L
.40307 .59994 L
.40355 .59794 L
.40461 .59174 L
.4055 .58474 L
.40646 .5755 L
.40818 .55447 L
.41209 .48816 L
.41993 .30581 L
.42386 .20967 L
.42748 .13046 L
.43101 .06939 L
.43279 .04641 L
.43379 .03606 L
.43475 .02805 L
.43566 .02209 L
.43618 .01949 L
.43666 .01758 L
.43689 .01684 L
.43711 .01624 L
.43731 .01579 L
.43751 .01539 L
.43774 .01507 L
.43795 .01486 L
.43817 .01475 L
.43842 .01474 L
.43854 .01479 L
.43868 .01488 L
.43881 .01501 L
Mistroke
.43893 .01515 L
.43916 .01551 L
.4394 .01601 L
.43991 .01745 L
.44046 .01965 L
.44144 .02512 L
.44236 .03205 L
.44422 .05114 L
.44618 .07816 L
.44968 .14167 L
.45689 .31108 L
.46091 .40945 L
.46456 .48902 L
.46638 .52276 L
.46836 .55353 L
.47022 .57628 L
.47112 .58488 L
.47194 .59134 L
.47283 .59676 L
.47331 .59906 L
.47378 .60078 L
.47398 .6014 L
.4742 .60196 L
.47439 .60237 L
.4746 .60272 L
.47484 .60302 L
.47507 .60319 L
.47529 .60325 L
.47549 .60321 L
.47572 .60307 L
.47596 .6028 L
.47619 .60242 L
.4764 .60198 L
.47691 .60053 L
.47739 .59865 L
.47835 .59346 L
.47939 .5857 L
.48118 .56743 L
.48314 .54048 L
.48711 .46729 L
.49473 .28597 L
.50205 .11935 L
.50396 .08552 L
.50605 .05531 L
.507 .04409 L
.50802 .03404 L
.5089 .02692 L
.50984 .02114 L
.51033 .01888 L
.51086 .01696 L
Mistroke
.51109 .0163 L
.51134 .01572 L
.51157 .0153 L
.51179 .01501 L
.51192 .01489 L
.51205 .01479 L
.5123 .01473 L
.51244 .01475 L
.51257 .0148 L
.51271 .0149 L
.51287 .01506 L
.51299 .01522 L
.51313 .01544 L
.5134 .016 L
.51389 .01738 L
.51439 .01932 L
.51484 .02153 L
.51586 .02805 L
.51681 .03597 L
.5177 .04506 L
.52148 .0996 L
.52497 .16903 L
.53241 .34902 L
.53615 .43806 L
.53957 .50833 L
.54133 .5383 L
.54325 .56515 L
.5443 .57703 L
.54527 .58614 L
.5462 .59308 L
.5472 .59852 L
.54769 .60047 L
.54796 .60131 L
.54821 .60197 L
.54844 .60245 L
.54866 .60279 L
.54889 .60306 L
.54902 .60315 L
.54914 .60321 L
.54926 .60324 L
.5494 .60323 L
.54954 .60318 L
.54967 .6031 L
.5499 .60286 L
.55003 .60268 L
.55015 .60248 L
.55069 .60122 L
.55096 .60036 L
.55125 .59925 L
.5522 .59438 L
Mistroke
.55323 .5871 L
.55506 .5688 L
.557 .54263 L
.5591 .50719 L
.56291 .42777 L
.57065 .23853 L
.57451 .15044 L
.57639 .113 L
.57811 .08317 L
.57977 .05897 L
.58157 .03823 L
.58256 .02952 L
.58347 .02321 L
.58435 .01879 L
.58479 .01716 L
.58504 .01642 L
.58528 .01585 L
.58551 .0154 L
.58572 .01509 L
.58596 .01486 L
.58608 .01478 L
.58621 .01474 L
.58645 .01475 L
.58667 .01487 L
.58692 .01512 L
.58705 .0153 L
.58718 .01554 L
.58762 .01654 L
.58808 .01807 L
.58893 .02199 L
.58943 .02503 L
.58998 .02895 L
.59099 .03765 L
.59287 .05922 L
.59482 .08829 L
.59659 .11989 L
.60055 .20496 L
.60813 .39081 L
.6116 .46946 L
.61358 .50833 L
.61542 .53958 L
.61739 .56682 L
.61919 .58538 L
.62017 .59286 L
.62111 .5981 L
.62162 .60021 L
.62209 .60166 L
.62234 .60224 L
.62261 .60272 L
.62275 .6029 L
Mistroke
.6229 .60305 L
.62304 .60315 L
.62317 .60321 L
.62341 .60322 L
.62364 .60311 L
.62384 .60293 L
.62406 .60262 L
.62431 .60217 L
.62456 .60156 L
.62502 .60012 L
.62545 .5984 L
.62584 .59645 L
.62675 .59079 L
.62773 .58273 L
.62863 .57368 L
.63066 .54778 L
.63426 .48503 L
.63817 .39835 L
.64587 .20956 L
.64943 .1316 L
.65328 .06566 L
.65431 .05215 L
.65539 .04003 L
.6564 .03083 L
.65733 .02408 L
.65821 .01938 L
.6587 .01745 L
.65915 .01614 L
.65941 .01559 L
.65964 .01519 L
.65977 .01504 L
.6599 .0149 L
.66004 .0148 L
.66018 .01474 L
.66042 .01474 L
.66064 .01484 L
.66077 .01494 L
.6609 .01509 L
.66115 .01546 L
.6614 .01598 L
.66163 .01656 L
.66215 .0183 L
.66261 .02031 L
.6631 .02291 L
.66394 .02856 L
.66486 .03643 L
.66691 .05974 L
.66882 .08832 L
.67617 .24365 L
.68399 .43417 L
Mistroke
.6879 .51409 L
.68962 .5426 L
.69151 .56828 L
.69238 .57785 L
.69332 .58651 L
.69414 .59258 L
.69502 .59768 L
.69551 .5998 L
.69597 .60131 L
.69622 .60196 L
.69645 .60244 L
.69658 .60265 L
.69672 .60284 L
.69685 .60299 L
.69697 .60309 L
.69718 .6032 L
.69742 .6032 L
.69765 .60309 L
.6979 .60285 L
.69813 .60251 L
.69835 .60208 L
.69875 .60101 L
.69924 .59926 L
.69971 .59715 L
.70057 .59203 L
.7015 .58482 L
.7025 .5751 L
.70431 .55273 L
.70598 .52708 L
.71345 .36766 L
.72063 .19194 L
.72463 .10867 L
.72652 .07674 L
.72828 .05254 L
.73009 .03345 L
.73104 .02599 L
.73153 .02289 L
.73206 .0201 L
.73251 .01814 L
.73293 .01673 L
.73334 .01573 L
.73354 .01536 L
.73376 .01505 L
.734 .01482 L
.73423 .01473 L
.73435 .01472 L
.73449 .01475 L
.73473 .01491 L
.73496 .01516 L
.7352 .01556 L
Mistroke
.73541 .01599 L
.73563 .01657 L
.73611 .01813 L
.73662 .02036 L
.73756 .02582 L
.73847 .03286 L
.73931 .04086 L
.74123 .06401 L
.74326 .0957 L
.75039 .24884 L
.75798 .43389 L
.76146 .50614 L
.76344 .53984 L
.76528 .56542 L
.76711 .58462 L
.76813 .59251 L
.76906 .59783 L
.76957 .59999 L
.77004 .60149 L
.77029 .60209 L
.77056 .6026 L
.7707 .6028 L
.77084 .60297 L
.77098 .60309 L
.77111 .60316 L
.77135 .6032 L
.77158 .60313 L
.77171 .60303 L
.77183 .60292 L
.7721 .60255 L
.77233 .6021 L
.77259 .60149 L
.77304 .60003 L
.77349 .59818 L
.77397 .59573 L
.77484 .59011 L
.77587 .58144 L
.77681 .57171 L
.77886 .54489 L
.78079 .51293 L
.78804 .35318 L
.7917 .26202 L
.79574 .16698 L
.79962 .09138 L
.80131 .06522 L
.80317 .04239 L
.80403 .034 L
.80495 .02667 L
.80546 .02334 L
.80592 .02079 L
Mistroke
.80636 .01877 L
.80682 .01708 L
.80706 .01638 L
.80733 .01575 L
.80757 .01531 L
.8078 .015 L
.80793 .01487 L
.80806 .01479 L
.8083 .01472 L
.80844 .01473 L
.80857 .01478 L
.8087 .01488 L
.80885 .01502 L
.8091 .01537 L
.80937 .01589 L
.80985 .01723 L
.81033 .01901 L
.81076 .02105 L
.81165 .02647 L
.81261 .03405 L
.81433 .05225 L
.81637 .08096 L
.81824 .11309 L
.82578 .28304 L
.83303 .45711 L
.83678 .52916 L
.83866 .55751 L
.83968 .57014 L
.84075 .58133 L
.84166 .58914 L
.84215 .59259 L
.84266 .59574 L
.84314 .59817 L
.84357 .59996 L
.844 .60136 L
.84441 .60232 L
.84464 .60271 L
.84477 .60288 L
.84489 .603 L
.84514 .60316 L
.84527 .60319 L
.8454 .60319 L
.84562 .60309 L
.84586 .60287 L
.84609 .60255 L
.84631 .60215 L
.84678 .60093 L
.8473 .59903 L
.84784 .59644 L
.84836 .59345 L
Mistroke
.85021 .57815 L
.85114 .5679 L
.85217 .55482 L
.85566 .4968 L
.86332 .32134 L
.87069 .14675 L
.87263 .10882 L
.87472 .07379 L
.8767 .04751 L
.87853 .02979 L
.87941 .02362 L
.8799 .0209 L
.88036 .01877 L
.88079 .01719 L
.88101 .01652 L
.88125 .01591 L
.88148 .01546 L
.88168 .01515 L
.88188 .01492 L
.88207 .01478 L
.8823 .01472 L
.88255 .01477 L
.88267 .01485 L
.88281 .01497 L
.88305 .01528 L
.88329 .01572 L
.88352 .01624 L
.88395 .01752 L
.88445 .01952 L
.88492 .02185 L
.88597 .02876 L
.88685 .03621 L
.88779 .04594 L
.8895 .06777 L
.8934 .13556 L
.90117 .31785 L
.90506 .41257 L
.90867 .49083 L
.91215 .55037 L
.9141 .57479 L
.91495 .58313 L
.91587 .59068 L
.91679 .59643 L
.91729 .59884 L
.91776 .60061 L
.91799 .6013 L
.9182 .60185 L
.91839 .60227 L
.9186 .60263 L
.91882 .60292 L
Mistroke
.91903 .60309 L
.91928 .60318 L
.9195 .60314 L
.91975 .60298 L
.91987 .60285 L
.92001 .60267 L
.92025 .60226 L
.92048 .60176 L
.92098 .60024 L
.92153 .59802 L
.92253 .59234 L
.92343 .58541 L
.92531 .56588 L
.92705 .54203 L
.93098 .47043 L
.93841 .29416 L
.94556 .1292 L
.94923 .06649 L
.95028 .05253 L
.95129 .04118 L
.95227 .0319 L
.95317 .02516 L
.95362 .02241 L
.9541 .01991 L
.95452 .01813 L
.95498 .01661 L
.95523 .01596 L
.95547 .01548 L
.95572 .01509 L
.95586 .01494 L
.95599 .01483 L
.95621 .01472 L
.95646 .01473 L
.9567 .01486 L
.95691 .01508 L
.95711 .01538 L
.95733 .01578 L
.95771 .01677 L
.95817 .01835 L
.9586 .02019 L
.95947 .02517 L
.96039 .03208 L
.96219 .0505 L
.96412 .07686 L
.96759 .13938 L
.97543 .32409 L
.97619 .34309 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00803oool200000240oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000P3oool5000001@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`800000103oool3000001@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000`3oool3000001D0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000`3oool3000001P0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?oo
o`<000002P3oool001l0oooo00@000000?ooo`3oool000007`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00000C0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0503oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02@3o
ool001l0oooo00@000000?ooo`3oool000007`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0C0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?oo
o`000000oooo00D000004`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0140oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`090?ooo`007`3oool010000000oooo0?oo
o`00000O0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000P3oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool01@000000oooo0?ooo`000000oooo00@00000503oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool3000001L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00T0oooo
000O0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`0A0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0000001@0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000005`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00T0oooo000O0?ooo`040000003oool0oooo0000
01l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`800000503o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool0503oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo0P00000;
0?ooo`00803oool200000240oooo0P00000:0?ooo`800000103oool2000000<0oooo0`00000E0?oo
o`8000002P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo01<0oooo0P00000:0?oo
o`800000103oool2000000@0oooo0P00000E0?ooo`8000002P3oool2000000@0oooo0P0000030?oo
o`<00000603oool2000000X0oooo0P0000040?ooo`030000003oool0oooo00T0oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000K0?ooooP000003@3oool001/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo
0?ooo`3d0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`800000403oool200000140oooo00<0
00000?ooo`3oool03`3oool200000100oooo0P00000A0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03`3oool200000140oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool001/0oooo00<00000
0?ooo`3oool03@3oool200000140oooo0P00000@0?ooo`800000403oool200000100oooo0P00000A
0?ooo`800000403oool200000100oooo0P00000A0?ooo`800000403oool200000100oooo0P00000A
0?ooo`800000403oool2000000T0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00000>0?oo
o`800000403oool300000100oooo0P00000@0?ooo`800000403oool200000140oooo0P00000@0?oo
o`800000403oool200000140oooo0P00000@0?ooo`800000403oool200000100oooo00<000000?oo
o`000000403oool2000000P0oooo0P00000=0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`80
0000403oool00`000000oooo0000000@0?ooo`800000403oool200000100oooo00<000000?ooo`00
0000403oool200000100oooo0P00000@0?ooo`030000003oool0000000l0oooo00<000000?ooo`00
0000403oool200000100oooo00<000000?ooo`0000003`3oool00`000000oooo0000000?0?ooo`03
0000003oool0000000T0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0000000?0?ooo`030000003oool0000000l0oooo00<000000?ooo`000000
403oool00`000000oooo0000000?0?ooo`030000003oool0000000l0oooo00<000000?ooo`000000
403oool200000100oooo00<000000?ooo`0000003`3oool00`000000oooo0000000@0?ooo`800000
403oool00`000000oooo0000000?0?ooo`030000003oool0000000l0oooo00<000000?ooo`000000
2@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000@0?ooo`030000003o
ool0000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000?0?ooo`030000003o
ool000000100oooo00<000000?ooo`0000003`3oool00`000000oooo0000000?0?ooo`030000003o
ool000000100oooo00<000000?ooo`0000003`3oool00`000000oooo0000000?0?ooo`030000003o
ool0000000T0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00000>0?ooo`030000003oool0
000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000@0?ooo`030000003oool0
000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000?0?ooo`040000003oool0
oooo000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000?0?ooo`030000003o
ool000000100oooo00<000000?ooo`0000003`3oool00`000000oooo0000000?0?ooo`030000003o
ool0000000P0oooo0P00000=0?ooo`006`3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000?0?ooo`040000003o
ool0oooo000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000?0?ooo`040000
003oool0oooo000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000?0?ooo`04
0000003oool0oooo000000h0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0000000?
0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?oo
o`3oool0303oool010000000oooo0?ooo`00000?0?ooo`030000003oool0000000l0oooo00@00000
0?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0000000l0oooo
00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`030000003oool00000
00l0oooo00<000000?ooo`0000003`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo000000l0oooo00<000000?ooo`0000003`3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000
3`3oool00`000000oooo0000000?0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000003`3oool00`000000oooo0000000?0?ooo`040000003oool0oooo000000h0oooo00@00000
0?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0oooo000000h0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0
000000l0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0;0?ooo`006`3oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`0000003`3o
ool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3o
ool000003`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@0
00000?ooo`3oool000003`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo0000
00h0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0000000?0?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00000=0?ooo`040000003oool0
oooo000000l0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`04
0000003oool0oooo000000h0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`040000003oool0
oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`04
0000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00
000?0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000001`3oool2000000d0
oooo000K0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000003`3oool010000000
oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3o
ool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`04
0000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool01@000000oooo0?ooo`3o
ool0000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`05
0000003oool0oooo0?ooo`0000003P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo00/0oooo000=0?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0303oool01000
0000oooo0?ooo`00000?0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool00000
3P3oool010000000oooo0?ooo`00000>0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?oo
o`00000>0?ooo`050000003oool0oooo0?ooo`0000003P3oool010000000oooo0?ooo`00000>0?oo
o`040000003oool0oooo000000h0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`3oool02`3oool000`0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0303oool010000000
oooo0?ooo`00000>0?ooo`050000003oool0oooo0?ooo`0000003P3oool010000000oooo0?ooo`00
000>0?ooo`040000003oool0oooo000000h0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`05
0000003oool0oooo0?ooo`0000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo000000h0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?ooo`00
00003P3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000>
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool02`3oool00100oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooooP000003@3oool00100oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00D0
00000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?ooo`0000003P3oool010000000
oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?oo
o`0000003@3oool01@000000oooo0?ooo`3oool0000000h0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`050000003oool0oooo0?ooo`0000003P3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo00/0oooo000<0?ooo`@000000`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo
0?ooo`0000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo
00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?ooo`00
00003P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00/0oooo000<0?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0<0?oo
o`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000d0oooo00D0
00000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2`3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0
000000d0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0
oooo0000000>0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool02`3oool000`0
oooo1@0000030?ooo`8000001@3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?oo
o`0000003@3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool01@000000oooo0?oo
o`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?oo
o`3oool0oooo0000000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
1@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00000=0?ooo`050000
003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool01@000000oooo0?oo
o`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?oo
o`3oool0oooo0000000>0?ooo`040000003oool0oooo000000L0oooo0P00000=0?ooo`006`3oool0
0`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?oo
o`3oool0000000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?oo
o`3oool0oooo0000000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
1@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0
303oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?oo
o`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00/0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0
2`3oool001/0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000d0oooo
00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0:0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02`3oool001/0oooo0P00000<0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool20000
00d0oooo000K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?oo
o`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00/0oooo000K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;
0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00/0oooo000K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0;0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00/0oooo000K0?ooo`800000303oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
0P00000=0?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool2000000`0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000003@3oool001/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02`3oool000L0oooo0`0000040?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02`3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool000P0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo0P00000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000d0
oooo00080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00080?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00/0oooo00070?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02`3oool000P0oooo00<000000?ooo`3oool00`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo000K0?ooo`8000002`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P00000=0?ooo`006`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0;0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`006`3oool2000000/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`8000003@3oool001/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02`3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3o
ool001/0oooo0P00000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2
000000d0oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0
oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo000K
0?ooo`8000002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P00000=
0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0;0?ooo`001`3oool3000000<0oooo0`0000040?ooo`80
00001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0;0?ooo`00203oool01@000000oooo0?ooo`3oool0000000<0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00/0oooo00080?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00080?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`8000002P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000=0?ooo`00203oool010000000
oooo0?ooo`3oool4000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;
0?ooo`001`3oool2000000<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00/0oooo00080?ooo`040000003oool0oooo0?ooo`D000000`3oool2
000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00000:0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool2000000d0oooo000K0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0
oooo000K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo000K
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00/0oooo000K0?ooo`8000002P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo0P00000=0?ooo`006`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`00
6`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`006`3oool2
000000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`8000003@3oool0
01/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool001/0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool001/0oooo0P00000:
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool2000000d0oooo000K0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00/0oooo00060?ooo`D000000`3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`00
1`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool02`3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00/0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0P0000090?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00`0oooo0P00000=0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`001P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0;0?ooo`001`3oool3000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool001/0oooo0P0000090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00`0oooo0P00000=0?ooo`006`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`006`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool0
01/0oooo0P0000090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo0P00000=0?ooo`006`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool001/0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo
000K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0;0?ooo`006`3oool2000000T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool2000000d0oooo000K0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?oo
o`006`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02`3oool001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0;0?ooo`006`3oool2000000T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool2
000000d0oooo000K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0;0?ooo`001P3oool500000080oooo0`0000040?ooo`8000001@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool000L0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool02`3oool000P0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`020?ooo`8000002@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=
0?ooo`8000003@3oool000H0oooo00H000000?ooo`3oool0oooo0000003oool4000000<0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool02`3oool000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool02`3oool000L0oooo0`0000020?ooo`D000000`3oool2000000D0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0
oooo000K0?ooo`8000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`8000003@3oool001/0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo000K
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;
0?ooo`006`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool02`3oool001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00/0oooo000K0?ooo`8000002@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`8000003@3oool001/0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`00
00003@3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02P3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0:0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`05
0000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000d0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000303o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3o
ool001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`050000003oool0
oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0
oooo0000000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool01@000000
oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00/0oooo000K0?ooo`800000203oool00`000000oooo0?ooo`0;0?ooo`05
0000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000d0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00D00000
0?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo
0000000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool01@000000oooo
0?ooo`3oool0000000`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`80
00003@3oool001/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`050000
003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo0000000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool01@000000oooo0?oo
o`3oool0000000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3o
ool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`05
0000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo
0?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00/0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?ooo`000000
3@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0
000000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0
oooo0?ooo`000000303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool02`3oool001/0oooo0P0000080?ooo`030000003oool0oooo00/0oooo00D00000
0?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool00000
00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo
0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo
0?ooo`3oool000000100oooo0P00000=0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?oo
o`0000003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000003@3oool0
1@000000oooo0?ooo`3oool0000000h0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`050000
003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000h0oooo00D000000?oo
o`3oool0oooo0000000=0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?oo
o`3oool000000140oooo00<000000?ooo`3oool02`3oool000L0oooo0`0000040?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`050000003o
ool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3o
ool0oooo0000000>0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3o
ool0000000d0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`050000003oool0oooo0?ooo`00
00003@3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000>
0?ooo`040000003oool0oooo000000h0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`050000
003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0;0?ooo`001P3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3o
ool0000000d0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?ooo`00
00003P3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`050000003oool0oooo0?ooo`0000003P3oool01@000000oooo0?ooo`3oool0000000d0oooo
00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?ooo`0000003P3oool01000
0000oooo0?ooo`00000>0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?oo
o`3oool000000140oooo00<000000?ooo`3oool02`3oool000X0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00@000000?ooo`3oool000003P3oool01@000000oooo0?oo
o`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`040000003oool0oooo0000
00h0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`050000003oool0oooo0?ooo`0000003@3o
ool01@000000oooo0?ooo`3oool0000000h0oooo00@000000?ooo`3oool000003P3oool01@000000
oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0
oooo00/0oooo00080?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo0P0000080?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo
0000000=0?ooo`050000003oool0oooo0?ooo`0000003P3oool010000000oooo0?ooo`00000>0?oo
o`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000h0oooo00@0
00000?ooo`3oool000003P3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3o
ool0oooo0000000=0?ooo`050000003oool0oooo0?ooo`0000003P3oool010000000oooo0?ooo`00
000>0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool000000100
oooo0P00000=0?ooo`002P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`040000003oool0oooo000000h0oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`050000003oool0oooo0?ooo`0000003P3oool010000000oooo0?ooo`00000>0?ooo`050000003o
ool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3o
ool0oooo0000000>0?ooo`040000003oool0oooo000000h0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0;0?ooo`001P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000000h0oooo
00@000000?ooo`3oool000003P3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?oo
o`3oool0oooo0000000>0?ooo`040000003oool0oooo000000h0oooo00D000000?ooo`3oool0oooo
0000000=0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool00000
00h0oooo00@000000?ooo`3oool000003P3oool01@000000oooo0?ooo`3oool0000000d0oooo00D0
00000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo00/0oooo00070?ooo`<00000103o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
3P3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3oool0oooo0000000>0?oo
o`040000003oool0oooo000000h0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`040000003o
ool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool01@000000oooo0?ooo`3oool00000
00h0oooo00@000000?ooo`3oool000003@3oool01@000000oooo0?ooo`3oool0000000h0oooo00@0
00000?ooo`3oool000003P3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3o
ool0oooo0000000A0?ooo`030000003oool0oooo00/0oooo000K0?ooo`800000103oool010000000
oooo0?ooo`00000>0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3o
ool0000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`04
0000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00
000?0?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000
oooo0?ooo`00000>0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3o
ool000000100oooo0P00000=0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000h0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`040000003oool0oooo000000h0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0
oooo000000h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`03
0000003oool0000000l0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>
0?ooo`040000003oool0oooo000000h0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
3P3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0oooo000000h0oooo00@000000?oo
o`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0000000l0oooo00@0
00000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0000000l0
oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0
oooo000000l0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0;0?ooo`006`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000h0oooo00@000000?ooo`3oool0
00003`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000h0oooo00@00000
0?ooo`3oool000003`3oool00`000000oooo0000000?0?ooo`040000003oool0oooo000000h0oooo
00@000000?ooo`3oool000003`3oool00`000000oooo0000000?0?ooo`040000003oool0oooo0000
00h0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`040000003o
ool0oooo00000140oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000l0oooo00@000000?ooo`3o
ool000003P3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000l0oooo00<0
00000?ooo`0000003`3oool010000000oooo0?ooo`00000>0?ooo`040000003oool0oooo000000l0
oooo00<000000?ooo`0000003`3oool010000000oooo0?ooo`00000?0?ooo`030000003oool00000
00h0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00000A0?ooo`030000003o
ool0oooo00/0oooo000K0?ooo`8000001@3oool00`000000oooo0000000?0?ooo`030000003oool0
000000l0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000?0?ooo`030000
003oool0000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000?0?ooo`040000
003oool0oooo000000l0oooo00<000000?ooo`0000003`3oool010000000oooo0?ooo`00000?0?oo
o`030000003oool0000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000A0?oo
o`8000003@3oool001/0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000?0?ooo`03
0000003oool0000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000@0?ooo`03
0000003oool0000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000@0?ooo`03
0000003oool0000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000@0?ooo`03
0000003oool0000000l0oooo00<000000?ooo`0000003`3oool00`000000oooo0000000B0?ooo`03
0000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
3`3oool00`000000oooo0000000?0?ooo`030000003oool0000000l0oooo00<000000?ooo`000000
403oool00`000000oooo0000000?0?ooo`030000003oool0000000l0oooo00<000000?ooo`000000
403oool00`000000oooo0000000?0?ooo`030000003oool0000000l0oooo00<000000?ooo`000000
403oool200000100oooo00<000000?ooo`0000003`3oool00`000000oooo0000000B0?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000003`3o
ool00`000000oooo0000000?0?ooo`030000003oool000000100oooo0P00000@0?ooo`030000003o
ool0000000l0oooo00<000000?ooo`000000403oool200000100oooo00<000000?ooo`0000003`3o
ool00`000000oooo0000000?0?ooo`030000003oool000000100oooo0P00000@0?ooo`030000003o
ool0000000l0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0;0?ooo`006`3oool0
0`000000oooo0?ooo`040?ooo`800000403oool00`000000oooo0000000@0?ooo`800000403oool2
00000100oooo0P00000@0?ooo`<00000403oool200000100oooo0P00000@0?ooo`030000003oool0
00000100oooo0P00000@0?ooo`800000403oool200000140oooo0P00000B0?ooo`030000003oool0
oooo00/0oooo000K0?ooo`8000001@3oool200000100oooo0P00000A0?ooo`800000403oool20000
0100oooo0P00000A0?ooo`800000403oool200000100oooo0P00000A0?ooo`030000003oool0oooo
00l0oooo0P00000@0?ooo`800000403oool200000140oooo0P00000A0?ooo`8000003@3oool001/0
oooo00<000000?ooo`3oool0103oool200000140oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`8000004@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0
oooo0P00000@0?ooo`8000004@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0
oooo0P00000A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo00/0oooo
000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool001/0oooon000000=
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00dP3oool3000004/0oooo003C
0?ooo`030000003oool0oooo04X0oooo001D0?ooo`D0000000D0oooo00000000000000000?ooo`02
00000080oooo0P0000030?ooo`<000000P3oool3000000<0oooo1@0000020?ooo`<000000P3oool3
000000@0oooo0`0000020?ooo`<0000000@0oooo000000000000oooo0`0000030?ooo`<00000203o
ool5000000050?ooo`00000000000000003oool00P0000020?ooo`8000000`3oool300000080oooo
0`0000000`3oool000000000000400000080oooo1@0000030?ooo`800000103oool00`000000oooo
0?ooo`190?ooo`00EP3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00H000000?ooo`3oool000000?ooo`0000060?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000003@3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`000006
0?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0B@3oool005H0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo1@0000020?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`030000003oool0oooo
0080oooo1@0000020?ooo`060000003oool0oooo0000003oool000001@3oool5000000T0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
1@0000020?ooo`040000003oool0oooo00000080oooo0`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0000001:0?ooo`00EP3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool000000080oooo0P0000050?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0000003oool00000
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
BP3oool005H0oooo00@000000?ooo`3oool0oooo100000020?ooo`@000000`3oool300000080oooo
0P0000000`3oool00000000000020?ooo`@000000P3oool300000080oooo0P0000000`3oool00000
000000020?ooo`<000000P3oool4000000<0oooo0`0000030?ooo`<000002P3oool010000000oooo
0?ooo`3oool400000080oooo100000030?ooo`<000000P3oool4000000<0oooo10000000103oool0
00000000000000030?ooo`@000000P3oool2000000030?ooo`000000000004T0oooo001F0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1@0?ooo`00
E03oool5000000P0oooo00<000000?ooo`3oool04@3oool2000002/0oooo1@0000080?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1@0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00141415, -16.8167, \
4.24814*^-5, 2.16636}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}]
}, Open  ]]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 5", "Subsubsection",
  CellTags->{"AOG0.", "6.2.5", "AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[CellGroupData[{

Cell["?GaussianBeam", "Input",
  CellLabel->"In[275]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[BoxData[
    \("GaussianBeam[spotsize, divergence, options] and \
GaussianBeam[complexbeamparameter, options] is a light source that takes \
either the output beam spotsize radius (specified at 1/e of the amplitude \
peak in the starting plane) and far-field beam divergence (specified as the \
full angle in radians) or the complex beam parameter as input and creates an \
extended point source ray model of a Gaussian laser beam.\n\nIn addition, \
GaussianBeam uses the FullForm option to determine whether a uniform grid of \
rays are created or two distinct fans of rays are instead constructed. For \
FullForm->False, GaussianBeam creates either a single two-dimensional fan of \
rays in the x-y plane or two cross-hatched fans of rays that lie in the x-y \
and x-z planes, depending on whether the spotsize and divergence or \
complexbeamparameter contains single numbers or sets of two numbers. For \
FullForm->True, GaussianBeam attempts to construct a uniform \
three-dimensional grid of rays to model the spot size and beam divergence \
behavior. In some instances, however, when the two tranverse beam waists \
occur at different locations along the optical axis, then GaussianBeam cannot \
presently construct a full three-dimensional model. In this event, it reverts \
to the FullForm->False behavior.\n\nEach input parameter may also take a \
symbolic setting in addition to a numeric value. In such an event, a \
two-element list of terms, {symbolic,numeric}, is given for each symbolic \
parameter setting. In addition to geometric ray tracing, GaussianBeam is also \
used in symbolic Gaussian beam propagation calculations.\n\nSee also: \
FarField, SpotSizeFactor, BeamWaist, SymbolicBeamWaist, BeamSpotSize, \
SymbolicBeamSpotSize, BeamCurvature, SymbolicBeamCurvature, BeamDivergence, \
SymbolicBeamDivergence, BeamScaleLength, SymbolicBeamScaleLength, \
ComplexBeamParameter, and SymbolicComplexBeamParameter."\)], "Print",
  CellLabel->"From In[275]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],

Cell["\<\
system = 
\t{
\t\tMove[GaussianBeam[1.5,.001],-50],
\t\tPlanoConcaveLens[-30,20,2,\"L1\",CurvatureDirection->Back],
\t\tMove[PlanoConvexLens[160,30,6.5,\"L2\"],130],
\t\tMove[BeamSplitter[{70,30},50,10],175,-45],
\t\tMove[Mirror[50,10],250],
\t\tMove[Mirror[50,10],{175,50},90.01],
\t\tMove[BeamSplitter[{70,30},50,10,\"\"],175,-45,GraphicDesign->Off],
\t\tMove[Screen[50],{175,-50},90]
\t};\
\>", "Input",
  CellLabel->"In[541]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[system,PlotType->TopView];", "Input",
  CellLabel->"In[542]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35485 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.17742 0.00307219 0.162059 0.00307219 [
[.81766 .33105 -8.9375 -6 ]
[.81766 .33105 8.9375 6 ]
[.81767 .00845 -4.75 -6 ]
[.81767 .00845 4.75 6 ]
[.18049 .10553 -7.53125 -6 ]
[.18049 .10553 7.53125 6 ]
[.96083 .05945 -8.9375 -6 ]
[.96083 .05945 8.9375 6 ]
[.58679 .09017 -7.53125 -6 ]
[.58679 .09017 7.53125 6 ]
[.65336 .07864 -8.0625 -6 ]
[.65336 .07864 8.0625 6 ]
[ 0 0 0 0 ]
[ 1 .35485 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.17742 .13134 m
.19474 .13134 L
.18817 .14158 L
.17742 .14158 L
.17742 .13134 L
F
.17742 .14158 m
.18817 .14158 L
.18467 .15182 L
.17742 .15182 L
.17742 .14158 L
F
.17742 .15182 m
.18467 .15182 L
.18356 .16206 L
.17742 .16206 L
.17742 .15182 L
F
.17742 .16206 m
.18356 .16206 L
.18467 .1723 L
.17742 .1723 L
.17742 .16206 L
F
.17742 .1723 m
.18467 .1723 L
.18817 .18254 L
.17742 .18254 L
.17742 .1723 L
F
.17742 .18254 m
.18817 .18254 L
.19474 .19278 L
.17742 .19278 L
.17742 .18254 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.17742 .13134 m
.17742 .14158 L
.17742 .15182 L
.17742 .16206 L
.17742 .1723 L
.17742 .18254 L
.17742 .19278 L
.19474 .19278 L
.18817 .18254 L
.18467 .1723 L
.18356 .16206 L
.18467 .15182 L
.18817 .14158 L
.19474 .13134 L
.17742 .13134 L
s
.5 g
.17742 .16206 m
.19474 .16206 L
.18817 .16206 L
.17742 .16206 L
.17742 .16206 L
F
.17742 .16206 m
.18817 .16206 L
.18467 .16206 L
.17742 .16206 L
.17742 .16206 L
F
.17742 .16206 m
.18467 .16206 L
.18356 .16206 L
.17742 .16206 L
.17742 .16206 L
F
.17742 .16206 m
.18356 .16206 L
.18467 .16206 L
.17742 .16206 L
.17742 .16206 L
F
.17742 .16206 m
.18467 .16206 L
.18817 .16206 L
.17742 .16206 L
.17742 .16206 L
F
.17742 .16206 m
.18817 .16206 L
.19474 .16206 L
.17742 .16206 L
.17742 .16206 L
F
0 g
.17742 .16206 m
.17742 .16206 L
.17742 .16206 L
.17742 .16206 L
.17742 .16206 L
.17742 .16206 L
.17742 .16206 L
.19474 .16206 L
.18817 .16206 L
.18467 .16206 L
.18356 .16206 L
.18467 .16206 L
.18817 .16206 L
.19474 .16206 L
.17742 .16206 L
s
.17742 .19278 m
.19474 .19278 L
.19474 .19173 L
.17742 .19173 L
.17742 .19278 L
s
.17742 .19173 m
.19474 .19173 L
.19474 .18866 L
.17742 .18866 L
.17742 .19173 L
s
.17742 .18866 m
.19474 .18866 L
.19474 .18378 L
.17742 .18378 L
.17742 .18866 L
s
.17742 .18378 m
.19474 .18378 L
.19474 .17742 L
.17742 .17742 L
.17742 .18378 L
s
.17742 .17742 m
.19474 .17742 L
.19474 .17001 L
.17742 .17001 L
.17742 .17742 L
s
.17742 .17001 m
.19474 .17001 L
.19474 .16206 L
.17742 .16206 L
.17742 .17001 L
s
.17742 .16206 m
.19474 .16206 L
.19474 .15411 L
.17742 .15411 L
.17742 .16206 L
s
.17742 .15411 m
.19474 .15411 L
.19474 .1467 L
.17742 .1467 L
.17742 .15411 L
s
.17742 .1467 m
.19474 .1467 L
.19474 .14033 L
.17742 .14033 L
.17742 .1467 L
s
.17742 .14033 m
.19474 .14033 L
.19474 .13545 L
.17742 .13545 L
.17742 .14033 L
s
.17742 .13545 m
.19474 .13545 L
.19474 .13238 L
.17742 .13238 L
.17742 .13545 L
s
.17742 .13238 m
.19474 .13238 L
.19474 .13134 L
.17742 .13134 L
.17742 .13238 L
s
.17742 .13134 m
.19474 .13134 L
.19474 .13238 L
.17742 .13238 L
.17742 .13134 L
s
.17742 .13238 m
.19474 .13238 L
.19474 .13545 L
.17742 .13545 L
.17742 .13238 L
s
.17742 .13545 m
.19474 .13545 L
.19474 .14033 L
.17742 .14033 L
.17742 .13545 L
s
.17742 .14033 m
.19474 .14033 L
.19474 .1467 L
.17742 .1467 L
.17742 .14033 L
s
.17742 .1467 m
.19474 .1467 L
.19474 .15411 L
.17742 .15411 L
.17742 .1467 L
s
.17742 .15411 m
.19474 .15411 L
.19474 .16206 L
.17742 .16206 L
.17742 .15411 L
s
.17742 .16206 m
.19474 .16206 L
.19474 .17001 L
.17742 .17001 L
.17742 .16206 L
s
.17742 .17001 m
.19474 .17001 L
.19474 .17742 L
.17742 .17742 L
.17742 .17001 L
s
.17742 .17742 m
.19474 .17742 L
.19474 .18378 L
.17742 .18378 L
.17742 .17742 L
s
.17742 .18378 m
.19474 .18378 L
.19474 .18866 L
.17742 .18866 L
.17742 .18378 L
s
.17742 .18866 m
.19474 .18866 L
.19474 .19173 L
.17742 .19173 L
.17742 .18866 L
s
.17742 .19173 m
.19474 .19173 L
.19474 .19278 L
.17742 .19278 L
.17742 .19173 L
s
.5 g
.581 .11598 m
.59677 .11598 L
.59677 .13134 L
.57866 .13134 L
.581 .11598 L
F
.57866 .13134 m
.59677 .13134 L
.59677 .1467 L
.57727 .1467 L
.57866 .13134 L
F
.57727 .1467 m
.59677 .1467 L
.59677 .16206 L
.57681 .16206 L
.57727 .1467 L
F
.57681 .16206 m
.59677 .16206 L
.59677 .17742 L
.57727 .17742 L
.57681 .16206 L
F
.57727 .17742 m
.59677 .17742 L
.59677 .19278 L
.57866 .19278 L
.57727 .17742 L
F
.57866 .19278 m
.59677 .19278 L
.59677 .20814 L
.581 .20814 L
.57866 .19278 L
F
0 g
.581 .11598 m
.57866 .13134 L
.57727 .1467 L
.57681 .16206 L
.57727 .17742 L
.57866 .19278 L
.581 .20814 L
.59677 .20814 L
.59677 .19278 L
.59677 .17742 L
.59677 .16206 L
.59677 .1467 L
.59677 .13134 L
.59677 .11598 L
.581 .11598 L
s
.5 g
.581 .16206 m
.59677 .16206 L
.59677 .16206 L
.57866 .16206 L
.581 .16206 L
F
.57866 .16206 m
.59677 .16206 L
.59677 .16206 L
.57727 .16206 L
.57866 .16206 L
F
.57727 .16206 m
.59677 .16206 L
.59677 .16206 L
.57681 .16206 L
.57727 .16206 L
F
.57681 .16206 m
.59677 .16206 L
.59677 .16206 L
.57727 .16206 L
.57681 .16206 L
F
.57727 .16206 m
.59677 .16206 L
.59677 .16206 L
.57866 .16206 L
.57727 .16206 L
F
.57866 .16206 m
.59677 .16206 L
.59677 .16206 L
.581 .16206 L
.57866 .16206 L
F
0 g
.581 .16206 m
.57866 .16206 L
.57727 .16206 L
.57681 .16206 L
.57727 .16206 L
.57866 .16206 L
.581 .16206 L
.59677 .16206 L
.59677 .16206 L
.59677 .16206 L
.59677 .16206 L
.59677 .16206 L
.59677 .16206 L
.59677 .16206 L
.581 .16206 L
s
.581 .20814 m
.59677 .20814 L
.59677 .20657 L
.581 .20657 L
.581 .20814 L
s
.581 .20657 m
.59677 .20657 L
.59677 .20197 L
.581 .20197 L
.581 .20657 L
s
.581 .20197 m
.59677 .20197 L
.59677 .19464 L
.581 .19464 L
.581 .20197 L
s
.581 .19464 m
.59677 .19464 L
.59677 .1851 L
.581 .1851 L
.581 .19464 L
s
.581 .1851 m
.59677 .1851 L
.59677 .17399 L
.581 .17399 L
.581 .1851 L
s
.581 .17399 m
.59677 .17399 L
.59677 .16206 L
.581 .16206 L
.581 .17399 L
s
.581 .16206 m
.59677 .16206 L
.59677 .15013 L
.581 .15013 L
.581 .16206 L
s
.581 .15013 m
.59677 .15013 L
.59677 .13902 L
.581 .13902 L
.581 .15013 L
s
.581 .13902 m
.59677 .13902 L
.59677 .12947 L
.581 .12947 L
.581 .13902 L
s
.581 .12947 m
.59677 .12947 L
.59677 .12215 L
.581 .12215 L
.581 .12947 L
s
.581 .12215 m
.59677 .12215 L
.59677 .11755 L
.581 .11755 L
.581 .12215 L
s
.581 .11755 m
.59677 .11755 L
.59677 .11598 L
.581 .11598 L
.581 .11755 L
s
.581 .11598 m
.59677 .11598 L
.59677 .11755 L
.581 .11755 L
.581 .11598 L
s
.581 .11755 m
.59677 .11755 L
.59677 .12215 L
.581 .12215 L
.581 .11755 L
s
.581 .12215 m
.59677 .12215 L
.59677 .12947 L
.581 .12947 L
.581 .12215 L
s
.581 .12947 m
.59677 .12947 L
.59677 .13902 L
.581 .13902 L
.581 .12947 L
s
.581 .13902 m
.59677 .13902 L
.59677 .15013 L
.581 .15013 L
.581 .13902 L
s
.581 .15013 m
.59677 .15013 L
.59677 .16206 L
.581 .16206 L
.581 .15013 L
s
.581 .16206 m
.59677 .16206 L
.59677 .17399 L
.581 .17399 L
.581 .16206 L
s
.581 .17399 m
.59677 .17399 L
.59677 .1851 L
.581 .1851 L
.581 .17399 L
s
.581 .1851 m
.59677 .1851 L
.59677 .19464 L
.581 .19464 L
.581 .1851 L
s
.581 .19464 m
.59677 .19464 L
.59677 .20197 L
.581 .20197 L
.581 .19464 L
s
.581 .20197 m
.59677 .20197 L
.59677 .20657 L
.581 .20657 L
.581 .20197 L
s
.581 .20657 m
.59677 .20657 L
.59677 .20814 L
.581 .20814 L
.581 .20657 L
s
.5 g
.66074 .10775 m
.68247 .08603 L
.70057 .10413 L
.67885 .12585 L
.66074 .10775 L
F
.67885 .12585 m
.70057 .10413 L
.71867 .12223 L
.69695 .14396 L
.67885 .12585 L
F
.69695 .14396 m
.71867 .12223 L
.73678 .14033 L
.71505 .16206 L
.69695 .14396 L
F
.71505 .16206 m
.73678 .14033 L
.75488 .15844 L
.73316 .18016 L
.71505 .16206 L
F
.73316 .18016 m
.75488 .15844 L
.77298 .17654 L
.75126 .19826 L
.73316 .18016 L
F
.75126 .19826 m
.77298 .17654 L
.79109 .19464 L
.76936 .21637 L
.75126 .19826 L
F
0 g
.66074 .10775 m
.67885 .12585 L
.69695 .14396 L
.71505 .16206 L
.73316 .18016 L
.75126 .19826 L
.76936 .21637 L
.79109 .19464 L
.77298 .17654 L
.75488 .15844 L
.73678 .14033 L
.71867 .12223 L
.70057 .10413 L
.68247 .08603 L
.66074 .10775 L
s
.5 g
.71505 .16206 m
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
.71505 .16206 L
F
0 g
.71505 .16206 m
.71505 .16206 L
.71505 .16206 L
.71505 .16206 L
.71505 .16206 L
.71505 .16206 L
.71505 .16206 L
.73678 .14033 L
.73678 .14033 L
.73678 .14033 L
.73678 .14033 L
.73678 .14033 L
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
s
.5 g
.71505 .16206 m
.73316 .18016 L
.73254 .17954 L
.71505 .16206 L
.71505 .16206 L
F
.73316 .18016 m
.75126 .19826 L
.75003 .19703 L
.73254 .17954 L
.73316 .18016 L
F
.75126 .19826 m
.76936 .21637 L
.76751 .21452 L
.75003 .19703 L
.75126 .19826 L
F
.71505 .16206 m
.73254 .17954 L
.73073 .17774 L
.71505 .16206 L
.71505 .16206 L
F
.73254 .17954 m
.75003 .19703 L
.74641 .19341 L
.73073 .17774 L
.73254 .17954 L
F
.75003 .19703 m
.76751 .21452 L
.76209 .20909 L
.74641 .19341 L
.75003 .19703 L
F
.71505 .16206 m
.73073 .17774 L
.72785 .17486 L
.71505 .16206 L
.71505 .16206 L
F
.73073 .17774 m
.74641 .19341 L
.74066 .18766 L
.72785 .17486 L
.73073 .17774 L
F
.74641 .19341 m
.76209 .20909 L
.75346 .20046 L
.74066 .18766 L
.74641 .19341 L
F
.71505 .16206 m
.72785 .17486 L
.72411 .17111 L
.71505 .16206 L
.71505 .16206 L
F
.72785 .17486 m
.74066 .18766 L
.73316 .18016 L
.72411 .17111 L
.72785 .17486 L
F
.74066 .18766 m
.75346 .20046 L
.74221 .18921 L
.73316 .18016 L
.74066 .18766 L
F
.71505 .16206 m
.72411 .17111 L
.71974 .16674 L
.71505 .16206 L
.71505 .16206 L
F
.72411 .17111 m
.73316 .18016 L
.72442 .17143 L
.71974 .16674 L
.72411 .17111 L
F
.73316 .18016 m
.74221 .18921 L
.72911 .17611 L
.72442 .17143 L
.73316 .18016 L
F
.71505 .16206 m
.71974 .16674 L
.71505 .16206 L
.71505 .16206 L
.71505 .16206 L
F
.71974 .16674 m
.72442 .17143 L
.71505 .16206 L
.71505 .16206 L
.71974 .16674 L
F
.72442 .17143 m
.72911 .17611 L
.71505 .16206 L
.71505 .16206 L
.72442 .17143 L
F
.71505 .16206 m
.71505 .16206 L
.71037 .15737 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.71505 .16206 L
.70568 .15269 L
.71037 .15737 L
.71505 .16206 L
F
.71505 .16206 m
.71505 .16206 L
.701 .148 L
.70568 .15269 L
.71505 .16206 L
F
.71505 .16206 m
.71037 .15737 L
.706 .15301 L
.71505 .16206 L
.71505 .16206 L
F
.71037 .15737 m
.70568 .15269 L
.69695 .14396 L
.706 .15301 L
.71037 .15737 L
F
.70568 .15269 m
.701 .148 L
.6879 .1349 L
.69695 .14396 L
.70568 .15269 L
F
.71505 .16206 m
.706 .15301 L
.70225 .14926 L
.71505 .16206 L
.71505 .16206 L
F
.706 .15301 m
.69695 .14396 L
.68945 .13646 L
.70225 .14926 L
.706 .15301 L
F
.69695 .14396 m
.6879 .1349 L
.67665 .12366 L
.68945 .13646 L
.69695 .14396 L
F
.71505 .16206 m
.70225 .14926 L
.69938 .14638 L
.71505 .16206 L
.71505 .16206 L
F
.70225 .14926 m
.68945 .13646 L
.6837 .1307 L
.69938 .14638 L
.70225 .14926 L
F
.68945 .13646 m
.67665 .12366 L
.66802 .11503 L
.6837 .1307 L
.68945 .13646 L
F
.71505 .16206 m
.69938 .14638 L
.69757 .14457 L
.71505 .16206 L
.71505 .16206 L
F
.69938 .14638 m
.6837 .1307 L
.68008 .12709 L
.69757 .14457 L
.69938 .14638 L
F
.6837 .1307 m
.66802 .11503 L
.6626 .1096 L
.68008 .12709 L
.6837 .1307 L
F
.71505 .16206 m
.69757 .14457 L
.69695 .14396 L
.71505 .16206 L
.71505 .16206 L
F
.69757 .14457 m
.68008 .12709 L
.67885 .12585 L
.69695 .14396 L
.69757 .14457 L
F
.68008 .12709 m
.6626 .1096 L
.66074 .10775 L
.67885 .12585 L
.68008 .12709 L
F
.71505 .16206 m
.69695 .14396 L
.69757 .14457 L
.71505 .16206 L
.71505 .16206 L
F
.69695 .14396 m
.67885 .12585 L
.68008 .12709 L
.69757 .14457 L
.69695 .14396 L
F
.67885 .12585 m
.66074 .10775 L
.6626 .1096 L
.68008 .12709 L
.67885 .12585 L
F
.71505 .16206 m
.69757 .14457 L
.69938 .14638 L
.71505 .16206 L
.71505 .16206 L
F
.69757 .14457 m
.68008 .12709 L
.6837 .1307 L
.69938 .14638 L
.69757 .14457 L
F
.68008 .12709 m
.6626 .1096 L
.66802 .11503 L
.6837 .1307 L
.68008 .12709 L
F
.71505 .16206 m
.69938 .14638 L
.70225 .14926 L
.71505 .16206 L
.71505 .16206 L
F
.69938 .14638 m
.6837 .1307 L
.68945 .13646 L
.70225 .14926 L
.69938 .14638 L
F
.6837 .1307 m
.66802 .11503 L
.67665 .12366 L
.68945 .13646 L
.6837 .1307 L
F
.71505 .16206 m
.70225 .14926 L
.706 .15301 L
.71505 .16206 L
.71505 .16206 L
F
.70225 .14926 m
.68945 .13646 L
.69695 .14396 L
.706 .15301 L
.70225 .14926 L
F
.68945 .13646 m
.67665 .12366 L
.6879 .1349 L
.69695 .14396 L
.68945 .13646 L
F
.71505 .16206 m
.706 .15301 L
.71037 .15737 L
.71505 .16206 L
.71505 .16206 L
F
.706 .15301 m
.69695 .14396 L
.70568 .15269 L
.71037 .15737 L
.706 .15301 L
F
.69695 .14396 m
.6879 .1349 L
.701 .148 L
.70568 .15269 L
.69695 .14396 L
F
.71505 .16206 m
.71037 .15737 L
.71505 .16206 L
.71505 .16206 L
.71505 .16206 L
F
.71037 .15737 m
.70568 .15269 L
.71505 .16206 L
.71505 .16206 L
.71037 .15737 L
F
.70568 .15269 m
.701 .148 L
.71505 .16206 L
.71505 .16206 L
.70568 .15269 L
F
.71505 .16206 m
.71505 .16206 L
.71974 .16674 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.71505 .16206 L
.72442 .17143 L
.71974 .16674 L
.71505 .16206 L
F
.71505 .16206 m
.71505 .16206 L
.72911 .17611 L
.72442 .17143 L
.71505 .16206 L
F
.71505 .16206 m
.71974 .16674 L
.72411 .17111 L
.71505 .16206 L
.71505 .16206 L
F
.71974 .16674 m
.72442 .17143 L
.73316 .18016 L
.72411 .17111 L
.71974 .16674 L
F
.72442 .17143 m
.72911 .17611 L
.74221 .18921 L
.73316 .18016 L
.72442 .17143 L
F
.71505 .16206 m
.72411 .17111 L
.72785 .17486 L
.71505 .16206 L
.71505 .16206 L
F
.72411 .17111 m
.73316 .18016 L
.74066 .18766 L
.72785 .17486 L
.72411 .17111 L
F
.73316 .18016 m
.74221 .18921 L
.75346 .20046 L
.74066 .18766 L
.73316 .18016 L
F
.71505 .16206 m
.72785 .17486 L
.73073 .17774 L
.71505 .16206 L
.71505 .16206 L
F
.72785 .17486 m
.74066 .18766 L
.74641 .19341 L
.73073 .17774 L
.72785 .17486 L
F
.74066 .18766 m
.75346 .20046 L
.76209 .20909 L
.74641 .19341 L
.74066 .18766 L
F
.71505 .16206 m
.73073 .17774 L
.73254 .17954 L
.71505 .16206 L
.71505 .16206 L
F
.73073 .17774 m
.74641 .19341 L
.75003 .19703 L
.73254 .17954 L
.73073 .17774 L
F
.74641 .19341 m
.76209 .20909 L
.76751 .21452 L
.75003 .19703 L
.74641 .19341 L
F
.71505 .16206 m
.73254 .17954 L
.73316 .18016 L
.71505 .16206 L
.71505 .16206 L
F
.73254 .17954 m
.75003 .19703 L
.75126 .19826 L
.73316 .18016 L
.73254 .17954 L
F
.75003 .19703 m
.76751 .21452 L
.76936 .21637 L
.75126 .19826 L
.75003 .19703 L
F
0 g
.76936 .21637 m
.76751 .21452 L
.76209 .20909 L
.75346 .20046 L
.74221 .18921 L
.72911 .17611 L
.71505 .16206 L
.701 .148 L
.6879 .1349 L
.67665 .12366 L
.66802 .11503 L
.6626 .1096 L
.66074 .10775 L
.6626 .1096 L
.66802 .11503 L
.67665 .12366 L
.6879 .1349 L
.701 .148 L
.71505 .16206 L
.72911 .17611 L
.74221 .18921 L
.75346 .20046 L
.76209 .20909 L
.76751 .21452 L
.76936 .21637 L
s
.76936 .21637 m
.79109 .19464 L
.78924 .19279 L
.76751 .21452 L
.76936 .21637 L
s
.76751 .21452 m
.78924 .19279 L
.78381 .18737 L
.76209 .20909 L
.76751 .21452 L
s
.76209 .20909 m
.78381 .18737 L
.77518 .17874 L
.75346 .20046 L
.76209 .20909 L
s
.75346 .20046 m
.77518 .17874 L
.76393 .16749 L
.74221 .18921 L
.75346 .20046 L
s
.74221 .18921 m
.76393 .16749 L
.75083 .15439 L
.72911 .17611 L
.74221 .18921 L
s
.72911 .17611 m
.75083 .15439 L
.73678 .14033 L
.71505 .16206 L
.72911 .17611 L
s
.71505 .16206 m
.73678 .14033 L
.72272 .12628 L
.701 .148 L
.71505 .16206 L
s
.701 .148 m
.72272 .12628 L
.70962 .11318 L
.6879 .1349 L
.701 .148 L
s
.6879 .1349 m
.70962 .11318 L
.69838 .10193 L
.67665 .12366 L
.6879 .1349 L
s
.67665 .12366 m
.69838 .10193 L
.68974 .0933 L
.66802 .11503 L
.67665 .12366 L
s
.66802 .11503 m
.68974 .0933 L
.68432 .08788 L
.6626 .1096 L
.66802 .11503 L
s
.6626 .1096 m
.68432 .08788 L
.68247 .08603 L
.66074 .10775 L
.6626 .1096 L
s
.66074 .10775 m
.68247 .08603 L
.68432 .08788 L
.6626 .1096 L
.66074 .10775 L
s
.6626 .1096 m
.68432 .08788 L
.68974 .0933 L
.66802 .11503 L
.6626 .1096 L
s
.66802 .11503 m
.68974 .0933 L
.69838 .10193 L
.67665 .12366 L
.66802 .11503 L
s
.67665 .12366 m
.69838 .10193 L
.70962 .11318 L
.6879 .1349 L
.67665 .12366 L
s
.6879 .1349 m
.70962 .11318 L
.72272 .12628 L
.701 .148 L
.6879 .1349 L
s
.701 .148 m
.72272 .12628 L
.73678 .14033 L
.71505 .16206 L
.701 .148 L
s
.71505 .16206 m
.73678 .14033 L
.75083 .15439 L
.72911 .17611 L
.71505 .16206 L
s
.72911 .17611 m
.75083 .15439 L
.76393 .16749 L
.74221 .18921 L
.72911 .17611 L
s
.74221 .18921 m
.76393 .16749 L
.77518 .17874 L
.75346 .20046 L
.74221 .18921 L
s
.75346 .20046 m
.77518 .17874 L
.78381 .18737 L
.76209 .20909 L
.75346 .20046 L
s
.76209 .20909 m
.78381 .18737 L
.78924 .19279 L
.76751 .21452 L
.76209 .20909 L
s
.76751 .21452 m
.78924 .19279 L
.79109 .19464 L
.76936 .21637 L
.76751 .21452 L
s
.5 g
.94547 .08525 m
.97619 .08525 L
.97619 .11086 L
.94547 .11086 L
.94547 .08525 L
F
.94547 .11086 m
.97619 .11086 L
.97619 .13646 L
.94547 .13646 L
.94547 .11086 L
F
.94547 .13646 m
.97619 .13646 L
.97619 .16206 L
.94547 .16206 L
.94547 .13646 L
F
.94547 .16206 m
.97619 .16206 L
.97619 .18766 L
.94547 .18766 L
.94547 .16206 L
F
.94547 .18766 m
.97619 .18766 L
.97619 .21326 L
.94547 .21326 L
.94547 .18766 L
F
.94547 .21326 m
.97619 .21326 L
.97619 .23886 L
.94547 .23886 L
.94547 .21326 L
F
0 g
.94547 .08525 m
.94547 .11086 L
.94547 .13646 L
.94547 .16206 L
.94547 .18766 L
.94547 .21326 L
.94547 .23886 L
.97619 .23886 L
.97619 .21326 L
.97619 .18766 L
.97619 .16206 L
.97619 .13646 L
.97619 .11086 L
.97619 .08525 L
.94547 .08525 L
s
.5 g
.94547 .16206 m
.97619 .16206 L
.97619 .16206 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .16206 m
.97619 .16206 L
.97619 .16206 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .16206 m
.97619 .16206 L
.97619 .16206 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .16206 m
.97619 .16206 L
.97619 .16206 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .16206 m
.97619 .16206 L
.97619 .16206 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .16206 m
.97619 .16206 L
.97619 .16206 L
.94547 .16206 L
.94547 .16206 L
F
0 g
.94547 .16206 m
.94547 .16206 L
.94547 .16206 L
.94547 .16206 L
.94547 .16206 L
.94547 .16206 L
.94547 .16206 L
.97619 .16206 L
.97619 .16206 L
.97619 .16206 L
.97619 .16206 L
.97619 .16206 L
.97619 .16206 L
.97619 .16206 L
.94547 .16206 L
s
.5 g
.94547 .16206 m
.94547 .18766 L
.94547 .18679 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .18766 m
.94547 .21326 L
.94547 .21152 L
.94547 .18679 L
.94547 .18766 L
F
.94547 .21326 m
.94547 .23886 L
.94547 .23625 L
.94547 .21152 L
.94547 .21326 L
F
.94547 .16206 m
.94547 .18679 L
.94547 .18423 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .18679 m
.94547 .21152 L
.94547 .2064 L
.94547 .18423 L
.94547 .18679 L
F
.94547 .21152 m
.94547 .23625 L
.94547 .22857 L
.94547 .2064 L
.94547 .21152 L
F
.94547 .16206 m
.94547 .18423 L
.94547 .18016 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .18423 m
.94547 .2064 L
.94547 .19826 L
.94547 .18016 L
.94547 .18423 L
F
.94547 .2064 m
.94547 .22857 L
.94547 .21637 L
.94547 .19826 L
.94547 .2064 L
F
.94547 .16206 m
.94547 .18016 L
.94547 .17486 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .18016 m
.94547 .19826 L
.94547 .18766 L
.94547 .17486 L
.94547 .18016 L
F
.94547 .19826 m
.94547 .21637 L
.94547 .20046 L
.94547 .18766 L
.94547 .19826 L
F
.94547 .16206 m
.94547 .17486 L
.94547 .16868 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .17486 m
.94547 .18766 L
.94547 .17531 L
.94547 .16868 L
.94547 .17486 L
F
.94547 .18766 m
.94547 .20046 L
.94547 .18194 L
.94547 .17531 L
.94547 .18766 L
F
.94547 .16206 m
.94547 .16868 L
.94547 .16206 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .16868 m
.94547 .17531 L
.94547 .16206 L
.94547 .16206 L
.94547 .16868 L
F
.94547 .17531 m
.94547 .18194 L
.94547 .16206 L
.94547 .16206 L
.94547 .17531 L
F
.94547 .16206 m
.94547 .16206 L
.94547 .15543 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .16206 m
.94547 .16206 L
.94547 .14881 L
.94547 .15543 L
.94547 .16206 L
F
.94547 .16206 m
.94547 .16206 L
.94547 .14218 L
.94547 .14881 L
.94547 .16206 L
F
.94547 .16206 m
.94547 .15543 L
.94547 .14926 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .15543 m
.94547 .14881 L
.94547 .13646 L
.94547 .14926 L
.94547 .15543 L
F
.94547 .14881 m
.94547 .14218 L
.94547 .12366 L
.94547 .13646 L
.94547 .14881 L
F
.94547 .16206 m
.94547 .14926 L
.94547 .14396 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .14926 m
.94547 .13646 L
.94547 .12585 L
.94547 .14396 L
.94547 .14926 L
F
.94547 .13646 m
.94547 .12366 L
.94547 .10775 L
.94547 .12585 L
.94547 .13646 L
F
.94547 .16206 m
.94547 .14396 L
.94547 .13989 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .14396 m
.94547 .12585 L
.94547 .11772 L
.94547 .13989 L
.94547 .14396 L
F
.94547 .12585 m
.94547 .10775 L
.94547 .09554 L
.94547 .11772 L
.94547 .12585 L
F
.94547 .16206 m
.94547 .13989 L
.94547 .13733 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .13989 m
.94547 .11772 L
.94547 .1126 L
.94547 .13733 L
.94547 .13989 L
F
.94547 .11772 m
.94547 .09554 L
.94547 .08787 L
.94547 .1126 L
.94547 .11772 L
F
.94547 .16206 m
.94547 .13733 L
.94547 .13646 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .13733 m
.94547 .1126 L
.94547 .11086 L
.94547 .13646 L
.94547 .13733 L
F
.94547 .1126 m
.94547 .08787 L
.94547 .08525 L
.94547 .11086 L
.94547 .1126 L
F
.94547 .16206 m
.94547 .13646 L
.94547 .13733 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .13646 m
.94547 .11086 L
.94547 .1126 L
.94547 .13733 L
.94547 .13646 L
F
.94547 .11086 m
.94547 .08525 L
.94547 .08787 L
.94547 .1126 L
.94547 .11086 L
F
.94547 .16206 m
.94547 .13733 L
.94547 .13989 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .13733 m
.94547 .1126 L
.94547 .11772 L
.94547 .13989 L
.94547 .13733 L
F
.94547 .1126 m
.94547 .08787 L
.94547 .09554 L
.94547 .11772 L
.94547 .1126 L
F
.94547 .16206 m
.94547 .13989 L
.94547 .14396 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .13989 m
.94547 .11772 L
.94547 .12585 L
.94547 .14396 L
.94547 .13989 L
F
.94547 .11772 m
.94547 .09554 L
.94547 .10775 L
.94547 .12585 L
.94547 .11772 L
F
.94547 .16206 m
.94547 .14396 L
.94547 .14926 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .14396 m
.94547 .12585 L
.94547 .13646 L
.94547 .14926 L
.94547 .14396 L
F
.94547 .12585 m
.94547 .10775 L
.94547 .12366 L
.94547 .13646 L
.94547 .12585 L
F
.94547 .16206 m
.94547 .14926 L
.94547 .15543 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .14926 m
.94547 .13646 L
.94547 .14881 L
.94547 .15543 L
.94547 .14926 L
F
.94547 .13646 m
.94547 .12366 L
.94547 .14218 L
.94547 .14881 L
.94547 .13646 L
F
.94547 .16206 m
.94547 .15543 L
.94547 .16206 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .15543 m
.94547 .14881 L
.94547 .16206 L
.94547 .16206 L
.94547 .15543 L
F
.94547 .14881 m
.94547 .14218 L
.94547 .16206 L
.94547 .16206 L
.94547 .14881 L
F
.94547 .16206 m
.94547 .16206 L
.94547 .16868 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .16206 m
.94547 .16206 L
.94547 .17531 L
.94547 .16868 L
.94547 .16206 L
F
.94547 .16206 m
.94547 .16206 L
.94547 .18194 L
.94547 .17531 L
.94547 .16206 L
F
.94547 .16206 m
.94547 .16868 L
.94547 .17486 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .16868 m
.94547 .17531 L
.94547 .18766 L
.94547 .17486 L
.94547 .16868 L
F
.94547 .17531 m
.94547 .18194 L
.94547 .20046 L
.94547 .18766 L
.94547 .17531 L
F
.94547 .16206 m
.94547 .17486 L
.94547 .18016 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .17486 m
.94547 .18766 L
.94547 .19826 L
.94547 .18016 L
.94547 .17486 L
F
.94547 .18766 m
.94547 .20046 L
.94547 .21637 L
.94547 .19826 L
.94547 .18766 L
F
.94547 .16206 m
.94547 .18016 L
.94547 .18423 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .18016 m
.94547 .19826 L
.94547 .2064 L
.94547 .18423 L
.94547 .18016 L
F
.94547 .19826 m
.94547 .21637 L
.94547 .22857 L
.94547 .2064 L
.94547 .19826 L
F
.94547 .16206 m
.94547 .18423 L
.94547 .18679 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .18423 m
.94547 .2064 L
.94547 .21152 L
.94547 .18679 L
.94547 .18423 L
F
.94547 .2064 m
.94547 .22857 L
.94547 .23625 L
.94547 .21152 L
.94547 .2064 L
F
.94547 .16206 m
.94547 .18679 L
.94547 .18766 L
.94547 .16206 L
.94547 .16206 L
F
.94547 .18679 m
.94547 .21152 L
.94547 .21326 L
.94547 .18766 L
.94547 .18679 L
F
.94547 .21152 m
.94547 .23625 L
.94547 .23886 L
.94547 .21326 L
.94547 .21152 L
F
0 g
.94547 .23886 m
.94547 .23625 L
.94547 .22857 L
.94547 .21637 L
.94547 .20046 L
.94547 .18194 L
.94547 .16206 L
.94547 .14218 L
.94547 .12366 L
.94547 .10775 L
.94547 .09554 L
.94547 .08787 L
.94547 .08525 L
.94547 .08787 L
.94547 .09554 L
.94547 .10775 L
.94547 .12366 L
.94547 .14218 L
.94547 .16206 L
.94547 .18194 L
.94547 .20046 L
.94547 .21637 L
.94547 .22857 L
.94547 .23625 L
.94547 .23886 L
s
.97619 .23886 m
.97619 .23625 L
.97619 .22857 L
.97619 .21637 L
.97619 .20046 L
.97619 .18194 L
.97619 .16206 L
.97619 .14218 L
.97619 .12366 L
.97619 .10775 L
.97619 .09554 L
.97619 .08787 L
.97619 .08525 L
.97619 .08787 L
.97619 .09554 L
.97619 .10775 L
.97619 .12366 L
.97619 .14218 L
.97619 .16206 L
.97619 .18194 L
.97619 .20046 L
.97619 .21637 L
.97619 .22857 L
.97619 .23625 L
.97619 .23886 L
s
.94547 .23886 m
.97619 .23886 L
.97619 .23625 L
.94547 .23625 L
.94547 .23886 L
s
.94547 .23625 m
.97619 .23625 L
.97619 .22857 L
.94547 .22857 L
.94547 .23625 L
s
.94547 .22857 m
.97619 .22857 L
.97619 .21637 L
.94547 .21637 L
.94547 .22857 L
s
.94547 .21637 m
.97619 .21637 L
.97619 .20046 L
.94547 .20046 L
.94547 .21637 L
s
.94547 .20046 m
.97619 .20046 L
.97619 .18194 L
.94547 .18194 L
.94547 .20046 L
s
.94547 .18194 m
.97619 .18194 L
.97619 .16206 L
.94547 .16206 L
.94547 .18194 L
s
.94547 .16206 m
.97619 .16206 L
.97619 .14218 L
.94547 .14218 L
.94547 .16206 L
s
.94547 .14218 m
.97619 .14218 L
.97619 .12366 L
.94547 .12366 L
.94547 .14218 L
s
.94547 .12366 m
.97619 .12366 L
.97619 .10775 L
.94547 .10775 L
.94547 .12366 L
s
.94547 .10775 m
.97619 .10775 L
.97619 .09554 L
.94547 .09554 L
.94547 .10775 L
s
.94547 .09554 m
.97619 .09554 L
.97619 .08787 L
.94547 .08787 L
.94547 .09554 L
s
.94547 .08787 m
.97619 .08787 L
.97619 .08525 L
.94547 .08525 L
.94547 .08787 L
s
.94547 .08525 m
.97619 .08525 L
.97619 .08787 L
.94547 .08787 L
.94547 .08525 L
s
.94547 .08787 m
.97619 .08787 L
.97619 .09554 L
.94547 .09554 L
.94547 .08787 L
s
.94547 .09554 m
.97619 .09554 L
.97619 .10775 L
.94547 .10775 L
.94547 .09554 L
s
.94547 .10775 m
.97619 .10775 L
.97619 .12366 L
.94547 .12366 L
.94547 .10775 L
s
.94547 .12366 m
.97619 .12366 L
.97619 .14218 L
.94547 .14218 L
.94547 .12366 L
s
.94547 .14218 m
.97619 .14218 L
.97619 .16206 L
.94547 .16206 L
.94547 .14218 L
s
.94547 .16206 m
.97619 .16206 L
.97619 .18194 L
.94547 .18194 L
.94547 .16206 L
s
.94547 .18194 m
.97619 .18194 L
.97619 .20046 L
.94547 .20046 L
.94547 .18194 L
s
.94547 .20046 m
.97619 .20046 L
.97619 .21637 L
.94547 .21637 L
.94547 .20046 L
s
.94547 .21637 m
.97619 .21637 L
.97619 .22857 L
.94547 .22857 L
.94547 .21637 L
s
.94547 .22857 m
.97619 .22857 L
.97619 .23625 L
.94547 .23625 L
.94547 .22857 L
s
.94547 .23625 m
.97619 .23625 L
.97619 .23886 L
.94547 .23886 L
.94547 .23625 L
s
.5 g
.79186 .31568 m
.79185 .3464 L
.76625 .3464 L
.76626 .31568 L
.79186 .31568 L
F
.76626 .31568 m
.76625 .3464 L
.74065 .34639 L
.74066 .31567 L
.76626 .31568 L
F
.74066 .31567 m
.74065 .34639 L
.71505 .34639 L
.71505 .31567 L
.74066 .31567 L
F
.71505 .31567 m
.71505 .34639 L
.68945 .34639 L
.68945 .31566 L
.71505 .31567 L
F
.68945 .31566 m
.68945 .34639 L
.66385 .34638 L
.66385 .31566 L
.68945 .31566 L
F
.66385 .31566 m
.66385 .34638 L
.63824 .34638 L
.63825 .31565 L
.66385 .31566 L
F
0 g
.79186 .31568 m
.76626 .31568 L
.74066 .31567 L
.71505 .31567 L
.68945 .31566 L
.66385 .31566 L
.63825 .31565 L
.63824 .34638 L
.66385 .34638 L
.68945 .34639 L
.71505 .34639 L
.74065 .34639 L
.76625 .3464 L
.79185 .3464 L
.79186 .31568 L
s
.5 g
.71505 .31567 m
.71505 .34639 L
.71505 .34639 L
.71505 .31567 L
.71505 .31567 L
F
.71505 .31567 m
.71505 .34639 L
.71505 .34639 L
.71505 .31567 L
.71505 .31567 L
F
.71505 .31567 m
.71505 .34639 L
.71505 .34639 L
.71505 .31567 L
.71505 .31567 L
F
.71505 .31567 m
.71505 .34639 L
.71505 .34639 L
.71505 .31567 L
.71505 .31567 L
F
.71505 .31567 m
.71505 .34639 L
.71505 .34639 L
.71505 .31567 L
.71505 .31567 L
F
.71505 .31567 m
.71505 .34639 L
.71505 .34639 L
.71505 .31567 L
.71505 .31567 L
F
0 g
.71505 .31567 m
.71505 .31567 L
.71505 .31567 L
.71505 .31567 L
.71505 .31567 L
.71505 .31567 L
.71505 .31567 L
.71505 .34639 L
.71505 .34639 L
.71505 .34639 L
.71505 .34639 L
.71505 .34639 L
.71505 .34639 L
.71505 .34639 L
.71505 .31567 L
s
.5 g
.71505 .31567 m
.68945 .31566 L
.69032 .31566 L
.71505 .31567 L
.71505 .31567 L
F
.68945 .31566 m
.66385 .31566 L
.6656 .31566 L
.69032 .31566 L
.68945 .31566 L
F
.66385 .31566 m
.63825 .31565 L
.64087 .31566 L
.6656 .31566 L
.66385 .31566 L
F
.71505 .31567 m
.69032 .31566 L
.69288 .31566 L
.71505 .31567 L
.71505 .31567 L
F
.69032 .31566 m
.6656 .31566 L
.67071 .31566 L
.69288 .31566 L
.69032 .31566 L
F
.6656 .31566 m
.64087 .31566 L
.64854 .31566 L
.67071 .31566 L
.6656 .31566 L
F
.71505 .31567 m
.69288 .31566 L
.69695 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.69288 .31566 m
.67071 .31566 L
.67885 .31566 L
.69695 .31567 L
.69288 .31566 L
F
.67071 .31566 m
.64854 .31566 L
.66074 .31566 L
.67885 .31566 L
.67071 .31566 L
F
.71505 .31567 m
.69695 .31567 L
.70225 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.69695 .31567 m
.67885 .31566 L
.68945 .31566 L
.70225 .31567 L
.69695 .31567 L
F
.67885 .31566 m
.66074 .31566 L
.67665 .31566 L
.68945 .31566 L
.67885 .31566 L
F
.71505 .31567 m
.70225 .31567 L
.70843 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.70225 .31567 m
.68945 .31566 L
.7018 .31567 L
.70843 .31567 L
.70225 .31567 L
F
.68945 .31566 m
.67665 .31566 L
.69518 .31566 L
.7018 .31567 L
.68945 .31566 L
F
.71505 .31567 m
.70843 .31567 L
.71505 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.70843 .31567 m
.7018 .31567 L
.71505 .31567 L
.71505 .31567 L
.70843 .31567 L
F
.7018 .31567 m
.69518 .31566 L
.71505 .31567 L
.71505 .31567 L
.7018 .31567 L
F
.71505 .31567 m
.71505 .31567 L
.72168 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.71505 .31567 m
.71505 .31567 L
.72831 .31567 L
.72168 .31567 L
.71505 .31567 L
F
.71505 .31567 m
.71505 .31567 L
.73493 .31567 L
.72831 .31567 L
.71505 .31567 L
F
.71505 .31567 m
.72168 .31567 L
.72785 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.72168 .31567 m
.72831 .31567 L
.74066 .31567 L
.72785 .31567 L
.72168 .31567 L
F
.72831 .31567 m
.73493 .31567 L
.75346 .31567 L
.74066 .31567 L
.72831 .31567 L
F
.71505 .31567 m
.72785 .31567 L
.73316 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.72785 .31567 m
.74066 .31567 L
.75126 .31567 L
.73316 .31567 L
.72785 .31567 L
F
.74066 .31567 m
.75346 .31567 L
.76936 .31568 L
.75126 .31567 L
.74066 .31567 L
F
.71505 .31567 m
.73316 .31567 L
.73723 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.73316 .31567 m
.75126 .31567 L
.7594 .31568 L
.73723 .31567 L
.73316 .31567 L
F
.75126 .31567 m
.76936 .31568 L
.78157 .31568 L
.7594 .31568 L
.75126 .31567 L
F
.71505 .31567 m
.73723 .31567 L
.73978 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.73723 .31567 m
.7594 .31568 L
.76451 .31568 L
.73978 .31567 L
.73723 .31567 L
F
.7594 .31568 m
.78157 .31568 L
.78924 .31568 L
.76451 .31568 L
.7594 .31568 L
F
.71505 .31567 m
.73978 .31567 L
.74066 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.73978 .31567 m
.76451 .31568 L
.76626 .31568 L
.74066 .31567 L
.73978 .31567 L
F
.76451 .31568 m
.78924 .31568 L
.79186 .31568 L
.76626 .31568 L
.76451 .31568 L
F
.71505 .31567 m
.74066 .31567 L
.73978 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.74066 .31567 m
.76626 .31568 L
.76451 .31568 L
.73978 .31567 L
.74066 .31567 L
F
.76626 .31568 m
.79186 .31568 L
.78924 .31568 L
.76451 .31568 L
.76626 .31568 L
F
.71505 .31567 m
.73978 .31567 L
.73723 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.73978 .31567 m
.76451 .31568 L
.7594 .31568 L
.73723 .31567 L
.73978 .31567 L
F
.76451 .31568 m
.78924 .31568 L
.78157 .31568 L
.7594 .31568 L
.76451 .31568 L
F
.71505 .31567 m
.73723 .31567 L
.73316 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.73723 .31567 m
.7594 .31568 L
.75126 .31567 L
.73316 .31567 L
.73723 .31567 L
F
.7594 .31568 m
.78157 .31568 L
.76936 .31568 L
.75126 .31567 L
.7594 .31568 L
F
.71505 .31567 m
.73316 .31567 L
.72785 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.73316 .31567 m
.75126 .31567 L
.74066 .31567 L
.72785 .31567 L
.73316 .31567 L
F
.75126 .31567 m
.76936 .31568 L
.75346 .31567 L
.74066 .31567 L
.75126 .31567 L
F
.71505 .31567 m
.72785 .31567 L
.72168 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.72785 .31567 m
.74066 .31567 L
.72831 .31567 L
.72168 .31567 L
.72785 .31567 L
F
.74066 .31567 m
.75346 .31567 L
.73493 .31567 L
.72831 .31567 L
.74066 .31567 L
F
.71505 .31567 m
.72168 .31567 L
.71505 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.72168 .31567 m
.72831 .31567 L
.71505 .31567 L
.71505 .31567 L
.72168 .31567 L
F
.72831 .31567 m
.73493 .31567 L
.71505 .31567 L
.71505 .31567 L
.72831 .31567 L
F
.71505 .31567 m
.71505 .31567 L
.70843 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.71505 .31567 m
.71505 .31567 L
.7018 .31567 L
.70843 .31567 L
.71505 .31567 L
F
.71505 .31567 m
.71505 .31567 L
.69518 .31566 L
.7018 .31567 L
.71505 .31567 L
F
.71505 .31567 m
.70843 .31567 L
.70225 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.70843 .31567 m
.7018 .31567 L
.68945 .31566 L
.70225 .31567 L
.70843 .31567 L
F
.7018 .31567 m
.69518 .31566 L
.67665 .31566 L
.68945 .31566 L
.7018 .31567 L
F
.71505 .31567 m
.70225 .31567 L
.69695 .31567 L
.71505 .31567 L
.71505 .31567 L
F
.70225 .31567 m
.68945 .31566 L
.67885 .31566 L
.69695 .31567 L
.70225 .31567 L
F
.68945 .31566 m
.67665 .31566 L
.66074 .31566 L
.67885 .31566 L
.68945 .31566 L
F
.71505 .31567 m
.69695 .31567 L
.69288 .31566 L
.71505 .31567 L
.71505 .31567 L
F
.69695 .31567 m
.67885 .31566 L
.67071 .31566 L
.69288 .31566 L
.69695 .31567 L
F
.67885 .31566 m
.66074 .31566 L
.64854 .31566 L
.67071 .31566 L
.67885 .31566 L
F
.71505 .31567 m
.69288 .31566 L
.69032 .31566 L
.71505 .31567 L
.71505 .31567 L
F
.69288 .31566 m
.67071 .31566 L
.6656 .31566 L
.69032 .31566 L
.69288 .31566 L
F
.67071 .31566 m
.64854 .31566 L
.64087 .31566 L
.6656 .31566 L
.67071 .31566 L
F
.71505 .31567 m
.69032 .31566 L
.68945 .31566 L
.71505 .31567 L
.71505 .31567 L
F
.69032 .31566 m
.6656 .31566 L
.66385 .31566 L
.68945 .31566 L
.69032 .31566 L
F
.6656 .31566 m
.64087 .31566 L
.63825 .31565 L
.66385 .31566 L
.6656 .31566 L
F
0 g
.63825 .31565 m
.64087 .31566 L
.64854 .31566 L
.66074 .31566 L
.67665 .31566 L
.69518 .31566 L
.71505 .31567 L
.73493 .31567 L
.75346 .31567 L
.76936 .31568 L
.78157 .31568 L
.78924 .31568 L
.79186 .31568 L
.78924 .31568 L
.78157 .31568 L
.76936 .31568 L
.75346 .31567 L
.73493 .31567 L
.71505 .31567 L
.69518 .31566 L
.67665 .31566 L
.66074 .31566 L
.64854 .31566 L
.64087 .31566 L
.63825 .31565 L
s
.63824 .34638 m
.64086 .34638 L
.64853 .34638 L
.66074 .34638 L
.67665 .34638 L
.69517 .34639 L
.71505 .34639 L
.73493 .34639 L
.75345 .3464 L
.76936 .3464 L
.78156 .3464 L
.78924 .3464 L
.79185 .3464 L
.78924 .3464 L
.78156 .3464 L
.76936 .3464 L
.75345 .3464 L
.73493 .34639 L
.71505 .34639 L
.69517 .34639 L
.67665 .34638 L
.66074 .34638 L
.64853 .34638 L
.64086 .34638 L
.63824 .34638 L
s
.63825 .31565 m
.63824 .34638 L
.64086 .34638 L
.64087 .31566 L
.63825 .31565 L
s
.64087 .31566 m
.64086 .34638 L
.64853 .34638 L
.64854 .31566 L
.64087 .31566 L
s
.64854 .31566 m
.64853 .34638 L
.66074 .34638 L
.66074 .31566 L
.64854 .31566 L
s
.66074 .31566 m
.66074 .34638 L
.67665 .34638 L
.67665 .31566 L
.66074 .31566 L
s
.67665 .31566 m
.67665 .34638 L
.69517 .34639 L
.69518 .31566 L
.67665 .31566 L
s
.69518 .31566 m
.69517 .34639 L
.71505 .34639 L
.71505 .31567 L
.69518 .31566 L
s
.71505 .31567 m
.71505 .34639 L
.73493 .34639 L
.73493 .31567 L
.71505 .31567 L
s
.73493 .31567 m
.73493 .34639 L
.75345 .3464 L
.75346 .31567 L
.73493 .31567 L
s
.75346 .31567 m
.75345 .3464 L
.76936 .3464 L
.76936 .31568 L
.75346 .31567 L
s
.76936 .31568 m
.76936 .3464 L
.78156 .3464 L
.78157 .31568 L
.76936 .31568 L
s
.78157 .31568 m
.78156 .3464 L
.78924 .3464 L
.78924 .31568 L
.78157 .31568 L
s
.78924 .31568 m
.78924 .3464 L
.79185 .3464 L
.79186 .31568 L
.78924 .31568 L
s
.79186 .31568 m
.79185 .3464 L
.78924 .3464 L
.78924 .31568 L
.79186 .31568 L
s
.78924 .31568 m
.78924 .3464 L
.78156 .3464 L
.78157 .31568 L
.78924 .31568 L
s
.78157 .31568 m
.78156 .3464 L
.76936 .3464 L
.76936 .31568 L
.78157 .31568 L
s
.76936 .31568 m
.76936 .3464 L
.75345 .3464 L
.75346 .31567 L
.76936 .31568 L
s
.75346 .31567 m
.75345 .3464 L
.73493 .34639 L
.73493 .31567 L
.75346 .31567 L
s
.73493 .31567 m
.73493 .34639 L
.71505 .34639 L
.71505 .31567 L
.73493 .31567 L
s
.71505 .31567 m
.71505 .34639 L
.69517 .34639 L
.69518 .31566 L
.71505 .31567 L
s
.69518 .31566 m
.69517 .34639 L
.67665 .34638 L
.67665 .31566 L
.69518 .31566 L
s
.67665 .31566 m
.67665 .34638 L
.66074 .34638 L
.66074 .31566 L
.67665 .31566 L
s
.66074 .31566 m
.66074 .34638 L
.64853 .34638 L
.64854 .31566 L
.66074 .31566 L
s
.64854 .31566 m
.64853 .34638 L
.64086 .34638 L
.64087 .31566 L
.64854 .31566 L
s
.64087 .31566 m
.64086 .34638 L
.63824 .34638 L
.63825 .31565 L
.64087 .31566 L
s
.5 g
.66074 .10775 m
.68247 .08603 L
.70057 .10413 L
.67885 .12585 L
.66074 .10775 L
F
.67885 .12585 m
.70057 .10413 L
.71867 .12223 L
.69695 .14396 L
.67885 .12585 L
F
.69695 .14396 m
.71867 .12223 L
.73678 .14033 L
.71505 .16206 L
.69695 .14396 L
F
.71505 .16206 m
.73678 .14033 L
.75488 .15844 L
.73316 .18016 L
.71505 .16206 L
F
.73316 .18016 m
.75488 .15844 L
.77298 .17654 L
.75126 .19826 L
.73316 .18016 L
F
.75126 .19826 m
.77298 .17654 L
.79109 .19464 L
.76936 .21637 L
.75126 .19826 L
F
0 g
.66074 .10775 m
.67885 .12585 L
.69695 .14396 L
.71505 .16206 L
.73316 .18016 L
.75126 .19826 L
.76936 .21637 L
.79109 .19464 L
.77298 .17654 L
.75488 .15844 L
.73678 .14033 L
.71867 .12223 L
.70057 .10413 L
.68247 .08603 L
.66074 .10775 L
s
.5 g
.71505 .16206 m
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
.71505 .16206 L
F
0 g
.71505 .16206 m
.71505 .16206 L
.71505 .16206 L
.71505 .16206 L
.71505 .16206 L
.71505 .16206 L
.71505 .16206 L
.73678 .14033 L
.73678 .14033 L
.73678 .14033 L
.73678 .14033 L
.73678 .14033 L
.73678 .14033 L
.73678 .14033 L
.71505 .16206 L
s
.5 g
.71505 .16206 m
.73316 .18016 L
.73254 .17954 L
.71505 .16206 L
.71505 .16206 L
F
.73316 .18016 m
.75126 .19826 L
.75003 .19703 L
.73254 .17954 L
.73316 .18016 L
F
.75126 .19826 m
.76936 .21637 L
.76751 .21452 L
.75003 .19703 L
.75126 .19826 L
F
.71505 .16206 m
.73254 .17954 L
.73073 .17774 L
.71505 .16206 L
.71505 .16206 L
F
.73254 .17954 m
.75003 .19703 L
.74641 .19341 L
.73073 .17774 L
.73254 .17954 L
F
.75003 .19703 m
.76751 .21452 L
.76209 .20909 L
.74641 .19341 L
.75003 .19703 L
F
.71505 .16206 m
.73073 .17774 L
.72785 .17486 L
.71505 .16206 L
.71505 .16206 L
F
.73073 .17774 m
.74641 .19341 L
.74066 .18766 L
.72785 .17486 L
.73073 .17774 L
F
.74641 .19341 m
.76209 .20909 L
.75346 .20046 L
.74066 .18766 L
.74641 .19341 L
F
.71505 .16206 m
.72785 .17486 L
.72411 .17111 L
.71505 .16206 L
.71505 .16206 L
F
.72785 .17486 m
.74066 .18766 L
.73316 .18016 L
.72411 .17111 L
.72785 .17486 L
F
.74066 .18766 m
.75346 .20046 L
.74221 .18921 L
.73316 .18016 L
.74066 .18766 L
F
.71505 .16206 m
.72411 .17111 L
.71974 .16674 L
.71505 .16206 L
.71505 .16206 L
F
.72411 .17111 m
.73316 .18016 L
.72442 .17143 L
.71974 .16674 L
.72411 .17111 L
F
.73316 .18016 m
.74221 .18921 L
.72911 .17611 L
.72442 .17143 L
.73316 .18016 L
F
.71505 .16206 m
.71974 .16674 L
.71505 .16206 L
.71505 .16206 L
.71505 .16206 L
F
.71974 .16674 m
.72442 .17143 L
.71505 .16206 L
.71505 .16206 L
.71974 .16674 L
F
.72442 .17143 m
.72911 .17611 L
.71505 .16206 L
.71505 .16206 L
.72442 .17143 L
F
.71505 .16206 m
.71505 .16206 L
.71037 .15737 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.71505 .16206 L
.70568 .15269 L
.71037 .15737 L
.71505 .16206 L
F
.71505 .16206 m
.71505 .16206 L
.701 .148 L
.70568 .15269 L
.71505 .16206 L
F
.71505 .16206 m
.71037 .15737 L
.706 .15301 L
.71505 .16206 L
.71505 .16206 L
F
.71037 .15737 m
.70568 .15269 L
.69695 .14396 L
.706 .15301 L
.71037 .15737 L
F
.70568 .15269 m
.701 .148 L
.6879 .1349 L
.69695 .14396 L
.70568 .15269 L
F
.71505 .16206 m
.706 .15301 L
.70225 .14926 L
.71505 .16206 L
.71505 .16206 L
F
.706 .15301 m
.69695 .14396 L
.68945 .13646 L
.70225 .14926 L
.706 .15301 L
F
.69695 .14396 m
.6879 .1349 L
.67665 .12366 L
.68945 .13646 L
.69695 .14396 L
F
.71505 .16206 m
.70225 .14926 L
.69938 .14638 L
.71505 .16206 L
.71505 .16206 L
F
.70225 .14926 m
.68945 .13646 L
.6837 .1307 L
.69938 .14638 L
.70225 .14926 L
F
.68945 .13646 m
.67665 .12366 L
.66802 .11503 L
.6837 .1307 L
.68945 .13646 L
F
.71505 .16206 m
.69938 .14638 L
.69757 .14457 L
.71505 .16206 L
.71505 .16206 L
F
.69938 .14638 m
.6837 .1307 L
.68008 .12709 L
.69757 .14457 L
.69938 .14638 L
F
.6837 .1307 m
.66802 .11503 L
.6626 .1096 L
.68008 .12709 L
.6837 .1307 L
F
.71505 .16206 m
.69757 .14457 L
.69695 .14396 L
.71505 .16206 L
.71505 .16206 L
F
.69757 .14457 m
.68008 .12709 L
.67885 .12585 L
.69695 .14396 L
.69757 .14457 L
F
.68008 .12709 m
.6626 .1096 L
.66074 .10775 L
.67885 .12585 L
.68008 .12709 L
F
.71505 .16206 m
.69695 .14396 L
.69757 .14457 L
.71505 .16206 L
.71505 .16206 L
F
.69695 .14396 m
.67885 .12585 L
.68008 .12709 L
.69757 .14457 L
.69695 .14396 L
F
.67885 .12585 m
.66074 .10775 L
.6626 .1096 L
.68008 .12709 L
.67885 .12585 L
F
.71505 .16206 m
.69757 .14457 L
.69938 .14638 L
.71505 .16206 L
.71505 .16206 L
F
.69757 .14457 m
.68008 .12709 L
.6837 .1307 L
.69938 .14638 L
.69757 .14457 L
F
.68008 .12709 m
.6626 .1096 L
.66802 .11503 L
.6837 .1307 L
.68008 .12709 L
F
.71505 .16206 m
.69938 .14638 L
.70225 .14926 L
.71505 .16206 L
.71505 .16206 L
F
.69938 .14638 m
.6837 .1307 L
.68945 .13646 L
.70225 .14926 L
.69938 .14638 L
F
.6837 .1307 m
.66802 .11503 L
.67665 .12366 L
.68945 .13646 L
.6837 .1307 L
F
.71505 .16206 m
.70225 .14926 L
.706 .15301 L
.71505 .16206 L
.71505 .16206 L
F
.70225 .14926 m
.68945 .13646 L
.69695 .14396 L
.706 .15301 L
.70225 .14926 L
F
.68945 .13646 m
.67665 .12366 L
.6879 .1349 L
.69695 .14396 L
.68945 .13646 L
F
.71505 .16206 m
.706 .15301 L
.71037 .15737 L
.71505 .16206 L
.71505 .16206 L
F
.706 .15301 m
.69695 .14396 L
.70568 .15269 L
.71037 .15737 L
.706 .15301 L
F
.69695 .14396 m
.6879 .1349 L
.701 .148 L
.70568 .15269 L
.69695 .14396 L
F
.71505 .16206 m
.71037 .15737 L
.71505 .16206 L
.71505 .16206 L
.71505 .16206 L
F
.71037 .15737 m
.70568 .15269 L
.71505 .16206 L
.71505 .16206 L
.71037 .15737 L
F
.70568 .15269 m
.701 .148 L
.71505 .16206 L
.71505 .16206 L
.70568 .15269 L
F
.71505 .16206 m
.71505 .16206 L
.71974 .16674 L
.71505 .16206 L
.71505 .16206 L
F
.71505 .16206 m
.71505 .16206 L
.72442 .17143 L
.71974 .16674 L
.71505 .16206 L
F
.71505 .16206 m
.71505 .16206 L
.72911 .17611 L
.72442 .17143 L
.71505 .16206 L
F
.71505 .16206 m
.71974 .16674 L
.72411 .17111 L
.71505 .16206 L
.71505 .16206 L
F
.71974 .16674 m
.72442 .17143 L
.73316 .18016 L
.72411 .17111 L
.71974 .16674 L
F
.72442 .17143 m
.72911 .17611 L
.74221 .18921 L
.73316 .18016 L
.72442 .17143 L
F
.71505 .16206 m
.72411 .17111 L
.72785 .17486 L
.71505 .16206 L
.71505 .16206 L
F
.72411 .17111 m
.73316 .18016 L
.74066 .18766 L
.72785 .17486 L
.72411 .17111 L
F
.73316 .18016 m
.74221 .18921 L
.75346 .20046 L
.74066 .18766 L
.73316 .18016 L
F
.71505 .16206 m
.72785 .17486 L
.73073 .17774 L
.71505 .16206 L
.71505 .16206 L
F
.72785 .17486 m
.74066 .18766 L
.74641 .19341 L
.73073 .17774 L
.72785 .17486 L
F
.74066 .18766 m
.75346 .20046 L
.76209 .20909 L
.74641 .19341 L
.74066 .18766 L
F
.71505 .16206 m
.73073 .17774 L
.73254 .17954 L
.71505 .16206 L
.71505 .16206 L
F
.73073 .17774 m
.74641 .19341 L
.75003 .19703 L
.73254 .17954 L
.73073 .17774 L
F
.74641 .19341 m
.76209 .20909 L
.76751 .21452 L
.75003 .19703 L
.74641 .19341 L
F
.71505 .16206 m
.73254 .17954 L
.73316 .18016 L
.71505 .16206 L
.71505 .16206 L
F
.73254 .17954 m
.75003 .19703 L
.75126 .19826 L
.73316 .18016 L
.73254 .17954 L
F
.75003 .19703 m
.76751 .21452 L
.76936 .21637 L
.75126 .19826 L
.75003 .19703 L
F
0 g
.76936 .21637 m
.76751 .21452 L
.76209 .20909 L
.75346 .20046 L
.74221 .18921 L
.72911 .17611 L
.71505 .16206 L
.701 .148 L
.6879 .1349 L
.67665 .12366 L
.66802 .11503 L
.6626 .1096 L
.66074 .10775 L
.6626 .1096 L
.66802 .11503 L
.67665 .12366 L
.6879 .1349 L
.701 .148 L
.71505 .16206 L
.72911 .17611 L
.74221 .18921 L
.75346 .20046 L
.76209 .20909 L
.76751 .21452 L
.76936 .21637 L
s
.76936 .21637 m
.79109 .19464 L
.78924 .19279 L
.76751 .21452 L
.76936 .21637 L
s
.76751 .21452 m
.78924 .19279 L
.78381 .18737 L
.76209 .20909 L
.76751 .21452 L
s
.76209 .20909 m
.78381 .18737 L
.77518 .17874 L
.75346 .20046 L
.76209 .20909 L
s
.75346 .20046 m
.77518 .17874 L
.76393 .16749 L
.74221 .18921 L
.75346 .20046 L
s
.74221 .18921 m
.76393 .16749 L
.75083 .15439 L
.72911 .17611 L
.74221 .18921 L
s
.72911 .17611 m
.75083 .15439 L
.73678 .14033 L
.71505 .16206 L
.72911 .17611 L
s
.71505 .16206 m
.73678 .14033 L
.72272 .12628 L
.701 .148 L
.71505 .16206 L
s
.701 .148 m
.72272 .12628 L
.70962 .11318 L
.6879 .1349 L
.701 .148 L
s
.6879 .1349 m
.70962 .11318 L
.69838 .10193 L
.67665 .12366 L
.6879 .1349 L
s
.67665 .12366 m
.69838 .10193 L
.68974 .0933 L
.66802 .11503 L
.67665 .12366 L
s
.66802 .11503 m
.68974 .0933 L
.68432 .08788 L
.6626 .1096 L
.66802 .11503 L
s
.6626 .1096 m
.68432 .08788 L
.68247 .08603 L
.66074 .10775 L
.6626 .1096 L
s
.66074 .10775 m
.68247 .08603 L
.68432 .08788 L
.6626 .1096 L
.66074 .10775 L
s
.6626 .1096 m
.68432 .08788 L
.68974 .0933 L
.66802 .11503 L
.6626 .1096 L
s
.66802 .11503 m
.68974 .0933 L
.69838 .10193 L
.67665 .12366 L
.66802 .11503 L
s
.67665 .12366 m
.69838 .10193 L
.70962 .11318 L
.6879 .1349 L
.67665 .12366 L
s
.6879 .1349 m
.70962 .11318 L
.72272 .12628 L
.701 .148 L
.6879 .1349 L
s
.701 .148 m
.72272 .12628 L
.73678 .14033 L
.71505 .16206 L
.701 .148 L
s
.71505 .16206 m
.73678 .14033 L
.75083 .15439 L
.72911 .17611 L
.71505 .16206 L
s
.72911 .17611 m
.75083 .15439 L
.76393 .16749 L
.74221 .18921 L
.72911 .17611 L
s
.74221 .18921 m
.76393 .16749 L
.77518 .17874 L
.75346 .20046 L
.74221 .18921 L
s
.75346 .20046 m
.77518 .17874 L
.78381 .18737 L
.76209 .20909 L
.75346 .20046 L
s
.76209 .20909 m
.78381 .18737 L
.78924 .19279 L
.76751 .21452 L
.76209 .20909 L
s
.76751 .21452 m
.78924 .19279 L
.79109 .19464 L
.76936 .21637 L
.76751 .21452 L
s
.79186 .00845 m
.76626 .00845 L
.74066 .00845 L
.71505 .00845 L
.68945 .00845 L
.66385 .00845 L
.63825 .00845 L
.63825 .00845 L
.66385 .00845 L
.68945 .00845 L
.71505 .00845 L
.74066 .00845 L
.76626 .00845 L
.79186 .00845 L
.79186 .00845 L
s
.71505 .00845 m
.71505 .00845 L
.71505 .00845 L
.71505 .00845 L
.71505 .00845 L
.71505 .00845 L
.71505 .00845 L
.71505 .00845 L
.71505 .00845 L
.71505 .00845 L
.71505 .00845 L
.71505 .00845 L
.71505 .00845 L
.71505 .00845 L
.71505 .00845 L
s
.63825 .00845 m
.64087 .00845 L
.64854 .00845 L
.66074 .00845 L
.67665 .00845 L
.69518 .00845 L
.71505 .00845 L
.73493 .00845 L
.75346 .00845 L
.76936 .00845 L
.78157 .00845 L
.78924 .00845 L
.79186 .00845 L
.78924 .00845 L
.78157 .00845 L
.76936 .00845 L
.75346 .00845 L
.73493 .00845 L
.71505 .00845 L
.69518 .00845 L
.67665 .00845 L
.66074 .00845 L
.64854 .00845 L
.64087 .00845 L
.63825 .00845 L
s
.039 .916 .04 r
.02381 .15745 m
.17742 .15738 L
s
% Start of user PostScript
-50.0004 -1.5 0 -1.52435 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.17742 .15738 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16206 m
.17742 .16206 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.17742 .16206 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16667 m
.17742 .16674 L
s
% Start of user PostScript
-50.0004 1.5 0 1.52435 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.17742 .16674 Mdot
.039 .916 .04 r
.5 Mabswid
.17742 .15738 m
.18379 .15737 L
s
% Start of user PostScript
0 -1.52435 2.07491 -1.52502 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.18379 .15737 Mdot
.039 .916 .04 r
.5 Mabswid
.17742 .16206 m
.18356 .16206 L
s
% Start of user PostScript
0 0 2. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.18356 .16206 Mdot
.039 .916 .04 r
.5 Mabswid
.17742 .16674 m
.18379 .16674 L
s
% Start of user PostScript
0 1.52435 2.07491 1.52502 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.18379 .16674 Mdot
.039 .916 .04 r
.5 Mabswid
.18379 .15737 m
.57804 .13695 L
s
% Start of user PostScript
2.07491 -1.52502 130.403 -8.17268 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57804 .13695 Mdot
.039 .916 .04 r
.5 Mabswid
.18356 .16206 m
.57681 .16206 L
s
% Start of user PostScript
2. 0 130. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57681 .16206 Mdot
.039 .916 .04 r
.5 Mabswid
.18379 .16674 m
.57804 .18717 L
s
% Start of user PostScript
2.07491 1.52502 130.403 8.17268 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.57804 .18717 Mdot
.039 .916 .04 r
.5 Mabswid
.57804 .13695 m
.59677 .13695 L
s
% Start of user PostScript
130.403 -8.17268 136.5 -8.17364 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59677 .13695 Mdot
.039 .916 .04 r
.5 Mabswid
.57681 .16206 m
.59677 .16206 L
s
% Start of user PostScript
130. 0 136.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59677 .16206 Mdot
.039 .916 .04 r
.5 Mabswid
.57804 .18717 m
.59677 .18717 L
s
% Start of user PostScript
130.403 8.17268 136.5 8.17364 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.59677 .18717 Mdot
.039 .916 .04 r
.5 Mabswid
.59677 .13695 m
.68992 .13693 L
s
% Start of user PostScript
136.5 -8.17364 166.819 -8.18083 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68992 .13693 Mdot
.039 .916 .04 r
.5 Mabswid
.59677 .16206 m
.71505 .16206 L
s
% Start of user PostScript
136.5 0 175. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.71505 .16206 Mdot
.039 .916 .04 r
.5 Mabswid
.59677 .18717 m
.7402 .1872 L
s
% Start of user PostScript
136.5 8.17364 183.185 8.18472 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.7402 .1872 Mdot
.039 .916 .04 r
.5 Mabswid
.68992 .13693 m
.72307 .12662 L
s
% Start of user PostScript
166.819 -8.18083 177.608 -11.534 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.72307 .12662 Mdot
.039 .916 .04 r
.5 Mabswid
.68992 .13693 m
.68988 .31566 L
s
% Start of user PostScript
166.819 -8.18083 166.805 49.9986 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68988 .31566 Mdot
.039 .916 .04 r
.5 Mabswid
.71505 .16206 m
.7482 .15176 L
s
% Start of user PostScript
175. 0 185.79 -3.35208 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.7482 .15176 Mdot
.039 .916 .04 r
.5 Mabswid
.71505 .16206 m
.71505 .31567 L
s
% Start of user PostScript
175. 0 175. 50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.71505 .31567 Mdot
.039 .916 .04 r
.5 Mabswid
.7402 .1872 m
.77335 .17691 L
s
% Start of user PostScript
183.185 8.18472 193.976 4.83377 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.77335 .17691 Mdot
.039 .916 .04 r
.5 Mabswid
.7402 .1872 m
.74023 .31567 L
s
% Start of user PostScript
183.185 8.18472 183.195 50.0014 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.74023 .31567 Mdot
.039 .916 .04 r
.5 Mabswid
.72307 .12662 m
.94547 .12657 L
s
% Start of user PostScript
177.608 -11.534 250. -11.5512 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.94547 .12657 Mdot
.039 .916 .04 r
.5 Mabswid
.68988 .31566 m
.6899 .1369 L
s
% Start of user PostScript
166.805 49.9986 166.812 -8.18815 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6899 .1369 Mdot
.039 .916 .04 r
.5 Mabswid
.7482 .15176 m
.94547 .15176 L
s
% Start of user PostScript
185.79 -3.35208 250. -3.35208 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.94547 .15176 Mdot
.039 .916 .04 r
.5 Mabswid
.71505 .31567 m
.71511 .16211 L
s
% Start of user PostScript
175. 50. 175.017 0.0174472 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.71511 .16211 Mdot
.039 .916 .04 r
.5 Mabswid
.77335 .17691 m
.94547 .17695 L
s
% Start of user PostScript
193.976 4.83377 250. 4.84707 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.94547 .17695 Mdot
.039 .916 .04 r
.5 Mabswid
.74023 .31567 m
.7403 .18731 L
s
% Start of user PostScript
183.195 50.0014 183.219 8.21915 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.7403 .18731 Mdot
.039 .916 .04 r
.5 Mabswid
.94547 .12657 m
.72296 .12652 L
s
% Start of user PostScript
250. -11.5512 177.574 -11.5684 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.72296 .12652 Mdot
.039 .916 .04 r
.5 Mabswid
.6899 .1369 m
.7002 .10376 L
s
% Start of user PostScript
166.812 -8.18815 170.164 -18.9777 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.7002 .10376 Mdot
.039 .916 .04 r
.5 Mabswid
.94547 .15176 m
.7482 .15176 L
s
% Start of user PostScript
250. -3.35208 185.79 -3.35208 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.7482 .15176 Mdot
.039 .916 .04 r
.5 Mabswid
.71511 .16211 m
.72541 .12897 L
s
% Start of user PostScript
175.017 0.0174472 178.371 -10.7709 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.72541 .12897 Mdot
.039 .916 .04 r
.5 Mabswid
.94547 .17695 m
.77343 .17699 L
s
% Start of user PostScript
250. 4.84707 194.002 4.86036 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.77343 .17699 Mdot
.039 .916 .04 r
.5 Mabswid
.7403 .18731 m
.75061 .15417 L
s
% Start of user PostScript
183.219 8.21915 186.574 -2.56812 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.75061 .15417 Mdot
.039 .916 .04 r
.5 Mabswid
.72296 .12652 m
.68981 .13681 L
s
% Start of user PostScript
177.574 -11.5684 166.783 -8.21747 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68981 .13681 Mdot
.039 .916 .04 r
.5 Mabswid
.7002 .10376 m
.70021 .00845 L
s
% Start of user PostScript
170.164 -18.9777 170.168 -50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70021 .00845 Mdot
.039 .916 .04 r
.5 Mabswid
.7482 .15176 m
.71505 .16206 L
s
% Start of user PostScript
185.79 -3.35208 175. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.71505 .16206 Mdot
.039 .916 .04 r
.5 Mabswid
.72541 .12897 m
.72545 .00845 L
s
% Start of user PostScript
178.371 -10.7709 178.385 -50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.72545 .00845 Mdot
.039 .916 .04 r
.5 Mabswid
.77343 .17699 m
.74029 .18729 L
s
% Start of user PostScript
194.002 4.86036 183.214 8.21357 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.74029 .18729 Mdot
.039 .916 .04 r
.5 Mabswid
.75061 .15417 m
.7507 .00845 L
s
% Start of user PostScript
186.574 -2.56812 186.602 -50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.7507 .00845 Mdot
.039 .916 .04 r
.5 Mabswid
.68981 .13681 m
.7001 .10366 L
s
% Start of user PostScript
166.783 -8.21747 170.133 -19.0087 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.7001 .10366 Mdot
.039 .916 .04 r
.5 Mabswid
.71505 .16206 m
.72535 .12891 L
s
% Start of user PostScript
175. 0 178.352 -10.7901 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.72535 .12891 Mdot
.039 .916 .04 r
.5 Mabswid
.74029 .18729 m
.75059 .15415 L
s
% Start of user PostScript
183.214 8.21357 186.567 -2.57536 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.75059 .15415 Mdot
.039 .916 .04 r
.5 Mabswid
.7001 .10366 m
.70008 .00845 L
s
% Start of user PostScript
170.133 -19.0087 170.126 -50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70008 .00845 Mdot
.039 .916 .04 r
.5 Mabswid
.72535 .12891 m
.72535 .00845 L
s
% Start of user PostScript
178.352 -10.7901 178.352 -50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.72535 .00845 Mdot
.039 .916 .04 r
.5 Mabswid
.75059 .15415 m
.75062 .00845 L
s
% Start of user PostScript
186.567 -2.57536 186.578 -50. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.75062 .00845 Mdot
gsave
.81766 .33105 -69.9375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M2) show
76.875 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81767 .00845 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18049 .10553 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.96083 .05945 -69.9375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M1) show
76.875 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58679 .09017 -68.5312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L2) show
74.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.65336 .07864 -69.0625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(BS) show
75.125 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35485 L
0 .35485 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[542]:=",
  ImageSize->{419, 148.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006S0000U2000`400?l00000o`00003ooooooonT
ooooo`00oooooonTooooo`00oooooonTooooo`00oooooonTooooo`00oooooomBooooo`?o0000Cooo
ool00?oooooo8oooool2o`0000Sooooo0_l00008ooooo`;o00006Oooool01?l0003oooooooooool0
001>ooooo`00ooooool:oooood3o00002oooool00ol0003oooooooooo`1<ooooo`00oooooolSoooo
o`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`0Hoooo
o`;o0000Coooool00?oooooo8oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Oo
oooo00?o2NX:ooooooooool05oooool00ol0003oooooooooo`1?ooooo`00oooooolRooooo`?o2NX:
2?ooool3o`WZ2POooooo0ol9jPXHooooo`04o`000?ooooooooooo`0004kooooo003oooooob;ooooo
0ol9jPX8ooooo`?o2NX:1oooool3o`WZ2QWooooo0ol0001>ooooo`00oooooolRooooo`?o2NX:2?oo
ool3o`WZ2POooooo0ol9jPYZooooo`00oooooolRooooo`?o2NX:2?ooool3o`WZ2POooooo0ol9jPYZ
ooooo`00oooooolQooooo`Go2NX:1_ooool5o`WZ2PGooooo1Ol9jPYYooooo`00oooooolQooooo`05
o`WZ2_oooooo2NX:ooooool9jPX01_ooool01Ol9jP[oooooo`WZ2_oooooo2NX:00Gooooo00Go2NX:
ooooool9jP[oooooo`WZ2P1Yooooo`00oooooolSooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:
ooooooooool01oooool00ol9jP[oooooooooo`1Yooooo`00oooooolSooooo`03o`WZ2_oooooooooo
00Sooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`1Yooooo`00oooooolSooooo`03
o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`1Yooooo`00
oooooolSooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooo
ooooo`1Yooooo`00oooooolSooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01ooo
ool00ol9jP[oooooooooo`1Yooooo`00oooooolSooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:
ooooooooool01oooool00ol9jP[oooooooooo`1Yooooo`00oooooolSooooo`03o`WZ2_oooooooooo
00Sooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`1Yooooo`00oooooolSooooo`03
o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`1Yooooo`00
oooooolSooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooo
ooooo`1Yooooo`00oooooolSooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool01ooo
ool00ol9jP[oooooooooo`1Yooooo`00oooooolSooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:
ooooooooool01oooool00ol9jP[oooooooooo`1<ooooo`?o000000?oooooo`000?ooool00ol00000
1?oooooo0000o`000?l0000@ooooo`00oooooolSooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:
ooooooooool01oooool00ol9jP[oooooooooo`1=ooooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooooooooooooooo`00000Aooooo`00oooooolSooooo`03o`WZ2_oooooooooo00Sooooo00?o
2NX:ooooooooool01oooool00ol9jP[oooooooooo`1=ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000003ooooo`03o`000?oooooooooo00oooooo003oooooob?ooooo00?o2NX:ooooooooool0
2?ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo04gooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000?ooooo00?o0000ooooooooool03oooool00?oooooo8oooool00ol9jP[o
ooooooooo`08ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool0COooool2o`0000?o
oooo0_l00003ooooo`03o`000?oooooooooo00oooooo003oooooob?ooooo00?o2NX:ooooooooool0
2?ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo04gooooo0_l00003ooooo`;o0000
0oooool00ol0003oooooooooo`0?ooooo`00oooooolSooooo`03o`WZ2_oooooooooo00Sooooo00?o
2NX:ooooooooool01oooool00ol9jP[oooooooooo`1<ooooo`;o00001Oooool2o`000003ooooool0
003o0000017ooooo003oooooob?ooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`07
ooooo`03o`WZ2_oooooooooo06Wooooo003oooooo`[ooooo1Ol00003ooooo`?o00003_ooool00ol9
jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool0JOooool00?oo
oooo2oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00003Oooool0
0ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool0JOooool0
0?oooooo2oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool02oooool0
0ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool0JOooool0
0?oooooo2oooool4o`0000Cooooo0_l0000>ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:oooo
ooooool01oooool00ol9jP[oooooooooo`1Yooooo`00k_ooool9o`0001?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00kooooo00?o2NX:ooooooooool02?ooool00ol9
jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo04gooooo3Ol0000?ooooo`00koooool01?l0003o
ooooooooooooool2o`0000;ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00001Oooool3o`0000Gooooo00?o2NX:ooooooooool02?oo
ool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo04gooooo3Ol0000?ooooo`00koooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo1Ol00004ooooo`?o00001?ooool0
0ol0003oOgmoo`000002o`0000Cooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`07
ooooo`03o`WZ2_oooooooooo04gooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0=
ooooo`00koooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ogmo
Ool000000_moOgl2o`0000?ooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`07oooo
o`03o`WZ2_oooooooooo04gooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0=oooo
o`00koooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000ogmoOol0
00000omoOgl3o`0000;ooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`07ooooo`03
o`WZ2_oooooooooo04gooooo3Ol0000?ooooo`00koooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooo000001oooooo00?o0000ogmoOol000000omoOgl01ol0003oOgmoogmoOomoOgoo0000oooo
ool9jPX02_ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo04gooooo00?o0000ogmo
OomoOgl02OmoOgl00ol0003oooooooooo`0=ooooo`00k_ooool3o`0000Cooooo00?o0000oooooooo
ool07Oooool00ol0003oOgmoo`000003ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000o`WZ2_oo
ool02Oooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo04gooooo00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oooooooooo`0=ooooo`00B?ooool6o`000004ooooool0003o0000o`000<;o
oooo00?o0000ogmoOol000000omoOgl00ol0003oOgmoogmoO`05ogmoO`03o`WZ2_l0003ooooo00So
oooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`1=ooooo`03o`000?moOgooOgmo00Wo
Ogmo00?o0000ooooooooool03Oooool004Wooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo0<3ooooo00?o0000ogmoOol000000omoOgl00ol0003oOgmoogmoO`05ogmoO`03
o`000?l9jP[o000000Wooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`1=ooooo`03
o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool03Oooool004Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2oooooo`03o`000?moOgoo000000?oOgmo00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oOgmoo`WZ2P02o`0000Sooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooo
ooooo`1=ooooo`go00003oooool004Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`30ooooo`05o`000?moOgooOgmoogmoOol000001omoOgl01Ol0003oOgmoo`WZ2_l9jP[oOgmo00;o
00001oooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo04gooooo00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oooooooooo`0=ooooo`00BOooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0<7ooooo00?o0000ogmoOol000001omoOgl00ol0003oOgmoogmoO`02o`WZ2P;oOgmo
0_l00006ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool0COooool00ol0003oOgmo
ogmoO`09ogmoO`03o`000?oooooooooo00gooooo0019ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0`_ooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?o2NX:0omo
Ogl2o`0000Gooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`1=ooooo`03o`000?mo
OgooOgmo00WoOgmo00?o0000ooooooooool03Oooool004Sooooo0ol00004ooooo`;o0000XOooool7
o`0001gooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`04o`WZ2P;oOgmo00Co0000
ogmoOomoOgoo00001?ooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo04gooooo00?o
0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0=ooooo`00l_ooool00ol0003oOgmoogmoO`03
ogmoO`03o`000?oooooooooo01cooooo00Go0000ogmoOomoOgooOgmoo`000003ogmoO`Co2NX:00?o
Ogmoo`000?moOgl00omoOgl01Ol0003ooooooooooooooooo2NX:00Wooooo00?o2NX:ooooooooool0
COooool00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00gooooo003booooo`Oo00007ooo
ool00ol0003oOgmoo`000003ogmoO`Go2NX:00?o0000ogmoOomoOgl01?moOgl01?l0003ooooooooo
ool9jPX4ooooo`?o2NX:0_ooool00ol9jP[oooooooooo`15ooooo`?o2NX:1Oooool00ol0003oOgmo
ogmoO`09ogmoO`03o`000?oooooooooo00gooooo003booooo`03o`000?moOgooOgmo00?oOgmo00?o
0000ooooooooool07_ooool00ol0003oOgmoogmoO`04ogmoO`03o`WZ2_moOgoo2NX:00OoOgmo0_l0
00000ooooooo2NX:o`WZ2P05o`WZ2P?ooooo00?o2NX:ooooooooool0A_ooool6o`WZ2P03ooooool0
003o000000_o00003oooool00?7ooooo0_l00005ogmoO`03o`000?oooooooooo01kooooo0_l00004
ogmoO`03o`WZ2_moOgoo000000;oOgmo0_l9jPX2ogmoOf3o2NX:2omoOgl00ol0003oooooooooo`0=
ooooo`00lOooool8o`00027ooooo0_l00003ogmoO`03o`WZ2_l0003oOgmo00Wo2NX:0_l000000ol9
jP[oooooo`WZ2P04o`WZ2P?ooooo00?o2NX:ooooooooool0A_ooool5o`WZ2P03ooooool0003o0000
00_oOgmo00?o0000ooooooooool03Oooool004gooooo2?l0002Kooooo`?o2NX:1OmoOgl00ol0003o
ooooooooo`0Kooooo`?o2NX:0_ooool2o`0000;oOgmo00?o2NX:ogmoOol9jPX02?l9jPX01?l0003o
Ogmoo`000?l00005ooooo`;o2NX:0_ooool00ol9jP[oooooooooo`15ooooo`;o2NX:1_ooool00ol0
003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00gooooo001=ooooo`So0000Toooool5o`WZ2PCo
oooo1_l9jPX00omoOgoo0000ooooo`0Mooooo`Ko2NX:00?o0000o`WZ2_l9jPX02?l9jPX01?moOgoo
0000ogmoOomoOgl2o`WZ2P03o`000?oooooooooo00Kooooo00?o2NX:ooooooooool0COooool00ol0
003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00gooooo001=ooooo`So0000T_oooolho`WZ2P03
o`000?l9jP[o2NX:00Go2NX:00CoOgmoo`000?moOgooOgmo0ol9jPX00omoOgoo0000ooooo`06oooo
o`03o`WZ2_oooooooooo04gooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0=oooo
o`00COooool00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooo0000083ooooo4_l9jPX3ooooo`Go
2NX:00?oooooo`000?l9jPX01?l9jPX4o`0001gooooo1Ol9jPX2ooooo`;o00001OmoOgl00ol9jP[o
Ogmoo`000002ogmoO`Co2NX:0_moOgl00ol0003oooooooooo`04ooooo`03o`WZ2_oooooooooo04go
oooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0=ooooo`00COooool8o`0006kooooo
4_l9jPXDooooo`?o2NX:1?ooool2o`WZ2P03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0
6oooool2o`WZ2PKooooo00?o2NX:ogmoOol000001OmoOgl01?l0003oOgmoogmoOomoOgl3o`WZ2PCo
Ogmo0_l00004ooooo`03o`WZ2_oooooooooo04gooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003o
ooooooooo`0=ooooo`00COooool01Ol0003oOgmoogmoOomoOgoo000000;ooooo00?o0000oooooooo
ool0F_oooolBo`WZ2RGooooo00?o2NX:ooooooooool01Oooool00ol0003oOgmoo`000005ogmoO`03
o`000?oooooooooo02;ooooo0ol9jPX00omoOgoo0000ogmoO`02ogmoO`04o`000?moOgooOgmoogmo
O`Co2NX:0omoOgl01?l0003oOgmoo`000?l00003ooooo`03o`WZ2_oooooooooo04gooooo3Ol0000?
ooooo`00COooool8o`0004[ooooo4_l9jPXoooooo`03o`000?moOgoo000000GoOgmo00?o0000oooo
ooooool08_ooool3o`WZ2P05oooooomoOgoo0000ogmoOol000000omoOgl2o`WZ2P03ogmoOol9jP[o
2NX:00;oOgmo00Co0000ogmoOomoOgooOgmo0_l00002ooooo`03o`WZ2_oooooooooo00;ooooo0ol9
jPY0ooooo`?o2NX:1Oooool00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00gooooo001=
ooooo`04o`000?moOgooOgmoo`0000?ooooo00?o0000ooooooooool0=ooooolAo`WZ2U7ooooo00?o
0000ogmoOol000001OmoOgl00ol0003oooooooooo`0Rooooo`?o2NX:0_ooool00omoOgoo0000ogmo
O`05ogmoO`05o`WZ2_moOgoo2NX:ogmoOol000001OmoOgl2o`000003ooooool9jP[o2NX:00Go2NX:
@_ooool6o`WZ2P03ooooool0003oOgmo00[oOgmo00?o0000ooooooooool03Oooool004gooooo00Co
0000ogmoOomoOgoo00000oooool00ol0003oooooooooo`0Uoooooa;o2NX:H_ooool00ol0003oOgmo
o`000006o`0002Cooooo0ol9jPX3ooooo`03o`000?moOgooOgmo00CoOgmo00Co2NX:ogmoOomoOgoo
00000_l9jPX2ogmoOeKo2NX:2omoOgl00ol0003oooooooooo`0=ooooo`00AOooool5o`WZ2P?ooooo
2?l0000Eoooooa;o2NX:M?ooool00ol0003oOgmoo`000005ogmoO`03o`000?oooooooooo027ooooo
1Ol9jPX3ooooo`03o`000?moOgooOgmo00?oOgmo00?o2NX:ogmoOol000002?l9jPX2o`000003o`WZ
2_oooooo2NX:00Co2NX:@_ooool5o`WZ2P03ooooool0003o000000_oOgmo00?o0000ooooooooool0
3Oooool004Kooooo2?l9jPX00omoOgoo0000o`000003ooooo`04o`000?oooooooooooooooa;o2NX:
Q_ooool00ol0003oOgmoo`000005ogmoO`03o`000?oooooooooo027ooooo00Go2NX:ooooool9jP[o
ooooo`WZ2P04ooooo`06o`000?moOgooOgmoogmoOol9jP[oOgmo2Ol9jPX2ogmoO`?o00001?ooool2
o`WZ2T3ooooo0_l9jPX6ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool03Oooool0
00koooooB_l9jPZ@ooooo`?o2NX:1Oooool3o`WZ2PGoOgmo00?o0000ooooooooool08oooool00ol9
jP[oooooo`WZ2P02o`WZ2P?ooooo00?o0000ogmoOomoOgl02Ol9jPX3ogmoO`03o`000?l9jP[o2NX:
00;o0000COooool00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00gooooo0016ooooo`So
2NX:00?oOgmoo`000?l000000oooool00ol0003oooooooooo`2Booooo`Ko2NX:0_l00006o`WZ2P03
ogmoOol0003o000002Cooooo00?o2NX:ooooooooool01_l9jPX2o`0000Wo2NX:0_moOgl01_l0003o
Ogmoo`WZ2_l9jP[oOgmoo`0004gooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0=
ooooo`003_oooooQo`WZ2P03o`000?l9jP[o2NX:03Oo2NX:00Co0000o`WZ2_l9jP[o2NX:0_moOgl0
1_l9jP[oOgmoogmoOomoOgoo0000ogmoO`?o2NX:0_moOgl00ol0003oooooooooo`1:ooooo`go0000
3oooool004Kooooo2?l9jPX00omoOgoo0000o`000003ooooo`03o`000?oooooooooo09;ooooo1Ol9
jPX2ooooo`03o`000?l9jP[o2NX:00?o2NX:0_moOgl00ol0003oooooooooo`0Sooooo`03o`WZ2_oo
oooooooo00Go2NX:0_ooool00ol9jP[oOgmoo`000007ogmoO`03o`000?moOgooOgmo00;o2NX:1?mo
Ogl00ol0003oooooooooo`19ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool03Ooo
ool000koooooC?l9jPZ>ooooo`;o2NX:1_ooool2o`WZ2P03o`000?moOgooOgmo00?oOgmo00?o0000
ooooooooool08oooool01?l9jP[oooooo`WZ2_l9jPX6ooooo`04o`WZ2_ooooooOgmoo`0000GoOgmo
00?o0000ogmoOomoOgl00ol9jPX5ogmoO`;o0000BOooool00ol0003oOgmoogmoO`09ogmoO`03o`00
0?oooooooooo00gooooo0016ooooo`Oo2NX:2?l00005oooooaCo2NX:P_ooool00ol0003oOgmoo`00
0005ogmoO`03o`000?oooooooooo02?ooooo00?o2NX:ooooooooool01_ooool3o`WZ2P03oooooomo
Ogoo000000?oOgmo00Co0000ogmoOomoOgooOgmo0ol9jPX5ogmoO`?o0000B?ooool00ol0003oOgmo
ogmoO`09ogmoO`03o`000?oooooooooo00gooooo0015ooooo`Co2NX:1?ooool01?l0003oOgmoogmo
Ool00003ooooo`03o`000?oooooooooo01Oooooo5?l9jPY^ooooo`03o`000?moOgoo000000GoOgmo
00?o0000ooooooooool08oooool00ol9jP[oooooooooo`06ooooo`?o2NX:0_ooool01?moOgoo0000
ogmoOol00003ogmoO`04o`WZ2_moOgoo2NX:o`WZ2PCoOgmo00?o0000ogmoOomoOgl00_l00006oooo
o`?o2NX:=_ooool3o`WZ2PGooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0=oooo
o`00COooool01?l0003oOgmoogmoOol00003ooooo`03o`000?oooooooooo02_ooooo5?l9jPYJoooo
o`03o`000?moOgoo000000Ko00009Oooool00ol9jP[oooooooooo`06ooooo`?o2NX:1?ooool00ol0
003oOgmoogmoO`04ogmoO`;o2NX:0omoOgl00ol0003oOgmoogmoO`02ogmoO`?o00001_l9jPXhoooo
o`Ko2NX:0_l0000;ogmoO`03o`000?oooooooooo00gooooo001=ooooo`So0000@OoooolEo`WZ2TGo
oooo00?o0000ogmoOol000001OmoOgl00ol0003oooooooooo`0Sooooo`03o`WZ2_oooooooooo00Ko
oooo0ol9jPX5ooooo`03o`000?moOgooOgmo00;oOgmo00Co2NX:ogmoOomoOgooOgmo2Ol9jPX00ol0
003o2NX:o`WZ2P14o`WZ2P_oOgmo00?o0000ooooooooool03Oooool004gooooo00Go0000ogmoOomo
OgooOgmoo`000002ooooo`03o`000?oooooooooo05Cooooo5?l9jPXaooooo`03o`000?moOgoo0000
00GoOgmo00?o0000ooooooooool08oooool00ol9jP[oooooooooo`05ooooo`Go2NX:1Oooool01Ol0
003oOgmoogmoOomoOgoo2NX:00;oOgmo2?l9jPX01?moOgoo0000ogmoOol00005o`WZ2SSooooo1Ol9
jPX2ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool03Oooool004gooooo00Go0000
ogmoOomoOgooOgmoo`000002ooooo`03o`000?oooooooooo06Sooooo5?l9jPXEooooo`?o2NX:1Ooo
ool3o`WZ2PGoOgmo00?o0000ooooooooool08oooool00ol9jP[oooooooooo`05ooooo`04o`WZ2_oo
oooo2NX:ooooo`Co2NX:0oooool01Ol0003oOgmoogmoOol9jP[oOgmo00Oo2NX:0_moOgl01Ol0003o
OgmoogmoOomoOgoo000000?ooooo0_l9jPXfooooo`;o2NX:1_ooool=o`0000oooooo001=ooooo`So
0000O_oooolDo`WZ2P;ooooo1_l9jPX00ooooooo0000o`WZ2P05o`WZ2P?o00009?ooool00ol9jP[o
ooooooooo`07ooooo`04o`WZ2_ooooooooooooooo`Ko2NX:00?o0000o`WZ2_l9jPX01ol9jPX2ogmo
O`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0@?ooool00ol0003oOgmoogmoO`09ogmo
O`03o`000?oooooooooo00gooooo001=ooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ooooool0
0000T_oooom;o`WZ2P03o`000?l9jP[o2NX:00Oo2NX:00?oOgmoo`000?moOgl01_moOgl00ol0003o
ooooooooo`0oooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool03Oooool004gooooo
2?l0002Dooooo`Go2NX:0oooool5o`WZ2P;oOgmo00?o0000ooooooooool08oooool00ol9jP[ooooo
ooooo`07ooooo`04o`WZ2_ooooooooooooooo`Go2NX:0_ooool00ol9jP[o0000ogmoO`06ogmoO`03
o`000?moOgooOgmo00GoOgmo00?o0000ogmoOol00000@?ooool00ol0003oOgmoogmoO`09ogmoO`03
o`000?oooooooooo00gooooo001=ooooo`So0000Toooool2o`WZ2PKooooo0_l9jPX00ol0003oOgmo
ogmoO`03ogmoO`03o`000?oooooooooo02?ooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooo
ooooo`02o`WZ2PKooooo00?o2NX:ooooool000001OmoOgl00ol0003oOgmoogmoO`05ogmoO`05o`00
0?moOgooOgmoogmoOol00000?oooool00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00go
oooo003aooooo`So00009Oooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00Oooooo
0ol9jPX00ooooooo0000ogmoO`02ogmoO`03o`000?moOgooOgmo00GoOgmo00Oo0000ogmoOomoOgoo
Ogmoo`000?moOgoo000003kooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0=oooo
o`00lOooool2o`0000GoOgmo00?o0000ooooooooool08oooool00ol9jP[oooooooooo`07ooooo`03
o`WZ2_oooooooooo00Oooooo0ol9jPX2ooooo`03o`000?moOgoo000000OoOgmo00Oo0000ogmoOomo
OgooOgmoo`000?moOgoo000003oooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0=
ooooo`00lOooool2o`0000GoOgmo00?o0000ooooooooool08oooool00ol9jP[oooooooooo`07oooo
o`03o`WZ2_oooooooooo00Oooooo0ol9jPX3ooooo`03o`000?moOgooOgmo00GoOgmo00Oo0000ogmo
OomoOgooOgmoo`000?moOgoo0000043ooooo3Ol0000?ooooo`00l_ooool7o`0002Gooooo00?o2NX:
ooooooooool01oooool00ol9jP[oooooooooo`07ooooo`?o2NX:1?ooool00ol0003oOgmoogmoO`03
ogmoO`07o`000?moOgooOgmoogmoOol0003oOgmoo`000011ooooo`03o`000?moOgooOgmo00WoOgmo
00?o0000ooooooooool03Oooool00?;ooooo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`0Sooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool01_ooool5o`WZ2PCooooo00Go
0000ogmoOomoOgooOgmoo`000003ogmoO`03o`000?moOgoo000004;ooooo00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oooooooooo`0=ooooo`00l_ooool7o`0002Gooooo00?o2NX:ooooooooool01ooo
ool00ol9jP[oooooooooo`06ooooo`05o`WZ2_oooooo2NX:ooooool9jPX01Oooool00ol0003oOgmo
o`000003ogmoO`03o`000?moOgoo000004?ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003ooooo
ooooo`0=ooooo`00l_ooool7o`0002Gooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooooooo
o`08ooooo`03o`WZ2_oooooooooo00Kooooo00Oo0000ogmoOomoOgooOgmoo`000?moOgoo000004Co
oooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0=ooooo`00oooooolOooooo`03o`WZ
2_oooooooooo00Oooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`07ooooo`05o`00
0?moOgoo0000ogmoOol00000AOooool00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00go
oooo003ooooooaoooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ
2_oooooooooo00Sooooo00?o0000ogmoOol00000A_ooool00ol0003oOgmoogmoO`09ogmoO`03o`00
0?oooooooooo00gooooo003ooooooaoooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooooooo
o`08ooooo`03o`WZ2_oooooooooo00Wooooo00?o0000ooooooooool0AOooool=o`0000oooooo003o
oooooaoooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooo
oooo057ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0=ooooo`00oooooolOoooo
o`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`1Aoooo
o`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool03Oooool00?oooooo7oooool00ol9jP[o
ooooooooo`07ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool0DOooool00ol0003o
OgmoogmoO`09ogmoO`03o`000?oooooooooo00gooooo003ooooooaoooooo00?o2NX:ooooooooool0
1oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo057ooooo00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oooooooooo`0=ooooo`00oooooolOooooo`03o`WZ2_oooooooooo00Oooooo00?o
2NX:ooooooooool02?ooool00ol9jP[oooooooooo`1Aooooo`go00003oooool00?oooooo7oooool0
0ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool0DOooool0
0ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo00gooooo003ooooooaoooooo00?o2NX:oooo
ooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo057ooooo00?o0000ogmo
OomoOgl02OmoOgl00ol0003oooooooooo`0=ooooo`00oooooolOooooo`03o`WZ2_oooooooooo00Oo
oooo00?o2NX:ooooooooool02?ooool00ol9jP[oooooooooo`1Aooooo`go00003oooool00?oooooo
7oooool00ol9jP[oooooooooo`07ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool0
DOooool=o`0000oooooo003ooooooaoooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooooooo
o`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:ooooooooool01oooool0
0ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:oooo
ooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoo
oooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06go
oooo003ooooooaoooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ
2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooooooo
o`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:ooooooooool01oooool0
0ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:oooo
ooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoo
oooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06go
oooo003ooooooaoooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ
2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooooooo
o`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:ooooooooool01oooool0
0ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:oooo
ooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoo
oooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06go
oooo003ooooooaoooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ
2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooooooo
o`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:ooooooooool01oooool0
0ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:oooo
ooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoo
oooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06go
oooo003ooooooaoooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`08ooooo`03o`WZ
2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:ooooooooool01oooool00ol9jP[ooooooooo
o`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooaoooooo00?o2NX:ooooooooool01oooool0
0ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06gooooo003ooooooagooooo00Go2NX:oooo
ool9jP[oooooo`WZ2P05ooooo`05o`WZ2_oooooo2NX:ooooool9jPX01_ooool01Ol9jP[oooooo`WZ
2_oooooo2NX:06gooooo003ooooooagooooo1Ol9jPX5ooooo`Go2NX:1_ooool5o`WZ2Vgooooo003o
oooooagooooo1Ol9jPX5ooooo`Go2NX:1_ooool5o`WZ2Vgooooo003ooooooakooooo0ol9jPX7oooo
o`?o2NX:2?ooool3o`WZ2Vkooooo003ooooooakooooo0ol9jPX7ooooo`?o2NX:2?ooool3o`WZ2Vko
oooo003ooooooakooooo0ol9jPX7ooooo`?o2NX:2?ooool3o`WZ2Vkooooo003ooooooakooooo0ol9
jPX7ooooo`?o2NX:2?ooool3o`WZ2Vkooooo003ooooooaoooooo00?o2NX:ooooooooool01oooool0
0ol9jP[oooooooooo`08ooooo`03o`WZ2_oooooooooo06gooooo003oooooo`[ooooo5Ol000000ol9
jP[o0000o`000007o`000003o`WZ2_l0003o000000So000000?o2NX:o`000?l000004ol0001Joooo
o`00ooooool:ooooo`;o00000_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00Co
Ogmo00?o0000ogmoOomoOgl00_moOgl3o`0000OoOgmo0_l00007ogmoO`?o00001?moOgl00ol0003o
OgmoogmoO`04ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00_l0001Jooooo`00
ooooool:ooooo`;o00000_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00CoOgmo
00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00KoOgmo
00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00;oOgmo
00?o0000ogmoOomoOgl00_l0001Jooooo`00ooooool:ooooo`;o00000_moOgl00ol0003oOgmoogmo
O`02ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmo
O`05ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmo
O`04ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00_l0001Jooooo`00ooooool:
ooooo`;o00000_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000
ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000
ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000
ogmoOomoOgl00_l0001Jooooo`00ooooool:ooooo`;o00000_moOgl00ol0003oOgmoogmoO`02ogmo
O`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`05ogmo
O`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`04ogmo
O`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00_l00002ooooo`?o000000?oooooo`00
0?ooool01_l0001<ooooo`00ooooool:ooooo`;o00000_moOgl00ol0003oOgmoogmoO`02ogmoO`03
o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`05ogmoO`03
o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`04ogmoO`03
o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00_l00003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`19ooooo`00ooooool:ooooo`;o
00000_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomo
Ogl01?moOgl00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomo
Ogl01?moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomo
Ogl00_l00003ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`03o`000?oooooo
oooo04_ooooo003oooooo`[ooooo0_l00002ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ogmo
OomoOgl01?moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000ogmo
OomoOgl01_moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ogmo
OomoOgl00_moOgl00ol0003oOgmoogmoO`02o`0000?ooooo00Oo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00?o0000ooooooooool0Boooool00?oooooo2_ooool2o`0000;oOgmo00?o0000
ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000
ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000
ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00;o00000oooool2
o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo04[ooooo003oooooo`[ooooo0_l00002ogmo
O`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`04ogmo
O`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`04ogmo
O`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`02o`00
00?ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo0000C?ooool00?oooooo2_ooool2o`00
00;oOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo
00CoOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo
00CoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo
00;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000ooooo`1<ooooo`00ooooool:ooooo`;o
00000_moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomo
Ogl01?moOgl00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomo
Ogl01?moOgl00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomo
Ogl00_l0001Jooooo`00ooooool:oooood3o0000F_ooool00?ooooooY?ooool00?ooooooY?ooool0
0?ooooooY?ooool00001\
\>"],
  ImageRangeCache->{{{0, 418}, {147.625, 0}} -> {-61.3951, -54.7773, \
0.796149, 0.796149}},
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["wavefronts = FindWaveFronts[system]", "Input",
  CellLabel->"In[543]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 7, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 1, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 7, SurfaceNumber -> 1, 
        WaveFrontID -> 1, Source -> 1}],
      Editable->False]], "Print",
  CellLabel->"From In[543]:=",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.696161 0.0579522 -39584 102.579 [
[.11664 -0.0125 -9 -9 ]
[.11664 -0.0125 9 0 ]
[.26152 -0.0125 -12 -9 ]
[.26152 -0.0125 12 0 ]
[.4064 -0.0125 -6 -9 ]
[.4064 -0.0125 6 0 ]
[.55128 -0.0125 -12 -9 ]
[.55128 -0.0125 12 0 ]
[.69616 -0.0125 -3 -9 ]
[.69616 -0.0125 3 0 ]
[.84104 -0.0125 -9 -9 ]
[.84104 -0.0125 9 0 ]
[.98592 -0.0125 -3 -9 ]
[.98592 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00825 -42 -4.5 ]
[-0.0125 .00825 0 4.5 ]
[-0.0125 .11083 -36 -4.5 ]
[-0.0125 .11083 0 4.5 ]
[-0.0125 .21341 -42 -4.5 ]
[-0.0125 .21341 0 4.5 ]
[-0.0125 .31599 -42 -4.5 ]
[-0.0125 .31599 0 4.5 ]
[-0.0125 .41856 -42 -4.5 ]
[-0.0125 .41856 0 4.5 ]
[-0.0125 .52114 -42 -4.5 ]
[-0.0125 .52114 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11664 0 m
.11664 .00625 L
s
[(-10)] .11664 -0.0125 0 1 Mshowa
.26152 0 m
.26152 .00625 L
s
[(-7.5)] .26152 -0.0125 0 1 Mshowa
.4064 0 m
.4064 .00625 L
s
[(-5)] .4064 -0.0125 0 1 Mshowa
.55128 0 m
.55128 .00625 L
s
[(-2.5)] .55128 -0.0125 0 1 Mshowa
.69616 0 m
.69616 .00625 L
s
[(0)] .69616 -0.0125 0 1 Mshowa
.84104 0 m
.84104 .00625 L
s
[(2.5)] .84104 -0.0125 0 1 Mshowa
.98592 0 m
.98592 .00625 L
s
[(5)] .98592 -0.0125 0 1 Mshowa
.125 Mabswid
.14562 0 m
.14562 .00375 L
s
.17459 0 m
.17459 .00375 L
s
.20357 0 m
.20357 .00375 L
s
.23254 0 m
.23254 .00375 L
s
.2905 0 m
.2905 .00375 L
s
.31947 0 m
.31947 .00375 L
s
.34845 0 m
.34845 .00375 L
s
.37742 0 m
.37742 .00375 L
s
.43538 0 m
.43538 .00375 L
s
.46435 0 m
.46435 .00375 L
s
.49333 0 m
.49333 .00375 L
s
.5223 0 m
.5223 .00375 L
s
.58026 0 m
.58026 .00375 L
s
.60923 0 m
.60923 .00375 L
s
.63821 0 m
.63821 .00375 L
s
.66719 0 m
.66719 .00375 L
s
.72514 0 m
.72514 .00375 L
s
.75411 0 m
.75411 .00375 L
s
.78309 0 m
.78309 .00375 L
s
.81207 0 m
.81207 .00375 L
s
.87002 0 m
.87002 .00375 L
s
.89899 0 m
.89899 .00375 L
s
.92797 0 m
.92797 .00375 L
s
.95695 0 m
.95695 .00375 L
s
.08766 0 m
.08766 .00375 L
s
.05869 0 m
.05869 .00375 L
s
.02971 0 m
.02971 .00375 L
s
.00074 0 m
.00074 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00825 m
.00625 .00825 L
s
[(385.889)] -0.0125 .00825 1 0 Mshowa
0 .11083 m
.00625 .11083 L
s
[(385.89)] -0.0125 .11083 1 0 Mshowa
0 .21341 m
.00625 .21341 L
s
[(385.891)] -0.0125 .21341 1 0 Mshowa
0 .31599 m
.00625 .31599 L
s
[(385.892)] -0.0125 .31599 1 0 Mshowa
0 .41856 m
.00625 .41856 L
s
[(385.893)] -0.0125 .41856 1 0 Mshowa
0 .52114 m
.00625 .52114 L
s
[(385.894)] -0.0125 .52114 1 0 Mshowa
.125 Mabswid
0 .02876 m
.00375 .02876 L
s
0 .04928 m
.00375 .04928 L
s
0 .0698 m
.00375 .0698 L
s
0 .09031 m
.00375 .09031 L
s
0 .13134 m
.00375 .13134 L
s
0 .15186 m
.00375 .15186 L
s
0 .17237 m
.00375 .17237 L
s
0 .19289 m
.00375 .19289 L
s
0 .23392 m
.00375 .23392 L
s
0 .25444 m
.00375 .25444 L
s
0 .27495 m
.00375 .27495 L
s
0 .29547 m
.00375 .29547 L
s
0 .3365 m
.00375 .3365 L
s
0 .35702 m
.00375 .35702 L
s
0 .37753 m
.00375 .37753 L
s
0 .39805 m
.00375 .39805 L
s
0 .43908 m
.00375 .43908 L
s
0 .4596 m
.00375 .4596 L
s
0 .48011 m
.00375 .48011 L
s
0 .50063 m
.00375 .50063 L
s
0 .54166 m
.00375 .54166 L
s
0 .56217 m
.00375 .56217 L
s
0 .58269 m
.00375 .58269 L
s
0 .60321 m
.00375 .60321 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11664 .61178 m
.11664 .61803 L
s
.26152 .61178 m
.26152 .61803 L
s
.4064 .61178 m
.4064 .61803 L
s
.55128 .61178 m
.55128 .61803 L
s
.69616 .61178 m
.69616 .61803 L
s
.84104 .61178 m
.84104 .61803 L
s
.98592 .61178 m
.98592 .61803 L
s
.125 Mabswid
.14562 .61428 m
.14562 .61803 L
s
.17459 .61428 m
.17459 .61803 L
s
.20357 .61428 m
.20357 .61803 L
s
.23254 .61428 m
.23254 .61803 L
s
.2905 .61428 m
.2905 .61803 L
s
.31947 .61428 m
.31947 .61803 L
s
.34845 .61428 m
.34845 .61803 L
s
.37742 .61428 m
.37742 .61803 L
s
.43538 .61428 m
.43538 .61803 L
s
.46435 .61428 m
.46435 .61803 L
s
.49333 .61428 m
.49333 .61803 L
s
.5223 .61428 m
.5223 .61803 L
s
.58026 .61428 m
.58026 .61803 L
s
.60923 .61428 m
.60923 .61803 L
s
.63821 .61428 m
.63821 .61803 L
s
.66719 .61428 m
.66719 .61803 L
s
.72514 .61428 m
.72514 .61803 L
s
.75411 .61428 m
.75411 .61803 L
s
.78309 .61428 m
.78309 .61803 L
s
.81207 .61428 m
.81207 .61803 L
s
.87002 .61428 m
.87002 .61803 L
s
.89899 .61428 m
.89899 .61803 L
s
.92797 .61428 m
.92797 .61803 L
s
.95695 .61428 m
.95695 .61803 L
s
.08766 .61428 m
.08766 .61803 L
s
.05869 .61428 m
.05869 .61803 L
s
.02971 .61428 m
.02971 .61803 L
s
.00074 .61428 m
.00074 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00825 m
1 .00825 L
s
.99375 .11083 m
1 .11083 L
s
.99375 .21341 m
1 .21341 L
s
.99375 .31599 m
1 .31599 L
s
.99375 .41856 m
1 .41856 L
s
.99375 .52114 m
1 .52114 L
s
.125 Mabswid
.99625 .02876 m
1 .02876 L
s
.99625 .04928 m
1 .04928 L
s
.99625 .0698 m
1 .0698 L
s
.99625 .09031 m
1 .09031 L
s
.99625 .13134 m
1 .13134 L
s
.99625 .15186 m
1 .15186 L
s
.99625 .17237 m
1 .17237 L
s
.99625 .19289 m
1 .19289 L
s
.99625 .23392 m
1 .23392 L
s
.99625 .25444 m
1 .25444 L
s
.99625 .27495 m
1 .27495 L
s
.99625 .29547 m
1 .29547 L
s
.99625 .3365 m
1 .3365 L
s
.99625 .35702 m
1 .35702 L
s
.99625 .37753 m
1 .37753 L
s
.99625 .39805 m
1 .39805 L
s
.99625 .43908 m
1 .43908 L
s
.99625 .4596 m
1 .4596 L
s
.99625 .48011 m
1 .48011 L
s
.99625 .50063 m
1 .50063 L
s
.99625 .54166 m
1 .54166 L
s
.99625 .56217 m
1 .56217 L
s
.99625 .58269 m
1 .58269 L
s
.99625 .60321 m
1 .60321 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.69616 0 m
.69616 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .01472 Mdot
.94557 .0196 Mdot
.91492 .02257 Mdot
.88426 .02425 Mdot
.85357 .02518 Mdot
.82288 .02588 Mdot
.79216 .02681 Mdot
.76144 .02839 Mdot
.73071 .03098 Mdot
.69996 .03492 Mdot
.66921 .04049 Mdot
.63845 .04793 Mdot
.60769 .05745 Mdot
.57693 .06921 Mdot
.54616 .08332 Mdot
.51539 .09986 Mdot
.48461 .11888 Mdot
.45384 .14037 Mdot
.42307 .16429 Mdot
.39231 .19057 Mdot
.36155 .21907 Mdot
.33079 .24965 Mdot
.30004 .28209 Mdot
.26929 .31615 Mdot
.23856 .35155 Mdot
.20784 .38795 Mdot
.17712 .42498 Mdot
.14643 .46223 Mdot
.11574 .49922 Mdot
.08508 .53545 Mdot
.05443 .57035 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.05372 .57112 L
.08634 .53395 L
.11698 .49773 L
.14644 .46221 L
.1778 .42416 L
.20799 .38777 L
.24008 .3498 L
.27099 .31427 L
.30073 .28136 L
.33237 .24808 L
.36283 .21788 L
.39213 .19074 L
.42332 .1641 L
.45333 .14077 L
.48525 .11849 L
.51599 .09953 L
.54556 .08364 L
.57703 .06917 L
.60732 .05759 L
.63951 .04768 L
.67053 .04025 L
.70038 .03487 L
.71582 .03289 L
.72369 .03188 L
.72802 .03133 L
.73212 .03086 L
.74008 .03019 L
.74733 .02958 L
.75407 .02901 L
.75766 .02871 L
.75967 .02854 L
.76063 .02846 L
.76152 .02839 L
.76242 .02834 L
.7634 .02829 L
.76538 .02819 L
.76899 .028 L
.77693 .02759 L
.78378 .02724 L
.78738 .02706 L
.7912 .02686 L
.79321 .02678 L
.79543 .02671 L
.79934 .0266 L
.80703 .02636 L
.82142 .02593 L
.85265 .0252 L
.86704 .02477 L
.87463 .02454 L
Mistroke
.87879 .02442 L
.88271 .0243 L
.88376 .02426 L
.88428 .02425 L
.88486 .02422 L
.88607 .02415 L
.88718 .02409 L
.89122 .02387 L
.89911 .02344 L
.90725 .02299 L
.91111 .02278 L
.9128 .02269 L
.91376 .02264 L
.91467 .02259 L
.91554 .02251 L
.91648 .02242 L
.9184 .02224 L
.92244 .02184 L
.9298 .02113 L
.93755 .02038 L
.94164 .01998 L
.94389 .01976 L
.94499 .01965 L
.946 .01953 L
.94792 .01922 L
.95 .01889 L
.95363 .01831 L
.96072 .01718 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[543]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00Aoooool3o`0000Cooooo0_l0000Hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool3o`0001[ooooo0ol0000Iooooo`Go00000oooool00ol0003o
ooooooooo`02ooooo`?o00006?ooool2o`0001Wooooo1Ol00003ooooo`03o`000?oooooooooo00;o
oooo0ol0000Jooooo`?o00001?ooool004Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Gooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Hoooo
o`05o`000?ooooooooooooooool000006Oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000005_ooool01?l0003oooooooooool0000Iooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Hooooo`05o`000?ooooooooooooooool000000ooo
ool0043ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00003ooo
ool5o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`Go00001Ooo
ool00ol0003oooooooooo`0@ooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Cooooo00Co0000oooooooooooo00006_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool00Oooool004Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5?ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`01ooooo`00B?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0001Wooooo00?o0000ooooooooool01Oooool4o`0001Wooooo1?l0000Iooooo`05
o`000?ooooooooooooooool000001oooool4o`0001Oooooo00Co0000oooooooooooo00006?ooool0
1Ol0003ooooooooooooooooo000000Oooooo1?l0000Iooooo`Co00001?ooool004Oooooo0_l00004
ooooo`04o`000?ooooooooooo`0001Gooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Hooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo0018oooo
o`03o`000?oooooooooo00?ooooo0_l0000Fooooo`Go00001oooool5o`0001Sooooo1Ol0000Ioooo
o`?o00002?ooool5o`0001Oooooo0_l0000Jooooo`?o00002?ooool5o`0001Sooooo1Ol00003oooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`0000Coooooo`00
0?l0003o00000oooool3o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00003
ooooo`?o00000oooool2o`0000Koooool_l00001ooooo`0000Oo0000ooooooooooooooooo`000?oo
oooo000000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`05ooooo`07o`000?oo
ooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00007ooooo0004ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool2o`0001[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo023ooooo00Co0000ooooool0003o00000Oooool000;ooooo0_l00003
ooooo`?o00001_ooool00ol0003oooooooooo`06ooooo`?o00000oooool3o`0000?ooooo1?l00004
ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0A_ooool1o`00007ooooo0004oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooool000000ol00008ooooo`07o`000?oooooooooo
ooooool0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03cooooo1_l00004ooooo`7o00000Ooo
ool00007o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000_ooooo
00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0<Oooool2o`00
00;ooooo1ol00004ooooo`;o00001?ooool1o`00007ooooo00001?oooooo0000o`000?l00003oooo
o`?o00000_ooool5o`0000Sooooo0ol00003ooooo`?o00000oooool3o`0000Gooooo00?o0000oooo
ooooool0YOooool00ol0003oooooooooo`0Cooooo`;o00001_ooool2o`0000;ooooo5_l00004oooo
o`;o00002oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo0:Gooooo00?o0000oooooooo
ool01Oooool2o`0000;ooooo5_l00003ooooo`;o00001_ooool2o`0001Wooooo0_l00001ooooo`00
;Oooool00ol0003oooooooooo`2Uooooo`;o000000?oooooo`000?l000001ol00003ooooo`;o0000
>?ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo0:?ooooo1Ol00016ooooo`7o00000Ooo
ool002gooooo00?o0000ooooooooool0WOooool6o`0000;ooooo00?o0000ooooooooool0A_ooool1
o`00007ooooo000]ooooo`03o`000?oooooooooo09Wooooo1?l000000ooooooo0000o`000005oooo
o`03o`000?oooooooooo04Kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`2Eooooo`Co
00003?ooool00ol0003oooooooooo`15ooooo`;o00000Oooool002gooooo00?o0000ooooooooool0
TOooool4o`000003ooooool0003o000000gooooo00?o0000ooooooooool0A_ooool1o`00007ooooo
000]ooooo`03o`000?oooooooooo08kooooo0ol0000Dooooo`03o`000?oooooooooo04Kooooo0Ol0
0001ooooo`00;Oooool00ol0003oooooooooo`2;ooooo`?o000000?oooooo`000?l000005?ooool0
0ol0003oooooooooo`16ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0ROooool2o`00
01[ooooo00?o0000ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo08Oo
oooo0_l0000Looooo`03o`000?oooooooooo04Gooooo0_l00001ooooo`00;Oooool00ol0003ooooo
ooooo`25ooooo`Co00007?ooool00ol0003oooooooooo`16ooooo`7o00000Oooool002gooooo00?o
0000ooooooooool0Poooool2o`00023ooooo00?o0000ooooooooool0A_ooool1o`00007ooooo000]
ooooo`03o`000?oooooooooo083ooooo0ol0000Rooooo`03o`000?oooooooooo04Kooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`1oooooo`?o00008oooool00ol0003oooooooooo`16oooo
o`7o00000Oooool002gooooo00?o0000ooooooooool0O?ooool3o`0002Kooooo00?o0000oooooooo
ool0AOooool2o`00007ooooo000]ooooo`03o`000?oooooooooo07[ooooo0_l0000Yooooo`03o`00
0?oooooooooo04Kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1hooooo`;o0000:ooo
ool00ol0003oooooooooo`16ooooo`7o00000Oooool000Oooooo0ol00003ooooo`?o00000oooool3
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0_l00006ooooo`03o`000?oooooo
oooo07Oooooo0ol0000[ooooo`03o`000?oooooooooo04Kooooo0Ol00001ooooo`001_ooool01ol0
003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0MOooool2o`0002kooooo00?o0000ooooooooool0A_ooool1o`00007ooooo
000:ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`;o0000
MOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Gooooo0_l00001ooooo`002?oo
ool2o`0000?ooooo0ol00006ooooo`03o`000?oooooooooo00Kooooo0ol00003ooooo`Co00001?oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0A_oo
ool1o`00007ooooo000:ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000ol00008
ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0LOooool2o`0003;ooooo00?o0000ooooooooool0A_ooool1o`00007ooooo
0006ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000_o
oooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1`ooooo`?o0000<_ooool00ol0003oooooooooo`16ooooo`7o00000Oooool0
00Oooooo0ol00003ooooo`?o00000_ooool5o`0000Sooooo0ol00003ooooo`?o00001Oooool00ol0
003oooooooooo`1^ooooo`;o0000=Oooool00ol0003oooooooooo`16ooooo`7o00000Oooool002go
oooo00?o0000ooooooooool0K?ooool2o`0003Oooooo00?o0000ooooooooool0AOooool2o`00007o
oooo000]ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`16ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0JOooool3o`0003Wooooo00?o
0000ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo06Sooooo00Co0000
ooooool0003o0000>Oooool00ol0003oooooooooo`16ooooo`7o00000Oooool002gooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo04Kooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0AOooool2o`00007ooooo000]ooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`16ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo04Kooooo0Ol00001ooooo`00;Ooo
ool00ol0003oooooooooo`1Rooooo`;o0000@Oooool00ol0003oooooooooo`16ooooo`7o00000Ooo
ool002gooooo00?o0000ooooooooool0HOooool3o`00047ooooo00?o0000ooooooooool0A_ooool1
o`00007ooooo000]ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`15ooooo`;o00000Oooool002gooooo00?o0000ooooooooool0G_ooool2o`0004Go
oooo00?o0000ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`7o00000Oooool002gooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo0Ol0
0001ooooo`00;Oooool00ol0003oooooooooo`1Kooooo`;o0000B?ooool00ol0003oooooooooo`16
ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0F_ooool3o`0004Sooooo00?o0000oooo
ooooool0AOooool2o`00007ooooo000]ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`16ooooo`7o00000Oooool00004ooooool0003o0000o`0000?o
oooo0ol00003ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool2o`0000Co
oooo0ol00005ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`16ooooo`7o00000Oooool00007o`000?ooooooooooooooool0003oooooo`000003oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`16ooooo`7o00000Oooool0
00Cooooo00?o0000ooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0A_oo
ool1o`00007ooooo0002ooooo`;o00000oooool3o`0000Kooooo00?o0000ooooooooool01_ooool3
o`0000?ooooo1?l00003ooooo`03o`000?oooooooooo00Cooooo0_l0001Fooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0AOooool2o`00007ooooo0004ooooo`03o`000?oooooo0000
00?ooooo00?o0000ooooool000000ol00008ooooo`07o`000?ooooooooooooooool0003oooooo`00
0003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Cooooo`;o0000
D?ooool00ol0003oooooooooo`16ooooo`7o00000Oooool00007o`000?ooooooooooooooool0003o
ooooo`000003ooooo`03o`000?oooooo000000_ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000?ooooo00?o0000ooooooooool00_l00006ooooo`03o`000?oooooooooo05?ooooo0_l0001@
ooooo`03o`000?oooooooooo04Kooooo0Ol00001ooooo`0000Coooooo`000?l0003o00000oooool3
o`0000;ooooo1Ol00008ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0A_ooool1
o`00007ooooo000]ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`16ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo04Gooooo0_l00001ooooo`00;Oooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0A_ooool1o`00007ooooo
000]ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`16ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0C?ooool2o`0005Oooooo00?o0000
ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo04cooooo0_l0001Goooo
o`03o`000?oooooooooo04Kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1;ooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool0AOooool2o`00007ooooo000]ooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`16ooooo`7o0000
0Oooool002gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo04Kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`16ooooo`7o00000Oooool002go
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo04Go
oooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`14ooooo`;o0000Goooool00ol0003ooooo
ooooo`16ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0A?ooool2o`0005oooooo00?o
0000ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`16ooooo`7o00000Oooool002gooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo04Kooooo0Ol00001oooo
o`00;Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0AOooool2o`00007ooooo000]ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`16ooooo`7o00000Oooool00004ooooool0003o0000o`0000?ooooo
0ol00003ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool2o`0000?ooooo
1Ol00004ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`16ooooo`7o00000Oooool00007o`000?ooooooooooooooool0003oooooo`000003ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo04Kooooo0Ol00001
ooooo`001?ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo03gooooo0_l0001Vooooo`03o`000?oooooooooo04Kooooo0Ol0
0001ooooo`000_ooool2o`0000?ooooo0ol00006ooooo`03o`000?oooooooooo00Kooooo0ol00003
ooooo`Co00001?ooool00ol0003oooooooooo`03ooooo`;o0000?_ooool2o`0006Kooooo00?o0000
ooooooooool0AOooool2o`00007ooooo0004ooooo`03o`000?oooooo000000?ooooo00?o0000oooo
ool000000ol00008ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0A_ooool1o`00007ooooo00001ol0003ooooooooooooo
oooo0000ooooool000000oooool00ol0003oooooo`00000;ooooo`07o`000?ooooooooooooooool0
003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0A_ooool1o`00
007ooooo00001?oooooo0000o`000?l00003ooooo`?o00000_ooool5o`0000Sooooo0ol00003oooo
o`?o00000oooool3o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1Woooo
o`03o`000?oooooooooo04Kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`15ooooo`;o0000
0Oooool002gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo04Kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo
03Kooooo0_l0001]ooooo`03o`000?oooooooooo04Kooooo0Ol00001ooooo`00;Oooool00ol0003o
ooooooooo`0fooooo`;o0000KOooool00ol0003oooooooooo`16ooooo`7o00000Oooool002gooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo04Gooooo
0_l00001ooooo`00;Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`16ooooo`7o00000Oooool002gooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo04Kooooo0Ol00001oooo
o`00;Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`15ooooo`;o00000Oooool002gooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo04Kooooo0Ol00001ooooo`00;Oooool0
0ol0003oooooooooo`0^ooooo`;o0000MOooool00ol0003oooooooooo`16ooooo`7o00000Oooool0
02gooooo00?o0000ooooooooool0;_ooool2o`0007Gooooo00?o0000ooooooooool0A_ooool1o`00
007ooooo000]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0M?ooool00ol0003o
ooooooooo`16ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`1eooooo`03o`000?oooooooooo04Gooooo0_l00001ooooo`00;Oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0A_ooool1o`00007ooooo0000
1?oooooo0000o`000?l00003ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000?ooooo0_l00004ooooo`?o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo07Oooooo00?o0000ooooooooool0A_ooool1o`00007ooooo00001ol0003ooooooooooooo
oooo0000ooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07Oooooo00?o0000oooo
ooooool0A_ooool1o`00007ooooo0004ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo04Kooooo0Ol00001ooooo`000_ooool2o`0000?o
oooo0ol00006ooooo`03o`000?oooooooooo00Kooooo0ol00003ooooo`Co00000oooool2o`0000Go
oooo0_l0000Zooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0AOooool2o`00007o
oooo0004ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000ol00008ooooo`07o`00
0?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Wooooo`;o0000O?ooool00ol0003oooooooooo`16oooo
o`7o00000Oooool00007o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
000000_ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Oooooo0_l0001looooo`03o`00
0?oooooooooo04Kooooo0Ol00001ooooo`0000Coooooo`000?l0003o00000oooool3o`0000;ooooo
1Ol00008ooooo`?o00000oooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0Noooool00ol0003oooooooooo`16ooooo`7o00000Oooool002gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo04Gooooo0_l0
0001ooooo`00;Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07gooooo00?o0000
ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0O_ooool00ol0003oooooooooo`16ooooo`7o00000Oooool002gooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo04Kooooo0Ol00001ooooo`00
;Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0
A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`15ooooo`;o00000Oooool002gooooo00?o0000ooooooooool07oooool2
o`0008Cooooo00?o0000ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo
01oooooo0_l00024ooooo`03o`000?oooooooooo04Kooooo0Ol00001ooooo`00;Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0A_ooool1o`00007o
oooo000]ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Q?ooool00ol0003ooooo
ooooo`16ooooo`7o00000Oooool002gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`25ooooo`03o`000?oooooooooo04Gooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0A_ooool1o`00007ooooo000]oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`16oooo
o`7o00000Oooool002gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`27ooooo`03
o`000?oooooooooo04Kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo08Sooooo00?o0000ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`000?oo
oooooooo01Sooooo0_l0002;ooooo`03o`000?oooooooooo04Gooooo0_l00001ooooo`00;Oooool0
0ol0003oooooooooo`0Hooooo`;o0000Roooool00ol0003oooooooooo`16ooooo`7o00000Oooool0
02gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo
04Kooooo0Ol00001ooooo`0000Coooooo`000?l0003o00000oooool3o`0000?ooooo0ol00004oooo
o`03o`000?oooooooooo00;ooooo0ol00003ooooo`;o00001Oooool3o`0000Cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo04Kooooo0Ol00001oooo
o`0000Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooooooo04Kooooo0Ol00001ooooo`001?ooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooool000001?l00004ooooo`;o00005Oooool00ol0003ooooooooo
o`2>ooooo`03o`000?oooooooooo04Gooooo0_l00001ooooo`000_ooool2o`0000?ooooo0ol00006
ooooo`03o`000?oooooooooo00Kooooo0ol00003ooooo`Co000000Goooooo`000?ooooooooooo`00
0005ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Soooool00ol0003ooooooooo
o`16ooooo`7o00000Oooool000Cooooo00?o0000ooooool000000oooool00ol0003oooooo`000003
o`0000Sooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00Ko0000oooooooooooo
0000ooooool00005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0T?ooool00ol0
003oooooooooo`16ooooo`7o00000Oooool00007o`000?ooooooooooooooool0003oooooo`000003
ooooo`03o`000?oooooo000000_ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo
00Co0000oooooooooooooooo0_l00005ooooo`03o`000?oooooooooo013ooooo0_l0002Cooooo`03
o`000?oooooooooo04Kooooo0Ol00001ooooo`0000Coooooo`000?l0003o00000oooool3o`0000;o
oooo1Ol00008ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0@ooooo`;o0000Toooool00ol0003oooooooooo`16ooooo`7o00000Oooool002gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo04Gooooo
0_l00001ooooo`00;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09?ooooo00?o
0000ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0U?ooool00ol0003oooooooooo`16ooooo`7o00000Oooool002gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo04Kooooo0Ol00001oooo
o`00;Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo09Gooooo00?o0000oooooooo
ool0A_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
U_ooool00ol0003oooooooooo`15ooooo`;o00000Oooool002gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo04Kooooo0Ol00001ooooo`00;Oooool0
0ol0003oooooooooo`09ooooo`;o0000V_ooool00ol0003oooooooooo`16ooooo`7o00000Oooool0
02gooooo00?o0000ooooooooool02Oooool2o`0009[ooooo00?o0000ooooooooool0A_ooool1o`00
007ooooo000]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0V_ooool00ol0003o
ooooooooo`16ooooo`7o00000Oooool002gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2Kooooo`03o`000?oooooooooo04Gooooo0_l00001ooooo`00;Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0A_ooool1o`00007ooooo000]
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`16
ooooo`7o00000Oooool002gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo04Kooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo09oooooo00?o0000ooooooooool0A_ooool1o`00007ooooo000]ooooo`03o`00
0?oooooooooo00;ooooo0_l0002Qooooo`03o`000?oooooooooo04Gooooo0_l00001ooooo`00;Ooo
ool00ol0003oooooooooo`02ooooo`;o0000XOooool00ol0003oooooooooo`16ooooo`7o00000Ooo
ool002gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00001ooooo`00;Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00007ooooo000]oooooo;o00000Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool003Kooooo0ol0001Hooooo`?o00005ooo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00Sooooo000gooooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo00Oooooo000aooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`00
00?ooooo1?l000000ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co00000oooool2o`00
00;ooooo1_l00006ooooo`Go00000_ooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool4
o`0000?ooooo0_l00002ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`Co000000?ooooo
o`000?l000000_l00002ooooo`Co00000oooool3o`0000;ooooo1Ol00003ooooo`;o000000Cooooo
o`000?oooooooooo0_l00003ooooo`?o00002Oooool4o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000_l00004ooooo`;o00000oooool4o`000005ooooool0003o0000o`000?ooool0
0_l000001?oooooo0000o`000?l00003ooooo`?o00001Oooool00ol0003oooooooooo`06ooooo`00
<?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000oooool01Ol0003ooooo
oooooooooooo000000Cooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003o
ooooo`0000_ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooool000000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo
00Kooooo000`ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`Go0000
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`04o`000?oo
ooooooooo`0000;ooooo0ol00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool5o`00
00Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool0
0ol0003oooooooooo`03ooooo`?o00000oooool01_l0003oooooooooool0003oooooo`0000Gooooo
1Ol00004ooooo`03o`000?oooooooooo00Kooooo000`ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000Gooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`00<?oo
ool01_l0003ooooooooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo0ol00004ooooo`?o
00000oooool2o`0000Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00002oooo
o`;o00000oooool4o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo0ol00002oooo
o`Co00000oooool9o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`?o00000oooool4o`0000;ooooo0ol00004ooooo`04o`000?ooooooooooooooo`;o000000Cooooo
o`000?l0003ooooo1?l00003ooooo`?o00002Oooool3o`0000;ooooo0ol00004ooooo`Co000000?o
ooooo`000?l000000_l00003ooooo`;o00000oooool4o`0000?ooooo0ol00003ooooo`?o00001Ooo
ool00ol0003oooooooooo`06ooooo`00<?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo
000aooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0ol0
0009ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool3o`0001Kooooo00?o
0000ooooooooool00_ooool2o`0000gooooo00?o0000ooooooooool01_ooool2o`00013ooooo0ol0
000:ooooo`03o`000?oooooooooo013ooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-15.2251, 385.887, \
0.0713485, 4.03085*^-5}},
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.696161 0.0579522 -0.0578549 0.314355 [
[.11664 -0.0125 -9 -9 ]
[.11664 -0.0125 9 0 ]
[.26152 -0.0125 -12 -9 ]
[.26152 -0.0125 12 0 ]
[.4064 -0.0125 -6 -9 ]
[.4064 -0.0125 6 0 ]
[.55128 -0.0125 -12 -9 ]
[.55128 -0.0125 12 0 ]
[.69616 -0.0125 -3 -9 ]
[.69616 -0.0125 3 0 ]
[.84104 -0.0125 -9 -9 ]
[.84104 -0.0125 9 0 ]
[.98592 -0.0125 -3 -9 ]
[.98592 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02073 -24 -4.5 ]
[-0.0125 .02073 0 4.5 ]
[-0.0125 .09932 -18 -4.5 ]
[-0.0125 .09932 0 4.5 ]
[-0.0125 .17791 -24 -4.5 ]
[-0.0125 .17791 0 4.5 ]
[-0.0125 .2565 -6 -4.5 ]
[-0.0125 .2565 0 4.5 ]
[-0.0125 .33509 -24 -4.5 ]
[-0.0125 .33509 0 4.5 ]
[-0.0125 .41368 -18 -4.5 ]
[-0.0125 .41368 0 4.5 ]
[-0.0125 .49227 -24 -4.5 ]
[-0.0125 .49227 0 4.5 ]
[-0.0125 .57086 -6 -4.5 ]
[-0.0125 .57086 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11664 0 m
.11664 .00625 L
s
[(-10)] .11664 -0.0125 0 1 Mshowa
.26152 0 m
.26152 .00625 L
s
[(-7.5)] .26152 -0.0125 0 1 Mshowa
.4064 0 m
.4064 .00625 L
s
[(-5)] .4064 -0.0125 0 1 Mshowa
.55128 0 m
.55128 .00625 L
s
[(-2.5)] .55128 -0.0125 0 1 Mshowa
.69616 0 m
.69616 .00625 L
s
[(0)] .69616 -0.0125 0 1 Mshowa
.84104 0 m
.84104 .00625 L
s
[(2.5)] .84104 -0.0125 0 1 Mshowa
.98592 0 m
.98592 .00625 L
s
[(5)] .98592 -0.0125 0 1 Mshowa
.125 Mabswid
.14562 0 m
.14562 .00375 L
s
.17459 0 m
.17459 .00375 L
s
.20357 0 m
.20357 .00375 L
s
.23254 0 m
.23254 .00375 L
s
.2905 0 m
.2905 .00375 L
s
.31947 0 m
.31947 .00375 L
s
.34845 0 m
.34845 .00375 L
s
.37742 0 m
.37742 .00375 L
s
.43538 0 m
.43538 .00375 L
s
.46435 0 m
.46435 .00375 L
s
.49333 0 m
.49333 .00375 L
s
.5223 0 m
.5223 .00375 L
s
.58026 0 m
.58026 .00375 L
s
.60923 0 m
.60923 .00375 L
s
.63821 0 m
.63821 .00375 L
s
.66719 0 m
.66719 .00375 L
s
.72514 0 m
.72514 .00375 L
s
.75411 0 m
.75411 .00375 L
s
.78309 0 m
.78309 .00375 L
s
.81207 0 m
.81207 .00375 L
s
.87002 0 m
.87002 .00375 L
s
.89899 0 m
.89899 .00375 L
s
.92797 0 m
.92797 .00375 L
s
.95695 0 m
.95695 .00375 L
s
.08766 0 m
.08766 .00375 L
s
.05869 0 m
.05869 .00375 L
s
.02971 0 m
.02971 .00375 L
s
.00074 0 m
.00074 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02073 m
.00625 .02073 L
s
[(0.25)] -0.0125 .02073 1 0 Mshowa
0 .09932 m
.00625 .09932 L
s
[(0.5)] -0.0125 .09932 1 0 Mshowa
0 .17791 m
.00625 .17791 L
s
[(0.75)] -0.0125 .17791 1 0 Mshowa
0 .2565 m
.00625 .2565 L
s
[(1)] -0.0125 .2565 1 0 Mshowa
0 .33509 m
.00625 .33509 L
s
[(1.25)] -0.0125 .33509 1 0 Mshowa
0 .41368 m
.00625 .41368 L
s
[(1.5)] -0.0125 .41368 1 0 Mshowa
0 .49227 m
.00625 .49227 L
s
[(1.75)] -0.0125 .49227 1 0 Mshowa
0 .57086 m
.00625 .57086 L
s
[(2)] -0.0125 .57086 1 0 Mshowa
.125 Mabswid
0 .03645 m
.00375 .03645 L
s
0 .05217 m
.00375 .05217 L
s
0 .06789 m
.00375 .06789 L
s
0 .0836 m
.00375 .0836 L
s
0 .11504 m
.00375 .11504 L
s
0 .13076 m
.00375 .13076 L
s
0 .14648 m
.00375 .14648 L
s
0 .16219 m
.00375 .16219 L
s
0 .19363 m
.00375 .19363 L
s
0 .20935 m
.00375 .20935 L
s
0 .22506 m
.00375 .22506 L
s
0 .24078 m
.00375 .24078 L
s
0 .27222 m
.00375 .27222 L
s
0 .28794 m
.00375 .28794 L
s
0 .30365 m
.00375 .30365 L
s
0 .31937 m
.00375 .31937 L
s
0 .35081 m
.00375 .35081 L
s
0 .36652 m
.00375 .36652 L
s
0 .38224 m
.00375 .38224 L
s
0 .39796 m
.00375 .39796 L
s
0 .4294 m
.00375 .4294 L
s
0 .44511 m
.00375 .44511 L
s
0 .46083 m
.00375 .46083 L
s
0 .47655 m
.00375 .47655 L
s
0 .50798 m
.00375 .50798 L
s
0 .5237 m
.00375 .5237 L
s
0 .53942 m
.00375 .53942 L
s
0 .55514 m
.00375 .55514 L
s
0 .00502 m
.00375 .00502 L
s
0 .58657 m
.00375 .58657 L
s
0 .60229 m
.00375 .60229 L
s
0 .61801 m
.00375 .61801 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11664 .61178 m
.11664 .61803 L
s
.26152 .61178 m
.26152 .61803 L
s
.4064 .61178 m
.4064 .61803 L
s
.55128 .61178 m
.55128 .61803 L
s
.69616 .61178 m
.69616 .61803 L
s
.84104 .61178 m
.84104 .61803 L
s
.98592 .61178 m
.98592 .61803 L
s
.125 Mabswid
.14562 .61428 m
.14562 .61803 L
s
.17459 .61428 m
.17459 .61803 L
s
.20357 .61428 m
.20357 .61803 L
s
.23254 .61428 m
.23254 .61803 L
s
.2905 .61428 m
.2905 .61803 L
s
.31947 .61428 m
.31947 .61803 L
s
.34845 .61428 m
.34845 .61803 L
s
.37742 .61428 m
.37742 .61803 L
s
.43538 .61428 m
.43538 .61803 L
s
.46435 .61428 m
.46435 .61803 L
s
.49333 .61428 m
.49333 .61803 L
s
.5223 .61428 m
.5223 .61803 L
s
.58026 .61428 m
.58026 .61803 L
s
.60923 .61428 m
.60923 .61803 L
s
.63821 .61428 m
.63821 .61803 L
s
.66719 .61428 m
.66719 .61803 L
s
.72514 .61428 m
.72514 .61803 L
s
.75411 .61428 m
.75411 .61803 L
s
.78309 .61428 m
.78309 .61803 L
s
.81207 .61428 m
.81207 .61803 L
s
.87002 .61428 m
.87002 .61803 L
s
.89899 .61428 m
.89899 .61803 L
s
.92797 .61428 m
.92797 .61803 L
s
.95695 .61428 m
.95695 .61803 L
s
.08766 .61428 m
.08766 .61803 L
s
.05869 .61428 m
.05869 .61803 L
s
.02971 .61428 m
.02971 .61803 L
s
.00074 .61428 m
.00074 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02073 m
1 .02073 L
s
.99375 .09932 m
1 .09932 L
s
.99375 .17791 m
1 .17791 L
s
.99375 .2565 m
1 .2565 L
s
.99375 .33509 m
1 .33509 L
s
.99375 .41368 m
1 .41368 L
s
.99375 .49227 m
1 .49227 L
s
.99375 .57086 m
1 .57086 L
s
.125 Mabswid
.99625 .03645 m
1 .03645 L
s
.99625 .05217 m
1 .05217 L
s
.99625 .06789 m
1 .06789 L
s
.99625 .0836 m
1 .0836 L
s
.99625 .11504 m
1 .11504 L
s
.99625 .13076 m
1 .13076 L
s
.99625 .14648 m
1 .14648 L
s
.99625 .16219 m
1 .16219 L
s
.99625 .19363 m
1 .19363 L
s
.99625 .20935 m
1 .20935 L
s
.99625 .22506 m
1 .22506 L
s
.99625 .24078 m
1 .24078 L
s
.99625 .27222 m
1 .27222 L
s
.99625 .28794 m
1 .28794 L
s
.99625 .30365 m
1 .30365 L
s
.99625 .31937 m
1 .31937 L
s
.99625 .35081 m
1 .35081 L
s
.99625 .36652 m
1 .36652 L
s
.99625 .38224 m
1 .38224 L
s
.99625 .39796 m
1 .39796 L
s
.99625 .4294 m
1 .4294 L
s
.99625 .44511 m
1 .44511 L
s
.99625 .46083 m
1 .46083 L
s
.99625 .47655 m
1 .47655 L
s
.99625 .50798 m
1 .50798 L
s
.99625 .5237 m
1 .5237 L
s
.99625 .53942 m
1 .53942 L
s
.99625 .55514 m
1 .55514 L
s
.99625 .00502 m
1 .00502 L
s
.99625 .58657 m
1 .58657 L
s
.99625 .60229 m
1 .60229 L
s
.99625 .61801 m
1 .61801 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.69616 0 m
.69616 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01563 m
.05372 .05565 L
.08634 .09211 L
.11698 .12782 L
.14644 .16629 L
.1778 .21141 L
.20799 .25829 L
.24008 .31061 L
.27099 .36207 L
.30073 .41094 L
.33237 .46044 L
.36283 .50373 L
.39213 .53953 L
.40841 .55643 L
.42332 .57 L
.43888 .58164 L
.45333 .59034 L
.4573 .59272 L
.45925 .5939 L
.4601 .59441 L
.46104 .59497 L
.46189 .59532 L
.46267 .59553 L
.4644 .59599 L
.46803 .59695 L
.4758 .599 L
.48408 .60119 L
.48795 .60221 L
.49 .60276 L
.49112 .60305 L
.49166 .6032 L
.49217 .60332 L
.49308 .60324 L
.49406 .60316 L
.49615 .60298 L
.49983 .60266 L
.5142 .60143 L
.51787 .60112 L
.51988 .60095 L
.52087 .60086 L
.52179 .60078 L
.52265 .60071 L
.52356 .60039 L
.52549 .59956 L
.52885 .59811 L
.54487 .59119 L
.56003 .58255 L
.57421 .57183 L
.60426 .5433 L
.63622 .50476 L
Mistroke
.667 .46119 L
.69661 .41509 L
.72812 .36346 L
.75845 .31301 L
.79069 .26037 L
.82175 .21209 L
.85163 .16897 L
.88342 .12739 L
.91403 .0919 L
.94347 .0594 L
.9748 .01676 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[543]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00??ooool3o`0000Cooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool3o`0001[ooooo0ol0000Jooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`?o00006Oooool2o`0001[ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0000Koooo
o`?o00002_ooool003gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Hoooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Hooooo`05o`000?oooooo
ooooooooool000006_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00005oooool01?l0003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Iooooo`05o`000?ooooooooooooooool000002Oooool003Gooooo1Ol0
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004?ooool5o`0000Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003ooooo
ooooo`0Aooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo
00Co0000oooooooooooo00006oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool01oooool003gooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`07ooooo`00?Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
01[ooooo00?o0000ooooooooool01Oooool4o`0001Wooooo1?l0000Jooooo`05o`000?oooooooooo
ooooool000001oooool4o`0001Sooooo00Co0000oooooooooooo00006Oooool01Ol0003ooooooooo
oooooooo000000Oooooo1?l0000Jooooo`Co00002_ooool003cooooo0_l00004ooooo`04o`000?oo
ooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool06Oooool01?l0003oooooooooool0000Iooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo000mooooo`03o`000?oooooo
oooo00?ooooo0_l0000Gooooo`Go00001oooool5o`0001Sooooo1Ol0000Jooooo`?o00002?ooool5
o`0001Sooooo0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol00009ooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`008Ooooooho`0000Oooooo000Qoooo
o`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool01?l0003oooooo`000?l00007ooooo`002?ooool2o`0000Cooooo00Co0000oooo
oooooooooooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`2Yooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:?ooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
0007ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool00_ooool2o`0000Oooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo
00Ko0000ooooooooooooooooo`000?ooool4o`0000Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2Rooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00007ooooo`07o`000?oooooooooo
ooooool0003oooooo`000008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0XOoo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool000Sooooo0_l00009ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`2Pooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`008Oooool2o`0000Sooooo00?o0000ooooooooool0Woooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`008Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`2Mooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`05ooooo`008Oooool2o`0000_ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00Wooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo09cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Voooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0;ooooo`;o00001oooool0027ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo09Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Uoooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool0027o
oooo0_l0000Aooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0?ooooo`;o00001oooool0027ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`2Eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`05ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`003Oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo09Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00Gooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
0_ooool2o`0001Cooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01;ooooo0_l00007ooooo`003Oooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Booooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`003Ooo
ool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo000>ooooo`;o00002?oo
ool5o`0000Cooooo0_l0000Hooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Fooooo`;o00001oooool0027ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`2>ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
08gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0S?ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool0027ooooo
0_l0000Kooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Iooooo`;o00001oooool0027ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`2;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08[ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000Nooooo`03
o`000?oooooooooo08Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Mooooo`;o
00001oooool0027ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`28ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000Qooooo`03o`000?oooooooooo
08Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Pooooo`;o00001oooool000So
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3o`0000Go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`001oooool01?l0003ooooo
ooooool00009ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooo
oooo00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0002Cooooo00?o0000oooo
ooooool0Poooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02?ooooo0_l00007oooo
o`001oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo000000?o00001Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`00
00Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`05ooooo`002?ooool2o`0000Sooooo1Ol000000ooooooo0000o`000003
o`0000Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`008Oooool2o`00
02Oooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02Gooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo083o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Go
oooo000Qooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool0027ooooo0_l0
000Yooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Wooooo`;o00001oooool0027ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1m
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07gooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000/ooooo`03o`00
0?oooooooooo07_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Zooooo`;o0000
1oooool0027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`05ooooo`008Oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000^ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0/ooooo`;o00001oooool0027ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`05ooooo`006Oooool3o`0000Gooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`05ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01Oooool001[ooooo00?o0000oooo
ooooool01?ooool2o`00037ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02oooooo0_l00007ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01Oooool001[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Gooooo000Iooooo`;o00001_oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Gooooo000Jooooo`03o`000?oooooo
oooo00Cooooo0_l0000cooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0booooo`;o00001oooool0027ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Go
oooo000Qooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool0027ooooo0_l0
000fooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0dooooo`;o00001oooool0027ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000hooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0fooooo`;o0000
1oooool0027ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`05ooooo`008Oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000kooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`;o00001oooool000Oooooo
0ol00004ooooo`04o`000?ooooooooooooooo`Go00000_ooool3o`0000Gooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`05ooooo`002?ooool00ol0003oooooooooo`08ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool01Oooool000Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0kooooo`;o00001oooool000Sooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`05ooooo`002?ooool00ol0003ooooooooo
o`07ooooo`06o`000?ooooooooooooooool0003ooooo1?l00005ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool01Oooool000Oooooo0_l00009ooooo`07o`000?ooooooooooooooool0
003oooooo`000008ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool000So
oooo00?o0000ooooooooool02?ooool3o`0000;ooooo1Ol00004ooooo`;o0000?oooool00ol0003o
ooooooooo`1Xooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?Oooool2o`0000Oo
oooo000Qooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000@Oooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?oooool2o`0000Oooooo000Qooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`;o0000A?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0@_ooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`1Rooooo`05o`000?ooooooooooooooool00000A_ooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo06;ooooo00Co0000oooooooo
oooo0000Aoooool00ol0003oooooooooo`05ooooo`008Oooool2o`0004Kooooo00?o0000oooooooo
ool0HOooool01?l0003oooooooooool00016ooooo`;o00001oooool000gooooo0ol00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooo`000018ooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`00
0?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool0H?ooool00ol0003oooooo`000018ooooo`03o`000?oooooooooo00Go
oooo000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo05oooooo0_l00019ooooo`03o`000?oooooooooo00Gooooo
000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool2o`0004Sooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`17ooooo`;o00001oooool000kooooo00?o0000
ooooooooool01oooool4o`0000Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01Oooool000gooooo0_l00009oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Loooo
o`;o0000B_ooool00ol0003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`07ooooo`Go
00001?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo05cooooo0_l0001:ooooo`03
o`000?oooooooooo00Gooooo000Qooooo`;o0000Boooool00ol0003oooooooooo`1Jooooo`03o`00
0?oooooo000004Wooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo05Sooooo00Co0000oooooooooooo0000B_ooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo05Sooooo00Co0000oooooooooooo0000
B_ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo05Kooooo00Go0000ooooooooooooooooo`00001:ooooo`03o`000?oooooooooo00Gooooo
000Qooooo`;o0000C_ooool00ol0003oooooooooo`1Eooooo`05o`000?ooooooooooooooool00000
BOooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01Ooo
ool0027ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000D?ooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Aoooool2o`0000Oo
oooo000Qooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`008Oooool2o`0005?ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Oooooo0_l00007
ooooo`008Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Gooooo0007ooooo`?o
00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool01Oooool000Sooooo00?o0000ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00Gooooo0008ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000EOooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Aoooool2o`0000Oooooo
0008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01Oooool000Sooooo00?o0000
ooooooooool02oooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`05ooooo`001oooool2o`0000Wooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000Sooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`002?ooool0
0ol0003oooooooooo`07ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o0000F?ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Aoooool2
o`0000Oooooo000Qooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000G?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Aoooool2o`0000Oooooo000Q
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1Mooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo00Gooooo000Qooooo`;o0000Goooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0Aoooool2o`0000Oooooo000Qooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00Gooooo000Qooooo`;o0000Hoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0Aoooool2o`0000Oooooo000Hooooo`Go00001?ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo00Gooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01Oooool001_ooooo00?o0000
ooooooooool00oooool2o`0006Oooooo0_l0000Rooooo`;o00007Oooool00ol0003oooooooooo`17
ooooo`;o00001oooool001Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool01Oooool001Sooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo06Wooooo0_l0000Mooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`006Oooool3o`0000Gooooo00?o0000oooo
ooooool0Joooool00ol0003oooooooooo`0Hooooo`;o00008Oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`;o0000KOooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0Aoooool2o`0000Oooooo000Qooooo`03o`00
0?oooooooooo06gooooo0_l0000Cooooo`?o00009?ooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo06oooooo1?l0000=ooooo`;o00009ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo07?ooooo1?l00003ooooo`Ko0000:Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`;o0000Moooool4o`0002oooooo00?o0000ooooooooool0Aoooool2o`00
00Oooooo000Qooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`05ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oo
oooo000QooooooSo00001oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00<oo
oooo0ol0001>ooooo`00d?ooool00ol0003oooooooooo`1=ooooo`00I?ooool00ol0003oooooo`00
0003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool3o`0000?ooooo0ol0
0004ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00008ooooo`Go000000Go
ooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003ooooo`?o00000_ooool3o`000003oooo
ool0003o000000Co00000_ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04cooooo
001Tooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
ooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04cooooo
001Tooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`03o`000?oooooo000000;ooooo1Ol0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`Go00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000COooool006?ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`?o00000oooool2o`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001=
ooooo`00Hoooool01Ol0003oooooo`000?oooooo000000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000?ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o
000000;ooooo0ol00002ooooo`Co00000_ooool4o`0000[ooooo00Co0000oooooooooooooooo1?l0
0002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0003o0000
0oooool4o`0000;ooooo0_l000000ooooooo0000o`00001<ooooo`00Hoooool01Ol0003oooooo`00
0?oooooo000001Cooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Cooooo`00
Hoooool6o`0001;ooooo1Ol0000Dooooo`03o`000?oooooooooo00Sooooo1Ol00008ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Cooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14.3444, 0.0284363, \
0.0698135, 0.0128703}},
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.696161 0.0579522 0.0998602 0.0545719 [
[.11664 -0.0125 -9 -9 ]
[.11664 -0.0125 9 0 ]
[.26152 -0.0125 -12 -9 ]
[.26152 -0.0125 12 0 ]
[.4064 -0.0125 -6 -9 ]
[.4064 -0.0125 6 0 ]
[.55128 -0.0125 -12 -9 ]
[.55128 -0.0125 12 0 ]
[.69616 -0.0125 -3 -9 ]
[.69616 -0.0125 3 0 ]
[.84104 -0.0125 -9 -9 ]
[.84104 -0.0125 9 0 ]
[.98592 -0.0125 -3 -9 ]
[.98592 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09986 -6 -4.5 ]
[-0.0125 .09986 0 4.5 ]
[-0.0125 .209 -6 -4.5 ]
[-0.0125 .209 0 4.5 ]
[-0.0125 .31815 -6 -4.5 ]
[-0.0125 .31815 0 4.5 ]
[-0.0125 .42729 -6 -4.5 ]
[-0.0125 .42729 0 4.5 ]
[-0.0125 .53644 -6 -4.5 ]
[-0.0125 .53644 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11664 0 m
.11664 .00625 L
s
[(-10)] .11664 -0.0125 0 1 Mshowa
.26152 0 m
.26152 .00625 L
s
[(-7.5)] .26152 -0.0125 0 1 Mshowa
.4064 0 m
.4064 .00625 L
s
[(-5)] .4064 -0.0125 0 1 Mshowa
.55128 0 m
.55128 .00625 L
s
[(-2.5)] .55128 -0.0125 0 1 Mshowa
.69616 0 m
.69616 .00625 L
s
[(0)] .69616 -0.0125 0 1 Mshowa
.84104 0 m
.84104 .00625 L
s
[(2.5)] .84104 -0.0125 0 1 Mshowa
.98592 0 m
.98592 .00625 L
s
[(5)] .98592 -0.0125 0 1 Mshowa
.125 Mabswid
.14562 0 m
.14562 .00375 L
s
.17459 0 m
.17459 .00375 L
s
.20357 0 m
.20357 .00375 L
s
.23254 0 m
.23254 .00375 L
s
.2905 0 m
.2905 .00375 L
s
.31947 0 m
.31947 .00375 L
s
.34845 0 m
.34845 .00375 L
s
.37742 0 m
.37742 .00375 L
s
.43538 0 m
.43538 .00375 L
s
.46435 0 m
.46435 .00375 L
s
.49333 0 m
.49333 .00375 L
s
.5223 0 m
.5223 .00375 L
s
.58026 0 m
.58026 .00375 L
s
.60923 0 m
.60923 .00375 L
s
.63821 0 m
.63821 .00375 L
s
.66719 0 m
.66719 .00375 L
s
.72514 0 m
.72514 .00375 L
s
.75411 0 m
.75411 .00375 L
s
.78309 0 m
.78309 .00375 L
s
.81207 0 m
.81207 .00375 L
s
.87002 0 m
.87002 .00375 L
s
.89899 0 m
.89899 .00375 L
s
.92797 0 m
.92797 .00375 L
s
.95695 0 m
.95695 .00375 L
s
.08766 0 m
.08766 .00375 L
s
.05869 0 m
.05869 .00375 L
s
.02971 0 m
.02971 .00375 L
s
.00074 0 m
.00074 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09986 m
.00625 .09986 L
s
[(0)] -0.0125 .09986 1 0 Mshowa
0 .209 m
.00625 .209 L
s
[(2)] -0.0125 .209 1 0 Mshowa
0 .31815 m
.00625 .31815 L
s
[(4)] -0.0125 .31815 1 0 Mshowa
0 .42729 m
.00625 .42729 L
s
[(6)] -0.0125 .42729 1 0 Mshowa
0 .53644 m
.00625 .53644 L
s
[(8)] -0.0125 .53644 1 0 Mshowa
.125 Mabswid
0 .12715 m
.00375 .12715 L
s
0 .15443 m
.00375 .15443 L
s
0 .18172 m
.00375 .18172 L
s
0 .23629 m
.00375 .23629 L
s
0 .26358 m
.00375 .26358 L
s
0 .29086 m
.00375 .29086 L
s
0 .34543 m
.00375 .34543 L
s
0 .37272 m
.00375 .37272 L
s
0 .40001 m
.00375 .40001 L
s
0 .45458 m
.00375 .45458 L
s
0 .48186 m
.00375 .48186 L
s
0 .50915 m
.00375 .50915 L
s
0 .07257 m
.00375 .07257 L
s
0 .04529 m
.00375 .04529 L
s
0 .018 m
.00375 .018 L
s
0 .56372 m
.00375 .56372 L
s
0 .59101 m
.00375 .59101 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11664 .61178 m
.11664 .61803 L
s
.26152 .61178 m
.26152 .61803 L
s
.4064 .61178 m
.4064 .61803 L
s
.55128 .61178 m
.55128 .61803 L
s
.69616 .61178 m
.69616 .61803 L
s
.84104 .61178 m
.84104 .61803 L
s
.98592 .61178 m
.98592 .61803 L
s
.125 Mabswid
.14562 .61428 m
.14562 .61803 L
s
.17459 .61428 m
.17459 .61803 L
s
.20357 .61428 m
.20357 .61803 L
s
.23254 .61428 m
.23254 .61803 L
s
.2905 .61428 m
.2905 .61803 L
s
.31947 .61428 m
.31947 .61803 L
s
.34845 .61428 m
.34845 .61803 L
s
.37742 .61428 m
.37742 .61803 L
s
.43538 .61428 m
.43538 .61803 L
s
.46435 .61428 m
.46435 .61803 L
s
.49333 .61428 m
.49333 .61803 L
s
.5223 .61428 m
.5223 .61803 L
s
.58026 .61428 m
.58026 .61803 L
s
.60923 .61428 m
.60923 .61803 L
s
.63821 .61428 m
.63821 .61803 L
s
.66719 .61428 m
.66719 .61803 L
s
.72514 .61428 m
.72514 .61803 L
s
.75411 .61428 m
.75411 .61803 L
s
.78309 .61428 m
.78309 .61803 L
s
.81207 .61428 m
.81207 .61803 L
s
.87002 .61428 m
.87002 .61803 L
s
.89899 .61428 m
.89899 .61803 L
s
.92797 .61428 m
.92797 .61803 L
s
.95695 .61428 m
.95695 .61803 L
s
.08766 .61428 m
.08766 .61803 L
s
.05869 .61428 m
.05869 .61803 L
s
.02971 .61428 m
.02971 .61803 L
s
.00074 .61428 m
.00074 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09986 m
1 .09986 L
s
.99375 .209 m
1 .209 L
s
.99375 .31815 m
1 .31815 L
s
.99375 .42729 m
1 .42729 L
s
.99375 .53644 m
1 .53644 L
s
.125 Mabswid
.99625 .12715 m
1 .12715 L
s
.99625 .15443 m
1 .15443 L
s
.99625 .18172 m
1 .18172 L
s
.99625 .23629 m
1 .23629 L
s
.99625 .26358 m
1 .26358 L
s
.99625 .29086 m
1 .29086 L
s
.99625 .34543 m
1 .34543 L
s
.99625 .37272 m
1 .37272 L
s
.99625 .40001 m
1 .40001 L
s
.99625 .45458 m
1 .45458 L
s
.99625 .48186 m
1 .48186 L
s
.99625 .50915 m
1 .50915 L
s
.99625 .07257 m
1 .07257 L
s
.99625 .04529 m
1 .04529 L
s
.99625 .018 m
1 .018 L
s
.99625 .56372 m
1 .56372 L
s
.99625 .59101 m
1 .59101 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .09986 m
1 .09986 L
s
.69616 0 m
.69616 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .01472 Mdot
.94557 .0196 Mdot
.91492 .02257 Mdot
.88426 .02425 Mdot
.85357 .02518 Mdot
.82288 .02588 Mdot
.79216 .02681 Mdot
.76144 .02839 Mdot
.73071 .03098 Mdot
.69996 .03492 Mdot
.66921 .04049 Mdot
.63845 .04793 Mdot
.60769 .05745 Mdot
.57693 .06921 Mdot
.54616 .08332 Mdot
.51539 .09986 Mdot
.48461 .11888 Mdot
.45384 .14037 Mdot
.42307 .16429 Mdot
.39231 .19057 Mdot
.36155 .21907 Mdot
.33079 .24965 Mdot
.30004 .28209 Mdot
.26929 .31615 Mdot
.23856 .35155 Mdot
.20784 .38795 Mdot
.17712 .42498 Mdot
.14643 .46223 Mdot
.11574 .49922 Mdot
.08508 .53545 Mdot
.05443 .57035 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.05372 .57112 L
.08634 .53395 L
.11698 .49773 L
.14644 .46221 L
.1778 .42416 L
.20799 .38777 L
.24008 .3498 L
.27099 .31427 L
.30073 .28136 L
.33237 .24808 L
.36283 .21788 L
.39213 .19074 L
.42332 .1641 L
.45333 .14077 L
.48525 .11849 L
.51599 .09953 L
.54556 .08364 L
.57703 .06917 L
.60732 .05759 L
.63951 .04768 L
.67053 .04025 L
.70038 .03487 L
.71582 .03289 L
.72369 .03188 L
.72802 .03133 L
.73212 .03086 L
.74008 .03019 L
.74733 .02958 L
.75407 .02901 L
.75766 .02871 L
.75967 .02854 L
.76063 .02846 L
.76152 .02839 L
.76242 .02834 L
.7634 .02829 L
.76538 .02819 L
.76899 .028 L
.77693 .02759 L
.78378 .02724 L
.78738 .02706 L
.7912 .02686 L
.79321 .02678 L
.79543 .02671 L
.79934 .0266 L
.80703 .02636 L
.82142 .02593 L
.85265 .0252 L
.86704 .02477 L
.87463 .02454 L
Mistroke
.87879 .02442 L
.88271 .0243 L
.88376 .02426 L
.88428 .02425 L
.88486 .02422 L
.88607 .02415 L
.88718 .02409 L
.89122 .02387 L
.89911 .02344 L
.90725 .02299 L
.91111 .02278 L
.9128 .02269 L
.91376 .02264 L
.91467 .02259 L
.91554 .02251 L
.91648 .02242 L
.9184 .02224 L
.92244 .02184 L
.9298 .02113 L
.93755 .02038 L
.94164 .01998 L
.94389 .01976 L
.94499 .01965 L
.946 .01953 L
.94792 .01922 L
.95 .01889 L
.95363 .01831 L
.96072 .01718 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[543]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0000Cooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool3o`0001[ooooo0ol0000Jooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`?o00006Oooool2o`0001[ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0000Koooo
o`?o00004oooool003Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Hoooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Hooooo`05o`000?oooooo
ooooooooool000006_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00005oooool01?l0003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Iooooo`05o`000?ooooooooooooooool000004_ooool002cooooo1Ol0
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004?ooool5o`0000Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003ooooo
ooooo`0Aooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo
00Co0000oooooooooooo00006oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool04?ooool003Cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0@ooooo`00=?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
01[ooooo00?o0000ooooooooool01Oooool4o`0001Wooooo1?l0000Jooooo`05o`000?oooooooooo
ooooool000001oooool4o`0001Sooooo00Co0000oooooooooooo00006Oooool01Ol0003ooooooooo
oooooooo000000Oooooo1?l0000Jooooo`Co00004oooool003?ooooo0_l00004ooooo`04o`000?oo
ooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool06Oooool01?l0003oooooooooool0000Iooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo000dooooo`03o`000?oooooo
oooo00?ooooo0_l0000Gooooo`Go00001oooool5o`0001Sooooo1Ol0000Jooooo`?o00002?ooool5
o`0001Sooooo0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol0000Booooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006?oooooho`00013ooooo000Hoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00004?ooool001Sooooo00?o0000oooo
ooooool0ZOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03
o`000?oooooooooo0:Wooooo00?o0000ooooooooool0@?ooool3o`0000Gooooo00?o0000oooooooo
ool03_ooool001Sooooo0_l0002Zooooo`03o`000?oooooooooo03[ooooo1_l000000ooooooo0000
o`000004ooooo`;o00004?ooool001Sooooo00?o0000ooooooooool0ZOooool00ol0003ooooooooo
o`0[ooooo`;o000000?oooooo`000?l000003?l0000<ooooo`03o`000?oooooooooo00kooooo000H
ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool03?ooool2o`0000;ooooo7_l00004
ooooo`;o00005?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`2Yoooo
o`03o`000?oooooooooo00Gooooo2ol00004ooooo`;o00001_ooool2o`0000Gooooo0_l0000Soooo
o`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo0:Sooooo2ol00011ooooo`03
o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo0:;ooooo0_l000001Ooooooo0000
o`000?l0003ooooo00;o0000BOooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003ooooo
ooooo`2Oooooo`Ko00001?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo
000Hooooo`;o0000Voooool5o`0000[ooooo00?o0000ooooooooool0Aoooool2o`00013ooooo000H
ooooo`03o`000?oooooooooo09Oooooo1Ol0000=ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool03_ooool001Sooooo00?o0000ooooooooool0U?ooool3o`0001;ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`2Booooo`;o
00005Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`00
0?oooooooooo08oooooo1Ol0000Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
3_ooool001Sooooo00?o0000ooooooooool0Roooool4o`0001[ooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`2;ooooo`;o00007?ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`;o0000ROooool3o`00
01kooooo00?o0000ooooooooool0Aoooool2o`00013ooooo000Hooooo`03o`000?oooooooooo08Go
oooo0ol0000Qooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo
00?o0000ooooooooool0Poooool2o`0002Cooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0>ooooo`006?ooool00ol0003oooooooooo`21ooooo`Co00009?ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo00kooooo000Aooooo`;o00001Oooool00ol0003oooooooooo`1o
ooooo`;o0000:?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000@oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0OOooool2o`0002[ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`004?ooool01?l0003oooooooooool00004
ooooooSo00004?ooool0013ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1j
ooooo`04o`000?oooooo0000o`0002_ooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0>ooooo`004?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Sooooo0_l0
000_ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool0013ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`004Oooool2o`0000Gooooo00?o0000
ooooooooool0M_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool03_ooool001Sooooo00?o0000ooooooooool0M?ooool2o`0003?ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`1cooooo`?o
0000<oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`;o0000
L_ooool2o`0003Kooooo00?o0000ooooooooool0Aoooool2o`00013ooooo000Hooooo`03o`000?oo
oooooooo06oooooo0_l0000hooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_oo
ool001Sooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0K?ooool2o`00
03_ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003o
ooooooooo`1[ooooo`?o0000>oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00ko
oooo000Hooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000H
ooooo`;o0000JOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo04Oooooo0_l0000@
ooooo`006?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`1Uooooo`;o
0000@_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`00
0?oooooooooo06Cooooo0ol00012ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
3_ooool001Sooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool0
01Sooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool03_ooool001Sooooo0_l0001Qooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool0Aoooool2o`00013ooooo000Hooooo`03o`000?oooooooooo05gooooo
0ol00019ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o
0000ooooooooool0GOooool2o`0004[ooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0>ooooo`006?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`003oooool5o`0000Cooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool03_ooool0013ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>oooo
o`004Oooool00ol0003oooooooooo`04ooooo`;o0000Foooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo04Oooooo0_l0000@ooooo`004_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo00kooooo000?ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`1Fooooo`?o0000D?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo
000?ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Fooooo`;o0000
DOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000@ooooo`?o00001Ooo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0>ooooo`006?ooool2o`0005?ooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooooooo`17ooooo`;o00004?ooool001Sooooo00?o0000ooooooooool0DOooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0C_ooool2o`0005Wooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`1>oooo
o`;o0000FOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
F_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`;o0000C?oo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo04Oooooo0_l0000@ooooo`006?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`16ooooo`;o0000HOooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo04Kooooo0_l0
001Qooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool03_ooool001Sooooo0_l00016ooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0Aoooool2o`00013ooooo000Hooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Aooooo`?o00001?ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0>ooooo`004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03oooooo0_l0001Xooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool000oo
oooo1Ol00004ooooo`;o0000@?ooool2o`0006Sooooo00?o0000ooooooooool0Aoooool2o`00013o
oooo000?ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool0013ooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`004Oooool2o`0000Gooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool03_ooool001;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>
ooooo`006?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo06cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`00
6?ooool2o`0003[ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`17ooooo`;o0000
4?ooool001Sooooo00?o0000ooooooooool0=oooool2o`00073ooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0gooooo`;o0000L?ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00kooooo000Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo
000Hooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`;o0000=?ooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo04Oooooo0_l0000@ooooo`006?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>oooo
o`006?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo07Gooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0`ooooo`;o0000
Moooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oo
oooooooo033ooooo0_l0001gooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_oo
ool001Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001So
oooo0_l0000^ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0Aoooool2o`00013o
oooo000Hooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0N_ooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000H
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo00kooooo000@ooooo`?o00001Oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo07cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>oooo
o`003oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0:?ooool2o`00
07oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`003oooool01Ol0003o
oooooooooooooooo000000Cooooo0_l0000Yooooo`;o0000Ooooool00ol0003oooooooooo`17oooo
o`;o00004?ooool000oooooo1?l00005ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000?ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool03_ooool0013ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0>ooooo`004Oooool2o`0000Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`21ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool0
01Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo
0_l0000Tooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0Aoooool2o`00013ooooo
000Hooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo023ooooo0_l00027
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooo
ooooool08?ooool2o`0008Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>oooo
o`006?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo08Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0>ooooo`006?ooool2o`0001kooooo00?o0000ooooooooool0ROooool0
0ol0003oooooooooo`17ooooo`;o00004?ooool001Sooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`29ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001So
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`2;ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o
0000ooooooooool06Oooool2o`0008kooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0>ooooo`006?ooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo00kooooo000Hooooo`;o00006_ooool00ol0003oooooooooo`2=oooo
o`03o`000?oooooooooo04Oooooo0_l0000@ooooo`006?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`00
6?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo093ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0>ooooo`004?ooool3o`0000Gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`2Booooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool000oo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0Toooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000?ooooo`05
o`000?ooooooooooooooool000001?ooool2o`0001;ooooo0_l0002Fooooo`03o`000?oooooooooo
04Oooooo0_l0000@ooooo`004?ooool3o`0000Gooooo00?o0000ooooooooool04Oooool2o`0009Ko
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`003oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2Eooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool000oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0U_ooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00kooooo000@ooooo`?o00001Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0>ooooo`006?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09Sooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>
ooooo`006?ooool2o`0000gooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`17oooo
o`;o00004?ooool001Sooooo00?o0000ooooooooool02_ooool2o`0009gooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0:ooooo`;o0000
WOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo00kooooo000Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0WOooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00kooooo000Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Woooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`;o00001oooool00ol0003ooooo
ooooo`2Pooooo`03o`000?oooooooooo04Oooooo0_l0000@ooooo`006?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0>ooooo`006?ooool00ol0003oooooooooo`02ooooo`?o0000Y?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo00;ooooo0_l0002Uoooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooooooo
ool0ZOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo00004?ooool001Sooooon?l0000@ooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00:_ooool3o`0008[ooooo00?o0000oooooooo
ool0:oooool3o`0001Gooooo00?o0000ooooooooool08?ooool002_ooooo00?o0000ooooooooool0
R?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
7oooool002Gooooo0ol00003ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000ooo
ool4o`000003ooooool0003o000000?o00001oooool3o`0000Cooooo1?l00003ooooo`;o00000_oo
ool6o`0000Kooooo1?l00002ooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000o`00
0003o`0000;ooooo0ol00002ooooo`?o00001?ooool3o`0000;ooooo0ol000001?oooooo0000o`00
0?ooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
0oooool4o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1Ol00002ooooo`?o0000
0_ooool3o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000;ooooo2_l00005ooooo`03
o`000?oooooooooo01kooooo000Tooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo000Toooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool5o`0000;ooooo00?o0000
ooooooooool00_ooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`Go0000
2?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000?o
oooo00?o0000ooooool000000_ooool5o`0000?ooooo00Co0000oooooooooooooooo1Ol00002oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000;ooooo0ol00005ooooo`03o`000?oooooooooo01kooooo000Tooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`08ooooo`?o00000_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?oooooooooo
ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001Oooool0
1_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool07_ooool002Cooooo00Ko
0000ooooooooooooooooo`000?ooool4o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000?o
oooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool2o`00
00?ooooo1?l00003ooooo`?o00002Oooool01Ol0003oooooooooool0003ooooo00?o00001?ooool4
o`0000;ooooo1?l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00002
ooooo`Co00000oooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo1_l00000
0ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000;ooooo1?l00003ooooo`Wo00000oooool3o`0000?ooooo1?l00004
ooooo`03o`000?oooooooooo01kooooo000Tooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Oooooo`009Oooool3o`0000Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0=ooooo`?o00002Oooool4o`0000Wooooo00?o0000ooooooooool00_oo
ool2o`0000[ooooo1?l00004ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o0000;_oo
ool00ol0003oooooooooo`0Hooooo`?o00005_ooool00ol0003oooooooooo`02ooooo`;o00002ooo
ool00ol0003oooooooooo`0Pooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.716, -2.72624, \
0.0698135, 0.0741379}},
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 7, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 2, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 7, SurfaceNumber -> 1, 
        WaveFrontID -> 2, Source -> 1}],
      Editable->False]], "Print",
  CellLabel->"From In[543]:=",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.694048 0.0578888 -135610 302.259 [
[.11516 -0.0125 -9 -9 ]
[.11516 -0.0125 9 0 ]
[.25988 -0.0125 -12 -9 ]
[.25988 -0.0125 12 0 ]
[.4046 -0.0125 -6 -9 ]
[.4046 -0.0125 6 0 ]
[.54933 -0.0125 -12 -9 ]
[.54933 -0.0125 12 0 ]
[.69405 -0.0125 -3 -9 ]
[.69405 -0.0125 3 0 ]
[.83877 -0.0125 -9 -9 ]
[.83877 -0.0125 9 0 ]
[.98349 -0.0125 -3 -9 ]
[.98349 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0034 -42 -4.5 ]
[-0.0125 .0034 0 4.5 ]
[-0.0125 .15453 -42 -4.5 ]
[-0.0125 .15453 0 4.5 ]
[-0.0125 .30566 -42 -4.5 ]
[-0.0125 .30566 0 4.5 ]
[-0.0125 .45679 -42 -4.5 ]
[-0.0125 .45679 0 4.5 ]
[-0.0125 .60792 -42 -4.5 ]
[-0.0125 .60792 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11516 0 m
.11516 .00625 L
s
[(-10)] .11516 -0.0125 0 1 Mshowa
.25988 0 m
.25988 .00625 L
s
[(-7.5)] .25988 -0.0125 0 1 Mshowa
.4046 0 m
.4046 .00625 L
s
[(-5)] .4046 -0.0125 0 1 Mshowa
.54933 0 m
.54933 .00625 L
s
[(-2.5)] .54933 -0.0125 0 1 Mshowa
.69405 0 m
.69405 .00625 L
s
[(0)] .69405 -0.0125 0 1 Mshowa
.83877 0 m
.83877 .00625 L
s
[(2.5)] .83877 -0.0125 0 1 Mshowa
.98349 0 m
.98349 .00625 L
s
[(5)] .98349 -0.0125 0 1 Mshowa
.125 Mabswid
.1441 0 m
.1441 .00375 L
s
.17305 0 m
.17305 .00375 L
s
.20199 0 m
.20199 .00375 L
s
.23094 0 m
.23094 .00375 L
s
.28883 0 m
.28883 .00375 L
s
.31777 0 m
.31777 .00375 L
s
.34672 0 m
.34672 .00375 L
s
.37566 0 m
.37566 .00375 L
s
.43355 0 m
.43355 .00375 L
s
.46249 0 m
.46249 .00375 L
s
.49144 0 m
.49144 .00375 L
s
.52038 0 m
.52038 .00375 L
s
.57827 0 m
.57827 .00375 L
s
.60721 0 m
.60721 .00375 L
s
.63616 0 m
.63616 .00375 L
s
.6651 0 m
.6651 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.75194 0 m
.75194 .00375 L
s
.78088 0 m
.78088 .00375 L
s
.80983 0 m
.80983 .00375 L
s
.86771 0 m
.86771 .00375 L
s
.89666 0 m
.89666 .00375 L
s
.9256 0 m
.9256 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.08622 0 m
.08622 .00375 L
s
.05727 0 m
.05727 .00375 L
s
.02833 0 m
.02833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0034 m
.00625 .0034 L
s
[(448.654)] -0.0125 .0034 1 0 Mshowa
0 .15453 m
.00625 .15453 L
s
[(448.654)] -0.0125 .15453 1 0 Mshowa
0 .30566 m
.00625 .30566 L
s
[(448.655)] -0.0125 .30566 1 0 Mshowa
0 .45679 m
.00625 .45679 L
s
[(448.655)] -0.0125 .45679 1 0 Mshowa
0 .60792 m
.00625 .60792 L
s
[(448.656)] -0.0125 .60792 1 0 Mshowa
.125 Mabswid
0 .03363 m
.00375 .03363 L
s
0 .06385 m
.00375 .06385 L
s
0 .09408 m
.00375 .09408 L
s
0 .1243 m
.00375 .1243 L
s
0 .18476 m
.00375 .18476 L
s
0 .21498 m
.00375 .21498 L
s
0 .24521 m
.00375 .24521 L
s
0 .27543 m
.00375 .27543 L
s
0 .33589 m
.00375 .33589 L
s
0 .36611 m
.00375 .36611 L
s
0 .39634 m
.00375 .39634 L
s
0 .42656 m
.00375 .42656 L
s
0 .48702 m
.00375 .48702 L
s
0 .51724 m
.00375 .51724 L
s
0 .54747 m
.00375 .54747 L
s
0 .57769 m
.00375 .57769 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11516 .61178 m
.11516 .61803 L
s
.25988 .61178 m
.25988 .61803 L
s
.4046 .61178 m
.4046 .61803 L
s
.54933 .61178 m
.54933 .61803 L
s
.69405 .61178 m
.69405 .61803 L
s
.83877 .61178 m
.83877 .61803 L
s
.98349 .61178 m
.98349 .61803 L
s
.125 Mabswid
.1441 .61428 m
.1441 .61803 L
s
.17305 .61428 m
.17305 .61803 L
s
.20199 .61428 m
.20199 .61803 L
s
.23094 .61428 m
.23094 .61803 L
s
.28883 .61428 m
.28883 .61803 L
s
.31777 .61428 m
.31777 .61803 L
s
.34672 .61428 m
.34672 .61803 L
s
.37566 .61428 m
.37566 .61803 L
s
.43355 .61428 m
.43355 .61803 L
s
.46249 .61428 m
.46249 .61803 L
s
.49144 .61428 m
.49144 .61803 L
s
.52038 .61428 m
.52038 .61803 L
s
.57827 .61428 m
.57827 .61803 L
s
.60721 .61428 m
.60721 .61803 L
s
.63616 .61428 m
.63616 .61803 L
s
.6651 .61428 m
.6651 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.75194 .61428 m
.75194 .61803 L
s
.78088 .61428 m
.78088 .61803 L
s
.80983 .61428 m
.80983 .61803 L
s
.86771 .61428 m
.86771 .61803 L
s
.89666 .61428 m
.89666 .61803 L
s
.9256 .61428 m
.9256 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.08622 .61428 m
.08622 .61803 L
s
.05727 .61428 m
.05727 .61803 L
s
.02833 .61428 m
.02833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0034 m
1 .0034 L
s
.99375 .15453 m
1 .15453 L
s
.99375 .30566 m
1 .30566 L
s
.99375 .45679 m
1 .45679 L
s
.99375 .60792 m
1 .60792 L
s
.125 Mabswid
.99625 .03363 m
1 .03363 L
s
.99625 .06385 m
1 .06385 L
s
.99625 .09408 m
1 .09408 L
s
.99625 .1243 m
1 .1243 L
s
.99625 .18476 m
1 .18476 L
s
.99625 .21498 m
1 .21498 L
s
.99625 .24521 m
1 .24521 L
s
.99625 .27543 m
1 .27543 L
s
.99625 .33589 m
1 .33589 L
s
.99625 .36611 m
1 .36611 L
s
.99625 .39634 m
1 .39634 L
s
.99625 .42656 m
1 .42656 L
s
.99625 .48702 m
1 .48702 L
s
.99625 .51724 m
1 .51724 L
s
.99625 .54747 m
1 .54747 L
s
.99625 .57769 m
1 .57769 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.69405 0 m
.69405 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .60332 Mdot
.94569 .56206 Mdot
.91514 .51512 Mdot
.88455 .46428 Mdot
.85392 .41119 Mdot
.82326 .35735 Mdot
.79256 .30413 Mdot
.76184 .25276 Mdot
.73109 .20436 Mdot
.70032 .15989 Mdot
.66953 .12021 Mdot
.63873 .08604 Mdot
.60791 .05799 Mdot
.57709 .03653 Mdot
.54625 .02203 Mdot
.51542 .01472 Mdot
.48458 .01472 Mdot
.45375 .02203 Mdot
.42291 .03653 Mdot
.39209 .05799 Mdot
.36127 .08604 Mdot
.33047 .12021 Mdot
.29968 .15989 Mdot
.26891 .20436 Mdot
.23816 .25277 Mdot
.20744 .30413 Mdot
.17674 .35735 Mdot
.14608 .41119 Mdot
.11545 .46428 Mdot
.08486 .51512 Mdot
.05431 .56206 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.05372 .56286 L
.08634 .51265 L
.11698 .46163 L
.14644 .41055 L
.1778 .35551 L
.20799 .3032 L
.24008 .24975 L
.27099 .20135 L
.30073 .15854 L
.33237 .1181 L
.36283 .08462 L
.39213 .05796 L
.40841 .04663 L
.41614 .04125 L
.4199 .03863 L
.42154 .03749 L
.42332 .03634 L
.42515 .03548 L
.42688 .03467 L
.43067 .03288 L
.4387 .0291 L
.44627 .02554 L
.44996 .02381 L
.45158 .02305 L
.45333 .02222 L
.45428 .0219 L
.45516 .02169 L
.45688 .02128 L
.46069 .02038 L
.46877 .01846 L
.47718 .01647 L
.4813 .01549 L
.4831 .01507 L
.48406 .01484 L
.48508 .01472 L
.486 .01472 L
.48683 .01472 L
.48847 .01472 L
.49032 .01472 L
.49114 .01472 L
.49203 .01472 L
.49293 .01472 L
.49388 .01472 L
.49589 .01472 L
.49953 .01472 L
.5035 .01472 L
.50464 .01472 L
.50573 .01472 L
.50671 .01472 L
Mistroke
.50726 .01472 L
.50777 .01472 L
.50878 .01472 L
.50973 .01472 L
.5115 .01472 L
.51341 .01472 L
.51394 .01472 L
.51449 .01472 L
.51548 .01473 L
.51643 .01495 L
.51746 .0152 L
.51933 .01564 L
.52283 .01647 L
.53071 .01834 L
.53804 .02008 L
.54163 .02093 L
.54492 .02171 L
.5458 .02192 L
.54663 .0222 L
.54749 .02261 L
.54843 .02305 L
.55221 .02483 L
.56025 .02861 L
.56863 .03255 L
.57274 .03449 L
.57653 .03627 L
.58023 .03872 L
.58415 .04145 L
.5924 .04719 L
.6068 .05722 L
.63617 .08372 L
.66744 .11789 L
.69754 .15631 L
.72954 .20211 L
.76036 .25044 L
.79001 .29986 L
.82156 .3544 L
.85193 .40769 L
.88113 .45835 L
.91223 .51028 L
.94216 .55663 L
.97398 .60033 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[543]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00A_ooool3o`0000Cooooo0_l0000Hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool3o`0001[ooooo0ol0000Iooooo`Go00000oooool00ol0003o
ooooooooo`02ooooo`?o00006?ooool2o`0001Wooooo1Ol00003ooooo`03o`000?oooooooooo00;o
oooo0ol0000Jooooo`?o00001Oooool004Oooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Gooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Hoooo
o`05o`000?ooooooooooooooool000006Oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000005_ooool01?l0003oooooooooool0000Iooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Hooooo`05o`000?ooooooooooooooool000001?oo
ool003oooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00003ooo
ool5o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`Go00001Ooo
ool00ol0003oooooooooo`0@ooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Cooooo00Co0000oooooooooooo00006_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool00_ooool004Oooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5?ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`02ooooo`00Aoooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0001Wooooo00?o0000ooooooooool01Oooool4o`0001Wooooo1?l0000Iooooo`05
o`000?ooooooooooooooool000001oooool4o`0001Oooooo00Co0000oooooooooooo00006?ooool0
1Ol0003ooooooooooooooooo000000Oooooo1?l0000Iooooo`Co00001Oooool004Kooooo0_l00004
ooooo`04o`000?ooooooooooo`0001Gooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Hooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo0017oooo
o`03o`000?oooooooooo00?ooooo0_l0000Fooooo`Go00001oooool5o`0001Sooooo1Ol0000Ioooo
o`?o00002?ooool5o`0001Oooooo0_l0000Jooooo`?o00002?ooool5o`0001Sooooo1Ol00004oooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`000_ooool3o`0000?ooooo0ol00002
ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`0000Cooooo0ol0003g
ooooo`000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool01Oooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?oooool_l00001ooooo`001Ol000000ooooooo0000o`00
0003o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooool000001?l00004ooooo`;o00001?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02o`00007ooooo00001?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo0ol00008ooooo`Co00001_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo0000007ooooo00001?oooooo
0000ooooool00003ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00?ooooo1?l00003ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool0Y?ooool00ol0003oooooooooo`17ooooo`7o00000Oooool000;ooooo0_l00004oooo
o`;o00000_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`1_ooooo`ko00009oooool0
0ol0003oooooooooo`17ooooo`7o00000Oooool000?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooooooool3o`0000[ooooo0_l00002ooooo`Go00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo06[ooooo1Ol00002ooooo`;o00001Oooool2o`0000?ooooo1Ol0000R
ooooo`03o`000?oooooooooo04Oooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1Xoooo
o`Co00005?ooool4o`00023ooooo00?o0000ooooooooool0Aoooool1o`00007ooooo000]ooooo`03
o`000?oooooooooo06Kooooo0_l0000Looooo`;o00007_ooool00ol0003oooooooooo`17ooooo`7o
00000Oooool002gooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0A_ooool2o`00007ooooo000]ooooo`03o`000?oo
oooooooo06;ooooo0ol0000Rooooo`;o00006oooool00ol0003oooooooooo`17ooooo`7o00000Ooo
ool002gooooo00?o0000ooooooooool0HOooool3o`0002?ooooo1?l0000Iooooo`03o`000?oooooo
oooo04Oooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`7o00000Oooool002go
oooo00?o0000ooooooooool0G_ooool2o`0002cooooo0_l0000Fooooo`03o`000?oooooooooo04Oo
oooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1Looooo`;o0000<?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo04Oooooo0Ol00001ooooo`00;Oooool00ol0003ooooooooo
o`1Kooooo`;o0000<_ooool2o`0001?ooooo00?o0000ooooooooool0Aoooool1o`00007ooooo000]
ooooo`03o`000?oooooooooo05[ooooo0ol0000booooo`;o00004oooool00ol0003oooooooooo`17
ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0A_ooool2o`00007ooooo000]ooooo`03
o`000?oooooooooo05Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04Oooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1Gooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`17ooooo`7o0000
0Oooool002gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0Aoooool1o`00007ooooo000]ooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo04Oooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`1Cooooo`;o0000@Oooool2o`00
00cooooo00?o0000ooooooooool0Aoooool1o`00007ooooo000]ooooo`03o`000?oooooooooo05?o
oooo0_l00011ooooo`;o00003?ooool00ol0003oooooooooo`17ooooo`7o00000Oooool002gooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0A_ooool2o`00007ooooo000]ooooo`03o`000?oooooooooo05;ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo0Ol0
0001ooooo`00;Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`17ooooo`7o00000Oooool002gooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Aoooool1o`00007ooooo000]ooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Oooooo0Ol00001ooooo`00
;Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`17ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0C?oo
ool2o`00053ooooo0_l00004ooooo`03o`000?oooooooooo04Oooooo0Ol00001ooooo`00;Oooool0
0ol0003oooooooooo`1<ooooo`;o0000D?ooool2o`0000Cooooo00?o0000ooooooooool0A_ooool2
o`00007ooooo000]ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo04Oooooo0Ol00001ooooo`00;Oooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo05;ooooo00Go0000ooooooooooooooooo`000019oooo
o`7o00000Oooool002gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Dooooo`04
o`000?ooooooooooo`0004Wooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo05Kooooo00?o0000ooooool00000BOooool1o`00007ooooo0002ooooo`?o0000
0oooool3o`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`?o0000
1?ooool3o`0000Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooo000004Wooooo0Ol00001ooooo`000oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01ol0003ooooooooooooooooo0000oooo
ool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`1Hooooo`;o0000BOooool1o`00007ooooo0005o`000003
ooooool0003o000000?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooo`000004o`0000Cooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo04Oooooo0Ol00001oooo
o`0000Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`?o00002?ooool4
o`0000Kooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`;o0000Aoooool0
0ol0003oooooooooo`1Kooooo`;o0000Aoooool2o`00007ooooo00001?oooooo0000ooooool00003
ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00?ooooo1?l00003ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0A?oo
ool2o`0005kooooo0ol00017ooooo`7o00000Oooool000;ooooo0_l00004ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`;o00001Oooool00ol0003oooooooooo`14ooooo`;o0000G_ooool3o`0004Oooooo0Ol0
0001ooooo`000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`?o00002_oo
ool2o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`1Mooooo`04o`000?ooooooooooo`0004Kooooo0Ol00001ooooo`00;Ooo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo05kooooo00Go0000oooooooooooooooo
o`000015ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`1Nooooo`05o`000?ooooooooooooooool00000AOooool1o`00007ooooo000]ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo04;ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`;o00000Oooool0
02gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0@Oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043o
oooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0oooooo`7o00000Oooool002gooooo00?o
0000ooooooooool0?Oooool2o`0006Gooooo00?o0000ooooooooool01_ooool2o`0003oooooo0Ol0
0001ooooo`00;Oooool00ol0003oooooooooo`0mooooo`;o0000IOooool00ol0003oooooooooo`06
ooooo`;o0000?oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03gooooo0Ol00001oooo
o`00;Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0looooo`;o00000Oooool002gooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
??ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03_ooooo0Ol00001ooooo`00;Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0kooooo`7o00000Oooool002gooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`1Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>_ooool1o`00
007ooooo000]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo03[ooooo0Ol00001ooooo`00;Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0iooooo`7o00000Oooool002gooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`1Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>?ooool1o`00007ooooo000]
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03Oooooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0eoooo
o`?o0000K?ooool00ol0003oooooooooo`0=ooooo`;o0000>?ooool1o`00007ooooo000]ooooo`03
o`000?oooooooooo03Gooooo0ol0001/ooooo`03o`000?oooooooooo00gooooo0_l0000hooooo`7o
00000Oooool002gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1[ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0=_ooool1o`00007ooooo000]ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03Gooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo06cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0eooooo`7o00000Oooool0
02gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0=?ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03;o
oooo0_l00001ooooo`00;Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0cooooo`7o00000Oooool002gooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0<_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo037ooooo0Ol00001
ooooo`00;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0aooooo`7o00000Oooool000;ooooo0ol00003ooooo`?o
00000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol00003ooooo`?o
00001Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0`ooooo`7o00000Oooool000?ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo02oooooo0Ol00001ooooo`001Ol000000ooooooo0000o`000003o`00
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o0000;oooool2
o`0007Cooooo00?o0000ooooooooool05Oooool2o`0002oooooo0_l00001ooooo`0000Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00003ooooo`?o00002?ooool4o`0000Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo0_l0
001dooooo`03o`000?oooooooooo01Gooooo0_l0000`ooooo`7o00000Oooool00004ooooool0003o
ooooo`0000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00oooool4o`0000;ooooo1?l00005ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02kooooo
0Ol00001ooooo`000_ooool2o`0000Cooooo0_l00002ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0]ooooo`7o00000Oooool000?ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool3o`0000[ooooo0_l00002ooooo`Go000000?oooooo`000?l00000
0ol00004ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo02gooooo0Ol00001ooooo`00;Oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0/ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1e
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:oooool1o`00007ooooo000]oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo02_ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo07Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`;o
00000Oooool002gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1gooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0:_ooool1o`00007ooooo000]ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo02Wooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo07Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Yooooo`7o00000Oooool0
02gooooo00?o0000ooooooooool09oooool2o`0007_ooooo00?o0000ooooooooool07?ooool2o`00
02Wooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Wooooo`;o0000Noooool00ol0003o
ooooooooo`0Looooo`;o0000:Oooool1o`00007ooooo000]ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Oooooo
0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`;o00000Oooool002gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0O?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Gooooo0Ol00001oooo
o`00;Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07cooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Uooooo`7o00000Oooool002gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
9?ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02?ooooo0Ol00001ooooo`00;Oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Sooooo`7o00000Oooool002gooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool2o`00
007ooooo000]ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo0Ol00001ooooo`00;Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0Qooooo`7o00000Oooool002gooooo00?o0000ooooooooool07oooool3o`0008;ooooo00?o
0000ooooooooool08oooool2o`0002;ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0O
ooooo`;o0000Poooool00ol0003oooooooooo`0Sooooo`;o00008_ooool1o`00007ooooo000]oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01oooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Oooooo`7o
00000Oooool002gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool07Oooool2o`00007ooooo000]ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01gooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo08Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Mooooo`7o00000Oooool0
02gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool07?ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01co
oooo0Ol00001ooooo`000_ooool3o`0000?ooooo0ol00002ooooo`?o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00000oooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01_ooooo
0Ol00001ooooo`000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01Oooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`26ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06_ooool1o`00
007ooooo0005o`000003ooooool0003o000000?o000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`27oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06_ooool1o`00007ooooo00001?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo0ol00008ooooo`Co00001_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`03o`000?oooooo
oooo08Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`;o00000Oooool0
0004ooooool0003oooooo`0000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00oooool4o`0000;ooooo1?l00005ooooo`03o`000?oo
oooooooo01Sooooo0_l0002:ooooo`03o`000?oooooooooo02_ooooo0_l0000Jooooo`7o00000Ooo
ool000;ooooo0_l00004ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool06?ooool2o`0008[ooooo00?o0000ooooooooool0:oooool2o`0001[ooooo0Ol0
0001ooooo`000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`?o00002_oo
ool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool06?oo
ool1o`00007ooooo000]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0R_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Oooooo0Ol00001ooooo`00;Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Gooooo`7o00000Oooool002gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`2;ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05_ooool1o`00007o
oooo000]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01Cooooo0_l00001ooooo`00;Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0Eooooo`7o00000Oooool002gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2=
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05?ooool1o`00007ooooo000]oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo01Cooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Cooooo`7o
00000Oooool002gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2?ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool04oooool1o`00007ooooo000]ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01;ooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0@ooooo`;o0000T_ooool0
0ol0003oooooooooo`0booooo`;o00004_ooool2o`00007ooooo000]ooooo`03o`000?oooooooooo
013ooooo0_l0002Booooo`03o`000?oooooooooo03;ooooo0_l0000Cooooo`7o00000Oooool002go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool04?ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo013ooooo
0Ol00001ooooo`00;Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09?ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0?ooooo`7o00000Oooool002gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool03_ooool1o`00007ooooo000]ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0U?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00kooooo0Ol00001oooo
o`00;Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo09Cooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0=ooooo`7o00000Oooool002gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
3?ooool2o`00007ooooo000]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0U_oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00cooooo0Ol00001ooooo`00;Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0;ooooo`7o00000Oooool002gooooo00?o0000ooooooooool02Oooool2o`00
09Wooooo00?o0000ooooooooool0>Oooool3o`0000_ooooo0Ol00001ooooo`00;Oooool00ol0003o
ooooooooo`09ooooo`;o0000VOooool00ol0003oooooooooo`0jooooo`;o00002oooool1o`00007o
oooo000]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0V?ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`00;Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`08ooooo`7o00000Oooool002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01_ooool2o`00007ooooo000]oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Oooooo0Ol00001ooooo`00;Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo09_ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`7o
00000Oooool002gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Looooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool01Oooool1o`00007ooooo000]ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo00Cooooo0Ol00001ooooo`000_ooool3o`0000?ooooo0ol00002ooooo`?o00001?ooool0
0ol0003oooooooooo`02ooooo`?o00000oooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00?ooooo0Ol00001ooooo`000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool01Oooool01ol0003ooooooooooooooooo0000ooooool00000
0oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool2o`000:3ooooo00?o0000ooooooooool0@Oooool2o`0000Cooooo0Ol00001ooooo`001Ol0
00000ooooooo0000o`000003o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`02ooooo`;o00000oooool2o`000:3ooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo
0_l00001ooooo`0000Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`?o
00002?ooool4o`0000Kooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo023o
oooo00Go0000ooooooooooooooooo`000001ooooo`0000Coooooo`000?oooooo00000oooool00ol0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`03
ooooo`Co00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000001ooooo`000_ooool2o`0000Cooooo0_l00002ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooooobo`00007ooooo0003ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooooooo0ol0000:ooooo`;o00000_ooool5o`0000?ooooo0_l0003hooooo`00oooooolQ
ooooo`00oooooolQooooo`00=_ooool3o`0005Sooooo0ol0000Gooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool02?ooool003Oooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool01oooool0037ooooo0ol0
0003ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000oooool4o`000003ooooool0
003o000000?o00001oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6o`0000Kooooo1Ol0
0002ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000;ooooo
1_l00007ooooo`03o`000?oooooooooo00?ooooo1?l000000ooooooo0000o`000002o`0000;ooooo
1?l00003ooooo`?o00000_ooool5o`0000?ooooo0_l000001?oooooo0000ooooooooool2o`0000?o
oooo0ol00009ooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`0000Co
oooo0_l00003ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003o0000
o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00Kooooo000`ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00006ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool0
1?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00002oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`00
0003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01_ooool0033ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool00oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool3o`00
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go00001oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo
0ol00003ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5o`0000Cooooo00?o0000oooo
ooooool01_ooool0033ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0ol0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0oooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo000`ooooo`06o`000?oooooooooooooo
ool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol00003ooooo`;o00001Oooool0
0ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co00000ooo
ool3o`0000Wooooo00?o0000ooooooooool00oooool3o`0000;ooooo1?l00003ooooo`Wo00000ooo
ool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol00003ooooo`Co00000_oo
ool3o`0000Cooooo00Co0000oooooooooooooooo0_l000001?oooooo0000o`000?ooool4o`0000?o
oooo0ol00009ooooo`?o00000_ooool3o`0000Cooooo1?l000000ooooooo0000o`000002o`0000?o
oooo0_l00003ooooo`Co00000oooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00Ko
oooo000`ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool0037ooooo0ol00009ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool3o`0000Wooooo1?l00009ooooo`03
o`000?oooooooooo00;ooooo0_l0000:ooooo`?o00005_ooool00ol0003oooooooooo`02ooooo`;o
00003Oooool00ol0003oooooooooo`06ooooo`;o00004?ooool3o`0000[ooooo00?o0000oooooooo
ool04?ooool2o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Sooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-15.2053, 448.655, \
0.0714267, 1.36797*^-5}},
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.694048 0.0578888 -0.0583287 0.315616 [
[.11516 -0.0125 -9 -9 ]
[.11516 -0.0125 9 0 ]
[.25988 -0.0125 -12 -9 ]
[.25988 -0.0125 12 0 ]
[.4046 -0.0125 -6 -9 ]
[.4046 -0.0125 6 0 ]
[.54933 -0.0125 -12 -9 ]
[.54933 -0.0125 12 0 ]
[.69405 -0.0125 -3 -9 ]
[.69405 -0.0125 3 0 ]
[.83877 -0.0125 -9 -9 ]
[.83877 -0.0125 9 0 ]
[.98349 -0.0125 -3 -9 ]
[.98349 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02058 -24 -4.5 ]
[-0.0125 .02058 0 4.5 ]
[-0.0125 .09948 -18 -4.5 ]
[-0.0125 .09948 0 4.5 ]
[-0.0125 .17838 -24 -4.5 ]
[-0.0125 .17838 0 4.5 ]
[-0.0125 .25729 -6 -4.5 ]
[-0.0125 .25729 0 4.5 ]
[-0.0125 .33619 -24 -4.5 ]
[-0.0125 .33619 0 4.5 ]
[-0.0125 .4151 -18 -4.5 ]
[-0.0125 .4151 0 4.5 ]
[-0.0125 .494 -24 -4.5 ]
[-0.0125 .494 0 4.5 ]
[-0.0125 .5729 -6 -4.5 ]
[-0.0125 .5729 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11516 0 m
.11516 .00625 L
s
[(-10)] .11516 -0.0125 0 1 Mshowa
.25988 0 m
.25988 .00625 L
s
[(-7.5)] .25988 -0.0125 0 1 Mshowa
.4046 0 m
.4046 .00625 L
s
[(-5)] .4046 -0.0125 0 1 Mshowa
.54933 0 m
.54933 .00625 L
s
[(-2.5)] .54933 -0.0125 0 1 Mshowa
.69405 0 m
.69405 .00625 L
s
[(0)] .69405 -0.0125 0 1 Mshowa
.83877 0 m
.83877 .00625 L
s
[(2.5)] .83877 -0.0125 0 1 Mshowa
.98349 0 m
.98349 .00625 L
s
[(5)] .98349 -0.0125 0 1 Mshowa
.125 Mabswid
.1441 0 m
.1441 .00375 L
s
.17305 0 m
.17305 .00375 L
s
.20199 0 m
.20199 .00375 L
s
.23094 0 m
.23094 .00375 L
s
.28883 0 m
.28883 .00375 L
s
.31777 0 m
.31777 .00375 L
s
.34672 0 m
.34672 .00375 L
s
.37566 0 m
.37566 .00375 L
s
.43355 0 m
.43355 .00375 L
s
.46249 0 m
.46249 .00375 L
s
.49144 0 m
.49144 .00375 L
s
.52038 0 m
.52038 .00375 L
s
.57827 0 m
.57827 .00375 L
s
.60721 0 m
.60721 .00375 L
s
.63616 0 m
.63616 .00375 L
s
.6651 0 m
.6651 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.75194 0 m
.75194 .00375 L
s
.78088 0 m
.78088 .00375 L
s
.80983 0 m
.80983 .00375 L
s
.86771 0 m
.86771 .00375 L
s
.89666 0 m
.89666 .00375 L
s
.9256 0 m
.9256 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.08622 0 m
.08622 .00375 L
s
.05727 0 m
.05727 .00375 L
s
.02833 0 m
.02833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02058 m
.00625 .02058 L
s
[(0.25)] -0.0125 .02058 1 0 Mshowa
0 .09948 m
.00625 .09948 L
s
[(0.5)] -0.0125 .09948 1 0 Mshowa
0 .17838 m
.00625 .17838 L
s
[(0.75)] -0.0125 .17838 1 0 Mshowa
0 .25729 m
.00625 .25729 L
s
[(1)] -0.0125 .25729 1 0 Mshowa
0 .33619 m
.00625 .33619 L
s
[(1.25)] -0.0125 .33619 1 0 Mshowa
0 .4151 m
.00625 .4151 L
s
[(1.5)] -0.0125 .4151 1 0 Mshowa
0 .494 m
.00625 .494 L
s
[(1.75)] -0.0125 .494 1 0 Mshowa
0 .5729 m
.00625 .5729 L
s
[(2)] -0.0125 .5729 1 0 Mshowa
.125 Mabswid
0 .03636 m
.00375 .03636 L
s
0 .05214 m
.00375 .05214 L
s
0 .06792 m
.00375 .06792 L
s
0 .0837 m
.00375 .0837 L
s
0 .11526 m
.00375 .11526 L
s
0 .13104 m
.00375 .13104 L
s
0 .14682 m
.00375 .14682 L
s
0 .1626 m
.00375 .1626 L
s
0 .19416 m
.00375 .19416 L
s
0 .20994 m
.00375 .20994 L
s
0 .22573 m
.00375 .22573 L
s
0 .24151 m
.00375 .24151 L
s
0 .27307 m
.00375 .27307 L
s
0 .28885 m
.00375 .28885 L
s
0 .30463 m
.00375 .30463 L
s
0 .32041 m
.00375 .32041 L
s
0 .35197 m
.00375 .35197 L
s
0 .36775 m
.00375 .36775 L
s
0 .38353 m
.00375 .38353 L
s
0 .39931 m
.00375 .39931 L
s
0 .43088 m
.00375 .43088 L
s
0 .44666 m
.00375 .44666 L
s
0 .46244 m
.00375 .46244 L
s
0 .47822 m
.00375 .47822 L
s
0 .50978 m
.00375 .50978 L
s
0 .52556 m
.00375 .52556 L
s
0 .54134 m
.00375 .54134 L
s
0 .55712 m
.00375 .55712 L
s
0 .00479 m
.00375 .00479 L
s
0 .58868 m
.00375 .58868 L
s
0 .60446 m
.00375 .60446 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11516 .61178 m
.11516 .61803 L
s
.25988 .61178 m
.25988 .61803 L
s
.4046 .61178 m
.4046 .61803 L
s
.54933 .61178 m
.54933 .61803 L
s
.69405 .61178 m
.69405 .61803 L
s
.83877 .61178 m
.83877 .61803 L
s
.98349 .61178 m
.98349 .61803 L
s
.125 Mabswid
.1441 .61428 m
.1441 .61803 L
s
.17305 .61428 m
.17305 .61803 L
s
.20199 .61428 m
.20199 .61803 L
s
.23094 .61428 m
.23094 .61803 L
s
.28883 .61428 m
.28883 .61803 L
s
.31777 .61428 m
.31777 .61803 L
s
.34672 .61428 m
.34672 .61803 L
s
.37566 .61428 m
.37566 .61803 L
s
.43355 .61428 m
.43355 .61803 L
s
.46249 .61428 m
.46249 .61803 L
s
.49144 .61428 m
.49144 .61803 L
s
.52038 .61428 m
.52038 .61803 L
s
.57827 .61428 m
.57827 .61803 L
s
.60721 .61428 m
.60721 .61803 L
s
.63616 .61428 m
.63616 .61803 L
s
.6651 .61428 m
.6651 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.75194 .61428 m
.75194 .61803 L
s
.78088 .61428 m
.78088 .61803 L
s
.80983 .61428 m
.80983 .61803 L
s
.86771 .61428 m
.86771 .61803 L
s
.89666 .61428 m
.89666 .61803 L
s
.9256 .61428 m
.9256 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.08622 .61428 m
.08622 .61803 L
s
.05727 .61428 m
.05727 .61803 L
s
.02833 .61428 m
.02833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02058 m
1 .02058 L
s
.99375 .09948 m
1 .09948 L
s
.99375 .17838 m
1 .17838 L
s
.99375 .25729 m
1 .25729 L
s
.99375 .33619 m
1 .33619 L
s
.99375 .4151 m
1 .4151 L
s
.99375 .494 m
1 .494 L
s
.99375 .5729 m
1 .5729 L
s
.125 Mabswid
.99625 .03636 m
1 .03636 L
s
.99625 .05214 m
1 .05214 L
s
.99625 .06792 m
1 .06792 L
s
.99625 .0837 m
1 .0837 L
s
.99625 .11526 m
1 .11526 L
s
.99625 .13104 m
1 .13104 L
s
.99625 .14682 m
1 .14682 L
s
.99625 .1626 m
1 .1626 L
s
.99625 .19416 m
1 .19416 L
s
.99625 .20994 m
1 .20994 L
s
.99625 .22573 m
1 .22573 L
s
.99625 .24151 m
1 .24151 L
s
.99625 .27307 m
1 .27307 L
s
.99625 .28885 m
1 .28885 L
s
.99625 .30463 m
1 .30463 L
s
.99625 .32041 m
1 .32041 L
s
.99625 .35197 m
1 .35197 L
s
.99625 .36775 m
1 .36775 L
s
.99625 .38353 m
1 .38353 L
s
.99625 .39931 m
1 .39931 L
s
.99625 .43088 m
1 .43088 L
s
.99625 .44666 m
1 .44666 L
s
.99625 .46244 m
1 .46244 L
s
.99625 .47822 m
1 .47822 L
s
.99625 .50978 m
1 .50978 L
s
.99625 .52556 m
1 .52556 L
s
.99625 .54134 m
1 .54134 L
s
.99625 .55712 m
1 .55712 L
s
.99625 .00479 m
1 .00479 L
s
.99625 .58868 m
1 .58868 L
s
.99625 .60446 m
1 .60446 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.69405 0 m
.69405 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01565 m
.05372 .05599 L
.08634 .09271 L
.11698 .12861 L
.14644 .16724 L
.1778 .21248 L
.20799 .25942 L
.24008 .31174 L
.27099 .36314 L
.30073 .4119 L
.33237 .46124 L
.36283 .50434 L
.39213 .53996 L
.40841 .55675 L
.42332 .57027 L
.43888 .5818 L
.45333 .59048 L
.4573 .59286 L
.45925 .59403 L
.4601 .59455 L
.46104 .59511 L
.46189 .59538 L
.46267 .59559 L
.4644 .59604 L
.46803 .59701 L
.4758 .59907 L
.48408 .60127 L
.48795 .6023 L
.49 .60284 L
.49053 .60298 L
.49112 .60314 L
.49166 .60328 L
.49217 .60332 L
.49309 .60324 L
.49406 .60316 L
.49615 .60299 L
.49983 .60269 L
.5142 .60151 L
.518 .60119 L
.51987 .60104 L
.52159 .6009 L
.52255 .60082 L
.52357 .6004 L
.52572 .59949 L
.52948 .59789 L
.5437 .59183 L
.55886 .58358 L
.57303 .57296 L
.60309 .54493 L
.63505 .50686 L
Mistroke
.66583 .4637 L
.69544 .4179 L
.72695 .36647 L
.75728 .3161 L
.78951 .26341 L
.82057 .21495 L
.85046 .17158 L
.88224 .12968 L
.91286 .09382 L
.94229 .06107 L
.97363 .01851 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[543]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00>oooool3o`0000Cooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool3o`0001_ooooo0ol0000Jooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`?o00006?ooool2o`0001[ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0000Koooo
o`?o00002oooool003cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Hoooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Iooooo`05o`000?oooooo
ooooooooool000006_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00005_ooool01?l0003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Iooooo`05o`000?ooooooooooooooool000002_ooool003Cooooo1Ol0
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004?ooool5o`0000Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`Go00001Oooool00ol0003ooooo
ooooo`0Aooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo
00Co0000oooooooooooo00006oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02?ooool003cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`08ooooo`00??ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
01[ooooo00?o0000ooooooooool01Oooool4o`0001[ooooo1?l0000Jooooo`05o`000?oooooooooo
ooooool000001oooool4o`0001Oooooo00Co0000oooooooooooo00006Oooool01Ol0003ooooooooo
oooooooo000000Oooooo1?l0000Jooooo`Co00002oooool003_ooooo0_l00004ooooo`04o`000?oo
ooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool06?ooool01?l0003oooooooooool0000Iooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo000looooo`03o`000?oooooo
oooo00?ooooo0_l0000Gooooo`Go00001oooool5o`0001Wooooo1Ol0000Jooooo`?o00002?ooool5
o`0001Oooooo0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol0000:ooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`008Ooooooho`0000Oooooo000Qoooo
o`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02o`0000Oooooo0008ooooo`;o00001?ooool01?l0003o
ooooooooooooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo0:Sooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`05ooooo`001oooool01?l0003oooooooooool00008oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0:Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0X_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool000Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`02ooooo`;o00001oooool000Oooooo00Co0000oooooooooooo00001ooo
ool01_l0003ooooooooooooooooo0000ooooo`Co00001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0:7ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2P
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`002?ooool2o`0000Wooooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo09oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo000Qooooo`;o00002?ooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool01Oooool2o`0000Oooooo000Qooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo09cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`;o00002oooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool02?ooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`2Jooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`008Oooool2o`0000gooooo00?o0000ooooooooool0VOooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00[ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0Uoooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Gooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`00
8Oooool2o`00013ooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo00kooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo09Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Gooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo000=ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0Toooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00002oooool00ol0003ooooooooo
o`02ooooo`;o00005?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool04Oooool2o`0000Oooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo097ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo000=
ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0T?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Soooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool000kooooo0_l00008
ooooo`Go00001?ooool2o`0001Sooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo01Gooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo08gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0S?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2;ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`008Ooo
ool2o`0001_ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01Wooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo08[ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0ROooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`008Oooool2o`0001kooooo
00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01cooooo
0_l00007ooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo08Oooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo000Q
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`05ooooo`008Oooool2o`00027ooooo00?o0000oooooooo
ool0QOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01oooooo0_l00007ooooo`00
2?ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?oo
ooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`001oooool01?l0003ooooo
ooooool0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo0007ooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o00009?ooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08_ooool2o`0000Oo
oooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooool000000ol00005ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool000Oooooo00Co0000oooooooooooo
00001oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Gooooo0008ooooo`;o00002?ooool5o`000003ooooool0003o0000
00?o00001?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o
00009oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool09Oooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
1Oooool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`008Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000:_ooool00ol0
003oooooooooo`1looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09oooool2o`00
00Oooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0O?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`05ooooo`008Oooool2o`0002_ooooo00?o
0000ooooooooool0Noooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Wooooo0_l0
0007ooooo`008Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07[ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`05ooooo`008Oooool2o`0002kooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02cooooo0_l00007ooooo`008Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Gooooo000Iooooo`?o00001Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`05ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`;o0000<?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0;_ooool2o`0000Oooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0MOooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01Oooool001Wooooo0_l00006
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01Oooool001[ooooo00?o0000oooo
ooooool01?ooool2o`0003?ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo037ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
1Oooool0027ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`05ooooo`008Oooool2
o`0003Gooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo03?ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`008Oooool2o`0003Oooooo00?o
0000ooooooooool0Koooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Kooooo0_l0
0007ooooo`008Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`05ooooo`008Oooool2o`0003[ooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Sooooo0_l00007ooooo`001ooo
ool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00001Oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo00Gooooo0008ooooo`03o`000?oooooooooo00Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`05ooooo`002?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00Gooooo0008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`;o0000?Oooool00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0>oooool2o`0000Oooooo0008ooooo`03o`000?oooooo
oooo00Oooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Gooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`05ooooo`001oooool2o`0000Wooooo00Oo0000oooooooooooooooo
o`000?oooooo000000Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1Xooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`00
2?ooool00ol0003oooooooooo`08ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`05ooooo`008Oooool2o`0003oooooo00?o0000ooooooooool0Iooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03gooooo0_l00007ooooo`008Oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`05ooooo`008Oooool2o`0004;ooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03oooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool01Oooool0027ooooo0_l00014ooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`11ooooo`;o00001oooool0027ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool01Ooo
ool0027ooooo0_l00016ooooo`03o`000?oooooooooo063ooooo00Go0000ooooooooooooooooo`00
0016ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1O
ooooo`05o`000?ooooooooooooooool00000Aoooool00ol0003oooooooooo`05ooooo`003Oooool3
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`1Oooooo`04o`000?ooooooooooo`0004Sooooo00?o0000ooooooooool01Ooo
ool000kooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`1Nooooo`04o`000?ooooooooooo`0004Sooooo
00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`02ooooo`;o0000B?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo000004Sooooo0_l0
0007ooooo`003_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`1Mooooo`;o0000B_ooool00ol0003oooooooooo`05
ooooo`003_ooool00ol0003oooooooooo`07ooooo`Co00001Oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo05cooooo0_l0001:ooooo`03o`000?oooooooooo00Gooooo000=ooooo`;o
00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`00
0?oooooooooo00Oooooo1Ol00004ooooo`;o0000Boooool00ol0003oooooooooo`1Jooooo`;o0000
B_ooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooo`00001;ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooo`00001;ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0E_ooool01?l0
003oooooooooool0001;ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000COooool00ol0
003oooooooooo`1Eooooo`05o`000?ooooooooooooooool00000B_ooool2o`0000Oooooo000Qoooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool0E?ooool01Ol0003ooooooooooooooooo
000004_ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo057o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Go
oooo000Qooooo`;o0000D?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0B?ooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`05
ooooo`008Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o
0000Doooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0B?ooool2o`0000Oooooo0007ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
1Oooool000Sooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo
0008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01Oooool000Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0001F
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`18
ooooo`;o00001oooool000Sooooo00?o0000ooooooooool02oooool00ol0003oooooo`000003o`00
00Gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`05ooooo`001oooool2o`0000Wo
oooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o0000ooooooooool0Eoooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`05ooooo`002?ooool00ol0003oooooooooo`07ooooo`Go000000?oooooo`00
0?l000000ol00004ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01Oooool0027o
oooo0_l0001Iooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`18ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`05ooooo`008Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo000Q
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01Oooool0027ooooo0_l0001Loooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`18oooo
o`;o00001oooool0027ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`05ooooo`00
8Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000Gooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0B?oo
ool2o`0000Oooooo000Qooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000Hoooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B?ooool2o`0000Oooooo
000Qooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01Oooool001Sooooo1Ol00004
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01Oooool001Wooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo000Joooo
o`03o`000?oooooooooo00Cooooo0_l0001Wooooo`;o00008_ooool2o`0001cooooo00?o0000oooo
ooooool0B?ooool2o`0000Oooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`05ooooo`006?ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0JOooool2o`0001gooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo00Gooooo000Hooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Sooooo0_l0000Pooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool01Oooool001Wooooo0ol00005ooooo`;o0000
KOooool00ol0003oooooooooo`0Eooooo`;o00008_ooool00ol0003oooooooooo`18ooooo`;o0000
1oooool0027ooooo00?o0000ooooooooool0KOooool2o`0001?ooooo0_l0000Tooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0Koooool4
o`0000gooooo0_l0000Vooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool0Loooool3o`0000Cooooo1_l0000Xooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool01Oooool0027ooooo0_l0001gooooo`Co0000;_ooool00ol0003o
ooooooooo`18ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0Z?ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000007ooooo`008Ooooooho`0000Oooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003?ooooo`?o0000C_ooool00=3ooooo00?o0000ooooooooool0COoo
ool006Cooooo00?o0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool00_ooool3
o`0000;ooooo0ol00003ooooo`?o00001?ooool3o`0000;ooooo0ol000000ooooooo0000o`000002
ooooo`;o00002?ooool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00000ooo
ool3o`0000;ooooo0ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003ooooo`;o00001?oo
ool00ol0003oooooooooo`1<ooooo`00I?ooool00ol0003oooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00Co0000oooooooo
oooo00001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`1<ooooo`00I?ooool00ol0003oooooo`000003ooooo`?o00000oooool0
0ol0003oooooo`000002ooooo`Go00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
04gooooo001Sooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo
ooooooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000?o
oooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`00
0?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool00000COooool006?ooooo00Go0000ooooool0003oooooo`000002oooo
o`;o00000oooool2o`000003ooooool0003o000000;ooooo0ol00003ooooo`03o`000?oooooooooo
00;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`0000;ooooo1?l0000:oooo
o`04o`000?ooooooooooooooo`Co00000_ooool4o`0000?ooooo0ol00002ooooo`Co00000oooool4
o`000004ooooool0003o0000o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l00000C?oo
ool006?ooooo00Go0000ooooool0003oooooo`00000Dooooo`04o`000?ooooooooooo`0001Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0Doooool006?ooooo1_l0000Booooo`Go00005?ooool00ol0003ooooooooo
o`08ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0Doooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14.3236, 0.0298238, \
0.0698899, 0.0128189}},
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.694048 0.0578888 0.0147151 0.160802 [
[.11516 -0.0125 -9 -9 ]
[.11516 -0.0125 9 0 ]
[.25988 -0.0125 -12 -9 ]
[.25988 -0.0125 12 0 ]
[.4046 -0.0125 -6 -9 ]
[.4046 -0.0125 6 0 ]
[.54933 -0.0125 -12 -9 ]
[.54933 -0.0125 12 0 ]
[.69405 -0.0125 -3 -9 ]
[.69405 -0.0125 3 0 ]
[.83877 -0.0125 -9 -9 ]
[.83877 -0.0125 9 0 ]
[.98349 -0.0125 -3 -9 ]
[.98349 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09512 -18 -4.5 ]
[-0.0125 .09512 0 4.5 ]
[-0.0125 .17552 -6 -4.5 ]
[-0.0125 .17552 0 4.5 ]
[-0.0125 .25592 -18 -4.5 ]
[-0.0125 .25592 0 4.5 ]
[-0.0125 .33632 -6 -4.5 ]
[-0.0125 .33632 0 4.5 ]
[-0.0125 .41672 -18 -4.5 ]
[-0.0125 .41672 0 4.5 ]
[-0.0125 .49712 -6 -4.5 ]
[-0.0125 .49712 0 4.5 ]
[-0.0125 .57752 -18 -4.5 ]
[-0.0125 .57752 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11516 0 m
.11516 .00625 L
s
[(-10)] .11516 -0.0125 0 1 Mshowa
.25988 0 m
.25988 .00625 L
s
[(-7.5)] .25988 -0.0125 0 1 Mshowa
.4046 0 m
.4046 .00625 L
s
[(-5)] .4046 -0.0125 0 1 Mshowa
.54933 0 m
.54933 .00625 L
s
[(-2.5)] .54933 -0.0125 0 1 Mshowa
.69405 0 m
.69405 .00625 L
s
[(0)] .69405 -0.0125 0 1 Mshowa
.83877 0 m
.83877 .00625 L
s
[(2.5)] .83877 -0.0125 0 1 Mshowa
.98349 0 m
.98349 .00625 L
s
[(5)] .98349 -0.0125 0 1 Mshowa
.125 Mabswid
.1441 0 m
.1441 .00375 L
s
.17305 0 m
.17305 .00375 L
s
.20199 0 m
.20199 .00375 L
s
.23094 0 m
.23094 .00375 L
s
.28883 0 m
.28883 .00375 L
s
.31777 0 m
.31777 .00375 L
s
.34672 0 m
.34672 .00375 L
s
.37566 0 m
.37566 .00375 L
s
.43355 0 m
.43355 .00375 L
s
.46249 0 m
.46249 .00375 L
s
.49144 0 m
.49144 .00375 L
s
.52038 0 m
.52038 .00375 L
s
.57827 0 m
.57827 .00375 L
s
.60721 0 m
.60721 .00375 L
s
.63616 0 m
.63616 .00375 L
s
.6651 0 m
.6651 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.75194 0 m
.75194 .00375 L
s
.78088 0 m
.78088 .00375 L
s
.80983 0 m
.80983 .00375 L
s
.86771 0 m
.86771 .00375 L
s
.89666 0 m
.89666 .00375 L
s
.9256 0 m
.9256 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.08622 0 m
.08622 .00375 L
s
.05727 0 m
.05727 .00375 L
s
.02833 0 m
.02833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09512 m
.00625 .09512 L
s
[(0.5)] -0.0125 .09512 1 0 Mshowa
0 .17552 m
.00625 .17552 L
s
[(1)] -0.0125 .17552 1 0 Mshowa
0 .25592 m
.00625 .25592 L
s
[(1.5)] -0.0125 .25592 1 0 Mshowa
0 .33632 m
.00625 .33632 L
s
[(2)] -0.0125 .33632 1 0 Mshowa
0 .41672 m
.00625 .41672 L
s
[(2.5)] -0.0125 .41672 1 0 Mshowa
0 .49712 m
.00625 .49712 L
s
[(3)] -0.0125 .49712 1 0 Mshowa
0 .57752 m
.00625 .57752 L
s
[(3.5)] -0.0125 .57752 1 0 Mshowa
.125 Mabswid
0 .0308 m
.00375 .0308 L
s
0 .04688 m
.00375 .04688 L
s
0 .06296 m
.00375 .06296 L
s
0 .07904 m
.00375 .07904 L
s
0 .1112 m
.00375 .1112 L
s
0 .12728 m
.00375 .12728 L
s
0 .14336 m
.00375 .14336 L
s
0 .15944 m
.00375 .15944 L
s
0 .1916 m
.00375 .1916 L
s
0 .20768 m
.00375 .20768 L
s
0 .22376 m
.00375 .22376 L
s
0 .23984 m
.00375 .23984 L
s
0 .272 m
.00375 .272 L
s
0 .28808 m
.00375 .28808 L
s
0 .30416 m
.00375 .30416 L
s
0 .32024 m
.00375 .32024 L
s
0 .3524 m
.00375 .3524 L
s
0 .36848 m
.00375 .36848 L
s
0 .38456 m
.00375 .38456 L
s
0 .40064 m
.00375 .40064 L
s
0 .4328 m
.00375 .4328 L
s
0 .44888 m
.00375 .44888 L
s
0 .46496 m
.00375 .46496 L
s
0 .48104 m
.00375 .48104 L
s
0 .5132 m
.00375 .5132 L
s
0 .52928 m
.00375 .52928 L
s
0 .54536 m
.00375 .54536 L
s
0 .56144 m
.00375 .56144 L
s
0 .5936 m
.00375 .5936 L
s
0 .60968 m
.00375 .60968 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11516 .61178 m
.11516 .61803 L
s
.25988 .61178 m
.25988 .61803 L
s
.4046 .61178 m
.4046 .61803 L
s
.54933 .61178 m
.54933 .61803 L
s
.69405 .61178 m
.69405 .61803 L
s
.83877 .61178 m
.83877 .61803 L
s
.98349 .61178 m
.98349 .61803 L
s
.125 Mabswid
.1441 .61428 m
.1441 .61803 L
s
.17305 .61428 m
.17305 .61803 L
s
.20199 .61428 m
.20199 .61803 L
s
.23094 .61428 m
.23094 .61803 L
s
.28883 .61428 m
.28883 .61803 L
s
.31777 .61428 m
.31777 .61803 L
s
.34672 .61428 m
.34672 .61803 L
s
.37566 .61428 m
.37566 .61803 L
s
.43355 .61428 m
.43355 .61803 L
s
.46249 .61428 m
.46249 .61803 L
s
.49144 .61428 m
.49144 .61803 L
s
.52038 .61428 m
.52038 .61803 L
s
.57827 .61428 m
.57827 .61803 L
s
.60721 .61428 m
.60721 .61803 L
s
.63616 .61428 m
.63616 .61803 L
s
.6651 .61428 m
.6651 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.75194 .61428 m
.75194 .61803 L
s
.78088 .61428 m
.78088 .61803 L
s
.80983 .61428 m
.80983 .61803 L
s
.86771 .61428 m
.86771 .61803 L
s
.89666 .61428 m
.89666 .61803 L
s
.9256 .61428 m
.9256 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.08622 .61428 m
.08622 .61803 L
s
.05727 .61428 m
.05727 .61803 L
s
.02833 .61428 m
.02833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09512 m
1 .09512 L
s
.99375 .17552 m
1 .17552 L
s
.99375 .25592 m
1 .25592 L
s
.99375 .33632 m
1 .33632 L
s
.99375 .41672 m
1 .41672 L
s
.99375 .49712 m
1 .49712 L
s
.99375 .57752 m
1 .57752 L
s
.125 Mabswid
.99625 .0308 m
1 .0308 L
s
.99625 .04688 m
1 .04688 L
s
.99625 .06296 m
1 .06296 L
s
.99625 .07904 m
1 .07904 L
s
.99625 .1112 m
1 .1112 L
s
.99625 .12728 m
1 .12728 L
s
.99625 .14336 m
1 .14336 L
s
.99625 .15944 m
1 .15944 L
s
.99625 .1916 m
1 .1916 L
s
.99625 .20768 m
1 .20768 L
s
.99625 .22376 m
1 .22376 L
s
.99625 .23984 m
1 .23984 L
s
.99625 .272 m
1 .272 L
s
.99625 .28808 m
1 .28808 L
s
.99625 .30416 m
1 .30416 L
s
.99625 .32024 m
1 .32024 L
s
.99625 .3524 m
1 .3524 L
s
.99625 .36848 m
1 .36848 L
s
.99625 .38456 m
1 .38456 L
s
.99625 .40064 m
1 .40064 L
s
.99625 .4328 m
1 .4328 L
s
.99625 .44888 m
1 .44888 L
s
.99625 .46496 m
1 .46496 L
s
.99625 .48104 m
1 .48104 L
s
.99625 .5132 m
1 .5132 L
s
.99625 .52928 m
1 .52928 L
s
.99625 .54536 m
1 .54536 L
s
.99625 .56144 m
1 .56144 L
s
.99625 .5936 m
1 .5936 L
s
.99625 .60968 m
1 .60968 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.69405 0 m
.69405 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .60332 Mdot
.94569 .56206 Mdot
.91514 .51512 Mdot
.88455 .46428 Mdot
.85392 .41119 Mdot
.82326 .35735 Mdot
.79256 .30413 Mdot
.76184 .25276 Mdot
.73109 .20436 Mdot
.70032 .15989 Mdot
.66953 .12021 Mdot
.63873 .08604 Mdot
.60791 .05799 Mdot
.57709 .03653 Mdot
.54625 .02203 Mdot
.51542 .01472 Mdot
.48458 .01472 Mdot
.45375 .02203 Mdot
.42291 .03653 Mdot
.39209 .05799 Mdot
.36127 .08604 Mdot
.33047 .12021 Mdot
.29968 .15989 Mdot
.26891 .20436 Mdot
.23816 .25277 Mdot
.20744 .30413 Mdot
.17674 .35735 Mdot
.14608 .41119 Mdot
.11545 .46428 Mdot
.08486 .51512 Mdot
.05431 .56206 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.05372 .56286 L
.08634 .51265 L
.11698 .46163 L
.14644 .41055 L
.1778 .35551 L
.20799 .3032 L
.24008 .24975 L
.27099 .20135 L
.30073 .15854 L
.33237 .1181 L
.36283 .08462 L
.39213 .05796 L
.40841 .04663 L
.41614 .04125 L
.4199 .03863 L
.42154 .03749 L
.42332 .03634 L
.42515 .03548 L
.42688 .03467 L
.43067 .03288 L
.4387 .0291 L
.44627 .02554 L
.44996 .02381 L
.45158 .02305 L
.45333 .02222 L
.45428 .0219 L
.45516 .02169 L
.45688 .02128 L
.46069 .02038 L
.46877 .01846 L
.47718 .01647 L
.4813 .01549 L
.4831 .01507 L
.48406 .01484 L
.48508 .01472 L
.486 .01472 L
.48683 .01472 L
.48847 .01472 L
.49203 .01472 L
.49953 .01472 L
.50346 .01472 L
.50773 .01472 L
.50969 .01472 L
.51176 .01472 L
.51353 .01472 L
.51454 .01472 L
.51548 .01473 L
.51645 .01496 L
.51748 .0152 L
Mistroke
.51933 .01564 L
.52353 .01664 L
.53118 .01845 L
.53866 .02023 L
.54194 .021 L
.54368 .02142 L
.54553 .02186 L
.54608 .02198 L
.54659 .02218 L
.54755 .02263 L
.54942 .02352 L
.55352 .02544 L
.56214 .0295 L
.56972 .03307 L
.57388 .03502 L
.57777 .03701 L
.58511 .04212 L
.59321 .04776 L
.60748 .05769 L
.63747 .0849 L
.66937 .12003 L
.70008 .15959 L
.72963 .20224 L
.76107 .25155 L
.79134 .30208 L
.82351 .35778 L
.8545 .41219 L
.88432 .46388 L
.91604 .5165 L
.94659 .56327 L
.97596 .603 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[543]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00>?ooool3o`0000Cooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool3o`0001_ooooo0ol0000Jooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`?o00006?ooool2o`0001[ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0000Koooo
o`?o00003_ooool003Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Hoooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Iooooo`05o`000?oooooo
ooooooooool000006_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00005_ooool01?l0003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Iooooo`05o`000?ooooooooooooooool000003Oooool0037ooooo1Ol0
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004?ooool5o`0000Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`Go00001Oooool00ol0003ooooo
ooooo`0Aooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo
00Co0000oooooooooooo00006oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02oooool003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0;ooooo`00>Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
01[ooooo00?o0000ooooooooool01Oooool4o`0001[ooooo1?l0000Jooooo`05o`000?oooooooooo
ooooool000001oooool4o`0001Oooooo00Co0000oooooooooooo00006Oooool01Ol0003ooooooooo
oooooooo000000Oooooo1?l0000Jooooo`Co00003_ooool003Sooooo0_l00004ooooo`04o`000?oo
ooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool06?ooool01?l0003oooooooooool0000Iooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo000iooooo`03o`000?oooooo
oooo00?ooooo0_l0000Gooooo`Go00001oooool5o`0001Wooooo1Ol0000Jooooo`?o00002?ooool5
o`0001Oooooo0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol0000=ooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`007_oooooho`0000[ooooo000Goooo
o`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002_ooool0
01Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool2
o`0007Gooooo2_l0000Zooooo`03o`000?oooooooooo04Sooooo0_l0000:ooooo`005_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo073ooooo1_l00006ooooo`Ko00009_ooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Sooooo000Fooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0K?ooool4o`0001;ooooo1?l0000Rooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`1Zooooo`Co00005Oooool2o`000003ooooool0003o0000023ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`08ooooo`005oooool2o`0000Gooooo0_l0001Yoooo
o`;o00007_ooool2o`0001kooooo00?o0000ooooooooool0B?ooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo06Gooooo0ol0000Rooooo`?o00006oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo06Gooooo0_l0000Tooooo`?o0000
6_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oo
oooooooo06?ooooo0_l0000Yooooo`;o00006?ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`;o0000H_ooool2o`0002gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`18ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo05gooooo0_l0000cooooo`;o00005?ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000G_ooool2o`0003?ooooo0ol0
000Cooooo`03o`000?oooooooooo04Sooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`0005[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04Sooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo00Sooooo000;ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0ol0003oooooooooo`1Fooooo`;o0000@_ooool2o`0000cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`1Fooooo`;o0000@_ooool2o`0000cooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooooooo00;ooooo0_l0001Fooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`18ooooo`;o00002_ooool000[ooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`08ooooo`002oooool2o`0000Sooooo1Ol00004ooooo`;o0000D_ooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool0C_ooool2o`0005;ooooo0_l00004ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool0C_ooool2o`0005;ooooo0_l00004ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool02?ooool001kooooo0_l0001?ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`18ooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Dooooo`05o`000?oooooo
ooooooooool00000Boooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo05Kooooo00Co0000oooooooooooo0000Boooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooool00000Boooool00ol0003oooooooooo`08ooooo`007_ooool2o`0004cooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooo`00001:ooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`1Jooooo`;o0000Boooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo05gooooo0_l0001:ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000Aoooool2
o`00063ooooo0ol00018ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0A_ooool2o`00
063ooooo0ol00019ooooo`03o`000?oooooooooo00Sooooo000Fooooo`?o00001Oooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo05oooooo00Co0000oooooooooooo0000B?ooool00ol0
003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool0H?ooool01Ol0003ooooooooooooooooo000004Oooooo00?o0000oooo
ooooool02?ooool001Oooooo00?o0000ooooooooool01?ooool2o`0004Kooooo00?o0000oooooooo
ool0H?ooool01Ol0003ooooooooooooooooo000004Kooooo0_l0000:ooooo`005oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool001Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Sooooo
000Fooooo`;o00001_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Sooooo000G
ooooo`03o`000?oooooooooo00Cooooo0_l00013ooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`11ooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0001Wooooo`03o`00
0?oooooooooo00Kooooo0_l00011ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000@?oo
ool2o`0006Oooooo00?o0000ooooooooool01_ooool2o`00043ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`08ooooo`007_ooool2o`0003gooooo00?o0000ooooooooool0JOooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo03cooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1[oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08oooo
o`007_ooool2o`0003_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03Wooooo0_l0000:ooooo`002_ooool3o`0000Cooooo00?o0000ooooooooool0
0_ooool3o`0000Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`002ooo
ool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0gooooo`;o0000Koooool00ol0003ooooooooo
o`0>ooooo`;o0000>Oooool00ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00;ooooo0_l0000hooooo`;o0000Koooool00ol0003oooooooooo`0>
ooooo`;o0000>?ooool2o`0000[ooooo000;ooooo`03o`000?oooooooooo00Oooooo1?l00005oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool000[ooooo0_l00009ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08ooooo`00
2oooool00ol0003oooooooooo`07ooooo`Go00001?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`;o0000=_ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0=?ooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00So
oooo000Nooooo`;o0000=?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0<_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1d
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo07Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o
0000<?ooool2o`0007Oooooo00?o0000ooooooooool05Oooool2o`00037ooooo0_l0000:ooooo`00
7_ooool00ol0003oooooooooo`0_ooooo`;o0000Moooool00ol0003oooooooooo`0Eooooo`;o0000
<_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02?ooool0
01kooooo0_l0000_ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0]ooooo`;o00002_ooool001Gooooo1Ol00004ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo000Gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`006?ooool00ol0003ooooooooo
o`03ooooo`;o0000;Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0:oooool2o`0000[ooooo000Eooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo000F
ooooo`?o00001Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Sooooo000Noooo
o`;o0000:oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0:Oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0001nooooo`03
o`000?oooooooooo01gooooo0_l0000Zooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo02Sooooo0_l0001nooooo`03o`000?oooooooooo01gooooo0_l0000Zooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02?oo
ool001kooooo0_l0000Xooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Wooooo`;o00002_ooool001kooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool001kooooo0_l0
000Vooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Tooooo`;o00002_ooool001kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo087ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool001kooooo0_l0000Tooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Rooooo`;o0000
2_ooool000Wooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool08?ooool2o`0008Kooooo
00?o0000ooooooooool09?ooool2o`0002?ooooo00?o0000ooooooooool02?ooool000_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo0_l0
0026ooooo`03o`000?oooooooooo02Cooooo0_l0000Sooooo`03o`000?oooooooooo00Sooooo000<
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool2o`00027ooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo023ooooo0_l0000:
ooooo`002Oooool01Ol0003ooooooooooooooooo000000Oooooo1?l00005ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`26
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08
ooooo`002_ooool3o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0Q_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02?ooool001kooooo0_l0000Oooooo`03o`000?oooooooooo08Oooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Mooooo`;o00002_ooool001kooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo08Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0ROooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool0
01kooooo0_l0000Mooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Kooooo`;o00002_ooool001kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`2:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo08[ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo01Wooooo0_l0002=ooooo`03o`000?oooooooooo02cooooo0_l0
000Kooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00006_ooool2o`0008gooooo00?o0000
ooooooooool0;?ooool2o`0001[ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo08cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0SOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2=ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`007_oo
ool2o`0001Sooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01Kooooo0_l0000:ooooo`005_ooool3o`0000Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`2?ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`08ooooo`005Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`08ooooo`006Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool001Oooooo0_l00005ooooo`;o
00005Oooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool05?ooool2o`0000[ooooo000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`08ooooo`005Oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`005_ooool3o`0000Gooooo0_l0
000Cooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Booooo`;o00002_ooool001kooooo00?o0000ooooooooool04Oooool2o`0009Gooooo00?o0000
ooooooooool0<oooool2o`0001Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool04Oooool2o`0009Gooooo00?o0000ooooooooool0<oooool2o`0001Cooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Eooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`00
7_ooool2o`00017ooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo09Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0U_ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000ko
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00go
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo09Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0VOooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000_ooooo0_l0002Loooo
o`03o`000?oooooooooo03_ooooo0_l0000;ooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool02_ooool2o`0009cooooo00?o0000ooooooooool0>oooool2o`0000cooooo00?o0000oooooooo
ool02?ooool000[ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02?ooool000Wooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo09cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo000=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool2o`0000Wooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00Oooooo0_l0000:ooooo`002oooool2o`0000cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000=ooooo`03o`000?oooooo
oooo00Gooooo1?l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0W_ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
00Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002_ooool3o`0000Sooooo1Ol00004oooo
o`;o00001_ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool01?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0X?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool00_ooool3o`000:?ooooo00?o0000ooooooooool0
@_ooool2o`0000Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00_oo
ool2o`000:Cooooo00?o0000ooooooooool0@_ooool2o`0000Gooooo00?o0000ooooooooool02?oo
ool001kooooo0_l0002Yooooo`03o`000?oooooooooo04Sooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002_ooool001kooooon?l0000:oooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00<?ooool3o`0008[ooooo00?o0000
ooooooooool0:oooool3o`0001Gooooo00?o0000ooooooooool06_ooool0037ooooo00?o0000oooo
ooooool0R?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool06Oooool002_ooooo0ol00003ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o
00000oooool4o`000003ooooool0003o000000?o00001oooool3o`0000Cooooo1?l00003ooooo`;o
00000_ooool6o`0000Kooooo1?l00002ooooo`Go000000?oooooo`000?l000000ol000000ooooooo
0000o`000003o`0000;ooooo0ol00002ooooo`?o00001?ooool3o`0000;ooooo0ol000001?oooooo
0000o`000?ooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000000oooool4o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1Ol00002oooo
o`?o00000_ooool3o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000;ooooo2_l00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo
000Zooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool5o`0000;ooooo
00?o0000ooooooooool00_ooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00005oooo
o`Go00002?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo0000ooooool000000_ooool3
o`0000?ooooo00?o0000ooooool000000_ooool5o`0000?ooooo00Co0000oooooooooooooooo1Ol0
0002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000;ooooo0ol00005ooooo`03o`000?oooooooooo01Sooooo000Zoooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`?o00000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?oo
ooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000
1Oooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool06?ooool002[o
oooo00Ko0000ooooooooooooooooo`000?ooool4o`0000;ooooo1?l00002ooooo`?o00001?ooool3
o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_oo
ool2o`0000?ooooo1?l00003ooooo`?o00002Oooool01Ol0003oooooooooool0003ooooo00?o0000
1?ooool4o`0000;ooooo1?l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo
0ol00002ooooo`Co00000oooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo
1_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0000;ooooo1?l00003ooooo`Wo00000oooool3o`0000?ooooo
1?l00004ooooo`03o`000?oooooooooo01Sooooo000Zooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Iooooo`00:oooool3o`0000Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0=ooooo`?o00002Oooool4o`0000Wooooo00?o0000oooooooo
ool00_ooool2o`0000[ooooo1?l00004ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o
0000;_ooool00ol0003oooooooooo`0Hooooo`?o00005_ooool00ol0003oooooooooo`02ooooo`;o
00002oooool00ol0003oooooooooo`0Jooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14.1139, -0.39571, \
0.0698899, 0.0251604}},
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          
          RowBox[{\(ComponentNumber \[Rule] 7\), 
            ",", \(Energy \[Rule] 20.999999999999996`\), 
            ",", \(Offset \[Rule] 385.8898930836815`\), ",", 
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.601837947408837`\), 
                      4.832075777557927`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.601837947408837`\), 
                      4.832075777557927`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {385.88906303771944`, 
                385.89480110163976`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(RayBoundary \[Rule] {\(-11.601837947408837`\), 
                4.832075777557927`}\), 
            ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
            ",", \(Source \[Rule] 1\), ",", \(SpatialScale \[Rule] 1\), 
            ",", \(SurfaceNumber \[Rule] 1\), ",", \(WaveFrontID \[Rule] 1\), 
            ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-13.592966053571082`\), 
                      6.551831415743017`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
            ",", \(WaveTilt \[Rule] WaveTilt\)}], "}"}], ",", 
        RowBox[{"{", 
          
          RowBox[{\(ComponentNumber \[Rule] 7\), 
            ",", \(Energy \[Rule] 20.999999999999996`\), 
            ",", \(Offset \[Rule] 448.65353743119795`\), ",", 
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.578039757381847`\), 
                      4.873875033715966`}}, "<>"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-11.578039757381847`\), 
                      4.873875033715966`}}, "<>"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {448.65353743119795`, 
                448.6554847779822`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          Graphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(RayBoundary \[Rule] {\(-11.578039757381847`\), 
                4.873875033715966`}\), 
            ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
            ",", \(Source \[Rule] 1\), ",", \(SpatialScale \[Rule] 1\), 
            ",", \(SurfaceNumber \[Rule] 1\), ",", \(WaveFrontID \[Rule] 2\), 
            ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-13.575588071626344`\), 
                      6.591275220687104`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
            ",", \(WaveTilt \[Rule] WaveTilt\)}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[543]=",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindInterference[wavefronts];", "Input",
  CellLabel->"In[544]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.695755 0.0580362 0.0147141 0.0708899 [
[.11539 -0.0125 -9 -9 ]
[.11539 -0.0125 9 0 ]
[.26048 -0.0125 -12 -9 ]
[.26048 -0.0125 12 0 ]
[.40557 -0.0125 -6 -9 ]
[.40557 -0.0125 6 0 ]
[.55066 -0.0125 -12 -9 ]
[.55066 -0.0125 12 0 ]
[.69576 -0.0125 -3 -9 ]
[.69576 -0.0125 3 0 ]
[.84085 -0.0125 -9 -9 ]
[.84085 -0.0125 9 0 ]
[.98594 -0.0125 -3 -9 ]
[.98594 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -6 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .15649 -6 -4.5 ]
[-0.0125 .15649 0 4.5 ]
[-0.0125 .29827 -6 -4.5 ]
[-0.0125 .29827 0 4.5 ]
[-0.0125 .44005 -6 -4.5 ]
[-0.0125 .44005 0 4.5 ]
[-0.0125 .58183 -6 -4.5 ]
[-0.0125 .58183 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -66 0 ]
[.5 .63053 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11539 0 m
.11539 .00625 L
s
[(-10)] .11539 -0.0125 0 1 Mshowa
.26048 0 m
.26048 .00625 L
s
[(-7.5)] .26048 -0.0125 0 1 Mshowa
.40557 0 m
.40557 .00625 L
s
[(-5)] .40557 -0.0125 0 1 Mshowa
.55066 0 m
.55066 .00625 L
s
[(-2.5)] .55066 -0.0125 0 1 Mshowa
.69576 0 m
.69576 .00625 L
s
[(0)] .69576 -0.0125 0 1 Mshowa
.84085 0 m
.84085 .00625 L
s
[(2.5)] .84085 -0.0125 0 1 Mshowa
.98594 0 m
.98594 .00625 L
s
[(5)] .98594 -0.0125 0 1 Mshowa
.125 Mabswid
.14441 0 m
.14441 .00375 L
s
.17343 0 m
.17343 .00375 L
s
.20245 0 m
.20245 .00375 L
s
.23147 0 m
.23147 .00375 L
s
.2895 0 m
.2895 .00375 L
s
.31852 0 m
.31852 .00375 L
s
.34754 0 m
.34754 .00375 L
s
.37656 0 m
.37656 .00375 L
s
.43459 0 m
.43459 .00375 L
s
.46361 0 m
.46361 .00375 L
s
.49263 0 m
.49263 .00375 L
s
.52165 0 m
.52165 .00375 L
s
.57968 0 m
.57968 .00375 L
s
.6087 0 m
.6087 .00375 L
s
.63772 0 m
.63772 .00375 L
s
.66674 0 m
.66674 .00375 L
s
.72477 0 m
.72477 .00375 L
s
.75379 0 m
.75379 .00375 L
s
.78281 0 m
.78281 .00375 L
s
.81183 0 m
.81183 .00375 L
s
.86986 0 m
.86986 .00375 L
s
.89888 0 m
.89888 .00375 L
s
.9279 0 m
.9279 .00375 L
s
.95692 0 m
.95692 .00375 L
s
.08637 0 m
.08637 .00375 L
s
.05736 0 m
.05736 .00375 L
s
.02834 0 m
.02834 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(0)] -0.0125 .01471 1 0 Mshowa
0 .15649 m
.00625 .15649 L
s
[(2)] -0.0125 .15649 1 0 Mshowa
0 .29827 m
.00625 .29827 L
s
[(4)] -0.0125 .29827 1 0 Mshowa
0 .44005 m
.00625 .44005 L
s
[(6)] -0.0125 .44005 1 0 Mshowa
0 .58183 m
.00625 .58183 L
s
[(8)] -0.0125 .58183 1 0 Mshowa
.125 Mabswid
0 .05016 m
.00375 .05016 L
s
0 .0856 m
.00375 .0856 L
s
0 .12105 m
.00375 .12105 L
s
0 .19194 m
.00375 .19194 L
s
0 .22738 m
.00375 .22738 L
s
0 .26283 m
.00375 .26283 L
s
0 .33372 m
.00375 .33372 L
s
0 .36916 m
.00375 .36916 L
s
0 .40461 m
.00375 .40461 L
s
0 .4755 m
.00375 .4755 L
s
0 .51094 m
.00375 .51094 L
s
0 .54639 m
.00375 .54639 L
s
0 .61728 m
.00375 .61728 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11539 .61178 m
.11539 .61803 L
s
.26048 .61178 m
.26048 .61803 L
s
.40557 .61178 m
.40557 .61803 L
s
.55066 .61178 m
.55066 .61803 L
s
.69576 .61178 m
.69576 .61803 L
s
.84085 .61178 m
.84085 .61803 L
s
.98594 .61178 m
.98594 .61803 L
s
.125 Mabswid
.14441 .61428 m
.14441 .61803 L
s
.17343 .61428 m
.17343 .61803 L
s
.20245 .61428 m
.20245 .61803 L
s
.23147 .61428 m
.23147 .61803 L
s
.2895 .61428 m
.2895 .61803 L
s
.31852 .61428 m
.31852 .61803 L
s
.34754 .61428 m
.34754 .61803 L
s
.37656 .61428 m
.37656 .61803 L
s
.43459 .61428 m
.43459 .61803 L
s
.46361 .61428 m
.46361 .61803 L
s
.49263 .61428 m
.49263 .61803 L
s
.52165 .61428 m
.52165 .61803 L
s
.57968 .61428 m
.57968 .61803 L
s
.6087 .61428 m
.6087 .61803 L
s
.63772 .61428 m
.63772 .61803 L
s
.66674 .61428 m
.66674 .61803 L
s
.72477 .61428 m
.72477 .61803 L
s
.75379 .61428 m
.75379 .61803 L
s
.78281 .61428 m
.78281 .61803 L
s
.81183 .61428 m
.81183 .61803 L
s
.86986 .61428 m
.86986 .61803 L
s
.89888 .61428 m
.89888 .61803 L
s
.9279 .61428 m
.9279 .61803 L
s
.95692 .61428 m
.95692 .61803 L
s
.08637 .61428 m
.08637 .61803 L
s
.05736 .61428 m
.05736 .61803 L
s
.02834 .61428 m
.02834 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .15649 m
1 .15649 L
s
.99375 .29827 m
1 .29827 L
s
.99375 .44005 m
1 .44005 L
s
.99375 .58183 m
1 .58183 L
s
.125 Mabswid
.99625 .05016 m
1 .05016 L
s
.99625 .0856 m
1 .0856 L
s
.99625 .12105 m
1 .12105 L
s
.99625 .19194 m
1 .19194 L
s
.99625 .22738 m
1 .22738 L
s
.99625 .26283 m
1 .26283 L
s
.99625 .33372 m
1 .33372 L
s
.99625 .36916 m
1 .36916 L
s
.99625 .40461 m
1 .40461 L
s
.99625 .4755 m
1 .4755 L
s
.99625 .51094 m
1 .51094 L
s
.99625 .54639 m
1 .54639 L
s
.99625 .61728 m
1 .61728 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.69576 0 m
.69576 .61803 L
s
[(Interference Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .05112 m
.03111 .03711 L
.03491 .02906 L
.03692 .02518 L
.03907 .0215 L
.0411 .01864 L
.04294 .01664 L
.04383 .01592 L
.0443 .0156 L
.0448 .01531 L
.04523 .01511 L
.04571 .01493 L
.04592 .01487 L
.04614 .01481 L
.04636 .01477 L
.04655 .01475 L
.04679 .01472 L
.04702 .01472 L
.04723 .01472 L
.04745 .01473 L
.04769 .01477 L
.04782 .01479 L
.04795 .01481 L
.04841 .01494 L
.04884 .01511 L
.04931 .01534 L
.05014 .0159 L
.05119 .01687 L
.05219 .01805 L
.05406 .02117 L
.05588 .02506 L
.05782 .03008 L
.0613 .04141 L
.06843 .07154 L
.07603 .10781 L
.08334 .13788 L
.0853 .14418 L
.08713 .14886 L
.08903 .15263 L
.09004 .15414 L
.09112 .15536 L
.0916 .15579 L
.09212 .15617 L
.09256 .15642 L
.09281 .15653 L
.09305 .15662 L
.09318 .15667 L
.09332 .1567 L
.09357 .15676 L
.09371 .15677 L
Mistroke
.09387 .15679 L
.09401 .15679 L
.09414 .15679 L
.09427 .15678 L
.09439 .15676 L
.09452 .15674 L
.09466 .15671 L
.09489 .15664 L
.09515 .15654 L
.09565 .15628 L
.0961 .15597 L
.09712 .15498 L
.09806 .15372 L
.09896 .15223 L
.10079 .14829 L
.10273 .14287 L
.10621 .13022 L
.11335 .09577 L
.12096 .05533 L
.12446 .03928 L
.12644 .03156 L
.12828 .0255 L
.13012 .02067 L
.13106 .01872 L
.13208 .01702 L
.13264 .01628 L
.13315 .01572 L
.13365 .0153 L
.1339 .01513 L
.13417 .01498 L
.13441 .01487 L
.13464 .0148 L
.13486 .01475 L
.13507 .01472 L
.13532 .01472 L
.13555 .01474 L
.13567 .01476 L
.1358 .0148 L
.13607 .01489 L
.1363 .01499 L
.13651 .01511 L
.13699 .01547 L
.13747 .01593 L
.13797 .01655 L
.13889 .01798 L
.13972 .01965 L
.14174 .02512 L
.14366 .03212 L
.14744 .05089 L
.15092 .07318 L
Mistroke
.15836 .13176 L
.16552 .19094 L
.16949 .21957 L
.17313 .24048 L
.17493 .24846 L
.17588 .25198 L
.17689 .25514 L
.17786 .25764 L
.17874 .25942 L
.17917 .2601 L
.17963 .26072 L
.18006 .26119 L
.18046 .26151 L
.1807 .26165 L
.18093 .26176 L
.18113 .26182 L
.18135 .26186 L
.18159 .26187 L
.18171 .26186 L
.18185 .26184 L
.18208 .26178 L
.18231 .26169 L
.18252 .26157 L
.18274 .26142 L
.18313 .26107 L
.18356 .26058 L
.18402 .25993 L
.185 .25813 L
.18605 .25558 L
.18793 .24932 L
.18987 .24068 L
.19197 .22899 L
.19578 .20242 L
.20351 .13494 L
.20736 .10012 L
.21096 .07007 L
.21464 .0442 L
.21645 .034 L
.21813 .0263 L
.21996 .02 L
.22093 .01763 L
.22147 .0166 L
.22196 .01587 L
.22241 .01534 L
.22283 .015 L
.22305 .01487 L
.22329 .01478 L
.22354 .01472 L
.22377 .01472 L
.22399 .01475 L
Mistroke
.2242 .01482 L
.22438 .0149 L
.22459 .01503 L
.22504 .01543 L
.22547 .01595 L
.22635 .01749 L
.22729 .01983 L
.22819 .02269 L
.229 .02586 L
.231 .03579 L
.2329 .048 L
.23664 .07935 L
.24012 .11507 L
.24751 .2067 L
.25536 .30365 L
.2593 .34305 L
.26103 .35716 L
.26293 .37004 L
.26382 .37503 L
.26476 .37963 L
.26558 .38297 L
.26647 .38592 L
.267 .3873 L
.26748 .38836 L
.26794 .38916 L
.26843 .3898 L
.26864 .39002 L
.26887 .39021 L
.26908 .39035 L
.26928 .39044 L
.2695 .39051 L
.26973 .39052 L
.26998 .39046 L
.27022 .39036 L
.27046 .39019 L
.27071 .38996 L
.27117 .38939 L
.27166 .38854 L
.2722 .38735 L
.27317 .38452 L
.27408 .38107 L
.27577 .37261 L
.27759 .36066 L
.28159 .32503 L
.28539 .2815 L
.29261 .18459 L
.29665 .13047 L
.3003 .08776 L
.30218 .06817 L
.30416 .05022 L
Mistroke
.30599 .03653 L
.30771 .02657 L
.30861 .02246 L
.30944 .01945 L
.31036 .01696 L
.31087 .01598 L
.3111 .01563 L
.31135 .01531 L
.31159 .01506 L
.31182 .01489 L
.31207 .01477 L
.3122 .01473 L
.31233 .01472 L
.31254 .01473 L
.31277 .0148 L
.31301 .01493 L
.31323 .01512 L
.3135 .01541 L
.31375 .01576 L
.31423 .01661 L
.31473 .01779 L
.31528 .01941 L
.31621 .02289 L
.31708 .027 L
.31905 .03939 L
.32097 .05539 L
.32302 .0766 L
.33083 .18596 L
.33835 .31466 L
.34559 .42718 L
.34932 .47075 L
.3512 .48754 L
.35222 .49496 L
.35329 .5015 L
.3542 .50599 L
.35468 .50796 L
.35519 .50976 L
.35566 .51112 L
.35609 .51212 L
.3563 .51252 L
.35653 .51289 L
.35673 .51317 L
.35694 .5134 L
.35718 .51361 L
.35741 .51373 L
.35755 .51378 L
.35768 .51379 L
.35793 .51377 L
.35806 .51372 L
.35819 .51365 L
Mistroke
.35844 .51347 L
.35858 .51333 L
.35872 .51316 L
.35899 .51279 L
.35946 .51189 L
.35989 .51082 L
.36088 .50764 L
.36176 .50426 L
.36272 .49931 L
.36443 .4872 L
.36648 .46841 L
.36834 .44743 L
.37587 .33272 L
.38312 .20289 L
.38678 .14121 L
.39082 .08326 L
.39267 .0633 L
.39465 .04427 L
.39557 .03684 L
.39653 .03013 L
.39741 .02499 L
.39825 .02108 L
.3987 .01933 L
.39919 .01775 L
.3996 .01669 L
.40005 .01578 L
.4003 .01539 L
.40054 .01511 L
.40079 .01489 L
.40093 .01481 L
.40105 .01476 L
.40128 .01472 L
.40153 .01475 L
.40176 .01487 L
.40198 .01504 L
.4022 .01528 L
.40243 .01561 L
.40286 .01641 L
.40328 .01744 L
.40366 .01859 L
.40453 .02196 L
.40545 .02663 L
.40725 .03905 L
.40917 .05695 L
.41264 .10033 L
.42046 .23795 L
.42801 .38689 L
.43146 .45202 L
.43526 .51308 L
.43901 .55859 L
Mistroke
.43999 .56774 L
.44106 .57614 L
.44205 .58262 L
.44298 .58739 L
.4439 .59094 L
.44442 .59238 L
.44489 .59336 L
.44515 .59378 L
.4454 .59407 L
.44553 .59419 L
.44567 .59429 L
.44582 .59436 L
.44596 .5944 L
.44609 .59441 L
.44621 .5944 L
.44645 .59431 L
.44658 .59423 L
.4467 .59413 L
.44697 .59383 L
.44719 .59352 L
.44742 .5931 L
.44784 .59214 L
.44835 .59066 L
.44881 .58898 L
.44976 .58455 L
.45076 .57849 L
.45257 .56412 L
.45449 .5462 L
.45796 .50031 L
.4658 .35609 L
.47335 .20143 L
.47681 .13804 L
.48061 .08019 L
.48242 .05832 L
.48437 .03995 L
.48544 .03262 L
.48642 .02647 L
.48735 .02163 L
.48786 .01951 L
.48834 .01786 L
.48881 .01659 L
.48906 .01605 L
.48932 .01558 L
.48954 .01526 L
.48978 .015 L
.49 .01483 L
.4902 .01474 L
.49043 .01472 L
.49064 .01476 L
.49083 .01486 L
Mistroke
.49104 .01503 L
.49126 .01529 L
.4915 .01564 L
.49193 .0165 L
.4924 .01773 L
.49289 .01941 L
.4938 .02338 L
.49487 .02964 L
.49585 .03682 L
.49943 .07398 L
.50146 .10201 L
.50334 .13198 L
.51073 .27446 L
.51858 .43072 L
.52251 .50079 L
.52424 .52689 L
.52614 .55157 L
.52784 .56996 L
.52967 .58543 L
.53068 .59197 L
.5316 .59667 L
.53205 .59849 L
.53253 .60014 L
.53299 .60139 L
.53341 .60227 L
.53365 .60265 L
.5339 .60295 L
.53415 .60317 L
.53429 .60325 L
.53442 .6033 L
.53466 .60332 L
.53488 .60326 L
.535 .6032 L
.53513 .60311 L
.53537 .60288 L
.53558 .60261 L
.53582 .60223 L
.53629 .60121 L
.53673 .59997 L
.53714 .59855 L
.53814 .59408 L
.53905 .58874 L
.54111 .57246 L
.54297 .55291 L
.54469 .53096 L
.54861 .474 L
.556 .32982 L
.56386 .17156 L
.5678 .10545 L
.56953 .08118 L
Mistroke
.57143 .05845 L
.57314 .0418 L
.57497 .02823 L
.57549 .02521 L
.57599 .0227 L
.57646 .02064 L
.57691 .01915 L
.57777 .01687 L
.57823 .01599 L
.57846 .01563 L
.57872 .01527 L
.57895 .01502 L
.57917 .01485 L
.57939 .01474 L
.57964 .01472 L
.57987 .01476 L
.58008 .01488 L
.58028 .01504 L
.58049 .01527 L
.58072 .01559 L
.58097 .01604 L
.58148 .01721 L
.58195 .01862 L
.58239 .02023 L
.58406 .02866 L
.58499 .03501 L
.58585 .04181 L
.58944 .07994 L
.59336 .13649 L
.60105 .2745 L
.60846 .40525 L
.61224 .46009 L
.61422 .48473 L
.61632 .50595 L
.61821 .52039 L
.61928 .52663 L
.62027 .53112 L
.62074 .53279 L
.62119 .53411 L
.6216 .53508 L
.62203 .53588 L
.62225 .53619 L
.62249 .53646 L
.62272 .53664 L
.62293 .53674 L
.62317 .53679 L
.6234 .53677 L
.62364 .53667 L
.62377 .53659 L
.6239 .53647 L
Mistroke
.62415 .5362 L
.62438 .53588 L
.6249 .53489 L
.62536 .53373 L
.62585 .5322 L
.62669 .52883 L
.62762 .52409 L
.62966 .50985 L
.63158 .49211 L
.63542 .44508 L
.63892 .39305 L
.64645 .26247 L
.65368 .13818 L
.65734 .08708 L
.65928 .06473 L
.66138 .04491 L
.66235 .03735 L
.66337 .03052 L
.66432 .02528 L
.6652 .02133 L
.66603 .01846 L
.66646 .0173 L
.66692 .01628 L
.66718 .01582 L
.66742 .01546 L
.66765 .01519 L
.66777 .01507 L
.6679 .01496 L
.66813 .01482 L
.66834 .01474 L
.66858 .01472 L
.6688 .01475 L
.66904 .01484 L
.66927 .01498 L
.66947 .01515 L
.6697 .01537 L
.6702 .01605 L
.67066 .01688 L
.6715 .019 L
.67192 .02043 L
.67239 .02222 L
.67441 .0328 L
.6763 .04649 L
.68015 .08432 L
.68366 .12804 L
.69119 .23688 L
.69844 .33554 L
.70218 .37285 L
.70409 .38907 L
.70615 .40287 L
Mistroke
.70708 .4078 L
.70807 .41203 L
.70891 .41487 L
.70939 .41616 L
.70983 .41712 L
.71027 .41791 L
.71069 .41846 L
.71092 .41868 L
.71114 .41884 L
.71137 .41896 L
.71162 .41903 L
.71182 .41904 L
.71203 .419 L
.71223 .41893 L
.71241 .41882 L
.71263 .41865 L
.71286 .41842 L
.71328 .41785 L
.71377 .41697 L
.71429 .41576 L
.71524 .41286 L
.71616 .40919 L
.71701 .4051 L
.71894 .39329 L
.72098 .37733 L
.72817 .2979 L
.73582 .19531 L
.74318 .1009 L
.74721 .06068 L
.74905 .04602 L
.75101 .0334 L
.75281 .02462 L
.75383 .02085 L
.75478 .01813 L
.75523 .01713 L
.75566 .01634 L
.75605 .01575 L
.75646 .01527 L
.7567 .01507 L
.75691 .01492 L
.75712 .01481 L
.75733 .01475 L
.75756 .01472 L
.75778 .01473 L
.75802 .01479 L
.75814 .01484 L
.75827 .0149 L
.75851 .01507 L
.75874 .01526 L
.75926 .01587 L
Mistroke
.75971 .01658 L
.7602 .01753 L
.76195 .02238 L
.76292 .0259 L
.76383 .0298 L
.7659 .04124 L
.76972 .06902 L
.77321 .10033 L
.7807 .17529 L
.7879 .24007 L
.7916 .26465 L
.79367 .27454 L
.79459 .27807 L
.79556 .28136 L
.79645 .28384 L
.79693 .28493 L
.79744 .28592 L
.79791 .28667 L
.79834 .28722 L
.79877 .28765 L
.79918 .28793 L
.79943 .28805 L
.79965 .28813 L
.79978 .28815 L
.79991 .28817 L
.80016 .28817 L
.80038 .28812 L
.80063 .28804 L
.80083 .28794 L
.80106 .28779 L
.80157 .28734 L
.80212 .28666 L
.80264 .28583 L
.80311 .28492 L
.80402 .28273 L
.80499 .27981 L
.80672 .27308 L
.80859 .26381 L
.81065 .25139 L
.81825 .19045 L
.82557 .12281 L
.82929 .09042 L
.83335 .05987 L
.83523 .048 L
.83723 .03716 L
.83911 .02885 L
.84084 .02285 L
.84177 .02032 L
.84278 .01808 L
.8438 .0164 L
Mistroke
.84436 .01573 L
.84461 .01548 L
.84488 .01526 L
.84514 .01508 L
.84538 .01494 L
.8456 .01485 L
.84584 .01477 L
.84606 .01473 L
.84626 .01472 L
.84648 .01473 L
.84672 .01477 L
.84696 .01484 L
.84709 .01489 L
.84722 .01495 L
.84775 .01528 L
.8482 .01569 L
.84869 .01624 L
.8497 .01775 L
.85062 .01959 L
.85272 .0252 L
.85457 .03176 L
.85653 .04014 L
.86368 .07898 L
.87129 .12469 L
.87479 .14321 L
.87862 .15961 L
.88069 .16641 L
.88261 .17126 L
.88356 .1731 L
.88445 .17452 L
.88494 .17519 L
.88548 .17579 L
.88593 .1762 L
.88641 .17653 L
.88666 .17666 L
.88689 .17675 L
.88711 .17681 L
.88734 .17685 L
.88756 .17686 L
.88779 .17686 L
.88799 .17683 L
.8882 .17679 L
.88833 .17676 L
.88846 .17671 L
.88869 .17662 L
.88922 .17632 L
.88968 .17598 L
.89018 .1755 L
.89117 .17424 L
.89224 .17251 L
Mistroke
.89416 .16837 L
.89609 .16293 L
.89819 .15564 L
.902 .13932 L
.90973 .09872 L
.91718 .05876 L
.92092 .04222 L
.92434 .03016 L
.9261 .02523 L
.92802 .02092 L
.92907 .01903 L
.93004 .01759 L
.93097 .01649 L
.93196 .01561 L
.93246 .01528 L
.93298 .01502 L
.93342 .01486 L
.93368 .0148 L
.93391 .01475 L
.93404 .01474 L
.93419 .01473 L
.93432 .01472 L
.93445 .01472 L
.93468 .01473 L
.93493 .01476 L
.93506 .01478 L
.9352 .01481 L
.93545 .01488 L
.93575 .01498 L
.93602 .01509 L
.93691 .01561 L
.93741 .016 L
.93788 .01642 L
.93983 .01878 L
.94183 .0221 L
.94371 .02596 L
.94722 .0352 L
.9545 .05669 L
.95819 .06649 L
.96015 .07102 L
.96224 .07524 L
.96426 .07856 L
.9661 .08092 L
.96698 .08181 L
.96795 .0826 L
.96839 .08289 L
.96886 .08316 L
.96927 .08336 L
.9697 .08353 L
.9701 .08365 L
Mistroke
.97031 .0837 L
.97054 .08375 L
.97075 .08378 L
.97094 .0838 L
.97113 .08381 L
.97131 .08382 L
.97152 .08381 L
.97174 .0838 L
.97193 .08378 L
.97214 .08375 L
.97237 .08371 L
.97261 .08365 L
.97305 .08352 L
.97345 .08337 L
.97389 .08316 L
.97469 .08268 L
.97619 .08146 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[544]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<_ooool3o`0000Cooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool3o`0001_ooooo0ol0000Jooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`?o00006Oooool2o`0001[ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0000Koooo
o`?o00004oooool003?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Hoooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Iooooo`05o`000?oooooo
ooooooooool000006_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00005oooool01?l0003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Iooooo`05o`000?ooooooooooooooool000004_ooool002_ooooo1Ol0
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004?ooool5o`0000Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`Go00001Oooool00ol0003ooooo
ooooo`0Aooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo
00Co0000oooooooooooo00006oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool04?ooool003?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0@ooooo`00<oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
01[ooooo00?o0000ooooooooool01Oooool4o`0001[ooooo1?l0000Jooooo`05o`000?oooooooooo
ooooool000001oooool4o`0001Sooooo00Co0000oooooooooooo00006Oooool01Ol0003ooooooooo
oooooooo000000Oooooo1?l0000Jooooo`Co00004oooool003;ooooo0_l00004ooooo`04o`000?oo
ooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool06Oooool01?l0003oooooooooool0000Iooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo000cooooo`03o`000?oooooo
oooo00?ooooo0_l0000Gooooo`Go00001oooool5o`0001Wooooo1Ol0000Jooooo`?o00002?ooool5
o`0001Sooooo0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol0000Booooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006?oooooho`00013ooooo000Aoooo
o`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00013ooooo000@oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo00kooooo000@ooooo`04o`000?ooooooooooo`0000Cooooo0_l00009
ooooo`;o00005?ooool2o`0001Cooooo0_l0000Dooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`;o00005?ooool2o`0001?ooooo0_l0000>
ooooo`;o00004?ooool0013ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`07
ooooo`Co00004_ooool3o`0001Cooooo0_l0000Cooooo`?o00004oooool3o`0001?ooooo0ol0000C
ooooo`?o00005?ooool2o`0000Gooooo00?o0000ooooooooool02oooool3o`0001?ooooo0ol0000C
ooooo`?o00003_ooool00ol0003oooooooooo`0>ooooo`004?ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00004_ooool00ol0003oooooo`00
000Cooooo`03o`000?oooooo000001?ooooo00?o0000ooooool000004oooool00ol0003oooooo`00
000Cooooo`03o`000?oooooo000001?ooooo00?o0000ooooool000004oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000004oooool00ol0003oooooo`00
000Booooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`0>ooooo`004?oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0001;ooooo00Co0000oooooooo
oooo00004_ooool00ol0003oooooo`00000Cooooo`03o`000?oooooo000001?ooooo00?o0000oooo
ool000004oooool00ol0003oooooo`00000Cooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooo`00000Cooooo`04o`000?ooooooooooo`00017ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00kooooo000Aooooo`;o00001Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool0
1Ol0003ooooooooooooooooo000001;ooooo00Co0000oooooooooooo00004_ooool00ol0003ooooo
o`00000Cooooo`03o`000?oooooo000001?ooooo00?o0000ooooool000004oooool00ol0003ooooo
o`00000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02oooool01?l0003o
ooooooooool0000Aooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Go0000oooo
ooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000004_ooool01?l0003ooooooooo
ool0000Booooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooool000004oooool00ol0003o
ooooo`00000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02oooool01?l0
003oooooooooool0000Aooooo`05o`000?ooooooooooooooool000004?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00Go0000
ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000004_ooool01?l0003ooooo
ooooool0000Booooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooool000004oooool00ol0
003oooooo`00000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02oooool0
1?l0003oooooooooool0000Aooooo`05o`000?ooooooooooooooool000004?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool001Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00Go
0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000004_ooool01?l0003o
ooooooooool0000Booooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooool000004oooool0
1?l0003oooooooooool0000Booooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
2_ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo
00Go0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000004Oooool01Ol0
003ooooooooooooooooo000001;ooooo00?o0000ooooool000004oooool01?l0003oooooooooool0
000Aooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0:ooooo`05o`00
0?ooooooooooooooool000004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00ko
oooo000Hooooo`;o00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool0
00004Oooool01Ol0003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000B
ooooo`03o`000?oooooo000001?ooooo00Co0000oooooooooooo00004Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool2o`00013ooooo000Hooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo
00Go0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000004Oooool01Ol0
003ooooooooooooooooo0000017ooooo00Co0000oooooooooooo00004_ooool01Ol0003ooooooooo
oooooooo0000017ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00[o
oooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool03_ooool001Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo0000
017ooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000004Ooo
ool01Ol0003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000Aooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00kooooo000Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0?ooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooooooooooooooo
0000017ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo0000017ooooo
00Go0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000004Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000004Oooool0
1Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00Go0000oooooooooooooooo
o`00000Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`00
6?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03_ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000<
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool3o`0000Gooooo00?o0000
ooooooooool03_ooool001Sooooo0_l0000@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000004Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Aooooo`;o00004?ooool001Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`006?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_oo
ool001Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0>ooooo`006?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0>ooooo`006?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`006?ooool2o`00017ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`;o00004?ooool001Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00002_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000
ooooooooool04_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
3_ooool000oooooo1Ol00004ooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00kooooo000@ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool04oooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00kooooo000Aooooo`03o`000?oooooooooo00Cooooo0_l0000Dooooo`?o00003oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool2o`00
013ooooo000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooo`00000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0>ooooo`003oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000006Oooool00ol0
003oooooooooo`0>ooooo`003oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000
ooooooooool03_ooool0013ooooo0ol00005ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ool000002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo00kooooo000Hooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool2o`0001[ooooo00?o0000oooooooo
ool03_ooool001Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000009ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000002Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
000000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool03_ooool001Sooooo0_l0000Wooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Wooooo0_l0000@ooooo`006?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
o`000009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool2o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool2o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2?ooool2o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool2o`0000Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool03_ooool001Sooooo0_l0000Xooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00002?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool2
o`00013ooooo000Hooooo`03o`000?oooooooooo02Sooooo00Go0000ooooooooooooooooo`00000=
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00kooooo000Hoooo
o`03o`000?oooooooooo02Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo0_l00008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo
02Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l00008
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo02Sooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo00kooooo000Hooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo00003oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`;o00002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0
003oooooooooo`0Xooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool2
o`0000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0:Oooool00ol0
003oooooo`00000?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`03o`000?oooooooooo
00cooooo00Go0000ooooooooooooooooo`00000^ooooo`03o`000?oooooooooo00kooooo000Hoooo
o`03o`000?oooooooooo02Wooooo0_l0000@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l00008oooo
o`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000^ooooo`03o`000?oooooo
oooo00kooooo000Hooooo`;o0000??ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000002gooooo0_l0000@
ooooo`006?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool00000;_ooool0
0ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooooooo
o`0002oooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool01?l0
003oooooooooool0000_ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooool00000;oooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0>ooooo`?o0000;oooool00ol0003oooooooooo`0>ooooo`004Oooool3o`0000Cooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03_ooool2o`00033ooooo00?o0000ooooooooool03_ooool001;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00kooooo000?
ooooo`Go00001?ooool2o`0003gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03oooooo0_l0000@ooooo`003oooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03_ooool0013ooooo00?o0000oooo
ool000001Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00kooooo000Aooooo`;o
00001Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00kooooo000Booooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0>ooooo`006?oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0:ooooo`;o00001Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00kooooo000Hooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool2o`00
00Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l00005ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool03_ooool001Sooooo0_l0000nooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo
0_l00005ooooo`03o`000?oooooooooo043ooooo0_l0000@ooooo`006?ooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00[ooooo0_l00005ooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:
ooooo`;o00001Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo000Hoooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool2o`0000Gooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00[ooooo0_l00005ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool03_ooool001Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`;o0000
1Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02_ooool2o`0000Gooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00[ooooo0_l00004ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool03_ooool0
01Sooooo00?o0000ooooooooool0?_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`;o00001?ooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo00kooooo000Hooooo`;o0000?oooool01?l0003oooooooooool0000?
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool2o`0000Cooooo00?o0000
ooooooooool0@Oooool2o`00013ooooo000Hooooo`03o`000?oooooooooo03kooooo00Co0000oooo
oooooooo00004?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo0_l00004
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooo
ooooool0?_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool2o`0000Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0>
ooooo`006?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo0000013ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`;o00001?ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo03oooooo0_l0000Aooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0
?oooool2o`00017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0>ooooo`006?oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool03_oo
ool001Sooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo00kooooo000Hooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0>ooooo`006?ooool2o`0005?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0;ooooo`06o`000?ooooooooooo`000?oooooo0000A?ooool2o`00013ooooo000Hoooo
o`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`06o`000?ooooooooooo`000?oooooo0000AOooool00ol0003oooooooooo`0>ooooo`006?ooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03o`0004Gooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00_l00016ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0>ooooo`004?ooool3o`0000Gooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0>ooooo`003oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0>ooooo`003oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0
001Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`17ooooo`;o00004?ooool000oooooo1?l00005ooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool03_ooool000oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00kooooo000@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0>ooooo`004Oooool2o`0000Gooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`1Cooooo`05o`000?oo
ooooooooooooool000004?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo
000Hooooo`03o`000?oooooooooo05?ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0Dooo
ool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0>ooooo`006?ooool00ol0003oooooooooo`1Cooooo`05o`000?ooooooooooooooool00000
4?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`;o0000E?oo
ool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool01Ol0003ooooo
oooooooooooo000000oooooo00?o0000ooooooooool0Aoooool2o`00013ooooo000Hooooo`03o`00
0?oooooooooo05?ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool03_ooool001Sooooo00?o0000ooooooooool0E?ooool01?l0003oooooooooool0000@oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0E?ooool01?l0
003oooooooooool0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00
000?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000
ooooooooool0E?ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00Go
0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
3_ooool001Sooooo00?o0000ooooooooool0E?ooool01?l0003oooooooooool0000@ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0E?ooool01?l0003ooooo
ooooool0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001So
oooo00?o0000ooooooooool0E?ooool3o`00017ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool01Ol0003o
oooooooooooooooo000000oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>oooo
o`006?ooool2o`0005Kooooo0_l0000Aooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03o`000?oooooooooo04Oooooo0_l0000@ooooo`006?ooool00ol0003o
ooooooooo`1Eooooo`;o00004Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`00
00oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003o
ooooooooo`1Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool000004?ooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03oooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0>ooooo`006?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooool000004?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hoooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool2o`00017ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`1Yooooo`05
o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003o
ooooooooo`1Yooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooooooooooooooo
000002Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool2o`00
06[ooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000009Ooo
ool00ol0003oooooooooo`17ooooo`;o00004?ooool001Sooooo00?o0000ooooooooool0JOooool0
1Ol0003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0JOoo
ool01Ol0003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000Uooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0
JOooool01Ol0003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000Uoooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooooooo
ool0JOooool01Ol0003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000U
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooo
ooooool0J_ooool01?l0003oooooooooool0000Aooooo`05o`000?ooooooooooooooool000009Ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000@ooooo`?o00001Oooool0
0ol0003oooooooooo`1Zooooo`04o`000?ooooooooooo`00017ooooo00Go0000oooooooooooooooo
o`00000Uooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool000oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooool00000
4_ooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`003oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0001[ooooo`03
o`000?oooooo000001?ooooo00Co0000oooooooooooo00009Oooool00ol0003oooooooooo`17oooo
o`;o00004?ooool0013ooooo0ol00005ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooool0
00004oooool00ol0003oooooo`00000Vooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool03_ooool000oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooool000004oooool00ol0003oooooo`00000Vooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool03_ooool000oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo06_ooooo0_l0000Cooooo`03o`000?oooooo000002Kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0>ooooo`004?ooool3o`0000Gooooo00?o0000ooooooooool0
Joooool00ol0003oooooooooo`0Booooo`03o`000?oooooo000002Kooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`20ooooo`?o00009_oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooo
oooo087ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo00kooooo000Hooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00
013ooooo000HooooooSo00004?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0<oooooo0ol0001>ooooo`00d?ooool00ol0003oooooooooo`1=ooooo`00DOooool5o`000005oooo
ool0003o0000o`000?ooool00_l00002ooooo`;o00000oooool3o`0000;ooooo0ol00003ooooo`Go
00000_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3o`000004ooooool0003o0000oooo
o`?o00000oooool3o`0000Sooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2
o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l00002ooooo`Go00000oooool2
o`0000Cooooo00?o0000ooooooooool0C?ooool005?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
000000gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`06o`000?oo
ooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooooooo
ooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04cooooo001C
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`Go0000
0_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`00
00Gooooo1Ol00009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`?o00001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000COoo
ool005?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00001Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?oooooooooooooo
ool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003o
ooooooooool0003oooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000004gooooo001Cooooo`04o`000?ooooooooooooooo`Co00000_ooool4
o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo0ol00002
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l00003ooooo`?o00000oooool3
o`0000[ooooo00Co0000oooooooooooooooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l0
0003ooooo`Co000000Coooooo`000?l0003o00000oooool4o`0000;ooooo0_l000000ooooooo0000
o`00001<ooooo`00Doooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0Doooool0057ooooo1Ol00008ooooo`03o`000?oooooooooo017ooooo0_l0000[
ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Doooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.6892, -0.897588, \
0.0697124, 0.0570722}},
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindInterference[system]", "Input",
  CellLabel->"In[545]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 7, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 1, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 7, SurfaceNumber -> 1, 
        WaveFrontID -> 1, Source -> 1}],
      Editable->False]], "Print",
  CellLabel->"From In[545]:=",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.696161 0.0579522 0.0998602 0.0545719 [
[.11664 -0.0125 -9 -9 ]
[.11664 -0.0125 9 0 ]
[.26152 -0.0125 -12 -9 ]
[.26152 -0.0125 12 0 ]
[.4064 -0.0125 -6 -9 ]
[.4064 -0.0125 6 0 ]
[.55128 -0.0125 -12 -9 ]
[.55128 -0.0125 12 0 ]
[.69616 -0.0125 -3 -9 ]
[.69616 -0.0125 3 0 ]
[.84104 -0.0125 -9 -9 ]
[.84104 -0.0125 9 0 ]
[.98592 -0.0125 -3 -9 ]
[.98592 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09986 -6 -4.5 ]
[-0.0125 .09986 0 4.5 ]
[-0.0125 .209 -6 -4.5 ]
[-0.0125 .209 0 4.5 ]
[-0.0125 .31815 -6 -4.5 ]
[-0.0125 .31815 0 4.5 ]
[-0.0125 .42729 -6 -4.5 ]
[-0.0125 .42729 0 4.5 ]
[-0.0125 .53644 -6 -4.5 ]
[-0.0125 .53644 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11664 0 m
.11664 .00625 L
s
[(-10)] .11664 -0.0125 0 1 Mshowa
.26152 0 m
.26152 .00625 L
s
[(-7.5)] .26152 -0.0125 0 1 Mshowa
.4064 0 m
.4064 .00625 L
s
[(-5)] .4064 -0.0125 0 1 Mshowa
.55128 0 m
.55128 .00625 L
s
[(-2.5)] .55128 -0.0125 0 1 Mshowa
.69616 0 m
.69616 .00625 L
s
[(0)] .69616 -0.0125 0 1 Mshowa
.84104 0 m
.84104 .00625 L
s
[(2.5)] .84104 -0.0125 0 1 Mshowa
.98592 0 m
.98592 .00625 L
s
[(5)] .98592 -0.0125 0 1 Mshowa
.125 Mabswid
.14562 0 m
.14562 .00375 L
s
.17459 0 m
.17459 .00375 L
s
.20357 0 m
.20357 .00375 L
s
.23254 0 m
.23254 .00375 L
s
.2905 0 m
.2905 .00375 L
s
.31947 0 m
.31947 .00375 L
s
.34845 0 m
.34845 .00375 L
s
.37742 0 m
.37742 .00375 L
s
.43538 0 m
.43538 .00375 L
s
.46435 0 m
.46435 .00375 L
s
.49333 0 m
.49333 .00375 L
s
.5223 0 m
.5223 .00375 L
s
.58026 0 m
.58026 .00375 L
s
.60923 0 m
.60923 .00375 L
s
.63821 0 m
.63821 .00375 L
s
.66719 0 m
.66719 .00375 L
s
.72514 0 m
.72514 .00375 L
s
.75411 0 m
.75411 .00375 L
s
.78309 0 m
.78309 .00375 L
s
.81207 0 m
.81207 .00375 L
s
.87002 0 m
.87002 .00375 L
s
.89899 0 m
.89899 .00375 L
s
.92797 0 m
.92797 .00375 L
s
.95695 0 m
.95695 .00375 L
s
.08766 0 m
.08766 .00375 L
s
.05869 0 m
.05869 .00375 L
s
.02971 0 m
.02971 .00375 L
s
.00074 0 m
.00074 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09986 m
.00625 .09986 L
s
[(0)] -0.0125 .09986 1 0 Mshowa
0 .209 m
.00625 .209 L
s
[(2)] -0.0125 .209 1 0 Mshowa
0 .31815 m
.00625 .31815 L
s
[(4)] -0.0125 .31815 1 0 Mshowa
0 .42729 m
.00625 .42729 L
s
[(6)] -0.0125 .42729 1 0 Mshowa
0 .53644 m
.00625 .53644 L
s
[(8)] -0.0125 .53644 1 0 Mshowa
.125 Mabswid
0 .12715 m
.00375 .12715 L
s
0 .15443 m
.00375 .15443 L
s
0 .18172 m
.00375 .18172 L
s
0 .23629 m
.00375 .23629 L
s
0 .26358 m
.00375 .26358 L
s
0 .29086 m
.00375 .29086 L
s
0 .34543 m
.00375 .34543 L
s
0 .37272 m
.00375 .37272 L
s
0 .40001 m
.00375 .40001 L
s
0 .45458 m
.00375 .45458 L
s
0 .48186 m
.00375 .48186 L
s
0 .50915 m
.00375 .50915 L
s
0 .07257 m
.00375 .07257 L
s
0 .04529 m
.00375 .04529 L
s
0 .018 m
.00375 .018 L
s
0 .56372 m
.00375 .56372 L
s
0 .59101 m
.00375 .59101 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11664 .61178 m
.11664 .61803 L
s
.26152 .61178 m
.26152 .61803 L
s
.4064 .61178 m
.4064 .61803 L
s
.55128 .61178 m
.55128 .61803 L
s
.69616 .61178 m
.69616 .61803 L
s
.84104 .61178 m
.84104 .61803 L
s
.98592 .61178 m
.98592 .61803 L
s
.125 Mabswid
.14562 .61428 m
.14562 .61803 L
s
.17459 .61428 m
.17459 .61803 L
s
.20357 .61428 m
.20357 .61803 L
s
.23254 .61428 m
.23254 .61803 L
s
.2905 .61428 m
.2905 .61803 L
s
.31947 .61428 m
.31947 .61803 L
s
.34845 .61428 m
.34845 .61803 L
s
.37742 .61428 m
.37742 .61803 L
s
.43538 .61428 m
.43538 .61803 L
s
.46435 .61428 m
.46435 .61803 L
s
.49333 .61428 m
.49333 .61803 L
s
.5223 .61428 m
.5223 .61803 L
s
.58026 .61428 m
.58026 .61803 L
s
.60923 .61428 m
.60923 .61803 L
s
.63821 .61428 m
.63821 .61803 L
s
.66719 .61428 m
.66719 .61803 L
s
.72514 .61428 m
.72514 .61803 L
s
.75411 .61428 m
.75411 .61803 L
s
.78309 .61428 m
.78309 .61803 L
s
.81207 .61428 m
.81207 .61803 L
s
.87002 .61428 m
.87002 .61803 L
s
.89899 .61428 m
.89899 .61803 L
s
.92797 .61428 m
.92797 .61803 L
s
.95695 .61428 m
.95695 .61803 L
s
.08766 .61428 m
.08766 .61803 L
s
.05869 .61428 m
.05869 .61803 L
s
.02971 .61428 m
.02971 .61803 L
s
.00074 .61428 m
.00074 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09986 m
1 .09986 L
s
.99375 .209 m
1 .209 L
s
.99375 .31815 m
1 .31815 L
s
.99375 .42729 m
1 .42729 L
s
.99375 .53644 m
1 .53644 L
s
.125 Mabswid
.99625 .12715 m
1 .12715 L
s
.99625 .15443 m
1 .15443 L
s
.99625 .18172 m
1 .18172 L
s
.99625 .23629 m
1 .23629 L
s
.99625 .26358 m
1 .26358 L
s
.99625 .29086 m
1 .29086 L
s
.99625 .34543 m
1 .34543 L
s
.99625 .37272 m
1 .37272 L
s
.99625 .40001 m
1 .40001 L
s
.99625 .45458 m
1 .45458 L
s
.99625 .48186 m
1 .48186 L
s
.99625 .50915 m
1 .50915 L
s
.99625 .07257 m
1 .07257 L
s
.99625 .04529 m
1 .04529 L
s
.99625 .018 m
1 .018 L
s
.99625 .56372 m
1 .56372 L
s
.99625 .59101 m
1 .59101 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .09986 m
1 .09986 L
s
.69616 0 m
.69616 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .01472 Mdot
.94557 .0196 Mdot
.91492 .02257 Mdot
.88426 .02425 Mdot
.85357 .02518 Mdot
.82288 .02588 Mdot
.79216 .02681 Mdot
.76144 .02839 Mdot
.73071 .03098 Mdot
.69996 .03492 Mdot
.66921 .04049 Mdot
.63845 .04793 Mdot
.60769 .05745 Mdot
.57693 .06921 Mdot
.54616 .08332 Mdot
.51539 .09986 Mdot
.48461 .11888 Mdot
.45384 .14037 Mdot
.42307 .16429 Mdot
.39231 .19057 Mdot
.36155 .21907 Mdot
.33079 .24965 Mdot
.30004 .28209 Mdot
.26929 .31615 Mdot
.23856 .35155 Mdot
.20784 .38795 Mdot
.17712 .42498 Mdot
.14643 .46223 Mdot
.11574 .49922 Mdot
.08508 .53545 Mdot
.05443 .57035 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.03111 .59563 L
.03907 .58712 L
.04655 .57902 L
.05374 .57111 L
.0614 .56258 L
.06877 .55426 L
.0766 .54529 L
.08415 .53654 L
.0914 .52808 L
.09913 .51901 L
.10656 .5102 L
.11371 .50166 L
.12133 .49254 L
.12865 .48374 L
.13644 .47434 L
.14395 .46524 L
.15117 .45649 L
.15885 .44718 L
.16624 .43821 L
.1741 .42866 L
.18167 .41948 L
.18896 .41069 L
.1967 .40134 L
.20417 .39236 L
.21134 .38376 L
.21898 .37467 L
.22633 .36595 L
.23415 .35673 L
.24168 .34791 L
.24892 .3395 L
.25663 .33061 L
.26405 .32212 L
.27119 .31402 L
.27878 .30549 L
.28609 .29737 L
.29387 .28882 L
.30136 .28066 L
.30856 .27294 L
.31622 .26481 L
.3236 .25708 L
.33144 .24898 L
.339 .2413 L
.34627 .23403 L
.354 .2264 L
.36145 .21917 L
.36861 .21235 L
.37623 .20521 L
.38357 .19846 L
.39137 .19141 L
Mistroke
.39888 .18477 L
.40611 .1785 L
.4138 .17198 L
.4212 .16583 L
.42907 .15944 L
.43665 .15344 L
.44395 .14781 L
.45171 .14195 L
.45918 .13647 L
.46637 .13133 L
.47401 .12601 L
.48138 .12102 L
.4892 .11588 L
.49674 .11109 L
.504 .10661 L
.51171 .102 L
.51914 .09771 L
.52629 .09372 L
.53389 .08962 L
.54122 .08581 L
.549 .08191 L
.5565 .07831 L
.56371 .07498 L
.57138 .07157 L
.57877 .06844 L
.58662 .06526 L
.59419 .06234 L
.60147 .05965 L
.60921 .05693 L
.61667 .05446 L
.62384 .0522 L
.63147 .04991 L
.63882 .04784 L
.64663 .04577 L
.65415 .0439 L
.66139 .04221 L
.66909 .04052 L
.6765 .03902 L
.68363 .03768 L
.69122 .03634 L
.69853 .03515 L
.7063 .034 L
.71378 .03299 L
.72097 .03208 L
.72863 .03121 L
.736 .03046 L
.74384 .02975 L
.75139 .02913 L
.75865 .02858 L
.76638 .02809 L
Mistroke
.77382 .02768 L
.78097 .02731 L
.78859 .02696 L
.79592 .02669 L
.80372 .02644 L
.81122 .02621 L
.81844 .026 L
.82613 .02582 L
.83353 .02567 L
.84139 .02549 L
.84897 .0253 L
.85625 .02513 L
.86401 .02495 L
.87147 .02473 L
.87865 .02448 L
.8863 .02418 L
.89365 .02387 L
.90147 .02347 L
.90901 .023 L
.91625 .02248 L
.92396 .02189 L
.93139 .02121 L
.93853 .02045 L
.94613 .01953 L
.95344 .01852 L
.96122 .01734 L
.96871 .01608 L
.97592 .01477 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[545]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0000Cooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool3o`0001[ooooo0ol0000Jooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`?o00006Oooool2o`0001[ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0000Koooo
o`?o00004oooool003Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Hoooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Hooooo`05o`000?oooooo
ooooooooool000006_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00005oooool01?l0003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Iooooo`05o`000?ooooooooooooooool000004_ooool002cooooo1Ol0
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004?ooool5o`0000Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`Go00001Oooool00ol0003ooooo
ooooo`0Aooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo
00Co0000oooooooooooo00006oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool04?ooool003Cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0@ooooo`00=?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
01[ooooo00?o0000ooooooooool01Oooool4o`0001Wooooo1?l0000Jooooo`05o`000?oooooooooo
ooooool000001oooool4o`0001Sooooo00Co0000oooooooooooo00006Oooool01Ol0003ooooooooo
oooooooo000000Oooooo1?l0000Jooooo`Co00004oooool003?ooooo0_l00004ooooo`04o`000?oo
ooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool06Oooool01?l0003oooooooooool0000Iooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo000dooooo`03o`000?oooooo
oooo00?ooooo0_l0000Gooooo`Go00001oooool5o`0001Sooooo1Ol0000Jooooo`?o00002?ooool5
o`0001Sooooo0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol0000Booooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006?oooooho`00013ooooo000Hoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00004?ooool001Sooooo00?o0000oooo
ooooool0ZOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03
o`000?oooooooooo0:Wooooo00?o0000ooooooooool0@Oooool2o`0000Gooooo00?o0000oooooooo
ool03_ooool001Sooooo0_l0002Zooooo`03o`000?oooooooooo03[ooooo2Ol00004ooooo`;o0000
4?ooool001Sooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`0[ooooo`;o00000_oo
ool=o`0000cooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0ZOooool0
0ol0003oooooooooo`0<ooooo`;o000000?oooooo`000?l000007_l00003ooooo`;o00005?ooool0
0ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo
00Cooooo2ol00005ooooo`;o00001_ooool2o`0000Gooooo0_l0000Sooooo`03o`000?oooooooooo
00kooooo000Hooooo`03o`000?oooooooooo0:Wooooo1ol000000ooooooo0000o`000011ooooo`03
o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo0:;ooooo2Ol00019ooooo`03o`00
0?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo0:3ooooo1?l00005ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo0_l0002Kooooo`Ko00002Oooool0
0ol0003oooooooooo`17ooooo`;o00004?ooool001Sooooo00?o0000ooooooooool0V?ooool4o`00
00gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003o
ooooooooo`2Dooooo`Co00004Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00ko
oooo000Hooooo`03o`000?oooooooooo097ooooo0ol0000Eooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0Soooool2o`000003ooooool0
003o000001Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool0
0ol0003oooooooooo`2;ooooo`Co00006_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo00kooooo000Hooooo`03o`000?oooooooooo08Wooooo1?l0000Looooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool03_ooool001Sooooo0_l00028ooooo`;o00008?ooool00ol0003o
ooooooooo`17ooooo`;o00004?ooool001Sooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o
0000ooooooooool0Poooool3o`0002?ooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0>ooooo`006?ooool00ol0003oooooooooo`22ooooo`?o00009?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo00kooooo000Aooooo`;o00001Oooool00ol0003oooooooooo`20oooo
o`;o00009oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000@ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0O_ooool2o`0002Wooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0>ooooo`004?ooool01?l0003oooooooooool00004oooo
ooSo00004?ooool0013ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1joooo
o`Co0000:oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000@ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool0013ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`1gooooo`;o0000<?ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00kooooo000Aooooo`;o00001Oooool00ol0003oooooooooo`1fooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`00
6?ooool00ol0003oooooooooo`1dooooo`;o0000<oooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo07?ooooo0ol0000cooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo0_l0001booooo`;o0000=_ooool0
0ol0003oooooooooo`17ooooo`;o00004?ooool001Sooooo00?o0000ooooooooool0Koooool2o`00
03Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`1/ooooo`?o0000>_ooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo06cooooo0_l0
000kooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000
ooooooooool0Joooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool03_ooool001Sooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo0_l0001Yooooo`;o
0000?oooool00ol0003oooooooooo`17ooooo`;o00004?ooool001Sooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
3_ooool001Sooooo00?o0000ooooooooool0IOooool2o`0004;ooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`1Tooooo`?o0000@_ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00kooooo000Hooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo063ooooo
0_l00017ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo0_l0
001Pooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0Aoooool2o`00013ooooo000H
ooooo`03o`000?oooooooooo05gooooo0ol00019ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool03_ooool001Sooooo00?o0000ooooooooool0GOooool2o`0004[ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`1Mooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`00
3oooool5o`0000Cooooo00?o0000ooooooooool0Foooool2o`0004cooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0>ooooo`004?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo05[ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo00kooooo000Aooooo`03o`000?oooooooooo00Cooooo0_l0001Jooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool0Aoooool2o`00013ooooo000Booooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool03_ooool000oooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo05Kooooo0_l0001Aooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool03_ooool000oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo05Kooooo0_l0001Aooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool0
013ooooo0ol00005ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo05?o
oooo0_l0001Dooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool03_ooool001Sooooo0_l0001Cooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool0Aoooool2o`00013ooooo000Hooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool0EOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hoooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo04kooooo0_l0001Iooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0
C_ooool2o`0005Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool2o`00
04cooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`17ooooo`;o00004?ooool001So
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0A_ooool2o`00067ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`16oooo
o`;o0000HOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo00kooooo000Hooooo`;o0000A_ooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo04Oooooo0_l0000@ooooo`006?ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`004Oooool3o`0000Co
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool03_ooool001;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0oooooo`;o0000J?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo
000?ooooo`Go00001?ooool2o`00043ooooo0_l0001Xooooo`03o`000?oooooooooo04Oooooo0_l0
000@ooooo`003oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000@
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1Y
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool0017ooooo0_l00005oooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00kooooo000Booooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool03_ooool001Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1[ooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_oo
ool001Sooooo0_l0000kooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0Aoooool2
o`00013ooooo000Hooooo`03o`000?oooooooooo03Oooooo0ol0001_ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0=oooool2o`00073o
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0>ooooo`006?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>
ooooo`006?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool2o`0003Cooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`17ooooo`;o00004?ooool001Sooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
3_ooool001Sooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0<?ooool2
o`0007Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0
003oooooooooo`0`ooooo`;o0000Moooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00kooooo000Hooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Moooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0Moooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo
000Hooooo`;o0000;oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo04Oooooo0_l0
000@ooooo`006?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>oooo
o`006?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07_ooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0>ooooo`004?ooool3o`0000Gooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
3_ooool000oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Sooooo
0ol0001nooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool000oooooo00Go
0000ooooooooooooooooo`000004ooooo`;o0000:Oooool2o`0007oooooo00?o0000ooooooooool0
Aoooool2o`00013ooooo000?ooooo`Co00001Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo07kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`003oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000@ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool03_ooool0017ooooo0_l00005ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0POooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00ko
oooo000Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0Poooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000H
ooooo`;o00008oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo04Oooooo0_l0000@
ooooo`006?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo08Cooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0Pooooo`;o
0000Qoooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`00
0?oooooooooo023ooooo0_l00027ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
3_ooool001Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`27ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool0
01Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool03_ooool001Sooooo0_l0000Nooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool0Aoooool2o`00013ooooo000Hooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0R_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo
000Hooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0Roooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hoooo
o`03o`000?oooooooooo01Wooooo0_l0002>ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool03_ooool001Sooooo00?o0000ooooooooool06Oooool2o`0008kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool2o`0001Wooooo00?o0000ooooooooool0
S_ooool00ol0003oooooooooo`17ooooo`;o00004?ooool001Sooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_oo
ool001Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`2Aooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001So
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool03_ooool0013ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0Toooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo
000?ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo09?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`003ooo
ool01Ol0003ooooooooooooooooo000000Cooooo0_l0000Booooo`;o0000U_ooool00ol0003ooooo
ooooo`17ooooo`;o00004?ooool0013ooooo0ol00005ooooo`03o`000?oooooooooo017ooooo0_l0
002Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool000oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0U_oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000?ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09Kooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`004?ooool3o`0000Gooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool03_ooool001Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Hoooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool03_ooool001Sooooo0_l0000=ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
Aoooool2o`00013ooooo000Hooooo`03o`000?oooooooooo00[ooooo0_l0002Mooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool02_ooool2
o`0009gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo09ko
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0>ooooo`006?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09oooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool2o`0000Oooooo00?o0000
ooooooooool0X?ooool00ol0003oooooooooo`17ooooo`;o00004?ooool001Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool03_ooool001Sooooo00?o0000ooooooooool00_ooool3o`000:Cooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`02ooooo`;o0000
YOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oo
oooooooo0:Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00013ooooo000HooooooSo00004?ooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool002[ooooo0ol0002:ooooo`03o`000?oo
oooooooo02_ooooo0ol0000Eooooo`03o`000?oooooooooo023ooooo000[ooooo`03o`000?oooooo
oooo08Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01oooooo000Uooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`00
00?ooooo1?l000000ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co00000oooool2o`00
00;ooooo1_l00006ooooo`Co00000_ooool5o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000ol00002ooooo`?o00000_ooool3o`0000Cooooo0ol00002ooooo`?o000000Coooooo`00
0?l0003ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00000_ooool3
o`0000;ooooo0ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00002ooooo`[o00001Ooo
ool00ol0003oooooooooo`0Nooooo`009?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Nooooo`00
9?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`03
o`000?oooooooooo00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5
o`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol0
0003ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`04o`000?ooooooooooooooo`Go0000
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00002ooooo`?o00001Oooool00ol0003oooooooooo`0Nooooo`009?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool3o`0000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`07o`000?oooooo
0000ooooool0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Go
oooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo01kooooo000Toooo
o`06o`000?ooooooooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol0
0003ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo
0_l00003ooooo`Co00000oooool3o`0000Wooooo00Go0000oooooooooooo0000ooooo`03o`0000Co
oooo1?l00002ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o
00000_ooool4o`0000?ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`Ko
000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`03
o`000?oooooooooo00;ooooo0ol00002ooooo`Co00000oooool9o`0000?ooooo0ol00003ooooo`Co
00001?ooool00ol0003oooooooooo`0Nooooo`009?ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07oooool002Gooooo0ol00009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03Oooool3o`0000Wooooo1?l00009ooooo`03o`000?oooooooooo
00;ooooo0_l0000:ooooo`Co00001?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool2o`00
02kooooo00?o0000ooooooooool06?ooool3o`0001Kooooo00?o0000ooooooooool00_ooool2o`00
00_ooooo00?o0000ooooooooool08?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.716, -2.72624, \
0.0698135, 0.0741379}},
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 7, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 2, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 7, SurfaceNumber -> 1, 
        WaveFrontID -> 2, Source -> 1}],
      Editable->False]], "Print",
  CellLabel->"From In[545]:=",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.694048 0.0578888 0.0156278 0.160553 [
[.11516 -0.0125 -9 -9 ]
[.11516 -0.0125 9 0 ]
[.25988 -0.0125 -12 -9 ]
[.25988 -0.0125 12 0 ]
[.4046 -0.0125 -6 -9 ]
[.4046 -0.0125 6 0 ]
[.54933 -0.0125 -12 -9 ]
[.54933 -0.0125 12 0 ]
[.69405 -0.0125 -3 -9 ]
[.69405 -0.0125 3 0 ]
[.83877 -0.0125 -9 -9 ]
[.83877 -0.0125 9 0 ]
[.98349 -0.0125 -3 -9 ]
[.98349 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01563 -6 -4.5 ]
[-0.0125 .01563 0 4.5 ]
[-0.0125 .0959 -18 -4.5 ]
[-0.0125 .0959 0 4.5 ]
[-0.0125 .17618 -6 -4.5 ]
[-0.0125 .17618 0 4.5 ]
[-0.0125 .25646 -18 -4.5 ]
[-0.0125 .25646 0 4.5 ]
[-0.0125 .33673 -6 -4.5 ]
[-0.0125 .33673 0 4.5 ]
[-0.0125 .41701 -18 -4.5 ]
[-0.0125 .41701 0 4.5 ]
[-0.0125 .49729 -6 -4.5 ]
[-0.0125 .49729 0 4.5 ]
[-0.0125 .57756 -18 -4.5 ]
[-0.0125 .57756 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11516 0 m
.11516 .00625 L
s
[(-10)] .11516 -0.0125 0 1 Mshowa
.25988 0 m
.25988 .00625 L
s
[(-7.5)] .25988 -0.0125 0 1 Mshowa
.4046 0 m
.4046 .00625 L
s
[(-5)] .4046 -0.0125 0 1 Mshowa
.54933 0 m
.54933 .00625 L
s
[(-2.5)] .54933 -0.0125 0 1 Mshowa
.69405 0 m
.69405 .00625 L
s
[(0)] .69405 -0.0125 0 1 Mshowa
.83877 0 m
.83877 .00625 L
s
[(2.5)] .83877 -0.0125 0 1 Mshowa
.98349 0 m
.98349 .00625 L
s
[(5)] .98349 -0.0125 0 1 Mshowa
.125 Mabswid
.1441 0 m
.1441 .00375 L
s
.17305 0 m
.17305 .00375 L
s
.20199 0 m
.20199 .00375 L
s
.23094 0 m
.23094 .00375 L
s
.28883 0 m
.28883 .00375 L
s
.31777 0 m
.31777 .00375 L
s
.34672 0 m
.34672 .00375 L
s
.37566 0 m
.37566 .00375 L
s
.43355 0 m
.43355 .00375 L
s
.46249 0 m
.46249 .00375 L
s
.49144 0 m
.49144 .00375 L
s
.52038 0 m
.52038 .00375 L
s
.57827 0 m
.57827 .00375 L
s
.60721 0 m
.60721 .00375 L
s
.63616 0 m
.63616 .00375 L
s
.6651 0 m
.6651 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.75194 0 m
.75194 .00375 L
s
.78088 0 m
.78088 .00375 L
s
.80983 0 m
.80983 .00375 L
s
.86771 0 m
.86771 .00375 L
s
.89666 0 m
.89666 .00375 L
s
.9256 0 m
.9256 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.08622 0 m
.08622 .00375 L
s
.05727 0 m
.05727 .00375 L
s
.02833 0 m
.02833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01563 m
.00625 .01563 L
s
[(0)] -0.0125 .01563 1 0 Mshowa
0 .0959 m
.00625 .0959 L
s
[(0.5)] -0.0125 .0959 1 0 Mshowa
0 .17618 m
.00625 .17618 L
s
[(1)] -0.0125 .17618 1 0 Mshowa
0 .25646 m
.00625 .25646 L
s
[(1.5)] -0.0125 .25646 1 0 Mshowa
0 .33673 m
.00625 .33673 L
s
[(2)] -0.0125 .33673 1 0 Mshowa
0 .41701 m
.00625 .41701 L
s
[(2.5)] -0.0125 .41701 1 0 Mshowa
0 .49729 m
.00625 .49729 L
s
[(3)] -0.0125 .49729 1 0 Mshowa
0 .57756 m
.00625 .57756 L
s
[(3.5)] -0.0125 .57756 1 0 Mshowa
.125 Mabswid
0 .03168 m
.00375 .03168 L
s
0 .04774 m
.00375 .04774 L
s
0 .06379 m
.00375 .06379 L
s
0 .07985 m
.00375 .07985 L
s
0 .11196 m
.00375 .11196 L
s
0 .12801 m
.00375 .12801 L
s
0 .14407 m
.00375 .14407 L
s
0 .16013 m
.00375 .16013 L
s
0 .19224 m
.00375 .19224 L
s
0 .20829 m
.00375 .20829 L
s
0 .22435 m
.00375 .22435 L
s
0 .2404 m
.00375 .2404 L
s
0 .27251 m
.00375 .27251 L
s
0 .28857 m
.00375 .28857 L
s
0 .30462 m
.00375 .30462 L
s
0 .32068 m
.00375 .32068 L
s
0 .35279 m
.00375 .35279 L
s
0 .36884 m
.00375 .36884 L
s
0 .3849 m
.00375 .3849 L
s
0 .40095 m
.00375 .40095 L
s
0 .43306 m
.00375 .43306 L
s
0 .44912 m
.00375 .44912 L
s
0 .46518 m
.00375 .46518 L
s
0 .48123 m
.00375 .48123 L
s
0 .51334 m
.00375 .51334 L
s
0 .5294 m
.00375 .5294 L
s
0 .54545 m
.00375 .54545 L
s
0 .56151 m
.00375 .56151 L
s
0 .59362 m
.00375 .59362 L
s
0 .60967 m
.00375 .60967 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11516 .61178 m
.11516 .61803 L
s
.25988 .61178 m
.25988 .61803 L
s
.4046 .61178 m
.4046 .61803 L
s
.54933 .61178 m
.54933 .61803 L
s
.69405 .61178 m
.69405 .61803 L
s
.83877 .61178 m
.83877 .61803 L
s
.98349 .61178 m
.98349 .61803 L
s
.125 Mabswid
.1441 .61428 m
.1441 .61803 L
s
.17305 .61428 m
.17305 .61803 L
s
.20199 .61428 m
.20199 .61803 L
s
.23094 .61428 m
.23094 .61803 L
s
.28883 .61428 m
.28883 .61803 L
s
.31777 .61428 m
.31777 .61803 L
s
.34672 .61428 m
.34672 .61803 L
s
.37566 .61428 m
.37566 .61803 L
s
.43355 .61428 m
.43355 .61803 L
s
.46249 .61428 m
.46249 .61803 L
s
.49144 .61428 m
.49144 .61803 L
s
.52038 .61428 m
.52038 .61803 L
s
.57827 .61428 m
.57827 .61803 L
s
.60721 .61428 m
.60721 .61803 L
s
.63616 .61428 m
.63616 .61803 L
s
.6651 .61428 m
.6651 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.75194 .61428 m
.75194 .61803 L
s
.78088 .61428 m
.78088 .61803 L
s
.80983 .61428 m
.80983 .61803 L
s
.86771 .61428 m
.86771 .61803 L
s
.89666 .61428 m
.89666 .61803 L
s
.9256 .61428 m
.9256 .61803 L
s
.95455 .61428 m
.95455 .61803 L
s
.08622 .61428 m
.08622 .61803 L
s
.05727 .61428 m
.05727 .61803 L
s
.02833 .61428 m
.02833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01563 m
1 .01563 L
s
.99375 .0959 m
1 .0959 L
s
.99375 .17618 m
1 .17618 L
s
.99375 .25646 m
1 .25646 L
s
.99375 .33673 m
1 .33673 L
s
.99375 .41701 m
1 .41701 L
s
.99375 .49729 m
1 .49729 L
s
.99375 .57756 m
1 .57756 L
s
.125 Mabswid
.99625 .03168 m
1 .03168 L
s
.99625 .04774 m
1 .04774 L
s
.99625 .06379 m
1 .06379 L
s
.99625 .07985 m
1 .07985 L
s
.99625 .11196 m
1 .11196 L
s
.99625 .12801 m
1 .12801 L
s
.99625 .14407 m
1 .14407 L
s
.99625 .16013 m
1 .16013 L
s
.99625 .19224 m
1 .19224 L
s
.99625 .20829 m
1 .20829 L
s
.99625 .22435 m
1 .22435 L
s
.99625 .2404 m
1 .2404 L
s
.99625 .27251 m
1 .27251 L
s
.99625 .28857 m
1 .28857 L
s
.99625 .30462 m
1 .30462 L
s
.99625 .32068 m
1 .32068 L
s
.99625 .35279 m
1 .35279 L
s
.99625 .36884 m
1 .36884 L
s
.99625 .3849 m
1 .3849 L
s
.99625 .40095 m
1 .40095 L
s
.99625 .43306 m
1 .43306 L
s
.99625 .44912 m
1 .44912 L
s
.99625 .46518 m
1 .46518 L
s
.99625 .48123 m
1 .48123 L
s
.99625 .51334 m
1 .51334 L
s
.99625 .5294 m
1 .5294 L
s
.99625 .54545 m
1 .54545 L
s
.99625 .56151 m
1 .56151 L
s
.99625 .59362 m
1 .59362 L
s
.99625 .60967 m
1 .60967 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.69405 0 m
.69405 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .60332 Mdot
.94569 .56212 Mdot
.91514 .51526 Mdot
.88455 .4645 Mdot
.85392 .41149 Mdot
.82326 .35773 Mdot
.79256 .30459 Mdot
.76184 .25331 Mdot
.73109 .20498 Mdot
.70032 .16058 Mdot
.66953 .12096 Mdot
.63873 .08685 Mdot
.60791 .05884 Mdot
.57709 .03741 Mdot
.54625 .02293 Mdot
.51542 .01563 Mdot
.48458 .01563 Mdot
.45375 .02293 Mdot
.42291 .03741 Mdot
.39209 .05884 Mdot
.36127 .08685 Mdot
.33047 .12096 Mdot
.29968 .16058 Mdot
.26891 .20498 Mdot
.23816 .25331 Mdot
.20744 .30459 Mdot
.17674 .35773 Mdot
.14608 .41149 Mdot
.11545 .4645 Mdot
.08486 .51526 Mdot
.05431 .56212 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.03111 .59397 L
.03907 .5834 L
.04655 .57313 L
.05374 .56294 L
.0614 .55175 L
.06877 .54064 L
.0766 .52848 L
.08415 .51641 L
.0914 .50471 L
.09913 .49205 L
.10656 .47963 L
.11371 .46748 L
.12133 .45449 L
.12865 .44191 L
.13644 .42839 L
.14395 .41524 L
.15117 .40261 L
.15885 .38918 L
.16624 .37621 L
.1741 .36239 L
.18167 .34915 L
.18896 .3365 L
.1967 .3231 L
.20417 .31022 L
.21134 .29797 L
.21898 .2851 L
.22633 .27282 L
.23415 .25989 L
.24168 .24762 L
.24892 .23605 L
.25663 .22392 L
.26405 .21242 L
.27119 .20156 L
.27878 .1903 L
.28609 .17969 L
.29387 .16866 L
.30136 .1583 L
.30856 .14866 L
.31622 .13869 L
.3236 .12938 L
.33144 .1198 L
.339 .11096 L
.34627 .10277 L
.354 .0944 L
.36145 .08667 L
.36861 .07962 L
.37623 .07249 L
.38357 .06597 L
.39137 .05942 L
Mistroke
.39888 .05355 L
.40611 .04827 L
.4138 .04306 L
.4212 .03843 L
.42907 .03396 L
.43665 .0301 L
.44395 .02678 L
.45171 .02367 L
.45918 .02112 L
.46637 .01907 L
.47401 .01732 L
.48138 .01605 L
.4854 .01553 L
.48724 .01534 L
.4892 .01516 L
.491 .01503 L
.49297 .0149 L
.49477 .01482 L
.49646 .01476 L
.49735 .01474 L
.49785 .01473 L
.49832 .01473 L
.49858 .01472 L
.49882 .01472 L
.49904 .01472 L
.49927 .01472 L
.49939 .01472 L
.49952 .01472 L
.49975 .01472 L
.49988 .01472 L
.50002 .01472 L
.50016 .01472 L
.50028 .01472 L
.50049 .01472 L
.50072 .01472 L
.50092 .01472 L
.50114 .01472 L
.50162 .01473 L
.50207 .01473 L
.50289 .01475 L
.50378 .01477 L
.50558 .01483 L
.50756 .01493 L
.50962 .01507 L
.51155 .01523 L
.51541 .01563 L
.51892 .01609 L
.52647 .01742 L
.53373 .0191 L
.54146 .02132 L
Mistroke
.5489 .0239 L
.55605 .02678 L
.56367 .03025 L
.571 .034 L
.57879 .03842 L
.5863 .04312 L
.59352 .04801 L
.60121 .05361 L
.60861 .0594 L
.61647 .066 L
.62404 .07273 L
.63133 .07957 L
.63908 .08721 L
.64655 .09499 L
.65373 .10277 L
.66137 .11139 L
.66873 .12 L
.67655 .12957 L
.68408 .13909 L
.69133 .14851 L
.69904 .15884 L
.70646 .16913 L
.7136 .17926 L
.7212 .19028 L
.72852 .20112 L
.7363 .21295 L
.74379 .22457 L
.75099 .23592 L
.75866 .24818 L
.76605 .26022 L
.77389 .2732 L
.78145 .28582 L
.78872 .29808 L
.79646 .3113 L
.80391 .32416 L
.81107 .33656 L
.8187 .3498 L
.82604 .36264 L
.83385 .37637 L
.84136 .38955 L
.84859 .40219 L
.85629 .41566 L
.8637 .42864 L
.87157 .44229 L
.87915 .45531 L
.88645 .46776 L
.89421 .48094 L
.90169 .4934 L
.90888 .50517 L
.91653 .51751 L
Mistroke
.9239 .52926 L
.93173 .5414 L
.93927 .55274 L
.94653 .56333 L
.95425 .57425 L
.96168 .58442 L
.96883 .59389 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[545]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00>?ooool3o`0000Cooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool3o`0001_ooooo0ol0000Jooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`?o00006?ooool2o`0001[ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0000Koooo
o`?o00003_ooool003Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Hoooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Iooooo`05o`000?oooooo
ooooooooool000006_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00005_ooool01?l0003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Iooooo`05o`000?ooooooooooooooool000003Oooool0037ooooo1Ol0
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004?ooool5o`0000Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`Go00001Oooool00ol0003ooooo
ooooo`0Aooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo
00Co0000oooooooooooo00006oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02oooool003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0;ooooo`00>Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
01[ooooo00?o0000ooooooooool01Oooool4o`0001[ooooo1?l0000Jooooo`05o`000?oooooooooo
ooooool000001oooool4o`0001Oooooo00Co0000oooooooooooo00006Oooool01Ol0003ooooooooo
oooooooo000000Oooooo1?l0000Jooooo`Co00003_ooool003Sooooo0_l00004ooooo`04o`000?oo
ooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool06?ooool01?l0003oooooooooool0000Iooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo000iooooo`03o`000?oooooo
oooo00?ooooo0_l0000Gooooo`Go00001oooool5o`0001Wooooo1Ol0000Jooooo`?o00002?ooool5
o`0001Oooooo0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol0000=ooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`007_oooooho`0000[ooooo000Goooo
o`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002_ooool0
01Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`1dooooo`[o0000:_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo00Sooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo0_l0001`ooooo`Oo00001_ooool7
o`0002Gooooo00?o0000ooooooooool0B?ooool2o`0000[ooooo000Fooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0K?ooool3o`0001Cooooo0_l0000Sooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`1Zooooo`Co00005Oooool5o`00023ooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`08ooooo`005oooool2o`0000Gooooo0_l0001Yooooo`;o00007_ooool2o`00
01kooooo00?o0000ooooooooool0B?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo06Ko
oooo0_l0000Rooooo`;o00007?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo06Cooooo0ol0000Tooooo`?o00006_ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo06?ooooo00Co
0000ooooool0003o00009?ooool2o`000003ooooool0003ooooo01Sooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`08ooooo`007_ooool2o`0006?ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`1Pooooo`;o0000;_ooool2o`0001Kooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo05gooooo0_l0000cooooo`;o00005?ooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000G_ooool2o`0003?ooooo
0ol0000Cooooo`03o`000?oooooooooo04Sooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool0FOooool2o`0003cooooo0_l0000?oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02?ooool001kooooo0_l0001Iooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`18ooooo`;o
00002_ooool001kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`08ooooo`002ooo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0E_oo
ool2o`0004;ooooo0_l0000<ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02?oo
ool000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0EOooool3o`0004;ooooo0ol0000;ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00002oooool00ol0003ooooo
ooooo`02ooooo`;o0000EOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0B?ooool2o`0000[ooooo000:ooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Sooooo
000:ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02?ooool000_ooooo0_l0
0008ooooo`Go00001?ooool2o`0005;ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04Sooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0001Boooo
o`;o00001?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo04kooooo0_l0001Booooo`;o00001?ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`;o0000Coooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0B?ooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool0E?ooool01Ol0003ooooooooooooooooo000004_ooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`1Fooooo`04o`000?ooooooooooo`0004_ooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo000004_ooooo00?o
0000ooooooooool02?ooool001kooooo0_l0001;ooooo`03o`000?oooooooooo05[ooooo0_l0001:
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Mooooo`;o0000
B_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0004Oooooo0_l0001Pooooo`?o0000B?oo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0001Pooooo`Co0000B?ooool0
0ol0003oooooooooo`08ooooo`005_ooool3o`0000Gooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`1Oooooo`05o`000?ooooooooooooooool00000Aoooool00ol0003oooooooooo`08
ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0Goooool01Ol0003ooooooooooooooooo000004Oooooo00?o0000ooooooooool02?ooool0
01Oooooo00?o0000ooooooooool01?ooool2o`0004Kooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo0_l0000:ooooo`005oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool001Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00Sooooo
000Fooooo`;o00001_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Sooooo000G
ooooo`03o`000?oooooooooo00Cooooo0_l00013ooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`11ooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0001Wooooo`03o`00
0?oooooooooo00Kooooo0_l00011ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o0000@?oo
ool2o`0006Oooooo00?o0000ooooooooool01_ooool2o`00043ooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`1Xooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`08ooooo`007_ooool2o`0003gooooo00?o0000ooooooooool0JOooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03_ooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1[oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08oooo
o`007_ooool2o`0003_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03Wooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00Sooooo000:ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooo
oooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03Oooooo0ol0
001^ooooo`03o`000?oooooooooo00gooooo0ol0000iooooo`03o`000?oooooooooo00Sooooo000;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool2o`0003Sooooo0_l0001_
ooooo`03o`000?oooooooooo00kooooo0_l0000hooooo`;o00002_ooool000_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool02?ooool000_ooooo00?o0000ooooooooool01oooool4o`0000Gooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`08ooooo`002_ooool2o`0000Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oo
oooooooo00Oooooo1Ol00004ooooo`;o0000=_ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0=?ooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00So
oooo000Nooooo`;o0000=?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0<_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1d
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo07Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o
0000<?ooool2o`0007Oooooo00?o0000ooooooooool05Oooool2o`00037ooooo0_l0000:ooooo`00
7_ooool00ol0003oooooooooo`0_ooooo`;o0000Moooool00ol0003oooooooooo`0Eooooo`;o0000
<_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02?ooool0
01kooooo0_l0000_ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0]ooooo`;o00002_ooool001Gooooo1Ol00004ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo000Gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`08ooooo`006?ooool00ol0003ooooooooo
o`03ooooo`;o0000;Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0:oooool2o`0000[ooooo000Eooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo000F
ooooo`?o00001Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Sooooo000Noooo
o`;o0000:oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0:Oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0001nooooo`03
o`000?oooooooooo01gooooo0_l0000Zooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo02Sooooo0_l0001nooooo`03o`000?oooooooooo01gooooo0_l0000Zooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02?oo
ool001kooooo0_l0000Xooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Vooooo`;o00002_ooool001kooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00So
oooo000Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool001kooooo0_l0
000Vooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Tooooo`;o00002_ooool001kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo087ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo000Nooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool001kooooo0_l0000Sooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Qooooo`;o0000
2_ooool000Wooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool08?ooool2o`0008Kooooo
00?o0000ooooooooool09?ooool2o`0002?ooooo00?o0000ooooooooool02?ooool000_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo0_l0
0026ooooo`03o`000?oooooooooo02Cooooo0ol0000Rooooo`03o`000?oooooooooo00Sooooo000<
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool2o`00027ooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01oooooo0_l0000:
ooooo`002Oooool01Ol0003ooooooooooooooooo000000Oooooo1?l00005ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`26
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08
ooooo`002_ooool3o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0Q_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02?ooool001kooooo0_l0000Pooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Nooooo`;o00002_ooool001kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo08Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Sooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0R?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool0
01kooooo0_l0000Mooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Kooooo`;o00002_ooool001kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`2:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo08[ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo01Wooooo0_l0002=ooooo`03o`000?oooooooooo02cooooo0_l0
000Kooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00006_ooool2o`0008gooooo00?o0000
ooooooooool0;?ooool2o`0001[ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo08cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0SOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2>ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`007_oo
ool2o`0001Sooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01Kooooo0_l0000:ooooo`005_ooool3o`0000Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`2?ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`08ooooo`005Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`08ooooo`006Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool001Oooooo0_l00005ooooo`;o
00005Oooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool05?ooool2o`0000[ooooo000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`08ooooo`005Oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`005_ooool3o`0000Gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0001;ooooo0_l0002E
ooooo`03o`000?oooooooooo03?ooooo0_l0000Cooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool04Oooool2o`0009Gooooo00?o0000ooooooooool0<oooool2o`0001Cooooo00?o0000oooo
ooooool02?ooool001kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2Dooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00004Ooo
ool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03ooo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0U_ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool0
01kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000oo
oooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00go
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo09Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0VOooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0000_ooooo0_l0002Loooo
o`03o`000?oooooooooo03_ooooo0_l0000;ooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool02_ooool2o`0009cooooo00?o0000ooooooooool0>oooool2o`0000cooooo00?o0000oooooooo
ool02?ooool000[ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02?ooool000Wooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo09gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo000=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool2o`0000Wooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00Oooooo0_l0000:ooooo`002oooool2o`0000cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000=ooooo`03o`000?oooooo
oooo00Gooooo1?l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0W_ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool0
00Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002_ooool3o`0000Sooooo1Ol00004oooo
o`;o00001_ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool01?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0X?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool00_ooool3o`000:?ooooo00?o0000ooooooooool0
@_ooool2o`0000Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool00_oo
ool2o`000:Cooooo00?o0000ooooooooool0@_ooool2o`0000Gooooo00?o0000ooooooooool02?oo
ool001kooooo0_l0002Yooooo`03o`000?oooooooooo04Sooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002_ooool001kooooon?l0000:oooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00<?ooool3o`0008[ooooo00?o0000
ooooooooool0:oooool3o`0001Gooooo00?o0000ooooooooool06_ooool0037ooooo00?o0000oooo
ooooool0R?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool06Oooool002_ooooo0ol00003ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o
00000oooool4o`000003ooooool0003o000000?o00001oooool3o`0000Cooooo1?l00003ooooo`;o
00000_ooool6o`0000Kooooo1?l00002ooooo`Go000000?oooooo`000?l000000ol000000ooooooo
0000o`000003o`0000;ooooo0ol00002ooooo`?o00001?ooool3o`0000;ooooo0ol000001?oooooo
0000o`000?ooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000000oooool4o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1Ol00002oooo
o`?o00000_ooool3o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000;ooooo2_l00005
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo
000Zooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool5o`0000;ooooo
00?o0000ooooooooool00_ooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00005oooo
o`Go00002?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo0000ooooool000000_ooool3
o`0000?ooooo00?o0000ooooool000000_ooool5o`0000?ooooo00Co0000oooooooooooooooo1Ol0
0002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000;ooooo0ol00005ooooo`03o`000?oooooooooo01Sooooo000Zoooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`?o00000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?oo
ooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000
1Oooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool06?ooool002[o
oooo00Ko0000ooooooooooooooooo`000?ooool4o`0000;ooooo1?l00002ooooo`?o00001?ooool3
o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_oo
ool2o`0000?ooooo1?l00003ooooo`?o00002Oooool01Ol0003oooooooooool0003ooooo00?o0000
1?ooool4o`0000;ooooo1?l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo
0ol00002ooooo`Co00000oooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo
1_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0000;ooooo1?l00003ooooo`Wo00000oooool3o`0000?ooooo
1?l00004ooooo`03o`000?oooooooooo01Sooooo000Zooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Iooooo`00:oooool3o`0000Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0=ooooo`?o00002Oooool4o`0000Wooooo00?o0000oooooooo
ool00_ooool2o`0000[ooooo1?l00004ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o
0000;_ooool00ol0003oooooooooo`0Hooooo`?o00005_ooool00ol0003oooooooooo`02ooooo`;o
00002oooool00ol0003oooooooooo`0Jooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14.1139, -0.402008, \
0.0698899, 0.0251994}},
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.695755 0.0580362 0.0147151 0.070765 [
[.11539 -0.0125 -9 -9 ]
[.11539 -0.0125 9 0 ]
[.26048 -0.0125 -12 -9 ]
[.26048 -0.0125 12 0 ]
[.40557 -0.0125 -6 -9 ]
[.40557 -0.0125 6 0 ]
[.55066 -0.0125 -12 -9 ]
[.55066 -0.0125 12 0 ]
[.69576 -0.0125 -3 -9 ]
[.69576 -0.0125 3 0 ]
[.84085 -0.0125 -9 -9 ]
[.84085 -0.0125 9 0 ]
[.98594 -0.0125 -3 -9 ]
[.98594 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15625 -6 -4.5 ]
[-0.0125 .15625 0 4.5 ]
[-0.0125 .29778 -6 -4.5 ]
[-0.0125 .29778 0 4.5 ]
[-0.0125 .43931 -6 -4.5 ]
[-0.0125 .43931 0 4.5 ]
[-0.0125 .58084 -6 -4.5 ]
[-0.0125 .58084 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -66 0 ]
[.5 .63053 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11539 0 m
.11539 .00625 L
s
[(-10)] .11539 -0.0125 0 1 Mshowa
.26048 0 m
.26048 .00625 L
s
[(-7.5)] .26048 -0.0125 0 1 Mshowa
.40557 0 m
.40557 .00625 L
s
[(-5)] .40557 -0.0125 0 1 Mshowa
.55066 0 m
.55066 .00625 L
s
[(-2.5)] .55066 -0.0125 0 1 Mshowa
.69576 0 m
.69576 .00625 L
s
[(0)] .69576 -0.0125 0 1 Mshowa
.84085 0 m
.84085 .00625 L
s
[(2.5)] .84085 -0.0125 0 1 Mshowa
.98594 0 m
.98594 .00625 L
s
[(5)] .98594 -0.0125 0 1 Mshowa
.125 Mabswid
.14441 0 m
.14441 .00375 L
s
.17343 0 m
.17343 .00375 L
s
.20245 0 m
.20245 .00375 L
s
.23147 0 m
.23147 .00375 L
s
.2895 0 m
.2895 .00375 L
s
.31852 0 m
.31852 .00375 L
s
.34754 0 m
.34754 .00375 L
s
.37656 0 m
.37656 .00375 L
s
.43459 0 m
.43459 .00375 L
s
.46361 0 m
.46361 .00375 L
s
.49263 0 m
.49263 .00375 L
s
.52165 0 m
.52165 .00375 L
s
.57968 0 m
.57968 .00375 L
s
.6087 0 m
.6087 .00375 L
s
.63772 0 m
.63772 .00375 L
s
.66674 0 m
.66674 .00375 L
s
.72477 0 m
.72477 .00375 L
s
.75379 0 m
.75379 .00375 L
s
.78281 0 m
.78281 .00375 L
s
.81183 0 m
.81183 .00375 L
s
.86986 0 m
.86986 .00375 L
s
.89888 0 m
.89888 .00375 L
s
.9279 0 m
.9279 .00375 L
s
.95692 0 m
.95692 .00375 L
s
.08637 0 m
.08637 .00375 L
s
.05736 0 m
.05736 .00375 L
s
.02834 0 m
.02834 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15625 m
.00625 .15625 L
s
[(2)] -0.0125 .15625 1 0 Mshowa
0 .29778 m
.00625 .29778 L
s
[(4)] -0.0125 .29778 1 0 Mshowa
0 .43931 m
.00625 .43931 L
s
[(6)] -0.0125 .43931 1 0 Mshowa
0 .58084 m
.00625 .58084 L
s
[(8)] -0.0125 .58084 1 0 Mshowa
.125 Mabswid
0 .0501 m
.00375 .0501 L
s
0 .08548 m
.00375 .08548 L
s
0 .12086 m
.00375 .12086 L
s
0 .19163 m
.00375 .19163 L
s
0 .22701 m
.00375 .22701 L
s
0 .26239 m
.00375 .26239 L
s
0 .33316 m
.00375 .33316 L
s
0 .36854 m
.00375 .36854 L
s
0 .40392 m
.00375 .40392 L
s
0 .47469 m
.00375 .47469 L
s
0 .51007 m
.00375 .51007 L
s
0 .54545 m
.00375 .54545 L
s
0 .61622 m
.00375 .61622 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11539 .61178 m
.11539 .61803 L
s
.26048 .61178 m
.26048 .61803 L
s
.40557 .61178 m
.40557 .61803 L
s
.55066 .61178 m
.55066 .61803 L
s
.69576 .61178 m
.69576 .61803 L
s
.84085 .61178 m
.84085 .61803 L
s
.98594 .61178 m
.98594 .61803 L
s
.125 Mabswid
.14441 .61428 m
.14441 .61803 L
s
.17343 .61428 m
.17343 .61803 L
s
.20245 .61428 m
.20245 .61803 L
s
.23147 .61428 m
.23147 .61803 L
s
.2895 .61428 m
.2895 .61803 L
s
.31852 .61428 m
.31852 .61803 L
s
.34754 .61428 m
.34754 .61803 L
s
.37656 .61428 m
.37656 .61803 L
s
.43459 .61428 m
.43459 .61803 L
s
.46361 .61428 m
.46361 .61803 L
s
.49263 .61428 m
.49263 .61803 L
s
.52165 .61428 m
.52165 .61803 L
s
.57968 .61428 m
.57968 .61803 L
s
.6087 .61428 m
.6087 .61803 L
s
.63772 .61428 m
.63772 .61803 L
s
.66674 .61428 m
.66674 .61803 L
s
.72477 .61428 m
.72477 .61803 L
s
.75379 .61428 m
.75379 .61803 L
s
.78281 .61428 m
.78281 .61803 L
s
.81183 .61428 m
.81183 .61803 L
s
.86986 .61428 m
.86986 .61803 L
s
.89888 .61428 m
.89888 .61803 L
s
.9279 .61428 m
.9279 .61803 L
s
.95692 .61428 m
.95692 .61803 L
s
.08637 .61428 m
.08637 .61803 L
s
.05736 .61428 m
.05736 .61803 L
s
.02834 .61428 m
.02834 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15625 m
1 .15625 L
s
.99375 .29778 m
1 .29778 L
s
.99375 .43931 m
1 .43931 L
s
.99375 .58084 m
1 .58084 L
s
.125 Mabswid
.99625 .0501 m
1 .0501 L
s
.99625 .08548 m
1 .08548 L
s
.99625 .12086 m
1 .12086 L
s
.99625 .19163 m
1 .19163 L
s
.99625 .22701 m
1 .22701 L
s
.99625 .26239 m
1 .26239 L
s
.99625 .33316 m
1 .33316 L
s
.99625 .36854 m
1 .36854 L
s
.99625 .40392 m
1 .40392 L
s
.99625 .47469 m
1 .47469 L
s
.99625 .51007 m
1 .51007 L
s
.99625 .54545 m
1 .54545 L
s
.99625 .61622 m
1 .61622 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.69576 0 m
.69576 .61803 L
s
[(Interference Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .051 m
.03111 .03717 L
.03491 .02915 L
.03692 .02525 L
.03907 .02155 L
.0411 .01866 L
.04294 .01664 L
.04383 .01591 L
.0443 .01559 L
.0448 .0153 L
.04523 .0151 L
.04571 .01492 L
.04592 .01486 L
.04614 .01481 L
.04636 .01477 L
.04655 .01474 L
.04679 .01472 L
.04702 .01472 L
.04723 .01472 L
.04745 .01474 L
.04769 .01477 L
.04782 .01479 L
.04795 .01482 L
.04841 .01496 L
.04884 .01513 L
.04931 .01537 L
.05014 .01595 L
.05119 .01694 L
.05219 .01815 L
.05406 .02114 L
.05588 .02497 L
.05782 .02998 L
.0613 .04127 L
.06843 .07147 L
.07603 .10783 L
.07952 .12335 L
.08334 .13787 L
.08517 .14355 L
.08713 .14861 L
.08821 .1509 L
.08919 .15264 L
.09013 .15399 L
.09112 .15509 L
.09201 .15582 L
.09226 .15598 L
.09252 .15612 L
.09275 .15622 L
.093 .15631 L
.09324 .15637 L
.09347 .15642 L
Mistroke
.09368 .15644 L
.09391 .15644 L
.09414 .15643 L
.09435 .1564 L
.09454 .15636 L
.09474 .1563 L
.09499 .15621 L
.09522 .1561 L
.09574 .15579 L
.09625 .15539 L
.09679 .15486 L
.09777 .15362 L
.09867 .15219 L
.10055 .14827 L
.10229 .14358 L
.10621 .12956 L
.11364 .09369 L
.12079 .05619 L
.12476 .03804 L
.12649 .03135 L
.12839 .02515 L
.13024 .02038 L
.13113 .01858 L
.13196 .01718 L
.13242 .01654 L
.13291 .01596 L
.13332 .01556 L
.13378 .0152 L
.13401 .01506 L
.13427 .01493 L
.13441 .01487 L
.13453 .01483 L
.13466 .01479 L
.13478 .01476 L
.13501 .01473 L
.13526 .01472 L
.13548 .01473 L
.13571 .01478 L
.13593 .01484 L
.13616 .01493 L
.13641 .01506 L
.13664 .0152 L
.13748 .01596 L
.13796 .01655 L
.1384 .01718 L
.13939 .01896 L
.14116 .02336 L
.14284 .02893 L
.14662 .04618 L
.1501 .0674 L
Mistroke
.15754 .12458 L
.1647 .18391 L
.16868 .21339 L
.17232 .23553 L
.17411 .24427 L
.17607 .25187 L
.17697 .25462 L
.17793 .25706 L
.17883 .25886 L
.17965 .26007 L
.18009 .26055 L
.18057 .26094 L
.18081 .26108 L
.18095 .26114 L
.18107 .26119 L
.18132 .26125 L
.18154 .26128 L
.18175 .26128 L
.18198 .26124 L
.18217 .26119 L
.18238 .2611 L
.1826 .26097 L
.18285 .2608 L
.18329 .2604 L
.18376 .25982 L
.18429 .25903 L
.18534 .25691 L
.18631 .25433 L
.18722 .25141 L
.18921 .24329 L
.19109 .23359 L
.1946 .21072 L
.20188 .14964 L
.20961 .08064 L
.21346 .05163 L
.21534 .03989 L
.21706 .0309 L
.21884 .02355 L
.21965 .02088 L
.22052 .01854 L
.221 .01748 L
.22144 .01666 L
.22188 .01597 L
.22229 .01547 L
.22252 .01524 L
.22277 .01504 L
.22302 .01489 L
.22316 .01482 L
.22329 .01478 L
.22353 .01473 L
Mistroke
.22374 .01472 L
.22399 .01475 L
.22423 .01483 L
.22444 .01494 L
.22468 .01509 L
.2251 .01549 L
.2256 .01614 L
.22606 .01691 L
.22705 .01915 L
.228 .02201 L
.22967 .02874 L
.23148 .03853 L
.2352 .06596 L
.23916 .10465 L
.24702 .2002 L
.25459 .29441 L
.25806 .33098 L
.26003 .34856 L
.26187 .3625 L
.26369 .37365 L
.26462 .37829 L
.26564 .38248 L
.26619 .38438 L
.26671 .38589 L
.26719 .38708 L
.26772 .38815 L
.26819 .38888 L
.26864 .38937 L
.26888 .38957 L
.26911 .38969 L
.26936 .38978 L
.26948 .3898 L
.26962 .38981 L
.26987 .38977 L
.2701 .38968 L
.27022 .38962 L
.27035 .38953 L
.27061 .38931 L
.27085 .38905 L
.2711 .38872 L
.27156 .38797 L
.27248 .38584 L
.27332 .3832 L
.27429 .37934 L
.27535 .37414 L
.27728 .36215 L
.281 .33047 L
.28497 .28643 L
.29283 .18179 L
.29678 .12913 L
Mistroke
.30041 .08593 L
.30396 .05148 L
.30575 .03793 L
.30675 .03156 L
.30771 .02642 L
.30863 .02229 L
.30964 .01879 L
.31008 .01758 L
.31055 .01653 L
.31095 .01582 L
.3114 .01524 L
.31165 .01501 L
.31177 .01491 L
.31191 .01483 L
.31215 .01474 L
.31238 .01472 L
.31252 .01473 L
.31265 .01476 L
.31289 .01486 L
.31303 .01495 L
.31315 .01505 L
.31344 .01534 L
.31388 .01597 L
.31437 .01691 L
.31535 .01962 L
.31634 .02342 L
.31728 .02801 L
.31903 .03916 L
.32092 .05477 L
.32298 .07576 L
.33068 .18381 L
.33809 .31028 L
.34522 .42189 L
.34887 .46579 L
.35092 .48487 L
.35183 .49188 L
.35281 .49835 L
.35378 .50367 L
.35466 .50754 L
.35508 .50907 L
.35554 .51048 L
.35597 .51156 L
.35638 .51237 L
.35662 .51276 L
.35685 .51305 L
.3571 .51329 L
.35723 .5134 L
.35736 .51347 L
.35749 .51353 L
.35762 .51356 L
Mistroke
.35787 .51357 L
.35801 .51353 L
.35815 .51348 L
.35828 .51341 L
.35841 .51331 L
.35864 .51309 L
.35889 .51278 L
.35939 .51192 L
.35985 .51083 L
.36029 .50957 L
.36123 .50604 L
.36226 .50097 L
.36413 .48845 L
.36596 .47242 L
.36764 .45442 L
.37506 .34625 L
.3822 .21967 L
.38616 .15194 L
.3898 .09764 L
.39336 .05555 L
.39515 .03946 L
.39616 .03208 L
.39711 .02627 L
.39804 .02169 L
.39853 .01973 L
.39905 .01801 L
.39949 .01683 L
.39972 .01632 L
.39997 .01584 L
.4002 .01548 L
.40041 .01521 L
.40062 .01499 L
.40082 .01485 L
.40107 .01474 L
.40129 .01472 L
.40142 .01473 L
.40155 .01478 L
.4018 .01492 L
.40203 .01513 L
.40228 .01543 L
.40271 .01616 L
.40322 .01735 L
.4037 .01878 L
.40478 .02317 L
.40573 .02832 L
.40676 .03527 L
.40863 .0514 L
.41214 .09292 L
.41589 .15117 L
.41986 .22446 L
Mistroke
.427 .36805 L
.43098 .44362 L
.43461 .50359 L
.43641 .52862 L
.43837 .55187 L
.4402 .5694 L
.44194 .58185 L
.44287 .58686 L
.44336 .589 L
.44388 .59089 L
.44432 .59218 L
.4448 .59328 L
.44501 .59366 L
.44524 .59399 L
.44545 .59424 L
.44565 .5944 L
.44589 .59453 L
.44602 .59456 L
.44616 .59457 L
.4464 .59453 L
.44662 .5944 L
.44675 .5943 L
.44689 .59416 L
.44713 .59385 L
.4474 .59342 L
.44768 .59284 L
.44817 .59158 L
.44868 .58987 L
.44961 .58583 L
.45062 .58008 L
.45155 .57354 L
.45364 .55451 L
.45745 .50623 L
.46489 .3736 L
.47205 .22763 L
.47603 .15255 L
.47966 .09436 L
.48146 .07057 L
.48342 .04901 L
.48528 .03323 L
.48617 .02728 L
.487 .0228 L
.48796 .0188 L
.48846 .01724 L
.48872 .01659 L
.489 .016 L
.48924 .01557 L
.48946 .01525 L
.48968 .01501 L
.48989 .01485 L
Mistroke
.49014 .01474 L
.49037 .01472 L
.49061 .01478 L
.49074 .01485 L
.49088 .01495 L
.4911 .01517 L
.49134 .01548 L
.49175 .01624 L
.4922 .01734 L
.49269 .01889 L
.49358 .02254 L
.4944 .02694 L
.49639 .04155 L
.49827 .06022 L
.50178 .10666 L
.50905 .23839 L
.51679 .39771 L
.52064 .47008 L
.52424 .52702 L
.5277 .56842 L
.52869 .57756 L
.52964 .585 L
.53055 .59102 L
.53141 .59561 L
.53187 .59763 L
.53236 .59947 L
.53278 .60073 L
.53323 .60183 L
.53347 .60228 L
.53372 .60268 L
.53386 .60286 L
.53399 .60299 L
.53424 .60319 L
.53447 .6033 L
.53471 .60332 L
.53495 .60326 L
.53516 .60313 L
.53536 .60295 L
.53558 .60269 L
.53597 .60206 L
.53643 .60101 L
.53685 .59978 L
.53777 .59622 L
.53864 .59171 L
.54045 .57896 L
.54238 .56053 L
.54586 .51595 L
.55372 .37519 L
.56129 .22075 L
.56476 .15579 L
Mistroke
.56857 .09511 L
.57039 .07129 L
.57234 .05002 L
.57341 .04031 L
.5744 .03276 L
.57533 .02679 L
.57632 .02173 L
.57721 .01836 L
.57772 .01692 L
.57819 .0159 L
.5784 .01555 L
.57863 .01524 L
.57882 .01504 L
.57903 .01487 L
.57925 .01476 L
.57949 .01472 L
.57972 .01475 L
.57992 .01485 L
.58017 .01503 L
.58029 .01516 L
.58043 .01533 L
.58089 .01608 L
.58115 .01664 L
.58143 .01734 L
.58194 .01889 L
.58294 .02294 L
.58385 .0278 L
.58571 .04111 L
.58744 .05728 L
.59136 .106 L
.59876 .23044 L
.60663 .37478 L
.61058 .43791 L
.61421 .48477 L
.61605 .50331 L
.61776 .51709 L
.61955 .52764 L
.62049 .53159 L
.62102 .53331 L
.62151 .53455 L
.62194 .53541 L
.62219 .53579 L
.62242 .53607 L
.62266 .53629 L
.62288 .53643 L
.62313 .5365 L
.62325 .53651 L
.62338 .53649 L
.62361 .53642 L
.62382 .53629 L
Mistroke
.62406 .53607 L
.62428 .5358 L
.62468 .53514 L
.62512 .5342 L
.62559 .5329 L
.62611 .53114 L
.62716 .52654 L
.62904 .51488 L
.63097 .49863 L
.63273 .48024 L
.63668 .42816 L
.6442 .30168 L
.65144 .17372 L
.65509 .11715 L
.65704 .09105 L
.65914 .06664 L
.66113 .04746 L
.66296 .03357 L
.66471 .02379 L
.66559 .0202 L
.66655 .0173 L
.66703 .01626 L
.66728 .01582 L
.66755 .01543 L
.66778 .01516 L
.6679 .01505 L
.66804 .01494 L
.66827 .0148 L
.66849 .01473 L
.66871 .01472 L
.66896 .01477 L
.66919 .01488 L
.66941 .01504 L
.66962 .01525 L
.66982 .01548 L
.67025 .01616 L
.67076 .01723 L
.67123 .01847 L
.67229 .02218 L
.67322 .02646 L
.67421 .03198 L
.67792 .0613 L
.68139 .09907 L
.68874 .20004 L
.69656 .31072 L
.70047 .3566 L
.70219 .37334 L
.70409 .38915 L
.70579 .40054 L
.70761 .40977 L
Mistroke
.70861 .41345 L
.70905 .41474 L
.70953 .41593 L
.70996 .41679 L
.71041 .4175 L
.71066 .4178 L
.71089 .41802 L
.71112 .41819 L
.71134 .4183 L
.71156 .41836 L
.71179 .41837 L
.71201 .41833 L
.71222 .41825 L
.71245 .41811 L
.71271 .41789 L
.71295 .41761 L
.71318 .41731 L
.71367 .41646 L
.71412 .41548 L
.71512 .41256 L
.71599 .40927 L
.71692 .40491 L
.71861 .39497 L
.72239 .36402 L
.72637 .32054 L
.73356 .22561 L
.74121 .12357 L
.74474 .08382 L
.74858 .04953 L
.75067 .03543 L
.75159 .03035 L
.7526 .02557 L
.75349 .02208 L
.75445 .01908 L
.75498 .01776 L
.75546 .01675 L
.75596 .01593 L
.75641 .01537 L
.75663 .01516 L
.75687 .01498 L
.7571 .01485 L
.75731 .01477 L
.75753 .01472 L
.75777 .01472 L
.7579 .01474 L
.75803 .01478 L
.75827 .01488 L
.75849 .01501 L
.75873 .0152 L
.75917 .01568 L
Mistroke
.7596 .01629 L
.75999 .01699 L
.7609 .01906 L
.76189 .02205 L
.76391 .03035 L
.76581 .04086 L
.76756 .0525 L
.7715 .0845 L
.77899 .15767 L
.78619 .22556 L
.78989 .25334 L
.79195 .26564 L
.79385 .27462 L
.79578 .28148 L
.7968 .2841 L
.79732 .28517 L
.79788 .2861 L
.79837 .28674 L
.79882 .28718 L
.79903 .28734 L
.79927 .28748 L
.79949 .28757 L
.79969 .28763 L
.79982 .28765 L
.79995 .28766 L
.8002 .28765 L
.80044 .28759 L
.80066 .28751 L
.8009 .28738 L
.80116 .28719 L
.80169 .28666 L
.80216 .28602 L
.80268 .28515 L
.80362 .28312 L
.80538 .27775 L
.80743 .26904 L
.80933 .25882 L
.81676 .20318 L
.8239 .13778 L
.82787 .10226 L
.8315 .07291 L
.8353 .04753 L
.83882 .02996 L
.84055 .0237 L
.84144 .02113 L
.8424 .01883 L
.84295 .01774 L
.84346 .01689 L
.84393 .01622 L
.84445 .01562 L
Mistroke
.84492 .01522 L
.84515 .01507 L
.84536 .01495 L
.8456 .01484 L
.84582 .01478 L
.84606 .01473 L
.84619 .01472 L
.84632 .01472 L
.84654 .01474 L
.84677 .01478 L
.84697 .01484 L
.84719 .01494 L
.84743 .01506 L
.84768 .01523 L
.84813 .01562 L
.84903 .01669 L
.84984 .01801 L
.85184 .02261 L
.85373 .02858 L
.8575 .04446 L
.86099 .06293 L
.86843 .10754 L
.87558 .14644 L
.87924 .16131 L
.8813 .16759 L
.88222 .16985 L
.88319 .1719 L
.88417 .17356 L
.88505 .1747 L
.88548 .17514 L
.88594 .17553 L
.88638 .17582 L
.88678 .17602 L
.887 .17611 L
.88725 .17618 L
.88748 .17622 L
.88769 .17624 L
.88793 .17624 L
.88807 .17623 L
.8882 .17621 L
.88843 .17616 L
.88868 .17608 L
.88892 .17599 L
.88918 .17585 L
.88964 .17555 L
.89019 .17506 L
.89069 .17452 L
.89159 .17329 L
.89255 .17166 L
.89427 .16786 L
Mistroke
.89632 .16197 L
.89818 .15543 L
.90574 .12008 L
.91301 .08034 L
.91669 .06146 L
.92074 .04323 L
.9226 .03614 L
.92459 .02957 L
.92646 .02446 L
.92819 .02066 L
.9301 .01754 L
.93111 .01636 L
.93163 .01588 L
.93219 .01545 L
.93273 .01514 L
.93296 .01503 L
.93322 .01492 L
.93345 .01485 L
.93369 .01479 L
.93382 .01477 L
.93394 .01475 L
.93418 .01472 L
.93442 .01472 L
.93463 .01473 L
.93486 .01475 L
.93511 .0148 L
.93533 .01485 L
.93553 .01491 L
.93599 .0151 L
.93645 .01535 L
.93688 .01563 L
.93785 .01647 L
.9388 .01752 L
.93981 .01889 L
.94331 .02542 L
.94735 .03559 L
.95116 .04661 L
.95844 .06687 L
.96221 .07499 L
.9641 .07817 L
.96517 .07967 L
.96619 .08087 L
.96711 .08178 L
.96811 .08257 L
.96855 .08286 L
.96902 .08311 L
.96946 .0833 L
.96987 .08345 L
.97033 .08357 L
.97058 .08361 L
Mistroke
.9707 .08363 L
.97084 .08365 L
.97106 .08367 L
.97127 .08367 L
.97152 .08367 L
.97175 .08366 L
.97188 .08364 L
.97201 .08363 L
.97226 .08359 L
.97252 .08353 L
.97281 .08345 L
.97333 .08326 L
.97382 .08304 L
.97506 .08225 L
.97619 .08128 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[545]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<_ooool3o`0000Cooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool3o`0001_ooooo0ol0000Jooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`?o00006Oooool2o`0001[ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0000Koooo
o`?o00004oooool003?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Hoooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Iooooo`05o`000?oooooo
ooooooooool000006_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00005oooool01?l0003oooooooooool0000Jooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Iooooo`05o`000?ooooooooooooooool000004_ooool002_ooooo1Ol0
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004?ooool5o`0000Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`Go00001Oooool00ol0003ooooo
ooooo`0Aooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo
00Co0000oooooooooooo00006oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool04?ooool003?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0@ooooo`00<oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
01[ooooo00?o0000ooooooooool01Oooool4o`0001[ooooo1?l0000Jooooo`05o`000?oooooooooo
ooooool000001oooool4o`0001Sooooo00Co0000oooooooooooo00006Oooool01Ol0003ooooooooo
oooooooo000000Oooooo1?l0000Jooooo`Co00004oooool003;ooooo0_l00004ooooo`04o`000?oo
ooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool06Oooool01?l0003oooooooooool0000Iooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo000cooooo`03o`000?oooooo
oooo00?ooooo0_l0000Gooooo`Go00001oooool5o`0001Wooooo1Ol0000Jooooo`?o00002?ooool5
o`0001Sooooo0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol0000Booooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006?oooooho`00013ooooo000Aoooo
o`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00013ooooo000@oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo00kooooo000@ooooo`04o`000?ooooooooooo`0000Cooooo0_l00009
ooooo`;o00005?ooool2o`0001Cooooo0_l0000Dooooo`;o00005?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00cooooo0_l0000Dooooo`03o`000?oooooooooo01;ooooo0_l0000>
ooooo`;o00004?ooool0013ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`07
ooooo`Co00004_ooool3o`0001?ooooo0ol0000Cooooo`?o00005?ooool2o`0001Cooooo0_l0000D
ooooo`;o00005?ooool2o`0000Gooooo00?o0000ooooooooool02oooool3o`0001?ooooo0ol0000C
ooooo`?o00003_ooool00ol0003oooooooooo`0>ooooo`004?ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00004_ooool01?l0003ooooooooo
ool0000Booooo`03o`000?oooooo000001?ooooo00?o0000ooooool000004oooool00ol0003ooooo
o`00000Cooooo`03o`000?oooooo000001?ooooo00?o0000ooooool000004oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000004oooool00ol0003ooooo
o`00000Booooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool03_ooool0013ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03oooool01?l0003oooooooooool0000Booooo`03o`000?oooooo0000
01?ooooo00?o0000ooooool000004oooool00ol0003oooooo`00000Cooooo`03o`000?oooooo0000
01?ooooo00?o0000ooooool000004oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooool000004oooool00ol0003oooooo`00000Booooo`05o`000?oooooooooo
ooooool000003Oooool00ol0003oooooooooo`0>ooooo`004Oooool2o`0000Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Go0000oooo
ooooooooooooo`00000Booooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooool000004ooo
ool00ol0003oooooo`00000Cooooo`03o`000?oooooo000001?ooooo00?o0000ooooool000004ooo
ool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo0000
4Oooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool0
00004_ooool01?l0003oooooooooool0000Booooo`03o`000?oooooo000001?ooooo00?o0000oooo
ool000004oooool00ol0003oooooo`00000Cooooo`03o`000?oooooo000001?ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000004Ooo
ool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000
4Oooool01Ol0003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000Boooo
o`03o`000?oooooo000001?ooooo00Co0000oooooooooooo00004_ooool01?l0003oooooooooool0
000Booooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02_ooool01Ol0003ooooo
oooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000Aoooo
o`05o`000?ooooooooooooooool000004_ooool00ol0003oooooo`00000Cooooo`04o`000?oooooo
ooooo`0001;ooooo00Co0000oooooooooooo00004Oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`000?oooooooooo
ooooool000004_ooool01?l0003oooooooooool0000Aooooo`05o`000?ooooooooooooooool00000
4_ooool01?l0003oooooooooool0000Aooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00kooooo000Hooooo`;o00001?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>oooo
o`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooooooooooooooo0000017ooooo00Go
0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003o
oooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Sooooo0_l0000@ooooo`006?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo0000017ooooo00Go0000
ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooo
oooooooooooo0000017ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000Aoooo
o`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooooooooooooooo0000017ooooo00Go
0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool0
00004Oooool01Ol0003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000A
ooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`00
0?ooooooooooooooool000004Oooool01Ol0003ooooooooooooooooo0000017ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool0
01Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`05o`000?oooooooooo
ooooool000004Oooool01Ol0003ooooooooooooooooo0000017ooooo00Go0000oooooooooooooooo
o`00000Aooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooo
ooooo`00000Aooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooooooooooo
oooo0000017ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooo
oooooooo0000017ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool3o`0000Gooooo00?o0000ooooooooool03_ooool001Sooooo0_l0000@ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`;o00004?ooool001So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00kooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo000Hooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>oooo
o`006?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo000Hooooo`;o00004_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool2o`00013ooooo000Hooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo000Hooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo000Hooooo`03
o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00kooooo000?ooooo`Go00001?ooool00ol0003oooooooooo`0Booooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0>ooooo`004?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool000003oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0>ooooo`004Oooool00ol0003oooooooooo`04ooooo`;o00005?ooool3o`0000oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo
0_l0000@ooooo`004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool03_ooool000oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo0000
01Wooooo00?o0000ooooooooool03_ooool000oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0
000Iooooo`03o`000?oooooooooo00kooooo000@ooooo`?o00001Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00cooooo00Co0000ooooool0003o00006Oooool00ol0003ooooo
ooooo`0>ooooo`006?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo
0ol0000Jooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00kooooo000Hooooo`;o
00009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Yooooo`;o00004?ooool001Sooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0>ooooo`006?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03_ooool0
01Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00kooooo000Hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Sooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooo`00
0008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooool000002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0>ooooo`006?ooool2o`0002Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0:_ooool2o`00013ooooo000Hooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00kooooo000Hooooo`03o`000?oooooooooo02Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00kooooo000H
ooooo`03o`000?oooooooooo02Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo0_l00008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooo
oooo02Sooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00001ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
000000oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool2o`0000Oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03_ooool0
01Sooooo00?o0000ooooooooool0:Oooool2o`00013ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool2o`00
00Oooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000
ooooooooool03_ooool001Sooooo0_l0000looooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l00007oooo
o`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000]ooooo`;o00004?ooool0
01Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00001oooool00ol0
003oooooooooo`0=ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool03_ooool0
01Sooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`;o00001oooool00ol0
003oooooooooo`0=ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool03_ooool0
01Sooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`;o00001oooool00ol0
003oooooooooo`0=ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool03_ooool0
01Sooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`;o00001oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooo000002oooooo00?o0000ooooooooool03_ooool001So
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool03_ooool3o`0002oooooo00?o0000ooooooooool03_ooool0017ooooo
0ol00004ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00kooooo0_l0000`ooooo`03o`000?oooooooooo00kooooo
000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0>ooooo`003oooool5o`0000Cooooo0_l0000mooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0oooooo`;o00004?ooool000oooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo000@oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0>oooo
o`004Oooool2o`0000Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0>ooooo`00
4_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
3_ooool001Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0>ooooo`006?ooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0>ooooo`006?ooool2o`0003kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo043ooooo0_l0000@ooooo`006?ooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;
ooooo`;o00001Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo000Hoooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool2o`0000Cooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0mooooo`05
o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00_ooooo0_l00004ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool03_ooool001So
oooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`;o00001?ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo03kooooo00Co0000oooooooo
oooo00003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo0_l00004oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooooooo
ool0?_ooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02oooool2o`0000Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0>oooo
o`006?ooool00ol0003oooooooooo`0nooooo`04o`000?ooooooooooo`0000oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`;o00001?ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo00kooooo000Hooooo`;o0000?oooool01?l0003oooooooooool0000?oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool2o`0000Cooooo00?o0000oooo
ooooool0@Oooool2o`00013ooooo000Hooooo`03o`000?oooooooooo03kooooo00Co0000oooooooo
oooo00003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo0_l00004oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooooooo
ool0?_ooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02oooool2o`0000Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0>oooo
o`006?ooool00ol0003oooooooooo`0oooooo`;o00004?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00_ooooo0_l00004ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool03_ooool001Sooooo00?o0000ooooooooool0?oooool2o`00013ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`0oooooo`;o00004?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool03_ooool001So
oooo0_l0001Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo04;ooooo0_l0000@ooooo`006?ooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
o`000002ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool03_ooool001Sooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00Ko
0000oooooooooooo0000ooooool00015ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00?o0000AOooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`02o`0004Kooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0>ooooo`006?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00kooooo000@ooooo`?o00001Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00ko
oooo000?ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo00kooooo000?ooooo`05o`000?ooooooooooooooool000001?ooool2o`0005?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Oo
oooo0_l0000@ooooo`003oooool4o`0000Gooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0>ooooo`003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool03_ooool0013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1C
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo00kooooo000Aooooo`;o00001Oooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool03_ooool001Sooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000oo
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003ooooo
ooooo`1Cooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`05
o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00kooooo000Hooooo`03o`000?oooooooooo05?ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo0_l0001Dooooo`05o`000?oooooooooo
ooooool000004?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003ooo
ool00ol0003oooooooooo`17ooooo`;o00004?ooool001Sooooo00?o0000ooooooooool0E?ooool0
1?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00Go0000oooooooooooooooo
o`00000?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o
0000ooooooooool0E?ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool03_ooool001Sooooo00?o0000ooooooooool0E?ooool01?l0003oooooooooool0000@ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0E?ooool01?l0003o
ooooooooool0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool0
01Sooooo00?o0000ooooooooool0E?ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool03_ooool001Sooooo00?o0000ooooooooool0E?ooool00ol0003oooooo`00000Aoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0EOooool2o`00
017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool2o`0005Kooooo0_l0000Aoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooool000004?ooool00ol0003oooooooooo`17oooo
o`;o00004?ooool001Sooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooool000004?ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3oooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
3_ooool001Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooo0000013ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool000004?ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03oooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0JOooool01Ol0003o
oooooooooooooooo0000013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>oooo
o`006?ooool00ol0003oooooooooo`1Yooooo`05o`000?ooooooooooooooool000004?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0>ooooo`006?ooool2o`0006[ooooo00Go0000ooooooooooooooooo`00000@oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`17oooo
o`;o00004?ooool001Sooooo00?o0000ooooooooool0JOooool01Ol0003ooooooooooooooooo0000
013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0JOooool01Ol0003o
oooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0JOooool01Ol0
003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0JOooool0
1Ol0003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Sooooo00?o0000ooooooooool0J_oo
ool01?l0003oooooooooool0000Aooooo`05o`000?ooooooooooooooool000009Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo06[ooooo
00Co0000oooooooooooo00004Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0>ooooo`004?ooool3o`0000Gooooo00?o0000oooooooo
ool0J_ooool01?l0003oooooooooool0000Aooooo`04o`000?ooooooooooo`0002Kooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`003oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0J_ooool01?l0003oooooooooool0000Booooo`03o`000?oo
oooo000002Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`003oooool0
1Ol0003ooooooooooooooooo000000Cooooo0_l0001[ooooo`03o`000?oooooo000001?ooooo00?o
0000ooooool000009_ooool00ol0003oooooooooo`17ooooo`;o00004?ooool0013ooooo0ol00005
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooool000004oooool00ol0003oooooo`00000V
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool000oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooool000004oooool0
0ol0003oooooo`00000Vooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool0
00oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06_ooooo0_l0000C
ooooo`03o`000?oooooo000002Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>
ooooo`004?ooool3o`0000Gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooo000002Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>oooo
o`006?ooool00ol0003oooooooooo`20ooooo`?o00009_ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo00kooooo000Hooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Hooooo`03o`000?oo
oooooooo0:Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00013ooooo000HooooooSo00004?ooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00<oooooo0ol0001>ooooo`00d?ooool0
0ol0003oooooooooo`1=ooooo`00DOooool5o`000005ooooool0003o0000o`000?ooool00_l00002
ooooo`;o00000oooool3o`0000;ooooo0ol00003ooooo`Go00000_ooool3o`0000;ooooo0ol00004
ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`?o00000oooool3o`0000Sooooo1Ol0
00001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o0000
00?oooooo`000?l000001?l00002ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool0
C?ooool005?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool0
1?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo04cooooo001Cooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooooooo`Go00000_ooool00ol0003oooooooooo`02oooo
o`Go00000_ooool01_l0003oooooooooool0003oooooo`0000Gooooo1Ol00009ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go0000
0_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool00000COooool005?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000004gooooo
001Cooooo`04o`000?ooooooooooooooo`Co00000_ooool4o`0000?ooooo0ol00002ooooo`;o0000
00?oooooo`000?l000000_ooool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l00000
0_ooool3o`0000;ooooo1?l00003ooooo`?o00000oooool3o`0000[ooooo00Co0000oooooooooooo
oooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0
003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`00001<ooooo`00Doooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Doooool0057ooooo
1Ol00008ooooo`03o`000?oooooooooo017ooooo0_l0000[ooooo`Go00002?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Doooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.6892, -0.899186, \
0.0697124, 0.057173}},
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(InterferenceFunction \[Rule] 
          "CompiledFunction[-intensity data-]"\), ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"InterferenceFunction", "\[Rule]", 
            RowBox[{"(", 
              
              TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
                
                False,
                Editable->False], ")"}]}]}], 
        ",", \(WaveLength \[Rule] 0.532`\), ",", \(SpatialScale \[Rule] 1\), 
        ",", \(OpticalPathRange \[Rule] {385.88906303771944`, 
            448.6554847779822`}\), 
        ",", \(RayBoundary \[Rule] {\(-11.578039757381847`\), 
            4.832075777557927`}\)}], "}"}]], "Output",
  CellLabel->"Out[545]=",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.3 Two-Dimensional Wavefronts", "Subsection",
  CellTags->{"AOG0.", "6.3", "AOG6.", "AOG6.3", "AOG6.3.1"}],

Cell[CellGroupData[{

Cell["Example 1", "Subsubsection",
  CellTags->{"AOG0.", "6.3.1", "AOG6.", "AOG6.3", "AOG6.3.1"}],

Cell["\<\
sys = {
MoveDirected[PointOfRays[{2,2}],{0,-2},{100,0},SideOfObject->After],
MoveDirected[GridOfRays[{5,5}],{0,2},{100,0},SideOfObject->After],
Move[Screen[100],100]};\
\>", "Input",
  CellLabel->"In[17]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],

Cell[CellGroupData[{

Cell["DrawSystem[sys,PlotType->TopView];", "Input",
  CellLabel->"In[18]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9995 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0242854 0.00951905 0.49975 0.00951905 [
[ 0 0 0 0 ]
[ 1 .9995 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .0238 m
.97619 .18245 L
.97619 .3411 L
.97619 .49975 L
.97619 .6584 L
.97619 .81705 L
.97619 .9757 L
.97619 .9757 L
.97619 .81705 L
.97619 .6584 L
.97619 .49975 L
.97619 .3411 L
.97619 .18245 L
.97619 .0238 L
.97619 .0238 L
s
.97619 .49975 m
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
.97619 .49975 L
s
.97619 .9757 m
.97619 .95949 L
.97619 .91194 L
.97619 .8363 L
.97619 .73773 L
.97619 .62294 L
.97619 .49975 L
.97619 .37656 L
.97619 .26177 L
.97619 .1632 L
.97619 .08756 L
.97619 .04002 L
.97619 .0238 L
.97619 .04002 L
.97619 .08756 L
.97619 .1632 L
.97619 .26177 L
.97619 .37656 L
.97619 .49975 L
.97619 .62294 L
.97619 .73773 L
.97619 .8363 L
.97619 .91194 L
.97619 .95949 L
.97619 .9757 L
s
.039 .916 .04 r
.02429 .48071 m
.97619 .51638 L
s
% Start of user PostScript
0 -2. 100. 1.74708 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .51638 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .48071 m
.97619 .49975 L
s
% Start of user PostScript
0 -2. 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .49975 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .48071 m
.97619 .48313 L
s
% Start of user PostScript
0 -2. 100. -1.74586 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .48313 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .48071 m
.97619 .51638 L
s
% Start of user PostScript
0 -2. 100. 1.74681 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .51638 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .48071 m
.97619 .49975 L
s
% Start of user PostScript
0 -2. 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .49975 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .48071 m
.97619 .48313 L
s
% Start of user PostScript
0 -2. 100. -1.7456 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .48313 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .48071 m
.97619 .51638 L
s
% Start of user PostScript
0 -2. 100. 1.74708 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .51638 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .48071 m
.97619 .49975 L
s
% Start of user PostScript
0 -2. 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .49975 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .48071 m
.97619 .48313 L
s
% Start of user PostScript
0 -2. 100. -1.74586 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .48313 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .495 m
.97619 .47595 L
s
% Start of user PostScript
-0.04999 -0.4995 100. -2.5005 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .47595 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .51879 m
.97619 .49975 L
s
% Start of user PostScript
0 2. 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .49975 Mdot
.039 .916 .04 r
.5 Mabswid
.02476 .54258 m
.97619 .52355 L
s
% Start of user PostScript
0.04999 4.4995 100. 2.5005 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .52355 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .495 m
.97619 .47595 L
s
% Start of user PostScript
-0.04999 -0.4995 100. -2.5005 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .47595 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .51879 m
.97619 .49975 L
s
% Start of user PostScript
0 2. 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .49975 Mdot
.039 .916 .04 r
.5 Mabswid
.02476 .54258 m
.97619 .52355 L
s
% Start of user PostScript
0.04999 4.4995 100. 2.5005 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .52355 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .495 m
.97619 .47595 L
s
% Start of user PostScript
-0.04999 -0.4995 100. -2.5005 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .47595 Mdot
.039 .916 .04 r
.5 Mabswid
.02429 .51879 m
.97619 .49975 L
s
% Start of user PostScript
0 2. 100. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .49975 Mdot
.039 .916 .04 r
.5 Mabswid
.02476 .54258 m
.97619 .52355 L
s
% Start of user PostScript
0.04999 4.4995 100. 2.5005 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.97619 .52355 Mdot
0 0 m
1 0 L
1 .9995 L
0 .9995 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{288, 287.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00017b000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000oooooooo
ool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oo
oooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0
003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo
00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolI
ooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oo
oooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo
003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05
ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000oooooooo
ool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oo
oooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0
003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo
00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolI
ooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oo
oooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo
003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05
ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000oooooooo
ool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oo
oooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0
003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo
00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolI
ooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oo
oooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo
003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05
ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000oooooooo
ool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oo
oooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0
003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo
00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolI
ooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oo
oooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo
003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05
ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000oooooooo
ool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oo
oooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0
003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo
00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolI
ooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oo
oooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo
003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05
ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000oooooooo
ool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oo
oooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0
003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo
00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolI
ooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oo
oooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo
003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05
ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000oooooooo
ool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oo
oooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0
003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo
00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolI
ooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oo
oooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo
003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05
ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000oooooooo
ool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oo
oooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0
003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo
00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolI
ooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oo
oooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo
003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05
ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000oooooooo
ool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oo
oooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0
003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo
00?o0000ooooooooool01Oooool00?oooooo4Oooool3o`WZ2PGooooo00?o0000ooooooooool01Ooo
ool00?oooooo4_ooool6o`WZ2P03ooooool0003ooooo00Kooooo003oooooo`;ooooo5_l9jPX2o`00
00Oooooo003Cooooobko2NX:4?ooool6o`WZ2P;o00001oooool000Koooooool9jPXBo`WZ2P;o0000
1oooool001GoooooA?l9jPXOooooobko2NX:Joooool5o`WZ2P03ooooool0003o000000Oooooo000`
ooooof3o2NX:P?ooool2o`WZ2PKooooo00?o0000ooooooooool01Oooool001gooooo;Ol9jPX2oooo
oa_o2NX::Ooooolgo`WZ2TWooooo0ol9jPX5ooooo`03o`000?oooooooooo00Gooooo0006oooooaOo
2NX:B_oooolKo`WZ2TGooooo=ol9jPXCooooo`Ko2NX:00?oooooo`000?ooool01_ooool008;ooooo
7?l9jPYPoooooaWo2NX:0_l00007ooooo`00W_oooolKo`WZ2Q[ooooo;_l9jPX@ooooo`Go2NX:00?o
ooooo`000?l000001oooool00:Kooooo;ol9jPXkooooo`;o2NX:1_ooool00ol0003oooooooooo`05
ooooo`00N?ooool^o`WZ2Roooooo6ol9jPXPooooo`?o2NX:1Oooool00ol0003oooooooooo`05oooo
o`00B_ooool^o`WZ2WSooooo6ol9jPX6ooooo`Ko2NX:0_l00007ooooo`007Oooool]o`WZ2/7ooooo
3?l9jPX2o`0000Oooooo0006oooooaOo2NX:m?ooool6o`WZ2P;o00001oooool00?gooooo6_l9jPX2
o`0000Oooooo0036ooooocOo2NX:5?ooool5o`WZ2P;ooooo00?o0000ooooooooool01Oooool008oo
oooo=ol9jPY:ooooo`;o2NX:1_ooool00ol0003oooooooooo`05ooooo`00FOoooolfo`WZ2XWooooo
00?o0000ooooooooool01Oooool002;ooooo=ol9jPZoooooo`03o`000?oooooooooo00Gooooo0007
oooooa_o2NX:m_ooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo
00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003ooooo
ooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000
ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03
o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Ooo
ool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooo
oaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00
oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Ooo
ool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo
00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003ooooo
ooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000
ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03
o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Ooo
ool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooo
oaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00
oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Ooo
ool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo
00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003ooooo
ooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000
ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03
o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Ooo
ool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooo
oaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00
oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Ooo
ool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo
00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003ooooo
ooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000
ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03
o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Ooo
ool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooo
oaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00
oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Ooo
ool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo
00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003ooooo
ooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000
ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03
o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Ooo
ool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooo
oaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00
oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Ooo
ool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo
00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003ooooo
ooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000
ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03
o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Ooo
ool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooo
oaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00
oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Ooo
ool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo
00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003ooooo
ooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000
ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03
o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Ooo
ool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooo
oaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00
oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Ooo
ool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo
00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003ooooo
ooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000
ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03
o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Ooo
ool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooo
oaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00
oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000ooooooooool01Ooo
ool00?oooooo6Oooool00ol0003oooooooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo
00Gooooo003ooooooaWooooo00?o0000ooooooooool01Oooool00?oooooo6Oooool00ol0003ooooo
ooooo`05ooooo`00oooooolIooooo`03o`000?oooooooooo00Gooooo003ooooooaWooooo00?o0000
ooooooooool01Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {286.812, 0}} -> {-2.55983, -52.5005, \
0.366096, 0.366096}},
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
wavefront = FindWaveFronts[sys,PlotDomain->{{-.5,-.1},{-.2,.2}}]\
\>", "Input",
  CellLabel->"In[19]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 1, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 1, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 1, SurfaceNumber -> 1, 
        WaveFrontID -> 1, Source -> 1}],
      Editable->False]], "Print",
  CellLabel->"From In[19]:=",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -117 0 ]
[.5 .82364 117 9 ]
[.02757 .24618 -24 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -22.3468 -9 ]
[.3345 .12542 1.65319 0 ]
[.50253 .05935 -21.0958 -9 ]
[.50253 .05935 2.90415 0 ]
[.68156 -0.01098 -19.8449 -9 ]
[.68156 -0.01098 4.1551 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 24 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 24 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 18 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.01543 .31955 -36 -2.78835 ]
[.01543 .31955 0 6.21165 ]
[.00542 .38227 -42 -2.84158 ]
[.00542 .38227 0 6.15842 ]
[-0.00499 .44754 -42 -2.89721 ]
[-0.00499 .44754 0 6.10279 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Length \\(absolute distance\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-0.5)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.4)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(-0.3)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(-0.2)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(-0.1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-0.2)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-0.1)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.1)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.2)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02769 .31489 m
.03382 .31255 L
s
[(100.04)] .01543 .31955 1 -0.38037 Mshowa
.01773 .37773 m
.02389 .37546 L
s
[(100.042)] .00542 .38227 1 -0.36854 Mshowa
.00737 .44314 m
.01355 .44094 L
s
[(100.044)] -0.00499 .44754 1 -0.35618 Mshowa
.125 Mabswid
.03491 .26935 m
.03858 .26792 L
s
.03253 .28438 m
.0362 .28296 L
s
.03012 .29956 m
.0338 .29815 L
s
.02524 .33036 m
.02892 .32897 L
s
.02276 .346 m
.02645 .34461 L
s
.02026 .36178 m
.02395 .36041 L
s
.01518 .39383 m
.01888 .39248 L
s
.0126 .4101 m
.0163 .40876 L
s
.01 .42654 m
.0137 .42521 L
s
.00471 .45991 m
.00842 .4586 L
s
.00202 .47686 m
.00574 .47556 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .054 .156 r
.39508 .59931 .40493 .60917 .42134 .60955 .41153 .59965 Metetra
0 .081 .18 r
.41153 .59965 .42134 .60955 .4379 .60998 .42813 .60003 Metetra
0 .113 .204 r
.42813 .60003 .4379 .60998 .45461 .61045 .44489 .60047 Metetra
0 .15 .229 r
.44489 .60047 .45461 .61045 .47148 .61098 .46181 .60095 Metetra
0 .193 .253 r
.46181 .60095 .47148 .61098 .48851 .61157 .47889 .60149 Metetra
0 .242 .278 r
.47889 .60149 .48851 .61157 .50571 .6122 .49614 .60208 Metetra
0 .296 .303 r
.49614 .60208 .50571 .6122 .52307 .61289 .51355 .60272 Metetra
0 .328 .299 r
.51355 .60272 .52307 .61289 .5406 .61363 .53113 .60341 Metetra
0 .353 .284 r
.53113 .60341 .5406 .61363 .5583 .61442 .54889 .60416 Metetra
0 .379 .262 r
.54889 .60416 .5583 .61442 .57618 .61528 .56683 .60497 Metetra
0 .404 .235 r
.56683 .60497 .57618 .61528 .59424 .61618 .58495 .60583 Metetra
0 .43 .201 r
.58495 .60583 .59424 .61618 .61249 .61715 .60325 .60675 Metetra
0 .457 .162 r
.60325 .60675 .61249 .61715 .63092 .61817 .62174 .60773 Metetra
0 .483 .116 r
.62174 .60773 .63092 .61817 .64954 .61926 .64042 .60876 Metetra
0 .509 .064 r
.64042 .60876 .64954 .61926 .66835 .6204 .6593 .60986 Metetra
0 .536 .005 r
.6593 .60986 .66835 .6204 .68736 .62161 .67838 .61102 Metetra
.06 .563 0 r
.67838 .61102 .68736 .62161 .70658 .62287 .69766 .61224 Metetra
.133 .59 0 r
.69766 .61224 .70658 .62287 .72599 .62421 .71715 .61352 Metetra
.212 .618 0 r
.71715 .61352 .72599 .62421 .74562 .6256 .73685 .61487 Metetra
.299 .645 0 r
.73685 .61487 .74562 .6256 .76547 .62706 .75676 .61628 Metetra
.393 .673 0 r
.75676 .61628 .76547 .62706 .78553 .62859 .7769 .61775 Metetra
.494 .701 0 r
.7769 .61775 .78553 .62859 .80582 .63018 .79726 .6193 Metetra
.603 .729 0 r
.79726 .6193 .80582 .63018 .82633 .63185 .81786 .62091 Metetra
.72 .758 0 r
.81786 .62091 .82633 .63185 .84707 .63358 .83868 .6226 Metetra
.786 .728 0 r
.83868 .6226 .84707 .63358 .86806 .63539 .85975 .62435 Metetra
.815 .653 0 r
.85975 .62435 .86806 .63539 .88928 .63727 .88106 .62618 Metetra
.844 .57 0 r
.88106 .62618 .88928 .63727 .91075 .63922 .90262 .62808 Metetra
.873 .48 0 r
.90262 .62808 .91075 .63922 .93248 .64125 .92444 .63006 Metetra
.903 .381 0 r
.92444 .63006 .93248 .64125 .95446 .64335 .94651 .63211 Metetra
.932 .274 0 r
.94651 .63211 .95446 .64335 .97671 .64554 .96885 .63425 Metetra
.962 .158 0 r
.96885 .63425 .97671 .64554 .99922 .6478 .99147 .63646 Metetra
0 .051 .153 r
.38511 .5894 .39508 .59931 .41153 .59965 .4016 .58969 Metetra
0 .077 .177 r
.4016 .58969 .41153 .59965 .42813 .60003 .41826 .59003 Metetra
0 .109 .201 r
.41826 .59003 .42813 .60003 .44489 .60047 .43506 .59042 Metetra
0 .145 .226 r
.43506 .59042 .44489 .60047 .46181 .60095 .45203 .59086 Metetra
0 .188 .25 r
.45203 .59086 .46181 .60095 .47889 .60149 .46916 .59135 Metetra
0 .236 .275 r
.46916 .59135 .47889 .60149 .49614 .60208 .48646 .59189 Metetra
0 .29 .3 r
.48646 .59189 .49614 .60208 .51355 .60272 .50392 .59248 Metetra
0 .325 .301 r
.50392 .59248 .51355 .60272 .53113 .60341 .52156 .59313 Metetra
0 .35 .286 r
.52156 .59313 .53113 .60341 .54889 .60416 .53937 .59384 Metetra
0 .376 .265 r
.53937 .59384 .54889 .60416 .56683 .60497 .55737 .59459 Metetra
0 .402 .238 r
.55737 .59459 .56683 .60497 .58495 .60583 .57554 .59541 Metetra
0 .427 .206 r
.57554 .59541 .58495 .60583 .60325 .60675 .5939 .59628 Metetra
0 .454 .167 r
.5939 .59628 .60325 .60675 .62174 .60773 .61246 .59721 Metetra
0 .48 .122 r
.61246 .59721 .62174 .60773 .64042 .60876 .6312 .5982 Metetra
0 .507 .07 r
.6312 .5982 .64042 .60876 .6593 .60986 .65014 .59924 Metetra
0 .533 .012 r
.65014 .59924 .6593 .60986 .67838 .61102 .66929 .60035 Metetra
.053 .56 0 r
.66929 .60035 .67838 .61102 .69766 .61224 .68864 .60152 Metetra
.125 .587 0 r
.68864 .60152 .69766 .61224 .71715 .61352 .70819 .60275 Metetra
.203 .615 0 r
.70819 .60275 .71715 .61352 .73685 .61487 .72797 .60405 Metetra
.289 .642 0 r
.72797 .60405 .73685 .61487 .75676 .61628 .74796 .60541 Metetra
.382 .67 0 r
.74796 .60541 .75676 .61628 .7769 .61775 .76817 .60684 Metetra
.483 .698 0 r
.76817 .60684 .7769 .61775 .79726 .6193 .78861 .60833 Metetra
.591 .726 0 r
.78861 .60833 .79726 .6193 .81786 .62091 .80928 .6099 Metetra
.707 .755 0 r
.80928 .6099 .81786 .62091 .83868 .6226 .83019 .61153 Metetra
.783 .736 0 r
.83019 .61153 .83868 .6226 .85975 .62435 .85134 .61323 Metetra
.812 .661 0 r
.85134 .61323 .85975 .62435 .88106 .62618 .87274 .61501 Metetra
.841 .579 0 r
.87274 .61501 .88106 .62618 .90262 .62808 .89439 .61686 Metetra
.87 .489 0 r
.89439 .61686 .90262 .62808 .92444 .63006 .9163 .61878 Metetra
.9 .391 0 r
.9163 .61878 .92444 .63006 .94651 .63211 .93847 .62078 Metetra
.929 .285 0 r
.93847 .62078 .94651 .63211 .96885 .63425 .96091 .62286 Metetra
.959 .17 0 r
.96091 .62286 .96885 .63425 .99147 .63646 .98362 .62502 Metetra
0 .048 .151 r
.37503 .57941 .38511 .5894 .4016 .58969 .39157 .57966 Metetra
0 .074 .174 r
.39157 .57966 .4016 .58969 .41826 .59003 .40827 .57995 Metetra
0 .105 .199 r
.40827 .57995 .41826 .59003 .43506 .59042 .42512 .5803 Metetra
0 .141 .223 r
.42512 .5803 .43506 .59042 .45203 .59086 .44214 .58069 Metetra
0 .183 .247 r
.44214 .58069 .45203 .59086 .46916 .59135 .45932 .58113 Metetra
0 .23 .272 r
.45932 .58113 .46916 .59135 .48646 .59189 .47667 .58163 Metetra
0 .283 .297 r
.47667 .58163 .48646 .59189 .50392 .59248 .49418 .58218 Metetra
0 .322 .302 r
.49418 .58218 .50392 .59248 .52156 .59313 .51188 .58278 Metetra
0 .348 .288 r
.51188 .58278 .52156 .59313 .53937 .59384 .52974 .58343 Metetra
0 .373 .267 r
.52974 .58343 .53937 .59384 .55737 .59459 .54779 .58414 Metetra
0 .399 .241 r
.54779 .58414 .55737 .59459 .57554 .59541 .56603 .58491 Metetra
0 .425 .209 r
.56603 .58491 .57554 .59541 .5939 .59628 .58445 .58573 Metetra
0 .451 .171 r
.58445 .58573 .5939 .59628 .61246 .59721 .60306 .58661 Metetra
0 .477 .127 r
.60306 .58661 .61246 .59721 .6312 .5982 .62187 .58755 Metetra
0 .504 .076 r
.62187 .58755 .6312 .5982 .65014 .59924 .64088 .58855 Metetra
0 .531 .018 r
.64088 .58855 .65014 .59924 .66929 .60035 .66009 .58961 Metetra
.046 .557 0 r
.66009 .58961 .66929 .60035 .68864 .60152 .67951 .59072 Metetra
.117 .585 0 r
.67951 .59072 .68864 .60152 .70819 .60275 .69913 .59191 Metetra
.195 .612 0 r
.69913 .59191 .70819 .60275 .72797 .60405 .71898 .59315 Metetra
.28 .64 0 r
.71898 .59315 .72797 .60405 .74796 .60541 .73904 .59446 Metetra
.373 .667 0 r
.73904 .59446 .74796 .60541 .76817 .60684 .75933 .59584 Metetra
.473 .695 0 r
.75933 .59584 .76817 .60684 .78861 .60833 .77985 .59728 Metetra
.58 .724 0 r
.77985 .59728 .78861 .60833 .80928 .6099 .80061 .59879 Metetra
.696 .752 0 r
.80061 .59879 .80928 .6099 .83019 .61153 .8216 .60037 Metetra
.781 .742 0 r
.8216 .60037 .83019 .61153 .85134 .61323 .84283 .60202 Metetra
.809 .669 0 r
.84283 .60202 .85134 .61323 .87274 .61501 .86432 .60374 Metetra
.838 .587 0 r
.86432 .60374 .87274 .61501 .89439 .61686 .88606 .60554 Metetra
.868 .498 0 r
.88606 .60554 .89439 .61686 .9163 .61878 .90806 .60741 Metetra
.897 .401 0 r
.90806 .60741 .9163 .61878 .93847 .62078 .93033 .60936 Metetra
.927 .295 0 r
.93033 .60936 .93847 .62078 .96091 .62286 .95287 .61138 Metetra
.956 .181 0 r
.95287 .61138 .96091 .62286 .98362 .62502 .97568 .61348 Metetra
0 .046 .148 r
.36483 .56937 .37503 .57941 .39157 .57966 .38142 .56957 Metetra
0 .071 .172 r
.38142 .56957 .39157 .57966 .40827 .57995 .39816 .56981 Metetra
0 .101 .196 r
.39816 .56981 .40827 .57995 .42512 .5803 .41506 .57011 Metetra
0 .137 .22 r
.41506 .57011 .42512 .5803 .44214 .58069 .43213 .57045 Metetra
0 .178 .245 r
.43213 .57045 .44214 .58069 .45932 .58113 .44936 .57085 Metetra
0 .225 .27 r
.44936 .57085 .45932 .58113 .47667 .58163 .46676 .5713 Metetra
0 .278 .294 r
.46676 .5713 .47667 .58163 .49418 .58218 .48433 .5718 Metetra
0 .32 .303 r
.48433 .5718 .49418 .58218 .51188 .58278 .50208 .57235 Metetra
0 .345 .289 r
.50208 .57235 .51188 .58278 .52974 .58343 .52 .57296 Metetra
0 .37 .27 r
.52 .57296 .52974 .58343 .54779 .58414 .53811 .57362 Metetra
0 .396 .244 r
.53811 .57362 .54779 .58414 .56603 .58491 .5564 .57433 Metetra
0 .422 .213 r
.5564 .57433 .56603 .58491 .58445 .58573 .57488 .57511 Metetra
0 .448 .175 r
.57488 .57511 .58445 .58573 .60306 .58661 .59356 .57594 Metetra
0 .475 .131 r
.59356 .57594 .60306 .58661 .62187 .58755 .61243 .57682 Metetra
0 .501 .081 r
.61243 .57682 .62187 .58755 .64088 .58855 .6315 .57777 Metetra
0 .528 .024 r
.6315 .57777 .64088 .58855 .66009 .58961 .65078 .57878 Metetra
.04 .555 0 r
.65078 .57878 .66009 .58961 .67951 .59072 .67027 .57985 Metetra
.11 .582 0 r
.67027 .57985 .67951 .59072 .69913 .59191 .68997 .58098 Metetra
.188 .609 0 r
.68997 .58098 .69913 .59191 .71898 .59315 .70988 .58217 Metetra
.272 .637 0 r
.70988 .58217 .71898 .59315 .73904 .59446 .73002 .58343 Metetra
.364 .665 0 r
.73002 .58343 .73904 .59446 .75933 .59584 .75039 .58475 Metetra
.463 .693 0 r
.75039 .58475 .75933 .59584 .77985 .59728 .77099 .58614 Metetra
.57 .721 0 r
.77099 .58614 .77985 .59728 .80061 .59879 .79182 .5876 Metetra
.685 .749 0 r
.79182 .5876 .80061 .59879 .8216 .60037 .8129 .58912 Metetra
.778 .748 0 r
.8129 .58912 .8216 .60037 .84283 .60202 .83422 .59072 Metetra
.807 .675 0 r
.83422 .59072 .84283 .60202 .86432 .60374 .8558 .59239 Metetra
.836 .595 0 r
.8558 .59239 .86432 .60374 .88606 .60554 .87763 .59413 Metetra
.865 .506 0 r
.87763 .59413 .88606 .60554 .90806 .60741 .89972 .59595 Metetra
.894 .409 0 r
.89972 .59595 .90806 .60741 .93033 .60936 .92209 .59784 Metetra
.924 .304 0 r
.92209 .59784 .93033 .60936 .95287 .61138 .94472 .5998 Metetra
.954 .191 0 r
.94472 .5998 .95287 .61138 .97568 .61348 .96764 .60185 Metetra
0 .043 .146 r
.35452 .55925 .36483 .56937 .38142 .56957 .37115 .5594 Metetra
0 .068 .17 r
.37115 .5594 .38142 .56957 .39816 .56981 .38794 .5596 Metetra
0 .098 .194 r
.38794 .5596 .39816 .56981 .41506 .57011 .40489 .55985 Metetra
0 .133 .218 r
.40489 .55985 .41506 .57011 .43213 .57045 .42201 .56015 Metetra
0 .174 .243 r
.42201 .56015 .43213 .57045 .44936 .57085 .43929 .5605 Metetra
0 .22 .267 r
.43929 .5605 .44936 .57085 .46676 .5713 .45674 .5609 Metetra
0 .272 .292 r
.45674 .5609 .46676 .5713 .48433 .5718 .47436 .56135 Metetra
0 .317 .304 r
.47436 .56135 .48433 .5718 .50208 .57235 .49216 .56185 Metetra
0 .343 .291 r
.49216 .56185 .50208 .57235 .52 .57296 .51014 .56241 Metetra
0 .368 .272 r
.51014 .56241 .52 .57296 .53811 .57362 .52831 .56302 Metetra
0 .394 .247 r
.52831 .56302 .53811 .57362 .5564 .57433 .54666 .56368 Metetra
0 .42 .216 r
.54666 .56368 .5564 .57433 .57488 .57511 .5652 .5644 Metetra
0 .446 .179 r
.5652 .5644 .57488 .57511 .59356 .57594 .58394 .56518 Metetra
0 .472 .135 r
.58394 .56518 .59356 .57594 .61243 .57682 .60287 .56602 Metetra
0 .499 .086 r
.60287 .56602 .61243 .57682 .6315 .57777 .62201 .56691 Metetra
0 .526 .029 r
.62201 .56691 .6315 .57777 .65078 .57878 .64136 .56787 Metetra
.034 .553 0 r
.64136 .56787 .65078 .57878 .67027 .57985 .66091 .56889 Metetra
.104 .58 0 r
.66091 .56889 .67027 .57985 .68997 .58098 .68069 .56996 Metetra
.181 .607 0 r
.68069 .56996 .68997 .58098 .70988 .58217 .70068 .5711 Metetra
.265 .635 0 r
.70068 .5711 .70988 .58217 .73002 .58343 .72089 .57231 Metetra
.356 .662 0 r
.72089 .57231 .73002 .58343 .75039 .58475 .74134 .57358 Metetra
.455 .69 0 r
.74134 .57358 .75039 .58475 .77099 .58614 .76202 .57491 Metetra
.561 .719 0 r
.76202 .57491 .77099 .58614 .79182 .5876 .78293 .57631 Metetra
.675 .747 0 r
.78293 .57631 .79182 .5876 .8129 .58912 .80409 .57779 Metetra
.776 .754 0 r
.80409 .57779 .8129 .58912 .83422 .59072 .8255 .57933 Metetra
.804 .682 0 r
.8255 .57933 .83422 .59072 .8558 .59239 .84717 .58094 Metetra
.833 .602 0 r
.84717 .58094 .8558 .59239 .87763 .59413 .86909 .58262 Metetra
.863 .513 0 r
.86909 .58262 .87763 .59413 .89972 .59595 .89128 .58438 Metetra
.892 .417 0 r
.89128 .58438 .89972 .59595 .92209 .59784 .91374 .58622 Metetra
.922 .313 0 r
.91374 .58622 .92209 .59784 .94472 .5998 .93648 .58813 Metetra
.951 .2 0 r
.93648 .58813 .94472 .5998 .96764 .60185 .9595 .59012 Metetra
0 .041 .144 r
.34409 .54907 .35452 .55925 .37115 .5594 .36076 .54917 Metetra
0 .066 .167 r
.36076 .54917 .37115 .5594 .38794 .5596 .3776 .54932 Metetra
0 .095 .192 r
.3776 .54932 .38794 .5596 .40489 .55985 .3946 .54952 Metetra
0 .13 .216 r
.3946 .54952 .40489 .55985 .42201 .56015 .41176 .54977 Metetra
0 .17 .24 r
.41176 .54977 .42201 .56015 .43929 .5605 .42909 .55007 Metetra
0 .216 .265 r
.42909 .55007 .43929 .5605 .45674 .5609 .4466 .55042 Metetra
0 .268 .29 r
.4466 .55042 .45674 .5609 .47436 .56135 .46427 .55082 Metetra
0 .315 .305 r
.46427 .55082 .47436 .56135 .49216 .56185 .48213 .55127 Metetra
0 .34 .292 r
.48213 .55127 .49216 .56185 .51014 .56241 .50017 .55178 Metetra
0 .366 .274 r
.50017 .55178 .51014 .56241 .52831 .56302 .51839 .55234 Metetra
0 .392 .249 r
.51839 .55234 .52831 .56302 .54666 .56368 .5368 .55295 Metetra
0 .418 .219 r
.5368 .55295 .54666 .56368 .5652 .5644 .5554 .55362 Metetra
0 .444 .182 r
.5554 .55362 .5652 .5644 .58394 .56518 .5742 .55435 Metetra
0 .47 .139 r
.5742 .55435 .58394 .56518 .60287 .56602 .5932 .55513 Metetra
0 .497 .09 r
.5932 .55513 .60287 .56602 .62201 .56691 .61241 .55597 Metetra
0 .524 .034 r
.61241 .55597 .62201 .56691 .64136 .56787 .63182 .55688 Metetra
.029 .55 0 r
.63182 .55688 .64136 .56787 .66091 .56889 .65145 .55784 Metetra
.098 .578 0 r
.65145 .55784 .66091 .56889 .68069 .56996 .67129 .55886 Metetra
.174 .605 0 r
.67129 .55886 .68069 .56996 .70068 .5711 .69136 .55995 Metetra
.258 .633 0 r
.69136 .55995 .70068 .5711 .72089 .57231 .71165 .5611 Metetra
.349 .66 0 r
.71165 .5611 .72089 .57231 .74134 .57358 .73217 .56231 Metetra
.447 .688 0 r
.73217 .56231 .74134 .57358 .76202 .57491 .75293 .56359 Metetra
.553 .717 0 r
.75293 .56359 .76202 .57491 .78293 .57631 .77393 .56494 Metetra
.666 .745 0 r
.77393 .56494 .78293 .57631 .80409 .57779 .79518 .56635 Metetra
.774 .759 0 r
.79518 .56635 .80409 .57779 .8255 .57933 .81667 .56784 Metetra
.802 .687 0 r
.81667 .56784 .8255 .57933 .84717 .58094 .83843 .56939 Metetra
.831 .608 0 r
.83843 .56939 .84717 .58094 .86909 .58262 .86045 .57102 Metetra
.861 .52 0 r
.86045 .57102 .86909 .58262 .89128 .58438 .88273 .57272 Metetra
.89 .425 0 r
.88273 .57272 .89128 .58438 .91374 .58622 .90529 .5745 Metetra
.92 .321 0 r
.90529 .5745 .91374 .58622 .93648 .58813 .92813 .57635 Metetra
.949 .208 0 r
.92813 .57635 .93648 .58813 .9595 .59012 .95126 .57828 Metetra
0 .04 .142 r
.33353 .53881 .34409 .54907 .36076 .54917 .35025 .53886 Metetra
0 .064 .165 r
.35025 .53886 .36076 .54917 .3776 .54932 .36714 .53897 Metetra
0 .093 .19 r
.36714 .53897 .3776 .54932 .3946 .54952 .38418 .53912 Metetra
0 .127 .214 r
.38418 .53912 .3946 .54952 .41176 .54977 .4014 .53932 Metetra
0 .167 .238 r
.4014 .53932 .41176 .54977 .42909 .55007 .41878 .53956 Metetra
0 .212 .263 r
.41878 .53956 .42909 .55007 .4466 .55042 .43633 .53986 Metetra
0 .264 .288 r
.43633 .53986 .4466 .55042 .46427 .55082 .45406 .54021 Metetra
0 .313 .306 r
.45406 .54021 .46427 .55082 .48213 .55127 .47197 .54061 Metetra
0 .339 .293 r
.47197 .54061 .48213 .55127 .50017 .55178 .49007 .54107 Metetra
0 .364 .275 r
.49007 .54107 .50017 .55178 .51839 .55234 .50835 .54158 Metetra
0 .39 .251 r
.50835 .54158 .51839 .55234 .5368 .55295 .52682 .54214 Metetra
0 .416 .221 r
.52682 .54214 .5368 .55295 .5554 .55362 .54549 .54275 Metetra
0 .442 .185 r
.54549 .54275 .5554 .55362 .5742 .55435 .56435 .54343 Metetra
0 .468 .142 r
.56435 .54343 .5742 .55435 .5932 .55513 .58341 .54416 Metetra
0 .495 .094 r
.58341 .54416 .5932 .55513 .61241 .55597 .60269 .54495 Metetra
0 .522 .038 r
.60269 .54495 .61241 .55597 .63182 .55688 .62217 .54579 Metetra
.024 .549 0 r
.62217 .54579 .63182 .55688 .65145 .55784 .64186 .5467 Metetra
.093 .576 0 r
.64186 .5467 .65145 .55784 .67129 .55886 .66178 .54767 Metetra
.169 .603 0 r
.66178 .54767 .67129 .55886 .69136 .55995 .68192 .5487 Metetra
.252 .631 0 r
.68192 .5487 .69136 .55995 .71165 .5611 .70229 .54979 Metetra
.342 .658 0 r
.70229 .54979 .71165 .5611 .73217 .56231 .72289 .55095 Metetra
.44 .686 0 r
.72289 .55095 .73217 .56231 .75293 .56359 .74373 .55218 Metetra
.545 .715 0 r
.74373 .55218 .75293 .56359 .77393 .56494 .76482 .55347 Metetra
.658 .743 0 r
.76482 .55347 .77393 .56494 .79518 .56635 .78615 .55482 Metetra
.772 .764 0 r
.78615 .55482 .79518 .56635 .81667 .56784 .80773 .55625 Metetra
.8 .692 0 r
.80773 .55625 .81667 .56784 .83843 .56939 .82958 .55775 Metetra
.829 .613 0 r
.82958 .55775 .83843 .56939 .86045 .57102 .85169 .55932 Metetra
.859 .526 0 r
.85169 .55932 .86045 .57102 .88273 .57272 .87407 .56096 Metetra
.888 .431 0 r
.87407 .56096 .88273 .57272 .90529 .5745 .89673 .56268 Metetra
.918 .328 0 r
.89673 .56268 .90529 .5745 .92813 .57635 .91967 .56447 Metetra
.947 .216 0 r
.91967 .56447 .92813 .57635 .95126 .57828 .94291 .56634 Metetra
0 .038 .14 r
.32285 .52848 .33353 .53881 .35025 .53886 .33962 .52849 Metetra
0 .062 .164 r
.33962 .52849 .35025 .53886 .36714 .53897 .35655 .52854 Metetra
0 .09 .188 r
.35655 .52854 .36714 .53897 .38418 .53912 .37364 .52864 Metetra
0 .124 .212 r
.37364 .52864 .38418 .53912 .4014 .53932 .39091 .52879 Metetra
0 .164 .237 r
.39091 .52879 .4014 .53932 .41878 .53956 .40834 .52898 Metetra
0 .209 .261 r
.40834 .52898 .41878 .53956 .43633 .53986 .42595 .52923 Metetra
0 .26 .286 r
.42595 .52923 .43633 .53986 .45406 .54021 .44373 .52953 Metetra
0 .311 .306 r
.44373 .52953 .45406 .54021 .47197 .54061 .4617 .52988 Metetra
0 .337 .294 r
.4617 .52988 .47197 .54061 .49007 .54107 .47985 .53028 Metetra
0 .362 .277 r
.47985 .53028 .49007 .54107 .50835 .54158 .49819 .53073 Metetra
0 .388 .253 r
.49819 .53073 .50835 .54158 .52682 .54214 .51672 .53124 Metetra
0 .414 .223 r
.51672 .53124 .52682 .54214 .54549 .54275 .53545 .5318 Metetra
0 .44 .187 r
.53545 .5318 .54549 .54275 .56435 .54343 .55437 .53242 Metetra
0 .467 .145 r
.55437 .53242 .56435 .54343 .58341 .54416 .5735 .5331 Metetra
0 .493 .097 r
.5735 .5331 .58341 .54416 .60269 .54495 .59284 .53383 Metetra
0 .52 .042 r
.59284 .53383 .60269 .54495 .62217 .54579 .61239 .53462 Metetra
.02 .547 0 r
.61239 .53462 .62217 .54579 .64186 .5467 .63216 .53548 Metetra
.088 .574 0 r
.63216 .53548 .64186 .5467 .66178 .54767 .65215 .53639 Metetra
.164 .601 0 r
.65215 .53639 .66178 .54767 .68192 .5487 .67237 .53736 Metetra
.246 .629 0 r
.67237 .53736 .68192 .5487 .70229 .54979 .69281 .5384 Metetra
.336 .657 0 r
.69281 .5384 .70229 .54979 .72289 .55095 .71349 .5395 Metetra
.434 .685 0 r
.71349 .5395 .72289 .55095 .74373 .55218 .73442 .54066 Metetra
.539 .713 0 r
.73442 .54066 .74373 .55218 .76482 .55347 .75559 .5419 Metetra
.651 .741 0 r
.75559 .5419 .76482 .55347 .78615 .55482 .777 .54319 Metetra
.77 .768 0 r
.777 .54319 .78615 .55482 .80773 .55625 .79868 .54456 Metetra
.799 .697 0 r
.79868 .54456 .80773 .55625 .82958 .55775 .82062 .546 Metetra
.828 .618 0 r
.82062 .546 .82958 .55775 .85169 .55932 .84282 .54751 Metetra
.857 .532 0 r
.84282 .54751 .85169 .55932 .87407 .56096 .8653 .54909 Metetra
.886 .437 0 r
.8653 .54909 .87407 .56096 .89673 .56268 .88806 .55075 Metetra
.916 .334 0 r
.88806 .55075 .89673 .56268 .91967 .56447 .91111 .55248 Metetra
.946 .223 0 r
.91111 .55248 .91967 .56447 .94291 .56634 .93445 .55429 Metetra
0 .037 .138 r
.31204 .51808 .32285 .52848 .33962 .52849 .32885 .51803 Metetra
0 .06 .162 r
.32885 .51803 .33962 .52849 .35655 .52854 .34583 .51803 Metetra
0 .088 .186 r
.34583 .51803 .35655 .52854 .37364 .52864 .36297 .51808 Metetra
0 .122 .211 r
.36297 .51808 .37364 .52864 .39091 .52879 .38029 .51818 Metetra
0 .161 .235 r
.38029 .51818 .39091 .52879 .40834 .52898 .39777 .51832 Metetra
0 .206 .26 r
.39777 .51832 .40834 .52898 .42595 .52923 .41543 .51852 Metetra
0 .257 .285 r
.41543 .51852 .42595 .52923 .44373 .52953 .43327 .51876 Metetra
0 .31 .307 r
.43327 .51876 .44373 .52953 .4617 .52988 .45129 .51906 Metetra
0 .335 .295 r
.45129 .51906 .4617 .52988 .47985 .53028 .4695 .5194 Metetra
0 .361 .278 r
.4695 .5194 .47985 .53028 .49819 .53073 .4879 .5198 Metetra
0 .387 .254 r
.4879 .5198 .49819 .53073 .51672 .53124 .50649 .52026 Metetra
0 .412 .225 r
.50649 .52026 .51672 .53124 .53545 .5318 .52528 .52077 Metetra
0 .439 .19 r
.52528 .52077 .53545 .5318 .55437 .53242 .54427 .52133 Metetra
0 .465 .148 r
.54427 .52133 .55437 .53242 .5735 .5331 .56347 .52195 Metetra
0 .492 .1 r
.56347 .52195 .5735 .5331 .59284 .53383 .58287 .52263 Metetra
0 .518 .045 r
.58287 .52263 .59284 .53383 .61239 .53462 .6025 .52336 Metetra
.016 .545 0 r
.6025 .52336 .61239 .53462 .63216 .53548 .62234 .52416 Metetra
.084 .572 0 r
.62234 .52416 .63216 .53548 .65215 .53639 .6424 .52501 Metetra
.159 .6 0 r
.6424 .52501 .65215 .53639 .67237 .53736 .66269 .52593 Metetra
.242 .627 0 r
.66269 .52593 .67237 .53736 .69281 .5384 .68322 .52691 Metetra
.331 .655 0 r
.68322 .52691 .69281 .5384 .71349 .5395 .70398 .52795 Metetra
.428 .683 0 r
.70398 .52795 .71349 .5395 .73442 .54066 .72498 .52905 Metetra
.533 .711 0 r
.72498 .52905 .73442 .54066 .75559 .5419 .74624 .53023 Metetra
.645 .74 0 r
.74624 .53023 .75559 .5419 .777 .54319 .76774 .53146 Metetra
.765 .768 0 r
.76774 .53146 .777 .54319 .79868 .54456 .78951 .53277 Metetra
.797 .701 0 r
.78951 .53277 .79868 .54456 .82062 .546 .81154 .53415 Metetra
.826 .623 0 r
.81154 .53415 .82062 .546 .84282 .54751 .83384 .5356 Metetra
.855 .536 0 r
.83384 .5356 .84282 .54751 .8653 .54909 .85642 .53712 Metetra
.885 .442 0 r
.85642 .53712 .8653 .54909 .88806 .55075 .87928 .53871 Metetra
.914 .339 0 r
.87928 .53871 .88806 .55075 .91111 .55248 .90243 .54038 Metetra
.944 .229 0 r
.90243 .54038 .91111 .55248 .93445 .55429 .92588 .54212 Metetra
0 .036 .137 r
.3011 .5076 .31204 .51808 .32885 .51803 .31796 .5075 Metetra
0 .059 .161 r
.31796 .5075 .32885 .51803 .34583 .51803 .33498 .50745 Metetra
0 .087 .185 r
.33498 .50745 .34583 .51803 .36297 .51808 .35218 .50745 Metetra
0 .12 .209 r
.35218 .50745 .36297 .51808 .38029 .51818 .36954 .50749 Metetra
0 .159 .234 r
.36954 .50749 .38029 .51818 .39777 .51832 .38708 .50758 Metetra
0 .204 .259 r
.38708 .50758 .39777 .51832 .41543 .51852 .40479 .50772 Metetra
0 .254 .283 r
.40479 .50772 .41543 .51852 .43327 .51876 .42268 .50791 Metetra
0 .309 .307 r
.42268 .50791 .43327 .51876 .45129 .51906 .44076 .50815 Metetra
0 .334 .296 r
.44076 .50815 .45129 .51906 .4695 .5194 .45903 .50845 Metetra
0 .359 .279 r
.45903 .50845 .4695 .5194 .4879 .5198 .47748 .50879 Metetra
0 .385 .256 r
.47748 .50879 .4879 .5198 .50649 .52026 .49614 .50919 Metetra
0 .411 .227 r
.49614 .50919 .50649 .52026 .52528 .52077 .51499 .50964 Metetra
0 .437 .192 r
.51499 .50964 .52528 .52077 .54427 .52133 .53404 .51015 Metetra
0 .464 .15 r
.53404 .51015 .54427 .52133 .56347 .52195 .55331 .51071 Metetra
0 .49 .102 r
.55331 .51071 .56347 .52195 .58287 .52263 .57278 .51133 Metetra
0 .517 .048 r
.57278 .51133 .58287 .52263 .6025 .52336 .59247 .51201 Metetra
.013 .544 0 r
.59247 .51201 .6025 .52336 .62234 .52416 .61238 .51274 Metetra
.081 .571 0 r
.61238 .51274 .62234 .52416 .6424 .52501 .63252 .51354 Metetra
.156 .598 0 r
.63252 .51354 .6424 .52501 .66269 .52593 .65289 .5144 Metetra
.238 .626 0 r
.65289 .5144 .66269 .52593 .68322 .52691 .67349 .51531 Metetra
.327 .654 0 r
.67349 .51531 .68322 .52691 .70398 .52795 .69434 .5163 Metetra
.424 .682 0 r
.69434 .5163 .70398 .52795 .72498 .52905 .71543 .51734 Metetra
.528 .71 0 r
.71543 .51734 .72498 .52905 .74624 .53023 .73677 .51845 Metetra
.64 .738 0 r
.73677 .51845 .74624 .53023 .76774 .53146 .75836 .51963 Metetra
.759 .767 0 r
.75836 .51963 .76774 .53146 .78951 .53277 .78022 .52088 Metetra
.796 .704 0 r
.78022 .52088 .78951 .53277 .81154 .53415 .80234 .52219 Metetra
.825 .626 0 r
.80234 .52219 .81154 .53415 .83384 .5356 .82474 .52358 Metetra
.854 .54 0 r
.82474 .52358 .83384 .5356 .85642 .53712 .84742 .52503 Metetra
.883 .446 0 r
.84742 .52503 .85642 .53712 .87928 .53871 .87038 .52656 Metetra
.913 .344 0 r
.87038 .52656 .87928 .53871 .90243 .54038 .89364 .52817 Metetra
.943 .234 0 r
.89364 .52817 .90243 .54038 .92588 .54212 .9172 .52985 Metetra
0 .035 .136 r
.29002 .49704 .3011 .5076 .31796 .5075 .30693 .49689 Metetra
0 .057 .16 r
.30693 .49689 .31796 .5075 .33498 .50745 .324 .49679 Metetra
0 .085 .184 r
.324 .49679 .33498 .50745 .35218 .50745 .34125 .49673 Metetra
0 .118 .208 r
.34125 .49673 .35218 .50745 .36954 .50749 .35866 .49672 Metetra
0 .157 .233 r
.35866 .49672 .36954 .50749 .38708 .50758 .37625 .49676 Metetra
0 .201 .257 r
.37625 .49676 .38708 .50758 .40479 .50772 .39401 .49684 Metetra
0 .251 .282 r
.39401 .49684 .40479 .50772 .42268 .50791 .41196 .49698 Metetra
0 .307 .307 r
.41196 .49698 .42268 .50791 .44076 .50815 .4301 .49716 Metetra
0 .333 .297 r
.4301 .49716 .44076 .50815 .45903 .50845 .44842 .4974 Metetra
0 .358 .28 r
.44842 .4974 .45903 .50845 .47748 .50879 .46694 .49769 Metetra
0 .384 .257 r
.46694 .49769 .47748 .50879 .49614 .50919 .48565 .49803 Metetra
0 .41 .228 r
.48565 .49803 .49614 .50919 .51499 .50964 .50456 .49842 Metetra
0 .436 .193 r
.50456 .49842 .51499 .50964 .53404 .51015 .52368 .49887 Metetra
0 .463 .152 r
.52368 .49887 .53404 .51015 .55331 .51071 .54301 .49938 Metetra
0 .489 .105 r
.54301 .49938 .55331 .51071 .57278 .51133 .56256 .49994 Metetra
0 .516 .051 r
.56256 .49994 .57278 .51133 .59247 .51201 .58232 .50056 Metetra
.01 .543 0 r
.58232 .50056 .59247 .51201 .61238 .51274 .60231 .50123 Metetra
.078 .57 0 r
.60231 .50123 .61238 .51274 .63252 .51354 .62252 .50197 Metetra
.152 .597 0 r
.62252 .50197 .63252 .51354 .65289 .5144 .64296 .50277 Metetra
.234 .625 0 r
.64296 .50277 .65289 .5144 .67349 .51531 .66365 .50362 Metetra
.323 .653 0 r
.66365 .50362 .67349 .51531 .69434 .5163 .68457 .50454 Metetra
.42 .681 0 r
.68457 .50454 .69434 .5163 .71543 .51734 .70574 .50553 Metetra
.523 .709 0 r
.70574 .50553 .71543 .51734 .73677 .51845 .72717 .50658 Metetra
.635 .737 0 r
.72717 .50658 .73677 .51845 .75836 .51963 .74886 .50769 Metetra
.755 .766 0 r
.74886 .50769 .75836 .51963 .78022 .52088 .7708 .50887 Metetra
.795 .707 0 r
.7708 .50887 .78022 .52088 .80234 .52219 .79302 .51012 Metetra
.824 .629 0 r
.79302 .51012 .80234 .52219 .82474 .52358 .81552 .51144 Metetra
.853 .544 0 r
.81552 .51144 .82474 .52358 .84742 .52503 .8383 .51283 Metetra
.882 .45 0 r
.8383 .51283 .84742 .52503 .87038 .52656 .86137 .5143 Metetra
.912 .348 0 r
.86137 .5143 .87038 .52656 .89364 .52817 .88473 .51584 Metetra
.942 .238 0 r
.88473 .51584 .89364 .52817 .9172 .52985 .9084 .51745 Metetra
0 .034 .135 r
.27881 .48641 .29002 .49704 .30693 .49689 .29577 .4862 Metetra
0 .056 .159 r
.29577 .4862 .30693 .49689 .324 .49679 .31289 .48604 Metetra
0 .084 .183 r
.31289 .48604 .324 .49679 .34125 .49673 .33018 .48593 Metetra
0 .117 .207 r
.33018 .48593 .34125 .49673 .35866 .49672 .34764 .48587 Metetra
0 .156 .232 r
.34764 .48587 .35866 .49672 .37625 .49676 .36528 .48585 Metetra
0 .2 .257 r
.36528 .48585 .37625 .49676 .39401 .49684 .3831 .48588 Metetra
0 .249 .281 r
.3831 .48588 .39401 .49684 .41196 .49698 .40111 .48596 Metetra
0 .305 .307 r
.40111 .48596 .41196 .49698 .4301 .49716 .4193 .48608 Metetra
0 .332 .297 r
.4193 .48608 .4301 .49716 .44842 .4974 .43768 .48626 Metetra
0 .357 .28 r
.43768 .48626 .44842 .4974 .46694 .49769 .45625 .48649 Metetra
0 .383 .258 r
.45625 .48649 .46694 .49769 .48565 .49803 .47503 .48678 Metetra
0 .409 .229 r
.47503 .48678 .48565 .49803 .50456 .49842 .49401 .48711 Metetra
0 .435 .195 r
.49401 .48711 .50456 .49842 .52368 .49887 .51319 .4875 Metetra
0 .462 .154 r
.51319 .4875 .52368 .49887 .54301 .49938 .53259 .48795 Metetra
0 .488 .106 r
.53259 .48795 .54301 .49938 .56256 .49994 .5522 .48845 Metetra
0 .515 .052 r
.5522 .48845 .56256 .49994 .58232 .50056 .57204 .48901 Metetra
.008 .542 0 r
.57204 .48901 .58232 .50056 .60231 .50123 .59209 .48962 Metetra
.075 .569 0 r
.59209 .48962 .60231 .50123 .62252 .50197 .61238 .4903 Metetra
.15 .596 0 r
.61238 .4903 .62252 .50197 .64296 .50277 .63291 .49103 Metetra
.231 .624 0 r
.63291 .49103 .64296 .50277 .66365 .50362 .65367 .49183 Metetra
.32 .652 0 r
.65367 .49183 .66365 .50362 .68457 .50454 .67468 .49268 Metetra
.416 .68 0 r
.67468 .49268 .68457 .50454 .70574 .50553 .69593 .4936 Metetra
.52 .708 0 r
.69593 .4936 .70574 .50553 .72717 .50658 .71745 .49459 Metetra
.631 .736 0 r
.71745 .49459 .72717 .50658 .74886 .50769 .73922 .49564 Metetra
.751 .765 0 r
.73922 .49564 .74886 .50769 .7708 .50887 .76127 .49676 Metetra
.794 .709 0 r
.76127 .49676 .7708 .50887 .79302 .51012 .78358 .49794 Metetra
.823 .632 0 r
.78358 .49794 .79302 .51012 .81552 .51144 .80618 .4992 Metetra
.852 .547 0 r
.80618 .4992 .81552 .51144 .8383 .51283 .82906 .50052 Metetra
.881 .453 0 r
.82906 .50052 .8383 .51283 .86137 .5143 .85223 .50192 Metetra
.911 .351 0 r
.85223 .50192 .86137 .5143 .88473 .51584 .8757 .50339 Metetra
.941 .241 0 r
.8757 .50339 .88473 .51584 .9084 .51745 .89948 .50493 Metetra
0 .033 .134 r
.26746 .47569 .27881 .48641 .29577 .4862 .28446 .47543 Metetra
0 .056 .158 r
.28446 .47543 .29577 .4862 .31289 .48604 .30163 .47522 Metetra
0 .083 .182 r
.30163 .47522 .31289 .48604 .33018 .48593 .31897 .47505 Metetra
0 .116 .207 r
.31897 .47505 .33018 .48593 .34764 .48587 .33649 .47493 Metetra
0 .154 .231 r
.33649 .47493 .34764 .48587 .36528 .48585 .35418 .47485 Metetra
0 .198 .256 r
.35418 .47485 .36528 .48585 .3831 .48588 .37205 .47482 Metetra
0 .248 .281 r
.37205 .47482 .3831 .48588 .40111 .48596 .39011 .47484 Metetra
0 .303 .306 r
.39011 .47484 .40111 .48596 .4193 .48608 .40836 .47492 Metetra
0 .331 .297 r
.40836 .47492 .4193 .48608 .43768 .48626 .4268 .47504 Metetra
0 .357 .281 r
.4268 .47504 .43768 .48626 .45625 .48649 .44544 .47521 Metetra
0 .382 .259 r
.44544 .47521 .45625 .48649 .47503 .48678 .46427 .47543 Metetra
0 .408 .23 r
.46427 .47543 .47503 .48678 .49401 .48711 .48331 .47571 Metetra
0 .435 .196 r
.48331 .47571 .49401 .48711 .51319 .4875 .50257 .47604 Metetra
0 .461 .155 r
.50257 .47604 .51319 .4875 .53259 .48795 .52203 .47642 Metetra
0 .487 .108 r
.52203 .47642 .53259 .48795 .5522 .48845 .54171 .47686 Metetra
0 .514 .054 r
.54171 .47686 .5522 .48845 .57204 .48901 .56162 .47736 Metetra
.006 .541 0 r
.56162 .47736 .57204 .48901 .59209 .48962 .58175 .47791 Metetra
.074 .568 0 r
.58175 .47791 .59209 .48962 .61238 .4903 .60211 .47852 Metetra
.148 .596 0 r
.60211 .47852 .61238 .4903 .63291 .49103 .62271 .47919 Metetra
.229 .623 0 r
.62271 .47919 .63291 .49103 .65367 .49183 .64356 .47992 Metetra
.318 .651 0 r
.64356 .47992 .65367 .49183 .67468 .49268 .66465 .48072 Metetra
.414 .679 0 r
.66465 .48072 .67468 .49268 .69593 .4936 .68599 .48157 Metetra
.517 .707 0 r
.68599 .48157 .69593 .4936 .71745 .49459 .70759 .48249 Metetra
.629 .736 0 r
.70759 .48249 .71745 .49459 .73922 .49564 .72946 .48348 Metetra
.748 .764 0 r
.72946 .48348 .73922 .49564 .76127 .49676 .7516 .48453 Metetra
.793 .711 0 r
.7516 .48453 .76127 .49676 .78358 .49794 .77401 .48564 Metetra
.822 .634 0 r
.77401 .48564 .78358 .49794 .80618 .4992 .7967 .48683 Metetra
.851 .549 0 r
.7967 .48683 .80618 .4992 .82906 .50052 .81969 .48809 Metetra
.881 .455 0 r
.81969 .48809 .82906 .50052 .85223 .50192 .84297 .48942 Metetra
.91 .354 0 r
.84297 .48942 .85223 .50192 .8757 .50339 .86655 .49082 Metetra
.94 .244 0 r
.86655 .49082 .8757 .50339 .89948 .50493 .89044 .49229 Metetra
0 .033 .134 r
.25597 .46489 .26746 .47569 .28446 .47543 .27302 .46457 Metetra
0 .055 .158 r
.27302 .46457 .28446 .47543 .30163 .47522 .29024 .4643 Metetra
0 .083 .182 r
.29024 .4643 .30163 .47522 .31897 .47505 .30762 .46408 Metetra
0 .115 .206 r
.30762 .46408 .31897 .47505 .33649 .47493 .32519 .4639 Metetra
0 .154 .231 r
.32519 .4639 .33649 .47493 .35418 .47485 .34293 .46376 Metetra
0 .197 .255 r
.34293 .46376 .35418 .47485 .37205 .47482 .36086 .46368 Metetra
0 .247 .28 r
.36086 .46368 .37205 .47482 .39011 .47484 .37898 .46364 Metetra
0 .302 .305 r
.37898 .46364 .39011 .47484 .40836 .47492 .39728 .46365 Metetra
0 .331 .298 r
.39728 .46365 .40836 .47492 .4268 .47504 .41578 .46372 Metetra
0 .356 .281 r
.41578 .46372 .4268 .47504 .44544 .47521 .43448 .46383 Metetra
0 .382 .259 r
.43448 .46383 .44544 .47521 .46427 .47543 .45338 .46399 Metetra
0 .408 .231 r
.45338 .46399 .46427 .47543 .48331 .47571 .47248 .4642 Metetra
0 .434 .196 r
.47248 .4642 .48331 .47571 .50257 .47604 .4918 .46447 Metetra
0 .46 .156 r
.4918 .46447 .50257 .47604 .52203 .47642 .51133 .4648 Metetra
0 .487 .109 r
.51133 .4648 .52203 .47642 .54171 .47686 .53108 .46517 Metetra
0 .514 .055 r
.53108 .46517 .54171 .47686 .56162 .47736 .55106 .4656 Metetra
.005 .541 0 r
.55106 .4656 .56162 .47736 .58175 .47791 .57127 .46609 Metetra
.072 .568 0 r
.57127 .46609 .58175 .47791 .60211 .47852 .59171 .46664 Metetra
.146 .595 0 r
.59171 .46664 .60211 .47852 .62271 .47919 .61239 .46725 Metetra
.228 .623 0 r
.61239 .46725 .62271 .47919 .64356 .47992 .63331 .46791 Metetra
.316 .651 0 r
.63331 .46791 .64356 .47992 .66465 .48072 .65449 .46864 Metetra
.412 .679 0 r
.65449 .46864 .66465 .48072 .68599 .48157 .67592 .46943 Metetra
.515 .707 0 r
.67592 .46943 .68599 .48157 .70759 .48249 .69761 .47028 Metetra
.626 .735 0 r
.69761 .47028 .70759 .48249 .72946 .48348 .71957 .4712 Metetra
.745 .764 0 r
.71957 .4712 .72946 .48348 .7516 .48453 .7418 .47218 Metetra
.793 .713 0 r
.7418 .47218 .7516 .48453 .77401 .48564 .76431 .47323 Metetra
.822 .635 0 r
.76431 .47323 .77401 .48564 .7967 .48683 .7871 .47435 Metetra
.851 .55 0 r
.7871 .47435 .7967 .48683 .81969 .48809 .81019 .47553 Metetra
.88 .457 0 r
.81019 .47553 .81969 .48809 .84297 .48942 .83358 .47679 Metetra
.91 .356 0 r
.83358 .47679 .84297 .48942 .86655 .49082 .85727 .47812 Metetra
.94 .246 0 r
.85727 .47812 .86655 .49082 .89044 .49229 .88128 .47953 Metetra
0 .033 .133 r
.24433 .454 .25597 .46489 .27302 .46457 .26143 .45363 Metetra
0 .055 .157 r
.26143 .45363 .27302 .46457 .29024 .4643 .27869 .4533 Metetra
0 .082 .181 r
.27869 .4533 .29024 .4643 .30762 .46408 .29613 .45302 Metetra
0 .115 .206 r
.29613 .45302 .30762 .46408 .32519 .4639 .31375 .45278 Metetra
0 .153 .23 r
.31375 .45278 .32519 .4639 .34293 .46376 .33154 .45259 Metetra
0 .197 .255 r
.33154 .45259 .34293 .46376 .36086 .46368 .34953 .45244 Metetra
0 .246 .28 r
.34953 .45244 .36086 .46368 .37898 .46364 .36769 .45235 Metetra
0 .302 .305 r
.36769 .45235 .37898 .46364 .39728 .46365 .38606 .4523 Metetra
0 .33 .298 r
.38606 .4523 .39728 .46365 .41578 .46372 .40461 .4523 Metetra
0 .356 .282 r
.40461 .4523 .41578 .46372 .43448 .46383 .42337 .45235 Metetra
0 .382 .259 r
.42337 .45235 .43448 .46383 .45338 .46399 .44233 .45245 Metetra
0 .408 .231 r
.44233 .45245 .45338 .46399 .47248 .4642 .46151 .4526 Metetra
0 .434 .197 r
.46151 .4526 .47248 .4642 .4918 .46447 .48089 .45281 Metetra
0 .46 .156 r
.48089 .45281 .4918 .46447 .51133 .4648 .50049 .45306 Metetra
0 .487 .109 r
.50049 .45306 .51133 .4648 .53108 .46517 .52031 .45338 Metetra
0 .513 .056 r
.52031 .45338 .53108 .46517 .55106 .4656 .54036 .45375 Metetra
.004 .54 0 r
.54036 .45375 .55106 .4656 .57127 .46609 .56064 .45417 Metetra
.072 .568 0 r
.56064 .45417 .57127 .46609 .59171 .46664 .58116 .45465 Metetra
.146 .595 0 r
.58116 .45465 .59171 .46664 .61239 .46725 .60192 .45519 Metetra
.227 .622 0 r
.60192 .45519 .61239 .46725 .63331 .46791 .62293 .45579 Metetra
.315 .65 0 r
.62293 .45579 .63331 .46791 .65449 .46864 .64419 .45645 Metetra
.411 .678 0 r
.64419 .45645 .65449 .46864 .67592 .46943 .6657 .45717 Metetra
.514 .706 0 r
.6657 .45717 .67592 .46943 .69761 .47028 .68748 .45795 Metetra
.625 .735 0 r
.68748 .45795 .69761 .47028 .71957 .4712 .70954 .4588 Metetra
.744 .763 0 r
.70954 .4588 .71957 .4712 .7418 .47218 .73186 .45971 Metetra
.792 .713 0 r
.73186 .45971 .7418 .47218 .76431 .47323 .75447 .46069 Metetra
.821 .636 0 r
.75447 .46069 .76431 .47323 .7871 .47435 .77737 .46174 Metetra
.85 .551 0 r
.77737 .46174 .7871 .47435 .81019 .47553 .80056 .46285 Metetra
.88 .458 0 r
.80056 .46285 .81019 .47553 .83358 .47679 .82406 .46404 Metetra
.909 .357 0 r
.82406 .46404 .83358 .47679 .85727 .47812 .84786 .4653 Metetra
.939 .247 0 r
.84786 .4653 .85727 .47812 .88128 .47953 .87198 .46663 Metetra
0 .033 .133 r
.23255 .44303 .24433 .454 .26143 .45363 .24969 .4426 Metetra
0 .055 .157 r
.24969 .4426 .26143 .45363 .27869 .4533 .267 .44221 Metetra
0 .082 .181 r
.267 .44221 .27869 .4533 .29613 .45302 .28449 .44187 Metetra
0 .115 .206 r
.28449 .44187 .29613 .45302 .31375 .45278 .30216 .44157 Metetra
0 .153 .23 r
.30216 .44157 .31375 .45278 .33154 .45259 .32001 .44132 Metetra
0 .197 .255 r
.32001 .44132 .33154 .45259 .34953 .45244 .33804 .44111 Metetra
0 .246 .28 r
.33804 .44111 .34953 .45244 .36769 .45235 .35627 .44095 Metetra
0 .301 .305 r
.35627 .44095 .36769 .45235 .38606 .4523 .37469 .44084 Metetra
0 .33 .298 r
.37469 .44084 .38606 .4523 .40461 .4523 .3933 .44078 Metetra
0 .356 .282 r
.3933 .44078 .40461 .4523 .42337 .45235 .41212 .44077 Metetra
0 .382 .259 r
.41212 .44077 .42337 .45235 .44233 .45245 .43115 .44081 Metetra
0 .407 .231 r
.43115 .44081 .44233 .45245 .46151 .4526 .45038 .44089 Metetra
0 .434 .197 r
.45038 .44089 .46151 .4526 .48089 .45281 .46983 .44103 Metetra
0 .46 .156 r
.46983 .44103 .48089 .45281 .50049 .45306 .4895 .44123 Metetra
0 .487 .109 r
.4895 .44123 .50049 .45306 .52031 .45338 .5094 .44148 Metetra
0 .513 .056 r
.5094 .44148 .52031 .45338 .54036 .45375 .52952 .44178 Metetra
.004 .54 0 r
.52952 .44178 .54036 .45375 .56064 .45417 .54988 .44213 Metetra
.071 .567 0 r
.54988 .44213 .56064 .45417 .58116 .45465 .57047 .44255 Metetra
.145 .595 0 r
.57047 .44255 .58116 .45465 .60192 .45519 .59131 .44302 Metetra
.226 .622 0 r
.59131 .44302 .60192 .45519 .62293 .45579 .6124 .44355 Metetra
.315 .65 0 r
.6124 .44355 .62293 .45579 .64419 .45645 .63374 .44414 Metetra
.41 .678 0 r
.63374 .44414 .64419 .45645 .6657 .45717 .65535 .44479 Metetra
.514 .706 0 r
.65535 .44479 .6657 .45717 .68748 .45795 .67722 .44551 Metetra
.625 .735 0 r
.67722 .44551 .68748 .45795 .70954 .4588 .69936 .44628 Metetra
.744 .763 0 r
.69936 .44628 .70954 .4588 .73186 .45971 .72179 .44712 Metetra
.792 .714 0 r
.72179 .44712 .73186 .45971 .75447 .46069 .7445 .44803 Metetra
.821 .637 0 r
.7445 .44803 .75447 .46069 .77737 .46174 .7675 .449 Metetra
.85 .552 0 r
.7675 .449 .77737 .46174 .80056 .46285 .7908 .45005 Metetra
.88 .459 0 r
.7908 .45005 .80056 .46285 .82406 .46404 .8144 .45116 Metetra
.909 .357 0 r
.8144 .45116 .82406 .46404 .84786 .4653 .83832 .45234 Metetra
.939 .248 0 r
.83832 .45234 .84786 .4653 .87198 .46663 .86255 .4536 Metetra
0 .033 .133 r
.22061 .43196 .23255 .44303 .24969 .4426 .2378 .43147 Metetra
0 .055 .157 r
.2378 .43147 .24969 .4426 .267 .44221 .25516 .43103 Metetra
0 .082 .181 r
.25516 .43103 .267 .44221 .28449 .44187 .2727 .43062 Metetra
0 .115 .206 r
.2727 .43062 .28449 .44187 .30216 .44157 .29041 .43026 Metetra
0 .153 .23 r
.29041 .43026 .30216 .44157 .32001 .44132 .30832 .42995 Metetra
0 .197 .255 r
.30832 .42995 .32001 .44132 .33804 .44111 .32641 .42968 Metetra
0 .246 .28 r
.32641 .42968 .33804 .44111 .35627 .44095 .34469 .42946 Metetra
0 .302 .305 r
.34469 .42946 .35627 .44095 .37469 .44084 .36316 .42929 Metetra
0 .33 .298 r
.36316 .42929 .37469 .44084 .3933 .44078 .38184 .42916 Metetra
0 .356 .282 r
.38184 .42916 .3933 .44078 .41212 .44077 .40072 .42909 Metetra
0 .382 .259 r
.40072 .42909 .41212 .44077 .43115 .44081 .41981 .42906 Metetra
0 .408 .231 r
.41981 .42906 .43115 .44081 .45038 .44089 .43911 .42908 Metetra
0 .434 .197 r
.43911 .42908 .45038 .44089 .46983 .44103 .45863 .42916 Metetra
0 .46 .156 r
.45863 .42916 .46983 .44103 .4895 .44123 .47837 .42928 Metetra
0 .487 .109 r
.47837 .42928 .4895 .44123 .5094 .44148 .49833 .42946 Metetra
0 .513 .056 r
.49833 .42946 .5094 .44148 .52952 .44178 .51853 .4297 Metetra
.004 .54 0 r
.51853 .4297 .52952 .44178 .54988 .44213 .53896 .42999 Metetra
.072 .568 0 r
.53896 .42999 .54988 .44213 .57047 .44255 .55963 .43033 Metetra
.146 .595 0 r
.55963 .43033 .57047 .44255 .59131 .44302 .58055 .43073 Metetra
.227 .622 0 r
.58055 .43073 .59131 .44302 .6124 .44355 .60173 .4312 Metetra
.315 .65 0 r
.60173 .4312 .6124 .44355 .63374 .44414 .62316 .43171 Metetra
.411 .678 0 r
.62316 .43171 .63374 .44414 .65535 .44479 .64485 .43229 Metetra
.514 .706 0 r
.64485 .43229 .65535 .44479 .67722 .44551 .66681 .43294 Metetra
.625 .735 0 r
.66681 .43294 .67722 .44551 .69936 .44628 .68905 .43364 Metetra
.744 .763 0 r
.68905 .43364 .69936 .44628 .72179 .44712 .71157 .43441 Metetra
.792 .713 0 r
.71157 .43441 .72179 .44712 .7445 .44803 .73438 .43524 Metetra
.821 .636 0 r
.73438 .43524 .7445 .44803 .7675 .449 .75748 .43614 Metetra
.85 .551 0 r
.75748 .43614 .7675 .449 .7908 .45005 .78089 .4371 Metetra
.88 .458 0 r
.78089 .4371 .7908 .45005 .8144 .45116 .80461 .43814 Metetra
.909 .357 0 r
.80461 .43814 .8144 .45116 .83832 .45234 .82864 .43925 Metetra
.939 .247 0 r
.82864 .43925 .83832 .45234 .86255 .4536 .85299 .44042 Metetra
0 .033 .134 r
.20851 .42081 .22061 .43196 .2378 .43147 .22575 .42026 Metetra
0 .055 .158 r
.22575 .42026 .2378 .43147 .25516 .43103 .24316 .41975 Metetra
0 .083 .182 r
.24316 .41975 .25516 .43103 .2727 .43062 .26075 .41928 Metetra
0 .115 .206 r
.26075 .41928 .2727 .43062 .29041 .43026 .27852 .41886 Metetra
0 .154 .231 r
.27852 .41886 .29041 .43026 .30832 .42995 .29647 .41849 Metetra
0 .197 .255 r
.29647 .41849 .30832 .42995 .32641 .42968 .31462 .41815 Metetra
0 .247 .28 r
.31462 .41815 .32641 .42968 .34469 .42946 .33295 .41787 Metetra
0 .302 .305 r
.33295 .41787 .34469 .42946 .36316 .42929 .35149 .41763 Metetra
0 .331 .298 r
.35149 .41763 .36316 .42929 .38184 .42916 .37022 .41744 Metetra
0 .356 .281 r
.37022 .41744 .38184 .42916 .40072 .42909 .38917 .4173 Metetra
0 .382 .259 r
.38917 .4173 .40072 .42909 .41981 .42906 .40832 .4172 Metetra
0 .408 .231 r
.40832 .4172 .41981 .42906 .43911 .42908 .42768 .41716 Metetra
0 .434 .196 r
.42768 .41716 .43911 .42908 .45863 .42916 .44727 .41717 Metetra
0 .46 .156 r
.44727 .41717 .45863 .42916 .47837 .42928 .46708 .41723 Metetra
0 .487 .109 r
.46708 .41723 .47837 .42928 .49833 .42946 .48711 .41734 Metetra
0 .514 .055 r
.48711 .41734 .49833 .42946 .51853 .4297 .50738 .4175 Metetra
.005 .541 0 r
.50738 .4175 .51853 .4297 .53896 .42999 .52789 .41772 Metetra
.072 .568 0 r
.52789 .41772 .53896 .42999 .55963 .43033 .54865 .418 Metetra
.146 .595 0 r
.54865 .418 .55963 .43033 .58055 .43073 .56965 .41833 Metetra
.228 .623 0 r
.56965 .41833 .58055 .43073 .60173 .4312 .5909 .41872 Metetra
.316 .651 0 r
.5909 .41872 .60173 .4312 .62316 .43171 .61242 .41916 Metetra
.412 .679 0 r
.61242 .41916 .62316 .43171 .64485 .43229 .6342 .41967 Metetra
.515 .707 0 r
.6342 .41967 .64485 .43229 .66681 .43294 .65626 .42024 Metetra
.626 .735 0 r
.65626 .42024 .66681 .43294 .68905 .43364 .67859 .42087 Metetra
.745 .764 0 r
.67859 .42087 .68905 .43364 .71157 .43441 .70121 .42156 Metetra
.793 .713 0 r
.70121 .42156 .71157 .43441 .73438 .43524 .72412 .42232 Metetra
.822 .635 0 r
.72412 .42232 .73438 .43524 .75748 .43614 .74733 .42314 Metetra
.851 .55 0 r
.74733 .42314 .75748 .43614 .78089 .4371 .77084 .42403 Metetra
.88 .457 0 r
.77084 .42403 .78089 .4371 .80461 .43814 .79467 .42499 Metetra
.91 .356 0 r
.79467 .42499 .80461 .43814 .82864 .43925 .81882 .42601 Metetra
.94 .246 0 r
.81882 .42601 .82864 .43925 .85299 .44042 .84329 .42711 Metetra
0 .033 .134 r
.19626 .40956 .20851 .42081 .22575 .42026 .21354 .40894 Metetra
0 .056 .158 r
.21354 .40894 .22575 .42026 .24316 .41975 .231 .40837 Metetra
0 .083 .182 r
.231 .40837 .24316 .41975 .26075 .41928 .24864 .40784 Metetra
0 .116 .207 r
.24864 .40784 .26075 .41928 .27852 .41886 .26646 .40736 Metetra
0 .154 .231 r
.26646 .40736 .27852 .41886 .29647 .41849 .28447 .40692 Metetra
0 .198 .256 r
.28447 .40692 .29647 .41849 .31462 .41815 .30267 .40652 Metetra
0 .248 .281 r
.30267 .40652 .31462 .41815 .33295 .41787 .32106 .40617 Metetra
0 .303 .306 r
.32106 .40617 .33295 .41787 .35149 .41763 .33965 .40587 Metetra
0 .331 .297 r
.33965 .40587 .35149 .41763 .37022 .41744 .35845 .40561 Metetra
0 .357 .281 r
.35845 .40561 .37022 .41744 .38917 .4173 .37745 .4054 Metetra
0 .382 .259 r
.37745 .4054 .38917 .4173 .40832 .4172 .39667 .40524 Metetra
0 .408 .23 r
.39667 .40524 .40832 .4172 .42768 .41716 .4161 .40513 Metetra
0 .435 .196 r
.4161 .40513 .42768 .41716 .44727 .41717 .43575 .40507 Metetra
0 .461 .155 r
.43575 .40507 .44727 .41717 .46708 .41723 .45563 .40506 Metetra
0 .487 .108 r
.45563 .40506 .46708 .41723 .48711 .41734 .47574 .4051 Metetra
0 .514 .054 r
.47574 .4051 .48711 .41734 .50738 .4175 .49609 .40519 Metetra
.006 .541 0 r
.49609 .40519 .50738 .4175 .52789 .41772 .51667 .40534 Metetra
.074 .568 0 r
.51667 .40534 .52789 .41772 .54865 .418 .5375 .40554 Metetra
.148 .596 0 r
.5375 .40554 .54865 .418 .56965 .41833 .55859 .4058 Metetra
.229 .623 0 r
.55859 .4058 .56965 .41833 .5909 .41872 .57993 .40612 Metetra
.318 .651 0 r
.57993 .40612 .5909 .41872 .61242 .41916 .60153 .40649 Metetra
.414 .679 0 r
.60153 .40649 .61242 .41916 .6342 .41967 .6234 .40692 Metetra
.517 .707 0 r
.6234 .40692 .6342 .41967 .65626 .42024 .64555 .40741 Metetra
.629 .736 0 r
.64555 .40741 .65626 .42024 .67859 .42087 .66798 .40796 Metetra
.748 .764 0 r
.66798 .40796 .67859 .42087 .70121 .42156 .6907 .40858 Metetra
.793 .711 0 r
.6907 .40858 .70121 .42156 .72412 .42232 .71371 .40926 Metetra
.822 .634 0 r
.71371 .40926 .72412 .42232 .74733 .42314 .73702 .41 Metetra
.851 .549 0 r
.73702 .41 .74733 .42314 .77084 .42403 .76065 .41081 Metetra
.881 .455 0 r
.76065 .41081 .77084 .42403 .79467 .42499 .78459 .41169 Metetra
.91 .354 0 r
.78459 .41169 .79467 .42499 .81882 .42601 .80885 .41264 Metetra
.94 .244 0 r
.80885 .41264 .81882 .42601 .84329 .42711 .83345 .41365 Metetra
0 .034 .135 r
.18385 .39821 .19626 .40956 .21354 .40894 .20117 .39753 Metetra
0 .056 .159 r
.20117 .39753 .21354 .40894 .231 .40837 .21868 .3969 Metetra
0 .084 .183 r
.21868 .3969 .231 .40837 .24864 .40784 .23637 .39631 Metetra
0 .117 .207 r
.23637 .39631 .24864 .40784 .26646 .40736 .25424 .39576 Metetra
0 .156 .232 r
.25424 .39576 .26646 .40736 .28447 .40692 .2723 .39525 Metetra
0 .2 .257 r
.2723 .39525 .28447 .40692 .30267 .40652 .29056 .39479 Metetra
0 .249 .281 r
.29056 .39479 .30267 .40652 .32106 .40617 .30901 .39437 Metetra
0 .305 .307 r
.30901 .39437 .32106 .40617 .33965 .40587 .32766 .394 Metetra
0 .332 .297 r
.32766 .394 .33965 .40587 .35845 .40561 .34651 .39368 Metetra
0 .357 .28 r
.34651 .39368 .35845 .40561 .37745 .4054 .36558 .3934 Metetra
0 .383 .258 r
.36558 .3934 .37745 .4054 .39667 .40524 .38486 .39317 Metetra
0 .409 .229 r
.38486 .39317 .39667 .40524 .4161 .40513 .40436 .39298 Metetra
0 .435 .195 r
.40436 .39298 .4161 .40513 .43575 .40507 .42408 .39285 Metetra
0 .462 .154 r
.42408 .39285 .43575 .40507 .45563 .40506 .44403 .39277 Metetra
0 .488 .106 r
.44403 .39277 .45563 .40506 .47574 .4051 .46421 .39274 Metetra
0 .515 .052 r
.46421 .39274 .47574 .4051 .49609 .40519 .48463 .39276 Metetra
.008 .542 0 r
.48463 .39276 .49609 .40519 .51667 .40534 .50529 .39284 Metetra
.075 .569 0 r
.50529 .39284 .51667 .40534 .5375 .40554 .5262 .39296 Metetra
.15 .596 0 r
.5262 .39296 .5375 .40554 .55859 .4058 .54737 .39315 Metetra
.231 .624 0 r
.54737 .39315 .55859 .4058 .57993 .40612 .56879 .39339 Metetra
.32 .652 0 r
.56879 .39339 .57993 .40612 .60153 .40649 .59048 .39368 Metetra
.416 .68 0 r
.59048 .39368 .60153 .40649 .6234 .40692 .61245 .39404 Metetra
.52 .708 0 r
.61245 .39404 .6234 .40692 .64555 .40741 .63469 .39445 Metetra
.631 .736 0 r
.63469 .39445 .64555 .40741 .66798 .40796 .65722 .39493 Metetra
.751 .765 0 r
.65722 .39493 .66798 .40796 .6907 .40858 .68003 .39546 Metetra
.794 .709 0 r
.68003 .39546 .6907 .40858 .71371 .40926 .70315 .39606 Metetra
.823 .632 0 r
.70315 .39606 .71371 .40926 .73702 .41 .72657 .39672 Metetra
.852 .547 0 r
.72657 .39672 .73702 .41 .76065 .41081 .7503 .39745 Metetra
.881 .453 0 r
.7503 .39745 .76065 .41081 .78459 .41169 .77436 .39825 Metetra
.911 .351 0 r
.77436 .39825 .78459 .41169 .80885 .41264 .79874 .39911 Metetra
.941 .241 0 r
.79874 .39911 .80885 .41264 .83345 .41365 .82345 .40004 Metetra
0 .035 .136 r
.17126 .38676 .18385 .39821 .20117 .39753 .18864 .38602 Metetra
0 .057 .16 r
.18864 .38602 .20117 .39753 .21868 .3969 .20619 .38532 Metetra
0 .085 .184 r
.20619 .38532 .21868 .3969 .23637 .39631 .22393 .38467 Metetra
0 .118 .208 r
.22393 .38467 .23637 .39631 .25424 .39576 .24186 .38405 Metetra
0 .157 .233 r
.24186 .38405 .25424 .39576 .2723 .39525 .25997 .38348 Metetra
0 .201 .257 r
.25997 .38348 .2723 .39525 .29056 .39479 .27828 .38295 Metetra
0 .251 .282 r
.27828 .38295 .29056 .39479 .30901 .39437 .29679 .38246 Metetra
0 .307 .307 r
.29679 .38246 .30901 .39437 .32766 .394 .3155 .38202 Metetra
0 .333 .297 r
.3155 .38202 .32766 .394 .34651 .39368 .33441 .38163 Metetra
0 .358 .28 r
.33441 .38163 .34651 .39368 .36558 .3934 .35354 .38128 Metetra
0 .384 .257 r
.35354 .38128 .36558 .3934 .38486 .39317 .37288 .38098 Metetra
0 .41 .228 r
.37288 .38098 .38486 .39317 .40436 .39298 .39245 .38072 Metetra
0 .436 .193 r
.39245 .38072 .40436 .39298 .42408 .39285 .41224 .38052 Metetra
0 .463 .152 r
.41224 .38052 .42408 .39285 .44403 .39277 .43226 .38036 Metetra
0 .489 .105 r
.43226 .38036 .44403 .39277 .46421 .39274 .45251 .38026 Metetra
0 .516 .051 r
.45251 .38026 .46421 .39274 .48463 .39276 .47301 .38021 Metetra
.01 .543 0 r
.47301 .38021 .48463 .39276 .50529 .39284 .49375 .38021 Metetra
.078 .57 0 r
.49375 .38021 .50529 .39284 .5262 .39296 .51474 .38026 Metetra
.152 .597 0 r
.51474 .38026 .5262 .39296 .54737 .39315 .53599 .38036 Metetra
.234 .625 0 r
.53599 .38036 .54737 .39315 .56879 .39339 .5575 .38053 Metetra
.323 .653 0 r
.5575 .38053 .56879 .39339 .59048 .39368 .57928 .38075 Metetra
.42 .681 0 r
.57928 .38075 .59048 .39368 .61245 .39404 .60133 .38102 Metetra
.523 .709 0 r
.60133 .38102 .61245 .39404 .63469 .39445 .62367 .38136 Metetra
.635 .737 0 r
.62367 .38136 .63469 .39445 .65722 .39493 .64629 .38175 Metetra
.755 .766 0 r
.64629 .38175 .65722 .39493 .68003 .39546 .66921 .3822 Metetra
.795 .707 0 r
.66921 .3822 .68003 .39546 .70315 .39606 .69243 .38272 Metetra
.824 .629 0 r
.69243 .38272 .70315 .39606 .72657 .39672 .71596 .3833 Metetra
.853 .544 0 r
.71596 .3833 .72657 .39672 .7503 .39745 .7398 .38395 Metetra
.882 .45 0 r
.7398 .38395 .7503 .39745 .77436 .39825 .76397 .38466 Metetra
.912 .348 0 r
.76397 .38466 .77436 .39825 .79874 .39911 .78847 .38543 Metetra
.942 .238 0 r
.78847 .38543 .79874 .39911 .82345 .40004 .81331 .38628 Metetra
0 .036 .137 r
.15851 .37522 .17126 .38676 .18864 .38602 .17593 .37441 Metetra
0 .059 .161 r
.17593 .37441 .18864 .38602 .20619 .38532 .19354 .37364 Metetra
0 .087 .185 r
.19354 .37364 .20619 .38532 .22393 .38467 .21133 .37292 Metetra
0 .12 .209 r
.21133 .37292 .22393 .38467 .24186 .38405 .2293 .37223 Metetra
0 .159 .234 r
.2293 .37223 .24186 .38405 .25997 .38348 .24747 .37159 Metetra
0 .204 .259 r
.24747 .37159 .25997 .38348 .27828 .38295 .26583 .37099 Metetra
0 .254 .283 r
.26583 .37099 .27828 .38295 .29679 .38246 .2844 .37044 Metetra
0 .309 .307 r
.2844 .37044 .29679 .38246 .3155 .38202 .30317 .36993 Metetra
0 .334 .296 r
.30317 .36993 .3155 .38202 .33441 .38163 .32214 .36946 Metetra
0 .359 .279 r
.32214 .36946 .33441 .38163 .35354 .38128 .34133 .36904 Metetra
0 .385 .256 r
.34133 .36904 .35354 .38128 .37288 .38098 .36074 .36867 Metetra
0 .411 .227 r
.36074 .36867 .37288 .38098 .39245 .38072 .38037 .36834 Metetra
0 .437 .192 r
.38037 .36834 .39245 .38072 .41224 .38052 .40023 .36806 Metetra
0 .464 .15 r
.40023 .36806 .41224 .38052 .43226 .38036 .42032 .36783 Metetra
0 .49 .102 r
.42032 .36783 .43226 .38036 .45251 .38026 .44065 .36765 Metetra
0 .517 .048 r
.44065 .36765 .45251 .38026 .47301 .38021 .46122 .36752 Metetra
.013 .544 0 r
.46122 .36752 .47301 .38021 .49375 .38021 .48204 .36745 Metetra
.081 .571 0 r
.48204 .36745 .49375 .38021 .51474 .38026 .50311 .36742 Metetra
.156 .598 0 r
.50311 .36742 .51474 .38026 .53599 .38036 .52444 .36745 Metetra
.238 .626 0 r
.52444 .36745 .53599 .38036 .5575 .38053 .54604 .36753 Metetra
.327 .654 0 r
.54604 .36753 .5575 .38053 .57928 .38075 .56791 .36767 Metetra
.424 .682 0 r
.56791 .36767 .57928 .38075 .60133 .38102 .59005 .36787 Metetra
.528 .71 0 r
.59005 .36787 .60133 .38102 .62367 .38136 .61248 .36812 Metetra
.64 .738 0 r
.61248 .36812 .62367 .38136 .64629 .38175 .63521 .36843 Metetra
.759 .767 0 r
.63521 .36843 .64629 .38175 .66921 .3822 .65823 .3688 Metetra
.796 .704 0 r
.65823 .3688 .66921 .3822 .69243 .38272 .68155 .36923 Metetra
.825 .626 0 r
.68155 .36923 .69243 .38272 .71596 .3833 .70519 .36973 Metetra
.854 .54 0 r
.70519 .36973 .71596 .3833 .7398 .38395 .72915 .37029 Metetra
.883 .446 0 r
.72915 .37029 .7398 .38395 .76397 .38466 .75343 .37091 Metetra
.913 .344 0 r
.75343 .37091 .76397 .38466 .78847 .38543 .77805 .3716 Metetra
.943 .234 0 r
.77805 .3716 .78847 .38543 .81331 .38628 .80302 .37236 Metetra
0 .037 .138 r
.14559 .36357 .15851 .37522 .17593 .37441 .16306 .36269 Metetra
0 .06 .162 r
.16306 .36269 .17593 .37441 .19354 .37364 .18071 .36186 Metetra
0 .088 .186 r
.18071 .36186 .19354 .37364 .21133 .37292 .19855 .36106 Metetra
0 .122 .211 r
.19855 .36106 .21133 .37292 .2293 .37223 .21657 .36031 Metetra
0 .161 .235 r
.21657 .36031 .2293 .37223 .24747 .37159 .23479 .3596 Metetra
0 .206 .26 r
.23479 .3596 .24747 .37159 .26583 .37099 .25321 .35893 Metetra
0 .257 .285 r
.25321 .35893 .26583 .37099 .2844 .37044 .27183 .3583 Metetra
0 .31 .307 r
.27183 .3583 .2844 .37044 .30317 .36993 .29066 .35772 Metetra
0 .335 .295 r
.29066 .35772 .30317 .36993 .32214 .36946 .3097 .35718 Metetra
0 .361 .278 r
.3097 .35718 .32214 .36946 .34133 .36904 .32895 .35669 Metetra
0 .387 .254 r
.32895 .35669 .34133 .36904 .36074 .36867 .34842 .35624 Metetra
0 .412 .225 r
.34842 .35624 .36074 .36867 .38037 .36834 .36812 .35584 Metetra
0 .439 .19 r
.36812 .35584 .38037 .36834 .40023 .36806 .38805 .35548 Metetra
0 .465 .148 r
.38805 .35548 .40023 .36806 .42032 .36783 .40821 .35518 Metetra
0 .492 .1 r
.40821 .35518 .42032 .36783 .44065 .36765 .42861 .35492 Metetra
0 .518 .045 r
.42861 .35492 .44065 .36765 .46122 .36752 .44926 .35471 Metetra
.016 .545 0 r
.44926 .35471 .46122 .36752 .48204 .36745 .47015 .35455 Metetra
.084 .572 0 r
.47015 .35455 .48204 .36745 .50311 .36742 .49131 .35445 Metetra
.159 .6 0 r
.49131 .35445 .50311 .36742 .52444 .36745 .51272 .3544 Metetra
.242 .627 0 r
.51272 .3544 .52444 .36745 .54604 .36753 .53441 .3544 Metetra
.331 .655 0 r
.53441 .3544 .54604 .36753 .56791 .36767 .55637 .35446 Metetra
.428 .683 0 r
.55637 .35446 .56791 .36767 .59005 .36787 .57861 .35457 Metetra
.533 .711 0 r
.57861 .35457 .59005 .36787 .61248 .36812 .60113 .35474 Metetra
.645 .74 0 r
.60113 .35474 .61248 .36812 .63521 .36843 .62395 .35496 Metetra
.765 .768 0 r
.62395 .35496 .63521 .36843 .65823 .3688 .64708 .35525 Metetra
.797 .701 0 r
.64708 .35525 .65823 .3688 .68155 .36923 .67051 .35559 Metetra
.826 .623 0 r
.67051 .35559 .68155 .36923 .70519 .36973 .69426 .356 Metetra
.855 .536 0 r
.69426 .356 .70519 .36973 .72915 .37029 .71833 .35647 Metetra
.885 .442 0 r
.71833 .35647 .72915 .37029 .75343 .37091 .74273 .35701 Metetra
.914 .339 0 r
.74273 .35701 .75343 .37091 .77805 .3716 .76747 .35761 Metetra
.944 .229 0 r
.76747 .35761 .77805 .3716 .80302 .37236 .79256 .35827 Metetra
0 .038 .14 r
.13248 .35181 .14559 .36357 .16306 .36269 .15 .35087 Metetra
0 .062 .164 r
.15 .35087 .16306 .36269 .18071 .36186 .1677 .34996 Metetra
0 .09 .188 r
.1677 .34996 .18071 .36186 .19855 .36106 .18559 .3491 Metetra
0 .124 .212 r
.18559 .3491 .19855 .36106 .21657 .36031 .20367 .34827 Metetra
0 .164 .237 r
.20367 .34827 .21657 .36031 .23479 .3596 .22194 .34749 Metetra
0 .209 .261 r
.22194 .34749 .23479 .3596 .25321 .35893 .24041 .34675 Metetra
0 .26 .286 r
.24041 .34675 .25321 .35893 .27183 .3583 .25909 .34605 Metetra
0 .311 .306 r
.25909 .34605 .27183 .3583 .29066 .35772 .27798 .34539 Metetra
0 .337 .294 r
.27798 .34539 .29066 .35772 .3097 .35718 .29708 .34478 Metetra
0 .362 .277 r
.29708 .34478 .3097 .35718 .32895 .35669 .31639 .34421 Metetra
0 .388 .253 r
.31639 .34421 .32895 .35669 .34842 .35624 .33593 .34368 Metetra
0 .414 .223 r
.33593 .34368 .34842 .35624 .36812 .35584 .35569 .3432 Metetra
0 .44 .187 r
.35569 .3432 .36812 .35584 .38805 .35548 .37569 .34277 Metetra
0 .467 .145 r
.37569 .34277 .38805 .35548 .40821 .35518 .39592 .34239 Metetra
0 .493 .097 r
.39592 .34239 .40821 .35518 .42861 .35492 .4164 .34205 Metetra
0 .52 .042 r
.4164 .34205 .42861 .35492 .44926 .35471 .43712 .34176 Metetra
.02 .547 0 r
.43712 .34176 .44926 .35471 .47015 .35455 .4581 .34153 Metetra
.088 .574 0 r
.4581 .34153 .47015 .35455 .49131 .35445 .47933 .34134 Metetra
.164 .601 0 r
.47933 .34134 .49131 .35445 .51272 .3544 .50083 .34121 Metetra
.246 .629 0 r
.50083 .34121 .51272 .3544 .53441 .3544 .5226 .34112 Metetra
.336 .657 0 r
.5226 .34112 .53441 .3544 .55637 .35446 .54465 .3411 Metetra
.434 .685 0 r
.54465 .3411 .55637 .35446 .57861 .35457 .56699 .34112 Metetra
.539 .713 0 r
.56699 .34112 .57861 .35457 .60113 .35474 .58961 .34121 Metetra
.651 .741 0 r
.58961 .34121 .60113 .35474 .62395 .35496 .61253 .34135 Metetra
.77 .768 0 r
.61253 .34135 .62395 .35496 .64708 .35525 .63576 .34154 Metetra
.799 .697 0 r
.63576 .34154 .64708 .35525 .67051 .35559 .65929 .3418 Metetra
.828 .618 0 r
.65929 .3418 .67051 .35559 .69426 .356 .68315 .34212 Metetra
.857 .532 0 r
.68315 .34212 .69426 .356 .71833 .35647 .70734 .3425 Metetra
.886 .437 0 r
.70734 .3425 .71833 .35647 .74273 .35701 .73186 .34294 Metetra
.916 .334 0 r
.73186 .34294 .74273 .35701 .76747 .35761 .75672 .34345 Metetra
.946 .223 0 r
.75672 .34345 .76747 .35761 .79256 .35827 .78194 .34402 Metetra
0 .04 .142 r
.11919 .33994 .13248 .35181 .15 .35087 .13676 .33893 Metetra
0 .064 .165 r
.13676 .33893 .15 .35087 .1677 .34996 .15451 .33795 Metetra
0 .093 .19 r
.15451 .33795 .1677 .34996 .18559 .3491 .17245 .33702 Metetra
0 .127 .214 r
.17245 .33702 .18559 .3491 .20367 .34827 .19058 .33612 Metetra
0 .167 .238 r
.19058 .33612 .20367 .34827 .22194 .34749 .2089 .33526 Metetra
0 .212 .263 r
.2089 .33526 .22194 .34749 .24041 .34675 .22743 .33445 Metetra
0 .264 .288 r
.22743 .33445 .24041 .34675 .25909 .34605 .24617 .33367 Metetra
0 .313 .306 r
.24617 .33367 .25909 .34605 .27798 .34539 .26511 .33294 Metetra
0 .339 .293 r
.26511 .33294 .27798 .34539 .29708 .34478 .28427 .33225 Metetra
0 .364 .275 r
.28427 .33225 .29708 .34478 .31639 .34421 .30365 .3316 Metetra
0 .39 .251 r
.30365 .3316 .31639 .34421 .33593 .34368 .32325 .331 Metetra
0 .416 .221 r
.32325 .331 .33593 .34368 .35569 .3432 .34308 .33044 Metetra
0 .442 .185 r
.34308 .33044 .35569 .3432 .37569 .34277 .36315 .32993 Metetra
0 .468 .142 r
.36315 .32993 .37569 .34277 .39592 .34239 .38345 .32947 Metetra
0 .495 .094 r
.38345 .32947 .39592 .34239 .4164 .34205 .404 .32905 Metetra
0 .522 .038 r
.404 .32905 .4164 .34205 .43712 .34176 .4248 .32868 Metetra
.024 .549 0 r
.4248 .32868 .43712 .34176 .4581 .34153 .44586 .32836 Metetra
.093 .576 0 r
.44586 .32836 .4581 .34153 .47933 .34134 .46718 .32809 Metetra
.169 .603 0 r
.46718 .32809 .47933 .34134 .50083 .34121 .48876 .32787 Metetra
.252 .631 0 r
.48876 .32787 .50083 .34121 .5226 .34112 .51062 .3277 Metetra
.342 .658 0 r
.51062 .3277 .5226 .34112 .54465 .3411 .53276 .32759 Metetra
.44 .686 0 r
.53276 .32759 .54465 .3411 .56699 .34112 .55519 .32753 Metetra
.545 .715 0 r
.55519 .32753 .56699 .34112 .58961 .34121 .57791 .32752 Metetra
.658 .743 0 r
.57791 .32752 .58961 .34121 .61253 .34135 .60093 .32757 Metetra
.772 .764 0 r
.60093 .32757 .61253 .34135 .63576 .34154 .62426 .32768 Metetra
.8 .692 0 r
.62426 .32768 .63576 .34154 .65929 .3418 .64791 .32785 Metetra
.829 .613 0 r
.64791 .32785 .65929 .3418 .68315 .34212 .67188 .32807 Metetra
.859 .526 0 r
.67188 .32807 .68315 .34212 .70734 .3425 .69618 .32836 Metetra
.888 .431 0 r
.69618 .32836 .70734 .3425 .73186 .34294 .72082 .3287 Metetra
.918 .328 0 r
.72082 .3287 .73186 .34294 .75672 .34345 .74581 .32912 Metetra
.947 .216 0 r
.74581 .32912 .75672 .34345 .78194 .34402 .77115 .32959 Metetra
0 .041 .144 r
.10572 .32796 .11919 .33994 .13676 .33893 .12333 .32688 Metetra
0 .066 .167 r
.12333 .32688 .13676 .33893 .15451 .33795 .14113 .32583 Metetra
0 .095 .192 r
.14113 .32583 .15451 .33795 .17245 .33702 .15912 .32482 Metetra
0 .13 .216 r
.15912 .32482 .17245 .33702 .19058 .33612 .1773 .32385 Metetra
0 .17 .24 r
.1773 .32385 .19058 .33612 .2089 .33526 .19568 .32292 Metetra
0 .216 .265 r
.19568 .32292 .2089 .33526 .22743 .33445 .21426 .32202 Metetra
0 .268 .29 r
.21426 .32202 .22743 .33445 .24617 .33367 .23306 .32117 Metetra
0 .315 .305 r
.23306 .32117 .24617 .33367 .26511 .33294 .25206 .32036 Metetra
0 .34 .292 r
.25206 .32036 .26511 .33294 .28427 .33225 .27128 .3196 Metetra
0 .366 .274 r
.27128 .3196 .28427 .33225 .30365 .3316 .29072 .31887 Metetra
0 .392 .249 r
.29072 .31887 .30365 .3316 .32325 .331 .31039 .31819 Metetra
0 .418 .219 r
.31039 .31819 .32325 .331 .34308 .33044 .33029 .31755 Metetra
0 .444 .182 r
.33029 .31755 .34308 .33044 .36315 .32993 .35042 .31696 Metetra
0 .47 .139 r
.35042 .31696 .36315 .32993 .38345 .32947 .3708 .31641 Metetra
0 .497 .09 r
.3708 .31641 .38345 .32947 .404 .32905 .39142 .31591 Metetra
0 .524 .034 r
.39142 .31591 .404 .32905 .4248 .32868 .4123 .31546 Metetra
.029 .55 0 r
.4123 .31546 .4248 .32868 .44586 .32836 .43344 .31505 Metetra
.098 .578 0 r
.43344 .31505 .44586 .32836 .46718 .32809 .45484 .31469 Metetra
.174 .605 0 r
.45484 .31469 .46718 .32809 .48876 .32787 .47651 .31439 Metetra
.258 .633 0 r
.47651 .31439 .48876 .32787 .51062 .3277 .49845 .31413 Metetra
.349 .66 0 r
.49845 .31413 .51062 .3277 .53276 .32759 .52069 .31393 Metetra
.447 .688 0 r
.52069 .31393 .53276 .32759 .55519 .32753 .54321 .31378 Metetra
.553 .717 0 r
.54321 .31378 .55519 .32753 .57791 .32752 .56603 .31368 Metetra
.666 .745 0 r
.56603 .31368 .57791 .32752 .60093 .32757 .58915 .31364 Metetra
.774 .759 0 r
.58915 .31364 .60093 .32757 .62426 .32768 .61259 .31366 Metetra
.802 .687 0 r
.61259 .31366 .62426 .32768 .64791 .32785 .63634 .31373 Metetra
.831 .608 0 r
.63634 .31373 .64791 .32785 .67188 .32807 .66042 .31386 Metetra
.861 .52 0 r
.66042 .31386 .67188 .32807 .69618 .32836 .68484 .31405 Metetra
.89 .425 0 r
.68484 .31405 .69618 .32836 .72082 .3287 .7096 .3143 Metetra
.92 .321 0 r
.7096 .3143 .72082 .3287 .74581 .32912 .73472 .31461 Metetra
.949 .208 0 r
.73472 .31461 .74581 .32912 .77115 .32959 .76019 .31499 Metetra
0 .043 .146 r
.09206 .31587 .10572 .32796 .12333 .32688 .10971 .31471 Metetra
0 .068 .17 r
.10971 .31471 .12333 .32688 .14113 .32583 .12756 .31359 Metetra
0 .098 .194 r
.12756 .31359 .14113 .32583 .15912 .32482 .1456 .3125 Metetra
0 .133 .218 r
.1456 .3125 .15912 .32482 .1773 .32385 .16383 .31146 Metetra
0 .174 .243 r
.16383 .31146 .1773 .32385 .19568 .32292 .18226 .31045 Metetra
0 .22 .267 r
.18226 .31045 .19568 .32292 .21426 .32202 .2009 .30948 Metetra
0 .272 .292 r
.2009 .30948 .21426 .32202 .23306 .32117 .21975 .30855 Metetra
0 .317 .304 r
.21975 .30855 .23306 .32117 .25206 .32036 .23882 .30766 Metetra
0 .343 .291 r
.23882 .30766 .25206 .32036 .27128 .3196 .2581 .30681 Metetra
0 .368 .272 r
.2581 .30681 .27128 .3196 .29072 .31887 .2776 .306 Metetra
0 .394 .247 r
.2776 .306 .29072 .31887 .31039 .31819 .29733 .30524 Metetra
0 .42 .216 r
.29733 .30524 .31039 .31819 .33029 .31755 .3173 .30452 Metetra
0 .446 .179 r
.3173 .30452 .33029 .31755 .35042 .31696 .33751 .30384 Metetra
0 .472 .135 r
.33751 .30384 .35042 .31696 .3708 .31641 .35795 .30321 Metetra
0 .499 .086 r
.35795 .30321 .3708 .31641 .39142 .31591 .37865 .30263 Metetra
0 .526 .029 r
.37865 .30263 .39142 .31591 .4123 .31546 .39961 .30209 Metetra
.034 .553 0 r
.39961 .30209 .4123 .31546 .43344 .31505 .42082 .30159 Metetra
.104 .58 0 r
.42082 .30159 .43344 .31505 .45484 .31469 .44231 .30115 Metetra
.181 .607 0 r
.44231 .30115 .45484 .31469 .47651 .31439 .46406 .30075 Metetra
.265 .635 0 r
.46406 .30075 .47651 .31439 .49845 .31413 .4861 .30041 Metetra
.356 .662 0 r
.4861 .30041 .49845 .31413 .52069 .31393 .50842 .30011 Metetra
.455 .69 0 r
.50842 .30011 .52069 .31393 .54321 .31378 .53104 .29987 Metetra
.561 .719 0 r
.53104 .29987 .54321 .31378 .56603 .31368 .55396 .29968 Metetra
.675 .747 0 r
.55396 .29968 .56603 .31368 .58915 .31364 .57719 .29954 Metetra
.776 .754 0 r
.57719 .29954 .58915 .31364 .61259 .31366 .60073 .29946 Metetra
.804 .682 0 r
.60073 .29946 .61259 .31366 .63634 .31373 .62459 .29944 Metetra
.833 .602 0 r
.62459 .29944 .63634 .31373 .66042 .31386 .64879 .29947 Metetra
.863 .513 0 r
.64879 .29947 .66042 .31386 .68484 .31405 .67332 .29956 Metetra
.892 .417 0 r
.67332 .29956 .68484 .31405 .7096 .3143 .69821 .29971 Metetra
.922 .313 0 r
.69821 .29971 .7096 .3143 .73472 .31461 .72345 .29992 Metetra
.951 .2 0 r
.72345 .29992 .73472 .31461 .76019 .31499 .74905 .3002 Metetra
0 .046 .148 r
.0782 .30366 .09206 .31587 .10971 .31471 .0959 .30242 Metetra
0 .071 .172 r
.0959 .30242 .10971 .31471 .12756 .31359 .11379 .30123 Metetra
0 .101 .196 r
.11379 .30123 .12756 .31359 .1456 .3125 .13188 .30006 Metetra
0 .137 .22 r
.13188 .30006 .1456 .3125 .16383 .31146 .15017 .29894 Metetra
0 .178 .245 r
.15017 .29894 .16383 .31146 .18226 .31045 .16865 .29785 Metetra
0 .225 .27 r
.16865 .29785 .18226 .31045 .2009 .30948 .18735 .2968 Metetra
0 .278 .294 r
.18735 .2968 .2009 .30948 .21975 .30855 .20625 .29579 Metetra
0 .32 .303 r
.20625 .29579 .21975 .30855 .23882 .30766 .22537 .29482 Metetra
0 .345 .289 r
.22537 .29482 .23882 .30766 .2581 .30681 .24472 .29389 Metetra
0 .37 .27 r
.24472 .29389 .2581 .30681 .2776 .306 .26428 .293 Metetra
0 .396 .244 r
.26428 .293 .2776 .306 .29733 .30524 .28408 .29216 Metetra
0 .422 .213 r
.28408 .29216 .29733 .30524 .3173 .30452 .30412 .29135 Metetra
0 .448 .175 r
.30412 .29135 .3173 .30452 .33751 .30384 .32439 .29059 Metetra
0 .475 .131 r
.32439 .29059 .33751 .30384 .35795 .30321 .34491 .28987 Metetra
0 .501 .081 r
.34491 .28987 .35795 .30321 .37865 .30263 .36569 .2892 Metetra
0 .528 .024 r
.36569 .2892 .37865 .30263 .39961 .30209 .38672 .28857 Metetra
.04 .555 0 r
.38672 .28857 .39961 .30209 .42082 .30159 .40802 .28799 Metetra
.11 .582 0 r
.40802 .28799 .42082 .30159 .44231 .30115 .42958 .28745 Metetra
.188 .609 0 r
.42958 .28745 .44231 .30115 .46406 .30075 .45143 .28696 Metetra
.272 .637 0 r
.45143 .28696 .46406 .30075 .4861 .30041 .47355 .28653 Metetra
.364 .665 0 r
.47355 .28653 .4861 .30041 .50842 .30011 .49597 .28614 Metetra
.463 .693 0 r
.49597 .28614 .50842 .30011 .53104 .29987 .51868 .2858 Metetra
.57 .721 0 r
.51868 .2858 .53104 .29987 .55396 .29968 .5417 .28551 Metetra
.685 .749 0 r
.5417 .28551 .55396 .29968 .57719 .29954 .56503 .28528 Metetra
.778 .748 0 r
.56503 .28528 .57719 .29954 .60073 .29946 .58868 .2851 Metetra
.807 .675 0 r
.58868 .2851 .60073 .29946 .62459 .29944 .61265 .28498 Metetra
.836 .595 0 r
.61265 .28498 .62459 .29944 .64879 .29947 .63696 .28491 Metetra
.865 .506 0 r
.63696 .28491 .64879 .29947 .67332 .29956 .66162 .2849 Metetra
.894 .409 0 r
.66162 .2849 .67332 .29956 .69821 .29971 .68663 .28495 Metetra
.924 .304 0 r
.68663 .28495 .69821 .29971 .72345 .29992 .71199 .28505 Metetra
.954 .191 0 r
.71199 .28505 .72345 .29992 .74905 .3002 .73773 .28522 Metetra
0 .048 .151 r
.06414 .29133 .0782 .30366 .0959 .30242 .08189 .29002 Metetra
0 .074 .174 r
.08189 .29002 .0959 .30242 .11379 .30123 .09983 .28874 Metetra
0 .105 .199 r
.09983 .28874 .11379 .30123 .13188 .30006 .11796 .2875 Metetra
0 .141 .223 r
.11796 .2875 .13188 .30006 .15017 .29894 .1363 .28629 Metetra
0 .183 .247 r
.1363 .28629 .15017 .29894 .16865 .29785 .15484 .28513 Metetra
0 .23 .272 r
.15484 .28513 .16865 .29785 .18735 .2968 .17359 .28399 Metetra
0 .283 .297 r
.17359 .28399 .18735 .2968 .20625 .29579 .19255 .2829 Metetra
0 .322 .302 r
.19255 .2829 .20625 .29579 .22537 .29482 .21173 .28185 Metetra
0 .348 .288 r
.21173 .28185 .22537 .29482 .24472 .29389 .23114 .28084 Metetra
0 .373 .267 r
.23114 .28084 .24472 .29389 .26428 .293 .25077 .27986 Metetra
0 .399 .241 r
.25077 .27986 .26428 .293 .28408 .29216 .27063 .27893 Metetra
0 .425 .209 r
.27063 .27893 .28408 .29216 .30412 .29135 .29073 .27804 Metetra
0 .451 .171 r
.29073 .27804 .30412 .29135 .32439 .29059 .31108 .27719 Metetra
0 .477 .127 r
.31108 .27719 .32439 .29059 .34491 .28987 .33167 .27638 Metetra
0 .504 .076 r
.33167 .27638 .34491 .28987 .36569 .2892 .35252 .27561 Metetra
0 .531 .018 r
.35252 .27561 .36569 .2892 .38672 .28857 .37363 .2749 Metetra
.046 .557 0 r
.37363 .2749 .38672 .28857 .40802 .28799 .39501 .27422 Metetra
.117 .585 0 r
.39501 .27422 .40802 .28799 .42958 .28745 .41666 .27359 Metetra
.195 .612 0 r
.41666 .27359 .42958 .28745 .45143 .28696 .43859 .27301 Metetra
.28 .64 0 r
.43859 .27301 .45143 .28696 .47355 .28653 .46081 .27248 Metetra
.373 .667 0 r
.46081 .27248 .47355 .28653 .49597 .28614 .48332 .27199 Metetra
.473 .695 0 r
.48332 .27199 .49597 .28614 .51868 .2858 .50613 .27156 Metetra
.58 .724 0 r
.50613 .27156 .51868 .2858 .5417 .28551 .52925 .27118 Metetra
.696 .752 0 r
.52925 .27118 .5417 .28551 .56503 .28528 .55268 .27084 Metetra
.781 .742 0 r
.55268 .27084 .56503 .28528 .58868 .2851 .57643 .27056 Metetra
.809 .669 0 r
.57643 .27056 .58868 .2851 .61265 .28498 .60052 .27034 Metetra
.838 .587 0 r
.60052 .27034 .61265 .28498 .63696 .28491 .62495 .27016 Metetra
.868 .498 0 r
.62495 .27016 .63696 .28491 .66162 .2849 .64972 .27005 Metetra
.897 .401 0 r
.64972 .27005 .66162 .2849 .68663 .28495 .67485 .26999 Metetra
.927 .295 0 r
.67485 .26999 .68663 .28495 .71199 .28505 .70035 .26999 Metetra
.956 .181 0 r
.70035 .26999 .71199 .28505 .73773 .28522 .72622 .27005 Metetra
0 .051 .153 r
.04987 .27887 .06414 .29133 .08189 .29002 .06767 .27748 Metetra
0 .077 .177 r
.06767 .27748 .08189 .29002 .09983 .28874 .08565 .27612 Metetra
0 .109 .201 r
.08565 .27612 .09983 .28874 .11796 .2875 .10384 .2748 Metetra
0 .145 .226 r
.10384 .2748 .11796 .2875 .1363 .28629 .12223 .27352 Metetra
0 .188 .25 r
.12223 .27352 .1363 .28629 .15484 .28513 .14082 .27227 Metetra
0 .236 .275 r
.14082 .27227 .15484 .28513 .17359 .28399 .15963 .27105 Metetra
0 .29 .3 r
.15963 .27105 .17359 .28399 .19255 .2829 .17865 .26988 Metetra
0 .325 .301 r
.17865 .26988 .19255 .2829 .21173 .28185 .19789 .26874 Metetra
0 .35 .286 r
.19789 .26874 .21173 .28185 .23114 .28084 .21735 .26764 Metetra
0 .376 .265 r
.21735 .26764 .23114 .28084 .25077 .27986 .23704 .26658 Metetra
0 .402 .238 r
.23704 .26658 .25077 .27986 .27063 .27893 .25697 .26555 Metetra
0 .427 .206 r
.25697 .26555 .27063 .27893 .29073 .27804 .27714 .26457 Metetra
0 .454 .167 r
.27714 .26457 .29073 .27804 .31108 .27719 .29756 .26363 Metetra
0 .48 .122 r
.29756 .26363 .31108 .27719 .33167 .27638 .31823 .26273 Metetra
0 .507 .07 r
.31823 .26273 .33167 .27638 .35252 .27561 .33915 .26188 Metetra
0 .533 .012 r
.33915 .26188 .35252 .27561 .37363 .2749 .36034 .26107 Metetra
.053 .56 0 r
.36034 .26107 .37363 .2749 .39501 .27422 .3818 .2603 Metetra
.125 .587 0 r
.3818 .2603 .39501 .27422 .41666 .27359 .40353 .25957 Metetra
.203 .615 0 r
.40353 .25957 .41666 .27359 .43859 .27301 .42555 .2589 Metetra
.289 .642 0 r
.42555 .2589 .43859 .27301 .46081 .27248 .44786 .25827 Metetra
.382 .67 0 r
.44786 .25827 .46081 .27248 .48332 .27199 .47046 .25768 Metetra
.483 .698 0 r
.47046 .25768 .48332 .27199 .50613 .27156 .49337 .25715 Metetra
.591 .726 0 r
.49337 .25715 .50613 .27156 .52925 .27118 .51659 .25666 Metetra
.707 .755 0 r
.51659 .25666 .52925 .27118 .55268 .27084 .54013 .25623 Metetra
.783 .736 0 r
.54013 .25623 .55268 .27084 .57643 .27056 .56399 .25584 Metetra
.812 .661 0 r
.56399 .25584 .57643 .27056 .60052 .27034 .58819 .25551 Metetra
.841 .579 0 r
.58819 .25551 .60052 .27034 .62495 .27016 .61273 .25523 Metetra
.87 .489 0 r
.61273 .25523 .62495 .27016 .64972 .27005 .63763 .25501 Metetra
.9 .391 0 r
.63763 .25501 .64972 .27005 .67485 .26999 .66288 .25484 Metetra
.929 .285 0 r
.66288 .25484 .67485 .26999 .70035 .26999 .68851 .25473 Metetra
.959 .17 0 r
.68851 .25473 .70035 .26999 .72622 .27005 .71452 .25468 Metetra
0 .054 .156 r
.03539 .26629 .04987 .27887 .06767 .27748 .05323 .26482 Metetra
0 .081 .18 r
.05323 .26482 .06767 .27748 .08565 .27612 .07127 .26338 Metetra
0 .113 .204 r
.07127 .26338 .08565 .27612 .10384 .2748 .08951 .26197 Metetra
0 .15 .229 r
.08951 .26197 .10384 .2748 .12223 .27352 .10794 .2606 Metetra
0 .193 .253 r
.10794 .2606 .12223 .27352 .14082 .27227 .12659 .25927 Metetra
0 .242 .278 r
.12659 .25927 .14082 .27227 .15963 .27105 .14545 .25797 Metetra
0 .296 .303 r
.14545 .25797 .15963 .27105 .17865 .26988 .16453 .25671 Metetra
0 .328 .299 r
.16453 .25671 .17865 .26988 .19789 .26874 .18383 .25548 Metetra
0 .353 .284 r
.18383 .25548 .19789 .26874 .21735 .26764 .20335 .25429 Metetra
0 .379 .262 r
.20335 .25429 .21735 .26764 .23704 .26658 .22311 .25314 Metetra
0 .404 .235 r
.22311 .25314 .23704 .26658 .25697 .26555 .2431 .25203 Metetra
0 .43 .201 r
.2431 .25203 .25697 .26555 .27714 .26457 .26334 .25096 Metetra
0 .457 .162 r
.26334 .25096 .27714 .26457 .29756 .26363 .28383 .24993 Metetra
0 .483 .116 r
.28383 .24993 .29756 .26363 .31823 .26273 .30457 .24893 Metetra
0 .509 .064 r
.30457 .24893 .31823 .26273 .33915 .26188 .32557 .24798 Metetra
0 .536 .005 r
.32557 .24798 .33915 .26188 .36034 .26107 .34684 .24708 Metetra
.06 .563 0 r
.34684 .24708 .36034 .26107 .3818 .2603 .36838 .24621 Metetra
.133 .59 0 r
.36838 .24621 .3818 .2603 .40353 .25957 .3902 .24539 Metetra
.212 .618 0 r
.3902 .24539 .40353 .25957 .42555 .2589 .4123 .24461 Metetra
.299 .645 0 r
.4123 .24461 .42555 .2589 .44786 .25827 .4347 .24388 Metetra
.393 .673 0 r
.4347 .24388 .44786 .25827 .47046 .25768 .4574 .24319 Metetra
.494 .701 0 r
.4574 .24319 .47046 .25768 .49337 .25715 .4804 .24256 Metetra
.603 .729 0 r
.4804 .24256 .49337 .25715 .51659 .25666 .50372 .24197 Metetra
.72 .758 0 r
.50372 .24197 .51659 .25666 .54013 .25623 .52736 .24143 Metetra
.786 .728 0 r
.52736 .24143 .54013 .25623 .56399 .25584 .55134 .24093 Metetra
.815 .653 0 r
.55134 .24093 .56399 .25584 .58819 .25551 .57565 .24049 Metetra
.844 .57 0 r
.57565 .24049 .58819 .25551 .61273 .25523 .60031 .24011 Metetra
.873 .48 0 r
.60031 .24011 .61273 .25523 .63763 .25501 .62533 .23977 Metetra
.903 .381 0 r
.62533 .23977 .63763 .25501 .66288 .25484 .65071 .23949 Metetra
.932 .274 0 r
.65071 .23949 .66288 .25484 .68851 .25473 .67647 .23927 Metetra
.962 .158 0 r
.67647 .23927 .68851 .25473 .71452 .25468 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-0.5)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.4)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(-0.3)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(-0.2)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(-0.1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00_?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0005Ko
oooo002kooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0EOooool00;Cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0EOooool00;_ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`1Eooooo`00^oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo05Gooooo002kooooo`04o`000?ooooooooooo`0000So
oooo0_l0000;ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0003gooooo002looooo`;o
00002_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo0000?Oooool00<cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool0?Oooool00=?ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0l
ooooo`00doooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000?Ooo
ool00=?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000003gooooo
0038ooooo`;o00002_ooool2o`0000Wooooo0ol0000nooooo`00aOooool3o`000003ooooool0003o
000005Gooooo0033ooooo`;o00001?ooool2o`0005Gooooo0030ooooo`?o00001_ooool00ol0003o
ooooo`00001Dooooo`00_Oooool3o`000003ooooool0003ooooo00Kooooo00?o0000ooooool00000
E?ooool0097ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00006oooool2o`0000cooooo
00Co0000oooooooooooo0000Doooool0093ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool0000Hooooo`?o00003_ooool00ol0003oooooooooo`02o`0005;ooooo0029ooooo`Go
00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo01Kooooo0_l000000ooo
oooo0000ooooo`0>ooooo`05o`000?ooooooooooooooool00000D_ooool0093ooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`0Booooo`?o00004oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo04oooooo002@ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000@ooooo`?o00005_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04kooooo002@ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00000>ooooo`Co00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo
002Aooooo`;o00002Oooool3o`0000cooooo0ol0000Looooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0COooool00:Wooooo0_l0000Oooooo`03o`000?oooooooooo00?ooooo0_l0001>
ooooo`00Y_ooool4o`00023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<oooo
o`00Xoooool3o`0002Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`00
XOooool2o`0002Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1:ooooo`00W_oo
ool3o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1:ooooo`00W?ooool2
o`0000?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`07ooooo`;o0000B_ooool0
09Wooooo0ol0000^ooooo`03o`000?oooooooooo00Oooooo0_l0001:ooooo`00Uoooool2o`00037o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`18ooooo`00U?ooool3o`0000;ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Oooooo
001Yooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00006_ooool3o`0003Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`16ooooo`00J?ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000005oooool2o`0003Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`16ooooo`00HOooool5o`0000;ooooo00Co0000oooooooooooo0000
2oooool00ol0003oooooooooo`0Booooo`?o00000_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00[ooooo0_l0000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
:oooool006Sooooo00Co0000oooooooooooo00002Oooool2o`0001?ooooo0_l0000nooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo02[ooooo001Xooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooooooo
ool03Oooool3o`00043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`Go
00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo02[ooooo001Xooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`?o00000_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo02[ooooo001Yooooo`;o00002Oooool3
o`0000_ooooo0_l00016ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo02[ooooo001oooooo`?o0000B?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?oo
ool2o`0002cooooo001mooooo`;o00000oooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo00gooooo0_l0000:ooooo`;o00002_ooool00ol0003oooooooooo`0Zooooo`00N_ooool3o`00
04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`10ooooo`00N?ooool3o`00053o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`10ooooo`00MOooool3o`0000?ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03oooooo
001booooo`?o0000E_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03kooooo001`
ooooo`Co0000Eoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03kooooo0014oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00006_ooool3o`0005_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0mooooo`00@oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo01Oooooo0_l0001Nooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0??ooool003cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Oooooo1Ol0000Eoooo
o`Co0000Goooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03cooooo0013ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00004oooool3o`0006?ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0kooooo`00@oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo0000017ooooo0_l0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0>_ooool004?ooooo00Co0000oooooooooooo00002Oooool2o`0000kooooo0ol00000
0ooooooo0000ooooo`1Uooooo`03o`000?oooooooooo01Cooooo0_l0000looooo`00A?ooool2o`00
00_ooooo00?o0000ooooooooool02_ooool2o`0006_ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0iooooo`00Foooool3o`0006gooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0hooooo`00F?ooool3o`0000;ooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo03Sooooo001Fooooo`;o0000Loooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo03Oooooo001Cooooo`?o0000MOooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooo000003Sooooo001Aooooo`;o00000oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0=_ooool004kooooo0ol0001jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0=Oooool004cooooo1?l0001looooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0=?ooool0027ooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo0ol0000Jooooo`?o0000P?ooool00ol0003oooooooooo`0Jooooo`;o00001ooo
ool2o`0002cooooo000Pooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00000Fooooo`?o0000Poooool00ol0003oooooooooo`0Jooooo`;o00001_ooool01?l0003ooooo
ooooool0000[ooooo`006Oooool5o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`0Booooo`;o000000?oooooo`000?l00000Poooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000:oooool0023ooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`0?ooooo`?o0000R?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000:oooool0023ooooo00Co0000oooo
oooooooo00001oooool4o`00013ooooo0ol0002:ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000[ooooo`008?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00kooooo0ol00002ooooo`03o`000?oooooooooo08Sooooo00?o
0000ooooooooool07Oooool2o`0000?ooooo00Co0000oooooooooooo0000:oooool0027ooooo0_l0
0008ooooo`Go00002Oooool3o`00063ooooo<Ol0000Nooooo`03o`000?oooooo000000Cooooo0_l0
000/ooooo`00=oooool2o`000003ooooool0003o0000047ooooo7ol00003oiZj0003o`000?nh`P3o
^<8000;o^<8000?o0000olVj0?o9^P000_o9^P000ol0003od:L0om2W0003om2W0003o`000?oHT@3o
f94000Cof94000?o0000ommj0?oONP000_oONP000ol0003oif40onMQ0003onMQ0003o`000?o^AP3o
kTH000?okTH000Co0000ooHX0?of:03omRP00ol0000Pooooo`03o`000?oooooooooo02oooooo000d
ooooo`?o0000;_oooolHo`0000;o3i0000?o0000ob:G0?lRU`000olRU`000ol0003o=Yh0ocJN0003
ocJN0003o`000?m<Y@3oC:D000;oC:D000?o0000ofB/0?mT[0000_mT[0000ol0003oO[<0ogjc0002
ogjc0003o`000?nJ^P3oV[X000?oV[X000?o0000okS20?nh`P000_nh`P000ol0003obKX0olVj0002
olVj0003o`000?o@Y`3od:L000?od:L000?o0000omRA0?oHT@001?oHT@000ol0003oggX0ommj0002
ommj0003o`000?oWH@3oif4000?oif4000?o0000oni60?o^AP000oo^AP03o`000004ooHX0?l0003o
mRP0o`0001oooooo00?o0000ooooooooool0;oooool003?ooooo0_l0000Rooooo`ko00000_l0KS<0
0ol0003o07@Yo`1d:@03o`1d:@03o`000?l0Nago07/M00;o07/M00?o0000o`224?l0PQ000_l0PQ00
0ol0003o08T1o`290@02o`290@05o`000?l?T03o3i00o`n@0?l000001OlRU`000ol0003o=Yh0ocJN
0003ocJN0003o`000?m<Y@3oC:D000;oC:D000?o0000ofB/0?mT[0000_mT[0000ol0003oO[<0ogjc
0002ogjc0003o`000?nJ^P3oV[X000;oV[X000?o0000okS20?nh`P000onh`P000ol0003obKX0olVj
0002olVj0003o`000?o@Y`3od:L000?od:L000Co0000omRA0?oHT@3of9406ol0000Oooooo`03o`00
0?oooooooooo02kooooo000cooooo`?o00004?oooolAo`0000Co05Y800Go0000o`1Q@ol0HD?o0653
o`000004o`1W?005o`000?l0KS?o06hco`1^<ol000001Ol0M2T00ol0003o07/Mo`1k7@02o`1k7@03
o`000?l0PQ3o088@00;o088@00?o0000o`290Ol0R@400_l0R@401Ol0003o3i00o`n@0?l?T03o0000
00?o8YL0<?l00003omND0003o`000?oNO@3ogWd000;ogWd000?o0000onIT0?oVI0000_oVI003o`00
00CokDP000?o0000ooD[0?oe:`000_oe:`02o`00023ooooo00?o0000ooooooooool0;Oooool003?o
oooo00Co0000oooooooooooo00000_ooool=o`0000?o035000Go0000o`0mAol0?DOo03e7o`000004
o`1;C@05o`000?l0Ddco05=<o`1CC?l000001Ol0FTP01Ol0003o0653o`1Q@ol0HD?o000000Co06Ll
00Go0000o`1^<ol0KS?o06hco`000003o`1d:ASo00000_lOUP000ol0003o<id0oc>M0003oc>M0003
o`000?m9Y03oBJ@000?oBJ@000?o0000of6[0?mQZ`000_mQZ`000ol0003oNk80og^b0002og^b0003
o`000?nG^@3oUkT000;oUkT000?o0000okC10?nd`@000ond`@000ol0003ob;`0olRl0002olRl0003
o`000?o?Z@3ocjT000?ocjT000?o0000omND0?oGU0000ooGU0000ol0003ogWd0omim0002omim00Co
00000_oVI0000ol0003okDP0one80003one80003o`000?oe:`3omB/000;omB/00_l0000Nooooo`;o
0000;oooool003?ooooo1_l00003o`0D;P03o`000?l073Co01`d00;o01`d00Go0000o`0V>_l09S[o
02Hjo`000004o`0a@005o`000?l0?DOo03e7o`0mAol000001?l0Bdd01Ol0003o05=<o`1CC?l0Ddco
000000?o05Y84_l00002o`1d:P03o`000?l0NQoo07XO00?o07XO00?o0000o`214Ol0PA400_l0PA40
0ol0003o08P3o`280`02o`280`03o`000?l=S`3o3Hl000;o3Hl000Go0000oanF0?lOUP3o7iH0o`00
0005oc>M0003o`000?m9Y03oBJ@000?oBJ@000?o0000of6[0?mQZ`000_mQZ`000ol0003oNk80og^b
0002og^b0003o`000?nG^@3oUkT000;oUkT000?o0000okC10?nd`@000ond`@000ol0003ob;`0olRl
0002olRl0003o`000?o?Z@3ocjT000?ocjT000?o0000omND0?oGU0000_oGU0000ol0003ogWd0omim
0004o`0000GoiV@000?o0000one80?o]B0000oo]B0001ol0003omB/0ooD[0?oe:`3o0000ooD[0?l0
00007oooool00ol0003oooooooooo`0/ooooo`00<_ooool3o`0000?o00dW00?o0000o`0D;_l052h0
0_l052h00ol0003o01`do`0L=002o`0L=005o`000?l09S[o02Hjo`0V>_l000000_l0<D0Bo`0000?o
05U900Go0000o`1P@ol0H4?o0613o`000004o`1V?003o`000?l0KCCo06dd00;o06dd00Go0000o`1d
:_l0M2[o07@Zo`000005o`1j7`03o`000?l0PA7o084A00;o084A00?o0000o`280ol0R0<00_l0R0<0
0ol0003o3Hl0o`f?0002o`f?0005o`000?lOUP3o7iH0oanF0?l000001OlcW@001?l0003oBJ@0odVT
0?m9Y010o`0001oooooo00?o0000ooooooooool0:oooool003;ooooo00Co0000oooooooooooo0000
0ol03BL00ol0003o01@^o`0D;P0=o`0000?o030o00?o0000o`0lA_l0?4H00_l0?4H01Ol0003o04Y<
o`1:C?l0BTco000000?o05==00?o0000o`1IBOl0FDT00ol0FDT01Ol0003o0613o`1P@ol0H4?o0000
00Co06Hl00?o0000o`1]=?l0KC@00_l0KC@01Ol0003o07@Zo`1d:_l0M2[o000000?o07XO7_l00002
odNS0003o`000?mOZP3oGjX000;oGjX000?o0000ogVa0?mi/@000omi/@000ol0003oU;T0oiBi0002
oiBi0003o`000?nb`03o//0000?o//0000?o0000olNm0?o7_@000_o7_@000ol0003ocj/0oln[0003
oln[00?o00000_oFUP000ol0003ogWl0omio0003omio0003o`000?oUIP3oiFH000?oiFH000?o0000
one;0?o]B`000_o]B`000ol0003om2h0oo@^0002oo@^00;o00007oooool00ol0003oooooooooo`0[
ooooo`00<_ooool01?l0003oooooooooooooool6o`0000Co01<]00Go0000o`0K<ol06c?o01/co`00
0003o`0U>@03o`000?l0<3oo030o00;o030o00?o0000o`0lA_l0?4H00_l0?4H01Ol0003o04Y<o`1:
C?l0BTco000000?o05==00Co0000o`1IBOl0FDWo05U95ol00003o`1j8003o`000?l0PA?o084C00;o
084C00?o0000o`271?l0Q`@00_l0Q`@01Ol0003o2hh0o`^>0?l;SP3o000000Co7ID000?o0000oc6L
0?laW0000_laW0000ol0003oAj<0odNS0003odNS0003o`000?mOZP3oGjX000;oGjX000?o0000ogVa
0?mi/@000omi/@000ol0003oU;T0oiBi0002oiBi0003o`000?nb`03o//0000?o//0000?o0000olNm
0?o7_@000_o7_@000ol0003ocj/0oln[0002o`000003oln[0?l0003oeYH000?oeYH000?o0000omio
0?oNO`000ooNO`000ol0003oiFH0onEV0003onEV0003o`000?o]B`3okD/000;okD/000?o0000oo@^
0?od;P000_od;P02o`0001kooooo0_l0000/ooooo`00<_ooool2o`0000?ooooo00?o0000o`0=9ol0
3BL00_l03BL00ol0003o01<]o`0C;@02o`0C;@05o`000?l06c?o01/co`0K<ol000000ol09CT00ol0
003o030oo`0`?`0Bo`0000?o05U900Go0000o`1OA?l0GdCo05m4o`000004o`1V?@03o`000?l0K3Go
06`e00;o06`e00Go0000o`1c:ol0Lb_o07<[o`000005o`1j8003o`000?l0PA?o084C00;o084C00?o
0000o`271?l0Q`@00_l0Q`@01Ol0003o2hh0o`^>0?l;SP3o000000Co7ID000?o0000oc6L0?laW000
0_laW0000ol0003oAj<0odNS0003odNS0003o`000?mOZP3oGjX000;oGjX000Co0000ogVa0?mi/@3o
NK40=Ol0000Oooooo`03o`000?oooooooooo02Wooooo000booooo`03o`000?oooooooooo00?ooooo
00?o0000o`0=9ol03BL04Ol00003o`0^?`03o`000?l0>TGo03Y500;o03Y500Go0000o`18C?l0B4co
04Q<o`000003o`1BC@03o`000?l0FDWo05U900?o05U900Go0000o`1OA?l0GdCo05m4o`000004o`1V
?@03o`000?l0K3Go06`e00;o06`e00Go0000o`1c:ol0Lb_o07<[o`000003o`1j82So00000_mf/@00
0ol0003oTKP0oi6h0002oi6h0003o`000?n__`3o[kl000?o[kl01?l000000oo7_`3o0000olj/0004
olj/0003o`000?oFV03oeYP000;oeYP000?o0000omf10?oMP@000ooMP@000ol0003oi6P0onAX0003
onAX0003o`000?o/C@3ok4d000;ok4d000?o0000oo@`0?od<0000_od<002o`0001oooooo00?o0000
ooooooooool0:Oooool003;ooooo00?o0000ooooooooool01?ooool2o`0000Co00`V00Go0000o`0B
;?l04Rco018/o`000003o`0J<P05o`000?l093Wo02@io`0T>Ol000001?l0;Sl00ol0003o03Y5o`0j
A@02o`0jA@05o`000?l0B4co04Q<o`18C?l000000ol0DTd01?l0003o05U9o`1IBOl0FDTGo`0000?o
07TQ00?o0000o`205?l0P1@00_l0P1@00ol0003o08L6o`271P02o`271P05o`000?l:SP3o2Xh0o`Z>
0?l000001?lLU0000ol0003o<9/0oc2K0002oc2K0003o`000?m5X`3oAJ<000;oAJ<000?o0000oefZ
0?mMZP000omMZP000ol0003oM[40ogJa0002ogJa0003o`000?nA^03oTKP000;oTKP000?o0000ojno
0?n__`001?l00004olNo0003o`000?o>[03ocZ`000?ocZ`000?o0000omJH0?oFV0000_oFV0000ol0
003ogH40omf10003omf10003o`000?oTJ03oi6P000?oi6P000?o0000ona=0?o/C@000_o/C@000ol0
003om300oo@`0002oo@`00;o00007oooool00ol0003oooooooooo`0Xooooo`00<_ooool00ol0003o
ooooooooo`06ooooo`03o`000?l032Ko00`V00;o00`V00Go0000o`0B;?l04Rco018/o`000003o`0J
<P05o`000?l093Wo02@io`0T>Ol000000_l0;SlBo`0000?o05Q900?o0000o`1NAOl0GTD00_l0GTD0
1Ol0003o06Dno`1U?_l0ICko000000Co06`f00Go0000o`1b;?l0LRco078/o`000005o`1i8@03o`00
0?l0P1Co080D00;o080D00?o0000o`271_l0Q`H00_l0Q`H01Ol0003o2Xh0o`Z>0?l:SP3o000000Co
79@000?o0000oc2K0?l`V`000_l`V`000ol0003oAJ<0odFS0002odFS0003o`000?mMZP3oGJX000?o
GJX000?o0000ogJa0?mf/@000_mf/@001?l0003oTKP0oi6h0?nA^003o`0000?o[kl000?o0000olNo
0?o7_`000oo7_`000ol0003ocZ`0olj/0002olj/0003o`000?oFV03oeYP000?oeYP000?o0000omf1
0?oMP@000ooMP@000ol0003oi6P0onAX0002onAX0003o`000?o/C@3ok4d000?ok4d000Oo0000oo@`
0?od<03om300o`000?od<03o000001oooooo00?o0000ooooooooool09oooool0037ooooo0_l00009
ooooo`03o`000?l032Ko00`V013o00001?l0;Ch01Ol0003o03U5o`0iAOl0>DGo000000?o04M;00?o
0000o`1ACOl0DDd00_l0DDd00ol0003o05Q9o`1HB@02o`1HB@03o`000?l0GTGo05i500;o05i500Go
0000o`1U?_l0ICko06Dno`000004o`1/=P05o`000?l0LRco078/o`1b;?l000000ol0NB5Mo`0001go
oooo0_l0000Yooooo`00<Oooool00ol0003oooooooooo`09ooooo`;o00000ol02bD01Ol0003o018/
o`0B;?l04Rco000000?o01Tb00?o0000o`0S>?l08cP00_l08cP00ol0003o02dno`0]?P02o`0]?P05
o`000?l0>DGo03U5o`0iAOl000000ol0Ad/00ol0003o055=o`1AC@02o`1AC@03o`000?l0F4Wo05Q9
01Oo00000_l0N2800ol0003o07lFo`1o5P03o`1o5P05o`000?l0QPOo08H7o`261ol000001?l8S@00
0ol0003o6Y@0oaZD0002oaZD0003o`000?l^V`3o;Y/000;o;Y/000?o0000od>R0?m3XP000_m3XP00
0ol0003oFjT0oe^Y0002oe^Y0003o`000?md/03o000000;o000000?oM;00o`000?n?^0000on?^000
0ol0003o[;l0ojbo0002ojbo0003o`000?o6`@3oa/4000?oa/4000?o0000olf^0?o=[P000_o=[P00
0ol0003oeIX0omFJ0003omFJ0003o`000?oLP`3og8<000;og8<000?o0000onAZ0?oTJP000ooTJP00
0ol0003ok500ona@0003ona@0007o`000?oc<`3olc<0oo<c0?l0003olc<0o`00000Nooooo`03o`00
0?oooooooooo02Kooooo000aooooo`03o`000?oooooooooo00_ooooo00Go0000o`0;9Ol02bGo00/U
o`000003o`0B;005o`000?l06C;o01Tbo`0I<_l000000_l08cPFo`0000?o05M:00?o0000o`1NAOl0
GTD00_l0GTD01Ol0003o06@oo`1T?ol0I3oo000000Co06/g00Go0000o`1b;Ol0LRgo078]o`000004
o`1h8P03o`000?l0OaKo07lF00?o07lF00Go0000o`261ol0QPOo08H7o`000004o`R=0003o`000?lJ
U03o6Y@000;o6Y@000?o0000objK0?l^V`000_l^V`000ol0003o@j80od>R0002od>R0003o`000?mK
Z@3oFjT000?o00001Omd/0000ol0003oSkP0ohnh0002ohnh0003o`000?n/_`3o[;l000;o[;l000?o
0000olK10?o6`@000oo6`@000ol0003ocJh0olf^0002olf^0003o`000?oEVP3oeIX000?oeIX000?o
0000omb30?oLP`000_oLP`000ol0003oi6X0onAZ0003onAZ0003o`000?o/D03ok50000?ok50000Oo
0000oo<c0?oc<`3olc<0o`000?oc<`3o000001kooooo00?o0000ooooooooool09Oooool0037ooooo
0_l0000=ooooo`ko00000ol08SL00ol0003o02`no`0/?P02o`0/?P05o`000?l0>4Co03Q4o`0hA?l0
00000ol0ADX00ol0003o055=o`1AC@03o`1AC@05o`000?l0Ed[o05M:o`1GB_l000001?l0GTD01Ol0
003o06@oo`1T?ol0I3oo000000Co06/g00Go0000o`1b;Ol0LRgo078]o`000004o`1h8P04o`000?l0
OaKo07lFo`1o5USo00007Oooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00004Oooool000_ooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0ol00004ooooo`03o`000?oooooooooo00gooooo00Go
0000o`0;9Ol02bGo00/Uo`000003o`0A:`03o`000?l06C7o01Ta00;o01Ta00Go0000o`0R=ol08SOo
028go`000004o`0/?P05o`000?l0>4Co03Q4o`0hA?l000000ol0ADX01?l0003o055=o`1ACOl0DDdP
o`0000?o07lG00Go0000o`262?l0QPSo08H8o`000004o`N<0003o`000?lIT`3o6I<000;o6I<000?o
0000obbJ0?l/VP000_l/VP04o`000003od:R0?l0003oFJP000?oFJP000?o0000og:`0?mb/0000_mb
/0000ol0003oSKL0ohfg0003ohfg0003o`000?nZ_P3oZ[h000;oZ[h000?o0000olK20?o6`P000_o6
`P000ol0003ocJl0olf_0003olf_0003o`000?oDV`3oe9/000;oe9/000?o0000omb50?oLQ@000ooL
Q@000ol0003ohf`0on=/0002on=/0003o`000?o[DP3oje8000?oje8000Oo0000oo8e0?ob=@3olSD0
o`000?ob=@3o000001gooooo0_l00006ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool04?ooool000cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00kooooo00Go0000o`0;9Ol02bGo00/Uo`000003o`0A:`03o`00
0?l06C7o01Ta01Ko00000ol0D4h01Ol0003o05M:o`1GB_l0Ed[o000000?o05e600?o0000o`1T?ol0
I3l00_l0I3l00ol0003o06/ho`1[>002o`1[>005o`000?l0LBko074^o`1a;_l000001?l0N2<00ol0
003o07lGo`1o5`03o`1o5`05o`000?l0QPSo08H8o`262?l000001?l7S0000ol0003o6I<0oaVC0002
oaVC0003o`000?l/VP3o000000?o00001?m2XP000ol0003oFJP0oeVX0002oeVX0003o`000?mb/03o
L[0000;oL[0000?o0000ohfg0?n=]`000on=]`000ol0003oZ[h0ojZn0002ojZn0003o`000?o6`P3o
a/8000;oa/8000?o0000olf_0?o=[`000oo=[`000ol0003oe9/0omBK0002omBK0003o`000?oLQ@3o
g8D000?og8D000?o0000on=/0?oSK0000_oSK0000ol0003oje80on]B0003on]B0007o`000?ob=@3o
lSD0oo8e0?l0003olSD0o`00000Nooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`0@ooooo`003?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003o
oooo00Go00001?ooool00ol0003oooooooooo`0?ooooo`[o00000ol063401Ol0003o024go`0Q=ol0
8COo000000Co02/m00Go0000o`0g@ol0=d?o03M3o`000003o`14BP03o`000?l0D4ko051>00?o051>
00Go0000o`1GB_l0Ed[o05M:o`000003o`1MAP03o`000?l0I3oo06@o00;o06@o00?o0000o`1[>?l0
JcP00_l0JcP01Ol0003o074^o`1a;_l0LBko000000Co07PS00Co0000o`1o5ol0OaOo07lGE_l0000N
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`0@ooooo`003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Aooooo`05o`000?l02RCo00XTo`0:9?l000001?l042X0
1Ol0003o01Pao`0H<Ol0637o000000?o024g00?o0000o`0[?Ol0:cd00_l0:cd01Ol0003o03M3o`0g
@ol0=d?o000000?o04A:00Co0000o`1@C_l0D4ko051>8?l00002o`1n6003o`000?l0Q@Wo08D900;o
08D900Co0000o`J<0?l6S03o1X`00ol00003oaNC0003o`000?l[VP3o:iX000;o:iX000?o0000od2Q
0?m0X@000_m0X@000ol0003oEjP0oeNX0002oeNX0003o`000?m`[`3oL:l000;oL:l000?o0000oh^g
0?n;]`000_n;]`000ol0003oZ;h0ojRn0003ojRn0003o`000?o5``3oaL<000;oaL<000?o0000olba
0?o</@000_o</@000ol0003oe9`0omBL0003omBL0003o`000?oKQP3ofhH000;ofhH000?o0000on=^
0?oSKP000_oSKP000ol0003oje<0on]C0003on]C0004o`000?ob=`3olSL0oo8g00?o00007_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool04?oo
ool000cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`03
o`000?oooooooooo01;ooooo00Go0000o`0:9?l02RCo00XTo`000002o`0@:Q[o00000ol0D4h01Ol0
003o05I;o`1FBol0ET_o000000?o05e600?o0000o`1S@?l0Hd000_l0Hd001Ol0003o06Xho`1Z>?l0
JSSo000000Co074_00?o0000o`1g9?l0Mb@00_l0Mb@00ol0003o07hHo`1n6002o`1n6003o`000?l0
Q@Wo08D900;o08D90ol00002o`J<0003o`000?lGT`3o5i<000;o5i<000?o0000ob^J0?l[VP000_l[
VP000ol0003o@:40od2Q0002od2Q0003o`000?mGZ03oEjP000;oEjP000?o0000og2_0?m`[`000_m`
[`000ol0003oRkL0oh^g0002oh^g0003o`000?nX_P3oZ;h000?oZ;h000?o0000olG30?o5``000_o5
``000ol0003oc;40olba0002olba0003o`000?oDW03oe9`000?oe9`000?o0000om^60?oKQP000_oK
QP000ol0003ohfh0on=^0002on=^0003o`000?o[D`3oje<000?oje<000Oo0000oo8g0?ob=`3olSL0
o`000?ob=`3o000001kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00Kooooo0_l0000Booooo`002oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l00004ooooo`03o`000?oo
oooooooo01?ooooo1_l00003o`0@:P05o`000?l05c3o01L`o`0G<?l000000ol083H00ol0003o02Xl
o`0Z?002o`0Z?005o`000?l0=T?o03I3o`0f@ol000001?l0@dT00ol0003o051>o`1@CP02o`1@CP05
o`000?l0ET_o05I;o`1FBol000000ol0GDH00ol0003o06=0o`1S@002o`1S@005o`000?l0JSSo06Xh
o`1Z>?l000001?l0LBl00ol0003o07LTo`1g9002o`1g9003o`000?l0OQSo07hH04Go00001OoSKP00
0ol0003oje<0on]C0003on]C0007o`000?ob=`3olSL0oo8g0?l0003olSL0o`00000Looooo`;o0000
1?ooool2o`0000[ooooo00?o0000ooooooooool04?ooool000cooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`;o00005Ooo
ool00ol0003o00XTo`0:9002o`0:9005o`000?l042[o010Zo`0@:_l000000ol05c001Ol0003o020f
o`0P=_l083Ko000000Co02Xl00Go0000o`0f@ol0=T?o03I3o`000002o`13BBSo00001?l0Q@X00ol0
003o1H`0o`F<0002o`F<0003o`000?lFTP3o5Y8000;o5Y8000?o0000obVI0?lYV@000_lYV@000ol0
003o?Z40ocjQ0002ocjQ0003o`000?mFZ03oEZP000;oEZP000?o0000ofn_0?m_[`000_m_[`000ol0
003oRKH0ohVf0002ohVf0003o`000?nV_@3oY[d000;oY[d000?o0000olG40?o5a0000_o5a0000ol0
003oc;80olbb0002olbb0003o`000?oCWP3odih000?odih000Co0000om^80?oKR03ofhP05?l0000M
ooooo`03o`000?oooooooooo023ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000o`0:
9?l02R@06Ol00003o`12B@03o`000?l0Cdko04m>00;o04m>00Go0000o`1FBol0ET_o05I;o`000003
o`1LAP03o`000?l0Hd3o06=000;o06=000Go0000o`1Y>Ol0JCWo06Tio`000004o`1`;`04o`000?l0
MbGo07LUo`1g9@?o00000ol0OQP00ol0003o08D:o`252P02o`252P03o`000?l5S03o1H`000;o1H`0
00?o0000oaJB0?lFTP000_lFTP000ol0003o:IT0obVI0002obVI0003o`000?lnX@3o?Z4000;o?Z40
00?o0000oeJX0?mFZ0000_mFZ0000ol0003oKjl0ofn_0002ofn_0003o`000?n9]P3oRKH000;oRKH0
00?o0000ojJm0?nV_@000_nV_@000ol0003oaL@0olG40002olG40003o`000?o</P3oc;8000;oc;80
00?o0000om>N0?oCWP000ooCWP000ol0003ofhP0om^80002om^80003o`000?oRK`3ohVl000;ohVl0
00?o0000onYE0?oZE@000ooZE@001ol0003olST0oo8i0?ob>@3o0000oo8i0?l000007_ooool00ol0
003oooooooooo`0Oooooo`00<?ooool00ol0003oooooooooo`0Fooooo`;o00000ol02B<01Ol0003o
00lYo`0?:Ol03bWo000000?o01L`00Go0000o`0O=_l07cKo01lfo`000005o`0Y?005o`000?l0=D;o
03E2o`0e@_l000000ol0@TT00ol0003o04m>o`1?CP02o`1?CP05o`000?l0ET_o05I;o`1FBol00000
0ol0G4H00ol0003o06=0o`1S@002o`1S@005o`000?l0JCWo06Tio`1Y>Ol000001?l0L2l3o`000003
o`1g9Ol0003o000003[o000000?oc;80o`000?oCWP000ooCWP000ol0003ofhP0om^80003om^80003
o`000?oRK`3ohVl000;ohVl000?o0000onYE0?oZE@000ooZE@001ol0003olST0oo8i0?ob>@3o0000
oo8i0?l000007Oooool00ol0003oooooooooo`0Oooooo`00<?ooool00ol0003oooooooooo`0Hoooo
o`05o`000?l02B?o00TSo`098ol000000ol03bT01Ol0003o01L`o`0G<?l05c3o000000?o01lf00Co
0000o`0Y??l0:Cco02Tl:?l00002o`1g9@03o`000?l0OAWo07dI00;o07dI00?o0000o`242ol0Q0/0
0_l0Q0/00ol0003o18/0o`B;0002o`B;0005o`000?lETP3o5I80oaFB0?l000001?lXV@000ol0003o
?J00ocfP0002ocfP0003o`000?mDY`3oE:L000;oE:L000?o0000off^0?m][P000_m][P000ol0003o
R;H0ohRf0003ohRf0003o`000?nU_@3oYKd000;oYKd000Go0000ol?40?o3a03o`l@0o`000003olbc
01oo00007?ooool2o`00023ooooo000_ooooo`;o00006ooooolCo`0000?o02Tl00Go0000o`0d@_l0
=4;o03A2o`000003o`11B005o`000?l0Cdko04m>o`1?C_l000001?l0ED/01Ol0003o05a7o`1LAol0
G4Oo000000Co06=11?l000000ol0JCWo0000o`1`<003o`1`<005o`000?l0MbGo07LUo`1g9Ol00000
1?l0OAT00ol0003o08@;o`242`02o`242`03o`000?l4R`3o18/000;o18/000Go0000oaFB0?lETP3o
5I80o`000004obRI0003o`000?lmX03o?J0000;o?J0000?o0000oeBW0?mDY`000_mDY`000ol0003o
KJh0off^0002off^0003o`000?n8]P3oR;H000?oR;H000?o0000ojFm0?nU_@000_nU_@001Ol0003o
`l@0ol?40?o3a03o000000Coc;<000?o0000om>O0?oCW`000ooCW`000ol0003ofXT0omZ90002omZ9
0003o`000?oRL@3ohW4000?ohW4000?o0000onUF0?oYEP000ooYEP001_l0003olCX0oo4j0?l0003o
lCX0o`0001kooooo00?o0000ooooooooool07Oooool002oooooo00?o0000ooooooooool06oooool0
1Ol0003o00TSo`098ol02B?o000000?o00lY00Go0000o`0F;ol05Roo01H_o`000004o`0O=P03o`00
0?l0:Cco02Tl00;o02Tl00Go0000o`0d@_l0=4;o03A2o`000003o`11B005o`000?l0Cdko04m>o`1?
C_l000001?l0ED/01_l0003o05a7o`1LAol0G4Oo0000o`1S@@Co00000_l0JCU2o`0000Coc;<000?o
0000om>O0?oCW`000ooCW`000ol0003ofXT0omZ90002omZ90003o`000?oRL@3ohW4000?ohW4000?o
0000onUF0?oYEP000ooYEP001_l0003olCX0oo4j0?l0003olCX0o`0001gooooo00?o0000oooooooo
ool07Oooool002oooooo00?o0000ooooooooool07?ooool01Ol0003o00TSo`098ol02B?o000000?o
00lY00Go0000o`0F;ol05Roo01H_o`000002o`0O=R?o00000ol0JCX01Ol0003o06lao`1_<Ol0Kc7o
000000Co07HV00?o0000o`1m6_l0OAX00_l0OAX01Ol0003o08@<o`243?l0Q0co000000Co0h/000?o
0000oaBB0?lDTP000_lDTP000ol0003o9iT0obNI0002obNI0003o`000?llX03o?:0000;o?:0000?o
0000oe>W0?mCY`000_mCY`000ol0003oK:h0ofb^0002ofb^0003o`000?n7]@3oQkD000;oQkD000?o
0000oj>l0?nS_0000_nS_0001?l0003o`/@0ol;40?o2a00So`0001gooooo00?o0000ooooooooool0
7?ooool002oooooo0_l0000Nooooo`ko00000ol07SD01Ol0003o02Pko`0X>ol0:3_o000000Co03A2
00Go0000o`11B?l0@DSo0458o`000003o`1?CP03o`000?l0ED_o05E;00?o00001?l0FdL01Ol0003o
0691o`1R@Ol0HT7o000000Co06Tj00Go0000o`1_<Ol0Kc7o06lao`000004o`1f9P03o`000?l0OA[o
07dJ00;o07dJ00Go0000o`243?l0Q0co08@<o`000004o`>;0003o`000?lDTP3o598000;o598000?o
0000obNI0?lWV@000_lWV@000ol0003o?:00ocbP0002ocbP0003o`000?mCY`3oDjL000;oDjL000?o
0000ofb^0?m/[P000_m/[P000ol0003oQkD0ohNe0002ohNe0003o`000?nS_03oXk`000;oXk`000?o
0000ol;40?o2a0000_o2a0000ol0003obk@0ol^d0002ol^d0003o`000?oCX03odj0000;odj0000?o
0000omZ:0?oJRP000ooJRP000ol0003ohW80on9b0002on9b0003o`000?oYF03ojEP000?ojEP000Co
0000oo4k0?oa>`3olC/00_l0000Mooooo`;o00007Oooool000?ooooo0ol00004ooooo`;o00001?oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol000000ooooooo0000o`00
0003o`0000Cooooo00?o0000ooooooooool07_ooool01Ol0003o00TSo`098ol02B?o000000Co00lY
00Go0000o`0F;ol05Roo01H_o`000003o`0N=@05o`000?l0:3_o02Pko`0X>ol000001?l0=4801Ol0
003o0458o`11B?l0@DSo000000;o04m>0ol00003o`1EB`03o`000?l0FdOo05]704Go00001Oo2a000
0ol0003obk@0ol^d0002ol^d0003o`000?oCX03odj0000;odj0000?o0000omZ:0?oJRP000ooJRP00
0ol0003ohW80on9b0002on9b0003o`000?oYF03ojEP000?ojEP000Ko0000oo4k0?oa>`3o0000oo4k
0?l0000Mooooo`03o`000?oooooooooo01_ooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool07oooool01Ol0003o00TSo`098ol02B?o000000;o00lY8_l00003o`1KA`05o`000?l0
HT7o0691o`1R@Ol000001?l0J3X01Ol0003o06lao`1_<Ol0Kc7o000000Co07HV00Go0000o`1m6_l0
OA[o07dJo`000004o`243@03o`000?l2R`3o0X/000;o0X/000?o0000oa>A0?lCT@000_lCT@000ol0
003o9YP0obJH0002obJH0005o`000?lkW`3o>il0oc^O0?l000001?mBY`000ol0003oJjh0of^^0003
of^^0003o`000?n5]@3oQKD000;oQKD000?o0000oj:l0?nR_0009_l000000ooa>`3o0000ooooo`0L
ooooo`03o`000?oooooooooo01[ooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool0
1Ol00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool6o`0000?o00hX
00Go0000o`0E;ol05Boo01D_o`000003o`0N=@05o`000?l0:3_o02Pko`0X>ol000000ol0<d44o`00
00;o041800Go0000o`1>C_l0CTko04i>o`000003o`1EC003o`000?l0FdOo05]700;o05]700Go0000
o`1R@Ol0HT7o0691o`000004o`1X>P05o`000?l0Kc7o06lao`1_<Ol000001?l0MRH01Ol0003o07dJ
o`1m6_l0OA[o000000Co08@=00?o0000o`:;0?l2R`000_l2R`000ol0003o4i40oa>A0002oa>A0003
o`000?lVV03o9YP000;o9YP000Go0000oc^O0?lkW`3o>il0o`000004oe:W0003o`000?m[[P3oJjh0
00?oJjh000?o0000ohFe0?n5]@000_n5]@001Ol0003oX[`0oj:l0?nR_03o000000Co`L@000?o0000
ol^d0?o;]0000_o;]0000ol0003odZ40om:Q0003om:Q0003o`000?oJR`3ofX/000;ofX/000?o0000
on5c0?oQL`000ooQL`000ol0003ojET0onUI0002onUI0004o`000?oa?03olC`0oo4l00?o00007Ooo
ool00ol0003oooooooooo`0Iooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00009?ooool01Ol0
003o00PRo`088_l022;o000000?o00hX00Go0000o`0E;ol05Boo01D_o`000003o`0N=@04o`000?l0
:3_o02Pko`0X>`Go00000ol0@4QBo`0000Co`L@000?o0000ol^d0?o;]0000_o;]0000ol0003odZ40
om:Q0003om:Q0003o`000?oJR`3ofX/000;ofX/000?o0000on5c0?oQL`000ooQL`000ol0003ojET0
onUI0002onUI0004o`000?oa?03olC`0oo4l00;o00007Oooool00ol0003oooooooooo`0Iooooo`00
1?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02Cooooo6ol00002o`0oA`03o`000?l0
CTko04i>00;o04i>00Go0000o`1DC?l0E4co05A<o`000003o`1KA`03o`000?l0HT;o069200;o0692
00Go0000o`1X>_l0J3[o06Pjo`000004o`1_<@05o`000?l0MROo07HWo`1f9ol000001?l0O1/00ol0
003o08<=o`233@02o`233@05o`000?l2RP3o0XX0o`::0?l000001?lCT@000ol0003o9YP0obJH0002
obJH0003o`000?lkW`3o>il000;o>il000?o0000oe6V0?mAYP000_mAYP000ol0003oJZh0ofZ^0002
ofZ^0003o`000?n5]@3oQKD000;oQKD000Co0000oj6l0?nQ_03oXK`08Ol00003oo4l0003o`000?oa
?03o000001_ooooo00?o0000ooooool000006_ooool000?ooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`;o
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool09Oooool01Ol0
003o00PRo`088_l022;o000000?o00hX00Co0000o`0E;_l05Bko01D^1?l000000ol07CCo0000o`0W
>`02o`0W>`05o`000?l0<d7o03=1o`0c@Ol000000ol0?dL00ol0003o04i>o`1>CP02o`1>CP05o`00
0?l0E4co05A<o`1DC?l000000ol0FdL00ol0003o0692o`1R@P02o`1R@P05o`000?l0J3[o06Pjo`1X
>_l000001?l0Kc401Ol0003o07HWo`1f9ol0MROo000000Co07`K00?o0000o`233Ol0P`d00_l0P`d0
1Ol0003o0XX0o`::0?l2RP3o000000Co4i4000?o0000obJH0?lVV0000_lVV0000ol0003o>il0oc^O
0002oc^O0003o`000?mAYP3oDJH000;oDJH000?o0000ofZ^0?mZ[P000_mZ[P000ol0003oQKD0ohFe
0002ohFe0005o`000?nQ_03oXK`0oj6l0?l000001Oo0``000ol0003obkD0ol^e0002ol^e0003o`00
0?oBX@3odZ4000;odZ4000?o0000omZ<0?oJS0000ooJS0000ol0003ohG<0on5c0002on5c0004o`00
0?oYF@3ojET0onUI00So00007Oooool00ol0003oooooooooo`0Gooooo`001?ooool00ol0003ooooo
ooooo`03ooooo`;o00001?ooool2o`0000[ooooo0_l00005ooooo`04o`000?ooooooooooooooo`?o
00001?ooool00ol0003oooooooooo`0Vooooo`05o`000?l022;o00PRo`088_l000000ol03RP5o`00
00;o01ddG_l00005ol330003o`000?o;]@3obkD000;obkD000?o0000om:Q0?oBX@000_oBX@000ol0
003ofX`0omZ<0003omZ<0003o`000?oQL`3ohG<000;ohG<000?o0000onUI0?oYF@000_oYF@001?l0
003ol3d0oo0m0?o`?@02o`0001gooooo00?o0000ooooooooool01_ooool2o`0000Cooooo00Co0000
oooooooooooooooo1Ol00002ooooo`00;_ooool00ol0003oooooooooo`0Wooooo`ko00000ol07C@0
1Ol0003o02Lko`0W>ol09c_o000000?o039100Go0000o`0oAol0?dOo03m7o`000003o`1=CP03o`00
0?l0E4co05A<00;o05A<00Go0000o`1KAol0FdOo05]7o`000004o`1Q@P05o`000?l0J3[o06Pjo`1X
>_l000001?l0Kc801Ol0003o07HWo`1f9ol0MROo000000Co07`K00Go0000o`233Ol0P`go08<=o`00
0004o`6:0003o`000?lBT@3o4Y4000;o4Y4000?o0000obFH0?lUV0000_lUV0000ol0003o>Yl0ocZO
0002ocZO0003o`000?mAYP3oDJH000;oDJH000?o0000ofV]0?mY[@000_mY[@000ol0003oQ;@0ohBd
0002ohBd0003o`000?nQ_03oXK`0023o000000?ojET0o`000?o`?@000_o`?@02o`0001gooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo000^ooooo`03o`000?oooooooooo02Sooooo1?l000000ol022;o0000o`0>:002o`0>:005o`00
0?l05Bko01D^o`0E;_l000000ol07C@01Ol0003o02Lko`0W>ol09c_o000000?o039100Go0000o`0o
Aol0?dOo03m7o`000003o`1=CP03o`000?l0E4co05A<00;o05A<00Go0000o`1KAol0FdOo05]7o`00
0004o`1Q@P05o`000?l0J3[o06Pjo`1X>_l000001?l0Kc801Ol0003o07HWo`1f9ol0MROo000000Co
07`K00Go0000o`233Ol0P`go08<=o`000004o`6:0003o`000?lBT@3o4Y4000;o4Y4000?o0000obFH
0?lUV0000_lUV0000ol0003o>Yl0ocZO0002ocZO0003o`000?mAYP3oDJH000;oDJH000?o0000ofV]
0?mY[@000_mY[@000ol0003oQ;@0ohBd0002ohBd0005o`000?nQ_03oXK`0oj6l0?l000001?no``00
0ol0003obkH0ol^f0002ol^f0003o`000?oBXP3odZ8000?odZ8000?o0000omV<0?oIS0000_oIS000
0ol0003ohG@0on5d0002on5d0004o`000?oXFP3oj5X0onQJ00So00006oooool00ol0003oooooo`00
0005ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool002gooooo00?o
0000ooooooooool0:?ooool3o`0000;o00PRJ_l00004oko30003o`000?o;]P3obkH000;obkH000?o
0000om:R0?oBXP000ooBXP000ol0003ofH`0omV<0002omV<0003o`000?oQM03ohG@000;ohG@000?o
0000onQJ0?oXFP000_oXFP001ol0003ol3h0oo0n0?o`?P3o0000oo0n0?l000007?ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00Oooool002go
oooo00?o0000ooooooooool09Oooool3o`0000?ooooo0_l00002o`088P05o`000?l03RSo00hXo`0>
:?l000000ol05Bh01Ol0003o01ddo`0M=?l07CCo000000Co02Lk00Go0000o`0b@Ol0<T7o0391o`00
0003o`0oA`03o`000?l0CDko04e>00;o04e>00Go0000o`1DC?l0E4co05A<o`000004o`1KA`05o`00
0?l0HD;o0652o`1Q@_l000001?l0J3/01Ol0003o06lbo`1_<_l0Kc;o000000Co07DW00Co0000o`1l
6ol0O1_o00001?l0P`h00ol0003o0HX0o`6:0002o`6:0005o`000?lBT@3o4Y40oa:A0?l000001?lU
V0000ol0003o>Yl0ocZO0002ocZO0003o`000?m@YP3oD:H000;oD:H000?o0000ofV]0?mY[@000_mY
[@000ol0003oPk@0oh>d0002oh>d0004o`000?nP_03oX;`0oj2l01_o00001OoXFP001ol0003ol3h0
oo0n0?o`?P3o0000oo0n0?l000007?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`00;Oooool2o`0002?ooooo0ol00007
ooooo`05o`000?l022;o00PRo`088_l000000ol03RP01Ol0003o01D^o`0E;_l05Bko000000?o01dd
00?o0000o`0W>ol09c/00_l09c/01Ol0003o0391o`0b@Ol0<T7o000000?o03m700?o0000o`1=C_l0
CDh08Ol00004o`233P03o`000?l1RP3o0HX000;o0HX000Go0000oa:A0?lBT@3o4Y40o`000004obFH
0003o`000?ljW`3o>Yl000;o>Yl000?o0000oe2V0?m@YP000_m@YP000ol0003oJJd0ofV]0002ofV]
0003o`000?n3]03oPk@000;oPk@000?o0000oj2l0?nP_0000_nP_0001Ol0003o_/<0okk30?nn``3o
000000GobkH000?o0000om:R0?oBXP000_oBXP000ol0003ofH`0omV<0002omV<0004o`000?oQM03o
hG@0on5d00ko00006_ooool3o`0000?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000;ooooo000]ooooo`03o`000?oooooooooo01oooooo0ol0000;oooooaoo0000
0ol0CDh01Ol0003o05A<o`1DC?l0E4co000000?o05]800?o0000o`1Q@_l0HD800_l0HD801Ol0003o
06Pko`1X>ol0J3_o000000Co06lb00Go0000o`1e9ol0MBOo07DWo`000002o`1l6c;o00001Oo;]P00
0ol0003odZ80om:R0002om:R0003o`000?oIS03ofH`000;ofH`000?o0000on5d0?oQM0000_oQM000
0ol0003oj5/0onQK0002onQK0007o`000?o`?P3ol3h0oo0n0?l0003ol3h0o`00000Gooooo`Co0000
00?oooooo`000?ooool00oooool2o`0000Wooooo0ol00003ooooo`00;Oooool00ol0003ooooooooo
o`0Looooo`?o00003oooool01Ol0003o00PRo`088_l022;o000000Co00hX00Go0000o`0D;_l052ko
01@^o`000003o`0M=005o`000?l09c[o02Ljo`0W>_l000000ol0<T400ol0003o03i7o`0nA`02o`0n
A`05o`000?l0CDko04e>o`1=C_l000000ol0E4`01Ol0003o05]8o`1KB?l0FdSo000000Co065200Go
0000o`1X>ol0J3_o06Pko`000004o`1_<P05o`000?l0MBOo07DWo`1e9ol000001?l0O1/01Ol0003o
08<>o`233_l0P`ko000000Co0HX000Go0000oa:A0?lBT@3o4Y40o`000004obFH0003o`000?ljW`3o
>Yl000;o>Yl000Go0000oe2V0?m@YP3oD:H0o`000004ofV]0003o`000?n3]03oPk@000;oPk@000?o
0000oinl0?nO_0000onO_0000ol0003o_/<0okk3000Eo`000003on5d0?l0003oj5/000?oj5/000Oo
0000oo0n0?o`?P3ol3h0o`000?o`?P3o000001?ooooo0ol00005ooooo`03o`000?oooooooooo01?o
oooo000]ooooo`;o00006_ooool3o`0001?ooooo00Go0000o`088_l022;o00PRo`000002o`0>:4So
00001?lUV0000ol0003o>Yl0ocZO0002ocZO0005o`000?m@YP3oD:H0oe2V0?l000001?mY[@000ol0
003oPk@0oh>d0002oh>d0003o`000?nO_03oWk`000?oWk`000Go0000okk30?nn``3o_/<0o`000004
olZf0003o`000?oBXP3odZ8000;odZ8000?o0000omV=0?oIS@000ooIS@000ol0003ohGD0on5e000>
o`0000oooooo0ol00008ooooo`03o`000?oooooooooo01?ooooo00001?oooooo0000o`000?l00004
ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol00003
ooooo`?o00000oooool2o`0001Sooooo0ol0000Gooooo`Ko00000ol03RP01Ol0003o01@^o`0D;_l0
52ko000000?o01dd00Go0000o`0W>_l09c[o02Ljo`000003o`0b@@05o`000?l0?TOo03i7o`0nAol0
00000ol0CDh00ol0003o05A<o`1DC002o`1DC005o`000?l0FdSo05]8o`1KB?l000000ol0HD800ol0
003o06Pko`1X>`02o`1X>`05o`000?l0Kc;o06lbo`1_<_l000001?l0MBL01Ol0003o07`Ko`1l6ol0
O1_o000000Co08<>00?o0000o`6:0?l1RP000_l1RP000ol0003o4Y40oa:A000To`0000Cob[H000?o
0000om:R0?oBXP000_oBXP000ol0003ofHd0omV=0003omV=0005o`000?oQM@3ohGD0on5e0?l00000
1?oXF`001ol0003ol3l0oo0o0?o`?`3o0000oo0o0?l000002oooool4o`0000_ooooo00?o0000oooo
ooooool04oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool3o`0001cooooo00Go
0000o`088_l022;o00PRo`000003o`0>:005o`000?l052ko01@^o`0D;_l000000ol07C@01Ol0003o
02Ljo`0W>_l09c[o000000?o039100Go0000o`0nAol0?TOo03i7o`000003o`1=CP03o`000?l0E4co
05A<00;o05A<00Go0000o`1KB?l0FdSo05]8o`000003o`1Q@P03o`000?l0J3_o06Pk00;o06Pk00Go
0000o`1_<_l0Kc;o06lbo`000004o`1e9`05o`000?l0O1_o07`Ko`1l6ol000001?l0P`h00ol0003o
0HX0o`6:0002o`6:0005o`000?lBT@3o4Y40oa:A0?l000001?lUV0001Ol0003o>Il0ocVO0?liW`3o
000000CoD:H000?o0000ofR]0?mX[@000_mX[@000ol0003oPk@0oh>d0002oh>d0003o`000?nO_03o
Wk`000;oWk`000Co0000okk30?nn``3o_/<05_l00004onQK0007o`000?o`?`3ol3l0oo0o0?l0003o
l3l0o`000007ooooo`?o00004?ooool00ol0003oooooooooo`0Booooo`000_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01Ol0
003oooooooooool0003ooooo00Go000000?oooooo`000?l000000ol00003ooooo`03o`000?oooooo
oooo01;ooooo0_l0000PoooooeOo00001?m@YP000ol0003oJ:d0ofR]0002ofR]0003o`000?n3]03o
Pk@000;oPk@000?o0000oinl0?nO_0000_nO_0000ol0003o_/<0okk30002okk30005o`000?o:]P3o
b[H0olZf0?l000001?oBX`000ol0003ofHd0omV=0003omV=0004o`000?oQM@3ohGD0on5e00go0000
0oooool3o`0001?ooooo00?o0000ooooooooool04_ooool000;ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool2o`00013ooooo0ol0000Sooooo`04o`000?l022;o00PRo`0000?o00hX00?o0000o`0D;_l052h0
0_l052h01Ol0003o01ddo`0M=?l07CCo000000Co02Lj00Go0000o`0b@Ol0<T7o0391o`000003o`0n
A`05o`000?l0CDko04e>o`1=C_l000000ol0E4`00ol0003o05]8o`1KB002o`1KB005o`000?l0HD;o
0652o`1Q@_l000000_l0J3/00ol0003o06lbo`1_<P02o`1_<P05o`000?l0MBOo07DWo`1e9ol00000
1?l0O1/01Ol0003o08<>o`233_l0P`ko000000Co0HX000?o0000oa:A0?lBT@000_lBT@000ol0003o
9IP0obFH0002obFH0003o`000?ljW`3o>Yl001oo00001?oBX`000ol0003ofHd0omV=0003omV=0003
o`000?oQM@3ohGD000;ohGD000?o0000onQK0?oXF`000_oXF`001?l0003ol3l0oo0o0?o`?`05o`00
01Kooooo00?o0000ooooooooool04_ooool000;ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool03?oo
ool3o`0002Oooooo00Co0000o`088_l022;o00000ol03RP00ol0003o01@^o`0D;P0Xo`0000Co06lb
00Go0000o`1e9ol0MBOo07DWo`000004o`1l6`05o`000?l0P`ko08<>o`233_l000001?l1RP000ol0
003o4Y40oa:A0002oa:A0003o`000?lUV03o9IP000;o9IP000Go0000ocZO0?ljW`3o>Yl0o`000003
oe2V0003o`000?mY[@3oJJd000;oJJd000?o0000oh>d0?n3]0000_n3]0000ol0003oWk`0oinl0002
oinl0003o`000?nn``3o_/<000;o_/<000Co0000olZf0?o:]P3ob[H05Ol000001ooXF`3o0000oo0o
0?o`?`3o0000oo0o0?l000006?ooool00ol0003oooooooooo`0Booooo`0000?oooooo`000?l00000
1?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000oooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo0ol0000[
ooooo`Wo00000ol05Bh01Ol0003o01ddo`0M=?l07CCo000000?o02Lk00Go0000o`0b@Ol0<T7o0391
o`000003o`0oA`03o`000?l0CDko04e>00;o04e>00Go0000o`1DC?l0E4co05A<o`000003o`1KA`05
o`000?l0HD;o0652o`1Q@_l000000_l0J3/[o`0000CoJJd000?o0000oh>d0?n3]0000_n3]0000ol0
003oWk`0oinl0002oinl0003o`000?nn``3o_/<000;o_/<000Go0000olZf0?o:]P3ob[H0o`000005
om:R0003o`000?oIS@3ofHd000;ofHd000?o0000on5e0?oQM@000_oQM@001?l0003oj5/0onQK0?oX
F`08o`0001Oooooo00?o0000ooooooooool04_ooool000;ooooo00?o0000ooooooooool00oooool2
o`0000Cooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool3o`0002oooooo00Go0000o`088_l022;o00PRo`00
0003o`0>:005o`000?l05Bko01D^o`0E;_l000000ol07C@01Ol0003o02Lko`0W>ol09c_o000000?o
039100Go0000o`0oAol0?dOo03m7o`000004o`1=CP05o`000?l0E4co05A<o`1DC?l000000ol0FdL0
1Ol0003o0652o`1Q@_l0HD;o000000Co06Pk00Go0000o`1_<_l0Kc;o06lbo`000004o`1e9`05o`00
0?l0O1_o07`Ko`1l6ol000000ol0P`h01Ol0003o0HX0o`6:0?l1RP3o000000Co4Y4000?o0000obFH
0?lUV0000_lUV0000ol0003o>Yl0ocZO0002ocZO0003o`000?m@YP3oD:H001[o00001OoBXP000ol0
003ofHd0omV=0002omV=0003o`000?oQM@3ohGD000;ohGD000?o0000onQK0?oXF`000_oXF`001?l0
003ol3l0oo0o0?o`?`02o`0001Oooooo00?o0000ooooooooool04_ooool002_ooooo0_l00005oooo
o`?o0000<ooooom4o`0000?o0HX000?o0000oa:A0?lBT@000_lBT@000ol0003o9IP0obFH0002obFH
0003o`000?ljW`3o>Yl000;o>Yl000?o0000oe2V0?m@YP000_m@YP001?l0003oJJd0ofV]0?l00004
oh>d0003o`000?nP_03oX;`000;oX;`000?o0000okk30?nn``000onn``000ol0003obkH0ol^f000E
o`000003onQK0?l0003ol3l000;ol3l00_l0000Fooooo`03o`000?oooooooooo01;ooooo000[oooo
o`04o`000?ooooooooooooooo`?o0000=oooool01Ol0003o00PRo`088_l022;o000000?o00hX00Go
0000o`0E;_l05Bko01D^o`000003o`0M=005o`000?l09c_o02Lko`0W>ol000000ol0<T401Ol0003o
03m7o`0oAol0?dOo000000?o04e>00Go0000o`1DC?l0E4co05A<o`000004o`1KA`05o`000?l0HD;o
0652o`1Q@_l000000ol0J3X00ol0003o06lbo`1_<P02o`1_<P05o`000?l0MROo07HWo`1f9ol00000
1?l0O1/00ol0003o08<=o`233@0Mo`0000CoPk@000?o0000oj2l0?nP_0000_nP_0000ol0003o_/<0
okk30003okk30003o`000?o;]P3obkH000;obkH000Go0000om:R0?oBXP3odZ80o`000004omV<0003
o`000?oQM03ohG@000?ohG@000?o0000onQK0?oXF`002?l0000Fooooo`03o`000?oooooooooo017o
oooo000[ooooo`Co0000>oooool01Ol0003o00PRo`088_l022;o000000?o00hX00Go0000o`0E;_l0
5Bko01D^o`000003o`0M=005o`000?l09c_o02Lko`0W>ol000000ol0<T401Ol0003o03m7o`0oAol0
?dOo000000?o04e>00Go0000o`1DC?l0E4co05A<o`000004o`1KA`05o`000?l0HD;o0652o`1Q@_l0
00000ol0J3X00ol0003o06lbo`1_<P02o`1_<P05o`000?l0MROo07HWo`1f9ol000001?l0O1/01Ol0
003o08<=o`233Ol0P`go000000Co0HX000Go0000oa:A0?lBT@3o4Y40o`000003obFH0003o`000?lj
W`3o>Yl000;o>Yl000?o0000oe6V0?mAYP000_mAYP000ol0003oJJd0ofV]000Ko`0000CofH`000?o
0000on5d0?oQM0000ooQM0001Ol0003oj5/0onQK0?oXF`3o000000?ol3h00_l0000Fooooo`03o`00
0?oooooooooo017ooooo000[ooooo`;o0000?_oooom=o`0000?o9IP000?o0000ocZO0?ljW`000_lj
W`000ol0003oDJH0oe6V0002oe6V0003o`000?mY[@3oJJd000;oJJd000Go0000ohBd0?n4]03oQ;@0
o`000004oj6l0003o`000?no``3o_l<000;o_l<000?o0000ol^f0?o;]P000_o;]P001?l0003odZ80
om:R0?oBXP0Ao`0000?ol3h00_l0000Eooooo`03o`000?oooooooooo017ooooo000]ooooo`03o`00
0?oooooooooo03cooooo00Go0000o`088_l022;o00PRo`000003o`0>:005o`000?l05Bko01D^o`0E
;_l000000ol07C@01Ol0003o02Lko`0W>ol09c_o000000?o03=100Go0000o`0oAol0?dOo03m7o`00
0004o`1>CP05o`000?l0E4co05A<o`1DC?l000000ol0FdL01Ol0003o0692o`1R@_l0HT;o000000Co
06Pj00Co0000o`1_<Ol0Kc7o00001?l0MRL01Ol0003o07`Ko`1l6ol0O1_o000000Co08<=00Go0000
o`::0?l2RP3o0XX0o`000003oa>A01Wo00001?nQ_0000ol0003o_l<0oko30002oko30003o`000?o;
]P3obkH000;obkH000Go0000om:R0?oBXP3odZ80o`000004omV<0003o`000?oQM03ohG@000?ohG@0
00Co0000onQJ0?oXFP3oj5X01ol0000Dooooo`03o`000?oooooooooo017ooooo000^ooooo`03o`00
0?oooooooooo03cooooo=_l00004o`1f9`05o`000?l0O1_o07`Ko`1l6ol000001?l0P`d01Ol0003o
0XX0o`::0?l2RP3o000000Co4i4000?o0000obJH0?lVV0000_lVV0001?l0003o>il0oc^O0?l00004
oe6V0003o`000?mZ[P3oJZh000;oJZh000Co0000ohFe0?n5]@3oQKD05Ol00004omV<0003o`000?oQ
M03ohG@000?ohG@000Go0000onQJ0?oXFP3oj5X0o`000003oo0n0003o`000?o`?P3o000001?ooooo
00?o0000ooooooooool04Oooool002oooooo00?o0000ooooooooool0??ooool00ol0003o00PRo`08
8P02o`088P05o`000?l03RSo00hXo`0>:?l000000ol05Bl01Ol0003o01heo`0N=Ol07SGo000000;o
02Pk00Go0000o`0c@Ol0<d7o03=1o`000003o`10B005o`000?l0CTko04i>o`1>C_l000000ol0ED`0
1Ol0003o05]7o`1KAol0FdOo000000Co069100Go0000o`1X>_l0J3[o06Pjo`000002o`1_<B7o0000
1?mAYP000ol0003oJZh0ofZ^0002ofZ^0003o`000?n5]@3oQKD000;oQKD000Go0000oj6l0?nQ_03o
XK`0o`000004ol330003o`000?o;]@3obkD000;obkD000Co0000om:Q0?oBX@3odZ404Ol00003oo0n
0003o`000?o`?P3o000001;ooooo00?o0000ooooooooool04Oooool0033ooooo0_l0000mooooo`03
o`000?l022;o00PR01;o00000ol0<d401Ol0003o0418o`10B?l0@4So000000?o04i>00Go0000o`1E
C?l0EDco05E<o`000003o`1KA`03o`000?l0HT7o069100;o069100Go0000o`1X>_l0J3[o06Pjo`00
0003o`1_<@03o`000?l0MRKo07HV00;o07HV00Go0000o`1m6_l0OA[o07dJo`000003o`243@03o`00
0?l2R`3o0X/000;o0X/000Go0000oa>A0?lCT@3o4i40o`000004obJH0003o`000?lkW`3o>il001Go
00001?o0``000ol0003obkD0ol^e0002ol^e0003o`000?oBX@3odZ4000;odZ4000Go0000omZ<0?oJ
S03ofX`0o`000005on5c0004o`000?oYF@3ojET0onUI00So00004Oooool00ol0003oooooooooo`0A
ooooo`00<_ooool00ol0003oooooooooo`0kooooo`;o00000_l02B<01Ol0003o00lYo`0?:Ol03bWo
000000?o01H_00Go0000o`0N=Ol07SGo01heo`000002o`0X>c3o00001?l2R`001Ol0003o4i40oa>A
0?lCT@3o000000Co9YP000?o0000oc^O0?lkW`000_lkW`001?l0003oDZL0oe:W0?l00004of^^0003
o`000?n5]@3oQKD000;oQKD000Co0000oj:l0?nR_03oX[`05Ol00005on5c0003o`000?oYF@3ojET0
00;ojET000Ko0000oo0m0?o`?@3o0000oo0m0?l0000Aooooo`03o`000?oooooooooo017ooooo000c
ooooo`03o`000?oooooooooo03_ooooo00Go0000o`098ol02B?o00TSo`000003o`0?:@05o`000?l0
5Roo01H_o`0F;ol000000ol07SD01Ol0003o02Pko`0X>ol0:3_o000000?o03A200Go0000o`11B?l0
@DSo0458o`000003o`1?CP03o`000?l0ED_o05E;00;o05E;00Go0000o`1KAol0FdOo05]7o`000003
o`1R@@04o`000?l0JC[o06Tjo`0000Co06la00Go0000o`1f9_l0MRKo07HVo`000004o`1m6P03o`00
0?l0Q0co08@<01So00001?m[[P000ol0003oQKD0ohFe0002ohFe0003o`000?nR_03oX[`000;oX[`0
00Go0000ol740?o1a03o`L@0o`000004ol^d0003o`000?oBX@3odZ4000;odZ4000Co0000omZ;0?oJ
R`3ofX/04?l000000oo`?@3o0000ooooo`0@ooooo`03o`000?oooooooooo013ooooo000dooooo`03
o`000?oooooooooo03_ooooo<Ol00004o`1_<@05o`000?l0MRKo07HVo`1f9_l000001?l0OAX01Ol0
003o08@<o`243?l0Q0co000000Co0h/000Co0000oaBB0?lDTP3o00001?lWV@000ol0003o?:00ocbP
0002ocbP0003o`000?mCY`3oDjL001Go00001?o;]0000ol0003odZ40om:Q0002om:Q0003o`000?oJ
R`3ofX/000;ofX/000?o0000on5c0?oQL`000_oQL`000ol0003ojET0onUI0002onUI0004o`000?oa
?03olC`0oo4l00?o00004?ooool00ol0003oooooooooo`0@ooooo`00=Oooool00ol0003ooooooooo
o`0looooo`05o`000?l02B?o00TSo`098ol000000ol03bT01Ol0003o01H_o`0F;ol05Roo000000?o
01lf00Go0000o`0Y??l0:Cco02Tlo`000003o`0d@P04o`000?l0@DSo0458o`0000?o04m>00Go0000
o`1EBol0ED_o05E;o`000003o`1LA`03o`000?l0Hd7o06=100;o06=100?o0000o`1Y>Ol000006ol0
0004obNI0003o`000?llX03o?:0000;o?:0000?o0000oe>W0?mCY`000_mCY`001Ol0003oK:h0ofb^
0?m/[P3o000000?oQkD000?o0000oj>l0?nS_0000_nS_0001?l0003o`/@0ol;40?o2a00?o`000003
omZ;0?l0003ohG<000?ohG<000?o0000onUI0?oYF@000_oYF@001?l0003olC`0oo4l0?oa?002o`00
013ooooo00?o0000ooooooooool04?ooool003Kooooo0_l0000moooooaco00000ol0Cdh01Ol0003o
05E;o`1EBol0ED_o000000?o05a700?o0000o`1S@Ol0Hd400_l0Hd401Ol0003o06Tio`1Y>Ol0JCWo
000000?o070`00?o0000o`1g9Ol0MbD00_l0MbD01?l0003o07dIo`1m6Ol00004o`242`05o`000?l4
R`3o18/0o`B;0?l000000_lETP0Io`0000CoXk`000?o0000ol;40?o2a0000_o2a0001Ol0003obk@0
ol^d0?o;]03o000000Codj0000Co0000omZ:0?oJRP3ofXX04?l000000ooa?03o0000ooooo`0>oooo
o`03o`000?oooooooooo013ooooo000hooooo`03o`000?oooooooooo03[ooooo00Go0000o`098ol0
2B?o00TSo`000003o`0?:@05o`000?l05c3o01L`o`0G<?l000000ol07cH01Ol0003o02Tlo`0Y??l0
:Cco000000?o03E200?o0000o`12BOl0@TT08ol00004o`242`05o`000?l4R`3o18/0o`B;0?l00000
1?lETP001Ol0003o:9T0obRI0?lXV@3o000000?o?J0000?o0000oeBW0?mDY`000_mDY`000ol0003o
KJh0off^0002off^0003o`000?n8]P3oR;H0013o00001?oCX0000ol0003ofXX0omZ:0003omZ:0005
o`000?oRLP3ohW80on9b0?l000001?oYF0001?l0003olC/0oo4k0?oa>`03o`0000kooooo00?o0000
ooooooooool04?ooool003Wooooo00?o0000ooooooooool0>_ooool01Ol0003o00TSo`098ol02B?o
000000?o00lY00Go0000o`0G<?l05c3o01L`o`000003o`0O=P05o`000?l0:Cco02Tlo`0Y??l00000
0ol0=D801Ol0003o0499o`12BOl0@TWo000000?o04m>00Go0000o`1FBol0ET_o05I;o`000004o`1L
AP05o`000?l0Hd3o06=0o`1S@?l000000_l0JCT01Ol0003o070_o`1`;ol0L2oo000000Co07LU00?o
0000o`1n6?l0OQP06?l00004oeBW0003o`000?m][P3oKJh000;oKJh000Go0000ohRf0?n8]P3oR;H0
o`000003ojFm0003o`000?o3a03o`l@000;o`l@000Co0000olbc0?o</`3oc;<04Ol00004onUH0007
o`000?oa>`3olC/0oo4k0?l0003olC/0o`00000=ooooo`03o`000?oooooooooo013ooooo000joooo
o`03o`000?oooooooooo03[ooooo<Ol00003o`1`;`03o`000?l0MbGo07LU00;o07LU00Go0000o`1n
6?l0OQSo07hHo`000004o`252P04o`000?l5S03o1H`0o`0000Co5Y8000Go0000obVI0?lYV@3o:IT0
o`000003ocjQ01Co00001?o3a0000ol0003oc;<0olbc0002olbc0003o`000?oCW`3odil000;odil0
00?o0000omZ90?oJR@000_oJR@001?l0003ohW40on9a0?oRL@0=o`0000cooooo00?o0000oooooooo
ool04?ooool003_ooooo0_l0000looooo`05o`000?l02RCo00XTo`0:9?l000000ol042X01?l0003o
01L`o`0G<?l00003o`0P=P05o`000?l0:Sco02Xlo`0Z??l000000ol0=T<01Ol0003o04=9o`13BOl0
@dWo000000?o051>00Go0000o`1FBol0ET_o05I;o`000003o`1MAP05o`000?l0Hd3o06=0o`1S@?l0
00000_l0JSPGo`0000Co5Y8000Go0000obVI0?lYV@3o:IT0o`000004ocjQ0003o`000?mFZ03oEZP0
00;oEZP000Go0000ofn_0?m_[`3oKjl0o`000004ohVf0003o`000?nV_@3oY[d000oo000000?odil0
o`000?oJR@000ooJR@000ol0003ohW40on9a0002on9a0005o`000?oYEP3ojEH0onUF0?l000000ooa
>P000ol0003olCX0o`00000=ooooo`03o`000?oooooooooo00oooooo000mooooo`03o`000?oooooo
oooo03[ooooo8?l00003o`1FB`05o`000?l0GDKo05e6o`1MA_l000000ol0Hd001Ol0003o06Xho`1Z
>?l0JSSo000000Co074_00Go0000o`1g9?l0MbCo07LTo`000003o`1n6005o`000?l0Q@Wo08D9o`25
2Ol000000_l6S00Io`0000CoRKH000Go0000ojJm0?nV_@3oY[d0o`000003olG40003o`000?o</P3o
c;8000;oc;8000Co0000om>N0?oCWP3odih04Ol00003oo4j0003o`000?oa>P3o000000cooooo00?o
0000ooooooooool03oooool003kooooo00?o0000ooooooooool0>_ooool01Ol0003o00XTo`0:9?l0
2RCo000000?o010Z00Co0000o`0H<Ol0637o00000ol08CL01Ol0003o02/mo`0[?Ol0:cgo000000?o
03M300Go0000o`14B_l0A4[o04A:o`000002o`1@CQoo00000ol0Q@T01Ol0003o1X`0o`J<0?l6S03o
000000Co5i<000Go0000ob^J0?l[VP3o:iX0o`000003od2Q0003o`000?mGZ03oEjP000;oEjP000Co
0000og2_0?m`[`3oL:l03ol00004olbb0003o`000?oCWP3odih000?odih000Go0000om^80?oKR03o
fhP0o`000004on9_0004o`000?oZE@3ojUD0onYE00So00002oooool00ol0003oooooooooo`0?oooo
o`00?oooool00ol0003oooooooooo`0jooooo`co00000ol08CL01Ol0003o02/mo`0[?Ol0:cgo0000
00?o03M300Go0000o`14B_l0A4[o04A:o`000003o`1@CP05o`000?l0Ed[o05M:o`1GB_l000000ol0
GDH01Ol0003o06@oo`1T?ol0I3oo000000?o06/h00Go0000o`1a;_l0LBko074^o`000003o`1h8`04
o`000?l0OaOo07lGo`1o5a?o00000om0X@000ol0003oEjP0oeNX0002oeNX0003o`000?m`[`3oL:l0
00;oL:l000Go0000oh^g0?n;]`3oRkL0o`000004ojRn0003o`000?o5``3oaL<0017o00001?oRK`00
1Ol0003ojUD0onYE0?oZE@3o000000?olST000?o0000oo8i0?l000002oooool00ol0003ooooooooo
o`0?ooooo`00@?ooool2o`0003_ooooo00Co0000o`0;9Ol02bGo00000ol04B/00ol0003o01Tao`0I
<@0Vo`0000?o074^00Go0000o`1h8ol0N2?o07PSo`000004o`1o5`05o`000?l0QPSo08H8o`262?l0
00000ol7S0001Ol0003o6I<0oaVC0?lIT`3o000000?o;9X05?l00004ojRn0005o`000?o5``3oaL<0
olG30?l000000oo</@000ol0003oe9`0omBL0003omBL0004o`000?oKQP3ofhH0om^600_o00000oob
>@000ol0003olST0o`00000:ooooo`03o`000?oooooooooo00oooooo0012ooooo`03o`000?oooooo
oooo03Wooooo00Co0000o`0;9Ol02bGo00000ol04B/01Ol0003o01Tao`0I<Ol06C7o000000?o028g
00Go0000o`0/?_l0;3ko02`no`000003o`0hA005o`000?l0AD[o04E:o`15B_l000000ol0DDd01?l0
003o05M:o`1GB_l00003o`1NA@03o`000?l0I3oo06@o00;o06@o00?o0000o`1[=ol0JcL05ol00003
oaVC0003o`000?l/VP3o;9X000;o;9X000Go0000od:R0?m2XP3o@Z80o`000003oeVX0003o`000?mb
/03oL[0000;oL[0000Co0000ohfg0?n=]`3oSKL03ol00005omBL0003o`000?oKQP3ofhH000;ofhH0
00Go0000on=^0?oSKP3ohfh0o`000003on]C00So00002Oooool00ol0003oooooooooo`0?ooooo`00
@oooool00ol0003oooooooooo`0iooooob?o00000ol0GTD00ol0003o06@oo`1T?`02o`1T?`05o`00
0?l0JcOo06/go`1[=ol000000ol0LRd00ol0003o07PRo`1h8P02o`1h8P04o`000?l0OaKo07lFo`00
00?o08H700Co0000o`R=0?l8S@3o28d04ol00004og:`0003o`000?n=]`3oSKL000;oSKL000Go0000
ojZn0?nZ_P3oZ[h0o`000004olK20003o`000?o=[`3ocJl0017o00001?o[D`001?l0003olSL0oo8g
0?ob=`02o`0000Wooooo00?o0000ooooooooool03oooool004Cooooo00?o0000ooooooooool0>Ooo
ool01Ol0003o00/Uo`0;9Ol02bGo000000?o018/00Co0000o`0I<_l06C;o00000ol08cP01Ol0003o
02dno`0]?_l0;Cko000000;o03U500Go0000o`17Bol0Ad_o04M;o`000003o`1AC@03o`000?l0F4Wo
05Q901_o00000ol0QPL00ol0003o28d0o`R=0002o`R=0005o`000?lJU03o6Y@0oaZD0?l000000ol^
V`000ol0003o@j80od>R0002od>R0003o`000?mKZ@3oFjT0013o00001?o6`P000ol0003ocJl0olf_
0002olf_0005o`000?oDV`3oe9/0omBK0?l000001?oLQ@001?l0003ohf`0on=/0?oSK00:o`000003
oo8g0?l0003ooooo00Sooooo00?o0000ooooooooool03_ooool004Gooooo00?o0000ooooooooool0
>OoooolGo`0000?o04M;00Go0000o`1ACOl0DDgo055=o`000003o`1HB@03o`000?l0GTGo05i500;o
05i500Go0000o`1U?_l0ICko06Dno`000003o`1/=P04o`000?l0LRco078/o`0000Co07TQ00?o0000
o`205?l0P1@04ol00004od>R0005o`000?mKZ@3oFjT0oe^Y0?l000000omd/0000ol0003oSkP0ohnh
0002ohnh0004o`000?n/_`3o[;l0ojbo013o00001?oLQ@001Ol0003ohf`0on=/0?oSK03o000000Co
je8000Co0000oo8e0?ob=@3olSD00_l00009ooooo`03o`000?oooooooooo00kooooo0016ooooo`;o
0000>_ooool01Ol0003o00`Vo`0<9_l032Ko000000?o018/00Co0000o`0J<_l06S;o00000ol093T0
1_l0003o02hoo`0^?ol0;Soo0000o`0jAAko00001?l0NB401Ol0003o080Do`205?l0P1Co000000?o
08L600Go0000o`Z>0?l:SP3o2Xh0o`000003oabD0004o`000?l`V`3o<9/0oc2K00oo00001?n?^000
0ol0003o[;l0ojbo0002ojbo0005o`000?o6`@3oa/40olK10?l000001?o=[P001?l0003oeIX0omFJ
0?oEVP0;o`0000Coje8000Co0000oo8e0?ob=@3olSD00_l00008ooooo`03o`000?oooooooooo00ko
oooo0018ooooo`03o`000?oooooooooo03Sooooo3?l00003o`0T>@05o`000?l0;Soo02hoo`0^?ol0
00000ol0>TD01Ol0003o04Q<o`18C?l0B4co000000?o059=00Go0000o`1IBOl0FDWo05U9o`000002
o`1OA005o`000?l0ISgo06Hmo`1V?Ol000000ol0K3D00ol0003o07<[o`1c:`0Co`0000?o79@000?o
0000oc2K0?l`V`000_l`V`000ol0003oAJ<0odFS0002odFS0004o`000?mMZP3oGJX0o`0000?oM[40
4?l00004olf^0003o`000?oEVP3oeIX000;oeIX000Go0000omb30?oLP`3og8<0o`000003onAZ00co
00001oooool00ol0003oooooooooo`0>ooooo`00BOooool00ol0003oooooooooo`0hooooo`04o`00
0?l03BOo00dWo`0000?o01<]00?o0000o`0K<ol06c<07Ol00003o`1V?@05o`000?l0K3Go06`eo`1/
=Ol000001?l0Lb/01Ol0003o07XPo`1j8?l0NR3o000000;o084C00?o0000o`271?l0Q`@00_l0Q`@0
0ol0003o2hh0o`^>000Co`0000CoM[4000?o0000oi6h0?nA^0000_nA^0001Ol0003o[kl0ojno0?n_
_`3o000000?oakl04?l00004onAZ0005o`000?o/D03ok500ona@0?l000000ooc<`02o`0000Oooooo
00?o0000ooooooooool03_ooool004[ooooo00?o0000ooooooooool0>?ooool01?l0003o00dWo`0=
9ol00003o`0C;@05o`000?l06c?o01/co`0K<ol000000ol09CT01Ol0003o030oo`0`?ol0<3oo0000
00?o03a600Go0000o`1:C?l0BTco04Y<o`000002o`1CC@05o`000?l0FDWo05U9o`1IBOl000000_l0
H4<Fo`0000Co08L400Go0000o`^>0?l;SP3o2hh0o`000004oafE0004o`000?laW03o<I`0o`0000Co
Aj<000?o0000oenZ0?mOZP004?l00004olNo0004o`000?o>[03ocZ`0o`0000GoeYP000Co0000omf1
0?oMP@3ogH402ol00003oo<c00;o00001_ooool00ol0003oooooooooo`0>ooooo`00Boooool2o`00
03Wooooo7ol00003o`1IB@05o`000?l0H4?o0613o`1P@ol000000ol0IS`01Ol0003o06ddo`1]=?l0
KCCo000000?o07@Z00Go0000o`1j7ol0NQoo07XOo`000002o`214A?o00001?m7X`001Ol0003oGjX0
oenZ0?mOZP3o000000?oNK4000?o0000oiBi0?nD^@000_nD^@001?l0003o//00ok;00?nb`00:o`00
00GoeYP000?o0000omf10?oMP@000_oMP@001Ol0003oi6P0onAX0?oTJ03o000000?ok4d01ol00005
ooooo`03o`000?oooooooooo00kooooo001=ooooo`03o`000?oooooooooo03Oooooo00Go0000o`0=
9ol03BOo00dWo`000002o`0D;P05o`000?l073Co01`do`0L=?l000000ol09SX01Ol0003o0350o`0a
@?l0<D3o000000;o03e700Go0000o`1;COl0Bdgo04]=o`000002o`1CC1Ko00000ol0NQl01Ol0003o
084Ao`214Ol0PA7o000000Co08P300Co0000o`f?0?l=S`3o00001?lOUP000ol0003o<id0oc>M000?
o`0000CoU;T000?o0000ok;00?nb`0000_nb`0001Ol0003oakd0olNm0?o7_@3o000000;ocj/04Ol0
0004ona=0005o`000?od<03om300oo@`0?l000001Oooool00ol0003oooooooooo`0>ooooo`00C_oo
ool00ol0003oooooooooo`0goooooaOo00000ol0Bdd01Ol0003o05=<o`1CC?l0Ddco000000?o05Y8
00Go0000o`1Q@ol0HD?o0653o`000003o`1W?005o`000?l0KS?o06hco`1^<ol000000_l0M2TBo`00
00Co7iH000Go0000oc>M0?lcW@3o<id0o`000003odVT0005o`000?mQZ`3oHJ/0of6[0?l000000omk
/P0>o`000003olNm0?l0003ocj/000;ocj/000Go0000omJF0?oFUP3oeYH0o`000005omio0004o`00
0?oUIP3oiFH0onEV00_o00001Oooool00ol0003oooooooooo`0=ooooo`00Coooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo01?ooooo6_l00003o`1d:@05o`000?l0Nago07/Mo`1k7Ol0
00000ol0PQ001Ol0003o08T1o`290Ol0R@7o000000;o3i003ol00003of6[0003o`000?mk/P3oNk80
00;oNk8000Go0000oiNi0?nG^@3oUkT0o`000004okC10003o`000?o8_03ob;`000_o00001OoNO`00
1Ol0003oiFH0onEV0?oUIP3o000000CokD/000Co0000oo@^0?od;P3om2h00_l00004ooooo`03o`00
0?oooooooooo00gooooo001@ooooo`;o0000=_ooool00ol0003oooooooooo`0/oooooa;o00000ol?
T0000ol0003o8YL0ob:G0002ob:G0004o`000?lfWP3o=Yh0o`0000?oC:D03ol00004okC10005o`00
0?o8_03ob;`0olRl0?l000000oo?Z@001?l0003oei@0omND0?oGU00:o`000003onEV0?l0003okD/0
00?okD/000Go0000oo@^0?od;P3om2h0o`000004ooooo`03o`000?oooooooooo00gooooo001Boooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0?Oooool>o`0000CoC:D000Go0000ofB/
0?mT[03oI:`0o`000003ogjc0004o`000?nJ^P3oV[X0oiZj00oo00001?oGU0001Ol0003ogWd0omim
0?oNO@3o000000?oiV@03?l00003ooooo`03o`000?oooooooooo00gooooo001Cooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0B_ooool?o`0000CoV[X000Go0000okS20?nh`P3o^<80
o`000003olVj0004o`000?o@Y`3od:L0om2W00_o00001?oVI0000ol0003okDP0one80002one80004
o`000?oe:`3omB/0ooD[00;o00000_ooool00ol0003oooooooooo`0=ooooo`00E?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo05Sooooo3ol00004om2W0005o`000?oHT@3of940omRA
0?l000000ooONP0:o`000003one80?l0003omB/000;omB/00_l000000ooooooo0000ooooo`0>oooo
o`00EOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo06Kooooo2ol00004ommj0005
o`000?oWH@3oif40onMQ0?l000000oo^AP09o`0000oooooo001Fooooo`;o0000<?ooool00ol0003o
ooooooooo`1`ooooo`_o00001?o^AP001?l0003omRP0ooHX0?of:002o`000003ooooool0003ooooo
00gooooo001Hooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0N_ooool=o`0000ko
oooo001Iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Q?ooool3o`0000kooooo
001Jooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Q?ooool3o`0000kooooo001K
ooooo`;o0000:_ooool00ol0003oooooooooo`21ooooo`Co00004Oooool005gooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1mooooo`Co00005Oooool005kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1iooooo`Co00006Oooool005oooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1fooooo`?o00007Oooool0063ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1booooo`Co00008?ooool0067ooooo0_l0000Tooooo`03o`000?oooooo
oooo06kooooo1?l0000Tooooo`00Hoooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
06[ooooo1?l0000Xooooo`00I?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Ko
oooo1?l0000/ooooo`00IOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06;ooooo
1?l0000`ooooo`00I_ooool2o`0001oooooo00?o0000ooooooooool0G_ooool4o`0003Cooooo001X
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Foooool3o`0003Sooooo001Yoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Eoooool4o`0003_ooooo001Zooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0Doooool4o`0003oooooo001[ooooo`;o0000
6_ooool00ol0003oooooooooo`1?ooooo`Co0000@oooool006gooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`Co0000Aoooool006kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`17ooooo`Co0000Boooool006oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`13ooooo`Co0000Coooool0073ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`10ooooo`?o0000Doooool0077ooooo0_l0000Dooooo`03o`000?oooooooooo03cooooo
1?l0001Fooooo`00Loooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo1?l0
001Jooooo`00M?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Cooooo1?l0001N
ooooo`00MOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo1?l0001Roooo
o`00M_ooool2o`0000oooooo00?o0000ooooooooool0;?ooool4o`0006Kooooo001hooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0:?ooool4o`0006[ooooo001iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool09_ooool3o`0006kooooo001jooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool08_ooool4o`00077ooooo001kooooo`;o00002Oooool00ol0
003oooooooooo`0Nooooo`Co0000MOooool007gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Jooooo`Co0000NOooool007kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Fooooo`Co0000OOooool007oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Booooo`Co0000POooool0083ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`Co0000QOooool0087ooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo0ol00029oooo
o`00Poooool01?l0003oooooooooool00009ooooo`Co0000S?ooool008Cooooo00?o0000ooooool0
00001Oooool4o`00093ooooo0025ooooo`;o000000?oooooo`000?l000000_l0002Dooooo`00Q_oo
ool2o`0009Sooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000_ooooo`?o0000
F?ooool3o`0001Oooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0?ooooo`00<?oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOoo
ool00ol0003oooooooooo`0>ooooo`00:_ooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5
o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000ol00007ooooo`?o00001?ooool4
o`0000?ooooo0_l00002ooooo`Ko00001_ooool5o`0000;ooooo0ol00002ooooo`?o000000Cooooo
o`000?l0003ooooo1?l00003ooooo`;o00000_ooool6o`0000Oooooo00?o0000ooooooooool00ooo
ool4o`000003ooooool0003o000000;o00000_ooool4o`0000?ooooo0ol00002ooooo`Go00000ooo
ool2o`000004ooooool0003oooooooooo`;o00000oooool3o`0000Wooooo1?l000000ooooooo0000
o`000003o`000003ooooool0003o000000;o00001?ooool2o`0000?ooooo1?l000001Ooooooo0000
o`000?l0003ooooo00;o000000Coooooo`000?l0003o00000oooool3o`0000Gooooo00?o0000oooo
ooooool03Oooool002Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Kooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000
oooooooooooo0000ooooool0000;ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000002?ooool0
0ol0003oooooooooo`0=ooooo`00:Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1_ooool3o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
0oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool00_ooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`?o0000
0oooool01?l0003oooooooooool00002ooooo`?o00000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo1Ol00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000?ooooo00?o0000ooooooooool00oooool3o`0000?ooooo00Ko0000oooooooooooo0000
ooooool00005ooooo`Go00001?ooool00ol0003oooooooooo`0=ooooo`00:Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02?ooool3o`0000;ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00005
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00003ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03Oooool002Wooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000;ooooo1?l00002oooo
o`?o00001?ooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00Co0000oooo
oooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002Oooool00ol0003oooooooooo`03
ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o00002Oooool00ol0003oooooooooo`03
ooooo`;o00001?ooool3o`0000?ooooo1?l00002ooooo`?o00001?ooool01?l0003ooooooooooooo
ool2o`000004ooooool0003o0000ooooo`Co00000oooool3o`0000Wooooo0ol00002ooooo`?o0000
1?ooool4o`000003ooooool0003o000000;o00000oooool2o`0000?ooooo1?l00003ooooo`?o0000
0oooool3o`0000Gooooo00?o0000ooooooooool03Oooool002Wooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0>ooooo`00:_ooool3o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0=ooooo`?o00002Oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`0000[ooooo
0ol0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`03o`000?oooooooooo00Kooooo
0_l0000@ooooo`?o00002_ooool00ol0003oooooooooo`0@ooooo`;o00001?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.178701, -0.0297761, \
0.0041415, 0.0041415}},
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .80819 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00131954 1.04772 -0.0720652 1.04772 [
[.5 .82069 -60 0 ]
[.5 .82069 60 9 ]
[.02856 .24287 -24 -8.71076 ]
[.02856 .24287 0 .28924 ]
[.17652 .18612 -23.5898 -9 ]
[.17652 .18612 .41022 0 ]
[.3355 .12129 -22.319 -9 ]
[.3355 .12129 1.68101 0 ]
[.5025 .05719 -21.0831 -9 ]
[.5025 .05719 2.91692 0 ]
[.68155 -0.01096 -19.8391 -9 ]
[.68155 -0.01096 4.1609 0 ]
[.7009 -0.00478 0 -6.26324 ]
[.7009 -0.00478 24 2.73676 ]
[.78177 .11679 0 -6.14316 ]
[.78177 .11679 24 2.85684 ]
[.85585 .23084 0 -6.034 ]
[.85585 .23084 6 2.966 ]
[.92174 .3327 0 -5.93891 ]
[.92174 .3327 18 3.06109 ]
[.98004 .42456 0 -5.85522 ]
[.98004 .42456 18 3.14478 ]
[.01659 .31269 -42 -2.78135 ]
[.01659 .31269 0 6.21865 ]
[.00688 .37604 -42 -2.83538 ]
[.00688 .37604 0 6.16462 ]
[-0.0045 .44837 -42 -2.89722 ]
[-0.0045 .44837 0 6.10278 ]
[ 0 0 0 0 ]
[ 1 .80819 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82069 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03812 .25182 m
.68871 0 L
s
.03812 .25182 m
.04291 .25629 L
s
[(-0.5)] .02856 .24287 1 .93573 Mshowa
.18562 .19554 m
.19017 .20025 L
s
[(-0.4)] .17652 .18612 .96582 1 Mshowa
.34404 .13122 m
.34831 .13619 L
s
[(-0.3)] .3355 .12129 .85992 1 Mshowa
.5104 .06763 m
.51435 .07285 L
s
[(-0.2)] .5025 .05719 .75692 1 Mshowa
.68871 0 m
.69229 .00548 L
s
[(-0.1)] .68155 -0.01096 .65326 1 Mshowa
.125 Mabswid
.06665 .24348 m
.06949 .24619 L
s
.09566 .23083 m
.09848 .23357 L
s
.12605 .2173 m
.12883 .22007 L
s
.15584 .20934 m
.1586 .21213 L
s
.21747 .18224 m
.22017 .18509 L
s
.24792 .16814 m
.25058 .17103 L
s
.27934 .15962 m
.28197 .16253 L
s
.31046 .14524 m
.31306 .14819 L
s
.37588 .12176 m
.37841 .12477 L
s
.40803 .10694 m
.41052 .10998 L
s
.44295 .09239 m
.4454 .09546 L
s
.47586 .08256 m
.47827 .08566 L
s
.54408 .05215 m
.54641 .05531 L
s
.58097 .04223 m
.58325 .04543 L
s
.61545 .02641 m
.61769 .02964 L
s
.65201 .01065 m
.6542 .01391 L
s
.25 Mabswid
.68871 0 m
.9675 .42834 L
s
.68871 0 m
.68261 .00239 L
s
[(-0.2)] .7009 -0.00478 -1 .39183 Mshowa
.76947 .12128 m
.76332 .12353 L
s
[(-0.1)] .78177 .11679 -1 .36515 Mshowa
.84346 .23507 m
.83726 .23718 L
s
[(0)] .85585 .23084 -1 .34089 Mshowa
.90926 .33669 m
.90303 .33868 L
s
[(0.1)] .92174 .3327 -1 .31976 Mshowa
.9675 .42834 m
.96123 .43023 L
s
[(0.2)] .98004 .42456 -1 .30116 Mshowa
.125 Mabswid
.7062 .02667 m
.70253 .02809 L
s
.72281 .05247 m
.71914 .05387 L
s
.73955 .07263 m
.73587 .07401 L
s
.75536 .09726 m
.75167 .09863 L
s
.78646 .14524 m
.78276 .14657 L
s
.79988 .16814 m
.79618 .16946 L
s
.81621 .19113 m
.8125 .19243 L
s
.82899 .21299 m
.82528 .21428 L
s
.85687 .25596 m
.85315 .25721 L
s
.87078 .27717 m
.86705 .27841 L
s
.88361 .29715 m
.87987 .29838 L
s
.89699 .31756 m
.89325 .31877 L
s
.92215 .35633 m
.9184 .35752 L
s
.9339 .37465 m
.93015 .37582 L
s
.94427 .39257 m
.94051 .39373 L
s
.95759 .41115 m
.95383 .41229 L
s
.25 Mabswid
.03812 .25182 m
0 .48742 L
s
.02883 .30801 m
.03494 .30568 L
s
[(3.75292)] .01659 .31269 1 -0.38192 Mshowa
.01916 .37149 m
.02531 .36922 L
s
[(3.75292)] .00688 .37604 1 -0.36992 Mshowa
.00784 .44397 m
.014 .44178 L
s
[(3.75292)] -0.0045 .44837 1 -0.35617 Mshowa
.125 Mabswid
.02764 .31895 m
.03131 .31755 L
s
.02525 .3309 m
.02892 .32952 L
s
.02283 .34803 m
.02651 .34666 L
s
.02035 .3592 m
.02403 .35783 L
s
.01665 .3828 m
.02034 .38144 L
s
.01544 .3953 m
.01913 .39395 L
s
.01293 .41308 m
.01663 .41175 L
s
.0104 .42586 m
.01409 .42453 L
s
.03118 .29625 m
.03485 .29484 L
s
.03235 .28545 m
.03602 .28403 L
s
.03468 .27388 m
.03834 .27246 L
s
.03575 .26242 m
.03941 .26099 L
s
.00524 .45571 m
.00894 .4544 L
s
.00395 .46886 m
.00765 .46756 L
s
.00132 .48075 m
.00503 .47946 L
s
.25 Mabswid
.03812 .25182 m
0 .48742 L
s
0 .48742 m
.39743 .80819 L
s
.39743 .80819 m
.40584 .5954 L
s
.40584 .5954 m
.03812 .25182 L
s
.68871 0 m
.9675 .42834 L
s
.9675 .42834 m
1 .65033 L
s
1 .65033 m
.7013 .24105 L
s
.7013 .24105 m
.68871 0 L
s
.03812 .25182 m
0 .48742 L
s
0 .48742 m
.7013 .24105 L
s
.7013 .24105 m
.68871 0 L
s
.68871 0 m
.03812 .25182 L
s
.40584 .5954 m
.9675 .42834 L
s
.9675 .42834 m
1 .65033 L
s
1 .65033 m
.39743 .80819 L
s
.39743 .80819 m
.40584 .5954 L
s
0 0 m
1 0 L
1 .80819 L
0 .80819 L
closepath
clip
newpath
.5 Mabswid
.146 .595 0 r
.39158 .70215 .40179 .71006 .41936 .69905 .40923 .69106 Metetra
.084 .573 0 r
.40923 .69106 .41936 .69905 .43594 .6964 .4259 .68415 Metetra
.084 .573 0 r
.4259 .68415 .43594 .6964 .4535 .69106 .44352 .68297 Metetra
.084 .573 0 r
.44352 .68297 .4535 .69106 .47026 .68415 .46036 .676 Metetra
.084 .573 0 r
.46036 .676 .47026 .68415 .48806 .67873 .47823 .67051 Metetra
.084 .573 0 r
.47823 .67051 .48806 .67873 .50601 .67752 .49625 .66926 Metetra
.084 .573 0 r
.49625 .66926 .50601 .67752 .52304 .67051 .51337 .6622 Metetra
.084 .573 0 r
.51337 .6622 .52304 .67051 .54125 .66498 .53165 .65659 Metetra
.084 .573 0 r
.53165 .65659 .54125 .66498 .55846 .6622 .54894 .64946 Metetra
.084 .573 0 r
.54894 .64946 .55846 .6622 .57692 .65659 .56748 .6481 Metetra
.084 .573 0 r
.56748 .6481 .57692 .65659 .59553 .65095 .58495 .6409 Metetra
.084 .573 0 r
.58495 .6409 .59553 .65095 .61303 .64377 .60376 .63514 Metetra
.084 .573 0 r
.60376 .63514 .61303 .64377 .63191 .64239 .62272 .62934 Metetra
.027 .55 0 r
.62272 .62934 .63191 .64239 .65069 .63078 .64025 .62057 Metetra
.027 .55 0 r
.64025 .62057 .65069 .63078 .66845 .6235 .65944 .61467 Metetra
.027 .55 0 r
.65944 .61467 .66845 .6235 .68772 .61763 .6788 .60873 Metetra
.027 .55 0 r
.6788 .60873 .68772 .61763 .70567 .61467 .69684 .60131 Metetra
.027 .55 0 r
.69684 .60131 .70567 .61467 .72522 .60873 .71648 .59972 Metetra
.027 .55 0 r
.71648 .59972 .72522 .60873 .74336 .60131 .73472 .59223 Metetra
.027 .55 0 r
.73472 .59223 .74336 .60131 .76319 .59527 .75465 .58612 Metetra
.027 .55 0 r
.75465 .58612 .76319 .59527 .7832 .59365 .77474 .58444 Metetra
.027 .55 0 r
.77474 .58444 .7832 .59365 .80166 .58612 .7933 .57684 Metetra
.027 .55 0 r
.7933 .57684 .80166 .58612 .82196 .57995 .8137 .5706 Metetra
.027 .55 0 r
.8137 .5706 .82196 .57995 .84062 .57684 .83246 .56292 Metetra
.027 .55 0 r
.83246 .56292 .84062 .57684 .86122 .5706 .85316 .56112 Metetra
.027 .55 0 r
.85316 .56112 .86122 .5706 .88199 .56429 .87213 .55337 Metetra
0 .528 .025 r
.87213 .55337 .88199 .56429 .90017 .55066 .89234 .54101 Metetra
0 .528 .025 r
.89234 .54101 .90017 .55066 .92121 .5488 .91348 .53451 Metetra
0 .528 .025 r
.91348 .53451 .92121 .5488 .94243 .54235 .93275 .53124 Metetra
0 .528 .025 r
.93275 .53124 .94243 .54235 .96173 .53451 .95421 .52465 Metetra
0 .528 .025 r
.95421 .52465 .96173 .53451 .98327 .52795 .97586 .518 Metetra
.146 .595 0 r
.38125 .69414 .39158 .70215 .40923 .69106 .39899 .68297 Metetra
.084 .573 0 r
.39899 .68297 .40923 .69106 .4259 .68415 .41573 .676 Metetra
.084 .573 0 r
.41573 .676 .4259 .68415 .44352 .68297 .43342 .67478 Metetra
.084 .573 0 r
.43342 .67478 .44352 .68297 .46036 .676 .45034 .66775 Metetra
.084 .573 0 r
.45034 .66775 .46036 .676 .47823 .67051 .46828 .6622 Metetra
.084 .573 0 r
.46828 .6622 .47823 .67051 .49625 .66926 .48538 .6551 Metetra
.084 .573 0 r
.48538 .6551 .49625 .66926 .51337 .6622 .50358 .65378 Metetra
.084 .573 0 r
.50358 .65378 .51337 .6622 .53165 .65659 .52192 .6481 Metetra
.084 .573 0 r
.52192 .6481 .53165 .65659 .54894 .64946 .53931 .6409 Metetra
.084 .573 0 r
.53931 .6409 .54894 .64946 .56748 .6481 .55792 .63514 Metetra
.084 .573 0 r
.55792 .63514 .56748 .6481 .58495 .6409 .57549 .63225 Metetra
.084 .573 0 r
.57549 .63225 .58495 .6409 .60376 .63514 .59437 .62641 Metetra
.084 .573 0 r
.59437 .62641 .60376 .63514 .62272 .62934 .61341 .62053 Metetra
.027 .55 0 r
.61341 .62053 .62272 .62934 .64025 .62057 .63105 .6073 Metetra
.027 .55 0 r
.63105 .6073 .64025 .62057 .65944 .61467 .65033 .60574 Metetra
.027 .55 0 r
.65033 .60574 .65944 .61467 .6788 .60873 .66977 .59972 Metetra
.027 .55 0 r
.66977 .59972 .6788 .60873 .69684 .60131 .68791 .59223 Metetra
.027 .55 0 r
.68791 .59223 .69684 .60131 .71648 .59972 .70763 .59059 Metetra
.027 .55 0 r
.70763 .59059 .71648 .59972 .73472 .59223 .72597 .58304 Metetra
.027 .55 0 r
.72597 .58304 .73472 .59223 .75465 .58612 .74599 .57684 Metetra
.027 .55 0 r
.74599 .57684 .75465 .58612 .77474 .58444 .76453 .56921 Metetra
.027 .55 0 r
.76453 .56921 .77474 .58444 .7933 .57684 .78484 .56745 Metetra
.027 .55 0 r
.78484 .56745 .7933 .57684 .8137 .5706 .80533 .56112 Metetra
.027 .55 0 r
.80533 .56112 .8137 .5706 .83246 .56292 .8242 .55337 Metetra
.027 .55 0 r
.8242 .55337 .83246 .56292 .85316 .56112 .845 .54694 Metetra
.027 .55 0 r
.845 .54694 .85316 .56112 .87213 .55337 .86408 .5437 Metetra
0 .528 .025 r
.86408 .5437 .87213 .55337 .89234 .54101 .8844 .53124 Metetra
0 .528 .025 r
.8844 .53124 .89234 .54101 .91348 .53451 .90564 .52465 Metetra
0 .528 .025 r
.90564 .52465 .91348 .53451 .93275 .53124 .92503 .52133 Metetra
0 .528 .025 r
.92503 .52133 .93275 .53124 .95421 .52465 .94659 .51466 Metetra
0 .528 .025 r
.94659 .51466 .95421 .52465 .97586 .518 .96835 .50792 Metetra
.146 .595 0 r
.37079 .68178 .38125 .69414 .39899 .68297 .38783 .67326 Metetra
.084 .573 0 r
.38783 .67326 .39899 .68297 .41573 .676 .40544 .66775 Metetra
.084 .573 0 r
.40544 .66775 .41573 .676 .43342 .67478 .4232 .6622 Metetra
.084 .573 0 r
.4232 .6622 .43342 .67478 .45034 .66775 .4402 .6594 Metetra
.084 .573 0 r
.4402 .6594 .45034 .66775 .46828 .6622 .45821 .65378 Metetra
.084 .573 0 r
.45821 .65378 .46828 .6622 .48538 .6551 .47539 .64662 Metetra
.084 .573 0 r
.47539 .64662 .48538 .6551 .50358 .65378 .49366 .6409 Metetra
.084 .573 0 r
.49366 .6409 .50358 .65378 .52192 .6481 .51208 .63951 Metetra
.084 .573 0 r
.51208 .63951 .52192 .6481 .53931 .6409 .52955 .63225 Metetra
.084 .573 0 r
.52955 .63225 .53931 .6409 .55792 .63514 .54824 .62641 Metetra
.084 .573 0 r
.54824 .62641 .55792 .63514 .57549 .63225 .5659 .61908 Metetra
.084 .573 0 r
.5659 .61908 .57549 .63225 .59437 .62641 .58486 .61757 Metetra
.084 .573 0 r
.58486 .61757 .59437 .62641 .61341 .62053 .6027 .61017 Metetra
.027 .55 0 r
.6027 .61017 .61341 .62053 .63105 .6073 .62174 .5983 Metetra
.027 .55 0 r
.62174 .5983 .63105 .6073 .65033 .60574 .6411 .59669 Metetra
.027 .55 0 r
.6411 .59669 .65033 .60574 .66977 .59972 .65921 .58918 Metetra
.027 .55 0 r
.65921 .58918 .66977 .59972 .68791 .59223 .67886 .58304 Metetra
.027 .55 0 r
.67886 .58304 .68791 .59223 .70763 .59059 .69867 .57684 Metetra
.027 .55 0 r
.69867 .57684 .70763 .59059 .72597 .58304 .71711 .57373 Metetra
.027 .55 0 r
.71711 .57373 .72597 .58304 .74599 .57684 .73722 .56745 Metetra
.027 .55 0 r
.73722 .56745 .74599 .57684 .76453 .56921 .75586 .55975 Metetra
.027 .55 0 r
.75586 .55975 .76453 .56921 .78484 .56745 .77627 .55337 Metetra
.027 .55 0 r
.77627 .55337 .78484 .56745 .80533 .56112 .79685 .55152 Metetra
.027 .55 0 r
.79685 .55152 .80533 .56112 .8242 .55337 .81583 .5437 Metetra
.027 .55 0 r
.81583 .5437 .8242 .55337 .845 .54694 .83672 .53718 Metetra
.027 .55 0 r
.83672 .53718 .845 .54694 .86408 .5437 .85591 .5339 Metetra
0 .528 .025 r
.85591 .5339 .86408 .5437 .8844 .53124 .87635 .52133 Metetra
0 .528 .025 r
.87635 .52133 .8844 .53124 .90564 .52465 .8977 .51466 Metetra
0 .528 .025 r
.8977 .51466 .90564 .52465 .92503 .52133 .9172 .50663 Metetra
0 .528 .025 r
.9172 .50663 .92503 .52133 .94659 .51466 .93887 .50453 Metetra
0 .528 .025 r
.93887 .50453 .94659 .51466 .96835 .50792 .96075 .4977 Metetra
.146 .595 0 r
.3602 .67355 .37079 .68178 .38783 .67326 .37734 .66498 Metetra
.084 .573 0 r
.37734 .66498 .38783 .67326 .40544 .66775 .39502 .6594 Metetra
.084 .573 0 r
.39502 .6594 .40544 .66775 .4232 .6622 .41285 .65378 Metetra
.084 .573 0 r
.41285 .65378 .4232 .6622 .4402 .6594 .42993 .64662 Metetra
.084 .573 0 r
.42993 .64662 .4402 .6594 .45821 .65378 .44801 .64525 Metetra
.084 .573 0 r
.44801 .64525 .45821 .65378 .47539 .64662 .46528 .63803 Metetra
.084 .573 0 r
.46528 .63803 .47539 .64662 .49366 .6409 .48362 .63225 Metetra
.084 .573 0 r
.48362 .63225 .49366 .6409 .51208 .63951 .50107 .62495 Metetra
.084 .573 0 r
.50107 .62495 .51208 .63951 .52955 .63225 .51968 .62348 Metetra
.084 .573 0 r
.51968 .62348 .52955 .63225 .54824 .62641 .53844 .61757 Metetra
.084 .573 0 r
.53844 .61757 .54824 .62641 .5659 .61908 .55619 .61017 Metetra
.084 .573 0 r
.55619 .61017 .5659 .61908 .58486 .61757 .57523 .60862 Metetra
.084 .573 0 r
.57523 .60862 .58486 .61757 .6027 .61017 .59317 .60115 Metetra
.027 .55 0 r
.59317 .60115 .6027 .61017 .62174 .5983 .6123 .58918 Metetra
.027 .55 0 r
.6123 .58918 .62174 .5983 .6411 .59669 .63174 .58304 Metetra
.027 .55 0 r
.63174 .58304 .6411 .59669 .65921 .58918 .64996 .57995 Metetra
.027 .55 0 r
.64996 .57995 .65921 .58918 .67886 .58304 .66969 .57373 Metetra
.027 .55 0 r
.66969 .57373 .67886 .58304 .69867 .57684 .68959 .56745 Metetra
.027 .55 0 r
.68959 .56745 .69867 .57684 .71711 .57373 .70813 .55975 Metetra
.027 .55 0 r
.70813 .55975 .71711 .57373 .73722 .56745 .72833 .55793 Metetra
.027 .55 0 r
.72833 .55793 .73722 .56745 .75586 .55975 .74707 .55016 Metetra
.027 .55 0 r
.74707 .55016 .75586 .55975 .77627 .55337 .76758 .5437 Metetra
.027 .55 0 r
.76758 .5437 .77627 .55337 .79685 .55152 .78826 .5418 Metetra
.027 .55 0 r
.78826 .5418 .79685 .55152 .81583 .5437 .80735 .5339 Metetra
.027 .55 0 r
.80735 .5339 .81583 .5437 .83672 .53718 .82834 .52729 Metetra
.027 .55 0 r
.82834 .52729 .83672 .53718 .85591 .5339 .84764 .51931 Metetra
0 .528 .025 r
.84764 .51931 .85591 .5339 .87635 .52133 .86819 .5113 Metetra
0 .528 .025 r
.86819 .5113 .87635 .52133 .8977 .51466 .88965 .50453 Metetra
0 .528 .025 r
.88965 .50453 .8977 .51466 .9172 .50663 .90926 .49643 Metetra
0 .528 .025 r
.90926 .49643 .9172 .50663 .93887 .50453 .93105 .48955 Metetra
0 .528 .025 r
.93105 .48955 .93887 .50453 .96075 .4977 .95089 .48609 Metetra
.146 .595 0 r
.34877 .6637 .3602 .67355 .37734 .66498 .36673 .65228 Metetra
.084 .573 0 r
.36673 .65228 .37734 .66498 .39502 .6594 .38447 .65095 Metetra
.084 .573 0 r
.38447 .65095 .39502 .6594 .41285 .65378 .40153 .64377 Metetra
.084 .573 0 r
.40153 .64377 .41285 .65378 .42993 .64662 .41954 .63803 Metetra
.084 .573 0 r
.41954 .63803 .42993 .64662 .44801 .64525 .43769 .63225 Metetra
.084 .573 0 r
.43769 .63225 .44801 .64525 .46528 .63803 .45504 .62934 Metetra
.084 .573 0 r
.45504 .62934 .46528 .63803 .48362 .63225 .47345 .62348 Metetra
.084 .573 0 r
.47345 .62348 .48362 .63225 .50107 .62495 .49099 .61612 Metetra
.084 .573 0 r
.49099 .61612 .50107 .62495 .51968 .62348 .50967 .6146 Metetra
.084 .573 0 r
.50967 .6146 .51968 .62348 .53844 .61757 .52851 .60862 Metetra
.084 .573 0 r
.52851 .60862 .53844 .61757 .55619 .61017 .54636 .60115 Metetra
.084 .573 0 r
.54636 .60115 .55619 .61017 .57523 .60862 .56548 .59507 Metetra
.084 .573 0 r
.56548 .59507 .57523 .60862 .59317 .60115 .58351 .59201 Metetra
.027 .55 0 r
.58351 .59201 .59317 .60115 .6123 .58918 .60275 .57995 Metetra
.027 .55 0 r
.60275 .57995 .6123 .58918 .63174 .58304 .62227 .57373 Metetra
.027 .55 0 r
.62227 .57373 .63174 .58304 .64996 .57995 .64059 .56607 Metetra
.027 .55 0 r
.64059 .56607 .64996 .57995 .66969 .57373 .6604 .56429 Metetra
.027 .55 0 r
.6604 .56429 .66969 .57373 .68959 .56745 .6804 .55793 Metetra
.027 .55 0 r
.6804 .55793 .68959 .56745 .70813 .55975 .69904 .55016 Metetra
.027 .55 0 r
.69904 .55016 .70813 .55975 .72833 .55793 .71933 .54829 Metetra
.027 .55 0 r
.71933 .54829 .72833 .55793 .74707 .55016 .73818 .54045 Metetra
.027 .55 0 r
.73818 .54045 .74707 .55016 .76758 .5437 .75878 .5339 Metetra
.027 .55 0 r
.75878 .5339 .76758 .5437 .78826 .5418 .77784 .52597 Metetra
.027 .55 0 r
.77784 .52597 .78826 .5418 .80735 .5339 .79875 .52397 Metetra
.027 .55 0 r
.79875 .52397 .80735 .5339 .82834 .52729 .81985 .51728 Metetra
.027 .55 0 r
.81985 .51728 .82834 .52729 .84764 .51931 .83926 .50922 Metetra
0 .528 .025 r
.83926 .50922 .84764 .51931 .86819 .5113 .85993 .49643 Metetra
0 .528 .025 r
.85993 .49643 .86819 .5113 .88965 .50453 .8815 .49427 Metetra
0 .528 .025 r
.8815 .49427 .88965 .50453 .90926 .49643 .90122 .48609 Metetra
0 .528 .025 r
.90122 .48609 .90926 .49643 .93105 .48955 .92312 .47911 Metetra
0 .528 .025 r
.92312 .47911 .93105 .48955 .95089 .48609 .94307 .47084 Metetra
.146 .595 0 r
.33793 .65528 .34877 .6637 .36673 .65228 .35563 .6496 Metetra
.146 .595 0 r
.35563 .6496 .36673 .65228 .38447 .65095 .37348 .64388 Metetra
.146 .595 0 r
.37348 .64388 .38447 .65095 .40153 .64377 .39066 .641 Metetra
.146 .595 0 r
.39066 .641 .40153 .64377 .41954 .63803 .40877 .6352 Metetra
.146 .595 0 r
.40877 .6352 .41954 .63803 .43769 .63225 .42613 .62788 Metetra
.146 .595 0 r
.42613 .62788 .43769 .63225 .45504 .62934 .4445 .62641 Metetra
.146 .595 0 r
.4445 .62641 .45504 .62934 .47345 .62348 .46414 .62049 Metetra
.146 .595 0 r
.46414 .62049 .47345 .62348 .49099 .61612 .4818 .61307 Metetra
.146 .595 0 r
.4818 .61307 .49099 .61612 .50967 .6146 .5006 .60705 Metetra
.146 .595 0 r
.5006 .60705 .50967 .6146 .52851 .60862 .51846 .60403 Metetra
.146 .595 0 r
.51846 .60403 .52851 .60862 .54636 .60115 .5364 .59201 Metetra
.084 .573 0 r
.5364 .59201 .54636 .60115 .56548 .59507 .5556 .58586 Metetra
.084 .573 0 r
.5556 .58586 .56548 .59507 .58351 .59201 .57373 .57824 Metetra
.027 .55 0 r
.57373 .57824 .58351 .59201 .60275 .57995 .59321 .57652 Metetra
.027 .55 0 r
.59321 .57652 .60275 .57995 .62227 .57373 .61154 .56884 Metetra
.027 .55 0 r
.61154 .56884 .62227 .57373 .64059 .56607 .63246 .5625 Metetra
.027 .55 0 r
.63246 .5625 .64059 .56607 .6604 .56429 .651 .55474 Metetra
.027 .55 0 r
.651 .55474 .6604 .56429 .6804 .55793 .66961 .54694 Metetra
.027 .55 0 r
.66961 .54694 .6804 .55793 .69904 .55016 .68982 .54045 Metetra
.027 .55 0 r
.68982 .54045 .69904 .55016 .71933 .54829 .71021 .5339 Metetra
.027 .55 0 r
.71021 .5339 .71933 .54829 .73818 .54045 .72916 .5306 Metetra
.027 .55 0 r
.72916 .5306 .73818 .54045 .75878 .5339 .74986 .52397 Metetra
.027 .55 0 r
.74986 .52397 .75878 .5339 .77784 .52597 .76902 .51596 Metetra
.027 .55 0 r
.76902 .51596 .77784 .52597 .79875 .52397 .79004 .50922 Metetra
.027 .55 0 r
.79004 .50922 .79875 .52397 .81985 .51728 .81242 .50712 Metetra
.027 .55 0 r
.81242 .50712 .81985 .51728 .83926 .50922 .83194 .49899 Metetra
.027 .55 0 r
.83194 .49899 .83926 .50922 .85993 .49643 .85348 .49209 Metetra
.027 .55 0 r
.85348 .49209 .85993 .49643 .8815 .49427 .87323 .48387 Metetra
.027 .55 0 r
.87323 .48387 .8815 .49427 .90122 .48609 .8951 .48163 Metetra
.027 .55 0 r
.8951 .48163 .90122 .48609 .92312 .47911 .91508 .47332 Metetra
.027 .55 0 r
.91508 .47332 .92312 .47911 .94307 .47084 .9373 .46621 Metetra
.146 .595 0 r
.32696 .64674 .33793 .65528 .35563 .6496 .34473 .641 Metetra
.146 .595 0 r
.34473 .641 .35563 .6496 .37348 .64388 .36264 .6352 Metetra
.146 .595 0 r
.36264 .6352 .37348 .64388 .39066 .641 .37991 .63228 Metetra
.146 .595 0 r
.37991 .63228 .39066 .641 .40877 .6352 .39808 .62641 Metetra
.146 .595 0 r
.39808 .62641 .40877 .6352 .42613 .62788 .41664 .61903 Metetra
.146 .595 0 r
.41664 .61903 .42613 .62788 .4445 .62641 .43509 .61307 Metetra
.146 .595 0 r
.43509 .61307 .4445 .62641 .46414 .62049 .45273 .61007 Metetra
.146 .595 0 r
.45273 .61007 .46414 .62049 .4818 .61307 .47145 .60403 Metetra
.146 .595 0 r
.47145 .60403 .4818 .61307 .5006 .60705 .49033 .59793 Metetra
.146 .595 0 r
.49033 .59793 .5006 .60705 .51846 .60403 .50828 .59036 Metetra
.146 .595 0 r
.50828 .59036 .51846 .60403 .5364 .59201 .52631 .58276 Metetra
.084 .573 0 r
.52631 .58276 .5364 .59201 .5556 .58586 .54559 .57652 Metetra
.084 .573 0 r
.54559 .57652 .5556 .58586 .57373 .57824 .56381 .56884 Metetra
.084 .573 0 r
.56381 .56884 .57373 .57824 .59321 .57652 .58453 .5625 Metetra
.084 .573 0 r
.58453 .5625 .59321 .57652 .61154 .56884 .60296 .55931 Metetra
.084 .573 0 r
.60296 .55931 .61154 .56884 .63246 .5625 .62283 .55289 Metetra
.027 .55 0 r
.62283 .55289 .63246 .5625 .651 .55474 .64146 .54045 Metetra
.027 .55 0 r
.64146 .54045 .651 .55474 .66961 .54694 .66018 .53718 Metetra
.027 .55 0 r
.66018 .53718 .66961 .54694 .68982 .54045 .68048 .5306 Metetra
.027 .55 0 r
.68048 .5306 .68982 .54045 .71021 .5339 .70096 .52397 Metetra
.027 .55 0 r
.70096 .52397 .71021 .5339 .72916 .5306 .72002 .51596 Metetra
.027 .55 0 r
.72002 .51596 .72916 .5306 .74986 .52397 .74082 .51391 Metetra
.027 .55 0 r
.74082 .51391 .74986 .52397 .76902 .51596 .76127 .50582 Metetra
.027 .55 0 r
.76127 .50582 .76902 .51596 .79004 .50922 .78239 .49899 Metetra
.027 .55 0 r
.78239 .49899 .79004 .50922 .81242 .50712 .80189 .49082 Metetra
.027 .55 0 r
.80189 .49082 .81242 .50712 .83194 .49899 .82334 .48862 Metetra
.027 .55 0 r
.82334 .48862 .83194 .49899 .85348 .49209 .84498 .48163 Metetra
.027 .55 0 r
.84498 .48163 .85348 .49209 .87323 .48387 .86485 .47332 Metetra
.027 .55 0 r
.86485 .47332 .87323 .48387 .8951 .48163 .88683 .47102 Metetra
.027 .55 0 r
.88683 .47102 .8951 .48163 .91508 .47332 .90693 .46263 Metetra
.027 .55 0 r
.90693 .46263 .91508 .47332 .9373 .46621 .92926 .45542 Metetra
.146 .595 0 r
.31585 .6381 .32696 .64674 .34473 .641 .33368 .63228 Metetra
.146 .595 0 r
.33368 .63228 .34473 .641 .36264 .6352 .35203 .62494 Metetra
.146 .595 0 r
.35203 .62494 .36264 .6352 .37991 .63228 .37012 .61903 Metetra
.146 .595 0 r
.37012 .61903 .37991 .63228 .39808 .62641 .38837 .61752 Metetra
.146 .595 0 r
.38837 .61752 .39808 .62641 .41664 .61903 .40592 .61007 Metetra
.146 .595 0 r
.40592 .61007 .41664 .61903 .43509 .61307 .42444 .60403 Metetra
.146 .595 0 r
.42444 .60403 .43509 .61307 .45273 .61007 .44217 .5965 Metetra
.146 .595 0 r
.44217 .5965 .45273 .61007 .47145 .60403 .46096 .59487 Metetra
.146 .595 0 r
.46096 .59487 .47145 .60403 .49033 .59793 .47992 .5887 Metetra
.146 .595 0 r
.47992 .5887 .49033 .59793 .50828 .59036 .49796 .58106 Metetra
.146 .595 0 r
.49796 .58106 .50828 .59036 .52631 .58276 .51722 .56884 Metetra
.084 .573 0 r
.51722 .56884 .52631 .58276 .54559 .57652 .53659 .56707 Metetra
.084 .573 0 r
.53659 .56707 .54559 .57652 .56381 .56884 .55492 .55931 Metetra
.084 .573 0 r
.55492 .55931 .56381 .56884 .58453 .5625 .57458 .55289 Metetra
.084 .573 0 r
.57458 .55289 .58453 .5625 .60296 .55931 .59311 .54966 Metetra
.084 .573 0 r
.59311 .54966 .60296 .55931 .62283 .55289 .61307 .54315 Metetra
.027 .55 0 r
.61307 .54315 .62283 .55289 .64146 .54045 .6318 .5306 Metetra
.027 .55 0 r
.6318 .5306 .64146 .54045 .66018 .53718 .65063 .52265 Metetra
.027 .55 0 r
.65063 .52265 .66018 .53718 .68048 .5306 .67102 .52063 Metetra
.027 .55 0 r
.67102 .52063 .68048 .5306 .70096 .52397 .69122 .5126 Metetra
.027 .55 0 r
.69122 .5126 .70096 .52397 .72002 .51596 .71194 .50582 Metetra
.027 .55 0 r
.71194 .50582 .72002 .51596 .74082 .51391 .73283 .49899 Metetra
.027 .55 0 r
.73283 .49899 .74082 .51391 .76127 .50582 .75222 .49555 Metetra
.027 .55 0 r
.75222 .49555 .76127 .50582 .78239 .49899 .77345 .48862 Metetra
.027 .55 0 r
.77345 .48862 .78239 .49899 .80189 .49082 .79306 .48037 Metetra
.027 .55 0 r
.79306 .48037 .80189 .49082 .82334 .48862 .81462 .47811 Metetra
.027 .55 0 r
.81462 .47811 .82334 .48862 .84498 .48163 .83637 .47102 Metetra
.027 .55 0 r
.83637 .47102 .84498 .48163 .86485 .47332 .85635 .46263 Metetra
.027 .55 0 r
.85635 .46263 .86485 .47332 .88683 .47102 .87845 .45542 Metetra
.027 .55 0 r
.87845 .45542 .88683 .47102 .90693 .46263 .89867 .45179 Metetra
.027 .55 0 r
.89867 .45179 .90693 .46263 .92926 .45542 .92112 .44448 Metetra
.146 .595 0 r
.30571 .62494 .31585 .6381 .33368 .63228 .32361 .62346 Metetra
.146 .595 0 r
.32361 .62346 .33368 .63228 .35203 .62494 .34094 .61605 Metetra
.146 .595 0 r
.34094 .61605 .35203 .62494 .37012 .61903 .3591 .61007 Metetra
.146 .595 0 r
.3591 .61007 .37012 .61903 .38837 .61752 .37742 .60403 Metetra
.146 .595 0 r
.37742 .60403 .38837 .61752 .40592 .61007 .39505 .60099 Metetra
.146 .595 0 r
.39505 .60099 .40592 .61007 .42444 .60403 .41365 .59487 Metetra
.146 .595 0 r
.41365 .59487 .42444 .60403 .44217 .5965 .43147 .58727 Metetra
.146 .595 0 r
.43147 .58727 .44217 .5965 .46096 .59487 .45034 .58106 Metetra
.146 .595 0 r
.45034 .58106 .46096 .59487 .47992 .5887 .46836 .57793 Metetra
.146 .595 0 r
.46836 .57793 .47992 .5887 .49796 .58106 .48752 .57163 Metetra
.146 .595 0 r
.48752 .57163 .49796 .58106 .51722 .56884 .50688 .55931 Metetra
.084 .573 0 r
.50688 .55931 .51722 .56884 .53659 .56707 .52518 .55611 Metetra
.084 .573 0 r
.52518 .55611 .53659 .56707 .55492 .55931 .54475 .54966 Metetra
.084 .573 0 r
.54475 .54966 .55492 .55931 .57458 .55289 .5645 .54315 Metetra
.084 .573 0 r
.5645 .54315 .57458 .55289 .59311 .54966 .58313 .53524 Metetra
.084 .573 0 r
.58313 .53524 .59311 .54966 .61307 .54315 .60318 .53328 Metetra
.027 .55 0 r
.60318 .53328 .61307 .54315 .6318 .5306 .62318 .52063 Metetra
.027 .55 0 r
.62318 .52063 .6318 .5306 .65063 .52265 .64211 .5126 Metetra
.027 .55 0 r
.64211 .5126 .65063 .52265 .67102 .52063 .6626 .50582 Metetra
.027 .55 0 r
.6626 .50582 .67102 .52063 .69122 .5126 .68175 .50241 Metetra
.027 .55 0 r
.68175 .50241 .69122 .5126 .71194 .50582 .70256 .49555 Metetra
.027 .55 0 r
.70256 .49555 .71194 .50582 .73283 .49899 .72356 .48862 Metetra
.027 .55 0 r
.72356 .48862 .73283 .49899 .75222 .49555 .74306 .48513 Metetra
.027 .55 0 r
.74306 .48513 .75222 .49555 .77345 .48862 .76438 .47811 Metetra
.027 .55 0 r
.76438 .47811 .77345 .48862 .79306 .48037 .78411 .46977 Metetra
.027 .55 0 r
.78411 .46977 .79306 .48037 .81462 .47811 .80577 .46263 Metetra
.027 .55 0 r
.80577 .46263 .81462 .47811 .83637 .47102 .82764 .46026 Metetra
.027 .55 0 r
.82764 .46026 .83637 .47102 .85635 .46263 .84774 .45179 Metetra
.027 .55 0 r
.84774 .45179 .85635 .46263 .87845 .45542 .86995 .44448 Metetra
.027 .55 0 r
.86995 .44448 .87845 .45542 .89867 .45179 .89029 .43592 Metetra
.027 .55 0 r
.89029 .43592 .89867 .45179 .92112 .44448 .91286 .43339 Metetra
.146 .595 0 r
.29433 .61605 .30571 .62494 .32361 .62346 .31229 .61007 Metetra
.146 .595 0 r
.31229 .61007 .32361 .62346 .34094 .61605 .32971 .60705 Metetra
.146 .595 0 r
.32971 .60705 .34094 .61605 .3591 .61007 .34794 .60099 Metetra
.146 .595 0 r
.34794 .60099 .3591 .61007 .37742 .60403 .36555 .59344 Metetra
.146 .595 0 r
.36555 .59344 .37742 .60403 .39505 .60099 .38405 .58727 Metetra
.146 .595 0 r
.38405 .58727 .39505 .60099 .41365 .59487 .40272 .58559 Metetra
.146 .595 0 r
.40272 .58559 .41365 .59487 .43147 .58727 .42063 .57793 Metetra
.146 .595 0 r
.42063 .57793 .43147 .58727 .45034 .58106 .43958 .57163 Metetra
.146 .595 0 r
.43958 .57163 .45034 .58106 .46836 .57793 .45769 .56846 Metetra
.146 .595 0 r
.45769 .56846 .46836 .57793 .48752 .57163 .47693 .56208 Metetra
.146 .595 0 r
.47693 .56208 .48752 .57163 .50688 .55931 .49639 .54966 Metetra
.084 .573 0 r
.49639 .54966 .50688 .55931 .52518 .55611 .51479 .5418 Metetra
.084 .573 0 r
.51479 .5418 .52518 .55611 .54475 .54966 .53445 .53988 Metetra
.084 .573 0 r
.53445 .53988 .54475 .54966 .5645 .54315 .55428 .53328 Metetra
.084 .573 0 r
.55428 .53328 .5645 .54315 .58313 .53524 .57301 .5253 Metetra
.084 .573 0 r
.57301 .5253 .58313 .53524 .60318 .53328 .59315 .51859 Metetra
.027 .55 0 r
.59315 .51859 .60318 .53328 .62318 .52063 .61327 .51052 Metetra
.027 .55 0 r
.61327 .51052 .62318 .52063 .64211 .5126 .6323 .50241 Metetra
.027 .55 0 r
.6323 .50241 .64211 .5126 .6626 .50582 .65289 .49555 Metetra
.027 .55 0 r
.65289 .49555 .6626 .50582 .68175 .50241 .67214 .49209 Metetra
.027 .55 0 r
.67214 .49209 .68175 .50241 .70256 .49555 .69305 .48513 Metetra
.027 .55 0 r
.69305 .48513 .70256 .49555 .72356 .48862 .71253 .47685 Metetra
.027 .55 0 r
.71253 .47685 .72356 .48862 .74306 .48513 .73376 .46977 Metetra
.027 .55 0 r
.73376 .46977 .74306 .48513 .76438 .47811 .75519 .46745 Metetra
.027 .55 0 r
.75519 .46745 .76438 .47811 .78411 .46977 .77504 .45904 Metetra
.027 .55 0 r
.77504 .45904 .78411 .46977 .80577 .46263 .79681 .45179 Metetra
.027 .55 0 r
.79681 .45179 .80577 .46263 .82764 .46026 .81689 .44329 Metetra
.027 .55 0 r
.81689 .44329 .82764 .46026 .84774 .45179 .83901 .4408 Metetra
.027 .55 0 r
.83901 .4408 .84774 .45179 .86995 .44448 .86133 .43339 Metetra
.027 .55 0 r
.86133 .43339 .86995 .44448 .89029 .43592 .8818 .42474 Metetra
.027 .55 0 r
.8818 .42474 .89029 .43592 .91286 .43339 .90448 .42214 Metetra
.146 .595 0 r
.2828 .60705 .29433 .61605 .31229 .61007 .30083 .60099 Metetra
.146 .595 0 r
.30083 .60099 .31229 .61007 .32971 .60705 .31833 .59344 Metetra
.146 .595 0 r
.31833 .59344 .32971 .60705 .34794 .60099 .33663 .59179 Metetra
.146 .595 0 r
.33663 .59179 .34794 .60099 .36555 .59344 .35433 .58417 Metetra
.146 .595 0 r
.35433 .58417 .36555 .59344 .38405 .58727 .37291 .57793 Metetra
.146 .595 0 r
.37291 .57793 .38405 .58727 .40272 .58559 .39165 .5762 Metetra
.146 .595 0 r
.39165 .5762 .40272 .58559 .42063 .57793 .40965 .56846 Metetra
.146 .595 0 r
.40965 .56846 .42063 .57793 .43958 .57163 .42868 .56208 Metetra
.146 .595 0 r
.42868 .56208 .43958 .57163 .45769 .56846 .44689 .55426 Metetra
.146 .595 0 r
.44689 .55426 .45769 .56846 .47693 .56208 .4662 .5524 Metetra
.146 .595 0 r
.4662 .5524 .47693 .56208 .49639 .54966 .48577 .53988 Metetra
.084 .573 0 r
.48577 .53988 .49639 .54966 .51479 .5418 .50427 .53194 Metetra
.084 .573 0 r
.50427 .53194 .51479 .5418 .53445 .53988 .52401 .5253 Metetra
.084 .573 0 r
.52401 .5253 .53445 .53988 .55428 .53328 .54272 .52195 Metetra
.084 .573 0 r
.54272 .52195 .55428 .53328 .57301 .5253 .56276 .51522 Metetra
.084 .573 0 r
.56276 .51522 .57301 .5253 .59315 .51859 .58299 .50843 Metetra
.027 .55 0 r
.58299 .50843 .59315 .51859 .61327 .51052 .60187 .49899 Metetra
.027 .55 0 r
.60187 .49899 .61327 .51052 .6323 .50241 .62236 .49209 Metetra
.027 .55 0 r
.62236 .49209 .6323 .50241 .65289 .49555 .64305 .48513 Metetra
.027 .55 0 r
.64305 .48513 .65289 .49555 .67214 .49209 .66241 .47685 Metetra
.027 .55 0 r
.66241 .47685 .67214 .49209 .69305 .48513 .68341 .47457 Metetra
.027 .55 0 r
.68341 .47457 .69305 .48513 .71253 .47685 .703 .46621 Metetra
.027 .55 0 r
.703 .46621 .71253 .47685 .73376 .46977 .72434 .45904 Metetra
.027 .55 0 r
.72434 .45904 .73376 .46977 .75519 .46745 .74588 .45179 Metetra
.027 .55 0 r
.74588 .45179 .75519 .46745 .77504 .45904 .76584 .44815 Metetra
.027 .55 0 r
.76584 .44815 .77504 .45904 .79681 .45179 .78772 .4408 Metetra
.027 .55 0 r
.78772 .4408 .79681 .45179 .81689 .44329 .80792 .43221 Metetra
.027 .55 0 r
.80792 .43221 .81689 .44329 .83901 .4408 .83015 .42474 Metetra
.027 .55 0 r
.83015 .42474 .83901 .4408 .86133 .43339 .85259 .42214 Metetra
.027 .55 0 r
.85259 .42214 .86133 .43339 .8818 .42474 .87318 .4134 Metetra
.027 .55 0 r
.87318 .4134 .8818 .42474 .90448 .42214 .89599 .40575 Metetra
.146 .595 0 r
.27112 .59793 .2828 .60705 .30083 .60099 .28972 .58586 Metetra
.146 .595 0 r
.28972 .58586 .30083 .60099 .31833 .59344 .30728 .57824 Metetra
.146 .595 0 r
.30728 .57824 .31833 .59344 .33663 .59179 .32561 .57652 Metetra
.146 .595 0 r
.32561 .57652 .33663 .59179 .35433 .58417 .34411 .57023 Metetra
.146 .595 0 r
.34411 .57023 .35433 .58417 .37291 .57793 .36197 .5625 Metetra
.146 .595 0 r
.36197 .5625 .37291 .57793 .39165 .5762 .38074 .55611 Metetra
.146 .595 0 r
.38074 .55611 .39165 .5762 .40965 .56846 .39881 .55289 Metetra
.146 .595 0 r
.39881 .55289 .40965 .56846 .42868 .56208 .41787 .54641 Metetra
.146 .595 0 r
.41787 .54641 .42868 .56208 .44689 .55426 .43613 .53853 Metetra
.146 .595 0 r
.43613 .53853 .44689 .55426 .4662 .5524 .45549 .53194 Metetra
.146 .595 0 r
.45549 .53194 .4662 .5524 .48577 .53988 .47501 .52996 Metetra
.084 .573 0 r
.47501 .52996 .48577 .53988 .50427 .53194 .49361 .52195 Metetra
.084 .573 0 r
.49361 .52195 .50427 .53194 .52401 .5253 .51343 .51522 Metetra
.084 .573 0 r
.51343 .51522 .52401 .5253 .54272 .52195 .53342 .50712 Metetra
.084 .573 0 r
.53342 .50712 .54272 .52195 .56276 .51522 .55232 .49899 Metetra
.084 .573 0 r
.55232 .49899 .56276 .51522 .58299 .50843 .57259 .49209 Metetra
.027 .55 0 r
.57259 .49209 .58299 .50843 .60187 .49899 .5917 .48387 Metetra
.027 .55 0 r
.5917 .48387 .60187 .49899 .62236 .49209 .61229 .48163 Metetra
.027 .55 0 r
.61229 .48163 .62236 .49209 .64305 .48513 .63307 .47457 Metetra
.027 .55 0 r
.63307 .47457 .64305 .48513 .66241 .47685 .65254 .46621 Metetra
.027 .55 0 r
.65254 .46621 .66241 .47685 .68341 .47457 .67365 .45904 Metetra
.027 .55 0 r
.67365 .45904 .68341 .47457 .703 .46621 .69335 .45542 Metetra
.027 .55 0 r
.69335 .45542 .703 .46621 .72434 .45904 .71479 .44815 Metetra
.027 .55 0 r
.71479 .44815 .72434 .45904 .74588 .45179 .73643 .4408 Metetra
.027 .55 0 r
.73643 .4408 .74588 .45179 .76584 .44815 .75651 .43221 Metetra
.027 .55 0 r
.75651 .43221 .76584 .44815 .78772 .4408 .7785 .42966 Metetra
.027 .55 0 r
.7785 .42966 .78772 .4408 .80792 .43221 .80005 .41605 Metetra
.027 .55 0 r
.80005 .41605 .80792 .43221 .83015 .42474 .82047 .40731 Metetra
.027 .55 0 r
.82047 .40731 .83015 .42474 .85259 .42214 .84297 .40462 Metetra
.027 .55 0 r
.84297 .40462 .85259 .42214 .87318 .4134 .86363 .3958 Metetra
.027 .55 0 r
.86363 .3958 .87318 .4134 .89599 .40575 .8865 .38803 Metetra
.146 .595 0 r
.25929 .5887 .27112 .59793 .28972 .58586 .27799 .57652 Metetra
.084 .573 0 r
.27799 .57652 .28972 .58586 .30728 .57824 .29563 .56884 Metetra
.084 .573 0 r
.29563 .56884 .30728 .57824 .32561 .57652 .31404 .5625 Metetra
.084 .573 0 r
.31404 .5625 .32561 .57652 .34411 .57023 .33188 .55931 Metetra
.084 .573 0 r
.33188 .55931 .34411 .57023 .36197 .5625 .35056 .55289 Metetra
.084 .573 0 r
.35056 .55289 .36197 .5625 .38074 .55611 .36941 .54641 Metetra
.084 .573 0 r
.36941 .54641 .38074 .55611 .39881 .55289 .38756 .53853 Metetra
.084 .573 0 r
.38756 .53853 .39881 .55289 .41787 .54641 .4067 .53659 Metetra
.084 .573 0 r
.4067 .53659 .41787 .54641 .43613 .53853 .42506 .52863 Metetra
.084 .573 0 r
.42506 .52863 .43613 .53853 .45549 .53194 .44449 .52195 Metetra
.084 .573 0 r
.44449 .52195 .45549 .53194 .47501 .52996 .4641 .51992 Metetra
.084 .573 0 r
.4641 .51992 .47501 .52996 .49361 .52195 .4828 .51183 Metetra
.084 .573 0 r
.4828 .51183 .49361 .52195 .51343 .51522 .50271 .50501 Metetra
.027 .55 0 r
.50271 .50501 .51343 .51522 .53342 .50712 .52281 .49209 Metetra
.027 .55 0 r
.52281 .49209 .53342 .50712 .55232 .49899 .54181 .48862 Metetra
.027 .55 0 r
.54181 .48862 .55232 .49899 .57259 .49209 .56217 .48163 Metetra
.027 .55 0 r
.56217 .48163 .57259 .49209 .5917 .48387 .58139 .47332 Metetra
.027 .55 0 r
.58139 .47332 .5917 .48387 .61229 .48163 .60207 .46621 Metetra
.027 .55 0 r
.60207 .46621 .61229 .48163 .63307 .47457 .62295 .46386 Metetra
.027 .55 0 r
.62295 .46386 .63307 .47457 .65254 .46621 .64253 .45542 Metetra
.027 .55 0 r
.64253 .45542 .65254 .46621 .67365 .45904 .66374 .44815 Metetra
.027 .55 0 r
.66374 .44815 .67365 .45904 .69335 .45542 .68355 .43961 Metetra
.027 .55 0 r
.68355 .43961 .69335 .45542 .71479 .44815 .7051 .43711 Metetra
.027 .55 0 r
.7051 .43711 .71479 .44815 .73643 .4408 .72515 .42848 Metetra
.027 .55 0 r
.72515 .42848 .73643 .4408 .75651 .43221 .74705 .42098 Metetra
.027 .55 0 r
.74705 .42098 .75651 .43221 .7785 .42966 .76915 .41836 Metetra
0 .528 .025 r
.76915 .41836 .7785 .42966 .80005 .41605 .78897 .40349 Metetra
0 .528 .025 r
.78897 .40349 .80005 .41605 .82047 .40731 .81137 .3958 Metetra
0 .528 .025 r
.81137 .3958 .82047 .40731 .84297 .40462 .83399 .38803 Metetra
0 .528 .025 r
.83399 .38803 .84297 .40462 .86363 .3958 .85478 .38412 Metetra
0 .528 .025 r
.85478 .38412 .86363 .3958 .8865 .38803 .87778 .37624 Metetra
.146 .595 0 r
.24731 .57479 .25929 .5887 .27799 .57652 .2661 .56707 Metetra
.084 .573 0 r
.2661 .56707 .27799 .57652 .29563 .56884 .28384 .55931 Metetra
.084 .573 0 r
.28384 .55931 .29563 .56884 .31404 .5625 .30231 .55289 Metetra
.084 .573 0 r
.30231 .55289 .31404 .5625 .33188 .55931 .32024 .54505 Metetra
.084 .573 0 r
.32024 .54505 .33188 .55931 .35056 .55289 .33899 .54315 Metetra
.084 .573 0 r
.33899 .54315 .35056 .55289 .36941 .54641 .35792 .53659 Metetra
.084 .573 0 r
.35792 .53659 .36941 .54641 .38756 .53853 .37617 .52863 Metetra
.084 .573 0 r
.37617 .52863 .38756 .53853 .4067 .53659 .39538 .52663 Metetra
.084 .573 0 r
.39538 .52663 .4067 .53659 .42506 .52863 .41384 .51859 Metetra
.084 .573 0 r
.41384 .51859 .42506 .52863 .44449 .52195 .43336 .51183 Metetra
.084 .573 0 r
.43336 .51183 .44449 .52195 .4641 .51992 .45304 .50501 Metetra
.084 .573 0 r
.45304 .50501 .4641 .51992 .4828 .51183 .47184 .50157 Metetra
.084 .573 0 r
.47184 .50157 .4828 .51183 .50271 .50501 .49184 .49465 Metetra
.027 .55 0 r
.49184 .49465 .50271 .50501 .52281 .49209 .51205 .48163 Metetra
.027 .55 0 r
.51205 .48163 .52281 .49209 .54181 .48862 .53116 .47332 Metetra
.027 .55 0 r
.53116 .47332 .54181 .48862 .56217 .48163 .55161 .47102 Metetra
.027 .55 0 r
.55161 .47102 .56217 .48163 .58139 .47332 .57094 .46263 Metetra
.027 .55 0 r
.57094 .46263 .58139 .47332 .60207 .46621 .59172 .45542 Metetra
.027 .55 0 r
.59172 .45542 .60207 .46621 .62295 .46386 .61128 .44694 Metetra
.027 .55 0 r
.61128 .44694 .62295 .46386 .64253 .45542 .63239 .44448 Metetra
.027 .55 0 r
.63239 .44448 .64253 .45542 .66374 .44815 .6537 .43711 Metetra
.027 .55 0 r
.6537 .43711 .66374 .44815 .68355 .43961 .67363 .42848 Metetra
.027 .55 0 r
.67363 .42848 .68355 .43961 .7051 .43711 .69528 .42591 Metetra
.027 .55 0 r
.69528 .42591 .7051 .43711 .72515 .42848 .71545 .4172 Metetra
.027 .55 0 r
.71545 .4172 .72515 .42848 .74705 .42098 .73745 .40959 Metetra
.027 .55 0 r
.73745 .40959 .74705 .42098 .76915 .41836 .75967 .4019 Metetra
0 .528 .025 r
.75967 .4019 .76915 .41836 .78897 .40349 .77962 .39192 Metetra
0 .528 .025 r
.77962 .39192 .78897 .40349 .81137 .3958 .80215 .38412 Metetra
0 .528 .025 r
.80215 .38412 .81137 .3958 .83399 .38803 .82489 .37624 Metetra
0 .528 .025 r
.82489 .37624 .83399 .38803 .85478 .38412 .84581 .36722 Metetra
0 .528 .025 r
.84581 .36722 .85478 .38412 .87778 .37624 .86892 .36427 Metetra
.146 .595 0 r
.23516 .56528 .24731 .57479 .2661 .56707 .25406 .55289 Metetra
.084 .573 0 r
.25406 .55289 .2661 .56707 .28384 .55931 .27188 .54966 Metetra
.084 .573 0 r
.27188 .54966 .28384 .55931 .30231 .55289 .29042 .54315 Metetra
.084 .573 0 r
.29042 .54315 .30231 .55289 .32024 .54505 .30845 .53524 Metetra
.084 .573 0 r
.30845 .53524 .32024 .54505 .33899 .54315 .32728 .53328 Metetra
.084 .573 0 r
.32728 .53328 .33899 .54315 .35792 .53659 .34627 .52663 Metetra
.084 .573 0 r
.34627 .52663 .35792 .53659 .37617 .52863 .36462 .51859 Metetra
.084 .573 0 r
.36462 .51859 .37617 .52863 .39538 .52663 .38391 .51183 Metetra
.084 .573 0 r
.38391 .51183 .39538 .52663 .41384 .51859 .40247 .50843 Metetra
.084 .573 0 r
.40247 .50843 .41384 .51859 .43336 .51183 .42207 .50157 Metetra
.084 .573 0 r
.42207 .50157 .43336 .51183 .45304 .50501 .44084 .49337 Metetra
.084 .573 0 r
.44084 .49337 .45304 .50501 .47184 .50157 .46074 .4864 Metetra
.084 .573 0 r
.46074 .4864 .47184 .50157 .49184 .49465 .48082 .48416 Metetra
.027 .55 0 r
.48082 .48416 .49184 .49465 .51205 .48163 .5 .46977 Metetra
.027 .55 0 r
.5 .46977 .51205 .48163 .53116 .47332 .52036 .46263 Metetra
.027 .55 0 r
.52036 .46263 .53116 .47332 .55161 .47102 .54091 .45542 Metetra
.027 .55 0 r
.54091 .45542 .55161 .47102 .57094 .46263 .56034 .45179 Metetra
.027 .55 0 r
.56034 .45179 .57094 .46263 .59172 .45542 .58122 .44448 Metetra
.027 .55 0 r
.58122 .44448 .59172 .45542 .61128 .44694 .60089 .43592 Metetra
.027 .55 0 r
.60089 .43592 .61128 .44694 .63239 .44448 .6221 .43339 Metetra
.027 .55 0 r
.6221 .43339 .63239 .44448 .6537 .43711 .64351 .42591 Metetra
.027 .55 0 r
.64351 .42591 .6537 .43711 .67363 .42848 .66356 .4172 Metetra
.027 .55 0 r
.66356 .4172 .67363 .42848 .69528 .42591 .68532 .40959 Metetra
.027 .55 0 r
.68532 .40959 .69528 .42591 .71545 .4172 .7056 .40575 Metetra
.027 .55 0 r
.7056 .40575 .71545 .4172 .73745 .40959 .72772 .39803 Metetra
.027 .55 0 r
.72772 .39803 .73745 .40959 .75967 .4019 .74826 .38913 Metetra
0 .528 .025 r
.74826 .38913 .75967 .4019 .77962 .39192 .77015 .37516 Metetra
0 .528 .025 r
.77015 .37516 .77962 .39192 .80215 .38412 .79279 .37227 Metetra
0 .528 .025 r
.79279 .37227 .80215 .38412 .82489 .37624 .81368 .36322 Metetra
0 .528 .025 r
.81368 .36322 .82489 .37624 .84581 .36722 .8367 .35516 Metetra
0 .528 .025 r
.8367 .35516 .84581 .36722 .86892 .36427 .85994 .35213 Metetra
.084 .573 0 r
.22353 .54966 .23516 .56528 .25406 .55289 .24248 .53718 Metetra
.084 .573 0 r
.24248 .53718 .25406 .55289 .27188 .54966 .26036 .5339 Metetra
.084 .573 0 r
.26036 .5339 .27188 .54966 .29042 .54315 .27893 .52729 Metetra
.084 .573 0 r
.27893 .52729 .29042 .54315 .30845 .53524 .29767 .52063 Metetra
.084 .573 0 r
.29767 .52063 .30845 .53524 .32728 .53328 .31587 .5126 Metetra
.084 .573 0 r
.31587 .5126 .32728 .53328 .34627 .52663 .3349 .51052 Metetra
.084 .573 0 r
.3349 .51052 .34627 .52663 .36462 .51859 .35331 .50241 Metetra
.084 .573 0 r
.35331 .50241 .36462 .51859 .38391 .51183 .37263 .49555 Metetra
.084 .573 0 r
.37263 .49555 .38391 .51183 .40247 .50843 .39125 .48735 Metetra
.084 .573 0 r
.39125 .48735 .40247 .50843 .42207 .50157 .41088 .48513 Metetra
.084 .573 0 r
.41088 .48513 .42207 .50157 .44084 .49337 .43069 .47811 Metetra
.084 .573 0 r
.43069 .47811 .44084 .49337 .46074 .4864 .44966 .46977 Metetra
.084 .573 0 r
.44966 .46977 .46074 .4864 .48082 .48416 .46978 .46263 Metetra
.027 .55 0 r
.46978 .46263 .48082 .48416 .5 .46977 .48888 .4651 Metetra
.027 .55 0 r
.48888 .4651 .5 .46977 .52036 .46263 .50938 .45787 Metetra
.027 .55 0 r
.50938 .45787 .52036 .46263 .54091 .45542 .52883 .44936 Metetra
.027 .55 0 r
.52883 .44936 .54091 .45542 .56034 .45179 .54966 .4469 Metetra
.027 .55 0 r
.54966 .4469 .56034 .45179 .58122 .44448 .56934 .4383 Metetra
.027 .55 0 r
.56934 .4383 .58122 .44448 .60089 .43592 .59051 .43084 Metetra
.027 .55 0 r
.59051 .43084 .60089 .43592 .6221 .43339 .61187 .42331 Metetra
.027 .55 0 r
.61187 .42331 .6221 .43339 .64351 .42591 .63194 .41952 Metetra
.027 .55 0 r
.63194 .41952 .64351 .42591 .66356 .4172 .65334 .40575 Metetra
.027 .55 0 r
.65334 .40575 .66356 .4172 .68532 .40959 .67521 .39803 Metetra
.027 .55 0 r
.67521 .39803 .68532 .40959 .7056 .40575 .69562 .38913 Metetra
.027 .55 0 r
.69562 .38913 .7056 .40575 .72772 .39803 .71785 .38631 Metetra
.027 .55 0 r
.71785 .38631 .72772 .39803 .74826 .38913 .73851 .37732 Metetra
0 .528 .025 r
.73851 .37732 .74826 .38913 .77015 .37516 .76054 .36322 Metetra
0 .528 .025 r
.76054 .36322 .77015 .37516 .79279 .37227 .78329 .36025 Metetra
0 .528 .025 r
.78329 .36025 .79279 .37227 .81368 .36322 .80431 .3511 Metetra
0 .528 .025 r
.80431 .3511 .81368 .36322 .8367 .35516 .82745 .34292 Metetra
0 .505 .073 r
.82745 .34292 .8367 .35516 .85994 .35213 .85002 .32853 Metetra
.027 .55 0 r
.21109 .53988 .22353 .54966 .24248 .53718 .23014 .52729 Metetra
.027 .55 0 r
.23014 .52729 .24248 .53718 .26036 .5339 .24812 .51931 Metetra
.027 .55 0 r
.24812 .51931 .26036 .5339 .27893 .52729 .26676 .51728 Metetra
.027 .55 0 r
.26676 .51728 .27893 .52729 .29767 .52063 .28493 .50922 Metetra
.027 .55 0 r
.28493 .50922 .29767 .52063 .31587 .5126 .30386 .50241 Metetra
.027 .55 0 r
.30386 .50241 .31587 .5126 .3349 .51052 .32297 .49555 Metetra
.027 .55 0 r
.32297 .49555 .3349 .51052 .35331 .50241 .34147 .49209 Metetra
.027 .55 0 r
.34147 .49209 .35331 .50241 .37263 .49555 .36088 .48513 Metetra
.027 .55 0 r
.36088 .48513 .37263 .49555 .39125 .48735 .3796 .47685 Metetra
.027 .55 0 r
.3796 .47685 .39125 .48735 .41088 .48513 .39931 .46977 Metetra
.027 .55 0 r
.39931 .46977 .41088 .48513 .43069 .47811 .4192 .46745 Metetra
.027 .55 0 r
.4192 .46745 .43069 .47811 .44966 .46977 .43827 .45904 Metetra
.027 .55 0 r
.43827 .45904 .44966 .46977 .46978 .46263 .45848 .45179 Metetra
.084 .573 0 r
.45848 .45179 .46978 .46263 .48888 .4651 .47767 .45423 Metetra
.084 .573 0 r
.47767 .45423 .48888 .4651 .50938 .45787 .49825 .4469 Metetra
.084 .573 0 r
.49825 .4469 .50938 .45787 .52883 .44936 .51782 .4383 Metetra
.084 .573 0 r
.51782 .4383 .52883 .44936 .54966 .4469 .53874 .43084 Metetra
.084 .573 0 r
.53874 .43084 .54966 .4469 .56934 .4383 .55854 .42708 Metetra
.084 .573 0 r
.55854 .42708 .56934 .4383 .59051 .43084 .5798 .41952 Metetra
.084 .573 0 r
.5798 .41952 .59051 .43084 .61187 .42331 .60126 .41188 Metetra
.084 .573 0 r
.60126 .41188 .61187 .42331 .63194 .41952 .62145 .40303 Metetra
.027 .55 0 r
.62145 .40303 .63194 .41952 .65334 .40575 .64298 .39414 Metetra
.027 .55 0 r
.64298 .39414 .65334 .40575 .67521 .39803 .66496 .38631 Metetra
.027 .55 0 r
.66496 .38631 .67521 .39803 .69562 .38913 .68549 .37732 Metetra
.027 .55 0 r
.68549 .37732 .69562 .38913 .71785 .38631 .70783 .37442 Metetra
.027 .55 0 r
.70783 .37442 .71785 .38631 .73851 .37732 .72862 .36533 Metetra
0 .528 .025 r
.72862 .36533 .73851 .37732 .76054 .36322 .75078 .3511 Metetra
0 .528 .025 r
.75078 .3511 .76054 .36322 .78329 .36025 .77366 .34292 Metetra
0 .528 .025 r
.77366 .34292 .78329 .36025 .80431 .3511 .79481 .3388 Metetra
0 .528 .025 r
.79481 .3388 .80431 .3511 .82745 .34292 .81807 .33051 Metetra
0 .505 .073 r
.81807 .33051 .82745 .34292 .85002 .32853 .84079 .31598 Metetra
.027 .55 0 r
.1985 .52996 .21109 .53988 .23014 .52729 .21765 .51728 Metetra
.027 .55 0 r
.21765 .51728 .23014 .52729 .24812 .51931 .23571 .50922 Metetra
.027 .55 0 r
.23571 .50922 .24812 .51931 .26676 .51728 .25442 .50241 Metetra
.027 .55 0 r
.25442 .50241 .26676 .51728 .28493 .50922 .27269 .49899 Metetra
.027 .55 0 r
.27269 .49899 .28493 .50922 .30386 .50241 .29169 .49209 Metetra
.027 .55 0 r
.29169 .49209 .30386 .50241 .32297 .49555 .31087 .48513 Metetra
.027 .55 0 r
.31087 .48513 .32297 .49555 .34147 .49209 .32948 .47685 Metetra
.027 .55 0 r
.32948 .47685 .34147 .49209 .36088 .48513 .34896 .47457 Metetra
.027 .55 0 r
.34896 .47457 .36088 .48513 .3796 .47685 .36778 .46621 Metetra
.027 .55 0 r
.36778 .46621 .3796 .47685 .39931 .46977 .38757 .45904 Metetra
.027 .55 0 r
.38757 .45904 .39931 .46977 .4192 .46745 .40661 .45542 Metetra
.027 .55 0 r
.40661 .45542 .4192 .46745 .43827 .45904 .42673 .44815 Metetra
.027 .55 0 r
.42673 .44815 .43827 .45904 .45848 .45179 .44703 .4408 Metetra
.084 .573 0 r
.44703 .4408 .45848 .45179 .47767 .45423 .46629 .4383 Metetra
.084 .573 0 r
.46629 .4383 .47767 .45423 .49825 .4469 .48697 .43577 Metetra
.084 .573 0 r
.48697 .43577 .49825 .4469 .51782 .4383 .50665 .42708 Metetra
.084 .573 0 r
.50665 .42708 .51782 .4383 .53874 .43084 .52766 .41952 Metetra
.084 .573 0 r
.52766 .41952 .53874 .43084 .55854 .42708 .54758 .41073 Metetra
.084 .573 0 r
.54758 .41073 .55854 .42708 .5798 .41952 .56894 .40803 Metetra
.084 .573 0 r
.56894 .40803 .5798 .41952 .60126 .41188 .5905 .40029 Metetra
.084 .573 0 r
.5905 .40029 .60126 .41188 .62145 .40303 .61207 .39135 Metetra
.027 .55 0 r
.61207 .39135 .62145 .40303 .64298 .39414 .63247 .38237 Metetra
.027 .55 0 r
.63247 .38237 .64298 .39414 .66496 .38631 .65456 .37442 Metetra
.027 .55 0 r
.65456 .37442 .66496 .38631 .68549 .37732 .67522 .36533 Metetra
.027 .55 0 r
.67522 .36533 .68549 .37732 .70783 .37442 .69767 .35724 Metetra
.027 .55 0 r
.69767 .35724 .70783 .37442 .72862 .36533 .71858 .35317 Metetra
0 .528 .025 r
.71858 .35317 .72862 .36533 .75078 .3511 .74088 .3388 Metetra
0 .528 .025 r
.74088 .3388 .75078 .3511 .77366 .34292 .76388 .33051 Metetra
0 .528 .025 r
.76388 .33051 .77366 .34292 .79481 .3388 .78517 .32115 Metetra
0 .528 .025 r
.78517 .32115 .79481 .3388 .81807 .33051 .80856 .3179 Metetra
0 .505 .073 r
.80856 .3179 .81807 .33051 .84079 .31598 .83141 .30324 Metetra
.027 .55 0 r
.18573 .51522 .1985 .52996 .21765 .51728 .20498 .50712 Metetra
.027 .55 0 r
.20498 .50712 .21765 .51728 .23571 .50922 .22313 .49899 Metetra
.027 .55 0 r
.22313 .49899 .23571 .50922 .25442 .50241 .24192 .49209 Metetra
.027 .55 0 r
.24192 .49209 .25442 .50241 .27269 .49899 .26028 .48387 Metetra
.027 .55 0 r
.26028 .48387 .27269 .49899 .29169 .49209 .27936 .48163 Metetra
.027 .55 0 r
.27936 .48163 .29169 .49209 .31087 .48513 .29793 .47332 Metetra
.027 .55 0 r
.29793 .47332 .31087 .48513 .32948 .47685 .31732 .46621 Metetra
.027 .55 0 r
.31732 .46621 .32948 .47685 .34896 .47457 .33688 .46386 Metetra
.027 .55 0 r
.33688 .46386 .34896 .47457 .36778 .46621 .3558 .45542 Metetra
.027 .55 0 r
.3558 .45542 .36778 .46621 .38757 .45904 .37568 .44815 Metetra
.027 .55 0 r
.37568 .44815 .38757 .45904 .40661 .45542 .39482 .43961 Metetra
.027 .55 0 r
.39482 .43961 .40661 .45542 .42673 .44815 .41502 .43711 Metetra
.027 .55 0 r
.41502 .43711 .42673 .44815 .44703 .4408 .43541 .42966 Metetra
.084 .573 0 r
.43541 .42966 .44703 .4408 .46629 .4383 .45475 .42708 Metetra
.084 .573 0 r
.45475 .42708 .46629 .4383 .48697 .43577 .47552 .41952 Metetra
.084 .573 0 r
.47552 .41952 .48697 .43577 .50665 .42708 .49531 .41571 Metetra
.084 .573 0 r
.49531 .41571 .50665 .42708 .52766 .41952 .51643 .40803 Metetra
.084 .573 0 r
.51643 .40803 .52766 .41952 .54758 .41073 .53646 .39916 Metetra
.084 .573 0 r
.53646 .39916 .54758 .41073 .56894 .40803 .55918 .39639 Metetra
.084 .573 0 r
.55918 .39639 .56894 .40803 .5905 .40029 .57946 .38742 Metetra
.084 .573 0 r
.57946 .38742 .5905 .40029 .61207 .39135 .60128 .37949 Metetra
.027 .55 0 r
.60128 .37949 .61207 .39135 .63247 .38237 .62181 .36533 Metetra
.027 .55 0 r
.62181 .36533 .63247 .38237 .65456 .37442 .64244 .3613 Metetra
.027 .55 0 r
.64244 .3613 .65456 .37442 .67522 .36533 .66479 .35317 Metetra
.027 .55 0 r
.66479 .35317 .67522 .36533 .69767 .35724 .68736 .34496 Metetra
.027 .55 0 r
.68736 .34496 .69767 .35724 .71858 .35317 .7084 .33567 Metetra
0 .528 .025 r
.7084 .33567 .71858 .35317 .74088 .3388 .73084 .32633 Metetra
0 .528 .025 r
.73084 .32633 .74088 .3388 .76388 .33051 .75396 .3179 Metetra
0 .528 .025 r
.75396 .3179 .76388 .33051 .78517 .32115 .77538 .30845 Metetra
0 .528 .025 r
.77538 .30845 .78517 .32115 .80856 .3179 .79889 .29987 Metetra
0 .505 .073 r
.79889 .29987 .80856 .3179 .83141 .30324 .8219 .2903 Metetra
.027 .55 0 r
.17358 .49899 .18573 .51522 .20498 .50712 .19171 .49082 Metetra
.027 .55 0 r
.19171 .49082 .20498 .50712 .22313 .49899 .21039 .48862 Metetra
.027 .55 0 r
.21039 .48862 .22313 .49899 .24192 .49209 .22924 .48163 Metetra
.027 .55 0 r
.22924 .48163 .24192 .49209 .26028 .48387 .24833 .46731 Metetra
.027 .55 0 r
.24833 .46731 .26028 .48387 .27936 .48163 .26744 .46498 Metetra
.027 .55 0 r
.26744 .46498 .27936 .48163 .29793 .47332 .28673 .45781 Metetra
.027 .55 0 r
.28673 .45781 .29793 .47332 .31732 .46621 .3055 .44938 Metetra
.027 .55 0 r
.3055 .44938 .31732 .46621 .33688 .46386 .32509 .44209 Metetra
.027 .55 0 r
.32509 .44209 .33688 .46386 .3558 .45542 .34408 .43842 Metetra
.027 .55 0 r
.34408 .43842 .3558 .45542 .37568 .44815 .36399 .43103 Metetra
.027 .55 0 r
.36399 .43103 .37568 .44815 .39482 .43961 .38287 .42848 Metetra
.027 .55 0 r
.38287 .42848 .39482 .43961 .41502 .43711 .40315 .42098 Metetra
.027 .55 0 r
.40315 .42098 .41502 .43711 .43541 .42966 .42363 .41836 Metetra
.084 .573 0 r
.42363 .41836 .43541 .42966 .45475 .42708 .44325 .40959 Metetra
.084 .573 0 r
.44325 .40959 .45475 .42708 .47552 .41952 .46406 .4019 Metetra
.084 .573 0 r
.46406 .4019 .47552 .41952 .49531 .41571 .48392 .39803 Metetra
.084 .573 0 r
.48392 .39803 .49531 .41571 .51643 .40803 .50629 .39639 Metetra
.084 .573 0 r
.50629 .39639 .51643 .40803 .53646 .39916 .52644 .38742 Metetra
.084 .573 0 r
.52644 .38742 .53646 .39916 .55918 .39639 .54801 .37949 Metetra
.084 .573 0 r
.54801 .37949 .55918 .39639 .57946 .38742 .56841 .3755 Metetra
.084 .573 0 r
.56841 .3755 .57946 .38742 .60128 .37949 .59034 .36747 Metetra
.027 .55 0 r
.59034 .36747 .60128 .37949 .62181 .36533 .61099 .35317 Metetra
.027 .55 0 r
.61099 .35317 .62181 .36533 .64244 .3613 .63175 .34394 Metetra
.027 .55 0 r
.63175 .34394 .64244 .3613 .66479 .35317 .65421 .34083 Metetra
.027 .55 0 r
.65421 .34083 .66479 .35317 .68736 .34496 .67652 .32633 Metetra
.027 .55 0 r
.67652 .32633 .68736 .34496 .7084 .33567 .69764 .31694 Metetra
0 .528 .025 r
.69764 .31694 .7084 .33567 .73084 .32633 .72065 .30845 Metetra
0 .505 .073 r
.72065 .30845 .73084 .32633 .75396 .3179 .74334 .29895 Metetra
0 .505 .073 r
.74334 .29895 .75396 .3179 .77538 .30845 .76484 .2894 Metetra
0 .505 .073 r
.76484 .2894 .77538 .30845 .79889 .29987 .78842 .28068 Metetra
0 .505 .073 r
.78842 .28068 .79889 .29987 .8219 .2903 .81152 .27102 Metetra
.027 .55 0 r
.1605 .48862 .17358 .49899 .19171 .49082 .17872 .48037 Metetra
.027 .55 0 r
.17872 .48037 .19171 .49082 .21039 .48862 .19747 .47811 Metetra
.027 .55 0 r
.19747 .47811 .21039 .48862 .22924 .48163 .21639 .47102 Metetra
0 .528 .025 r
.21639 .47102 .22924 .48163 .24833 .46731 .23561 .4566 Metetra
0 .528 .025 r
.23561 .4566 .24833 .46731 .26744 .46498 .2548 .44938 Metetra
0 .528 .025 r
.2548 .44938 .26744 .46498 .28673 .45781 .27416 .44694 Metetra
0 .528 .025 r
.27416 .44694 .28673 .45781 .3055 .44938 .29303 .43842 Metetra
0 .528 .025 r
.29303 .43842 .3055 .44938 .32509 .44209 .3127 .43103 Metetra
0 .528 .025 r
.3127 .43103 .32509 .44209 .34408 .43842 .33179 .42242 Metetra
0 .528 .025 r
.33179 .42242 .34408 .43842 .36399 .43103 .35179 .41982 Metetra
.027 .55 0 r
.35179 .41982 .36399 .43103 .38287 .42848 .37074 .4172 Metetra
.027 .55 0 r
.37074 .4172 .38287 .42848 .40315 .42098 .39111 .40959 Metetra
.027 .55 0 r
.39111 .40959 .40315 .42098 .42363 .41836 .4107 .40575 Metetra
.027 .55 0 r
.4107 .40575 .42363 .41836 .44325 .40959 .43141 .39803 Metetra
.027 .55 0 r
.43141 .39803 .44325 .40959 .46406 .4019 .45232 .39024 Metetra
.027 .55 0 r
.45232 .39024 .46406 .4019 .48392 .39803 .47229 .38127 Metetra
.084 .573 0 r
.47229 .38127 .48392 .39803 .50629 .39639 .49474 .38457 Metetra
.084 .573 0 r
.49474 .38457 .50629 .39639 .52644 .38742 .51501 .3755 Metetra
.084 .573 0 r
.51501 .3755 .52644 .38742 .54801 .37949 .53668 .36747 Metetra
.084 .573 0 r
.53668 .36747 .54801 .37949 .56841 .3755 .5572 .35829 Metetra
.084 .573 0 r
.5572 .35829 .56841 .3755 .59034 .36747 .57924 .35526 Metetra
.027 .55 0 r
.57924 .35526 .59034 .36747 .61099 .35317 .60131 .34083 Metetra
.027 .55 0 r
.60131 .34083 .61099 .35317 .63175 .34394 .62219 .3315 Metetra
.027 .55 0 r
.62219 .3315 .63175 .34394 .65421 .34083 .64477 .3231 Metetra
0 .528 .025 r
.64477 .3231 .65421 .34083 .67652 .32633 .66592 .31366 Metetra
0 .528 .025 r
.66592 .31366 .67652 .32633 .69764 .31694 .68717 .30417 Metetra
0 .528 .025 r
.68717 .30417 .69764 .31694 .72065 .30845 .7103 .29555 Metetra
0 .505 .073 r
.7103 .29555 .72065 .30845 .74334 .29895 .73314 .28595 Metetra
0 .505 .073 r
.73314 .28595 .74334 .29895 .76484 .2894 .75478 .27629 Metetra
0 .505 .073 r
.75478 .27629 .76484 .2894 .78842 .28068 .77849 .26745 Metetra
0 .505 .073 r
.77849 .26745 .78842 .28068 .81152 .27102 .80173 .25235 Metetra
.027 .55 0 r
.14723 .47811 .1605 .48862 .17872 .48037 .16555 .46977 Metetra
.027 .55 0 r
.16555 .46977 .17872 .48037 .19747 .47811 .18437 .46263 Metetra
.027 .55 0 r
.18437 .46263 .19747 .47811 .21639 .47102 .20336 .46026 Metetra
0 .528 .025 r
.20336 .46026 .21639 .47102 .23561 .4566 .22272 .44574 Metetra
0 .528 .025 r
.22272 .44574 .23561 .4566 .2548 .44938 .24198 .43842 Metetra
0 .528 .025 r
.24198 .43842 .2548 .44938 .27416 .44694 .26142 .43103 Metetra
0 .528 .025 r
.26142 .43103 .27416 .44694 .29303 .43842 .28038 .42731 Metetra
0 .528 .025 r
.28038 .42731 .29303 .43842 .3127 .43103 .30014 .41982 Metetra
0 .528 .025 r
.30014 .41982 .3127 .43103 .33179 .42242 .31933 .41112 Metetra
0 .528 .025 r
.31933 .41112 .33179 .42242 .35179 .41982 .33941 .40845 Metetra
.027 .55 0 r
.33941 .40845 .35179 .41982 .37074 .4172 .35844 .40575 Metetra
.027 .55 0 r
.35844 .40575 .37074 .4172 .39111 .40959 .3789 .39803 Metetra
.027 .55 0 r
.3789 .39803 .39111 .40959 .4107 .40575 .3986 .38913 Metetra
.027 .55 0 r
.3986 .38913 .4107 .40575 .43141 .39803 .4194 .38631 Metetra
.027 .55 0 r
.4194 .38631 .43141 .39803 .45232 .39024 .4404 .3784 Metetra
.027 .55 0 r
.4404 .3784 .45232 .39024 .47229 .38127 .46049 .36935 Metetra
.084 .573 0 r
.46049 .36935 .47229 .38127 .49474 .38457 .48184 .3664 Metetra
.084 .573 0 r
.48184 .3664 .49474 .38457 .51501 .3755 .5034 .36342 Metetra
.084 .573 0 r
.5034 .36342 .51501 .3755 .53668 .36747 .52518 .35526 Metetra
.084 .573 0 r
.52518 .35526 .53668 .36747 .5572 .35829 .54582 .34599 Metetra
.084 .573 0 r
.54582 .34599 .5572 .35829 .57924 .35526 .56797 .33769 Metetra
.027 .55 0 r
.56797 .33769 .57924 .35526 .60131 .34083 .59017 .3283 Metetra
.027 .55 0 r
.59017 .3283 .60131 .34083 .62219 .3315 .61118 .31887 Metetra
.027 .55 0 r
.61118 .31887 .62219 .3315 .64477 .3231 .63388 .31035 Metetra
0 .528 .025 r
.63388 .31035 .64477 .3231 .66592 .31366 .65516 .30081 Metetra
0 .528 .025 r
.65516 .30081 .66592 .31366 .68717 .30417 .67654 .29121 Metetra
0 .528 .025 r
.67654 .29121 .68717 .30417 .7103 .29555 .6998 .28247 Metetra
0 .505 .073 r
.6998 .28247 .7103 .29555 .73314 .28595 .72279 .26745 Metetra
0 .505 .073 r
.72279 .26745 .73314 .28595 .75478 .27629 .74456 .26299 Metetra
0 .505 .073 r
.74456 .26299 .75478 .27629 .77849 .26745 .7684 .25401 Metetra
0 .505 .073 r
.7684 .25401 .77849 .26745 .80173 .25235 .7918 .23877 Metetra
.027 .55 0 r
.13379 .46745 .14723 .47811 .16555 .46977 .1522 .45904 Metetra
.027 .55 0 r
.1522 .45904 .16555 .46977 .18437 .46263 .17109 .45179 Metetra
.027 .55 0 r
.17109 .45179 .18437 .46263 .20336 .46026 .18971 .44329 Metetra
0 .528 .025 r
.18971 .44329 .20336 .46026 .22272 .44574 .20964 .43474 Metetra
0 .528 .025 r
.20964 .43474 .22272 .44574 .24198 .43842 .22898 .42731 Metetra
0 .528 .025 r
.22898 .42731 .24198 .43842 .26142 .43103 .24791 .41867 Metetra
0 .528 .025 r
.24791 .41867 .26142 .43103 .28038 .42731 .26756 .41605 Metetra
0 .528 .025 r
.26756 .41605 .28038 .42731 .30014 .41982 .2874 .40845 Metetra
0 .528 .025 r
.2874 .40845 .30014 .41982 .31933 .41112 .3067 .39966 Metetra
0 .528 .025 r
.3067 .39966 .31933 .41112 .33941 .40845 .32686 .39192 Metetra
.027 .55 0 r
.32686 .39192 .33941 .40845 .35844 .40575 .34596 .39414 Metetra
.027 .55 0 r
.34596 .39414 .35844 .40575 .3789 .39803 .36651 .38631 Metetra
.027 .55 0 r
.36651 .38631 .3789 .39803 .3986 .38913 .38632 .37732 Metetra
.027 .55 0 r
.38632 .37732 .3986 .38913 .4194 .38631 .40721 .36935 Metetra
.027 .55 0 r
.40721 .36935 .4194 .38631 .4404 .3784 .42727 .36533 Metetra
.027 .55 0 r
.42727 .36533 .4404 .3784 .46049 .36935 .44852 .35724 Metetra
.084 .573 0 r
.44852 .35724 .46049 .36935 .48184 .3664 .46997 .35421 Metetra
.084 .573 0 r
.46997 .35421 .48184 .3664 .5034 .36342 .49163 .34599 Metetra
.084 .573 0 r
.49163 .34599 .5034 .36342 .52518 .35526 .51351 .34287 Metetra
.084 .573 0 r
.51351 .34287 .52518 .35526 .54582 .34599 .53428 .3335 Metetra
.084 .573 0 r
.53428 .3335 .54582 .34599 .56797 .33769 .55653 .32507 Metetra
.027 .55 0 r
.55653 .32507 .56797 .33769 .59017 .3283 .57887 .31559 Metetra
.027 .55 0 r
.57887 .31559 .59017 .3283 .61118 .31887 .60002 .30606 Metetra
.027 .55 0 r
.60002 .30606 .61118 .31887 .63388 .31035 .62282 .29741 Metetra
0 .528 .025 r
.62282 .29741 .63388 .31035 .65516 .30081 .64424 .28247 Metetra
0 .528 .025 r
.64424 .28247 .65516 .30081 .67654 .29121 .66708 .27806 Metetra
0 .528 .025 r
.66708 .27806 .67654 .29121 .6998 .28247 .69047 .26918 Metetra
0 .505 .073 r
.69047 .26918 .6998 .28247 .72279 .26745 .71227 .25401 Metetra
0 .505 .073 r
.71227 .25401 .72279 .26745 .74456 .26299 .73419 .24413 Metetra
0 .505 .073 r
.73419 .24413 .74456 .26299 .7684 .25401 .75815 .24036 Metetra
0 .505 .073 r
.75815 .24036 .7684 .25401 .7918 .23877 .78171 .22497 Metetra
.027 .55 0 r
.12016 .45179 .13379 .46745 .1522 .45904 .13867 .44815 Metetra
.027 .55 0 r
.13867 .44815 .1522 .45904 .17109 .45179 .15762 .4408 Metetra
.027 .55 0 r
.15762 .4408 .17109 .45179 .18971 .44329 .17635 .43221 Metetra
0 .528 .025 r
.17635 .43221 .18971 .44329 .20964 .43474 .19639 .42358 Metetra
0 .528 .025 r
.19639 .42358 .20964 .43474 .22898 .42731 .21579 .41605 Metetra
0 .528 .025 r
.21579 .41605 .22898 .42731 .24791 .41867 .23483 .40731 Metetra
0 .528 .025 r
.23483 .40731 .24791 .41867 .26756 .41605 .25456 .39966 Metetra
0 .528 .025 r
.25456 .39966 .26756 .41605 .2874 .40845 .27447 .39691 Metetra
0 .528 .025 r
.27447 .39691 .2874 .40845 .3067 .39966 .29388 .38803 Metetra
0 .528 .025 r
.29388 .38803 .3067 .39966 .32686 .39192 .31413 .38019 Metetra
.027 .55 0 r
.31413 .38019 .32686 .39192 .34596 .39414 .33331 .37732 Metetra
.027 .55 0 r
.33331 .37732 .34596 .39414 .36651 .38631 .35394 .37442 Metetra
.027 .55 0 r
.35394 .37442 .36651 .38631 .38632 .37732 .37387 .36533 Metetra
.027 .55 0 r
.37387 .36533 .38632 .37732 .40721 .36935 .39613 .35724 Metetra
.027 .55 0 r
.39613 .35724 .40721 .36935 .42727 .36533 .41631 .34805 Metetra
.027 .55 0 r
.41631 .34805 .42727 .36533 .44852 .35724 .43765 .34496 Metetra
.084 .573 0 r
.43765 .34496 .44852 .35724 .46997 .35421 .45792 .34185 Metetra
.084 .573 0 r
.45792 .34185 .46997 .35421 .49163 .34599 .47968 .3335 Metetra
.084 .573 0 r
.47968 .3335 .49163 .34599 .51351 .34287 .50042 .3293 Metetra
.084 .573 0 r
.50042 .3293 .51351 .34287 .53428 .3335 .52256 .32083 Metetra
.084 .573 0 r
.52256 .32083 .53428 .3335 .55653 .32507 .54492 .31227 Metetra
.027 .55 0 r
.54492 .31227 .55653 .32507 .57887 .31559 .56598 .29648 Metetra
.027 .55 0 r
.56598 .29648 .57887 .31559 .60002 .30606 .58868 .29305 Metetra
.027 .55 0 r
.58868 .29305 .60002 .30606 .62282 .29741 .6116 .28427 Metetra
0 .528 .025 r
.6116 .28427 .62282 .29741 .64424 .28247 .63448 .26918 Metetra
0 .528 .025 r
.63448 .26918 .64424 .28247 .66708 .27806 .65614 .25936 Metetra
0 .528 .025 r
.65614 .25936 .66708 .27806 .69047 .26918 .67965 .25568 Metetra
0 .505 .073 r
.67965 .25568 .69047 .26918 .71227 .25401 .70159 .24036 Metetra
0 .505 .073 r
.70159 .24036 .71227 .25401 .73419 .24413 .72365 .23037 Metetra
0 .505 .073 r
.72365 .23037 .73419 .24413 .75815 .24036 .74775 .22651 Metetra
0 .505 .073 r
.74775 .22651 .75815 .24036 .78171 .22497 .77146 .21095 Metetra
.027 .55 0 r
.10634 .4408 .12016 .45179 .13867 .44815 .12494 .43221 Metetra
.027 .55 0 r
.12494 .43221 .13867 .44815 .15762 .4408 .14397 .42966 Metetra
.027 .55 0 r
.14397 .42966 .15762 .4408 .17635 .43221 .16279 .42098 Metetra
0 .528 .025 r
.16279 .42098 .17635 .43221 .19639 .42358 .18294 .40731 Metetra
0 .528 .025 r
.18294 .40731 .19639 .42358 .21579 .41605 .20242 .40462 Metetra
0 .528 .025 r
.20242 .40462 .21579 .41605 .23483 .40731 .22156 .3958 Metetra
0 .528 .025 r
.22156 .3958 .23483 .40731 .25456 .39966 .24137 .38803 Metetra
0 .528 .025 r
.24137 .38803 .25456 .39966 .27447 .39691 .26074 .3791 Metetra
0 .528 .025 r
.26074 .3791 .27447 .39691 .29388 .38803 .28088 .37624 Metetra
0 .528 .025 r
.28088 .37624 .29388 .38803 .31413 .38019 .30121 .36828 Metetra
.027 .55 0 r
.30121 .36828 .31413 .38019 .33331 .37732 .32047 .36533 Metetra
.027 .55 0 r
.32047 .36533 .33331 .37732 .35394 .37442 .34247 .35724 Metetra
.027 .55 0 r
.34247 .35724 .35394 .37442 .37387 .36533 .36251 .35317 Metetra
.027 .55 0 r
.36251 .35317 .37387 .36533 .39613 .35724 .38359 .34496 Metetra
.027 .55 0 r
.38359 .34496 .39613 .35724 .41631 .34805 .40389 .33567 Metetra
.027 .55 0 r
.40389 .33567 .41631 .34805 .43765 .34496 .42533 .3325 Metetra
.084 .573 0 r
.42533 .3325 .43765 .34496 .45792 .34185 .44569 .3293 Metetra
.084 .573 0 r
.44569 .3293 .45792 .34185 .47968 .3335 .46755 .32083 Metetra
.084 .573 0 r
.46755 .32083 .47968 .3335 .50042 .3293 .48842 .31131 Metetra
.084 .573 0 r
.48842 .31131 .50042 .3293 .52256 .32083 .51066 .30796 Metetra
.084 .573 0 r
.51066 .30796 .52256 .32083 .54492 .31227 .53314 .29928 Metetra
.027 .55 0 r
.53314 .29928 .54492 .31227 .56598 .29648 .55436 .28336 Metetra
.027 .55 0 r
.55436 .28336 .56598 .29648 .58868 .29305 .57716 .27451 Metetra
.027 .55 0 r
.57716 .27451 .58868 .29305 .6116 .28427 .60021 .27092 Metetra
0 .528 .025 r
.60021 .27092 .6116 .28427 .63448 .26918 .62164 .25484 Metetra
0 .528 .025 r
.62164 .25484 .63448 .26918 .65614 .25936 .64503 .24575 Metetra
0 .528 .025 r
.64503 .24575 .65614 .25936 .67965 .25568 .66866 .24198 Metetra
0 .505 .073 r
.66866 .24198 .67965 .25568 .70159 .24036 .68897 .22574 Metetra
0 .505 .073 r
.68897 .22574 .70159 .24036 .72365 .23037 .71431 .2164 Metetra
0 .505 .073 r
.71431 .2164 .72365 .23037 .74775 .22651 .73855 .20696 Metetra
0 .505 .073 r
.73855 .20696 .74775 .22651 .77146 .21095 .75907 .19602 Metetra
.027 .55 0 r
.09232 .43458 .10634 .4408 .12494 .43221 .11128 .42708 Metetra
.027 .55 0 r
.11128 .42708 .12494 .43221 .14397 .42966 .13012 .42331 Metetra
.027 .55 0 r
.13012 .42331 .14397 .42966 .16279 .42098 .14939 .41571 Metetra
.027 .55 0 r
.14939 .41571 .16279 .42098 .18294 .40731 .16846 .4019 Metetra
.027 .55 0 r
.16846 .4019 .18294 .40731 .20242 .40462 .18761 .39303 Metetra
.027 .55 0 r
.18761 .39303 .20242 .40462 .22156 .3958 .20735 .39024 Metetra
.027 .55 0 r
.20735 .39024 .22156 .3958 .24137 .38803 .22727 .38237 Metetra
.027 .55 0 r
.22727 .38237 .24137 .38803 .26074 .3791 .2468 .37334 Metetra
.027 .55 0 r
.2468 .37334 .26074 .3791 .28088 .37624 .26833 .36533 Metetra
.027 .55 0 r
.26833 .36533 .28088 .37624 .30121 .36828 .2881 .3613 Metetra
.027 .55 0 r
.2881 .3613 .30121 .36828 .32047 .36533 .30872 .35317 Metetra
.027 .55 0 r
.30872 .35317 .32047 .36533 .34247 .35724 .32873 .34394 Metetra
.027 .55 0 r
.32873 .34394 .34247 .35724 .36251 .35317 .3497 .34083 Metetra
.027 .55 0 r
.3497 .34083 .36251 .35317 .38359 .34496 .36958 .33769 Metetra
.027 .55 0 r
.36958 .33769 .38359 .34496 .40389 .33567 .39096 .3293 Metetra
.027 .55 0 r
.39096 .3293 .40389 .33567 .42533 .3325 .41255 .32083 Metetra
.084 .573 0 r
.41255 .32083 .42533 .3325 .44569 .3293 .43327 .31656 Metetra
.084 .573 0 r
.43327 .31656 .44569 .3293 .46755 .32083 .45524 .30796 Metetra
.084 .573 0 r
.45524 .30796 .46755 .32083 .48842 .31131 .47623 .29834 Metetra
.084 .573 0 r
.47623 .29834 .48842 .31131 .51066 .30796 .49859 .28958 Metetra
.084 .573 0 r
.49859 .28958 .51066 .30796 .53314 .29928 .52117 .28608 Metetra
.027 .55 0 r
.52117 .28608 .53314 .29928 .55436 .28336 .54255 .27005 Metetra
.027 .55 0 r
.54255 .27005 .55436 .28336 .57716 .27451 .56548 .26106 Metetra
.027 .55 0 r
.56548 .26106 .57716 .27451 .60021 .27092 .58864 .25737 Metetra
.027 .55 0 r
.58864 .25737 .60021 .27092 .62164 .25484 .61046 .24739 Metetra
.027 .55 0 r
.61046 .24739 .62164 .25484 .64503 .24575 .63403 .23817 Metetra
0 .528 .025 r
.63403 .23817 .64503 .24575 .66866 .24198 .65751 .22261 Metetra
0 .528 .025 r
.65751 .22261 .66866 .24198 .68897 .22574 .67974 .2179 Metetra
0 .505 .073 r
.67974 .2179 .68897 .22574 .71431 .2164 .70392 .20843 Metetra
0 .505 .073 r
.70392 .20843 .71431 .2164 .73855 .20696 .72645 .19814 Metetra
0 .505 .073 r
.72645 .19814 .73855 .20696 .75907 .19602 .75048 .18226 Metetra
.084 .573 0 r
.0781 .42331 .09232 .43458 .11128 .42708 .09713 .41571 Metetra
.084 .573 0 r
.09713 .41571 .11128 .42708 .13012 .42331 .11607 .40689 Metetra
.084 .573 0 r
.11607 .40689 .13012 .42331 .14939 .41571 .13542 .40417 Metetra
.027 .55 0 r
.13542 .40417 .14939 .41571 .16846 .4019 .15458 .39024 Metetra
.027 .55 0 r
.15458 .39024 .16846 .4019 .18761 .39303 .17384 .38127 Metetra
.027 .55 0 r
.17384 .38127 .18761 .39303 .20735 .39024 .19492 .37334 Metetra
.027 .55 0 r
.19492 .37334 .20735 .39024 .22727 .38237 .21441 .36935 Metetra
.027 .55 0 r
.21441 .36935 .22727 .38237 .2468 .37334 .23457 .3613 Metetra
.027 .55 0 r
.23457 .3613 .2468 .37334 .26833 .36533 .25492 .35317 Metetra
.027 .55 0 r
.25492 .35317 .26833 .36533 .2881 .3613 .2748 .34908 Metetra
.027 .55 0 r
.2748 .34908 .2881 .3613 .30872 .35317 .29551 .34083 Metetra
.027 .55 0 r
.29551 .34083 .30872 .35317 .32873 .34394 .31563 .3315 Metetra
.027 .55 0 r
.31563 .3315 .32873 .34394 .3497 .34083 .33669 .3231 Metetra
.084 .573 0 r
.33669 .3231 .3497 .34083 .36958 .33769 .35666 .32507 Metetra
.084 .573 0 r
.35666 .32507 .36958 .33769 .39096 .3293 .37813 .31656 Metetra
.084 .573 0 r
.37813 .31656 .39096 .3293 .41255 .32083 .39982 .30796 Metetra
.084 .573 0 r
.39982 .30796 .41255 .32083 .43327 .31656 .42067 .29834 Metetra
.084 .573 0 r
.42067 .29834 .43327 .31656 .45524 .30796 .44274 .2949 Metetra
.084 .573 0 r
.44274 .2949 .45524 .30796 .47623 .29834 .46386 .28517 Metetra
.084 .573 0 r
.46386 .28517 .47623 .29834 .49859 .28958 .48632 .27628 Metetra
.084 .573 0 r
.48632 .27628 .49859 .28958 .52117 .28608 .50772 .26643 Metetra
.027 .55 0 r
.50772 .26643 .52117 .28608 .54255 .27005 .53056 .25652 Metetra
.027 .55 0 r
.53056 .25652 .54255 .27005 .56548 .26106 .5536 .24739 Metetra
.027 .55 0 r
.5536 .24739 .56548 .26106 .58864 .25737 .57539 .23736 Metetra
.027 .55 0 r
.57539 .23736 .58864 .25737 .61046 .24739 .59885 .23352 Metetra
.027 .55 0 r
.59885 .23352 .61046 .24739 .63403 .23817 .62254 .22415 Metetra
0 .528 .025 r
.62254 .22415 .63403 .23817 .65751 .22261 .64449 .20769 Metetra
0 .528 .025 r
.64449 .20769 .65751 .22261 .67974 .2179 .66855 .19814 Metetra
0 .528 .025 r
.66855 .19814 .67974 .2179 .70392 .20843 .69287 .19402 Metetra
0 .528 .025 r
.69287 .19402 .70392 .20843 .72645 .19814 .71555 .18361 Metetra
0 .505 .073 r
.71555 .18361 .72645 .19814 .75048 .18226 .73974 .16757 Metetra
.084 .573 0 r
.06368 .41188 .0781 .42331 .09713 .41571 .08278 .40417 Metetra
.084 .573 0 r
.08278 .40417 .09713 .41571 .11607 .40689 .10182 .39526 Metetra
.084 .573 0 r
.10182 .39526 .11607 .40689 .13542 .40417 .12124 .38742 Metetra
.027 .55 0 r
.12124 .38742 .13542 .40417 .15458 .39024 .14177 .3784 Metetra
.027 .55 0 r
.14177 .3784 .15458 .39024 .17384 .38127 .16114 .36935 Metetra
.027 .55 0 r
.16114 .36935 .17384 .38127 .19492 .37334 .18104 .3613 Metetra
.027 .55 0 r
.18104 .3613 .19492 .37334 .21441 .36935 .20064 .35724 Metetra
.027 .55 0 r
.20064 .35724 .21441 .36935 .23457 .3613 .22088 .34908 Metetra
.027 .55 0 r
.22088 .34908 .23457 .3613 .25492 .35317 .24131 .34083 Metetra
.027 .55 0 r
.24131 .34083 .25492 .35317 .2748 .34908 .26131 .3315 Metetra
.027 .55 0 r
.26131 .3315 .2748 .34908 .29551 .34083 .2821 .3283 Metetra
.027 .55 0 r
.2821 .3283 .29551 .34083 .31563 .3315 .30234 .31887 Metetra
.027 .55 0 r
.30234 .31887 .31563 .3315 .33669 .3231 .32349 .31035 Metetra
.084 .573 0 r
.32349 .31035 .33669 .3231 .35666 .32507 .34354 .30701 Metetra
.084 .573 0 r
.34354 .30701 .35666 .32507 .37813 .31656 .36511 .30363 Metetra
.084 .573 0 r
.36511 .30363 .37813 .31656 .39982 .30796 .38592 .29397 Metetra
.084 .573 0 r
.38592 .29397 .39982 .30796 .42067 .29834 .40788 .28517 Metetra
.084 .573 0 r
.40788 .28517 .42067 .29834 .44274 .2949 .43005 .27628 Metetra
.084 .573 0 r
.43005 .27628 .44274 .2949 .46386 .28517 .4513 .2718 Metetra
.084 .573 0 r
.4513 .2718 .46386 .28517 .48632 .27628 .47387 .26277 Metetra
.084 .573 0 r
.47387 .26277 .48632 .27628 .50772 .26643 .4954 .25281 Metetra
.027 .55 0 r
.4954 .25281 .50772 .26643 .53056 .25652 .51839 .24279 Metetra
.027 .55 0 r
.51839 .24279 .53056 .25652 .5536 .24739 .54155 .23352 Metetra
.027 .55 0 r
.54155 .23352 .5536 .24739 .57539 .23736 .56348 .22337 Metetra
.027 .55 0 r
.56348 .22337 .57539 .23736 .59885 .23352 .58705 .21393 Metetra
.027 .55 0 r
.58705 .21393 .59885 .23352 .62254 .22415 .61088 .20991 Metetra
0 .528 .025 r
.61088 .20991 .62254 .22415 .64449 .20769 .63299 .19332 Metetra
0 .528 .025 r
.63299 .19332 .64449 .20769 .66855 .19814 .65719 .18361 Metetra
0 .528 .025 r
.65719 .18361 .66855 .19814 .69287 .19402 .68164 .1738 Metetra
0 .528 .025 r
.68164 .1738 .69287 .19402 .71555 .18361 .70447 .16885 Metetra
0 .505 .073 r
.70447 .16885 .71555 .18361 .73974 .16757 .72882 .15265 Metetra
.084 .573 0 r
.04906 .39526 .06368 .41188 .08278 .40417 .06822 .39246 Metetra
.084 .573 0 r
.06822 .39246 .08278 .40417 .10182 .39526 .08736 .38346 Metetra
.084 .573 0 r
.08736 .38346 .10182 .39526 .12124 .38742 .10685 .3755 Metetra
.027 .55 0 r
.10685 .3755 .12124 .38742 .14177 .3784 .1275 .3664 Metetra
.027 .55 0 r
.1275 .3664 .14177 .3784 .16114 .36935 .14698 .35724 Metetra
.027 .55 0 r
.14698 .35724 .16114 .36935 .18104 .3613 .16695 .34908 Metetra
.027 .55 0 r
.16695 .34908 .18104 .3613 .20064 .35724 .18667 .33981 Metetra
.027 .55 0 r
.18667 .33981 .20064 .35724 .22088 .34908 .20698 .33667 Metetra
.027 .55 0 r
.20698 .33667 .22088 .34908 .24131 .34083 .2275 .3283 Metetra
.027 .55 0 r
.2275 .3283 .24131 .34083 .26131 .3315 .24761 .31887 Metetra
.027 .55 0 r
.24761 .31887 .26131 .3315 .2821 .3283 .26849 .31035 Metetra
.027 .55 0 r
.26849 .31035 .2821 .3283 .30234 .31887 .28885 .30606 Metetra
.027 .55 0 r
.28885 .30606 .30234 .31887 .32349 .31035 .31009 .29741 Metetra
.084 .573 0 r
.31009 .29741 .32349 .31035 .34354 .30701 .33072 .28776 Metetra
.084 .573 0 r
.33072 .28776 .34354 .30701 .36511 .30363 .35233 .27895 Metetra
.084 .573 0 r
.35233 .27895 .36511 .30363 .38592 .29397 .37417 .27539 Metetra
.084 .573 0 r
.37417 .27539 .38592 .29397 .40788 .28517 .39522 .26556 Metetra
.084 .573 0 r
.39522 .26556 .40788 .28517 .43005 .27628 .41744 .25652 Metetra
.084 .573 0 r
.41744 .25652 .43005 .27628 .4513 .2718 .43877 .25197 Metetra
.084 .573 0 r
.43877 .25197 .4513 .2718 .47387 .26277 .46139 .24279 Metetra
.084 .573 0 r
.46139 .24279 .47387 .26277 .4954 .25281 .48425 .23352 Metetra
.027 .55 0 r
.48425 .23352 .4954 .25281 .51839 .24279 .50603 .22337 Metetra
.027 .55 0 r
.50603 .22337 .51839 .24279 .54155 .23352 .52929 .21318 Metetra
.027 .55 0 r
.52929 .21318 .54155 .23352 .56348 .22337 .55275 .20365 Metetra
.027 .55 0 r
.55275 .20365 .56348 .22337 .58705 .21393 .57494 .19332 Metetra
.027 .55 0 r
.57494 .19332 .58705 .21393 .61088 .20991 .59882 .18361 Metetra
0 .528 .025 r
.59882 .18361 .61088 .20991 .63299 .19332 .62131 .17872 Metetra
0 .528 .025 r
.62131 .17872 .63299 .19332 .65719 .18361 .64564 .16885 Metetra
0 .528 .025 r
.64564 .16885 .65719 .18361 .68164 .1738 .66843 .15826 Metetra
0 .505 .073 r
.66843 .15826 .68164 .1738 .70447 .16885 .69276 .14762 Metetra
0 .505 .073 r
.69276 .14762 .70447 .16885 .72882 .15265 .71773 .13748 Metetra
.084 .573 0 r
.03422 .38346 .04906 .39526 .06822 .39246 .05345 .38059 Metetra
.084 .573 0 r
.05345 .38059 .06822 .39246 .08736 .38346 .0727 .37149 Metetra
.084 .573 0 r
.0727 .37149 .08736 .38346 .10685 .3755 .09226 .36342 Metetra
.027 .55 0 r
.09226 .36342 .10685 .3755 .1275 .3664 .11302 .34908 Metetra
.027 .55 0 r
.11302 .34908 .1275 .3664 .14698 .35724 .13261 .34496 Metetra
.027 .55 0 r
.13261 .34496 .14698 .35724 .16695 .34908 .15266 .33667 Metetra
.027 .55 0 r
.15266 .33667 .16695 .34908 .18667 .33981 .17248 .32731 Metetra
.027 .55 0 r
.17248 .32731 .18667 .33981 .20698 .33667 .19288 .31887 Metetra
.027 .55 0 r
.19288 .31887 .20698 .33667 .2275 .3283 .21295 .31462 Metetra
.027 .55 0 r
.21295 .31462 .2275 .3283 .24761 .31887 .23371 .30606 Metetra
.027 .55 0 r
.23371 .30606 .24761 .31887 .26849 .31035 .25467 .29741 Metetra
.027 .55 0 r
.25467 .29741 .26849 .31035 .28885 .30606 .27515 .28776 Metetra
.027 .55 0 r
.27515 .28776 .28885 .30606 .31009 .29741 .29649 .28427 Metetra
.027 .55 0 r
.29649 .28427 .31009 .29741 .33072 .28776 .31723 .27451 Metetra
.027 .55 0 r
.31723 .27451 .33072 .28776 .35233 .27895 .33895 .26556 Metetra
.027 .55 0 r
.33895 .26556 .35233 .27895 .37417 .27539 .36088 .26191 Metetra
.027 .55 0 r
.36088 .26191 .37417 .27539 .39522 .26556 .38206 .25197 Metetra
.027 .55 0 r
.38206 .25197 .39522 .26556 .41744 .25652 .40439 .24279 Metetra
.027 .55 0 r
.40439 .24279 .41744 .25652 .43877 .25197 .42585 .23273 Metetra
.027 .55 0 r
.42585 .23273 .43877 .25197 .46139 .24279 .44858 .22885 Metetra
.027 .55 0 r
.44858 .22885 .46139 .24279 .48425 .23352 .47032 .21866 Metetra
.027 .55 0 r
.47032 .21866 .48425 .23352 .50603 .22337 .49347 .20916 Metetra
0 .528 .025 r
.49347 .20916 .50603 .22337 .52929 .21318 .51688 .19332 Metetra
0 .528 .025 r
.51688 .19332 .52929 .21318 .55275 .20365 .53904 .18848 Metetra
0 .528 .025 r
.53904 .18848 .55275 .20365 .57494 .19332 .5628 .17872 Metetra
0 .528 .025 r
.5628 .17872 .57494 .19332 .59882 .18361 .58681 .16885 Metetra
0 .528 .025 r
.58681 .16885 .59882 .18361 .62131 .17872 .60945 .16388 Metetra
0 .528 .025 r
.60945 .16388 .62131 .17872 .64564 .16885 .6339 .15386 Metetra
0 .528 .025 r
.6339 .15386 .64564 .16885 .66843 .15826 .65685 .14314 Metetra
0 .505 .073 r
.65685 .14314 .66843 .15826 .69276 .14762 .68134 .12669 Metetra
0 .505 .073 r
.68134 .12669 .69276 .14762 .71773 .13748 .70646 .12206 Metetra
.084 .573 0 r
.01916 .37149 .03422 .38346 .05345 .38059 .03837 .36235 Metetra
.084 .573 0 r
.03837 .36235 .05345 .38059 .0727 .37149 .05781 .35935 Metetra
.084 .573 0 r
.05781 .35935 .0727 .37149 .09226 .36342 .07745 .35115 Metetra
.027 .55 0 r
.07745 .35115 .09226 .36342 .11302 .34908 .09809 .33567 Metetra
.027 .55 0 r
.09809 .33567 .11302 .34908 .13261 .34496 .11802 .32731 Metetra
.027 .55 0 r
.11802 .32731 .13261 .34496 .15266 .33667 .13815 .32409 Metetra
.027 .55 0 r
.13815 .32409 .15266 .33667 .17248 .32731 .15809 .31462 Metetra
.027 .55 0 r
.15809 .31462 .17248 .32731 .19288 .31887 .17856 .30606 Metetra
.027 .55 0 r
.17856 .30606 .19288 .31887 .21295 .31462 .19875 .29648 Metetra
.027 .55 0 r
.19875 .29648 .21295 .31462 .23371 .30606 .21959 .29305 Metetra
.027 .55 0 r
.21959 .29305 .23371 .30606 .25467 .29741 .24065 .28427 Metetra
.027 .55 0 r
.24065 .28427 .25467 .29741 .27515 .28776 .26125 .27451 Metetra
.027 .55 0 r
.26125 .27451 .27515 .28776 .29649 .28427 .28268 .27092 Metetra
.027 .55 0 r
.28268 .27092 .29649 .28427 .31723 .27451 .30355 .26106 Metetra
.027 .55 0 r
.30355 .26106 .31723 .27451 .33895 .26556 .32536 .25197 Metetra
.027 .55 0 r
.32536 .25197 .33895 .26556 .36088 .26191 .3465 .24198 Metetra
.027 .55 0 r
.3465 .24198 .36088 .26191 .38206 .25197 .3687 .23817 Metetra
.027 .55 0 r
.3687 .23817 .38206 .25197 .40439 .24279 .39114 .22885 Metetra
.027 .55 0 r
.39114 .22885 .40439 .24279 .42585 .23273 .41273 .21866 Metetra
.027 .55 0 r
.41273 .21866 .42585 .23273 .44858 .22885 .43557 .20916 Metetra
.027 .55 0 r
.43557 .20916 .44858 .22885 .47032 .21866 .45745 .20438 Metetra
.027 .55 0 r
.45745 .20438 .47032 .21866 .49347 .20916 .48071 .19473 Metetra
0 .528 .025 r
.48071 .19473 .49347 .20916 .51688 .19332 .50428 .17872 Metetra
0 .528 .025 r
.50428 .17872 .51688 .19332 .53904 .18848 .52658 .1738 Metetra
0 .528 .025 r
.52658 .1738 .53904 .18848 .5628 .17872 .55046 .16388 Metetra
0 .528 .025 r
.55046 .16388 .5628 .17872 .58681 .16885 .5746 .15386 Metetra
0 .528 .025 r
.5746 .15386 .58681 .16885 .60945 .16388 .59739 .14314 Metetra
0 .528 .025 r
.59739 .14314 .60945 .16388 .6339 .15386 .62198 .13862 Metetra
0 .528 .025 r
.62198 .13862 .6339 .15386 .65685 .14314 .64508 .12777 Metetra
0 .505 .073 r
.64508 .12777 .65685 .14314 .68134 .12669 .66974 .11114 Metetra
0 .505 .073 r
.66974 .11114 .68134 .12669 .70646 .12206 .695 .10064 Metetra
0 g
.25 Mabswid
.68871 0 m
.9675 .42834 L
s
.9675 .42834 m
1 .65033 L
s
1 .65033 m
.7013 .24105 L
s
.7013 .24105 m
.68871 0 L
s
.03812 .25182 m
0 .48742 L
s
0 .48742 m
.7013 .24105 L
s
.7013 .24105 m
.68871 0 L
s
.68871 0 m
.03812 .25182 L
s
.03812 .25182 m
.68871 0 L
s
.03812 .25182 m
.04291 .25629 L
s
[(-0.5)] .02856 .24287 1 .93573 Mshowa
.18562 .19554 m
.19017 .20025 L
s
[(-0.4)] .17652 .18612 .96582 1 Mshowa
.34404 .13122 m
.34831 .13619 L
s
[(-0.3)] .3355 .12129 .85992 1 Mshowa
.5104 .06763 m
.51435 .07285 L
s
[(-0.2)] .5025 .05719 .75692 1 Mshowa
.68871 0 m
.69229 .00548 L
s
[(-0.1)] .68155 -0.01096 .65326 1 Mshowa
.125 Mabswid
.06665 .24348 m
.06949 .24619 L
s
.09566 .23083 m
.09848 .23357 L
s
.12605 .2173 m
.12883 .22007 L
s
.15584 .20934 m
.1586 .21213 L
s
.21747 .18224 m
.22017 .18509 L
s
.24792 .16814 m
.25058 .17103 L
s
.27934 .15962 m
.28197 .16253 L
s
.31046 .14524 m
.31306 .14819 L
s
.37588 .12176 m
.37841 .12477 L
s
.40803 .10694 m
.41052 .10998 L
s
.44295 .09239 m
.4454 .09546 L
s
.47586 .08256 m
.47827 .08566 L
s
.54408 .05215 m
.54641 .05531 L
s
.58097 .04223 m
.58325 .04543 L
s
.61545 .02641 m
.61769 .02964 L
s
.65201 .01065 m
.6542 .01391 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 232.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000j2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00_?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0005Ko
oooo002kooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0EOooool00;Cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0EOooool00;_ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`1Eooooo`00^oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo05Gooooo002kooooo`04o`000?ooooooooooo`0000So
oooo0_l0000;ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0003gooooo002looooo`;o
00002_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo0000?Oooool00<cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool0?Oooool00=?ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0l
ooooo`00doooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000?Ooo
ool00<Sooooo0_l00009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00000mooooo`00aOooool5o`0000[ooooo0_l00009ooooo`?o0000?_ooool00<?ooooo0_l00004
ooooo`;o0000EOooool00<3ooooo0ol00006ooooo`03o`000?oooooo000005Cooooo002mooooo`?o
00002Oooool00ol0003oooooo`00001Dooooo`00TOooool2o`0000Cooooo00Co0000oooooooooooo
oooo1Ol0000Kooooo`;o00003?ooool01?l0003oooooooooool0001Cooooo`00T?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0001Sooooo0ol0000>ooooo`05o`000?oooooo
ooooooooool00000D_ooool008Wooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool05_ooool2o`000003ooooool0003ooooo00kooooo00Go0000oooooooooooooooo
o`00001Booooo`00T?ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo01;ooooo
0ol0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Coooool0093ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000013ooooo0ol0000Fooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0C_ooool0093ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000kooooo0ol0000Iooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0C_ooool0097ooooo0_l00009ooooo`?o00003?ooool3o`0000?o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04go
oooo002Xooooo`?o00007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04cooooo
002Vooooo`Co00008?ooool00ol0003oooooooooo`03ooooo`;o0000C_ooool00:?ooooo0ol0000T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00:7ooooo0_l0000Woooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool009kooooo0ol0000Yooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool009cooooo0_l00003ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool01oooool2o`0004[ooooo002Iooooo`?o0000;_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Wooooo002Gooooo`;o0000<Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Sooooo001Zooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00007?ooool3o`0000;ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo04Oooooo001Yooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Hooooo`?o0000=_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo04Oooooo001Rooooo`Go00000_ooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo01Cooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0A_ooool006Wooooo00Co0000oooooooooooo00002Oooool2o`0001Cooooo0ol0000k
ooooo`;o00003?ooool2o`0000gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000[
ooooo`00JOooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00oooooo0_l0000l
ooooo`Co00003?ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0:_ooool006Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000kooooo0ol0000looooo`;o00000_l0PA800ol0003o084Bo`00000<ooooo`03o`00
0?oooooooooo00?ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool0:_ooool006[ooooo0_l00009ooooo`?o00003?ooool3o`0000;ooooo00?o0000ooooooooool0
>?ooool2o`0000Co084B00?o0000o`214_l000003Oooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool0:_ooool008;ooooo0_l0000oooooo`04o`00
0?l0PA;o084Bo`0000?o084B00?o0000o`214_l000003Oooool00ol0003oooooooooo`09ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0:_ooool007oooooo0ol0000oooooo`;o
00001?l0PA800ol0003o084Bo`214P04o`0000gooooo0_l00009ooooo`04o`000?ooooooooooo`00
00Sooooo0_l0000/ooooo`00OOooool2o`0000?ooooo00?o0000ooooooooool0>oooool00ol0003o
084Bo`214P04o`214PGo000000?o084Bo`000?ooool03?ooool2o`0000[ooooo0_l0000:ooooo`03
o`000?oooooooooo02[ooooo001jooooo`?o0000@Oooool2o`0000Ko084B00?o0000o`214_l00000
0_l0PA801?l0003o084Bo`214_l0000=ooooo`03o`000?oooooooooo047ooooo001hooooo`?o0000
@?ooool3o`0000;o08L600Co0000o`214_l0PA;o084B0_l00003o`214P03o`000?l0PA;o000000?o
084B00?o0000ooooooooool02oooool00ol0003oooooooooo`10ooooo`00MOooool3o`0000?ooooo
00?o0000ooooooooool0>Oooool4o`0000Ko08L600?o0000o`214_l000001Ol0PA800ol0003o084B
o`000003o`214P;o00003Oooool00ol0003oooooooooo`0oooooo`00L_ooool3o`0003kooooo1?l0
0003o`271P03o`000?l0Q`Ko08L600Co08L60_l00006o`214P03o`000?l0PA;o000000?o00000_l0
PA800ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03oooooo001`ooooo`Co0000?Oooool2
o`000003o`271_l0003o08L600Go08L600Co0000o`271_l0Q`Ko08L60_l000000ol0Q`Ko0000o`21
4P05o`214P?o00001_l0PA800ol0003oooooooooo`0:ooooo`;o0000?oooool004Cooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo0ol0000Jooooo`?o0000@?ooool00ol0003o08L6o`271P02
o`271P03o`000?l0Q`Ko08L600Co08L600?o0000o`271_l000001?l0Q`H01?l0003o084Bo`214_l0
PA82o`000003o`214_l0003o000000Ko084B0_l0000<ooooo`03o`000?oooooooooo03gooooo0013
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool05oooool2o`00047ooooo0_l0
0006o`271P03o`000?l0Q`Ko08L600?o08L60_l00006o`271P03o`000?l0PA;o000000Co084B00?o
0000o`214_l0PA800ol0PA800ol0003o084Bo`00000<ooooo`03o`000?oooooooooo03gooooo000l
ooooo`Go00000_ooool01?l0003oooooooooool00007ooooo`Go00005Oooool4o`0003oooooo0ol0
0002o`271P03o`000?l0Q`Ko08L600?o08L600?o0000o`271_l0Q`H00ol000000ol0Q`Ko0000o`27
1P05o`271P;o00001Ol0PA82o`0000;o084B0_l00003o`214P03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0??ooool004?ooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool0000Cooooo`?o00001?ooool00ol0003oooooooooo`0iooooo`?o00001_l0Q`H01?l0003o08L6
o`271_l0Q`H4o`0000Go08L600?o0000o`271_l0Q`H00ol00002o`271P03o`000?l0PA;o084B00;o
084B0_l000000ol0PA;o0000o`214P04o`214P03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0>oooool004?ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000Aooooo`;o
0000@?ooool3o`0000;o08L600?o0000o`271_l0Q`H01?l0Q`H4o`0000?o08L600?o0000o`271_l0
Q`H00ol0Q`H3o`0000Ko08L600Co0000o`214_l0PA;o084B0ol00006o`214P;o00003?ooool2o`00
03cooooo0013ooooo`04o`000?ooooooooooo`0000Wooooo0_l0000>ooooo`?o000000?oooooo`00
0?ooool0??ooool3o`0000Ko08L600?o0000o`271_l0Q`H00ol000000ol0Q`Ko0000o`271P05o`27
1P03o`000?l0Q`Ko000000;o000000?o08L6o`000?l0Q`H01_l0Q`H5o`000003o`271_l0003o084B
00Co084B00Co0000o`214_l0PA;o00003?ooool00ol0003oooooooooo`0jooooo`00A?ooool2o`00
00_ooooo00?o0000ooooooooool02_ooool2o`0003kooooo1?l00002o`271P03o`000?l0Q`Ko08L6
00Co08L60ol00005o`271P03o`000?l0Q`Ko08L600?o08L60_l00005o`271P03o`000?l0Q`Ko08L6
00;o08L60_l000001Ol0Q`Ko0000o`271_l0Q`Ko000000;o08L600Go0000o`214_l0PA;o084Bo`00
0004o`214P03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool005_ooooo0ol0000o
ooooo`03o`000?l0Q`Ko000000Go08L600Co0000o`271_l0Q`Ko08L60_l000000ol0Q`Ko0000o`27
1P06o`271P03o`000?l0Q`Ko000000;o000000?o08L6o`000?l0Q`H01Ol0Q`H01?l0003o08L6o`00
0?l00004o`271P03o`000?l0Q`Ko000000?o08L600?o0000o`214_l000001Ol0PA82o`0000_ooooo
00?o0000ooooooooool0>Oooool005Sooooo0ol00002ooooo`03o`000?oooooooooo03_ooooo0_l0
0003o`271P03o`000?l0Q`Ko08L600?o08L600?o0000o`271_l000001?l0Q`H00ol0003o08L6o`27
1P04o`271P;o00001Ol0Q`H00ol0003o08L6o`271P03o`271P;o00001_l0Q`H00ol0003o08L6o`00
0003o`271P;o00001Ol0PA800ol0003o084Bo`00000<ooooo`03o`000?oooooooooo03Sooooo001F
ooooo`;o0000@_ooool00ol0003o08L6o`271P04o`271P04o`000?l0Q`Ko08L6o`271P?o00001_l0
Q`H00ol0003o08L6o`271P03o`000003o`J<0?l0003o08L600Co08L600?o0000o`271_l0Q`H00ol0
0002o`271P03o`000?l0Q`Ko08L600?o08L600?o0000o`271_l000000ol000000ol0Q`Ko0000o`21
4P02o`214P;o00000ol0PA800ol0003oooooooooo`0:ooooo`;o0000>?ooool005?ooooo0ol00012
ooooo`;o00001ol0Q`H4o`0000?o08L600?o0000o`271_l0Q`H00ol0Q`H3o`0000Go1X`000?o0000
o`271_l0Q`H00_l0Q`H3o`0000Ko08L600Co0000o`271_l0Q`Ko08L61?l00005o`271P03o`000?l0
PA;o000000Go084B0_l0000;ooooo`03o`000?oooooooooo03Oooooo001Aooooo`;o00000oooool0
0ol0003oooooooooo`0looooo`?o000000?o1X`0o`000?l0Q`H01Ol0Q`H00ol0003o08L6o`000006
o`271P03o`000?l0Q`Ko000000;o000000?o1X`0o`000?l6S0001Ol6S0001Ol0003o08L6o`271_l0
Q`Ko000000;o08L600?o0000o`271_l0Q`H01?l0Q`H4o`0000?o08L600?o0000o`271_l0Q`H00ol0
Q`H3o`0000?o084B0_l000000ol0PA;o0000ooooo`0;ooooo`03o`000?oooooooooo03Kooooo001>
ooooo`?o0000@_ooool2o`0000Go1X`000Co0000o`271_l0Q`Ko08L60_l00003o`271P03o`000?l0
Q`Ko08L600?o08L60_l00005o`J<0003o`000?l6S03o1X`000?o1X`000Co0000o`271_l0Q`Ko0000
1?l0Q`H00ol0003o08L6o`271P03o`000003o`271_l0003o08L600Co08L60_l000001?l0Q`Ko0000
o`000?l00003o`214P03o`000?l0PA;o000000Co084B00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0eooooo`00C?ooool2o`0004;ooooo0ol000000ol6S03o0000o`J<0005o`J<0003o`00
0?l0Q`Ko000000Ko08L600?o0000o`271_l000000_l000000ol6S03o0000o`J<0005o`J<0003o`00
0?l6S03o1X`000?o1X`00_l00005o`271P?o00001Ol0Q`H00ol0003o08L6o`271P03o`271P;o0000
1_l0PA82o`0000Go084B00?o0000ooooooooool02_ooool00ol0003oooooooooo`0eooooo`008Ooo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001[ooooo0ol00002ooooo`;o0000?_oo
ool2o`0000Go1X`000?o0000o`J<0?l6S0000ol6S002o`0000Oo08L60_l00005o`J<0003o`000?l6
S03o1X`000?o1X`000Co0000o`J<0?l6S03o1X`00ol00005o`271P03o`000?l0Q`Ko000000Ko08L6
00Co0000o`271_l0Q`Ko08L60ol000001?l0PA;o0000o`214_l0PA83o`000003o`214_l0003o084B
00Co084B0_l0000<ooooo`;o00001oooool2o`0002cooooo000Pooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Fooooo`?o0000@_ooool3o`000003o`J<0?l0003o
1X`000Go1X`000?o0000o`J<0?l000000_l00002o`J<0003o`000?l0Q`Ko08L600;o08L60_l00000
0ol6S03o0000o`J<0004o`J<0003o`000?l6S03o1X`000?o1X`01?l00003o`J<0005o`000?l0Q`Ko
08L6o`271_l000000ol0Q`H00ol0003o08L6o`271P03o`271P04o`000?l0Q`Ko0000o`0000;o084B
00?o0000o`214_l000000_l00005o`214P05o`000?l0PA;o084Bo`214_l000000_l0PA800ol0003o
ooooooooo`09ooooo`;o00001_ooool01?l0003oooooooooool0000[ooooo`006Oooool5o`0000;o
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Booooo`;o00000_ooool00ol0
003oooooooooo`0nooooo`;o00001Ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001_l6S0001?l0
003o08L6o`000?l00004o`J<0003o`000?l6S03o1X`000;o1X`000?o0000o`J<0?l6S0000ol00000
0ol6S03o0000o`J<0005o`J<0003o`000?l0Q`Ko000000Go08L600Co0000o`271_l0Q`Ko08L61?l0
0002o`214P?o000000?o084Bo`000?l0PA801Ol0PA801?l0003o084Bo`214_l00004o`214P03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000[ooooo`00
8?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00oooooo0ol00012ooooo`?o
00000_l6S0000ol0003o1X`0o`J<0003o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0003o
1X`0o`J<0003o`J<00;o00001_l6S0000ol0003o1X`0o`J<0002o`J<00?o00001Ol6S0000ol0003o
1X`0o`J<0003o`J<00;o00001_l0Q`H4o`0000Co08L60_l000000ol0PA;o0000o`214P02o`214P03
o`000?l0PA;o084B00?o084B00?o0000o`214_l000001Ol0PA82o`0000_ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool0000[ooooo`008?ooool01?l0003oooooooooool00007oooo
o`Co00004?ooool3o`0004;ooooo0_l00006o`J<0004o`000?l6S03o1X`0o`J<00?o00001_l6S000
0ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Go1X`000?o0000o`J<0?l000000_l00002
o`J<0003o`000?l6S03o1X`000Co1X`000?o0000o`J<0?l000000_l00002o`J<0004o`000?l0Q`Ko
08L6o`271P;o000000?o08L6o`000?l0Q`H01?l0Q`H2o`0000;o084B00Co0000o`214_l0PA;o084B
2?l00005o`214P03o`000?l0PA;o000000_ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool0000[ooooo`008?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00ko
oooo0ol00002ooooo`03o`000?oooooooooo03gooooo0ol00002o`J<0003o`000?l6S03o1X`000?o
1X`01?l00003o`J<0003o`000?l6S03o1X`000?o1X`00_l00005o`J<0003o`000?l6S03o1X`000?o
1X`00_l00006o`J<0004o`000?l6S03o1X`0o`J<00Co00001_l6S0000ol0003o08L6o`000004o`27
1P05o`000?l0Q`Ko08L6o`271_l000000_l0PA801?l0003o084Bo`000?l0PA82o`000003o`214_l0
003o084B00Co084B00Co0000o`214_l0PA;o084B0_l00003o`214P03o`000?oooooooooo00Wooooo
0_l00003ooooo`04o`000?ooooooooooo`0002_ooooo000Qooooo`;o00002?ooool5o`0000Wooooo
0ol00011ooooo`Co00001_l6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Go1X`0
00?o0000o`J<0?l000000_l000000olETP3o0000o`J<0005o`J<0003o`000?l6S03o000000;o0000
0_l6S0000ol0003o1X`0o`J<0003o`J<00Co00000ol6S0000ol0003o1X`0o`J<0004o`J<00;o0000
1_l0Q`H00ol0003o08L6o`000004o`214P?o00001?l0PA800ol0003o084Bo`214P03o`214P03o`00
0?l0PA;o000000Go084B0_l0000:ooooo`;o00001?ooool2o`0002cooooo000gooooo`;o000000?o
ooooo`000?ooool0?Oooool4o`0000Co1X`000?o0000o`J<0?l6S0000ol6S002o`0000Go1X`000?o
0000o`J<0?l6S0000ol6S002o`0000Go5I8000?o0000o`J<0?l6S0000ol6S002o`0000Ko1X`000?o
0000o`J<0?l000000_l000000ol6S03o0000o`J<0005o`J<0003o`000?l6S03o1X`000?o00000_l6
S0001?l0003o08L6o`271_l0Q`H4o`0000Go084B0_l00006o`214P04o`000?l0PA;o084Bo`214P?o
00001Ol0PA800ol0003o084Bo`00000;ooooo`03o`000?oooooooooo033ooooo000dooooo`?o0000
1?ooool00ol0003oooooooooo`0iooooo`;o000000?o1X`0o`000?l6S0001_l6S0000ol0003o1X`0
o`000002o`0000;o1X`000?o0000o`J<0?l6S0000ol6S0000ol0003o1X`0o`000002o`000003oaFB
0?l0003o5I8000Go5I8000?o0000o`J<0?l6S0000_l00002o`J<0003o`000?l6S03o1X`000?o1X`0
0_l00005o`J<0003o`000?l6S03o1X`000?o1X`00ol00005o`J<00Co00000ol0Q`H00ol0003o084B
o`214P03o`000003o`214_l0003o000000Go084B1?l00003o`214P05o`000?l0PA;o084Bo`214_l0
00000ol0PA800ol0003oooooooooo`09ooooo`03o`000?oooooooooo02oooooo000cooooo`;o0000
@?ooool2o`0000Co1X`000?o0000o`J<0?l6S0001?l6S002o`0000Ko1X`000Co0000o`J<0?l6S03o
1X`00ol00005oaFB0003o`000?lETP3o5I8000?o5I8000?o0000o`J<0?l000001Ol6S0000ol0003o
1X`0o`000002o`0000;o1X`000?o0000o`J<0?l6S0000ol6S0000ol0003o1X`0o`J<0002o`0000?o
1X`000?o0000o`J<0?l000000_l00002o`271P03o`000?l0Q`Ko08L600;o08L61?l00004o`214P;o
000000Ko084Bo`000?l0003o0000o`214_l00006o`214P03o`000?l0PA;o000000Co084B0_l0000;
ooooo`03o`000?oooooooooo02kooooo000cooooo`?o0000??ooool3o`000003o`J<0?l0003o1X`0
00Co1X`000Co0000o`J<0?l6S03o1X`00_l000000ol6S03o0000o`J<0005o`J<00Co00000_lETP00
0ol0003o5I80oaFB0004oaFB0003o`000?lETP3o5I8000;o5I800_l00006o`J<00;o00001_l6S000
0ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000Go1X`00_l00006o`271POo00001_l0PA82
o`0000Go084B00?o0000o`214_l0PA800ol0PA82o`0000Co084B00?o0000o`214_l000002oooool2
o`0002oooooo000cooooo`;o000000?oooooo`000?ooool0>?ooool2o`0000Go1X`000?o0000o`J<
0?l6S0000ol6S0000ol0003o1X`0o`000004o`J<0004o`000?l6S03o1X`0o`J<00;o000000?o5I80
o`000?lETP001?lETP000ol0003o5I80oaFB0003oaFB0003o`000?lETP3o000000;o00000_lETP00
1?l0003o1X`0o`J<0?l6S002o`000003o`J<0?l0003o1X`000Go1X`01ol00005o`J<0004o`000?l0
Q`Ko08L6o`0000?o08L61_l00003o`271P04o`000?l0PA;o084Bo`214P;o000000?o084Bo`000?l0
PA801?l0PA800ol0003o084Bo`214P03o`000003o`214_l0003o084B00;o084B00Go0000o`214_l0
PA;o084Bo`00000:ooooo`;o0000;oooool003?ooooo00Go0000ooooooooooooooooo`00000foooo
o`;o000000?o1X`0o`000?l6S0001Ol6S0001?l0003o1X`0o`J<0?l6S003o`0000Ko1X`000?o0000
o`J<0?l000001?lETP000ol0003o5I80oaFB0003oaFB0003o`000?lETP3o5I8000;o5I800_l00006
oaFB0003o`000?l6S03o000000Co1X`000Co0000o`J<0?l6S03o1X`00_l000000ol6S03o0000o`J<
0004o`J<0005o`000?l6S03o1X`0o`J<0?l000001?l0Q`H5o`000003o`271_l0003o08L600Go08L6
00?o0000o`214_l000000ol0PA82o`0000?o084B1?l00005o`214P03o`000?l0PA;o000000Go084B
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/ooooo`00<_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03;ooooo00?o0000o`J<0?l6S0000_l6S0000ol0003o1X`0o`J<
0003o`J<00Co00000ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001_lETP000ol0003o5I80oaFB
0002oaFB0003o`000?lETP3o000000;o00000_lETP000ol0003o5I80oaFB0003oaFB00;o00001_l6
S0000ol0003o1X`0o`000004o`J<0003o`000?l6S03o1X`000?o1X`000?o0000o`J<0?l000000ol0
Q`H4o`0000Go08L600?o0000o`271_l0Q`H00ol0Q`H2o`0000Go084B1?l00003o`214P03o`000?l0
PA;o084B00?o084B0_l00006o`214P03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?oo
ool003;ooooo0_l00005ooooo`03o`000?oooooooooo02kooooo0ol00006o`J<0003o`000?l6S03o
000000;o00000_l6S0000ol0003o1X`0o`J<0003o`J<0003o`000?l6S03o000000;o000000?o5I80
o`000?lETP001OlETP001?l0003o5I80oaFB0?lETP03o`0000Ko5I8000?o0000oaFB0?l000000_l0
00000olETP3o0000o`J<0005o`J<00;o00001_l6S0001?l0003o1X`0o`J<0?l6S003o`000008o`27
1_l0003o0000o`000?l0Q`Ko0000o`271_l00005o`271P03o`000?l0Q`Ko08L600?o000000?o08L6
o`000?l0PA800_l0PA82o`000003o`214_l0003o084B00Go084B00?o0000o`214_l000000_l00000
0ol0PA;o0000o`214P05o`214P;o00002oooool00ol0003oooooooooo`0[ooooo`00<_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo1?l00003o`J<0003o`000?l6S03o1X`0
00?o1X`00_l00006o`J<0004o`000?l6S03o1X`0o`J<00?o00001OlETP000ol0003o5I80oaFB0003
oaFB00Co00000_lETP000ol0003o5I80oaFB0004oaFB00;o00001OlETP001?l0003o1X`0o`J<0?l6
S002o`000003o`J<0?l0003o1X`000Go1X`01?l000001?l6S03o0000o`000?l00003o`271P05o`00
0?l0Q`Ko08L6o`271_l000000ol0Q`H4o`0000Go08L600?o0000o`214_l000001?l0PA800ol0003o
084Bo`214P03o`214P;o00001Ol0PA800ol0003o084Bo`214P03o`000003o`214_l0003ooooo00[o
oooo0_l0000/ooooo`00<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Gooooo
0ol00002o`J<0003o`000?l6S03o1X`000?o1X`000?o0000o`J<0?l000000_l00002o`J<0003o`00
0?l6S03o1X`000?o1X`01?l00002oaFB0003o`000?lETP3o5I8000Co5I8000?o0000oaFB0?l00000
0_l000000olETP3o0000oaFB0004oaFB0003o`000?lETP3o5I8000?o000000?o5I80o`000?lETP00
1OlETP000ol0003o1X`0o`000004o`J<0003o`000?l6S03o1X`000?o000000?o1X`0o`000?l00000
0_l00003o`J<0003o`000?l0Q`Ko000000Co08L61?l00003o`271P03o`000?l0Q`Ko08L600?o08L6
0_l00005o`214P;o000000Ko084Bo`000?l0003o0000o`214_l00005o`214P?o00001Ol0PA800ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo000booooo`;o00002?ooool00ol0003o
ooooooooo`0Rooooo`;o00001_l6S0001?l0003o1X`0o`J<0?l6S003o`0000Ko1X`000?o0000o`J<
0?l000000_l000000olETP3o0000oaFB0004oaFB0003o`000?lETP3o5I8000?o5I800_l00005oaFB
0003o`000?lETP3o5I8000;o5I800ol00005oaFB0004o`000?lETP3o5I80oaFB00Co00001Ol6S003
o`0000;o1X`01?l00005o`J<00;o00001?l0Q`H00ol0003o08L6o`000006o`271P03o`000?l0Q`Ko
000000;o000000?o08L6o`000?l0PA801Ol0PA82o`0000Go084B00?o0000o`214_l000000_l00000
0ol0PA;o0000o`214P05o`214P03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool0
03;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`?o00000_l6S0000ol0
003o1X`0o`J<0003o`J<00Co00000ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001OlETP000ol0
003o5I80oaFB0003oaFB0003o`000?lETP3o000000;o00000_lETP000ol0003o5I80oaFB0003oaFB
0004o`000?lETP3o0000o`0000;o5I8000?o0000oaFB0?lETP000olETP04o`0000?o5I8000Co0000
o`J<0?l6S03o1X`00_l00002o`J<00?o00000ol6S0000ol0003o1X`0o`J<0003o`000003o`J<0?l0
003o08L600;o08L600Go0000o`271_l0Q`Ko08L6o`000005o`271P;o00001Ol0Q`H00ol0003o084B
o`214P03o`000003o`214_l0003o084B00Co084B0_l00005o`214P03o`000?l0PA;o084B00?o084B
0_l0000<ooooo`03o`000?oooooooooo02Sooooo000booooo`;o00002_ooool00ol0003ooooooooo
o`0Jooooo`?o00001_l6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Go1X`000?o
0000o`J<0?l000000_l000000olETP3o0000oaFB0005oaFB0003o`000?lETP3o5I8000;o5I800_l0
0006oaFB0004o`000?lETP3o5I80oaFB00?o00001OlETP000ol0003o5I80o`000002o`000003oaFB
0?l0003o5I8000Go5I8000?o0000o`J<0?l000000_l6S004o`0000?o1X`01?l00005o`J<0003o`00
0?l0Q`Ko000000Go08L600?o0000o`271_l0Q`H00_l000000ol0Q`Ko0000o`271P04o`271P?o0000
1?l0PA82o`000006o`214_l0003o0000o`000?l0PA;o00001_l0PA800ol0003o084Bo`000002o`00
0003o`214_l0003ooooo00_ooooo00?o0000ooooooooool0:?ooool0037ooooo0_l0000<ooooo`03
o`000?oooooooooo01Gooooo1?l00003o`J<0003o`000?l6S03o1X`000?o1X`00_l00005o`J<0003
o`000?l6S03o1X`000?o1X`00_l00005oaFB0003o`000?lETP3o5I8000?o5I8000?o0000oaFB0?l0
00000_l00002oaFB0003o`000?lETP3o5I8000?o5I801?l00003oaFB0003o`000?lETP3o5I8000;o
5I800_l00005oaFB0003o`000?lETP3o5I8000?o5I801Ol00003o`J<00Co00000ol6S0000ol0003o
1X`0o`J<0003o`J<00;o00001_l0Q`H00ol0003o08L6o`000004o`271P03o`000?l0Q`Ko000000;o
00000_l0Q`H00ol0003o084Bo`214P03o`214P;o00001Ol0PA800ol0003o084Bo`214P03o`214P;o
00001Ol0PA800ol0003oooooooooo`09ooooo`;o0000:Oooool0037ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Booooo`;o00000_l6S0000ol0003o1X`0o`J<0003o`J<0003o`00
0?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<0003o`J<0003o`000?l6S03o000000;o0000
0_l6S0000ol0003o5I80oaFB0003oaFB0004o`000?lETP3o5I80oaFB00?o00001_lETP000ol0003o
5I80o`000002o`000003oaFB0?l0003o5I8000Go5I8000Co0000oaFB0?l0003o00000_lETP000ol0
003o5I80oaFB0003oaFB0003o`000?lETP3o000000Go00000ol6S002o`000003o`J<0?l0003o1X`0
00Go1X`000?o0000o`J<0?l000000_l00002o`J<0003o`000?l0Q`Ko08L600?o08L60_l00005o`27
1P;o00001_l0Q`H00ol0003o084Bo`000002o`000003o`214_l0003o084B00Co084B00?o0000o`21
4_l0PA800ol000000ol0Q`Ko0000o`214P04o`214P;o00003?ooool00ol0003oooooooooo`0Voooo
o`00<Oooool3o`0000gooooo00?o0000ooooooooool03oooool2o`0000Go1X`000?o0000o`J<0?l6
S0000_l6S003o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol00006o`J<0004o`000?lETP3o5I80
oaFB00Go00000olETP000ol0003o5I80oaFB0003oaFB00;o00001OlETP000ol0003o5I80oaFB0003
oaFB00;o00001OlETP001?l0003o5I80oaFB0?lETP05o`0000Co5I8000?o0000o`J<0?l000001?l6
S0000ol0003o1X`0o`J<0003o`J<00;o00001_l6S0000ol0003o08L6o`000002o`000003o`271_l0
003o08L600;o08L60_l000000ol0Q`Ko0000o`271P05o`271P;o00001Ol0PA800ol0003o084Bo`21
4P02o`214P?o00001Ol0Q`H01ol0003o084Bo`214_l0PA;o0000o`214_l000003?ooool00ol0003o
ooooooooo`0Vooooo`001Oooool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`?o00000_ooool5o`0000;ooooo0_l00003ooooo`Go00001?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00_ooooo0ol00002o`J<0003o`000?l6S03o1X`000?o1X`0
00Co0000o`J<0?l0003o00000ol6S0000ol0003o1X`0o`J<0002o`J<00Co00000ol6S0000ol0003o
1X`0o`J<0003o`J<00Co00000_lETP000ol0003o5I80oaFB0004oaFB0003o`000?lETP3o000000;o
00000_lETP000ol0003o5I80oaFB0002oaFB0003o`000?lETP3o5I8000?o000000?o5I80o`000?lE
TP001?lETP06o`000003oaFB0?l0003o5I8000Co5I800_l00006o`J<0003o`000?l6S03o000000;o
000000?o1X`0o`000?l6S0001Ol6S002o`0000Go08L600?o0000o`271_l000001?l0Q`H00ol0003o
08L6o`271P03o`000003o`271_l0003o084B00Co084B00?o0000o`214_l0PA800_l00002o`271P03
o`000?l0Q`Ko08L600?o08L600Co0000o`214_l0PA;o00000ol0PA800ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02Gooooo0004ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`;o0000
4?ooool00ol0003oooooooooo`08ooooo`;o00001_l6S0001?l0003o1X`0o`J<0?l6S003o`0000Ko
1X`000Co0000o`J<0?l0003o00000_l6S0000ol0003o1X`0o`J<0003o`J<0003o`000?l6S03o0000
00;o00000_l6S0000ol0003o5I80oaFB0002oaFB0003o`000?lETP3o5I8000?o5I800_l00006oaFB
0003o`000?lETP3o5I8000Co00001OlETP000ol0003o5I80o`000002o`000003oaFB0?l0003o0000
00Go5I8000?o0000oaFB0?l000000_l00002oaFB0003o`000?l6S03o1X`000?o1X`00_l00005o`J<
0003o`000?l6S03o1X`000?o000000?o1X`0o`000?l0Q`H01?l0Q`H2o`0000Go08L60ol00005o`27
1P03o`000?l0PA;o084B00;o084B0ol00005o`271P03o`000?l0Q`Ko08L600;o08L600?o0000o`21
4_l000001?l0PA82o`0000cooooo00?o0000ooooooooool01Oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`00017ooooo0008ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo013ooooo0_l00005ooooo`?o00000_l6S0000ol0003o1X`0o`J<0003
o`J<00Co00000ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001Ol6S0000ol0003o1X`0o`J<0002
o`J<00;o00001_l6S0000ol0003o5I80oaFB0002oaFB0003o`000?lETP3o000000;o00000_lETP00
0ol0003o5I80oaFB0003oaFB00?o00000olETP000ol0003o5I80oaFB0003oaFB00;o000000Ko5I80
o`000?l0003o0000oaFB0?l00005oaFB00;o00001_lETP000ol0003o1X`0o`000002o`0000;o1X`0
00?o0000o`J<0?l6S0000_l6S003o`0000Go1X`000?o0000o`271_l000000_l00002o`271P07o`00
0?l0Q`Ko08L6o`271_l0003o1X`0o`000006o`271P03o`000?l0PA;o084B00;o084B0ol00005o`27
1POo00000ol0PA82o`0000;o084B00?o0000ooooooooool02?ooool2o`0000Kooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`0@ooooo`001_ooool2o`0000_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Co00001?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooool000000ol00005
o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001Ol6S0000ol0003o1X`0o`000002
o`0000;o1X`000?o0000o`J<0?l6S0000ol6S0001?l0003o1X`0o`000?l00002o`J<0003o`000?l6
S03o1X`000?o1X`01ol00006oaFB0003o`000?lETP3o000000;o00000_l6S0000ol0003o5I80oaFB
0002oaFB0003o`000?lETP3o000000Go00001OlETP000ol0003o5I80o`000002o`0000;o5I8000?o
0000oaFB0?lETP000olETP02o`0000Ko1X`000Co0000o`J<0?l0003o00000_l6S0000ol0003o1X`0
o`J<0003o`J<00;o00001_l0Q`H00ol0003o08L6o`000003o`J<0003o`000?l0Q`Ko08L600?o08L6
00?o0000o`214_l000000_l00003o`271P03o`000?l0Q`Ko000000;o000000?o08L6o`000?l0Q`H0
1?l0Q`H00ol0003o084Bo`000005o`214P03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo013ooooo0008ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooool000000ol00002ooooo`07o`000?ooooooooooooooool0
003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooooooo0_l0000C
ooooo`?o00001?l6S0000ol0003o1X`0o`J<0002o`J<00?o00001?l6S0000ol0003o1X`0o`J<0003
o`J<00;o00001_l6S0001?l0003o1X`0o`J<0?l6S003o`0000Go1X`000?o0000o`J<0?l000000_l0
00000ol6S03o0000oaFB0004oaFB0003o`000?lETP3o5I8000?o5I800ol00005o`J<0003o`000?lE
TP3o5I8000Ko00000olETP001?l0003o5I80oaFB0?lETP03o`0000Ko5I8000?o0000oaFB0?l00000
0_l000000olETP3o0000o`J<0005o`J<00;o00001Ol6S0000ol0003o1X`0o`000002o`000003o`J<
0?l0003o08L600Go08L60_l00005o`J<0003o`000?l0Q`Ko08L600;o08L60_l00006o`271P;o0000
1Ol0Q`H00ol0003o08L6o`271P02o`271P;o00001_l0PA82o`0000_ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo013ooooo0004ooooo`05o`00
0?ooooooooooooooool000001oooool01ol0003ooooooooooooooooo0000ooooool000001Oooool0
1ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000003ooooo`05o`00
0?ooooooooooooooool000004Oooool3o`000003o`J<0?l0003o1X`000Go1X`000Co0000o`J<0?l0
003o00000ol6S0000ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0
003o1X`0o`J<0003o`J<00Co00000ol6S0000ol0003o1X`0o`J<0002o`J<00;o00001Ol6S0000ol0
003o5I80oaFB0003oaFB0003o`000?lETP3o000000;o00000ol6S0001?l0003o1X`0o`J<0?l6S008
o`0000Go5I801?l00003oaFB0003o`000?lETP3o5I8000?o5I800_l00005oaFB0003o`000?l6S03o
1X`000?o000000?o1X`0o`000?l6S0001?l6S002o`0000Go1X`000Co0000o`271_l0Q`Ko08L60_l0
00000ol6S03o0000o`J<0004o`J<0003o`000?l0Q`Ko000000;o00000_l0Q`H00ol0003o08L6o`27
1P03o`000003o`271_l0003o08L600Co08L600?o0000o`271_l000000_l000000ol0Q`Ko0000o`21
4P03o`214P;o000000?o084Bo`000?ooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool04?ooool000Gooooo0ol00008ooooo`Go000000?o
ooooo`000?l000000ol00002ooooo`?o00000oooool3o`0000?ooooo0ol00004ooooo`03o`000?oo
oooooooo00gooooo0ol00004o`J<0003o`000?l6S03o1X`000?o1X`00_l00006o`J<0003o`000?l6
S03o1X`000?o00001_l6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Go1X`000Co
0000o`J<0?l0003o00000_l6S0000ol0003o1X`0o`J<0003o`J<0004o`000?lETP3o5I80oaFB00Co
00001Ol6S004o`000004o`J<0?l0003o0000o`0000Co5I8000?o0000oaFB0?l000000_l00002oaFB
0003o`000?lETP3o5I8000?o5I8000?o0000oaFB0?l000000_l000000olETP3o0000oaFB0004oaFB
00?o00001Ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Co1X`000Co0000o`27
1_l0003o00001?l6S0000ol0003o1X`0o`J<0002o`J<00;o00001Ol0Q`H3o`0000Go08L600Co0000
o`271_l0Q`Ko08L60ol00005o`271P04o`000?l0PA;o0000o`0000Co084B00?o0000ooooooooool0
2?ooool2o`0000?ooooo00Co0000oooooooooooo00002?ooool2o`0001;ooooo000`ooooo`03o`00
0?oooooooooo00_ooooo0_l00003o`J<0003o`000?l6S03o1X`000;o1X`000?o0000o`J<0?l00000
0_l00002o`J<0003o`000?l6S03o1X`000?o1X`00ol00003o`J<0003o`000?l6S03o1X`000?o1X`0
0_l00005o`J<0003o`000?l6S03o1X`000?o1X`00_l00005o`J<0004o`000?l6S03o1X`0o`J<00Go
00001?l6S0000ol0003o1X`0o`000002o`0000;o1X`00ol00002o`J<0004o`000?lETP3o5I80oaFB
00?o00001_lETP001?l0003o5I80oaFB0?lETP03o`0000Go5I8000?o0000oaFB0?l000000_l00000
0olETP3o0000o`J<0005o`J<00;o00001Ol6S0001?l0003o1X`0o`J<0?l6S003o`0000Ko1X`000?o
0000o`J<0?l000000_l000000ol6S03o0000o`271P03o`271P04o`000?l0Q`Ko08L6o`0000Go08L6
1?l00002o`271P03o`000?l0Q`Ko08L600?o08L60_l00006o`214P03o`000?oooooooooo00[ooooo
00Co0000oooooooooooooooo0_l0000:ooooo`03o`000?oooooooooo013ooooo000`ooooo`;o0000
2oooool00ol0003o1X`0o`J<0004o`J<0003o`000?l6S03o1X`000?o00001_l6S0000ol0003o1X`0
o`000002o`000003o`J<0?l0003o1X`000Co1X`000?o0000o`J<0?l000000_l00002o`J<0003o`00
0?l6S03o1X`000?o1X`000?o0000o`J<0?l000000_l00002o`J<0003o`000?l6S03o1X`000;o1X`0
1?l00003o`J<0003o`000?l6S03o1X`000?o1X`00_l00003o`J<00Co00000_l6S005o`0000?o5I80
00?o0000oaFB0?lETP000olETP04o`0000?o5I8000?o0000oaFB0?lETP000_lETP02o`0000Go5I80
00Co0000o`J<0?l6S03o1X`00_l000000ol6S03o0000o`J<0004o`J<00Co00000ol6S0000ol0003o
1X`0o`J<0003o`J<00;o00001Ol6S0001?l0003o08L6o`271_l00004o`271P03o`000?l0Q`Ko0000
00;o000000?o08L6o`000?l0Q`H01?l0Q`H00ol0003o08L6o`000002o`000003o`271_l0003o084B
00Go084B00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`00<?ooool00ol0003o
ooooooooo`08ooooo`?o00001_l6S003o`0000?o1X`000?o0000o`J<0?l6S0000ol6S002o`0000Go
1X`000?o0000o`J<0?l6S0000_l6S003o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol00006o`J<
0004o`000?l6S03o0000o`0000?o1X`000?o0000o`J<0?l6S0000_l6S0000ol0003o1X`0o`000002
o`0000;o1X`00ol00003o`J<00?o00000ol6S0000ol0003o5I80oaFB0003oaFB0003o`000?lETP3o
000000;o000000?o5I80o`000?lETP001OlETP001?l0003o5I80o`000?l00002oaFB0003o`000?lE
TP3o5I8000?o5I8000?o0000o`J<0?l000001?l6S0000ol0003o1X`0o`000002o`000003o`J<0?l0
003o1X`000Go1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0003o`000?l0
Q`Ko000000Go08L60_l00005o`271P03o`000?l0Q`Ko08L600;o08L60_l00005o`271P04o`000?l0
PA;o084Bo`214PCo00003?ooool00ol0003oooooooooo`0Oooooo`00<?ooool00ol0003ooooooooo
o`06ooooo`;o00000olETP001?l0003o1X`0o`J<0?l6S002o`000003o`J<0?l0003o1X`000Co1X`0
00?o0000o`J<0?l000000_l00002o`J<0003o`000?l6S03o1X`000?o1X`000Co0000o`J<0?l0003o
00000ol6S0000ol0003o1X`0o`J<0002o`J<00Co00000ol6S0000ol0003o1X`0o`J<0003o`J<00;o
00001_l6S0000ol0003o1X`0o`J<0003o`0000;o1X`00ol000000ol6S03o0000o`J<0003o`000003
o`J<0?l0003o1X`000Co1X`000Co0000oaFB0?lETP3o5I800ol00005oaFB0003o`000?lETP3o5I80
00?o5I800_l00005oaFB0004o`000?lETP3o5I80oaFB00?o00001Ol6S002o`0000Go1X`000?o0000
o`J<0?l6S0000ol6S002o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol00005o`271P03o`000?l0
Q`Ko000000Go08L61Ol000000ol0Q`Ko0000o`271P04o`271PCo00000ol0Q`H00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01kooooo000_ooooo`;o00001Oooool3o`0000Ko5I8000?o0000
o`J<0?l000001?l6S0000ol0003o1X`0o`J<0002o`J<00?o00001Ol6S0001?l0003o1X`0o`J<0?l6
S004o`0000Go1X`000Co0000o`J<0?l0003o00000_l6S0000ol0003o1X`0o`J<0003o`J<0003o`00
0?l6S03o000000;o000000?o1X`0o`000?l6S0001Ol6S003o`0000;o1X`00ol00004o`J<00;o0000
1Ol6S0000ol0003o1X`0o`J<0002o`J<00Co00000olETP000ol0003o5I80oaFB0003oaFB0003o`00
0?lETP3o000000;o000000?o5I80o`000?lETP001?lETP04o`0000?o5I8000Go0000o`J<0?l6S03o
1X`0o`000002o`J<0003o`000?l6S03o1X`000?o1X`000?o0000o`J<0?l000000_l000000ol6S03o
0000o`J<0004o`J<00Co00000ol6S0001Ol0003o08L6o`271_l0Q`Ko000000?o08L600Co0000o`27
1_l0Q`Ko08L60ol00005o`271P03o`000?l0Q`Ko000000;o00000_l0Q`H00ol0003o08L6o`271P03
o`271P03o`000?oooooooooo00Wooooo0_l0000Pooooo`00;oooool00ol0003oooooooooo`04o`00
00?o5I8000?o0000oaFB0?lETP000olETP02o`0000Ko1X`000Co0000o`J<0?l0003o00000ol6S002
o`0000;o1X`01Ol00004o`J<0004o`000?l6S03o1X`0o`J<00?o00001Ol6S0001?l0003o1X`0o`J<
0?l6S005o`0000?o1X`000?o0000o`J<0?l6S0000ol000000ol6S03o0000o`000002o`0000;o1X`0
00?o0000o`J<0?l000000_l00002o`J<0003o`000?l6S03o1X`000;o1X`000?o0000o`J<0?l00000
0_l00003o`J<0003o`000?lETP3o5I8000;o5I8000Co0000oaFB0?lETP3o5I800ol00005oaFB0003
o`000?lETP3o000000;o000000?o5I80o`000?lETP001OlETP000ol0003o1X`0o`000004o`J<0004
o`000?l6S03o1X`0o`J<00?o00001Ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`0
00Go1X`000?o0000o`271_l000001?l0Q`H4o`0000;o08L60_l00004o`271P;o00001_l0Q`H01?l0
003o08L6o`271_l0Q`H3o`0000cooooo00?o0000ooooooooool07Oooool002oooooo0ol00002oaFB
0003o`000?lETP3o5I8000?o5I8000?o0000oaFB0?l000000_l00002oaFB0003o`000?l6S03o1X`0
00?o1X`00_l00006o`J<00?o00001?l6S0001?l0003o1X`0o`J<0?l6S005o`0000?o1X`000Co0000
o`J<0?l6S03o1X`01Ol00004o`J<00Oo00000ol6S003o`0000Co1X`00ol00004o`J<00Oo00001_l6
S009o`0000;o5I8000?o0000oaFB0?lETP000olETP02o`0000Go5I8000?o0000oaFB0?lETP000olE
TP02o`0000Go1X`01?l00002o`J<0003o`000?l6S03o1X`000?o1X`00ol00004o`J<0003o`000?l6
S03o1X`000?o1X`00_l00003o`271P;o000000?o08L6o`000?l0Q`H01?l0Q`H5o`0000;o08L600?o
0000o`271_l0Q`H00ol0Q`H4o`0000;o08L600?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Mooooo`00;oooool00ol0003o5I80oaFB0003oaFB0003o`000?lETP3o5I8000;o5I800ol00005
oaFB0003o`000?l6S03o000000;o00000_l6S0001?l0003o1X`0o`J<0?l6S002o`0000;o1X`000?o
0000o`J<0?l6S0000_l6S004o`0000?o1X`000?o0000o`J<0?l6S0000_l6S004o`0000Co1X`000?o
0000o`J<0?l000000_l00002o`271P03o`000?l6S03o1X`000;o1X`00ol00002o`J<0003o`000?l6
S03o000000;o00000ol6S0001_l0003o1X`0o`000?l0003o1X`0o`0000Go1X`000Co0000o`J<0?l6
S03o1X`00_l000000ol6S03o0000oaFB0003oaFB0003o`000?lETP3o5I8000?o5I8000?o0000oaFB
0?l000000_l00002oaFB0003o`000?lETP3o5I8000?o5I8000?o0000oaFB0?l000000_l000000olE
TP3o0000o`J<0002o`J<00;o000000?o1X`0o`000?l6S0001?l6S0000ol0003o1X`0o`000002o`00
00?o1X`000?o0000o`J<0?l6S0000_l6S0000ol0003o1X`0o`000002o`0000;o1X`000?o0000o`27
1_l000001?l0Q`H01?l0003o08L6o`271_l0Q`H4o`0000Go08L600?o0000o`271_l000000_l00000
0ol0Q`Ko0000o`271P04o`271P03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool0
00?ooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3o`00
00;ooooo1Ol00002ooooo`;o00000oooool5o`0000Cooooo0_l00005oaFB0004o`000?lETP3o0000
o`0000?o5I8000?o0000oaFB0?lETP000_lETP02o`0000Ko1X`000?o0000o`J<0?l000001Ol6S000
1_l0003o1X`0o`000?l0003o1X`0o`0000Ko1X`000Co0000o`J<0?l0003o00000ol6S002o`0000;o
1X`00ol00006o`271Pco00001Ol6S002o`0000Co1X`000?o0000o`J<0?l6S0000ol6S0000ol0003o
1X`0o`000004o`J<0003o`000?lETP3o5I8000;o5I8000?o0000oaFB0?lETP000_lETP02o`0000Ko
5I8000Co0000oaFB0?lETP3o5I800ol00005oaFB0003o`000?l6S03o000000Co1X`000Co0000o`J<
0?l6S03o1X`01?l00005o`J<00Oo00001Ol6S002o`0000Go08L61?l00002o`271P;o00001Ol0Q`H2
o`0000Go08L600?o0000o`271_l0Q`H00_l0Q`H2o`0000_ooooo0_l0000Mooooo`000_ooool01Ol0
003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003oaFB00?o00001_lETP001?l0003o
5I80o`000?l00002oaFB0003o`000?l6S03o1X`000?o1X`00ol00005o`J<00;o00001?l6S0000ol0
003o1X`0o`J<0003o`J<00?o00001Ol6S003o`0000?o08L600Co0000o`271_l0Q`Ko08L61Ol00002
o`J<0003o`000?l6S03o1X`000Co1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004
o`J<0004o`000?l6S03o1X`0o`J<00Co00001?l6S005o`000003oaFB0?l0003o5I8000;o00000_lE
TP000ol0003o5I80oaFB0003oaFB00Co00000_lETP000ol0003o5I80oaFB0003oaFB00;o00001Ol6
S004o`0000Co1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0003o`000?l6
S03o000000;o000000?o1X`0o`000?l0Q`H00_l0Q`H2o`000003o`271_l0003o08L600Co08L60_l0
00001_l0Q`Ko0000o`000?l0003o08L6o`0000Go08L600?o0000o`271_l000000_l000000ol0Q`Ko
0000ooooo`0;ooooo`03o`000?oooooooooo01_ooooo0006ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000005ooooo`;o00000_ooool3o`0000?o5I8000?o0000oaFB0?lETP000olETP03o`00
00Co5I8000?o0000o`J<0?l000000_l00003o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0
003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o00000ol6S0000ol0003o1X`0o`000002o`00
0003o`271_l0003o08L600Co08L61Ol00002o`271P05o`000?l6S03o1X`0o`J<0?l000001Ol6S002
o`0000Go1X`000Co0000o`J<0?l6S03o1X`01Ol00004o`J<0006o`000?l6S03o0000o`000?l6S03o
00000olETP03o`0000Go5I8000?o0000oaFB0?l000000_l000000olETP3o0000oaFB0004oaFB0003
o`000?lETP3o000000;o00000_lETP001Ol0003o1X`0o`J<0?l6S03o000000;o1X`000?o0000o`J<
0?l6S0000ol6S002o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol00005o`J<0003o`000?l0Q`Ko
000000Co08L600?o0000o`271_l0Q`H00_l0Q`H3o`0000Go08L600Co0000o`271_l0Q`Ko08L60ol0
0005o`271P03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool000Cooooo0_l0000;
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooooooo
ool4o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o00000olE
TP000ol0003o5I80o`000002o`0000?o5I8000?o0000oaFB0?lETP001?l00005o`J<00;o00001_l6
S0000ol0003o1X`0o`J<0004o`0000Go1X`00ol00004o`271P03o`000?l0Q`Ko08L600Go00001Ol0
Q`H01_l0003o1X`0o`J<0?l6S03o0000o`J<00?o00000_l6S0000ol0003o1X`0o`J<0002o`J<00Co
00000ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001?l6S0000ol0003o5I80oaFB0002oaFB0003
o`000?lETP3o5I8000?o5I800_l00005oaFB0003o`000?lETP3o5I8000;o5I800_l00006oaFB0003
o`000?l6S03o000000Co1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<00Co
00000_l6S0000ol0003o1X`0o`J<0003o`J<00;o00001Ol0Q`H00ol0003o08L6o`000002o`0000;o
08L60_l00004o`271PCo00000_l0Q`H00ol0003o08L6o`271P03o`271P;o00003?ooool00ol0003o
ooooooooo`0Iooooo`001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000?o0000
0_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000003oooo
o`04o`000?ooooooooooooooo`;o00001_ooool6o`0000Go5I800ol00004oaFB0005o`000?l6S03o
1X`0o`J<0?l000000_l6S0000ol0003o1X`0o`J<0003o`J<00?o00001?l6S002o`000003o`J<0?l0
003o000000?o08L600Co0000o`271_l0Q`Ko08L61Ol00003o`271P04o`000?l0Q`Ko08L6o`271POo
00001_l6S0001_l0003o1X`0o`000?l0003o1X`0o`0000Ko1X`000?o0000o`J<0?l000000_l00002
o`J<0003o`000?l6S03o1X`000;o1X`000?o0000oaFB0?lETP000_lETP000ol0003o5I80o`000002
o`0000;o5I8000?o0000oaFB0?lETP000_lETP000ol0003o5I80o`000002o`0000;o5I8000?o0000
oaFB0?lETP000olETP02o`0000Go1X`00_l00005o`J<0003o`000?l6S03o000000;o000000?o1X`0
o`000?l6S0001?l6S0000ol0003o1X`0o`000002o`0000;o1X`000?o0000o`271_l0Q`H00_l0Q`H2
o`0000Ko08L600?o0000o`271_l000000_l000000ol0Q`Ko0000o`271P04o`271P03o`000?l0Q`Ko
000000;o000000?o1X`0o`000?ooool02_ooool2o`0001_ooooo0002ooooo`05o`000?oooooooooo
ooooool000001oooool01ol0003ooooooooooooooooo0000ooooool000001Oooool01ol0003ooooo
oooooooooooo0000ooooool000000oooool00ol0003oooooo`000003ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003o5I80oaFB0003oaFB00;o000000?o5I80o`000?l000000_lETP00
0ol0003o5I80oaFB0003oaFB0003o`000?l6S03o000000Co1X`000?o0000o`J<0?l000000_l00002
o`J<0003o`000?l6S03o1X`000?o1X`00ol00004o`271PSo00001?l0Q`H4o`0000?o08L600Go0000
o`J<0?l6S03o1X`0o`000005o`J<00;o00001?l6S0000ol0003o1X`0o`J<0003o`J<00;o00001_l6
S0000ol0003o1X`0o`J<0009o`0000Co5I802?l00005oaFB0003o`000?lETP3o000000;o00000_lE
TP000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Co1X`00_l00005o`J<0003o`000?l6
S03o1X`000;o1X`00_l00006o`J<0004o`000?l0Q`Ko0000o`0000;o08L600Co0000o`271_l0Q`Ko
08L61?l00005o`271P03o`000?l0Q`Ko08L600;o08L60_l00005o`J<0003o`000?oooooooooo00[o
oooo00?o0000ooooooooool06?ooool000?ooooo0ol00008ooooo`Go000000?oooooo`000?l00000
0ol00002ooooo`?o00000oooool3o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo00Kooooo
00?o0000oaFB0?lETP000olETP02o`0000Go5I8000Co0000oaFB0?lETP3o5I800ol00005o`J<00Co
00001?l6S0000ol0003o1X`0o`000002o`0000?o08L600?o0000o`271_l000000ol00006o`271P04
o`000?l0Q`Ko0000o`0000;o08L600?o0000o`271_l0Q`H00ol0Q`H01_l0003o1X`0o`J<0?l6S03o
0000o`J<00?o00000_l6S0000ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o00000_l6
S0000ol0003o1X`0o`J<0003o`J<00?o00000_lETP000ol0003o5I80oaFB0004oaFB0004o`000?lE
TP3o0000o`0000;o5I8000?o0000oaFB0?lETP000olETP001?l0003o5I80oaFB0?lETP03o`0000Go
5I800_l00005o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<0002o`J<0003
o`000?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<0003o`J<00;o00001Ol0Q`H3o`0000Co
08L600?o0000o`271_l0Q`H00_l0Q`H00ol0003o08L6o`000002o`000003o`J<0?l0003o1X`000Co
1X`000?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`00;_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?lETP3o000000;o00000_lETP000ol0003o5I80oaFB0002oaFB00Co0000
0olETP001Ol0003o1X`0o`J<0?l6S03o000000Co1X`01ol00004o`271P?o00001?l0Q`H00ol0003o
08L6o`271P03o`271P;o00001Ol0Q`H01?l0003o08L6o`271_l0Q`H8o`0000Go1X`000?o0000o`J<
0?l6S0000ol00006o`J<0003o`000?l6S03o000000;o000000?o5I80o`000?lETP000olETP000ol0
003o5I80oaFB0003oaFB00;o00001OlETP001?l0003o5I80oaFB0?lETP05o`0000?o5I8000?o0000
oaFB0?l000000_l000000olETP3o0000o`J<0004o`J<00?o00001Ol6S0000ol0003o1X`0o`J<0003
o`0000Ko1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`271P03o`271P03o`000?l0Q`Ko
000000Go08L61ol00005o`J<0003o`000?l6S03o1X`000;o1X`00_l0000<ooooo`03o`000?oooooo
oooo00Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00000_ooool002kooooo00?o0000
ooooooooool02?ooool2o`0000Go5I8000Co0000oaFB0?l0003o00000_lETP000ol0003o5I80oaFB
0003oaFB0003o`000?l6S03o000000?o1X`00_l000000ol0Q`Ko0000o`271P04o`271PGo00000_l0
Q`H00ol0003o08L6o`271P02o`271P03o`000?l0Q`Ko000000;o00000_l0Q`H00ol0003o08L6o`27
1P02o`271PCo00000ol0Q`H00ol0003o1X`0o`J<0002o`J<0004o`000?l6S03o1X`0o`J<00Co0000
0ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001OlETP000ol0003o5I80oaFB0002oaFB0003o`00
0?lETP3o000000;o000000?o5I80o`000?lETP001?lETP04o`0000;o5I8000?o0000oaFB0?lETP00
0olETP02o`0000Go5I8000?o0000o`J<0?l6S0000_l00003o`J<0004o`000?l6S03o1X`0o`J<00Co
00000ol6S0001?l0003o1X`0o`J<0?l6S004o`0000Go1X`000Co0000o`271_l0Q`Ko00000ol0Q`H0
0ol0003o08L6o`000002o`000003o`J<0?l0003o1X`000?o1X`000?o0000o`J<0?l6S0000ol6S000
0ol0003o1X`0o`000002o`000003o`J<0?l0003ooooo00_ooooo0_l00006ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000_ooool002kooooo00?o0000ooooooooool02_oo
ool00ol0003o5I80oaFB0002oaFB00;o00001OlETP000ol0003o5I80oaFB0002oaFB00Co000000?o
1X`0o`000?l0Q`H00ol0Q`H01?l0003o08L6o`271_l0Q`H3o`0000Ko08L600?o0000o`271_l0Q`H0
0ol00006o`271P04o`000?l0Q`Ko0000o`0000;o08L600?o0000o`271_l0Q`H00ol0Q`H00ol0003o
1X`0o`J<0005o`0000?o1X`000?o0000o`J<0?l6S0000_l6S0000ol0003o1X`0o`000002o`000003
oaFB0?l0003o5I8000Co5I8000Co0000oaFB0?lETP3o5I800ol00005oaFB0003o`000?lETP3o0000
00;o000000?o5I80o`000?lETP001?lETP000ol0003o5I80o`000002o`0000;o5I8000?o0000oaFB
0?lETP000_lETP000ol0003o1X`0o`000005o`J<00Co00000_l6S0000ol0003o1X`0o`J<0002o`J<
00Co00001?l6S0000ol0003o1X`0o`J<0002o`J<0003o`000?l0Q`Ko000000Co08L60_l00005o`J<
0003o`000?l6S03o1X`000;o1X`000?o0000o`J<0?l6S0000_l6S002o`0000Go1X`000?o0000oooo
ooooool02oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool00_ooool002gooooo00?o0000ooooooooool03?ooool01?l0003o5I80o`000?l00002
oaFB0003o`000?lETP3o5I8000?o5I8000Co0000oaFB0?l0003o00000ol6S002o`0000Ko08L61?l0
0002o`271P03o`000?l0Q`Ko08L600?o08L60ol00003o`271P03o`000?l0Q`Ko08L600?o08L60_l0
0005o`271P04o`000?l0Q`Ko08L6o`271PCo00000ol6S0000ol0003o1X`0o`J<0002o`J<00So0000
1?lETP000ol0003o5I80oaFB0002oaFB00Co00000_lETP000ol0003o5I80oaFB0003oaFB00;o0000
1OlETP000ol0003o5I80oaFB0002oaFB00;o00001_lETP000ol0003o5I80oaFB0005o`000006o`J<
0?l0003o0000o`000?l6S03o00001Ol6S0001?l0003o1X`0o`000?l00002o`J<0003o`000?l6S03o
1X`000?o1X`01ol00003o`271P;o000000?o1X`0o`000?l6S0001?l6S002o`0000?o1X`000?o0000
o`J<0?l000000_l00002o`J<0003o`000?l6S03o1X`000;o1X`000?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00Ooo
ool002gooooo0_l0000>ooooo`;o00001?lETP001?l0003o5I80oaFB0?lETP05o`000003o`J<0?l0
003o000000;o1X`000?o0000o`271_l0Q`H01Ol00005o`271P03o`000?l0Q`Ko000000;o00000_l0
Q`H00ol0003o08L6o`271P02o`271P03o`000?l0Q`Ko000000;o00000_l0Q`H00ol0003o08L6o`27
1P02o`271PCo00000_l0Q`H00ol0003o1X`0o`J<0003o`J<0006o`000?l6S03o0000o`000?l6S03o
00001_l6S0001_l0003o5I80oaFB0?lETP3o0000oaFB00?o000000?o5I80o`000?lETP001?lETP00
0ol0003o5I80o`000002o`0000;o5I8000?o0000oaFB0?lETP000_lETP000ol0003o5I80o`000002
o`0000;o5I8000?o0000oaFB0?lETP000olETP03o`0000Co1X`00_l00005o`J<0004o`000?l6S03o
1X`0o`J<00?o00001Ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Co1X`000?o
0000o`271_l000001?l6S0000ol0003o1X`0o`J<0002o`J<00Oo00001Ol6S007o`0000gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00000_ooool002gooooo00?o0000ooooooooool03oooool00ol0003o5I80oaFB0005o`0000?o1X`0
0ol00004o`J<00Ko00000_l0Q`H00ol0003o08L6o`271P02o`271P?o00001Ol0Q`H00ol0003o08L6
o`271P04o`0000Go08L600Co0000o`271_l0003o00000_l0Q`H00ol0003o08L6o`271P02o`271P04
o`000?l6S03o1X`0o`J<00?o00001?l6S0000ol0003o1X`0o`J<0003o`J<00Oo00001?lETP000ol0
003o5I80oaFB0002oaFB00?o00001OlETP000ol0003o5I80oaFB0004o`0000Go5I8000?o0000oaFB
0?l000000_l00002o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001?l6S004o`00
00;o1X`000?o0000o`J<0?l6S0000ol6S002o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol00005
o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l000001?l6S0000ol0003o1X`0o`000002
o`000003o`J<0?l0003o1X`000Co1X`000?o0000ooooooooool02Oooool3o`0000?ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000;ooooo000]ooooo`03o`000?oo
oooooooo013ooooo0_l00004o`J<00Co00000ol6S004o`000004o`J<0?l0003o0000o`0000Go08L6
00Co0000o`271_l0003o00000ol0Q`H01?l0003o08L6o`271_l0Q`H4o`0000Co08L600Co0000o`27
1_l0Q`Ko08L60ol00005o`271P03o`000?l0Q`Ko08L600Go00000ol6S0000ol0003o1X`0o`J<0002
o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0003o5I80oaFB0002oaFB0003o`000?lETP3o
5I8000;o5I8000Co0000oaFB0?l0003o00000olETP001?l0003o5I80oaFB0?lETP04o`0000Co5I80
00Co0000oaFB0?lETP3o5I801?l00003o`J<00?o00001Ol6S0000ol0003o1X`0o`000002o`000003
o`J<0?l0003o1X`000Co1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<00Co
00000_l6S0000ol0003o1X`0o`J<0003o`J<00;o00001Ol6S002o`0000?o1X`00_l00005o`J<0004
o`000?l6S03o1X`0o`J<00?o00001oooool3o`0000;ooooo00?o0000ooooooooool00_ooool2o`00
00Wooooo0ol00003ooooo`00;Oooool00ol0003oooooooooo`0Booooo`04o`000?l6S03o0000o`00
00;o1X`000?o0000o`J<0?l6S0001?l000000ol6S03o0000o`000003o`J<0004o`000?l0Q`Ko08L6
o`271PCo00001?l0Q`H4o`0000?o08L600?o0000o`271_l0Q`H00_l0Q`H4o`0000?o08L600Co0000
o`271_l0Q`Ko08L61?l00002o`J<0003o`000?l6S03o1X`000Co1X`000?o0000o`J<0?l6S0000ol0
0006o`J<0003o`000?lETP3o5I8000So00001OlETP04o`0000;o5I8000?o0000oaFB0?lETP000olE
TP04o`0000?o1X`01?l00002o`J<0003o`000?l6S03o1X`000?o1X`00_l00005o`J<0004o`000?l6
S03o1X`0o`J<00?o00001Ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Co1X`0
00?o0000o`J<0?l000000_l00002o`J<0003o`000?l6S03o1X`000;o1X`000?o0000o`J<0?l00000
0_l000000ol6S03o0000o`J<0004o`J<00Co00000_l6S0000ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`0Cooooo`00;Oooool2o`0001Cooooo0_l00004o`J<00;o00000ol6
S003o`0000Co1X`01?l00004o`271P04o`000?l0Q`Ko0000o`0000;o08L600?o0000o`271_l0Q`H0
0ol0Q`H01?l0003o08L6o`000?l00002o`271P03o`000?l0Q`Ko08L600;o08L61?l00002o`J<0003
o`000?l6S03o1X`000;o1X`000?o0000o`J<0?l6S0000ol6S003o`0000?o1X`000?o0000o`J<0?l6
S0000ol6S003o`0000;o5I8000?o0000oaFB0?lETP000olETP000ol0003o5I80o`000002o`000003
oaFB0?l0003o5I8000Co5I8000?o0000oaFB0?l000000_l00003o`J<0004o`000?l6S03o0000o`00
00;o1X`000?o0000o`J<0?l6S0000_l6S0000ol0003o1X`0o`000002o`0000;o1X`000?o0000o`J<
0?l6S0000_l6S004o`0000;o1X`000?o0000o`J<0?l6S0000ol6S003o`0000Co1X`000?o0000o`J<
0?l6S0000_l6S002o`0000Go1X`02?l00004o`J<0003o`000?l6S03o000000;o000000?o1X`0o`00
0?l6S0001?l6S004o`0000Sooooo00?o0000ooooooooool04oooool00004ooooool0003o0000o`00
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`00
00;ooooo0_l00003ooooo`Go00000oooool2o`0001Oooooo1?l000000ol6S03o0000o`J<0002o`00
00?o1X`000Ko0000o`J<0?l0003o0000o`J<0?l00006o`271P;o00001Ol0Q`H01?l0003o08L6o`27
1_l0Q`H3o`0000Go08L600Ko0000o`271_l0003o0000o`J<0?l00005o`J<0003o`000?l6S03o1X`0
00;o1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0003o`000?l6S03o0000
00;o00000_l6S0001Ol0003o5I80oaFB0?lETP3o000000Co5I800_l00005oaFB0004o`000?lETP3o
5I80oaFB00Go00000ol6S003o`0000Co1X`02?l00005o`J<0006o`000?l6S03o0000o`000?l6S03o
00001Ol6S0000ol0003o1X`0o`000002o`0000?o1X`000Ko0000o`J<0?l6S03o1X`0o`000?l6S003
o`0000;o1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<00;o00000_l6S003
o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol0000:ooooo`03o`000?oooooooooo01?ooooo0000
1Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`[o00001?l6S002o`0000Co1X`000Co0000
o`271_l0Q`Ko08L60_l00002o`271P03o`000?l0Q`Ko08L600;o08L61?l00003o`271P03o`000?l0
Q`Ko08L600;o08L60_l00004o`J<0003o`000?l6S03o1X`000?o1X`000?o0000o`J<0?l6S0001?l0
0004o`J<0004o`000?l6S03o1X`0o`J<00Co00001?l6S006o`000003oaFB0?l0003o000000;o5I80
00?o0000oaFB0?lETP000_lETP04o`0000?o1X`01Ol00003o`J<0006o`000?l6S03o0000o`000?l6
S03o00001_l6S0001?l0003o1X`0o`J<0?l6S003o`0000Co1X`000Co0000o`J<0?l6S03o1X`01?l0
0005o`J<00Ko00001Ol6S002o`0000Go1X`000?o0000o`J<0?l6S0000_l6S004o`0000?o1X`000Co
0000o`J<0?l6S03o1X`01Ol00003o`J<0003o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4_ooool000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Booooo`?o
00000oooool00ol0003o1X`0o`J<0004o`J<0004o`000?l6S03o0000o`0000;o1X`000?o0000o`J<
0?l6S0000_l6S0000ol0003o08L6o`000005o`271P04o`000?l0Q`Ko0000o`0000;o08L600?o0000
o`271_l0Q`H00ol0Q`H01_l0003o08L6o`000?l0003o1X`0o`0000Go1X`000?o0000o`J<0?l6S000
0_l6S003o`0000Co1X`000?o0000o`J<0?l6S0001Ol00004o`J<0004o`000?l6S03o0000o`0000;o
1X`000?o0000oaFB0?lETP000_l00005oaFB0004o`000?lETP3o0000o`0000?o1X`01?l00002o`J<
0003o`000?l6S03o1X`000?o1X`00_l00004o`J<0003o`000?l6S03o1X`000?o1X`01?l00003o`J<
0003o`000?l6S03o1X`000Go00001?l6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`0
00?o1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0003o`000?l6S03o0000
00;o000000Co1X`0o`000?l6S03o00000ol6S004o`0000;o1X`000?o0000o`J<0?l6S0000ol6S002
o`0000Wooooo00?o0000ooooooooool04_ooool000;ooooo0_l0000;ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool4o`0000Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`?o00001oooool00ol0003o1X`0o`J<0003
o`J<00;o00001Ol6S0000ol0003o1X`0o`J<0003o`0000Ko08L60ol00004o`271P04o`000?l0Q`Ko
08L6o`271P?o00001?l6S0000ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o000000?o
1X`0o`000?l6S0001?l6S003o`0000?o1X`000?o0000o`J<0?l6S0000ol6S002o`0000Go1X`000Co
0000oaFB0?lETP3o00001OlETP04o`000005o`J<0?l0003o0000o`J<0?l000001Ol6S0000ol0003o
1X`0o`000002o`000003o`J<0?l0003o1X`000Co1X`000?o0000o`J<0?l000000_l000000ol6S03o
0000o`J<0004o`J<00?o00000ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001Ol6S0001?l0003o
1X`0o`J<0?l6S002o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol00005o`J<00Go000000?o1X`0
o`000?l6S0001?l6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003ooooo00Sooooo00?o0000
ooooooooool04_ooool000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000003o`00
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000ooo
ool01Ol0003ooooooooooooooooo000000kooooo0_l0000;ooooo`03o`000?l6S03o000000;o0000
0_l6S0000ol0003o1X`0o`J<0002o`J<00?o00000ol6S0001?l0003o08L6o`271_l0Q`H2o`0000?o
08L600?o0000o`271_l0Q`H01Ol00002o`J<0003o`000?l6S03o1X`000?o1X`000?o0000o`J<0?l6
S0000ol00005o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<0002o`J<0003
o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001?l6S005o`000004oaFB0?l0003o0000o`00
00?o1X`00_l00004o`J<0003o`000?l6S03o1X`000;o1X`00ol00004o`J<0004o`000?l6S03o1X`0
o`J<00?o00001Ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Co1X`000?o0000
o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0006o`000?l6S03o0000o`000?l6S03o0000
1Ol6S004o`0000;o1X`000?o0000o`J<0?l6S0000ol6S003o`0000Co1X`000?o0000o`J<0?l6S000
0_l6S002o`0000Go1X`000?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`0000Go
0000ooooooooooooooooo`000007ooooo`07o`000?ooooooooooooooool0003oooooo`000005oooo
o`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00_l0000;ooooo`?o00003_ooool00ol0003o1X`0o`J<0004o`J<0006o`000?l6
S03o0000o`000?l6S03o00001Ol6S0000ol0003o08L6o`000005o`271P?o00000_l6S0000ol0003o
1X`0o`J<0003o`J<0004o`000?l6S03o1X`0o`J<00Co00000ol6S0000ol0003o1X`0o`J<0002o`J<
00?o00001Ol6S0000ol0003o1X`0o`J<0003o`0000Go1X`000?o0000o`J<0?l000000_l000001?lE
TP3o0000o`J<0?l6S004o`000004o`J<0?l0003o0000o`0000;o1X`000?o0000o`J<0?l6S0000_l6
S0001?l0003o1X`0o`000?l00003o`J<0003o`000?l6S03o1X`000Go00000ol6S0000ol0003o1X`0
o`J<0002o`J<00;o00001Ol6S0000ol0003o1X`0o`J<0002o`J<00;o00001Ol6S0001?l0003o1X`0
o`J<0?l6S003o`0000Co1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0003
o`000?l6S03o000000;o00000_l6S002o`0000?o1X`000?o0000o`J<0?l000000_l00002o`J<0004
o`000?l6S03o1X`0o`J<00?o00001oooool00ol0003oooooooooo`0Booooo`0000Coooooo`000?l0
003o00002?ooool5o`000003ooooool0003o000000?o00000_ooool3o`0000?ooooo0ol00003oooo
o`?o00001?ooool00ol0003oooooooooo`06ooooo`?o00004_ooool00ol0003o1X`0o`J<0003o`J<
00?o00000ol6S0000ol0003o1X`0o`J<0002o`J<00?o00000ol0Q`H2o`000003o`J<0?l0003o1X`0
00?o1X`000?o0000o`J<0?l6S0000_l6S004o`0000Co1X`000Ko0000o`J<0?l6S03o1X`0o`000?l6
S002o`0000?o1X`000Co0000o`J<0?l6S03o1X`01?l00003o`J<0003o`000?l6S03o1X`000;o1X`0
0_l00005oaFB0003o`000?l6S03o1X`000;o1X`00ol00004o`J<00Oo00001Ol6S003o`0000?o1X`0
00?o0000o`J<0?l6S0000ol6S0001?l0003o1X`0o`000?l00002o`J<0003o`000?l6S03o1X`000;o
1X`000?o0000o`J<0?l000000_l00002o`J<0004o`000?l6S03o1X`0o`J<00Go00000_l6S0000ol0
003o1X`0o`J<0002o`J<00;o00001Ol6S0000ol0003o1X`0o`J<0002o`J<00;o00001Ol6S007o`00
00Go1X`01?l00002o`J<00;o00001_ooool00ol0003oooooooooo`0Booooo`00;?ooool00ol0003o
ooooooooo`03ooooo`?o00005_ooool00ol0003o1X`0o`000002o`0000?o1X`000Ko0000o`J<0?l6
S03o1X`0o`000?l6S002o`0000?o1X`000?o0000o`271_l000001?l6S0000ol0003o1X`0o`J<0002
o`J<0004o`000?l6S03o0000o`0000;o1X`000?o0000o`J<0?l6S0000ol6S007o`0000Co1X`01?l0
0002o`J<0003o`000?l6S03o1X`000?o1X`000Co0000o`J<0?l0003o00000_lETP000ol0003o5I80
oaFB0002oaFB0003o`000?l6S03o1X`000;o00000ol6S0001_l0003o1X`0o`000?l0003o1X`0o`00
00Go1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0004o`000?l6S03o1X`0
o`J<00?o00001?l6S007o`0000Go1X`01?l00002o`J<0003o`000?l6S03o1X`000?o1X`000Co0000
o`J<0?l0003o00000_l6S0000ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o00000_l6
S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o000000Co1X`000?o0000o`J<0?l000000_l0
00000ol6S03o0000o`J<0003o`000003o`271_l0003ooooo00Gooooo00?o0000ooooooooool04_oo
ool002_ooooo0_l00002ooooo`?o00006_ooool2o`0000Go1X`01ol00004o`J<00;o00001_l6S000
0ol0003o1X`0o`J<0003o`0000Go1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004
o`J<0004o`000?l6S03o0000o`0000;o1X`000?o0000o`J<0?l6S0000_l6S0001?l0003o1X`0o`J<
0?l6S003o`0000Go5I8000Oo0000oaFB0?lETP3o5I80o`000?l6S03o000000Go1X`00_l00004o`J<
0003o`000?l6S03o1X`000;o1X`00_l00005o`J<0004o`000?l6S03o1X`0o`J<00Go00000ol6S000
1_l0003o1X`0o`000?l0003o1X`0o`0000Go1X`000?o0000o`J<0?l000000_l000000ol6S03o0000
o`J<0004o`J<0004o`000?l6S03o1X`0o`J<00?o00001?l6S007o`0000Go1X`00_l00005o`J<00;o
00000_l6S003o`0000?o1X`00ol00005o`271P03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04Oooool002_ooooo1?l0000Oooooo`;o000000?o1X`0o`000?l000000ol6S0001_l0003o1X`0
o`J<0?l6S03o0000o`J<00;o00000_l6S0000ol0003o1X`0o`J<0003o`J<00?o00000ol6S0000ol0
003o1X`0o`J<0002o`J<00;o00001Ol6S0000ol0003o1X`0o`J<0002o`J<00;o00001Ol6S0000ol0
003o1X`0o`J<0005o`0000;o5I8000?o0000oaFB0?lETP000olETP07o`0000?o1X`00_l000000ol6
S03o0000o`J<0003o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<0002o`J<
00Co00000_l6S0000ol0003o1X`0o`J<0003o`J<00;o00001?l6S0000ol0003o1X`0o`J<0002o`J<
00;o00001Ol6S0001?l0003o1X`0o`J<0?l6S005o`0000?o1X`000Co0000o`J<0?l0003o00000_l6
S0000ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001?l6
S004o`0000;o1X`01?l00003o`271P04o`000?l0Q`Ko08L6o`271P?o00001Oooool00ol0003ooooo
ooooo`0Aooooo`00:oooool2o`0002?ooooo0_l00004o`J<00Oo00001?l6S0000ol0003o1X`0o`00
0002o`000003o`J<0?l0003o1X`000Co1X`000Co0000o`J<0?l0003o00000_l6S0000ol0003o1X`0
o`J<0002o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001?l6S003o`0000;o5I80
00?o0000oaFB0?lETP000olETP000ol0003o5I80o`000002o`000003oaFB0?l0003o5I8000Co5I80
00?o0000o`J<0?l000001?l6S0000ol0003o1X`0o`J<0004o`0000Go1X`000Ko0000o`J<0?l0003o
0000o`J<0?l00005o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001?l6S0001?l0
003o1X`0o`000?l00002o`J<0003o`000?l6S03o1X`000;o1X`01?l00002o`J<0003o`000?l6S03o
1X`000?o1X`00_l00004o`J<00Oo00001Ol6S0000ol0003o1X`0o`000002o`0000;o1X`000Ko0000
o`J<0?l0003o0000o`271_l00005o`271PCo00000_l0Q`H00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo017ooooo000]ooooo`03o`000?oooooooooo02;ooooo00Ko0000o`J<0?l0003o0000
o`J<0?l00005o`J<0003o`000?l6S03o1X`000Co00001?l6S0001?l0003o1X`0o`J<0?l6S004o`00
00Co1X`000?o0000o`J<0?l6S0001?l00004o`J<0003o`000?l6S03o000000;o000000?o5I80o`00
0?lETP000olETP000ol0003o5I80oaFB0002oaFB00;o00001OlETP000ol0003o5I80oaFB0002oaFB
00;o00001Ol6S003o`0000Co1X`000Co0000o`J<0?l6S03o1X`00ol00004o`J<0004o`000?l6S03o
1X`0o`J<00?o00001Ol6S0001?l0003o1X`0o`J<0?l6S003o`0000Go1X`000Co0000o`J<0?l0003o
00000ol6S0001_l0003o1X`0o`J<0?l6S03o0000o`J<00?o00000_l6S0001_l0003o1X`0o`000?l0
003o1X`0o`0000Go1X`000Co0000o`J<0?l6S03o1X`01?l00003o`J<00?o00001?l0Q`H00ol0003o
08L6o`000002o`000003o`271_l0003o08L600Co08L600?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Aooooo`00;_ooool00ol0003oooooooooo`0Rooooo`03o`000?l6S03o1X`000;o1X`0
00?o0000o`J<0?l6S0000_l6S003o`0000Co1X`000?o0000o`J<0?l6S0001Ol00004o`J<0003o`00
0?l6S03o1X`000Co00001?l6S0000ol0003o1X`0o`J<0003o`0000Go5I8000?o0000oaFB0?lETP00
0_lETP001?l0003o5I80o`000?l00002oaFB0003o`000?lETP3o5I8000;o5I8000?o0000oaFB0?l0
00000_l000000olETP3o0000o`J<0002o`J<00;o00000_l6S0000ol0003o1X`0o`J<0002o`J<00Co
00000_lETP000ol0003o1X`0o`J<0002o`J<00Co00000ol6S0001?l0003o1X`0o`J<0?l6S005o`00
00?o1X`000Co0000o`J<0?l6S03o1X`00ol00005o`J<00Ko00001Ol6S002o`0000Co1X`000?o0000
o`J<0?l6S0000_l6S004o`0000?o1X`01?l00002o`271P;o00000ol0Q`H2o`0000Go08L600?o0000
o`271_l0Q`H00_l0Q`H2o`0000?ooooo00?o0000ooooooooool04Oooool002oooooo00?o0000oooo
ooooool08Oooool00ol0003o1X`0o`J<0003o`J<0004o`000?l6S03o0000o`0000;o1X`000?o0000
o`J<0?l6S0000_l6S003o`0000?o1X`000?o0000o`J<0?l6S0000ol6S003o`0000?o1X`000?o0000
o`J<0?l6S0000_l6S003o`0000?o5I8000?o0000oaFB0?lETP000_lETP000ol0003o5I80oaFB0002
oaFB00;o00001OlETP000ol0003o5I80oaFB0004o`0000Co5I8000?o0000o`J<0?l000001Ol6S000
1_l0003o1X`0o`000?l0003o5I80o`0000Go5I8000Co0000o`J<0?l6S03o00000_l6S0000ol0003o
1X`0o`J<0002o`J<00Co00000ol6S0001?l0003o1X`0o`J<0?l6S005o`0000?o1X`000?o0000o`J<
0?l000000_l000000ol6S03o0000o`J<0003o`J<0003o`000?l6S03o000000;o000000?o1X`0o`00
0?l6S0001?l6S0001_l0003o1X`0o`000?l0003o1X`0o`0000?o1X`00_l000000ol0Q`Ko0000o`27
1P04o`271PCo00000_l0Q`H00ol0003o08L6o`271P02o`271P03o`000?l0Q`Ko000000;o00000_l0
Q`H01?l0003oooooooooool0000Cooooo`00<?ooool2o`0002;ooooo00?o0000o`J<0?l6S0000_l6
S002o`0000Go1X`000Ko0000o`J<0?l0003o0000o`J<0?l00005o`J<0003o`000?l6S03o000000;o
00000_l6S0000ol0003o1X`0o`J<0002o`J<0006o`000?l6S03o0000o`000?lETP3o00001OlETP00
1_l0003o5I80oaFB0?lETP3o0000oaFB00?o00000_lETP001?l0003o5I80oaFB0?lETP04o`0000Co
5I8000?o0000oaFB0?lETP001?l00005o`J<00;o00001?lETP000ol0003o5I80oaFB0002oaFB0003
o`000?l6S03o000000Co1X`000Co0000o`J<0?l0003o00000ol6S0000ol0003o1X`0o`J<0005o`00
00?o1X`000Co0000o`J<0?l6S03o1X`00ol00004o`J<0003o`000?l6S03o1X`000;o1X`00_l00005
o`J<0004o`000?l6S03o1X`0o`J<00?o00001?l6S0000ol0003o1X`0o`000004o`271P04o`000?l0
Q`Ko08L6o`271P?o00001?l0Q`H7o`0000Go08L60_l000000ooooooo0000ooooo`0Booooo`00<_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<
0002o`J<00?o00000ol6S0000ol0003o1X`0o`J<0002o`J<00?o00001?l6S007o`0000Co5I8000?o
0000oaFB0?lETP000_lETP07o`0000Co5I801?l00003oaFB0003o`000?lETP3o5I8000;o5I800ol0
0004oaFB0003o`000?l6S03o000000;o000000?o5I80o`000?lETP000olETP001?l0003o5I80oaFB
0?lETP03o`0000Go1X`00_l00005o`J<00?o00000_l6S0000ol0003o1X`0o`J<0003o`J<00Co0000
0ol6S0000ol0003o1X`0o`J<0002o`J<00Co00000_l6S0001?l0003o1X`0o`J<0?l6S005o`0000;o
1X`000?o0000o`J<0?l6S0000_l6S002o`0000Go08L61?l00003o`271P06o`000?l0Q`Ko0000o`00
0?l0Q`Ko00001Ol0Q`H00ol0003o08L6o`000002o`000005o`271_l0003oooooooooool000004_oo
ool003?ooooo00?o0000ooooooooool07oooool00ol0003o1X`0o`J<0004o`J<0004o`000?l6S03o
0000o`0000?o1X`000Ko0000o`J<0?l6S03o1X`0o`000?l6S002o`0000?o1X`000Ko0000o`J<0?l0
003o0000oaFB0?l00004oaFB0003o`000?lETP3o5I8000?o5I8000Ko0000oaFB0?l0003o0000oaFB
0?l00005oaFB0004o`000?lETP3o0000o`0000;o5I8000?o0000oaFB0?lETP000olETP001_l0003o
5I80o`000?l0003o5I80o`0000Go5I800_l00005oaFB0004o`000?lETP3o5I80oaFB00Co00000olE
TP000ol0003o1X`0o`000002o`0000;o1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<
0003o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001?l6S006o`0000Go1X`01?l0
0002o`J<0003o`000?l6S03o1X`000?o1X`000Co0000o`J<0?l0003o00000_l6S0000ol0003o08L6
o`000002o`0000;o08L600Co0000o`271_l0Q`Ko08L60ol00004o`271P04o`000?l0Q`Ko08L6o`27
1P?o00001Ol0Q`H00ol0003oooooo`00000Booooo`00=?ooool00ol0003oooooooooo`0Oooooo`03
o`000?l6S03o1X`000?o1X`00ol00004o`J<00Oo00001?l6S002o`0000Co5I8000?o0000oaFB0?lE
TP000_lETP000ol0003o5I80oaFB0002oaFB00;o00001?lETP000ol0003o5I80oaFB0002oaFB00?o
00001?lETP001?l0003o5I80oaFB0?lETP03o`0000Co5I8000?o0000oaFB0?l000000_l00002oaFB
0003o`000?lETP3o5I8000;o5I8000Co0000oaFB0?l0003o00000olETP000ol0003o5I80oaFB0003
o`0000Go1X`00_l00005o`J<0003o`000?l6S03o1X`000?o00001Ol6S0000ol0003o1X`0o`000002
o`000003o`J<0?l0003o1X`000?o1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004
o`J<0004o`000?l6S03o1X`0o`J<00?o00001?l6S002o`0000Go08L61?l00002o`271P;o00000_l0
Q`H5o`0000?o08L600Co0000o`271_l0Q`Ko08L61?l0000Booooo`00=Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?l6S03o000000;o00000ol6S0001?l0003o1X`0o`000?l00002o`J<0003o`00
0?l6S03o1X`000;o1X`000Ko0000o`J<0?l0003o0000oaFB0?l00005oaFB0006o`000?lETP3o5I80
oaFB0?l0003o5I800ol00002oaFB0003o`000?lETP3o5I8000;o5I8000Co0000oaFB0?l0003o0000
0olETP000ol0003o5I80oaFB0005o`0000?o5I8000?o0000oaFB0?lETP001?l00004oaFB00Oo0000
1OlETP03o`0000?o5I8000Oo0000o`J<0?l6S03o1X`0o`000?l6S03o000000Go1X`00ol00002o`J<
0003o`000?l6S03o1X`000?o1X`00_l00005o`J<0004o`000?l6S03o1X`0o`J<00;o00001Ol6S000
1?l0003o1X`0o`J<0?l6S005o`0000?o1X`000Ko0000o`J<0?l0003o0000o`J<0?l00003o`271P;o
000000?o08L6o`000?l0Q`H00ol0Q`H4o`0000;o08L600?o0000o`271_l0Q`H00ol0Q`H4o`0000;o
08L60_l0000Booooo`00=_ooool2o`00023ooooo00?o0000o`J<0?l6S0001?l6S002o`0000Go1X`0
00?o0000o`J<0?l6S0000ol00004oaFB0003o`000?lETP3o5I8000;o5I8000?o0000oaFB0?lETP00
1?l00004oaFB00Oo00001OlETP03o`0000Co5I8000?o0000oaFB0?lETP001?l00004oaFB0006o`00
0?lETP3o0000o`000?lETP3o00001OlETP000ol0003o5I80o`000002o`000003oaFB0?l0003o5I80
00Co5I8000?o0000o`J<0?l000000ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`0
00?o1X`000?o0000o`J<0?l000000_l00002o`J<0003o`000?l6S03o1X`000;o1X`000Co0000o`J<
0?l0003o00000_l6S0001?l0003o1X`0o`J<0?l6S005o`0000?o1X`000Co0000o`J<0?l6S03o1X`0
0ol00004o`J<0003o`000?l0Q`Ko000000Co08L61?l000000ol0Q`Ko0000o`000004o`271P03o`00
0?l0Q`Ko000000;o000000?o08L6o`000?l0Q`H00ol0Q`H2o`0001;ooooo000hooooo`03o`000?oo
oooooooo01kooooo00Co0000o`J<0?l6S03o1X`00_l00002o`J<0004o`000?l6S03o1X`0o`J<00Co
00000_lETP000ol0003o5I80oaFB0003oaFB0003o`000?lETP3o5I8000Co00001?lETP001?l0003o
5I80o`000?l00003oaFB0006o`000?lETP3o5I80oaFB0?l0003o5I800ol00002oaFB0004o`000?lE
TP3o5I80oaFB00Co00000olUV0000ol0003o5I80oaFB0002oaFB00;o00001?lETP000ol0003o5I80
oaFB0002oaFB00;o00001OlETP001?l0003o5I80oaFB0?lETP03o`0000Co1X`00_l00005o`J<0003
o`000?l6S03o1X`000Co00001?l6S007o`0000Co1X`01?l00002o`J<0003o`000?l6S03o1X`000?o
1X`01?l00002o`J<0004o`000?l6S03o1X`0o`J<00?o00001?l0Q`H2o`0000Go08L60_l00002o`27
1P?o00001Ol0Q`H4o`000003ooooool0003ooooo017ooooo000iooooo`03o`000?oooooooooo01ko
oooo00?o0000o`J<0?l000001?l6S004o`0000;o5I8000?o0000oaFB0?lETP000_lETP000ol0003o
5I80oaFB0002oaFB00?o00000olETP000ol0003o5I80oaFB0002oaFB00?o00001?lETP07o`0000Co
5I801?l00002obFH0003o`000?lUV03o9IP000?o9IP000Co0000oaFB0?l0003o00000_lETP000ol0
003o5I80oaFB0002oaFB0004o`000?lETP3o0000o`0000;o5I8000?o0000oaFB0?lETP000_lETP04
o`0000;o5I8000Go0000o`J<0?l6S03o1X`0o`000002o`J<0004o`000?l6S03o1X`0o`J<00Co0000
1?l6S0001_l0003o1X`0o`000?l0003o1X`0o`0000Go1X`000Co0000o`J<0?l0003o00000_l6S000
0ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0000ol6S004
o`0000;o1X`000Go0000o`271_l0Q`Ko08L6o`000002o`271P04o`000?l0Q`Ko08L6o`271PGo0000
0ol0Q`H00ol0003o08L6o`271P03o`0000Cooooo00?o0000ooooooooool04?ooool003[ooooo00?o
0000ooooooooool07_ooool2o`0000?o1X`000?o0000oaFB0?l000001OlETP000ol0003o5I80oaFB
0002oaFB0004o`000?lETP3o0000o`0000;o5I8000?o0000oaFB0?lETP000_lETP001?l0003o5I80
o`000?l00003oaFB0006o`000?lETP3o0000o`000?lETP3o00001OlETP001_l0003o5I80o`000?l0
003o9IP0o`0000Go9IP000?o0000obFH0?lUV0000_lUV002o`0000Co5I801ol00005oaFB0006o`00
0?lETP3o0000o`000?lETP3o00001OlETP000ol0003o1X`0o`000003o`J<00Co00000ol6S0001?l0
003o1X`0o`J<0?l6S003o`0000Co1X`000?o0000o`J<0?l6S0000_l6S002o`0000Go1X`000?o0000
o`J<0?l6S0000ol00005o`J<0004o`000?l6S03o0000o`0000;o1X`000?o0000o`J<0?l6S0000_l6
S0000ol0003o08L6o`000003o`271PCo00000_l0Q`H2o`0000Co08L60ol00008ooooo`03o`000?oo
oooooooo00oooooo000kooooo`;o00008?ooool00ol0003o1X`0o`000003oaFB0003o`000?lETP3o
5I8000;o5I8000Co0000oaFB0?lETP3o5I800ol00004oaFB00Oo00001OlETP02o`0000Co5I8000?o
0000oaFB0?lETP000_lETP02o`0000Co9IP000?o0000obFH0?lUV0000_lUV0000ol0003o9IP0obFH
0002o`0000;o9IP000Co0000oaFB0?l0003o00000_lETP000ol0003o5I80oaFB0002oaFB0004o`00
0?lETP3o5I80oaFB00?o00001?lETP001?l0003o5I80oaFB0?lETP03o`0000?o1X`000Co0000o`J<
0?l6S03o00001?l6S004o`0000?o1X`000Ko0000o`J<0?l6S03o1X`0o`000?l6S003o`0000;o1X`0
00Co0000o`J<0?l6S03o1X`01?l00003o`J<0004o`000?l6S03o1X`0o`J<00?o00001?l6S007o`00
00?o08L600Co0000o`271_l0Q`Ko00001?l0Q`H5o`0000_ooooo00?o0000ooooooooool03oooool0
03gooooo00?o0000ooooooooool07_ooool00ol0003o5I80oaFB0003oaFB0003o`000?lETP3o5I80
00Go00000olETP001?l0003o5I80o`000?l00002oaFB0003o`000?lETP3o5I8000;o5I8000?o0000
oaFB0?l000000_l00002oaFB0006o`000?lETP3o5I80oaFB0?l0003o5I800ol000000olUV03o0000
obFH0004obFH0007o`000?lUV03o9IP0obFH0?l0003o9IP0o`000004obFH00;o00001OlETP000ol0
003o5I80oaFB0005o`0000?o5I8000?o0000oaFB0?lETP001Ol00003oaFB0003o`000?l6S03o0000
00Co1X`000Ko0000o`J<0?l0003o0000o`J<0?l00005o`J<00Ko00001Ol6S004o`0000?o1X`000?o
0000o`J<0?l6S0001Ol00003o`J<0006o`000?l6S03o0000o`000?l6S03o00001Ol6S0000ol0003o
08L6o`000003o`271PSo00003Oooool00ol0003oooooooooo`0?ooooo`00?_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?lETP3o5I8000?o5I800ol00004oaFB0003o`000?lETP3o5I8000Co0000
1?lETP000ol0003o5I80oaFB0004o`0000Co5I801_l00005obFH0003o`000?lUV03o9IP000;o9IP0
1ol00003obFH0004o`000?lUV03o9IP0o`0000?o5I801?l00003oaFB0004o`000?lETP3o5I80oaFB
00Co00001?lETP000ol0003o5I80oaFB0003o`0000Go1X`00_l00004o`J<0003o`000?l6S03o0000
00;o00000_l6S0001_l0003o1X`0o`J<0?l6S03o0000o`J<00?o00000_l6S0001?l0003o1X`0o`J<
0?l6S004o`0000;o1X`000?o0000o`J<0?l6S0000ol6S002o`0000Co1X`000?o0000o`J<0?l6S000
0_l6S002o`0000?o08L600?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00oooooo000oooooo`03o`000?oooooooooo01gooooo00Go0000oaFB0?lETP3o5I80
o`000002obFH0003o`000?lETP3o5I8000;o5I800ol00004oaFB0003o`000?lETP3o5I8000Co0000
1?lETP001_l0003o5I80o`000?l0003o9IP0o`0000Co9IP000?o0000obFH0?lUV0000_lUV0000ol0
003o9IP0o`000002o`000003obFH0?l0003o9IP000Co9IP000?o0000obFH0?l000000olUV004o`00
00;o5I8000?o0000oaFB0?lETP000_lETP04o`0000?o5I8000Co0000oaFB0?lETP3o5I801?l00003
oaFB0003o`000?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<0004o`0000Co1X`01ol00004
o`J<00Co00000_l6S0000ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o000000?o1X`0
o`000?l6S0000ol6S0000ol0003o1X`0o`000002o`0000;o1X`000?o0000o`271_l000002Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo0010ooooo`;o00007_ooool00ol0
003o5I80o`000004obFH0004o`000?lETP3o0000o`0000?o5I8000?o0000oaFB0?lETP001?l00003
oaFB0003o`000?lETP3o5I8000;o5I800_l00004obFH0003o`000?lUV03o9IP000;o9IP000?o0000
obFH0?lUV0001?l00004obFH0004o`000?lUV03o9IP0obFH00?o00000olUV0001Ol0003o9IP0obFH
0?lUV03o000000?o5I8000Co0000oaFB0?l0003o00000olETP000ol0003o5I80oaFB0005o`0000?o
5I8000?o0000oaFB0?lETP001?l00003o`J<00Co00001?l6S0001_l0003o1X`0o`000?l0003o1X`0
o`0000Go1X`000Ko0000o`J<0?l0003o0000o`J<0?l00005o`J<0003o`000?l6S03o1X`000?o0000
1?l6S007o`0000Go1X`00_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3oooool004;ooooo00?o0000ooooooooool07?ooool2o`0000Co9IP00ol00004oaFB00?o00000olE
TP000ol0003o5I80oaFB0002oaFB0006o`000?lETP3o0000o`000?lUV03o00001OlUV0001?l0003o
9IP0obFH0?lUV003o`0000Co9IP000?o0000obFH0?lUV0001Ol00003obFH0003o`000?lUV03o0000
00Co9IP01_l00005oaFB00?o00000_lETP000ol0003o5I80oaFB0003oaFB00?o00000ol6S004o`00
00;o1X`000?o0000o`J<0?l6S0000ol6S002o`0000Co1X`000?o0000o`J<0?l6S0000_l6S002o`00
00Co1X`000?o0000o`J<0?l6S0001Ol00003o`J<0006o`000?l6S03o0000o`000?l6S03o00001Ol6
S0000ol0003o1X`0o`000002o`0000kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0?ooooo`00@oooool00ol0003oooooooooo`0Mooooo`04o`000?lUV03o0000o`0000?o9IP000Ko
0000oaFB0?l0003o0000oaFB0?l00005oaFB0003o`000?lETP3o5I8000?o00001?lUV0000ol0003o
9IP0obFH0002obFH0004o`000?lUV03o0000o`0000;o9IP000?o0000obFH0?lUV0000_lUV003o`00
00?o9IP000?o0000obFH0?lUV0000_lUV002o`0000?o9IP00_l000000olUV03o0000oaFB0003oaFB
0003o`000?lETP3o000000;o000000?o5I80o`000?lETP000olETP000ol0003o5I80o`000002o`00
00;o1X`000Ko0000o`J<0?l0003o0000o`J<0?l00005o`J<0003o`000?l6S03o000000;o00000_l6
S0001_l0003o1X`0o`J<0?l6S03o0000o`J<00?o00000_l6S0000ol0003o1X`0o`J<0004o`0000?o
1X`000Co0000o`J<0?l6S03o1X`00ol00004o`J<0004o`000?l6S03o1X`0o`J<00?o00004Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo0014ooooo`03o`000?oooooooooo
01gooooo00?o0000obFH0?lUV0000olUV002o`0000Co5I8000Co0000oaFB0?lETP3o5I801?l00002
obFH0003o`000?lUV03o9IP000?o9IP000?o0000obFH0?lUV0000ol00005obFH0004o`000?lUV03o
0000o`0000;o9IP000?o0000obFH0?lUV0000_lUV0001?l0003o9IP0o`000?l00002obFH0003o`00
0?lUV03o000000Co9IP000Co0000oaFB0?lETP3o5I800ol00004oaFB0003o`000?lETP3o5I8000Go
00000_l6S003o`0000Co1X`000Co0000o`J<0?l6S03o1X`00ol00005o`J<00Ko00001Ol6S003o`00
00;o1X`000?o0000o`J<0?l6S0000_l6S004o`0000?o1X`000?o0000o`J<0?l6S0001Ol0000Eoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool004Gooooo00?o0000oooooooo
ool07?ooool01?l0003o9IP0obFH0?lUV002o`0000;o9IP000?o0000oaFB0?lETP001Ol00002obFH
0003o`000?lUV03o9IP000;o9IP000Co0000obFH0?lUV03o9IP01?l00003obFH0004o`000?lUV03o
9IP0obFH00?o00001?lUV007o`0000Co9IP00ol00004obFH0004o`000?lETP3o0000o`0000?o5I80
00?o0000oaFB0?lETP001?l00004o`J<00?o00000ol6S0000ol0003o1X`0o`J<0005o`0000?o1X`0
00?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0003o`J<0003o`000?l6S03o000000;o0000
0_l6S0001_l0003o1X`0o`J<0?l6S03o0000o`J<00;o00000_l6S0001?l0003o1X`0o`J<0?l6S004
o`0001_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`00A_ooool2o`00
01gooooo00?o0000obFH0?l000001?lUV003o`0000?o9IP000?o0000obFH0?lUV0000_lUV0001?l0
003o9IP0obFH0?lUV004o`0000?o9IP000?o0000obFH0?lUV0001Ol00003obFH0004o`000?lUV03o
0000o`0000;o9IP000?o0000obFH0?lUV0000_lUV0001?l0003o9IP0o`000?l00003obFH0003o`00
0?lUV03o9IP000?o00001OlETP03o`0000;o5I8000Co0000o`J<0?l6S03o1X`00_l00002o`J<0003
o`000?l6S03o1X`000Co00001?l6S0000ol0003o1X`0o`J<0003o`0000Go1X`000?o0000o`J<0?l6
S0000ol00005o`J<00Ko00001?l6S004o`00023ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0>ooooo`00B?ooool00ol0003oooooooooo`0Kooooo`;o00000olUV0000ol0003o9IP0
o`000005obFH0006o`000?lUV03o9IP0obFH0?l0003o9IP00_l00003obFH0003o`000?lUV03o9IP0
00Co00001?lUV0000ol0003o9IP0obFH0003o`0000Go9IP000?o0000obFH0?lUV0001?l00004obFH
00?o00000olUV0000ol0003o5I80o`000002o`0000;o5I8000Oo0000oaFB0?lETP3o5I80o`000?l6
S03o000000Co1X`00ol00002o`J<0003o`000?l6S03o1X`000?o1X`00ol00003o`J<0004o`000?l6
S03o1X`0o`J<00Co00000ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000?o1X`0
00Co0000o`J<0?l0003o00009?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00ko
oooo0019ooooo`03o`000?oooooooooo01cooooo00?o0000obFH0?l000000olUV0000ol0003o9IP0
obFH0002obFH00Oo00001?lUV003o`0000?o9IP000?o0000obFH0?lUV0000_lUV003o`0000?o9IP0
00Co0000obFH0?lUV03o9IP01?l00004obFH0006o`000?lUV03o0000o`000?lUV03o00001?lUV003
o`0000Co5I801_l00003o`J<00;o00000_l6S0001_l0003o1X`0o`J<0?l6S03o0000o`J<00?o0000
00?o1X`0o`000?l6S0000ol6S004o`0000;o1X`000?o0000o`J<0?l6S0000_l6S002o`0000Go1X`0
00?o0000o`J<0?l6S0000ol0000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
3_ooool004[ooooo00?o0000ooooooooool07?ooool2o`0000Co9IP000Co0000obFH0?l0003o0000
0_lUV0000ol0003o9IP0obFH0002obFH0004o`000?lUV03o0000o`0000;o9IP000?o0000obFH0?lU
V0000_lUV0001_l0003o9IP0o`000?l0003o9IP0o`0000Co9IP01?l00002obFH0003o`000?lUV03o
9IP000?o9IP00_l00004obFH0004o`000?lUV03o9IP0o`0000?o9IP000Ko0000oaFB0?l0003o0000
oaFB0?l00004oaFB0003o`000?l6S03o000000Co1X`01_l00005o`J<0004o`000?l6S03o0000o`00
00;o1X`000?o0000o`J<0?l6S0000_l6S0001?l0003o1X`0o`000?l00002o`J<0004o`000?l6S03o
1X`0o`J<00Co0000:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo001;
ooooo`;o00007_ooool00ol0003o9IP0obFH0004o`0000Co9IP000?o0000obFH0?lUV0000ol00005
obFH0003o`000?lUV03o9IP000?o00001?lUV0001?l0003o9IP0o`000?l00002obFH0003o`000?lU
V03o9IP000;o9IP000?o0000obFH0?l000000_l00002obFH0007o`000?lUV03o9IP0obFH0?l0003o
9IP0o`000004obFH00;o00001?lETP001?l0003o5I80oaFB0?lETP03o`0000?o1X`000Co0000o`J<
0?l6S03o00000ol6S0001?l0003o1X`0o`J<0?l6S003o`0000Co1X`01ol00004o`J<00Co0000<?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo001=ooooo`03o`000?oooooo
oooo01cooooo0_l00004obFH0003o`000?lUV03o9IP000Co00000olUV0001?l0003o9IP0obFH0?lU
V004o`0000?o9IP000?o0000obFH0?lUV0001?l00004obFH0003o`000?lUV03o9IP000Co00001?lU
V007o`000004obFH0?l0003o0000o`0000;o5I8000Ko0000oaFB0?lETP3o5I80o`000?lETP02o`00
00?o5I8000?o0000o`J<0?l000000ol6S008o`0000?o1X`000Ko0000o`J<0?l0003o0000o`J<0?l0
0005o`J<0004o`000?l6S03o0000o`0003Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0=ooooo`00C_ooool00ol0003oooooooooo`0Looooo`04o`000?lUV03o9IP0obFH00Co0000
0olUV0000ol0003o9IP0obFH0005o`0000;o9IP000?o0000obFH0?lUV0000_lUV003o`0000Co9IP0
00?o0000obFH0?lUV0001?l00004obFH0004o`000?lUV03o0000o`0000;o9IP000?o0000obFH0?lU
V0001?l00004oaFB00Ko00001OlETP02o`0000?o1X`000?o0000o`J<0?l000001Ol6S0000ol0003o
1X`0o`J<0003o`0000Co1X`000Co0000o`J<0?l6S03o1X`00ol0000gooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03Oooool004oooooo00?o0000ooooooooool07?ooool3o`0000;o
9IP000?o0000obFH0?lUV0000_lUV003o`0000Co9IP000Ko0000obFH0?lUV03o9IP0o`000?lUV002
o`0000?o9IP000?o0000obFH0?lUV0001?l00004obFH0003o`000?lUV03o9IP000[o00001?lETP00
1?l0003o5I80o`000?l00002oaFB0006o`000?lETP3o5I80oaFB0?l0003o5I800ol00002oaFB0003
o`000?l6S03o000000?o1X`000Co0000o`J<0?l6S03o1X`01?l00003o`J<0003o`000?l6S03o1X`0
00Go0000>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo001@ooooo`;o
00007_ooool01_l0003o9IP0obFH0?lUV03o0000obFH00;o00000olUV0000ol0003o9IP0obFH0007
o`0000Go9IP00ol00002obFH0003o`000?lUV03o9IP000?o9IP00ol000000olUV03o0000o`000002
oaFB0005o`000?lETP3o5I80oaFB0?l000000olETP03o`0000Co5I801ol00004oaFB00;o00001?l6
S004o`0000?o1X`000?o0000o`J<0?l6S0001?l00010ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool005;ooooo00?o0000ooooooooool07?ooool5o`0000Go9IP00ol00002
obFH0003o`000?lUV03o9IP000;o9IP000?o0000obFH0?l000000_l00002obFH0006o`000?lUV03o
9IP0obFH0?l0003o9IP00ol000001?lUV03o0000o`000?l00004oaFB00So00000olETP001_l0003o
5I80o`000?l0003o5I80o`0000Go5I8000Co0000oaFB0?l0003o00000_lETP001?l0003o1X`0o`00
0?l00002o`J<0003o`000?l6S03o1X`000;o1X`00ol00015ooooo`05o`000?ooooooooooooooool0
00003oooool005?ooooo00?o0000ooooooooool06oooool00ol0003o9IP0obFH0002obFH0003o`00
0?lUV03o000000;o000000?o9IP0o`000?lUV0000olUV0000ol0003o9IP0obFH0004o`0000Co9IP0
2_l00003oaFB0006o`000?lETP3o0000o`000?lETP3o00001OlETP000ol0003o5I80oaFB0003o`00
00Co5I8000Co0000oaFB0?lETP3o5I800ol00004oaFB00;o00001Ol6S0001?l0003o1X`0o`000?l0
0019ooooo`04o`000?ooooooooooo`0000oooooo001Dooooo`03o`000?oooooooooo01_ooooo00?o
0000obFH0?lUV0001?l00004obFH0003o`000?lUV03o9IP000Co00001?lUV0001Ol0003o9IP0o`00
0?l0003o9IP000Co00001?lETP000ol0003o5I80oaFB0003o`0000Co5I8000?o0000oaFB0?lETP00
0_lETP03o`0000?o5I8000?o0000oaFB0?lETP001Ol00003oaFB0006o`000?lETP3o0000o`000?lE
TP3o00001Ol6S002o`0004cooooo00?o0000ooooool000003oooool005Gooooo00?o0000oooooooo
ool06oooool2o`0000Co9IP000?o0000obFH0?lUV0001?l00004obFH0003o`000?lUV03o9IP000Ko
00000olETP000ol0003o5I80oaFB0002oaFB00?o00000olETP000ol0003o5I80oaFB0002oaFB0004
o`000?lETP3o0000o`0000;o5I8000?o0000oaFB0?lETP001?l00003oaFB0004o`000?lETP3o5I80
oaFB00?o00001?lETP000ol0003o1X`0o`000002o`0004kooooo00Co0000oooooooooooo00003_oo
ool005Kooooo0_l0000Mooooo`03o`000?lUV03o9IP000Co00001?lUV0000ol0003o9IP0obFH0004
o`000003obFH0?l0003o000000?o5I8000Ko0000oaFB0?lETP3o5I80o`000?lETP02o`0000;o5I80
00?o0000oaFB0?lETP002?l00004oaFB00?o00000_lETP000ol0003o5I80oaFB0002oaFB00Co0000
0olETP000ol0003o5I80oaFB0003o`0005;ooooo00?o0000ooooool000003_ooool005Sooooo00?o
0000ooooooooool06oooool2o`0000Co9IP000?o0000obFH0?lUV0001?l00002obFH00Co00001?lE
TP06o`0000Co5I800ol00003oaFB0003o`000?lETP3o5I8000;o5I8000Co0000oaFB0?l0003o0000
0_lETP001_l0003o5I80oaFB0?lETP3o0000oaFB00;o00000olETP000ol0003o5I80oaFB0004o`00
05Kooooo0_l0000>ooooo`00FOooool00ol0003oooooooooo`0Kooooo`04o`000?lUV03o9IP0obFH
00Co00000_lUV004o`0000Co5I8000Ko0000oaFB0?l0003o0000oaFB0?l00004oaFB0004o`000?lE
TP3o0000o`0000;o5I8000?o0000oaFB0?lETP000_lETP000ol0003o5I80oaFB0003o`0000Co5I80
1ol00004oaFB00?o0000FOooool3o`0000kooooo001Jooooo`03o`000?oooooooooo01_ooooo0ol0
0003obFH00?o00001?lETP000ol0003o5I80oaFB0003o`0000Co5I8000?o0000oaFB0?lETP001?l0
0003oaFB00So00000olETP001_l0003o5I80o`000?l0003o5I80o`0000Go5I8000Co0000oaFB0?l0
003o0000F?ooool4o`00017ooooo001Kooooo`;o00007Oooool01?l0003o9IP0o`000?l00002obFH
0003o`000?lETP3o5I8000;o5I800ol00003oaFB0003o`000?lETP3o5I8000Co00001?lETP001Ol0
003o5I80o`000?lETP3o000000Go5I8000?o0000oaFB0?lETP000ol00004oaFB0004o`000?lETP3o
5I80oaFB00?o0000Eoooool3o`0001Gooooo001Mooooo`03o`000?oooooooooo01_ooooo00?o0000
obFH0?lUV0000olUV0001?l0003o5I80o`000?l00002oaFB0003o`000?lETP3o5I8000Co00000olE
TP001?l0003o5I80oaFB0?lETP03o`0000?o5I8000?o0000oaFB0?lETP000_lETP03o`0000?o5I80
00?o0000oaFB0?lETP001Ol0001Fooooo`Co00006?ooool005kooooo00?o0000ooooooooool06ooo
ool00ol0003o9IP0obFH0002obFH00;o00001?lETP03o`0000;o5I8000?o0000oaFB0?lETP000_lE
TP04o`0000?o5I8000Ko0000oaFB0?lETP3o5I80o`000?lETP02o`0000;o5I8000?o0000oaFB0?lE
TP001?l0001Gooooo`Co00007?ooool005oooooo00?o0000ooooooooool06oooool01?l0003o9IP0
o`000?l00002obFH0004o`000?lETP3o0000o`0000;o5I8000Ko0000oaFB0?lETP3o5I80o`000?lE
TP02o`0000?o5I8000?o0000oaFB0?lETP002?l00002oaFB00Co0000Eoooool4o`00023ooooo001P
ooooo`03o`000?oooooooooo01_ooooo0_l00002obFH00Co00000olETP07o`0000Co5I800ol00003
oaFB0003o`000?lETP3o5I8000Co0000F?ooool3o`0002Cooooo001Qooooo`;o00007Oooool2o`00
00Co9IP000?o0000oaFB0?l000000olETP001_l0003o5I80oaFB0?lETP3o0000oaFB00;o00000_lE
TP000ol0003o5I80oaFB0004o`0005Sooooo1?l0000Wooooo`00Hoooool00ol0003oooooooooo`0J
ooooo`03o`000?lUV03o9IP000?o9IP00_l00004oaFB00Ko00001?lETP03o`0005Sooooo1?l0000[
ooooo`00I?ooool00ol0003oooooooooo`0Jooooo`03o`000?lUV03o000000;o00000_lUV0001_l0
003o5I80o`000?l0003o5I80o`0000Co5I8000Co0000oaFB0?l0003o0000Eoooool4o`0002oooooo
001Uooooo`03o`000?oooooooooo01[ooooo0_l00004obFH00?o00000olETP000ol0003o5I80oaFB
0003o`0005Kooooo0ol0000cooooo`00I_ooool2o`0001cooooo00Co0000obFH0?l0003o00000_lU
V007o`0005Gooooo1?l0000fooooo`00J?ooool00ol0003oooooooooo`0Jooooo`05o`000?lUV03o
9IP0obFH0?l00000F?ooool4o`0003[ooooo001Yooooo`03o`000?oooooooooo01[ooooo00?o0000
obFH0?l00000EOooool4o`0003kooooo001Zooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0DOooool3o`0004;ooooo001[ooooo`;o00006_ooool00ol0003oooooooooo`1=ooooo`Co
0000AOooool006gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`Co0000
BOooool006kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000COoo
ool006oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`11ooooo`Co0000DOooool0
073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0nooooo`?o0000EOooool0077o
oooo0_l0000Dooooo`03o`000?oooooooooo03[ooooo1?l0001Hooooo`00Loooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo03Kooooo1?l0001Looooo`00M?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03;ooooo1?l0001Pooooo`00MOooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02oooooo0ol0001Tooooo`00M_ooool2o`0000oooooo00?o0000oooo
ooooool0:oooool4o`0006Oooooo001hooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool09oooool4o`0006_ooooo001iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
9?ooool4o`0006oooooo001jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Ooo
ool3o`0007?ooooo001kooooo`;o00002Oooool00ol0003oooooooooo`0Mooooo`Co0000M_ooool0
07gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`Co0000N_ooool007ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000O_ooool007oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o0000P_ooool0083ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000QOooool0087ooooo0_l00003
ooooo`03o`000?oooooooooo00[ooooo1?l00029ooooo`00Poooool01?l0003oooooooooool00008
ooooo`Co0000SOooool008Cooooo00?o0000ooooool000001Oooool3o`00097ooooo0025ooooo`;o
000000?oooooo`000?l000000_l0002Dooooo`00Q_ooool2o`0009Sooooo003oooooob7ooooo003o
ooooob7ooooo003Dooooo`?o0000BOooool00=Gooooo00?o0000ooooooooool0B?ooool006?ooooo
00?o0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Sooooo
0ol00003ooooo`?o00001?ooool3o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o0000
2?ooool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00000oooool3o`0000;o
oooo0ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003ooooo`;o00001?ooool00ol0003o
ooooooooo`17ooooo`00Hoooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Co
oooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00Co0000oooooooooooo00001Ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`17ooooo`00Hoooool00ol0003oooooo`000003ooooo`?o00000oooool00ol0003ooooo
o`000002ooooo`Go00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool3o`0000Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000004Sooooo001R
ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?ooooooooooooooool0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000002?ooool3o`0000?ooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooooooo
o`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool00000B?ooool006;ooooo00Go0000ooooool0003oooooo`000002ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo0_l0
00000ooooooo0000o`000002ooooo`?o00000_ooool4o`0000;ooooo1?l0000:ooooo`04o`000?oo
ooooooooooooo`Co00000_ooool4o`0000?ooooo0ol00002ooooo`Co00000oooool4o`000004oooo
ool0003o0000o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l00000Aoooool006;ooooo
00Go0000ooooool0003oooooo`00000Jooooo`04o`000?ooooooooooo`0001Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0C_ooool006;ooooo1_l0000Hooooo`Go00005?ooool00ol0003oooooooooo`08ooooo`Go
00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0C_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {231.75, 0}} -> {-0.179426, -0.0244776, \
0.00413968, 0.00413968}},
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.02757 .24618 -24 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -22.3468 -9 ]
[.3345 .12542 1.65319 0 ]
[.50253 .05935 -21.0958 -9 ]
[.50253 .05935 2.90415 0 ]
[.68156 -0.01098 -19.8449 -9 ]
[.68156 -0.01098 4.1551 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 24 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 24 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 18 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.0148 .32345 -18 -2.79166 ]
[.0148 .32345 0 6.20834 ]
[.00137 .40763 -18 -2.86317 ]
[.00137 .40763 0 6.13683 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-0.5)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.4)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(-0.3)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(-0.2)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(-0.1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-0.2)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-0.1)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.1)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.2)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02707 .3188 m
.03321 .31647 L
s
[(-15)] .0148 .32345 1 -0.37963 Mshowa
.0137 .40315 m
.01987 .4009 L
s
[(-10)] .00137 .40763 1 -0.36374 Mshowa
.125 Mabswid
.02445 .33531 m
.02814 .33392 L
s
.02181 .352 m
.0255 .35062 L
s
.01914 .36887 m
.02283 .3675 L
s
.01644 .38592 m
.02013 .38456 L
s
.01095 .42056 m
.01465 .41923 L
s
.00816 .43817 m
.01186 .43684 L
s
.00533 .45597 m
.00905 .45465 L
s
.00248 .47396 m
.0062 .47266 L
s
.02966 .30245 m
.03334 .30105 L
s
.03223 .28628 m
.0359 .28486 L
s
.03476 .27027 m
.03843 .26885 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .054 .156 r
.39508 .59931 .40493 .60917 .42134 .60955 .41153 .59965 Metetra
0 .081 .18 r
.41153 .59965 .42134 .60955 .4379 .60998 .42813 .60003 Metetra
0 .113 .204 r
.42813 .60003 .4379 .60998 .45461 .61045 .44489 .60047 Metetra
0 .15 .229 r
.44489 .60047 .45461 .61045 .47148 .61098 .46181 .60095 Metetra
0 .193 .253 r
.46181 .60095 .47148 .61098 .48851 .61157 .47889 .60149 Metetra
0 .242 .278 r
.47889 .60149 .48851 .61157 .50571 .6122 .49614 .60208 Metetra
0 .296 .303 r
.49614 .60208 .50571 .6122 .52307 .61289 .51355 .60272 Metetra
0 .328 .299 r
.51355 .60272 .52307 .61289 .5406 .61363 .53113 .60341 Metetra
0 .353 .284 r
.53113 .60341 .5406 .61363 .5583 .61442 .54889 .60416 Metetra
0 .379 .262 r
.54889 .60416 .5583 .61442 .57618 .61528 .56683 .60497 Metetra
0 .404 .235 r
.56683 .60497 .57618 .61528 .59424 .61618 .58495 .60583 Metetra
0 .43 .201 r
.58495 .60583 .59424 .61618 .61249 .61715 .60325 .60675 Metetra
0 .457 .162 r
.60325 .60675 .61249 .61715 .63092 .61817 .62174 .60773 Metetra
0 .483 .116 r
.62174 .60773 .63092 .61817 .64954 .61926 .64042 .60876 Metetra
0 .509 .064 r
.64042 .60876 .64954 .61926 .66835 .6204 .6593 .60986 Metetra
0 .536 .005 r
.6593 .60986 .66835 .6204 .68736 .62161 .67838 .61102 Metetra
.06 .563 0 r
.67838 .61102 .68736 .62161 .70658 .62287 .69766 .61224 Metetra
.133 .59 0 r
.69766 .61224 .70658 .62287 .72599 .62421 .71715 .61352 Metetra
.212 .618 0 r
.71715 .61352 .72599 .62421 .74562 .6256 .73685 .61487 Metetra
.299 .645 0 r
.73685 .61487 .74562 .6256 .76547 .62706 .75676 .61628 Metetra
.393 .673 0 r
.75676 .61628 .76547 .62706 .78553 .62859 .7769 .61775 Metetra
.494 .701 0 r
.7769 .61775 .78553 .62859 .80582 .63018 .79726 .6193 Metetra
.603 .729 0 r
.79726 .6193 .80582 .63018 .82633 .63185 .81786 .62091 Metetra
.72 .758 0 r
.81786 .62091 .82633 .63185 .84707 .63358 .83868 .6226 Metetra
.786 .728 0 r
.83868 .6226 .84707 .63358 .86806 .63539 .85975 .62435 Metetra
.815 .653 0 r
.85975 .62435 .86806 .63539 .88928 .63727 .88106 .62618 Metetra
.844 .57 0 r
.88106 .62618 .88928 .63727 .91075 .63922 .90262 .62808 Metetra
.873 .48 0 r
.90262 .62808 .91075 .63922 .93248 .64125 .92444 .63006 Metetra
.903 .381 0 r
.92444 .63006 .93248 .64125 .95446 .64335 .94651 .63211 Metetra
.932 .274 0 r
.94651 .63211 .95446 .64335 .97671 .64554 .96885 .63425 Metetra
.962 .158 0 r
.96885 .63425 .97671 .64554 .99922 .6478 .99147 .63646 Metetra
0 .051 .153 r
.38511 .5894 .39508 .59931 .41153 .59965 .4016 .58969 Metetra
0 .077 .177 r
.4016 .58969 .41153 .59965 .42813 .60003 .41826 .59003 Metetra
0 .109 .201 r
.41826 .59003 .42813 .60003 .44489 .60047 .43506 .59042 Metetra
0 .145 .226 r
.43506 .59042 .44489 .60047 .46181 .60095 .45203 .59086 Metetra
0 .188 .25 r
.45203 .59086 .46181 .60095 .47889 .60149 .46916 .59135 Metetra
0 .236 .275 r
.46916 .59135 .47889 .60149 .49614 .60208 .48646 .59189 Metetra
0 .29 .3 r
.48646 .59189 .49614 .60208 .51355 .60272 .50392 .59248 Metetra
0 .325 .301 r
.50392 .59248 .51355 .60272 .53113 .60341 .52156 .59313 Metetra
0 .35 .286 r
.52156 .59313 .53113 .60341 .54889 .60416 .53937 .59384 Metetra
0 .376 .265 r
.53937 .59384 .54889 .60416 .56683 .60497 .55737 .59459 Metetra
0 .402 .238 r
.55737 .59459 .56683 .60497 .58495 .60583 .57554 .59541 Metetra
0 .427 .206 r
.57554 .59541 .58495 .60583 .60325 .60675 .5939 .59628 Metetra
0 .454 .167 r
.5939 .59628 .60325 .60675 .62174 .60773 .61246 .59721 Metetra
0 .48 .122 r
.61246 .59721 .62174 .60773 .64042 .60876 .6312 .5982 Metetra
0 .507 .07 r
.6312 .5982 .64042 .60876 .6593 .60986 .65014 .59924 Metetra
0 .533 .012 r
.65014 .59924 .6593 .60986 .67838 .61102 .66929 .60035 Metetra
.053 .56 0 r
.66929 .60035 .67838 .61102 .69766 .61224 .68864 .60152 Metetra
.125 .587 0 r
.68864 .60152 .69766 .61224 .71715 .61352 .70819 .60275 Metetra
.203 .615 0 r
.70819 .60275 .71715 .61352 .73685 .61487 .72797 .60405 Metetra
.289 .642 0 r
.72797 .60405 .73685 .61487 .75676 .61628 .74796 .60541 Metetra
.382 .67 0 r
.74796 .60541 .75676 .61628 .7769 .61775 .76817 .60684 Metetra
.483 .698 0 r
.76817 .60684 .7769 .61775 .79726 .6193 .78861 .60833 Metetra
.591 .726 0 r
.78861 .60833 .79726 .6193 .81786 .62091 .80928 .6099 Metetra
.707 .755 0 r
.80928 .6099 .81786 .62091 .83868 .6226 .83019 .61153 Metetra
.783 .736 0 r
.83019 .61153 .83868 .6226 .85975 .62435 .85134 .61323 Metetra
.812 .661 0 r
.85134 .61323 .85975 .62435 .88106 .62618 .87274 .61501 Metetra
.841 .579 0 r
.87274 .61501 .88106 .62618 .90262 .62808 .89439 .61686 Metetra
.87 .489 0 r
.89439 .61686 .90262 .62808 .92444 .63006 .9163 .61878 Metetra
.9 .391 0 r
.9163 .61878 .92444 .63006 .94651 .63211 .93847 .62078 Metetra
.929 .285 0 r
.93847 .62078 .94651 .63211 .96885 .63425 .96091 .62286 Metetra
.959 .17 0 r
.96091 .62286 .96885 .63425 .99147 .63646 .98362 .62502 Metetra
0 .048 .151 r
.37503 .57941 .38511 .5894 .4016 .58969 .39157 .57966 Metetra
0 .074 .174 r
.39157 .57966 .4016 .58969 .41826 .59003 .40827 .57995 Metetra
0 .105 .199 r
.40827 .57995 .41826 .59003 .43506 .59042 .42512 .5803 Metetra
0 .141 .223 r
.42512 .5803 .43506 .59042 .45203 .59086 .44214 .58069 Metetra
0 .183 .247 r
.44214 .58069 .45203 .59086 .46916 .59135 .45932 .58113 Metetra
0 .23 .272 r
.45932 .58113 .46916 .59135 .48646 .59189 .47667 .58163 Metetra
0 .283 .297 r
.47667 .58163 .48646 .59189 .50392 .59248 .49418 .58218 Metetra
0 .322 .302 r
.49418 .58218 .50392 .59248 .52156 .59313 .51188 .58278 Metetra
0 .348 .288 r
.51188 .58278 .52156 .59313 .53937 .59384 .52974 .58343 Metetra
0 .373 .267 r
.52974 .58343 .53937 .59384 .55737 .59459 .54779 .58414 Metetra
0 .399 .241 r
.54779 .58414 .55737 .59459 .57554 .59541 .56603 .58491 Metetra
0 .425 .209 r
.56603 .58491 .57554 .59541 .5939 .59628 .58445 .58573 Metetra
0 .451 .171 r
.58445 .58573 .5939 .59628 .61246 .59721 .60306 .58661 Metetra
0 .477 .127 r
.60306 .58661 .61246 .59721 .6312 .5982 .62187 .58755 Metetra
0 .504 .076 r
.62187 .58755 .6312 .5982 .65014 .59924 .64088 .58855 Metetra
0 .531 .018 r
.64088 .58855 .65014 .59924 .66929 .60035 .66009 .58961 Metetra
.046 .557 0 r
.66009 .58961 .66929 .60035 .68864 .60152 .67951 .59072 Metetra
.117 .585 0 r
.67951 .59072 .68864 .60152 .70819 .60275 .69913 .59191 Metetra
.195 .612 0 r
.69913 .59191 .70819 .60275 .72797 .60405 .71898 .59315 Metetra
.28 .64 0 r
.71898 .59315 .72797 .60405 .74796 .60541 .73904 .59446 Metetra
.373 .667 0 r
.73904 .59446 .74796 .60541 .76817 .60684 .75933 .59584 Metetra
.473 .695 0 r
.75933 .59584 .76817 .60684 .78861 .60833 .77985 .59728 Metetra
.58 .724 0 r
.77985 .59728 .78861 .60833 .80928 .6099 .80061 .59879 Metetra
.696 .752 0 r
.80061 .59879 .80928 .6099 .83019 .61153 .8216 .60037 Metetra
.781 .742 0 r
.8216 .60037 .83019 .61153 .85134 .61323 .84283 .60202 Metetra
.809 .669 0 r
.84283 .60202 .85134 .61323 .87274 .61501 .86432 .60374 Metetra
.838 .587 0 r
.86432 .60374 .87274 .61501 .89439 .61686 .88606 .60554 Metetra
.868 .498 0 r
.88606 .60554 .89439 .61686 .9163 .61878 .90806 .60741 Metetra
.897 .401 0 r
.90806 .60741 .9163 .61878 .93847 .62078 .93033 .60936 Metetra
.927 .295 0 r
.93033 .60936 .93847 .62078 .96091 .62286 .95287 .61138 Metetra
.956 .181 0 r
.95287 .61138 .96091 .62286 .98362 .62502 .97568 .61348 Metetra
0 .046 .148 r
.36483 .56937 .37503 .57941 .39157 .57966 .38142 .56957 Metetra
0 .071 .172 r
.38142 .56957 .39157 .57966 .40827 .57995 .39816 .56981 Metetra
0 .101 .196 r
.39816 .56981 .40827 .57995 .42512 .5803 .41506 .57011 Metetra
0 .137 .22 r
.41506 .57011 .42512 .5803 .44214 .58069 .43213 .57045 Metetra
0 .178 .245 r
.43213 .57045 .44214 .58069 .45932 .58113 .44936 .57085 Metetra
0 .225 .27 r
.44936 .57085 .45932 .58113 .47667 .58163 .46676 .5713 Metetra
0 .278 .294 r
.46676 .5713 .47667 .58163 .49418 .58218 .48433 .5718 Metetra
0 .32 .303 r
.48433 .5718 .49418 .58218 .51188 .58278 .50208 .57235 Metetra
0 .345 .289 r
.50208 .57235 .51188 .58278 .52974 .58343 .52 .57296 Metetra
0 .37 .27 r
.52 .57296 .52974 .58343 .54779 .58414 .53811 .57362 Metetra
0 .396 .244 r
.53811 .57362 .54779 .58414 .56603 .58491 .5564 .57433 Metetra
0 .422 .213 r
.5564 .57433 .56603 .58491 .58445 .58573 .57488 .57511 Metetra
0 .448 .175 r
.57488 .57511 .58445 .58573 .60306 .58661 .59356 .57594 Metetra
0 .475 .131 r
.59356 .57594 .60306 .58661 .62187 .58755 .61243 .57682 Metetra
0 .501 .081 r
.61243 .57682 .62187 .58755 .64088 .58855 .6315 .57777 Metetra
0 .528 .024 r
.6315 .57777 .64088 .58855 .66009 .58961 .65078 .57878 Metetra
.04 .555 0 r
.65078 .57878 .66009 .58961 .67951 .59072 .67027 .57985 Metetra
.11 .582 0 r
.67027 .57985 .67951 .59072 .69913 .59191 .68997 .58098 Metetra
.188 .609 0 r
.68997 .58098 .69913 .59191 .71898 .59315 .70988 .58217 Metetra
.272 .637 0 r
.70988 .58217 .71898 .59315 .73904 .59446 .73002 .58343 Metetra
.364 .665 0 r
.73002 .58343 .73904 .59446 .75933 .59584 .75039 .58475 Metetra
.463 .693 0 r
.75039 .58475 .75933 .59584 .77985 .59728 .77099 .58614 Metetra
.57 .721 0 r
.77099 .58614 .77985 .59728 .80061 .59879 .79182 .5876 Metetra
.685 .749 0 r
.79182 .5876 .80061 .59879 .8216 .60037 .8129 .58912 Metetra
.778 .748 0 r
.8129 .58912 .8216 .60037 .84283 .60202 .83422 .59072 Metetra
.807 .675 0 r
.83422 .59072 .84283 .60202 .86432 .60374 .8558 .59239 Metetra
.836 .595 0 r
.8558 .59239 .86432 .60374 .88606 .60554 .87763 .59413 Metetra
.865 .506 0 r
.87763 .59413 .88606 .60554 .90806 .60741 .89972 .59595 Metetra
.894 .409 0 r
.89972 .59595 .90806 .60741 .93033 .60936 .92209 .59784 Metetra
.924 .304 0 r
.92209 .59784 .93033 .60936 .95287 .61138 .94472 .5998 Metetra
.954 .191 0 r
.94472 .5998 .95287 .61138 .97568 .61348 .96764 .60185 Metetra
0 .043 .146 r
.35452 .55925 .36483 .56937 .38142 .56957 .37115 .5594 Metetra
0 .068 .17 r
.37115 .5594 .38142 .56957 .39816 .56981 .38794 .5596 Metetra
0 .098 .194 r
.38794 .5596 .39816 .56981 .41506 .57011 .40489 .55985 Metetra
0 .133 .218 r
.40489 .55985 .41506 .57011 .43213 .57045 .42201 .56015 Metetra
0 .174 .243 r
.42201 .56015 .43213 .57045 .44936 .57085 .43929 .5605 Metetra
0 .22 .267 r
.43929 .5605 .44936 .57085 .46676 .5713 .45674 .5609 Metetra
0 .272 .292 r
.45674 .5609 .46676 .5713 .48433 .5718 .47436 .56135 Metetra
0 .317 .304 r
.47436 .56135 .48433 .5718 .50208 .57235 .49216 .56185 Metetra
0 .343 .291 r
.49216 .56185 .50208 .57235 .52 .57296 .51014 .56241 Metetra
0 .368 .272 r
.51014 .56241 .52 .57296 .53811 .57362 .52831 .56302 Metetra
0 .394 .247 r
.52831 .56302 .53811 .57362 .5564 .57433 .54666 .56368 Metetra
0 .42 .216 r
.54666 .56368 .5564 .57433 .57488 .57511 .5652 .5644 Metetra
0 .446 .179 r
.5652 .5644 .57488 .57511 .59356 .57594 .58394 .56518 Metetra
0 .472 .135 r
.58394 .56518 .59356 .57594 .61243 .57682 .60287 .56602 Metetra
0 .499 .086 r
.60287 .56602 .61243 .57682 .6315 .57777 .62201 .56691 Metetra
0 .526 .029 r
.62201 .56691 .6315 .57777 .65078 .57878 .64136 .56787 Metetra
.034 .553 0 r
.64136 .56787 .65078 .57878 .67027 .57985 .66091 .56889 Metetra
.104 .58 0 r
.66091 .56889 .67027 .57985 .68997 .58098 .68069 .56996 Metetra
.181 .607 0 r
.68069 .56996 .68997 .58098 .70988 .58217 .70068 .5711 Metetra
.265 .635 0 r
.70068 .5711 .70988 .58217 .73002 .58343 .72089 .57231 Metetra
.356 .662 0 r
.72089 .57231 .73002 .58343 .75039 .58475 .74134 .57358 Metetra
.455 .69 0 r
.74134 .57358 .75039 .58475 .77099 .58614 .76202 .57491 Metetra
.561 .719 0 r
.76202 .57491 .77099 .58614 .79182 .5876 .78293 .57631 Metetra
.675 .747 0 r
.78293 .57631 .79182 .5876 .8129 .58912 .80409 .57779 Metetra
.776 .754 0 r
.80409 .57779 .8129 .58912 .83422 .59072 .8255 .57933 Metetra
.804 .682 0 r
.8255 .57933 .83422 .59072 .8558 .59239 .84717 .58094 Metetra
.833 .602 0 r
.84717 .58094 .8558 .59239 .87763 .59413 .86909 .58262 Metetra
.863 .513 0 r
.86909 .58262 .87763 .59413 .89972 .59595 .89128 .58438 Metetra
.892 .417 0 r
.89128 .58438 .89972 .59595 .92209 .59784 .91374 .58622 Metetra
.922 .313 0 r
.91374 .58622 .92209 .59784 .94472 .5998 .93648 .58813 Metetra
.951 .2 0 r
.93648 .58813 .94472 .5998 .96764 .60185 .9595 .59012 Metetra
0 .041 .144 r
.34409 .54907 .35452 .55925 .37115 .5594 .36076 .54917 Metetra
0 .066 .167 r
.36076 .54917 .37115 .5594 .38794 .5596 .3776 .54932 Metetra
0 .095 .192 r
.3776 .54932 .38794 .5596 .40489 .55985 .3946 .54952 Metetra
0 .13 .216 r
.3946 .54952 .40489 .55985 .42201 .56015 .41176 .54977 Metetra
0 .17 .24 r
.41176 .54977 .42201 .56015 .43929 .5605 .42909 .55007 Metetra
0 .216 .265 r
.42909 .55007 .43929 .5605 .45674 .5609 .4466 .55042 Metetra
0 .268 .29 r
.4466 .55042 .45674 .5609 .47436 .56135 .46427 .55082 Metetra
0 .315 .305 r
.46427 .55082 .47436 .56135 .49216 .56185 .48213 .55127 Metetra
0 .34 .292 r
.48213 .55127 .49216 .56185 .51014 .56241 .50017 .55178 Metetra
0 .366 .274 r
.50017 .55178 .51014 .56241 .52831 .56302 .51839 .55234 Metetra
0 .392 .249 r
.51839 .55234 .52831 .56302 .54666 .56368 .5368 .55295 Metetra
0 .418 .219 r
.5368 .55295 .54666 .56368 .5652 .5644 .5554 .55362 Metetra
0 .444 .182 r
.5554 .55362 .5652 .5644 .58394 .56518 .5742 .55435 Metetra
0 .47 .139 r
.5742 .55435 .58394 .56518 .60287 .56602 .5932 .55513 Metetra
0 .497 .09 r
.5932 .55513 .60287 .56602 .62201 .56691 .61241 .55597 Metetra
0 .524 .034 r
.61241 .55597 .62201 .56691 .64136 .56787 .63182 .55688 Metetra
.029 .55 0 r
.63182 .55688 .64136 .56787 .66091 .56889 .65145 .55784 Metetra
.098 .578 0 r
.65145 .55784 .66091 .56889 .68069 .56996 .67129 .55886 Metetra
.174 .605 0 r
.67129 .55886 .68069 .56996 .70068 .5711 .69136 .55995 Metetra
.258 .633 0 r
.69136 .55995 .70068 .5711 .72089 .57231 .71165 .5611 Metetra
.349 .66 0 r
.71165 .5611 .72089 .57231 .74134 .57358 .73217 .56231 Metetra
.447 .688 0 r
.73217 .56231 .74134 .57358 .76202 .57491 .75293 .56359 Metetra
.553 .717 0 r
.75293 .56359 .76202 .57491 .78293 .57631 .77393 .56494 Metetra
.666 .745 0 r
.77393 .56494 .78293 .57631 .80409 .57779 .79518 .56635 Metetra
.774 .759 0 r
.79518 .56635 .80409 .57779 .8255 .57933 .81667 .56784 Metetra
.802 .687 0 r
.81667 .56784 .8255 .57933 .84717 .58094 .83843 .56939 Metetra
.831 .608 0 r
.83843 .56939 .84717 .58094 .86909 .58262 .86045 .57102 Metetra
.861 .52 0 r
.86045 .57102 .86909 .58262 .89128 .58438 .88273 .57272 Metetra
.89 .425 0 r
.88273 .57272 .89128 .58438 .91374 .58622 .90529 .5745 Metetra
.92 .321 0 r
.90529 .5745 .91374 .58622 .93648 .58813 .92813 .57635 Metetra
.949 .208 0 r
.92813 .57635 .93648 .58813 .9595 .59012 .95126 .57828 Metetra
0 .04 .142 r
.33353 .53881 .34409 .54907 .36076 .54917 .35025 .53886 Metetra
0 .064 .165 r
.35025 .53886 .36076 .54917 .3776 .54932 .36714 .53897 Metetra
0 .093 .19 r
.36714 .53897 .3776 .54932 .3946 .54952 .38418 .53912 Metetra
0 .127 .214 r
.38418 .53912 .3946 .54952 .41176 .54977 .4014 .53932 Metetra
0 .167 .238 r
.4014 .53932 .41176 .54977 .42909 .55007 .41878 .53956 Metetra
0 .212 .263 r
.41878 .53956 .42909 .55007 .4466 .55042 .43633 .53986 Metetra
0 .264 .288 r
.43633 .53986 .4466 .55042 .46427 .55082 .45406 .54021 Metetra
0 .313 .306 r
.45406 .54021 .46427 .55082 .48213 .55127 .47197 .54061 Metetra
0 .339 .293 r
.47197 .54061 .48213 .55127 .50017 .55178 .49007 .54107 Metetra
0 .364 .275 r
.49007 .54107 .50017 .55178 .51839 .55234 .50835 .54158 Metetra
0 .39 .251 r
.50835 .54158 .51839 .55234 .5368 .55295 .52682 .54214 Metetra
0 .416 .221 r
.52682 .54214 .5368 .55295 .5554 .55362 .54549 .54275 Metetra
0 .442 .185 r
.54549 .54275 .5554 .55362 .5742 .55435 .56435 .54343 Metetra
0 .468 .142 r
.56435 .54343 .5742 .55435 .5932 .55513 .58341 .54416 Metetra
0 .495 .094 r
.58341 .54416 .5932 .55513 .61241 .55597 .60269 .54495 Metetra
0 .522 .038 r
.60269 .54495 .61241 .55597 .63182 .55688 .62217 .54579 Metetra
.024 .549 0 r
.62217 .54579 .63182 .55688 .65145 .55784 .64186 .5467 Metetra
.093 .576 0 r
.64186 .5467 .65145 .55784 .67129 .55886 .66178 .54767 Metetra
.169 .603 0 r
.66178 .54767 .67129 .55886 .69136 .55995 .68192 .5487 Metetra
.252 .631 0 r
.68192 .5487 .69136 .55995 .71165 .5611 .70229 .54979 Metetra
.342 .658 0 r
.70229 .54979 .71165 .5611 .73217 .56231 .72289 .55095 Metetra
.44 .686 0 r
.72289 .55095 .73217 .56231 .75293 .56359 .74373 .55218 Metetra
.545 .715 0 r
.74373 .55218 .75293 .56359 .77393 .56494 .76482 .55347 Metetra
.658 .743 0 r
.76482 .55347 .77393 .56494 .79518 .56635 .78615 .55482 Metetra
.772 .764 0 r
.78615 .55482 .79518 .56635 .81667 .56784 .80773 .55625 Metetra
.8 .692 0 r
.80773 .55625 .81667 .56784 .83843 .56939 .82958 .55775 Metetra
.829 .613 0 r
.82958 .55775 .83843 .56939 .86045 .57102 .85169 .55932 Metetra
.859 .526 0 r
.85169 .55932 .86045 .57102 .88273 .57272 .87407 .56096 Metetra
.888 .431 0 r
.87407 .56096 .88273 .57272 .90529 .5745 .89673 .56268 Metetra
.918 .328 0 r
.89673 .56268 .90529 .5745 .92813 .57635 .91967 .56447 Metetra
.947 .216 0 r
.91967 .56447 .92813 .57635 .95126 .57828 .94291 .56634 Metetra
0 .038 .14 r
.32285 .52848 .33353 .53881 .35025 .53886 .33962 .52849 Metetra
0 .062 .164 r
.33962 .52849 .35025 .53886 .36714 .53897 .35655 .52854 Metetra
0 .09 .188 r
.35655 .52854 .36714 .53897 .38418 .53912 .37364 .52864 Metetra
0 .124 .212 r
.37364 .52864 .38418 .53912 .4014 .53932 .39091 .52879 Metetra
0 .164 .237 r
.39091 .52879 .4014 .53932 .41878 .53956 .40834 .52898 Metetra
0 .209 .261 r
.40834 .52898 .41878 .53956 .43633 .53986 .42595 .52923 Metetra
0 .26 .286 r
.42595 .52923 .43633 .53986 .45406 .54021 .44373 .52953 Metetra
0 .311 .306 r
.44373 .52953 .45406 .54021 .47197 .54061 .4617 .52988 Metetra
0 .337 .294 r
.4617 .52988 .47197 .54061 .49007 .54107 .47985 .53028 Metetra
0 .362 .277 r
.47985 .53028 .49007 .54107 .50835 .54158 .49819 .53073 Metetra
0 .388 .253 r
.49819 .53073 .50835 .54158 .52682 .54214 .51672 .53124 Metetra
0 .414 .223 r
.51672 .53124 .52682 .54214 .54549 .54275 .53545 .5318 Metetra
0 .44 .187 r
.53545 .5318 .54549 .54275 .56435 .54343 .55437 .53242 Metetra
0 .467 .145 r
.55437 .53242 .56435 .54343 .58341 .54416 .5735 .5331 Metetra
0 .493 .097 r
.5735 .5331 .58341 .54416 .60269 .54495 .59284 .53383 Metetra
0 .52 .042 r
.59284 .53383 .60269 .54495 .62217 .54579 .61239 .53462 Metetra
.02 .547 0 r
.61239 .53462 .62217 .54579 .64186 .5467 .63216 .53548 Metetra
.088 .574 0 r
.63216 .53548 .64186 .5467 .66178 .54767 .65215 .53639 Metetra
.164 .601 0 r
.65215 .53639 .66178 .54767 .68192 .5487 .67237 .53736 Metetra
.246 .629 0 r
.67237 .53736 .68192 .5487 .70229 .54979 .69281 .5384 Metetra
.336 .657 0 r
.69281 .5384 .70229 .54979 .72289 .55095 .71349 .5395 Metetra
.434 .685 0 r
.71349 .5395 .72289 .55095 .74373 .55218 .73442 .54066 Metetra
.539 .713 0 r
.73442 .54066 .74373 .55218 .76482 .55347 .75559 .5419 Metetra
.651 .741 0 r
.75559 .5419 .76482 .55347 .78615 .55482 .777 .54319 Metetra
.77 .768 0 r
.777 .54319 .78615 .55482 .80773 .55625 .79868 .54456 Metetra
.799 .697 0 r
.79868 .54456 .80773 .55625 .82958 .55775 .82062 .546 Metetra
.828 .618 0 r
.82062 .546 .82958 .55775 .85169 .55932 .84282 .54751 Metetra
.857 .532 0 r
.84282 .54751 .85169 .55932 .87407 .56096 .8653 .54909 Metetra
.886 .437 0 r
.8653 .54909 .87407 .56096 .89673 .56268 .88806 .55075 Metetra
.916 .334 0 r
.88806 .55075 .89673 .56268 .91967 .56447 .91111 .55248 Metetra
.946 .223 0 r
.91111 .55248 .91967 .56447 .94291 .56634 .93445 .55429 Metetra
0 .037 .138 r
.31204 .51808 .32285 .52848 .33962 .52849 .32885 .51803 Metetra
0 .06 .162 r
.32885 .51803 .33962 .52849 .35655 .52854 .34583 .51803 Metetra
0 .088 .186 r
.34583 .51803 .35655 .52854 .37364 .52864 .36297 .51808 Metetra
0 .122 .211 r
.36297 .51808 .37364 .52864 .39091 .52879 .38029 .51818 Metetra
0 .161 .235 r
.38029 .51818 .39091 .52879 .40834 .52898 .39777 .51832 Metetra
0 .206 .26 r
.39777 .51832 .40834 .52898 .42595 .52923 .41543 .51852 Metetra
0 .257 .285 r
.41543 .51852 .42595 .52923 .44373 .52953 .43327 .51876 Metetra
0 .31 .307 r
.43327 .51876 .44373 .52953 .4617 .52988 .45129 .51906 Metetra
0 .335 .295 r
.45129 .51906 .4617 .52988 .47985 .53028 .4695 .5194 Metetra
0 .361 .278 r
.4695 .5194 .47985 .53028 .49819 .53073 .4879 .5198 Metetra
0 .387 .254 r
.4879 .5198 .49819 .53073 .51672 .53124 .50649 .52026 Metetra
0 .412 .225 r
.50649 .52026 .51672 .53124 .53545 .5318 .52528 .52077 Metetra
0 .439 .19 r
.52528 .52077 .53545 .5318 .55437 .53242 .54427 .52133 Metetra
0 .465 .148 r
.54427 .52133 .55437 .53242 .5735 .5331 .56347 .52195 Metetra
0 .492 .1 r
.56347 .52195 .5735 .5331 .59284 .53383 .58287 .52263 Metetra
0 .518 .045 r
.58287 .52263 .59284 .53383 .61239 .53462 .6025 .52336 Metetra
.016 .545 0 r
.6025 .52336 .61239 .53462 .63216 .53548 .62234 .52416 Metetra
.084 .572 0 r
.62234 .52416 .63216 .53548 .65215 .53639 .6424 .52501 Metetra
.159 .6 0 r
.6424 .52501 .65215 .53639 .67237 .53736 .66269 .52593 Metetra
.242 .627 0 r
.66269 .52593 .67237 .53736 .69281 .5384 .68322 .52691 Metetra
.331 .655 0 r
.68322 .52691 .69281 .5384 .71349 .5395 .70398 .52795 Metetra
.428 .683 0 r
.70398 .52795 .71349 .5395 .73442 .54066 .72498 .52905 Metetra
.533 .711 0 r
.72498 .52905 .73442 .54066 .75559 .5419 .74624 .53023 Metetra
.645 .74 0 r
.74624 .53023 .75559 .5419 .777 .54319 .76774 .53146 Metetra
.765 .768 0 r
.76774 .53146 .777 .54319 .79868 .54456 .78951 .53277 Metetra
.797 .701 0 r
.78951 .53277 .79868 .54456 .82062 .546 .81154 .53415 Metetra
.826 .623 0 r
.81154 .53415 .82062 .546 .84282 .54751 .83384 .5356 Metetra
.855 .536 0 r
.83384 .5356 .84282 .54751 .8653 .54909 .85642 .53712 Metetra
.885 .442 0 r
.85642 .53712 .8653 .54909 .88806 .55075 .87928 .53871 Metetra
.914 .339 0 r
.87928 .53871 .88806 .55075 .91111 .55248 .90243 .54038 Metetra
.944 .229 0 r
.90243 .54038 .91111 .55248 .93445 .55429 .92588 .54212 Metetra
0 .036 .137 r
.3011 .5076 .31204 .51808 .32885 .51803 .31796 .5075 Metetra
0 .059 .161 r
.31796 .5075 .32885 .51803 .34583 .51803 .33498 .50745 Metetra
0 .087 .185 r
.33498 .50745 .34583 .51803 .36297 .51808 .35218 .50745 Metetra
0 .12 .209 r
.35218 .50745 .36297 .51808 .38029 .51818 .36954 .50749 Metetra
0 .159 .234 r
.36954 .50749 .38029 .51818 .39777 .51832 .38708 .50758 Metetra
0 .204 .259 r
.38708 .50758 .39777 .51832 .41543 .51852 .40479 .50772 Metetra
0 .254 .283 r
.40479 .50772 .41543 .51852 .43327 .51876 .42268 .50791 Metetra
0 .309 .307 r
.42268 .50791 .43327 .51876 .45129 .51906 .44076 .50815 Metetra
0 .334 .296 r
.44076 .50815 .45129 .51906 .4695 .5194 .45903 .50845 Metetra
0 .359 .279 r
.45903 .50845 .4695 .5194 .4879 .5198 .47748 .50879 Metetra
0 .385 .256 r
.47748 .50879 .4879 .5198 .50649 .52026 .49614 .50919 Metetra
0 .411 .227 r
.49614 .50919 .50649 .52026 .52528 .52077 .51499 .50964 Metetra
0 .437 .192 r
.51499 .50964 .52528 .52077 .54427 .52133 .53404 .51015 Metetra
0 .464 .15 r
.53404 .51015 .54427 .52133 .56347 .52195 .55331 .51071 Metetra
0 .49 .102 r
.55331 .51071 .56347 .52195 .58287 .52263 .57278 .51133 Metetra
0 .517 .048 r
.57278 .51133 .58287 .52263 .6025 .52336 .59247 .51201 Metetra
.013 .544 0 r
.59247 .51201 .6025 .52336 .62234 .52416 .61238 .51274 Metetra
.081 .571 0 r
.61238 .51274 .62234 .52416 .6424 .52501 .63252 .51354 Metetra
.156 .598 0 r
.63252 .51354 .6424 .52501 .66269 .52593 .65289 .5144 Metetra
.238 .626 0 r
.65289 .5144 .66269 .52593 .68322 .52691 .67349 .51531 Metetra
.327 .654 0 r
.67349 .51531 .68322 .52691 .70398 .52795 .69434 .5163 Metetra
.424 .682 0 r
.69434 .5163 .70398 .52795 .72498 .52905 .71543 .51734 Metetra
.528 .71 0 r
.71543 .51734 .72498 .52905 .74624 .53023 .73677 .51845 Metetra
.64 .738 0 r
.73677 .51845 .74624 .53023 .76774 .53146 .75836 .51963 Metetra
.759 .767 0 r
.75836 .51963 .76774 .53146 .78951 .53277 .78022 .52088 Metetra
.796 .704 0 r
.78022 .52088 .78951 .53277 .81154 .53415 .80234 .52219 Metetra
.825 .626 0 r
.80234 .52219 .81154 .53415 .83384 .5356 .82474 .52358 Metetra
.854 .54 0 r
.82474 .52358 .83384 .5356 .85642 .53712 .84742 .52503 Metetra
.883 .446 0 r
.84742 .52503 .85642 .53712 .87928 .53871 .87038 .52656 Metetra
.913 .344 0 r
.87038 .52656 .87928 .53871 .90243 .54038 .89364 .52817 Metetra
.943 .234 0 r
.89364 .52817 .90243 .54038 .92588 .54212 .9172 .52985 Metetra
0 .035 .136 r
.29002 .49704 .3011 .5076 .31796 .5075 .30693 .49689 Metetra
0 .057 .16 r
.30693 .49689 .31796 .5075 .33498 .50745 .324 .49679 Metetra
0 .085 .184 r
.324 .49679 .33498 .50745 .35218 .50745 .34125 .49673 Metetra
0 .118 .208 r
.34125 .49673 .35218 .50745 .36954 .50749 .35866 .49672 Metetra
0 .157 .233 r
.35866 .49672 .36954 .50749 .38708 .50758 .37625 .49676 Metetra
0 .201 .257 r
.37625 .49676 .38708 .50758 .40479 .50772 .39401 .49684 Metetra
0 .251 .282 r
.39401 .49684 .40479 .50772 .42268 .50791 .41196 .49698 Metetra
0 .307 .307 r
.41196 .49698 .42268 .50791 .44076 .50815 .4301 .49716 Metetra
0 .333 .297 r
.4301 .49716 .44076 .50815 .45903 .50845 .44842 .4974 Metetra
0 .358 .28 r
.44842 .4974 .45903 .50845 .47748 .50879 .46694 .49769 Metetra
0 .384 .257 r
.46694 .49769 .47748 .50879 .49614 .50919 .48565 .49803 Metetra
0 .41 .228 r
.48565 .49803 .49614 .50919 .51499 .50964 .50456 .49842 Metetra
0 .436 .193 r
.50456 .49842 .51499 .50964 .53404 .51015 .52368 .49887 Metetra
0 .463 .152 r
.52368 .49887 .53404 .51015 .55331 .51071 .54301 .49938 Metetra
0 .489 .105 r
.54301 .49938 .55331 .51071 .57278 .51133 .56256 .49994 Metetra
0 .516 .051 r
.56256 .49994 .57278 .51133 .59247 .51201 .58232 .50056 Metetra
.01 .543 0 r
.58232 .50056 .59247 .51201 .61238 .51274 .60231 .50123 Metetra
.078 .57 0 r
.60231 .50123 .61238 .51274 .63252 .51354 .62252 .50197 Metetra
.152 .597 0 r
.62252 .50197 .63252 .51354 .65289 .5144 .64296 .50277 Metetra
.234 .625 0 r
.64296 .50277 .65289 .5144 .67349 .51531 .66365 .50362 Metetra
.323 .653 0 r
.66365 .50362 .67349 .51531 .69434 .5163 .68457 .50454 Metetra
.42 .681 0 r
.68457 .50454 .69434 .5163 .71543 .51734 .70574 .50553 Metetra
.523 .709 0 r
.70574 .50553 .71543 .51734 .73677 .51845 .72717 .50658 Metetra
.635 .737 0 r
.72717 .50658 .73677 .51845 .75836 .51963 .74886 .50769 Metetra
.755 .766 0 r
.74886 .50769 .75836 .51963 .78022 .52088 .7708 .50887 Metetra
.795 .707 0 r
.7708 .50887 .78022 .52088 .80234 .52219 .79302 .51012 Metetra
.824 .629 0 r
.79302 .51012 .80234 .52219 .82474 .52358 .81552 .51144 Metetra
.853 .544 0 r
.81552 .51144 .82474 .52358 .84742 .52503 .8383 .51283 Metetra
.882 .45 0 r
.8383 .51283 .84742 .52503 .87038 .52656 .86137 .5143 Metetra
.912 .348 0 r
.86137 .5143 .87038 .52656 .89364 .52817 .88473 .51584 Metetra
.942 .238 0 r
.88473 .51584 .89364 .52817 .9172 .52985 .9084 .51745 Metetra
0 .034 .135 r
.27881 .48641 .29002 .49704 .30693 .49689 .29577 .4862 Metetra
0 .056 .159 r
.29577 .4862 .30693 .49689 .324 .49679 .31289 .48604 Metetra
0 .084 .183 r
.31289 .48604 .324 .49679 .34125 .49673 .33018 .48593 Metetra
0 .117 .207 r
.33018 .48593 .34125 .49673 .35866 .49672 .34764 .48587 Metetra
0 .156 .232 r
.34764 .48587 .35866 .49672 .37625 .49676 .36528 .48585 Metetra
0 .2 .257 r
.36528 .48585 .37625 .49676 .39401 .49684 .3831 .48588 Metetra
0 .249 .281 r
.3831 .48588 .39401 .49684 .41196 .49698 .40111 .48596 Metetra
0 .305 .307 r
.40111 .48596 .41196 .49698 .4301 .49716 .4193 .48608 Metetra
0 .332 .297 r
.4193 .48608 .4301 .49716 .44842 .4974 .43768 .48626 Metetra
0 .357 .28 r
.43768 .48626 .44842 .4974 .46694 .49769 .45625 .48649 Metetra
0 .383 .258 r
.45625 .48649 .46694 .49769 .48565 .49803 .47503 .48678 Metetra
0 .409 .229 r
.47503 .48678 .48565 .49803 .50456 .49842 .49401 .48711 Metetra
0 .435 .195 r
.49401 .48711 .50456 .49842 .52368 .49887 .51319 .4875 Metetra
0 .462 .154 r
.51319 .4875 .52368 .49887 .54301 .49938 .53259 .48795 Metetra
0 .488 .106 r
.53259 .48795 .54301 .49938 .56256 .49994 .5522 .48845 Metetra
0 .515 .052 r
.5522 .48845 .56256 .49994 .58232 .50056 .57204 .48901 Metetra
.008 .542 0 r
.57204 .48901 .58232 .50056 .60231 .50123 .59209 .48962 Metetra
.075 .569 0 r
.59209 .48962 .60231 .50123 .62252 .50197 .61238 .4903 Metetra
.15 .596 0 r
.61238 .4903 .62252 .50197 .64296 .50277 .63291 .49103 Metetra
.231 .624 0 r
.63291 .49103 .64296 .50277 .66365 .50362 .65367 .49183 Metetra
.32 .652 0 r
.65367 .49183 .66365 .50362 .68457 .50454 .67468 .49268 Metetra
.416 .68 0 r
.67468 .49268 .68457 .50454 .70574 .50553 .69593 .4936 Metetra
.52 .708 0 r
.69593 .4936 .70574 .50553 .72717 .50658 .71745 .49459 Metetra
.631 .736 0 r
.71745 .49459 .72717 .50658 .74886 .50769 .73922 .49564 Metetra
.751 .765 0 r
.73922 .49564 .74886 .50769 .7708 .50887 .76127 .49676 Metetra
.794 .709 0 r
.76127 .49676 .7708 .50887 .79302 .51012 .78358 .49794 Metetra
.823 .632 0 r
.78358 .49794 .79302 .51012 .81552 .51144 .80618 .4992 Metetra
.852 .547 0 r
.80618 .4992 .81552 .51144 .8383 .51283 .82906 .50052 Metetra
.881 .453 0 r
.82906 .50052 .8383 .51283 .86137 .5143 .85223 .50192 Metetra
.911 .351 0 r
.85223 .50192 .86137 .5143 .88473 .51584 .8757 .50339 Metetra
.941 .241 0 r
.8757 .50339 .88473 .51584 .9084 .51745 .89948 .50493 Metetra
0 .033 .134 r
.26746 .47569 .27881 .48641 .29577 .4862 .28446 .47543 Metetra
0 .056 .158 r
.28446 .47543 .29577 .4862 .31289 .48604 .30163 .47522 Metetra
0 .083 .182 r
.30163 .47522 .31289 .48604 .33018 .48593 .31897 .47505 Metetra
0 .116 .207 r
.31897 .47505 .33018 .48593 .34764 .48587 .33649 .47493 Metetra
0 .154 .231 r
.33649 .47493 .34764 .48587 .36528 .48585 .35418 .47485 Metetra
0 .198 .256 r
.35418 .47485 .36528 .48585 .3831 .48588 .37205 .47482 Metetra
0 .248 .281 r
.37205 .47482 .3831 .48588 .40111 .48596 .39011 .47484 Metetra
0 .303 .306 r
.39011 .47484 .40111 .48596 .4193 .48608 .40836 .47492 Metetra
0 .331 .297 r
.40836 .47492 .4193 .48608 .43768 .48626 .4268 .47504 Metetra
0 .357 .281 r
.4268 .47504 .43768 .48626 .45625 .48649 .44544 .47521 Metetra
0 .382 .259 r
.44544 .47521 .45625 .48649 .47503 .48678 .46427 .47543 Metetra
0 .408 .23 r
.46427 .47543 .47503 .48678 .49401 .48711 .48331 .47571 Metetra
0 .435 .196 r
.48331 .47571 .49401 .48711 .51319 .4875 .50257 .47604 Metetra
0 .461 .155 r
.50257 .47604 .51319 .4875 .53259 .48795 .52203 .47642 Metetra
0 .487 .108 r
.52203 .47642 .53259 .48795 .5522 .48845 .54171 .47686 Metetra
0 .514 .054 r
.54171 .47686 .5522 .48845 .57204 .48901 .56162 .47736 Metetra
.006 .541 0 r
.56162 .47736 .57204 .48901 .59209 .48962 .58175 .47791 Metetra
.074 .568 0 r
.58175 .47791 .59209 .48962 .61238 .4903 .60211 .47852 Metetra
.148 .596 0 r
.60211 .47852 .61238 .4903 .63291 .49103 .62271 .47919 Metetra
.229 .623 0 r
.62271 .47919 .63291 .49103 .65367 .49183 .64356 .47992 Metetra
.318 .651 0 r
.64356 .47992 .65367 .49183 .67468 .49268 .66465 .48072 Metetra
.414 .679 0 r
.66465 .48072 .67468 .49268 .69593 .4936 .68599 .48157 Metetra
.517 .707 0 r
.68599 .48157 .69593 .4936 .71745 .49459 .70759 .48249 Metetra
.629 .736 0 r
.70759 .48249 .71745 .49459 .73922 .49564 .72946 .48348 Metetra
.748 .764 0 r
.72946 .48348 .73922 .49564 .76127 .49676 .7516 .48453 Metetra
.793 .711 0 r
.7516 .48453 .76127 .49676 .78358 .49794 .77401 .48564 Metetra
.822 .634 0 r
.77401 .48564 .78358 .49794 .80618 .4992 .7967 .48683 Metetra
.851 .549 0 r
.7967 .48683 .80618 .4992 .82906 .50052 .81969 .48809 Metetra
.881 .455 0 r
.81969 .48809 .82906 .50052 .85223 .50192 .84297 .48942 Metetra
.91 .354 0 r
.84297 .48942 .85223 .50192 .8757 .50339 .86655 .49082 Metetra
.94 .244 0 r
.86655 .49082 .8757 .50339 .89948 .50493 .89044 .49229 Metetra
0 .033 .134 r
.25597 .46489 .26746 .47569 .28446 .47543 .27302 .46457 Metetra
0 .055 .158 r
.27302 .46457 .28446 .47543 .30163 .47522 .29024 .4643 Metetra
0 .083 .182 r
.29024 .4643 .30163 .47522 .31897 .47505 .30762 .46408 Metetra
0 .115 .206 r
.30762 .46408 .31897 .47505 .33649 .47493 .32519 .4639 Metetra
0 .154 .231 r
.32519 .4639 .33649 .47493 .35418 .47485 .34293 .46376 Metetra
0 .197 .255 r
.34293 .46376 .35418 .47485 .37205 .47482 .36086 .46368 Metetra
0 .247 .28 r
.36086 .46368 .37205 .47482 .39011 .47484 .37898 .46364 Metetra
0 .302 .305 r
.37898 .46364 .39011 .47484 .40836 .47492 .39728 .46365 Metetra
0 .331 .298 r
.39728 .46365 .40836 .47492 .4268 .47504 .41578 .46372 Metetra
0 .356 .281 r
.41578 .46372 .4268 .47504 .44544 .47521 .43448 .46383 Metetra
0 .382 .259 r
.43448 .46383 .44544 .47521 .46427 .47543 .45338 .46399 Metetra
0 .408 .231 r
.45338 .46399 .46427 .47543 .48331 .47571 .47248 .4642 Metetra
0 .434 .196 r
.47248 .4642 .48331 .47571 .50257 .47604 .4918 .46447 Metetra
0 .46 .156 r
.4918 .46447 .50257 .47604 .52203 .47642 .51133 .4648 Metetra
0 .487 .109 r
.51133 .4648 .52203 .47642 .54171 .47686 .53108 .46517 Metetra
0 .514 .055 r
.53108 .46517 .54171 .47686 .56162 .47736 .55106 .4656 Metetra
.005 .541 0 r
.55106 .4656 .56162 .47736 .58175 .47791 .57127 .46609 Metetra
.072 .568 0 r
.57127 .46609 .58175 .47791 .60211 .47852 .59171 .46664 Metetra
.146 .595 0 r
.59171 .46664 .60211 .47852 .62271 .47919 .61239 .46725 Metetra
.228 .623 0 r
.61239 .46725 .62271 .47919 .64356 .47992 .63331 .46791 Metetra
.316 .651 0 r
.63331 .46791 .64356 .47992 .66465 .48072 .65449 .46864 Metetra
.412 .679 0 r
.65449 .46864 .66465 .48072 .68599 .48157 .67592 .46943 Metetra
.515 .707 0 r
.67592 .46943 .68599 .48157 .70759 .48249 .69761 .47028 Metetra
.626 .735 0 r
.69761 .47028 .70759 .48249 .72946 .48348 .71957 .4712 Metetra
.745 .764 0 r
.71957 .4712 .72946 .48348 .7516 .48453 .7418 .47218 Metetra
.793 .713 0 r
.7418 .47218 .7516 .48453 .77401 .48564 .76431 .47323 Metetra
.822 .635 0 r
.76431 .47323 .77401 .48564 .7967 .48683 .7871 .47435 Metetra
.851 .55 0 r
.7871 .47435 .7967 .48683 .81969 .48809 .81019 .47553 Metetra
.88 .457 0 r
.81019 .47553 .81969 .48809 .84297 .48942 .83358 .47679 Metetra
.91 .356 0 r
.83358 .47679 .84297 .48942 .86655 .49082 .85727 .47812 Metetra
.94 .246 0 r
.85727 .47812 .86655 .49082 .89044 .49229 .88128 .47953 Metetra
0 .033 .133 r
.24433 .454 .25597 .46489 .27302 .46457 .26143 .45363 Metetra
0 .055 .157 r
.26143 .45363 .27302 .46457 .29024 .4643 .27869 .4533 Metetra
0 .082 .181 r
.27869 .4533 .29024 .4643 .30762 .46408 .29613 .45302 Metetra
0 .115 .206 r
.29613 .45302 .30762 .46408 .32519 .4639 .31375 .45278 Metetra
0 .153 .23 r
.31375 .45278 .32519 .4639 .34293 .46376 .33154 .45259 Metetra
0 .197 .255 r
.33154 .45259 .34293 .46376 .36086 .46368 .34953 .45244 Metetra
0 .246 .28 r
.34953 .45244 .36086 .46368 .37898 .46364 .36769 .45235 Metetra
0 .302 .305 r
.36769 .45235 .37898 .46364 .39728 .46365 .38606 .4523 Metetra
0 .33 .298 r
.38606 .4523 .39728 .46365 .41578 .46372 .40461 .4523 Metetra
0 .356 .282 r
.40461 .4523 .41578 .46372 .43448 .46383 .42337 .45235 Metetra
0 .382 .259 r
.42337 .45235 .43448 .46383 .45338 .46399 .44233 .45245 Metetra
0 .408 .231 r
.44233 .45245 .45338 .46399 .47248 .4642 .46151 .4526 Metetra
0 .434 .197 r
.46151 .4526 .47248 .4642 .4918 .46447 .48089 .45281 Metetra
0 .46 .156 r
.48089 .45281 .4918 .46447 .51133 .4648 .50049 .45306 Metetra
0 .487 .109 r
.50049 .45306 .51133 .4648 .53108 .46517 .52031 .45338 Metetra
0 .513 .056 r
.52031 .45338 .53108 .46517 .55106 .4656 .54036 .45375 Metetra
.004 .54 0 r
.54036 .45375 .55106 .4656 .57127 .46609 .56064 .45417 Metetra
.072 .568 0 r
.56064 .45417 .57127 .46609 .59171 .46664 .58116 .45465 Metetra
.146 .595 0 r
.58116 .45465 .59171 .46664 .61239 .46725 .60192 .45519 Metetra
.227 .622 0 r
.60192 .45519 .61239 .46725 .63331 .46791 .62293 .45579 Metetra
.315 .65 0 r
.62293 .45579 .63331 .46791 .65449 .46864 .64419 .45645 Metetra
.411 .678 0 r
.64419 .45645 .65449 .46864 .67592 .46943 .6657 .45717 Metetra
.514 .706 0 r
.6657 .45717 .67592 .46943 .69761 .47028 .68748 .45795 Metetra
.625 .735 0 r
.68748 .45795 .69761 .47028 .71957 .4712 .70954 .4588 Metetra
.744 .763 0 r
.70954 .4588 .71957 .4712 .7418 .47218 .73186 .45971 Metetra
.792 .713 0 r
.73186 .45971 .7418 .47218 .76431 .47323 .75447 .46069 Metetra
.821 .636 0 r
.75447 .46069 .76431 .47323 .7871 .47435 .77737 .46174 Metetra
.85 .551 0 r
.77737 .46174 .7871 .47435 .81019 .47553 .80056 .46285 Metetra
.88 .458 0 r
.80056 .46285 .81019 .47553 .83358 .47679 .82406 .46404 Metetra
.909 .357 0 r
.82406 .46404 .83358 .47679 .85727 .47812 .84786 .4653 Metetra
.939 .247 0 r
.84786 .4653 .85727 .47812 .88128 .47953 .87198 .46663 Metetra
0 .033 .133 r
.23255 .44303 .24433 .454 .26143 .45363 .24969 .4426 Metetra
0 .055 .157 r
.24969 .4426 .26143 .45363 .27869 .4533 .267 .44221 Metetra
0 .082 .181 r
.267 .44221 .27869 .4533 .29613 .45302 .28449 .44187 Metetra
0 .115 .206 r
.28449 .44187 .29613 .45302 .31375 .45278 .30216 .44157 Metetra
0 .153 .23 r
.30216 .44157 .31375 .45278 .33154 .45259 .32001 .44132 Metetra
0 .197 .255 r
.32001 .44132 .33154 .45259 .34953 .45244 .33804 .44111 Metetra
0 .246 .28 r
.33804 .44111 .34953 .45244 .36769 .45235 .35627 .44095 Metetra
0 .301 .305 r
.35627 .44095 .36769 .45235 .38606 .4523 .37469 .44084 Metetra
0 .33 .298 r
.37469 .44084 .38606 .4523 .40461 .4523 .3933 .44078 Metetra
0 .356 .282 r
.3933 .44078 .40461 .4523 .42337 .45235 .41212 .44077 Metetra
0 .382 .259 r
.41212 .44077 .42337 .45235 .44233 .45245 .43115 .44081 Metetra
0 .407 .231 r
.43115 .44081 .44233 .45245 .46151 .4526 .45038 .44089 Metetra
0 .434 .197 r
.45038 .44089 .46151 .4526 .48089 .45281 .46983 .44103 Metetra
0 .46 .156 r
.46983 .44103 .48089 .45281 .50049 .45306 .4895 .44123 Metetra
0 .487 .109 r
.4895 .44123 .50049 .45306 .52031 .45338 .5094 .44148 Metetra
0 .513 .056 r
.5094 .44148 .52031 .45338 .54036 .45375 .52952 .44178 Metetra
.004 .54 0 r
.52952 .44178 .54036 .45375 .56064 .45417 .54988 .44213 Metetra
.071 .567 0 r
.54988 .44213 .56064 .45417 .58116 .45465 .57047 .44255 Metetra
.145 .595 0 r
.57047 .44255 .58116 .45465 .60192 .45519 .59131 .44302 Metetra
.226 .622 0 r
.59131 .44302 .60192 .45519 .62293 .45579 .6124 .44355 Metetra
.315 .65 0 r
.6124 .44355 .62293 .45579 .64419 .45645 .63374 .44414 Metetra
.41 .678 0 r
.63374 .44414 .64419 .45645 .6657 .45717 .65535 .44479 Metetra
.514 .706 0 r
.65535 .44479 .6657 .45717 .68748 .45795 .67722 .44551 Metetra
.625 .735 0 r
.67722 .44551 .68748 .45795 .70954 .4588 .69936 .44628 Metetra
.744 .763 0 r
.69936 .44628 .70954 .4588 .73186 .45971 .72179 .44712 Metetra
.792 .714 0 r
.72179 .44712 .73186 .45971 .75447 .46069 .7445 .44803 Metetra
.821 .637 0 r
.7445 .44803 .75447 .46069 .77737 .46174 .7675 .449 Metetra
.85 .552 0 r
.7675 .449 .77737 .46174 .80056 .46285 .7908 .45005 Metetra
.88 .459 0 r
.7908 .45005 .80056 .46285 .82406 .46404 .8144 .45116 Metetra
.909 .357 0 r
.8144 .45116 .82406 .46404 .84786 .4653 .83832 .45234 Metetra
.939 .248 0 r
.83832 .45234 .84786 .4653 .87198 .46663 .86255 .4536 Metetra
0 .033 .133 r
.22061 .43196 .23255 .44303 .24969 .4426 .2378 .43147 Metetra
0 .055 .157 r
.2378 .43147 .24969 .4426 .267 .44221 .25516 .43103 Metetra
0 .082 .181 r
.25516 .43103 .267 .44221 .28449 .44187 .2727 .43062 Metetra
0 .115 .206 r
.2727 .43062 .28449 .44187 .30216 .44157 .29041 .43026 Metetra
0 .153 .23 r
.29041 .43026 .30216 .44157 .32001 .44132 .30832 .42995 Metetra
0 .197 .255 r
.30832 .42995 .32001 .44132 .33804 .44111 .32641 .42968 Metetra
0 .246 .28 r
.32641 .42968 .33804 .44111 .35627 .44095 .34469 .42946 Metetra
0 .302 .305 r
.34469 .42946 .35627 .44095 .37469 .44084 .36316 .42929 Metetra
0 .33 .298 r
.36316 .42929 .37469 .44084 .3933 .44078 .38184 .42916 Metetra
0 .356 .282 r
.38184 .42916 .3933 .44078 .41212 .44077 .40072 .42909 Metetra
0 .382 .259 r
.40072 .42909 .41212 .44077 .43115 .44081 .41981 .42906 Metetra
0 .408 .231 r
.41981 .42906 .43115 .44081 .45038 .44089 .43911 .42908 Metetra
0 .434 .197 r
.43911 .42908 .45038 .44089 .46983 .44103 .45863 .42916 Metetra
0 .46 .156 r
.45863 .42916 .46983 .44103 .4895 .44123 .47837 .42928 Metetra
0 .487 .109 r
.47837 .42928 .4895 .44123 .5094 .44148 .49833 .42946 Metetra
0 .513 .056 r
.49833 .42946 .5094 .44148 .52952 .44178 .51853 .4297 Metetra
.004 .54 0 r
.51853 .4297 .52952 .44178 .54988 .44213 .53896 .42999 Metetra
.072 .568 0 r
.53896 .42999 .54988 .44213 .57047 .44255 .55963 .43033 Metetra
.146 .595 0 r
.55963 .43033 .57047 .44255 .59131 .44302 .58055 .43073 Metetra
.227 .622 0 r
.58055 .43073 .59131 .44302 .6124 .44355 .60173 .4312 Metetra
.315 .65 0 r
.60173 .4312 .6124 .44355 .63374 .44414 .62316 .43171 Metetra
.411 .678 0 r
.62316 .43171 .63374 .44414 .65535 .44479 .64485 .43229 Metetra
.514 .706 0 r
.64485 .43229 .65535 .44479 .67722 .44551 .66681 .43294 Metetra
.625 .735 0 r
.66681 .43294 .67722 .44551 .69936 .44628 .68905 .43364 Metetra
.744 .763 0 r
.68905 .43364 .69936 .44628 .72179 .44712 .71157 .43441 Metetra
.792 .713 0 r
.71157 .43441 .72179 .44712 .7445 .44803 .73438 .43524 Metetra
.821 .636 0 r
.73438 .43524 .7445 .44803 .7675 .449 .75748 .43614 Metetra
.85 .551 0 r
.75748 .43614 .7675 .449 .7908 .45005 .78089 .4371 Metetra
.88 .458 0 r
.78089 .4371 .7908 .45005 .8144 .45116 .80461 .43814 Metetra
.909 .357 0 r
.80461 .43814 .8144 .45116 .83832 .45234 .82864 .43925 Metetra
.939 .247 0 r
.82864 .43925 .83832 .45234 .86255 .4536 .85299 .44042 Metetra
0 .033 .134 r
.20851 .42081 .22061 .43196 .2378 .43147 .22575 .42026 Metetra
0 .055 .158 r
.22575 .42026 .2378 .43147 .25516 .43103 .24316 .41975 Metetra
0 .083 .182 r
.24316 .41975 .25516 .43103 .2727 .43062 .26075 .41928 Metetra
0 .115 .206 r
.26075 .41928 .2727 .43062 .29041 .43026 .27852 .41886 Metetra
0 .154 .231 r
.27852 .41886 .29041 .43026 .30832 .42995 .29647 .41849 Metetra
0 .197 .255 r
.29647 .41849 .30832 .42995 .32641 .42968 .31462 .41815 Metetra
0 .247 .28 r
.31462 .41815 .32641 .42968 .34469 .42946 .33295 .41787 Metetra
0 .302 .305 r
.33295 .41787 .34469 .42946 .36316 .42929 .35149 .41763 Metetra
0 .331 .298 r
.35149 .41763 .36316 .42929 .38184 .42916 .37022 .41744 Metetra
0 .356 .281 r
.37022 .41744 .38184 .42916 .40072 .42909 .38917 .4173 Metetra
0 .382 .259 r
.38917 .4173 .40072 .42909 .41981 .42906 .40832 .4172 Metetra
0 .408 .231 r
.40832 .4172 .41981 .42906 .43911 .42908 .42768 .41716 Metetra
0 .434 .196 r
.42768 .41716 .43911 .42908 .45863 .42916 .44727 .41717 Metetra
0 .46 .156 r
.44727 .41717 .45863 .42916 .47837 .42928 .46708 .41723 Metetra
0 .487 .109 r
.46708 .41723 .47837 .42928 .49833 .42946 .48711 .41734 Metetra
0 .514 .055 r
.48711 .41734 .49833 .42946 .51853 .4297 .50738 .4175 Metetra
.005 .541 0 r
.50738 .4175 .51853 .4297 .53896 .42999 .52789 .41772 Metetra
.072 .568 0 r
.52789 .41772 .53896 .42999 .55963 .43033 .54865 .418 Metetra
.146 .595 0 r
.54865 .418 .55963 .43033 .58055 .43073 .56965 .41833 Metetra
.228 .623 0 r
.56965 .41833 .58055 .43073 .60173 .4312 .5909 .41872 Metetra
.316 .651 0 r
.5909 .41872 .60173 .4312 .62316 .43171 .61242 .41916 Metetra
.412 .679 0 r
.61242 .41916 .62316 .43171 .64485 .43229 .6342 .41967 Metetra
.515 .707 0 r
.6342 .41967 .64485 .43229 .66681 .43294 .65626 .42024 Metetra
.626 .735 0 r
.65626 .42024 .66681 .43294 .68905 .43364 .67859 .42087 Metetra
.745 .764 0 r
.67859 .42087 .68905 .43364 .71157 .43441 .70121 .42156 Metetra
.793 .713 0 r
.70121 .42156 .71157 .43441 .73438 .43524 .72412 .42232 Metetra
.822 .635 0 r
.72412 .42232 .73438 .43524 .75748 .43614 .74733 .42314 Metetra
.851 .55 0 r
.74733 .42314 .75748 .43614 .78089 .4371 .77084 .42403 Metetra
.88 .457 0 r
.77084 .42403 .78089 .4371 .80461 .43814 .79467 .42499 Metetra
.91 .356 0 r
.79467 .42499 .80461 .43814 .82864 .43925 .81882 .42601 Metetra
.94 .246 0 r
.81882 .42601 .82864 .43925 .85299 .44042 .84329 .42711 Metetra
0 .033 .134 r
.19626 .40956 .20851 .42081 .22575 .42026 .21354 .40894 Metetra
0 .056 .158 r
.21354 .40894 .22575 .42026 .24316 .41975 .231 .40837 Metetra
0 .083 .182 r
.231 .40837 .24316 .41975 .26075 .41928 .24864 .40784 Metetra
0 .116 .207 r
.24864 .40784 .26075 .41928 .27852 .41886 .26646 .40736 Metetra
0 .154 .231 r
.26646 .40736 .27852 .41886 .29647 .41849 .28447 .40692 Metetra
0 .198 .256 r
.28447 .40692 .29647 .41849 .31462 .41815 .30267 .40652 Metetra
0 .248 .281 r
.30267 .40652 .31462 .41815 .33295 .41787 .32106 .40617 Metetra
0 .303 .306 r
.32106 .40617 .33295 .41787 .35149 .41763 .33965 .40587 Metetra
0 .331 .297 r
.33965 .40587 .35149 .41763 .37022 .41744 .35845 .40561 Metetra
0 .357 .281 r
.35845 .40561 .37022 .41744 .38917 .4173 .37745 .4054 Metetra
0 .382 .259 r
.37745 .4054 .38917 .4173 .40832 .4172 .39667 .40524 Metetra
0 .408 .23 r
.39667 .40524 .40832 .4172 .42768 .41716 .4161 .40513 Metetra
0 .435 .196 r
.4161 .40513 .42768 .41716 .44727 .41717 .43575 .40507 Metetra
0 .461 .155 r
.43575 .40507 .44727 .41717 .46708 .41723 .45563 .40506 Metetra
0 .487 .108 r
.45563 .40506 .46708 .41723 .48711 .41734 .47574 .4051 Metetra
0 .514 .054 r
.47574 .4051 .48711 .41734 .50738 .4175 .49609 .40519 Metetra
.006 .541 0 r
.49609 .40519 .50738 .4175 .52789 .41772 .51667 .40534 Metetra
.074 .568 0 r
.51667 .40534 .52789 .41772 .54865 .418 .5375 .40554 Metetra
.148 .596 0 r
.5375 .40554 .54865 .418 .56965 .41833 .55859 .4058 Metetra
.229 .623 0 r
.55859 .4058 .56965 .41833 .5909 .41872 .57993 .40612 Metetra
.318 .651 0 r
.57993 .40612 .5909 .41872 .61242 .41916 .60153 .40649 Metetra
.414 .679 0 r
.60153 .40649 .61242 .41916 .6342 .41967 .6234 .40692 Metetra
.517 .707 0 r
.6234 .40692 .6342 .41967 .65626 .42024 .64555 .40741 Metetra
.629 .736 0 r
.64555 .40741 .65626 .42024 .67859 .42087 .66798 .40796 Metetra
.748 .764 0 r
.66798 .40796 .67859 .42087 .70121 .42156 .6907 .40858 Metetra
.793 .711 0 r
.6907 .40858 .70121 .42156 .72412 .42232 .71371 .40926 Metetra
.822 .634 0 r
.71371 .40926 .72412 .42232 .74733 .42314 .73702 .41 Metetra
.851 .549 0 r
.73702 .41 .74733 .42314 .77084 .42403 .76065 .41081 Metetra
.881 .455 0 r
.76065 .41081 .77084 .42403 .79467 .42499 .78459 .41169 Metetra
.91 .354 0 r
.78459 .41169 .79467 .42499 .81882 .42601 .80885 .41264 Metetra
.94 .244 0 r
.80885 .41264 .81882 .42601 .84329 .42711 .83345 .41365 Metetra
0 .034 .135 r
.18385 .39821 .19626 .40956 .21354 .40894 .20117 .39753 Metetra
0 .056 .159 r
.20117 .39753 .21354 .40894 .231 .40837 .21868 .3969 Metetra
0 .084 .183 r
.21868 .3969 .231 .40837 .24864 .40784 .23637 .39631 Metetra
0 .117 .207 r
.23637 .39631 .24864 .40784 .26646 .40736 .25424 .39576 Metetra
0 .156 .232 r
.25424 .39576 .26646 .40736 .28447 .40692 .2723 .39525 Metetra
0 .2 .257 r
.2723 .39525 .28447 .40692 .30267 .40652 .29056 .39479 Metetra
0 .249 .281 r
.29056 .39479 .30267 .40652 .32106 .40617 .30901 .39437 Metetra
0 .305 .307 r
.30901 .39437 .32106 .40617 .33965 .40587 .32766 .394 Metetra
0 .332 .297 r
.32766 .394 .33965 .40587 .35845 .40561 .34651 .39368 Metetra
0 .357 .28 r
.34651 .39368 .35845 .40561 .37745 .4054 .36558 .3934 Metetra
0 .383 .258 r
.36558 .3934 .37745 .4054 .39667 .40524 .38486 .39317 Metetra
0 .409 .229 r
.38486 .39317 .39667 .40524 .4161 .40513 .40436 .39298 Metetra
0 .435 .195 r
.40436 .39298 .4161 .40513 .43575 .40507 .42408 .39285 Metetra
0 .462 .154 r
.42408 .39285 .43575 .40507 .45563 .40506 .44403 .39277 Metetra
0 .488 .106 r
.44403 .39277 .45563 .40506 .47574 .4051 .46421 .39274 Metetra
0 .515 .052 r
.46421 .39274 .47574 .4051 .49609 .40519 .48463 .39276 Metetra
.008 .542 0 r
.48463 .39276 .49609 .40519 .51667 .40534 .50529 .39284 Metetra
.075 .569 0 r
.50529 .39284 .51667 .40534 .5375 .40554 .5262 .39296 Metetra
.15 .596 0 r
.5262 .39296 .5375 .40554 .55859 .4058 .54737 .39315 Metetra
.231 .624 0 r
.54737 .39315 .55859 .4058 .57993 .40612 .56879 .39339 Metetra
.32 .652 0 r
.56879 .39339 .57993 .40612 .60153 .40649 .59048 .39368 Metetra
.416 .68 0 r
.59048 .39368 .60153 .40649 .6234 .40692 .61245 .39404 Metetra
.52 .708 0 r
.61245 .39404 .6234 .40692 .64555 .40741 .63469 .39445 Metetra
.631 .736 0 r
.63469 .39445 .64555 .40741 .66798 .40796 .65722 .39493 Metetra
.751 .765 0 r
.65722 .39493 .66798 .40796 .6907 .40858 .68003 .39546 Metetra
.794 .709 0 r
.68003 .39546 .6907 .40858 .71371 .40926 .70315 .39606 Metetra
.823 .632 0 r
.70315 .39606 .71371 .40926 .73702 .41 .72657 .39672 Metetra
.852 .547 0 r
.72657 .39672 .73702 .41 .76065 .41081 .7503 .39745 Metetra
.881 .453 0 r
.7503 .39745 .76065 .41081 .78459 .41169 .77436 .39825 Metetra
.911 .351 0 r
.77436 .39825 .78459 .41169 .80885 .41264 .79874 .39911 Metetra
.941 .241 0 r
.79874 .39911 .80885 .41264 .83345 .41365 .82345 .40004 Metetra
0 .035 .136 r
.17126 .38676 .18385 .39821 .20117 .39753 .18864 .38602 Metetra
0 .057 .16 r
.18864 .38602 .20117 .39753 .21868 .3969 .20619 .38532 Metetra
0 .085 .184 r
.20619 .38532 .21868 .3969 .23637 .39631 .22393 .38467 Metetra
0 .118 .208 r
.22393 .38467 .23637 .39631 .25424 .39576 .24186 .38405 Metetra
0 .157 .233 r
.24186 .38405 .25424 .39576 .2723 .39525 .25997 .38348 Metetra
0 .201 .257 r
.25997 .38348 .2723 .39525 .29056 .39479 .27828 .38295 Metetra
0 .251 .282 r
.27828 .38295 .29056 .39479 .30901 .39437 .29679 .38246 Metetra
0 .307 .307 r
.29679 .38246 .30901 .39437 .32766 .394 .3155 .38202 Metetra
0 .333 .297 r
.3155 .38202 .32766 .394 .34651 .39368 .33441 .38163 Metetra
0 .358 .28 r
.33441 .38163 .34651 .39368 .36558 .3934 .35354 .38128 Metetra
0 .384 .257 r
.35354 .38128 .36558 .3934 .38486 .39317 .37288 .38098 Metetra
0 .41 .228 r
.37288 .38098 .38486 .39317 .40436 .39298 .39245 .38072 Metetra
0 .436 .193 r
.39245 .38072 .40436 .39298 .42408 .39285 .41224 .38052 Metetra
0 .463 .152 r
.41224 .38052 .42408 .39285 .44403 .39277 .43226 .38036 Metetra
0 .489 .105 r
.43226 .38036 .44403 .39277 .46421 .39274 .45251 .38026 Metetra
0 .516 .051 r
.45251 .38026 .46421 .39274 .48463 .39276 .47301 .38021 Metetra
.01 .543 0 r
.47301 .38021 .48463 .39276 .50529 .39284 .49375 .38021 Metetra
.078 .57 0 r
.49375 .38021 .50529 .39284 .5262 .39296 .51474 .38026 Metetra
.152 .597 0 r
.51474 .38026 .5262 .39296 .54737 .39315 .53599 .38036 Metetra
.234 .625 0 r
.53599 .38036 .54737 .39315 .56879 .39339 .5575 .38053 Metetra
.323 .653 0 r
.5575 .38053 .56879 .39339 .59048 .39368 .57928 .38075 Metetra
.42 .681 0 r
.57928 .38075 .59048 .39368 .61245 .39404 .60133 .38102 Metetra
.523 .709 0 r
.60133 .38102 .61245 .39404 .63469 .39445 .62367 .38136 Metetra
.635 .737 0 r
.62367 .38136 .63469 .39445 .65722 .39493 .64629 .38175 Metetra
.755 .766 0 r
.64629 .38175 .65722 .39493 .68003 .39546 .66921 .3822 Metetra
.795 .707 0 r
.66921 .3822 .68003 .39546 .70315 .39606 .69243 .38272 Metetra
.824 .629 0 r
.69243 .38272 .70315 .39606 .72657 .39672 .71596 .3833 Metetra
.853 .544 0 r
.71596 .3833 .72657 .39672 .7503 .39745 .7398 .38395 Metetra
.882 .45 0 r
.7398 .38395 .7503 .39745 .77436 .39825 .76397 .38466 Metetra
.912 .348 0 r
.76397 .38466 .77436 .39825 .79874 .39911 .78847 .38543 Metetra
.942 .238 0 r
.78847 .38543 .79874 .39911 .82345 .40004 .81331 .38628 Metetra
0 .036 .137 r
.15851 .37522 .17126 .38676 .18864 .38602 .17593 .37441 Metetra
0 .059 .161 r
.17593 .37441 .18864 .38602 .20619 .38532 .19354 .37364 Metetra
0 .087 .185 r
.19354 .37364 .20619 .38532 .22393 .38467 .21133 .37292 Metetra
0 .12 .209 r
.21133 .37292 .22393 .38467 .24186 .38405 .2293 .37223 Metetra
0 .159 .234 r
.2293 .37223 .24186 .38405 .25997 .38348 .24747 .37159 Metetra
0 .204 .259 r
.24747 .37159 .25997 .38348 .27828 .38295 .26583 .37099 Metetra
0 .254 .283 r
.26583 .37099 .27828 .38295 .29679 .38246 .2844 .37044 Metetra
0 .309 .307 r
.2844 .37044 .29679 .38246 .3155 .38202 .30317 .36993 Metetra
0 .334 .296 r
.30317 .36993 .3155 .38202 .33441 .38163 .32214 .36946 Metetra
0 .359 .279 r
.32214 .36946 .33441 .38163 .35354 .38128 .34133 .36904 Metetra
0 .385 .256 r
.34133 .36904 .35354 .38128 .37288 .38098 .36074 .36867 Metetra
0 .411 .227 r
.36074 .36867 .37288 .38098 .39245 .38072 .38037 .36834 Metetra
0 .437 .192 r
.38037 .36834 .39245 .38072 .41224 .38052 .40023 .36806 Metetra
0 .464 .15 r
.40023 .36806 .41224 .38052 .43226 .38036 .42032 .36783 Metetra
0 .49 .102 r
.42032 .36783 .43226 .38036 .45251 .38026 .44065 .36765 Metetra
0 .517 .048 r
.44065 .36765 .45251 .38026 .47301 .38021 .46122 .36752 Metetra
.013 .544 0 r
.46122 .36752 .47301 .38021 .49375 .38021 .48204 .36745 Metetra
.081 .571 0 r
.48204 .36745 .49375 .38021 .51474 .38026 .50311 .36742 Metetra
.156 .598 0 r
.50311 .36742 .51474 .38026 .53599 .38036 .52444 .36745 Metetra
.238 .626 0 r
.52444 .36745 .53599 .38036 .5575 .38053 .54604 .36753 Metetra
.327 .654 0 r
.54604 .36753 .5575 .38053 .57928 .38075 .56791 .36767 Metetra
.424 .682 0 r
.56791 .36767 .57928 .38075 .60133 .38102 .59005 .36787 Metetra
.528 .71 0 r
.59005 .36787 .60133 .38102 .62367 .38136 .61248 .36812 Metetra
.64 .738 0 r
.61248 .36812 .62367 .38136 .64629 .38175 .63521 .36843 Metetra
.759 .767 0 r
.63521 .36843 .64629 .38175 .66921 .3822 .65823 .3688 Metetra
.796 .704 0 r
.65823 .3688 .66921 .3822 .69243 .38272 .68155 .36923 Metetra
.825 .626 0 r
.68155 .36923 .69243 .38272 .71596 .3833 .70519 .36973 Metetra
.854 .54 0 r
.70519 .36973 .71596 .3833 .7398 .38395 .72915 .37029 Metetra
.883 .446 0 r
.72915 .37029 .7398 .38395 .76397 .38466 .75343 .37091 Metetra
.913 .344 0 r
.75343 .37091 .76397 .38466 .78847 .38543 .77805 .3716 Metetra
.943 .234 0 r
.77805 .3716 .78847 .38543 .81331 .38628 .80302 .37236 Metetra
0 .037 .138 r
.14559 .36357 .15851 .37522 .17593 .37441 .16306 .36269 Metetra
0 .06 .162 r
.16306 .36269 .17593 .37441 .19354 .37364 .18071 .36186 Metetra
0 .088 .186 r
.18071 .36186 .19354 .37364 .21133 .37292 .19855 .36106 Metetra
0 .122 .211 r
.19855 .36106 .21133 .37292 .2293 .37223 .21657 .36031 Metetra
0 .161 .235 r
.21657 .36031 .2293 .37223 .24747 .37159 .23479 .3596 Metetra
0 .206 .26 r
.23479 .3596 .24747 .37159 .26583 .37099 .25321 .35893 Metetra
0 .257 .285 r
.25321 .35893 .26583 .37099 .2844 .37044 .27183 .3583 Metetra
0 .31 .307 r
.27183 .3583 .2844 .37044 .30317 .36993 .29066 .35772 Metetra
0 .335 .295 r
.29066 .35772 .30317 .36993 .32214 .36946 .3097 .35718 Metetra
0 .361 .278 r
.3097 .35718 .32214 .36946 .34133 .36904 .32895 .35669 Metetra
0 .387 .254 r
.32895 .35669 .34133 .36904 .36074 .36867 .34842 .35624 Metetra
0 .412 .225 r
.34842 .35624 .36074 .36867 .38037 .36834 .36812 .35584 Metetra
0 .439 .19 r
.36812 .35584 .38037 .36834 .40023 .36806 .38805 .35548 Metetra
0 .465 .148 r
.38805 .35548 .40023 .36806 .42032 .36783 .40821 .35518 Metetra
0 .492 .1 r
.40821 .35518 .42032 .36783 .44065 .36765 .42861 .35492 Metetra
0 .518 .045 r
.42861 .35492 .44065 .36765 .46122 .36752 .44926 .35471 Metetra
.016 .545 0 r
.44926 .35471 .46122 .36752 .48204 .36745 .47015 .35455 Metetra
.084 .572 0 r
.47015 .35455 .48204 .36745 .50311 .36742 .49131 .35445 Metetra
.159 .6 0 r
.49131 .35445 .50311 .36742 .52444 .36745 .51272 .3544 Metetra
.242 .627 0 r
.51272 .3544 .52444 .36745 .54604 .36753 .53441 .3544 Metetra
.331 .655 0 r
.53441 .3544 .54604 .36753 .56791 .36767 .55637 .35446 Metetra
.428 .683 0 r
.55637 .35446 .56791 .36767 .59005 .36787 .57861 .35457 Metetra
.533 .711 0 r
.57861 .35457 .59005 .36787 .61248 .36812 .60113 .35474 Metetra
.645 .74 0 r
.60113 .35474 .61248 .36812 .63521 .36843 .62395 .35496 Metetra
.765 .768 0 r
.62395 .35496 .63521 .36843 .65823 .3688 .64708 .35525 Metetra
.797 .701 0 r
.64708 .35525 .65823 .3688 .68155 .36923 .67051 .35559 Metetra
.826 .623 0 r
.67051 .35559 .68155 .36923 .70519 .36973 .69426 .356 Metetra
.855 .536 0 r
.69426 .356 .70519 .36973 .72915 .37029 .71833 .35647 Metetra
.885 .442 0 r
.71833 .35647 .72915 .37029 .75343 .37091 .74273 .35701 Metetra
.914 .339 0 r
.74273 .35701 .75343 .37091 .77805 .3716 .76747 .35761 Metetra
.944 .229 0 r
.76747 .35761 .77805 .3716 .80302 .37236 .79256 .35827 Metetra
0 .038 .14 r
.13248 .35181 .14559 .36357 .16306 .36269 .15 .35087 Metetra
0 .062 .164 r
.15 .35087 .16306 .36269 .18071 .36186 .1677 .34996 Metetra
0 .09 .188 r
.1677 .34996 .18071 .36186 .19855 .36106 .18559 .3491 Metetra
0 .124 .212 r
.18559 .3491 .19855 .36106 .21657 .36031 .20367 .34827 Metetra
0 .164 .237 r
.20367 .34827 .21657 .36031 .23479 .3596 .22194 .34749 Metetra
0 .209 .261 r
.22194 .34749 .23479 .3596 .25321 .35893 .24041 .34675 Metetra
0 .26 .286 r
.24041 .34675 .25321 .35893 .27183 .3583 .25909 .34605 Metetra
0 .311 .306 r
.25909 .34605 .27183 .3583 .29066 .35772 .27798 .34539 Metetra
0 .337 .294 r
.27798 .34539 .29066 .35772 .3097 .35718 .29708 .34478 Metetra
0 .362 .277 r
.29708 .34478 .3097 .35718 .32895 .35669 .31639 .34421 Metetra
0 .388 .253 r
.31639 .34421 .32895 .35669 .34842 .35624 .33593 .34368 Metetra
0 .414 .223 r
.33593 .34368 .34842 .35624 .36812 .35584 .35569 .3432 Metetra
0 .44 .187 r
.35569 .3432 .36812 .35584 .38805 .35548 .37569 .34277 Metetra
0 .467 .145 r
.37569 .34277 .38805 .35548 .40821 .35518 .39592 .34239 Metetra
0 .493 .097 r
.39592 .34239 .40821 .35518 .42861 .35492 .4164 .34205 Metetra
0 .52 .042 r
.4164 .34205 .42861 .35492 .44926 .35471 .43712 .34176 Metetra
.02 .547 0 r
.43712 .34176 .44926 .35471 .47015 .35455 .4581 .34153 Metetra
.088 .574 0 r
.4581 .34153 .47015 .35455 .49131 .35445 .47933 .34134 Metetra
.164 .601 0 r
.47933 .34134 .49131 .35445 .51272 .3544 .50083 .34121 Metetra
.246 .629 0 r
.50083 .34121 .51272 .3544 .53441 .3544 .5226 .34112 Metetra
.336 .657 0 r
.5226 .34112 .53441 .3544 .55637 .35446 .54465 .3411 Metetra
.434 .685 0 r
.54465 .3411 .55637 .35446 .57861 .35457 .56699 .34112 Metetra
.539 .713 0 r
.56699 .34112 .57861 .35457 .60113 .35474 .58961 .34121 Metetra
.651 .741 0 r
.58961 .34121 .60113 .35474 .62395 .35496 .61253 .34135 Metetra
.77 .768 0 r
.61253 .34135 .62395 .35496 .64708 .35525 .63576 .34154 Metetra
.799 .697 0 r
.63576 .34154 .64708 .35525 .67051 .35559 .65929 .3418 Metetra
.828 .618 0 r
.65929 .3418 .67051 .35559 .69426 .356 .68315 .34212 Metetra
.857 .532 0 r
.68315 .34212 .69426 .356 .71833 .35647 .70734 .3425 Metetra
.886 .437 0 r
.70734 .3425 .71833 .35647 .74273 .35701 .73186 .34294 Metetra
.916 .334 0 r
.73186 .34294 .74273 .35701 .76747 .35761 .75672 .34345 Metetra
.946 .223 0 r
.75672 .34345 .76747 .35761 .79256 .35827 .78194 .34402 Metetra
0 .04 .142 r
.11919 .33994 .13248 .35181 .15 .35087 .13676 .33893 Metetra
0 .064 .165 r
.13676 .33893 .15 .35087 .1677 .34996 .15451 .33795 Metetra
0 .093 .19 r
.15451 .33795 .1677 .34996 .18559 .3491 .17245 .33702 Metetra
0 .127 .214 r
.17245 .33702 .18559 .3491 .20367 .34827 .19058 .33612 Metetra
0 .167 .238 r
.19058 .33612 .20367 .34827 .22194 .34749 .2089 .33526 Metetra
0 .212 .263 r
.2089 .33526 .22194 .34749 .24041 .34675 .22743 .33445 Metetra
0 .264 .288 r
.22743 .33445 .24041 .34675 .25909 .34605 .24617 .33367 Metetra
0 .313 .306 r
.24617 .33367 .25909 .34605 .27798 .34539 .26511 .33294 Metetra
0 .339 .293 r
.26511 .33294 .27798 .34539 .29708 .34478 .28427 .33225 Metetra
0 .364 .275 r
.28427 .33225 .29708 .34478 .31639 .34421 .30365 .3316 Metetra
0 .39 .251 r
.30365 .3316 .31639 .34421 .33593 .34368 .32325 .331 Metetra
0 .416 .221 r
.32325 .331 .33593 .34368 .35569 .3432 .34308 .33044 Metetra
0 .442 .185 r
.34308 .33044 .35569 .3432 .37569 .34277 .36315 .32993 Metetra
0 .468 .142 r
.36315 .32993 .37569 .34277 .39592 .34239 .38345 .32947 Metetra
0 .495 .094 r
.38345 .32947 .39592 .34239 .4164 .34205 .404 .32905 Metetra
0 .522 .038 r
.404 .32905 .4164 .34205 .43712 .34176 .4248 .32868 Metetra
.024 .549 0 r
.4248 .32868 .43712 .34176 .4581 .34153 .44586 .32836 Metetra
.093 .576 0 r
.44586 .32836 .4581 .34153 .47933 .34134 .46718 .32809 Metetra
.169 .603 0 r
.46718 .32809 .47933 .34134 .50083 .34121 .48876 .32787 Metetra
.252 .631 0 r
.48876 .32787 .50083 .34121 .5226 .34112 .51062 .3277 Metetra
.342 .658 0 r
.51062 .3277 .5226 .34112 .54465 .3411 .53276 .32759 Metetra
.44 .686 0 r
.53276 .32759 .54465 .3411 .56699 .34112 .55519 .32753 Metetra
.545 .715 0 r
.55519 .32753 .56699 .34112 .58961 .34121 .57791 .32752 Metetra
.658 .743 0 r
.57791 .32752 .58961 .34121 .61253 .34135 .60093 .32757 Metetra
.772 .764 0 r
.60093 .32757 .61253 .34135 .63576 .34154 .62426 .32768 Metetra
.8 .692 0 r
.62426 .32768 .63576 .34154 .65929 .3418 .64791 .32785 Metetra
.829 .613 0 r
.64791 .32785 .65929 .3418 .68315 .34212 .67188 .32807 Metetra
.859 .526 0 r
.67188 .32807 .68315 .34212 .70734 .3425 .69618 .32836 Metetra
.888 .431 0 r
.69618 .32836 .70734 .3425 .73186 .34294 .72082 .3287 Metetra
.918 .328 0 r
.72082 .3287 .73186 .34294 .75672 .34345 .74581 .32912 Metetra
.947 .216 0 r
.74581 .32912 .75672 .34345 .78194 .34402 .77115 .32959 Metetra
0 .041 .144 r
.10572 .32796 .11919 .33994 .13676 .33893 .12333 .32688 Metetra
0 .066 .167 r
.12333 .32688 .13676 .33893 .15451 .33795 .14113 .32583 Metetra
0 .095 .192 r
.14113 .32583 .15451 .33795 .17245 .33702 .15912 .32482 Metetra
0 .13 .216 r
.15912 .32482 .17245 .33702 .19058 .33612 .1773 .32385 Metetra
0 .17 .24 r
.1773 .32385 .19058 .33612 .2089 .33526 .19568 .32292 Metetra
0 .216 .265 r
.19568 .32292 .2089 .33526 .22743 .33445 .21426 .32202 Metetra
0 .268 .29 r
.21426 .32202 .22743 .33445 .24617 .33367 .23306 .32117 Metetra
0 .315 .305 r
.23306 .32117 .24617 .33367 .26511 .33294 .25206 .32036 Metetra
0 .34 .292 r
.25206 .32036 .26511 .33294 .28427 .33225 .27128 .3196 Metetra
0 .366 .274 r
.27128 .3196 .28427 .33225 .30365 .3316 .29072 .31887 Metetra
0 .392 .249 r
.29072 .31887 .30365 .3316 .32325 .331 .31039 .31819 Metetra
0 .418 .219 r
.31039 .31819 .32325 .331 .34308 .33044 .33029 .31755 Metetra
0 .444 .182 r
.33029 .31755 .34308 .33044 .36315 .32993 .35042 .31696 Metetra
0 .47 .139 r
.35042 .31696 .36315 .32993 .38345 .32947 .3708 .31641 Metetra
0 .497 .09 r
.3708 .31641 .38345 .32947 .404 .32905 .39142 .31591 Metetra
0 .524 .034 r
.39142 .31591 .404 .32905 .4248 .32868 .4123 .31546 Metetra
.029 .55 0 r
.4123 .31546 .4248 .32868 .44586 .32836 .43344 .31505 Metetra
.098 .578 0 r
.43344 .31505 .44586 .32836 .46718 .32809 .45484 .31469 Metetra
.174 .605 0 r
.45484 .31469 .46718 .32809 .48876 .32787 .47651 .31439 Metetra
.258 .633 0 r
.47651 .31439 .48876 .32787 .51062 .3277 .49845 .31413 Metetra
.349 .66 0 r
.49845 .31413 .51062 .3277 .53276 .32759 .52069 .31393 Metetra
.447 .688 0 r
.52069 .31393 .53276 .32759 .55519 .32753 .54321 .31378 Metetra
.553 .717 0 r
.54321 .31378 .55519 .32753 .57791 .32752 .56603 .31368 Metetra
.666 .745 0 r
.56603 .31368 .57791 .32752 .60093 .32757 .58915 .31364 Metetra
.774 .759 0 r
.58915 .31364 .60093 .32757 .62426 .32768 .61259 .31366 Metetra
.802 .687 0 r
.61259 .31366 .62426 .32768 .64791 .32785 .63634 .31373 Metetra
.831 .608 0 r
.63634 .31373 .64791 .32785 .67188 .32807 .66042 .31386 Metetra
.861 .52 0 r
.66042 .31386 .67188 .32807 .69618 .32836 .68484 .31405 Metetra
.89 .425 0 r
.68484 .31405 .69618 .32836 .72082 .3287 .7096 .3143 Metetra
.92 .321 0 r
.7096 .3143 .72082 .3287 .74581 .32912 .73472 .31461 Metetra
.949 .208 0 r
.73472 .31461 .74581 .32912 .77115 .32959 .76019 .31499 Metetra
0 .043 .146 r
.09206 .31587 .10572 .32796 .12333 .32688 .10971 .31471 Metetra
0 .068 .17 r
.10971 .31471 .12333 .32688 .14113 .32583 .12756 .31359 Metetra
0 .098 .194 r
.12756 .31359 .14113 .32583 .15912 .32482 .1456 .3125 Metetra
0 .133 .218 r
.1456 .3125 .15912 .32482 .1773 .32385 .16383 .31146 Metetra
0 .174 .243 r
.16383 .31146 .1773 .32385 .19568 .32292 .18226 .31045 Metetra
0 .22 .267 r
.18226 .31045 .19568 .32292 .21426 .32202 .2009 .30948 Metetra
0 .272 .292 r
.2009 .30948 .21426 .32202 .23306 .32117 .21975 .30855 Metetra
0 .317 .304 r
.21975 .30855 .23306 .32117 .25206 .32036 .23882 .30766 Metetra
0 .343 .291 r
.23882 .30766 .25206 .32036 .27128 .3196 .2581 .30681 Metetra
0 .368 .272 r
.2581 .30681 .27128 .3196 .29072 .31887 .2776 .306 Metetra
0 .394 .247 r
.2776 .306 .29072 .31887 .31039 .31819 .29733 .30524 Metetra
0 .42 .216 r
.29733 .30524 .31039 .31819 .33029 .31755 .3173 .30452 Metetra
0 .446 .179 r
.3173 .30452 .33029 .31755 .35042 .31696 .33751 .30384 Metetra
0 .472 .135 r
.33751 .30384 .35042 .31696 .3708 .31641 .35795 .30321 Metetra
0 .499 .086 r
.35795 .30321 .3708 .31641 .39142 .31591 .37865 .30263 Metetra
0 .526 .029 r
.37865 .30263 .39142 .31591 .4123 .31546 .39961 .30209 Metetra
.034 .553 0 r
.39961 .30209 .4123 .31546 .43344 .31505 .42082 .30159 Metetra
.104 .58 0 r
.42082 .30159 .43344 .31505 .45484 .31469 .44231 .30115 Metetra
.181 .607 0 r
.44231 .30115 .45484 .31469 .47651 .31439 .46406 .30075 Metetra
.265 .635 0 r
.46406 .30075 .47651 .31439 .49845 .31413 .4861 .30041 Metetra
.356 .662 0 r
.4861 .30041 .49845 .31413 .52069 .31393 .50842 .30011 Metetra
.455 .69 0 r
.50842 .30011 .52069 .31393 .54321 .31378 .53104 .29987 Metetra
.561 .719 0 r
.53104 .29987 .54321 .31378 .56603 .31368 .55396 .29968 Metetra
.675 .747 0 r
.55396 .29968 .56603 .31368 .58915 .31364 .57719 .29954 Metetra
.776 .754 0 r
.57719 .29954 .58915 .31364 .61259 .31366 .60073 .29946 Metetra
.804 .682 0 r
.60073 .29946 .61259 .31366 .63634 .31373 .62459 .29944 Metetra
.833 .602 0 r
.62459 .29944 .63634 .31373 .66042 .31386 .64879 .29947 Metetra
.863 .513 0 r
.64879 .29947 .66042 .31386 .68484 .31405 .67332 .29956 Metetra
.892 .417 0 r
.67332 .29956 .68484 .31405 .7096 .3143 .69821 .29971 Metetra
.922 .313 0 r
.69821 .29971 .7096 .3143 .73472 .31461 .72345 .29992 Metetra
.951 .2 0 r
.72345 .29992 .73472 .31461 .76019 .31499 .74905 .3002 Metetra
0 .046 .148 r
.0782 .30366 .09206 .31587 .10971 .31471 .0959 .30242 Metetra
0 .071 .172 r
.0959 .30242 .10971 .31471 .12756 .31359 .11379 .30123 Metetra
0 .101 .196 r
.11379 .30123 .12756 .31359 .1456 .3125 .13188 .30006 Metetra
0 .137 .22 r
.13188 .30006 .1456 .3125 .16383 .31146 .15017 .29894 Metetra
0 .178 .245 r
.15017 .29894 .16383 .31146 .18226 .31045 .16865 .29785 Metetra
0 .225 .27 r
.16865 .29785 .18226 .31045 .2009 .30948 .18735 .2968 Metetra
0 .278 .294 r
.18735 .2968 .2009 .30948 .21975 .30855 .20625 .29579 Metetra
0 .32 .303 r
.20625 .29579 .21975 .30855 .23882 .30766 .22537 .29482 Metetra
0 .345 .289 r
.22537 .29482 .23882 .30766 .2581 .30681 .24472 .29389 Metetra
0 .37 .27 r
.24472 .29389 .2581 .30681 .2776 .306 .26428 .293 Metetra
0 .396 .244 r
.26428 .293 .2776 .306 .29733 .30524 .28408 .29216 Metetra
0 .422 .213 r
.28408 .29216 .29733 .30524 .3173 .30452 .30412 .29135 Metetra
0 .448 .175 r
.30412 .29135 .3173 .30452 .33751 .30384 .32439 .29059 Metetra
0 .475 .131 r
.32439 .29059 .33751 .30384 .35795 .30321 .34491 .28987 Metetra
0 .501 .081 r
.34491 .28987 .35795 .30321 .37865 .30263 .36569 .2892 Metetra
0 .528 .024 r
.36569 .2892 .37865 .30263 .39961 .30209 .38672 .28857 Metetra
.04 .555 0 r
.38672 .28857 .39961 .30209 .42082 .30159 .40802 .28799 Metetra
.11 .582 0 r
.40802 .28799 .42082 .30159 .44231 .30115 .42958 .28745 Metetra
.188 .609 0 r
.42958 .28745 .44231 .30115 .46406 .30075 .45143 .28696 Metetra
.272 .637 0 r
.45143 .28696 .46406 .30075 .4861 .30041 .47355 .28653 Metetra
.364 .665 0 r
.47355 .28653 .4861 .30041 .50842 .30011 .49597 .28614 Metetra
.463 .693 0 r
.49597 .28614 .50842 .30011 .53104 .29987 .51868 .2858 Metetra
.57 .721 0 r
.51868 .2858 .53104 .29987 .55396 .29968 .5417 .28551 Metetra
.685 .749 0 r
.5417 .28551 .55396 .29968 .57719 .29954 .56503 .28528 Metetra
.778 .748 0 r
.56503 .28528 .57719 .29954 .60073 .29946 .58868 .2851 Metetra
.807 .675 0 r
.58868 .2851 .60073 .29946 .62459 .29944 .61265 .28498 Metetra
.836 .595 0 r
.61265 .28498 .62459 .29944 .64879 .29947 .63696 .28491 Metetra
.865 .506 0 r
.63696 .28491 .64879 .29947 .67332 .29956 .66162 .2849 Metetra
.894 .409 0 r
.66162 .2849 .67332 .29956 .69821 .29971 .68663 .28495 Metetra
.924 .304 0 r
.68663 .28495 .69821 .29971 .72345 .29992 .71199 .28505 Metetra
.954 .191 0 r
.71199 .28505 .72345 .29992 .74905 .3002 .73773 .28522 Metetra
0 .048 .151 r
.06414 .29133 .0782 .30366 .0959 .30242 .08189 .29002 Metetra
0 .074 .174 r
.08189 .29002 .0959 .30242 .11379 .30123 .09983 .28874 Metetra
0 .105 .199 r
.09983 .28874 .11379 .30123 .13188 .30006 .11796 .2875 Metetra
0 .141 .223 r
.11796 .2875 .13188 .30006 .15017 .29894 .1363 .28629 Metetra
0 .183 .247 r
.1363 .28629 .15017 .29894 .16865 .29785 .15484 .28513 Metetra
0 .23 .272 r
.15484 .28513 .16865 .29785 .18735 .2968 .17359 .28399 Metetra
0 .283 .297 r
.17359 .28399 .18735 .2968 .20625 .29579 .19255 .2829 Metetra
0 .322 .302 r
.19255 .2829 .20625 .29579 .22537 .29482 .21173 .28185 Metetra
0 .348 .288 r
.21173 .28185 .22537 .29482 .24472 .29389 .23114 .28084 Metetra
0 .373 .267 r
.23114 .28084 .24472 .29389 .26428 .293 .25077 .27986 Metetra
0 .399 .241 r
.25077 .27986 .26428 .293 .28408 .29216 .27063 .27893 Metetra
0 .425 .209 r
.27063 .27893 .28408 .29216 .30412 .29135 .29073 .27804 Metetra
0 .451 .171 r
.29073 .27804 .30412 .29135 .32439 .29059 .31108 .27719 Metetra
0 .477 .127 r
.31108 .27719 .32439 .29059 .34491 .28987 .33167 .27638 Metetra
0 .504 .076 r
.33167 .27638 .34491 .28987 .36569 .2892 .35252 .27561 Metetra
0 .531 .018 r
.35252 .27561 .36569 .2892 .38672 .28857 .37363 .2749 Metetra
.046 .557 0 r
.37363 .2749 .38672 .28857 .40802 .28799 .39501 .27422 Metetra
.117 .585 0 r
.39501 .27422 .40802 .28799 .42958 .28745 .41666 .27359 Metetra
.195 .612 0 r
.41666 .27359 .42958 .28745 .45143 .28696 .43859 .27301 Metetra
.28 .64 0 r
.43859 .27301 .45143 .28696 .47355 .28653 .46081 .27248 Metetra
.373 .667 0 r
.46081 .27248 .47355 .28653 .49597 .28614 .48332 .27199 Metetra
.473 .695 0 r
.48332 .27199 .49597 .28614 .51868 .2858 .50613 .27156 Metetra
.58 .724 0 r
.50613 .27156 .51868 .2858 .5417 .28551 .52925 .27118 Metetra
.696 .752 0 r
.52925 .27118 .5417 .28551 .56503 .28528 .55268 .27084 Metetra
.781 .742 0 r
.55268 .27084 .56503 .28528 .58868 .2851 .57643 .27056 Metetra
.809 .669 0 r
.57643 .27056 .58868 .2851 .61265 .28498 .60052 .27034 Metetra
.838 .587 0 r
.60052 .27034 .61265 .28498 .63696 .28491 .62495 .27016 Metetra
.868 .498 0 r
.62495 .27016 .63696 .28491 .66162 .2849 .64972 .27005 Metetra
.897 .401 0 r
.64972 .27005 .66162 .2849 .68663 .28495 .67485 .26999 Metetra
.927 .295 0 r
.67485 .26999 .68663 .28495 .71199 .28505 .70035 .26999 Metetra
.956 .181 0 r
.70035 .26999 .71199 .28505 .73773 .28522 .72622 .27005 Metetra
0 .051 .153 r
.04987 .27887 .06414 .29133 .08189 .29002 .06767 .27748 Metetra
0 .077 .177 r
.06767 .27748 .08189 .29002 .09983 .28874 .08565 .27612 Metetra
0 .109 .201 r
.08565 .27612 .09983 .28874 .11796 .2875 .10384 .2748 Metetra
0 .145 .226 r
.10384 .2748 .11796 .2875 .1363 .28629 .12223 .27352 Metetra
0 .188 .25 r
.12223 .27352 .1363 .28629 .15484 .28513 .14082 .27227 Metetra
0 .236 .275 r
.14082 .27227 .15484 .28513 .17359 .28399 .15963 .27105 Metetra
0 .29 .3 r
.15963 .27105 .17359 .28399 .19255 .2829 .17865 .26988 Metetra
0 .325 .301 r
.17865 .26988 .19255 .2829 .21173 .28185 .19789 .26874 Metetra
0 .35 .286 r
.19789 .26874 .21173 .28185 .23114 .28084 .21735 .26764 Metetra
0 .376 .265 r
.21735 .26764 .23114 .28084 .25077 .27986 .23704 .26658 Metetra
0 .402 .238 r
.23704 .26658 .25077 .27986 .27063 .27893 .25697 .26555 Metetra
0 .427 .206 r
.25697 .26555 .27063 .27893 .29073 .27804 .27714 .26457 Metetra
0 .454 .167 r
.27714 .26457 .29073 .27804 .31108 .27719 .29756 .26363 Metetra
0 .48 .122 r
.29756 .26363 .31108 .27719 .33167 .27638 .31823 .26273 Metetra
0 .507 .07 r
.31823 .26273 .33167 .27638 .35252 .27561 .33915 .26188 Metetra
0 .533 .012 r
.33915 .26188 .35252 .27561 .37363 .2749 .36034 .26107 Metetra
.053 .56 0 r
.36034 .26107 .37363 .2749 .39501 .27422 .3818 .2603 Metetra
.125 .587 0 r
.3818 .2603 .39501 .27422 .41666 .27359 .40353 .25957 Metetra
.203 .615 0 r
.40353 .25957 .41666 .27359 .43859 .27301 .42555 .2589 Metetra
.289 .642 0 r
.42555 .2589 .43859 .27301 .46081 .27248 .44786 .25827 Metetra
.382 .67 0 r
.44786 .25827 .46081 .27248 .48332 .27199 .47046 .25768 Metetra
.483 .698 0 r
.47046 .25768 .48332 .27199 .50613 .27156 .49337 .25715 Metetra
.591 .726 0 r
.49337 .25715 .50613 .27156 .52925 .27118 .51659 .25666 Metetra
.707 .755 0 r
.51659 .25666 .52925 .27118 .55268 .27084 .54013 .25623 Metetra
.783 .736 0 r
.54013 .25623 .55268 .27084 .57643 .27056 .56399 .25584 Metetra
.812 .661 0 r
.56399 .25584 .57643 .27056 .60052 .27034 .58819 .25551 Metetra
.841 .579 0 r
.58819 .25551 .60052 .27034 .62495 .27016 .61273 .25523 Metetra
.87 .489 0 r
.61273 .25523 .62495 .27016 .64972 .27005 .63763 .25501 Metetra
.9 .391 0 r
.63763 .25501 .64972 .27005 .67485 .26999 .66288 .25484 Metetra
.929 .285 0 r
.66288 .25484 .67485 .26999 .70035 .26999 .68851 .25473 Metetra
.959 .17 0 r
.68851 .25473 .70035 .26999 .72622 .27005 .71452 .25468 Metetra
0 .054 .156 r
.03539 .26629 .04987 .27887 .06767 .27748 .05323 .26482 Metetra
0 .081 .18 r
.05323 .26482 .06767 .27748 .08565 .27612 .07127 .26338 Metetra
0 .113 .204 r
.07127 .26338 .08565 .27612 .10384 .2748 .08951 .26197 Metetra
0 .15 .229 r
.08951 .26197 .10384 .2748 .12223 .27352 .10794 .2606 Metetra
0 .193 .253 r
.10794 .2606 .12223 .27352 .14082 .27227 .12659 .25927 Metetra
0 .242 .278 r
.12659 .25927 .14082 .27227 .15963 .27105 .14545 .25797 Metetra
0 .296 .303 r
.14545 .25797 .15963 .27105 .17865 .26988 .16453 .25671 Metetra
0 .328 .299 r
.16453 .25671 .17865 .26988 .19789 .26874 .18383 .25548 Metetra
0 .353 .284 r
.18383 .25548 .19789 .26874 .21735 .26764 .20335 .25429 Metetra
0 .379 .262 r
.20335 .25429 .21735 .26764 .23704 .26658 .22311 .25314 Metetra
0 .404 .235 r
.22311 .25314 .23704 .26658 .25697 .26555 .2431 .25203 Metetra
0 .43 .201 r
.2431 .25203 .25697 .26555 .27714 .26457 .26334 .25096 Metetra
0 .457 .162 r
.26334 .25096 .27714 .26457 .29756 .26363 .28383 .24993 Metetra
0 .483 .116 r
.28383 .24993 .29756 .26363 .31823 .26273 .30457 .24893 Metetra
0 .509 .064 r
.30457 .24893 .31823 .26273 .33915 .26188 .32557 .24798 Metetra
0 .536 .005 r
.32557 .24798 .33915 .26188 .36034 .26107 .34684 .24708 Metetra
.06 .563 0 r
.34684 .24708 .36034 .26107 .3818 .2603 .36838 .24621 Metetra
.133 .59 0 r
.36838 .24621 .3818 .2603 .40353 .25957 .3902 .24539 Metetra
.212 .618 0 r
.3902 .24539 .40353 .25957 .42555 .2589 .4123 .24461 Metetra
.299 .645 0 r
.4123 .24461 .42555 .2589 .44786 .25827 .4347 .24388 Metetra
.393 .673 0 r
.4347 .24388 .44786 .25827 .47046 .25768 .4574 .24319 Metetra
.494 .701 0 r
.4574 .24319 .47046 .25768 .49337 .25715 .4804 .24256 Metetra
.603 .729 0 r
.4804 .24256 .49337 .25715 .51659 .25666 .50372 .24197 Metetra
.72 .758 0 r
.50372 .24197 .51659 .25666 .54013 .25623 .52736 .24143 Metetra
.786 .728 0 r
.52736 .24143 .54013 .25623 .56399 .25584 .55134 .24093 Metetra
.815 .653 0 r
.55134 .24093 .56399 .25584 .58819 .25551 .57565 .24049 Metetra
.844 .57 0 r
.57565 .24049 .58819 .25551 .61273 .25523 .60031 .24011 Metetra
.873 .48 0 r
.60031 .24011 .61273 .25523 .63763 .25501 .62533 .23977 Metetra
.903 .381 0 r
.62533 .23977 .63763 .25501 .66288 .25484 .65071 .23949 Metetra
.932 .274 0 r
.65071 .23949 .66288 .25484 .68851 .25473 .67647 .23927 Metetra
.962 .158 0 r
.67647 .23927 .68851 .25473 .71452 .25468 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-0.5)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.4)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(-0.3)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(-0.2)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(-0.1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00]?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0005kooooo002cooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0GOooool00:cooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0GOooool00;?ooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`1Mooooo`00/oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo05gooooo002cooooo`04o`000?ooooooooooo`0000Sooooo0_l0000<oooo
o`;o00001?ooool01?l0003oooooooooooooool5o`0004Cooooo002dooooo`;o00002_ooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000A?oo
ool00<Gooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0A?oo
ool00<cooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`13ooooo`00c?ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000A?ooool00<cooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000004Cooooo0030ooooo`;o0000
2oooool2o`0000Wooooo0ol00015ooooo`00_Oooool5o`0005kooooo002kooooo`;o00001?ooool2
o`0005gooooo002hooooo`?o00001_ooool00ol0003oooooo`00001Looooo`00]_ooool3o`0000So
oooo00?o0000ooooool00000G?ooool00;?ooooo0ol00003ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo0000Foooool00;7ooooo0_l0000>ooooo`05o`000?ooooooooooooooool0
0000F_ooool008Gooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00006_ooool3o`00013o
oooo00Co0000oooooooooooooooo0_l0001Iooooo`00Q?ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0001Sooooo0_l000000ooooooo0000ooooo`0@ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Eoooool007gooooo1Ol00002ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool05Oooool3o`0001Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Fooooo`00Q?ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo
oooo01;ooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E_ooool0
08Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000013ooooo0ol0
000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0EOooool008Cooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000kooooo0_l00002ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Dooooo`00QOoo
ool2o`0000Wooooo0ol0000<ooooo`?o00008?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo05Cooooo002Mooooo`;o00008oooool00ol0003oooooooooo`04ooooo`;o0000EOooool0
09[ooooo1?l0000Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Doooool009Oo
oooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0D_ooool009Gooooo
0_l0000[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0DOooool009;ooooo0ol0
000]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0DOooool0093ooooo0_l00003
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1@
ooooo`00SOooool3o`0003;ooooo00?o0000ooooooooool02?ooool2o`00057ooooo002;ooooo`;o
0000=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04oooooo0028ooooo`Go0000
=Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04kooooo0026ooooo`;o0000>_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04gooooo001Hooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`?o00007Oooool3o`0003cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1=ooooo`00Eoooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000006_ooool2o`00043ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1<ooooo`00D?ooool5o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003ooooooooo
o`0Eooooo`?o00000_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Boooool005Oooooo00Co0000oooooooooooo00002Oooool2o`0001Kooooo0_l0
0015ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`00033ooooo001Gooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool04?ooool3o`0004Oooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0;oooool005Oooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000013ooooo0_l000000ooooooo
0000ooooo`17ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool5o`0000;o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0_ooooo`00F?ooool2o`0000Wo
oooo0ol0000>ooooo`?o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0_ooooo`00L_ooool2o`0004oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool0;oooool006oooooo1?l0001@ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`;o0000<Oooool006go
oooo0_l0001Dooooo`03o`000?oooooooooo00oooooo0_l0000;ooooo`;o00002_ooool00ol0003o
ooooooooo`0_ooooo`00J_ooool3o`0005Kooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`16ooooo`00J?ooool2o`0005Wooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`15ooooo`00IOooool3o`0000;ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo04Gooooo001Sooooo`;o0000G_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04Cooooo001Pooooo`?o0000H?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o000000?oooooo`000?ooool0H?ooool00ol0003ooooo
ooooo`0Cooooo`;o0000AOooool002oooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol0
000Mooooo`?o0000I_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04;ooooo000^
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool06_ooool2o`0006Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`11ooooo`009oooool5o`0000;ooooo00Co0000
oooooooooooo00001oooool5o`0001Sooooo1?l0001Zooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0@Oooool002kooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool0000Gooooo`;o0000K_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo043ooooo
000^ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000004oooool4o`00073ooooo
00?o0000ooooooooool05_ooool2o`00047ooooo000^ooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Booooo`?o0000L_ooool00ol0003oooooooooo`0Fooooo`;o0000@Oooool002oooooo0_l0
000;ooooo`03o`000?oooooooooo00gooooo0ol0001eooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0?_ooool004[ooooo0_l0001hooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0?_ooool004Oooooo0ol0001jooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0?Oooool004Cooooo0ol0001mooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0??ooool004;ooooo0_l00020ooooo`03o`000?oooooooooo01[ooooo0_l0000mooooo`00?ooo
ool3o`0008;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0kooooo`00?Oooool2
o`0000?ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo03[ooooo000jooooo`?o0000Qoooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
03[ooooo000hooooo`?o0000ROooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Wo
oooo000eooooo`?o0000S?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03Sooooo
0008ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00007Oooool2o`00093ooooo00?o
0000ooooooooool07Oooool2o`0000Oooooo0_l0000`ooooo`001oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000006Oooool3o`0009;ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002oooooo0005o`0000;ooooo
00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Eooooo`;o0000UOooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000;oooool000Oo
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Booooo`?o0000Uoooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000;oooool0
00Oooooo00Co0000oooooooooooo00001oooool4o`0001?ooooo0_l0002Jooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000_ooooo`001oooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo017ooooo0ol0002Booooo`_o00008ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0;Oooool000Sooooo0_l0
0008ooooo`Go00003Oooool2o`0005gooooo>?l00003oni60003o`000?of:03omRP000ComRP000?o
0000ooooooooool08?ooool2o`0000Cooooo0_l0000`ooooo`008Oooool3o`0004?ooooo7?l00004
ofB/0003o`000?mn/`3oO[<000;oO[<000?o0000oiZj0?nJ^P000onJ^P000ol0003o^<80okS20003
okS20003o`000?o9^P3obKX000CobKX000?o0000om2W0?o@Y`000oo@Y`000ol0003of940omRA0003
omRA0003o`000?oONP3oggX000CoggX000?o0000onMQ0?oWH@001?oWH@000ol0003okTH0oni60003
oni60003o`000?of:03omRP000;omRP00ol0000Sooooo`03o`000?oooooooooo03?ooooo000Ooooo
o`;o0000<OoooolEo`0000?o08T100?o0000o`n@0?l?T0000ol?T0000ol0003o8YL0ob:G0002ob:G
0003o`000?lfWP3o=Yh000Co=Yh000?o0000odbU0?m<Y@000om<Y@000ol0003oI:`0ofB/0003ofB/
0003o`000?mn/`3oO[<000;oO[<000?o0000oiZj0?nJ^P000onJ^P000ol0003o^<80okS20003okS2
0003o`000?o9^P3obKX000CobKX000?o0000om2W0?o@Y`000oo@Y`000ol0003of940omRA0003omRA
0003o`000?oONP3oggX000CoggX000?o0000onMQ0?oWH@001?oWH@000ol0003okTH0oni60003oni6
00Co000000ComRP0o`000?of:03o00008oooool00ol0003oooooooooo`0booooo`007?ooool3o`00
02Cooooo3ol00003o`1^<`03o`000?l0M2Wo07@Y00;o07@Y00?o0000o`1k7Ol0Nad01?l0Nad00ol0
003o088@o`224002o`224003o`000?l0R@7o08T100;o08T100?o0000o`n@0?l?T0000ol?T0000ol0
003o8YL0ob:G0002ob:G0003o`000?lfWP3o=Yh000Co=Yh000?o0000odbU0?m<Y@000om<Y@000ol0
003oI:`0ofB/0003ofB/0003o`000?mn/`3oO[<000;oO[<000?o0000oiZj0?nJ^P000onJ^P000ol0
003o^<80okS20003okS20003o`000?o9^P3obKX000CobKX000?o0000om2W0?o@Y`000oo@Y`000ol0
003of940omRA0003omRA0004o`000?oONP3oggX0ommj01So00008_ooool00ol0003oooooooooo`0b
ooooo`006oooool2o`0001Oooooo3ol00003o`1JB003o`000?l0HD?o065300?o065300?o0000o`1W
??l0Ic`00_l0Ic`00ol0003o06hco`1^<`02o`1^<`03o`000?l0M2Wo07@Y00;o07@Y00?o0000o`1k
7Ol0Nad01?l0Nad00ol0003o088@o`224002o`224003o`000?l0R@7o08T100;o08T100?o0000o`n@
0?l?T0000ol?T0000ol0003o8YL0ob:G0002ob:G0004o`000?lfWP3o=Yh0ocJN03Ko00000ooNO@00
0ol0003oiV@0onIT0004onIT00?o00000oo]B0000ol0003omB/0ooD[0003ooD[00;o00008oooool2
o`0003;ooooo000Kooooo`?o00002?ooool>o`0000?o03e700?o0000o`1;COl0Bdd00ol0Bdd00ol0
003o05=<o`1CC002o`1CC003o`000?l0FTSo05Y800;o05Y800?o0000o`1Q@ol0HD<00ol0HD<00ol0
003o06Llo`1W?002o`1W?003o`000?l0KS?o06hc00;o06hc00?o0000o`1d:Ol0M2T00_l0M2T01?l0
003o07/Mo`1k7Ol0NadKo`0000?o<id000?o0000odVT0?m9Y0000om9Y0000ol0003oHJ/0of6[0003
of6[0003o`000?mk/P3oNk8000?oNk8000?o0000oiNi0?nG^@000onG^@000ol0003o]<40okC10003
okC10003o`000?o8_03ob;`000Cob;`000?o0000olnY0?o?Z@000oo?Z@000ol0003oei@0omND0003
omND0003o`000?oNO@3ogWd000?ogWd000?o0000onIT0?oVI0000ol000000ooVI03o0000one80004
one80003o`000?oe:`3omB/000?omB/00_l0000Rooooo`;o0000<_ooool001[ooooo3?l00003o`0L
=003o`000?l09S[o02Hj00;o02Hj00?o0000o`0a@?l0<D000_l0<D000ol0003o03e7o`0mA`02o`0m
A`03o`000?l0Bdgo04]=00?o04]=00?o0000o`1CC?l0Dd`00_l0Dd`00ol0003o05Y8o`1JB002o`1J
B004o`000?l0HD?o0653o`1Q@aCo00000ol0NQl00ol0003o084Ao`214@02o`214@03o`000?l0R0?o
08P300?o08P300?o0000o`f?0?l=S`000ol=S`000ol0003o7iH0oanF0003oanF0003o`000?lcW@3o
<id000;o<id000?o0000odVT0?m9Y0000om9Y0000ol0003oHJ/0of6[0003of6[0003o`000?mk/P3o
Nk8000?oNk8000?o0000oiNi0?nG^@000onG^@000ol0003o]<40okC10003okC10003o`000?o8_03o
b;`000Cob;`000?o0000olnY0?o?Z@000oo?Z@000ol0003oei@0omND0003omND0003o`000?oNO@3o
gWd000;ogWd00ol00005onIT0003o`000?o]B03okDP000?okDP000?o0000ooD[0?oe:`000_oe:`00
0ol0003omB/0o`00000Rooooo`03o`000?oooooooooo033ooooo000Jooooo`;o00001?l03BL00ol0
003o01@^o`0D;P02o`0D;P03o`000?l073Co01`d00;o01`d00?o0000o`0V>_l09SX00_l09SX00ol0
003o0350o`0a@002o`0a@003o`000?l0?DOo03e700;o03e700Co0000o`1;COl0Bdgo04]=3ol00002
o`1P@`03o`000?l0ISco06Hl00;o06Hl00?o0000o`1]=?l0KC@01?l0KC@00ol0003o07@Zo`1d:P02
o`1d:P03o`000?l0NQoo07XO00;o07XO00?o0000o`214Ol0PA400_l0PA400ol0003o08P3o`280`03
o`280`03o`000?l=S`3o3Hl000?o3Hl000?o0000oanF0?lOUP000olOUP000ol0003o<id0oc>M0002
oc>M0003o`000?m9Y03oBJ@000?oBJ@000?o0000of6[0?mQZ`000omQZ`000ol0003oNk80og^b0003
og^b0003o`000?nG^@3oUkT000?oUkT000?o0000okC10?nd`@000ond`@001?l0003ob;`0olRl0?o8
_00Zo`0002;ooooo00?o0000ooooooooool0;oooool001[ooooo00?o0000ooooool000001?l03BL0
0ol0003o01@^o`0D;P02o`0D;P03o`000?l073Co01`d00;o01`d00?o0000o`0V>_l09SX03ol00002
o`1:C003o`000?l0Ddgo05==00?o05==00?o0000o`1IBOl0FDT00_l0FDT00ol0003o0613o`1P@`02
o`1P@`03o`000?l0ISco06Hl00;o06Hl00?o0000o`1]=?l0KC@01?l0KC@00ol0003o07@Zo`1d:P02
o`1d:P03o`000?l0NQoo07XO00;o07XO00?o0000o`214Ol0PA400_l0PA400ol0003o08P3o`280`03
o`280`04o`000?l=S`3o3Hl0o`f?02ko00000oo7_@000ol0003ocj/0oln[0003oln[0003o`000?oF
UP3oeYH000;oeYH00_l00006omio0003o`000?oUIP3oiFH000?oiFH000?o0000one;0?o]B`000oo]
B`000ol0003om2h0oo@^0003oo@^00;o00008_ooool00ol0003oooooooooo`0_ooooo`006_ooool0
1?l0003oooooooooool00002o`0=9`ko00001?l09CT00ol0003o030oo`0`?`02o`0`?`03o`000?l0
?4Ko03a600;o03a600Go0000o`1:C?l0BTco04Y<o`000005o`1CC@03o`000?l0FDWo05U900;o05U9
00?o0000o`1P@ol0H4<00_l0H4<00ol0003o06Hlo`1V?002o`1V?004o`000?l0KCCo06ddo`1]=1_o
00000ol;SP000ol0003o7ID0oafE0002oafE0003o`000?laW03o<I`000?o<I`000?o0000odNS0?m7
X`000_m7X`000ol0003oGjX0oenZ0004oenZ0003o`000?mi/@3oNK4000?oNK4000?o0000oiBi0?nD
^@000onD^@000ol0003o//00ok;00003ok;00003o`000?o7_@3oakd000?oakd000?o0000oln[0?o?
Z`000oo?Z`04o`0000;oeYH000?o0000omio0?oNO`001?oNO`000ol0003oiFH0onEV0003onEV0003
o`000?o]B`3okD/000?okD/000?o0000oo@^0?od;P000_od;P000ol0003om2h0o`00000Rooooo`03
o`000?oooooooooo02kooooo000Jooooo`04o`000?ooooooooooooooo`;o00001?l03BL00ol0003o
01<]o`0C;@02o`0C;@05o`000?l06c?o01/co`0K<ol000001Ol09CT00ol0003o030oo`0`?`02o`0`
?`03o`000?l0?4Ko03a600;o03a600Go0000o`1:C?l0BTco04Y<o`000003o`1CCACo00000ol0K3D0
0ol0003o07<[o`1c:`02o`1c:`03o`000?l0NR3o07XP00?o07XP00?o0000o`214ol0PA<00ol0PA<0
0ol0003o08L4o`271002o`271003o`000?l;SP3o2hh000?o2hh000?o0000oafE0?lMU@000_lMU@00
0ol0003o<I`0oc6L0003oc6L0003o`000?m7X`3oAj<000;oAj<000?o0000oenZ0?mOZP001?mOZP00
0ol0003oNK40ogVa0003ogVa0003o`000?nD^@3oU;T000?oU;T000?o0000ok;00?nb`0000onb`000
0ol0003oakd0olNm0003olNm0003o`000?o?Z`3ocj/000Co00001OoFUP000ol0003ogWl0omio0004
omio0003o`000?oUIP3oiFH000?oiFH000?o0000one;0?o]B`000oo]B`000ol0003om2h0oo@^0002
oo@^0003o`000?od;P3o0000027ooooo0_l0000_ooooo`006Oooool2o`0000Gooooo00?o0000o`0=
9ol03BL00_l03BL00ol0003o01<]o`0C;@02o`0C;@05o`000?l06c?o01/co`0K<ol000000ol09CTC
o`0000?o059=00?o0000o`1IBOl0FDT00ol0FDT00ol0003o05m4o`1OA002o`1OA003o`000?l0ISgo
06Hm00;o06Hm00?o0000o`1/=Ol0K3D00_l0K3D00ol0003o07<[o`1c:`02o`1c:`03o`000?l0NR3o
07XP00?o07XP00?o0000o`214ol0PA<00ol0PA<00ol0003o08L4o`271002o`271003o`000?l;SP3o
2hh000?o2hh000?o0000oafE0?lMU@000_lMU@000ol0003o<I`0oc6L0003oc6L0003o`000?m7X`3o
Aj<000;oAj<000Co0000oenZ0?mOZP3oGjX0@_l0000Qooooo`03o`000?oooooooooo02gooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000o`0=9ol03BL03_l00003o`0T>@03o`000?l0;Soo
02ho00;o02ho00?o0000o`0jAOl0>TD00_l0>TD00ol0003o04Q<o`18C002o`18C003o`000?l0DTgo
059=00;o059=00?o0000o`1IBOl0FDT00ol0FDT00ol0003o05m4o`1OA002o`1OA003o`000?l0ISgo
06Hm00;o06Hm00?o0000o`1/=Ol0K3D00_l0K3D00ol0003o07<[o`1c:`02o`1c:`04o`000?l0NR3o
07XPo`1j82Ko00000omMZP000ol0003oM[40ogJa0003ogJa0003o`000?nA^03oTKP000?oTKP000?o
0000ojno0?n__`000on__`000ol0003oakl0o`000002o`000003olNo0?l0003ocZ`000CocZ`000?o
0000omJH0?oFV0000ooFV0000ol0003ogH40omf10004omf10003o`000?oTJ03oi6P000?oi6P000?o
0000ona=0?o/C@000oo/C@000ol0003om300oo@`0003oo@`00;o00008_ooool00ol0003ooooooooo
o`0/ooooo`006_ooool00ol0003oooooooooo`05ooooo`;o00000ol032H00ol0003o018/o`0B;002
o`0B;003o`000?l06S;o01Xb00;o01Xb00?o0000o`0T>Ol093T00_l093T00ol0003o02hoo`0^?`02
o`0^?`03o`000?l0>TGo03Y500;o03Y500?o0000o`18C?l0B4`00_l0B4`00ol0003o059=o`1BC@02
o`1BC@04o`000?l0FDWo05U9o`1IBAWo00000ol0NB400ol0003o080Do`205002o`205003o`000?l0
Q`Ko08L600;o08L600?o0000o`Z>0?l:SP001?l:SP000ol0003o79@0oabD0002oabD0003o`000?l`
V`3o<9/000?o<9/000?o0000odFS0?m5X`000om5X`000ol0003oGJX0oefZ0002oefZ0003o`000?mf
/@3oM[4000?oM[4000?o0000oi6h0?nA^0000onA^0001?l0003o[kl0ojno0?n__`03o`0000Goakl0
00?o0000olj/0?o>[0000oo>[0000ol0003oeYP0omJH0003omJH0003o`000?oMP@3ogH4000CogH40
00?o0000onAX0?oTJ0000ooTJ0000ol0003ok4d0ona=0003ona=0003o`000?od<03om30000;om300
00?o0000oo@`0?l000008_ooool00ol0003oooooooooo`0[ooooo`006Oooool00ol0003ooooooooo
o`07ooooo`03o`000?l032Ko00`V00;o00`V00?o0000o`0B;?l04R`00_l04R`00ol0003o01Xbo`0J
<P02o`0J<P03o`000?l093Wo02@i00;o02@i00?o0000o`0^?ol0;Sl05?l00002o`1HB@03o`000?l0
GTGo05i500;o05i500?o0000o`1U?_l0ICh00ol0ICh00ol0003o06`fo`1/=P02o`1/=P03o`000?l0
LRco078/00?o078/00?o0000o`1i8Ol0NB400_l0NB400ol0003o080Do`205002o`205003o`000?l0
Q`Ko08L600;o08L600?o0000o`Z>0?l:SP001?l:SP000ol0003o79@0oabD0002oabD0003o`000?l`
V`3o<9/000?o<9/000?o0000odFS0?m5X`000om5X`000ol0003oGJX0oefZ0002oefZ0003o`000?mf
/@3oM[4000?oM[4000?o0000oi6h0?nA^0000onA^003o`0000?o[kl000?o0000olNo0?o7_`000oo7
_`000ol0003ocZ`0olj/0003olj/0003o`000?oFV03oeYP000?oeYP000?o0000omf10?oMP@001?oM
P@000ol0003oi6P0onAX0003onAX0003o`000?o/C@3ok4d000?ok4d000?o0000oo@`0?od<0000_od
<0000ol0003om300o`00000Qooooo`03o`000?oooooooooo02_ooooo000Iooooo`;o00002Oooool0
0ol0003o00`Vo`0<9P02o`0<9P03o`000?l04Rco018/00ko00000ol0;Ch00ol0003o03U5o`0iA@03
o`0iA@05o`000?l0Ad_o04M;o`17Bol000001?l0DDd00ol0003o05Q9o`1HB@02o`1HB@03o`000?l0
GTGo05i500;o05i500?o0000o`1U?_l0ICh00ol0ICh00ol0003o06`fo`1/=P02o`1/=P03o`000?l0
LRco078/00?o078/00?o0000o`1i8Ol0NB400_l0NB400ol0003o080Do`205002o`205003o`000?l0
Q`Ko08L600;o08L600Co0000o`Z>0?l:SP3o2Xh0F?l0000Qooooo`;o0000:oooool001Wooooo00?o
0000ooooooooool02Oooool7o`0000Co018/00Go0000o`0I<_l06C;o01Tbo`000004o`0S>003o`00
0?l0;Cko02dn00;o02dn00?o0000o`0iAOl0>DD00ol0>DD01Ol0003o04M;o`17Bol0Ad_o000000Co
055=00?o0000o`1HBOl0F4T00_l0F4T00ol0003o05i5o`1NA@02o`1NA@04o`000?l0ICko06Dno`1U
?Qoo00000ol8S@000ol0003o6Y@0oaZD0003oaZD0003o`000?l^V`3o;Y/000;o;Y/000?o0000od>R
0?m3XP000om3XP000ol0003oFjT0oe^Y0002oe^Y0003o`000?md/03oM;0000?oM;000ol00003ohnh
0003o`000?n/_`3o[;l000Co[;l000?o0000olK10?o6`@000oo6`@000ol0003ocJh0olf^0002olf^
0003o`000?oEVP3oeIX000?oeIX000?o0000omb30?oLP`001?oLP`000ol0003oi6X0onAZ0003onAZ
0003o`000?o/D03ok50000?ok50000?o0000oo<c0?oc<`000ooc<`02o`0002;ooooo00?o0000oooo
ooooool0:Oooool001Wooooo00?o0000ooooooooool02oooool01Ol0003o00/Uo`0;9Ol02bGo0000
00Go018/00Go0000o`0I<_l06C;o01Tbo`000004o`0S>003o`000?l0;Cko02dn00;o02dn00Co0000
o`0iAOl0>DGo03U56?l00003o`1T?`03o`000?l0JcOo06/g00?o06/g00?o0000o`1b;Ol0LRd00_l0
LRd00ol0003o07PRo`1h8P02o`1h8P03o`000?l0OaKo07lF00;o07lF00?o0000o`261ol0QPL00ol0
QPL00ol0003o28d0o`R=0002o`R=0003o`000?lJU03o6Y@000?o6Y@000?o0000objK0?l^V`000_l^
V`000ol0003o@j80od>R0003od>R0003o`000?mKZ@3oFjT000;oFjT000?o0000ogB`0?l000000_l0
00000omd/03o0000ohnh0004ohnh0003o`000?n/_`3o[;l000Co[;l000?o0000olK10?o6`@000oo6
`@000ol0003ocJh0olf^0002olf^0003o`000?oEVP3oeIX000?oeIX000?o0000omb30?oLP`001?oL
P`000ol0003oi6X0onAZ0003onAZ0003o`000?o/D03ok50000?ok50000?o0000oo<c0?oc<`000_oc
<`000ol0003olc<0o`00000Qooooo`03o`000?oooooooooo02Wooooo000Iooooo`03o`000?oooooo
oooo00cooooo00Go0000o`0;9Ol02bGo00/Uo`000003o`0B;1?o00000_l0>4@00ol0003o04E:o`15
BP03o`15BP03o`000?l0DDgo055=00;o055=00?o0000o`1GB_l0EdX00_l0EdX00ol0003o05i5o`1N
A@02o`1NA@03o`000?l0I3oo06@o00;o06@o00?o0000o`1[=ol0JcL00ol0JcL00ol0003o078]o`1b
;@02o`1b;@03o`000?l0N2;o07PR00;o07PR00?o0000o`1o5_l0OaH00_l0OaH00ol0003o08H7o`26
1`03o`261`03o`000?l8S@3o28d000;o28d000?o0000oaZD0?lJU0000olJU0000ol0003o;Y/0objK
0002objK0003o`000?m3XP3o@j8000?o@j8000?o0000oe^Y0?mKZ@000ol00005ogB`0003o`000?n?
^03oSkP000?oSkP000Co0000ojbo0?n/_`3o[;l03Ol000000oo=[P3o0000omFJ0004omFJ0003o`00
0?oLP`3og8<000?og8<000?o0000onAZ0?oTJP001?oTJP000ol0003ok500ona@0003ona@0003o`00
0?oc<`3olc<000;olc<000?o0000oo<c0?l000008Oooool00ol0003oooooooooo`0Xooooo`006Ooo
ool2o`0000kooooo1ol00002o`0A:`03o`000?l06C7o01Ta00?o01Ta00?o0000o`0R=ol08SL00_l0
8SL01Ol0003o02`no`0/?_l0;3ko000000Co03Q400?o0000o`15B_l0ADX00ol0ADX00ol0003o055=
o`1AC@02o`1AC@03o`000?l0Ed[o05M:00;o05M:00?o0000o`1NAOl0GTD00_l0GTD00ol0003o06@o
o`1T?`02o`1T?`04o`000?l0JcOo06/go`1[=d7o00000onZ_P000ol0003oa/80olK20003olK20004
o`000?o=[`3ocJl0olf_02?o00008Oooool00ol0003oooooooooo`0Wooooo`006?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?l02bGo00/U00;o00/U00Go0000o`0A:ol04B_o014[o`000005o`0I
<@03o`000?l08SOo028g00;o028g00Go0000o`0/?_l0;3ko02`no`000004o`0hA004o`000?l0AD[o
04E:o`15BQWo00000_l0JcP00ol0003o074^o`1a;P02o`1a;P03o`000?l0N2?o07PS00;o07PS00?o
0000o`1o5ol0OaL01?l0OaL00ol0003o08H8o`262002o`262003o`000?l7S03o1h`000;o1h`000?o
0000oaVC0?lIT`000olIT`000ol0003o;9X0obbJ0002obbJ00Co00000_m2XP000ol0003oFJP0oeVX
0003oeVX0003o`000?mb/03oL[0000;oL[0000?o0000ohfg0?n=]`000on=]`000ol0003oZ[h0ojZn
0003ojZn0003o`000?o6`P3oa/8000?oa/8000?o0000olf_0?o=[`000oo=[`000ol0003oe9/0omBK
0003omBK0003o`000?oLQ@3og8D000?og8D000?o0000on=/0?oSK0001?oSK0000ol0003oje80on]B
0003on]B0003o`000?ob=@3olSD000;olSD00_l0000Qooooo`;o00001oooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0001?ooooo000:ooooo`?o00000oooool3o`0000Gooooo00?o0000
ooooooooool04?ooool00ol0003o00/Uo`0;9@02o`0;9@05o`000?l04B_o014[o`0A:ol000000ol0
6C4Co`0000;o04A:00?o0000o`1@C_l0D4h00ol0D4h00ol0003o05M:o`1GBP02o`1GBP03o`000?l0
GDKo05e600;o05e600?o0000o`1T?ol0I3l00_l0I3l00ol0003o06/ho`1[>002o`1[>003o`000?l0
LBko074^00;o074^00?o0000o`1h8ol0N2<00_l0N2<00ol0003o07lGo`1o5`04o`1o5`03o`000?l0
QPSo08H800;o08H800?o0000o`N<0?l7S0000_l7S0000ol0003o6I<0oaVC0003oaVC0003o`000?l/
VP3o000000?o00001Om2XP000ol0003oFJP0oeVX0003oeVX0003o`000?mb/03oL[0000;oL[0000?o
0000ohfg0?n=]`000on=]`000ol0003oZ[h0ojZn0003ojZn0003o`000?o6`P3oa/8000?oa/8000?o
0000olf_0?o=[`000oo=[`000ol0003oe9/0omBK0003omBK0003o`000?oLQ@3og8D000?og8D000?o
0000on=/0?oSK0001?oSK0000ol0003oje80on]B0003on]B0007o`000?ob=@3olSD0oo8e0?l0003o
lSD0o`00000Qooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`0Booooo`002oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Aooooo`co00000ol063400ol0003o024go`0Q=`02o`0Q
=`03o`000?l0:cgo02/m00;o02/m00Go0000o`0g@ol0=d?o03M3o`000004o`14BP03o`000?l0D4ko
051>00?o051>00?o0000o`1GB_l0EdX00_l0EdX00ol0003o05e6o`1MAP02o`1MAP03o`000?l0I3oo
06@o00;o06@o00?o0000o`1[>?l0JcP00_l0JcP00ol0003o074^o`1a;P02o`1a;P03o`000?l0N2?o
07PS00;o07PS00Co0000o`1o5ol0OaOo07lGGol000000oob=@3o0000ooooo`0Pooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Booooo`000ooo
ool5o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01?ooooo00Go0000o`0:9?l02RCo00XTo`000004o`0@:P03o`000?l0637o01Pa00;o01Pa
00?o0000o`0Q=ol08CL00_l08CL00ol0003o02/mo`0[?@02o`0[?@05o`000?l0=d?o03M3o`0g@ol0
00001?l0A4X01?l0003o051>o`1@C_l0D4hSo`0000?o07hH00?o0000o`252Ol0Q@T00_l0Q@T00ol0
003o1X`0o`J<0002o`J<0003o`000?lGT`3o000000;o000000?o5i<0o`000?l[VP000ol[VP000ol0
003o@:40od2Q0003od2Q0003o`000?mGZ03oEjP000?oEjP000?o0000og2_0?m`[`000_m`[`000ol0
003oRkL0oh^g0003oh^g0003o`000?nX_P3oZ;h000?oZ;h000?o0000olG30?o5``000oo5``000ol0
003oc;40olba0003olba0003o`000?oDW03oe9`000?oe9`000?o0000om^60?oKQP000ooKQP000ol0
003ohfh0on=^0004on=^0003o`000?o[D`3oje<000?oje<000?o0000oo8g0?ob=`000_ob=`03o`00
023ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo01;ooooo000;ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l0000F
ooooo`05o`000?l02RCo00XTo`0:9?l000001?l042X00ol0003o01Pao`0H<@0Ho`0000;o051>00?o
0000o`1FBol0ET/00ol0ET/00ol0003o05e6o`1MAP02o`1MAP03o`000?l0Hd3o06=000;o06=000?o
0000o`1Z>?l0JSP00_l0JSP00ol0003o074_o`1a;`02o`1a;`03o`000?l0MbCo07LT00;o07LT00?o
0000o`1n6?l0OQP00ol0OQP00ol0003o08D9o`252@02o`252@03o`000?l6S03o1X`000?o00001OlG
T`000ol0003o:iX0ob^J0002ob^J0003o`000?m0X@3o@:4000?o@:4000?o0000oeNX0?mGZ0000omG
Z0000ol0003oL:l0og2_0002og2_0003o`000?n;]`3oRkL000?oRkL000?o0000ojRn0?nX_P000onX
_P000ol0003oaL<0olG30003olG30003o`000?o</@3oc;4000?oc;4000?o0000omBL0?oDW0000ooD
W0000ol0003ofhH0om^60003om^60003o`000?oSKP3ohfh000Cohfh000?o0000on]C0?o[D`000oo[
D`001ol0003olSL0oo8g0?ob=`3o0000oo8g0?l000008Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool04_ooool000_ooooo00Co0000oooooooo
oooooooo1?l00005ooooo`03o`000?oooooooooo01Gooooo2ol00003o`0G<003o`000?l083Ko020f
00;o020f00?o0000o`0Z??l0:S`00_l0:S`00ol0003o03I3o`0f@`02o`0f@`05o`000?l0@dWo04=9
o`13BOl000001?l0D4h00ol0003o05I;o`1FB`03o`1FB`03o`000?l0GDKo05e600;o05e600?o0000
o`1S@?l0Hd000_l0Hd000ol0003o06Xho`1Z>002o`1Z>003o`000?l0LBoo074_00;o074_00?o0000
o`1g9?l0Mb@00_l0Mb@00ol0003o07hHo`1n6003o`1n6004o`000?l0Q@Wo08D9o`252@?o00000ol6
S0000ol0003o5i<0oaNC0003oaNC0003o`000?l[VP3o:iX000;o:iX000?o0000od2Q0?m0X@000om0
X@000ol0003oEjP0oeNX0003oeNX0003o`000?m`[`3oL:l000;oL:l000?o0000oh^g0?n;]`000on;
]`000ol0003oZ;h0ojRn0003ojRn0003o`000?o5``3oaL<000?oaL<000?o0000olba0?o</@000oo<
/@000ol0003oe9`0omBL0003omBL0003o`000?oKQP3ofhH000?ofhH000?o0000on=^0?oSKP000ooS
KP000ol0003oje<0on]C0004on]C0007o`000?ob=`3olSL0oo8g0?l0003olSL0o`00000Oooooo`?o
00000oooool01?l0003oooooooooool00008ooooo`;o00005?ooool000[ooooo0_l00003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool00ol0003o00XTo`0:9002o`0:9005
o`000?l042[o010Zo`0@:_l000001?l05c000ol0003o020fo`0P=P02o`0P=P03o`000?l0:Sco02Xl
00;o02Xl00?o0000o`0f@ol0=T<00_l0=T<01Ol0003o04=9o`13BOl0@dWo000000Co051>00Co0000
o`1FBol0ET_o05I;Ool0000Pooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`03o`000?oo
oooooooo01;ooooo000;ooooo`04o`000?ooooooooooooooo`Go00000oooool00ol0003ooooooooo
o`0Hooooo`03o`000?l02RCo00XT00;o00XT00Go0000o`0@:_l042[o010Zo`000004o`0G<003o`00
0?l083Ko020f01So00000_l0ET/00ol0003o05a6o`1LAP02o`1LAP03o`000?l0Hd3o06=000?o06=0
00?o0000o`1Y>Ol0JCT00_l0JCT00ol0003o070_o`1`;`02o`1`;`03o`000?l0MbGo07LU00?o07LU
1?l000000ol0OQSo0000o`252P03o`252P03o`000?l5S03o1H`000?o1H`000?o0000oaJB0?lFTP00
0_lFTP000ol0003o:IT0obVI0002obVI0003o`000?lnX@3o?Z4000?o?Z4000?o0000oeJX0?mFZ000
0omFZ0000ol0003oKjl0ofn_0002ofn_0003o`000?n9]P3oRKH000?oRKH000?o0000ojJm0?nV_@00
0onV_@000ol0003oaL@0olG40003olG40003o`000?o</P3oc;8000?oc;8000?o0000om>N0?oCWP00
0ooCWP000ol0003ofhP0om^80003om^80003o`000?oRK`3ohVl000;ohVl000?o0000onYE0?oZE@00
1?oZE@000ol0003olST0oo8i0002oo8i00;o00008Oooool00ol0003oooooooooo`0Rooooo`005ooo
ool2o`0001[ooooo4?l00004o`0O=P05o`000?l0:Cco02Tlo`0Y??l000001?l0=D800ol0003o0499
o`12B@02o`12B@03o`000?l0Cdko04m>00;o04m>00Go0000o`1FBol0ET_o05I;o`000004o`1LAP03
o`000?l0Hd3o06=000?o06=000?o0000o`1Y>Ol0JCT00_l0JCT00ol0003o070_o`1`;`02o`1`;`03
o`000?l0MbGo07LU00Co00001?l0OQP00ol0003o08D:o`252P02o`252P03o`000?l5S03o1H`000?o
1H`000?o0000oaJB0?lFTP000_lFTP000ol0003o:IT0obVI0002obVI0003o`000?lnX@3o?Z4000?o
?Z4000?o0000oeJX0?mFZ0000omFZ0000ol0003oKjl0ofn_0002ofn_0003o`000?n9]P3oRKH000?o
RKH000?o0000ojJm0?nV_@000onV_@000ol0003oaL@0olG40003olG40003o`000?o</P3oc;8000?o
c;8000?o0000om>N0?oCWP000ooCWP000ol0003ofhP0om^80003om^80003o`000?oRK`3ohVl000;o
hVl000?o0000onYE0?oZE@001?oZE@001ol0003olST0oo8i0?ob>@3o0000oo8i0?l000008Oooool0
0ol0003oooooooooo`0Qooooo`005oooool00ol0003oooooooooo`0Jooooo`03o`000?l02B?o00TS
00;o00TS00Go0000o`0?:Ol03bWo00lYo`000004o`0G<003o`000?l07cKo01lf00?o01lf00Go0000
o`0Y??l0:Cco02Tlo`000004o`0e@P03o`000?l0@TWo049900;o049900?o0000o`1?C_l0Cdh00_l0
Cdh01Ol0003o05I;o`1FBol0ET_o000000Co05a600Co0000o`1S@?l0Hd3o06=0IOl000000ooRK`3o
0000onYE0005onYE0007o`000?ob>@3olST0oo8i0?l0003olST0o`00000Pooooo`03o`000?oooooo
oooo027ooooo000Gooooo`03o`000?oooooooooo01_ooooo00?o0000o`098ol02B<00_l02B<01Ol0
003o00lYo`0?:Ol03bWo000000Co01L`00Co0000o`0O=_l07cKo01lf8Ol00002o`1S@@03o`000?l0
JCWo06Ti00Co06Ti0ol00002o`1`<003o`000?l0MbGo07LU00;o07LU00?o0000o`1m6Ol0OAT00_l0
OAT00ol0003o08@;o`242`02o`242`03o`000?l4R`3o18/000?o18/000?o0000oaFB0?lETP000_lE
TP000ol0003o:9T0obRI0002obRI0003o`000?lmX03o?J0000?o?J0000?o0000oeBW0?mDY`000omD
Y`000ol0003oKJh0off^0002off^0003o`000?n8]P3oR;H000?oR;H000?o0000ojFm0?nU_@000_nU
_@000ol0003o`l@0ol?40003ol?40003o`000?o</`3oc;<000?oc;<000?o0000om>O0?oCW`000ooC
W`000ol0003ofXT0omZ90003omZ90004o`000?oRL@3ohW40on9a013o00007oooool2o`0002;ooooo
000Gooooo`03o`000?oooooooooo01cooooo4Ol00003o`0O=P05o`000?l0:Cco02Tlo`0Y??l00000
1?l0=4800ol0003o0458o`11B002o`11B003o`000?l0Cdko04m>00;o04m>00?o0000o`1EBol0ED/0
0_l0ED/00ol0003o05a7o`1LA`02o`1LA`05o`000?l0Hd7o06=1o`1S@Ol000000_l0JCT3o`000003
o`1Y>Ol0003o070`00?o070`00?o0000o`1g9Ol0MbD00_l0MbD00ol0003o07dIo`1m6@02o`1m6@03
o`000?l0Q0_o08@;00;o08@;00?o0000o`B;0?l4R`000ol4R`000ol0003o5I80oaFB0002oaFB0003
o`000?lXV@3o:9T000;o:9T000?o0000ocfP0?lmX0000olmX0000ol0003oE:L0oeBW0003oeBW0003
o`000?m][P3oKJh000;oKJh000?o0000ohRf0?n8]P000on8]P000ol0003oYKd0ojFm0002ojFm0003
o`000?o3a03o`l@000?o`l@000?o0000olbc0?o</`000oo</`000ol0003odil0om>O0003om>O0003
o`000?oJR@3ofXT000?ofXT000?o0000on9a0?oRL@000ooRL@000ol0003ojEH0onUF0003onUF0003
o`000?oa>P3olCX000;olCX00_l0000Qooooo`03o`000?oooooooooo01oooooo000Fooooo`;o0000
8?ooool01Ol0003o00TSo`098ol02B?o000000Co00lY00Go0000o`0F;ol05Roo01H_o`000005o`0O
=P05o`000?l0:Cco02Tlo`0Y??l000001?l0=4800ol0003o0458o`11B002o`11B003o`000?l0Cdko
04m>00;o04m>00?o0000o`1EBol0ED/00_l0ED/00ol0003o05a7o`1LA`02o`1LA`03o`000?l0Hd7o
06=100?o00000_l0JCU2o`000003ojFm0?l0003o`l@000Co`l@000?o0000olbc0?o</`000oo</`00
0ol0003odil0om>O0003om>O0003o`000?oJR@3ofXT000?ofXT000?o0000on9a0?oRL@000ooRL@00
0ol0003ojEH0onUF0003onUF0007o`000?oa>P3olCX0oo4j0?l0003olCX0o`00000Pooooo`03o`00
0?oooooooooo01oooooo000Fooooo`03o`000?oooooooooo023ooooo00Go0000o`098ol02B?o00TS
o`000004o`0?:@05o`000?l05Roo01H_o`0F;ol000000ol07cHVo`0000?o06Tj00?o0000o`1_<Ol0
Kc400_l0Kc400ol0003o07HVo`1f9P02o`1f9P03o`000?l0OA[o07dJ00;o07dJ00?o0000o`243?l0
Q0`00_l0Q0`00ol0003o0h/0o`>;0003o`>;0003o`000?lDTP3o598000;o598000?o0000obNI0?lW
V@000_lWV@000ol0003o?:00ocbP0003ocbP0003o`000?mCY`3oDjL000?oDjL000?o0000ofb^0?m/
[P000_m/[P000ol0003oQkD0ohNe0003ohNe0004o`000?nS_03oXk`0oj>l02_o000000?olCX0o`00
0?ooool07oooool00ol0003oooooooooo`0Nooooo`005_ooool00ol0003oooooooooo`0Qoooooa3o
00000_l07SD00ol0003o02Pko`0X>`03o`0X>`05o`000?l0=4;o03A2o`0d@_l000001?l0@DP00ol0
003o04m>o`1?CP02o`1?CP03o`000?l0ED_o05E;00;o05E;0ol00002o`1KA`03o`000?l0HT7o0691
00;o069100?o0000o`1Y>_l0JCX00_l0JCX00ol0003o06lao`1_<@02o`1_<@03o`000?l0MRKo07HV
00;o07HV00?o0000o`1m6_l0OAX00_l0OAX00ol0003o08@<o`243002o`243003o`000?l3R`3o0h/0
00?o0h/000?o0000oaBB0?lDTP000_lDTP000ol0003o9iT0obNI0002obNI0003o`000?llX03o?:00
00?o?:0000?o0000oe>W0?mCY`000omCY`000ol0003oK:h0ofb^0002ofb^0003o`000?n7]@3oQkD0
00?oQkD000?o0000oj>l0?nS_0000onS_0000ol0003o`/@0ol;40002ol;40003o`000?o;]03obk@0
00?obk@000?o0000om>P0?oCX0000ooCX0000ol0003ofXX0omZ:0004omZ:0003o`000?oRLP3ohW80
00;ohW8000?o0000onUH0?oYF0000ooYF0000ol0003olC/0oo4k0002oo4k00?o00008?ooool00ol0
003oooooooooo`0Mooooo`005_ooool00ol0003oooooooooo`0Rooooo`05o`000?l02B?o00TSo`09
8ol000001?l03bT01Ol0003o01H_o`0F;ol05Roo000000Co01he00?o0000o`0X>ol0:3/00ol0:3/0
1Ol0003o03A2o`0d@_l0=4;o000000Co045800?o0000o`1?C_l0Cdh00_l0Cdh4o`000003o`1EBol0
003o05]700?o05]700?o0000o`1R@Ol0HT400_l0HT400ol0003o06Tjo`1Y>P02o`1Y>P03o`000?l0
Kc7o06la00;o06la00?o0000o`1f9_l0MRH00_l0MRH00ol0003o07dJo`1m6P02o`1m6P03o`000?l0
Q0co08@<00;o08@<00?o0000o`>;0?l3R`000ol3R`000ol0003o5980oaBB0002oaBB0003o`000?lW
V@3o9iT000;o9iT000?o0000ocbP0?llX0000ollX0000ol0003oDjL0oe>W0002oe>W0003o`000?m/
[P3oK:h000?oK:h000?o0000ohNe0?n7]@000on7]@000ol0003oXk`0oj>l0003oj>l0003o`000?o2
a03o`/@000;o`/@000?o0000ol^d0?o;]0000oo;]0000ol0003odj00om>P0003om>P0003o`000?oJ
RP3ofXX000CofXX000?o0000on9b0?oRLP000_oRLP000ol0003ojEP0onUH0003onUH0007o`000?oa
>`3olC/0oo4k0?l0003olC/0o`00000Oooooo`;o00007oooool001Kooooo00?o0000ooooooooool0
8oooool01Ol0003o00TSo`098ol02B?o000000Co00lY00Go0000o`0F;ol05Roo01H_o`000004o`0N
=@04o`000?l0:3_o02Pko`0X>h7o000000?ohW80o`000?oYF0001?oYF0001ol0003olC/0oo4k0?oa
>`3o0000oo4k0?l000008?ooool00ol0003oooooooooo`0Looooo`005Oooool2o`0002Kooooo5Ol0
0003o`0X>`03o`000?l0<d7o03=100;o03=100?o0000o`10B?l0@4P00ol00003o`1>CP03o`000?l0
EDco05E<00;o05E<00?o0000o`1KAol0FdL00_l0FdL00ol0003o0691o`1R@@02o`1R@@03o`000?l0
J3[o06Pj00;o06Pj00?o0000o`1_<Ol0Kc400_l0Kc400ol0003o07HVo`1f9P02o`1f9P03o`000?l0
OA[o07dJ00;o07dJ00?o0000o`243Ol0Q0d00_l0Q0d00ol0003o0X/0o`:;0002o`:;0003o`000?lC
T@3o4i4000?o4i4000?o0000obJH0?lVV0000_lVV0000ol0003o>il0oc^O0003oc^O0003o`000?mB
Y`3oDZL000;oDZL000?o0000of^^0?m[[P000om[[P000ol0003oQKD0ohFe0003ohFe0003o`000?nR
_03oX[`000;oX[`000?o0000ol740?o1a0000oo1a0000ol0003obk@0ol^d0002ol^d0003o`000?oB
X@3odZ4000?odZ4000?o0000omZ;0?oJR`001?oJR`001?l0003ohG<0on5c0?oQL`0?o`0001oooooo
00?o0000ooooooooool07?ooool001Gooooo00?o0000ooooooooool09_ooool00ol0003o00PRo`08
8P02o`088P05o`000?l03RSo00hXo`0>:?l000001?l05Bl01Ol0003o01heo`0N=Ol07SGo000000Go
02Pk00Co0000o`0c@Ol0<d7o03=10ol00002o`10B003o`000?l0CTko04i>00;o04i>00?o0000o`1E
C?l0ED`00_l0ED`00ol0003o05]7o`1KA`02o`1KA`03o`000?l0HT7o069100;o069100?o0000o`1X
>_l0J3X00_l0J3X00ol0003o06lao`1_<@02o`1_<@03o`000?l0MRKo07HV00;o07HV00?o0000o`1m
6_l0OAX00_l0OAX00ol0003o08@=o`243@02o`243@03o`000?l2R`3o0X/000;o0X/000?o0000oa>A
0?lCT@000olCT@000ol0003o9YP0obJH0002obJH0003o`000?lkW`3o>il000?o>il000?o0000oe:W
0?mBY`000_mBY`000ol0003oJjh0of^^0003of^^0003o`000?n5]@3oQKD000?oQKD000?o0000oj:l
0?nR_0000_nR_0000ol0003o`L@0ol740003ol740003o`000?o;]03obk@000;obk@000?o0000om:Q
0?oBX@000ooBX@000ol0003ofX/0omZ;0004omZ;0003o`000?oQL`3ohG<000;ohG<000?o0000onUI
0?oYF@001?oYF@001?l0003olC`0oo4l0?oa?002o`00023ooooo00?o0000ooooooooool06oooool0
01Gooooo00?o0000ooooooooool09oooool00ol0003o00PRo`088P02o`088P05o`000?l03RSo00hX
o`0>:?l000001?l05Bl01Ol0003o01heo`0N=Ol07SGo000000?o02PkK_l000000oo;]03o0000om:Q
0004om:Q0003o`000?oJR`3ofX/000?ofX/000?o0000on5c0?oQL`000ooQL`000ol0003ojET0onUI
0004onUI0006o`000?oa?03olC`0o`000?oa?03o00007oooool2o`0001cooooo000Eooooo`03o`00
0?oooooooooo02Sooooo5ol000000ol09c_o0000o`0c@@03o`0c@@05o`000?l0?dOo03m7o`0oAol0
00001?l0CTh00ol0003o05A<o`1DC002o`1DC003o`000?l0FdOo05]700;o05]700?o0000o`1R@_l0
HT800_l0HT800ol0003o06Pjo`1X>P02o`1X>P03o`000?l0Kc7o06la00;o06la00?o0000o`1f9ol0
MRL00_l0MRL00ol0003o07`Ko`1l6`02o`1l6`03o`000?l0P`go08<=00;o08<=00?o0000o`::0?l2
RP000_l2RP000ol0003o4i40oa>A0003oa>A0003o`000?lVV03o9YP000;o9YP000?o0000oc^O0?lk
W`000olkW`000ol0003oDJH0oe6V0002oe6V0003o`000?mZ[P3oJZh000?oJZh000?o0000ohFe0?n5
]@000_n5]@000ol0003oXK`0oj6l0002oj6l0003o`000?o0``3o`<<000?o`<<000Co0000ol^e0?o;
]@3obkD07ol000000ooa?03o0000ooooo`0Nooooo`03o`000?oooooooooo01[ooooo000Eooooo`;o
0000:_ooool00ol0003o00PRo`088P02o`088P05o`000?l03RSo00hXo`0>:?l000001?l05Bh00ol0
003o01ddo`000003o`0000Co02Lk00?o0000o`0c@Ol0<d400_l0<d401Ol0003o03m7o`0oAol0?dOo
000000Co04i>00?o0000o`1DC?l0E4`00_l0E4`00ol0003o05]7o`1KA`02o`1KA`03o`000?l0HT;o
069200;o069200?o0000o`1X>_l0J3X00_l0J3X00ol0003o06lao`1_<@02o`1_<@03o`000?l0MROo
07HW00;o07HW00?o0000o`1l6ol0O1/00_l0O1/00ol0003o08<=o`233@02o`233@03o`000?l2RP3o
0XX000;o0XX000?o0000oa>A0?lCT@000olCT@000ol0003o9YP0obJH0002obJH0003o`000?lkW`3o
>il000?o>il000?o0000oe6V0?mAYP000_mAYP000ol0003oJZh0ofZ^0003ofZ^0003o`000?n5]@3o
QKD000;oQKD000?o0000oj6l0?nQ_0000_nQ_0000ol0003o`<<0ol330003ol330003o`000?o;]@3o
bkD000?obkD000?o0000om:Q0?oBX@000ooBX@000ol0003ofX`0omZ<0003omZ<0003o`000?oQL`3o
hG<000;ohG<000?o0000onUI0?oYF@001?oYF@001?l0003ol3d0oo0m0?o`?@03o`0001oooooo00?o
0000ooooooooool06Oooool000Oooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0Z
ooooo`03o`000?l022;o00PR00;o00PR00Go0000o`0>:?l03RSo00hXo`000002o`0E;P?o00000_l0
7CAWo`000003oj6l0?l0003o`<<000Co`<<000?o0000ol^e0?o;]@000oo;]@000ol0003odZ40om:Q
0003om:Q0003o`000?oJS03ofX`000?ofX`000?o0000on5c0?oQL`000_oQL`000ol0003ojET0onUI
0004onUI0004o`000?o`?@3ol3d0oo0m00;o00008?ooool00ol0003oooooooooo`0Hooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
:oooool@o`0000?o01dd00?o0000o`0W>ol09c/00_l09c/00ol0003o0391o`0b@@02o`0b@@05o`00
0?l0?dOo03m7o`0oAol000001?l0CDh00ol0003o05A<o`1DC002o`1DC003o`000?l0FdOo05]700;o
05]700?o0000o`1Q@_l0HD800_l0HD800ol0003o06Pjo`1X>P02o`1X>P03o`000?l0Kc;o06lb00;o
06lb00?o0000o`1f9ol0MRL00_l0MRL00ol0003o07`Ko`1l6`02o`1l6`03o`000?l0P`go08<=00;o
08<=00?o0000o`6:0?l1RP000_l1RP000ol0003o4Y40oa:A0003oa:A0003o`000?lUV03o9IP000;o
9IP000?o0000ocZO0?ljW`000_ljW`000ol0003oDJH0oe6V0002oe6V0003o`000?mY[@3oJJd000?o
JJd000?o0000ohBd0?n4]0000_n4]0001?l0003oXK`0oj6l0?nQ_00No`000003on5c0?l0003ojET0
00CojET000Oo0000oo0m0?o`?@3ol3d0o`000?o`?@3o000001oooooo00?o0000ooooooooool01ooo
ool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`001Ol00003ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0^ooooo`04o`00
0?l022;o00PRo`088P?o000000?o00hXo`000?l05Bh00ol05Bh00ol0003o01ddo`0M=002o`0M=003
o`000?l09c_o02Lk00;o02Lk00?o0000o`0b@Ol0<T400_l0<T401Ol0003o03m7o`0oAol0?dOo0000
00Co04e>00?o0000o`1DC?l0E4`00_l0E4`00ol0003o05]7o`1KA`02o`1KA`03o`000?l0HD;o0652
00;o065200?o0000o`1X>_l0J3X00_l0J3X00ol0003o06lbo`1_<P02o`1_<P03o`000?l0MROo07HW
00;o07HW00?o0000o`1l6ol0O1/00_l0O1/00ol0003o08<=o`233@02o`233@03o`000?l1RP3o0HX0
00;o0HX000?o0000oa:A0?lBT@000olBT@000ol0003o9IP0obFH0002obFH0003o`000?ljW`3o>Yl0
00;o>Yl000?o0000oe6V0?mAYP000_mAYP000ol0003oJJd0ofV]0003ofV]0003o`000?n4]03oQ;@0
00;oQ;@000?o0000oj6l0?nQ_0000onQ_0000ol0003o_l<0oko30003oko30003o`000?o;]P3obkH0
00?obkH000?o0000om:R0?oBXP000_oBXP000ol0003ofH`0omV<0003omV<0004o`000?oQM03ohG@0
on5d00oo00007_ooool2o`0000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00002ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0;oooool3o`000003o`088_l0003o00hX00;o00hX00?o0000o`0E;_l05Bh0
0_l05Bh00ol0003o01ddo`0M=01Fo`000003oe6V0?l0003oJJd000?oJJd000?o0000ohBd0?n4]000
0on4]0000ol0003oXK`0oj6l0003oj6l0003o`000?no``3o_l<000?o_l<000?o0000ol^f0?o;]P00
0oo;]P000ol0003odZ80om:R0002om:R0003o`000?oIS03ofH`000?ofH`000?o0000on5d0?oQM000
0ooQM0000ol0003oj5X0onQJ0003onQJ0004o`000?o`?P3ol3h0oo0n00;o00008?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool000So
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`;o0000;Oooool3o`00
0003ooooool0003o000000go00000ol07C@00ol0003o02Lko`0W>`02o`0W>`03o`000?l0<T7o0391
00;o039100Go0000o`0oAol0?dOo03m7o`000004o`1=CP03o`000?l0E4co05A<00;o05A<00?o0000
o`1KAol0FdL00_l0FdL00ol0003o0652o`1Q@P02o`1Q@P03o`000?l0J3_o06Pk00;o06Pk00?o0000
o`1_<_l0Kc800_l0Kc800ol0003o07DWo`1e9`02o`1e9`03o`000?l0O1_o07`K00;o07`K00?o0000
o`233_l0P`h00_l0P`h00ol0003o0HX0o`6:0002o`6:0003o`000?lBT@3o4Y4000;o4Y4000?o0000
obFH0?lUV0000olUV0001Ol0003o>Yl0ocZO0?ljW`3o000000?oD:H09?l00005omV<0003o`000?oQ
M03ohG@000CohG@000?o0000onQJ0?oXFP000ooXFP001?l0003ol3h0oo0n0?o`?P02o`0001oooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo007o
oooo0007ooooo`;o00001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo02Wo
oooo0ol00005ooooo`05o`000?l022;o00PRo`088_l000000ol03RP00ol0003o01D^o`0E;P03o`0E
;P05o`000?l07CCo01ddo`0M=?l000001?l09c/00ol0003o0391o`0b@@02o`0b@@05o`000?l0?dOo
03m7o`0oAol000001?l0CDh00ol0003o05A<o`1DC002o`1DC003o`000?l0FdOo05]700;o05]700?o
0000o`1Q@_l0HD800_l0HD800ol0003o06Pko`1X>`02o`1X>`03o`000?l0Kc;o06lb00;o06lb00?o
0000o`1e9ol0MBL00_l0MBL00ol0003o07`Ko`1l6`02o`1l6`03o`000?l0P`ko08<>00;o08<>00?o
0000o`6:0?l1RP000_l1RP000ol0003o4Y40oa:A0002oa:A0003o`000?lUV03o9IP000?o9IP000Go
0000ocZO0?ljW`3o>Yl0o`000005oe2V0003o`000?mY[@3oJJd000;oJJd000?o0000oh>d0?n3]000
0on3]0000ol0003oX;`0oj2l0003oj2l0003o`000?nn``3o_/<000;o_/<000?o0000ol^f0?o;]P00
0oo;]P001?l0003odZ80om:R0?oBXP0Ho`000003oo0n0?l0003ooooo01kooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000_ooool0
00Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool09_ooool3o`00
00Wooooo00Go0000o`088_l022;o00PRo`000003o`0>:004o`000?l05Bko01D^o`0E;UKo00001Om@
YP000ol0003oJJd0ofV]0002ofV]0003o`000?n3]03oPk@000?oPk@000?o0000oj2l0?nP_0000onP
_0000ol0003o_/<0okk30002okk30003o`000?o;]P3obkH000?obkH000?o0000om:R0?oBXP000_oB
XP000ol0003ofH`0omV<0003omV<0003o`000?oQM03ohG@000?ohG@000?o0000onQK0?oXF`000ooX
F`001?l0003ol3h0oo0n0?o`?P03o`0001gooooo0ol00004ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000002ooooo`005?ooool00ol0003oooooooooo`0Sooooo`?o
00003Oooool;o`0000?o01@^00Go0000o`0M=?l07CCo01ddo`000004o`0W>P03o`000?l0<T7o0391
00;o039100Go0000o`0nAol0?TOo03i7o`000004o`1=CP03o`000?l0E4co05A<00;o05A<00?o0000
o`1KB?l0FdP00_l0FdP00ol0003o0652o`1Q@P02o`1Q@P05o`000?l0J3_o06Pko`1X>ol000001?l0
Kc800ol0003o07DWo`1e9`02o`1e9`03o`000?l0O1_o07`K00?o07`K00?o0000o`233_l0P`h00_l0
P`h00ol0003o0HX0o`6:0002o`6:0003o`000?lBT@3o4Y4000;o4Y4000?o0000obFH0?lUV0000_lU
V0001?l0003o>Yl0ocZO0?ljW`0Qo`000003ol^f0?l0003odZ8000CodZ8000?o0000omV<0?oIS000
0ooIS0000ol0003ohG@0on5d0003on5d0003o`000?oXF`3oj5/000?oj5/000Co0000oo0n0?o`?P3o
l3h00_l0000Jooooo`?o000000?oooooo`000?l000001Oooool2o`0000Wooooo0ol00003ooooo`00
4oooool2o`0002?ooooo0_l0000Aooooo`05o`000?l022;o00PRo`088_l000001?l03RP00ol0003o
01@^o`0D;P02o`0D;P05o`000?l07CCo01ddo`0M=?l000001?l09cX00ol0003o0391o`0b@@02o`0b
@@05o`000?l0?TOo03i7o`0nAol000001?l0CDh00ol0003o05A<o`1DC002o`1DC003o`000?l0FdSo
05]800;o05]800?o0000o`1Q@_l0HD800_l0HD801Ol0003o06Pko`1X>ol0J3_o000000Co06lb00?o
0000o`1e9ol0MBL00_l0MBL00ol0003o07`Ko`1l6`03o`1l6`03o`000?l0P`ko08<>00;o08<>00?o
0000o`6:0?l1RP000_l1RP000ol0003o4Y40oa:A0002oa:A0003o`000?lUV03o9IP000;o9IP000?o
0000ocZO0?ljW`000_ljW`000ol0003oD:H0oe2V0002oe2V0003o`000?mY[@3oJJd000?oJJd000?o
0000oh>d0?n3]0000on3]0000ol0003oWk`0oinl0002oinl0003o`000?nn``3o_/<000;o_/<000Co
0000olZf0?o:]P3ob[H06?l000000ooXF`3o0000oo0n0002oo0n0003o`000?o`?P3o000001Kooooo
0ol00005ooooo`03o`000?oooooooooo01Cooooo000Cooooo`03o`000?oooooooooo01oooooo0ol0
000Dooooo`05o`000?l022;o00PRo`088_l000000_l03RQDo`000003obFH0?l0003o>Yl000?o>Yl0
00?o0000oe2V0?m@YP000_m@YP000ol0003oJJd0ofV]0003ofV]0003o`000?n3]03oPk@000?oPk@0
00?o0000oinl0?nO_0000_nO_0000ol0003o_/<0okk30002okk30003o`000?o:]P3ob[H000?ob[H0
00?o0000om:R0?oBXP000ooBXP000ol0003ofHd0omV=0003omV=0003o`000?oQM@3ohGD000;ohGD0
00Co0000onQK0?oXF`3oj5/02Ol0000Booooo`?o00002?ooool00ol0003oooooooooo`0Dooooo`00
4oooool00ol0003oooooooooo`0Looooo`?o00006?ooool6o`0000?o00hX00?o0000o`0D;_l052h0
0_l052h01Ol0003o01ddo`0M=?l07CCo000000Co02Lj00?o0000o`0b@Ol0<T400_l0<T401Ol0003o
03i7o`0nAol0?TOo000000Co04e>00?o0000o`1DC?l0E4`00_l0E4`00ol0003o05]8o`1KB002o`1K
B005o`000?l0HD;o0652o`1Q@_l000001?l0J3/00ol0003o06lbo`1_<P02o`1_<P03o`000?l0MBOo
07DW00;o07DW00?o0000o`1l6ol0O1/00_l0O1/00ol0003o08<>o`233P02o`233P03o`000?l1RP3o
0HX000?o0HX000Go0000oa:A0?lBT@3o4Y40o`000003obFH027o000000?o_/<0o`000?o:]P001?o:
]P000ol0003odZ80om:R0003om:R0003o`000?oIS@3ofHd000?ofHd000?o0000on5e0?oQM@000_oQ
M@000ol0003oj5/0onQK0003onQK0007o`000?o`?`3ol3l0oo0o0?l0003ol3l0o`00000=ooooo`Co
00002oooool00ol0003oooooooooo`0Dooooo`004oooool00ol0003oooooooooo`0Iooooo`?o0000
7Oooool01Ol0003o00PRo`088_l022;o000000?o00hX00?o0000o`0D;_l052h00_l052h01Ol0003o
01ddo`0M=?l07CCo000000Co02Lj00?o0000o`0b@Ol0<T400_l0<T401Ol0003o03i7o`0nAol0?TOo
000000Co04e>00?o0000o`1DC?l0E4`00_l0E4`00ol0003o05]8o`1KB002o`1KB005o`000?l0HD;o
0652o`1Q@_l000001?l0J3/00ol0003o06lbo`1_<P02o`1_<P03o`000?l0MBOo07DW00;o07DW00?o
0000o`1l6ol0O1/00_l0O1/00ol0003o08<>o`233P02o`233P03o`000?l1RP3o0HX000?o0HX000Go
0000oa:A0?lBT@3o4Y40o`000004obFH0003o`000?liW`3o>Il000?o>Il000?o0000oe2V0?m@YP00
0_m@YP000ol0003oJ:d0ofR]0003ofR]0003o`000?n3]03oPk@000;oPk@000?o0000oinl0?nO_000
0_nO_0001?l0003o_/<0okk30?nn``0Ho`000003on5e0?l0003oj5/000Coj5/000Oo0000oo0o0?o`
?`3ol3l0o`000?o`?`3o000000Wooooo0ol0000@ooooo`03o`000?oooooooooo01?ooooo000Coooo
o`03o`000?oooooooooo01Kooooo0ol0000QoooooeKo00001?lUV0000ol0003o>Il0ocVO0003ocVO
0003o`000?m@YP3oD:H000;oD:H000?o0000ofR]0?mX[@000omX[@000ol0003oPk@0oh>d0002oh>d
0003o`000?nO_03oWk`000;oWk`000?o0000okk30?nn``000_nn``000ol0003ob[H0olZf0003olZf
0003o`000?oBX`3odZ<000?odZ<000?o0000omV=0?oIS@000ooIS@001?l0003ohGD0on5e0?oQM@0?
o`0000Gooooo0ol0000Cooooo`03o`000?oooooooooo01?ooooo000Cooooo`03o`000?oooooooooo
01?ooooo0ol0000Uooooo`05o`000?l022;o00PRo`088_l000000ol03RP00ol0003o01@^o`0D;P02
o`0D;P05o`000?l07CCo01ddo`0M=?l000001?l09cX00ol0003o0391o`0b@@02o`0b@@05o`000?l0
?TOo03i7o`0nAol000001?l0CDh00ol0003o05A<o`1DC002o`1DC005o`000?l0FdSo05]8o`1KB?l0
00001?l0HD800ol0003o06Pko`1X>`02o`1X>`03o`000?l0Kc;o06lb00;o06lb00?o0000o`1e9ol0
MBL00_l0MBL00ol0003o07`Ko`1l6`02o`1l6`03o`000?l0P`ko08<>00;o08<>00?o0000o`6:0?l1
RP000_l1RP001?l0003o4Y40oa:A0?lBT@0Po`000003oinl0?l0003o_/<000?o_/<000?o0000olZf
0?o:]P000oo:]P000ol0003odZ<0om:S0003om:S0003o`000?oIS@3ofHd000?ofHd000?o0000on5e
0?oQM@000_oQM@000ol0003oj5/0onQK0003onQK0008o`000?o`?`3ol3l0oo0o0?l0003ol3l0o`00
0?ooool4o`0001Kooooo00?o0000ooooooooool04oooool001;ooooo00?o0000ooooooooool04Ooo
ool3o`0002Wooooo00Go0000o`088_l022;o00PRo`000003o`0>:003o`000?l052ko01@^00;o01@^
00Go0000o`0M=?l07CCo01ddo`000004o`0W>P03o`000?l0<T7o039100;o039100Go0000o`0nAol0
?TOo03i7o`000004o`1=CP03o`000?l0E4co05A<00;o05A<00Go0000o`1KB?l0FdSo05]8o`000004
o`1Q@P03o`000?l0J3_o06Pk00;o06Pk00?o0000o`1_<_l0Kc800_l0Kc800ol0003o07DWo`1e9`02
o`1e9`03o`000?l0O1_o07`K00;o07`K00?o0000o`233_l0P`h00_l0P`h00ol0003o0HX0o`6:0002
o`6:0003o`000?lBT@3o4Y4000;o4Y4000?o0000obFH0?lUV0000_lUV0000ol0003o>Yl0ocZO0002
ocZO0003o`000?m@YP3oD:H000?oD:H000?o0000ofV]0?mY[@000_mY[@000ol0003oPk@0oh>d0002
oh>d0004o`000?nO_03oWk`0oinl01Oo000000?ofHd0o`000?oQM@001?oQM@000ol0003oj5/0onQK
0003onQK0007o`000?o`?`3ol3l0oo0o0?l0003ol3l0o`00000Jooooo`03o`000?oooooooooo01?o
oooo000Booooo`03o`000?oooooooooo00oooooo0_l0000]oooooe3o00001OlBT@000ol0003o9IP0
obFH0002obFH0003o`000?ljW`3o>Yl000;o>Yl000?o0000oe2V0?m@YP000om@YP000ol0003oJJd0
ofV]0002ofV]0003o`000?n3]03oPk@000;oPk@000?o0000oinl0?nO_0000_nO_0000ol0003o_/<0
okk30003okk30003o`000?o:]P3ob[H000?ob[H000?o0000om:R0?oBXP000_oBXP001?l0003ofHd0
omV=0?oIS@0Do`0001[ooooo00?o0000ooooooooool04oooool001;ooooo00?o0000ooooooooool0
3?ooool3o`00033ooooo00Go0000o`088_l022;o00PRo`000003o`0>:003o`000?l05Bko01D^00;o
01D^00Go0000o`0M=?l07CCo01ddo`000004o`0W>`05o`000?l0<T7o0391o`0b@Ol000001?l0?dL0
0ol0003o04e>o`1=CP02o`1=CP05o`000?l0E4co05A<o`1DC?l000001?l0FdL00ol0003o0652o`1Q
@P02o`1Q@P03o`000?l0J3_o06Pk00;o06Pk00?o0000o`1_<_l0Kc800_l0Kc800ol0003o07DWo`1e
9`02o`1e9`03o`000?l0O1_o07`K00;o07`K00?o0000o`233_l0P`h00_l0P`h00ol0003o0HX0o`6:
000Po`000003oh>d0?l0003oWk`000?oWk`000?o0000okk30?nn``000onn``000ol0003ob[H0olZf
0003olZf0003o`000?oBXP3odZ8000;odZ8000?o0000omV=0?oIS@000ooIS@000ol0003ohGD0on5e
0003on5e0003o`000?oXF`3oj5/000;oj5/000Co0000oo0o0?o`?`3ol3l00ol0000Iooooo`03o`00
0?oooooooooo01?ooooo000Booooo`;o00002_ooool3o`0003Cooooo00Go0000o`088_l022;o00PR
o`000003o`0>:003o`000?l05Bko01D^00;o01D^00Go0000o`0M=?l07CCo01ddo`000004o`0W>`05
o`000?l0<T7o0391o`0b@Ol000001?l0?dL00ol0003o04e>o`1=CP02o`1=CP05o`000?l0E4co05A<
o`1DC?l000001?l0FdL00ol0003o0652o`1Q@P02o`1Q@P03o`000?l0J3_o06Pk00;o06Pk00?o0000
o`1_<_l0Kc800_l0Kc800ol0003o07DWo`1e9`02o`1e9`03o`000?l0O1_o07`K00;o07`K00?o0000
o`233_l0P`h00_l0P`h01Ol0003o0HX0o`6:0?l1RP3o000000Co4Y4000?o0000obFH0?lUV0000olU
V0000ol0003o>Yl0ocZO0002ocZO0003o`000?m@YP3oD:H000;oD:H000?o0000ofV]0?mY[@000omY
[@000ol0003oPk@0oh>d000Go`000003om:R0?l0003ofHd000CofHd000?o0000on5e0?oQM@000ooQ
M@000ol0003oj5/0onQK0002onQK0007o`000?o`?`3ol3l0oo0o0?l0003ol3l0o`00000Hooooo`03
o`000?oooooooooo01?ooooo000Booooo`03o`000?oooooooooo00Kooooo0ol0000hoooooe3o0000
1?lBT@000ol0003o9IP0obFH0003obFH0003o`000?ljW`3o>Yl000;o>Yl000?o0000oe2V0?m@YP00
0_m@YP000ol0003oJJd0ofV]0003ofV]0005o`000?n3]03oPk@0oh>d0?l000001OnP_0000ol0003o
_/<0okk30003okk30003o`000?o;]P3obkH000;obkH000Co0000om:R0?oBXP3odZ804_l000000ooX
F`3o0000oo0o0002oo0o0003o`000?o`?`3o000001Sooooo00?o0000ooooooooool04_ooool001;o
oooo00?o0000ooooooooool00oooool3o`0003cooooo00Go0000o`088_l022;o00PRo`000003o`0>
:003o`000?l05Bko01D^00;o01D^00Go0000o`0M=?l07CCo01ddo`000004o`0W>`05o`000?l0<T7o
0391o`0b@Ol000001?l0?dL01Ol0003o04e>o`1=C_l0CDko000000Co05A<00?o0000o`1KAol0FdL0
0_l0FdL00ol0003o0652o`1Q@P02o`1Q@P03o`000?l0J3[o06Pj00;o06Pj00?o0000o`1_<_l0Kc80
0_l0Kc801Ol0003o07HWo`1f9ol0MROo000000Go07`K00?o0000o`233Ol0P`d00_l0P`d00ol0003o
0HX0o`6:000Qo`0000GoX;`000?o0000okk30?nn``000onn``000ol0003obkH0ol^f0002ol^f0003
o`000?oBXP3odZ8000;odZ8000?o0000omV<0?oIS0000ooIS0000ol0003ohG@0on5d0003on5d0004
o`000?oXF`3oj5/0onQK00Wo00005oooool00ol0003oooooooooo`0Booooo`004Oooool01?l0003o
ooooooooooooool3o`00043ooooo00Go0000o`088_l022;o00PRo`000003o`0>:003o`000?l05Bko
01D^00;o01D^00Go0000o`0M=?l07CCo01ddo`000004o`0W>`05o`000?l0<T7o0391o`0b@Ol00000
1?l0?dL01Ol0003o04e>o`1=C_l0CDko000000Co05A<00?o0000o`1KAol0FdL00_l0FdL00ol0003o
0652o`1Q@P02o`1Q@P03o`000?l0J3[o06Pj00;o06Pj00?o0000o`1_<_l0Kc800_l0Kc801Ol0003o
07HWo`1f9ol0MROo000000Go07`K00?o0000o`233Ol0P`d00_l0P`d01Ol0003o0HX0o`6:0?l1RP3o
000000Co4Y4000?o0000obFH0?lUV0000_lUV0000ol0003o>Yl0ocZO0002ocZO0003o`000?mAYP3o
DJH000?oDJH000?o0000ofV]0?mY[@000_mY[@001?l0003oQ;@0ohBd0?n4]00Bo`0000GodZ8000?o
0000omV<0?oIS0000ooIS0000ol0003ohG@0on5d0003on5d0003o`000?oXF`3oj5/000;oj5/000Oo
0000oo0n0?o`?P3ol3h0o`000?o`?P3o000001Oooooo00?o0000ooooooooool04_ooool0017ooooo
1?l00014oooooe3o00001?lBT@000ol0003o9IP0obFH0002obFH0003o`000?ljW`3o>Yl000;o>Yl0
00?o0000oe6V0?mAYP000omAYP000ol0003oJJd0ofV]0002ofV]0003o`000?n4]03oQ;@000;oQ;@0
00?o0000oj6l0?nQ_0000_nQ_0000ol0003o_l<0oko30003oko30004o`000?o;]P3obkH0ol^f01Oo
000000?oj5/0o`000?o`?P000_o`?P000ol0003ol3h0o`00000Fooooo`03o`000?oooooooooo01;o
oooo000Aooooo`;o0000Aoooool00ol0003o00PRo`088P02o`088P05o`000?l03RSo00hXo`0>:?l0
00001?l05Bh01Ol0003o01ddo`0M=?l07CCo000000?o02Lk00?o0000o`0c@Ol0<d400_l0<d400ol0
003o03m7o`0oA`02o`0oA`05o`000?l0CTko04i>o`1>C_l000000ol0E4`00ol0003o05]7o`1KA`02
o`1KA`05o`000?l0HT;o0692o`1R@_l000001?l0J3X00ol0003o06lao`1_<@02o`1_<@03o`000?l0
MROo07HW00;o07HW00?o0000o`1l6ol0O1/00_l0O1/00ol0003o08<=o`233@02o`233@04o`000?l2
RP3o0XX0o`::01_o00001On4]0000ol0003oXK`0oj6l0002oj6l0003o`000?no``3o_l<000?o_l<0
00?o0000ol^f0?o;]P000_o;]P000ol0003odZ80om:R0003om:R0003o`000?oIS03ofH`000;ofH`0
00?o0000on5d0?oQM0000ooQM0001?l0003oj5X0onQJ0?oXFP09o`0001Gooooo00?o0000oooooooo
ool04_ooool001?ooooo00?o0000ooooooooool0AOoooolYo`0000Co05]700Go0000o`1R@_l0HT;o
0692o`000004o`1X>P03o`000?l0Kc7o06la00;o06la00?o0000o`1f9ol0MRL00_l0MRL00ol0003o
07`Ko`1l6`02o`1l6`03o`000?l0P`go08<=00;o08<=00Go0000o`::0?l2RP3o0XX0o`000005oa>A
0003o`000?lVV03o9YP000;o9YP000?o0000oc^O0?lkW`000_lkW`000ol0003oDJH0oe6V0002oe6V
0004o`000?mZ[P3oJZh0ofZ^01Ko000000?obkH0o`000?oBXP001?oBXP000ol0003ofH`0omV<0002
omV<0003o`000?oQM03ohG@000?ohG@000?o0000onQJ0?oXFP000_oXFP001ol0003ol3h0oo0n0?o`
?P3o0000oo0n0?l000005Oooool00ol0003oooooooooo`0Booooo`005?ooool00ol0003ooooooooo
o`15ooooo`03o`000?l022;o00PR00;o00PR00Go0000o`0>:?l03RSo00hXo`000003o`0E;`03o`00
0?l07SGo01he00;o01he00Go0000o`0X>ol0:3_o02Pko`000004o`0c@@05o`000?l0@4So0418o`10
B?l000001?l0CTh00ol0003o05E<o`1EC00Xo`0000Go4i4000?o0000obJH0?lVV0000_lVV0000ol0
003o>il0oc^O0002oc^O0003o`000?mAYP3oDJH000;oDJH000?o0000ofZ^0?mZ[P000_mZ[P000ol0
003oQKD0ohFe0002ohFe0003o`000?nQ_03oXK`000?oXK`000?o0000ol330?o0``000_o0``001?l0
003obkD0ol^e0?o;]@0Ao`000003on5d0?l0003oj5X000Coj5X000Oo0000oo0n0?o`?P3ol3h0o`00
0?o`?P3o000001Cooooo00?o0000ooooooooool04_ooool001Gooooo00?o0000ooooooooool0AOoo
ool00ol0003o00PRo`088P02o`088P05o`000?l03RSo00hXo`0>:?l000000ol05Bl00ol0003o01he
o`0N=@02o`0N=@05o`000?l0:3_o02Pko`0X>ol000001?l0<d401Ol0003o0418o`10B?l0@4So0000
00Co04i>00?o0000o`1EC?l0ED`00_l0ED`01Ol0003o05]7o`1KAol0FdOo000000?o069100?o0000
o`1X>_l0J3X00_l0J3X00ol0003o06lao`1_<@02o`1_<@03o`000?l0MRKo07HV00;o07HV00?o0000
o`1m6_l0OAX00_l0OAX00ol0003o08@=o`243@02o`243@03o`000?l2R`3o0X/001[o000000?oJZh0
o`000?n5]@000on5]@000ol0003oXK`0oj6l0003oj6l0003o`000?o0``3o`<<000;o`<<000?o0000
ol^e0?o;]@000_o;]@000ol0003odZ40om:Q0003om:Q0003o`000?oJS03ofX`000?ofX`000?o0000
on5c0?oQL`003ol0000Dooooo`03o`000?oooooooooo017ooooo000Fooooo`;o0000A_oooolbo`00
00Co06Pj00?o0000o`1_<Ol0Kc400_l0Kc400ol0003o07HVo`1f9P02o`1f9P03o`000?l0OA[o07dJ
00;o07dJ00?o0000o`243Ol0Q0d00_l0Q0d00ol0003o0X/0o`:;0002o`:;0005o`000?lCT@3o4i40
oa>A0?l000001?lVV0000ol0003o>il0oc^O0003oc^O0003o`000?mBY`3oDZL000;oDZL000?o0000
of^^0?m[[P005_l000000oo;]@3o0000om:Q0004om:Q0003o`000?oJS03ofX`000?ofX`000?o0000
on5c0?oQL`000_oQL`000ol0003ojET0onUI0003onUI0004o`000?o`?@3ol3d0oo0m00;o00005?oo
ool00ol0003oooooooooo`0Aooooo`006?ooool00ol0003oooooooooo`14ooooo`05o`000?l02B?o
00TSo`098ol000001?l03bT01Ol0003o01H_o`0F;ol05Roo000000?o01he00?o0000o`0X>ol0:3/0
0_l0:3/01Ol0003o03A2o`0d@_l0=4;o000000Co045800?o0000o`1?C_l0Cdh00_l0Cdh01Ol0003o
05E;o`1EBol0ED_o000000Co05]700?o0000o`1R@Ol0HT409?l00004obJH0003o`000?lkW`3o>il0
00?o>il000?o0000oe:W0?mBY`000_mBY`001Ol0003oJjh0of^^0?m[[P3o000000GoQKD000?o0000
oj:l0?nR_0000_nR_0000ol0003o`L@0ol740002ol740004o`000?o;]03obk@0ol^d01;o000000?o
hG<0o`000?oYF@001?oYF@001_l0003ol3d0oo0m0?l0003ol3d0o`0001?ooooo00?o0000oooooooo
ool04Oooool001Wooooo00?o0000ooooooooool0A?ooool01Ol0003o00TSo`098ol02B?o000000Co
00lY00Go0000o`0F;ol05Roo01H_o`000003o`0N=@03o`000?l0:3_o02Pk00;o02Pk00Go0000o`0d
@_l0=4;o03A2o`000004o`11B003o`000?l0Cdko04m>00;o04m>00Go0000o`1EBol0ED_o05E;o`00
0004o`1KA`03o`000?l0HT7o069100;o069100Go0000o`1Y>_l0JC[o06Tjo`000003o`1_<@03o`00
0?l0MRKo07HV00;o07HV00?o0000o`1m6_l0OAX00_l0OAX00ol0003o08@<o`243002o`243003o`00
0?l3R`3o0h/000;o0h/000Co0000oaBB0?lDTP3o59805_l00005ohFe0003o`000?nR_03oX[`000;o
X[`000?o0000ol740?o1a0000_o1a0000ol0003obk@0ol^d0003ol^d0003o`000?oBX@3odZ4000;o
dZ4000?o0000omZ;0?oJR`000ooJR`001?l0003ohG<0on5c0?oQL`0<o`000003oo0m0?l0003ooooo
017ooooo00?o0000ooooooooool04Oooool001[ooooo00?o0000ooooooooool0A?oooolgo`0000?o
06la00?o0000o`1f9_l0MRH00_l0MRH00ol0003o07dJo`1m6P02o`1m6P03o`000?l0Q0co08@<00;o
08@<00?o0000o`>;0?l3R`000_l3R`000ol0003o5980oaBB0002oaBB0003o`000?lWV@3o9iT000;o
9iT000?o0000ocbP0?llX0000_llX0000ol0003oDjL0oe>W0002oe>W0004o`000?m/[P3oK:h0ofb^
013o000000?o`L@0o`000?o;]0001?o;]0000ol0003odZ40om:Q0002om:Q0003o`000?oJR`3ofX/0
00?ofX/000?o0000on5c0?oQL`000_oQL`000ol0003ojET0onUI0003onUI0004o`000?oa?03olC`0
oo4l00?o00004Oooool00ol0003oooooooooo`0Aooooo`006oooool2o`0004Kooooo00Go0000o`09
8ol02B?o00TSo`000003o`0?:@05o`000?l05Roo01H_o`0F;ol000000ol07cH00ol0003o02Tlo`0Y
?002o`0Y?005o`000?l0=4;o03A2o`0d@_l000001?l0@DP01Ol0003o04m>o`1?C_l0Cdko000000Co
05E;00?o0000o`1LAol0G4L00_l0G4L01Ol0003o06=1o`1S@Ol0Hd7o000000?o06Ti7Ol000000olD
TP3o0000obNI0003obNI0003o`000?llX03o?:0000;o?:0000?o0000oe>W0?mCY`000_mCY`000ol0
003oK:h0ofb^0002ofb^0003o`000?n7]@3oQkD000;oQkD000?o0000oj>l0?nS_0000onS_0000ol0
003o`/@0ol;4000Ao`000003omZ;0?l0003ohG<000CohG<000?o0000onUI0?oYF@000ooYF@001?l0
003olC`0oo4l0?oa?002o`00017ooooo00?o0000ooooooooool04Oooool001gooooo00?o0000oooo
ooooool0A?ooool=o`0000?o01lf00?o0000o`0Y??l0:C`00_l0:C`01Ol0003o03A2o`0d@_l0=4;o
000000Co045800Go0000o`1?C_l0Cdko04m>o`000004o`1EB`03o`000?l0G4Oo05a700;o05a700Go
0000o`1S@Ol0Hd7o06=1o`000004o`1Y>@03o`000?l0L33o070`00;o070`00Go0000o`1g9Ol0MbGo
07LUo`000004o`1m6@03o`000?l0Q0_o08@;00;o08@;00?o0000o`B;0?l4R`000_l4R`000ol0003o
5I80oaFB000Eo`000003ofb^0?l0003oQkD000?oQkD000?o0000oj>l0?nS_0000onS_0001Ol0003o
`/@0ol;40?o2a03o000000Gobk@000?o0000om>P0?oCX0000ooCX0000ol0003ofXX0omZ:000Bo`00
0003oo4l0?l0003ooooo00oooooo00?o0000ooooooooool04Oooool001kooooo00?o0000oooooooo
ool0A?ooool01Ol0003o00TSo`098ol02B?o000000?o00lY00?o0000o`0G<?l05c00=?l00004o`1m
6@03o`000?l0Q0_o08@;00;o08@;00?o0000o`B;0?l4R`000_l4R`001Ol0003o5I80oaFB0?lETP3o
000000Co:9T000?o0000ocfP0?lmX0000_lmX0000ol0003oE:L0oeBW0003oeBW0003o`000?m][P3o
KJh001;o00001Oo;]0000ol0003odj00om>P0003om>P0005o`000?oJRP3ofXX0omZ:0?l000001OoR
LP000ol0003ojEP0onUH0003onUH0004o`000?oa>`3olC/0oo4k00?o00004?ooool00ol0003ooooo
ooooo`0@ooooo`007oooool00ol0003oooooooooo`14ooooo`05o`000?l02B?o00TSo`098ol00000
0ol03bT01Ol0003o01L`o`0G<?l05c3o000000Co01lf00Go0000o`0Y??l0:Cco02Tlo`000004o`0e
@P05o`000?l0@TWo0499o`12BOl000000ol0Cdh00ol0003o05I;o`1FB`02o`1FB`05o`000?l0G4Ko
05a6o`1LA_l000001?l0Hd000ol0003o06Tio`1Y>@02o`1Y>@03o`000?l0L2oo070_00;o070_00?o
0000o`1g9Ol0MbD05Ol00004obRI0003o`000?lmX03o?J0000;o?J0000?o0000oeBW0?mDY`000omD
Y`001Ol0003oKJh0off^0?m][P3o000000GoR;H000?o0000ojFm0?nU_@000_nU_@001?l0003o`l@0
ol?40?o3a00Bo`0000GohW8000?o0000onUH0?oYF0000ooYF0001?l0003olC/0oo4k0?oa>`02o`00
013ooooo00?o0000ooooooooool04?ooool0023ooooo0_l00015ooooob?o00001?l0ET/01Ol0003o
05a6o`1LA_l0G4Ko000000Co06=000?o0000o`1Y>Ol0JCT00_l0JCT00ol0003o070_o`1`;`02o`1`
;`05o`000?l0MbGo07LUo`1g9Ol000000ol0OQP00ol0003o08D:o`252P02o`252P03o`000?l5S03o
1H`000;o1H`000Co0000oaJB0?lFTP3o5Y805_l00005ohRf0003o`000?nU_@3oYKd000;oYKd000?o
0000ol?40?o3a0000_o3a0000ol0003oc;<0olbc0002olbc0003o`000?oCW`3odil000?odil000Co
0000omZ90?oJR@3ofXT02ol000000ooYF03o0000oo4k0002oo4k0003o`000?oa>`3o000000oooooo
00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool0@_ooool01Ol0003o00XTo`0:
9?l02RCo000000Co010Z00Go0000o`0G<?l05c3o01L`o`000004o`0P=P05o`000?l0:Sco02Xlo`0Z
??l000000ol0=T<00ol0003o04=9o`13B@02o`13B@03o`000?l0D4ko051>02;o00001?l0Q@X00ol0
003o1H`0o`F<0002o`F<0003o`000?lFTP3o5Y8000?o5Y8000Go0000obVI0?lYV@3o:IT0o`000004
ocjQ0003o`000?mFZ03oEZP000;oEZP000Co0000ofn_0?m_[`3oKjl04?l000000oo3a03o0000olbc
0003olbc0003o`000?oCW`3odil000?odil000?o0000omZ90?oJR@000_oJR@000ol0003ohW40on9a
0002on9a0004o`000?oYEP3ojEH0onUF00Wo00003_ooool00ol0003oooooooooo`0@ooooo`008ooo
ool00ol0003oooooooooo`12ooooo`05o`000?l02RCo00XTo`0:9?l000001?l042X01Ol0003o01L`
o`0G<?l05c3o000000Co020f00Go0000o`0Z??l0:Sco02Xlo`000003o`0f@`03o`000?l0@dWo04=9
00;o04=900?o0000o`1@C_l0D4h00_l0D4h01Ol0003o05I;o`1FBol0ET_o000000?o05e600?o0000
o`1S@?l0Hd000_l0Hd001Ol0003o06Xho`1Z>?l0JSSo000000Co074_00?o0000o`1g9?l0Mb@00_l0
Mb@00ol0003o07hHo`1n600Fo`0000Co?Z4000?o0000oeJX0?mFZ0000_mFZ0000ol0003oKjl0ofn_
0002ofn_0003o`000?n9]P3oRKH000;oRKH000?o0000ojJm0?nV_@000_nV_@001?l0003oaL@0olG4
0?o5a00Ao`000003omZ90?l0003ohW4000?ohW4000?o0000onUF0?oYEP000_oYEP000ol0003olCX0
oo4j0002oo4j00;o00003_ooool00ol0003oooooooooo`0@ooooo`009?ooool00ol0003ooooooooo
o`12ooooobgo00001?l0Hd001Ol0003o06Xho`1Z>?l0JSSo000000Co074_00?o0000o`1g9?l0Mb@0
0_l0Mb@01Ol0003o07hHo`1n6?l0OQSo000000Co08D900?o0000o`J<0?l6S0000_l6S0000ol0003o
5i<0oaNC0002oaNC0004o`000?l[VP3o:iX0ob^J00oo000000?oKjl0o`000?n9]P000on9]P000ol0
003oY[d0ojJm0002ojJm0003o`000?o5a03oaL@000;oaL@000?o0000olbb0?o</P000oo</P000ol0
003odih0om>N0002om>N0004o`000?oKR03ofhP0om^800_o000000?ojEH0o`000?oa>P000ooa>P02
o`0000gooooo00?o0000ooooooooool04?ooool002Gooooo0_l00014ooooo`05o`000?l02RCo00XT
o`0:9?l000000ol042X01Ol0003o01Pao`0H<Ol0637o000000?o024g00?o0000o`0[?Ol0:cd00_l0
:cd01Ol0003o03M3o`0g@ol0=d?o000000Co04A:00Go0000o`1@C_l0D4ko051>o`000004o`1GBP03
o`000?l0GDKo05e601Wo00001?l0Q@T00ol0003o1X`0o`J<0002o`J<0003o`000?lGT`3o5i<000;o
5i<000Go0000ob^J0?l[VP3o:iX0o`000004od2Q0003o`000?mGZ03oEjP000?oEjP000?o0000og2_
0?m`[`004?l000000oo5a03o0000olbb0004olbb0003o`000?oCWP3odih000;odih000?o0000om^8
0?oKR0000_oKR0000ol0003ohVl0on9_0003on9_0003o`000?oZE@3ojUD000Wo00003?ooool00ol0
003oooooooooo`0@ooooo`009oooool00ol0003oooooooooo`12ooooo`go00000ol08CL00ol0003o
02/mo`0[?@02o`0[?@05o`000?l0=d?o03M3o`0g@ol000001?l0A4X01Ol0003o051>o`1@C_l0D4ko
000000Co05M:00Go0000o`1MA_l0GDKo05e6o`000004o`1T?`05o`000?l0JcSo06/ho`1[>?l00000
1?l0LBh01Ol0003o07PSo`1h8ol0N2?o000000?o07lG5Ol00004od2Q0003o`000?mGZ03oEjP000?o
EjP000?o0000og2_0?m`[`000_m`[`001Ol0003oRkL0oh^g0?n;]`3o000000GoZ;h000?o0000olG3
0?o5``004Ol000000ooKR03o0000on9_0004on9_0003o`000?oZE@3ojUD000;ojUD000Oo0000oo8i
0?ob>@3olST0o`000?ob>@3o000000cooooo00?o0000ooooooooool03oooool002Sooooo00?o0000
ooooooooool0@_ooool01Ol0003o00/Uo`0;9Ol02bGo000000?o014[00?o0000o`0I<Ol06C40:_l0
0004o`1a;P05o`000?l0N2?o07PSo`1h8ol000001?l0OaL01Ol0003o08H8o`262?l0QPSo000000Co
1h`000?o0000oaVC0?lIT`000_lIT`001?l0003o;9X0obbJ0?l/VP0Fo`0000GoZ;h000Go0000olG3
0?o5``3oaL<0o`000005olba0003o`000?oDW03oe9`000;oe9`000Co0000om^60?oKQP3ofhH03?l0
00000ooZE@3o0000oo8i0002oo8i0003o`000?ob>@3o000000_ooooo00?o0000ooooooooool03ooo
ool002Wooooo00?o0000ooooooooool0@_ooool01Ol0003o00/Uo`0;9Ol02bGo000000?o014[00Go
0000o`0I<Ol06C7o01Tao`000004o`0R=`05o`000?l0;3ko02`no`0/?_l000001?l0>4@01?l0003o
04E:o`15B_l00004o`1AC@05o`000?l0Ed[o05M:o`1GB_l000001?l0GTD00ol0003o06@oo`1T?`02
o`1T?`03o`000?l0JcOo06/g01Co00001?l7S0000ol0003o6I<0oaVC0002oaVC0003o`000?l/VP3o
;9X000?o;9X000Go0000od:R0?m2XP3o@Z80o`000004oeVX0003o`000?mb/03oL[0000;oL[0000Co
0000ohfg0?n=]`3oSKL03?l00005olba0003o`000?oDW03oe9`000;oe9`000?o0000om^60?oKQP00
0_oKQP000ol0003ohfh0on=^0003on=^0004o`000?o[D`3oje<0on]C00Wo00002_ooool00ol0003o
ooooooooo`0?ooooo`00:_ooool2o`0004?ooooo7_l00004o`1AC@05o`000?l0Ed[o05M:o`1GB_l0
00001?l0GTD00ol0003o06@oo`1T?`02o`1T?`05o`000?l0JcOo06/go`1[=ol000000ol0LRd00ol0
003o07PRo`1h8P02o`1h8P03o`000?l0OaKo07lF00;o07lF00?o0000o`261ol0QPL05_l00004oeVX
0003o`000?mb/03oL[0000;oL[0000?o0000ohfg0?n=]`000_n=]`000ol0003oZ[h0ojZn0002ojZn
0004o`000?o6`P3oa/80olK2013o000000?ofhH0o`000?oSKP001?oSKP000ol0003oje<0on]C0002
on]C0007o`000?ob=`3olSL0oo8g0?l0003olSL0o`00000:ooooo`03o`000?oooooooooo00oooooo
000/ooooo`03o`000?oooooooooo043ooooo00Go0000o`0;9Ol02bGo00/Uo`000004o`0B;005o`00
0?l06C;o01Tbo`0I<_l000000ol08cP00ol0003o02dno`0]?P02o`0]?P05o`000?l0>DGo03U5o`0i
AOl000000_l0Ad/Mo`0000Co07PR00?o0000o`1o5_l0OaH00_l0OaH00ol0003o08H7o`261`02o`26
1`05o`000?l8S@3o28d0o`R=0?l000001?lJU0000ol0003o;Y/0objK0002objK0004o`000?m3XP3o
@j80od>R00oo000000?oSKL0o`000?nZ_P000onZ_P001Ol0003oa/80olK20?o6`P3o000000GocJl0
00?o0000omBK0?oDV`000ooDV`000ol0003og8D0omb5000<o`000003on]C0?l0003olSL000;olSL0
00?o0000oo8g0?l000002Oooool00ol0003oooooooooo`0?ooooo`00;Oooool00ol0003ooooooooo
o`10ooooo`05o`000?l02bGo00/Uo`0;9Ol000001?l04R`01Ol0003o01Tbo`0I<_l06C;o000000?o
02<h00?o0000o`0]?_l0;Ch00_l0;Ch01Ol0003o03U5o`0iAOl0>DGo000000Co04M;00Go0000o`1A
COl0DDgo055=o`000003o`1HB@05o`000?l0GTGo05i5o`1NAOl000001?l0ICh00ol0003o06`fo`1/
=P02o`1/=P03o`000?l0LRco078/01Go00001?lJU0000ol0003o;Y/0objK0002objK0005o`000?m3
XP3o@j80od>R0?l000001?mKZ@000ol0003oM;00ogB`0003ogB`0003o`000?n?^03oSkP000co0000
1Oo=[`000ol0003oe9/0omBK0003omBK0005o`000?oLQ@3og8D0omb50?l000001OoSK0001?l0003o
je80on]B0?o[DP09o`0000Sooooo00?o0000ooooooooool03oooool002kooooo00?o0000oooooooo
ool0@?oooolXo`0000?o05i500?o0000o`1U?_l0ICh00_l0ICh00ol0003o06`fo`1/=P02o`1/=P03
o`000?l0LRco078/00;o078/00Co0000o`1i8Ol0NB7o00001?l0P1@00ol0003o08L6o`271P02o`27
1P04o`000?l:SP3o2Xh0o`Z>013o00001?mKZ@000ol0003oM;00ogB`0003ogB`0005o`000?n?^03o
SkP0ohnh0?l000001?n/_`001?l0003oa/40olK10?o6`@0Bo`0000Gohf`000?o0000on]B0?o[DP00
0_o[DP001ol0003olSD0oo8e0?ob=@3o0000oo8e0?l000002?ooool00ol0003oooooooooo`0?oooo
o`00;oooool00ol0003oooooooooo`11ooooo`05o`000?l032Ko00`Vo`0<9_l000000ol04R`00ol0
003o01Xbo`0J<P02o`0J<P05o`000?l093Wo02@io`0T>Ol000000_l0;Sl00ol0003o03Y5o`0jA@02
o`0jA@05o`000?l0B4co04Q<o`18C?l000001?l0DTd00ol0003o05U9o`1IB@0Ho`0000Co080D00?o
0000o`271_l0Q`H00_l0Q`H00ol0003o2Xh0o`Z>0002o`Z>0005o`000?lLU03o79@0oabD0?l00000
1?l`V`001?l0003oAJ<0odFS0?m5X`0Ao`0000Co[;l000?o0000olK10?o6`@000oo6`@001Ol0003o
cJh0olf^0?o=[P3o000000GoeIX000Co0000omb30?oLP`3og8<02ol000000oo[DP3o0000oo8e0002
oo8e0003o`000?ob=@3o000000Sooooo00?o0000ooooooooool03_ooool0033ooooo0_l00012oooo
oaGo00001?l0>TD01Ol0003o04Q<o`18C?l0B4co000000Co059=00Go0000o`1IBOl0FDWo05U9o`00
0004o`1OA004o`000?l0ISgo06Hmo`0000Co06`e00?o0000o`1c:ol0Lb/00_l0Lb/00ol0003o07XP
o`1j800Eo`0000Co<9/000?o0000odFS0?m5X`000_m5X`000ol0003oGJX0oefZ0002oefZ0003o`00
0?mf/@3oM[4000;oM[4000Co0000oi6h0?nA^03oTKP04Ol00005omFJ0005o`000?oLP`3og8<0omb3
0?l000001OoTJP001?l0003ok500ona@0?o/D009o`0000Oooooo00?o0000ooooooooool03_ooool0
03;ooooo00?o0000ooooooooool0?oooool01Ol0003o00dWo`0=9ol03BOo000000Co01<]00Go0000
o`0K<ol06c?o01/co`000003o`0U>@03o`000?l0<3oo030o01co00001?l0K3D00ol0003o07<[o`1c
:`02o`1c:`03o`000?l0NR3o07XP00;o07XP00Go0000o`214ol0PA?o084Co`000003o`271003o`00
0?l;SP3o2hh000;o2hh000Co0000oafE0?lMU@3o7ID03ol000000omMZP3o0000ogJa0003ogJa0003
o`000?nA^03oTKP000;oTKP000Go0000ojno0?n__`3o[kl0o`000005olNo0004o`000?o>[03ocZ`0
olj/00co00001OoTJP000ol0003ok500ona@0002ona@0003o`000?oc<`3olc<000;olc<00_l00007
ooooo`03o`000?oooooooooo00kooooo000cooooo`03o`000?oooooooooo03oooooo00Go0000o`0=
9ol03BOo00dWo`000004o`0C;@05o`000?l06c?o01/co`0K<ol000000ol09CT00ol0003o030oo`0`
?`02o`0`?`05o`000?l0?4Ko03a6o`0lA_l000001?l0BT`01?l0003o05==o`1CCOl00004o`1IB@05
o`000?l0H4?o0613o`1P@ol000000_l0IS`Eo`0000?o08L400?o0000o`^>0?l;SP000_l;SP000ol0
003o7ID0oafE0002oafE0005o`000?laW03o<I`0oc6L0?l000001Om7X`000ol0003oGjX0oenZ000A
o`0000Goakl000Go0000olj/0?o>[03ocZ`0o`000005omJH0004o`000?oMP@3ogH40omf100_o0000
00?ok500o`000?oc<`000_oc<`000ol0003olc<0o`000006ooooo`03o`000?oooooooooo00kooooo
000dooooo`03o`000?oooooooooo03oooooo8ol00004o`1IB@05o`000?l0H4?o0613o`1P@ol00000
1?l0IS`01Ol0003o06ddo`1]=?l0KCCo000000?o07@Z00?o0000o`1j7ol0NQl00_l0NQl01?l0003o
084Ao`214Ol0PA4Do`0000GoAj<000Go0000oenZ0?mOZP3oGjX0o`000004ogVa0003o`000?nD^@3o
U;T000;oU;T000Co0000ok;00?nb`03o//003?l00005omJH0003o`000?oMP@3ogH4000;ogH4000?o
0000onAX0?oTJ0000_oTJ0001?l0003ok4d0ona=0?o/C@09o`0000Gooooo00?o0000ooooooooool0
3_ooool003Gooooo0_l00011ooooo`05o`000?l03BOo00dWo`0=9ol000000ol052h00ol0003o01`d
o`0L=002o`0L=004o`000?l09S[o02Hjo`0000?o035000?o0000o`0mAol0?DL00_l0?DL01Ol0003o
04]=o`1;COl0Bdgo000000;o05=<5?l00003o`1d:P03o`000?l0NQoo07XO00;o07XO00?o0000o`21
4Ol0PA400_l0PA401Ol0003o08P3o`280ol0R0?o000000Co3Hl000?o0000oanF0?lOUP000_lOUP00
0ol0003o<id0oc>M000<o`0000CoNK4000?o0000oiBi0?nD^@000_nD^@000ol0003o//00ok;00002
ok;00003o`000?o7_@3oakd000;oakd000Co0000oln[0?o?Z`3ocj/02ol000000ooMP@3o0000onAX
0003onAX0003o`000?o/C@3ok4d000;ok4d000?o0000oo@`0?od<0000_od<002o`0000Gooooo00?o
0000ooooooooool03_ooool003Oooooo00?o0000ooooooooool0?ooooolAo`0000?o035000?o0000
o`0mAol0?DL00_l0?DL01Ol0003o04]=o`1;COl0Bdgo000000Co05=<00Go0000o`1JB?l0FTSo05Y8
o`000003o`1Q@`05o`000?l0Icco06Llo`1W??l000000ol0KS<Do`0000Co3Hl000?o0000oanF0?lO
UP000_lOUP001Ol0003o<id0oc>M0?lcW@3o000000CoBJ@000Co0000of6[0?mQZ`3oHJ/03ol00000
0onb`03o0000olNm0003olNm0003o`000?o?Z`3ocj/000;ocj/000?o0000omJF0?oFUP000_oFUP00
1?l0003ogWl0omio0?oNO`0;o`000003ona=0?l0003om30000?om3000_l00004ooooo`03o`000?oo
oooooooo00kooooo000hooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03OoooolL
o`0000?o06Ll00?o0000o`1^<ol0KS<00_l0KS<00ol0003o07@Yo`1d:@02o`1d:@04o`000?l0Nago
07/Mo`0000Co088@00Co0000o`290Ol0R@7o08T14?l00004odVT0003o`000?mQZ`3oHJ/000;oHJ/0
00Go0000og^b0?mk/P3oNk80o`000005oiNi0003o`000?nd`@3o]<4000_o000000?ocj/0o`000?oF
UP000ooFUP000ol0003ogWl0omio0002omio0003o`000?oUIP3oiFH000;oiFH000Co0000one;0?o]
B`3okD/02Ol00004ooooo`03o`000?oooooooooo00gooooo000iooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool0:?oooolCo`0000Co088@00?o0000o`290Ol0R@400_l0R@401Ol0003o
3i00o`n@0?l?T03o000000Co8YL000Co0000ocJN0?lfWP3o=Yh04?l00005oiNi0005o`000?nd`@3o
]<40okC10?l000001?o8_0001?l0003ocjT0olnY0?o?Z@0;o`000003omio0?l0003oiFH000?oiFH0
00?o0000one;0?o]B`000_o]B`000ol0003om2h0oo@^0002oo@^00;o00001?ooool00ol0003ooooo
ooooo`0=ooooo`00>_ooool2o`0003gooooo00?o0000ooooooooool0>_ooool@o`0000Co8YL000?o
0000ocJN0?lfWP000_lfWP001Ol0003oC:D0odbU0?m<Y@3o000000CoI:`000Co0000ogjc0?mn/`3o
O[<03?l00004olRl0003o`000?o?Z@3ocjT000?ocjT000Go0000omND0?oGU03oei@0o`000003omim
00_o000000?okD/0o`000?od;P000ood;P02o`0000?ooooo00?o0000ooooooooool03Oooool003co
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`19oooooa3o00001?mT[0001Ol0003o
O[<0ogjc0?mn/`3o000000GoV[X000Co0000okS20?nh`P3o^<804Ol00005omim0005o`000?oVI03o
iV@0onIT0?l000000oo]B009o`0000;ooooo00?o0000ooooooooool03Oooool003gooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`1Hooooo`_o00001OnJ^P000ol0003o^<80okS20002
okS20005o`000?o9^P3obKX0olVj0?l000001Oo@Y`001?l0003of940omRA0?oHT@0<o`0000CokDP0
00?o0000ooD[0?oe:`000_oe:`02o`0000;ooooo00?o0000ooooooooool03Oooool003kooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`1Roooooa7o00001Oo@Y`001Ol0003of940omRA
0?oHT@3o000000GoggX000Co0000onMQ0?oWH@3oif401Ol000000oo]B03o0000ooD[0003ooD[00;o
000000?oooooo`000?ooool03_ooool003oooooo0_l0000hooooo`03o`000?oooooooooo07;ooooo
3?l00005ommj0005o`000?oWH@3oif40onMQ0?l000000oo^AP0:o`0000oooooo0011ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0OOooool<o`0000GokTH000Co0000ooHX0?of:03o
mRP00_l000000ooooooo0000ooooo`0=ooooo`00@_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo08Sooooo3_l0000>ooooo`00@oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo09?ooooo0ol0000>ooooo`00A?ooool2o`0003?ooooo00?o0000ooooooooool0Toooool3
o`0000kooooo0016ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0T?ooool4o`00
017ooooo0017ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0SOooool3o`0001Go
oooo0018ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0ROooool4o`0001Sooooo
0019ooooo`;o0000;Oooool00ol0003oooooooooo`25ooooo`Co00007?ooool004_ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`21ooooo`Co00008?ooool004cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1nooooo`?o00009?ooool004gooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1jooooo`Co00009oooool004kooooo0_l0000Xooooo`03o`00
0?oooooooooo07Kooooo1?l0000[ooooo`00D?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo07;ooooo1?l0000_ooooo`00DOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo06oooooo0ol0000cooooo`00D_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
06_ooooo1?l0000fooooo`00Doooool2o`0002?ooooo00?o0000ooooooooool0Ioooool4o`0003[o
oooo001Eooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Hoooool4o`0003kooooo
001Fooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H?ooool3o`0004;ooooo001G
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G?ooool4o`0004Gooooo001Hoooo
o`;o00007_ooool00ol0003oooooooooo`1Hooooo`Co0000BOooool005[ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Dooooo`Co0000COooool005_ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Aooooo`?o0000DOooool005cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1=ooooo`Co0000E?ooool005gooooo0_l0000Iooooo`03o`000?oooooo
oooo04Wooooo1?l0001Hooooo`00Goooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Gooooo1?l0001Looooo`00H?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo047o
oooo1?l0001Pooooo`00HOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03kooooo
0ol0001Tooooo`00H_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03[ooooo1?l0
001Wooooo`00Hoooool2o`0001?ooooo00?o0000ooooooooool0=_ooool4o`0006_ooooo001Uoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool4o`0006oooooo001Vooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;oooool3o`0007?ooooo001Wooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0;?ooool4o`0007Kooooo001Xooooo`;o00003Ooo
ool00ol0003oooooooooo`0Xooooo`Co0000N_ooool006[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Tooooo`Co0000O_ooool006_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Qooooo`?o0000P_ooool006cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Mooooo`Co0000QOooool006gooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo
1?l00029ooooo`00Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0
002=ooooo`00L?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0002A
ooooo`00LOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002Doooo
o`00L_ooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`0009Sooooo001dooooo`04o`00
0?ooooooooooo`0000Sooooo1?l0002Looooo`00MOooool00ol0003oooooo`000005ooooo`?o0000
X?ooool007Kooooo0_l000000ooooooo0000o`000002o`000:?ooooo001gooooo`;o0000Yoooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool002Sooooo0ol0002:ooooo`03o`000?oo
oooooooo02_ooooo0ol0000Eooooo`03o`000?oooooooooo02;ooooo000Yooooo`03o`000?oooooo
oooo08Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo027ooooo000Sooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`00
00?ooooo1?l000000ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co00000oooool2o`00
00;ooooo1_l00006ooooo`Co00000_ooool5o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000ol00002ooooo`?o00000_ooool3o`0000Cooooo0ol00002ooooo`?o000000Coooooo`00
0?l0003ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00000_ooool3
o`0000;ooooo0ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00002ooooo`[o00001Ooo
ool00ol0003oooooooooo`0Pooooo`008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Pooooo`00
8_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`03
o`000?oooooooooo00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5
o`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol0
0003ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`04o`000?ooooooooooooooo`Go0000
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00002ooooo`?o00001Oooool00ol0003oooooooooo`0Pooooo`008_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool3o`0000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`07o`000?oooooo
0000ooooool0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Go
oooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo023ooooo000Roooo
o`06o`000?ooooooooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol0
0003ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo
0_l00003ooooo`Co00000oooool3o`0000Wooooo00Go0000oooooooooooo0000ooooo`03o`0000Co
oooo1?l00002ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o
00000_ooool4o`0000?ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`Ko
000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`03
o`000?oooooooooo00;ooooo0ol00002ooooo`Co00000oooool9o`0000?ooooo0ol00003ooooo`Co
00001?ooool00ol0003oooooooooo`0Pooooo`008_ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool08Oooool002?ooooo0ol00009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03Oooool3o`0000Wooooo1?l00009ooooo`03o`000?oooooooooo
00;ooooo0_l0000:ooooo`Co00001?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool2o`00
02kooooo00?o0000ooooooooool06?ooool3o`0001Kooooo00?o0000ooooooooool00_ooool2o`00
00_ooooo00?o0000ooooooooool08_ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0656841, 0.019078, \
0.00372136, 0.00372136}},
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 1, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 1, Source \[Rule] 2}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 1, SurfaceNumber -> 1, 
        WaveFrontID -> 1, Source -> 2}],
      Editable->False]], "Print",
  CellLabel->"From In[19]:=",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
7.69385e-14 1.04977 -0.0679587 1.04977 [
[.5 .82364 -117 0 ]
[.5 .82364 117 9 ]
[.02757 .24618 -24 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -22.3468 -9 ]
[.3345 .12542 1.65319 0 ]
[.50253 .05935 -21.0958 -9 ]
[.50253 .05935 2.90415 0 ]
[.68156 -0.01098 -19.8449 -9 ]
[.68156 -0.01098 4.1551 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 24 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 24 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 18 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.01972 .29266 -36 -2.76559 ]
[.01972 .29266 0 6.23441 ]
[.01113 .34646 -42 -2.81116 ]
[.01113 .34646 0 6.18884 ]
[.00225 .40215 -42 -2.8585 ]
[.00225 .40215 0 6.1415 ]
[-0.00696 .45984 -42 -2.90771 ]
[-0.00696 .45984 0 6.09229 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Length \\(absolute distance\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-0.5)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.4)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(-0.3)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(-0.2)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(-0.1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-0.2)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-0.1)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.1)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.2)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03196 .28794 m
.03808 .28558 L
s
[(100.05)] .01972 .29266 1 -0.38542 Mshowa
.02342 .34184 m
.02956 .33954 L
s
[(100.052)] .01113 .34646 1 -0.3753 Mshowa
.01458 .39765 m
.02074 .3954 L
s
[(100.054)] .00225 .40215 1 -0.36478 Mshowa
.00541 .45546 m
.0116 .45327 L
s
[(100.056)] -0.00696 .45984 1 -0.35384 Mshowa
.125 Mabswid
.02985 .30124 m
.03353 .29984 L
s
.02773 .31466 m
.03141 .31326 L
s
.02558 .32819 m
.02927 .3268 L
s
.02124 .35561 m
.02493 .35424 L
s
.01904 .3695 m
.02273 .36814 L
s
.01682 .38352 m
.02051 .38216 L
s
.01232 .41191 m
.01602 .41057 L
s
.01004 .4263 m
.01374 .42497 L
s
.00774 .44081 m
.01144 .43949 L
s
.03405 .27475 m
.03772 .27333 L
s
.03612 .26167 m
.03979 .26024 L
s
.00307 .47024 m
.00679 .46894 L
s
.00071 .48515 m
.00443 .48386 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.965 .147 0 r
.38757 .79727 .39806 .80578 .41576 .79428 .40536 .78568 Metetra
.937 .255 0 r
.40536 .78568 .41576 .79428 .43352 .78274 .42321 .77407 Metetra
.909 .357 0 r
.42321 .77407 .43352 .78274 .45132 .77118 .44111 .76242 Metetra
.882 .452 0 r
.44111 .76242 .45132 .77118 .46917 .75959 .45905 .75075 Metetra
.854 .54 0 r
.45905 .75075 .46917 .75959 .48707 .74796 .47704 .73904 Metetra
.826 .621 0 r
.47704 .73904 .48707 .74796 .50501 .7363 .49509 .7273 Metetra
.799 .696 0 r
.49509 .7273 .50501 .7363 .52301 .72461 .51318 .71553 Metetra
.771 .765 0 r
.51318 .71553 .52301 .72461 .54105 .71289 .53132 .70372 Metetra
.661 .744 0 r
.53132 .70372 .54105 .71289 .55915 .70114 .54951 .69188 Metetra
.55 .716 0 r
.54951 .69188 .55915 .70114 .57729 .68936 .56775 .68001 Metetra
.447 .688 0 r
.56775 .68001 .57729 .68936 .59548 .67754 .58604 .66811 Metetra
.35 .661 0 r
.58604 .66811 .59548 .67754 .61372 .66569 .60438 .65618 Metetra
.259 .633 0 r
.60438 .65618 .61372 .66569 .63201 .65381 .62277 .64421 Metetra
.175 .605 0 r
.62277 .64421 .63201 .65381 .65036 .64189 .64121 .63221 Metetra
.098 .578 0 r
.64121 .63221 .65036 .64189 .66875 .62995 .6597 .62018 Metetra
.027 .55 0 r
.6597 .62018 .66875 .62995 .68719 .61797 .67825 .60811 Metetra
0 .522 .036 r
.67825 .60811 .68719 .61797 .70568 .60595 .69684 .59601 Metetra
0 .495 .094 r
.69684 .59601 .70568 .60595 .72423 .59391 .71549 .58387 Metetra
0 .467 .145 r
.71549 .58387 .72423 .59391 .74282 .58183 .73419 .57171 Metetra
0 .439 .189 r
.73419 .57171 .74282 .58183 .76147 .56972 .75294 .55951 Metetra
0 .412 .226 r
.75294 .55951 .76147 .56972 .78017 .55757 .77174 .54727 Metetra
0 .384 .257 r
.77174 .54727 .78017 .55757 .79892 .54539 .79059 .535 Metetra
0 .356 .281 r
.79059 .535 .79892 .54539 .81772 .53318 .8095 .5227 Metetra
0 .329 .299 r
.8095 .5227 .81772 .53318 .83657 .52093 .82846 .51036 Metetra
0 .293 .301 r
.82846 .51036 .83657 .52093 .85548 .50865 .84747 .49799 Metetra
0 .233 .274 r
.84747 .49799 .85548 .50865 .87444 .49634 .86654 .48558 Metetra
0 .18 .246 r
.86654 .48558 .87444 .49634 .89345 .48399 .88566 .47314 Metetra
0 .134 .218 r
.88566 .47314 .89345 .48399 .91252 .4716 .90483 .46066 Metetra
0 .094 .191 r
.90483 .46066 .91252 .4716 .93163 .45918 .92406 .44815 Metetra
0 .061 .163 r
.92406 .44815 .93163 .45918 .95081 .44673 .94334 .4356 Metetra
0 .034 .135 r
.94334 .4356 .95081 .44673 .97003 .43424 .96268 .42302 Metetra
.965 .147 0 r
.37695 .78865 .38757 .79727 .40536 .78568 .39484 .77699 Metetra
.937 .255 0 r
.39484 .77699 .40536 .78568 .42321 .77407 .41278 .76529 Metetra
.909 .357 0 r
.41278 .76529 .42321 .77407 .44111 .76242 .43077 .75356 Metetra
.882 .452 0 r
.43077 .75356 .44111 .76242 .45905 .75075 .44881 .7418 Metetra
.854 .54 0 r
.44881 .7418 .45905 .75075 .47704 .73904 .4669 .73001 Metetra
.826 .621 0 r
.4669 .73001 .47704 .73904 .49509 .7273 .48504 .71818 Metetra
.799 .696 0 r
.48504 .71818 .49509 .7273 .51318 .71553 .50322 .70633 Metetra
.771 .765 0 r
.50322 .70633 .51318 .71553 .53132 .70372 .52146 .69444 Metetra
.661 .744 0 r
.52146 .69444 .53132 .70372 .54951 .69188 .53975 .68251 Metetra
.55 .716 0 r
.53975 .68251 .54951 .69188 .56775 .68001 .55809 .67056 Metetra
.447 .688 0 r
.55809 .67056 .56775 .68001 .58604 .66811 .57648 .65857 Metetra
.35 .661 0 r
.57648 .65857 .58604 .66811 .60438 .65618 .59492 .64655 Metetra
.259 .633 0 r
.59492 .64655 .60438 .65618 .62277 .64421 .61341 .63449 Metetra
.175 .605 0 r
.61341 .63449 .62277 .64421 .64121 .63221 .63195 .62241 Metetra
.098 .578 0 r
.63195 .62241 .64121 .63221 .6597 .62018 .65055 .61028 Metetra
.027 .55 0 r
.65055 .61028 .6597 .62018 .67825 .60811 .66919 .59813 Metetra
0 .522 .036 r
.66919 .59813 .67825 .60811 .69684 .59601 .68789 .58594 Metetra
0 .495 .094 r
.68789 .58594 .69684 .59601 .71549 .58387 .70664 .57372 Metetra
0 .467 .145 r
.70664 .57372 .71549 .58387 .73419 .57171 .72544 .56146 Metetra
0 .439 .189 r
.72544 .56146 .73419 .57171 .75294 .55951 .7443 .54917 Metetra
0 .412 .226 r
.7443 .54917 .75294 .55951 .77174 .54727 .7632 .53684 Metetra
0 .384 .257 r
.7632 .53684 .77174 .54727 .79059 .535 .78216 .52448 Metetra
0 .356 .281 r
.78216 .52448 .79059 .535 .8095 .5227 .80118 .51208 Metetra
0 .329 .299 r
.80118 .51208 .8095 .5227 .82846 .51036 .82025 .49965 Metetra
0 .293 .301 r
.82025 .49965 .82846 .51036 .84747 .49799 .83937 .48719 Metetra
0 .233 .274 r
.83937 .48719 .84747 .49799 .86654 .48558 .85854 .47469 Metetra
0 .18 .246 r
.85854 .47469 .86654 .48558 .88566 .47314 .87777 .46215 Metetra
0 .134 .218 r
.87777 .46215 .88566 .47314 .90483 .46066 .89705 .44958 Metetra
0 .094 .191 r
.89705 .44958 .90483 .46066 .92406 .44815 .91639 .43697 Metetra
0 .061 .163 r
.91639 .43697 .92406 .44815 .94334 .4356 .93578 .42433 Metetra
0 .034 .135 r
.93578 .42433 .94334 .4356 .96268 .42302 .95523 .41165 Metetra
.965 .147 0 r
.3662 .77993 .37695 .78865 .39484 .77699 .38418 .76818 Metetra
.937 .255 0 r
.38418 .76818 .39484 .77699 .41278 .76529 .40222 .7564 Metetra
.909 .357 0 r
.40222 .7564 .41278 .76529 .43077 .75356 .4203 .74459 Metetra
.882 .452 0 r
.4203 .74459 .43077 .75356 .44881 .7418 .43844 .73275 Metetra
.854 .54 0 r
.43844 .73275 .44881 .7418 .4669 .73001 .45663 .72087 Metetra
.826 .621 0 r
.45663 .72087 .4669 .73001 .48504 .71818 .47486 .70896 Metetra
.799 .696 0 r
.47486 .70896 .48504 .71818 .50322 .70633 .49315 .69702 Metetra
.771 .765 0 r
.49315 .69702 .50322 .70633 .52146 .69444 .51148 .68504 Metetra
.661 .744 0 r
.51148 .68504 .52146 .69444 .53975 .68251 .52987 .67303 Metetra
.55 .716 0 r
.52987 .67303 .53975 .68251 .55809 .67056 .54831 .66099 Metetra
.447 .688 0 r
.54831 .66099 .55809 .67056 .57648 .65857 .5668 .64891 Metetra
.35 .661 0 r
.5668 .64891 .57648 .65857 .59492 .64655 .58534 .6368 Metetra
.259 .633 0 r
.58534 .6368 .59492 .64655 .61341 .63449 .60393 .62466 Metetra
.175 .605 0 r
.60393 .62466 .61341 .63449 .63195 .62241 .62258 .61248 Metetra
.098 .578 0 r
.62258 .61248 .63195 .62241 .65055 .61028 .64128 .60027 Metetra
.027 .55 0 r
.64128 .60027 .65055 .61028 .66919 .59813 .66003 .58802 Metetra
0 .522 .036 r
.66003 .58802 .66919 .59813 .68789 .58594 .67883 .57574 Metetra
0 .495 .094 r
.67883 .57574 .68789 .58594 .70664 .57372 .69768 .56343 Metetra
0 .467 .145 r
.69768 .56343 .70664 .57372 .72544 .56146 .71659 .55108 Metetra
0 .439 .189 r
.71659 .55108 .72544 .56146 .7443 .54917 .73555 .5387 Metetra
0 .412 .226 r
.73555 .5387 .7443 .54917 .7632 .53684 .75456 .52628 Metetra
0 .384 .257 r
.75456 .52628 .7632 .53684 .78216 .52448 .77363 .51383 Metetra
0 .356 .281 r
.77363 .51383 .78216 .52448 .80118 .51208 .79275 .50134 Metetra
0 .329 .299 r
.79275 .50134 .80118 .51208 .82025 .49965 .81193 .48881 Metetra
0 .293 .301 r
.81193 .48881 .82025 .49965 .83937 .48719 .83116 .47625 Metetra
0 .233 .274 r
.83116 .47625 .83937 .48719 .85854 .47469 .85044 .46366 Metetra
0 .18 .246 r
.85044 .46366 .85854 .47469 .87777 .46215 .86978 .45103 Metetra
0 .134 .218 r
.86978 .45103 .87777 .46215 .89705 .44958 .88918 .43836 Metetra
0 .094 .191 r
.88918 .43836 .89705 .44958 .91639 .43697 .90863 .42566 Metetra
0 .061 .163 r
.90863 .42566 .91639 .43697 .93578 .42433 .92813 .41292 Metetra
0 .034 .135 r
.92813 .41292 .93578 .42433 .95523 .41165 .94769 .40014 Metetra
.965 .147 0 r
.35531 .7711 .3662 .77993 .38418 .76818 .3734 .75927 Metetra
.937 .255 0 r
.3734 .75927 .38418 .76818 .40222 .7564 .39153 .74741 Metetra
.909 .357 0 r
.39153 .74741 .40222 .7564 .4203 .74459 .40971 .73551 Metetra
.882 .452 0 r
.40971 .73551 .4203 .74459 .43844 .73275 .42794 .72358 Metetra
.854 .54 0 r
.42794 .72358 .43844 .73275 .45663 .72087 .44623 .71161 Metetra
.826 .621 0 r
.44623 .71161 .45663 .72087 .47486 .70896 .46456 .69962 Metetra
.799 .696 0 r
.46456 .69962 .47486 .70896 .49315 .69702 .48295 .68759 Metetra
.771 .765 0 r
.48295 .68759 .49315 .69702 .51148 .68504 .50138 .67552 Metetra
.661 .744 0 r
.50138 .67552 .51148 .68504 .52987 .67303 .51987 .66343 Metetra
.55 .716 0 r
.51987 .66343 .52987 .67303 .54831 .66099 .53841 .6513 Metetra
.447 .688 0 r
.53841 .6513 .54831 .66099 .5668 .64891 .557 .63913 Metetra
.35 .661 0 r
.557 .63913 .5668 .64891 .58534 .6368 .57564 .62693 Metetra
.259 .633 0 r
.57564 .62693 .58534 .6368 .60393 .62466 .59434 .6147 Metetra
.175 .605 0 r
.59434 .6147 .60393 .62466 .62258 .61248 .61309 .60243 Metetra
.098 .578 0 r
.61309 .60243 .62258 .61248 .64128 .60027 .63189 .59013 Metetra
.027 .55 0 r
.63189 .59013 .64128 .60027 .66003 .58802 .65074 .57779 Metetra
0 .522 .036 r
.65074 .57779 .66003 .58802 .67883 .57574 .66965 .56542 Metetra
0 .495 .094 r
.66965 .56542 .67883 .57574 .69768 .56343 .68861 .55302 Metetra
0 .467 .145 r
.68861 .55302 .69768 .56343 .71659 .55108 .70762 .54057 Metetra
0 .439 .189 r
.70762 .54057 .71659 .55108 .73555 .5387 .72669 .5281 Metetra
0 .412 .226 r
.72669 .5281 .73555 .5387 .75456 .52628 .74581 .51559 Metetra
0 .384 .257 r
.74581 .51559 .75456 .52628 .77363 .51383 .76499 .50304 Metetra
0 .356 .281 r
.76499 .50304 .77363 .51383 .79275 .50134 .78422 .49045 Metetra
0 .329 .299 r
.78422 .49045 .79275 .50134 .81193 .48881 .8035 .47784 Metetra
0 .293 .301 r
.8035 .47784 .81193 .48881 .83116 .47625 .82284 .46518 Metetra
0 .233 .274 r
.82284 .46518 .83116 .47625 .85044 .46366 .84224 .45249 Metetra
0 .18 .246 r
.84224 .45249 .85044 .46366 .86978 .45103 .86169 .43976 Metetra
0 .134 .218 r
.86169 .43976 .86978 .45103 .88918 .43836 .8812 .427 Metetra
0 .094 .191 r
.8812 .427 .88918 .43836 .90863 .42566 .90076 .4142 Metetra
0 .061 .163 r
.90076 .4142 .90863 .42566 .92813 .41292 .92038 .40136 Metetra
0 .034 .135 r
.92038 .40136 .92813 .41292 .94769 .40014 .94005 .38849 Metetra
.965 .147 0 r
.3443 .76217 .35531 .7711 .3734 .75927 .36248 .75025 Metetra
.937 .255 0 r
.36248 .75025 .3734 .75927 .39153 .74741 .38071 .7383 Metetra
.909 .357 0 r
.38071 .7383 .39153 .74741 .40971 .73551 .39899 .72631 Metetra
.882 .452 0 r
.39899 .72631 .40971 .73551 .42794 .72358 .41732 .7143 Metetra
.854 .54 0 r
.41732 .7143 .42794 .72358 .44623 .71161 .4357 .70224 Metetra
.826 .621 0 r
.4357 .70224 .44623 .71161 .46456 .69962 .45413 .69016 Metetra
.799 .696 0 r
.45413 .69016 .46456 .69962 .48295 .68759 .47262 .67804 Metetra
.771 .765 0 r
.47262 .67804 .48295 .68759 .50138 .67552 .49116 .66589 Metetra
.661 .744 0 r
.49116 .66589 .50138 .67552 .51987 .66343 .50974 .6537 Metetra
.55 .716 0 r
.50974 .6537 .51987 .66343 .53841 .6513 .52839 .64148 Metetra
.447 .688 0 r
.52839 .64148 .53841 .6513 .557 .63913 .54708 .62923 Metetra
.35 .661 0 r
.54708 .62923 .557 .63913 .57564 .62693 .56583 .61694 Metetra
.259 .633 0 r
.56583 .61694 .57564 .62693 .59434 .6147 .58463 .60461 Metetra
.175 .605 0 r
.58463 .60461 .59434 .6147 .61309 .60243 .60348 .59226 Metetra
.098 .578 0 r
.60348 .59226 .61309 .60243 .63189 .59013 .62238 .57986 Metetra
.027 .55 0 r
.62238 .57986 .63189 .59013 .65074 .57779 .64134 .56743 Metetra
0 .522 .036 r
.64134 .56743 .65074 .57779 .66965 .56542 .66036 .55497 Metetra
0 .495 .094 r
.66036 .55497 .66965 .56542 .68861 .55302 .67942 .54247 Metetra
0 .467 .145 r
.67942 .54247 .68861 .55302 .70762 .54057 .69854 .52993 Metetra
0 .439 .189 r
.69854 .52993 .70762 .54057 .72669 .5281 .71772 .51736 Metetra
0 .412 .226 r
.71772 .51736 .72669 .5281 .74581 .51559 .73695 .50475 Metetra
0 .384 .257 r
.73695 .50475 .74581 .51559 .76499 .50304 .75624 .49211 Metetra
0 .356 .281 r
.75624 .49211 .76499 .50304 .78422 .49045 .77558 .47943 Metetra
0 .329 .299 r
.77558 .47943 .78422 .49045 .8035 .47784 .79497 .46672 Metetra
0 .293 .301 r
.79497 .46672 .8035 .47784 .82284 .46518 .81442 .45397 Metetra
0 .233 .274 r
.81442 .45397 .82284 .46518 .84224 .45249 .83393 .44118 Metetra
0 .18 .246 r
.83393 .44118 .84224 .45249 .86169 .43976 .8535 .42835 Metetra
0 .134 .218 r
.8535 .42835 .86169 .43976 .8812 .427 .87312 .41549 Metetra
0 .094 .191 r
.87312 .41549 .8812 .427 .90076 .4142 .89279 .40259 Metetra
0 .061 .163 r
.89279 .40259 .90076 .4142 .92038 .40136 .91253 .38965 Metetra
0 .034 .135 r
.91253 .38965 .92038 .40136 .94005 .38849 .93232 .37668 Metetra
.965 .147 0 r
.33314 .75312 .3443 .76217 .36248 .75025 .35142 .74111 Metetra
.937 .255 0 r
.35142 .74111 .36248 .75025 .38071 .7383 .36975 .72907 Metetra
.909 .357 0 r
.36975 .72907 .38071 .7383 .39899 .72631 .38813 .717 Metetra
.882 .452 0 r
.38813 .717 .39899 .72631 .41732 .7143 .40656 .7049 Metetra
.854 .54 0 r
.40656 .7049 .41732 .7143 .4357 .70224 .42504 .69276 Metetra
.826 .621 0 r
.42504 .69276 .4357 .70224 .45413 .69016 .44357 .68058 Metetra
.799 .696 0 r
.44357 .68058 .45413 .69016 .47262 .67804 .46216 .66838 Metetra
.771 .765 0 r
.46216 .66838 .47262 .67804 .49116 .66589 .4808 .65613 Metetra
.661 .744 0 r
.4808 .65613 .49116 .66589 .50974 .6537 .49949 .64386 Metetra
.55 .716 0 r
.49949 .64386 .50974 .6537 .52839 .64148 .51824 .63155 Metetra
.447 .688 0 r
.51824 .63155 .52839 .64148 .54708 .62923 .53703 .6192 Metetra
.35 .661 0 r
.53703 .6192 .54708 .62923 .56583 .61694 .55588 .60682 Metetra
.259 .633 0 r
.55588 .60682 .56583 .61694 .58463 .60461 .57479 .5944 Metetra
.175 .605 0 r
.57479 .5944 .58463 .60461 .60348 .59226 .59375 .58195 Metetra
.098 .578 0 r
.59375 .58195 .60348 .59226 .62238 .57986 .61276 .56946 Metetra
.027 .55 0 r
.61276 .56946 .62238 .57986 .64134 .56743 .63182 .55694 Metetra
0 .522 .036 r
.63182 .55694 .64134 .56743 .66036 .55497 .65094 .54438 Metetra
0 .495 .094 r
.65094 .54438 .66036 .55497 .67942 .54247 .67012 .53179 Metetra
0 .467 .145 r
.67012 .53179 .67942 .54247 .69854 .52993 .68935 .51916 Metetra
0 .439 .189 r
.68935 .51916 .69854 .52993 .71772 .51736 .70863 .50649 Metetra
0 .412 .226 r
.70863 .50649 .71772 .51736 .73695 .50475 .72798 .49379 Metetra
0 .384 .257 r
.72798 .49379 .73695 .50475 .75624 .49211 .74737 .48105 Metetra
0 .356 .281 r
.74737 .48105 .75624 .49211 .77558 .47943 .76682 .46827 Metetra
0 .329 .299 r
.76682 .46827 .77558 .47943 .79497 .46672 .78633 .45546 Metetra
0 .293 .301 r
.78633 .45546 .79497 .46672 .81442 .45397 .8059 .44261 Metetra
0 .233 .274 r
.8059 .44261 .81442 .45397 .83393 .44118 .82552 .42972 Metetra
0 .18 .246 r
.82552 .42972 .83393 .44118 .8535 .42835 .8452 .41679 Metetra
0 .134 .218 r
.8452 .41679 .8535 .42835 .87312 .41549 .86493 .40383 Metetra
0 .094 .191 r
.86493 .40383 .87312 .41549 .89279 .40259 .88472 .39083 Metetra
0 .061 .163 r
.88472 .39083 .89279 .40259 .91253 .38965 .90457 .37779 Metetra
0 .034 .135 r
.90457 .37779 .91253 .38965 .93232 .37668 .92448 .36472 Metetra
.965 .147 0 r
.32185 .74396 .33314 .75312 .35142 .74111 .34023 .73186 Metetra
.937 .255 0 r
.34023 .73186 .35142 .74111 .36975 .72907 .35865 .71974 Metetra
.909 .357 0 r
.35865 .71974 .36975 .72907 .38813 .717 .37713 .70758 Metetra
.882 .452 0 r
.37713 .70758 .38813 .717 .40656 .7049 .39566 .69538 Metetra
.854 .54 0 r
.39566 .69538 .40656 .7049 .42504 .69276 .41425 .68315 Metetra
.826 .621 0 r
.41425 .68315 .42504 .69276 .44357 .68058 .43288 .67089 Metetra
.799 .696 0 r
.43288 .67089 .44357 .68058 .46216 .66838 .45157 .65859 Metetra
.771 .765 0 r
.45157 .65859 .46216 .66838 .4808 .65613 .47031 .64626 Metetra
.661 .744 0 r
.47031 .64626 .4808 .65613 .49949 .64386 .48911 .63389 Metetra
.55 .716 0 r
.48911 .63389 .49949 .64386 .51824 .63155 .50796 .62148 Metetra
.447 .688 0 r
.50796 .62148 .51824 .63155 .53703 .6192 .52686 .60904 Metetra
.35 .661 0 r
.52686 .60904 .53703 .6192 .55588 .60682 .54581 .59657 Metetra
.259 .633 0 r
.54581 .59657 .55588 .60682 .57479 .5944 .56482 .58406 Metetra
.175 .605 0 r
.56482 .58406 .57479 .5944 .59375 .58195 .58389 .57151 Metetra
.098 .578 0 r
.58389 .57151 .59375 .58195 .61276 .56946 .60301 .55893 Metetra
.027 .55 0 r
.60301 .55893 .61276 .56946 .63182 .55694 .62218 .54631 Metetra
0 .522 .036 r
.62218 .54631 .63182 .55694 .65094 .54438 .64141 .53366 Metetra
0 .495 .094 r
.64141 .53366 .65094 .54438 .67012 .53179 .6607 .52097 Metetra
0 .467 .145 r
.6607 .52097 .67012 .53179 .68935 .51916 .68004 .50824 Metetra
0 .439 .189 r
.68004 .50824 .68935 .51916 .70863 .50649 .69943 .49548 Metetra
0 .412 .226 r
.69943 .49548 .70863 .50649 .72798 .49379 .71888 .48268 Metetra
0 .384 .257 r
.71888 .48268 .72798 .49379 .74737 .48105 .73839 .46984 Metetra
0 .356 .281 r
.73839 .46984 .74737 .48105 .76682 .46827 .75796 .45696 Metetra
0 .329 .299 r
.75796 .45696 .76682 .46827 .78633 .45546 .77758 .44405 Metetra
0 .293 .301 r
.77758 .44405 .78633 .45546 .8059 .44261 .79726 .4311 Metetra
0 .233 .274 r
.79726 .4311 .8059 .44261 .82552 .42972 .81699 .41811 Metetra
0 .18 .246 r
.81699 .41811 .82552 .42972 .8452 .41679 .83679 .40509 Metetra
0 .134 .218 r
.83679 .40509 .8452 .41679 .86493 .40383 .85664 .39202 Metetra
0 .094 .191 r
.85664 .39202 .86493 .40383 .88472 .39083 .87655 .37892 Metetra
0 .061 .163 r
.87655 .37892 .88472 .39083 .90457 .37779 .89652 .36578 Metetra
0 .034 .135 r
.89652 .36578 .90457 .37779 .92448 .36472 .91654 .3526 Metetra
.965 .147 0 r
.31042 .73468 .32185 .74396 .34023 .73186 .32889 .7225 Metetra
.937 .255 0 r
.32889 .7225 .34023 .73186 .35865 .71974 .34742 .71028 Metetra
.909 .357 0 r
.34742 .71028 .35865 .71974 .37713 .70758 .366 .69803 Metetra
.882 .452 0 r
.366 .69803 .37713 .70758 .39566 .69538 .38463 .68574 Metetra
.854 .54 0 r
.38463 .68574 .39566 .69538 .41425 .68315 .40332 .67342 Metetra
.826 .621 0 r
.40332 .67342 .41425 .68315 .43288 .67089 .42205 .66107 Metetra
.799 .696 0 r
.42205 .66107 .43288 .67089 .45157 .65859 .44085 .64868 Metetra
.771 .765 0 r
.44085 .64868 .45157 .65859 .47031 .64626 .45969 .63625 Metetra
.661 .744 0 r
.45969 .63625 .47031 .64626 .48911 .63389 .47859 .62379 Metetra
.55 .716 0 r
.47859 .62379 .48911 .63389 .50796 .62148 .49755 .61129 Metetra
.447 .688 0 r
.49755 .61129 .50796 .62148 .52686 .60904 .51655 .59876 Metetra
.35 .661 0 r
.51655 .59876 .52686 .60904 .54581 .59657 .53562 .58619 Metetra
.259 .633 0 r
.53562 .58619 .54581 .59657 .56482 .58406 .55473 .57358 Metetra
.175 .605 0 r
.55473 .57358 .56482 .58406 .58389 .57151 .57391 .56094 Metetra
.098 .578 0 r
.57391 .56094 .58389 .57151 .60301 .55893 .59313 .54826 Metetra
.027 .55 0 r
.59313 .54826 .60301 .55893 .62218 .54631 .61242 .53555 Metetra
0 .522 .036 r
.61242 .53555 .62218 .54631 .64141 .53366 .63176 .5228 Metetra
0 .495 .094 r
.63176 .5228 .64141 .53366 .6607 .52097 .65115 .51001 Metetra
0 .467 .145 r
.65115 .51001 .6607 .52097 .68004 .50824 .6706 .49718 Metetra
0 .439 .189 r
.6706 .49718 .68004 .50824 .69943 .49548 .69011 .48432 Metetra
0 .412 .226 r
.69011 .48432 .69943 .49548 .71888 .48268 .70968 .47142 Metetra
0 .384 .257 r
.70968 .47142 .71888 .48268 .73839 .46984 .7293 .45848 Metetra
0 .356 .281 r
.7293 .45848 .73839 .46984 .75796 .45696 .74898 .44551 Metetra
0 .329 .299 r
.74898 .44551 .75796 .45696 .77758 .44405 .76871 .43249 Metetra
0 .293 .301 r
.76871 .43249 .77758 .44405 .79726 .4311 .78851 .41944 Metetra
0 .233 .274 r
.78851 .41944 .79726 .4311 .81699 .41811 .80836 .40635 Metetra
0 .18 .246 r
.80836 .40635 .81699 .41811 .83679 .40509 .82827 .39322 Metetra
0 .134 .218 r
.82827 .39322 .83679 .40509 .85664 .39202 .84824 .38006 Metetra
0 .094 .191 r
.84824 .38006 .85664 .39202 .87655 .37892 .86827 .36685 Metetra
0 .061 .163 r
.86827 .36685 .87655 .37892 .89652 .36578 .88835 .35361 Metetra
0 .034 .135 r
.88835 .35361 .89652 .36578 .91654 .3526 .9085 .34032 Metetra
.965 .147 0 r
.29884 .72529 .31042 .73468 .32889 .7225 .31741 .71301 Metetra
.937 .255 0 r
.31741 .71301 .32889 .7225 .34742 .71028 .33604 .70071 Metetra
.909 .357 0 r
.33604 .70071 .34742 .71028 .366 .69803 .35472 .68836 Metetra
.882 .452 0 r
.35472 .68836 .366 .69803 .38463 .68574 .37346 .67599 Metetra
.854 .54 0 r
.37346 .67599 .38463 .68574 .40332 .67342 .39225 .66357 Metetra
.826 .621 0 r
.39225 .66357 .40332 .67342 .42205 .66107 .41109 .65112 Metetra
.799 .696 0 r
.41109 .65112 .42205 .66107 .44085 .64868 .42998 .63864 Metetra
.771 .765 0 r
.42998 .63864 .44085 .64868 .45969 .63625 .44894 .62612 Metetra
.661 .744 0 r
.44894 .62612 .45969 .63625 .47859 .62379 .46794 .61356 Metetra
.55 .716 0 r
.46794 .61356 .47859 .62379 .49755 .61129 .487 .60097 Metetra
.447 .688 0 r
.487 .60097 .49755 .61129 .51655 .59876 .50612 .58834 Metetra
.35 .661 0 r
.50612 .58834 .51655 .59876 .53562 .58619 .52529 .57568 Metetra
.259 .633 0 r
.52529 .57568 .53562 .58619 .55473 .57358 .54451 .56297 Metetra
.175 .605 0 r
.54451 .56297 .55473 .57358 .57391 .56094 .56379 .55023 Metetra
.098 .578 0 r
.56379 .55023 .57391 .56094 .59313 .54826 .58313 .53746 Metetra
.027 .55 0 r
.58313 .53746 .59313 .54826 .61242 .53555 .60253 .52465 Metetra
0 .522 .036 r
.60253 .52465 .61242 .53555 .63176 .5228 .62198 .5118 Metetra
0 .495 .094 r
.62198 .5118 .63176 .5228 .65115 .51001 .64148 .49891 Metetra
0 .467 .145 r
.64148 .49891 .65115 .51001 .6706 .49718 .66105 .48598 Metetra
0 .439 .189 r
.66105 .48598 .6706 .49718 .69011 .48432 .68067 .47302 Metetra
0 .412 .226 r
.68067 .47302 .69011 .48432 .70968 .47142 .70035 .46002 Metetra
0 .384 .257 r
.70035 .46002 .70968 .47142 .7293 .45848 .72008 .44698 Metetra
0 .356 .281 r
.72008 .44698 .7293 .45848 .74898 .44551 .73988 .4339 Metetra
0 .329 .299 r
.73988 .4339 .74898 .44551 .76871 .43249 .75973 .42079 Metetra
0 .293 .301 r
.75973 .42079 .76871 .43249 .78851 .41944 .77964 .40763 Metetra
0 .233 .274 r
.77964 .40763 .78851 .41944 .80836 .40635 .79961 .39444 Metetra
0 .18 .246 r
.79961 .39444 .80836 .40635 .82827 .39322 .81964 .38121 Metetra
0 .134 .218 r
.81964 .38121 .82827 .39322 .84824 .38006 .83973 .36794 Metetra
0 .094 .191 r
.83973 .36794 .84824 .38006 .86827 .36685 .85987 .35462 Metetra
0 .061 .163 r
.85987 .35462 .86827 .36685 .88835 .35361 .88008 .34127 Metetra
0 .034 .135 r
.88008 .34127 .88835 .35361 .9085 .34032 .90035 .32788 Metetra
.965 .147 0 r
.28711 .71577 .29884 .72529 .31741 .71301 .30579 .70341 Metetra
.937 .255 0 r
.30579 .70341 .31741 .71301 .33604 .70071 .32452 .69101 Metetra
.909 .357 0 r
.32452 .69101 .33604 .70071 .35472 .68836 .3433 .67857 Metetra
.882 .452 0 r
.3433 .67857 .35472 .68836 .37346 .67599 .36214 .6661 Metetra
.854 .54 0 r
.36214 .6661 .37346 .67599 .39225 .66357 .38103 .65359 Metetra
.826 .621 0 r
.38103 .65359 .39225 .66357 .41109 .65112 .39998 .64105 Metetra
.799 .696 0 r
.39998 .64105 .41109 .65112 .42998 .63864 .41898 .62847 Metetra
.771 .765 0 r
.41898 .62847 .42998 .63864 .44894 .62612 .43804 .61586 Metetra
.661 .744 0 r
.43804 .61586 .44894 .62612 .46794 .61356 .45715 .6032 Metetra
.55 .716 0 r
.45715 .6032 .46794 .61356 .487 .60097 .47632 .59051 Metetra
.447 .688 0 r
.47632 .59051 .487 .60097 .50612 .58834 .49554 .57779 Metetra
.35 .661 0 r
.49554 .57779 .50612 .58834 .52529 .57568 .51482 .56503 Metetra
.259 .633 0 r
.51482 .56503 .52529 .57568 .54451 .56297 .53416 .55223 Metetra
.175 .605 0 r
.53416 .55223 .54451 .56297 .56379 .55023 .55355 .53939 Metetra
.098 .578 0 r
.55355 .53939 .56379 .55023 .58313 .53746 .573 .52651 Metetra
.027 .55 0 r
.573 .52651 .58313 .53746 .60253 .52465 .5925 .5136 Metetra
0 .522 .036 r
.5925 .5136 .60253 .52465 .62198 .5118 .61207 .50065 Metetra
0 .495 .094 r
.61207 .50065 .62198 .5118 .64148 .49891 .63169 .48766 Metetra
0 .467 .145 r
.63169 .48766 .64148 .49891 .66105 .48598 .65137 .47464 Metetra
0 .439 .189 r
.65137 .47464 .66105 .48598 .68067 .47302 .6711 .46157 Metetra
0 .412 .226 r
.6711 .46157 .68067 .47302 .70035 .46002 .69089 .44847 Metetra
0 .384 .257 r
.69089 .44847 .70035 .46002 .72008 .44698 .71075 .43533 Metetra
0 .356 .281 r
.71075 .43533 .72008 .44698 .73988 .4339 .73066 .42214 Metetra
0 .329 .299 r
.73066 .42214 .73988 .4339 .75973 .42079 .75063 .40892 Metetra
0 .293 .301 r
.75063 .40892 .75973 .42079 .77964 .40763 .77066 .39567 Metetra
0 .233 .274 r
.77066 .39567 .77964 .40763 .79961 .39444 .79074 .38237 Metetra
0 .18 .246 r
.79074 .38237 .79961 .39444 .81964 .38121 .81089 .36903 Metetra
0 .134 .218 r
.81089 .36903 .81964 .38121 .83973 .36794 .8311 .35565 Metetra
0 .094 .191 r
.8311 .35565 .83973 .36794 .85987 .35462 .85137 .34223 Metetra
0 .061 .163 r
.85137 .34223 .85987 .35462 .88008 .34127 .8717 .32878 Metetra
0 .034 .135 r
.8717 .32878 .88008 .34127 .90035 .32788 .89209 .31528 Metetra
.965 .147 0 r
.27523 .70614 .28711 .71577 .30579 .70341 .29401 .69368 Metetra
.937 .255 0 r
.29401 .69368 .30579 .70341 .32452 .69101 .31284 .68118 Metetra
.909 .357 0 r
.31284 .68118 .32452 .69101 .3433 .67857 .33173 .66865 Metetra
.882 .452 0 r
.33173 .66865 .3433 .67857 .36214 .6661 .35068 .65609 Metetra
.854 .54 0 r
.35068 .65609 .36214 .6661 .38103 .65359 .36968 .64349 Metetra
.826 .621 0 r
.36968 .64349 .38103 .65359 .39998 .64105 .38873 .63085 Metetra
.799 .696 0 r
.38873 .63085 .39998 .64105 .41898 .62847 .40784 .61817 Metetra
.771 .765 0 r
.40784 .61817 .41898 .62847 .43804 .61586 .427 .60546 Metetra
.661 .744 0 r
.427 .60546 .43804 .61586 .45715 .6032 .44622 .59271 Metetra
.55 .716 0 r
.44622 .59271 .45715 .6032 .47632 .59051 .4655 .57992 Metetra
.447 .688 0 r
.4655 .57992 .47632 .59051 .49554 .57779 .48483 .5671 Metetra
.35 .661 0 r
.48483 .5671 .49554 .57779 .51482 .56503 .50422 .55424 Metetra
.259 .633 0 r
.50422 .55424 .51482 .56503 .53416 .55223 .52367 .54134 Metetra
.175 .605 0 r
.52367 .54134 .53416 .55223 .55355 .53939 .54317 .5284 Metetra
.098 .578 0 r
.54317 .5284 .55355 .53939 .573 .52651 .56273 .51542 Metetra
.027 .55 0 r
.56273 .51542 .573 .52651 .5925 .5136 .58235 .50241 Metetra
0 .522 .036 r
.58235 .50241 .5925 .5136 .61207 .50065 .60203 .48936 Metetra
0 .495 .094 r
.60203 .48936 .61207 .50065 .63169 .48766 .62176 .47627 Metetra
0 .467 .145 r
.62176 .47627 .63169 .48766 .65137 .47464 .64156 .46314 Metetra
0 .439 .189 r
.64156 .46314 .65137 .47464 .6711 .46157 .66141 .44997 Metetra
0 .412 .226 r
.66141 .44997 .6711 .46157 .69089 .44847 .68132 .43676 Metetra
0 .384 .257 r
.68132 .43676 .69089 .44847 .71075 .43533 .70129 .42352 Metetra
0 .356 .281 r
.70129 .42352 .71075 .43533 .73066 .42214 .72132 .41023 Metetra
0 .329 .299 r
.72132 .41023 .73066 .42214 .75063 .40892 .7414 .39691 Metetra
0 .293 .301 r
.7414 .39691 .75063 .40892 .77066 .39567 .76155 .38354 Metetra
0 .233 .274 r
.76155 .38354 .77066 .39567 .79074 .38237 .78176 .37013 Metetra
0 .18 .246 r
.78176 .37013 .79074 .38237 .81089 .36903 .80203 .35669 Metetra
0 .134 .218 r
.80203 .35669 .81089 .36903 .8311 .35565 .82236 .3432 Metetra
0 .094 .191 r
.82236 .3432 .8311 .35565 .85137 .34223 .84275 .32968 Metetra
0 .061 .163 r
.84275 .32968 .85137 .34223 .8717 .32878 .8632 .31611 Metetra
0 .034 .135 r
.8632 .31611 .8717 .32878 .89209 .31528 .88372 .3025 Metetra
.965 .147 0 r
.2632 .69638 .27523 .70614 .29401 .69368 .28208 .68382 Metetra
.937 .255 0 r
.28208 .68382 .29401 .69368 .31284 .68118 .30102 .67123 Metetra
.909 .357 0 r
.30102 .67123 .31284 .68118 .33173 .66865 .32002 .65861 Metetra
.882 .452 0 r
.32002 .65861 .33173 .66865 .35068 .65609 .33907 .64595 Metetra
.854 .54 0 r
.33907 .64595 .35068 .65609 .36968 .64349 .35817 .63325 Metetra
.826 .621 0 r
.35817 .63325 .36968 .64349 .38873 .63085 .37733 .62051 Metetra
.799 .696 0 r
.37733 .62051 .38873 .63085 .40784 .61817 .39655 .60774 Metetra
.771 .765 0 r
.39655 .60774 .40784 .61817 .427 .60546 .41582 .59493 Metetra
.661 .744 0 r
.41582 .59493 .427 .60546 .44622 .59271 .43515 .58208 Metetra
.55 .716 0 r
.43515 .58208 .44622 .59271 .4655 .57992 .45454 .56919 Metetra
.447 .688 0 r
.45454 .56919 .4655 .57992 .48483 .5671 .47398 .55627 Metetra
.35 .661 0 r
.47398 .55627 .48483 .5671 .50422 .55424 .49348 .5433 Metetra
.259 .633 0 r
.49348 .5433 .50422 .55424 .52367 .54134 .51304 .5303 Metetra
.175 .605 0 r
.51304 .5303 .52367 .54134 .54317 .5284 .53266 .51727 Metetra
.098 .578 0 r
.53266 .51727 .54317 .5284 .56273 .51542 .55233 .50419 Metetra
.027 .55 0 r
.55233 .50419 .56273 .51542 .58235 .50241 .57207 .49107 Metetra
0 .522 .036 r
.57207 .49107 .58235 .50241 .60203 .48936 .59186 .47792 Metetra
0 .495 .094 r
.59186 .47792 .60203 .48936 .62176 .47627 .61171 .46472 Metetra
0 .467 .145 r
.61171 .46472 .62176 .47627 .64156 .46314 .63162 .45149 Metetra
0 .439 .189 r
.63162 .45149 .64156 .46314 .66141 .44997 .65159 .43822 Metetra
0 .412 .226 r
.65159 .43822 .66141 .44997 .68132 .43676 .67161 .4249 Metetra
0 .384 .257 r
.67161 .4249 .68132 .43676 .70129 .42352 .6917 .41155 Metetra
0 .356 .281 r
.6917 .41155 .70129 .42352 .72132 .41023 .71185 .39816 Metetra
0 .329 .299 r
.71185 .39816 .72132 .41023 .7414 .39691 .73206 .38473 Metetra
0 .293 .301 r
.73206 .38473 .7414 .39691 .76155 .38354 .75233 .37125 Metetra
0 .233 .274 r
.75233 .37125 .76155 .38354 .78176 .37013 .77266 .35774 Metetra
0 .18 .246 r
.77266 .35774 .78176 .37013 .80203 .35669 .79305 .34418 Metetra
0 .134 .218 r
.79305 .34418 .80203 .35669 .82236 .3432 .8135 .33059 Metetra
0 .094 .191 r
.8135 .33059 .82236 .3432 .84275 .32968 .83402 .31695 Metetra
0 .061 .163 r
.83402 .31695 .84275 .32968 .8632 .31611 .8546 .30328 Metetra
0 .034 .135 r
.8546 .30328 .8632 .31611 .88372 .3025 .87523 .28956 Metetra
.965 .147 0 r
.25101 .68649 .2632 .69638 .28208 .68382 .27 .67384 Metetra
.937 .255 0 r
.27 .67384 .28208 .68382 .30102 .67123 .28904 .66115 Metetra
.909 .357 0 r
.28904 .66115 .30102 .67123 .32002 .65861 .30815 .64843 Metetra
.882 .452 0 r
.30815 .64843 .32002 .65861 .33907 .64595 .3273 .63567 Metetra
.854 .54 0 r
.3273 .63567 .33907 .64595 .35817 .63325 .34652 .62287 Metetra
.826 .621 0 r
.34652 .62287 .35817 .63325 .37733 .62051 .36578 .61004 Metetra
.799 .696 0 r
.36578 .61004 .37733 .62051 .39655 .60774 .38511 .59717 Metetra
.771 .765 0 r
.38511 .59717 .39655 .60774 .41582 .59493 .40449 .58426 Metetra
.661 .744 0 r
.40449 .58426 .41582 .59493 .43515 .58208 .42393 .57131 Metetra
.55 .716 0 r
.42393 .57131 .43515 .58208 .45454 .56919 .44343 .55832 Metetra
.447 .688 0 r
.44343 .55832 .45454 .56919 .47398 .55627 .46299 .54529 Metetra
.35 .661 0 r
.46299 .54529 .47398 .55627 .49348 .5433 .4826 .53223 Metetra
.259 .633 0 r
.4826 .53223 .49348 .5433 .51304 .5303 .50227 .51913 Metetra
.175 .605 0 r
.50227 .51913 .51304 .5303 .53266 .51727 .522 .50598 Metetra
.098 .578 0 r
.522 .50598 .53266 .51727 .55233 .50419 .54179 .4928 Metetra
.027 .55 0 r
.54179 .4928 .55233 .50419 .57207 .49107 .56164 .47958 Metetra
0 .522 .036 r
.56164 .47958 .57207 .49107 .59186 .47792 .58155 .46632 Metetra
0 .495 .094 r
.58155 .46632 .59186 .47792 .61171 .46472 .60152 .45302 Metetra
0 .467 .145 r
.60152 .45302 .61171 .46472 .63162 .45149 .62154 .43968 Metetra
0 .439 .189 r
.62154 .43968 .63162 .45149 .65159 .43822 .64163 .4263 Metetra
0 .412 .226 r
.64163 .4263 .65159 .43822 .67161 .4249 .66178 .41288 Metetra
0 .384 .257 r
.66178 .41288 .67161 .4249 .6917 .41155 .68199 .39942 Metetra
0 .356 .281 r
.68199 .39942 .6917 .41155 .71185 .39816 .70226 .38592 Metetra
0 .329 .299 r
.70226 .38592 .71185 .39816 .73206 .38473 .72259 .37238 Metetra
0 .293 .301 r
.72259 .37238 .73206 .38473 .75233 .37125 .74298 .3588 Metetra
0 .233 .274 r
.74298 .3588 .75233 .37125 .77266 .35774 .76343 .34517 Metetra
0 .18 .246 r
.76343 .34517 .77266 .35774 .79305 .34418 .78395 .33151 Metetra
0 .134 .218 r
.78395 .33151 .79305 .34418 .8135 .33059 .80453 .3178 Metetra
0 .094 .191 r
.80453 .3178 .8135 .33059 .83402 .31695 .82517 .30405 Metetra
0 .061 .163 r
.82517 .30405 .83402 .31695 .8546 .30328 .84587 .29026 Metetra
0 .034 .135 r
.84587 .29026 .8546 .30328 .87523 .28956 .86664 .27643 Metetra
.965 .147 0 r
.23866 .67647 .25101 .68649 .27 .67384 .25776 .66373 Metetra
.937 .255 0 r
.25776 .66373 .27 .67384 .28904 .66115 .27691 .65094 Metetra
.909 .357 0 r
.27691 .65094 .28904 .66115 .30815 .64843 .29612 .63812 Metetra
.882 .452 0 r
.29612 .63812 .30815 .64843 .3273 .63567 .31538 .62526 Metetra
.854 .54 0 r
.31538 .62526 .3273 .63567 .34652 .62287 .33471 .61236 Metetra
.826 .621 0 r
.33471 .61236 .34652 .62287 .36578 .61004 .35409 .59943 Metetra
.799 .696 0 r
.35409 .59943 .36578 .61004 .38511 .59717 .37352 .58646 Metetra
.771 .765 0 r
.37352 .58646 .38511 .59717 .40449 .58426 .39302 .57344 Metetra
.661 .744 0 r
.39302 .57344 .40449 .58426 .42393 .57131 .41257 .56039 Metetra
.55 .716 0 r
.41257 .56039 .42393 .57131 .44343 .55832 .43218 .5473 Metetra
.447 .688 0 r
.43218 .5473 .44343 .55832 .46299 .54529 .45185 .53417 Metetra
.35 .661 0 r
.45185 .53417 .46299 .54529 .4826 .53223 .47158 .52101 Metetra
.259 .633 0 r
.47158 .52101 .4826 .53223 .50227 .51913 .49136 .5078 Metetra
.175 .605 0 r
.49136 .5078 .50227 .51913 .522 .50598 .51121 .49455 Metetra
.098 .578 0 r
.51121 .49455 .522 .50598 .54179 .4928 .53111 .48127 Metetra
.027 .55 0 r
.53111 .48127 .54179 .4928 .56164 .47958 .55108 .46794 Metetra
0 .522 .036 r
.55108 .46794 .56164 .47958 .58155 .46632 .5711 .45457 Metetra
0 .495 .094 r
.5711 .45457 .58155 .46632 .60152 .45302 .59119 .44117 Metetra
0 .467 .145 r
.59119 .44117 .60152 .45302 .62154 .43968 .61134 .42772 Metetra
0 .439 .189 r
.61134 .42772 .62154 .43968 .64163 .4263 .63154 .41423 Metetra
0 .412 .226 r
.63154 .41423 .64163 .4263 .66178 .41288 .65181 .4007 Metetra
0 .384 .257 r
.65181 .4007 .66178 .41288 .68199 .39942 .67214 .38713 Metetra
0 .356 .281 r
.67214 .38713 .68199 .39942 .70226 .38592 .69253 .37352 Metetra
0 .329 .299 r
.69253 .37352 .70226 .38592 .72259 .37238 .71299 .35987 Metetra
0 .293 .301 r
.71299 .35987 .72259 .37238 .74298 .3588 .7335 .34618 Metetra
0 .233 .274 r
.7335 .34618 .74298 .3588 .76343 .34517 .75408 .33244 Metetra
0 .18 .246 r
.75408 .33244 .76343 .34517 .78395 .33151 .77472 .31866 Metetra
0 .134 .218 r
.77472 .31866 .78395 .33151 .80453 .3178 .79543 .30484 Metetra
0 .094 .191 r
.79543 .30484 .80453 .3178 .82517 .30405 .81619 .29098 Metetra
0 .061 .163 r
.81619 .29098 .82517 .30405 .84587 .29026 .83702 .27708 Metetra
0 .034 .135 r
.83702 .27708 .84587 .29026 .86664 .27643 .85792 .26313 Metetra
.965 .147 0 r
.22615 .66632 .23866 .67647 .25776 .66373 .24536 .65348 Metetra
.937 .255 0 r
.24536 .65348 .25776 .66373 .27691 .65094 .26462 .64059 Metetra
.909 .357 0 r
.26462 .64059 .27691 .65094 .29612 .63812 .28393 .62767 Metetra
.882 .452 0 r
.28393 .62767 .29612 .63812 .31538 .62526 .30331 .61471 Metetra
.854 .54 0 r
.30331 .61471 .31538 .62526 .33471 .61236 .32274 .60171 Metetra
.826 .621 0 r
.32274 .60171 .33471 .61236 .35409 .59943 .34223 .58868 Metetra
.799 .696 0 r
.34223 .58868 .35409 .59943 .37352 .58646 .36178 .5756 Metetra
.771 .765 0 r
.36178 .5756 .37352 .58646 .39302 .57344 .38139 .56249 Metetra
.661 .744 0 r
.38139 .56249 .39302 .57344 .41257 .56039 .40105 .54933 Metetra
.55 .716 0 r
.40105 .54933 .41257 .56039 .43218 .5473 .42078 .53614 Metetra
.447 .688 0 r
.42078 .53614 .43218 .5473 .45185 .53417 .44056 .52291 Metetra
.35 .661 0 r
.44056 .52291 .45185 .53417 .47158 .52101 .4604 .50963 Metetra
.259 .633 0 r
.4604 .50963 .47158 .52101 .49136 .5078 .4803 .49632 Metetra
.175 .605 0 r
.4803 .49632 .49136 .5078 .51121 .49455 .50027 .48297 Metetra
.098 .578 0 r
.50027 .48297 .51121 .49455 .53111 .48127 .52029 .46957 Metetra
.027 .55 0 r
.52029 .46957 .53111 .48127 .55108 .46794 .54037 .45614 Metetra
0 .522 .036 r
.54037 .45614 .55108 .46794 .5711 .45457 .56052 .44266 Metetra
0 .495 .094 r
.56052 .44266 .5711 .45457 .59119 .44117 .58072 .42915 Metetra
0 .467 .145 r
.58072 .42915 .59119 .44117 .61134 .42772 .60099 .41559 Metetra
0 .439 .189 r
.60099 .41559 .61134 .42772 .63154 .41423 .62132 .40199 Metetra
0 .412 .226 r
.62132 .40199 .63154 .41423 .65181 .4007 .64171 .38835 Metetra
0 .384 .257 r
.64171 .38835 .65181 .4007 .67214 .38713 .66216 .37467 Metetra
0 .356 .281 r
.66216 .37467 .67214 .38713 .69253 .37352 .68268 .36095 Metetra
0 .329 .299 r
.68268 .36095 .69253 .37352 .71299 .35987 .70325 .34719 Metetra
0 .293 .301 r
.70325 .34719 .71299 .35987 .7335 .34618 .7239 .33338 Metetra
0 .233 .274 r
.7239 .33338 .7335 .34618 .75408 .33244 .7446 .31953 Metetra
0 .18 .246 r
.7446 .31953 .75408 .33244 .77472 .31866 .76537 .30564 Metetra
0 .134 .218 r
.76537 .30564 .77472 .31866 .79543 .30484 .7862 .2917 Metetra
0 .094 .191 r
.7862 .2917 .79543 .30484 .81619 .29098 .8071 .27773 Metetra
0 .061 .163 r
.8071 .27773 .81619 .29098 .83702 .27708 .82806 .26371 Metetra
0 .034 .135 r
.82806 .26371 .83702 .27708 .85792 .26313 .84908 .24964 Metetra
.965 .147 0 r
.21348 .65604 .22615 .66632 .24536 .65348 .23279 .64309 Metetra
.937 .255 0 r
.23279 .64309 .24536 .65348 .26462 .64059 .25216 .63011 Metetra
.909 .357 0 r
.25216 .63011 .26462 .64059 .28393 .62767 .27159 .61709 Metetra
.882 .452 0 r
.27159 .61709 .28393 .62767 .30331 .61471 .29107 .60402 Metetra
.854 .54 0 r
.29107 .60402 .30331 .61471 .32274 .60171 .31061 .59092 Metetra
.826 .621 0 r
.31061 .59092 .32274 .60171 .34223 .58868 .33022 .57778 Metetra
.799 .696 0 r
.33022 .57778 .34223 .58868 .36178 .5756 .34988 .5646 Metetra
.771 .765 0 r
.34988 .5646 .36178 .5756 .38139 .56249 .3696 .55138 Metetra
.661 .744 0 r
.3696 .55138 .38139 .56249 .40105 .54933 .38938 .53812 Metetra
.55 .716 0 r
.38938 .53812 .40105 .54933 .42078 .53614 .40922 .52482 Metetra
.447 .688 0 r
.40922 .52482 .42078 .53614 .44056 .52291 .42912 .51149 Metetra
.35 .661 0 r
.42912 .51149 .44056 .52291 .4604 .50963 .44908 .49811 Metetra
.259 .633 0 r
.44908 .49811 .4604 .50963 .4803 .49632 .4691 .48468 Metetra
.175 .605 0 r
.4691 .48468 .4803 .49632 .50027 .48297 .48918 .47122 Metetra
.098 .578 0 r
.48918 .47122 .50027 .48297 .52029 .46957 .50932 .45772 Metetra
.027 .55 0 r
.50932 .45772 .52029 .46957 .54037 .45614 .52952 .44418 Metetra
0 .522 .036 r
.52952 .44418 .54037 .45614 .56052 .44266 .54979 .43059 Metetra
0 .495 .094 r
.54979 .43059 .56052 .44266 .58072 .42915 .57011 .41697 Metetra
0 .467 .145 r
.57011 .41697 .58072 .42915 .60099 .41559 .5905 .4033 Metetra
0 .439 .189 r
.5905 .4033 .60099 .41559 .62132 .40199 .61095 .38959 Metetra
0 .412 .226 r
.61095 .38959 .62132 .40199 .64171 .38835 .63147 .37584 Metetra
0 .384 .257 r
.63147 .37584 .64171 .38835 .66216 .37467 .65204 .36205 Metetra
0 .356 .281 r
.65204 .36205 .66216 .37467 .68268 .36095 .67269 .34821 Metetra
0 .329 .299 r
.67269 .34821 .68268 .36095 .70325 .34719 .69339 .33433 Metetra
0 .293 .301 r
.69339 .33433 .70325 .34719 .7239 .33338 .71416 .32041 Metetra
0 .233 .274 r
.71416 .32041 .7239 .33338 .7446 .31953 .73499 .30644 Metetra
0 .18 .246 r
.73499 .30644 .7446 .31953 .76537 .30564 .75589 .29243 Metetra
0 .134 .218 r
.75589 .29243 .76537 .30564 .7862 .2917 .77685 .27838 Metetra
0 .094 .191 r
.77685 .27838 .7862 .2917 .8071 .27773 .79787 .26429 Metetra
0 .061 .163 r
.79787 .26429 .8071 .27773 .82806 .26371 .81897 .25015 Metetra
0 .034 .135 r
.81897 .25015 .82806 .26371 .84908 .24964 .84012 .23597 Metetra
.965 .147 0 r
.20063 .64562 .21348 .65604 .23279 .64309 .22005 .63257 Metetra
.937 .255 0 r
.22005 .63257 .23279 .64309 .25216 .63011 .23953 .61948 Metetra
.909 .357 0 r
.23953 .61948 .25216 .63011 .27159 .61709 .25907 .60636 Metetra
.882 .452 0 r
.25907 .60636 .27159 .61709 .29107 .60402 .27867 .59319 Metetra
.854 .54 0 r
.27867 .59319 .29107 .60402 .31061 .59092 .29833 .57999 Metetra
.826 .621 0 r
.29833 .57999 .31061 .59092 .33022 .57778 .31804 .56674 Metetra
.799 .696 0 r
.31804 .56674 .33022 .57778 .34988 .5646 .33782 .55346 Metetra
.771 .765 0 r
.33782 .55346 .34988 .5646 .3696 .55138 .35765 .54013 Metetra
.661 .744 0 r
.35765 .54013 .3696 .55138 .38938 .53812 .37755 .52676 Metetra
.55 .716 0 r
.37755 .52676 .38938 .53812 .40922 .52482 .3975 .51336 Metetra
.447 .688 0 r
.3975 .51336 .40922 .52482 .42912 .51149 .41752 .49991 Metetra
.35 .661 0 r
.41752 .49991 .42912 .51149 .44908 .49811 .4376 .48642 Metetra
.259 .633 0 r
.4376 .48642 .44908 .49811 .4691 .48468 .45774 .47289 Metetra
.175 .605 0 r
.45774 .47289 .4691 .48468 .48918 .47122 .47794 .45932 Metetra
.098 .578 0 r
.47794 .45932 .48918 .47122 .50932 .45772 .4982 .44571 Metetra
.027 .55 0 r
.4982 .44571 .50932 .45772 .52952 .44418 .51852 .43205 Metetra
0 .522 .036 r
.51852 .43205 .52952 .44418 .54979 .43059 .53891 .41836 Metetra
0 .495 .094 r
.53891 .41836 .54979 .43059 .57011 .41697 .55936 .40462 Metetra
0 .467 .145 r
.55936 .40462 .57011 .41697 .5905 .4033 .57987 .39084 Metetra
0 .439 .189 r
.57987 .39084 .5905 .4033 .61095 .38959 .60045 .37702 Metetra
0 .412 .226 r
.60045 .37702 .61095 .38959 .63147 .37584 .62109 .36315 Metetra
0 .384 .257 r
.62109 .36315 .63147 .37584 .65204 .36205 .64179 .34924 Metetra
0 .356 .281 r
.64179 .34924 .65204 .36205 .67269 .34821 .66256 .33529 Metetra
0 .329 .299 r
.66256 .33529 .67269 .34821 .69339 .33433 .68339 .32129 Metetra
0 .293 .301 r
.68339 .32129 .69339 .33433 .71416 .32041 .70428 .30726 Metetra
0 .233 .274 r
.70428 .30726 .71416 .32041 .73499 .30644 .72524 .29317 Metetra
0 .18 .246 r
.72524 .29317 .73499 .30644 .75589 .29243 .74627 .27905 Metetra
0 .134 .218 r
.74627 .27905 .75589 .29243 .77685 .27838 .76736 .26488 Metetra
0 .094 .191 r
.76736 .26488 .77685 .27838 .79787 .26429 .78852 .25066 Metetra
0 .061 .163 r
.78852 .25066 .79787 .26429 .81897 .25015 .80975 .2364 Metetra
0 .034 .135 r
.80975 .2364 .81897 .25015 .84012 .23597 .83104 .2221 Metetra
.965 .147 0 r
.18761 .63506 .20063 .64562 .22005 .63257 .20715 .62191 Metetra
.937 .255 0 r
.20715 .62191 .22005 .63257 .23953 .61948 .22674 .60872 Metetra
.909 .357 0 r
.22674 .60872 .23953 .61948 .25907 .60636 .24639 .59549 Metetra
.882 .452 0 r
.24639 .59549 .25907 .60636 .27867 .59319 .2661 .58221 Metetra
.854 .54 0 r
.2661 .58221 .27867 .59319 .29833 .57999 .28587 .5689 Metetra
.826 .621 0 r
.28587 .5689 .29833 .57999 .31804 .56674 .3057 .55555 Metetra
.799 .696 0 r
.3057 .55555 .31804 .56674 .33782 .55346 .32559 .54216 Metetra
.771 .765 0 r
.32559 .54216 .33782 .55346 .35765 .54013 .34554 .52872 Metetra
.661 .744 0 r
.34554 .52872 .35765 .54013 .37755 .52676 .36556 .51525 Metetra
.55 .716 0 r
.36556 .51525 .37755 .52676 .3975 .51336 .38563 .50173 Metetra
.447 .688 0 r
.38563 .50173 .3975 .51336 .41752 .49991 .40576 .48818 Metetra
.35 .661 0 r
.40576 .48818 .41752 .49991 .4376 .48642 .42596 .47458 Metetra
.259 .633 0 r
.42596 .47458 .4376 .48642 .45774 .47289 .44622 .46094 Metetra
.175 .605 0 r
.44622 .46094 .45774 .47289 .47794 .45932 .46654 .44725 Metetra
.098 .578 0 r
.46654 .44725 .47794 .45932 .4982 .44571 .48693 .43353 Metetra
.027 .55 0 r
.48693 .43353 .4982 .44571 .51852 .43205 .50737 .41976 Metetra
0 .522 .036 r
.50737 .41976 .51852 .43205 .53891 .41836 .52788 .40595 Metetra
0 .495 .094 r
.52788 .40595 .53891 .41836 .55936 .40462 .54846 .3921 Metetra
0 .467 .145 r
.54846 .3921 .55936 .40462 .57987 .39084 .56909 .37821 Metetra
0 .439 .189 r
.56909 .37821 .57987 .39084 .60045 .37702 .58979 .36427 Metetra
0 .412 .226 r
.58979 .36427 .60045 .37702 .62109 .36315 .61056 .35029 Metetra
0 .384 .257 r
.61056 .35029 .62109 .36315 .64179 .34924 .63139 .33626 Metetra
0 .356 .281 r
.63139 .33626 .64179 .34924 .66256 .33529 .65229 .32219 Metetra
0 .329 .299 r
.65229 .32219 .66256 .33529 .68339 .32129 .67325 .30808 Metetra
0 .293 .301 r
.67325 .30808 .68339 .32129 .70428 .30726 .69427 .29392 Metetra
0 .233 .274 r
.69427 .29392 .70428 .30726 .72524 .29317 .71536 .27972 Metetra
0 .18 .246 r
.71536 .27972 .72524 .29317 .74627 .27905 .73652 .26547 Metetra
0 .134 .218 r
.73652 .26547 .74627 .27905 .76736 .26488 .75775 .25118 Metetra
0 .094 .191 r
.75775 .25118 .76736 .26488 .78852 .25066 .77904 .23685 Metetra
0 .061 .163 r
.77904 .23685 .78852 .25066 .80975 .2364 .8004 .22247 Metetra
0 .034 .135 r
.8004 .22247 .80975 .2364 .83104 .2221 .82183 .20804 Metetra
.965 .147 0 r
.17442 .62436 .18761 .63506 .20715 .62191 .19407 .6111 Metetra
.937 .255 0 r
.19407 .6111 .20715 .62191 .22674 .60872 .21377 .5978 Metetra
.909 .357 0 r
.21377 .5978 .22674 .60872 .24639 .59549 .23354 .58446 Metetra
.882 .452 0 r
.23354 .58446 .24639 .59549 .2661 .58221 .25336 .57109 Metetra
.854 .54 0 r
.25336 .57109 .2661 .58221 .28587 .5689 .27325 .55767 Metetra
.826 .621 0 r
.27325 .55767 .28587 .5689 .3057 .55555 .29319 .54421 Metetra
.799 .696 0 r
.29319 .54421 .3057 .55555 .32559 .54216 .3132 .5307 Metetra
.771 .765 0 r
.3132 .5307 .32559 .54216 .34554 .52872 .33327 .51716 Metetra
.661 .744 0 r
.33327 .51716 .34554 .52872 .36556 .51525 .3534 .50358 Metetra
.55 .716 0 r
.3534 .50358 .36556 .51525 .38563 .50173 .37359 .48995 Metetra
.447 .688 0 r
.37359 .48995 .38563 .50173 .40576 .48818 .39385 .47628 Metetra
.35 .661 0 r
.39385 .47628 .40576 .48818 .42596 .47458 .41417 .46257 Metetra
.259 .633 0 r
.41417 .46257 .42596 .47458 .44622 .46094 .43455 .44882 Metetra
.175 .605 0 r
.43455 .44882 .44622 .46094 .46654 .44725 .45499 .43502 Metetra
.098 .578 0 r
.45499 .43502 .46654 .44725 .48693 .43353 .4755 .42118 Metetra
.027 .55 0 r
.4755 .42118 .48693 .43353 .50737 .41976 .49607 .4073 Metetra
0 .522 .036 r
.49607 .4073 .50737 .41976 .52788 .40595 .5167 .39338 Metetra
0 .495 .094 r
.5167 .39338 .52788 .40595 .54846 .3921 .5374 .37941 Metetra
0 .467 .145 r
.5374 .37941 .54846 .3921 .56909 .37821 .55816 .3654 Metetra
0 .439 .189 r
.55816 .3654 .56909 .37821 .58979 .36427 .57899 .35134 Metetra
0 .412 .226 r
.57899 .35134 .58979 .36427 .61056 .35029 .59989 .33724 Metetra
0 .384 .257 r
.59989 .33724 .61056 .35029 .63139 .33626 .62085 .3231 Metetra
0 .356 .281 r
.62085 .3231 .63139 .33626 .65229 .32219 .64187 .30891 Metetra
0 .329 .299 r
.64187 .30891 .65229 .32219 .67325 .30808 .66296 .29468 Metetra
0 .293 .301 r
.66296 .29468 .67325 .30808 .69427 .29392 .68412 .2804 Metetra
0 .233 .274 r
.68412 .2804 .69427 .29392 .71536 .27972 .70534 .26608 Metetra
0 .18 .246 r
.70534 .26608 .71536 .27972 .73652 .26547 .72664 .25171 Metetra
0 .134 .218 r
.72664 .25171 .73652 .26547 .75775 .25118 .748 .23729 Metetra
0 .094 .191 r
.748 .23729 .75775 .25118 .77904 .23685 .76942 .22283 Metetra
0 .061 .163 r
.76942 .22283 .77904 .23685 .8004 .22247 .79092 .20833 Metetra
0 .034 .135 r
.79092 .20833 .8004 .22247 .82183 .20804 .81248 .19378 Metetra
.965 .147 0 r
.16105 .61351 .17442 .62436 .19407 .6111 .18081 .60014 Metetra
.937 .255 0 r
.18081 .60014 .19407 .6111 .21377 .5978 .20063 .58674 Metetra
.909 .357 0 r
.20063 .58674 .21377 .5978 .23354 .58446 .22051 .57329 Metetra
.882 .452 0 r
.22051 .57329 .23354 .58446 .25336 .57109 .24045 .55981 Metetra
.854 .54 0 r
.24045 .55981 .25336 .57109 .27325 .55767 .26045 .54628 Metetra
.826 .621 0 r
.26045 .54628 .27325 .55767 .29319 .54421 .28051 .53271 Metetra
.799 .696 0 r
.28051 .53271 .29319 .54421 .3132 .5307 .30064 .51909 Metetra
.771 .765 0 r
.30064 .51909 .3132 .5307 .33327 .51716 .32083 .50544 Metetra
.661 .744 0 r
.32083 .50544 .33327 .51716 .3534 .50358 .34108 .49174 Metetra
.55 .716 0 r
.34108 .49174 .3534 .50358 .37359 .48995 .36139 .478 Metetra
.447 .688 0 r
.36139 .478 .37359 .48995 .39385 .47628 .38177 .46422 Metetra
.35 .661 0 r
.38177 .46422 .39385 .47628 .41417 .46257 .40221 .4504 Metetra
.259 .633 0 r
.40221 .4504 .41417 .46257 .43455 .44882 .42271 .43653 Metetra
.175 .605 0 r
.42271 .43653 .43455 .44882 .45499 .43502 .44328 .42262 Metetra
.098 .578 0 r
.44328 .42262 .45499 .43502 .4755 .42118 .46391 .40866 Metetra
.027 .55 0 r
.46391 .40866 .4755 .42118 .49607 .4073 .4846 .39467 Metetra
0 .522 .036 r
.4846 .39467 .49607 .4073 .5167 .39338 .50536 .38062 Metetra
0 .495 .094 r
.50536 .38062 .5167 .39338 .5374 .37941 .52619 .36654 Metetra
0 .467 .145 r
.52619 .36654 .5374 .37941 .55816 .3654 .54708 .35241 Metetra
0 .439 .189 r
.54708 .35241 .55816 .3654 .57899 .35134 .56804 .33823 Metetra
0 .412 .226 r
.56804 .33823 .57899 .35134 .59989 .33724 .58906 .32401 Metetra
0 .384 .257 r
.58906 .32401 .59989 .33724 .62085 .3231 .61015 .30975 Metetra
0 .356 .281 r
.61015 .30975 .62085 .3231 .64187 .30891 .63131 .29544 Metetra
0 .329 .299 r
.63131 .29544 .64187 .30891 .66296 .29468 .65253 .28108 Metetra
0 .293 .301 r
.65253 .28108 .66296 .29468 .68412 .2804 .67382 .26668 Metetra
0 .233 .274 r
.67382 .26668 .68412 .2804 .70534 .26608 .69518 .25224 Metetra
0 .18 .246 r
.69518 .25224 .70534 .26608 .72664 .25171 .71661 .23775 Metetra
0 .134 .218 r
.71661 .23775 .72664 .25171 .748 .23729 .73811 .22321 Metetra
0 .094 .191 r
.73811 .22321 .748 .23729 .76942 .22283 .75967 .20862 Metetra
0 .061 .163 r
.75967 .20862 .76942 .22283 .79092 .20833 .7813 .19399 Metetra
0 .034 .135 r
.7813 .19399 .79092 .20833 .81248 .19378 .803 .17931 Metetra
.965 .147 0 r
.14749 .60251 .16105 .61351 .18081 .60014 .16736 .58904 Metetra
.937 .255 0 r
.16736 .58904 .18081 .60014 .20063 .58674 .1873 .57552 Metetra
.909 .357 0 r
.1873 .57552 .20063 .58674 .22051 .57329 .2073 .56197 Metetra
.882 .452 0 r
.2073 .56197 .22051 .57329 .24045 .55981 .22735 .54837 Metetra
.854 .54 0 r
.22735 .54837 .24045 .55981 .26045 .54628 .24747 .53473 Metetra
.826 .621 0 r
.24747 .53473 .26045 .54628 .28051 .53271 .26766 .52105 Metetra
.799 .696 0 r
.26766 .52105 .28051 .53271 .30064 .51909 .2879 .50732 Metetra
.771 .765 0 r
.2879 .50732 .30064 .51909 .32083 .50544 .30821 .49356 Metetra
.661 .744 0 r
.30821 .49356 .32083 .50544 .34108 .49174 .32858 .47975 Metetra
.55 .716 0 r
.32858 .47975 .34108 .49174 .36139 .478 .34902 .46589 Metetra
.447 .688 0 r
.34902 .46589 .36139 .478 .38177 .46422 .36951 .45199 Metetra
.35 .661 0 r
.36951 .45199 .38177 .46422 .40221 .4504 .39008 .43805 Metetra
.259 .633 0 r
.39008 .43805 .40221 .4504 .42271 .43653 .41071 .42407 Metetra
.175 .605 0 r
.41071 .42407 .42271 .43653 .44328 .42262 .4314 .41004 Metetra
.098 .578 0 r
.4314 .41004 .44328 .42262 .46391 .40866 .45216 .39597 Metetra
.027 .55 0 r
.45216 .39597 .46391 .40866 .4846 .39467 .47298 .38185 Metetra
0 .522 .036 r
.47298 .38185 .4846 .39467 .50536 .38062 .49387 .36769 Metetra
0 .495 .094 r
.49387 .36769 .50536 .38062 .52619 .36654 .51482 .35349 Metetra
0 .467 .145 r
.51482 .35349 .52619 .36654 .54708 .35241 .53584 .33924 Metetra
0 .439 .189 r
.53584 .33924 .54708 .35241 .56804 .33823 .55693 .32494 Metetra
0 .412 .226 r
.55693 .32494 .56804 .33823 .58906 .32401 .57809 .3106 Metetra
0 .384 .257 r
.57809 .3106 .58906 .32401 .61015 .30975 .59931 .29621 Metetra
0 .356 .281 r
.59931 .29621 .61015 .30975 .63131 .29544 .6206 .28178 Metetra
0 .329 .299 r
.6206 .28178 .63131 .29544 .65253 .28108 .64196 .2673 Metetra
0 .293 .301 r
.64196 .2673 .65253 .28108 .67382 .26668 .66338 .25277 Metetra
0 .233 .274 r
.66338 .25277 .67382 .26668 .69518 .25224 .68488 .2382 Metetra
0 .18 .246 r
.68488 .2382 .69518 .25224 .71661 .23775 .70644 .22358 Metetra
0 .134 .218 r
.70644 .22358 .71661 .23775 .73811 .22321 .72807 .20892 Metetra
0 .094 .191 r
.72807 .20892 .73811 .22321 .75967 .20862 .74978 .19421 Metetra
0 .061 .163 r
.74978 .19421 .75967 .20862 .7813 .19399 .77155 .17945 Metetra
0 .034 .135 r
.77155 .17945 .7813 .19399 .803 .17931 .79339 .16464 Metetra
.965 .147 0 r
.13375 .59136 .14749 .60251 .16736 .58904 .15374 .57778 Metetra
.937 .255 0 r
.15374 .57778 .16736 .58904 .1873 .57552 .17379 .56415 Metetra
.909 .357 0 r
.17379 .56415 .1873 .57552 .2073 .56197 .1939 .55048 Metetra
.882 .452 0 r
.1939 .55048 .2073 .56197 .22735 .54837 .21408 .53677 Metetra
.854 .54 0 r
.21408 .53677 .22735 .54837 .24747 .53473 .23432 .52302 Metetra
.826 .621 0 r
.23432 .52302 .24747 .53473 .26766 .52105 .25462 .50923 Metetra
.799 .696 0 r
.25462 .50923 .26766 .52105 .2879 .50732 .27499 .49539 Metetra
.771 .765 0 r
.27499 .49539 .2879 .50732 .30821 .49356 .29542 .4815 Metetra
.661 .744 0 r
.29542 .4815 .30821 .49356 .32858 .47975 .31591 .46758 Metetra
.55 .716 0 r
.31591 .46758 .32858 .47975 .34902 .46589 .33647 .45361 Metetra
.447 .688 0 r
.33647 .45361 .34902 .46589 .36951 .45199 .35709 .4396 Metetra
.35 .661 0 r
.35709 .4396 .36951 .45199 .39008 .43805 .37778 .42554 Metetra
.259 .633 0 r
.37778 .42554 .39008 .43805 .41071 .42407 .39853 .41144 Metetra
.175 .605 0 r
.39853 .41144 .41071 .42407 .4314 .41004 .41935 .39729 Metetra
.098 .578 0 r
.41935 .39729 .4314 .41004 .45216 .39597 .44024 .3831 Metetra
.027 .55 0 r
.44024 .3831 .45216 .39597 .47298 .38185 .46119 .36886 Metetra
0 .522 .036 r
.46119 .36886 .47298 .38185 .49387 .36769 .48221 .35458 Metetra
0 .495 .094 r
.48221 .35458 .49387 .36769 .51482 .35349 .50329 .34025 Metetra
0 .467 .145 r
.50329 .34025 .51482 .35349 .53584 .33924 .52445 .32588 Metetra
0 .439 .189 r
.52445 .32588 .53584 .33924 .55693 .32494 .54567 .31146 Metetra
0 .412 .226 r
.54567 .31146 .55693 .32494 .57809 .3106 .56695 .29699 Metetra
0 .384 .257 r
.56695 .29699 .57809 .3106 .59931 .29621 .58831 .28248 Metetra
0 .356 .281 r
.58831 .28248 .59931 .29621 .6206 .28178 .60973 .26792 Metetra
0 .329 .299 r
.60973 .26792 .6206 .28178 .64196 .2673 .63123 .25332 Metetra
0 .293 .301 r
.63123 .25332 .64196 .2673 .66338 .25277 .65279 .23867 Metetra
0 .233 .274 r
.65279 .23867 .66338 .25277 .68488 .2382 .67442 .22397 Metetra
0 .18 .246 r
.67442 .22397 .68488 .2382 .70644 .22358 .69612 .20922 Metetra
0 .134 .218 r
.69612 .20922 .70644 .22358 .72807 .20892 .7179 .19442 Metetra
0 .094 .191 r
.7179 .19442 .72807 .20892 .74978 .19421 .73974 .17958 Metetra
0 .061 .163 r
.73974 .17958 .74978 .19421 .77155 .17945 .76165 .16469 Metetra
0 .034 .135 r
.76165 .16469 .77155 .17945 .79339 .16464 .78364 .14975 Metetra
.965 .147 0 r
.11981 .58006 .13375 .59136 .15374 .57778 .13992 .56636 Metetra
.937 .255 0 r
.13992 .56636 .15374 .57778 .17379 .56415 .16009 .55262 Metetra
.909 .357 0 r
.16009 .55262 .17379 .56415 .1939 .55048 .18032 .53884 Metetra
.882 .452 0 r
.18032 .53884 .1939 .55048 .21408 .53677 .20062 .52502 Metetra
.854 .54 0 r
.20062 .52502 .21408 .53677 .23432 .52302 .22098 .51115 Metetra
.826 .621 0 r
.22098 .51115 .23432 .52302 .25462 .50923 .2414 .49724 Metetra
.799 .696 0 r
.2414 .49724 .25462 .50923 .27499 .49539 .26189 .48328 Metetra
.771 .765 0 r
.26189 .48328 .27499 .49539 .29542 .4815 .28244 .46928 Metetra
.661 .744 0 r
.28244 .46928 .29542 .4815 .31591 .46758 .30306 .45524 Metetra
.55 .716 0 r
.30306 .45524 .31591 .46758 .33647 .45361 .32374 .44115 Metetra
.447 .688 0 r
.32374 .44115 .33647 .45361 .35709 .4396 .34449 .42702 Metetra
.35 .661 0 r
.34449 .42702 .35709 .4396 .37778 .42554 .36531 .41284 Metetra
.259 .633 0 r
.36531 .41284 .37778 .42554 .39853 .41144 .38619 .39862 Metetra
.175 .605 0 r
.38619 .39862 .39853 .41144 .41935 .39729 .40714 .38435 Metetra
.098 .578 0 r
.40714 .38435 .41935 .39729 .44024 .3831 .42815 .37004 Metetra
.027 .55 0 r
.42815 .37004 .44024 .3831 .46119 .36886 .44923 .35568 Metetra
0 .522 .036 r
.44923 .35568 .46119 .36886 .48221 .35458 .47038 .34127 Metetra
0 .495 .094 r
.47038 .34127 .48221 .35458 .50329 .34025 .4916 .32682 Metetra
0 .467 .145 r
.4916 .32682 .50329 .34025 .52445 .32588 .51288 .31233 Metetra
0 .439 .189 r
.51288 .31233 .52445 .32588 .54567 .31146 .53424 .29778 Metetra
0 .412 .226 r
.53424 .29778 .54567 .31146 .56695 .29699 .55566 .28319 Metetra
0 .384 .257 r
.55566 .28319 .56695 .29699 .58831 .28248 .57715 .26855 Metetra
0 .356 .281 r
.57715 .26855 .58831 .28248 .60973 .26792 .59871 .25387 Metetra
0 .329 .299 r
.59871 .25387 .60973 .26792 .63123 .25332 .62034 .23913 Metetra
0 .293 .301 r
.62034 .23913 .63123 .25332 .65279 .23867 .64204 .22435 Metetra
0 .233 .274 r
.64204 .22435 .65279 .23867 .67442 .22397 .66382 .20952 Metetra
0 .18 .246 r
.66382 .20952 .67442 .22397 .69612 .20922 .68566 .19465 Metetra
0 .134 .218 r
.68566 .19465 .69612 .20922 .7179 .19442 .70757 .17972 Metetra
0 .094 .191 r
.70757 .17972 .7179 .19442 .73974 .17958 .72956 .16475 Metetra
0 .061 .163 r
.72956 .16475 .73974 .17958 .76165 .16469 .75161 .14972 Metetra
0 .034 .135 r
.75161 .14972 .76165 .16469 .78364 .14975 .77374 .13465 Metetra
.965 .147 0 r
.10568 .56859 .11981 .58006 .13992 .56636 .12591 .55478 Metetra
.937 .255 0 r
.12591 .55478 .13992 .56636 .16009 .55262 .1462 .54093 Metetra
.909 .357 0 r
.1462 .54093 .16009 .55262 .18032 .53884 .16655 .52704 Metetra
.882 .452 0 r
.16655 .52704 .18032 .53884 .20062 .52502 .18697 .5131 Metetra
.854 .54 0 r
.18697 .5131 .20062 .52502 .22098 .51115 .20745 .49911 Metetra
.826 .621 0 r
.20745 .49911 .22098 .51115 .2414 .49724 .228 .48508 Metetra
.799 .696 0 r
.228 .48508 .2414 .49724 .26189 .48328 .24861 .47101 Metetra
.771 .765 0 r
.24861 .47101 .26189 .48328 .28244 .46928 .26929 .45689 Metetra
.661 .744 0 r
.26929 .45689 .28244 .46928 .30306 .45524 .29003 .44273 Metetra
.55 .716 0 r
.29003 .44273 .30306 .45524 .32374 .44115 .31084 .42852 Metetra
.447 .688 0 r
.31084 .42852 .32374 .44115 .34449 .42702 .33172 .41427 Metetra
.35 .661 0 r
.33172 .41427 .34449 .42702 .36531 .41284 .35266 .39997 Metetra
.259 .633 0 r
.35266 .39997 .36531 .41284 .38619 .39862 .37367 .38562 Metetra
.175 .605 0 r
.37367 .38562 .38619 .39862 .40714 .38435 .39475 .37123 Metetra
.098 .578 0 r
.39475 .37123 .40714 .38435 .42815 .37004 .41589 .35679 Metetra
.027 .55 0 r
.41589 .35679 .42815 .37004 .44923 .35568 .4371 .34231 Metetra
0 .522 .036 r
.4371 .34231 .44923 .35568 .47038 .34127 .45839 .32778 Metetra
0 .495 .094 r
.45839 .32778 .47038 .34127 .4916 .32682 .47974 .3132 Metetra
0 .467 .145 r
.47974 .3132 .4916 .32682 .51288 .31233 .50116 .29858 Metetra
0 .439 .189 r
.50116 .29858 .51288 .31233 .53424 .29778 .52264 .28391 Metetra
0 .412 .226 r
.52264 .28391 .53424 .29778 .55566 .28319 .5442 .26919 Metetra
0 .384 .257 r
.5442 .26919 .55566 .28319 .57715 .26855 .56583 .25442 Metetra
0 .356 .281 r
.56583 .25442 .57715 .26855 .59871 .25387 .58753 .23961 Metetra
0 .329 .299 r
.58753 .23961 .59871 .25387 .62034 .23913 .6093 .22474 Metetra
0 .293 .301 r
.6093 .22474 .62034 .23913 .64204 .22435 .63114 .20983 Metetra
0 .233 .274 r
.63114 .20983 .64204 .22435 .66382 .20952 .65305 .19487 Metetra
0 .18 .246 r
.65305 .19487 .66382 .20952 .68566 .19465 .67504 .17986 Metetra
0 .134 .218 r
.67504 .17986 .68566 .19465 .70757 .17972 .69709 .1648 Metetra
0 .094 .191 r
.69709 .1648 .70757 .17972 .72956 .16475 .71922 .14969 Metetra
0 .061 .163 r
.71922 .14969 .72956 .16475 .75161 .14972 .74143 .13453 Metetra
0 .034 .135 r
.74143 .13453 .75161 .14972 .77374 .13465 .7637 .11932 Metetra
.965 .147 0 r
.09135 .55697 .10568 .56859 .12591 .55478 .1117 .54304 Metetra
.937 .255 0 r
.1117 .54304 .12591 .55478 .1462 .54093 .13211 .52908 Metetra
.909 .357 0 r
.13211 .52908 .1462 .54093 .16655 .52704 .15258 .51506 Metetra
.882 .452 0 r
.15258 .51506 .16655 .52704 .18697 .5131 .17312 .501 Metetra
.854 .54 0 r
.17312 .501 .18697 .5131 .20745 .49911 .19373 .4869 Metetra
.826 .621 0 r
.19373 .4869 .20745 .49911 .228 .48508 .2144 .47275 Metetra
.799 .696 0 r
.2144 .47275 .228 .48508 .24861 .47101 .23514 .45856 Metetra
.771 .765 0 r
.23514 .45856 .24861 .47101 .26929 .45689 .25594 .44432 Metetra
.661 .744 0 r
.25594 .44432 .26929 .45689 .29003 .44273 .27681 .43004 Metetra
.55 .716 0 r
.27681 .43004 .29003 .44273 .31084 .42852 .29775 .41571 Metetra
.447 .688 0 r
.29775 .41571 .31084 .42852 .33172 .41427 .31875 .40133 Metetra
.35 .661 0 r
.31875 .40133 .33172 .41427 .35266 .39997 .33983 .38691 Metetra
.259 .633 0 r
.33983 .38691 .35266 .39997 .37367 .38562 .36097 .37244 Metetra
.175 .605 0 r
.36097 .37244 .37367 .38562 .39475 .37123 .38218 .35792 Metetra
.098 .578 0 r
.38218 .35792 .39475 .37123 .41589 .35679 .40345 .34336 Metetra
.027 .55 0 r
.40345 .34336 .41589 .35679 .4371 .34231 .4248 .32875 Metetra
0 .522 .036 r
.4248 .32875 .4371 .34231 .45839 .32778 .44622 .31409 Metetra
0 .495 .094 r
.44622 .31409 .45839 .32778 .47974 .3132 .4677 .29939 Metetra
0 .467 .145 r
.4677 .29939 .47974 .3132 .50116 .29858 .48926 .28463 Metetra
0 .439 .189 r
.48926 .28463 .50116 .29858 .52264 .28391 .51088 .26983 Metetra
0 .412 .226 r
.51088 .26983 .52264 .28391 .5442 .26919 .53258 .25498 Metetra
0 .384 .257 r
.53258 .25498 .5442 .26919 .56583 .25442 .55435 .24008 Metetra
0 .356 .281 r
.55435 .24008 .56583 .25442 .58753 .23961 .57619 .22514 Metetra
0 .329 .299 r
.57619 .22514 .58753 .23961 .6093 .22474 .5981 .21014 Metetra
0 .293 .301 r
.5981 .21014 .6093 .22474 .63114 .20983 .62008 .19509 Metetra
0 .233 .274 r
.62008 .19509 .63114 .20983 .65305 .19487 .64213 .18 Metetra
0 .18 .246 r
.64213 .18 .65305 .19487 .67504 .17986 .66426 .16485 Metetra
0 .134 .218 r
.66426 .16485 .67504 .17986 .69709 .1648 .68646 .14966 Metetra
0 .094 .191 r
.68646 .14966 .69709 .1648 .71922 .14969 .70874 .13441 Metetra
0 .061 .163 r
.70874 .13441 .71922 .14969 .74143 .13453 .73109 .11912 Metetra
0 .034 .135 r
.73109 .11912 .74143 .13453 .7637 .11932 .75351 .10377 Metetra
.965 .147 0 r
.07682 .54518 .09135 .55697 .1117 .54304 .09729 .53114 Metetra
.937 .255 0 r
.09729 .53114 .1117 .54304 .13211 .52908 .11782 .51705 Metetra
.909 .357 0 r
.11782 .51705 .13211 .52908 .15258 .51506 .13842 .50292 Metetra
.882 .452 0 r
.13842 .50292 .15258 .51506 .17312 .501 .15908 .48874 Metetra
.854 .54 0 r
.15908 .48874 .17312 .501 .19373 .4869 .17981 .47452 Metetra
.826 .621 0 r
.17981 .47452 .19373 .4869 .2144 .47275 .20061 .46025 Metetra
.799 .696 0 r
.20061 .46025 .2144 .47275 .23514 .45856 .22147 .44593 Metetra
.771 .765 0 r
.22147 .44593 .23514 .45856 .25594 .44432 .24241 .43157 Metetra
.661 .744 0 r
.24241 .43157 .25594 .44432 .27681 .43004 .2634 .41716 Metetra
.55 .716 0 r
.2634 .41716 .27681 .43004 .29775 .41571 .28447 .40271 Metetra
.447 .688 0 r
.28447 .40271 .29775 .41571 .31875 .40133 .30561 .38821 Metetra
.35 .661 0 r
.30561 .38821 .31875 .40133 .33983 .38691 .32681 .37366 Metetra
.259 .633 0 r
.32681 .37366 .33983 .38691 .36097 .37244 .34808 .35906 Metetra
.175 .605 0 r
.34808 .35906 .36097 .37244 .38218 .35792 .36942 .34442 Metetra
.098 .578 0 r
.36942 .34442 .38218 .35792 .40345 .34336 .39084 .32973 Metetra
.027 .55 0 r
.39084 .32973 .40345 .34336 .4248 .32875 .41232 .31499 Metetra
0 .522 .036 r
.41232 .31499 .4248 .32875 .44622 .31409 .43387 .3002 Metetra
0 .495 .094 r
.43387 .3002 .44622 .31409 .4677 .29939 .45549 .28537 Metetra
0 .467 .145 r
.45549 .28537 .4677 .29939 .48926 .28463 .47718 .27048 Metetra
0 .439 .189 r
.47718 .27048 .48926 .28463 .51088 .26983 .49895 .25555 Metetra
0 .412 .226 r
.49895 .25555 .51088 .26983 .53258 .25498 .52078 .24057 Metetra
0 .384 .257 r
.52078 .24057 .53258 .25498 .55435 .24008 .54269 .22554 Metetra
0 .356 .281 r
.54269 .22554 .55435 .24008 .57619 .22514 .56467 .21045 Metetra
0 .329 .299 r
.56467 .21045 .57619 .22514 .5981 .21014 .58673 .19532 Metetra
0 .293 .301 r
.58673 .19532 .5981 .21014 .62008 .19509 .60885 .18014 Metetra
0 .233 .274 r
.60885 .18014 .62008 .19509 .64213 .18 .63105 .16491 Metetra
0 .18 .246 r
.63105 .16491 .64213 .18 .66426 .16485 .65333 .14963 Metetra
0 .134 .218 r
.65333 .14963 .66426 .16485 .68646 .14966 .67567 .13429 Metetra
0 .094 .191 r
.67567 .13429 .68646 .14966 .70874 .13441 .6981 .11891 Metetra
0 .061 .163 r
.6981 .11891 .70874 .13441 .73109 .11912 .72059 .10347 Metetra
0 .034 .135 r
.72059 .10347 .73109 .11912 .75351 .10377 .74317 .08799 Metetra
.965 .147 0 r
.06208 .53322 .07682 .54518 .09729 .53114 .08267 .51906 Metetra
.937 .255 0 r
.08267 .51906 .09729 .53114 .11782 .51705 .10333 .50485 Metetra
.909 .357 0 r
.10333 .50485 .11782 .51705 .13842 .50292 .12405 .4906 Metetra
.882 .452 0 r
.12405 .4906 .13842 .50292 .15908 .48874 .14484 .4763 Metetra
.854 .54 0 r
.14484 .4763 .15908 .48874 .17981 .47452 .1657 .46195 Metetra
.826 .621 0 r
.1657 .46195 .17981 .47452 .20061 .46025 .18662 .44756 Metetra
.799 .696 0 r
.18662 .44756 .20061 .46025 .22147 .44593 .20761 .43312 Metetra
.771 .765 0 r
.20761 .43312 .22147 .44593 .24241 .43157 .22867 .41863 Metetra
.661 .744 0 r
.22867 .41863 .24241 .43157 .2634 .41716 .2498 .4041 Metetra
.55 .716 0 r
.2498 .4041 .2634 .41716 .28447 .40271 .271 .38952 Metetra
.447 .688 0 r
.271 .38952 .28447 .40271 .30561 .38821 .29227 .37489 Metetra
.35 .661 0 r
.29227 .37489 .30561 .38821 .32681 .37366 .3136 .36022 Metetra
.259 .633 0 r
.3136 .36022 .32681 .37366 .34808 .35906 .33501 .34549 Metetra
.175 .605 0 r
.33501 .34549 .34808 .35906 .36942 .34442 .35649 .33072 Metetra
.098 .578 0 r
.35649 .33072 .36942 .34442 .39084 .32973 .37803 .3159 Metetra
.027 .55 0 r
.37803 .3159 .39084 .32973 .41232 .31499 .39965 .30103 Metetra
0 .522 .036 r
.39965 .30103 .41232 .31499 .43387 .3002 .42134 .28611 Metetra
0 .495 .094 r
.42134 .28611 .43387 .3002 .45549 .28537 .4431 .27114 Metetra
0 .467 .145 r
.4431 .27114 .45549 .28537 .47718 .27048 .46493 .25612 Metetra
0 .439 .189 r
.46493 .25612 .47718 .27048 .49895 .25555 .48684 .24106 Metetra
0 .412 .226 r
.48684 .24106 .49895 .25555 .52078 .24057 .50882 .22594 Metetra
0 .384 .257 r
.50882 .22594 .52078 .24057 .54269 .22554 .53087 .21077 Metetra
0 .356 .281 r
.53087 .21077 .54269 .22554 .56467 .21045 .55299 .19555 Metetra
0 .329 .299 r
.55299 .19555 .56467 .21045 .58673 .19532 .57519 .18029 Metetra
0 .293 .301 r
.57519 .18029 .58673 .19532 .60885 .18014 .59746 .16497 Metetra
0 .233 .274 r
.59746 .16497 .60885 .18014 .63105 .16491 .61981 .1496 Metetra
0 .18 .246 r
.61981 .1496 .63105 .16491 .65333 .14963 .64223 .13417 Metetra
0 .134 .218 r
.64223 .13417 .65333 .14963 .67567 .13429 .66472 .1187 Metetra
0 .094 .191 r
.66472 .1187 .67567 .13429 .6981 .11891 .6873 .10317 Metetra
0 .061 .163 r
.6873 .10317 .6981 .11891 .72059 .10347 .70995 .08759 Metetra
0 .034 .135 r
.70995 .08759 .72059 .10347 .74317 .08799 .73267 .07196 Metetra
.965 .147 0 r
.04713 .52109 .06208 .53322 .08267 .51906 .06784 .50681 Metetra
.937 .255 0 r
.06784 .50681 .08267 .51906 .10333 .50485 .08862 .49248 Metetra
.909 .357 0 r
.08862 .49248 .10333 .50485 .12405 .4906 .10947 .4781 Metetra
.882 .452 0 r
.10947 .4781 .12405 .4906 .14484 .4763 .13039 .46368 Metetra
.854 .54 0 r
.13039 .46368 .14484 .4763 .1657 .46195 .15137 .44921 Metetra
.826 .621 0 r
.15137 .44921 .1657 .46195 .18662 .44756 .17243 .43469 Metetra
.799 .696 0 r
.17243 .43469 .18662 .44756 .20761 .43312 .19355 .42012 Metetra
.771 .765 0 r
.19355 .42012 .20761 .43312 .22867 .41863 .21474 .40551 Metetra
.661 .744 0 r
.21474 .40551 .22867 .41863 .2498 .4041 .236 .39085 Metetra
.55 .716 0 r
.236 .39085 .2498 .4041 .271 .38952 .25733 .37614 Metetra
.447 .688 0 r
.25733 .37614 .271 .38952 .29227 .37489 .27873 .36138 Metetra
.35 .661 0 r
.27873 .36138 .29227 .37489 .3136 .36022 .3002 .34657 Metetra
.259 .633 0 r
.3002 .34657 .3136 .36022 .33501 .34549 .32174 .33172 Metetra
.175 .605 0 r
.32174 .33172 .33501 .34549 .35649 .33072 .34336 .31682 Metetra
.098 .578 0 r
.34336 .31682 .35649 .33072 .37803 .3159 .36504 .30186 Metetra
.027 .55 0 r
.36504 .30186 .37803 .3159 .39965 .30103 .3868 .28686 Metetra
0 .522 .036 r
.3868 .28686 .39965 .30103 .42134 .28611 .40862 .27181 Metetra
0 .495 .094 r
.40862 .27181 .42134 .28611 .4431 .27114 .43053 .2567 Metetra
0 .467 .145 r
.43053 .2567 .4431 .27114 .46493 .25612 .4525 .24155 Metetra
0 .439 .189 r
.4525 .24155 .46493 .25612 .48684 .24106 .47455 .22635 Metetra
0 .412 .226 r
.47455 .22635 .48684 .24106 .50882 .22594 .49667 .21109 Metetra
0 .384 .257 r
.49667 .21109 .50882 .22594 .53087 .21077 .51886 .19579 Metetra
0 .356 .281 r
.51886 .19579 .53087 .21077 .55299 .19555 .54113 .18043 Metetra
0 .329 .299 r
.54113 .18043 .55299 .19555 .57519 .18029 .56348 .16502 Metetra
0 .293 .301 r
.56348 .16502 .57519 .18029 .59746 .16497 .5859 .14956 Metetra
0 .233 .274 r
.5859 .14956 .59746 .16497 .61981 .1496 .60839 .13405 Metetra
0 .18 .246 r
.60839 .13405 .61981 .1496 .64223 .13417 .63096 .11849 Metetra
0 .134 .218 r
.63096 .11849 .64223 .13417 .66472 .1187 .65361 .10287 Metetra
0 .094 .191 r
.65361 .10287 .66472 .1187 .6873 .10317 .67633 .0872 Metetra
0 .061 .163 r
.67633 .0872 .6873 .10317 .70995 .08759 .69913 .07147 Metetra
0 .034 .135 r
.69913 .07147 .70995 .08759 .73267 .07196 .72201 .0557 Metetra
.965 .147 0 r
.03196 .50879 .04713 .52109 .06784 .50681 .0528 .49438 Metetra
.937 .255 0 r
.0528 .49438 .06784 .50681 .08862 .49248 .07371 .47992 Metetra
.909 .357 0 r
.07371 .47992 .08862 .49248 .10947 .4781 .09468 .46542 Metetra
.882 .452 0 r
.09468 .46542 .10947 .4781 .13039 .46368 .11573 .45087 Metetra
.854 .54 0 r
.11573 .45087 .13039 .46368 .15137 .44921 .13684 .43627 Metetra
.826 .621 0 r
.13684 .43627 .15137 .44921 .17243 .43469 .15803 .42163 Metetra
.799 .696 0 r
.15803 .42163 .17243 .43469 .19355 .42012 .17928 .40693 Metetra
.771 .765 0 r
.17928 .40693 .19355 .42012 .21474 .40551 .2006 .39219 Metetra
.661 .744 0 r
.2006 .39219 .21474 .40551 .236 .39085 .222 .3774 Metetra
.55 .716 0 r
.222 .3774 .236 .39085 .25733 .37614 .24346 .36256 Metetra
.447 .688 0 r
.24346 .36256 .25733 .37614 .27873 .36138 .265 .34767 Metetra
.35 .661 0 r
.265 .34767 .27873 .36138 .3002 .34657 .2866 .33273 Metetra
.259 .633 0 r
.2866 .33273 .3002 .34657 .32174 .33172 .30828 .31775 Metetra
.175 .605 0 r
.30828 .31775 .32174 .33172 .34336 .31682 .33003 .30271 Metetra
.098 .578 0 r
.33003 .30271 .34336 .31682 .36504 .30186 .35186 .28762 Metetra
.027 .55 0 r
.35186 .28762 .36504 .30186 .3868 .28686 .37375 .27248 Metetra
0 .522 .036 r
.37375 .27248 .3868 .28686 .40862 .27181 .39572 .25729 Metetra
0 .495 .094 r
.39572 .25729 .40862 .27181 .43053 .2567 .41776 .24205 Metetra
0 .467 .145 r
.41776 .24205 .43053 .2567 .4525 .24155 .43988 .22676 Metetra
0 .439 .189 r
.43988 .22676 .4525 .24155 .47455 .22635 .46207 .21142 Metetra
0 .412 .226 r
.46207 .21142 .47455 .22635 .49667 .21109 .48434 .19602 Metetra
0 .384 .257 r
.48434 .19602 .49667 .21109 .51886 .19579 .50668 .18058 Metetra
0 .356 .281 r
.50668 .18058 .51886 .19579 .54113 .18043 .5291 .16508 Metetra
0 .329 .299 r
.5291 .16508 .54113 .18043 .56348 .16502 .55159 .14953 Metetra
0 .293 .301 r
.55159 .14953 .56348 .16502 .5859 .14956 .57416 .13393 Metetra
0 .233 .274 r
.57416 .13393 .5859 .14956 .60839 .13405 .5968 .11827 Metetra
0 .18 .246 r
.5968 .11827 .60839 .13405 .63096 .11849 .61952 .10256 Metetra
0 .134 .218 r
.61952 .10256 .63096 .11849 .65361 .10287 .64232 .0868 Metetra
0 .094 .191 r
.64232 .0868 .65361 .10287 .67633 .0872 .6652 .07098 Metetra
0 .061 .163 r
.6652 .07098 .67633 .0872 .69913 .07147 .68816 .05511 Metetra
0 .034 .135 r
.68816 .05511 .69913 .07147 .72201 .0557 .71119 .03918 Metetra
.965 .147 0 r
.01657 .4963 .03196 .50879 .0528 .49438 .03754 .48177 Metetra
.937 .255 0 r
.03754 .48177 .0528 .49438 .07371 .47992 .05857 .46718 Metetra
.909 .357 0 r
.05857 .46718 .07371 .47992 .09468 .46542 .07968 .45255 Metetra
.882 .452 0 r
.07968 .45255 .09468 .46542 .11573 .45087 .10085 .43788 Metetra
.854 .54 0 r
.10085 .43788 .11573 .45087 .13684 .43627 .1221 .42315 Metetra
.826 .621 0 r
.1221 .42315 .13684 .43627 .15803 .42163 .14341 .40837 Metetra
.799 .696 0 r
.14341 .40837 .15803 .42163 .17928 .40693 .1648 .39355 Metetra
.771 .765 0 r
.1648 .39355 .17928 .40693 .2006 .39219 .18626 .37868 Metetra
.661 .744 0 r
.18626 .37868 .2006 .39219 .222 .3774 .20778 .36375 Metetra
.55 .716 0 r
.20778 .36375 .222 .3774 .24346 .36256 .22938 .34878 Metetra
.447 .688 0 r
.22938 .34878 .24346 .36256 .265 .34767 .25106 .33376 Metetra
.35 .661 0 r
.25106 .33376 .265 .34767 .2866 .33273 .2728 .31868 Metetra
.259 .633 0 r
.2728 .31868 .2866 .33273 .30828 .31775 .29462 .30356 Metetra
.175 .605 0 r
.29462 .30356 .30828 .31775 .33003 .30271 .31651 .28839 Metetra
.098 .578 0 r
.31651 .28839 .33003 .30271 .35186 .28762 .33847 .27316 Metetra
.027 .55 0 r
.33847 .27316 .35186 .28762 .37375 .27248 .36051 .25789 Metetra
0 .522 .036 r
.36051 .25789 .37375 .27248 .39572 .25729 .38262 .24256 Metetra
0 .495 .094 r
.38262 .24256 .39572 .25729 .41776 .24205 .40481 .22718 Metetra
0 .467 .145 r
.40481 .22718 .41776 .24205 .43988 .22676 .42707 .21175 Metetra
0 .439 .189 r
.42707 .21175 .43988 .22676 .46207 .21142 .44941 .19626 Metetra
0 .412 .226 r
.44941 .19626 .46207 .21142 .48434 .19602 .47182 .18073 Metetra
0 .384 .257 r
.47182 .18073 .48434 .19602 .50668 .18058 .49431 .16514 Metetra
0 .356 .281 r
.49431 .16514 .50668 .18058 .5291 .16508 .51688 .1495 Metetra
0 .329 .299 r
.51688 .1495 .5291 .16508 .55159 .14953 .53952 .1338 Metetra
0 .293 .301 r
.53952 .1338 .55159 .14953 .57416 .13393 .56224 .11805 Metetra
0 .233 .274 r
.56224 .11805 .57416 .13393 .5968 .11827 .58504 .10225 Metetra
0 .18 .246 r
.58504 .10225 .5968 .11827 .61952 .10256 .60791 .08639 Metetra
0 .134 .218 r
.60791 .08639 .61952 .10256 .64232 .0868 .63087 .07048 Metetra
0 .094 .191 r
.63087 .07048 .64232 .0868 .6652 .07098 .6539 .05451 Metetra
0 .061 .163 r
.6539 .05451 .6652 .07098 .68816 .05511 .67701 .03849 Metetra
0 .034 .135 r
.67701 .03849 .68816 .05511 .71119 .03918 .70021 .02241 Metetra
.965 .147 0 r
.00095 .48363 .01657 .4963 .03754 .48177 .02205 .46897 Metetra
.937 .255 0 r
.02205 .46897 .03754 .48177 .05857 .46718 .04321 .45426 Metetra
.909 .357 0 r
.04321 .45426 .05857 .46718 .07968 .45255 .06445 .4395 Metetra
.882 .452 0 r
.06445 .4395 .07968 .45255 .10085 .43788 .08576 .42469 Metetra
.854 .54 0 r
.08576 .42469 .10085 .43788 .1221 .42315 .10713 .40983 Metetra
.826 .621 0 r
.10713 .40983 .1221 .42315 .14341 .40837 .12858 .39492 Metetra
.799 .696 0 r
.12858 .39492 .14341 .40837 .1648 .39355 .1501 .37997 Metetra
.771 .765 0 r
.1501 .37997 .1648 .39355 .18626 .37868 .17169 .36496 Metetra
.661 .744 0 r
.17169 .36496 .18626 .37868 .20778 .36375 .19336 .3499 Metetra
.55 .716 0 r
.19336 .3499 .20778 .36375 .22938 .34878 .2151 .33479 Metetra
.447 .688 0 r
.2151 .33479 .22938 .34878 .25106 .33376 .23691 .31964 Metetra
.35 .661 0 r
.23691 .31964 .25106 .33376 .2728 .31868 .25879 .30443 Metetra
.259 .633 0 r
.25879 .30443 .2728 .31868 .29462 .30356 .28075 .28916 Metetra
.175 .605 0 r
.28075 .28916 .29462 .30356 .31651 .28839 .30278 .27385 Metetra
.098 .578 0 r
.30278 .27385 .31651 .28839 .33847 .27316 .32489 .25849 Metetra
.027 .55 0 r
.32489 .25849 .33847 .27316 .36051 .25789 .34707 .24307 Metetra
0 .522 .036 r
.34707 .24307 .36051 .25789 .38262 .24256 .36933 .2276 Metetra
0 .495 .094 r
.36933 .2276 .38262 .24256 .40481 .22718 .39166 .21208 Metetra
0 .467 .145 r
.39166 .21208 .40481 .22718 .42707 .21175 .41407 .19651 Metetra
0 .439 .189 r
.41407 .19651 .42707 .21175 .44941 .19626 .43655 .18088 Metetra
0 .412 .226 r
.43655 .18088 .44941 .19626 .47182 .18073 .45911 .1652 Metetra
0 .384 .257 r
.45911 .1652 .47182 .18073 .49431 .16514 .48175 .14946 Metetra
0 .356 .281 r
.48175 .14946 .49431 .16514 .51688 .1495 .50447 .13367 Metetra
0 .329 .299 r
.50447 .13367 .51688 .1495 .53952 .1338 .52727 .11783 Metetra
0 .293 .301 r
.52727 .11783 .53952 .1338 .56224 .11805 .55014 .10193 Metetra
0 .233 .274 r
.55014 .10193 .56224 .11805 .58504 .10225 .57309 .08598 Metetra
0 .18 .246 r
.57309 .08598 .58504 .10225 .60791 .08639 .59612 .06997 Metetra
0 .134 .218 r
.59612 .06997 .60791 .08639 .63087 .07048 .61923 .05391 Metetra
0 .094 .191 r
.61923 .05391 .63087 .07048 .6539 .05451 .64242 .03779 Metetra
0 .061 .163 r
.64242 .03779 .6539 .05451 .67701 .03849 .6657 .02162 Metetra
0 .034 .135 r
.6657 .02162 .67701 .03849 .70021 .02241 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-0.5)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.4)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(-0.3)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(-0.2)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(-0.1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00_?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0005Ko
oooo002kooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0EOooool00;Cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0EOooool00;_ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`1Eooooo`00^oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo05Gooooo002kooooo`04o`000?ooooooooooo`0000So
oooo0_l0000;ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0003gooooo002looooo`;o
00002_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo0000?Oooool00<cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool0?Oooool00=?ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0l
ooooo`00doooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000?Ooo
ool00=?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000003gooooo
0038ooooo`;o00002_ooool2o`0000Wooooo0ol0000nooooo`00aOooool6o`0005Gooooo0033oooo
o`;o00000_ooool01?l0003o00PRo`000?l0001Eooooo`00`?ooool3o`0000?ooooo00?o0000o`08
8_l022800ol0001Dooooo`00__ooool2o`000003ooooool0003ooooo00;ooooo00Oo0000o`088_l0
22;o00PRo`000?l022;o000005Cooooo002kooooo`?o00001Oooool2o`0000Co00PR00Co0000o`08
8_l0003o0000Doooool0097ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00006Oooool2
o`0000Oooooo00?o0000o`0?:Ol000001?l02282o`000003o`088_l0003o000005;ooooo002@oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00005_ooool4o`0000Oooooo00Go
0000o`0?:Ol03bWo00lYo`000003o`088P05o`000?l022;o00PRo`088_l00000D_ooool008Wooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool05?ooool2o`0000[o
oooo00?o0000o`0?:Ol03bT00ol03bT01?l0003o00PRo`000?l00003o`088P;o0000DOooool0093o
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0@ooooo`?o00002_ooool2o`00
00Ko00lY0_l000000ol022;o0000o`088P02o`088P?o0000D?ooool0093ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000kooooo1?l0000:ooooo`;o000000?o01P`
o`000?l03bT00ol03bT2o`000008o`0?:Ol0003o00PRo`088_l0003o00PRo`000?l02282o`00053o
oooo002@ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000<oooo
o`;o00003?ooool2o`0000Co01P`00Co0000o`0?:Ol0003o00001?l03bT01?l0003o00PRo`000?l0
0003o`088P;o0000Coooool0097ooooo0_l00009ooooo`?o00002_ooool3o`0000cooooo0_l00006
o`0H<0;o00001_l03bT00ol0003o00PRo`000005o`088P;o0000C_ooool00:Oooooo0_l0000>oooo
o`03o`000?l08SOo000000Go01P`00?o0000o`0H<?l000001_l03bT3o`0000Go00PR0_l0001>oooo
o`00Y?ooool3o`0000;ooooo00?o0000ooooooooool02_ooool01Ol0003o028go`0R=ol08SOo0000
00?o01P`00Go0000o`0H<?l0633o01P`o`000003o`0?:@;o00000_l03bT01?l0003o00PRo`088_l0
2282o`000003o`088_l0003o000004gooooo002Rooooo`;o00004Oooool00ol0003o028go`0R=`03
o`0R=`03o`000?l0633o000000Go01P`00?o0000o`0?:Ol000001?l03bT2o`000003o`088_l0003o
00PR00?o00PR0_l0001<ooooo`00Woooool3o`00017ooooo0_l00006o`0R=`;o00001_l06302o`00
00Go00lY0ol00005o`088P;o0000C?ooool009gooooo0_l00002ooooo`03o`000?oooooooooo00ko
oooo00?o0000o`0^?_l000001Ol08SL00ol0003o028go`000005o`0H<003o`000?l0633o000000Go
00lY00?o0000o`0?:Ol000001?l022801?l0003o00PRo`000?l0001;ooooo`00V_ooool3o`0001Co
oooo00Go0000o`0^?_l0;Sko02hno`000003o`0R=`05o`000?l08SOo028go`0R=ol000000ol06300
1Ol0003o01P`o`0H<?l0633o000000;o00lY0ol00002o`0?:@04o`000?l022;o00PRo`0000?o00PR
0_l0001:ooooo`00V?ooool2o`0001Kooooo00?o0000o`0^?_l0;Sh00ol0;Sh00ol0003o028go`00
0005o`0R=`03o`000?l0633o000000Co01P`00?o0000o`0?:Ol000000_l03bT01_l0003o00lYo`0?
:Ol0003o00PRo`0000Go00PR00?o0000ooooooooool0B?ooool009Gooooo0ol000000ooooooo0000
ooooo`0Cooooo`;o00001_l0;Sh2o`0000Ko028g0_l00005o`0H<0;o00000ol03bT00ol0003o00lY
o`0?:@02o`0000Ko00PR0_l00019ooooo`00J_ooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0001_ooooo0_l0000Gooooo`;o000000?o03]6o`000?l0;Sh00ol0;Sh2o`000003o`0^?_l0
003o028g00?o028g0_l000000ol08SOo0000o`0H<003o`0H<003o`000?l0633o000000?o00lY00Go
0000o`0?:Ol0003o00lYo`000005o`088P04o`000?l022;o0000o`0004Sooooo001Yooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Gooooo`?o00005oooool2o`00
00Co03]600Co0000o`0^?_l0003o00001?l0;Sh01?l0003o028go`000?l00004o`0R=`04o`000?l0
633o01P`o`0000?o01P`00?o0000o`0?:Ol03bT00_l00003o`0?:@05o`000?l022;o00PRo`088_l0
00000ol022800ol0003oooooooooo`16ooooo`00H_ooool5o`0000;ooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`0Cooooo`;o000000?oooooo`000?ooool05Oooool2o`0000Ko
03]60_l00006o`0^?P;o00001_l08SL00ol0003o01P`o`000005o`0H<003o`000?l03bWo000000Go
00lY00?o0000o`088_l000001?l02282o`0000kooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol0000[ooooo`00JOooool01?l0003oooooooooool00009ooooo`;o00004oooool3o`0001Wo
oooo00?o0000o`1;COl000001Ol0>dH00ol0003o03]6o`000005o`0^?P03o`000?l0;Sko000000Ko
028g0_l00006o`0H<0?o00001Ol03bT2o`0000Go00PR0ol0000<ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool0:_ooool006Wooooo00Co0000oooooooooooo00002oooool00ol0
003oooooooooo`0>ooooo`;o00006oooool01Ol0003o04]=o`1;COl0Bdgo000000?o03]600Go0000
o`0kA_l0>dKo03]6o`000003o`0^?P05o`000?l0;Sko02hno`0^?_l000000ol08SL2o`0000;o028g
00Co0000o`0H<?l0633o01P`0_l000000ol0633o0000o`000003o`0?:@;o000000?o00lYo`000?l0
22800_l02282o`000003o`088_l0003o000000Gooooo1Ol00002ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool0:_ooool006Wooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000gooooo0ol000000ooooooo0000ooooo`0Iooooo`03o`000?l0Bdgo
04]=00?o04]=00?o0000o`0kA_l000001Ol0>dH00ol0003o02hno`000005o`0^?P03o`000?l08SOo
000000Go028g00?o0000o`0H<?l000001?l063001?l0003o00lYo`000?l00004o`0?:@03o`000?l0
22;o000000Co00PR0_l0000;ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
:_ooool006[ooooo0_l00009ooooo`?o00003?ooool2o`0001gooooo0_l00006o`1;C@;o00001_l0
>dH2o`0000Ko02hn0_l00006o`0R=`;o00001Ol06302o`0000Ko00lY0_l00005o`088P?o00002_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo02[ooooo0021ooooo`?o00007_oo
ool00ol0003o05A<o`000005o`1;C@03o`000?l0Bdgo000000Go03]600?o0000o`0kA_l000001Ol0
;Sh00ol0003o02hno`000005o`0R=`03o`000?l08SOo000000Co01P`0ol00005o`0?:@03o`000?l0
3bWo000000Co00PR00Co0000o`088_l0003o00002_ooool01?l0003oooooooooool00008ooooo`;o
0000;?ooool007kooooo0ol000000ooooooo0000ooooo`0Mooooo`05o`000?l0E4co05A<o`1DC?l0
00000ol0Bdd01Ol0003o04]=o`1;COl0Bdgo000000?o03]600Go0000o`0kA_l0>dKo03]6o`000003
o`0^?P05o`000?l0;Sko02hno`0^?_l000000ol08SL01Ol0003o028go`0R=ol08SOo000000;o01P`
00?o0000o`0H<?l063000_l00003o`0?:@05o`000?l03bWo00lYo`0?:Ol000000_l022801?l0003o
00PRo`088_l02282o`0000[ooooo0_l0000:ooooo`03o`000?oooooooooo02[ooooo001looooo`;o
00008_ooool00ol0003o05A<o`1DC003o`1DC003o`000?l0Bdgo000000Go04]=00?o0000o`0kA_l0
00001Ol0>dH00ol0003o02hno`000005o`0^?P03o`000?l08SOo000000Co028g00?o0000o`0H<?l0
00000ol063001Ol0003o01P`o`000?l03bWo000000Co00lY00?o0000o`088_l000001Ol02282o`00
04;ooooo001iooooo`?o00008_ooool2o`0000Ko05A<0_l00006o`1;C@;o00001_l0>dH2o`0000Ko
02hn0_l00005o`0R=`;o00001?l063001?l0003o01P`o`000?l00005o`0?:@;o00001_l02282o`00
04;ooooo001gooooo`;o00000_ooool00ol0003oooooooooo`0Nooooo`;o00000_l0FdL01?l0003o
05A<o`1DC?l0E4`2o`0000;o05A<00Co0000o`1;COl0Bdgo04]=0_l00002o`1;C@04o`000?l0>dKo
03]6o`0kAP;o000000?o03]6o`000?l0;Sh00ol0;Sh2o`000003o`0^?_l0003o028g00;o028g0_l0
0002o`0R=`04o`000?l0633o01P`o`0H<0;o000000?o01P`o`000?l03bT00_l03bT2o`0000;o00lY
00Co0000o`088_l022;o00PR0_l000000ol022;o0000o`000011ooooo`00M?ooool3o`0002Cooooo
00?o0000o`1KAol0FdL00ol0FdL00ol0003o05A<o`000005o`1DC003o`000?l0Bdgo000000Go04]=
00?o0000o`0kA_l000001?l0>dH01?l0003o02hno`000?l00004o`0^?P03o`000?l08SOo000000Go
028g00Co0000o`0H<?l0003o00000ol063000ol0003o00lYo`000005o`0?:@03o`000?l022;o0000
00Co00PR0_l00010ooooo`00L_ooool2o`0002Gooooo0_l00006o`1KA`;o00001_l0E4`2o`0000Ko
04]=0_l00005o`0kAP;o00001_l0;Sh2o`0000Ko028g0_l000000ol0633o0000o`0H<002o`0H<0;o
00001_l03bT2o`0000Go00PR0ol0000oooooo`00A?ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool3o`0001cooooo0ol000000ooooooo0000ooooo`0Sooooo`03o`000?l0HT7o000000Go05]7
00?o0000o`1KAol000001Ol0E4`00ol0003o05A<o`000005o`1;C@03o`000?l0Bdgo000000Co03]6
00?o0000o`0kA_l000001Ol0;Sh00ol0003o02hno`000005o`0R=`05o`000?l08SOo0000o`0H<?l0
00000_l063000ol0003o01P`o`000005o`0?:@03o`000?l03bWo000000Co00PR00Co0000o`088_l0
003o0000?oooool004?ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Ioooo
o`;o00009oooool2o`0000?o069100Go0000o`1KAol0FdOo05]7o`000003o`1KA`05o`000?l0E4co
05A<o`1DC?l000000ol0E4`00ol0003o04]=o`1;C@02o`0000?o04]=00Co0000o`0kA_l0>dKo0000
0ol0>dH01Ol0003o02hno`0^?_l0;Sko000000?o02hn00Go0000o`0R=ol08SOo028go`000003o`0R
=`;o000000?o01P`o`000?l063000_l063001Ol0003o00lYo`0?:Ol03bWo000000?o00lY00Co0000
o`088_l022;o00000ol02282o`0003kooooo000looooo`Go00000_ooool01?l0003oooooooooool0
0007ooooo`Go00005oooool3o`0002Sooooo00?o0000o`1R@Ol0HT401?l0HT400ol0003o05]7o`00
0005o`1KA`03o`000?l0E4co000000Co05A<00?o0000o`1;COl000001Ol0Bdd00ol0003o03]6o`00
0005o`0kAP03o`000?l0;Sko000000Go02hn00?o0000o`0R=ol000001?l08SL3o`0000Go01P`00?o
0000o`0?:Ol000001?l03bT00ol0003o00PRo`000004o`088P;o0000?_ooool004?ooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool0000Fooooo`;o0000:Oooool2o`0000Oo0691
0_l00006o`1KA`;o00001Ol0E4`2o`0000Ko04]=0_l00006o`0kAP;o00001_l0;Sh2o`0000Go028g
0_l00006o`0H<0;o00001Ol03bT2o`0000Go00PR0ol0000mooooo`00@oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo000001?ooooo0ol0000Yooooo`;o00000_l0JCT00ol0003o0691
o`1R@@02o`1R@@;o000000?o0691o`000?l0FdL00ol0FdL2o`000003o`1KAol0003o05A<00;o05A<
0_l00002o`1DC004o`000?l0Bdgo04]=o`1;C@;o00000_l0Bdd01?l0003o03]6o`0kA_l0>dH2o`00
00;o03]600Co0000o`0^?_l0;Sko02hn0_l000000ol0;Sko0000o`0R=`02o`0R=`;o000000?o028g
o`000?l000000ol06302o`000003o`0H<?l0003o00lY00;o00lY0_l000000ol03bWo0000o`088P02
o`088P;o000000Co00PRo`000?oooooo0000??ooool004?ooooo00Co0000oooooooooooo00002Ooo
ool2o`00017ooooo0ol0000Zooooo`03o`000?l0JCWo06Ti00?o06Ti00Co0000o`1R@Ol0003o0000
1?l0HT401?l0003o05]7o`000?l00004o`1KA`03o`000?l0E4co000000Go05A<00?o0000o`1;COl0
00001Ol0Bdd00ol0003o03]6o`000005o`0kAP03o`000?l0;Sko000000Co02hn00?o0000o`0R=ol0
00000ol08SL01Ol0003o028go`000?l0633o000000Co01P`00?o0000o`0?:Ol000001?l03bT00ol0
003o00PRo`000004o`088P;o0000??ooool004Cooooo0_l0000;ooooo`03o`000?oooooooooo00co
oooo0ol0000[ooooo`;o00001_l0JCT2o`0000Ko06910_l00006o`1KA`;o00001_l0E4`2o`0000Ko
04]=0_l00006o`0kAP;o00001Ol0;Sh2o`0000Co028g00Co0000o`0R=ol0003o00001Ol06302o`00
00Go00lY0_l00005o`088P?o0000>oooool005gooooo0ol0000]ooooo`03o`000?l0L33o000000Go
06Ti00?o0000o`1Y>Ol000001Ol0HT400ol0003o0691o`000005o`1KA`03o`000?l0FdOo000000Go
05A<00?o0000o`1DC?l000001Ol0Bdd00ol0003o04]=o`000005o`0kAP03o`000?l0>dKo000000Co
02hn00?o0000o`0^?_l000001?l08SL2o`000003o`0R=ol0003o01P`00?o01P`00?o0000o`0H<?l0
00001?l03bT00ol0003o00lYo`000003o`088P;o00000_l02282o`0003[ooooo001Kooooo`?o0000
;_ooool01Ol0003o070`o`1`<?l0L33o000000?o06Ti00Go0000o`1Y>Ol0JCWo06Tio`000003o`1R
@@05o`000?l0HT7o0691o`1R@Ol000000ol0FdL01Ol0003o05]7o`1KAol0FdOo000000?o05A<00Go
0000o`1DC?l0E4co05A<o`000003o`1;C@05o`000?l0Bdgo04]=o`1;COl000000_l0>dH2o`0000?o
03]600Co0000o`0^?_l0;Sko00000ol0;Sh00ol0003o028go`0R=`02o`0000?o028g00Co0000o`0H
<?l0633o00000ol063001?l0003o00lYo`0?:Ol00003o`0?:@03o`000?l022;o000000Go00PR00?o
0000ooooooooool0>?ooool005Wooooo0_l0000`ooooo`03o`000?l0L33o070`00?o070`00?o0000
o`1Y>Ol000001Ol0JCT00ol0003o0691o`000005o`1R@@03o`000?l0FdOo000000Go05]700?o0000
o`1DC?l000001Ol0E4`00ol0003o04]=o`000004o`1;C@03o`000?l0>dKo000000Go03]600?o0000
o`0^?_l000001?l0;Sh01Ol0003o028go`000?l08SOo000000?o028g00?o0000o`0H<?l000001?l0
63000ol0003o00lYo`000004o`0?:@;o00001_l02282o`0003Wooooo001Fooooo`?o0000<?ooool2
o`0000Ko070`0_l00006o`1Y>@;o00001_l0HT42o`0000Ko05]70_l00006o`1DC0;o00001Ol0Bdd2
o`0000Ko03]60_l00005o`0^?P;o00000_l08SL01?l0003o028go`0R=ol08SL2o`0000Go01P`0_l0
0004o`0?:@03o`000?l03bWo000000Go00PR00Co0000o`088_l0003o0000>?ooool005Cooooo0_l0
00000ooooooo0000ooooo`0_ooooo`03o`000?l0MbGo000000Go070`00Co0000o`1`<?l0L33o0000
0ol0JCT2o`0000;o06Ti00Co0000o`1R@Ol0HT7o06910_l00002o`1R@@04o`000?l0FdOo05]7o`1K
A`;o00000_l0FdL01?l0003o05A<o`1DC?l0E4`2o`000003o`1DC?l0003o04]=00;o04]=0_l00002
o`1;C@04o`000?l0>dKo03]6o`0kAP;o000000?o03]6o`000?l0;Sh00_l0;Sh2o`0000;o02hn00Co
0000o`0R=ol0003o028g0_l000000ol08SOo0000o`0H<002o`0H<0;o000000?o01P`o`000?l03bT0
0_l03bT01Ol0003o00lYo`0?:Ol03bWo000000?o00PR00Go0000o`088_l022;o00PRo`00000hoooo
o`00DOooool3o`0003?ooooo00Go0000o`1g9Ol0MbGo07LUo`000003o`1`<003o`000?l0L33o070`
00;o070`00?o0000o`1Y>Ol000001Ol0JCT00ol0003o0691o`000005o`1R@@03o`000?l0FdOo0000
00Go05]700?o0000o`1DC?l000001?l0E4`00ol0003o04]=o`000005o`1;C@03o`000?l0>dKo0000
00Co03]600?o0000o`0^?_l000001Ol0;Sh3o`0000Co028g00?o0000o`0H<?l000001?l063000ol0
003o00lYo`000005o`0?:@03o`000?l022;o000000Co00PR0_l0000gooooo`00Coooool2o`0003Go
oooo00?o0000o`1g9Ol0MbD00ol0MbD00ol0003o070`o`000005o`1`<0;o00001_l0JCT2o`0000Ko
06910_l00006o`1KA`;o00001Ol0E4`2o`0000Ko04]=0_l00005o`0kAP;o00001_l0;Sh3o`0000Co
028g0_l00005o`0H<0;o00001_l03bT2o`0000Go00PR0ol0000fooooo`008Oooool2o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0001gooooo1?l0000dooooo`;o00001_l0MbD2o`0000Go070`
00?o0000o`1`<?l000001Ol0JCT00ol0003o06Tio`000005o`1R@@03o`000?l0HT7o000000Go05]7
00?o0000o`1KAol000001?l0E4`00ol0003o05A<o`000005o`1;C@03o`000?l0Bdgo000000?o03]6
0_l00002o`0kAP04o`000?l0;Sko02hno`0^?P;o000000?o02hno`000?l000000_l08SL2o`0000;o
028g00Go0000o`0H<?l0633o01P`o`000002o`0H<004o`000?l03bWo00lYo`0?:@;o000000?o00lY
o`000?l022800_l02282o`000003o`088_l0003o000000Sooooo0_l0000/ooooo`008?ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000006Oooool3o`0003Kooooo0_l0
0002o`1n6004o`000?l0MbGo07LUo`1g9@;o00000_l0MbD01Ol0003o070`o`1`<?l0L33o000000?o
070`00Go0000o`1Y>Ol0JCWo06Tio`000003o`1Y>@05o`000?l0HT7o0691o`1R@Ol000000ol0HT40
1Ol0003o05]7o`1KAol0FdOo000000?o05]700Co0000o`1DC?l0E4co00000ol0E4`01Ol0003o04]=
o`1;COl0Bdgo000000?o04]=00?o0000o`0kA_l000001Ol0>dH00ol0003o02hno`000004o`0^?P03
o`000?l08SOo000000Go028g00?o0000o`0H<?l000001?l063000ol0003o00lYo`000004o`0?:@03
o`000?l022;o000000Co00PR0_l00006ooooo`04o`000?ooooooooooo`0002_ooooo000Iooooo`Go
00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo01Gooooo0_l0000hoooo
o`03o`000?l0OQSo07hH00?o07hH00?o0000o`1g9Ol000001Ol0MbD00ol0003o070`o`000005o`1`
<003o`000?l0JCWo000000Go06Ti00?o0000o`1R@Ol000001Ol0HT400ol0003o05]7o`000004o`1K
A`03o`000?l0E4co000000Go05A<00?o0000o`1;COl000001Ol0Bdd00ol0003o03]6o`0kAP04o`0k
AP;o00001Ol0;Sh2o`0000Ko028g0_l00005o`0H<0;o00001Ol03bT2o`0000Go00PR0_l00006oooo
o`04o`000?ooooooooooo`0002_ooooo000Pooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool04_ooool3o`0003Sooooo0_l00006o`1n60;o00001_l0MbD2o`0000Ko070`0_l00006
o`1Y>@;o00001_l0HT42o`0000Go05]70_l00006o`1DC0;o00001Ol0Bdd2o`0000Go03]600?o0000
o`0kA_l000001?l0;Sh3o`0000Go028g00?o0000o`0R=ol000000ol06302o`000003o`0H<?l0003o
00lY00;o00lY0_l000000ol03bWo0000o`088P02o`088P;o000000?o00PRo`000?l000001Oooool0
1?l0003oooooooooool0000[ooooo`008?ooool01?l0003oooooooooool00007ooooo`Co00004_oo
ool3o`0003[ooooo00?o0000o`252Ol000001Ol0OQP00ol0003o07hHo`000005o`1g9@04o`000?l0
MbGo07LUo`0000?o070`0_l00002o`1`<004o`000?l0JCWo06Tio`1Y>@;o00000_l0JCT01?l0003o
0691o`1R@Ol0HT42o`000003o`1R@Ol0003o05]700;o05]70_l00002o`1KA`04o`000?l0E4co05A<
o`1DC0;o00000_l0E4`01Ol0003o04]=o`1;COl0Bdgo000000;o04]=00Go0000o`0kA_l0>dKo03]6
o`000003o`0kAP08o`000?l0;Sko02hno`000?l0;Sko0000o`0^?_l00003o`0R=`07o`000?l08SOo
028go`0R=ol0003o01P`o`000004o`0H<003o`000?l03bWo000000Co00lY00?o0000o`088_l00000
1?l02282o`0000Cooooo00Co0000oooooooooooo0000:oooool0023ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Aooooo`Co0000>_ooool01Ol0003o08D9o`252Ol0Q@Wo0000
00?o07hH00Go0000o`1n6?l0OQSo07hHo`000003o`1g9@03o`000?l0MbGo07LU00;o07LU00?o0000
o`1`<?l000001Ol0L3000ol0003o06Tio`000005o`1Y>@03o`000?l0HT7o000000Co069100?o0000
o`1KAol000001Ol0FdL00ol0003o05A<o`000005o`1DC003o`000?l0Bdgo000000Co04]=00?o0000
o`0kA_l000001?l0>dH00ol0003o02hno`000002o`0^?P06o`000?l0;Sko02hno`000?l08SOo0000
1?l08SL2o`0000Go01P`0_l00005o`0?:@;o00001Ol02283o`0000?ooooo00Co0000oooooooooooo
0000:oooool0027ooooo0_l00008ooooo`Go00003Oooool2o`0003gooooo00?o0000o`252Ol0Q@T0
0ol0Q@T00ol0003o07hHo`000005o`1n6003o`000?l0MbGo000000Go07LU0_l00006o`1`<0;o0000
1_l0JCT2o`0000Go06910_l00006o`1KA`;o00001_l0E4`2o`0000Go04]=0_l00005o`0kAP;o0000
0ol0;Sh00ol0003o02hno`0^?P02o`0000Co028g00?o0000o`0R=ol000001?l063000ol0003o01P`
o`000003o`0?:@;o000000?o00lYo`000?l022800_l02282o`000003o`088_l0003o000000Cooooo
0_l0000/ooooo`00>_ooool3o`0003gooooo0_l00006o`252@;o00001_l0OQP2o`0000Go07LU00?o
0000o`1g9Ol000001Ol0L3000ol0003o070`o`000005o`1Y>@03o`000?l0JCWo000000?o06910_l0
0002o`1R@@04o`000?l0FdOo05]7o`1KA`;o00000_l0FdL01?l0003o05A<o`1DC?l0E4`2o`000003
o`1DC?l0003o04]=00;o04]=0_l000000ol0Bdgo0000o`0kAP02o`0kAP;o00000_l0>dH00ol0003o
02hno`000003o`000003o`0^?_l0003o028g00;o028g00Go0000o`0R=ol08SOo028go`000002o`0H
<007o`000?l0633o01P`o`0H<?l0003o00lYo`000004o`0?:@03o`000?l022;o000000Co00PR0_l0
000aooooo`00>?ooool2o`000003ooooool0003ooooo03_ooooo0_l00002o`J<0004o`000?l0Q@Wo
08D9o`252@;o00000_l0Q@T01?l0003o07hHo`1n6?l0OQP2o`0000;o07hH00Go0000o`1g9Ol0MbGo
07LUo`000003o`1g9@05o`000?l0L33o070`o`1`<?l000000ol0L3001Ol0003o06Tio`1Y>Ol0JCWo
000000?o06Ti00?o0000o`1R@Ol000001Ol0HT400ol0003o05]7o`000005o`1KA`03o`000?l0E4co
000000Co05A<00?o0000o`1;COl000001?l0Bdd00ol0003o03]6o`000003o`0kAP?o000000?o02hn
o`000?l0;Sh00ol0;Sh00ol0003o028go`000004o`0R=`03o`000?l0633o000000Co01P`0_l00005
o`0?:@;o00001Ol02282o`00037ooooo000eooooo`?o0000?oooool00ol0003o1X`0o`J<0003o`J<
0003o`000?l0Q@Wo000000Go08D900?o0000o`1n6?l000001Ol0OQP00ol0003o07LUo`000005o`1g
9@03o`000?l0L33o000000Go070`00?o0000o`1Y>Ol000001?l0JCT2o`0000Ko06910_l00006o`1K
A`;o00001Ol0E4`2o`0000Go04]=0_l000001?l0>dKo0000o`000?l00002o`0kAP;o000000?o02hn
o`000?l0;Sh00_l0;Sh2o`0000Go028g0_l00004o`0H<003o`000?l0633o000000Co00lY00?o0000
o`0?:Ol000000ol02282o`000003o`088_l0003o0000033ooooo000dooooo`;o0000?oooool2o`00
00Ko1X`00_l00006o`252@;o00001_l0OQP2o`0000Ko07LU0_l00006o`1`<0;o00001?l0JCT00ol0
003o06Tio`000005o`1R@@03o`000?l0HT7o000000Go05]700?o0000o`1KAol000000ol0E4`2o`00
0003o`1DC?l0003o04]=00;o04]=1Ol00003o`0kAP;o000000Co03]6o`000?l0;Sko02hn0ol00000
0ol0;Sko0000o`0R=`02o`0R=`;o000000?o028go`000?l063000_l063001Ol0003o01P`o`0H<?l0
633o000000;o00lY00Oo0000o`0?:Ol03bWo00lYo`000?l022;o000000Co00PR0_l0000_ooooo`00
<oooool4o`0003gooooo00?o0000oaVC0?l000001Ol6S0001?l0003o1X`0o`J<0?l00003o`252@;o
00000_l0Q@T01?l0003o07hHo`1n6?l0OQP2o`0000;o07hH00Co0000o`1g9Ol0MbGo07LU0_l00002
o`1g9@04o`000?l0L33o070`o`1`<0;o000000?o070`o`000?l0JCT00_l0JCT01Ol0003o06Tio`1Y
>Ol0JCWo000000?o069100Go0000o`1R@Ol0HT7o0691o`000003o`1KA`07o`000?l0FdOo05]7o`1K
Aol0003o05A<o`000004o`1DC003o`000?l0Bdgo000000;o00000ol0Bdd00ol0003o03]6o`000004
o`0kAP04o`000?l0;Sko0000o`0000?o02hn00?o0000o`0R=ol000001?l08SL00ol0003o01P`o`00
0004o`0H<003o`000?l03bWo000000Co00lY0_l00005o`088P;o0000;oooool003Cooooo00Co0000
oooooooooooo0000>oooool01Ol0003o6I<0oaVC0?lIT`3o000000?o1X`000?o0000o`J<0?l6S000
0_l6S0000ol0003o08D9o`000005o`252@03o`000?l0OQSo000000Go07hH00?o0000o`1g9Ol00000
1Ol0MbD00ol0003o070`o`000004o`1`<003o`000?l0JCWo000000Go06Ti00?o0000o`1R@Ol00000
1Ol0HT400ol0003o05]7o`000004o`1KA`;o00001?l0E4`3o`0000Ko04]=0_l00005o`0kAP;o0000
00?o02hno`000?l0;Sh00_l0;Sh2o`0000Go028g0_l00005o`0H<0;o00001?l03bT00ol0003o00lY
o`000004o`088P04o`000?l022;o0000o`0002kooooo000dooooo`05o`000?ooooooooooooooool0
0000>Oooool00ol0003o6I<0oaVC0003oaVC0003o`000?l6S03o000000Go1X`00_l00006o`252@;o
00001_l0OQP2o`0000Ko07LU0_l00005o`1`<0;o00001_l0JCT2o`0000Ko06910_l00004o`1KA`04
o`000?l0FdOo0000o`1DC0?o000000Co05A<o`000?l0E4co00000ol0Bdd2o`000003o`1;COl0003o
03]600;o03]60_l000001?l0>dKo0000o`0^?_l0;Sh3o`000003o`0^?_l0003o028g00;o028g0_l0
00000ol08SOo0000o`0H<002o`0H<0;o000000?o01P`o`000?l03bT00_l03bT01Ol0003o00lYo`0?
:Ol03bWo000000;o00PR00Co0000o`088_l022;o00PR0_l0000]ooooo`00<oooool2o`0000Cooooo
00?o0000ooooooooool0=?ooool2o`0000Ko6I<00_l00005o`J<0003o`000?l6S03o000000Go08D9
00?o0000o`252Ol000001Ol0OQP01?l0003o07hHo`1n6?l00003o`1g9@;o000000?o07LUo`000?l0
L3000_l0L302o`0000;o070`00Co0000o`1Y>Ol0JCWo06Ti0_l00002o`1Y>@04o`000?l0HT7o0691
o`1R@@;o000000?o0691o`000?l0FdL00_l0FdL00ol0003o05]7o`000002o`0000?o05A<00Oo0000
o`1DC?l0E4co05A<o`000?l0Bdgo000000Co04]=00?o0000o`0kA_l000001?l0>dH01?l0003o02hn
o`000?l00003o`0^?P03o`000?l08SOo000000Co028g00?o0000o`0H<?l000001?l063000ol0003o
00lYo`000004o`0?:@03o`000?l022;o000000Co00PR0_l0000]ooooo`00<oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo037ooooo0_l00002obbJ0004o`000?lIT`3o6I<0oaVC00;o
00000_lIT`001Ol0003o1X`0o`J<0?l6S03o000000?o1X`000Go0000o`252Ol0Q@Wo08D9o`000003
o`252@05o`000?l0OQSo07hHo`1n6?l000001?l0OQP00ol0003o07LUo`000004o`1g9@03o`000?l0
L33o000000Go070`00?o0000o`1Y>Ol000001Ol0JCT00ol0003o0691o`000004o`1R@@03o`000?l0
FdOo000000;o00000ol0FdL00ol0003o05A<o`000004o`1DC0;o00001Ol0Bdd2o`0000Go03]60_l0
0002o`0^?P03o`000?l0;Sko02hn00;o00001Ol08SL2o`0000Go01P`0_l00005o`0?:@;o00001?l0
22801?l0003o00PRo`000?l0000/ooooo`00<oooool2o`0000Kooooo00?o0000ooooooooool0;ooo
ool00ol0003o;9X0obbJ0003obbJ0003o`000?lIT`3o000000Go6I<000?o0000o`J<0?l000001Ol6
S0000ol0003o08D9o`000005o`252@03o`000?l0OQSo000000Go07hH0_l00005o`1g9@;o00001_l0
L302o`0000Ko06Ti0_l00005o`1R@@?o00001Ol0FdL2o`0000Co05A<00?o0000o`1DC?l000001?l0
Bdd00ol0003o04]=o`000003o`0kAP;o00000_l0>dH01Ol0003o02hno`000?l0;Sko000000;o02hn
00Go0000o`0R=ol08SOo028go`000002o`0R=`07o`000?l0633o01P`o`0H<?l0003o01P`o`000003
o`0?:@;o000000?o00lYo`000?l022800_l022801?l0003o00PRo`088_l02282o`0002_ooooo000b
ooooo`;o00002?ooool00ol0003oooooooooo`0/ooooo`;o00001_l/VP02o`0000Ko6I<00_l00006
o`J<00;o00001_l0Q@T2o`0000Go07hH00?o0000o`1n6?l000001?l0MbD01?l0003o07LUo`1g9Ol0
0003o`1`<0;o00000_l0L3001?l0003o06Tio`1Y>Ol0JCT2o`000004o`1Y>Ol0003o0691o`1R@@?o
00000_l0HT401?l0003o05]7o`1KAol0FdL2o`000003o`1KAol0003o05A<00;o05A<00Go0000o`1D
C?l0E4co05A<o`000002o`1;C@07o`000?l0Bdgo04]=o`1;COl0003o03]6o`000005o`0kAP03o`00
0?l0;Sko000000Co02hn00?o0000o`0R=ol000001?l08SL00ol0003o01P`o`000003o`0H<003o`00
0?l03bWo000000Co00lY00?o0000o`088_l000001?l02282o`0002_ooooo000=ooooo`?o00001?oo
ool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02[ooooo00?o0000od:R0?l000001Ol/
VP001?l0003o;9X0obbJ0?l00003oaVC00;o00000_lIT`001?l0003o1X`0o`J<0?l6S002o`0000;o
1X`000Co0000o`252Ol0Q@Wo08D90_l00002o`252@05o`000?l0OQSo07hHo`1n6?l000000ol0OQP0
1?l0003o07LUo`1g9Ol00004o`1g9@03o`000?l0L33o000000Go070`00?o0000o`1Y>Ol000000ol0
JCT4o`0000Go069100?o0000o`1KAol000001?l0FdL00ol0003o05A<o`000004o`1DC003o`000?l0
Bdgo000000Go04]=00?o0000o`0kA_l0>dH01?l0>dH2o`000003o`0^?_l0003o02hn00;o02hn0_l0
0005o`0R=`;o00001?l06302o`0000Go00lY0_l00004o`088P04o`000?l022;o0000o`0002[ooooo
000>ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:?ooool01Ol0003o@Z80od:R0?m2
XP3o000000?o;9X000?o0000obbJ0?l/VP000_l/VP000ol0003o6I<0o`000005oaVC0003o`000?l6
S03o000000Go1X`000?o0000o`252Ol000001Ol0Q@T00ol0003o07hHo`000004o`1n6003o`000?l0
MbGo000000Go07LU0_l00006o`1`<0;o000000Go06Tio`000?l0003o0000o`1Y>@02o`0000Ko0691
0_l00005o`1KA`;o00001Ol0E4`2o`0000Go04]=00?o0000o`1;COl000000ol0>dH2o`000005o`0k
A_l0003o02hno`000?l0;Sh00_l000000ol0;Sko0000o`0R=`02o`0R=`;o000000?o028go`000?l0
63000_l063001?l0003o01P`o`0H<?l00003o`0?:@03o`000?l03bWo000000?o00PR00Co0000o`08
8_l022;o00PR0_l0000Yooooo`003_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooooooo`;o00002oooool00ol0003oooooooooo`0Vooooo`03o`000?m2XP3o@Z8000?o
@Z8000?o0000obbJ0?l000001Ol/VP02o`0000Ko6I<00_l00006o`J<00;o00001_l0Q@T2o`0000Go
07hH0_l00005o`1g9@03o`000?l0MbGo000000Go070`1?l00002o`1Y>@;o00000_l0JCT01?l0003o
0691o`1R@Ol0HT42o`000003o`1R@Ol0003o05]700;o05]70_l000000ol0FdOo0000o`1DC002o`1D
C0;o00000_l0E4`01Ol0003o04]=o`1;COl0Bdgo000000?o04]=00?o0000o`0kA_l000001?l0>dH0
0ol0003o02hno`000004o`0^?P03o`000?l08SOo000000Co028g00?o0000o`0H<?l000001?l06300
0ol0003o00lYo`000003o`0?:@03o`000?l022;o000000Co00PR0_l0000Yooooo`003_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003o
ooooooooo`0Sooooo`;o00001_m2XP02o`0000Go;9X000?o0000obbJ0?l000001OlIT`001?l0003o
6I<0oaVC0?l00003o`J<00;o00000_l6S0001?l0003o08D9o`252Ol0Q@T2o`0000;o08D900Go0000
o`1n6?l0OQSo07hHo`000002o`1n6005o`000?l0MbGo07LUo`1g9Ol000000ol0MbD00ol0003o070`
o`1`<003o`0000;o070`00?o0000o`1Y>Ol000001Ol0JCT00ol0003o0691o`000004o`1R@@03o`00
0?l0FdOo000000Co05]700?o0000o`1DC?l000001Ol0E4`00ol0003o04]=o`000004o`1;C@;o0000
1Ol0>dH2o`000003o`0^?_l0003o02hn00;o02hn0_l00005o`0R=`;o00001Ol06302o`0000Co00lY
0_l00004o`088P04o`000?l022;o0000o`0002Sooooo000>ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
o`000?ooool01?l00004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08?ooool2
o`0000;oFJT000Co0000od:R0?m2XP3o@Z800_l00002od:R0005o`000?l/VP3o;9X0obbJ0?l00000
0ol/VP001Ol0003o6I<0oaVC0?lIT`3o000000Co6I<000?o0000o`J<0?l000001Ol6S0000ol0003o
08D9o`000005o`252@03o`000?l0OQSo000000Co07hH00?o0000o`1g9Ol000001?l0MbD4o`0000Co
070`0_l00006o`1Y>@;o00001Ol0HT42o`0000Go05]70_l00006o`1DC0;o00001?l0Bdd00ol0003o
04]=o`000003o`0kAP;o000000Co03]6o`000?l0;Sko02hn0ol000000ol0;Sko0000o`0R=`02o`0R
=`;o000000?o028go`000?l063000_l06302o`000003o`0H<?l0003o00lY00;o00lY00?o0000o`0?
:Ol000000ol022801?l0003o00PRo`088_l02282o`0002Oooooo000=ooooo`;o00001?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00006ooooo`;o00003oooool2o`0001kooooo0_l00005oeVY0003o`000?m2XP3o000000Go
@Z8000?o0000obbJ0?l000001Ol/VP000ol0003o6I<0o`000005oaVC00;o00001_l6S002o`0000Ko
08D90_l00005o`1n60;o00000ol0MbD2o`000003o`1g9Ol0003o000000Co070`00?o0000o`1`<?l0
00001Ol0JCT00ol0003o06Tio`000003o`1R@@;o00000_l0HT401Ol0003o05]7o`1KAol0FdOo0000
00;o05]700Co0000o`1DC?l0E4co05A<0_l000000ol0E4co0000o`1;C@02o`1;C@07o`000?l0Bdgo
04]=o`1;COl0003o03]6o`000004o`0kAP03o`000?l0;Sko000000Co02hn00?o0000o`0R=ol00000
1?l08SL00ol0003o01P`o`000004o`0H<003o`000?l03bWo000000?o00lY00?o0000o`088_l00000
1?l02282o`0000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Aooooo`003_oo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000[ooooo0_l00002ooooo`Go00000ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo0_l00007oeVY00;o00001_m2
XP02o`0000Ko;9X00_l00005oaVC0003o`000?lIT`3o000000Go1X`000Co0000o`J<0?l6S03o0000
0ol0Q@T2o`000003o`252Ol0003o07hH00;o07hH0_l00002o`1n60?o000000Go07LUo`000?l0003o
07LUo`000003o`1`<005o`000?l0L33o070`o`1`<?l000000ol0JCT01ol0003o06Tio`1Y>Ol0JCWo
0000o`1R@Ol000001Ol0HT400ol0003o05]7o`000004o`1KA`03o`000?l0E4co000000Co05A<00?o
0000o`1;COl000001?l0Bdd2o`0000Go03]60_l000000ol0;Sko0000o`0^?P02o`0^?P;o00001Ol0
8SL2o`0000Go01P`0_l00004o`0?:@;o00000ol02282o`000003o`088_l0003o000000Kooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`0@ooooo`00<_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01Oooooo00Co0000og:`0?mb/03o00001OmIZ@001?l0003oFJT0
oeVY0?l00003od:R00;o00000_m2XP001?l0003o;9X0obbJ0?l/VP02o`0000;o;9X000Go0000oaVC
0?lIT`3o6I<0o`000003oaVC0005o`000?l6S03o1X`0o`J<0?l000001?l6S0000ol0003o08D9o`00
0004o`252@04o`000?l0OQSo0000o`1n60?o000000Co07hHo`000?l0MbGo00001?l0MbD00ol0003o
070`o`000005o`1`<003o`000?l0JCWo000000Co06Ti0_l00006o`1R@@;o00001Ol0FdL2o`0000Go
05A<0_l00004o`1;C@03o`000?l0Bdgo000000?o03]60_l000001?l0>dKo0000o`0^?_l0;Sh3o`00
0003o`0^?_l0003o028g00;o028g0_l000000ol08SOo0000o`0H<002o`0H<0;o000000?o01P`o`00
0?l03bT00_l03bT01_l0003o00lYo`0?:Ol0003o00PRo`0000Co00PR0_l00005ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool04?ooool0037ooooo0_l0000Cooooo`03o`000?oo
oooooooo01Gooooo00?o0000og:`0?mb/0000_mb/0001Ol0003oFJT0oeVY0?mIZ@3o000000CoFJT0
00?o0000od:R0?l000001Om2XP000ol0003o;9X0o`000005obbJ0003o`000?lIT`3o000000Go6I<0
00?o0000o`J<0?l000001Ol6S002o`0000Go08D91?l00004o`1n60;o00001Ol0MbD2o`0000Ko070`
0_l00004o`1Y>@04o`000?l0JCWo06Tio`0000?o06910_l000000ol0HT7o0000o`1KA`02o`1KA`;o
000000?o05]7o`000?l0E4`00_l0E4`2o`000003o`1DC?l0003o04]=00;o04]=00Oo0000o`1;COl0
Bdgo04]=o`000?l0>dKo000000Co03]600Co0000o`0^?_l0003o00000ol0;Sh00ol0003o028go`00
0004o`0R=`03o`000?l0633o000000Co01P`00?o0000o`0?:Ol000001?l03bT00ol0003o00PRo`08
8P03o`088P;o00001Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo013ooooo
000aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oL[00og:`
0004og:`0003o`000?mIZ@3o000000GoFJT00_l00006od:R00;o00001_l/VP02o`0000Ko6I<00_l0
0005o`J<0003o`000?l6S03o000000?o08D90ol000000ol0Q@Wo0000o`1n6002o`1n60;o00000_l0
OQP01Ol0003o07LUo`1g9Ol0MbGo000000;o07LU00Co0000o`1`<?l0L33o070`0_l000000ol0L33o
0000o`1Y>@02o`1Y>@03o`000?l0JCWo06Ti00;o06Ti00?o0000o`1R@Ol000001?l0HT400ol0003o
05]7o`000004o`1KA`03o`000?l0E4co000000Co05A<00?o0000o`1;COl000001Ol0Bdd00ol0003o
03]6o`0kAP03o`0kAP;o000000?o02hno`000?l0;Sh00_l0;Sh2o`0000Go028g0_l00005o`0H<0;o
00001?l03bT2o`0000?o00PR0_l000000ol022;o0000o`000004ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool04?ooool0037ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0@ooooo`?o00001_mb/002o`0000GoFJT000Co0000oeVY0?mIZ@3o00000om2XP02o`00
00;o@Z8000Co0000obbJ0?l/VP3o;9X00_l00002obbJ0004o`000?lIT`3o6I<0oaVC00;o00000_lI
T`001Ol0003o1X`0o`J<0?l6S03o000000?o1X`01?l00004o`252@03o`000?l0OQSo000000Go07hH
00?o0000o`1g9Ol000001?l0MbD00ol0003o070`o`000004o`1`<003o`000?l0JCWo000000Go06Ti
0_l00005o`1R@@;o00001Ol0FdL2o`0000Go05A<0_l00005o`1;C@;o00000ol0>dH2o`000004o`0k
A_l0003o02hno`0^?P?o000000?o02hno`000?l08SL00_l08SL2o`000003o`0R=ol0003o01P`00;o
01P`0_l000000ol0633o0000o`0?:@02o`0?:@06o`000?l03bWo00lYo`000?l022;o00001?l02282
o`0000?ooooo00Co0000oooooooooooo00002?ooool2o`0001;ooooo000`ooooo`?o00005_ooool0
0ol0003oooooooooo`0=ooooo`;o00000on<]`001?l0003oL[00og:`0?mb/002o`0000;oL[0000Go
0000oeVY0?mIZ@3oFJT0o`000004oeVY0003o`000?m2XP3o000000Go@Z8000?o0000obbJ0?l00000
1Ol/VP000ol0003o6I<0o`000005oaVC0004o`000?l6S03o0000o`J<00Co000000?o08D9o`000?l0
Q@T01?l0Q@T2o`0000Ko07hH0_l00005o`1g9@;o00001Ol0L302o`0000Go06Ti00?o0000o`1Y>Ol0
00000ol0HT42o`000003o`1R@Ol0003o05]700;o05]70_l00002o`1KA`05o`000?l0E4co05A<o`1D
C?l000000_l0E4`01Ol0003o04]=o`1;COl0Bdgo000000;o04]=00?o0000o`0kA_l000001?l0>dH0
1?l0003o02hno`000?l00003o`0^?P03o`000?l08SOo000000Co028g00?o0000o`0H<?l000001?l0
63000ol0003o00lYo`000003o`0?:@;o00001Ol02282o`0000Cooooo0_l0000:ooooo`03o`000?oo
oooooooo013ooooo0005ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0_l00003ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?n<]`3oS;L000CoS;L000?o0000og:`0?l000001Omb/000
0ol0003oFJT0o`000005oeVY00;o00001_m2XP02o`0000Ko;9X00_l00006oaVC00Co00000ol6S002
o`0000Go08D900Co0000o`252Ol0Q@Wo00000ol0OQP2o`000003o`1n6?l0003o07LU00;o07LU0_l0
0002o`1g9@05o`000?l0L33o070`o`1`<?l000000_l0L3001Ol0003o06Tio`1Y>Ol0JCWo000000?o
06Ti00?o0000o`1R@Ol000001?l0HT400ol0003o05]7o`000005o`1KA`03o`000?l0E4co000000Co
05A<00?o0000o`1;COl000001?l0Bdd00ol0003o03]6o`0kAP03o`0kAP;o00000_l0;Sh00ol0003o
02hno`0^?P02o`0000Go028g0_l00005o`0H<0;o00000_l03bT2o`000003o`0?:Ol0003o00PR00;o
00PR0_l000000ol022;o0000o`00000Rooooo`001_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool02Oooool2o`0000KoS;L00_l00006og:`00;o0000
1OmIZ@000ol0003oFJT0o`000005od:R0004o`000?m2XP3o@Z80o`0000?o;9X00_l00002obbJ0004
o`000?lIT`3o6I<0oaVC00?o000000?o6I<0o`000?l6S0000_l6S0001?l0003o1X`0o`J<0?l00003
o`252@03o`000?l0Q@Wo08D900;o08D900?o0000o`1n6?l000001?l0OQP00ol0003o07LUo`000005
o`1g9@03o`000?l0L33o000000Co070`00?o0000o`1Y>Ol000001?l0JCT2o`0000Go06910_l00006
o`1KA`;o00001Ol0E4`2o`0000Co04]=00?o0000o`1;COl000000ol0>dH00ol0003o03]6o`000002
o`0^?P?o000000?o02hno`000?l08SL00_l08SL2o`000003o`0R=ol0003o01P`00;o01P`0_l00000
1?l0633o0000o`0?:Ol00004o`0?:@03o`000?l022;o000000Co00PR0_l0000Qooooo`001_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool000001Oooool2o`00
01[ooooo00?o0000ooooooooool01oooool01?l0003oZKh0ojVn0?l00003ohbg00;o00000_n<]`00
1?l0003oL[00og:`0?mb/002o`0000;oL[0000Go0000oeVY0?mIZ@3oFJT0o`000003oeVY0005o`00
0?m2XP3o@Z80od:R0?l000001?m2XP000ol0003o;9X0o`000005obbJ00Co00001?lIT`000ol0003o
1X`0o`000004o`J<0003o`000?l0Q@Wo000000Go08D90_l00005o`1n60;o00001_l0MbD2o`0000Go
070`0_l00004o`1Y>@04o`000?l0JCWo06Tio`0000?o069100Co0000o`1R@Ol0HT7o00000ol0FdL2
o`000003o`1KAol0003o05A<00;o05A<0_l000000ol0E4co0000o`1;C@02o`1;C@07o`000?l0Bdgo
04]=o`1;COl0003o03]6o`000003o`0kAP04o`000?l0;Sko0000o`0000?o02hn00?o0000o`0R=ol0
00001?l08SL00ol0003o01P`o`000003o`0H<0;o00001Ol03bT2o`0000Co00PR0ol0000Qooooo`00
1_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000
ojVn0?nY_P000_nY_P000ol0003oS;L0o`000005ohbg0003o`000?mb/03o000000GoL[0000?o0000
oeVY0?l000001OmIZ@000ol0003o@Z80o`000005od:R00;o00001?l/VP04o`0000Ko6I<00_l00005
o`J<00;o00001Ol0Q@T00ol0003o08D9o`000003o`1n60;o00000_l0OQP01?l0003o07LUo`1g9Ol0
MbD2o`000003o`1g9Ol0003o070`00;o070`0_l000000ol0L33o0000o`1Y>@02o`1Y>@03o`000?l0
JCWo06Ti00;o06Ti00?o0000o`1R@Ol000001?l0HT400ol0003o05]7o`000004o`1KA`03o`000?l0
E4co000000Co05A<00?o0000o`1;COl000001?l0Bdd2o`0000Co03]60_l00002o`0^?P03o`000?l0
;Sko02hn00;o00001Ol08SL2o`0000?o01P`00?o0000o`0H<?l000000ol03bT2o`000003o`0?:Ol0
003o00PR00;o00PR00?o0000o`088_l000000_l0000Pooooo`001_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
ooooool0003ooooo00Co00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?nY_P3oZKh000?oZKh00_l00006ohbg
00;o00001_mb/002o`0000KoFJT00_l00005od:R0003o`000?m2XP3o@Z8000Ko00000_l/VP001?l0
003o6I<0oaVC0?lIT`02o`000003oaVC0?l0003o1X`000;o1X`00_l00002o`J<0005o`000?l0Q@Wo
08D9o`252Ol000000ol0Q@T00ol0003o07hHo`000005o`1n6003o`000?l0MbGo000000Co07LU00?o
0000o`1`<?l000001?l0L3000ol0003o06Tio`000005o`1Y>@;o00001Ol0HT42o`0000Go05]70_l0
0005o`1DC0;o00000ol0Bdd2o`000003o`1;COl0003o03]600;o03]600[o0000o`0kA_l0>dKo0000
o`0^?_l0003o02hno`000?l0;Sko00000ol08SL2o`0000;o028g00?o0000o`0H<?l000000ol06300
0ol0003o00lYo`000004o`0?:@03o`000?l022;o000000?o00PR00?o0000ooooool000007oooool0
00Gooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?oo
ool01_l0003oooooooooool0003oooooo`0000Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_l00005ojVn0003o`000?nY_P3o0000
00GoS;L000Co0000ohbg0?n<]`3o00000omb/002o`0000;oL[0000Co0000oeVY0?mIZ@3oFJT00_l0
0002oeVY0006o`000?m2XP3o@Z80od:R0?l0003o@Z801?l000000ol/VP3o0000obbJ0004obbJ0003
o`000?lIT`3o000000Co6I<000?o0000o`J<0?l000001Ol6S0000ol0003o08D9o`000005o`252@03
o`000?l0OQSo07hH00Co07hH0_l00005o`1g9@;o00001Ol0L303o`0000?o06Ti0_l000000ol0JCWo
0000o`1R@@02o`1R@@;o000000?o0691o`000?l0FdL00_l0FdL2o`000003o`1KAol0003o05A<00;o
05A<0_l00002o`1DC003o`000?l0Bdgo000000Co04]=00?o0000o`0kA_l000001?l0>dH00ol0003o
02hno`000003o`0^?P03o`000?l08SOo000000Co028g0_l00004o`0H<0;o00001Ol03bT2o`0000Co
00PR0ol0000Oooooo`001_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000[ooooo
0_l00002ooooo`Go00000_ooool3o`0000?ooooo0_l0000Oooooo`;o00000_o5``001Ol0003oZKh0
ojVn0?nY_P3o000000?oZKh000Go0000ohbg0?n<]`3oS;L0o`000004ohbg0003o`000?mb/03o0000
00GoL[0000?o0000oeVY0?l000001OmIZ@000ol0003o@Z80o`000002o`0000?o@Z800_l00006obbJ
00;o00001OlIT`02o`0000Ko1X`00_l00005o`252@03o`000?l0Q@Wo000000?o07hH0_l000000ol0
OQSo0000o`1g9@02o`1g9@;o00000_l0MbD01Ol0003o070`o`1`<?l0L33o000000?o070`00?o0000
o`1Y>Ol000001?l0JCT00ol0003o0691o`000004o`1R@@03o`000?l0FdOo000000Co05]700?o0000
o`1DC?l000001?l0E4`2o`0000Go04]=0_l00005o`0kAP;o000000Co02hno`000?l0;Sko02hn0_l0
0003o`0R=`;o000000?o028go`000?l063000_l063000ol0003o01P`o`000003o`0?:@;o000000?o
00lYo`000?l022800_l022800ol0003o00PRo`088P02o`0001kooooo000_ooooo`03o`000?oooooo
oooo01gooooo00?o0000olG30?o5``000oo5``000ol0003oZKh0o`000005ojVn0003o`000?n<]`3o
000000GoS;L00_l00006og:`00;o00001OmIZ@03o`0000Go@Z8000Co0000od:R0?m2XP3o00000ol/
VP02o`0000;o;9X000Go0000oaVC0?lIT`3o6I<0o`000002oaVC0004o`000?l6S03o1X`0o`J<00;o
00000_l6S0001Ol0003o08D9o`252Ol0Q@Wo000000?o08D900?o0000o`1n6?l000001?l0OQP00ol0
003o07LUo`000005o`1g9@03o`000?l0L33o000000Co070`0_l00005o`1Y>@;o00001Ol0HT42o`00
00Go05]70_l00004o`1DC003o`000?l0E4co000000?o04]=0_l000000ol0Bdgo0000o`0kAP02o`0k
AP;o000000Co03]6o`000?l0;Sko02hn0_l00002o`0^?P03o`000?l08SOo000000Co028g00?o0000
o`0H<?l000000ol063000ol0003o00lYo`000004o`0?:@03o`000?l022;o000000?o00PR0ol0000M
ooooo`00;oooool00ol0003oooooooooo`0Kooooo`;o00001_o5``02o`0000KoZKh00_l00005ohbg
0004o`000?n<]`3oS;L0o`0000?oL[000_l00002og:`0003o`000?mIZ@3o000000?o00000_mIZ@00
1Ol0003o@Z80od:R0?m2XP3o000000Co@Z8000?o0000obbJ0?l000001Ol/VP000ol0003o6I<0o`00
0004oaVC0003o`000?l6S03o000000Go1X`000?o0000o`252Ol000001?l0Q@T2o`0000Go07hH0_l0
0006o`1g9@;o00001?l0L3000ol0003o070`o`000003o`1Y>@;o000000?o06Tio`000?l0HT400_l0
HT42o`000003o`1R@Ol0003o05]700;o05]70_l000000ol0FdOo0000o`1DC002o`1DC007o`000?l0
E4co05A<o`1DC?l0003o04]=o`000004o`1;C@03o`000?l0>dKo000000Co03]600?o0000o`0^?_l0
00000ol0;Sh2o`0000Go028g0_l00004o`0H<0;o00001Ol03bT2o`0000?o00PR00Co0000o`088_l0
003o00007Oooool002oooooo0_l0000Kooooo`04o`000?o</P3oc;80o`0000?oaL<00_l00002olG3
0004o`000?nY_P3oZKh0ojVn00;o00000_nY_P001Ol0003oS;L0ohbg0?n<]`3o000000CoS;L000?o
0000og:`0?l000001?mb/002o`000003oeVY0?l0003oFJT000CoFJT000?o0000od:R0?l000001Om2
XP02o`0000Ko;9X00_l00005oaVC00;o00001_l6S002o`0000Co08D900Co0000o`252Ol0Q@Wo0000
0ol0OQP01?l0003o07hHo`1n6?l00003o`1g9@;o000000?o07LUo`000?l0L3000_l0L3001ol0003o
070`o`1`<?l0L33o0000o`1Y>Ol000001?l0JCT00ol0003o0691o`000004o`1R@@03o`000?l0FdOo
000000Co05]700?o0000o`1DC?l000001?l0E4`2o`0000Go04]=0_l00005o`0kAP;o000000Ko02hn
o`000?l0;Sko0000o`0^?_l00003o`0R=`;o000000?o028go`000?l063000_l063000ol0003o01P`
o`000003o`0?:@;o00000_l03bT00ol0003o00PRo`000003o`088P;o00007?ooool002oooooo00?o
0000ooooooooool06Oooool00ol0003oc;80olbb0002olbb0003o`000?o5``3o000000GoaL<000?o
0000ojVn0?l000001OnY_P000ol0003oS;L0o`000005ohbg00;o00000_mb/003o`000003og:`0?l0
003o000000KoFJT00_l00005od:R0004o`000?m2XP3o@Z80o`0000?o;9X00_l000000ol/VP3o0000
oaVC0002oaVC00;o00000_lIT`001?l0003o1X`0o`J<0?l6S002o`000003o`J<0?l0003o08D900;o
08D900?o0000o`252Ol0Q@T00_l0Q@T00ol0003o07hHo`000004o`1n6003o`000?l0MbGo000000Co
07LU00?o0000o`1`<?l000001Ol0L3000ol0003o06Tio`1Y>@03o`1Y>@;o00001Ol0HT42o`0000Go
05]70ol00003o`1DC003o`000?l0E4co000000?o04]=0_l000000ol0Bdgo0000o`0kAP02o`0kAP;o
00000_l0>dH00ol0003o02hno`000003o`0^?P03o`000?l08SOo000000Co028g00?o0000o`0H<?l0
00000ol063000ol0003o00lYo`000004o`0?:@;o00001?l02283o`0001_ooooo000_ooooo`03o`00
0?oooooooooo01Sooooo00?o0000olbb0?o</P000oo</P02o`0000KoaL<00_l00006ojVn00;o0000
1On<]`000ol0003oS;L0o`000002o`0000;oL[000_l00002og:`0004o`000?mIZ@3oFJT0oeVY00;o
00000_mIZ@001Ol0003o@Z80od:R0?m2XP3o000000Co@Z8000?o0000obbJ0?l000001?l/VP000ol0
003o6I<0o`000005oaVC0003o`000?l6S03o000000Co1X`000?o0000o`252Ol000001Ol0Q@T2o`00
00Go07hH0_l00005o`1g9@;o00001Ol0L3000ol0003o070`o`000003o`1Y>@04o`000?l0JCWo06Ti
o`0000?o069100Co0000o`1R@Ol0HT7o00000ol0FdL01ol0003o05]7o`1KAol0FdOo0000o`1DC?l0
00000ol0E4`00ol0003o04]=o`000004o`1;C@03o`000?l0>dKo000000Co03]60_l000001?l0;Sko
0000o`0^?_l0;Sh2o`0000Go028g0_l00004o`0H<0;o00000ol03bT2o`000004o`0?:Ol0003o00PR
o`088P;o000000?o00PRo`000?l000006oooool002kooooo0ol0000Gooooo`;o00001Oo</P001?l0
003oc;80olbb0?l00003olG300;o00000_o5``001?l0003oZKh0ojVn0?nY_P02o`0000;oZKh000Co
0000ohbg0?n<]`3oS;L00ol00002ohbg0003o`000?mb/03o000000GoL[0000?o0000oeVY0?l00000
1OmIZ@000ol0003o@Z80o`000005od:R00;o00001Ol/VP02o`0000Ko6I<00_l00005o`J<00?o0000
0ol0Q@T2o`000003o`252Ol0003o07hH00;o07hH0_l00002o`1n6005o`000?l0MbGo07LUo`1g9Ol0
00000_l0MbD01Ol0003o070`o`1`<?l0L33o000000?o070`00?o0000o`1Y>Ol000001?l0JCT00ol0
003o0691o`000004o`1R@@03o`000?l0FdOo000000Co05]70_l00004o`1DC0;o00001Ol0Bdd2o`00
00Co03]600Wo0000o`0kA_l0003o02hno`000?l0;Sko0000o`0^?_l000000ol08SL2o`000003o`0R
=ol0003o01P`00;o01P`00Ko0000o`0H<?l0633o0000o`0?:Ol00004o`0?:@;o00001?l02282o`00
01[ooooo0003ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo0_l00003ooooo`?o00001?ooool3o`0000?ooooo00?o0000ooooooooool05Oooool2o`0000;o
dih000Go0000olbb0?o</P3oc;80o`000004olbb0003o`000?o5``3o000000GoaL<000?o0000ojVn
0?l000001OnY_P03o`0000KoS;L000?o0000og:`0?mb/0001?mb/002o`0000KoFJT00_l00005od:R
0004o`000?m2XP3o@Z80o`0000?o;9X000Co0000obbJ0?l/VP3o00000olIT`02o`0000;o6I<000Go
0000o`J<0?l6S03o1X`0o`000003o`J<0003o`000?l0Q@Wo000000Co08D900?o0000o`1n6?l00000
1Ol0OQP00ol0003o07LUo`000004o`1g9@03o`000?l0L33o000000Co070`0_l00005o`1Y>@;o0000
1Ol0HT42o`0000?o05]70_l000000ol0FdOo0000o`1DC002o`1DC003o`000?l0E4co000000?o04]=
0_l000000ol0Bdgo0000o`0kAP02o`0kAP07o`000?l0>dKo03]6o`0kA_l0003o02hno`000003o`0^
?P03o`000?l08SOo000000Co028g00?o0000o`0H<?l000000ol06302o`0000Co00lY0_l00005o`08
8P?o00006Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oCWP3odih000?odih000?o0000olbb0?l000001Oo</P03o`0000GoaL<00ol00002ojVn00Ko0000
1On<]`000ol0003oS;L0o`000003og:`00;o00000_mb/0001?l0003oFJT0oeVY0?mIZ@02o`0000;o
FJT000Go0000od:R0?m2XP3o@Z80o`000004od:R0003o`000?l/VP3o000000Co;9X000?o0000oaVC
0?l000001OlIT`000ol0003o1X`0o`000004o`J<00;o00001Ol0Q@T2o`0000Ko07hH0_l00005o`1g
9@;o00000ol0L302o`000003o`1`<?l0003o06Ti00;o06Ti0_l000000ol0JCWo0000o`1R@@02o`1R
@@;o00000_l0HT400ol0003o05]7o`000004o`1KA`03o`000?l0E4co000000?o05A<00?o0000o`1;
COl000001?l0Bdd00ol0003o03]6o`000004o`0kAP;o000000Co02hno`000?l0;Sko02hn0_l00005
o`0R=`;o00000ol063000ol0003o01P`o`000003o`0?:@03o`000?l03bWo000000?o00PR0_l00000
0ol022;o0000o`000008ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000;ooooo0004
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001?l00003ooooo`;o
00004oooool2o`0000Kodih00_l00005olbb0005o`000?o</P3oc;80olbb0?l000000oo5``000ol0
003oaL<0olG30003o`0000;oZKh000Go0000ojVn0?nY_P3oZKh0o`000003ohbg0007o`000?n<]`3o
S;L0ohbg0?l0003oL[00o`000005og:`0003o`000?mIZ@3o000000GoFJT000?o0000od:R0?l00000
1Om2XP02o`0000Go;9X00_l00006oaVC00;o00001?l6S0001?l0003o1X`0o`J<0?l00003o`252@04
o`000?l0Q@Wo08D9o`0000?o07hH0_l000000ol0OQSo0000o`1g9@02o`1g9@;o00000_l0MbD00ol0
003o070`o`000004o`1`<003o`000?l0JCWo000000Co06Ti00?o0000o`1R@Ol000001?l0HT42o`00
00Go05]70_l00004o`1DC0;o00001Ol0Bdd2o`0000?o03]60_l000001?l0>dKo0000o`0^?_l0;Sh2
o`000003o`0^?_l0003o028g00;o028g0_l00002o`0R=`03o`000?l0633o000000?o01P`00?o0000
o`0?:Ol000000ol03bT00ol0003o00PRo`000003o`088P?o00001_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000;ooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
013ooooo0_l00002omZ:0004o`000?oCWP3odih0om>N00;o00000_oCWP001Ol0003oc;80olbb0?o<
/P3o000000Goc;8000?o0000olG30?l000000ol00002olG30003o`000?nY_P3o000000GoZKh000?o
0000ohbg0?l000001On<]`000ol0003oL[00og:`0004og:`00;o00001_mIZ@02o`0000Go@Z8000?o
0000od:R0?l000000ol/VP02o`0000;o;9X000Co0000oaVC0?lIT`3o6I<00_l000000olIT`3o0000
o`J<0002o`J<0003o`000?l6S03o1X`000;o1X`000?o0000o`252Ol000001?l0Q@T00ol0003o07hH
o`000004o`1n6003o`000?l0MbGo000000Co07LU0_l00005o`1`<0;o00001Ol0JCT2o`0000?o0691
0_l000000ol0HT7o0000o`1KA`02o`1KA`;o000000?o05]7o`000?l0E4`00_l0E4`00ol0003o05A<
o`000003o`1;C@;o00000_l0Bdd00ol0003o03]6o`000004o`0kAP03o`000?l0;Sko000000?o02hn
00?o0000o`0R=ol000001?l08SL2o`0000Co01P`0_l00004o`0?:@;o00000ol022801Ol0003o00PR
o`000?oooooo000000Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02oooo
o`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co00000oooool00ol0003oooooo`00
0004ooooo`03o`000?oooooooooo00oooooo00?o0000omZ:0?oJRP000ooJRP000ol0003odih0o`00
0005om>N0003o`000?o</P3o000000Koc;800ol00005olG300;o00001_nY_P02o`0000GoS;L000?o
0000ohbg0?l000000omb/002o`0000;oL[0000Co0000oeVY0?mIZ@3oFJT00_l00002oeVY0005o`00
0?m2XP3o@Z80od:R0?l000000om2XP000ol0003o;9X0o`000005obbJ0003o`000?lIT`3o000000Co
6I<000?o0000o`J<0?l000001Ol6S002o`0000Go08D90_l00005o`1n60;o00000ol0MbD2o`000003
o`1g9Ol0003o070`00;o070`0_l000000ol0L33o0000o`1Y>@02o`1Y>@;o00000_l0JCT00ol0003o
0691o`000004o`1R@@03o`000?l0FdOo000000Co05]700?o0000o`1DC?l000000ol0E4`00ol0003o
04]=o`000004o`1;C@;o00001Ol0>dH2o`000004o`0^?_l0003o02hno`0^?P;o00000ol08SL2o`00
0004o`0R=ol0003o01P`o`0H<0;o000000?o01P`o`000?l03bT00_l03bT01_l0003o00lYo`0?:Ol0
003o00PRo`0000?o00PR0_l00005ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool00Oooool000?ooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000Oooooo0_l00004ooooo`03o`000?oo
oooooooo00gooooo0_l00006omZ:00?o00001OoCWP03o`0000Coc;800ol000000oo</P3o0000olG3
0002olG300;o00000_o5``001?l0003oZKh0ojVn0?nY_P02o`0000;oZKh000Go0000ohbg0?n<]`3o
S;L0o`000003ohbg0003o`000?mb/03o000000GoL[0000?o0000oeVY0?l000001OmIZ@000ol0003o
@Z80o`000004od:R00;o00001_l/VP02o`0000Go6I<00ol00003o`J<00;o000000?o1X`0o`000?l0
Q@T00_l0Q@T2o`000003o`252Ol0003o07hH00;o07hH0_l00002o`1n6003o`000?l0MbGo000000Co
07LU00?o0000o`1`<?l000001?l0L3000ol0003o06Tio`000005o`1Y>@03o`000?l0HT7o069100?o
06910_l00005o`1KA`;o00001?l0E4`3o`0000?o04]=00?o0000o`1;COl000000ol0>dH2o`000004
o`0kA_l0003o02hno`0^?P;o00000_l0;Sh00ol0003o028go`000004o`0R=`;o00001?l063000ol0
003o00lYo`000003o`0?:@;o00001?l02283o`0000Cooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000;ooooo0004ooooo`03o`000?oooooooooo00?ooooo0_l00004
ooooo`;o00002_ooool2o`0000;ooooo1Ol00004ooooo`05o`000?ooooooooooooooool000003ooo
ool01?l0003ohG<0on5c0?l00003omZ:00;o00000ooJRP001Ol0003odih0om>N0?oCWP3o000000?o
dih01Ol00004olbb0003o`000?o5``3o000000GoaL<000?o0000ojVn0?l000001OnY_P000ol0003o
S;L0o`000005ohbg0003o`000?mb/03oL[0000CoL[000_l00006oeVY00?o00000om2XP001?l0003o
@Z80od:R0?l00003obbJ00;o00000_l/VP001Ol0003o6I<0oaVC0?lIT`3o000000?o6I<000?o0000
o`J<0?l000001?l6S0000ol0003o08D9o`000004o`252@03o`000?l0OQSo000000Go07hH00?o0000
o`1g9Ol0MbD00ol0MbD2o`0000Go070`0_l00005o`1Y>@;o00000ol0HT42o`000003o`1R@Ol0003o
05]700;o05]70_l000000ol0FdOo0000o`1DC002o`1DC007o`000?l0E4co05A<o`1DC?l0003o04]=
o`000003o`1;C@03o`000?l0>dKo000000Co03]600?o0000o`0^?_l000000ol0;Sh2o`0000Co028g
0_l00005o`0H<0;o00000_l03bT2o`000003o`0?:Ol0003o00PR00;o00PR00?o0000o`088_l00000
0_l00003ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002oooo
o`00;Oooool00ol0003oooooooooo`0<ooooo`03o`000?oQL`3ohG<000;ohG<000?o0000omZ:0?l0
00001_oJRP000ol0003odih0o`000002om>N00Co000000?oc;80o`000?o</P001?o</P02o`0000Ko
aL<00_l00006ojVn00;o00001On<]`000ol0003oS;L0o`000003og:`00;o00000_mb/0001?l0003o
FJT0oeVY0?mIZ@02o`0000?oFJT000?o0000od:R0?l000001?m2XP000ol0003o;9X0o`000005obbJ
0003o`000?lIT`3o000000Co6I<00_l00005o`J<00;o00001Ol0Q@T2o`0000Go07hH00?o0000o`1n
6?l000000ol0MbD01?l0003o07LUo`1g9Ol00003o`1`<004o`000?l0L33o070`o`0000?o06Ti00Ko
0000o`1Y>Ol0JCWo0000o`1R@Ol00004o`1R@@03o`000?l0FdOo000000Co05]700?o0000o`1DC?l0
00001?l0E4`2o`0000Co04]=0_l00005o`0kAP;o000000Ko02hno`000?l0;Sko0000o`0^?_l00003
o`0R=`03o`000?l08SOo000000?o01P`0_l000001?l0633o0000o`0?:Ol00004o`0?:@03o`000?l0
22;o000000?o00PR0_l00004ooooo`;o00002Oooool3o`0000?ooooo000]ooooo`03o`000?oooooo
oooo00_ooooo00?o0000on5c0?oQL`000ooQL`03o`0000KofXX01Ol00003om>N00;o00001Oo</P00
1?l0003oc;80olbb0?l00003olG300;o00000_o5``001?l0003oZKh0ojVn0?nY_P02o`0000;oZKh0
00Go0000ohbg0?n<]`3oS;L0o`000003ohbg0003o`000?mb/03o000000GoL[0000?o0000oeVY0?l0
00001OmIZ@02o`0000Go@Z800_l00006obbJ00;o00001?lIT`000ol0003o6I<0o`000003o`J<00;o
00000_l6S0001Ol0003o08D9o`252Ol0Q@Wo000000;o08D900Go0000o`1n6?l0OQSo07hHo`000003
o`1n6003o`000?l0MbGo000000Co07LU00?o0000o`1`<?l000001?l0L3000ol0003o06Tio`000003
o`1Y>@;o00001Ol0HT42o`0000Go05]70_l00003o`1DC0;o000000?o05A<o`000?l0Bdd00_l0Bdd0
0ol0003o04]=o`000003o`0kAP;o00000_l0>dH00ol0003o02hno`000003o`0^?P03o`000?l08SOo
000000?o028g00?o0000o`0H<?l000000ol06302o`0000Go00lY0_l00004o`088P;o00005Oooool0
02gooooo0_l0000:ooooo`;o00001OoQL`001Ol0003ohG<0on5c0?oQL`3o000000?ofXX01Ol00003
om>N00;o00000_oCWP001Ol0003oc;80olbb0?o</P3o000000Coc;8000?o0000olG30?l000001Oo5
``000ol0003oZKh0o`000005ojVn0003o`000?n<]`3o000000CoS;L00_l00006og:`00;o00001OmI
Z@000ol0003oFJT0o`000003od:R00;o00000_m2XP001?l0003o;9X0obbJ0?l/VP02o`000003obbJ
0?l0003o6I<000;o6I<000Oo0000oaVC0?lIT`3o6I<0o`000?l6S03o000000Go1X`000?o0000o`25
2Ol000001?l0Q@T00ol0003o07hHo`000004o`1n60;o00001Ol0MbD2o`0000Go070`0_l00003o`1Y
>@04o`000?l0JCWo06Tio`0000?o069100?o0000o`1R@Ol000000ol0FdL2o`0000;o05]700?o0000
o`1DC?l000001?l0E4`00ol0003o04]=o`000003o`1;C@03o`000?l0>dKo000000Co03]60_l00000
1?l0;Sko0000o`0^?_l0;Sh2o`0000Co028g0_l00003o`0H<003o`000?l0633o000000?o00lY0_l0
00000ol03bWo0000o`088P03o`000003ooooool0003ooooo01Cooooo000]ooooo`03o`000?oooooo
oooo00Oooooo0_l00002onQK0005o`000?oQL`3ohG<0on5c0?l000001OoQL`04o`0000CofXX000?o
0000om>N0?l000001OoCWP000ol0003oc;80o`000005olbb00;o00001_o5``02o`0000KoZKh00ol0
0003ohbg0004o`000?n<]`3oS;L0o`0000?oL[000_l00002og:`0005o`000?mIZ@3oFJT0oeVY0?l0
00000omIZ@000ol0003o@Z80o`000005od:R0003o`000?l/VP3o000000Co;9X000?o0000oaVC0?l0
00001?lIT`02o`0000Ko1X`00_l00005o`252@;o00000ol0OQP2o`000003o`1n6?l0003o07LU00;o
07LU0_l000000ol0MbGo0000o`1`<002o`1`<0;o00000_l0L3000ol0003o06Tio`000004o`1Y>@03
o`000?l0HT7o000000?o069100?o0000o`1KAol000001?l0FdL2o`0000Go05A<0_l00004o`1;C@;o
00000ol0>dH2o`000003o`0kA_l0003o02hn00?o00000_l0;Sh01?l0003o028go`000?l00002o`0R
=`03o`000?l0633o000000?o01P`00?o0000o`0?:Ol000000ol03bT2o`0000Cooooo00?o0000oooo
ooooool04oooool002gooooo00?o0000ooooooooool01_ooool00ol0003oj5/0onQK0003onQK0003
o`000?oQL`3o000000CohG<01?l00006omZ:00;o00001_oCWP02o`0000Goc;8000Co0000olbb0?o<
/P3o00000oo5``02o`0000;oaL<000Co0000ojVn0?nY_P3oZKh00_l00003ojVn0003o`000?n<]`3o
000000CoS;L000?o0000og:`0?l000001Omb/0000ol0003oFJT0o`000005oeVY0003o`000?m2XP3o
@Z8000Co@Z800_l00005obbJ00?o00000olIT`001?l0003o6I<0oaVC0?l00003o`J<00;o000000?o
1X`0o`000?l0Q@T00_l0Q@T2o`0000;o08D900?o0000o`1n6?l000001?l0OQP00ol0003o07LUo`00
0004o`1g9@03o`000?l0L33o000000Co070`0_l00005o`1Y>@;o00001?l0HT43o`0000?o05]700?o
0000o`1KAol000000ol0E4`2o`0000;o05A<00Co0000o`1;COl0003o00000_l0Bdd00ol0003o03]6
o`000004o`0kAP?o00000ol0;Sh2o`0000Co028g0_l00004o`0H<0;o00000ol03bT00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01;ooooo000/ooooo`?o00001Oooool3o`0000Goj5/00ol0
0002on5c00;o000000GohG<0o`000?oQL`3ohG<0o`000003omZ:00;o00000_oJRP001?l0003odih0
om>N0?oCWP02o`0000;odih000Go0000olbb0?o</P3oc;80o`000004olbb0003o`000?o5``3o0000
00GoaL<000?o0000ojVn0?l000001OnY_P02o`0000GoS;L00_l00006og:`00;o00001OmIZ@000ol0
003oFJT0o`000003od:R00;o00000_m2XP001Ol0003o;9X0obbJ0?l/VP3o000000?o;9X000?o0000
oaVC0?l000001?lIT`000ol0003o1X`0o`000004o`J<0003o`000?l0Q@Wo000000Co08D90_l00005
o`1n60;o00001Ol0MbD2o`0000?o070`0_l000000ol0L33o0000o`1Y>@02o`1Y>@;o000000?o06Ti
o`000?l0HT400_l0HT401ol0003o0691o`1R@Ol0HT7o0000o`1KAol000000ol0FdL00ol0003o05A<
o`000004o`1DC0;o00001?l0Bdd2o`0000Co03]60_l00002o`0^?P?o000000?o02hno`000?l08SL0
0_l08SL00ol0003o028go`000003o`0H<006o`000?l0633o01P`o`000?l03bWo00002?ooool00ol0
003oooooooooo`0Booooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00000oooool3o`0000Cooooo00?o0000oooo
ooooool01?ooool01Ol0003okd40onm10?o_@@3o000000?oj5/000?o0000onQK0?oXF`000ol00002
on5c0003o`000?oQL`3ohG<000;ohG<000?o0000omZ:0?l000001OoJRP000ol0003odih0o`000005
om>N0003o`000?o</P3o000000Goc;800_l00006olG300;o00001OnY_P001?l0003oZKh0ojVn0?l0
0003ohbg0004o`000?n<]`3oS;L0o`0000?oL[000_l00002og:`0005o`000?mIZ@3oFJT0oeVY0?l0
00000omIZ@000ol0003o@Z80o`000005od:R0003o`000?l/VP3o000000Co;9X00_l00005oaVC00;o
00001Ol6S003o`0000?o08D900Co0000o`252Ol0Q@Wo00000ol0OQP01?l0003o07hHo`1n6?l00003
o`1g9@06o`000?l0MbGo07LUo`000?l0L33o00001?l0L3000ol0003o06Tio`000004o`1Y>@03o`00
0?l0HT7o000000Co06910_l00004o`1KA`;o00000ol0E4`2o`000003o`1DC?l0003o04]=00;o04]=
00?o0000o`1;COl000000ol0>dH01Ol0003o03]6o`0kA_l0003o02hn00;o00000ol0;Sh00ol0003o
028go`000003o`0R=`03o`000?l0633o000000?o01P`0_l00009ooooo`03o`000?oooooooooo01;o
oooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00
0003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003okd40onm10003onm10003o`00
0?oXF`3o000000?o00000_oXF`000ol0003ohG<0o`000005on5c00;o00001_oJRP02o`0000Kodih0
0ol00003olbb00;o00000_o</P001?l0003oaL<0olG30?o5``02o`0000;oaL<000Go0000ojVn0?nY
_P3oZKh0o`000004ojVn0003o`000?n<]`3o000000CoS;L000?o0000og:`0?l000001Omb/0000ol0
003oFJT0o`000004oeVY00;o00001_m2XP02o`0000?o;9X00_l000000ol/VP3o0000oaVC0002oaVC
00;o00000_lIT`001Ol0003o1X`0o`J<0?l6S03o000000?o1X`000?o0000o`252Ol000001?l0Q@T0
0ol0003o07hHo`000004o`1n6003o`000?l0MbGo000000?o07LU0_l00005o`1`<0;o00001Ol0JCT2
o`0000?o06910_l000000ol0HT7o0000o`1KA`02o`1KA`06o`000?l0FdOo05]7o`000?l0E4co0000
1?l0E4`00ol0003o04]=o`000003o`1;C@03o`000?l0>dKo000000?o03]60_l000000ol0;Sko0000
o`0^?P02o`0^?P;o00001?l08SL2o`0000?o01P`00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Booooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo0000
00?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?o_@@3okd4000Cokd400ol00005
onQK00;o00001OoQL`001?l0003ohG<0on5c0?l00003omZ:00;o00000_oJRP001?l0003odih0om>N
0?oCWP02o`0000?odih000?o0000olbb0?l000001Oo</P000ol0003oaL<0o`000005olG30003o`00
0?nY_P3o000000GoZKh00_l00005ohbg00;o00001_mb/003o`0000?oFJT000Co0000oeVY0?mIZ@3o
00000om2XP02o`0000;o@Z8000?o0000obbJ0?l000001?l/VP000ol0003o6I<0o`000005oaVC0003
o`000?l6S03o000000Co1X`00_l00005o`252@;o00001Ol0OQP2o`0000?o07LU00Co0000o`1g9Ol0
MbGo00000ol0L3000ol0003o070`o`000003o`1Y>@;o00000_l0JCT00ol0003o0691o`000004o`1R
@@03o`000?l0FdOo000000?o05]70_l00005o`1DC0;o00001?l0Bdd2o`0000?o03]600?o0000o`0k
A_l000000_l0;Sh3o`000004o`0^?_l0003o028go`0R=`;o00000_l08SL00ol0003o01P`o`00000<
ooooo`03o`000?oooooooooo01;ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooool000000ol00004ooooo`;o000000Coooooo`000?l0003o00000oo_@@03o`0000;o
kd4000Co0000onQK0?oXF`3oj5/00_l00002onQK0005o`000?oQL`3ohG<0on5c0?l000001?oQL`00
0ol0003ofXX0o`000005omZ:0003o`000?oCWP3o000000Kodih000?o0000olbb0?o</P001?o</P02
o`0000KoaL<00ol00003ojVn00;o00000_nY_P001Ol0003oS;L0ohbg0?n<]`3o000000;oS;L000Co
0000og:`0?mb/03oL[000_l00003og:`0003o`000?mIZ@3o000000CoFJT000?o0000od:R0?l00000
1Om2XP000ol0003o;9X0obbJ0003obbJ00;o00001_lIT`02o`0000?o1X`00_l000000ol6S03o0000
o`252@02o`252@;o000000?o08D9o`000?l0OQP00_l0OQP2o`0000;o07hH00?o0000o`1g9Ol00000
1?l0MbD00ol0003o070`o`000003o`1`<003o`000?l0JCWo000000Co06Ti0_l00005o`1R@@;o0000
0ol0FdL00ol0003o05]7o`000003o`1DC0;o000000?o05A<o`000?l0Bdd00_l0Bdd01_l0003o04]=
o`1;COl0003o03]6o`0000?o03]600Co0000o`0^?_l0003o00000ol0;Sh2o`0000Co028g0_l0000=
ooooo`03o`000?oooooooooo01;ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool0
1?l00002ooooo`03o`000?oooooooooo00Gooooo0ol00003ooLU00?o000000?okd40o`000?o_@@00
0oo_@@000ol0003oj5/0o`000005onQK0003o`000?oQL`3o000000KohG<00_l00005omZ:00?o0000
1OoCWP000ol0003odih0o`000003olbb00;o00000_o</P001?l0003oaL<0olG30?o5``02o`0000?o
aL<000?o0000ojVn0?l000001OnY_P000ol0003oS;L0o`000004ohbg0003o`000?mb/03o000000Go
L[000_l00005oeVY00;o00001Om2XP000ol0003o@Z80o`000003obbJ0004o`000?l/VP3o;9X0o`00
00?o6I<00_l00002oaVC0003o`000?l6S03o000000Co1X`000?o0000o`252Ol000001?l0Q@T00ol0
003o07hHo`000004o`1n60;o00001Ol0MbD2o`0000Co070`0ol00003o`1Y>@03o`000?l0JCWo0000
00?o06910_l00002o`1R@@03o`000?l0FdOo000000?o05]700?o0000o`1DC?l000001?l0E4`00ol0
003o04]=o`000003o`1;C@;o00001?l0>dH2o`0000;o02hn00Co0000o`0^?_l0003o00000ol08SL2
o`0000oooooo00?o0000ooooooooool04_ooool00003ooooool0003o000000Cooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00001_ooool00ol0003oooooooooo`03ooooo`;o00000_og9@03o`000004ooLU0?l0003okd40o`00
00Gokd400_l00006onQK00?o00001OoQL`001?l0003ohG<0on5c0?l00003omZ:0005o`000?oJRP3o
fXX0omZ:0?l000000ooCWP001ol0003odih0om>N0?oCWP3o0000olbb0?l000001Oo</P000ol0003o
aL<0o`000005olG300;o00001_nY_P02o`0000GoS;L00ol00003og:`00;o000000?oL[00o`000?mI
Z@000_mIZ@02o`0000;oFJT000Go0000od:R0?m2XP3o@Z80o`000003od:R0003o`000?l/VP3o0000
00Co;9X000?o0000oaVC0?l000001?lIT`02o`0000Go1X`00_l00005o`252@;o00000ol0OQP2o`00
0003o`1n6?l0003o07LU00;o07LU0_l000000ol0MbGo0000o`1`<002o`1`<007o`000?l0L33o070`
o`1`<?l0003o06Tio`000003o`1Y>@03o`000?l0HT7o000000Co06910_l00004o`1KA`;o00001Ol0
E4`2o`0000;o04]=0_l000000ol0Bdgo0000o`0kAP02o`0kAP05o`000?l0>dKo03]6o`000?l0;Sh0
0_l00002o`0^?P03o`000?l08SOo000001;ooooo00?o0000ooooooooool04Oooool000;ooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool5o`0000?ooooo0_l0
0003ooooo`Co00001?og9@03o`0000?okd400_l00002onm10004o`000?oXF`3oj5/0onQK00;o0000
0ooXF`001Ol0003ohG<0on5c0?oQL`3o000000CohG<000?o0000omZ:0?l000001OoJRP000ol0003o
dih0o`000005om>N00;o00001Oo</P02o`0000GoaL<000Co0000olG30?o5``3o00000onY_P02o`00
0003ojVn0?l0003oS;L000;oS;L00_l00003ohbg0003o`000?mb/03o000000CoL[0000?o0000oeVY
0?l000001OmIZ@000ol0003o@Z80o`000004od:R00;o00001Ol/VP02o`0000?o6I<00_l000000olI
T`3o0000o`J<0002o`J<00;o000000?o1X`0o`000?l0Q@T00_l0Q@T2o`0000;o08D900?o0000o`1n
6?l000001?l0OQP00ol0003o07LUo`000004o`1g9@03o`000?l0L33o000000Co070`0_l00004o`1Y
>@;o00000ol0HT42o`000003o`1R@Ol0003o05]700;o05]700?o0000o`1KAol000000ol0E4`2o`00
0004o`1DC?l0003o04]=o`0000Co04]=00?o0000o`0kA_l000000ol0>dH2o`000004o`0^?_l0003o
02hno`0^?P;o00004oooool00ol0003oooooooooo`0Aooooo`00:oooool3o`0000?ombD00_l00003
ooLU0003o`000?o_@@3o000000Gokd4000?o0000onQK0?l000001_oXF`000ol0003ohG<0o`000005
on5c00;o00001_oJRP02o`0000Godih000Co0000om>N0?oCWP3o00000oo</P001?l0003oc;80olbb
0?l00003olG30003o`000?o5``3oaL<000;oaL<000?o0000ojVn0?l000001?nY_P000ol0003oS;L0
o`000005ohbg00;o00001Omb/002o`0000KoFJT00_l00003od:R00;o000000?o@Z80o`000?l/VP00
0_l/VP02o`0000;o;9X000?o0000oaVC0?l000001?lIT`000ol0003o1X`0o`000004o`J<0003o`00
0?l0Q@Wo000000Co08D90_l00005o`1n60;o00001Ol0MbD2o`0000?o070`0_l000000ol0L33o0000
o`1Y>@02o`1Y>@06o`000?l0JCWo06Tio`000?l0HT7o00001?l0HT400ol0003o05]7o`000003o`1K
A`03o`000?l0E4co000000?o05A<0_l00005o`1;C@;o00000ol0>dH00ol0003o03]6o`000002o`0^
?P;o00005Oooool00ol0003oooooooooo`0Aooooo`00;Oooool2o`000003ooLU0?l0003ombD000Co
mbD00ol00005onm100?o00001_oXF`03o`0000?ohG<00_l00002on5c0004o`000?oJRP3ofXX0omZ:
00;o00000_oJRP001Ol0003odih0om>N0?oCWP3o000000Codih000?o0000olbb0?l000001?o</P00
0ol0003oaL<0o`000005olG300;o00001OnY_P02o`0000GoS;L000Co0000ohbg0?n<]`3o00000omb
/0001?l0003oL[00og:`0?l00003oeVY00;o00000_mIZ@000ol0003o@Z80o`000004od:R0003o`00
0?l/VP3o000000Go;9X000?o0000oaVC0?lIT`000olIT`02o`0000Go1X`00ol00003o`252@04o`00
0?l0Q@Wo08D9o`0000?o07hH00Go0000o`1n6?l0OQSo0000o`1g9@03o`0000;o07LU00?o0000o`1`
<?l000001?l0L3000ol0003o06Tio`000003o`1Y>@;o00001Ol0HT42o`0000Co05]70_l00003o`1D
C003o`000?l0E4co000000?o04]=0_l00002o`1;C@03o`000?l0>dKo000000?o03]600?o0000o`0^
?_l000005_ooool00ol0003oooooooooo`0Aooooo`00;_ooool2o`0000GombD000Go0000ooLU0?og
9@3ombD0o`000003onm10005o`000?o_@@3okd40onm10?l000000ooXF`02o`0000?oj5/000?o0000
on5c0?l000001OoQL`000ol0003ofXX0o`000005omZ:0003o`000?oCWP3o000000Godih00_l00005
olbb00?o00000oo5``02o`0000;oaL<000Go0000ojVn0?nY_P3oZKh0o`000002ojVn0005o`000?n<
]`3oS;L0ohbg0?l000001?n<]`000ol0003oL[00o`000004og:`0003o`000?mIZ@3o000000CoFJT0
0_l00005od:R00;o00001Ol/VP000ol0003o;9X0o`000003oaVC0004o`000?lIT`3o6I<0o`0000?o
1X`000Oo0000o`J<0?l6S03o1X`0o`000?l0Q@Wo000000Co08D900?o0000o`1n6?l000000ol0OQP2
o`0000Go07LU0_l00005o`1`<0;o00000ol0JCT00ol0003o06Tio`000003o`1R@@;o00000_l0HT40
1?l0003o05]7o`000?l00002o`1KA`03o`000?l0E4co000000?o05A<00?o0000o`1;COl000001?l0
Bdd2o`0000Co03]60_l000000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo017ooooo000_
ooooo`;o00000oog9@000ol0003ombD0ooLU0003ooLU0003o`000?o_@@3o000000Gokd4000?o0000
onQK0?l000001OoXF`02o`0000KohG<00_l00006omZ:00?o00000ooCWP02o`0000;odih000Go0000
olbb0?o</P3oc;80o`000003olbb0003o`000?o5``3o000000GoaL<000?o0000ojVn0?l000001?nY
_P000ol0003oS;L0o`000005ohbg00;o00001Omb/003o`0000?oFJT000Co0000oeVY0?mIZ@3o0000
0om2XP001?l0003o@Z80od:R0?l00003obbJ0007o`000?l/VP3o;9X0obbJ0?l0003o6I<0o`000004
oaVC0003o`000?l6S03o000000Co1X`00_l00005o`252@;o00000ol0OQP01?l0003o07hHo`1n6?l0
0003o`1g9@03o`000?l0MbGo000000?o070`0_l00002o`1`<003o`000?l0JCWo000000?o06Ti00?o
0000o`1R@Ol000001?l0HT42o`0000Co05]70_l00004o`1DC0;o00000ol0Bdd2o`000004o`1;COl0
003o03]6o`0kAP;o00001?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo
000`ooooo`;o000000?ombD0o`000?og9@001Oog9@02o`0000Kokd400_l00005onQK0004o`000?oX
F`3oj5/0o`0000?ohG<00_l00002on5c0004o`000?oJRP3ofXX0omZ:00;o00000ooJRP000ol0003o
dih0o`000005om>N0003o`000?o</P3o000000Goc;8000?o0000olG30?o5``001?o5``02o`0000Go
ZKh00ol00003ohbg00;o000000?oS;L0o`000?mb/0000_mb/002o`0000?oL[0000?o0000oeVY0?l0
00001?mIZ@000ol0003o@Z80o`000004od:R0003o`000?l/VP3o000000Co;9X00_l00005oaVC00;o
00000ol6S002o`000003o`J<0?l0003o08D900;o08D90_l00002o`252@03o`000?l0OQSo000000Co
07hH00?o0000o`1g9Ol000000ol0MbD00ol0003o070`o`000004o`1`<0;o00001?l0JCT2o`0000?o
06910_l000000ol0HT7o0000o`1KA`02o`1KA`05o`000?l0FdOo05]7o`000?l0E4`00_l00002o`1D
C003o`000?l0Bdgo000000Co04]=0_l00007ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool003;ooooo0_l00005ooLU0004o`000?og9@3ombD0o`0000?okd400_l00002onm1
0005o`000?oXF`3oj5/0onQK0?l000001?oXF`000ol0003ohG<0o`000005on5c0003o`000?oJRP3o
000000GofXX00_l00006om>N00;o00001Oo</P000ol0003oc;80o`000003olG300;o00000_o5``00
1Ol0003oZKh0ojVn0?nY_P3o000000?oZKh000?o0000ohbg0?l000001?n<]`000ol0003oL[00o`00
0005og:`00;o00001OmIZ@02o`0000Go@Z800_l00003obbJ00;o000000?o;9X0o`000?lIT`000_lI
T`02o`0000;o6I<000?o0000o`J<0?l000001?l6S0000ol0003o08D9o`000004o`252@;o00001Ol0
OQP2o`0000Co07LU0_l00003o`1`<0;o000000?o070`o`000?l0JCT00_l0JCT01_l0003o06Tio`1Y
>Ol0003o0691o`0000Co069100?o0000o`1KAol000000ol0FdL2o`0000Co05A<0_l00004o`1;C@;o
00002?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo000cooooo`;o0000
0oog9@000ol0003ombD0ooLU0002ooLU0003o`000?o_@@3o000000Gokd4000?o0000onQK0?l00000
1OoXF`02o`0000KohG<00ol00003omZ:00;o00000_oJRP001?l0003odih0om>N0?oCWP02o`0000;o
dih000Go0000olbb0?o</P3oc;80o`000003olbb0003o`000?o5``3o000000GoaL<000?o0000ojVn
0?l000001?nY_P02o`0000GoS;L00ol00003og:`00;o000000?oL[00o`000?mIZ@000_mIZ@02o`00
0003oeVY0?l0003o@Z8000;o@Z800_l00002od:R0003o`000?l/VP3o000000Co;9X000?o0000oaVC
0?l000001?lIT`02o`0000Go1X`00_l00003o`252@;o000000?o08D9o`000?l0OQP00_l0OQP2o`00
0003o`1n6?l0003o07LU00;o07LU00Ko0000o`1g9Ol0MbGo0000o`1`<?l00004o`1`<003o`000?l0
JCWo000000?o06Ti0_l00005o`1R@@;o00000ol0FdL00ol0003o05]7o`000003o`1DC003o`000?l0
E4co000000?o04]=00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo013ooooo000dooooo`;o000000?ombD0o`000?og9@001?og9@02o`0000Kokd400ol00003
onQK00;o00000_oXF`001?l0003ohG<0on5c0?oQL`02o`0000?ohG<000?o0000omZ:0?l000001OoJ
RP000ol0003odih0o`000005om>N0003o`000?o</P3o000000Coc;800_l00006olG300;o00000onY
_P02o`0000;oZKh000Go0000ohbg0?n<]`3oS;L0o`000003ohbg0003o`000?mb/03o000000CoL[00
00?o0000oeVY0?l000001?mIZ@000ol0003o@Z80o`000004od:R00;o00001Ol/VP03o`0000?o6I<0
00Co0000oaVC0?lIT`3o00000ol6S0001_l0003o1X`0o`J<0?l0003o08D9o`0000Co08D900?o0000
o`1n6?l000001?l0OQP00ol0003o07LUo`000003o`1g9@;o00001Ol0L302o`0000?o06Ti00?o0000
o`1Y>Ol000000ol0HT42o`0000;o069100?o0000o`1KAol000000ol0FdL00ol0003o05A<o`000003
o`1DC003o`000?l0Bdgo000000gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`00=Oooool3o`0000?ombD00_l00002ooLU0004o`000?o_@@3okd40onm100;o00000oo_@@00
0ol0003oj5/0o`000005onQK0003o`000?oQL`3o000000GohG<00_l00006omZ:00;o00001_oCWP02
o`0000?oc;800_l00002olbb0004o`000?o5``3oaL<0olG300;o00000_o5``000ol0003oZKh0o`00
0005ojVn0003o`000?n<]`3o000000CoS;L00_l00005og:`00;o00001OmIZ@03o`0000?o@Z8000Co
0000od:R0?m2XP3o00000ol/VP001ol0003o;9X0obbJ0?l/VP3o0000oaVC0?l000001?lIT`000ol0
003o1X`0o`000003o`J<00;o00001Ol0Q@T2o`0000Go07hH0_l00003o`1g9@03o`000?l0MbGo0000
00?o070`0_l00002o`1`<003o`000?l0JCWo000000?o06Ti00?o0000o`1R@Ol000001?l0HT42o`00
00Co05]70_l00004o`1DC0;o00003oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
013ooooo000fooooo`?o000000?ombD0o`000?og9@001?og9@000ol0003okd40o`000006onm100;o
00001OoXF`02o`0000GohG<000Co0000on5c0?oQL`3o00000ooJRP02o`0000;ofXX000Co0000om>N
0?oCWP3odih00_l00002om>N0003o`000?o</P3o000000Goc;8000?o0000olG30?l000001?o5``02
o`0000KoZKh00_l00003ohbg00;o00000_n<]`001Ol0003oL[00og:`0?mb/03o000000;oL[0000Go
0000oeVY0?mIZ@3oFJT0o`000003oeVY0003o`000?m2XP3o000000Co@Z8000?o0000obbJ0?l00000
1?l/VP02o`0000Go6I<00_l00003o`J<0004o`000?l6S03o1X`0o`0000?o08D900Go0000o`252Ol0
Q@Wo0000o`1n6003o`0000;o07hH00?o0000o`1g9Ol000000ol0MbD00ol0003o070`o`000004o`1`
<0;o00001?l0JCT2o`0000?o06910_l000000ol0HT7o0000o`1KA`02o`1KA`05o`000?l0FdOo05]7
o`000?l0E4`00_l0000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool0
03Sooooo0ol00005ooLU00?o00001Oo_@@001?l0003okd40onm10?l00003onQK0004o`000?oXF`3o
j5/0o`0000?ohG<000?o0000on5c0?oQL`000_oQL`000ol0003ofXX0o`000005omZ:0003o`000?oC
WP3o000000Codih00_l00006olbb00?o00000oo5``001?l0003oaL<0olG30?l00003ojVn00;o0000
0_nY_P000ol0003oS;L0o`000005ohbg0003o`000?mb/03o000000CoL[0000?o0000oeVY0?l00000
1?mIZ@02o`0000Go@Z800_l00003obbJ00;o000000?o;9X0o`000?lIT`000_lIT`02o`0000;o6I<0
00?o0000o`J<0?l000001?l6S0000ol0003o08D9o`000003o`252@;o00001Ol0OQP2o`0000Co07LU
0ol00003o`1`<003o`000?l0L33o000000?o06Ti00Ko0000o`1Y>Ol0JCWo0000o`1R@Ol00004o`1R
@@03o`000?l0FdOo000000?o05]70_l0000Dooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool04?ooool003Wooooo00?o0000ooooool000000oog9@001Ol0003ombD0ooLU0?og9@3o0000
00?okd4000?o0000onm10?o_@@000_o_@@000ol0003oj5/0o`000004onQK0003o`000?oQL`3o0000
00GohG<00_l00006omZ:00?o00000ooCWP001?l0003odih0om>N0?l00003olbb00;o00000oo</P00
0ol0003oaL<0o`000004olG30003o`000?nY_P3o000000GoZKh000?o0000ohbg0?n<]`001?n<]`02
o`0000GoL[000_l00003oeVY00;o000000?oFJT0o`000?m2XP000_m2XP02o`0000;o@Z8000?o0000
obbJ0?l000001?l/VP000ol0003o6I<0o`000004oaVC00;o00001Ol6S002o`0000?o08D900Co0000
o`252Ol0Q@Wo00000ol0OQP01Ol0003o07hHo`1n6?l0003o07LU00;o00000ol0MbD00ol0003o070`
o`000003o`1`<003o`000?l0JCWo000000?o06Ti0_l00005o`1R@@;o00000_l0FdL2o`0001Oooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`00>_ooool01Ol0003oooooo`00
0?og9@3o000000GombD000?o0000onm10?l000001Oo_@@02o`0000Goj5/00ol00004on5c0004o`00
0?oQL`3ohG<0o`0000?ofXX00_l00003omZ:0003o`000?oCWP3o000000Codih000?o0000olbb0?l0
00001Oo</P02o`0000GoaL<00_l00005ojVn0003o`000?nY_P3o000000?oS;L00_l000000on<]`3o
0000og:`0002og:`00;o00000_mb/0000ol0003oFJT0o`000004oeVY0003o`000?m2XP3o000000Co
@Z800_l00005obbJ00?o00000olIT`000ol0003o6I<0o`000003o`J<00;o00000_l6S0000ol0003o
08D9o`000004o`252@03o`000?l0OQSo000000?o07hH0_l00005o`1g9@;o00001?l0L302o`0000?o
06Ti00?o0000o`1Y>Ol000000ol0HT42o`000004o`1R@Ol0003o05]7o`0001[ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0@ooooo`00>oooool3o`0000KombD00ol00003onm100;o
00000_o_@@001Ol0003oj5/0onQK0?oXF`3o000000?oj5/00_l000000ooQL`3o0000on5c0003on5c
0003o`000?oJRP3o000000GofXX00_l00005om>N00?o00000oo</P02o`0000;oc;8000Go0000olG3
0?o5``3oaL<0o`000002olG30005o`000?nY_P3oZKh0ojVn0?l000000onY_P000ol0003oS;L0o`00
0004ohbg0003o`000?mb/03o000000CoL[000_l00005oeVY00?o00000om2XP001?l0003o@Z80od:R
0?l00003obbJ0007o`000?l/VP3o;9X0obbJ0?l0003o6I<0o`000003oaVC0003o`000?l6S03o0000
00Co1X`00_l00005o`252@;o00000ol0OQP00ol0003o07hHo`000003o`1g9@;o00000_l0MbD01?l0
003o070`o`000?l00002o`1`<003o`000?l0JCWo000000?o06Ti00?o0000o`1R@Ol000000ol0HT42
o`0001_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`00?Oooool2o`00
00?ombD00_l00003ooLU0003o`000?o_@@3o000000Gokd4000?o0000onQK0?l000001OoXF`02o`00
00GohG<00ol00003omZ:00;o00000_oJRP001Ol0003odih0om>N0?oCWP3o000000?odih000?o0000
olbb0?l000001Oo</P000ol0003oaL<0o`000004olG30003o`000?nY_P3o000000CoZKh00_l00005
ohbg00?o00000omb/0001?l0003oL[00og:`0?l00003oeVY0007o`000?mIZ@3oFJT0oeVY0?l0003o
@Z80o`000004od:R0003o`000?l/VP3o000000Co;9X00_l00004oaVC00?o00000ol6S0000ol0003o
1X`0o`000003o`252@;o00000_l0Q@T00ol0003o07hHo`000003o`1n6003o`000?l0MbGo000000Co
07LU0_l00004o`1`<0;o00001?l0JCT2o`0000?o069100?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00oooooo000nooooo`;o000000?ombD0o`000?og9@00
1?og9@02o`0000Kokd400ol00003onQK00;o00000_oXF`001Ol0003ohG<0on5c0?oQL`3o000000?o
hG<000?o0000omZ:0?l000001OoJRP000ol0003odih0o`000005om>N0003o`000?o</P3oc;8000Co
c;800_l00005olG300?o00000onY_P001?l0003oZKh0ojVn0?l00003ohbg0007o`000?n<]`3oS;L0
ohbg0?l0003oL[00o`000004og:`0003o`000?mIZ@3o000000CoFJT00_l00005od:R00;o00000ol/
VP02o`000003obbJ0?l0003o6I<000;o6I<000Oo0000oaVC0?lIT`3o6I<0o`000?l6S03o000000?o
1X`000?o0000o`252Ol000001?l0Q@T2o`0000Co07hH0_l00003o`1g9@;o000000?o07LUo`000?l0
L3000_l0L3001Ol0003o070`o`1`<?l0003o06Ti00;o00000_l0JCT00ol0003o0691o`00000Poooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool003oooooo0ol00003ooLU00;o
00000_og9@001?l0003okd40onm10?o_@@02o`0000?okd4000?o0000onQK0?l000001OoXF`000ol0
003ohG<0o`000005on5c0003o`000?oJRP3ofXX000CofXX00_l00005om>N0003o`000?oCWP3o0000
00?oc;800_l000000oo</P3o0000olG30002olG300;o00000oo5``000ol0003oZKh0o`000004ojVn
0003o`000?n<]`3o000000CoS;L00_l00005og:`00;o00000omIZ@02o`000003oeVY0?l0003o@Z80
00;o@Z800_l00002od:R0003o`000?l/VP3o000000Co;9X000?o0000oaVC0?l000001?lIT`02o`00
00Co1X`00_l00003o`252@;o000000?o08D9o`000?l0OQP00_l0OQP01_l0003o07hHo`1n6?l0003o
07LUo`0000Co07LU00?o0000o`1`<?l000000ol0L302o`0000Co06Ti0_l0000Qooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03oooool0043ooooo0ol000000oog9@3o0000ooLU0004
ooLU0003o`000?o_@@3o000000Gokd400_l00006onQK00;o00001OoQL`000ol0003ohG<0o`000003
omZ:00;o00000_oJRP001Ol0003odih0om>N0?oCWP3o000000?odih000?o0000olbb0?l000001?o<
/P000ol0003oaL<0o`000005olG300;o00001OnY_P02o`0000?oS;L00_l000000on<]`3o0000og:`
0002og:`00;o00000_mb/0000ol0003oFJT0o`000004oeVY0003o`000?m2XP3o000000Co@Z800_l0
0005obbJ00;o00000olIT`02o`000003oaVC0?l0003o1X`000;o1X`000Ko0000o`J<0?l6S03o0000
o`252Ol00004o`252@03o`000?l0OQSo000000?o07hH0_l00005o`1g9@;o00000ol0L3000ol0003o
070`o`000003o`1Y>@03o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0?ooooo`00@_ooool3o`0000GombD00_l00005onm10004o`000?o_@@3okd40o`0000?o
j5/00_l00002onQK0005o`000?oQL`3ohG<0on5c0?l000000ooQL`000ol0003ofXX0o`000005omZ:
0003o`000?oCWP3o000000Codih00_l00005olbb00?o00000oo5``02o`000003olG30?l0003oZKh0
00;oZKh00_l00002ojVn0003o`000?n<]`3o000000CoS;L000?o0000og:`0?l000001?mb/002o`00
00GoFJT00ol00003od:R0003o`000?m2XP3o000000?o;9X00_l00002obbJ0003o`000?lIT`3o0000
00Co6I<000?o0000o`J<0?l000000ol6S002o`0000Go08D90_l00003o`1n6003o`000?l0OQSo0000
00?o07LU0_l00002o`1g9@03o`000?l0L33o000000?o070`00?o0000o`1Y>Ol000009_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo0013ooooo`03o`000?oooooo000000?o
mbD000Co0000ooLU0?og9@3o00000oo_@@000ol0003okd40onm10002onm10003o`000?oXF`3o0000
00Goj5/000?o0000on5c0?l000001?oQL`02o`0000KofXX00ol00003om>N0004o`000?oCWP3odih0
o`0000?oc;8000Oo0000olbb0?o</P3oc;80o`000?o5``3o000000CoaL<000?o0000ojVn0?l00000
1?nY_P02o`0000GoS;L00ol00003og:`0004o`000?mb/03oL[00o`0000?oFJT000Oo0000oeVY0?mI
Z@3oFJT0o`000?m2XP3o000000?o@Z8000?o0000obbJ0?l000001?l/VP02o`0000Go6I<00_l00003
o`J<0003o`000?l6S03o000000?o08D90_l00002o`252@03o`000?l0OQSo000000?o07hH00?o0000
o`1g9Ol000001?l0MbD2o`0000Co070`0_l0000Xooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool03oooool004Cooooo00Go0000ooooool0003ombD0o`000004ooLU0003o`000?o_@@3o
000000Gokd400_l00006onQK00?o00000ooQL`001?l0003ohG<0on5c0?l00003omZ:00;o00000ooJ
RP000ol0003odih0o`000004om>N0003o`000?o</P3o000000Coc;800_l00005olG300?o00000onY
_P001?l0003oZKh0ojVn0?l00003ohbg0007o`000?n<]`3oS;L0ohbg0?l0003oL[00o`000004og:`
0003o`000?mIZ@3o000000CoFJT00_l00004od:R00?o00000ol/VP000ol0003o;9X0o`000003oaVC
00;o00000_lIT`000ol0003o1X`0o`000003o`J<0003o`000?l0Q@Wo000000Co08D90_l00004o`1n
60;o00000ol0MbD2o`000003o`1g9Ol0003o070`00;o070`00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo0015ooooo`03o`000?oooooo000000Go
mbD00ol00004onm10004o`000?o_@@3okd40o`0000?oj5/00_l00003onQK0003o`000?oQL`3o0000
00CohG<000?o0000omZ:0?l000001OoJRP02o`0000Godih00ol00003olbb0004o`000?o</P3oc;80
o`0000?oaL<000Oo0000olG30?o5``3oaL<0o`000?nY_P3o000000CoZKh000?o0000ohbg0?l00000
1?n<]`02o`0000GoL[000_l00003oeVY00;o000000?oFJT0o`000?m2XP000_m2XP001ol0003o@Z80
od:R0?m2XP3o0000obbJ0?l000000ol/VP000ol0003o6I<0o`000004oaVC00;o00001?l6S003o`00
00?o08D900Go0000o`252Ol0Q@Wo0000o`1n6002o`0000;o07hH00?o0000o`1g9Ol000001?l0MbD0
0ol0003o070`o`00000/ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool0
04Kooooo0ol00003ooLU0004o`000?og9@3ombD0ooLU00;o000000?okd40o`000?o_@@000oo_@@00
0ol0003oj5/0o`000005onQK00;o00001OoQL`03o`0000?ofXX00_l000000ooJRP3o0000om>N0002
om>N00;o00000ooCWP000ol0003oc;80o`000004olbb0003o`000?o5``3o000000CoaL<00_l00005
ojVn00?o00000on<]`001Ol0003oS;L0ohbg0?l0003oL[0000?o00000_mb/0000ol0003oFJT0o`00
0004oeVY0003o`000?m2XP3o000000Co@Z800_l00004obbJ00?o00000olIT`001Ol0003o6I<0oaVC
0?l0003o1X`000;o00000ol6S0000ol0003o08D9o`000003o`252@;o00001?l0OQP2o`0000Go07LU
0_l0000^ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool004Sooooo0_l0
00000oog9@3o0000ooLU0004ooLU00;o00001Oo_@@03o`0000?oj5/00_l00002onQK0005o`000?oQ
L`3ohG<0on5c0?l000000ooQL`000ol0003ofXX0o`000004omZ:0003o`000?oCWP3o000000Godih0
0_l00005olbb00?o00000oo5``001?l0003oaL<0olG30?l00003ojVn0007o`000?nY_P3oZKh0ojVn
0?l0003oS;L0o`000003ohbg00;o00001Omb/003o`0000CoFJT00_l00003od:R00;o00000_m2XP00
1?l0003o;9X0o`000?l00003obbJ0003o`000?lIT`3o000000?o6I<00_l00005o`J<00;o00000ol0
Q@T00ol0003o08D9o`000003o`1n6005o`000?l0OQSo07hHo`000?l0MbD00ol0000aooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool03_ooool004Wooooo0ol00003ooLU00;o00000_og
9@001Ol0003okd40onm10?o_@@3o000000?okd4000?o0000onQK0?l000001OoXF`000ol0003ohG<0
o`000004on5c00;o00001OoJRP03o`0000?odih00_l000000ooCWP3o0000olbb0002olbb00;o0000
0oo</P000ol0003oaL<0o`000004olG30003o`000?nY_P3o000000CoZKh00_l00003ohbg0004o`00
0?n<]`3oS;L0o`0000?oL[0000Ko0000og:`0?mb/03oL[00o`000?mIZ@02o`0000;oFJT000?o0000
od:R0?l000001?m2XP02o`0000Go;9X00_l00003oaVC0003o`000?lIT`3o000000?o1X`00_l00002
o`J<0003o`000?l0Q@Wo000000?o08D900?o0000o`1n6?l000000ol0OQP2o`0003Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`00B_ooool01Ol0003oooooo`000?og9@3o
000000GombD000?o0000onm10?l000001?o_@@02o`0000Koj5/00ol00003on5c0004o`000?oQL`3o
hG<0o`0000?ofXX000Oo0000omZ:0?oJRP3ofXX0o`000?oCWP3o000000Codih000?o0000olbb0?l0
00001Oo</P02o`0000GoaL<00_l00003ojVn00;o00000_nY_P000ol0003oS;L0o`000004ohbg0003
o`000?mb/03o000000CoL[000_l00004oeVY00?o00000om2XP000ol0003o@Z80o`000003obbJ00;o
00000_l/VP000ol0003o6I<0o`000003oaVC0003o`000?l6S03o000000Co1X`00_l00004o`252@;o
00000ol0OQP00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03_ooool004_ooooo0ol00006ooLU00?o00000oo_@@001?l0003okd40onm10?l00003onQK00;o
00000ooXF`000ol0003ohG<0o`000004on5c0003o`000?oJRP3o000000CofXX00_l00005om>N00?o
00000oo</P02o`0000;oc;8000?o0000olG30?l000000_l00002olG30003o`000?nY_P3o000000Co
ZKh00_l00005ohbg00;o00000omb/002o`000003og:`0?l0003oFJT000;oFJT000Oo0000oeVY0?mI
Z@3oFJT0o`000?m2XP3o000000?o@Z8000?o0000obbJ0?l000001?l/VP02o`0000Co6I<00_l00003
o`J<00;o000000?o1X`0o`000?l0Q@T00_l0Q@T01_l0003o08D9o`252Ol0003o07hHo`0003Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`00COooool2o`0000?ombD00_l0
0003ooLU0003o`000?o_@@3o000000Cokd4000?o0000onQK0?l000001OoXF`02o`0000GohG<00ol0
0003omZ:0004o`000?oJRP3ofXX0o`0000?odih000Oo0000om>N0?oCWP3odih0o`000?o</P3o0000
00Coc;800_l00005olG300?o00000onY_P001?l0003oZKh0ojVn0?l00003ohbg0006o`000?n<]`3o
S;L0o`000?mb/03o00001?mb/0000ol0003oFJT0o`000004oeVY00;o00001?m2XP03o`0000?o;9X0
00?o0000obbJ0?l000000olIT`001_l0003o6I<0oaVC0?l0003o1X`0o`0000Co1X`000?o0000o`25
2Ol000000ol0Q@T2o`0003_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>oooo
o`00C_ooool2o`000003ooLU0?l0003ombD000CombD00_l00005onm100?o00000ooXF`02o`000003
onQK0?l0003ohG<000;ohG<00_l00003on5c0003o`000?oJRP3o000000CofXX000?o0000om>N0?l0
00001?oCWP03o`0000?oc;8000Co0000olbb0?o</P3o00000oo5``001ol0003oaL<0olG30?o5``3o
0000ojVn0?l000001?nY_P000ol0003oS;L0o`000003ohbg00;o00001Omb/002o`0000?oFJT00_l0
00000omIZ@3o0000od:R0002od:R0007o`000?m2XP3o@Z80od:R0?l0003o;9X0o`000003obbJ0003
o`000?lIT`3o000000?o6I<00ol00004o`J<00;o00000ol0Q@T00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool004oooooo0ol00003ooLU00;o0000
0_og9@001Ol0003okd40onm10?o_@@3o000000?okd4000?o0000onQK0?l000001?oXF`000ol0003o
hG<0o`000005on5c00;o00001OoJRP03o`0000?odih000Oo0000om>N0?oCWP3odih0o`000?o</P3o
000000Coc;8000?o0000olG30?l000001?o5``02o`0000GoZKh00_l00003ohbg0004o`000?n<]`3o
S;L0o`0000?oL[0000Ko0000og:`0?mb/03o0000oeVY0?l00004oeVY0003o`000?m2XP3o000000Co
@Z800_l00004obbJ00;o00000olIT`001_l0003o6I<0oaVC0?lIT`3o0000o`J<00;o00000_l6S000
0ol0003o08D9o`00000oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool0
053ooooo0ol000000oog9@3o0000ooLU0004ooLU0003o`000?o_@@3o000000Cokd400_l00005onQK
00?o00000ooQL`02o`0000;ohG<000?o0000omZ:0?l000000_l00003omZ:0003o`000?oCWP3o0000
00Codih00_l00005olbb00;o00000oo5``02o`000003olG30?l0003oZKh000;oZKh00_l00002ojVn
0003o`000?n<]`3o000000CoS;L000?o0000og:`0?l000000omb/003o`0000CoFJT00_l00003od:R
00;o00000_m2XP001?l0003o;9X0o`000?l00002obbJ0003o`000?lIT`3o000000Co6I<00_l00004
o`J<00;o0000@Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo001Boooo
o`;o00001_og9@03o`0000?okd4000Co0000onm10?o_@@3o00000ooXF`001ol0003oj5/0onQK0?oX
F`3o0000on5c0?l000001?oQL`02o`0000KofXX00_l00003om>N00;o000000?odih0o`000?o</P00
0_o</P02o`0000;oc;8000?o0000olG30?l000001?o5``000ol0003oZKh0o`000004ojVn00;o0000
1On<]`02o`0000?oL[0000Ko0000og:`0?mb/03oL[00o`000?mIZ@02o`0000;oFJT000?o0000od:R
0?l000001?m2XP02o`0000Co;9X00_l00003oaVC00;o000000?o6I<0o`000?l6S0000_l6S0000ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool005?o
oooo0_l00003ooLU00;o00000oog9@000ol0003okd40o`000004onm10003o`000?oXF`3o000000Co
j5/00ol00003on5c0004o`000?oQL`3ohG<0o`0000?ofXX00_l00002omZ:0003o`000?oCWP3o0000
00Codih000?o0000olbb0?l000001?o</P02o`0000GoaL<00ol00003ojVn0005o`000?nY_P3oZKh0
o`000?n<]`000ol00002ohbg0003o`000?mb/03o000000CoL[000_l00004oeVY00;o00000om2XP02
o`000003od:R0?l0003o;9X000;o;9X000Ko0000obbJ0?l/VP3o0000oaVC0?l00004oaVC0003o`00
0?l6S03o000004Gooooo00Go0000ooooooooooooooooo`00000?ooooo`00E?ooool2o`000003ooLU
0?l0003ombD000CombD00_l00005onm100?o00000ooXF`001ol0003oj5/0onQK0?oXF`3o0000on5c
0?l000001?oQL`000ol0003ofXX0o`000004omZ:00;o00001OoCWP03o`0000?oc;8000Co0000olbb
0?o</P3o00000oo5``001ol0003oaL<0olG30?o5``3o0000ojVn0?l000000onY_P02o`0000GoS;L0
0_l00003og:`00;o000000?oL[00o`000?mIZ@000_mIZ@001_l0003oFJT0oeVY0?l0003o@Z80o`00
00Co@Z8000?o0000obbJ0?l000000ol/VP02o`0000Go6I<00_l00017ooooo`04o`000?oooooooooo
o`0000oooooo001Eooooo`?o00000oog9@02o`0000;ombD000Go0000onm10?o_@@3okd40o`000003
onm10003o`000?oXF`3o000000Coj5/00_l00005on5c00?o00000ooJRP001?l0003ofXX0omZ:0?l0
0003om>N0007o`000?oCWP3odih0om>N0?l0003oc;80o`000004olbb0003o`000?o5``3o000000Co
aL<00_l00003ojVn0004o`000?nY_P3oZKh0o`0000?oS;L000Ko0000ohbg0?n<]`3o0000og:`0?l0
0004og:`0003o`000?mIZ@3o000000?oFJT00ol00004od:R00;o00000ol/VP001Ol0003o;9X0obbJ
0?l0003o6I<000?o0000B_ooool00ol0003oooooo`00000?ooooo`00E_ooool3o`000003ooLU0?l0
003ombD000CombD000?o0000onm10?l000001?o_@@03o`0000?oj5/000Co0000onQK0?oXF`3o0000
0ooQL`001ol0003ohG<0on5c0?oQL`3o0000omZ:0?l000001?oJRP000ol0003odih0o`000004om>N
00;o00001Oo</P02o`0000?oaL<00_l00002olG30003o`000?nY_P3o000000CoZKh000?o0000ohbg
0?l000000on<]`03o`0000CoL[000_l00003oeVY0006o`000?mIZ@3oFJT0oeVY0?l0003o@Z800_l0
0002od:R0003o`000?l/VP3o000000?o;9X00_l0001=ooooo`04o`000?ooooooooooo`0000kooooo
001Hooooo`;o00001_og9@02o`0000?okd400_l00003onm10003o`000?oXF`3o000000Coj5/000?o
0000on5c0?l000001?oQL`02o`0000GofXX00ol00003om>N0005o`000?oCWP3odih0o`000?o</P00
0ol00002olbb0003o`000?o5``3o000000CoaL<00_l00005ojVn00;o00000on<]`001_l0003oS;L0
ohbg0?n<]`3o0000og:`00;o00000_mb/0000ol0003oFJT0o`000004oeVY00;o00001?m2XP02o`00
00?o;9X000?o0000ooooooooool0C_ooool00ol0003oooooo`00000>ooooo`00FOooool2o`0000?o
mbD00_l00002ooLU0003o`000?o_@@3o000000Gokd400_l00005onQK00?o00000ooQL`001?l0003o
hG<0on5c0?l00003omZ:0007o`000?oJRP3ofXX0omZ:0?l0003odih0o`000003om>N00;o00001Oo<
/P03o`0000?oaL<000?o0000olG30?l000000onY_P02o`0000;oZKh000?o0000ohbg0?l000001?n<
]`02o`0000CoL[000_l00003oeVY00;o000000?oFJT0o`000?m2XP000_m2XP001_l0003o@Z80od:R
0?l0003o;9X0o`0005;ooooo0_l0000>ooooo`00F_ooool2o`000003ooLU0?l0003ombD000?ombD0
0ol00003onm100;o000000?okd40o`000?oXF`000_oXF`02o`0000?oj5/000?o0000on5c0?l00000
1?oQL`000ol0003ofXX0o`000004omZ:00;o00000ooCWP001?l0003odih0om>N0?l00003olbb0007
o`000?o</P3oc;80olbb0?l0003oaL<0o`000003olG30003o`000?nY_P3o000000CoZKh00_l00003
ohbg00;o000000?oS;L0o`000?mb/0000_mb/0001_l0003oL[00og:`0?l0003oFJT0o`0000CoFJT0
00?o0000od:R0?l000000om2XP02o`0005;ooooo0ol0000>ooooo`00Foooool3o`0000?ombD000Oo
0000ooLU0?og9@3ombD0o`000?o_@@3o000000Cokd4000?o0000onQK0?l000001OoXF`02o`0000Go
hG<00_l00003omZ:00;o00000_oJRP000ol0003odih0o`000004om>N0003o`000?o</P3o000000Co
c;800_l00004olG300?o00000onY_P001_l0003oZKh0ojVn0?l0003oS;L0o`0000CoS;L000?o0000
og:`0?l000000omb/003o`0000CoFJT00_l00003od:R0003o`000?oooooooooo04kooooo1?l0000A
ooooo`00GOooool2o`000003ooLU0?l0003ombD000?ombD00_l00005onm100?o00000ooXF`02o`00
00;oj5/000?o0000on5c0?l000000_l00002on5c0003o`000?oJRP3o000000CofXX00_l00005om>N
00;o00000oo</P02o`0000;oc;8000Co0000olG30?l0003o00000oo5``000ol0003oZKh0o`000003
ojVn00?o00001?n<]`02o`0000?oL[0000Ko0000og:`0?mb/03oL[00o`000?mIZ@02o`0000;oFJT0
00?o0000od:R0?l00000COooool4o`0001Gooooo001Nooooo`?o00000oog9@001?l0003ombD0ooLU
0?l00003onm10007o`000?o_@@3okd40onm10?l0003oj5/0o`000004onQK00;o00001OoQL`03o`00
00?ofXX000Co0000omZ:0?oJRP3o00000ooCWP001_l0003odih0om>N0?l0003oc;80o`0000Coc;80
0_l00005olG300;o00000onY_P001_l0003oZKh0ojVn0?nY_P3o0000ohbg00;o00000_n<]`000ol0
003oL[00o`000004og:`00;o00001?mIZ@02o`0004[ooooo1?l0000Iooooo`00Goooool01Ol0003o
ooooo`000?og9@3o000000CombD000?o0000onm10?l000001?o_@@03o`0000?oj5/000Co0000onQK
0?oXF`3o00000ooQL`001ol0003ohG<0on5c0?oQL`3o0000omZ:0?l000001?oJRP000ol0003odih0
o`000003om>N00?o00000oo</P001?l0003oc;80olbb0?l00003olG30006o`000?o5``3oaL<0o`00
0?nY_P3o00001?nY_P02o`0000CoS;L00_l00003og:`00;o00000_mb/0001?l0003oFJT0o`000?l0
0019ooooo`?o00007Oooool0063ooooo00?o0000ooooool000001Oog9@03o`0000?okd4000Oo0000
onm10?o_@@3okd40o`000?oXF`3o000000Coj5/000?o0000on5c0?l000001?oQL`02o`0000GofXX0
0_l00003om>N0007o`000?oCWP3odih0om>N0?l0003oc;80o`000004olbb0003o`000?o5``3o0000
00?oaL<00ol00003ojVn0003o`000?nY_P3o000000?oS;L000Ko0000ohbg0?n<]`3o0000og:`0?l0
0004og:`00;o0000Aoooool4o`00023ooooo001Qooooo`?o00000oog9@001ol0003ombD0ooLU0?og
9@3o0000onm10?l000001?o_@@02o`0000Goj5/00ol00003on5c0005o`000?oQL`3ohG<0o`000?oJ
RP000ol00002omZ:0003o`000?oCWP3o000000Codih00_l00005olbb00;o00000oo5``001ol0003o
aL<0olG30?o5``3o0000ojVn0?l000000onY_P000ol0003oS;L0o`000003ohbg00?o00000omb/000
0ol0003oooooooooo`13ooooo`Co00009?ooool006?ooooo0_l000000oog9@3o0000ooLU0003ooLU
00?o00000oo_@@001?l0003okd40onm10?l00003onQK0007o`000?oXF`3oj5/0onQK0?l0003ohG<0
o`000003on5c00;o00001OoJRP03o`0000?odih000Go0000om>N0?oCWP3o0000olbb0003o`0000;o
c;8000?o0000olG30?l000001?o5``02o`0000CoZKh00_l00003ohbg0007o`000?n<]`3oS;L0ohbg
0?l0003oL[00o`000012ooooo`Co0000:?ooool006Cooooo0ol00003ooLU0007o`000?og9@3ombD0
ooLU0?l0003okd40o`000004onm10003o`000?oXF`3o000000Coj5/00_l00003on5c0004o`000?oQ
L`3ohG<0o`0000?ofXX000Oo0000omZ:0?oJRP3ofXX0o`000?oCWP3o000000?odih00_l00005olbb
00;o00000oo5``02o`0000;oaL<000Co0000ojVn0?l0003o00000_nY_P000ol0003oS;L0o`000004
ohbg00;o0000?oooool4o`0002cooooo001Uooooo`05o`000?oooooo0000ooLU0?l000001?og9@02
o`0000Gokd400_l00003onQK00;o00000_oXF`000ol0003ohG<0o`000004on5c0003o`000?oJRP3o
000000CofXX00_l00003om>N0004o`000?oCWP3odih0o`0000?oc;8000Ko0000olbb0?o</P3o0000
olG30?l00004olG300;o00001?nY_P02o`0000?oS;L00_l0000mooooo`Co0000<?ooool006Kooooo
0ol00003ooLU00;o00000_og9@000ol0003okd40o`000002o`0000;okd4000?o0000onQK0?l00000
1?oXF`03o`0000CohG<00_l00003omZ:00;o00000_oJRP000ol0003odih0o`000004om>N0003o`00
0?o</P3o000000?oc;800ol00003olG30005o`000?o5``3oaL<0o`000?nY_P000_l00002ojVn0003
o`000?n<]`3o000003_ooooo1?l0000dooooo`00J?ooool2o`000003ooLU0?l0003ombD000?ombD0
0_l00005onm100?o00000ooXF`001_l0003oj5/0onQK0?oXF`3o0000on5c00;o00000_oQL`000ol0
003ofXX0o`000004omZ:00?o00001?oCWP02o`0000?oc;8000Oo0000olbb0?o</P3oc;80o`000?o5
``3o000000?oaL<00_l00004ojVn00;o0000>Oooool3o`0003Sooooo001Yooooo`?o00000oog9@00
1?l0003ombD0ooLU0?l00003onm10007o`000?o_@@3okd40onm10?l0003oj5/0o`000004onQK00;o
00001?oQL`03o`0000?ofXX000Ko0000omZ:0?oJRP3ofXX0o`000?oCWP02o`0000;odih000?o0000
olbb0?l000001?o</P02o`0000?oaL<000?o0000olG30?l000000onY_P000ol0003oooooooooo`0e
ooooo`Co0000>oooool006[ooooo00Go0000ooooool0003ombD0o`000004ooLU0003o`000?o_@@3o
000000Cokd400_l00003onQK00;o000000?oj5/0o`000?oQL`000_oQL`001ol0003ohG<0on5c0?oQ
L`3o0000omZ:0?l000001?oJRP02o`0000Codih00_l00003olbb00;o00000_o</P000ol0003oaL<0
o`000003olG30003o`000?nY_P3o000003Cooooo1?l0000oooooo`00Joooool4o`0000CombD00ol0
0003onm10006o`000?o_@@3okd40o`000?oXF`3o00001?oXF`000ol0003ohG<0o`000004on5c00;o
00000ooJRP02o`0000;ofXX000Co0000om>N0?l0003o00000_oCWP000ol0003oc;80o`000004olbb
00;o00001?o5``02o`00037ooooo1?l00013ooooo`00KOooool01?l0003oooooo`000?og9@02o`00
00?ombD000?o0000onm10?l000000oo_@@03o`0000Coj5/00ol00003on5c0006o`000?oQL`3ohG<0
o`000?oJRP3o00001?oJRP02o`0000Codih00ol00003olbb0005o`000?o</P3oc;80o`000?o5``00
0_l0000_ooooo`Co0000Aoooool006kooooo00?o0000ooooool000001Oog9@02o`0000?okd4000Ko
0000onm10?o_@@3okd40o`000?oXF`02o`0000?oj5/000?o0000on5c0?l000000ooQL`03o`0000?o
fXX000?o0000omZ:0?l000000ooCWP001ol0003odih0om>N0?oCWP3o0000olbb0?l000000oo</P02
o`0002gooooo1?l0001;ooooo`00Koooool2o`0000?ombD00_l00002ooLU0003o`000?o_@@3o0000
00Cokd400_l00005onQK00;o00000ooQL`001ol0003ohG<0on5c0?oQL`3o0000omZ:0?l000000ooJ
RP000ol0003odih0o`000004om>N00;o00000oo</P000ol0003oooooooooo`0Yooooo`Co0000Cooo
ool0073ooooo0_l000000oog9@3o0000ooLU0003ooLU00?o00000oo_@@001Ol0003okd40onm10?l0
003oj5/000?o00000_oXF`000ol0003ohG<0o`000004on5c00;o00001?oJRP03o`0000?odih000Ko
0000om>N0?oCWP3o0000olbb0?l0000Yooooo`?o0000Doooool0077ooooo0ol00003ooLU0007o`00
0?og9@3ombD0ooLU0?l0003okd40o`000003onm100;o00001OoXF`03o`0000?ohG<000Go0000on5c
0?oQL`3o0000omZ:0002o`0000?ofXX000?o0000om>N0?l000000ooCWP02o`0002Kooooo1?l0001F
ooooo`00Loooool2o`000003ooLU0?l0003ombD000?ombD00_l00003onm10004o`000?o_@@3okd40
o`0000?oj5/000Oo0000onQK0?oXF`3oj5/0o`000?oQL`3o000000?ohG<00_l00005omZ:00;o0000
0ooCWP000ol0003oooooooooo`0Rooooo`Co0000F_ooool007Cooooo0ol00003ooLU0006o`000?og
9@3ombD0o`000?o_@@3o00001?o_@@000ol0003oj5/0o`000004onQK00;o00000ooQL`001Ol0003o
hG<0on5c0?l0003ofXX000?o00000_oJRP000ol0003odih0o`00000Qooooo`Co0000G_ooool007Go
oooo00Go0000ooooool0003ombD0o`000003ooLU00?o00001?o_@@02o`0000?oj5/00_l00002onQK
0003o`000?oQL`3o000000?ohG<00ol00004omZ:00;o00007_ooool4o`0006;ooooo001fooooo`?o
00000oog9@001_l0003ombD0ooLU0?og9@3o0000onm100;o00000_o_@@000ol0003oj5/0o`000004
onQK00;o00000ooQL`001_l0003ohG<0on5c0?oQL`3o0000omZ:00;o00007?ooool4o`0006Kooooo
001hooooo`;o000000?ombD0o`000?og9@000oog9@02o`0000Cokd400ol00003onQK0006o`000?oX
F`3oj5/0o`000?oQL`3o00001?oQL`02o`0001[ooooo1?l0001Zooooo`00NOooool3o`0000?ombD0
00Go0000ooLU0?og9@3o0000onm10002o`0000?okd4000?o0000onQK0?l000000ooXF`03o`0000?o
hG<000?o0000ooooooooool05oooool3o`0006kooooo001jooooo`05o`000?oooooo0000ooLU0?l0
00000oog9@03o`0000Cokd400_l00003onQK0007o`000?oXF`3oj5/0onQK0?l0003ohG<0o`00000F
ooooo`Co0000LOooool007_ooooo0ol00003ooLU0006o`000?og9@3ombD0ooLU0?l0003okd400_l0
0002onm10003o`000?oXF`3o000000Coj5/00_l0000Cooooo`Co0000MOooool007gooooo0_l00000
0oog9@3o0000ooLU0003ooLU00;o00001?o_@@03o`0000?oj5/000?o0000ooooooooool03oooool4
o`0007Wooooo001nooooo`?o00000oog9@001Ol0003ombD0ooLU0?l0003okd4000;o00000oo_@@00
0ol0003oj5/0o`00000>ooooo`Co0000OOooool007oooooo00Go0000ooooool0003ombD0o`000003
ooLU00?o00001?o_@@02o`0000_ooooo1?l00021ooooo`00P?ooool00ol0003oooooo`000003ooLU
0006o`000?og9@3ombD0ooLU0?l0003okd400_l00009ooooo`Co0000QOooool0087ooooo0ol00000
0oog9@3o0000ooLU0003ooLU00;o00002?ooool3o`0008Wooooo0023ooooo`;o00000oog9@02o`00
00Kooooo1?l0002<ooooo`00Q?ooool2o`000003ooLU0?l0003ooooo00?ooooo1?l0002@ooooo`00
QOooool2o`000003ooooool0003o000000;o0000U?ooool008Kooooo0_l0002Hooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00;oooool3o`0005Sooooo0ol0000Gooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool03oooool0033ooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool03_oo
ool002[ooooo0ol00003ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000oooool4
o`000003ooooool0003o000000?o00001oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6
o`0000Kooooo1Ol00002ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`Co00000ooo
ool2o`0000;ooooo1_l00007ooooo`03o`000?oooooooooo00?ooooo1?l000000ooooooo0000o`00
0002o`0000;ooooo1?l00003ooooo`?o00000_ooool5o`0000?ooooo0_l000001?oooooo0000oooo
ooooool2o`0000?ooooo0ol00009ooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000
o`000002o`0000Cooooo0_l00003ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`000004
ooooool0003o0000o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00gooooo000Yooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Sooooo00Ko0000oooooooooooo0000ooooool00006ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003ooooo`05o`000?oooooooooooooo
ool000001?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
2oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooo`000003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool03Oooool0
02Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00Co0000oooooooooooo
00000_ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go00001oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oo
oooooooo00?ooooo0ol00003ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5o`0000Co
oooo00?o0000ooooooooool03Oooool002Wooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool0
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Yooooo`06o`00
0?ooooooooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol00003oooo
o`;o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003
ooooo`Co00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool3o`0000;ooooo1?l00003
ooooo`Wo00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol00003
ooooo`Co00000_ooool3o`0000Cooooo00Co0000oooooooooooooooo0_l000001?oooooo0000o`00
0?ooool4o`0000?ooooo0ol00009ooooo`?o00000_ooool3o`0000Cooooo1?l000000ooooooo0000
o`000002o`0000?ooooo0_l00003ooooo`Co00000oooool3o`0000?ooooo0ol00005ooooo`03o`00
0?oooooooooo00gooooo000Yooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03_ooool002[ooooo
0ol00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool3o`0000Wooooo
1?l00009ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`?o00005_ooool00ol0003ooooo
ooooo`02ooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`;o00004?ooool3o`0000[ooooo
00?o0000ooooooooool04?ooool2o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00oooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.180925, -0.0307374, \
0.00414977, 0.00414977}},
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .80819 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00131954 1.04772 -0.0720652 1.04772 [
[.5 .82069 -60 0 ]
[.5 .82069 60 9 ]
[.02856 .24287 -24 -8.71076 ]
[.02856 .24287 0 .28924 ]
[.17652 .18612 -23.5898 -9 ]
[.17652 .18612 .41022 0 ]
[.3355 .12129 -22.319 -9 ]
[.3355 .12129 1.68101 0 ]
[.5025 .05719 -21.0831 -9 ]
[.5025 .05719 2.91692 0 ]
[.68155 -0.01096 -19.8391 -9 ]
[.68155 -0.01096 4.1609 0 ]
[.7009 -0.00478 0 -6.26324 ]
[.7009 -0.00478 24 2.73676 ]
[.78177 .11679 0 -6.14316 ]
[.78177 .11679 24 2.85684 ]
[.85585 .23084 0 -6.034 ]
[.85585 .23084 6 2.966 ]
[.92174 .3327 0 -5.93891 ]
[.92174 .3327 18 3.06109 ]
[.98004 .42456 0 -5.85522 ]
[.98004 .42456 18 3.14478 ]
[.01659 .31269 -42 -2.78135 ]
[.01659 .31269 0 6.21865 ]
[.00688 .37604 -42 -2.83538 ]
[.00688 .37604 0 6.16462 ]
[-0.0045 .44837 -42 -2.89722 ]
[-0.0045 .44837 0 6.10278 ]
[ 0 0 0 0 ]
[ 1 .80819 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82069 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03812 .25182 m
.68871 0 L
s
.03812 .25182 m
.04291 .25629 L
s
[(-0.5)] .02856 .24287 1 .93573 Mshowa
.18562 .19554 m
.19017 .20025 L
s
[(-0.4)] .17652 .18612 .96582 1 Mshowa
.34404 .13122 m
.34831 .13619 L
s
[(-0.3)] .3355 .12129 .85992 1 Mshowa
.5104 .06763 m
.51435 .07285 L
s
[(-0.2)] .5025 .05719 .75692 1 Mshowa
.68871 0 m
.69229 .00548 L
s
[(-0.1)] .68155 -0.01096 .65326 1 Mshowa
.125 Mabswid
.06665 .24348 m
.06949 .24619 L
s
.09566 .23083 m
.09848 .23357 L
s
.12605 .2173 m
.12883 .22007 L
s
.15584 .20934 m
.1586 .21213 L
s
.21747 .18224 m
.22017 .18509 L
s
.24792 .16814 m
.25058 .17103 L
s
.27934 .15962 m
.28197 .16253 L
s
.31046 .14524 m
.31306 .14819 L
s
.37588 .12176 m
.37841 .12477 L
s
.40803 .10694 m
.41052 .10998 L
s
.44295 .09239 m
.4454 .09546 L
s
.47586 .08256 m
.47827 .08566 L
s
.54408 .05215 m
.54641 .05531 L
s
.58097 .04223 m
.58325 .04543 L
s
.61545 .02641 m
.61769 .02964 L
s
.65201 .01065 m
.6542 .01391 L
s
.25 Mabswid
.68871 0 m
.9675 .42834 L
s
.68871 0 m
.68261 .00239 L
s
[(-0.2)] .7009 -0.00478 -1 .39183 Mshowa
.76947 .12128 m
.76332 .12353 L
s
[(-0.1)] .78177 .11679 -1 .36515 Mshowa
.84346 .23507 m
.83726 .23718 L
s
[(0)] .85585 .23084 -1 .34089 Mshowa
.90926 .33669 m
.90303 .33868 L
s
[(0.1)] .92174 .3327 -1 .31976 Mshowa
.9675 .42834 m
.96123 .43023 L
s
[(0.2)] .98004 .42456 -1 .30116 Mshowa
.125 Mabswid
.7062 .02667 m
.70253 .02809 L
s
.72281 .05247 m
.71914 .05387 L
s
.73955 .07263 m
.73587 .07401 L
s
.75536 .09726 m
.75167 .09863 L
s
.78646 .14524 m
.78276 .14657 L
s
.79988 .16814 m
.79618 .16946 L
s
.81621 .19113 m
.8125 .19243 L
s
.82899 .21299 m
.82528 .21428 L
s
.85687 .25596 m
.85315 .25721 L
s
.87078 .27717 m
.86705 .27841 L
s
.88361 .29715 m
.87987 .29838 L
s
.89699 .31756 m
.89325 .31877 L
s
.92215 .35633 m
.9184 .35752 L
s
.9339 .37465 m
.93015 .37582 L
s
.94427 .39257 m
.94051 .39373 L
s
.95759 .41115 m
.95383 .41229 L
s
.25 Mabswid
.03812 .25182 m
0 .48742 L
s
.02883 .30801 m
.03494 .30568 L
s
[(3.75292)] .01659 .31269 1 -0.38192 Mshowa
.01916 .37149 m
.02531 .36922 L
s
[(3.75292)] .00688 .37604 1 -0.36992 Mshowa
.00784 .44397 m
.014 .44178 L
s
[(3.75292)] -0.0045 .44837 1 -0.35617 Mshowa
.125 Mabswid
.02764 .31895 m
.03131 .31755 L
s
.02525 .3309 m
.02892 .32952 L
s
.02283 .34803 m
.02651 .34666 L
s
.02035 .3592 m
.02403 .35783 L
s
.01665 .3828 m
.02034 .38144 L
s
.01544 .3953 m
.01913 .39395 L
s
.01293 .41308 m
.01663 .41175 L
s
.0104 .42586 m
.01409 .42453 L
s
.03118 .29625 m
.03485 .29484 L
s
.03235 .28545 m
.03602 .28403 L
s
.03468 .27388 m
.03834 .27246 L
s
.03575 .26242 m
.03941 .26099 L
s
.00524 .45571 m
.00894 .4544 L
s
.00395 .46886 m
.00765 .46756 L
s
.00132 .48075 m
.00503 .47946 L
s
.25 Mabswid
.03812 .25182 m
0 .48742 L
s
0 .48742 m
.39743 .80819 L
s
.39743 .80819 m
.40584 .5954 L
s
.40584 .5954 m
.03812 .25182 L
s
.68871 0 m
.9675 .42834 L
s
.9675 .42834 m
1 .65033 L
s
1 .65033 m
.7013 .24105 L
s
.7013 .24105 m
.68871 0 L
s
.03812 .25182 m
0 .48742 L
s
0 .48742 m
.7013 .24105 L
s
.7013 .24105 m
.68871 0 L
s
.68871 0 m
.03812 .25182 L
s
.40584 .5954 m
.9675 .42834 L
s
.9675 .42834 m
1 .65033 L
s
1 .65033 m
.39743 .80819 L
s
.39743 .80819 m
.40584 .5954 L
s
0 0 m
1 0 L
1 .80819 L
0 .80819 L
closepath
clip
newpath
.5 Mabswid
.146 .595 0 r
.39158 .70215 .40179 .71006 .41936 .69905 .40923 .69106 Metetra
.084 .573 0 r
.40923 .69106 .41936 .69905 .43594 .6964 .4259 .68415 Metetra
.084 .573 0 r
.4259 .68415 .43594 .6964 .4535 .69106 .44352 .68297 Metetra
.084 .573 0 r
.44352 .68297 .4535 .69106 .47026 .68415 .46036 .676 Metetra
.084 .573 0 r
.46036 .676 .47026 .68415 .48806 .67873 .47823 .67051 Metetra
.084 .573 0 r
.47823 .67051 .48806 .67873 .50601 .67752 .49625 .66926 Metetra
.084 .573 0 r
.49625 .66926 .50601 .67752 .52304 .67051 .51337 .6622 Metetra
.084 .573 0 r
.51337 .6622 .52304 .67051 .54125 .66498 .53165 .65659 Metetra
.084 .573 0 r
.53165 .65659 .54125 .66498 .55846 .6622 .54894 .64946 Metetra
.084 .573 0 r
.54894 .64946 .55846 .6622 .57692 .65659 .56748 .6481 Metetra
.084 .573 0 r
.56748 .6481 .57692 .65659 .59553 .65095 .58495 .6409 Metetra
.084 .573 0 r
.58495 .6409 .59553 .65095 .61303 .64377 .60376 .63514 Metetra
.084 .573 0 r
.60376 .63514 .61303 .64377 .63191 .64239 .62272 .62934 Metetra
.027 .55 0 r
.62272 .62934 .63191 .64239 .65069 .63078 .64025 .62057 Metetra
.027 .55 0 r
.64025 .62057 .65069 .63078 .66845 .6235 .65944 .61467 Metetra
.027 .55 0 r
.65944 .61467 .66845 .6235 .68772 .61763 .6788 .60873 Metetra
.027 .55 0 r
.6788 .60873 .68772 .61763 .70567 .61467 .69684 .60131 Metetra
.027 .55 0 r
.69684 .60131 .70567 .61467 .72522 .60873 .71648 .59972 Metetra
.027 .55 0 r
.71648 .59972 .72522 .60873 .74336 .60131 .73472 .59223 Metetra
.027 .55 0 r
.73472 .59223 .74336 .60131 .76319 .59527 .75465 .58612 Metetra
.027 .55 0 r
.75465 .58612 .76319 .59527 .7832 .59365 .77474 .58444 Metetra
.027 .55 0 r
.77474 .58444 .7832 .59365 .80166 .58612 .7933 .57684 Metetra
.027 .55 0 r
.7933 .57684 .80166 .58612 .82196 .57995 .8137 .5706 Metetra
.027 .55 0 r
.8137 .5706 .82196 .57995 .84062 .57684 .83246 .56292 Metetra
.027 .55 0 r
.83246 .56292 .84062 .57684 .86122 .5706 .85316 .56112 Metetra
.027 .55 0 r
.85316 .56112 .86122 .5706 .88199 .56429 .87213 .55337 Metetra
0 .528 .025 r
.87213 .55337 .88199 .56429 .90017 .55066 .89234 .54101 Metetra
0 .528 .025 r
.89234 .54101 .90017 .55066 .92121 .5488 .91348 .53451 Metetra
0 .528 .025 r
.91348 .53451 .92121 .5488 .94243 .54235 .93275 .53124 Metetra
0 .528 .025 r
.93275 .53124 .94243 .54235 .96173 .53451 .95421 .52465 Metetra
0 .528 .025 r
.95421 .52465 .96173 .53451 .98327 .52795 .97586 .518 Metetra
.146 .595 0 r
.38125 .69414 .39158 .70215 .40923 .69106 .39899 .68297 Metetra
.084 .573 0 r
.39899 .68297 .40923 .69106 .4259 .68415 .41573 .676 Metetra
.084 .573 0 r
.41573 .676 .4259 .68415 .44352 .68297 .43342 .67478 Metetra
.084 .573 0 r
.43342 .67478 .44352 .68297 .46036 .676 .45034 .66775 Metetra
.084 .573 0 r
.45034 .66775 .46036 .676 .47823 .67051 .46828 .6622 Metetra
.084 .573 0 r
.46828 .6622 .47823 .67051 .49625 .66926 .48538 .6551 Metetra
.084 .573 0 r
.48538 .6551 .49625 .66926 .51337 .6622 .50358 .65378 Metetra
.084 .573 0 r
.50358 .65378 .51337 .6622 .53165 .65659 .52192 .6481 Metetra
.084 .573 0 r
.52192 .6481 .53165 .65659 .54894 .64946 .53931 .6409 Metetra
.084 .573 0 r
.53931 .6409 .54894 .64946 .56748 .6481 .55792 .63514 Metetra
.084 .573 0 r
.55792 .63514 .56748 .6481 .58495 .6409 .57549 .63225 Metetra
.084 .573 0 r
.57549 .63225 .58495 .6409 .60376 .63514 .59437 .62641 Metetra
.084 .573 0 r
.59437 .62641 .60376 .63514 .62272 .62934 .61341 .62053 Metetra
.027 .55 0 r
.61341 .62053 .62272 .62934 .64025 .62057 .63105 .6073 Metetra
.027 .55 0 r
.63105 .6073 .64025 .62057 .65944 .61467 .65033 .60574 Metetra
.027 .55 0 r
.65033 .60574 .65944 .61467 .6788 .60873 .66977 .59972 Metetra
.027 .55 0 r
.66977 .59972 .6788 .60873 .69684 .60131 .68791 .59223 Metetra
.027 .55 0 r
.68791 .59223 .69684 .60131 .71648 .59972 .70763 .59059 Metetra
.027 .55 0 r
.70763 .59059 .71648 .59972 .73472 .59223 .72597 .58304 Metetra
.027 .55 0 r
.72597 .58304 .73472 .59223 .75465 .58612 .74599 .57684 Metetra
.027 .55 0 r
.74599 .57684 .75465 .58612 .77474 .58444 .76453 .56921 Metetra
.027 .55 0 r
.76453 .56921 .77474 .58444 .7933 .57684 .78484 .56745 Metetra
.027 .55 0 r
.78484 .56745 .7933 .57684 .8137 .5706 .80533 .56112 Metetra
.027 .55 0 r
.80533 .56112 .8137 .5706 .83246 .56292 .8242 .55337 Metetra
.027 .55 0 r
.8242 .55337 .83246 .56292 .85316 .56112 .845 .54694 Metetra
.027 .55 0 r
.845 .54694 .85316 .56112 .87213 .55337 .86408 .5437 Metetra
0 .528 .025 r
.86408 .5437 .87213 .55337 .89234 .54101 .8844 .53124 Metetra
0 .528 .025 r
.8844 .53124 .89234 .54101 .91348 .53451 .90564 .52465 Metetra
0 .528 .025 r
.90564 .52465 .91348 .53451 .93275 .53124 .92503 .52133 Metetra
0 .528 .025 r
.92503 .52133 .93275 .53124 .95421 .52465 .94659 .51466 Metetra
0 .528 .025 r
.94659 .51466 .95421 .52465 .97586 .518 .96835 .50792 Metetra
.146 .595 0 r
.37079 .68178 .38125 .69414 .39899 .68297 .38783 .67326 Metetra
.084 .573 0 r
.38783 .67326 .39899 .68297 .41573 .676 .40544 .66775 Metetra
.084 .573 0 r
.40544 .66775 .41573 .676 .43342 .67478 .4232 .6622 Metetra
.084 .573 0 r
.4232 .6622 .43342 .67478 .45034 .66775 .4402 .6594 Metetra
.084 .573 0 r
.4402 .6594 .45034 .66775 .46828 .6622 .45821 .65378 Metetra
.084 .573 0 r
.45821 .65378 .46828 .6622 .48538 .6551 .47539 .64662 Metetra
.084 .573 0 r
.47539 .64662 .48538 .6551 .50358 .65378 .49366 .6409 Metetra
.084 .573 0 r
.49366 .6409 .50358 .65378 .52192 .6481 .51208 .63951 Metetra
.084 .573 0 r
.51208 .63951 .52192 .6481 .53931 .6409 .52955 .63225 Metetra
.084 .573 0 r
.52955 .63225 .53931 .6409 .55792 .63514 .54824 .62641 Metetra
.084 .573 0 r
.54824 .62641 .55792 .63514 .57549 .63225 .5659 .61908 Metetra
.084 .573 0 r
.5659 .61908 .57549 .63225 .59437 .62641 .58486 .61757 Metetra
.084 .573 0 r
.58486 .61757 .59437 .62641 .61341 .62053 .6027 .61017 Metetra
.027 .55 0 r
.6027 .61017 .61341 .62053 .63105 .6073 .62174 .5983 Metetra
.027 .55 0 r
.62174 .5983 .63105 .6073 .65033 .60574 .6411 .59669 Metetra
.027 .55 0 r
.6411 .59669 .65033 .60574 .66977 .59972 .65921 .58918 Metetra
.027 .55 0 r
.65921 .58918 .66977 .59972 .68791 .59223 .67886 .58304 Metetra
.027 .55 0 r
.67886 .58304 .68791 .59223 .70763 .59059 .69867 .57684 Metetra
.027 .55 0 r
.69867 .57684 .70763 .59059 .72597 .58304 .71711 .57373 Metetra
.027 .55 0 r
.71711 .57373 .72597 .58304 .74599 .57684 .73722 .56745 Metetra
.027 .55 0 r
.73722 .56745 .74599 .57684 .76453 .56921 .75586 .55975 Metetra
.027 .55 0 r
.75586 .55975 .76453 .56921 .78484 .56745 .77627 .55337 Metetra
.027 .55 0 r
.77627 .55337 .78484 .56745 .80533 .56112 .79685 .55152 Metetra
.027 .55 0 r
.79685 .55152 .80533 .56112 .8242 .55337 .81583 .5437 Metetra
.027 .55 0 r
.81583 .5437 .8242 .55337 .845 .54694 .83672 .53718 Metetra
.027 .55 0 r
.83672 .53718 .845 .54694 .86408 .5437 .85591 .5339 Metetra
0 .528 .025 r
.85591 .5339 .86408 .5437 .8844 .53124 .87635 .52133 Metetra
0 .528 .025 r
.87635 .52133 .8844 .53124 .90564 .52465 .8977 .51466 Metetra
0 .528 .025 r
.8977 .51466 .90564 .52465 .92503 .52133 .9172 .50663 Metetra
0 .528 .025 r
.9172 .50663 .92503 .52133 .94659 .51466 .93887 .50453 Metetra
0 .528 .025 r
.93887 .50453 .94659 .51466 .96835 .50792 .96075 .4977 Metetra
.146 .595 0 r
.3602 .67355 .37079 .68178 .38783 .67326 .37734 .66498 Metetra
.084 .573 0 r
.37734 .66498 .38783 .67326 .40544 .66775 .39502 .6594 Metetra
.084 .573 0 r
.39502 .6594 .40544 .66775 .4232 .6622 .41285 .65378 Metetra
.084 .573 0 r
.41285 .65378 .4232 .6622 .4402 .6594 .42993 .64662 Metetra
.084 .573 0 r
.42993 .64662 .4402 .6594 .45821 .65378 .44801 .64525 Metetra
.084 .573 0 r
.44801 .64525 .45821 .65378 .47539 .64662 .46528 .63803 Metetra
.084 .573 0 r
.46528 .63803 .47539 .64662 .49366 .6409 .48362 .63225 Metetra
.084 .573 0 r
.48362 .63225 .49366 .6409 .51208 .63951 .50107 .62495 Metetra
.084 .573 0 r
.50107 .62495 .51208 .63951 .52955 .63225 .51968 .62348 Metetra
.084 .573 0 r
.51968 .62348 .52955 .63225 .54824 .62641 .53844 .61757 Metetra
.084 .573 0 r
.53844 .61757 .54824 .62641 .5659 .61908 .55619 .61017 Metetra
.084 .573 0 r
.55619 .61017 .5659 .61908 .58486 .61757 .57523 .60862 Metetra
.084 .573 0 r
.57523 .60862 .58486 .61757 .6027 .61017 .59317 .60115 Metetra
.027 .55 0 r
.59317 .60115 .6027 .61017 .62174 .5983 .6123 .58918 Metetra
.027 .55 0 r
.6123 .58918 .62174 .5983 .6411 .59669 .63174 .58304 Metetra
.027 .55 0 r
.63174 .58304 .6411 .59669 .65921 .58918 .64996 .57995 Metetra
.027 .55 0 r
.64996 .57995 .65921 .58918 .67886 .58304 .66969 .57373 Metetra
.027 .55 0 r
.66969 .57373 .67886 .58304 .69867 .57684 .68959 .56745 Metetra
.027 .55 0 r
.68959 .56745 .69867 .57684 .71711 .57373 .70813 .55975 Metetra
.027 .55 0 r
.70813 .55975 .71711 .57373 .73722 .56745 .72833 .55793 Metetra
.027 .55 0 r
.72833 .55793 .73722 .56745 .75586 .55975 .74707 .55016 Metetra
.027 .55 0 r
.74707 .55016 .75586 .55975 .77627 .55337 .76758 .5437 Metetra
.027 .55 0 r
.76758 .5437 .77627 .55337 .79685 .55152 .78826 .5418 Metetra
.027 .55 0 r
.78826 .5418 .79685 .55152 .81583 .5437 .80735 .5339 Metetra
.027 .55 0 r
.80735 .5339 .81583 .5437 .83672 .53718 .82834 .52729 Metetra
.027 .55 0 r
.82834 .52729 .83672 .53718 .85591 .5339 .84764 .51931 Metetra
0 .528 .025 r
.84764 .51931 .85591 .5339 .87635 .52133 .86819 .5113 Metetra
0 .528 .025 r
.86819 .5113 .87635 .52133 .8977 .51466 .88965 .50453 Metetra
0 .528 .025 r
.88965 .50453 .8977 .51466 .9172 .50663 .90926 .49643 Metetra
0 .528 .025 r
.90926 .49643 .9172 .50663 .93887 .50453 .93105 .48955 Metetra
0 .528 .025 r
.93105 .48955 .93887 .50453 .96075 .4977 .95089 .48609 Metetra
.146 .595 0 r
.34877 .6637 .3602 .67355 .37734 .66498 .36673 .65228 Metetra
.084 .573 0 r
.36673 .65228 .37734 .66498 .39502 .6594 .38447 .65095 Metetra
.084 .573 0 r
.38447 .65095 .39502 .6594 .41285 .65378 .40153 .64377 Metetra
.084 .573 0 r
.40153 .64377 .41285 .65378 .42993 .64662 .41954 .63803 Metetra
.084 .573 0 r
.41954 .63803 .42993 .64662 .44801 .64525 .43769 .63225 Metetra
.084 .573 0 r
.43769 .63225 .44801 .64525 .46528 .63803 .45504 .62934 Metetra
.084 .573 0 r
.45504 .62934 .46528 .63803 .48362 .63225 .47345 .62348 Metetra
.084 .573 0 r
.47345 .62348 .48362 .63225 .50107 .62495 .49099 .61612 Metetra
.084 .573 0 r
.49099 .61612 .50107 .62495 .51968 .62348 .50967 .6146 Metetra
.084 .573 0 r
.50967 .6146 .51968 .62348 .53844 .61757 .52851 .60862 Metetra
.084 .573 0 r
.52851 .60862 .53844 .61757 .55619 .61017 .54636 .60115 Metetra
.084 .573 0 r
.54636 .60115 .55619 .61017 .57523 .60862 .56548 .59507 Metetra
.084 .573 0 r
.56548 .59507 .57523 .60862 .59317 .60115 .58351 .59201 Metetra
.027 .55 0 r
.58351 .59201 .59317 .60115 .6123 .58918 .60275 .57995 Metetra
.027 .55 0 r
.60275 .57995 .6123 .58918 .63174 .58304 .62227 .57373 Metetra
.027 .55 0 r
.62227 .57373 .63174 .58304 .64996 .57995 .64059 .56607 Metetra
.027 .55 0 r
.64059 .56607 .64996 .57995 .66969 .57373 .6604 .56429 Metetra
.027 .55 0 r
.6604 .56429 .66969 .57373 .68959 .56745 .6804 .55793 Metetra
.027 .55 0 r
.6804 .55793 .68959 .56745 .70813 .55975 .69904 .55016 Metetra
.027 .55 0 r
.69904 .55016 .70813 .55975 .72833 .55793 .71933 .54829 Metetra
.027 .55 0 r
.71933 .54829 .72833 .55793 .74707 .55016 .73818 .54045 Metetra
.027 .55 0 r
.73818 .54045 .74707 .55016 .76758 .5437 .75878 .5339 Metetra
.027 .55 0 r
.75878 .5339 .76758 .5437 .78826 .5418 .77784 .52597 Metetra
.027 .55 0 r
.77784 .52597 .78826 .5418 .80735 .5339 .79875 .52397 Metetra
.027 .55 0 r
.79875 .52397 .80735 .5339 .82834 .52729 .81985 .51728 Metetra
.027 .55 0 r
.81985 .51728 .82834 .52729 .84764 .51931 .83926 .50922 Metetra
0 .528 .025 r
.83926 .50922 .84764 .51931 .86819 .5113 .85993 .49643 Metetra
0 .528 .025 r
.85993 .49643 .86819 .5113 .88965 .50453 .8815 .49427 Metetra
0 .528 .025 r
.8815 .49427 .88965 .50453 .90926 .49643 .90122 .48609 Metetra
0 .528 .025 r
.90122 .48609 .90926 .49643 .93105 .48955 .92312 .47911 Metetra
0 .528 .025 r
.92312 .47911 .93105 .48955 .95089 .48609 .94307 .47084 Metetra
.146 .595 0 r
.33793 .65528 .34877 .6637 .36673 .65228 .35563 .6496 Metetra
.146 .595 0 r
.35563 .6496 .36673 .65228 .38447 .65095 .37348 .64388 Metetra
.146 .595 0 r
.37348 .64388 .38447 .65095 .40153 .64377 .39066 .641 Metetra
.146 .595 0 r
.39066 .641 .40153 .64377 .41954 .63803 .40877 .6352 Metetra
.146 .595 0 r
.40877 .6352 .41954 .63803 .43769 .63225 .42613 .62788 Metetra
.146 .595 0 r
.42613 .62788 .43769 .63225 .45504 .62934 .4445 .62641 Metetra
.146 .595 0 r
.4445 .62641 .45504 .62934 .47345 .62348 .46414 .62049 Metetra
.146 .595 0 r
.46414 .62049 .47345 .62348 .49099 .61612 .4818 .61307 Metetra
.146 .595 0 r
.4818 .61307 .49099 .61612 .50967 .6146 .5006 .60705 Metetra
.146 .595 0 r
.5006 .60705 .50967 .6146 .52851 .60862 .51846 .60403 Metetra
.146 .595 0 r
.51846 .60403 .52851 .60862 .54636 .60115 .5364 .59201 Metetra
.084 .573 0 r
.5364 .59201 .54636 .60115 .56548 .59507 .5556 .58586 Metetra
.084 .573 0 r
.5556 .58586 .56548 .59507 .58351 .59201 .57373 .57824 Metetra
.027 .55 0 r
.57373 .57824 .58351 .59201 .60275 .57995 .59321 .57652 Metetra
.027 .55 0 r
.59321 .57652 .60275 .57995 .62227 .57373 .61154 .56884 Metetra
.027 .55 0 r
.61154 .56884 .62227 .57373 .64059 .56607 .63246 .5625 Metetra
.027 .55 0 r
.63246 .5625 .64059 .56607 .6604 .56429 .651 .55474 Metetra
.027 .55 0 r
.651 .55474 .6604 .56429 .6804 .55793 .66961 .54694 Metetra
.027 .55 0 r
.66961 .54694 .6804 .55793 .69904 .55016 .68982 .54045 Metetra
.027 .55 0 r
.68982 .54045 .69904 .55016 .71933 .54829 .71021 .5339 Metetra
.027 .55 0 r
.71021 .5339 .71933 .54829 .73818 .54045 .72916 .5306 Metetra
.027 .55 0 r
.72916 .5306 .73818 .54045 .75878 .5339 .74986 .52397 Metetra
.027 .55 0 r
.74986 .52397 .75878 .5339 .77784 .52597 .76902 .51596 Metetra
.027 .55 0 r
.76902 .51596 .77784 .52597 .79875 .52397 .79004 .50922 Metetra
.027 .55 0 r
.79004 .50922 .79875 .52397 .81985 .51728 .81242 .50712 Metetra
.027 .55 0 r
.81242 .50712 .81985 .51728 .83926 .50922 .83194 .49899 Metetra
.027 .55 0 r
.83194 .49899 .83926 .50922 .85993 .49643 .85348 .49209 Metetra
.027 .55 0 r
.85348 .49209 .85993 .49643 .8815 .49427 .87323 .48387 Metetra
.027 .55 0 r
.87323 .48387 .8815 .49427 .90122 .48609 .8951 .48163 Metetra
.027 .55 0 r
.8951 .48163 .90122 .48609 .92312 .47911 .91508 .47332 Metetra
.027 .55 0 r
.91508 .47332 .92312 .47911 .94307 .47084 .9373 .46621 Metetra
.146 .595 0 r
.32696 .64674 .33793 .65528 .35563 .6496 .34473 .641 Metetra
.146 .595 0 r
.34473 .641 .35563 .6496 .37348 .64388 .36264 .6352 Metetra
.146 .595 0 r
.36264 .6352 .37348 .64388 .39066 .641 .37991 .63228 Metetra
.146 .595 0 r
.37991 .63228 .39066 .641 .40877 .6352 .39808 .62641 Metetra
.146 .595 0 r
.39808 .62641 .40877 .6352 .42613 .62788 .41664 .61903 Metetra
.146 .595 0 r
.41664 .61903 .42613 .62788 .4445 .62641 .43509 .61307 Metetra
.146 .595 0 r
.43509 .61307 .4445 .62641 .46414 .62049 .45273 .61007 Metetra
.146 .595 0 r
.45273 .61007 .46414 .62049 .4818 .61307 .47145 .60403 Metetra
.146 .595 0 r
.47145 .60403 .4818 .61307 .5006 .60705 .49033 .59793 Metetra
.146 .595 0 r
.49033 .59793 .5006 .60705 .51846 .60403 .50828 .59036 Metetra
.146 .595 0 r
.50828 .59036 .51846 .60403 .5364 .59201 .52631 .58276 Metetra
.084 .573 0 r
.52631 .58276 .5364 .59201 .5556 .58586 .54559 .57652 Metetra
.084 .573 0 r
.54559 .57652 .5556 .58586 .57373 .57824 .56381 .56884 Metetra
.084 .573 0 r
.56381 .56884 .57373 .57824 .59321 .57652 .58453 .5625 Metetra
.084 .573 0 r
.58453 .5625 .59321 .57652 .61154 .56884 .60296 .55931 Metetra
.084 .573 0 r
.60296 .55931 .61154 .56884 .63246 .5625 .62283 .55289 Metetra
.027 .55 0 r
.62283 .55289 .63246 .5625 .651 .55474 .64146 .54045 Metetra
.027 .55 0 r
.64146 .54045 .651 .55474 .66961 .54694 .66018 .53718 Metetra
.027 .55 0 r
.66018 .53718 .66961 .54694 .68982 .54045 .68048 .5306 Metetra
.027 .55 0 r
.68048 .5306 .68982 .54045 .71021 .5339 .70096 .52397 Metetra
.027 .55 0 r
.70096 .52397 .71021 .5339 .72916 .5306 .72002 .51596 Metetra
.027 .55 0 r
.72002 .51596 .72916 .5306 .74986 .52397 .74082 .51391 Metetra
.027 .55 0 r
.74082 .51391 .74986 .52397 .76902 .51596 .76127 .50582 Metetra
.027 .55 0 r
.76127 .50582 .76902 .51596 .79004 .50922 .78239 .49899 Metetra
.027 .55 0 r
.78239 .49899 .79004 .50922 .81242 .50712 .80189 .49082 Metetra
.027 .55 0 r
.80189 .49082 .81242 .50712 .83194 .49899 .82334 .48862 Metetra
.027 .55 0 r
.82334 .48862 .83194 .49899 .85348 .49209 .84498 .48163 Metetra
.027 .55 0 r
.84498 .48163 .85348 .49209 .87323 .48387 .86485 .47332 Metetra
.027 .55 0 r
.86485 .47332 .87323 .48387 .8951 .48163 .88683 .47102 Metetra
.027 .55 0 r
.88683 .47102 .8951 .48163 .91508 .47332 .90693 .46263 Metetra
.027 .55 0 r
.90693 .46263 .91508 .47332 .9373 .46621 .92926 .45542 Metetra
.146 .595 0 r
.31585 .6381 .32696 .64674 .34473 .641 .33368 .63228 Metetra
.146 .595 0 r
.33368 .63228 .34473 .641 .36264 .6352 .35203 .62494 Metetra
.146 .595 0 r
.35203 .62494 .36264 .6352 .37991 .63228 .37012 .61903 Metetra
.146 .595 0 r
.37012 .61903 .37991 .63228 .39808 .62641 .38837 .61752 Metetra
.146 .595 0 r
.38837 .61752 .39808 .62641 .41664 .61903 .40592 .61007 Metetra
.146 .595 0 r
.40592 .61007 .41664 .61903 .43509 .61307 .42444 .60403 Metetra
.146 .595 0 r
.42444 .60403 .43509 .61307 .45273 .61007 .44217 .5965 Metetra
.146 .595 0 r
.44217 .5965 .45273 .61007 .47145 .60403 .46096 .59487 Metetra
.146 .595 0 r
.46096 .59487 .47145 .60403 .49033 .59793 .47992 .5887 Metetra
.146 .595 0 r
.47992 .5887 .49033 .59793 .50828 .59036 .49796 .58106 Metetra
.146 .595 0 r
.49796 .58106 .50828 .59036 .52631 .58276 .51722 .56884 Metetra
.084 .573 0 r
.51722 .56884 .52631 .58276 .54559 .57652 .53659 .56707 Metetra
.084 .573 0 r
.53659 .56707 .54559 .57652 .56381 .56884 .55492 .55931 Metetra
.084 .573 0 r
.55492 .55931 .56381 .56884 .58453 .5625 .57458 .55289 Metetra
.084 .573 0 r
.57458 .55289 .58453 .5625 .60296 .55931 .59311 .54966 Metetra
.084 .573 0 r
.59311 .54966 .60296 .55931 .62283 .55289 .61307 .54315 Metetra
.027 .55 0 r
.61307 .54315 .62283 .55289 .64146 .54045 .6318 .5306 Metetra
.027 .55 0 r
.6318 .5306 .64146 .54045 .66018 .53718 .65063 .52265 Metetra
.027 .55 0 r
.65063 .52265 .66018 .53718 .68048 .5306 .67102 .52063 Metetra
.027 .55 0 r
.67102 .52063 .68048 .5306 .70096 .52397 .69122 .5126 Metetra
.027 .55 0 r
.69122 .5126 .70096 .52397 .72002 .51596 .71194 .50582 Metetra
.027 .55 0 r
.71194 .50582 .72002 .51596 .74082 .51391 .73283 .49899 Metetra
.027 .55 0 r
.73283 .49899 .74082 .51391 .76127 .50582 .75222 .49555 Metetra
.027 .55 0 r
.75222 .49555 .76127 .50582 .78239 .49899 .77345 .48862 Metetra
.027 .55 0 r
.77345 .48862 .78239 .49899 .80189 .49082 .79306 .48037 Metetra
.027 .55 0 r
.79306 .48037 .80189 .49082 .82334 .48862 .81462 .47811 Metetra
.027 .55 0 r
.81462 .47811 .82334 .48862 .84498 .48163 .83637 .47102 Metetra
.027 .55 0 r
.83637 .47102 .84498 .48163 .86485 .47332 .85635 .46263 Metetra
.027 .55 0 r
.85635 .46263 .86485 .47332 .88683 .47102 .87845 .45542 Metetra
.027 .55 0 r
.87845 .45542 .88683 .47102 .90693 .46263 .89867 .45179 Metetra
.027 .55 0 r
.89867 .45179 .90693 .46263 .92926 .45542 .92112 .44448 Metetra
.146 .595 0 r
.30571 .62494 .31585 .6381 .33368 .63228 .32361 .62346 Metetra
.146 .595 0 r
.32361 .62346 .33368 .63228 .35203 .62494 .34094 .61605 Metetra
.146 .595 0 r
.34094 .61605 .35203 .62494 .37012 .61903 .3591 .61007 Metetra
.146 .595 0 r
.3591 .61007 .37012 .61903 .38837 .61752 .37742 .60403 Metetra
.146 .595 0 r
.37742 .60403 .38837 .61752 .40592 .61007 .39505 .60099 Metetra
.146 .595 0 r
.39505 .60099 .40592 .61007 .42444 .60403 .41365 .59487 Metetra
.146 .595 0 r
.41365 .59487 .42444 .60403 .44217 .5965 .43147 .58727 Metetra
.146 .595 0 r
.43147 .58727 .44217 .5965 .46096 .59487 .45034 .58106 Metetra
.146 .595 0 r
.45034 .58106 .46096 .59487 .47992 .5887 .46836 .57793 Metetra
.146 .595 0 r
.46836 .57793 .47992 .5887 .49796 .58106 .48752 .57163 Metetra
.146 .595 0 r
.48752 .57163 .49796 .58106 .51722 .56884 .50688 .55931 Metetra
.084 .573 0 r
.50688 .55931 .51722 .56884 .53659 .56707 .52518 .55611 Metetra
.084 .573 0 r
.52518 .55611 .53659 .56707 .55492 .55931 .54475 .54966 Metetra
.084 .573 0 r
.54475 .54966 .55492 .55931 .57458 .55289 .5645 .54315 Metetra
.084 .573 0 r
.5645 .54315 .57458 .55289 .59311 .54966 .58313 .53524 Metetra
.084 .573 0 r
.58313 .53524 .59311 .54966 .61307 .54315 .60318 .53328 Metetra
.027 .55 0 r
.60318 .53328 .61307 .54315 .6318 .5306 .62318 .52063 Metetra
.027 .55 0 r
.62318 .52063 .6318 .5306 .65063 .52265 .64211 .5126 Metetra
.027 .55 0 r
.64211 .5126 .65063 .52265 .67102 .52063 .6626 .50582 Metetra
.027 .55 0 r
.6626 .50582 .67102 .52063 .69122 .5126 .68175 .50241 Metetra
.027 .55 0 r
.68175 .50241 .69122 .5126 .71194 .50582 .70256 .49555 Metetra
.027 .55 0 r
.70256 .49555 .71194 .50582 .73283 .49899 .72356 .48862 Metetra
.027 .55 0 r
.72356 .48862 .73283 .49899 .75222 .49555 .74306 .48513 Metetra
.027 .55 0 r
.74306 .48513 .75222 .49555 .77345 .48862 .76438 .47811 Metetra
.027 .55 0 r
.76438 .47811 .77345 .48862 .79306 .48037 .78411 .46977 Metetra
.027 .55 0 r
.78411 .46977 .79306 .48037 .81462 .47811 .80577 .46263 Metetra
.027 .55 0 r
.80577 .46263 .81462 .47811 .83637 .47102 .82764 .46026 Metetra
.027 .55 0 r
.82764 .46026 .83637 .47102 .85635 .46263 .84774 .45179 Metetra
.027 .55 0 r
.84774 .45179 .85635 .46263 .87845 .45542 .86995 .44448 Metetra
.027 .55 0 r
.86995 .44448 .87845 .45542 .89867 .45179 .89029 .43592 Metetra
.027 .55 0 r
.89029 .43592 .89867 .45179 .92112 .44448 .91286 .43339 Metetra
.146 .595 0 r
.29433 .61605 .30571 .62494 .32361 .62346 .31229 .61007 Metetra
.146 .595 0 r
.31229 .61007 .32361 .62346 .34094 .61605 .32971 .60705 Metetra
.146 .595 0 r
.32971 .60705 .34094 .61605 .3591 .61007 .34794 .60099 Metetra
.146 .595 0 r
.34794 .60099 .3591 .61007 .37742 .60403 .36555 .59344 Metetra
.146 .595 0 r
.36555 .59344 .37742 .60403 .39505 .60099 .38405 .58727 Metetra
.146 .595 0 r
.38405 .58727 .39505 .60099 .41365 .59487 .40272 .58559 Metetra
.146 .595 0 r
.40272 .58559 .41365 .59487 .43147 .58727 .42063 .57793 Metetra
.146 .595 0 r
.42063 .57793 .43147 .58727 .45034 .58106 .43958 .57163 Metetra
.146 .595 0 r
.43958 .57163 .45034 .58106 .46836 .57793 .45769 .56846 Metetra
.146 .595 0 r
.45769 .56846 .46836 .57793 .48752 .57163 .47693 .56208 Metetra
.146 .595 0 r
.47693 .56208 .48752 .57163 .50688 .55931 .49639 .54966 Metetra
.084 .573 0 r
.49639 .54966 .50688 .55931 .52518 .55611 .51479 .5418 Metetra
.084 .573 0 r
.51479 .5418 .52518 .55611 .54475 .54966 .53445 .53988 Metetra
.084 .573 0 r
.53445 .53988 .54475 .54966 .5645 .54315 .55428 .53328 Metetra
.084 .573 0 r
.55428 .53328 .5645 .54315 .58313 .53524 .57301 .5253 Metetra
.084 .573 0 r
.57301 .5253 .58313 .53524 .60318 .53328 .59315 .51859 Metetra
.027 .55 0 r
.59315 .51859 .60318 .53328 .62318 .52063 .61327 .51052 Metetra
.027 .55 0 r
.61327 .51052 .62318 .52063 .64211 .5126 .6323 .50241 Metetra
.027 .55 0 r
.6323 .50241 .64211 .5126 .6626 .50582 .65289 .49555 Metetra
.027 .55 0 r
.65289 .49555 .6626 .50582 .68175 .50241 .67214 .49209 Metetra
.027 .55 0 r
.67214 .49209 .68175 .50241 .70256 .49555 .69305 .48513 Metetra
.027 .55 0 r
.69305 .48513 .70256 .49555 .72356 .48862 .71253 .47685 Metetra
.027 .55 0 r
.71253 .47685 .72356 .48862 .74306 .48513 .73376 .46977 Metetra
.027 .55 0 r
.73376 .46977 .74306 .48513 .76438 .47811 .75519 .46745 Metetra
.027 .55 0 r
.75519 .46745 .76438 .47811 .78411 .46977 .77504 .45904 Metetra
.027 .55 0 r
.77504 .45904 .78411 .46977 .80577 .46263 .79681 .45179 Metetra
.027 .55 0 r
.79681 .45179 .80577 .46263 .82764 .46026 .81689 .44329 Metetra
.027 .55 0 r
.81689 .44329 .82764 .46026 .84774 .45179 .83901 .4408 Metetra
.027 .55 0 r
.83901 .4408 .84774 .45179 .86995 .44448 .86133 .43339 Metetra
.027 .55 0 r
.86133 .43339 .86995 .44448 .89029 .43592 .8818 .42474 Metetra
.027 .55 0 r
.8818 .42474 .89029 .43592 .91286 .43339 .90448 .42214 Metetra
.146 .595 0 r
.2828 .60705 .29433 .61605 .31229 .61007 .30083 .60099 Metetra
.146 .595 0 r
.30083 .60099 .31229 .61007 .32971 .60705 .31833 .59344 Metetra
.146 .595 0 r
.31833 .59344 .32971 .60705 .34794 .60099 .33663 .59179 Metetra
.146 .595 0 r
.33663 .59179 .34794 .60099 .36555 .59344 .35433 .58417 Metetra
.146 .595 0 r
.35433 .58417 .36555 .59344 .38405 .58727 .37291 .57793 Metetra
.146 .595 0 r
.37291 .57793 .38405 .58727 .40272 .58559 .39165 .5762 Metetra
.146 .595 0 r
.39165 .5762 .40272 .58559 .42063 .57793 .40965 .56846 Metetra
.146 .595 0 r
.40965 .56846 .42063 .57793 .43958 .57163 .42868 .56208 Metetra
.146 .595 0 r
.42868 .56208 .43958 .57163 .45769 .56846 .44689 .55426 Metetra
.146 .595 0 r
.44689 .55426 .45769 .56846 .47693 .56208 .4662 .5524 Metetra
.146 .595 0 r
.4662 .5524 .47693 .56208 .49639 .54966 .48577 .53988 Metetra
.084 .573 0 r
.48577 .53988 .49639 .54966 .51479 .5418 .50427 .53194 Metetra
.084 .573 0 r
.50427 .53194 .51479 .5418 .53445 .53988 .52401 .5253 Metetra
.084 .573 0 r
.52401 .5253 .53445 .53988 .55428 .53328 .54272 .52195 Metetra
.084 .573 0 r
.54272 .52195 .55428 .53328 .57301 .5253 .56276 .51522 Metetra
.084 .573 0 r
.56276 .51522 .57301 .5253 .59315 .51859 .58299 .50843 Metetra
.027 .55 0 r
.58299 .50843 .59315 .51859 .61327 .51052 .60187 .49899 Metetra
.027 .55 0 r
.60187 .49899 .61327 .51052 .6323 .50241 .62236 .49209 Metetra
.027 .55 0 r
.62236 .49209 .6323 .50241 .65289 .49555 .64305 .48513 Metetra
.027 .55 0 r
.64305 .48513 .65289 .49555 .67214 .49209 .66241 .47685 Metetra
.027 .55 0 r
.66241 .47685 .67214 .49209 .69305 .48513 .68341 .47457 Metetra
.027 .55 0 r
.68341 .47457 .69305 .48513 .71253 .47685 .703 .46621 Metetra
.027 .55 0 r
.703 .46621 .71253 .47685 .73376 .46977 .72434 .45904 Metetra
.027 .55 0 r
.72434 .45904 .73376 .46977 .75519 .46745 .74588 .45179 Metetra
.027 .55 0 r
.74588 .45179 .75519 .46745 .77504 .45904 .76584 .44815 Metetra
.027 .55 0 r
.76584 .44815 .77504 .45904 .79681 .45179 .78772 .4408 Metetra
.027 .55 0 r
.78772 .4408 .79681 .45179 .81689 .44329 .80792 .43221 Metetra
.027 .55 0 r
.80792 .43221 .81689 .44329 .83901 .4408 .83015 .42474 Metetra
.027 .55 0 r
.83015 .42474 .83901 .4408 .86133 .43339 .85259 .42214 Metetra
.027 .55 0 r
.85259 .42214 .86133 .43339 .8818 .42474 .87318 .4134 Metetra
.027 .55 0 r
.87318 .4134 .8818 .42474 .90448 .42214 .89599 .40575 Metetra
.146 .595 0 r
.27112 .59793 .2828 .60705 .30083 .60099 .28972 .58586 Metetra
.146 .595 0 r
.28972 .58586 .30083 .60099 .31833 .59344 .30728 .57824 Metetra
.146 .595 0 r
.30728 .57824 .31833 .59344 .33663 .59179 .32561 .57652 Metetra
.146 .595 0 r
.32561 .57652 .33663 .59179 .35433 .58417 .34411 .57023 Metetra
.146 .595 0 r
.34411 .57023 .35433 .58417 .37291 .57793 .36197 .5625 Metetra
.146 .595 0 r
.36197 .5625 .37291 .57793 .39165 .5762 .38074 .55611 Metetra
.146 .595 0 r
.38074 .55611 .39165 .5762 .40965 .56846 .39881 .55289 Metetra
.146 .595 0 r
.39881 .55289 .40965 .56846 .42868 .56208 .41787 .54641 Metetra
.146 .595 0 r
.41787 .54641 .42868 .56208 .44689 .55426 .43613 .53853 Metetra
.146 .595 0 r
.43613 .53853 .44689 .55426 .4662 .5524 .45549 .53194 Metetra
.146 .595 0 r
.45549 .53194 .4662 .5524 .48577 .53988 .47501 .52996 Metetra
.084 .573 0 r
.47501 .52996 .48577 .53988 .50427 .53194 .49361 .52195 Metetra
.084 .573 0 r
.49361 .52195 .50427 .53194 .52401 .5253 .51343 .51522 Metetra
.084 .573 0 r
.51343 .51522 .52401 .5253 .54272 .52195 .53342 .50712 Metetra
.084 .573 0 r
.53342 .50712 .54272 .52195 .56276 .51522 .55232 .49899 Metetra
.084 .573 0 r
.55232 .49899 .56276 .51522 .58299 .50843 .57259 .49209 Metetra
.027 .55 0 r
.57259 .49209 .58299 .50843 .60187 .49899 .5917 .48387 Metetra
.027 .55 0 r
.5917 .48387 .60187 .49899 .62236 .49209 .61229 .48163 Metetra
.027 .55 0 r
.61229 .48163 .62236 .49209 .64305 .48513 .63307 .47457 Metetra
.027 .55 0 r
.63307 .47457 .64305 .48513 .66241 .47685 .65254 .46621 Metetra
.027 .55 0 r
.65254 .46621 .66241 .47685 .68341 .47457 .67365 .45904 Metetra
.027 .55 0 r
.67365 .45904 .68341 .47457 .703 .46621 .69335 .45542 Metetra
.027 .55 0 r
.69335 .45542 .703 .46621 .72434 .45904 .71479 .44815 Metetra
.027 .55 0 r
.71479 .44815 .72434 .45904 .74588 .45179 .73643 .4408 Metetra
.027 .55 0 r
.73643 .4408 .74588 .45179 .76584 .44815 .75651 .43221 Metetra
.027 .55 0 r
.75651 .43221 .76584 .44815 .78772 .4408 .7785 .42966 Metetra
.027 .55 0 r
.7785 .42966 .78772 .4408 .80792 .43221 .80005 .41605 Metetra
.027 .55 0 r
.80005 .41605 .80792 .43221 .83015 .42474 .82047 .40731 Metetra
.027 .55 0 r
.82047 .40731 .83015 .42474 .85259 .42214 .84297 .40462 Metetra
.027 .55 0 r
.84297 .40462 .85259 .42214 .87318 .4134 .86363 .3958 Metetra
.027 .55 0 r
.86363 .3958 .87318 .4134 .89599 .40575 .8865 .38803 Metetra
.146 .595 0 r
.25929 .5887 .27112 .59793 .28972 .58586 .27799 .57652 Metetra
.084 .573 0 r
.27799 .57652 .28972 .58586 .30728 .57824 .29563 .56884 Metetra
.084 .573 0 r
.29563 .56884 .30728 .57824 .32561 .57652 .31404 .5625 Metetra
.084 .573 0 r
.31404 .5625 .32561 .57652 .34411 .57023 .33188 .55931 Metetra
.084 .573 0 r
.33188 .55931 .34411 .57023 .36197 .5625 .35056 .55289 Metetra
.084 .573 0 r
.35056 .55289 .36197 .5625 .38074 .55611 .36941 .54641 Metetra
.084 .573 0 r
.36941 .54641 .38074 .55611 .39881 .55289 .38756 .53853 Metetra
.084 .573 0 r
.38756 .53853 .39881 .55289 .41787 .54641 .4067 .53659 Metetra
.084 .573 0 r
.4067 .53659 .41787 .54641 .43613 .53853 .42506 .52863 Metetra
.084 .573 0 r
.42506 .52863 .43613 .53853 .45549 .53194 .44449 .52195 Metetra
.084 .573 0 r
.44449 .52195 .45549 .53194 .47501 .52996 .4641 .51992 Metetra
.084 .573 0 r
.4641 .51992 .47501 .52996 .49361 .52195 .4828 .51183 Metetra
.084 .573 0 r
.4828 .51183 .49361 .52195 .51343 .51522 .50271 .50501 Metetra
.027 .55 0 r
.50271 .50501 .51343 .51522 .53342 .50712 .52281 .49209 Metetra
.027 .55 0 r
.52281 .49209 .53342 .50712 .55232 .49899 .54181 .48862 Metetra
.027 .55 0 r
.54181 .48862 .55232 .49899 .57259 .49209 .56217 .48163 Metetra
.027 .55 0 r
.56217 .48163 .57259 .49209 .5917 .48387 .58139 .47332 Metetra
.027 .55 0 r
.58139 .47332 .5917 .48387 .61229 .48163 .60207 .46621 Metetra
.027 .55 0 r
.60207 .46621 .61229 .48163 .63307 .47457 .62295 .46386 Metetra
.027 .55 0 r
.62295 .46386 .63307 .47457 .65254 .46621 .64253 .45542 Metetra
.027 .55 0 r
.64253 .45542 .65254 .46621 .67365 .45904 .66374 .44815 Metetra
.027 .55 0 r
.66374 .44815 .67365 .45904 .69335 .45542 .68355 .43961 Metetra
.027 .55 0 r
.68355 .43961 .69335 .45542 .71479 .44815 .7051 .43711 Metetra
.027 .55 0 r
.7051 .43711 .71479 .44815 .73643 .4408 .72515 .42848 Metetra
.027 .55 0 r
.72515 .42848 .73643 .4408 .75651 .43221 .74705 .42098 Metetra
.027 .55 0 r
.74705 .42098 .75651 .43221 .7785 .42966 .76915 .41836 Metetra
0 .528 .025 r
.76915 .41836 .7785 .42966 .80005 .41605 .78897 .40349 Metetra
0 .528 .025 r
.78897 .40349 .80005 .41605 .82047 .40731 .81137 .3958 Metetra
0 .528 .025 r
.81137 .3958 .82047 .40731 .84297 .40462 .83399 .38803 Metetra
0 .528 .025 r
.83399 .38803 .84297 .40462 .86363 .3958 .85478 .38412 Metetra
0 .528 .025 r
.85478 .38412 .86363 .3958 .8865 .38803 .87778 .37624 Metetra
.146 .595 0 r
.24731 .57479 .25929 .5887 .27799 .57652 .2661 .56707 Metetra
.084 .573 0 r
.2661 .56707 .27799 .57652 .29563 .56884 .28384 .55931 Metetra
.084 .573 0 r
.28384 .55931 .29563 .56884 .31404 .5625 .30231 .55289 Metetra
.084 .573 0 r
.30231 .55289 .31404 .5625 .33188 .55931 .32024 .54505 Metetra
.084 .573 0 r
.32024 .54505 .33188 .55931 .35056 .55289 .33899 .54315 Metetra
.084 .573 0 r
.33899 .54315 .35056 .55289 .36941 .54641 .35792 .53659 Metetra
.084 .573 0 r
.35792 .53659 .36941 .54641 .38756 .53853 .37617 .52863 Metetra
.084 .573 0 r
.37617 .52863 .38756 .53853 .4067 .53659 .39538 .52663 Metetra
.084 .573 0 r
.39538 .52663 .4067 .53659 .42506 .52863 .41384 .51859 Metetra
.084 .573 0 r
.41384 .51859 .42506 .52863 .44449 .52195 .43336 .51183 Metetra
.084 .573 0 r
.43336 .51183 .44449 .52195 .4641 .51992 .45304 .50501 Metetra
.084 .573 0 r
.45304 .50501 .4641 .51992 .4828 .51183 .47184 .50157 Metetra
.084 .573 0 r
.47184 .50157 .4828 .51183 .50271 .50501 .49184 .49465 Metetra
.027 .55 0 r
.49184 .49465 .50271 .50501 .52281 .49209 .51205 .48163 Metetra
.027 .55 0 r
.51205 .48163 .52281 .49209 .54181 .48862 .53116 .47332 Metetra
.027 .55 0 r
.53116 .47332 .54181 .48862 .56217 .48163 .55161 .47102 Metetra
.027 .55 0 r
.55161 .47102 .56217 .48163 .58139 .47332 .57094 .46263 Metetra
.027 .55 0 r
.57094 .46263 .58139 .47332 .60207 .46621 .59172 .45542 Metetra
.027 .55 0 r
.59172 .45542 .60207 .46621 .62295 .46386 .61128 .44694 Metetra
.027 .55 0 r
.61128 .44694 .62295 .46386 .64253 .45542 .63239 .44448 Metetra
.027 .55 0 r
.63239 .44448 .64253 .45542 .66374 .44815 .6537 .43711 Metetra
.027 .55 0 r
.6537 .43711 .66374 .44815 .68355 .43961 .67363 .42848 Metetra
.027 .55 0 r
.67363 .42848 .68355 .43961 .7051 .43711 .69528 .42591 Metetra
.027 .55 0 r
.69528 .42591 .7051 .43711 .72515 .42848 .71545 .4172 Metetra
.027 .55 0 r
.71545 .4172 .72515 .42848 .74705 .42098 .73745 .40959 Metetra
.027 .55 0 r
.73745 .40959 .74705 .42098 .76915 .41836 .75967 .4019 Metetra
0 .528 .025 r
.75967 .4019 .76915 .41836 .78897 .40349 .77962 .39192 Metetra
0 .528 .025 r
.77962 .39192 .78897 .40349 .81137 .3958 .80215 .38412 Metetra
0 .528 .025 r
.80215 .38412 .81137 .3958 .83399 .38803 .82489 .37624 Metetra
0 .528 .025 r
.82489 .37624 .83399 .38803 .85478 .38412 .84581 .36722 Metetra
0 .528 .025 r
.84581 .36722 .85478 .38412 .87778 .37624 .86892 .36427 Metetra
.146 .595 0 r
.23516 .56528 .24731 .57479 .2661 .56707 .25406 .55289 Metetra
.084 .573 0 r
.25406 .55289 .2661 .56707 .28384 .55931 .27188 .54966 Metetra
.084 .573 0 r
.27188 .54966 .28384 .55931 .30231 .55289 .29042 .54315 Metetra
.084 .573 0 r
.29042 .54315 .30231 .55289 .32024 .54505 .30845 .53524 Metetra
.084 .573 0 r
.30845 .53524 .32024 .54505 .33899 .54315 .32728 .53328 Metetra
.084 .573 0 r
.32728 .53328 .33899 .54315 .35792 .53659 .34627 .52663 Metetra
.084 .573 0 r
.34627 .52663 .35792 .53659 .37617 .52863 .36462 .51859 Metetra
.084 .573 0 r
.36462 .51859 .37617 .52863 .39538 .52663 .38391 .51183 Metetra
.084 .573 0 r
.38391 .51183 .39538 .52663 .41384 .51859 .40247 .50843 Metetra
.084 .573 0 r
.40247 .50843 .41384 .51859 .43336 .51183 .42207 .50157 Metetra
.084 .573 0 r
.42207 .50157 .43336 .51183 .45304 .50501 .44084 .49337 Metetra
.084 .573 0 r
.44084 .49337 .45304 .50501 .47184 .50157 .46074 .4864 Metetra
.084 .573 0 r
.46074 .4864 .47184 .50157 .49184 .49465 .48082 .48416 Metetra
.027 .55 0 r
.48082 .48416 .49184 .49465 .51205 .48163 .5 .46977 Metetra
.027 .55 0 r
.5 .46977 .51205 .48163 .53116 .47332 .52036 .46263 Metetra
.027 .55 0 r
.52036 .46263 .53116 .47332 .55161 .47102 .54091 .45542 Metetra
.027 .55 0 r
.54091 .45542 .55161 .47102 .57094 .46263 .56034 .45179 Metetra
.027 .55 0 r
.56034 .45179 .57094 .46263 .59172 .45542 .58122 .44448 Metetra
.027 .55 0 r
.58122 .44448 .59172 .45542 .61128 .44694 .60089 .43592 Metetra
.027 .55 0 r
.60089 .43592 .61128 .44694 .63239 .44448 .6221 .43339 Metetra
.027 .55 0 r
.6221 .43339 .63239 .44448 .6537 .43711 .64351 .42591 Metetra
.027 .55 0 r
.64351 .42591 .6537 .43711 .67363 .42848 .66356 .4172 Metetra
.027 .55 0 r
.66356 .4172 .67363 .42848 .69528 .42591 .68532 .40959 Metetra
.027 .55 0 r
.68532 .40959 .69528 .42591 .71545 .4172 .7056 .40575 Metetra
.027 .55 0 r
.7056 .40575 .71545 .4172 .73745 .40959 .72772 .39803 Metetra
.027 .55 0 r
.72772 .39803 .73745 .40959 .75967 .4019 .74826 .38913 Metetra
0 .528 .025 r
.74826 .38913 .75967 .4019 .77962 .39192 .77015 .37516 Metetra
0 .528 .025 r
.77015 .37516 .77962 .39192 .80215 .38412 .79279 .37227 Metetra
0 .528 .025 r
.79279 .37227 .80215 .38412 .82489 .37624 .81368 .36322 Metetra
0 .528 .025 r
.81368 .36322 .82489 .37624 .84581 .36722 .8367 .35516 Metetra
0 .528 .025 r
.8367 .35516 .84581 .36722 .86892 .36427 .85994 .35213 Metetra
.084 .573 0 r
.22353 .54966 .23516 .56528 .25406 .55289 .24248 .53718 Metetra
.084 .573 0 r
.24248 .53718 .25406 .55289 .27188 .54966 .26036 .5339 Metetra
.084 .573 0 r
.26036 .5339 .27188 .54966 .29042 .54315 .27893 .52729 Metetra
.084 .573 0 r
.27893 .52729 .29042 .54315 .30845 .53524 .29767 .52063 Metetra
.084 .573 0 r
.29767 .52063 .30845 .53524 .32728 .53328 .31587 .5126 Metetra
.084 .573 0 r
.31587 .5126 .32728 .53328 .34627 .52663 .3349 .51052 Metetra
.084 .573 0 r
.3349 .51052 .34627 .52663 .36462 .51859 .35331 .50241 Metetra
.084 .573 0 r
.35331 .50241 .36462 .51859 .38391 .51183 .37263 .49555 Metetra
.084 .573 0 r
.37263 .49555 .38391 .51183 .40247 .50843 .39125 .48735 Metetra
.084 .573 0 r
.39125 .48735 .40247 .50843 .42207 .50157 .41088 .48513 Metetra
.084 .573 0 r
.41088 .48513 .42207 .50157 .44084 .49337 .43069 .47811 Metetra
.084 .573 0 r
.43069 .47811 .44084 .49337 .46074 .4864 .44966 .46977 Metetra
.084 .573 0 r
.44966 .46977 .46074 .4864 .48082 .48416 .46978 .46263 Metetra
.027 .55 0 r
.46978 .46263 .48082 .48416 .5 .46977 .48888 .4651 Metetra
.027 .55 0 r
.48888 .4651 .5 .46977 .52036 .46263 .50938 .45787 Metetra
.027 .55 0 r
.50938 .45787 .52036 .46263 .54091 .45542 .52883 .44936 Metetra
.027 .55 0 r
.52883 .44936 .54091 .45542 .56034 .45179 .54966 .4469 Metetra
.027 .55 0 r
.54966 .4469 .56034 .45179 .58122 .44448 .56934 .4383 Metetra
.027 .55 0 r
.56934 .4383 .58122 .44448 .60089 .43592 .59051 .43084 Metetra
.027 .55 0 r
.59051 .43084 .60089 .43592 .6221 .43339 .61187 .42331 Metetra
.027 .55 0 r
.61187 .42331 .6221 .43339 .64351 .42591 .63194 .41952 Metetra
.027 .55 0 r
.63194 .41952 .64351 .42591 .66356 .4172 .65334 .40575 Metetra
.027 .55 0 r
.65334 .40575 .66356 .4172 .68532 .40959 .67521 .39803 Metetra
.027 .55 0 r
.67521 .39803 .68532 .40959 .7056 .40575 .69562 .38913 Metetra
.027 .55 0 r
.69562 .38913 .7056 .40575 .72772 .39803 .71785 .38631 Metetra
.027 .55 0 r
.71785 .38631 .72772 .39803 .74826 .38913 .73851 .37732 Metetra
0 .528 .025 r
.73851 .37732 .74826 .38913 .77015 .37516 .76054 .36322 Metetra
0 .528 .025 r
.76054 .36322 .77015 .37516 .79279 .37227 .78329 .36025 Metetra
0 .528 .025 r
.78329 .36025 .79279 .37227 .81368 .36322 .80431 .3511 Metetra
0 .528 .025 r
.80431 .3511 .81368 .36322 .8367 .35516 .82745 .34292 Metetra
0 .505 .073 r
.82745 .34292 .8367 .35516 .85994 .35213 .85002 .32853 Metetra
.027 .55 0 r
.21109 .53988 .22353 .54966 .24248 .53718 .23014 .52729 Metetra
.027 .55 0 r
.23014 .52729 .24248 .53718 .26036 .5339 .24812 .51931 Metetra
.027 .55 0 r
.24812 .51931 .26036 .5339 .27893 .52729 .26676 .51728 Metetra
.027 .55 0 r
.26676 .51728 .27893 .52729 .29767 .52063 .28493 .50922 Metetra
.027 .55 0 r
.28493 .50922 .29767 .52063 .31587 .5126 .30386 .50241 Metetra
.027 .55 0 r
.30386 .50241 .31587 .5126 .3349 .51052 .32297 .49555 Metetra
.027 .55 0 r
.32297 .49555 .3349 .51052 .35331 .50241 .34147 .49209 Metetra
.027 .55 0 r
.34147 .49209 .35331 .50241 .37263 .49555 .36088 .48513 Metetra
.027 .55 0 r
.36088 .48513 .37263 .49555 .39125 .48735 .3796 .47685 Metetra
.027 .55 0 r
.3796 .47685 .39125 .48735 .41088 .48513 .39931 .46977 Metetra
.027 .55 0 r
.39931 .46977 .41088 .48513 .43069 .47811 .4192 .46745 Metetra
.027 .55 0 r
.4192 .46745 .43069 .47811 .44966 .46977 .43827 .45904 Metetra
.027 .55 0 r
.43827 .45904 .44966 .46977 .46978 .46263 .45848 .45179 Metetra
.084 .573 0 r
.45848 .45179 .46978 .46263 .48888 .4651 .47767 .45423 Metetra
.084 .573 0 r
.47767 .45423 .48888 .4651 .50938 .45787 .49825 .4469 Metetra
.084 .573 0 r
.49825 .4469 .50938 .45787 .52883 .44936 .51782 .4383 Metetra
.084 .573 0 r
.51782 .4383 .52883 .44936 .54966 .4469 .53874 .43084 Metetra
.084 .573 0 r
.53874 .43084 .54966 .4469 .56934 .4383 .55854 .42708 Metetra
.084 .573 0 r
.55854 .42708 .56934 .4383 .59051 .43084 .5798 .41952 Metetra
.084 .573 0 r
.5798 .41952 .59051 .43084 .61187 .42331 .60126 .41188 Metetra
.084 .573 0 r
.60126 .41188 .61187 .42331 .63194 .41952 .62145 .40303 Metetra
.027 .55 0 r
.62145 .40303 .63194 .41952 .65334 .40575 .64298 .39414 Metetra
.027 .55 0 r
.64298 .39414 .65334 .40575 .67521 .39803 .66496 .38631 Metetra
.027 .55 0 r
.66496 .38631 .67521 .39803 .69562 .38913 .68549 .37732 Metetra
.027 .55 0 r
.68549 .37732 .69562 .38913 .71785 .38631 .70783 .37442 Metetra
.027 .55 0 r
.70783 .37442 .71785 .38631 .73851 .37732 .72862 .36533 Metetra
0 .528 .025 r
.72862 .36533 .73851 .37732 .76054 .36322 .75078 .3511 Metetra
0 .528 .025 r
.75078 .3511 .76054 .36322 .78329 .36025 .77366 .34292 Metetra
0 .528 .025 r
.77366 .34292 .78329 .36025 .80431 .3511 .79481 .3388 Metetra
0 .528 .025 r
.79481 .3388 .80431 .3511 .82745 .34292 .81807 .33051 Metetra
0 .505 .073 r
.81807 .33051 .82745 .34292 .85002 .32853 .84079 .31598 Metetra
.027 .55 0 r
.1985 .52996 .21109 .53988 .23014 .52729 .21765 .51728 Metetra
.027 .55 0 r
.21765 .51728 .23014 .52729 .24812 .51931 .23571 .50922 Metetra
.027 .55 0 r
.23571 .50922 .24812 .51931 .26676 .51728 .25442 .50241 Metetra
.027 .55 0 r
.25442 .50241 .26676 .51728 .28493 .50922 .27269 .49899 Metetra
.027 .55 0 r
.27269 .49899 .28493 .50922 .30386 .50241 .29169 .49209 Metetra
.027 .55 0 r
.29169 .49209 .30386 .50241 .32297 .49555 .31087 .48513 Metetra
.027 .55 0 r
.31087 .48513 .32297 .49555 .34147 .49209 .32948 .47685 Metetra
.027 .55 0 r
.32948 .47685 .34147 .49209 .36088 .48513 .34896 .47457 Metetra
.027 .55 0 r
.34896 .47457 .36088 .48513 .3796 .47685 .36778 .46621 Metetra
.027 .55 0 r
.36778 .46621 .3796 .47685 .39931 .46977 .38757 .45904 Metetra
.027 .55 0 r
.38757 .45904 .39931 .46977 .4192 .46745 .40661 .45542 Metetra
.027 .55 0 r
.40661 .45542 .4192 .46745 .43827 .45904 .42673 .44815 Metetra
.027 .55 0 r
.42673 .44815 .43827 .45904 .45848 .45179 .44703 .4408 Metetra
.084 .573 0 r
.44703 .4408 .45848 .45179 .47767 .45423 .46629 .4383 Metetra
.084 .573 0 r
.46629 .4383 .47767 .45423 .49825 .4469 .48697 .43577 Metetra
.084 .573 0 r
.48697 .43577 .49825 .4469 .51782 .4383 .50665 .42708 Metetra
.084 .573 0 r
.50665 .42708 .51782 .4383 .53874 .43084 .52766 .41952 Metetra
.084 .573 0 r
.52766 .41952 .53874 .43084 .55854 .42708 .54758 .41073 Metetra
.084 .573 0 r
.54758 .41073 .55854 .42708 .5798 .41952 .56894 .40803 Metetra
.084 .573 0 r
.56894 .40803 .5798 .41952 .60126 .41188 .5905 .40029 Metetra
.084 .573 0 r
.5905 .40029 .60126 .41188 .62145 .40303 .61207 .39135 Metetra
.027 .55 0 r
.61207 .39135 .62145 .40303 .64298 .39414 .63247 .38237 Metetra
.027 .55 0 r
.63247 .38237 .64298 .39414 .66496 .38631 .65456 .37442 Metetra
.027 .55 0 r
.65456 .37442 .66496 .38631 .68549 .37732 .67522 .36533 Metetra
.027 .55 0 r
.67522 .36533 .68549 .37732 .70783 .37442 .69767 .35724 Metetra
.027 .55 0 r
.69767 .35724 .70783 .37442 .72862 .36533 .71858 .35317 Metetra
0 .528 .025 r
.71858 .35317 .72862 .36533 .75078 .3511 .74088 .3388 Metetra
0 .528 .025 r
.74088 .3388 .75078 .3511 .77366 .34292 .76388 .33051 Metetra
0 .528 .025 r
.76388 .33051 .77366 .34292 .79481 .3388 .78517 .32115 Metetra
0 .528 .025 r
.78517 .32115 .79481 .3388 .81807 .33051 .80856 .3179 Metetra
0 .505 .073 r
.80856 .3179 .81807 .33051 .84079 .31598 .83141 .30324 Metetra
.027 .55 0 r
.18573 .51522 .1985 .52996 .21765 .51728 .20498 .50712 Metetra
.027 .55 0 r
.20498 .50712 .21765 .51728 .23571 .50922 .22313 .49899 Metetra
.027 .55 0 r
.22313 .49899 .23571 .50922 .25442 .50241 .24192 .49209 Metetra
.027 .55 0 r
.24192 .49209 .25442 .50241 .27269 .49899 .26028 .48387 Metetra
.027 .55 0 r
.26028 .48387 .27269 .49899 .29169 .49209 .27936 .48163 Metetra
.027 .55 0 r
.27936 .48163 .29169 .49209 .31087 .48513 .29793 .47332 Metetra
.027 .55 0 r
.29793 .47332 .31087 .48513 .32948 .47685 .31732 .46621 Metetra
.027 .55 0 r
.31732 .46621 .32948 .47685 .34896 .47457 .33688 .46386 Metetra
.027 .55 0 r
.33688 .46386 .34896 .47457 .36778 .46621 .3558 .45542 Metetra
.027 .55 0 r
.3558 .45542 .36778 .46621 .38757 .45904 .37568 .44815 Metetra
.027 .55 0 r
.37568 .44815 .38757 .45904 .40661 .45542 .39482 .43961 Metetra
.027 .55 0 r
.39482 .43961 .40661 .45542 .42673 .44815 .41502 .43711 Metetra
.027 .55 0 r
.41502 .43711 .42673 .44815 .44703 .4408 .43541 .42966 Metetra
.084 .573 0 r
.43541 .42966 .44703 .4408 .46629 .4383 .45475 .42708 Metetra
.084 .573 0 r
.45475 .42708 .46629 .4383 .48697 .43577 .47552 .41952 Metetra
.084 .573 0 r
.47552 .41952 .48697 .43577 .50665 .42708 .49531 .41571 Metetra
.084 .573 0 r
.49531 .41571 .50665 .42708 .52766 .41952 .51643 .40803 Metetra
.084 .573 0 r
.51643 .40803 .52766 .41952 .54758 .41073 .53646 .39916 Metetra
.084 .573 0 r
.53646 .39916 .54758 .41073 .56894 .40803 .55918 .39639 Metetra
.084 .573 0 r
.55918 .39639 .56894 .40803 .5905 .40029 .57946 .38742 Metetra
.084 .573 0 r
.57946 .38742 .5905 .40029 .61207 .39135 .60128 .37949 Metetra
.027 .55 0 r
.60128 .37949 .61207 .39135 .63247 .38237 .62181 .36533 Metetra
.027 .55 0 r
.62181 .36533 .63247 .38237 .65456 .37442 .64244 .3613 Metetra
.027 .55 0 r
.64244 .3613 .65456 .37442 .67522 .36533 .66479 .35317 Metetra
.027 .55 0 r
.66479 .35317 .67522 .36533 .69767 .35724 .68736 .34496 Metetra
.027 .55 0 r
.68736 .34496 .69767 .35724 .71858 .35317 .7084 .33567 Metetra
0 .528 .025 r
.7084 .33567 .71858 .35317 .74088 .3388 .73084 .32633 Metetra
0 .528 .025 r
.73084 .32633 .74088 .3388 .76388 .33051 .75396 .3179 Metetra
0 .528 .025 r
.75396 .3179 .76388 .33051 .78517 .32115 .77538 .30845 Metetra
0 .528 .025 r
.77538 .30845 .78517 .32115 .80856 .3179 .79889 .29987 Metetra
0 .505 .073 r
.79889 .29987 .80856 .3179 .83141 .30324 .8219 .2903 Metetra
.027 .55 0 r
.17358 .49899 .18573 .51522 .20498 .50712 .19171 .49082 Metetra
.027 .55 0 r
.19171 .49082 .20498 .50712 .22313 .49899 .21039 .48862 Metetra
.027 .55 0 r
.21039 .48862 .22313 .49899 .24192 .49209 .22924 .48163 Metetra
.027 .55 0 r
.22924 .48163 .24192 .49209 .26028 .48387 .24833 .46731 Metetra
.027 .55 0 r
.24833 .46731 .26028 .48387 .27936 .48163 .26744 .46498 Metetra
.027 .55 0 r
.26744 .46498 .27936 .48163 .29793 .47332 .28673 .45781 Metetra
.027 .55 0 r
.28673 .45781 .29793 .47332 .31732 .46621 .3055 .44938 Metetra
.027 .55 0 r
.3055 .44938 .31732 .46621 .33688 .46386 .32509 .44209 Metetra
.027 .55 0 r
.32509 .44209 .33688 .46386 .3558 .45542 .34408 .43842 Metetra
.027 .55 0 r
.34408 .43842 .3558 .45542 .37568 .44815 .36399 .43103 Metetra
.027 .55 0 r
.36399 .43103 .37568 .44815 .39482 .43961 .38287 .42848 Metetra
.027 .55 0 r
.38287 .42848 .39482 .43961 .41502 .43711 .40315 .42098 Metetra
.027 .55 0 r
.40315 .42098 .41502 .43711 .43541 .42966 .42363 .41836 Metetra
.084 .573 0 r
.42363 .41836 .43541 .42966 .45475 .42708 .44325 .40959 Metetra
.084 .573 0 r
.44325 .40959 .45475 .42708 .47552 .41952 .46406 .4019 Metetra
.084 .573 0 r
.46406 .4019 .47552 .41952 .49531 .41571 .48392 .39803 Metetra
.084 .573 0 r
.48392 .39803 .49531 .41571 .51643 .40803 .50629 .39639 Metetra
.084 .573 0 r
.50629 .39639 .51643 .40803 .53646 .39916 .52644 .38742 Metetra
.084 .573 0 r
.52644 .38742 .53646 .39916 .55918 .39639 .54801 .37949 Metetra
.084 .573 0 r
.54801 .37949 .55918 .39639 .57946 .38742 .56841 .3755 Metetra
.084 .573 0 r
.56841 .3755 .57946 .38742 .60128 .37949 .59034 .36747 Metetra
.027 .55 0 r
.59034 .36747 .60128 .37949 .62181 .36533 .61099 .35317 Metetra
.027 .55 0 r
.61099 .35317 .62181 .36533 .64244 .3613 .63175 .34394 Metetra
.027 .55 0 r
.63175 .34394 .64244 .3613 .66479 .35317 .65421 .34083 Metetra
.027 .55 0 r
.65421 .34083 .66479 .35317 .68736 .34496 .67652 .32633 Metetra
.027 .55 0 r
.67652 .32633 .68736 .34496 .7084 .33567 .69764 .31694 Metetra
0 .528 .025 r
.69764 .31694 .7084 .33567 .73084 .32633 .72065 .30845 Metetra
0 .505 .073 r
.72065 .30845 .73084 .32633 .75396 .3179 .74334 .29895 Metetra
0 .505 .073 r
.74334 .29895 .75396 .3179 .77538 .30845 .76484 .2894 Metetra
0 .505 .073 r
.76484 .2894 .77538 .30845 .79889 .29987 .78842 .28068 Metetra
0 .505 .073 r
.78842 .28068 .79889 .29987 .8219 .2903 .81152 .27102 Metetra
.027 .55 0 r
.1605 .48862 .17358 .49899 .19171 .49082 .17872 .48037 Metetra
.027 .55 0 r
.17872 .48037 .19171 .49082 .21039 .48862 .19747 .47811 Metetra
.027 .55 0 r
.19747 .47811 .21039 .48862 .22924 .48163 .21639 .47102 Metetra
0 .528 .025 r
.21639 .47102 .22924 .48163 .24833 .46731 .23561 .4566 Metetra
0 .528 .025 r
.23561 .4566 .24833 .46731 .26744 .46498 .2548 .44938 Metetra
0 .528 .025 r
.2548 .44938 .26744 .46498 .28673 .45781 .27416 .44694 Metetra
0 .528 .025 r
.27416 .44694 .28673 .45781 .3055 .44938 .29303 .43842 Metetra
0 .528 .025 r
.29303 .43842 .3055 .44938 .32509 .44209 .3127 .43103 Metetra
0 .528 .025 r
.3127 .43103 .32509 .44209 .34408 .43842 .33179 .42242 Metetra
0 .528 .025 r
.33179 .42242 .34408 .43842 .36399 .43103 .35179 .41982 Metetra
.027 .55 0 r
.35179 .41982 .36399 .43103 .38287 .42848 .37074 .4172 Metetra
.027 .55 0 r
.37074 .4172 .38287 .42848 .40315 .42098 .39111 .40959 Metetra
.027 .55 0 r
.39111 .40959 .40315 .42098 .42363 .41836 .4107 .40575 Metetra
.027 .55 0 r
.4107 .40575 .42363 .41836 .44325 .40959 .43141 .39803 Metetra
.027 .55 0 r
.43141 .39803 .44325 .40959 .46406 .4019 .45232 .39024 Metetra
.027 .55 0 r
.45232 .39024 .46406 .4019 .48392 .39803 .47229 .38127 Metetra
.084 .573 0 r
.47229 .38127 .48392 .39803 .50629 .39639 .49474 .38457 Metetra
.084 .573 0 r
.49474 .38457 .50629 .39639 .52644 .38742 .51501 .3755 Metetra
.084 .573 0 r
.51501 .3755 .52644 .38742 .54801 .37949 .53668 .36747 Metetra
.084 .573 0 r
.53668 .36747 .54801 .37949 .56841 .3755 .5572 .35829 Metetra
.084 .573 0 r
.5572 .35829 .56841 .3755 .59034 .36747 .57924 .35526 Metetra
.027 .55 0 r
.57924 .35526 .59034 .36747 .61099 .35317 .60131 .34083 Metetra
.027 .55 0 r
.60131 .34083 .61099 .35317 .63175 .34394 .62219 .3315 Metetra
.027 .55 0 r
.62219 .3315 .63175 .34394 .65421 .34083 .64477 .3231 Metetra
0 .528 .025 r
.64477 .3231 .65421 .34083 .67652 .32633 .66592 .31366 Metetra
0 .528 .025 r
.66592 .31366 .67652 .32633 .69764 .31694 .68717 .30417 Metetra
0 .528 .025 r
.68717 .30417 .69764 .31694 .72065 .30845 .7103 .29555 Metetra
0 .505 .073 r
.7103 .29555 .72065 .30845 .74334 .29895 .73314 .28595 Metetra
0 .505 .073 r
.73314 .28595 .74334 .29895 .76484 .2894 .75478 .27629 Metetra
0 .505 .073 r
.75478 .27629 .76484 .2894 .78842 .28068 .77849 .26745 Metetra
0 .505 .073 r
.77849 .26745 .78842 .28068 .81152 .27102 .80173 .25235 Metetra
.027 .55 0 r
.14723 .47811 .1605 .48862 .17872 .48037 .16555 .46977 Metetra
.027 .55 0 r
.16555 .46977 .17872 .48037 .19747 .47811 .18437 .46263 Metetra
.027 .55 0 r
.18437 .46263 .19747 .47811 .21639 .47102 .20336 .46026 Metetra
0 .528 .025 r
.20336 .46026 .21639 .47102 .23561 .4566 .22272 .44574 Metetra
0 .528 .025 r
.22272 .44574 .23561 .4566 .2548 .44938 .24198 .43842 Metetra
0 .528 .025 r
.24198 .43842 .2548 .44938 .27416 .44694 .26142 .43103 Metetra
0 .528 .025 r
.26142 .43103 .27416 .44694 .29303 .43842 .28038 .42731 Metetra
0 .528 .025 r
.28038 .42731 .29303 .43842 .3127 .43103 .30014 .41982 Metetra
0 .528 .025 r
.30014 .41982 .3127 .43103 .33179 .42242 .31933 .41112 Metetra
0 .528 .025 r
.31933 .41112 .33179 .42242 .35179 .41982 .33941 .40845 Metetra
.027 .55 0 r
.33941 .40845 .35179 .41982 .37074 .4172 .35844 .40575 Metetra
.027 .55 0 r
.35844 .40575 .37074 .4172 .39111 .40959 .3789 .39803 Metetra
.027 .55 0 r
.3789 .39803 .39111 .40959 .4107 .40575 .3986 .38913 Metetra
.027 .55 0 r
.3986 .38913 .4107 .40575 .43141 .39803 .4194 .38631 Metetra
.027 .55 0 r
.4194 .38631 .43141 .39803 .45232 .39024 .4404 .3784 Metetra
.027 .55 0 r
.4404 .3784 .45232 .39024 .47229 .38127 .46049 .36935 Metetra
.084 .573 0 r
.46049 .36935 .47229 .38127 .49474 .38457 .48184 .3664 Metetra
.084 .573 0 r
.48184 .3664 .49474 .38457 .51501 .3755 .5034 .36342 Metetra
.084 .573 0 r
.5034 .36342 .51501 .3755 .53668 .36747 .52518 .35526 Metetra
.084 .573 0 r
.52518 .35526 .53668 .36747 .5572 .35829 .54582 .34599 Metetra
.084 .573 0 r
.54582 .34599 .5572 .35829 .57924 .35526 .56797 .33769 Metetra
.027 .55 0 r
.56797 .33769 .57924 .35526 .60131 .34083 .59017 .3283 Metetra
.027 .55 0 r
.59017 .3283 .60131 .34083 .62219 .3315 .61118 .31887 Metetra
.027 .55 0 r
.61118 .31887 .62219 .3315 .64477 .3231 .63388 .31035 Metetra
0 .528 .025 r
.63388 .31035 .64477 .3231 .66592 .31366 .65516 .30081 Metetra
0 .528 .025 r
.65516 .30081 .66592 .31366 .68717 .30417 .67654 .29121 Metetra
0 .528 .025 r
.67654 .29121 .68717 .30417 .7103 .29555 .6998 .28247 Metetra
0 .505 .073 r
.6998 .28247 .7103 .29555 .73314 .28595 .72279 .26745 Metetra
0 .505 .073 r
.72279 .26745 .73314 .28595 .75478 .27629 .74456 .26299 Metetra
0 .505 .073 r
.74456 .26299 .75478 .27629 .77849 .26745 .7684 .25401 Metetra
0 .505 .073 r
.7684 .25401 .77849 .26745 .80173 .25235 .7918 .23877 Metetra
.027 .55 0 r
.13379 .46745 .14723 .47811 .16555 .46977 .1522 .45904 Metetra
.027 .55 0 r
.1522 .45904 .16555 .46977 .18437 .46263 .17109 .45179 Metetra
.027 .55 0 r
.17109 .45179 .18437 .46263 .20336 .46026 .18971 .44329 Metetra
0 .528 .025 r
.18971 .44329 .20336 .46026 .22272 .44574 .20964 .43474 Metetra
0 .528 .025 r
.20964 .43474 .22272 .44574 .24198 .43842 .22898 .42731 Metetra
0 .528 .025 r
.22898 .42731 .24198 .43842 .26142 .43103 .24791 .41867 Metetra
0 .528 .025 r
.24791 .41867 .26142 .43103 .28038 .42731 .26756 .41605 Metetra
0 .528 .025 r
.26756 .41605 .28038 .42731 .30014 .41982 .2874 .40845 Metetra
0 .528 .025 r
.2874 .40845 .30014 .41982 .31933 .41112 .3067 .39966 Metetra
0 .528 .025 r
.3067 .39966 .31933 .41112 .33941 .40845 .32686 .39192 Metetra
.027 .55 0 r
.32686 .39192 .33941 .40845 .35844 .40575 .34596 .39414 Metetra
.027 .55 0 r
.34596 .39414 .35844 .40575 .3789 .39803 .36651 .38631 Metetra
.027 .55 0 r
.36651 .38631 .3789 .39803 .3986 .38913 .38632 .37732 Metetra
.027 .55 0 r
.38632 .37732 .3986 .38913 .4194 .38631 .40721 .36935 Metetra
.027 .55 0 r
.40721 .36935 .4194 .38631 .4404 .3784 .42727 .36533 Metetra
.027 .55 0 r
.42727 .36533 .4404 .3784 .46049 .36935 .44852 .35724 Metetra
.084 .573 0 r
.44852 .35724 .46049 .36935 .48184 .3664 .46997 .35421 Metetra
.084 .573 0 r
.46997 .35421 .48184 .3664 .5034 .36342 .49163 .34599 Metetra
.084 .573 0 r
.49163 .34599 .5034 .36342 .52518 .35526 .51351 .34287 Metetra
.084 .573 0 r
.51351 .34287 .52518 .35526 .54582 .34599 .53428 .3335 Metetra
.084 .573 0 r
.53428 .3335 .54582 .34599 .56797 .33769 .55653 .32507 Metetra
.027 .55 0 r
.55653 .32507 .56797 .33769 .59017 .3283 .57887 .31559 Metetra
.027 .55 0 r
.57887 .31559 .59017 .3283 .61118 .31887 .60002 .30606 Metetra
.027 .55 0 r
.60002 .30606 .61118 .31887 .63388 .31035 .62282 .29741 Metetra
0 .528 .025 r
.62282 .29741 .63388 .31035 .65516 .30081 .64424 .28247 Metetra
0 .528 .025 r
.64424 .28247 .65516 .30081 .67654 .29121 .66708 .27806 Metetra
0 .528 .025 r
.66708 .27806 .67654 .29121 .6998 .28247 .69047 .26918 Metetra
0 .505 .073 r
.69047 .26918 .6998 .28247 .72279 .26745 .71227 .25401 Metetra
0 .505 .073 r
.71227 .25401 .72279 .26745 .74456 .26299 .73419 .24413 Metetra
0 .505 .073 r
.73419 .24413 .74456 .26299 .7684 .25401 .75815 .24036 Metetra
0 .505 .073 r
.75815 .24036 .7684 .25401 .7918 .23877 .78171 .22497 Metetra
.027 .55 0 r
.12016 .45179 .13379 .46745 .1522 .45904 .13867 .44815 Metetra
.027 .55 0 r
.13867 .44815 .1522 .45904 .17109 .45179 .15762 .4408 Metetra
.027 .55 0 r
.15762 .4408 .17109 .45179 .18971 .44329 .17635 .43221 Metetra
0 .528 .025 r
.17635 .43221 .18971 .44329 .20964 .43474 .19639 .42358 Metetra
0 .528 .025 r
.19639 .42358 .20964 .43474 .22898 .42731 .21579 .41605 Metetra
0 .528 .025 r
.21579 .41605 .22898 .42731 .24791 .41867 .23483 .40731 Metetra
0 .528 .025 r
.23483 .40731 .24791 .41867 .26756 .41605 .25456 .39966 Metetra
0 .528 .025 r
.25456 .39966 .26756 .41605 .2874 .40845 .27447 .39691 Metetra
0 .528 .025 r
.27447 .39691 .2874 .40845 .3067 .39966 .29388 .38803 Metetra
0 .528 .025 r
.29388 .38803 .3067 .39966 .32686 .39192 .31413 .38019 Metetra
.027 .55 0 r
.31413 .38019 .32686 .39192 .34596 .39414 .33331 .37732 Metetra
.027 .55 0 r
.33331 .37732 .34596 .39414 .36651 .38631 .35394 .37442 Metetra
.027 .55 0 r
.35394 .37442 .36651 .38631 .38632 .37732 .37387 .36533 Metetra
.027 .55 0 r
.37387 .36533 .38632 .37732 .40721 .36935 .39613 .35724 Metetra
.027 .55 0 r
.39613 .35724 .40721 .36935 .42727 .36533 .41631 .34805 Metetra
.027 .55 0 r
.41631 .34805 .42727 .36533 .44852 .35724 .43765 .34496 Metetra
.084 .573 0 r
.43765 .34496 .44852 .35724 .46997 .35421 .45792 .34185 Metetra
.084 .573 0 r
.45792 .34185 .46997 .35421 .49163 .34599 .47968 .3335 Metetra
.084 .573 0 r
.47968 .3335 .49163 .34599 .51351 .34287 .50042 .3293 Metetra
.084 .573 0 r
.50042 .3293 .51351 .34287 .53428 .3335 .52256 .32083 Metetra
.084 .573 0 r
.52256 .32083 .53428 .3335 .55653 .32507 .54492 .31227 Metetra
.027 .55 0 r
.54492 .31227 .55653 .32507 .57887 .31559 .56598 .29648 Metetra
.027 .55 0 r
.56598 .29648 .57887 .31559 .60002 .30606 .58868 .29305 Metetra
.027 .55 0 r
.58868 .29305 .60002 .30606 .62282 .29741 .6116 .28427 Metetra
0 .528 .025 r
.6116 .28427 .62282 .29741 .64424 .28247 .63448 .26918 Metetra
0 .528 .025 r
.63448 .26918 .64424 .28247 .66708 .27806 .65614 .25936 Metetra
0 .528 .025 r
.65614 .25936 .66708 .27806 .69047 .26918 .67965 .25568 Metetra
0 .505 .073 r
.67965 .25568 .69047 .26918 .71227 .25401 .70159 .24036 Metetra
0 .505 .073 r
.70159 .24036 .71227 .25401 .73419 .24413 .72365 .23037 Metetra
0 .505 .073 r
.72365 .23037 .73419 .24413 .75815 .24036 .74775 .22651 Metetra
0 .505 .073 r
.74775 .22651 .75815 .24036 .78171 .22497 .77146 .21095 Metetra
.027 .55 0 r
.10634 .4408 .12016 .45179 .13867 .44815 .12494 .43221 Metetra
.027 .55 0 r
.12494 .43221 .13867 .44815 .15762 .4408 .14397 .42966 Metetra
.027 .55 0 r
.14397 .42966 .15762 .4408 .17635 .43221 .16279 .42098 Metetra
0 .528 .025 r
.16279 .42098 .17635 .43221 .19639 .42358 .18294 .40731 Metetra
0 .528 .025 r
.18294 .40731 .19639 .42358 .21579 .41605 .20242 .40462 Metetra
0 .528 .025 r
.20242 .40462 .21579 .41605 .23483 .40731 .22156 .3958 Metetra
0 .528 .025 r
.22156 .3958 .23483 .40731 .25456 .39966 .24137 .38803 Metetra
0 .528 .025 r
.24137 .38803 .25456 .39966 .27447 .39691 .26074 .3791 Metetra
0 .528 .025 r
.26074 .3791 .27447 .39691 .29388 .38803 .28088 .37624 Metetra
0 .528 .025 r
.28088 .37624 .29388 .38803 .31413 .38019 .30121 .36828 Metetra
.027 .55 0 r
.30121 .36828 .31413 .38019 .33331 .37732 .32047 .36533 Metetra
.027 .55 0 r
.32047 .36533 .33331 .37732 .35394 .37442 .34247 .35724 Metetra
.027 .55 0 r
.34247 .35724 .35394 .37442 .37387 .36533 .36251 .35317 Metetra
.027 .55 0 r
.36251 .35317 .37387 .36533 .39613 .35724 .38359 .34496 Metetra
.027 .55 0 r
.38359 .34496 .39613 .35724 .41631 .34805 .40389 .33567 Metetra
.027 .55 0 r
.40389 .33567 .41631 .34805 .43765 .34496 .42533 .3325 Metetra
.084 .573 0 r
.42533 .3325 .43765 .34496 .45792 .34185 .44569 .3293 Metetra
.084 .573 0 r
.44569 .3293 .45792 .34185 .47968 .3335 .46755 .32083 Metetra
.084 .573 0 r
.46755 .32083 .47968 .3335 .50042 .3293 .48842 .31131 Metetra
.084 .573 0 r
.48842 .31131 .50042 .3293 .52256 .32083 .51066 .30796 Metetra
.084 .573 0 r
.51066 .30796 .52256 .32083 .54492 .31227 .53314 .29928 Metetra
.027 .55 0 r
.53314 .29928 .54492 .31227 .56598 .29648 .55436 .28336 Metetra
.027 .55 0 r
.55436 .28336 .56598 .29648 .58868 .29305 .57716 .27451 Metetra
.027 .55 0 r
.57716 .27451 .58868 .29305 .6116 .28427 .60021 .27092 Metetra
0 .528 .025 r
.60021 .27092 .6116 .28427 .63448 .26918 .62164 .25484 Metetra
0 .528 .025 r
.62164 .25484 .63448 .26918 .65614 .25936 .64503 .24575 Metetra
0 .528 .025 r
.64503 .24575 .65614 .25936 .67965 .25568 .66866 .24198 Metetra
0 .505 .073 r
.66866 .24198 .67965 .25568 .70159 .24036 .68897 .22574 Metetra
0 .505 .073 r
.68897 .22574 .70159 .24036 .72365 .23037 .71431 .2164 Metetra
0 .505 .073 r
.71431 .2164 .72365 .23037 .74775 .22651 .73855 .20696 Metetra
0 .505 .073 r
.73855 .20696 .74775 .22651 .77146 .21095 .75907 .19602 Metetra
.027 .55 0 r
.09232 .43458 .10634 .4408 .12494 .43221 .11128 .42708 Metetra
.027 .55 0 r
.11128 .42708 .12494 .43221 .14397 .42966 .13012 .42331 Metetra
.027 .55 0 r
.13012 .42331 .14397 .42966 .16279 .42098 .14939 .41571 Metetra
.027 .55 0 r
.14939 .41571 .16279 .42098 .18294 .40731 .16846 .4019 Metetra
.027 .55 0 r
.16846 .4019 .18294 .40731 .20242 .40462 .18761 .39303 Metetra
.027 .55 0 r
.18761 .39303 .20242 .40462 .22156 .3958 .20735 .39024 Metetra
.027 .55 0 r
.20735 .39024 .22156 .3958 .24137 .38803 .22727 .38237 Metetra
.027 .55 0 r
.22727 .38237 .24137 .38803 .26074 .3791 .2468 .37334 Metetra
.027 .55 0 r
.2468 .37334 .26074 .3791 .28088 .37624 .26833 .36533 Metetra
.027 .55 0 r
.26833 .36533 .28088 .37624 .30121 .36828 .2881 .3613 Metetra
.027 .55 0 r
.2881 .3613 .30121 .36828 .32047 .36533 .30872 .35317 Metetra
.027 .55 0 r
.30872 .35317 .32047 .36533 .34247 .35724 .32873 .34394 Metetra
.027 .55 0 r
.32873 .34394 .34247 .35724 .36251 .35317 .3497 .34083 Metetra
.027 .55 0 r
.3497 .34083 .36251 .35317 .38359 .34496 .36958 .33769 Metetra
.027 .55 0 r
.36958 .33769 .38359 .34496 .40389 .33567 .39096 .3293 Metetra
.027 .55 0 r
.39096 .3293 .40389 .33567 .42533 .3325 .41255 .32083 Metetra
.084 .573 0 r
.41255 .32083 .42533 .3325 .44569 .3293 .43327 .31656 Metetra
.084 .573 0 r
.43327 .31656 .44569 .3293 .46755 .32083 .45524 .30796 Metetra
.084 .573 0 r
.45524 .30796 .46755 .32083 .48842 .31131 .47623 .29834 Metetra
.084 .573 0 r
.47623 .29834 .48842 .31131 .51066 .30796 .49859 .28958 Metetra
.084 .573 0 r
.49859 .28958 .51066 .30796 .53314 .29928 .52117 .28608 Metetra
.027 .55 0 r
.52117 .28608 .53314 .29928 .55436 .28336 .54255 .27005 Metetra
.027 .55 0 r
.54255 .27005 .55436 .28336 .57716 .27451 .56548 .26106 Metetra
.027 .55 0 r
.56548 .26106 .57716 .27451 .60021 .27092 .58864 .25737 Metetra
.027 .55 0 r
.58864 .25737 .60021 .27092 .62164 .25484 .61046 .24739 Metetra
.027 .55 0 r
.61046 .24739 .62164 .25484 .64503 .24575 .63403 .23817 Metetra
0 .528 .025 r
.63403 .23817 .64503 .24575 .66866 .24198 .65751 .22261 Metetra
0 .528 .025 r
.65751 .22261 .66866 .24198 .68897 .22574 .67974 .2179 Metetra
0 .505 .073 r
.67974 .2179 .68897 .22574 .71431 .2164 .70392 .20843 Metetra
0 .505 .073 r
.70392 .20843 .71431 .2164 .73855 .20696 .72645 .19814 Metetra
0 .505 .073 r
.72645 .19814 .73855 .20696 .75907 .19602 .75048 .18226 Metetra
.084 .573 0 r
.0781 .42331 .09232 .43458 .11128 .42708 .09713 .41571 Metetra
.084 .573 0 r
.09713 .41571 .11128 .42708 .13012 .42331 .11607 .40689 Metetra
.084 .573 0 r
.11607 .40689 .13012 .42331 .14939 .41571 .13542 .40417 Metetra
.027 .55 0 r
.13542 .40417 .14939 .41571 .16846 .4019 .15458 .39024 Metetra
.027 .55 0 r
.15458 .39024 .16846 .4019 .18761 .39303 .17384 .38127 Metetra
.027 .55 0 r
.17384 .38127 .18761 .39303 .20735 .39024 .19492 .37334 Metetra
.027 .55 0 r
.19492 .37334 .20735 .39024 .22727 .38237 .21441 .36935 Metetra
.027 .55 0 r
.21441 .36935 .22727 .38237 .2468 .37334 .23457 .3613 Metetra
.027 .55 0 r
.23457 .3613 .2468 .37334 .26833 .36533 .25492 .35317 Metetra
.027 .55 0 r
.25492 .35317 .26833 .36533 .2881 .3613 .2748 .34908 Metetra
.027 .55 0 r
.2748 .34908 .2881 .3613 .30872 .35317 .29551 .34083 Metetra
.027 .55 0 r
.29551 .34083 .30872 .35317 .32873 .34394 .31563 .3315 Metetra
.027 .55 0 r
.31563 .3315 .32873 .34394 .3497 .34083 .33669 .3231 Metetra
.084 .573 0 r
.33669 .3231 .3497 .34083 .36958 .33769 .35666 .32507 Metetra
.084 .573 0 r
.35666 .32507 .36958 .33769 .39096 .3293 .37813 .31656 Metetra
.084 .573 0 r
.37813 .31656 .39096 .3293 .41255 .32083 .39982 .30796 Metetra
.084 .573 0 r
.39982 .30796 .41255 .32083 .43327 .31656 .42067 .29834 Metetra
.084 .573 0 r
.42067 .29834 .43327 .31656 .45524 .30796 .44274 .2949 Metetra
.084 .573 0 r
.44274 .2949 .45524 .30796 .47623 .29834 .46386 .28517 Metetra
.084 .573 0 r
.46386 .28517 .47623 .29834 .49859 .28958 .48632 .27628 Metetra
.084 .573 0 r
.48632 .27628 .49859 .28958 .52117 .28608 .50772 .26643 Metetra
.027 .55 0 r
.50772 .26643 .52117 .28608 .54255 .27005 .53056 .25652 Metetra
.027 .55 0 r
.53056 .25652 .54255 .27005 .56548 .26106 .5536 .24739 Metetra
.027 .55 0 r
.5536 .24739 .56548 .26106 .58864 .25737 .57539 .23736 Metetra
.027 .55 0 r
.57539 .23736 .58864 .25737 .61046 .24739 .59885 .23352 Metetra
.027 .55 0 r
.59885 .23352 .61046 .24739 .63403 .23817 .62254 .22415 Metetra
0 .528 .025 r
.62254 .22415 .63403 .23817 .65751 .22261 .64449 .20769 Metetra
0 .528 .025 r
.64449 .20769 .65751 .22261 .67974 .2179 .66855 .19814 Metetra
0 .528 .025 r
.66855 .19814 .67974 .2179 .70392 .20843 .69287 .19402 Metetra
0 .528 .025 r
.69287 .19402 .70392 .20843 .72645 .19814 .71555 .18361 Metetra
0 .505 .073 r
.71555 .18361 .72645 .19814 .75048 .18226 .73974 .16757 Metetra
.084 .573 0 r
.06368 .41188 .0781 .42331 .09713 .41571 .08278 .40417 Metetra
.084 .573 0 r
.08278 .40417 .09713 .41571 .11607 .40689 .10182 .39526 Metetra
.084 .573 0 r
.10182 .39526 .11607 .40689 .13542 .40417 .12124 .38742 Metetra
.027 .55 0 r
.12124 .38742 .13542 .40417 .15458 .39024 .14177 .3784 Metetra
.027 .55 0 r
.14177 .3784 .15458 .39024 .17384 .38127 .16114 .36935 Metetra
.027 .55 0 r
.16114 .36935 .17384 .38127 .19492 .37334 .18104 .3613 Metetra
.027 .55 0 r
.18104 .3613 .19492 .37334 .21441 .36935 .20064 .35724 Metetra
.027 .55 0 r
.20064 .35724 .21441 .36935 .23457 .3613 .22088 .34908 Metetra
.027 .55 0 r
.22088 .34908 .23457 .3613 .25492 .35317 .24131 .34083 Metetra
.027 .55 0 r
.24131 .34083 .25492 .35317 .2748 .34908 .26131 .3315 Metetra
.027 .55 0 r
.26131 .3315 .2748 .34908 .29551 .34083 .2821 .3283 Metetra
.027 .55 0 r
.2821 .3283 .29551 .34083 .31563 .3315 .30234 .31887 Metetra
.027 .55 0 r
.30234 .31887 .31563 .3315 .33669 .3231 .32349 .31035 Metetra
.084 .573 0 r
.32349 .31035 .33669 .3231 .35666 .32507 .34354 .30701 Metetra
.084 .573 0 r
.34354 .30701 .35666 .32507 .37813 .31656 .36511 .30363 Metetra
.084 .573 0 r
.36511 .30363 .37813 .31656 .39982 .30796 .38592 .29397 Metetra
.084 .573 0 r
.38592 .29397 .39982 .30796 .42067 .29834 .40788 .28517 Metetra
.084 .573 0 r
.40788 .28517 .42067 .29834 .44274 .2949 .43005 .27628 Metetra
.084 .573 0 r
.43005 .27628 .44274 .2949 .46386 .28517 .4513 .2718 Metetra
.084 .573 0 r
.4513 .2718 .46386 .28517 .48632 .27628 .47387 .26277 Metetra
.084 .573 0 r
.47387 .26277 .48632 .27628 .50772 .26643 .4954 .25281 Metetra
.027 .55 0 r
.4954 .25281 .50772 .26643 .53056 .25652 .51839 .24279 Metetra
.027 .55 0 r
.51839 .24279 .53056 .25652 .5536 .24739 .54155 .23352 Metetra
.027 .55 0 r
.54155 .23352 .5536 .24739 .57539 .23736 .56348 .22337 Metetra
.027 .55 0 r
.56348 .22337 .57539 .23736 .59885 .23352 .58705 .21393 Metetra
.027 .55 0 r
.58705 .21393 .59885 .23352 .62254 .22415 .61088 .20991 Metetra
0 .528 .025 r
.61088 .20991 .62254 .22415 .64449 .20769 .63299 .19332 Metetra
0 .528 .025 r
.63299 .19332 .64449 .20769 .66855 .19814 .65719 .18361 Metetra
0 .528 .025 r
.65719 .18361 .66855 .19814 .69287 .19402 .68164 .1738 Metetra
0 .528 .025 r
.68164 .1738 .69287 .19402 .71555 .18361 .70447 .16885 Metetra
0 .505 .073 r
.70447 .16885 .71555 .18361 .73974 .16757 .72882 .15265 Metetra
.084 .573 0 r
.04906 .39526 .06368 .41188 .08278 .40417 .06822 .39246 Metetra
.084 .573 0 r
.06822 .39246 .08278 .40417 .10182 .39526 .08736 .38346 Metetra
.084 .573 0 r
.08736 .38346 .10182 .39526 .12124 .38742 .10685 .3755 Metetra
.027 .55 0 r
.10685 .3755 .12124 .38742 .14177 .3784 .1275 .3664 Metetra
.027 .55 0 r
.1275 .3664 .14177 .3784 .16114 .36935 .14698 .35724 Metetra
.027 .55 0 r
.14698 .35724 .16114 .36935 .18104 .3613 .16695 .34908 Metetra
.027 .55 0 r
.16695 .34908 .18104 .3613 .20064 .35724 .18667 .33981 Metetra
.027 .55 0 r
.18667 .33981 .20064 .35724 .22088 .34908 .20698 .33667 Metetra
.027 .55 0 r
.20698 .33667 .22088 .34908 .24131 .34083 .2275 .3283 Metetra
.027 .55 0 r
.2275 .3283 .24131 .34083 .26131 .3315 .24761 .31887 Metetra
.027 .55 0 r
.24761 .31887 .26131 .3315 .2821 .3283 .26849 .31035 Metetra
.027 .55 0 r
.26849 .31035 .2821 .3283 .30234 .31887 .28885 .30606 Metetra
.027 .55 0 r
.28885 .30606 .30234 .31887 .32349 .31035 .31009 .29741 Metetra
.084 .573 0 r
.31009 .29741 .32349 .31035 .34354 .30701 .33072 .28776 Metetra
.084 .573 0 r
.33072 .28776 .34354 .30701 .36511 .30363 .35233 .27895 Metetra
.084 .573 0 r
.35233 .27895 .36511 .30363 .38592 .29397 .37417 .27539 Metetra
.084 .573 0 r
.37417 .27539 .38592 .29397 .40788 .28517 .39522 .26556 Metetra
.084 .573 0 r
.39522 .26556 .40788 .28517 .43005 .27628 .41744 .25652 Metetra
.084 .573 0 r
.41744 .25652 .43005 .27628 .4513 .2718 .43877 .25197 Metetra
.084 .573 0 r
.43877 .25197 .4513 .2718 .47387 .26277 .46139 .24279 Metetra
.084 .573 0 r
.46139 .24279 .47387 .26277 .4954 .25281 .48425 .23352 Metetra
.027 .55 0 r
.48425 .23352 .4954 .25281 .51839 .24279 .50603 .22337 Metetra
.027 .55 0 r
.50603 .22337 .51839 .24279 .54155 .23352 .52929 .21318 Metetra
.027 .55 0 r
.52929 .21318 .54155 .23352 .56348 .22337 .55275 .20365 Metetra
.027 .55 0 r
.55275 .20365 .56348 .22337 .58705 .21393 .57494 .19332 Metetra
.027 .55 0 r
.57494 .19332 .58705 .21393 .61088 .20991 .59882 .18361 Metetra
0 .528 .025 r
.59882 .18361 .61088 .20991 .63299 .19332 .62131 .17872 Metetra
0 .528 .025 r
.62131 .17872 .63299 .19332 .65719 .18361 .64564 .16885 Metetra
0 .528 .025 r
.64564 .16885 .65719 .18361 .68164 .1738 .66843 .15826 Metetra
0 .505 .073 r
.66843 .15826 .68164 .1738 .70447 .16885 .69276 .14762 Metetra
0 .505 .073 r
.69276 .14762 .70447 .16885 .72882 .15265 .71773 .13748 Metetra
.084 .573 0 r
.03422 .38346 .04906 .39526 .06822 .39246 .05345 .38059 Metetra
.084 .573 0 r
.05345 .38059 .06822 .39246 .08736 .38346 .0727 .37149 Metetra
.084 .573 0 r
.0727 .37149 .08736 .38346 .10685 .3755 .09226 .36342 Metetra
.027 .55 0 r
.09226 .36342 .10685 .3755 .1275 .3664 .11302 .34908 Metetra
.027 .55 0 r
.11302 .34908 .1275 .3664 .14698 .35724 .13261 .34496 Metetra
.027 .55 0 r
.13261 .34496 .14698 .35724 .16695 .34908 .15266 .33667 Metetra
.027 .55 0 r
.15266 .33667 .16695 .34908 .18667 .33981 .17248 .32731 Metetra
.027 .55 0 r
.17248 .32731 .18667 .33981 .20698 .33667 .19288 .31887 Metetra
.027 .55 0 r
.19288 .31887 .20698 .33667 .2275 .3283 .21295 .31462 Metetra
.027 .55 0 r
.21295 .31462 .2275 .3283 .24761 .31887 .23371 .30606 Metetra
.027 .55 0 r
.23371 .30606 .24761 .31887 .26849 .31035 .25467 .29741 Metetra
.027 .55 0 r
.25467 .29741 .26849 .31035 .28885 .30606 .27515 .28776 Metetra
.027 .55 0 r
.27515 .28776 .28885 .30606 .31009 .29741 .29649 .28427 Metetra
.027 .55 0 r
.29649 .28427 .31009 .29741 .33072 .28776 .31723 .27451 Metetra
.027 .55 0 r
.31723 .27451 .33072 .28776 .35233 .27895 .33895 .26556 Metetra
.027 .55 0 r
.33895 .26556 .35233 .27895 .37417 .27539 .36088 .26191 Metetra
.027 .55 0 r
.36088 .26191 .37417 .27539 .39522 .26556 .38206 .25197 Metetra
.027 .55 0 r
.38206 .25197 .39522 .26556 .41744 .25652 .40439 .24279 Metetra
.027 .55 0 r
.40439 .24279 .41744 .25652 .43877 .25197 .42585 .23273 Metetra
.027 .55 0 r
.42585 .23273 .43877 .25197 .46139 .24279 .44858 .22885 Metetra
.027 .55 0 r
.44858 .22885 .46139 .24279 .48425 .23352 .47032 .21866 Metetra
.027 .55 0 r
.47032 .21866 .48425 .23352 .50603 .22337 .49347 .20916 Metetra
0 .528 .025 r
.49347 .20916 .50603 .22337 .52929 .21318 .51688 .19332 Metetra
0 .528 .025 r
.51688 .19332 .52929 .21318 .55275 .20365 .53904 .18848 Metetra
0 .528 .025 r
.53904 .18848 .55275 .20365 .57494 .19332 .5628 .17872 Metetra
0 .528 .025 r
.5628 .17872 .57494 .19332 .59882 .18361 .58681 .16885 Metetra
0 .528 .025 r
.58681 .16885 .59882 .18361 .62131 .17872 .60945 .16388 Metetra
0 .528 .025 r
.60945 .16388 .62131 .17872 .64564 .16885 .6339 .15386 Metetra
0 .528 .025 r
.6339 .15386 .64564 .16885 .66843 .15826 .65685 .14314 Metetra
0 .505 .073 r
.65685 .14314 .66843 .15826 .69276 .14762 .68134 .12669 Metetra
0 .505 .073 r
.68134 .12669 .69276 .14762 .71773 .13748 .70646 .12206 Metetra
.084 .573 0 r
.01916 .37149 .03422 .38346 .05345 .38059 .03837 .36235 Metetra
.084 .573 0 r
.03837 .36235 .05345 .38059 .0727 .37149 .05781 .35935 Metetra
.084 .573 0 r
.05781 .35935 .0727 .37149 .09226 .36342 .07745 .35115 Metetra
.027 .55 0 r
.07745 .35115 .09226 .36342 .11302 .34908 .09809 .33567 Metetra
.027 .55 0 r
.09809 .33567 .11302 .34908 .13261 .34496 .11802 .32731 Metetra
.027 .55 0 r
.11802 .32731 .13261 .34496 .15266 .33667 .13815 .32409 Metetra
.027 .55 0 r
.13815 .32409 .15266 .33667 .17248 .32731 .15809 .31462 Metetra
.027 .55 0 r
.15809 .31462 .17248 .32731 .19288 .31887 .17856 .30606 Metetra
.027 .55 0 r
.17856 .30606 .19288 .31887 .21295 .31462 .19875 .29648 Metetra
.027 .55 0 r
.19875 .29648 .21295 .31462 .23371 .30606 .21959 .29305 Metetra
.027 .55 0 r
.21959 .29305 .23371 .30606 .25467 .29741 .24065 .28427 Metetra
.027 .55 0 r
.24065 .28427 .25467 .29741 .27515 .28776 .26125 .27451 Metetra
.027 .55 0 r
.26125 .27451 .27515 .28776 .29649 .28427 .28268 .27092 Metetra
.027 .55 0 r
.28268 .27092 .29649 .28427 .31723 .27451 .30355 .26106 Metetra
.027 .55 0 r
.30355 .26106 .31723 .27451 .33895 .26556 .32536 .25197 Metetra
.027 .55 0 r
.32536 .25197 .33895 .26556 .36088 .26191 .3465 .24198 Metetra
.027 .55 0 r
.3465 .24198 .36088 .26191 .38206 .25197 .3687 .23817 Metetra
.027 .55 0 r
.3687 .23817 .38206 .25197 .40439 .24279 .39114 .22885 Metetra
.027 .55 0 r
.39114 .22885 .40439 .24279 .42585 .23273 .41273 .21866 Metetra
.027 .55 0 r
.41273 .21866 .42585 .23273 .44858 .22885 .43557 .20916 Metetra
.027 .55 0 r
.43557 .20916 .44858 .22885 .47032 .21866 .45745 .20438 Metetra
.027 .55 0 r
.45745 .20438 .47032 .21866 .49347 .20916 .48071 .19473 Metetra
0 .528 .025 r
.48071 .19473 .49347 .20916 .51688 .19332 .50428 .17872 Metetra
0 .528 .025 r
.50428 .17872 .51688 .19332 .53904 .18848 .52658 .1738 Metetra
0 .528 .025 r
.52658 .1738 .53904 .18848 .5628 .17872 .55046 .16388 Metetra
0 .528 .025 r
.55046 .16388 .5628 .17872 .58681 .16885 .5746 .15386 Metetra
0 .528 .025 r
.5746 .15386 .58681 .16885 .60945 .16388 .59739 .14314 Metetra
0 .528 .025 r
.59739 .14314 .60945 .16388 .6339 .15386 .62198 .13862 Metetra
0 .528 .025 r
.62198 .13862 .6339 .15386 .65685 .14314 .64508 .12777 Metetra
0 .505 .073 r
.64508 .12777 .65685 .14314 .68134 .12669 .66974 .11114 Metetra
0 .505 .073 r
.66974 .11114 .68134 .12669 .70646 .12206 .695 .10064 Metetra
0 g
.25 Mabswid
.68871 0 m
.9675 .42834 L
s
.9675 .42834 m
1 .65033 L
s
1 .65033 m
.7013 .24105 L
s
.7013 .24105 m
.68871 0 L
s
.03812 .25182 m
0 .48742 L
s
0 .48742 m
.7013 .24105 L
s
.7013 .24105 m
.68871 0 L
s
.68871 0 m
.03812 .25182 L
s
.03812 .25182 m
.68871 0 L
s
.03812 .25182 m
.04291 .25629 L
s
[(-0.5)] .02856 .24287 1 .93573 Mshowa
.18562 .19554 m
.19017 .20025 L
s
[(-0.4)] .17652 .18612 .96582 1 Mshowa
.34404 .13122 m
.34831 .13619 L
s
[(-0.3)] .3355 .12129 .85992 1 Mshowa
.5104 .06763 m
.51435 .07285 L
s
[(-0.2)] .5025 .05719 .75692 1 Mshowa
.68871 0 m
.69229 .00548 L
s
[(-0.1)] .68155 -0.01096 .65326 1 Mshowa
.125 Mabswid
.06665 .24348 m
.06949 .24619 L
s
.09566 .23083 m
.09848 .23357 L
s
.12605 .2173 m
.12883 .22007 L
s
.15584 .20934 m
.1586 .21213 L
s
.21747 .18224 m
.22017 .18509 L
s
.24792 .16814 m
.25058 .17103 L
s
.27934 .15962 m
.28197 .16253 L
s
.31046 .14524 m
.31306 .14819 L
s
.37588 .12176 m
.37841 .12477 L
s
.40803 .10694 m
.41052 .10998 L
s
.44295 .09239 m
.4454 .09546 L
s
.47586 .08256 m
.47827 .08566 L
s
.54408 .05215 m
.54641 .05531 L
s
.58097 .04223 m
.58325 .04543 L
s
.61545 .02641 m
.61769 .02964 L
s
.65201 .01065 m
.6542 .01391 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 232.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000j2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00_?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0005Ko
oooo002kooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0EOooool00;Cooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0EOooool00;_ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`1Eooooo`00^oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo05Gooooo002kooooo`04o`000?ooooooooooo`0000So
oooo0_l0000;ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0003gooooo002looooo`;o
00002_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo0000?Oooool00<cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool0?Oooool00=?ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0l
ooooo`00doooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000?Ooo
ool00<Sooooo0_l00009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00000mooooo`00aOooool5o`0000[ooooo0_l00009ooooo`?o0000?_ooool00<?ooooo0_l00004
ooooo`;o0000EOooool00<3ooooo0ol00006ooooo`03o`000?oooooo000005Cooooo002mooooo`?o
00002Oooool00ol0003oooooo`00001Dooooo`00TOooool2o`0000Cooooo00Co0000oooooooooooo
oooo1Ol0000Kooooo`;o00003?ooool01?l0003oooooooooool0001Cooooo`00T?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0001Sooooo0ol0000>ooooo`05o`000?oooooo
ooooooooool00000D_ooool008Wooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool05_ooool2o`000003ooooool0003ooooo00kooooo00Go0000oooooooooooooooo
o`00001Booooo`00T?ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo01;ooooo
0ol0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Coooool0093ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000013ooooo0ol0000Fooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0C_ooool0093ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000kooooo0ol0000Iooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0C_ooool0097ooooo0_l00009ooooo`?o00003?ooool3o`0000?o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04go
oooo002Xooooo`?o00007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04cooooo
002Vooooo`Co00008?ooool00ol0003oooooooooo`03ooooo`;o0000C_ooool00:?ooooo0ol0000T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00:7ooooo0_l0000Woooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool009kooooo0ol0000Yooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool009cooooo0_l00003ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool01oooool2o`0004[ooooo002Iooooo`?o0000;_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Wooooo002Gooooo`;o0000<Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Sooooo001Zooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00007?ooool3o`0000;ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo04Oooooo001Yooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Hooooo`?o0000=_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo04Oooooo001Rooooo`Go00000_ooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo01Cooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0A_ooool006Wooooo00Co0000oooooooooooo00002Oooool2o`0001Cooooo0ol0000k
ooooo`;o00003?ooool2o`0000gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000[
ooooo`00JOooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00oooooo0_l0000l
ooooo`Co00003?ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0:_ooool006Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000kooooo0ol0000looooo`;o00000_l0PA800ol0003o084Bo`00000<ooooo`03o`00
0?oooooooooo00?ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool0:_ooool006[ooooo0_l00009ooooo`?o00003?ooool3o`0000;ooooo00?o0000ooooooooool0
>?ooool2o`0000Co084B00?o0000o`214_l000003Oooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool0:_ooool008;ooooo0_l0000oooooo`04o`00
0?l0PA;o084Bo`0000?o084B00?o0000o`214_l000003Oooool00ol0003oooooooooo`09ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0:_ooool007oooooo0ol0000oooooo`;o
00001?l0PA800ol0003o084Bo`214P04o`0000gooooo0_l00009ooooo`04o`000?ooooooooooo`00
00Sooooo0_l0000/ooooo`00OOooool2o`0000?ooooo00?o0000ooooooooool0>oooool00ol0003o
084Bo`214P04o`214PGo000000?o084Bo`000?ooool03?ooool2o`0000[ooooo0_l0000:ooooo`03
o`000?oooooooooo02[ooooo001jooooo`?o0000@Oooool2o`0000Ko084B00?o0000o`214_l00000
0_l0PA801?l0003o084Bo`214_l0000=ooooo`03o`000?oooooooooo047ooooo001hooooo`?o0000
@?ooool3o`0000;o08L600Co0000o`214_l0PA;o084B0_l00003o`214P03o`000?l0PA;o000000?o
084B00?o0000ooooooooool02oooool00ol0003oooooooooo`10ooooo`00MOooool3o`0000?ooooo
00?o0000ooooooooool0>Oooool4o`0000Ko08L600?o0000o`214_l000001Ol0PA800ol0003o084B
o`000003o`214P;o00003Oooool00ol0003oooooooooo`0oooooo`00L_ooool3o`0003kooooo1?l0
0003o`271P03o`000?l0Q`Ko08L600Co08L60_l00006o`214P03o`000?l0PA;o000000?o00000_l0
PA800ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03oooooo001`ooooo`Co0000?Oooool2
o`000003o`271_l0003o08L600Go08L600Co0000o`271_l0Q`Ko08L60_l000000ol0Q`Ko0000o`21
4P05o`214P?o00001_l0PA800ol0003oooooooooo`0:ooooo`;o0000?oooool004Cooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo0ol0000Jooooo`?o0000@?ooool00ol0003o08L6o`271P02
o`271P03o`000?l0Q`Ko08L600Co08L600?o0000o`271_l000001?l0Q`H01?l0003o084Bo`214_l0
PA82o`000003o`214_l0003o000000Ko084B0_l0000<ooooo`03o`000?oooooooooo03gooooo0013
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool05oooool2o`00047ooooo0_l0
0006o`271P03o`000?l0Q`Ko08L600?o08L60_l00006o`271P03o`000?l0PA;o000000Co084B00?o
0000o`214_l0PA800ol0PA800ol0003o084Bo`00000<ooooo`03o`000?oooooooooo03gooooo000l
ooooo`Go00000_ooool01?l0003oooooooooool00007ooooo`Go00005Oooool4o`0003oooooo0ol0
0002o`271P03o`000?l0Q`Ko08L600?o08L600?o0000o`271_l0Q`H00ol000000ol0Q`Ko0000o`27
1P05o`271P;o00001Ol0PA82o`0000;o084B0_l00003o`214P03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0??ooool004?ooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool0000Cooooo`?o00001?ooool00ol0003oooooooooo`0iooooo`?o00001_l0Q`H01?l0003o08L6
o`271_l0Q`H4o`0000Go08L600?o0000o`271_l0Q`H00ol00002o`271P03o`000?l0PA;o084B00;o
084B0_l000000ol0PA;o0000o`214P04o`214P03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0>oooool004?ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000Aooooo`;o
0000@?ooool3o`0000;o08L600?o0000o`271_l0Q`H01?l0Q`H4o`0000?o08L600?o0000o`271_l0
Q`H00ol0Q`H3o`0000Ko08L600Co0000o`214_l0PA;o084B0ol00006o`214P;o00003?ooool2o`00
03cooooo0013ooooo`04o`000?ooooooooooo`0000Wooooo0_l0000>ooooo`?o000000?oooooo`00
0?ooool0??ooool3o`0000Ko08L600?o0000o`271_l0Q`H00ol000000ol0Q`Ko0000o`271P05o`27
1P03o`000?l0Q`Ko000000;o000000?o08L6o`000?l0Q`H01_l0Q`H5o`000003o`271_l0003o084B
00Co084B00Co0000o`214_l0PA;o00003?ooool00ol0003oooooooooo`0jooooo`00A?ooool2o`00
00_ooooo00?o0000ooooooooool02_ooool2o`0003kooooo1?l00002o`271P03o`000?l0Q`Ko08L6
00Co08L60ol00005o`271P03o`000?l0Q`Ko08L600?o08L60_l00005o`271P03o`000?l0Q`Ko08L6
00;o08L60_l000001Ol0Q`Ko0000o`271_l0Q`Ko000000;o08L600Go0000o`214_l0PA;o084Bo`00
0004o`214P03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool005_ooooo0ol0000o
ooooo`03o`000?l0Q`Ko000000Go08L600Co0000o`271_l0Q`Ko08L60_l000000ol0Q`Ko0000o`27
1P06o`271P03o`000?l0Q`Ko000000;o000000?o08L6o`000?l0Q`H01Ol0Q`H01?l0003o08L6o`00
0?l00004o`271P03o`000?l0Q`Ko000000?o08L600?o0000o`214_l000001Ol0PA82o`0000_ooooo
00?o0000ooooooooool0>Oooool005Sooooo0ol00002ooooo`03o`000?oooooooooo03_ooooo0_l0
0003o`271P03o`000?l0Q`Ko08L600?o08L600?o0000o`271_l000001?l0Q`H00ol0003o08L6o`27
1P04o`271P;o00001Ol0Q`H00ol0003o08L6o`271P03o`271P;o00001_l0Q`H00ol0003o08L6o`00
0003o`271P;o00001Ol0PA800ol0003o084Bo`00000<ooooo`03o`000?oooooooooo03Sooooo001F
ooooo`;o0000@_ooool00ol0003o08L6o`271P04o`271P04o`000?l0Q`Ko08L6o`271P?o00001_l0
Q`H00ol0003o08L6o`271P03o`000003o`J<0?l0003o08L600Co08L600?o0000o`271_l0Q`H00ol0
0002o`271P03o`000?l0Q`Ko08L600?o08L600?o0000o`271_l000000ol000000ol0Q`Ko0000o`21
4P02o`214P;o00000ol0PA800ol0003oooooooooo`0:ooooo`;o0000>?ooool005?ooooo0ol00012
ooooo`;o00001ol0Q`H4o`0000?o08L600?o0000o`271_l0Q`H00ol0Q`H3o`0000Go1X`000?o0000
o`271_l0Q`H00_l0Q`H3o`0000Ko08L600Co0000o`271_l0Q`Ko08L61?l00005o`271P03o`000?l0
PA;o000000Go084B0_l0000;ooooo`03o`000?oooooooooo03Oooooo001Aooooo`;o00000oooool0
0ol0003oooooooooo`0looooo`?o000000?o1X`0o`000?l0Q`H01Ol0Q`H00ol0003o08L6o`000006
o`271P03o`000?l0Q`Ko000000;o000000?o1X`0o`000?l6S0001Ol6S0001Ol0003o08L6o`271_l0
Q`Ko000000;o08L600?o0000o`271_l0Q`H01?l0Q`H4o`0000?o08L600?o0000o`271_l0Q`H00ol0
Q`H3o`0000?o084B0_l000000ol0PA;o0000ooooo`0;ooooo`03o`000?oooooooooo03Kooooo001>
ooooo`?o0000@_ooool2o`0000Go1X`000Co0000o`271_l0Q`Ko08L60_l00003o`271P03o`000?l0
Q`Ko08L600?o08L60_l00005o`J<0003o`000?l6S03o1X`000?o1X`000Co0000o`271_l0Q`Ko0000
1?l0Q`H00ol0003o08L6o`271P03o`000003o`271_l0003o08L600Co08L60_l000001?l0Q`Ko0000
o`000?l00003o`214P03o`000?l0PA;o000000Co084B00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0eooooo`00C?ooool2o`0004;ooooo0ol000000ol6S03o0000o`J<0005o`J<0003o`00
0?l0Q`Ko000000Ko08L600?o0000o`271_l000000_l000000ol6S03o0000o`J<0005o`J<0003o`00
0?l6S03o1X`000?o1X`00_l00005o`271P?o00001Ol0Q`H00ol0003o08L6o`271P03o`271P;o0000
1_l0PA82o`0000Go084B00?o0000ooooooooool02_ooool00ol0003oooooooooo`0eooooo`008Ooo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001[ooooo0ol00002ooooo`;o0000?_oo
ool2o`0000Go1X`000?o0000o`J<0?l6S0000ol6S002o`0000Oo08L60_l00005o`J<0003o`000?l6
S03o1X`000?o1X`000Co0000o`J<0?l6S03o1X`00ol00005o`271P03o`000?l0Q`Ko000000Ko08L6
00Co0000o`271_l0Q`Ko08L60ol000001?l0PA;o0000o`214_l0PA83o`000003o`214_l0003o084B
00Co084B0_l0000<ooooo`;o00001oooool2o`0002cooooo000Pooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000Fooooo`?o0000@_ooool3o`000003o`J<0?l0003o
1X`000Go1X`000?o0000o`J<0?l000000_l00002o`J<0003o`000?l0Q`Ko08L600;o08L60_l00000
0ol6S03o0000o`J<0004o`J<0003o`000?l6S03o1X`000?o1X`01?l00003o`J<0005o`000?l0Q`Ko
08L6o`271_l000000ol0Q`H00ol0003o08L6o`271P03o`271P04o`000?l0Q`Ko0000o`0000;o084B
00?o0000o`214_l000000_l00005o`214P05o`000?l0PA;o084Bo`214_l000000_l0PA800ol0003o
ooooooooo`09ooooo`;o00001_ooool01?l0003oooooooooool0000[ooooo`006Oooool5o`0000;o
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Booooo`;o00000_ooool00ol0
003oooooooooo`0nooooo`;o00001Ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001_l6S0001?l0
003o08L6o`000?l00004o`J<0003o`000?l6S03o1X`000;o1X`000?o0000o`J<0?l6S0000ol00000
0ol6S03o0000o`J<0005o`J<0003o`000?l0Q`Ko000000Go08L600Co0000o`271_l0Q`Ko08L61?l0
0002o`214P?o000000?o084Bo`000?l0PA801Ol0PA801?l0003o084Bo`214_l00004o`214P03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000[ooooo`00
8?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00oooooo0ol00012ooooo`?o
00000_l6S0000ol0003o1X`0o`J<0003o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0003o
1X`0o`J<0003o`J<00;o00001_l6S0000ol0003o1X`0o`J<0002o`J<00?o00001Ol6S0000ol0003o
1X`0o`J<0003o`J<00;o00001_l0Q`H4o`0000Co08L60_l000000ol0PA;o0000o`214P02o`214P03
o`000?l0PA;o084B00?o084B00?o0000o`214_l000001Ol0PA82o`0000_ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool0000[ooooo`008?ooool01?l0003oooooooooool00007oooo
o`Co00004?ooool3o`0004;ooooo0_l00006o`J<0004o`000?l6S03o1X`0o`J<00?o00001_l6S000
0ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Go1X`000?o0000o`J<0?l000000_l00002
o`J<0003o`000?l6S03o1X`000Co1X`000?o0000o`J<0?l000000_l00002o`J<0004o`000?l0Q`Ko
08L6o`271P;o000000?o08L6o`000?l0Q`H01?l0Q`H2o`0000;o084B00Co0000o`214_l0PA;o084B
2?l00005o`214P03o`000?l0PA;o000000_ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool0000[ooooo`008?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00ko
oooo0ol00002ooooo`03o`000?oooooooooo03gooooo0ol00002o`J<0003o`000?l6S03o1X`000?o
1X`01?l00003o`J<0003o`000?l6S03o1X`000?o1X`00_l00005o`J<0003o`000?l6S03o1X`000?o
1X`00_l00006o`J<0004o`000?l6S03o1X`0o`J<00Co00001_l6S0000ol0003o08L6o`000004o`27
1P05o`000?l0Q`Ko08L6o`271_l000000_l0PA801?l0003o084Bo`000?l0PA82o`000003o`214_l0
003o084B00Co084B00Co0000o`214_l0PA;o084B0_l00003o`214P03o`000?oooooooooo00Wooooo
0_l00003ooooo`04o`000?ooooooooooo`0002_ooooo000Qooooo`;o00002?ooool5o`0000Wooooo
0ol00011ooooo`Co00001_l6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Go1X`0
00?o0000o`J<0?l000000_l000000olETP3o0000o`J<0005o`J<0003o`000?l6S03o000000;o0000
0_l6S0000ol0003o1X`0o`J<0003o`J<00Co00000ol6S0000ol0003o1X`0o`J<0004o`J<00;o0000
1_l0Q`H00ol0003o08L6o`000004o`214P?o00001?l0PA800ol0003o084Bo`214P03o`214P03o`00
0?l0PA;o000000Go084B0_l0000:ooooo`;o00001?ooool2o`0002cooooo000gooooo`;o000000?o
ooooo`000?ooool0?Oooool4o`0000Co1X`000?o0000o`J<0?l6S0000ol6S002o`0000Go1X`000?o
0000o`J<0?l6S0000ol6S002o`0000Go5I8000?o0000o`J<0?l6S0000ol6S002o`0000Ko1X`000?o
0000o`J<0?l000000_l000000ol6S03o0000o`J<0005o`J<0003o`000?l6S03o1X`000?o00000_l6
S0001?l0003o08L6o`271_l0Q`H4o`0000Go084B0_l00006o`214P04o`000?l0PA;o084Bo`214P?o
00001Ol0PA800ol0003o084Bo`00000;ooooo`03o`000?oooooooooo033ooooo000dooooo`?o0000
1?ooool00ol0003oooooooooo`0iooooo`;o000000?o1X`0o`000?l6S0001_l6S0000ol0003o1X`0
o`000002o`0000;o1X`000?o0000o`J<0?l6S0000ol6S0000ol0003o1X`0o`000002o`000003oaFB
0?l0003o5I8000Go5I8000?o0000o`J<0?l6S0000_l00002o`J<0003o`000?l6S03o1X`000?o1X`0
0_l00005o`J<0003o`000?l6S03o1X`000?o1X`00ol00005o`J<00Co00000ol0Q`H00ol0003o084B
o`214P03o`000003o`214_l0003o000000Go084B1?l00003o`214P05o`000?l0PA;o084Bo`214_l0
00000ol0PA800ol0003oooooooooo`09ooooo`03o`000?oooooooooo02oooooo000cooooo`;o0000
@?ooool2o`0000Co1X`000?o0000o`J<0?l6S0001?l6S002o`0000Ko1X`000Co0000o`J<0?l6S03o
1X`00ol00005oaFB0003o`000?lETP3o5I8000?o5I8000?o0000o`J<0?l000001Ol6S0000ol0003o
1X`0o`000002o`0000;o1X`000?o0000o`J<0?l6S0000ol6S0000ol0003o1X`0o`J<0002o`0000?o
1X`000?o0000o`J<0?l000000_l00002o`271P03o`000?l0Q`Ko08L600;o08L61?l00004o`214P;o
000000Ko084Bo`000?l0003o0000o`214_l00006o`214P03o`000?l0PA;o000000Co084B0_l0000;
ooooo`03o`000?oooooooooo02kooooo000cooooo`?o0000??ooool3o`000003o`J<0?l0003o1X`0
00Co1X`000Co0000o`J<0?l6S03o1X`00_l000000ol6S03o0000o`J<0005o`J<00Co00000_lETP00
0ol0003o5I80oaFB0004oaFB0003o`000?lETP3o5I8000;o5I800_l00006o`J<00;o00001_l6S000
0ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000Go1X`00_l00006o`271POo00001_l0PA82
o`0000Go084B00?o0000o`214_l0PA800ol0PA82o`0000Co084B00?o0000o`214_l000002oooool2
o`0002oooooo000cooooo`;o000000?oooooo`000?ooool0>?ooool2o`0000Go1X`000?o0000o`J<
0?l6S0000ol6S0000ol0003o1X`0o`000004o`J<0004o`000?l6S03o1X`0o`J<00;o000000?o5I80
o`000?lETP001?lETP000ol0003o5I80oaFB0003oaFB0003o`000?lETP3o000000;o00000_lETP00
1?l0003o1X`0o`J<0?l6S002o`000003o`J<0?l0003o1X`000Go1X`01ol00005o`J<0004o`000?l0
Q`Ko08L6o`0000?o08L61_l00003o`271P04o`000?l0PA;o084Bo`214P;o000000?o084Bo`000?l0
PA801?l0PA800ol0003o084Bo`214P03o`000003o`214_l0003o084B00;o084B00Go0000o`214_l0
PA;o084Bo`00000:ooooo`;o0000;oooool003?ooooo00Go0000ooooooooooooooooo`00000foooo
o`;o000000?o1X`0o`000?l6S0001Ol6S0001?l0003o1X`0o`J<0?l6S003o`0000Ko1X`000?o0000
o`J<0?l000001?lETP000ol0003o5I80oaFB0003oaFB0003o`000?lETP3o5I8000;o5I800_l00006
oaFB0003o`000?l6S03o000000Co1X`000Co0000o`J<0?l6S03o1X`00_l000000ol6S03o0000o`J<
0004o`J<0005o`000?l6S03o1X`0o`J<0?l000001?l0Q`H5o`000003o`271_l0003o08L600Go08L6
00?o0000o`214_l000000ol0PA82o`0000?o084B1?l00005o`214P03o`000?l0PA;o000000Go084B
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/ooooo`00<_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03;ooooo00?o0000o`J<0?l6S0000_l6S0000ol0003o1X`0o`J<
0003o`J<00Co00000ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001_lETP000ol0003o5I80oaFB
0002oaFB0003o`000?lETP3o000000;o00000_lETP000ol0003o5I80oaFB0003oaFB00;o00001_l6
S0000ol0003o1X`0o`000004o`J<0003o`000?l6S03o1X`000?o1X`000?o0000o`J<0?l000000ol0
Q`H4o`0000Go08L600?o0000o`271_l0Q`H00ol0Q`H2o`0000Go084B1?l00003o`214P03o`000?l0
PA;o084B00?o084B0_l00006o`214P03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?oo
ool003;ooooo0_l00005ooooo`03o`000?oooooooooo02kooooo0ol00006o`J<0003o`000?l6S03o
000000;o00000_l6S0000ol0003o1X`0o`J<0003o`J<0003o`000?l6S03o000000;o000000?o5I80
o`000?lETP001OlETP001?l0003o5I80oaFB0?lETP03o`0000Ko5I8000?o0000oaFB0?l000000_l0
00000olETP3o0000o`J<0005o`J<00;o00001_l6S0001?l0003o1X`0o`J<0?l6S003o`000008o`27
1_l0003o0000o`000?l0Q`Ko0000o`271_l00005o`271P03o`000?l0Q`Ko08L600?o000000?o08L6
o`000?l0PA800_l0PA82o`000003o`214_l0003o084B00Go084B00?o0000o`214_l000000_l00000
0ol0PA;o0000o`214P05o`214P;o00002oooool00ol0003oooooooooo`0[ooooo`00<_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo1?l00003o`J<0003o`000?l6S03o1X`0
00?o1X`00_l00006o`J<0004o`000?l6S03o1X`0o`J<00?o00001OlETP000ol0003o5I80oaFB0003
oaFB00Co00000_lETP000ol0003o5I80oaFB0004oaFB00;o00001OlETP001?l0003o1X`0o`J<0?l6
S002o`000003o`J<0?l0003o1X`000Go1X`01?l000001?l6S03o0000o`000?l00003o`271P05o`00
0?l0Q`Ko08L6o`271_l000000ol0Q`H4o`0000Go08L600?o0000o`214_l000001?l0PA800ol0003o
084Bo`214P03o`214P;o00001Ol0PA800ol0003o084Bo`214P03o`000003o`214_l0003ooooo00[o
oooo0_l0000/ooooo`00<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Gooooo
0ol00002o`J<0003o`000?l6S03o1X`000?o1X`000?o0000o`J<0?l000000_l00002o`J<0003o`00
0?l6S03o1X`000?o1X`01?l00002oaFB0003o`000?lETP3o5I8000Co5I8000?o0000oaFB0?l00000
0_l000000olETP3o0000oaFB0004oaFB0003o`000?lETP3o5I8000?o000000?o5I80o`000?lETP00
1OlETP000ol0003o1X`0o`000004o`J<0003o`000?l6S03o1X`000?o000000?o1X`0o`000?l00000
0_l00003o`J<0003o`000?l0Q`Ko000000Co08L61?l00003o`271P03o`000?l0Q`Ko08L600?o08L6
0_l00005o`214P;o000000Ko084Bo`000?l0003o0000o`214_l00005o`214P?o00001Ol0PA800ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo000booooo`;o00002?ooool00ol0003o
ooooooooo`0Rooooo`;o00001_l6S0001?l0003o1X`0o`J<0?l6S003o`0000Ko1X`000?o0000o`J<
0?l000000_l000000olETP3o0000oaFB0004oaFB0003o`000?lETP3o5I8000?o5I800_l00005oaFB
0003o`000?lETP3o5I8000;o5I800ol00005oaFB0004o`000?lETP3o5I80oaFB00Co00001Ol6S003
o`0000;o1X`01?l00005o`J<00;o00001?l0Q`H00ol0003o08L6o`000006o`271P03o`000?l0Q`Ko
000000;o000000?o08L6o`000?l0PA801Ol0PA82o`0000Go084B00?o0000o`214_l000000_l00000
0ol0PA;o0000o`214P05o`214P03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool0
03;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`?o00000_l6S0000ol0
003o1X`0o`J<0003o`J<00Co00000ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001OlETP000ol0
003o5I80oaFB0003oaFB0003o`000?lETP3o000000;o00000_lETP000ol0003o5I80oaFB0003oaFB
0004o`000?lETP3o0000o`0000;o5I8000?o0000oaFB0?lETP000olETP04o`0000?o5I8000Co0000
o`J<0?l6S03o1X`00_l00002o`J<00?o00000ol6S0000ol0003o1X`0o`J<0003o`000003o`J<0?l0
003o08L600;o08L600Go0000o`271_l0Q`Ko08L6o`000005o`271P;o00001Ol0Q`H00ol0003o084B
o`214P03o`000003o`214_l0003o084B00Co084B0_l00005o`214P03o`000?l0PA;o084B00?o084B
0_l0000<ooooo`03o`000?oooooooooo02Sooooo000booooo`;o00002_ooool00ol0003ooooooooo
o`0Jooooo`?o00001_l6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Go1X`000?o
0000o`J<0?l000000_l000000olETP3o0000oaFB0005oaFB0003o`000?lETP3o5I8000;o5I800_l0
0006oaFB0004o`000?lETP3o5I80oaFB00?o00001OlETP000ol0003o5I80o`000002o`000003oaFB
0?l0003o5I8000Go5I8000?o0000o`J<0?l000000_l6S004o`0000?o1X`01?l00005o`J<0003o`00
0?l0Q`Ko000000Go08L600?o0000o`271_l0Q`H00_l000000ol0Q`Ko0000o`271P04o`271P?o0000
1?l0PA82o`000006o`214_l0003o0000o`000?l0PA;o00001_l0PA800ol0003o084Bo`000002o`00
0003o`214_l0003ooooo00_ooooo00?o0000ooooooooool0:?ooool0037ooooo0_l0000<ooooo`03
o`000?oooooooooo01Gooooo1?l00003o`J<0003o`000?l6S03o1X`000?o1X`00_l00005o`J<0003
o`000?l6S03o1X`000?o1X`00_l00005oaFB0003o`000?lETP3o5I8000?o5I8000?o0000oaFB0?l0
00000_l00002oaFB0003o`000?lETP3o5I8000?o5I801?l00003oaFB0003o`000?lETP3o5I8000;o
5I800_l00005oaFB0003o`000?lETP3o5I8000?o5I801Ol00003o`J<00Co00000ol6S0000ol0003o
1X`0o`J<0003o`J<00;o00001_l0Q`H00ol0003o08L6o`000004o`271P03o`000?l0Q`Ko000000;o
00000_l0Q`H00ol0003o084Bo`214P03o`214P;o00001Ol0PA800ol0003o084Bo`214P03o`214P;o
00001Ol0PA800ol0003oooooooooo`09ooooo`;o0000:Oooool0037ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Booooo`;o00000_l6S0000ol0003o1X`0o`J<0003o`J<0003o`00
0?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<0003o`J<0003o`000?l6S03o000000;o0000
0_l6S0000ol0003o5I80oaFB0003oaFB0004o`000?lETP3o5I80oaFB00?o00001_lETP000ol0003o
5I80o`000002o`000003oaFB0?l0003o5I8000Go5I8000Co0000oaFB0?l0003o00000_lETP000ol0
003o5I80oaFB0003oaFB0003o`000?lETP3o000000Go00000ol6S002o`000003o`J<0?l0003o1X`0
00Go1X`000?o0000o`J<0?l000000_l00002o`J<0003o`000?l0Q`Ko08L600?o08L60_l00005o`27
1P;o00001_l0Q`H00ol0003o084Bo`000002o`000003o`214_l0003o084B00Co084B00?o0000o`21
4_l0PA800ol000000ol0Q`Ko0000o`214P04o`214P;o00003?ooool00ol0003oooooooooo`0Voooo
o`00<Oooool3o`0000gooooo00?o0000ooooooooool03oooool2o`0000Go1X`000?o0000o`J<0?l6
S0000_l6S003o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol00006o`J<0004o`000?lETP3o5I80
oaFB00Go00000olETP000ol0003o5I80oaFB0003oaFB00;o00001OlETP000ol0003o5I80oaFB0003
oaFB00;o00001OlETP001?l0003o5I80oaFB0?lETP05o`0000Co5I8000?o0000o`J<0?l000001?l6
S0000ol0003o1X`0o`J<0003o`J<00;o00001_l6S0000ol0003o08L6o`000002o`000003o`271_l0
003o08L600;o08L60_l000000ol0Q`Ko0000o`271P05o`271P;o00001Ol0PA800ol0003o084Bo`21
4P02o`214P?o00001Ol0Q`H01ol0003o084Bo`214_l0PA;o0000o`214_l000003?ooool00ol0003o
ooooooooo`0Vooooo`001Oooool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`?o00000_ooool5o`0000;ooooo0_l00003ooooo`Go00001?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00_ooooo0ol00002o`J<0003o`000?l6S03o1X`000?o1X`0
00Co0000o`J<0?l0003o00000ol6S0000ol0003o1X`0o`J<0002o`J<00Co00000ol6S0000ol0003o
1X`0o`J<0003o`J<00Co00000_lETP000ol0003o5I80oaFB0004oaFB0003o`000?lETP3o000000;o
00000_lETP000ol0003o5I80oaFB0002oaFB0003o`000?lETP3o5I8000?o000000?o5I80o`000?lE
TP001?lETP06o`000003oaFB0?l0003o5I8000Co5I800_l00006o`J<0003o`000?l6S03o000000;o
000000?o1X`0o`000?l6S0001Ol6S002o`0000Go08L600?o0000o`271_l000001?l0Q`H00ol0003o
08L6o`271P03o`000003o`271_l0003o084B00Co084B00?o0000o`214_l0PA800_l00002o`271P03
o`000?l0Q`Ko08L600?o08L600Co0000o`214_l0PA;o00000ol0PA800ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02Gooooo0004ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`;o0000
4?ooool00ol0003oooooooooo`08ooooo`;o00001_l6S0001?l0003o1X`0o`J<0?l6S003o`0000Ko
1X`000Co0000o`J<0?l0003o00000_l6S0000ol0003o1X`0o`J<0003o`J<0003o`000?l6S03o0000
00;o00000_l6S0000ol0003o5I80oaFB0002oaFB0003o`000?lETP3o5I8000?o5I800_l00006oaFB
0003o`000?lETP3o5I8000Co00001OlETP000ol0003o5I80o`000002o`000003oaFB0?l0003o0000
00Go5I8000?o0000oaFB0?l000000_l00002oaFB0003o`000?l6S03o1X`000?o1X`00_l00005o`J<
0003o`000?l6S03o1X`000?o000000?o1X`0o`000?l0Q`H01?l0Q`H2o`0000Go08L60ol00005o`27
1P03o`000?l0PA;o084B00;o084B0ol00005o`271P03o`000?l0Q`Ko08L600;o08L600?o0000o`21
4_l000001?l0PA82o`0000cooooo00?o0000ooooooooool01Oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`00017ooooo0008ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo013ooooo0_l00005ooooo`?o00000_l6S0000ol0003o1X`0o`J<0003
o`J<00Co00000ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001Ol6S0000ol0003o1X`0o`J<0002
o`J<00;o00001_l6S0000ol0003o5I80oaFB0002oaFB0003o`000?lETP3o000000;o00000_lETP00
0ol0003o5I80oaFB0003oaFB00?o00000olETP000ol0003o5I80oaFB0003oaFB00;o000000Ko5I80
o`000?l0003o0000oaFB0?l00005oaFB00;o00001_lETP000ol0003o1X`0o`000002o`0000;o1X`0
00?o0000o`J<0?l6S0000_l6S003o`0000Go1X`000?o0000o`271_l000000_l00002o`271P07o`00
0?l0Q`Ko08L6o`271_l0003o1X`0o`000006o`271P03o`000?l0PA;o084B00;o084B0ol00005o`27
1POo00000ol0PA82o`0000;o084B00?o0000ooooooooool02?ooool2o`0000Kooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`0@ooooo`001_ooool2o`0000_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Co00001?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooool000000ol00005
o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001Ol6S0000ol0003o1X`0o`000002
o`0000;o1X`000?o0000o`J<0?l6S0000ol6S0001?l0003o1X`0o`000?l00002o`J<0003o`000?l6
S03o1X`000?o1X`01ol00006oaFB0003o`000?lETP3o000000;o00000_l6S0000ol0003o5I80oaFB
0002oaFB0003o`000?lETP3o000000Go00001OlETP000ol0003o5I80o`000002o`0000;o5I8000?o
0000oaFB0?lETP000olETP02o`0000Ko1X`000Co0000o`J<0?l0003o00000_l6S0000ol0003o1X`0
o`J<0003o`J<00;o00001_l0Q`H00ol0003o08L6o`000003o`J<0003o`000?l0Q`Ko08L600?o08L6
00?o0000o`214_l000000_l00003o`271P03o`000?l0Q`Ko000000;o000000?o08L6o`000?l0Q`H0
1?l0Q`H00ol0003o084Bo`000005o`214P03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo013ooooo0008ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooool000000ol00002ooooo`07o`000?ooooooooooooooool0
003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooooooo0_l0000C
ooooo`?o00001?l6S0000ol0003o1X`0o`J<0002o`J<00?o00001?l6S0000ol0003o1X`0o`J<0003
o`J<00;o00001_l6S0001?l0003o1X`0o`J<0?l6S003o`0000Go1X`000?o0000o`J<0?l000000_l0
00000ol6S03o0000oaFB0004oaFB0003o`000?lETP3o5I8000?o5I800ol00005o`J<0003o`000?lE
TP3o5I8000Ko00000olETP001?l0003o5I80oaFB0?lETP03o`0000Ko5I8000?o0000oaFB0?l00000
0_l000000olETP3o0000o`J<0005o`J<00;o00001Ol6S0000ol0003o1X`0o`000002o`000003o`J<
0?l0003o08L600Go08L60_l00005o`J<0003o`000?l0Q`Ko08L600;o08L60_l00006o`271P;o0000
1Ol0Q`H00ol0003o08L6o`271P02o`271P;o00001_l0PA82o`0000_ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo013ooooo0004ooooo`05o`00
0?ooooooooooooooool000001oooool01ol0003ooooooooooooooooo0000ooooool000001Oooool0
1ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000003ooooo`05o`00
0?ooooooooooooooool000004Oooool3o`000003o`J<0?l0003o1X`000Go1X`000Co0000o`J<0?l0
003o00000ol6S0000ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0
003o1X`0o`J<0003o`J<00Co00000ol6S0000ol0003o1X`0o`J<0002o`J<00;o00001Ol6S0000ol0
003o5I80oaFB0003oaFB0003o`000?lETP3o000000;o00000ol6S0001?l0003o1X`0o`J<0?l6S008
o`0000Go5I801?l00003oaFB0003o`000?lETP3o5I8000?o5I800_l00005oaFB0003o`000?l6S03o
1X`000?o000000?o1X`0o`000?l6S0001?l6S002o`0000Go1X`000Co0000o`271_l0Q`Ko08L60_l0
00000ol6S03o0000o`J<0004o`J<0003o`000?l0Q`Ko000000;o00000_l0Q`H00ol0003o08L6o`27
1P03o`000003o`271_l0003o08L600Co08L600?o0000o`271_l000000_l000000ol0Q`Ko0000o`21
4P03o`214P;o000000?o084Bo`000?ooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool04?ooool000Gooooo0ol00008ooooo`Go000000?o
ooooo`000?l000000ol00002ooooo`?o00000oooool3o`0000?ooooo0ol00004ooooo`03o`000?oo
oooooooo00gooooo0ol00004o`J<0003o`000?l6S03o1X`000?o1X`00_l00006o`J<0003o`000?l6
S03o1X`000?o00001_l6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Go1X`000Co
0000o`J<0?l0003o00000_l6S0000ol0003o1X`0o`J<0003o`J<0004o`000?lETP3o5I80oaFB00Co
00001Ol6S004o`000004o`J<0?l0003o0000o`0000Co5I8000?o0000oaFB0?l000000_l00002oaFB
0003o`000?lETP3o5I8000?o5I8000?o0000oaFB0?l000000_l000000olETP3o0000oaFB0004oaFB
00?o00001Ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Co1X`000Co0000o`27
1_l0003o00001?l6S0000ol0003o1X`0o`J<0002o`J<00;o00001Ol0Q`H3o`0000Go08L600Co0000
o`271_l0Q`Ko08L60ol00005o`271P04o`000?l0PA;o0000o`0000Co084B00?o0000ooooooooool0
2?ooool2o`0000?ooooo00Co0000oooooooooooo00002?ooool2o`0001;ooooo000`ooooo`03o`00
0?oooooooooo00_ooooo0_l00003o`J<0003o`000?l6S03o1X`000;o1X`000?o0000o`J<0?l00000
0_l00002o`J<0003o`000?l6S03o1X`000?o1X`00ol00003o`J<0003o`000?l6S03o1X`000?o1X`0
0_l00005o`J<0003o`000?l6S03o1X`000?o1X`00_l00005o`J<0004o`000?l6S03o1X`0o`J<00Go
00001?l6S0000ol0003o1X`0o`000002o`0000;o1X`00ol00002o`J<0004o`000?lETP3o5I80oaFB
00?o00001_lETP001?l0003o5I80oaFB0?lETP03o`0000Go5I8000?o0000oaFB0?l000000_l00000
0olETP3o0000o`J<0005o`J<00;o00001Ol6S0001?l0003o1X`0o`J<0?l6S003o`0000Ko1X`000?o
0000o`J<0?l000000_l000000ol6S03o0000o`271P03o`271P04o`000?l0Q`Ko08L6o`0000Go08L6
1?l00002o`271P03o`000?l0Q`Ko08L600?o08L60_l00006o`214P03o`000?oooooooooo00[ooooo
00Co0000oooooooooooooooo0_l0000:ooooo`03o`000?oooooooooo013ooooo000`ooooo`;o0000
2oooool00ol0003o1X`0o`J<0004o`J<0003o`000?l6S03o1X`000?o00001_l6S0000ol0003o1X`0
o`000002o`000003o`J<0?l0003o1X`000Co1X`000?o0000o`J<0?l000000_l00002o`J<0003o`00
0?l6S03o1X`000?o1X`000?o0000o`J<0?l000000_l00002o`J<0003o`000?l6S03o1X`000;o1X`0
1?l00003o`J<0003o`000?l6S03o1X`000?o1X`00_l00003o`J<00Co00000_l6S005o`0000?o5I80
00?o0000oaFB0?lETP000olETP04o`0000?o5I8000?o0000oaFB0?lETP000_lETP02o`0000Go5I80
00Co0000o`J<0?l6S03o1X`00_l000000ol6S03o0000o`J<0004o`J<00Co00000ol6S0000ol0003o
1X`0o`J<0003o`J<00;o00001Ol6S0001?l0003o08L6o`271_l00004o`271P03o`000?l0Q`Ko0000
00;o000000?o08L6o`000?l0Q`H01?l0Q`H00ol0003o08L6o`000002o`000003o`271_l0003o084B
00Go084B00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`00<?ooool00ol0003o
ooooooooo`08ooooo`?o00001_l6S003o`0000?o1X`000?o0000o`J<0?l6S0000ol6S002o`0000Go
1X`000?o0000o`J<0?l6S0000_l6S003o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol00006o`J<
0004o`000?l6S03o0000o`0000?o1X`000?o0000o`J<0?l6S0000_l6S0000ol0003o1X`0o`000002
o`0000;o1X`00ol00003o`J<00?o00000ol6S0000ol0003o5I80oaFB0003oaFB0003o`000?lETP3o
000000;o000000?o5I80o`000?lETP001OlETP001?l0003o5I80o`000?l00002oaFB0003o`000?lE
TP3o5I8000?o5I8000?o0000o`J<0?l000001?l6S0000ol0003o1X`0o`000002o`000003o`J<0?l0
003o1X`000Go1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0003o`000?l0
Q`Ko000000Go08L60_l00005o`271P03o`000?l0Q`Ko08L600;o08L60_l00005o`271P04o`000?l0
PA;o084Bo`214PCo00003?ooool00ol0003oooooooooo`0Oooooo`00<?ooool00ol0003ooooooooo
o`06ooooo`;o00000olETP001?l0003o1X`0o`J<0?l6S002o`000003o`J<0?l0003o1X`000Co1X`0
00?o0000o`J<0?l000000_l00002o`J<0003o`000?l6S03o1X`000?o1X`000Co0000o`J<0?l0003o
00000ol6S0000ol0003o1X`0o`J<0002o`J<00Co00000ol6S0000ol0003o1X`0o`J<0003o`J<00;o
00001_l6S0000ol0003o1X`0o`J<0003o`0000;o1X`00ol000000ol6S03o0000o`J<0003o`000003
o`J<0?l0003o1X`000Co1X`000Co0000oaFB0?lETP3o5I800ol00005oaFB0003o`000?lETP3o5I80
00?o5I800_l00005oaFB0004o`000?lETP3o5I80oaFB00?o00001Ol6S002o`0000Go1X`000?o0000
o`J<0?l6S0000ol6S002o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol00005o`271P03o`000?l0
Q`Ko000000Go08L61Ol000000ol0Q`Ko0000o`271P04o`271PCo00000ol0Q`H00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01kooooo000_ooooo`;o00001Oooool3o`0000Ko5I8000?o0000
o`J<0?l000001?l6S0000ol0003o1X`0o`J<0002o`J<00?o00001Ol6S0001?l0003o1X`0o`J<0?l6
S004o`0000Go1X`000Co0000o`J<0?l0003o00000_l6S0000ol0003o1X`0o`J<0003o`J<0003o`00
0?l6S03o000000;o000000?o1X`0o`000?l6S0001Ol6S003o`0000;o1X`00ol00004o`J<00;o0000
1Ol6S0000ol0003o1X`0o`J<0002o`J<00Co00000olETP000ol0003o5I80oaFB0003oaFB0003o`00
0?lETP3o000000;o000000?o5I80o`000?lETP001?lETP04o`0000?o5I8000Go0000o`J<0?l6S03o
1X`0o`000002o`J<0003o`000?l6S03o1X`000?o1X`000?o0000o`J<0?l000000_l000000ol6S03o
0000o`J<0004o`J<00Co00000ol6S0001Ol0003o08L6o`271_l0Q`Ko000000?o08L600Co0000o`27
1_l0Q`Ko08L60ol00005o`271P03o`000?l0Q`Ko000000;o00000_l0Q`H00ol0003o08L6o`271P03
o`271P03o`000?oooooooooo00Wooooo0_l0000Pooooo`00;oooool00ol0003oooooooooo`04o`00
00?o5I8000?o0000oaFB0?lETP000olETP02o`0000Ko1X`000Co0000o`J<0?l0003o00000ol6S002
o`0000;o1X`01Ol00004o`J<0004o`000?l6S03o1X`0o`J<00?o00001Ol6S0001?l0003o1X`0o`J<
0?l6S005o`0000?o1X`000?o0000o`J<0?l6S0000ol000000ol6S03o0000o`000002o`0000;o1X`0
00?o0000o`J<0?l000000_l00002o`J<0003o`000?l6S03o1X`000;o1X`000?o0000o`J<0?l00000
0_l00003o`J<0003o`000?lETP3o5I8000;o5I8000Co0000oaFB0?lETP3o5I800ol00005oaFB0003
o`000?lETP3o000000;o000000?o5I80o`000?lETP001OlETP000ol0003o1X`0o`000004o`J<0004
o`000?l6S03o1X`0o`J<00?o00001Ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`0
00Go1X`000?o0000o`271_l000001?l0Q`H4o`0000;o08L60_l00004o`271P;o00001_l0Q`H01?l0
003o08L6o`271_l0Q`H3o`0000cooooo00?o0000ooooooooool07Oooool002oooooo0ol00002oaFB
0003o`000?lETP3o5I8000?o5I8000?o0000oaFB0?l000000_l00002oaFB0003o`000?l6S03o1X`0
00?o1X`00_l00006o`J<00?o00001?l6S0001?l0003o1X`0o`J<0?l6S005o`0000?o1X`000Co0000
o`J<0?l6S03o1X`01Ol00004o`J<00Oo00000ol6S003o`0000Co1X`00ol00004o`J<00Oo00001_l6
S009o`0000;o5I8000?o0000oaFB0?lETP000olETP02o`0000Go5I8000?o0000oaFB0?lETP000olE
TP02o`0000Go1X`01?l00002o`J<0003o`000?l6S03o1X`000?o1X`00ol00004o`J<0003o`000?l6
S03o1X`000?o1X`00_l00003o`271P;o000000?o08L6o`000?l0Q`H01?l0Q`H5o`0000;o08L600?o
0000o`271_l0Q`H00ol0Q`H4o`0000;o08L600?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Mooooo`00;oooool00ol0003o5I80oaFB0003oaFB0003o`000?lETP3o5I8000;o5I800ol00005
oaFB0003o`000?l6S03o000000;o00000_l6S0001?l0003o1X`0o`J<0?l6S002o`0000;o1X`000?o
0000o`J<0?l6S0000_l6S004o`0000?o1X`000?o0000o`J<0?l6S0000_l6S004o`0000Co1X`000?o
0000o`J<0?l000000_l00002o`271P03o`000?l6S03o1X`000;o1X`00ol00002o`J<0003o`000?l6
S03o000000;o00000ol6S0001_l0003o1X`0o`000?l0003o1X`0o`0000Go1X`000Co0000o`J<0?l6
S03o1X`00_l000000ol6S03o0000oaFB0003oaFB0003o`000?lETP3o5I8000?o5I8000?o0000oaFB
0?l000000_l00002oaFB0003o`000?lETP3o5I8000?o5I8000?o0000oaFB0?l000000_l000000olE
TP3o0000o`J<0002o`J<00;o000000?o1X`0o`000?l6S0001?l6S0000ol0003o1X`0o`000002o`00
00?o1X`000?o0000o`J<0?l6S0000_l6S0000ol0003o1X`0o`000002o`0000;o1X`000?o0000o`27
1_l000001?l0Q`H01?l0003o08L6o`271_l0Q`H4o`0000Go08L600?o0000o`271_l000000_l00000
0ol0Q`Ko0000o`271P04o`271P03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool0
00?ooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3o`00
00;ooooo1Ol00002ooooo`;o00000oooool5o`0000Cooooo0_l00005oaFB0004o`000?lETP3o0000
o`0000?o5I8000?o0000oaFB0?lETP000_lETP02o`0000Ko1X`000?o0000o`J<0?l000001Ol6S000
1_l0003o1X`0o`000?l0003o1X`0o`0000Ko1X`000Co0000o`J<0?l0003o00000ol6S002o`0000;o
1X`00ol00006o`271Pco00001Ol6S002o`0000Co1X`000?o0000o`J<0?l6S0000ol6S0000ol0003o
1X`0o`000004o`J<0003o`000?lETP3o5I8000;o5I8000?o0000oaFB0?lETP000_lETP02o`0000Ko
5I8000Co0000oaFB0?lETP3o5I800ol00005oaFB0003o`000?l6S03o000000Co1X`000Co0000o`J<
0?l6S03o1X`01?l00005o`J<00Oo00001Ol6S002o`0000Go08L61?l00002o`271P;o00001Ol0Q`H2
o`0000Go08L600?o0000o`271_l0Q`H00_l0Q`H2o`0000_ooooo0_l0000Mooooo`000_ooool01Ol0
003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003oaFB00?o00001_lETP001?l0003o
5I80o`000?l00002oaFB0003o`000?l6S03o1X`000?o1X`00ol00005o`J<00;o00001?l6S0000ol0
003o1X`0o`J<0003o`J<00?o00001Ol6S003o`0000?o08L600Co0000o`271_l0Q`Ko08L61Ol00002
o`J<0003o`000?l6S03o1X`000Co1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004
o`J<0004o`000?l6S03o1X`0o`J<00Co00001?l6S005o`000003oaFB0?l0003o5I8000;o00000_lE
TP000ol0003o5I80oaFB0003oaFB00Co00000_lETP000ol0003o5I80oaFB0003oaFB00;o00001Ol6
S004o`0000Co1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0003o`000?l6
S03o000000;o000000?o1X`0o`000?l0Q`H00_l0Q`H2o`000003o`271_l0003o08L600Co08L60_l0
00001_l0Q`Ko0000o`000?l0003o08L6o`0000Go08L600?o0000o`271_l000000_l000000ol0Q`Ko
0000ooooo`0;ooooo`03o`000?oooooooooo01_ooooo0006ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000005ooooo`;o00000_ooool3o`0000?o5I8000?o0000oaFB0?lETP000olETP03o`00
00Co5I8000?o0000o`J<0?l000000_l00003o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0
003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o00000ol6S0000ol0003o1X`0o`000002o`00
0003o`271_l0003o08L600Co08L61Ol00002o`271P05o`000?l6S03o1X`0o`J<0?l000001Ol6S002
o`0000Go1X`000Co0000o`J<0?l6S03o1X`01Ol00004o`J<0006o`000?l6S03o0000o`000?l6S03o
00000olETP03o`0000Go5I8000?o0000oaFB0?l000000_l000000olETP3o0000oaFB0004oaFB0003
o`000?lETP3o000000;o00000_lETP001Ol0003o1X`0o`J<0?l6S03o000000;o1X`000?o0000o`J<
0?l6S0000ol6S002o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol00005o`J<0003o`000?l0Q`Ko
000000Co08L600?o0000o`271_l0Q`H00_l0Q`H3o`0000Go08L600Co0000o`271_l0Q`Ko08L60ol0
0005o`271P03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool000Cooooo0_l0000;
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooooooo
ool4o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o00000olE
TP000ol0003o5I80o`000002o`0000?o5I8000?o0000oaFB0?lETP001?l00005o`J<00;o00001_l6
S0000ol0003o1X`0o`J<0004o`0000Go1X`00ol00004o`271P03o`000?l0Q`Ko08L600Go00001Ol0
Q`H01_l0003o1X`0o`J<0?l6S03o0000o`J<00?o00000_l6S0000ol0003o1X`0o`J<0002o`J<00Co
00000ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001?l6S0000ol0003o5I80oaFB0002oaFB0003
o`000?lETP3o5I8000?o5I800_l00005oaFB0003o`000?lETP3o5I8000;o5I800_l00006oaFB0003
o`000?l6S03o000000Co1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<00Co
00000_l6S0000ol0003o1X`0o`J<0003o`J<00;o00001Ol0Q`H00ol0003o08L6o`000002o`0000;o
08L60_l00004o`271PCo00000_l0Q`H00ol0003o08L6o`271P03o`271P;o00003?ooool00ol0003o
ooooooooo`0Iooooo`001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000?o0000
0_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000003oooo
o`04o`000?ooooooooooooooo`;o00001_ooool6o`0000Go5I800ol00004oaFB0005o`000?l6S03o
1X`0o`J<0?l000000_l6S0000ol0003o1X`0o`J<0003o`J<00?o00001?l6S002o`000003o`J<0?l0
003o000000?o08L600Co0000o`271_l0Q`Ko08L61Ol00003o`271P04o`000?l0Q`Ko08L6o`271POo
00001_l6S0001_l0003o1X`0o`000?l0003o1X`0o`0000Ko1X`000?o0000o`J<0?l000000_l00002
o`J<0003o`000?l6S03o1X`000;o1X`000?o0000oaFB0?lETP000_lETP000ol0003o5I80o`000002
o`0000;o5I8000?o0000oaFB0?lETP000_lETP000ol0003o5I80o`000002o`0000;o5I8000?o0000
oaFB0?lETP000olETP02o`0000Go1X`00_l00005o`J<0003o`000?l6S03o000000;o000000?o1X`0
o`000?l6S0001?l6S0000ol0003o1X`0o`000002o`0000;o1X`000?o0000o`271_l0Q`H00_l0Q`H2
o`0000Ko08L600?o0000o`271_l000000_l000000ol0Q`Ko0000o`271P04o`271P03o`000?l0Q`Ko
000000;o000000?o1X`0o`000?ooool02_ooool2o`0001_ooooo0002ooooo`05o`000?oooooooooo
ooooool000001oooool01ol0003ooooooooooooooooo0000ooooool000001Oooool01ol0003ooooo
oooooooooooo0000ooooool000000oooool00ol0003oooooo`000003ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003o5I80oaFB0003oaFB00;o000000?o5I80o`000?l000000_lETP00
0ol0003o5I80oaFB0003oaFB0003o`000?l6S03o000000Co1X`000?o0000o`J<0?l000000_l00002
o`J<0003o`000?l6S03o1X`000?o1X`00ol00004o`271PSo00001?l0Q`H4o`0000?o08L600Go0000
o`J<0?l6S03o1X`0o`000005o`J<00;o00001?l6S0000ol0003o1X`0o`J<0003o`J<00;o00001_l6
S0000ol0003o1X`0o`J<0009o`0000Co5I802?l00005oaFB0003o`000?lETP3o000000;o00000_lE
TP000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Co1X`00_l00005o`J<0003o`000?l6
S03o1X`000;o1X`00_l00006o`J<0004o`000?l0Q`Ko0000o`0000;o08L600Co0000o`271_l0Q`Ko
08L61?l00005o`271P03o`000?l0Q`Ko08L600;o08L60_l00005o`J<0003o`000?oooooooooo00[o
oooo00?o0000ooooooooool06?ooool000?ooooo0ol00008ooooo`Go000000?oooooo`000?l00000
0ol00002ooooo`?o00000oooool3o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo00Kooooo
00?o0000oaFB0?lETP000olETP02o`0000Go5I8000Co0000oaFB0?lETP3o5I800ol00005o`J<00Co
00001?l6S0000ol0003o1X`0o`000002o`0000?o08L600?o0000o`271_l000000ol00006o`271P04
o`000?l0Q`Ko0000o`0000;o08L600?o0000o`271_l0Q`H00ol0Q`H01_l0003o1X`0o`J<0?l6S03o
0000o`J<00?o00000_l6S0000ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o00000_l6
S0000ol0003o1X`0o`J<0003o`J<00?o00000_lETP000ol0003o5I80oaFB0004oaFB0004o`000?lE
TP3o0000o`0000;o5I8000?o0000oaFB0?lETP000olETP001?l0003o5I80oaFB0?lETP03o`0000Go
5I800_l00005o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<0002o`J<0003
o`000?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<0003o`J<00;o00001Ol0Q`H3o`0000Co
08L600?o0000o`271_l0Q`H00_l0Q`H00ol0003o08L6o`000002o`000003o`J<0?l0003o1X`000Co
1X`000?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`00;_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?lETP3o000000;o00000_lETP000ol0003o5I80oaFB0002oaFB00Co0000
0olETP001Ol0003o1X`0o`J<0?l6S03o000000Co1X`01ol00004o`271P?o00001?l0Q`H00ol0003o
08L6o`271P03o`271P;o00001Ol0Q`H01?l0003o08L6o`271_l0Q`H8o`0000Go1X`000?o0000o`J<
0?l6S0000ol00006o`J<0003o`000?l6S03o000000;o000000?o5I80o`000?lETP000olETP000ol0
003o5I80oaFB0003oaFB00;o00001OlETP001?l0003o5I80oaFB0?lETP05o`0000?o5I8000?o0000
oaFB0?l000000_l000000olETP3o0000o`J<0004o`J<00?o00001Ol6S0000ol0003o1X`0o`J<0003
o`0000Ko1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`271P03o`271P03o`000?l0Q`Ko
000000Go08L61ol00005o`J<0003o`000?l6S03o1X`000;o1X`00_l0000<ooooo`03o`000?oooooo
oooo00Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00000_ooool002kooooo00?o0000
ooooooooool02?ooool2o`0000Go5I8000Co0000oaFB0?l0003o00000_lETP000ol0003o5I80oaFB
0003oaFB0003o`000?l6S03o000000?o1X`00_l000000ol0Q`Ko0000o`271P04o`271PGo00000_l0
Q`H00ol0003o08L6o`271P02o`271P03o`000?l0Q`Ko000000;o00000_l0Q`H00ol0003o08L6o`27
1P02o`271PCo00000ol0Q`H00ol0003o1X`0o`J<0002o`J<0004o`000?l6S03o1X`0o`J<00Co0000
0ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001OlETP000ol0003o5I80oaFB0002oaFB0003o`00
0?lETP3o000000;o000000?o5I80o`000?lETP001?lETP04o`0000;o5I8000?o0000oaFB0?lETP00
0olETP02o`0000Go5I8000?o0000o`J<0?l6S0000_l00003o`J<0004o`000?l6S03o1X`0o`J<00Co
00000ol6S0001?l0003o1X`0o`J<0?l6S004o`0000Go1X`000Co0000o`271_l0Q`Ko00000ol0Q`H0
0ol0003o08L6o`000002o`000003o`J<0?l0003o1X`000?o1X`000?o0000o`J<0?l6S0000ol6S000
0ol0003o1X`0o`000002o`000003o`J<0?l0003ooooo00_ooooo0_l00006ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000_ooool002kooooo00?o0000ooooooooool02_oo
ool00ol0003o5I80oaFB0002oaFB00;o00001OlETP000ol0003o5I80oaFB0002oaFB00Co000000?o
1X`0o`000?l0Q`H00ol0Q`H01?l0003o08L6o`271_l0Q`H3o`0000Ko08L600?o0000o`271_l0Q`H0
0ol00006o`271P04o`000?l0Q`Ko0000o`0000;o08L600?o0000o`271_l0Q`H00ol0Q`H00ol0003o
1X`0o`J<0005o`0000?o1X`000?o0000o`J<0?l6S0000_l6S0000ol0003o1X`0o`000002o`000003
oaFB0?l0003o5I8000Co5I8000Co0000oaFB0?lETP3o5I800ol00005oaFB0003o`000?lETP3o0000
00;o000000?o5I80o`000?lETP001?lETP000ol0003o5I80o`000002o`0000;o5I8000?o0000oaFB
0?lETP000_lETP000ol0003o1X`0o`000005o`J<00Co00000_l6S0000ol0003o1X`0o`J<0002o`J<
00Co00001?l6S0000ol0003o1X`0o`J<0002o`J<0003o`000?l0Q`Ko000000Co08L60_l00005o`J<
0003o`000?l6S03o1X`000;o1X`000?o0000o`J<0?l6S0000_l6S002o`0000Go1X`000?o0000oooo
ooooool02oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool00_ooool002gooooo00?o0000ooooooooool03?ooool01?l0003o5I80o`000?l00002
oaFB0003o`000?lETP3o5I8000?o5I8000Co0000oaFB0?l0003o00000ol6S002o`0000Ko08L61?l0
0002o`271P03o`000?l0Q`Ko08L600?o08L60ol00003o`271P03o`000?l0Q`Ko08L600?o08L60_l0
0005o`271P04o`000?l0Q`Ko08L6o`271PCo00000ol6S0000ol0003o1X`0o`J<0002o`J<00So0000
1?lETP000ol0003o5I80oaFB0002oaFB00Co00000_lETP000ol0003o5I80oaFB0003oaFB00;o0000
1OlETP000ol0003o5I80oaFB0002oaFB00;o00001_lETP000ol0003o5I80oaFB0005o`000006o`J<
0?l0003o0000o`000?l6S03o00001Ol6S0001?l0003o1X`0o`000?l00002o`J<0003o`000?l6S03o
1X`000?o1X`01ol00003o`271P;o000000?o1X`0o`000?l6S0001?l6S002o`0000?o1X`000?o0000
o`J<0?l000000_l00002o`J<0003o`000?l6S03o1X`000;o1X`000?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00Ooo
ool002gooooo0_l0000>ooooo`;o00001?lETP001?l0003o5I80oaFB0?lETP05o`000003o`J<0?l0
003o000000;o1X`000?o0000o`271_l0Q`H01Ol00005o`271P03o`000?l0Q`Ko000000;o00000_l0
Q`H00ol0003o08L6o`271P02o`271P03o`000?l0Q`Ko000000;o00000_l0Q`H00ol0003o08L6o`27
1P02o`271PCo00000_l0Q`H00ol0003o1X`0o`J<0003o`J<0006o`000?l6S03o0000o`000?l6S03o
00001_l6S0001_l0003o5I80oaFB0?lETP3o0000oaFB00?o000000?o5I80o`000?lETP001?lETP00
0ol0003o5I80o`000002o`0000;o5I8000?o0000oaFB0?lETP000_lETP000ol0003o5I80o`000002
o`0000;o5I8000?o0000oaFB0?lETP000olETP03o`0000Co1X`00_l00005o`J<0004o`000?l6S03o
1X`0o`J<00?o00001Ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Co1X`000?o
0000o`271_l000001?l6S0000ol0003o1X`0o`J<0002o`J<00Oo00001Ol6S007o`0000gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00000_ooool002gooooo00?o0000ooooooooool03oooool00ol0003o5I80oaFB0005o`0000?o1X`0
0ol00004o`J<00Ko00000_l0Q`H00ol0003o08L6o`271P02o`271P?o00001Ol0Q`H00ol0003o08L6
o`271P04o`0000Go08L600Co0000o`271_l0003o00000_l0Q`H00ol0003o08L6o`271P02o`271P04
o`000?l6S03o1X`0o`J<00?o00001?l6S0000ol0003o1X`0o`J<0003o`J<00Oo00001?lETP000ol0
003o5I80oaFB0002oaFB00?o00001OlETP000ol0003o5I80oaFB0004o`0000Go5I8000?o0000oaFB
0?l000000_l00002o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001?l6S004o`00
00;o1X`000?o0000o`J<0?l6S0000ol6S002o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol00005
o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l000001?l6S0000ol0003o1X`0o`000002
o`000003o`J<0?l0003o1X`000Co1X`000?o0000ooooooooool02Oooool3o`0000?ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000;ooooo000]ooooo`03o`000?oo
oooooooo013ooooo0_l00004o`J<00Co00000ol6S004o`000004o`J<0?l0003o0000o`0000Go08L6
00Co0000o`271_l0003o00000ol0Q`H01?l0003o08L6o`271_l0Q`H4o`0000Co08L600Co0000o`27
1_l0Q`Ko08L60ol00005o`271P03o`000?l0Q`Ko08L600Go00000ol6S0000ol0003o1X`0o`J<0002
o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0003o5I80oaFB0002oaFB0003o`000?lETP3o
5I8000;o5I8000Co0000oaFB0?l0003o00000olETP001?l0003o5I80oaFB0?lETP04o`0000Co5I80
00Co0000oaFB0?lETP3o5I801?l00003o`J<00?o00001Ol6S0000ol0003o1X`0o`000002o`000003
o`J<0?l0003o1X`000Co1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<00Co
00000_l6S0000ol0003o1X`0o`J<0003o`J<00;o00001Ol6S002o`0000?o1X`00_l00005o`J<0004
o`000?l6S03o1X`0o`J<00?o00001oooool3o`0000;ooooo00?o0000ooooooooool00_ooool2o`00
00Wooooo0ol00003ooooo`00;Oooool00ol0003oooooooooo`0Booooo`04o`000?l6S03o0000o`00
00;o1X`000?o0000o`J<0?l6S0001?l000000ol6S03o0000o`000003o`J<0004o`000?l0Q`Ko08L6
o`271PCo00001?l0Q`H4o`0000?o08L600?o0000o`271_l0Q`H00_l0Q`H4o`0000?o08L600Co0000
o`271_l0Q`Ko08L61?l00002o`J<0003o`000?l6S03o1X`000Co1X`000?o0000o`J<0?l6S0000ol0
0006o`J<0003o`000?lETP3o5I8000So00001OlETP04o`0000;o5I8000?o0000oaFB0?lETP000olE
TP04o`0000?o1X`01?l00002o`J<0003o`000?l6S03o1X`000?o1X`00_l00005o`J<0004o`000?l6
S03o1X`0o`J<00?o00001Ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Co1X`0
00?o0000o`J<0?l000000_l00002o`J<0003o`000?l6S03o1X`000;o1X`000?o0000o`J<0?l00000
0_l000000ol6S03o0000o`J<0004o`J<00Co00000_l6S0000ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`0Cooooo`00;Oooool2o`0001Cooooo0_l00004o`J<00;o00000ol6
S003o`0000Co1X`01?l00004o`271P04o`000?l0Q`Ko0000o`0000;o08L600?o0000o`271_l0Q`H0
0ol0Q`H01?l0003o08L6o`000?l00002o`271P03o`000?l0Q`Ko08L600;o08L61?l00002o`J<0003
o`000?l6S03o1X`000;o1X`000?o0000o`J<0?l6S0000ol6S003o`0000?o1X`000?o0000o`J<0?l6
S0000ol6S003o`0000;o5I8000?o0000oaFB0?lETP000olETP000ol0003o5I80o`000002o`000003
oaFB0?l0003o5I8000Co5I8000?o0000oaFB0?l000000_l00003o`J<0004o`000?l6S03o0000o`00
00;o1X`000?o0000o`J<0?l6S0000_l6S0000ol0003o1X`0o`000002o`0000;o1X`000?o0000o`J<
0?l6S0000_l6S004o`0000;o1X`000?o0000o`J<0?l6S0000ol6S003o`0000Co1X`000?o0000o`J<
0?l6S0000_l6S002o`0000Go1X`02?l00004o`J<0003o`000?l6S03o000000;o000000?o1X`0o`00
0?l6S0001?l6S004o`0000Sooooo00?o0000ooooooooool04oooool00004ooooool0003o0000o`00
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`00
00;ooooo0_l00003ooooo`Go00000oooool2o`0001Oooooo1?l000000ol6S03o0000o`J<0002o`00
00?o1X`000Ko0000o`J<0?l0003o0000o`J<0?l00006o`271P;o00001Ol0Q`H01?l0003o08L6o`27
1_l0Q`H3o`0000Go08L600Ko0000o`271_l0003o0000o`J<0?l00005o`J<0003o`000?l6S03o1X`0
00;o1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0003o`000?l6S03o0000
00;o00000_l6S0001Ol0003o5I80oaFB0?lETP3o000000Co5I800_l00005oaFB0004o`000?lETP3o
5I80oaFB00Go00000ol6S003o`0000Co1X`02?l00005o`J<0006o`000?l6S03o0000o`000?l6S03o
00001Ol6S0000ol0003o1X`0o`000002o`0000?o1X`000Ko0000o`J<0?l6S03o1X`0o`000?l6S003
o`0000;o1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<00;o00000_l6S003
o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol0000:ooooo`03o`000?oooooooooo01?ooooo0000
1Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`[o00001?l6S002o`0000Co1X`000Co0000
o`271_l0Q`Ko08L60_l00002o`271P03o`000?l0Q`Ko08L600;o08L61?l00003o`271P03o`000?l0
Q`Ko08L600;o08L60_l00004o`J<0003o`000?l6S03o1X`000?o1X`000?o0000o`J<0?l6S0001?l0
0004o`J<0004o`000?l6S03o1X`0o`J<00Co00001?l6S006o`000003oaFB0?l0003o000000;o5I80
00?o0000oaFB0?lETP000_lETP04o`0000?o1X`01Ol00003o`J<0006o`000?l6S03o0000o`000?l6
S03o00001_l6S0001?l0003o1X`0o`J<0?l6S003o`0000Co1X`000Co0000o`J<0?l6S03o1X`01?l0
0005o`J<00Ko00001Ol6S002o`0000Go1X`000?o0000o`J<0?l6S0000_l6S004o`0000?o1X`000Co
0000o`J<0?l6S03o1X`01Ol00003o`J<0003o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4_ooool000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Booooo`?o
00000oooool00ol0003o1X`0o`J<0004o`J<0004o`000?l6S03o0000o`0000;o1X`000?o0000o`J<
0?l6S0000_l6S0000ol0003o08L6o`000005o`271P04o`000?l0Q`Ko0000o`0000;o08L600?o0000
o`271_l0Q`H00ol0Q`H01_l0003o08L6o`000?l0003o1X`0o`0000Go1X`000?o0000o`J<0?l6S000
0_l6S003o`0000Co1X`000?o0000o`J<0?l6S0001Ol00004o`J<0004o`000?l6S03o0000o`0000;o
1X`000?o0000oaFB0?lETP000_l00005oaFB0004o`000?lETP3o0000o`0000?o1X`01?l00002o`J<
0003o`000?l6S03o1X`000?o1X`00_l00004o`J<0003o`000?l6S03o1X`000?o1X`01?l00003o`J<
0003o`000?l6S03o1X`000Go00001?l6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`0
00?o1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0003o`000?l6S03o0000
00;o000000Co1X`0o`000?l6S03o00000ol6S004o`0000;o1X`000?o0000o`J<0?l6S0000ol6S002
o`0000Wooooo00?o0000ooooooooool04_ooool000;ooooo0_l0000;ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool4o`0000Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`?o00001oooool00ol0003o1X`0o`J<0003
o`J<00;o00001Ol6S0000ol0003o1X`0o`J<0003o`0000Ko08L60ol00004o`271P04o`000?l0Q`Ko
08L6o`271P?o00001?l6S0000ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o000000?o
1X`0o`000?l6S0001?l6S003o`0000?o1X`000?o0000o`J<0?l6S0000ol6S002o`0000Go1X`000Co
0000oaFB0?lETP3o00001OlETP04o`000005o`J<0?l0003o0000o`J<0?l000001Ol6S0000ol0003o
1X`0o`000002o`000003o`J<0?l0003o1X`000Co1X`000?o0000o`J<0?l000000_l000000ol6S03o
0000o`J<0004o`J<00?o00000ol6S0000ol0003o1X`0o`J<0003o`J<00;o00001Ol6S0001?l0003o
1X`0o`J<0?l6S002o`0000Go1X`000Co0000o`J<0?l6S03o1X`00ol00005o`J<00Go000000?o1X`0
o`000?l6S0001?l6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003ooooo00Sooooo00?o0000
ooooooooool04_ooool000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000003o`00
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000ooo
ool01Ol0003ooooooooooooooooo000000kooooo0_l0000;ooooo`03o`000?l6S03o000000;o0000
0_l6S0000ol0003o1X`0o`J<0002o`J<00?o00000ol6S0001?l0003o08L6o`271_l0Q`H2o`0000?o
08L600?o0000o`271_l0Q`H01Ol00002o`J<0003o`000?l6S03o1X`000?o1X`000?o0000o`J<0?l6
S0000ol00005o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<0002o`J<0003
o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001?l6S005o`000004oaFB0?l0003o0000o`00
00?o1X`00_l00004o`J<0003o`000?l6S03o1X`000;o1X`00ol00004o`J<0004o`000?l6S03o1X`0
o`J<00?o00001Ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000Co1X`000?o0000
o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0006o`000?l6S03o0000o`000?l6S03o0000
1Ol6S004o`0000;o1X`000?o0000o`J<0?l6S0000ol6S003o`0000Co1X`000?o0000o`J<0?l6S000
0_l6S002o`0000Go1X`000?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`0000Go
0000ooooooooooooooooo`000007ooooo`07o`000?ooooooooooooooool0003oooooo`000005oooo
o`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00_l0000;ooooo`?o00003_ooool00ol0003o1X`0o`J<0004o`J<0006o`000?l6
S03o0000o`000?l6S03o00001Ol6S0000ol0003o08L6o`000005o`271P?o00000_l6S0000ol0003o
1X`0o`J<0003o`J<0004o`000?l6S03o1X`0o`J<00Co00000ol6S0000ol0003o1X`0o`J<0002o`J<
00?o00001Ol6S0000ol0003o1X`0o`J<0003o`0000Go1X`000?o0000o`J<0?l000000_l000001?lE
TP3o0000o`J<0?l6S004o`000004o`J<0?l0003o0000o`0000;o1X`000?o0000o`J<0?l6S0000_l6
S0001?l0003o1X`0o`000?l00003o`J<0003o`000?l6S03o1X`000Go00000ol6S0000ol0003o1X`0
o`J<0002o`J<00;o00001Ol6S0000ol0003o1X`0o`J<0002o`J<00;o00001Ol6S0001?l0003o1X`0
o`J<0?l6S003o`0000Co1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0003
o`000?l6S03o000000;o00000_l6S002o`0000?o1X`000?o0000o`J<0?l000000_l00002o`J<0004
o`000?l6S03o1X`0o`J<00?o00001oooool00ol0003oooooooooo`0Booooo`0000Coooooo`000?l0
003o00002?ooool5o`000003ooooool0003o000000?o00000_ooool3o`0000?ooooo0ol00003oooo
o`?o00001?ooool00ol0003oooooooooo`06ooooo`?o00004_ooool00ol0003o1X`0o`J<0003o`J<
00?o00000ol6S0000ol0003o1X`0o`J<0002o`J<00?o00000ol0Q`H2o`000003o`J<0?l0003o1X`0
00?o1X`000?o0000o`J<0?l6S0000_l6S004o`0000Co1X`000Ko0000o`J<0?l6S03o1X`0o`000?l6
S002o`0000?o1X`000Co0000o`J<0?l6S03o1X`01?l00003o`J<0003o`000?l6S03o1X`000;o1X`0
0_l00005oaFB0003o`000?l6S03o1X`000;o1X`00ol00004o`J<00Oo00001Ol6S003o`0000?o1X`0
00?o0000o`J<0?l6S0000ol6S0001?l0003o1X`0o`000?l00002o`J<0003o`000?l6S03o1X`000;o
1X`000?o0000o`J<0?l000000_l00002o`J<0004o`000?l6S03o1X`0o`J<00Go00000_l6S0000ol0
003o1X`0o`J<0002o`J<00;o00001Ol6S0000ol0003o1X`0o`J<0002o`J<00;o00001Ol6S007o`00
00Go1X`01?l00002o`J<00;o00001_ooool00ol0003oooooooooo`0Booooo`00;?ooool00ol0003o
ooooooooo`03ooooo`?o00005_ooool00ol0003o1X`0o`000002o`0000?o1X`000Ko0000o`J<0?l6
S03o1X`0o`000?l6S002o`0000?o1X`000?o0000o`271_l000001?l6S0000ol0003o1X`0o`J<0002
o`J<0004o`000?l6S03o0000o`0000;o1X`000?o0000o`J<0?l6S0000ol6S007o`0000Co1X`01?l0
0002o`J<0003o`000?l6S03o1X`000?o1X`000Co0000o`J<0?l0003o00000_lETP000ol0003o5I80
oaFB0002oaFB0003o`000?l6S03o1X`000;o00000ol6S0001_l0003o1X`0o`000?l0003o1X`0o`00
00Go1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004o`J<0004o`000?l6S03o1X`0
o`J<00?o00001?l6S007o`0000Go1X`01?l00002o`J<0003o`000?l6S03o1X`000?o1X`000Co0000
o`J<0?l0003o00000_l6S0000ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o00000_l6
S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o000000Co1X`000?o0000o`J<0?l000000_l0
00000ol6S03o0000o`J<0003o`000003o`271_l0003ooooo00Gooooo00?o0000ooooooooool04_oo
ool002_ooooo0_l00002ooooo`?o00006_ooool2o`0000Go1X`01ol00004o`J<00;o00001_l6S000
0ol0003o1X`0o`J<0003o`0000Go1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004
o`J<0004o`000?l6S03o0000o`0000;o1X`000?o0000o`J<0?l6S0000_l6S0001?l0003o1X`0o`J<
0?l6S003o`0000Go5I8000Oo0000oaFB0?lETP3o5I80o`000?l6S03o000000Go1X`00_l00004o`J<
0003o`000?l6S03o1X`000;o1X`00_l00005o`J<0004o`000?l6S03o1X`0o`J<00Go00000ol6S000
1_l0003o1X`0o`000?l0003o1X`0o`0000Go1X`000?o0000o`J<0?l000000_l000000ol6S03o0000
o`J<0004o`J<0004o`000?l6S03o1X`0o`J<00?o00001?l6S007o`0000Go1X`00_l00005o`J<00;o
00000_l6S003o`0000?o1X`00ol00005o`271P03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04Oooool002_ooooo1?l0000Oooooo`;o000000?o1X`0o`000?l000000ol6S0001_l0003o1X`0
o`J<0?l6S03o0000o`J<00;o00000_l6S0000ol0003o1X`0o`J<0003o`J<00?o00000ol6S0000ol0
003o1X`0o`J<0002o`J<00;o00001Ol6S0000ol0003o1X`0o`J<0002o`J<00;o00001Ol6S0000ol0
003o1X`0o`J<0005o`0000;o5I8000?o0000oaFB0?lETP000olETP07o`0000?o1X`00_l000000ol6
S03o0000o`J<0003o`J<0003o`000?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<0002o`J<
00Co00000_l6S0000ol0003o1X`0o`J<0003o`J<00;o00001?l6S0000ol0003o1X`0o`J<0002o`J<
00;o00001Ol6S0001?l0003o1X`0o`J<0?l6S005o`0000?o1X`000Co0000o`J<0?l0003o00000_l6
S0000ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001?l6
S004o`0000;o1X`01?l00003o`271P04o`000?l0Q`Ko08L6o`271P?o00001Oooool00ol0003ooooo
ooooo`0Aooooo`00:oooool2o`0002?ooooo0_l00004o`J<00Oo00001?l6S0000ol0003o1X`0o`00
0002o`000003o`J<0?l0003o1X`000Co1X`000Co0000o`J<0?l0003o00000_l6S0000ol0003o1X`0
o`J<0002o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001?l6S003o`0000;o5I80
00?o0000oaFB0?lETP000olETP000ol0003o5I80o`000002o`000003oaFB0?l0003o5I8000Co5I80
00?o0000o`J<0?l000001?l6S0000ol0003o1X`0o`J<0004o`0000Go1X`000Ko0000o`J<0?l0003o
0000o`J<0?l00005o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001?l6S0001?l0
003o1X`0o`000?l00002o`J<0003o`000?l6S03o1X`000;o1X`01?l00002o`J<0003o`000?l6S03o
1X`000?o1X`00_l00004o`J<00Oo00001Ol6S0000ol0003o1X`0o`000002o`0000;o1X`000Ko0000
o`J<0?l0003o0000o`271_l00005o`271PCo00000_l0Q`H00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo017ooooo000]ooooo`03o`000?oooooooooo02;ooooo00Ko0000o`J<0?l0003o0000
o`J<0?l00005o`J<0003o`000?l6S03o1X`000Co00001?l6S0001?l0003o1X`0o`J<0?l6S004o`00
00Co1X`000?o0000o`J<0?l6S0001?l00004o`J<0003o`000?l6S03o000000;o000000?o5I80o`00
0?lETP000olETP000ol0003o5I80oaFB0002oaFB00;o00001OlETP000ol0003o5I80oaFB0002oaFB
00;o00001Ol6S003o`0000Co1X`000Co0000o`J<0?l6S03o1X`00ol00004o`J<0004o`000?l6S03o
1X`0o`J<00?o00001Ol6S0001?l0003o1X`0o`J<0?l6S003o`0000Go1X`000Co0000o`J<0?l0003o
00000ol6S0001_l0003o1X`0o`J<0?l6S03o0000o`J<00?o00000_l6S0001_l0003o1X`0o`000?l0
003o1X`0o`0000Go1X`000Co0000o`J<0?l6S03o1X`01?l00003o`J<00?o00001?l0Q`H00ol0003o
08L6o`000002o`000003o`271_l0003o08L600Co08L600?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Aooooo`00;_ooool00ol0003oooooooooo`0Rooooo`03o`000?l6S03o1X`000;o1X`0
00?o0000o`J<0?l6S0000_l6S003o`0000Co1X`000?o0000o`J<0?l6S0001Ol00004o`J<0003o`00
0?l6S03o1X`000Co00001?l6S0000ol0003o1X`0o`J<0003o`0000Go5I8000?o0000oaFB0?lETP00
0_lETP001?l0003o5I80o`000?l00002oaFB0003o`000?lETP3o5I8000;o5I8000?o0000oaFB0?l0
00000_l000000olETP3o0000o`J<0002o`J<00;o00000_l6S0000ol0003o1X`0o`J<0002o`J<00Co
00000_lETP000ol0003o1X`0o`J<0002o`J<00Co00000ol6S0001?l0003o1X`0o`J<0?l6S005o`00
00?o1X`000Co0000o`J<0?l6S03o1X`00ol00005o`J<00Ko00001Ol6S002o`0000Co1X`000?o0000
o`J<0?l6S0000_l6S004o`0000?o1X`01?l00002o`271P;o00000ol0Q`H2o`0000Go08L600?o0000
o`271_l0Q`H00_l0Q`H2o`0000?ooooo00?o0000ooooooooool04Oooool002oooooo00?o0000oooo
ooooool08Oooool00ol0003o1X`0o`J<0003o`J<0004o`000?l6S03o0000o`0000;o1X`000?o0000
o`J<0?l6S0000_l6S003o`0000?o1X`000?o0000o`J<0?l6S0000ol6S003o`0000?o1X`000?o0000
o`J<0?l6S0000_l6S003o`0000?o5I8000?o0000oaFB0?lETP000_lETP000ol0003o5I80oaFB0002
oaFB00;o00001OlETP000ol0003o5I80oaFB0004o`0000Co5I8000?o0000o`J<0?l000001Ol6S000
1_l0003o1X`0o`000?l0003o5I80o`0000Go5I8000Co0000o`J<0?l6S03o00000_l6S0000ol0003o
1X`0o`J<0002o`J<00Co00000ol6S0001?l0003o1X`0o`J<0?l6S005o`0000?o1X`000?o0000o`J<
0?l000000_l000000ol6S03o0000o`J<0003o`J<0003o`000?l6S03o000000;o000000?o1X`0o`00
0?l6S0001?l6S0001_l0003o1X`0o`000?l0003o1X`0o`0000?o1X`00_l000000ol0Q`Ko0000o`27
1P04o`271PCo00000_l0Q`H00ol0003o08L6o`271P02o`271P03o`000?l0Q`Ko000000;o00000_l0
Q`H01?l0003oooooooooool0000Cooooo`00<?ooool2o`0002;ooooo00?o0000o`J<0?l6S0000_l6
S002o`0000Go1X`000Ko0000o`J<0?l0003o0000o`J<0?l00005o`J<0003o`000?l6S03o000000;o
00000_l6S0000ol0003o1X`0o`J<0002o`J<0006o`000?l6S03o0000o`000?lETP3o00001OlETP00
1_l0003o5I80oaFB0?lETP3o0000oaFB00?o00000_lETP001?l0003o5I80oaFB0?lETP04o`0000Co
5I8000?o0000oaFB0?lETP001?l00005o`J<00;o00001?lETP000ol0003o5I80oaFB0002oaFB0003
o`000?l6S03o000000Co1X`000Co0000o`J<0?l0003o00000ol6S0000ol0003o1X`0o`J<0005o`00
00?o1X`000Co0000o`J<0?l6S03o1X`00ol00004o`J<0003o`000?l6S03o1X`000;o1X`00_l00005
o`J<0004o`000?l6S03o1X`0o`J<00?o00001?l6S0000ol0003o1X`0o`000004o`271P04o`000?l0
Q`Ko08L6o`271P?o00001?l0Q`H7o`0000Go08L60_l000000ooooooo0000ooooo`0Booooo`00<_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<
0002o`J<00?o00000ol6S0000ol0003o1X`0o`J<0002o`J<00?o00001?l6S007o`0000Co5I8000?o
0000oaFB0?lETP000_lETP07o`0000Co5I801?l00003oaFB0003o`000?lETP3o5I8000;o5I800ol0
0004oaFB0003o`000?l6S03o000000;o000000?o5I80o`000?lETP000olETP001?l0003o5I80oaFB
0?lETP03o`0000Go1X`00_l00005o`J<00?o00000_l6S0000ol0003o1X`0o`J<0003o`J<00Co0000
0ol6S0000ol0003o1X`0o`J<0002o`J<00Co00000_l6S0001?l0003o1X`0o`J<0?l6S005o`0000;o
1X`000?o0000o`J<0?l6S0000_l6S002o`0000Go08L61?l00003o`271P06o`000?l0Q`Ko0000o`00
0?l0Q`Ko00001Ol0Q`H00ol0003o08L6o`000002o`000005o`271_l0003oooooooooool000004_oo
ool003?ooooo00?o0000ooooooooool07oooool00ol0003o1X`0o`J<0004o`J<0004o`000?l6S03o
0000o`0000?o1X`000Ko0000o`J<0?l6S03o1X`0o`000?l6S002o`0000?o1X`000Ko0000o`J<0?l0
003o0000oaFB0?l00004oaFB0003o`000?lETP3o5I8000?o5I8000Ko0000oaFB0?l0003o0000oaFB
0?l00005oaFB0004o`000?lETP3o0000o`0000;o5I8000?o0000oaFB0?lETP000olETP001_l0003o
5I80o`000?l0003o5I80o`0000Go5I800_l00005oaFB0004o`000?lETP3o5I80oaFB00Co00000olE
TP000ol0003o1X`0o`000002o`0000;o1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<
0003o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0001?l6S006o`0000Go1X`01?l0
0002o`J<0003o`000?l6S03o1X`000?o1X`000Co0000o`J<0?l0003o00000_l6S0000ol0003o08L6
o`000002o`0000;o08L600Co0000o`271_l0Q`Ko08L60ol00004o`271P04o`000?l0Q`Ko08L6o`27
1P?o00001Ol0Q`H00ol0003oooooo`00000Booooo`00=?ooool00ol0003oooooooooo`0Oooooo`03
o`000?l6S03o1X`000?o1X`00ol00004o`J<00Oo00001?l6S002o`0000Co5I8000?o0000oaFB0?lE
TP000_lETP000ol0003o5I80oaFB0002oaFB00;o00001?lETP000ol0003o5I80oaFB0002oaFB00?o
00001?lETP001?l0003o5I80oaFB0?lETP03o`0000Co5I8000?o0000oaFB0?l000000_l00002oaFB
0003o`000?lETP3o5I8000;o5I8000Co0000oaFB0?l0003o00000olETP000ol0003o5I80oaFB0003
o`0000Go1X`00_l00005o`J<0003o`000?l6S03o1X`000?o00001Ol6S0000ol0003o1X`0o`000002
o`000003o`J<0?l0003o1X`000?o1X`000?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0004
o`J<0004o`000?l6S03o1X`0o`J<00?o00001?l6S002o`0000Go08L61?l00002o`271P;o00000_l0
Q`H5o`0000?o08L600Co0000o`271_l0Q`Ko08L61?l0000Booooo`00=Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?l6S03o000000;o00000ol6S0001?l0003o1X`0o`000?l00002o`J<0003o`00
0?l6S03o1X`000;o1X`000Ko0000o`J<0?l0003o0000oaFB0?l00005oaFB0006o`000?lETP3o5I80
oaFB0?l0003o5I800ol00002oaFB0003o`000?lETP3o5I8000;o5I8000Co0000oaFB0?l0003o0000
0olETP000ol0003o5I80oaFB0005o`0000?o5I8000?o0000oaFB0?lETP001?l00004oaFB00Oo0000
1OlETP03o`0000?o5I8000Oo0000o`J<0?l6S03o1X`0o`000?l6S03o000000Go1X`00ol00002o`J<
0003o`000?l6S03o1X`000?o1X`00_l00005o`J<0004o`000?l6S03o1X`0o`J<00;o00001Ol6S000
1?l0003o1X`0o`J<0?l6S005o`0000?o1X`000Ko0000o`J<0?l0003o0000o`J<0?l00003o`271P;o
000000?o08L6o`000?l0Q`H00ol0Q`H4o`0000;o08L600?o0000o`271_l0Q`H00ol0Q`H4o`0000;o
08L60_l0000Booooo`00=_ooool2o`00023ooooo00?o0000o`J<0?l6S0001?l6S002o`0000Go1X`0
00?o0000o`J<0?l6S0000ol00004oaFB0003o`000?lETP3o5I8000;o5I8000?o0000oaFB0?lETP00
1?l00004oaFB00Oo00001OlETP03o`0000Co5I8000?o0000oaFB0?lETP001?l00004oaFB0006o`00
0?lETP3o0000o`000?lETP3o00001OlETP000ol0003o5I80o`000002o`000003oaFB0?l0003o5I80
00Co5I8000?o0000o`J<0?l000000ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`0
00?o1X`000?o0000o`J<0?l000000_l00002o`J<0003o`000?l6S03o1X`000;o1X`000Co0000o`J<
0?l0003o00000_l6S0001?l0003o1X`0o`J<0?l6S005o`0000?o1X`000Co0000o`J<0?l6S03o1X`0
0ol00004o`J<0003o`000?l0Q`Ko000000Co08L61?l000000ol0Q`Ko0000o`000004o`271P03o`00
0?l0Q`Ko000000;o000000?o08L6o`000?l0Q`H00ol0Q`H2o`0001;ooooo000hooooo`03o`000?oo
oooooooo01kooooo00Co0000o`J<0?l6S03o1X`00_l00002o`J<0004o`000?l6S03o1X`0o`J<00Co
00000_lETP000ol0003o5I80oaFB0003oaFB0003o`000?lETP3o5I8000Co00001?lETP001?l0003o
5I80o`000?l00003oaFB0006o`000?lETP3o5I80oaFB0?l0003o5I800ol00002oaFB0004o`000?lE
TP3o5I80oaFB00Co00000olUV0000ol0003o5I80oaFB0002oaFB00;o00001?lETP000ol0003o5I80
oaFB0002oaFB00;o00001OlETP001?l0003o5I80oaFB0?lETP03o`0000Co1X`00_l00005o`J<0003
o`000?l6S03o1X`000Co00001?l6S007o`0000Co1X`01?l00002o`J<0003o`000?l6S03o1X`000?o
1X`01?l00002o`J<0004o`000?l6S03o1X`0o`J<00?o00001?l0Q`H2o`0000Go08L60_l00002o`27
1P?o00001Ol0Q`H4o`000003ooooool0003ooooo017ooooo000iooooo`03o`000?oooooooooo01ko
oooo00?o0000o`J<0?l000001?l6S004o`0000;o5I8000?o0000oaFB0?lETP000_lETP000ol0003o
5I80oaFB0002oaFB00?o00000olETP000ol0003o5I80oaFB0002oaFB00?o00001?lETP07o`0000Co
5I801?l00002obFH0003o`000?lUV03o9IP000?o9IP000Co0000oaFB0?l0003o00000_lETP000ol0
003o5I80oaFB0002oaFB0004o`000?lETP3o0000o`0000;o5I8000?o0000oaFB0?lETP000_lETP04
o`0000;o5I8000Go0000o`J<0?l6S03o1X`0o`000002o`J<0004o`000?l6S03o1X`0o`J<00Co0000
1?l6S0001_l0003o1X`0o`000?l0003o1X`0o`0000Go1X`000Co0000o`J<0?l0003o00000_l6S000
0ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o000000?o1X`0o`000?l6S0000ol6S004
o`0000;o1X`000Go0000o`271_l0Q`Ko08L6o`000002o`271P04o`000?l0Q`Ko08L6o`271PGo0000
0ol0Q`H00ol0003o08L6o`271P03o`0000Cooooo00?o0000ooooooooool04?ooool003[ooooo00?o
0000ooooooooool07_ooool2o`0000?o1X`000?o0000oaFB0?l000001OlETP000ol0003o5I80oaFB
0002oaFB0004o`000?lETP3o0000o`0000;o5I8000?o0000oaFB0?lETP000_lETP001?l0003o5I80
o`000?l00003oaFB0006o`000?lETP3o0000o`000?lETP3o00001OlETP001_l0003o5I80o`000?l0
003o9IP0o`0000Go9IP000?o0000obFH0?lUV0000_lUV002o`0000Co5I801ol00005oaFB0006o`00
0?lETP3o0000o`000?lETP3o00001OlETP000ol0003o1X`0o`000003o`J<00Co00000ol6S0001?l0
003o1X`0o`J<0?l6S003o`0000Co1X`000?o0000o`J<0?l6S0000_l6S002o`0000Go1X`000?o0000
o`J<0?l6S0000ol00005o`J<0004o`000?l6S03o0000o`0000;o1X`000?o0000o`J<0?l6S0000_l6
S0000ol0003o08L6o`000003o`271PCo00000_l0Q`H2o`0000Co08L60ol00008ooooo`03o`000?oo
oooooooo00oooooo000kooooo`;o00008?ooool00ol0003o1X`0o`000003oaFB0003o`000?lETP3o
5I8000;o5I8000Co0000oaFB0?lETP3o5I800ol00004oaFB00Oo00001OlETP02o`0000Co5I8000?o
0000oaFB0?lETP000_lETP02o`0000Co9IP000?o0000obFH0?lUV0000_lUV0000ol0003o9IP0obFH
0002o`0000;o9IP000Co0000oaFB0?l0003o00000_lETP000ol0003o5I80oaFB0002oaFB0004o`00
0?lETP3o5I80oaFB00?o00001?lETP001?l0003o5I80oaFB0?lETP03o`0000?o1X`000Co0000o`J<
0?l6S03o00001?l6S004o`0000?o1X`000Ko0000o`J<0?l6S03o1X`0o`000?l6S003o`0000;o1X`0
00Co0000o`J<0?l6S03o1X`01?l00003o`J<0004o`000?l6S03o1X`0o`J<00?o00001?l6S007o`00
00?o08L600Co0000o`271_l0Q`Ko00001?l0Q`H5o`0000_ooooo00?o0000ooooooooool03oooool0
03gooooo00?o0000ooooooooool07_ooool00ol0003o5I80oaFB0003oaFB0003o`000?lETP3o5I80
00Go00000olETP001?l0003o5I80o`000?l00002oaFB0003o`000?lETP3o5I8000;o5I8000?o0000
oaFB0?l000000_l00002oaFB0006o`000?lETP3o5I80oaFB0?l0003o5I800ol000000olUV03o0000
obFH0004obFH0007o`000?lUV03o9IP0obFH0?l0003o9IP0o`000004obFH00;o00001OlETP000ol0
003o5I80oaFB0005o`0000?o5I8000?o0000oaFB0?lETP001Ol00003oaFB0003o`000?l6S03o0000
00Co1X`000Ko0000o`J<0?l0003o0000o`J<0?l00005o`J<00Ko00001Ol6S004o`0000?o1X`000?o
0000o`J<0?l6S0001Ol00003o`J<0006o`000?l6S03o0000o`000?l6S03o00001Ol6S0000ol0003o
08L6o`000003o`271PSo00003Oooool00ol0003oooooooooo`0?ooooo`00?_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?lETP3o5I8000?o5I800ol00004oaFB0003o`000?lETP3o5I8000Co0000
1?lETP000ol0003o5I80oaFB0004o`0000Co5I801_l00005obFH0003o`000?lUV03o9IP000;o9IP0
1ol00003obFH0004o`000?lUV03o9IP0o`0000?o5I801?l00003oaFB0004o`000?lETP3o5I80oaFB
00Co00001?lETP000ol0003o5I80oaFB0003o`0000Go1X`00_l00004o`J<0003o`000?l6S03o0000
00;o00000_l6S0001_l0003o1X`0o`J<0?l6S03o0000o`J<00?o00000_l6S0001?l0003o1X`0o`J<
0?l6S004o`0000;o1X`000?o0000o`J<0?l6S0000ol6S002o`0000Co1X`000?o0000o`J<0?l6S000
0_l6S002o`0000?o08L600?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00oooooo000oooooo`03o`000?oooooooooo01gooooo00Go0000oaFB0?lETP3o5I80
o`000002obFH0003o`000?lETP3o5I8000;o5I800ol00004oaFB0003o`000?lETP3o5I8000Co0000
1?lETP001_l0003o5I80o`000?l0003o9IP0o`0000Co9IP000?o0000obFH0?lUV0000_lUV0000ol0
003o9IP0o`000002o`000003obFH0?l0003o9IP000Co9IP000?o0000obFH0?l000000olUV004o`00
00;o5I8000?o0000oaFB0?lETP000_lETP04o`0000?o5I8000Co0000oaFB0?lETP3o5I801?l00003
oaFB0003o`000?l6S03o000000;o00000_l6S0000ol0003o1X`0o`J<0004o`0000Co1X`01ol00004
o`J<00Co00000_l6S0000ol0003o1X`0o`J<0002o`J<0003o`000?l6S03o000000;o000000?o1X`0
o`000?l6S0000ol6S0000ol0003o1X`0o`000002o`0000;o1X`000?o0000o`271_l000002Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo0010ooooo`;o00007_ooool00ol0
003o5I80o`000004obFH0004o`000?lETP3o0000o`0000?o5I8000?o0000oaFB0?lETP001?l00003
oaFB0003o`000?lETP3o5I8000;o5I800_l00004obFH0003o`000?lUV03o9IP000;o9IP000?o0000
obFH0?lUV0001?l00004obFH0004o`000?lUV03o9IP0obFH00?o00000olUV0001Ol0003o9IP0obFH
0?lUV03o000000?o5I8000Co0000oaFB0?l0003o00000olETP000ol0003o5I80oaFB0005o`0000?o
5I8000?o0000oaFB0?lETP001?l00003o`J<00Co00001?l6S0001_l0003o1X`0o`000?l0003o1X`0
o`0000Go1X`000Ko0000o`J<0?l0003o0000o`J<0?l00005o`J<0003o`000?l6S03o1X`000?o0000
1?l6S007o`0000Go1X`00_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3oooool004;ooooo00?o0000ooooooooool07?ooool2o`0000Co9IP00ol00004oaFB00?o00000olE
TP000ol0003o5I80oaFB0002oaFB0006o`000?lETP3o0000o`000?lUV03o00001OlUV0001?l0003o
9IP0obFH0?lUV003o`0000Co9IP000?o0000obFH0?lUV0001Ol00003obFH0003o`000?lUV03o0000
00Co9IP01_l00005oaFB00?o00000_lETP000ol0003o5I80oaFB0003oaFB00?o00000ol6S004o`00
00;o1X`000?o0000o`J<0?l6S0000ol6S002o`0000Co1X`000?o0000o`J<0?l6S0000_l6S002o`00
00Co1X`000?o0000o`J<0?l6S0001Ol00003o`J<0006o`000?l6S03o0000o`000?l6S03o00001Ol6
S0000ol0003o1X`0o`000002o`0000kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0?ooooo`00@oooool00ol0003oooooooooo`0Mooooo`04o`000?lUV03o0000o`0000?o9IP000Ko
0000oaFB0?l0003o0000oaFB0?l00005oaFB0003o`000?lETP3o5I8000?o00001?lUV0000ol0003o
9IP0obFH0002obFH0004o`000?lUV03o0000o`0000;o9IP000?o0000obFH0?lUV0000_lUV003o`00
00?o9IP000?o0000obFH0?lUV0000_lUV002o`0000?o9IP00_l000000olUV03o0000oaFB0003oaFB
0003o`000?lETP3o000000;o000000?o5I80o`000?lETP000olETP000ol0003o5I80o`000002o`00
00;o1X`000Ko0000o`J<0?l0003o0000o`J<0?l00005o`J<0003o`000?l6S03o000000;o00000_l6
S0001_l0003o1X`0o`J<0?l6S03o0000o`J<00?o00000_l6S0000ol0003o1X`0o`J<0004o`0000?o
1X`000Co0000o`J<0?l6S03o1X`00ol00004o`J<0004o`000?l6S03o1X`0o`J<00?o00004Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo0014ooooo`03o`000?oooooooooo
01gooooo00?o0000obFH0?lUV0000olUV002o`0000Co5I8000Co0000oaFB0?lETP3o5I801?l00002
obFH0003o`000?lUV03o9IP000?o9IP000?o0000obFH0?lUV0000ol00005obFH0004o`000?lUV03o
0000o`0000;o9IP000?o0000obFH0?lUV0000_lUV0001?l0003o9IP0o`000?l00002obFH0003o`00
0?lUV03o000000Co9IP000Co0000oaFB0?lETP3o5I800ol00004oaFB0003o`000?lETP3o5I8000Go
00000_l6S003o`0000Co1X`000Co0000o`J<0?l6S03o1X`00ol00005o`J<00Ko00001Ol6S003o`00
00;o1X`000?o0000o`J<0?l6S0000_l6S004o`0000?o1X`000?o0000o`J<0?l6S0001Ol0000Eoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool004Gooooo00?o0000oooooooo
ool07?ooool01?l0003o9IP0obFH0?lUV002o`0000;o9IP000?o0000oaFB0?lETP001Ol00002obFH
0003o`000?lUV03o9IP000;o9IP000Co0000obFH0?lUV03o9IP01?l00003obFH0004o`000?lUV03o
9IP0obFH00?o00001?lUV007o`0000Co9IP00ol00004obFH0004o`000?lETP3o0000o`0000?o5I80
00?o0000oaFB0?lETP001?l00004o`J<00?o00000ol6S0000ol0003o1X`0o`J<0005o`0000?o1X`0
00?o0000o`J<0?l000000_l000000ol6S03o0000o`J<0003o`J<0003o`000?l6S03o000000;o0000
0_l6S0001_l0003o1X`0o`J<0?l6S03o0000o`J<00;o00000_l6S0001?l0003o1X`0o`J<0?l6S004
o`0001_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`00A_ooool2o`00
01gooooo00?o0000obFH0?l000001?lUV003o`0000?o9IP000?o0000obFH0?lUV0000_lUV0001?l0
003o9IP0obFH0?lUV004o`0000?o9IP000?o0000obFH0?lUV0001Ol00003obFH0004o`000?lUV03o
0000o`0000;o9IP000?o0000obFH0?lUV0000_lUV0001?l0003o9IP0o`000?l00003obFH0003o`00
0?lUV03o9IP000?o00001OlETP03o`0000;o5I8000Co0000o`J<0?l6S03o1X`00_l00002o`J<0003
o`000?l6S03o1X`000Co00001?l6S0000ol0003o1X`0o`J<0003o`0000Go1X`000?o0000o`J<0?l6
S0000ol00005o`J<00Ko00001?l6S004o`00023ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0>ooooo`00B?ooool00ol0003oooooooooo`0Kooooo`;o00000olUV0000ol0003o9IP0
o`000005obFH0006o`000?lUV03o9IP0obFH0?l0003o9IP00_l00003obFH0003o`000?lUV03o9IP0
00Co00001?lUV0000ol0003o9IP0obFH0003o`0000Go9IP000?o0000obFH0?lUV0001?l00004obFH
00?o00000olUV0000ol0003o5I80o`000002o`0000;o5I8000Oo0000oaFB0?lETP3o5I80o`000?l6
S03o000000Co1X`00ol00002o`J<0003o`000?l6S03o1X`000?o1X`00ol00003o`J<0004o`000?l6
S03o1X`0o`J<00Co00000ol6S0000ol0003o1X`0o`000002o`000003o`J<0?l0003o1X`000?o1X`0
00Co0000o`J<0?l0003o00009?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00ko
oooo0019ooooo`03o`000?oooooooooo01cooooo00?o0000obFH0?l000000olUV0000ol0003o9IP0
obFH0002obFH00Oo00001?lUV003o`0000?o9IP000?o0000obFH0?lUV0000_lUV003o`0000?o9IP0
00Co0000obFH0?lUV03o9IP01?l00004obFH0006o`000?lUV03o0000o`000?lUV03o00001?lUV003
o`0000Co5I801_l00003o`J<00;o00000_l6S0001_l0003o1X`0o`J<0?l6S03o0000o`J<00?o0000
00?o1X`0o`000?l6S0000ol6S004o`0000;o1X`000?o0000o`J<0?l6S0000_l6S002o`0000Go1X`0
00?o0000o`J<0?l6S0000ol0000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
3_ooool004[ooooo00?o0000ooooooooool07?ooool2o`0000Co9IP000Co0000obFH0?l0003o0000
0_lUV0000ol0003o9IP0obFH0002obFH0004o`000?lUV03o0000o`0000;o9IP000?o0000obFH0?lU
V0000_lUV0001_l0003o9IP0o`000?l0003o9IP0o`0000Co9IP01?l00002obFH0003o`000?lUV03o
9IP000?o9IP00_l00004obFH0004o`000?lUV03o9IP0o`0000?o9IP000Ko0000oaFB0?l0003o0000
oaFB0?l00004oaFB0003o`000?l6S03o000000Co1X`01_l00005o`J<0004o`000?l6S03o0000o`00
00;o1X`000?o0000o`J<0?l6S0000_l6S0001?l0003o1X`0o`000?l00002o`J<0004o`000?l6S03o
1X`0o`J<00Co0000:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo001;
ooooo`;o00007_ooool00ol0003o9IP0obFH0004o`0000Co9IP000?o0000obFH0?lUV0000ol00005
obFH0003o`000?lUV03o9IP000?o00001?lUV0001?l0003o9IP0o`000?l00002obFH0003o`000?lU
V03o9IP000;o9IP000?o0000obFH0?l000000_l00002obFH0007o`000?lUV03o9IP0obFH0?l0003o
9IP0o`000004obFH00;o00001?lETP001?l0003o5I80oaFB0?lETP03o`0000?o1X`000Co0000o`J<
0?l6S03o00000ol6S0001?l0003o1X`0o`J<0?l6S003o`0000Co1X`01ol00004o`J<00Co0000<?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo001=ooooo`03o`000?oooooo
oooo01cooooo0_l00004obFH0003o`000?lUV03o9IP000Co00000olUV0001?l0003o9IP0obFH0?lU
V004o`0000?o9IP000?o0000obFH0?lUV0001?l00004obFH0003o`000?lUV03o9IP000Co00001?lU
V007o`000004obFH0?l0003o0000o`0000;o5I8000Ko0000oaFB0?lETP3o5I80o`000?lETP02o`00
00?o5I8000?o0000o`J<0?l000000ol6S008o`0000?o1X`000Ko0000o`J<0?l0003o0000o`J<0?l0
0005o`J<0004o`000?l6S03o0000o`0003Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0=ooooo`00C_ooool00ol0003oooooooooo`0Looooo`04o`000?lUV03o9IP0obFH00Co0000
0olUV0000ol0003o9IP0obFH0005o`0000;o9IP000?o0000obFH0?lUV0000_lUV003o`0000Co9IP0
00?o0000obFH0?lUV0001?l00004obFH0004o`000?lUV03o0000o`0000;o9IP000?o0000obFH0?lU
V0001?l00004oaFB00Ko00001OlETP02o`0000?o1X`000?o0000o`J<0?l000001Ol6S0000ol0003o
1X`0o`J<0003o`0000Co1X`000Co0000o`J<0?l6S03o1X`00ol0000gooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03Oooool004oooooo00?o0000ooooooooool07?ooool3o`0000;o
9IP000?o0000obFH0?lUV0000_lUV003o`0000Co9IP000Ko0000obFH0?lUV03o9IP0o`000?lUV002
o`0000?o9IP000?o0000obFH0?lUV0001?l00004obFH0003o`000?lUV03o9IP000[o00001?lETP00
1?l0003o5I80o`000?l00002oaFB0006o`000?lETP3o5I80oaFB0?l0003o5I800ol00002oaFB0003
o`000?l6S03o000000?o1X`000Co0000o`J<0?l6S03o1X`01?l00003o`J<0003o`000?l6S03o1X`0
00Go0000>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo001@ooooo`;o
00007_ooool01_l0003o9IP0obFH0?lUV03o0000obFH00;o00000olUV0000ol0003o9IP0obFH0007
o`0000Go9IP00ol00002obFH0003o`000?lUV03o9IP000?o9IP00ol000000olUV03o0000o`000002
oaFB0005o`000?lETP3o5I80oaFB0?l000000olETP03o`0000Co5I801ol00004oaFB00;o00001?l6
S004o`0000?o1X`000?o0000o`J<0?l6S0001?l00010ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool005;ooooo00?o0000ooooooooool07?ooool5o`0000Go9IP00ol00002
obFH0003o`000?lUV03o9IP000;o9IP000?o0000obFH0?l000000_l00002obFH0006o`000?lUV03o
9IP0obFH0?l0003o9IP00ol000001?lUV03o0000o`000?l00004oaFB00So00000olETP001_l0003o
5I80o`000?l0003o5I80o`0000Go5I8000Co0000oaFB0?l0003o00000_lETP001?l0003o1X`0o`00
0?l00002o`J<0003o`000?l6S03o1X`000;o1X`00ol00015ooooo`05o`000?ooooooooooooooool0
00003oooool005?ooooo00?o0000ooooooooool06oooool00ol0003o9IP0obFH0002obFH0003o`00
0?lUV03o000000;o000000?o9IP0o`000?lUV0000olUV0000ol0003o9IP0obFH0004o`0000Co9IP0
2_l00003oaFB0006o`000?lETP3o0000o`000?lETP3o00001OlETP000ol0003o5I80oaFB0003o`00
00Co5I8000Co0000oaFB0?lETP3o5I800ol00004oaFB00;o00001Ol6S0001?l0003o1X`0o`000?l0
0019ooooo`04o`000?ooooooooooo`0000oooooo001Dooooo`03o`000?oooooooooo01_ooooo00?o
0000obFH0?lUV0001?l00004obFH0003o`000?lUV03o9IP000Co00001?lUV0001Ol0003o9IP0o`00
0?l0003o9IP000Co00001?lETP000ol0003o5I80oaFB0003o`0000Co5I8000?o0000oaFB0?lETP00
0_lETP03o`0000?o5I8000?o0000oaFB0?lETP001Ol00003oaFB0006o`000?lETP3o0000o`000?lE
TP3o00001Ol6S002o`0004cooooo00?o0000ooooool000003oooool005Gooooo00?o0000oooooooo
ool06oooool2o`0000Co9IP000?o0000obFH0?lUV0001?l00004obFH0003o`000?lUV03o9IP000Ko
00000olETP000ol0003o5I80oaFB0002oaFB00?o00000olETP000ol0003o5I80oaFB0002oaFB0004
o`000?lETP3o0000o`0000;o5I8000?o0000oaFB0?lETP001?l00003oaFB0004o`000?lETP3o5I80
oaFB00?o00001?lETP000ol0003o1X`0o`000002o`0004kooooo00Co0000oooooooooooo00003_oo
ool005Kooooo0_l0000Mooooo`03o`000?lUV03o9IP000Co00001?lUV0000ol0003o9IP0obFH0004
o`000003obFH0?l0003o000000?o5I8000Ko0000oaFB0?lETP3o5I80o`000?lETP02o`0000;o5I80
00?o0000oaFB0?lETP002?l00004oaFB00?o00000_lETP000ol0003o5I80oaFB0002oaFB00Co0000
0olETP000ol0003o5I80oaFB0003o`0005;ooooo00?o0000ooooool000003_ooool005Sooooo00?o
0000ooooooooool06oooool2o`0000Co9IP000?o0000obFH0?lUV0001?l00002obFH00Co00001?lE
TP06o`0000Co5I800ol00003oaFB0003o`000?lETP3o5I8000;o5I8000Co0000oaFB0?l0003o0000
0_lETP001_l0003o5I80oaFB0?lETP3o0000oaFB00;o00000olETP000ol0003o5I80oaFB0004o`00
05Kooooo0_l0000>ooooo`00FOooool00ol0003oooooooooo`0Kooooo`04o`000?lUV03o9IP0obFH
00Co00000_lUV004o`0000Co5I8000Ko0000oaFB0?l0003o0000oaFB0?l00004oaFB0004o`000?lE
TP3o0000o`0000;o5I8000?o0000oaFB0?lETP000_lETP000ol0003o5I80oaFB0003o`0000Co5I80
1ol00004oaFB00?o0000FOooool3o`0000kooooo001Jooooo`03o`000?oooooooooo01_ooooo0ol0
0003obFH00?o00001?lETP000ol0003o5I80oaFB0003o`0000Co5I8000?o0000oaFB0?lETP001?l0
0003oaFB00So00000olETP001_l0003o5I80o`000?l0003o5I80o`0000Go5I8000Co0000oaFB0?l0
003o0000F?ooool4o`00017ooooo001Kooooo`;o00007Oooool01?l0003o9IP0o`000?l00002obFH
0003o`000?lETP3o5I8000;o5I800ol00003oaFB0003o`000?lETP3o5I8000Co00001?lETP001Ol0
003o5I80o`000?lETP3o000000Go5I8000?o0000oaFB0?lETP000ol00004oaFB0004o`000?lETP3o
5I80oaFB00?o0000Eoooool3o`0001Gooooo001Mooooo`03o`000?oooooooooo01_ooooo00?o0000
obFH0?lUV0000olUV0001?l0003o5I80o`000?l00002oaFB0003o`000?lETP3o5I8000Co00000olE
TP001?l0003o5I80oaFB0?lETP03o`0000?o5I8000?o0000oaFB0?lETP000_lETP03o`0000?o5I80
00?o0000oaFB0?lETP001Ol0001Fooooo`Co00006?ooool005kooooo00?o0000ooooooooool06ooo
ool00ol0003o9IP0obFH0002obFH00;o00001?lETP03o`0000;o5I8000?o0000oaFB0?lETP000_lE
TP04o`0000?o5I8000Ko0000oaFB0?lETP3o5I80o`000?lETP02o`0000;o5I8000?o0000oaFB0?lE
TP001?l0001Gooooo`Co00007?ooool005oooooo00?o0000ooooooooool06oooool01?l0003o9IP0
o`000?l00002obFH0004o`000?lETP3o0000o`0000;o5I8000Ko0000oaFB0?lETP3o5I80o`000?lE
TP02o`0000?o5I8000?o0000oaFB0?lETP002?l00002oaFB00Co0000Eoooool4o`00023ooooo001P
ooooo`03o`000?oooooooooo01_ooooo0_l00002obFH00Co00000olETP07o`0000Co5I800ol00003
oaFB0003o`000?lETP3o5I8000Co0000F?ooool3o`0002Cooooo001Qooooo`;o00007Oooool2o`00
00Co9IP000?o0000oaFB0?l000000olETP001_l0003o5I80oaFB0?lETP3o0000oaFB00;o00000_lE
TP000ol0003o5I80oaFB0004o`0005Sooooo1?l0000Wooooo`00Hoooool00ol0003oooooooooo`0J
ooooo`03o`000?lUV03o9IP000?o9IP00_l00004oaFB00Ko00001?lETP03o`0005Sooooo1?l0000[
ooooo`00I?ooool00ol0003oooooooooo`0Jooooo`03o`000?lUV03o000000;o00000_lUV0001_l0
003o5I80o`000?l0003o5I80o`0000Co5I8000Co0000oaFB0?l0003o0000Eoooool4o`0002oooooo
001Uooooo`03o`000?oooooooooo01[ooooo0_l00004obFH00?o00000olETP000ol0003o5I80oaFB
0003o`0005Kooooo0ol0000cooooo`00I_ooool2o`0001cooooo00Co0000obFH0?l0003o00000_lU
V007o`0005Gooooo1?l0000fooooo`00J?ooool00ol0003oooooooooo`0Jooooo`05o`000?lUV03o
9IP0obFH0?l00000F?ooool4o`0003[ooooo001Yooooo`03o`000?oooooooooo01[ooooo00?o0000
obFH0?l00000EOooool4o`0003kooooo001Zooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0DOooool3o`0004;ooooo001[ooooo`;o00006_ooool00ol0003oooooooooo`1=ooooo`Co
0000AOooool006gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`Co0000
BOooool006kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000COoo
ool006oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`11ooooo`Co0000DOooool0
073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0nooooo`?o0000EOooool0077o
oooo0_l0000Dooooo`03o`000?oooooooooo03[ooooo1?l0001Hooooo`00Loooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo03Kooooo1?l0001Looooo`00M?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03;ooooo1?l0001Pooooo`00MOooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02oooooo0ol0001Tooooo`00M_ooool2o`0000oooooo00?o0000oooo
ooooool0:oooool4o`0006Oooooo001hooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool09oooool4o`0006_ooooo001iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
9?ooool4o`0006oooooo001jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Ooo
ool3o`0007?ooooo001kooooo`;o00002Oooool00ol0003oooooooooo`0Mooooo`Co0000M_ooool0
07gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`Co0000N_ooool007ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000O_ooool007oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o0000P_ooool0083ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000QOooool0087ooooo0_l00003
ooooo`03o`000?oooooooooo00[ooooo1?l00029ooooo`00Poooool01?l0003oooooooooool00008
ooooo`Co0000SOooool008Cooooo00?o0000ooooool000001Oooool3o`00097ooooo0025ooooo`;o
000000?oooooo`000?l000000_l0002Dooooo`00Q_ooool2o`0009Sooooo003oooooob7ooooo003o
ooooob7ooooo003Dooooo`?o0000BOooool00=Gooooo00?o0000ooooooooool0B?ooool006?ooooo
00?o0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Sooooo
0ol00003ooooo`?o00001?ooool3o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o0000
2?ooool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00000oooool3o`0000;o
oooo0ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003ooooo`;o00001?ooool00ol0003o
ooooooooo`17ooooo`00Hoooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Co
oooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00Co0000oooooooooooo00001Ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`17ooooo`00Hoooool00ol0003oooooo`000003ooooo`?o00000oooool00ol0003ooooo
o`000002ooooo`Go00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool3o`0000Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000004Sooooo001R
ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?ooooooooooooooool0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000002?ooool3o`0000?ooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooooooo
o`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool00000B?ooool006;ooooo00Go0000ooooool0003oooooo`000002ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo0_l0
00000ooooooo0000o`000002ooooo`?o00000_ooool4o`0000;ooooo1?l0000:ooooo`04o`000?oo
ooooooooooooo`Co00000_ooool4o`0000?ooooo0ol00002ooooo`Co00000oooool4o`000004oooo
ool0003o0000o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l00000Aoooool006;ooooo
00Go0000ooooool0003oooooo`00000Jooooo`04o`000?ooooooooooo`0001Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0C_ooool006;ooooo1_l0000Hooooo`Go00005?ooool00ol0003oooooooooo`08ooooo`Go
00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0C_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {231.75, 0}} -> {-0.179426, -0.0244776, \
0.00413968, 0.00413968}},
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.02757 .24618 -24 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -22.3468 -9 ]
[.3345 .12542 1.65319 0 ]
[.50253 .05935 -21.0958 -9 ]
[.50253 .05935 2.90415 0 ]
[.68156 -0.01098 -19.8449 -9 ]
[.68156 -0.01098 4.1551 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 24 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 24 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 18 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.01451 .32531 -6 -2.79323 ]
[.01451 .32531 0 6.20677 ]
[.00278 .3988 -12 -2.85565 ]
[.00278 .3988 0 6.14435 ]
[-0.00951 .47583 -12 -2.92138 ]
[-0.00951 .47583 0 6.07862 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-0.5)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.4)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(-0.3)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(-0.2)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(-0.1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-0.2)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-0.1)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.1)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.2)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02678 .32065 m
.03291 .31832 L
s
[(5)] .01451 .32531 1 -0.37928 Mshowa
.01511 .3943 m
.02127 .39205 L
s
[(10)] .00278 .3988 1 -0.36541 Mshowa
.00288 .47148 m
.00907 .46931 L
s
[(15)] -0.00951 .47583 1 -0.3508 Mshowa
.125 Mabswid
.02449 .33511 m
.02817 .33372 L
s
.02217 .3497 m
.02586 .34832 L
s
.01984 .36443 m
.02353 .36306 L
s
.01748 .3793 m
.02118 .37794 L
s
.01271 .40945 m
.01641 .4081 L
s
.01028 .42474 m
.01399 .4234 L
s
.00784 .44017 m
.01155 .43885 L
s
.00537 .45575 m
.00908 .45444 L
s
.02905 .30632 m
.03273 .30492 L
s
.0313 .29213 m
.03497 .29071 L
s
.03353 .27806 m
.0372 .27664 L
s
.03574 .26412 m
.0394 .26269 L
s
.00036 .48737 m
.00408 .48607 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.965 .147 0 r
.38757 .79727 .39806 .80578 .41576 .79428 .40536 .78568 Metetra
.937 .255 0 r
.40536 .78568 .41576 .79428 .43352 .78274 .42321 .77407 Metetra
.909 .357 0 r
.42321 .77407 .43352 .78274 .45132 .77118 .44111 .76242 Metetra
.882 .452 0 r
.44111 .76242 .45132 .77118 .46917 .75959 .45905 .75075 Metetra
.854 .54 0 r
.45905 .75075 .46917 .75959 .48707 .74796 .47704 .73904 Metetra
.826 .621 0 r
.47704 .73904 .48707 .74796 .50501 .7363 .49509 .7273 Metetra
.799 .696 0 r
.49509 .7273 .50501 .7363 .52301 .72461 .51318 .71553 Metetra
.771 .765 0 r
.51318 .71553 .52301 .72461 .54105 .71289 .53132 .70372 Metetra
.661 .744 0 r
.53132 .70372 .54105 .71289 .55915 .70114 .54951 .69188 Metetra
.55 .716 0 r
.54951 .69188 .55915 .70114 .57729 .68936 .56775 .68001 Metetra
.447 .688 0 r
.56775 .68001 .57729 .68936 .59548 .67754 .58604 .66811 Metetra
.35 .661 0 r
.58604 .66811 .59548 .67754 .61372 .66569 .60438 .65618 Metetra
.259 .633 0 r
.60438 .65618 .61372 .66569 .63201 .65381 .62277 .64421 Metetra
.175 .605 0 r
.62277 .64421 .63201 .65381 .65036 .64189 .64121 .63221 Metetra
.098 .578 0 r
.64121 .63221 .65036 .64189 .66875 .62995 .6597 .62018 Metetra
.028 .55 0 r
.6597 .62018 .66875 .62995 .68719 .61797 .67825 .60811 Metetra
0 .522 .036 r
.67825 .60811 .68719 .61797 .70568 .60595 .69684 .59601 Metetra
0 .495 .094 r
.69684 .59601 .70568 .60595 .72423 .59391 .71549 .58387 Metetra
0 .467 .145 r
.71549 .58387 .72423 .59391 .74282 .58183 .73419 .57171 Metetra
0 .439 .189 r
.73419 .57171 .74282 .58183 .76147 .56972 .75294 .55951 Metetra
0 .412 .226 r
.75294 .55951 .76147 .56972 .78017 .55757 .77174 .54727 Metetra
0 .384 .257 r
.77174 .54727 .78017 .55757 .79892 .54539 .79059 .535 Metetra
0 .356 .281 r
.79059 .535 .79892 .54539 .81772 .53318 .8095 .5227 Metetra
0 .329 .299 r
.8095 .5227 .81772 .53318 .83657 .52093 .82846 .51036 Metetra
0 .293 .301 r
.82846 .51036 .83657 .52093 .85548 .50865 .84747 .49799 Metetra
0 .233 .274 r
.84747 .49799 .85548 .50865 .87444 .49634 .86654 .48558 Metetra
0 .18 .246 r
.86654 .48558 .87444 .49634 .89345 .48399 .88566 .47314 Metetra
0 .134 .218 r
.88566 .47314 .89345 .48399 .91252 .4716 .90483 .46066 Metetra
0 .094 .191 r
.90483 .46066 .91252 .4716 .93163 .45918 .92406 .44815 Metetra
0 .061 .163 r
.92406 .44815 .93163 .45918 .95081 .44673 .94334 .4356 Metetra
0 .034 .135 r
.94334 .4356 .95081 .44673 .97003 .43424 .96268 .42302 Metetra
.965 .147 0 r
.37695 .78865 .38757 .79727 .40536 .78568 .39484 .77699 Metetra
.937 .255 0 r
.39484 .77699 .40536 .78568 .42321 .77407 .41278 .76529 Metetra
.909 .357 0 r
.41278 .76529 .42321 .77407 .44111 .76242 .43077 .75356 Metetra
.882 .452 0 r
.43077 .75356 .44111 .76242 .45905 .75075 .44881 .7418 Metetra
.854 .54 0 r
.44881 .7418 .45905 .75075 .47704 .73904 .4669 .73001 Metetra
.826 .621 0 r
.4669 .73001 .47704 .73904 .49509 .7273 .48504 .71818 Metetra
.799 .696 0 r
.48504 .71818 .49509 .7273 .51318 .71553 .50322 .70633 Metetra
.771 .765 0 r
.50322 .70633 .51318 .71553 .53132 .70372 .52146 .69444 Metetra
.661 .744 0 r
.52146 .69444 .53132 .70372 .54951 .69188 .53975 .68251 Metetra
.55 .716 0 r
.53975 .68251 .54951 .69188 .56775 .68001 .55809 .67056 Metetra
.447 .688 0 r
.55809 .67056 .56775 .68001 .58604 .66811 .57648 .65857 Metetra
.35 .661 0 r
.57648 .65857 .58604 .66811 .60438 .65618 .59492 .64655 Metetra
.259 .633 0 r
.59492 .64655 .60438 .65618 .62277 .64421 .61341 .63449 Metetra
.175 .605 0 r
.61341 .63449 .62277 .64421 .64121 .63221 .63195 .62241 Metetra
.098 .578 0 r
.63195 .62241 .64121 .63221 .6597 .62018 .65055 .61028 Metetra
.028 .55 0 r
.65055 .61028 .6597 .62018 .67825 .60811 .66919 .59813 Metetra
0 .522 .036 r
.66919 .59813 .67825 .60811 .69684 .59601 .68789 .58594 Metetra
0 .495 .094 r
.68789 .58594 .69684 .59601 .71549 .58387 .70664 .57372 Metetra
0 .467 .145 r
.70664 .57372 .71549 .58387 .73419 .57171 .72544 .56146 Metetra
0 .439 .189 r
.72544 .56146 .73419 .57171 .75294 .55951 .7443 .54917 Metetra
0 .412 .226 r
.7443 .54917 .75294 .55951 .77174 .54727 .7632 .53684 Metetra
0 .384 .257 r
.7632 .53684 .77174 .54727 .79059 .535 .78216 .52448 Metetra
0 .356 .281 r
.78216 .52448 .79059 .535 .8095 .5227 .80118 .51208 Metetra
0 .329 .299 r
.80118 .51208 .8095 .5227 .82846 .51036 .82025 .49965 Metetra
0 .293 .301 r
.82025 .49965 .82846 .51036 .84747 .49799 .83937 .48719 Metetra
0 .233 .274 r
.83937 .48719 .84747 .49799 .86654 .48558 .85854 .47469 Metetra
0 .18 .246 r
.85854 .47469 .86654 .48558 .88566 .47314 .87777 .46215 Metetra
0 .134 .218 r
.87777 .46215 .88566 .47314 .90483 .46066 .89705 .44958 Metetra
0 .094 .191 r
.89705 .44958 .90483 .46066 .92406 .44815 .91639 .43697 Metetra
0 .061 .163 r
.91639 .43697 .92406 .44815 .94334 .4356 .93578 .42433 Metetra
0 .034 .135 r
.93578 .42433 .94334 .4356 .96268 .42302 .95523 .41165 Metetra
.965 .147 0 r
.3662 .77993 .37695 .78865 .39484 .77699 .38418 .76818 Metetra
.937 .255 0 r
.38418 .76818 .39484 .77699 .41278 .76529 .40222 .7564 Metetra
.909 .357 0 r
.40222 .7564 .41278 .76529 .43077 .75356 .4203 .74459 Metetra
.882 .452 0 r
.4203 .74459 .43077 .75356 .44881 .7418 .43844 .73275 Metetra
.854 .54 0 r
.43844 .73275 .44881 .7418 .4669 .73001 .45663 .72087 Metetra
.826 .621 0 r
.45663 .72087 .4669 .73001 .48504 .71818 .47486 .70896 Metetra
.799 .696 0 r
.47486 .70896 .48504 .71818 .50322 .70633 .49315 .69702 Metetra
.771 .765 0 r
.49315 .69702 .50322 .70633 .52146 .69444 .51148 .68504 Metetra
.661 .744 0 r
.51148 .68504 .52146 .69444 .53975 .68251 .52987 .67303 Metetra
.55 .716 0 r
.52987 .67303 .53975 .68251 .55809 .67056 .54831 .66099 Metetra
.447 .688 0 r
.54831 .66099 .55809 .67056 .57648 .65857 .5668 .64891 Metetra
.35 .661 0 r
.5668 .64891 .57648 .65857 .59492 .64655 .58534 .6368 Metetra
.259 .633 0 r
.58534 .6368 .59492 .64655 .61341 .63449 .60393 .62466 Metetra
.175 .605 0 r
.60393 .62466 .61341 .63449 .63195 .62241 .62258 .61248 Metetra
.098 .578 0 r
.62258 .61248 .63195 .62241 .65055 .61028 .64128 .60027 Metetra
.028 .55 0 r
.64128 .60027 .65055 .61028 .66919 .59813 .66003 .58802 Metetra
0 .522 .036 r
.66003 .58802 .66919 .59813 .68789 .58594 .67883 .57574 Metetra
0 .495 .094 r
.67883 .57574 .68789 .58594 .70664 .57372 .69768 .56343 Metetra
0 .467 .145 r
.69768 .56343 .70664 .57372 .72544 .56146 .71659 .55108 Metetra
0 .439 .189 r
.71659 .55108 .72544 .56146 .7443 .54917 .73555 .5387 Metetra
0 .412 .226 r
.73555 .5387 .7443 .54917 .7632 .53684 .75456 .52628 Metetra
0 .384 .257 r
.75456 .52628 .7632 .53684 .78216 .52448 .77363 .51383 Metetra
0 .356 .281 r
.77363 .51383 .78216 .52448 .80118 .51208 .79275 .50134 Metetra
0 .329 .299 r
.79275 .50134 .80118 .51208 .82025 .49965 .81193 .48881 Metetra
0 .293 .301 r
.81193 .48881 .82025 .49965 .83937 .48719 .83116 .47625 Metetra
0 .233 .274 r
.83116 .47625 .83937 .48719 .85854 .47469 .85044 .46366 Metetra
0 .18 .246 r
.85044 .46366 .85854 .47469 .87777 .46215 .86978 .45103 Metetra
0 .134 .218 r
.86978 .45103 .87777 .46215 .89705 .44958 .88918 .43836 Metetra
0 .094 .191 r
.88918 .43836 .89705 .44958 .91639 .43697 .90863 .42566 Metetra
0 .061 .163 r
.90863 .42566 .91639 .43697 .93578 .42433 .92813 .41292 Metetra
0 .034 .135 r
.92813 .41292 .93578 .42433 .95523 .41165 .94769 .40014 Metetra
.965 .147 0 r
.35531 .7711 .3662 .77993 .38418 .76818 .3734 .75927 Metetra
.937 .255 0 r
.3734 .75927 .38418 .76818 .40222 .7564 .39153 .74741 Metetra
.909 .357 0 r
.39153 .74741 .40222 .7564 .4203 .74459 .40971 .73551 Metetra
.882 .452 0 r
.40971 .73551 .4203 .74459 .43844 .73275 .42794 .72358 Metetra
.854 .54 0 r
.42794 .72358 .43844 .73275 .45663 .72087 .44623 .71161 Metetra
.826 .621 0 r
.44623 .71161 .45663 .72087 .47486 .70896 .46456 .69962 Metetra
.799 .696 0 r
.46456 .69962 .47486 .70896 .49315 .69702 .48295 .68759 Metetra
.771 .765 0 r
.48295 .68759 .49315 .69702 .51148 .68504 .50138 .67552 Metetra
.661 .744 0 r
.50138 .67552 .51148 .68504 .52987 .67303 .51987 .66343 Metetra
.55 .716 0 r
.51987 .66343 .52987 .67303 .54831 .66099 .53841 .6513 Metetra
.447 .688 0 r
.53841 .6513 .54831 .66099 .5668 .64891 .557 .63913 Metetra
.35 .661 0 r
.557 .63913 .5668 .64891 .58534 .6368 .57564 .62693 Metetra
.259 .633 0 r
.57564 .62693 .58534 .6368 .60393 .62466 .59434 .6147 Metetra
.175 .605 0 r
.59434 .6147 .60393 .62466 .62258 .61248 .61309 .60243 Metetra
.098 .578 0 r
.61309 .60243 .62258 .61248 .64128 .60027 .63189 .59013 Metetra
.028 .55 0 r
.63189 .59013 .64128 .60027 .66003 .58802 .65074 .57779 Metetra
0 .522 .036 r
.65074 .57779 .66003 .58802 .67883 .57574 .66965 .56542 Metetra
0 .495 .094 r
.66965 .56542 .67883 .57574 .69768 .56343 .68861 .55302 Metetra
0 .467 .145 r
.68861 .55302 .69768 .56343 .71659 .55108 .70762 .54057 Metetra
0 .439 .189 r
.70762 .54057 .71659 .55108 .73555 .5387 .72669 .5281 Metetra
0 .412 .226 r
.72669 .5281 .73555 .5387 .75456 .52628 .74581 .51559 Metetra
0 .384 .257 r
.74581 .51559 .75456 .52628 .77363 .51383 .76499 .50304 Metetra
0 .356 .281 r
.76499 .50304 .77363 .51383 .79275 .50134 .78422 .49045 Metetra
0 .329 .299 r
.78422 .49045 .79275 .50134 .81193 .48881 .8035 .47784 Metetra
0 .293 .301 r
.8035 .47784 .81193 .48881 .83116 .47625 .82284 .46518 Metetra
0 .233 .274 r
.82284 .46518 .83116 .47625 .85044 .46366 .84224 .45249 Metetra
0 .18 .246 r
.84224 .45249 .85044 .46366 .86978 .45103 .86169 .43976 Metetra
0 .134 .218 r
.86169 .43976 .86978 .45103 .88918 .43836 .8812 .427 Metetra
0 .094 .191 r
.8812 .427 .88918 .43836 .90863 .42566 .90076 .4142 Metetra
0 .061 .163 r
.90076 .4142 .90863 .42566 .92813 .41292 .92038 .40136 Metetra
0 .034 .135 r
.92038 .40136 .92813 .41292 .94769 .40014 .94005 .38849 Metetra
.965 .147 0 r
.3443 .76217 .35531 .7711 .3734 .75927 .36248 .75025 Metetra
.937 .255 0 r
.36248 .75025 .3734 .75927 .39153 .74741 .38071 .7383 Metetra
.909 .357 0 r
.38071 .7383 .39153 .74741 .40971 .73551 .39899 .72631 Metetra
.882 .452 0 r
.39899 .72631 .40971 .73551 .42794 .72358 .41732 .7143 Metetra
.854 .54 0 r
.41732 .7143 .42794 .72358 .44623 .71161 .4357 .70224 Metetra
.826 .621 0 r
.4357 .70224 .44623 .71161 .46456 .69962 .45413 .69016 Metetra
.799 .696 0 r
.45413 .69016 .46456 .69962 .48295 .68759 .47262 .67804 Metetra
.771 .765 0 r
.47262 .67804 .48295 .68759 .50138 .67552 .49116 .66589 Metetra
.661 .744 0 r
.49116 .66589 .50138 .67552 .51987 .66343 .50974 .6537 Metetra
.55 .716 0 r
.50974 .6537 .51987 .66343 .53841 .6513 .52839 .64148 Metetra
.447 .688 0 r
.52839 .64148 .53841 .6513 .557 .63913 .54708 .62923 Metetra
.35 .661 0 r
.54708 .62923 .557 .63913 .57564 .62693 .56583 .61694 Metetra
.259 .633 0 r
.56583 .61694 .57564 .62693 .59434 .6147 .58463 .60461 Metetra
.175 .605 0 r
.58463 .60461 .59434 .6147 .61309 .60243 .60348 .59226 Metetra
.098 .578 0 r
.60348 .59226 .61309 .60243 .63189 .59013 .62238 .57986 Metetra
.028 .55 0 r
.62238 .57986 .63189 .59013 .65074 .57779 .64134 .56743 Metetra
0 .522 .036 r
.64134 .56743 .65074 .57779 .66965 .56542 .66036 .55497 Metetra
0 .495 .094 r
.66036 .55497 .66965 .56542 .68861 .55302 .67942 .54247 Metetra
0 .467 .145 r
.67942 .54247 .68861 .55302 .70762 .54057 .69854 .52993 Metetra
0 .439 .189 r
.69854 .52993 .70762 .54057 .72669 .5281 .71772 .51736 Metetra
0 .412 .226 r
.71772 .51736 .72669 .5281 .74581 .51559 .73695 .50475 Metetra
0 .384 .257 r
.73695 .50475 .74581 .51559 .76499 .50304 .75624 .49211 Metetra
0 .356 .281 r
.75624 .49211 .76499 .50304 .78422 .49045 .77558 .47943 Metetra
0 .329 .299 r
.77558 .47943 .78422 .49045 .8035 .47784 .79497 .46672 Metetra
0 .293 .301 r
.79497 .46672 .8035 .47784 .82284 .46518 .81442 .45397 Metetra
0 .233 .274 r
.81442 .45397 .82284 .46518 .84224 .45249 .83393 .44118 Metetra
0 .18 .246 r
.83393 .44118 .84224 .45249 .86169 .43976 .8535 .42835 Metetra
0 .134 .218 r
.8535 .42835 .86169 .43976 .8812 .427 .87312 .41549 Metetra
0 .094 .191 r
.87312 .41549 .8812 .427 .90076 .4142 .89279 .40259 Metetra
0 .061 .163 r
.89279 .40259 .90076 .4142 .92038 .40136 .91253 .38965 Metetra
0 .034 .135 r
.91253 .38965 .92038 .40136 .94005 .38849 .93232 .37668 Metetra
.965 .147 0 r
.33314 .75312 .3443 .76217 .36248 .75025 .35142 .74111 Metetra
.937 .255 0 r
.35142 .74111 .36248 .75025 .38071 .7383 .36975 .72907 Metetra
.909 .357 0 r
.36975 .72907 .38071 .7383 .39899 .72631 .38813 .717 Metetra
.882 .452 0 r
.38813 .717 .39899 .72631 .41732 .7143 .40656 .7049 Metetra
.854 .54 0 r
.40656 .7049 .41732 .7143 .4357 .70224 .42504 .69276 Metetra
.826 .621 0 r
.42504 .69276 .4357 .70224 .45413 .69016 .44357 .68058 Metetra
.799 .696 0 r
.44357 .68058 .45413 .69016 .47262 .67804 .46216 .66838 Metetra
.771 .765 0 r
.46216 .66838 .47262 .67804 .49116 .66589 .4808 .65613 Metetra
.661 .744 0 r
.4808 .65613 .49116 .66589 .50974 .6537 .49949 .64386 Metetra
.55 .716 0 r
.49949 .64386 .50974 .6537 .52839 .64148 .51824 .63155 Metetra
.447 .688 0 r
.51824 .63155 .52839 .64148 .54708 .62923 .53703 .6192 Metetra
.35 .661 0 r
.53703 .6192 .54708 .62923 .56583 .61694 .55588 .60682 Metetra
.259 .633 0 r
.55588 .60682 .56583 .61694 .58463 .60461 .57479 .5944 Metetra
.175 .605 0 r
.57479 .5944 .58463 .60461 .60348 .59226 .59375 .58195 Metetra
.098 .578 0 r
.59375 .58195 .60348 .59226 .62238 .57986 .61276 .56946 Metetra
.028 .55 0 r
.61276 .56946 .62238 .57986 .64134 .56743 .63182 .55694 Metetra
0 .522 .036 r
.63182 .55694 .64134 .56743 .66036 .55497 .65094 .54438 Metetra
0 .495 .094 r
.65094 .54438 .66036 .55497 .67942 .54247 .67012 .53179 Metetra
0 .467 .145 r
.67012 .53179 .67942 .54247 .69854 .52993 .68935 .51916 Metetra
0 .439 .189 r
.68935 .51916 .69854 .52993 .71772 .51736 .70863 .50649 Metetra
0 .412 .226 r
.70863 .50649 .71772 .51736 .73695 .50475 .72798 .49379 Metetra
0 .384 .257 r
.72798 .49379 .73695 .50475 .75624 .49211 .74737 .48105 Metetra
0 .356 .281 r
.74737 .48105 .75624 .49211 .77558 .47943 .76682 .46827 Metetra
0 .329 .299 r
.76682 .46827 .77558 .47943 .79497 .46672 .78633 .45546 Metetra
0 .293 .301 r
.78633 .45546 .79497 .46672 .81442 .45397 .8059 .44261 Metetra
0 .233 .274 r
.8059 .44261 .81442 .45397 .83393 .44118 .82552 .42972 Metetra
0 .18 .246 r
.82552 .42972 .83393 .44118 .8535 .42835 .8452 .41679 Metetra
0 .134 .218 r
.8452 .41679 .8535 .42835 .87312 .41549 .86493 .40383 Metetra
0 .094 .191 r
.86493 .40383 .87312 .41549 .89279 .40259 .88472 .39083 Metetra
0 .061 .163 r
.88472 .39083 .89279 .40259 .91253 .38965 .90457 .37779 Metetra
0 .034 .135 r
.90457 .37779 .91253 .38965 .93232 .37668 .92448 .36472 Metetra
.965 .147 0 r
.32185 .74396 .33314 .75312 .35142 .74111 .34023 .73186 Metetra
.937 .255 0 r
.34023 .73186 .35142 .74111 .36975 .72907 .35865 .71974 Metetra
.909 .357 0 r
.35865 .71974 .36975 .72907 .38813 .717 .37713 .70758 Metetra
.882 .452 0 r
.37713 .70758 .38813 .717 .40656 .7049 .39566 .69538 Metetra
.854 .54 0 r
.39566 .69538 .40656 .7049 .42504 .69276 .41425 .68315 Metetra
.826 .621 0 r
.41425 .68315 .42504 .69276 .44357 .68058 .43288 .67089 Metetra
.799 .696 0 r
.43288 .67089 .44357 .68058 .46216 .66838 .45157 .65859 Metetra
.771 .765 0 r
.45157 .65859 .46216 .66838 .4808 .65613 .47031 .64626 Metetra
.661 .744 0 r
.47031 .64626 .4808 .65613 .49949 .64386 .48911 .63389 Metetra
.55 .716 0 r
.48911 .63389 .49949 .64386 .51824 .63155 .50796 .62148 Metetra
.447 .688 0 r
.50796 .62148 .51824 .63155 .53703 .6192 .52686 .60904 Metetra
.35 .661 0 r
.52686 .60904 .53703 .6192 .55588 .60682 .54581 .59657 Metetra
.259 .633 0 r
.54581 .59657 .55588 .60682 .57479 .5944 .56482 .58406 Metetra
.175 .605 0 r
.56482 .58406 .57479 .5944 .59375 .58195 .58389 .57151 Metetra
.098 .578 0 r
.58389 .57151 .59375 .58195 .61276 .56946 .60301 .55893 Metetra
.028 .55 0 r
.60301 .55893 .61276 .56946 .63182 .55694 .62218 .54631 Metetra
0 .522 .036 r
.62218 .54631 .63182 .55694 .65094 .54438 .64141 .53366 Metetra
0 .495 .094 r
.64141 .53366 .65094 .54438 .67012 .53179 .6607 .52097 Metetra
0 .467 .145 r
.6607 .52097 .67012 .53179 .68935 .51916 .68004 .50824 Metetra
0 .439 .189 r
.68004 .50824 .68935 .51916 .70863 .50649 .69943 .49548 Metetra
0 .412 .226 r
.69943 .49548 .70863 .50649 .72798 .49379 .71888 .48268 Metetra
0 .384 .257 r
.71888 .48268 .72798 .49379 .74737 .48105 .73839 .46984 Metetra
0 .356 .281 r
.73839 .46984 .74737 .48105 .76682 .46827 .75796 .45696 Metetra
0 .329 .299 r
.75796 .45696 .76682 .46827 .78633 .45546 .77758 .44405 Metetra
0 .293 .301 r
.77758 .44405 .78633 .45546 .8059 .44261 .79726 .4311 Metetra
0 .233 .274 r
.79726 .4311 .8059 .44261 .82552 .42972 .81699 .41811 Metetra
0 .18 .246 r
.81699 .41811 .82552 .42972 .8452 .41679 .83679 .40509 Metetra
0 .134 .218 r
.83679 .40509 .8452 .41679 .86493 .40383 .85664 .39202 Metetra
0 .094 .191 r
.85664 .39202 .86493 .40383 .88472 .39083 .87655 .37892 Metetra
0 .061 .163 r
.87655 .37892 .88472 .39083 .90457 .37779 .89652 .36578 Metetra
0 .034 .135 r
.89652 .36578 .90457 .37779 .92448 .36472 .91654 .3526 Metetra
.965 .147 0 r
.31042 .73468 .32185 .74396 .34023 .73186 .32889 .7225 Metetra
.937 .255 0 r
.32889 .7225 .34023 .73186 .35865 .71974 .34742 .71028 Metetra
.909 .357 0 r
.34742 .71028 .35865 .71974 .37713 .70758 .366 .69803 Metetra
.882 .452 0 r
.366 .69803 .37713 .70758 .39566 .69538 .38463 .68574 Metetra
.854 .54 0 r
.38463 .68574 .39566 .69538 .41425 .68315 .40332 .67342 Metetra
.826 .621 0 r
.40332 .67342 .41425 .68315 .43288 .67089 .42205 .66107 Metetra
.799 .696 0 r
.42205 .66107 .43288 .67089 .45157 .65859 .44085 .64868 Metetra
.771 .765 0 r
.44085 .64868 .45157 .65859 .47031 .64626 .45969 .63625 Metetra
.661 .744 0 r
.45969 .63625 .47031 .64626 .48911 .63389 .47859 .62379 Metetra
.55 .716 0 r
.47859 .62379 .48911 .63389 .50796 .62148 .49755 .61129 Metetra
.447 .688 0 r
.49755 .61129 .50796 .62148 .52686 .60904 .51655 .59876 Metetra
.35 .661 0 r
.51655 .59876 .52686 .60904 .54581 .59657 .53562 .58619 Metetra
.259 .633 0 r
.53562 .58619 .54581 .59657 .56482 .58406 .55473 .57358 Metetra
.175 .605 0 r
.55473 .57358 .56482 .58406 .58389 .57151 .57391 .56094 Metetra
.098 .578 0 r
.57391 .56094 .58389 .57151 .60301 .55893 .59313 .54826 Metetra
.028 .55 0 r
.59313 .54826 .60301 .55893 .62218 .54631 .61242 .53555 Metetra
0 .522 .036 r
.61242 .53555 .62218 .54631 .64141 .53366 .63176 .5228 Metetra
0 .495 .094 r
.63176 .5228 .64141 .53366 .6607 .52097 .65115 .51001 Metetra
0 .467 .145 r
.65115 .51001 .6607 .52097 .68004 .50824 .6706 .49718 Metetra
0 .439 .189 r
.6706 .49718 .68004 .50824 .69943 .49548 .69011 .48432 Metetra
0 .412 .226 r
.69011 .48432 .69943 .49548 .71888 .48268 .70968 .47142 Metetra
0 .384 .257 r
.70968 .47142 .71888 .48268 .73839 .46984 .7293 .45848 Metetra
0 .356 .281 r
.7293 .45848 .73839 .46984 .75796 .45696 .74898 .44551 Metetra
0 .329 .299 r
.74898 .44551 .75796 .45696 .77758 .44405 .76871 .43249 Metetra
0 .293 .301 r
.76871 .43249 .77758 .44405 .79726 .4311 .78851 .41944 Metetra
0 .233 .274 r
.78851 .41944 .79726 .4311 .81699 .41811 .80836 .40635 Metetra
0 .18 .246 r
.80836 .40635 .81699 .41811 .83679 .40509 .82827 .39322 Metetra
0 .134 .218 r
.82827 .39322 .83679 .40509 .85664 .39202 .84824 .38006 Metetra
0 .094 .191 r
.84824 .38006 .85664 .39202 .87655 .37892 .86827 .36685 Metetra
0 .061 .163 r
.86827 .36685 .87655 .37892 .89652 .36578 .88835 .35361 Metetra
0 .034 .135 r
.88835 .35361 .89652 .36578 .91654 .3526 .9085 .34032 Metetra
.965 .147 0 r
.29884 .72529 .31042 .73468 .32889 .7225 .31741 .71301 Metetra
.937 .255 0 r
.31741 .71301 .32889 .7225 .34742 .71028 .33604 .70071 Metetra
.909 .357 0 r
.33604 .70071 .34742 .71028 .366 .69803 .35472 .68836 Metetra
.882 .452 0 r
.35472 .68836 .366 .69803 .38463 .68574 .37346 .67599 Metetra
.854 .54 0 r
.37346 .67599 .38463 .68574 .40332 .67342 .39225 .66357 Metetra
.826 .621 0 r
.39225 .66357 .40332 .67342 .42205 .66107 .41109 .65112 Metetra
.799 .696 0 r
.41109 .65112 .42205 .66107 .44085 .64868 .42998 .63864 Metetra
.771 .765 0 r
.42998 .63864 .44085 .64868 .45969 .63625 .44894 .62612 Metetra
.661 .744 0 r
.44894 .62612 .45969 .63625 .47859 .62379 .46794 .61356 Metetra
.55 .716 0 r
.46794 .61356 .47859 .62379 .49755 .61129 .487 .60097 Metetra
.447 .688 0 r
.487 .60097 .49755 .61129 .51655 .59876 .50612 .58834 Metetra
.35 .661 0 r
.50612 .58834 .51655 .59876 .53562 .58619 .52529 .57568 Metetra
.259 .633 0 r
.52529 .57568 .53562 .58619 .55473 .57358 .54451 .56297 Metetra
.175 .605 0 r
.54451 .56297 .55473 .57358 .57391 .56094 .56379 .55023 Metetra
.098 .578 0 r
.56379 .55023 .57391 .56094 .59313 .54826 .58313 .53746 Metetra
.028 .55 0 r
.58313 .53746 .59313 .54826 .61242 .53555 .60253 .52465 Metetra
0 .522 .036 r
.60253 .52465 .61242 .53555 .63176 .5228 .62198 .5118 Metetra
0 .495 .094 r
.62198 .5118 .63176 .5228 .65115 .51001 .64148 .49891 Metetra
0 .467 .145 r
.64148 .49891 .65115 .51001 .6706 .49718 .66105 .48598 Metetra
0 .439 .189 r
.66105 .48598 .6706 .49718 .69011 .48432 .68067 .47302 Metetra
0 .412 .226 r
.68067 .47302 .69011 .48432 .70968 .47142 .70035 .46002 Metetra
0 .384 .257 r
.70035 .46002 .70968 .47142 .7293 .45848 .72008 .44698 Metetra
0 .356 .281 r
.72008 .44698 .7293 .45848 .74898 .44551 .73988 .4339 Metetra
0 .329 .299 r
.73988 .4339 .74898 .44551 .76871 .43249 .75973 .42079 Metetra
0 .293 .301 r
.75973 .42079 .76871 .43249 .78851 .41944 .77964 .40763 Metetra
0 .233 .274 r
.77964 .40763 .78851 .41944 .80836 .40635 .79961 .39444 Metetra
0 .18 .246 r
.79961 .39444 .80836 .40635 .82827 .39322 .81964 .38121 Metetra
0 .134 .218 r
.81964 .38121 .82827 .39322 .84824 .38006 .83973 .36794 Metetra
0 .094 .191 r
.83973 .36794 .84824 .38006 .86827 .36685 .85987 .35462 Metetra
0 .061 .163 r
.85987 .35462 .86827 .36685 .88835 .35361 .88008 .34127 Metetra
0 .034 .135 r
.88008 .34127 .88835 .35361 .9085 .34032 .90035 .32788 Metetra
.965 .147 0 r
.28711 .71577 .29884 .72529 .31741 .71301 .30579 .70341 Metetra
.937 .255 0 r
.30579 .70341 .31741 .71301 .33604 .70071 .32452 .69101 Metetra
.909 .357 0 r
.32452 .69101 .33604 .70071 .35472 .68836 .3433 .67857 Metetra
.882 .452 0 r
.3433 .67857 .35472 .68836 .37346 .67599 .36214 .6661 Metetra
.854 .54 0 r
.36214 .6661 .37346 .67599 .39225 .66357 .38103 .65359 Metetra
.826 .621 0 r
.38103 .65359 .39225 .66357 .41109 .65112 .39998 .64105 Metetra
.799 .696 0 r
.39998 .64105 .41109 .65112 .42998 .63864 .41898 .62847 Metetra
.771 .765 0 r
.41898 .62847 .42998 .63864 .44894 .62612 .43804 .61586 Metetra
.661 .744 0 r
.43804 .61586 .44894 .62612 .46794 .61356 .45715 .6032 Metetra
.55 .716 0 r
.45715 .6032 .46794 .61356 .487 .60097 .47632 .59051 Metetra
.447 .688 0 r
.47632 .59051 .487 .60097 .50612 .58834 .49554 .57779 Metetra
.35 .661 0 r
.49554 .57779 .50612 .58834 .52529 .57568 .51482 .56503 Metetra
.259 .633 0 r
.51482 .56503 .52529 .57568 .54451 .56297 .53416 .55223 Metetra
.175 .605 0 r
.53416 .55223 .54451 .56297 .56379 .55023 .55355 .53939 Metetra
.098 .578 0 r
.55355 .53939 .56379 .55023 .58313 .53746 .573 .52651 Metetra
.028 .55 0 r
.573 .52651 .58313 .53746 .60253 .52465 .5925 .5136 Metetra
0 .522 .036 r
.5925 .5136 .60253 .52465 .62198 .5118 .61207 .50065 Metetra
0 .495 .094 r
.61207 .50065 .62198 .5118 .64148 .49891 .63169 .48766 Metetra
0 .467 .145 r
.63169 .48766 .64148 .49891 .66105 .48598 .65137 .47464 Metetra
0 .439 .189 r
.65137 .47464 .66105 .48598 .68067 .47302 .6711 .46157 Metetra
0 .412 .226 r
.6711 .46157 .68067 .47302 .70035 .46002 .69089 .44847 Metetra
0 .384 .257 r
.69089 .44847 .70035 .46002 .72008 .44698 .71075 .43533 Metetra
0 .356 .281 r
.71075 .43533 .72008 .44698 .73988 .4339 .73066 .42214 Metetra
0 .329 .299 r
.73066 .42214 .73988 .4339 .75973 .42079 .75063 .40892 Metetra
0 .293 .301 r
.75063 .40892 .75973 .42079 .77964 .40763 .77066 .39567 Metetra
0 .233 .274 r
.77066 .39567 .77964 .40763 .79961 .39444 .79074 .38237 Metetra
0 .18 .246 r
.79074 .38237 .79961 .39444 .81964 .38121 .81089 .36903 Metetra
0 .134 .218 r
.81089 .36903 .81964 .38121 .83973 .36794 .8311 .35565 Metetra
0 .094 .191 r
.8311 .35565 .83973 .36794 .85987 .35462 .85137 .34223 Metetra
0 .061 .163 r
.85137 .34223 .85987 .35462 .88008 .34127 .8717 .32878 Metetra
0 .034 .135 r
.8717 .32878 .88008 .34127 .90035 .32788 .89209 .31528 Metetra
.965 .147 0 r
.27523 .70614 .28711 .71577 .30579 .70341 .29401 .69368 Metetra
.937 .255 0 r
.29401 .69368 .30579 .70341 .32452 .69101 .31284 .68118 Metetra
.909 .357 0 r
.31284 .68118 .32452 .69101 .3433 .67857 .33173 .66865 Metetra
.882 .452 0 r
.33173 .66865 .3433 .67857 .36214 .6661 .35068 .65609 Metetra
.854 .54 0 r
.35068 .65609 .36214 .6661 .38103 .65359 .36968 .64349 Metetra
.826 .621 0 r
.36968 .64349 .38103 .65359 .39998 .64105 .38873 .63085 Metetra
.799 .696 0 r
.38873 .63085 .39998 .64105 .41898 .62847 .40784 .61817 Metetra
.771 .765 0 r
.40784 .61817 .41898 .62847 .43804 .61586 .427 .60546 Metetra
.661 .744 0 r
.427 .60546 .43804 .61586 .45715 .6032 .44622 .59271 Metetra
.55 .716 0 r
.44622 .59271 .45715 .6032 .47632 .59051 .4655 .57992 Metetra
.447 .688 0 r
.4655 .57992 .47632 .59051 .49554 .57779 .48483 .5671 Metetra
.35 .661 0 r
.48483 .5671 .49554 .57779 .51482 .56503 .50422 .55424 Metetra
.259 .633 0 r
.50422 .55424 .51482 .56503 .53416 .55223 .52367 .54134 Metetra
.175 .605 0 r
.52367 .54134 .53416 .55223 .55355 .53939 .54317 .5284 Metetra
.098 .578 0 r
.54317 .5284 .55355 .53939 .573 .52651 .56273 .51542 Metetra
.028 .55 0 r
.56273 .51542 .573 .52651 .5925 .5136 .58235 .50241 Metetra
0 .522 .036 r
.58235 .50241 .5925 .5136 .61207 .50065 .60203 .48936 Metetra
0 .495 .094 r
.60203 .48936 .61207 .50065 .63169 .48766 .62176 .47627 Metetra
0 .467 .145 r
.62176 .47627 .63169 .48766 .65137 .47464 .64156 .46314 Metetra
0 .439 .189 r
.64156 .46314 .65137 .47464 .6711 .46157 .66141 .44997 Metetra
0 .412 .226 r
.66141 .44997 .6711 .46157 .69089 .44847 .68132 .43676 Metetra
0 .384 .257 r
.68132 .43676 .69089 .44847 .71075 .43533 .70129 .42352 Metetra
0 .356 .281 r
.70129 .42352 .71075 .43533 .73066 .42214 .72132 .41023 Metetra
0 .329 .299 r
.72132 .41023 .73066 .42214 .75063 .40892 .7414 .39691 Metetra
0 .293 .301 r
.7414 .39691 .75063 .40892 .77066 .39567 .76155 .38354 Metetra
0 .233 .274 r
.76155 .38354 .77066 .39567 .79074 .38237 .78176 .37013 Metetra
0 .18 .246 r
.78176 .37013 .79074 .38237 .81089 .36903 .80203 .35669 Metetra
0 .134 .218 r
.80203 .35669 .81089 .36903 .8311 .35565 .82236 .3432 Metetra
0 .094 .191 r
.82236 .3432 .8311 .35565 .85137 .34223 .84275 .32968 Metetra
0 .061 .163 r
.84275 .32968 .85137 .34223 .8717 .32878 .8632 .31611 Metetra
0 .034 .135 r
.8632 .31611 .8717 .32878 .89209 .31528 .88372 .3025 Metetra
.965 .147 0 r
.2632 .69638 .27523 .70614 .29401 .69368 .28208 .68382 Metetra
.937 .255 0 r
.28208 .68382 .29401 .69368 .31284 .68118 .30102 .67123 Metetra
.909 .357 0 r
.30102 .67123 .31284 .68118 .33173 .66865 .32002 .65861 Metetra
.882 .452 0 r
.32002 .65861 .33173 .66865 .35068 .65609 .33907 .64595 Metetra
.854 .54 0 r
.33907 .64595 .35068 .65609 .36968 .64349 .35817 .63325 Metetra
.826 .621 0 r
.35817 .63325 .36968 .64349 .38873 .63085 .37733 .62051 Metetra
.799 .696 0 r
.37733 .62051 .38873 .63085 .40784 .61817 .39655 .60774 Metetra
.771 .765 0 r
.39655 .60774 .40784 .61817 .427 .60546 .41582 .59493 Metetra
.661 .744 0 r
.41582 .59493 .427 .60546 .44622 .59271 .43515 .58208 Metetra
.55 .716 0 r
.43515 .58208 .44622 .59271 .4655 .57992 .45454 .56919 Metetra
.447 .688 0 r
.45454 .56919 .4655 .57992 .48483 .5671 .47398 .55627 Metetra
.35 .661 0 r
.47398 .55627 .48483 .5671 .50422 .55424 .49348 .5433 Metetra
.259 .633 0 r
.49348 .5433 .50422 .55424 .52367 .54134 .51304 .5303 Metetra
.175 .605 0 r
.51304 .5303 .52367 .54134 .54317 .5284 .53266 .51727 Metetra
.098 .578 0 r
.53266 .51727 .54317 .5284 .56273 .51542 .55233 .50419 Metetra
.028 .55 0 r
.55233 .50419 .56273 .51542 .58235 .50241 .57207 .49107 Metetra
0 .522 .036 r
.57207 .49107 .58235 .50241 .60203 .48936 .59186 .47792 Metetra
0 .495 .094 r
.59186 .47792 .60203 .48936 .62176 .47627 .61171 .46472 Metetra
0 .467 .145 r
.61171 .46472 .62176 .47627 .64156 .46314 .63162 .45149 Metetra
0 .439 .189 r
.63162 .45149 .64156 .46314 .66141 .44997 .65159 .43822 Metetra
0 .412 .226 r
.65159 .43822 .66141 .44997 .68132 .43676 .67161 .4249 Metetra
0 .384 .257 r
.67161 .4249 .68132 .43676 .70129 .42352 .6917 .41155 Metetra
0 .356 .281 r
.6917 .41155 .70129 .42352 .72132 .41023 .71185 .39816 Metetra
0 .329 .299 r
.71185 .39816 .72132 .41023 .7414 .39691 .73206 .38473 Metetra
0 .293 .301 r
.73206 .38473 .7414 .39691 .76155 .38354 .75233 .37125 Metetra
0 .233 .274 r
.75233 .37125 .76155 .38354 .78176 .37013 .77266 .35774 Metetra
0 .18 .246 r
.77266 .35774 .78176 .37013 .80203 .35669 .79305 .34418 Metetra
0 .134 .218 r
.79305 .34418 .80203 .35669 .82236 .3432 .8135 .33059 Metetra
0 .094 .191 r
.8135 .33059 .82236 .3432 .84275 .32968 .83402 .31695 Metetra
0 .061 .163 r
.83402 .31695 .84275 .32968 .8632 .31611 .8546 .30328 Metetra
0 .034 .135 r
.8546 .30328 .8632 .31611 .88372 .3025 .87523 .28956 Metetra
.965 .147 0 r
.25101 .68649 .2632 .69638 .28208 .68382 .27 .67384 Metetra
.937 .255 0 r
.27 .67384 .28208 .68382 .30102 .67123 .28904 .66115 Metetra
.909 .357 0 r
.28904 .66115 .30102 .67123 .32002 .65861 .30815 .64843 Metetra
.882 .452 0 r
.30815 .64843 .32002 .65861 .33907 .64595 .3273 .63567 Metetra
.854 .54 0 r
.3273 .63567 .33907 .64595 .35817 .63325 .34652 .62287 Metetra
.826 .621 0 r
.34652 .62287 .35817 .63325 .37733 .62051 .36578 .61004 Metetra
.799 .696 0 r
.36578 .61004 .37733 .62051 .39655 .60774 .38511 .59717 Metetra
.771 .765 0 r
.38511 .59717 .39655 .60774 .41582 .59493 .40449 .58426 Metetra
.661 .744 0 r
.40449 .58426 .41582 .59493 .43515 .58208 .42393 .57131 Metetra
.55 .716 0 r
.42393 .57131 .43515 .58208 .45454 .56919 .44343 .55832 Metetra
.447 .688 0 r
.44343 .55832 .45454 .56919 .47398 .55627 .46299 .54529 Metetra
.35 .661 0 r
.46299 .54529 .47398 .55627 .49348 .5433 .4826 .53223 Metetra
.259 .633 0 r
.4826 .53223 .49348 .5433 .51304 .5303 .50227 .51913 Metetra
.175 .605 0 r
.50227 .51913 .51304 .5303 .53266 .51727 .522 .50598 Metetra
.098 .578 0 r
.522 .50598 .53266 .51727 .55233 .50419 .54179 .4928 Metetra
.028 .55 0 r
.54179 .4928 .55233 .50419 .57207 .49107 .56164 .47958 Metetra
0 .522 .036 r
.56164 .47958 .57207 .49107 .59186 .47792 .58155 .46632 Metetra
0 .495 .094 r
.58155 .46632 .59186 .47792 .61171 .46472 .60152 .45302 Metetra
0 .467 .145 r
.60152 .45302 .61171 .46472 .63162 .45149 .62154 .43968 Metetra
0 .439 .189 r
.62154 .43968 .63162 .45149 .65159 .43822 .64163 .4263 Metetra
0 .412 .226 r
.64163 .4263 .65159 .43822 .67161 .4249 .66178 .41288 Metetra
0 .384 .257 r
.66178 .41288 .67161 .4249 .6917 .41155 .68199 .39942 Metetra
0 .356 .281 r
.68199 .39942 .6917 .41155 .71185 .39816 .70226 .38592 Metetra
0 .329 .299 r
.70226 .38592 .71185 .39816 .73206 .38473 .72259 .37238 Metetra
0 .293 .301 r
.72259 .37238 .73206 .38473 .75233 .37125 .74298 .3588 Metetra
0 .233 .274 r
.74298 .3588 .75233 .37125 .77266 .35774 .76343 .34517 Metetra
0 .18 .246 r
.76343 .34517 .77266 .35774 .79305 .34418 .78395 .33151 Metetra
0 .134 .218 r
.78395 .33151 .79305 .34418 .8135 .33059 .80453 .3178 Metetra
0 .094 .191 r
.80453 .3178 .8135 .33059 .83402 .31695 .82517 .30405 Metetra
0 .061 .163 r
.82517 .30405 .83402 .31695 .8546 .30328 .84587 .29026 Metetra
0 .034 .135 r
.84587 .29026 .8546 .30328 .87523 .28956 .86664 .27643 Metetra
.965 .147 0 r
.23866 .67647 .25101 .68649 .27 .67384 .25776 .66373 Metetra
.937 .255 0 r
.25776 .66373 .27 .67384 .28904 .66115 .27691 .65094 Metetra
.909 .357 0 r
.27691 .65094 .28904 .66115 .30815 .64843 .29612 .63812 Metetra
.882 .452 0 r
.29612 .63812 .30815 .64843 .3273 .63567 .31538 .62526 Metetra
.854 .54 0 r
.31538 .62526 .3273 .63567 .34652 .62287 .33471 .61236 Metetra
.826 .621 0 r
.33471 .61236 .34652 .62287 .36578 .61004 .35409 .59943 Metetra
.799 .696 0 r
.35409 .59943 .36578 .61004 .38511 .59717 .37352 .58646 Metetra
.771 .765 0 r
.37352 .58646 .38511 .59717 .40449 .58426 .39302 .57344 Metetra
.661 .744 0 r
.39302 .57344 .40449 .58426 .42393 .57131 .41257 .56039 Metetra
.55 .716 0 r
.41257 .56039 .42393 .57131 .44343 .55832 .43218 .5473 Metetra
.447 .688 0 r
.43218 .5473 .44343 .55832 .46299 .54529 .45185 .53417 Metetra
.35 .661 0 r
.45185 .53417 .46299 .54529 .4826 .53223 .47158 .52101 Metetra
.259 .633 0 r
.47158 .52101 .4826 .53223 .50227 .51913 .49136 .5078 Metetra
.175 .605 0 r
.49136 .5078 .50227 .51913 .522 .50598 .51121 .49455 Metetra
.098 .578 0 r
.51121 .49455 .522 .50598 .54179 .4928 .53111 .48127 Metetra
.028 .55 0 r
.53111 .48127 .54179 .4928 .56164 .47958 .55108 .46794 Metetra
0 .522 .036 r
.55108 .46794 .56164 .47958 .58155 .46632 .5711 .45457 Metetra
0 .495 .094 r
.5711 .45457 .58155 .46632 .60152 .45302 .59119 .44117 Metetra
0 .467 .145 r
.59119 .44117 .60152 .45302 .62154 .43968 .61134 .42772 Metetra
0 .439 .189 r
.61134 .42772 .62154 .43968 .64163 .4263 .63154 .41423 Metetra
0 .412 .226 r
.63154 .41423 .64163 .4263 .66178 .41288 .65181 .4007 Metetra
0 .384 .257 r
.65181 .4007 .66178 .41288 .68199 .39942 .67214 .38713 Metetra
0 .356 .281 r
.67214 .38713 .68199 .39942 .70226 .38592 .69253 .37352 Metetra
0 .329 .299 r
.69253 .37352 .70226 .38592 .72259 .37238 .71299 .35987 Metetra
0 .293 .301 r
.71299 .35987 .72259 .37238 .74298 .3588 .7335 .34618 Metetra
0 .233 .274 r
.7335 .34618 .74298 .3588 .76343 .34517 .75408 .33244 Metetra
0 .18 .246 r
.75408 .33244 .76343 .34517 .78395 .33151 .77472 .31866 Metetra
0 .134 .218 r
.77472 .31866 .78395 .33151 .80453 .3178 .79543 .30484 Metetra
0 .094 .191 r
.79543 .30484 .80453 .3178 .82517 .30405 .81619 .29098 Metetra
0 .061 .163 r
.81619 .29098 .82517 .30405 .84587 .29026 .83702 .27708 Metetra
0 .034 .135 r
.83702 .27708 .84587 .29026 .86664 .27643 .85792 .26313 Metetra
.965 .147 0 r
.22615 .66632 .23866 .67647 .25776 .66373 .24536 .65348 Metetra
.937 .255 0 r
.24536 .65348 .25776 .66373 .27691 .65094 .26462 .64059 Metetra
.909 .357 0 r
.26462 .64059 .27691 .65094 .29612 .63812 .28393 .62767 Metetra
.882 .452 0 r
.28393 .62767 .29612 .63812 .31538 .62526 .30331 .61471 Metetra
.854 .54 0 r
.30331 .61471 .31538 .62526 .33471 .61236 .32274 .60171 Metetra
.826 .621 0 r
.32274 .60171 .33471 .61236 .35409 .59943 .34223 .58868 Metetra
.799 .696 0 r
.34223 .58868 .35409 .59943 .37352 .58646 .36178 .5756 Metetra
.771 .765 0 r
.36178 .5756 .37352 .58646 .39302 .57344 .38139 .56249 Metetra
.661 .744 0 r
.38139 .56249 .39302 .57344 .41257 .56039 .40105 .54933 Metetra
.55 .716 0 r
.40105 .54933 .41257 .56039 .43218 .5473 .42078 .53614 Metetra
.447 .688 0 r
.42078 .53614 .43218 .5473 .45185 .53417 .44056 .52291 Metetra
.35 .661 0 r
.44056 .52291 .45185 .53417 .47158 .52101 .4604 .50963 Metetra
.259 .633 0 r
.4604 .50963 .47158 .52101 .49136 .5078 .4803 .49632 Metetra
.175 .605 0 r
.4803 .49632 .49136 .5078 .51121 .49455 .50027 .48297 Metetra
.098 .578 0 r
.50027 .48297 .51121 .49455 .53111 .48127 .52029 .46957 Metetra
.028 .55 0 r
.52029 .46957 .53111 .48127 .55108 .46794 .54037 .45614 Metetra
0 .522 .036 r
.54037 .45614 .55108 .46794 .5711 .45457 .56052 .44266 Metetra
0 .495 .094 r
.56052 .44266 .5711 .45457 .59119 .44117 .58072 .42915 Metetra
0 .467 .145 r
.58072 .42915 .59119 .44117 .61134 .42772 .60099 .41559 Metetra
0 .439 .189 r
.60099 .41559 .61134 .42772 .63154 .41423 .62132 .40199 Metetra
0 .412 .226 r
.62132 .40199 .63154 .41423 .65181 .4007 .64171 .38835 Metetra
0 .384 .257 r
.64171 .38835 .65181 .4007 .67214 .38713 .66216 .37467 Metetra
0 .356 .281 r
.66216 .37467 .67214 .38713 .69253 .37352 .68268 .36095 Metetra
0 .329 .299 r
.68268 .36095 .69253 .37352 .71299 .35987 .70325 .34719 Metetra
0 .293 .301 r
.70325 .34719 .71299 .35987 .7335 .34618 .7239 .33338 Metetra
0 .233 .274 r
.7239 .33338 .7335 .34618 .75408 .33244 .7446 .31953 Metetra
0 .18 .246 r
.7446 .31953 .75408 .33244 .77472 .31866 .76537 .30564 Metetra
0 .134 .218 r
.76537 .30564 .77472 .31866 .79543 .30484 .7862 .2917 Metetra
0 .094 .191 r
.7862 .2917 .79543 .30484 .81619 .29098 .8071 .27773 Metetra
0 .061 .163 r
.8071 .27773 .81619 .29098 .83702 .27708 .82806 .26371 Metetra
0 .034 .135 r
.82806 .26371 .83702 .27708 .85792 .26313 .84908 .24964 Metetra
.965 .147 0 r
.21348 .65604 .22615 .66632 .24536 .65348 .23279 .64309 Metetra
.937 .255 0 r
.23279 .64309 .24536 .65348 .26462 .64059 .25216 .63011 Metetra
.909 .357 0 r
.25216 .63011 .26462 .64059 .28393 .62767 .27159 .61709 Metetra
.882 .452 0 r
.27159 .61709 .28393 .62767 .30331 .61471 .29107 .60402 Metetra
.854 .54 0 r
.29107 .60402 .30331 .61471 .32274 .60171 .31061 .59092 Metetra
.826 .621 0 r
.31061 .59092 .32274 .60171 .34223 .58868 .33022 .57778 Metetra
.799 .696 0 r
.33022 .57778 .34223 .58868 .36178 .5756 .34988 .5646 Metetra
.771 .765 0 r
.34988 .5646 .36178 .5756 .38139 .56249 .3696 .55138 Metetra
.661 .744 0 r
.3696 .55138 .38139 .56249 .40105 .54933 .38938 .53812 Metetra
.55 .716 0 r
.38938 .53812 .40105 .54933 .42078 .53614 .40922 .52482 Metetra
.447 .688 0 r
.40922 .52482 .42078 .53614 .44056 .52291 .42912 .51149 Metetra
.35 .661 0 r
.42912 .51149 .44056 .52291 .4604 .50963 .44908 .49811 Metetra
.259 .633 0 r
.44908 .49811 .4604 .50963 .4803 .49632 .4691 .48468 Metetra
.175 .605 0 r
.4691 .48468 .4803 .49632 .50027 .48297 .48918 .47122 Metetra
.098 .578 0 r
.48918 .47122 .50027 .48297 .52029 .46957 .50932 .45772 Metetra
.028 .55 0 r
.50932 .45772 .52029 .46957 .54037 .45614 .52952 .44418 Metetra
0 .522 .036 r
.52952 .44418 .54037 .45614 .56052 .44266 .54979 .43059 Metetra
0 .495 .094 r
.54979 .43059 .56052 .44266 .58072 .42915 .57011 .41697 Metetra
0 .467 .145 r
.57011 .41697 .58072 .42915 .60099 .41559 .5905 .4033 Metetra
0 .439 .189 r
.5905 .4033 .60099 .41559 .62132 .40199 .61095 .38959 Metetra
0 .412 .226 r
.61095 .38959 .62132 .40199 .64171 .38835 .63147 .37584 Metetra
0 .384 .257 r
.63147 .37584 .64171 .38835 .66216 .37467 .65204 .36205 Metetra
0 .356 .281 r
.65204 .36205 .66216 .37467 .68268 .36095 .67269 .34821 Metetra
0 .329 .299 r
.67269 .34821 .68268 .36095 .70325 .34719 .69339 .33433 Metetra
0 .293 .301 r
.69339 .33433 .70325 .34719 .7239 .33338 .71416 .32041 Metetra
0 .233 .274 r
.71416 .32041 .7239 .33338 .7446 .31953 .73499 .30644 Metetra
0 .18 .246 r
.73499 .30644 .7446 .31953 .76537 .30564 .75589 .29243 Metetra
0 .134 .218 r
.75589 .29243 .76537 .30564 .7862 .2917 .77685 .27838 Metetra
0 .094 .191 r
.77685 .27838 .7862 .2917 .8071 .27773 .79787 .26429 Metetra
0 .061 .163 r
.79787 .26429 .8071 .27773 .82806 .26371 .81897 .25015 Metetra
0 .034 .135 r
.81897 .25015 .82806 .26371 .84908 .24964 .84012 .23597 Metetra
.965 .147 0 r
.20063 .64562 .21348 .65604 .23279 .64309 .22005 .63257 Metetra
.937 .255 0 r
.22005 .63257 .23279 .64309 .25216 .63011 .23953 .61948 Metetra
.909 .357 0 r
.23953 .61948 .25216 .63011 .27159 .61709 .25907 .60636 Metetra
.882 .452 0 r
.25907 .60636 .27159 .61709 .29107 .60402 .27867 .59319 Metetra
.854 .54 0 r
.27867 .59319 .29107 .60402 .31061 .59092 .29833 .57999 Metetra
.826 .621 0 r
.29833 .57999 .31061 .59092 .33022 .57778 .31804 .56674 Metetra
.799 .696 0 r
.31804 .56674 .33022 .57778 .34988 .5646 .33782 .55346 Metetra
.771 .765 0 r
.33782 .55346 .34988 .5646 .3696 .55138 .35765 .54013 Metetra
.661 .744 0 r
.35765 .54013 .3696 .55138 .38938 .53812 .37755 .52676 Metetra
.55 .716 0 r
.37755 .52676 .38938 .53812 .40922 .52482 .3975 .51336 Metetra
.447 .688 0 r
.3975 .51336 .40922 .52482 .42912 .51149 .41752 .49991 Metetra
.35 .661 0 r
.41752 .49991 .42912 .51149 .44908 .49811 .4376 .48642 Metetra
.259 .633 0 r
.4376 .48642 .44908 .49811 .4691 .48468 .45774 .47289 Metetra
.175 .605 0 r
.45774 .47289 .4691 .48468 .48918 .47122 .47794 .45932 Metetra
.098 .578 0 r
.47794 .45932 .48918 .47122 .50932 .45772 .4982 .44571 Metetra
.028 .55 0 r
.4982 .44571 .50932 .45772 .52952 .44418 .51852 .43205 Metetra
0 .522 .036 r
.51852 .43205 .52952 .44418 .54979 .43059 .53891 .41836 Metetra
0 .495 .094 r
.53891 .41836 .54979 .43059 .57011 .41697 .55936 .40462 Metetra
0 .467 .145 r
.55936 .40462 .57011 .41697 .5905 .4033 .57987 .39084 Metetra
0 .439 .189 r
.57987 .39084 .5905 .4033 .61095 .38959 .60045 .37702 Metetra
0 .412 .226 r
.60045 .37702 .61095 .38959 .63147 .37584 .62109 .36315 Metetra
0 .384 .257 r
.62109 .36315 .63147 .37584 .65204 .36205 .64179 .34924 Metetra
0 .356 .281 r
.64179 .34924 .65204 .36205 .67269 .34821 .66256 .33529 Metetra
0 .329 .299 r
.66256 .33529 .67269 .34821 .69339 .33433 .68339 .32129 Metetra
0 .293 .301 r
.68339 .32129 .69339 .33433 .71416 .32041 .70428 .30726 Metetra
0 .233 .274 r
.70428 .30726 .71416 .32041 .73499 .30644 .72524 .29317 Metetra
0 .18 .246 r
.72524 .29317 .73499 .30644 .75589 .29243 .74627 .27905 Metetra
0 .134 .218 r
.74627 .27905 .75589 .29243 .77685 .27838 .76736 .26488 Metetra
0 .094 .191 r
.76736 .26488 .77685 .27838 .79787 .26429 .78852 .25066 Metetra
0 .061 .163 r
.78852 .25066 .79787 .26429 .81897 .25015 .80975 .2364 Metetra
0 .034 .135 r
.80975 .2364 .81897 .25015 .84012 .23597 .83104 .2221 Metetra
.965 .147 0 r
.18761 .63506 .20063 .64562 .22005 .63257 .20715 .62191 Metetra
.937 .255 0 r
.20715 .62191 .22005 .63257 .23953 .61948 .22674 .60872 Metetra
.909 .357 0 r
.22674 .60872 .23953 .61948 .25907 .60636 .24639 .59549 Metetra
.882 .452 0 r
.24639 .59549 .25907 .60636 .27867 .59319 .2661 .58221 Metetra
.854 .54 0 r
.2661 .58221 .27867 .59319 .29833 .57999 .28587 .5689 Metetra
.826 .621 0 r
.28587 .5689 .29833 .57999 .31804 .56674 .3057 .55555 Metetra
.799 .696 0 r
.3057 .55555 .31804 .56674 .33782 .55346 .32559 .54216 Metetra
.771 .765 0 r
.32559 .54216 .33782 .55346 .35765 .54013 .34554 .52872 Metetra
.661 .744 0 r
.34554 .52872 .35765 .54013 .37755 .52676 .36556 .51525 Metetra
.55 .716 0 r
.36556 .51525 .37755 .52676 .3975 .51336 .38563 .50173 Metetra
.447 .688 0 r
.38563 .50173 .3975 .51336 .41752 .49991 .40576 .48818 Metetra
.35 .661 0 r
.40576 .48818 .41752 .49991 .4376 .48642 .42596 .47458 Metetra
.259 .633 0 r
.42596 .47458 .4376 .48642 .45774 .47289 .44622 .46094 Metetra
.175 .605 0 r
.44622 .46094 .45774 .47289 .47794 .45932 .46654 .44725 Metetra
.098 .578 0 r
.46654 .44725 .47794 .45932 .4982 .44571 .48693 .43353 Metetra
.028 .55 0 r
.48693 .43353 .4982 .44571 .51852 .43205 .50737 .41976 Metetra
0 .522 .036 r
.50737 .41976 .51852 .43205 .53891 .41836 .52788 .40595 Metetra
0 .495 .094 r
.52788 .40595 .53891 .41836 .55936 .40462 .54846 .3921 Metetra
0 .467 .145 r
.54846 .3921 .55936 .40462 .57987 .39084 .56909 .37821 Metetra
0 .439 .189 r
.56909 .37821 .57987 .39084 .60045 .37702 .58979 .36427 Metetra
0 .412 .226 r
.58979 .36427 .60045 .37702 .62109 .36315 .61056 .35029 Metetra
0 .384 .257 r
.61056 .35029 .62109 .36315 .64179 .34924 .63139 .33626 Metetra
0 .356 .281 r
.63139 .33626 .64179 .34924 .66256 .33529 .65229 .32219 Metetra
0 .329 .299 r
.65229 .32219 .66256 .33529 .68339 .32129 .67325 .30808 Metetra
0 .293 .301 r
.67325 .30808 .68339 .32129 .70428 .30726 .69427 .29392 Metetra
0 .233 .274 r
.69427 .29392 .70428 .30726 .72524 .29317 .71536 .27972 Metetra
0 .18 .246 r
.71536 .27972 .72524 .29317 .74627 .27905 .73652 .26547 Metetra
0 .134 .218 r
.73652 .26547 .74627 .27905 .76736 .26488 .75775 .25118 Metetra
0 .094 .191 r
.75775 .25118 .76736 .26488 .78852 .25066 .77904 .23685 Metetra
0 .061 .163 r
.77904 .23685 .78852 .25066 .80975 .2364 .8004 .22247 Metetra
0 .034 .135 r
.8004 .22247 .80975 .2364 .83104 .2221 .82183 .20804 Metetra
.965 .147 0 r
.17442 .62436 .18761 .63506 .20715 .62191 .19407 .6111 Metetra
.937 .255 0 r
.19407 .6111 .20715 .62191 .22674 .60872 .21377 .5978 Metetra
.909 .357 0 r
.21377 .5978 .22674 .60872 .24639 .59549 .23354 .58446 Metetra
.882 .452 0 r
.23354 .58446 .24639 .59549 .2661 .58221 .25336 .57109 Metetra
.854 .54 0 r
.25336 .57109 .2661 .58221 .28587 .5689 .27325 .55767 Metetra
.826 .621 0 r
.27325 .55767 .28587 .5689 .3057 .55555 .29319 .54421 Metetra
.799 .696 0 r
.29319 .54421 .3057 .55555 .32559 .54216 .3132 .5307 Metetra
.771 .765 0 r
.3132 .5307 .32559 .54216 .34554 .52872 .33327 .51716 Metetra
.661 .744 0 r
.33327 .51716 .34554 .52872 .36556 .51525 .3534 .50358 Metetra
.55 .716 0 r
.3534 .50358 .36556 .51525 .38563 .50173 .37359 .48995 Metetra
.447 .688 0 r
.37359 .48995 .38563 .50173 .40576 .48818 .39385 .47628 Metetra
.35 .661 0 r
.39385 .47628 .40576 .48818 .42596 .47458 .41417 .46257 Metetra
.259 .633 0 r
.41417 .46257 .42596 .47458 .44622 .46094 .43455 .44882 Metetra
.175 .605 0 r
.43455 .44882 .44622 .46094 .46654 .44725 .45499 .43502 Metetra
.098 .578 0 r
.45499 .43502 .46654 .44725 .48693 .43353 .4755 .42118 Metetra
.028 .55 0 r
.4755 .42118 .48693 .43353 .50737 .41976 .49607 .4073 Metetra
0 .522 .036 r
.49607 .4073 .50737 .41976 .52788 .40595 .5167 .39338 Metetra
0 .495 .094 r
.5167 .39338 .52788 .40595 .54846 .3921 .5374 .37941 Metetra
0 .467 .145 r
.5374 .37941 .54846 .3921 .56909 .37821 .55816 .3654 Metetra
0 .439 .189 r
.55816 .3654 .56909 .37821 .58979 .36427 .57899 .35134 Metetra
0 .412 .226 r
.57899 .35134 .58979 .36427 .61056 .35029 .59989 .33724 Metetra
0 .384 .257 r
.59989 .33724 .61056 .35029 .63139 .33626 .62085 .3231 Metetra
0 .356 .281 r
.62085 .3231 .63139 .33626 .65229 .32219 .64187 .30891 Metetra
0 .329 .299 r
.64187 .30891 .65229 .32219 .67325 .30808 .66296 .29468 Metetra
0 .293 .301 r
.66296 .29468 .67325 .30808 .69427 .29392 .68412 .2804 Metetra
0 .233 .274 r
.68412 .2804 .69427 .29392 .71536 .27972 .70534 .26608 Metetra
0 .18 .246 r
.70534 .26608 .71536 .27972 .73652 .26547 .72664 .25171 Metetra
0 .134 .218 r
.72664 .25171 .73652 .26547 .75775 .25118 .748 .23729 Metetra
0 .094 .191 r
.748 .23729 .75775 .25118 .77904 .23685 .76942 .22283 Metetra
0 .061 .163 r
.76942 .22283 .77904 .23685 .8004 .22247 .79092 .20833 Metetra
0 .034 .135 r
.79092 .20833 .8004 .22247 .82183 .20804 .81248 .19378 Metetra
.965 .147 0 r
.16105 .61351 .17442 .62436 .19407 .6111 .18081 .60014 Metetra
.937 .255 0 r
.18081 .60014 .19407 .6111 .21377 .5978 .20063 .58674 Metetra
.909 .357 0 r
.20063 .58674 .21377 .5978 .23354 .58446 .22051 .57329 Metetra
.882 .452 0 r
.22051 .57329 .23354 .58446 .25336 .57109 .24045 .55981 Metetra
.854 .54 0 r
.24045 .55981 .25336 .57109 .27325 .55767 .26045 .54628 Metetra
.826 .621 0 r
.26045 .54628 .27325 .55767 .29319 .54421 .28051 .53271 Metetra
.799 .696 0 r
.28051 .53271 .29319 .54421 .3132 .5307 .30064 .51909 Metetra
.771 .765 0 r
.30064 .51909 .3132 .5307 .33327 .51716 .32083 .50544 Metetra
.661 .744 0 r
.32083 .50544 .33327 .51716 .3534 .50358 .34108 .49174 Metetra
.55 .716 0 r
.34108 .49174 .3534 .50358 .37359 .48995 .36139 .478 Metetra
.447 .688 0 r
.36139 .478 .37359 .48995 .39385 .47628 .38177 .46422 Metetra
.35 .661 0 r
.38177 .46422 .39385 .47628 .41417 .46257 .40221 .4504 Metetra
.259 .633 0 r
.40221 .4504 .41417 .46257 .43455 .44882 .42271 .43653 Metetra
.175 .605 0 r
.42271 .43653 .43455 .44882 .45499 .43502 .44328 .42262 Metetra
.098 .578 0 r
.44328 .42262 .45499 .43502 .4755 .42118 .46391 .40866 Metetra
.028 .55 0 r
.46391 .40866 .4755 .42118 .49607 .4073 .4846 .39467 Metetra
0 .522 .036 r
.4846 .39467 .49607 .4073 .5167 .39338 .50536 .38062 Metetra
0 .495 .094 r
.50536 .38062 .5167 .39338 .5374 .37941 .52619 .36654 Metetra
0 .467 .145 r
.52619 .36654 .5374 .37941 .55816 .3654 .54708 .35241 Metetra
0 .439 .189 r
.54708 .35241 .55816 .3654 .57899 .35134 .56804 .33823 Metetra
0 .412 .226 r
.56804 .33823 .57899 .35134 .59989 .33724 .58906 .32401 Metetra
0 .384 .257 r
.58906 .32401 .59989 .33724 .62085 .3231 .61015 .30975 Metetra
0 .356 .281 r
.61015 .30975 .62085 .3231 .64187 .30891 .63131 .29544 Metetra
0 .329 .299 r
.63131 .29544 .64187 .30891 .66296 .29468 .65253 .28108 Metetra
0 .293 .301 r
.65253 .28108 .66296 .29468 .68412 .2804 .67382 .26668 Metetra
0 .233 .274 r
.67382 .26668 .68412 .2804 .70534 .26608 .69518 .25224 Metetra
0 .18 .246 r
.69518 .25224 .70534 .26608 .72664 .25171 .71661 .23775 Metetra
0 .134 .218 r
.71661 .23775 .72664 .25171 .748 .23729 .73811 .22321 Metetra
0 .094 .191 r
.73811 .22321 .748 .23729 .76942 .22283 .75967 .20862 Metetra
0 .061 .163 r
.75967 .20862 .76942 .22283 .79092 .20833 .7813 .19399 Metetra
0 .034 .135 r
.7813 .19399 .79092 .20833 .81248 .19378 .803 .17931 Metetra
.965 .147 0 r
.14749 .60251 .16105 .61351 .18081 .60014 .16736 .58904 Metetra
.937 .255 0 r
.16736 .58904 .18081 .60014 .20063 .58674 .1873 .57552 Metetra
.909 .357 0 r
.1873 .57552 .20063 .58674 .22051 .57329 .2073 .56197 Metetra
.882 .452 0 r
.2073 .56197 .22051 .57329 .24045 .55981 .22735 .54837 Metetra
.854 .54 0 r
.22735 .54837 .24045 .55981 .26045 .54628 .24747 .53473 Metetra
.826 .621 0 r
.24747 .53473 .26045 .54628 .28051 .53271 .26766 .52105 Metetra
.799 .696 0 r
.26766 .52105 .28051 .53271 .30064 .51909 .2879 .50732 Metetra
.771 .765 0 r
.2879 .50732 .30064 .51909 .32083 .50544 .30821 .49356 Metetra
.661 .744 0 r
.30821 .49356 .32083 .50544 .34108 .49174 .32858 .47975 Metetra
.55 .716 0 r
.32858 .47975 .34108 .49174 .36139 .478 .34902 .46589 Metetra
.447 .688 0 r
.34902 .46589 .36139 .478 .38177 .46422 .36951 .45199 Metetra
.35 .661 0 r
.36951 .45199 .38177 .46422 .40221 .4504 .39008 .43805 Metetra
.259 .633 0 r
.39008 .43805 .40221 .4504 .42271 .43653 .41071 .42407 Metetra
.175 .605 0 r
.41071 .42407 .42271 .43653 .44328 .42262 .4314 .41004 Metetra
.098 .578 0 r
.4314 .41004 .44328 .42262 .46391 .40866 .45216 .39597 Metetra
.028 .55 0 r
.45216 .39597 .46391 .40866 .4846 .39467 .47298 .38185 Metetra
0 .522 .036 r
.47298 .38185 .4846 .39467 .50536 .38062 .49387 .36769 Metetra
0 .495 .094 r
.49387 .36769 .50536 .38062 .52619 .36654 .51482 .35349 Metetra
0 .467 .145 r
.51482 .35349 .52619 .36654 .54708 .35241 .53584 .33924 Metetra
0 .439 .189 r
.53584 .33924 .54708 .35241 .56804 .33823 .55693 .32494 Metetra
0 .412 .226 r
.55693 .32494 .56804 .33823 .58906 .32401 .57809 .3106 Metetra
0 .384 .257 r
.57809 .3106 .58906 .32401 .61015 .30975 .59931 .29621 Metetra
0 .356 .281 r
.59931 .29621 .61015 .30975 .63131 .29544 .6206 .28178 Metetra
0 .329 .299 r
.6206 .28178 .63131 .29544 .65253 .28108 .64196 .2673 Metetra
0 .293 .301 r
.64196 .2673 .65253 .28108 .67382 .26668 .66338 .25277 Metetra
0 .233 .274 r
.66338 .25277 .67382 .26668 .69518 .25224 .68488 .2382 Metetra
0 .18 .246 r
.68488 .2382 .69518 .25224 .71661 .23775 .70644 .22358 Metetra
0 .134 .218 r
.70644 .22358 .71661 .23775 .73811 .22321 .72807 .20892 Metetra
0 .094 .191 r
.72807 .20892 .73811 .22321 .75967 .20862 .74978 .19421 Metetra
0 .061 .163 r
.74978 .19421 .75967 .20862 .7813 .19399 .77155 .17945 Metetra
0 .034 .135 r
.77155 .17945 .7813 .19399 .803 .17931 .79339 .16464 Metetra
.965 .147 0 r
.13375 .59136 .14749 .60251 .16736 .58904 .15374 .57778 Metetra
.937 .255 0 r
.15374 .57778 .16736 .58904 .1873 .57552 .17379 .56415 Metetra
.909 .357 0 r
.17379 .56415 .1873 .57552 .2073 .56197 .1939 .55048 Metetra
.882 .452 0 r
.1939 .55048 .2073 .56197 .22735 .54837 .21408 .53677 Metetra
.854 .54 0 r
.21408 .53677 .22735 .54837 .24747 .53473 .23432 .52302 Metetra
.826 .621 0 r
.23432 .52302 .24747 .53473 .26766 .52105 .25462 .50923 Metetra
.799 .696 0 r
.25462 .50923 .26766 .52105 .2879 .50732 .27499 .49539 Metetra
.771 .765 0 r
.27499 .49539 .2879 .50732 .30821 .49356 .29542 .4815 Metetra
.661 .744 0 r
.29542 .4815 .30821 .49356 .32858 .47975 .31591 .46758 Metetra
.55 .716 0 r
.31591 .46758 .32858 .47975 .34902 .46589 .33647 .45361 Metetra
.447 .688 0 r
.33647 .45361 .34902 .46589 .36951 .45199 .35709 .4396 Metetra
.35 .661 0 r
.35709 .4396 .36951 .45199 .39008 .43805 .37778 .42554 Metetra
.259 .633 0 r
.37778 .42554 .39008 .43805 .41071 .42407 .39853 .41144 Metetra
.175 .605 0 r
.39853 .41144 .41071 .42407 .4314 .41004 .41935 .39729 Metetra
.098 .578 0 r
.41935 .39729 .4314 .41004 .45216 .39597 .44024 .3831 Metetra
.028 .55 0 r
.44024 .3831 .45216 .39597 .47298 .38185 .46119 .36886 Metetra
0 .522 .036 r
.46119 .36886 .47298 .38185 .49387 .36769 .48221 .35458 Metetra
0 .495 .094 r
.48221 .35458 .49387 .36769 .51482 .35349 .50329 .34025 Metetra
0 .467 .145 r
.50329 .34025 .51482 .35349 .53584 .33924 .52445 .32588 Metetra
0 .439 .189 r
.52445 .32588 .53584 .33924 .55693 .32494 .54567 .31146 Metetra
0 .412 .226 r
.54567 .31146 .55693 .32494 .57809 .3106 .56695 .29699 Metetra
0 .384 .257 r
.56695 .29699 .57809 .3106 .59931 .29621 .58831 .28248 Metetra
0 .356 .281 r
.58831 .28248 .59931 .29621 .6206 .28178 .60973 .26792 Metetra
0 .329 .299 r
.60973 .26792 .6206 .28178 .64196 .2673 .63123 .25332 Metetra
0 .293 .301 r
.63123 .25332 .64196 .2673 .66338 .25277 .65279 .23867 Metetra
0 .233 .274 r
.65279 .23867 .66338 .25277 .68488 .2382 .67442 .22397 Metetra
0 .18 .246 r
.67442 .22397 .68488 .2382 .70644 .22358 .69612 .20922 Metetra
0 .134 .218 r
.69612 .20922 .70644 .22358 .72807 .20892 .7179 .19442 Metetra
0 .094 .191 r
.7179 .19442 .72807 .20892 .74978 .19421 .73974 .17958 Metetra
0 .061 .163 r
.73974 .17958 .74978 .19421 .77155 .17945 .76165 .16469 Metetra
0 .034 .135 r
.76165 .16469 .77155 .17945 .79339 .16464 .78364 .14975 Metetra
.965 .147 0 r
.11981 .58006 .13375 .59136 .15374 .57778 .13992 .56636 Metetra
.937 .255 0 r
.13992 .56636 .15374 .57778 .17379 .56415 .16009 .55262 Metetra
.909 .357 0 r
.16009 .55262 .17379 .56415 .1939 .55048 .18032 .53884 Metetra
.882 .452 0 r
.18032 .53884 .1939 .55048 .21408 .53677 .20062 .52502 Metetra
.854 .54 0 r
.20062 .52502 .21408 .53677 .23432 .52302 .22098 .51115 Metetra
.826 .621 0 r
.22098 .51115 .23432 .52302 .25462 .50923 .2414 .49724 Metetra
.799 .696 0 r
.2414 .49724 .25462 .50923 .27499 .49539 .26189 .48328 Metetra
.771 .765 0 r
.26189 .48328 .27499 .49539 .29542 .4815 .28244 .46928 Metetra
.661 .744 0 r
.28244 .46928 .29542 .4815 .31591 .46758 .30306 .45524 Metetra
.55 .716 0 r
.30306 .45524 .31591 .46758 .33647 .45361 .32374 .44115 Metetra
.447 .688 0 r
.32374 .44115 .33647 .45361 .35709 .4396 .34449 .42702 Metetra
.35 .661 0 r
.34449 .42702 .35709 .4396 .37778 .42554 .36531 .41284 Metetra
.259 .633 0 r
.36531 .41284 .37778 .42554 .39853 .41144 .38619 .39862 Metetra
.175 .605 0 r
.38619 .39862 .39853 .41144 .41935 .39729 .40714 .38435 Metetra
.098 .578 0 r
.40714 .38435 .41935 .39729 .44024 .3831 .42815 .37004 Metetra
.028 .55 0 r
.42815 .37004 .44024 .3831 .46119 .36886 .44923 .35568 Metetra
0 .522 .036 r
.44923 .35568 .46119 .36886 .48221 .35458 .47038 .34127 Metetra
0 .495 .094 r
.47038 .34127 .48221 .35458 .50329 .34025 .4916 .32682 Metetra
0 .467 .145 r
.4916 .32682 .50329 .34025 .52445 .32588 .51288 .31233 Metetra
0 .439 .189 r
.51288 .31233 .52445 .32588 .54567 .31146 .53424 .29778 Metetra
0 .412 .226 r
.53424 .29778 .54567 .31146 .56695 .29699 .55566 .28319 Metetra
0 .384 .257 r
.55566 .28319 .56695 .29699 .58831 .28248 .57715 .26855 Metetra
0 .356 .281 r
.57715 .26855 .58831 .28248 .60973 .26792 .59871 .25387 Metetra
0 .329 .299 r
.59871 .25387 .60973 .26792 .63123 .25332 .62034 .23913 Metetra
0 .293 .301 r
.62034 .23913 .63123 .25332 .65279 .23867 .64204 .22435 Metetra
0 .233 .274 r
.64204 .22435 .65279 .23867 .67442 .22397 .66382 .20952 Metetra
0 .18 .246 r
.66382 .20952 .67442 .22397 .69612 .20922 .68566 .19465 Metetra
0 .134 .218 r
.68566 .19465 .69612 .20922 .7179 .19442 .70757 .17972 Metetra
0 .094 .191 r
.70757 .17972 .7179 .19442 .73974 .17958 .72956 .16475 Metetra
0 .061 .163 r
.72956 .16475 .73974 .17958 .76165 .16469 .75161 .14972 Metetra
0 .034 .135 r
.75161 .14972 .76165 .16469 .78364 .14975 .77374 .13465 Metetra
.965 .147 0 r
.10568 .56859 .11981 .58006 .13992 .56636 .12591 .55478 Metetra
.937 .255 0 r
.12591 .55478 .13992 .56636 .16009 .55262 .1462 .54093 Metetra
.909 .357 0 r
.1462 .54093 .16009 .55262 .18032 .53884 .16655 .52704 Metetra
.882 .452 0 r
.16655 .52704 .18032 .53884 .20062 .52502 .18697 .5131 Metetra
.854 .54 0 r
.18697 .5131 .20062 .52502 .22098 .51115 .20745 .49911 Metetra
.826 .621 0 r
.20745 .49911 .22098 .51115 .2414 .49724 .228 .48508 Metetra
.799 .696 0 r
.228 .48508 .2414 .49724 .26189 .48328 .24861 .47101 Metetra
.771 .765 0 r
.24861 .47101 .26189 .48328 .28244 .46928 .26929 .45689 Metetra
.661 .744 0 r
.26929 .45689 .28244 .46928 .30306 .45524 .29003 .44273 Metetra
.55 .716 0 r
.29003 .44273 .30306 .45524 .32374 .44115 .31084 .42852 Metetra
.447 .688 0 r
.31084 .42852 .32374 .44115 .34449 .42702 .33172 .41427 Metetra
.35 .661 0 r
.33172 .41427 .34449 .42702 .36531 .41284 .35266 .39997 Metetra
.259 .633 0 r
.35266 .39997 .36531 .41284 .38619 .39862 .37367 .38562 Metetra
.175 .605 0 r
.37367 .38562 .38619 .39862 .40714 .38435 .39475 .37123 Metetra
.098 .578 0 r
.39475 .37123 .40714 .38435 .42815 .37004 .41589 .35679 Metetra
.028 .55 0 r
.41589 .35679 .42815 .37004 .44923 .35568 .4371 .34231 Metetra
0 .522 .036 r
.4371 .34231 .44923 .35568 .47038 .34127 .45839 .32778 Metetra
0 .495 .094 r
.45839 .32778 .47038 .34127 .4916 .32682 .47974 .3132 Metetra
0 .467 .145 r
.47974 .3132 .4916 .32682 .51288 .31233 .50116 .29858 Metetra
0 .439 .189 r
.50116 .29858 .51288 .31233 .53424 .29778 .52264 .28391 Metetra
0 .412 .226 r
.52264 .28391 .53424 .29778 .55566 .28319 .5442 .26919 Metetra
0 .384 .257 r
.5442 .26919 .55566 .28319 .57715 .26855 .56583 .25442 Metetra
0 .356 .281 r
.56583 .25442 .57715 .26855 .59871 .25387 .58753 .23961 Metetra
0 .329 .299 r
.58753 .23961 .59871 .25387 .62034 .23913 .6093 .22474 Metetra
0 .293 .301 r
.6093 .22474 .62034 .23913 .64204 .22435 .63114 .20983 Metetra
0 .233 .274 r
.63114 .20983 .64204 .22435 .66382 .20952 .65305 .19487 Metetra
0 .18 .246 r
.65305 .19487 .66382 .20952 .68566 .19465 .67504 .17986 Metetra
0 .134 .218 r
.67504 .17986 .68566 .19465 .70757 .17972 .69709 .1648 Metetra
0 .094 .191 r
.69709 .1648 .70757 .17972 .72956 .16475 .71922 .14969 Metetra
0 .061 .163 r
.71922 .14969 .72956 .16475 .75161 .14972 .74143 .13453 Metetra
0 .034 .135 r
.74143 .13453 .75161 .14972 .77374 .13465 .7637 .11932 Metetra
.965 .147 0 r
.09135 .55697 .10568 .56859 .12591 .55478 .1117 .54304 Metetra
.937 .255 0 r
.1117 .54304 .12591 .55478 .1462 .54093 .13211 .52908 Metetra
.909 .357 0 r
.13211 .52908 .1462 .54093 .16655 .52704 .15258 .51506 Metetra
.882 .452 0 r
.15258 .51506 .16655 .52704 .18697 .5131 .17312 .501 Metetra
.854 .54 0 r
.17312 .501 .18697 .5131 .20745 .49911 .19373 .4869 Metetra
.826 .621 0 r
.19373 .4869 .20745 .49911 .228 .48508 .2144 .47275 Metetra
.799 .696 0 r
.2144 .47275 .228 .48508 .24861 .47101 .23514 .45856 Metetra
.771 .765 0 r
.23514 .45856 .24861 .47101 .26929 .45689 .25594 .44432 Metetra
.661 .744 0 r
.25594 .44432 .26929 .45689 .29003 .44273 .27681 .43004 Metetra
.55 .716 0 r
.27681 .43004 .29003 .44273 .31084 .42852 .29775 .41571 Metetra
.447 .688 0 r
.29775 .41571 .31084 .42852 .33172 .41427 .31875 .40133 Metetra
.35 .661 0 r
.31875 .40133 .33172 .41427 .35266 .39997 .33983 .38691 Metetra
.259 .633 0 r
.33983 .38691 .35266 .39997 .37367 .38562 .36097 .37244 Metetra
.175 .605 0 r
.36097 .37244 .37367 .38562 .39475 .37123 .38218 .35792 Metetra
.098 .578 0 r
.38218 .35792 .39475 .37123 .41589 .35679 .40345 .34336 Metetra
.028 .55 0 r
.40345 .34336 .41589 .35679 .4371 .34231 .4248 .32875 Metetra
0 .522 .036 r
.4248 .32875 .4371 .34231 .45839 .32778 .44622 .31409 Metetra
0 .495 .094 r
.44622 .31409 .45839 .32778 .47974 .3132 .4677 .29939 Metetra
0 .467 .145 r
.4677 .29939 .47974 .3132 .50116 .29858 .48926 .28463 Metetra
0 .439 .189 r
.48926 .28463 .50116 .29858 .52264 .28391 .51088 .26983 Metetra
0 .412 .226 r
.51088 .26983 .52264 .28391 .5442 .26919 .53258 .25498 Metetra
0 .384 .257 r
.53258 .25498 .5442 .26919 .56583 .25442 .55435 .24008 Metetra
0 .356 .281 r
.55435 .24008 .56583 .25442 .58753 .23961 .57619 .22514 Metetra
0 .329 .299 r
.57619 .22514 .58753 .23961 .6093 .22474 .5981 .21014 Metetra
0 .293 .301 r
.5981 .21014 .6093 .22474 .63114 .20983 .62008 .19509 Metetra
0 .233 .274 r
.62008 .19509 .63114 .20983 .65305 .19487 .64213 .18 Metetra
0 .18 .246 r
.64213 .18 .65305 .19487 .67504 .17986 .66426 .16485 Metetra
0 .134 .218 r
.66426 .16485 .67504 .17986 .69709 .1648 .68646 .14966 Metetra
0 .094 .191 r
.68646 .14966 .69709 .1648 .71922 .14969 .70874 .13441 Metetra
0 .061 .163 r
.70874 .13441 .71922 .14969 .74143 .13453 .73109 .11912 Metetra
0 .034 .135 r
.73109 .11912 .74143 .13453 .7637 .11932 .75351 .10377 Metetra
.965 .147 0 r
.07682 .54518 .09135 .55697 .1117 .54304 .09729 .53114 Metetra
.937 .255 0 r
.09729 .53114 .1117 .54304 .13211 .52908 .11782 .51705 Metetra
.909 .357 0 r
.11782 .51705 .13211 .52908 .15258 .51506 .13842 .50292 Metetra
.882 .452 0 r
.13842 .50292 .15258 .51506 .17312 .501 .15908 .48874 Metetra
.854 .54 0 r
.15908 .48874 .17312 .501 .19373 .4869 .17981 .47452 Metetra
.826 .621 0 r
.17981 .47452 .19373 .4869 .2144 .47275 .20061 .46025 Metetra
.799 .696 0 r
.20061 .46025 .2144 .47275 .23514 .45856 .22147 .44593 Metetra
.771 .765 0 r
.22147 .44593 .23514 .45856 .25594 .44432 .24241 .43157 Metetra
.661 .744 0 r
.24241 .43157 .25594 .44432 .27681 .43004 .2634 .41716 Metetra
.55 .716 0 r
.2634 .41716 .27681 .43004 .29775 .41571 .28447 .40271 Metetra
.447 .688 0 r
.28447 .40271 .29775 .41571 .31875 .40133 .30561 .38821 Metetra
.35 .661 0 r
.30561 .38821 .31875 .40133 .33983 .38691 .32681 .37366 Metetra
.259 .633 0 r
.32681 .37366 .33983 .38691 .36097 .37244 .34808 .35906 Metetra
.175 .605 0 r
.34808 .35906 .36097 .37244 .38218 .35792 .36942 .34442 Metetra
.098 .578 0 r
.36942 .34442 .38218 .35792 .40345 .34336 .39084 .32973 Metetra
.028 .55 0 r
.39084 .32973 .40345 .34336 .4248 .32875 .41232 .31499 Metetra
0 .522 .036 r
.41232 .31499 .4248 .32875 .44622 .31409 .43387 .3002 Metetra
0 .495 .094 r
.43387 .3002 .44622 .31409 .4677 .29939 .45549 .28537 Metetra
0 .467 .145 r
.45549 .28537 .4677 .29939 .48926 .28463 .47718 .27048 Metetra
0 .439 .189 r
.47718 .27048 .48926 .28463 .51088 .26983 .49895 .25555 Metetra
0 .412 .226 r
.49895 .25555 .51088 .26983 .53258 .25498 .52078 .24057 Metetra
0 .384 .257 r
.52078 .24057 .53258 .25498 .55435 .24008 .54269 .22554 Metetra
0 .356 .281 r
.54269 .22554 .55435 .24008 .57619 .22514 .56467 .21045 Metetra
0 .329 .299 r
.56467 .21045 .57619 .22514 .5981 .21014 .58673 .19532 Metetra
0 .293 .301 r
.58673 .19532 .5981 .21014 .62008 .19509 .60885 .18014 Metetra
0 .233 .274 r
.60885 .18014 .62008 .19509 .64213 .18 .63105 .16491 Metetra
0 .18 .246 r
.63105 .16491 .64213 .18 .66426 .16485 .65333 .14963 Metetra
0 .134 .218 r
.65333 .14963 .66426 .16485 .68646 .14966 .67567 .13429 Metetra
0 .094 .191 r
.67567 .13429 .68646 .14966 .70874 .13441 .6981 .11891 Metetra
0 .061 .163 r
.6981 .11891 .70874 .13441 .73109 .11912 .72059 .10347 Metetra
0 .034 .135 r
.72059 .10347 .73109 .11912 .75351 .10377 .74317 .08799 Metetra
.965 .147 0 r
.06208 .53322 .07682 .54518 .09729 .53114 .08267 .51906 Metetra
.937 .255 0 r
.08267 .51906 .09729 .53114 .11782 .51705 .10333 .50485 Metetra
.909 .357 0 r
.10333 .50485 .11782 .51705 .13842 .50292 .12405 .4906 Metetra
.882 .452 0 r
.12405 .4906 .13842 .50292 .15908 .48874 .14484 .4763 Metetra
.854 .54 0 r
.14484 .4763 .15908 .48874 .17981 .47452 .1657 .46195 Metetra
.826 .621 0 r
.1657 .46195 .17981 .47452 .20061 .46025 .18662 .44756 Metetra
.799 .696 0 r
.18662 .44756 .20061 .46025 .22147 .44593 .20761 .43312 Metetra
.771 .765 0 r
.20761 .43312 .22147 .44593 .24241 .43157 .22867 .41863 Metetra
.661 .744 0 r
.22867 .41863 .24241 .43157 .2634 .41716 .2498 .4041 Metetra
.55 .716 0 r
.2498 .4041 .2634 .41716 .28447 .40271 .271 .38952 Metetra
.447 .688 0 r
.271 .38952 .28447 .40271 .30561 .38821 .29227 .37489 Metetra
.35 .661 0 r
.29227 .37489 .30561 .38821 .32681 .37366 .3136 .36022 Metetra
.259 .633 0 r
.3136 .36022 .32681 .37366 .34808 .35906 .33501 .34549 Metetra
.175 .605 0 r
.33501 .34549 .34808 .35906 .36942 .34442 .35649 .33072 Metetra
.098 .578 0 r
.35649 .33072 .36942 .34442 .39084 .32973 .37803 .3159 Metetra
.028 .55 0 r
.37803 .3159 .39084 .32973 .41232 .31499 .39965 .30103 Metetra
0 .522 .036 r
.39965 .30103 .41232 .31499 .43387 .3002 .42134 .28611 Metetra
0 .495 .094 r
.42134 .28611 .43387 .3002 .45549 .28537 .4431 .27114 Metetra
0 .467 .145 r
.4431 .27114 .45549 .28537 .47718 .27048 .46493 .25612 Metetra
0 .439 .189 r
.46493 .25612 .47718 .27048 .49895 .25555 .48684 .24106 Metetra
0 .412 .226 r
.48684 .24106 .49895 .25555 .52078 .24057 .50882 .22594 Metetra
0 .384 .257 r
.50882 .22594 .52078 .24057 .54269 .22554 .53087 .21077 Metetra
0 .356 .281 r
.53087 .21077 .54269 .22554 .56467 .21045 .55299 .19555 Metetra
0 .329 .299 r
.55299 .19555 .56467 .21045 .58673 .19532 .57519 .18029 Metetra
0 .293 .301 r
.57519 .18029 .58673 .19532 .60885 .18014 .59746 .16497 Metetra
0 .233 .274 r
.59746 .16497 .60885 .18014 .63105 .16491 .61981 .1496 Metetra
0 .18 .246 r
.61981 .1496 .63105 .16491 .65333 .14963 .64223 .13417 Metetra
0 .134 .218 r
.64223 .13417 .65333 .14963 .67567 .13429 .66472 .1187 Metetra
0 .094 .191 r
.66472 .1187 .67567 .13429 .6981 .11891 .6873 .10317 Metetra
0 .061 .163 r
.6873 .10317 .6981 .11891 .72059 .10347 .70995 .08759 Metetra
0 .034 .135 r
.70995 .08759 .72059 .10347 .74317 .08799 .73267 .07196 Metetra
.965 .147 0 r
.04713 .52109 .06208 .53322 .08267 .51906 .06784 .50681 Metetra
.937 .255 0 r
.06784 .50681 .08267 .51906 .10333 .50485 .08862 .49248 Metetra
.909 .357 0 r
.08862 .49248 .10333 .50485 .12405 .4906 .10947 .4781 Metetra
.882 .452 0 r
.10947 .4781 .12405 .4906 .14484 .4763 .13039 .46368 Metetra
.854 .54 0 r
.13039 .46368 .14484 .4763 .1657 .46195 .15137 .44921 Metetra
.826 .621 0 r
.15137 .44921 .1657 .46195 .18662 .44756 .17243 .43469 Metetra
.799 .696 0 r
.17243 .43469 .18662 .44756 .20761 .43312 .19355 .42012 Metetra
.771 .765 0 r
.19355 .42012 .20761 .43312 .22867 .41863 .21474 .40551 Metetra
.661 .744 0 r
.21474 .40551 .22867 .41863 .2498 .4041 .236 .39085 Metetra
.55 .716 0 r
.236 .39085 .2498 .4041 .271 .38952 .25733 .37614 Metetra
.447 .688 0 r
.25733 .37614 .271 .38952 .29227 .37489 .27873 .36138 Metetra
.35 .661 0 r
.27873 .36138 .29227 .37489 .3136 .36022 .3002 .34657 Metetra
.259 .633 0 r
.3002 .34657 .3136 .36022 .33501 .34549 .32174 .33172 Metetra
.175 .605 0 r
.32174 .33172 .33501 .34549 .35649 .33072 .34336 .31682 Metetra
.098 .578 0 r
.34336 .31682 .35649 .33072 .37803 .3159 .36504 .30186 Metetra
.028 .55 0 r
.36504 .30186 .37803 .3159 .39965 .30103 .3868 .28686 Metetra
0 .522 .036 r
.3868 .28686 .39965 .30103 .42134 .28611 .40862 .27181 Metetra
0 .495 .094 r
.40862 .27181 .42134 .28611 .4431 .27114 .43053 .2567 Metetra
0 .467 .145 r
.43053 .2567 .4431 .27114 .46493 .25612 .4525 .24155 Metetra
0 .439 .189 r
.4525 .24155 .46493 .25612 .48684 .24106 .47455 .22635 Metetra
0 .412 .226 r
.47455 .22635 .48684 .24106 .50882 .22594 .49667 .21109 Metetra
0 .384 .257 r
.49667 .21109 .50882 .22594 .53087 .21077 .51886 .19579 Metetra
0 .356 .281 r
.51886 .19579 .53087 .21077 .55299 .19555 .54113 .18043 Metetra
0 .329 .299 r
.54113 .18043 .55299 .19555 .57519 .18029 .56348 .16502 Metetra
0 .293 .301 r
.56348 .16502 .57519 .18029 .59746 .16497 .5859 .14956 Metetra
0 .233 .274 r
.5859 .14956 .59746 .16497 .61981 .1496 .60839 .13405 Metetra
0 .18 .246 r
.60839 .13405 .61981 .1496 .64223 .13417 .63096 .11849 Metetra
0 .134 .218 r
.63096 .11849 .64223 .13417 .66472 .1187 .65361 .10287 Metetra
0 .094 .191 r
.65361 .10287 .66472 .1187 .6873 .10317 .67633 .0872 Metetra
0 .061 .163 r
.67633 .0872 .6873 .10317 .70995 .08759 .69913 .07147 Metetra
0 .034 .135 r
.69913 .07147 .70995 .08759 .73267 .07196 .72201 .0557 Metetra
.965 .147 0 r
.03196 .50879 .04713 .52109 .06784 .50681 .0528 .49438 Metetra
.937 .255 0 r
.0528 .49438 .06784 .50681 .08862 .49248 .07371 .47992 Metetra
.909 .357 0 r
.07371 .47992 .08862 .49248 .10947 .4781 .09468 .46542 Metetra
.882 .452 0 r
.09468 .46542 .10947 .4781 .13039 .46368 .11573 .45087 Metetra
.854 .54 0 r
.11573 .45087 .13039 .46368 .15137 .44921 .13684 .43627 Metetra
.826 .621 0 r
.13684 .43627 .15137 .44921 .17243 .43469 .15803 .42163 Metetra
.799 .696 0 r
.15803 .42163 .17243 .43469 .19355 .42012 .17928 .40693 Metetra
.771 .765 0 r
.17928 .40693 .19355 .42012 .21474 .40551 .2006 .39219 Metetra
.661 .744 0 r
.2006 .39219 .21474 .40551 .236 .39085 .222 .3774 Metetra
.55 .716 0 r
.222 .3774 .236 .39085 .25733 .37614 .24346 .36256 Metetra
.447 .688 0 r
.24346 .36256 .25733 .37614 .27873 .36138 .265 .34767 Metetra
.35 .661 0 r
.265 .34767 .27873 .36138 .3002 .34657 .2866 .33273 Metetra
.259 .633 0 r
.2866 .33273 .3002 .34657 .32174 .33172 .30828 .31775 Metetra
.175 .605 0 r
.30828 .31775 .32174 .33172 .34336 .31682 .33003 .30271 Metetra
.098 .578 0 r
.33003 .30271 .34336 .31682 .36504 .30186 .35186 .28762 Metetra
.028 .55 0 r
.35186 .28762 .36504 .30186 .3868 .28686 .37375 .27248 Metetra
0 .522 .036 r
.37375 .27248 .3868 .28686 .40862 .27181 .39572 .25729 Metetra
0 .495 .094 r
.39572 .25729 .40862 .27181 .43053 .2567 .41776 .24205 Metetra
0 .467 .145 r
.41776 .24205 .43053 .2567 .4525 .24155 .43988 .22676 Metetra
0 .439 .189 r
.43988 .22676 .4525 .24155 .47455 .22635 .46207 .21142 Metetra
0 .412 .226 r
.46207 .21142 .47455 .22635 .49667 .21109 .48434 .19602 Metetra
0 .384 .257 r
.48434 .19602 .49667 .21109 .51886 .19579 .50668 .18058 Metetra
0 .356 .281 r
.50668 .18058 .51886 .19579 .54113 .18043 .5291 .16508 Metetra
0 .329 .299 r
.5291 .16508 .54113 .18043 .56348 .16502 .55159 .14953 Metetra
0 .293 .301 r
.55159 .14953 .56348 .16502 .5859 .14956 .57416 .13393 Metetra
0 .233 .274 r
.57416 .13393 .5859 .14956 .60839 .13405 .5968 .11827 Metetra
0 .18 .246 r
.5968 .11827 .60839 .13405 .63096 .11849 .61952 .10256 Metetra
0 .134 .218 r
.61952 .10256 .63096 .11849 .65361 .10287 .64232 .0868 Metetra
0 .094 .191 r
.64232 .0868 .65361 .10287 .67633 .0872 .6652 .07098 Metetra
0 .061 .163 r
.6652 .07098 .67633 .0872 .69913 .07147 .68816 .05511 Metetra
0 .034 .135 r
.68816 .05511 .69913 .07147 .72201 .0557 .71119 .03918 Metetra
.965 .147 0 r
.01657 .4963 .03196 .50879 .0528 .49438 .03754 .48177 Metetra
.937 .255 0 r
.03754 .48177 .0528 .49438 .07371 .47992 .05857 .46718 Metetra
.909 .357 0 r
.05857 .46718 .07371 .47992 .09468 .46542 .07968 .45255 Metetra
.882 .452 0 r
.07968 .45255 .09468 .46542 .11573 .45087 .10085 .43788 Metetra
.854 .54 0 r
.10085 .43788 .11573 .45087 .13684 .43627 .1221 .42315 Metetra
.826 .621 0 r
.1221 .42315 .13684 .43627 .15803 .42163 .14341 .40837 Metetra
.799 .696 0 r
.14341 .40837 .15803 .42163 .17928 .40693 .1648 .39355 Metetra
.771 .765 0 r
.1648 .39355 .17928 .40693 .2006 .39219 .18626 .37868 Metetra
.661 .744 0 r
.18626 .37868 .2006 .39219 .222 .3774 .20778 .36375 Metetra
.55 .716 0 r
.20778 .36375 .222 .3774 .24346 .36256 .22938 .34878 Metetra
.447 .688 0 r
.22938 .34878 .24346 .36256 .265 .34767 .25106 .33376 Metetra
.35 .661 0 r
.25106 .33376 .265 .34767 .2866 .33273 .2728 .31868 Metetra
.259 .633 0 r
.2728 .31868 .2866 .33273 .30828 .31775 .29462 .30356 Metetra
.175 .605 0 r
.29462 .30356 .30828 .31775 .33003 .30271 .31651 .28839 Metetra
.098 .578 0 r
.31651 .28839 .33003 .30271 .35186 .28762 .33847 .27316 Metetra
.028 .55 0 r
.33847 .27316 .35186 .28762 .37375 .27248 .36051 .25789 Metetra
0 .522 .036 r
.36051 .25789 .37375 .27248 .39572 .25729 .38262 .24256 Metetra
0 .495 .094 r
.38262 .24256 .39572 .25729 .41776 .24205 .40481 .22718 Metetra
0 .467 .145 r
.40481 .22718 .41776 .24205 .43988 .22676 .42707 .21175 Metetra
0 .439 .189 r
.42707 .21175 .43988 .22676 .46207 .21142 .44941 .19626 Metetra
0 .412 .226 r
.44941 .19626 .46207 .21142 .48434 .19602 .47182 .18073 Metetra
0 .384 .257 r
.47182 .18073 .48434 .19602 .50668 .18058 .49431 .16514 Metetra
0 .356 .281 r
.49431 .16514 .50668 .18058 .5291 .16508 .51688 .1495 Metetra
0 .329 .299 r
.51688 .1495 .5291 .16508 .55159 .14953 .53952 .1338 Metetra
0 .293 .301 r
.53952 .1338 .55159 .14953 .57416 .13393 .56224 .11805 Metetra
0 .233 .274 r
.56224 .11805 .57416 .13393 .5968 .11827 .58504 .10225 Metetra
0 .18 .246 r
.58504 .10225 .5968 .11827 .61952 .10256 .60791 .08639 Metetra
0 .134 .218 r
.60791 .08639 .61952 .10256 .64232 .0868 .63087 .07048 Metetra
0 .094 .191 r
.63087 .07048 .64232 .0868 .6652 .07098 .6539 .05451 Metetra
0 .061 .163 r
.6539 .05451 .6652 .07098 .68816 .05511 .67701 .03849 Metetra
0 .034 .135 r
.67701 .03849 .68816 .05511 .71119 .03918 .70021 .02241 Metetra
.965 .147 0 r
.00095 .48363 .01657 .4963 .03754 .48177 .02205 .46897 Metetra
.937 .255 0 r
.02205 .46897 .03754 .48177 .05857 .46718 .04321 .45426 Metetra
.909 .357 0 r
.04321 .45426 .05857 .46718 .07968 .45255 .06445 .4395 Metetra
.882 .452 0 r
.06445 .4395 .07968 .45255 .10085 .43788 .08576 .42469 Metetra
.854 .54 0 r
.08576 .42469 .10085 .43788 .1221 .42315 .10713 .40983 Metetra
.826 .621 0 r
.10713 .40983 .1221 .42315 .14341 .40837 .12858 .39492 Metetra
.799 .696 0 r
.12858 .39492 .14341 .40837 .1648 .39355 .1501 .37997 Metetra
.771 .765 0 r
.1501 .37997 .1648 .39355 .18626 .37868 .17169 .36496 Metetra
.661 .744 0 r
.17169 .36496 .18626 .37868 .20778 .36375 .19336 .3499 Metetra
.55 .716 0 r
.19336 .3499 .20778 .36375 .22938 .34878 .2151 .33479 Metetra
.447 .688 0 r
.2151 .33479 .22938 .34878 .25106 .33376 .23691 .31964 Metetra
.35 .661 0 r
.23691 .31964 .25106 .33376 .2728 .31868 .25879 .30443 Metetra
.259 .633 0 r
.25879 .30443 .2728 .31868 .29462 .30356 .28075 .28916 Metetra
.175 .605 0 r
.28075 .28916 .29462 .30356 .31651 .28839 .30278 .27385 Metetra
.098 .578 0 r
.30278 .27385 .31651 .28839 .33847 .27316 .32489 .25849 Metetra
.028 .55 0 r
.32489 .25849 .33847 .27316 .36051 .25789 .34707 .24307 Metetra
0 .522 .036 r
.34707 .24307 .36051 .25789 .38262 .24256 .36933 .2276 Metetra
0 .495 .094 r
.36933 .2276 .38262 .24256 .40481 .22718 .39166 .21208 Metetra
0 .467 .145 r
.39166 .21208 .40481 .22718 .42707 .21175 .41407 .19651 Metetra
0 .439 .189 r
.41407 .19651 .42707 .21175 .44941 .19626 .43655 .18088 Metetra
0 .412 .226 r
.43655 .18088 .44941 .19626 .47182 .18073 .45911 .1652 Metetra
0 .384 .257 r
.45911 .1652 .47182 .18073 .49431 .16514 .48175 .14946 Metetra
0 .356 .281 r
.48175 .14946 .49431 .16514 .51688 .1495 .50447 .13367 Metetra
0 .329 .299 r
.50447 .13367 .51688 .1495 .53952 .1338 .52727 .11783 Metetra
0 .293 .301 r
.52727 .11783 .53952 .1338 .56224 .11805 .55014 .10193 Metetra
0 .233 .274 r
.55014 .10193 .56224 .11805 .58504 .10225 .57309 .08598 Metetra
0 .18 .246 r
.57309 .08598 .58504 .10225 .60791 .08639 .59612 .06997 Metetra
0 .134 .218 r
.59612 .06997 .60791 .08639 .63087 .07048 .61923 .05391 Metetra
0 .094 .191 r
.61923 .05391 .63087 .07048 .6539 .05451 .64242 .03779 Metetra
0 .061 .163 r
.64242 .03779 .6539 .05451 .67701 .03849 .6657 .02162 Metetra
0 .034 .135 r
.6657 .02162 .67701 .03849 .70021 .02241 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-0.5)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.4)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(-0.3)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(-0.2)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(-0.1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00]?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0005kooooo002cooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0GOooool00:cooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0GOooool00;?ooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`1Mooooo`00/oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo05gooooo002cooooo`04o`000?ooooooooooo`0000Sooooo0_l0000;oooo
o`;o00001?ooool01?l0003oooooooooooooool5o`0004Gooooo002dooooo`;o00002_ooool00ol0
003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000AOoo
ool00<Cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0AOoo
ool00<_ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`14ooooo`00boooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000AOooool00<_ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000004Gooooo0030ooooo`;o0000
2_ooool2o`0000Wooooo0ol00016ooooo`00_Oooool6o`0005gooooo002kooooo`;o00000_ooool0
1?l0003o00PRo`000?l0001Mooooo`00^?ooool3o`0000;ooooo0_l00002o`088P?o0000G?ooool0
0;Gooooo1?l00003ooooo`03o`000?l022;o00PR00;o00PR00?o0000o`088_l00000G?ooool00;?o
oooo0_l00005ooooo`;o00001Ol022801?l0003o00PRo`000?l0001Kooooo`00/?ooool3o`0000Ko
oooo00?o0000o`0?:Ol000001Ol022800ol0003o00PRo`000002o`0005[ooooo0024ooooo`;o0000
1?ooool01?l0003oooooooooooooool5o`0001_ooooo0_l00008ooooo`05o`000?l03bWo00lYo`0?
:Ol000001?l02282o`000004o`088_l0003o0000o`0005Wooooo0023ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00006?ooool3o`000003ooooool0003ooooo00Kooooo00?o
0000o`0?:Ol03bT00ol03bT00ol0003o00PRo`088P02o`0000?o00PR0_l0001Iooooo`00O?ooool5
o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Fooooo`;o00002ooo
ool00ol0003o00lYo`0?:@04o`0?:@03o`000?l022;o000000;o00PR00Co0000o`088_l022;o00PR
0_l0001Hooooo`00Poooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo01;ooooo
0ol0000;ooooo`;o00001ol03bT2o`0000?o00PR00Co0000o`088_l022;o00PR0_l0001Hooooo`00
Poooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000004?ooool3o`00
00gooooo00?o0000o`0H<?l000001_l03bT00ol0003o00lYo`000003o`088P05o`000?l022;o00PR
o`000?l022800_l0001Gooooo`00Poooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000003_ooool2o`0000?ooooo00?o0000ooooooooool02?ooool2o`0000?o01P`00Co
0000o`0?:Ol03bWo00lY0_l00003o`0?:@03o`000?l022;o00PR00?o00000ol02282o`0005Kooooo
0024ooooo`;o00002Oooool3o`0000cooooo0ol0000?ooooo`03o`000?l0633o01P`00Co01P`00?o
0000o`0?:Ol000001_l03bT00ol0003o00PRo`000006o`088P;o0000EOooool009cooooo0_l0000@
ooooo`;o00001ol06302o`0000Oo00lY0ol00006o`088P;o0000EOooool009Wooooo0ol000000ooo
oooo0000ooooo`0>ooooo`03o`000?l08SOo000000Ko01P`00?o0000o`0H<?l000001_l03bT01?l0
003o00lYo`000?l00005o`088P03o`000?l022;o000005Gooooo002Gooooo`;o00004_ooool2o`00
00?o028g00Co0000o`0H<?l0633o01P`0_l00003o`0H<004o`000?l03bWo00lYo`0?:@;o00000ol0
3bT01?l0003o00PRo`088_l02282o`0000?o00PR00?o0000ooooooooool0D_ooool009Cooooo0ol0
000Cooooo`03o`000?l08SOo028g00Co028g00?o0000o`0H<?l000001_l063000ol0003o00lYo`00
0005o`0?:@;o000000?o00PRo`000?l022801Ol022800ol0003oooooooooo`1Aooooo`00TOooool3
o`0001Cooooo0_l00007o`0R=`;o00001ol06302o`0000Ko00lY0ol00007o`088P;o0000D_ooool0
08oooooo0_l00003ooooo`03o`000?oooooooooo013ooooo00?o0000o`0^?_l000001_l08SL00ol0
003o028go`000006o`0H<003o`000?l0633o000000Ko00lY00?o0000o`0?:Ol000001_l022800ol0
003o00PRo`00001Booooo`00S?ooool3o`0001Oooooo00Go0000o`0^?_l0;Sko02hno`000003o`0R
=`;o00000ol08SL01?l0003o01P`o`0H<?l06302o`0000?o01P`00Co0000o`0?:Ol03bWo00lY0ol0
0002o`0?:@04o`000?l022;o00PRo`088P;o00000ol022800ol0003oooooooooo`1?ooooo`00R_oo
ool2o`0001Wooooo00?o0000o`0^?_l0;Sh00ol0;Sh00ol0003o028go`000006o`0R=`03o`000?l0
633o000000Ko01P`00?o0000o`0?:Ol000000_l03bT01ol0003o00lYo`0?:Ol03bWo0000o`088_l0
00001Ol022800ol0003oooooooooo`1?ooooo`00Qoooool3o`000003ooooool0003ooooo01Kooooo
0_l00006o`0^?P;o00001ol08SL2o`0000Oo01P`0_l00003o`0?:@04o`000?l03bWo00lYo`0?:@;o
00001_l02282o`00053ooooo0025ooooo`;o00006oooool00ol0003o03]6o`000005o`0^?P03o`00
0?l0;Sko000000Ko028g00?o0000o`0R=ol000001_l063000ol0003o01P`o`000003o`0?:@06o`00
0?l03bWo00lYo`000?l03bWo00001Ol022801?l0003o00PRo`000?l0001?ooooo`00F?ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0001cooooo0ol0000Kooooo`;o00000ol0>dH01Ol0
003o02hno`0^?_l0;Sko000000?o02hn00Co0000o`0R=ol08SOo028g0_l00003o`0R=`04o`000?l0
633o01P`o`0H<0;o00000ol063000ol0003o00lYo`0?:@03o`0000?o00lY00?o0000o`088_l02280
0_l00003o`088P03o`000?oooooooooo04gooooo001Gooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Hooooo`Go00006oooool00ol0003o03]6o`0kAP04o`0kAP03
o`000?l0;Sko000000Go02hn00?o0000o`0R=ol000001_l08SL00ol0003o01P`o`000006o`0H<004
o`000?l03bWo0000o`0000Co00lY00?o0000o`088_l000001_l022800ol0003oooooooooo`1<oooo
o`00D?ooool5o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Doooo
o`;o00007_ooool2o`0000Oo03]60_l00006o`0^?P;o00001ol08SL2o`0000Oo01P`0_l000000ol0
3bWo0000o`0?:@03o`0?:@;o00001ol02282o`0000kooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol0000aooooo`00Eoooool01?l0003oooooooooool00009ooooo`;o00005?ooool3o`00
01oooooo00?o0000o`1;COl000001_l0>dH00ol0003o03]6o`000005o`0^?P03o`000?l0;Sko0000
00Ko028g00?o0000o`0R=ol000001_l063001Ol0003o01P`o`000?l03bWo000000?o00lY00?o0000
o`0?:Ol000001ol02282o`0000gooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`0`ooooo`00Eoooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00oooooo0_l0
000Pooooo`;o00000ol0Bdd01?l0003o03]6o`0kA_l0>dH2o`0000?o03]600Go0000o`0^?_l0;Sko
02hno`000003o`0^?P04o`000?l08SOo028go`0R=`;o00000ol08SL01?l0003o01P`o`0H<?l06302
o`0000?o01P`0_l00002o`0?:@05o`000?l03bWo00lYo`0?:Ol000001?l02282o`000003o`088_l0
003o000000Gooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
<?ooool005Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000ko
oooo0ol00002ooooo`03o`000?oooooooooo01cooooo00?o0000o`1;COl0Bdd01?l0Bdd00ol0003o
03]6o`000006o`0kAP03o`000?l0;Sko000000Go02hn00?o0000o`0R=ol000001_l08SL00ol0003o
01P`o`000006o`0H<003o`000?l03bWo000000Go00lY00Co0000o`088_l0003o00001?l02282o`00
00_ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0`ooooo`00F?ooool2o`00
00Wooooo0ol0000=ooooo`;o00008_ooool2o`0000Oo04]=0_l00007o`0kAP;o00001_l0;Sh2o`00
00Oo028g0_l00007o`0H<0;o00001_l03bT2o`0000Ko00PR0_l0000;ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool0<?ooool0073ooooo0ol0000Sooooo`03o`000?l0E4co0000
00Ko04]=00?o0000o`1;COl000001_l0>dH00ol0003o03]6o`000005o`0^?P03o`000?l0;Sko0000
00Ko028g00?o0000o`0R=ol000001_l06303o`0000Go00lY00?o0000o`0?:Ol000001_l02283o`00
00[ooooo00Co0000oooooooooooo00002?ooool2o`0003;ooooo001]ooooo`?o00000_ooool00ol0
003oooooooooo`0Oooooo`;o00000ol0E4`01?l0003o04]=o`1;COl0Bdd2o`0000?o04]=00Co0000
o`0kA_l0>dKo03]60_l00003o`0kAP05o`000?l0;Sko02hno`0^?_l000000ol0;Sh01?l0003o028g
o`0R=ol08SL2o`0000?o028g00Co0000o`0H<?l0633o01P`0_l000001?l0633o0000o`0H<?l00002
o`0?:@;o00000ol03bT01?l0003o00PRo`088_l02282o`0000;o00PR0_l0000:ooooo`;o00002_oo
ool00ol0003oooooooooo`0`ooooo`00Joooool2o`0002Kooooo00?o0000o`1DC?l0E4`01?l0E4`0
0ol0003o04]=o`000006o`1;C@03o`000?l0>dKo000000Ko03]600?o0000o`0^?_l000001Ol0;Sh0
0ol0003o028go`000006o`0R=`03o`000?l0633o000000?o01P`00Go0000o`0H<?l0003o00lYo`00
0006o`0?:@03o`000?l022;o000000Go00PR00?o0000ooooooooool0Aoooool006Sooooo0ol0000V
ooooo`;o00001ol0E4`2o`0000Oo04]=0_l00007o`0kAP;o00001_l0;Sh2o`0000Oo028g0_l00004
o`0H<004o`000?l0633o0000o`0000Oo00lY0_l00006o`088P;o0000B?ooool006Kooooo1?l0000V
ooooo`03o`000?l0FdOo000000Ko05A<00?o0000o`1DC?l000001_l0Bdd00ol0003o04]=o`000006
o`0kAP03o`000?l0>dKo000000Go02hn00?o0000o`0^?_l000001_l08SL00ol0003o028go`000004
o`0H<0;o000000?o01P`o`000?l03bT01Ol03bT00ol0003o00lYo`000005o`088P04o`000?l022;o
0000o`0004Oooooo001Sooooo`?o00001?ooool00ol0003oooooooooo`0Qooooo`;o00000ol0FdL0
1?l0003o05A<o`1DC?l0E4`2o`0000?o05A<00Co0000o`1;COl0Bdgo04]=0_l00003o`1;C@04o`00
0?l0>dKo03]6o`0kAP;o00000ol0>dH01Ol0003o02hno`0^?_l0;Sko000000?o02hn00Co0000o`0R
=ol08SOo028g0_l00003o`0R=`05o`000?l0633o01P`o`0H<?l000000ol063001?l0003o00lYo`0?
:Ol03bT2o`0000?o00lY00?o0000o`088_l022800_l00003o`088P03o`000?oooooooooo04Gooooo
001Qooooo`;o0000:_ooool00ol0003o05]7o`1KA`04o`1KA`03o`000?l0E4co000000Ko05A<00?o
0000o`1;COl000001_l0Bdd00ol0003o03]6o`000006o`0kAP03o`000?l0;Sko000000Go02hn00?o
0000o`0R=ol000001_l08SL01?l0003o01P`o`000?l00004o`0H<003o`000?l03bWo000000Go00lY
00?o0000o`088_l000001_l022800ol0003oooooooooo`14ooooo`00G_ooool3o`0002[ooooo0_l0
0007o`1KA`;o00001ol0E4`2o`0000Oo04]=0_l00007o`0kAP;o00001_l0;Sh2o`0000Oo028g0_l0
00000ol0633o0000o`0H<003o`0H<0;o00001_l03bT2o`0000Oo00PR0_l00015ooooo`00G?ooool2
o`0000?ooooo00?o0000ooooooooool09_ooool00ol0003o0691o`000006o`1KA`03o`000?l0FdOo
000000Ko05A<00?o0000o`1DC?l000001_l0Bdd00ol0003o04]=o`000006o`0kAP03o`000?l0>dKo
000000Go02hn00?o0000o`0^?_l000001_l08SL01Ol0003o028go`000?l0633o000000?o01P`00?o
0000o`0H<?l000001Ol03bT00ol0003o00lYo`000006o`088P03o`000?l022;o000004Gooooo000^
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00007?ooool3o`0002cooooo0_l00003
o`1R@@04o`000?l0FdOo05]7o`1KA`;o00000ol0FdL01?l0003o05A<o`1DC?l0E4`2o`0000?o05A<
00Co0000o`1;COl0Bdgo04]=0_l00003o`1;C@04o`000?l0>dKo03]6o`0kAP;o00000ol0>dH00ol0
003o02hno`0^?P02o`0000?o02hn00Co0000o`0R=ol08SOo028g0_l00003o`0R=`03o`000?l0633o
000000;o00000ol063001Ol0003o00lYo`0?:Ol03bWo000000?o00lY00Co0000o`088_l022;o00PR
0_l00003o`088P03o`000?oooooooooo04;ooooo000]ooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool06?ooool3o`0002kooooo00?o0000o`1R@Ol0HT401?l0HT400ol0003o05]7
o`000006o`1KA`03o`000?l0E4co000000Ko05A<00?o0000o`1;COl000001_l0Bdd00ol0003o03]6
o`000005o`0kAP03o`000?l0;Sko000000Ko02hn00?o0000o`0R=ol000001Ol08SL00ol0003o01P`
o`000006o`0H<003o`000?l03bWo000000Go00lY00?o0000o`088_l000001Ol02282o`0004?ooooo
000Vooooo`Go00000_ooool01?l0003oooooooooool00007ooooo`Go00005oooool2o`0000?ooooo
00?o0000ooooooooool0:Oooool2o`0000Oo06910_l00007o`1KA`;o00001ol0E4`2o`0000Oo04]=
0_l00006o`0kAP;o00001ol0;Sh2o`0000Ko028g0ol00006o`0H<0;o00001_l03bT2o`0000Ko00PR
0_l00013ooooo`00;Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0001Go
oooo0ol0000`ooooo`04o`000?l0JCWo06Tio`0000Go069100?o0000o`1R@Ol000001_l0FdL00ol0
003o05]7o`000006o`1DC003o`000?l0E4co000000Ko04]=00?o0000o`1;COl000001Ol0>dH00ol0
003o03]6o`000006o`0^?P03o`000?l0;Sko000000Go028g00Co0000o`0R=ol0003o00001Ol06300
0ol0003o01P`o`000005o`0?:@03o`000?l03bWo000000Go00PR00Co0000o`088_l0003o0000@_oo
ool002gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000Cooooo`;o0000<Ooo
ool2o`0000Co06Ti00Go0000o`1R@Ol0HT7o0691o`000003o`1R@@04o`000?l0FdOo05]7o`1KA`;o
00000ol0FdL01?l0003o05A<o`1DC?l0E4`2o`0000?o05A<00Co0000o`1;COl0Bdgo04]=0_l00003
o`1;C@05o`000?l0>dKo03]6o`0kA_l000000ol0>dH01?l0003o02hno`0^?_l0;Sh2o`0000?o02hn
00Go0000o`0R=ol08SOo028go`000003o`0R=`04o`000?l0633o01P`o`0H<0;o00000ol063000ol0
003o00lYo`0?:@02o`0000?o00lY00?o0000o`088_l022800_l00003o`088P;o0000@Oooool002go
oooo00Co0000oooooooooooo00002Oooool2o`00013ooooo0ol00002ooooo`03o`000?oooooooooo
02gooooo00?o0000o`1Y>Ol0JCT01Ol0JCT00ol0003o0691o`000005o`1R@@03o`000?l0FdOo0000
00Ko05]700?o0000o`1DC?l000001_l0E4`00ol0003o04]=o`000006o`1;C@03o`000?l0>dKo0000
00Go03]600?o0000o`0^?_l000001_l0;Sh00ol0003o028go`000004o`0R=`;o000000?o01P`o`00
0?l063001?l063000ol0003o00lYo`000005o`0?:@03o`000?l022;o000000Ko00PR00?o0000oooo
ooooool0?oooool002kooooo0_l0000;ooooo`03o`000?oooooooooo00cooooo0_l0000cooooo`;o
00002?l0JCT2o`0000Ko06910_l00007o`1KA`;o00001ol0E4`2o`0000Oo04]=0_l00006o`0kAP;o
00001ol0;Sh2o`0000Go028g0ol00006o`0H<0;o00001_l03bT2o`0000Oo00PR0_l00010ooooo`00
Aoooool3o`0003Cooooo00Co0000o`1`<?l0L33o00001_l0JCT00ol0003o06Tio`000005o`1R@@04
o`000?l0HT7o0691o`0000Go05]700?o0000o`1KAol000001_l0E4`00ol0003o05A<o`000006o`1;
C@03o`000?l0Bdgo000000Go03]600?o0000o`0kA_l000001_l0;Sh00ol0003o02hno`000005o`0R
=`03o`000?l08SOo000000Go01P`00?o0000o`0H<?l000001Ol03bT00ol0003o00lYo`000006o`08
8P03o`000?l022;o0000043ooooo0014ooooo`?o00000_ooool00ol0003oooooooooo`0aooooo`03
o`000?l0L33o070`00;o070`00Co0000o`1Y>Ol0JCWo06Ti0_l00003o`1Y>@05o`000?l0HT7o0691
o`1R@Ol000001?l0HT401Ol0003o05]7o`1KAol0FdOo000000?o05]700Co0000o`1DC?l0E4co05A<
0_l00003o`1DC004o`000?l0Bdgo04]=o`1;C@;o00000ol0Bdd01Ol0003o03]6o`0kA_l0>dKo0000
00?o03]600Co0000o`0^?_l0;Sko02hn0_l00003o`0^?P03o`000?l08SOo028g00?o00000_l08SL0
1Ol0003o01P`o`0H<?l0633o000000?o01P`00Go0000o`0?:Ol03bWo00lYo`000003o`0?:@04o`00
0?l022;o00PRo`088P;o00000ol022800ol0003oooooooooo`0mooooo`00@_ooool2o`0003Sooooo
00?o0000o`1`<?l0L3001?l0L3000ol0003o06Tio`000006o`1Y>@03o`000?l0HT7o000000Ko0691
00?o0000o`1KAol000001Ol0FdL00ol0003o05A<o`000006o`1DC003o`000?l0Bdgo000000Ko04]=
00?o0000o`0kA_l000001Ol0>dH00ol0003o02hno`000005o`0^?P03o`000?l08SOo000000;o028g
00Oo0000o`0R=ol08SOo028go`000?l0633o000000Go01P`00?o0000o`0?:Ol000001Ol03bT00ol0
003o00PRo`000005o`088P;o0000?_ooool003oooooo0ol0000hooooo`;o00001ol0L302o`0000Oo
06Ti0_l00007o`1R@@;o00001_l0FdL2o`0000Oo05A<0_l00007o`1;C@;o00001_l0>dH2o`0000Ko
02hn0_l00003o`0R=`04o`000?l08SOo028go`0R=`;o00001_l06302o`0000Ko00lY0_l00006o`08
8P?o0000?Oooool003gooooo0_l000000ooooooo0000ooooo`0gooooo`03o`000?l0MbGo000000Ko
070`00?o0000o`1`<?l000001_l0JCT00ol0003o06Tio`000006o`1R@@03o`000?l0HT7o000000Go
05]700?o0000o`1KAol000001_l0E4`00ol0003o05A<o`000006o`1;C@03o`000?l0Bdgo000000Go
03]600?o0000o`0kA_l000001Ol0;Sh00ol0003o02hno`000003o`0R=`06o`000?l08SOo028go`00
0?l08SOo00001Ol063000ol0003o01P`o`000004o`0?:@;o000000?o00lYo`000?l022800ol02282
o`000003o`088_l0003o000003gooooo000jooooo`?o00001?ooool00ol0003oooooooooo`0coooo
o`;o00000ol0MbD01?l0003o070`o`1`<?l0L302o`0000?o070`00Co0000o`1Y>Ol0JCWo06Ti0_l0
0003o`1Y>@04o`000?l0HT7o0691o`1R@@;o00000ol0HT401Ol0003o05]7o`1KAol0FdOo000000?o
05]700Co0000o`1DC?l0E4co05A<0_l00003o`1DC004o`000?l0Bdgo04]=o`1;C@;o00000ol0Bdd0
0ol0003o03]6o`0kAP02o`0000?o03]600Go0000o`0^?_l0;Sko02hno`000003o`0^?P03o`000?l0
8SOo028g00?o00000ol08SL00ol0003o01P`o`0H<002o`0000?o01P`00Co0000o`0?:Ol0003o0000
1?l03bT01?l0003o00PRo`000?l00004o`088P;o0000??ooool003Sooooo0_l0000looooo`03o`00
0?l0MbGo07LU00Co07LU00?o0000o`1`<?l000001_l0L3000ol0003o06Tio`000006o`1Y>@03o`00
0?l0HT7o000000Ko069100?o0000o`1KAol000001Ol0FdL00ol0003o05A<o`000006o`1DC003o`00
0?l0Bdgo000000Go04]=00?o0000o`0kA_l000001_l0>dH00ol0003o02hno`000005o`0^?P03o`00
0?l08SOo000000Go028g00?o0000o`0H<?l000001Ol06302o`0000Ko00lY0_l00006o`088P;o0000
??ooool003Gooooo1Ol0000jooooo`;o00001ol0MbD2o`0000Oo070`0_l00007o`1Y>@;o00001ol0
HT42o`0000Ko05]70_l00007o`1DC0;o00001_l0Bdd2o`0000Oo03]60_l00006o`0^?P?o00001Ol0
8SL2o`0000Go01P`00?o0000o`0H<?l000001Ol03bT00ol0003o00lYo`000005o`088P04o`000?l0
22;o0000o`0003_ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00007?oo
ool3o`0003kooooo00?o0000o`1n6?l000001_l0MbD00ol0003o07LUo`000006o`1`<003o`000?l0
L33o000000Ko06Ti00?o0000o`1Y>Ol000001_l0HT400ol0003o0691o`000005o`1KA`03o`000?l0
FdOo000000Ko05A<00?o0000o`1DC?l000001Ol0Bdd01?l0003o04]=o`1;COl00004o`0kAP;o0000
0_l0>dH01?l0003o02hno`0^?_l0;Sh2o`0000;o02hn00Co0000o`0R=ol08SOo028g0_l00002o`0R
=`05o`000?l0633o01P`o`0H<?l000000ol063001Ol0003o00lYo`0?:Ol03bWo000000?o00lY00Go
0000o`088_l022;o00PRo`000003o`088P?o0000>Oooool000Oooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000001Wooooo0_l0000oooooo`;o00000ol0OQP01?l0003o
07LUo`1g9Ol0MbD2o`0000?o07LU00Co0000o`1`<?l0L33o070`0_l00003o`1`<004o`000?l0JCWo
06Tio`1Y>@;o00000ol0JCT01?l0003o0691o`1R@Ol0HT42o`0000?o069100Go0000o`1KAol0FdOo
05]7o`000003o`1KA`04o`000?l0E4co05A<o`1DC0;o00000ol0E4`01Ol0003o04]=o`1;COl0Bdgo
000000Co04]=00Co0000o`0kA_l0003o00001Ol0>dH00ol0003o02hno`000005o`0^?P03o`000?l0
8SOo000000Go028g00?o0000o`0H<?l000001Ol063000ol0003o00lYo`000005o`0?:@03o`000?l0
22;o000000Go00PR00?o0000ooooooooool01_ooool2o`00033ooooo0005o`0000;ooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`0Dooooo`?o000000?oooooo`000?ooool0?Ooo
ool00ol0003o07hHo`1n6004o`1n6003o`000?l0MbGo000000Ko07LU00?o0000o`1`<?l000001_l0
L3000ol0003o06Tio`000006o`1Y>@03o`000?l0HT7o000000Ko069100?o0000o`1KAol000001Ol0
FdL00ol0003o05A<o`000006o`1DC003o`000?l0Bdgo000000Go04]=0_l00007o`0kAP;o00001_l0
;Sh2o`0000Ko028g0_l00006o`0H<0;o00001_l03bT2o`0000Ko00PR0_l00006ooooo`04o`000?oo
ooooooooo`0002oooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
4_ooool2o`00047ooooo0_l00007o`1n60;o00001ol0MbD2o`0000Oo070`0_l00007o`1Y>@;o0000
1ol0HT42o`0000Ko05]70_l00007o`1DC0;o00001Ol0Bdd00ol0003o04]=o`000006o`0kAP03o`00
0?l0>dKo000000Go02hn0ol00005o`0R=`03o`000?l08SOo000000Go01P`00?o0000o`0H<?l00000
1Ol03bT00ol0003o00lYo`000005o`088P04o`000?l022;o0000o`0000Gooooo00Co0000oooooooo
oooo0000;oooool000Oooooo00Co0000oooooooooooo00001oooool4o`0001;ooooo0ol00012oooo
o`04o`000?l0Q@Wo08D9o`0000Go07hH00Co0000o`1n6?l0OQSo00001Ol0MbD01?l0003o07LUo`1g
9Ol00005o`1`<003o`000?l0L33o000000Ko06Ti00?o0000o`1Y>Ol000001_l0HT400ol0003o0691
o`000005o`1KA`04o`000?l0FdOo05]7o`0000Co05A<0_l00002o`1DC005o`000?l0Bdgo04]=o`1;
COl000000ol0Bdd01?l0003o03]6o`0kA_l0>dH2o`0000?o03]600?o0000o`0^?_l0;Sh00_l00000
1?l0;Sko0000o`0^?_l00002o`0R=`;o00000ol08SL00ol0003o01P`o`0H<002o`0000?o01P`00?o
0000o`0?:Ol03bT00_l00003o`0?:@03o`000?l022;o00PR00;o00000ol022800ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0002oooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool04Oooool2o`000003ooooool0003o0000047ooooo00?o0000o`252Ol0Q@T0
0_l0Q@T01Ol0003o07hHo`1n6?l0OQSo000000Co07hH00Go0000o`1g9Ol0MbGo07LUo`000004o`1g
9@05o`000?l0L33o070`o`1`<?l000000ol0L3001?l0003o06Tio`1Y>Ol0JCT2o`0000?o06Ti00Co
0000o`1R@Ol0HT7o06910_l00003o`1R@@05o`000?l0FdOo05]7o`1KAol000001?l0FdL01?l0003o
05A<o`000?l00005o`1DC003o`000?l0Bdgo000000Go04]=00?o0000o`0kA_l000001Ol0>dH00ol0
003o02hno`000003o`0^?P05o`000?l0;Sko0000o`0R=ol000001Ol08SL00ol0003o01P`o`000005
o`0H<003o`000?l03bWo000000Go00lY00?o0000o`088_l000001Ol02282o`0000Cooooo00Co0000
oooooooooooo0000;oooool000Sooooo0_l00008ooooo`Go00003?ooool3o`0004Gooooo00?o0000
o`252Ol0Q@T01?l0Q@T00ol0003o07hHo`000006o`1n6003o`000?l0MbGo000000Ko07LU00?o0000
o`1`<?l000001Ol0L3000ol0003o06Tio`000006o`1Y>@03o`000?l0HT7o000000Ko069100?o0000
o`1KAol000001Ol0FdL2o`0000Oo05A<0_l00006o`1;C@;o00001_l0>dH2o`0000Co02hn00Co0000
o`0^?_l0003o00001_l08SL2o`0000Ko01P`0_l00006o`0?:@;o00001Ol022801?l0003o00PRo`00
0?l00003ooooo`04o`000?ooooooooooo`0002oooooo000Pooooo`?o0000A_ooool2o`0000Oo08D9
0_l00007o`1n60;o00001ol0MbD2o`0000Ko070`0_l00007o`1Y>@;o00001ol0HT42o`0000Go05]7
00?o0000o`1KAol000001_l0E4`00ol0003o05A<o`000005o`1;C@03o`000?l0Bdgo000000Go03]6
00?o0000o`0kA_l000001?l0;Sh2o`000003o`0^?_l0003o028g00Co028g00Co0000o`0R=ol08SOo
00000ol06302o`0000;o01P`00Co0000o`0?:Ol03bWo00lY0_l00002o`0?:@05o`000?l022;o00PR
o`088_l000000ol022800ol0003oooooooooo`02ooooo`;o0000<?ooool001kooooo0_l00002oooo
o`03o`000?oooooooooo04?ooooo00?o0000o`N<0?l000001_l0Q@T00ol0003o08D9o`000006o`1n
6003o`000?l0OQSo000000Ko07LU00?o0000o`1g9Ol000001Ol0L3001?l0003o070`o`1`<?l00005
o`1Y>@04o`000?l0JCWo06Tio`0000Co06910_l00002o`1R@@05o`000?l0FdOo05]7o`1KAol00000
0ol0FdL01?l0003o05A<o`1DC?l0E4`2o`0000?o05A<00?o0000o`1;COl0Bdd00_l00003o`1;C@05
o`000?l0>dKo03]6o`0kA_l000000ol0>dH00ol0003o02hno`0^?P02o`0000?o02hn00Go0000o`0R
=ol08SOo028go`000004o`0R=`03o`000?l0633o000000Go01P`00?o0000o`0?:Ol000001Ol03bT0
0ol0003o00PRo`000004o`088P;o0000=Oooool001_ooooo0ol00018ooooo`;o00000ol7S0001?l0
003o08D9o`252Ol0Q@T2o`0000?o08D900Co0000o`1n6?l0OQSo07hH0_l00003o`1n6004o`000?l0
MbGo07LUo`1g9@;o00000ol0MbD01Ol0003o070`o`1`<?l0L33o000000Co070`00Go0000o`1Y>Ol0
JCWo06Tio`000004o`1Y>@04o`000?l0HT7o0000o`0000Go069100?o0000o`1KAol000001Ol0FdL0
0ol0003o05A<o`000005o`1DC003o`000?l0Bdgo000000Ko04]=00?o0000o`0kA_l000001?l0>dH5
o`0000Co02hn00?o0000o`0R=ol000001Ol08SL2o`0000Ko01P`0_l00006o`0?:@;o00001Ol02283
o`0003Cooooo000Jooooo`;o0000BOooool00ol0003o1h`0o`N<0004o`N<0003o`000?l0Q@Wo0000
00Ko08D900?o0000o`1n6?l000001_l0OQP00ol0003o07LUo`000006o`1g9@03o`000?l0L33o0000
00Ko070`00?o0000o`1Y>Ol000001Ol0JCT2o`0000Oo06910_l00006o`1KA`;o00001_l0E4`2o`00
00Oo04]=0_l00002o`0kAP?o000000?o03]6o`000?l000000_l0;Sh01?l0003o02hno`0^?_l0;Sh2
o`0000Go028g00?o0000o`0R=ol000001Ol063000ol0003o01P`o`000005o`0?:@03o`000?l03bWo
000000Co00PR00Co0000o`088_l022;o0000=?ooool001[ooooo00?o0000ooooool00000A_ooool2
o`0000Oo1h`00_l00007o`252@;o00001ol0OQP2o`0000Oo07LU0_l00007o`1`<0;o00001Ol0JCT0
0ol0003o06Tio`000006o`1R@@03o`000?l0HT7o000000Go05]700?o0000o`1KAol000001Ol0E4`0
0ol0003o05A<o`000006o`1;C@03o`000?l0Bdgo000000;o00000_l0>dH2o`000003o`0kA_l0003o
02hn00;o02hn0ol00002o`0^?P05o`000?l08SOo028go`0R=ol000000ol08SL00ol0003o01P`o`0H
<002o`0000?o01P`00?o0000o`0?:Ol03bT00_l00003o`0?:@04o`000?l022;o00PRo`0000Co00PR
0_l0000booooo`006_ooool2o`000003ooooool0003ooooo04?ooooo00?o0000oaVC0?l000001_l7
S0000ol0003o1h`0o`000006o`252@03o`000?l0Q@Wo000000Ko07hH00?o0000o`1n6?l000001_l0
MbD01?l0003o07LUo`1g9Ol00004o`1`<0;o00000_l0L3001Ol0003o06Tio`1Y>Ol0JCWo000000?o
06Ti00Co0000o`1R@Ol0HT7o06910_l00003o`1R@@05o`000?l0FdOo05]7o`1KAol000000ol0FdL0
1Ol0003o05A<o`1DC?l0E4co000000?o05A<00Co0000o`1;COl0Bdgo04]=1?l000000ol0Bdgo0000
o`0kAP02o`0000Co03]600?o0000o`0^?_l000000_l00004o`0^?P03o`000?l08SOo000000Co028g
00?o0000o`0H<?l000001Ol063000ol0003o00lYo`000005o`0?:@03o`000?l022;o000000Go00PR
0_l0000booooo`006_ooool01Ol0003ooooooooooooooooo0000047ooooo0_l00003oaVC0004o`00
0?l7S03o1h`0o`N<00;o00000ol7S0001?l0003o08D9o`252Ol0Q@T2o`0000?o08D900Co0000o`1n
6?l0OQSo07hH0_l00003o`1n6004o`000?l0MbGo07LUo`1g9@;o00001?l0MbD01?l0003o070`o`00
0?l00005o`1`<003o`000?l0JCWo000000Go06Ti00?o0000o`1R@Ol000001_l0HT400ol0003o05]7
o`000005o`1KA`03o`000?l0E4co000000Go05A<1?l00004o`1;C@;o00001_l0>dH2o`0000;o02hn
00?o0000o`0^?_l0;Sh00_l0;Sh2o`0000Go028g0_l00006o`0H<0;o00001_l03bT2o`0000Go00PR
00?o0000o`088_l00000<_ooool001Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0mooooo`03o`000?lIT`3o6I<000Co6I<000?o0000o`N<0?l000001_l7S0000ol0003o08D9o`00
0006o`252@03o`000?l0OQSo000000Ko07hH00?o0000o`1g9Ol000001_l0MbD2o`0000Oo070`0_l0
0006o`1Y>@;o00001ol0HT42o`0000Ko05]70_l00004o`1DC0Co00001Ol0Bdd00ol0003o04]=o`00
0005o`0kAP03o`000?l0>dKo000000?o02hn00Ko0000o`0^?_l0;Sko0000o`0^?_l00004o`0R=`04
o`000?l08SOo028go`0000?o01P`0_l00002o`0H<004o`000?l03bWo00lYo`0?:@;o000000?o00lY
o`000?l022800_l02282o`0000?o00PR00?o0000ooooooooool0;oooool001Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0jooooo`;o00001olIT`02o`0000Oo1h`00_l00007o`25
2@?o00001_l0OQP2o`0000Ko07LU00?o0000o`1g9Ol000001_l0L3000ol0003o070`o`000005o`1Y
>@03o`000?l0JCWo000000Ko069100?o0000o`1R@Ol000001?l0FdL2o`0000;o05]71_l00002o`1D
C005o`000?l0Bdgo04]=o`1;COl000000ol0Bdd01Ol0003o03]6o`0kA_l0>dKo000000?o03]600Co
0000o`0^?_l0;Sko02hn0_l00003o`0^?P04o`000?l08SOo028go`0000Co028g00?o0000o`0H<?l0
00001Ol063000ol0003o00lYo`000004o`0?:@03o`000?l022;o000000Go00PR00?o0000oooooooo
ool0;oooool001Wooooo0_l00006ooooo`03o`000?oooooooooo03Sooooo00Co0000obbJ0?l/VP3o
00001OlIT`001?l0003o6I<0oaVC0?l00005o`N<0004o`000?l7S03o1h`0o`0000Go08D900Go0000
o`252Ol0Q@Wo08D9o`000003o`1n60;o00000_l0OQP01?l0003o07LUo`1g9Ol0MbD2o`0000?o07LU
00Co0000o`1`<?l0L33o070`0_l00003o`1`<005o`000?l0JCWo06Tio`1Y>Ol000000ol0JCT01?l0
003o0691o`1R@Ol0HT42o`0000?o069100Co0000o`1KAol0003o00000ol0FdL3o`000003o`1DC?l0
003o05A<00Co05A<00?o0000o`1;COl000001Ol0Bdd00ol0003o03]6o`000005o`0kAP04o`000?l0
;Sko0000o`0000Co02hn00?o0000o`0R=ol000001Ol08SL2o`0000Ko01P`0_l00005o`0?:@;o0000
1_l02282o`00033ooooo000Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=Ooo
ool2o`0000Co;9X000Go0000oaVC0?lIT`3o6I<0o`000004oaVC0005o`000?l7S03o1h`0o`N<0?l0
00001?l7S0001Ol0003o08D9o`252Ol0Q@Wo000000Go08D900?o0000o`1n6?l000001Ol0OQP00ol0
003o07LUo`000006o`1g9@03o`000?l0L33o000000Ko070`00?o0000o`1Y>Ol000001Ol0JCT00ol0
003o0691o`000005o`1R@@;o00000_l0FdL3o`0000;o05]70_l00006o`1DC0;o00001_l0Bdd2o`00
00Ko03]60_l00002o`0^?P04o`000?l0;Sko02hno`0^?P;o00001Ol08SL00ol0003o028go`000005
o`0H<003o`000?l0633o000000Co00lY00Co0000o`0?:Ol03bWo00000ol02282o`000003o`088_l0
003o000002oooooo000Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<oooool0
0ol0003o;9X0obbJ0005obbJ0003o`000?lIT`3o000000Ko6I<000?o0000o`N<0?l000001_l7S000
0ol0003o08D9o`000006o`252@;o00001_l0OQP2o`0000Oo07LU0_l00007o`1`<0;o00001_l0JCT2
o`0000Go069100?o0000o`1R@Ol000000_l00004o`1KA`03o`000?l0FdOo000000Go05A<00?o0000
o`1DC?l000001Ol0Bdd01?l0003o04]=o`1;COl00003o`0kAP;o00000_l0>dH00ol0003o02hno`0^
?P03o`000003o`0^?_l0003o028g00;o028g0_l00003o`0R=`03o`000?l0633o01P`00;o00000ol0
63001?l0003o00lYo`0?:Ol00004o`0?:@03o`000?l022;o000000Co00PR00?o0000ooooooooool0
;Oooool001Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0`ooooo`;o00002?l/
VP02o`0000Oo6I<00_l00007o`N<00;o00001_l0Q@T00ol0003o08D9o`000005o`1n6003o`000?l0
OQSo000000Ko07LU00?o0000o`1g9Ol000001_l0L3001?l0003o070`o`1`<?l00003o`1Y>@;o0000
0_l0JCT01?l0003o0691o`1R@Ol0HT43o`000003o`1R@Ol0003o05]700;o05]70_l00003o`1KA`03
o`000?l0E4co05A<00;o00000ol0E4`01Ol0003o04]=o`1;COl0Bdgo000000Co04]=00?o0000o`0k
A_l000001Ol0>dH01?l0003o02hno`000?l00003o`0^?P03o`000?l08SOo000000Go028g00?o0000
o`0H<?l000001Ol063000ol0003o00lYo`000005o`0?:@;o00001Ol02282o`0002kooooo000Hoooo
o`;o00002oooool00ol0003oooooooooo`0^ooooo`04o`000?m2XP3o@Z80o`0000Ko;9X000?o0000
obbJ0?l000001_lIT`001?l0003o6I<0oaVC0?l00004o`N<00;o00000_l7S0001?l0003o08D9o`25
2Ol0Q@T2o`0000?o08D900Go0000o`1n6?l0OQSo07hHo`000003o`1n6004o`000?l0MbGo07LUo`1g
9@;o00000ol0MbD01?l0003o070`o`1`<?l0L302o`0000Co070`00?o0000o`1Y>Ol000001Ol0JCT3
o`0000Go069100?o0000o`1KAol000001Ol0FdL00ol0003o05A<o`000006o`1DC003o`000?l0Bdgo
000000Go04]=0_l00006o`0kAP;o000000?o02hno`000?l0;Sh00_l0;Sh2o`0000Ko028g0_l00006
o`0H<0;o00001Ol03bT00ol0003o00lYo`000004o`088P04o`000?l022;o0000o`0002gooooo000H
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;?ooool00ol0003o@Z80od:R0002
od:R0004o`000?l/VP3o;9X0obbJ00;o00000ol/VP001?l0003o6I<0oaVC0?lIT`02o`0000Co6I<0
00Co0000o`N<0?l0003o00001Ol7S0000ol0003o08D9o`000006o`252@03o`000?l0OQSo000000Go
07hH00?o0000o`1g9Ol000001_l0MbD00ol0003o070`o`000006o`1`<0;o00000ol0JCT5o`0000Ko
06910_l00006o`1KA`;o00001ol0E4`2o`0000Go04]=00?o0000o`1;COl000001Ol0>dH00ol0003o
03]6o`000002o`0^?P03o`000?l0;Sko000000;o02hn00Co0000o`0R=ol08SOo028g0_l00002o`0R
=`04o`000?l0633o01P`o`0H<0;o000000?o01P`o`000?l03bT00_l03bT2o`0000?o00lY00Co0000
o`088_l022;o00000ol022800ol0003oooooooooo`0[ooooo`006?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo02[ooooo00?o0000od:R0?m2XP001?m2XP000ol0003o;9X0o`000006
obbJ0003o`000?lIT`3o000000Ko6I<00_l00007o`N<00;o00001ol0Q@T2o`0000Ko07hH0ol00006
o`1g9@;o00001_l0L3000ol0003o070`o`000003o`0000;o06Ti00?o0000o`1Y>Ol000001Ol0HT40
1?l0003o0691o`1R@Ol00003o`1KA`;o00000_l0FdL00ol0003o05A<o`1DC002o`1DC0;o000000?o
05A<o`000?l0Bdd00_l0Bdd2o`0000?o04]=00?o0000o`0kA_l0>dH00_l00003o`0kAP04o`000?l0
;Sko02hno`0000Co02hn00?o0000o`0R=ol000001Ol08SL00ol0003o01P`o`000004o`0H<003o`00
0?l03bWo000000Go00lY00?o0000o`088_l000001?l02282o`0002cooooo000Hooooo`;o00003_oo
ool00ol0003oooooooooo`0Wooooo`;o00001om2XP03o`0000Ko;9X00ol00005oaVC0003o`000?lI
T`3o000000Ko1h`000?o0000o`N<0?l000001_l0Q@T00ol0003o08D9o`000005o`1n6005o`000?l0
OQSo07hHo`1n6?l000000ol0MbD2o`0000;o07LU00Co0000o`1`<?l0L33o070`1_l00003o`1Y>@05
o`000?l0JCWo06Tio`1Y>Ol000000ol0HT400ol0003o0691o`1R@@02o`1R@@03o`000?l0FdOo0000
00Go05]700Co0000o`1DC?l0003o00001?l0E4`00ol0003o04]=o`000005o`1;C@03o`000?l0>dKo
000000Go03]600Co0000o`0^?_l0003o00001?l0;Sh2o`0000Ko028g0_l00005o`0H<0;o00001_l0
3bT2o`0000Go00PR0ol0000[ooooo`006?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo02Gooooo00?o0000oeVY0?l000001_m2XP001Ol0003o@Z80od:R0?m2XP3o000000?o;9X00_l0
0003obbJ0005o`000?lIT`3o6I<0oaVC0?l000000olIT`001?l0003o1h`0o`N<0?l7S002o`0000?o
1h`000Co0000o`252Ol0Q@Wo08D90_l00003o`252@05o`000?l0OQSo07hHo`1n6?l000001Ol0OQP0
0ol0003o07LUo`000005o`1g9@03o`000?l0L33o000000;o00001?l0L3000ol0003o06Tio`000005
o`1Y>@03o`000?l0HT7o000000Go06910_l00006o`1KA`;o00001_l0E4`2o`0000Ko04]=0_l00006
o`0kAP;o00000_l0;Sh01_l0003o02hno`0^?_l0003o02hno`0000Go028g00?o0000o`0R=ol00000
0ol06302o`0000;o01P`00Co0000o`0?:Ol03bWo00lY0_l000000ol03bWo0000o`088P02o`088P;o
000000?o00PRo`000?l00000:oooool001Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Rooooo`;o00000omIZ@001?l0003o@Z80od:R0?m2XP02o`0000Go@Z8000?o0000obbJ0?l0
00001_l/VP000ol0003o6I<0o`000005oaVC0003o`000?l7S03o000000Ko1h`000?o0000o`252Ol0
00001_l0Q@T00ol0003o07hHo`000006o`1n60;o00001_l0MbD3o`0000Ko070`0_l00006o`1Y>@;o
00001Ol0HT400ol0003o0691o`000005o`1KA`03o`000?l0FdOo000000Go05A<00Co0000o`1DC?l0
E4co00000ol0Bdd2o`0000;o04]=00Co0000o`0kA_l0>dKo03]60_l00002o`0kAP03o`000?l0;Sko
02hn00;o00000ol0;Sh00ol0003o028go`0R=`02o`0000?o028g00?o0000o`0H<?l000001Ol06300
0ol0003o00lYo`000004o`0?:@03o`000?l022;o000000Co00PR0_l0000Zooooo`005oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo023ooooo00?o0000oeVY0?mIZ@001?mIZ@000ol0
003o@Z80o`000007od:R00;o00001ol/VP02o`0000Ko6I<00_l00007o`N<00;o00001ol0Q@T2o`00
00Ko07hH00?o0000o`1n6?l000000ol0MbD3o`000003o`1g9Ol0003o070`00Go070`00?o0000o`1`
<?l000001?l0JCT2o`0000;o06Ti00Go0000o`1R@Ol0HT7o0691o`000003o`1R@@05o`000?l0FdOo
05]7o`1KAol000000ol0FdL01Ol0003o05A<o`1DC?l0E4co000000Co05A<00?o0000o`1;COl00000
1Ol0Bdd00ol0003o03]6o`000005o`0kAP04o`000?l0;Sko0000o`0000?o02hn00?o0000o`0R=ol0
00001Ol08SL2o`0000Ko01P`0_l00005o`0?:@;o00001Ol02283o`0000Sooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol0000Cooooo`005oooool3o`0001;ooooo00?o0000ooooooooool0
7Oooool2o`0000OoFJT00ol00006od:R0003o`000?m2XP3o000000Ko;9X000?o0000obbJ0?l00000
1OlIT`001?l0003o6I<0oaVC0?l00005o`N<0004o`000?l7S03o1h`0o`0000Co08D90_l00002o`25
2@04o`000?l0OQSo07hHo`1n60;o00000ol0OQP3o`000003o`1g9Ol0003o07LU00;o07LU00Co0000
o`1`<?l0L33o070`0_l00003o`1`<004o`000?l0JCWo0000o`0000Go06Ti00?o0000o`1R@Ol00000
1Ol0HT400ol0003o05]7o`000005o`1KA`03o`000?l0E4co000000Go05A<0_l00006o`1;C@;o0000
1_l0>dH2o`000003o`0^?_l0003o02hn00;o02hn0_l00005o`0R=`03o`000?l08SOo000000Go01P`
00?o0000o`0H<?l000001?l03bT00ol0003o00lYo`000003o`088P;o00000_l02282o`0000Kooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Booooo`003oooool3o`0000Gooooo
00?o0000ooooooooool04oooool2o`0001cooooo00Co0000og:`0?mb/03o00001OmIZ@001Ol0003o
FJT0oeVY0?mIZ@3o000000?o@Z800_l00003od:R0004o`000?l/VP3o;9X0obbJ00;o00000ol/VP00
1Ol0003o6I<0oaVC0?lIT`3o000000Co6I<000Go0000o`N<0?l7S03o1h`0o`000004o`N<0004o`00
0?l0Q@Wo0000o`0000Go08D900?o0000o`1n6?l000000_l0OQP3o`000004o`1n6?l0003o07LUo`00
00Go07LU00?o0000o`1`<?l000001Ol0L302o`0000Oo06Ti0_l00006o`1R@@;o00001_l0FdL2o`00
00Go05A<00?o0000o`1DC?l000001Ol0Bdd00ol0003o04]=o`000004o`0kAP;o000000Co03]6o`00
0?l0;Sko02hn0ol00002o`0^?P05o`000?l08SOo028go`0R=ol000000ol08SL00ol0003o01P`o`0H
<002o`0000?o01P`00Co0000o`0?:Ol03bWo00000ol03bT00ol0003o00PRo`000005o`088P03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Booooo`00
3_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?mb/03oL[0000;oL[0000Go0000oeVY0?mIZ@3oFJT0o`000005oeVY
0003o`000?m2XP3o000000Ko@Z8000?o0000obbJ0?l000001_l/VP000ol0003o6I<0o`000006oaVC
0003o`000?l7S03o000000Go1h`00_l00007o`252@Go00001?l0OQP2o`0000Ko07LU0_l00005o`1`
<003o`000?l0L33o000000Ko06Ti00?o0000o`1Y>Ol000001?l0HT42o`0000;o069100Co0000o`1K
Aol0FdOo05]70_l00002o`1KA`05o`000?l0E4co05A<o`1DC?l000000ol0E4`00ol0003o04]=o`1;
C@02o`0000?o04]=00Co0000o`0kA_l0003o00001?l0>dH01?l0003o02hno`000?l00004o`0^?P03
o`000?l08SOo000000Co028g00?o0000o`0H<?l000001Ol063000ol0003o00lYo`000004o`0?:@;o
00001_l02282o`0000Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Boooo
o`004_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool05_ooool00ol0003oL[00og:`0004og:`0003o`000?mIZ@3o000000KoFJT00_l00007od:R00;o
00001ol/VP02o`0000Oo6I<00_l00005o`N<0004o`000?l7S03o1h`0o`0000Go08D90ol00006o`1n
6004o`000?l0OQSo07hHo`0000?o07LU0_l00002o`1g9@05o`000?l0L33o070`o`1`<?l000000ol0
L3001?l0003o06Tio`1Y>Ol0JCT2o`0000?o06Ti00Co0000o`1R@Ol0003o00001Ol0HT400ol0003o
05]7o`000005o`1KA`03o`000?l0E4co000000Co05A<00?o0000o`1;COl000001Ol0Bdd2o`0000Ko
03]60_l00002o`0^?P04o`000?l0;Sko02hno`0^?P;o00001Ol08SL2o`0000Ko01P`0_l00004o`0?
:@03o`000?l03bWo000000Go00PR00?o0000o`088_l000001Oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo01;ooooo000Booooo`03o`000?oooooooooo00;ooooo0_l0000Hoooo
o`03o`000?oooooooooo01?ooooo0_l00007og:`00;o00001_mIZ@000ol0003oFJT0o`000006od:R
0003o`000?m2XP3o000000Ko;9X000Co0000obbJ0?l/VP3o00001?lIT`02o`0000;o6I<000Go0000
o`N<0?l7S03o1h`0o`000004o`N<0003o`000?l0Q@Wo000000;o00000ol0Q@T01?l0003o07hHo`1n
6?l0OQP2o`0000Co07hH00?o0000o`1g9Ol000001Ol0MbD00ol0003o070`o`000005o`1`<003o`00
0?l0JCWo000000Go06Ti0_l00007o`1R@@;o00001_l0FdL2o`0000Go05A<0_l00005o`1;C@03o`00
0?l0Bdgo000000Go03]600?o0000o`0kA_l000000_l0;Sh01_l0003o02hno`0^?_l0003o02hno`00
00?o028g0_l00002o`0R=`04o`000?l0633o01P`o`0H<0;o000000?o01P`o`000?l03bT00_l03bT0
1Ol0003o00lYo`0?:Ol03bWo000000;o00PR0_l00003o`088P03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00002?ooool2o`0001Cooooo000>ooooo`Co00001?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo017ooooo00Co0000ohbg0?n<]`3o00001?mb/002o`0000;oL[00
00Co0000oeVY0?mIZ@3oFJT00_l00003oeVY0004o`000?m2XP3o@Z80od:R00;o00000om2XP001?l0
003o;9X0obbJ0?l/VP02o`0000Co;9X000Co0000oaVC0?l0003o00001OlIT`000ol0003o1h`0o`00
0005o`N<00;o000000?o08D9o`000?l0Q@T01?l0Q@T00ol0003o07hHo`000006o`1n60;o00001_l0
MbD2o`0000Ko070`0_l00005o`1Y>@03o`000?l0JCWo000000Ko069100?o0000o`1R@Ol000001Ol0
FdL00ol0003o05]7o`000003o`1DC0;o00000_l0E4`01Ol0003o04]=o`1;COl0Bdgo000000?o04]=
00Go0000o`0kA_l0>dKo03]6o`000003o`0kAP03o`000?l0;Sko02hn00;o00000ol0;Sh00ol0003o
028go`000005o`0R=`03o`000?l0633o000000Co01P`00?o0000o`0?:Ol000001?l03bT00ol0003o
00PRo`000005o`088P;o00001?ooool2o`0000[ooooo00?o0000ooooooooool04_ooool000kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00kooooo
0_l00004ohbg0004o`000?mb/03o0000o`0000GoL[0000?o0000oeVY0?l000001_mIZ@000ol0003o
@Z80o`000006od:R0003o`000?l/VP3o000000Ko;9X00_l00007oaVC00;o00000ol7S003o`000003
o`N<0?l0003o000000Ko08D90_l00006o`1n6003o`000?l0OQSo000000Go07LU00Co0000o`1g9Ol0
MbGo00000ol0L302o`0000;o070`00Go0000o`1Y>Ol0JCWo06Tio`000003o`1Y>@04o`000?l0HT7o
0691o`1R@@;o00000ol0HT400ol0003o05]7o`1KA`02o`0000?o05]700?o0000o`1DC?l000001Ol0
E4`00ol0003o04]=o`000005o`1;C@03o`000?l0>dKo000000Co03]600Go0000o`0^?_l0003o02hn
o`000003o`0^?P;o00001_l08SL2o`0000Go01P`0_l00005o`0?:@;o00001Ol022800ol0003o00PR
o`00000Uooooo`003_ooool5o`0000?ooooo0_l0000Looooo`03o`000?oooooooooo00cooooo00?o
0000ohbg0?n<]`001?n<]`02o`0000OoL[000_l00007oeVY00?o00001_m2XP03o`0000Go;9X000Co
0000obbJ0?l/VP3o00001OlIT`000ol0003o6I<0oaVC0003o`0000;o1h`00_l00002o`N<0004o`00
0?l0Q@Wo08D9o`252@;o00000_l0Q@T01?l0003o07hHo`1n6?l0OQP2o`0000?o07hH00Go0000o`1g
9Ol0MbGo07LUo`000004o`1g9@03o`000?l0L33o000000Go070`00?o0000o`1Y>Ol000001Ol0JCT0
0ol0003o0691o`000005o`1R@@03o`000?l0FdOo000000Go05]70_l00006o`1DC0;o00001_l0Bdd2
o`0000Go03]60_l00002o`0^?P06o`000?l0;Sko02hno`000?l0;Sko00001?l08SL2o`000003o`0R
=ol0003o01P`00;o01P`0_l000000ol0633o0000o`0?:@02o`0?:@;o000000?o00lYo`000?l02280
0_l02282o`0000?o00PR00?o0000ooooooooool08_ooool001Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`09ooooo`?o00001On<]`001?l0003oS;L0ohbg0?l00005og:`0004o`00
0?mb/03oL[00o`0000GoFJT000Go0000oeVY0?mIZ@3oFJT0o`000003od:R00;o00000om2XP001Ol0
003o;9X0obbJ0?l/VP3o000000Co;9X000Co0000oaVC0?lIT`3o6I<01?l000000olIT`3o0000o`N<
0002o`0000Go1h`000?o0000o`252Ol000001Ol0Q@T00ol0003o07hHo`000006o`1n6003o`000?l0
MbGo000000Go07LU0_l00006o`1`<0;o00001_l0JCT2o`0000Ko06910_l00005o`1KA`03o`000?l0
FdOo000000Go05A<00?o0000o`1DC?l000001?l0Bdd2o`000003o`1;COl0003o03]600;o03]60_l0
0002o`0kAP03o`000?l0;Sko02hn00;o00000ol0;Sh01?l0003o028go`000?l00004o`0R=`03o`00
0?l0633o000000Co01P`00?o0000o`0?:Ol000001?l03bT00ol0003o00PRo`000005o`088P;o0000
8oooool001Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`05o`000?nY
_P3oZKh0ojVn0?l000000on<]`000ol0003oS;L0ohbg0002ohbg0005o`000?mb/03oL[00og:`0?l0
00001?mb/0001Ol0003oFJT0oeVY0?mIZ@3o000000GoFJT000?o0000od:R0?l000001_m2XP000ol0
003o;9X0o`000006obbJ00Co00001?lIT`02o`0000Oo1h`00_l00006o`252@;o00001ol0OQP2o`00
00Go07LU00?o0000o`1g9Ol000001Ol0L3001?l0003o070`o`1`<?l00003o`1Y>@;o00000_l0JCT0
1?l0003o0691o`1R@Ol0HT42o`0000;o069100Go0000o`1KAol0FdOo05]7o`000003o`1KA`05o`00
0?l0E4co05A<o`1DC?l000000ol0E4`01?l0003o04]=o`000?l00004o`1;C@03o`000?l0>dKo0000
00Go03]600Co0000o`0^?_l0003o00000ol0;Sh2o`0000Ko028g0_l00005o`0H<0;o00001Ol03bT2
o`0000Go00PR00?o0000o`088_l000008oooool001Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`05ooooo`03o`000?nY_P3oZKh000?oZKh000?o0000ohbg0?l000001_n<]`000ol0
003oL[00o`000006og:`0003o`000?mIZ@3o000000KoFJT00_l00007od:R00;o00001Ol/VP04o`00
00Go6I<000?o0000oaVC0?l000001_l7S0000ol0003o1h`0o`000005o`252@04o`000?l0Q@Wo08D9
o`0000Co07hH0_l00002o`1n6005o`000?l0MbGo07LUo`1g9Ol000000ol0MbD01Ol0003o070`o`1`
<?l0L33o000000Co070`00?o0000o`1Y>Ol000001Ol0JCT00ol0003o0691o`000005o`1R@@03o`00
0?l0FdOo000000Go05]700?o0000o`1DC?l000001?l0E4`2o`0000Ko04]=0_l00006o`0kAP;o0000
0_l0;Sh01Ol0003o02hno`000?l0;Sko000000Go028g00?o0000o`0R=ol000000ol06302o`000003
o`0H<?l0003o00lY00;o00lY0_l00002o`0?:@05o`000?l022;o00PRo`088_l000000ol022800ol0
003oooooooooo`0Pooooo`005Oooool2o`00027ooooo00?o0000ooooooooool00oooool00ol0003o
ZKh0ojVn0004ojVn00;o00001on<]`02o`0000OoL[000_l00006oeVY0003o`000?mIZ@3o000000Ko
@Z8000?o0000od:R0?l000000_l/VP03o`000005obbJ0?l0003o;9X0obbJ0?l000000olIT`001Ol0
003o6I<0oaVC0?lIT`3o000000?o1h`00_l00003o`N<0005o`000?l0Q@Wo08D9o`252Ol000001?l0
Q@T01?l0003o07hHo`000?l00005o`1n6003o`000?l0MbGo000000Go07LU00?o0000o`1`<?l00000
1Ol0L302o`0000Ko06Ti0_l00006o`1R@@;o00001_l0FdL2o`0000Co05A<00?o0000o`1DC?l00000
1Ol0Bdd01?l0003o04]=o`1;COl00003o`0kAP;o000000Co03]6o`000?l0;Sko02hn0_l00003o`0^
?P05o`000?l08SOo028go`0R=ol000000ol08SL00ol0003o01P`o`000004o`0H<003o`000?l03bWo
000000Go00lY00?o0000o`088_l000001?l02282o`00027ooooo000Eooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool00_l00006ojVn0003o`000?nY_P3o000000KoS;L000Co0000ohbg
0?n<]`3o00001?mb/002o`0000;oL[0000Co0000oeVY0?mIZ@3oFJT00_l00003oeVY0004o`000?m2
XP3o@Z80od:R00;o00000_m2XP03o`0000;o;9X00_l00004obbJ0003o`000?lIT`3o000000Go6I<0
00?o0000o`N<0?l000001_l7S0000ol0003o08D9o`000005o`252@;o00001ol0OQP2o`0000Ko07LU
0_l00005o`1`<003o`000?l0L33o000000Go06Ti00Co0000o`1Y>Ol0JCWo00000ol0HT42o`000003
o`1R@Ol0003o05]700?o05]70_l000000ol0FdOo0000o`1DC002o`1DC005o`000?l0E4co05A<o`1D
C?l000000ol0Bdd00ol0003o04]=o`1;C@02o`1;C@03o`000?l0>dKo000000Co03]600Co0000o`0^
?_l0003o00001?l0;Sh00ol0003o028go`000004o`0R=`;o00001Ol06302o`0000Ko00lY0_l00005
o`088P;o00008Oooool001Gooooo00?o0000ooooooooool08_ooool2o`0000;oaL<000Co0000ojVn
0?nY_P3oZKh00_l00003ojVn0004o`000?n<]`3oS;L0ohbg00;o00001?n<]`001?l0003oL[00o`00
0?l00005og:`0003o`000?mIZ@3o000000KoFJT000?o0000od:R0?l000000_m2XP02o`0000;o@Z80
00?o0000obbJ0?l000001_l/VP02o`0000Ko6I<00_l00007o`N<00;o00001Ol0Q@T00ol0003o08D9
o`000006o`1n6003o`000?l0OQSo000000Co07LU0_l00002o`1g9@05o`000?l0L33o070`o`1`<?l0
00000ol0L3001Ol0003o06Tio`1Y>Ol0JCWo000000Co06Ti00?o0000o`1R@Ol000001?l0HT401?l0
003o05]7o`000?l00004o`1KA`03o`000?l0E4co000000Go05A<00?o0000o`1;COl000001Ol0Bdd2
o`0000Go03]60_l00002o`0^?P04o`000?l0;Sko02hno`0^?P;o00001?l08SL00ol0003o028go`00
0003o`0H<0;o000000?o01P`o`000?l03bT00ol03bT2o`000003o`0?:Ol0003o00PR00;o00PR0_l0
00000ol022;o0000o`00000Pooooo`005Oooool00ol0003oooooooooo`0Pooooo`;o00001Oo5``00
0ol0003oZKh0o`000006ojVn0003o`000?n<]`3o000000KoS;L00_l00007og:`00;o00001omIZ@05
o`0000Co@Z800_l00006obbJ0003o`000?l/VP3o000000Go6I<000Co0000oaVC0?lIT`3o00001?l7
S002o`0000;o1h`000Go0000o`252Ol0Q@Wo08D9o`000003o`252@04o`000?l0OQSo07hHo`1n60;o
00000ol0OQP01?l0003o07LUo`000?l00005o`1g9@03o`000?l0L33o000000Go070`00?o0000o`1Y
>Ol000001Ol0JCT2o`0000Go06910_l00006o`1KA`;o00001_l0E4`2o`0000Go04]=00?o0000o`1;
COl000000ol0>dH2o`000003o`0kA_l0003o02hn00;o02hn0ol000000ol0;Sko0000o`0R=`02o`0R
=`07o`000?l08SOo028go`0R=ol0003o01P`o`000004o`0H<004o`000?l03bWo0000o`0000Co00lY
00?o0000o`088_l000001?l02282o`0001oooooo000Eooooo`;o00007oooool2o`0000OoaL<00_l0
0007ojVn00?o00001On<]`001?l0003oS;L0ohbg0?l00005og:`0004o`000?mb/03oL[00o`0000Go
FJT00ol000000omIZ@3o0000od:R0002od:R00;o00000_m2XP001?l0003o;9X0obbJ0?l/VP02o`00
00?o;9X000Go0000oaVC0?lIT`3o6I<0o`000004oaVC0004o`000?l7S03o0000o`0000Go1h`000?o
0000o`252Ol000001Ol0Q@T00ol0003o07hHo`000005o`1n60;o00001ol0MbD2o`0000Ko070`0_l0
0005o`1Y>@03o`000?l0JCWo000000Co069100Co0000o`1R@Ol0HT7o00000ol0FdL2o`0000;o05]7
00Co0000o`1DC?l0E4co05A<0_l000000ol0E4co0000o`1;C@02o`1;C@;o00000ol0Bdd00ol0003o
03]6o`000004o`0kAP04o`000?l0;Sko0000o`0000Co02hn00?o0000o`0R=ol000001?l08SL2o`00
00Go01P`0_l00006o`0?:@;o00001Ol02282o`0001oooooo000Eooooo`03o`000?oooooooooo01go
oooo00Co0000olbb0?o</P3o00001Oo5``001?l0003oaL<0olG30?l00005ojVn0005o`000?nY_P3o
ZKh0ojVn0?l000000on<]`000ol0003oS;L0ohbg0002ohbg0005o`000?mb/03oL[00og:`0?l00000
1?mb/0000ol0003oFJT0o`000002o`0000GoFJT000?o0000od:R0?l000001Om2XP000ol0003o;9X0
o`000006obbJ0003o`000?lIT`3o000000Go6I<00_l00007o`N<00;o00001_l0Q@T2o`0000Go07hH
00?o0000o`1n6?l000001_l0MbD00ol0003o07LUo`000004o`1`<0;o000000?o070`o`000?l0JCT0
0_l0JCT2o`0000?o06Ti00Co0000o`1R@Ol0HT7o00001?l0HT400ol0003o05]7o`000005o`1KA`03
o`000?l0E4co000000Co05A<00?o0000o`1;COl000001Ol0Bdd2o`0000Go03]60_l00002o`0^?P04
o`000?l0;Sko02hno`0^?P;o00001?l08SL00ol0003o028go`000004o`0H<004o`000?l0633o01P`
o`0000?o00lY0_l000000ol03bWo0000o`088P02o`088P;o000000?o00PRo`000?l000007_ooool0
01Gooooo00?o0000ooooooooool06oooool2o`0000Coc;8000Go0000olG30?o5``3oaL<0o`000004
olG30005o`000?nY_P3oZKh0ojVn0?l000001OnY_P000ol0003oS;L0o`000006ohbg0003o`000?mb
/03o000000CoL[000ol000000omIZ@3o0000oeVY0005oeVY00;o00001_m2XP03o`0000Ko;9X00_l0
0005oaVC0004o`000?lIT`3o6I<0o`0000Go1h`000Co0000o`N<0?l7S03o00000ol0Q@T2o`0000;o
08D900Go0000o`1n6?l0OQSo07hHo`000003o`1n6004o`000?l0MbGo07LUo`1g9@;o00000ol0MbD0
1?l0003o070`o`000?l00004o`1`<003o`000?l0JCWo000000Go06Ti00?o0000o`1R@Ol000001Ol0
HT42o`0000Ko05]70_l00005o`1DC0;o00001Ol0Bdd00ol0003o04]=o`000003o`0kAP;o00000_l0
>dH00ol0003o02hno`0^?P03o`000003o`0^?_l0003o028g00;o028g00Go0000o`0R=ol08SOo028g
o`000002o`0H<003o`000?l0633o01P`00;o01P`00?o0000o`0?:Ol000001?l03bT00ol0003o00PR
o`000004o`088P03o`000?oooooooooo01cooooo000Dooooo`03o`000?oooooooooo01_ooooo00?o
0000olbb0?o</P001Oo</P000ol0003oaL<0o`000006olG30003o`000?nY_P3o000000KoZKh00_l0
0007ohbg00;o00000_mb/003o`0000;oL[000_l00006oeVY0003o`000?mIZ@3o000000Go@Z8000Go
0000od:R0?m2XP3o@Z80o`000003obbJ00;o00000_l/VP001Ol0003o6I<0oaVC0?lIT`3o000000Co
6I<000Go0000o`N<0?l7S03o1h`0o`000004o`N<0003o`000?l0Q@Wo000000Go08D900?o0000o`1n
6?l000001Ol0OQP00ol0003o07LUo`000005o`1g9@;o00001_l0L302o`0000Ko06Ti0_l00005o`1R
@@04o`000?l0HT7o0691o`0000?o05]70_l000000ol0FdOo0000o`1DC002o`1DC0;o00000_l0E4`0
1Ol0003o04]=o`1;COl0Bdgo000000?o04]=00?o0000o`0kA_l000001Ol0>dH00ol0003o02hno`00
0004o`0^?P03o`000?l08SOo000000Co028g00?o0000o`0H<?l000001Ol06302o`0000Go00lY0_l0
0005o`088P;o00007Oooool001Cooooo0ol0000Iooooo`;o00002?o</P02o`0000OoaL<00ol00005
ojVn0004o`000?nY_P3oZKh0o`0000GoS;L000?o0000ohbg0?l000000_l00003og:`00;o00000_mb
/0001?l0003oFJT0oeVY0?mIZ@02o`0000?oFJT000Go0000od:R0?m2XP3o@Z80o`000005od:R0003
o`000?l/VP3o000000Go;9X000?o0000oaVC0?l000001_lIT`000ol0003o1h`0o`000005o`N<00;o
00001_l0Q@T2o`0000Ko07hH0_l00005o`1g9@04o`000?l0MbGo07LUo`0000?o070`0_l00002o`1`
<004o`000?l0JCWo06Tio`1Y>@;o00000_l0JCT01Ol0003o0691o`1R@Ol0HT7o000000Co069100?o
0000o`1KAol000001?l0FdL00ol0003o05A<o`000005o`1DC003o`000?l0Bdgo000000Co04]=0_l0
0006o`0kAP;o000000?o02hno`000?l0;Sh00_l0;Sh2o`0000Go028g0_l00005o`0H<003o`000?l0
633o000000?o00lY0_l000000ol03bWo0000o`088P02o`088P;o000000?o00PRo`000?l000007?oo
ool000Kooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0Hooooo`04o`000?oCWP3o
dih0o`0000Koc;8000Co0000olbb0?o</P3o00001?o5``02o`0000?oaL<000Go0000ojVn0?nY_P3o
ZKh0o`000004ojVn0004o`000?n<]`3oS;L0ohbg00?o00000_n<]`001?l0003oL[00o`000?l00005
og:`0003o`000?mIZ@3o000000KoFJT000?o0000od:R0?l000001_m2XP02o`0000Ko;9X00_l00007
oaVC00;o00001Ol7S0001?l0003o1h`0o`N<0?l00003o`252@;o00000_l0Q@T01?l0003o07hHo`1n
6?l0OQP2o`0000;o07hH00Go0000o`1g9Ol0MbGo07LUo`000004o`1g9@03o`000?l0L33o000000Go
070`00?o0000o`1Y>Ol000001Ol0JCT00ol0003o0691o`000005o`1R@@;o00001Ol0FdL2o`0000Ko
05A<0_l00004o`1;C@03o`000?l0Bdgo000000Go03]600?o0000o`0kA_l000000_l0;Sh3o`000003
o`0^?_l0003o028g00;o028g0_l000000ol08SOo0000o`0H<002o`0H<0;o00000ol063000ol0003o
00lYo`000004o`0?:@03o`000?l022;o000000Co00PR00?o0000ooooooooool06_ooool000Oooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Oo
oooo00?o0000om>N0?oCWP000_oCWP001?l0003oc;80olbb0?o</P02o`0000Coc;8000Co0000olG3
0?l0003o00001_o5``000ol0003oZKh0o`000006ojVn00Co00001?n<]`02o`0000OoL[000ol00006
oeVY00;o00001_m2XP000ol0003o@Z80o`000005obbJ0004o`000?l/VP3o;9X0o`0000Co6I<00_l0
0002oaVC0005o`000?l7S03o1h`0o`N<0?l000001?l7S0000ol0003o08D9o`000005o`252@03o`00
0?l0OQSo000000Go07hH00?o0000o`1g9Ol000001Ol0MbD2o`0000Ko070`0_l00006o`1Y>@;o0000
1Ol0HT400ol0003o0691o`000004o`1KA`04o`000?l0FdOo05]7o`0000?o05A<0_l000000ol0E4co
0000o`1;C@02o`1;C@05o`000?l0Bdgo04]=o`1;COl000000ol0>dH01_l0003o03]6o`0kA_l0>dKo
0000o`0^?P;o00000ol0;Sh00ol0003o028go`000004o`0R=`03o`000?l0633o000000Go01P`0_l0
0005o`0?:@;o00001Ol02282o`0001_ooooo0007ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0Fooooo`03o`000?oCWP3odih000Codih000?o
0000olbb0?l000001_o</P02o`0000SoaL<00_l00005ojVn00Co00001On<]`001?l0003oS;L0ohbg
0?l00005og:`0005o`000?mb/03oL[00og:`0?l000000omIZ@02o`0000;oFJT000Co0000od:R0?m2
XP3o@Z800_l00003od:R0005o`000?l/VP3o;9X0obbJ0?l000001?l/VP001?l0003o6I<0o`000?l0
0005oaVC0003o`000?l7S03o000000Go1h`00_l00006o`252@;o00001_l0OQP2o`0000Go07LU00?o
0000o`1g9Ol000001Ol0L3001?l0003o070`o`1`<?l00003o`1Y>@;o000000?o06Tio`000?l0HT40
0_l0HT42o`0000?o069100Co0000o`1KAol0FdOo00001?l0FdL00ol0003o05A<o`000004o`1DC003
o`000?l0Bdgo000000Go04]=00?o0000o`0kA_l000001?l0>dH2o`000003o`0^?_l0003o02hn00;o
02hn0_l00005o`0R=`;o00001Ol063000ol0003o01P`o`000003o`0?:@;o000000?o00lYo`000?l0
22800_l02282o`000003o`088_l0003o000001[ooooo0007ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001?ooool2o`0001Gooooo0_l00007om>N00?o00001Oo</P001?l0003o
c;80olbb0?l00006olG30005o`000?o5``3oaL<0o`000?nY_P001Ol00002ojVn0005o`000?n<]`3o
S;L0ohbg0?l000001?n<]`001Ol0003oL[00og:`0?mb/03o000000GoL[0000?o0000oeVY0?l00000
1OmIZ@000ol0003o@Z80o`000006od:R0003o`000?l/VP3o000000Go;9X00_l00007oaVC00;o0000
1Ol7S0000ol0003o1h`0o`000005o`252@04o`000?l0Q@Wo08D9o`0000?o07hH0_l00002o`1n6005
o`000?l0MbGo07LUo`1g9Ol000000ol0MbD01Ol0003o070`o`1`<?l0L33o000000Co070`00?o0000
o`1Y>Ol000001?l0JCT00ol0003o0691o`000005o`1R@@03o`000?l0FdOo000000Go05]70_l00005
o`1DC0;o00001_l0Bdd2o`0000Co03]600?o0000o`0kA_l000000_l0;Sh3o`000003o`0^?_l0003o
028g00;o028g0_l00002o`0R=`05o`000?l0633o01P`o`0H<?l000000ol063000ol0003o00lYo`00
0004o`0?:@03o`000?l022;o000000Co00PR00?o0000ooooooooool01oooool2o`0000Cooooo00Co
0000oooooooooooooooo1Ol00002ooooo`001oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool05?ooool01?l0003ofXX0omZ:0?l00005om>N0005
o`000?oCWP3odih0om>N0?l000000oo</P000ol0003oc;80olbb0002olbb0004o`000?o5``3oaL<0
olG300;o00000_o5``03o`000003ojVn0?l0003o000000GoZKh000?o0000ohbg0?l000001_n<]`00
0ol0003oL[00o`000006og:`00;o00001_mIZ@02o`0000Oo@Z800_l00005obbJ0004o`000?l/VP3o
;9X0o`0000Co6I<00_l000000olIT`3o0000o`N<0002o`N<00;o00000ol7S0001Ol0003o08D9o`25
2Ol0Q@Wo000000Co08D900?o0000o`1n6?l000001Ol0OQP00ol0003o07LUo`000005o`1g9@03o`00
0?l0L33o000000Go070`0_l00005o`1Y>@;o00001_l0HT42o`0000Go05]700?o0000o`1KAol00000
0ol0E4`2o`000003o`1DC?l0003o04]=00?o04]=0_l000000ol0Bdgo0000o`0kAP02o`0kAP06o`00
0?l0>dKo03]6o`0kA_l0003o02hn0_l00003o`0^?P03o`000?l08SOo000000Go028g00?o0000o`0H
<?l000001?l06302o`0000Go00lY0_l00005o`088P;o00001oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo0006ooooo`;o00001?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo01;ooooo0_l00004omZ:0005o`000?oCWP3odih0om>N0?l00000
1OoCWP000ol0003oc;80o`000006olbb0004o`000?o5``3o0000olG300?o00000_o5``02o`0000Oo
ZKh00_l00007ohbg00;o00001_mb/0000ol0003oL[00o`000005oeVY0004o`000?mIZ@3oFJT0o`00
00Co@Z800_l00002od:R0005o`000?l/VP3o;9X0obbJ0?l000001?l/VP001?l0003o6I<0o`000?l0
0004oaVC0003o`000?l7S03o000000Ko1h`000?o0000o`252Ol000001Ol0Q@T2o`0000Ko07hH0_l0
0006o`1g9@;o00001Ol0L3000ol0003o070`o`000003o`1Y>@;o00000_l0JCT01?l0003o0691o`1R
@Ol0HT42o`000003o`1R@Ol0003o05]700;o05]70_l00003o`1KA`03o`000?l0E4co000000Co05A<
00Co0000o`1;COl0003o00001?l0Bdd00ol0003o03]6o`000004o`0kAP;o000000?o02hno`000?l0
;Sh00_l0;Sh2o`0000Ko028g0_l00004o`0H<003o`000?l0633o000000?o00lY0_l000000ol03bWo
0000o`088P02o`088P;o000000?o00PRo`000?l000001_ooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00;ooooo0007ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo017ooooo00?o0000omZ:0?oJRP001OoJRP000ol0003odih0o`000006om>N00?o
00001_o</P04o`0000CoaL<000Co0000olG30?o5``3o00001OnY_P001?l0003oZKh0ojVn0?l00004
ohbg00;o00000_n<]`001?l0003oL[00og:`0?mb/002o`0000?oL[0000Go0000oeVY0?mIZ@3oFJT0
o`000004oeVY0004o`000?m2XP3o0000o`0000Go@Z8000?o0000obbJ0?l000001Ol/VP02o`0000Ko
6I<00_l00007o`N<00;o00001Ol0Q@T01?l0003o08D9o`252Ol00003o`1n60;o00000_l0OQP01?l0
003o07LUo`1g9Ol0MbD2o`000003o`1g9Ol0003o070`00;o070`0_l00003o`1`<003o`000?l0JCWo
000000Go06Ti00?o0000o`1R@Ol000001?l0HT400ol0003o05]7o`000005o`1KA`;o00001Ol0E4`2
o`0000Ko04]=0_l00004o`0kAP03o`000?l0>dKo000000;o02hn0ol00002o`0^?P04o`000?l08SOo
028go`0R=`;o000000?o028go`000?l063000_l063001ol0003o01P`o`0H<?l0633o0000o`0?:Ol0
00001?l03bT00ol0003o00PRo`000004o`088P03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00002_ooool00ol0003oooooooooo`01ooooo`004oooool2o`00013ooooo0ol00007omZ:00?o
00001OoCWP001Ol0003odih0om>N0?oCWP3o000000?oc;800ol00002olbb0005o`000?o5``3oaL<0
olG30?l000001?o5``001Ol0003oZKh0ojVn0?nY_P3o000000CoZKh000Co0000ohbg0?l0003o0000
1On<]`000ol0003oL[00o`000006og:`0003o`000?mIZ@3o000000GoFJT00ol00006od:R00;o0000
1Ol/VP000ol0003o;9X0o`000005oaVC0004o`000?lIT`3o6I<0o`0000Co1h`00_l00002o`N<0005
o`000?l0Q@Wo08D9o`252Ol000001?l0Q@T00ol0003o07hHo`000005o`1n6003o`000?l0MbGo0000
00Co07LU00?o0000o`1`<?l000001Ol0L302o`0000Ko06Ti0_l00005o`1R@@;o00001Ol0FdL00ol0
003o05]7o`000003o`1DC0;o00000_l0E4`01?l0003o04]=o`1;COl0Bdd2o`000003o`1;COl0003o
03]600;o03]600Ko0000o`0kA_l0>dKo03]6o`000?l0;Sh2o`0000Co02hn00?o0000o`0R=ol00000
1?l08SL00ol0003o01P`o`000004o`0H<0;o00001Ol03bT2o`0000Go00PR0_l00005ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`004oooool00ol0003o
ooooooooo`0>ooooo`05o`000?oQL`3ohG<0on5c0?l000001?oJRP02o`0000?ofXX000Go0000om>N
0?oCWP3odih0o`000005om>N00?o00001_o</P000ol0003oaL<0o`000006olG30003o`000?nY_P3o
000000GoZKh00_l00007ohbg00?o00001_mb/002o`0000GoFJT000Go0000oeVY0?mIZ@3oFJT0o`00
0003od:R00;o00000_m2XP001Ol0003o;9X0obbJ0?l/VP3o000000?o;9X000Go0000oaVC0?lIT`3o
6I<0o`000004oaVC0004o`000?l7S03o0000o`0000Go1h`000?o0000o`252Ol000001Ol0Q@T2o`00
00Ko07hH0_l00005o`1g9@;o00001Ol0L3001?l0003o070`o`1`<?l00003o`1Y>@;o000000?o06Ti
o`000?l0HT400_l0HT42o`0000;o069100Go0000o`1KAol0FdOo05]7o`000003o`1KA`03o`000?l0
E4co000000Go05A<00?o0000o`1;COl000001?l0Bdd00ol0003o03]6o`000004o`0kAP;o00000_l0
;Sh01?l0003o02hno`0^?_l0;Sh2o`0000Go028g0_l00003o`0H<0;o000000?o01P`o`000?l03bT0
0_l03bT2o`000003o`0?:Ol0003o00PR00;o00PR0_l000000ol022;o0000o`000004ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`004oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oQL`3ohG<000?ohG<000Co0000omZ:0?l0003o00001_oJRP000ol0
003odih0o`000004om>N00Co00001oo</P02o`0000OoaL<00_l00005ojVn0004o`000?nY_P3oZKh0
o`0000GoS;L000Go0000ohbg0?n<]`3oS;L0o`000003og:`00;o00000_mb/0001Ol0003oFJT0oeVY
0?mIZ@3o000000GoFJT000?o0000od:R0?l000001Om2XP000ol0003o;9X0o`000005obbJ0003o`00
0?lIT`3o000000Go6I<00_l00007o`N<00;o00001Ol0Q@T00ol0003o08D9o`000005o`1n6003o`00
0?l0OQSo000000?o07LU0_l00002o`1g9@05o`000?l0L33o070`o`1`<?l000001?l0L3000ol0003o
06Tio`000004o`1Y>@03o`000?l0HT7o000000Go069100?o0000o`1KAol000001?l0FdL2o`0000Ko
05A<0_l00005o`1;C@;o00001?l0>dH01ol0003o03]6o`0kA_l0003o02hno`000?l0;Sh00_l00000
0ol0;Sko0000o`0R=`02o`0R=`;o00000_l08SL00ol0003o01P`o`000004o`0H<003o`000?l03bWo
000000Co00lY00?o0000o`088_l000001?l022800ol0003oooooooooo`03ooooo`;o00002Oooool3
o`0000?ooooo000Booooo`03o`000?oooooooooo00gooooo00?o0000on5c0?oQL`001?oQL`02o`00
00SofXX00_l00002om>N00?o000000Codih0o`000?oCWP3o00001_o</P001?l0003oc;80olbb0?l0
0004olG300;o00000_o5``001Ol0003oZKh0ojVn0?nY_P3o000000CoZKh000Go0000ohbg0?n<]`3o
S;L0o`000005ohbg0003o`000?mb/03o000000GoL[0000?o0000oeVY0?l000001_mIZ@02o`0000Ko
@Z800_l00006obbJ00;o00001OlIT`001?l0003o6I<0oaVC0?l00004o`N<00;o000000?o1h`0o`00
0?l0Q@T00_l0Q@T2o`0000?o08D900?o0000o`1n6?l0OQP00_l00003o`1n6003o`000?l0MbGo0000
00Go07LU00?o0000o`1`<?l000001Ol0L302o`0000Go06Ti0_l00006o`1R@@;o00001?l0FdL01?l0
003o05]7o`1KAol00003o`1DC0;o000000?o05A<o`000?l0Bdd00_l0Bdd2o`000003o`1;COl0003o
03]600;o03]600?o0000o`0kA_l0>dH00_l0>dH00ol0003o02hno`000004o`0^?P03o`000?l08SOo
000000Co028g0_l00005o`0H<0;o00001Ol03bT2o`0000Co00PR0_l0000Fooooo`004_ooool2o`00
00cooooo0ol00005on5c0004o`000?oQL`3ohG<0o`0000KofXX000?o0000omZ:0?l000000_l00002
om>N00;o00000ooCWP001?l0003oc;80olbb0?o</P02o`0000Coc;8000Co0000olG30?l0003o0000
1Oo5``000ol0003oZKh0o`000006ojVn0003o`000?n<]`3o000000KoS;L00_l00006og:`00;o0000
1_mIZ@000ol0003oFJT0o`000005od:R0004o`000?m2XP3o@Z80o`0000?o;9X00_l00002obbJ0005
o`000?lIT`3o6I<0oaVC0?l000001?lIT`001?l0003o1h`0o`000?l00004o`N<0003o`000?l0Q@Wo
000000Go08D900?o0000o`1n6?l000001Ol0OQP2o`0000Ko07LU0_l00005o`1`<003o`000?l0L33o
000000?o06Ti0_l00002o`1Y>@04o`000?l0HT7o0691o`1R@@;o000000?o0691o`000?l0FdL00_l0
FdL00ol0003o05]7o`1KA`02o`1KA`03o`000?l0E4co000000Co05A<00?o0000o`1;COl000001?l0
Bdd00ol0003o03]6o`000005o`0kAP;o000000?o02hno`000?l0;Sh00_l0;Sh2o`0000Co028g00?o
0000o`0R=ol000000ol06302o`000003o`0H<?l0003o00lY00;o00lY0_l000000ol03bWo0000o`08
8P02o`088P03o`000?oooooo000001Kooooo000Booooo`03o`000?oooooooooo00[ooooo00Go0000
onQK0?oXF`3oj5/0o`000003on5c0003o`000?oQL`3ohG<000;ohG<000Co0000omZ:0?oJRP3ofXX0
1?l00002omZ:0003o`000?oCWP3o000000Kodih000?o0000olbb0?l000001_o</P02o`0000OoaL<0
0ol00006ojVn00;o00001_n<]`001?l0003oS;L0ohbg0?l00003og:`00;o00000_mb/0001?l0003o
FJT0oeVY0?mIZ@02o`0000?oFJT000Go0000od:R0?m2XP3o@Z80o`000004od:R0003o`000?l/VP3o
000000Go;9X000?o0000oaVC0?l000001OlIT`02o`0000Ko1h`00_l00006o`252@;o00001Ol0OQP0
1?l0003o07hHo`1n6?l00003o`1g9@;o00000_l0MbD01Ol0003o070`o`1`<?l0L33o000000?o070`
00?o0000o`1Y>Ol000001Ol0JCT00ol0003o0691o`000004o`1R@@03o`000?l0FdOo000000Go05]7
0_l00005o`1DC0;o00001Ol0Bdd3o`0000?o03]60_l000001?l0>dKo0000o`0^?_l0;Sh3o`000003
o`0^?_l0003o028g00;o028g00Oo0000o`0R=ol08SOo028go`000?l0633o000000Co01P`00?o0000
o`0?:Ol000001?l03bT00ol0003o00PRo`000002ooooo`03o`000?oooooooooo01Cooooo000Boooo
o`03o`000?oooooooooo00Wooooo00?o0000onQK0?oXF`000ooXF`000ol0003ohG<0o`000006on5c
00Co00001OoJRP03o`0000Kodih00ol00005olbb0004o`000?o</P3oc;80o`0000GoaL<000Go0000
olG30?o5``3oaL<0o`000003ojVn00;o00000_nY_P001?l0003oS;L0ohbg0?n<]`02o`0000CoS;L0
00?o0000og:`0?l000001Omb/0000ol0003oFJT0o`000006oeVY0003o`000?m2XP3o000000Go@Z80
0_l00006obbJ00;o00001OlIT`001?l0003o6I<0oaVC0?l00003o`N<00;o00000_l7S0001?l0003o
08D9o`252Ol0Q@T2o`0000;o08D900Go0000o`1n6?l0OQSo07hHo`000004o`1n6003o`000?l0MbGo
000000Go07LU00?o0000o`1`<?l000001?l0L302o`0000Ko06Ti0_l00005o`1R@@;o00001Ol0FdL0
0ol0003o05]7o`000003o`1DC0;o000000?o05A<o`000?l0Bdd00_l0Bdd2o`0000?o04]=00?o0000
o`0kA_l000001?l0>dH00ol0003o02hno`000004o`0^?P03o`000?l08SOo000000Co028g0_l00005
o`0H<0;o00001Ol03bT2o`0000Cooooo00?o0000ooooooooool04oooool001;ooooo00?o0000oooo
ooooool02?ooool00ol0003oj5/0onQK0004onQK00?o00001?oQL`05o`0000GofXX000Go0000omZ:
0?oJRP3ofXX0o`000003om>N00;o00000ooCWP001Ol0003oc;80olbb0?o</P3o000000Coc;8000Go
0000olG30?o5``3oaL<0o`000005olG30003o`000?nY_P3o000000GoZKh000?o0000ohbg0?l00000
1_n<]`02o`0000KoL[000_l00007oeVY00;o00001Om2XP001?l0003o@Z80od:R0?l00003obbJ00;o
00000_l/VP001Ol0003o6I<0oaVC0?lIT`3o000000Co6I<000?o0000o`N<0?l000001Ol7S0000ol0
003o08D9o`000005o`252@03o`000?l0OQSo000000Go07hH0_l00006o`1g9@;o00001?l0L3001?l0
003o070`o`1`<?l00003o`1Y>@;o000000?o06Tio`000?l0HT400_l0HT42o`0000;o069100Go0000
o`1KAol0FdOo05]7o`000003o`1KA`03o`000?l0E4co000000Co05A<00?o0000o`1;COl000001Ol0
Bdd2o`0000Go03]60_l000000ol0;Sko0000o`0^?P02o`0^?P;o00001?l08SL00ol0003o028go`00
0003o`0H<0;o000000?o01P`o`000?l03bT00_l03bT2o`0000Kooooo00?o0000ooooooooool04ooo
ool001;ooooo0_l00007ooooo`;o00001_oXF`001?l0003oj5/0onQK0?oXF`06o`0000?ohG<000Go
0000omZ:0?oJRP3ofXX0o`000005omZ:0003o`000?oCWP3o000000Kodih000?o0000olbb0?l00000
1_o</P000ol0003oaL<0o`000006olG300;o00001_nY_P03o`0000GoS;L000?o0000ohbg0?l00000
1Omb/0001?l0003oL[00og:`0?l00004oeVY00;o00000_mIZ@001Ol0003o@Z80od:R0?m2XP3o0000
00Co@Z8000?o0000obbJ0?l000001Ol/VP000ol0003o6I<0o`000005oaVC00;o00001_l7S002o`00
00Ko08D90_l00005o`1n6003o`000?l0OQSo000000Co07LU0_l000000ol0MbGo0000o`1`<002o`1`
<003o`000?l0L33o070`00;o070`00?o0000o`1Y>Ol000001?l0JCT00ol0003o0691o`000005o`1R
@@03o`000?l0FdOo000000Co05]70_l00005o`1DC0;o00001Ol0Bdd00ol0003o04]=o`000003o`0k
AP;o000000Co03]6o`000?l0;Sko02hn0ol000000ol0;Sko0000o`0R=`02o`0R=`07o`000?l08SOo
028go`0R=ol0003o01P`o`000004o`0H<003o`000?l03bWo000000Sooooo00?o0000ooooooooool0
4oooool0017ooooo00?o0000ooooooooool01Oooool2o`0000;okd4000Co0000onQK0?oXF`3oj5/0
0_l00003onQK00?o000000?ohG<0o`000?oQL`001OoQL`000ol0003ofXX0o`000006omZ:00;o0000
1ooCWP02o`0000Ooc;800_l00006olG30004o`000?o5``3oaL<0o`0000?oZKh00_l00003ojVn0005
o`000?n<]`3oS;L0ohbg0?l000000on<]`001Ol0003oL[00og:`0?mb/03o000000CoL[0000Co0000
oeVY0?l0003o00001OmIZ@000ol0003o@Z80o`000005od:R00;o00001_l/VP02o`0000Go6I<000Co
0000oaVC0?lIT`3o00000ol7S002o`0000;o1h`000Co0000o`252Ol0Q@Wo08D90_l00002o`252@05
o`000?l0OQSo07hHo`1n6?l000000ol0OQP01?l0003o07LUo`000?l00004o`1g9@03o`000?l0L33o
000000Go070`0_l00005o`1Y>@;o00001_l0HT42o`0000Co05]700?o0000o`1KAol000000ol0E4`2
o`0000;o05A<00Go0000o`1;COl0Bdgo04]=o`000003o`1;C@03o`000?l0>dKo000000Co03]600?o
0000o`0^?_l000001?l0;Sh00ol0003o028go`000004o`0R=`;o00001Ol06302o`0000Wooooo00?o
0000ooooooooool04oooool0017ooooo00?o0000ooooooooool00oooool2o`0000Gokd4000?o0000
onQK0?l000000_oXF`03o`0000;oj5/00_l00007on5c00?o00001OoJRP001?l0003ofXX0omZ:0?l0
0005om>N0004o`000?oCWP3odih0o`0000Coc;800_l00002olbb0004o`000?o5``3oaL<0olG300;o
00001?o5``000ol0003oZKh0o`000006ojVn0003o`000?n<]`3o000000GoS;L000?o0000og:`0?l0
00001Omb/003o`0000KoFJT00_l00005od:R0004o`000?m2XP3o@Z80o`0000?o;9X00_l00002obbJ
0005o`000?lIT`3o6I<0oaVC0?l000001?lIT`000ol0003o1h`0o`000005o`N<0003o`000?l0Q@Wo
000000Go08D900?o0000o`1n6?l000001?l0OQP2o`0000Ko07LU0_l00005o`1`<003o`000?l0L33o
000000?o06Ti0_l00002o`1Y>@04o`000?l0HT7o0691o`1R@@;o000000?o0691o`000?l0FdL00_l0
FdL01ol0003o05]7o`1KAol0FdOo0000o`1DC?l000001Ol0E4`00ol0003o04]=o`000004o`1;C@;o
00001Ol0>dH2o`000003o`0^?_l0003o02hn00;o02hn0_l00003o`0R=`;o000000?o028go`000?l0
63000_l06302o`0000_ooooo00?o0000ooooooooool04oooool0017ooooo0ol000000ooooooo0000
o`000007onm100Go00001?oXF`001?l0003oj5/0onQK0?l00005on5c0005o`000?oQL`3ohG<0on5c
0?l000000ooJRP000ol0003ofXX0omZ:0002omZ:0005o`000?oCWP3odih0om>N0?l000001?oCWP00
1?l0003oc;80o`000?l00005olbb0003o`000?o5``3o000000KoaL<00_l00007ojVn00;o00001_n<
]`02o`0000GoL[0000Go0000og:`0?mb/03oL[00o`000003oeVY00;o00000_mIZ@001Ol0003o@Z80
od:R0?m2XP3o000000Co@Z8000?o0000obbJ0?l000001Ol/VP000ol0003o6I<0o`000005oaVC00;o
00001_l7S002o`0000Ko08D90_l00004o`1n6004o`000?l0OQSo07hHo`0000?o07LU0_l00002o`1g
9@05o`000?l0L33o070`o`1`<?l000000ol0L3000ol0003o06Tio`000005o`1Y>@03o`000?l0HT7o
000000Co069100?o0000o`1KAol000001?l0FdL2o`0000Ko05A<0_l00004o`1;C@03o`000?l0Bdgo
000000?o03]60_l000001?l0>dKo0000o`0^?_l0;Sh3o`0000;o02hn00?o0000o`0R=ol000001?l0
8SL00ol0003o01P`o`00000=ooooo`03o`000?oooooooooo01?ooooo0003ooooo`?o00000oooool3
o`0000Gooooo00Co0000oooooooooooo00000_og9@000ol0003okd40onm10003onm100?o000000?o
kd40o`000?oXF`000_oXF`02o`0000Coj5/000Go0000on5c0?oQL`3ohG<0o`000005on5c0003o`00
0?oJRP3o000000KofXX000?o0000om>N0?l000001OoCWP03o`0000Koc;800ol00005olG30003o`00
0?o5``3o000000KoZKh000Co0000ojVn0?nY_P3o00000on<]`02o`0000;oS;L000Go0000og:`0?mb
/03oL[00o`000005og:`0003o`000?mIZ@3o000000GoFJT000?o0000od:R0?l000001Om2XP02o`00
00Ko;9X00_l00005oaVC0004o`000?lIT`3o6I<0o`0000?o1h`00_l00002o`N<0004o`000?l0Q@Wo
08D9o`252@;o000000?o08D9o`000?l0OQP00_l0OQP00ol0003o07hHo`1n6002o`1n6003o`000?l0
MbGo000000Go07LU00?o0000o`1`<?l000001?l0L302o`0000Ko06Ti0_l00005o`1R@@;o00000ol0
FdL2o`0000;o05]700Co0000o`1DC?l0E4co05A<0_l000000ol0E4co0000o`1;C@02o`1;C@07o`00
0?l0Bdgo04]=o`1;COl0003o03]6o`000004o`0kAP04o`000?l0;Sko0000o`0000?o02hn0_l00005
o`0R=`;o00003_ooool00ol0003oooooooooo`0Cooooo`001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004ooLU0003o`000?o_@@3o
000000;o00001Oo_@@000ol0003oj5/0o`000007onQK0003o`000?oQL`3o000000KohG<00_l00007
omZ:00;o00001OoCWP001Ol0003odih0om>N0?oCWP3o000000?oc;800_l00003olbb0005o`000?o5
``3oaL<0olG30?l000000oo5``001?l0003oZKh0ojVn0?nY_P02o`0000CoZKh000?o0000ohbg0?l0
00001On<]`000ol0003oL[00o`000006og:`00;o00001_mIZ@02o`0000Go@Z8000Co0000od:R0?m2
XP3o00000ol/VP02o`0000;o;9X000Go0000oaVC0?lIT`3o6I<0o`000004oaVC0003o`000?l7S03o
000000Go1h`000?o0000o`252Ol000001?l0Q@T00ol0003o07hHo`000005o`1n60;o00001_l0MbD2
o`0000Co070`00Co0000o`1`<?l0L33o00000ol0JCT2o`000003o`1Y>Ol0003o069100;o06910_l0
0002o`1R@@03o`000?l0FdOo000000Go05]700?o0000o`1DC?l000001?l0E4`00ol0003o04]=o`00
0004o`1;C@;o00001Ol0>dH2o`000007o`0^?_l0003o02hno`0^?_l0003o02hno`000003o`0R=`;o
00004Oooool00ol0003oooooooooo`0Booooo`001?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo0_l00004ooLU00?o000000?okd40o`000?o_@@001Oo_@@03o`0000Ooj5/0
0_l00006on5c0004o`000?oQL`3ohG<0o`0000CofXX00_l00002omZ:0005o`000?oCWP3odih0om>N
0?l000001OoCWP000ol0003oc;80o`000006olbb0003o`000?o5``3o000000GoaL<000?o0000ojVn
0?l000001_nY_P02o`0000KoS;L00_l00006og:`0004o`000?mb/03oL[00o`0000?oFJT00_l00002
oeVY0005o`000?m2XP3o@Z80od:R0?l000001?m2XP000ol0003o;9X0o`000005obbJ0003o`000?lI
T`3o000000Go6I<00_l00006o`N<00;o00001Ol0Q@T2o`0000Go07hH00Co0000o`1n6?l0OQSo0000
0ol0MbD2o`000003o`1g9Ol0003o070`00;o070`00?o0000o`1`<?l0L3000_l0L3000ol0003o06Ti
o`000004o`1Y>@03o`000?l0HT7o000000Co06910_l00006o`1KA`;o00001Ol0E4`2o`0000?o04]=
0_l000000ol0Bdgo0000o`0kAP02o`0kAP;o000000Co03]6o`000?l0;Sko02hn0_l00003o`0^?P03
o`000?l08SOo000001?ooooo00?o0000ooooooooool04_ooool000Cooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooooooool3o`000004ooLU0?l0003o0000o`0000;ombD00ol00005onm1
0005o`000?o_@@3okd40onm10?l000001?oXF`02o`0000;oj5/000Co0000on5c0?oQL`3ohG<00_l0
0004on5c0004o`000?oJRP3o0000o`0000GofXX000?o0000om>N0?l000001_oCWP02o`0000Ooc;80
0_l00006olG300?o00001OnY_P001?l0003oZKh0ojVn0?l00003ohbg00;o00000_n<]`001?l0003o
L[00og:`0?mb/002o`0000CoL[0000?o0000oeVY0?l000001OmIZ@000ol0003o@Z80o`000005od:R
00;o00001_l/VP02o`0000Go6I<000Co0000oaVC0?lIT`3o00000ol7S002o`000003o`N<0?l0003o
08D900;o08D90_l00002o`252@05o`000?l0OQSo07hHo`1n6?l000001?l0OQP00ol0003o07LUo`00
0004o`1g9@03o`000?l0L33o000000Go070`0_l00005o`1Y>@;o00001?l0HT401?l0003o0691o`1R
@Ol00003o`1KA`;o000000?o05]7o`000?l0E4`00_l0E4`2o`0000;o05A<00?o0000o`1;COl00000
1?l0Bdd00ol0003o03]6o`000004o`0kAP04o`000?l0;Sko0000o`0000?o02hn0_l0000Dooooo`03
o`000?oooooooooo01;ooooo0004ooooo`04o`000?ooooooooooooooo`Co00001?ooool4o`0000?o
mbD00_l00003ooLU0005o`000?o_@@3okd40onm10?l000001Oo_@@001?l0003oj5/0o`000?l00005
onQK0003o`000?oQL`3o000000KohG<00_l00007omZ:00?o00001OoCWP000ol0003odih0o`000006
olbb0004o`000?o</P3oc;80o`0000?oaL<00_l00003olG30005o`000?nY_P3oZKh0ojVn0?l00000
1?nY_P000ol0003oS;L0o`000005ohbg0003o`000?mb/03o000000KoL[000_l00006oeVY00;o0000
1Om2XP001?l0003o@Z80od:R0?l00003obbJ00;o00000_l/VP001Ol0003o6I<0oaVC0?lIT`3o0000
00Co6I<000?o0000o`N<0?l000001?l7S0000ol0003o08D9o`000005o`252@03o`000?l0OQSo0000
00Go07hH0_l00005o`1g9@;o00001Ol0L3000ol0003o070`o`000003o`1Y>@;o000000?o06Tio`00
0?l0HT400_l0HT400ol0003o0691o`1R@@02o`1R@@03o`000?l0FdOo000000Co05]700?o0000o`1D
C?l000001?l0E4`2o`0000Go04]=0_l00005o`0kAP;o00000_l0;Sh3o`0001Kooooo00?o0000oooo
ooooool04_ooool000?ooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03
o`000?og9@3o000000KombD000?o0000onm10?l000001_o_@@02o`0000Ooj5/00ol00005on5c0004
o`000?oQL`3ohG<0o`0000GofXX000Go0000omZ:0?oJRP3ofXX0o`000003om>N0005o`000?oCWP3o
dih0om>N0?l000000oo</P02o`0000Coc;8000?o0000olG30?l000001_o5``000ol0003oZKh0o`00
0005ojVn00;o00001_n<]`02o`0000KoL[0000Co0000og:`0?mb/03o00000omIZ@02o`0000;oFJT0
00Go0000od:R0?m2XP3o@Z80o`000004od:R0003o`000?l/VP3o000000Go;9X000?o0000oaVC0?l0
00001OlIT`02o`0000Go1h`00_l00006o`252@?o00000ol0OQP2o`000003o`1n6?l0003o07LU00;o
07LU0_l00002o`1g9@05o`000?l0L33o070`o`1`<?l000000ol0L3000ol0003o06Tio`000004o`1Y
>@03o`000?l0HT7o000000Go06910_l00005o`1KA`;o00001?l0E4`00ol0003o05A<o`000003o`1;
C@;o000000?o04]=o`000?l0>dH00_l0>dH2o`0000;o03]600?o0000o`0^?_l000006?ooool00ol0
003oooooooooo`0Booooo`001?ooool01?l0003oooooooooooooool5o`0000Gooooo00Co0000oooo
oooooooo00001oog9@03o`0000Gokd4000Co0000onm10?o_@@3o00001OoXF`001Ol0003oj5/0onQK
0?oXF`3o000000?ohG<000?o0000on5c0?oQL`000_oQL`001Ol0003ofXX0omZ:0?oJRP3o000000Go
fXX000?o0000om>N0?l000001OoCWP000ol0003oc;80o`000006olbb00;o00001oo5``02o`0000Go
ZKh000Co0000ojVn0?nY_P3o00000on<]`02o`0000;oS;L000Co0000og:`0?mb/03oL[000_l00004
og:`0003o`000?mIZ@3o000000GoFJT000?o0000od:R0?l000001Om2XP02o`0000Ko;9X00_l00005
oaVC0003o`000?lIT`3o000000?o1h`00_l00002o`N<0004o`000?l0Q@Wo08D9o`252@;o00000ol0
Q@T00ol0003o07hHo`000004o`1n6003o`000?l0MbGo000000Go07LU00?o0000o`1`<?l000001?l0
L302o`0000Go06Ti0ol00003o`1R@@;o000000?o0691o`000?l0FdL00_l0FdL2o`000003o`1KAol0
003o05A<00;o05A<00Oo0000o`1DC?l0E4co05A<o`000?l0Bdgo000000Co04]=00?o0000o`0kA_l0
00001?l0>dH2o`000003ooooool0003ooooo01Kooooo00?o0000ooooooooool04_ooool001?ooooo
00Co0000oooooooooooo00001Oog9@001Ol0003ombD0ooLU0?og9@3o000000?okd4000?o0000onm1
0?o_@@000_o_@@001Ol0003oj5/0onQK0?oXF`3o000000Goj5/000?o0000on5c0?l000001_oQL`00
0ol0003ofXX0o`000006omZ:00;o00001_oCWP03o`0000Goc;8000Co0000olbb0?o</P3o00001?o5
``02o`0000;oaL<000Go0000ojVn0?nY_P3oZKh0o`000004ojVn0003o`000?n<]`3o000000GoS;L0
00?o0000og:`0?l000001_mb/002o`0000KoFJT00_l00005od:R0004o`000?m2XP3o@Z80o`0000?o
;9X00_l000000ol/VP3o0000oaVC0002oaVC00;o00000olIT`000ol0003o1h`0o`000005o`N<0003
o`000?l0Q@Wo000000Go08D90_l00005o`1n60;o00001_l0MbD2o`0000?o070`0_l000000ol0L33o
0000o`1Y>@02o`1Y>@;o00000ol0JCT00ol0003o0691o`000004o`1R@@03o`000?l0FdOo000000Co
05]700?o0000o`1DC?l000001?l0E4`2o`0000Go04]=0_l00003o`0kAP;o00001?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo000Dooooo`04o`000?ooooooooooo`0000?o
mbD000?o0000ooLU0?og9@000oog9@000ol0003okd40o`000006onm10003o`000?oXF`3o000000Ko
j5/00ol00006on5c00;o00001_oJRP001?l0003ofXX0omZ:0?l00003om>N00;o00000ooCWP001Ol0
003oc;80olbb0?o</P3o000000Coc;8000Co0000olG30?l0003o00001Oo5``000ol0003oZKh0o`00
0005ojVn00;o00001_n<]`02o`0000KoL[0000Co0000og:`0?mb/03o00000omIZ@02o`0000;oFJT0
00Go0000od:R0?m2XP3o@Z80o`000004od:R0003o`000?l/VP3o000000Co;9X000?o0000oaVC0?l0
00001OlIT`02o`0000Ko1h`00_l00005o`252@03o`000?l0Q@Wo000000?o07hH0_l00002o`1n6004
o`000?l0MbGo07LUo`1g9@;o00000_l0MbD00ol0003o070`o`000004o`1`<003o`000?l0JCWo0000
00Go06Ti0_l00005o`1R@@;o00001Ol0FdL2o`0000?o05A<0_l000000ol0E4co0000o`1;C@02o`1;
C@;o00000_l0Bdd00ol0003o03]6o`000006ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool04Oooool001Gooooo0_l000001?oooooo0000ooLU0?l00006ooLU00?o00001_o_@@03o`00
00Goj5/000Go0000onQK0?oXF`3oj5/0o`000003on5c00;o00000_oQL`001?l0003ofXX0omZ:0?oJ
RP02o`0000CofXX000?o0000om>N0?l000001_oCWP000ol0003oc;80o`000005olbb00?o00001_o5
``02o`0000GoZKh000Co0000ojVn0?nY_P3o00000on<]`02o`0000;oS;L000Co0000og:`0?mb/03o
L[000_l00004og:`0003o`000?mIZ@3o000000GoFJT000?o0000od:R0?l000001Om2XP02o`0000Go
;9X00_l00005oaVC0004o`000?lIT`3o6I<0o`0000?o1h`00_l00002o`N<0005o`000?l0Q@Wo08D9
o`252Ol000000ol0Q@T00ol0003o07hHo`000005o`1n6003o`000?l0MbGo000000Co07LU0_l00005
o`1`<0;o00001Ol0JCT00ol0003o06Tio`000003o`1R@@;o000000?o0691o`000?l0FdL00_l0FdL2
o`0000;o05]700?o0000o`1DC?l000001?l0E4`00ol0003o04]=o`000004o`1;C@;o00002?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo000Gooooo`04o`000?oooooo0000
o`0000GombD000Go0000ooLU0?og9@3ombD0o`000003onm100;o00000oo_@@001Ol0003oj5/0onQK
0?oXF`3o000000Goj5/000?o0000on5c0?l000001OoQL`000ol0003ofXX0o`000006omZ:00?o0000
1_oCWP02o`0000Goc;8000Go0000olbb0?o</P3oc;80o`000003olG300;o00000_o5``001Ol0003o
ZKh0ojVn0?nY_P3o000000CoZKh000?o0000ohbg0?l000001On<]`000ol0003oL[00o`000006og:`
00;o00001_mIZ@02o`0000Go@Z8000?o0000od:R0?l000000ol/VP02o`0000;o;9X000Go0000oaVC
0?lIT`3o6I<0o`000004oaVC0003o`000?l7S03o000000Go1h`000?o0000o`252Ol000001?l0Q@T2
o`0000Ko07hH0_l00004o`1g9@03o`000?l0MbGo000000?o070`0_l00002o`1`<005o`000?l0JCWo
06Tio`1Y>Ol000000ol0JCT00ol0003o0691o`000004o`1R@@03o`000?l0FdOo000000Co05]70_l0
0005o`1DC0;o00001?l0Bdd00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04Oooool001Sooooo00Co0000oooooooooooo00000oog9@000ol0003ombD0ooLU
0003ooLU0003o`000?o_@@3o000000Kokd4000?o0000onQK0?l000001_oXF`02o`0000KohG<00ol0
0005omZ:0005o`000?oJRP3ofXX0omZ:0?l000000ooCWP02o`0000;odih000Go0000olbb0?o</P3o
c;80o`000005olbb0003o`000?o5``3o000000GoaL<000?o0000ojVn0?l000001OnY_P02o`0000Ko
S;L00_l00006og:`0004o`000?mb/03oL[00o`0000?oFJT00_l000000omIZ@3o0000od:R0002od:R
00;o00000om2XP000ol0003o;9X0o`000005obbJ0003o`000?lIT`3o000000Go6I<00_l00006o`N<
00;o00001?l0Q@T01?l0003o08D9o`252Ol00003o`1n60;o000000?o07hHo`000?l0MbD00_l0MbD0
1ol0003o07LUo`1g9Ol0MbGo0000o`1`<?l000001Ol0L3000ol0003o06Tio`000004o`1Y>@;o0000
1Ol0HT42o`0000Co05]700?o0000o`1KAol000000ol0E4`2o`000003o`1DC?l0003o04]=00;o04]=
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo
000Iooooo`06o`000?ooooooooooo`000?og9@3o00001_og9@02o`0000Ookd400_l00006onQK0004
o`000?oXF`3oj5/0o`0000?ohG<00_l00003on5c0005o`000?oJRP3ofXX0omZ:0?l000001OoJRP00
0ol0003odih0o`000005om>N0003o`000?o</P3o000000Koc;800_l00006olG300;o00001OnY_P00
1?l0003oZKh0ojVn0?l00003ohbg00;o00000_n<]`001?l0003oL[00og:`0?mb/002o`0000CoL[00
00?o0000oeVY0?l000001?mIZ@000ol0003o@Z80o`000005od:R00;o00001_l/VP02o`0000Go6I<0
00Co0000oaVC0?lIT`3o00000ol7S002o`000003o`N<0?l0003o08D900;o08D900?o0000o`252Ol0
Q@T00_l0Q@T00ol0003o07hHo`000004o`1n6003o`000?l0MbGo000000Co07LU0_l00006o`1`<0;o
00000ol0JCT2o`000003o`1Y>Ol0003o069100;o06910_l000000ol0HT7o0000o`1KA`02o`1KA`07
o`000?l0FdOo05]7o`1KAol0003o05A<o`000004o`1DC003o`000?l0Bdgo000000kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`006_ooool2o`000003ooooool0003ombD0
00GombD000Co0000ooLU0?og9@3o00001?o_@@02o`0000;okd4000Co0000onQK0?oXF`3oj5/00_l0
0004onQK0003o`000?oQL`3o000000KohG<000?o0000omZ:0?l000001_oJRP02o`0000Kodih00_l0
0006olbb0004o`000?o</P3oc;80o`0000?oaL<00_l00002olG30005o`000?nY_P3oZKh0ojVn0?l0
00001?nY_P000ol0003oS;L0o`000005ohbg0003o`000?mb/03o000000KoL[000_l00005oeVY00;o
00001Om2XP001?l0003o@Z80od:R0?l00003obbJ00;o00000_l/VP001Ol0003o6I<0oaVC0?lIT`3o
000000Co6I<000?o0000o`N<0?l000001?l7S0000ol0003o08D9o`000005o`252@;o00001Ol0OQP2
o`0000?o07LU0_l00002o`1g9@04o`000?l0L33o070`o`1`<0;o00000_l0L3000ol0003o06Tio`00
0004o`1Y>@03o`000?l0HT7o000000Co069100?o0000o`1KAol000001?l0FdL2o`0000Go05A<0_l0
000@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool001cooooo00?o0000
ooooool000000oog9@02o`0000CombD000Co0000onm10?l0003o00001Oo_@@000ol0003oj5/0o`00
0006onQK00?o00001_oQL`02o`0000KofXX000Co0000omZ:0?oJRP3o00000ooCWP02o`0000;odih0
00Co0000olbb0?o</P3oc;800_l00004olbb0003o`000?o5``3o000000GoaL<000?o0000ojVn0?l0
00001OnY_P02o`0000KoS;L00_l00006og:`0003o`000?mb/03o000000?oFJT00_l00002oeVY0005
o`000?m2XP3o@Z80od:R0?l000001?m2XP000ol0003o;9X0o`000005obbJ0003o`000?lIT`3o0000
00Go6I<00_l00005o`N<00?o00000ol0Q@T2o`000003o`252Ol0003o07hH00;o07hH0_l00002o`1n
6003o`000?l0MbGo000000Go07LU00?o0000o`1`<?l000001?l0L302o`0000Go06Ti0_l00005o`1R
@@;o00000ol0FdL2o`000003o`1KAol0003o05A<00;o05A<0_l0000Cooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04Oooool001gooooo00Go0000ooooool0003ombD0o`000006ooLU
00?o00001_o_@@03o`0000Goj5/000Go0000onQK0?oXF`3oj5/0o`000003on5c00;o00000_oQL`00
1?l0003ofXX0omZ:0?oJRP02o`0000CofXX000?o0000om>N0?l000001OoCWP000ol0003oc;80o`00
0006olbb00;o00001_o5``02o`0000GoZKh000Co0000ojVn0?nY_P3o00000on<]`02o`0000;oS;L0
00Co0000og:`0?mb/03oL[000_l00003og:`0003o`000?mIZ@3o000000GoFJT000?o0000od:R0?l0
00001Om2XP02o`0000Ko;9X00ol00003oaVC00;o000000?o6I<0o`000?l7S0000_l7S002o`0000?o
1h`000?o0000o`252Ol000001?l0Q@T00ol0003o07hHo`000005o`1n6003o`000?l0MbGo07LU00Co
07LU0_l00004o`1`<003o`000?l0L33o000000?o06Ti0_l000000ol0JCWo0000o`1R@@02o`1R@@;o
00000_l0HT400ol0003o05]7o`000004o`1KA`03o`000?l0E4co000001Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0@ooooo`007_ooool01?l0003oooooo`000?l00005ooLU0005
o`000?og9@3ombD0ooLU0?l000000oo_@@02o`0000?okd4000Go0000onQK0?oXF`3oj5/0o`000005
onQK0003o`000?oQL`3o000000GohG<000?o0000omZ:0?l000001_oJRP02o`0000Kodih00ol00005
olbb0004o`000?o</P3oc;80o`0000?oaL<00_l00002olG30005o`000?nY_P3oZKh0ojVn0?l00000
1?nY_P000ol0003oS;L0o`000005ohbg0003o`000?mb/03o000000GoL[000_l00006oeVY00?o0000
0om2XP02o`0000;o@Z8000Co0000obbJ0?l/VP3o;9X00_l00003obbJ0003o`000?lIT`3o000000Co
6I<000?o0000o`N<0?l000001Ol7S002o`0000Go08D90_l00005o`1n6003o`000?l0OQSo000000?o
07LU0_l000000ol0MbGo0000o`1`<002o`1`<007o`000?l0L33o070`o`1`<?l0003o06Tio`000004
o`1Y>@03o`000?l0HT7o000000Co06910_l00005o`1KA`;o00005oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo000Oooooo`;o000000?oooooo`000?og9@000_og9@000ol0
003ombD0ooLU0003ooLU0003o`000?o_@@3o000000Kokd4000?o0000onQK0?l000001_oXF`02o`00
00KohG<00ol00005omZ:0004o`000?oJRP3ofXX0o`0000?odih00_l00003om>N0005o`000?o</P3o
c;80olbb0?l000001?o</P000ol0003oaL<0o`000005olG30003o`000?nY_P3o000000GoZKh00_l0
0006ohbg00?o00000omb/002o`0000;oL[0000Co0000oeVY0?mIZ@3oFJT00_l00003oeVY0003o`00
0?m2XP3o000000Go@Z8000?o0000obbJ0?l000001Ol/VP02o`0000Go6I<00_l00005o`N<0003o`00
0?l7S03o000000?o08D90_l00002o`252@05o`000?l0OQSo07hHo`1n6?l000000ol0OQP00ol0003o
07LUo`000004o`1g9@03o`000?l0L33o000000Co070`0_l00005o`1Y>@?o00000ol0HT401?l0003o
0691o`1R@Ol00003o`1KA`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0@ooooo`008Oooool01Ol0003oooooo`000?og9@3o000000KombD00ol00006onm1
00?o00001OoXF`001?l0003oj5/0onQK0?l00003on5c00;o00000ooQL`001Ol0003ofXX0omZ:0?oJ
RP3o000000CofXX000?o0000om>N0?l000001_oCWP000ol0003oc;80o`000005olbb00;o00001_o5
``03o`0000?oZKh00_l00002ojVn0004o`000?n<]`3oS;L0ohbg00;o00000on<]`000ol0003oL[00
o`000005og:`0003o`000?mIZ@3o000000GoFJT00_l00006od:R00;o00001Ol/VP000ol0003o;9X0
o`000003oaVC00;o00000_lIT`001Ol0003o1h`0o`N<0?l7S03o000000?o1h`000?o0000o`252Ol0
00001Ol0Q@T00ol0003o07hHo`000004o`1n60;o00001Ol0MbD2o`0000?o070`0_l00002o`1`<005
o`000?l0JCWo06Tio`1Y>Ol000000ol0JCT00ol0003o0691o`000004o`1R@@03o`000?l0FdOo0000
01cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`008_ooool01?l0003o
ooooo`000?l00005ooLU0005o`000?og9@3ombD0ooLU0?l000000oo_@@02o`0000?okd4000Go0000
onQK0?oXF`3oj5/0o`000004onQK0003o`000?oQL`3o000000KohG<000?o0000omZ:0?l000001OoJ
RP03o`0000Kodih00_l00005olbb0004o`000?o</P3oc;80o`0000?oaL<00_l00003olG30003o`00
0?nY_P3o000000GoZKh000?o0000ohbg0?l000001On<]`02o`0000KoL[000_l00005oeVY0004o`00
0?mIZ@3oFJT0o`0000?o@Z800_l00002od:R0005o`000?l/VP3o;9X0obbJ0?l000000ol/VP000ol0
003o6I<0o`000005oaVC0003o`000?l7S03o000000Co1h`00_l00006o`252@;o00000ol0OQP2o`00
0003o`1n6?l0003o07LU00;o07LU0_l00002o`1g9@03o`000?l0L33o000000Go070`00?o0000o`1Y
>Ol000001?l0JCT2o`0000Go06910_l0000Mooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool04?ooool002?ooooo00Co0000oooooooooooo00000oog9@000ol0003ombD0ooLU0003ooLU
0003o`000?o_@@3o000000Kokd4000?o0000onQK0?l000001OoXF`03o`0000KohG<00_l00005omZ:
0005o`000?oJRP3ofXX0omZ:0?l000000ooCWP02o`0000;odih000Go0000olbb0?o</P3oc;80o`00
0004olbb0003o`000?o5``3o000000GoaL<00_l00006ojVn00;o00001On<]`001?l0003oS;L0ohbg
0?l00003og:`00;o00000_mb/0001Ol0003oFJT0oeVY0?mIZ@3o000000CoFJT000?o0000od:R0?l0
00001Om2XP000ol0003o;9X0o`000004obbJ00;o00001_lIT`02o`0000?o1h`00_l00002o`N<0004
o`000?l0Q@Wo08D9o`252@;o00000_l0Q@T00ol0003o07hHo`000004o`1n6003o`000?l0MbGo0000
00Go07LU00?o0000o`1`<?l0L3001?l0L302o`0000Co06Ti00?o0000o`1Y>Ol000000ol0HT42o`00
023ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`009?ooool2o`000004
ooooool0003ombD0o`0000KombD00_l00007onm100;o00001OoXF`001Ol0003oj5/0onQK0?oXF`3o
000000?ohG<00_l00002on5c0005o`000?oJRP3ofXX0omZ:0?l000001OoJRP000ol0003odih0o`00
0005om>N0003o`000?o</P3o000000Goc;800_l00005olG30004o`000?o5``3oaL<0o`0000?oZKh0
0_l00002ojVn0005o`000?n<]`3oS;L0ohbg0?l000001?n<]`000ol0003oL[00o`000005og:`0003
o`000?mIZ@3o000000GoFJT00_l00006od:R00;o00000ol/VP02o`0000;o;9X000Co0000oaVC0?lI
T`3o6I<00_l00002oaVC0003o`000?l7S03o000000Go1h`000?o0000o`252Ol000001?l0Q@T2o`00
00Go07hH0_l00005o`1g9@03o`000?l0MbGo000000?o070`0_l000000ol0L33o0000o`1Y>@02o`1Y
>@07o`000?l0JCWo06Tio`1Y>Ol0003o0691o`00000Sooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04?ooool002Kooooo00Co0000ooooool0003o00001Oog9@001?l0003ombD0ooLU
0?l00004onm100;o00000_o_@@001Ol0003oj5/0onQK0?oXF`3o000000Goj5/000?o0000on5c0?l0
00001OoQL`000ol0003ofXX0o`000006omZ:00;o00001_oCWP03o`0000?oc;800_l00002olbb0005
o`000?o5``3oaL<0olG30?l000001?o5``000ol0003oZKh0o`000005ojVn0003o`000?n<]`3o0000
00GoS;L00_l00006og:`00?o00000omIZ@02o`0000;oFJT000Co0000od:R0?m2XP3o@Z800_l00002
od:R0003o`000?l/VP3o000000Go;9X000?o0000oaVC0?l000001?lIT`02o`0000Ko1h`00_l00004
o`252@03o`000?l0Q@Wo000000?o07hH0_l00002o`1n6005o`000?l0MbGo07LUo`1g9Ol000000ol0
MbD00ol0003o070`o`000004o`1`<003o`000?l0JCWo000000Co06Ti0_l0000Uooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool04?ooool002Oooooo00Co0000oooooooooooo00000oog
9@000ol0003ombD0ooLU0002ooLU0004o`000?o_@@3o0000o`0000Gokd4000?o0000onQK0?l00000
1_oXF`02o`0000KohG<00_l00006omZ:0004o`000?oJRP3ofXX0o`0000?odih00_l00003om>N0003
o`000?o</P3o000000Goc;8000?o0000olG30?l000001Oo5``02o`0000KoZKh00_l00005ohbg0004
o`000?n<]`3oS;L0o`0000?oL[000_l00003og:`0003o`000?mIZ@3o000000GoFJT000?o0000od:R
0?l000001?m2XP02o`0000Ko;9X00_l00004oaVC0004o`000?lIT`3o6I<0o`0000?o1h`00_l00000
0ol7S03o0000o`252@02o`252@07o`000?l0Q@Wo08D9o`252Ol0003o07hHo`000005o`1n6003o`00
0?l0MbGo000000Co07LU0_l00005o`1`<0;o00000ol0JCT2o`0002Oooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0?ooooo`00:?ooool01_l0003oooooooooool0003ombD0o`0000Go
mbD00ol00006onm100?o00001OoXF`001?l0003oj5/0onQK0?l00003on5c00;o00000_oQL`001?l0
003ofXX0omZ:0?oJRP02o`0000CofXX000?o0000om>N0?l000001OoCWP02o`0000Koc;800_l00005
olG30004o`000?o5``3oaL<0o`0000?oZKh00_l00002ojVn0005o`000?n<]`3oS;L0ohbg0?l00000
1?n<]`000ol0003oL[00o`000005og:`00;o00001_mIZ@02o`0000Co@Z8000Co0000od:R0?m2XP3o
00000ol/VP02o`000003obbJ0?l0003o6I<000;o6I<000?o0000oaVC0?lIT`000_lIT`000ol0003o
1h`0o`000004o`N<0003o`000?l0Q@Wo000000Co08D90_l00006o`1n60;o00000ol0MbD2o`000003
o`1g9Ol0003o070`00;o070`0_l00002o`1`<003o`000?l0JCWo000002[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0?ooooo`00:Oooool2o`000003ooooool0003ombD000CombD0
00Go0000ooLU0?og9@3ombD0o`000003onm100;o00000oo_@@001Ol0003oj5/0onQK0?oXF`3o0000
00Coj5/000?o0000on5c0?l000001OoQL`000ol0003ofXX0o`000006omZ:00;o00001OoCWP001?l0
003odih0om>N0?l00003olbb00;o00000_o</P001Ol0003oaL<0olG30?o5``3o000000CoaL<000?o
0000ojVn0?l000001OnY_P000ol0003oS;L0o`000005ohbg00;o00001Omb/0001?l0003oL[00og:`
0?l00003oeVY00;o000000?oFJT0o`000?m2XP000_m2XP000ol0003o@Z80od:R0002od:R0003o`00
0?l/VP3o000000Co;9X000?o0000oaVC0?l000001OlIT`02o`0000Go1h`00_l00003o`252@;o0000
0_l0Q@T01?l0003o07hHo`1n6?l0OQP2o`0000;o07hH00?o0000o`1g9Ol000001?l0MbD00ol0003o
070`o`000004o`1`<0;o0000;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oo
oooo000[ooooo`03o`000?oooooo000000?ombD000?o0000ooLU0?og9@000oog9@000ol0003okd40
o`000006onm10003o`000?oXF`3o000000Goj5/00_l00006on5c00?o00001?oJRP02o`0000;ofXX0
00Go0000om>N0?oCWP3odih0o`000004om>N0003o`000?o</P3o000000Goc;8000?o0000olG30?l0
00001Oo5``02o`0000KoZKh00ol00003ohbg00;o00000_n<]`001Ol0003oL[00og:`0?mb/03o0000
00CoL[0000?o0000oeVY0?l000001?mIZ@000ol0003o@Z80o`000005od:R00;o00001Ol/VP03o`00
00?o6I<00_l000000olIT`3o0000o`N<0002o`N<00;o00000_l7S0000ol0003o08D9o`000005o`25
2@03o`000?l0OQSo000000Co07hH0_l00005o`1g9@;o00000ol0L302o`0002kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0?ooooo`00;?ooool01Ol0003oooooo`000?og9@3o0000
00KombD00_l00007onm100;o00001OoXF`001?l0003oj5/0onQK0?l00003on5c00;o00000ooQL`02
o`000003omZ:0?l0003ofXX000CofXX000?o0000om>N0?l000001OoCWP02o`0000Koc;800ol00003
olG300;o00000_o5``001?l0003oZKh0ojVn0?nY_P02o`0000?oZKh000?o0000ohbg0?l000001On<
]`000ol0003oL[00o`000005og:`00;o00001OmIZ@03o`0000?o@Z800_l000000om2XP3o0000obbJ
0002obbJ00;o00000ol/VP000ol0003o6I<0o`000004oaVC0003o`000?l7S03o000000Co1h`00_l0
0006o`252@;o00000ol0OQP2o`000003o`1n6?l0003o07LU00;o07LU0_l00002o`1g9@03o`000?l0
L33o0000037ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`00;Oooool4
o`0000GombD000Co0000ooLU0?og9@3o00001?o_@@02o`0000;okd4000Go0000onQK0?oXF`3oj5/0
o`000004onQK0003o`000?oQL`3o000000KohG<00_l00006omZ:00;o00001OoCWP001?l0003odih0
om>N0?l00003olbb00;o00000oo</P000ol0003oaL<0o`000005olG30003o`000?nY_P3o000000Go
ZKh00_l00006ohbg00?o00000omb/002o`000003og:`0?l0003oFJT000;oFJT00_l00003oeVY0003
o`000?m2XP3o000000Co@Z8000?o0000obbJ0?l000001Ol/VP02o`0000Go6I<00ol00003o`N<0004
o`000?l7S03o1h`0o`0000?o08D90_l00002o`252@03o`000?l0OQSo000000Co07hH00?o0000o`1g
9Ol000001?l0MbD2o`0003?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?oooo
o`00;oooool00ol0003oooooo`000003ooLU0003o`000?og9@3ombD000;ombD000Co0000onm10?l0
003o00001Oo_@@000ol0003oj5/0o`000005onQK00?o00001OoQL`001?l0003ohG<0on5c0?l00003
omZ:00;o00000_oJRP001Ol0003odih0om>N0?oCWP3o000000Codih000?o0000olbb0?l000001Oo<
/P02o`0000KoaL<00_l00005ojVn0004o`000?nY_P3oZKh0o`0000?oS;L00_l00003ohbg0003o`00
0?mb/03o000000CoL[0000?o0000oeVY0?l000001OmIZ@02o`0000Go@Z800ol00003obbJ00;o0000
00?o;9X0o`000?lIT`000_lIT`02o`0000?o6I<000?o0000o`N<0?l000001?l7S0000ol0003o08D9
o`000004o`252@;o00001Ol0OQP2o`0000?o07LU0_l0000fooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03oooool0033ooooo00Go0000ooooool0003ombD0o`000005ooLU00?o0000
1_o_@@03o`0000?oj5/00_l00003onQK0005o`000?oQL`3ohG<0on5c0?l000001?oQL`000ol0003o
fXX0o`000005omZ:0003o`000?oCWP3o000000Godih00_l00005olbb0004o`000?o</P3oc;80o`00
00?oaL<00_l00002olG30005o`000?nY_P3oZKh0ojVn0?l000001?nY_P000ol0003oS;L0o`000005
ohbg00;o00001Omb/002o`0000GoFJT000Co0000oeVY0?mIZ@3o00000om2XP001ol0003o@Z80od:R
0?m2XP3o0000obbJ0?l000001?l/VP000ol0003o6I<0o`000005oaVC00;o00001Ol7S002o`0000?o
08D90_l000000ol0Q@Wo0000o`1n6002o`1n60;o00000_l0OQP00ol0003o07LUo`00000hooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool0037ooooo00?o0000ooooool00000
1Oog9@001Ol0003ombD0ooLU0?og9@3o000000?okd400_l00003onm10003o`000?oXF`3o000000Ko
j5/000?o0000on5c0?l000001OoQL`02o`0000KofXX00ol00003om>N00;o00000_oCWP001Ol0003o
c;80olbb0?o</P3o000000Coc;8000?o0000olG30?l000001Oo5``000ol0003oZKh0o`000005ojVn
00;o00001On<]`000ol0003oS;L0o`000003og:`00;o00000_mb/0001Ol0003oFJT0oeVY0?mIZ@3o
000000CoFJT000?o0000od:R0?l000001?m2XP02o`0000Go;9X00_l00005oaVC0003o`000?lIT`3o
000000?o1h`00_l00002o`N<0003o`000?l0Q@Wo000000Co08D900?o0000o`1n6?l000001?l0OQP2
o`0003[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`00<_ooool3o`00
00?ombD000?o0000ooLU0?og9@000oog9@000ol0003okd40o`000005onm100?o00001_oXF`02o`00
00GohG<000Co0000on5c0?oQL`3o00000ooJRP02o`0000?ofXX000?o0000om>N0?l000001OoCWP00
0ol0003oc;80o`000005olbb00;o00001_o5``03o`0000?oZKh00_l00002ojVn0005o`000?n<]`3o
S;L0ohbg0?l000000on<]`000ol0003oL[00o`000005og:`0003o`000?mIZ@3o000000GoFJT00_l0
0004od:R0004o`000?m2XP3o@Z80o`0000?o;9X000Co0000obbJ0?l/VP3o00000olIT`001ol0003o
6I<0oaVC0?lIT`3o0000o`N<0?l000001?l7S002o`0000Go08D90ol00003o`1n6003o`000?oooooo
oooo03_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`00=?ooool2o`00
0003ooLU0?l0003ombD000GombD00_l00005onm10005o`000?o_@@3okd40onm10?l000000ooXF`02
o`0000;oj5/000Go0000on5c0?oQL`3ohG<0o`000004on5c0003o`000?oJRP3o000000GofXX00_l0
0006om>N00;o00001Oo</P001?l0003oc;80olbb0?l00003olG300;o00000oo5``000ol0003oZKh0
o`000005ojVn0003o`000?n<]`3o000000CoS;L00_l00006og:`00?o00000omIZ@02o`000003oeVY
0?l0003o@Z8000;o@Z8000?o0000od:R0?m2XP000_m2XP000ol0003o;9X0o`000004obbJ0003o`00
0?lIT`3o000000Co6I<00_l00004o`N<0004o`000?l7S03o1h`0o`0000?o08D900Oo0000o`252Ol0
Q@Wo08D9o`000?l0OQSo000003oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>
ooooo`00=Oooool3o`0000CombD00_l00002ooLU0005o`000?o_@@3okd40onm10?l000001Oo_@@00
0ol0003oj5/0o`000005onQK0003o`000?oQL`3o000000GohG<00_l00005omZ:0004o`000?oJRP3o
fXX0o`0000?odih00_l00002om>N0005o`000?o</P3oc;80olbb0?l000001?o</P000ol0003oaL<0
o`000005olG300;o00001_nY_P03o`0000?oS;L000Co0000ohbg0?n<]`3o00000omb/002o`0000?o
L[0000?o0000oeVY0?l000001?mIZ@000ol0003o@Z80o`000005od:R00;o00001Ol/VP02o`0000?o
6I<00_l000000olIT`3o0000o`N<0002o`N<0003o`000?l7S03o1h`000;o1h`000?o0000o`252Ol0
00001?l0Q@T2o`00043ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`00
=_ooool01_l0003oooooo`000?l0003ombD0o`0000GombD000?o0000onm10?l000001_o_@@02o`00
00Koj5/00ol00003on5c00;o00000_oQL`001Ol0003ofXX0omZ:0?oJRP3o000000CofXX000?o0000
om>N0?l000001OoCWP000ol0003oc;80o`000005olbb00;o00001Oo5``001?l0003oaL<0olG30?l0
0003ojVn00;o00000onY_P000ol0003oS;L0o`000004ohbg0003o`000?mb/03o000000GoL[000_l0
0005oeVY00?o00000om2XP02o`000003od:R0?l0003o;9X000;o;9X00_l00002obbJ0003o`000?lI
T`3o000000Co6I<000?o0000o`N<0?l000001Ol7S002o`0000Co08D900?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo000gooooo`;o000000?ooooo
o`000?og9@001Oog9@03o`0000Gokd4000Co0000onm10?o_@@3o00000ooXF`02o`0000?oj5/000?o
0000on5c0?l000001OoQL`000ol0003ofXX0o`000005omZ:00;o00001_oCWP03o`0000?oc;800_l0
0002olbb0005o`000?o5``3oaL<0olG30?l000001?o5``000ol0003oZKh0o`000005ojVn00;o0000
1On<]`03o`0000?oL[000_l000000omb/03o0000oeVY0002oeVY00;o00000omIZ@000ol0003o@Z80
o`000004od:R0003o`000?l/VP3o000000Co;9X00_l00005oaVC00?o00000ol7S002o`000003o`N<
0?l0003o08D900;o08D900?o0000ooooooooool0@oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00kooooo000iooooo`03o`000?oooooo000000?ombD00_l00003ooLU0005o`000?o_
@@3okd40onm10?l000001?o_@@000ol0003oj5/0o`000005onQK00;o00001_oQL`03o`0000?ofXX0
0_l00002omZ:0004o`000?oCWP3odih0om>N00;o00000ooCWP000ol0003oc;80o`000005olbb0003
o`000?o5``3o000000GoaL<00_l00005ojVn0003o`000?nY_P3o000000?oS;L00_l00003ohbg0003
o`000?mb/03o000000CoL[0000?o0000oeVY0?l000001OmIZ@02o`0000Go@Z800_l00003obbJ00;o
00000_l/VP001Ol0003o6I<0oaVC0?lIT`3o000000?o6I<000?o0000o`N<0?l000001?l7S0000ol0
003o08D9o`000016ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool003[o
oooo00Go0000ooooool0003ombD0o`000006ooLU0003o`000?o_@@3o000000Gokd400_l00005onQK
0004o`000?oXF`3oj5/0o`0000?ohG<00_l00003on5c0003o`000?oJRP3o000000GofXX000?o0000
om>N0?l000001OoCWP02o`0000Koc;800ol00003olG300;o00000_o5``001Ol0003oZKh0ojVn0?nY
_P3o000000?oZKh000?o0000ohbg0?l000001On<]`02o`0000GoL[000ol00003oeVY00;o000000?o
FJT0o`000?m2XP000_m2XP02o`0000;o@Z8000?o0000obbJ0?l000001Ol/VP000ol0003o6I<0o`00
0004oaVC00;o00001Ol7S002o`0004Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0=ooooo`00>oooool01?l0003oooooo`000?l00006ooLU00?o00000oo_@@02o`0000;okd4000Go
0000onQK0?oXF`3oj5/0o`000004onQK0003o`000?oQL`3o000000GohG<00_l00006omZ:00?o0000
0ooCWP02o`0000;odih000Co0000olbb0?o</P3oc;800_l00003olbb0003o`000?o5``3o000000Go
aL<000?o0000ojVn0?l000001?nY_P02o`0000GoS;L000?o0000ohbg0?l000000omb/002o`0000?o
L[0000?o0000oeVY0?l000001?mIZ@000ol0003o@Z80o`000004od:R00;o00001_l/VP02o`0000?o
6I<00_l000000olIT`3o0000o`N<0002o`N<00;o0000Boooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00gooooo000looooo`;o000000?oooooo`000?og9@000_og9@02o`0000?ombD0
00?o0000onm10?l000001Oo_@@000ol0003oj5/0o`000005onQK00;o00001OoQL`001?l0003ohG<0
on5c0?l00003omZ:00;o00000ooJRP000ol0003odih0o`000005om>N0003o`000?o</P3o000000Go
c;800_l00006olG300;o00000onY_P02o`0000;oZKh000Go0000ohbg0?n<]`3oS;L0o`000003ohbg
0003o`000?mb/03o000000GoL[000_l00005oeVY00?o00000om2XP001?l0003o@Z80od:R0?l00003
obbJ00;o00000_l/VP000ol0003o6I<0o`000004oaVC0003o`000?l7S03o000004kooooo00Go0000
ooooooooooooooooo`00000?ooooo`00?_ooool01Ol0003oooooo`000?og9@3o000000GombD00_l0
0006onm100?o00000ooXF`02o`0000;oj5/000Go0000on5c0?oQL`3ohG<0o`000004on5c0003o`00
0?oJRP3o000000GofXX00_l00006om>N00?o00000oo</P02o`0000;oc;8000Co0000olG30?o5``3o
aL<00_l00002olG30003o`000?nY_P3o000000GoZKh000?o0000ohbg0?l000001?n<]`02o`0000Go
L[0000?o0000og:`0?l000000omIZ@02o`0000?oFJT000?o0000od:R0?l000001?m2XP000ol0003o
;9X0o`000004obbJ00;o00001OlIT`02o`0004oooooo00Go0000ooooooooooooooooo`00000?oooo
o`00?oooool00ol0003oooooo`000005ooLU0004o`000?og9@3ombD0o`0000?okd400_l00003onm1
0003o`000?oXF`3o000000Goj5/000?o0000on5c0?l000001OoQL`02o`0000GofXX000Co0000omZ:
0?oJRP3o00000ooCWP02o`0000?odih000?o0000olbb0?l000001Oo</P000ol0003oaL<0o`000004
olG300;o00001_nY_P03o`0000?oS;L000Co0000ohbg0?n<]`3o00000omb/0001ol0003oL[00og:`
0?mb/03o0000oeVY0?l000001OmIZ@02o`0000Go@Z800_l00003obbJ00;o000000?o;9X0o`000?lI
T`000_lIT`02o`0005;ooooo00Co0000oooooooooooo00003oooool0043ooooo00?o0000ooooool0
00000oog9@000ol0003ombD0ooLU0002ooLU0003o`000?o_@@3o000000Gokd400ol00005onQK00?o
00001?oQL`001?l0003ohG<0on5c0?l00003omZ:0003o`000?oJRP3ofXX000;ofXX000?o0000om>N
0?l000001OoCWP02o`0000Koc;800ol00003olG30004o`000?o5``3oaL<0o`0000?oZKh00_l00003
ojVn0003o`000?n<]`3o000000CoS;L000?o0000og:`0?l000001?mb/003o`0000?oFJT00_l00000
0omIZ@3o0000od:R0002od:R00;o00000_m2XP000ol0003o;9X0o`000004obbJ0003o`000?lIT`3o
000005Gooooo00?o0000ooooool000003oooool0047ooooo0ol000000oog9@3o0000ooLU0004ooLU
00;o00001Oo_@@001Ol0003okd40onm10?o_@@3o000000?oj5/000Co0000onQK0?oXF`3oj5/00_l0
00000ooQL`3o0000on5c0003on5c0003o`000?oJRP3o000000GofXX00_l00005om>N0004o`000?oC
WP3odih0o`0000?oc;800_l00003olbb0003o`000?o5``3o000000CoaL<000?o0000ojVn0?l00000
1OnY_P02o`0000GoS;L00ol00003og:`0007o`000?mb/03oL[00og:`0?l0003oFJT0o`000004oeVY
0003o`000?m2XP3o000000Co@Z800_l00005obbJ00;o0000E_ooool01?l0003oooooooooool0000>
ooooo`00@oooool3o`0000?ombD00_l00002ooLU0005o`000?o_@@3okd40onm10?l000001Oo_@@00
0ol0003oj5/0o`000005onQK00;o00001OoQL`03o`0000?ofXX00_l00002omZ:0005o`000?oCWP3o
dih0om>N0?l000001?oCWP000ol0003oc;80o`000005olbb00;o00001Oo5``03o`0000?oZKh00_l0
00000onY_P3o0000ohbg0002ohbg00;o00000on<]`000ol0003oL[00o`000004og:`00;o00001OmI
Z@03o`0000?o@Z8000Co0000od:R0?m2XP3o00000ol/VP000ol0003oooooooooo`1Gooooo`03o`00
0?oooooo000000kooooo0014ooooo`05o`000?oooooo0000ooLU0?l000001Oog9@000ol0003okd40
o`000006onm100;o00001OoXF`001?l0003oj5/0onQK0?l00003on5c0007o`000?oQL`3ohG<0on5c
0?l0003ofXX0o`000005omZ:0003o`000?oCWP3o000000Godih00_l00005olbb0003o`000?o</P3o
000000?oaL<00_l00003olG30003o`000?nY_P3o000000CoZKh000?o0000ohbg0?l000001On<]`02
o`0000CoL[0000?o0000og:`0?l000000omIZ@02o`0000?oFJT000?o0000od:R0?l000001?m2XP00
0ol0003o;9X0o`00001Kooooo`;o00003_ooool004Gooooo00?o0000ooooool000001_og9@03o`00
00Cokd400_l00002onm10005o`000?oXF`3oj5/0onQK0?l000001?oXF`000ol0003ohG<0o`000005
on5c0003o`000?oJRP3ofXX000CofXX00ol00003om>N00;o00000_oCWP001Ol0003oc;80olbb0?o<
/P3o000000?oc;8000?o0000olG30?l000001Oo5``02o`0000GoZKh00ol00003ohbg00;o000000?o
S;L0o`000?mb/0000_mb/0001ol0003oL[00og:`0?mb/03o0000oeVY0?l000001OmIZ@02o`0000Go
@Z800_l0001Kooooo`?o00003_ooool004Kooooo0ol00003ooLU00;o00000oog9@02o`000003onm1
0?l0003okd4000Cokd4000?o0000onQK0?l000001OoXF`02o`0000GohG<000?o0000on5c0?l00000
0ooJRP02o`0000?ofXX000?o0000om>N0?l000001OoCWP000ol0003oc;80o`000004olbb00?o0000
0oo5``02o`0000;oaL<000Go0000ojVn0?nY_P3oZKh0o`000003ojVn0003o`000?n<]`3o000000Co
S;L000?o0000og:`0?l000001?mb/003o`0000?oFJT00_l000000omIZ@3o0000od:R0002od:R00;o
0000FOooool4o`00017ooooo0018ooooo`;o000000?ombD0o`000?og9@001Oog9@02o`0000Kokd40
0ol00003onQK00;o00000_oXF`001Ol0003ohG<0on5c0?oQL`3o000000?ohG<000?o0000omZ:0?l0
00001OoJRP02o`0000Kodih00ol00003olbb0007o`000?o</P3oc;80olbb0?l0003oaL<0o`000005
olG30003o`000?nY_P3o000000CoZKh00_l00005ohbg00?o00000omb/0001ol0003oL[00og:`0?mb
/03o0000oeVY0?l000001?mIZ@000ol0003o@Z80o`00001Gooooo`Co00005Oooool004Wooooo0ol0
0005ooLU0004o`000?og9@3ombD0o`0000?okd400_l00003onm10003o`000?oXF`3o000000Goj5/0
00?o0000on5c0?l000001?oQL`03o`0000?ofXX00_l00002omZ:0004o`000?oCWP3odih0om>N00;o
00000ooCWP000ol0003oc;80o`000004olbb00;o00001_o5``02o`0000?oZKh00_l000000onY_P3o
0000ohbg0002ohbg00;o00000on<]`000ol0003oL[00o`000004og:`00;o00001OmIZ@02o`0005Go
oooo0ol0000Iooooo`00B_ooool00ol0003oooooo`000003ooLU0003o`000?og9@3ombD000;ombD0
00?o0000onm10?l000001Oo_@@02o`0000Koj5/00ol00003on5c0007o`000?oQL`3ohG<0on5c0?l0
003ofXX0o`000005omZ:0003o`000?oCWP3o000000Godih00_l00004olbb0004o`000?o</P3oc;80
o`0000?oaL<00_l00002olG30003o`000?nY_P3o000000CoZKh000?o0000ohbg0?l000001On<]`02
o`0000?oL[000_l000000omb/03o0000oeVY0002oeVY00;o0000Doooool4o`0001cooooo001;oooo
o`?o000000?ombD0o`000?og9@001?og9@03o`0000?okd400_l00002onm10004o`000?oXF`3oj5/0
onQK00;o00000ooXF`000ol0003ohG<0o`000004on5c00;o00001_oJRP03o`0000?odih00_l00000
0ooCWP3o0000olbb0002olbb0003o`000?o</P3oc;8000;oc;8000?o0000olG30?l000001?o5``02
o`0000GoZKh00ol00003ohbg00;o00000_n<]`000ol0003oL[00o`000004og:`0003o`000?mIZ@3o
0000057ooooo1?l0000Pooooo`00COooool3o`0000?ombD00_l00003ooLU0003o`000?o_@@3o0000
00Gokd4000?o0000onQK0?l000001OoXF`02o`0000CohG<000Co0000on5c0?oQL`3o00000ooJRP02
o`0000?ofXX000?o0000om>N0?l000001?oCWP000ol0003oc;80o`000005olbb00;o00000oo5``02
o`0000;oaL<000Go0000ojVn0?nY_P3oZKh0o`000003ojVn0003o`000?n<]`3o000000CoS;L00_l0
0005og:`00;o0000C_ooool4o`0002Cooooo001>ooooo`05o`000?oooooo0000ooLU0?l000001Oog
9@02o`0000Kokd400ol00003onQK00;o000000?oj5/0o`000?oQL`000_oQL`000ol0003ohG<0on5c
0002on5c0003o`000?oJRP3o000000GofXX00_l00005om>N00?o00000oo</P02o`0000;oc;8000?o
0000olG30?l000001Oo5``000ol0003oZKh0o`000004ojVn00;o00001?n<]`001?l0003oS;L0ohbg
0?l00003og:`0003o`000?oooooooooo04[ooooo1?l0000Xooooo`00Coooool00ol0003oooooo`00
0005ooLU0004o`000?og9@3ombD0o`0000?okd400_l00003onm10003o`000?oXF`3o000000Coj5/0
00?o0000on5c0?l000001OoQL`03o`0000?ofXX00_l00002omZ:0005o`000?oCWP3odih0om>N0?l0
00000ooCWP000ol0003oc;80o`000005olbb0003o`000?o5``3oaL<000CoaL<00_l00003ojVn00;o
000000?oZKh0o`000?n<]`000_n<]`000ol0003oS;L0ohbg0002ohbg0003o`000?mb/03o000004Wo
oooo1?l0000/ooooo`00D?ooool3o`0000?ombD000?o0000ooLU0?og9@000_og9@000ol0003okd40
o`000005onm100;o00001OoXF`03o`0000?ohG<00_l00003on5c0003o`000?oJRP3o000000GofXX0
00?o0000om>N0?l000001?oCWP02o`0000Goc;8000?o0000olbb0?l000000oo5``02o`0000;oaL<0
00?o0000ojVn0?l000001?nY_P000ol0003oS;L0o`000005ohbg00;o0000A_ooool4o`00033ooooo
001Booooo`;o000000?ombD0o`000?og9@001?og9@03o`0000?okd400_l00002onm10005o`000?oX
F`3oj5/0onQK0?l000000ooXF`000ol0003ohG<0o`000005on5c00;o00001_oJRP02o`0000?odih0
0_l00002om>N0005o`000?o</P3oc;80olbb0?l000000oo</P000ol0003oaL<0o`000004olG300;o
00001OnY_P03o`0000?oS;L00_l00015ooooo`?o0000=?ooool005?ooooo0ol00003ooLU00;o0000
0oog9@000ol0003okd40o`000005onm10003o`000?oXF`3o000000Coj5/00_l00005on5c0004o`00
0?oQL`3ohG<0o`0000?ofXX00_l00002omZ:0003o`000?oCWP3o000000Godih000?o0000olbb0?l0
00001?o</P03o`0000?oaL<000Co0000olG30?o5``3o00000onY_P001ol0003oZKh0ojVn0?nY_P3o
0000ohbg0?l00000@oooool4o`0003Oooooo001Dooooo`05o`000?oooooo0000ooLU0?l000001Oog
9@02o`0000Kokd400ol00003onQK0004o`000?oXF`3oj5/0o`0000?ohG<000?o0000on5c0?oQL`00
0_oQL`000ol0003ofXX0o`000004omZ:00;o00001_oCWP02o`0000?oc;800_l00003olbb0003o`00
0?o5``3o000000CoaL<000?o0000ojVn0?l000001?nY_P02o`00043ooooo1?l0000kooooo`00EOoo
ool3o`0000GombD000Co0000ooLU0?og9@3o00000oo_@@02o`0000?okd4000?o0000onQK0?l00000
1?oXF`000ol0003ohG<0o`000005on5c00?o00000ooJRP001?l0003ofXX0omZ:0?l00003om>N00;o
00000_oCWP000ol0003oc;80o`000005olbb00;o00001Oo5``02o`0000?oZKh00_l0000nooooo`Co
0000?oooool005Oooooo0_l00003ooLU0003o`000?og9@3ombD000;ombD000?o0000onm10?l00000
1Oo_@@02o`0000Goj5/00ol00003on5c00;o00000ooQL`000ol0003ofXX0o`000004omZ:0003o`00
0?oCWP3o000000Codih00ol00003olbb00;o000000?oc;80o`000?o5``000_o5``02o`0000;oaL<0
00?o0000ojVn0?l00000??ooool4o`0004?ooooo001Hooooo`;o000000?ombD0o`000?og9@001?og
9@03o`0000?okd400_l000000oo_@@3o0000onQK0002onQK00;o00000ooXF`000ol0003ohG<0o`00
0005on5c00;o00001OoJRP03o`0000?odih000Oo0000om>N0?oCWP3odih0o`000?o</P3o000000Co
c;8000?o0000olG30?l000001?o5``02o`0003Wooooo1?l00017ooooo`00FOooool3o`0000?ombD0
0_l00003ooLU0003o`000?o_@@3o000000Cokd4000?o0000onQK0?l000001OoXF`03o`0000?ohG<0
0_l000000ooQL`3o0000omZ:0002omZ:00;o00000ooJRP000ol0003odih0o`000004om>N00;o0000
1Oo</P03o`0000?oaL<000?o0000ooooooooool0=Oooool4o`0004_ooooo001Jooooo`?o000000?o
mbD0o`000?og9@001?og9@02o`0000Gokd400ol00003onQK00;o00000ooXF`000ol0003ohG<0o`00
0004on5c0003o`000?oJRP3o000000GofXX00_l00003om>N00;o00000_oCWP001Ol0003oc;80olbb
0?o</P3o000000?oc;8000?o0000olG30?l00000=Oooool3o`0004oooooo001Looooo`;o00001Oog
9@001?l0003ombD0ooLU0?l00003onm10007o`000?o_@@3okd40onm10?l0003oj5/0o`000005onQK
00;o00001OoQL`03o`0000?ofXX00_l00002omZ:0003o`000?oCWP3o000000Godih000?o0000olbb
0?l000001?o</P02o`0003;ooooo1?l0001Booooo`00GOooool2o`0000?ombD000?o0000ooLU0?og
9@000_og9@000ol0003okd40o`000004onm100?o00000ooXF`02o`0000;oj5/000Go0000on5c0?oQ
L`3ohG<0o`000003on5c0003o`000?oJRP3o000000CofXX00_l00006om>N00;o00000oo</P02o`00
033ooooo1?l0001Fooooo`00G_ooool2o`000003ooLU0?l0003ombD000CombD00ol00003onm10007
o`000?o_@@3okd40onm10?l0003oj5/0o`000005onQK0003o`000?oQL`3o000000CohG<00ol00003
omZ:0004o`000?oJRP3ofXX0o`0000?odih00_l00002om>N0003o`000?o</P3o000002kooooo1?l0
001Jooooo`00H?ooool2o`0000?ombD00_l00003ooLU0003o`000?o_@@3o000000Cokd400_l00006
onQK00;o00000ooQL`02o`0000?ohG<000?o0000omZ:0?l000001?oJRP000ol0003odih0o`000004
om>N00;o0000:oooool4o`0005kooooo001Qooooo`;o000000?ombD0o`000?og9@001?og9@02o`00
00Cokd4000Co0000onm10?o_@@3o00000ooXF`02o`0000;oj5/000?o0000on5c0?l000001OoQL`02
o`0000GofXX00_l00003om>N00;o0000:Oooool4o`0006;ooooo001Rooooo`?o00000oog9@02o`00
0003ooLU0?l0003okd4000;okd4000?o0000onm10?o_@@000_o_@@000ol0003oj5/0o`000004onQK
00?o00000ooQL`02o`000003on5c0?l0003ofXX000;ofXX00_l00002omZ:0003o`000?oCWP3o0000
02Sooooo0ol0001Vooooo`00Hoooool3o`000003ooLU0?l0003ombD000?ombD000?o0000onm10?l0
00001Oo_@@03o`0000?oj5/000Oo0000onQK0?oXF`3oj5/0o`000?oQL`3o000000CohG<000?o0000
omZ:0?l000001?oJRP02o`0002Gooooo1?l0001Yooooo`00IOooool2o`0000GombD00ol00003onm1
00;o00000oo_@@000ol0003oj5/0o`000004onQK00;o00001OoQL`03o`0000?ofXX000?o0000oooo
ooooool08Oooool4o`0006gooooo001Vooooo`;o00000oog9@001ol0003ombD0ooLU0?og9@3o0000
onm10?l000001Oo_@@02o`0000?oj5/00_l00002onQK0005o`000?oQL`3ohG<0on5c0?l000000ooQ
L`000ol0003ofXX0o`00000Pooooo`Co0000LOooool006Oooooo0_l000000oog9@3o0000ooLU0003
ooLU00?o00000oo_@@02o`0000;okd4000?o0000onQK0?l000001OoXF`000ol0003ohG<0o`000004
on5c00;o00007Oooool4o`0007Gooooo001Xooooo`?o00000oog9@001ol0003ombD0ooLU0?og9@3o
0000onm10?l000001?o_@@02o`0000Koj5/00_l00003on5c00;o00006oooool4o`0007Wooooo001Z
ooooo`;o000000?ombD0o`000?og9@000oog9@03o`0000?okd4000Co0000onm10?o_@@3o00000ooX
F`02o`0000;oj5/000?o0000on5c0?l000006Oooool4o`0007gooooo001[ooooo`;o00000oog9@02
o`0000?ombD000?o0000onm10?l000001?o_@@000ol0003oj5/0o`000004onQK00;o00005oooool3
o`00087ooooo001/ooooo`;o000000?ombD0o`000?og9@001?og9@02o`0000Gokd400ol00003onQK
0003o`000?oooooooooo01?ooooo1?l00024ooooo`00KOooool3o`0000?ombD00_l000000oog9@3o
0000onm10002onm100;o00000oo_@@000ol0003oj5/0o`00000Booooo`Co0000R?ooool006oooooo
0_l000000oog9@3o0000ooLU0003ooLU0003o`000?o_@@3o000000Gokd400_l0000?ooooo`Co0000
S?ooool0073ooooo0_l00005ooLU00?o00000oo_@@02o`0000gooooo1?l0002@ooooo`00LOooool2
o`0000?ombD000Oo0000ooLU0?og9@3ombD0o`000?o_@@3o000000_ooooo1?l0002Dooooo`00L_oo
ool2o`000003ooLU0?l0003ombD000?ombD00_l00008ooooo`Co0000V?ooool007Cooooo0_l00003
ooLU0003o`000?oooooooooo00Gooooo0ol0002Looooo`00MOooool2o`000003ooLU0?l0003ooooo
00?ooooo1?l0002Oooooo`00M_ooool2o`000003ooooool0003o000000;o0000Xoooool007Oooooo
0_l0002Wooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00:?ooool3o`0008[o
oooo00?o0000ooooooooool0:oooool3o`0001Gooooo00?o0000ooooooooool08_ooool002Wooooo
00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool08Oooool002?ooooo0ol00003ooooo`?o00001?ooool2o`0000;ooooo1Ol0
0002ooooo`?o00000oooool4o`000003ooooool0003o000000?o00001oooool3o`0000Cooooo1?l0
0003ooooo`;o00000_ooool6o`0000Kooooo1?l00002ooooo`Go000000?oooooo`000?l000000ol0
00000ooooooo0000o`000003o`0000;ooooo0ol00002ooooo`?o00001?ooool3o`0000;ooooo0ol0
00001?oooooo0000o`000?ooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000000oooool4o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo
1Ol00002ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000;o
oooo2_l00005ooooo`03o`000?oooooooooo023ooooo000Rooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000003?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo023ooooo000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
1?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool5
o`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Ko0000oooooooooooo0000oooo
ool00005ooooo`Go00002?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo0000ooooool0
00000_ooool3o`0000?ooooo00?o0000ooooool000000_ooool5o`0000?ooooo00Co0000oooooooo
oooooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooooooo`0000;ooooo0ol00005ooooo`03o`000?oooooooooo023o
oooo000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`?o00000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00003oooo
o`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00Co0000oooo
oooooooo00001Oooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0
8?ooool002;ooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000;ooooo1?l00002ooooo`?o
00001?ooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooo
oooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002Oooool01Ol0003oooooooooool0003o
oooo00?o00001?ooool4o`0000;ooooo1?l00002ooooo`?o00000_ooool2o`000003ooooool0003o
000000;ooooo0ol00002ooooo`Co00000oooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooo
oooo00;ooooo1_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_ooool3
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1?l00003ooooo`Wo00000oooool3
o`0000?ooooo1?l00004ooooo`03o`000?oooooooooo023ooooo000Rooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`008oooool3o`0000Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`?o00002Oooool4o`0000Wooooo00?o
0000ooooooooool00_ooool2o`0000[ooooo1?l00004ooooo`03o`000?oooooooooo00Cooooo0_l0
0004ooooo`;o0000;_ooool00ol0003oooooooooo`0Hooooo`?o00005_ooool00ol0003ooooooooo
o`02ooooo`;o00002oooool00ol0003oooooooooo`0Rooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0627967, 0.0203262, \
0.00371063, 0.00371063}},
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          
          RowBox[{\(ComponentNumber \[Rule] 1\), 
            ",", \(Energy \[Rule] 100.`\), 
            ",", \(Offset \[Rule] 100.04810680830577`\), ",", 
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(CompiledFunction[
                  If[#1 == 0 && #2 == 0, 
                    100.0469485346684`, \(\(100.06219875297163`\)\(\
\[InvisibleSpace]\)\) + 
                      0.019997325439219685`\ Cos[
                          ArcTan[#1, #2]]\ \@\(#1\^2 + #2\^2\) - 
                      9.989843229165515`*^-7\ Cos[
                          2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                      0.015249444251986261`\ \((\(-1\) + 
                            0.327788096577263`\ \((#1\^2 + #2\^2)\))\) - 
                      5.017900174569917`*^-6\ Cos[
                          ArcTan[#1, #2]]\ \((\(-0.8096765978799968`\)\ \
\@\(#1\^2 + #2\^2\) + 0.1990517631466786`\ \((#1\^2 + #2\^2)\)\^\(3/2\))\) + 
                      1.3932523519034754`*^-9\ Cos[
                          2\ ArcTan[#1, #2]]\ \((\(-0.49168214486589445`\)\ \
\((#1\^2 + #2\^2)\) + 0.10744503625774508`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                      7.740512297711918`*^-7\ \((1 - 
                            0.9833642897317889`\ \((#1\^2 + #2\^2)\) + 
                            0.16116755438661762`\ \((#1\^2 + #2\^2)\)\^2)\) + 
                      6.880321093150056`*^-10\ Cos[
                          ArcTan[#1, #2]]\ \((1.2145148968199952`\ \@\(#1\^2 \
+ #2\^2\) - 0.7962070525867144`\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                            0.10874466427032993`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\)], "-CompiledCode-"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(CompiledFunction[
                  If[#1 == 0 && #2 == 
                        0, \(-2.1772062171105575`\), \
\(\(26.488617793446064`\)\(\[InvisibleSpace]\)\) + 
                      37.58895759251126`\ Cos[
                          ArcTan[#1, #2]]\ \@\(#1\^2 + #2\^2\) - 
                      0.0018777900763525966`\ Cos[
                          2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) + 
                      1.8761146230655825`*^-7\ Cos[
                          3\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                      28.66436889492741`\ \((\(-1\) + 
                            0.327788096577263`\ \((#1\^2 + #2\^2)\))\) - 
                      0.009432143254663461`\ Cos[
                          ArcTan[#1, #2]]\ \((\(-0.8096765978799968`\)\ \
\@\(#1\^2 + #2\^2\) + 0.1990517631466786`\ \((#1\^2 + #2\^2)\)\^\(3/2\))\) + 
                      2.61869712582059`*^-6\ Cos[
                          2\ ArcTan[#1, #2]]\ \((\(-0.49168214486589445`\)\ \
\((#1\^2 + #2\^2)\) + 0.10744503625774508`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                      0.0014549827913314297`\ \((1 - 
                            0.9833642897317889`\ \((#1\^2 + #2\^2)\) + 
                            0.16116755438661762`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                      7.686597424754487`*^-10\ Cos[
                          3\ ArcTan[#1, #2]]\ \((\(-0.2654023508622381`\)\ \
\((#1\^2 + #2\^2)\)\^\(3/2\) + 
                            0.054372332135164965`\ \((#1\^2 + #2\^2)\)\^\(5/2\
\))\) + 1.2932064806553932`*^-6\ Cos[
                          ArcTan[#1, #2]]\ \((1.2145148968199952`\ \@\(#1\^2 \
+ #2\^2\) - 0.7962070525867144`\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                            0.10874466427032993`\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) - 
                      5.527141254571457`*^-10\ Cos[
                          2\ ArcTan[#1, #2]]\ \((0.9833642897317889`\ \
\((#1\^2 + #2\^2)\) - 0.5372251812887254`\ \((#1\^2 + #2\^2)\)\^2 + 
                            0.06603600735300239`\ \((#1\^2 + #2\^2)\)\^3)\) + 
                      1.3283788039301167`*^-7\ \((\(-1\) + 
                            1.9667285794635778`\ \((#1\^2 + #2\^2)\) - 
                            0.8058377719330881`\ \((#1\^2 + #2\^2)\)\^2 + 
                            0.08804800980400318`\ \((#1\^2 + #2\^2)\)\^3)\)], 
                  "-CompiledCode-"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {100.02728468406887`, 
                100.11238081006073`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          SurfaceGraphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          SurfaceGraphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          SurfaceGraphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(PlotDomain \[Rule] {{\(-0.5`\), \(-0.1`\)}, {\(-0.2`\), 
                  0.2`}}\), 
            ",", \(RayBoundary \[Rule] {{\(-1.7458610351843245`\), 
                  1.7470806113397281`}, {\(-1.746199350250952`\), 
                  1.746199350250952`}}\), 
            ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
            ",", \(ResidualFitError \[Rule] 1.9653737448513654`*^-10\), 
            ",", \(Source \[Rule] 1\), ",", \(SpatialScale \[Rule] 1\), 
            ",", \(SurfaceNumber \[Rule] 1\), ",", \(WaveFrontID \[Rule] 1\), 
            ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-3.3559565891182483`\), 
                      3.3559565891182483`}, {\(-3.355456639108251`\), 
                      3.355456639108251`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
            ",", \(WaveTilt \[Rule] WaveTilt\)}], "}"}], ",", 
        RowBox[{"{", 
          
          RowBox[{\(ComponentNumber \[Rule] 1\), 
            ",", \(Energy \[Rule] 100.`\), 
            ",", \(Offset \[Rule] 100.04856187242319`\), ",", 
            RowBox[{"OpticalLengthFunction", "\[Rule]", 
              
              TagBox[\(CompiledFunction[
                  If[#1 == 0 && #2 == 0, 
                    100.0469485345983`, \(\(100.0469485345983`\)\(\
\[InvisibleSpace]\)\) - 
                      0.020001389151312835`\ Cos[
                          ArcTan[#1, #2]]\ \@\(#1\^2 + #2\^2\)], 
                  "-CompiledCode-"]\),
                False,
                Editable->False]}], ",", 
            RowBox[{"OpticalPathDifference", "\[Rule]", 
              
              TagBox[\(CompiledFunction[
                  If[#1 == 0 && #2 == 
                        0, \(-3.0325898964823974`\), \(-3.0325898964823974`\) \
- 37.59659614898486`\ Cos[ArcTan[#1, #2]]\ \@\(#1\^2 + #2\^2\)], 
                  "-CompiledCode-"]\),
                False,
                Editable->False]}], 
            ",", \(OpticalPathRange \[Rule] {99.99693506202541`, 
                100.09696200717111`}\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"OpticalLengthFunction", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          SurfaceGraphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"WaveFrontIntensity", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          SurfaceGraphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}], ",", 
                  RowBox[{"OpticalPathDifference", "\[Rule]", 
                    RowBox[{"(", 
                      
                      TagBox[\(\[SkeletonIndicator]  
                          SurfaceGraphics  \[SkeletonIndicator]\),
                        False,
                        Editable->False], ")"}]}]}], "}"}]}], 
            ",", \(PlotDomain \[Rule] {{\(-0.5`\), \(-0.1`\)}, {\(-0.2`\), 
                  0.2`}}\), 
            ",", \(RayBoundary \[Rule] {{\(-2.5004999500099974`\), 
                  2.5004999500099983`}, {\(-2.5`\), 2.5`}}\), 
            ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
            ",", \(ResidualFitError \[Rule] 1.5756648257792838`*^-11\), 
            ",", \(Source \[Rule] 2\), ",", \(SpatialScale \[Rule] 1\), 
            ",", \(SurfaceNumber \[Rule] 1\), ",", \(WaveFrontID \[Rule] 1\), 
            ",", 
            RowBox[{"WaveFrontIntensity", "\[Rule]", 
              
              TagBox[\(InterpolatingFunction[{{\(-3.3559565891182483`\), 
                      3.3559565891182483`}, {\(-3.355456639108251`\), 
                      3.355456639108251`}}, "<>"]\),
                False,
                Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
            ",", \(WaveTilt \[Rule] WaveTilt\)}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[19]=",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindInterference[wavefront,PlotDomain->{{-.6,.1},{-.3,.3}}, \
PlotPoints->500]\
\>", "Input",
  CellLabel->"In[34]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.843407 1.37363 0.5 1.60256 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.15659 -0.0125 -12 -9 ]
[.15659 -0.0125 12 0 ]
[.29396 -0.0125 -12 -9 ]
[.29396 -0.0125 12 0 ]
[.43132 -0.0125 -12 -9 ]
[.43132 -0.0125 12 0 ]
[.56868 -0.0125 -12 -9 ]
[.56868 -0.0125 12 0 ]
[.70604 -0.0125 -12 -9 ]
[.70604 -0.0125 12 0 ]
[.84341 -0.0125 -3 -9 ]
[.84341 -0.0125 3 0 ]
[.98077 -0.0125 -9 -9 ]
[.98077 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -24 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .17949 -24 -4.5 ]
[-0.0125 .17949 0 4.5 ]
[-0.0125 .33974 -24 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66026 -18 -4.5 ]
[-0.0125 .66026 0 4.5 ]
[-0.0125 .82051 -18 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[-0.0125 .98077 -18 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -66 0 ]
[.5 1.0125 66 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-0.6)] .01923 -0.0125 0 1 Mshowa
.15659 0 m
.15659 .00625 L
s
[(-0.5)] .15659 -0.0125 0 1 Mshowa
.29396 0 m
.29396 .00625 L
s
[(-0.4)] .29396 -0.0125 0 1 Mshowa
.43132 0 m
.43132 .00625 L
s
[(-0.3)] .43132 -0.0125 0 1 Mshowa
.56868 0 m
.56868 .00625 L
s
[(-0.2)] .56868 -0.0125 0 1 Mshowa
.70604 0 m
.70604 .00625 L
s
[(-0.1)] .70604 -0.0125 0 1 Mshowa
.84341 0 m
.84341 .00625 L
s
[(0)] .84341 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(0.1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.0467 0 m
.0467 .00375 L
s
.07418 0 m
.07418 .00375 L
s
.10165 0 m
.10165 .00375 L
s
.12912 0 m
.12912 .00375 L
s
.18407 0 m
.18407 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.23901 0 m
.23901 .00375 L
s
.26648 0 m
.26648 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.3489 0 m
.3489 .00375 L
s
.37637 0 m
.37637 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45879 0 m
.45879 .00375 L
s
.48626 0 m
.48626 .00375 L
s
.51374 0 m
.51374 .00375 L
s
.54121 0 m
.54121 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62363 0 m
.62363 .00375 L
s
.6511 0 m
.6511 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.73352 0 m
.73352 .00375 L
s
.76099 0 m
.76099 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.81593 0 m
.81593 .00375 L
s
.87088 0 m
.87088 .00375 L
s
.89835 0 m
.89835 .00375 L
s
.92582 0 m
.92582 .00375 L
s
.9533 0 m
.9533 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-0.3)] -0.0125 .01923 1 0 Mshowa
0 .17949 m
.00625 .17949 L
s
[(-0.2)] -0.0125 .17949 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(-0.1)] -0.0125 .33974 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66026 m
.00625 .66026 L
s
[(0.1)] -0.0125 .66026 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(0.2)] -0.0125 .82051 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(0.3)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05128 m
.00375 .05128 L
s
0 .08333 m
.00375 .08333 L
s
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .21154 m
.00375 .21154 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .46795 m
.00375 .46795 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .59615 m
.00375 .59615 L
s
0 .62821 m
.00375 .62821 L
s
0 .69231 m
.00375 .69231 L
s
0 .72436 m
.00375 .72436 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .85256 m
.00375 .85256 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.15659 .99375 m
.15659 1 L
s
.29396 .99375 m
.29396 1 L
s
.43132 .99375 m
.43132 1 L
s
.56868 .99375 m
.56868 1 L
s
.70604 .99375 m
.70604 1 L
s
.84341 .99375 m
.84341 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.0467 .99625 m
.0467 1 L
s
.07418 .99625 m
.07418 1 L
s
.10165 .99625 m
.10165 1 L
s
.12912 .99625 m
.12912 1 L
s
.18407 .99625 m
.18407 1 L
s
.21154 .99625 m
.21154 1 L
s
.23901 .99625 m
.23901 1 L
s
.26648 .99625 m
.26648 1 L
s
.32143 .99625 m
.32143 1 L
s
.3489 .99625 m
.3489 1 L
s
.37637 .99625 m
.37637 1 L
s
.40385 .99625 m
.40385 1 L
s
.45879 .99625 m
.45879 1 L
s
.48626 .99625 m
.48626 1 L
s
.51374 .99625 m
.51374 1 L
s
.54121 .99625 m
.54121 1 L
s
.59615 .99625 m
.59615 1 L
s
.62363 .99625 m
.62363 1 L
s
.6511 .99625 m
.6511 1 L
s
.67857 .99625 m
.67857 1 L
s
.73352 .99625 m
.73352 1 L
s
.76099 .99625 m
.76099 1 L
s
.78846 .99625 m
.78846 1 L
s
.81593 .99625 m
.81593 1 L
s
.87088 .99625 m
.87088 1 L
s
.89835 .99625 m
.89835 1 L
s
.92582 .99625 m
.92582 1 L
s
.9533 .99625 m
.9533 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17949 m
1 .17949 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .5 m
1 .5 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .82051 m
1 .82051 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05128 m
1 .05128 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .46795 m
1 .46795 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .72436 m
1 .72436 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .85256 m
1 .85256 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
0 0 m
0 1 L
s
[(Interference Intensity)] .5 1.0125 0 -1 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
1500 string
500 500 8 [500 0 0 500 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage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E760007DB30000732B00273B00041C000620003B46008111B3C000EF4100FF0000EC4E00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EA56008FB700007824002D3E00041D00051E003442007C1BA1BC00ED4B00FF0000EE4500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ED4C00A1BC00007C1B00344200051E00041D002D3E0078248FB700EA5500FF0000F13B00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EF4200B3C000008111003B4600072000041C00273B00732C7EB300E75F00FF0200F33300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F23900C4C40000860700444A00082200031B002237006E336DAE00E46A00FE0400F52A00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F43000C9BA00038B00004C4D000A2400031A001D340069395DAA00E17500FE0800F72300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F62800CDB0000F900000524D000B2600021A00193100653E4DA500DD7F00FD0C00F91C00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F82100D1A6001B940000564B000E2800021900152E0061433EA000DA8A00FB1100FA1600
D79400319C00005C4600122C00021900112B005B472D9B00D69700FA1700FC1000DA8900
3FA00000604300142E000219000F29005849259800D49C00F91A00FC0E00DC860042A200
00614200152E000219000F29005849269800D59A00FA1800FC0F00DA89003CA000005F44
00132D00021900112B005B47319C00D89100FB1300FB1500D795002D9B00005A48000F2A
00021900152E00624147A300DD8100FD0B00F81F00D0A70015920000524D000B2500021A
001D34006B3768AD00E46900FF0300F43100C7BF0000860600414800072000041C002B3D
00782398BA00EC4C00FF0000EC4C0097B900007824002A3C00041C000721004349008802
C8BB00F52C00FE0500E2720059A80000663D001730000219000F29005A48309C00D98F00
FC1000F91A00D2A10019940000534D000B2500031A002036006F317BB200E85B00FF0000
EF4100A8BE00007B1D002E3F00041C000720004249008901CAB800F62900FE0700DF7B00
49A40000614200132C00021900142D0062414FA500E07600FE0600F52C00C7BE00008608
003C4600061F00051E003543008111C1C400F33300FF0300E26F0058A80000653E00152E
00021900122C0060434BA400E07800FE0600F42D00C6C00000840C00394400051E00051E
003B46008608C8BC00F52A00FE0700DE7E0041A100005D4500102A000219001931006A38
6DAE00E76000FF0000EF44009DBB0000772500263A00031B000A2400524D1F9600D69700
FB1200F91A00D0A7000C8F00004A4C00072100041C003040007F16BEC300F33200FE0500
E0770049A400005F4400102A000219001A32006C3677B100E95800FF0000EC4E0088B500
007030001E3500021A000E28005B473FA100DE7D00FE0600F42F00C2C400007F15003040
00041C000822004F4E169200D49C00FB1300F91A00CFA900078C0000444A00061F00051E
003A45008706CBB500F72200FC0E00D7920022970000524D00092300031B002D3E007E18
BFC300F43000FE0700DD8000389E00005849000C2600031A002539007824A8BE00F13A00
FF0300E1740047A300005D46000E2800021A00213700742A9CBB00F04000FF0200E36F00
4EA500005F44000F2900021A001F3600732B99BA00F04000FF0200E26F004DA500005E45
000E2900021A002137007528A1BC00F13C00FF0300E1750043A200005B47000D2700031A
00253A007921B2C000F33300FE0600DD8200329C0000564B000A2400031B002E3F008013
C7BF00F62600FC0D00D794001A9400004E4E00072100051D003C46018A00CFAA00FA1700
FA1900CEAC00008901003A4500041D00082100504E219600D98D00FD0A00F52D00BDC300
007B1D00263A00031A000D27005D464EA500E46B00FF0100ED4A0081B400006B3700162F
000219001831006D338BB600EE4500FF0200E1720042A200005949000B2500031B002D3E
008111C9BA00F82100FB1200D2A200068C00003E4700051D00072100504D269800DB8700
FE0700F23500A7BD00007429001E3500021900132D00673B77B100EC4E00FF0000E46B00
4AA400005B47000C2600031B002E3F00830ECAB600F91C00FA1600CEAC00008705003442
00041C000A2400584A41A100E27100FF0100ED4B007AB20000683B00132D000219002036
007725B4C100F42D00FD0B00D6960011900000424900051E00072100514D2C9A00DE7F00
FF0300EF41008BB600006C3600152F000219001D34007528AEBF00F42F00FD0B00D69600
10900000414800051D00082200534C359D00E07700FF0200ED4A007AB20000673C00112B
00021A002439007C1BC6C000F72200FB1400CFAB0000860700314000031B000C27005E45
5CAA00E85A00FF0000E5670049A400005949000A2400041C003B45098D00D59A00FD0B00
F42F00AABE0000722C001A32000219001A3200732CABBE00F42E00FD0C00D49D00058C00
00384400041C000B25005C4756A800E85D00FF0000E5680046A30000574A00092300041D
004149159200D98E00FE0600F13C008DB700006A3800132D
F91A00D49B00289900005A4800102A00021900122C005C46309C00D69500FA1600FC1000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FB1400D89000369E00005E4500132D000219000F29005849239700D39F00F91C00FD0B00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FC0F00DB860045A200006341001730000219000D2700544C169200CFAA00F72300FE0700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FD0A00DF7B0054A70000673C001A3200021A000B2500504E0A8E00CBB400F52B00FE0400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FE0700E2710063AC00006B36001F3500031A00092300494C008900C7BE00F33300FF0200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FF0400E5670073B00000703000243900031B00072100404800840BBFC300F13B00FF0000
EA55008EB700007724002C3E00041D00061F003643007E17AABE00EE4500FF0000ED4B00
9EBB00007B1D00314100051E00051E003241007C1CA1BC00ED4A00FF0000ED4800A3BC00
007C1B00324100051E00051E003241007C1BA4BD00EE4700FF0000EC4C009CBB00007A20
002F3F00041D00061F003744008014B3C000F03F00FF0000EA560089B60000742900273B
00031C000721004249008705C7BF00F43100FF0300E568006BAE00006C35001E3500031A
000B2500514D139100D0A800F82000FD0B00DD810044A20000614200142D00021900112B
005D46399F00DA8900FC0E00F91B00D2A20019940000534C000B2500031A001E35006C35
6FAF00E66300FF0200F23800BDC30000811100374400051E00051E003542008014B7C100
F13A00FF0100E6620070AF00006C35001D3400021A000C2600554B219700D59A00FA1500
FB1400D5980024970000564B000C2600021A001D34006D3474B000E75F00FF0100F03F00
ABBE00007C1C002E3F00041C000720004349008A00CBB500F62600FD0900DD7F0042A200
005E4500112B00021900162F00663D5CAA00E36D00FF0300F23500BDC300008014003341
00041D000620004048008802CAB700F62600FD0900DD82003DA000005C46000F29000219
001932006A386DAE00E76000FF0100EF4200A2BC0000782300283B00031B00092300504E
179300D39E00FA1600FA1600D39E0017930000504E00092300031B00293C007A20A9BE00
F03D00FF0200E568005FAA0000653E00152E00021900142D00643F5AA900E46B00FF0200
F13C00AABE00007A2000293C00031B00092300524D1E9600D69700FB1100F91D00CEAC00
068C0000444A00062000051D00374400850AC8BB00F62700FD0A00DB8800309C0000574A
000B2600031A002439007626A0BC00F03F00FF0200E46A0058A80000624100122C000219
001931006B3778B100EA5600FF0000EA54007BB200006C3600193200021900122C006341
5AA900E56800FF0100EF440096B90000732B00203600021A000E28005D4647A300E17500
FF0300F13A00A8BE0000782400243900031A000C27005A483CA000DF7C00FE0500F23500
B1C00000792000263A00031A000C260059493A9F00DE7C00FE0500F23500AFBF00007921
00253A00031A000C27005A4840A100E07700FF0300F13A00A4BD0000762700213700021A
000E29005E454FA600E36C00FF0100EE45008FB700007030001B3300021900132C00653E
68AD00E85C00FF0000EA560071AF0000673B00142E000219001A32006E328BB600EE4600
FF0100E36D004CA500005D46000D2800031A00263A007A1FB9C200F42E00FD0900DA8B00
23970000504E00082100041D003A45008900CFAA00FA1700F91A00CDB000008706003643
00041C00092300534C2E9B00DD8100FE0500F23800A3BC0000742A001E3500021900122C
00663D70AF00EA5400FF0000E6630057A800005F44000E2800031A00273A007C1CC4C400
F62800FC0D00D5990010900000444A00051E000720004E4E1E9600D98C00FD0800F33200
ACBF00007527001F3600021900132C00673C77B100EC4E00FF0000E36D0046A300005948
000B2500031B003140008509CDB000FA1800F91B00CBB40000830D002E3F00031B000C26
005C4651A600E56500FF0000E9580065AC00006242000F2900031A00283B007E17C7BD00
F82000FB1400CFAA0000870400344200031B000B25005A484CA500E56700FF0000E95700
64AC00006142000E2800031A002B3D008111CAB600F91B00F91A00CBB400008210002B3D
00031A000E2800614266AC00EA5500FF0000E36C0043A20000574A00092300041D003C46
0A8E00D59900FD0B00F42F00ABBE0000732B001B3300021900193100712EA4BD00F33200
FD0A00D697000C8E00003D4600041D00092400584949A400E56600FF0000E85E0055A800
005C47000B2500041C003844058C00D49C00FD0C00F43000A7BD0000712E001931000219
001D34007626B9C200F62700FB1100D0A800008607002F3F
FF0100E85D0083B40000742900293C00041C00061F003944008014AEBF00EF4400FF0000
EC4C009FBB00007C1C00324100051E00051D003040007A2099BA00EC4F00FF0000EF4200
AFBF0000801400384400061F00041D002C3D00772490B800EA5300FF0000F03F00B4C100
00811200394500061F00041D002C3E00782393B800EB5100FF0000EF4300ADBF00007E17
00354300051E00051D003140007B1DA2BC00EE4800FF0000EC4D0099BA00007921002D3E
00041D00061F003B4500820FBDC300F13900FF0100E85E007BB20000702F00223800031B
000923004C4D078D00CCB200F62700FE0700E0770053A70000653E001730000219000E29
0059492B9A00D79400FB1300FA1500D5980026980000574A000D2700021900193200683A
5FAA00E36D00FE0400F42F00C7BF00008607003F4700062000041D002E3F007B1DA6BD00
EF4300FF0000E9580080B40000712F00223700031A000A2400514D159200D1A400F91B00
FC0F00D98D00319C00005A48000E2900021900193100683A64AC00E46900FF0200F23600
BDC30000801300354200051E00061F003C46008509C7BF00F42E00FE0500E1750050A600
00634100142D00021900132D0061424DA500E07700FE0600F42D00C7BF0000840A003A45
00051E00051E00394400840CC6C000F42E00FE0600E077004BA50000614300122C000219
00162F00663D5DAA00E46B00FF0200F13900B3C000007D1A002E3F00041C000821004A4C
0B8E00CFA900F91C00FC1000D7940023970000544C000B2500031A00243900752898BA00
EE4600FF0000E75E006FAF00006A3800193100021900112B0060434BA400E17500FE0400
F33300BCC200007E17002F3F00041C000822004D4E129100D2A100FA1600FA1600D2A200
119100004C4D00082100041C003140008014C4C400F42F00FE0600DE7E003DA000005B47
000E2800021A001F3600722D90B800ED4800FF0000E7600067AD0000673C00152E000219
00152E00673C68AD00E76000FF0000ED4A008BB60000702F001D34000219000F29005E45
4BA400E27200FF0300F13B00A7BD0000772400253900031A000C26005949389F00DE7F00
FE0600F33100BAC200007C1B002A3C00031B000A2400554B2F9B00DB8600FD0800F52D00
C2C400007E18002C3E00031B000A2400554B2D9B00DB8700FD0800F42D00C1C400007D19
002B3D00031B000A2500564B339D00DD8200FE0600F33200B5C100007A1F00273A00031A
000C26005A4841A100E07700FF0300F13C00A0BC0000742900203600021A00102A006143
58A800E56600FF0000EC4C0081B400006C3600183000021900162F006A387AB200EB5000
FF0000E663005BA90000614200102A00021A002137007627A8BE00F23600FE0500DD8100
309C0000544C00092300041C00334100850ACBB400F81D00FB1400D1A500048B00003D46
00051D00072100504E219700D98C00FD0900F43000B4C10000782200233800021A00102A
00624260AB00E85E00FF0000E9590067AD0000634000112B00021A002137007724B3C000
F43000FD0900D98E001C9500004C4D00062000051F00454A129100D69700FD0C00F52A00
BDC300007A1F00243900021A00102A00634067AD00E95700FF0000E6630055A800005E45
000D2700031B002B3D008113C9BA00F81F00FA1500CFAA0000880300354200041C000A24
00584942A200E26F00FF0100EC4E0075B00000663D00112B00021A002338007A20C0C300
F62700FC0F00D39F00068C00003B4500041D00092300564B3DA000E27200FF0100EC4E00
73B00000653E00112B00021A00253A007D1AC6C000F72100FB1400CFAA00008706003241
00031B000C26005D4656A800E75F00FF0000E6620052A600005B47000B2500031C003542
008900D1A400FC1000F62800BCC200007824001F3600021900152F006D3493B900F13A00
FE0600D98D0018930000444A00051E00082200544C3B9F00E27000FF0000EA540065AC00
006043000D2700031B003140008704D0A600FC1000F62800B8C200007627001D34000219
00193100712EA8BE00F42F00FD0C00D39E00028B00003543
FF0000EB530094B900007921002F3F00051D00051E003241007B1D9DBB00EC4D00FF0000
EF4300B0C00000801300394500061F00041C002A3C00752788B600E95800FF0100F13A00
C1C40000840B00404800072100031C00263A00732C80B300E85D00FF0100F23700C5C400
00850900414800072100031C00263A00732B82B400E85B00FF0100F13A00BEC30000830E
003C4600062000041C002B3D00772591B800EB5100FF0000EF4300AABE00007E19003342
00051E00051E003442007E18ACBF00EF4200FF0000EA54008BB60000752800273B00031C
00072100444A008803C8BC00F42E00FE0400E36D0062AB00006939001B3300021A000C26
00554B1E9600D39E00FA1900FC1000D98E00339D00005B4700102A00021900162F00643F
50A600E07800FE0700F62800CBB500028B0000474B00082100031C00283B00772595B900
EC4C00FF0000EC4E0091B80000752700273A00031B000822004B4D098D00CDAE00F72200
FD0A00DC83003FA100005E4500112B00021900152F00643F55A700E17300FE0500F42E00
C7BF00008509003C4600061F00051D003442008013BDC300F23600FF0300E46B0060AB00
00673C00173000021900102A005D463FA100DD8100FD0900F62600CBB500008900004249
00062000041D003241007F16BAC200F23600FF0300E36D005AA90000653E00152E000219
00122C0061424EA500E17500FE0500F43100C4C40000811100344200051D000620004249
008A00CCB300F72300FD0C00DA8A00319C00005849000D2700021A001F3600712F87B500
EB4F00FF0000EA54007FB300006E32001D3400021A000E28005B473DA000DD8000FE0700
F52B00C6C00000830E00354300041D00072000454A078C00CFAB00F91C00FB1100D69700
1D950000514D00092300031B002B3D007B1DB2C000F23700FF0300E173004CA500005F44
00102A000219001B33006D347FB300EB5200FF0000EA560077B100006B37001931000219
00122C00624158A800E46A00FF0100EF41009CBB0000752800223800031A000D27005A48
3DA000DE7C00FE0500F33200B8C200007C1C002A3D00031B000A2400554C2B9A00DA8900
FD0A00F52A00C6C10000811300304000041C00092300514D219700D89000FD0C00F62500
C8BC0000830E00324100041C00082200514D209600D89100FD0C00F62600C8BD00008210
00314000041C00092300524D259800D98C00FD0A00F52A00C5C300007F17002C3E00031B
000A2400564B339D00DD8100FE0600F33400B1C00000792200253900031A000D28005C46
49A400E27000FF0200EF430092B800007030001C3300021900132C00653E6AAE00E95900
FF0000E959006BAE0000653E00132C000219001C3400712E97BA00F03F00FF0300E07700
3EA000005849000B2500031B002D3E008013C7BE00F72400FC0F00D49B000F900000454A
00061F00061F00484C159200D69600FC0D00F62800C5C400007D1A00283B00031A000D27
005D4551A600E56800FF0000EB500077B10000683B00132D000219001D3400732BA1BC00
F23800FE0600DC840029990000514D00082100051D003D46078C00D2A100FB1100F72300
C7BF00007F1700293C00031A000D28005F4458A800E76100FF0000E9590065AC00006241
000F2900021A00263A007C1CC5C300F62600FC1000D3A000078C00003C4600041D000822
00544C349D00DF7900FF0200EE450085B500006A3800152E000219001E35007528AFBF00
F42F00FD0A00D6950011910000424900051E00082100524D2F9B00DF7C00FF0300EE4400
84B40000693900142D000219002036007823BCC200F62900FC0F00D3A000048B00003944
00041C000A2400594948A300E46900FF0000E9580061AB00006043000D2700031B002E3F
00850ACEAE00FA1500F82000C6C000007C1B00243900021A00122C00683A83B400EF4300
FF0400DD8200249800004D4E00061F00072000504E2D9B00DF7B00FF0200ED4A0075B000
00643F000F2900031A002B3D00830ECDB000FA1600F82100C6C200007A1F002137000219
00152E006D3497B900F23700FD0800D794000E8F00003C46
FF0000ED4900A4BD00007D1900354300061F00041D002C3D0077258CB700E95700FF0000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FF0000F04000B5C100008210003D4600072000041C00263A00722C7CB200E76100FF0200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FF0100F23800C5C30000860600444A00082200031B002137006E336CAE00E46A00FE0500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FF0200F43000C9BA00038B00004D4E000A2400031A001D340069395DAA00E17500FE0800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FE0500F62800CDB0000F900000514D000B2600021A00193100653E4EA500DE7F00FD0B00
F91C00D39F0022970000584A000F2900021900142E0060433CA000DA8B00FB1100FA1600
D695002E9B00005B4700112B00021900122C005D46359D00D89000FB1300FB1400D79200
319C00005C4700112B00021900122C005E45389E00D98D00FB1100FA1600D697002A9A00
005948000F2900021900152E00614244A200DC8300FD0C00F91D00D2A3001B940000544C
000C2600021A001A3200683B5BA900E27200FE0600F52900CBB500048B00004A4D000822
00031B00233800722D80B300E85A00FF0000F03D00B4C000007F1500354300051E00051E
003442007F16B2C000F03E00FF0000E85B007DB30000702F00223700031B000923004F4E
0F9000CFAB00F82000FD0B00DC830041A100005F4400122C00021900132D00614248A300
DE7D00FD0900F72500CCB200058C0000494C00082200031B00283B00772597B900ED4A00
FF0000EB51008BB60000732B00243900031B00092300504E129100D0A600F91C00FC0F00
D98D00309C00005949000E28000219001A32006A386BAE00E66400FF0100F13C00B0C000
007D1A002F3F00041C00072000444A018A00CBB400F72500FD0A00DC83003CA000005C46
000F2A00021900193100693968AD00E66400FF0100F03E00ABBE00007B1E002C3D00041C
000822004C4D0D8F00D0A800F91C00FC1000D7930025980000554B000B2500031A002238
00732B8FB800ED4B00FF0000E957007AB200006D34001C3400021A000E29005B473CA000
DD8100FD0800F52900C8BD0000850A00384400051E00061F004048008900CCB200F72100
FC0D00D98E002A990000554B000B2500031A0024390076279CBB00EF4300FF0100E66400
63AB0000663D00152E00021900152E00653E61AB00E56500FF0100EF43009ABA00007528
00233800031A000C26005849359D00DC8400FD0800F52B00C6C10000811100324100041C
000821004E4E159200D49D00FB1300F91B00CEAB00048B0000414800061F00051E003E47
008900CDAF00F81D00FB1100D59A00179300004E4E00082100041D00344200830DC8BC00
F62600FD0C00D88F0023970000524D00092300041C002F3F008014C5C200F52A00FD0A00
DA8A0029990000544C00092300031B002E3E007F15C5C300F52A00FD0A00DA8B00279900
00534C00092300041C003040008111C7BE00F62600FD0C00D792001E950000504E000821
00041D003643008607CBB400F81E00FB1200D39F000E8F0000464A00061F00051F004249
098D00D2A300FB1400F91C00CCB10000870600374300041D00082200514D239700D98C00
FD0900F42D00BDC300007B1D00273B00031A000D27005C4749A400E36F00FF0100EE4600
8AB600006E3300193100021900162F006A387DB300EC4D00FF0000E5680052A600005E45
000E2800031A00263A007B1DBFC300F52B00FD0B00D79300199300004B4D00062000051E
00444A0F9000D49B00FC0E00F62600C6C200007E1800293C00031A000D27005D4552A700
E56600FF0000EB520071B00000663D00122C000219001F36007627ADBF00F33200FD0800
D98D001E9500004D4E00062000061F00464B159200D79400FD0B00F52D00B6C100007823
00213700021900122C00663D74B000EC4F00FF0000E36C0046A300005949000B2500031B
003341008706CEAC00FA1600F81E00C9B900008013002B3D00031A000E280060435EAA00
E85B00FF0000E6620054A700005D46000C2600031B00304000850ACDAF00FA1700F81E00
C9BA0000801500293C00031A000F290062416AAD00EA5300FF0000E36D0043A20000574A
00092300041C003B45088D00D49C00FC0D00F52C00B2C000007528001D34000219001730
006E3298BA00F23800FE0700D98E0017930000444A00051E00082200544C389E00E17300
FF0100EB50006BAE00006241000E2800031A002D3E00840BCEAE00FB1500F72200C5C300
007A1F00213700021900152E006C3593B900F13900FE0700D8900012910000404800041D
00092300584A49A400E56500FF0000E761004FA600005948
FD0800F72100D0A6001A940000554B000D2800021900152F00614240A100DA8900FC1000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FD0C00F91B00D49D0027980000594900102A00021900122C005D46329D00D79300FA1500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FB1100FA1500D79300339D00005D4500132C00021900102A005949269800D49D00F91B00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FA1600FC1000DB890041A10000614200162F000219000D2700554B199400D0A700F72100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F91C00FD0C00DE7F004FA60000663D00193200021A000B2500514D0E8F00CDB000F62800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F72200FE0800E175005DAA00006A38001D3400031A000924004C4D038B00C9BA00F42F00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F62900FE0500E46B006CAE00006E3300213700031B00082200444A008706C5C300F23700
FF0100E95A0086B50000752800293C00041C000620003A45008112B3C000EF4100FF0000
EB510095B900007922002E3F00041D00061F003643007F17ABBE00EF4400FF0000EC4E00
98BA00007921002E3F00041D00061F003743007F15AFBF00EF4100FF0000EB520090B800
007725002A3D00041C000620003D4600830DC0C300F23900FF0100E85E007CB20000712E
00233800031B00082200494C038B00CAB700F52B00FE0500E270005EAA0000683A001A32
00021A000C2600554B1E9500D39F00F91A00FC0F00DA8A00389E00005D4600112B000219
00142D00614246A300DD8000FD0A00F72200CEAC000E8F00004F4E00092300031B002238
00712F7FB300E95900FF0000F04000ABBF00007D1A00314000041D00061F003C4600850A
C6C200F33100FF0400E36D005FAA0000683B001931000219000E29005948309C00D98E00
FC0F00F91B00D1A30015920000514D000A2400031A00223800722D87B500EA5300FF0000
ED4A0097B90000762600273B00031B000922004E4E0E8F00CFA900F81E00FC0E00D98C00
309C00005949000E2800021A001B33006B3670AF00E75F00FF0100EF4100A6BD00007A20
002B3D00041C000822004B4D0C8F00CFA900F91D00FC0F00D890002A9A0000574A000C26
00031A001F3600703084B400EB5300FF0000EC4F008AB60000722D00213700031A000C26
00564B2A9A00D88F00FC0E00F81F00CEAE00058C0000454A00072000041D003341008113
C3C400F43000FE0500E0780048A300005F4400102A000219001932006B3773B000E85B00
FF0000ED4A008FB70000722C00203700031A000D27005949349D00DC8500FD0900F62800
C8BC0000840B00374300051D00062000454A078C00CFAA00F91B00FB1200D59A00199400
00504E00082200041C002E3F007E17BFC300F43000FE0600DE7D003EA000005B48000D28
00021A00203700732B96B900EE4400FF0100E566005EAA0000643F00132D000219001831
006B3778B100EA5500FF0000EA560077B100006A3800183000021900142D00653E64AC00
E76100FF0000ED4B0087B500006F32001B3300021900112B0062415AA900E56700FF0100
EE47008EB70000702F001D3400021900112B00614258A800E56700FF0100EE48008CB700
006F31001C3300021900122C00634060AB00E66200FF0000EC4E0080B400006C36001831
00021900152E00683B71AF00EA5600FF0000E95A006BAE0000663D00132D000219001A32
006F328CB700EE4600FF0100E36C004EA500005E45000E2800031A002439007822B2C000
F33200FE0700DC85002C9A0000534C00092300041C003442008509CBB400F81D00FB1400
D1A400068C00003F4700051E000720004E4E1C9400D89100FD0B00F52B00BFC300007B1D
00273A00031A000D28005E4551A600E56800FF0000EC4E0079B20000693A00142E000219
001B3300712E99BA00F13D00FE0400DE7D00339D0000544C00092300041C003643008803
CEAB00FA1700F91B00CBB30000840B00314000031B000B2500594942A200E27100FF0100
ED490080B300006A3900152E000219001D3400732BA4BD00F23600FE0700DA8900219700
004F4E00072000051E00464A149200D79400FD0A00F42E00B2C000007625001F36000219
00132D00683A7DB300ED4900FF0100E174003B9F0000564B00092300041C003A45058C00
D2A100FC0F00F62700C2C400007A1F00233800021A00122C00673C79B200ED4B00FF0100
E17500389E0000554C00082200041D003F470D8F00D59800FD0B00F42F00AEBF00007429
001C34000219001730006E3297B900F13900FE0600DA8B001A940000474B00051E000721
00524D319C00DF7900FF0200ED4A0077B10000653E00102A00021A00283B007F15CAB800
F91B00F91A00CAB70000801400283B00021A00102A00663D7AB200EE4700FF0300DE7E00
289900004F4E00061F00062000504E2D9B00DF7A00FF0200EC4C0071AF00006340000E29
00031A002E3E008509CFAB00FB1200F62600BDC300007725
F43000FF0200E661007BB20000722D00263A00041C000720003D4600820FB7C100F03F00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F23800FF0100E958008AB600007626002B3D00041D00061F003643007E18A7BD00EE4800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F04000FF0000EC4F009ABA00007B1E00314000051E00051E003040007A2097B900EB5000
FF0000F04000B5C100008210003C4600062000041C00283B00742984B400E85B00FF0100
F23700C5C40000860800424900072100031B00253900722D7CB200E75F00FF0200F23500
C5C20000860700424900072100031B00263A00732C80B400E85C00FF0100F23900C0C300
00840C003D4700062000041C002A3C00772590B800EB5200FF0000EF4300ABBE00007E18
00344200051E00051E003442007E18ACBF00EF4200FF0000EA54008BB60000752800273B
00031C00072100444A008802C8BC00F42E00FE0400E36D0061AB00006939001A3200021A
000C2700554B209600D49D00FA1800FB1100D88F00319C00005A48000F2900021900162F
00643F53A700E07600FE0600F52900CAB700008A0000454A00072100041C002A3C007824
99BA00ED4A00FF0000EB51008DB70000742900253A00031B000923004E4E0D8F00CEAB00
F82000FD0C00DB86003A9F00005C4600102A00021900173000663D5AA900E26F00FE0400
F33100C5C30000830D00394400051E00051E00374400820FC4C400F33200FF0400E26F00
59A90000653E00162F00021900112B005F4446A300DE7C00FE0700F52900C9BA00008705
003E4700061F00051D003543008211C4C400F33100FE0400E1730052A60000624100132D
00021900142E00643F57A800E36F00FF0300F23600BAC200007E1700304000041C000721
00474B078D00CEAC00F81E00FC0F00D8910028990000554B000B2500031A00233800742A
93B800ED4900FF0000E85B0073B000006B37001A3200021900102A005F4448A300E07700
FE0500F33200BFC300007F1600304000041C000821004C4D109000D2A300FA1700FA1600
D3A000139100004E4E00082200041C003040007F15C2C400F42F00FE0600DE7D003EA000
005B47000E2800021A001F3600722D8FB700ED4900FF0000E7600067AD0000673C00152E
00021900152E00673C68AD00E75F00FF0000ED4A008BB600007030001D34000219000F2A
005F444CA500E27100FF0300F13C00A5BD0000772500243900031A000C260059493A9F00
DE7E00FE0600F33300B7C100007B1D00293C00031B000B2500564B319C00DC8400FE0700
F42F00BEC300007D1A002B3D00031B000A2400564B309C00DC8400FE0700F42F00BCC200
007C1B00293C00031B000B2500574A379E00DE7E00FE0500F33500AFBF00007922002539
00031A000D27005C4746A300E17300FF0200F03F0099BA0000722C001E3500021900112B
0062415FAA00E66100FF0000EB50007AB200006A3800162F000219001830006C3682B400
ED4B00FF0000E5680053A700005F44000E2900021A002338007823B2C000F33200FE0700
DB870028990000524D00082200041D003743008704CDAE00F91900FA1800CEAC00008802
00384400041D00082200524D2A9A00DC8500FE0600F23500A8BE00007528001F36000219
00112B00653E6BAE00EA5700FF0000E760005BA900006043000F2900031A00253A007B1E
C0C300F52A00FD0C00D6970013910000464A00061F000620004C4D1C9500D98E00FD0900
F43100AFBF0000762600203600021900122C00673C75B100EC4F00FF0000E36C0048A300
005A48000B2500031B00314000850ACDB000FA1900F91A00CBB30000830D002F3F00031B
000C26005C4651A600E56500FF0000E9580065AC00006142000F2900031A00283B007F17
C8BD00F82000FB1400CFAA0000870500334100031B000B25005B484DA500E56600FF0000
E9580062AB00006043000E2800031A002C3D008210CBB400F91A00F91B00CAB600008112
002A3D00031A000E2900624169AD00EB5300FF0000E36E0040A10000564B00092300041D
003E470D8F00D69600FD0A00F33100A6BD0000722D001A32000219001A3200732CAABE00
F42F00FD0B00D59B00088D00003A4500041C000A24005A484FA600E66200FF0000E66200
50A600005A48000A2400041C003B450A8E00D69800FD0A00F333009FBC00006F31001730
000219001F35007823C1C400F72400FB1400CEAD0000840C
ED4800FF0000EE4600AABE00007F1600384400061F00041C002A3C00752787B500E95900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EB5100FF0000F03E00BAC20000830D003E4700072100031B00253900712E78B100E66300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E95A00FF0100F23600C6C20000870400464B00082200031B002037006D346AAD00E36C00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E66300FF0300F42F00C9B900058C00004E4E000A2400031A001C340069395CA900E17500
FE0800F72200CFA90017930000544C000D2700021900173000643F4AA400DD8100FD0C00
F91C00D39F0021970000574A000E2800021900152F00624244A200DC8500FC0D00F91A00
D49D0023970000574A000E2800021900162F00624147A300DD8200FD0C00F91D00D2A200
1C950000554B000D2700021900193100663D55A700E07700FE0800F72500CDAF000D8F00
00504E000A2400031A001F36006D346EAF00E56600FF0200F33300C6C100008608004048
00072000041C002A3D00772495B900EC4E00FF0000ED49009DBB00007920002D3E00041C
000620003E47008509C6C200F33200FF0300E4690067AD00006A38001C3300021A000C26
00554B209600D49C00FA1700FB1200D892002D9B00005949000E2800021900183100673B
5EAA00E36E00FE0400F43000C6C000008509003D4600061F00041D003141007E18B1C000
F13D00FF0100E7600072B000006C35001D3400021A000C2700564B269800D69600FB1300
FA1700D39E001B940000534D000A2500031A00213700712E85B500EA5300FF0000ED4B00
94B90000752800263A00031B00092300504E159200D2A300F91900FB1200D69500259800
00554B000B2600031A00203600712F85B500EB5200FF0000EC4E008CB70000732C002238
00031A000B2500544C239700D69500FB1100F91B00D0A6000E8F00004C4D00082200041C
002C3E007C1CB0C000F13A00FF0200E46A005CAA0000653E00152E00021900142D006340
58A800E36D00FF0200F13900B0C000007B1D002B3D00031C000822004F4E169300D39E00
FB1500FA1800D1A300109000004C4D00082100041C003040007F16C0C300F43100FE0500
DF7A0043A200005D46000F29000219001D34006F3283B400EB5000FF0000E9570076B100
006B3700193100021900122B00614254A700E36D00FF0200F03D00A4BD00007724002539
00031A000B2600574A329C00DC8500FD0900F52B00C6C20000811200314000041C000822
00504E1A9400D69800FC1000F81F00CCB200008803003B4500051E00062000464A0B8E00
D1A400FA1600FA1800D0A800078C0000424900061F00051E004048048B00CFAA00F91900
FA1500D1A3000B8E0000454A00061F00051E003F47038B00CFAA00F91900FA1600D1A500
088D0000434900061F00061F004249088D00D1A500FA1600F91A00CEAC00008900003C46
00051E000720004B4D159200D59900FC0F00F72200C9B90000830D00324100041C000923
00534C2A9A00DB8700FE0800F43000B8C200007A1F00263A00031A000D27005C4749A400
E26F00FF0100EE44008EB700006F31001A3200021900142E00683B74B000EB5300FF0000
E761005DAA0000614200102A00021A002137007725ACBF00F33400FE0700DB8600299900
00524D00082200041D003844008901CFAB00FA1700F91A00CDB00000860700344200041C
00092300554B359D00DF7C00FF0400F03E0097B90000702F001A3200021900152F006A38
81B400ED4900FF0100E2700043A200005949000B2500031B00304000840CCBB400F91C00
FA1700CEAD0000870500344200041C000A2400574A3DA000E17400FF0100EE480081B400
006A3800142E000219001D3400742AA8BE00F33300FE0800D98E001B9400004A4C00061F
00061F004C4D1E9500DA8B00FE0700F23600A1BC0000722D001B33000219001730006E33
93B800F03D00FE0500DC8400269800004F4E00072000061F00494C1B9400D98C00FE0700
F237009EBB0000702F001931000219001A3200712EA1BC00F33500FD0800D89000159200
00444A00051E00082100534D339D00E07800FF0200ED4A0078B10000663D00112B00021A
00263A007E18C8BC00F81E00FA1700CCB20000830F002C3D00031A000F290062416DAE00
EB5000FF0100E17400369E0000534C00072100051E00474B1C9500DB8800FE0500F03F00
8AB600006A3800132D00021A002439007D1AC8BD00F81D00FA1900CBB60000801400283B
00021A00112B00683B83B400EF4200FE0400DB87001C9500
E36C00FE0500F62800CDB0000F900000524D000B2600021A00193100653E4EA500DE7F00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E17500FD0800F72100D0A7001A940000554B000D2800021900152F00614241A100DB8800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DE7F00FD0C00F91B00D49D0026980000594900102A00021900132C005D45349D00D89200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DB8800FC1000FA1600D79400329C00005D4600122C00021900102A005A48289900D49B00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D89200FB1500FB1100DA8B003EA00000614300152E000219000E2800564B1C9500D1A400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D49B00F91A00FC0D00DD81004BA40000643F00183100021A000C2600524D129100CEAD00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D1A400F82000FD0900E0780058A80000683A001C3300031A000A24004F4E078D00CAB600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CEAD00F62600FE0600E26F0066AC00006C35001F3600031B00092300484B008901C7BF00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CAB600F52C00FF0300E5660073B00000703000243900031B00072100414800840AC0C300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C7BE00F33300FF0200E85D0082B40000742A00283B00041C000620003A45008013B1C000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C1C400F13B00FF0000EA550090B800007823002D3E00041D00051E003442007C1BA2BC00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B2C000EF4200FF0000EC4D009EBB00007C1C00334100051E00051D002E3F00792293B800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A3BC00ED4A00FF0000EE4500ADBF0000801400394400061F00041C00293C00752985B500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94B900EB5200FF0000F03D00BCC20000840C003F4800072100031B00243900712F77B100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86B500E85B00FF0100F23600C6C10000880300464B00082200031B002036006D3469AD00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78B100E66300FF0300F42F00C9B900058C00004E4E000A2400031A001C340069395CAA00
E17500FE0800F72300CFA90016920000544C000C2700021900183000643F4CA500DD8000
FD0B00F91D00D2A10020960000564A000E2800021900162F00624146A300DC8300FC0D00
F91B00D39F0021960000574A000E2800021900162F0063404AA400DE7F00FD0B00F81F00
D1A50019930000544C000C2600021A001A3200673B59A900E17400FE0700F62700CCB200
098D00004E4E00092300031A002137006F3274B000E66200FF0200F23600C4C40000840C
003D4600062000041C002D3E0079219CBB00ED4A00FF0000EC4D0096B900007724002A3D
00041C000720004249008704C7BD00F42E00FE0400E36E005FAA0000683A001932000219
000D2700574A279800D69700FB1400FB1500D6970025980000574A000D2700021A001B33
006A3867AD00E56800FF0200F23500C1C40000821000384400051E00051E003643008112
BDC300F23700FF0200E5670067AD00006939001A32000219000E280059492F9B00D98E00
FC0F00F91C00D0A600129100004F4E00092300031B00253A00752893B800ED4C00FF0000
EB520086B50000722D00213700031A000B2500534C1F9600D59A00FB1400FA1600D39E00
19940000524D000A2400031B00253900752894B900ED4A00FF0000E957007DB300006E32
001E3500021A000D27005849309C00DA8B00FC0C00F72100CDB000038B0000444A000720
00041D003341008013C2C400F33100FE0500E175004CA50000604300112B000219001730
00683A69AD00E66200FF0100EF43009DBB0000762600253A00031B000A2500544C259800
D79200FC0F00F81F00CDAF00038B0000424900061F00051E00384400850AC8BB00F62700
FD0A00DB8700329C0000584A000C2600031A00223800742999BA00EF4400FF0100E66400
62AB0000653E00142E00021900162F00673B69AD00E75F00FF0000ED49008DB70000712E
001E3500021A000E29005D4645A300E07700FE0400F23600B1C000007A1F00283B00031B
000A2500554B2D9B00DB8800FD0900F52A00C6C00000811200314000041C00082200504E
1D9500D79400FC0E00F72200CAB70000850900364300041D000721004D4E169200D59A00
FC1100F81F00CBB30000870600384400041D000721004C4D159200D59A00FC1000F82000
CBB50000850800364300041D000821004F4E1C9500D79300FC0D00F62500C7BD00008211
00304000041C00092300544C2B9A00DB8700FE0800F42F00BAC200007B1D00273B00031A
000C26005A4842A200E17500FF0300F03F0099BA0000722D001D3400021900122B00643F
65AC00E85D00FF0000EA56006FAF0000673C00132D000219001B3300703093B900EF4100
FF0200E1750041A100005949000B2500031B002C3D008015C7BF00F72500FC0F00D59A00
10900000454A00061F00061F00484C159200D69600FC0D00F62800C5C400007D1A00283B
00031A000D28005E4552A700E56600FF0000EB510074B00000673C00132D000219001E35
00742AA5BD00F23600FE0600DB870026980000504E00072100051E003F480A8E00D39E00
FC0F00F62500C5C200007D1A00273B00031A000E290060435FAA00E85D00FF0000E85E00
5DAA00006043000E2800031A00283C007E17C7BE00F72200FB1200D1A600008A00003844
00041C00092300574A3EA000E17200FF0100ED4B0079B20000673C00122C000219002137
007922BCC300F62900FC0E00D49D00088D00003C4600041D00092300554B3B9F00E17300
FF0100EC4D0075B00000653E00112B00021A002539007D1BC6C000F72100FB1400CFAA00
00860600314100031B000C26005D4658A800E75E00FF0000E6630050A600005B48000B25
00041C003643018A00D2A100FC0F00F52900B8C100007626001E35000219001730006E32
99BA00F23700FE0800D8900013910000414800051D00092200564B41A100E36C00FF0000
E958005EAA00005E45000C2600031B003442008A00D2A100FC0E00F52C00AEBF0000732B
001A32000219001B33007429B3C000F52A00FC0F00D1A500
6BAE00E36C00FE0500F62800CDB0000E8F0000514D000B2600021A00193100663D4FA600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5EAA00E17400FE0800F72200D0A80018930000554B000D2700021900162F00624143A200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51A600DE7D00FD0B00F91D00D39F00239700005849000F2900021900132D005E45379E00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45A300DB8600FC0F00FA1700D697002E9B00005C4700112B00021900112B005B472C9A00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399F00D98E00FB1300FB1300D98E00399F00005F4400142D000219000F2900574A219700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2E9B00D69700FA1800FC0F00DB860045A200006341001730000219000D2700544C179300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239700D39F00F91D00FD0B00DE7D0051A60000663D001A3200021A000B2500514D0D8F00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199400D0A800F72200FE0800E175005DAA00006A38001D3400031A000A24004D4E048B00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0F9000CDB000F62800FE0500E36C006AAD00006D3400213700031B00082200464B008704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068C00CAB800F42E00FF0300E6640076B10000712F00253900031B000721003F4800840C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008802C6C000F33500FF0100E85C0083B40000742900293C00041C00061F003945008014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00850AC0C300F13B00FF0000EA540091B800007823002E3E00041D00051E003442007C1B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008112B2C000EF4200FF0000EC4D009EBB00007C1C00334100051E00051D002F3F007921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007D19A4BD00ED4900FF0000EE4500ABBF00007F1500384400061F00041C002A3C007528
87B500E95900FF0100F23800C5C40000860800424900082100031B00243900702F76B100
E66300FF0200F43100C8BD0000890000484B00082200031B002137006F3271AF00E56600
FF0300F43000C8BC0000890000474B00082200031B00233800703077B100E66100FF0200
F33400C5C20000860700414800072100041C00273B00742988B600EA5600FF0000F03F00
B2C00000801500364300051E00051D003140007C1BA6BD00EE4500FF0000EB510090B800
00762600293C00041C000721004249008704C7BD00F42F00FF0400E36C0063AC00006939
001B3300021A000C2600554B1F9600D39E00FA1800FC1000D98F00319C00005A48000F29
00021900162F00653E54A700E17500FE0600F52A00C9B80000890000444A00072100041C
002B3D0078229CBB00EE4800FF0000EB530089B60000732B00243900031B000923004F4E
109000D0A800F81E00FC0D00DA8A00359D00005B47000F2900021900183100673B60AB00
E46B00FF0300F33500BFC30000811200354300051E00061F003B4600850AC7BF00F42E00
FE0500E1750050A60000624100142D00021900132D0062414FA600E17500FE0500F42F00
C6C10000830D00384400051E00051F003B45008509C7BD00F52B00FE0700DF7B0045A300
005F4400112B00021900173000683B65AC00E56500FF0100F03E00A9BE00007A1F002A3D
00031B000822004F4E139100D2A100FA1700FB1400D49C001A940000514D00092300031B
00293C007921A7BD00F03E00FF0100E5670060AB0000653D00152E00021900142D00643F
5BA900E46A00FF0200F13D00A8BE0000792100283B00031B000A2400534C219700D79400
FC0F00F81E00CDAF00028A0000414800061F00051E003A45008606CAB700F72400FD0C00
D98D0029990000554B000A2500031B00273B007921ABBE00F13A00FF0300E271004EA500
005F4400102A000219001C33006E3284B500EC4E00FF0000E85C006DAE0000683A00162F
00021900152E00673C69AD00E75E00FF0000EC4D0085B500006E32001B3300021900112B
00614257A800E46900FF0100EF440094B90000722D001F3500021A000F29005F444FA600
E36E00FF0200EF41009ABA0000732B001F3600021A000F29005F444FA600E36D00FF0100
EF420095B90000722D001E3500021900102A00614259A800E56600FF0000ED4A0087B500
006E33001A3200021900132D00663D6BAE00E95A00FF0000EA570070AF0000673B00142E
000219001932006E3388B600ED4800FF0100E46A0051A600005E45000E2800021A002338
007823AFBF00F33300FE0600DC84002D9B0000534C00092300041C003442008509CBB400
F81D00FB1400D1A400068C00003E4700051E000720004E4E1D9500D89000FD0A00F52C00
BDC300007B1E00263A00031A000E28005E4454A700E56600FF0000EB510075B10000673B
00142D000219001D3400722C9FBB00F13A00FE0500DD81002E9B0000534C00082200041D
003945018A00D0A700FB1400F81E00CAB800008210002E3E00031B000C26005B474AA400
E46B00FF0000EC4F0076B10000673C00132C000219001F36007626AFBF00F43000FD0900
D8900019930000494C00061F000620004C4D1E9500DA8C00FE0700F33500A4BD0000732C
001C3300021900162F006C358BB600EF4100FF0300DE7E002E9B0000524D00082100051E
004249109000D69600FD0B00F42E00B0C000007527001E3500021900152E006B368AB600
EF4100FF0400DD810029990000504E00072000061F00494C1C9400DA8B00FE0700F23900
98BA00006F32001730000219001C3400742AADBF00F42E00FD0C00D59A000A8E00003C46
00041D00092300574A45A200E46A00FF0000E9580060AB00005F44000D2700031B003140
008606CFA900FB1200F72500C1C40000792200203600021900152F006D3495B900F23900
FE0700D8900013910000414800041D00092300574A45A300E46800FF0000E85D0055A700
005B47000B2500041C003A45098D00D69700FD0A00F33400
007A2097B900EB5100FF0000F03E00B9C20000830E003E4700072000031C00263A00722D
7AB200E76100FF0200F33100C8BD0000890000494C00092300031B002036006D346AAD00
E46B00FE0400F52B00CBB500078D00004E4E000A2400031A001E35006B3765AC00E36E00
FE0500F52A00CBB400088D00004E4E00092400031A001F35006C356AAE00E46900FF0400
F42E00C9BA00008A0000484B00082200031B00233800712E7CB200E75E00FF0100F23800
C0C30000830D003C4600062000041C002C3E00792299BA00EC4C00FF0000ED4A009DBB00
007A20002D3E00041D00061F003C4600840CC3C400F23600FF0200E6640070AF00006D34
001E3500031A000B2500524D159200D1A600F81D00FC0D00DB87003CA000005E4500112B
00021900142D00614248A400DE7D00FD0900F72400CDB000088D00004B4D00082200031B
00263A0075288FB700EC4F00FF0000ED4B0096B90000772500283B00031B000822004A4C
078D00CDB000F72300FD0A00DD820040A100005E4500112B00021900152F00643F55A700
E17300FE0500F42F00C6C00000850A003B4500061F00051E003643008111C0C300F33400
FF0300E36D005CA90000663D00162F00021900112B005F4444A200DE7D00FE0800F62900
C9BA00008705003E4700061F00051D003543008211C4C400F33100FE0400E1730051A600
00624100132D00021900152E00643F59A900E36D00FF0300F23700B6C100007E19002F3F
00041C00072100494C0A8E00CFA900F91C00FC1000D7940024970000544C000B2500031A
00243900752799BA00EE4500FF0000E760006CAE0000693900183100021900112B006142
4FA600E27200FF0400F23600B6C100007D1B002D3E00041C00082200504E189300D49C00
FB1300F91900D0A7000B8E0000484B00072000041D00354200830EC7BF00F52A00FD0900
DC8500339D0000584A000C2600031A0023380075279DBB00EF4100FF0100E469005AA900
00634000122C000219001931006B3777B100EA5600FF0000EA54007AB200006B36001931
00021900122C0063405DAA00E56600FF0100EE460092B80000722D001F3500021A000F29
005E454CA500E27100FF0200F03D00A1BC0000762700223800031A000D28005C4744A200
E07600FF0300F13A00A7BD0000772500233800031A000D27005B4744A200E17500FF0300
F13B00A2BC0000752700213700021A000E29005E454DA500E36E00FF0200EF420094B900
00712E001D3400021900112B0063415FAA00E66200FF0000EC4F007DB300006B37001730
00021900162F006A387BB200EB5000FF0000E662005DAA0000624100102A00021A001F36
007429A2BC00F13A00FE0400DF7C00379E0000574A000A2400031B002F3F008111C8BC00
F72300FC1000D49C000F900000454A00061F00061F00474B139100D59800FC0E00F62600
C6C100007E17002A3C00031B000C26005B4749A400E36E00FF0100ED490082B400006B37
00162F000219001932006F3191B800EF4100FF0300E07900389E0000564B000A2400041C
003442008607CDAF00FA1900F91900CDB00000860800334100041C000A2400574A3FA000
E17300FF0100EE470083B400006A3800152E000219001C3300722CA2BC00F23700FE0600
DB8800229700004F4E00072000051E00454A149200D79400FD0A00F42E00B2C000007626
001F3600021900132D00683A7EB300ED4800FF0200E17500399F0000554B00092300041D
003B46078C00D39E00FC0E00F62800BEC30000792100213700021900132C00683B7EB300
EE4800FF0200E07800339D0000534C00082200051E004249129100D79300FD0900F33200
A6BD0000722C001A3200021900193100702FA0BC00F33500FD0800D89100139100004249
00051D00082200544C399F00E17200FF0100EB50006CAE00006241000E2900031A002C3D
00830ECCB100FA1600F81F00C7BF00007C1B00243900021A00132D006A3988B600F03F00
FE0500DB88001D950000474B00051E00082100544C3A9F00E27000FF0000EA560061AB00
005F44000C2600031B003442018A00D3A000FC0D00F42E00
0076268AB600E95800FF0100F23800C5C30000860600444A00082200031B002237006E32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00732B7DB300E76000FF0200F33100C8BC00018A00004B4D00092300031A001E35006B37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006F3171AF00E56800FE0400F52B00CBB4000A8E0000504E000A2500021A001B3300673B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006C3565AC00E27000FE0600F62500CEAD0013910000534C000C2600021900183000643F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00693A59A900E07800FD0900F82000D1A5001C950000564B000E2800021900152E006142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00653E4EA500DD7F00FD0C00F91B00D49D0026980000594900102A00021900132C005E45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00624143A200DB8700FC0F00FA1700D69500309C00005C4600122C00021900102B005A48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005F44389E00D88F00FB1300FB1200D98D003A9F00005F4400142D000219000F2900574A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005C472E9B00D69700FA1800FC0F00DB860045A20000624100162F000219000D2700544C
189300D0A800F72200FD0800E076005AA90000683A001B3300021A000A2500504E0B8E00
CCB200F62800FE0500E36E0065AC00006B36001E3500031A000A24004E4E088D00CBB500
F52A00FE0500E36D0065AC00006B37001D3500031A000A2400504E0C8E00CDB000F62600
FE0700E174005AA90000683B001A3200021A000C2600544C199300D1A500F81E00FD0B00
DD820045A30000614200152E00021900102A005B482F9C00D89200FB1300FA1500D69700
299900005849000E2800021900173000653E53A700E07700FE0700F62700CCB300068C00
004B4D00082200031B00243900732C85B500EA5600FF0000EF4200A9BE00007C1B003040
00041D00061F003C4600840BC5C300F33300FF0300E46A0065AC00006939001A3200021A
000D2700574A289900D69500FB1300FA1600D49B0020960000554C000C2600021A001E35
006D3474B000E75F00FF0100F03E00ADBF00007D1B00304000041D000620004148008803
C9B900F52900FE0700DF7A004AA40000614200132C00021900142D00624150A600E17500
FE0500F42E00C7BF0000850A003B4500051F00051E00374400830EC5C300F43000FE0500
E1730052A60000634100142D00021900142D00634053A700E27200FE0400F33200C1C400
00811200344200041D000620004148008900CBB400F72400FD0B00DB8700349D00005948
000D2800021A001D34006E327FB300EA5500FF0000EC4E008AB60000712E00203600031A
000C2700584A309C00DA8A00FD0B00F72400CBB500008803003E4700061F00051E003B45
008607C9B900F62600FD0A00DB8800319C0000584A000C2600031A00223700732A94B900
EE4700FF0000E7600069AD0000683B00162F00021900132D00643F5DAA00E56800FF0100
EF41009EBB0000762700243900031A000C2600584A339D00DC8500FD0900F52B00C6C100
00811100324100041C000821004E4E159200D49C00FB1200F91C00CEAC00038B00004048
00061F00051F003F47028A00CEAD00F91C00FB1300D49D00139100004C4D00072100041D
003643008509CAB800F72300FC0E00D794001D950000504E00082200041C00324100830F
C8BC00F62600FD0C00D8910021960000514D00082200041C00324100830EC8BC00F72500
FC0D00D793001D9500004F4E00082100041D003643008508CBB500F82000FB1100D49C00
12910000484C00062000051E003E47038B00CFA900FA1700FA1800CFAB00018A00003C46
00051E000720004C4D189300D69600FC0D00F62500C7BE00008013002E3F00031B000A24
00574A379E00DE7D00FE0400F13900A3BC00007429001F3600021900112B00634062AB00
E75E00FF0000EA56006FAF0000663D00132D000219001C3400722D9BBA00F13D00FF0400
DF7B00379E0000564B000A2400041C00324100840BCBB400F91D00FA1500D0A700018A00
003A4500041D00082200524D299900DC8400FE0600F23700A4BD0000742A001E35000219
00132D00673B76B100EB4F00FF0000E469004DA500005C47000C2600031B002C3E008112
C9BA00F81F00FB1400D0A700008A0000384400041C00092300554B379E00E07900FF0200
EF440088B600006C3600162F000219001B3300722CA2BC00F23600FE0700DA8A001F9600
004D4E00062000061F00494C1B9400D98E00FE0800F33400A5BD0000732C001B33000219
001730006D3490B800F03E00FE0400DC830027990000504E00072000061F00484C1A9400
D98D00FE0700F237009EBB0000702F001931000219001A3200712EA2BC00F33400FD0900
D8910014920000434900051E00082200534C359D00E07600FF0100EC4C0075B00000653E
00102A00021A00283B007F15C9B900F91C00F91900CBB500008112002A3C00031A000F2A
00643F73B000EC4C00FF0200E07900309C0000514D00072000061F004B4D229700DC8300
FF0400EF430081B40000673B00112B00021A00273B008015CAB700F91A00F91D00C8BC00
007D1A00243900021900132D006B378FB700F13B00FE0700
005949249800D39F00F91C00FD0B00DE7E004FA60000663D00193200021A000B2500514D
0F9000CDB000F62700FE0600E36F0065AC00006C36001F3500031A000923004B4D038B00
C9B900F42E00FF0300E5670070AF00006E3200213700031B00082200484C008900C8BC00
F43000FF0300E5660070AF00006E3200213700031B000923004B4D038B00CAB800F52C00
FE0400E36C0066AC00006B37001D3400031A000A2500514D109000CEAC00F72300FD0900
DF7A0050A60000653E001730000219000E2800574A269800D59900FA1700FB1100D88F00
329D00005B4700102A00021900142E00624148A300DE7F00FD0A00F72100CEAB000F9000
00504E000A2400031A002137006F3179B200E75E00FF0100F13C00B5C100008015003542
00051E00051E003643008113BAC200F13900FF0100E6620070AF00006D35001D3400021A
000B2600544C1E9500D49D00FA1700FB1200D793002A9A0000584A000D2700021A001A32
006A3868AD00E56600FF0200F23800BAC20000801400344200051E00061F003B4500840B
C6C000F42F00FE0500E2720055A70000643F00152E00021900122B005F4445A300DE7D00
FE0800F62800C9B80000880300404800062000041D003241007F15BAC200F23600FF0300
E36C005DAA0000663D00162F00021900122B00604348A400DF7900FE0600F52C00C7BF00
00840B00394400051E00051F003C46008607C8BB00F62900FE0800DD7F003FA100005C46
000F29000219001A32006B3773B000E85C00FF0000EE470096B90000752800243900031A
000B2500554B269800D89100FC0F00F81E00CEAE00048B0000444A00062000051D003543
00830EC6C000F52B00FE0700DD80003CA000005B47000E2800021A001E3500703088B600
EC4E00FF0000E9590075B100006B3700193100021900112B00614251A600E26F00FF0300
F13A00ABBE0000792100273B00031B000A2400554B299900D98D00FD0C00F72500C9B900
00850A00374400051D00072000484B0D8F00D1A400FA1700FA1700D1A5000B8E0000464B
00062000051E003A45008705CBB400F82100FC0F00D696001C950000504E00082200041C
003141008210C7BF00F62800FD0B00D98C0027990000534C00092300031B002E3E007F16
C5C300F52B00FD0900DA89002A9A0000544C000A2400031B002D3E007F15C5C300F52A00
FD0A00DA8C0026980000524D00092300041C003140008210C8BC00F72500FC0D00D79400
1B9400004F4E00072100041D003944008804CDB000F91C00FB1400D1A300098D00004249
00051F00061F00464B0F9000D49D00FB1100F82000CAB70000840C00324100041C000923
00544C2D9B00DC8400FE0700F33300AFBF0000782300233800021A000F29005F4456A800
E56600FF0000EC4F007AB20000693900152F000219001932006E328EB700EF4300FF0200
E1730041A100005949000B2500031B002D3E008112C8BC00F72200FB1100D3A0000A8E00
00404800051E000720004F4E209600D98C00FD0800F43100B1C00000772500213700021A
00112B00643F6AAE00EA5700FF0000E6620058A800005F44000E2800031A00283B007E19
C6C100F72400FC1000D39F00088D00003E4700051D00082200524D2C9A00DD8000FE0400
F03D0095B900006F31001931000219001831006F3195B900F13C00FE0500DD8200299900
00514D00072100051E004349129100D69500FD0B00F42E00B2C000007626001F35000219
00142E006A3884B500EE4500FF0300DF7B00319C0000524D00082100051E004249119100
D79500FD0A00F43000ABBE0000742A001C33000219001730006E3396B900F13A00FE0600
DA8A001D950000494C00061F00072000504E2B9A00DE7E00FF0300EE450081B40000683A
00122C00021A002439007C1CC6C000F82100FA1500CEAE0000840B002E3F00031B000E28
00614267AD00EB5300FF0000E271003B9F0000544C00082200051E00454A199400DA8B00
FE0600F03D008DB700006B3700142D000219002338007C1BC7BE00F81E00FA1800CBB500
00801300283B00021A00112B00673B82B400EF4200FE0400
00564B1B9400D0A600F82100FD0800E076005BA900006939001C3400031A000A24004E4E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00534D129100CEAE00F62600FE0600E36F0066AC00006C35001F3600031B00092300484C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00504E098D00CBB500F52C00FF0400E5670071B000006F3100233800031B000821004249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004B4D018A00C8BC00F33100FF0200E760007DB30000732C00273A00041C000720003C46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00454A008705C5C300F23700FF0100E9590089B600007627002B3D00041D00061F003744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003F4700830DBBC200F03E00FF0000EB520095B900007921002F3F00051D00051E003241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003A45008013AFBF00EF4400FF0000ED4B00A1BC00007C1B00344200051E00041D002E3F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003542007D1AA2BC00ED4A00FF0000EE4500ADBF0000801500394400061F00041C002A3C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003040007A2097B900EB5100FF0000F03E00B9C20000830E003E4700072000031C00263A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002C3D0077258BB600E95800FF0100F23800C5C40000860700434900082200031B002238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00283B00732B7FB300E75F00FF0200F33300C7BD0000890000494C00092300031A001F36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00243900702F74B000E56600FF0300F52D00CAB700078C00004F4E000A2400031A001C33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002137006D3469AD00E36D00FE0500F62800CDB0000F900000514D000B2600021A001931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001E35006A385FAA00E17400FE0700F72300CFA90017930000544C000D27000219001730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001B3300673B55A700DF7B00FD0A00F81E00D2A2001F960000574A000E2900021900142E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00183100643F4BA400DD8200FC0D00F91A00D49B00289900005A4800102A00021900122C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00162F00614241A100DB8900FC1000FA1600D79400319C00005C4600122C00021900102A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00142D005F44379E00D88F00FB1400FB1200D98D003A9F00005F4400142D000219000F29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00122C005C472E9B00D69600FA1700FC0F00DB860044A20000624100162F000219000D27
00554B199300D0A700F72100FD0900E0780057A80000683B001B3300021A000B2500514D
0D8F00CDB000F62700FE0600E2700061AB00006A38001D3400031A000A24004F4E0A8E00
CCB200F62800FE0600E2700061AB00006A38001C3400031A000B2500514D0F9000CEAD00
F72400FE0800E0770055A70000663D001931000219000D2700554B1D9500D2A100F91C00
FC0D00DB860040A10000604300132D00021900112B005C46359D00D98D00FC1000FA1800
D49C0023970000564A000D2700021900193100673C5AA900E27200FE0500F52A00CAB800
018A0000464B00082100031B00273B0075288EB700EB5100FF0000EE48009FBB00007920
002C3E00041C000720004048008705C7BD00F42E00FE0500E270005BA90000663C001830
000219000F29005A48319C00D98E00FC1000F91A00D2A20017930000524D000A2400031A
00213700702F80B400E95700FF0000EE4500A0BC00007921002B3D00041C00072100474B
058C00CCB100F72400FD0A00DD82003EA000005D4500102A00021900173000663D5DAA00
E36C00FF0300F33500BEC30000801300344200051D00061F003E47008705C9BA00F62900
FE0800DE7D0044A200005E4400112B00021900173000673C62AB00E56800FF0200F13B00
B0C000007C1B002D3E00041C000821004A4C0B8E00CFA900F91C00FC1000D79200269800
00554B000B2500031A00223800732B91B800ED4A00FF0000E9590077B100006C35001B33
000219000F29005C4640A100DE7D00FE0700F52C00C6C10000830F00354300041D000620
00444A058C00CEAD00F81D00FC1000D7950021960000534C000A2400031B00283B007921
AABE00F13B00FF0200E36D0055A70000624100122C000219001831006A3872B000E85A00
FF0000EC4D0087B500007030001D3400021A000F29005D4547A300E07600FE0400F23600
B3C000007B1E00293C00031B000A2400544C289900D98D00FD0B00F62600C8BB0000840C
00354200041D000721004C4D139100D49D00FB1300F91C00CEAD00018A00003F4700051E
00061F004249078C00D0A800FA1800FA1600D1A4000A8E0000444A00061F00051E003E47
018A00CEAC00F91A00FB1400D2A2000C8F0000464A00061F00051E003E47028A00CFAB00
F91900FA1600D1A500088D0000424900061F00061F0043490A8E00D1A300FB1500F91B00
CDAE00008801003A4500051D000721004D4E189300D69600FC0E00F72500C8BD00008111
002F3F00031B000A2400554B309C00DD8200FE0600F33400AFBF0000782300233800021A
000E29005F4452A700E46900FF0000ED4B0082B400006C36001730000219001730006B36
81B400ED4B00FF0000E46A0050A600005D45000D2800031A00263A007B1DBEC300F52C00
FD0A00D891001C9500004D4E00072000051E0041480A8E00D39F00FB1100F72200C8BC00
008013002C3E00031B000C26005A4847A300E36E00FF0100ED4A0080B300006A3800152E
000219001B3300712E9ABA00F13B00FE0400DD80002E9B0000534D00082200041D003B46
048B00D1A300FB1200F72200C7BE00007F1600293C00031A000D28005F4458A800E76100
FF0000E95A0063AB00006142000F2900031A00273A007D1AC6C100F72400FB1100D2A300
038B0000394500041C00092300564B3B9F00E17400FF0100ED4A007CB20000683B00132C
000219002137007822BBC200F52A00FC0E00D49D00088D00003C4600041D00092300564B
3CA000E17200FF0100EC4D0074B00000653E00112B00021A00263A007D19C7BE00F82000
FA1500CEAC0000860800304000031B000C27005E455CA900E85B00FF0000E566004BA500
005948000A2400041C003944058C00D39E00FC0D00F52C00B1C000007529001C34000219
00183100702FA1BC00F33300FD0900D695000D8F00003D4700041D00092300584949A400
E56600FF0000E75E0054A700005B47000B2500041C003944088D00D59A00FD0B00F33200
A2BC00007030001730000219001E35007823C0C400F72400
00102A005949269800D49D00F91B00FD0C00DD80004DA50000653E00193100021A000C26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000E2800564A1D9500D1A400F82000FD0900E0790057A80000683B001B3300021A000A24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000D2700544C159200CFAA00F72400FE0700E2720061AB00006B37001E3500031A000923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000B2600514D0E8F00CCB100F62900FE0500E46B006BAE00006D3300213700031B000822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000A24004F4E068C00CAB700F42E00FF0300E5650075B10000702F00243900031B000721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000923004A4C008900C7BD00F33300FF0200E75F007FB30000732B00273B00041C000620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00082200444A008606C5C300F23800FF0100E958008AB600007626002B3D00041D00061F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000721003F4800840CBBC200F03D00FF0000EB520094B900007921002F3F00051D00051E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000620003B45008112B0C000EF4300FF0000EC4C009EBB00007C1C00334100051E00051D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00061F003643007E18A6BD00ED4800FF0000EE4700A9BE00007F1700374300061F00041D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00051E003241007B1D9BBB00EC4E00FF0000EF4100B4C000008111003B4600062000041C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00051D002E3F00782291B800EA5400FF0000F13C00BEC30000840B00404800072100031B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00041D002B3D00762787B500E95A00FF0100F23700C5C20000870500454A00082200031B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00041C00273B00732B7DB300E76000FF0200F33200C8BC00008A00004A4C00092300031A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00031B00243900703074B000E56600FF0300F52D00CAB700078C00004F4E000A2400031A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00031B002137006D336AAE00E36C00FE0500F62800CCB1000E8F0000514D000B2500021A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00031A001E35006B3761AB00E27200FE0700F72400CFAB0015920000534C000C27000219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00031A001C3300683A58A800E07800FD0900F82000D1A5001C950000564B000E28000219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00021A00193200663D4FA600DE7E00FD0B00F91C00D39F00239700005849000F29000219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00021900173000634047A300DC8400FC0E00FA1900D599002B9A00005B4800112B000219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00021900152F0061423FA100DA8A00FB1100FA1500D79300329D00005D4600122C000219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00021900132D005E44379E00D89000FB1400FB1200D98D003A9F00005F4400142D000219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00021900122C005C462F9B00D69600FA1700FC0F00DB870042A20000624100162F000219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00021900102A005A48289900D49C00F91A00FC0D00DD81004AA40000643F001831000219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000219000F2900574A219600D2A100F81E00FD0A00DF7C0053A70000673C001A3200021A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000219000D2800554B1A9400D0A700F72100FD0800E076005BA900006939001C3400031A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000219000C2600534C139100CEAC00F62500FE0600E2700063AC00006B36001F3500031A
000923004A4C018A00C8BC00F43100FF0200E6630078B10000712F00243900031B000721
004249008608C5C400F23700FF0100E85C0081B40000732B00273A00041C000721004048
00850AC3C400F23800FF0100E85D007FB30000722C00253A00031B000721004349008705
C6C000F33200FF0200E6640072B000006E3200213700031B000923004D4E078D00CBB300
F62800FE0600E173005AA90000673B00193200021A000C2700554B1E9500D39F00F91A00
FC0E00DA89003A9F00005E4500122B00021900132D00604341A100DC8400FD0C00F81E00
D0A70014920000514D000A2500031A001F36006E3373B000E76100FF0100F13900BBC200
00811200374300051E00051E003542008015B6C100F13B00FF0100E7600073B000006D34
001E3500031A000B2500544C1D9500D39E00FA1800FB1200D793002A9A0000584A000D28
00021A001B32006A3869AD00E56600FF0200F23800B9C20000801500344200051D00061F
003C46008509C7BF00F42E00FE0500E1740052A70000634000142E00021900122C006043
49A400DF7A00FE0700F52A00C8BB00008606003E4700061F00051D003542008112C1C400
F33300FF0400E2700056A80000643F00142E00021900132D00624150A600E17400FE0500
F43100C4C40000821100354200051D00061F004048008901CBB500F72400FD0B00DB8700
359D00005A48000D2800021A001D34006E327FB300EA5500FF0000EC4F0089B60000712E
00203600021A000D27005849329C00DB8800FD0B00F72500CAB700008705003C4600051E
00051E003C46008704CAB600F72400FD0B00DA8B002D9B0000564A000B2600031A002338
0075289ABA00EF4300FF0100E6640063AB0000663D00152E00021900152E00663D64AC00
E66300FF0000EE460095B90000732B00213700021A000D27005A483B9F00DE7E00FE0600
F43000C0C300007E17002E3F00041C00092300514D1E9600D79400FC0F00F82100CBB400
008705003A4500051E00062000464B0B8E00D1A400FA1600FA1800D0A600098D0000444A
00061F00051E003D47008900CDAE00F91C00FB1300D39E0011900000494C00072000051D
003A45008704CCB200F81E00FB1200D49C00139100004A4C00072000051D003A45008802
CDB000F91C00FB1300D3A0000D8F0000464B00061F00051E003F48058C00D0A800FA1700
FA1800CFAA00028A00003D4700051E000720004A4C149200D59A00FC0F00F72200C9B900
00830D00324100041C00092300534C2C9A00DC8600FE0700F33100B4C100007921002539
00031A000E28005D454EA500E46B00FF0100ED480086B500006D3400183100021900162F
006A387EB300EC4D00FF0000E5680053A700005E45000E2800031A00253A007A1FBBC200
F52D00FD0A00D88F001D9500004E4E00072000051E004048098D00D3A000FB1100F72200
C8BC00008112002D3E00031B000C26005A4847A300E36E00FF0100ED4A0080B400006A38
00152E000219001B3300712E9BBA00F13B00FE0500DD81002D9B0000524D00082200041D
003C46058C00D2A200FB1100F72200C7BE00007F1700293C00031A000E28005F445AA900
E76000FF0000E85B0061AB00006142000E2900031A00283B007E18C7BF00F72200FB1200
D1A500018A0000384400041C00092300574A3EA000E27200FF0100EC4C0078B10000673C
00122C00021A002238007A20C0C300F62700FC0F00D3A000058C00003A4500041C000923
00574A41A100E36F00FF0000EB51006EAF00006340000F2A00031A00283B007F16C9BB00
F81E00FA1700CDB00000840C002D3E00031B000D2800604363AB00E95700FF0000E46B00
44A20000574A00092300041D003C460B8E00D59800FD0B00F43000A8BE0000722D001A32
000219001A3200732CAABE00F42F00FD0C00D49C00078C0000394400041C000A25005B47
52A700E76000FF0000E665004BA40000594900092400041D003E470F9000D79300FE0800
F2370096B900006D3400152E000219002237007B1DC6C000
00021A000B2500514D0D8F00CCB200F52900FE0500E46B006CAE00006E3300213700031B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00031A000A24004F4E078C00CAB700F42D00FF0300E5650074B00000703000243900031B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00031A000923004B4D018A00C8BC00F33200FF0200E760007DB30000732C00273A00041C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00031B00082200464B008704C6C100F23600FF0100E85B0086B50000752800293C00041C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00031B000821004249008509C1C400F13A00FF0000EA56008EB700007724002D3E00041D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00031C000720003E4700830EB8C100F03F00FF0000EB510097B900007A2000304000051D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00041C000620003A45008013AFBF00EF4400FF0000ED4C00A0BC00007C1C00334100051E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00041D00061F003643007E18A6BD00ED4800FF0000EE4700A8BE00007E1700374300061F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00051D00051E003341007C1C9EBB00EC4D00FF0000EF4200B1C000008112003A45000620
00041C00293C00742984B500E85B00FF0100F23700C5C30000860600434900082100031B
00233800702F76B100E66300FF0200F33100C7BD0000890100474B00082200031B002238
006F3174B000E66400FF0200F33200C7BE0000880300454A00082200031B00243900722D
7DB300E85E00FF0100F23800C1C40000840C003D4700062000041C002A3D00772592B800
EB5100FF0000EE4500A7BD00007D1B00324100051D00051E003643008015B3C000F03E00
FF0000E9590082B40000722C00243900031B000822004A4C058C00CBB400F62800FE0700
E0760054A70000653E001730000219000F290059482D9B00D79200FB1200FA1700D49B00
21970000554B000C2700021A001B33006A3868AD00E56800FF0200F33500C3C40000830E
00394500061F00051E003442007F15B6C100F13A00FF0100E662006FAF00006C36001C34
00021A000C2700564B259800D69700FB1300FA1600D49C001E950000544C000B2500031A
0020360070307EB300E95800FF0000EE46009EBB0000782300293C00031B000822004C4D
0B8E00CFAB00F81F00FC0D00DA8B00319C00005949000E2800021A001B33006C3672B000
E75E00FF0000EF4200A2BC0000792200293C00031B000822004E4E119000D1A500F91A00
FB1100D6950023970000544C000B2500031A00223800732B8FB800ED4C00FF0000EA5600
7CB300006E33001D3400021A000E28005A48379E00DC8400FD0A00F62700C9B900008706
003C4600051E00051E003C46008706C9B800F62600FD0A00DB8700339D00005949000D27
00021A00203600722D8DB700ED4B00FF0000E85A0073B000006B3700193100021900112B
0060434FA600E27100FF0300F23800B0C000007B1E002A3C00031B00092300524D219600
D79300FC0F00F82000CCB200008901003E4700051E00061F003F47018A00CDAF00F81E00
FC1000D598001B940000504E00082200041C003040008014C5C400F52D00FE0800DC8400
339D0000574A000B2600031A00263A007822ABBE00F23900FF0300E1750046A300005C46
000E2800021A00213700742A9BBA00F04000FF0200E36D0050A600005F44000F2A00021A
001E3500722D95B900EF4300FF0100E46B0052A70000604300102A00021A001F3500732C
98BA00EF4100FF0200E26F004CA500005E45000E2800021A002237007627A5BD00F13A00
FF0400DF79003DA000005949000C2600031B00283B007C1CBDC300F42E00FD0800DA8900
28990000524D00092300041C00344200840ACAB600F81F00FB1200D39F000D8F0000444A
00061F00061F00464A0F9000D49C00FC1000F72200C9BA0000821000304000031B000A24
00564B369E00DE7C00FE0400F13B009EBB0000732B001E3500021900122C00653E6CAE00
E95700FF0000E75E0060AB0000624100102A00021A002238007823B2C000F43100FD0800
DA8C00219600004F4E00072100051E004048098D00D39F00FC1100F72300C7BE00007F15
002B3D00031B000D27005C464FA600E56800FF0000EB510073B00000663D00122C000219
002036007626AEBF00F43100FD0900D98F001B9400004B4D00061F00061F00494C199300
D89000FD0900F43000AEBF00007627001F3500021900142D00693A7EB300ED4900FF0100
E174003CA00000564B00092300041C003944038B00D2A300FB1100F72500C5C300007C1C
00253900021A00102B00653E71AF00EB5000FF0000E26F0041A10000574A00092300041C
003945058B00D3A000FC0F00F62800BDC30000782200203700021900142D006A3886B500
EF4300FF0300DD800029990000504E00072000061F004B4D209600DB8700FE0500F03E00
8EB700006C3600152E000219002036007822BFC300F62600FB1100D0A600008803003241
00031B000C26005E455DAA00E95900FF0000E46B0043A20000574A00092300041D004048
129100D89000FE0700F2380095B900006D3400152E000219002137007A1FC5C200F72100
FA1600CCB10000820F002A3C00031A00102A00663D7DB300
00051E00051D002F3F00792195B900EB5200FF0000F03E00BAC20000830E003E47000720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00051E00041D002C3E0077258DB700EA5700FF0100F13A00C2C400008509004249000821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00061F00041C002A3C00752885B500E85B00FF0100F23500C6C10000880400464B000822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00062000041C00273B00732C7DB300E76000FF0200F33100C8BC00018A00004A4C000923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00072100031B00243900702F75B000E56500FF0300F42D00CAB700068C00004E4E000A24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00082200031B002237006E326DAE00E46A00FE0400F52A00CCB3000B8E0000504E000B25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00082200031B002036006C3566AC00E26F00FE0600F62600CEAE0011900000524D000C26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00092300031A001D35006A385EAA00E17400FE0700F72300CFA90017930000544C000D27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000A2400031A001B3300683B57A800E07900FD0900F82000D1A4001D950000564B000E28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000B2500021A001A3200663D50A600DE7E00FD0B00F91D00D3A00022970000584A000F29
00021900142D005F443A9F00D98D00FB1200FB1400D79200339D00005D4600122C000219
00112B005B472E9B00D69500FA1600FB1100D98C003A9F00005F4400132D00021900102A
005A482C9A00D69600FA1600FB1100D98D00379E00005E4500122C00021900112B005C46
349D00D88F00FB1200FA1500D696002B9A00005A48000F2900021900152E00624246A300
DD8100FD0B00F81E00D1A50017930000534C000B2600021A001C33006A3863AC00E36C00
FE0400F42E00C8BC0000880200444A00072100031C00283B0075278EB700EB5100FF0000
EE4600A2BC00007B1E002E3F00041D00061F003D4600850AC5C200F33300FF0300E46900
67AD00006A38001B3300021A000C2700564B239700D59A00FA1600FB1300D69500289900
00574A000D2700021A001A3200693966AC00E46800FF0200F23500C0C300008210003744
00051E00051E003743008211C0C300F23500FF0300E46A0062AB0000683B001931000219
000F29005B48359D00DA8900FC0D00F81F00CFAB000B8E00004C4D00082200031B00293C
0078239EBB00EE4500FF0000E95A007AB200006E33001E3500021A000C2700574A2B9A00
D89000FC0F00F91C00D0A8000D8F00004C4D00082200031C002B3D007A1FA8BE00F03F00
FF0100E6630069AD0000693A00183100021900102A005E4544A200DF7C00FE0700F52C00
C7BF0000840C00384400051E00061F003E47008803CAB600F72500FD0B00DB8700339D00
005949000D2700021A001F3600702F87B500EC4F00FF0000EA55007CB200006D34001C33
000219000F29005D4642A200DF7C00FE0600F42F00C4C40000801300324100041C000721
004B4D0F9000D1A400FA1700FA1500D3A000139100004D4E00082100041C003140008013
C5C400F42E00FE0700DD80003A9F00005A48000D2700031A00213700742A97B900EF4400
FF0100E566005EAA0000643F00132D000219001830006A3874B000E95700FF0000EB5300
7CB200006C3500193200021900122C0063405CAA00E56600FF0100EE460092B80000722D
001E3500021A000F29005F444EA500E26F00FF0200F03F009EBB0000752900213700021A
000E28005D4648A400E17300FF0300F03D00A0BC0000752800213700021A000E28005D45
4BA400E27000FF0200F0400099BA0000732C001F3500021900102A00614357A800E56700
FF0000ED490088B600006E33001A3200021900142D00663D6CAE00E95900FF0000E95800
6EAF0000673C00142D000219001A32006E328BB700EE4600FF0100E36D004DA500005D46
000D2800031A002539007A20B6C100F43000FE0800DA890026980000524D00082200041D
003744008804CDAE00F91900FA1700CFAB0000890000394500041D00082200514D269800
DB8800FE0700F33200AFBF0000772500213700021A00102A00624162AB00E85C00FF0000
E95A0066AC0000634000112B00021A002137007724B1C000F43000FD0900D98D001F9600
004E4E00072000051E0043490F9000D59A00FC0E00F62700C4C400007C1C00263A00031A
000F290061425FAA00E85D00FF0000E85D005FAA00006043000E2900031A00273B007D19
C6C100F72400FC1100D2A100058C00003B4600041D00082200544C359D00DF7900FF0200
EE440086B500006B3700152E000219001D34007429ACBF00F43100FD0900D79200159200
00454A00051E00072100504D2A9A00DD8000FF0400F040008CB700006C3600152F000219
001E35007527B1C000F42E00FD0C00D599000C8F00003E4700041D00092200554B3CA000
E27200FF0100EC4F0070AF0000643F00102A00031A00283B008014C9B800F91C00F91900
CBB400008211002A3D00031A000F290063406EAF00EC4F00FF0100E17400379E0000534C
00082100051E00464B1A9400DA8B00FE0600F13C008FB700006B3600142E000219002237
007B1EC6C100F82100FA1600CDB00000830E002B3D00031A000F2A00653E77B100ED4900
FF0200DE7F00279800004D4E00061F00072000524D349D00
000C2600021A00183100643F49A400DD8200FC0D00F91A00D49B00289900005A4800102A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000D2700021900162F00624143A200DB8700FC0F00FA1700D696002E9B00005C4700112B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000E2800021900152E0060433CA000D98C00FB1200FB1400D89100359D00005E4500132C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000F2900021900132D005E45369E00D89000FB1400FB1200D98D003B9F00005F4400142E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00102A00021900122C005C46309C00D69500FA1600FC1000DB880041A10000614200152F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00112B00021900112B005A482A9A00D59A00F91900FC0E00DC830047A300006340001730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00132C000219000F2A005949249800D39E00F91C00FD0C00DE7F004EA50000653E001931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00142D000219000E2900574A1F9600D2A300F81F00FD0A00DF7A0054A70000673C001A32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00152F000219000D2800554B1A9400D0A700F72100FD0800E076005BA900006939001C34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001730000219000C2700534C149200CFAB00F72400FE0700E2720061AB00006B37001E35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00183100021A000C2600524D0F9000CDAF00F62700FE0500E36D0068AD00006D35002036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001A3200021A000B2500504E0B8E00CBB400F52B00FE0400E469006EAF00006E32002237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001B3300031A000A24004F4E068C00CAB800F42E00FF0300E5650075B00000702F002439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001D3400031A000923004B4D028A00C8BB00F43100FF0200E761007BB20000722D00263A
00031C000720003E4700830DBBC200F03D00FF0000EA54008FB700007724002C3E00041D
00061F003744007F15ADBF00EF4300FF0000EC4F0098BA00007921002E3F00041D00051F
003643007F17ACBF00EF4300FF0000EB500095B900007822002D3E00041D00061F003945
008111B7C100F03D00FF0000E9580086B50000742A00273B00031C000721004349008705
C7BF00F33100FF0300E567006DAE00006D35001E3500031A000A2400504D109000CFAB00
F72200FD0A00DE7E004AA40000624100152E00021900102A005B47329C00D88F00FB1100
FA1800D49C0021960000564B000C2700021A001A3200693963AC00E46B00FF0300F43100
C6C000008508003E4700062000041D002E3F007B1DA6BD00EF4300FF0000E9570082B400
00712E00223800031B000A2400504E129100D0A700F81D00FC0D00DA8A00369E00005B47
000F2900021900173000663C5CA900E36E00FF0400F33200C5C30000830D00394500051E
00051E003643008211C1C400F33400FF0300E36C005DAA0000663C00173000021900102A
005D453FA100DD8100FD0900F62500CBB500008A0000434900072000041D003140007E18
B6C100F23800FF0200E46A0060AB0000663C00173000021900112B005F4447A300DF7A00
FE0600F52C00C7BF0000840B00394400051E00061F003C46008606C9BA00F62800FD0900
DD81003CA000005C47000F29000219001B33006C3577B100E95900FF0000ED4A0090B800
00732B00223700031A000C2600564A2C9A00D98C00FC0C00F72200CBB300008901003F48
00061F00051E003A45008608C9BA00F62600FD0A00DB8700329C0000584A000C2600031A
00223700742A96B900EE4600FF0000E6610067AD0000673C00162F00021900142E00653E
61AB00E56500FF0100EF440098BA0000742900223700031A000D27005949399F00DD8000
FE0700F42E00C3C400007F16002F3F00041C00082200514D1D9500D69600FC0F00F82000
CBB300008704003B4500051E00062000454A0A8E00D1A500FA1700FA1700D0A600098D00
00444A00061F00051E003D47008900CDAE00F91C00FB1300D39F0011900000494C000720
00051D003A45008803CCB100F81E00FB1200D49D0012910000494C00072000051E003B46
008901CDAE00F91C00FB1400D2A2000C8E0000454A00061F00051E004148078C00D0A600
FA1600F91A00CEAC00008900003C4600051E000720004C4D179300D69700FC0E00F72400
C8BC0000821000304000031C00092400554B309C00DC8200FE0600F33400AEBF00007823
00233800021A000E29005F4453A700E56800FF0000EC4C0080B400006B37001730000219
001830006C3584B500ED4900FF0100E36C004CA500005C46000D2700031A00283B007C1B
C3C400F52900FD0C00D79400179300004A4C00062000051F00444A0F9000D49B00FC0F00
F62500C6C100007E1700293C00031A000D27005D464FA600E46900FF0000EC4F0076B100
00673B00132D000219001E3500742AA5BD00F23600FE0700DB870025980000504E000721
00051E0041480D8F00D49B00FC0E00F62800C3C400007B1D00253900021A000F2A006241
65AC00E95800FF0000E6630055A700005D45000D2700031B002C3E008111CAB700F91D00
FA1700CEAD0000860700324100031B000B25005A484AA400E46900FF0000EA54006AAD00
006340000F2A00031A00273B007E18C7BE00F82100FB1400CFA90000870400334100031B
000B25005B474FA600E56500FF0000E85A005EAA00005F44000D2700031B002E3F00840C
CDB000FA1700F81E00C8BB00007F1600273B00021A00102A00653E73B000EC4C00FF0100
E07600359D0000534C00082100051E00454A189300D98D00FE0700F13A0094B900006D34
00162F000219001F36007823BFC300F62600FB1200D0A80000870500314000031B000D27
00604365AC00EA5400FF0000E27100399F0000534C00082100051E00484C1F9600DC8500
FE0400EF430081B40000673C00112B00021A00293C008111
001F3600031A00092300484B008802C7BF00F33400FF0100E85D0082B40000742A00283B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00213700031B00082200444A008706C5C300F23800FF0100E9590088B600007627002A3D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00233800031B00072100414800850AC0C300F13B00FF0000EA55008FB700007724002D3E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00253900031B000721003E4700830EB9C200F03E00FF0000EB510095B900007921002F3F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00273B00041C000620003B46008111B3C000EF4200FF0000EC4E009CBB00007B1E003141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00293C00041C00061F003944007F15ACBF00EE4500FF0000ED4A00A2BC00007D1A003442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002B3D00041D00061F003643007E18A6BD00ED4800FF0000EE4700A8BE00007E17003743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002D3E00041D00051E003342007C1C9FBC00EC4C00FF0000EF4300AFBF00008014003945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002F3F00051E00051E003140007A1F99BA00EB4F00FF0000F04000B5C100008210003C46
00072000041C00273B00732B81B400E85D00FF0100F23500C6C10000870500454A000822
00031B00233800703074B000E66400FF0300F43000C8BC0000890000484B00082200031B
002237006F3173B000E66400FF0300F33100C7BE0000880200454A00082200031B002439
00712E7DB300E85E00FF0100F23800C1C40000840C003D4700062000041C002B3D007724
93B800EB5000FF0000EE4500A6BD00007C1B00314000051D00051E003743008014B5C100
F03D00FF0100E85A0080B30000722E00233800031B000923004C4D078C00CCB200F62600
FE0700E0780051A60000643F00162F000219000F29005A48319C00D88F00FB1100FA1800
D39E001E950000544C000C2600021A001C34006C366DAE00E66400FF0200F23700BDC300
00811200374300051E00051E003643008112BCC300F23700FF0200E5660069AD00006A38
001B3300021A000D2700584A2B9A00D79200FB1100F91900D2A10018930000524D000A24
00031A00223800722D86B500EB5300FF0000ED4A0095B90000762700263A00031B000923
004F4E129100D1A500F91B00FC1000D891002A9A0000574A000C2700021A001E35006E32
7CB200E95800FF0000EE480098BA0000762700263A00031B00092400514D199300D39E00
FA1600FA1500D49C001A940000514D000A2400031B00263A0076259CBB00EE4500FF0000
E75E0070AF00006A37001A3200021900102A005D4543A200DE7C00FE0700F52D00C6C100
00830E00364300051D000620004249028A00CDB000F82000FC0E00D8900028990000554B
000B2500031A0024390076279CBB00EF4300FF0100E6640064AC0000663C00152F000219
00142E00653E5EAA00E56700FF0100EF41009FBC0000762600243900031A000B2600564A
2F9B00DB8900FD0A00F62700C8BC0000840C00364300041D00072000484C0D8F00D1A400
FA1700FA1700D1A3000D8F0000484C00072000051D003744008509C9B900F72400FC0D00
D8900024970000524D00092300031B002D3E007E18C0C300F42F00FE0700DD8200349D00
00574A000B2500031B00273B007A20B1C000F23500FE0500DF7B003EA000005A48000C27
00031A002539007823ABBE00F23800FE0400DF79003FA100005A48000C2700031A00253A
007921B0C000F33500FE0500DE7E00389E0000584A000B2500031B00293C007C1BBEC300
F42E00FD0800DB880029990000534C00092300041C00314000830EC9BA00F72300FC0F00
D59900149200004A4C00062000051E003F47058C00D0A600FA1600F91B00CDAF00008704
00384400041D00082200514D239700DA8C00FD0900F42E00BAC200007B1E00263A00031A
000D28005D464EA500E46B00FF0100ED4A0082B400006B36001730000219001831006D34
88B600EE4600FF0100E2700045A300005A48000C2600031B002C3D008014C7BD00F72300
FC1000D39E000B8E0000414800051E000720004F4E1F9600D98C00FD0800F43100B0C000
00772500213700021900112B00653E6CAE00EA5500FF0000E6640055A700005E45000D27
00031A002A3C007F16C7BE00F72200FB1200D1A300048B00003B4500041D00082200544C
339D00DF7B00FF0300EF42008CB700006C3500162F000219001B3300722DA0BC00F23700
FE0700DA8A00209600004D4E00062000061F004A4C1B9400D98D00FE0800F23500A2BC00
00722D001B33000219001730006E3294B900F13C00FE0500DB8600239700004E4E000620
00061F004B4D1F9600DB8900FE0600F13A0096B900006E32001730000219001C3400742A
ACBF00F42F00FD0B00D598000C8F00003E4700041D00092300564B3FA100E36F00FF0000
EA530068AD00006142000E2800031A002D3E00830DCDB000FA1600F81F00C7BE00007D1B
00243900021A00122C00693A84B500EF4200FE0400DC8400229700004B4D00061F000721
00524D329D00E07600FF0100EC4F006CAE00006241000E2800031B002F3F008608CFA900
FB1200F62700BBC200007626001D3400021900193100712E
00324100051E00051D002F3F00792293B800EB5300FF0000F03D00BBC20000830D003F47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00344200051E00041D002C3E0077248DB700EA5600FF0000F13A00C2C400008509004149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00374300061F00041C002A3D00752787B500E95A00FF0100F23700C5C30000870600444A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00394500061F00041C00283B00742A81B400E85D00FF0200F33400C7BF0000880200474B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003C4600072000041C00263A00722C7CB200E76100FF0200F33100C8BC00018A00004A4D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003E4700072100031B00253900712F76B100E66400FF0300F42E00C9B900048B00004D4E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00414800072100031B002338006F3171AF00E56800FF0400F52C00CBB500088D00004F4E
000A2400031A001C3300683A5AA900E07600FE0800F72200CFA90016920000534C000C26
00021900183100653E4EA500DE7D00FD0B00F81E00D1A4001C940000554B000D27000219
00173000643F4DA500DE7E00FD0A00F81F00D1A60019930000544C000C2600021A001932
00673C56A800E07600FE0700F72500CDAE000D8F0000504E000A2400031A001E35006C35
6BAE00E56800FF0300F43000C7BE0000870400434900072100031C00283B0075288CB700
EA5300FF0000EF4300A8BE00007D1A00314100051D00061F003844008111BAC200F13A00
FF0100E75F0077B100006F3200203600031A000A2400504D129100D0A800F81F00FD0C00
DC84003FA100005E4400122C00021900132D00614248A300DE7E00FD0900F72400CCB100
078C00004A4C00082200031B00273B00762793B800EC4D00FF0000EC4E0091B800007528
00263A00031B000922004D4E0C8F00CEAB00F82000FD0C00DB8700389E00005C47000F2A
00021900183000673C5FAA00E46B00FF0300F33500BFC30000811200354200051E00061F
003C46008508C7BE00F52C00FE0600E078004CA50000614200132C00021900152E00643F
55A800E27100FE0400F33300C2C40000811200344200051D00061F004048008802CAB700
F62600FD0900DC83003B9F00005B47000F29000219001B33006C3673B000E85C00FF0000
EE460098BA0000752700253900031B000A2400534C219700D69600FB1100F91B00D0A800
0B8E0000494C00072100041C003140007F15BFC300F33200FE0500E076004AA400005F44
00102A000219001932006B3774B000E95A00FF0000EC4C008BB70000712E001F3600021A
000D28005A483A9F00DD8100FE0700F52C00C6C20000811100334100041D000721004B4D
109000D2A200FA1600FA1700D1A4000E8F0000494C00072000041D00354300840CC8BC00
F62700FD0A00DA8A002C9A0000554B000A2500031B00283B007A20AFBF00F23700FE0400
E0760045A300005D46000E2800021A00203600732B96B900EF4300FF0100E4690058A800
00624200112B000219001B33006F3287B500ED4B00FF0000E6620062AB0000643F00132C
000219001A32006D3482B400EC4E00FF0000E7600063AC0000643F00132C000219001A32
006E3386B500ED4B00FF0000E665005CA90000624100112B000219001D3400712E94B900
EF4200FF0200E36F004BA500005D46000E2800031A002338007724ACBF00F23500FE0500
DD7F00349D0000564B000A2400031B002E3F008013C7BF00F62500FC0D00D69600179300
004B4D00072000051E003F47068C00D1A500FB1400F91C00CCB20000860800354200041C
00092300534C2C9A00DC8400FE0600F33500ABBE0000762600213700021A00102A006241
61AB00E85E00FF0000E958006AAE0000653E00122C000219001F36007528A7BD00F23600
FE0600DC850029990000524D00082200041D003B45028B00D1A600FB1400F81F00C9B800
008210002E3F00031B000B26005A4847A300E36D00FF0100EC4C007BB20000683A00142D
000219001D3400742AA6BD00F33500FE0700DA8A00219600004E4E00072000051E00454A
139100D79500FD0B00F42D00B5C10000772400203700021900122C00673C78B100EC4D00
FF0100E2700041A10000574A000A2400041C003743008900D0A600FB1200F72200C6C000
007D1A00263A00021A00102A0063406DAE00EB5200FF0000E36C0044A200005849000A24
00041C003844028A00D2A200FC1000F62700C0C30000792100213700021900132D006939
83B400EF4400FF0300DE7E002B9A0000504E00072000061F004A4C1E9600DB8800FE0500
F03D0090B800006C3500152E000219002036007823BEC300F62600FB1100D0A600008803
00334100031B000C26005E455DAA00E95900FF0000E46B0043A20000564A00092300041D
004148139100D89000FE0700F1390094B900006C3500152E000219002137007B1EC6C100
F82000FA1600CCB20000821100293C00031A00112B00673C
00444A00082200031B002137006E336CAE00E46B00FE0500F52900CCB2000C8F0000504D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00464B00082200031B002036006C3567AD00E36E00FE0600F62700CDAF0010900000524D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00494C00092300031A001E35006B3761AB00E27200FE0700F72400CEAB0014920000534C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004C4D00092300031A001D34006A395DAA00E17500FE0800F72200D0A80018930000544C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004E4E000A2400031A001C3300683A58A800E07800FD0900F82000D1A5001C940000564B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00504E000B2500021A001A3200673C53A700DF7B00FD0A00F81E00D2A2001F960000574A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00514D000B2500021A00193100653D4FA500DE7F00FD0C00F91C00D39F00239700005849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00524D000C2600021A00183100643F4AA400DD8200FC0D00F91A00D49C00279900005948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00534C000C2700021900173000634046A300DC8500FC0E00FA1800D598002B9A00005B48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00544C000D2700021900162F00624241A100DB8800FC1000FA1700D695002F9B00005C47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00564B000E2800021900152E0060433DA000DA8B00FB1100FA1500D79200339D00005D46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00574A000E2900021900142D005F44399F00D98E00FB1300FB1300D88F00379E00005E45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005849000F2900021900132D005E45359E00D89100FB1400FB1200D98C003B9F00005F44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00594900102A00021900122C005D46329C00D79400FA1600FC1000DA8A003FA100006142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005A4800112B00021900112B005C472E9B00D69700FA1700FC0F00DB870043A200006241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005B4700112B00021900112B005A482A9A00D59900FA1900FC0E00DC840047A300006340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005C4600122C00021900102A005948279900D49C00F91A00FC0D00DD81004AA40000643F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005E4500132D000219000F29005849249700D39F00F91C00FD0B00DE7E004EA50000653E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005F4400142D000219000F2900574A209600D2A100F81E00FD0A00DF7C0052A70000663C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00604300142E000219000E2800564B1D9500D1A400F81F00FD0900DF790056A80000673B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00614200152F000219000D2800554B1A9400D0A700F72100FD0800E077005AA90000693A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00624100162F000219000D2700544C179300CFA900F72300FE0800E174005DAA00006A39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006340001730000219000C2700534C149200CEAB00F72500FE0700E2720061AB00006B37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00643F00183000021A000C2600524D119100CEAE00F62600FE0600E26F0065AC00006C36
001F3600031A000923004A4C018A00C8BC00F43100FF0200E6630077B10000712F002439
00031B000821004349008607C5C300F23600FF0100E85E007EB30000722C00263A00031B
000721004249008607C5C300F23500FF0200E75F007BB20000712E00243900031B000822
00464B008901C8BC00F42F00FF0300E468006BAE00006C35001F3500031A000A2400504E
0D8F00CDAE00F72400FE0800E0780052A70000653E001730000219000E2800574A269800
D59900FA1600FB1200D89000319C00005B4800102A00021900152E0063404CA500DF7C00
FD0900F72400CDAF000A8E00004E4E00092300031B00233800722D81B400E95800FF0000
EF4100ABBE00007D1A00314000041D00061F003C4600840BC5C300F33200FF0300E46B00
63AB0000693A001A32000219000E280058492B9A00D79200FB1100FA1800D39F001B9400
00534C000B2500031A002036006F317DB300E95900FF0000EF4400A3BC00007A20002B3D
00041C00072100474B048B00CCB200F72400FD0A00DC83003DA000005D4600102A000219
00173000673C5FAA00E46B00FF0300F23700BAC200007F1500324100041D000620004148
008802CAB700F62600FD0900DD81003EA000005D4600102A0002190019310069396AAE00
E66200FF0100F04000A6BD00007921002A3C00031B000922004F4E139100D2A200FA1800
FB1400D59A001C950000524D000A2400031B00273A007724A0BC00EF4200FF0100E66200
68AD0000683A00173000021900122C0061424FA600E17200FF0400F23500B8C100007D19
002E3E00041C000822004E4E149100D3A000FA1600FA1700D2A200119000004C4D000821
00041C003140008014C3C400F42F00FE0600DE7C003FA100005C47000E2800021A001E35
00712F8CB700ED4B00FF0000E85D006CAE0000683A00162F00021900142D00653E61AB00
E66400FF0000EE460093B90000722C00203600021A000E28005C4743A200E07800FE0400
F23500B2C000007A1E00283B00031B000B2500564B2E9B00DB8700FD0900F52B00C5C200
008014002F3F00041C00092300524D229700D89000FD0C00F62600C8BC0000830E003341
00041C00082200504E1E9500D79300FC0D00F72500C8BB0000830E00324100041C000822
00514D229700D88F00FD0B00F62800C6C000008013002F3F00031B00092400544C2D9B00
DB8600FE0800F43000BAC200007B1D00283B00031A000C26005A4840A100E07600FF0300
F03D009DBB0000732B001F3500021900112B0062415EAA00E66100FF0000EB510078B100
00693900152F000219001831006D3487B500EE4800FF0100E36C004DA500005D46000D27
00031A00263A007B1EBDC300F52D00FD0A00D98F001E9600004F4E00072100051E003E47
068C00D1A400FB1300F81F00CAB70000830D00304000031B000A2400574A3CA000E07700
FF0200EF410090B800006F32001931000219001730006C3686B500EE4700FF0100E17200
41A100005849000B2500031B00314000840CCBB400F91B00FA1700CEAC00008704003542
00041C000A2400564A3B9F00E07600FF0200EE460085B500006B3700152F000219001C33
00722CA1BC00F23700FE0700DB8900229700004E4E00072000051F00474B169300D89200
FD0900F43000ADBF00007528001E3500021900152E006A3885B500EE4400FF0200DF7A00
329C0000534C00082200051D0040480E8F00D69800FD0B00F42E00B1C000007627001E35
00021900152E006C368CB700F04000FE0400DD8200279800004F4E00062000061F004B4D
1F9600DB8800FE0500F13C0092B800006D3400162F000219001E35007626B6C100F52A00
FC0E00D3A000038B0000374400041C000A25005A484FA600E66300FF0000E7600053A700
005B47000B2500041C003743038B00D39F00FC0D00F52C00AFBF0000742A001B33000219
00193200722DA9BE00F42F00FD0C00D49D00048B0000374300041C000B25005D465AA900
E95A00FF0000E36C0040A10000554B00082200051E00464B
00653E00193100021A000B2600514D0F9000CDB000F62800FE0500E36D0068AD00006D34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00663D00193200021A000B2500514D0C8E00CCB200F52A00FE0500E46B006CAE00006E33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00673C001A3200021A000B2500504E098D00CBB500F52B00FE0400E468006FAF00006F32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00683B001B3300031A000A24004F4E078C00CAB700F52D00FF0300E5660073B000007030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00693A001C3400031A000A24004E4E058B00C9B900F42F00FF0300E6640076B10000712F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006A39001D3400031A000923004C4D028B00C8BB00F43000FF0200E662007AB20000722D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006A37001E3500031A000923004A4C008A00C8BD00F33200FF0200E760007DB30000722C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006B36001F3500031A00092300484C008901C7BF00F33400FF0200E75E0080B40000732B
00273B00041C000620003C46008210B6C100F03F00FF0000EB520093B900007822002D3E
00041D00051F003643007E17AABE00EE4500FF0000EC4D009BBA00007A1F00304000051D
00051E003542007E18AABE00EE4400FF0000EC4F0097B900007922002D3E00041D00061F
003944008112B6C100F03E00FF0000E9570087B50000742900273B00031C000721004249
008705C7BF00F33100FF0300E567006DAE00006D35001E3500031A000A2400514D109000
CFAB00F72100FD0A00DE7E0049A40000624100152E00021900102A005B47339D00D98E00
FC1000FA1800D39D001F960000554B000C2600021A001B33006A3866AC00E46A00FF0300
F33200C5C20000850A003D4600061F00041D003040007C1BAABE00EF4100FF0000E95A00
7EB30000702F00213700031A000A2400514D159200D1A400F91B00FC0F00D98D00319C00
005A48000F2900021900193100683B61AB00E46A00FF0300F33500C0C300008211003743
00051E00051E00394500830DC5C200F43100FE0400E2710057A80000643F00152F000219
00122B005F4446A300DE7C00FE0700F62900C9B900008704003F4700061F00051D003442
008113BFC300F33400FF0300E26F0057A80000643F00152E00021900132D00624150A600
E17400FE0400F33100C4C40000811100344200051D000620004148008900CBB300F72300
FD0B00DB8800339D00005949000D2700021A001E3500703083B400EB5200FF0000EB5100
84B500007030001E3500021A000D28005A48379E00DC8400FD0900F62800C8BB00008509
00394500051E00061F004048008A00CCB100F82000FC0E00D8900026980000544C000A25
00031B00263A007823A5BD00F03E00FF0200E46B0058A80000634000132C000219001730
00693970AF00E85B00FF0000EC4D0088B600007030001D3400021A000F29005E4548A300
E17500FF0400F23700B1C000007A1F00283C00031B000A2400554B2B9A00DA8A00FD0A00
F62800C7BE0000820F00334100041C000821004F4E189300D59900FC1000F81F00CCB200
008803003B4500051E00062000474B0D8F00D2A200FB1500F91A00CFAB00038B00003F47
00051E00061F00444A0A8E00D1A400FA1600F91900CFAA00038B00003F4700051E00061F
00454A0D8F00D2A100FB1400F91C00CDAF00008802003A4500051D000721004C4D179300
D59800FC0F00F72300C9BA0000830E00324100041C00092300534C299900DB8800FD0800
F42F00BBC200007B1D00273B00031A000C27005B4844A200E17300FF0200EF410095B900
00712F001C3400021900132C00653D6BAE00E95800FF0000E85B0067AD0000643F00122C
000219001E3500732B9FBC00F13B00FE0400DE7D00359D0000564B000A2400041C003241
00840CCBB500F81E00FB1400D1A500048B00003C4600051D00072100504E249800DA8900
FE0700F33300ADBF0000762600203600021900112B00643F6AAE00E95700FF0000E76100
5AA900006043000E2800031A00263A007C1BC5C400F62700FC0E00D49B000E8F00004249
00051E000721004F4E249700DB8800FE0600F23700A2BC0000732C001C3400021900152E
006B3785B500EE4600FF0200E07700399F0000554B00092300041C003945028B00D1A300
FB1100F72300C6C100007D1A00263A00021A000F2A00634069AD00EA5500FF0000E46900
4AA400005A48000B2500031B003442008704CFA900FB1400F82100C7BE00007D1900263A
00021A00102A00643F70AF00EB5000FF0100E270003EA00000564B00092300041D003D46
0A8E00D59A00FD0C00F42E00AFBF00007529001C34000219001730006F3299BA00F23800
FE0700D98E0017930000454A00051E00082100534C379E00E17400FF0100EC4F006EAF00
006340000F2900031A002C3D00830ECDB000FA1600F82000C6C000007C1C002338000219
00132D006A378CB700F03D00FE0600DA8B0019930000444A00051E00082200554B40A100
E46B00FF0000E85B0059A900005C46000B2500041C003944
006C3500203600031B00082200474B008803C6C100F23500FF0100E85C0083B400007429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006D3400213700031B00082200454A008705C5C200F23700FF0100E95A0086B500007528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006E3300223700031B000822004349008607C5C400F23800FF0100E958008AB600007626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006F3200223800031B000821004249008509C2C400F13A00FF0000EA56008DB700007725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00703000233800031B00072100414800840BBFC300F13B00FF0000EA550090B800007824
002D3E00041D00051F003542007E19A6BD00EE4800FF0000ED4900A3BD00007D1A003342
00051E00051D003040007A1F9ABA00EC4E00FF0000EF4400ABBE00007E1700364300051F
00041D002F3F007A209ABA00EC4D00FF0000EE4600A7BD00007D1A00334100051E00051E
003241007C1BA6BD00EE4600FF0000EC4E0097B900007822002C3E00041D00061F003B46
00830EBEC300F13900FF0100E85D007CB20000712F00233800031B000923004B4D068C00
CBB400F62800FE0600E1750057A80000663D001831000219000E2800584A279900D69800
FA1500FB1300D794002B9A00005949000E2900021900173000663D57A800E17300FE0600
F52B00C9B90000890100444A00072100041C002A3D0078239ABA00ED4A00FF0000EB5000
8DB70000742900263A00031B000822004D4E0A8E00CEAD00F72100FD0B00DC83003EA000
005E4500112B00021900152E00643F53A700E17400FE0500F52D00C7BE00008607003D47
00061F00051D003341007F16B8C200F23800FF0200E5670065AC0000683A001931000219
000F29005B47389E00DB8600FD0B00F72200CDB000058C0000464B00072100041C002E3F
007C1BAFBF00F13C00FF0100E5660065AC0000683A00183100021900102A005E4542A200
DE7E00FE0700F52A00C8BC00008608003B4500051E00051E003A45008509C8BD00F52A00
FE0800DE7F0040A100005D46000F29000219001A32006B3674B000E85B00FF0000ED4900
93B90000742A00233800031A000B2600564B2A9A00D98E00FC0D00F82100CCB200008900
00404800061F00051E003944008509C9BB00F62700FD0A00DB8700339D00005849000C26
00031A00223700742A95B900EE4600FF0000E7610067AD0000673C00162F00021900142E
00653E61AB00E66500FF0100EF440098BA0000742A00213700031A000D27005A483A9F00
DE7F00FE0700F42F00C1C400007F17002E3F00041C00092300514D1F9600D79400FC0E00
F72100CBB50000870600394500051D00062000474B0D8F00D2A300FA1600FA1900D0A800
068C0000424900061F00051E003F48038B00CEAB00F91A00FB1400D2A1000D8F0000474B
00062000051E003C46008900CDAE00F91B00FB1400D2A1000E8F0000464B00062000051E
003E47028A00CFAB00F91900FA1600D1A600078D0000414800051F00061F00444A0B8E00
D2A100FB1400F91C00CCB10000870400384400041D000721004F4E1D9500D79200FD0C00
F62700C6C100007F15002D3E00031B000A2500574A379E00DE7D00FE0400F23900A5BD00
00752800203600021A00102A0061425DAA00E66200FF0000EB520076B10000683A00152E
000219001A32006F318FB800EF4300FF0200E1730042A200005A48000B2600031B002C3D
008014C7BE00F72400FC0F00D49C000E8F0000444A00051E000620004B4D189300D79300
FD0B00F52B00BDC300007B1E00253900031A000F290060435CA900E76000FF0000E95800
69AD0000643F00112B00021A002237007823B5C100F42E00FD0A00D89100199400004A4C
00061F00061F00494C189300D89100FD0A00F42F00B2C00000772500203600021900122C
00663C75B100EC4E00FF0000E36D0046A300005949000B2500031B003341008607CEAD00
FA1600F81D00CAB800008112002B3D00031A000D27005F445BA900E75E00FF0000E75F00
58A800005E45000D2700031B002E3E00830DCCB300F91900F91B00CBB500008210002C3D
00031A000E2800604361AB00E95900FF0000E567004CA500005A48000A2500041C003643
008A00D1A400FC1000F62700C0C30000792100213700021900142D006A3889B600F04000
FE0400DC8400239700004D4E00061F00062000504E2A9A00DE7E00FF0300EE46007DB300
00673C00112B00021A00263A007F17C9BA00F91C00F91A00CAB60000801400283B00021A
00112B00663C7DB300EE4600FF0300DD8100249800004C4D00061F00072000524D339D00
E17500FF0100EB510067AD00006043000D2700031B003241
00702F00243900031B000721003F4700840DBCC200F03D00FF0000EB530093B800007822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00712E00253900031C000720003E4700830EB9C200F03F00FF0000EB510095B900007921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00722D00263A00041C000720003D46008210B6C100F04000FF0000EB500098BA00007A1F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00732C00273B00041C000620003B46008111B3C000EF4100FF0000EC4E009BBA00007B1E
00314000051E00051E003140007A1E9BBA00EC4E00FF0000EF4300AFBF00008014003844
00061F00041D002B3D0077258FB700EA5400FF0000F03E00B7C100008211003B4500061F
00041C002B3D0077258FB700EA5400FF0000F04000B2C00000801400384400061F00041D
002E3F0079209ABA00EC4C00FF0000EE4800A2BC00007B1D00314000051D00051E003643
007F15B2C000F03F00FF0000E9570087B50000742A00263A00031B00082100454A008901
C9BB00F42D00FE0400E36E0061AB00006939001B3300021A000C2600554B1E9500D39F00
F91900FC1000D98D00349D00005C4700102A00021900152E0063404DA500DF7A00FE0800
F62600CCB300068C00004A4C00082200031B00263A0075288FB700EB5000FF0000ED4A00
99BA0000772400293C00041C00082100474B038B00CBB400F62600FE0800DE7C0048A400
00614200132D00021900132D00614249A400DF7B00FE0700F62800CAB700008900004349
00072000041C002E3F007C1CACBF00F03E00FF0100E7610070AF00006B36001B3300021A
000D280059492F9B00D98D00FC0E00F81E00CFA9000C8F00004C4D00082200031C002A3C
007921A4BD00EF4200FF0000E75F0070AF00006B37001A32000219000F29005B47399F00
DC8500FD0A00F72500CBB50000890100404800061F00051D003543008210C5C300F42F00
FE0500E0780049A400005F4400112B00021900183000683A69AD00E66200FF0100EF4200
9FBB0000772500263A00031B000A2400534C219700D69500FC1000F91D00CFAB00078D00
00464A00072000041D00344200820FC6C100F52C00FE0700DD7F003CA000005B47000E28
00021A001E3500712F8AB600EC4C00FF0000E85B0072B000006A3800183100021900122C
00624157A800E46B00FF0200F03E00A3BC0000772500253900031A000B2600574A319C00
DB8600FD0900F52A00C6C00000821000324100041C000821004E4E169300D49B00FB1200
F91D00CDAE00018A00003E4700051E00061F004249058C00CFAA00F91A00FA1500D2A100
0E8F0000484B00072000051E003A45008804CCB200F81F00FB1100D49B00159200004C4D
00072100041D003744008607CBB500F82000FC1000D59A00169200004C4D00072100051D
003944008704CCB100F81D00FB1200D39F000F900000474B00062000051E003F47048B00
D0A800FA1700FA1800CFAA00028A00003D4700051E000720004A4C149200D59900FC0F00
F72300C9BA0000830F00314000041C00092300544C2E9B00DC8400FE0600F33300B0C000
00782300233800021A000E28005F4452A700E46800FF0000ED4B0081B400006B36001730
000219001730006C3584B500ED4900FF0100E36C004CA500005C46000D2700031A00283B
007D1BC4C400F62900FD0C00D6950016930000494C00061F00061F00454A109000D59A00
FC0E00F62600C5C200007E1900293C00031A000D27005D4551A600E56700FF0000EB5100
73B00000673C00132C000219001E35007528A9BE00F33400FE0700DA8A00219700004F4E
00072000051E004349109000D59800FC0D00F52A00BEC300007A1F00233800021A00102A
0064406BAE00EA5500FF0000E5660050A600005C47000C2600031B002E3F00830DCBB400
F91A00FA1900CCB10000840B00304000031B000C26005C4751A600E66500FF0000E95900
63AB00006142000E2800031A002A3C008014C9B900F81D00FA1700CDAF0000850A003040
00031B000C26005D4657A800E75F00FF0000E7600056A800005D46000C2600031B003141
008606CFAA00FB1400F72200C6C100007C1C00243900021A00122C00673B7EB300EE4600
FF0300DE7D002C9A0000504E00072000061F004B4D219700DC8500FE0400F0400088B600
006A3800132D000219002338007B1DC6C000F82000FA1600CDB00000830D002C3D00031A
000F2900634072B000EC4C00FF0200DF7A002D9B0000504E00062000061F004F4E2A9A00
DF7C00FF0200ED4B0072B000006340000E2900031A002E3F
00732B00283B00041C000620003A45008113B0C000EF4300FF0000EC4D009EBB00007B1D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00742A00293C00041C00061F003944008014AEBF00EF4400FF0000ED4B00A0BC00007C1B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00752900293C00041C00061F003844007F16ABBE00EE4600FF0000ED4A00A3BC00007D1A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007528002A3D00041C00061F003743007E17A8BE00EE4700FF0000ED4900A5BD00007D19
00354200051F00041D002D3E00782391B800EA5400FF0000F03D00B9C20000820F003D46
00072000041C00283B00742985B500E95A00FF0100F13900C1C40000840B003F47000720
00041C00273B00742A85B500E95900FF0100F13B00BDC30000830E003C4600062000041C
002A3D00772590B800EB5200FF0000EF4200ADBF00007E1700354200051E00051E003241
007D1AA7BE00EE4500FF0000EB510091B800007626002A3C00041C000720004048008607
C6C000F33200FF0300E568006BAE00006C36001D3400031A000B2500524D179300D1A500
F91D00FC0D00DB86003DA000005E4500122C00021900132D00604344A200DD8000FD0A00
F72200CEAC000D8F00004F4E00092300031B00233800722D84B500EA5600FF0000EE4500
A3BC00007A1F002D3E00041C000720004249008803C9BA00F52B00FE0600E0760051A600
00634000152E00021900112B005E4540A100DD8100FD0A00F72400CCB100058C0000484B
00082100041C002B3D007921A2BC00EF4300FF0000E85B0079B200006E33001E3500021A
000C2600564B279900D79300FB1100F91A00D1A30014910000504E00092300031B00273A
00762699BA00EE4700FF0000E959007AB200006E33001D3400021A000D27005849309C00
DA8B00FC0D00F82100CDAF00048B0000454A00072000041D003140007F16BCC300F33400
FF0400E2710052A70000624100132D00021900162F00663D60AB00E56800FF0200F03D00
A9BE00007A2000293C00031B00092300514D1A9400D49B00FB1300FA1900D1A5000E8F00
004B4D00072100041C003040007F15C0C300F43100FE0500DF790045A200005D45000F29
000219001C33006E3380B300EB5200FF0000EA55007BB200006D35001A3200021900102A
0060434EA500E27200FF0300F23900ADBF00007A2000283B00031B000A2400544C299900
D98D00FD0B00F62500C9BA0000840B00364300041D00072000494C0F9000D2A100FA1500
FA1900D0A800078D0000434900061F00051E003D46008900CDB000F81D00FB1100D49B00
159200004D4E00072100041D00364300850ACAB800F72300FC0E00D794001D950000504E
00082200041C00334200830DC9BB00F72400FC0D00D793001D950000504E00082200041C
00354200850ACAB700F72100FC0F00D59800169200004C4D00072100051D003A45008802
CDAE00F91B00FB1500D1A400098D0000424900061F00061F00454A0D8F00D39F00FB1200
F81E00CBB40000850900354200041C00082200524D269800DA8A00FD0900F42E00BBC200
007B1E00273A00031A000D27005C474AA400E36F00FF0100EE46008BB600006E33001931
00021900152F0069397AB200EC4F00FF0000E5660055A700005F44000E2800031A002539
007A20B9C200F42E00FD0A00D98E001E9500004E4E00072000051E004048098D00D3A000
FB1100F72200C8BC00008013002C3E00031B000C26005B4848A400E36D00FF0100ED4B00
7DB30000693900152E000219001C3300722D9FBB00F13900FE0500DC840029990000514D
00082100051D003E47098D00D39F00FC0F00F62500C5C200007D1A00273A00031A000F29
00614261AB00E85B00FF0000E7600059A900005E44000D2700031A002B3D008013C9BA00
F81E00FA1500CFAB0000870500334200031C000B2500594848A300E46B00FF0000EB5300
6CAE0000634000102A00021A00263A007D19C7BF00F72200FB1300CFA900008803003442
00031B000B25005B484EA500E56500FF0000E95A005FAA00005F44000D2700031B002E3E
00840CCDB000FA1700F81E00C8BB00007F1600273B00021A00102A00653E74B000EC4C00
FF0100E07700349D0000534C00072100051E00464B1A9400DA8B00FE0600F13B0092B800
006C3500152E000219002036007922C2C400F72500FB1200CFAA00008607002F3F00031B
000D2800614268AD00EB5200FF0100E17400359E0000524D00072100051F004B4D229700
DD8200FF0300EE45007CB20000663D00102A00031A002A3D
007626002B3D00041D00061F003643007E18A6BD00ED4800FF0000EE4700A8BE00007E18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007725002C3D00041D00061F003542007D19A4BD00ED4900FF0000EE4600AABE00007F16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007724002D3E00041D00051E003442007D1BA2BC00ED4B00FF0000EE4500ACBF00007F15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007823002D3E00041D00051E003342007C1C9FBC00EC4C00FF0000EF4400AEBF00008014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007822002E3F00051D00051E003241007B1D9DBB00EC4D00FF0000EF4200B1C000008013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007921002F3F00051D00051E003241007B1E9BBB00EC4E00FF0000EF4100B3C000008112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00792100304000051E00051E003140007A1F99BA00EC4F00FF0000F04000B5C100008211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007A2000304000051E00051E003040007A2097BA00EB5000FF0000F03F00B6C100008210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007A1F00314000051E00051D00304000792096B900EB5100FF0000F03E00B8C20000830F
003D4700072000041C00273A00732C7EB300E75F00FF0200F33400C6C00000880400454A
00082200031B002238006F3173B000E56500FF0300F43000C8BC0000890000484C000822
00031B002237006F3172B000E66500FF0300F33100C7BE0000880300454A00082200031B
00243900722D7EB300E85D00FF0100F23900C0C30000830D003D4600062000041C002B3D
00782395B900EC4F00FF0000EE4700A3BD00007C1D00304000051D00061F003844008112
B8C200F13B00FF0100E85C007CB30000712F00223800031B000923004E4E0A8E00CDB000
F72500FD0800DF7B004DA50000634000152E00021900102A005C47359D00D98C00FC0F00
F91A00D2A1001A940000534C000B2500031A001E35006D3472B000E76100FF0100F13B00
B6C100007F1500344200051E00051F00394500830EC4C400F33400FF0300E46B0062AB00
00683A001931000219000E29005A48319C00D98D00FC0F00F91C00D0A60012910000504E
00092300031B0025390074298FB800EC4E00FF0000EB50008CB70000732B00233800031B
000A2400524D199400D39F00FA1700FB1300D5980021970000544C000B2500031A002137
00712E87B500EB5200FF0000EC4E008CB70000732C00223800031A000B2500544C229700
D69600FB1200F91900D1A400119100004E4E00082200031B002A3D007A1FA9BE00F03E00
FF0100E5660063AC0000673C00162F00021900122C0061424FA600E17300FE0400F33400
BCC300007F1600304000041C000721004A4C0C8F00D0A700F91A00FB1200D599001C9500
00514D00092300031B002A3C007A1FADBF00F13A00FF0200E36E0055A70000624100122C
0002190017300069396EAF00E85D00FF0000ED4A008EB70000712E001F3600021A000E28
005B473EA000DE7D00FE0600F43000C1C400007F16002F3F00041C00082200504E1B9400
D59800FB1100F81E00CDAF00008A00003F4700051E00061F004048028B00CEAD00F91C00
FB1200D49D00149200004D4E00072100041D00354200840CC8BB00F72500FD0C00D89000
23970000524D00092300041C002F3F008015C5C300F52B00FD0900DA89002B9A0000544C
000A2400031B002C3E007E17C3C400F52C00FD0900DB88002B9A0000544C000A2400031B
002E3E007F15C5C200F52900FD0A00D98D0024980000524D00092200041C00324100830D
C9B900F72300FC0F00D59800169200004B4D00072000051E003C46018A00CFAB00FA1800
FA1700CFA900028A00003D4600051E000720004C4D189300D69600FC0D00F62600C7BF00
008014002D3E00031B000B2500574A3A9F00DF7A00FF0400F13C009DBB0000732B001E35
00021900122C00643F69AD00E95900FF0000E85B0066AC0000643F00112B000219001F36
007528A6BD00F23700FE0600DC83002C9A0000534C00082200041C003844008802CEAB00
FA1700F91B00CCB10000850800334100041C000A2400564B399F00E07900FF0300EF4100
8FB800006E32001831000219001730006D348CB700EF4300FF0200E07800389E0000564B
00092300041C003643008802CFAA00FA1500F81E00CAB700008210002D3E00031B000C26
005C4650A600E56600FF0000EA55006AAD0000634000102A00021A002539007B1DC5C400
F62600FC0F00D3A000068C00003B4600041D00092300554B389E00E07600FF0200ED4800
7EB30000683A00132D000219002137007823BBC200F52A00FC0E00D49D00088D00003C46
00041D00092300564B3EA000E27100FF0100EC4F0070AF0000643F00102A00021A00273B
007F17C8BB00F81E00FA1700CDB00000840C002E3E00031B000D2800604363AB00EA5700
FF0000E46B0044A20000574A00092300041D003D460C8F00D69700FD0A00F33200A5BD00
00712E001931000219001B3300742AAEBF00F52D00FC0D00D39E00038B0000374300041C
000B25005C4657A800E85C00FF0000E4680045A30000574A00092300041D004149159200
D98E00FE0600F13C008EB700006B3700132D00021A002439
007B1E00324100051E00051D002F3F00792194B900EB5200FF0000F03E00BAC20000830E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007B1D00324100051E00051D002E3F00782292B800EA5300FF0000F03D00BCC20000830D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007C1C00334100051E00041D002E3F00782391B800EA5400FF0000F13C00BDC30000840C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007C1C00344200051E00041D002D3E0078248FB700EA5500FF0000F13B00BFC30000840B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007C1B00344200051E00041D002D3E0077248EB700EA5600FF0000F13A00C0C40000850A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007D1A00354200051F00041D002C3E0077258CB700E95700FF0000F13A00C2C400008509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007D1900354300061F00041D002C3D0077258BB600E95700FF0100F13900C3C400008508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007E1900364300061F00041D002B3D0076268AB600E95800FF0100F23800C4C400008608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007E1800364300061F00041D002B3D00762689B600E95900FF0100F23800C5C400008607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007E1800374300061F00041D002B3D00762788B600E95900FF0100F23700C5C300008606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007E1700374300061F00041C002A3D00752787B500E95A00FF0100F23700C5C300008706
00444A00082200031B002238006F3270AF00E56700FF0400F52D00CAB700058C00004D4E
00092400031A001E35006B3665AC00E36E00FE0500F62900CCB3000A8E00004F4E000A24
00031A001D35006B3764AC00E36E00FE0500F52A00CBB500068C00004D4E00092300031A
002036006E336FAF00E56600FF0300F33100C7BE0000870400444A00072100031B00263A
00742A86B500E95700FF0000F03F00B3C00000801500364300051E00051D003241007D1A
A9BE00EF4300FF0000EA54008BB60000752900273B00031B00082100464B008900C9B900
F52B00FE0500E272005AA90000673C001831000219000E2800584A299900D69500FB1400
FA1500D5980025980000574A000D2700021A001A3200693964AC00E46A00FF0300F33300
C5C40000830D003A4500061F00051D003341007F16B4C100F13B00FF0100E6620070AF00
006C35001C3400021A000C2700564B259800D69600FB1300FA1700D49D001D950000534C
000B2500031A00203600702F81B400EA5600FF0000EE47009ABA0000772400283B00031B
000822004E4E0E8F00D0A800F91D00FC0F00D98F002D9B0000584A000D2700021A001D34
006D3378B100E95A00FF0000EE46009BBA0000772500273A00031B00092300504D179300
D3A000FA1700FB1400D49B001C950000524D000A2400031B00253A0076269ABA00EE4600
FF0000E85D0071B000006B37001A3200021900102A005D4642A200DE7C00FE0700F52C00
C6C00000830E00364300051D000620004249028B00CDB000F82000FC0E00D89000279900
00554B000B2500031A0025390076269EBB00EF4200FF0100E6650062AB0000663D00152E
00021900142E00653E60AB00E56600FF0100EF42009CBB0000752700233800031A000C26
00574A319C00DB8600FD0900F62900C7BE0000830E00344200041D000721004A4D109000
D2A100FA1500FA1800D0A6000A8E0000464A00062000051E003945008606CBB500F72200
FC0E00D793001F960000514D00092300041C002F3F008014C5C300F52C00FD0900DB8600
2F9B0000564B000A2500031B00293C007C1CB8C200F33200FE0600DD7F00379E00005849
000B2600031B00273B007A1FB4C000F33300FE0600DE7E00389E0000584A000B2500031B
00283B007B1DB9C200F43000FE0700DC8400309C0000554B000A2400031B002D3E007F15
C5C200F62900FD0B00D88F0021960000514D00082200041D003643008608CBB400F81E00
FB1200D3A0000C8F0000444A00061F00061F00444A0D8F00D39F00FB1200F82000CAB700
00840B00334100041C00092300544C2D9B00DC8300FE0600F33400ADBF00007725002237
00021A000F290061425BA900E66200FF0000EB520074B00000673B00142D000219001B33
00712F97B900F03E00FF0300DF7A00399F0000564A000A2400031C00324100840BCBB400
F91D00FA1500D0A800008A0000394500041D00082200534D2C9A00DD8200FE0500F13900
9EBB0000722D001C3400021900142E0069397DB300ED4B00FF0100E36F0045A300005948
000B2500031B00304000840BCCB300F91B00FA1800CDAF0000860700334100031C000A25
00594943A200E26F00FF0100EC4D0078B10000673C00122C000219002036007724B5C100
F52D00FD0B00D6970010900000424900051E00072100514D2C9A00DD7F00FF0400F04000
8DB700006C3500162F000219001D34007429ABBE00F43100FD0A00D79400129100004249
00051E00082100524D319C00DF7A00FF0200EE47007FB30000683B00122C000219002338
007A1FC5C400F72400FB1200D0A70000880300334200031B000B26005C4655A700E75F00
FF0000E6620051A600005B47000B2500041C003743028A00D2A000FC0E00F52B00B4C100
007527001D340002190018300070309FBC00F33400FD0900D695000E8F00003D4700041D
0009240058494AA400E56500FF0000E7600052A700005B48000A2400041C003B450A8E00
D69700FD0A00F334009DBB00006F3200162F000219002036
007F1700374400061F00041C002A3C00752886B500E85B00FF0100F23600C5C200008705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007F1600384400061F00041C002A3C00752885B500E85B00FF0100F23600C6C200008705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007F1600384400061F00041C00293C00752984B500E85B00FF0100F23600C6C100008704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007F1500384400061F00041C00293C00742984B400E85C00FF0100F23500C6C100008804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007F1500394400061F00041C00293C00742983B400E85C00FF0100F33500C6C000008803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00801500394400061F00041C00293C00742982B400E85D00FF0100F33500C6C000008803
00464B00082200031B002137006D336CAE00E46A00FE0400F52B00CBB500088D00004F4E
000A2400031A001D34006A3860AB00E27100FE0600F62700CDB0000D8F0000504E000A25
00031A001C34006A3860AB00E27000FE0600F62800CCB300098D00004F4E000A2400031A
001F35006C356BAE00E46900FF0300F42F00C8BC0000890100464B00082200031B002539
00722C81B400E95A00FF0100F13C00B7C10000811200384400061F00051D003040007C1C
A4BD00EE4600FF0000EB51008FB80000762700283B00041C00072100444A008802C8BB00
F42D00FE0400E36F005EAA0000683B001932000219000D2700574A259800D59800FA1500
FB1400D6950029990000584A000E2800021900193200683A60AB00E36C00FF0400F43100
C6C10000850A003C4600061F00041D003140007D19B0C000F03D00FF0100E75F0074B000
006D34001E3500021A000C2600554B229700D59900FB1500FA1500D59A0020960000544C
000B2600031A001F36006F317CB300E95900FF0000EE45009FBB0000782200293C00031B
000822004C4D0B8E00CFAB00F81F00FC0D00D98C00319C00005949000D2800021A001C33
006C3574B000E85D00FF0000EF44009FBC0000782300283B00031B000923004F4E139100
D2A200FA1900FB1300D598001F960000534C000A2400031B00243900752895B900ED4800
FF0000E85A0076B100006C35001B33000219000F29005C463EA000DD7F00FE0800F52A00
C7BE0000840B00384400051E00061F004048008900CCB200F72200FC0D00D98D002B9A00
00564B000B2500031A00233800752899BA00EE4400FF0000E6620067AD0000673C00162F
00021900142D00643F5CA900E46900FF0100F04000A1BC0000772500253900031A000B25
00564B2E9B00DA8900FD0A00F62700C8BB0000840B00364300041D00072000484B0D8F00
D1A400FA1700FA1700D1A3000D8F0000484C00072000051D003744008509CAB800F72400
FC0D00D8910023970000524D00092300031B002D3E007E17C2C400F42E00FE0800DC8400
329D0000574A000B2500031B00283B007A1FB3C000F33400FE0500DE7D003B9F00005949
000C2600031A00263A007921AFBF00F23600FE0500DF7C003B9F00005949000C2600031A
00273B007A1FB4C100F33300FE0600DD8100349D0000564A000A2500031B002B3D007E18
C4C400F52B00FD0A00D98C0025980000524D00082200041C00344200840ACAB600F82000
FB1100D49D000F900000464B00061F00051F0042490A8E00D2A200FB1300F81E00CBB400
00850900344200041C00092300534C2A9A00DB8600FE0700F33200B1C000007823002338
00021A000F29005F4457A800E56500FF0000EB500078B10000693A00152E000219001A32
00703093B800EF4100FF0300E077003CA00000584A000A2500031B00304000830ECAB700
F81E00FB1400D1A500038B00003B4600041D00082200514D299900DC8500FE0600F23700
A3BC0000732B001D3400021900142D00683B79B200EC4D00FF0000E36C0049A400005A48
000B2600031B002F3F00830ECBB600F91C00FA1600CEAC0000870500344200041C000A24
00574A3FA100E27200FF0100ED4A007CB30000683A00132D000219001F36007626B1C000
F42F00FD0A00D7940014910000444A00051E00072100504E289900DD8200FE0400F03E00
91B800006D34001730000219001B3300732BA7BD00F33300FD0900D8910015920000454A
00051E00072100514D2E9B00DE7D00FF0300EE440083B40000693900132D000219002137
007921C1C400F62600FC1000D1A40000890000354200031C000B25005B4751A600E66200
FF0000E75F0055A700005C47000B2500031B003542008900D2A300FC0F00F62900B9C200
007725001E35000219001730006E329BBA00F23600FD0800D79200119000003F4800041D
00092300574A46A300E56800FF0000E85D0056A800005C47000B2500041C003944078D00
D59A00FD0B00F33200A2BC00007030001730000219001F35
00801400394500061F00041C00283C00742A82B400E85D00FF0100F33400C6C000008803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00801400394500062000041C00283B00742A81B400E85D00FF0200F33400C7BF00008802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00801400394500062000041C00283B00742A81B400E85D00FF0200F33400C7BF00008802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008014003A4500062000041C00283B00742A81B400E85E00FF0200F33400C7BF00008802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008014003A4500062000041C00283B00742A81B400E85E00FF0200F33400C7BF00008802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008014003A4500062000041C00283B00742A80B400E75E00FF0200F33400C7BF00008802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008014003A4500062000041C00283B00742A80B400E75E00FF0200F33400C7BF00008802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008014003A4500062000041C00283B00742A80B400E75E00FF0200F33400C7BF00008802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008014003A4500062000041C00283B00742A80B400E75E00FF0200F33400C7BF00008802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008014003A4500062000041C00283B00742A81B400E85E00FF0200F33400C7BF00008802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008014003A4500062000041C00283B00742A81B400E85E00FF0200F33400C7BF00008802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00801400394500062000041C00283B00742A81B400E85D00FF0200F33400C7BF00008802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00801400394500062000041C00283B00742A81B400E85D00FF0200F33400C7BF00008802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00801400394500061F00041C00283C00742A82B400E85D00FF0100F33400C6C000008803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00801500394400061F00041C00293C00742982B400E85D00FF0100F33500C6C000008803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007F1500394400061F00041C00293C00742983B400E85C00FF0100F33500C6C000008803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007F1500384400061F00041C00293C00742984B400E85C00FF0100F23500C6C100008804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007F1600384400061F00041C00293C00752984B500E85B00FF0100F23600C6C100008704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007F1600384400061F00041C002A3C00752885B500E85B00FF0100F23600C6C200008705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007F1700374400061F00041C002A3C00752886B500E85B00FF0100F23600C5C200008705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007E1700374300061F00041C002A3D00752787B500E95A00FF0100F23700C5C300008706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007E1800374300061F00041D002B3D00762788B600E95900FF0100F23700C5C300008606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007E1800364300061F00041D002B3D00762689B600E95900FF0100F23800C5C400008607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007E1900364300061F00041D002B3D0076268AB600E95800FF0100F23800C4C400008608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007D1900354300061F00041D002C3D0077258BB600E95700FF0100F13900C3C400008508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007D1A00354200051F00041D002C3E0077258CB700E95700FF0000F13A00C2C400008509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007C1B00344200051E00041D002D3E0077248EB700EA5600FF0000F13A00C0C40000850A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007C1C00344200051E00041D002D3E0078248FB700EA5500FF0000F13B00BFC30000840B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007C1C00334100051E00041D002E3F00782391B800EA5400FF0000F13C00BDC30000840C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007B1D00324100051E00051D002E3F00782292B800EA5300FF0000F03D00BCC20000830D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007B1E00324100051E00051D002F3F00792194B900EB5200FF0000F03E00BAC20000830E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007A1F00314000051E00051D00304000792096B900EB5100FF0000F03E00B8C20000830F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007A2000304000051E00051E003040007A2097BA00EB5000FF0000F03F00B6C100008210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00792100304000051E00051E003140007A1F99BA00EC4F00FF0000F04000B5C100008211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007921002F3F00051D00051E003241007B1E9BBB00EC4E00FF0000EF4100B3C000008112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007822002E3F00051D00051E003241007B1D9DBB00EC4D00FF0000EF4200B1C000008013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007823002D3E00041D00051E003342007C1C9FBC00EC4C00FF0000EF4400AEBF00008014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007724002D3E00041D00051E003442007D1BA2BC00ED4B00FF0000EE4500ACBF00007F15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007725002C3D00041D00061F003542007D19A4BD00ED4900FF0000EE4600AABE00007F16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007626002B3D00041D00061F003643007E18A6BD00ED4800FF0000EE4700A8BE00007E18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007528002A3D00041C00061F003743007E17A8BE00EE4700FF0000ED4900A5BD00007D19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00752900293C00041C00061F003844007F16ABBE00EE4600FF0000ED4A00A3BC00007D1A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00742A00293C00041C00061F003944008014AEBF00EF4400FF0000ED4B00A0BC00007C1B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00732B00283B00041C000620003A45008113B0C000EF4300FF0000EC4D009EBB00007B1D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00732C00273B00041C000620003B46008111B3C000EF4100FF0000EC4E009BBA00007B1E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00722D00263A00041C000720003D46008210B6C100F04000FF0000EB500098BA00007A1F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00712E00253900031C000720003E4700830EB9C200F03F00FF0000EB510095B900007921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00702F00243900031B000721003F4700840DBCC200F03D00FF0000EB530093B800007822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00703000233800031B00072100414800840BBFC300F13B00FF0000EA550090B800007824
002D3E00041D00051F003542007E19A6BD00EE4800FF0000ED4900A3BD00007D1A003342
00051E00051D003040007A1F9ABA00EC4E00FF0000EF4400ABBE00007E1700364300051F
00041D002F3F007A209ABA00EC4D00FF0000EE4600A7BD00007D1A00334100051E00051E
003241007C1BA6BD00EE4600FF0000EC4E0097B900007822002C3E00041D00061F003B46
00830EBEC300F13900FF0100E85D007CB20000712F00233800031B000923004B4D068C00
CBB400F62800FE0600E1750057A80000663D001831000219000E2800584A279900D69800
FA1500FB1300D794002B9A00005949000E2900021900173000663D57A800E17300FE0600
F52B00C9B90000890100444A00072100041C002A3D0078239ABA00ED4A00FF0000EB5000
8DB70000742900263A00031B000822004D4E0A8E00CEAD00F72100FD0B00DC83003EA000
005E4500112B00021900152E00643F53A700E17400FE0500F52D00C7BE00008607003D47
00061F00051D003341007F16B8C200F23800FF0200E5670065AC0000683A001931000219
000F29005B47389E00DB8600FD0B00F72200CDB000058C0000464B00072100041C002E3F
007C1BAFBF00F13C00FF0100E5660065AC0000683A00183100021900102A005E4542A200
DE7E00FE0700F52A00C8BC00008608003B4500051E00051E003A45008509C8BD00F52A00
FE0800DE7F0040A100005D46000F29000219001A32006B3674B000E85B00FF0000ED4900
93B90000742A00233800031A000B2600564B2A9A00D98E00FC0D00F82100CCB200008900
00404800061F00051E003944008509C9BB00F62700FD0A00DB8700339D00005849000C26
00031A00223700742A95B900EE4600FF0000E7610067AD0000673C00162F00021900142E
00653E61AB00E66500FF0100EF440098BA0000742A00213700031A000D27005A483A9F00
DE7F00FE0700F42F00C1C400007F17002E3F00041C00092300514D1F9600D79400FC0E00
F72100CBB50000870600394500051D00062000474B0D8F00D2A300FA1600FA1900D0A800
068C0000424900061F00051E003F48038B00CEAB00F91A00FB1400D2A1000D8F0000474B
00062000051E003C46008900CDAE00F91B00FB1400D2A1000E8F0000464B00062000051E
003E47028A00CFAB00F91900FA1600D1A600078D0000414800051F00061F00444A0B8E00
D2A100FB1400F91C00CCB10000870400384400041D000721004F4E1D9500D79200FD0C00
F62700C6C100007F15002D3E00031B000A2500574A379E00DE7D00FE0400F23900A5BD00
00752800203600021A00102A0061425DAA00E66200FF0000EB520076B10000683A00152E
000219001A32006F318FB800EF4300FF0200E1730042A200005A48000B2600031B002C3D
008014C7BE00F72400FC0F00D49C000E8F0000444A00051E000620004B4D189300D79300
FD0B00F52B00BDC300007B1E00253900031A000F290060435CA900E76000FF0000E95800
69AD0000643F00112B00021A002237007823B5C100F42E00FD0A00D89100199400004A4C
00061F00061F00494C189300D89100FD0A00F42F00B2C00000772500203600021900122C
00663C75B100EC4E00FF0000E36D0046A300005949000B2500031B003341008607CEAD00
FA1600F81D00CAB800008112002B3D00031A000D27005F445BA900E75E00FF0000E75F00
58A800005E45000D2700031B002E3E00830DCCB300F91900F91B00CBB500008210002C3D
00031A000E2800604361AB00E95900FF0000E567004CA500005A48000A2500041C003643
008A00D1A400FC1000F62700C0C30000792100213700021900142D006A3889B600F04000
FE0400DC8400239700004D4E00061F00062000504E2A9A00DE7E00FF0300EE46007DB300
00673C00112B00021A00263A007F17C9BA00F91C00F91A00CAB60000801400283B00021A
00112B00663C7DB300EE4600FF0300DD8100249800004C4D00061F00072000524D339D00
E17500FF0100EB510067AD00006043000D2700031B003241
006F3200223800031B000821004249008509C2C400F13A00FF0000EA56008DB700007725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006E3300223700031B000822004349008607C5C400F23800FF0100E958008AB600007626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006D3400213700031B00082200454A008705C5C200F23700FF0100E95A0086B500007528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006C3500203600031B00082200474B008803C6C100F23500FF0100E85C0083B400007429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006B36001F3500031A00092300484C008901C7BF00F33400FF0200E75E0080B40000732B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006A37001E3500031A000923004A4C008A00C8BD00F33200FF0200E760007DB30000722C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006A39001D3400031A000923004C4D028B00C8BB00F43000FF0200E662007AB20000722D
00253A00031B000721003F4700840CBDC300F13C00FF0000EA56008DB700007625002B3D
00041C00061F003944008014B1C000EF4100FF0000EB510094B900007822002D3E00041D
00061F003844008014B1C000EF4100FF0000EB520090B800007725002B3D00041C000620
003C4600830EBDC300F13A00FF0100E85B0081B40000722C00253900031B00082200464B
008901C8BB00F42E00FF0400E46B0066AC00006B37001D3400021A000B2500524D159200
D0A700F81F00FD0B00DC830043A20000604300132D00021900112B005D46399F00DA8A00
FC0E00F91B00D2A2001A940000534C000B2600021A001D34006C366CAE00E56500FF0200
F23600C1C40000830E003A4500061F00051D003241007E18B1C000F03E00FF0100E85D00
77B100006E32001F3600031A000B2500534C1A9400D3A000FA1900FB1100D891002C9A00
005849000E28000219001A32006A3868AD00E56600FF0200F23800B9C200008015003442
00051D00061F003C46008509C7BE00F42D00FE0500E1750051A60000634000142E000219
00132D0061424CA500E07800FE0600F52C00C7BD00008508003C4600061F00051E003743
00820FC5C300F43000FE0500E1740051A60000624100132D00021900142E00644056A800
E27000FF0300F33400BCC300007F1500324100041D00072000454A048B00CDAF00F82000
FC0D00D98D002D9B0000574A000C2600031A00203600712E8AB600EC4E00FF0000EA5500
7DB300006E33001C3400021A000E28005B473CA000DD8000FE0800F52B00C7BF0000830D
00364300051D000620004349048B00CEAD00F81E00FC1000D7950021960000534D000A24
00031B00293C007A20ACBF00F13A00FF0300E36F0052A70000614200112B000219001931
006B3776B100E95700FF0000EB510081B400006E33001B3300021900102A005F444DA500
E27100FF0300F13A00AABE0000782200263A00031B000B2500564A309C00DB8600FD0900
F52B00C6C20000811300304000041C00082200504E1D9500D69500FC0F00F72100CAB600
00860700384400051D000720004A4D129100D39E00FB1200F91D00CDAF00008901003C46
00051E00062000474B0E8F00D2A000FB1400F91C00CDAE00008900003C4600051E000720
00494C119100D49D00FB1200F81E00CBB30000860600374400041D000721004F4E1C9400
D79400FC0D00F62500C7BE00008111002F3F00031C00092400544C2E9B00DC8400FE0700
F33200B4C10000792100253A00031A000D27005C464AA400E36F00FF0100EE44008EB700
006F31001A3200021900142D00673B72B000EA5400FF0000E75F0061AB0000624100112B
00021A002036007528A6BD00F23700FE0500DD8100309C0000544C00092300041C003442
008607CCB100F91B00FA1600CFAA0000890000394500041D00082200524D2A9900DC8500
FE0600F23600A6BD00007429001E3500021900122C00663D70AF00EB5300FF0000E56500
54A700005E45000D2800031A00293C007E18C6C000F72400FC1000D39F00098D00003F47
00051D00082100514D299900DC8300FE0500F13A009BBB0000712F001A32000219001730
006C358BB600EF4200FF0300DF7B00339D0000544C00082200041D003C46078C00D39F00
FC0F00F62600C4C400007B1E00243900021A00112B00643F70AF00EB5100FF0000E36D00
44A200005849000A2400041C003643008900D1A500FB1200F72400C5C200007C1C002439
00021A00112B00663D76B100EC4C00FF0100E17400389E0000544C00082200051D004048
0F9000D69600FD0A00F43100A8BE0000732C001B3300021900193100702FA0BC00F33500
FD0800D7920012910000414900051D00082200554B3CA000E27000FF0000EB530068AD00
006142000E2800031B002E3F00850ACEAC00FB1400F72300C5C300007A20002137000219
00152E006C3593B800F13A00FE0700D88F0014910000414800041D00092300574A46A300
E56700FF0000E75F0053A700005B48000A2400041C003C46
00693A001C3400031A000A24004E4E058B00C9B900F42F00FF0300E6640076B10000712F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00683B001B3300031A000A24004F4E078C00CAB700F52D00FF0300E5660073B000007030
00233800031B000821004249008608C4C400F23800FF0100E95A0086B50000752900293C
00041C000620003C46008210B8C200F03E00FF0000EA55008DB700007626002B3D00041C
00061F003B45008210B8C200F03D00FF0000EA570089B60000752800283B00041C000720
003F4700850AC4C400F23700FF0100E75F007AB20000702F00233800031B00082200494C
038B00CAB700F52B00FE0500E26F0060AB00006939001B3300021A000C2600544C1B9400
D2A200F91C00FC0D00DB87003DA000005E4400122C00021900122C005F443FA100DC8500
FD0C00F81E00D0A60015920000524D000B2500031A001F35006E3373B000E76100FF0100
F13900BAC20000811200374300051E00051E003543008014B8C200F13A00FF0100E66200
71AF00006D35001D3400021A000C2600554C209600D49B00FA1600FB1300D69600269800
00574A000D2700021A001C33006B366EAF00E66200FF0100F13C00B2C000007E18003140
00041D000620004048008704C9BA00F52A00FE0700DF79004AA40000614200132C000219
00142E00634052A600E17400FE0500F42F00C6C10000830D00394400051E00051E003A45
00840BC7BF00F52D00FE0600E078004BA40000604300122C00021900162F00653E5CAA00
E46B00FF0200F23800B5C100007D19002F3F00041C00072100484C098D00CEAB00F81E00
FC0F00D8910028990000554B000B2500031A00223800732B91B800ED4A00FF0000E95900
76B100006C35001B33000219000F29005D4642A200DF7C00FE0600F42E00C5C300008111
00334200041D00072000474B098D00CFA900F91B00FB1200D599001C940000514D000923
00031B002B3D007C1CB3C000F23700FF0400E173004CA500005F4400102A000219001B33
006D347DB300EA5300FF0000EA55007AB200006C35001A3200021900112B00614254A700
E36D00FF0200F03E00A2BC0000772500243900031A000C26005849369E00DD8200FE0700
F42E00C2C400007F17002E3E00031C00092300524D229700D89000FC0D00F72400C9BA00
00840B00354200041D000721004E4E179300D59900FC1000F81F00CBB300008705003944
00051D000720004B4D139100D49C00FB1100F81E00CCB20000870500394400041D000721
004D4E169300D59900FC0F00F72100CAB70000840B00344200041C00082200514D219600
D88F00FD0B00F62900C6C200007F15002D3E00031B000A2400564B349D00DD8000FE0500
F23500ADBF0000772400233800021A000E28005E4550A600E46A00FF0100ED480087B500
006D3400193100021900152F00693978B100EB5000FF0000E663005AA900006142000F2A
00021A002237007725ADBF00F33400FE0700DC85002A9A0000524D00082200041D003744
008803CEAD00FA1800FA1900CEAE0000870400364300041C00092300544C2F9B00DD8000
FE0500F13A009FBB0000732C001D3400021900142D00683B77B100EC4F00FF0000E46900
4EA500005C46000C2700031B002B3D008014C8BC00F72100FB1200D1A300048B00003B46
00041D00082200534C2F9B00DE7F00FE0400F03E0094B900006F31001931000219001831
006E3292B800F03E00FE0400DD7F002D9B0000524D00082100051D003F480C8E00D49B00
FC0D00F52A00BCC30000792100223800021A00122C00663C77B100EC4D00FF0100E27100
3EA00000574A00092300041C003945048B00D2A100FC0F00F62700C1C400007A20002238
00021900122C00683B7DB300EE4800FF0200DF7900339D0000534C00082100051E004349
149200D89100FD0800F33400A1BC0000712E001931000219001A3200722CA7BD00F33100
FD0A00D696000D8F00003E4700041D00092300574A42A200E36C00FF0000E9570061AB00
005F44000D2700031B003140008706D0A800FB1200F62600BFC300007823001F36000219
00162F006E329ABA00F23600FD0800D794000F9000003E4700041D000A240059494CA500
E66300FF0000E663004DA50000594900092400041D003F47
00673C001A3200021A000B2500504E098D00CBB500F52B00FE0400E468006FAF00006F32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00663D00193200021A000B2500514D0C8E00CCB200F52A00FE0500E46B006CAE00006E33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00653E00193100021A000B2600514D0F9000CDB000F62800FE0500E36D0068AD00006D34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00643F00183000021A000C2600524D119100CEAE00F62600FE0600E26F0065AC00006C36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006340001730000219000C2700534C149200CEAB00F72500FE0700E2720061AB00006B37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00624100162F000219000D2700544C179300CFA900F72300FE0800E174005DAA00006A39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00614200152F000219000D2800554B1A9400D0A700F72100FD0800E077005AA90000693A
001C3300031A000A24004F4E088D00CBB500F52B00FE0400E46A006CAE00006D34002036
00031B00092300494C008900C8BC00F43000FF0300E5650073B000006F3100223800031B
00082200474B008900C8BC00F43000FF0300E567006FAF00006E3300203600031A000923
004C4D068C00CBB500F52A00FE0500E2700060AB00006939001B3300021A000B2500524D
159200D0A700F81F00FD0B00DD800048A30000624100152E00021900102A005A482F9B00
D89200FB1200FA1600D5980027990000584A000E2800021900183000663D56A800E17400
FE0600F62900CAB600028B0000484B00082200031B00273A0075288DB700EB5100FF0000
EE48009EBB00007921002C3E00041C000720004148008704C8BC00F52D00FE0500E27200
58A80000653D001730000219000F2A005B47359D00DA8B00FC0E00F91D00D0A600129100
00504E00092400031B00233800732C88B600EB5200FF0000ED4A0097B90000762600273B
00031B000822004D4E0C8F00CFAA00F81F00FC0D00DA8A00339D00005A48000E28000219
001A32006A386BAE00E66300FF0100F13D00AEBF00007C1C002E3F00041C00072100464B
058C00CDB000F72100FD0C00DA8900349D00005A48000E2800021A001C33006C3576B100
E85B00FF0000EE46009ABA0000762600263A00031B000A2400524D1C9500D49B00FB1400
FA1800D2A200139100004F4E00082200031B002B3D007B1EACBF00F13C00FF0200E46900
5DAA0000653E00152E00021900142D00643F5AA900E46B00FF0200F13B00ABBE00007A1F
00293C00031B00092300514D1C9500D59800FB1200F91B00CFA900088D0000464B000720
00041D00354300830EC7BF00F52A00FD0900DC8400359D00005949000C2700031A002237
00742998BA00EF4400FF0100E6650061AB0000653E00142D00021900162F00683A6DAE00
E85D00FF0000EC4C0087B500006F31001C3400021900102A005F444DA500E27100FF0300
F13B00A6BD0000772400253900031A000C26005949389E00DD8000FE0600F43100BCC200
007D1A002B3D00031B000A2400554B2C9A00DB8800FD0900F52B00C5C300007F15002E3F
00031B00092300534C279900DA8B00FD0A00F52A00C5C200008015002E3F00031B000924
00544C2B9A00DB8800FD0800F42D00C0C300007D1A002A3D00031B000B2500574A369E00
DE7E00FE0500F23500ADBF0000782300243900031A000E28005D464BA400E26F00FF0200
EF430091B800007030001C3300021900132C00653E69AD00E85A00FF0000E958006DAE00
00663D00132D000219001B3300702F93B800EF4100FF0200E1730043A200005A48000C26
00031B002A3D007E17C6C200F62700FC0D00D6960016920000494C00062000051F004349
0E8F00D49D00FC1000F72300C7BE00008014002C3D00031B000C26005A4846A300E27000
FF0100EE480084B500006B3600162F000219001932006F3192B800F04000FF0300DF7A00
379E0000554B00092300041C003543008704CEAC00FA1700F91B00CBB30000840C003040
00031B000B2500594945A300E36E00FF0100EC4C007AB20000683B00132D000219001F35
007527AEBF00F43100FD0900D8900019930000484C00061F000620004D4E1F9600DA8A00
FE0700F23600A1BC0000722D001B33000219001730006D3391B800F03E00FE0400DD8200
28990000504E00072000051E00464B179300D89000FD0900F33300A5BD0000722C001B33
000219001830006F3298BA00F13A00FE0600DA8A001D9500004A4C00061F00072000504E
289900DD8000FF0300EF420086B500006A3800132D000219002137007A20C3C400F72500
FB1200D0A70000880300334100031B000C26005D455AA900E85C00FF0000E5670049A400
005849000A2400041C003C460B8E00D69800FD0A00F33200A3BD0000712F001831000219
001C34007527B6C100F52900FC0F00D1A40000880200324100031B000D2700604365AC00
EA5300FF0100E17300369E0000524D00072100061F004C4D
00604300142E000219000E2800564B1D9500D1A400F81F00FD0900DF790056A80000673B
001B3300021A000B2500504E0B8E00CCB200F62900FE0500E36D0068AD00006C35001F36
00031A000923004B4D038B00C9B900F42E00FF0300E567006FAF00006E3300213700031B
000923004A4C028A00C9B900F42E00FF0400E469006BAE00006D35001F3600031A000924
004E4E098D00CCB300F62800FE0600E272005CAA0000683A001A3200021A000C2600534C
189300D1A500F81E00FD0C00DC830044A20000614200142E00021900102A005B47339D00
D88F00FB1100FA1700D59A0024970000574A000D2800021900193100673C5AA900E27200
FE0500F52B00C9B90000890000464A00082100031C00283B00762691B800EC4F00FF0000
ED4A009ABA00007823002B3D00041C000721004349008901C9B900F52B00FE0600E17500
54A70000643F00162F00021900102A005C46389E00DB8800FC0D00F81E00CFA9000F9000
004F4E00092300031B00253900742A8DB700EB5000FF0000EC4C0092B80000752800263A
00031B000923004F4E0F9000D0A800F91D00FC0E00D98D00309C00005949000E2800021A
001B33006B376EAF00E76100FF0100F03F00AABE00007B1E002C3E00041C00072100494C
088D00CEAD00F82000FC0D00DA8B00319C00005949000D2700021A001D34006E337AB200
E95900FF0000ED480095B90000752800243900031B000A2400534C1F9600D59800FB1300
F91900D1A400109000004E4E00082200041C002C3E007C1CB0C000F13A00FF0200E36C00
59A90000643F00142D00021900152E00653E5EAA00E46800FF0200F03E00A7BD00007921
00283B00031B000A2400524D209600D69600FC1000F91D00CEAC00068C0000444A000620
00051D00374300840BC8BC00F62800FD0A00DB8700329C0000584A000C2600031A002338
0075289CBB00EF4200FF0100E567005DAA0000643F00132D00021900173000693970AF00
E85A00FF0000EC4F0083B400006E32001B3300021900102A00604351A600E36E00FF0200
F03E00A2BC0000762600233800031A000C27005A483B9F00DE7D00FE0600F33300B7C100
007C1D00293C00031B000A2500564B2F9B00DB8600FD0800F52D00C3C400007E17002D3E
00031B000A2400544C2B9A00DB8900FD0900F52C00C4C400007E17002C3E00031B000A24
00554B2E9B00DC8500FE0800F42F00BCC200007C1C00293C00031B000B250058493A9F00
DF7C00FE0500F23700A9BE0000772500233800021A000E28005E454EA500E36D00FF0100
EE45008DB700006F31001B3300021900132D00663D6DAE00E95800FF0000E95A0069AD00
00653E00122C000219001C3400712E97B900F03F00FF0300E076003FA100005949000B25
00031B002C3D007F15C7BF00F62500FC0E00D5990013910000474B00061F00061F00464A
119000D59A00FC0E00F62500C6C000007F16002A3D00031B000C26005B4749A400E36D00
FF0100ED4A0080B400006A3800162F000219001A3200703096B900F03E00FF0400DE7C00
339D0000544C00092300041C003743008802CFAA00FA1600F91D00CAB60000830E002F3F
00031B000B26005A4849A400E36C00FF0000EC4F0076B10000673C00122C000219002036
007725B2C000F42F00FD0A00D7930015920000464B00051F000720004F4E229700DB8700
FE0600F238009DBB0000712F001A32000219001831006F3295B900F13C00FE0500DC8500
259800004F4E00072000061F00484C1A9400D98E00FE0800F23500A1BC0000712E001A32
0002190019310070309CBB00F23700FE0700D98C001A940000484B00051E00072000514D
2C9A00DE7E00FF0300EE440082B40000693A00132C000219002338007B1EC5C300F72300
FB1300CFA90000860600314000031B000C27005E455EAA00E95900FF0000E4690045A300
00574A00092300041D003E470E8F00D69500FD0900F334009FBB00007030001730000219
001D35007626BAC200F62700FB1100D0A70000870500314000031B000D2800614269AD00
EB5100FF0100E07600329C0000514D00072000061F004E4E
005F4400142D000219000F2900574A209600D2A100F81E00FD0A00DF7C0052A70000663C
001A3200021A000B2500514D0E8F00CDB000F62700FE0600E26F0064AC00006B37001E35
00031A000923004D4E058C00CAB700F52C00FE0400E46A006BAE00006D3400203600031A
000923004C4D048B00CAB700F52C00FE0400E36C0067AD00006C36001E3500031A000A24
004F4E0C8E00CDB000F62600FE0700E1750059A80000673C00193200021A000C2700544C
1C9400D2A200F91C00FC0D00DC850040A10000604300132D00021900112B005D46369E00
D98C00FC1000FA1900D49D0021960000564B000D2700021A001A3200683B5EAA00E26F00
FE0500F52D00C8BB0000880200434900072100041C00293C00772595B900EC4D00FF0000
EC4C0096B90000772400293C00041C00072100454A008A00CAB700F62900FE0700E07700
50A60000634000152E00021900112B005D463CA000DC8500FD0C00F82000CEAB000C8F00
004E4E00092300031B00263A00752891B800EC4E00FF0000EC4F008EB700007429002539
00031B00092300504E129100D1A500F91B00FC0F00D88F002D9B00005849000D2700021A
001C33006C3572B000E75E00FF0000EF4100A5BD00007A20002B3D00041C000822004B4D
0B8E00CFAB00F81E00FC0E00D98E002D9B0000584A000D2700021A001E35006F327EB300
EA5600FF0000ED4B0091B80000742A00233800031A000B2500544C229700D69600FB1100
F91B00D0A7000D8F00004B4D00082100041C002E3F007D1AB5C100F23700FF0300E36F00
55A80000634000132D00021900162F00663D62AB00E56600FF0100F04000A3BC00007823
00273A00031B000A2400534C239700D79300FC0F00F81E00CDAE00038B0000424900061F
00051E003944008509C9BA00F62600FD0B00DA89002E9B0000564A000B2600031A002439
007626A0BC00F04000FF0100E46A0059A90000634000122C000219001831006A3874B000
E95800FF0000EB51007FB300006D34001A3200021900112B00614254A700E36C00FF0200
F040009EBB0000752800223800031A000D27005B483FA100DF7A00FE0500F33500B3C000
007A1F00283B00031B000B2500574A329D00DC8300FE0700F42F00BEC300007D19002B3D
00031B000A2400554B2E9B00DB8600FE0800F42E00C0C300007D19002B3D00031B000A25
00564B329C00DC8300FE0700F33100B7C100007B1E00273B00031A000C260059493DA000
DF7900FE0400F13A00A5BD0000762700213700021A000F29005F4452A700E46A00FF0100
EE480089B600006E33001A3200021900142E00673B71AF00EA5500FF0000E85D0065AC00
00643F00122C000219001D3500722C9BBB00F03D00FF0300E079003B9F0000584A000B25
00031B002D3E008113C8BD00F72300FC0F00D49B0010900000454A00061F00061F00484B
149200D69700FC0D00F62700C5C200007E1900293C00031A000D27005C464DA500E46A00
FF0000EC4D007CB20000693900152E000219001B3300712E9ABA00F13C00FE0400DE7F00
309C0000534C00082200041D003944008A00D0A700FB1400F81F00C9B800008210002D3E
00031B000C26005B474CA500E46900FF0000EB510072B00000663D00122C000219002137
007823B6C100F52D00FD0B00D6950012910000444A00051E00072000504E269800DC8500
FE0500F13B0098BA00006F3100193100021900193100703099BA00F13A00FE0600DB8700
229700004E4E00062000061F004A4C1D9500DA8B00FE0700F237009DBB00007030001931
000219001A3200712EA0BC00F23500FE0800D88F0017930000464A00051E00072100524D
2F9B00DF7B00FF0200EE47007EB30000683B00122C00021A002439007C1CC6C100F72100
FB1400CEAC00008509002F3F00031B000D27005F4462AB00E95700FF0000E36C0042A100
00564A00092300041D004048119000D79200FD0800F236009BBA00006E3200162F000219
001F35007824BEC300F62600FB1200CFA900008608002F3F00031B000E280062416DAE00
EC4E00FF0100E078002F9B0000504E00062000061F004F4E
005E4500132D000219000F29005849249700D39F00F91C00FD0B00DE7E004EA50000653E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005C4600122C00021900102A005948279900D49C00F91A00FC0D00DD81004AA40000643F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005B4700112B00021900112B005A482A9A00D59900FA1900FC0E00DC840047A300006340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005A4800112B00021900112B005C472E9B00D69700FA1700FC0F00DB870043A200006241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00594900102A00021900122C005D46329C00D79400FA1600FC1000DA8A003FA100006142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005849000F2900021900132D005E45359E00D89100FB1400FB1200D98C003B9F00005F44
00142E000219000F2900574A229700D3A000F91C00FD0C00DD80004CA50000643F001830
000219000C2700544C189300D0A700F82000FD0900DF7A0052A70000663D00193100021A
000C2600544C179300D0A700F82000FD0A00DE7C004FA60000653E001730000219000D27
00564B1F9600D3A000F91B00FC0D00DC850041A10000604300142D00021900102A005B47
309C00D89100FB1300FA1500D696002A9A00005949000F2900021900162F0063404DA500
DF7C00FD0900F72300CEAD000D8F00004F4E000A2400031A002137006F3177B100E75F00
FF0100F13A00BAC20000811200374400051E00051E003342007E17B1C000F03E00FF0000
E85C007CB20000703000213700031A000A2400514D139100D0A700F81E00FC0D00DB8800
399F00005C4600102A00021900162F00643F53A700E17500FE0600F52C00C8BB00008704
00404800062000041D002F3F007C1BACBF00F03F00FF0100E75E0074B000006D34001D34
00021A000C2600564B269800D69500FB1200FA1800D3A00018930000514D000A2400031B
00233800732B8CB700EC4F00FF0000EB50008AB60000732C00223800031A000A2500534C
1E9500D59A00FB1400FA1700D39E0019930000514D000A2400031B00263A00762798BA00
EE4700FF0000E95A0077B100006D34001C3300021A000E28005A48389E00DC8500FD0A00
F62500CAB700008803003E4700061F00051E00384400840BC7BE00F52B00FE0800DE7F00
3EA000005C47000F29000219001C33006D347BB200EA5600FF0000EC4E0088B60000702F
001F3500021A000D28005A48389E00DC8300FD0800F52A00C7BE0000830D00364300051D
00072000454A078D00CFAA00F91B00FB1200D59A001A940000504E00092200041C002D3E
007E19BCC200F33200FE0500DF7A0042A100005C47000E2800021A001F3500712E8FB700
ED4900FF0000E7610066AC0000663D00152E00021900162F00683B6DAE00E85C00FF0000
EC4E0083B400006E33001B3300021900112B00614256A800E46A00FF0100EF420098BA00
00732B00203600021A000E29005D4549A400E17300FF0300F13C00A3BC00007627002238
00031A000D28005C4744A200E17500FF0300F13B00A4BD0000762600223800021A000E28
005D4648A400E27200FF0200F03F009CBB0000742A001F3600021A000F2A00604355A700
E46900FF0100EE48008AB600006E32001A3200021900132D00663D6AAE00E95A00FF0000
E957006FAF0000673C00142D000219001A32006E328BB600EE4600FF0100E36D004DA500
005D46000D2800031A00253A007A20B7C100F43000FE0800DA890026980000514D000822
00041D003844008803CEAD00F91900FA1800CEAC0000890100394400041D00082200524D
289900DB8700FE0700F33300ACBF0000762600213700021A00112B00634065AC00E85A00
FF0000E85C0063AB0000624100102A00021A002238007822B5C100F42E00FD0A00D89000
1B9400004C4D00062000051F00454A129100D69700FD0C00F52A00BFC300007A1F002439
00021A00102A00624165AC00E95900FF0000E7610059A900005F44000E2800031A00293C
007F16C8BD00F72100FB1300D1A600008A0000384400041C00092300564B3B9F00E17400
FF0100ED49007EB30000683A00132D000219002036007725B5C100F52D00FD0C00D59800
0E8F0000404800051D00082200534C329C00DF7A00FF0200EE460082B40000693900132D
000219002037007823BCC200F62900FC0E00D39F00058C0000394500041C000A24005849
45A300E46B00FF0000EA560065AC00006142000E2800031A002D3E00830DCCB100FA1700
F81E00C8BC00007E1800263A00021A00112B00663C7BB200EE4800FF0200DE7D002C9A00
00504E00072000061F004D4E259800DD8200FF0300EF440080B40000673B00112B00021A
00263A007F16C9B800F91B00F91B00C9B900007E1700263A00021A00122C00693A87B500
F04000FE0500DA89001A940000454A00051E00082200564B
00574A000E2900021900142D005F44399F00D98E00FB1300FB1300D88F00379E00005E45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00564B000E2800021900152E0060433DA000DA8B00FB1100FA1500D79200339D00005D46
00122C00021900102A005A48299900D59A00FA1900FC0E00DB860043A20000624100162F
000219000E2800564A1F9600D2A100F91D00FD0C00DD80004AA400006340001730000219
000D2800564B1E9500D2A100F91C00FD0C00DD820047A30000624100152F000219000E29
005849269800D59A00FA1800FC1000DA8B00399F00005E4500122C00021900122C005D45
389E00DA8C00FC1000FA1800D49C0023970000574A000D2800021900183100663D55A800
E07600FE0700F62700CCB300078C00004C4D00092300031B00233800722D80B400E95900
FF0000F03F00B0C000007E1700334200051E00051E003744008112BAC200F13900FF0100
E7610073B000006D34001E3500031A000B2500534C199400D2A100F91A00FC1000D98E00
319C00005A48000F2900021900183000663C5CA900E26F00FE0400F43000C6C10000850A
003C4600061F00051D003341007F16B6C100F13A00FF0100E664006BAE00006A37001B33
00021A000D280058492E9B00D88F00FC0F00F91C00D0A600119100004F4E00092300031B
00263A00762796B900ED4900FF0000EA550081B40000703000203600031A000C2600554B
259800D79400FB1100F91A00D1A400129100004F4E00092300031B00293C007822A2BC00
EF4200FF0000E760006EAF00006A38001A32000219000F2A005D4640A100DE7F00FE0800
F52A00C8BC00008509003A4500051E00051F003C46008705C9B800F62600FD0A00DC8500
369E00005A48000D2800021A001E3500703084B500EB5100FF0000EA54007FB300006E33
001C34000219000F29005C4640A100DE7D00FE0600F42E00C5C40000811200324100041D
000721004A4C0E8F00D1A400FA1800FA1500D3A000139100004D4E00082100041C003140
008013C5C400F42E00FE0700DD80003A9F00005A48000D2700031A00213700742A98BA00
EF4300FF0100E567005DAA0000643F00132D000219001831006A3776B100EA5600FF0000
EA54007AB200006B3600193100021900132C00643F5FAA00E66400FF0000EE48008EB700
00712F001D3400021900102A00604351A600E36D00FF0200EF410099BA0000732B002036
00021A000F29005E454DA500E26F00FF0200F040009BBA0000732A00203600021A000F29
005F4450A600E36C00FF0100EF440092B80000712E001D3400021900112B0062415DAA00
E66300FF0000EC4D0081B400006C3600183100021900152E00683A73B000EA5400FF0000
E85C0066AC0000643F00122C000219001C3400712F94B900EF4100FF0200E1720045A200
005B48000C2600031A00283B007C1BC1C400F52B00FD0A00D88F001F9600004F4E000721
00051D003C46028B00D0A800FA1600F91B00CCB10000860700354200041C00092300544C
2F9B00DD8100FE0500F23800A3BC0000742A001E3500021900122C00663D6EAF00EA5500
FF0000E662005AA900006043000E2900031A00253A007B1EBFC300F52A00FD0C00D69500
14920000474B00061F00061F004A4C199400D89100FD0A00F42E00B5C100007823002137
00021A00112B00653E6EAE00EA5400FF0000E5660050A600005C46000C2600031B002D3E
008210CAB700F81D00FA1600CEAC0000870500344200041C000A2400584943A200E36E00
FF0100EC4E0075B00000663D00122B00021A002238007920BEC300F62800FC0E00D39E00
088D00003C4600041D00092300554B3A9F00E17400FF0100ED4B0079B20000673C00122C
00021A002338007B1EC5C400F72500FB1100D1A50000890100354300041C000B25005A48
4EA500E56500FF0000E85B005CA900005E45000C2700031B003040008608CEAB00FB1400
F72200C6C100007B1D00233800021A00132C00693A84B500EF4200FF0400DC8200249800
004D4E00061F00072000504E2C9A00DF7C00FF0200ED490077B10000653E00102A00031A
002A3C008211CCB300FA1700F81F00C7BF00007C1C00233800021900142D006B3690B800
F13B00FE0700D88F0013910000404800041D000923005849
00544C000D2700021900162F00624241A100DB8800FC1000FA1700D695002F9B00005C47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00534C000C2700021900173000634046A300DC8500FC0E00FA1800D598002B9A00005B48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00524D000C2600021A00183100643F4AA400DD8200FC0D00F91A00D49C00279900005948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00514D000B2500021A00193100653D4FA500DE7F00FD0C00F91C00D39F00239700005849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00504E000B2500021A001A3200673C53A700DF7B00FD0A00F81E00D2A2001F960000574A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004E4E000A2400031A001C3300683A58A800E07800FD0900F82000D1A5001C940000564B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004C4D00092300031A001D34006A395DAA00E17500FE0800F72200D0A80018930000544C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00494C00092300031A001E35006B3761AB00E27200FE0700F72400CEAB0014920000534C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00464B00082200031B002036006C3567AD00E36E00FE0600F62700CDAF0010900000524D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00444A00082200031B002137006E336CAE00E46B00FE0500F52900CCB2000C8F0000504D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00414800072100031B002338006F3171AF00E56800FF0400F52C00CBB500088D00004F4E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003E4700072100031B00253900712F76B100E66400FF0300F42E00C9B900048B00004D4E
000A2400031A001D34006A385FAA00E17300FE0700F72500CEAC0012910000524D000C26
00021A00193200663D53A700DF7A00FD0900F82100D0A70017930000544C000C2600021A
00193100663D52A700DF7A00FD0900F72100CFA90014920000524D000B2600021A001B32
00683A5CA900E17300FE0600F62700CCB200098D00004F4E00092400031A002036006E33
70AF00E66500FF0200F33300C6C10000860700404800072000041C002A3C00772591B800
EB5000FF0000EE4600A3BC00007B1D002F3F00041D00061F003A4500830EC0C300F23700
FF0200E6630071B000006D34001F3500031A000B2500524D169200D1A500F91D00FC0D00
DB88003A9F00005D4600112B00021900152E0062414CA500DF7A00FE0800F62700CBB400
038B0000474B00082100031C00293C00772498BA00ED4A00FF0000EB51008BB60000742A
00243900031B000923004F4E109000D0A800F81D00FC0E00DA8B00349D00005A48000F29
00021900193100683A64AC00E56800FF0200F23800B9C200007F1500334100041D00061F
003F47008705C9BA00F52A00FE0700DF7B0047A30000604300122C00021900162F00653E
5BA900E36D00FF0300F23500BCC200007F1500324100041D000620004249008A00CBB300
F72400FD0B00DB8600369E00005A48000E2800021A001C34006D3479B200E95900FF0000
ED4A0093B80000742A00233800031A000B2500554B269800D79200FC0F00F81E00CEAC00
078C0000464B00072000041D003341008112C4C400F42F00FE0600DF7A0045A200005E45
00102A000219001B33006C3579B200EA5700FF0000EC4F0086B500007030001E3500021A
000E28005C473FA100DE7D00FE0600F42F00C4C40000801400304000041C000821004E4E
149200D39F00FB1400F91900D0A7000A8E0000464B00072000051D003844008509C9B900
F72500FD0C00D98D0027990000544C000A2400031B002A3C007B1DB5C100F33400FE0500
DF7A0040A100005B47000D2800021A0021370074299CBB00F04000FF0200E36C0053A700
00604300102A000219001D340070308DB700EE4800FF0000E565005DAA0000634000122C
000219001B33006E3288B500ED4A00FF0000E664005EAA0000634000122C000219001B33
006F318CB700EE4700FF0100E5680056A80000604300102A000219001F3500732B9ABA00
F03F00FF0200E1720047A300005C47000D2700031A002539007921B2C000F33300FE0600
DC83002F9B0000554B000A2400031C003040008210C8BB00F72300FC0F00D59A00139100
00484C00062000051E0041490A8E00D2A100FB1300F81F00CBB60000840B00334100041C
00092300544C309C00DD8100FE0500F23700A5BD00007528001F3600021900112B00643F
66AC00E85A00FF0000E85B0065AC0000634000112B00021A002137007626ACBF00F33300
FE0700DB880025980000504E00072100051D003D47068C00D2A200FB1200F72100C8BB00
008013002C3D00031B000C26005C474CA500E46A00FF0000EC4F0076B10000673C00132C
000219001F35007528ACBF00F33200FD0800D98D001D9500004C4D00062000061F00484C
189300D89100FD0A00F43000AFBF00007627001F3600021900132D00683A7DB300ED4900
FF0100E174003CA00000564B00092300041C003944038B00D2A300FB1100F72500C5C300
007C1D00243900021A00112B00653E72B000EC4F00FF0100E2700040A10000574A000923
00041C003A45068C00D39E00FC0E00F52900BAC20000782300203600021900142E006A37
89B600EF4100FF0400DD8200269800004F4E00062000061F004D4E239700DC8400FE0400
F040008AB600006A3700142D000219002137007A20C4C400F72400FB1300CFA900008607
00304000031B000D27005F4462AB00EA5600FF0000E36E003EA00000554B00082200051E
00444A179300D98C00FE0600F13C008EB700006B3700142D000219002338007C1BC7BE00
F81E00FA1800CBB50000801400273B00021A00122B00683A
003C4600072000041C00263A00722C7CB200E76100FF0200F33100C8BC00018A00004A4D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00394500061F00041C00283B00742A81B400E85D00FF0200F33400C7BF0000880200474B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00374300061F00041C002A3D00752787B500E95A00FF0100F23700C5C30000870600444A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00344200051E00041D002C3E0077248DB700EA5600FF0000F13A00C2C400008509004149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00324100051E00051D002F3F00792293B800EB5300FF0000F03D00BBC20000830D003F47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002F3F00051E00051E003140007A1F99BA00EB4F00FF0000F04000B5C100008210003C46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002D3E00041D00051E003342007C1C9FBC00EC4C00FF0000EF4300AFBF00008014003945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002B3D00041D00061F003643007E18A6BD00ED4800FF0000EE4700A8BE00007E17003743
00061F00041D002C3D0077258DB700EA5600FF0000F13B00BEC30000840C003F47000720
00041C00263A00732B80B300E85D00FF0100F23600C5C30000860800424900072100031B
00253A00722C7FB300E85D00FF0100F23700C4C40000850A003F4800072000041C00283B
00752889B600EA5600FF0000F03E00B4C10000801300384400061F00041D002F3F007B1E
9FBC00ED4900FF0000EC4C0099BA00007921002D3E00041C000620003C4600840CC2C400
F23700FF0200E6620074B000006E3200203600031A000A2400504E0F9000CFAB00F72100
FD0A00DD800046A30000614200142D00021900112B005D453B9F00DB8700FC0D00F91D00
D1A50015920000514D000A2400031A002036006F3179B200E85D00FF0100F03E00B0C000
007E1800324100051D00061F003C4600840BC6C200F33100FF0400E36E005EAA0000673C
001831000219000F29005B47349D00DA8A00FC0D00F81E00D0A8000F9000004F4E000923
00031B00263A00752892B800EC4C00FF0000EB510089B60000722C00223800031A000A24
00524D1B9400D39E00FA1700FB1400D5990020960000544C000B2500031A00213700722D
88B600EB5100FF0000EC4F008BB60000722C00223800031A000B2500544C229700D69600
FB1200F91900D1A400119100004F4E00082200031B002A3D007A20A8BE00F03E00FF0100
E5650064AC0000673B00173000021900122C0061434DA500E17400FE0400F33300BFC300
007F1500314000041C00072100484C0A8E00D0A800F91B00FB1100D697001E950000524D
00092400031B00283B007921A9BE00F13C00FF0200E46B0059A90000634000132D000219
00162F00683B69AD00E76000FF0000EE470093B80000732B00213700021A000D27005948
399F00DD8100FE0700F52D00C5C30000811300314000041C000822004E4E169200D49C00
FB1300F91B00CFAB00058C0000424900061F00051E003D46008802CCB100F81F00FC1000
D698001A940000504E00082200041C003141008111C6C000F62900FD0A00DA8A002A9A00
00544C000A2400031B002B3D007D1ABDC300F42F00FE0700DD8200339D0000574A000B25
00031B00293C007B1DB8C100F33100FE0600DD8100349D0000574A000B2500031B00293C
007C1BBCC300F42F00FE0800DC85002E9B0000554B000A2400031B002E3F008014C6C100
F62800FD0B00D8900020960000504E00082200041D003643008607CCB300F81E00FB1300
D2A1000C8E0000444A00061F00061F00454A0D8F00D39F00FB1200F82000CAB60000840B
00334100041C00092300544C2D9B00DC8400FE0600F33400AEBF0000772400223800021A
000F2900604359A900E66300FF0000EB510076B10000683A00142E000219001B33007030
94B900F04000FF0300E078003B9F0000574A000A2400031B00304000830DCAB600F81E00
FB1400D0A600038B00003B4600041D00082200524D299900DC8500FE0600F23700A3BD00
00732A001D3400021900132D00683B78B100EC4E00FF0000E46B004AA400005B47000C26
00031B002E3F00820FCAB700F81D00FA1600CFAB0000880300354300041C000A2400574A
3DA000E17400FF0100ED480080B30000693900142D000219001E35007528ADBF00F43100
FD0900D8910016930000474B00051F000720004F4E259800DC8500FE0500F13B0096B900
006F32001831000219001A3200712EA1BC00F23500FE0800D98D001A940000484B00051F
00072000504E299900DD8100FF0400EF41008AB600006B3700152E000219001F36007724
B9C200F52A00FC0E00D39F00048B0000384400041C000A240059494AA400E56700FF0000
E85A005DAA00005E45000C2700031B003140008706CFA900FB1200F72400C3C400007921
00213700021900152E006C3690B800F13B00FE0600D98C0018930000454A00051E000822
00554B3DA000E36F00FF0000EA560061AB00005F44000C2600031B003442008900D2A100
FC0E00F52C00AEBF0000732B001A32000219001B33007528
00293C00041C00061F003944007F15ACBF00EE4500FF0000ED4A00A2BC00007D1A003442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00273B00041C000620003B46008111B3C000EF4200FF0000EC4E009CBB00007B1E003141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00253900031B000721003E4700830EB9C200F03E00FF0000EB510095B900007921002F3F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00233800031B00072100414800850AC0C300F13B00FF0000EA55008FB700007724002D3E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00213700031B00082200444A008706C5C300F23800FF0100E9590088B600007627002A3D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001F3600031A00092300484B008802C7BF00F33400FF0100E85D0082B40000742A00283B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001D3400031A000923004B4D028A00C8BB00F43100FF0200E761007BB20000722D00263A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001B3300031A000A24004F4E068C00CAB800F42E00FF0300E5650075B00000702F002439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001A3200021A000B2500504E0B8E00CBB400F52B00FE0400E469006EAF00006E32002237
00031B00082200444A008705C6C200F23600FF0100E85C0082B40000742A00273B00041C
000720003D4700830EBCC200F13C00FF0000EA56008AB600007627002A3C00041C000620
003C4600820FBAC200F13C00FF0000E9580087B50000752900283B00041C000720004048
00850AC5C400F23600FF0200E7600079B20000702F00233800031B00082200494C038B00
CAB700F52B00FE0500E26F0060AB00006939001B3300021A000C2600544C1A9400D2A300
F91C00FC0D00DB86003EA000005F4400122C00021900122C005E443DA000DB8600FC0D00
F91D00D1A40017930000524D000B2500031A001E35006D3470AF00E66300FF0200F23700
BEC30000821000384400051E00051E003442007F16B4C100F13C00FF0100E75F0075B100
006E33001E3500031A000B2500534C1C9500D39F00FA1800FB1100D792002B9A00005849
000D2800021A001A32006A3869AD00E56600FF0200F23800B9C20000801500344200051D
00061F003C46008509C7BF00F42D00FE0500E1750051A60000634000142E00021900132C
0061424BA400DF7900FE0600F52B00C8BD00008607003D4600061F00051E003643008210
C4C400F33200FE0400E2720053A70000634000142D00021900142D00634053A700E27200
FE0400F33300C0C30000801300334100041D000620004349018A00CCB200F72200FD0C00
DA8A00319C00005849000D2700021A001F3500703085B500EB5100FF0000EB520083B400
006F31001E3500021A000D28005A48379E00DC8400FD0900F62800C8BB00008509003945
00051E00061F004048008900CCB200F82100FC0E00D8900027990000544C000A2500031B
00263A007724A3BD00F03F00FF0200E46A005AA90000634000132D00021900173000693A
6DAE00E85D00FF0000ED4B008BB60000702F001E3500021A000F29005D4645A200E07800
FE0400F33500B5C100007B1D002A3C00031B000A2400544C279900D98D00FD0B00F62600
C8BB0000840C00354200041D000721004C4D149200D49C00FB1200F91C00CDAE00008900
003E4700051E00061F00444A098D00D1A600FA1700FA1800D0A700078D0000424900061F
00051F004048058C00CFA900FA1800FA1600D1A500088D0000434900061F00061F004149
078C00D0A600FA1700FA1900CFAA00038B00003E4700051E00062000474B109000D39E00
FB1200F81F00CBB40000860800364300041D00082200504E219600D88F00FD0B00F52A00
C5C400007E18002B3D00031B000B250058493B9F00DF7A00FF0400F13B00A1BC0000742A
001F3600021900112B00624160AB00E76000FF0000EA530073B00000673B00142E000219
001B3300703092B800EF4200FF0200E1740040A100005949000B2500031B002C3E008014
C7BD00F72300FC1000D49D000E8F0000434900051E000620004B4D199400D79200FD0B00
F52B00BDC300007A1E00253900031A000F290060435BA900E76000FF0000E9570069AD00
00643F00112B00021A002137007724B3C000F42F00FD0900D890001A9400004B4D00061F
00061F00484B169300D79300FD0A00F42E00B5C10000782400213700021900122C00663D
72B000EB5000FF0000E46B0049A400005A48000B2500031B003140008509CDAF00FA1800
F91B00CBB50000820F002D3E00031B000D27005E4556A800E76100FF0000E85C005DAA00
005F44000D2800031A002C3D008111CAB600F91B00FA1900CCB20000830D002E3F00031B
000D27005E455BA900E85D00FF0000E6620052A700005C47000B2600031B003341008704
D0A800FB1300F72300C5C200007B1D00233800021A00122C00683A81B400EE4500FF0300
DE7E002A9A0000504E00072000061F004C4D229700DC8400FE0400EF410087B500006939
00132D000219002338007C1CC6C000F82000FA1600CDB00000830E002C3D00031A000F29
00634072B000EC4C00FF0200DF7A002E9B0000504E00062000061F004F4E2A9900DE7D00
FF0200ED4A0073B000006340000F2900031A002D3E008509
00183100021A000C2600524D0F9000CDAF00F62700FE0500E36D0068AD00006D35002036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001730000219000C2700534C149200CFAB00F72400FE0700E2720061AB00006B37001E35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00152F000219000D2800554B1A9400D0A700F72100FD0800E076005BA900006939001C34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00142D000219000E2900574A1F9600D2A300F81F00FD0A00DF7A0054A70000673C001A32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00132C000219000F2A005949249800D39E00F91C00FD0C00DE7F004EA50000653E001931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00112B00021900112B005A482A9A00D59A00F91900FC0E00DC830047A300006340001730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00102A00021900122C005C46309C00D69500FA1600FC1000DB880041A10000614200152F
000219000E2800564B1C9500D1A400F81F00FD0A00DF7B0053A70000663C00193200021A
000B2600524D129100CEAC00F72400FE0700E175005BA90000683A001B3300021A000B25
00514D109000CEAD00F72400FE0700E0760058A80000673B001A3200021A000C2600534C
179300D0A700F82000FD0A00DE7E004BA40000634000162F000219000E29005849279800
D59900FA1700FB1100D98E00349D00005C4600112B00021900132D00604342A100DC8400
FD0C00F81E00D1A50017930000534D000B2500021A001D34006B366AAD00E56800FF0300
F33300C5C200008509003E4700062000041D002E3E007A1FA1BC00EE4600FF0000EB5300
8BB60000742900263A00031B000822004B4D078D00CCB100F72400FD0900DE7E0047A300
00614200132D00021900122C00604344A200DD8000FD0900F72400CCB100068C0000494C
00082200031B00293C00772499BA00ED4900FF0000EA530086B50000722D00223800031A
000A2400514D189300D2A100FA1900FB1200D7940027990000564B000C2600021A001E35
006E3379B200E85B00FF0000EE44009FBC0000782300293C00031B000822004E4E0F9000
D0A700F91C00FC1000D8910029990000564A000C2600021A001F3600703082B400EA5400
FF0000EC4D008DB70000732C00223800031A000B2500554B259800D79400FC1000F91C00
CFA9000B8E00004A4C00072100041C002F3F007E19B7C100F23600FF0300E2700054A700
00624100132D00021900162F00663C63AC00E56500FF0100F04000A2BC0000772400263A
00031B000A2400534C239700D79300FC0F00F81E00CDAE00038B0000424900061F00051E
003944008509C9BA00F62600FD0A00DB88002F9B0000574A000B2600031A002439007626
9EBB00EF4100FF0100E468005BA90000634000132D000219001830006A3972B000E95900
FF0000EB500082B400006E33001B3300021900102B00604351A600E36E00FF0200F03E00
A2BC0000762600233800031A000C270059483B9F00DE7D00FE0600F33200B8C200007C1C
002A3C00031B000A2400554B2E9B00DB8700FD0900F52C00C4C400007F16002D3E00031B
00092300544C299900DA8A00FD0A00F52A00C5C300007F15002D3E00031B000A2400544C
2C9A00DB8700FD0800F42D00C0C300007D1A002A3D00031B000B2500574A369E00DE7F00
FE0500F23500AEBF0000782300243900031A000D28005C464AA400E27000FF0200EF4200
93B80000712F001C3400021900122C00653E67AD00E85C00FF0000EA56006FAF0000673C
00142D000219001B33006F3190B800EF4300FF0200E2710045A300005B48000C2600031B
00293C007D19C5C400F62900FD0C00D79300199300004B4D00072000051E0041480A8E00
D3A000FB1100F72100C9BB00008111002E3F00031B000B2500594941A100E17300FF0200
EE45008AB600006D34001830000219001830006D348BB600EF4400FF0200E175003DA000
00574A000A2400031C003241008509CCB100F91A00FA1800CDAF0000860700344200041C
000A2400574A3EA000E17400FF0200EE470083B400006A3800152E000219001C3400732B
A4BD00F23600FE0700DA8A00209600004E4E00062000061F00474B179300D89100FD0900
F43100ACBF00007528001E3500021900152E006A3886B500EF4400FF0300DF7B00329C00
00534C00082200051D0040480E8F00D59800FD0C00F42D00B2C000007627001E35000219
00152E006B368AB600EF4100FF0400DD810028990000504E00072000061F004A4C1D9500
DA8900FE0600F13B0095B900006E3300162F000219001D34007527B3C000F52C00FC0D00
D39D00068C0000394400041C000A240059494CA500E56500FF0000E85D0058A800005D46
000B2600031B003542008900D2A200FC0F00F52A00B5C100007527001D34000219001831
00712FA3BD00F33200FD0B00D59900098D00003A4500041C000A25005B4754A700E75E00
FF0000E5680046A30000574A00092300051D004249179300
000F2900021900132D005E45369E00D89000FB1400FB1200D98D003B9F00005F4400142E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000E2800021900152E0060433CA000D98C00FB1200FB1400D89100359D00005E4500132C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000D2700021900162F00624143A200DB8700FC0F00FA1700D696002E9B00005C4700112B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000C2600021A00183100643F49A400DD8200FC0D00F91A00D49B00289900005A4800102A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000B2500021A001A3200663D50A600DE7E00FD0B00F91D00D3A00022970000584A000F29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000A2400031A001B3300683B57A800E07900FD0900F82000D1A4001D950000564B000E28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00092300031A001D35006A385EAA00E17400FE0700F72300CFA90017930000544C000D27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00082200031B002036006C3566AC00E26F00FE0600F62600CEAE0011900000524D000C26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00082200031B002237006E326DAE00E46A00FE0400F52A00CCB3000B8E0000504E000B25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00072100031B00243900702F75B000E56500FF0300F42D00CAB700068C00004E4E000A24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00062000041C00273B00732C7DB300E76000FF0200F33100C8BC00018A00004A4C000923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00061F00041C002A3C00752885B500E85B00FF0100F23500C6C10000880400464B000822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00051E00041D002C3E0077258DB700EA5700FF0100F13A00C2C400008509004249000821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00051E00051D002F3F00792195B900EB5200FF0000F03E00BAC20000830E003E47000720
00031C00263A00722D7CB200E76000FF0200F33200C7BE0000890100474B00082200031B
002137006E336EAF00E56800FF0400F42D00C9B800038B00004B4D00092300031A002036
006D346CAE00E46900FF0400F42E00C9B900028A0000494C00092200031B002237006F31
75B000E66300FF0200F33400C6C10000860700414800072100041C00283B00752989B600
EA5500FF0000F04000B0C000007F1600354200051E00051E003341007D19ABBE00EF4200
FF0000EA54008AB60000742900273B00031B00082100464A008900C9B900F52C00FE0500
E271005CA90000673B001931000219000D2800574A279900D69700FB1500FB1400D69600
28990000584A000D2800021900193200683A60AB00E36D00FF0400F43100C6C100008509
003D4600061F00041D003140007D1AADBF00F03F00FF0100E85D0077B100006E32001F35
00031A000B2500544C1E9600D49C00FA1600FB1300D6970024980000564B000C2600021A
001D35006D3476B100E85D00FF0000EF4100A6BD00007A1F002C3E00041C00072100474B
058C00CDB000F72200FD0B00DB8600389E00005B47000F290002190019320069396AAD00
E66300FF0100F03E00ABBE00007B1D002C3E00041C000821004A4C0B8E00CFAA00F81D00
FC0F00D890002A9A0000564A000C2600031A00203600712E87B500EB5000FF0000EB5200
84B500007030001F3600021A000D27005849309C00DA8A00FD0C00F72300CBB400008901
00404800061F00051E00384400840BC7BD00F52A00FD0800DD81003A9F00005B48000E28
00021A001E3500703085B500EB5000FF0000EA55007BB200006D34001B3300021900102A
005E4548A300E07700FE0400F33400B9C200007D1A002D3E00031C00092300504E1B9400
D59900FB1100F91C00CEAD00048B0000424900061F00051E003B46008704CBB400F72100
FC0E00D7930021960000524D00092300031B002C3E007D19BDC300F43100FE0600DE7E00
3A9F00005948000C2700031A002338007626A3BC00F03D00FF0200E270004DA500005F44
000F2900021A001E3500722D92B800EE4500FF0100E4680058A80000614200112B000219
001C340070308CB700EE4800FF0000E566005AA90000624100112B000219001C3400702F
90B800EE4500FF0100E46A0053A700006043000F2A00021A001F3600742A9DBB00F03E00
FF0300E1740045A200005B47000D2700031A00263A007A20B4C100F33200FE0700DC8400
2E9B0000544C00092300041C00304000820FC8BB00F72300FC0F00D59A0013910000484C
00062000051E0041490A8E00D2A200FB1300F81E00CBB50000840B00334100041C000923
00544C309C00DD8100FE0500F23700A7BD0000752800203600021900112B00634064AC00
E85C00FF0000E95A0067AD0000643F00112B000219002036007527A9BE00F33500FE0700
DB860027990000514D00082100041D003C46048B00D1A500FB1300F81F00C9B900008211
002E3E00031B000B26005A4848A300E36D00FF0100EC4C007BB20000683A00142D000219
001D3400742AA6BD00F33500FE0700DA8900219700004F4E00072000051E00454A139100
D69500FD0B00F52D00B7C10000782300213700021900122C00663C76B100EC4E00FF0100
E36F0043A200005849000A2400041C003543008802D0A800FB1300F82100C7BE00007E18
00273B00031A000F2900624169AD00EA5400FF0000E46A0048A300005949000A2400041C
003643008900D1A500FB1100F72500C5C400007B1E00233800021A00122C00683B7DB300
EE4700FF0200DF7B00309C0000524D00072100051E00474B199400D98C00FE0700F13900
97B900006E3300162F000219001E35007626B6C100F52A00FC0F00D2A100018A00003643
00031C000B25005C4756A800E75E00FF0000E565004AA400005949000A2400041C003D46
0C8F00D69600FD0900F334009EBB00006F31001730000219001F35007823C0C300F72500
FB1300CEAC0000850A002D3E00031A000F2900643F75B100
00051D00051E003341007C1C9EBB00EC4D00FF0000EF4200B1C000008112003A45000620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00041D00061F003643007E18A6BD00ED4800FF0000EE4700A8BE00007E1700374300061F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00041C000620003A45008013AFBF00EF4400FF0000ED4C00A0BC00007C1C00334100051E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00031C000720003E4700830EB8C100F03F00FF0000EB510097B900007A2000304000051D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00031B000821004249008509C1C400F13A00FF0000EA56008EB700007724002D3E00041D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00031B00082200464B008704C6C100F23600FF0100E85B0086B50000752800293C00041C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00031A000923004B4D018A00C8BC00F33200FF0200E760007DB30000732C00273A00041C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00031A000A24004F4E078C00CAB700F42D00FF0300E5650074B00000703000243900031B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00021A000B2500514D0D8F00CCB200F52900FE0500E46B006CAE00006E3300213700031B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000219000C2600534C139100CEAC00F62500FE0600E2700063AC00006B36001F3500031A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000219000D2800554B1A9400D0A700F72100FD0800E076005BA900006939001C3400031A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000219000F2900574A219600D2A100F81E00FD0A00DF7C0053A70000673C001A3200021A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00021900102A005A48289900D49C00F91A00FC0D00DD81004AA40000643F001831000219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00021900122C005C462F9B00D69600FA1700FC0F00DB870042A20000624100162F000219
000D2700554B1A9400D1A600F82000FD0900DF790055A70000673C001A3200021A000B25
00514D0F9000CDAE00F62600FE0700E172005EAA00006939001C3400031A000A2500504E
0D8F00CDB000F62600FE0700E173005CAA0000693A001B3300021A000B2500524D139100
CFAA00F72200FD0900DF7B0050A60000653E001730000219000D2800574A229700D49D00
F91900FC0F00DA8A003A9F00005E4500122C00021900122C005E453B9F00DB8900FC0E00
F91B00D2A0001D950000544C000C2600021A001B3300693962AB00E36D00FE0400F42F00
C8BD0000870400424900072100041C002A3D00782497BA00ED4C00FF0000EC4D0095B900
00772500293C00041C00072100454A008A00CAB700F62900FE0700E0770051A60000643F
00152F00021900102A005D463A9F00DB8700FD0C00F81F00CFAA000F9000004F4E000923
00031B00253900742A8DB700EB5000FF0000EC4C0093B90000762700263A00031B000923
004E4E0E8F00CFA900F81E00FC0E00DA8B00339D00005A48000E28000219001A32006A38
6BAE00E66300FF0100F13C00AFBF00007C1B002E3F00041C00072100464A048B00CCB100
F72200FD0B00DB8700369E00005A48000E28000219001B33006B3672B000E85E00FF0000
EF44009EBB0000772400273B00031B00092300504D179300D39F00FA1600FA1500D39E00
18930000514D00092300031B00283B007822A4BD00F04000FF0100E6640065AC0000673B
00173000021900122C00614251A600E27100FF0300F23600B6C100007D1A002D3E00041C
000822004F4E149100D3A000FA1600FA1700D2A200119100004D4E00082100041C003040
007F15C0C300F43000FE0600DF7B0042A100005C46000E2900021A001D3500703088B600
EC4D00FF0000E85B0071AF0000693900183000021900132D0063405CA900E56800FF0100
EF42009ABA0000742900223700031A000D27005A483CA000DE7D00FE0600F33100BBC200
007D1A002C3D00031B000A2400534C269800D98D00FD0B00F62600C8BC0000830E003342
00041C000822004F4E199400D69700FC0F00F82000CBB50000860700384400041D000721
004C4D149200D49B00FB1100F81F00CCB30000870500394400041D000721004C4D169200
D59900FC1000F82100CAB60000850900354200041D00082200504E1F9600D89100FD0C00
F62700C6C000008013002E3F00031B000A2400554B309C00DC8300FE0600F33300B2C000
00792100253900031A000D28005D464BA400E36F00FF0100EE44008EB700006F31001A32
00021900142D00673C70AF00EA5500FF0000E85E0063AB0000634000112B000219001F36
007429A3BC00F13900FE0500DE7E00339D0000554B00092300041C00324100840BCBB400
F81D00FB1400D0A600038B00003C4600051D00072100504E249800DA8900FE0800F33200
AEBF0000772500213700021A00112B00643F68AD00E95800FF0000E75F005DAA00006043
000F2900031A00253A007B1EC0C400F52900FC0D00D6980011910000444A00051E000720
004E4E1F9600DA8B00FE0800F33300A9BE00007429001E3500021900142D00693A7DB300
ED4A00FF0100E2710040A10000574A000A2400041C003543008803CFA900FB1400F81F00
C8BB00008014002A3C00031A000E280060435FAA00E85B00FF0000E6610055A800005D46
000C2700031B002E3F00840CCCB100FA1900F91B00CAB600008111002B3D00031A000E28
00604361AB00E95900FF0000E567004CA500005A48000B2500041C003543008900D1A400
FB1100F62600C2C40000792000213700021900132D006A3986B500EF4200FF0400DD8200
269800004F4E00062000061F004E4E269800DD8100FF0300EF430083B40000683A00122C
00021A002439007D1AC7BE00F81F00FA1700CCB20000820F002B3D00031A000F2900643F
74B000ED4A00FF0200DF7B002C9A0000504E000620000620004F4E2B9A00DF7C00FF0200
ED4B0072B000006340000F2900031A002E3F008509CFAA00
00021900132D005E44379E00D89000FB1400FB1200D98D003A9F00005F4400142D000219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00021900152F0061423FA100DA8A00FB1100FA1500D79300329D00005D4600122C000219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00021900173000634047A300DC8400FC0E00FA1900D599002B9A00005B4800112B000219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00021A00193200663D4FA600DE7E00FD0B00F91C00D39F00239700005849000F29000219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00031A001C3300683A58A800E07800FD0900F82000D1A5001C950000564B000E28000219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00031A001E35006B3761AB00E27200FE0700F72400CFAB0015920000534C000C27000219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00031B002137006D336AAE00E36C00FE0500F62800CCB1000E8F0000514D000B2500021A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00031B00243900703074B000E56600FF0300F52D00CAB700078C00004F4E000A2400031A
001C3300693A5BA900E07600FE0800F72200CFA90016920000544C000C27000219001831
00643F4DA500DE7E00FD0B00F81E00D2A2001D950000564B000D28000219001730006340
4AA400DD8000FD0B00F81E00D2A3001C950000554B000D2700021900183100653E51A600
DF7A00FD0900F72200CFAB0012910000514D000B2500021A001C34006A3864AC00E36D00
FE0400F52C00C9B900018A0000474B00082200031B00253900722C82B400E95900FF0000
F03E00B3C00000801500364300051E00051E003341007E18AEBF00F04000FF0000E95800
83B40000722C00243900031B000923004C4D088D00CCB100F72500FD0800DF7B004CA500
00624100152E00021900112B005D463A9F00DB8800FC0D00F81D00D0A70013910000504D
000A2400031A00223700712E81B400E95800FF0000EF4400A4BD00007A1F002D3E00041C
000720004349008900CAB700F62800FE0700DF7A004AA40000614200132D00021900132D
0061424BA400DF7900FE0700F52A00C9BA00008704003F4800062000041D003241007F16
B7C100F23800FF0200E4680063AB0000683B00183000021900102A005D463EA000DD8100
FD0900F62600CAB60000890100414800062000041D003342008013BFC300F33300FF0400
E2710054A70000634000142D00021900142E00643F57A800E36F00FF0300F23600B8C200
007E1800304000041C00072100494C0A8E00CFAA00F91C00FC1000D7940023970000544C
000A2500031B0025390076279BBA00EF4400FF0000E761006AAD0000683A001730000219
00122C00614252A700E27000FF0300F23800B1C000007B1D002B3D00031B00092300514D
1C9400D59900FB1200F91C00CFAB00068C0000444A00062000051D00384400850AC9BA00
F62600FD0B00DA8A002D9B0000564B000B2500031B00263A007823A7BD00F13C00FF0200
E26F0050A60000604300102A000219001B33006E3383B400EC4F00FF0000E85B006EAF00
00683A00162F00021900152E00673C69AD00E75E00FF0000EC4D0084B500006E33001B33
00021900112B00624159A900E56700FF0100EE460091B80000712E001E3500021900102A
00604353A700E46B00FF0100EF430095B90000722D001E3500021900102A00604355A700
E46900FF0100EE46008EB700007030001C3300021900122C00634060AB00E66100FF0000
EC4E007EB300006B3600183000021900152F00693A75B000EA5400FF0000E85D0066AC00
00643F00122C000219001C3400712F93B900EF4200FF0200E2720046A300005B47000C27
00031A00273B007C1CBEC300F52D00FD0A00D98D0021970000504E00082100041D003A45
008900CFAA00FA1700F91A00CDAE0000870400374300041C00082200524D2A9A00DC8500
FE0600F33500AABE0000762700203600021A00112B00634066AC00E95A00FF0000E85C00
62AB0000624100102A00021A002238007823B5C100F42F00FD0900D98F001C9500004D4E
00062000051E00444A109000D59900FC0D00F62800C2C400007B1D00253A00031A000F29
00614260AB00E85C00FF0000E85E005EAA00006043000E2900031A00273B007D19C6C100
F72400FB1100D2A100058C00003B4600041D00082200544C349D00DF7900FF0200EF4400
87B500006B3700152E000219001D34007429AABE00F33200FD0900D8910016920000464B
00051E00072000504E289900DD8200FE0400F03F008EB700006C3500162F000219001D34
007429ADBF00F42F00FD0B00D696000F900000404800051D00082200544C389E00E17400
FF0100EC4D0074B00000653E00102A00021A00273B007E17C8BB00F81E00FA1700CCB100
00830E002C3E00031A000E2800614269AD00EB5300FF0000E270003CA00000554B000822
00051D004349159200D88F00FE0700F2390096B900006D3400162F000219002036007922
C2C400F72400FB1300CEAB00008509002E3F00031A000E280062416FAF00EC4D00FF0100
DF79002E9B0000504E00062000062000504E2C9A00DF7A00
00041C00273B00732B7DB300E76000FF0200F33200C8BC00008A00004A4C00092300031A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00041D002B3D00762787B500E95A00FF0100F23700C5C20000870500454A00082200031B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00051D002E3F00782291B800EA5400FF0000F13C00BEC30000840B00404800072100031B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00051E003241007B1D9BBB00EC4E00FF0000EF4100B4C000008111003B4600062000041C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00061F003643007E18A6BD00ED4800FF0000EE4700A9BE00007F1700374300061F00041D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000620003B45008112B0C000EF4300FF0000EC4C009EBB00007C1C00334100051E00051D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000721003F4800840CBBC200F03D00FF0000EB520094B900007921002F3F00051D00051E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00082200444A008606C5C300F23800FF0100E958008AB600007626002B3D00041D00061F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000923004A4C008900C7BD00F33300FF0200E75F007FB30000732B00273B00041C000620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000A24004F4E068C00CAB700F42E00FF0300E5650075B10000702F00243900031B000721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000B2600514D0E8F00CCB100F62900FE0500E46B006BAE00006D3300213700031B000822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000D2700544C159200CFAA00F72400FE0700E2720061AB00006B37001E3500031A000923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000E2800564A1D9500D1A400F82000FD0900E0790057A80000683B001B3300021A000A24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00102A005949269800D49D00F91B00FD0C00DD80004DA50000653E00193100021A000C26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00122C005C472E9B00D69600FA1700FC0F00DB860044A20000624100162F000219000D27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00142D005F44379E00D88F00FB1400FB1200D98D003A9F00005F4400142D000219000F29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00162F00614241A100DB8900FC1000FA1600D79400319C00005C4600122C00021900102A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00183100643F4BA400DD8200FC0D00F91A00D49B00289900005A4800102A00021900122C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001B3300673B55A700DF7B00FD0A00F81E00D2A2001F960000574A000E2900021900142E
0060433CA000DA8B00FB1100FA1500D79300319C00005C4600122B00021900112B005B47
2F9B00D69500FA1600FB1100D98C003A9F00005F4400132D00021900102A005A482B9A00
D69700FA1600FB1100D98C00399F00005E4500132C00021900112B005C47319C00D89200
FB1300FB1400D793002F9B00005B4700102A00021900142D00604341A100DC8500FC0D00
F91C00D2A1001C950000554C000C2700021A001A3200683B5CAA00E27100FE0500F52A00
CAB700038B0000494C00082200031B00253900732C84B500E95700FF0000EF4100ADBF00
007E1900324100051D00051E003844008111BBC200F13900FF0100E7610073B000006D33
001F3500031A000B2500524D189300D2A300F91B00FC0F00D98C00349D00005B47000F2A
00021900173000653E57A800E17200FE0500F42D00C8BD00008706003F4700062000041D
003040007D1BADBF00F03E00FF0100E75E0074B000006D34001D3400021A000C2600564B
259800D69600FB1300FA1700D39E001B940000524D000A2400031A00223800722D88B500
EB5200FF0000EC4C0091B80000742900243900031B000A2400514D189300D39F00FA1700
FB1400D5990020960000534C000B2500031A00223800732B8DB700EC4D00FF0000EA5300
83B400007030001F3600021A000C2600574A2C9A00D98E00FC0E00F81F00CEAE00068C00
00464B00072000041D003241008015BEC300F33300FE0400E174004EA50000614200122C
00021900173000683B68AD00E66200FF0100EF43009DBB0000762600253A00031B000A25
00544C269800D89100FC0E00F82000CDB000018A0000414800061F00051E003945008608
C9B900F62600FD0A00DA89002F9B0000574A000B2600031A0024390076279EBB00EF4100
FF0100E568005DAA0000643F00132D0002190017300069396FAF00E85B00FF0000EC4E00
86B500006F31001C3400021900102A005F444DA500E27100FF0300F13B00A7BD00007824
00253900031A000C2600584A369E00DD8200FE0700F42F00C0C300007E18002C3E00031B
00092400534C279900D98C00FD0B00F62800C7BF0000811100314000041C00082200514D
219600D89100FD0C00F62600C8BD0000820F00324100041C00082200514D229700D88F00
FD0B00F62700C6C000008113002F3F00031C00092300544C2B9A00DB8800FD0800F42E00
BEC300007C1B00293C00031B000B260058493CA000DF7A00FE0400F13A00A4BD00007528
00213700021A000F2900604356A800E56700FF0000ED4C0082B400006C36001830000219
00162F006A387CB200EC4E00FF0000E6650058A800006043000F2900021A002238007724
AEBF00F33300FE0700DC85002A9A0000524D00082200041C003743008704CDAE00F91900
FA1800CEAC0000880200384400041D00082200534D2B9A00DC8300FE0600F23700A5BD00
007429001E3500021900122C00663D70AF00EA5300FF0000E6640056A800005E44000E28
00031A00283B007D1AC5C200F62600FC0F00D49C000C8F0000414800051E00072100504E
249800DB8700FE0600F23600A3BC0000732B001C3400021900152E006A3882B400EE4700
FF0200E175003B9F0000564B00092300041C003744008900D0A700FB1300F82100C7BD00
007F1700283B00031A000E2900614262AB00E95900FF0000E6640052A700005C46000C26
00031B00304000850ACDB000FA1800F91C00CAB800008112002A3D00031A000E28006142
63AC00E95700FF0000E568004BA400005A48000A2500041C003643008900D1A400FC1000
F62600C1C40000792100213700021900132D006A3986B500EF4200FF0400DD8100269800
004F4E00062000061F004E4E259800DD8200FF0400EF430084B50000693A00122C00021A
002439007C1BC7BF00F81F00FA1600CCB10000830E002B3D00031A000F2900634072B000
EC4C00FF0200DF7A002E9B0000504D00072000061F004F4E289900DE7E00FF0200ED4900
76B10000643F000F2900031A002C3E00840CCEAD00FB1300
001E35006A385FAA00E17400FE0700F72300CFA90017930000544C000D27000219001730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002137006D3469AD00E36D00FE0500F62800CDB0000F900000514D000B2600021A001931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00243900702F74B000E56600FF0300F52D00CAB700078C00004F4E000A2400031A001C33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00283B00732B7FB300E75F00FF0200F33300C7BD0000890000494C00092300031A001F36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002C3D0077258BB600E95800FF0100F23800C5C40000860700434900082200031B002238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003040007A2097B900EB5100FF0000F03E00B9C20000830E003E4700072000031C00263A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003542007D1AA2BC00ED4A00FF0000EE4500ADBF0000801500394400061F00041C002A3C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003A45008013AFBF00EF4400FF0000ED4B00A1BC00007C1B00344200051E00041D002E3F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003F4700830DBBC200F03E00FF0000EB520095B900007921002F3F00051D00051E003241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00454A008705C5C300F23700FF0100E9590089B600007627002B3D00041D00061F003744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004B4D018A00C8BC00F33100FF0200E760007DB30000732C00273A00041C000720003C46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00504E098D00CBB500F52C00FF0400E5670071B000006F3100233800031B000821004249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00534D129100CEAE00F62600FE0600E36F0066AC00006C35001F3600031B00092300484C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00564B1B9400D0A600F82100FD0800E076005BA900006939001C3400031A000A24004E4E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005949249800D39F00F91C00FD0B00DE7E004FA60000663D00193200021A000B2500514D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005C472E9B00D69700FA1800FC0F00DB860045A20000624100162F000219000D2700544C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005F44389E00D88F00FB1300FB1200D98D003A9F00005F4400142D000219000F2900574A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00624143A200DB8700FC0F00FA1700D69500309C00005C4600122C00021900102B005A48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00653E4EA500DD7F00FD0C00F91B00D49D0026980000594900102A00021900132C005E45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00693A59A900E07800FD0900F82000D1A5001C950000564B000E2800021900152E006142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006C3565AC00E27000FE0600F62500CEAD0013910000534C000C2600021900183000643F
4AA400DD8100FC0C00F91B00D39E00249800005849000F2900021900142D005F443CA000
DA8B00FB1100FA1600D695002E9B00005B4700112B00021900122C005E45379E00D98E00
FB1200FA1500D795002E9B00005B4700102A00021900132D005F443CA000DA8900FC0F00
FA1800D49B0025980000584A000E2800021900162F0063404CA500DE7E00FD0A00F82100
CFA90013910000524D000B2500031A001D34006B3767AD00E46B00FF0400F42F00C8BD00
00880300434900072100041C00283B0076278FB700EB5100FF0000EE4600A3BC00007B1E
002F3F00041D00061F003C4600840CC5C400F33400FF0200E567006AAE00006B36001C34
00021A000C2600544C1E9500D39E00FA1800FB1100D891002E9B00005949000E29000219
00183100673C5DAA00E36E00FE0400F43000C6C10000850A003C4600061F00051D003241
007E17B3C000F13B00FF0100E662006FAF00006C36001C3300021A000D2700574A299900
D79300FB1100F91900D2A10017930000514D000A2400031B00233800732B8BB700EB5000
FF0000EC4F008DB70000732B00233800031B000A2400524D1A9400D39D00FA1600FB1400
D59A001E950000534C000A2400031A00233800732A8FB700EC4C00FF0000EA540081B400
007030001F3500021A000C2700574A2D9B00D98D00FC0D00F82000CDAE00058C0000464A
00072000041D003241008015BEC300F33300FE0400E174004EA50000614200122C000219
00173000683B67AD00E66300FF0100EF42009FBB0000772500263A00031B000A2400544C
249800D79200FC0F00F81F00CDAF00038B0000424900061F00051E00384400850AC8BB00
F62700FD0A00DB8700329C0000584A000C2600031A0023380075299ABA00EF4300FF0100
E5650061AB0000653E00142E00021900162F00683B6BAE00E75E00FF0000ED4B008BB600
00702F001E3500021A000F29005E4548A300E17500FF0400F23800AEBF0000792000273B
00031B000B2500564B309C00DB8600FD0900F52B00C5C300008014002F3F00041C000923
00514D219600D89100FC0D00F72400C9BA0000840C00344200041D000821004F4E1A9400
D69600FC0F00F72200CAB70000850900364300041D000821004F4E1A9400D69500FC0E00
F72300C9BA0000830D00334100041C00082200514D229700D98E00FD0B00F62900C6C200
007F15002D3E00031B000A2400564B329C00DD8100FE0600F33400B1C000007922002439
00031A000D28005D464BA400E36F00FF0100EE44008FB700006F31001B3300021900132D
00673C6FAF00EA5600FF0000E85C0065AC0000643F00112B000219001E3500732B9FBB00
F13B00FE0400DF7C00369E0000564B000A2400031B00304000830ECAB800F81F00FB1300
D2A200078D00003F4700051E000721004F4E1F9600D98E00FD0900F42F00B6C100007921
00233800021A000F2A00614260AB00E75E00FF0000E9590066AC0000634000102A00021A
002238007823B5C100F42E00FD0A00D890001A9400004A4D00061F00061F00474B169200
D79300FD0B00F52D00B7C10000782300223700021A00112B00653E6FAF00EB5300FF0000
E568004DA500005B47000C2600031B002F3F00830DCBB300F91A00FA1900CCB10000840A
00304000031B000B26005B474EA500E56700FF0000EA560067AD00006241000F2900031A
00283B007E17C7BD00F82000FB1400CFAA0000870400334100031B000B25005B484EA500
E56600FF0000E9590061AB00006043000D2800031A002C3E00830FCCB300FA1900F91C00
CAB80000801300293C00031A000F290063406DAE00EB5000FF0100E271003CA00000554B
00082200051D004148119100D79300FD0900F335009FBB00007030001831000219001C34
007528B2C000F52B00FC0E00D3A000028A0000364300031C000B25005C4657A800E85D00
FF0000E5680046A30000574A00092300041D004048129100D89000FE0700F1390093B800
006C3500142E000219002238007C1CC7BF00F81E00FA1800
006F3171AF00E56800FE0400F52B00CBB4000A8E0000504E000A2500021A001B3300673B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00732B7DB300E76000FF0200F33100C8BC00018A00004B4D00092300031A001E35006B37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0076268AB600E95800FF0100F23800C5C30000860600444A00082200031B002237006E32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007A2097B900EB5100FF0000F03E00B9C20000830E003E4700072000031C00263A00722D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007D19A4BD00ED4900FF0000EE4500ABBF00007F1500384400061F00041C002A3C007528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008112B2C000EF4200FF0000EC4D009EBB00007C1C00334100051E00051D002F3F007921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00850AC0C300F13B00FF0000EA540091B800007823002E3E00041D00051E003442007C1B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008802C6C000F33500FF0100E85C0083B40000742900293C00041C00061F003945008014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068C00CAB800F42E00FF0300E6640076B10000712F00253900031B000721003F4800840C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0F9000CDB000F62800FE0500E36C006AAD00006D3400213700031B00082200464B008704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199400D0A800F72200FE0800E175005DAA00006A38001D3400031A000A24004D4E048B00
C9B900F42F00FF0300E5650074B00000703000233800031B000821004349008607C5C300
F23600FF0100E85C0081B40000732B00273A00041C000720003F4800840BC1C400F23900
FF0100E85B0082B40000732B00263A00031C000721004148008608C5C300F23500FF0200
E7610078B10000703000233800031B00082200494C028A00C9B800F52C00FE0500E36D00
63AB00006A38001C3300021A000B2500524D169200D0A600F81F00FD0B00DD820045A200
00614200142D00021900112B005C46359D00D98D00FC1000FA1900D39E001F960000554B
000C2700021A001B3300693963AB00E36C00FF0400F43000C7BF00008607003F48000620
00041C002D3E007A1FA1BC00EE4600FF0000EA540088B60000732B00243900031B000923
004E4E0C8E00CEAC00F82100FD0B00DC83003FA100005E4500112B00021900152E006340
50A600E07600FE0600F52B00C8BB0000870400404800062000041D003040007D1AAFBF00
F03D00FF0100E661006FAF00006B36001B3300021A000D280058492E9B00D98F00FC0F00
F91C00D0A700109000004F4E00092300031B00283B0077249CBB00EE4600FF0000E95A00
79B200006E33001D3400021A000D270058492F9B00D98C00FC0D00F81F00CEAD00078D00
00484B00072100041C002F3F007D19B5C100F23800FF0200E36C005BA90000653E00152E
00021900132D00634055A700E27000FF0300F23600B8C100007E18002F3F00041C000821
004B4D0D8F00D0A600F91A00FB1200D599001C950000514D00092300031B00293C007921
A9BE00F13C00FF0200E46A005AA90000643F00142D00021900162F00673C66AC00E66200
FF0000EE440098BA0000742900223800031A000C2600584A329C00DB8600FD0900F62900
C7BE0000830D00354200041D00072000494C0D8F00D1A400FA1700FA1600D2A3000E8F00
00494C00072000041D00364300840BC8BB00F62600FD0B00D98D0028990000544C000A24
00031B002A3D007C1BB8C200F33200FE0600DE7D003CA000005A48000C2700031A002439
007725A5BD00F13B00FF0300E1730049A400005D46000E2800021A00203600742A9CBB00
F04000FF0200E26F004DA500005E45000F2900021A00203600742A9CBB00F03F00FF0200
E2710049A400005D46000E2800021A002238007626A6BD00F13900FE0400DF79003DA000
005949000C2600031B00283B007B1DBBC200F42F00FE0800DB87002A9A0000534C000923
00041C00324100830DC9B900F72100FC1000D49C0011900000474B00061F00051E004249
0A8E00D2A100FB1300F81E00CBB50000840A00334100041C00092300544C2E9B00DC8300
FE0600F23500AABE0000762600213700021A00102A00624160AB00E75F00FF0000EA5600
6DAE0000653E00122C000219001E3500732AA2BC00F23900FE0500DD81002E9B0000534C
00092200041C003744008802CFAB00FA1700F91B00CCB20000850A00324100031C000A24
00574A3DA000E17500FF0200EE440089B600006C3500173000021900193200703096B900
F03D00FE0400DE7F002F9B0000534C00082200041D003C46068C00D2A100FC1100F72400
C6C100007D1900273B00031A000F2900614261AB00E85A00FF0000E7610057A800005E45
000D2700031B002C3E008210CAB700F91C00FA1700CDAF0000850900314000031B000C26
005C4750A600E66500FF0000E9590061AB00006043000E2800031A002B3D008112CAB700
F91C00FA1900CCB20000830D002D3E00031B000D27005F445FAA00E95A00FF0000E56600
4CA500005A48000A2500041C003643018A00D2A200FC0F00F62800BCC200007823001F36
00021900152E006C3590B800F13D00FE0500DA89001D950000484C00051E00072100524D
339D00E07700FF0100EC4D0071AF00006340000F2900031A002B3D00830ECDB000FA1600
F82000C6C000007B1D00223800021900142E006B3691B800F13B00FE0700D98F00149200
00414800041D00092300584A48A300E56600FF0000E76100
239700D39F00F91D00FD0B00DE7D0051A60000663D001A3200021A000B2500514D0D8F00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2E9B00D69700FA1800FC0F00DB860045A200006341001730000219000D2700544C179300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399F00D98E00FB1300FB1300D98E00399F00005F4400142D000219000F2900574A219700
D2A000F91D00FD0B00DE7E004EA50000653E00183100021A000C2600534C149200CFAB00
F72300FE0800E175005AA90000683A001B3300021A000B2500514D0F9000CDAE00F62500
FE0700E174005BA90000683A001B3300021A000B2500524D139100CFAA00F72200FD0900
DF7A0052A60000653E001831000219000D2700564B1F9600D39F00F91B00FC0E00DB8700
3EA000005F4400132D00021900112B005C46369E00D98D00FC1000FA1800D49B00239700
00574A000D2700021900183100673C59A800E17300FE0600F52900CAB600028B0000484B
00082200031B00263A0074298AB600EA5300FF0000EE4500A3BD00007B1E002E3F00041D
000620003E47008509C6C100F43100FF0400E36C0061AB0000683A001932000219000E28
0058492A9A00D79300FB1200FA1700D49D001E950000544C000B2600031A001E35006E33
76B100E85D00FF0100F03F00ABBF00007C1B002F3F00041D000720004149008802C9B900
F62900FE0700DF7A0049A40000614200132C00021900142D00634150A600E17500FE0500
F42E00C7BF0000850A003B4500051F00051E00374400820FC5C300F43100FE0400E17300
53A70000634000142D00021900132D00624152A600E17300FE0400F33100C4C400008111
00354200051D00061F004048008901CBB600F72500FD0A00DC8500379E00005A48000E28
00021A001C34006D337BB200E95700FF0000EC4C008EB70000732C00213700031A000C26
00574A2C9A00D98D00FC0D00F72100CCB20000890000404800061F00051E00384400850A
C8BC00F62800FD0900DC8400369E00005949000D2700021A00203600722D8DB700ED4B00
FF0000E85C0070AF00006A3900183100021900122C00624156A800E36D00FF0200F13D00
A6BD0000782300263A00031B000B2500564B2C9A00DA8A00FD0B00F62600C8BB0000840B
00364300041D00072000494C0F9000D2A200FA1600FA1800D0A6000A8E0000454A000620
00051E003A45008704CBB300F82000FC0F00D696001B940000504E00082200041C003241
008210C7BE00F62800FD0B00D98C0027980000534C00092300031B002E3E007F16C5C400
F52B00FD0900DB89002B9A0000544C000A2400031B002D3E007F16C5C300F52B00FD0A00
DA8B0027990000534C00092300041C003040008111C7BE00F62600FC0D00D793001D9500
004F4E00082100041D003744008706CCB200F81D00FB1300D2A1000B8E0000444A00061F
00061F00444A0C8F00D3A000FB1200F81E00CBB50000850900344200041C00092200524D
299900DB8800FE0800F43100B5C10000792100253900031A000E28005E4551A600E46900
FF0000ED4B0081B400006B37001730000219001831006D3587B500EE4700FF0100E36F00
48A300005B47000C2600031B002A3D007F17C6C000F62500FC0E00D49B000F900000444A
00051F000620004B4D199400D79200FD0B00F52C00BAC200007A2000243900021A000F2A
00614261AB00E85C00FF0000E85C0061AB00006242000F2900021A002539007B1EC0C300
F52900FC0D00D5980010900000434900051E000720004F4E239700DB8800FE0600F23700
A1BC0000722D001B3300021900162F006C3689B600EF4300FF0300DF7A00339D0000544C
00082200041D003D46088D00D39E00FC0E00F62800C0C300007A2000233800021A00122B
00663D76B100EC4D00FF0100E272003DA00000564B00092300041D003B45078C00D39E00
FC0E00F52900BBC20000782300203600021900142D006A3886B500EF4300FF0300DE7F00
2A9A0000504E00072000061F004A4C1E9500DA8900FE0600F13C0092B800006D3400162F
000219001F35007725B9C200F62900FC0F00D2A200008A0000354300031C000B25005C46
56A800E75E00FF0000E565004BA400005949000A2400041C003C460B8E00D69700FD0A00
F33300A1BC00007030001830000219001D34007626BAC200F62700FB1100D0A800008606
002F3F00031B000E280062416DAE00EC4E00FF0100DF7A00
45A300DB8600FC0F00FA1700D697002E9B00005C4700112B00021900112B005B472C9A00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51A600DE7D00FD0B00F91D00D39F00239700005849000F2900021900132D005E45379E00
D88F00FB1300FB1300D88F00379E00005E4500132D00021900102A005948299900D59A00
FA1900FC0E00DB870042A10000614200152E000219000E2900584A239700D49D00F91A00
FC0E00DC850043A20000614200152E000219000F29005949279900D59900FA1800FC1000
DA8B003A9F00005E4500122C00021900112B005D46359D00D98E00FB1100FA1600D59800
289900005849000E2900021900162F0064404DA500DF7C00FD0900F72300CEAC000F9000
00504E000A2400031A001F36006E3372B000E66200FF0200F23700C1C40000830E003B45
00061F00041D003040007C1CA6BD00EF4400FF0000EA550088B60000732B00253900031B
000822004C4D088D00CDB000F72400FD0900DE7D0048A40000614200142D00021900122C
005F4441A100DD8200FD0A00F72200CDAE000A8E00004C4D00082200031B00263A007527
92B800EC4D00FF0000EC4E008FB80000752900253A00031B000923004F4E0F9000D0A800
F81D00FC0E00D98C00329C00005A48000E28000219001A32006A386AAD00E66400FF0100
F13B00B1C000007D1A002F3F00041C00072000444A018A00CBB300F72400FD0A00DC8400
3B9F00005C47000F29000219001932006A386BAE00E66200FF0100F03F00A7BD00007A20
002A3D00031B000822004E4E109000D1A500F91A00FB1200D6970021960000534C000A25
00031A00243900752896B900EE4700FF0000E85C0073B000006B37001A3200021900102A
005D4543A200DF7B00FE0600F42E00C5C20000821000344200041D00072000454A068C00
CEAC00F91D00FC1000D6950020960000534D000A2400031B00283B007921A9BE00F13C00
FF0200E36C0056A80000624100122C0002190018300069396FAF00E85C00FF0000ED4C00
8AB60000702F001E3500021A000E29005C4643A200DF7900FE0500F33300B8C200007C1B
002B3D00031B00092300524D239700D89100FC0D00F72300CAB70000860700384400051D
00072000484B0D8F00D2A300FA1600FA1800D0A800078D0000434900061F00051E003E47
008A00CDAE00F91C00FB1300D39E00129100004A4D00072000051D003944008706CBB400
F81F00FC1000D59A00169200004D4E00072100041D003844008706CBB300F81F00FB1100
D49C00139100004A4C00072000051E003C46008900CEAD00F91A00FA1500D1A400098D00
00424900061F00061F00444A0C8E00D2A100FB1300F91D00CCB20000870600374300041D
00082200504E209600D88F00FD0A00F52A00C4C400007D19002A3C00031B000B26005949
3FA100E07600FF0300F03F0099BA0000722D001D3400021900122C00653E6AAE00E95900
FF0000E85B0066AC0000643F00112B000219001F35007429A3BC00F23800FE0500DD8000
309C0000544C00092300041C003542008607CDB000F91A00FA1700CEAC00008802003744
00041C00092200534C2F9B00DD8000FE0500F13A009EBB0000722D001C3400021900142E
00693A7BB200EC4C00FF0100E36D0049A400005B48000B2600031B002E3F00820FCAB700
F81E00FA1500CFA90000880200364300041C00092300564B3A9F00E07600FF0200EE4500
85B500006B3700152F000219001C3400732BA5BD00F33500FE0700DA8C001E9500004C4D
00061F00061F004A4D1C9500D98D00FE0800F33500A3BD0000722C001B33000219001730
006D3491B800F03E00FE0400DC8300279800004F4E00072000061F00484C1A9400D98D00
FE0700F236009EBB0000702F001931000219001A3200712EA1BC00F33400FD0800D89100
15920000444A00051E00082100534C349D00E07700FF0200ED4B0077B10000653D00112B
00021A00273A007F17C9BB00F81D00FA1800CBB300008210002B3D00031A000F29006340
70AF00EC4E00FF0100E07600349D0000524D00072100051E00494C1F9600DB8600FE0400
EF410086B50000693A00122C00021A00253A007E18C9BA00F91C00F91B00C9B800007F16
00263A00021A00122C00693988B600F03F00FE0500DA8B00
5EAA00E17400FE0800F72200D0A80018930000554B000D2700021900162F00624143A200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6BAE00E36C00FE0500F62800CDB0000E8F0000514D000B2600021A00193100663D4FA600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78B100E66300FF0300F42F00C9B900058C00004E4E000A2400031A001C340069395CAA00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86B500E85B00FF0100F23600C6C10000880300464B00082200031B002036006D3469AD00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94B900EB5200FF0000F03D00BCC20000840C003F4800072100031B00243900712F77B100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A3BC00ED4A00FF0000EE4500ADBF0000801400394400061F00041C00293C00752985B500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B2C000EF4200FF0000EC4D009EBB00007C1C00334100051E00051D002E3F00792293B800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C1C400F13B00FF0000EA550090B800007823002D3E00041D00051E003442007C1BA2BC00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C7BE00F33300FF0200E85D0082B40000742A00283B00041C000620003A45008013B1C000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CAB600F52C00FF0300E5660073B00000703000243900031B00072100414800840AC0C300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CEAD00F62600FE0600E26F0066AC00006C35001F3600031B00092300484B008901C7BF00
F33300FF0200E75F007EB30000732C00273A00041C000720003E4700830DBCC200F13C00
FF0000EA56008CB700007626002B3D00041C00061F003A45008112B5C100F03F00FF0000
EA54008EB700007725002B3D00041C000620003B4600820FBAC200F13C00FF0000E95900
85B50000742A00273A00031C000721004249008706C6C000F33300FF0200E6650071AF00
006E3300203600031A000A24004F4E0B8E00CDB000F72500FE0800E0780052A70000653E
001730000219000E28005849289900D69700FA1500FB1300D793002C9A00005949000F29
00021900173000653E53A700E07600FE0700F62800CBB500038B0000484C00082200031B
00273B0075288FB700EB5000FF0000ED49009BBA00007822002B3D00041C00072100444A
008900CAB800F52900FE0700E0770050A60000634000152E00021900112B005E453FA100
DC8300FD0B00F72200CDAE00098D00004B4D00082200031B00283B00772499BA00ED4800
FF0000EA550084B50000712E00213700031A000B2500534C1C9500D49D00FA1600FB1400
D5990020960000544C000B2500031A00213700712E85B500EA5300FF0000EC4C0090B800
00742A00243900031B000A2400524D1C9500D49C00FA1500FA1600D39E0019940000514D
00092400031B00263A0076269BBA00EE4600FF0000E85C0073B000006B36001B32000219
000F29005C463EA000DD8000FE0800F52900C8BC00008509003A4500051E00061F003D47
008704CAB700F72500FD0B00DB8800329C00005849000D2700021A00203600722D8CB700
EC4C00FF0000E9590075B100006B36001A3200021900102A005F444BA400E17400FE0400
F23500B7C100007D1A002C3E00031C00092300504D1B9400D59900FB1200F91C00CEAB00
058C0000434900061F00051E003A45008606CAB700F72300FC0D00D88F0026980000534C
000A2400031B002A3C007B1DB4C100F33500FE0400E0780043A200005C47000E2800021A
00203600732B96B900EF4400FF0100E5680059A90000624100122B000219001A32006D33
82B400EC4E00FF0000E75E0068AD0000663D00142E000219001830006A3779B200EA5300
FF0000E95A006EAF0000673B00152E000219001730006A3878B100EA5300FF0000E85B00
6BAE0000663C00142D000219001931006C3581B400EC4D00FF0000E662005FAA00006340
00112B000219001D3400712E94B900EF4200FF0200E270004AA400005D46000D2800031A
002439007922B1C000F33300FE0600DC83002F9B0000544C00092300041C00314000830E
C9B900F72100FC1000D49D000F900000454A00061F00061F00454A0F9000D49C00FC1000
F72200C8BB00008111002E3F00031B000A2500574A3B9F00E07800FF0300F03F0096B900
00712F001B3300021900142E00683A77B100EB5000FF0000E5660053A700005E45000E28
00031A00273B007C1BC4C400F62800FC0D00D6970013910000464B00061F00061F004A4D
199400D89100FD0A00F42E00B7C10000782200223800021A00102A00634069AD00E95700
FF0000E6630056A800005E45000D2800031A002A3C007F16C7BD00F72100FB1200D1A500
028A0000394400041C00092300554B379E00E07700FF0200EE460084B500006A3800152E
000219001D34007429ABBE00F33100FD0900D8910016930000464B00051E00072000504E
279800DC8300FE0500F03D0092B800006D34001730000219001C3300732BA8BE00F33200
FD0900D7930013910000434900051E00082100534D329C00DF7900FF0200EE48007CB300
00673B00122C00021A002439007C1CC6C100F72200FB1400CFAA0000860700314000031B
000C27005E455DAA00E85A00FF0000E5680048A400005849000A2400041C003B460A8E00
D59900FD0B00F43100A7BD0000722D001932000219001B3300742AAFBF00F52C00FC0D00
D39F00028A0000364300031B000B26005D465BA900E95A00FF0000E36C0040A10000554B
00082200051E00454A1A9400DA8900FE0500F0400085B500
D1A400F82000FD0900E0780058A80000683A001C3300031A000A24004F4E078D00CAB600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D49B00F91A00FC0D00DD81004BA40000643F00183100021A000C2600524D129100CEAD00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D89200FB1500FB1100DA8B003EA00000614300152E000219000E2800564B1C9500D1A400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DB8800FC1000FA1600D79400329C00005D4600122C00021900102A005A48289900D49B00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DE7F00FD0C00F91B00D49D0026980000594900102A00021900132C005D45349D00D89200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E17500FD0800F72100D0A7001A940000554B000D2800021900152F00614241A100DB8800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E36C00FE0500F62800CDB0000F900000524D000B2600021A00193100653E4EA500DE7F00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E66300FF0300F42F00C9B900058C00004E4E000A2400031A001C340069395CA900E17500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E95A00FF0100F23600C6C20000870400464B00082200031B002037006D346AAD00E36C00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EB5100FF0000F03E00BAC20000830D003E4700072100031B00253900712E78B100E66300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ED4800FF0000EE4600AABE00007F1600384400061F00041C002A3C00752787B500E95900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F04000FF0000EC4F009ABA00007B1E00314000051E00051E003040007A2097B900EB5000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F23800FF0100E958008AB600007626002B3D00041D00061F003643007E18A7BD00EE4800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F43000FF0200E661007BB20000722D00263A00041C000720003D4600820FB7C100F03F00
FF0000EB510095B900007921002F3F00051D00051E003442007D1BA3BC00ED4900FF0000
EE4800A5BD00007D1A00344200051E00051D003040007A1F9BBB00EC4D00FF0000EE4600
A8BE00007E1900344200051E00051D003040007B1D9FBC00ED4A00FF0000ED4A00A0BC00
007B1E00304000051D00051E003643007F16AFBF00EF4100FF0000EA54008CB700007528
00283B00041C000721004148008606C6C000F33200FF0300E566006DAE00006C35001E35
00031A000A2500514D129100CFA900F82000FD0B00DD810045A30000614200142D000219
00112B005D46399F00DA8A00FC0E00F91B00D2A20019940000534C000B2500031A001E35
006D3570AF00E66300FF0200F23800BCC20000811200374300051E00051E003543008013
B9C200F13900FF0100E663006EAF00006C36001C3400021A000C2600564B249700D59800
FB1400FA1500D59A0021960000554B000C2600021A001E35006E3377B100E85C00FF0000
EF4100A7BD00007B1E002D3E00041C00072100464B038B00CCB200F72400FD0A00DC8300
3DA000005D4600102A00021900183000673B62AB00E46900FF0200F23800B6C100007E18
00314000041D000720004349018A00CCB300F72300FD0B00DB8600379E00005A48000E28
000219001B33006C3574B000E85C00FF0000EE460099BA0000762600253A00031B000A24
00524D1E9500D59900FB1300F91900D1A400109000004D4E00082200041C002D3E007C1B
B3C000F23800FF0300E36E0056A80000634000132D00021900162F00673C64AC00E66400
FF0100EF42009FBB0000772500253A00031B000B2500554B289900D88F00FC0D00F72100
CBB300008801003E4700051F00051E003D46008802CBB400F72100FC0D00D89000259800
00534C000A2400031B00293C007A1FAFBF00F23800FF0300E173004BA400005F4400102A
000219001C34006F3186B500EC4D00FF0000E85C006CAE0000683B00162F00021900152E
00673C69AD00E75E00FF0000EC4D0086B500006F32001B3300021900112B00614256A800
E46A00FF0100EF430097B90000732B001F3600021A000F29005E454CA500E27000FF0200
F03E009EBB0000752900213700021A000E28005D454AA400E27100FF0200F03F009CBB00
00742A00203600021A000F29005F4452A600E46B00FF0100EE450090B800007030001C33
00021900122C00644062AB00E76000FF0000EB51007AB200006A3800162F000219001730
006A377CB300EC4F00FF0000E663005CAA0000624200102A00021A001F36007429A1BC00
F13A00FE0400DF7B00389E0000574A000A2500031B002E3F008112C8BD00F72400FC0F00
D59A0011900000464B00061F00061F00454A109000D49B00FC0F00F72400C7BE00008014
002C3E00031B000B26005A4844A200E27200FF0200EE460089B600006D34001830000219
001830006D3489B600EE4500FF0200E1730040A100005849000B2500031B00304000840C
CBB500F91D00FA1600CFAA0000880100374400041C00092300554B359D00DF7B00FF0300
EF41008FB700006E33001830000219001931006F3194B900F03E00FE0400DE7F002E9B00
00524D00082200051D003E47098D00D49D00FC0F00F62700C3C400007B1E00243900021A
00102A00643F6EAF00EB5200FF0000E46A0048A400005A48000B2500031C003342008704
CFAA00FB1400F82000C8BD00007E1700283B00031A000F290062416AAD00EA5400FF0000
E46B0046A300005849000A2400041C003844028B00D2A200FC0F00F62700BEC300007922
00213700021900142D006A3887B500EF4200FF0400DD8200269800004F4E00062000061F
004E4E249800DC8300FE0400EF410086B50000693900132D000219002338007B1DC6C100
F72100FA1500CEAE0000840B002D3E00031A000E280062416BAE00EB5000FF0100E17500
359D0000524D00072100051E004A4C219600DC8400FF0400EF430080B40000673C00112B
00021A00283B008113CBB400FA1800F81F00C6C000007B1D
F62900FE0500E46B006CAE00006E3300213700031B00082200444A008706C5C300F23700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F72200FE0800E175005DAA00006A38001D3400031A000924004C4D038B00C9BA00F42F00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F91C00FD0C00DE7F004FA60000663D00193200021A000B2500514D0E8F00CDB000F62800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FA1600FC1000DB890041A10000614200162F000219000D2700554B199400D0A700F72100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FB1100FA1500D79300339D00005D4500132C00021900102A005949269800D49D00F91B00
FC0C00DD81004AA40000643F001830000219000C2700544C169200CFA900F72200FD0800
E0770058A80000683B001B3300021A000B2500514D109000CEAD00F72500FE0700E17400
5BA90000683A001B3300021A000B2500524D129100CFAB00F72300FD0800E0790053A700
00663D001831000219000D2700554B1D9500D2A100F91C00FC0D00DC850042A200006043
00142D00021900102A005B47329C00D89000FB1200FA1600D59800289900005849000E28
00021900173000653E52A700E07800FE0700F62600CCB200088D00004C4D00092300031B
00233800722D81B400E95900FF0000F04000AEBF00007E1900324100051D00061F003944
00820FBFC300F23700FF0200E565006CAE00006C36001C3400021A000C2600554B209600
D49C00FA1700FB1300D7940029990000574A000D2700021A001A32006A3868AD00E56700
FF0200F23700BCC30000811300354300051E00051F003A4500830DC5C300F33100FE0400
E26F005AA90000653D00162F00021900112B005E453FA100DD8100FD0900F72500CBB300
028A0000444A00072000041C002F3F007D1BB0C000F13C00FF0100E5650067AD0000693A
001931000219000F2A005C463DA000DD8200FD0900F62600CAB70000880200404800061F
00051D003542008111C4C400F43100FE0500E175004EA50000614200122C00021900162F
00663D61AB00E56800FF0200F13C00ABBE00007A1F002A3D00031B000923004F4E159200
D39F00FA1600FA1600D3A000159200004F4E00082200031C002C3E007C1CB2C000F23800
FF0300E2700053A70000624200122C00021900173000693A6DAE00E75E00FF0000ED4800
92B80000732C00213700031A000D27005949379E00DC8300FD0800F52B00C6C000008210
00334200041D000721004B4D109000D2A200FA1600FA1700D1A4000C8F0000484B000720
00041D00374300850AC9BA00F62500FD0C00D98D0027990000544C000A2400031B002A3D
007C1CB8C100F33300FE0500DE7C003DA000005A48000D2700031A002338007626A2BC00
F03D00FF0200E271004CA500005E45000F2900021A001F3600732C97B900EF4200FF0100
E36C0052A70000604300102A00021A001E3500722D96B900EF4200FF0100E36D0050A600
005F44000F2900021A00203600742A9EBB00F03E00FF0300E1740045A300005B47000D27
00031A002539007922B0C000F33400FE0600DD8100339D0000564B000A2400031B002D3E
008014C6C000F62700FC0D00D794001A9400004E4E00072100051D003C46018A00CFAA00
FA1700F91900CEAC0000890100394500041D00082100504E229700D98D00FD0900F42D00
BBC200007B1E00263A00031A000D28005D4550A600E46A00FF0000ED4C007FB300006A38
00162F000219001931006E328EB700EF4300FF0200E174003FA100005849000B2500031B
002F3F00820FCAB800F81F00FB1300D1A500048B00003C4600041D00082200524D299900
DC8400FE0600F23800A1BC0000732C001D3400021900142E00693A7CB300ED4B00FF0100
E36F0045A200005949000B2500031B00314000840BCCB200F91A00FA1900CDB000008509
00314000031B000B25005A4847A300E36C00FF0000EB500073B00000663D00112B00021A
002238007921BDC300F52900FC0D00D49C000A8E00003E4700041D00082200544C349D00
DF7900FF0200EE460081B40000693900132D000219002036007824B9C200F52A00FC0D00
D49D00088D00003C4600041D00092300564B3EA000E27000FF0100EB50006EAF00006340
000F2A00031A00283B007F15C9B900F91D00FA1800CCB30000820F002C3D00031A000E28
00614269AD00EB5300FF0000E270003DA00000554B00082200051D004148129100D89100
FE0800F236009BBA00006F32001730000219001E35007725BAC200F62700FC1000D0A600
00870400324100031B000D2700604364AC00EA5400FF0000E27200389E0000534C000721
00051E004A4C219700DC8300FF0300EE45007CB30000663D
FD0C00F91B00D49D0027980000594900102A00021900122C005D46329D00D79300FA1500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FD0800F72100D0A6001A940000554B000D2800021900152F00614240A100DA8900FC1000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FE0500F62800CDB0000F900000514D000B2600021A00193100653E4EA500DE7F00FD0B00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FF0200F43000C9BA00038B00004D4E000A2400031A001D340069395DAA00E17500FE0800
F72300CFA90016920000544C000C2700021900173000643F4AA400DD8100FD0C00F91C00
D39F0021970000574A000E2800021900152E00614243A200DC8500FC0E00F91A00D49D00
24980000584A000E2900021900152F00624145A300DC8300FC0C00F91C00D2A1001E9500
00554B000D2700021900183100653E52A700DF7900FD0800F72300CEAD000F900000504D
000A2400031A001E35006C356BAE00E56800FF0300F43100C7BF00008705004249000721
00041C00293C00762690B800EB5100FF0000EE4600A3BC00007B1E002F3F00041D00061F
003B4600830DC3C400F23500FF0200E565006DAE00006C35001D3400021A000B2500534C
1A9400D2A100F91A00FC0F00D98D00339D00005B47000F2900021900173000653E56A800
E17300FE0500F52C00C8BB0000870400414800072000041C002E3F007B1DA8BE00EF4200
FF0000E85B007BB200006F31001F3600031A000B2500544C1E9500D49C00FA1600FB1400
D6980023970000554B000C2600031A001E35006E327AB200E95A00FF0000EE4400A0BC00
00782200293C00031B000822004C4D0C8E00CFAA00F81E00FC0E00D98D002F9B00005849
000D2700021A001D34006D3478B100E95A00FF0000EE46009ABA0000762600263A00031B
00092300514D199300D39E00FA1600FA1500D49D0019940000514D00092300031B00273B
007824A0BC00EF4200FF0100E761006BAE0000693900183100021900112B005F444AA400
E07700FE0500F43100C1C40000801400324100041D00072100484C0A8E00CFA900F91B00
FB1200D598001D950000514D00092300031B00293C007A1FADBF00F13A00FF0200E36E00
54A70000624100122C000219001831006A3871AF00E85B00FF0000EC4C008AB60000702F
001E3500021A000E29005C4642A200DF7900FE0500F33300B9C200007D1A002C3D00031B
00092300524D219600D79300FC0E00F72200CBB500008705003A4500051E00062000464A
0A8E00D1A500FA1700FA1700D1A4000B8E0000464B00062000051E003B45008803CCB200
F81F00FC1000D59900179300004E4E00072100041D00354300840BC9B900F72300FC0E00
D794001D950000504E00082200041C00344200840CC9B900F72300FC0E00D695001B9400
004F4E00082100041D003643008608CBB500F81F00FB1100D49C0012910000494C000620
00051E003D47028A00CFAA00FA1800FA1700CFA900038B00003E4700051E000720004A4C
149200D59900FC0F00F72300C8BB0000820F00304000031C000A2400554B309C00DD8200
FE0600F23500ACBF0000772500223800021A000F2900604358A800E66500FF0000EC4F00
7AB20000693900152F000219001932006E328DB700EF4400FF0200E2720043A200005A48
000B2600031B002C3D008014C7BE00F72400FC1000D49D000D8F0000434900051E000620
004C4D1B9400D89100FD0A00F42D00B9C20000792100233800021A000F2A00624261AB00
E85C00FF0000E85C0062AB00006241000F2A00021A002439007A1FBEC300F52A00FD0C00
D6970012910000444A00051E000720004E4E219600DA8A00FE0700F33500A5BD0000732B
001D3400021900152E006A3883B400EE4600FF0200E07700389F0000554B00092300041C
003A45038B00D2A200FB1100F72400C5C200007C1C00253A00021A00102A00643F6EAE00
EB5200FF0000E36C0045A300005949000A2400041C003643008900D1A500FB1100F72400
C5C300007B1D00243900021A00122B00673C79B200ED4A00FF0200E07700359D0000534C
00082200051E004249139100D79200FD0900F33400A1BC0000712F001931000219001A32
00732CA8BE00F43000FD0B00D598000B8E00003D4600041D00092300584A46A300E46900
FF0000E95A005CAA00005E45000C2600031B003342008901D1A400FC0F00F62900B7C100
007627001D3400021900183100712FA4BD00F33100FD0B00D59A00078D0000394400041C
000B25005C4757A800E85C00FF0000E46B0041A10000554B
FF0100F23800C5C30000860600444A00082200031B002137006E336CAE00E46A00FE0500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FF0000F04000B5C100008210003D4600072000041C00263A00722C7CB200E76100FF0200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FF0000ED4900A4BD00007D1900354300061F00041D002C3D0077258CB700E95700FF0000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FF0000EB530094B900007921002F3F00051D00051E003241007B1D9DBB00EC4D00FF0000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FF0100E85D0083B40000742900293C00041C00061F003944008014AEBF00EF4400FF0000
EC4C009FBB00007C1C00324100051E00051D003040007A2099BA00EC4F00FF0000EF4200
AFBF0000801400384400061F00041D002C3D00772490B800EA5300FF0000F03F00B4C100
00811200394500061F00041D002C3E00782393B800EB5100FF0000EF4300ADBF00007E17
00354300051E00051D003140007B1DA2BC00EE4800FF0000EC4D0099BA00007921002D3E
00041D00061F003B4500820FBDC300F13900FF0100E85E007BB20000702F00223800031B
000923004C4D078D00CCB200F62700FE0700E0770053A70000653E001730000219000E29
0059492B9A00D79400FB1300FA1500D5980026980000574A000D2700021900193200683A
5FAA00E36D00FE0400F42F00C7BF00008607003F4700062000041D002E3F007B1DA6BD00
EF4300FF0000E9580080B40000712F00223700031A000A2400514D159200D1A400F91B00
FC0F00D98D00319C00005A48000E2900021900193100683A64AC00E46900FF0200F23600
BDC30000801300354200051E00061F003C46008509C7BF00F42E00FE0500E1750050A600
00634100142D00021900132D0061424DA500E07700FE0600F42D00C7BF0000840A003A45
00051E00051E00394400840CC6C000F42E00FE0600E077004BA50000614300122C000219
00162F00663D5DAA00E46B00FF0200F13900B3C000007D1A002E3F00041C000821004A4C
0B8E00CFA900F91C00FC1000D7940023970000544C000B2500031A00243900752898BA00
EE4600FF0000E75E006FAF00006A3800193100021900112B0060434BA400E17500FE0400
F33300BCC200007E17002F3F00041C000822004D4E129100D2A100FA1600FA1600D2A200
119100004C4D00082100041C003140008014C4C400F42F00FE0600DE7E003DA000005B47
000E2800021A001F3600722D90B800ED4800FF0000E7600067AD0000673C00152E000219
00152E00673C68AD00E76000FF0000ED4A008BB60000702F001D34000219000F29005E45
4BA400E27200FF0300F13B00A7BD0000772400253900031A000C26005949389F00DE7F00
FE0600F33100BAC200007C1B002A3C00031B000A2400554B2F9B00DB8600FD0800F52D00
C2C400007E18002C3E00031B000A2400554B2D9B00DB8700FD0800F42D00C1C400007D19
002B3D00031B000A2500564B339D00DD8200FE0600F33200B5C100007A1F00273A00031A
000C26005A4841A100E07700FF0300F13C00A0BC0000742900203600021A00102A006143
58A800E56600FF0000EC4C0081B400006C3600183000021900162F006A387AB200EB5000
FF0000E663005BA90000614200102A00021A002137007627A8BE00F23600FE0500DD8100
309C0000544C00092300041C00334100850ACBB400F81D00FB1400D1A500048B00003D46
00051D00072100504E219700D98C00FD0900F43000B4C10000782200233800021A00102A
00624260AB00E85E00FF0000E9590067AD0000634000112B00021A002137007724B3C000
F43000FD0900D98E001C9500004C4D00062000051F00454A129100D69700FD0C00F52A00
BDC300007A1F00243900021A00102A00634067AD00E95700FF0000E6630055A800005E45
000D2700031B002B3D008113C9BA00F81F00FA1500CFAA0000880300354200041C000A24
00584942A200E26F00FF0100EC4E0075B00000663D00112B00021A002338007A20C0C300
F62700FC0F00D39F00068C00003B4500041D00092300564B3DA000E27200FF0100EC4E00
73B00000653E00112B00021A00253A007D1AC6C000F72100FB1400CFAA00008706003241
00031B000C26005D4656A800E75F00FF0000E6620052A600005B47000B2500031C003542
008900D1A400FC1000F62800BCC200007824001F3600021900152F006D3493B900F13A00
FE0600D98D0018930000444A00051E00082200544C3B9F00E27000FF0000EA540065AC00
006043000D2700031B003140008704D0A600FC1000F62800B8C200007627001D34000219
00193100712EA8BE00F42F00FD0C00D39E00028B00003543
FF0400E5670073B00000703000243900031B00072100404800840BBFC300F13B00FF0000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FE0700E2710063AC00006B36001F3500031A00092300494C008900C7BE00F33300FF0200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FD0A00DF7B0054A70000673C001A3200021A000B2500504E0A8E00CBB400F52B00FE0400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FC0F00DB860045A200006341001730000219000D2700544C169200CFAA00F72300FE0700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FB1400D89000369E00005E4500132D000219000F29005849239700D39F00F91C00FD0B00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F91A00D49B00289900005A4800102A00021900122C005C46309C00D69500FA1600FC1000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F82100D1A6001B940000564B000E2800021900152E0061433EA000DA8A00FB1100FA1600
D79400319C00005C4600122C00021900112B005B472D9B00D69700FA1700FC1000DA8900
3FA00000604300142E000219000F29005849259800D49C00F91A00FC0E00DC860042A200
00614200152E000219000F29005849269800D59A00FA1800FC0F00DA89003CA000005F44
00132D00021900112B005B47319C00D89100FB1300FB1500D795002D9B00005A48000F2A
00021900152E00624147A300DD8100FD0B00F81F00D0A70015920000524D000B2500021A
001D34006B3768AD00E46900FF0300F43100C7BF0000860600414800072000041C002B3D
00782398BA00EC4C00FF0000EC4C0097B900007824002A3C00041C000721004349008802
C8BB00F52C00FE0500E2720059A80000663D001730000219000F29005A48309C00D98F00
FC1000F91A00D2A10019940000534D000B2500031A002036006F317BB200E85B00FF0000
EF4100A8BE00007B1D002E3F00041C000720004249008901CAB800F62900FE0700DF7B00
49A40000614200132C00021900142D0062414FA500E07600FE0600F52C00C7BE00008608
003C4600061F00051E003543008111C1C400F33300FF0300E26F0058A80000653E00152E
00021900122C0060434BA400E07800FE0600F42D00C6C00000840C00394400051E00051E
003B46008608C8BC00F52A00FE0700DE7E0041A100005D4500102A000219001931006A38
6DAE00E76000FF0000EF44009DBB0000772500263A00031B000A2400524D1F9600D69700
FB1200F91A00D0A7000C8F00004A4C00072100041C003040007F16BEC300F33200FE0500
E0770049A400005F4400102A000219001A32006C3677B100E95800FF0000EC4E0088B500
007030001E3500021A000E28005B473FA100DE7D00FE0600F42F00C2C400007F15003040
00041C000822004F4E169200D49C00FB1300F91A00CFA900078C0000444A00061F00051E
003A45008706CBB500F72200FC0E00D7920022970000524D00092300031B002D3E007E18
BFC300F43000FE0700DD8000389E00005849000C2600031A002539007824A8BE00F13A00
FF0300E1740047A300005D46000E2800021A00213700742A9CBB00F04000FF0200E36F00
4EA500005F44000F2900021A001F3600732B99BA00F04000FF0200E26F004DA500005E45
000E2900021A002137007528A1BC00F13C00FF0300E1750043A200005B47000D2700031A
00253A007921B2C000F33300FE0600DD8200329C0000564B000A2400031B002E3F008013
C7BF00F62600FC0D00D794001A9400004E4E00072100051D003C46018A00CFAA00FA1700
FA1900CEAC00008901003A4500041D00082100504E219600D98D00FD0A00F52D00BDC300
007B1D00263A00031A000D27005D464EA500E46B00FF0100ED4A0081B400006B3700162F
000219001831006D338BB600EE4500FF0200E1720042A200005949000B2500031B002D3E
008111C9BA00F82100FB1200D2A200068C00003E4700051D00072100504D269800DB8700
FE0700F23500A7BD00007429001E3500021900132D00673B77B100EC4E00FF0000E46B00
4AA400005B47000C2600031B002E3F00830ECAB600F91C00FA1600CEAC00008705003442
00041C000A2400584A41A100E27100FF0100ED4B007AB20000683B00132D000219002036
007725B4C100F42D00FD0B00D6960011900000424900051E00072100514D2C9A00DE7F00
FF0300EF41008BB600006C3600152F000219001D34007528AEBF00F42F00FD0B00D69600
10900000414800051D00082200534C359D00E07700FF0200ED4A007AB20000673C00112B
00021A002439007C1BC6C000F72200FB1400CFAB0000860700314000031B000C27005E45
5CAA00E85A00FF0000E5670049A400005949000A2400041C003B45098D00D59A00FD0B00
F42F00AABE0000722C001A32000219001A3200732CABBE00F42E00FD0C00D49D00058C00
00384400041C000B25005C4756A800E85D00FF0000E5680046A30000574A00092300041D
004149159200D98E00FE0600F13C008DB700006A3800132D
F62800CDB0000F900000524D000B2600021A00193100653E4DA500DD7F00FD0C00F91C00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F43000C9BA00038B00004C4D000A2400031A001D340069395DAA00E17500FE0800F72300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F23900C4C40000860700444A00082200031B002237006E336DAE00E46A00FE0400F52A00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EF4200B3C000008111003B4600072000041C00273B00732C7EB300E75F00FF0200F33300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ED4C00A1BC00007C1B00344200051E00041D002D3E0078248FB700EA5500FF0000F13B00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EA56008FB700007824002D3E00041D00051E003442007C1BA1BC00ED4B00FF0000EE4500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E760007DB30000732B00273B00041C000620003B46008111B3C000EF4100FF0000EC4E00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E46B006CAE00006E3300223700031B000822004349008607C5C400F23800FF0100E95900
88B600007627002A3D00041C00061F003944008014AFBF00EF4300FF0000EC4E009ABA00
007A1F00304000051D00051E003442007D1AA5BD00EE4800FF0000ED4A009FBC00007B1D
00314000051E00051E003442007D1AA7BD00EE4600FF0000EC4D0099BA00007921002E3F
00041D00061F003844008113B5C100F03E00FF0000E9570087B50000742900273B00031C
000721004349008704C7BE00F43100FF0300E568006BAE00006C36001E3500031A000B25
00514D139100D0A800F82000FD0B00DD810045A30000614200142D00021900112B005D46
389E00DA8A00FC0F00F91B00D2A1001A940000534C000B2600021A001D34006C366DAE00
E56500FF0200F23600C0C30000820F00394400051F00051E003342007F16B4C100F13C00
FF0100E7600074B000006D34001E3500031A000B2600544C1E9500D49D00FA1700FB1300
D6950027990000574A000D2700021A001C33006B366EAF00E66200FF0100F13C00B1C000
007D1900314000041D000620004048008803C9B900F62900FE0700DF7B0048A300006043
00122C00021900152E00643F55A800E27100FE0400F33100C5C40000821000364300051E
00061F003C46008607C8BC00F52A00FE0700DF7C0045A200005F4400112B000219001730
00673B64AC00E56600FF0100F13C00ACBF00007B1E002C3D00041C000822004D4E109000
D1A500F91A00FB1200D598001F960000534C000A2400031B00263A0076259DBB00EF4300
FF0000E761006AAE0000693A00183000021900122B0061424FA600E17300FF0400F23500
B8C100007D19002E3E00041C000822004F4E149200D39F00FA1500FA1700D1A3000F9000
004B4D00072100041C003241008113C5C400F42E00FE0700DE7F003CA000005A48000D28
00021A00203600722D91B800EE4800FF0000E7610067AD0000663C00152E00021900152F
00673C68AD00E76000FF0000ED4A008BB70000702F001D3500021A000F29005E454AA400
E17300FF0300F13A00A8BE0000782300253A00031A000C26005849379E00DD8000FE0600
F43000BCC200007D1A002B3D00031B000A2400554B2C9A00DB8800FD0900F52C00C5C400
007F16002D3E00031B00092400544C2A9A00DA8900FD0900F52B00C5C400007F17002C3E
00031B000A2400554B2F9B00DC8500FE0700F43000BAC200007B1D00283B00031B000C26
0059493CA000DF7A00FE0400F13900A6BD0000762700213700021A000F29005F4452A700
E46A00FF0100ED480088B600006E3300193200021900142E00683B73B000EA5400FF0000
E75E0062AB0000634000112B000219001E3500732A9FBC00F13B00FE0400DF7C00379E00
00574A000A2400031B002F3F00820FC9BA00F82100FB1100D39F000B8E0000414900051E
000620004C4D199400D79200FD0B00F52B00BFC300007B1D00263A00031A000E28005F44
56A800E66400FF0000EB520072B00000663C00132C000219001E35007429A6BD00F23600
FE0600DB870026980000504D00072100051D003F47098D00D39F00FC1000F72400C6C000
007E1800283B00031A000E28005F445AA900E76000FF0000E95A0063AB00006142000F29
00031A00263A007C1BC5C200F72500FC1000D2A000068C00003C4600041D00082200544C
359D00DF7900FF0200EE450085B500006A3800152E000219001E35007528AFBF00F42F00
FD0A00D7950012910000434900051E00072100524D2E9B00DE7D00FF0300EF440085B500
006A3800142D000219002036007824B9C200F52A00FC0E00D39E00068C00003A4500041C
000A2400584A45A300E46B00FF0000EA560064AC00006043000E2800031B002D3E00830D
CDB000FA1700F81F00C8BD00007D1900253A00021A00112B00673C7EB300EE4600FF0300
DE7F00289900004F4E000620000620004F4E299900DE7E00FF0300EE47007BB20000663D
00102A00031A00293C008112CBB400FA1800F81E00C7BE00007C1B00233800021900142D
006B378FB700F13B00FE0700D88F0013910000404800041D
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{550, 550},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008V00029R000`400?l00000o`00003ooooooooo
ooooobSooooo003ooooooooooooo:?ooool002Cooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol0000iooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000>Oooool2o`0000Co
oooo00?o0000ooooooooool00oooool3o`0003Wooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol0000iooooo`;o00001?ooool01?l0003oooooooooooooool5o`0003Sooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol0000looooo`;o0000?oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000Gooooo000Sooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000gooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00000gooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0=oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool00000=oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0003Oooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`0jooooo`04o`000?ooooooooooo`0003gooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`04ooooo`007?ooool5o`0000;ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo0000033ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool0;_ooool5o`0000;ooooo00Co0000oooooooooooo00001oooool5o`00037o
oooo1Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0;_ooool5o`00
00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0`ooooo`Go00000_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooooooo0000
?Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo000Sooooo`04o`00
0?ooooooooooo`0000Oooooo1?l0000hooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0=Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0003Wooooo00Co
0000oooooooooooo00002Oooool2o`0003Sooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`0fooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0>_ooool01?l0
003oooooooooool0000mooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?oo
ool002?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0iooooo`04o`000?oo
ooooooooo`0000Oooooo1?l0000hooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000>Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo03Gooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000003Oooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0003gooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`04ooooo`008oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0i
ooooo`04o`000?ooooooooooo`0000Wooooo0_l0000iooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000gooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000gooooo`04o`000?ooooooooooo`0000Sooooo0_l0000looooo`04o`000?oo
ooooooooo`0003gooooo00Co0000oooooooooooo00002?ooool2o`0000Kooooo000Tooooo`;o0000
2_ooool2o`0003Wooooo0_l00008ooooo`Go0000>?ooool2o`0000_ooooo00?o0000ooooooooool0
>?ooool2o`0000Wooooo0ol0000iooooo`;o00002Oooool3o`0003Wooooo0_l0000:ooooo`03o`00
0?oooooooooo03_ooooo0_l0000oooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`00oooo
ooooooooobSooooo003ooooooooooooo:?ooool00?oooooooooooolXooooo`00ooooooooooooobSo
oooo003ooooooooooooo:?ooool00?oooooooooooolXooooo`00ooooooooooooobSooooo000Noooo
oooo0000ool00009o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`00
7_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`007_ooool0
0ol0003oooooooooo`3ooooooooooooo1Oooool1o`00007ooooo000Nooooo`03o`000?oooooooooo
0?ooooooooooool5ooooo`7o00000Oooool001kooooo00?o0000ooooooooool0ooooooooooooo`Go
oooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Sooooo
00?o0000ooooooooool0ooooooooooooo`Gooooo0Ol00001ooooo`001oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`3ooooooooo
oooo1Oooool1o`00007ooooo0005o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?ooooooooooool5ooooo`7o00000Oooool000Oooooo
00Co0000oooooooooooo00002Oooool2o`0000Sooooo1?l0003ooooooooooooo0Oooool4o`00007o
oooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`07ooooo`0U0>A[001/[P0006hc000R=`000a/000PR0013B@00QPL0aL@00?8h003o0@00
jET008Rf0000MRL002Xm000470001Ql003U40020502__`00kd<00?l0003/CP00V[X0001j7`00<400
00DM00057P00=48007dJ0:Fm003^B000o`000>e:002O_00007/M000a@00200057P3o000d@P00OAX0
Ykd00>i6003o0000k4d009Vj0000NB4002ho00047@001Ql003Q400214`2e`@00l3h00?l0003YE`00
QkD0001d:@009c/000<L00078@00@dT008L40<Nn003d<@00o`<00>EX001[[P0006`f000N=@000aX0
00/U001AC@0CT@00d:P00?PP003m2`00gH4004FS0000HD8001@]00026@004B/005e603RN003JRP00
o0l00?TK003BX@006Y@0001CC0002bH0008J000M=000K3H0KJh00>EU003o0P00lSH00<330000PPl0
03U400057`001Ah003=2001o5P2d`@00lC`00?l1003WH000M;00001]=0007SD000<J000;9P00E4`0
7YD00=BM003j5`00na<00=JE000WV@0005M:000=9`003bL006/f06j_003VHP00o`400?4l002a`000
07dI000a@00011d000HP0010B000R0<0bKT00?HY003n1`00gg/004RS0000H4<0018/00026@005Bh0
06@o05FX003RL@00oP@00?<a0035a000088@000f@`001Ah000HO000lAP00QPL0b;`00?DZ003n1`00
gg`004FR0000Gd@0014[00026@005c0006Lk06B/003UIP00o`400?4l002/_`0007/N000/?@0011`0
00PR001=CP0@T000dJD00?TJ003k4P00eIP001nF0000Dd`000XT00036`009SX007HU09fk003_@`00
o`000>MQ001Z[P0006Tj000H<0000QT0018[001Q@P1?YP00hG<00?l4003b=@00^<40001m6@00;Sh0
00@L00088P00Cdh059800=>O003j5@00nQL00=6S000?T00004]=00078@0011`0039100214`35a000
m2h00?h7003NO`00?:00001JB0003BP0008J000P=P00LRd0TKP00>i8003o0000if4006N]0000IS`0
01D^00026@005Bl006Ll06R]003WH000o`000>e:002;]`00070_000M=@000QX000lY001NA@1:Y000
hG<00?l3003a>P00Z;h0001h8`009CX000<J000<9P00F4T0=ih00=f0003n1P00m3000;c20000OAX0
02/m00036`002R@005E;02bJ003KR000o@T00?D/0035a00007lF000]?P000a/000TT001DC00ZVP00
fXT00?d9003e:`00aL@0001o5`00;3h000<K000:9000ED/0;i/00=b5003n1`00m300002_0;[20000
Nad002Pk00036`0032H005U903bP003ONP00oP@00?4i002V_@0007HW000Q=`000QX000lY001OA01B
Y`00i6X00?l1003]B000R;H0001^<`006C80008I000D;P00J3/0Lk000>YD003o0000ieh006:[0000
Hd00014[00026@007SD007<Z09nl003a>`00oP@00=ml000gWP0005M:000:90000a/002lo00223`39
^P00n2400?/A003CW`002hh00011B@001Ah000HP001<C@0IU000ei800?d;003e:`00_l<0001k7@00
9SX000<J000>:000Gd@0EZP00>IT003o0000je8007:`0000IS`001</00026@007SD007@Y0:Jm003b
=P00oPH00=^7000CM2L000LQ00057@00?dL02Hd00=>O003l4000mb@00<K00000OQP002Pk00036P00
3RP005m405ZY003WH000o`000>UJ001SZ`000652000?:@000aX002Hj001l6`35`P00mbD00?`@003B
X0001X`0000lAP0011d000PR001DC00eW@00ggT00?l2003^A@00QKD0001Z>0005Bh0008I000N=@00
MBP0[kl00?@_003m2P00eiD001:A0000@dT000DN00078@00DTd0;Y/00=im003o0`00kd@008Fe0000
JSP001@]00026@0083H007PT0;W2003e:P00o0h00=>N0006S00003Y5000470002R@005Q:04FS003T
J`00o`000>YF001T[0000613000>:0000a/002dn00233@3=/000nQL00?PO0038_@0007dI000U>P00
0QX0014[001W?01n/`00kTH00?l3003NO`00:9T0001?CP020006800K001?CP0YV@00gWh00?l3003^
A`00Nk80001V?@0042X000<J000Y?000PA80bk@00?XH003h7P00akh0001l6`008cP0008I000D;@00
JcL0SkL00?4k003n1`00f8l001>A0000@4P000@M00[ooooo0Ol00001ooooo`001oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`07
ooooo`0?0>MP001m/`0007<[000W>`0011`000HP000kAP00PA40/l000>m1003o0000k4h009Zj0000
NQl00350008000DN04D00350001k7P2M^`00k4d00?l0003^A000[;l0001o5P00=d<000HO00047@00
;Ch007PS09>h003[DP00o`000>m1002b`000080D000hA0001Ql000@M000]?P00N280UKT00>]@003o
0000kd<00:^n0000OQP003E200057P001Ad00350001l702S_000kTP00?l0003/C@00VKX0001i8@00
;Ch000@M00067`00>dD0088?0;g3003a>P00o`400>QM001l/P00074_000S>0000a/000TS001<C@07
S000bk<00?HW003n1`00h7H005FW0000ICh001L`00026@003RP005Q902VI003FU@000P3k5000;@3F
UP00:9T0001HBP003RP0008I000I<@00Ic/0G:X00>9`003n1@00m2h00<Rm0000Q`D0045800078000
11`002dn001j7`2R_000kTD00?l0003ZE@00QKD0001b;@008cP000<K00098`00D4h04I000=2W003h
7@00o0d00=Z:000fWP0005]7000?:@003BD006Ll05jZ003SK@00o`<00?<c0034a000088?000hA002
00057P3o000hA000P`h0aL<00?<a003n1000hW0005RX0000ICh001D_00026@004R/005m404JS003N
O000oPL00?DY0039^P0008L5000nA`001Ql000DM000e@P00PA80`/@00?<c003n1000hW4005BW0000
Hd0001@]00026@0052d006=005BW003RL@00o`@00?<c002n``00080D000b@@0011d000LP0014BP03
R`00cK000?PP003l3@00fHd002fK0000EdX000`V00036P0083L0078]08^f003/C@00o`000>YF001k
/P0006dd000L<`000QT000lY001LAP0oX@00gWh00?h7003e;@00a/4000224000=48000@M00078000
AT/028d00<nZ003i6`00na800=FH000LU@00055=00098`000a/002/m001l702c`000lSH00?l4003Q
M000Bj@0001OA00042X0008I000K<`00KC<0Ok<00>]B003o0000jUH007Na0000JcL001Ta00026@00
4R`0069105RX003TJP00o`400?10002M^`0007DX000R>0000aX000dW001JB00kW`00gWh00?h6003c
<@00^l80001m6P00:cd000<K000:9000E4`0:IT00=Z;003m2P00mRP00<No0000PQ40035000047000
2280055=01nF003GT`00o0d00?LT0039^P0008@<000d@P0011`000PR001?CP0LU@00ei@00?`>003g
9000bKX000233@00<d4000@L00088P00DDd08IH00=R@003m2`00mRL00<K00000P1<002ho00036`00
2R@005A<02fK003LQ@00oPL00?@`002h`P0007/N000W>`000aX000`W001JB013XP00hGD00?l3003`
?`00V[X0001b;0007SD0008I000A:`00Hd00HZ/00>MN003o0000jU@007>`0000J3/001@^00026@00
6S8006lb08jg003_A000o`800>9a0016X`0005]7000<9P000aX002Tl001m6@35a000mRP00?d<003G
U0005i<0001:C@001R0000DN0013B@0=S`00e9d00?`@003g8`00akd000205000;3h000<K000<9P00
FTP0AZ<00>9_003o0@00kDP008>d0000JcL001H_00026@006S8006la09Bi003`?`00o`<00=mk000J
NBH000TS00047000=d<008P20<nZ003j5P00n1d00<Zf0000P`l002ho00036`002bH005]704ZT003T
J`00o`00000P0>]@001c/00006Hm000B;0000QT0024g001h902f`@00mBd00?d;003FU@004Y400014
BP001Ah000LQ001@CP0WV000g8@00?h5003a?000U[T0001_<@006340008I000I<P00L2l0WK/00?8h
003n1P00fXT001nF0000C4d200067`1:001=CP0QUP00fhP00?h6003a>P00UkT0001_<P006300008I
000K<`00Lb`0Ykd00?<b003m2@00ei<001:A0000@TT000DN00088P00E4`0=Yh00>1f003o0@00k4`0
07Fa0000ICh0010Z00026P009c/007lG0<Vk003h7@00nQP00<bc0000PPl002/m00036P003bT006=1
06f^003[D000o`400>5d000gWP0005=<00088@001Ah004M;01^D003JR@00oPD00?0n002<]`0006Xg
000C;@000QT002<h001l7037_`00n1l00?XG003;/`00084A000Y?0000aX0010[001V?01n/`00kT@0
0?l4003LQ00089H00019C0001Ah:ooooo`7o00000Oooool000Sooooo0_l00009ooooo`?o00002?oo
ool00ol0003oooooooooo`07ooooo`0k0>YF002?]`0007PT000]?P0011d000DN000d@P00O1/0XK`0
0>e;003o0000kTD00:bo0000OaD003Q400067`0011`002/m001f9P2;]P00jEL00?l0003a>`00_/<0
00243000?dL000LP000470009c/007<[086d003XG000o`400?8h0034a00008D90010B0001b4000<L
000W>P00LbX0Pk@00>UJ003o0@00lCX00;g30000P`h003a60006800011`002/m001g9@2A^000je80
0?l0003_@`00Zkh0001n6000=4800P001Ah0o`00<d8007dI0:^n003_@`00o`000>]C002=]`0007DW
000X>`0011`000LQ0013B@00Q`@0akh00?@_003o1000i6/006F/0000JSP001`c00026P0032H005A<
01bE003BX000nAX00?`?003JR`00=Yh0001LAP0042X0008I000E;P00Hd40C:D00=mk003n2000mRH0
0<bb0006S00004Y<00088P000a/002Lj001e:02@^000k4l00?l0003]B`00UkT0001g9@00:C`000<L
00088P00B4`01H`00<bb003g9@00o@T00=io0015XP000613000B;0002b<0069104jU003PN000oPH0
0?D[0038^`0008L40010B0001R0000@M000a@000OQP0]<400?4j003o0P00iFD006R]0000JCT001Tb
00026@003bT005]703NN003KQ`00o@`00?LR003=/0001H`00017B`001b4000@L000^?`00O1/0[kl0
0?4k003o0P00iFH006F/0000J3/001P`00026@004B/005i504BR003NO000oPL00?D[0037_P0008D:
000jA@001Ah000DO000lAP00QPL0bKX00?HX003m2@00gH8003^O0000FdL000hY00026@0073<006dd
07Zb003YE`00o`000>a<002<]`00078]000P=`000aX000`W001HBP0aW000fXT00?d;003g9@00b[L0
00271@00?4H000DN00057`00?DL008P30<^d003g8`00o0`00=V=000ZVP0005E;000;9@000aX002Dj
001g9@2Q_000l3l00?l1003TJ@00FjT0001S@0004bd0008I000G<000JCX0KZl00>QL003o0000k4`0
08Vf0000L30001dd00026P003bT005i504RS003QM@00o`@00?8g002__`0007XO000X>`000a/000/U
001EB`0]V`00fXT00?d:003f:@00a/0000214@00<T4000@L00088P00D4h06i@00=JF003l3`00n240
0<^e0000QPH003Q400057@001b0004Y<01:A003CWP00na<00?TM003=[`0008T1000lAP001Ah000HP
0018B`0?T000dil00?/C003i7000cK0000280P00>dD000DM00078000BTd059800=BK003l4000n200
0<^f0000Q@T003E300047@002280051>022F003HT000o@/00?HX0036`@0007lE000]?P000a/000XT
001FB`0dW@00gH000?h5003b=P00[;l0001g9000]P008cP0008J000>:@00Gd@0DZL00>AY003o0@00
kDX008Be0000K3D001Pa00026@005Rl006Xh07bc003/CP00o`000>EV001FZ00005m4000?:@000QX0
02<h001h8P2c`000m3400?h8003JR@009IP0001AC@00224000@M000jA@01RP00d:P00?XF003i7000
c;<000252@00<d4000@L000:9000ET/0=ih00=mj003o0`00l3l009Fi0000L30001Xb00026@005Rl0
06/g08:d003]B000o`400>9a000RORD000/U00036`00<40008@=0<^d003i7000nQL00<j/0000Q`@0
03E3000470002R@005I:03^O003QM@00o`800>i60024]@0006/g000E;P000QT001`d001c;02T_@00
lSD00?h7003JRP007iH0001=CP001R0000HO0019C00IU000f8l00?d8003c<`00Z;h0001d:P0073@0
008I000F;`00K3H0RkH00>m1003o0`00gWh002fK0000DDd000LQ00057P00A4X04i400=NC003m2@00
lc400:Vn0000Lb/001`c00026@005c0006hc09Fi003a>`00oPH00=^8000OUP0004]=00067`001b00
04m>02RI003MP@00o`@00>m20026]@0006Xh000C;@000QT0028g001j8034a000mb@00?/B003@Z000
08L5000b@@000a/000`V001NA@1MZP00jEX00?l0003TJ@00AZ<0001GBP002B<000@M000nA`0>S`00
eiD00?d9003c=@00W[/0001_<@005c00008I000N=@00Mb@0_<<00?HV003k4P00cjT000261`00;cl0
00<K000>:000HT40KJh00>a>003o0@00h7T002jK0000D4h000HP2_ooool1o`00007ooooo000Noooo
o`03o`000?oooooooooo00Oooooo0?l0kD`00:6l0000O1/003A200057P0011d002dn001h902?]`00
jUD00?l0003a>`00_/<000242`00@4P000LQ00036`009CT0074^07Zb003WH@00o`800?<b0037_P00
08T10017B`00228000<K000Q=`00Kc80L:l00>EV003o0`00m2l00<Rk0001RP0004U<00098P000a/0
024g001_<P1b/000iVD00?l3003c<@00akh000280`00ADX000PQ00036`009CT0078]07nc003XG000
o`400?4j002m``0008<?000kAP001Ql000@M000]?P00NB80VKX00>a<003o0000kDT009nk0000NQl0
02ho00047@001Ql003]500233`2o``00lSP00?l1003WH000M[40001_<P0083H000<J000:9000D4h0
3i000<n[003h8@00o@X00=f00015X`000653000C;@000QT0018[001NA@0mX000g8H00?d<003h7P00
d:P001:A0000D4h000XT00036P008CL0070_07jc003YF@00o`000>m1002Y_P0007`L000_?`0011d0
00HP0010B000Q`D0b;`00?D]003n1@00hG@005BW0000I3l001D_000:8P00GTD0?j400=b3003m2P00
mb<00<f`0006S00004Q<00088@0011`002/m001i8@2R_000kd<00?l0003XF`00NK80001^<`007SD0
008J000<9`00ETX0:IT00=NB003l4000nA/00=6U000BT@0004m>00098`000a/002Pk001g902M^`00
kTD00?l0003XG000MK40001/=@0073<0008J000>:000FTP0=Id00=^7003m2`00mb<00<^c0000RP00
04990006800011d003A200214@34a000m3000?h5003PM`00Bj@0001P@`004B/0008I000H<000J3X0
JJd00>IR003o0@00kd<009jk0000MbD002Hj00036`002R@005=<02>G003GU000o1000?PM003>[@00
1H`00014BP001R0000DM000f@`00P`d0akl00?DZ003m2000gH8003RN0000FTP000dW00026P0083H0
078]092h003]B@00o`000>MN001[[P0006Pj000G<0000QT001<]001T?`1NZP00iFL00?l1003_@`00
V[X0001e:@008SP000<J000=9`00FDT0>Il00=f0003n1`00m2l00<;40000OaH002ho000470002B<0
055=01nF003GU000o0h00?LR003;]@0000`008H6000iA0001Ad000LP0018C00>S`00dZ400?/E003i
6P00cjX000B;0000@4P200067`0B0011B005S000cjT00?XH003j5P00dJD000Z>0000A4X000HO0005
7P00?dL00h/00<nZ003i6@00nQH00=6U0009S@0004=90P001Ql0d@00@TT01hd00=6V003j5P00nAT0
0<n[0001RP0003e600057P001R0004U<01>A003DV`00o1000?PQ003:]`0008@;000d@P0011`000PR
001BC@0VV000fX/00?d9003e;@00_/<0001l7000:3/000<J000<9P00FTP0@j800>5d003o0P00l400
09Ji0000LBh001`d00026@004b`006Dm06^^003YF000o`000>QK001V[00006@o000A:`000QT001he
001d:P2Q_000lCT00?h5003NOP00<id0001EB`002B<000@L000c@@00Q@T0c;<00?TL003j5P00d:P0
006:0000>TD000@M00088P00DTd0:IT00=b5003n1P00lSH00:Jm0000M2T001he00026@004R`006Hm
076`003[DP00o`000>EV000ZPR<000dW00036P00:C`007lF0<No003g8`00na400=:Q0007S00003e6
00047@002280059=02fK003MP000oP@00?4m002F^@0006la000I<@000QT001Pa001^<`2B^000l3h0
0?h4003MO`00;I/0001BC@00224000DM0010B00=S`00eIX00?`=003e:P00^/80001h8P008CL0008I
000B;000Ic`0N[800>e;003o0@00hG@003^O0000ET/000TS00047@00>dH01hd00=>N003l3P00mBT0
0;_20000N2<0020f00026@004bd006Ti08Be003_A000o`<00=im000/VP00055=00078@001Ah004M;
01ZD003IS000oPL00?4i002H^P0006hb000G<0000QT001dd001e:02b`000mB`00?`=003DW@001X`0
000iA00011`000XT001JB01=Y@00iV@00?l0003WG`00EJL0001LA`002bD000@L000f@`02R`00dil0
0?`=003e;000/<00001d:P006c<0008I000J<P00LR`0Z[h00?@^003l3000dih000>;0000=T<000<L
000;9P00GDD0G:X00>UH003o0000hfh003fP0000E4`000PQ00[ooooo0Ol00001ooooo`007_ooool0
0ol0003oooooooooo`07ooooo`160>m2002c`000084A000kAP001b0000@L000W>`00Lb`0O[<00>MO
003o0P00lc<00<Nn0000R@0004Q<00098`000a/0020f001]=01Y[@00hf`00?h5003e:P00bk@000V=
0000Cdh000XT00036P007C@006Xh062[003RL@00oPH00?HW003=/00038l0001@CP002R@000<J000M
=000JSP0HZ/00>9_003n1@00mBT00<^d0007S@0004i>00098`000aX0020f001]<`1_[`00iFH00?l3
003c<@00akh000271000@dT000LQ00036`009cX007@Z08Ne003ZE`00o`000?10002a`00007lF000e
@P8000DN02T003=1001n602]_`00kd400?l0003ZEP00QkD0001c:`009CX000<K00088P00B4`00h/0
0<^e003f:@00oPH00>5e001DY`0006Dn000G<0000QT000lY001JB00_V`00f9000?/A003j6000e9d0
01nF0000E4`000`V00026P007C@006`f06j^003VI000o`800?8h002k`P00080C000f@`0200057P3o
000hA000PQ00`L@00?8e003o0`00i6T006B/0000JCX001Tb00088@00FDT0<9`00=V>003l3`00nA`0
0=6V000BT@00051>00098`000a/002Di001d:@2@^000k4d00?l0003[D@00R[H0001c;0008cP000<J
000:9000DTd06i@00=BM003j5P00na@00=FJ000NUP0005=<000;9@000aX0028h001c;02<]`00k4l0
0?l0003[DP00Q[D0001a;P0083H000<J000<9P00ET/09iT00=NB003l4000nA`00<nY000<SP0004Y=
00088@0011`002hn001m6`2b`000lST00?l2003SK000FZT0001T?`0052h0008I000D;@00I3l0FJT0
0>=/003o0P00lCT00;300000Nad002`m00037000228004m>01JB003CW`00nQD00?XG003BXP004I40
001=CP00228000@L000_?`00OQL0_L<00?<b003n1@00h7L004NS0000GTD0010Z00026@006c<006dc
07jc003[D`00o`000>YD001l/P0006dd000J<P000QT0010Z001P@`1>Y@00hW400?l3003a>@00[;l0
001i8@00:3/000<K000:9@00ED/0:iX00=Z;003m2`00mRL00<Rl0000Q0`003E200047@001b4004]=
01:A003CW`00na@00?TK003?Z`0018/00011B0001Ql000DO0010B003R`00cZ`00?TK003k5000dil0
012@0000BD`000LP00057@00>DD008L50<^c003h7`00o1000=FJ000FTP0004e>00078@0011d003M4
00261`3;]@00n2000?`@003EVP005I80001<C@001b0000DM000jA@00R0<0cK000?TL003k4`00dZ00
00f?0000ADX000HO00057P00@4P01X`00=2V003j5P00nAX00<j/0000R@0003]500057@001b4004e>
01RC003FU@00o0d00?HU0037_P00084B000^?`000a/000XT001FB`0dW@00gWl00?h5003b=`00Z;h0
001f9`008CL0008J000@:P00HD80FjT00>IS003o0000je4007Na0000J3X001D^00026@006S8006la
092h003_@`00o`800>5d0011X@0005U9000;9@000a/002`n00204`38_@00mb<00?`@003CW@0038l0
0012B@001Ah000LP001<CP0KU000f9000?d:003d;@00^<80001i8@008cP0008J000?:P00HT80HJ/0
00200>QM003o0000j5/003:78@0042X0008J000T>@00NR00_L<00?D[003m3000eYH001>A0000ADX0
00DN00068000CTh07iH00=Z;003n2000lc@00:Rn0000M2X001dd00026@0052h006Ti082d003^B000
o`800>5d000kW`0005I;00098`0011`003Q4006:003AY@00na800?LS0036`00007dI000W>P000aX0
00lY001S@@1Y[@00jUD00?l0003TJ@00BZ@0001JB0002bD000<L000d@P00R0<0d:P00?/C003g8P00
a/00001m6P009SX0008J000@:P00ICh0Lk000>a>003o0@00hG<003^O0000ED/000PR00047@00?dL0
3Xl00=JG003m2P00m3000:Zn0000Lb/001/c00026@006C40070_0:2l003c=@00o@T00=NB000BT@00
045800057@00228005E;03jP003RK`00o`000>YD001U[0000613000=:0000a/002lo0026203?ZP00
na<00?LT0032a00007TR000P=P000QT001H_001^<`2H^P00lSL00?d8003GT`003i00000nA`0011d0
00XT001IB@1=Y@00iV<00?l0003VH`00C:D0001IB@002B<:ooooo`7o00000Oooool001kooooo00?o
0000ooooooooool01oooool0o`3b>@00a<@000261`00A4X000PR00036`008SL006hc06f^003TJP00
oP@00?DZ003;/`002Xh0001@CP002RD0008J000K<`00J3X0FJT00>1f003n2000mb800<nY000FTP00
05=<000<9P000QX001Pa001U?P1@YP00gg`00?d:003h8000dJH001VC0000E4`000`W00026@006340
06Hm05:V003ONP00o@T00?LR003?ZP005940001BC@002bD0008J000K<`00JCX0GZX00>9a003n1P00
mRT00<^d0006S00004a=00098`000a/0024g001_<@1f/@00if400?l2003b=`00`l@000243000?DH0
00HP00047000;Ch007TQ09^j003]B`00o`000>a<002H^P0007PS000[?@0011`000LP0010B000QPL0
a/000?@a003o0`00i6/006B/0000JST001/c00026P0032L005E;026G003DV`00nQL00?/B003GTP00
;9X0001IB@003RP0008I000H<@00Ic`0GJX00>=^003n1000m3000<K00000Q@T003e700067`0011d0
0350001m6@2__`00l3h00?l1003WG`00MK00001]=0007SD000LP001EB`0RU`00eIP00?/D003j5P00
e9/001nF0000E4`000/U00036P0083H0070`07nc003YE`00o`000>i7002K^`0007LT000X>`000a/0
00PR001>CP0?T000d:P00?TL003l3`00f8l002bJ0000EdX000dW00026P007CD006hc07^b003YF@00
o`000>i8002H^P0007HW000V>P000a/000XT001AC@0JU000e9d00?XE003j5P00dih001RC0000DDd0
00TS00036`009c/007PS0:6l003_@P00o`400>IQ001Z[P0006Ti000H<@000QT0014[001OA019Y000
h7L00?h5003d<@00`/@000204`00<T4000@M00078@00Ad/02Hd00<nY003i6`00na400=JG000NU@00
059=00098`000a/002Tl001j802[_P00lC/00?l2003SK@00EZP0001R@@004R`0008I000G<000JCX0
KZh00>QM003o0000kDX008fg0000LBh001lf00026P003RP005]703nQ003NO000oPH00?@a002n``00
07hH000^?P0011`000TS001AC@0MU@00eYH00?`?003h7`00c;8000280P00?4H000DN00067`00@dT0
1X`00<nY003i6P00na@00=:P0000=00@T00004U<000780001Ad003Q40026203:]P00mb800?`>003G
U@007ID0001@CP00228000@L000b@@00PPl0akd00?HV003m3000f8l002>G0000DTd000TS00047000
<400084A0<No003f9`00o@/00=R?000RU`00055=00088P0011`0039100233P39^`00mb@00?`>003F
UP006Y@0001>CP001b4000@M000iA000Q`@0c;000?TL003k5000dZ8000^>0000@dT200067`2m0014
BP0<S`00dZ000?/C003h7P00bk@000262000=D8000@L00088P00DTd09YP00=Z:003m2000m2l00;[2
0000NQh002Hj00036P003BL005a604bU003SK@00o`400>i70028]P0006dd000H<@000QT001H_001Z
>01n/`00k4`00?l0003TJ@00DJH0001NA@003BP000<J000W>P00Nad0`<<00?D[003m2`00ei<001VC
0000Bdd000HP00057P00A4X03i000=BK003l3`00mRD00<K10000OQP002Tl00036P003BL005e6056V
003UI`00o`000>]A000jRah0018/00026@007cD007DX0:^n003c<`00oPP00=Z;000PUP0004i>0007
80001Ah004E:01:A003FUP00o@`00?D[002j`P0007TR000R>0000QX0014[001U?P1`[`00je800?l0
003TJP00BZ@0001JB0002bD000<K000a@000Q@T0cJl00?XH003i7000b[H000224000;Ch000<K000=
9`00GTD0FJT00>MO003o0000ieh005ZY0000GTD000dW00036`00;Ch008<>0<bc003i6@00nA/00<^e
0000PQ0002/m00036P003RP0061306:[003YF000o`000>EX001:Y00005U9000:900011`003M400::
003BX@00o0l00?HX002l`P0007PS000O=P000QT001D^001/=P2>]`00l3d00?h5003KQ`007iH0001:
C0001Ql000LQ001AC@0_V`00ggX00?l2003]BP00M[40001U?P0042X000<J000Y?000PA80bkD00?XI
003h7@00b;`0001m6@009CT0008J000B;000JCT0QkD00?10003n1@00fhP001bE0000AT/000DN0008
8P00ED/0?Z000>=]003o0000jET005^Y0000GDH000/U00[ooooo0Ol00001ooooo`007_ooool00ol0
003oooooooooo`07ooooo`3o0?@`0039^P000h/0001<C@002R@000<J000M=000JCT0GJX00>5e003n
2000mb<00<nY000FT`0005A<000=9`000QT001L`001T?`19Y000gH400?d<003i6`00dih002>G0000
F4X000hY00026@005Bh00652046Q003KQ`00o0h00?TI003DV`009YP0001HB@003bT0008I000E;P00
HD80@j800=b5003l3@00nA/00=>O000PUP0005I:000=:0000QT001L`001T?`1?Y@00gg`00?d9003g
8@00cjX001:A0000DDd000/U00036P007C@006/g06J/003TJ`00oP@00?@^0038^`0008T10015BP00
224000<K000W>P00M2T0RKH00>YE003o0000kd800:Zn0000OAX0039100057@001Al003Q400214@2k
`P00lCT00?l1003WH000MK40001^<P007cH000<J000:9000DDd059800=2V003h7@00o0d00=^7000j
W`0005e6000A:`000QT001D^001S@01>Y@00ggT00?h7003f:000b[H0006:0000ATX000LQ00047000
:Sd007PR09fk003^A`00o`000>YD0025]@00078]000R>0001b00055=01FB003AX`00nAX00?`@003H
T000;9X0001HB@003BP0008J000K<`00JcL0KZl00>IQ003o0@00l3h00:fo0000O1`002ho00047000
1b4004E:00>;003</P00mb<00?d:003LQ000>Yl0001LA`003bT0008I000I<P00JCT0JZh00>IS003o
0@00l3h00:Vn0000NQh002/m00047000228004a=00f?003@Y`00nA/00?`@003GT`009IP0001EB`00
2bD000<J000R>000Lb/0SkL00>e;003o0000jEL007^b0000KC<001`d00026P003RP005]703ZO003M
PP00o@P00?HY0038_00008D9000iA@001Ah000HO000oA`00R@40bk@00?LR003m3000fH`002bJ0000
ET/000/V00036P008cP007DX09Vj003^A000o`000>IR001V[00006Ll000F;`000QT001@]001T?`1M
ZP00iFP00?l1003_@@00Wk/0001f9P0093T000<J000;9P00EdX0<9`00=^7003m2@00mRT00<Nn0000
P`h003A200047@001b4004]=012@003BX@00nQD00?XI003@Y`002Hd00015BP001R0000DN000kA@00
Q`@0bk@00?PP003l3`00eYH0003c01bE0000D4h000PR00047000<D00084B0<K0003e:@00o@X00=Z:
000ZVP0005A<000:90000a/002`m001m6@2o``00m2h00?h7003LQ000<I`0001FB`002RD000<K000Z
?000OA/0_L<00?@_003n1`00g8@0032L0000ED/000XT00036`00;3d007hG0<C4003e:`00o@T00=Z;
000WV@00059=00098`0011`0035100233P38^`00mb<00?`>003FU`005i<0001<C@001b0000DN000l
AP00RP00cj/00?XH003j5`00cjT000::0000?DH000DN00078000CDh06I<00=NE003l3@00mRL00<K0
0000OaD002`n00036`002bD005Q903fP003PN000o`<00?0n002I^P00078]000M=0000QT001</001V
?@1^[`00jUH00?l0003WGP00H:/0001R@@0042X0008J000Q=`00MbD0[[l00?<c003n1`00fhP002JH
0000DDd000PQ00047@00>dH00h/00=6V003k5000n1h00<Zg0000P`h002lo00036`002bD005U904:R
003RLP00o`400>i70012T1`001H_00026@006S80070_09Vj003a?000oP@00=f0000]V`00059=0008
8P0011d003a600J<003BX@00o1400?LT0036`00007dI000X>`000aX000hY001P@`1OZP00j5`00?l0
003WG`00FZT0001OA0003BP000<J000[?@00P1<0bKX00?PN003j5@00cZ/000271@00<d4000<K000;
9@00FTP0BJ@00>AZ003o0000jU@006Z]0000Hd0000lY00036P009c/007hH0<Nm003h8000naD00<n[
0000QPH0039100036`002bH005a705>W003VHP00o`000>QM001IZ@0005i5000<9`000a/003100026
203>[000naD00?PQ0037_`0007`K000U>@000QX0018[001W?01m/`00kTL00?l2003NO@00;9X0001@
CP001b0000HO001;C@0RU`00g8D00?h4003_@@00QkD0001Y>@004bd0008J000T>@00O1/0akl00?PO
003j5`00c;8000223`00:Sd000<J000@:P00I3l0M[400>e9003o0P00gWd002VI0000Cdh000HO0007
8000D4d0;i/00>1h003o0@00k4l006b^0000HD8000dX00[ooooo0Ol00001ooooo`007_ooool00ol0
003oooooooooo`07ooooo`3o0?HX003=/0003i00001BC@002bH0008J000I<@00ICh0CJD00=eo003m
3000nA`00=>N000SU`0005Q9000?:@000QT001@]001OA00kW`00fH`00?/A003j5@00ei@0032L0000
G4L0014[00026@004R/005a603>M003HTP00na@00?/C003HT000=9d0001MAP004R/0008I000B:`00
GDH0=9d00=R@003k4P00naD00=ND000^V`0005]8000@:P000QT001@]001P@`10X@00fhH00?`>003i
6`00dil001nF0000ET/000dW00026@00634006Hm05JX003PMP00oPL00?HV003</@002Hd0001>CP00
2B<000<K000Q=`00L300N;400>MO003o0@00lCT00;c20000PQ4003U400067`001Ad00350001m6`2Y
_P00kd800?l0003ZEP00Q[D0001c:`0093T000<K00098P00C4d028d00<b`003g9000o@T00=im0019
Y0000652000D;@000QT0018[001NA@0oX@00g8@00?d;003h8000cZ/000f?0000CTh000TS00036`00
9CT007@Z08^g003[D@00o`000>e:002G^@0007LU000X>`001Ql004]=00V=003>[P00mb400?d;003L
Q@00>il0001LAP0042X0008I000G<000Ic`0GZX00>=/003o0`00lcD00;o30000PA8003E200057@00
1Ql003e600261`38_000mB/00?h6003ONP00BJ@0001P@`004R`0008I000E;`00ICh0FZT00>=]003o
0`00lSD00;_20000OaD0039100047@001b0004=900::003</P00mb800?d;003KR@00<id0001IB@00
3BP0008J000M=000KS80O[<00>YE003o0000k4d008bg0000LRd0024g00036P0032H005M:02bJ003I
S@00o0d00?LQ003</P000HX00011B0001Ql000DN000gA000Q0`0akh00?DZ003n2000gH4003ZO0000
FTP000hX00026P007SD0070_08Rf003/CP00o`000>UH001g/@0006/f000J<P000QT0014[001P@`1>
Y@00hW800?l3003b>000/<00001k7P00:S`000<K000:9000Dd`08iL00=NB003l3P00mb400<^d0000
R0<003a600057P001Ql0049900F;003?Z`00nA/00?/C003DW@005I80001>CP00224000@L000c@P00
P`l0akh00?HX003m2P00fX/0000n02ZJ0000E4`000XT00036`00:Sd007`K0;[2003c<@00oPH00=io
000hWP0005Q9000<9P000aX002Hj001i8P2]_`00lSL00?h4003ON@00?j40001JB0003BL000<J000T
>@00N2<0Zkh00?8h003n1000ggX003jP0000FTP000`V00036P009SX007XP0;;0003c<`00oPH00=f0
000eW@0005M:000;9@000a/002/m001n6034a000mB/00?d:003IS00099P0001AC@00228000@L000d
@P00Q@T0bkD00?PO003k4P00dil000j?0000ADX200067`2c0014BP0<S`00dil00?/B003h7`00b[H0
00242`00<T4000@L00098`00E4`0;Y/00=b3003n1P00lSD00:^n0000MRH0024g00026P0042X00652
05jZ003WH000o`000>YD001a[`0006Hl000C;@000QT001dd001b;@2L^`00lC`00?h4003NO@00=9d0
001EB`002B<000@L000d@P00QPL0cK000?TJ003j6000cZd000271000=T<000@L00098`00ED`0<id0
0=il003o1000l3h004^E60006S80008I000F;`00K3H0R;H00>i5003o0P00h7H003^O0000EdX000XT
00047000=D8008L40<j[003j5P00nAd00<Zf0000PPl002hn00036`0032H005a6052V003UIP00o`00
0>YE001Z[@0006=0000@:P000QX002Di001l7035a000mRD00?`@003BX@001H`0000jA@0011d000TS
001EB`0jW`00hG@00?l1003]BP00N[80001W?0004R`0008I000R>000NB00`<<00?HW003l3`00dZ40
00B;0000>D@000@L000:9000F4X0@j800>=]003o0000jU<006V]0000HT4000lY00036P00:S`0084B
0<Zf003i6`00nAX00<^e0000PA4002Xm00036P003bT006=106b^003[D000o`400>9b000jW`0005A<
00088P001Ad004=901FB003HS`00oPL00?8h002H^P0006hc000F;`000QT001le001g902m``00mRL0
0?/A003@Y`0008L5000a@0000a/000dW001P@`1V[000jU<00?l0003QLP00=ih0001CC0001b4000DN
001:C00RU`00g8<00?l3003^A@00O;80001V?@0042X02_ooool1o`00007ooooo000Nooooo`03o`00
0?oooooooooo00Oooooo0:D0n2400=6V000KU00005I;000>:0000QT001D^001Q@`0nX000fXX00?/A
003j5P00ei@0036L0000G4H0018/00026@004B/005]702fK003FU`00nQL00?`@003JR@00?j00001P
@`0052h0008I000?:@00F4T09IP00=BL003i6P00o0h00=b60012XP000652000E;P000QT000lY001H
B@0VV000eIX00?XH003l3`00fXT003bP0000Gd@001<]00026@004B/005]7036L003HT@00na<00?/E
003GU@00;I/0001JB0003bX0008I000E;P00HT40Aj<00=f1003m2`00n1l00=2W000ETP00059=000;
9@000QX001dd001[=`1X[@00i6T00?l3003d<@00akl000261P00@DP000LP00047000:cd007PS09Rj
003/C000o`000>a<002G^@0007PT000Z?00011`000LQ0013B@00R080b;/00?D/003n1@00hW8005VX
0000ISd001L`00026@003bT005Y8032L003IS`00o1000?TJ003BX@006I@0001CC@002bD000<J000P
=P00Kc40Nk800>QK003o0000kd400:Rn0000Nad002ho00067P00@TT008T10<Zh003f:@00oPL00=mk
0019Y0000652000C;0000QT001@]001R@@1?Y@00h7H00?h6003e;000akh000262000?4H000HO0005
7P00=D<0084A0<74003c<`00o`<00>9_001HZ00006Dn000E;P000QT0018/001P@`1;Y000h7P00?h6
003d;@00a/0000243000>D@00P001Ah0o`00>dH008H80<Rl003e:P00oPL00=in0011X@0005e5000@
:P000QT001Ta001Z>01][P00if000?l0003_A000WK/0001g9@009SX000<K000:9000DTd07iH00=JG
003k4P00nAX00=2W000<S`0004Y<00078@0011`00310001o5P2n``00lc800?h5003PM`00BJ@0001O
A00042X0008I000J<P00K3H0Mk400>UH003o0000k4h008Re0000L30001he00026P003RP005]703nQ
003NO@00oPH00?@_0032a00007lE000`@00011`000PR001?CP0FTP00e9`00?/C003i6P00cjT000N<
0000A4X000HO00057P00>TD008L60<^e003g8P00o0h00=NB000RU`00059=00098`000a/002dn001n
602o``00m3000?h7003MP000>9h0001HB@0032H000<J000U>@00N2@0Z;h00?4j003o0`00hG@004NS
0000GDH000hX00026P008CL007@Z09bk003`@000o`800>=_001>Y@0005m4000?:@000QX001lf001c
:`2I^P00l4000?l2003RK`00CJD0001NA@003RT0008J000Q=`00MBP0XK`00?4l003o0`00hGD004>R
0000FdL000dW00036P009CX007TQ0;;0003c<`00oPH00=f2000bW00005I;000:90000a/002ho0020
4`37_`00mRH00?`=003GU0006Y@0001>CP001b4000DM000lAP01RP00cjX00?XG003j6@00cZ`00029
0@00>TD000@M00088@00D4h08IH00=V=003m2P00mBd00;g30000Nad002Hj00036P003BL005e604jU
003TJ`00o`400>e:0021]00006/g000F;`000QT001Pa001]<`2;]P00kTD00?l2003QLP00@Z80001I
B@002bD000<K000]?P00PA40bKX00?PQ003k4P00dZ8000J<0000?TL000DM00078@00D4d09YP00=^7
003n1`00lSD005BI5@007SD0008I000C;@00Ic/0Mk400>a>003o0000i6/004ZT0000FdL000`V0003
6`00;Sl008<>0<Zf003i7000nQH00<j/0000Q`D003A2000470002R@005Q:046Q003RL@00o`400>e;
001j/P0006Pk000C;@000QT0020f001g9@2d`@00m2d00?d;003FUP004I000012B@001Ah000LQ001A
C@0/VP00gWl00?l3003_@@00RkH0001/=P00C0005Bl0008I000M=000MBP0[[l00?@_003m2`00eYH0
012@0000@DP000DM00088P00Dd`0=Id00>1g003o0P00kDX007Zb0000Ic`0014[00026P0093T007`K
0<K0003g8P00na@00<n[0000QPL0035000036`0032L005i505bZ003XFP00o`000>EW0019Y00005U9
000:900011`003]500V=003EVP00o@/00?@_002Z_P00078/000J<P000QT001Xb001c;02[_P00m2h0
0?d<003DW@001H`0000hA00011`000/U001LA`1FZ000j5d00?l0003UJ000AZ<0001GBP002B<000@M
0011B@0ETP00fHh00?h6003a?000SKL0001Z>0004bd:ooooo`7o00000Oooool001kooooo00?o0000
ooooooooool01oooool0o`3i6P00e9/002RI0000FTP0010Z00026@004R`005a6032L003FU@00nQH0
0?`@003JR@00?j40001Q@P005Bh0008I000>:000EdX07iH00=:Q003h7@00o@/00=in001=Y@0006Dn
000H<@000QT000`W001DC00HT`00d:L00?PP003m2@00gg/0056V0000ICd001Pa00026@0032L005A<
01VD003AY@00n1l00?d;003NO`00Bj@0001S@0005Rl0008I000>:000EdX099L00=BL003j6@00o0l0
0=Z:000kW`0005i5000B;0000QT0018[001MA@0hWP00fX/00?`@003j6@00e9`002:G0000ET/000dW
00026@006C4006Ll05RX003QM000oPH00?HY003;]@0018/00019C000228000<K000U>@00Lb/0QkD0
0>YF003o0000kd<00:Rn0000O1/0031000047@001Ql003]500233@34a000lc@00?l2003UI`00J:d0
001Z=`006c<0008J000<9`00ET/08iL00=FI003j5@00na@00=JF000VV00005M:000=9`000QX001/c
001[=`1Z[P00iFD00?l2003b>000^/8000205000=D8000HO000jA@00Q0`0a/800?@a003n1000hW00
05VY0000ICh001H_00026@004B/005i5042Q003MP@00o@T00?LU003;]0000XX00014BP001b0000@L
000_?`00O1/0[kl00?4l003o0@00iV@006R]0000JCT001Ta00026@003bT005a603bP003LP`00o@T0
0?HU003:]P0008T10011B0001R0000@M000d@P00PA80`/@00?<b003n1000hG<0052V0000HT4001</
00026@005Bl006Dn05fZ003TJP00o`800?4j002__`0007/M000/?@0011`000PR001>CP0BT@00dZ80
0?XG003k5000e9d001RC0000D4h000TS00036`00:S`007XO0:fo003a>`00o`800>=/001HZ00006=0
000C;@000QT001H_001W?01V[000iV800?l0003^A000VKX0001e:@008cP000<J000<9P00EdX0<I`0
0=^8003m2P00mRL00<Rl0000Q0/003M300057@001b0004I;00Z>003@Y`00nAT00?/D003CW`004i40
001=CP001b4000@L000c@@00PQ00akl00?DY003m2@00fhL002nK0000ET/000/U00036`009c/007TQ
0:fo003b>000o`@00>5e0000K`16X`0005e6000>:0000QX0020f001c:`2G^@00kd<00?l1003TJP00
EZP0001Q@P004B/0008I000L=000Kc40RkH00>e9003o0000iV@005jZ0000Hd00018/00026@006c<0
06lb08Rf003]BP00o`000>IT001LZP000691000A:`000QT001`d001`;`2?^000kTD00?l1003TJ`00
DZL0001OA0003bT0008J000P=P00MBT0X;`00?4l003o0`00h7L0042Q0000FTP000`V00036P00:3/0
07/M0;c2003d;P00o@P00=Z9000WV@00059=00088P0011`003A200252@3;]000n1h00?/C003BXP00
2Hh00011B@001Ah000HP0019C00DTP00eIP00?`>003g9@00akl000205000;3h000<K000;9@00FDT0
?j400>5e003o0P00kd4009:h0000L30001Xb00026@005Bh006Ti07Zb003/CP00o`000>EX001AYP00
05i5000=:0000aX002Pk001m6`35a000mRP00?`=003FV0004Y400016B`0200067`0]001:C00IT`00
ei800?d:003e;@00G9hA000S>0000QX0010Z001S@01W[@00jEP00?l0003WH@00FJT0001OA0003RP0
00<J000X>`00OQP0a/000?LS003k4@00dZ8000F<0000>dH000@M00088P00E4`0<Y`00=mk003o0`00
kd8008^f0000K3D001H_00026@006c<0078/0:>l003b=@00oPL00=Z<000MU@0004]=008000HO05<0
04a=01nF003JRP00oPH00?8h002L^`00070_000I<P000QT001Ta001`<02L^`00lSP00?h7003JR`00
79D00019C0001Ql000LP001?CP0WV@00gH800?h4003`@000R[H0001[=`005Bh0008I000O=P00Mb@0
^/800?HY003l3`00dZ4000>;0000=d@000@L000:9@00FTP0CJD00>EU003o0000j5d005RX0000GDH0
00`V00036`00=48008P20=6U003l4000mRL00;_20000Mb@001he00026@005Rl006hb09Zj003b=`00
oPP00=NB000AT00003m800047@002B<005M:04NS003UI`00o`000>QN001EY`0005]7000;9@0011`0
03Y500V=003EV000o@X00?<c002N^`0006la000F;`0:ooooo`7o00000Oooool001kooooo00?o0000
ooooooooool01oooool0G03k5000f90003JN0000GTD001<]00026@003bT005Q902>G003CW`00nA`0
0?d;003NOP00CZD0001U?P006C40008J000<9P00DTd04i400<j/003g9000oPL00>5d001MZP0006Ti
000L<`000aX000XU001@CP0<SP00c;400?HX003n1P00hW00066[0000JSP001dd00036P002R@0051>
00f?003=[`00mRH00?h7003QM000FZT0001X>`006S80008J000<9P00Dd`05i<00=2V003h7`00o@/0
0=io0019Y00006=1000F;`000QT000lY001IB@0ZVP00eYH00?XE003k4`00f98002nK0000FdP0010Z
00026@005Bh0069104VT003NOP00o@X00?LQ003>Z`003i00001@CP002R@000<J000P=P00Kc80M[40
0>MP003o0@00lCX00;[20000PA8003M40P001Ah0Q@00=48007lF0;?0003`?@00o`400>QM001i/P00
06la000P=P000aX000XT001BC@0FTP00dJ@00?TL003l3P00fX`003BM0000FdL000lY00026@005c00
06Hm05ZY003RL000oP@00?@`0036`00008D:000lAP001Qh003=1001o5@2g`@00lCT00?l2003UIP00
J:d0001Z>0006S80008I000>:000FDP0<I`00=V<003l3P00n1h00<nY000=S`0004e>00088P000a/0
02Tl001h8`2N^`00kTD00?l0003XFP00N;40001^<`007C@0008J000=9`00F4X0;Y/00=V=003l3P00
n1h00<j[0009S@0004U<00078@0011`002dn001l6`2``000lC/00?l2003TJ@00H:/0001V?@005Rl0
008I000B;000HD80CZD00>5d003n1000lc800<740000P1@0039100047@001b0004I:00J<003>[000
n1h00?`?003GTP009IP0001DC0002bD000<J000U>@00MRL0Vk/00>m4003o0000iV8006R]0000J3/0
01L`00026@004b`006=005NX003SK@00o`800?4k002Z_P0007TQ000X>`000a/000XT001CC00SU`00
ei800?`>003h8000c;8000290@00?TL00P001Al0o`00?TL008T10<ba003h8000o0l00=ND000OUP00
059=00098`000a/002`n001m6@2l`P00lc400?h6003NO@00?J00001JB0003BL000<J000R=`00M2T0
Vk/00>m1003o0@00i6/005FX0000HD80014[00026@006c<006hb08Je003/C000o`000>MO001V[000
06Dm000D;@000QT001Pa001[=`1j/P00je<00?l0003YFP00KZh0001W>`005Bh0008I000G<000JSP0
Mk400>YD003o0000j5X006b^0000Ic`001@^00026@00634006`f07nc003/C`00o`000>MP001RZ`00
06@o000B;0000QT001`c001`<02?^000kTD00?l1003SK000CjH0001NA@003RP0008J000R>000MbD0
Z[h00?8f003n1@00gWl003FM0000ET/000XT00036`00;Sl0084C0<Nn003g9@00o0h00=JG000FTP00
04Y<000680001Ah0041800R=003BX`00na<00?PN003;]@0008@;000c@@0011`000TS001DC00aW000
gH000?h5003b>000Y;d0001d:@007cD0008I000B:`00I3l0JZd00>UH003o0000j5h0066[0000HT40
010Z00026P008SP007PS0;?0003d<000o@T00=V=000OUP0004i>000780001Ah0049900b?003DW000
o0l00?HU001SX0d002Pk00036P003RP005i405NX003VH`00o`000>YG001Y[@0006=0000@:P000QX0
02<h001i8@2k`P00mB/00?d<003FU`004I000013B@001Ah000LP001?CP0UV000fhH00?h6003a>@00
W;/0001a;`006S80008I000G<000KS<0TKP00?0n003n1000gH4002ZJ0000DDd000LQ00057P00@dT0
4Y400=ND003m2P00m3000:jo0000MBP001dd00026@005Bl006`f08^f003`@000o`@00=f0000YV@00
051>000780001Al004Q;01ZD003IS@00oPL00?8g002L^`00070`000H<@000QT001/c001c;02X_P00
m3400?d:003FUP003Xl0000oA`0011d000TS001FB`0nX000hVl00?l0003ZD`00J:d0001Q@P003RP0
00<J000]?P00Q0`0cJl00?XF003h8000a/00001l70008cP0008I000C;@00JSP0R;H00?10003n1@00
fhL001fE0000B4/000DN00078@00Dd`0>9h00>9b00003P3o0000jU@006F/0000H4<000dW00036`00
<T4008P20=:S003l3`00mB/00;300000Lb/001Xb2_ooool1o`00007ooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0?l0o0l00=^60015XP0006=1000G<0000QT000dW001DC00FTP00cjX00?LS003n
1`00hG@005jZ0000JST001dd00036P002R@004i>00N<003:]P00mB`00?h4003TJ@00KJh0001^<`00
83L000<K00098`00BD`008X00<Rk003d;`00o`<00>EV001a[`0006hb000Q=`000a/000TS0019C002
RP00bKT00?@^003o1000i6X006Z]0000K3D001le00036P002R@004m>00^>003</@00mRH00?h7003Q
M@00F:P0001W?0006C80008J000<9`00ED/07ID00=:Q003i6`00o0h00=^7000mX00005m4000B;000
0QT0018/001NA@0jW`00fXT00?`>003i6`00dZ4001bE0000E4`000`V00026P0073<006Xh06J/003T
JP00o`<00?<a0036`00008H8000oA`001R0000@L000]?P00NQl0XK`00>i6003o0000jU<008Vf0000
M2X002Di00036`002B<004e>00Z>003=[P00mb800?d:003MP@00@Z80001OA0004R`0008I000D;@00
HT40Bj@00=mj003n1`00mRP00<Zg0000R@0004A:00067`00;Ch007/N0:Jm003_@P00o`000>QK001i
/P0006hb000N=@000QX000`V001EB`0TV000eYH00?/C003j5`00dil001VD0000DTd000XT00036`00
8cP007<[08fg003/C`00o`000>]@0029]P00078]000R=`000aX000/U001DC00PUP00eIP00?/C003j
6000dZ4001FB0000D4h000TS00036`009c/007LT09nk003_A000o`000>MN001`[`0006/g000J<P00
0QT000lY001MAP0oX@00gWl00?h8003e:P00b;d000252P00>DD000DN00067`00?TL008P40<Zg003g
9@00o@/00=^7000cW@0005U9000=9`000QX0020f001a;P2:]P00k4d00?l0003YF000N;40001/=@00
6S80008I000@:P00GTD0B:<00>1g003n1@00lc<00;c20000OQP002ho00047000228004m>01JC003D
W@00na@00?TJ003@Y`002Xh00016B`001b0000DM000g@`00Q0/0b;/00?HW003m2P00fXX002fK0000
ET/000/U00036`009cX007TR0:Zn003a>P00o`<00>9b001<Y@0005m4000@:P000QT001dd001`<02:
]P00kDX00?l0003WH@000>00IJ`0001U?@0052d0008I000G<000JSP0MK400>YF003o0000jUD007Ja
0000JSP001L`00026@0052h006Hl06Z]003XG@00o`000>]@001n/`0006`f000I<@000QT001@]001V
?@1W[@00j5h00?l0003[D000O;<0001[=P006340008I000E;P00Ic/0KZl00>UI003o0000jUH007:`
0000J3X001D^00026@00630006/f07jc003/CP00o`000>IR001NZP000691000A:`000QT001he001b
;02I^P00l3l00?l2003QM000@j80001JB00032H000<J000X>`00O1`0_/<00?D]003m2@00fHd002:G
0000D4d000PR00047@00>D@008P20<j]003i6@00nQP00<n[0000R@0003Y500047@002240051=02>G
003JR`00o@P00?@`002e`@0007TR000T>@000QX000lY001P@`1JZ@00iV800?l0003ZE000LJl0001V
?@004b`0008I000M=@00Lb/0X[`00?8h003n1@00gH8002bJ0000DTd000PR00047@00>TD00HX00=2W
003k5000n1h006FM2000;Sl000<K000;9P00FTP0B:<00>=]003o0@00k4d007Vb0000J3/001<]0002
6@007SD007DY0:Zn003c<`00oPP00=V<000MU@0004a=000680001Ql004Q<01RC003HT@00o@T00?@`
002^_`0007DW000N=@000QT001@]001Y>@20]000kTL00?l2003PMP00>9h0001EB`002B<000@M000k
AP07S000dil00?`?003f:000_l<0001i80008SP0008I000B;000Ic`0N[800>e:003o0@00h7H003NN
0000E4`000PR00057@00?dP03Xl00=JG003m2`00m2l00:fo0000M2T001`d00026@005c0006hb09Ni
003a>@00oPH00=Z;000KU00004M;00057P001b40059=032L003ONP00o`800>e9001h/@0006Hm000A
:`000QX002Lk001o5P39^@00nA`00?TJ003:]P00080C000Y?0000aX0010Z001U?P1h/@00kDT00?l2
003NO@00:iX0001?CP8000HP014004m>02ZJ003NO000o`800>e:001e/00006@o000?:@000aX002`n
0024303>[@00na@00?LT0032a00007PS000O=@0:ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool0o`3m2P00gg/005BW0000Ic`001Xb00026P002bD0051>00Z>003;]000mB/00?h4
003TJ@00KJh0001^<`008CL000<K00088P00AT/008P30<K0003c=000o`800>MO001m/`00078]000V
>P000a/000LQ0011B000Q@T0a<@00?8h003o0@00j5`0086d0000Lb/002Hj000370001b4004580026
2035``00lSH00?l2003WG`00N[80001a;`008cP000<K00088P00Ad/008T00<Rk003d;P00o`@00>AZ
001X[@0006/f000M=@000aX000XU001AC@0AT000cj/00?LR003m2@00gWd004bU0000Hd0001H_0002
6@003bT005Y802fK003GT`00na<00?XE003FUP00:IT0001HB@003RP0008I000H<000ISd0EZP00>5d
003n1P00mBT00<Zg0002RP0004M;00088@000a/002Lk001e9`2@^000je000?l0003]BP00V[X0001h
8`00:cd000@L00078@00A4X008T00<Vh003e:P00oPH00>1f001AYP0006A0000E;P000QT0014[001M
A@0lX000g8D00?d;003h8@00cZ`000^>0000CDh000HO000W>`00MRH0UKT00>e;003o0000je4008Vf
0000Lb`002<h00036`002R@0055=01NC003BX@00nQT00?/B003GU0009YP0001FB`0032H0008J000N
=@00Kc80O;800>UH003o0000kTL009Zj0000MbD002Lk00036`002B<0051>01BB003BXP00nQT00?/B
003FU`008YL0001DC0002bD000<J000R>000Lb/0S[L00>a=003o0000jU@0082d0000Kc4001he0002
6P003BL005Q9036L003JRP00o@`00?LS003</`0008T00011B0001Ql000DM000f@`00P`h0a/000?D/
003n1`00gWd0046Q0000GDH000lY00026@006c<006de07Zb003YE`00o`000>a>0028]P00074_000O
=@000QX000dX001JB00iW`00gH800?h8003e:`00a/0000233P00=D8000@M00078000Ad/02Xh00=2W
003i6@00na@00=BM000FTP0004m>00088P0011`0031000205@33a000m2h00?h7003NO`00>Yl0001J
B0003BL000<J000Q=`00M2X0VKX00>m3003o0@00iFP005^Y0000Hd00018/00026@006C4006/f07Zb
003ZE000o`000>YG0000l`1e/@0006Xh000G<0000QT001@]001U?P1U[000if000?l0003/C000Q[D0
001^<P006c<0008I000A:`00HT40FZT00>EW003o0@00kTL008ng0000L2l001dd00026@004B/00652
05RX003UJ000o`400>i7002=]`00070`000L<`000QT0014[001S@01NZP00iV<00?l0003/C@00P[@0
001/=@006C40008I000D;P00Ic`0KZl00>UH003o0000jEP006j_0000Ic`001@]00026@006C8006hc
08Rf003]B000o`400>AZ001BYP0005m4000>:@000QX002<h001g902]_`00lcD00?h6003MPP00<9`0
001DC0002B<000@L000b@@00Q0`0b[L00?PP003k4P00dZ0000Z>0000@TT000DN00068000BT`05i<0
0=JE003l3000mRP00<G30000OAT002Tl00036P0032L005a704^T003SK@00o`400>e:0021]00006/g
000F;`000QT001Tb001_<P2A^000kd400?l3003PN000>Yl0001GBP002R@000@L000c@@00Q@T0c;40
0?TJ003j6000IiX3000e@P0011`000TT001FB`0iW`00h7L00?l2003_@`00R[H0001/=@005c00008I
000J<P00L300V;X00?4k003n1@00gH8002ZJ0000DDd000PQ00057P00@4P038h00=BK003l3P00mRT0
0;o30000NQl002<h00026P004B/006Dn072_003[D@00o`000>=/0017X`0005U9000:9@0011`003A2
00280`3?Z@00na@00?PP0037_@0007hH000W>`000aX000lY001S@01Z[P00jU<00?l0003TJ`00AJ<0
001HB@002R@000@L000hA002R`00dZ800?`@003f9`00_l<0001i8P008CL0008I000D;@00JSP0Q[D0
0>m2003o0`00gH4002RI0000Cdh000HP00067`00CDh08iL00=b4003n1000l40008Vf0000JSP001@]
00026@008SL007XO0<G3003g8`00na@00<j/0000Q@T002lo00036`003RP0065206R]003[DP00o`40
0>9b000hWP0005=<00088@001Ah004Q;01fE003KQ`00oPD00>m10025]@0006Pj000B;0000QX002Hj
001o5P3:]`00nAX00?TM0038_00007dJ000S>00:ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool0o`3n1`00hW4006>/0000JcH001le00036P002B<004U<00290037_P00lc<00?l2
003WG`00O[<0001c;0009SX000@L00078000?TL008<>0;_2003a?000o`000>YE002=]`0007LU000[
?@0011`000HO000iA000P1<0//000>m1003o0000je8009:h0000N2@002`n00047@001Ql003U50021
4P2e`@00l3h00?l0003ZE@00RkH0001e9`00:C`000@L00078000?dL008D:0<C4003b=P00o`800>MP
001h/@00070`000R>0000a/000TS001;C@05S000bkD00?DY003n1P00hW8005^Y0000J3/001Tb0002
6P003BL005E;01nF003CWP00nAT00?`?003IS000=Yh0001LAP004B/0008I000D;P00HD80Aj<00=io
003m2P00mb800<j]000=S`0004m>00098`000a/0028h001a;P1o/`00jET00?l0003`@000[;l0001m
6P00<D0000@M00067`00?4H008@;0<G2003c<P00o`<00>=/001PZ`0006Pk000I<@000QT000hX001I
B@0_V`00f8l00?`@003i6P00dZ8001NC0000DDd000LO000R=`00LBh0Q;D00>YE003o0000kTP009Zj
0000Mb@002Pk00036`00228004a=00^>003>Z`00n1l00?`=003JRP00=9d0001JB0003RP0008I000J
<P00JSP0K:h00>IR003o0@00l3h00:^n0000Nad002dn000470001b4004U<00R=003>[@00n1l00?`=
003IS000;i/0001HB@003BL0008J000N=@00KS80OK<00>YG003o0000kD/0096h0000M2X002<h0003
6P002bD005A<02BG003GU000o1000?TL003?Z@002hh00019C0001b4000@L000_?`00OQL0^/800?<e
003o1000hG80052V0000HD80018/00026@005c0006Pj06Z]003WH@00o`000>i5002I^P0007DX000T
>@000aX000/U001FB`0[VP00fH`00?d<003g8`00b[H000271000?4H000DN00067`00?dL008T00<ba
003h8000o0h00=NC000RU`0005=<000:90000a/002Xl001k7P2b`000lSL00?l4003QM@00BJ@0001N
A@003bT0008I000M=000L300R;H00>a<003o0000j5d006^^0000Ic/001H_00026@005Bh006Ll06Z]
003WGP00o`000>a=0000X`25]@0006hb000K<`000QT0014[001Q@P1FZ000i6X00?l1003_@P00UkX0
001c:`0083H0008J000?:@00GTD0Bj@00>9a003o0P00l3h00:2l0000MBP0024g00026P003RP005e6
04VT003RLP00o`800?0n002N^`0007@Y000P=P000QX000lY001NA01?YP00hfd00?l1003_@`00TkP0
001a;P007C@0008I000A:`00Hd40GZX00>IR003o0000k4h007jc0000JcH001L`00026@005Rl006Ti
07Ra003[DP00o`000>MO001QZ`0006=0000A:`000QT001he001c;02K^`00l3d00?l3003PM`00?Z00
001IB@002bD000<K000[?@00OaH0a/400?HW003l3@00eYH001JB0000BT`000HP00057P00@TT02hh0
0=>P003k4@00n2400<Vj0000PQ0002lo00036`002RD005Q:03bP003PM`00o`<00>m1002B^00006la
000J<P000QT001H_001Z>020/`00kDX00?l1003SK@00B:@0001KA`0032H000<K000/?P00PA<0b;/0
0?PQ003k4P00JiP0000lAP0011d000PR001BC@0/VP00gH800?h5003a>`00VkX0001a;P006c<0008I
000F;`00K3H0R;H00>i4003o0P00h7L003RN0000ED/000TS00047000>4@008X00=6V003k4`00mb40
0<Nn0000OaL002Pl00036P003RP00613062[003XF`00o`000>IR001EZ00005e5000<9`000a/002ho
00233P3;/`000P3i6P00CP3;]00008<>000]?P000a/000dW001NA@1KZ@00j5d00?l0003WH@00E:L0
001LAP0032H000<K000a@000QPL0cZ`00?XE003h8000akh0001m6@009SX0008J000A:`00ICh0M[40
0>e<003o0@00h7H003FM0000Dd`000PQ00057P00A4X05Y800=R?003n1`00lSL009Zj0000Kc8001L`
00026@007C@007HW0;K1003e:P00o0l00=:Q0001RP0003E300036`002bH005e605RX003XG000o`00
0>EX0017X`0005Q:00098`0011d003m8016@003HTP00oPP00?8h002F^@0006dd000E;P000QT0024g
001j7P36`@00n2000?XG003</P00084A000Y?0[ooooo0Ol00001ooooo`007_ooool00ol0003ooooo
ooooo`07ooooo`0K0?l4003UI`00Lk00001`<00093T000<K00078@00@4P008@;0;o3003a>`00o`00
0>YE002>]`0007LT000/?P0011d000HO000f@`00OQL0Z[h00>i5003o0000kD/009jk0000Nad00351
008000DN00T00391001l702Q_000kDX00?l0003]B000Xk`0001l6`00<T400P001Ah0?`00<T4007`K
0:Bm003^A`00o`000>a<002L^`0007XP000_?`0011d000HO000gA000P1@0/l000?0o003o0000jUH0
08Vf0000M2T002Lk000370001b40049900271@37_`00m3400?l3003UJ000Jjh0001/=@007SD000<J
000;9@00DDd04i400=2X003h8000o@/00=f10014XP000652000D;@000QT0014[001MAP0iW`00fXT0
0?`>003i6`00dZ8001VD0000Dd`000/U00036P007SD006`e06n_003VH`00o`800?8h002m``00084A
000gA00200057P1<000e@P00P1@0]l400?4j003o0@00iV80072_0000K3D001dd00026P0032H005E;
026G003EVP00nQD00?/D003EV00099L0001FB`001b0001dd001]=01d/000iel00?l1003`?`00Zkh0
001l7000;Sl000@L00078000@dT008X00<^e003f9P00o@T00=eo0012XP0005i5000A:`000QT001H_
001V?@1LZP00hfd00?l3003b=@00_L<000205000<d4000@M00068000@4P008P20<Zg003f9P00o@T0
0=f2000mX00005a6000?:@000QT001Tb001Z>01][P00if000?l1003_@P00X[`0001h8`00:3/000<K
00098`00D4h05i<00=>N0080nQH00?l0dih001NC0000D4h000TS00036`00:C`007XP0:Vn003`?@00
o`800>EX001OZP0006Dn000E;P000QT001@]001T?`1JZ@00i6/00?l2003a?000Z[h0001j8000:C`0
00<K00098`00DTd07YH00=JG003k4@00nAd00<j/0006S00004A:000680001Ad003M400252P38^`00
mRL00?d:003KR000<9`0001GBP002bH000<J000T>@00MRH0X;`00?0o003o0P00i6X005RX0000HT40
018/00026@006C4006/g07Ra003ZEP00o`000>YD001k/P0006`f000I<P000QT0018/001S@@1JZ@00
iFP00?l1003_A000U[T0001c:`0083H0008J000>:000GDH0Aj<00>5e003o0`00lCX00:Rn0000N2@0
02@i00036P0032L005Y803bP003OO000oPD00?8e002a`00007TP000V>P000aX000`V001IB@0jW`00
gW`00?h5003b=@00[kl0001i8@009CX000<J000<9`00FTP0@:400>1g003o0`00lCX00:Bm0000MRL0
024g00026P003RT005i504nV003SK000o`400>i5002?]`00070`000K<`000QT001</001U?P1X[@00
j5`00?l0003ZEP00LJl0001W>`0052h0008I000J<P00KS80RkH00>i6003o0@00hfd004bU0000GDH0
00dX00036P009SX007XO0;W2003d;P00o@T00=Z;000SU`00051>00088@0011d003Y50029003?ZP00
nQL00?TJ003=/00008L6000f@`0011`000TS001CC00^V`00gH400?h5003b>000Xk`0001d:P007SD0
008I000B;000ISd0L:l00>YD003o0000iV<005NX0000Gd@000hX00036P009cX007`L0<C4003f:000
o0d007>E0000A4X000DN00078000CTh07YH00=V<003m2000lc800:bo0000MBL001lf00026@004b`0
06Ll07Na003/CP00o`000>=]0016X`0005U8000;9@000a/0035000252@3=/000nQP00?TK003;]000
08<=000^?`000a/000`V001LAP1AYP00iFD00?l0003YF000IJ`0001R@P003bT000<J000X>`00OQL0
akd00?PP003k5000cjX000271000=48000<K000;9@00FTP0C:D00>EW003o0000jEL006B/0000HD80
00hX00036P00:cd0084A0<Zf003i6`0003`0nAX00<^d0000PQ0002/m00036P003RP0065206J/003Z
E@00o`000>=/0013XP0005M:00098`0011d003a600Z>003EV@00o@/00?@_002[_P0007<[000K<`00
0QT001Ta001a;P2T_@00lc800?d:003FU`0038h0000mAP0011d000TT001HB@19Y000iFH00?l0003X
GP00EJP0001LA`002bD000@L000hA005S000e9`00?d<003d<000Ykd0001a;P006C40008I000M=000
MRH0^L800?HW003k4@00d:P000261`00;cl:ooooo`7o00000Oooool001kooooo00?o0000oooooooo
ool01oooool0V`3o0@00j5d008>d0000M2T002Tl000470001Ql003U40020502^_`00kd@00?l0003/
C000Wk/0001l7000<T4000DN00057@00<40007XP09Vj003/C`00o`000>m2002__`00080D000hA000
1Ql000@M000/?@00Mb@0T;P00>YC003o0000l3l00;C10000PA8003U500067`0011d002`n001h8`2C
^000je400?l0003_@`00[Kl0001n5`00=D<000DN00057@00<D0007/M0::l003^B000o`000>a=002I
^P0007TQ000]?P0011d000HO000kA@00PPl0_L<00?4i003o0@00j5h007^b0000L2l0028h00036`00
2B<004a=00N=003</P00mRL00?h7003PM`00DjL0001U?P005c00008I000>:@00FDT0:iX00=ND003k
4`00nQD00=FH000VV00005M:000=9`000QT001Tb001X>P1OZP00hfd00?h4003d;`00akl000261`00
?dL000HP00047@00;Sl007/M0:Jm003_@`00o`000>UH0020]000074_000R=`000aX000XT001AC@0E
TP00dJ@00?TK003l3`00fHd0036L0000FTP000PQ000I<@00J3X0I:`00>AY003o0P00lSH00;g30000
P1<003E200057P001Ql003a600252@37_`00m2h00?h5003QM@00D:H0001S@@0052d0008I000C;@00
HD80CJD00>1g003n1P00m2d00<No0000Q0X003Y5008000DN03L003U400243036`000m2h00?h6003P
M`00BjD0001Q@`004R`0008I000F;`00ISd0GJX00>A[003o0P00lCT00;?00000OAX002ho00047000
224004Y<00^>003?Z@00nA`00?`@003GU0008iL0001DC0002bD000<J000T>@00MBP0V;X00>i6003o
0000ieh006n_0000JSP001Ta00026@004B/0061304^T003QM@00oP@00?<c002l`P0007hG000_?`00
11`000PR001=CP0BT@00dZ400080nQH00?l0dZ80016A0000C4d000PQ00047000<D00080D0<C4003d
;`00oPH00=in000mX00005]7000>:0000QX001lf001b;@2@^000kDP00?l0003WH000Ijd0001W?000
5Bh0008I000E;P00Ic`0J:d00>MP003o0000kDX008^f0000L2l001dd00026@003bT005i504^T003R
LP00o`<00?4k002W_@0007LT000U>@000aX000`V001IB@0hW`00gWl00?h6003c<@00^/80001l6`00
:S`000<K000:9000ED/0;i/00=^6003m2000mBd00<;40000OQP002`n00036`002R@005E;02fK003K
Q`00o@P00?@]0031a00007dI000[?@000a/000XU001FB`0cW@00gH800?h6003c<P00]L40001j7`00
9cX000<J000<9P00FTP0@J400>1g003o0`00lC`00:2l0000M2T0020f00026P0042X0065305RX003U
IP00o`000>a<0021]00006`f000H<0000QT001H_001Z>01j/P00je000?l0003VH`00FjT0001Q@P00
42X0008J000Q=`00MRL0Z;h00?8f003n1@00gH40032L0000E4`000TS00047000<d4008D:0<^d003h
7@00na@00=6U0004R`0003e600057@001b40051>026G003IS000o@T00?@`002d`@0007PR000S>000
0QX0010Z001R@P1PZ`00j5h00?l0003YF@00Ijd0001S@0004B/0008J000Q=`00Mb@0/l000?@`003m
2@00Ni80001<C@001R0000DO0015BP0BT@00eYL00?d<003e:P00_L<0001j7`0093T0008J000@:P00
Hd00Ijd00>UG003o0000iV<005FX0000GTD000dW00036`00:cd0084C0<Vj003h7`00nQD00<nZ0000
R0<003E2000470002R@005Q904:R003RK`00o`400>a>001e/00006Hm000A:`000QX002<h001j8030
``00mRL00?`?003CW`001X`0000kA@0011d000TS001FB`0mX000hW800?l1003/CP00Lk00001U?P00
4B/0008J000U>P00OAX0a/000?LQ003k5000cjX000271P00<T4000<K000<9P00GDH0EZP00>MO003o
0000iV8005:V0000FdL000/U00037000=D8008T00=6T003l4000mRP00;c20000N2@001lf00026@00
5Bl006dd09>i003a>P00oPH00=V=000HT`0001d004A:00057P00228005A<03^O003RL000o`000>YD
001U[0000613000=9`000a/003500027103@YP00o1000?HX002h`P0007HW000M=0000QT001Ta001a
;P2X_P00m2l00?d<003CWP000X/0000e@`0:ooooo`7o00000Oooool001kooooo0ol00007ooooo`0l
0?l0003[D`00U;T0001i8@00;cl000DM00057P00<T4007/M09fk003/C@00o`000>m3002``000080C
000iA@001Ql000@L000Z?000MBL0R;H00>UH003o0@00lCX00<740000Q0/0041800078@000a`002Hj
001c;020/`00j5d00?l1003b=`00aL@000252@00@DP000LQ000370009SX007<[08:d003XF`00o`40
0?4j002n``0008<>000lAP001R0000@L000[?@00MbD0TKP00>]A003o0000kd<00:Zn0000OQT003=2
0P001Ah0o`00=48007hH0:bo003_@P00o`000>YD002;]P0007DX000W>`000a`000LQ0014BP00R0<0
b;`00?@^003n1000hfd006:[0000JCT001/c00026P0032H005E;01jF003CWP00nQT00?`@003ISP00
<id0001KA`0042X0008I000F;`00I3l0D:H00>1h003n1`00mRP00<^e0002R`0004M;00088@000a`0
02Pk001g9@2E^@00k4`00?l0003/CP00TKP0001e9`009cX000<K00088P00Bdd02Hd00<f^003g8P00
o@X00=b3000oX@0005i5000:8P005Bl006@o05FW003QL`00oPD00?@^0037_`0008D9000lAP001Ql0
00DM000d@P00P1<0_L<00?8f003o0`00i6/0062[0000Ic`001L`00026@0042X005e603nQ003MP@00
o@T00?HV003;]@0008T00012B@001R0000@M000b@@00OaH0^/800?8f003o0`00hfd005ZY0000ICh0
01D^00026@004R`0065204jU003QM@00oPD00?@a0034a000084A000d@P001Ad000HP0012B@00RP00
c;<00?LS003m3000fXX0036L0000F4T000dW00026P007cH0074_08Ne003[C`00o`000>YD001o/`00
06hb000M=0000QX000hX001KA`0mX000gH000?h7003e:`00a/0000233P00=D<000@M00078000ADX0
1h`00<n[003i7000na400=JG000MU@00055=00098`000a/002/m001k7@2b`000lSL00?l3003QL`00
C:D0001OA00042X0008I000K<`00KC@0Ok<00>]B003o0000jUH007Na0000JcL001Ta00026@004R`0
069105RX003TJP00o`400>m1002L^`0007DX000R>0000aX000dW001JB00mX000gW`00?h5003c<P00
^<80001l7000:Sd000<K000:9000ED`0:iX00=Z9003m2P00mBX00<K10000PA<00310000470002B<0
055=026G003HT000o@`00?HU0038_00008<>000b@@0011`000PR001AC@0PUP00f9400?d<003f9P00
b;d000224000<D0000@L00098`00DTd09IP00=V<003m2P00mBX00<G30000OaL002`n00036`002R@0
05I;03>M003MP@00oPH00?<d002a`00007TR000U>@000aX000dX001LAP19Y000hW000?l2003_@`00
T[P0001`<0007P0073<0008I000C;000ICh0JZh00>UI003o0000jET006^^0000ICh001</00026@00
73@0074^09Nj003`?`00o`<00>1g000nX00005Q9000;9@000a/002dn00204`37_P00mb@00?`?003D
V`003i000015BP8000HO09D004Q<01FB003FUP00o0d00?HX0035a00007dJ000X>`000aX000dW001M
A@1AYP00iFP00?l0003[D000Mk40001X>`004bd0008I000M=000Lb/0XK`00?8h003n1P00Phl0001A
C@00224000DM000mAP07S000dZ400?/A003g8`00akl0001o5`00:C`000<J000=:000Gd@0F:P00>MQ
003o0000jET006F/0000HT4000lY00026P009SX007`L0<G3003f9P00o1000=>P0007S00003a60004
7@00228005A<03BM003ON@00o`800>i50025]@0006Xh000E;P000QT001he001e:02__`00m2l00?d:
003FU@004I400012B@001Ah000PQ001BC@0_V`00gg`00?l3003^A000Q;@0001Y>@0052d0008I000P
=P00N2<0_<800?HY003l3`00dj0000B;0000>D@000@L000:9000FDT0B:<00>AY003o0000jEP0066[
0000H4<000dW00036`00;Sl008D:0<j^003j5@00n2000<K00000O1/002@i00026P004R`006Pj08>d
003_@`00o`@00=f2000TV00004e>00067`001b00051>02fK003ON`00o`800>e:001e/00006@o000?
:@000aX002/m00233P3=/000nQH00?PQ0036`P0007XO000Q=`000QT001D^001]=02G^@00lSL00?d8
003GU0003Xl0000lAP08ooooo`?o00000Oooool001kooooo00?o0000ooooooooool01oooool0/03o
0000kDT00:Bm0000OAT003E300067`0011d002`m001g9@2<]`00jEL00?l0003a>P00`L@000252P00
@DP000LQ00036`0093T0074^07Ra003VHP00o`800?<a0038_@0008T00018B`00228000<K000Q=`00
KS80L:l00>EW003o0`00m2l00<Vj0001RP0004U<00098P000a/0024g001_<P1b/000iV@00?l3003c
<P00akl000280`00A4X000PQ00036`009CT0078/086d003XF`00o`400?4k002k`P00088@000jA@00
1Ql000@M000]?P00NB40VkX00>e;003o0000kDX009bk0000NB0002dn00047@001Ql003a600233@32
a000lSH00?l2003VH`00L[00001^<`007cH000<J000:9000DDd04Y400=2X003h7`00o@/00=b30011
X@0005m4000B;0000QT001</001OA012XP00gH800?d;003h8@00cZ/000j?0000Cdh000TS00036`00
8cP0078]08Fe003ZEP00o`000>i5002R_00007XP000/?P0011`000LP0013B@00R@40b[P00?HY003n
1`00h7T004fU0000HT4000/S000B;000H4<0AZ<00=im003m2000mRL00<^f0000RP0004A:00078000
11`002ho001l702/_`00l3h00?l1003WH@00Kjl0001[=P006c<0008J000>:000FDT0<I`00=Z<003l
3@00n1l00<j/000:SP0004Y<00088@0011`002`m001k7P2Y_P00l3l00?l1003VH`00JZd0001Y>@00
6C40008I000@:P00GDH0@:400=io003n2000mRT00<Rk0000QPL003a60P001Ah07@00>TD008D90<Rl
003e:P00oPP00=eo000nX00005a6000?:@000QT001/c001/=@1g/@00jET00?l0003]B`00SkL0001c
;0008CL000<J000<9P00EdX0;i/00=Z:003m2`00mb@00<Zf0000Q`@003e6008000DN0?l003e60028
0`3;]@00mb<00?d<003IS@00:YX0001EB`002bD000<J000U>P00MbD0XK`00?0o003o0@00i6T005^Y
0000Hd0001<]00026@005c0006Ti06n_003XF`00o`000>a=0027]@0006la000M=0000QT000lY001N
A@1:Y000hG@00?l3003b>000[Kl0001i8@009c/000<K000;9@00ET/0;i/00=^7003m2@00mB/00<K2
0000PA<00310000470002280055=01jE003GU000o0h00?LR003:]`0008D9000g@`0011d000LQ001=
CP0ETP00e9/00?/A003h7`00c;8000271000>DD000DM00078000Bdd04i400=BL003k4@00n1l00<^c
0000Q`H003Q400047@001b4004i>01VC003FUP00o0h00?LS0039^P0008<=000b@@0011`000TR001B
C@0VV000fX/00?d9003e;000`/@0001m6@00:S`000<K000;9@00F4T0>il00=mj003n1000lCX00::l
0000MBT0020f00026P0042X0065205^Y003VH`00o`000>]?001j/P0006Xh000F;`000QT001Pa001]
=027]@00kTP00?l1003SK000C:D0001MAP003BL000<J000W>`00O1`0_l<00?D[003m2`00f94001bD
0000CDh000LP00057P00@4P02Hd00=:P003k4@00n2400<Vj0000PA4002ho00036`002bD005U904:R
003RLP00o`400>i60027]@0006`e000G<0000QT001Ta001_<P2A^000l4000?l3002;S00005E;0009
8`0011`003I300280`3?Z`00nQH00?TL003;]@0008<=000_?`000a/000/V001JB019Y000i6/00?l0
003/C`00M;00001V?@004R`0008I000Q=`00Mb@0]L400?D]003m2`00eYD001:A0000A4X000DN0007
8@00D4h09iT00=b4003n1@00lC`009Fi0000Kc8001Pa00026@006S80074_09jk003b=`00oPL00=Z;
000MU@0004]=00067`001R0004i>02:G003KQP00oPD00?4l002D^@0006hc000G<0000QT001`c001d
:P2[_P00m3000?d:003FUP003i000010B0001Ad000PR001EC00iW`00hG<00?l1003/CP00LJl0001T
?`0042X000<J000Y?000P1@0b[P00?TK003i6P00b[H000214P00:C`000<J000@:P00I3l00280Lk00
0>a<003o0@00h7P0036L0000DTd000LQ00057`00BT`089H00=b5003n1000kd4008Fe0000JCX0018/
00026P009CX007hH0<Vj003i7000nAX00<Zh0000OaH002Hj00026P004R`006Tj08Je003`@000oPD0
0=Z9000JU00004A:2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo04L0o`00
0?10002e`@00088@000mAP001b0000@L000V>P00LR`0O;800>MQ003o0P00lc800<Rm0000R@0004U<
00098`000aX001lf001/=@1X[@00hf`00?h5003e:P00bk<000Z>0000Cdh000XT00036P007C@006Xh
062[003RL@00oPH00?HW003</@0038h0001@CP002R@000<J000M=000JSP0Hj/00>=^003n1@00mBX0
0<^e0006S00004e>00098`000aX0020f001^<`1a[`00iFD00?l2003c<P00a/0000271P00@TT000LQ
00047000:3/007DX08Zf003ZE@00o`000>m1002]_`0007hH000d@P0200057P3=000e@P00OaH0/L00
0?0o003o0000jET008:d0000LRd002@i00036`002B8004]=00N<003</P00mRH00?h8003ON@00CjH0
001T@0005Rl0008I000@:P00FdL0=9d00=V<003l3`00nAX00=:Q000JU00005=<000;9@000aX001he
001^<`1e/000iel00?l1003a?000/l00001n5`00<T4000DM00067`00>dH008@;0<K2003d<@00oP@0
0>=^001LZ@0006Hl000=9@003bX005a703RN003KR000o@`00?PP003>[0002hh0001<C@00228000<K
000X>`00Mb@0VkX00>i7003o0000jEL007nc0000L30001lf00036P002bH005E;02BG003FUP00na80
0?XH003BX@005Y80001@CP002B<000<K000V>P00MRH0V;X00>i7003o0000jET007Zb0000KS<001dd
00026P003BP005U903:L003JR@00o@`00?LR003</@000XX00013B@001b0000@M000c@@00P1<0`/@0
0?<a003n1@00hGD004fU0000H4<0018/00026@005c0006Pk06N]003VH`00o`400>m2002P_00007LU
000V>P000a/000XT001CC00RU`00ei@00?`@003h7@00cZ`000J<0000A4X000HP00057@00=T<008<=
0<No003e:P00o@P00=b3000hWP0005U8000=9`000QX0020f001b;02A^000kDP00?l0003WG`00JZd0
001X>`005Rl0008I000D;@00ICh0H:/00>EU003o0@00kd@009Rj0000M2X0024g00036P003BL005Y8
03^O003NOP00oPH00?@`002n``0007hH000]?P000a/000TS001BC@0RU`00f9400?`=003g8`00b[P0
00252@00=d<000@M00078@00Bdd04Y400=>N003k4`00nA`00<j]0000RP0003i700057P001Ql004A:
00V=003AY@00nQH00?XH003@Z0001H`00011B00200067`3J0012B@08S@00dJH00?XF003j6000cjT0
00B;0000?dL000DN00067`00ADX03Hl00=:Q003k4`00nA`00<f`0000R0<003U500057@001b4004i>
01VD003FUP00o0h00?LT0038_000088@000`@00011`000TS001DC00^V`00g8@00?h7003c<P00/l00
001i8@009CT000<J000=:000GDH0C:D00>=]003o0@00kTH008^f0000KS<001Tb00026@005Bh006Pj
07Na003[D@00o`000>IR001KZ@000652000?:P000QX0028g001g902^_`00lc<00?h7003KQ`00:9T0
001BC@00228000@M000iA000R@40cj/00?XG003i6`00c;4000261`00=48000@L00098`00ED/0=Id0
0=ml003o1000l3d009Nj0000L2l001/c00026@005Bl006Xh082d003]B@00o`4009B90000FDP000/U
00036`00;cl008<=0<^e003i7000nQH00<n[0000R0<003E3000470002B@005I;03^O003QM@00o`80
0>i60024]@0006/g000E;P000QT001`d001c:`2T_@00lSD00?h7003JR`007YH0001<C@001R0000HO
0019C00JU000fHh00?h8003c=000Y[d0001c:`0073<0008I000F;`00K3D0SKL00?10003o1000gH00
02ZJ0000DDd000LQ00057P00ADX05Y800=RA003m2@00lc<00:Fm0000LR`001/c00026@00634006la
09Zj003b>000oPL00=Z;000KU00004Q<00057`001b00055=02bJ003NO@00o`<00>i50021]00006Pj
000B;0000QX002<h001k7@36`@00mb800?/D003>[00008D9000_?`000a/000dW001P@`1S[000jUH0
0?l0003SKP00?j40001FB`00228000DM0012B@0DTP00f8l00?h7003b>@00UKT0001]=0005Bl0008I
000P=`00NR00aL@00?LR003k5000cJh000233@00;3d000<J000?:@00I3l0M[400>e9003o0P00gWl0
02JH0000CDh:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0HP3o0@00lSP0
0<G30000QPH004A:00088P000a/0024g001^<`1/[P00i6X00?h5003e:P00bk<000^>0000D4h000XU
00026P006c<006Pj05VY003PMP00oPP00?LR003?Z@005I80001CC00032H0008J000I<@00ISd0DJH0
0=mk003m2P00n2000=2W000HT`0005A<000<9P000QX001Ta001V?@1DY`00h7T00?d8003g8`00cj/0
01:A0000DDd000/U00026P0073<006Xh066[003SK`00oPD00?D[003:]P0018/0001:C@002B<000<K
000R>000L2l0N[800>MN003o0@00lCT00;k30000PPl003Y500067`0011d002ho001j7`2P_000kTP0
0?l0003/C`00T[P0001g9@00:C`000@L00078@00@dT008P30<Rl003d;P00oP@00>=_001NZP0006Pk
000I<P000QT000dX001GBP0WV@00eYL00P3k5000o`3FU`009YP0001GBP003BL0008J000J<P00JCT0
IJ`00>AY003o0`00lc@00<C40000P`h003U500057`001Ah003A20020502h`P00lCT00?l2003VI000
Jjh0001[=`003bL000dW001HBP0[VP00ei800?/A003i6@00dZ8001NC0000DDd000XT00036`008cP0
07<[08Zf003[D000o`000>a=002?]`0007@Z000T>@000a/000XT001AC@0HT`00dj000?XH003k4`00
eYL002:G0000E4`000/U00036P008CL0078]08Rf003[D@00o`000>]@002:]P00078]000Q=`000aX0
00/U001EB`0UV000ei@00?`A003i6`00d:L000f?0000C4d000PR00047000;Ch007`L0;70003a>P00
o`800>A[001KZ@0006Dn000E;P000QT001@]001T@01HZ000hfd00?l2003a>@00/<00001l7000;3d0
00<L00088P00Cdh05Y800=>N003j5@00nQL00=:R000AT00004e>00088P0011`002lo001o5`2n``00
lc800?h5003PN000AJ<0001NA@003bT0008I000L<`00KS<0P;@00>]B003o0000jUD007Zb0000K3D0
01Xb00026@004B/00613056V003RK`00o`800?4k002X_P0007PR000V>P000a/000/U001FB`0^V`00
fhP00?d:003f:@00akl000223`00<d4000@L00088@00CTh05Y800=BK003k4P00nAd00<f^0000RP00
03i700057P001Ql0049900N<003@Z000nQT00?XF003AX`0038h00016BP001R0000DN000lAP00R@00
cJl00?TL003k4`00dih0016@0000BD`000LP00057P00>dD008P20<f`003i7@00na<00=>O000?T000
04M;000680001Ah003i700::003?Z`00nAT00?XF003@YP001h`00011B0001Ah000HO0015BP0=S`00
dj000?/C003h7P00c;<000261`00=d<000@M00088P00D4h08IH00=V?003m2`00mBX00<C40000OQT0
02Xm00036`002bH005U903jP003PM`00o`<00?0m002K^P00078/000M=@000QT0018/001T?`1W[@00
j5/00?l0003YF@00JZh0001U?P004R`0008I000M=000Lb`0WK/00?4k003n1000gW`003FN0000ET/0
00XT00047000<T4008@;0<^d003i7@00naD00=2W0000S`02RP0003]500047@002280055=02NI003K
QP00oPH00?8e002X_P0007DX000O=@000QT0018/001V?@1a[`00je<00?l0002LQP0005i5000=9`00
0aX002Tl001o5P37_`00mb<00?/A003BX@001X`0000mAP0011d000PR001BC@0]V`00gH000?h4003`
?@00UKT0001_<@006C40008I000H<@00Kc80U;T00?0m003n1000gH4002^J0000DDd000LQ00057P00
@DP03i000=FH003m3000mB`00;O10000N2@0020f00026@004bd006Pj07fc003]B@00o`800>1f000h
WP0005E<00088P0011d003e700Z>003DV`00o0d00?D[002f`@0007LU000O=P000QT001D^001[=`29
]P00kd400?l4003MP@00:9T0001?CP001b0000HO001;C@0OUP00fhP00?h5003a?000TKP0001/=@00
5Bl0008I000O=@00MbD0^L800?HY003l3`00dZ80002:0000=T<000<L000;9@00G4L0E:L00>MO003o
0000iV@004fU0000FTP000XT00047000>TD028d00=FJ003m2`00m3400:Jm0000LBh001Ta00026@00
73@007DX0;G1003e:P00o0l00=6T0000R0<0039100036`003BL0061306N]003[DP00o`400>5e000c
W@00059=00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3m0?l2003d<000
bKX000>;0000CDh000XT00036P007C@006Ti05fZ003QM@00oPP00?LS003?Z@005Y80001DC00032L0
008I000G<000I3l0BZ@00=f1003m3000nA`00=>O000QU`0005M:000>:0000QT001D^001Q@P13XP00
g8D00?`>003i6P00e9d002BH0000F4X000hY00026@005Bl0069104FS003LP`00o0`00?TL003BX@00
7YD0001EB`003BL0008I000H<@00ICh0DZL00=mi003m2000mb<00<j]000?T000051=000:90000aX0
01he001/=@1[[P00iFP00?l3003d<@00akl000271@00@TT000LQ00047000:C`007HV092h003[D@00
o`000>i6002S_00007/N000_?`0011d000HO000kAP00P`d0`l@00?8e003o0P00iFD006f^0000K3D0
01dd00026P002bD005=<01ZD003BX@00nAX00?`?003IS@00<id0001KA`003bT0008I000G<000ICh0
EZP00>5c003n1@00mB`00<Rk0000Q`@004580007800011`002ho001k7@2X_P00kd800?l0003XF`00
Nk80001_<@004BP000/U001DC00NU@00e9`00?XF003k5000eYP002>G0000ED/000`V00036P007SD0
06hb07Zb003YFP00o`000>i4002P_00007PR000Y?0000a/000PR001<C@0<SP00cjX00?PN003l3P00
fHd002nK0000F4T000dW00026P007C@006dd07Ra003YFP00o`000>i6002J^P0007HV000V>P000a/0
00TS001AC@0IT`00dih00?XF003j5@00e9d001VD0000DDd000TS00036`009c/007PT0:2l003_@P00
o`400>MQ001[[P0006Ti000H<@000QT0014[001OA01:Y000h7L00?h5003d<@00`L@000205000<T40
00@M00078@00B4`02Xh00<nY003i6`00na800=FH000MU@00055=00098`000a/002Tl001j7`2]_`00
lCX00?l2003SKP00E:L0001R@@004R`0008I000H<@00JSP0LJl00>QK003o0000k4`008Zf0000L2l0
01he00026P003RT005a604:R003ON@00oPD00?<c002i`P0007dJ000/?@000a/000TS001BC@0QUP00
ei<00?`>003g8P00bkD000271@00>TD000DN00068000ATX02Xh00=6U00020?XG003c0=6T000;SP00
04I;000680001Ah003]500280`3</P00n1l00?`@003EV@005i<0001>CP001b4000@M000e@`00Q0/0
bKT00?LS003l3P00ei@001fE0000D4h000PR00047000=48008@<0<Vi003g8`00o0h00=JE000KU000
04m>00088@0011d003I30026203;]@00n1l00?/A003DW0004Y400019C0001R0000DN000mA`02RP00
cjX00?XH003j5`00cjT000>;0000?TL000DN00078000BT`059800=FI003l3`00mb<00<Rk0000PPl0
0310000370002R@005E;032L003MPP00oPH00?8e002/_`0007LU000R>0000QX000lY001P@`1HZ000
iVD00?l0003/C`00N[80001Y>@005Bl0008I000I<P00KS80SKL00>m4003o0P00hW8004>R0000FTP0
00/V00036`00;3d0080D0<Nn003g9000o1000=BM000=S`0004=900057P001R0004a=01^D003HT@00
o@X00?@]002i`P0007TQ000S>0000QX000lZ001R@P1QZ`00j5`00?l0002UQ0000691000?:P000QX0
02@i001j7`2n``00mBX00?d<003FU`004Y400014BP001Ah000LP001>CP0QUP00fXX00?h7003c=@00
YKd0001c:`007C@0008I000E;P00JSP0Pk@00>i6003o0P00h7L003RO0000ED/000TS00047000>TD0
0h/00=:R003k4@00mb@00<G20000O1`002Dj00026P0042X006@o06j^003[DP00o`000>=/0015X`00
05U9000:900011`003I30029003AY@00na400?LT0035``0007/M000T>@000QX0018[001W?01i/P00
kDX00?l2003PM`00=Id0001CC000228000DN0012B@0CT@00ei800?d9003c=000XK`0001a;`006C40
008I000J<P00Lb`0Z;h00?@`003m2`00eIP000^>0000?DH000@M00098`00F4X0AZ<00>AY003o0000
jEX005bZ0000GTD000`V00036`00<d8008T10=6T003l3`00mRT00;O10000MRL001dd00026@006340
074_0:Bm003c<@00o@/00=FJ0007S@0003U4000470002bD005a705NX003XG000o`000>A[0011X@00
05E;00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1B0?h5003f:000cK00
00n@0000DDd000/V00026P006C4006Dn04jU003NO`00o@/00?TL003CW`008YL0001HBP003bT0008I
000D;P00H4<0?:000=Z;003k4@00nQH00=JE000^V`0005]7000A:`000QT0018/001MAP0eW@00f900
0?/C003k5000ei80036L0000G4L0014[00026@004R`005i503RN003IS@00na400?XF003FU`00:YX0
001IB0003bT0008I000E;P00HD80A:800=b3003m3000nAd00=:S000KU00005A<000<9P000QX001Xb
001X>`1KZ@00hW800?h6003e:@00bkD000B;0000BTd000PR00036`008cP0078]082c003XFP00o`00
0?0m002d`00007lE000e@`8000DN0?l003A2001o5P2b`000l3h00?l0003XF`00OK<0001`;`008SL0
00<K00098`00Cdh03i000<n[003h8000o@/00=b30011X@0005m4000B;0000QT001<]001Q@P18X`00
gWd00?d9003g9@00c;8000F<0000BD`000PR00036`00:3/007LU09Ni003]BP00o`000>]A002;]P00
07<[000D:P002B<0051>01:A003@YP00nA`00?`?003IS@00<9`0001IB@003RP0008I000J<P00JSP0
Jjh00>IT003o0@00lC`00;300000OAX002lo000470001b0004A:006:003;]000mbD00?d:003LP`00
?:00001LAP003bX0008I000I<@00JCT0J:d00>IT003o0@00l3h00:^n0000Nah002`m000470002280
04a=00f?003@Z000nA`00?`@003GT`009IP0001EB`002bD000<J000R>000Lb/0SkP00>e;003o0000
jEL007Zb0000KC@001`d00026P003RT005]703bP003MP@00o@P00?DY0038_@0008D:000hA0001Ah0
00HO0010B000R@00c;800?LQ003l3@00fHh002ZI0000ED/000/U00036P0093T007HW09bk003_@`00
o`400>IT001SZ`0006Hm000E;P000QT001D^001U?P1QZ`00iFD00?l1003_@`00V[X0001e:0008cP0
00<J000<9P00F4T0=Id00=b4003m2000mB/00<K10000PA40039100047000224004i>01FB003DW@00
na<00?TK003>Z`0018/00011B0001Ql000DN000nA`00R@00cJl00?PM003k4@00eIX001NC0000CTh0
00PQ00047@00=48008<=0<Rl003f9P00o@`00=R?000SU`00059=00098`0011`002lo00205035`P00
mBX00?d:003JRP00:IT0001DC0002B<000<K000^?P00OaD0aL<00?DZ003m2P00fX/002NI0000Dd`0
00TS00047000<400084A0<Nn003f9P00o@`00=NB000NU@00051>00088@0011d003I300261`3;]000
n1h00?/B003CW`003Xl00016BP001Ql000DO0012B@09S@00dZ<00?/D003i7000c;4000271P00=d<0
00@M00088P00DDd08iL00=V<003m2@00m2d00;g30000Nad002Lk00036P003BL005a704VT003SK`00
o`400>i6002:]P0006hc000I<@000QT009l001H_001Z>01m/`00k4d00?l0003UJ000DZH0001NA@00
3RP000<J000V>P00Nad0_l<00?D[003m2`00ei<001VC0000Bdd000HP00057P00A4X03i000=BK003l
3P00mRH00<K20000OQP002Tl00036P003BL005e505:W003UIP00o`000:j10000ISd0018/00026@00
7cH007HW0:fo003c<P00o@P00=V=000NU@0004e>000680001Ql004I;01FB003GU000o@/00?D]002f
`@0007PS000Q=`000QT0018/001V?@1d/000k4l00?l0003SK000AZ<0001IB@002bD000<K000c@@00
Q`H0cZ`00?XF003h7P00bKT000204`00:cd000<J000>:000H4<0GZX00>QK003o0000iV8005BW0000
GDH000`V00036`00<40008D:0<f_003j5`00n1h00<Vj0000P1D002Tl00036P003bT0069106Z]003Z
D`00o`000>=]0013XP0005M:00098`0011`003]500R=003DW000o0d00?D/002b`00007DX000M=000
0QT001L`001^<P2H^P00lSP00?h7003ISP005i<00014BP001Ah000PR001DC00hWP00hG<00?l1003[
D000Jjh0001R@@003RP000<J000]?P00Q0/0cZh00?/E003g8P00aL<0001j7`008CL0008I000E;P00
K3D0TkT00?4i003n1`00f90001:A0000@4P000@M00098`00F4X0BJ@00>EU003o0000if4004nV0000
FDP02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l0o@P00?LQ003@YP00
6Y@0001EB`003BP0008I000E;`00HD80@:400=Z9003l4000nQH00=JE000_V`0005a7000A:`000QT0
014[001LA`0_V`00eYD00?XF003k4@00fX/003bP0000Gd@001@]00026@003bX005U902RI003EVP00
nQP00?`?003KR000?Z00001P@`0052d0008I000?:P00FTP0:YX00=JG003j5P00na400=V=000gWP00
05e5000B;0000QT0018[001MAP0fWP00fHd00?/A003j5`00eIT002NI0000F4T000hY00026@005Rl0
06=004fU003NO000o@T00?LR003>[0004900001@CP002R@000<J000O=@00KC@0L:l00>IT003o0P00
lSD00<C40000Q0`003a600067`0011d002ho001j7`2Q_000kTL00?l0003[DP00SKL0001e:0009cX0
00<K00088P00B4`018/00<^d003f9`00oPL00>1i001?YP0006=0000E;P000QT0010[001MAP0jW`00
fhL00?`=003h7P00d:P0016@0000D4h000TS00036`008cP0078/08Ne003ZE000o`000>i8002K^`00
07PS000F;000228004U<00N<003=/000mb<00?d:003LP`00?J00001MAP0042X0008I000G<000ISd0
G:T00>=]003o0`00lc@00<740000PA4003I300057P001Ql003a600252037_@00mB`00?h6003PN@00
BZ@0001P@`004R`0008I000E;`00ICh0FJT00>=^003o0`00lSD00;_20000OaD0039100047@001b00
04=900::003</P00mb800?d<003JR@00<Y`0001IB@003BL0008J000N=@00Kc80Ok<00>YD003o0000
k4h008Zf0000LRd0020f00036P0032H005M:02jK003JR`00o@`00?LR003;/`0008T00010B0001Ql0
00DN000iA000Q@X0b;`00?HX003m2@00g8@003NN0000FDP000dW00026P007cH0074^08bg003]C000
o`000>QK001b/00006Xh000H<@000QT0018[001Q@P1CY`00hfl00?l2003a>`00Z[h0001i8@00:3/0
00<K000:9000E4`0:9T00=V>003m3000mb@00<Zh0000QPP003U400057@001R0004E:00V=003@Y`00
nQP00?XE003BX@003i000019C0001b0000@M000g@`00Q@X0bKT00?LT003l3@000?<0f90002>G0000
DTd000TS00037000;Sh007lF0<C4003e;@00oPP00=b5000`W00005I;000;9@000a/002Tl001k7@2h
`P00lc800?h6003MP000=Yh0001HBP002bD000<K000X>`00Nah0]l400?<b003n1P00gH4003BM0000
EdX000/U00036`00:S`007dJ0;o3003d;P00o@P00=^8000ZVP0005A<00098`0011`0031000214@37
_@00mbD00?`=003FU@006Y@0001>CP001b4000DM000jA@00R@40cZd00?TJ003j5P00d:P000B;0000
?TL000DN00078000Bdd05i<00=JF003l3@00mRH00<No0000P1@002dn00036`002bD005Q:03^O003P
N@00o`<00?0m002J^P00078]000M=0000QT001</001V?@1][P00jUH00?l0003WGP00H:/0001R@@00
42X0008J000Q=`00MbD0[[l00?<c003n1`00fhP002FH0000DDd000PQ00057@00?4H018/00=6U003k
4`00n1l00<Zh0000PPl002ho00036`002bD005U804BR003RL000o`400;Mo0000JSP001D^00026@00
6c<0074^09bk003a>P00oPD00=b3000ZVP00055=00088@001Ad003i700V=003CWP00o0l00?HV0035
``0007`K000V>P000aX000lY001R@@1T[000jET00?l0003VH`00EJL0001MA@003BL000<K000]?P00
PQ00b[H00?TL003j6000cJl000252@00<40000<K000<9P00G4L0D:H00>EU003o0000jEP006>[0000
HD8000hX00036P00:S`0080C0<Vh003i7@00nQL00<f`0000Q0/002lo00036`003BL005i505^Y003X
G@00o`000>IS001AYP0005]7000;9@000a/003A200280P3@YP00na400?LU0033a00007XP000Q=`00
0QT001@]001Z>028]P00kd400?h4003LQ0008iL0001=CP001Ql000LP001@CP0[VP00gWd00?l2003^
A`00Nk80001V?@004B/0008J000W>`00P1D0b[L00?TJ003i6`00bKT0001o5`009SX0008J000B;000
J3X0Pk@00>m2003n1000fhH001jF0000B4`000DN00088@00E4`0>il00>9_003o0000jEL005jZ0000
GTD02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l0o@`00?TK003DW@00
9iP0001IB@0042X0008I000B;000GDH0<Yd00=NC003j5@00na400=Z;000lX0000613000D;P000QT0
00lY001HBP0RU`00dil00?TL003m3000gH4004VT0000Hd0001L`00026@003BL005E;01bE003AY000
n1h00?d;003NOP00C:D0001T?`005c00008I000=9`00ET/07YD00=:Q003i7000o@`00=b30015X`00
0692000E;P000QT000lY001IB@0YV@00eYL00?XF003k4@00fHl003BM0000G4H0014[00026@004bd0
05m403nQ003KQP00o0d00?TL003BXP006i@0001DC00032H0008J000K<`00JCT0HJ/00>=^003n1000
m2d00<Rk0000R08004A:00078@0011`002Pk001f9P2A^000je000?l0003]B000WK/0001i8@00;3h0
00@L00078000@4P008L60<Nn003d;`00oP@00>=_001MZP0006Lk000I<@000QT000hX001IB@0]V`00
f9800?/A003j6000dih001bE0000Dd`000/U00036P007cD006hc07Na003XG@00o`400?0o002/_`00
07`K000J;P001b00045800280`39^@00mBX00?h7003ON@00Bj@0001Q@P004bd0008I000C;@00HT40
CJD00>1g003n1P00mB`00<Rm0000QPP003e600067`001Ad003E200214P31a000lc@00?l3003SK`00
F:P0001U?P005Bh0008I000B;000HD<0Bj@00>1h003n1P00m2d00<K00000Q0`003Q400057P001Ql0
03a600261`38^`00mBT00?h8003NO`00@:40001MAP003bX0008I000J<P00JSL0L:l00>MN003o0000
kTD009Zj0000MRH002Di00036`002R@005=<026G003FU@00na400?TL003?Z@002Hd00018B`001b40
00@M000b@@00P1<0`l@00?@`003n1P00ggX004BR0000GDD000lZ00026@006c<006dd07bb003ZE@00
o`000>]A0022]00006hb000L=0000QT000lY001MAP14XP00h7T00?h5003c<P00^l80001n6@00;Ch0
00@L00098`00D4d06i@00=FH003k4@00n1d00<f^0002RP00041800067`001Ah003i70029003=/000
n1h00?`@003FU`006i@0001@CP00228000@L000`@000P1<0aL800?D[003m2@0003l0fhH0032L0000
ET/000/U00036`00:3/007XO0;?0003c=@00oPD00=mk000nX00005Y8000=9`000aX002@i001g902W
_P00lCX00?l3003PMP00A:80001LA`003BP000<J000S>000MRH0Y[d00?4j003o0`00h7L004:R0000
FdP000dW00036P009CT007PR0:jo003b=@00oPD00=in000hWP0005M:000;9@000a/002Xl001m6P31
a000mB`00?d9003JR`009YP0001BC@00228000@L000d@P00Q0/0b[H00?PP003k4@00dih000n@0000
ATX00P001Ql0:P00@dT038h00=>P003k4P00n1l00<Zf0000Q0/003=1000470002B<005A<02jK003L
P`00oPH00?8e002[_P0007HV000Q=`000QX0010Z001R@P1NZP00if000?l0003ZE@00Kjl0001V?@00
4bd0008I000M=000LR`0W[/00?4k003n1000gWh003:L0000E4`000TS00047000=D<008L50<f^0080
nQT007d0cJl000271P00=D8000@L00098`00ED/0=Yh00=mj003o0`00`G`0001^<P006C40008I000G
<000KC@0S;L00>m2003o0`00h7T003NN0000ED/000TS00047000=d@008T10=2X003k5000n1l00<Vj
0000PA<002/m00036`003BL005i505FX003VHP00o`000>UI001S[0000652000?:@000aX002Lk001n
6@37_`00mb800?/B003AYP0008T0000g@`0011`000XT001GBP12X@00hVl00?l1003/C`00L[00001U
?P004B/0008J000U>@00O1`0a/800?LS003k4P00d:H000290@00=D8000@L000;9@00FTP0C:D00>EV
003o0000jET005nZ0000Gd@000dW00036`00;Sl008@<0<f`003j5`00n1h00<Rl0000OQP002Hj0002
6P004B/006Hm07Ra003]BP00o`800=mi000`W000055=00078@001Al004U<01jE003KQ`00oPD00?0o
002;]P0006Xh000D;@000QT0028h001k7@36`@00n2400?XF003=/00008<>000/?@000aX000lY001T
?`1d/000kD/00?l2003OO000:iX0001?CP0200068007001@CP0^V`00ggT00?l1003/CP00KJh0001R
@@0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0`03k4@00nQD00=NC000c
W@0005e5000C;0000QT0010Z001IB@0VV000e9d00?TK003l3000gH4004ZT0000I3l001P`00026@00
32L005A<01JB003?Z@00mb800?d8003PM`00F:P0001X>`006c<0008J000;9@00DDd049000<j]003g
9@00oPL00>5d001KZ@0006Pj000K<`000QX000/U001BC@0BT@00cj/00?LS003m2000h7T005>W0000
ISd001Pa00026@003BL005E;01fE003BX@00nA`00?`=003LQ@00@Z80001P@`0052d0008I000@:P00
FdL0<Y`00=R@003k4P00nQH00=FH000XV@0005Q9000>:0000QT001L`001U?P1BY`00h7P00?h7003f
9P00c;8000R=0000C4d000TS00036`008cP0078]086d003YF@00o`000?10002^_`0007hI000b@@00
1Ad000HO000iA000PPl0_l<00?8g003o0P00iFD006b^0000K3H001`d00026P0032H005E;022F003D
W000nQL00?/C003GU000:IT0001GBP003BL0008J000J<P00JSP0J:d00>EW003o0P00lSL00;c30000
PA<001da00057`00>TD008<=0<G3003c<@00oP@00>9_001JZ@0006Dm000F;`000QT0014[001NA@0o
X@00gH400?d9003g9@00bk<000::0000A4X000LP00047000;cl007dK0;30003a?000o`400>EU001W
[@0006Tj000I<@000QT000lZ001LAP0mX000gH800?d9003f9P00b[L000280P00@4P000HO00057@00
=D80084A0<C4003d<@00oPD00>5e001>Y@000652000B;0000QT001H_001V?@1QZ`00iFP00?l2003a
?000Zkh0001j7`00:Sd000<K00098`00Cdh05I800=>O0080nQH00?l0dj0001FB0000Cdh000PR0003
7000;3h007`L0;;0003b>000o`<00>9`001CY`000692000B;0000QT001L`001Y>P1][P00ieh00?l0
003]B000T[P0001c;0008CL000<J000=9`00FDT0=ih00=b3003m2000mB/00<K00000PQ0003=20004
7@001b4004]=012@003BXP00nQH00?XG003AY00038l00018B`001b0000@M000g@`00Q@X0bKX00?HU
003m3000fHd002NI0000E4`000XT00036`00:Sd007`L0;S1003c<`00oPD00=il000mX00005Y8000=
9`000aX002<h001f9P2R_000l3d00?l2003RL@00C:D0001NA@003bT0008J000O=P00Lb`0UkT00>m2
003o0@00hf`005:W0000H4<0010Z00026P007SD0078]09Ji003_@P00o`400>=]001@YP0005m4000?
:@000QX0020f001d:P2N^`00l3h00?l3003QM000AJ<0001KA`003BL000<J000U>@00NB80/<000?<d
003n1P00gH4003>M0000ET/000XT00036`00;Ch0080D0<K0003f9`00o0d00=ND000JU00004i>0007
8@001Ad003a6006:003?ZP00nQL00?TI003>[00008T1000iA@0011d000PQ001@CP0RU`00fHd00?d9
003d;@00^l80001k7P009SX000<J000=:000GDD0D:H00>AZ003o0000kD`007nc0000JSP001H_0002
6@006C4006hb08jg003_@`00o`800>5d000oX@0005Q9000;9@000a/002lo00223`3:^000n1l00?/C
003AY@0018/0000lAP0011d000PR001BC@0YV@00g8@00?h6003:NP0007</000M=0000QT001@^001Y
>P1l/`00kD/00?l1003SK`00AJ80001IB@002bD000<K000a@000Q0/0c;800?TJ003j6@00cK000025
2@00<D0000<K000;9@00FTP0Aj<00>=/003o0000je0007>`0000ISd0014[00026P008SP007TQ0;g3
003e:@00o0d00=BL000:SP0003i700047@00228005A<03BM003ON@00o`800>i60021]00006Ti000C
;@000QT0020f001h902i`P00mBX00?`=003DW@0028d0000lAP0011d000TS001FB`0nX000hW000?l1
003[D000KZl0001S@0003bX000<J000X>`00OaD0bKT00?TM003j60000340c;<000223`00;3d000<J
000>:000HD80JJd00>]C003o0000hW0003fP0000ED/000PR00057@00@DP04Y400=RA003n2000lSH0
09^j0000Kc8001L`00026@007SD007LU0;[2003f9`00o1000=2V0000Q`@0039100036`003BL00613
06B/003ZE000o`000>9b000hWP0005=<00078@001Ah004Y<026G003LP`00o`<00>i5001l/`0006Hm
00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o0?XF003l4000fhT0046Q
0000HD8001H_00026@003BL005E;01VD003@Y`00mb400?d8003PM`00FJP0001X>P006c<0008J000:
9@00D4h02hh00<bb003f:@00oPD00>=]001V[@0006`f000O=@000aX000TS001=CP05S000b[L00?D/
003n1000i6X006Z]0000K3D001lf00036P002B<004i>00N<003;]@00mBX00?h5003SK`00HZ/0001Z
>00073@000<J000;9@00DDd04I400<n[003g8P00o@T00=mk001@YP0006@o000G<0000QT000hX001G
BP0UV000eIX00?XG003k4@00fHh003FM0000G4H0014[00026@0052d0065204BR003MPP00o@/00?PO
003@Z0004i40001AC@002RD000<J000O=@00KC@0LK000>IR003o0P00lSL00;k30000PQ0003U40006
7`001Ad00391001n602__`00l3l00?l0003XF`00O;80001`<0008CL000<J000:9000DDd059800=6U
003i7000o0h00=Z:000fWP0005]7000@:P000QT001L`001V?@1IZ@00hW400?h4003d;`00a/000025
2@008C<000DM000c@@00OaH0]l400?4i003o0P00iFD006V]0000JSP001Xb00026@003RP005Y803:L
003JR`00o0h00?PN003?ZP0038l0001=CP00228000<K000Y?000N2<0Wk`00>m4003o0000j5/007Na
0000KC@001`d00026P003BL005Q9032L003IS000o0d00?PO003>[@001hd00017B`001b4000@L000_
?`00OAX0]<400?8i003o0P00i6/005bZ0000ICh001D^00026@004bd0069105:W003RL@00o`@00?<d
002k`P0007lF000`@00011`000LQ0018C00:SP00cjT00?TL003k4@00eYH0026F0000Dd`000XT0003
6`009cX007PT0::l003`@000o`400>EV001QZ`0006Hm000E;P000QT001@^001U?P1NZP00iFP00?l1
003`?`00X[`0001g90009SX000<K000;9@00ED/0:YX00=V=003m3000mb@00<Zg0000QPH003Y50005
7P001Ql0049900F<003>[000nA`00?/B003DV`0069<0001?CP00228000@L000`@000P1<0aL<00?D/
003n2000g8<003BM0000F4X000`V00036P009CT007PT0:Nm003a>`00o`<0003c0>9b001;Y00005i5
000?:@000QX001he001b;@2B^000kTD00?l1003UI`00FZT0001R@@004B/0008I000K<`00KS80QkD0
0>e;003o0000iV80066[0000I3l0018/00026@006S8006hc08Je003]B`00o`000>IS001NZP0006=0
000B:`000QT001`c001`<02>]`00kTH00?l1003TJP00DjL0001P@`003bT0008J000P=P00M2T0X;`0
0?4l003o0`00h7L0042Q0000FTP000`V00036P00:3/007`L0;c3003d;P00o@T00=Z:000VV000059=
00088P0011`003E20026203;/`00n1d00?/C003BX`0028d00011B0001Ah000HP001:C00FTP00eYL0
0?`=003f9P00a/00001o5P00:cd000<K000;9P00FDP0@Z800>5c003o0P00kd<008ng0000Kc8001Tb
00026@005Rl006Xh07jc003/C000o`000>AZ001=Y@0005a6000=9`000aX002Tl001n6036`@00mRH0
0?`>003DV`003Xl00013B@001Ah000LP001=CP0MU@00fHh00?d9003CN00007LT000Q=`000QX0014[
001U?P1][P00jU@00?l0003UI@00DjL0001MA@003BL000<K000[?@00P1@0b;/00?PP003k4`00d:L0
00290000>4@000@L00098`00ET/0>Yl00>1f003o0P00kTL008:d0000JSP001@^00026@007SD007DX
0:bo003d<@00o@T00=NB000FTP0004I:00057P001b00051>02NI003LP`00oP@00?0n002A^00006dd
000G<0000QT001`c001c:`2X_P00lc800?d9003GT`004i400013B@001Ah000PQ001BC@0aW000ggX0
0?l2003^A`00O[<0001X>`004R`0008J000S>000Nad0aL<00?LS003k4`00cjT000271@00<T4000<K
000<9P00GDD0FZT00>QL003o0000iFH004^T0000FDT000XT00047000>TD01hd00=BK003m3000m2l0
0:^n0000Lb/001Xb00026@006S80078/0:Zn003d;`00o@`00=BL0005S00003Q4000470002bD005a7
05JX003XG@00o`000>EX0016X`0005M:00098`0011d0049901FB003IS@00oPH00?4m002<]`0006Xh
00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o0?TL003m3000gWl004nV
0000ISd001Tb00026P002bD0055=00j?003=/000mRP00?h5003SK@00Ijd0001/=@007cH000<J0009
8`00BD`008X00<Rl003d<000o`<00>IS001f/@00070`000S>0000a/000PR0014BP00Q`@0a/000?<d
003o0P00if4007Vb0000LBl002@i00036`00228004E:00280P37_P00lc400?l3003UI@00LJl0001^
<P0083L000<K00098`00C4d01X`00<^e003e:@00oPH00>9a001NZP0006Tj000K<`000QX000`V001C
C00IT`00dJ@00?PM003m3000g8@004:R0000H4<001<]00026@004B/005e603NN003IS000o0l00?TI
003CWP007iH0001EB`0032L0008J000K<`00JCT0HZ/00>=/003o1000m3000<No0000QPH004180007
800011`002`n001i802O^`00kTL00?l0003[DP00RkL0001d:@009SX000<K00088P00C4d02Hd00<f_
003g8`00o@X00=f00013XP0005m4000B;0000QT001@]001Q@P1;Y000ggX00?h7003f:000b[L00029
00009SH000@L000]?P00Nah0Y[d00>m2003o0000j5`007Ra0000KS<001he00026P0032H005I;02FH
003FU@00na800?XH003CX00069<0001AC@002R@000<K000T>@00M2X0SkP00>a=003o0000je8008Je
0000LBh0024g00036P002bD005E<02>G003FUP00na800?TI003AY0004Y40001?CP002B<000<K000Y
?000NB80Xkd00>m1003o0@00iV4006^^0000JCT001Ta00026@0042X005i504BR003ON`00oPH00?D]
0036`00008<=000g@`001Ad000HO0011B000R@00c;<00?LR003m3000fH`002fK0000EdX000`V0003
6P008SL007<[09:h003]B@00o`000>QL001`[`0006Xh000H<@000QT0014[001P@`1?YP00hW800?l3
003b=`00//00001k7@00:cd000<K00098`00DDd07ID00=JG003l4000n1d00<j^0003R`0004580006
7`001Ah003]500271@3;]@00mb800?`=003HT@0099L0001CC0002R@000<K000Z?@00O1`0]/400?<d
003n1@00ggT0046Q0000G4L000hX00026P0083H007<[09Ni003_@`00o`40003c0>AX001IZ@000691
000B:`000QT001Xb001]<`22]000k4h00?l0003XGP00JJd0001V?@0052h0008I000G<000JSP0Mk40
0>YD003o0000jET006n_0000J3/001D_00026@005c0006Xi07Ja003ZE000o`000>UJ001][P0006Ll
000D;P000QT001Pa001[=P1n/`00k4l00?l0003WH000HZ/0001T?`004R`0008I000L<`00L300T;P0
0>i5003o0@00hfd004jU0000GTD000hX00026P008cP007LT0:bo003b=P00oPD00=f0000cW@0005I;
000:90000a/002lo00214P38_@00mb@00?`?003EV@0059400019C0001R0000DN0012B@0:SP00dZ40
0?/B003h7`00b[L000233@00<D0000@L000:9000ET/0=9d00=im003n1000lCX009nk0000Lb/001dd
00026@004R`006Hm06n_003ZE@00o`000>MQ001LZ@000613000?:@000QX002@i001j802j`P00mBd0
0?d:003HT@006Y@0001;C@001R0000DO0015BP0AT@00eIP00?`=003LM`0007/M000V>P000aX000lY
001Q@`1NZP00j5h00?l0003XF`00HJ/0001Q@P003bT000<J000V>P00O1`0a<@00?HW003l3P00e9d0
00Z>0000?dL000DM00088@00DTd0;IX00=f0003n1000l3h009:h0000KS<001P`00026@006S80074_
09bk003b>@00oPH00=^8000RU`0004i>000680001Ql004U<01^D003IS@00oPL00?8e002Q_000078]
000J<P000QT001Pa001_<@2H^P00lCX00?h6003KR@007iH0001;C@001Ql000HP001>CP0TV000g8@0
0?h4003`?`00S[L0001/=P005Bh0008I000O=@00MbD0]l400?DZ003l3P00dil000B;0000>4@000@L
000:9000FDP0BjD00>EV003o0000j5`005VY0000GDH000`V00036`00<d4008P20=6U003l4000mRL0
0;c20000Mb@001he00026@005Rl006hb09Zj003b=`00o@P00=NB000@T00003m700047@002B<005Q:
04RS003UI`00o`000>MN001DY`0005]7000:9@0011`003Y500Z>003FU`00o@X00?<d002L^`0006hb
00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1=0?LR003n2000hGD005fZ
0000JSP001dd00036P002B@004a=00>;0039^P00m2l00?l3003VI000M[40001a;`0093T000<K0007
8@00@DT008D90<C4003b>000o`400>UJ0025]@0007@Y000X>`0011`000LP000mAP00P`h0_<800?4l
003o0000jEL008Rf0000MBP002Tl000470001b0003i700243030``00lCT00?l1003XG000P;@0001b
;0009CX000<K00088@00A4X008P30<Nn003d<@00o`<00>EW001][P0006dd000O=@000aX000XT001@
CP0=S`00cZh00?LT003m2000ggX0052V0000I3l001L`00026@003RT005U902ZJ003FUP000P3k5000
o`3GU000:iX0001IB@003RT0008I000G<000ICh0E:L00>1f003n1`00mRP00<^e0003R`0004Q;0008
8P000a/002Lk001e:02?]`00je000?l0003]B@00Vk/0001h8P00:cd000@L00078@00A4X008T10<Vh
003e:P00oPH00>1f001AYP0006=0000E;P000QT0014[001MA@0mX000g8@00?d;003h8@00cZd000Z>
0000:SP000<K000W>`00MRH0U[T00>e:003o0000je<008Ne0000LRd0028h00036P002R@0059=01VD
003CW`00nQP00?/C003FUP0099L0001EB`0032H000<J000O=P00L300P;<00>YF003o0000kDT009Ji
0000MRL002Hj00036`002B<0055=01NC003CX000nQL00?/D003EVP007YD0001CC0002R@000<K000T
>@00M2T0TkT00>e:003o0000jEP007Zb0000KC<001`d00026P003RP005Y803NN003LQ@00o@X00?HV
003:]`0008L4000nA`001Ql000DN000iA@00Q@T0b;`00?HY003m2000gH8003ZO0000FdP000hX0002
6P007C@006la08:d003[DP00o`000>YC001o/`0006hc000L=0000QT000lY001LAP11X@00gg/00?h6
003d;`00`l@000205000<D0000@L00088@00CDh04Y400=:Q003j5P00nQL00=6T000>S`0004U<0007
8@0011d003A200233P37_P00mRT00?d9003KQ`00<9`0001GBP002bH000<J000U>P00Mb@0Y[d00?4l
003o0P00hW0004nV0000H4<0010Z00026@0073@006la08Ne003/C000o`000>MO001X[@0006Hm000D
;P000QT001L`001Y>@1c/000jEL00?l0003ZE000N;40001Z=`006300008I000D;P00ISd0J:d00>QM
003o0000je0007nc0000K3D001Ta00026@004bd006Dm06N]003XGP00o`000>]@001l/`0006/f000H
<@000QT001D^001W>`1_[`00jEP00?l0003YE`00LJl0001X>`005Bh0008I000H<@00K3H0P;@00>a=
003o0000iV<005bZ0000HT40014[00026@007SD007<[09bk003`?P00o`<00>1f0010X@0005Y8000<
9P000a/002Tl001m6P32a000mB/00?d:003HS`007iH0001?CP001b4000@M000kA@00R@00cjX00?XG
0000Y03i6@00cZh000280`00>4@000@M00088P00DTd0:9T00=^7003n1`00lc<00:no0000Mb@0028g
00026P0042X00691062[003WGP00o`000>UG001Z[P0006@o000A:`000QT001lf001e:02Y_P00lc@0
0?h7003KQ`009YP0001AC@001b4000DM000mA`06S000dZ800?/B003PL000080D000[?@000a/000`W
001LAP1@YP00iFL00?l0003[DP00L:l0001U?P004R`0008I000Q=`00Mb@0]<400?@^003m2P00ei<0
01JB0000Ad/000HO00068000CTh089H00=Z:003n1`00lSH00::l0000LR`001/c00026@005Rl006`e
08bg003_@@00o`<00=in000^V`00059=00088@001Ah0045800n@003FU`00o@/00?@^002b`00007HW
000N=@000QT001D^001[=`28]P00kd800?l3003NO`00;9X0001AC@001b4000DN0016B`0HT`00fHh0
0?h7003b=P00W[/0001`<0006C40008I000K<P00LR`0Ykd00?<b003m2P00eYD000n@0000?dP000@M
00098P00ET/0?Z000>9_003o0000je<006R]0000HD8000hX00036P00;Ch008@<0<f_003j5@00n240
0<K00000O1`002<h00026@004bd006Xh08Zf003`?`00oPD00=^8000LU@0004M;00057P00224005A<
03ZO003RL000o`000>YE001RZ`0005m4000<9`000a/003A20029003BX@00o0h00?D]002/_`00078/
2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l0mRT00?h5003TJ`00K:h0
001^<`008CL000<K00088P00A4X008L60<G3003b=`00o`400>UJ0026]@0007DX000Y?00011`000HP
000jA@00PA80/l000>m1003o0000je4009Fi0000NB8002ho00047@001Ql003I3001o5`2[_P00kd@0
0?l0003/CP00V;X0001i8@00;Sl000@M00067`00=d<007lE0:no003_@@00o`000>]B002@^00007LU
000Z?@0011`000HP000mAP00P`d0`<<00?8i003o0@00j5h007bb0000LBh002<h00036`00228004U<
00>;003:]`00mB/00?h5003RL000GZX0001X>P006S80008J000<9P00ED/07YD00=>O003i6P00o0l0
0=Z:000hWP0005e6000A:`000QT001@]001Q@P16X`00gH000?d:003g8P00cZ`000j?0000Cdh000TS
00036`008SP0074_07nc003YF@00o`000?10002[_`0007dJ000a@00011d000HO000lAP00Q@X0a/80
0?<a003o1000hfd005nZ0000J3/001Ta00026@003RT005U8032L003ISP00o0l00?TK003AX`005I80
000^>@000aX0028h001b;@27]@00jU<00?l0003]BP00UkT0001f9P009c/000<K00098P00CTh03Xl0
0<nY003h7P00o0h00=V<000`W00005U9000>:0000QX001/c001[=P1`[`00iel00?l1003_@@00Y[d0
001j8000:cd000@L00088P00Bdd038l00<nY003i7@00o0l00=R@000ZVP0005M:000<9P000aX001lf
001`<024]000je<00?l0003/C`00R[H0001b;@008CL000<J000<9P00ET/0:YX00=R?003l3P00n1l0
0<j^0005S00004E:0007800011d003=100214`33a000m3000?h5003PN000B:<0001OA00042X0008I
000I<P00JcL0Lk000>QK003o0000kDX008ng0000LR`0020g00036P003BL005U903BM003LQ@00o@T0
0?HX0038_00008@;000g@`001Ad000HP0015BP07S000cjX00?TK003k4P00eIX001VD0000D4h000PR
00047000;Sl007hG0;o3003d<000oPH00=im000nX00005]8000=:0000QX0020g001c:`2F^@00kT@0
0?l1003UIP00GZX0001T?`004bd0008I000H<@00JcL0N;400>YE003o00000?<0jUH007Na0000JSP0
01P`00026@0052d006Dn06B/003WH@00o`000>e;0027]@0006lb000K<`000QT0014[001R@@1JZ@00
iFL00?l1003^A`00S[L0001`;`007C@0008I000A:`00HD80F:P00>EW003o0@00kTP008bg0000Kc40
01`c00026@004R`006=0062[003VHP00o`000>a>0020]00006`f000H<@000QT001D^001X>`1a[`00
jUH00?l0003YFP00Jjh0001V?@004bd0008I000J<P00Kc80S;L00>i6003o0@00hf`004jU0000GTD0
00hX00036P0093T007PR0;;0003c<P00oPL00=b5000/VP0005=<00098`0011`003A200252@3;]000
n1d00?/D003AY0001X`0000oA`001Ah000LP001>CP0LU000f9400?d;003e:`00_l<0001k7@009cX0
00<J000=:000GTD0DJH00>EX003o0000k4h007Vb0000JCX001@^00026@006c<0074^09Vj003a?@00
oP@00=im000cW@0005A<00098`0011`003I300280`3>Z`00nQL00>9W0000Q0/0035000036`002bD0
05U904:R003RL@00o`400>e90020/`0006Xi000E;P000QT001dd001c:`2T_@00lSH00?h7003JR@00
8IL0001?CP001b0000DN0016BP0DTP00ei@00?d:003d;P00//00001f9@007cH0008I000C;@00J3X0
OK<00>e9003o0@00hG@003^O0000ET/000TS00047000>TD01H`00=:Q003l3`00mRL00<;40000NQl0
02<h00026P004R`006Ll07Vb003]B`00o`400>5e000hWP0005E<00088P0011d003m700f?003EV000
o@/00?@_002^_`0007@Y000L=0000QT001L`001^<P2G^@00lCT00?h6003JR`006Y@00017B`001Ah0
00LQ001BC@0aW000ggT00?l2003]BP00Mk40001U?P0042X0008J000X>`00OaD0b[P00?TK003i6P00
b[L000205000:3/0008J000@:P00ISd0N[800>i7003o0`00gWh002RI0000Cdh000HO00068000D4h0
;I/00=mj003o0P00k4`0076_0000Hd0000hY00036P00;Sh008D90<n[003k4P00mRH00;g30000MbD0
2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo06P0m3000?l2003VH@00Nk80
001b;@009SX000@L00078000?DH0088?0;O1003`?`00o`000>]A002E^@0007TQ000_?`001Ad000DN
000d@P00OA/0Xk`00>e9003o0000kTP00:Fm0000OAX003A200057P001Ad00310001j7`2K^`00k4d0
0?l0003^AP00Z;h0001n6@00=48000DN00057@00<40007/M09nl003]BP00o`000>e:002P_00007/N
000`@0001Ad000DN000f@`00OaH0[kl00>m1003o0000jU@008bg0000MBP002Pk000470001b400458
00261P36`000lc800?l3003UIP00KJh0001/=@007SD000<J000:9@00DDd04Y400<nY003h8000o@/0
0=f10015X`000652000D;@000QT0014[001MAP0iW`00fXX00?`>003i6`00dZ8001VD0000Dd`000/U
00036P007SD006de072_003VH`00o`800?8h002l`P00084B000g@`8000DN0>P003E300204`2i`P00
lCT00?l1003VH`00KZl0001/=P0073@0008J000<9P00ET/099L00=FH003k5000nQD00=FJ000QUP00
034i00026P007SD006hc07Na003XG000o`000>m1002W_@0007/N000]?P0011`000LQ0016B`03R`00
c;800?LT003m2P00g8<003fP0000GDH0010Z00026@00630006Lk06:[003TJ@00o`800?8h002f`@00
07hH000a@00011d000LP0013B@01RP00c;<00?LS003m2`00fhH003NN0000FTP000hX00026@006c<0
06`e07B`003XG000o`000>i6002I^P0007HV000U>P000a/000XT001BC@0NU@00eIT00?/C003i6@00
dJ@0012@0000CDh000PR00047000;Ch007`K0;?0003b>000o`<00>=^001FZ00006=0000C;@000QT0
01H_001W?01T[000iV@00?l1003_@P00Wk/0001g9@009CX000<K000;9@00ED/0:9T00=R?003l3@00
mb400<^c0000R04003i700057`001Ah003e600280P3;]000mb400?`=003HT0009IP0001CC0002R@0
00<K000Y?000NQl0[kl00?8h003o0`00hG<004^T0000Gd@0010Z00026@0073@006la08Je003/C@00
o`000>QL001/[P0006Pk000F;`000QT001D^001W?01Y[@00ieh00?l0003/C@00Q[D0001_<P006c<0
008I000A:`00HD80EZP00>AZ003o0@00kd<009Ni0000Lb/001lf00026P003bT005i504bU003RL000
o`800?0n002N^`0007DY000Q=`000QX000hX001MA@1:Y000hW400?l2003`?`00W;/0001d:P0083H0
008J000?:@00Gd@0DZH00>A[003o0@00kTD0092h0000L30001`c00026@004R`006A006:[003WH000
o`000>]A001j/P0006Xh000F;`000QT001L`001Z=`1l/`00k4l00?l0003VH`00G:X0001R@P0042X0
008J000O=P00M2T0XK`00?4j003n1000gg/003RN0000EdX000XU00036`00;Sl0084B0<Rm003g9000
o0l00=FJ000AT00004I;0P001Ql0WP00ADX049000=BK003l3`00mb@00<Nn0000P1@002`n00036`00
2bH005Y804BR003RLP00o`800>i60029]P0006dd000H<0000QT001P`001]=029]P00kTD00?l2003Q
L`00@:40001HB@002bD000<K000`@000Q0`0bkD00?TM003UH00008P1000gA00011`000TS001EB`0e
W@00gg/00?l3003_@@00SkL0001^<`006300008I000I<@00Kc40U;T00?0n003n1000gWl002jK0000
DTd000PR00057@00?TL02Hd00=BM003l3`00mRL00<?40000Nah002@i00026P0042X006@o06j_003[
DP00o`000>AZ0018Y00005Y8000;9@000a`003=20027103?ZP00na@00?PP0038_@0007hG000X>`00
0aX000lY001R@@1Z[@00jU@00?l0003TJ`00AZ<0001HB@002R@000@L000hA002R`00dZ800?`?003f
9`00_/<0001i8P008CL0008I000D;@00JSP0QkD00>m2003o1000gH8002JH0000Cdh000HP00067`00
CTh099P00=b3003n1000kd4008Je0000JCT001<]00026@008cP007/M0<K1003g8@00nQD00<j^0000
Q0/002dn00036P003RP0069106^^003[D000o`400>5e000eW@00059=00078@001Ah004Y<026F003L
Q000o`@00>m30020]00006Ll000A:`000QX002Pk00214`3;]000nQP00?PO0036`00007/M2_ooool1
o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l0lSP00?l1003YF000R[H0001f9P00
:cd000@M00067`00=T<007hH0:Nm003^B000o`000>e8002U_@0007dI000e@P001Ah000@M000^?P00
N280TkP00>]B003o0000l3l00;G10000PA4003Y50006800011`002Xl001f9P2<]`00jUH00?l0003`
?@00^<8000224000>dD000HP00047000:cd007LU092h003[D`00o`000>m1002``00007lE000f@`00
1Al000DM000`@000Nah0Wk`00>e9003o0000kD/009^k0000NR0002ho00047@001Ql003Y50022402l
`P00lCX00?l1003XG@00O;80001a;`008cP000<K00098`00C4d01hd00<bb003f9`00oPL00>1g001C
Y`0006Dn000G<0000QT000hY001IB@0/VP00ei<00?/C003j5P00eIT002FH0000EdX000dW00026P00
6S8006Pj066[003SK000o`@00?@`0036`00008D9000nA`001R0000@M000_?`00O1`0ZKh00>m1003o
0000jEX007fc0000L300024g00036P002R@0059=01RC003BXP00nAX00?`@003HT000;I/0000d>@00
0QT001Xb001Z>01X[@00iFH00?l2003a>@00]l40001o5P00<d4000@M00067`00?TL008L60<Rl003e
:`00oPH00=mi001;Y0000652000C;0000QT001@^001S@01CY`00hG800?h4003d<@00aL<000223`00
=d<000DN00067`00?4H008H70<Rl003e:P00oPL00=il0014XP0005i4000A:`000QT001P`001X>`1V
[000iFD00?l1003`?P00ZKh0001j7`00:cd000<K00088P00Cdh04Y400=:S003j6000na@00=FJ000L
U000059=000990000a/002Lk001h8`2S_000l4000?l1003UI@00I:`0001W?0005Rl0008I000C;@00
Hd40EZP00>=^003o0`00lCT00:no0000Nah002Xm00036`002B<0055=01bD003EV@00na800?TK003?
ZP0028d00015BP001b0000DM000f@`00Q0`0b;d00?HX003m2@00fhL0036L0000EdX000`V00036P00
93T007HW09nk003`@000o`400>AY001IZ@0006=0000B;0000QT001Ta001[=`1g/@00jUH00?l0003Z
D`00Nk80001/=P006C80008I000B;000Hd40FZT00>EX003o0@000:@0kd@009Ji0000Lb`0020f0002
6P003RT005e604RS003QM000o`<00?4j002W_@0007LT000T>@000aX000dW001JB00nX000ggX00?h4
003b=P00[[l0001i8P009SX000<J000<9P00FDP0?J000=mj003n1000lSL00:bo0000N2<002@i0003
6P003BL005]704BR003QM@00o`<00?4m002O_00007@Y000P=P000QX000lY001P@`1DY`00i6T00?l1
003^B000RKH0001^<P006S80008I000D;@00IS`0KJh00>UH003o0000jET006^^0000ISd001<]0002
6@006c<0070`09:h003_@P00o`800>9b0016X`0005]7000<9`000aX002Pk001l6`32a000mB/00?d;
003HT@007ID0001>CP001b4000DN000nA`05S000dJ@00?/D003h7P00bkD000242`00<T4000@L000:
9000ET/0=Yh00=mk003o1000l3d009Vj0000LBh001/c00026@0052h006Tj07Zb003/CP00o`000>AZ
001=Y@0005a6000<9`000a/002Xm001o5@37_P00mb<00>MI0008S@0003i700057@002240055=02RI
003LQ000oPH00?8h002O^`00078]000K<`000QT001D_001[=`24]@00kTH00?l2003QMP00>il0001F
B`002B<000@L000gA000R@00d:L00?/C003h8@00b;`0001o5P00:C`000<J000>:000H4<0GjX00>QK
003o0000if4005JX0000GDD000dW00036`00;Ch008<>0<^d0080nAX004d0bk@000233P00;Ch000<K
000=9`00GT@0FjT00>QM003o0000iV8005BW0000G4H000`V00036`00<D4008H70<n[003k5000n240
0<No0000OAX002Dj00026P004B/006Hm07Ra003]BP00o`800>1h000cW@00059=00078@001Ah004I:
01RC003IS@00oPL00?4i002F^@0006hc000F;`000QT001he001g9@2j`P00mRP00?`@003AY00008T1
000c@P000a/000`V001NA@1MZP00jET00?l0003TJ`00@Z80001FB`002B8000DM0012B@0ETP00fHh0
0?h6003a>`00T;P0001[=P0052d0008I000S>000O1/0akd00?PM003i6@00b[L0001o5@0:ooooo`7o
00000Oooool001kooooo00?o0000ooooooooool01oooool01P3`@000o`000>a?002J^P0007/N000a
@08000DN03D00310001j802G^@00je000?l0003`@000]L4000224000?4H000HP00047000:3/007@Y
08Bd003XF`00o`400?8g0035a00008H80012B@001b4000<K000U>@00LRd0O;800>MO003o0P00lSD0
0<G20000QPL0049900078@000a/002Hj001c;020]000j5`00?l1003b>@00`<<000243000?DL000HP
00047000:S`007LU092h003[DP00o`000>m3002[_P0007hH000d@P0200057P18000d@P00OQP0[;l0
0>m2003o0000jU@008^f0000MBP002Lk000370001b4004A:00280P38_000m2h00?h4003SK@00HJ/0
001Y>@006S80008J000<9`00ED/089H00=BM003j6000na400=R?000aW00005Y8000?:@000QT001H_
001T?`1CY`00h7H00?h6003e:@00b[L0002:0000ADX000LQ00047000:S`007PT09Vj003]BP00o`00
0>]A002=]`0007@Y000U>P000a/000TS001>CP0=S`00cZ/00?PP003m3000fhH003ZO0000=SP0008I
000G<000ISd0FZT00>9_003n1000lc400<G30000P`d003U40P001Ah0o`00=d@0088?0<C4003c<P00
o`@00>9_001IZ@0006Dn000F;`000QT0014[001OA016X`00gW`00?h7003e:@00bKX000271@00?TL0
00HO00057@00=D<0088A0<C4003c<@00oP@00>5c001BYP000691000C;@000QT001@^001T?`1GZ000
hfl00?l3003b=P00^/80001n5`00<40000@L00078@00Ad/01hd00<j/003h7P00o0l00=RA000XV@00
05E;000;9@000aX002<h001d:P2C^000kDT00?l0003XF`00Lk00001[=`006S80008I000@:P00Gd@0
B:<00>1g003n1@00lc800;o30000OaH0031000047000224004a=012@003BX`00nQL00?XF003CX000
4i40001>CP00228000@L000`@000OaD0`/@00?@_003n1P00gWd003jP0000FdL000hX00026P007cH0
078]08ng003]B@00o`000>MP001W[@0006Ll000E;P000QT001D^001W?01X[@00iel00?l0003]BP00
RkH0001`<0007C@0008I000?:P00Gd@0C:D00>9a003o0`00lC`00:Fm0000MbD002@i00036P0032H0
05U903ZO003NOP00oPH00?<c002g`@0007/M000Y?0000a/000/U001FB`0aW000g8@00?h7003d;`00
_/<0001m6P00:cd000<K000:9000ET/0<9`00=b4003n1`00m2l00;c20000O1/002Tl00036`002bD0
05M:03NN003NOP00oPD00?<e002__`0007TR000U>@000aX000dW001LA`16X`00hG<00?l2003`?`00
VKX0001b;0007SD0008I000A:`00HT40GjX00>IQ003o0000je0007Zb0000JSP001H_00026@006300
06`f08:d003]B`00o`000>EX001CY`0005m4000>:@000QX002<h001h8`2b`000lc800?h7003KQ`00
:9T0001BC@00228000@M000g@`00Q`@0cJh00?TI003j6000cZ`000280P00>4@000@M00088P00DTd0
:YX00=b5003n1P00lSD00:Rn0000MBP001lf00026@004B/006Dn06^^003ZE`00o`000>MP001KZ@00
0613000?:@000aX002Dj001k7P30``00mBX00>YB000CT@0004I:00067`001R0004a=01bE003ISP00
o@T00?@a002__`0007HV000P=P000QT0018/001W?01e/@00k4l00?l00000JP3SK000B:<0001JB000
2bD000<K000a@000Q@X0cK000?XI003i6P00bk<000233@00;cl000<K000<9P00G4H0DJH00>EU003o
0000jEP006F/0000HD8000lY00036P00:3/007lG0<Rm003h8000na@00<nZ0000Q`D003=100036`00
2bD005]804fU003UIP00o`000>UH001RZ`000613000>:0000aX002`m0022403;]000nAX00?TK003:
]P00084B000Z?@000aX000hY001R@@1Y[@00je<00?l0003SKP00@:40001FB`002B<000@M000nA`0=
S`00eYH00?d:003c<@00Y[d0001b;@006S80008I000J<P00Lb`0Z[h00?@_003m2`00eI/000R=0000
>TD000@L000:9000FTP0CjH00>IR003o0000iV80052V0000FTP000XT00047000>dD02Xh00=JH003m
2P00lc<009nl0000Kc4001L`00026@007cD007PS0<74003g9000na@00<j]0000Q0`:ooooo`7o0000
0Oooool001kooooo0ol00007ooooo`3o0>e8003o0000kTH00:Zn0000OaH003Q400067`0011`002Xl
001e9`27]@00jET00?l1003b>000aL@000261`00@dT000PQ00036`008cP0070`07F`003VI000o`<0
0?@`0038^`000HX00019C0002B<000<K000P=P00KS<0KJh00>AX003o1000m2h00<Vi0002RP0004Y<
00098`000a/0024g001^<P1a[`00iFD00?l3003c<@00akh000280`00ADX000PQ00036`009CT0078/
082d003XF`00o`400?4k002k`P00088@000jA@001Ql000@M000^?P00NB00W;/00>e;003o0000kD/0
09^j0000NB4002dn000470001R0003e600243034a000lSD00?l2003VI000L:l0001]=0007SD000<J
000:9@00DDd059800=2W003h7P00o@`00=b5000nX00005i4000B;0000QT001<]001P@`15X`00gH00
0?d:003g8P00cJh000^>0000CDh000TS00036`009CT007<Z08Zf003[D`00o`000>i8002L^`0007PR
000Z?@0011`000LQ0016B`02RP00bkD00?HV003n2000gWd004NS0000>SP0008I000C;@00HT80C:D0
0=mi003n1`00mBX00<Vj0000R0@004180006800011d00350001n602d`@00lCX00?l2003UIP00Ijd0
001Y>@006C40008I000?:@00FdL0>9l00=^6003m2`00mb<00<ba0003R`0004E:00078@0011`002lo
001m6@2d`000lCT00?l2003TJ@00H:/0001V?0005Rl0008I000A:`00H4<0BJ@00>1h003n1P00m2h0
0<K20000P`h003I300057P001Ql003m800280P3;]@00mb@00?d;003KQ`00=9d0001IB@003BL0008J
000N=@00L300Q;D00>]A003o0000je8008:d0000Kc4001dd00026P003RP005]803^O003MP@00oPP0
0?DZ0037_`0008<=000f@`001Ad000HP0014BP06S000cZ`00?TM003k4@00eYL001jE0000DTd000TS
00036`00:Sd007/M0;;0003b=`00o`<00>5c001<Y@0005m4000@:P000QT001/c001]<`20/`00je40
0?l0003YE`00M[40001[=`006C40008I000B;000Hd00FZT00>AY003o0@00kd8009Zj0000M2T0024g
00026P003BL005]803nQ003ON`00oPD0003c0?<d002e`@0007/M000Y?0000a/000XU001EB`0^V`00
fhL00?d9003e:`00aL<000205@00;Sl000<L00098`00DTd09IP00=V>003m2`00mRP00<No0000PA40
0310000470002B<0059=02BG003ISP00o@/00?HX0036`000080C000_?`000a`000TS001DC00ZVP00
fhP00?d8003d;@00_l<0001m6P00:S`000<K000;9@00F4X0>Il00=il003n1@00lSL00:Vn0000MbD0
028h00026P003RT005i5056V003TJ`00o`400>i80029]P0006hc000I<P000QT001@^001X>`1c/000
jU@00?l0003WG`00HZ/0001S@0004B/0008I000O=P00M2X0X[`00?4j003n1000gWd003FM0000ET/0
00XT00037000<D0008<=0<Zg003h7`00na<00=:R0007S@0003m700057P001b0004i>01jE003IS`00
o@X00?@^002h`P0007TP000T>@000QX000lY001Q@P1MZP00if000?l0003YE`00JZd0001T?`004B/0
008J000Q=`00MbD0/<000?@a003[B`007YD0001>CP001b0000DN0014BP0AT000eIP00?`=003e:P00
_l<0001j7`0093T0008J000@:P00Hd40IZd00>UH003o0000iV8005JX0000GTD000dW00036`00:cd0
084C0<Vj003h7`00nQD00<nZ0000R0<003E2000470002R@005Q904>R003SKP00o`400>a?001c/000
06Dm000A:`000QX002<h001j7`32a000mRL00?`?003BX@0018/0000jA@0011`000TS001GBP10X@00
hW000?l1003[C`00L:l0001T?`0042X0008J000V>P00OQP0akd00?PP003j5@00cZd000252000<400
00<K000<9`00GTD0FjT00>QL003o0000iFD004fU0000FTP000XU00047000=d@00h/00=>P003l3P00
mBX00;K10000MRH001de00026@005c0006lb09Zj003b=`00oPP00=RA000CT@00045800057@002B80
05I;046Q003SK000o`000>UH001NZP0005i5000<9P000a/003A20029003BX@00o0h00?D/002__`00
07<Z000J<P000QT001/c001d:P2a`000mB/00?`?003AY00008P300Sooooo0ol00001ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`180>]A003o0000l3h00;[20000P`d003i700078@000a/002Di
001a;P1h/@00iV<00?l3003d<000b;/0006:0000Bdd000TS00036P007cD006`f06J/003SKP00oPD0
0?HY003</P002hh0001@CP002R@000<J000L=000JCT0GjX00>9b003n1P00mRL00<f`000=S`00051>
000:90000aX001dd001Z>01SZ`00hfl00?h5003e:P00bkD000J<0000CDh000TS00036P0083L006hb
076`003VI000o`800?<c0036`@0008H60011B0001b4000@L000X>`00MBL0S;L00>YC003o0000kd<0
0:Zn0000OAT003=10P001Ah0QP00=T<0080D0;C1003`?@00o`000>QK001o/`00074^000S>0000a/0
00TS001=CP09S@00cK000?LT003m2000gg`004^U0000HT4001D^00026@0042/005a603RN003JR@00
o0h00?TL003AY@005I80001AC@002R@000<J000P=P00Kc40N[800>QL003o0000l4000:bo0000OA/0
031000047@001R0003m700261`37_P00m2d00?h5003QL`00EJL0000m=`000QT0014[001NA@0oX@00
g8800?d:003g8`00c;4000F<0000B4/000LQ00047000:cd007XP0:Bm003_@P00o`000>QL001f/@00
06dd000M=0000QX000dW001GBP0/VP00f8l00?`?003i7000d:P000j?0000CDh000PR00036`00:S`0
07TQ0:Bm003_@@00o`400>MP001^[`0006Xg000J<P000QT000lY001LA`0lX000gH800?d9003f9`00
bKT000271@00?DL000HO00057P00>4@008@;0<Nn003e:`00oPL00=im0011X@0005e6000?:@000QT0
01Xb001/=P1e/000j5X00?l0003]BP00TKP0001c:`008SL000<J000<9P00EdX0;Y/00=Z;003m3000
mb@00<^f0000R0<003e60P001Ah0RP00?DH008P40<^e003g8`00o@`00=V=000ZVP0005E;000;9@00
0aX002Dj001g9@2R_000l3l00?l1003TJP00FZT0001S@0004b`0008I000H<000JCT0LJl00>QJ003o
0000k4h008Fe0000Kc4001`d00026@0042X005m404bU003RLP00o`<00?4j002Z_P0007PR000V>P00
0aX000/U001GBP0bW000g8@00?h8003e;000aL@0001o5@00;cl000@L00098`00DTd08YL00=RA003l
3@00mb@00<Vj0000Q0`003A200047@00224004m>01VD003FU`00o0l00?PQ003:]P0008H8000g@`00
11d000LQ001>CP0HT`00eYP00?`?003g8P00b[L000252P00=D8000@L00088P00D4h07YD00=NB003m
3000mRH00<Nn0000PA8002lo000370002B<005A<02bJ003KQP00oPP00?@`002i`P0007/N000W>`00
0aX000`W001JB013XP00hG@00?l2003`?`00V;X0001b;@007C@0008I000B:`00I3l0IJ`00>QM003o
0000jUH0072_0000Ic`001@]00026@006c<0070`09:h003_@P00o`800>5d0012XP0005Y8000;9P00
0a/002/m001o5P36`000mRH00?`>003EV@004Y400017B`8000HO09@004M;01:A003EV000o0h00?HW
0035`P0007hI000Y?0000aX000dW001MAP1?YP00i6T00?l0003/CP00N;80001X>P0052d0008I000L
=000Lb`0X;`00?8i003]A000:YX0001BC@00228000DM000mAP06S000dZ400?/A003g8`00akl0001o
5`00:C`000<J000=:000Gd@0F:P00>MQ003o0000jET006B/0000HT4000lY00036P009SX007`K0<G2
003g9@00o1000=:Q0006S00003]600047@002B8005A<03JN003PN000o`800>i60022]00006Xi000D
;@000QT001le001f9P2b`000m2h00?d;003FU`003i000011B0001Ad000PR001CC00cW@00ggT00?l2
003^A`00Ok<0001X>P004b`0008I000R=`00NB00`L@00?HV003l4000dJ<0002:0000=T<000@L000:
9@00FTP0CJD00>EU003o0000j5`005^Y0000GTD000`W00036`00<D0008H60<nZ003k4`00mb<00<G4
0000NQl0028g00026@0052d006Xg08^f003`?`00oPD00=^7000NU@0004U<00057P001b40059=03BM
003QM@00o`400>]?001/[P000691000>:0000a/002ho00252@3?Z`00na<00?LU002o``0007PS000N
=@000QT001L`001`<02Q_000lc800?d;003EVP001X`02_ooool1o`00007ooooo000Nooooo`03o`00
0?oooooooooo00Oooooo07<0jEX00?l1003b=P00a/8000271000AT/000PR00036`0083L006dd06Z]
003SK000oPD00?HY003</P0038h0001@CP002bD0008J000K<`00J3/0F:P00>1g003m2000mb800<nY
000FTP0005=<000<9P000QX001Ta001U?@1AYP00gg/00?d:003h8000d:L001RC0000E4`000`V0002
6P006C4006Hm05FW003PN000o@P00?LS003>[0004I00001AC@002bD000<J000L=000JSP0Hj`00>=^
003n1@00mB`00<Zh0002R`0004U<00088P000a/002<h001a;P1m/`00j5`00?l1003a>`00^/800021
4@00>D@000HO00047@00<40007/M0:Bm003^A@00o`000>]B002>]`0007DW000X>`000a`000PQ0015
BP00R@00bKT00?D[003n1@00hW8005VY0000IS`001Pa00026@003RP005U902bJ003GT`00na800?XG
003DV`008IH0001EB`0032H0008J000L=000JcH0K:h00>EU003o0P00lSP00;c20000PA8003I30080
00DN0?l003Q400224031a000lcD00?l3003TJP00Hj`00011=P000QT000hY001JB00bW000fH`00?`>
003i7@00d:L0012@0000Cdh000TS00036`009SX007HW09Fi003]B`00o`000>YC0025]@00074^000Q
=`000aX000/U001DC00PUP00eIT00?/D003j5`00dih001VD0000DDd000XT00036`009CT007DX09Bi
003]BP00o`000>UG001m/`0006lb000N=@000QX000dW001HB@0_W000fX/00?`=003h8@00cK0000B;
0000ADX000LP00047@00<T40080D0;o3003c<P00oP@00>5d001>Y@000652000B;0000QT001L`001W
>`1V[000iV<00?l1003_@@00X;`0001g90009SX000<K000:9000Dd`08YL00=ND003l4000n1d00<j/
0006S00004A:000680001Ad003I300233@37_P00mBX00?d8003LP`00=ih0001IB@003BL000<J000Q
=`00Lb/0TkP00>i7003o0000if0006R]0000Ic`001H_00026@0052h006Dn06:[003VI000o`000>i5
002E^@0007<[000P=P000QX000dX001KA`0oX000gg`00?h5003c<P00^/80001m6P00:cd000<K000:
9000Dd`09YP00=V>003m3000mRD00<Rk0000Q0`003E200047@001b4004i>01JB003EVP00na400?PN
003</@0008P2000kA@001Ah000HP0017B`0>S`00dZ400?/D003i6`00cZd0006:0000?DL000DN0006
8000AT/03Hl00=:Q003k5000nA/00<f^0000R@4003]600057P001b0004Y<01>A003DV`00na400?PP
003;]@0008D9000e@`0011d000PR001@CP0PUP00f9000?d;003f:@00aL80001o5P00;3h000<K000:
9@00EdX0=Yh00=in003n1@00lSL00:Rn0000MRH0024g00026P003bT0061305JX003UIP00o`000>a=
001o/`0006/g000G<0000QT001L`001/=P23]000kDX00?l1003TJP00CjH0001MA@003BP000<J000V
>P00Nah0_<<00?D]003m2P00f8l001jE0000CTh000LP00057P00?dL028d00=:R003k4P00n2000<Vi
0000PQ0002ho00036`002bD005U9046Q003QLP00o`800>i60028]@0006`e000G<0000QT001Ta001^
<P2A^00007h0kd400>lo000gWP0005E;00098`0011`003I300280`3?Z`00nQH00?TM003:]P0008<>
000_?`000a/000/V001KA`1;Y000i6X00?l0003[D000L[00001V?@004R`0008I000Q=`00N2<0^<80
0?D/003m3000eYL0012@0000@TT000DN00078@00DDd0:YX00=f1003n1000l3h009:h0000KS<001L`
00026@006c<0078]0:>l003c=@00oPP00=V>000JU00004Q<00067`001b0004m>02JH003LP`00oP@0
0?0o002>]`0006`e000F;`000QT001de001e:02a`000m2d00?d<003EVP002hh0000mAP0011d000TS
001FB`0oX@00hfl00?l0003[D`00JJd0001R@@003RT000<J000[?@00PPl0c;<00?XH003h7@00b;/0
001n5`009SX0008J000A:`00IS`0Nk800>i7003o0P00gWh002ZJ0000Cdh000HP00067`00Cdh0:9T0
0=io003o0`00kTL007^b0000ISd0010Z00036P00:C`0084B0<^d003j6000n1l00<Nn0000O1`002<h
00026@0052h006`f09:h003a>P00oPL00=RA000AT00:ooooo`7o00000Oooool001kooooo00?o0000
ooooooooool01oooool0o`3VH`00o`<00?@_0039^@001H`0001>CP002R@000<J000L=000JCT0G:T0
0>5e003n2000mb800<nY000GT`0005A<000=9`000QT001L`001T?`1:Y000gH400?d<003i7000dil0
026G0000EdX000hX00026@005Bl0069204BR003LQ@00o0d00?TJ003DW@008iL0001GBP003RP0008I
000F;`00HT40Aj<00=f2003m3000nAd00=:R000LU@0005E;000=9`000QT001Ta001V?@1EY`00h7L0
0?h8003g9@00cJl000f?0000D4h000XT00036P007cH006dd06j_003UIP00o`800?<c0036`@0008H8
0010B0001b0000@L000Z?@00Mb@0UKT00>a>003o0000kDT009fk0000NB0002dn000470001R0003i7
00252@36`P00lc800?l3003TJ@00Ijd0001Z>00073<0008J000<9P00ED/089H00=BL003j5`00na80
0=RB000]V`0005U9000>:0000QT001Pa001W>`1NZP00hfh00?h4003d<000a/0000252@00?DH000HO
00047@00<D4007hH0;70003a?@00o`400>MP001b/00004De00026P0032L005I;02JH003FUP00na<0
0?XG003CWP006i@0001CC@002RD000<J000Q=`00LBh0QKD00>YC003o0000kD/009Bi0000MBP002Hj
00036`002B<0051>01FB003BX`00nAT00?/B003FU@009IP0001EB`002bH000<J000P=P00LBl0QKD0
0>]B003o0000k4h008bg0000Lb`0028h00036P002bD005A<02>G003FU@00na400?TK003@YP003Xl0
001<C@00228000@L000/?P00O1`0/<000?4j003o0P00i6X005bZ0000ICh001D^00026@0052d006=0
05RX003SK@00o`800?4i002``00007/M000[?@000a`000PR001?CP0FT`00dih00?/E003j6000dJ<0
012@0000C4d000PQ00047000<40007lF0<33003d<@00oPD00=mj0013XP0005e6000?:@000QT001dd
001_<P23]000je000?l0003YE`00M[40001[=`006C40008I000B:`00HD80E:L00>=]003o0P00l3d0
0:Bm0000Mb@002Di00036P002bH005M:03:L003LQ@00o@T00?D[0036`P00084B000a@00011`000PR
001@CP0JU000eYP00?`@00008P3h7`00c;8000280`00>dD000DN00068000ATX02hh00=6T003j5P00
nQP00=2X0007S000049900067`001Ah0041800B;003?ZP00nAT00?XE003AX`002hh00015BP001Ql0
00DN000oA`03R`00cjX00?TI003j5P00dJD000R=0000@dT200067`1b0012B@08S@00dJD00?XF003i
6P00cZ`000290000?4H000DN00078000Bdd05I800=FI003l3`00mb800<Vi0000P`d0039100047000
2B<005=<02ZJ003KQ`00oPP00?@`002h`P0007XO000V>P000aX000dW001LA`19Y000hVl00?l1003^
A000S[L0001_<@006S80008I000D;P00J3/0M;000>]C003o0000if4005fZ0000HD80010Z00026P00
8CL007LU0:bo003c=000oPL00=^6000YV@00059=00088P0011d003Q400290@3?Z`00nQL00?TJ003=
/00008H7000d@P0011`000TS001EB`0eW@00gg`00?l4003`?P00UkT0001`;`006S80008I000E;`00
JSP0PK@00>e9003a>@00@j80001IB@002bD000<K000`@000Q0`0bk@00?TL003j5`00cZd000271@00
=48000@L000:9000EdX0?J000>5d003o0@00kTP0086d0000JSP001@^00026@007C@007@Z0:Rn003c
<`00oPP00=V>000KU00004Y<0P001Ql0F`00C4d07YD00=Z;003n1`00lSH00:6l0000LRd001/c0002
6@005c0006hc09>h003`?@00oPD00=b4000VV00004m>000780001Ql004U<01^D003IS000oPL00?8g
002N^`00070_000I<@000QT001Xb001a;P2Q_000lcD00?d8003HT0005I800014BP001Ah000PQ001C
C@0cW@00h7P00?l2003]BP00N;40001V?@004B/0008J000V>P00OQP0b;`00?PN003j5`00c;800023
3`00;3d000<J000?:@00HT40KJh00>]@003o0@00hG@003JN0000Dd`000LQ00057P00Ad/079D00=^8
003n1@00l3l008Zf0000JSP001<]00026P0093T007dJ0<Rm003h7@00nQT00<^f0000P1@002Pk0002
6P004B/006Pk08>d003_@P00oP@00=^7000LU@002_ooool1o`00007ooooo000Nooooo`03o`000?oo
oooooooo00Oooooo05<0hf`00?h5003f:000cK0000n@0000DTd000/V00026P006C4006Dn04jU003N
O`00o@/00?TL003CW`008YL0001HBP003bT0008I000D;P00H4<0?J000=Z:003l4000nQH00=JF000]
V`0005]7000@:`000QT0018/001NA@0gWP00fHh00?/B003j5@00ei@002nK0000FdL0014[00026@00
4b`005i503ZO003JR`00o1000?XG003EV@00:9T0001IB@003bT0008I000E;`00HT40Aj<00=f1003m
2`00n1h00=6U000HT`0005=<000<9P000QX001/c001Y>@1PZ`00hfl00?h5003e;000bKP0006:0000
Ad/000PR00036`009CX007<[08Je003YE`00o`000>m1002]_`0007hI000c@@0200057P3F000gA000
PA80^L800?4j003o0@00if0007Ja0000KS80020f00036P002R@0055=01BB003AYP00n1d00?`=003K
R000>Il0001MAP004B/0008I000E;P00Hd00D:H00>1g003n1`00mRT00<Zh0000R@0004A:00078@00
11`002`m001j802Q_000kTD00?l0003YE`00P;@00019<`000aX000XU001BC@0JU000dil00?XH003k
4P00eiD002NH0000ET/000`V00026P007C@006dd07Na003XG000o`000>m2002S_@0007TP000[?@00
11`000PR001:C@0:SP00cZ`00?PO003l3@00fX/0036L0000FDT000dX00026P0073@006dd07Ja003X
F`00o`000>i5002L^`0007LU000W>P000a/000TS001AC@0HT`00dih00?XF003j5@00e9d001VD0000
DDd000TS00036`009c/007PT0:2l003_@P00o`400>IQ001Z[P0006Tj000H<@000QT0014[001P@`1:
Y000h7H00?h5003c<P00`<<000205@00<D0000@L00078@00BD`038h00=2W003i6P00na800=FJ000K
U000055=00098`000a/002Xm001k7P2``000lSP00?l3003RL000DJH0001Q@P004B/0008I000I<@00
JcL0MK000>UI003o0000k4l008Fe0000Kc4001dd00026@003bT005i504NS003PMP00oP@00?8e002d
`@0007/M000Z?0000a/000XT001CC00VV000fHl00?d<003g9000bKT000252@00=d<000@M00078000
BD`03i000=:Q003j5@00nAT00<nY0006S000049900067`001Ah003i7006:003>[@00nA`00?/C003C
W`004I00001:C0001b0000DM000iA000Q`D0bk<00?PO003l4000eIX001JB0000C4d000LQ00047@00
>4@008L60<^d003h7`00na400=BL000CT@0004Y<000780001Ah003]500290@3=[P00nA/00?/E003B
X`002Xh00013B@8000HO0<D004=900Z>003BX`00na@00?TL003=/00008L4000hA00011d000PQ001?
CP0NU@00f9400?d;003f:@00aL<0001n5`00:cd000<K000;9@00F4T0?:000=mi003o0`00lC`009fk
0000Lb/001he00026@004B/006@o06J/003XG000o`000>UH001[[P0006Dn000B;0000QT001dd001b
;02M^`00lC`00?h4003NO000=Yh0001FB`002R@000@L000b@@00Q0/0bk@00?TM003j5@00d:L000::
0000>dD000@M00088P00DDd0:9T00=b5003n1P00lSH00:Jm0000M2T001he00026@004b`006Hl07>`
003[D@00lS@0056V0000GDH000dW00036`00:Sd0080E0<Rm003g8P00na800=6S0004R`0003]50004
7@00228005=<036L003NO@00o`<00?10002@^00006hc000H<0000QT001Tb001`<02I^P00lC/00?h5
003LQ0009iT0001@CP001b4000DN0014BP0CT@00ei@00?d:003d;`00/L00001f9`007SD0008I000D
;P00JSP0Q;D00>i5003o0P00ggX003:L0000Dd`000PR00057@00@DP049000=JF003m2`00m2l00:fo
0000M2T001dd00026@005Rl006dd09:h003a?000oPD00=^7000QUP0004a=00067`001R0004m>02NH
003MPP00o`@00>m20027]@0006Xh000C;@000QT0028g001j8034a000mb@00?/B003?Z@0008L5000a
@0000a/000`W001OA01OZP00jEP00?l0003TJ`00@j80001GBP002B<000@M0010B00AT000ei800?h8
003b=`00VKX0001^<`005Rl0008I000O=P00NB80`/@00?LT003k4`00cZ`000242`00;Ch000<J000?
:@00I3l0M;000>e:003o0P00gWh002RI000:ooooo`7o00000Oooool001kooooo00?o0000oooooooo
ool01oooool0o`3QM@00o@P00?LQ003@Y`006Y@0001EB`003BP0008I000E;`00HD80@J400=^8003l
4000nQL00=JF000^V`0005]7000A:`000QT0014[001LAP0aW000ei@00?XE003k4@00fHd003ZO0000
Gd@001<]00026@0042X005Y802ZJ003EV000nQL00?`@003JRP00?:00001OA0004bd0008I000@:P00
FdP0;Y/00=NE003j5@00na800=R@000dW@0005a6000A:`000QT0018/001NA@0kW`00fXX00?`?003j
6@00e9`002>G0000EdX000hX00026@005c0006Dn05:W003PN000oPP00?LU003=[`002hh0001?CP00
2B<000<J000Q=`00Kc40Mk400>MP003o0@00lCT00;g30000PQ0003U400067`001Ad00350001m6P2Z
_P00kd800?l0003ZE`00Q;D0001b;00093T000<K00098`00CDh02Xh00<f_003g8`00o@T00=io0016
X`000653000C;@000QT0018/001OA012XP00gH400?d:003g8P00cJl000V=0000C4d000PR00036`00
9cX007DW09:h003/C@00o`000>a?002?]`0004db00036`002B<004m>00n@003@Z000n1h00?`>003J
R`00<id0001JB0003RT0008I000J<P00JCT0J:d00>EU003o0P00lCX00;?00000OQT0031000047@00
1b0004=90029003;]@00mRD00?d9003MPP00?J00001MAP0042X0008I000I<@00JCX0J:d00>IT003o
0@00l3d00:^n0000Nah002`m00047000228004a=00f?003@Z000nA`00?`@003GT`009IP0001EB`00
2bD000<J000R>000Lb/0TKP00>e:003o0000jEP007Vb0000KC@001/c00026@003bT005a703fP003M
P000oPP00?D[0037_P0008@<000gA0001Ah000HO0011B@01RP00cK000?PP003l3P00f90002NH0000
E4`000/U00036`009CX007LU0:6l003`@000o`400>EW001OZP0006Dn000D;P000QT001H_001W?01V
[000iV800?l0003^AP00U;T0001c:`008CL0008J000=9`00FTP0>Yl00=f0003n1`00m2h00<?40000
OaD002lo000470002280051>01ZD003EV000o1400?PN003=/00008T0000nA`001Ah000HO0011B@05
S000cjX00?TJ0000l`3k5000dj00012@0000BT`000LP00047@00>4@008H80<Zf003g8P00o0h00=JE
000LU@00051>00088P0011`003=100233P38_000mRH00?d<003HT@008IH0001AC@00228000@L000b
@@00PPl0b;`00?HU003l3@00ei8001jE0000D4h000PR00047000=D8008D:0<Zg003h8@00o1000=FJ
000ETP0004]=000780001Ah003a6002:003>[000nAT00?XF003@Y`001H`0000oA`001Ah000HP0019
C00CT@00eIX00?`@003g8P00bKX000233P00<D0000@L00098`00E4`0;i/00=f2003n1P00lc@00:fo
0000Mb@0028h00026P003bT0061305RX003UI@00o`000>a?001j/P0006Ti000E;P000QT001Tb001^
<P2>]`00kd@00?l2003QL`00@Z80001IB0002bH000<K000/?P00P1@0akd00?LS003l4000dih000b>
0000@TT000DN00078000CDh07ID00=R?003m2@00m2h00;K10000N28002<h00026P0042X0069106B/
003XFP00lbl005jZ0000HD8000lY00036P009CX007/M0<;4003f:000o0d00=FJ000>S`0004990005
7P001b40051>02FH003KQ`00oPH00?8h002O_000078]000K<`000QT001H_001/=P29]P00kd<00?l3
003ON`00<id0001DC000228000@M000mAP08S@00dih00?`>003f:000`<<0001j7`008cP0008J000A
:`00ISd0MK400>a=003o0@00hW4003jP0000ETX000TS00047000>TD01H`00=>O003l3`00mRP00;g3
0000NB80024g00026@004bd006Ti08>d003^A000o`<00=im000]V`00055=00078@001Ah004Q;01^D
003JR`00oPH00?4j002F^@0006hc000G<0000QT001dd001f9`2e`@00mB/00?`>003CW`000h/0000g
A00011`000/U001KB01AYP00iV400?l0003VHP00D:H0001JB0002RD000@L000iA006S000e9/00?d<
003d;`00Z;h0001b;@006C80008I000L<`00M2T0/l000?DZ003l3`00dJ<000280P00<d4000<K000=
9`00H4<0IZ`00>]C003o0@00hG@003BM000:ooooo`7o00000Oooool001kooooo00?o0000oooooooo
ool01oooool0o`3NO`00o@`00?TK003DW@009YP0001IB@0042X0008I000C;000GDD0=9d00=RB003k
5000na800=V=000jW`0005m4000D;@000QT000lY001HB@0UV000e9d00?TJ003l3@00g8<004JS0000
HT4001H_00026@003RP005I;01nF003BX@00nAd00?d<003MP@00B:@0001S@0005Rl0008I000>:000
EdX08YL00=>N003i6P00o0h00=^60010X@000613000D;@000QT0010Z001JB00^V`00ei<00?/D003k
4`00ei<002nK0000FdP0010Z00026@0052h0065204FS003MPP00o@/00?PO003@YP005Y80001BC@00
2bD0008J000M=000JcL0JJd00>AY003o0`00lc400<K00000QPL004180007800011`002`m001i8P2J
^P00kDX00?l0003/CP00TkT0001g9@00:C`000@L00078@00ADX008T00<Zh003e:P00oPH00>5e001D
Y`0006@o000F;`000QT0010Z001LA`0fWP00fXX00?`>003i7000dJD001BB0000DDd000XT00036P00
8SP0074^08>d003ZEP00o`000>i6002N^`00058`00047000224004M;00F<003</@00mb@00?d:003M
PP00?j40001NA@004B/0008I000F;`00ICd0FZT00>=^003o1000lc<00<?40000PQ0003I300057P00
1Ql003a600252@37_P00mB`00?h6003PN@00BZ@0001P@`004R`0008I000E;`00ICh0FZT00>=]003o
0`00lSH00;_20000OaH0035100047@001b0004A:00>;003</@00mb800?d<003JRP00<I`0001HB@00
3BL0008J000N=@00Kc40P[@00>YC003o0000je0008Ne0000LBl001lf00026P003BL005Q9036L003J
R@00o@/00?LT003;]@0008P3000nA`001Ql000DN000jA@00QPL0bKT00?HV003m2P00fhL003>M0000
F4T000`W00036P008CL007</096h003]B000o`000>MN001][P0006Tj000G<0000QT001</001S@01H
Z000i6/00?l2003`?P00Y;d0001g90009CX000<J000;9@00ET/0;Y/00=Z9003m2P00mRL00<Rl0000
Q0`003E300047@001b4004Y<00n@003BX@00nQD00?XH003@Y`002Hd00015BP001R0000DN000kA@00
Q`@0bk<00?PP0000I`3l3`00eYH001^D0000D4h000PR00047000<T40088@0<No003f:000o@X00=Z<
000XV@0005=<00098`000a/002dn001o5`34a000mB`00?d9003KQ`00;I/0001EB`002R@000<K000/
?P00OQL0`l@00?D/003m2@00fXT002ZJ0000E4`000TS00037000;cl0080C0<K0003f9`00o@`00=R@
000PUP00051>00088P0011`003E30025203;]@00n1l00?/A003CWP003i000016B`001Ql000DN0011
B008S@00dJ@00?/D003i7000c;4000271@00=d<000@M00088P00DDd08iL00=V<003m2@00m2d00;c3
0000Nad002Lk00036P003BL005a604ZT003SKP00o`400>i70029]P0006dd000H<@000QT001H_001Z
>01o/`00k4`00?l0003TJ@00D:H0001MA@003BP000<J000W>`00O1`0`/@00?DZ003m3000ei@001NC
0000BD`00P001Ql06P00ADX04Y400=FH003l3@00mRP00<G40000OA/002Lk00036P003RP005m405JX
003VH`00mB/006f^0000ICh0014[00026P008CL007LT0;?0003d;`00o@X00=RA000IU00004Y<0P00
1Ql0KP00BD`06I@00=R@003m2@00m3000:no0000MRL001lf00026@004bd006Pk07^b003]B`00o`40
0>9a0010X@0005M:000:900011`003I300290@3@Y`00na<00?LQ0037_P0007hH000X>`000aX000lY
001R@@1W[@00jUH00?l0003UJ000Bj@0001JB0002bD000<K000d@P00R0@0cjT00?/C003g8P00a/00
001m6P009CX0008J000A:`00ICh0M;000>a=003o0@00hG@003VO0000E4`000PR00057@00@4P04900
0=NE003m2P00lc800:Fm0000LRd001Xb00026@006S80078]0:Fm003c<P00o@X00=JF000>S`0003i7
00047@002B<005M:04BR003TJ`00o`000>UI001NZP0005i5000<9P000a/003=100280P3AY@00o100
0?HX002h`P0007HV000M=0000QT001Pa001`;`2S_@00lc400?d;003EVP001hd0000iA00011`000/U
001LA`1HZ000j5/00?l0003TJ`00@:402_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo
00Oooooo0?l0fhP00?`@003j5P00ei@003:L0000GDH0018/00026@0042X005Y802RI003DV`00nAX0
0?`=003LP`00Aj<0001S@0005c00008I000=9`00ED/06I@00=2V003h8000o@T00=mj001DY`0006Hl
000I<P000QX000`V001BC@0DT@00cjX00?LS003m2000h7P005JX0000Ic`001Tb00026P0032H005=<
01NC003@Y`00n2000?d:003NO@00CJD0001T?`005c00008I000>:000EdX08YL00=BM003i6@00o0l0
0=Z9000kW`0005i5000B;0000QT0018[001MA@0hWP00fX/00?`?003j6@00e9d0026F0000ET/000dW
00026@006C4006Lk05^Y003RLP00oPH00?DZ003:]`000HX00017B`00228000<K000V>P00M2T0RkH0
0>]C003o0000kTH00:>l0000Nah002ho00047@001R0003i700252@36`@00m3400?l4003SK000HJ/0
001X>P006C80008I000=:000F4X0:YX00=ND003k4P00nQL00=BL000OUP0005A<000;9P000QX001he
001]=01e/000iel00?l1003`?P00[[l0001G;@0011d000HP0010B000Q`@0bKX00?DZ003n1P00h7P0
04bU0000HT8001<]00026@004bd0069204fU003PN000oPH00?D/0038_@0008H7000mAP001Ql000DN
000e@`00PA80`L@00?<c003o1000hVl005RX0000I3l001D^00026@004R`0065204bU003PM`00oPD0
0?@^0036`@0008<=000hA0001Ah000HO000mAP00Q`H0bKX00?HX003m2000gH4003fP0000G4H000lY
00026@006S8006/f07>`003XG000o`000>i7002F^@0007DX000T>@000aX000/U001DC00UV000ei80
0?`?003h7P00cZ`000J<0000ADX000LP00047@00=480088@0<G2003d;@00oPL00=im000oX@0005a7
000>:@000QX001dd001_<P22]000je400?l0003ZE@00Nk80001]=@006c<0008I000@:P00Gd@0Bj@0
0>5d003o1000lSH00;?00000Nad002Xm00036`002B<0059=02:G003GTP00o0h00?PQ003;/`0008P3
000lAP001Ah000HO0012B@05S000cj/00?TK003k4`00did001BB0000CDh000LQ00047@00=48008<=
0<Rl003f9P000?<0o@/00=V=000WV@0005=<000:90000a/002`n001n6@2o``00m2l00?h7003MPP00
=9d0001GBP002bD000<K000X>`00NQh0]<400?<c003n1@00gWh003VO0000F4T000`V00036P009c/0
07XO0;C1003c<`00oPH00=eo000fWP0005M:000;9@000a/002Tl001l6`2m``00m2h00?h8003KQ`00
;9X0001DC0002B<000<L000_?`00PA40akh00?HU003l3@00ei@001ZD0000CTh000LQ00057@00>TD0
08T10<j]003i6@00nQL00=2X0003R`0003e700057P001b0004a=01RC003FU@00o0d00?HV0036`000
07lE000/?P000a/000/U001HB@0mX000h7L00?l3003`?`00V;X0001a;P0073@0008I000C;@00IS`0
L:l00>YD003o0000if0005fZ0000HD8000lZ00026P008SP007PS0;;0003d<@00o@P00=Z;000RU`00
051>00078@001Ah003i700N=003BXP00na800?LQ0038^`00084B000/?P000a/000`V001KA`19Y000
hf`00?HW001k/P0006Tj000D;@000QT001dd001c:`2S_@00lSH00?h6003KQ`0099P0001@CP001b40
00DN0012B@0>S`00eIT00?`=003e:@00_l<0001j7`008cP0008J000@:P00I3l0K:h00>YD003o0000
iFP004fU0000FdL000/V00036`00<40008D:0<f`003j6000nA/00<^e0000PPl002dn00036`003BL0
05i505VY003WG`00o`000>MO001IZ@0005i5000=9`000a/002ho00233@3</P00nQP00?TL003:]`00
084B000Z?@000aX000hX001Q@P1V[000jUD00?l0003TJ`00AZ<0001HB@002R@000@L000jA@06S000
dih00?`=003e:`00]L40001f9P007SD0008I000F;`00KS<0U[T00?4i003n1`00fHd001RC0000ADX0
00DN00088@00Dd`0=ih00>5d003o0@00je0006b^0000HT4000hX00036P00;Ch008@<0<j^003k5@00
mb800<G30000NQl0024g00026@005Bh006`e09Bi003a>@00oPL00=RA000BT@00041800047@002B<0
05Q904ZT003VI000o`000>IR001=Y@002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo
00Oooooo04<0f9800?/E003k4@00fX/003jP0000HD<001D^00026@003RP005I;01bE003AY000n1l0
0?d9003ONP00E:L0001W?0006S80008J000;9@00DDd03Xl00<f_003f9`00oPH00>9a001QZ`0006Xh
000M=0000aX000XT001?CP09S@00bk<00?HY003n1@00hfh006>/0000JcL001dd00036P002R@0051>
00b>003=/000mRH00?h7003QM000FjT0001X>`006S80008J000<9P00Dd`05i<00=2V003h7`00o@/0
0=f00018X`000691000E;P000QT000lY001JB00/VP00ei@00080na@001T0ei@002fK0000FTP000lY
00026@005Rl006=004fU003ON`00o@T00?LT003=[`002hh0001?CP002B<000<K000R=`00L2l0OK<0
0>QL003o0@00l3h00;;00000OaH003A2008000DN01d003M400214@2l`P00lSP00?l2003VH`00Kjl0
001/=@007C@0008J000<9P00E4`07YD00=BM003j5`00na800=NC000ZVP0005Q:000=:0000QT001Xb
001Y>@1V[000iFP00?l2003b=P00_L<0001L:`0200057P30000iA@00P`d0aL<00?<a003n1000hVl0
05ZY0000ICh001H_00026@004B/005i5042Q003MP@00o@T00?LU003;]0000HX00014BP001b0000@L
000_?`00OAX0//000?4k003o0P00iFH006F/0000J3X001Pa00026@0042X005e603nQ003MP000o@P0
0?HX0039^@0008L4000nA`001Ql000DN000f@`00PPl0aL800?@_003n1@00h7L004ZT0000H4<0014[
00026@005c0006Lk06F/003UI@00o`400?0o002V_@0007TQ000Y?0000a/000TS001AC@0JU000e9`0
0?/D003j6000dJ<0012@0000CDh000PR00047000;Sl007hH0;W2003c=000oP@00>5d001<Y@000613
000A:`000QT001Tb001[=`1d/000jEX00?l0003/C@00R[H0001a;`007SD0008J000>:000FdL0?Z00
0=im003n1P00m2l00<?40000OaD0031000047000228004m>01NC003DW000na<00?TK003?Z`001H`0
0013B@001Ql000DN000kAP00R0@0bk@00?PQ003l3`00ei@001nF0000DDd000TS00047000;Sl007lF
0<C4003d;@00oPP00=b4000cW@0005M:000;9@000a/002Lk001i802__`00lSH00?h4003ON@00@:40
001KA`003BL000<J000S>000MRH0YKd00?4k003o0`00hG@004JS0000G4H000hX00026P008SP007HV
0:Bm003a>`00o`<00>1f0013XP0005]7000=9`000aX002Di001h8P2^_`00lSH00?h5003NOP00>9h0
001GBP002bD000<K000Z?000OAT0`L@00?D/003m2@00fX/002FH0000DTd000PR00047000=48008D:
0<^f003h7`00na800=>O000=S`0004E:0P001Ql0/@00A4X03Hl00=>N003k4@00n2000<Zh0000P`d0
0391000470002B<005E;036L003MP@00oPD00?8g002W_@0007DX000P=P000QX0014[001S@@1RZ`00
j5d00?l0003YE`00Jjh0001U?P004R`0008I000N=@00M2X0Xk`00?8h003n1@00gH8002jK0000Dd`0
00PR00047000>4@008P20<n[003j5`00nA/00<bb0000Q@X00391000370002R@005M:03bP003PMP00
mb<008Zf0000K3D001L`00026@006C8006la09Bi003`?P00o`@00=in000`W00005=<00088P0011d0
03]500B;003BX`00na400?LS0037_`0007hH000X>`000aX000hX001P@`1NZP00j5`00?l0003WG`00
FZT0001OA0003BP000<J000[?@00PA<0bKT00?PN003j5P00cZ`000261P00<T4000<K000;9@00FTP0
C:D00>EX003o0000jUH006J]0000HT4000lY00036P00:C`007lE0<Vj003h7P00nQH00<f^0000Q@T0
031000036`0032H005e505RX003WGP00o`000>IR001CY`0005a7000;9P000a/003=200280`3@Y`00
na800?LT0034a00007XO000R=`000QT001<]001Z>027]@00kd400?h4003LP`0099L0001=CP001Ql0
00HP001@CP0[VP00gWd00?l2003^B000N[80001V?@004B/0008J000X>`00P1@0b[L00?TJ003i7000
bKX0001n5`009SX0008J000B;000J3X0QKD00>m1003n1@00fhL001fE0000Ad/000DN00088P00ED`0
?J000>=]003o0000jET005^Y000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0o`3DV`00nAX00?`=003MP@00Bj@0001T?`006340008J000<9P00DTd04Y400<j]003f9P00oPH0
0>9a001RZ`0006/g000N=@000aX000TS001=CP04R`00b[P00?@]003o0`00iFL006n_0000KS80024g
00036`00228004Q<00290038_000m3000?l3003UI@00LK00001_<P008CL000<K00098`00BD`00XX0
0<Vi003e;@00oP@00>AZ001Y[@0006`f000N=@000aX000XT001@CP0=S`00cJl00?LU003n1`00h7L0
05FW0000ISd001Pa00026@003BL005I;026F003CWP00nAT00?`?003JR`00>Il0001MA@004B/0008I
000C;@00Gd@0@:400=b4003m3000n1h00=6V000FTP00059=000;9@000aX001he001/=@1^[`00iV@0
0?l2003b=P00`/@000233P00>TD000HO00057@00<D0007dJ0:bo003`@000o`000>UJ001n/`00070_
000Q=`000aX000XT001AC@0CT@00d:H00?TM003l3P00fXX003JN0000G4L0010Z00026@005c0006Hm
05VY003RL@00oP@00?@_0036`000064X00067`001Ad003=1001o5@2h`@00lST00?l2003UIP00Ijd0
001Y>@006S80008I000>:@00FTP0<id00=Z:003l3@00n1l00<n[000;SP0004]=00088P000a`002Xl
001i8@2R_000kd<00?l0003XG@00Lk00001/=@0073<0008J000>:000FDP0<id00=Z9003m3000mb40
0<f`0004R`0004E:0007800011d00310001n5`2i`P00lSH00?l3003SKP00EjP0001T?`0052h0008I
000D;@00I400EjP00>=^003o0`00lSL00;G10000OAX002ho00047000228004a=00n@003AY@00nAT0
0?/C003EVP006i@0001AC@002B<000<K000Y?000NR00Z[h00?4l003o0P00i6/005ZY0000I40001<]
00026@005Rl006Ll06J/003VHP00o`000>i4002I^P0007DY000S>0000aX000`V001GBP0bW000fhL0
0?d9003f:000b;d000243000=T<000@M00078000B4/038l00=6U003j6000nQH00=:Q000@T00004Y=
00078@0011d003E200233@38_000mRL00?d;003JR`00:YX0001EB`002R@000<K000Y?000Nad0]<40
0?<d0000l`3n1@00ggX003nQ0000FdP000dW00036P008SP007DW0:2l003`?P00o`800>9`001=Y@00
05i4000?:@000QX001le001b;02F^@00kd<00?l1003TJ`00DjL0001P@`0042X0008I000N=@00LRd0
UKT00>m3003o0@00hfd0052V0000Gd@000lY00026P0083H007@Y09nk003`?@00o`<00>5d0014XP00
05]7000=9`000aX002Dj001i8@2b`000lc<00?h6003MPP00<I`0001EB`002R@000<K000^?`00PA<0
akh00?HU003l3@00eYH001RC0000C4d000LP00057P00?DL00h/00=2X003j5P00nAX00<f_0000R0@0
03Q400047@002280055=02FH003JRP00o@P00?@`002f`@0007TQ000T>@000aX000hX001OA01EY`00
iFH00?l0003/C`00NK80001Y>P005Bh0008I000J<P00L300U;T00?10003o0`00h7P003ZO0000EdX0
00XT00037000<T4008@;0<^d003i7000nQH00<nY0000R@4003Q400047@002B8005=<032L003NO`00
n20009Rj0000L2l001Xb00026@005Rl006/f08Fe003^AP00o`800>5e000mX00005M:000:900011`0
03E20027103>[000nQH00?TM003:]P00088?000]?P000a/000`V001LAP1AYP00iFD00?l0003ZEP00
J:d0001S@@003bX0008J000V>P00O1/0a/800?LT003k4@00dJ<000::0000>4@000@L00098`00EdX0
?j400>9a003o0@00k4d007F`0000ISd0014[00026P0093T007/M0<G3003g9000na400=6U0000R@00
03I3000470002RD005Y804^T003UI`00o`000>UI001PZ`000613000=9`000a/002hn0024303=/000
nQL00?PN0038_00007hH000V>P000QX0014[001V?@1h/@00kDT00?l2003ONP00;i/0001AC@001b40
00HO001:C00OUP00fhH00?h5003`?`00RKH0001Z>0004bd0008I000S>000O1`0akl00?PP003j5`00
c;4000223`00:cd000<J000@:P00ICh0Mk400>e9003o0P00gWh002RI0000CTh000HO00078000DDd0
<I`00>1g003o0@00je0006V]000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0o`3AY000n2000?d9003PN000F:P0001X>P0073<000<J000:9000Cdh01hd00<Zf003e;000o`@0
0>EX001`[`0006lb000R>0000a/000PR0015BP00Q`@0a/400?<e003o0P00ieh007jc0000LR`002Hj
00036`001b40045800252@34a000lSL00?l1003XG000P;<0001c;0009SX000<K00078@00@TT008H7
0<K2003c=000o`800>IQ001g/@00070`000R>0000a/000PR0019C002R`00b[P00?D/003n1@00hfh0
06>[0000JSP001`c00026P002bD0059=01JB003@Y`00n1l00?d;003MP@00AJ<0001Q@P0052h0008I
000@:P00G4L0=9d00=V>003l4000nQP00=BL000QUP0005I;000=9`000QX001Xb001Y>P1PZ`00hfd0
0?h4003d;`00akh000271@00@DP000LP00047000;3d007TQ09fk003^B000o`000>]A002<]`0007@Y
000V>P000a/000PR001<C@09S@00cJl00?LS003m2P00gH0004>R0000Gd@0018/00026@0052d00691
04^U003ONP00oPL00?HX003:]`0006HU0007800011`002hn001k7@2X_P00l4000?l0003XG@00MK40
001]=0007C@0008J000<9`00ETX09iT00=ND003k4@00nAT00=:R000ETP00051=00098`000a/002Di
001e:02C^@00kD/00?l0003ZE@00P[@0001`<00083H000<J000<9P00ET/09iT00=NC003l4000nA/0
0=2W000>S`0004e>00088P000a`002/m001j7`2Z_P00l3h00?l1003UI@00IJ`0001X>`005c00008I
000A:`00H4<0BZ@00>1g003n1@00m3000<C40000PA8003A200047@001b0004A:00F<003>[P00n1l0
0?`?003HT@009YP0001EB`002bD000<J000T>@00MRL0VkX00>m4003o0000iV8006N]0000Ic/001H_
00026@004bd006=005RX003TJ`00o`800?4l002X_P0007TR000W>`000a/000XT001DC00VV000f900
0?`=003g8P00bk@000280`00?4H000DN00067`00@4P00XX00<f^003h7@00na400=FH000JU000051>
00088P0011`002lo001o5@34a000m2h00?h7003MPP00=Yh0001HB@0032H000<J000T>@00MbD0YKd0
0?4l0000l`3o0`00hW4004bU0000GT@000lY00026P007SD0074^096h003^AP00o`400>EW001JZ@00
0691000A:`000QT001/c001^<P27]@00kD/00?l0003VHP00H:/0001T?`004R`0008I000J<P00KS<0
Q[D00>e;003o0000iV@005fZ0000HT40014[00026@0073@0070_092h003^A@00o`400>A[001AYP00
05m4000?:@000QX0024g001e:02S_000lC/00?l4003PN@00?J00001IB@0032H000<K000Y?000OA/0
`<<00?D/003m2P00fH`002>G0000DDd000PR00047@00=d<008L50<b`003i6`00nQD00=2V0005S000
03i700057P001b0004e>01ZD003GT`00o@`00?HY0035a00007dI000Y?0000a/000`V001KA`18X`00
hVl00?l1003^A`00R;H0001]=0006300008I000G<000K3H0QKD00>i8003o0@00hVl004JS0000FTP0
00`V00036`00;3h0080C0<Rl003g8P00na400=:P0008S@0003m700057P001b40051>02BH003KR000
nAh00:Rn0000M2T001he00026@004bd006Lk07Na003/CP00o`000>A[0019Y00005Y8000;9P000a/0
02lo00233@3;]@00nA`00?XG003>[P0008H7000c@@000a`000XU001IB@14XP00hfh00?l1003/CP00
M[40001V?0004R`0008I000Q=`00N280^/800?DZ003l3@00eIX000b>0000?dL000DM00088P00Dd`0
<Yd00=mj003o0P00kTD008>d0000JCT001@]00026@0083H007LT0;S1003e:`00o0d00=BL0009S@00
03a600047@002B<005I;03jP003RL000o`400>]@001^[`0006=0000?:P000aX002Pk00205@39^@00
nA`00?XI003;/`00088?000[?@000aX000hY001R@@1Z[P00je800?l0003RL@00?:00001EB`002280
00DM0012B@0DTP00f9000?h7003b>000V;X0001^<`005Rl0008I000O=P00N2<0_/<00?HV003k4P00
d:P000261P00<40000<K000=:000HD80JJd00>]A003o0@00hGD003BM0000DTd000LQ00067`00C4d0
9IP00=f0003o0`00kDP007Na000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0o`3>[@00mRH00?h6003RK`00IZ`0001/=@007cH000<K00098`00B4/008T10<No003c<`00o`80
0>MO001n/`0007</000W>P0011`000LP000nA`00P`d0_<800?4l003o0000jUH008bg0000MRH002/m
000470001Ql003Y500214P2e`@00l3l00?l0003ZE000S[L0001g9@00:cd000@L00068000>dH0088?
0;[2003a?000o`000>UI0025]@0007@Z000W>P000a`000LQ0012B@00Q`H0a/000?<c003o0P00iVD0
076_0000KS<0020f00036P002R@004m>00^>003=/000mbD00?h8003PN000DZL0001U?P005c00008I
000>:000F4T0:9T00=JG003j5@00na<00=NC000/VP0005U9000?:@000QT001L`001U?P1CY`00h7H0
0?h7003f:000bkD000>;0000B4`000PR00036`009c/007DX08ng003[D000o`000>e9002K^P0007PR
000[?@0011`000LQ0014BP00R@00b[P00?DY003n1`00h7L0052V0000Hd0001D^00026@004B/005i5
03nQ003LP`00o@/00?LR003=[P001F`W00088P000a/002Pk001g902I^P00kDP00?l0003ZE@00Q;D0
001a;P008CL000<J000;9@00Dd`079D00=BM003j5P00na@00=FI000PUP0005A<000;9@000aX0024g
001a;P25]@00jU<00?l0003/C000T;P0001d:P0093T000<K000:9000DTd079D00=BL003j5@00nQH0
0=>N000IU000055=000990000a/002Hj001f9P2K^P00kTH00?l0003XG000Lk00001[=P006c80008I
000?:@00G4H0?Z000=f0003n2000mBT00<Rl0000Q@T003Y500057P001Ql003e70027103:]`00mbD0
0?d;003KR000<Y`0001HB@003BL0008J000P=P00LRd0S;L00>a<003o0000jET007Fa0000JcH001Xb
00026@0042X005m404^T003QM000oP@00?8e002g`@0007dJ000/?P000a`000TS001@C@0KU000eIT0
0?/B003i7000cZ/000F<0000@dT000HO00057P00>TD008H60<Zg003g8`00o0d00=R?000VV00005=<
000:90000a/002Xl001k7@2d`@00lcD00?h4003PN000@j80001LA`003RP0008J000P=P00Lb/0U[T0
0>m40000BP3o0@00iFP005VY0000HT40018[00026@006S8006dc08:d003/CP00o`000>MN001X[@00
06Hm000D;P000QT001P`001Z=`1i/P00jU<00?l0003YFP00KZl0001W>`005Bh0008I000G<000JSP0
N;400>YC003o0000j5/006^^0000IS`001@]00026@006C4006`e086d003/C@00o`000>IR001OZP00
06=0000A:`000QT001dd001a;P2D^@00kd800?l2003RL000BZ@0001MAP003BP000<J000T>@00NB80
/L000?<c003n1P00g8<002nK0000E4`000TS00047000<D0008<>0<Vi003g8@00o1000=BM000?T000
04E:0P001Ql09@00ADX03i000=BL003l4000mb800<Rk0000PA4002ho00036`002RD005M:03^O003P
N000o`<00?0o002F^@00074_000K<`000QT001@^001X>P1g/@00je000?l0003UIP00DjL0001NA@00
3RP000<J000W>`00O1/0a<@00?HX003l3@00eYL001>A0000AT/00P001Ql0P000BTd06I@00=RA003i
7000]l40001h8P008SP0008J000@:P00Hd00JJd00>UG003o0000iV<005JX0000GTD000dX00036P00
:S`007lF0<Nm003g8@00na800=6U0002RP0003U4000470002B<005E;03NN003PM`00o`800>i60024
]@0006Xh000E;P000QT001dd001d:@2[_P00lc400?d9003HT@005Y<00016B`001Ah000LP001@CP0W
V000g8<00?h5003`?@00T[P0001]=0005c00008I000L<`00Lb/0Z;h00?<b003m2@00ei<001>A0000
@dT000DN00088@00Ddd0<Y`00=mi003o0P00kTP007bc0000Ic/0018/00026P0093T007`L0<K1003g
8P00na@00<nZ0000QPL0035000036`0032L005i505fZ003XFP00o`000>EX0018Y00005Q9000:9000
11`003]600Z>003EV@00o@/00?@a002W_@00078]000I<P000QT001/c001d:P2__`00mB`00?`=003C
W`000XX0000f@`000a/000/V001MAP1KZ@00jEX00?l0003SK000@:40001EB`00228000DN0015BP0J
U000fXT00?h5003`@000QKD02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo
0?l0b[H00?D/003o0`00iFH007>`0000L30002@i00036`001b40045800242P30``00lC/00?l0003Z
EP00SKL0001g9@00:cd000@M00067`00=d@007lF0:fo003_A000o`000>a=002K^P0007XO000`@000
1Ad000DN000d@P00OAX0Y[d00>i7003o0000kD/009fk0000Nah0031000057@001Ah003E2001n5`2[
_P00kd<00?l0003[D000U;T0001h8`00;3d000@L00067`00>dH008<?0;g3003a>P00o`400>QL001o
/`00078]000T>@000a/000PR0018B`01RP00bKP00?D/003n1@00hVl0062[0000JCX001Xb00026P00
32H005A<01fE003CX000nAX00?`?003JRP00>9h0001MAP004B/0008I000D;@00HD80AZ<00=f0003m
2P00mb800<j/000=S`0004m>00098`000a/0028h001a;P20]000jET00?l0003_@@00Z[h0001l6`00
<40000@M00067`00?DH008D90<K0003d<000oP@00>=^001MZP0006Ll000H<@000QT000lY001JB00c
W@00fH`00?`>003i7000dJH000Ya9`002B<000<K000T>@00Lb/0RkH00>]A003o0000k4`009:h0000
MBP002Hj00036`002B<004m>016A003AYP00nA/00?`?003HT000;9X0001HBP003BL0008J000M=000
KC@0M[400>QL003o0000kd@009nl0000N2<002Pl00036`002B8004m>016A003AY@00nAX00?/A003G
U@0099P0001EB`002bD000<J000R=`00LR`0S;L00>a>003o0000jU@0086d0000Kc4001he00026P00
3BL005Q9036L003JR@00o@`00?LS003;/`0008T00010B0001Ql000DN000g@`00P`d0akl00?D[003n
1`00gWl003jP0000G4L000lY00026@0073@006hc07jc003ZE000o`000>]A0023]00006la000M=000
0QX000hX001LA`0nX000gWh00?h7003d;P00aL@000214`00<T4000@L00078@00Bdd049000=:R003j
5P00nQL00=:S000?T00004Y=00078@0011d003A200223`37_`00mBX00?d9003KQP00<I`0001GBP00
2bH000<J000U>@00Mb@0YKd00?4l003o0P00hVl004nV0000H4<0010Z00026@0073@006la08Rf003]
C0000?<0o`000>MO001W[@0006Hm000D;P000QT001L`001Z>@1d/000jUL00?l0003ZE@00M[40001Z
>0005c00008I000E;P00Ic`0Jjh00>QL003o0000je4007bb0000JcH001Pa00026@0052h006Hm06Z^
003XG000o`000>]B001i/P0006Xh000G<0000QT001H_001X>P1c/000jUH00?l0003YFP00K:h0001V
?00052d0008I000I<P00KC@0QKD00>e:003o0000iFL005NX0000H4<0010Z00026P0083H007DY0::l
003a>P00o`@00=mj000kW`0005Q9000;9@000a/002/m001o5P36`P00mRP00?d<003GU0006Y@0001=
CP001b0000DN000nA`05S000dJD00?/E003i7000c;<000252000=48000@L00098`00E4`0;i/00=f1
003n1@00lSL00:Fm0000MBT001lf00026@004B/006@o06V]003YF000o`000>QM001QZ`000691000@
:P000QX0028h001h8`2e`@00m2l00?d9003ISP007ID0001=CP001b0000DN0013B@0?T000eIX00?TK
0035a00007`K000W>`000aX000hX001P@`1KZ@00iel00?l0003YFP00I:`0001R@@003bX0008J000U
>@00Nad0`/@00?HX003l3P00e9`000b>0000@4P000DM00088@00DDd0;9X00=f1003n1000l3h009>h
0000KS8001P`00026@006S80070_09bk003b>@00oPH00=^8000QU`0004i>000680001Ql004Y<01^D
003IS000oPL00?8f002P_000074^000J<P000QT001Pa001_<@2I^P00lCT00?h6003JRP007YD0001:
C@001Ql000HP001?CP0VV000gH800?h4003`@000RkH0001[=`005Bh0008I000O=P00N2@0^l800?HX
003l3`00dZ4000::0000=d<000@L000;9@00FTP0CjH00>IS003o0000iel005FW0000G4L000/U0003
6`00=D<008X00=:R003l3`00mBX00;K10000MRL001dd00026@006300070`0:2l003c<`00o@X00=JF
000<SP0003a6000470002R@005U804jU003VHP00o`000>IS001=Y@0005U9000:900011d003i700n@
003GTP00oPP00?8i002D^@002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo
0180akh00?<c003o0P00j5d008:d0000M2X002Pk000470001R0003Y500204`2a`000kd800?l0003/
CP00Vk/0001k7P00<D0200057P1E000a@@00Nad0W[/00>a<003o0000kTD00:Zn0000OQL003I30005
7`0011d002ho001i8@2G^P00k4l00?l0003_@`00[;l0001o5`00=T<000DN00057@00;cl007XO09bk
003]C000o`000>i8002R_00007`L000a@0001Ad000DN000e@P00OQL0[[l00>m2003o0000jU<008fg
0000MRL002Tl000470001b00045800261`36`@00lc800?l3003UIP00KJh0001]=@007SD000<J000:
9@00DDd04Y400<nY003h8000o@/00=f10015XP000652000D;@000QT0014[001MAP0jW`00fXT00?`>
003i7000dJ<001RC0000DTd000/U00036P007SD006dd07:`003VH@00o`400?4i002i`P00080C000f
@`0200057P3o000g@`00PA80_L<00?8g003o0P00iFD006^^0000JcL001/c00026P003BL005M:02NI
003FU@00na<00?XG003DW@003gDV000;9@000aX001lf001_<@1l/`00jET00?l0003_A000XK`0001i
8@00:cd000@L00088@00BD`01hd00<f_003g8@00o@/00=^7000hWP0005]7000?:@000QT001Ta001Y
>@1Y[@00iV@00?l1003a?000[[l0001l7000;Sh000@L00078@00B4/01h`00<j^003h8000o0d00=Z<
000`W00005Q9000=9`000QX001he001^<P1m/`00jUH00?l0003]B`00T;P0001c:`008SP000<J000;
9@00ED/09YP00=NB003l4000nAd00<n[0009S@0004M;00078@0011`00350001o5@2o``00lc800?h5
003QMP00Bj@0001P@`004B/0008I000I<@00JSP0L:l00>QM003o0000kDP009:h0000Lb/0024g0003
6P0032H005Q903:L003KQ`00o@X00?HW0038^`0008D:000hA0001Ad000HP0014BP06S000cj/00?TL
003k4P00eIX001ZD0000D4h000PR00047000;Sl007hG0;o3003d<000oPH00=im000mX00005]8000=
:0000QX0024g001c:`2F^@00kd@00?l1003UIP00GJX0001S@0004b`0008I000I<@00JcH0NK800>YD
003o0000jUL007F`0000JSP001L`00026@0052h006Hm06J/003WG`00o`000>a=0024]@0006hc000K
<P000QT0018/001S@01MZP00iVD00?l0003]B@00R[H0001_<@0073<0008I000A:`00HT40GJX00>IT
003o0000kDX008Ne0000KS<001Xb00026@004b`006Dn06F/003WGP00o`000>]A001j/P0006Xh000G
<0000QT001H_001Y>@1g/@00je<00?l0003WGP00IJ`0001T?`004R`0008I000L=000LBl0TkP00>m2
003o0P00hW4004NS0000G4L000dW00036P009cX007/N0;[2003d;P00o@T00=Z;000UV000055=0008
8P0011d003Q400280`3=[P00nAX00?XG003?ZP0008T0000jA@0011d000PQ001@CP0SU`00fX/00?d8
003d<000]<40001i8P008cP0008J000?:@00H4<0FjT00>MQ003o0000jUD006j_0000ISd0018/0002
6@007SD007@Y00280:Jm003b=P00oPH00=b5000YV@00055=00088P0011d003a600F;003AX`00nQX0
0<Rk0000P1<002`m00036`0032H005a604jU003TJ000o`000>]A001b/00006Hm000B;0000QT0020g
001g902c`000m2h00?d:003GT`005Y800017B`001Ql000HP001>CP0PUP00fXX00?h7003b=P00X[`0
001b;@006c<0008I000F;`00KCD0SKL00?10003o1000gWl002fK0000DTd000LQ00057P00@TT04I00
0=JF003m2`00m2l00:no0000MBP001he00026@005Bh006/f08^f003_@@00o`@00=f1000YV@00051>
000780001Ql004Q<01^D003JS000oPL00?8h002I^P0006la000H<0000QT001`c001d:P2/_`00m2l0
0?d;003EV0002hh0000mAP0011d000TS001GBP13XP00hf`00?l0003ZEP00HZ/0001P@`003BL000<K
000_?`00QPP0cj/00?/C003g8`00aL@0001j80008CL0008I000E;P00K3H0TKP00?4k003n1P00fHd0
01JB0000@dT000DM00088P00ET/0@J400>A[003o0000jEX005ZY0000GDH000/U00047000=d@01H`0
0=BK003m2`00lc400::l00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o
0<74003a>`00o`000>YE002@^00007PS000]?P0011d000DN000d@P00O1/0X[`00>e:003o0000kTH0
0:Zn0000OaL003M300067`0011d002`n001g902?]`00jU@00?l0003`?P00^L8000223`00?4H000HP
00047000:C`007DX08Vf003YE`00o`000?4l002k`P0008<?000lAP001R0000@L000Z?000MRH0S[L0
0>YD003o0000l4000;700000P1D003M300067`0011d002lo001k7P2O^`00kDX00?l0003]B`00W;/0
001j8000;Sl000@M00067`00>TD0088@0;c2003a>P00o`400>QM001k/P00070_000R>0000a/000TS
001=CP08S@00c;800?HV003n1`00h7P005:V0000I3l001L`00026@003bT005Y802jK003GTP00na80
0?XG003EVP008iL0001FB`003BL0008J000J<P00JCT0I:`00>AZ003o0`00lc800<G20000Q0/003a6
00067`0011d00350001m6P2^_`00l3l00?l0003XG@00N;80001_<P007cH000<J000;9@00Dd`079D0
0=>N003j6000na800=ND000EN2D000dW00026P0073<006/f06j_003VHP00o`400?4l002``00007dJ
000`@00011d000LP0012B@00R@40b[L00?HW003n2000gWh004BR0000Gd@0014[00026@005Rl006Dn
05^Y003SK@00o`<00?<e002m``00080D000c@@0011d000HP0010B000R080b[H00?HV003m2@00g880
03bP0000G4L000lY00026@006S8006/g06n_003WG`00o`000>m3002N^`0007LT000W>`000a/000TS
001AC@0KU000e9/00?/D003j6000dZ8001>A0000Cdh000PR00037000;3d007/M0;30003a>@00o`80
0>=]001HZ00006=0000C;@000QT001D_001V?@1RZ`00iFD00?l1003_@@00XK`0001g9@009SX000<K
000:9@00E4`09iP00=R@003l3@00n2400<bc0000R@4003i700067`001Ah003e600280`3;]000mb40
0?`=003HT@009IP0001CC0002R@000<K000Y?000NQl0/<000?8h003o0`00hG@004ZT0000GTD000lZ
00026@007C@006la08Rf003/C000o`000>MN001Z[P0006Ll000E;`000QT001D_001W>`1[[P00j5d0
003c0?l0003/CP00Pk@0001^<`006c<0008I000A:`00HT40FJT00>EX003o0@00kTD009>h0000LRd0
01he00026P003bX005m4052V003SK@00o`800>m1002I^P0007<[000O=P000QX000lY001OA01?YP00
hfd00?l1003_@P00U[T0001b;@007SD0008I000@:P00HD80F:P00>EW003o0000kDT008Rf0000KS80
01Xb00026@004bd006Dm06V]003XF`00o`000>YE001b/00006Pk000E;P000QT001Ta001]=025]@00
kDX00?l0003UJ000E:L0001OA0003bT0008J000R>000MbD0Zkh00?8e003n1P00gH40032L0000ED`0
00TS00047000<T4008@<0<Zg003h7`00na800=:Q0009S@00045800057P001R0004]=01RC003GU000
o@`00?DY0033a00007dK000X>`000aX000dW001MAP1>Y@00i6X00?l0003/C@00O;<0001Y>@005Bh0
008I000K<`00L2l0UkT00?0n003o1000gg`003BM0000ED/000TS00047000=T<008L40<j/003j6@00
c;<000242`00<D0000<K000:9@00F4T0@Z400>9a003o0@00kDT0082c0000JST001D^00026@007C@0
07<[0:Bm003b=@00oPL00=Z:000QUP0004i>000780001Al004I;01FB003GT`00o@X00?@_002``000
07HV000O=P000QT001@]001Y>P1o/`00kDP00?l2003PMP00>Il0001EB`002B<000@M000kAP07S000
dil00?`?003f:000_/<0001i8@008SL0008I000B;000J3/0OK<00>e8003o0P00h7P003FM0000Dd`0
00PR00057@00@DP04I000=NE003m2P00lc400:Rn0000Lb/001/c00026@006340070`09fk003b=P00
oPP00=R?000FTP0004A:00057P00228005=<03JN003QM@00o`400>a>001`[`0006=0000?:@000aX0
02Xm00224@3;/`00nQP00?PM0038_00007hI000U>P000QX0018/001X>P23]000kd800?h4003LQ000
8IH0001:C@001Al000LQ001BC@0eW@00hG@00?l1003[DP00J:d0001P@`003BL000<K000b@@00R0<0
dJ@00?`?003e:P00/L0000[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`0n
0;;0003_@P00o`000>a=002N^`0007`L000c@@001Ah000DM000^?`00NB80TkP00>]C003o0000l3h0
0;W20000P`h003e60007800011`002Lk001c:`21]000j5d00?l1003b=P00aL<000261`00@dT000PQ
00036`0093T0074^07Zb003WH000o`800?<d0036`@0008L60013B@001b4000<K000U>P00LR`0Ok<0
0>QL003o0@00lST00<330000Q0`003e70006800011`002Xl001g9@2@^000je800?l0003_@`00Z[h0
001n6@00<d8200057P1M000d@P00OQP0[Kl00>m1003o0000jUD008Vf0000M2T002Lj00036`002240
04E:00290@39^P00mBd00?h5003RK`00GjX0001X>P006S80008J000=9`00ET/08YL00=BK003j5`00
na800=RA000^V`0005U8000?:@000QT001L`001V?@1GZ000hG<00?h5003e:`00bKX000280P00@dT0
00LQ00047000;3d007TQ09nk003^A`00o`000>YD0027]@00078/000S>0000a/000TS001@CP0AT@00
d:L00?PM003l3P00fX/001Yl90003bT0008I000H<@00J3/0HJ/00>A[003o0`00lSD00;o30000PA80
03I300057P001Ql003]500252P36`000m2h00?h5003QM@00DJH0001S@@0052d0008I000C;@00HT40
CZD00>1f003n1@00m2h00<K00000Q0`003U5008000DN0;@003Y500242P37_`00mB`00?h6003ON@00
B:<0001P@`004B/0008I000G<000Ic`0HZ/00>EW003o0P00lC`00:fo0000Nad002`m000470002280
04e>012@003AY000nAT00?/C003EV@007ID0001BC@002R@000<K000W>`00N2@0XK`00>m1003o0@00
iV@006F/0000Ic`001H_00026@004b`0069105FW003SKP00o`<00?4i002__`0007/N000Z?@000a/0
00TS001AC@0LU000eIT00?/B003i6`00cjX000N=0000ADX000HP00057@00=d<008@;0<Rl003f:000
o@X00=^7000`W00005M:000;9P000aX002@i001f9P2Q_000l3l00?l2003TJ`00EjP0001R@@004R`0
008I000I<P00K3H0N[800>YD003o0000jUD007Ra0000JcL001Pa00026@004b`006@o05jZ003UI@00
o`400>i6002A^000078]000N=@000QX000lY001NA@1<Y@00hW400?l2003`?@00XK`0001f9`008SP0
00<J000=:000FdL0@j800>1f003o1000lCT00:Rn0000MbD002@i00036P003BL005]704>R003PMP00
o`<00?4k002T_@0007HW000R>0000QX000hX001MAP1;Y000hW000?l2003_@@00UkT0001b;@007SD0
008I000A:`00HT40G:T00>IT003o0000k4d0082d0000K3H001P`00026@005Rl006Ti07Na003[DP00
o`000>MO001QZ`0006=0000A:`000QT001he001c:`2L^`00l3d00?l3003PN000?:00001HB@002bD0
00<K000/?P00P1@0akl00?HU003l3P00eIP001BA0000B4`200067`2M0014BP0>S`00e9d00?`@003g
8`00b;d000204`00;Ch000<K000;9@00FDT0@Z800>5c003o0P00kTD008Zf0000KC@001Pa00026@00
5c0006`e08Rf003^A@00o`800>5c0010X@0005Q9000;9@000a/0031000233@3;]@00nQT00<nZ0000
R08003M3000470002B<005E;03FN003ONP00o`<00>m1002>]`0006dd000H<0000QT001Ta001_<@2F
^@00l3d00?h4003MP@00;9X0001BC@00224000DM000oA`0;SP00e9`00?`>003f:000_l<0001j7`00
8cP0008J000A:`00ICh0LJl00>]@003o0000hfd004FS0000FDT000XT00047000=D<008P20=2W003k
4`00mb800<No0000OAX002Hj00026P0042X006@o06n_003[D@00o`000>=_0011X@0005M:00098`00
11`003]500N<003CWP00o0h00?DZ002g`@0007LU000O=@000QT001D^001/=P2>]`00l3h00?h5003K
QP0089H0001;C@001Ql000LP001@CP0[VP00gWh00?l3003^AP00O[<0001W>`004B/0008J000U>P00
OQT0b;`00?PN003j6000bk<000224@00:S`000<J000@:P00I3l0MK000>e:003o0P00gg/002bJ0000
D4h000HP00067`00Cdh0:IT00=im003o0P00kDT007Fa0000I3l000lY00036P00;3h008@<0<j]003k
5000mb@00<33000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0eP2S_000
kDX00?l0003^A@00[Kl000205000>D@000HO00047000:C`007DY08Fe003XF`00o`400?8g0035`P00
08L60014BP00228000<K000S>000Kc40Lk000>EU003o0`00m2l00<Vj0001RP0004Y<00098`000a/0
020f001]=01][P00i6T00?l4003d;P00bKT000::0000BT`000TS00036`008CL006hb07:`003UI@00
o`<00?<a0037_P0008P40014BP00224000<K000U>P00Lb`0P[@00>UJ003o0@00lC`00;W20000PA40
03U500067`0011d002ho001j7`2N^`00kDT00?l0003/C@00V;X0001h8`00;3d000@L00068000?TL0
08D90<G2003c<`00o`800>EV001/[P0006`e000M=0000aX000/U001CC@0HT`00dJ@00?TL003l3P00
fhP003ZO0000GDH0014[00026@0052h0069104ZT003OO000o@P00?LU003</P001X`0001:C0002280
00<K000W>P00MBP0T;P00>a?003o0000k4`009Fi0000MRH002Pk00036`00228004Y<00N=003=/000
mb<00?d:003MPP00880S000A:`000QT001D^001T?`1DY`00hG<00?h5003d;P00akl000252@00?4H0
00HO00057P00=D80084B0;k3003b=@00o`<00>=/001NZP0006Hm000G<0000QT0014[001NA@12X@00
gWl00?d8003f9`00b[P000280`00@4P000HO00057@00=480084C0<33003c<`00o`@00>9a001EY`00
06=0000D;@000QT001@]001S@01EY`00hW000?l3003c=@00_<80001o5P00<D0000@M00078000AT/0
1X`00<j]003h7`00o0h00=R@000XV@0005I;000;9@000aX0028h001d:P2B^000kDT00?l0003XF`00
Lk00001[=`006S80008I000@:P00Gd@0B:<00>1g003n1@00lc800;k30000OaH00310000470002240
04e>016A003BXP020?XF003o0=:Q000AT@0004e>00088@0011`0035000205034a000m2h00?h7003N
OP00?:00001JB0003BP0008J000P=P00LR`0T[P00>i7003o0000iV8006B/0000ISd001@^00026@00
5Rl006Pk06b^003XG@00o`000>a=0026]@0006lb000L<`000QT0010Z001P@`1AYP00hfh00?l2003`
?P00X;`0001e9`008SP000<J000=9`00FdP0@:400=mj003n1000lSH00;300000NB0002Lj00036P00
2bH005Q903NN003MO`00oPH00?<b002f`@0007/N000X>`000a/000/U001HBP0gWP00gWl00?h6003c
<`00/l00001j80009SX000<J000<9P00FTP0?Z000>1i003o1000lCT00:Jm0000MRH0028g00026P00
3RT005i504nV003SK000o`400>i5002>]`00070`000K<`000QT001</001U?P1Y[@00j5/00?l0003Y
E`00Kjl0001W?00052d0008I000J<P00Kc40S[L00>i4003o0@00hW0004RT0000G4L000dW00036P00
9c/007`L0;o3003e;000o@X00=R?000NU@0004m>00078@001Ad003e600B;003AY@00na@00?PM003;
]00008@;000b@@0011`000XT001FB`0fWP00gg`00?l4003`?@00VKX0001a;P006c<0008I000D;P00
JCX0N[800>a=003o0000i6X004fU0000G4L000`W00036`00:cd0080E0<Nm003i6P00dZ4000N<0000
?DL000DM00088@00DDd0:YX00=b3003n1@00lCX009bk0000LBh001/c00026@005Rl006/f08Ne003^
A000o`800>1h000hWP0005E;00098`0011`003U4006:003AY@00na800?LR0037_`0007hH000X>`00
0aX000lY001Q@P1S[000jET00?l0003VI000DZH0001LAP0032H000<K000`@000Q0/0cK000?XH003i
7000b[L000214P00:cd000<J000>:000H4<0HJ/00>UI003o0000iFH004fU0000FTP000/U00037000
=48008P20=2V003k4P00mb@00<G40000Nah002<h00026P004R`006Pj082d003^A@00o`<00=im000/
VP00051>000780001Ql004Y=01nF003KQ`00oPD00?0n002<]`0006/g000D;P000QT0024g001j8035
a000mb<00?/C003?Z`0008H8000K000_?`000a/000dX001Q@P1W[@00je<00?l0003RLP00>9h0001C
C000224000DN0018C00NU@00fhH00?h4003_@P00Pk@0001X>`004B/0008J000W>`00P1@0bkH00?XH
003h7P00akh000[ooooo0Ol00001ooooo`007_ooool3o`0000Oooooo0?l0U;T00>]B003o0000l3d0
0;c20000Q0`003m800078@000a/002@i001a;`1g/@00iV<00?l3003d;`00bKX000:;0000Bdd000TS
00036P007cD006`f06F/003SKP00oPD00?HY003</P002hh0001@CP002R@000<J000L=000JST0GjX0
0>9a003n1P00mRL00<ba000<SP00051>000:90000aX001dd001[=`1T[000hfh00?h5003e:`00b[H0
00F<0000Bdd000TS00036`008CL006la07B`003VH`00o`800?<d0035`P0008D80010B0001b0000@L
000Y?000MRH0T;P00>]A003o0000kTD00:Jm0000O1/0035000057@001Ql003Q400214P2i`P00lC/0
0?l1003XGP00N[80001`<0008CL000<J00098`00Cdh03Hl00<j/003g8P00o@X00=eo0016X`000652
000C;@000QT0018/001NA@0nX000g8D00?d<003h7`00cjT0012@0000D4h000TT00036`008SP0074^
08:d003YE`00o`000>m4002S_@0007XO000]?P0011`000LP0013B@00R@40bKP00?DY003n1`00h7T0
02N48@0052d0008I000B;000H4<0Aj<00=il003n2000mRP00<Zg0000R@4004990007800011d002lo
001m6P2__`00lC`00?l1003VH`00Jjh0001Z>0006S80008I000>:@00FTP0=Yh00=^8003m3000mb40
0<f_0005S00004M;00078@0011`002ho001m6P2a`000lCX00?l2003UJ000HZ/0001W?0005c00008I
000A:`00Gd@0B:@00=mi003n1P00m2h00<K10000P`h003M300057P001Ql003m700280P3;]P00mb@0
0?d;003KQ`00=9d0001IB@003BL0008J000N=@00L300Q;D00>]A003o0000je<0086d0000Kc8001dd
00026P003RP005]703bP003MP000oPP00?D[0036`00008<>000e@`0011d000LP0015BP07S@00cjX0
0?TL003k4@00eIP001bE0000DDd000TS00036`00;3d007`K0;K1003b=@00oP@00>1f0018Y00005i5
000?:P000QT001`d001_<P24]@00k4l00?l0003YFP00LK00001Y>@005c00008I000C;@00I3l0GjX0
0>EU003o0@00kTD009Bi0000Lb`0020f00026P003RP005a604BR003PM`000?<0oP@00?8g002^_`00
07TQ000W>`000a/000/U001GBP0dW@00g8<00?h7003d;`00_l<0001m6@00;3d000<K000:9000E4`0
:iX00=^8003m2@00mB/00<G40000OaH002dn00036`002R@005A<02^J003KR000o@T00?D]0032a000
07hH000[?@000a/000XU001FB`0cW@00gH800?h6003c<P00]<40001j80009SX000<J000<9`00FTP0
@Z800>5e003o0`00l3d009fk0000Lb/001le00026@0042X0065205bY003VH`00o`000>a?001m/`00
06Xg000G<0000QT001L`001[=P20/`00k4`00?l0003UI`00EJL0001OA0003bT0008J000S>000N2<0
/<000?<b003n1`00fhH002VI0000DTd000PR00047000=d<008L40<f^003i6@00nQP00<j/0000R080
03Q400047@002280059=02ZJ003LQ@00oPH00?8f002W_P0007DX000O=P000QT0018/001U?P1][P00
jUH00?l0003VH@00FZT0001P@`003RP000<J000V>P00O1`0`l@00?TK003EV0004I000014BP001Ah0
00LP001>CP0OUP00fH`00?h8003c<`00Zkh0001e:0007SD0008I000C;@00J3/0NK800>a<003o0@00
hfl004BR0000FDT000XU00037000<d4008H70<j]003j5`00nA`00<Zg0000PQ0002dn00036`003BL0
05i505JX003WH@00o`000>QL001OZP000613000>:0000aX002Xm00214`39^@00n1d00?XG003=[`00
08D9000`@0000a/000`V001MAP1DY`00iV400?l0003XG@00FZT0001NA@003BL000<K000_?`00Q0/0
cJl00?XG003h7P00b;/0001o5`009c/0008J000@:P00I3l0L[000>a=003o0@00hG@003NN0000E4`0
00PR00057P00@dT05I800=R@003n2000lSL009^j0000Kc8001L`00026@007C@007HW0;K1003e:P00
o0l00=:R0000RP0003E200036`0032H005e605ZY003XF`00o`000>AY0014XP0005M:00098`0011d0
045801BA003HS`00oPL00?4j002A^00006`f000D;P000QT002<h001l7037_P00n1h00?XI003:]P00
2?ooool3o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l0Q[D00>QK003o0@00lSH0
0<K10000R0<004I;00088P000a/0020f001]=01Y[@00hf`00?h5003f:@00c;8000b>0000D4h000/U
00026P006c<006Pk05RX003PM`00o@P00?LR003?Z@005I80001CC00032H0008J000I<@00ISd0DZL0
0=mj003m2@00n2400=2X000FTP0005=<000<9P000QX001Xb001W?01GZ000h7H00?h8003g9000cZh0
00j?0000D4d000XT00036P007C@006/g06J]003TJ`00oP@00?@]0039^P0008T00017B`00228000<K
000U>@00LR`0P[@00>UJ003o0000l3d00;G10000P1@003M300057P001Ad00391001m6P2Z_P00kd80
0?l0003ZE@00R;H0001d:P009SX000<K00088P00BD`018/00<^e003f:000oPL00>1g001CY`0006@o
000F;`000QT000lY001KB00bW000fHh00?`@003i6P00dZ0001^D0000Dd`000/U00036P007SD006hc
07B`003WG`00o`400?4l002b`00007hH000b@@001Ad000HO000lAP00Q@X0a/400?@`003n1000hW00
02f87`005c00008I000@:P00GDH0>il00=b5003m2`00mb400<f^0008S@0004Y<00088P0011`002Xl
001i8@2Q_000kd@00?l0003XF`00NK80001^<`007CD0008J000<9`00EdX0:YX00=RA003l4000nA`0
0=2W000?T00004i>00088P000a/002Tl001i8P2R_000kd800?l0003WG`00Kjl0001[=`006S80008I
000?:@00G4L0?:000=f2003m2@00mRL00<Vi0000Q`D003e600067`001Ah003U400242`37_P00mB/0
0?h7003NOP00@:40001MAP003bT0008I000K<`00K3D0M[400>UI003o0000kD/008ng0000LR`0024g
00036P0032H005M:032L003JR@00o@/00?LU003:]`0008L5000kAP001Ah000HO000nA`00R@40c;<0
0?LQ003l3@00f8l002NI0000E4`000XT00036`009cX007PR0:Nm003a?000o`800>=]001EY`000691
000B;0000QT001Ta001[=`1f/@00jEL00?l0003[D@00Ok<0001]=0006c<0008I000A:`00H4<0DZH0
0>=^003o0P00l3d00:>l0000MRH002@i00036P0032H005U903RN003MP0000?<0oPH00?@`002m``00
07dI000/?@000a/000XT001DC00XV@00fX/00?d:003f:000akl000214@00<D0000@L00088P00DDd0
89H00=RA003l3000mbD00<Rl0000P`h00391000470002280055=022F003HT@00o@`00?HV0037_P00
088A000`@00011`000TS001CC00WV@00fXX00?d9003e;000`l@0001n6000:cd000<K000;9@00EdX0
=Yh00=in003n1@00lSH00:^o0000Mb@002<h00026P003RP005i504nV003SK000o`400>i7002;]P00
06hb000J<P000QT001@^001W>`1b/000jU@00?l0003WGP00HZ/0001S@0004B/0008I000O=@00M2X0
X[`00?4j003n1000gWd003FM0000ET/000XT00037000<D0008<=0<Zg003h7`00na<00=6S0007S000
03i700057P001b4004m>01nF003IS@00o@T00?@_002f`@0007TR000S>0000QX000lZ001Q@P1OZP00
ieh00?l0003YF@00Ijd0001S@00042/0008J000R=`00N2<0]<400?TL003HS`006i@0001;C@001R00
00HO0016B`0DTP00eYD00?d;003e;000^/80001i8@008cP0008J000A:`00I3l0K:h00>YD003o0000
iFH0052V0000G4H000`V00036`00;Ch0088?0<Zf003i7000nQL00<f^0000QPP0039100036`002bD0
05Y804ZT003TJP00o`000>YC001/[P0006=0000@:P000QX002Hj001m6P36`@00mb<00?/B003@YP00
08T1000f@`0011`000XT001IB@18X`00i6X00?l0003ZE@00Ijd0001R@@003bT000<J000Z?000P1<0
b[P00?TL003j6@00c;<000223`00;3h000<J000>:000HD80IJ`00>YE003o0000hf`004>R0000EdX0
00TS00047@00?4H02hh00=FI003m2`00m3000:Vn0000Lb`001Xb00026@006S80078]0:Nn003d<000
o@/00=FI0009S@0003]5000470002R@005U804fU003VH`00o`000>MQ001AYP0005Y8000:900011`0
03Y500Z>003EV000o@X00?<c002P_00006la000G<0000QT001le001h8`32a000mb@00?/D003>[P00
2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo07@0N;400>IS003o0`00m2l0
0<Vi0005S00004i>000:90000aX001`d001Y>@1LZP00hGD00?h8003g8`00cjT001JB0000E4`000`W
00026@00630006@o04bU003MP000o@/00?TM003BX@0089H0001FBP003RP0008I000F;`00HT40AZ<0
0=b3003l3@00nA/00=>O000QUP0005M:000>:0000QT001H_001S@01:Y000gWl00?d;003h7`00dJD0
01VC0000E4`000`V00026P006S8006Lk05VY003QM000oPL00?HW003</P002Hd0001>CP002B<000<J
000Q=`00Kc80M;000>IR003o0P00lSH00<C40000Q0`003e60006800011`002dn001i8@2L^`00kDX0
0?l0003/C@00U[T0001g9000:Sd000@L00078000@TT008L40<Nm003d;P00oP@00>=^001OZP0006Pj
000I<P000QT000dW001GBP0WV000eYL00?/D003k5@00eYL002FH0000EdX000dW00026P006c<006Xh
06N]003UJ000o`800?8e0031a000088@000hA08000DN0>L003I300214P2m``00lSL00?l2003UI`00
=8/M000J<P000QT000hX001IB@0_V`00fHh00?`?003i7000d:H001:A0000Cdh000TS00036`009CX0
07DX09>h003]C000o`000>]B0026]@00078]000Q=`000aX000/U001CC00OUP00eIX00?/D003j5P00
dih001VD0000DTd000XT00036`009CT007DX09Bi003]BP00o`000>UG001m/`0006hb000N=@000QX0
00dW001HB@0`W000fX/00?`<003g8@00cK0000>;0000A4X000LP00047@00<d40080C0<;4003c<@00
oPD00>5e001<Y@000613000A:`000QT001L`001X>P1Y[@00iV800?l1003_@`00WK/0001f9P009CX0
00<K000:9@00E4`09IP00=NB003l3`00n1l00<f_0003R`00049900067`001Ah003Q400252P38^`00
mRL00?d:003KQ`00<Y`0001HBP0032H000<J000R>000M2T0VKX00>m4003o0@00iV@006:[0000ICh0
01@^00026@005Rl006Lk06V]003WG`00o`000>e9002=]`00074^000N=@000QX000hY001MAP15X`00
h7L00?h4003b=P00/L00001j7`00:3/000<K000:9@00ED/0;I/00=^8003m2@00mBX00<K00000PA80
0350000470002280051>01fE003GU000o0h00?LR003:]`0008D9000f@`0011d000LQ001=CP0FTP00
eIX00?`A003h7`00bk<000271P00>4@000@M00078@00C4d05I800=FJ003l4000n2000<^e0000Q@P0
03I300047@00224004m>01bE003GT`00o0d00?HU0037_@00088A000`@00011`000TS001DC00[VP00
fhL00?h8003d;`00^/80001k7@009c/000<J000<9P00FTP0@Z800>5e003o0`00l3l009Vj0000LRd0
01dd00026@004R/006@o06F/003XG@00o`000>YF001_[`0006Ll000C;@000QT001/c001`<02C^@00
kd400?l2003QM@00@J40001IB@002bD000<K000/?@00P1D0akl00?LU003l3`00eIX0012@0000ADX0
0P001Ql0T`00B4`05I800=JF003l3@00mRP00<G40000OAX002Pk00036P003BP005i505:W003UIP00
o`000>]A001d/00006Ll000C;@000QT001he001d:P2U_@00n1h00=^7000VV000051>00078@001Ah0
03m800Z>003CWP00o0l00?HU0035`P0007dJ000W>`000aX000hY001P@`1OZP00j5d00?l0003XGP00
GJX0001P@`003RP000<J000X?000OQL0akh00?LR003k4P00dJH0002:0000>4@000@L00098`00EdX0
?Z000>5b003o0@00kD/007Vb0000Ic`0018/00026@008CL007TR0;c3003f:@00o0h00=BM0008S@00
03a600047@002B<005E;03^O003QL`00o`400>a=001e/00006Dn000A:`000QX002Di001m6`36`000
mb400?/D003?ZP0008H6000a@@000a/000`V001MAP1HZ000ieh00?l0003VH`00D:H0001KB0002bD0
00@L000f@`01RP00dZ400?`?003e:@00^<40001f9P007SD0008I000G<000KS80VKX00?8g003n2000
f90001>A0000@DP000DM00098P00ET/0@J400>=/003o0000jEP005jZ0000GTD000`V00036`00=480
08X00=:Q003l3P00mB`00:jo0000Lb/001Xb00026@006c<007@Y0;?0003e:P00o0l00=6U000:oooo
o`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`1[[P00hf`00?h5003f:000cK00
00j?0000DDd000/V00026P006C4006Hm04nV003NOP00o@/00?PM003BX@0089H0001GBP003RP0008I
000E;P00HD<0?j400=^8003l3`00nQL00=FH000[VP0005Y8000@:P000QT001<]001OA00jW`00fH`0
0?/A003j5P00eYL002bJ0000FTP0010Z00026@0052d0061303jP003KR000o0l00?TI003DW0008iL0
001GBP003RP0008I000G<000I3l0CJD00=im003m2P00n2400<nY000CT@00059=000;9@000aX001dd
001[=`1W[@00i6X00?l4003d;`00b;d000280`00@dT000LQ00047000:3/007DW08jg003[DP00o`00
0>i5002T_@0007/M000_?`0011d000HO000kAP00P`d0`l@00?8e003o0P00iFD006f^0000K3H001dd
00026P002bH005A<01bE003CW`00nAT00?`@003IS`00<I`0001JB0003bT0008I000G<000ISd0FZT0
0>9`003n1@00m2h00<Nn0000QPL003i70006800011d00310001m6P2^_`00l3h00?l1003WG`00>XlJ
000M=0000QX000`V001FB`0TV000eYL00?/C003j5`00e9d001bE0000Dd`000/U00036P008CL0074^
08Fe003ZE000o`000>e:002D^@0007DW000V>P000a/000TS001@CP0ETP00dZ800?TI003k4P00eYD0
02BH0000ED/000/V00036P0083L0074^08Je003[DP00o`000>a?002;]P00078/000Q=`000aX000/U
001EB`0UV000ei@00?`@003i7000d:P000f?0000Bdd000PQ00047000;Ch007dK0;?0003b>000o`<0
0>=]001IZ@0006@o000D;P000QT001D^001U?P1LZ@00i6X00?l2003a?000Zkl0001j7`00:S`000<K
00098`00DDd06Y@00=BK003k4`00nAX00=2V000<S`0004U<00078@0011d0039100214P35``00m2h0
0?h7003NOP00?Z00001KA`003RP0008J000N=@00LBl0R[H00>e<003o0000j5`006n_0000JCT001L`
00026@004bd006=005bY003UJ000o`400>m2002K^`0007DX000R>0000aX000dW001IB@0iW`00gGl0
0?h7003d;`00`<<0001n5`00;Ch000<L00098`00DTd08YL00=RA0000l`3l3@00mb<00<Vh0000Q@T0
03M300047@001b4004]=01>A003DW@00na800?TM003=[`0008T0000mAP001Ah000HP0016BP0<SP00
dZ<00?XE003i6P00cj/000:;0000?dL000DN00067`00ADX02hh00=:R003k5@00nA/00<j]0000R@00
03a600057P001b0004U<01:A003DW000na400?PO003;]@0008D8000f@`0011d000PR001@CP0PUP00
f9000?d;003f:@00aL80001o5P00;3h000<K000:9@00EdX0=ih00=im003n1@00lSP00:Nm0000MRL0
024g00026P003bT0061305RX003UI@00o`000>a>001m/`0006Xh000F;`000QT001Pa001/=@25]@00
kDT00?l1003SK000CJD0001MAP003BL000<J000W>`00O1`0`<<00?D[003m2`00f98001^D0000CDh0
00LP00057P00@DP02hh00=>O003k4@00mb800<Rl0000P1<002`n00036`0032H005Y804JS003RK`00
o`400>e90022]00006/g000F;`000QT001Xb001`<02G^@00mb400=in000aW00005A<00098P0011d0
03U5006:003@YP00na@00?PP0039^P00084B000/?@000a/000`W001MAP1BYP00iFD00?l0003ZE@00
JZh0001S@00042X0008J000T>@00Nah0`L@00?HX003l3P00e9d000Z>0000?TL000@M00088P00Dd`0
<Y`00=mk003o0`00kd<008Ne0000JcL001D^00026@007SD007DX0:jo003d<000o@X00=NE000BT@00
049900057P002240059=032L003ON`00o`<00>i50022]00006Ti000C;@000QT0024g001i8P2n``00
mRL00?`@003BXP000XX0000g@`0011`000XT001JB01;Y000iFH00?l0003XF`00G:X0001NA@0032L0
00<K000a@000QPL0cjX00?/C003g8`00aL<0001j7`008SL0008I000D;@00JSL0RkH00?0o003n1@00
fhL001jE0000B4`000DN00078@00Ddd0=Id00>5e003o0@00je0006^^0000HD8000hX00036`00;cl0
08H80<nY003k4P00mRH00;g30000MbD001he00026@006300070_0:Bm003d<@00o@`00=BL000:oooo
o`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0E01NZP00hG@00?h8003g8P00d:P0
01RC0000ED/000dW00026@005Rl0069104>R003KQP00o0l00?XH003EV000:iX0001JB00042X0008I
000B;000GDH0=9d00=RA003k5000na<00=R?000fWP0005e5000B;0000QT0014[001KA`0^V`00eiD0
0?XE003k4P00fHh003NN0000GTD0018/00026@004B/005a603>M003HT@00na<00?/D003GU000;Y/0
001KB00042X0008I000D;@00H4<0@J400=b6003l3@00nA/00=:Q000MU@0005E;000<9`000QX001Tb
001W>`1JZ@00hG<00?h6003f:@00bkD000F<0000Bdd000TR00036`008cP0078]082c003YFP00o`00
0?0n002b`00007lF000e@P8000DN0;<003E3001o5@2d`@00lC`00?l1003XG@00N[80001`<0008CL0
00<J000:9000D4h04Y400=2X003h7P00o@`00=^6000lX00005i5000A:`000QT001D^001R@@1=Y@00
ggT00?h7003f:000b[H0006:0000ADX000LQ00047000:cd007TQ0:2l003^AP00o`000>YF0011TaP0
024g00036P002RD0059=01ZD003CW`00nQP00?/B003GU0009iT0001FB`0032H0008J000M=000KC<0
Mk400>QL003o0000kd<00:>l0000NB4002Xm00047000228004]=00^>003?Z`00n1h00?`>003IS@00
;i/0001HB@003BL0008J000M=000KC@0N;400>UJ003o0000kTL009Vj0000MRH002Hj00036`002R@0
055=01ZD003DW000nQD00?XF003CW`005i<0001@CP002B<000<K000Y?000NB80Y;d00?10003o0@00
iV@006J/0000Ic/001L`00026@004R`0065204nV003QL`00o`@00?<d002j`P0007hH000_?`0011`0
00PQ001<C@0@T000dJ<00?XH003k5@00dih001JB0000Cdh000PR00047000;Ch007dJ0;S1003c=@00
oP@00>5e001:Y00005m4000@:P000QT001/c001]=01m/`00jU@00?l0003ZE000OK<0001]=0006S80
008I000A:`00H4<0CjH00>9`003o0`00lCX00:Zn0000NB8002Lj00036`002bD005I;02jK003KR000
o@X00?HY0037_`00088@000c@@0011`000PQ001?CP0GT`00eIX00?/A003h7P00cK0000290@00?DH0
00DN00067`00A4X02Hd00=6V00020?XG000G0=2V0008S@0004=900067`001Ah003m700:;003>Z`00
nAX00?XE003BXP0038h00015BP001Ql000DN000nA`02RP00cj/00?TI003j5P00dJD000V=0000@dT0
0P001Ql0]000@TT028d00=6U003j5P00nAX00<j/0000R@0003a600057P001b0004]=01FB003EV000
o0l00?LS0039^P0008<>000a@@0011`000TS001CC00[VP00fhH00?h7003d<@00]/40001j80009CX0
00<J000=:000GDH0Bj@00>=^003o0@00kTH008^f0000KS<001Tb00026@005Bh006Tj07Ra003[D@00
o`000>IS001IZ@000613000?:@000QX002<h001h8`2a`000lc400?h8003JR@009IP0001AC@002240
00@M000kA@01RP00d:P00?XE003i7@00bk@000242`00<T4000<L000:9000EdX0>Yl00>1h003o0`00
kd40092h0000KS8001Ta00026@005c0006`e08Vf003g9000hGD003fP0000EdX000XT00047000<d80
08H70<f_003j6000nAX00<bb0000Q@X0035000036`002bD005U904FS003SKP00o`400>a=001h/@00
06Ll000C;0000QT0020f001g9@2c`000m2h00?d;003GU0004i400015BP001Ah000LP001@CP0WV000
g8@00?h5003a?000UKT0001_<P006340008I000J<P00LBh0Wk`00?8f003n1`00fH`001bE0000BD`0
00HO00068000Cdh09IP00=b4003n1@00l3h0092h0000KC@001H_00026@007C@007DX0;30003d;P00
o@`00=FI000;SP0003e700047@002B<005I;03nQ003SK`00o`000>]C001Y[@000691000>:@000aX0
02/m00223`3</P00nQP00?PM0038^`0007hH000V>P000QX0014[001W?01m/`00kTH00?l3003NO`00
:9T0001?CP8000HP01P004m>02ZJ003NO@00o`800>e8001h/@0006Dn000@:P000aX002Xl0022403<
/P00nQL00?PP0036`@0007/N000R=`000QT001D^001]=02F^@00lSL00?d8003GU00:ooooo`7o0000
0Oooool001kooooo00?o0000ooooooooool01oooool03@1AYP00gWd00?d;003i7@00dil002>G0000
F4T000lY00026@004bd005i503NN003HS`000P3k4`00o`3HS`00=ih0001NA@004bd0008I000@:P00
FDP0:IT00=FJ003j6@00o0h00=^70012X@000652000E;P000QT000hY001HBP0SU`00e9d00?TJ003l
3P00g8D004>R0000HD8001D^00026@003bT005U902NI003EV@00nQP00?`@003JR`00>Yl0001NA@00
4R`0008I000A:`00GDH0=Id00=V>003k4@00nQH00=FH000XV@0005Q9000>:@000QT001H_001T@01=
Y@00gg`00?d9003g8`00cZ`000n@0000D4h000XT00036P007cH006hc07:`003VHP00o`800?8g0031
a00008<>000kA@001Ql000@M000`@000O1`0Y[d00>m4003o0000jUD008Rf0000Lb/002Di00036`00
228004a=00R=003=/000mb@00?d9003NO@00B:@0001Q@P0052d0008I000B;000Gd@0@J400=f2003m
2P00mb800<f^000:SP0004a=00088P000a/002Hj001e9`2B^000k4d00?l0003/CP00B9LE000U>P00
0a/000TS001?CP0?T000d:P00?PM003l3P00fH`003:L0000FTP000hX00026@006S8006Xh06Z]003V
I000o`400?4k002a`00007dJ000_?`0011`000LP0014BP01RP00bk<00?LT003m2P00g8@003^O0000
G4L000lY00026@006C8006Xh06^^003VHP00o`400?0o002W_@0007XP000Z?@000a/000PR001>CP0@
T000dJD00?TJ003k4P00eYL0026F0000Dd`000XU00036P0093T007DX09Ji003^A`00o`000>QL001c
/00006/g000J<P000QT0010Z001MA@13XP00gg/00?h6003d;P00aL8000224000=48000@M00078000
ADX01X`00<j/003i7@00o1000=JE000PUP0005==000:90000a/002Pk001i8@2Y_P00lC`00?l2003S
K000EZP0001R@@004R`0008I000H<000JCT0Kjl00>QL003o0000kD`008Zf0000L2l001he00026P00
3RT005a604>R003ON@00oPD00?<c002h`P0007`K000[?@000a/000TS001BC@0SU`00f9400?`=003g
8`00b[L000261`00>4@000DM00078000B4/03Hl00=:S003j5P00nQP00=2X0007S@0004=900067`00
1Ah003i7002:003=[P00nA`00?/C003CWP004Y40001:C@007P001b0000DM000iA000Q`H0bk@00?PO
003l4000eIX001JB0000CDh000LQ00047@00>4@008L60<^c003h7`00na400=BL000CT@0004Y<0007
80001Ah003a60029003>[@00nAX00?XE003AY0002Hd00012B@8000HO06P004A:00b>003BX@00na<0
0?TM003</P0008L6000g@`0011d000PR001@CP0PUP00f8l00?d:003e:P00a<@0001m6@00:S`000<K
000;9P00FDT0?j400>1f003o0`00l3l009Vj0000LRd001dd00026@004R`006Dn06Z^003YF@00o`00
0>QK001V[00006@o000A:`000QT001le001d:@2S_000lSP00?h5003MP000<9`0001DC0002B<000@L
000e@P00QPL0cK000?TJ003j5`00cZ`000280P00=d@000@L00098P00Dd`0;i/00=f0003n1@00lCX0
09jk0000LRd001`d00026@0052h006Tj07^b003f9`00hfd004VT0000FdP000/V00036`00;Sl0088?
0<Zg003h7P00nQD00<nY0000R08003I3000470002B<005I;03ZO003PMP00o`800>i50025]@0006/g
000E;`000QT001`d001c:`2U_@00lcD00?h7003JS0007YD0001<C@8000HO05X004Y=01bE003IS@00
oPP00?<e002S_@00078/000K<`000QT001L`001]=02A^000l3h00?h4003LP`009iP0001?CP001b00
00HO0018C00JU000fHd00?h7003b=P00W[/0001`;`006C40008I000J<P00LBh0XK`00?<d003m2000
f94001FB0000A4X000DN00088@00Dd`0=9d00>1g003o0P00kD/007Na0000ICd0014[00026P009cX0
07lG0<Vk003h7@00nQP00<^c0000PQ0002/m00036P003bT006=0072_003/CP00o`400>1f000dW@00
059=00078@001Ah004U<01nF003KQP00oP@00>m10026]@0006Tj000B;0000QX002Dj001n6039^P00
nA`00?TK0039^00007lF000V>P000QX0018/001Y>@28]P00l3l00?h5003JR`0:ooooo`7o00000Ooo
ool001kooooo00?o0000ooooooooool01oooool0o`15X`00fhH00?`?003j5`00eYL002jK0000G4L0
014[00026@004B/005]702bJ003EV000nQP00?`?003KQ`00@Z80001R@P005Rl0008I000>:000ET/0
7YD00=:R003h7P00o@/00=in001>Y@0006Dn000H<@000QT000`W001DC00IT`00dJH00?PP003m2P00
gW`004nV0000ICh001P`00026@003BL005E;01fE003BXP00nAd00?d<003MPP00AZ<0001R@@005Bh0
008I000?:@00FDT0:YX00=JG003j5P00na800=R?000cW@0005a7000A:`000QT001<]001P@`11X@00
g8@00?`<003i7@00dJ@001VC0000Dd`000/V00026P0073<006Xh06F/003TJ`00o`@00?@`0037_P00
08L50011B0001b0000@L000[?@00N2<0V;X00>e<003o0000k4d009Fi0000MbD002Tl000470001b40
04A:00290039^@00mBX00?h6003QM@00E:L0001U?P005Rl0008I000@:P00FdL0=Yh00=Z;003l3P00
nA`00=6U000DT@00055=000:90000aX0028h001b;@24]@00jUD00?l0003^A`00CiXA000Z?00011`0
00PQ0018C006S000cK000?LS003m2P00g8<003fP0000GDH0010Z00026@005c0006Hm05fZ003SK@00
o`<00?<d002o``00084B000e@P001Ad000HO000mA`00QPH0b;/00?DZ003n1`00gg/004NS0000Gd@0
014[00026@005Rl006Hm05jZ003TJP00o`800?8h002e`@0007hI000_?`0011`000LQ0017B`07S000
cZd00?PO003l3P00fHh002bJ0000EdX000`V00036P0083H0074^08Rf003/C`00o`000>YD0020]000
06la000M=@000QX000hX001JB00gWP00g8@00?d9003f9`00bKX000262000>TD000DN00067`00?TL0
08P20<^d003g8`00o@`00=V<000[VP0005I;000;9@000aX002@i001e9`2K^`00kd<00?l1003VI000
Hj`0001V?@005Bh0008I000E;P00ISd0HZ/00>IT003o0@00kd@009Rj0000M2T0028g00036P0032L0
05U903NN003MPP00oPL00?D]0035``00080C000`@00011`000PR001?CP0HT`00eIX00?/A003h7@00
cJl0002:0000?TL000DN00067`00@DP018/00<n[0000<P3i6`00na@00=>O000AT@0004Y<00078000
11d003M40026203:]P00mb800?`>003FU@0079D0001@CP00228000@L000c@@00P`h0b;`00?HU003l
3000f940022F0000DDd000PR00047000<T4008<>0<Rk003g9@00o0d00=NC000MU@00051>00088@00
11d003I300252@3;]@00n2000?/A003DV`004Y400019C0001R0000DN000mA`02R`00cjX00P3j6000
_`3?Z@000XX0000mAP001Ah000LP001;C@0FTP00eYL00?`>003g9000b;d000214@00;cl000<K000:
9000ET/0=9d00=io003n1@00lSL00:Nm0000MBL0020g00026P0042X0065205fZ003WH@00o`000>]C
001c/00006Lk000D;@000QT001/c001`;`2E^@00l4000?l3003PM`00?:00001HBP002RD000<K000_
?`00PPl0bKP00?PO003k4`00dJ<000J<0000?TL000DM00078@00D4h099L00=Z9003n1`00lc<00:bo
0000MRL0020f00026@004R`006Dn06j_003e:P00iV@005FW0000GTD000dX00036P00:C`007hG0<No
003g8`00na400=:Q0006S00003e600047@002280059=02jK003NO`00oP@00?0n002C^00006hb000H
<@000QT001Ta001_<@2F^@00lC`00?h5003LP`00:9T0001@C@001b4000DN0013B@0BT@00eYD00?d;
003d;P00//00001f9P007cD0008I000D;P00JSP0Q;@00>i5003o0P00ggX003:L0000Dd`000PR0005
7P00@DP049000=JF003m2P00m3000:bo0000M2T001`d00026@005c0006dc09>i003a?000oPD00=^8
000OUP0004]=00067`001b0004m>02RI003MP000o`<00>m30024]@0006Ti000C;@000QT0028h001k
7P35``00mb<00?/C003?Z`0008H8000`@0000a/000dW001P@`1SZ`00jUH00?l0003SK@00?j40001F
B`00228000DM0012B@0ETP00f8l00?h7003a>P00TkT0001/=@005Bh0008I000Q=`00NQl0aL800?LQ
003j5P00cK0000223`00:Sd000<J000@:P00ICh0Nk800>i6003o0`00gH8000[ooooo0Ol00001oooo
o`007_ooool00ol0003oooooooooo`07ooooo`3o03VO003ISP00na<00?/C003ISP00>Il0001OA000
52d0008I000?:@00EdX08IL00=:P003i7@00o@/00=in001>Y@0006Dn000H<@000QX000`V001CC00D
TP00cj/00?LS003n2000hGD005ZY0000J3X001/c00026P002bD0055=00n@003=[P00mRD00?h7003Q
M000FjT0001X>P006c<0008J000;9@00DTd04i400<nZ003g8P00o@T00=mj001BYP0006Dn000H<@00
0QT000dW001FB`0OUP00dil00?TK003l3P00fhL003jP0000Gd@001<]00026@004B/005a603JN003I
S@00o1000?XH003DV`008iL0001GBP003BL0008I000H<@00Ic`0FJP00>5c003n1P00mBT00<Zf0002
R`0004Q;00088P000a/002Hj001d:@2:]P00jU<00?l0003^A@00Xkd0001k7P00;Sl000@M00068000
?TL008D90<K1003d<@00o`@00>=/001QZ`0006Pj000I<P000QT000hX001HB@0ZVP00ei<00?/B003j
5`00e9d001jE0000E4`000/V00036P007SD006hc07Ja003XG@00o`400?0o001FWPh002lo00047@00
1b00045900280P39^@00mRT00?h7003ONP00BJ@0001Q@P004b`0008I000D;@00Hd40D:H00>5e003n
1@00m2h00<No0000Q@X003]500057`001Ah003M400223`35``00m3400?h4003QL`00DjL0001S@000
52d0008I000C;@00HT40DZH00>5c003n1000lc400<C40000PA4003E200057@001Ql0041800290@3;
]P00mbD00?d:003LQ@00=ih0001JB0003RP0008J000L=000KC<0Nk800>UG003o0000k4`008jg0000
Lb`0024g00036P0032H005M:02bJ003IS@00o0d00?LQ003</P0008T00010B0001Ql000DN000hA000
Q@X0b;`00?HX003m2@00g8@003JN0000FDT000dW00026P0083H0078]08fg003]B`00o`000>QL001`
[`0006Xi000H<@000QT0018/001R@@1FZ000hfd00?l2003a?@00Y[d0001h8`009SX000<K000;9@00
ET/0;9X00=Z:003m2`00mRH00<Rk0000Q0/003I300047@001b0004U<00n@003BXP00nQH00?XH003@
YP002Xh00015BP001R0000DN000jA@00Q`@0bk<0000g0?PP003l3`00eYH001^D0000D4h000PR0004
7000<T40088@0<Nn003f:000o@/00=V<000WV00005=<00098`000a/002hn001o5P35a000mB/00?d9
003KR@00:iX0001DC0002R@000<K000]?P00OaH0aL<00?D[003m2P00fX/002NI0000Dd`000TS0004
7000<400084A0<Nn003f9P00o0d00=NC000MU@0004m>00088@0011d003M400271P3</P00n1d00?/C
003BX@002hh00014BP0200067`2j0014BP0<S`00dj000?/B003h7P00bkD000252@00=48000@L0009
8P00DTd0:IT00=^8003n2000m3400;G10000NB4002Di00036P003RP005i5056V003TJ@00o`000>e;
0021]00006/g000G<0000QT001Pa001]=@27]@00kTL00?l1003SK`00B:<0001KA`0032H000<K000Z
?@00OaL0a/000?HU003l3P00e9/000n@0000A4X000DO00068000Bdd06I@00=NB003m2`00mB`00;[2
0000NR0002@i00026P003bX00652066[003d;P00j5`0066[0000HT8000lY00026P009CT007/N0<33
003e:@00o0d00=FH000@T00004=900057P001b0004m>02>G003KR000oPH00?8g002Q_000078]000K
<`000QT001H_001/=P29]P00kd<00?l3003ONP00<id0001DC000228000@M000mAP08S@00dih00?`>
003f:000`<<0001j80008cP0008J000B:`00ISd0M[400>a=003o0@00hW8003fP0000ET/000TS0004
7@00>dD01h`00=>N003l3P00mBT00;_20000N2<0020f00026@0052d006Xh08Je003_@`00o`<00=io
000ZVP00051>000780001Ql004Y<01jE003JR@00oPH00?4l002B^00006dd000F;`000QT001le001g
9@2i`P00mRT00?`?003BXP0008X0000e@`000a`000/U001LAP1FZ000ieh00?l0003UI@00Bj@0001I
B@002R@000@L000lAP0;SP00eYL00?d:003c<`00XK`0001`<0006300008I000M=000MRH0^/800?HW
003k4@00d:P000261P00;cl000<K000>:000HT40KJh00>a>003o0@00ggX02_ooool1o`00007ooooo
000Nooooo`03o`000?oooooooooo00Oooooo05l0;Y/00=JG003j6000o0l00=^60015XP0006=1000G
<0000QT000dW001DC00GT`00cjT00?LR003n2000hGH005^Y0000JCX001`c00036P002R@004m>00Z>
003</`00mBT00?h5003SK@00Ijd0001/=P007cD000<J00098`00CDh01X`00<Zf003e:`00oP@00>A[
001X[@0006`f000N=@000aX000XT001?CP09S@00c;<00?HX003n1P00hW4005jZ0000JCT001/c0002
6P002bD0059=01FB003@Z000n2000?d:003NOP00BZ@0001S@0005Rl0008I000?:@00FDT0:iX00=JF
003k5@00na<00=NC000^V`0005Y8000?:@000QT001H_001S@01<Y@00gg`00?d9003g8`00cJh000b>
0000Cdh000TS00036`008SL0070_07fc003XF`00o`400?0n002b`00007lG000d@P0200057P17000h
A000PA40_L<00?8h003o0P00iV@006j_0000K3H001dd00026P0032H005E;022F003DW000nQL00?/C
003GU000:9T0001GBP003BL0008J000K<`00JSP0JJd00>EV003o0P00lSP005fQ2P00=48000DM0006
7`00>dH008@;0<K1003d;`00oPD00>9b001FZ00006@o000E;`000QT0014[001OA014XP00gWh00?h8
003f9`00b[L000280P00@DP000HP00047@00<T4007lF0;S2003b=`00o`800>AZ001OZP0006Hl000G
<0000QT0014[001OA016X`00gg/00?h7003e:`00b;d000252@00>dD00P001Ah0f@00>TD008D:0<Nn
003e:`00oPL00=im0013XP0005i5000@:P000QT001Ta001Z>01^[`00iel00?l0003_A000W;/0001f
9P009CX000<K000:9000Dd`08IL00=JE003k4@00nA`00<nZ0009S@0004M;0007800011d003=10021
4P35a000m2l00?h6003ON`00@Z80001MAP003bT0008I000L=000KS<0P;<00>]B003o0000jU@007fc
0000KC@001/c00026@0042X005i404VT003QM@00oP@00?8f002d`@0007`L000[?@000a/000TS001B
C@0QU`00ei<00?`>003h8@00bk<000280`00?4H000DN00067`00@TT01H`00<nZ003i6`00na<00=>N
000CT@0004a=00078@0011d003E200243038^`00mRH00?d<003ISP009YP0001CC0002B<000<K000]
?P00OQP0`L@00?@^003n2000g8@003:L0000ETX000/U00036`00:C`007/M0;S1003c<P00oPH00=f0
000fWP0005M:000;9@000a/002Pk001k7@2h`P00lc400?h7003MPP00<Y`0001FB`002RD000<K000[
?@00OQP0`l@00?D/003m2@00fXX002NI0000DTd000TS00047000<T4008<>0<Vj003g8`00o0l00=FH
000ETP0004]=000780001Ah003e700>;003@Z000nQL00?TI003>[00008T1000jA@0011d000LQ001?
CP0NU@00f9000?d;003e:P00`l@0001m6P00:C`000<K000<9P00FTP0AJ800>9b003o0P00kd@008jg
0000Kc8001Xb00026@005Bh006Ti07Zb003/C`00o`000>EV001DY`0005i4000>:0000aX002Hj001k
7P2n``00mB/00?d;003GTP006I@0001;C@001R0000DN0014BP0?T000eIX00?`>003f9P00aL80001m
6@00:3/000<J000=:000GTD0E:L00?<c003ZE000KZl0001U?P004R/0008I000P=`00MbD0/L000?@`
003m2@00f90001ZD0000BT`00P001Ql0K@00BD`06I<00=R@003m2@00m3000:no0000MRL001lf0002
6@004bd006Pk07^b003]B`00o`400>9b000oX@0005M:000:900011`003M30029003@YP00na<00?LR
0037_`0007hI000W>`000aX000lY001S@@1Y[@00jU@00?l0003TJ@00BJ@0001IB0002RD000@L000e
@P00R@40d:L00?/B003g8`00aL80001l700093T0008J000A:`00ISd0N;400>e:003o0@00h7L003FM
0000Dd`000PR00057P00@dT059400=RA003m2000lcD00:2l0000L2l001Ta00026@006c<007<[0:^n
003d;`00o@/00=FJ0009S@0003]5000470002R@005U904ZT003UIP00o`000>QM001GZ00005a6000;
9P000a`003I300::003CX000o0h00?D/002__`0007@Z000K<`000QT001Xb001c;02/_`00m2d00?`=
003CX0000HX0000e@P000a/000`V001NA@1PZ`00jUH00?l0003RL@002_ooool1o`00007ooooo000N
ooooo`03o`000?oooooooooo00Oooooo0?l08iL00=>O003i7@00o@/00=im001AYP0006Hm000J<P00
0QX000/U001AC@0=S`00c;400?HX003n1@00hfd006N]0000K3D001lf00036P002B<004Y<006:0038
^`00m3000?l3003VI@00M;00001_<@008SP000<K00088P00AT/008P20<Nn003c<P00o`800>IS001e
/@00070`000R>0000a/000PR0018B`00RP00b;/00?@^003o1000i6T006^^0000K3D001le00036P00
2R@004m>00^>003=/000mRH00?h7003PMP00EZP0001V?0006C40008I000=9`00ET/089H00=>N003i
6@00o0l00=Z:000iW`0005e5000A:`000QT001<]001OA010X@00g8@00?d<003h7P00d:H001FB0000
DTd000/U00036P007SD006dd06n_003VI000o`800?8g0030``00088?000iA@001Ql000DM000b@@00
OQP0[kl00?0o003o0000j5`007^b0000L300020g00036P002R@0055=01JB003AY000nA`00?`?003I
S000<id0001KB0003bT0008I000H<000Ic`0GJX00>=^003o1000lc4006>T1P00>TD000DO00057P00
=D<0084B0;g3003b=P00o`<00>AZ001RZ`0006Pk000H<@000QT000lY001LA`0iW`00fhH00?d;003g
8P00cJl000J<0000B4/000LQ00047000;3h007/N0:Zn003`?`00o`400>IR001/[P0006Xh000J<P00
0QT000lY001KA`0jW`00g8@00?d:003g9@00bkD000290000@DP000HP00057@00=480084B0<?4003c
<@00oP@00>5d001?Y@000652000B;0000QT001H_001V?@1QZ`00iFL00?l1003`?@00Z[h0001j7`00
:S`000<K00098`00D4h05i<00=>N003j5@00nQL00=:R000BT@0004i>00088P0011`002dn001m6P2g
`@00lSD00?l4003QL`00CZD0001P@`004B/0008I000I<@00JSP0Lk000>QJ003o0000k4`008^f0000
LBl001le00026P003RP005]703jP003NO@00oPH00?@_0033a00007lE000`@00011`000PR001?CP0G
T`00e9/00?/B003i6`00cj/000F<0000@TT000HO00057P00?4H008P30<bc003h8000o0l00=JE000M
U@00055=00088P0011`002lo00205035``000?<0mB`00?d8003LQ@00<9`0001FB`002bD000<K000X
>`00NQl0/l000?<d003n1@00gg/003fP0000FTP000`W00036P0093T007PT0:Vn003b>@00o`@00>1g
0011X@0005]7000=9`000aX002@i001g902Z_P00lSP00?h4003ONP00?Z00001IB00032H000<J000W
>P00NQl0]<400?<b003n1P00gH8003:L0000ET/000XT00036`00;Ch007lF0<K2003f:@00o@/00=R@
000OUP00051>00088@0011d003M400271@3</@00nA`00?/D003AY0001hd00010B0001Ah000HP0019
C00DTP00eIT00?`>003g9000akd000214P00;Sl000<K000:9@00EdX0>Il00=mj003o1000lC`009bk
0000LR`001dd00026@004R`006Dm06f^003ZE`00o`000>MN001PZ`000691000@:P000QX0028g001g
902``000lc800?h8003JRP0099L0001@CP001b4000DM000mA`06S000dZ<00?/B003h8000bKX00021
4P00;Ch000<K000<9P00FdP0B:@00?4g003/C000Nk80001Y>P0052h0008I000M=000Lb/0Xkd00?8f
003n1P00fhL002BH0000D4h000LQ00057P00@TT03i000=FI003l3@00mBX00;g30000NR0002<h0002
6P004B/006@o06j_003[DP00o`000>AY001;Y00005Y8000;9@000a/003500025203=[P00nQL00?TL
003:]`00084A000/?@000aX000dX001OA01LZP00j5d00?l0003WH@00EJL0001MAP0032H000<K000`
@000Q@X0cJl00?XG003h7P00bKX0001o5@00:C`000<J000?:@00Hd00Jjh00>]B003o0000hfh0046Q
0000EdX000TS00047@00?4H02Xh00=FJ003m3000m2h00:jo0000M2X001`c00026@006340070`09fk
003b=P00o@P00=RA000CT@00045900057@00228005E;03jP003SK`00o`000>YE001T[0000613000=
9`000a/0031000261P3@Z000na800?HV002n``0007LT000N=@000QT001L`001_<@2N^`00lc@00?d:
003FU`002Xh0000kA@0011`000XU001KA`1DY`00j5h00?l0003TJ@002_ooool1o`00007ooooo000N
ooooo`03o`000?oooooooooo00Oooooo0?l06I@00=2X003g8P00oPP00>5e001MZP0006Xh000M=000
0aX000XT001=CP04R`00bKT00?@_003o0`00iFD007B`0000L30002<h00036`00224004=900261`35
``00lSH00?l1003XG000PK@0001c:`009cX000@L00078000?dP008@;0<74003b>@00o`400>QK0022
]00007<[000V>P000a`000LQ0011B000QPP0aL<00?8e003o0P00if4007Ra0000L30002<h00036`00
228004U<00::0039^000mB`00?h5003SK@00Hj/0001Z>00073<0008J000;9@00DTd05Y800=2V003h
7`00o@/00=f20015XP000652000D;@000QT0014[001LAP0eW@00fHd00?`@003j6@00dih001nF0000
ED/000`W00026P006c<006Ti06>[003SK000o`@00?@`0037_`0008H7000oB0001R0000@L000]?P00
NQl0XK`00>i6003o0000jU@008Rf0000Lb/002@i00036`002B<004i>00b>003>[000n2400?d;003L
P`00?j40001NA@004B/0008I000E;P00Hd00D:H00>1f003n1P00mB/006BQ0P00@4P000HP00047@00
<40007dJ0:no003`?@00o`400>IQ001_[`0006/f000K<`000QX000dX001HB@0^V`00fHl00?`?003i
7000d:L0012@0000Cdh000TS00036`00:3/007LT09bk003^AP00o`000>UJ001i/P0006hc000M=000
0QX000dW001HB@0_V`00fH`00?`=003h7`00cZd000N=0000B4/000LQ00047000;cl007dI0;G1003b
>000o`800>=/001KZ@0006Dn000E;P000QT001<]001S@01EY`00hW000?l3003b=P00^<40001n6000
;cl000@L00088@00Bdd03Hl00=2V003i6P00na800=FI000LU@00055=00098`000a/002Tl001i8@2Y
_P00lC`00?l2003TJP00FZT0001T?`0052d0008I000F;`00Ic`0IZ`00>IR003o0000kT@009Rj0000
M2T0028h00036P0032H005Q:03:L003KQP00o@T00?HY0037_P0008<=000e@P0011d000LP0019C00=
S`00dJ@00?XG003j5P00dZ<000j?0000BD`000LP00047@00=T<008@;0<Rk003f9P00o@/00=V=000X
V@0005A<000:90000a/002Xm001l6`2h`P000?<0lc800?h6003NO@00?:00001JB00032L000<J000T
>@00MbD0YKd00?4k003o0`00hG<004VT0000GDH000hX00026P0083H007@Z09bk003`@000o`800>9_
001=Y@0005i5000?:@000QX0020f001d:P2L^`00l3l00?l2003RL@00BJ@0001MAP003RP0008J000R
>000MRH0Y[d00?4i003n1000ggT003fP0000FDT000`V00036`00:3/007/M0;_2003d;`00oPP00=^7
000ZVP0005=<00098`0011`0039100233@39^@00mb400?`@003DW0004I000017B`001Ql000DN0012
B@0:SP00dZ400?/C003h7P00bkD000242P00<d4000@L00098`00E4`0;Y/00=b3003n1P00lSD00:Zn
0000MRH0024g00026P0042X00691062[003WG`00o`000>YF001][P0006Dn000B;0000QT001he001c
:P2R_000lST00?h5003MP@00;Y/0001CC0002B8000@L000gA000R080cj/00?XG003i6`00c;800025
2P00<T4000<L000:9000EdX0?J000?0l003^A000RKH0001/=@005c00008I000I<P00L300U[T00?0m
003n1000gWl002nK0000Dd`000PR00047@00?4H01X`00=:Q003l4@00mb@00<K10000OAT002Lk0003
6P003bT00652066[003XFP00o`000>MQ001GZ00005i5000=9`000a/002`n0022403:]`00nA`00?XG
003=[`0008D9000a@0000a/000`V001LA`1@YP00iVD00?l0003YF@00HJ/0001P@`003RP000<J000[
?@00PA80b[L00?TL003j6@00c;8000233@00;Ch000<K000=9`00Gd@0GjX00>UJ003o0000iFH004bU
0000FTP000XU00047000=T<00HX00=:R003l3`00mRP00;c20000N2<001lf00026@005Bh006`e092h
003a?@00oPD00=Z9000MU@0004Q<00057P001b40059=03>M003PM`00o`400>a=001a[`0006=0000?
:@000aX002/m00233P3=/000nQH00?PP0036`00007/M000R>0000QT001@^001[=P2A^000lC/00?h7
003IS`0059800011B00011d000TS001HBP18X`00iFH00?l0003WH@002_ooool1o`00007ooooo000N
ooooo`03o`000?oooooooooo00Oooooo04l03i000<f`003f:000oPD00>=/001Z[@0006dd000Q=`00
0a/000PR0016B`00Q`@0a/400?8e003o0@00j5d0086d0000M2X002Pk000470001b0003e600223`2i
`P00l3d00?l0003ZE000S[L0001g9@00:cd000@L00067`00>DD0084C0;?0003`@000o`000>YC002?
^00007LU000[?@0011`000HP000kA@00PQ00^/800?4l003o0000jET008Fe0000M2X002Lj00037000
1b40049900271P36`000lc800?l3003UI@00L:l0001]<`007cH000<J000:9000Cdh038l00<f_003g
9000oPP00=mi001@YP0006@o000G<0000QT000hY001IB@0ZVP00eYD00080na@00?l0eYD002ZJ0000
F4T000hX00026@005c0006Hm05JX003QM000oPH00?DZ003:]`000HX00016B`00224000<L000X>`00
MRH0TkT00>a>003o0000k4`009Ji0000MbD002Tl00037000224004M;00>;003;]000mRL00?h8003O
N`00BZ@0001Q@P0052d0008I000B;000H4<0AJ800=io003m2@00mbD006RO0000Ad/000LQ00047000
:cd007TQ0:6l003_A000o`000>UI001l/P0006la000O=P000aX000`V001EB`0SU`00eYL00?/C003j
5`00dil001VD0000DTd000XT00036`0093T007@Z08jg003/C@00o`000>]B0026]@00074^000Q=`00
0aX000/U001EB`0TV000eYD00?/A003i6P00dJD0016@0000CTh000PR00036`00:S`007XP0:Nm003`
?`00o`400>IT001W[@0006Pj000H<0000QT0014[001OA019Y000h7P00?h5003d;`00aL@000214@00
=48000@M00068000A4X018/00<f^003h7`00o0h00=RA000WV00005E;000;9@000aX002@i001f9`2K
^`00kd@00?l1003VHP00Ijd0001W>`005Rl0008I000C;@00Hd00FJT00>A[003o0P00l3d00:Jm0000
N2<002Lj00036`002RD005A<02RI003ISP00o0d00?LS003:]P0008L5000kA@001Ah000HO0012B@04
R`00cZ`00?TL003k4P00eIX001RC0000Cdh000PR00047000<D00080C0<G2003e;000o@P00=b4000b
W@0005M:000;9P000aX002Hj001h8P2Z_P00lCT00?l3003QM000Aj<0001MAP003RT0008J000P=P00
Lb/0UkX00>m3003o0@00i6/005FW0000HD<0010Z00026@007C@0070_08jg003^A`00o`400>EW001I
Z@000691000A:`000QT001`d001`<02>]`00kTH00?l1003TJ@00EJP0001P@`0042X0008I000O=@00
Lb`0VKX00?10003o0P00hW4004VT0000G4H000hX00036P0093T007PS0:fo003b=@00oPD00=io000e
W@0005I:000:90000a/002dn00205@36`000mRL00?d<003GT`006i@0001>CP001b4000DM000lAP01
RP00cjT00?XG003i6@00cZd000280P00>D@000@M00088P00DDd08iL00=Z;003m2@0007l0m2l00;S1
0000NR0002Di00036P003RP005i405BW003UI`00o`000>a>001j/P0006Ti000E;P000QT001Xb001`
<02D^@00l4000?l3003PN@00>Il0001GBP002R@000<L000b@@00Q@X0bk<00?TL003j5P00cjX00029
0@00>4@000@L00098`00E4`0<I`00>i1003`?@00U[T0001`<0006S80008I000F;`00K3H0R;H00>i4
003o0P00h7H003ZO0000ET/000TS00047000=T<008P20<nY003j5@00n1h00<Vi0000PA8002`m0003
6`003BL005e505FW003VHP00o`000>UI001S[0000652000?:@000aX002Pk001n6037_P00mb800?/C
003@Y`0008T1000f@`0011`000XT001HB@14XP00hfd00?l0003[D@00KZl0001T?`0042X0008J000V
>P00OAT0akl00?PQ003k5000cjX000271@00<T4000<K000;9P00G4L0DZL00>IR003o0000ieh005RX
0000GDD000`V00036`00<D0008H70<nZ003k5000mb800<K10000Nad002<h00026P004R`006Pj08:d
003_A000o`<00=f0000WV@0004m>008000HP00`004m>02RI003MO`00o`<00>i6001n/`0006Ll000A
:`000QX002Lk001o5P39^0020?TK000C0<Vi0000OaH002Hj00026P004R`006Pk08>d003_@P00oP@0
0=^6000NU@0004Q;00057P00224005A<03bP003SKP00o`000>UI000:ooooo`7o00000Oooool001ko
oooo00?o0000ooooooooool01oooool0o`06S000b[P00?@^003o0`00iV@007Ja0000LBl002Di0003
6`001b4003m80024302m``00lC`00?l0003ZE@00SkL0001g9000;3h000@M00067`00=d<007lF0:^n
003^A@00o`000>a=002L^`0007XO000`@0001Ad000DN000d@P00OAX0Y[d00>i7003o0000kD/009fk
0000Nah0031000057@001Ah003E3001n5`2/_`00kd<00?l0003[D@00T[P0001g9000:cd000@L0006
8000?4H008<>0;k3003a>@00o`400>QM001m/`00074^000S>0000a/000PR0019C003R`00b[L00?DZ
003n1@00hW4005fZ0000J3/001Xb00026P003BL005E;022F003CWP00nQT00?`@003IS@00=Id0001L
A`0042X0008I000E;P00HT40BZ@00=im003m2@00mb@00<f_000:SP0004e>00098`000a/002@i001c
;026]@00jUD00?l0003^A@00Xkd0001k7P00;Ch000@L00078000@4P008L50<Rl003e;@00oPD00>5c
001FZ00006Dn000F;`000QT0010Z001LAP0iW`00fhL00?d<003h7`00KYd0001>CP002B<000<K000V
>P00MRL0U;T00>e;003o0000je8008Vf0000Lb`002<h00036P002R@0059=01VC003CW`00nQP00?/C
003FUP0099L0001EB`002bH000<J000P=P00L300PK@00>YE003o0000kDX009Bi0000MBP002Di0003
6`002R@0059=01ZD003DW@00nQH00?XE003DW0006i@0001BC@002R@000<K000U>P00MRH0VKX00>i6
003o0000j5`007B`0000K3H001/c00026@003bT005a703fP003MP000o@P00?DY0038_00008D9000j
A@001Ah000HO000nA`00R0@0b[H00?LU003m2`00fhP0036L0000F4T000`W00036P0083H0078]08jg
003]B`00o`000>QJ001c/00006/g000I<P000QT0014[001P@`1=Y@00hG<00?l4003b=P00]<40001l
7000:cd000<K00098`00DDd07ID00=JG003l4000n1d00<j^0002R`00045800067`001Ah003a60028
103;]000mb400?`>003GTP008YL0001BC@002B<000<K000/?@00OAX0^/800?<b003n1@00gg`003jP
0000FTP000dW00036P008SL007DX09fk0000l`3`@000o`800>=/001CY`000613000@:P000QT001`d
001_<@2:]P00kDX00?l0003VHP00HJ/0001T?`004b`0008I000I<P00KC@0PK@00>a>003o0000iel0
06J/0000ICh001<]00026@006C4006de086d003/CP00o`000>MQ001RZ`0006@o000B;0000QT001/c
001_<@2;]P00kTL00?l1003TJ@00EJL0001P@`003bX0008J000P=P00M2T0Wk`00?4l003o0`00h7L0
042Q0000FTP000`V00036P00:3/007`L0;k3003d;@00o@T00=Z;000UV000055=00088P0011`003I3
00261P3</@00nA`00?/E003AY@001X`0000oA`001Ah000LP001<C@0IU000ei<00?d<003f:@00aL@0
001m6@00:C`000<K000<9P00FdL0B:<00>9_003o0@00kTL008Ne0000K3D001P`00026@005c0006`e
08Ne003^A`00o`400>9`0015XP0005Y8000;9P000a/002dn00214P38^`00n2400?/B003BXP001X`0
000mA`001Ad000LQ001AC@0WV000kDH00?8f002T_@0007<Z000M=0000QT001@]001X>P1k/P00k4`0
0?l1003SKP00AJ<0001IB0002bD000<K000a@000Q@X0c;800?TJ003i6@00c;4000252P00<D0000<K
000;9@00FTP0BJ@00>A[003o0000je40072_0000ICh0014[00026P008cP007XO0<74003f9`00o0l0
0=>O0007S00003a600047@002B<005E;03VO003QM@00o`400>e:001k/P0006Lk000B;0000QT0028h
001j8031a000mRL00?`@003BXP000X/0000hA00011`000XT001HB@16X`00i6X00?l0003ZEP00IJ`0
001Q@P003RP000<J000/?P00P`l0c;<00?XH003i7@00bKX0001o5P00:3/0008J000@:P00ICh0MK40
0>e;003o0P00h7P003:L0000DTd000LQ00057P00B4`07ID00=^8003n1@00l3h008^f0000JSP001@]
00026@008cP007/M0<K0003h8000nQH00<ba0000P`l002/m00036P003bX006@o07Ja003]B@00o`80
0=in000XV@0004i>00067`001b00055=036L003PMP00o`400>]A000:ooooo`7o00000Oooool001ko
oooo00?o0000ooooooooool01oooool04`00R080a/000?<e003o0@00j5`008>d0000M2T002Tl0004
70001Ql003U50020502__`00kd<00?l0003/C@00W;/0001k7P00<D000P001Ah0o`00<D0007/M09jk
003/C000o`000>i5002Y_P0007hH000e@`001Ah000@M000^?`00NB40V;X00>a>003o0000kd@00:^n
0000OQL003E200057P001Ad00310001k7P2N^`00kDX00?l0003]B@00X;`0001k7@00<40000DM0005
7P00=T<007lE0;70003`@000o`000>YE002:]P0007DX000X>`0011`000LQ0013B@00Q`D0akh00?@`
003o0`00i6T006V]0000JcH001dd00036P002bD0059=01JB003@YP00n1h00?d<003LQ000@:40001O
A0004b`0008I000B;000Gd@0?j400=b5003m3000n1h00=2W000CT@00055=000:90000aX0020f001_
<@1i/P00j5d00?l1003`?@00/L00001n5`00<d4000DM00067`00>TD008<=0<G4003c<`00o`<00>AZ
001SZ`0006Pj000I<P000QT000hX001IB@0^V`00f9000?`@003i6P00M9/0001AC@002R@000<J000R
>000LRd0Q[D00>YC003o0000kDX009Ji0000MRH002Lk00036`002B<004i>00n@003@Z000nAd00?`?
003ISP00;Y/0001HB@003BL0008J000L=000K3D0M;000>QM003o0000kd<00:6l0000N28002Tl0003
6`00228004i>012@003AYP00nA/00?/A003GU0009IP0001EB`002bD000<J000Q=`00LR`0S;L00>a>
003o0000jU@0086d0000Kc4001he00026P003BL005U903:L003JR@00o@/00?LS003;]00008T10010
B0001Ql000DN000hA000Q0`0akh00?DZ003n2000gH0003fP0000FdL000hX00026P007C@006hb082d
003[D`00o`000>]B0020]00006hb000L=0000QT000lY001LAP12X@00gg/00?h6003d<000`/@0001o
5@00<40000@L00088P00CTh04i400=>O003k5@00nQP00=6V000<SP0004Q;0007800011d003I30024
3038_000mRL00?d:003JRP00;9X0001EB`002bD000<K000W>`00NB40[;l00?8i003o0`00hG@004VT
0000GTD000lY00026P007SD0074^08ng003^A`00o`000>IT001OZP0006@o000C;0000QT001Ta001/
=P1m/`00je400?l0003XF`00KJh0001X>`005Bl0008I000F;`00JCT0M;000>YF0000=P3o0000jEL0
07:`0000JCX001H_00026@005Rl006Ti07B`003ZE@00o`000>UI001^[`0006Lk000E;P000QT001Pa
001[=P1n/`00k4l00?l0003WH@00HJ/0001S@0004R`0008I000L=000L2l0T[P00>m3003o0@00hfh0
04bU0000GDH000hX00036P0093T007PS0;30003c=000oPH00=b3000_W00005E<00098`0011`00350
00233P39^@00mb400?`@003DW@003i000015BP8000HO0:H004E:012@003DW000o1000?LS0038_000
084B000^?`000a/000/U001HBP0lX000h7L00?l3003`@000U;T0001`<0006c<0008I000E;P00JCX0
NK800>a>003o0000iFP0056V0000GDD000dW00036P00:3/007dI0<G3003f9`00o0h00=FJ000@T000
04A:00057P001R0004e>01bE003[C000m3000;;00000MbD0024g00026@004B/006Dn06j_003ZE000
o`000>EV001AYP0005e6000<9`000a/002`m00214P39^@00n1l00?/D003?Z@0008P2000f@`0011`0
00XT001GBP0nX000hG<00?l1003]BP00OK<0001X>P004bd0008I000O=P00MbD0/l000?@]003m2`00
eYH0012@0000@TT000DN00078@00DTd0;Y/00=im003o0`00kd8008Rf0000JcL001D^00026@007SD0
07HV0;?0003e;@00o@`00=FI000;SP0003i700047@002B8005E;03^O003QLP00o`400>a>001a/000
06@o000@:P000aX002Lk001o5P39^P00n1d00?XH003</P0008<>000/?P000aX000hX001Q@P1X[@00
je<00?l0003RL000?J00001EB`00228000DM0012B@0DT@00f9000?h8003b=`00V;X0001^<`005Rl0
008I000O=@00N2<0_/<00?HV003k4P00cjT000261`00<40000<K000=:000HD80JJd00>]A003o0@00
hGD003>M0000DTd000LP00067`00CDh09iP00=io003o0P00kDT02_ooool1o`00007ooooo000Noooo
o`03o`000?oooooooooo00Oooooo06X008D:0<33003a>`00o`000>YD002A^00007PS000^?P0011d0
00DN000d@P00O1/0X[`00>e:003o0000kTH00:Zn0000OQL003I300067`0011d002`n001g902@^000
jU@00?l0003`?P00]l4000224000>dH000HP00047000:S`007HW08^f003ZEP00o`000?0m002h`P00
088@000kA@001Ql000@L000[?@00MbD0TKP00>]B003o0000kd800:jo0000OaH003E300057P001Ad0
0350001l702S_000kTL00?l0003/CP00UkT0001h8P00;3h000@L00068000?4H008<=0<;4003b=`00
o`800>MQ001f/@0006la000Q=`000aX000TT001?CP0<S`00cJh00?LS003m2@00gg`004bU0000Hd00
01D^00026@0042X005]703BM003IS@00o1000?TI003CW`007ID0001DC00032H0008J000M=000K3H0
K:h00>EU003o0P00lSL00;o30000PQ0003Q40P001Ah0o`00=D80080E0;O1003a>P00o`400>IR001_
[`0006`e000L=0000QX000`V001FB`0TU`00eIP00?/D003j5@00NiP0001DC0002bH000<J000O=@00
KS80NK800>QK003o0000kd<00:Bm0000NR0002/m000470001b4004Q;00J<003=/000mb800?d;003K
QP00>Il0001LA`003bT0008I000I<@00JCT0J:d00>EU003o0@00lC`00:no0000O1/002ho00047000
1b4004Q;00N<003>[P00n2000?`=003IS000;i/0001HB@003BL0008J000N=@00Kc80O[<00>YE003o
0000k4`008jg0000Lb/0028g00036P002bD005E;02NI003HT@00o0l00?PN003>[0001h`00016B`00
1b0000@M000b@@00P1<0`/@00?@a003n1@00h7P004RS0000Gd@0010Z00026@006C8006/g07B`003X
FP00o`000>e;002=]`00078]000P=P000QX000dW001IB@0fWP00g8@00?d9003e:P00akh000233@00
=D<000@M00078000Ad/02Xh00=2W003i6@00na@00=>M000ETP0004i>00088P0011`0035000204`35
a000mBd00?h7003MP@00=ih0001IB@0032L000<J000S>000MBL0Wk/00?10003o0P00i6`005FW0000
HD80014[00026@006c<006hc08:d003/C`00o`000>QL001/[P0006Lk000E;`000QT001H_001X>P1`
[`00jET00?l0003[D`00N[80001[=`006340008I000D;@00ISd0Ijd00>MN003o0000k4l007nc0000
K3D001Ta00026@0052d006Hm06R]003XG@00o`000>]A001k/P0006/g000G<0000QT001D^001X>`1a
/000jUL00?l0003YF@00KZh0001W?00052h0008I000I<@00KC@0Q;D00>e;003o0000iFH005RX0000
H4<0010Z00026P0083H007DY0::l003a>P00oP@00=mj000jW`0005Q:000;9@000a/002`m001o5P36
`@00mRL00?`=003GU@0069<0001<C@001b0000DN000oA`06S000dJ@00?/D003h7@00bk@000252P00
<d4000@L00098`00ED`0<I`00=f0003n1@00lST00::l0000M2X001he00026@004R`006Dn06f^003Z
EP00o`000>MP001MZP000652000?:@000QX002@i001j8000Q`2j`P00mBd00?d:003HT@006I@0001;
C@001R0000HO0016BP0CT@00jU800?DZ0030``0007/N000U>@000QX000lY001Q@P1RZ`00j5/00?l0
003WGP00GJX0001P@`003RT000<J000W>`00OAT0a/400?LT003l4000dZ4000J<0000?4H000@M0008
8P00E4`0<id00=mk003o0`00kd8008Zf0000K3H001H_00026@0073@007<[0:Jm003c=000oPP00=V>
000JU00004U<00067`001R0004m>02>G003KQP00oPD00?4k002E^@0006hb000G<0000QT001/c001b
;02U_@00lc<00?d9003HT@005I800014BP001Ah000LQ001BC@0`W000gg/00?l2003^A`00O[<0001X
>`004R`0008J000S>000Nad0aL800?LS003k4`00cjX000261P00<D0000<K000<9`00GTD0G:X00>QK
003o0000iFP004RT0000F4T000XT00047000?4H02Xh00=FI003m2`00m3400:Jm0000LBh001Ta0002
6@006c<007@Y0;30003e;000o0h00=:P0001RP0003E200036`0032H005i505fZ003YF000o`000>=]
000nX00005E;00088P001Ah004I;01bE003KQ`00oP@00>m2000:ooooo`7o00000Oooool001kooooo
00?o0000ooooooooool01oooool0o`00PA80//000>m2003o0000k4d009jk0000O1`003=100057P00
1Ad002lo001i8@2D^@00je800?l0003`?`00]l4000223`00?4H000LP00047000:3/007@Z08>d003X
F`00o`400?8g0035a00008D80011B0001b4000<K000U>P00LRd0O[<00>MN003o0@00lSH00<G30000
Q@P0045800078@000a`002Lj001c:P24]@00jEX00?l1003a>`00^l8000223`00>dD000HO00047000
;3h007PS09Ji003/C`00o`000>i6002T_@0007`L000a@0001Ad000DN000g@`00P1@0]<400?0n003o
0000jET008:d0000LR`002@i00036`00228004U<00>;003:]P00mRT00?h6003QM000EjP0001V?@00
6340008I000>:000F4T0:IT00=JE003k5000naD00=JG000WV@0005M:000=:0000QT001Tb001X>P1P
Z`00hfd00?l4003d<000a/0000252000?TL000HP00047@00;cl007`L0:Zn003_@@00o`000>QJ001l
/P0006la000P=P000aX000/U001BC@0JU000dj000?XI003k4@00PIH0001HBP003BL0008J000K<`00
JcL0KJh00>IS003o0@00lC`00;700000OAT0031000047@001R00045800280P3:^000mRP00?h8003N
O@00A:80001OA0004B/0008I000F;`00ICd0FjT00>=]003o0`00lSD00;c30000P1@003=100047@00
1R00045800290@3;]@00mRD00?d:003LQ000>Yl0001KA`003bT0008I000J<P00JcH0L[000>QM003o
0000kTD009^k0000MRH002Hj00036`002R@0059=01fE003EV@00na<00?XI003AY0004900001=CP00
228000@L000]?P00OAX0]<400?8g003o0`00hVl005BW0000HT4001</00026@005c0006Lk06N]003V
HP00o`400>m4002K^P0007DW000T>@000aX000/U001FB`0/VP00fH`00?d<003g9000b[L000271@00
>dD000DN00067`00@4P00HX00<f_003h7P00o1000=JE000OUP00059=00098`000a/002`m001m6`2h
`P00lc<00?h5003ON@00@Z80001LAP003RP0008J000O=P00LRd0TKP00>i7003o0000iV<0066[0000
ICh001<]00026@00630006Xh07Fa0000D03ZEP00o`000>YD001h/@0006/g000H<@000QT001<]001U
?P1S[000if400?l0003]B`00QkD0001_<P006c<0008I000A:`00HT40FjT00>EV003o0000kTP008bg
0000L30001`d00026@004B/0069105^Y003UI@00o`000>e:0028]P0006hb000J<P000QT001</001T
?`1U[000ieh00?l0003[D@00N[80001Z>0005c00008I000F;`00JCT0N;400>]B003o0000ieh006B/
0000I3l0018/00026@0073@0074^09Fi003_@@00o`800>9b0016X`0005]7000<9`000aX002Lk001k
7@2m``00mBd00?d9003IS0008YL0001@CP00224000@M000iA000R@40cZ`00P3j6000X@3>[00008P2
000hA00011d000PR001AC@0WV000fhP00?h7003c<P00[kl0001g90008SL0008J000@:P00HT40H:/0
0>MN003o0000jEP006V]0000I3l0014[00026@0083H007HV0:bo003c<`00oPL00=Z9000SU`00051>
00078@001Ah003m800V=003XF000mb@00<K00000OQL002Tl00036P003BP005i505JX003VH`00o`00
0>YF001Z[@0006=0000@:P000QX002<h001j802m``00mBX00?`=003EV0003i000012B@001Ah000LQ
001@C@0XV@00g8<00?h5003a>`00UkT0001_<@006C40008I000I<@00Kc40V;X00?4j003n1@00fhH0
02BH0000Cdh000LP00067`00B4`06I@00=V>003n2000lcD00:>l0000LRd001/b00026@00634006la
09Rj003a>P00oPH00=Z9000OUP0004]=00067`001R0004m>02JH003LP`00oP@00?10002;]P0006/g
000E;P000QT001lf001h902k`P00mRP00?`?003BXP000HX0000f@`0011`000/U001KB01@YP00iV80
0?l0003WH000E:L0001LA`002bD000<L000f@`01RP00dZ400?`>003e:`00]<00001e:00073@0008I
000H<@00LBl0Xk`00?<b003m2P00eIP000Z>0000>dD000@L000:9000FTP0DJH00>MP003o0000iFD0
04ZT0000F4T000TS00047@00@4P04i400=R?003n1`00lC/000[ooooo0Ol00001ooooo`007_ooool3
o`0000Oooooo0?l007dI0:Bm003]B@00o`000>i5002[_`0007lE000hA0001Ql000@L000Z?000MBP0
QkD00>UI003o0@00lSP00<G40000QPP0049900088@000a/002@i001`;`1f/@00iV<00?l2003d<@00
b;d000290000B4/000PR00036`008CL006lb076_003UIP00o`<00?@`0038_00008T00017B`002280
00<K000S>000L300Mk400>IQ003o0P00lc@00<G20000QPL0045800078@0011`002Lk001d:@28]P00
jUH00?l0003`?`00//0000205@00=T<000DN00057@00<D0007`K0:Jm003^A@00o`000>]A002@^000
07HV000Y?00011`000LQ0012B@00Q`@0akd00?@_003o1000hf`006>/0000JCT001/c00026P0032H0
05E;01nF003CWP00nQP00?`@003IS`00<I`0001JB0003bT0008I000F;`00ICh0E:L00>5e003n1P00
mBX00<Vh0000R@0004A:00078@0011`002/m001h8P2L^`00kTP00?l0003[D`00RKH0001c:`0093T0
00<K00098`00Cdh049000=2X003h7P00o0d008RD0000FdL000lY00026@00634006Lk062[003TJ`00
o`<00?<e002o``00084B000e@`001Ah000HO000kAP00Q@X0akl00?@^003n1@00hGD0052V0000HT40
01@]00026@004bd0069104nV003QM@00oPD00?@_0036`@0008<=000hA0001Ah000DO000kA@00Q@T0
akd00?D[003n1`00gg/004FS0000Gd@0014[00026@005c0006Pk06F/003UI@00o`400?0n002Y_P00
07XO000Z?@000a/000PR001?CP0CT@00dZ400?XG003k5000e9`001ZD0000DDd000TS00036`00:C`0
07TQ0:Nm003`?P00o`400>EW001PZ`0006Dm000E;P000QT001@]001T?`1KZ@00i6X00?l2003a?@00
Z;h0001i8@00:3/000<K000:9000Dd`08IL00=ND003l3`00n1h00<f_0002RP00045800067`001Ah0
03Y500261P3:]`00mb@00?d<003IS@00:IT0001EB`002RD000<K000W>`00NB40Zkh00?4j003o0`00
hW4004jU0000Gd@0010Z00026@0073<006hb08Be003/CP00o`000>QL001][P0006Pj000F;`000QT0
01D^001W?01Y[@000?<0ieh00?l0003/C@00QKD0001^<P006c<0008I000A:`00HD80EjP00>AY003o
0@00kd@009Bi0000LRd001le00026P003bT005m404nV003SKP00o`800>m1002J^P0007<[000O=P00
0QX000lY001OA01?YP00hfd00?l1003_@P00UKT0001b;@007SD0008I000@:P00HD80FJP00>EV003o
0000kDX008Ne0000KS<001Xb00026@004bd006Hm06^^003YFP00o`000>YG001`[`0006Lk000D;P00
0QT001Tb001^<`28]P00kDP00?l1003TJP00DJH0001NA@003RP0008J000S>000N2<0[kl00?<c003n
1P00g8@002fK0000Dd`000TS00047000=48008D90<^d003h7@00na@00=6T0006S00003i700057P00
1b0004i>01fE003HT000o@X00?D/002m``0007/N000V>P000aX000hX001NA01DY`00iFH00?l0003[
D@00MK40001W>`0052d0008I000M=000LR`0Wk/00?4j003n1@00gH4002jK0000Dd`000PR00047@00
>DD00HX00>IN003h7P00b[P000224000;Sh000<K000<9P00FdL0BZ@00>A[003o0000k4l007Ja0000
Ic`001</00026@007cH007HV0:no003d<000o@T00=R@000IT`0004U<00067`001R0004a=01jE003J
S000oPL00?<e002T_@0007</000L<`000QT001H_001/=@2;]P00kd400?l3003NOP00;Y/0001BC@00
224000DN0012B@0@T000eYH00?d;003d;P00/<00001e9`007SD0008I000E;P00JcH0R[H00>m1003o
1000gH4002VI0000D4h000LP00067`00BD`079@00=Z;003n1`00lST009Rj0000Kc8001L`00026@00
73@007@Z0:fo003d;P00o@`00=FJ000:SP0003a600047@002B<005M:04FR003TJP00o`000>UH001P
Z`0005m4000=9`000a/0035000261P3?Z@00na800?LU0031a00007TR000P=P000QT001D_001]=02E
^@00lST00?h7003HT0004i400011B00011d000TS001GBP15X`00i6P00?l0003XG@00EJL0001KA`00
2bD000@L000jA@09S@00eYL00?d:003c=0002?ooool3o`00007ooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0?l007XP09Ni003[D@00o`000?0n002i`P0008<>000nA`001b0000<L000V>P00LRd0
N[800>MQ003o0P00lc400<Rm0000R@0004U<00098`000a/0020f001]=01Z[@00i6/00?h4003e:`00
bkD000N=0000CTh000XT00036P007SD006/g06F/003SKP00oPD00?DZ003;]00028d0001>CP002B@0
00<J000O=@00K3D0JZh00>AY003o1000m2h00<Vj0000RP0004Q;00088P000a/002<h001a;P1l/P00
ieh00?l1003b>000`<<000233@00?4H000HP00047000;3h007TR09Vj003/C000o`000>e:002M^`00
07XP000]?P0011d000HO000lAP00Q0`0`l@00?8f003o0P00iV@0072_0000KC@001he00036P002bD0
059=01FB003AYP00n1d00?`=003KQ`00?:00001NA@004B/0008I000D;@00HD80B:@00=im003m2@00
mb@00<f`0008S@0004]=00088P000a/002Hj001e:02?]`00k4l00?l0003]B`00U[T0001g9@00:3/0
00<K00088P00BT`01hd00<f`003g8`00o@X008nB0000GTD0014[00026@005Bl006@o05FW003QL`00
oPD00?@_0036`00008D:000kA@001Ql000DN000f@`00PA40`<<00?<d003o0`00hfd005bY0000ISd0
01H_00026@004B/005m404BR003NO@00oPP00?HY0039^P0008L5000nA`001Ql000DM000e@`00PQ40
a<@00?<a003n1000hG<0056V0000HT4001<]00026@005Bh006@o05VY003SK@00o`<00?8g002f`@00
07hI000_?`0011`000LQ0019C00:SP00cjT00?TL003l4000ei@002BG0000E4`000/U00036P0093T0
07DW09Vj003^A@00o`000>MP001/[P0006Ti000H<@000QT0014[001Q@P1?YP00hW800?l4003b=P00
]/40001m6`00;Ch000@L00088P00D4h069<00=BL003k4`00nAT00=2W000;SP0004Q;0007800011d0
03E200233P37_`00mBX00?d9003LQ@00<id0001HBP0032H000<J000S>000MBL0WK/00>m1003o0@00
i6T005ZY0000Hd00018/00026@006C4006/g07Na003ZEP00o`000>YD001j/P0006/f000I<@000QT0
018/001S@01MZP0005D0iFH00?l1003^AP00T[P0001b;@007cD0008J000?:@00GTD0C:D00>9a003o
0P00l3d00:6l0000MRL0028h00036P003BP005a704BR003PMP00o`<00?4j002W_@0007LU000S>000
0aX000dW001KA`14XP00hGD00?l3003a>`00X[`0001e9`008CL0008J000>:@00GTD0CJD00>=^003o
0P00kd8009Bi0000LBh001dd00026@004B/006=105nZ003VHP00o`000>a?001m/`0006/g000G<000
0QT001H_001Z>01k/P00je000?l0003VHP00GJX0001R@@0042X0008J000O=P00M2T0X[`00?4j003n
1000gg`003NN0000EdX000XT00036`00;cl0084A0<Rl003g8`00o1000=BL000?T00004E:008000HO
09`004M;01>A003EV000o0h00?HV0036`@0007hG000Z?0000a/000`V001KA`19Y000hfh00?l1003]
B@00P[@0001[=`005Rl0008I000I<P00Kc40TKP00>m1003o0`00h7T003RN0000ET/000XT00047000
=48008H70>AT003i6@00cK0000262000<d4000@L000:9000EdX0?j000>5c003o0@00kTL008>d0000
JSP001D^00026@0073<0078/0::l003b=`00oPH00=^8000RU`0004m>000780001Ah004E:01BB003G
U000o@X00?@^002b`00007HV000O=P000QT001<]001X>P1n/`00kDP00?l2003QM@00>Il0001EB`00
2B<000@M000kAP07S000dih00?`>003f:000_/<0001i8@008CL0008I000C;000J3/0O[<00>i8003o
0P00h7P003>M0000Dd`000PR00057P00@TT04Y400=NC003m2@00lc800:Jm0000LR`001Xb00026@00
6C40070_0:2l003c=@00o@P00=RA000CT@00049900057@00228005A<03VO003QLP00o`400>]@001/
[P000691000>:@000aX002`m00233P3</@00nQH00?PO0037_`0007`K000T>@000QX001<]001Z>@28
]P00l3l00?h5003KR0007ID00017B`001Ah000PQ001DC00jW`00hW000?l0003ZEP00HJ/0001OA000
32H000<K000d@P01RP00dj000?`=003d;P0:ooooo`7o00000Oooool001kooooo00?o0000oooooooo
ool01oooool0BP00MRH0R[H00>UH003o0@00lSP00<G30000QPH004A:00088P000a/0028g001^<P1^
[`00i6T00?h4003e:`00bkD000R=0000Cdh000XT00036P0073@006Ti05jZ003QL`00oPL00?LU003>
[@004900001BC@002bD0008J000J<P00J3/0FJT00>1f003n2000mb@00<j/000AT000055=000;9@00
0QX001/c001Y>@1NZP00hW400?h6003f:000c;<000V=0000CTh000TS00036P0083H006dc06n_003U
IP00o`<00?<b0036`00008L50012B@001b4000@L000X>`00MBP0S;L00>YD003o0000kd<00:Zn0000
OAX003910P001Ah0o`00=d<0080D0;K1003a?000o`400>QL001l/`00070_000R>0000a/000TS001?
CP0<SP00cZh00?LS003m2@00gWh004NS0000HD8001@]00026@004B/005i503fP003LQP00o@`00?PO
003?Z@004I00001@CP002R@000<K000R>000LBh0P[@00>UG003o0000kd@00:>l0000NQl002dn0004
70001b0004=900290@3:^000mRT00?h7002ET0000692000C;@000QT001<]001Q@P19Y000gg/00?h7
003f:@00bKP000280P00@DP000HP00047@00<40007hI0;?0003a>`00o`800>EU001X[@0006Ti000I
<@000QT000lY001KA`0iW`00g8D00?d;003g8`00c;8000:;0000A4X000LP00047@00<40007hH0;K1
003b>000o`800>A[001MZP0006Dm000F;`000QT0018/001Q@P1>Y@00hGD00?h5003d<@00a<@00021
4@00=48000@M00068000@TT00HX00<ba003g8@00o0`00=Z<000^V`0005M:000<9P000aX0024g001b
;@2<]`00k4`00?l0003YF000N;40001/=@006c<0008I000?:P00GDD0A:800=mj003n1P00m3000<?4
0000P1@00351000470001b4004Y=00j?003AY000nQP00?XE003CW`005980001>CP00228000@L000`
@000OaD0`L@00?@`003n1P00gWd003jP0000FdL000hX00026P007cH0078]092h003^B000o`000>MQ
001V[00006Hm000E;P000QT001H_001W>`1[[P00j5d00?l0003/C@00QkD0001_<@0073@0008I000@
:P00H4<0DJH00>=^003o0P00l3l009nl0000MBL0028h00036P003BL005]7042Q003ON@00oP@00?8f
002__`0007TQ000V>P000aX000`V001HB@0iW`00gWh00?h6003c<`00]<40001j7`009c/000<K000;
9P00F4T0>Il00=im003n1@00lcD00;300000NB4002Dj00036P003BL005Y804:Q003PMP00o`<00?4l
002Q_00007DX000Q=`000QX000lY001OA01CY`00i6X00?l1003^B000RKH0001^<P006S80008I000D
;@00Ic`0KZl00>UG003o0000j5X006V]0000ICh001</00026@0073@0074_09Fi003_@@00o`800>5d
0012XP0005Y8000<9P00Y`000a/002Xl001n6035``00mRP00?d<003GU00069<0001;C@001R0000DN
0011B00:SP00dZ000?/B003h8@00bKT000224000;cl000<K000;9@00F4T0?Z000>1f003o0P00kd80
08ng0000KS8001Ta00026@005Rl006/f08Be003^B000o`400>9a0013XP0005U9000;9@000a/002lo
00233P3QJ`00nQD00=2X0000R@0003Q4000470002B<005A<03BM003ON`00o`<00?10002@^00006hc
000H<@000QT001Ta001_<@2D^@00l3d00?h4003MP000;I/0001BC@00224000DM000oA`0;SP00e9`0
0?`>003f:000_l<0001j80008cP0008J000A:`00ICh0L[000>]@003o0000hfd004BR0000F4T000XT
00047000=T<008T10=2V003k4P00mb<00<K10000OA/002Dj00026P0042X006@o076_003/C`00o`40
0>9`000nX00005I;00098`0011d003a600V=003DV`00o0d00?D/002c`00007HW000N=@000QT001H_
001]=02C^000lC/00?h6003JR@007ID00019C0001Al000LQ001AC@0_V`00gg/00?l2003]B@00NK80
001V?@004B/0008J000W>`00OaD0bKP00?TK003i6P00b[L000205000:3/0008J000A:`00ISd0O;80
0>i6003o0`00gH0002NH0000CTh000HO00078000DDd0<9`00>1h003o0@00k4h006f^0000HT4000hX
00036`00;cl008H60=2X003k4@00mRP000[ooooo0Ol00001ooooo`007_ooool00ol0003ooooooooo
o`07ooooo`3o001c:`1m/`00if000?l2003c<@00b;`0006:0000Bdd000TS00036P007SD006/g06:[
003RL@00oPH00?HU003>[@004I40001BC@002bH0008J000I<P00ISd0DZL00=mk003m2P00n2000=6U
000JU00005E;000=9`000QT001L`001T?`1=Y@00gWh00?d;003h7`00dJD001ZD0000E4`000`W0002
6@00634006Hm05>W003ON@00o@T00?LR003?Z`004Y40001AC@002bD0008J000L=000JSP0Hj/00>=^
003n1@00mB`00<Zh0002RP0004Q<00088P000a/002@i001b;@1o/`00j5/00?l1003a?000]l400021
4P00>4@000DO00057@00<D0007dK0:Vn003_@`00o`000>YD0029]P0007@Z000V>P000a/000PR0018
C003R`00bkD00?HX003n1`00h7H005>W0000I3l001H_00026@003bT005]803:L003ISP00o1000?TJ
003BX@006Y@0001CC0002bD000<J000O=@00KS<0M[400>MN003o0@00l3d00;300000OQT003510004
7@001Ql003e600252@37_`00m2l00?h5002MS@0006Dn000F;`000QT0014[001MA@0nX000g8<00?d:
003g8`00c;4000F<0000Ad/000LQ00047000;3d007XO0:Fm003_@@00o`000>QN001d/00006`e000L
=0000QX000dW001HB@0^V`00fHd00?`>003h7P00cjX000^>0000Bdd000PR00047000:cd007XN0:Vn
003`?P00o`400>IS001Y[@0006Ti000H<@000QT0010Z001NA@12XP00gWd00?h7003e:`00akd00025
2P00>TD000DN00067`00?4H008L60<Vi003f9`00o@T00=b4000hWP0005Y8000>:0000QX001dd001^
<P20/`00jU@00?l0003[D000QKD0001`<0007SD0008J000=:000FTP0>Il00=f2003m2000mBX00<Nn
0000Q0`003M300057@001R0004A:00F<003>[000nAd00?/A003FU`007YD0001AC@002B<000<K000[
?@00O1`0]<400?8f003o1000hGD004VT0000GTD0010Z00026@0073@006hb08>d003/C`00o`000>UI
001b/00006Xi000G<0000QT001<]001T?`1OZP00iFD00?l1003^A@00U;T0001b;0007cH0008J000>
:000GDH0AJ<0003c0>1f003o1000lSP00:fo0000NB4002Hj00036P002bH005Q:03FN003MP@00oPL0
0?@`002l``0007dJ000[?@000a/000XT001EB`0^V`00fhH00?d8003e;@00`/@0001n6000;3d000<K
000:9000ED/0;Y/00=b5003n2000m2l00;g30000O1/002Xl00036`002bD005M:03NN003NOP00oPD0
0?<e002__`0007PR000T>@000aX000dW001LA`18X`00hW400?l2003_@@00U[T0001b;@007C@0008I
000A:`00Hd00HZ/00>MO003o0000je<007Fa0000J3X001D^00026@006C4006dd08Rf003^B000o`40
0>=/001>Y@0005e6000=:0000aX002Hj001j7`2i`P00m2h00?d9003IS0008YL0001@CP001b4000@M
000kA@01RP00d:P00?XF003i6`00c;8000262000=48000@L00098`00ED/0<id00=in003n1000lC/0
09bk0000LRd001`d00026@0052d006Pk07Ra003/C`00o`000>AY001?YP0005a6000=9`000aX002Xm
001o5P3OL@00na400=:P0008S@0003i700057@002240055=02VI003LP`00oPD00?4i002M^`00074^
000K<`000QT001H_001[=P28]P00kd@00?l2003PN000=ih0001EB`002B<000@L000iA@02RP00dJ@0
0?/B003g8`00a/00001m6@009c/000<J000?:@00HT40IJ`00>UG003o0000iFD004nV0000FdL000`V
00036`00<D0008D90<f^003j5`00n1d00<Vi0000P1@002Xl00036P003RT0065206F/003ZE`00o`00
0>AX0019Y00005U8000:900011`003I3002:003AX`00o1000?HV0031a00007TQ000Q=`000QT001<]
001Z>@26]@00kd800?l4003MP@009iT0001?CP001R0000HO001>CP0UV000g8<00?l4003_@P00QKD0
001Y>@004b`0008I000S>000O1`0a/000?PP003j5P00cJl000233@00;3h000<J000?:@00Hd00Kjl0
0>a>003o0@00h7P0036L0000DDd000LP00067`00CDh09IP00=f0003o0`00kTL007Zb0000ICh0010Z
00036P00:cd008<>0<f_003j5@00mb8000[ooooo0Ol00001ooooo`007_ooool00ol0003ooooooooo
o`07ooooo`1e001_<@1a[`00iFP00?h4003e:`00bk@000Z>0000D4h000XU00026P006c<006Lk05JX
003ON@00o@T00?PP003AY@006i@0001EB`003BL0008I000F;`00Hd00Aj<00=b3003l3@00nA/00=>M
000TU`0005Q:000?:@000QT001D^001Q@P12XP00fhH00?`>003i6P00e9d002BG0000F4X000hX0002
6@005Rl0069104NS003MP@00o@`00?PM003AX`006i@0001DC00032L0008J000I<@00Ic`0EjP00>5f
003n1`00mRH00<b`000:SP0004m>000990000aX0020f001^<P1c/000iV<00?l2003b=@00aL@00024
2`00?DL000HP00047000;Ch007TQ09^k003]BP00o`000>a=002F^@0007LT000Z?@0011`000LQ0012
B@00Q`@0b;d00?@^003n1000hfh005jZ0000J3/001Tb00026@003BP005M:02RI003FUP00na@00?XE
003EV@0099L0001FB`003BL0008J000K<`00JSL0JJd00>EV003o0P00lSL00;k30000PA4003M30080
00DN0?l003M400224031a000lcD00?l3002TR`0006Pj000I<@000QT000lY001JB00cW@00fX/00?`>
003h7P00cjT000j?0000CTh000TS00036`009c/007LU09Rj003]B000o`000>YF0020]000070`000P
=P000aX000/V001EB`0TV000eYD00?/B003i6@00dZ8001BB0000D4h000TS00036`009c/007LU09bk
003^A@00o`000>QL001e/@0006`e000K<`000QT000hX001JB00gWP00g8D00?d:003g9@00b[H00028
0P00?dP000HO00057P00=d<008<=0<K0003e;@00oPH00=ml0013XP0005i5000@:P000QT001Xb001[
=`1c/000j5/00?l0003]B@00T[P0001c:`008SL000<J000<9P00EdX0;Y/00=Z:003m2`00mb@00<Zf
0000Q`@003a600057P001Al003i700280P3;]000mb800?`=003HS`00:9T0001DC0002RD000<K000W
>P00N2<0Ykd00?4m003o0P00hfd005FW0000HT40018/00026@006C4006/g07Na003ZE`00o`000>]B
001n/`0006dd000J<P000QT0014[001Q@P1CY`00hfd00?l2003`?P00XK`0001f9P008cP000<J000<
9`00FDP0>Yl00=in003n1P00lc400;[20000O1/002/m00036`002R@005A<02^J003JR@00o@T00?DZ
0036`P00080C000_?`0011`000TS001BC@0TU`00fHh00?d;003f9`00akl000214@00<D0000@L0009
8`00DTd099P00=V=003m2`00mRT00<K10000P1@002ho00036`002R@005A<02bJ003KQP00oPP00?@_
002l`P0007`L000Y?0000a/000`V001IB@0lX000ggT00?l4003a>P00Xkd0001e:0008CL0008J000?
:@00H4<0EZP00>EW003o0000kD/008:d0000K3H001P`00026@005Rl006Xh07^b003/C`00o`000>IT
001IZ@000613000?:@000QX0028g001g9@2/_`00lc@00?h6003LQ000;9X0001CC0002B<000@L000e
@`00Q`H0cK000?TJ003j5`00cjX000290000>DD000@M00088P00DTd0:9T00=^6003n1P00lcD00:Vn
0000MBL001lf00026@004B/006Dn06^^003ZEP00o`000>MQ001JZ@000613000>:@000aX002Hj001l
7@3LM`0007`0o0d00=FH000@T00004A:00057P001b0004i>01nF003JR`00oPP00?<c002Z_P0007DX
000N=@000QT001<]001X>P1k/P00kD/00?l1003RL000@Z80001HB@002R@000@L000d@P00Q`D0cZ`0
0?XF003h7P00bKP000214P00:cd000<J000=9`00GT@0FZT00>MO003o0000j5h005^Y0000Gd@000dW
00036`00;3h0088@0<Zf003i6`00nQT00<ba0000Q0`002ho00036`003BL005i505VY003WGP00o`00
0>MQ001EY`0005e6000<9P000a/0035000261`3>Z`00na@00?PQ0037_`0007dJ000U>@000QX0014[
001V?@1i/P00kDT00?l2003ON@00<I`0001BC@001b4000DN0017B`0KU000fX/00?h6003a>`00T[P0
001/=@005Bl0008I000P=P00N280_l<00?HV003k4@00d:P000271@00<D0000<K000=9`00Gd@0Hj`0
0>YE003o0000hW0003bP0000E4`000PR00057P00AT/06i@00=^8003n1@00l40008Je0000JCX0018/
00026P009SX007lF0<Zg003i6@00n1d02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo
00Oooooo0?l006`e06F/003RL000oPH00?HU003>[@004i40001CC00032H0008I000H<000I3l0BZ@0
0=f1003l3000nA/00=>N000TV00005Q9000?:@000QT001@]001OA00lX000fX/00?/A003j5P00eYD0
02jK0000FdL0014[00026@004R`005i503NN003ISP00na800?XE003GU@00;Y/0001KA`0042X0008I
000C;@00Gd@0?:000=Z9003l3`00nQP00=BK000UV00005Q:000>:0000QT001H_001S@01<Y@00gWh0
0?d:003h8@00cjT001>A0000DTd000/U00036P007C@006/g06N]003TJ`00o`@00?@_0038_@0008P3
0013B@001b4000@L000X>`00MRL0SkL00>]A003o0000kTH00:>l0000Nah002lo00047@001Ql003a6
00243035a000lc@00?l2003UI`00JZh0001[=P0073@0008J000<9P00E4`07YD00=>N003j6000na40
0=RA000^V`0005U9000>:@000QT001Pa001W?01MZP00hfh00?h4003d<000a/4000252P00?4H000HO
00057@00<T4007hG0;?0003a>`00o`400:^90000K3H001`c00026P003BL005M:02VI003GT`00na40
0?TI003BX@005i<0001AC@002R@000<K000S>000Lb/0RkL00>]@003o0000k4l008fg0000Lb/002<h
00036`002R@0059=01ZD003CW@00nQH00?/D003EVP007YD0001CC0002R@000<J000S>000LbX0SkL0
0>a<003o0000jU@0086d0000L30001le00026P0032L005M:02fK003IS@00o0d00?PP003=[P001H`0
0016BP001b0000@M000b@@00P1D0_/<00?<c003n1000hG@004jU0000HD80018/00026@005c0006Pk
06N]003VH`00o`400>m2002O^`0007LU000V>P000a/000XT001DC00TV000ei800?`?003h7`00cJl0
00>;0000@TT000HO00057P00>4@008D:0<Rk003f9`00o@X00=^7000bW00005Q:000<9P000aX002<h
001e:@2J^P00kd<00?l1003UI@00HJ/0001U?P0052h0008I000F;`00J3/0Jjh00>MN003o0000kD/0
08^f0000L2l001he00026P003bT005i504RS003QM@00o`@00?8h002^_`0007TP000W>`000a/000/U
001FB`0`W00007/0fhH00?d9003e:`00aL<000205000;cl000@L00098`00DDd08IH00=RA003l3@00
mb@00<Vj0000Q0`003A200047@00224004m>01ZD003FUP00o0l00?LR003:]`0008D9000f@`0011d0
00PQ001?CP0JU000eYD00?`>003g8`00bKX000233@00<d4000@L00088P00DDd08YL00=V>003m2`00
mRT00<K20000OaD002dn00036`002R@005I;03:L003MP@00oPH00?<d002a`00007TR000T>@000aX0
00dX001MAP1;Y000hfl00?l1003^A000SkL0001_<@006c<0008I000C;@00Ic`0Kjl00>YF003o0000
j5`006F/0000I3l0014[00026@007SD007<[09nk003a>`00oP@00=ml000fWP0005I;000:90000a/0
031000233P3:^000n1l00?/C003BXP001hd0000oA`001Ah000LQ001?CP0OUP00fHh00?d9003d;`00
]/40001i8@008cP0008J000?:P00HD80H:/00>MN003o0000jET006J/0000Hd00010Z00026P008SP0
07PS0=Eh003m2P00f90001ZD0000BTd00P001Ql0MP00Ad/05Y800=NC003m2`00mBd00;O10000N2<0
028g00026P004B/006Dn06n_003[D`00o`000>EX001=Y@0005]7000<9P000a/002lo00233@3;/`00
nAX00?XI003</@0008@:000`@0000a/000/V001KA`1>Y@00iFL00?l0003ZEP00Ijd0001R@@003bT0
00<J000X>`00OQL0akd00?PP003k5000cjX000271000<d4000<K000;9@00FdP0CZD00>EV003o0000
jET0066[0000H4<000dX00036P00;3h008<?0<bc003j6@00nA`00<Zh0000P1<002Tl00036P003bT0
06=006f^003[D000o`400>9a000lX00005E;00088P001Ad00458016A003GT`00o@T00?<e002O^`00
070`000H<@000QT001`d001e:02b`000mB/00?`>003CX0000XX0000f@`000a`000/U001LAP1GZ000
j5d00?l0003UJ000AZ<0001GBP002B<000@M0010B00BT@00f9000?h7003a>@00TkP0001/=@0052h0
008I000R>000O1`0akl00?PN003j600:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool0
1oooool0E@00JCX0FJT00>1h003m2@00n2000=6U000LU@0005I;000>:0000QT001D^001Q@P0oX@00
fXT00?`@003j5P00eYH002jK0000FdL0014[00026@004B/005a6036L003GT`00naD00?/B003ISP00
>9h0001NA@004b`0008I000@:P00FTP0;I/00=JF003j5P00na400=V=000hWP0005i5000B;0000QT0
014[001LA`0bW000f9400?/C003k5000ei<002nK0000FdL0010Z00026@0052d00613046Q003LQ@00
o0d00?TL003BX@007ID0001EB`0032L0008J000I<P00Ic/0FjT00>5b003n1P00mBT00<^e0004R`00
04Y<00088P000a/002@i001b;@22]000jET00?l0003`?`00/<00001n5`00=4800P001Ah0o`00=T<0
080C0;S1003a>`00o`400>MO001g/@0006lb000P=P000aX000XT001AC@0ETP00dJD00?TM003l3@00
fXT003RN0000G4H0010Z00026@005Rl006@o05:W003PMP00oPH00?DZ0039^@0008P20012B@001b00
00@L000]?P00Nah0Y[d00>m2003o0000/XH0001_<@007cH000<J000;9@00E4`07iH00=BK003j5@00
na@00=FI000QUP0005A<000;9@000aX0020f001`<01o/`00jEL00?l0003^A`00V[X0001g9@009c/0
00<K00098`00Cdh04I400=6U003i6`00o1000=NC000WV@0005I;000<9P000aX001lf001`<022]000
jU@00?l0003/C@00S[L0001c:`008SP000<J000;9@00E4`08iL00=JE003k4@00nA/00=2V000>S`00
04a=00088P0011`002dn001l702a`000lCT00?l2003SK000FZT0001T?`0052h0008I000D;P00I3l0
FjT00>A[003o0P00lC/00:bo0000NQl002Xl00036`002B<0055=01ZD003EVP00na<00?TJ003@Y`00
38h00019C0001b4000@M000c@@00PA40aL<00?@]003n1`00gWl003bP0000FdL000hX00026P007cH0
074^08fg003]BP00o`000>QM001][P0006Pj000G<0000QT001@]001T?`1OZP00iFH00?l1003_A000
V;X0001d:P008CL0008J000=9`00FTP0?J000=im003n1P00lc800;_20000OAX002/m00036`002B@0
05=<02JH003ISP00o@`00?HV0038_00008<=000d@P0011d000PQ001>CP0GT`00eIT00?`@003h7`00
c;<000271000>TD000DM00078000BD`04I000=>N003k4`00nAd00<f`0000R08003]500057P001b00
04U<016A003DW@00na800?PN003</P0008L5000hA00011d000LQ001>CP0IT`00eYH00?`>003g8`00
bKX000233P00<T4000@L00098`00Ddd0:9T00=Z9003m2@00m2d00;k30000O1`002Pl00036`0032H0
05Y8042Q003PMP00o`<00?0n002K^`0007</000N=@000QT0014[001S@01SZ`00ieh00?l0003ZE@00
LJl0001W?00052d0008I000K<`00L300T[P00>m2003o0P00hG@0046Q0000FDT000/V00036`002000
;3d007lE0<No003g9@00o0l00=FJ000@T00004E:0P001Ql0TP00B4`05I800=JF003l3000mRT00<C4
0000O1/002Lk00036P003RP005i505BW003UI@00o`000>]B001b/00006Hl000C;0000QT001he001e
:@3>NP00oPL00=^8000SU`00051>00078@001Ah0045800f?003DV`00o0h00?HW0034a00007`L000V
>P000aX000lY001Q@P1SZ`00jEX00?l0003WH000FJT0001OA0003BP000<J000Z?@00P1@0b;/00?PO
003k5000cjT000280`00=D8000@L000:9000F4T0@j800>=^003o0@00k4l007>`0000ICh0014[0002
6P0093T007/N0<C4003f9P00o1000=:R0003R`0003Q4000470002R@005M:04:R003SKP00o`000>]B
001/[P0006=0000?:@000aX002Pk001o5P39^P00n1h00?XG003=/00008@<000^?`000a/000dW001P
@`1QZ`00jEP00?l0003TJ@00Aj<0001HB@002R@000@L000kA@09S@00e9/00?d<003d;P00[;l0001c
:`006c<0008I000I<@00LBh0YKd00?<a003m2P00eIP000^>0000?4H000@L000:9000FDT0C:D00>IT
003o0000if0005:V0000FdP000XT00047000>TD02Hd00=FH003m2P00lc<00:2l0000Kc4001L`0002
6@007cD007PS0<;4003g8`00na@02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo0?l006Dn04jU003MO`00o@`00?TK003DW@009YP0001IB@0042X0008I000C;000GTD0=Id00=RA
003k5000na800=V>000iW`0005m4000C;@000QT000lZ001IB@0WV@00e9/00?TI003l3P00fhH004>R
0000HD8001D^00026@003RP005M:02>G003CWP00nAX00?`=003LQ@00@j80001Q@P005Bh0008I000?
:@00FDT0:9T00=FI003j5`00o1000=Z;000iW`0005i5000B;0000QT0014[001MAP0fWP00fHd00?/A
003j5`00eIT002JH0000F4T000hX00026@005c0006@o04nV003ONP00o@P00?LT003=[P003Hl0001?
CP002R@000<J000P=P00Kc80M[400>MP003o0@00lSP00;g30000PQ0003U400067`001Ad00350001m
6P2[_P00kd400?l0003YE`00Pk@0001b;@008cP000<K00098`00CTh038h00<j]003g8P00o@X00=f1
0013XP000613000B;0000QT001<]001Q@`17X`00gWh00?d9003g9@00c;8000F<0000B4`000PR0003
7000:C`007LT09Vj003]B@00o`000;V40000LR`002<h00036`002R@0055=01JB003BX`00nAX00?`@
003HT@00:iX0001GBP003BL0008J000L=000K3D0Lk000>MN003o0000kd400:Nm0000NQl002`m0004
7000224004U<00R=003>[@00n2000?`=003JR`00<Y`0001IB@003BP0008J000L=000KC@0M[400>QK
003o0000kTH009^j0000MRD002Hj00036`002B<0055=01VD003DW@00nQD00?XF003CW`005i<0001@
CP002B<000<K000X>`00NB80Y;d00?10003o0@00iV@006J/0000Ic/001L`00026@004R`00652052V
003QLP00o`@00?<e002i`P0007hH000^?`0011`000PR001=CP0AT@00dZ800?XG003j5@00dil001FB
0000Cdh000PR00047000;Sl007hH0;_2003c<`00oPD00>1g0017X`0005i5000?:P000QT001`c001^
<`20]000je800?l0003ZEP00NK80001/=P006C80008I000A:`00HD80DjL00>=^003o0P00l3d00:Fm
0000Mb@002Di00036P002bH005M:03:M003LQ@00o@P00?D/0035`P00080C000`@00011`000PR001@
CP0LU@0001X0eYH00?`?003h8000bk@000271@00>DD000DM00078000B4/03Xl00=:Q003k5000nAX0
0<n[0003R`0003m800057P001Ql004=900R=003@YP00nQL00?XH003@Z0001X`00011B08000HO0=L0
04=900R=003AY@00nQH00?TI003?Z`000XX0000nA`001Ah000HP0017B`0?T000dih00?/B003h7P00
c;<000261P00=d<000@M00088@00D4h07YD00=RA003m3000mRP00<K10000P1D002dn00036`002R@0
05I:03FM003NOP00oPD00?8g002X_P0007HV000Q=`000QX000lY001P@`1GZ000iFD00?l0003/CP00
OK<0001Z>0005Rl0008I000H<@00K3D0Q[D00>e8003o0@00hf`004bU0000G4H000dW00036P009c/0
07`L0<74003e:P00o@/00=NB000IU00004a=000680001Ah0049900b?003CWP00o1000?LS0037_P00
080D000[?@000a/000`V001KA`19Y000hfd00?l1003]B`00O[<0001Z>0005Bh0008I000K<`00LBh0
aW/00?h5003MP@00;I/0001CC@00228000@M000kAP04R`00dJ<00?/B003g8P00akd0001o5P00:S`0
00<J000=9`00GTD0EjP00>IR003o0000jET006B/0000HT4000lY00036P009SX007`K0<G2003g9@00
o1000=:Q0005S00003]500047@002B<005E;03RN003PMP00o`800>i8001o/`0006Tj000C;@000QT0
020f001g902g`@00mB/00?`<003EVP002hh0000nA`0011d000PR001DC00hWP00hGD00?l1003]B`00
NK80001V?0004B/0008J000T>@00O1`0a/800?LS003k4`00cjT000271000<d4000<K000<9P00G4H0
EZP00>MO003o0000iV8005:V0000FdL000/U00037000=T<008X00=:R003l3`00mRT00;W20000MbD0
01he00026@005Rl006hc09Rj003b>000oPL00=R@000DT@00049900057@002B8005I;046Q003SK000
o`000>UI001MZP0005i5000<9P000a/003E2006:003CX000o0d00?D]002]_`0007<[000J<P000QT0
01/c001e:02e`@00mRT00?`@000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0o`00HT40@j800=^7003l3`00nQL00=JE000`W00005a6000B;0000QT0010[001JB00[VP00eIT0
0?XH003l3P00fhH004>R0000HT4001H_00026@003RP005I;01fE003BX`00n1h00?d;003NOP00CZD0
001U?P006340008I000=9`00E4`06I@00=6U003h7`00o@X00=im001>Y@0006@o000G<0000QT000dW
001FB`0NU@00dZ400?TL003l3000g8<004BR0000HD8001D^00026@003bT005Y802bJ003FU@00nQD0
0?/C003HT@00<I`0001KA`0042X0008I000D;P00HD80A:800=f2003m2`00n1h00=2V000FTP00059=
000;9@000aX001dd001[=P1Z[@00iFP00?l3003c<P00a/4000252@00?dL000HP00047000;Ch007TP
09jk003]B000o`000>]@002?^00007DW000W>`000a/000PR0018B`03R`00bkD00?HW003n1`00ggT0
04jU0000Hd0001D^00026@004B/005e503bP003KQP00o@`00?PP003?ZP003Xl0001?CP002B<000<K
000U>@00M2X0SKL00>]@003o0000`8<0001f9`009c/000<K00088P00CDh03Hl00<nZ003h7`00o0d0
0=Z9000eW@0005]8000?:@000QT001Ta001Y>@1W[@00iFH00?l2003a>P00]<00001n6000<40000@M
00078000@dT008X00<^d003g9@00o@X00=b3000lX00005a6000?:@000QT001Ta001Y>@1Z[P00iV<0
0?l1003`?`00Z;h0001j7`00:cd000<L00088P00CTh049000=6U003i6P00na800=JG000QUP0005=<
000:90000a/002@i001e:02G^P00kTL00?l0003XG@00L[00001[=`006S80008I000@:P00GTD0AJ80
0=mj003n1P00m2l00<G40000PA8003=100047@001b0004M;00R=003?ZP00nA`00?/A003FU`007YD0
001BC@002B<000<K000Y?000NQl0[[l00?4j003o0`00hVl005:W0000HD80018[00026@006C4006Xg
07B`003YF@00o`000>a?0025]@0006la000M=0000QT000lY001NA@18X`00hGD00?l4003b=P00/L00
001k7P00:C`000<K000:9000E4`0:9T00=V=003m2`00mRH00<Rk0000Q0`003E200047@001b4004a=
01>A0000l`3CWP00na<00?TK003>[@000XX0000oA`001Ah000HO0012B@06S000cjT00?XI003j5P00
dJ<000^>0000ADX000HP00057P00?DH008T00<j^003i6`00na@00=>P000>S`0004M;000680001Ah0
03e6002:003>[@00nA/00?/E003BX`002hh00014BP001Ql000DO0011B007S000d:H00?XF003i6@00
cZ/0006:0000?4H000DN00078000BTd05I800=FI003l3`00mb800<Vj0000P`h00391000470002B<0
05=<02^J003KQP00oPL00?@a002e`@0007XP000U>P000aX000dX001MAP1<Y@00hfd00?l1003^A`00
R[H0001^<`006C40008I000E;`00JCT0NK800>]@003o0000iVD005NX0000H4<000lY00026P008cP0
07TR0;C1003d<000o@P00=Z;000SU`00051>00078@001Ad003a600B;003AY@00na@00?PN003:]P00
08<=000`@0000a/000XU001HBP0nX000hGD00?l2003_A000RkH0001]=0006300008I000H<@00KS<0
_gd00?l3003PN@00>9h0001FB`002B<000@L000f@`00R0<0cj/00?XF003i7@00b[H000233P00;Sl0
00<K000<9P00FdL0C:D00>AY003o0000je80072_0000ICh0014[00026P008SP007TQ0;c2003e:P00
o0d00=FJ000=S`00041800057P002240059=02jK003NOP00o`<00>m1002<]`0006`e000F;`000QT0
01`d001d:P2Z_P00lc400?d9003GTP0059800014BP001Ah000LQ001AC@0]V`00gWd00?l3003_A000
QKD0001Z>00052d0008I000P=P00N2<0_<<00?HX003l3`00dZ4000>;0000>4@000@L000:9000FDT0
BZ@00>EW003o0000jEX005fZ0000GT@000`W00036`00<D0008H70<nZ003k4`00mb<00<G30000NQl0
028g00026@0052d006/g08^g003`?P00oPD00=^8000MU@0004Q;00057P001b4005=<03JN003QM000
o`400>]A001Y[@000652000=:0000a/0031000261P3@Z000na400?HW002j`P0007HV000M=0000QT0
01Pa001a;P2X_P00m2l00?`<000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0o`00Gd@0>9h00=R?003k4`00na800=V=000jW`0005m4000D;@000QT000lY001GBP0QUP00dZ00
0?TM003m2`00gWh004jU0000ICh001Pa00026P0032H005=<01BB003?ZP00mb<00?h8003PMP00FJT0
001X>`006c<0008J000;9@00DDd049000<j]003g9@00oPL00>5e001IZ@0006Pk000J<P000QX000/V
001CC@0ETP00cjT00?PQ003m2@00gg`004nV0000I3l001L`00026@003BP005M:02:G003DW@00nAT0
0?`?003JR@00>il0001NA@004R`0008I000B;000GTD0>Yl00=Z:003l3`00nAX00=>O000OUP0005E;
000<9`000QX001Xb001X>P1NZP00hW000?h5003e;000bKX000290@00ADX000LQ00037000:3/007HV
096h003/C`00o`000>e9002L^`0007TR000/?@0011`000LP0012B@00Q`@0b;`00?D]003n1@00hW40
05VY0000ISd001L`00026@003bT005Y803:L003IS@00o0l00?TK003BX`005i<0001BC@002R@000<J
000Q=`00LBl0P;@00>UG003o0000b840001i8@00:cd000@L00078@00Ad/018/00<bb003g9000o@X0
0=f2000oX@0005i5000A:`000QT001H_001V?@1KZ@00hfh00?l3003c=000`L@000214P00=D<000DN
00067`00?DH008H70<Rl003e:P00oPL00=mk0017X`0005m4000A:`000QT001H_001V?@1NZP00i6X0
0?l2003b>@00]<40001m6@00;cl000@L00078@00Ad/028d00<j/003h7`00o0h00=R?000ZVP0005I:
000<9P000aX0024g001b;@2;]P00k4h00?l0003ZE@00O[<0001^<`007C@0008J000>:000FdL0>Yl0
0=f2003m2000mRT00<Rl0000Q@X003Q400057P001Ql00418002:003</@00n2400?`>003HS`009iT0
001EB`002bD000<K000U>P00MbD0XK`00?10003o0@00iFL005jZ0000I3l001@]00026@005Rl006Lk
06R]003WH000o`000>i8002A^000078/000P=P000QX000dX001KB00mX000gWd00?h6003d<000_/<0
001n6000;Ch000<L00098`00DDd07iH00=ND003l3`00n2400<^d0000Q`@003Y500057P001R0004E:
00Z>00010=6U0080nQL002/0dJD000Z>0000ADX000HP00057P00?4H008T10<f`003h7@00na800=BL
000DTP0004a=00078@0011d003M400261`3;]@00n2000?`@003EV0005i<0001>CP001b4000@M000g
A000QPL0bk@00?PO003k4@00e9/001>A0000BTd000LP00057P00>dH008T00<j^003i6`00nQD00=6T
0009S@000499008000HO0<<004A:00b>003BX@00na<00?PM003</P0008H6000g@`0011d000PR001@
CP0QU`00fHh00?d:003e:`00`/@0001m6P00:C`000<K000<9P00FTP0@J400>5e003o0P00l40009Ji
0000LBh001`d00026@004bd006Hm06f^003YE`00o`000>QM001SZ`0006=0000A:`000QT0020f001e
:02W_P00lSH00?h6003LP`00;I/0001CC0002B8000@L000g@`00R0<0cZd00?XH003i6@00cJl00027
1P00=D8000@L00098`00ED/0<id00=im003o1000l3d009Nj0000L2l001Xb00026@005Rl006Xg0;Qn
003o0@00hW4004:R0000FDT000/U00036`00<D0008@;0<bb003i6`00nQP00<f^0000QPL003=10004
70002R@005Q9046Q003RL@00o`400>e:001l/`0006Pj000C;@000QT001le001f9`2__`00m3000?d:
003GTP005Y800016B`001Al000LP001?CP0TV000fhH00?h5003a>P00V;X0001_<@006340008I000I
<P00L2l0WK/00?8h003n1`00fX/001fE0000BTd000HO00068000CTh099L00=b5003n1@00l3d0096h
0000KC@001H_00026@007C@007DX0:no003d;P00o@`00=FI000;SP0003e700047@002B<005I;03nQ
003SK`00o`000>]C001Y[@000692000>:0000aX002`m00233P3</P00nQL00?PN0038_00007hI000U
>P000QX0018[001W>`1o/`00kTD00?l3003MP0009YP0001>CP001Ql000HP001@CP0/VP00gg/00?l2
003]BP00MK00001T?`003bT000<J000[?@00P`h0cJl00?XE003g8P00aL<0001j800083H0008I000F
;`00KS<0VkX00?<e003m2@002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo
0?l005a702jK003FU`00nQP00?`?003KQP00AJ80001R@@005Rl0008I000=9`00E4`069<00=2X003g
8P00o@P00>1f001JZ@0006Pj000K<`000QX000XU001@CP0;SP00c;800?HX003n1@00hfh006F/0000
JcH001he00036P002R@004i>00R=003;]@00mBX00?h5003SK@00IJ`0001[=`007CD000<J000:9000
D4h038h00<f`003f9P00oPL00>5d001JZ@0006Pk000J<P000QX000`V001DC00IT`00dJD00?PN003m
2`00gH8004FS0000HD8001D^00026@0042X005]802nL003HTP00na<00?XE003FU`00:IT0001HB@00
3RP0008I000G<000ICh0DjL00>1g003n1`00mRL00<bc0006S00004]=00088P000a/002@i001c;025
]@00jUH00?l0003_@P00ZKh0001l6`00<40000@M00067`00?4H008@;0<G3003c<`00o`<00>AZ001U
[00006Ti000J<P000QX000dW001GBP0XV@00eYD00?/C003j5P00e9/0022F0000ED`000`V00026P00
7SD006dd07B`003WG`00o`400<mo0000OA/0031000047@001R00045800280`39^@00mBT00?h7003O
NP00BZ@0001Q@P004b`0008I000D;@00HT40D:H00>5e003n1@00m2h00<No0000Q@X003]500057`00
1Ah003M400233P35``00m3000?h5003QL`00DZH0001S@@0052d0008I000D;@00Hd00DjL00>9b003n
1000lc800<740000PA8003A200047@001R0004580029003;]000mb@00?d;003KQ`00=9d0001IB000
3BP0008J000M=000KS80Ok<00>YE003o0000k4h008Zf0000LBh0020f00036P0032L005Q:032L003J
RP00o@/00?LT003;]@0008P3000nA`001Ql000DN000kA@00QPL0bKT00?HV003m2P00fhP0036L0000
F4X000`V00036P008SL007<Z09Bi003^A`00o`000>MP001Y[@0006Pk000F;`000QT001<]001T?`1M
ZP00iFP00?l1003_@@00W[/0001f9`0093T000<J000<9P00F4X0<id00=b5003m2@00mB/00<K10000
PA40039100047000224004i>01FB003DW000na800?TL003>[0000h/00010B0001Ql000DO000oA`02
RP000?<0cZd00?TL003k4`00e9d001>A0000C4d000LQ00047@00=T<008D90<Zh003g8`00o0h00=ND
000MU@00051>00088P0011`0039100233`38_000mRH00?d<003HT@008IH0001AC@00228000@L000b
@@00P`h0b;`00?LU003l3@00ei<001fE0000Cdh000PQ00047@00=T<008D80<^e003h8000na400=BL
000BT@0004Q<000680001Ah003i700>;003?Z@00nQL00?XH003?Z`000HX0000lAP001Ah000LP001<
C@0HT`00eYH00?`=003f9@00akh000204`00;Sl000<K000:9000EdX0=ih00=im003n1000lCT00:>l
0000M2T001lf00026@004B/006=006:[003WGP00o`000>YF001_[`0006Hm000C;@000QT001`d001b
;@2K^P00lCd00?l4003ON`00=ih0001FB`002R@000@L000b@@00Q0/0bk@00?TM003j5@00d:L0006:
0000>TD000@M00088P00DTd0:IT00=b4003n1P00lSL00:Bm0000M2X001he00026@004bd006Lk0;60
003o0000i6T004fU0000G4L000`V00036`00;3h0084B0<Vj003h7`00na@00=2W0000RP0003Q40004
70002B<005E;03NN003PN@00o`800>m40028]P0006`f000F;`000QT001/c001b;02R_000lSH00?h7
003JRP007iH0001=CP001R0000HO0019C00KU000fHh00?h8003c=000YKd0001c;0006c<0008I000G
<000KC@0T;P00?0n003n1000g8<002NI0000D4h000LP00067`00B4`06Y@00=V=003n1`00lSL009jk
0000L2l001Ta00026@006S80074^0::l003c=000o@T00=RA000DTP0004=900057P00228005=<03FM
003PMP00o`400>a<001e/00006Dn000@:P000QX002Pk001o5@39^@00nA`00?TI003;]@00084B000Z
?0000aX000lZ001T?`1c/000k4`00?l2003PN@00<9`0001AC@001b0000HO001;C@0RU`00g8<00?l4
003_@`00PK@0001W>`004B/0008J000W>`00P1D0b[L00?TJ003i7@00b;`0001m6P0093T0008I000C
;@00JcL0SkL00?4k003n1`002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo
060005U902BH003CW`00nA`00?d;003NOP00CjH0001V?@006C80008J000;9@00DDd03i000<f`003f
9`00oPH00>=_001U[00006`f000O=@000aX000TS001;C@03R`00bKT00?@^003o0`00iFL0072_0000
KS80024g00036`00228004Q<00290038_000m3000?l3003UIP00L:l0001^<P008CL000<K00098`00
Bdd00h/00<Zh003e;000oP@00>=/001V[00006/g000M=0000aX000XU001AC@0@T000cZ`00?LS003m
2@00ggX0052V0000ICh001L`00026@003RP005M:02JH003EV@00nQL00?/A003HS`00<Yd0001KA`00
42X0008I000D;P00HT40B:<00=io003m2P00mb400<j[000?T000051>000:90000aX0024g001_<@1i
/P00ieh00?l1003a?000]L4000205@00=D8200057P2D000f@`00PA<0^/800?4i003o0@00iV80072_
0000KCD001dd00026P002bH005A<01jE003DW@00nQL00?/B003GT`00:YX0001HBP003BL0008J000J
<P00JSP0J:d00>EV003o0P00eWd000205000=48000DN00067`00>dD008@;0<K0003d;`00oPD00>9b
001EY`0006@o000E;P000QT0018[001OA015X`00gWd00?h8003f:000bKP000280`00@4P000HP0004
7@00<T4007lE0;[2003b=P00o`<00>=/001MZP0006Hm000F;`000QT0018[001P@`18Y000ggT00?h6
003e;000akl000242`00>D@000DN00057`00?4H008H70<Rk003f:@00oPP00=eo000oX@0005a6000?
:@000QT001Xb001[=`1c/000j5`00?l0003^A`00U[T0001e:00093T000<J000;9@00ED/09YP00=RA
003l3`00n1h00<j^0004R`0004A:000680001Ad003E300233P36`000mB/00?h7003MP000?:00001K
A`003RP0008J000N=@00L300R;H00>a>003o0000jET007Fa0000JcL001Ta00026@004B/00652056V
003RK`00o`<00?4j002[_P0007TQ000W>`000a/000XT001EB`0YV@00fHd00?d<003g9@00bKT00025
2P00=d@000DM00078000B4/03Hl00=6T0080nQL00?X0dJD000^>0000AT/000HP00057P00>TD008L5
0<^d003h8@00o0l00=JF000LU@00051>00088P0011`0035100224037_`00mRP00?d;003IS0009iT0
001CC0002B<000<K000^?P00OaH0aL<00?D[003m2@00fXT002ZJ0000E4`000XT00036`00;Ch007lE
0<G3003e:P00o@X00=Z<000VV000059=00098`0011`0035000224038_000mbD00?`=003GU0006i@0
001?CP001b4000@M000iA000R0@0cK000?TL003k5000dJ<000V=0000@TT000DO00067`00AT/03i00
0=BM003k4@00n2000<Zg0000Q0`00391000470002B<005A<02fK003LQ000oPL00?<c002__`0007PS
000S>0000QX000lY001OA01FZ000iFH00?l0003/C`00N[80001Y>@005Bl0008I000I<P00KS80S[L0
0>m3003o0P00hG<0046Q0000FDT000/U00036`00;Ch0084B0<Rl003g8P00na400=>P000:SP000418
00057P001b0004m>022F003IS000o@P00?@a002a`00007LU000Q=`000QX0014[001T?`2ZP`00o`00
0>IR001HZ00005m4000>:0000aX002Pk001n6@36`@00mb@00?`@003CW`0028d0000nA`001Ad000PR
001BC@0/VP00gH000?h4003`?@00UKT0001_<@006C40008I000H<@00Kc40UKT00?4l003n1@00gH80
02VI0000DDd000LQ00057P00@dT04Y400=JE003m2`00m2h00;;00000MRH001le00026@0052h006Xh
08Be003^A@00o`<00=mk000aW000059=00088@001Ah00499016A003GU@00o@X00?@`002[_P0007@Z
000L<`000QT001L`001^<`2F^@00lCX00?h6003JRP007ID00019C0001Ql000LP001@CP0[VP00gWh0
0?l3003^A@00PK@0001X>P004R`0008J000T>@00O1`0a/000?PQ003j5@00cZh000242`00;Sl000<K
000>:000HD80Ijd00>]C003o0000hW4003^O0000E4`000PR00057P00ADX06I@00=Z;003n1P00l3d0
08fg0000JcL001@]00026@008cP007`K0<Nn003h7P00nQP00<^e0000P1<002Pk00026P004B/006Lk
08:d003_@P00oP@02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l005I;
01^D003@YP00n2400?d8003PMP00FjT0001Y>@0073@000<J000:9000CTh01X`00<Zg003e;@00o`@0
0>EW001a[`0006la000R>0000a/000PR0015BP00Q`@0a/000?<d003o0P00iel007bb0000LRd002Di
00036`001b40049900261`35``00lSH00?l1003WG`00O;<0001b;@0093T000<K00088@00A4X008P4
0<No003c<P00o`<00>EU001a[`0006hb000P=`000aX000TS001=CP07S@00bk@00?HX003n1P00hG80
05^Y0000J3/001Xb00026P0032H005A<01bE003BX@00nA/00?`>003KQ`00?J00001NA0004R`0008I
000B;000GT@0?J000=^7003l3@00nA`00=6T000HT`0005=<000;9@000aX001dd001/=@1][P00iFD0
0?l2003b=@00`/@000233P00>TD000HO00057@00<D4007dI0:fo003`@000o`000>QK001l/`00070`
000Q=`000aX000XT001AC@0ETP00dJ@00?TL003l3P00fH`003BM0000FdP000lY00026@00630006Ll
05fZ003SKP00o`@00=ak0000P`d003Y500057`001Ah003I300214P2o``00lSD00?l3003TJ`00H:/0
001W>`006300008I000@:P00G4H0>il00=b5003m2`00mb<00<ba0004R`0004I;00078@0011`002hn
001l702]_`00lCd00?l1003VI000J:d0001Y>@006C40008I000?:P00GDH0?Z000=f1003m2@00mRL0
0<Zh0000R0@003m700067`001Ah003I300223`35`P00m2l00?h5003PN000BJ@0001P@`004B/0008I
000G<000J3/0Ijd00>IS003o0@00l4000:>l0000N2<002Pk00036`002B@0059=01fE003EV@00na80
0?TJ003@YP003Hl0001:C0001b4000@L000a@000OaD0`<<00?<a003n1@00h7P004JS0000GTD0010Z
00026@006c<006dd07bb003ZE@00o`000>]B0021]00006hb000L=0000QT000lY001NA@17X`00h7L0
0?h4003c=000]l40001l6`00;3d000<K00098`00DTd07iH00=ND003l3`00n2000<bb0000R08003e6
00057P001Ql0049900B;003>Z`00nA/00?/C003DW@005980001=CP001b4000@M000d@P00P`d006T0
b;`00?HV003m3000fHh002JH0000Dd`000TS00036`00;Ch007hG0<;4003d;@00oPP00=b5000aW000
05I;000;9@000a/002Tl001l702i`P00m3400?h6003MP@00=9d0001GBP002bD000<K000Y?000O1`0
^l800?@`003n1`00g8@0032L0000ED/000XT00036`00;3h007lF0<G3003e:P00o@X00=V=000TV000
059=00088P0011`003A200242`3:]`00n2400?`@003DW0004Y400018C0001R0000DN0010B007S000
dJD00?XE003i6`00cK0000271000=d@000@M00088P00DDd08iL00=V<003m2@00m2d00;c30000Nad0
02Lj00036P003BL005a604^T003SK@00o`400>i80027]@0006de000H<@000QT001L`001[=P22]000
kDX00?l1003SK000C:D0001LAP003BL000<J000Y?000OAT0aL<00?HW003l3@00eIP001:A0000AT/0
0P001Ql0R000BD`05i<00=ND003m2`00mB/00;g30000NQl002Di00026P003bT006520:>4003o0000
j5X006>/0000HT40010Z00026P0093T007XO0;k3003e:P00o0`00=JH000AT00004A:00057P001b00
04m>02>G003KR000oPH00?8g002Q_000078/000K<`000QT001H_001/=P29]P00kd<00?l3003ON`00
<id0001DC000228000@M000mA`09S@00e9d00?`>003f:000_/<0001i8@008SP0008J000B;000Ic`0
N;400>e;003o0@00hG<003^O0000ED/000TS00047@00?4H02Hd00=BL003l3@00mB/00;O10000MbD0
01lf00026@0052h006/g08Zf003_@@00oP@00=f2000WV00004m>000680001Ql004a=026G003KQP00
oPD00?0n002=]`0006/f000E;P000QT0020f001i8P2o``00mRH00?/A003@YP0008P3000c@@000a/0
00`V001NA@1LZ@00jEX00?l0003TJ@00AJ<0001GBP002B<000@M000oA`0@T000ei<00?d8003b=P00
VKX0001^<`005Rl0008I000P=P00NB80`l@00?LS003k5000cZd000243000;3h000<J000?:@00I3l0
M[400>e8003o0`0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`00Ddd0
4Y400<j^003f9P00oPH00>=_001V[00006`e000O=P000a/000TS0018C000R@40akh00?<c003o0P00
if0007bc0000LRd002Hj000370001b4003m700242`2o``00lCX00?l1003YF000R;H0001e:000:C`0
00@L00068000?4H008<?0;_2003a?000o`000>UG0028]P0007DX000X>`0011`000LP000nA`00Q0/0
`/@00?8h003o0@00j5d007fc0000LBh002@i00036`00228004M;00290038^`00m2h00?h4003TJ`00
Ijd0001[=`007C@000<J000;9@00DTd04i400<nY003h8000o@X00=f00017X`000692000D;P000QT0
010Z001KA`0cW@00fHh00?/A003j6000e9`0026F0000ET/000dW00026P006S8006Tj066[003SK@00
oP@00?@`0037_`0008H60010B0001b0000@L000]?P00NR00XK`00>i6003o0000jU@008Rf0000Lb/0
02@i00036`002B<004i>00b?003>[000n2400?d;003LQ000?Z00001NA@004B/0008I000E;P00I400
DZH00>5e003n1P00gg@000271@00?dL000HP00047@00<D0007hH0;;0003a>`00o`400>IS001/[P00
06Xg000K<`000QT000hX001IB@0aW000fH`00?`>003h7P00cjX000f?0000CDh000PR00036`00:C`0
07TR0:6l003_@`00o`000>QM001d/00006`e000L<`000QX000hX001IB00cW@00fXT00?d<003g8P00
c;4000>;0000A4X000LP00047@00<D0007lF0;c2003c=@00o`<00>9`001DY`0006=0000C;@000QT0
01D^001U?P1LZ@00i6/00?l2003a>P00[kl0001k7@00;3d000<L00088P00Cdh059400=:Q003j5`00
nQD00=>O000FTP0004m>00088P000a`002`n001l702c`000lSL00?l3003RL@00DJH0001Q@P004R`0
008I000H<@00JSP0L:l00>QL003o0000kD/008fg0000LBh001lf00026P003BP005]803bP003NO`00
oPL00?@^0034a000080D000`@00011`000PR001?CP0FT`00e9`00?/C003i6`00cj/000F<0000@TT0
00HO00057P00?4H008P30<bc003h8000o0l00=JF000MU@00051=00088P0011`0031000205000Q@35
``00mB/00?d9003KQP00;i/0001FB`002bD000<K000Y?000Nah0]L400?<c003n1@00gWd003^O0000
FDT000`V00036P009CX007PR0:fo003b=`00oP@00=mj000nX00005Y8000<9`000aX002Dj001i8P2^
_`00lSH00?h5003NO000>Yl0001HB@002bH000<K000X>`00Nad0^/800?@`003n1`00g8D002jK0000
E4`000XT00036`00;cl0084B0<Nn003f9P00o0d00=ND000KU00004i>00078@001Ad003Y50029003>
[000nAT00?XG003?Z@000X/0000mAP001Ah000LP001=CP0JU000ei@00?d<003f:000aL80001n5`00
:cd000<K000;9P00FDT0@J400>5e003o0P00kd4009>h0000L30001/c00026@0052h006Pj07Ja003[
D@00o`000>IT001GZ00005m4000>:@000aX002Di001j7`2k`P00mBd00?d:003HT0006i@0001<C@00
1b0000DN0013B@0>S`00e9/00?`?003f9@00a/40001n6000:C`000<J000=9`00GTD0W8H00?l0003Z
D`00Kjl0001U?P004R/0008I000P=`00MbD0/L000?@`003m2@00f90001ZD0000BT`00P001Ql0K000
BT`06Y@00=R@003m2@00m3400:jo0000MRL001le00026@004bd006Pj07fc003]BP00o`400>5c000m
X00005I:00098`0011`003Q4006:003AY@00na800?LS0036`@0007dJ000V>P000QX0010Z001S@01/
[P00je800?l0003SK000AJ<0001HB@002R@000@L000g@`00RP00dJ@00?/A003f9@00a<@0001j7`00
8cP0008J000B;000J3/0O[<00>i7003o0P00ggX0032L0000DTd000LQ00057P00AT/069<00=V=003n
1`00lSP009Vj0000Kc8001L`00026@007C@007DX0;?0003e;000o0d00=>O0004R`0003Q400047000
2bD005]8056V003VH@00o`000>IR001@YP0005Y8000:900011`003Y500R=003EVP00o@/00?@`002V
_@00074^000I<@000QT001`d001e9`2g`@00mRT00?`@003@YP0008L4000a@0000a/000dX001Q@P1[
[P00k4l00?l100[ooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo
1Ol00007ooooo`03o`000?oooooooooo00Oooooo0500051>00V=003;]@00mB`00?l4003UI`00LK00
001_<@008cP000<K00088@00@TT008D80<?4003b>@00o`400>UI0028]P0007DW000Z?00011`000HO
000jA@00PA80/l000>m1003o0000je4009Bi0000N28002dn00047@001Ql003M3001o5P2^_`00kd80
0?l0003[D000U;T0001h8`00;Ch000@M00067`00>D@0084B0;G1003`?P00o`000>YF0029]P0007DX
000X>`0011`000LQ0011B000QPP0a/800?<d003o0P00iV<007:`0000KS80020f00036P002B<004m>
00^>003=/000mRD00?h8003PN000DZL0001U?P005c00008I000>:000F4T0:IT00=JF0080na@009X0
eiD002ZJ0000FDT000hX00026@005c0006Hm05JX003QM000oPH00?DZ003:^00008X00016BP001b40
00<L000Y?000MbD0U;T00>a=003o0000k4d009Bi0000MRH002Pk00036`00228004Q;00B;003;/`00
mRH00?d8003NO000B:@0001Q@P004bd0008I000C;000H4<0Aj<00=im003m2000hFh0006:0000ADX0
00LQ00047000;3h007XO0:Jm003_@P00o`000>QL001g/@0006hc000N=@000QX000`V001FB`0WV@00
ei@00?/A003i6@00dZ8001FB0000D4d000TS00036`009CX007DX09Fi003]BP00o`000>YF0020/`00
06la000O=@000QX000`V001FBP0ZVP00f9000?`?003i7@00cjT000b>0000Bdd000PQ00047000;Ch0
07`L0:no003a>`00o`800>AY001OZP0006Hm000F;`000QT0018/001R@P1AYP00hG800?h4003c=000
_<80001o5P00<40000@L00078@00BD`02hh00=2X003i6`00na400=JG000OUP00059=000:90000a/0
02Pk001i8P2W_@00l3h00?l2003TJ@00G:T0001T?`0052d0008I000F;`00IS`0I:`00>IS003o0@00
kd@009Vj0000MBP002<h00036P0032H005Q:03:L003KQP00o@T00?HY0037_P0008<=000e@P0011d0
00LP0019C00>S`00dJ<00P3j5`00o`3AX`003Hl00018C0001b0000@M000g@`00Q@X0bKX00?LU003m
3000fHh002JH0000Dd`000XT00036`00:cd007dJ0;_2003d<@00oPH00=io000iW`0005U9000<9P00
0aX002Di001h902Y_P00lCT00?l3003QM@00AJ<0001LAP003RP0008J000R=`00MBP0X;`00?0m003o
0P00hW8004VT0000GDH000hX00026P008CL007DX0::l003a?000o`<00>5e0014XP0005]7000=9`00
0aX002@i001h8`2]_`00lSH00?h5003NO@00>9h0001GBP002bD000<K000Z?@00OAT0`l@00?D[003m
2P00fH`002BG0000DDd000PR00047000=D<008H80<^d003h7P00na<00=:Q000;SP0004=900057`00
1Ql004M;016@003DV`00o1000?LR0038^`00088@000_?`000a/000XT001FB`0fWP00gW`00?h4003a
>`00Wk/0001c:`007SD0008I000B;000ICh0JZh00>UH003o0000j5d006:[0000HT40010Z00026P00
8CL007LU0:jo003c<P00oPL00=Z9000TV000051>00078@001Ad003e600J<003BX`00na800?PP0039
^P00084B000]?P000a/000`V001KB02FR@00o`400>a<001k/P0006Pj000D;@000QT001dd001d:P2U
_@00lSH00?h7003KR0008iL0001?CP001b0000DN0013B@0AT000eYL00?d<003e:`00^/80001i8@00
8SP0008J000A:`00ICh0LK000>]A003o0000i6/004NS0000FDP000/U00036`00<d4008L60<j/003j
5P00n1h00<Vj0000P1@002Xl00036P003RP00613066[003YF@00o`000>IT001@YP0005]7000;9P00
0a/0039100261P3?Z`00naD00?PP0037_P0007hH000V>P000QX0010Z001T?`1b/000k4h00?l1003Q
L`00>Yl0001EB`00228000DM0010B00?T000eYD00?d:003c<P00YKd0001b;@006S80008I000J<P00
LRd0Y[d00?<a003m2P00eYL000b?0000?DH000@M00098`00F4X0AZ<00>AY003o0000j5/005^Y0000
GDD000`V00036`00=48008T00=:R003l3P00mB/00;;00000M2T001`c00026@006C80078]0:Zn003d
;P00o0d00=>N0002R`0003I300036`001@0032H005i505nZ003ZEP00o`0000[ooooo0Ol00001oooo
o`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01oooool07`00Bdd00HX00<Rl003c<@00o`800>MP001m/`0007</000W>P0011`000LP
000lAP00PQ00]l400?0o003o0000je4009Bi0000NB8002ho00047@001Ah003E2001m6@2V_@00kTL0
0?l0003]BP00X;`0001l7000<T400P001Ah02@00<T4007`L0::l003]B@00o`000>e9002Q_00007/M
000a@00200057P1S000d@P00OQT0ZKh00>i5003o0000k4l009Fi0000N2<002`n000470001Ql003]6
00223`2m``00lCX00?l1003XG000O[<0001a;P0093T000<K00088P00BD`00h/00<Zg003e:`00oPD0
0>9a001MZP0006Pk000J<P000QX000dW001EB`0PUP00e9d00?XI003l4000fHd003BM0000G4L0010Z
00026@005Bh0069104^U003OO000o@P00?LU003=/00028d0001<C@002B8000<K000U>@00Lb/0R;H0
0>YD003o0000kTH00:6l0000NR0002`n000470001b00049900280`39^P00mB/00?h6003QM@00DjL0
001T?`005Bl0008I000A:`00GDD0?J000=b4003m2`00hfP000V=0000Bdd000PR00036`00:3/007LU
09Vj003]B000o`000>YE0023]000074^000Q=`000aX000/U001CC00NU@00e9/00080nQD00?l0e9/0
01jE0000Dd`000/U00036P008SL0078]08Vf003[D@00o`000>a?002<]`0007</000R>0000aX000/U
001DC00PUP00eIP00?/C003j6000dZ8001BB0000Cdh000TS00036`00:C`007PR0:>l003_@@00o`40
0>IQ001[[P0006Ti000H<@000QT0010Z001NA016X`00ggX00?h6003d;P00aL8000224000=D8000DM
00068000@dT00h/00<f_003h8000o0h00=R@000XV@0005E;000;9@000aX002@i001e9`2J^P00kd@0
0?l0003VHP00Ijd0001W>`005Rl0008I000C;@00Hd00FJT00>A[003o0P00l3d00:Jm0000N2<002Hj
00036`002RD005E;02RI003ISP00o@`00?LS003:]`0008H6000jA@001Ah000HO0013B@05S000cj/0
0?TK003k4`00e9`001JB0000CTh000PR00047000<T40084A0<K1003e:P00o@T00=^7000`W00005I;
000;9@000a/002Lk001i802__`00lSL00?h4003PM`00@j80001LA`003RP0008J000Q=`00M2T0W;/0
0?10003o0P00hfh0052V0000Gd@000lZ00026P007SD0078]09Bi003_A000o`400>A[001DY`000613
000@:P000QT001he001b;@2E^@00kd800?l1003SK@00CjH0001NA0003bT0008J000Q=`00MBP0XK`0
0?4l003o0`00h7H004:R0000FTP000`W00036P009SX007XO0;K1003d<@00oPL00=b5000]V`0005A<
00098`0011`0031000223`38^`00mb<00?`?003EVP004i400019C0001R0000DN0011B008S@00dZ<0
0?/C003h7P00bk@000252@00=48000@L00098`00Dd`0;I/00=b4003n1P00lcD00:^o0000MRH0024g
00026P0042X0069105nZ003WG`00o`000>YF001][P0006Dm000B;0000QT001he001c:P2R_000lSP0
0?h5003MP@00;Y/0001CC000228000@L000hA000R@40cjX00?XF003i7000bk<000242`00<D4000<K
000:9000F4X0T8X00?l2003^AP00QkD0001/=P005Rl0008I000J<P00L2l0VKX00?4l003n1000gH40
02bJ0000DTd000PR00057@00?TL028d00=>O003l3`00mRH00<G30000O1/002Hj00026P003bT000`0
069106J/003YF000o`000>IT001BY`0005a6000<9P000a/002ho00233@3;/`020?TJ001D0<bc0000
P`d002ho00036`0032L005e505JX003WH@00o`000>QM001KZ@0005i4000=9`000a/002dn00233P3<
/P00nQT00?TK003:]`00084B000Z?@000aX000hX001Q@P1V[000jUD00?l0003TJ`00AJ80001HBP00
2R@000@L000jA@07S@00e9`00?`=003e;000//00001e:0007C@0008I000G<000Kc80V[X00?8g003n
2000f8l001FB0000@dT000DM00088P00ED/0?:000>9`003o0000jU@006J/0000H4<000dX00036`00
<40008H70<nY003k4P00mRD00;o30000N2<001le00026@005c0006la09jk003c=000o@X00=JG000;
SP0003]5000470002RD005]705BW003XG@00o`002_ooool1o`00007ooooo0005o`0000;ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
0?l004E:00271@35``00lSL00?l1003YF@00RKH0001f9`00:cd000@M00067`00=d@007lF0:Zn003^
AP00o`000>e;002Q_00007`L000c@@001Ah000DM000`@000NQl0V[X00>a>003o0000kd@00:fo0000
OaH003M300067`0011d002dn001i8P2E^@00je000?l0003_@`00[Kl0001o5P00=T<000DN00057@00
;cl007XO09fk003]B`00o`000>e9002Q_00007/M000`@0001Ad000DN000f@`00OaH0/<000?10003o
0000jUD008Zf0000MBP002Lk000370001b4004=900271037_P00m3000?l3003TJ@00J:d0001[=`00
7C@0008J000;9@00Ddd05i<00=6U003h7@00o0d00=^6000nX00005m4000B;0000QT001</001OA011
X@00g8<00?d;003h8000cjT0016@0000D4h000XT00036P008CL0070`07bc003XF`00o`000?0o002]
_`0007dJ000a@00011d000HO000lAP00Q@X0a/400?@a003o1000hfh005jZ0000Ic`001Pa00026@00
3bT005Y803>M003IS000o0h00>EQ000BT@00051>00098`000a/002@i001d:P2=]`00k4l00?l0003/
CP00SkL0001d:@009CT000<K00098`00D4h05I800=:S003i6P00na400=NC000WV@0005I;000<9P00
0QX001he001_<P1m/`00jEP00?l0003^B000V;X0001f9P009SX000<K00098`00DDd05i<00=>O003j
5`00na@00=FJ000MU@00059=000:90000a/002Di001e:02F^@00kTP00?l0003XFP00M[40001/=@00
6c<0008I000?:@00FdL0?:000=f1003m2000mRT00<Rk0000Q@P003Y500057P001Ql003e70027103:
]`00mbD00?d;003KR000<Y`0001HB@0032L000<J000P=`00LRd0S[L00>e;003o0000j5/007>`0000
JSL001Ta00026@004B/0061304nU003RLP00o`<00?8g002b`00007/M000Z?@000a/000TS001BC@0O
UP00eYD00?`@003h7P00cJl0006:0000@4P000HO00057P00?DL008T10<bb003h8000o0l00=ND000O
UP00055=00098`000a`002dn001n602o``00m3000?h6003NO`00>Yl0001IB@0032L000<J000S>000
MRH00?<0X[`00?0m003o0P00hW0004jU0000Gd@000lZ00026@007SD0074^092h003^AP00o`400>EW
001KZ@000691000A:`000QT001/c001_<P28]P00kDX00?l0003VH`00GjX0001S@0004R`0008I000K
<`00Kc80RKH00>e9003o0000iFH005ZY0000HD80014[00026@007C@0074^09Fi003_@P00o`800>=_
001<Y@0005e5000>:0000QX002<h001g9@2Z_P00lSL00?h5003NO@00=ih0001GBP002bD000<K000/
?P00OaH0a/800?HX003m3000ei8001bE0000Cdh000LQ00057@00>dH008X00<nZ003j5`00nAT00<j]
0000R08003U400047@002240051=02>G003JR`00o@T00?@_002h`@0007XP000U>@000aX000hX001O
A01DY`00iFH00?l0003/C`00NK80001Y>P005Bh0008I000K<`00L2l0U[T00?0o003o0`00ggX003RN
0000ET/000XT00047000<d4008D90<bb003i6`00nQL00<j/0000R0<003I3000470002B<005E;08Z<
003o0`00l3l009:h0000Kc8001Ta00026@005c0006dd08bg003_@P00o`<00=mi000fWP0005E;0009
8`0011`003Q4002:003@YP00na<00?PQ0038_00007lE000Z?0000aX000hX001OA01KZ@00iel00?l0
003XG@00GJX0001P@`003RP000<J000Z?000P1@0bKX00?PO003j5@00cZ/000271P00<d4000<K000;
9@00FTP0Bj@00>EX003o0000jUH006J/0000HT8000lY00036P00:C`0080D0<Vj003h7@00nQL00<f`
0000Q0/002lo00036`003BL005i505^Y003XG000o`000>IT001?YP0005]7000;9@000a`003E30029
003AY000o1000?HW002n``0007PR000P=P000QT001D^001[=P2>]`00l3d00?h5003KR0007YD00019
C0001Ah000LQ001BC@0bW000h7P00?l1003/C@00LK00001S@0003bT000<J000[?@00P`h0cK000?XF
003h8000a/40001k7@008SP0008I000D;P00K3H0TKP00?4j003n1`00f8l001>A0000@4P000@M0009
8`00F4T0BZ@00>IU003o00002_ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool01_ooool4o`0000Kooooo06/003m700233@2k`P00l3h00?l0003[DP00
UKT0001i8@00;cl000DM00057P00<T4007`M09jk003/C000o`000>m4002]_`0007lE000hA0001Ql0
00@M000[?@00MbD0S[L00>YE003o0000l3d00;W20000PPl003a60006800011`002Tl001e9`29]P00
jEL00?l0003a?@00^L8000224000>dD000HP00047000:cd007LU096h003[DP00o`000>m2002]_`00
07lG000e@`001Ah000DM000a@000O1`0Y;d00>i7003o0000k4h009Ji0000N2<002`m000470001R00
03e700242`34a000lSH00?l2003VHP00Lk00001^<P0083H000<J000:9000D4h03Xl00<j/003g8P00
o@X00=in0019Y0000691000D;P000QT0014[001LAP0gWP00fX/00?`?003i6`00dZ8001VD0000Dd`0
00/U00036P007SD006dd076_003VHP00o`400?4i002i`P00080C000f@`0200057P3o000g@`00PA40
_/<00?8g003o0P00iFH006V]0000JSP001/c00026P003BL005M:02VI003GT`00na800>ML000KU000
05==000;9@000aX0024g001a;`21]000jUH00?l0003^A`00Vk/0001g9000:3/000<K00088P00C4h0
38l00<nZ003h7P00o0h00=Z<000aW00005U9000>:0000QX001/c001/=P1a/000iel00?l0003_@@00
Y;d0001i8@00:S`000<K00088P00CDh03i000=2W003i6`00o1000=NC000VV00005E;000;9P000aX0
024g001b;@2;]P00k4h00?l0003ZD`00P[@0001_<@007SD0008J000=9`00F4T0<Y`00=Z9003m2`00
mb<00<^d0000R@4003m800067`001Ah003Q400242`37_P00mBX00?h8003MP@00>il0001KA`003RP0
008J000M=000Kc40P[@00>]A003o0000jU@007jc0000KS<001`c00026@003bT005e604BR003ON@00
oPD00?<a002n``0007lG000_?`0011`000PR001?CP0FTP00e9d00?/C003i6P00d:P000V=0000ADX0
00HP00057@00>4@008D90<Vi003g9@00o@`00=V=000XV@0005A<000:90000a/002Tl001k7P2b`000
lSH00?h4003PN000A:80001LAP003RP0008J000P=P00Lb/0U[T00>m4003o0@00i6P005VY0000HT40
014[00026@006c<006hc08Be003/C@00o`000>MO001V[00006Dn000D;@000QT001Pa001[=P1l/`00
je400?l0003XG000JZd0001V?@0052h0008I000H<@00K3H0O[<00>]@003o0000iel006F/0000ICh0
01</00026@006S8006hb08Vf003]B@00o`000>EW001GZ0000613000@:P000QX001lf001d:P2M^`00
l3d00?l3003PMP00@J40001JB00032H000<J000X>`00O1`0_L<00?@]003m2@00fX/002FH0000DDd0
00PR00047000=T<008H60<ba003i7000nQD00=6U0005S00003i700057P001b0004e>01ZD003GT`00
o@`00?DY0034a00007dJ000Y?0000aX000`W001LA`1:Y000hfh00?l1003]B000QKD0001/=P005c00
008I000H<@00KC@0R[H00>i5003o0P00hG8004:R0000FDT000/U00036`00;Sl0088@00260<Vi003h
7`00na<00=6U0004R`0003]600047@002280059=08B?003n1@00lCT009nk0000LRd001`c00026@00
5Bh006Xh086d003]B@00o`400>9b0010X@0005Q:000:900011`003=200261P3>[@00nQL00?TL003;
]@0008<>000^?`000a/000`V001LA`1@YP00iFH00?l0003ZEP00J:d0001S@0003bX0008J000V>P00
OAX0a/400?LS003k4@00dJ@0006:0000>4@000@L000:9000EdX0@J400>9_003o0@00k4l0076`0000
ICh0010Z00026P009CX007`K0<K0003g8P00na<00=2X0000R0@003=200036`002bD005]7056V003V
H`00o`000>QM001JZ@0005i5000<9`000a/0035000261`3?Z`00na@00?LR0036`@0007`L000S>000
0QX0018/001X>P22]000kd@00?l3003MP@009iT0001?CP001Ql000HP001?CP0XV@00gWl00?l3003^
AP00OK<0001W?0004B/0008J000W>`00OaD0b[L00?TJ003i7000bKX0001n5`009SX0008J000B;000
JCX0Q[D00?10003n1@00fhP001bE0000AT/000DN00088P00ED/0?j400>=/003o0007ooooo`Co0000
0Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool01oooool0o`00>TD0080C0:no003_A000o`000>e;002Q_00007`K000d
@P001Ah000@M000^?`00N280T[P00>]C003o0000l3h00;W20000P`l003e60007800011`002Lk001d
:P22]000j5`00?l1003b=`00aL@000262000@DT000LQ00036`009CX0078]07jc003WGP00o`400?8f
0035a00008D90011B0001b4000@L000W>`00M2X0QKD00>UI003o0000lC`00;[20000PQ0003Y50006
7`0011d002dn001i8P2H^P00k4d00?l0003^B000X[`0001k7@00<40000@M00067`00>4@0084B0;O1
003a?000o`400>QK001o/`00074^000S>0000a/000TS001;C@06S000bk<00?HW003n1`00h7L005>W
0000ICh001L`00026@003bT005U802fK003GTP00na800?XG003EVP008YL0001FB`003BL0008J000K
<`00JSP0IZ`00>AY003o0`00lc<00<G40000Q0`003]500067`001Ad00391001n602a`000l3d00?l1
003WG`00M;00001]=0007SD0008J000<9P00E4`089H00=BK003j5P00jEH002BG0000ED/000`V0002
6P007SD006dc07Ja003XG@00o`000>m1002W_@0007/N000]?P0011`000LQ0016B`04R`00c;400?LS
003m2P00g8@003^O0000G4H000lZ00026@00634006Pj06J/003UIP00o`800?4k002``00007`K000^
?`0011`000LQ0017B`06S000cJh00?PP003l3@00fX`0032L0000F4T000dW00026P007SD006lb07nc
003ZE@00o`000>a=002=]`0007</000R=`000aX000/V001FB`0XV@00f9000?`>003h7`00cZd000J<
0000ADX000LP00047@00<d40084B0<C4003d<000oPH00=mi0016X`0005i5000@:P000QT001Xb001/
=P1g/@00jEP00?l0003/C@00R[H0001a;`007cH0008J000=:000FTP0>Yl00=f1003n2000mB`00<K1
0000PQ0003=200047@001b4004U<00j?003AY000nQL00?XF003BX@004I00001;C@001b4000@M000c
@@00PQ00a/000?DZ003m2@00fhH003:L0000EdX000/V00036P009CT007LT0:Jm003a?000o`800>9`
001>Y@0005m4000@:P000QT001dd001`<000C02:]P00kDX00?l0003WH@00I:`0001U?P0052d0008I
000H<@00JcL0NK800>YD003o0000jEP0076_0000J3X001H_00026@005Rl006Pj076_003YF000o`00
0>YE001e/@0006Ti000F;`000QT001H_001X>P1b/000jUL00?l0003YF000L:l0001X>`005Bh0008I
000H<000JcL0OK<00>]@003o0000if0006:[0000I400018/00026@0073@0070_09:h003_@`00o`40
0>=^001;Y@0005e6000>:0000aX002@i001h8P2a`000lc<00?h6003LP`00;Y/0001DC0002B<000@L
000a@000P`d0bKP00?PQ003k4@00dih000f?0000A4X200067`2U0017B`0AT@00eIX00?`?003g9000
akh000204`00;Ch000<K000;9@00FDT0?j400>5e003o0P00kd80092h0000Kc4001Xb00026@005Bl0
06Xh07jc003]C000o`400>A[001<Y@0005a7000<9`000a/002Xl001o5`36`000mb@00?`?003DW@00
38h00011B0001Ah000LP001?CP1nT@00oPP00?<c002[_P0007DX000O=@000QT001</001W?01e/@00
k4l00?l0003TJ`00BZ@0001KA`002bH000<K000_?`00P`d0bk@00?TK003j5`00cJh000261`00<d40
00<K000;9@00FDT0AJ<00>=]003o0000k4l007>`0000ISd0014[00026P008SP007TP0;k3003f:@00
o0h00=BM0009S@0003e600047@00228005A<03NN003PM`00o`800>e9001m/`0006Pk000C;0000QT0
028g001i8@2o``00mRL00?`?003BX@000h/0000hA00011`000XT001HB@16X`00i6X00?l0003ZEP00
IJ`0001Q@P003RP000<J000/?P00P`h0c;800?XH003i7@00bKX0001o5P009c/0008J000@:P00ICh0
M[400>e:003o0P00ggT0032L0000DDd000LQ00057`00BT`07iH00=^6003n1@00l40008Rf0000JSP0
01<]00026@008cP007`K0<Nn003h7`00nQL00<bc0000PQ4002Xl00036P0042X006Dm07Zb003^A`00
o`<00=f0000UV00004a=00067`001b40059=03FM003QL`00o`0000[ooooo0Ol00001ooooo`001ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`07ooooo`10000e@P00OAX0X[`00>e:003o0000kTD00:fo0000P1D003U400067`0011`0
02Xl001e:026]@00jEX00?l1003b>000aL@000262000@TT000PQ00036`0093T0070_07Na003VH`00
o`800?<a0037_@0008T10017B`00228000<K000R=`00Kc40L[000>EU003o0`00m3400<Rm0000R@40
04I;00088P000a/002<h001a;`1i/P00if000?l2003b=P00aL@000252@00@4P000LP00047000:C`0
07DW08bg003ZE000o`000>m1002^_`0007hG000e@P8000DN0?l003=1001m6@2[_P00kd800?l0003Z
E000R[H0001e:@009c/000<K00088@00ADX008T10<Vj003e;000oPD00>9_001NZP0006Pk000I<P00
0QT000dW001FBP0TV000eIT00?XF003k4`00ei<002bJ0000FDT000hX00026@00634006Ll05^Y003R
L000oPD00?@^0038_@0008L50010B0001b0000@L000^?`00Nah0YKd00>m3003o0000jEP0082c0000
L2l0024g00036P002R@0059=01NC003BXP00nAX00>Y@000]V`0005Q9000=:0000QX001/c001Z>01[
[P00iV@00?l1003a>`00/l00001n6000<D0000@M00068000@DP008P30<Vh003f:000oPP00=im0015
X`0005m4000A:`000QT001H_001U?P1KZ@00hfd00?l3003b=@00_<<000205000<d4000@M00068000
@DP008T00<^e003g9@00o@X00=b4000iW`0005]7000>:@000QT001/c001/=P1c/000j5`00?l0003^
AP00VKX0001f9`009CX000<K000:9000Dd`07iH00=JH003k4P00nAX00=2V000>S`0004]=00088@00
11`002lo001n6@2h`P00lSD00?l4003RLP00D:H0001Q@P004R`0008I000H<000JCX0Jjh00>MO003o
0000kTH009Ji0000M2X0028h00036P0032H005M:032L003KR000o@X00?HV0039^P0008D9000hA000
1Ah000HP0013B@06S000cj/00?TL003k4P00eIX001VD0000D4h000PR00047000;Sl007lF0<33003d
<000oPH00=in000kW`0005Y8000=9`000aX0028g001d:@2J^P00kd800?l1003TJ@00FJT0001R@@00
4R`0008I000J<P00KCD0Ok<00>]A003o0000jEX006n_0000J3X001H_00026@005Bl006Pk06f^003X
F`00o`000>]A001l/`0006`f000I<@000QT001<]001U?P1V[000iel00?l0003/CP00P;@0001/=@00
6C40008I000C;@00ICh0Ijd00>QM003o0000je4007^b0000JcL001L`00026@005Bh006Pj07:`003Z
EP00o`000>UI001][P0006Ll000D;@000QT001Tb001]=026]@00kDX00?l0003UI`00EZP0001P@`00
3bT0008J000Q=`00MBP0Y;d00?4i003n1000gg`003RN0000EdX0034000/U00036`00;Ch0080D0<No
003f9P00o0h00=JG000FTP0004Y<000680001Ah0045800V=003BX@00na800?PO003:]`0008<=000a
@0000a`000XT001FB`0eWP00gW`00?h4003a?000W;/0001b;@007C@0008I000C;@00Ic`0Lk000>]B
003o0000iV@005NX0000Gd@000hX00036P009SX007/M0<74003e:@00o@`00=JF000DTP0004M;0080
00HO07h004Y<07RC003m2P00m2d00;O10000N280028h00026P004B/006@o06Z]003ZEP00o`000>IS
001EY`0005i5000=9`000aX002/m00205038^`00n2000?/C003@Y`0008T0000gA00011`000TS001F
B`0kW`00hG@00?l1003]B000Ok<0001Y>P0052d0008I000O=P00MRH0//000?@^003m2`00eYH0016A
0000@TT000DN00078@00DTd0;I/00=in003o0`00kd8008Rf0000JcL001D^00026@007SD007HV0;?0
003e;@00o@`00=FJ000;SP0003i700047@002B<005E;03bP003RLP00o`400>a?001`[`0006@o000@
:P000aX002Pk001o5@39^@00nA`00?XI003;/`00088@000[?@000aX000hY001R@@1[[P00je400?l1
003RLP00>Yl0001DC000228000DN0014BP0FT`00fHh00?h7003a>P00U;T0001]=0005Bl0008I000P
=P00NB40`l@00?LT003k4`00cZ`000252P00;Sl000<J000>:000HT40Kjl00>a=003o0@00ggT002jK
0000D4h000HP00067`00Cdh0;9X00=mk003o0P0:ooooo`7o00000Oooool000Sooooo0_l00009oooo
o`?o00002?ooool00ol0003oooooooooo`07ooooo`2i000`@000NR00UkT00>]A003o0000l3h00;W2
0000P`h003i7000780000a`002Hj001b;@1k/P00if400?l2003c<P00akd000290000B4`000TS0003
6`0083H006dd06^^003TJP00oP@00?D/003:]P001X`0001=CP002B<000<J000N=@00K3H0Ijd00>=/
003n1000mB/00<Zf0005S00004a=00098`000aX0020f001]<`1^[`00iFL00?l3003d<000b;d00028
0P00ADX000PR00036`009CT0078/082d003XF`00o`400?4k002j`P00088@000jA@001Ql000@M000_
?`00NQl0Wk/00>e9003o0000k4d009Ji0000N2<002/m000470001b0003m800262036`@00lc800?l3
003TJ000JJd0001[=`0073@0008J000;9P00E4`06i@00=:Q003i6P00o0l00=V<000eW@0005a7000@
:P000QT001H_001T@01@YP00h7P00?h7003f:000b[H0006:0000AT/000LQ00047000:S`007PT09Vj
003]BP00o`000>]A002;]P0007@Z000U>@000a/000TS001?CP0?T000cjT00?PN003[B`00=Yh0001K
A`003bT0008I000H<@00Ic/0H:/00>A[003o0`00lcD00<330000PA8003I300057P001Ql003]60025
2P37_`00m2h00?h5003PMP00CjH0001R@@004bd0008I000D;@00HT40D:H00>5d003n1@00m2l00<G2
0000P`h003Q400057P001Ql003a600262038_000mBX00?h7003NO@00@j80001NA@0042X0008I000H
<@00JCX0J:d00>IS003o0@00l4000:Fm0000NB4002Tl00036`002B<0051>01JC003CW`000P3j5P00
o`3CW`005Y80001@CP002B<000<K000Z?@00NQl0[;l00?4k003o0P00i6/005^Y0000I3l001@]0002
6@005Bh006Hm066[003UIP00o`400?10002Q_00007LT000V>P000a/000XU001DC00WV@00f8l00?`=
003g8@00bk<000280P00?TL000DN00057`00?TL008T10<bb003h8000o0h00=NB000RU`0005==0009
90000a/002Xm001k7@2d`@00lSD00?h4003PM`00AJ<0001MAP003bT0008J000N=@00LBh0S[L00>e8
003o0000iV8006>/0000ICh001@]00026@005c0006Ti07>`003YF000o`000>YC001j/P0006/f000H
<@000QT001<]001U?P1RZ`00iV800?l0003]B`00R;H0001_<P006c<0008I000A:`00HT40FjT00>EV
003o0000kTP008bg0000L30001`c00026@004B/0069105bZ003VI000o`000>e:0027]@0006hc000J
<P000QT001<]001U?P1V[@00j5d00?l0003[DP00N;40001Z>0005Rl0008I000G<000JSP0N[800>]A
003o0000if00066[0000Hd00014[00026@007CD0078]09Vj003`?`00o`800>5e0012XP0005Y8000<
9P000a/002Tl001m6P32a000mB/00?d:003HS`007YH0001?CP001b4000DM000kAP01RP00cjT00?XF
003i6`00cK0000271P00=T<000@L00098P00Dd`0;9X00=b4003n1P00lSH00:Rn0000MBL0020f0002
6@004B/006@o06N]003YF@00o`000>QM001QZ`000691000@:P000QX0028h001h8`2e`@00m2l00?d9
003IS`007ID0001=CP001R0000DN0014BP1cU@00o0d00?HX0033a00007`L000V>P000aX000lY001Q
@P1OZP00j5d00?l0003XG000H:/0001Q@P003bT000<J000W>P00OAX0aL800?LU003l4000dj0000N<
0000?DH000@M00088P00Dd`0<Y`00=ml003o0`00kd8008Zf0000K3H001H_00026@0073<007<[0:Jm
003c=000oPP00=V>000JU00004Q<00067`001R0004m>02BH003LQ@00oPD00?4l002D^@0006hc000G
<0000QT001/c001c:`2W_@00lc800?d9003GTP004i400013B@001Ah000PQ001CC@0bW000ggT00?l2
0000>03]B000Nk80001W?0004R/0008J000T>@00O1/0a/000?LQ003k5000cZ`000252@00<40000<K
000=9`00Gd@0H:/00>UH003o0000i6/004BR0000EdX000TS00047@00?TL03Xl00=JE003m2@00lc@0
0:2l0000L30001P`00026@007C@007HW0;O1003f:@00o1000=6T0000R080039100036`003BL005m4
06B/003ZE000o`000>9b000hWP0005=<00078@001Ah004Y=02>G003MPP00o`<02_ooool1o`00007o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0?l002`m001g9@2;]P00jEP00?l1003b>000aL@0
00261`00@dT000PR00036`008SP006lb072_003UJ000o`@00?D/003:]P001X`0001>CP002R@000<J
000M=000JSP0HJ/00>9a003n1P00mRH00<f_000>S`00055=000;9@000QX001/c001Y>P1LZP00hG<0
0?h7003f9P00cJl000f?0000D4h000XU00036P007C@006Xh06>/003SKP00oPD00?D[003:]P001H`0
001;C@002B<000<K000Q=`00Kc40MK400>IR003o0P00lSD00<G30000Q@X003m70007800011`002Xm
001g902C^@00k4l00?l0003^A`00X[`0001k7P00;cl000@M00067`00>TD0088?0;o3003b>000o`40
0>MQ001d/00006hc000O=P000aX000XT001AC@0CT@00d:P00?PO003m3000g8D003nQ0000Gd@0018/
00026@004bd0065304JS003NO`00o@T00?LS003=[`002Hd0001<C@00228000<K000V>P00M2T0S[L0
0>]@003o0000kD/009Ni0000MbD002Pk00036`00228004U<00N<003=/000mb<00>e60010X@0005i5
000A:`000QT001D_001T?`1EY`00hG800?h5003d;`00a/0000242`00>dD000HO00057P00=T<0088A
0<;4003c<`00o`<00>=^001JZ@0006Dn000F;`000QT0014[001OA016X`00gg`00?h7003e:P00b;/0
00261`00?DH000HO00057P00=d<008<?0<G3003d;`00oPD00>1f001=Y@000652000B;0000QT001H_
001U?@1MZP00i6X00?l2003a>P00/L00001l6`00;Ch000@L00088P00C4d03Xl00=2V003i6P00na80
0=JH000OUP00059=000:90000a/002Hj001g902P_000kd400?l1003VI000IJ`0001W?0005Rl0008I
000C;@00Hd40EZP00>=]003o0P00lCX00:fo0000NQl002Xl00036`002B<0059=01jE003FU`00na40
0?TM003>[0001H`00013B@001Ql000DN000iA000Q@P0bKT00?HU003m2`00fX/002^J0000ED/000/U
00036`009SX007PR0:Rn003a>`00o`800>9`001@YP000613000@:P000QT001/c001^<`23]000k4l0
0?l0003XF`00KZl0001X>P005Rl0008I000E;P00IS`00?<0J:d00>MN003o0000k4d008Fe0000KS80
01/c00026@004B/0069205RX003TJ@00o`400>i4002C^@00078]000N=@000QX000lZ001OA01@YP00
hfd00?l2003_@P00V;X0001c;0007cH0008J000?:P00Gd@0DZH00>=/003o0@00kd@009:h0000LBh0
01dd00026@004B/0069105bY003VI000o`000>e<0023]00006dd000I<@000QT001@^001W?01_[`00
jEL00?l0003YF@00K:h0001V?@004bd0008I000J<P00Kc40SKL00>i5003o0@00hfd004bU0000GDH0
00dX00036P009CT007TP0;K1003d<000oPP00=^8000WV@00059=00088P0011`003I300271@3=/000
nAX00?XF003?Z@000HX0000kA@0011d000PQ001@CP0SU`00fX/00?d8003d<000]<40001h8P008cP0
008J000?:@00HD80GJX00>MP003o0000jUH006b^0000ICh0018/00026@007cH007DX0:Vn003c=@00
oPL00=^7000UV000051=00078@001Ad003i706fG003k4@00mb<00<Nn0000OaH002Xl00036P003BL0
05i505BW003VI000o`000>YF001Z[P0006@o000@:P000QX002<h001i802l``00mBX00?`<003EV000
3i000012B@001Ah000LQ001@C@0XV@00g8<00?h5003a?000U[T0001_<@006340008I000I<@00L300
V[X00?4j003n1P00fhL002:G0000CTh000HP00067`00BD`06i@00=V=003n1`00lSH00:2l0000LBh0
01Xb00026@006C40070`09^j003b>000oPL00=Z;000LU@0004U<00067`001b00051>02VI003MP000
o`<00>m20027]@0006Xh000D;@000QT0024g001i8@30``00mRH00?/A003AY@0008T1000d@P000a/0
00/V001LAP1FZ000iel00?l0003VH`00CZD0001JB0002R@000@L000iA006S000e9`00?d<003d;P00
[;l0001c:`006S80008I000J<P00Lb`0Zkh00?@^003l3000e9d000B;0000=d<000@L000;9@00G4H0
FJT00>QK003o0000i6/004:Q0000ET/000PR00057P00ADX06Y@00=Z9003n1@002_ooool1o`00007o
oooo000Nooooo`03o`000?oooooooooo00Oooooo04/002Pk001c:`1o/`00iel00?l2003c<`00akd0
00290000BD`000TS00036P007cH006`f06F/003SK`00oPH00?HW003=[`003Xl0001AC@002bD0008J
000J<P00Ic`0EZP00>1h003m2@00mb800=2X000FTP0005=<000<9P000QX001Ta001V?@1BY`00ggX0
0?d9003h8@00d:P001JB0000Dd`000`V00026P006S8006Lk05RX003QM@00oPL00?HU003=[`003Hl0
001@CP002R@000<J000N=@00K3D0JZh00>AY003o0`00m2l00<Rm0000R08004A:00088@000a/002Hj
001d:P28]P00jUH00?l0003_@@00[[l0001n6000=4800P001Ah0o`00=D<007lE0;?0003`?P00o`00
0>QJ001o/`00074^000S>0000a/000TS001>CP0:SP00cJl00?LS003m2@00gWd004VT0000HT8001@^
00026@004B/005i503bP003KQP00o@`00?PN003@Z0004I40001@CP002R@000<K000R>000LBh0P[@0
0>UG003o0000kT@00:>l0000NQl002`n000470001b4004A90029003:]`00mRP00>m1001:Y0000652
000C;@000QT001<]001Q@P1;Y000ggX00?h7003e:P00bKX000281000@4P000HP00047@00<D4007hG
0;K1003a>@00o`800>EW001T[00006Pj000H<@000QT0010Z001LAP0lX000g8<00?d:003g9@00bkD0
00290000@TT000HP00047@00<T4007lE0;c2003b=@00o`<00>=^001HZ00006@o000D;P000QT001<]
001R@@1CY`00hW400?l4003c=000_L<0001o5@00<D4000@M00078000AT/01X`00<j]003h7P00o0h0
0=R@000XV@0005E;000;9@000aX002<h001d:@2D^@00kTP00?l0003XG@00L:l0001Z>0006C40008I
000A:`00H4<0C:D00>5e003n1000lc@00;W20000OQT002ho00047000228004m>01FB003CWP00na@0
0?XH003AY@003Hl00019C0001b4000@M000d@P00PPl0a/000?DZ003m2000g8@003FM0000F4T000`V
00036P008cP007DX09bk003_@@00o`400>AY001JZ@0006=0000B;0000QT001Ta001[=`1g/@00jUH0
0?l0003ZE000N[80001[=P006C40008I000C;000Hd00GJX00>EU003o0@00kTH0096h0000LBh001he
00026P003bT005m404fU003RL000o`800?0n002O^`0007DX000R=`000QX000hX001LAP16X`00hG@0
0?l3003a>`00Xkd0001f9`008SP0008J000>:000G4H0Aj<00>5c003o0`00l3h009jk0000M2T0020f
00026P003bT005m4056V003TJ`00o`400>i5002?]`00070`000L<`000QT0018/001T?`1T[000ieh0
0?l0003[D`00Mk40001Y>@005Rl0008I000H<000K3H0PK@00>a<003o0000iFH005NX0000H4<000lY
00026P008SL007HV0:Zn003b=P00oPD00=f1000aW00005E;00098`00YP0011`003910024303:]P00
n1l00?/C003BXP002Hd00010B0001Ah000LP001<C@0JU000ei800?d;003e:`00`<<0001l70009cX0
00<J000=:000GTD0DZL00>EW003o0000k4l007Na0000J3X001@]00026@0073@0078]09fk003a>P00
oPD00=f0000_V`0005=<00088P0011d003U406RI003k5000n1h00<Zh0000PQ0002ho00036`0032H0
05]704ZT003TJ`00o`000>a?001e/@0006Ll000B;0000QT0020f001f9P2``000m3000?d:003HT@00
5i<00018B`001Ql000HP001=CP0OUP00fXX00?h7003b=P00X[`0001b;@006c<0008I000G<000KC@0
S[L00?10003o1000gH0002bJ0000DDd000LQ00057P00@dT04i400=ND003m2P00m3000:bo0000M2T0
01dd00026@005Rl006de08nh003`?P00oP@00=b4000UV00004m>000680001Ql004a=022F003KQ`00
oPD00?4l002B^00006dd000F;`000QT001he001f9`2d`@00mB/00?`=003CWP001H`0000iA00011`0
00XT001IB@1;Y000iFH00?l0003XG@00FJP0001MAP0032H000<K000d@P00R@40dJ@00?`?003f:@00
^<80001f9P007C@0008I000G<000L300Wk/00?<d003m2@00eYH000b?0000?4H000@L000:9000FTP0
CZD00>IR003o0000iV@004bU0000FDT000TS00047@00?dL04I400=R@003n1`0:ooooo`7o00000Ooo
ool001kooooo00?o0000ooooooooool01oooool0o`0093T0070_07B`003UIP00o`<00?D]003:]`00
1h`0001?CP002R@000<J000L<`00JCX0FZT00>1f003n2000mb800<nY000GT`0005A<000<9`000QT0
01P`001T?`1<Y@00gGl00?d;003i7@00dZ4001nF0000ET/000hX00026@005Rl006=004RS003MPP00
o@`00?TL003BX@007YD0001FB`003BL0008I000G<000I3l0CZD00=il003m2P00n2400=2X000ETP00
059=000;9P000QX001/c001Y>@1OZP00hW000?h5003e:P00b[H000B;0000BT`000TR00036`008cP0
074_07bc003XG@00o`400?4k002j`P00084A000iA0001Ql000DM000a@000O1`0Ykd00>m4003o0000
jU@008Zf0000M2T002Hj00036`00228004Q;00>;003:]P00mRP00?h7003PMP00DjL0001T?`005Rl0
008I000?:@00FdP0<id00=V=003l3`00nAX00=:Q000IU00005=<000;9@000aX001lf001^<P1g/@00
j5h00?l1003`?P00[[l0001m6@00<D0000@M00067`00?TL008H70<Nn003d;@00l3`005BW0000I3l0
01D_00026@004B/005i5046Q003MP@00o@T00?LU003</`000h/00015BP001b4000@L000]?P00Nad0
Z[h00?0o003o0@00if0006n_0000JcL001/c00026@003RP005U803>M003JRP00o0d00?PP003>[P00
1hd00018B`001b4000@L000^?`00O1/0/<000?4k003o0P00iFL006:[0000Ic`001L`00026@004B/0
061304VT003PN000oPH00?@^0036`P0008<?000f@`001Ad000HO0010B000R@00bk@00?LS003m2`00
fXT0036L0000F4T000dW00026P0083H0074^08Vf003/CP00o`000>YF001k/P0006dd000L<`000QT0
00lY001MAP12X@00gg`00?h6003d;`00aL@000214P00<T4000@M00078@00BD`03Hl00=6U003j6000
na@00=>N000ETP0004m>00088P0011`002lo001o5P31a000m3000?h6003NO@00?Z00001KA`003RP0
008J000O=P00LRd0TKP00>i8003o0000iV8006F/0000ISd001D^00026@005Rl006Pk06b^003XG000
o`000>a>0025]@0006hb000L<`000QT0014[001P@`00EP1CY`00hf`00?l2003`@000WK/0001e:@00
8CL0008J000>:000G4L0@j800>1g003o1000lSP00:^n0000N2<002Di00036P0032H005U803bP003O
N`00oPD00?8f002__`0007TQ000V>P000aX000`V001JB00mX000ggX00?h4003b>000Z[h0001g9000
8cP000<J000=:000G4H0Aj<00>5b003o0P00l3l009^j0000Lb/001le00026@0042X0065205ZY003U
I@00o`000>a<0022]00006`e000H<@000QT001D_001Y>P1f/@00je800?l0003WG`00HJ/0001S@000
4B/0008I000N=@00Lb/0W[/00?4l003o1000ggX003ZO0000EdX000/U00036`00;Ch0084C0<Nm003g
9000o0l00=BK000AT00004I;0P001Ql0V`00AT/04Y400=FI003l3P00mRD00<K00000OaH002/m0003
6`0032H005]704RS003SKP00o`400>e90023]00006/g000F;`000QT001Tb001_<@2A^000l4000?l3
003ON@00>9h0001FB`002R@000@L000d@P1WVP<0nQP00?TJ003</@0008D9000b@@000a`000XT001H
B@10X@00hW800?l1003]B000PK@0001Z>0005Bh0008I000M=000Lb/0YKd00?8e003n1`00fXX0022F
0000CTh000HP00067`00Ad/05i<00=RA003m2@00m3000:jo0000MBP001he00026@0052h006Xh08>d
003^AP00o`800>1h000eW@0005A<00088P0011d003i700^>003DV`00o0d00?D[002h`@0007LT000P
=P000QT001@]001Z>@24]@00kd@00?l3003NO@00;Y/0001AC@001b4000DN0016BP0GT`00fHl00?h8
003b=P00W[/0001`<0006340008I000K<`00Lb`0Z;h00?@a003m2P00eYL000f?0000?TL000@M0009
8`00ETX0@J400>=]003o0000jUH006>/0000H4<000dW00036`00;cl008H80<n[003k4`00mb@00<C4
0000NB40024g00026@005Bh006`e09>i003a>P00oPL00=R?000DTP00045900047@002B<005M:04BR
003TJ@00o`000>QM001FZ00005]7000;9@0011`003Y500V=003FV000o@X000[ooooo0Ol00001oooo
o`007_ooool00ol0003oooooooooo`07ooooo`1f000Q=`00KC@0JJd00>=]003n1@00mRP00<f`000?
T000055=000;9P000QX001Ta001V?@1@YP00gWd00?d;003h7@00dZ8001nF0000EdX000hX00026@00
5Bh0065204:Q003KQ`00o0h00?XI003EVP00:9T0001IB@003bT0008I000D;@00H4<0?Z000=Z9003l
3`00nQP00=FJ000WV@0005U9000?:@000QT001D^001Q@P14XP00g8@00?`=003i7000dZ4001fE0000
ED/000dW00026@00634006Hm05FW003PM`00oPL00?LU003=[`0038h0001?CP002R@000<J000P=P00
KS<0LK000>IT003o0P00lcD00<G40000Q0/003i70006800011`002`n001i8@2K^`00kDX00?l0003/
C@00U[T0001g9000:S`000@L00078@00@TT008P40<Rl003d;P00oP@00>9_001MZP0006Lk000I<@00
0QT000hX001HBP0YV@00eiD00?/C003j5P00eIX002:G0000ED/000`V00026P0073<006/f06b^003V
I000o`800?8h002j`P00080C000e@`8000DN03`003U400233P34a000lc<00?4h001OZP0006Ll000H
<@000QT000lY001KA`0gWP00fhP00?d<003h8000cZ`000Z>0000Bdd000PR00036`00:C`007PS09jk
003^A@00o`000>UJ001j/P0006hb000N=@000QX000`W001GBP0ZV@00f9400?`@003i7000d:L000n@
0000CTh000PR00036`00:S`007TQ0:Bm003_@@00o`400>MQ001][P0006Xh000I<P000QT000lZ001M
AP0oX@00gH000?h8003f:@00b;/000262000>dD200057P3o000kA@00QPP0b;/00?HX003m2@00gH80
03^O0000FdL000hX00026P0073@006hc07jc003ZE@00o`000>a?0027]@00070_000O=@000QX000dX
001JB00hWP00g8<00?d9003e:@00akd000243000=d<000DM00068000A4X01H`00<j/003i7@00na40
0=JG000MU@00055=00098`000a/002/m001l702e`@00lSD00?h4003QMP00B:@0001NA@003bT0008I
000L=000Kc40QKD00>a>003o0000j5/0072_0000JCT001L`00026@0052d006Dn06:[003VH`00o`00
0>i7002@^000074^000N=@000QX000lY001NA@19Y000hG<00?l3003a>P00Z;h0001h90009CT000<J
000<9P00FDT0>Yl00=in003n1P00lc800;O10000Nad002Tl00036`002bD005M:03>M003LP`00oPL0
0?@`002k`P0007`K000Z?0000a/000/U001GBP0dW@00gH400?h6003c<P00]/40001j7`009c/000<J
000<9P00FDT0?J000=mi003n1000lCT00:Jm0000MRH0028g00026P003RT005i504nV003SK000o`40
0>i6002=]`0006la000K<`000QT001<]001V?@1[[P00jET00?l0003YF@00K:h0001V?@004bd0008I
000K<`00L300T[P00>m2003o0P00hG<004BR0000FTP000`V00036`00:C`007dI0<G4003f:@00o@`0
0=NC000IT`0004a=000780001Ah0045800Z>003BX000na800?PQ0039^@00088@000_?`000a/000/U
001HB@0nX000hGD00?l2003_@`00S[L0001^<`006C40008I000G<000K3H0Q[D00>i7003o0@00hW80
04:R0000FDT000/U00036`00<400IY`70?TM003j5P00cjX000280P00=d<000@L00098`00ED/0=Yh0
0=mi003o0`00kd8008bg0000KC@001L`00026@006S80070`09Vj003a>`00oPD00=b3000YV@00055=
00078@001Ah0045900n@003EV@00o@`00?D[002i`P0007PR000Q=`000QT0018/001W?01h/@00k4`0
0?l1003RL@00?Z00001GBP002B<000@L000iA003R`00dZ800?`@003f9P00a<@0001j7P008cP0008J
000B;000Ic`0NK800>e;003o0@00hGH003NN0000E4`000PR000m00057@00@4P03i000=JF003m2P00
m3000:Zn0000Lb/001/c00026@006340070`09fk003b=P00oPP00=R@000ETP0004A900057P002280
05A<03RN003QM000o`400>a?001^[`0006=0000?:@000aX002/m00223`3</@00nQL00?PO0037_P00
07`K000T>@000QX001</001Y>@28]P00l4000?h5003KR0007ID00017B`001Ah000PQ001DC00kW`00
hW000?l0003ZEP00H:/0001NA@0032H000<K000e@P02RP00dil00?`=000:ooooo`7o00000Oooool0
01kooooo00?o0000ooooooooool01oooool0o`007SD006Xh05nZ003QM000oPL00?LS003?Z@005i<0
001DC0003BL0008I000G<000Hd00AZ<00=b4003l3P00nAT00=FJ000XV@0005U8000@:P000QT001<]
001NA@0hWP00fHh00?/B003k5@00ei<0036L0000G4L0014[00026@004R`005e603BM003HT000na<0
0?/D003GT`00<9`0001KA`004B/0008I000C;000GT@0>Yl00=Z;003l4000nQP00=FJ000VV00005Q9
000>:@000QT001H_001S@01;Y000gWh00?d:003h8000d:P001BB0000DTd000/U00026P007C@006/g
06N]003TJP00o`@00?@_0037_@0008P40013B@001b4000@L000X>`00MRL0T;P00>]A003o0000kTL0
0:6l0000NQh002ho00047@001Ql003e600242`35``00lc<00?l3003UJ000J:d0001Z=`0073<0008J
000<9P00ED/089H00=BL003j5`00na800=NC000[VP0005Q9000>:0000QT001Tb001X>P1QZ`00i6/0
0?l3003c<`00aL<000233@00>TD000HO00057P00=480080D0;W2003b>@00lS@006V]0000JSP001Xb
00026@003RP005Q902jK003HS`00o0l00?TK003AY@004Y40001@CP002B<000<K000U>P00MBP0TkP0
0>e;003o0000je<008Fe0000LBh0024g00036P002bD005A<026F003EV000na<00?XG003CX0005i<0
001AC@002B<000<K000V>P00MRH0V;X00>i7003o0000jEX007Ra0000KC@001`d00026P003RP005Y8
03FM003KQ`00o@/00?LT003;]00008T10010B0001Ql000DM000f@`00P`h0a/400?@]003n1P00gg/0
04BR0000GTD0010Z00026@006S8006/g07>`003XF`00o`000>e9002B^00007<[000R=`000aX000`V
001GBP0_V`00fXX00?d;003g9000b[L000271@00?4H000DN00067`00?TL008T10<bc003g8@00o0d0
0=R@000VV00005A<000:90000a/002Lk001i8@2Y_P00lC/00?l2003SKP00DZL0001Q@P004B/0008I
000J<P00K3H0N[800>YD003o0000jU@007^b0000K3H001Tb00026@004R`0069105NX003TJP00o`40
0>m1002L^`0007DY000R=`000aX000dW001KB000eP0oX@00gg/00?h5003c=000]<40001k7P00:3`0
00<K000;9@00ET/0<9`00=b5003n2000mBd00<?40000OQL002dn00036`002R@005A<02ZI003JRP00
o@T00?D[0035``0007lE000^?P000a/000XT001DC00[VP00fhP00?d9003e;@00`/@0001n6@00:cd0
00<K000:9@00ETX0=9d00=f1003n1P00lc<00;;00000NB4002Dj00036P003BL005]704FS003QL`00
o`800?0o002I^P00078/000N=@000QT0014[001S@01QZ`00if000?l0003[DP00Mk40001Y>P005Bh0
008I000I<@00KC@0QkD00>e8003o0@00hf`004jU0000GDH000dX00036P009SX007XO0;[2003d;P00
o@T00=V<000QU`00051>00078@001Ad003]600::003@Y`00nQD00?TL003</`0008D9000c@@0011`0
00TS001EB`0eW@00gW`00?l4003a?@00VKX0001a;P006c<0008I000D;P00JCX0Nk800>a=003o0000
i6/004bU0000G4L000`V00036`00;3d0I9h:0?LQ003k4P00dJ<000F;0000?4H000@M00088P00DTd0
;I/00=f0003n1000lC`009Nj0000L30001Xb00026@005c0006dd08fg003_@@00o`<00=ml000bW000
05=<00088P0011d003a600N<003CX000o0l00?HV0035a00007/M000U>@000QX0010Z001T?`1][P00
je<00?l0003TJP00B:@0001IB0002bD000<L000d@P00R0<0cjT00?/D003h8@00akh0001n6@009cX0
008J000@:P00I3l0KZl00>]A003o0000hfl0046Q0000EdX000TS00047000>dD01hd00=BM003l3@00
mB/00;G10000MRH001he00026@005Rl006de096h003a?000oPD00=^8000NU@0004U<00057`001b00
055=02jK003ON`00o`800>e9001i/P0006Hm000A:`000QX002Lk001o5@39^0020?TK000K0<Zg0000
P1D002Lk00026P004B/006Hl07fc003^AP00o`<00=f1000UV00004e>00067`001b00055=036L003P
M`00o`400>]?001[[P000652000>:0000a/0031000271@3AYP00o10000[ooooo0Ol00001ooooo`00
7_ooool00ol0003oooooooooo`07ooooo`3o000K<`00Ic/0EJL00=mk003m2P00n1h00=:R000OUP00
05M:000>:@000QT001@^001P@`0lX000fX/00?/A003j5@00ei<0036L0000G4H0018[00026@004B/0
05]702nK003FU@00nQH00?/A003IS000>Yl0001OA0004bd0008I000@:P00FTP0:iX00=JG003j5P00
na400=V<000iW`0005i5000C;0000QT0014[001LA`0aW000f9800?/C003k5000ei<002nK0000FdL0
010Z00026@0052d00613046Q003LQ@00o0d00?TL003BX@0079D0001EC00032L0008J000J<P00J3/0
G:X00>9a003n1@00mBX00<Zg0003R`0004U<00088P000a/002Di001c;024]@00jEL00?l0003_@@00
[Kl0001n6@00<T4000DM00057P00>4@0084A0;_2003a>@00o`400>MQ001c/00006dc000O=@000aX0
00/U001BC@0HT`00dZ<00?TK003l3`00fH`003BM0000FdL000lZ00026@005c0006Dn05NX003QLP00
oPD00?@]0038_@0008L6000oA`001R0000@M000`@000OA/0[Kl00?0n003c<000M;00001]=0007C@0
008J000<9P00ET/09IP00=JF003k4`00nQL00=>N000KU000059=000:90000aX0028h001b;@28]@00
je800?l0003/C000TKP0001d:@0093T000<K000:9000DDd069<00=>O003j5`00na@00=FI000PUP00
05=<000;9@000aX0028h001c:`2=]`00k4d00?l0003ZD`00Pk@0001`<0007cH0008J000<9P00EdX0
;9X00=V>003l3P00n1l00<j^0006S00004I;0007800011d0039100205@2n``00lc<00?h4003QM000
CZD0001Q@P004R`0008I000G<000J3/0J:d00>IR003o0@00kd<009fk0000MRH002Dj00036`002RD0
05A<02JH003HT@00o0h00?PP003=/0000HX00011B0001Ql000DN000iA@00QPP0bKT00?HV003m2P00
fXT002nK0000EdX000/V00036P0093T007HW09jk003_@@00o`400>EX001MZP0006@o000C;@000QT0
01L`001Y>@1_[`00j5/00?l0003/CP00Q[D0001_<@0073@0008I000@:P00Gd@0CJD00>9a003o0`00
lC/00:Nm0000N2@002Di00036P0032H005Q:003c03JN003MPP00oPL00?@_0030``0007hH000/?P00
0a/000TT001CC00WV@00fH`00?d;003f:000akl000214@00<D0000@L00088P00DDd08IH00=RA003m
3000mRH00<Rm0000PPl00391000470002280055=02:G003HS`00o@/00?HW0036`000084C000_?`00
0a`000TS001DC00[VP00fhP00?d8003d;P00_/<0001l6`00:C`000<K000;9P00F4T0?:000=mj003n
1000lCX00:Bm0000MBP0024g00026P003bT0061305JX003UI`00o`000>e<0022]00006`f000H<000
0QT001H_001Z>01l/P00k4h00?l0003VI@00F:P0001P@`003bT0008J000R>000Mb@0[[l00?<c003n
1`00g8D002ZJ0000DTd000PR00047000=d<008L40<f^003i6@00nQP00<j/0000R08003Q400047@00
228005==02^J003LP`00oPH00?8g002U_@0007@Y000N=@000QT0018/001V?@1`[`00jU<00?l0003V
I000EZP0001NA0003RP000<J000X>`1SX0d0mRH00?`?003DW00038l00011B0001Ah000LQ001@CP0T
V000fhL00?h6003b=P00Xk`0001c:`0073@0008I000E;P00JSP0P[@00>i7003o0P00hGD003^O0000
ET/000TS00047000=d@008T00=2W003k4`00n2400<Nm0000OaL002Pk00036P003RT0065206:[003Y
F@00o`000>IT001BY`0005a6000<9P000a/0031000252P3=/000nQP00?TL003:^000084B000Z?@00
0aX000hX001Q@P1S[000jEL00?l0003UJ000Bj@0001JB0002RD000@L000f@`00R@00dJ@00?`@003f
9P00`L@0001i8@008CL0008I000C;@00JST0Q[D00>m2003o1000gH4002JH0000Cdh000HP00067`00
CTh09IP00=f2003o1000kd<008Be0000JCX0018/00026P0093T007`K0<No003h7`00nQH00<ba0000
P`h002/m00036P003bT006=007:`003/C000o`800=mj000^V`00051=000780001Ql004m>02RI003N
OP00o`800>e9001f/@0006@o000?:@000aX002`n0024303>[@00na<000[ooooo0Ol00001ooooo`00
7_ooool00ol0003oooooooooo`07ooooo`1F000H<@00I3l0Bj@00=f2003l3@00nAX00=BK000XV@00
05Y8000@:P000QT0018/001MAP0cW@00ei800?/E003k4P00fH`003ZO0000Gd@001@]00026@003bT0
05U902JH003DW000nAX00?`>003LQ@00A:80001R@P005Bl0008I000>:000EdX08YL00=>N003i6P00
o0d00=b50013XP000652000E;P000QT000lY001IB@0XV@00eIT00?XG003l4000fH`003RN0000GTD0
018/00026@004R`005e503NN003IS000o1000?XH003EV`009IP0001GBP003RP0008I000G<000ICh0
DZL00>1h003n2000mbD00<f`000:SP0004i>00098`000a/0024g001`<01i/P00ieh00?l1003a>`00
^L8000214P00=d<200057P3o000c@@00OQL0/<000?0o003o0000j5/007jc0000L2l0028g00036P00
2R@0051>012@003?Z@00n1l00?d<003LQ@00?Z00001NA@004B/0008I000D;P00HT40CJD00=mi003n
1`00mRP00<Zf0000RP0004E:00078@0011`002`m001j802Q_000kTD00?@/001o/`00070`000P=P00
0aX000/U001CC00LU@00e9d00?XG003k4`00eYL002>G0000ED/000`V00036P007cD006la07bc003Y
F000o`000>i6002L^`0007LT000X>`000a/000TR001?CP0@T000d:H00?TK003l4000ei8002RI0000
ET/000`V00036P007cH0070`08:d003ZE000o`000>a=002>]`0007<[000R>0000aX000/U001DC00S
U`00eYD00?/A003i6`00d:L000f?0000C4d000PR00047000;Ch007`K0;?0003b>000o`<00>=]001H
Z00006@o000D;@000QT001D^001U?P1NZP00i6T00?l2003`?@00ZKh0001i8000:C`000<K00098`00
DTd07ID00=FH003k4P00nA/00<nY0009S@0004M;0007800011d003A200223`36`000mB/00?h8003M
PP00>9h0001JB0003BL0008J000P=`00Lb`0T[P00>i7003o0000if4006N]0000Ic`001D_00026@00
5Bh006Hm06F/003VHP00o`000>i7002A^000078]000O=P000QX000hX001LAP13XP00h7P00?h4003b
=@00/l00001k7P00:C`000<K000:9@00ED/0;9X00=^9003m2@00mBX00<K10000PA80035000047000
2280055=01jF003GT`00o0h00?LS0039^00008D:000e@`0011d000LQ001>CP0HT`00eIP00?`?003h
8@00b[H000252000=T<000@M00078@00Cdh06I@00=JF003l3P00mb<00<Vi0000Q0`003=200047000
2280055=02:G003IS`00o@/00?HY0036`P0007lE000]?P000a/000XT001FB`0bW000gH400?h6003c
=000/<00001h8P0093T000<J000>:000GDH0C:D00>=^003o0@00kTD008fg0000Kc8001Xb00026@00
52d006Ll076`003ZE@00o`000>MN001RZ`0006=0000A:`000QT001lf001d:@2S_000lCT00?h5003N
OP00<id0001EB`002B@000@L002K000b@@00Q0/0bkD00?PN003k5000dJD000B;0000?DH000DM0007
8@00D4h08iL00=Z:003n2000lc400;700000Mb@0024g00026P0042X006=006F/003YFP00o`000>QM
001PZ`000652000?:@000QX002@i05nO403e:`00o@`00=JE000DTP0004I;00067`001R0004a=01bE
003ISP00o@T00?@a002^_`0007HW000O=P000QT001</001W?01g/@00k4d00?l1003SKP00AJ<0001I
B@002bD000<K000c@@00QPL0cZd00?XG003i7@00b[L000224@00;3h000<K000=9`00GTD0F:P00>MP
003o0000j5d005bZ0000Gd@000dX00036P00;3d0084A0<Zf003i7000nQP00<ba0000Q0`002ho0003
6`003BL005i505VY003WGP00o`000>MQ001EY`0005a6000<9P000a/0035100261P3?Z`00na@00?LQ
0036`00007`K000U>@000QX0014[001W?01k/P00kDP00?l2003ONP00;i/0001AC@001b4000DN0018
C00MU@00fXT00?h5003a?@00SkL0001/=P005Bh0008I000Q=`00NB40`l@00?LT003k4`00cjX00026
2000;cl000<K000=:000HD80Ijd00>]B003o0@00hG<003NN0000Dd`000LQ00057P00BD`089H00=b5
003n1000kd<0086d0000Ic`0014[00026P00:3/0084B0<^c003j5`002_ooool1o`00007ooooo000N
ooooo`03o`000?oooooooooo00Oooooo03/001H_001Q@P11X@00fhT00?`@003j5P00ei@0036L0000
G4H0018/00026@0042X005Y802ZJ003EV@00nQT00?`>003LQ@00A:80001R@@005Rl0008I000>:000
ET/07ID00=:S003h7P00o@/00=in001=Y@0006@o000H<0000QT000dW001EC00JU000dJD00?PO003m
2P00gWh004fU0000I3l001L`00026@003BP005I;01nF003CX000nA/00?`=003LQ@00@Z40001P@`00
52h0008I000@:P00FTP0;Y/00=NC00020?/D003o0=ND000^V`0005Y8000?:P000QT001D^001R@@18
X`00gGl00?d:003h8000cjT001:A0000DDd000XU00036P007SD006dd06n_003VI@00o`800?8e0034
a00008@<000lAP001Ql000@M000_?`00Nad0Y;d00>i5003o0000jU@008Vf0000LbX002Di00036`00
228004a=00R=003=/000mb@00?d9003NOP00Aj<0001Q@P004bd0008I000B;000Gd@0@j800=f0003m
2P00mb<00<f`0008S@0004Y=00088P000a/002Pk001f9P2F^@00kD/00?DY002:]P0007<[000T>@00
0a/000XT001@CP0DTP00dJ@00?TK003l4000f90002bJ0000F4X000dW00026P0073<006`e07:`003W
G`00o`400?10002W_P0007XO000/?@0011`000PQ0019C008S@00cZd00?PP003l3@00fX/0036L0000
FDT000dX00026P0073@006dd07Na003XFP00o`000>i7002I^P0007HV000V>P000a/000XT001BC@0K
U000e9`00?/E003j5`00dj0001FB0000D4h000TS00036`00:C`007TP0:Nn003`?P00o`400>EV001R
Z`0006Hl000F;`000QT001</001R@@1CY`00hW000?l3003b=`00]<40001l6`00;Ch000@L00088P00
Cdh05I800=>O003j5@00nQL00=:R000AT00004a=00088@0011`00310001o5@31a000m3000?h6003O
N`00@Z40001LAP003RT0008J000M=@00L300QkD00>a=003o0000jEX007:`0000JSP001P`00026@00
4b`006=005ZY003TJ@00o`400>m1002L^`0007DX000R>0000aX000dW001IB00jW`00gWl00?h6003d
<000_/<0001n6000;Ch000<K00098`00DTd099L00=R@003m3000mbD00<Vj0000Q0/003E200047@00
1b4004i>01JB003EVP00na400?PN003</P0008P4000jA@001Ad000LP0019C00@T000dil00?/C003i
7000cJl000290@00>dH000DN00078000BD`04I400=BM003k4P00n1h00<bb0000Q`D003Q400047@00
1b4004i>01VD003FUP00o0h00?LT0038^`00088?000a@00011`000TS001CC00YV@00fhP00?d8003d
;`00^l80001k7@00:3/000<J000<9P00FTP0@j80002f0>5d003o0P00l3l009Rj0000LRd001dd0002
6@004R`006@o06N]003XF`00o`000>UG001][P0006Hm000C;@000QT001`d001a;P2G^P00l3l00?l3
003PM`00?J00001HB@002bD000<K000^?`00PA80b;/00?LR003l4000dih000b>0000@TT000DN0006
8000C4d06Y@00=RA003m2`00mB`00;c20000NQl002Di00036P003bT0061305^Y003WH@00o`000>UG
001Z[P0006@o000A:`000QX0024g05VL4`3d<000o@T00=V>000LU@0004a=000680001Ql004I;01BA
003FU@00o@/00?D/002j`P0007TQ000R>0000QX0014[001T?`1][P00jU@00?l0003UI`00CjH0001L
A`0032H000<K000^?`00P`d0bk@00?TK003j6000cK0000252P00<40000<K000;9P00FdL0CZD00>EW
003o0000jUH006N]0000HT4000lY00036P00:3/007hG0<Rm003h8000na@00<nZ0000Q`D003=10003
6`002bD005]704nV003UI@00o`000>UJ001OZP0005m4000=9`000a/002dn00233@3</@00nQP00?TM
0039^@0007lE000X>`000aX0010Z001T?`1`[`00k4h00?l1003QL`00>9l0001DC000228000DN0013
B@0ETP00f9000?h8003b=`00V[X0001_<P005c00008I000M=@00MRH0]l400?HY003l3`00dJ<00029
0@00=48000<K000<9P00GTD0GJX00>UI003o0000hf`0046Q0000ET/000PR00057@00@dT05i<00=V<
003n1P00l3d008bg0000JSP001<]00026P009CT007hH0<Vj003i6`0:ooooo`7o00000Oooool001ko
oooo00?o0000ooooooooool01oooool0o`0052d005m403NN003HS`00na@00?/B003IS@00>Yl0001O
A00052d0008I000?:@00EdX08IL00=>P003i7@00o@/00=in001>Y@0006Dn000H<@000QX000`V001C
C00ETP00cjT00?LR003m2000h7L005NX0000Ic/001Xb00026P002bD0059=01:A003>Z`00mb<00?h8
003PM`00EjP0001W?0006S80008J000<9P00Dd`05i<00=2V003h7`00o@X00=in001;Y00006=0000F
;`000QT000hX001HBP0VV000eIX00?XG003l4000fHd003NN0000GDH0014[00026@004bd005m403nP
003KQP00o0d00?TL003BXP006Y@0001DC00032H0008J000K<`00JSP0I:`00>A[003o1000m3000<Nn
0000Q`D004580007800011`002/m001h8`2I^P00kD/00?l0003/CP00U;T0001f9@00:C`000@L0007
8@00AT/00HX00<Zg003f:@00oPL00>1g001AYP0006@o000E;`000QT0010Z001MAP0jW`00fhL00?`<
003h7`00cjT000n@0000Cdh000TS00036`0093T007<Z08^f003[D@00mRH009Fi0000MRH002Lk0003
6`00228004e>00b?003?Z`00n1l00?`=003JR@00=Id0001KB0003bT0008I000I<P00JCT0Ijd00>EV
003o0P00lCX00;?00000OAT0031000047@001b0004=9006:003;]000mb@00?d:003LQ000>Yl0001L
A`003bT0008I000J<P00JSP0KJh00>MQ003o0@00kd400:Fm0000NB4002Tl00036`002B8004m>01>A
003BX`00nQP00?/C003EV@007YD0001BC@002R@000<K000V>P00MRH0W;/00>m4003o0000iel006f^
0000JCT001Pa00026@004B/005m404ZT003PM`00oPD00?<b0030``0007lE000a@00011`000LQ001:
C00=S`00d:H00?TI003k4`00e9`001VC0000D4h000TS00037000;3h007`K0;G1003b=P00o`@00>5d
001;Y00005m4000@:P000QT001/c001]=01l/`00jU@00?l0003ZE000O;<0001]=@006S80008I000A
:`00H4<0D:H00>9_003o0P00lC/00:Nn0000N2<002Hj00036P002bD005M:036L003KQP00o@T00?D[
0036`@00084B000a@00011`000PR001@CP00H00KU000eYL00?`?003h8000bk@000271@00>TD000DM
00078000B4/03Xl00=:Q003k5000nAX00<j[0003R`0003m700057P001Ql004=900V=003AY@00nQL0
0?XH003?Z@001H`00010B0001Ah000HO0013B@0:SP00dJ@00?XE003i6P00cZ`0006:0000?DH000DN
00068000BD`04I400=BM003k4@00n1l00<^e0000Q@P003I300047@002280051=026F003HS`00o@/0
0?DY0035``0007hG000[?@000a/000/U001HBP0iW`00gg/00?h4003a>P00Xkd0001e:00083H0008J
000@:P00HD80G:X00>IR003o0000je4007Na0000JCX001D^00026@006C8006hb08bg003^A@00o`40
0>9`0016X`0005]8000<9P000a/002Xl001n6036`P00mRL00?`=003FU`0059400017B`8000HO0940
04I;01:A003EV000o0d00?HW0035``0007dI000X>`000aX000dW001MAP1AYP00iFL00?l0003[D000
MK40001W?0004bd0008I000N=@1CVAD0lSH00?h6003KQ`009IP0001@CP001b4000DN0010B00<SP00
e9`00?`>003f9`00aL@0001l70009SX000<J000?:@00HD80HZ/00>QJ003o0000if0005VY0000Gd@0
00dX00036P00:Sd0080D0<Vk003h7`00naD00<nZ0000R0<003E2000470002R@005Q904BR003SK@00
o`000>]@001a/00006Dn000A:`000QX002@i001k7@35``00mbD00?/A003AY0000HX0000gA00011`0
00XT001HB@15X`00hf`00?l0003ZE000JJd0001R@@003bT000<J000Y?000P1<0b[P00?TL003j6@00
c;<000223`00;3h000<J000>:000HD80IZ`00>YE003o0000hfd004:R0000EdX000TS00047@00?TL0
3Hl00=JG003m2P00lc400:Jm0000LRd001Tb00026@006c<007<[0:bo003d;P00o@`00=BL0006S000
03Q4000470002bD005]705>W003WG`00o`000>EU001:Y00005Q90009900011d003i700n@003GT`00
o@P00?8g002G^@0006dd000E;P000QT0024g001k7P36`000n1l000[ooooo0Ol00001ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`3o000B;000G4L0;Y/00=JF003j5`00o0l00=^60014XP000691
000F;`000QT000dW001EB`0IT`00d:L00?LQ003m2@00h7P005NX0000J3/001/c00026P002bD0055=
00f?003=/000mRL00?h6003RL000HJ/0001Z>0007C@000<J000:9000Cdh02Xh00<bb003f:000oPH0
0>9`001QZ`0006Xh000L=0000aX000/U001AC@0?T000cZd00?LT003n2000h7L005FW0000ISd001Ta
00026@003BL005E;01fE003BX@00nA`00?`=003KQP00@:40001P@`004bd0008I000A:`00G4H0=Id0
0=V=003l4000nQP00=BL000SU`0005I:000=9`000QT001Ta001W?01JZ@00hW800?h5003e:P00b[P0
006:0000AT/000PQ00036`009c/007DX08jg003[D@00o`000>i8002O^`0007TP000/?P0011`000LP
0010B000Q`D0akd00?@^003n1@00hW0005^Y0000IS`001P`00026@003bT005Y8036L003ISP00o100
0?TJ003BXP005i<0001BC@002R@000<J000Q=`00L2l0P;@00>UG003g8`00X;`0001i8@00:cd000@L
00078@00Ad/01H`00<ba003g9000o@X00=f2000nX00005e5000@:P000QT001L`001V?@1MZP00hf`0
0?l3003c=@00_/<000204`00=48000DM00067`00?TL008L50<Vj003f:@00oPP00=im0014XP0005i4
000A:`000QT001L`001W?01RZ`00iFP00?l2003a>`00/<00001l6`00;Ch000@L00088@00BT`02hh0
0<nY003i7000o1000=NB000VV00005E;000;9@000aX0028h001c:`2A^000kDX00?l0003YF@00Mk40
001/=@006c<0008I000?:@00G4H0@:400=im003n1`00mB`00<K10000P`l003E300047@001R0004A:
00F<003>[@00n1d00?`@003GU@008IH0001CC0002R@000<K000X>`00NB40Z[h00?4k003o0P00hfd0
05FW0000HT40018/00026@00634006Xh07:`003XFP00o`000>a=0027]@00070`000M=0000QX000lY
001MA@17X`00h7H00?h4003b=P00/l00001k7P00:C`000<K000:9000E4`0:9T00=V=003m2`00mRH0
0<Rk0000Q0`003E200047@001b4004a=000U01>A003DW@00na<00?TL003>[@000HX0000oA`001Ah0
00HO0012B@07S000d:P00?XH003j5P00dJ@000Z>0000A4X000HO00057P00?TL00HX00<j/003i6P00
na@00=:R000<S`0004I:00067`001Ah003i700::003?Z`00nAT00?XF003AY@0028d00012B@020006
7`3<0013B@0:SP00dJ<00?/E003i6`00cJh000280@00>TD000DM00078@00CDh069<00=JF003l3P00
mbD00<Rm0000PA4002lo00036`002R@005E;032L003MPP00oPH00?<d002__`0007PS000S>0000QX0
00hY001OA01BY`00i6T00?l0003]B`00P[@0001/=P005c00008I000G<000JcH0PK@00>e;003o0000
i6X0052V0000GDD000dX00036P009SX007/M0;k3003e;000o@X00=RA000LU@0004e>000780001Ah0
045800Z>003CW`00na400?LR0038_000080C000/?P000a/000`V001JB017X`00hfh00?l1003]BP00
P;<0001Z>0005Bh0008I000K<`1=UQL0lC/00?h4003MP000;Y/0001CC@00228000@M000kAP04R`00
dJ<00?/B003g8P00akh0001o5P00:C`000<J000=:000Gd@0F:P00>MQ003o0000jEX006>[0000HD80
00lY00036P009cX007dJ0<K1003g9000na400=:S0003R`0003U5000470002B<005I;03^O003QM000
o`400>e:001l/P0006Pk000C;0000QT0024g001h8P2k`P00mBX00?`>003DW@0028d0000lAP0011d0
00TS001FB`0lX000hG800?l1003/C@00M;00001U?P004B/0008J000V>P00OAT0akh00?PP003j5@00
cZ`000262000<40000<K000<9`00GTD0G:T00>QK003o0000iFH004^U0000FDP000XT00047000>D@0
1H`00=>N003l3@00mB`00;700000MBT001`d00026@006340070_0:6l003c<`00o@T00=JE000=S`00
03e700047@002B<005Q904VT003UIP00o`000>MN001DY`0005]7000;9@0011`003U400R=003EVP00
o@/00?<b002R_000070`000G<0000QT001he001h8`30a000mb@02_ooool1o`00007ooooo000Noooo
o`03o`000?oooooooooo00Oooooo04H0010Z001IB@0VV000e9d00?TK003m3000gH0004fU0000ICh0
01Ta00026P0032H0059=016@003>[P00mRH00?h6003RL@00HJ/0001[=`007SD000<J000:9000CTh0
1X`00<Zg003e;000oP@00>AZ001/[P0006dd000P=P000aX000TS001;C@03R`00bKT00?@]003o1000
i6T006^^0000KCD001lf00036P002B<004i>00R=003;]000mRT00?h6003RL000GjX0001Y>@006c<0
008J000;9@00DTd05I800=2X003h8000o@X00=io0019Y0000691000E;`000QT000lY001JB00/VP00
ei@00P3k5000C@3FU@00:iX0001IB@003bT0008I000F;`00I3l0D:H00=mi003n2000mRH00<ba0008
S@0004a=00098`000a/002@i001b;@23]000jEL00?l0003_@P00Z[h0001l6`00<D0000@M00067`00
>dH008@<0<G3003c<`00o`<00>AY001U[00006Ti000J<P000QX000dW001GBP0XV@00eYD00?/C003j
5P00e9`001nF0000E4`000`V00026P007SD006hc07Ja003WGP00n2000:bo0000O1`002lo00047000
1b00049900290@3:^000mRP00?h7003OO000B:<0001P@`004R`0008I000D;P00Hd00DjL00>5c003n
1@00m2l00<K20000P`d003U4008000DN0?l003U500243036`000m2h00?h5003PMP00CJD0001Q@P00
4b`0008I000E;P00I3l0F:P00>=^003o0`00lSD00;_20000OaH0035100047@001b0004A:00B;003=
/000n2400?`=003JR`00;i/0001HBP0032L0008J000O=P00L2l0Q[D00>]@003o0000je<008:d0000
Kc4001he00026P003BP005Y803NN003LQ000o@T00?HW0039^P0008H8000jA@001Ah000HO000oA`00
R@40bk<00?LR003l3@00fHh002VI0000ED/000/U00036P009CT007HV09nk003_@@00o`400>EW001O
ZP0006Dn000D;P000QT001H_001W?01W[@00if400?l0003^A`00T[P0001b;00083H0008J000=:000
FdP0?J000=im003n1P00m3000;k30000OQP002dn000370002B<0055=01nF003GU000o0h00?LQ003;
]@0008L5000jA@001Ah000HP0016B`0;SP00dJ@00?XF003j6000d:H000V=0000A4X000HO00057P00
?DH008T00<f^003i7000na<00=>N000BT@0004Y<000780001Ad003U400271@3</`00n1l00?/A003D
V`005980001;C@001b0000DM000iA@00Q`@0c;400?PM003k4P00dih0012@0000Ad/000HP00057P00
?TL00X/00<nZ003j6000nQL00=2X0005S00003m700057P001R0004M;016@003DW@00na400?PP003:
]P0008@;000d@P0011`000TR001BC@0WV@00fXT00?d8003d;`00^/80001k7P009cX000<J000=9`00
G4L0BJ@00>9_003o0@00kTD008fg0000Kc8001Xb00026@005Bh006Pj07Na003[D@00o`000>IS001J
Z@000613000?:@000QX002<h001h8`2b`000m3400?h8003JRP0099P0001@C@00224000DM000lAP03
R`00d:H00?/D003h7P00b[H000233@00<40000<K000:9@00F4X0?Z000>5e003o0P00kd@008Zf0000
KC@001L`00026@006340B9<J0>m1003o0`00ggT003NN0000ED/000TS00047000=d<008P20<nZ003j
5@00n1d00<Zg0000PQ0002dn00036`0032H005a704jU003UI`00o`000>YC001][P0006@o000A:`00
0QX002<h001j7`2o``00mRP00?`>003DW00005`02Xh0000nA`001Ad000PR001CC00bW000gg/00?l3
003_A000QkD0001[=`005Bh0008I000N=@00MBL0/<000?@_003m2`00eYH0012@0000@DP000DN0008
8P00Dd`0<id00=mi003o0P00kTL007jc0000J3/0018/00026@008SP007XO0<C4003g9@00na400=6V
0000R@4003A200036`002bD005]705:V003VHP00o`000>MO001EY`0005a6000;9P000a/003A20029
0@3AY000o1000?HW002l``0007PT000O=P000QT001H_001]=02F^@00lCT00?h7003IS`005I800012
B@001Ad000PR001FB`10X@00hfd00?l0003YF000GZX0001NA@0032H000<K000d@P00RP00dZ000?`>
003e;@00[Kl0001c:`006S80008I000L<`00MBP0]L400?HY00[ooooo0Ol00001ooooo`007_ooool0
0ol0003oooooooooo`07ooooo`1Q000>:000ETX07ID00=6T003h8000o@T00>1i001GZ00006Pk000K
<`000QX000XT001?CP09S@00bk@00?D[003n1000i6X006b^0000KC<0024g00036`00228004Q;0029
0038_@00lc400?l2003VH`00M[40001`<0008cP000<K00088P00ADX008P30<No003c<P00o`800>IS
001e/@00070`000R>0000a/000PR0018C000RP00bKX00?@^003o1000i6X006V]0000K3H001he0003
6P002R@0051>00f?003=[P00mb@00?h8003PN000DjL0001U?P006300008I000>:000EdX099L00=BK
003j5`00na400=V>000dW@0005a7000@:P000QT001@^001Q@P17X`00gH000?d:003h8@00cj/000n@
0000D4h000XT00036P0083L006la07Ra003WGP00o`400?4l002e`@0007lE000e@P0200057P3;000g
@`00PA80^l800?8i003o0P00iV<006n_0000K3D001dd00026P0032H005E<022F003DW000nQL00?/C
003FU@00:9T0001GBP003BL0008J000K<`00JcL0Jjh00>IT003h7P00]l40001o5P00<d4000DM0006
7`00?DH008H80<Nn003d;@00oPD00>5e001AYP0006=0000D;P000QT0018/001P@`19Y000ggX00?h7
003e:P00b;/000261P00?TL000HO00057@00=D80084B0<74003c<`00o`@00>9`001GZ00006@o000E
;P000QT001</001Q@P1>Y@00hGD00?h5003d<000aL<000224000=T<000DM00067`00?dL008P20<Zf
003f9@00o@X00=b5000hWP0005Y8000>:0000QX001`d001^<`1k/P00jEL00?l0003/C000SKL0001b
;@008CL000<J000<9P00EdX0;Y/00=Z;003m3000mb<00<^d0000R@4003m700067`001Ah003Y50026
2039^P00mRH00?d:003KQ`00<Y`0001HB@0032H000<J000Q=`00Lb/0U;T00>i7003o0000if0006V]
0000J3/001H_00026@0052d006@o05fZ003UI`00o`400>m1002M^`0007DW000S>0000aX000`V001H
B@0dW@00g8@00?d8003e:`00a/8000214P00<D0000@L00088P00Cdh05i<00=FJ003k4P00nAd00<f^
0001RP0003m700057P001Ql0045800B;003?Z`00nAX00?/D003CX00049000019C0001b0000DM000h
A000QPH0bkD00?PQ003l3`00eYL001ZD0000Cdh000PQ00047@00=D8008@;0<Vi003g8`00o0h00=ND
000LU@00051>00088P0011`003E200242`3:^000mb800?`?003FV0005i<0001=CP001b4000@M000i
A000R0@0c;400?TM003k4`00dZ4000b?0000A4X00P001Ql0D000@TT02Hd00=6S003k5000nA`00<f`
0000Q`@003Q400047@002240051>01nF003HT000o@/00?DZ0035a00007hH000Z?@000a/000/V001I
B@0oX@00h7H00?l3003`?`00V;X0001a;P0073@0008I000C;000ISd0K:h00>UG003o0000j5d006B/
0000Hd00014[00026@0083H007DX0:Nm003b=P00oPH00=b3000]V`0005=<00088P0011`003M30028
0`3>[@00nQP00?TJ003=[`0008H6000e@P0011`000TS001EB`0eW@00gg`00?l3003`?P00UKT0001`
<0006S80008I000F;`12T1`0kTL00?l1003QL`00@:40001HB@002R@000<L000b@@00Q@T0cK000P3i
6@00L03</@0008D9000a@@000a/000/U001IB@15XP00hfh00?l1003/C@00N;40001W?0004R`0008I
000P=P00MbD0]<400?@]003m2`00eYD001:A0000@dT000DN00078@00D4d0:IT00=f2003n1000l3h0
096h0000KC<001L`00026@006c<0078/0:Bm003c=000o@P00=R?000HT`0004I;00057P001b00051>
02ZJ003MP000o`@00>m10029]P0006/g000D;P000QT001lf001g902i`P00mBX00?`>003CW`001H`0
000iA00011`000XT001IB@18X`00i6P00?l0003YF@00GjX0001OA0003BL000<K000`@000QPP0cj/0
0?/D003g8`00aL<0001k7P008SP0008I000D;@00JSP0RkH00?0o003n1@00fhP001fE0000B4/000DN
00078@00Dd`0=Yh00>5c003o0@00je8006R]0000HD8000dX00036`00<40008L60=2W003k4@00mRP0
0;S20000MRL001dd00026@006C40078]0:Zn003d;P0:ooooo`7o00000Oooool001kooooo00?o0000
ooooooooool01oooool0P0003BL005A<01FB003?ZP00mb@00?h7003RLP00HJ/0001[=`007SD000<J
00098`00Bdd00XX00<Vj003d<000o`<00>IT001f/@00070_000T>@000a/000PQ0013B@00QPL0aL<0
0?8g003o0@00j5`0086d0000Lb/002Hj000370001b40041800252P33a000lSP00?l1003XG000P;<0
001b;0009CX000<K00078@00@dT008L50<K0003c<`00o`800>IS001d/00006lb000Q=`000a/000TS
001<C@06S000bkD00?HY003n1P00hW4005fZ0000J3X001Xb00026P0032H005A<01bD003BX@00nA/0
0?`>003KQ`00?J00001OA0004R`0008I000B;000Gd@0?J000=^6003l3@00nAd00=6T000GT`00059=
000;9@000aX001he001/=@1^[`00iV@00?l2003b=P00`<@000223`00>DD000HO00057@00<T4007hH
0;30003`?P00o`400>QL001j/P0006la000P=P000aX000XU001BC@0GT`00dZ800?TJ003l3`00fHh0
032L0000FTP000hY00026@006C4006Pk066[003TJ`00nA`00<;40000PQ0003M40P001Ah0:000>4@0
08<?0<C4003c<P00o`@00>=^001KZ@0006Hm000F;`000QT0014[001NA@10X@00gH400?d9003f9P00
bkD000290000@dT000LP00047@00<40007hH0;G1003b>@00o`800>AY001QZ`0006Ll000G<0000QT0
014[001OA015XP00gg`00?h7003e:`00b;d000252@00>TD200057P27000jA@00Q@T0b;d00?DZ003n
1`00gWh0046Q0000GDH0010Z00026@006S8006/g076_003XG@00o`000>i6002H^P0007DX000T>@00
0aX000/U001DC00UV000ei800?`?003h7P00cZd000F<0000A4X000HP00057@00=D<008<>0<K0003e
:`00oPP00=f0000kW`0005]8000>:0000QX001he001`;`29]P00k4d00?l0003YFP00Lk00001Z=`00
6C40008I000B:`00HD80DjL00>=^003o0P00lC`00:Rn0000N28002Lj00036`002bD005E;02bJ003J
R`00o@/00?HW0038_00008@<000f@`0011d000LQ001:C00@T000dZ400?XE003j6@00d:P000R=0000
A4X000HO00057P00?4H008P20<ba003h7`00o1400=FI000HT`0004m>00088@0011`003A200233@38
^`00mRD00?d<003HT0008YL0001AC@002B<000@L000`@000PA80akl00?HX003m2`00fHh002BH0000
DTd000TS00047000<400084A0<Nn003f9P00o@`00=RA000PUP00051>00088P0011`003A200252P3:
]`00n2400?`@003EVP005980001:C0001b0000DN000mAP02RP00cjX00080nQP007H0cjT000::0000
?DH000DN00078000C4d05i<00=JG003l3P00mbD00<Nn0000PA8002ho00036`002R@005I:03JN003N
O@00oP@00?4i002S_00007@Y000O=P000QT0014[001S@01RZ`00ieh00?l0003ZEP00KZl0001V?@00
4b`0008I000M=000LR`0W;/00?4l003n1000gW`003FM0000ET/000XT00047000<d4008D:0<bc003i
7000nQH00<nY0000R@0003U500047@002280059=02bJ003MPP00oPD00?8i002P_00007</000M=000
0QT001@]03f=7@3/C@00o`000>=/0019Y00005]8000<9P000a/002ho00223`3:]`00n1d00?XF003?
ZP0008P3000f@`0011`000TT001FBP0lX000hGD00?l2003^A`00P[@0001Z>0005Bh0008I000M=000
M2T0ZKh00?<c003m2000fHl001ZD0000BD`000HO00068000CDh08IH00=^9003n1P00lSP009bk0000
L2l001Tb00026@006C4006la09Vj003a>@00oPH00=^8000PUP0004a=0P001Ql0A@00CDh08YL00=^7
003n1@00lC`009Bi0000KS<001L`00026@0073@007@Y0:fo003d;`00o@/00=FH000<S`0003i70004
7@002B<005I;03nQ003RK`00o`000>]C001Y[@000691000>:0000aX002`m00233P3</P00nQL00?PN
0038_00007dI000U>P000QX0018/001X>`20]000kT@00?l3003MP@009IP0001>CP001Ql000LP001@
CP0^V`00ggX00?l2003]B`00Lk00001T@0003bT000<J000/?P00Q0`0cZh00?/D003g8`00a<@0001i
8P007cH0008I000G<000Kc40Wk/00?<c000:ooooo`7o00000Oooool001kooooo0ol00007ooooo`3o
000;9P00DDd03Xl00<ba003f:@00oPD00>A[001[[P0006dc000Q=`000a/000PR0016B`00R0@0a/40
0?<e003o0@00j5d0082d0000Lb/002Lk000470001b0003e700233P2l`P00lC`00?l0003ZEP00RkH0
001f9P00:S`000@L00068000>dD0088@0;S2003`?@00o`000>YF002:]P0007DW000Y?00011`000LP
000nA`00Q0`0`L@00?8h003o0@00j5d007jc0000LRd002@i00036`00228004I;00290038^`00m2h0
0?l4003TJ`00Ijd0001[=`007C@000<J000;9@00DTd059800=2X003h8000o@/00=f00016X`000652
000D;P000QT0010Z001LA`0dW@00fHd00?`@003j6@00dih001nF0000ED/000`W00026P006c<006Ti
06B/003TJ`00o`<00?@a0036`00008D8000nA`001R0000@M000^?`00Nah0YKd00>m4003o0000jUH0
08Be0000LRd002<h00036`002B<004m>012@003?Z@00n1l00?`<003KQ`00>Il0001LAP0042X0008I
000F;`00ICh0EjP00>9a003i6P00a/0000252@00?4H000HO00057@00=480080E0;W2003b>000o`80
0>EX001U[00006Pj000I<@000QT000lY001KA`0gWP00fhL00?d<003h8@00cJl000N<0000B4`000LQ
00047000;3h007/N0:Zn003`?P00o`400>IR001[[P0006Xh000I<P000QT000lY001LA`0lX000g8<0
0?d9003f9P00b[L000280P00?dP000HO00057@00=T<0088@0<G3003d;`00oPD00>1g001:Y0000613
000A:`000QT001L`001X>`1W[@00iV<00?l1003_@@00Xk`0001h8`009c/000<K000:9000DTd07ID0
0=FI003k4P00nAX00=2W000<SP0004U<00078@0011`0035000205032a000m3000?h5003ONP00A:80
001MA@003bT0008I000L<`00KS<0O[<00>YC003o0000jU<007jc0000KC@001/c00026@0042X005m4
04ZT003QM@00o`@00?8f002c`00007/M000Z?0000a/000XT001CC00SU`00f9400?`>003g8P00bkD0
00271@00>TD000DN00068000A4X028d00=2X003j6@00nQD00=:Q000?T00004U<0007800011d003M4
003c00252@3:^000mb<00?`=003GTP0089H0001AC@002B<000@L000`@000P1<0a/400?DZ003m2P00
fXX002ZJ0000E4`000XT00036`00;3h007hH0<;4003e;@00o@P00=^7000]V`0005E;000:90000a/0
02`n001o5`35a000mB/00?d9003JRP00:9T0001CC0002B<000@L000`@000PQ40akd00?HU003l3@00
ei@001bD0000Cdh000LQ00047@00>4@008L40<f`003i7000na@00=:S0009S@00049900057`001Ql0
04I;00n@003DW@00na400?PP003:^00008@<000b@@0011`000TS001DC00]V`00g8@00?h6003c=000
[[l0001g90008SP0008J000?:@00H4<0F:P00>IT003o0000je0007Ra0000JCX001D^00026@006S80
06la096h003_@P00o`800>5e000nX00005Q9000;9@000a/002ho00224039^@00n2000?/B003BXP00
1h`0000nA`001Ad000LQ001@CP0TU`00fXT00?h7003c<`00Zkh0001f9`007cH0008I000B;00hRQl0
jU<00?l0003UIP00DjL0001MA@003BL000<J000Z?@00OaD0b;d00?LR003k4P00dJ@000>;0000>TD0
00@M00088P00E4`0<id00=mk003o0`00kd4008fg0000KC@001L`00026@006S80074^09jk003b>000
oPH00=^8000RU`0004i>000680001Ql004Q;01RC003HS`00o@P00?<c002W_P0007<[000L=0000QT0
01H_001]=@2?]`00l3l00?h4003MPP00:9T0001@CP001b0000DO0017B`0IU000fHd00?h7003b=P00
W[/0001`;`006C40008I000J<P00LBh0X[`00?<d003m2@00f94001BB0000@dT000DN00088P00Dd`0
=Yh00>1f003o0@00k4`007>`0000I3l0010Z00036P00:3/0080D0<Zh003i6`00nAX00<Zf0000P1<0
02Tl00036P0042X006Dn07Ja003]BP00o`800=mj000^V`00051=000780001Ql004e>02FH003MP@00
o`<00>i5001m/`0006Hl000A:`000QX002Pl00214P3;]000nQP00?PO0037_`0007`L000R>0000QT0
01@^001/=@2D^@00lSP000Sooooo0ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`34
000:9000Cdh01X`00<Zg003d;P00o`<00>EU001e/@00070_000T>@000a/000LQ0011B000Q@X0`<<0
0?4j003o0000jEL008^f0000MRH002/m000470001Ql003U40020502a`000kd800?l0003[D000U[T0
001i8@00;Sl000@M00067`00=T<007lF0:fo003_@`00o`000>]@002E^@0007PR000]?P0011d000HO
000iA000PA80]/400?0n003o0000jUL008Rf0000MBT002Pk000470001b40045800261`36`@00lc<0
0?l2003VI000LJl0001^<`0083H000<J000:9000Cdh038l00<f^003g9000o@P00=mj001@YP0006@o
000F;`000QT000lY001IB@0/VP00ei@00?/C003j5@00eYL002RI0000F4X000hX00026@00634006Ll
05ZY003RL@00oPD00?D/0039^P0008P20013B@001b4000@L000Z?@00N2<0V[X00>e:003o0000je00
08ng0000MBP002Hj00036`00228004]=00R=003=[`00mb<00?d:003MP@00@Z80001OA0004R`0008I
000D;P00HT40CZD00>1h003j6@00bKT000280`00@DP000LP00047@00;cl007dJ0:jo003`?@00o`40
0>MQ001_[`0006/f000K<`000QX000dX001HB@0^V`00fHh00?`?003i7@00d:P000j?0000CTh000PR
00036`00:C`007PS09nl003_A000o`000>QL001e/@0006de000L=0000QX000hX001IB@0cW@00fXT0
0?d<003g8@00cK0000>;0000A4X000LP00047@00<D4007lE0;c2003c=000o`@00>9a001DY`0006=1
000C;@000QT001D^001U?P1MZP00i6X00?l2003a>`00[Kl0001k7P00:cd000<K00088P00Cdh05I80
0=>O0080nQH002`0dZ0001BA0000Cdh000PR00047000;Ch007dJ0;O1003b=P00o`@00>5c001>Y@00
0613000A:`000QT001Ta001[=`1d/000jET00?l0003/C@00R;H0001`<0007SD0008J000>:000G4L0
@J400=mk003n1P00m3400;k30000OQL002ho000470002280051>01^D003EV000na400?PN003=[`00
0HX0000oA`8000DO0?h003m7006:003=[P00nAd00?/B003EVP005i<0001?CP00224000@L000c@@00
PPl0akh00?HX003m2`00fX`002RI0000E4`000XT00036`00;3d007dI0;o3003d;`00oPL00=b3000c
W@0005M:000;9@000a/002Tl001k7@2g`@00lc800?h6003MP000=Yh0001GBP002bD000<K000Y?000
O1`0^/800?@`003n1`00g8<0032L0000ED/000XT00036`00;3h007lG0<G3003e:P00o@X00=V=000T
U`00055=00088P0011`003A200242`3:]`00n2000?/A003DW0004I000017B`001Ql000DN0011B008
S@00dJ@00?/D003i7000c;4000271P00=T<000@M00088P00DDd09IP00=Z:003m2@00m2l00;W20000
NQl002Hj00036P003BP005e504nU003TJ`00o`400>e:0022]00006/f000G<0000QT001P`001/=@27
]@00kTL00?l1003SK`00B:<0001KA`0032H000<K000[?@00OaH0a/000?LU003l3`00e9`000j?0000
@dT000DN00068000C4d06i@00=R@003m2P00m2h00;K10000N28002<h00026P0042X0<hPP0>UI003o
0000iel005bZ0000H4<000hY00036P009cX007`K0<G3003f9P00o0l00=BM000:SP0003m800057@00
2240055=02ZJ003MPP00oPD00?4l002G^P00070`000I<@000QT001Pa001^<P2C^@00l3d00?h4003M
P@00:YX0001AC@001b4000DN0012B@0AT000eYH00?d;003d;P00//00001f9P007cD0008I000D;P00
JSP0Q;D00>i5003o0`00gg/0036L0000DTd000PQ00057P00@TT04Y400=ND003m2P00m3400:Vn0000
Lb/001`c00026@005c0006lb09Rj003a>@00oPH00=Z;000LU00004Q<00057P001b00055=02fK003N
O000o`800>i7001n/`0006Lk000B;0000QX002Di001m6P37_P00n1l00?XF003=/00008<=000/?P00
0aX000hX001R@@1[[P00je000?l1003QM000=ih0001CC0001b4000DN0018B`0MU@00fhP00?h5003`
@000QkD0001Y>@004R`0008J000U>@00OQP0bKX00?TL003i6P00bKP0001o5`009SX0008J000B;000
JCT0RKH00?0n00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`0P00098`00
BT`008T00<Nm003c<`00o`800>MO001o/`0007<[000W>`0011`000HP000lAP00PQ00]L400?10003o
0000je4009Ji0000NB4002lo00057@001Ah003A2001m6@2V_@00kTL00?l0003]BP00XK`0001l7000
<T4200057P3o000b@@00O1`0X[`00>e9003o0000kDX00:2l0000Nad0035000057@001Ah003E2001n
602[_P00kd@00?l0003[D000TkP0001g9000:cd000@L00068000?4H008<=0;o3003b>000o`400>MN
001k/P00074_000S>0000a/000TS001;C@05S000bkD00?HY003n1P00hG<005VY0000Ic`001Ta0002
6@003BL005M:02BG003EVP00nQL00?/A003HT000<9`0001JB0003bT0008I000F;`00I3l0DJH00>1h
003n1`00mRL00<^d0004R`0004U<00088P000a/002Lk001e:02?]`00je000?l0003]BP00VKX0001h
8`00:S`000@L00078@00ATX00HX00<Zf003f:000oPL00=mj001;Y@000691000D;@000QT0018/001P
@`14XP00gWl00?XG003;/`000h/00016B`001b4000@L000/?@00NR00Xkd00>m3003o0000j5/007Vb
0000KS8001he00026P0032H005I;02JH003GU@00na800?XI003BXP005Y80001AC@002B<000<K000U
>P00MBP0UKT00>e:003o0000jUH007nc0000Kc4001le00026P0032H005M:02ZJ003HT000o0l00?PM
003?ZP002hh0001:C000224000@L000]?P00O1/0/L000?4j003o0P00i6X005fZ0000ICh001D_0002
6@004bd0069105>W003RL000o`<00?8f002h`P0007hH000_?`0011`000PQ001;C@0>S`00dJH00?TI
003k4`00eIX001^D0000DDd000TS00036`00:C`007XO0:bo003a>`00o`800>=/001GZ00006=0000C
;@000QT001L`001X>`1Z[P00if000?l0003^A`00TkP0001c:`008CL000<J000=9`00FDT0>9h00=f2
003n2000mB`00<K20000PA80039100047000224004e>01>A003CWP00na@00?TJ003@Z00028d00014
BP001R0000DN000jA@00Q`D0bk@00?LQ003l3P00ei@001nF0000DDd000TS00047000;cl007lE0<G4
003e;000o@P00=b5000aW00005I;000;9@000a/002Pk001k7P2d`@00lc@00?h5003NO000?:00001I
B@0032H000<J000U>P00N280[;l00?8g003n1000ggX003jP0000FTP000`W00036P009CX007TR0:no
003b=@00oPD0000L0=im000iW`0005Q9000;9P000a/002Tl001l702k`P00m2l00?h8003KQP00;9X0
001DC0002B<000<L000`@000PA40b;d00?LU003l3P00eYH001RC0000CDh000LP00057@00?4H00HX0
0<nZ0080nQP002X0cj/0002:0000>dD000DM00078@00Cdh07ID00=RA003m2`00mBX00<C40000OAX0
02Tl00036`0032H005]804FS003RL@00o`800>m4002=]`0006hb000I<P000QT001D_001Z>01l/P00
k4d00?l0003TJ000DJH0001NA@003BP000<J000W>`00O1`0`/@00?DY003m3000eYD001FB0000B4`2
00067`1C0017B`0DTP00eYH00?d<003e:@00`L@0001k7@009SX000<J000>:@0^QB80if000?l0003Y
F@00IZ`0001S@00042X0008J000S>000NR00_<800?D[003m3000eYL001:A0000A4X000DN00078000
Cdh08YL00=Z9003n1`00lSH00::l0000LR`001`c00026@005Rl006`f08Vf003_@`00o`<00=mk000c
W@0005=<00088P0011d003e700V=003DW@00o0h00?HY002m``0007TQ000R=`000QT0018/001W?01j
/P00kDX00?l1003QM@00>Il0001EB`002B8000@M000mA`0:SP00e9/00?`<003e;000]<40001f9P00
7SD0008I000E;P00K3H0SKL00?0o003n1000g8@002BG0000CTh00P001Ql0<P00CTh09IP00=b3003n
1000kd4008Rf0000JSP001@]00026@008SL007XO0<G4003g9000na<00<nY0000QPH0031000036`00
3BL005m406:[003ZEP00o`000>=]000oX@0005I;00088P001Ad0049901FB003ISP00oPL00?4j002B
^00006`e000D;P000QT0028g001k7P36`@00n2000?XG003</P00088A000Y?0000aX0014[001V?01o
/`00kd@02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo090000PR0014BP00
QPH0aL<00?8h003o0@00jEP008Zf0000MRH002/m00047@001Ql003M3001o5P2Z_P00kTD00?l0003]
B`00X;`0001l7000<d4000DN00057@00<40007XO09^j003/C@00o`000>m4002[_P0007lG000f@`00
1Ql000@M000^?`00NB40UkX00>a?003o0000kd@00:Zn0000OQP003E200057P001Ad00310001k7@2P
_000kDT00?l0003]BP00W[/0001j7`00;cl000@M00067`00>4@0080C0;C1003`?P00o`000>UH0025
]@0007<[000V>P000a/000PQ0015BP00R@40b;/00?@^003n1000hfd006>[0000JST001/c00026P00
32H005A<01bD003BX@00nA/00?`>003JRP00>Il0001MAP004B/0008I000D;@00HD80Aj<00=io003m
2@00mb<00<j^000;SP0004i>00098`000a/002@i001b;025]@00jUH00?l0003_A000Y;d0001k7P00
;Sh000@L00078000@DP008L40<Rl003e;000oPD00>5d001EY`0006@o000F;`000QT0010Z001MAP0k
W`00g8D00?/F003>[@002Xh0001<C@00228000<K000X>`00MbD0VKX00>e9003o0000jUD008>d0000
LBh0024g00036P002bD005=<01jE003DV`020?XE003c0=BK000NU@0005=<000;9@000aX0028h001b
;02:]P00je000?l0003[D000R[H0001b;0008SL000<J000;9@00E4`08YL00=JF003k4P00nAT00=6T
000BT@0004m>00088P000a/002Xl001i802V_@00l3l00?l1003VI000Ijd0001X>P005c00008I000A
:`00H4<0BZ@00>1g003n1@00m3000<?40000PA8003=100047@001b0004I:00J<003>[000n1d00?`@
003GT`008iL0001DC0002R@000<K000V>P00Mb@0XK`00?10003o0@00iFH0066[0000ICd001D^0002
6@005Bh006Dn062[003UIP00o`400>m2002N^`0007HW000T>@000aX000/V001GBP0_V`00fhP00?d:
003f9`00b;`000242`00=T<000@M00078000Ad/038h00=6U003j6000nQH00=:R000?T00004U<0007
8@0011d003I300242`38^`00mRH00?d<003IS@009iT0001DC0002R@000<K000[?@00OA/0^/800?<a
003n1P00gWh003VO0000FDT000`V00036P009CT007PS0:Vn003a>@00o`<00>1f0015XP0005a7000>
:0000QX0028h001e9`2R_000lC`00?l3003QL`00Aj<0001MAP003RP0008J000R>000MRL0Y;d00?4k
003o0`00h7H004:R0000FdP000dW00036P009CX007TQ0;30003c=000oPH00=f0000eW@0005I:000:
9@000a/002`m001o5`35``00mBT00?d;003HS`0089H0001@CP00228000@M000gA000Q`D0c;400?TL
003k5@00dJ@000N<0000@4P000DN00068000BT`05I800=JG003l3P00mbD00<No0000P1@002dn0003
6`002bD005Q903bP003PN000o`<00?0o002H^P00074^000L<`000QT001<]001W?01b/000jU<00?l0
003VHP00FZT0001P@`003bT0008J000T>@00NB40]l400?@^003m2@00fHl001fE0000CTh000LP0005
7P00@TT038l00=BM003l3`00mbD00<K00000OQL002Tl00036P003BL0:H8S0>EV003o0000je<0072_
0000ICd0018/00026@0083H007LU0;70003d<000o@T00=R@000JU00004Y<008000HO06/004Y<01ZD
003HS`00o@T00?<a002]_`0007DX000N=@000QT001@]001Y>P1n/`00kDT00?l1003QM000?:00001F
B`002B<000@L000iA002R`00dJ<00?/A003g9000aL80001l70009CT0008J000@:P00I3l0L:l00>]@
003o0000hfh004:R0000EdX000XT00047000>D@00h/00=:Q003l3`00mRL00;o30000NB40024g0002
6@004bd006Ti08>d003^A000o`<00=in000/VP00055=000780001Al004U<01fE003JR@00oPH00?4k
002C^00006dd000F;`000QT001le001g9@2j`P00mRP00?`?003AX`0008T0000e@P000a/000/V001M
AP1HZ000j5d00?l0003UI`00BJ@0001HB@002B<000@M000mA`0>S`00eYD00?d9003c=@00WK/0001_
<P005c00008I000O=@00N2<0`L@00?LT003k4`00cZ`000242`00;Ch000<J000?:@00I3l0MK000>e9
000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0=P001b4003m80024302k
`P00l3d00?l0003[DP00U;T0001i8@00;cl000DM00057P00<d4007`L0:2l003]B`00o`000>i5002[
_P0007lF000g@`001Ql000@M000/?P00Mb@0T;P00>YC003o0000l3l00;K10000PA4003]500068000
11`002Xm001f9P2=]`00jUD00?l0003`?`00]L4000214P00>DD000HO00047@00;Ch007PS09Fi003/
C`00o`000>i5002X_P0007dI000c@@8000DN0?l003=2001m6@2Z_P00kd@00?l0003[DP00T;P0001f
9P00:C`000@L00078000@4P008H70<K1003c<`00o`<00>EV001][P0006`e000N=@000aX000/U001A
C@0DTP00d:L00?PO003m3000g8<0046Q0000H4<001<]00026@004R`005m403jP003LQ@00o@`00?PN
003@Y`004i40001AC@002R@000<J000P=`00Kc40N[800>QL003o0000l3l00:no0000OAT003510004
7@001Ql003a600242`36`P00lc400?l4003SK@00GZX0001W>`006340008I000?:@00FTP0<id00=V<
003k5P00d:L0016A0000D4h000TS00036`009CT007@Z08jg003/C`00o`000>a?002>]`0007@Z000T
>@000a/000XT001AC@0FTP00dZ800?XI003k4P00eiD002JH0000ET/000`V00036P007cH0070`082c
003ZEP00o`000>e:002D^@0007DX000U>@000a/000XT001BC@0JU000e9d00?XE003j5P00e9d001ZD
0000DDd000TT00036`009SX007LU09bk003^A@00o`000>QM001a[`0006/g000J<P000QT000lZ001M
AP11X@00gWd00?h7003e:`00akl000243000=d@000DN00067`00@4P008T00<bb003g8P00o0d00=V=
000[VP0005I;000;9P000aX002<h001d:@2F^@00kTH00?l0003WH000JZh0001X>P005c00008I000C
;000HT40EjP00>=/003o0P00lC`00:Rn0000NB8002Lk00036`002R@005A<02NH003HS`00o0d00?LS
003:]P0008L5000kA@001Ah000HO0012B@05S000cZ/00?TK003k4P00e9`001JC0000Cdh000PR0004
7000<T40084A0<K1003e:P00o@T00=^7000_V`0005I;000;9@000a/002Lk001j802``000lSH00?h4
003PN000@Z80001KA`003BP0008J000R=`00MBP0W[/00?0o003o0P00hVl004jU0000Gd@000lY0002
6P007cH007</09Ni003_@P00o`400>=]001AYP0005m4000?:@000QX001lf001c:`2I^P00l4000?l2
003RL000Bj@0001MA@003RP0008J000R>000MRH0Y[d00?4i003n1000ggT003fP0000FDT000`V0003
6`00:3/007`L0;c3003d;P00o@P00=^9000XV@0000/005==00098`0011`003=100242`3:]`00n200
0?/A003CWP003Xl00015BP0200067`2^0014BP0>S`00dih00?/A003h8@00bKT000233P00<D0000<L
000:9000ED/0=9d00=in003n1@00lCT00::l0000M2X001le00026@004B/006@o06R]003YF@00o`00
0>QL001T[00006=0000A:`000QX0024g001f9P2]_`00lc<00?h7003KR0009IP0001AC@00224000DM
000mAP05S000dJ<00?/B003h8000bKX000214P00;Ch000<K000<9P0UP2@0hf`00?l1003/C@00N[80
001X>P0052d0008I000M=@00M2X0Y[d00?<e003n1`00fXT0026G0000Cdh000LP00057P00A4X04Y40
0=JF003m2`00mB`00;S10000N2<0024g00026@004R`006Hm07B`003/C`00o`000>=^0014XP0005U9
000:900011`003A200280`3?Z@00na@00?PP0038_00007lF000X>`000aX000lY001R@P1V[000jUH0
0?l0003UJ000Bj@0001JB0002bD000<L000d@P00R0<0d:P00?/C003g8`00a/40001l700093T0008J
000A:`00ISd0N;400>e:003o0P00h7L003BM0000Dd`000PQ00057P00A4X05I800=R@003n2000lSH0
09fk0000L30001Pa00026@0073<007@Y0:no003e;@00o0d00=BM0006S00003U4000470002R@005Y8
04nU003VH`00o`000>MP001BYP0005]7000;9@0011`003U400J<003DV`00o@`00?@`002W_@00078]
000I<@000QT001`d001e:02f`@00mRT00?`@003AYP0008L4000a@0000a/000dX001Q@P1[[P00k4l0
2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo06`000HP000kA@00PA80/<00
0>m3003o0000k4`009jk0000O1`003=100057P001Ad002lo001i8@2E^@00je400?l0003`?`00]/40
00224@00>dH000HP00047000:C`007DY08Je003YF@00o`400?4i0031a00008@;000oB0001b0000@L
000W>`00Lb/0Pk@00>QK003o0@00lCT00<330000Q0`003i70007800011`002Tl001e9`2;]P00jUD0
0?l0003`?`00/l0000205000=d@000HO00047@00;cl007/N09nk003]B@00o`000>a<002J^P0007TQ
000]?P0011d000HO000kAP00P`h0`<<00?8h003o0@00if0007Ja0000Kc40024g00036P002B@004m>
00b?003>[P00mb<00?d9003NO@00BZ@0001R@@005Bh0008I000@:P00G4L0=Yh00=Z<003l3`00nAX0
0=:Q000JU00005=<000;9@000aX001he001]=01`[`00iV800?l1003a>@00^L8000204`00=T<20005
7P1A000gA000PA40_/<00?8f003o0P00iFL006R]0000JSP001/c00026P003BL005Q:02ZJ003GTP00
naD00=>P000IU000059=000:90000aX0024g001a;P24]@00jU@00?l0003]B@00V;X0001g9@009c/0
00<K00098P00CTh03i000=2X003i7@00o0l00=V>000^V`0005Q9000=9`000QX001`d001]=01f/@00
j5`00?l0003_A000Wk/0001h8`00:3/000<K00098`00Cdh04i400=6S003i6@00na800=JG000QU`00
05A<000;9@000aX002<h001d:P2A^000kD/00?l0003YE`00Nk80001^<`0073@0008J000>:000FTP0
>9h00=b4003m2@00mRL00<Vi0000QPH003a6008000DN0?l003a600271P39^@00mRH00?d:003KQP00
=9d0001IB@003BL0008J000P=P00LBh0S;L00>a<003o0000jEX007B`0000JcL001Tb00026@004B/0
061304fU003QL`00o`<00?8g002c`00007`M000[?@000a/000TS001BC@0OUP00eYD00?`@003h7P00
cJl0006:0000?dP000HO00057P00?DL008T10<bb003h7`00o0l00=JE000NU@00055=00098`0011`0
02ho001n5`30``00m2l00?h7003MP000>9h0001IB@0032H000<J000T>@00MbD0YKd00?4l003o0`00
hW4004^T0000GTD000lY00026P007cD0078]09Bi003_A000o`400>AY001GZ0000652000A:`000QT0
01`d001`<02<]`00kTP00?l0003UIP00FZT0001R@@004B/0008I000L=000L2l0SkL00>i6003o0@00
i6T005BW0000H4<0010Z00026P007cH007<[09^k003`?`00o`800>5c0016X`0005a7000=9`000aX0
02Di001i8@2a`000lc<00?h6003MPP00<I`0001EB`002R@000<K000_?`00PA40b;d00?LT003l3P00
eYP001FB0000BT`000HP00057P00?dP01h`00=6T003k5000nAd00<bb0000QPP003E2000470002B<0
05=<02^J003LQ@00oPH00?<d002]_`0007LU000Q=`000QX0010Z001Q@P1NZP00iel00?l0003ZEP00
KZl0001V?@004R`0008I000N=@00LbX0X[`00?8h003n1@00gH8002fK0000Dd`000PR00047@00>4@0
08T10<nZ003j5P00nA`00<^d0000Q0`0035000036`002RD087dU0>5c003o0@00kTL008Be0000JcL0
01H_00026@006c<0074^09bk003a>P00oPD00=b3000ZV@00055=00078@001Ad003m800^>003DW000
o0h00?HW0033a00007/N000T>@000QX0010Z001S@01Z[P00jUD00?l0003UI`00CJD0001KA`002bH0
00<K000`@000Q@X0cK000?XH003i7000b[H000224000;3d000<K000=9`00Gd@0G:X00>QM003o0000
iV4005FW0000GDH000`V00036`00<40008D90<f^003j5P00n1h00<Rk0000OaH002Pk00036P0042X0
06=006j_003[D000o`400>9a000mX00005I;00098`0011d0038003m700j?003FU`00o@X00?@a002X
_P00078/000J<P000QT001Tb001a;P2T_@00lc800?d:003FUP003Hl0000nA`0011d000TS001GBP15
X`00i6T00?l0003XFP00FjT0001MA@0032H000<K000d@P00R@00dZ800?`>003e:`00//00001d:@00
6c<0008I000J<P00LR`0Zkh00?@^003l3@00dil0006:0000=D8000<K000<9P00GT@0HJ/00>YE00[o
oooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o00067`00=T<007hH0:Jm003]
B000o`000>i7002Y_P0007lG000g@`001Ql000@M000[?@00MRH0RkH00>UG003o0@00lCX00<330000
Q0/0041800078@000a/002Dj001b;@1l/P00iel00?l2003c=000a/0000271@00A4X000PR00036`00
93T0074_07Vb003WH@00o`800?<d0036`@0008L60013B@001b4000<K000V>P00Lb`0PK@00>QK003o
0@00lCX00;k30000P`h003a60006800011`002`m001h8`2E^@00k4l00?l0003^AP00YKd0001l7000
<D0000DM00057P00=d<0080D0;G1003`?@00o`000>UJ0020]000078]000T>@000a/000PR001:C@05
S000bk@00?HW003n1`00h7H005BW0000ICh001L`00026@003bT005U902fK003GTP00na800?XG003D
V`008YL0001FB`0032L0008J000K<`00JSP0Ijd00>AX003o0`00lc@00<C40000P`d003Y500067`00
1Ad003=1001o5`2d`000lC`00?l1003WH@00L[00001]=@007C@0008J000<9P00ED/08YL00=FI003k
5@00eIX0026F0000ED`000/V00036P007cD006hb07Zb003XF`00o`000>m3002S_00007TP000[?@00
11`000PQ0019C008S@00cJh00?PQ003m3000fhP003JN0000FdP000lY00026@006S8006Xh06b^003V
HP00o`400?0o002Y_P0007/N000/?@0011`000PR001;C@0;SP00cjX00?TM003l3`00f90002VI0000
ET/000`V00036P0083H0074^08Ne003[D000o`000>]A0025]@00070_000O=P000QX000`W001HBP0`
W000fXX00?d<003g8P00c;<000290000@4P000HO00057P00=d@008@<0<Nn003e:`00oPP00=f0000l
X00005]7000>:0000QX001dd001_<P22]000je800?l0003ZE000O[<0001^<`0073<0008I000?:@00
GDH0A:800=mi003n1@00lc800;k30000OQL002ho00047000228004m>01NC003DW000na<00?TJ003?
Z@001hd00014BP001R0000DN000iA000QPP0b[P00?LT003m3000fHl002JH0000E4`000XT00036`00
:S`007`L0;K1003c=000oPD00=mj0011X@0005]7000=:0000QX0024g002a001d:@2J^P00kd400?l1
003TJ`00E:L0001Q@P004B/0008I000L=000Kc40RKH00>e:003o0000iV<0062[0000I3l001</0002
6@006S8006dd08:d003/C@00o`000>MP001T[00006@o000C;0000QT001Xb001]<`25]@00kD`00?l0
003VH`00GZX0001S@@004B/0008I000L=000L2l0TKP00>i4003o0@00hf`004nV0000GTD000hY0002
6P008SL007HV0:Nm003b>000oP@00=ml000iW`0005Q:000;9@000a/002/m001n5`35``00mRT00?d;
003HT@007ID0001?CP001b4000DM000kA@00R@00cj/00?XH003j6@00cZ`000290@00>DD000@M0008
8@00D4d08iL00=Z;003m2@00m2l00;O10000NR0002Di00036P003RP005m405FW003UIP00o`000>]@
001h/@0006Pj000D;P000QT001/c001a;`2G^P00l3h00?l3003ON`00=Yh0001EB`002B<000@L000d
@P00QPL0cK000?TJ003j6000cZh000271@00=D8000@L00098`0LNRH0ggT00?l3003_@@00S[L0001^
<`006340008I000H<@00KS80TKP00?0o003o0`00gW`003:L0000E4`000PR00047@00>dD018/00=:S
003k4@00mb<00<K00000OQP002Pk00036P003RT00652066[003XF`00o`000>MQ001GZ00005i5000=
9`000a/002`n0022403:]P00nA`00?XH003=/00008@:000`@0000a/000`V001LAP1CY`00iV<00?l0
003XF`00GZX0001OA0003BP000<K000/?P00PPl0bk@00080nAX00400bkD000224@00:cd000<J000>
:000HD80IJ`00>YF003o0000i6X004JS0000F4T000XT00047000>TD01X`00=BM003l3@00mB`00;;0
0000MBP001dd00026@005c0006lb09Zj003b=`00oPP00=R@000DTP00049900057@00228005E;03fP
003RK`00o`000>YD001U[0000613000=9`000a/0031000271P3@Z000na400?HV002m``0007LT000N
=@000QT001L`001`<02P_000lc<00?d:003EV@0028d0000iA@0011`000/U001LA`1HZ000j5/02_oo
ool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo044000DN000b@@00Nad0Vk/00>a>
003o0000kd400;C00000PA4003]60006800011`002Pk001c:P21]000j5d00?l1003c=@00a/400027
1000ADX000PR00036`008SP006la07:`003UIP00o`<00?@_0039^`000HX00019C0002B<000<K000Q
=`00KS<0Kjl00>EW003o0`00m2l00<Rk0000R@0004Q;00088P000a/0028h001`<01g/@00iV400?l2
003c=@00aL8000262000@DP000LQ00047000:3/007DX08Zf003ZE@00o`000>m1002__`0007lF000e
@P0200057P3o000c@@00OAT0Zkh00>m3003o0000jU@008^f0000MBT002Lk00036`00224004E:0029
0039^P00mB`00?h5003RL000GJX0001X>`006C80008I000=9`00EdX09IP00=FH003j5@00na<00=ND
000ZVP0005Q9000>:0000QT001Ta001W>`1MZP00hfl00?h4003d;`00akl000261`00?dL000HP0004
7@00;cl007`L0:Vn003_@@00o`000>QJ001l/P0006la000P=P000aX000/U001CC00KU000dil00?/E
003GT`00:IT0001GBP003BL0008J000L<`00K3H0L:l00>MQ003o0@00l3h00:fo0000O1/002lo0004
70001b0004A:006:003;]000mRD00?d9003MP@00?j40001MAP0042X0008I000G<000Ic/0HZ/00>AX
003o0P00lCT00;C10000OAT002lo000470001b4004I:00B;003=/000mb400?d<003JRP00<Y`0001I
B@003BL0008J000M=000KS80OK<00>YF003o0000kD`008ng0000Lb/0028h00036P002bD005E;02NI
003HT@00o0l00?PN003>[@001X`00015BP001b0000@M000c@@00PA80a<@00?@_003n1P00ggT004FS
0000GTD0010Z00026@006S8006`e07Ra003YF000o`000>a>0028]P00070_000N=@000QX000hX001K
B00lX000gGl00?h7003e;@00aL8000214@00<T4000@M00078@00Bdd049000=:R003j5P00nQL00=:S
000>S`0004Y<00078@0011d003E200233P37_P00mRP00?d:003KR000;Y/0001FB`002bD000<K000W
>P00NB80Zkh00?4i003o0`00hG<004VT0000GTD000lY00026P007SD0074^092h003^A`00o`000>EU
001NZP0006=0000B;0000QT001Tb001]=@1o/`00je000?l0003XG@00JZd0001W?00052h0008I000G
<000JSP0N;400>YC003o0000jEX006f^0000Ic`001D^00026@00630006/g07^b003[D@00o`000>QM
001W[@0006Dn000C;@000QT001Xb001^<`27]@00kDX00?l0003UIP00F:P0001Q@P0042X0008I000O
=P00Lb/0W;/00?0n003o0`00hGD004:R0000FTP000`V00036P00:3/007`L0;g3003d;@00o@T00=Z;
000UV000055=002`00088P0011d003I300271P3</@00nA`00?XE003@YP0018/0000nA`001Ah000LP
001>CP0KU000f9800?d;003e:P00`/@0001l6`00:3/000<J000=9`00G4H0C:D00>=/003o0@00kDX0
08:d0000JcL001H_00026@006C4006hc08fg003_@`00o`800>5e000nX00005Q9000;9@000a/00310
00233@3:]P00n1d00?/E003@Z00008X0000iA@0011d000PR01Qg9P3MO`00oP@00?4l002I^P00070_
000J<P000QT001H_001/=P27]@00kTD00?l2003PMP00>Yl0001FB`002B<000@L000f@`00R080cjT0
0?/E003h7`00bKX000214`00:cd000<J000=9`00GTD0EjP00>MQ003o0000j5/0062[0000H4<000hX
00036P00:C`007lF0<Rl003h8000na@00<nZ0000Q`@003A2000370002bD005Y804ZT003TJ@00o`00
0>YE001W[@000691000?:@000aX002Tl001o5@39^P00n1h00?XG003=[`0008@;000_?`000a/000dW
001NA@1KZ@00j5`00?l0003VI000CjH0001KB0002bD000@L000f@`00R@00dJ<00?`@003f9`00_L<0
001h8`0083H0008I000E;P00K3H0T;P00?4l003n1P00fXT001bE0000B4/000DN00078@00DTd0=9d0
0>1f003o0@00k4h006j_0000Hd0000lY00036P00;Ch008@<0<f^003k5@00mb800<G30000NQl0024g
00026@005Bh006dd09Ji003b>000oPP00=NB000?T00003i700047@002R@005U904jU003VH@0:oooo
o`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`001Ad002ho001h8P2A^000jU@0
0?l0003a?000_/<000242`00@4P000LQ00036`0093T0074_07Na003VH`00o`<00?@`0038^`000HX0
001:C0002B<000<J000O=P00K3D0J:d00>=/003n1@00mBX00<^e0008S@0004m>000:90000aX001he
001[=P1U[000hfd00?h5003e:P00bkD000J<0000CDh000TS00036P007cH006dd06f^003UI`00o`<0
0?@`0038_00008P10016BP00228000<K000U>@00LR`0P;@00>QK003o0@00lC/00;[20000PQ4003U5
00067`0011d002lo001k7P2P_000kDP00?l0003/CP00UKT0001g9000:Sd000@L00078000@4P008H7
0<K0003d<@00o`<00>AZ001V[00006Xh000L<`000QX000`V001DC00MU@00dil00?TI003l4000fHh0
03:L0000FdP000lY00026@005Rl006Dn05BW003QM@00oPH00?DZ0039^@0008T10014BP001b4000@L
000[?@00NB40Wk/00>i7003o0000jUD008Je0000LRd002<h00036`002R@0051>01>A003AY@00naH0
0=V=000aW00005Y8000>:0000QT001Tb001Y>@1V[000iFL00?l2003b>000^<40001o5P00<T4000@M
00067`00?dL008L50<Vj003e:P00oPL00=mk0018X`000613000B;0000QT001D_001U?P1IZ@00hfh0
0?l3003c=000_/<000204`00<d8000@M00068000@DP008T10<Zf003f9@00o@X00=b4000jW`0005]7
000?:@000QT001/c001[=P1c/000j5`00?l0003^AP00VKX0001f9`009CX000<K000:9000Dd`089H0
0=JG003k4P00nAX00=2W000=S`0004]=00088@0011`002lo001n602j`P00lc@00?h4003QL`00CZD0
001P@`004B/0008I000H<@00JCT0KZl00>QN003o0000kTP009>h0000Lb/0024g00036P0032L005Q9
03>M003KQP00o@T00?HX0038_00008@<000g@`001Ad000LP0016BP09S@00d:P00?TJ003k4`00e9d0
01JB0000Cdh000PR00047000<D00080C0<G3003e;@00oPL00=f2000fWP0005Q9000<9P000aX002<h
001f9P2Q_000l3h00?l2003SK@00DZL0001P@`004B/0008I000L<`00l`00Kc80Q[D00>a<003o0000
iel006N]0000ISd001@^00026@005c0006Xh07Ja003ZEP00o`000>YG001d/00006Ti000G<0000QT0
01D_001X>`1_[`00jET00?l0003ZE000Mk40001Z>0005c00008I000E;`00J3X0LJl00>UG003o0000
jEL0076_0000J3/001D^00026@00630006/g07fc003[D000o`000>MP001RZ`0006=0000B;0000QT0
01`d001a;`2B^000kd<00?l2003RK`00Bj@0001MAP003BP000<J000T>@00NB40//000?<b003n1`00
g8@002fK0000E4`000TS00047000<T4008@<0<Zg003h8000na800=>P000;SP00049900057P001Ql0
04Q<01BB003EV000o0h00?HV0036`00007lF000[?@000a/000/V001JB013XP00hW800?l2003^A000
S;L0001^<`006C40008I000F;`00JcH0Pk@00>e9003o0@00hfh004NS0000FdP000`V00036`00;3h0
080C0<Rl003g8P00na400=:Q0007S00003i700057@001b4057DW0=^6003n1P00lSL00:>l0000Lb/0
01dd00026@0052h006Ti07fc003]B`00o`400>9`0013XP0005U9000:9@000a/003910026203=[`00
nQP00?TK003;]00008<=000_?`000a/000`V001KA`1>Y@00iFL00?l0003ZE@00JZd0001S@00042X0
008J000V>P00O1/0a/800?LT003k4@00dJ@0006:0000>4@000@L000:9000EdX0@J400>9_003o0@00
k4l0076_0000ICh0010Z00026P009CX007dJ0<K0003g8P00na<00<nY0000Q`@003=100036`002bH0
05a705:W003VHP00o`000>MN001HZ00005e6000<9P000a/0039100271P3?Z@00na<00?LS0035``00
07/N000S>0000QT001<]001Y>@26]@00kd800?l4003LP`0099L0001=CP001Ql000LP001@CP0/VP00
gW`00?l2003]B@00N;40001U?P0042X000<J000Y?000PA80bk@00?XH003h7P00b;d0001m6P0093T0
008I000C;@00JSP0S;L00?0m003n1P00fH`001NC0000@dT000DM00098`00EdX0AJ<00>EW000:oooo
o`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`0011d002/m001f9`27]@00jEX0
0?l1003b=`00aL8000271@00ADX000PR00036`008CL006hc06f^003TJ@00oP@00?D[003;]@0028d0
001?CP002R@000<J000M=000JSP0GjX00>9b003n1P00mRH00<f_000?T000055=000;9@000QX001/c
001Y>P1LZ@00hG<00?h7003f9P00cJl000f?0000D4h000XT00036P007C@006Xg06B/003SKP00oPD0
0?D[003:]`0018/0001;C@002B<000<K000R=`00L300Mk400>MQ003o0P00lSH00<C40000Q0/003i7
0006800011`002/m001h8`2F^@00k4h00?l0003]B@00Wk/0001j7`00;Sl000@M00067`00?4H008<=
0<?4003b=P00o`800>IT001`[`0006dd000N=@000aX000/U001BC@0FTP00dJD00?TM003l3@00fhP0
03^O0000GDD0014[00026@0052h0069104^T003ON`00oPP00?HV003</`001H`00019C000228000<K
000X>`00MRH0U;T00>a<003o0000k4l0092h0000MBP002Hj00036`002B<004e>00b?003>Z`00naH0
0=^7000iW`0005a6000@:P000QT001L`001V?01MZP00hfd00?l3003c<`00`/@000224000=d<000DN
00057`00>TD008@;0<K0003d;P00oPD00>5e001@YP000691000D;@000QT001<]001R@@1@YP00hGD0
0?h5003d;`00aL8000233P00>4@000DN00067`00?4H008H80<Rl003e:P00oPL00=im0013XP0005i5
000@:P000QT001Pa001Y>@1Y[@00iV800?l1003`@000Y;d0001i8P00:3/000<K00098`00D4d069<0
0=>M003j5@00nQL00=:P000DTP0004m>00088P000a`002/m001k7@2``000lCT00?l2003SK@00EjP0
001S@0004bd0008I000F;`00Ic`0I:`00>IT003o0@00kd8009fk0000MRH002@i00036P002bD005I;
02^J003IS000o@`00?LT003:]`0008L5000kA@001Ah000HO0011B002RP00cJh00?PN003l4000eYH0
01fE0000DDd000TS00037000;Ch007dI0;c2003c<P00oPD00=ml000oX@0005]7000=:0000QX0020g
001c:`2F^@00kd@00?l1003UI`00G:T0001S@0004R`0008I000I<@00C@00K3H0O;800>]B003o0000
jET0076_0000JCX001H_00026@005Bh006Lk06b^003XF`00o`000>]A001m/`0006`f000I<@000QT0
01<]001U?P1U[000iel00?l0003/CP00PK@0001/=@006C40008I000C;@00ICd0Ijd00>QM003o0000
je4007^b0000JcL001L`00026@005Bl006Pj07>`003ZEP00o`000>UJ001[[P0006Hm000D;@000QT0
01Xb001^<`28]P00kDT00?l1003TJ@00E:L0001OA0003bT0008J000Q=`00MRH0Z;h00?8g003n1@00
gWh003FM0000ET/000XT00036`00;Sl0084B0<Rm003g9000o0l00=FJ000BT@0004Q;008000HO0:@0
04=900f?003CWP00na400?LQ0039^P00088@000_?`000a/000XT001GBP0kW`00h7P00?l3003`?`00
U[T0001`;`006c<0008I000D;P00JCX0NK800>a>003o0000i6P0052V0000GDH000dW00036P00:C`0
07hI0<K2003f9P00o0h00=BK000>S`00049900057P001b00478W0=V<003m2000lc800:fo0000MRL0
01lf00026@004R`006Hm07>`003[D000o`000>AZ001<Y@0005]7000<9P000a/002ho00233P3;]@00
nA`00?XG003>[P0008H7000c@@000a`000XU001IB@15X`00hfd00?l0003/C`00Lk00001V?@004B/0
008J000R>000NR00_l<00?HX003l3P00dih000R=0000?4H000@M00098P00ED/0>9h00>5e003o0@00
kDX007^b0000Ic/0018/00026P008SP007XO0<;4003f9P00o1000=:S0001RP0003M3000470002R@0
05U904VT003TJ000o`000>UH001QZ`000613000=:0000a/002hn0024303=/000nQH00?PO0038_@00
07hI000V>P000QX0014[001W?01l/P00kTL00?l2003NO@00;9X0001@CP001b0000HO001=CP0TU`00
gH800?l4003_@`00P[@0001X>`004R`0008J000V>P00OQP0bKX00?TL003i6P00b[L0001o5@009c/0
008J000A:`00J3/0P[@00>m2003n1000fhH001jE0000B4/000DN00088P00E4`0?J000>=^00[ooooo
0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o000470009c/007<[07fc003WH000
o`800?<b0038_00008X0001:C0002B<000<J000O=@00JcH0I:`00>9`003n1P00mRL00<f_000?T000
055=000;9@000QX001Xb001W?01FZ000h7P00?d9003g8P00d:P001JB0000Dd`000`V00026P006C40
06Hm05>W003ONP00o@T00?LR003?Z@005I80001CC@002bH0008J000J<P00J3/0FZT00>5d003n1`00
mRH00<ba000;SP0004m>000:90000aX001lf001]=01][P00iFL00?l3003c<@00akl000271@00@TT0
00LQ00047000:3/007DX08bg003ZD`00o`000>m3002Y_P0007dJ000b@@001Ad000DN000gA000PA<0
^<800?4k003o0@00j5h007Zb0000L300024g00036P002R@0051>00n@003?Z`00n2400?d;003MP@00
@j80001P@`004b`0008I000B;000Gd@0@Z800=f2003m2P00mb800<j]000<SP0004i>00098`000a/0
02Di001d:P2:]P00je800?l0003]B@00V[X0001h9000:C`000<L00088@00B4`01H`00<bb003j5`00
gH0004:Q0000Gd@0014[00026@005Bh006@o05BW003QL`00oPD00?@_0036`00008D:000kA@001Ql0
00DN000f@`00PQ40`/@00?<c003o0`00hfh005VY0000ICh001H_00026@004R/0061304NS003ON`00
oPL00?D[0038_00008H8000lAP001Ql000DN000hA000P`h0a/400?@_003n1@00h7L004^T0000H4<0
018/00026@005Rl006Hm062[003TJ000o`800?4k002^_`0007/M000/?@0011`000PR001>CP0AT000
dJ@00?XI003k4`00eIX001bE0000DDd000TS00036`00:3/007TR0:Fm003`?`00o`400>EW001PZ`00
06Hm000E;P000QT001@]001T?`1KZ@00i6X00?l2003`?@00Ykd0001i8P009c/000<K000:9000Dd`0
8iL00=NB003l3`00n2000<ba0000RP0003m800067`001Ah003a60028103;]000mb800?`=003HT000
9IP0001CC0002R@000<K000Y?000Nah0/L000?8g003o1000hGD004RS0000GTD000lY00026P007SD0
074_08bg003]B@00o`000>MQ001U[00006Hm000D;P000QT001L`001d001Y>@1b/000jEP00?l0003[
D`00N[80001[=P006340008I000C;@00ICh0HZ/00>IQ003o0000kD/008Ne0000Kc8001/c00026@00
4B/0069105bY003UI@00o`000>e9002;]P0006la000K<`000QT0018[001S@01NZP00iV<00?l0003]
C000Q;D0001]=0006C80008I000C;@00ISd0JJd00>QK003o0000jU@007F`0000JCX001H_00026@00
5c0006/f07jc003/CP00o`000>IS001MZP000691000@:`000QT001le001c:`2N^`00lCd00?l3003P
N000?Z00001IB@002bD000<K000[?@00OQL0aL800?HX003m3000ei<001ZD0000CDh000LP00057P00
?dL01X`00=6T003k5000n1d00<^d0000Q@X003=1000470002B<005E;03:L003NO`00oPD00?4j002P
_00007<[000M=@000QT001</001V?@1`[`00jU@00?l0003VHP00FJT0001P@`003RT000<J000U>P00
Nah0_l<00?DZ003m3000eYD001FB0000Ad/200067`1m00a^9P3GTP00o@X00?D]002h`@0007TR000R
>0000QX0010[001T?`1Z[@00jUH00?l0003VI000EJL0001NA@003BL000<J000[?@00P1@0b;/00?PP
003k5000d:P000290000=d<000@L00098`00ETX0?J000>5c003o0@00kDX007fc0000J3X001<]0002
6@0083H007LU0;C1003e;@00o@/00=JG000?T000045800057P002240059=032L003OO000o`<00>m4
0025]@0006Xh000D;@000QT001lf001g902h`@00mB/00?`=003DW@0028d0000kAP0011d000TS001G
BP10X@00hfh00?l0003[DP00Jjh0001R@@003bT000<J000Z?000PA80bkH00?TJ003i6`00b[L00020
4`00:C`000<J000@:P00I3l0L[000>a=003o0@00h7H003BM0000DTd000LQ00057P00B4/079D00=Z9
003n1@00l3h008bg0000JcL001@]00026@008cP007/M0<K0003h8000nQH00<ba0000PPl002Xm0003
6P0042X006Dn07Ra003^B000o`<00=eo000VV00004e>00067`001b00059=03BM003QM0002_ooool1
o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo04`000<K000T>@00L300M;000>EV003o
0`00mBd00<Zg0007S00004m>000:90000aX001`c001Y>P1KZ@00h7H00?h8003g8P00cjT001JB0000
E4`000`W00026@00634006@o04fU003NOP00o@/00?PN003BXP007ID0001FB`003BP0008I000G<000
Hd00BZ@00=f0003m2`00n1h00=:S000LU@0005E;000=9`000QT001Pa001U?P1AYP00ggX00?d9003g
8P00cj/001:A0000DDd000/U00026P0073@006Xh06B/003SK@00oP@00?D/0039^@000HX00017B`00
228000<K000U>@00LR`0P[@00>UI003o0000l3h00;?00000P1D003I30P001Ah0o`00<d4007hH0:jo
003`@000o`000>UH0023]000078/000T>@000a/000TS001<C@08S@00c;400?LU003m2000gg/004bU
0000HT4001D^00026@004B/005e603ZO003KR000o0d00?PM003@Y`004i40001@C@002R@000<J000R
=`00LBh0PK@00>UH003o0000kd@00:Bm0000NQl002dn000470001b0004=90029003:]`00nQP00=mj
001:Y0000652000C;@000QT001<]001Q@P1;Y000ggT00?h7003e:P00bKX000271000?dP000HP0004
7@00<T4007lF0;O1003b>000o`800>AX001SZ`0006Pk000H<0000QT0010Z001MAP0nX000gH400?d9
003f9P00b[H000290@00@DP000HP00047@00<d80080C0;o3003c<`00o`@00>9a001DY`0006=0000D
;@000QT001@^001T?`1GZ000hfl00?l3003b=P00^<80001n6000<40000@L00078@00BD`02Xh00<nZ
003i7000o1000=ND000SU`0005A<000:9@000a/002Di001f9`2K^P00kd@00?l0003WH@00JZd0001X
>P005c00008I000B;000HD80DZL00>9`003o0`00lSP00;700000Nad002/m00036`002B<0055=01bD
003EV@00na800?TL003?Z`001X`00014BP001R0000DM000hA000Q@X0bKX00?HV003m2`00fXX002fK
0000ET/000/U00036`009SX007PS0:Nm003a?000o`800>9_001@YP000613000@:P000QT001/c001^
<`23]000k4l00?l0003XF`00KZl0001X>P005Rl0008I000E;P00Ic`0JJd00>MN003o0000k4d008Be
0000KS<001/c00026@004B/0069105VY003UI`00o`400>i6002A^000074^000N=@000QT0010Z001P
@`1CY`00i6/00?l1003_@`00UKT0001b;@007SD0008I000@:P00H4<0EJL00>AY003o0@00kTH008jg
0000L30001`c00026@004R`006=0062[003VH@00o`000>a>001n/`0006/f000H<0000QT001D_001Y
>P1e/000jU@00?l0003XG@00IZ`0001T?`004R`0008I000L=000LBl0TkT00>m2003o0P00hW8004JS
0000FdL000`W00036P009c/007`L0;k3003e;@00o@X00=V=000QU`00051>00088@00X00011d003Y5
0029003?ZP00nQL00?TJ003=[P0008L4000g@`0011`000PR001BC@0ZVP00g8D00?h6003c=@00Z[h0
001f9`0083H0008J000A:`00Hd00IZ`00>UJ003o0000j5`006:[0000HT40010Z00026P008SP007PS
0;G1003d;`00o@T00=V?000LU@0004e>000680001Ah026XU0=FI003l3@00mRP00<;40000Nad002Dj
00036P003bT00652062[003XG000o`000>QN001NZP000613000>:@000aX002Lk001m6@36`@00mb@0
0?/A003BX@001H`0000kAP0011d000PR001DC00dW@00ggT00?l2003_A000QkD0001[=`005Bh0008I
000M=000M2T0Z[h00?<b003m2@00f94001JB0000AT/000DN00078000D4h0:9T00=f2003n1000l3l0
08jg0000K3D001H_00026@007C@007@Y0:fo003d;`00o@/00=JF000?T000041800057@00228005A<
03RN003QM000o`400>a=001d/00006Dn000@:P000QX002Lk001n5`38^`00n1h00?XG003</@0008<>
000/?P000aX000hX001Q@P1Y[@00je<00?l0003RL000?:00001EB`00228000DM0013B@0ETP00f8l0
0?h7003b>@00U[T0001]=0005Rl0008I000P=P00NB80`/@00?LT003k4`00cZ/000252@00;Sl000<J
000>:000HT40Kjl00>a=003o0@00ggT002jK0000D4h200068003001@CP0/VP00ggX000[ooooo0Ol0
0001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o00036`008CL006dc06Z^003SK000oPD0
0?HX003</@003Xl0001AC@002bD0008J000J<P00ISd0DZH00=ml003m2P00n1h00=:S000MU@0005I;
000>:0000QT001H_001R@@14XP00g8D00?`>003i6P00e9`002FH0000F4T000lY00026@005Bh00652
046Q003KQP00o0h00?TJ003DW@008iL0001GBP003RP0008I000F;`00Hd00BJ@00=f0003m2`00n1h0
0=6U000IU00005A<000<9P000QX001Xb001X>`1KZ@00hG<00?h6003f:000bk<000N=0000CDh000TS
00036`008SL0070`07Ra003WG`00o`400?8i002n``00088?000jA@001Ql000@M000_?`00Nad0Y;d0
0>i6003o0000je8008fg0000MBP002Lk00036`00224004M;006:003:]`00mBT00?h6003QM@00E:L0
001U?P005c00008I000?:@00FTP0<Y`00=V>003l4000nAX00=:Q000JU00005=<000;9@000aX001lf
001^<P1g/@00j5d00?l1003`?P00[[l0001m6P00<40000@M00068000?TL008H70<Nm003j6@00hG@0
05>W0000I3l001D^00026@004B/005m404>R003MO`00o@T00?HV003;]0000HX00014BP001b0000@L
000^?`00O1`0[Kl00?0m003o0@00iV8006b^0000JSP001Xb00026@003RT005Y803JN003KQ`00o@/0
0?LR003</00018/00015BP001b4000@L000`@000OQT0]L400?8h003o0P00i6/005fZ0000ISd001H_
00026@004R`0065204jU003QM@00oPD00?<a0032a000084B000c@P0011d000LP0014BP03R`00cK00
0?PP003l3@00fHh002^J0000ET/000`V00036P008SL007<[096h003]B@00o`000>QK001c/00006/g
000I<P000QT0010Z001OA019Y000h7H00?h4003c<`00^l80001n6000;Sl000@L00088P00Cdh05980
0=>O003j5@00nQP00=6U000=S`0004U<00078@0011d003A200224036`000mB/00?d8003LQ000=Id0
001HB@0032H000<J000S>000MBP0WK/00>m1003o0@00i6T005VY0000Hd40018/00026@006C4006/f
07Vb003ZE@00o`000>YE001h/@0006/g000H<@000QT001<]002S001T?`1PZ`00iV@00?l0003^B000
S[L0001a;`007C@0008I000@:P00Gd@0D:H00>=^003o0P00l40009^j0000M2X0020f00026P003RT0
05e504ZT003RL@00o`800?0n002O^`0007DY000Q=`000QX000hY001NA@1<Y@00hVl00?l2003_@@00
V;X0001c;0007SD0008I000@:P00HD80EjP00>EW003o0000kDT008Rf0000KS<001Xb00026@004bd0
06Hm06^^003YFP00o`000>UG001_[`0006Ll000D;P000QT001Xb001^<`2:]P00kTL00?l1003TK000
CjH0001NA@003RP000<J000T>@00NB40/l000?<a003n1`00fhL002VI0000DTd000PR00047000=T<0
08L60<f`003i6`00nQH00=2X0001RP0003]600057@001b40051>02:G003JR`00o@P00?@`002d`@00
07PR000S>0000QX000lY001Q@P1MZP00if000?l0003ZEP00K:h0001U?P004R/0008I000O=P00MBL0
Z[h00?<d003n1`00fhP002BH0000D4h000LQ00057P05Ib@0dil00?`@003g9000a/00001n6000:C`0
00<J000=:000Gd@0EjP00>IR003o0000jEP006N]0000Hd00010Z00026P0093T007/N0<74003f:000
o0h00=BK000<SP00041800057@002240059=02bJ003MP000oP@00?0o002@^00006dc000G<0000QT0
01Xb001a;P2P_000lSH00?h7003JR`007ID0001;C@0200067`1>001=CP0QUP00fhP00?h6003a>P00
V;X0001_<@006340008I000J<P00LRd0Xkd00?<d003m2000f90001JB0000ADX000DN00078@00DTd0
<9`00=mk003o0P00kTL007jc0000Ic/0018/00026P0093T007`L0<K1003g8P00na@00<n[0000QPP0
031000036`003BL005m405nZ003YF000o`000>AZ0014XP0005M:00098`0011d003i700j?003FU@00
o@T00?<d002P_000070`000H<0000QT001dd001f9P2h`@00mRP00?`@003AY@0008P3000b@@000a/0
00dW001P@`1U[000jU<00?l1003QL`00=Yh0001BC@001b4000HO001<C@0UV000gH002_ooool1o`00
007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l000<J000N=@00JcL0HJ/00>9b003n1`00
mb@00<n[000ETP0005=<000<9`000QT001L`001T?`19Y000gH800?`=003i6`00e9d002FH0000F4T0
00lY00026@0052d005m403bP003JR`00o1000?XF003FUP00;I/0001KB00042X0008I000C;000GTD0
>Il00=V<003k4@00nQH00=JG000[VP0005Y8000@:P000QT001@]001P@`10X@00fhH00?`>003i6P00
dil0022F0000ET/000dX00026@00630006Dn05:V003ON@00o@P00?LT003>[@003Xl0001@CP002R@0
00<J000O=@00KC@0Kjl00>EU003o0P00lc@00<G20000Q@T003i70006800011`002`m001i8P2J^P00
kD/00?l0003/C000UkT0001h9000:Sd000@L00078000@TT008L40<Rm003d;P00oP@00>9_001MZP00
06Lk000I<@000QT000hX001HB@0ZVP00ei@00?/C003j5P00e9/0026G0000ED/000`V00026P0073@0
06`f06j_003VH`00o`800?4i002h`P00080D000d@P001Ah000HO000jA@00Q0`0aL<00?TK003SKP00
G:T0001V?@005c00008I000@:P00G4H0>Yl00=b6003m2`00mb400<f_0008S@0004U<00088@0011`0
02/m001i802S_000kd800?l0003XG@00MK40001]=00073@0008J000=9`00F4T0;Y/00=V=003l3P00
n1h00<n[000;SP0004Y=00088@0011`002`n001k7P2[_P00l3d00?l1003UI@00IZ`0001X>P006300
008I000A:`00Gd@0AZ<00=mk003n1P00mBd00<K00000P`d003M400057P001Ql003m700280P3;]@00
mb@00?d;003KR000<id0001IB@003BL0008J000O=P00LBl0QkD00>a?003o0000jUD007fc0000KC<0
01`c00026@003bT005a6046Q003NO000oPH00?@^0035a000084B000b@@0011d000LQ001:C00=S`00
dJD00?XH003k5@00dil001BB0000CTh000PR00047000<40007lE0<;4003d;`00oPH00=in000mX000
05]8000=:0000QX0020f001c;02C^000kTH00?l0003VH`00HZ/0001U?P0052d0008I000G<000JCX0
L:l00>QJ003o0000je00086d0000KC<001/c00026@004B/00?<0069205NX003TJP00o`400>m2002H
^P0007<[000P=P000QX000hX001MAP18X`00hG@00?l3003a>`00YKd0001g9@008cP000<J000=9`00
FdL0@Z400>1g003o1000lST00:Vn0000Mb@002@i00036P003BL005]704BR003QM@00o`<00?4l002R
_00007DX000Q=`000QX000hY001NA@1>Y@00hfd00?l1003_A000T[P0001a;`0073@0008I000B;000
Hd00HZ/00>MO003o0000je4007Vb0000JST001H_00026@005c0006/f082d003/C@00o`000>EV001H
Z0000613000?:@000QX0024g001f9P2Y_P00lSH00?h5003MP@00<I`0001EB`002B<000@L000b@@00
Q0`0b[H00?PO003k4`00dZ8000R=0000@4P000DN00078000CDh06i@00=RA003m2`00mB/00;o30000
Nad002Hj00036P003RP005i505BW003UIP00o`000>]A001e/@0006Lk000C;@000QT001dd001c;02P
_000lST00?h5003MPP00;9X0001BC@00228000@M009S8`3AY@00na<00?PP0039^P00084B000/?P00
0a/000`V001LAP1?Y@00iFP00?l0003[DP00L:l0001U?P004B/0008J000Q=`00N2<0]l400?D]003m
2`00eYD001>A0000A4X000DN00078000Cdh09IP00=^6003n1P00lCX009Zj0000L30001Tb00026@00
634006la09Ji003a>`00oPD00=b5000UV00004m>000780001Ql004Q;01VD003ISP00oPP00?<e002R
_000078]000J<P000QT001Pa001_<@2I^P00lCT00?h6003JRP007ID0001:C0001Ql000LP001@CP0X
V@00gH400?l4003_@P00QkD0001Z>00052d0008I000Q=`00NB40`<<00?HV003k4@00dJD000280P00
=48000<K000;9P00G4H0EZP00>MN003o0000iV@004fU0000FTP000XT00047000>TD01hd00=BK003m
3000m2l00:Zn0000LR`001Xb00026@006c<007<[0:jo003e;@00o0d00=>O0002RP0003I300036`00
32H005e505bZ003YF@00o`000>=]000nX00005E;00088P001Ah004M;01fE003KQP002_ooool1o`00
007ooooo000Nooooo`03o`000?oooooooooo00Oooooo01/000<J000L<`00J3X0F:P00>1h003m2@00
n2000=6U000LU@0005I;000>:0000QT001D_001Q@P11X@00fhP00?`?003j5`00eYL002fK0000FdL0
014[00026@004R`005e603BM003HT@000P3k4`00FP3HT000=Id0001MAP004R`0008I000A:`00G4L0
<I`00=NB003k5000na<00=RA000cW@0005a6000A:`000QT0018/001NA@0hWP00fH`00?/A003j5`00
eIP002RI0000FDT000lY00026@005Rl0069104VT003NO`00o@X00?PP003@Y`005I80001BC@002bD0
008J000L=000JcL0IZ`00>A[003o1000m2l00<Rm0000R0<004=900078@0011`002Pk001f9`2@^000
je400?l0003^A`00XK`0001j7`00;Sl000@M00068000?DL008D:0<G2003c<`00o`<00>AY001V[@00
06Xh000K<`000QX000`W001FB`0RU`00eIX00?XF003k4`00eiD002VI0000F4X000dX00026@006S80
06Ti06B/003TJ@00o`<00?<d0032a000088?000hA08000DN03`003I300214P2m``00nA`00>EX001U
[00006Tj000I<P000QT000hY001JB00bW000fX`00?`>003h7@00cjT000j?0000CTh000TR00036`00
9c/007LU09Vj003^B000o`000>UG001o/`0006la000O=P000aX000`V001FB`0VV000ei@00?/A003i
6P00dJD0016A0000Cdh000TS00036`00:C`007PR0:6l003_@`00o`000>MO001_[`0006/g000J<P00
0QT000lY001LAP0mX000gH400?d8003f:000bKX000261`00?4H200057P2O000jA@00QPP0b;/00?HY
003m2000gH8003^O0000FdL000hX00026P0073@006hc07jc003ZE@00o`000>]@0026]@00070`000N
=@000QX000dX001JB00iW`00gH800?d8003e:P00akh000233@00=T<000DM00068000ADX01h`00<n[
003i7000na400=FI000KU000055=00098`000a/002`n001m6P2h`P00lc@00?h5003PN000AJ<0001M
AP003bT0008J000M=@00L300RKH00>e<003o0000j5d006^^0000J3/001H_00026@005Bh006Hm06J/
003WH000o`000>e:002;]P00070`000M=0000QT0010Z001OA01>Y@00hW000?l2003`?@00X[`0001f
9`008cP000<J000=9`00FdP0?j400=mj003n1000lSH00:no0000NB4002Hj00036P0032H005Q903VO
003NOP00oPD00?<d002c`00007XP000W>P000aX000`V001IB@0kW`00gg/00?h5003b=`00[;l0001h
8`0093T000<J000=9`00G4L0AZ<00>5c003o0P00l3h009bk0000Lb/001lf00026P0042X0065205VY
003UI@00o`000>a<0022]00006`e000H<@000QT001D_001Y>@1f/@00je800?l0003WH000H:/0001S
@0004B/0008I000O=@00M2X0Wk`00?4k003o1000gg/003VO0000EdX000XU00036`00;Sl0084A0<Rl
003g8`00o1000=BL000?T00004A:008000HO03L004Q;01BB003FU`00o0d00?HW0035`P0007hH000Y
?0000aX000`W001LA`1<Y@00hf`00?l1003]B`00O[<0001Z>0005Bl0008I000J<P00L300U[T00?0n
003o1000gW`003BM0000ED/000TS00047000H2<0cj/00?XF003i7000bkD000233@00<40000<K000;
9@00FTP0AZ<00>=^003o0@00k4`007Vb0000J3/001<]00026@007cD007DX0:fo003c<@00o@T00=R?
000JU00004U<008000HO064004a=01fE003IS000oPL00?<e002T_@0007</000L<`000QT001H_001/
=@2<]`00kd400?l3003NO`00;I/0001AC@001b4000DN0013B@0BT@00ei@00?d:003d<000[;l0001d
:@007C@0008I000F;`00KCD0SkP00?0n003n1@00g8@002BH0000Cdh000HP00067`00C4d08IH00=^7
003n1@00lCd0096h0000KCD001H_00026@007SD007HV0;K1003e:P00o0h00=>O0004R`0003Q40004
70002R@005Y804jU003VI000o`000>MN001FZ00005a6000;9@000a`003E3006:003BX@00o0h00?DZ
002d`@0007DX000L=0000QT001Pa001a;`2T_@00lc800?d;003EV@002Hd0000jA@0011`000XU001K
A`1CY`00iel00?l0003UI`00Aj<0001GBP002B<000@M0012B@0FTP00fH`000[ooooo0Ol00001oooo
o`007_ooool00ol0003oooooooooo`07ooooo`0a00026P006C8006Hm04nV003NOP00o@/00?TL003C
W`008iL0001HB@003bT0008I000C;@00Gd@0>9h00=V>003k4P00na@00=RA000dW@0005e5000B;000
0QT0010Z001KB00/VP00eYL00?XG003l4000fXX003fP0000Gd@001@]00026@003bX005U802VI003E
V000nQL00?`@003JR`00>il0001OA0004bd0008I000@:P00FdL0<9`00=NB00020?/D003o0=NB000`
W00005]7000@:P000QT001@]001P@`11X@00g8D00?`=003i7000dZ8001bE0000E4`000`V00026P00
6S8006Pk05fZ003RL@00oPD00?DZ003:]`000XX00018C000228000<K000U>P00Lb/0Q[D00>YF003o
0000kd800:^n0000OAX0039100057@001Ql003U40022402n``00lSL00?l2003VH`00L:l0001]=@00
7SD000<J000;9@00Dd`06i@00=>P003i6@00o1000=V?000aW00005Y8000?:@000QT001P`001V?01K
Z@00hVl00?h4003d<000a/0000252@00?DH000HO00047@00<T4007hG0;?0003h7P00iV8006j_0000
JcH001`c00026P003BL005M:02ZJ003HTP00na400?TJ003BX`005I80001AC@002R@000<K000T>@00
M2T0T;P00>a=003o0000je4008Rf0000LRd0028g00036P002bD005=<01nF003EVP00na@00?XG003C
W`0069<0001AC@002R@000<K000U>P00MRL0UkX00>i8003o0000jET007Vb0000KC@001`d00026P00
3RP005Y803FM003KQ`00o@/00?LT003;]@0008T10010B0001Ql000DM000f@`00P`h0a/400?D]003n
1P00gg`004>R0000GDD0010Z00026@006S8006/f07B`003XFP00o`000>e:002@^00007</000Q=`00
0aX000`V001HBP0aW000fhP00?d;003f9P00bKT000261`00>TD000DN00067`00@4P008X00<ba003h
8000o0l00=NC000SU`0005=<000:90000a/002Tl001j7`2^_`00lST00?l3003RLP00CZD0001P@`00
42X0008I000K<`00KC<0P;<00>]A003o0000jEP007F`0000JSP001Pa00026@004bd006@o05fZ003U
IP00o`400>i5002D^@0007</000P=P000QX000hX001MAP16X`00h7H00?l4003b>000[;l0001i8P00
9SX000<J000<9P00F4T0=ih00=f0003n1P00lc400;W20000O1`002Tl00036`002bD005I;036L003L
Q000oPL00?@_002m``0007`K000Z?0000a/000/U001FBP0cW@00gH400?h6003c<P00]/40001j7P00
9c/000<J000<9P00FDT0?J000=mi003n1000lCT00:Jm0000MRL0028g00026P003bT005i40030052V
003TJ`00o`400>i6002<]`0006lb000J<P000QT001<]001V?@1][P00jEP00?l0003YFP00JJd0001U
?P004b`0008I000L=000LBh0U[T00?10003o0P00hGD0046Q0000FDP000/V00036`00:cd007hG0<K1
003f9`00o0d00=JF000FTP0004U<000680001Ah004=900f?003DW@00o1000?LS0038_@00080C000]
?P000a/000/U001IB013XP00hW800?l1003^AP00R;H0001/=@005c00008I000H<@00KS<0SKL00>m3
003o0P00h7H003bP0000EdX000XT00047000G2D0c;400?TJ003j6@00cJl000261`00<d8000@L000:
9000EdX0?Z000>5d003o0P00kTL008>d0000JSP001D^00026@0073@007</0:>l003b=P00oPL00=Z9
000QUP0004i>000780001Ql004M;01JB003GTP00o@X00?@`002^_`0007DW000N=@000QT001@^001Z
>023]000kTH00?l2003PN@00=9d0001DC000228000@M000nA`0;SP00eIX00?`=003e:`00]/40001g
9@007cH0008I000D;P00JSP0Q[D00>m3003o0`00gWh002bJ0000DDd000LQ00057P00Ad/06I@00=V=
003n1`00lSP009^j0000Kc4001P`00026@0073<007@Z0:bo003d;`00o@/00=FI000:SP0003a60004
7@002B<005Q:04FS003TJP00o`000>UI001OZP0005m4000<9`000a/003910027103@Y`00na400?HV
002n``0007PS000O=@000QT001H_001^<P2J^P00lSH00?d8003GT`003i00000nA`0011d000TS001H
B@1;Y000iV@00?l0003VH@00CjH0001JB0002R@000@L000mA`0?T000ei802_ooool1o`00007ooooo
000Nooooo`?o00001oooool0E`000QT001L`001S@017X`00g8@00?`>003j6@00eIT002^J0000FdP0
014[00026@004R`005a6032L003GU000nQH00?/A003JR`00?:00001P@`0052h0008I000?:@00F4T0
9IP00=BM003i6P00o0d00=b40015XP000691000F;`000QT000hX001GBP0RU`00dih00?TK003l3@00
g8D004>R0000HD8001D^00026@003bT005U902RI003EV000nQL00?`A003IS000>9h0001MA@004R`0
008I000B;000GTD0>Il00=Z;003l4000nQP00=BL000SU`0005M:000=:0000QT001P`001U?@1DY`00
h7L00?h7003f9P00c;8000R=0000CDh000TS00036`008SP0074_07fc003XG000o`400?4m002e`@00
080E000e@`0200057P3o000e@P00OaD0]<400?4l003o0@00j5d007Vb0000Kc40020f00036P002R@0
055=01BB003@YP00n1d00?`=003KR@00>9l0001LAP0042X0008I000F;`00I3l0DjL00>5e003n1P00
mB/00<Vk0000R0<004580007800011`002ho001l702Y_P00n2000>QL001g/@0006hc000N=@000QX0
00`V001EB`0SU`00eIP00?/D003j5P00e9d001bE0000Dd`000/U00036P008CL0078^08Je003[D`00
o`000>a<002B^00007DY000U>@000a/000XT001AC@0HT`00dj000?XG003k4`00eIT0022F0000Dd`0
00/U00036P008SP007<[08jg003/C@00o`000>YD0022]000070`000O=P000QX000`W001GBP0]V`00
fHd00?`=003h8000cJl000B;0000ADX000LP00047@00<T40080C0<74003c<P00oPD00>1f001<Y@00
0613000A:`000QT001Pa001Y>P1[[P00if000?l0003^A@00VKX0001e:00093T000<J000;9@00ED/0
:IT00=V>003l3@00mb400<bc0000R@4003m700067`001Ah003a600271@3:]P00mb@00?d<003IS@00
:YX0001EB`002bD000<K000V>P00Mb@0Y;d00?0n003o0P00hf`005JX0000HT40018/00026@006C40
06/g07Ja003YE`00o`000>]B001n/`0006dd000J<P000QT0014[001Q@P1EY`00hf`00?l2003`@000
W[/0001e:0008SP000<J000=9`00FTP0?J000=ml003n1@00lc<00;K10000Nad002Tl00036`002bD0
05I;02nK003KQP00o@P00?D]0033a00007hG000]?P000a/000XT001DC00ZV@00fXX00?d9003e:`00
aL<0001o5P00;Ch000<K000:9000E4`0;9X00=^7003m2000m2d00<330000OAX002Xm00036`002bD0
05M:03FM003MO`00oPH00?<d002__`0007PR000U>@000aX000dW001LAP18X`00hW400?l2003_@@00
UKT0001a;P007C@0008I000B;000I3l0I:`00>QM003o0000jU@007>`0000J3/001@^00026@006S80
06hb08bg003^A@00o`400>=_0019Y00005a7000=9`000aX002Lk001l7030``00mB/00?d:003HT000
7ID0001>CP001b0000DN002J000nA`06S000dJ<00?/C003h7`00b[L000233@00<40000<K000:9000
EdX0>il00>1h003o0`00kd40096h0000Kc4001Tb00026@005Rl006/g08>d003]B000o`400>9`0014
XP0005U9000;9@000a/005TW0<Zf003h7@00nQD00<nY0000R@4003M4000470002B<005E;03JN003O
NP00o`<00>m2002<]`0006dd000G<0000QT001Xb001`<02I^P00lC/00?h5003LP`00:IT0001AC@00
1b4000DN0012B@0?T000eIP00?d<003e;000^<80001h8`008CL0008I000B;000Ic/0NK800>e;003o
0@00hG<003bP0000ET/000TS00047000>TD01H`00=>P003l3`00mRL00<330000NR00028h00026@00
4R`006Lk07bc003]B000o`800>1h000dW@0005=<00088P001Ah0049901:A003GT`00o@T00?<c002T
_@00078]000J<P000QT001Tb001a;P2R_000lc<00?d9003GT`004I000011B0001Ad000PR001EB`0m
X000hW000?l0003ZD`00J:d0001Q@P003RP000<K000^?`00Q@X0cZd00?/D003g8P00aL<0001j7`00
8SL0008I000D;P00K3H0T;P00?4k003n1P00fHd001JB0000@dT000DM00088P00ET/0@Z800>AZ003o
0000j5`005RX0000G4L000/U00047000>DD028d00=FH00Sooooo0ol00001ooooo`007_ooool00ol0
003oooooooooo`07ooooo`3o00026@005Bl0065203nQ003JRP00na400?XE003GT`00<Yd0001MAP00
4R`0008I000@:P00FTP0:IT00=FJ003i6@00o0h00=b50015XP000691000F;`000QT000dX001FB`0M
U@00dZ<00?PN003m2`00gWh004fU0000I3l001P`00026@003BL005E;01^D003AY000n1h00?d;003N
O`00BjD0001T?`005c00008I000>:000ETX08IH00=>N003i6P00o0h00=^60010X@000613000D;@00
0QT0010Z001KA`0aW000f9400?/C003j5@00eYH002^J0000FDT000lY00026@005Rl006=004bU003N
O@00o@T00?LR003>[0003i00001@CP002R@000<J000P=P00KS80M;000>IQ003o0P00lSP00;k30000
PPl003U500067`001Ad00350001m6P2[_P00kd400?l0003YF000P[@0001b;@008cP000<K00098`00
Cdh03Hl00<j/003h8@00o@/00=b30011X@0005m4000B;0000QT001@]001R@P1:Y000gg/00?h8003f
9`00bkD000::0000AT/000LQ00047000:cd007TQ0:2l003g8`00jEL0086d0000L2l0024g00036P00
2bD005=<01bD003CWP00nQL00?/C003FU`0099L0001EB`0032H000<J000O=@00Kc40OK<00>UH003o
0000kTH009^k0000Mb@002Pk00036`002B<004m>016@003AY@00nA/00?`@003GT`009iT0001FB`00
32H000<J000P=P00L2l0Q;D00>]C003o0000k4h008bg0000LR`0028g00036P002bD005E;02JH003G
T`00o1000?TL003?Z@002hh0001:C0001b4000@L000_?`00OQT0]l400?8f003o0`00hW0005BW0000
HT4001<]00026@005Rl006Hl06:[003UIP00o`400?10002S_00007PS000W>`000a/000XT001CC00R
U`00ei@00?`@003h7P00cZd000B;0000@dT000HP00057@00=d@008@;0<Rl003f:000o@X00=^7000b
W00005Q:000<9P000aX002<h001e:02K^P00kd<00?l1003UIP00GjX0001T?`0052d0008I000G<000
J3X0KJh00>QL003o0000k4d008Ne0000Kc4001dd00026@0042X005m404bU003RLP00o`<00?4k002X
_P0007PS000U>P000aX000`V003c001HBP0eWP00gH800?h7003d;`00_l<0001n6000;3h000<K000:
9000Dd`0:9T00=Z<003m2P00mRP00<K00000PA800310000470002B<0055=02:G003HT000o@`00?HV
0037_P00088@000a@00011`000TS001BC@0TV000fHd00?d;003f:@00a/4000205000;Sl000<K000:
9000ED`0;Y/00=b5003n1`00m3000;W20000Nad002Pk00036P0032H005Y8042Q003PM`00o`<00?4l
002O^`0007@Z000O=P000QX0010Z001Q@P1KZ@00iV<00?l0003/C`00O;80001Z>0005Rl0008I000H
<000K3H0P[@00>e;003o0000i6T005:V0000GTD000hX00036P0093T007TQ0;K1003d<000o@P00=Z:
000TV000055=00088@0011d003Y5002:003?Z@00nQH00?TK003</@0008H8000d@P0011`000TS001E
B`0cW@00gWd00?h4003a?000VkX0001b;P0073<0008I000D;P00JCX0N[800>a=003o0000i6X004bU
0000G4L000`V00036`00ERT0b;`00?LQ003k4P00dJ<000B;0000>dH000@M00088P00Ddd0;Y/00=f0
003n1000l3d009Ji0000Kc4001Tb00026@00630006hc08nh003`@000o`<00=im000`W00005=<0008
8P0011d003e700V=003CWP00o0l00?HW0032a00007/N000T>@000QX0014[001U?P1`[`00je400?l0
003SK@00AJ80001HB@002R@000@L000f@`00R@00d:H00?/B003g8`00a/40001l6`009CT0008J000A
:`00ICh0Lk000>a>003o0@00hW8003bP0000ED/000TS00047@00?TL038h00=FI003m2`00m2h00:jo
0000M2T001`d00026@005c0006lb09Vj003b>000oPL00=V=000HT`0004E:00057P00224005=<03FM
003PMP00o`400>a>001a[`0006=0000?:@000aX002Xm0022403</`00nQP00?PN0038_@0007dJ000T
>@000QX001</001Y>@27]@00l4000?h5003KQ`007ID00017B`001Ah000PQ001DC00jW`00hW000?l0
003ZEP00H:/0001NA@0032H000<K000e@P02RP00dih000[ooooo0Ol00001ooooo`007_ooool00ol0
003oooooooooo`07ooooo`3o00026@004bd005i403NN003HT000na@00?/B003IS@00>Yl0001OA000
52d0008I000?:@00EdX08YL00=>P003i7000o@/00=io001=Y@0006Dn000H<@000QT000`V001DC00F
TP00d:P00?LR003m2@00h7P005JX0000Ic`001Xb00026P0032H0059=01BB003?ZP00mb800?d8003P
N@00E:L0001V?@006C40008J000<9`00E4`06Y@00=6T003h7P00o@/00=f10018X`000691000E;`00
0QT000lY001IB@0YV@00eYL00?XF003k4P00f90003:L0000G4L0010Z00026@0052d0065304>R003L
P`00o@`00?PN003@YP005Y80001BC@002bD000<J000M=000K3H0Jjh00>EW003o0`00lc<00<G20000
Q@X003i70006800011d002hn001j7`2Q_000kTH00?l0003[DP00RkL0001d:@009SX000<K00088P00
BTd01h`00<ba003g9@00o@P00=im0019Y0000652000D;@000QT0018/001OA012XP00gH400?d:003g
8`00cJl000R=0000Bdd000PR00036`00:3/007HV09Ji003f9P00je4008Zf0000Lb/002<h00036`00
2R@0055=01FB003AX`00nAX00?`@003HT@00:iX0001GBP003BL0008J000L=000K3D0Lk000>MN003o
0000kd400:Fm0000NR0002/m00047000228004Y=00Z>003?Z`00n1h00?`>003IS@00;i/0001HB@00
3BL0008J000M=000KS<0Nk800>UH003o0000kDT009Fi0000MBP002@i00036`002R@005=<01jF003E
V@00na<00?XI003AX`004Y40001>CP00228000<L000[?@00Nah0[Kl00?4k003o0P00i6X005fZ0000
ICh001D^00026@0052d006@o05ZY003TJ`00o`800?4k002]_`0007XO000Z?0000a/000TS001AC@0K
U000eIX00?/C003i6P00d:L000^>0000B4/000LQ00047@00=480088@0<K1003e;000oPL00=f1000j
W`0005Y8000=9`000QX0020f001b;02A^000kTP00?l0003WH000J:d0001W?0005Rl0008I000E;P00
ISd0I:`00>IR003o0000kTL0096h0000LRd001lf00026P003RP005a604BR003PN000oP@00?8f002b
`00007XO000X>`000a/000/U003G001FB`0^V`00fhP00?d9003e:P00a/8000204`00<40000@L0009
8`00DDd089H00=RB003l3@00mb@00<Vj0000Q0`003A200047000228004m>01^D003FU@00o0h00?LR
0039^00008@;000e@P0011`000PR001@CP0MU@00ei<00?`=003g9@00b;`000223`00<D4000@L0009
8`00DTd09YP00=Z;003m2P00mB/00<?40000OQP002/m00036`002bD005M:03RN003NO@00oPD00?8g
002Y_P0007HV000R>0000QX000lY001OA01CY`00i6T00?l1003]BP00QKD0001]=@006340008I000F
;`00JCT0NK800>]@003o0000iV<005ZY0000HD8000lZ00026P008SL007LU0:bo003c=000oPH00=b4
000[VP0005=<00098P0011`003I300271@3=[`00nAX00?XH003>[00008P2000hA00011d000PR001B
C@0[VP00g8<00?h6003b=`00YKd0001d:P007SD0008I000B;000ISd0LJl00>]C003o0000iVD005FW
0000GTD000dX00036P00DbX0a/400?LU003l3`00did000^>0000@4P000DN00078@00D4h09YP00=b6
003n1P00lSP00:2l0000LRd001/c00026@005Rl006/g08Je003^A@00o`800>1g000hWP0005E;0009
8`0011`003U500:;003AY000na400?LS0036`00007dJ000W>P000aX000lY001R@@1W[@00jUH00?l0
003UI`00CJD0001KA`002bD000<K000b@@00QPH0cZ`00?XE003h7`00b;`0001o5P00:3/000<J000?
:@00Hd40JZh00>YC003o0000hf`004BR0000F4X000XT00047000>DD01H`00=>O003l3P00mBX00;S2
0000MbD001le00026@005Bh006`e08ng003`?@00oPD00=^7000OUP0004Y<00067`001b00055=02fK
003ON`00o`800>e8001j/P0006Hm000A:`000QX002Lk001o5@39^0000P3i6`006P3:^000080E000W
>`000QX0014[001W?01m/`00kTD00?l3003MP@0099P0001<C@001Ql000LP001BC@0cW@00h7H00?l1
003[D000JJd0001Q@P003BL000<K000a@000R0<0dJ@02_ooool1o`00007ooooo000Nooooo`03o`00
0?oooooooooo00Oooooo0?l0008I000B;000G4H0;i/00=JF003j5`00o0l00=^70012XP000691000F
;`000QT000dW001EB`0JU000dJH00?PP003m2@00ggT005FW0000Ic`001Xb00026P002bD0055=00n@
003=[P00mRH00?h7003QLP00GZX0001Y>@0073@000<J000:9@00D4h03Hl00<f`003f9P00oPL00>5c
001LZP0006Tj000K<`000QX000/U001BC@0CT@00cjX00?LR003m2@00gg/0052V0000ICh001L`0002
6@003BP005M:02:G003DW@00nAT00?`?003JRP00>Yl0001NA@004R`0008I000B;000GTD0>il00=^9
003l3P00nA/00=:P000MU@0005A<000<9P000QX001/c001Y>@1RZ`00hfd00?h4003d;`00b;d00027
1000@TT000LQ00047000:Sd007PT09Nj003]C000o`000>a=002E^@0007LU000Y?00011`000LQ0015
BP00RP00b[L00?HY003n1`00h7L0056V0000I3l001D_00026@0042X005e603ZO003KQ`00o@`00?PO
003?ZP003i00001?CP002B<000<K000U>@00M2X0SKL00?DX003/C000TkT0001f9`009SX000<K0009
8`00CTh03Xl00<nY003h7P00o0h00=Z;000cW@0005Y8000>:0000QT001Xb001Z>01[[P00iV<00?l1
003a?000[kl0001l6`00;Sl000@L00078@00ATX018/00<ba003g8P00o@/00=^7000fWP0005Y8000>
:0000QT001/c001[=P1b/000j5h00?l0003_A000W[/0001g90009c/000<K00098`00D4d05i<00=>O
003j5P00nQD00=>N000HT`00055=00098`000a/002Pk001h8P2T_@00l4000?l1003VI000IJ`0001W
>`005c00008I000B;000HD80DJH00>9a003o0`00lSH00;K10000OAX002dn00047000228004m>01BA
003CX000nQH00?XG003BXP004I40001=CP00224000@L000`@000OaD0`<<00?@`003n1P00gg/004:Q
0000G4H000hY00026P007CD0070`08Rf003/C@00o`000>QK001a[`0006Ti000H<0000QT001<]001S
@01LZ@00iFP00?l1003_@P00V[X0001d:@008SL000<J000=9`00FTP0?:000=im003n1P00lc400;_2
0000OAX002`m00036`002R@00>D005=<02JH003IS@00o@/00?HV0038_00008<>000c@P0011`000PR
001?CP0IU000eYL00?`?003h8000bkD000261`00>4@000@M00078@00C4d059800=BK003k4@00n1l0
0<bc0000Q`D003U400047@001b4004a=01JB003EV@00o1000?PQ003:]P0008D9000e@P0011d000PR
001@CP0OUP00f9400?d<003f9`00a/0000204`00;Sl000<K000:9000ED/0<9`00=b3003n1P00lc<0
0;;00000NB4002Di00036P003BP005e604^T003SK`00o`400>i4002>]`0006la000J<P000QT001@]
001W?01`[`00jUD00?l0003XGP00Hj/0001S@0004B/0008I000O=P00M2T0Xk`00?4i003n1@00gWh0
03>M0000ED/000TS00047000<T4008@;0<^d003h7@00na@00=2V0003R`0003a600057@001b40051>
02BH003JR@00oPP00?<b002^_`0007LU000Q=`000QX0014[001T?`1X[@00jEP00?l0003WG`00GJX0
001P@`003bT000<J001@;030a000mBT00?`=003FV0004I400014BP001Ah000LP001>CP0OUP00fX/0
0?h8003c<`00ZKh0001d:@007SD0008I000D;@00JCX0OK<00>e:003o0@00hW40042Q0000EdX000XT
00047000=D<008P30<nY003k5000n1l00<Rk0000P1@002Xl00036P003RP0061305nZ003XF`00o`00
0>IQ001EZ00005e6000<9`000a/002ho0024303</@00nQT00?TK003:]P00084A000[?@000aX000hX
001P@`1QZ`00jET00?l0003UI`00C:D0001JB0002bD000@L000e@`00R@00dJ@00?/A003f9P00`/@0
001i80008CL0008I000C;@00JST0Q[D00>m2003o1000gH8002JH0000Cdh000HP00067`00CTh09YP0
0=f1003o0`00kd<008>d0000J3X0018/00026P0093T007dJ0<Nn003h7`00nQL00<bb0000PPl002/m
00036P003bT006@o07B`003]BP00o`800=mk000/VP00051>008000HP00`004m>02^J003OO000o`80
0>e;001b/00006=0000?:@000aX002ho00252@3?ZP0:ooooo`7o00000Oooool001kooooo00?o0000
ooooooooool01oooool0o`000QT0010Z001JB00XV@00e9`00?TJ003l3@00gH4004ZT0000I3l001Pa
00026@0032H005=<01BA003>Z`00mb@00?h7003QL`00GZX0001Y>@0073@000<J000:9000Cdh02Hd0
0<^d003e:P00oPD00>=]001W[@0006`f000N=@000aX000TT001>CP07S000bkD00?DZ003n1@00hfd0
06F/0000JcL001dd00036P002R@0051>00b?003=/000mRH00?h7003QM@00F:P0001W?0006C80008J
000<9P00E4`06i@00=:S003i7@00o0`00=b40012XP000613000D;@000QT0010[001LA`0dW@00fHh0
0?/A003j5`00e9/002BG0000EdX000dX00026@006C4006Ll05VY003QL`00oPH00?DZ003:]`000HX0
0017B`00224000<K000W>`00MBP0S[L00>]A003o0000kTP009jk0000NB4002`n000470001b000458
00271@38_@00m2d00?h5003RL@00FJT0001V?@005c00008I000?:@00FTP0<Yd00=V=003l3`00nA/0
0=6T000ETP00055=000:90000aX0028g001a;P23]000mB/00>i7002M^`0007PS000Y?0000a`000PR
0019C008S@00cJl00?LR003m2`00g8D003ZO0000G4H0010Z00026@00634006Lk06:[003TJ@00o`80
0?8h002h`P0007lF000b@@0011d000HP0011B000R@40b[H00?HV003m2@00gH4003jP0000GDH0010Z
00026@006C4006Ti06V]003VH`00o`400?0o002X_P0007XO000[?@000a`000PR001>CP0AT000dJ@0
0?TI003k4P00eIP001nF0000Dd`000XT00036`009CT007HV09Zj003^A@00o`000>MO001^[`0006Xh
000I<@000QT0014[001OA019Y000h7L00?h5003c<@00`<<000205@00<D0000@L00078@00BT`03Hl0
0=6V003i6@00na<00=BL000HT`00051>00098P000a`002`n001m6P2g`@00lcD00?h4003QM@00BZ@0
001OA00042X0008I000K<`00KC@0O[<00>]B003o0000jUD007Zb0000K3H001Xb00026@004B/00652
05>W003SK@00o`800?0m002T_@0007LU000U>@000aX000`V001HBP0dW@00g8<00?h8003e;@00aL@0
001o5@00;cl000@L00098`00O@00DDd07iH00=NC003l3P00mb800<Zg0000Q@P003M400047@001b40
04]=01>A003DW@00na800?TM003=[`0008T1000lAP001Ah000HP0017B`0=S`00dZ400?/D003i6`00
cZd0002:0000?DH000DN00068000Ad/03i000=>O003k4`00n1d00<ba0000Q`@003U400057@001b40
04e>01RC003FU`00o0h00?LS0039^P0008<>000b@@0011`000TS001CC00YV@00fhT00?d8003d;P00
_<80001k7@00:3/000<J000<9P00FTP0@Z800>5d003o0P00l3l009Rj0000LRd001dd00026@004R`0
06@o06N]003XF`00o`000>UH001/[P0006Dm000C;0000QT001`d001b;@2I^P00l3h00?l3003PN@00
>il0001GBP002RD000<K000_?`00PQ00bKX00?PQ003k4@00dj0000Z>0000@4P000DN00078000CTh0
7ID00=R?003m2P00m2h00;S10000NB4002@i00026P003bT0065205nZ003WGP00o`000>UJ001V[000
06=0000@:P000QX004d]0;O1003d;P00o@X00=NB000HT`0004U<008000HO07@004U<01RC003HT@00
o@X00?@_002c`00007LU000P=`000QT0018/001V?@1d/000jdl00?l0003SK000B:<0001JB0002bD0
00<K000a@@00Q@T0cJl00?XH003i7000bkD000223`00;Ch000<K000=9`00GDD0EZP00>MQ003o0000
j5`005jZ0000Gd@000hX00036P00:cd0084A0<Zg003i7000nQP00<ba0000Q0`002lo00036`0032L0
05i505VY003WGP00o`000>MQ001DY`0005a6000<9P000a/0039100271P3?ZP00na@00?LR0036`@00
07`L000T>@000QX0018/001W?01m/`00kTL00?l2003OO000;Y/0001AC@001b0000HO001:C00OUP00
fhL00?h5003`?P00S;L0001[=`0052d0008I000R=`00NQl0aL<00?LS003k5000cZ`000252P00;Sl0
00<K000>:000HT40Jjh00>]@003o0@00hGH003>M0000DTd000LQ00067`00C4d099L00=f1003o0`00
kTH007^b0000ISd0010Z00036P00:Sd008<>0<f`00[ooooo0Ol00001ooooo`007_ooool00ol0003o
ooooooooo`07ooooo`1700026@003bT005M:026F003BX@00n1h00?d:003OO000DjL0001W?0006S80
008J000;9@00DDd03Hl00<ba003f:000oPD00>=^001V[00006`f000O=P000aX000TS001;C@03R`00
bKT00?@^003o0`00iFL006n_0000KS80024g00036`002B8004U<006:0039^`00m2l00?l3003UJ000
KZl0001]<`0083H000<J00098`00CDh01X`00<^e003e:P00oPD00>9_001QZ`0006Xi000L<`000QX0
00/U001BC@0DTP00d:P00?PP003m2P00gWh004ZT0000Hd0001D_00026@003bT005U802bJ003GU000
0P3k5000dP3FU@00:iX0001IB@003bT0008I000G<000I3l0DJH00>1h003n1`00mRH00<bb0007S@00
04]=00098P000a/002@i001c;025]@00jUH00?l0003_@`00Z;h0001l7000<40000@M00067`00?DH0
08D:0<K2003c<P00o`<00>A[001RZ`0006Pj000I<P000QT000hX001HB@0[VP00ei800?/B003j6000
dih001bE0000Dd`000/U00036P007cH006la07Zb003d;P00kd800:Jm0000Nah002dn000470001b40
04E:006:003;]000mRH00?d9003MP000@Z80001NA0004B/0008I000F;`00ICh0FJT00>=_003o1000
lc<00<;40000PA4003I300057P001Ql003e600261`38_000mBX00?h7003ON`00AZ<0001OA0004B/0
008I000G<000Ic`0H:/00>AY003o0P00lCX00;;00000OA/002ho000470001b4004U<00Z>003?ZP00
nAd00?`?003GTP009YP0001EB`002bD000<J000R>000Lb/0TKP00>e:003o0000jET007Na0000K3D0
01/c00026@003bT005e6046Q003NO@00oPL00?D]0036`P00088@000e@P0011d000LP0015BP07S000
cZ/00?TM003k4@00eYH001nF0000DTd000TS00036`00:C`007XO0:fo003a>P00o`<00>9_001BY`00
0652000A:`000QT001Ta001[=`1f/@00jEP00?l0003[D000Pk@0001^<P0073<0008I000@:P00Gd@0
Bj@00>5c003o0`00lST00:fo0000NB0002Lk00036`002bD005E;02fK003JR@00o@X00?HY0037_`00
088@000b@@0011`000PR001?CP0HT`00eIT00?`A003h7`00c;4000280P00>dH000DN00068000AT/0
38l00=:S003j5@00nAT00<nZ0004R`00041800057`001Ql0049900N=003@Y`00nQL00?XH003@Z000
1X`00011B08000HO04<004=900V=003AY@00nQH00?TJ003>Z`000HX0000mA`001Ah000HP0018C00A
T@00e9d00?/A003h7`00bkD000252@00=D<000@L00088P00DDd08IL00=V>003m2`00mBX00<G40000
OQP002/m00036`002bD005Q903^O003ONP00o`@00?4k002Q_00007@Y000O=P000QT0010Z001R@@1O
ZP00if000?l0003[D`00M;00001X>`0052h0008I000J<P00Kc40T;P00>m3003o0P00hG<004>R0000
FTP000/V00036`00:cd007lE0<No003g9@00o0l00=FJ000@T00004E:008000HO090004U<01JB003F
U@00o@`00?DZ0032a00007`L000V>P000aX000hX001OA01GZ000iV<00?l0003ZE000KZl0001U?P00
4R`0008I001;;P2]_`00lc800?h8003IS0007iH0001>CP001b0000DN0014BP0BT@00eYL00?d<003e
:P00_<<0001j80008cP0008J000@:P00I3l0Jjh00>YE003o0000iFH0052V0000G4H000`V00036`00
;Sl008<>0<^d003i6`00nQP00<f`0000Q@X0031000036`002bH005]704jU003UI`00o`000>YF001V
[0000691000?:@000aX002Pk001o5`38_000n2000?XE003?Z`0008H6000b@@000a/000/V001KA`1A
YP00iV@00?l0003XF`00GJX0001OA0003BL000<K000^?`00Q0/0cK000?XG003h7P00b;/0001o5`00
9c/0008J000@:P00ICh0M;000>a<003o0@00h7H003FM0000Dd`000PQ00057P00ADX069<00=V=003n
1`00lCT009Fi0000KC@001H_00026@007cH007PT0;g3003f9P00na400=2W0000Q`@0035100036`00
3BL005m406>[003ZE@00o`000>9`000kW`0005A<00088P001Ah004M;01fE003KQ`00oPD00>m10024
]@0006Pj000B:`000QX002Lk0020503;]@0:ooooo`7o00000Oooool001kooooo00?o0000oooooooo
ool01oooool0LP000QT000dX001EB`0JU000d:L00?LQ003m2000h7H005^Y0000JCT001`d00036P00
2R@004m>00N<003:]P00mB`00?l4003UJ000Kjl0001^<P008CL000<K00088P00AT/008P20<No003c
<P00o`800>IQ001h/@00074_000T>@000a/000PQ0014BP00Q`@0a/000?<c003o0P00iV8007Ja0000
L30002<h00036`00228004Q;002:0039^P00m2h00?l4003TJP00JJd0001/=@007SD000<J000:9000
D4h03Hl00<f^003g9000oPP00>1i001BY`0006Dn000G<0000QT000hX001GBP0UV000eIX00?XG003k
4@00f8l003:M0000FdL0010Z00026@005Bh0069104VT003NOP00o@X00?LR003>[0003Hl0001?CP00
2B<000<J000Q=`00L300O;800>QL003o0@00l3h00;700000OQL003=100057P001Al003U400224030
``00lSH00?l2003UIP00JZh0001[=`0073<0008J000<9`00ET/099L00=FH0080naD00280eIT002>G
0000ED/000`V00026P007C@006`e076`003c<@00l3d00;300000OAX0031000047@001R0004180028
0`39^P00mBX00?h7003ONP00BZ@0001Q@P004b`0008I000D;P00Hd00DJH00>5d003n1@00m2l00<K1
0000Q0`003U50P001Ah0S@00>D@008@<0<K1003d;`00oPD00>1f001>Y@000652000C;0000QT001D^
001T?`1HZ000hfh00?l3003b=@00^l80001o5P00<D0000@M00078000ADX018/00<f_003h8000o0d0
0=V<000^V`0005M:000<9`000aX0020f001a;P28]P00k4l00?l0003ZE000P;<0001_<P007C@0008J
000>:000FTP0>Il00=b2003m2@00mRT00<Rl0000Q@X003Q400057P001Ql00458006:003</@00n200
0?`>003HT0009YP0001DC0002RD000<K000V>P00N2@0Y;d00?0n003o0P00i6X005ZY0000Hd0001<]
00026@005c0006Pj06f^003XG@00o`000>e;002<]`00074_000N=@000QX000hY001LAP13XP00h7T0
0?h5003c=000]l40001l7000:cd000<K000:9000Dd`09IP00=V?003m3000mbD00<Vi0000Q@X003I3
00047@001b4004]=01:A003CW`00na<00?TK003>[0000X/0000oB0001Ah000HO0012B@06S000d:P0
0?XI003j5P00dJ@000^>0000ADX000HO00057P00?TL00HX00<j/003i6`00na@00=:R000<S`0004E:
00067`001Ah003i700>;003?ZP00nAT00?XF003AYP001hd00011B@0200067`2C0014BP0;SP00dZ80
0?/D003i7000cJl000280`00>DD000@M00078@00CTh06Y@00=ND003l3@00mRH00<No0000PA<002ho
00036`002R@005I;03>M003MP000oPD00?8f002Z_P0007LU000R=`000QX000lY001P@`1FZ000iFH0
0?l0003/C@00OK<0001Z>0005Rl0008I000H<@00KC@0QkD00>i8003o0@00hfd004^T0000G4L000dW
00036P00:3/007dJ0<C4003f:@00o@`00=JE000GT`0004U<000680001Ql004A:00n@003DV`00o0h0
0?HU0036`@0007hG000Y?0000aX000dW001MAP1?Y@00i6T00?l0003/C`00Mk40001X>`004bd0008I
0018;`2T_@00lSH00?h6003KQP009YP0001@CP001b4000DN0010B00;SP00e9d00?`?003f9P00aL@0
001l70009SX000<J000?:@00HD80HZ/00>UJ003o0000if4005RX0000GTD000dW00036P00:cd0080C
0<Vj003h7`00nQD00<nZ0000Q`@003A2000470002R@005U904JS003SK000o`000>]A001_[`0006@o
000@:P000QX002Di001l6`36`P00mb<00?/B003AYP0008T0000f@`0011`000XT001IB@19Y000i6T0
0?l0003ZEP00IJ`0001Q@P003RP000<J000[?@00PA40bkD00080nAX003H0b[H000214P00:Sd000<J
000?:@00HT40Jjh00>]B003o0000hW0003fP0000ED/000PR00057@00@DP04I400=NC003m2@00lcD0
09nk0000L30001P`00026@007C@007DX0;C1003e:`00o0h00=:Q0001RP0003E200036`0032H005e6
05ZY003XFP00o`000>AZ0013XP0005I:00098`001Ad0049901JB003IS@00oPH00?4l002=]`0006Xg
000C;@000QX002@i001n6@39^P0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0HP000QT000`V001CC00CT@00cZ`00?HU003n1P00hW0006>/0000JcH001le00036P002B<004Y<
006:0038_000m3400?l2003VH`00N;40001a;`0093T000<K00078@00@TT008H80<G4003b=`00o`40
0>QL0021]00007<[000W>P0011`000LQ0010B000Q@X0`l@00?8h003o0@00j5d007nc0000LR`002Dj
00036`001b4004=900271@36`000lc800?l2003VI000L[00001^<P008CL000<K00098`00CDh01hd0
0<^c003f:000oPH00>5c001JZ@0006Lk000I<P000QX000`W001EB`0NU@00dil00?TJ003l3P00fXT0
03ZO0000GTD0018[00026@004bd00613046Q003LQ000o@`00?PN003@Y`005980001AC@002RD000<J
000O=P00KS<0Lk000>MQ003o0@00lCT00;_20000PA8003M30P001Ah0IP00=D80080E0;K1003a>`00
o`400>MP001c/00006dd000N=@000aX000/U001DC00MU@00dih00?XH003k4P00ei<002ZJ0000F4X0
00dX00026P006c8006Xh06V]003b=000lSP00;W20000P1D003A200057@001Ql003a600252@37_`00
m2h00?h5003QM000DZL0001S@00052h0008I000B;000H4<0BJ@00=mj003n1`00mBX00<Rk0000QPH0
03i700067`001Ad003E200214P31a000lc<00?l4003RL000EZP0001T?`0052h0008I000C;@00HT40
D:H00>5d003n1@00m3400<C40000PQ4003E200057@001Ql0041800290@3;]@00mb@00?d;003KQ`00
=Id0001JB0003BP0008J000M=000KS80Ok<00>YE003o0000k4l008Vf0000LBh0020f00026P003BL0
05Q903:L003KR000o@/00?LU003:]`0008L5000lAP8000DN0?l003a60027103:]P00mb@00?d;003J
R`00;I/0001FBP002bH000<J000S>000MBP0V[X00>m3003o0@00iV@006>[0000ISd001D^00026@00
5Bh006Hm06B/003VH`00o`000>i6002E^@0007<[000Q=`000QX000dW001JB00kW`00gWh00?h6003d
<000`<<0001n5`00;Sl000@L00098`00DDd07YH00=ND003l3`00n2400<^d0000Q`D003Y500057P00
1R0004I;00^>003AY000nQH00?XH003@YP002Hd00014BP001Ql000DN000mA`00R@00cJh00?TL003k
4`00dih0016@0000BD`000LP00057@00>TD008L40<bb003h7P00na800=BL000CT@0004Y<00078000
1Ad003Y500280P3=/000nA`00?/C003CX0003Hl00016B`001Ql000DN000oB005S000d:P00?XG003j
6000cjX000::0000?DL000DN00078000BT`059800=FJ003l3`00mb800<Vi0000P`d0039100047000
2B<005=<02bJ003LQP00oPL00?<a002d`@0007TQ000U>@000aX000hX001MA@1>Y@00i6/00?l1003]
B000Q[D0001]=0006340008I000F;`00JSP0O[<00>a=003o0000iFP005>W0000GTD000hX00036P00
9CX007XO0;_2003e;@00o@X00=R?000MU@0004i>000780001Ah0041800V=003CX000na400?LR0038
_000084B000]?P000a/000`V001JB017X`00hfh00?l1003]BP00P;@0001Z>0005Bh0008I0016<@2K
^P00lC/00?h5003MP@00;I/0001BC@00228000@M000lAP05S000dZ800?/A003g8P00akh0001o5`00
:C`000<J000>:000Gd@0FZT00>MP003o0000j5/0066[0000HD8000hY00036P00:3/007hH0<No003g
8P00na800=6U0001RP0003Q4000470002B<005M:03jP003RLP00o`400>a<001h/@0006Ll000B;000
0QX0028h001j8030``00mRL00?`?003CX0001H`0000jA@0011`000TS001GBP11X@00hfl00?l0003[
D@00KZl0001S@0003bX000<J000X>`00OaH0bK/00?PN003j5`00cK0000243000;Ch000<K000=:000
H4<0Hj/00>UG003o0000i6/004BR0000EdX000TS00047@00?4H002L02hh00=FH003m2`00m3000:Rn
0000LRd001Xb00026@006S8007</0:Zn003d;`00o@`00=BL0007S00003U4000470002RD005]705:W
003WH000o`000>IU001;Y00005U90009900011d003i700n@003GT`00oPP00?8g002F^@0006dd000E
;P000QT0028g001k7@36`0002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo
0840008J000;9@00DDd03Hl00<bb003e:@00oPD00>A[001/[P0006hc000Q=`000a/000PR0015BP00
Q`@0a/400?8e003o0@00j5d0082d0000Lb/002Lk000470001b0003i700233@2l``00lC`00?l0003Y
E`00R[H0001f9`00:S`000@L00068000?4H0088?0;[2003a?000o`000>UG0028]P0007DX000X>`00
11`000LP000oA`00Q@X0a<@00?8g003o0@00iel007^b0000LBl002<h00036`00228004Q<006:0039
^@00mB`00?h4003SK@00Hj/0001Z>00073<0008J000;9P00Dd`05i<00=6U003h7P00o@`00=b40012
X@000613000C;@000QT0014[001MA@0iW`00fXT00?`>003i6`00dZ4001ZD0000Dd`000/V00026P00
7C@006/f06^^003UI`00o`800?<e0034a00008<=000kA@001Ql000@M000a@000OAX0[Kl00?10003o
0000j5/007bb0000L300020g00036P002R@0055=01JB003AX`00nA/00?`?003IS@00<I`0001JB000
3bT0008I000H<@00J3/0H:/00?8g003c=000`/@000224000=d@00P001Ah0o`00>4@008<>0<G4003c
<P00o`@00>=_001JZ@0006Dm000F;`000QT0014[001NA@11X@00gH000?d9003f9P00b[H000290000
@TT000HP00047@00<D0007lG0;S1003b=`00o`800>A[001NZP0006Hm000F;`000QT0014[001OA018
X`00ggX00?h6003e;@00akl000242`00>D@000DN00067`00?4H008H70<Vj003f:000o@P00=f1000m
X00005a7000?:@000QT001/c001/=@1f/@00jEX00?l0003]B@00T[P0001c:P008SP000<J000;9P00
ET/0:YX00=V>003l3@00n2400<bb0000RP00045800067`001Ah003Q400252P38^`00mRP00?d9003L
Q@00=Id0001IB@003BL000<J000Q=`00Lb`0TKP00>e8003o0000iel006^^0000J3X001L`00026@00
4bd006@o05bY003UJ000o`400>m1002N^`0007HW000S>0000aX000`V001HBP0dW@00g8@00?d8003e
:`00a/8000214P00<D0000@L00088P00Cdh069<00=FJ003k4@00n1d00<f_0000RP0003i700057P00
1Ql0049900F<003?ZP00nAX00?/E003BX@003i000018C0001b0000DM000iA@00Q`D0bk<00?PP003l
4000eIT001NC0000CTh000LQ00047@00=T<008D90<Zg003g8P00o0l00=JG000IU00004m>00078@00
11d003I30026203;]@00n2000?`@003DV`005980001;C@001b0000DN000kAP00R@00cZd00?TJ003j
5@00dJ@000R=0000@TT000DO00067`00ADX03Hl00=>O003k4P00n1h00<^d0000QPP003E300047000
2280055=02FH003JR`00o@T00?@]002m``0007`L000X>`000aX000`W001KA`16X`00hW400?l2003_
@`00SkL0001_<@006S80008I000D;P00J3/0MK400>]B003o0000iV8005^Y0000HD<000lY00026P00
8cP007PS0;;0003c<@00oPP00=Z9000TV000051=00088@001Ad003a600>;003AYP00na@00?PN003:
]P0008<=000`@0000a/000XU001HB@0oX@00hG@00?l2003^A@00RKH0001/=@005c00008I0014<P2A
^000l4000?l3003ON`00=9d0001EB`002B<000@L000hA000R@00d:P00?/D0000L03h7`00bKT00021
4P00;3h000<K000<9`00GDH0DZH00>EU003o0000jUH006V]0000Hd00010Z00026P009CT007/M0<C4
003f9P00o0l00=>O0007S00003a600047@002B8005A<03JN003PM`00o`800>i70020]00006Ti000C
;@000QT0020f001g902g`@00mB/00?`=003EVP002hh0000nA`0011d000PR001EB`0iW`00hG@00?l1
003]C000M[40001V?@004B/0008J000U>@00OA/0a/000?LQ003k5000cj/000261`00<D0000<K000<
9P00GTD0FZT00>QL003o0000iFD004bU0000FTP000XT00047000>4@01H`00=>N003l3@00mB`00;70
0000MBT001`d00026@006340070_0:6l003c<`00o@X00=JF000=S`0003e600047@002R@005Q904ZT
003UI@00o`000>MO001CY`0005]7000:9@0011`003Y500V=003EV000o@X00?<c002O_00006la000G
<0000QT001lf001i8P34a00:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0
o`000aX000XT001=CP04R`00bKX00?@`003o0`00iV<007Vb0000LRh002Hj000470001b4003m70024
3@2m``00lC`00?l1003ZEP00S[L0001g9@00;3d000@M00067`00>4@0080E0:no003_@`00o`000>a?
002H^P0007TQ000_?`001Ad000HO000f@`00OaL0[;l00>m4003o0000k50009Ji0000NB8002dn0004
7@001Ql003U400214`2f`@00lCh00?l1003ZE`00R;H0001e:@00:3/000@L00078@00@TT008L60<K1
003d<`00o`<00>IV001`[`0006hd000O=P000aX000XT001@CP0>S`00cZd00?LS003n2@00gg`004fU
0000Hd0001H_00026@003bX005Y802nK003HTP00na<00?/G003EV@009IP0001GB`003RP0008J000I
<P00J3/0GZX00>=_003o1@00mBh00<Rm0000Q`D0045800078@0011`002dn001j8@2P_000kTL00?l0
003[E000RKH0001c:`009CT000<K00098`00CTh03Hl00<j/003h8@00o@`00=b5000mX00005e5000A
:`000QT001H_001T?`1DY`00l3d00?D]0037_P0008H8000mA`001R0000DM000c@@00OaH0]l400?8i
003o0P00iFL006N]0000JCX001Tb00026@003bT005]803JN003KR000o@`00?PQ003=[P001hd00019
C000228000@L000]?P00Nah0Z[h00?0o003o0@00iV<006^^0000JST001Tb00026@0042X005a703fP
003MPP00oPT00?LW003:^00008P3000oA`001R0000DN000f@`00P`l0a/800?D^003n1P00h7T004RT
0000Gd@0014[00026@00634006Tj06Z]003WHP00o`400>m3002P_00007LT000W>P000a/000XT001C
C@0PUP00eYH00?`A003i7000cjX000V>0000Ad/000LQ00047@00<d40084B0<C3003e;P00oPL00=im
0010X@0005a7000?:@000QX001dd001_<@24]@00k5000?l0003ZE`00N;40001/=P006S80008I000A
:`00H4<0D:H00>9a003o0`00lSX00:bo0000NR4002Pk00036`002bD005E<02ZJ003IS@00o@`00?LU
0039^P0008D:000g@`001Ad000LQ0019C00>T000dZ<00?/F003j6@00d:L000V>0000ADX000HP0005
7P00IP00>dH008P30<bb003h7`00o1400=FI000IU00004m>00088P0011d003A200243@38_000mbD0
0?d<003HT@008YL0001ACP002B<000@L000a@000PQ80akl00?HW003m2`00fHl002BH0000DTd000TS
00047000<D00088@0<Rm003g9P00o@d00=NB000NUP00051>00088P0011d003I300262@3;]P00n200
0?`A003DW0004Y400019C0001b0000DN000oA`04S000d:P00?XG003j6P00cZ`000690P00>dD000DN
00078@00CTh06i@00=ND003m3@00mbL00<K10000OaH002dn00036`002bD005Q:03^P003PNP00o`@0
0?4m002M^`0007</000N=@000QT0018/001U?`1X[@00jEX00?l0003YF`00Ijd0001T?`004R`0008J
000O=P00M2T0Y;d00?8h003n1@00gH4002nL0000E4`000TS00047@00=T<008L50<j^0080nQT008/0
cJl000271@00=D<000@L000:9000ED`0=9d00=mm003o1000lCh009Ni0000L30001Xb00026@00@C<0
Q;D00>i8003o0P00hW<0042Q0000F4X000/U00047000<d4008H90<f`003j6@00nQX00<bb0000Q@X0
0350000370002bD005U904JS003SK@00o`400>a?001f/@0006Lm000B;0000QX0024g001h902g`@00
mB`00?d<003FU`0049000012B@001Ah000PQ001ACP0/VP00gH000?l4003`@000S[L0001]=@005S00
008I000L=000M2X0ZKh00?@b003m2@00ei8001FB0000A4X000DN00088@00DTd0;Y/00=im003o0`00
kdD008Be0000JCT001@]00026@008CL007TR0;o3003g9`00o1000=:S0002RP4003I3000470002bD0
05Y804jV003VI000o`000>QN001HZ@0005e6000<9P000a/003=100280`3@YP00o1400?LV002o``00
07PS000P=P000QT001D_001]=@2D^@00lSX00?h7003ISP005i<00013B@001Ah000TS001EC00oX@00
hfh00?l0003ZF000Gj/0001NA@0032L000<L000e@P02RP40dZ400?`>003e;@00[[l0001c;0006S80
008I000L=000MBP0]/4000[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`0F
00036`00228004I;00271036`@00lSH00?l1003XF`00Q[D0001e:000:C`000@L00067`00>D@0080D
0:no003_@`00o`000>a>002K^P0007XN000`@08000DN01@00391001l702Q_000kDX00?l0003^B000
YKd0001m6P00<d8000DN00057@00<D0007/N09jk003]B`00o`000>e8002S_00007`L000b@@8000DN
0?l003=2001m6@2X_P00kTD00?l0003/C`00UKT0001h8`00;3h000@L00067`00>dH008<>0;k3003a
>@00o`400>QM001l/P00074^000S>0000a/000TR001:C@05R`00bkD00?HY003n1P00hG<005VY0000
Ic`001Ta00026@003BL005M:02BG003EVP00nQL00?/B003HT@00;i/0001JB0003bT0008I000F;`00
I3l0DZL00>1g003n1`00mRP00<^e0003R`0004Q;00088P000a/002Pk001f9`2B^000k4h00?l0003]
C000U[T0001g9@00:C`000<L00088@00Ad/018/00<^c003f9P00o@P00=im0018X`000652000C;@00
0QT001<]001Q@P18Y000kd800?HW003:]P0008T00014BP001b0000@L000^?P00Nad0ZKh00?10003o
0@00ieh007>`0000K3D001`d00026P003BL005M:02^J003HT000o1000?TK003@YP004I00001?CP00
2B<000<K000X>`00Mb@0W;/00>i6003o0000j5/007Ra0000KC@001dd00026P003BP005U9036L003J
RP00o0`00?PQ003=/00018/00015BP001b0000@M000a@000OaH0^l800?<e003o0`00hW0005BW0000
Hd0001<]00026@005Bh006Dn05fZ003TJP00o`800?4k002]_`0007/N000[?@000a/000TR001@CP0F
TP00dih00?XE003j5`00dZ4001:A0000CTh000PR00047000;Sl007dI0;W2003c=000oP@00>5d001;
Y00005m4000@:`000QT001Xb001/=P1g/@00jEL00?l0003/C`00QKD0001_<@007C@0008J000?:@00
GDH0A:800>1i003n1@00lc<00;W20000OAX002`n00036`002B<0055=01nF003GU@00o0l00?PP003<
/P0008P2000lAP001Ah000HO0012B@05S000cjX00?TJ003k5000dih001:A0000Bdd000LQ00047@00
=T<008@;0<Vj003g9000o0`00=R@000RU`00059=00098`0011`002lo00205@35``00mB/00?d9003K
R000;9X0001EB`002R@000<K000/?@00OQP0`L@00?@]003n2000fhH002jK0000ED/000XT00036`00
;3h007hG0<C4003e:`00o@T00=Z:000XV@0005=<00098`0011`0031000224038_@00mRD00?`=003G
U0000<D06i@0001?CP001b4000@M000iA000R0<0cK000?TL003k5@00dJ@000R=0000@DP000DN0006
7`00Ad/04I000=BL003l4000mb400<Vi0000P`h00350000470002B<005E<032L003MPP00oPH00?8f
002Z_P0007HV000Q=`000QX0010Z001Q@P1LZ@00iV800?l0003[D`00M;00001W>`0052d0008I000K
<`00LBl0U[T00?0o003o0`00h7T003ZO0000EdX000XT00036`00<D0008@=0<Zf003h7P00na@00=2V
0002R`0003]500047@002280059=02VI003LQ@00oPH00?8g002T_@0007@Z000M=@000QT003hd07Na
003/C`00o`000>A[001;Y00005]7000<9P000a/002dn0022403:^000n1h00?XE003?Z@0008P2000f
@`0011`000TS001FB`0kW`00hGD00?l2003^A`00Pk@0001Z>0005Bh0008I000M=000M2X0ZKh00?<c
003m2000fHl001ZD0000BD`000HO00068000CTh08IL00=^8003n1P00lST009^j0000L30001Ta0002
6@006C40070`09^k003b>000oPH00=Z:000NU@0004]=00067`001R0004i>02BG003LQ@00oPD00?0m
002A^00006dd000F;`000QT001dd001e:02a`000mBd00?d<003DV`002Hd0000lAP0011d000TS001G
BP13XP00hf`00?l0003ZE@00IJ`0001P@`003RP000<K000^?`00Q0/0cJh00?XE003h8000a/00001l
70008cP0008J000C;000JCT0Q[D00>m1003n1000g8D0022F0000BT`000DO00078@00DTd0=9d00>1f
003o0@00je0006^^0000HT8000hX00036`00;cl008H70<nY003k4@00mRL00;_20000MRH001dd0002
6@006340074^0:Rn000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`00
0a/000PQ0012B@00Q@T0`L@00?4j003o0000jUH008jg0000Mb@002dn00047@001Ql003E3001n6@2V
_@00kTP00?l0003]B@00Y;d0001m6P00=48000DN00057@00;cl007TP09Rj003/C`00o`000>m3002^
_`0007lE000g@`001Ql000@M000]?P00NB80U[T00>]@003o0000kd<00:bo0000OQL003E300057P00
1Ad00310001k7P2O^`00kDX00?l0003]BP00W[/0001j7`00;cl000@M00067`00>4@0080C0;G1003`
?P00o`000>UH0025]@0007<[000V>P000a/000PR0016B`00R@00bKX00?D]003n1000hfh0066[0000
JCT001/c00026P0032H005E<01fE003CW`00nAX00?`?003JR`00=Yh0001LAP0042X0008I000E;P00
HT40BZ@00=il003m2@00mb@00<f`0009S@0004a=00098P000a/002Di001c:`29]P00jU<00?l0003^
A`00Wk/0001i8@00;3d000@L00078@00@dT008T10<Vi003e:P00oPH00>1g001@YP0006=0000E;P00
0QT0014[001NA011X@00kDH00?LT003</@001H`00018C000224000@L000Z?@00NB40X;`00>i4003o
0000jET007bb0000Kc8001le00036P0032H005E;02BH003FUP00na800?XH003BX@005i<0001AC@00
2R@000<K000U>@00MBP0U;T00>e:003o0000jUD0082d0000Kc4001le00026P0032H005M:02ZJ003H
T000o0l00?PM003?ZP002Xh0001:C000224000@L000^?`00OA/0//000?4i003o0P00i6/005bY0000
ICh001D^00026@004bd006=005FW003RK`00o`<00?8g002f`@0007dJ000^?`0011`000PR001<CP0@
T000dJ@00?XH003k5000e9`001VC0000D4h000TS00036`00:cd007/M0;30003b>@00o`<00>9_001C
Y`000692000B;0000QT001P`001Y>@1_[`00j5d00?l0003]BP00SKL0001b;P007cH0008J000>:000
FdP0?J000=in003n1P00m2l00<;40000OaD002lo00047000228004m>01RC003EVP00na800?TL003>
[@000h/00010B0001Ql000DN000nA`00R@00cK000?PN003k4@00eIT001VC0000Cdh000PR00047000
>P00<T40088@0<No003f:000o@X00=Z;000YV@0005A<000:90000a/002/m001m6@2n``00m2l00?h7
003LP`00<id0001GBP002bD000<K000Y?000Nad0^<400?<b003n1P00gH4003FM0000EdX000/U0003
6`00:C`007`L0;_2003d<000oPL00=b4000_V`0005E;000:90000a/002dn001o5@35`P00mRT00?d;
003ISP008YL0001AC@00228000@L000e@P00Q@T0bkD00?PO003k4P00dih000j?0000ADX200067`2g
0013B@0;SP00dZ400?/C003h7P00bk@000252@00=D8000@L00098P00DTd0:IT00=^7003n1`00lc40
0;?00000NB8002@i00026P003RP005m405BW003UI`00o`000>a>001l/P0006Xh000F;`000QT001Tb
001^<P2>]`00kd<00?l2003QL`00@J40001IB@002bD000<K000]?P00PA80b;/00?LQ003k4@00dZ40
00R=0000?dL000DN00078@00Cdh08YL00=Z:003n2000lc800:fo0000MRH0020f00026@00?3D0Kjl0
0>YD003o0000iFD005>W0000GDD000dW00036P00:Sd007lE0<Rm003g8@00na800=6T0003R`0003Y5
00047@002B8005A<03>M003ON`00o`<00>m2002;]P0006`e000F;`000QT001/c001b;@2P_000lSL0
0?h7003JR@0089H0001=CP001R0000HO0019C00KU000fHh00?h8003c=000Y;d0001b;0006c<0008I
000G<000KS<0T[P00?0m003n1@00g8@002FH0000Cdh000HP00067`00BT`07ID00=Z:003n1P00lST0
09Vj0000Kc4001Pa00026@006c<007<[0:Rn003c<@00o@X00=JE000?T000041800057@00228005E;
03^O003RLP00o`400>]@001][P0006=0000?:@000aX002/m0022403;/`00nQP00?TM0038^`0007hG
000V>P000QX0014[001W?01n/`00kTH00?l3003MP0009iT0001>CP001Ql000HP001@CP0/VP00gg/0
0?l2003]B`00M;00001T?`003bT000<J000/?P00Q0d0cJh00?/D003g8`00a<@0001i8@007cH0008I
000G<000Kc40Wk/000[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`0g0003
70001b0003i700233P2h`@00l3l00?l0003[D@00UkT0001j8000<40000DM00057P00<T4007/M09fk
003/C000o`000>m4002]_`0007lE000hA0001Ql000@M000/?@00Mb@0SkL00>YD003o0000l3h00;O1
0000PQ0003]50006800011`002Xm001f9P2=]`00jUD00?l0003`?`00]L4000214P00>D@000HO0004
7@00;Ch007PR09Ji003/C`00o`000>i5002W_@0007dJ000c@@0200057P1H000d@P00OQP0[;l00>m2
003o0000je<008fg0000MRL002Pl000470001b40049900271P37_`00m3400?l3003TJ000JJd0001[
=P007C@000<J000;9@00DTd05i<00=6U003h7@00o0d00=^6000nX00005i4000B;0000QT001<]001P
@`13XP00gH800?d;003h8@00cj/000n@0000Cdh000TS00036`008SP0074^082d003YF000o`000>m2
002X_P0007`L000_?`0011d000HP000oA`00QPL0akh00?@^003n1@00hW8005NX0000ICh001H_0002
6@0042X005a603ZO003/BP00n2000<j/000;SP0004e>00088P000a/002Lk001g9@2H^P00kDT00?l0
003ZE000Q;D0001a;P008CL000<J000;9@00Dd`07YD00=BK0080nQD00?l0e9/001fE0000Dd`000XU
00036P008SP007</08^f003/C`00o`000>]@0029]P00078]000Q=`000aX000/U001EC00TU`00eYD0
0?/A003i6P00dJD0012@0000CTh000PR00037000:cd007XO0:Vn003`?P00o`400>EV001T[00006Ll
000G<0000QT0018/001Q@`1=Y@00hGD00?h4003c<P00_l<000205@00<D0000@L00078@00B4`02Xh0
0<nY003i7000na400=JG000OUP00059=000:90000a/002Pk001i8P2W_@00l3d00?l2003TJP00FjT0
001T?`0052d0008I000F;`00Ic`0Ijd00>IR003o0000kTD009Ji0000M2X0028g00036P0032L005U9
03FN003LP`00o@P00?D[0036`@00088@000c@@0011d000LQ001<C@0BT@00dil00?/D003i6@00d:P0
00R=0000ADX000HP00057P00>TD008L50<^e003g8@00o0h00=ND000OUP00055=00098`0011`002lo
001o5@35a000mB`00?d8003LQ@00<9`0001FB`002bD000<K000X?000Nah0]L400?<c003n1@00gWd0
03ZO0000FDT000`V00036P009SX007TQ0:no003b=P00oPD00=mk000lX00005U9000<9P000aX002Hj
001j802b`000lc@00?h6003NO`00=Yh0001GBP002bD000<K000Z?000OAX0`<<00?D]003m2@00fXT0
02RI0000Dd`000TS00047000<T4008<>0<Vj003g8`00o0l00=FI000DTP0004Y<000680001Ah003m7
00F<003@Y`00nQH00?TK003=[`0008P3000hA00011d000PR001@C@0RU`00fH`00?d9003e;@00_<<0
001k7@009cX000<J000=9`00GDH0C:D00>=/003o0@00kDT008Fe0000K3D001L`00026@005c0006`e
08Fe003]B000o`400>=^0019Y00005]7000<9P000a/002Xm001o5P36`000mbD00?`?003DV`003Xl0
0013B@001Ah000HP001<C@0LU000f9000?d:003d;P00]/40001h8P008SP0008J000j=@1W[@00jET0
0?l0003WH000FjT0001P@`003RP000<J000W>`00OAX0a/800?HU003l3`00dil000V=0000?TL000DM
00088P00DTd0;9X00=f0003n1000l3d009Bi0000Kc8001Pa00026@006C40060006la09Nj003a>`00
oPD00=b4000WV@00051>000780001Ah004E:01BB003GT`00o@X00?@`002]_`0007DX000M=0000QT0
01D^001[=P2:]P00kd400?l3003NO`00;9X0001AC@001b4000DN0015BP0FT`00f9000?d8003c=000
X[`0001a;P006S80008I000I<@00LBl0Wk`00?8e003n2000f90001JB0000A4X000DN00088@00Dd`0
=9d00>1g003o0@00kD/007Fa0000ICh0010Z00026P00:3/007lE0<Vi003i7000nAX00<Zf0000PA<0
02Tl00036P0042X006Dn07Fa003]BP00o`800=mj000^V`00051=000780001Ql004e>02JH003MP000
o`<00>i6001l/P0006Hm000@:P000aX002Tl00214P3;/`00nQL00?PO0036`00007/M000R=`000QT0
01D^001]=02F^@0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`0011`0
00HP000jA@00P1<0[kl00>m4003o0000kD`00:2l0000O1`003=100057P001Ad002lo001i8@2E^@00
je400?l0003`?`00]/4000224@00>dH000HP00047000:C`007DX08Ne003YF@00o`400?4j0030``00
08@;000oA`001b0000@L000W>`00M2X0Q;D00>UJ003o0@00lCX00;k30000P`d003e60006800011`0
02Xl001f9P2>]`00jU@00?l0003_@@00/<00001o5P00=T<000DN00057@00<D0007`L0:>l003^A`00
o`000>a>002F^@0007PS000[?@0011`000HP000nA`00Q0/0aL@00?8e003o0P00iV<0076`0000KS<0
01lf00036P002R@0051=016@003?ZP00n2400?d:003MP@00AJ<0001Q@P0052d0008I000A:`00GTD0
>il00=^7003l3@00n1d00=6V000ETP00055=000:90000aX0020f001_<P1h/@00j5d00?l1003`?@00
/L00001n6000<T4000DM00067`00>dD008@<0<G3003c<P00o`<00>=/001OZP0006Lk000H<@000QT0
00lY001JB00bW@00jdd00?TM003@Y`004I40001@CP002B<000<K000U>@00M2T0SkL00>a>003o0000
k4l008fg0000LbX002@i00036`002R@0055=01NC003BX@00nQP00?/B003FUP0099P0001EB`002bH0
00<J000P=P00L2l0P[@00>YD003o0000kD`0096h0000M2T002@i00036`002R@0059=01fE003DV`00
na@00?XG003CX0005i<0001@CP002B<000<K000X>`00N2<0X;`00>m2003o0@00if0006b^0000JCT0
01Ta00026@0042X005i504JS003ONP00oPH00?@^0035``00088@000e@P0011d000HP0014BP04R`00
cJh00?PO003l3`00f94002JH0000E4`000/U00036`009CT007HV09jk003_@P00o`400>IU001SZ`00
06Hm000E;`000QT001@^001U?P1OZP00iFL00?l1003_@@00Wk/0001f9P0093T000<J000;9P00ETX0
;Y/00=Z9003m2P00mRL00<Rl0000Q0/003I300047@001b0004Q;00b>003AY@00nQL00?XF003BXP00
3Xl00019C0001b0000@M000f@`00Q0/0bKX00?LU003m3000fHh002JH0000Dd`000TT00036`00J`00
;3d007dI0;g3003d<000oPH00=f0000gWP0005Q9000<9P000aX002Hj001i8P2/_`00lSP00?h4003P
N000@J40001KA`003BL000<J000S>000MbD0Y[d00?4j003o0`00h7H004BR0000FdL000dW00036P00
93T007LT0:Vn003b>000oP@00=mj000mX00005U9000<9P000aX002Lk001k7P2g`@00lc400?h7003L
Q000;i/0001EB`002R@000<K000^?`00P1<0akl00?HV003l3@00ei@001^D0000CTh000LQ00057@00
>dD008T00<j/003j6@00nQL00<nZ0001RP0003a600057@001b4004i>01bE003GTP00o@/00?DY0035
a00007dI000Y?0000a/000`V001JB015XP00hW800?l2003_A000SKL0001^<P006C80008I000E;`00
JSP0OK<00>a=003o0000i6T0052V0000GDD000dX00036P009c/007`K0<C4003f:@00o0`00=JF000D
TP0004M;008000HO08H004Q;01FB003FU@00o@`00?DZ002o``0007/N000U>@000QX003Pf05nZ003X
GP00o`000>QK001SZ`000691000?:P000QX002@i001k7P30``00mRT00?`=003EV@003i000012B@00
1Ah000LQ001@CP0VV000g8H00?h6003a>@00WK/0001a;P006S80008I000G<000KC@0SkL00?10003o
1000gWh002jK0000DTd000PQ00057P00@DP03Xl00=FH003m3000mB`00;K10000MbD0020f00026@00
4bd006Ti086d003^AP00o`800=mj000cW@0005=<00088P001Ad00458012@003FU@00o@X00?@`002[
_P0007@Z000L<`000QT001L`001^<P2G^@00lCX00?h6003JRP0079D00018C0001Al000LP001AC@0]
V`00gW`00?l2003^A`00OK<0001W?0004R/0008J000U>@00OAX0akh00?PO003j5`00c;4000233P00
;3h000<J000>:@00HT40KJh00>a?003o0@00hGD003FM0000DTd000LQ00057P00BD`07iH00=^6003n
1000kd4008Be0000J3X0018/00026P009SX007lF0<Vh003i6P00nA`00<Rk0000OQT002@i00026P00
4bd006Xg08jg00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1]00047@00
1Ql003I3001n602V_@00kDP00?l0003^A`00Z;h0001n5`00=d<000HO00047@00:cd007LU08bg003Z
EP00o`000?4k002o``0008@<000oA`001b4000<L000V>P00LR`0O[<00>MN003o0@00lSD00<G20000
QPH004=900088@000a/002Di001b;@1l/P00iel00?l1003b=P00aL<000262000@DP000LQ00037000
9c/007@Z08Fe003YF@00o`000?4l002i`P00084A000jA@001Ql000@M000]?P00NB40V[X00>a<003o
0000kDT009jk0000NQl002lo00047@001Ql003Y50022402l`P00lCX00?l1003WGP00N[80001`<000
8SL000<K00098`00CTh02hh00<f_003g9000o@P00=mk001<Y@0006=0000E;P000QT0010Z001KA`0d
W@00fHd00?`?003i6P00dZ0001^D0000Dd`000/V00026P007CD006de072_003VHP00o`400?4i002j
`P00080C000f@`0200057P3o000gA000PQ40_l<00?8f003o0P00iFL006N]0000JSP001Xb00026@00
3BP005Q902bJ003ZD@00nAT00=:Q000HT`00059=000:90000aX0028h001b;@26]@00je<00?l0003]
BP00UKT0001f9`009SX000<K00098`00Cdh04I400=6V003i6`00o1000=RA000[VP0005M:000=9`00
0QX001de001^<`1j/P00jET00?l0003^A`00V[X0001f9P009SX000<K00098`00D4d05i<00=>P003j
5`00na@00=FJ000MU@00059=000:90000a/002Di001e9`2H^P00kTL00?l0003XF`00M;00001/=P00
6c<0008I000?:@00G4H0?Z000=io003n2000mBX00<Nn0000Q0/003Q400057P001Ql0041800290@3;
/`00mb800?d<003IS000;I/0001FBP0032H000<J000R>000M2X0UKT00>i7003o0000iel006^^0000
J3X001L`00026@004b`006=105NX003SK000o`800?4l002X_P0007TR000W>`000a/000XT001DC00X
V@00fHh00?`<003g8`00b[L000261P00>TD000DN00067`00@dT01X`00<nZ003i6`00na<00=BM000D
TP0004i>00088@0011`003=100224037_`00mRT00?d:003JR@00;9X0001EB`002RD000<K000Y?000
Nah0]<400?<d003n1@00gg/003jP0000FTP000dW00036P008cP007HV0:>m003a?000o`<00>5c0019
Y00005e6000>:0000QX0024g001d:@2M^`00l3l00?l2003RL@00Bj@0001MA@003RT0008J000Q=`00
MBP0XK`00?4l003o0`00hG@004FR0000FdL000dW00036P0093T007PS0:jo003b=@00oPD00=in000f
WP0005M:000;9@000a/002/m001n6035a000mBX00?d:003ISP008IH0001@CP00228000@M000g@`00
Q`D0c;400?TL003k5000dJ@000N<0000@4P000DN00068000BT`05I800=JG003l3P00mRD00<No0000
P1@002`n00036`002bD005Q903fP003PM`00o`<00?0o002F^@00074_000K<`000QT001@]001W>`1d
/000je800?l0003VI000F:P0001OA0003RT000<J000U>@00NQl0^l800?D]003m2P00f94001^D0000
C4d000HP00057P00A4X03i0000240=FJ003l3P00mRH00<G30000OAX002Pk00036P00=cH0EjP00>IS
003o0000jUH006^^0000I3l0014[00026P008SP007PR0;O1003e;@00o@/00=ND000ETP0004I;0006
7`001R0004e>01nF003JR`00oPL00?<e002U_@0007<[000L=0000QT001D^001[=`26]@00kT@00?l2
003ON@00=Id0001DC000228000@M000mAP08S@00dih00?`>003f:000_l<0001i80008SP0008J000B
;000Ic`0NK800>e;003o0@00hG@003ZO0000ED/000TS00047@00?DL02Xh00=FK003l3000mB`00;C1
0000MRH001he00026@005Bl006`e08jg003`?P00oPD00=b5000RU`0004e>00067`001R0004m>02JH
003MPP00o`@00>m20026]@0006Ti000C;@000QT0028h001k7P35`P00mb800?/D003>Z`0008D9000_
?`000a/000dX001P@`1U[000jU@00?l0003RL000?:00001EC000228000DN0015BP0IT`00fX/00?h6
003`?@00SKL0001[=`004bd0008I000S>000O1/0akd00?PN003j6@00b[H0002050009c/0008J000B
:`00J3X0QKD02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0<0000DM0005
7P00<d4007`L09jk003/C@00o`000>m2002a`000084B000jA@001R0000@L000Y?000M2T0Q;D00>QK
003o0@00lSL00<G30000QPH004=900088@000a/002<h001`;`1f/@00iV<00?l2003c<@00akd00029
0@00Ad/000PR00036`008SP006la07B`003VI000o`800?<b0037_P0008P30015BP00228000<K000T
>@00LRd0OK<00>QN003o0@00lSP00<740000Q0`003e70006800011`002Xm001g9@2B^000je400?l0
003^A@00Ykd0001m6`00<T4000DM00057P00=T<0080E0;?0003`?P00o`000>UI0022]000078/000T
>@000a/000PR001:C005S000bk@00?HX003n1`00h7H005BW0000ICh001L`00026@003bT005U802fK
003GTP00na800?XG003DV`008IL0001EB`0032L0008J000K<`00JSP0J:d00>EX003o0P00lcD00<?4
0000P`h003U500067`001Ah003A2001o5@2f`@00lCX00?l1003VHP00Kjl0001/=P0073@0008J000<
9`00ET/09IP00>UE003j5P00e9`001jE0000E4`000/U00036P0083H0070`07jc003YF000o`000>i6
002N^`0007PS000Y?0000a/000PR001<C@0;SP00cj/00?PO003l3@00fX/0036L0000FDT000hX0002
6P006c<006`f07:`003WGP00o`000>m2002R_00007TR000Y?0000a/000PR001>CP0AT000dJD00?TJ
003k4@00eYD002>G0000E4`000/U00036P008SP007<[08nh003]C000o`000>YF001l/`0006hc000M
=0000QX000hX001JB00gWP00g8@00?d:003f9`00bKT000271P00?4H200057P21000lAP00Q`H0bKP0
0?HV003m2P00fhL003>M0000FDT000dW00026P0083H0078]08fg003]B`00o`000>QJ001c/00006/g
000I<@000QT0014[001P@`1?YP00hW400?l3003b>000/<00001k7P00:S`000<K00098`00DTd08IH0
0=NC003l3`00n2000<bb0000R@4003i700057P001Ql003m7006:003=[`00n1h00?`@003EV0006i@0
001@CP00228000@L000`@000P1@0aL@00?D]003n2000g8@003>M0000EdX000/V00036P009SX007PR
0:^n003b>@00o`<00>5e0016X`0005a6000>:0000QX0024g001d:P2K^P00l4000?l2003SK@00D:H0
001OA0003bX0008J000N=@00LRd0UKT00>m3003o0@00i6/005:W0000H4<0010Z00026P007cD007</
09Rj003_@@00o`800>9_001<Y@0005i5000>:0000QX0028g001f9`2U_@00lCX00?l4003ON@00?J00
001IB@0032H000<K000X>`00O1`0_L<00?@^003m2000fXT002RI0000DTd000TS00047000=48008@:
0<Zf003h7`00na800=>O000=S`0004A:008000HO044004I:00n@003DW000o1000?LR0039^P00088@
000`@0000a/000XT001FB`0fWP00gW`00?h4003a>`00W[/0001c:`007SD0008I000B;000ICh0K:h0
0>UG003o0000ieh0062[0000HT40010Z00026P008SP007PS0;;0003d<@00o@P00=Z<000QUP0004m>
00078@001Ah0041800V=003CW`00o1400?LS0037_P0007lE000[?@000a/003Dg04nV003UJ000o`00
0>]A001c/00006Hm000B;0000QT0020f001f9P2^_`00m3400?d9003IS`006i@0001;C@0200067`1Z
0019C00IT`00f9000?d9003d<000[[l0001f9`007cD0008I000D;@00JCX0O[<00>e9003o0@00hG@0
03bP0000ET/000TS00047000>D@00h/00=:S003k4@00mbD00<G30000O1`002Di00026P0042/006Dn
076_003[D000o`000>9_0011X@0005M:00098`0011`003U500F;003CX000o0l00?HX002m``0007PR
000P=`000QT001@]001Z>026]@00kd<00?l3003MP000:IT0001@CP001b0000HO001;C@0PUP00fhL0
0?h5003`?P00S[L0001/=P005Bh0008I000P=P00N280_l<00?HV003k4@00d:H000280`00<T4000<K
000<9P00GTD0GJX00>UI003o0000i6/004>R0000EdX000TS00047@00@4P04Y400=R@003n1`00lSP0
09Fi0000KC@001D^00026@008CL007XO0<G2003g8@00nQH00<ba0000PPl002Xl00036P0042X006Hm
07fc00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1200057P001Ad002lo
001i8@2E^@00je800?l0003`?P00^/8000233P00?TL000LP000370009SX0078]07bb003WH000o`80
0?<b0037_P0008T10017B`00228000<K000Q=`00KS<0KZl00>EX003o1000m2d00<Vh0003R`0004]=
00098`000aX0020f001]=01/[P00i6T00?l4003d;P00bKT000::0000BD`000TR00036`008SL006la
07F`003VH`00o`800?<d0036`@0008H70011B0001b4000@L000X>`00MBT0RKH00>YE003o0000l400
0;300000OaH003E20P001Ah0o`00<d4007dI0:^n003_@P00o`000>YD002:]P0007@Y000W>`000a/0
00PQ0016BP00R@00bKT00?D/003n1@00hW4005bY0000Ic/001Ta00026@003BP005M:02NI003FU`00
naD00?/D003FUP00:9T0001HBP003BP0008I000I<P00J3X0H:/00>=]003o1000m3400<K10000Q@T0
03e600067`0011d00350001m6P2]_`00l3l00?l1003XG@00Mk40001^<P007cD000<J000;9@00E4`0
7YH00>MI003k4`00eYL002BH0000ET/000`V00026P007CD006dd07Ja003XG@00o`000>m1002V_@00
07XO000/?P0011`000LQ0017B`05S000cK000?LR003m2`00fhH003RN0000FdL000lY00026@006C80
06Ti06Z]003VH`00o`400?0n002[_P0007/M000/?P0011`000PQ001:C00;SP00cjX00?PM003l3`00
f90002ZJ0000ETX000`V00036P0083H0074^08Ne003[D000o`000>]B0024]@00070`000O=P000QX0
00dW001HB@0`W000fXX00?d<003g8`00bk@000290@00@4P000HO00057P00>4@008@;0<Nm003e:P00
o@P00=f1000jW`0005]8000>:0000QX001he001`<025]@00je000?l0003ZE@00Nk80001]=0006c<0
008I000@:P00GTD0B:<00>1g003n1000lc@00;W20000OAX002dn000370002B<0051>01^D003EV@00
na400?TL003>[@0018/00012B@001Ql000DN000kAP00Q`@0bk@00?LQ003l3P00ei<0026F0000DTd0
00TS00036`00;3h007dI0;g3003d<@00oPH00=in000jW`0005U8000<9`000aX002<h001f9P2S_000
l3d00?l2003RL000CJD0001OA0003bT0008J000N=@00LRd0T[P00>i5003o0@00i6P005RX0000HD80
014[00026@0073@0070`08bg003^B000o`000>EV001JZ@000691000A:`000QT001`d001`;`2@^000
kTD00?l1003TJP00DjL0001P@`003bX0008J000O=P00M2X0WK/00?0n003o0`00hG@004FR0000FdL0
00dW00036P009SX007XP0;C1003c<P00oPL00=b4000^V`0005A<00098`0011`0031000223`38^`00
mb<00?`?003EVP004i400018C000[`001R0000DN0011B@0:SP00dZ800?/C003h7P00bkD000242`00
<d4000@L00098`00E4`0<9`00=f1003n1@00lSL00:Nm0000MBP0020f00026@004B/006=006B/003X
G000o`000>UJ001W[@0006@o000A:`000QT0020f001e9`2Y_P00lcD00?h7003KQP009iT0001AC@00
224000@M000lAP04R`00dJD00?/C003h7`00bKT000224@00;Sh000<K000c=`18X`00hfd00?l1003/
C000Nk80001X>P0052d0008I000M=000M2X0Y[d00?<e003n1`00fXT0026G0000Cdh000LP00057P00
ADX04i400=JE003m2`00mBd00;O10000N2<0024g00026@004R`006Hl07Ja003/CP00o`400>=_0013
XP0005Q9000:900011`003E300280P3@Z000na<00?PQ0037_P0007hH000W>`000aX000lY001R@@1Y
[@00jU@00?l0003TJP00B:<0001IB@002R@000@L000f@`00R@00dJD00?/A003g9@00aL@0001k7P00
8cP0008J000B;000J3/0OK<00>i7003o0P00gg/0032L0000DTd000LQ00057P00Ad/06I@00=V<003n
1`00lCT009Ni0000KS<001H_00026@007SD007HV0;K1003e:P00o0l00=:Q0001RP0003I300037000
2bD005a705JX003WGP00o`000>EU001:Y00005U9000:900011`003e600b?003FUP00o@T00?<d002N
^`0006la000G<0000QT001le001h8`30``00mbD00?/C003>[00008D:000]?P000aX000lY001T?`1e
/@002_ooool1o`00007ooooo000Nooooo`?o00001oooool0o`001Ah000@M000/?P00MbD0SKL00>YG
003o0@00lCX00<;40000Q@T0049900088@000a/002<h001`<01d/000iFD00?l3003d;P00bKT000>;
0000C4d000TS00036P007cD006`f06J/003SK@00oPD00?DY003;/`002Hd0001?CP002R@000<J000M
=@00JcL0I:`00>=^003n1@00mBX00<^e0007S@0004i>00098`000aX001lf001]=01][P00iFP00?l3
003d<000b;d000280P00ADX000PR00036`009CT0078/086d003XFP00o`400?4l002h`P00084A000i
A0001Ql000@M000_?`00Nad0X[`00>i7003o0000jdl009:h0000MbD002Xl000470001b4004990027
1@37_P00m2l00?l4003SK000Hj`0001Y>@006c<0008J000<9`00ED/089H00=BL003j6000na400=RA
000_V`0005Y8000?:@000QT001L`001V?@1HZ000hW800?h5003e;@00b;`000271000@DP000LP0004
7000;Ch007/N0:Fm003_@`00o`000>UH001o/`00070_000Q=`000aX000XT001BC@0HT`00iUd00?/A
003HTP00:iX0001HBP003BL0008J000K<`00JcL0KZl00>IR003o0@00l3d00:no0000OAX002lo0004
70001b0004=9002:003;]@00mRH00?d9003MP@00?j40001MA@0042X0008I000G<000Ic/0HZ/00>AX
003o0P00lCT00;C00000OAT002lo000470001b4004I;00F<003=[`00n2400?`<003JR`00<I`0001H
B@003BL0008J000N=@00Kc80Ok<00>YE003o0000k4d008fg0000LR`0024g00036P0032H005I;02ZJ
003HS`00o0h00?PO003=[`0018/00014BP001R0000@M000e@P00PQ00aL800?@^003n1P00gW`0046Q
0000GDH000lY00026@0073<006dd07fc003ZE@00o`000>]A0023]00006la000M=0000QX000hY001L
AP11X@00gg`00?h6003d<000`/@0001o5@00<40000@L00088P00CTh05I800=>N003k5000nAT00=2W
0009S@0004I;000680001Ad003Q400252@39^@00mbD00?d<003IS@00:9T0001DC0002R@000<K000Z
?000Nad0]<400?<e003n1@00ggT0046Q0000FdL000hX00026P00l`008CL007@Z09Zj003_@@00o`40
0>A[001DY`000652000A:`000QT001`d001_<@2:]P00kDX00?l0003VH`00GjX0001T@0004R`0008I
000J<P00KC<0Q;D00>a<003o0000if4006:[0000I3l0018/00026@006S8006hb08Ne003]BP00o`00
0>EU001KZ@000691000A:`000QT001dd001a;P2D^@00kd800?l2003SK`00C:D0001MA@003RP0008J
000S>000Mb@0Zkl00?8f003n1@00gWl003FM0000ETX000XT00036`00;Ch0080D0<K0003f9P00o0d0
0=JE000IT`0004a=000780001Ah003i700B;003@Y`00nQD00?TK003=/00008L6000f@`0011`000PR
001BC@0YV@00fhL00?h7003c<`00[kl0001g90008SP0008J000?:P00HD80GJX00>MQ003o0000jUD0
06n_0000ISd001</00026@007CD007<[0:6l003b>@00oPD00=f1000^V`0005=<00088P0011d003Q4
00290@3?ZP00nQH00?TL003;]00008@<000a@0000a/0034g046Q003RLP00o`400>i80023]00006/g
000E;`000QT001/c001a;P2M^`00lCT00?h5003LQ000:9T0001AC@001b4000DN0011B00=S`00e9/0
0?`=003f:@00_l<0001j7`008cP0008J000A:`00I3l0KZl00>]C003o0000i6X004ZT0000FTP000/U
00036`00<T4008H70<j]003j5P00n1h00<Vi0000P1<002Xl00036P003RP00613066[003YF@00o`00
0>EU001?YP0005]7000;9@000a/003=100271@3?ZP00na@00?LQ0037_`0007dJ000U>P000QX0014[
001U?P1e/@00k4`00?l1003QM@00=ih0001DC000228000DN0012B@0CT@00f9400?d8003c=@00Wk/0
001`<0006340008I000K<`00M2X0[[l00?@^003m3000e9`000N<0000>DD000@L000:9000FTP0CZD0
0>IS003o0000if0005:V0000FdL000XU00047000>D@01h`00=BK003m2`00m3000:Jm0000LBh001Ta
00026@0073@007HW0;O1003f:000o1000=2W0000Q`D0031000036`003RP0069106f^0008ooooo`?o
00000Oooool001kooooo00?o0000ooooooooool01oooool0o`001Ql000@L000Z?000MBP0QKD00>QK
003o0@00lSD00<K10000R0@004I;00088P000a/0024g001^<`1/[P00i6X00?h4003e:`00bk@000V=
0000Cdh000XT00036P0073@006Xi05nZ003QLP00oPL00?HV003=[P003i00001AC@002bD0008J000K
<`00JCX0G:X00>5c003n1`00mRH00<f`000=S`00051>000:90000aX001dd001[=`1U[000hfd00?h4
003e;000b[P000>;0000BT`000TR00036`008SP0070_07Vb003WG`00o`400?8h0031a00008<=000l
AP001R0000@L000/?P00NB80V[X00>e<003o0000kD/009^j0000NB4002`n000470001R0003i70025
2P35``00lc<00?l3003UI`00Jjh0001/=P007C@0008J000;9P00Dd`06Y@00=:Q003i6`00o0l00=Z<
000eW@0005a7000@:P000QT001H_001T?`1AYP00h7L00?h7003f:@00b[L0002:0000ADX000LQ0004
7000:Sd007PR09bk003^B000o`000>YC0027]@0007</000S>0000a/000TS001@CP0BT@00iF400?`>
003IS000<Y`0001JB0003RP0008I000I<P00JCT0IZ`00>EW003o0P00lST00;O10000OaH003910004
7@001Ql003m700271039^P00mBT00?h7003OO000AZ<0001OA0004R/0008I000F;`00ICh0FjT00>=]
003o0`00lSD00;c20000P1D0039100047@001R0004990029003;]000mb@00?d:003LQP00=ih0001J
B0003RP0008J000L<`00KCD0Mk400>UJ003o0000kDP009Fi0000MBT002@i00036P002bD005A<02>G
003GU000o1000?TL003?ZP002Hd00018B`001b4000@L000a@000P1D0`<<00?<a003n1@00h7L004VT
0000Gd@0010Z00026@006S8006/g07F`003YFP00o`000>a<002;]P00074^000O=P000QX000dX001J
B00jW`00gH400?h8003e;000a/4000224000<d4000@M00078@00BT`03i000=:S003j5`00nQH00=:R
000?T00004Y<00078@0011d003A200233P37_P00mRP00?d:003KR000;Y/0001FB`002bD000<K000W
>`00NB40[;l00?8i003o0`00hG@004RT0000GTD000lY00026P00B@007cD0078]09:h003^AP00o`40
0>EV001LZ@0006=0000B;0000QT001Xb001]=022]000k4h00?l0003WGP00Ijd0001V?@0052d0008I
000H<@00JcH0O;800>]A003o0000j5`006V]0000ISd001@]00026@00634006`f07nc003/C`00o`00
0>MP001SZ`0006@o000B;0000QT001/c001_<@2<]`00kTL00?l1003TJP00DjL0001OA0003bT0008J
000Q=`00MBP0Xk`00?4j003o1000ggT003bP0000F4T000/U00036`00:Sd007hI0<C4003e:P00o@/0
0=R@000OUP0004m>00078@0011d003Y50029003>[0000P3j6000Z03>Z`0008T0000jA@0011d000PQ
001@CP0RU`00fX`00?d9003d;`00^<80001j80009CT000<J000>:000Gd@0EJL00>EV003o0000je00
07Na0000J3X001@^00026@006c<0074^09Rj003`?@00o`@00=ml000eW@0005E;00098`0011`003E2
00271P3=[`00nQT00?TI003=[`0008H7000d@P0011`0030h03ZO003PM`00o`800>m3002;]P0006dd
000G<0000QT001Tb001_<@2E^@00l3d00?h4003NO`00;Y/0001CC@00228000@M000mAP07S@00dj00
0?`@003g9@00aL80001l6`009SX000<J000?:@00HT40IZ`00>UG003o0000iVD0056V0000G4H000`V
00036`00;cl008@<0<bb003i6@00nAX00<^d0000P`l002dn00036`003BL005i505ZY003WGP00o`00
0>MP001GZ00005e5000<9P000a/002lo00252P3=[`00nQL00?PN0039^P0007lF000X>`000aX000lY
001S@01^[P00je400?l1003RL000?Z00001FB`002B<000@M000nA`0>S`00eYL00?d:003d<@00Ykh0
001b;0006S80008I000J<P00LRd0YKd00?<b003m2P00eYL000b?0000?DH000@M00098`00F4X0Aj<0
0>EX003o0000j5`005VY0000GDH000/V00036`00=D<00HX00=>P003l3P00mB`00:no0000M2X001/c
00026@006S8007<[0:no003e;000o0h00=:R0000R@0003=200036`003BL0061306F/00[ooooo0Ol0
0001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o0006800011`002Lk001c;01m/`00if00
0?l2003c<@00b;`0006:0000BT`000TS00036P007cD006/f06B/003RK`00oPH00?HW003=[`003Xl0
001AC@002bD0008J000J<P00Ic/0EjP00>1g003m2000mb800<nZ000ETP0005=<000<9P000QX001Tb
001W?01EY`00h7P00?d8003g8`00cj/001:A0000DTd000/U00026P006c<006Tj05jZ003RLP00oPH0
0?HX003</`0028d0001>CP002B<000<J000P=P00KS<0LK000>IT003o0P00lc<00<K20000QPP00418
0007800011`002Xl001g9@2A^000je000?l0003^AP00Xk`0001k7@00;cl000@M00067`00>TD0088?
0;o3003b>000o`800>IR001c/00006hc000O=P000aX000XU001AC@0DTP00d:H00?PN003l3@00fhH0
03bP0000GTD0014[00026@0052h0069104ZT003OO000o@P00?HU003</P001H`00019C000228000<K
000X>`00MRH0U;T00>a<003o0000k4l0092h0000MBP002Hj00036`002B<004i>00b?003TIP00o@`0
0=^7000hWP0005a7000?:P000QT001P`001W?01OZP00hf`00?l3003c=000`<<000214P00=T<000DN
00067`00>dH008D90<No003e;@00oPH00>1g001>Y@000692000C;@000QT001@^001S@01CY`00hG80
0?h4003c<@00a<@000224000=T<000DN00067`00?TL008L50<Vi003f:000o@P00=f0000nX00005a6
000?:@000QT001Xb001Z>01_[`00iel00?l0003_A000WK/0001g9@009SX000<K000:9000DTd07ID0
0=FI003k4`00nAT00=6U000?T00004a=00088P0011`002ho001m6@2h`@00lSD00?l4003RLP00D:H0
001Q@P004R`0008I000H<000JCT0KJh00>MN003o0000kTL009>i0000Lb/0024g00036P0032H005Q9
03>M003KQP00o@T00?HX0038_@0008@<000f@`001Ad000LP0016B`09S@00d:P00?TJ003k5000e9d0
01FB0000CTh000PR00047000<D00084C0<G2003e;000oPP00=b3000eW@0005Q9000<9P000aX002@i
001g9@2S_@00l3d00?l2003RK`00D:H0001P@`0042X0008I003c000L=000L300R[H00>e:003o0000
if4006>/0000ICh001<]00026@00634006/g07Zb003[D`00o`000>UI001_[`0006Pk000E;`000QT0
01H_001Y>@1d/000jUH00?l0003YE`00LJl0001X>P005Rl0008I000G<000JSP0Mk400>YC003o0000
j5/006Z^0000ISd001@]00026@006C8006dd08Be003]B`00o`000>IU001KZ@000652000@:P000QT0
01he001c;02K^P00l3h00?l3003QM000@j80001JB00032H000<J000W>`00Nad0_<800?@^003m2@00
fXX002FH0000DDd000PR00047@00=T<008L60<ba003i6`00nQD00=2V0004R`0003e700057P001b40
04i>01bE003HT@00o@/00?D[0031a00007`L000W>`000aX000dW001MAP1>Y@00i6/00?l1003]B`00
Ok<0001Z>0005Rl0008I000I<P00Kc80T;P00>m1003o0P00h7L003bP0000EdX000XT00036`00<D00
08@;0<^d003i7000nQH00<nZ0000R08003M400047000;cP0<id00=il003o0`00l3l009>i0000Kc40
01Ta00026@005c0006dd08fg003_@P00o`<00=mj000eW@0005E<00098`0011`003U500::003AY@00
na800?LR0037_P0007lG000Y?0000aX000hX001P@`1NZP00j5`00?l0003WH000FJT0001NA@003BL0
00<K000/?@00PA40b[L00?TL003j6000cJl000252P00<40000<K000<9P00G4H0DZL00>IS003o0000
j5/005jZ0000Gd@000dX00036`00;3h0088?0<^d003i6P00nA/00<^f0000PA4002/m00036P003RP0
065206J/003ZE@00o`000>A[0014XP0005Q:0009900011`003]500R=003DW000o0`00?D]002``000
07DY000L=0000QT001P`001_<@2M^`00lSH00?d8003GTP004Y400011B0001Ad000TR001FB`10X@00
hfd00?l0003YE`00HJ/0001OA00032L000<K000b@@00R0<0dJD00?`@003f:@00]l40001f9`007C@0
008I000H<@00LBh0Y[d00?@`003m3000e9`000B;0000=d<000<L000<9P00GDD0GZX000[ooooo0Ol0
0001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1=00078@000a/002@i001`;`1e/000iFD0
0?l3003d;@00b[L000J<0000CTh000XT00036P0073@006Ti05bZ003QM000oPL00?LS003?Z`005980
001CC00032H0008J000I<@00ICh0D:H00=il003m2P00n1l00=6U000KU00005E;000=9`000QT001P`
001T?`1>Y@00gWd00?d:003h7`00dJH001RC0000E4`000`V00026P006C4006Ll05JX003PM`00oPP0
0?LU003=[P003Xl0001@CP002R@000<J000N=@00K3H0JZd00>AY003o0`00m3000<Rm0000R0<004A:
00078@000a/002Lk001d:@29]P00jUD00?l0003_@P00Zkl0001m6@00<d400P001Ah0?@00=d<0080C
0;O1003a?000o`400>QM001k/P00070`000Q=`000aX000TT001?CP0>S`00cZ/00?PQ003m2P00gH40
04>R0000H4<001</00026@004R`0061304>R003MP@00o@X00?LR003>[@002hh0001=CP002B<000<K
000U>@00M2X0S;L00>]A003o0000kDX009Rj0000MbD002Pl00036`00228004U<00N<003RJP00o@X0
0=f2000oX@0005i5000A:`000QT001H_001U?P1GZ000hW400?h4003d<000aL8000233@00>D@00P00
1Ah04`00>4@008<>0<G3003d<@00oP@00>9b001EY`0006@o000E;P000QT001</001Q@P1<Y@00h7L0
0?h6003d;@00a/0000242`00>DD00P001Ah0o`00>TD008D:0<Nn003e:`00oPL00=mk0015X`0005m4
000A:`000QT001P`001X>P1W[@00iV@00?l1003`?`00Y[d0001i8@00:C`000<K00098`00D4h05i<0
0=>N003j5@00nQH00=>P000ETP0004m>00088P000a/002/m001k7@2__`00lCX00?l2003SK@00EjP0
001S@0004bd0008I000F;`00Ic`0IJ`00>IS003o0@00kd<009bk0000MRL002@i00036P002bD005I;
02bJ003JR`00o@/00?LU003:^00008H7000jA@001Ah000HO0012B@04R`00cZd00?TM003k4@00eIP0
01^D0000D4h000PR00047000;Sl007hG0<33003d<000oPH00=in000kW`0005Y8000=9`000aX0028g
001e:@2K^`00kd400?l1003TJP00EjP0001R@@004B/0008I000J<P00KC@0P[@00>a?003o0000j5`0
06^^0000Ic`001D^00026@005Rl006Ti07:`003YF000o`000>YE001g/@0006Xh000G<0000QT001D^
001W?01/[P00j5/00?l0003[D`00NK80001Z>0005c00008I000E;P00J3/0Kjl00>UH003o0000jUH0
07:`0000J3X001D_00026@005c0006/g07bb003[D000o`000>MP001RZ`0006A0000B;0000QT001`d
001a;`2B^000kd<00?l2003RK`00BZ@0001LAP003BP000<J000U>@00NB40]<000?<b003n1`00g8D0
02bJ0000Dd`000TS00047000<d4008@;0<^e003h7`00na<00=:Q0009S@00045800057P001R0004Y<
01JB003FUP00o0d00?HW0035`P0007hH000Z?0000a/000`V001KB017X`00hW000?l1003^A`00QkD0
001/=@005c00008I000H<000KCD0R;H00>i6003o0P00hW8004:R0000FDT000/U00036`00;Sl0088@
0<Vh003h7`00na<00=6U0003R`0003]500047@00;CP0;9X00=f1003n1@00lCX009^k0000LBh001/c
00026@005Rl006/g08Fe003^AP00o`800>5e000lX00005M:000:900011`003I300280`3?ZP00nQD0
0?PN0039^@00084B000[?@000a/000dW001NA@1GZ000if400?l0003XF`00H:/0001P@`003RP000<J
000Y?000OaD0b;`00?PO003k5@00cjX000271@00D000<d8000<K000;9@00FTP0Bj@00>EX003o0000
jUH006J/0000HD8000hY00036P00:C`0080D0<Vi003i7@00nQP00<ba0000Q0`002ho00036`003BL0
05m405jZ003YFP00o`000>EV001<Y@0005Y8000:900011`003M400:;003BX@00o0l00?DY002h`P00
07LU000N=@000QT001H_001]=02E^@00lCX00?h7003IS@0069<00015BP001Ah000PR001DC00iW`00
hW800?l1003[DP00J:d0001Q@P003RP000<K000_?`00QPP0cjX00?/B003g9@00`<<0001h8`007cD0
008I000G<000Kc40W[/00?<d003m2P00eYL000Z>0000>TD000@L000;9@00FdL0EZP02_ooool1o`00
007ooooo000Nooooo`03o`000?oooooooooo00Oooooo04d000PR00036`008SL006hb06f^003TJP00
oP@00?DZ003</`002hh0001@CP002bD0008J000J<P00Ic`0EJL00=mi003m2@00n2000=6V000JU000
05E;000=9`000QT001L`001S@019Y000gH400?d<003i7000dj00026F0000EdX000hX00026@005Rl0
069104NS003MPP00o@`00?TL003BX@007YH0001FB`003BL0008I000G<000I3l0CjH00=ml003m2@00
mb400<nY000DT@00059=000;9@000QX001`c001Z>01RZ`00hfh00?h5003e;000bKP0006:0000B4`0
00PR00036`0093T0078/086d003YFP00o`000?0n002d`@00080E000f@`0200057P3n000c@P00OQP0
[[l00?10003o0000jEP008:d0000LRd002@i00036`002B<004e>00V=003=/000mb@00?d9003NO000
BZ@0001R@@0052h0008I000A:`00GTD0?:000=^6003m3000n1l00<nY000AT000051>000990000a/0
02<h001b;@24]@00jUH00?l0003^AP00X;`0001i8@00:cd000@L00078@00ADX00XX00>5^003m2000
gWd004JS0000H4<0018/00026@0052h006=0052V003PMP00oPH00?D]0037_P0008H8000mAP001Ql0
00DM000e@P00PA<0_/<00?<e003o0`00hfd005bZ0000ISd001H_00026@004B/005m404FS003NO000
oPL00?DZ0038^`0008H6000mAP001Ql000DN000g@`00P`h0aL800?@_003n1@00h7H004bU0000HD80
018/00026@005Rl006Hm062[003TJ@00o`800?4k002^_`0007/M000/?@0011`000PR001>CP0AT@00
dJ<00?XH003k5000e9/001^D0000DDd000TS00036`00:3`007TQ0:Nm003`?P00o`400>EX001NZP00
06Dn000E;P000QT001@^001U?P1NZP00iFP00?l1003`?`00Y;d0001h8`009SX000<K000:9000E4`0
9YP00=R@003l3P00mb400<bc0000R08003e700057P001Al003i700290@3</P00n2000?`?003GT`00
8IH0001BC@002B<000<K000[?@00O1/0]l400?<d003n1@00ggT004:R0000G4L000hX00026P007cH0
078/09>h003^AP00o`400>EU001NZP0006@o000C;0000QT001Ta001[=P1j/P00jU@00?l0003YF000
Lk00001Y>@005c00008I000E;P00Ic`0Jjh00>QL003o0000je0007jc0000K3D001Ta00026@004bd0
06Dn06F/003WG`00o`000>a>0021]00006`e000I<@000QT001<]001V?@1X[@00j5d00?l0003[DP00
N[80001Z>0005c00008I000F;`00JCX0M;000>YE003o0000j5/006V]0000ISd001<]00026@006S80
06hb08Zf003^A`00o`400>AZ001AYP0005i4000>:@000QX0028h001g9@2[_P00lSH00?h5003MP000
<Y`0001EB`002R@000<L000`@000PPl0bKX00?LR003l4000e9`000n@0000ADX200067`2S0016B`0@
T000e9/00?`?003g9000akd000204`00;Ch000<K000;9@00FDT0@:400>5e003o0P00kd8008ng0000
Kc8001Tb00026@005Rl006Xg082d003]BP00o`400>=]0019Y00005]7000<9P000a/002/m00205038
_@00mb800?/A003BX00028d0000nA`001Ad002`g02JH003KQP00oPH00?8f002T_@0007<[000M=000
0QT001@^001Y>@1m/`00kD/00?l1003RL000@j80001HB@002RD000<L000b@@00QPP0cJl00?XH003i
6`00bk@000233P00;Sl000<K000<9P00G4L0D:H00>EV003o0000jUH006R]0000HT4000lY00036P00
9SX007dJ0<K0003g8`00na800=6V0000R@0003M3000470002R@005Q904BR003SK@00o`000>]B001]
[P0006=0000@:P000QX002Lk001n6037_@00n2000?XE003>[00008H7000a@0000a/000`V001MAP1G
Z000iel00?l0003VH@00DjL0001LA`002bD000<K000d@P00R080dJH00?/A003f9P00`L@0001i8@00
8CL0008I000D;P00JcL0SKL00?0n003n1@00fhP001jE0000BD`000DN00078@00DTd0<Yd00>1g003o
0@00k4d0072_0000Hd0000lY00036P00;3h008<=0<f_003j5@00mb800<G20000NQl0024g00026@00
5Bh006dd09Ji003b>000oPP00=NB000?T00003i700047@002R@005U804nV000:ooooo`7o00000Ooo
ool001kooooo00?o0000ooooooooool01oooool0o`00228000<K000P=P00K3D0IZ`00>9_003n1P00
mRH00<j^000AT000059=000<9P000QX001Ta001U?P1>Y@00gWh00?d;003i7@00dZ40022F0000EdX0
00hX00026@005Bh0065204:R003KQP00o0h00?XI003DV`009iT0001IB@003bT0008I000D;P00H4<0
@:400=^7003l3P00nAT00=BL000TV00005Q:000>:@000QT001H_001R@@18X`00gH400?d;003h7P00
dJ@001VD0000E4`000`V00026P006S8006Pk05^Y003QL`00oPH00?HX003;]0001h`0001<C@002B<0
00<K000R>000L300N[800>MN003o0@00lCT00;c20000PQ0003U500067`0011d00310001l702V_@00
kd@00?l0003ZE000R[H0001d:@009SX000<K00088P00B4`00h/00<^e003f:000oPL00>1g001AYP00
06@o000F;`000QT0010Z001KA`0eW@00fX/00?`>003i6`00dJ@001JB0000DTd000XT00036P0083H0
070`07bc003YFP00o`000>m1002X_P0007/M000^?`0011`000LP0011B@00R0<0gg800?h7003PN000
CJD0001R@@0052d0008I000C;000HD80BJ@00=mk003n1`00mRT00<Vi0000R0<004180006800011d0
0351001n5`2f`@00lST00?l2003UJ000Hj`0001X>`006340008I000@:P00GDH0?Z000=f1003m2@00
mRH00<Zf0000R08004180006800011d003A200204`30``00lc<00?h4003RL@00DjL0001S@0004bd0
008I000D;P00I3l0F:P00>=]003o0`00lSL00;K10000OAT002lo000470001b4004Y<00b>003@Z000
nA/00?/A003FUP008IH0001CC0002R@000<K000V>P00MbD0Wk/00>m2003o0@00iV<006J/0000Ic`0
01H_00026@004bd006=005JX003SK@00o`800?4k002/_`0007XO000Y?0000a/000TT001BC@0PUP00
eYD00?`@003h7P00cJh000:;0000@DP000HO00057P00>dD008L60<Zf003g8`00o0`00=V>000WV@00
05A<000:90000a/002Pk001j7`2__`00lSP00?l3003QM000BJ@0001NA@003bT0008I000M=000L2l0
RkH00>e:003o0000if0006J/0000ISd001@^00026@00l`005c0006Ti07:`003YF000o`000>]C001j
/P0006/f000H<@000QT001<]001U?P1S[000if400?l0003]C000Q[D0001^<P006c<0008I000B;000
Hd00GJX00>IT003o0000kDX008Vf0000Kc8001/c00026@004R`006=0062[003VHP00o`000>a=0021
]00006`e000I<@000QT001@^001W?01][P00jET00?l0003ZEP00LJl0001X>`005Bh0008I000H<@00
K3D0Pk@00>e<003o0000iFH005RX0000HD<0010Z00026P0083H007DX0:>l003a>P00oP@00=mk000i
W`0005M:000;9@000a/002dn00205037_`00mRD00?`>003FV0005I800019C0001R0000DN0012B@0;
SP00dj000?/B003h8000bKT000233`00<40000<K000:9000EdX0>Il00=mi003o0`00l3h009Nj0000
LBl001/c00026@0052h006Pj07Vb003/C`00o`000>EX001@YP0005e6000=9`000aX002Tl001n6@36
`P00mRH00?`?003DV`003Xl00012B@001Ah002/g022F003JR`00oPP00?<b002/_`0007DW000O=P00
0QT001</001W?01e/@00k4l00?l0003TJ`00BZ@0001JB0002bH000<K000_?`00Q0`0bk<00?TK003j
6000cK0000252@00<D4000<K000;9@00FTP0BJ@00>A[003o0000je8006n_0000I3l0014[00026P00
93T007/N0<C4003f9P00o1000=:Q0005R`0003Y5000470002B<005I;03fP003RLP00o`400>a=001e
/@0006Hm000A:`000QX002@i001l7036`P00mb<00?/B003@Y`0008P2000d@P000a/000/U001KA`1@
YP00iV@00?l0003XG@00FZT0001NA@0032H000<K000a@000QPL0cjX00?/D003g8P00aL80001k7@00
8cP0008I000C;@00JCT0QKD00>m2003o1000g8<002BH0000CDh000HO00078000D4h0;9X00=ml003o
0P00kDT007Ra0000ICh0010Z00036P00:C`0084A0<^d003j6000n1h00<Nn0000O1/002<h00026@00
4bd006/g08jg003a?000oPH00=V=000ETP00049900047@002B<005M:04RS000:ooooo`7o00000Ooo
ool001kooooo00?o0000ooooooooool01oooool0o`002B<000<J000M=@00JSP0GZX00>5d003n1`00
mb<00<nY000GT`0005A<000=9`000QT001L`001S@017X`00g8<00?`=003i6P00e9`002JH0000FDT0
00lY00026@0052d005m403^O003JR`00na400?XF003FUP00;I/0001KB00042X0008I000C;000GTD0
>Il00=V<003k4@00nQH00=JG000[VP0005Y8000?:P000QT001@^001P@`11X@00fhH00?`=003i6`00
dil001nF0000ET/000dW00026@00634006Hm05BW003PN000oPP00?LU003=[`0038l0001?CP002R@0
00<J000P=P00KS<0L[000>IS003o0P00lSD00<C40000Q0`003e60006800011d002dn001j802N^`00
kDT00?l0003/C`00T[P0001f9P00:C`000@L00078@00A4X008T10<Vi003e:`00oPD00>5b001HZ000
06Hm000G<0000QT000lY001JB00_V`00f9000?/A003j6@00dil001bE0000E4`000/U00036P007SD0
06hc07F`003WG`00o`400?0m002``00007hI000a@00011d000HO000nA`00QPL0gWH00?h5003QL`00
E:L0001T?`005Bh0008I000A:`00Gd@0@Z800=f0003m2@00mRH00<^d0001RP0004A:0007800011`0
02ho001l6`2^_`00l3d00?l1003VH`00Jjh0001Z>0006S80008I000?:@00FdL0=ih00=^6003m2`00
mb<00<bb0003R`0004A:0007800011d00350001n5`2h`P00lSL00?l3003SK@00FZT0001U?P005Bh0
008I000C;@00HT40DJH00>5b003n1000lc<00;k30000P1D0039100047@001b0004I;00J<003>[@00
n1h00?`?003HT@009iT0001EB`002bD000<J000S>000MBP0UkT00>i6003o0000ieh006f^0000JCT0
01Pa00026@004B/0065204nV003RLP00o`<00?8g002d`@0007`K000/?@000a/000TS001@CP0JU000
eIX00?/B003i6`00cjX000R=0000ADX000HP00057@00=d@008@:0<Rk003f9`00o@X00=Z9000]V`00
05I;000;9@000a/002Hj001h8`2W_@00lC`00?l2003RK`00D:H0001P@`0042X0008I000K<`00KS<0
Pk@00>a>003o0000j5`006f^0000J3/001H_00026@00h@005Bh006Ll06^^003XG@00o`000>a>0022
]00006dd000J<P000QT0018/001S@01LZ@00iFH00?l1003^A`00S[L0001`;`007C@0008I000@:P00
HD80EZP00>AY003o0@00kTD0092h0000LBl001dd00026@004B/0065205VY003UIP00o`000>e90029
]P0006lb000K<`000QT001</001U?P1U[000ieh00?l0003[DP00NK80001Z>0005Rl0008I000G<000
JSP0Nk800>]@003o0000if4005nZ0000Hd40014[00026@007SD007</09^j003`?P00o`<00>1f000o
X@0005U9000;9P000a/002Xm001n6035``00mRT00?d<003GT`006i@0001=CP001b0000DN000nA`05
S000dJD00?/D003h7@00bk@000252P00<d4000@L00098`00ED/0<id00=in003n1000lCX009nl0000
Lb/001dd00026@004b`006Hl076_003ZD`00o`000>IS001HZ00005m4000>:0000aX002Hj001k7@31
a000mBT00?d<003FU`004i400016B`001Ql002Tg01ZD003HT000o@X00?@_002d`@0007PT000Q=`00
0QX0014[001U?P1^[`00jU@00?l0003UIP00DJH0001LAP0032L000<K000/?P00PA40b[P00?PN003j
5P00cj/000271000=D8000@L000:9000F4T0@Z800>9`003o0@00k4d007Na0000Ic`0018/00026@00
8SL007TR0;c2003e:P00o0d00=BL000:SP0003e700047@00228005A<03NN003PM`00o`800>e9001m
/`0006Pk000B;0000QT0028g001j8031a000mRL00?`@003BXP000XX0000gA00011`000XT001IB@19
Y000i6P00?l0003YF000HJ/0001P@`003BP000<K000^?`00Q0/0cJl00?XF003h7`00akd0001m6@00
9CX0008J000A:`00Ic`0OK<00>i6003o0`00gWh002ZJ0000D4h000HP00067`00CTh09YP00=f1003o
0`00kTD007nc0000Ic`0014[00026P009cX007lF0<Vh00020?TK000@0<Vi0000OQL002Hj00026P00
4R`006Tj08Je003`@000oPD00=^9000KU00004E:00057P00228005E;046Q00[ooooo0Ol00001oooo
o`007_ooool00ol0003oooooooooo`07ooooo`0L000:90000aX001/c001X>`1GZ000h7T00?d9003h
8000dJ@001fE0000ET/000hX00026@005Bh00652042Q003KR000o0l00?XG003FU`00;9X0001KB000
4B/0008I000B;000GDH0=Id00=R@0080na<00?l0f94003>M0000GDH0018/00026@004B/005a603>M
003HT@00na<00?/D003GTP00<I`0001LA`004B/0008I000C;000GT@0>Yl00=Z:003l4000nQP00=BK
000UV00005Q:000>:0000QT001H_001T@01=Y@00gWd00?d9003g8@00cjX001:A0000DDd000XU0003
6P007SD006`f06^^003UJ000o`<00?<b0036`00008H70010B0001b0000@L000Z?@00N2@0U[T00>a=
003o0000kD/009Zj0000N28002/m000470001b00045800271P37_P00m2l00?h4003SKP00GjX0001X
>`006C80008I000=:000F4X0:IT00=JE003k4`00nQH00=FJ000RU`0005E;000<9P000QX001`d001[
=P1][P00iV@00?l2003a>@00^<8000205@00=48000DN00067`00>TD008@<0=aj003o1000hfl005^Y
0000ISd001L`00026@0042X005e603bP003LQ000o@/00?LR003=/0001X`00018C000224000@L000/
?@00NQl0Y[d00>m1003o0000ieh007:`0000K3D001`c00026P003BP005U9036L003JR`00o0d00?PP
003>[@0028d00018C0001b4000@L000^?P00O1/0/<000?4k003o0P00iFP006:[0000Ic`001L`0002
6@004R/0061304ZT003PM`00oPD00?@_0035``00088@000e@P001Ad000HP0012B@01RP00c;400?LQ
003l3@00fH`002fK0000EdX000`V00036P008CL007</08ng003]B`00o`000>UJ001e/00006/f000J
<P000QT0010Z001OA018Y000h7L00?h5003c<`00_<<0001n5`00;cl000@L00088P00CTh059800=>O
003j5@00nQP00=6U000=S`0004U<00078@0011d003A200223`36`000mBX00?d9003LQ@00=9d0001H
BP0032H000<J000S>000MRL0Wk/00?10003o0@00i6X005NX0000HT40018/00026@006C8006`e07bb
003[D`00o`000>UG001e/00006Xh000H<0000QT001@]001U?P1S[000iV400?l0003]BP00R[H0001_
<@0073@0008I000@:`00HD80EJL00>A[003o0@00kd<009Ji0000LR`001le00026P003bT005m404nV
003SKP00o`800>m1002H^P0007<[000O=P000QX00=D000lZ001OA01BY`00i6/00?l1003^A000TKP0
001a;`007C@0008I000A:`00Hd40GZX00>IS003o0000k4d0082d0000K3H001Pa00026@005Bh006Pj
07>`003ZE@00o`000>QL001W[@0006Dn000B;0000QT001`c001a;`2C^@00kd800?l2003RLP00AZ<0
001KA`0032L000<J000X>`00O1`0_/<00?D/003m2P00fHh0022F0000D4h000LQ00047@00>dD008X0
0<nY003j5`00nAX00<f_0000Q`D003I3000470002B8005=<02bJ003LP`00oPH00?8f002W_@0007DX
000O=P000QT0014[001T?`1Z[@00jEP00?l0003WG`00GjX0001Q@P003bT0008J000T>@00NB40^L80
0?D]003m2P00f98001VC0000BT`000HO000W=@0DTP00eYD00?d<003e:`00_<80001j800093T0008J
000@:P00Hd00IZ`00>UH003o0000iV8005RX0000GT@000dX00036P00:S`007lE0<Rm003h8@00na<0
0=2V0000RP0003Q4000470002B<005I;03^O003QM000o`400>e9001n/`0006Tj000C;@000QT001lf
001g9@2d`000m2d00?d;003FU`003i000011B0001Ah000PQ001BC@0`W000gg`00?l3003^A000Q;D0
001Z>00052d0008I000P=P00Mb@0^L800?DZ003l3P00did000N<0000>dD000@L00098`00EdX0@Z80
0>=]003o0000jU<006R]0000HT4000hY00036P00:cd0088@0<^d003i6@00nA`00<Vi0000OaD002Pk
00036P0042X006Dn07Ja003]B`00o`800=mi000`W000055=00078@001Al004Y<022F003KQP00oP@0
0?100027]@0006Ti000C;0000QX002@i001m6P38_@00n1h00?XH003;]@00084C000X>`000QX0014[
001W?01n/`00kd@00?l4003LQ0008IH00019C0001Ah000LQ001DC00kW`002_ooool1o`00007ooooo
000Nooooo`03o`000?oooooooooo00Oooooo07P000/U00026P006S8006Hm052V003NOP00o@/00?TM
003CX0008YL0001HBP003bT0008I000D;@00Gd@0>Yl00=V=003k4P00na@00=NB000cW@0005e6000B
;0000QT0014[001KA`0^V`00eYD00?XF003k4@00fH`003ZO0000Gd@001<]00026@0042X005Y802bJ
003FUP00nQH00?/A003IS@00=ih0001NA@004R`0008I000A:`00G4H0=9d00=R?003k4P00nQD00=JF
000[VP0005Y8000?:@000QT001D^001R@P16X`00gH400?d;003h7P00dJD001NC0000Dd`000/V0002
6P0073<006Xh06>/003SK000oP@00?@^0038_00008P20014BP001b4000<L000X>`00MBL0S[L00>]A
003o0000kTH00::l0000Nah002ho00047@001Ql003e600252P35`P00lc<00?l3003TJ@00Ijd0001Z
>0006c<0008J000<9`00ET/08iL00=FJ003j5P00na<00=JE000XV@0005M:000=9`000QX001Xb001Y
>@1V[000i6P00?l2003b=@00`<<000224000=d@200057P3o000g@`00PQ40fG`00?l3003TJP00HZ/0
001X>`006C40008I000?:@00FdP0=Id00=Z9003l3@00n1l00<n[000;SP0004a=00088P000a/002Tl
001h8`2N^`00kTD00?l0003YFP00N[80001^<`007SD0008J000<9`00EdX0:iX00=R@003l3`00nA`0
0=2X000=S`0004a=00088P000a`002/m001j7`2X_P00l3l00?l1003VH`00JJd0001Y>P006340008I
000@:P00GTD0A:800=ml003n1`00mB`00<No0000Q0`003Q400057P001Ql003i700280`3:]P00mbD0
0?d;003KQ`00<id0001IB@003BL0008J000O=P00L2l0QkD00>a?003o0000jUD007bb0000KC@001`c
00026@003bT005e604:R003OO000oPH00?@_0034a000080C000b@@0011`000LQ001;C@0?T000dJ@0
0?XG003j5@00dj0001>A0000CDh000PQ00047000<D00080C0<G4003d;P00oPL00=f0000jW`0005Y8
000=9`000aX0024g001d:P2G^@00kd@00?l1003UIP00GZX0001T?`004bd0008I000H<000JSP0M;00
0>UG003o0000je<007bb0000K3D001Tb00026@004R`006=005bZ003UIP00o`400>i6002B^000078]
000N=@000QX000lY001OA01>Y@00hVl00?l2003`?`00W[/0001e:@008CL0008J000>:000GDH0B:@0
0>5c003o0`00l3d00:2l0000MBP0024g00026P003RP005e504^T003RL000o`800?10002I^P0007</
000O=@000QT0010Z001Q@`1GZ000iFL00?l0003]B@00R;H0001^<`006S80008I000D;@00ISd0K:h0
0>UI003o0000jEP006j_0000Ic`001@]00026@006S8006hb08^g003^AP00o`400>=]001=Y@0005e6
000=:0000aX002Di001j802f`@00m3000?h8003JR@009YP0001BC@00228000@M000gA000R0@0cJh0
0?TI003j5`00cj/000290000>DD000@M00088P00DDd09YP00=^8003n1`00lc800:no0000MbD0024g
00026P0042X0069106:[003XG000o`000>UJ001V[00006=0000A:`000QX0024g001g902a`000m300
0?d9003IS@007iH0001>CP001b0002@d00n@003EVP00o0h0001i0?HW0034a00007`L000V>P000aX0
00lY001Q@P1OZP00j5d00?l0003XG@00GjX0001P@`003RT000<J000W>`00OAT0a/400?LT003l4@00
dZ4000F<0000>dH000@M00088P00E4`0=Id00=mi003o0P00kT@008Je0000JcL001D^00026@007C@0
07@Y0:bo003d<@00o@T00=NB000ETP0004E:00057P001b40051=02ZJ003MP000o`@00?10002<]`00
06`f000E;`000QT001he001e9`2a`000m2h00?d<003EV@0038l0000nA`0011d000TR001EB`0lX000
hW800?l1003/C`00L:l0001T?`0042X000<J000X>`00P1@0bKP00?TL003i6@00bk@000224@00:Sd0
00<J000?:@00Hd00KZl00>a?003o0@00hG@003NN0000Dd`000PQ00057P00AT/06Y@00=Z;003n1P00
lC`008ng0000JcH001@^00026@008SL007/N0<K1003h8@00nQH00<f`0000P`h002/m00036P003bX0
06Dn07Na003]B@00o`800=io000WV00004e>00067`001b00059=03BM000:ooooo`7o00000Oooool0
01kooooo00?o0000ooooooooool01oooool0]P0032H0008J000H<@00I3l0BJ@00=f2003l3@00nAX0
0=BK000XV@0005Y8000@:P000QT0018/001MAP0cW@00ei800?/D003k4P00fHd003VO0000Gd@001<]
00026@0042X005U902RI003EVP00nQP00?`?003KQ`00@:40001Q@`0052h0008I000?:@00F4T09YP0
0=BK003j6000o0l00=^8000nX0000613000C;@000QT0010Z001KB00^V`00ei@00?/D003k4`00f940
03:L0000G4L0014[00026@004bd0061303nQ003KQP00o0d00?TK003BX@007ID0001EB`0032L0008J
000J<P00J3/0G:X00>9a003n1@00mBX00<Zg0002RP0004Q<00088P000a/002Dj001c:`27]@00jUH0
0?l0003_@P00Z[h0001m6P00<D0000DM00067`00>TD0088?0<33003b=`00o`800>IT001^[`0006`e
000M=0000QX000/V001DC00MU@00dil00?XH003k4@00f90002jK0000FDT000hX00026@00634006Lk
05nZ003SK@00o`@00?<a0035`P0008@<000kA@001Ql000DM000d@P00OaD0eGh00?l2003UI@00JJd0
001Z>0006S80008I000>:000FDT0;i/00=V>003l3`00nA`00=2V000AT00004m>00098`000a/002Hj
001f9`2F^@00kDT00?l0003ZE@00PK@0001`<00083H000<J000;9P00ED/09IP00=JE003k4@00nAX0
0=6T000CT@0004m>00098`000a/002Pk001h8`2P_000kd<00?l0003WG`00L:l0001[=`006S80008I
000?:@00G4H0?J000=f1003m2000mRP00<Vj0000QPL003]60P001Ah0o`00>dD008H80<Vk003f:000
o@T00=b2000jW`0005]8000>:0000QX001dd001^<P20/`00jU<00?l0003[D@00Q;@0001_<@007SD0
008J000>:000FdL0>il00=f0003n2000mB/00<K00000PPl003E200047@001b0004M;00V=003@Z000
nAX00?/C003DV`0069<0001@CP00228000@L000^?`00OQP0_L<00?<a003n1@00gg/0046Q0000G4L0
00hX00026P007cH0078]08nh003]B000o`000>MQ001U[00006Hm000E;P000QT001H_001X>`1][P00
j5`00?l0003/CP00Q;@0001^<`006c<0008I000A:`00HD80EJL00>A[003o0@00kd8009Vj0000M2X0
020f00026P003RP005e604NS003QM000o`<00?4k002V_@0007LU000S>0000aX000dW001KA`12X@00
h7L00?l4003a>@00Z;h0001g9@008cP000<J000=9`00G4L0AJ800>5e003o0`00lC`00:6l0000MBP0
024g00026P003bT005m4052V003SK000o`400>i5002?^000070`000L<`000QT0018/001T?`1U[000
j5h00?l0003ZD`00MK40001Y>P005Bl0008I000H<@00K3D0Q;D00>e:003o0000i6P005BW0000Gd@0
00lY00026P008cP007LT0:jo003c=000oPH00=b4000/VP0005=<00098`0011`003A20025203</`00
nA`00?XE003@YP0018/0000mAP001Ad000LQ001?CP0PUP00fHd00?d9003d;`00]l40001i8@0093T0
008J000?:@00H4<0FjT00>MQ003o0000jUD006f^0000ICh0018/00026@007cH007DX0:Vn003c=000
oPL00=^8000UV000051>00078@008S<02Hd00=>O003l4000mb@00<K00000OQP002Pl00036P003RP0
05m405RX003VH@00o`000>UH001V[0000691000@:P000QX002Di001k7@33a000mRL00?`>003DW@00
2Xh0000oA`001Ad000PR001BC@0_V`00gWh00?l3003`@000SKL0001]=@005Rl0008I000K<`00LR`0
Y;d00?<e003n2000fHd001ZD0000BD`000HO00068000Cdh099P00=b5003n1@00lC`009Bi0000KS<0
01L`00026@0073<007<[0:Vn003c<@00o@X00=ND000BT@00049900057P00=`00228005=<03FM003P
M`00o`400>e;001g/@0006Hm000A:`000QX002Hj001n6@38_@00n1l00?XF003=/00008@<000]?P00
0aX000hX001Q@P1W[@00jU@00?l0003RK`00?J00001EB`00228000DM0012B@0DTP00f8l00?h7003b
>000U[T0001]=0005Rl0008I000P=P00NB80`/@00?LT003k4`00cZ/000252P00;Sl000<J000>:@00
Hd40Kjl00>a=003o0P00ggX002fK0000D4h00P001R000`00D4h0;Y/0ooooo`09ooooo`7o00000Ooo
ool001kooooo00?o0000ooooooooool01oooool0F0003BL0008I000F;`00HT40@j800=^7003l3`00
nQL00=JF000^V`0005a7000A:`000QT0014[001KA`0]V`00eYH00?XG003l4000fhT003nQ0000HD<0
01D^00026@003RT005M:02:G003CW`00nA/00?`=003LPP00Aj<0001R@@005Rl0008I000>:000EdX0
89H00=>O003i6`00o0d00=b40014XP000652000E;P000QT000lY001IB@0XV@00eIT00?XG003l4000
fH`003RN0000GDD0018/00026@004R`005i503VO003JR`00o1000?XH003DW0008iL0001GBP003BP0
008I000H<@00ISd0EJP00>1f003n1`00mRL00<bc0007S@0004a=00098`000a/002<h001a;P1o/`00
j5X00?l0003`?P00//00001o5P00=48200057P3o000f@`00P1<0^<800?4j003o0@00if0007Fa0000
KS<001lf00036P002bD0059=01NC003AX`00nA/00?`?003JS000=9d0001KA`003bX0008I000G<000
ICd0F:P00>9b003n1@00m2h00<Nn0000QPL003i700067`0011d00350001m6@3@O`00o`400>MQ001a
[`0006`e000L=0000QX000dW001GBP0YV@00ei<00?/A003i6@00dZ8001JC0000DDd000XT00036`00
93T007@Z08ng003/CP00o`000>]A0029]P00078]000R=`000aX000/U001CC00OUP00eIX00?/D003j
5`00dil001RC0000DDd000TT00036`009SX007HW09Rj003^A`00o`000>UJ001g/@0006dd000L<`00
0QX000hX001JB00gWP00g8H00?d:003g9@00b[H000280P00?dL000HO00057P00>4@008@<0<No003e
:`00oPL00=in0010X@0005e6000?:@000QT001/c001/=@1h/@00jEP00?l0003/C@00RkH0001a;P00
83H0008J000=9`00FDT0=Id00=b5003m2@00mRP00<Rl0000Q@X003Q400057P001R0004=900B;003>
[@00n1d00?`@003FUP007YD0001AC@002B<000<K000[?@00O1`0]L400?8e003n1000h7H004NS0000
GTD000lY00026@007C@0070`08Rf003/C000o`000>QM001][P0006Pk000F;`000QT001D^001V?@1V
[000if000?l0003]BP00RkH0001`<0007C@0008I000@:P00Gd@0CZD00>9_003o0P00l3h00:6l0000
MRL002<h00036P003BL005]7042Q003PN@00oP@00?8g002]_`0007TR000V>P000aX000`V001IB@0k
W`00gg`00?h5003b=@00/<00001i8@009SX000<J000<9P00FTP0?Z000=mi003n1000lSP00:Rn0000
MbD002<h00036P003RP005e604VT003RL@00o`800>m1002G^P00078]000N=@000QT0014[001R@@1N
ZP00iV800?l0003/C`00OK<0001[=`005c00008I000G<000JSL0O;<00>a?003o0000iV@005ZY0000
HD80010Z00026P008CL007DW0:Nm003b=`00oPD00=eo000cW@0005E;000:900011`0035000233@3:
]`00n1l00?/B003BX@002Hd00010B0001Ah000LP001:001=CP0JU000f9800?d;003e:`00_l<0001k
7@009SX000<J000>:000GTD0E:L00>EV003o0000je4007B`0000Ic`001<]00026@007C@007<[0:6l
003b>000oPD00=b3000ZVP00059=00088P00838018/00=6S003k4P00n2400<Rl0000P1@002/m0003
6`003BL005e6056V003UIP00o`000>YD001][P0006@o000A:`000QX0028h001i8@2k`P00mB/00?d<
003EV00049000012B@001Ah000LQ001@C@0XV@00g8<00?h5003a?000UKT0001_<P006340008I000I
<P00L2l0W;/00?8h003n1P00fhT0022F0000CDh200067`1=001;C@0NU@00fXX00?h6003b>000Vk/0
001`<0006C40008I000J<P00LBh0XK`00?8e003n2000f8l001NC0000ATX000DN00078@00DTd0;i/0
0=mk003o0P00kTH007nc0000J3/0018/00026P0093T007`M0<K1003g8P00na@00<n[0000QPP00310
00036`003BL005m4062[003YF000o`000>A[0014XP0005M:00098`0011d003m700n@003GU000o@T0
0?<e002N^`0006la000G<0000QT001he001g9@2j`P00mRL00?/A003@Y`0008L5000a@0000a/000dW
001Q@P1X[@00je400?l1003QM@00<id0001BC@001b0000HO001>CP0XV@002_ooool1o`00007ooooo
000Nooooo`03o`000?oooooooooo00Oooooo05P000hX00026@005Bh0061303bP003IS000na800?/D
003HT@00=Id0001NA@004b`0008I000@:P00FDT09iT00=BK003i6P00o0d00=b40016X`000691000F
;`000QT000dX001FB`0MU@00dJ<00?PN003m2`00gWh004fU0000I3l001P`00026@003BL005E;01^D
003AY000n1h00?d;003NO`00Bj@0001S@0005c00008I000>:000EdX08YL00=>N003i6P00o0h00=^8
000nX00005m4000C;@000QT0014[001LA`0cW@00f9000?/B003j5P00eYL002VI0000F4T000hY0002
6@005Rl006@o04nU003ON`00o@P00?LT003=[P0038l0001?CP002B@000<J000Q=`00Kc40N;400>MO
003o0@00lCX00;W20000PA8003M40P001Ah0o@00<d8007hG0;30003`?P00o`000>QK001l/`00070`
000Q=`000aX000XT001@CP0BT@00d:P00?PN003l3000fhL003^O0000GDH0014[00026@005Bh006=0
056V003PMP00oPH00?DZ0039^P0008P20012B@001b0000@L000^?`00Nad0c8000?l0003XG000N;40
001^<`007SD0008J000<9P00ED/08iL00=JH003k5000nQH00=BM000LU@0005=<000:9@000aX0028g
001b;@27]@00je800?l0003/C@00T;P0001d:@0093T000<K000:9000DTd06I@00=>N003j5P00na@0
0=FJ000NU@0005=<000:90000aX002<h001d:P2A^000kD/00?l0003ZEP00Ok<0001_<P007SD0008J
000=9`00F4T0<I`00=Z:003m3000mb800<bb0001RP0004990006800011d003A200224@35``00m2l0
0?h6003ON@00Aj<0001NA00042X0008I000I<P00JSL0LJl00>QL003o0000kDP009>h0000LbX0028g
00036P0032H005M:02nK003JRP00o@/00?LU003:]`0008L6000kAP001Ah000HO000oA`00R@00c;40
0?PP003l3P00ei8002BG0000Dd`000XT00036`00:C`007XO0:jo003a>@00o`<00>9b001>Y@000613
000@:P000QT001/c001^<`20]000je400?l0003YF000M;00001Z>0006300008I000C;@00I3l0GjX0
0>EU003o0@00kTH009>h0000LRd001lf00026P003RT005e604RS003QM000o`<00?4j002Y_P0007PS
000U>@000aX000`V001IB@0jW`00gWd00?h5003c<`00]L40001k7P00:3/000<K000;9@00EdX0=Id0
0=f1003n1P00lc400;S10000Nad002Pk00036`002bD005Q:03RN003NOP00oPD00?<e002``00007TQ
000U>P000aX000dW001KA`13XP00hGD00?l3003`?@00Wk/0001d:P0083H0008J000@:P00H4<0EjP0
0>EW003o0000kD/008Be0000KCD001Pa00026@005Bh006Pj07Fa003[D`00o`000>MO001QZ`0006=0
000A:`000QT001he001c:`2O^`00lC/00?l4003ON`00>Il0001GBP002RD000<K000^?`00PA40b;`0
0?LR003l4000e9d000j?0000A4X00P001Ql0V@00BD`05I800=JF003l3@00mRP00<G30000OAT002Tl
00036P003BL005a604jU003TJP00o`000>a=001l/P0006Ti000E;P000QT001/c001a;P2J^P00lC`0
0?h4003NO`00<I`0001DC0002B8001h`0029003@Z000naD00?PN003:]`00088@000^?`000a/000`V
001KA`1;Y000i6/00?l0003[D000M;00001V?0004R`0008I000P=P00MbD0/l000?@^003m2P00ei<0
01FB0000AT/000DN00078000Cdh08iL00=^7003n1P00lSP009fk0000LBl001Xb00026@00630006hb
09Bi003a?000oPD00=b4000VV00004m>000780001Al004M;01RC003IS`00oPP00?<d002S_000078]
000J<P000QT001Pa001_<@2I^P00lST00?h6003JRP007ID00019C0001Ql000LP001@CP0YV@00gH00
0?l3003_@P00Q[D0001Z>0004bd0008I000Q=`00NB00`/@00?LU003k4@00d:L000280`00<d4000<K
000<9P00GDH0FJT00>QL003o0000iFH004ZT0000FDT000XT00047000>dH02Xh00=FI003m2`00m340
0:Jm0000LBh001Ta00026@0073<007DY0;;0003e:`00o0h00=:R0000R@0003A200036`0032H005m4
066[003ZE@00o`000>9a000iW`0005=<00078@001Ah004Y<02:G000:ooooo`7o00000Oooool001ko
oooo00?o0000ooooooooool01oooool0o`003bT0008I000C;@00GTD0=Yh00=R@003k5000na800=V=
000kW`0005m4000D;P000QT000lY001GBP0RU`00dj000?TL003m2`00gWl004bU0000I3l001Pa0002
6@0032L005A<01NC003@Z000mb400?d9003ON@00E:L0001V?0006C80008J000<9P00Dd`05I800<nY
003g8@00o@T00=mj001AYP0006Dn000H<@000QT000dW001EB`0LU@00dZ800?TM003m3000g8<004FR
0000HD8001D^00026@003bX005Y802fK003GU000na@00?/C003GT`00;Y/0001JB00042X0008I000E
;P00HT40B:<00=io003m2P00n2400<nZ000AT@00055=000:90000aX001le001]=01a[`00iV<00?l2
003b=P00`L@000233P00>TD000HO00047@00<40007`K0:Vn003_@P00o`000>UG0024]000078]000S
>0000a/000TS001>CP0<S`00cZ`00?LQ003m2`00gH80046Q0000Gd@0018/00026@0052d0069204ZT
003ON`00oPP00?HW003;]@000HX00015BP001b4000@L000[?@00NB40b8400?l0003YF000Ok<0001`
<00083H000<J000;9@00Dd`07ID00=BL003j5P00na@00=FH000RU`0005A<000;9P000aX0020f001`
<020/`00jUH00?l0003]B000V;X0001f9P009SX000<K00098`00D4h059800=:S003i6@00na800=JF
000SU`0005E;000;9@000aX0024g001b;@29]P00je000?l0003[D@00Q[D0001a;`0083H000<J000<
9P00ETX0:iX00=R?003l3P00n1l00<j]0006S00004I;0007800011d0035100205@2o``00lc<00?h4
003QM000CJD0001P@`004B/0008I000H<000J3X0JZh00>MQ003o0000kd@009Zj0000MBL002@i0003
6P002bD005E;02VI003ISP00o0d00?LQ003</`0008T1000oA`001Ql000DN000lAP00Q`@0b[H00?LS
003m3000fHd002VI0000ED/000/U00036`009SX007PS0:Jm003`?@00o`800>=]001DY`000652000B
:`000QT001Tb001/=P1i/P00jUD00?l0003ZE000Nk80001/=@006C80008I000B;000HT40F:P00>AZ
003o0@00kd8009Zj0000M2T0024g00026P00F0003BP005]7046Q003PN@00oP@00?8f002``00007XP
000W>`000a/000/U001GBP0dW@00gH800?h7003d<000_L<0001m6P00:cd000<K000:9000ED/0;i/0
0=b5003n2000m2h00;o30000OAT002/m00036`002RD005I;03:L003LP`00oPL00?@a002h`@0007/N
000X>`000aX000`V001IB@0lX000ggX00?h4003b>@00Y[d0001f9P008SL0008J000>:@00GTD0D:H0
0>A[003o0@00kTH008^g0000Kc8001Xb00026@0052d006Hl06j_003YE`00o`000>QK001X[@0006Dn
000B;0000QT001`d001a;P2G^P00l3l00?l3003PMP00?j40001IB@002bD000<K000/?@00OaD0a/00
0?HV003l3P00eIP001>A0000B4/200067`0g0015BP0@T000e9/00?`?003g9000akl0001o5@00:cd0
00<K000<9P00FdP0Aj<00>=_003o0@00kDT008>d0000JcL001H_00026@006C8006la09:h003`@000
o`<00=mj000gWP0005E;00098`007C0008L40<j]003j5`00nA/00<bc0000Q0/0035000036`002bD0
05U904BR003RK`00o`400>e;001k/P0006Pj000D;@000QT001he001e:02[_P00lc800?d9003IS`00
6Y@0001:C00200067`0T001;C@0MU@00fH`00?h8003c=@00Y;d0001c;00073<0008I000F;`00K3D0
SKL00?10003o1000gWl002bJ0000DDd000LQ00057P00A4T04i400=NC003m2P00m3400:^n0000M2X0
01`d00026@005Rl006dd09:h003a?@00oPD00=^6000RU`0004e>0P001Ql0>P00CTh08iL00=b5003n
1@00l3h008fg0000K3H001D^00026@007cH007LT0;_2003f:000o0l00=:R0001RP0003I300047000
2bD005]705:W003WH@00o`000>IR001AYP0005]8000;9@0011`003Q400F;003CWP00o0d00?@]002]
_`0007<[000K<`000QT001Xb001c;02[_P00m2h00?`<003CWP0018/0000g@`000a`000/V001MAP1J
Z@00jEX00?l0003SK000@:40001EB`00228000DN0016B`0LU@0:ooooo`7o00000Oooool001kooooo
00?o0000ooooooooool01oooool0o`0042X0008I000B;000G4H0<9`00=JE003j5P00o1000=^80011
X@000652000E;`000QT000hX001FB`0LU@00dJ@00?PO003m2P00gg/005>W0000IS`001Tb00026P00
2bH0059=01:A003>[000mb@00?h7003QM@00FjT0001X>P006c<0008J000;9@00DDd049000<j]003g
9000oPL00>1f001HZ00006Lk000J<P000QX000`V001CC00GT`00d:L00?PP003m2P00gWh004^T0000
Hd0001H_00026@003RT005Q902NH003EV@00nQL00?/A003ISP00=9d0001LAP004B/0008I000C;@00
H4<0@Z400=b4003m3000n1h00=6U000GT`0005==000;9@000QX001dd001[=P1Z[@00iFP00?l3003c
<`00aL8000252@00?TL000HP00047@00;Sh007XO0:6l003^AP00o`000>]C002;]P0007@Y000V>P00
0a/000PR001;C@07S@00c;400?LT003m2@00gWh004NS0000HD8001<]00026@004R`0061304BR003M
P000o@T00?LT003</@001X`00019C000228000<K000Y?000Mb@0`h800?l0003ZD`00Q[D0001b;@00
8SP000<J000:9000DDd069<00=:Q003j6@00na800=ND000WV@0005I;000<9P000QX001he001^<`1i
/P00j5/00?l0003^A000Wk`0001h8`00:C`000<K00088P00CTh03i000=2W003i7000o1000=RA000Y
V@0005I:000<9P000QX001lf001`<022]000jU@00?l0003/C@00SKL0001c;0008SP000<J000;9@00
ED/09IP00=ND003l4000nA`00<nY000;SP0004Y<00078@0011`002lo001n6@2g`@00lSH00?l3003R
L000E:L0001R@@004bd0008I000F;`00IS`0Hj`00>EU003o0@00l4000::l0000Mb@002Hj00036`00
2R@005=<02>G003GT`00o0l00?PN003=[P000h/00012B@001Ql000DN000iA000Q@T0bKX00?HV003m
2P00fhP002nK0000EdX000/V00036P0093T007HV09jk003_@@00o`400>AX001KZ@0006=0000C;@00
0QT001P`001Z>@1b/000jET00?l0003[D000P[@0001^<`006c<0008I000@:`00H4<0DJH00>=^003o
0P00l3h00::l0000MRH002<h00036P00l`0032L005U803^O003NO@00oPH00?<b002h`P0007`L000Z
?0000a/000XT001EB`0^V`00fhL00?d9003e;000a<@0001o5P00;Ch000<K00098`00E4`0:IT00=Z:
003m2P00mBX00<G30000OaD002dn00036`002R@005A<02bJ003KQ`00o@P00?@]0030``0007dJ000Z
?@000a/000/U001GBP0fWP00gWl00?h5003b=@00[[l0001h8`0093T000<J000=:000G4H0BZ@00>9`
003o0P00kd8009>h0000LBl001`d00026@004R`006Dn06N]003XG000o`000>YF001_[`0006Ll000D
;@000QT001/c001_<@2@^000kd<00?l2003RL@00AJ<0001KB00032H000<K000Y?000OAT0aL@00?HY
003m3000ei<001VC0000Bdd000LP00057P00@DP02Xh00=>P003k4@00mb400<Vk0000PA4002ho0003
6`002bD005U9046Q003QL`00o`800>i5002:]P0006dd000H<0000QT001P`001]=02;]P00kd@00?l2
003QM@00?J00001GBP002R@001/_00252@3</@00nAX00?XH003=[`0008H7000d@P0011`000XT001G
BP0nX000hG@00?l2003^A`00Pk@0001Z>0005Bh0008I000L=000Lb/0Y;d00?8f003n1`00fXX0022F
0000CTh000HP00067`00Ad/05i<00=RA003m2@00m3400:bo0000MBP001he00026@005Bh006Xh08Je
003_A000o`<00=mk000bW00005=<00088P001Ad0041800j?003EV000o@`00?@]002b`00007HW000N
=@000QT001D^001[=P2:]P00kd400?l4003MP@00:9T0001@CP001b0000HO001:C00MU@00fXT00?h6
003a>`00UKT0001^<`005Rl0008I000M=000MBL0/l000?D/003l3@00did000J<0000>D@000@L000:
9000FDT0C:D00>EU003o0000j5d005RX0000GDH000/V00036`00=D8008T00=:R003l3`00mBX00;G1
0000MBL001dd00026@006340074_0:>m003c<P00o@/00=FI0009S@0003Y5000470002RD005]705BW
003WGP00o`000>EX0016X`0005M:00098`001Ad0049901NC000:ooooo`7o00000Oooool001kooooo
00?o0000ooooooooool01oooool0o`004B/0008I000A:`00FTP0:YX00=FJ003i6@00o0h00=b30017
X`0006=0000G<0000QT000dW001DC00GT`00cjT00?LR003n2000h7H005ZY0000J3X001/c00026P00
2bD0051>00b?003</@00mRL00?h6003RL000HZ/0001Z>0007C@000<J000:9000Cdh02hh00<ba003f
:000oPH00>9a001OZP0006Ti000L<`000QX000/U001AC@0AT@00cj/00?LS003m2@00ggX0056V0000
ICh001P`00026@003BP005I;026F003CWP00nAT00?`?003JR@00>il0001NA@004R`0008I000B;000
GTD0>il00=^8003l3P00nA/00=:Q000LU@0005A<000<9P000QX001/c001Y>@1SZ`00hf`00?l4003d
;`00akh000271@00@DP000LP00047000:cd007PS09Zj003]BP00o`000>a>002B^00007HV000X>`00
0a/000PQ0017B`02R`00bkD00?HX003n1`00ggT004jU0000Hd0001D^00026@004B/005i503jP003L
Q000o@/00?PQ003>[0002hh0001=CP002B8000<K000V>P00MBP0_h<00?l0003/C`00S[L0001d:P00
9CT000<K00098`00D4h04Y400=6U003i6`00o0l00=R?000]V`0005Q9000=9`000QX001`c001/=P1a
/000iel00?l1003`@000Ykd0001j7`00:cd000@L00088@00BT`02Hh00<j/003h7`00o0d00=V<000_
V`0005Q9000=9`000QX001dd001^<`1k/P00jEP00?l0003]B@00UKT0001e:00093T000<K000:9000
Dd`07iH00=FH003k4`00nAT00=6T000AT00004i>00088P0011`002`n001k7@2__`00lCX00?l2003T
J`00FZT0001T?`0052h0008I000D;P00ICh0G:X00>AZ003o0P00lC`00:Vn0000NB0002Tl00036`00
2B<0059=01fE003FV000na400?TL003?ZP0028d00016BP001b0000@M000e@`00P`d0akh00?DZ003m
2@00g8@003FM0000FDT000`W00036P008SL007@Z09Ni003^A@00o`400>IT001RZ`0006Dn000D;P00
0QT001H_001X>`1[[P00j5h00?l0003]B`00RKH0001`<0007C@0008I000?:@00GTD0Bj@00>5c003o
0`00lCX00:Vn0000N2<002Hj00036P00l`0032H005Q:03FM003MPP00oPL00?@_0030``0007hH000/
?P000a/000XT001DC00XV@00fX/00?d:003f:@00a/0000214P00<40000@L00098`00DTd08iL00=V?
003m2`00mRL00<No0000PA400310000470002B<0059=02JH003IS000o@X00?DZ0035``0007lF000]
?P000a/000XT001EB`0`W000g8<00?h7003c<P00]/40001j7`009SX000<J000<9`00FdP0@j800>5d
003o0`00l3l009Zj0000Lb`001he00026@004B/006=0062[003WH000o`000>]B001f/@0006Tj000E
;P000QT001Ta001]<`29]P00kTL00?l1003SK@00C:D0001MAP003BL000<J000W>P00Nad0_L<00?D/
003m2P00f8l001jE0000Cdh000LQ00057P00?TL01H`00=6T003k4`00n1h00<Zf0000P`d003500003
6`002R@005M:03ZO003PN000o`<00>m1002B^00006la000I<P000QT001H_001[=`24]000kTP00?l1
003RL@00@j80001IB@002bD001T]00233@3;]@00nAd00?XF003?ZP0008P2000g@`0011`000TS001E
B`0hWP00h7P00?l2003_@`00R[H0001/=@005Rl0008I000J<P00LBh0W;/00?4i003n1P00g8D002JH
0000D4h000LQ00057P00A4X04Y400=JE003m2`00m2h00;?00000MbD0020f00026@004bd006Pj07jc
003]B000o`800>1f000hWP0005E;00098P0011d003e600V=003DW000o0d00?DZ002j`P0007PS000P
=P000QT001<]001Y>@23]000kTD00?l3003NO@00;Y/0001AC@001b4000DN0016B`0HT`00fHh00?h7
003b=`00W;/0001`<0006340008I000K<`00Lb/0Zkl00?@_003m2`00eIT000^>0000?4H000@M0009
8`00F4X0AJ<00>AZ003o0000jET005jZ0000GT@000`W00036`00<T4008L40=2W003k4@00mRL00;g3
0000Mb@001he00026@005c0006lb09bk003b=@00o@T00=ND000>S`0003e6000470002R@005U904fU
003VH`00o`000>IS001<Y@0005U900098`0011d003m7016A000:ooooo`7o00000Oooool001kooooo
00?o0000ooooooooool01oooool0o`004b`0008I000?:P00FDT099P00=>N003i7000o@`00=io001>
Y@0006Dn000I<@000QX000`V001BC@0AT@00cZd00?HU003n1P00hW80062[0000JSP001dd00036P00
2R@004m>00R=003;]@00mB/00?h4003SK000J:d0001/=@007cD000<J00098`00CDh01X`00<Zf003e
:`00oPD00>=]001V[00006/g000M=@000aX000XT001@CP0<S`00cJl00?HV003n1`00hGD005RX0000
Ic`001Tb00026P0032L005A<01bD003BXP00nA`00?`=003LQ@00@J40001P@`004bd0008I000A:`00
G4H0=Id00=V=003l4000nQP00=BL000RU`0005I;000=9`000QT001Tb001W>`1LZP00hW400?h5003e
;000bKX000290000ADX000LQ00047000:3/007HV09:h003/CP00o`000>e:002J^P0007PS000[?@00
11`000LQ0013B@00R@40bKT00?D[003n1P00hG@005BW0000ICh001H_00026@0042X005a703RN003J
R@00o0d00?PN003@Z0004900001?CP002B<000<K000T>@00Lb/0^h@00?l0003]B`00UKT0001f9P00
9c/000<K00098P00CTh03Hl00<nZ003h7P00o0d00=Z;000cW@0005Y8000>:0000QT001Xb001Z>01[
[P00iV<00?l1003a?@00[[l0001l6`00;Sl000@L00078@00AT/01H/00<f`003g8P00o@`00=^8000e
W@0005Y8000>:0000QT001/c001/=@1d/000j5`00?l0003^A@00W;/0001g9@009cX000<K00098`00
DDd06Y@00=BM003j5@00nQL00=>P000FTP00051>00098`000a/002Tl001j802X_P00l3h00?l1003U
I`00HJ/0001V?@005Rl0008I000C;@00Hd00EZP00>=^003o0`00lST00;700000Nad002/m00036`00
2B<0051>01RC003DW000na@00?TI003AYP003Hl00019C0001b4000@M000c@@00PA80aL<00?D]003n
1`00gGl003^O0000FTP000dX00026P0083H0078]092h003]B@00o`000>MP001Y[@0006Ll000F;`00
0QT001D^001V?@1T[000iV800?l0003^A`00TKP0001b;@007cH0008J000>:000G4H0A:800>1g003n
1000lSH00;700000NQl002Pk00036`00l`002bD005I;02nK003KQP00o@T00?D[0035``00080D000_
?`0011`000TS001BC@0RU`00f9000?d<003f9@00b;`000233P00<d4000@L00088P00D4h07YD00=NC
003l3@00mb@00<Vk0000P`d003=1000470002280055=022F003HT000o@`00?HW0037_`00084B000_
?`0011`000TS001DC00ZVP00fhP00?d8003d;P00_L<0001l7000:C`000<K000<9P00FDT0?J000=mi
003o1000lC/00::l0000MBT0020f00026P0042X0065205ZY003VI000o`000>a>001m/`0006/g000G
<0000QT001L`001/=P21]000kD/00?l0003TJ000DZL0001NA@003RP000<J000T>@00NB40]/400?@`
003m2000fXX002BG0000D4d000PQ00047@00>TD00HX00<nY003j5P00nA/00<bb0000Q@P003=20004
70002B<005E;03BM003NO000o`@00?0m002I^P00074^000K<`000QT001D^001Y>@1m/`00k4`00?l1
003SK000BJ@0001KA`0032H001P]00214P39^P00n2000?/C003AYP000XX0000jA@0011d000PR001D
C00bW000gWd00?l3003`?`00TKP0001^<`006340008I000I<@00Kc40UKT00?0m003n1000gH4002^J
0000DDd000PQ00057P00@4P03Hl00=FJ003l3@00mBX00;_20000NB80028g00026@004R`006Ll07Na
003/C000o`400>9b000nX00005I:00098`0011`003U500B;003BX@00o1000?HW0031a00007XP000R
>0000QT0018/001W>`1l/P00kDT00?l2003PN000=9d0001CC000228000DN0012B@0CT@00ei800?d9
003c<`00Y;d0001a;P006S80008I000J<P00LBh0Y;d00?<c003m2@00ei@0012@0000@4P000@M0009
8`00ET/0?j400>=^003o0000jUD006F/0000H4<000dX00036`00;cl008D80<n[003k4`00mb@00<C4
0000NB40020g00026@005Bh006de09Bi003a>@00oPL00=R@000CT@00041800047@002B<005M:04NS
003UI`00o`000>MO001CY`0005]8000:900011`003a600b?000:ooooo`7o00000Oooool001kooooo
0ol00007ooooo`3@000D;@000QT000hY001GBP0OUP00dZ<00?PO003m2P00ggX005BW0000Ic`001Xb
00026P002bD0051=00b?003</P00mRT00?h5003SK@00Ijd0001/=@007cH000<J00098`00Bdd00h/0
0<Vi003d;P00o`<00>EW001_[`0006hc000Q=`000a/000TS0019C001RP00bKX00?@^003o0`00i6P0
06b^0000KC@001lf00036P002B<004i>00N=003;]000mRT00?h6003RL@00GjX0001Y>@006c<0008J
000;9P00Dd`05Y800=2V003h7`00o@/00=f00017X`000691000E;P000QT0010Z001KB00`W000f940
0?/B003j5P00eYP002NI0000F4X000hX00026@00630006Hm05JX003QM@00oPH00?HX003;]@000h/0
0018C000228000<K000V>P00M2T0RkH00>]C003o0000kTH00:6l0000NQl002dn000470001b000418
00271P37_P00m2h00?h4003RL000FjT0001V?0006300008I000?:@00FTP0<Y`00=V=003l3`00nA/0
0=6T000FTP00055=000:90000aX0028g001a;P2gQ@00o`000>i7002L^`0007PS000Y?0000a`000PR
001:C008S@00cJh00?LQ003m2`00fhH003VO0000G4L000lY00026@00634006Pj06B/003UJ000o`80
0?8i002f`@0007hH000a@00011d000LP0013B@00RP00bk@00?LU003m2P00g8<003^O0000G4L000lY
00026@006S8006Xh06f^003WH@00o`400>m1002S_@0007TR000Y?0000a/000TS001?CP0DTP00dZ40
0?XG003k5000e9/001^D0000DDd000TT00036`009c/007PT0:6l003_@P00o`400>IS001X[@0006Pk
000G<0000QT0018/001Q@P1?YP00hG800?l4003b=@00^<80001m6@00;Sl000@L00088P00CTh04i40
0=:Q0080nQH00?l0dZ4001:A0000CDh000PQ00047000<40007lF0<33003d<000oPH00=mk0011X@00
05a6000>:@000QX001he001`<029]P00k4d00?l0003XF`00Kjl0001Y>@005c00008I000C;@00I3l0
GZX00>EV003o0@00kd<009Rj0000M2X0024g00026P003BL005]803jP003OO000oPD00?<c002h`P00
07`L000Z?@000a/000XT001DC00YV@00fX/00?d:003f:000akl000224000<T4000@L00088P00D4h0
7ID00=ND003l3P00mb800<Zh0000Q@X003I300047@001b4004i>01RC003EV000o0l00?PQ003:]P00
08D9000f@`0011d000PQ001?CP0KU000eYD00?`>003g9000bK/000233P00<T4000@L00098P00DTd0
9IP00=V<003m2P00mB/00<C40000OQP002/m00036`002bD005M:03NN003NO@00oPD00?8g002Y_P00
07HV000R>0000QX000lY001OA01CY`00i6T00?l0003]BP00Q;D0001/=@006340008I000F;`00JST0
N[800>a?003o0000iV@005VY0000H4<000lY00026P008SP007LT0:jo003c<`00oPL00=^6000YV@00
059=00088P0011d003M400280`3>[@00nQP00?XI003>[P0008L4000f@`0011`000TS001CC00_V`00
gH400?h5003a>@00X;`0001c:`007C@0008I000C;@00Ic/0M[400>]@003o0000iFP0052V0000GDH0
00dW000G;000OaH0akh00?LS003k4@00dZ4000J<0000?DH000@M00088P00DTd0;9X00=f1003n1@00
lC`009Rj0000L30001Xb00026@005c0006dd08jg003_@@00o`<00=il000aW00005=<00088P0011d0
03e600R=003CWP00o0l00?HW0032a00007/N000T>@000QX0014[001U?P1`[`00je000?l0003SK@00
A:80001HB@002R@000@L000f@`00R@00dJD00?/B003g9000aL80001l700093T0008J000A:`00ICd0
MK400>a=003o0@00hG@003ZO0000ED/000PR00047@00?dL03Xl00=JG003m2`00m3000:^n0000Lb/0
01/c00026@006340070`09fk003b=P00oPP00=R@000ETP0004=900057P00228005A<03VO003QL`00
o`400>]@001/[P0002400691000>:@000aX002`n00233@3=[`00nQH00?PQ0036`00007/M000S>000
0QT001@]001[=`2=]`00l3d00?h6003JR`0069<00014BP001Ah000PR001FB`11X@00i6/00?l0003X
FP00FJT0001LAP002bD000@L000iA007S@002?ooool3o`00007ooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0?l001D_00026@003BP005E;01ZD003@Y`00mb400?d8003PMP00FjT0001Y>@0073@0
00<J000:9000Cdh01hd00<Zf003e;000oP@00>AY001^[`0006hc000Q=`000a/000PR0017B`00R@40
akd00?<a003o0P00iV<007Ja0000L30002<h00036`00228004I:00280P37_P00lc800?l2003VI000
Lk00001_<@008CL000<K00098`00BT`00h/00<Zh003e;000oP@00>=/001U[00006/g000M=0000aX0
00/U001AC@0AT@00cj/00?LR003m2@00gg`004fU0000I40001H_00026@003bT005U902ZJ003FUP00
naD00?/C003GT`00;I/0001JB0003bT0008I000F;`00I3l0CjH00=mi003n2000mRD00<ba0008S@00
04a=00098`000a/002@i001b;024]@00jEL00?l0003_@P00Z;h0001l7000<40000@M00067`00?DH0
08D:0<K2003c<P00o`<00>=/001QZ`0006Pj000I<P000QT000hX001HB@0/VP00f9800?/A003j6000
dil001^D0000Dd`000/U00036P0083H006la0;>6003o0000kd<00:>m0000NR0002`m000470001b40
04I;00B;003</P00mb@00?d:003MPP00?j40001MA@0042X0008I000G<000ISd0GJX00>=/003o0`00
lSD00;g30000P1@003A200057@001Ql003m700281039^@00mRP00?d8003NO`00@J40001NA@0042X0
008I000H<@00J3X0IZ`00>EU003o0@00l3d00:^n0000Nah002/m00047000228004e>00n@003AY@00
nAX00?/B003FU`0089H0001CC0002R@000<K000U>@00MRL0VKX00>i5003o0000ieh006n_0000JSP0
01Ta00026@004B/005m404VT003PM`00oPD00?<b0030``0007lE000a@00011`000LQ001:C@0>S`00
dJD00?XI003k5000e9d001NC0000Cdh000PR00047000;Ch007dI0;W2003c=000oP@00>1f0018X`00
05i5000?:P000QT001`c001^<P22]000je400?l0003YE`00M[40001[=`006C40008I000B;000HT40
EjP00>A[003o0P00l40009nk0000MRL002<h00036P0032L005U903RN003MP000oPL00?@_002o``00
07hH000]?P000a/00?<000TS001BC@0TU`00f8l00?d<003g9@00b;/000243000=48000@M00088@00
CTh069<00=FI003l4000n2000<^d0000Q`D003U400057@001b0004]=01>A003DW000na400?PN003<
/P0008L4000iA0001Ad000LQ001<C@0FTP00eIT00?`@003h8@00b[H000252P00=D8000@L00088P00
D4h07iH00=RA003m3000mRP00<K00000P1@002ho00036`002R@005E;036L003MPP00oPH00?<d002`
`00007PR000T>@000aX000hX001MAP1=Y@00hfd00?l1003^AP00RkL0001^<P006S80008I000D;P00
J3/0M;000>YC003o0000if0005nZ0000HT40010Z00026P0083H007DW0:Nm003b=`00oPD00=f1000_
V`0005A<00098`0011`003A200261`3</@00nA/00?XF003?Z@0008T0000iA@0011d000PR001BC@0Y
V@00g8D00?h6003b=@00Ykh0001e:0007cD0008I000B;000ICd0Kjl00>YD003o0000iV@005JX0000
GT@000hX000F:`00OAT0aL800?HV003l3`00e9d000^>0000@4P000DN00078@00D4h09YP00=^6003n
1P00lSP009nl0000LRd001/c00026@005Rl006/f08Ne003^A@00o`800>1h000gWP0005E;00098`00
11d003Y500>;003BX`00na400?LT0036`@0007dK000V>P000QX0010Z001S@01Z[@00jU@00?l0003T
J@00BZ@0001JB0002bD000<K000c@P00Q`@0cjX00?/D003h8@00akh0001n60009cX0008J000@:P00
I3l0KZl00>]A003o0000hVl0042Q0000EdX000TS00047@00?4H02Hd00=BK003l3000mB`00;;00000
MBL001dd00026@005Rl006hc09Fi003a>P00oPH00=Z;000JU00004M;00057P001b40059=03>M003P
M`00o`400>a<001b/00006@o000?:P000aX002Xl00214@3;]000nQP00?PN0038_00007dI000U>@00
0QX0018/001Y>@26]@00l4000?h5003KQ`007ID00018B`001Ah000PQ001DC00kW`00hW000?l0003Z
EP00H:/0001NA@0032H000<K000f@`03R`002_ooool1o`00007ooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0?l001L`00026@0032L005=<01BB003?Z`00mb@00?h7003RLP00HJ/0001[=`007SD0
00<J00098`00C4d00h/00<Vj003d;`00o`<00>IU001d/000070`000S>0000a/000PR0014BP00Q`D0
a/400?<e003o0P00iel007fc0000LRd002Di00036`001b40049900261`35`P00lSD00?l2003WH000
N[80001a;`0093T000<K00088P00AT/008T10<Rl003d;`00o`<00>EX001/[P0006de000O=@000aX0
00XT001?CP0<S`00cJl00?LU003n2000h7P005>W0000ICh001P`00026@003RP005M:02BH003EVP00
nQL00?/A003HS`00<id0001KA`0042X0008I000E;P00HT40BJ@00=in003m2@00mb800<j]000=S`00
04m>00098`000a/0028g001`;`1m/`00j5/00?l0003`?`00[kl0001n6000<T4000DM00067`00>TD0
08<>0<;4003b=@00o`800>EW001X[@0006Xh000K<`000QX000dW001GBP0VV000eYH00?/C003j5P00
e9/0022F0000ED`000`V00026P007SD006hc0:n8003o0@00l3l00:^n0000O1`002ho000470001b00
04=90029003:]P00mRL00?h8003NO@00AJ<0001OA0004R/0008I000E;`00I3l0EjP00>9`003n1000
lc800<C40000PQ0003I300057P001Ql003a600262038_@00mB/00?h7003ON`00Aj<0001OA0004B/0
008I000F;`00IS`0H:/00>AY003o0P00lCX00;;00000OA/002ho000470001b4004U<00Z>003?ZP00
nAd00?`@003GTP009YP0001EB`002bD000<J000S>000M2X0T[P00>e9003o0000jEX007Fa0000K3H0
01Xb00026@003bX005e504>R003ON`00oPH00?@^0035``00084A000c@P0011d000LP0017B`09S@00
cjT00?TK003k4P00eIP001bE0000DDd000TS00036`00:cd007/M0;;0003b=`00o`<00>9b001>Y@00
0613000A:`000QT001Xb001/=@1k/P00jUD00?l0003ZD`00OK<0001]=0006S80008I000A:`00H4<0
DJH00>9_003o0P00lC`00:Jm0000N2@002Dj00036P002bH005M:03:M003LQ000o@P00?D/0035``00
080D000_?`0011`00=P000PR001AC@0NU@00ei@00?`>003g8P00b[L000262000=d@000@M00078@00
Bdd04i400=BM003k4P00nAd00<f_0000R@4003a600057P001R0004M;00j?003BX000na@00?TK003=
[P0008T0000lAP001Ah000HP0018C00AT000dih00?/B003h7P00c;8000271@00>4@000@M00078@00
CTh06Y@00=JE003l3P00mb@00<Rl0000PQ000310000470002B<005A<02bJ003KQP00oPL00?@`002h
`@0007XO000V>P000aX000dW001KA`17X`00hW400?l2003_@P00T[P0001`;`006c<0008I000C;@00
ISd0KJh00>UG003o0000j5`006J/0000I3l0014[00026@007SD007<[0:2l003a>P00oP@00=im000e
W@0005I;000:900011`003910024303;]@00n1h00?/D003AY@0018/0000mAP001Ad000LQ001@CP0S
U`00fXX00?h8003c<P00[kl0001g9@008CL0008J000A:`00I3l0J:d00>UH003o0000iel005fZ0000
H4<000lY000E:P00Nad0`/@00?HY003l3@00eIT0012@0000@dT000DN00078000Cdh08IH00=Z:003n
1`00lc@00:Nm0000M2X001dd00026@0052h006Ti082c003]B000o`400>5c000mX00005M:00099000
11`003M30029003@Y`00na<00?PQ0037_@0007hG000X>`000aX000hY001Q@P1S[000jET00?l0003V
I@00DJH0001LA`0032H000<K000a@000Q@T0cJh00?XF003h7P00bKX000205@00:C`000<J000?:@00
HT40J:d00>YE003o0000i6/004JS0000F4T000XT00047000>D@018/00=>P003l3P00mBT00;[20000
Mb@001lf00026@005Bh006`f08jg003`?P00oPD00=^7000OUP0004Y=00067`001b00055=02fK003O
N`00o`800>e8001i/P0006Hm000A:`000QX002Pk00205@3:^0020?TK000I0<Vh0000OaH002Lk0002
6P004B/006Ll07nc003_A000o`<00=b3000SU`0004]=00067`001b40059=03FM003QM000o`400>]B
001V[0000613000=9`000a/003=100290@0:ooooo`7o00000Oooool001kooooo00?o0000oooooooo
ool01oooool0H`006340008J000<9P00DTd03i000<f_003f9`00oPD00>=]001X[@0006de000P=P00
0a/000TR0018B`00R@40akh00?<b003o0P00if0007^b0000LRd002Dj00036`001b40041800252P33
a000lSP00?l1003XF`00Q;@0001d:P009c/000@L00078000?dL008@;0<74003b>000o`400>QL0021
]00007</000V>P000a/000LQ0013B@00Q`D0a/000?<c003o0P00iV@007:`0000KS80024g00036`00
2B<004e>00N=003;/`00mRP00?h6003QL`00FZT0001W>`006C80008J000=9`00ED/07iH00=>O003i
6P00o0l00=Z:000hW`0005e6000A:`000QT001<]001P@`13XP00gH800?d;003h8000cjT001:A0000
DDd000XT00036P0083H006lb07Ja003WG`00o`400?4k002g`@00080D000e@`0200057P0b000g@`00
PA80^l800?8i003o0P00iV<006j_0000K3D001dd00026P0032H005E;026F003EVP00nQH00?/D003F
U`009IP0001FB`0032L0008J000L=000K3H0ZhT00?l1003a?000//00001n6000<D0000@M00068000
?dP008L40<Vk003e:P00oPL00=mi001;Y0000652000C;@000QT001@]001S@@1AYP00hGD00?h5003d
;P00a/0000243000>DD200057P3o000iA000Q0`0a/400?@^003n1@00h7H004fU0000HD8001</0002
6@005Bh006Dn05VY003SK@00o`<00?8f002i`P0007hG000`@00011d000LP0016B`06S000cJh00?PO
003l3P00fHh002^J0000EdX000`V00036P008CL0078]08^f003/C@00o`000>YF001l/P0006hc000L
=0000QX000hY001LA`0mX000gH000?h8003e:`00akl000233@00=T<000DM00068000@dT018/00<j]
003h7P00o1000=ND000QU`0005=<000:90000a/002Pk001i802Z_P00lC/00?l2003SKP00E:L0001R
@P004R`0008I000H<@00JSP0M;000>UI003o0000k4l008Be0000Kc8001`d00026@0042X005i404^T
003QL`00o`<00?8h002]_`0007TP000X>`000a/000/U001EB`0]V`00fXT00?d:003f:@00akl00022
4000<T4000@L00088P00Cdh06I@00=FH003l4000n1l00<bb0000R0@003Y500057P001R0004M;00j?
003BX@00naD00?TJ003?Z`000h/0000oA`001Ah000HO0014BP09S@00dJD00?XF003j6@00cjX000B;
0000?dL000DN00067`00ADX038h00=:R003k5000nA/00<f^0000R@4003]500057@001b0004]=01FB
003EV@00o1000?LR0039^00008@<000c@@0011`000TR001BC@0VV000fX/00?d9003e;@00_l<0001l
6`00:C`000<K000<9P00FTP0@J400>1f003o0`00l3h009Zj0000LRd001dd00026@004R`006@o06J/
003XG000o`000>UH001/[P0006Hm000C;0000QT001`d001b;@2I^P00l3h00?l3003PN@00>il0001G
BP002RD000<K000_?`00PQ00bKT00?PQ003k4P00dZ4000V=0000@4P000DN00078000CTh07YD00=V>
003m2@00m2l00;K10000NB8002<h00026P0042X0069106:[003XG000o`000>QK001S[0000691000@
:P004bT007TP0;[2003e;000o@/00=ND000ETP0004M;00067`001R0004]=01bD003ISP00o@T00?@a
002^_`0007HW000O=P000QT001<]001W>`1i/P00k4`00?l1003RK`00@j80001HB@002R@000@L000d
@P00Q`D0cj/00?XE003h7P00bKT0001J00204`00:cd000<J000=:000Gd@0GJX00>QM003o0000if00
05NX0000GTD000`W00036`00;Sl008<=0<bb003j6@00nA/00<Zf0000PQ4002/m00036P003RP00613
066[003YF@00o`000>EW001<Y@0005Y8000;9@0011`003I30029003AY000o1000?HV0031a00007TQ
000Q=`000QT001@]001Z>027]@00kd400?h4003LP`009IP0001>CP001Ql000HP001?CP0XV@00gH00
0?l3003^A@00P;@0001X>`004R`0008J000U>P00OQT0b;`00?PM003j6000bk@000214P00:C`000<J
000@:P00ICh0N;400>e8003o0P00gWh002RI0000Cdh000HO00078000D4d0;i/00>1h003o0@00k4h0
06f^0000HT4000hX00036`00<40008L52_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo
00Oooooo06<001Xb00026P002bD0051>00^>003;]000mB/00?h4003TJ@00KZl0001^<P008SL000<K
00088P00A4X008L50<K2003b=P00o`400>QL0022]00007@Z000W>`0011`000LP000mA`00P`h0_<80
0?4l003o0000jUH008Zf0000MRL002Xl000470001R0003a600223`2j`P00lC`00?l0003YF000QkD0
001e:@00:3/000@L00078000@4P008D:0<G4003b=P00o`800>MP001i/P00070_000S>0000a/000PR
0019C003R`00b[L00?D[003n1@00hVl0062[0000JCT001/c00026P0032H005A<01ZD003BX`00nA`0
0?`=003KQP00?Z00001OA0004R`0008I000B;000GT@0?J000=^6003l3@00nAd00=6T000GT`00059=
000;9@000aX001he001]=01`[`00iV<00?l2003b=`00_/<000224000>4@00P001Ah0]`00=48007lF
0;C1003a?000o`400>MO001e/@0006hc000N=@000aX000/U001CC00LU@00dil00?XH003k4@00ei80
02^J0000F4T000dX00026P006S8006Xh0:N:003o0P00lSP00;W20000P1D003A200057@001Ql003a6
00252@37_`00m2d00?h5003QM@00DJH0001S@00052h0008I000C;000HD80Bj@00=mi003n1P00mB/0
0<Rm0000QPL003e600067`001Ah003I300224034a000lc800?h4003RLP00DjL0001S@00052d0008I
000D;@00Hd00DjL00>9b003n1000lc<00<330000P1<003=100047@001R0004=9006:003</P00mb80
0?d<003JRP00<I`0001HB@003BL0008J000O=@00L300QKD00>]A003o0000je8008>d0000Kc4001he
00026P003BP005Y803NN003LQ000o@T00?HX0038^`0008D9000iA@001Ah000HO0010B000R@00c;80
0?PQ003l3P00f90002NI0000E4`000XU00036`009SX007LT0:>m003`?`00o`800>AZ001JZ@0006=0
000C;@000QT001L`001Y>P1][P00j5d00?l0003]B`00RkH0001`;`007SD0008J000?:@00GDH0AJ80
0>1h003n1000lcD00;G10000Nad002Xl00036`002R@005A<02NI003IS@00o@/00?HV0038^`0008@<
000e@P0011d000LQ001<C@0DTP00e9`00?/B003i7000cJh000290000?TL000DN00067`00A4X02Hd0
0=6V003j5`00nQP00=2W0007S@00049900067`001Al0041800F<003?Z@00nQP00?XF003AY@0028d0
0013B@0200067`1O0011B@07S000d:H00?XG003j6@00cjX000>;0000?TL000DN00068000Ad/04900
0=>N003k4P00n1l00<^d0000QPP003I300047@002280051>026F003HS`00o@/00?DZ0035a00007hH
000[?@000a/000/U001HB@0kW`00ggX00?l4003a>`00XK`0001d:P007cH0008I000A:`00HT40H:/0
0>MP003o0000jU<007>`0000Ic/001@^00026@006c<0070`09:h003_@P00o`800>5d0010X@0005U9
000;9@000a/002`n00205037_@00mb<00?`@003DW@003Xl00013B@001Ah000HP001;C@0IU000ei80
0?d;003e:`00_L<0001j7P009CT000<J000?:@00H4<0FjT00>MP003o0000jEL006V]0000I3l0014[
000B:@00Mb@0/l000?@_003m2@00f90001ZD0000Bdd00P001Ql0L`00B4/05Y<00=NC003m2P00m2h0
0;G10000N2@0024g00026@004R`006Hm07:`003[D000o`000>A[0019Y00005Y8000;9@000a/00350
00252@3=[`00nQP00?TK003;]@00088?000]?P000a/000dW001NA@1FZ000if400?l0003XG000GJX0
001OA0003BP000<J000/?@00PA40b[H00?TK003j6@00c;8000233@00;Sl000<K000=9`00GTD0FjT0
0>QM003o0000iV8005:W0000G4L000/V00036`00<d4008L40=2X003k4`00mb<00<G20000Nad002<h
00026P004R`006Pj086d003^A@00o`<00=in000ZVP00051>000780001Ql004a=02:G003LQ000oP@0
0>m10027]@0006Ti000C;@000QT002<h001l7036`000n2000?XF003=/00008<>000/?@000aX000lY
001S@01b/000k4`00?l2003ONP00;Y/0001@CP001R0000HO001?CP0ZV@00gWd00?l2003]BP00Lk00
001S@0003bT000<J000]?P00Q@T02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo088001/c00036P002R@004m>00J<003:^000m2h00?l3003UI@00MK00001`;`0093T000<K0007
8@00@DP008D90<;4003a>@00o`400>UH0029]P0007DW000Z?00011`000HP000jA@00PA80]<400?10
003o0000je<0096h0000Mb@002`n00047@001Ql003U400204`2c`000l4000?l0003ZE000S[L0001f
9P00:Sd000@L00068000?4H008<>0;k3003a>P00o`400>QL0020/`00078]000U>@000a/000PR0016
B`00R@40b;/00?@^003o1000i6/006J/0000JcL001dd00026P002bD0059=01FB003@Y`00n1l00?d;
003MPP00A:80001Q@P0052d0008I000A:`00GDH0=ih00=Z;003l3`00nAX00=:P000LU@0005A<000<
9P000QX001`d001[=`1Y[@00iFL00?l3003c=000aL@000243000>dH000HO00047@00<D0007dJ0:fo
003`@000o`000>QK001l/P00070`000P=P000aX000XT001BC@0GT`00dZ<00?TK003l3`00fHh0032L
0000FTP000hY00026@006C4006Pj0:>;003o0`00lcD00<330000PA4003I30P001Ah0A`00>DD008<=
0<G2003d<@00oP@00>9a001GZ00006Dn000F;`000QT0014[001OA015XP00gWd00?h8003f:000bKT0
00280`00@4P000HO00047@00<d40080D0;g3003c=@00o`<00>=^001JZ@0006Dn000E;P000QT0018/
001Q@P1=Y@00h7H00?h5003d;`00aL<000223`00=T<000DM00067`00?dP008P20<Zf003g9@00o@X0
0=b5000gWP0005Y8000>:0000QX001dd001^<P1n/`00jUD00?l0003/CP00RKH0001a;P0083H0008J
000<9`00F4T0<Y`00=^8003m2`00mbD00<Zg0000Q`D003a6008000DN03/003e60028103:]P00mb<0
0?d<003JS000;9X0001FB`002bD000<J000T>@00MRL0W;/00>m2003o0@00iFD0062[0000ICh001@^
00026@005Rl006Ll06N]003WH@00o`000>i7002B^000078/000P=P000QX000hX001KA`0oX@00gg`0
0?h6003c<P00_<80001m6@00;3h000<K00098`00DTd08YL00=RA003l3@00mb<00<Zg0000QPP003Q4
00057@001b0004U<00n@003BX@00na@00?TJ003?ZP0018/00011B00200067`1G0010B004R`00cjX0
0?TI003j5@00dZ<000b>0000ATX000HP00057P00?DH008X00<j]003i6`00na@00=:Q000=S`0004I;
00067`001Ah003i700:;003?ZP00nAT00?XF003AYP001hd00011B0001Al000HO0014BP0;SP00dZ80
0?/D003i7000cK0000280`00>D@000@M00078@00Cdh079@00=NC003l3000mRL00<K00000P1@002dn
00036`002R@005I;03FM003NOP00oPD00?8g002W_P0007HW000Q=`000QX000lZ001Q@`1JZ@00iV@0
0?l0003[D000N[80001Y>@005Bl0008I000I<@00KS<0RkH00>i5003o0@00hW0004JS0000FdP000`V
00036`00:S`007hG0<K1003f9P00o0h00=FH000BT@0004I;008000HO08l004M;01BB003FU`00o0d0
0?HX0034a00007`K000W>`000aX000hX001NA@1EY`00iV@00?l0003ZD`00L:l0001V?@004R`0014X
001f9`2/_`00lc800?h8003JS0007iH0001>CP001b0000DN0014BP0AT@00eYL00?d<003e:`00_<80
001i80008cP0008J000A:`00I3l0K:h00>YD003o0000iFL004nV0000G4L000`V00036`00;cl008<=
0<^c003i6P00nAT00<ba0000Q0/0031000036`0032H005a7052V003UI@00o`000>UH001S[0000652
000>:@000aX002Tl00205@39^P00n1h00?XF003>[P0008D9000a@0000a/000`V001MAP1EY`00if40
0?l0003WGP00F:P0001MA@0032H000<K000`@000QPP0cZ`00?XE003h8000akl0001m6P009CX0008J
000A:`00IS`0N[800>e9003o0P00ggX0032L0000DDd000LQ00057P00BD`07ID00=^8003n1@00l3d0
08jg0000JcH001@^00026@008CL007XP0<G4003g8`00na@00<j/0000Q@X002ho00036`003RP00691
06^^003[D000o`400>1f000cW@00059=00078@001Ql004a=02BH003MP@00o`<00>i7001j/P0006Dn
000@:P000aX002/m00233P0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0
PP007C@000<J00098`00Bdd00XX00<Rk003d<@00o`800>MQ001k/P00078]000V>P000a`000LP000n
A`00P`d0^l800?0m003o0000jU@008ng0000Mb@002`n00047@001Ql003M4001o5@2]_`00kd<00?l0
003/C`00V;X0001i8@00;Sl000@M00057`00=T<007lG0:bo003_@`00o`000>]@002E^@0007PR000]
?P0011d000HO000iA@00PA40]l400?0m003o0000jEP008Je0000M2X002Lk000370001b4004=90027
1@37_`00lc400?l3003UI`00KJh0001]=@007SD000<J000:9000D4d049000<n[003g8P00o@X00=in
001:Y0000691000E;P000QT0010Z001KA`0bW000f8l00?/A003j6000e9`0026F0000ET/000`W0002
6P006S8006Ti06>/003TJ`00o`<00?@a0036`00008D8000nA`001R0000@M000^?`00Nad0Y[d00>m3
003o0000jEL008:d0000LBh0028h00036`002R@0051>01:A003@Y`00n1d00?`=003JRP00=Yh0001K
A`003bT0008I000G<000IS`0X8`00?l4003c<P00aL<000233@00>DD200057P1o000f@`00PQ40`L@0
0?<d003o0`00hf`005fZ0000IS`001L`00026@0042X005e503nQ003MP@00o@T00?HU003;]@0008X0
0013B@001b0000@M000a@000OQP0]/400?8h003o0P00i6X0062[0000IS`001L`00026@004B/005m4
04NS003ONP00oPH00?D/0037_`0008@;000iA0001Ah000HO000lAP00QPH0bKX00?HX003m2@00gH40
03bP0000G4L000lY00026@006c<006`e07Na003YF@00o`000>e:002@^00007<[000R=`000aX000`V
001FBP0/VP00fH`00?`<003g8P00bk<000290@00?dP000HO00057P00>TD008H80<Vj003f9P00o@X0
0=^7000bW00005Q:000<9P000aX0028g001d:P2F^@00kTH00?l0003VH@00Ijd0001W?0005Rl0008I
000D;P00ICh0HJ/00>EU003o0@00kd@009Rj0000M2T0028g00036P003BL005U903VO003MP000oPL0
0?@^0033a00007lF000_?`0011`000PR001AC@0MU@00eYH00?`?003h8000bk<000271000>dD000DN
00068000ADX02Xh00=6U00020?XG003]0=2V0009S@0004A:00067`001Ah003e70029003=[P00nA`0
0?/C003CW`004I000019C0001b0000DM000jA@00R0<0c;400?PN003k4P00e9d001:A0000BD`000LP
00057P00>dH008T10<f^003i7000na@00=:R000<SP0004E:00067`001Ah0045800N<003@YP00nQH0
0?TJ003>[00008T0000lAP001Ah000LP001<C@0GT`00eYL00?`>003g9000b;`000224000<40000<L
00099000ED/0<9`00=b2003n1P00lc@00:jo0000N2<002<h00026P003RT005m405>W003UJ000o`00
0>a<0020]00006/g000G<0000QT001P`001/=@24]@00kDT00?l1003SK000C:D0001LAP003BL000<J
000X>`00O1/0`l@00?DY003m3000ei@001NC0000BT`000HP00057`00A4X03i000=BK003l3`00mRD0
0<K10000OQL002Tl00036P003BL005e604nV003TJ@00o`000>a?001f/@0006Lk000C;@0042L007@Z
0:Fm003b=P00oPL00=^7000UV000051>00078@001Ah0045800f?003DV`00o0h00?HX0033a00007/M
000U>@000QX000lZ001R@@1U[000jEP00?l0003VH`00EJL0001MA@003BL000<K000/?P00PA40b[L0
0?TM003j5`00cZd000261`00<T4000<K000;9@00FTP0BZ@00>AY003o0000jU@006Z]0000Hd0000lZ
00036P009c/007hH0<Nn003h8@00na@00<nY0000Q`@003=100036`002bD005]704nV003UI@00o`00
0>QJ001NZP0005m4000=9`000a/002ho0024303=/000nQL00?PN0038^`0007lF000W>`000QX0010Z
001U?P1c/000k4`00?l1003PMP00=Id0001CC000224000DN0015BP0HT`00fHd00?h7003a>P00U;T0
001]=0005Rl0008I000O=P00N2<0_l<00?HV003k4P00d:P000271@00<D0000<K000=9`00H4<0IJ`0
0>YD003o0000hW4003VO0000Dd`000PQ00057P00B4`07iH00=b5003n1000kd<0086d0000Ic`0014[
00026P00:C`0084A00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`0R000O
=P000aX000TS0018B`00R080akl00?<d003o0@00j5d008:d0000M2X002Pk000470001R0003]50021
4@2d`@00l4000?l0003[D000U[T0001i8@00;cl000DM00057P00=D8007dI0:Nm003^A`00o`000>e;
002O^`0007/M000a@08000DN0?l003=1001m6P2U_@00kTL00?l0003/C000W;/0001j7`00;cl000@M
00057`00=d<007lE0;30003_@@00o`000>YD002=]`0007HW000Y?00011`000LP000oB000Q@T0aL<0
0?<e003o0P00iV<007>`0000KS80020f00036P002B@004m>00^>003=[`00mbD00?h8003ON@00D:H0
001T?`005Rl0008I000?:@00FDT0;9X00=NC003k4`00nQD00=FH000VV00005M:000=:0000QT001Ta
001W>`1MZP00hVl00?h5003d;P00b;`000271000@DP000LP00047000;3h007TQ09nk003^A`00o`00
0>YC0029]P0007<[000T>@000a/000TS001>CP0=S`00cj/00?PP003m3000g8H003^O0000GDH0010Z
00026@005Rl006Dn09b=003n1@00m2h00<No0000Q@T003a600067`001Ad003A20020502j`P00lSL0
0?l2003TJ000I:`0001X>P006340008I000?:@00G4L0>Il00=^6003m2`00mb800<ba0004R`0004I;
00078@0011`002ho001l6`2__`00lC`00?l1003UIP00IZ`0001X>P006340008I000@:P00GTD0@J40
0=in003n2000mBT00<Rk0000QPL003a600057`001Ah003U500242`37_P00mB/00?h7003NO@00@Z80
001MA@0042X0008I000J<P00JcL0LJl00>QM003o0000kTL009Ni0000MBP002@i00036P002bD005E;
02NI003HT@00o0h00?PO003=[`000h/00012B@001R0000DM000g@`00Q0`0akh00?DY003m2@00g8<0
03NN0000FDP000dW00026P0083H0078]08ng003]BP00o`000>QM001][P0006Tj000G<0000QT001<]
001S@01JZ@00i6T00?l1003`@000Wk/0001f9P0093T000<J000<9P00F4X0<id00=b4003m2000mB/0
0<K20000PA80035000047000228004m>01RC003EVP00na400?PM003=[`0008T0000nA`001Ah000HO
0012B@06S000cjT00?TI003j5@00dZ8000f?0000Ad/000HP00057P00>TD008P30<bb003h7P00na40
0=FJ000ETP0004e>00078@0011d003M400261`3;]@00n2000?`@003EV@005Y<0001=CP001b4000@M
000hA000Q`D0c;800?PN003k4P000<l0did0016@0000B4`000HP00057P00?TL00XX00<nZ003j6000
nQL00=2X0004R`0003m700057P001R0004Q<01:A003DV`00o1000?PQ003:^00008@<000c@@0011`0
00TS001CC00ZVP00fhL00?h7003d<@00]L40001i80009CT000<J000=:000GDH0CZD00>=/003o0@00
kDP008Ne0000KC@001Pa00026@005Rl006Xh07jc003/C@00o`000>EX001BY`0005i5000>:0000aX0
02Hj001k7P2l`P00mB`00?d:003HT00079D0001=CP001b0000DN0011B00:SP00dil00?`@003g8`00
b;d000205000;3d000<K000<9P00FdL0BJ@00>=]003o0@00kD`007fc0000JCT001D^000?9P00LRd0
W[/00?4i003n1@00g8<002ZJ0000DDd000PQ00057@00?TL028d00=>O003l4000mbD00<K10000OAX0
02Lk00036P003RT0061305nZ003XG000o`000>MO001KZ@0005m4000>:0000aX002Xl00205@38^`00
n2000?/D003?Z@0008P3000e@P0011`000XT001HB@14XP00hfd00?l0003[D000L:l0001T?`0042X0
008J000U>@00O1`0aL800?LT003k4P00dJD000290000=T<000@L000:9000FDT0BJ@00>AY003o0000
jUH006F/0000HD8000hX00036P00:cd0088@0<^d003i6P00nA/00<Zg0000PA<002Xl00036P003bT0
06=006f^003[D000o`400>9b000kW`0005E;00088P001Ad0049901>A003HT@00oPP00?8f002K^P00
06lb000G<0000QT001de001f9P2h`@00mRT00?`?003AY00008T1000c@P000a/000`V001NA@1OZP00
jEP00?l0003SK@00?Z00001EB`00228000DN0015BP0JU000fXT00?h5003`?`00QkD0001Y>P004R`0
008J000V>P00OaD02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo01L0024g
00036`00228004A:00271P35``00lSP00?l1003YF@00R;H0001f9`00:Sd000@L00067`00>4@007lE
0:fo003_A000o`000>a=002M^`0007/N000a@00200057P0D000b@@00O1`0X;`00>e:003o0000kTL0
0:Jm0000OAX003A200057P001Ad00350001k7P2O^`00kD/00?l0003]B000X[`0001l7000<T420005
7P3o000d@P00OQT0ZKh00>m4003o0000je0009Bi0000N2@002/m000470001R0003a600233@30``00
lSP00?l1003WG`00N[80001`<0008SP000<K00098`00C4d01h`00<^c003f9`00oPL00>5e001FZ000
06Hm000H<0000QT000hX001HBP0WV@00eYL00?XE003k4`00ei@002^J0000FDT000hY00026@005c00
06Hm05NX003QM000oPH00?D[0039^@0008T00015BP001b4000@L000Z?000N2@0V;X00>e;003o0000
k4l008nh0000MBP002Hj00036`00228004]=00V=003=[`00mb<00?d:003MP@00@J40001OA0004R/0
008I000E;P00Hd00V8h00?h6003e:`00b;/000271@00?dP000HP00047@00<D0007hH0;?0003a>`00
o`400>IT001Z[@0006Xh000J<P000QT000hX001JB00dW@00fXX00?`=003h8000cZd000V=0000BT`0
00PQ00047000;3d007XO0:Rn003`?`00o`400>IR001/[P0006Xh000J<P000QT000lY001LA`0lX000
gH800?d9003f9P00b[L000280`00?dL000HO00057P00=T<008<>0<K2003d;P00oPH00=mi0018X`00
05m4000A:`000QT001Pa001Y>@1[[P00if400?l0003_@`00W[/0001g9@009SX000<K000:9000Dd`0
8YL00=JE003l4000nAd00<n[0007S@0004I:0007800011d003A200224036`@00mB`00?h7003NO`00
?J00001KA`003RP0008J000N=@00L2l0R;H00>a=003o0000jET007>`0000JSP001Ta00026@004R`0
069205BW003SK@00o`800?4m002V_@0007PS000V>P000aX000/U001FB`0^V`00fhP00?d:003f:000
akh000233P00=48000@M00078@00C4d04i400=>N003k4`00nA/00<n[0004R`00045800067`001Ah0
03m700::003>[@00nA`00?/C003CWP004Y40001;C@001b4000@M000gA000QPP0b[H00?LQ003l3`00
eYH001ZD0000Cdh000PQ00047@00=48008@;0<Vi003g8`00o0h00=JE000KU00004m>00088@0011d0
03E300252@3:]P00n2400?`@003EV@005I80001;C@001b0000DM000kA@00R@40cJh00?TK003j5@00
dJ@000402Hd00@00@TT200067`300015BP0=S`00dj000?/B003h7P00bk@000262000=D<000@L0008
8P00DDd09IP00=Z;003m2@00m2h00;c30000Nad002Lk00036P003BL005]704RS003RL000o`400>i4
002=]`0006lb000J<P000QT001D^001Y>P1g/@00je000?l0003VI000F:P0001P@`003bT0008J000T
>@00NB80]L400?@`003m2@00fH`0026G0000Cdh000LQ00057@00?TL01X`00=:S003k4`00n2000<Vi
0000PQ0002ho00036`002bD005U904>R003RL@00o`400>i80023]00006/g000F;`003RH0070_09Rj
003a?000oP@00=io000_V`0005=<00088P0011d003]500B;003AX`00na800?LR0037_P0007lF000Y
?0000aX000dX001OA01IZ@00if000?l0003XF`00HJ/0001Q@P003bT000<J000X>`00OQP0akl00?LR
003k4P00dJD0002:0000>4@000@L00099000EdX0?j400>9a003o0@00k4d007Ja0000ISd0018[0002
6P008cP007XO0<;4003f9P00o1000=:Q0003R`0003U4000470002R@005Q:04>R003SK@00o`000>]C
001[[P0006=1000?:@000aX002Tl00205039^000nA`00?XI003</`00088?000/?@000aX000hX001Q
@P1W[@00jU@00?l0003SKP00@:40001FB`002B<000@M000oA`0?T000eYD00?d9003c<`00X[`0001a
;`006340008I000L<`00M2T0/L000?D/003l3P00dj0000::0000=T<000<L000;9P00GDH0FJT00>QK
003o0000i6T004BR0000EdX000TS00057@00@TT05I800=V>003n1P00lC`008jg0000JcL001<]0002
6P0093T007hI2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo02d002<h0003
6`001b40045800252P30``00lC/00?l0003ZE@00SkL0001g9000;Ch000@M00057`00=D<007hH0:Jm
003^A`00o`000>e9002S_@0007dJ000d@P001Ah000DM000_?`00NR00VKX00>a>003o0000kd@00:bo
0000OaH003I300067`0011d002ho001i8@2H^P00k4h00?l0003^A@00ZKh0001n6000=4800P001Ah0
o`00<D0007`L0:>l003^B000o`000>a<002J^P0007TQ000^?`0011d000HO000iA@00PQ40^L800?4k
003o0@00j5/0082c0000LRd002@i00036`00228004U<00:;003:]`00mBX00?h5003RL@00G:T0001W
>`006C80008I000=9`00ET/08YL00=BK003j5`00na400=R@000aW00005Y8000?:@000QT001H_001T
?`1AYP00h7P00?h7003f:000bkD000>;0000B4/000PR00036`009c/007HW09:h003/CP00o`000>e<
002F^@0007LU000Y?0000a`000PQ0018B`04R`00c;<00?HU003m2000gWd004NS0000H4<001</0002
6@004bd0065209F?003n1`00mRP00<Zh0000R@4004990007800011`002lo001l702/_`00l3h00?l1
003WH000L:l0001/=P0073<0008J000=:000F4T0;Y/00=V>003l3P00n1d00<nY000=S`0004e>0008
8P000a/002Tl001i8P2Q_000kd<00?l0003XGP00L[00001/=P006c<0008I000>:000FTP0=Yh00=^7
003m2`00mb<00<^c0000RP0004990006800011d003A200214P33a000lc400?h5003QM@00CJD0001Q
@P004R`0008I000G<000Ic`0I:`00>EU003o0@00l4000:Bm0000N28002Pk00036`002B<0059=01fE
003EV@00na800?TJ003@Y`0038h00019C0001b4000@L000b@@00P1<0`l@00?@_003n1P00gg/004:R
0000GDH000lY00026@0073@006hb08:d003[D@00o`000>YF001j/P0006`e000J<P000QT0014[001P
@`1?YP00hW400?l3003a>@00[Kl0001j8000:3/000<K000:9000E4`0:IT00=V=003m2`00mRD00<Vj
0000Q@X003M300047@001b0004U<00n@003BXP00nQD00?XH003@Y`0028d00014BP001Ql000DN000l
AP00R080c;400?PN003k4@00eIX001NC0000CTh000LQ00047@00=D8008@;0<Vj003g9000o0d00=NB
000OUP00055=00088P0011`0039100223`38_@00mRH00?d<003HT@0089H0001AC@00228000@L000c
@@00P`d0bKX00?LS003l3P00eYD001ZD0000Cdh000LQ00047@00>4@008L50<bb003h7@00na<00=>P
0000a00=S`0004E:00067`001Al0049900V=003AY000na@00?TL003=/00008L4000hA00011d000PQ
001@CP0PUP00f8l00?d:003e:`00`l@0001m6P00:C`000<K000<9P00FTP0@Z800>5d003o0P00kd40
09Bi0000L2l001/c00026@004bd006Ll076_003ZE000o`000>MP001NZP000652000@:P000QX0028g
001g9@2^_`00lc<00?h7003KR0009YP0001AC@00228000@M000kA@02RP00d:L00?/E003h7@00bkD0
00243000<D0000<K000:9000F4X0?Z000>5e003o0P00kT@008Zf0000KCD001L`000>9@00KS80TKP0
0?10003o0`00gg/003BM0000ED`000TS00047000>4@008T00=2W003k5000n1l00<Vj0000PA8002`m
00036`003BL005e605>W003VI000o`000>UG001W[@000691000@:P000QX002Dj001l7035``00mbD0
0?`@003BX@001H`0000jA@0011d000TS001EB`0iW`00hGD00?l1003]B@00OK<0001X>`004b`0008I
000Q=`00N280^l800?DY003l3P00e9d000R=0000?4H000@M00098`00ET/0?J000>9a003o0@00k4l0
076_0000I3l0010Z00026P009c/007hG0<Rl003h7`00nQH00<f_0000Q0/002ho00036`003BL005m4
066[003YF000o`000>AZ0016X`0005Q:00098`0011`003a600Z>003EV@00o@/00?@`002X_P00078/
000J<P000QT001Xb001c;02Z_P00m2l00?d<003DW0001X`0000iA00011`000/U001KA`1CY`00iel0
0?l0003UI@00BZ@0001HB@002B<000@M000oA`0@T000f9800?h8003b>000U;T0001/=@0052h0008I
000R>000O1`:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`009CT000<K
00078@00?TL008<>0;W2003`?P00o`000>]A002E^@0007TQ000_?`001Ad000DN000c@@00O1`0X;`0
0>e;003o0000kTD00:Zn0000OQL003I300067`0011d002dn001h8`2C^000je800?l0003`@000/l00
00214`00>D@000HO00047@00;3d007LT096h003[DP00o`000>m1002``00007lE000g@`001Ql000@M
000_?`00NQl0W;/00>e;003o0000kDT00:6l0000Nad0031000057@001Al003M30020502c`000l3l0
0?l0003YE`00Q[D0001d:P009SX000<K00088@00ADX008T10<Rk003d;@00oP@00>=]001RZ`0006Ti
000K<`000QX000`V001DC00MU@00dil00?TJ003l3`00fX`003JN0000G4H0010Z00026@005Bh00691
04^T003OO000o@P00?LU003</@0028d0001;C@00228000<K000U>P00M2X0RkH00>]B003o0000kDP0
09fk0000NB8002/m000470001b4004E:002:003:]`00mRP00?h7003ON@00C:D0001R@@0052d0008I
000B;000H4<0TI400?d9003f9@00bk@000:;0000ATX000LQ00047000;3h007XO0:Jm003_@P00o`00
0>QL001f/@0006dd000M=0000QX000`W001GBP0YV@00ei800?`@003i6`00dJD001:A0000Cdh000TS
00036`009c/007LU09^j003^AP00o`000>UJ001i/P0006dc000M=0000QX000dW001IB@0aW000fX/0
0?`<003h8@00cJl000B;0000ADX000LP00047@00<D0007lF0;c2003c=000o`@00>9a001CY`000691
000C;@000QT001D_001U?@1NZP00i6T00?l2003a?000Zkh0001j7`00:S`000<K00098`00D4h069<0
0=BM003k5000nQP00=6S000@T00004a=00088@0011`002lo001n5`2m``00lc<00?h5003PM`00B:<0
001NA@0042X0008I000K<`00KC@0O;800>YE003o0000je80082d0000KS<001`c00026@0042X005i5
04VT003QM@00oP@00?8f002c`00007/M000Z?0000a/000XT001CC00TU`00f9400?`=003g8`00b[H0
00261P00>DD000DN00068000ATX02Xh00=2V003j6000nQH00=6S000=S`0004M;00078000l`001Ad0
03U500271P3;]@00n2400?`?003FUP0079D0001@CP00228000@L000b@@00PPl0akd00?HW003m2`00
fHh002BH0000DTd000TS00047000;cl0080C0<K1003f:@00o@/00=V=000UV000059=00098`0011`0
031000214@37_P00mRH00?d<003HT@007iH0001@CP00228000@L000e@P00Q@T0b[H00?PP003k4@00
e9`001:A0000B4`000HP00057P00?dL018/00=2X003j5`00nAT00<j/0000R@0003]500057@001b40
04i>01^D003GT`00o@`00?HX0036`@0007lF000/?@000a/000/U001HB@0mX000h7P00?l3003`?@00
V[X0001b;@007C@0008I000B;000ICh0Jjh00>UH003o0000j5`006B/0000Hd00014[00026@0083H0
07DX0:Rn003b=P00oPH00=b4000[VP0005==00088P0011d003Q400280P3?Z`00nQL00?TK003</@00
08D8000c@@0011`000XT001FB`0hWP00h7T00?l3003_@@00T;P0001^<P006C4000dU001]=02;]P00
kd<00?l2003PM`00>Yl0001FB`002B@000@L000e@`00R0@0cZ/00?XF003i7@00b[H000233`00;Sl0
00<K000<9P00FdL0CZD00>EX003o0000jU<006f^0000I3l0014[00026P008cP007XO0<74003f:000
o0h00=BM0009S@0003e700047@00228005A<03BM003ON@00o`800>i50023]00006Xi000D;@000QT0
01lf001g9@2d`@00mB`00?d<003EV@0038l0000nA`0011d000PR001DC00hWP00hGD00?l1003]B`00
Mk40001V?@004B/0008J000U>@00O1/0a/000?LQ003k5000cj/000261`00<D0000<K000<9`00GTD0
FjT00>QL003o0000iFH004^U0000FDP000XT00047000>D@01X`00=BM003l3@00mBd00:no0000M2X0
01`c00026@006C40074^0:Bm003c<P00o@X00=JH000;SP0003a6000470002R@005U904fU003VH`00
o`000>IQ001?YP0005Y8000:900011`003a600b>003FUP00o@T00?8e002K^P0006hc000F;`000QT0
024g001j7`0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool030009c/000@L
00068000>dH0084A0;?0003_@P00o`000>a>002L^`0007/N000a@@8000DN02X00310001j7`2I^P00
k4l00?l0003_@P00/L0000204`00>D@000HO00047000:cd007HV08bg003ZEP00o`000?0m002j`P00
088?000lAP001R0000@L000Z?000MRL0RkH00>YF003o0000l3h00;K10000PA4003Y500067`0011d0
02`n001h8`2E^@00k4l00?l0003^A@00Ykh0001m6P00<d4200057P3o000d@P00OQP0[;l00>m2003o
0000jU<008fg0000MBL002Pk000470001b40049900271@37_P00m3000?l3003TJ@00J:d0001[=`00
73@0008J000;9@00Dd`069<00=6S003i7000o0d00=^8000kW`0005i5000A:`000QT001<]001Q@P16
X`00gH000?d:003g8P00cZd000b>0000CTh000TS00036`008cP0078/08Fe003ZEP00o`000>i5002S
_00007XO000]?P0011`000LP0011B@00R0<0bK/00?D[003n1P00hGD005:W0000I3l001D^00026@00
4B/005i508jB003m2P00mb<00<f`0007S00004U<00088@0011`002Xl001i8P2O_000kTD00?l0003Y
F@00O;<0001_<@007cD000<J000<9P00ED/099P00=JF003k4P00nQP00=:Q000GT`00055=00099000
0a/002Dj001e:02D^@00kDX00?l0003ZEP00Ok<0001_<@007SD0008J000<9`00EdX0;9X00=V?003l
3P00n1h00<j/0009S@0004Q<00078@0011`002lo001m6@2e`@00lSP00?l3003SK@00FJT0001T?`00
52h0008I000D;P00I3l0FJP00>=]003o0P00lST00;;00000O1`002`n00047000228004m>01>A003B
X@00nQL00?XF003CW`005I80001?CP00228000@L000]?P00OAX0]/400?8f003o1000hG<004fU0000
H4<0014[00026@006C8006/g07Fa003YF000o`000>a>0026]@00070`000M=0000QX000lY001MAP13
XP00ggT00?h5003c<`00^/80001m6P00;3h000<K00098`00DDd07iH00=NE003l3`00n2000<bb0000
R08003a600057P001Ql0049900J<003?ZP00nAX00?/D003CW`004I40001;C@001b4000@M000f@`00
Q@X0bKP00?LS003l3@00ei80026F0000DDd000TS00047000<400080C0<K1003e:P00o@X00=Z:000Y
V@0005A<000:90000a/002dn001o5P35a000mB`00?d9003JR@00:YX0001DC0002B@000<K000^?`00
P1D0a/800?HY003m2P00fHd002BG0000DTd000PR00047000<d4008<=0<Vj003g8`00o0l00=FH000F
T`0004a=000780001Ah003a6002:003>Z`00nAT00?XG003@Z0000h/0002i000nA`001Ah000LP001;
C@0FT`00eYL00?`>003g9@00akh000214`00;Sl000<K000:9000EdX0=ih00=ml003n1000lCX00:6l
0000M2X001le00026@004B/006=006F/003XG000o`000>UH001Z[P0006Dn000B;0000QT001he001c
:P2Q_000lCT00?h5003MP000<I`0001DC0002B<000@L000e@`00Q`H0cJl00?TI003j6000cZd00027
1000=T<000@L00098`00ED`0<id00=im003o1000l3d009Ni0000L30001Xb000<9000JcL0Q;D00>i7
003o0P00hG<003nQ0000F4X000XT00037000<d4008H80<f_003j6000nAX00<bb0000Q0/003100003
6`002bD005Y804RS003SK000o`000>]@001c/00006Hm000B;0000QT0028g001h8P2j`P00mB/00?`<
003EV@003Hl00010B0001Ah000PQ001BC@0_V`00gWd00?l3003_@P00RKH0001[=P005Bh0008I000M
=000MBP0[[l00?@_003m2P00eYD0012@0000@DT000DN00088P00Dd`0<id00=mi003o0P00kTP007fc
0000J3/0018/00026P008cP007/N0<G4003g9000na800=2W0000R0<003=100036`002bH005a605FW
003WG`00o`000>IR001AYP0005]7000;9@0011`003I3006:003BX@00o0h00?DZ002f`@0007HW000M
=0000QT001L`001_<@2M^`00lSD00?d9003GU0003i00000nA`0011d000TS001HBP17X`00iFL00?l0
003XGP00EJL0001KA`002bD000@L000iA008S@00eIX00?d;003c<P00XK`0001`<0005c00008I000O
=@00N2802_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l002Tl00047000
1Ql003U4001o5@2/_`00kTD00?l0003]BP00X[`0001m6P00=48000DN00047@00;Sl007PR09>h003[
DP00o`000?0o002g`@00088@000lAP001R0000@L000Y?000MBT0Q[D00>UI003o0@00lCX00<330000
Q0/003m70007800011`002Lk001d:P25]@00jET00?l1003a>`00_L<000233P00?4H000HP00047000
:Sd007HU08ng003[D`00o`000>m2002^_`0007lG000e@`001Ah000DM000b@@00O1/0Y[d00>i6003o
0000je0009>h0000Mb@002Xm000470001b0003m700252@35`P00lc<00?l2003UIP00KZl0001]=@00
7SD000<J000;9@00DDd059800=2W003h7`00o@`00=b40011X@0005m4000C;0000QT0018/001OA010
X@00g8@00?d;003h7`00cjT0012@0000D4h000XT00036P008SL0074_07nc003YF@00o`000>m1002Z
_P0007`L000_?`0011d000HP000nA`00QPL0akh00?@^003n1@00hW4005RX0000ICh001H_00026@00
42X005a608^C003m3000n2000<j/000;SP0004a=00088P000a/002Pk001g9@2I^P00kDT00?l0003Z
E@00Pk@0001a;`008CL000<J000;9@00E4`07iH00=FJ003k5000nQH00=BM000KU000059=000:9000
0aX002<h001c:`2>]`00k4d00?l0003[DP00QKD0001a;`0083H000<J000<9P00ET/09iT00=NC003l
4000nA`00=2X000=S`0004a=00088P0011`002`n001l702__`00lC/00?l2003TJ@00GjX0001V?@00
5Bl0008I000C;@00HT40DjL00>9a003o0`00lSH00;S20000OQP002lo00047000224004a=00n@003A
Y@00nQT00?/C003DV`006I@0001@C@002B<000<K000[?@00Nah0[kl00?4i003o0`00hVl005>W0000
HT80018/00026@00634006Ti06n_003XG000o`000>e;002=]`00074^000O=P000QX000hX001KA`0n
X000gWd00?h6003d<000`<@0001o5P00;cl000@L00088P00D4h06Y@00=FH003k4@00n1d00<f_0001
RP0003m700057`001Ql003m8006:003>[P00nA`00?/B003DV`005Y80001>CP0022400?<000@M000d
@P00P`d0b;`00?HV003m2`00fHh002FH0000Dd`000TS00036`00;Ch007lF0<C4003e;000o@P00=^6
000^V`0005E;000:90000a/002/m001m6P2n``00m2l00?h8003LQ@00;i/0001EB`002R@000<K000/
?@00OQP0`l@00?D/003m2@00fXT002VI0000Dd`000TS00047000<400088A0<Nm003f9@00o0d00=ND
000KU00004m>00078@0011d003U400280`3=[`00nA/00?XE003AY0001hd00011B0001Ah000HP0018
B`0BT@00e9/00?`@003g8P00bKX000223`00<40000<L000:9000ED/0<Y`00=f0003n1@00lSL00:Nn
0000MRL0020g00026P0042X0069105nZ003WH000o`000>YE001`[`0006Hl000C;@000QT001`d001b
;@2K^P00lC`00?l4003OO000=Yh0001FB`002R@000@L000c@@00Q@T0c;<00?TL003j5P00cjX00029
0000>4@000@M00088P00Dd`0;Y/00=f1003n1@00lCX009fk0000LRd001`c000<9000JCT0O[<00>e:
003o0@00hVl004FR0000FDT000/U00036`00<40008@;0<bc003i6`00nQP00<f^0000QPL003=10003
70002R@005Q904:R003RL000o`400>a<001i/P0006Lk000C;@000QT0020f001g9@2c`000m2h00?d;
003FU@004Y400013B@001Ah000LQ001AC@0ZVP00gH400?h4003`?`00T;P0001]=0005c00008I000L
<`00Lb/0Ykh00?<b003m2@00f94001FB0000ADX000DN00078@00DDd0;Y/00=im003o0`00kd@008Bd
0000JCT001<]00026@008CL007TQ0;o3003f9`00o1000=6S0000RP0003I3000470002bD005]804nV
003VH`00o`000>MN001GZ00005e6000<9P000a/003A200280P3AY@00o1000?HW002l``0007PT000O
=@000QT001H_001]<`2G^@00lSP00?h7003HT00059800011B@001Ad000TS001FB`12XP00i6/00?l0
003YFP00FjT0001MAP002bH000<L000f@`03R`00dih00?d<003d;`00Z;h0001a;P006C40008I000M
=000MbD02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l002/m00047@00
1Ql003I3001n602V_@00kDP00?l0003^A`00Z;h0001n5`00=d<000HO00047@00;3d007LU08fg003Z
EP00o`000?4k002n``0008@<000oA`001b0000@L000V>P00Lb/0P;<00>QM003o0@00lSH00<G30000
QPP0049900078@000a/002Dj001b;01o/`00j5d00?l1003b=`00a<@000252P00?dP000LP00047000
:3/007DX08Vf003ZEP00o`000?0n002d`@00080C000hA0001Ql000@M000_?`00Nah0Wk`00>e9003o
0000k4`009Vj0000NB4002dn000470001R0003a600243032a000lSL00?l2003VHP00M;00001^<P00
83H000<J000:9000D4h03i000<n[003g8@00o@X00=f00016X`000652000D;@000QT0014[001MA@0k
W`00fhL00?`=003i7@00dJD001FB0000DDd000XT00036P0083H006la07Vb003XG@00o`400?0n002`
`00007hH000b@@001Ad000HO000lAP00Q0/0a/800?<a003o1000hfh005jZ0000Ic`001Pa00026@00
3bT005]708ND003l3@00n1h00=2X000?T00004m>00098`000a/002Hj001e:02B^000k4`00?l0003[
D@00RKH0001b;0008SP000<J000:9000DTd06i@00=>N003j5`00na@00=FI000PUP0005A<000;9@00
0aX0024g001b;@28]P00je400?l0003/C`00RkH0001b;0008SP000<J000;9@00E4`08YL00=JF003k
4P00nAT00=6T000AT@0004m>00088P000a/002Xm001j802X_P00l3h00?l1003UI@00I:`0001W>`00
5c00008I000B;000HD<0CJD00>5d003n1000lc<00;o30000OaD00350000470001b4004Q<00Z>003@
Z000nA/00?/A003FU`007YD0001BC@002B@000<K000X>`00NB40ZKh00?4l003o0P00i6/005VY0000
Hd0001<]00026@005Rl006Pk06V]003WH000o`000>i7002C^00007<[000Q=`000QX000dW001IB00i
W`00gH400?h7003e;@00aL<000214`00<D0000@L00088P00CTh05Y800=BL003k4`00nA/00<n[0005
S000049900067`001Ah003e600280P3</@00n1l00?`@003FV0006Y@0001@CP00228003/000@L000a
@@00PA40a/000?HY003m2P00fXX002ZJ0000E4`000XT00036`00:cd007dJ0;g3003d;`00oPL00=f2
000cW@0005M:000;9@000a/002Tl001k7@2h`@00lc400?h6003MP@00=9d0001GBP002bD000<K000Y
?000O1/0_<<00?@_003n2000g8D002jK0000ED/000XT00036`00;Sl0080D0<K1003f:000o@/00=R@
000PUP00051>00088P0011d003I300261`3</`00n1h00?/C003BX@0038h00014BP0200067`2f0015
BP0=S`00dil00?/B003h8000b[H000242`00<d4000@L00098`00E4`0;I/00=b4003n1P00lc@00:jo
0000Mb@0028h00026P003bT0061305VY003VH`00o`000>]A001f/@0006Pj000D;P000QT001/c001`
<02D^@00l4000?l3003PN000>il0001GBP002R@000<K000`@000P`d0b[H00?PN003k5000d:H000>;
0000>dH000@M00088P00DTd0:IT00=b5003n1P00lSL00:>m0000LbX001dd000;8`00J3/0N;400>a>
003o0000i6/004ZT0000FdL000`V00036`00;Sl0088?0<Zg003h7@00nQH00<n[0000R0<003E30004
70002R@005M:03fP003QM000o`400>e80020/`0006Ti000D;@000QT001he001e:02]_`00m3400?d9
003HT@005Y<00017B`001Al000LP001?CP0UV000g8D00?h5003a>`00U[T0001_<P006340008I000J
<P00LBh0XK`00?8e003n2000fHd001ZD0000B4/000DO00078000D4h0:IT00=f1003o1000kd4008Zf
0000JcL001D^00026@007cH007LT0;W2003e:P00o0h00=>O0004R`0003Q4000470002R@005U904ZT
003UI`00o`000>QJ001MZP0005i5000<9`000a/0035000271P3?Z@00na800?LT0033a00007TQ000Q
=`000QT001D^001/=P2@^000lC/00?h6003IS00069<00015BP001Ah000PR001EB`0mX000hfl00?l0
003ZEP00HJ/0001OA00032H000<K000d@P00R@00dZ400?`>003e;000[[l0001c:`006S80008I000K
<`00MBP:ooooo`7o00000Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0
0008ooooo`03o`000?oooooooooo00Oooooo0?l002dn00047@001Ah003=2001l702O_000k4`00?l0
003_@`00[kl000205000>DD000HO00047000:C`007DX08Ne003YFP00o`400?8h0034a00008D80012
B@001b4000<K000U>@00LBh0N[800>MQ003o0P00lc<00<K00000Q`@004E:00088P000a/002<h001a
;`1i/P00if400?l2003c=000a/4000261P00@TT000LQ00036`009SX007<[08>d003YFP00o`400?4k
002k`P00088@000jA@001Ql000@M000]?P00NB40VKX00>a=003o0000kDT009nl0000NQh002lo0004
7@001Ql003Y50022402l`P00lCX00?l1003WGP00N[80001`<0008SL000<K00098`00Cdh02hh00<f_
003g9000o@T00=ml001;Y@000691000E;P000QT0010Z001LA`0fWP00fX/00?`?003i6`00dZ8001VD
0000Dd`000/U00036P007SD006dd07>`003WH@00o`400?4k002f`@0007lE000d@P001Ah000DO000i
A000P`l0`l@00?<d003o0`00i6X006>/0000JCX001Tb00026@003RP005U908BE003l3`00nA/00=6T
000DTP00051>000990000a/002@i001c:P2<]`00je000?l0003/CP00SkL0001d:P0093T000<K000:
9000DDd05Y800=:Q003j6@00na800=JE000UV00005E;000<9P000aX0020f001`<022]000jU@00?l0
003]B`00TKP0001d:@0093T000<K000:9000Ddd07ID00=FJ003k5000nQL00=>P000FTP00051>0009
8`000a/002Pk001h8`2R_000kd400?l1003VHP00JZh0001Y>@006340008I000A:`00Gd@0B:<00>1h
003n1@00m3000<G40000PA8003=200047@001b0004E:00J<003>[000n1d00?`@003GU0008iL0001C
C0002R@000<K000V>P00N2@0Xk`00?0o003o0@00iFL005jZ0000ICh001@^00026@005Bh006Hm06B/
003VI000o`400>m4002I^P0007DY000R>0000aX000`V001HB@0dW@00g8D00?d9003e:P00akl00022
3`00<d8000@M00078@00Bdd04I400=>P003j5@00nQT00=2W0009S@0004E:000680001Ah003Y50027
1@3;]@00mb400?`>003GU0007iH0001AC@002B<00?<000@L000_?`00P1@0aL<00?D/003m2000fhH0
02nK0000ET/000/U00036`00:C`007/M0;O1003c<P00oPH00=in000hWP0005Q9000<9P000aX002Lj
001j802a`000lcD00?h5003NO@00>Yl0001HB@0032H000<J000W>`00Nah0]/400?<b003n1P00gH80
03>M0000ET/000XU00036`00:cd007hH0<C4003e:`00o@X00=V<000TV000059=00088P0011`003A2
00242`3:]`00n2000?/A003DW@0049000017B`001Ql000DN0012B@09S@00dZ<00?/D003h7@00c;<0
00262000=D<000@L00088P00DTd0:9T00=^8003n2000m3400;C10000NB4002@i00036P003RP005m4
05BW003UI`00o`000>a>001l/P0006Xh000E;`000QT001Tb001^<P2>]`00kd<00?l2003QM000@:40
001IB@002bD000<K000^?`00PQ40bKX00?PP003k4P00dZ8000N<0000?TL000DM00078@00D4h099P0
0=^8003n1`00lc@00:Zn0000MBP001lf000:8`00ISd0L[000>]A003o0000iFP004nV0000G4H000`W
00036`00;3d0084C0<Vj003h8000na@00=2W0000R@0003Q4000470002B<005E;03RN003PM`00o`80
0>i50026]@0006/g000E;P000QT001`d001c:`2V_@00lc@00?h8003IS@006i@0001:C0001Ql000HP
001=CP0PUP00fXT00?h6003b>000W;/0001`;`006C80008I000I<@00L300VkX00?8i003n1P00fXX0
01jE0000Bdd000HO00068000CTh099L00=b5003n1@00l3h0092h0000KCD001H_00026@007SD007HW
0;?0003e;000o0d00=BL0008S@0003]6000470002B<005Q:04BR003TJ`00o`000>UG001RZ`000613
000=9`000a/002lo00252@3>[000na@00?LR0036`P0007/N000R>0000QT001<]001Z>02:]P00l3l0
0?h5003KR0007ID00018B`001Ah000LQ001CC00hWP00hG<00?l1003[D`00IZ`0001P@`003BL000<K
000a@000R0@0dJD00?`@003e:@00]L40001e:0006c<0008I000J<P00Lb/02_ooool1o`00007ooooo
0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`1^000_?`001Ah000DN000a@000NQl0VKX00>]?003o0000l4000;G10000PQ0003a6
0007800011`002Lk001c:`21]000j5d00?l1003b=@00a/4000271@00ADX000PR00036`008cP0070`
07B`003VI000o`<00?@`0038_00008T00018B`00228000<K000R=`00Kc40Lk000>IT003o0`00lc40
0<Nn0000R08004E:00088P000a/002@i001a;P1m/`00j5h00?l1003b>000`L@000243000?DL000HP
00047000:cd007LT09>h003[D000o`000>i5002V_@0007`K000a@0001Ad000DN000g@`00P1@0]L40
0?0m003o0@00j5X0082c0000LRh002<h00036`002B<004a=00N<003</P00mRH00?h7003PN000DJH0
001T?`005Rl0008I000?:@00FTP0<I`00=R?003k4@00nQP00=>N000NU@0005A<000<9P000QX001`d
001/=P1][P00iV@00?l2003b=`00_L<000214P00=d<200057P1o000f@`00PA80_<<00?8g003o0P00
iFH006V]0000JSP001/c00026P003BL005Q:086F003k4@00nAT00=:Q000HT`00059=000:90000aX0
028h001b;@26]@00je<00?l0003]BP00UKT0001f9`009SX000<K00098`00Cdh04Y400=6U003i6`00
o1000=RA000ZVP0005M:000<9`000QX001he001^<P1l/P00jEP00?l0003^B000V;X0001f9`009SX0
00<K00099000DDd06I<00=>N003j5P00nQD00=BL000JU000055=000:90000a/002Hj001f9@2L^`00
kTD00?l0003WGP00L:l0001Z=`006S80008I000@:P00GDD0@j800=il003n1`00mBd00<K10000P`h0
03I300057@001R00049900::003=/000n2000?`>003HT000:9T0001EB`002bD000<J000T>@00MRL0
W;/00>m3003o0@00iV@006B/0000IS`001D_00026@0052h006Dn05jZ003UI`00o`400>m1002O_000
07HV000T>@000aX000/V001FBP0_V`00fhT00?d:003f9`00b;`000243000=T<000@M00078000B4`0
3Hl00=6T00020?XG003o0=6S000=S`0004Q<000780001Ad003M400252@39^@00mb@00?`=003HT000
99L0001BC@002B<000<K000]?P00OQP0`<<00?@_003n1`00gH8003BM0000EdX000/U00036`009c/0
07XP0;70003b=@00oPD00=mk000nX00005Y8000<9`000aX002Di001h8`2[_P00lSP00?h4003ON@00
?j40001JB00032L000<J000U>P00NB40/<000?<e003n1@00gWh003RN0000F4X000/U00036`00:C`0
07`K0;k3003d;P00o@P00=^8000YV@0005=<00098`0011`0035000233P39^P00mb<00?`?003EV@00
5980001:C0001R0000DN000oA`05S000d:H00?XF003i6`00cJl000271000>4@000@M00088P00DDd0
8iL00=Z<003m2@00m2h00;[20000Nah002Hj00036P003BP005e604jU003TJ`00o`400>e:0022]000
06/f000G<0000QT001Pa001]=028]P00kTH00?l1003RL000AJ<0001JB00032H000<K000/?@00P1@0
akd00?LS003l4000dih000^>0000@DP000DN00078000Cdh07iH00=V<003m2000m3400;300000MbD0
024g000:8P00ICh0K:h00>YE003o0000iV@005FW0000GTD000dW00036P00:S`007lF0<Nn003g8P00
na800=6S0004R`0003]500047@00228005A<03>M003ON`00o`<00>m2002<]`0006`e000F;`000QT0
01/c001b;@2P_000lSL00?h7003JRP0089H0001=CP001R0000HO001:C00KU000fHd00?h8003b=@00
X[`0001b;@006c<0008I000G<000KS80U;T00?4l003n1@00fhH002>G0000CTh000HP00067`00Bdd0
7iH00=^9003n1P00lCX009Ji0000KS8001L`00026@0073@007@Z0:bo003d;`00o@/00=FH000<S`00
03i700047@002B<005I;03nQ003SK`00o`000>YC001X[@000652000>:0000aX002dn00233@3=/000
nQH00?PO0037_P0007dK000T>@000QX0018/001Y>P24]@00kd800?h4003LQ0008YL0001;C@001Ql0
00LQ001BC@0bW@00h7H00?l1003/C`00K:h0001R@@003RP000<K000_?`00QPP0cjT00?/B003f9`00
^l80001f9P007C@0008I004001Ta0@00LBh:ooooo`7o00000Oooool000Go00000_ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0@`00
<T4000DN00057@00;cl007TR09>h003[D`00o`000?0m002k`P0008<=000oA`001b4000<L000U>P00
LRd0Nk800>MQ003o0P00lc800<Nn0000R@4004Q;00088P000a/0024g001^<`1^[`00iFP00?l4003d
;@00bKT000>;0000Bdd000TS00036P0083H006dd06f^003UJ000o`<00?@^0039^P0008X00018C000
228000<K000R>000L300Mk400>MQ003o0P00lcD00<G30000Q@P004180007800011`002Tl001f9`2=
]`00jU<00?l0003_@P00[;l0001n6000=4800P001Ah0o`00=48007hG0:no003`@000o`000>UG0025
]@0007<[000U>P000a/000PR0018C003R`00b[H00?HY003n1P00hG@005JX0000ISd001L`00026@00
3RT005U902bJ003GT`00na800?XF003EVP008iL0001FB`0032L0008J000K<`00JSP0Ijd00>EX003o
0`00lc@00<?40000P`h003U500067`001Ah003A2001o5@2f`@00lCX00?l1003VHP00Kjl0001/=P00
73@0008J000<9`00ET/0OYL00?/C003j5`00e9d001fE0000Dd`000/U00036P0083H0070_082d003Z
E`00o`000>i7002K^`0007LT000X>`000a/000PR001=CP0=S`00cjT00?PM003l3P00fHh002jK0000
F4T000dW00026P0073@006dd07Ja003XG000o`000>i5002N^`0007LT000X>`000a/000TS001@CP0D
TP00dZ800?XH003k4`00eIT001nF0000Dd`000XT00036`0093T007DX09Ji003]B000o`000>QJ001f
/@0006`e000K<`000QT000lY001LA`0mX000gH000?h8003e:P00akd000242`00>4@000DN00067`00
?dP008T10<^d003g8P00o@`00=V<000/VP0005I:000<9P000aX002<h001d:@2F^@00kTH00?l0003W
H000JZd0001X>`005c00008I000C;@00Hd00F:P00>A[003o0P00l3d00:Fm0000N2<002Hj00036`00
2bD005E;02ZJ003IS000o@`00?LU0039^00008H8000iA0001Ad000HP0015BP09S@00d:P00?TI003k
5000dj00016A0000Bdd000LQ00047@00=D8008<=0<Rl003f9`00o@/00=V<000XV@0005A<000:9000
0a/002/m001l6`2j`P00lc400?h6003NOP00>Il0001IB@0032H000<J000U>@00N2<0Z[h00?8h003o
1000h7L004>R0000FdL000dW00036P008cP007HV0:Fm003a>`00o`<00>5e0014XP0005]7000=9`00
0aX002@i001g902Y_P00lSP00?h4003ONP00?J00001IB@0032H000<J000W>`00Nah0^<400?@a003n
1`00g8D002jK0000ED`000XT00036`00;cl0084B0<Nn003f9@00o0d00=JE000IT`0004e>00078000
1Ad003a6006:003?ZP00nQP00?XI003>[00008T0000jA@00[P001Ad000LQ001?CP0OUP00f8l00?d:
003e:`00`L@0001l6`00:3/000<J000=9`00G4L0BJ@00>=^003o0@00kTL008Rf0000KC@001Pa0002
6@005c0006/f08:d003]BP00o`400>=/001;Y00005a7000<9`000aX002Xl001n5`36`@00mRH00?`>
003DV`003i000014BP001Ah000HP001<C@0KU000f9000?d:003d;P00]/40001h8P008SP000TR001S
@01W[@00jEP00?l0003WH000FZT0001OA0003RP000<J000W>`00OAT0a/400?LU003l4000dil000R=
0000?DL000DM00088P00DTd0;Y/00=io003o1000l3l009:h0000KS<001P`00026@006C80070`09Zj
003a>P00oPD00=^6000TV00004m>000780001Al004M;01NC003HT@00o@T00?<b002Y_P0007@Z000L
=0000QT001H_001]=@2>]`00l3l00?h4003MPP00:9T0001@CP001b0000HO0018C00KU000fH`00?h7
003b=`00W;/0001`<0006340008I000J<P00LR`0Y[d00?<b003m2@00ei@0016@0000@DP000DM0008
8P00ED`0>Yl00>5b003o0@00je0006j_0000Hd0000lY00036P00:Sd0088@0<^d003j6000nAd00<Rk
0000OQL002Hj00026P004B/006Ll07jc003^A@00o`<00=f0000VV00004i>00067`001b00051>02jK
003ONP00o`800>e<001b/00006=0000?:@000aX002dn00242`3>[@00na<00?LT0031a00007PS000O
=@000QT001L`001`<0[ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00Oooooo1?l00006ooooo`13000d@P001Ah000@M000/?P00Mb@0SKL00>YF003o
0000lCX00<;40000Q@T0045900078@000a/002@i001`<01e/@00iV@00?l3003d;`00bKX000::0000
Bdd000TS00036P007cH006`e06V]003SK000oPD00?D[003;]@001hd0001>CP002R@000<J000N=@00
K3H0Ijd00>=/003n1000mB`00<Zg0004R`0004]=00098`000a/0024g001^<P1a/000iFD00?l3003c
<P00akl000271@00@dT000LQ00036`009cX007@Z08Ne003YE`00o`000?0o002b`00007lE000f@`02
00057P0I000b@@00OAX0ZKh00>m3003o0000jU<008^f0000MBP002Lk00036`00224004E:00290039
^@00mB`00?h5003RL@00G:T0001W>`006C40008I000=:000EdX09iT00=JG00020?/D003o0=JF000W
V@0005M:000=:0000QT001Xb001X>P1QZ`00hf`00?l3003c<@00a/8000242`00?4H000HO00047@00
<D4007hI0;30003`?@00o`400>MO001d/00006dd000N=@000QX000`V001EB`1kV@00nQD00?/E003E
V@008IL0001EB`002bH000<J000O=@00Kc80N[800>UJ003o0000kd@00:6l0000NB4002Xm00047000
228004Y<00V=003>[@00n2000?`=003JRP00<id0001JB0003RP0008I000K<`00JcH0L:l00>MO003o
0000kd400:Bm0000NB4002Xl00036`00228004i>012@003AY@00nAX00?/A003FU@0099L0001DC000
2bD000<J000R>000Lb/0T;P00>e;003o0000jEL007bb0000KS<001dd00026P003RP005Y803RN003L
Q000o@T00?HW0039^P0008H7000kA@001Ah000DO000mAP00Q`D0b[L00?LU003m2`00fhP0036L0000
F4X000`W00036P008CL007</092h003]B@00o`000>QL001_[`0006Xi000H<@000QT0018/001Q@P1C
Y`00hfl00?l3003a>P00[;l0001j8000:3/000<K000:9000E4`09IP00=R@003l3@00mb800<^e0000
Q`@003]600057P001Ql0049900F;003>Z`00nA/00?/C003DW0005Y80001>CP00224000@L000b@@00
PQ00a/000?DY003m2P00fhP002fK0000ED/000XU00036`00:C`007/N0;C0003c=000oPD00=mk000n
X00005Y8000=9`000aX002<h001f9P2T_@00lC`00?l3003QL`00B:<0001MAP003RP0008J000Q=`00
MBT0Wk/00?0n003o0P00hW8004VT0000GDH000hX00026P008SL007HW0:>m003a>`00o`<00>1f0012
XP0005]8000=9`000aX002Dj001i8@2b`000lc<00?h6003MP@00<id0001FB`002R@000<K000]?P00
OaD0a/400?HX003m3000f94001fE0000Cdh000LQ00047@00>DD008P20<j^003i6P00nQH00=2X0003
R`0003e600057P001b0004e>01ZD003GT`00o@`00?HX0035``0007hH000Z?0000a/000`V001JB014
XP00hW800?l2003_A000S[L0001^<P006C80008I000E;`00JSP0O;<00>a=003o0000i6T0000<052V
0000GDD000dW00036P00:3/007dK0<C4003f:000o0d00=JG000CT@0004M;0P001Ql0H@00BD`05Y<0
0=ND003m2`00mB/00;c30000NQl002@i00098P00HD80HJ/00>QL003o0000j5d0062[0000HD8000lY
00036P009SX007`L0<C4003f9`00o0h00=BL000<SP00041800057P001b40055=02VI003LP`00oPD0
0?4k002H^P00070`000I<@000QT001Pa001^<P2D^@00l3d00?h4003MPP00:IT0001AC@001b4000DN
0014BP0CT@00ei@00?d:003d;`00[kl0001e:0007SD0008I000E;P00JcL0R;H00>m2003o0`00gWh0
02bJ0000DDd000LQ00057P00ADX05Y800=R@003m2000lc@00::l0000LBh001Xb00026@006C40074_
0:2l003b=@00o@P00=R@000ETP0004A:00057P00224005=<03FM003PMP00o`400>a<001c/00006@o
000@:P000aX002Pk0020503:]`000P3i6`008P3:]`00080D000X>`000aX0010Z001U?@1h/@00kDT0
0?l2003NO@00:iX0001@CP001R0000HO001?CP0YV@00gWh00?l2003]B000N;40001U?P0042X000<J
000[?@00P`l0cK000?XE003g8@00aL<0001j800083H0008I000F;`00KS87ooooo`Co00000Oooool0
00Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo0?l003M300067`0011`002Xm001e9`27]@00jEX00?l1003b=`00aL<000271P00A4X0
00PR00036`008SL006lb06n_003UJ000o`@00?D/003:]`001X`0001>CP002R@000<J000N=@00JcL0
Hj`00>9_003n1P00mRP00<bb000;SP00051>000:90000aX001dd001Z>01RZ`00hVl00?h5003f:@00
bk<000R=0000CTh000XT00036P007cH006dd06b^003TJ000o`<00?@_0038_00008T10016B`002280
00<K000U>@00LR`0PK@00>QJ003o0@00lC`00;S20000PA8003U400067`0011d00310001k7@2S_000
kTH00?l0003[D000TKP0001f9P00:C`000@L00078@00@TT008L40<Rm003d;`00oP@00>=]001QZ`00
06Tj000J<P000QX000dW001FB`0SU`00eIX00?XF003k4P00ei<002bJ0000FDT000hX00026@006340
06Ll05bZ003RK`00oP@00?@_0037_P0008H7000oA`001R0000@M000_?`00O1`0Z[h00?10003o0000
j5/007Zb0000Kc4001lf00036P002bD005=<07VI003j5`00na<00=JF000VV00005I;000<9P000QX0
01dd001]=01e/000j5h00?l0003_@@00Ykd0001k7P00;3h000@L00078@00Ad/01H`00<f`003g8P00
o@/00=^6000hWP0005]7000?:@000QT001Tb001Z>01[[P00iV<00?l1003`?P00Z[h0001k7P00;3d0
00@L00088P00Bdd038h00<nY003i7@00o0l00=RA000XV@0005I;000<9P000aX0024g001b;@2:]P00
k4l00?l0003ZD`00PK@0001_<@007SD0008J000=9`00FDT0=9d00=^7003m2`00mbD00<Zf0000R0<0
03i700067`001Ah003Y500262039^`00mRL00?d9003LQ@00=Yh0001IB@003BL0008J000O=P00LBh0
R[H00>a=003o0000jET007Fa0000JcL001Tb00026@004B/0061304jU003QLP00o`<00?8g002b`000
07/M000Z?@000a/000TS001BC@0QUP00ei@00?`?003h8000c;4000290@00?TL000DN00067`00?dP0
0HX00<f_003h7P00na400=FH000JU000051>00088P0011`0031000205035``00mB`00?d8003LQ@00
<Y`0001GBP002bD006`000<K000W>P00NB40[[l00?8g003n1000h7L004>R0000G4L000hX00026P00
8CL007DX09jk003`?`00o`800>9`001=Y@0005i5000?:@000QX001lf001c:`2I^P00kd400?l2003S
KP00CZD0001NA0003bT0008J000P=P00M2X0WK/00?0n003o0P00hG<004NS0000G4H000dX00036P00
93T007PT0:bo003b=P00oPD00=im000hWP0005M:000;9@000a/002/m001n6034a000mB/00?d:003I
SP008YL0001AC@00228000@M000g@`00Q`H0c;400?TL003k5000dJ@000N<0000@4P000DN00068000
BT`05Y800=JG003l3@00mRH00<K00000OaD002`n00036`002bD005U903nQ003PMP00o`<00?10002D
^@00070`000K<`000QT001@^001X>P1g/@00je000?l0003UI@00EJP0001OA0003RP000<J000V>P00
Nah0_/<00?D[003m2`00ei<001RC0000BT`200067`250016BP0BT@00eYL00?`=003f:@00`l@0001l
70009SX000TR001P@`1LZ@00if000?l0003YF@00IJ`0001R@@0042X0008J000T>@00NQl0_/<00?DZ
003l3000eIP0012@0000@dT000DN00078000D4h09IP00=^6003n1P00lSP009jk0000LBh001Xb0002
6@005c0006dd08jg003`@000o`<00=in000^V`00059=00088@001Ah0045800j?003EV000o@`00?D/
002e`@0007LU000O=P000QT001@]001Y>@23]000kTD00?l2003ON`00<I`0001BC@00224000DN0012
B@0BT@00ei@00?d:003c<@00Z;h0001c:`006c<0008I000H<000Kc40V[X00?8h003n1`00fHd001VD
0000Ad/000DN00078@00DTd0<9`00=mj003o0P00kDT007Vb0000ISd0014[00026P009SX007hG0<Rk
003i7@00nQP00<^d0000PQ4002Xl00036P003bT006@o07>`003/C000o`800=mi000`W000055=0007
80001Ql004a=02BH003MPP00o`<00>i5001m/`0006Hl000A:`000QX002Tl00214P3;]000nQP00?PO
0037_`0007/M000R>0000QT001D^001]=00:ooooo`7o00000Oooool000Oooooo00Co0000oooooooo
oooo00002?ooool2o`0000Wooooo00?o0000ooooooooool01oooool0o`00>DD000HO00047000:3/0
07@Z086d003XG@00o`800?<d0037_`0008P20017B`00228000<K000P=P00KC@0JZd00>A/003n1@00
mBX00<^c000:SP0004m>000:90000aX001`d001Y>@1NZP00hG<00?h7003f9@00cJh000n@0000DDd0
00/U00026P006c<006Tj05bZ003QL`00oPL00?HV003=/00038l0001@CP002R@000<J000M=@00JcL0
IZ`00>=/003n1000mB`00<Vi0002RP0004U<00088P000a/002<h001a;`1k/P00ieh00?l1003b>@00
_/<000233P00>dD000HO00047@00;Sh007XP09fk003]BP00o`000>a=002G^P0007PS000[?@0011`0
00LP0010B000QPL0a/000?<a003o0`00i6T006N]0000JSP001`c00026P0032H005E<01jE003CWP00
nQT00?`@003HS`00<I`0001JB0003bT0008I000G<000ICh0EjP00>5c003n1@00mB`00<Rk0000R0<0
04590007800011`002dn001j7`2T_@00kd@00?l0003YF000P;<0001`;`008CL000<J000:9000DTd0
MIX00?TI003k4@00ei8002ZJ0000EdX000dW00026P0073<006/f06n_003WH@00o`400?0n002]_`00
07`K000^?`0011`000LP0014BP01RP00bk@00?LU003m2P00gH8003fP0000GDH0010Z00026@006340
06Pj06F/003UIP00o`800?4k002``00007`K000^?`0011`000LQ0018C008S@00cZd00?PO003l3P00
fHh002fK0000EdX000`W00026P007cH0070`08Be003[DP00o`000>]@0027]@00074_000P=P000QX0
00`W001GBP0_V`00fX/00?d<003g8P00c;<000290000@4P000HO00057P00=d@008@<0<Nn003e:P00
oPP00=f1000kW`0005]7000>:0000QX001he001_<@25]@00je000?l0003ZEP00Nk80001]=@006c<0
008I000@:P00GT@0BJ@00>1f003n1000lc@00;S10000OAX002`n00036`002B<0055=01bE003FU`00
na400?PM003=[P000XX00011B0001Ql000DN000mAP00R080c;800?PP003l3`00eiD001nF0000DDd0
00TS00047000;Sl007lG0<74003d;`00oPL00=f1000gWP0005Q9000<9P00l`000aX002Di001h902X
_P00lCX00?l3003QL`00B:@0001MAP003RT0008J000P=P00Lb/0V;X00>m2003o0@00hf`005:W0000
H4<0010Z00026@007SD0074^09>h003_A000o`400>A[001CY`000613000@:P000QX001he001b;02G
^P00kd400?l2003RK`00C:D0001NA@003RP0008J000R=`00MRH0Y[d00?4i003n1000ggT003fP0000
FDT000`V00036`00:C`007`K0;k3003d;@00o@T00=Z:000VV000059=00088P0011`003A200252@3;
]@00n1h00?/C003BX@002hh00013B@001Al000HO0017B`0BT@00eIX00?`?003g8`00b;`000214P00
;Sl000<K000:9@00EdX0>Yl00=mi003o0`00l3d009Zj0000LRd001`d00026@004bd006Ll076_003Z
E000o`000>IR001KZ@000613000?:@000QX002@i001i8@2h`P00m2h00?d:003HT00079D0001=CP00
1b0000DN0013B@0>S`00e9/00?`>003f9P00aL80001m6@00:3/000TQ001NA01FZ000iV<00?l0003Z
EP00Jjh0001T?`004B/0008J000R>000N280^<400?D]003m2`00ei@001BB0000AT/000DO00068000
CTh089H00=Z:003n1`00lSD00:Bm0000Lb`001`c00026@005Rl006/f08Rf003_@`00o`<00=mk000b
W@0005=<00088P0011d003i700Z>003DW000o0d00?DZ002k`P0007PR000Q=`000QT001</001X>`1m
/`00kDT00?l2003PM`00=Yh0001DC000228000DM000oB00>S`00eYL00?d;003d;`00[[l0001e:@00
7C@0008I000F;`00KS<0U;T00?4k003n1P00fXT001jE0000BT`000HO00078000D4h0;9X00=im003o
0`00kTH007nc0000Ic/0018/00026P009CT007dJ0<Nn003h7`00nQH00<f`0000P`d002`n00036P00
3RT0069106f^003/C`00o`400>5e000dW@00059=00078@001Ah004U<022F003LQ@00oP@00>m20023
]00006Pk000B;0000QX002Lj001o5@3:]`00nAX00?TM0038_00007dJ000T>@000QT001@]001[=`0:
ooooo`7o00000Oooool000Sooooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool0o`00?4H000LP000470009SX0078/07bb003WH@00o`800?<a0038_0000HX0001:
C@002B<000<J000O=@00JcH0I:`00>9_003n1P00mRL00<f`000>S`00055=000;9@000QX001/c001X
>`1HZ000h7H00?h8003g8`00cj/001>A0000DTd000/V00026P006S8006Ll05NX003PM`00oPP00?LT
003>[0004900001AC@002bD0008J000L<`00JST0HJ/00>9_003n1@00mBX00<^e0005S00004a=0009
8`000a/0024g001_<@1f/@00iV400?l2003b=P00a<@000242`00?TL000HP00047000:cd007PS09Ni
003/C@00o`000>e:002M^`0007XP000]?P0011d000HP000mAP00Q0/0aL@00?<d003o0P00iFH006b^
0000K3H001dd00026P002bD005=<01ZD003BXP00nA/00?`?003JR`00=Id0001LA`0042X0008I000F
;`00I3l0DZH00>1g003n1P00mBT00<Zh0000R@0004A:00078@0011`002/m001i8@2N^`00kTL00?l0
003ZE@00QKD0001b;@008cP000<K000:9000DDd0Li/00?TK003l3`00fHh002nK0000FDT000hX0002
6@006S8006Xh06Z]003VI000o`400?4k002c`00007hH000a@00011d000HP0011B000R@40b[L00?HW
003m2000gWl004:R0000GTD0014[00026@005c0006Ll062[003TJP00o`800?8h002f`@0007hH000`
@00011`000LP0015BP04R`00cK000?LQ003m3000fXX0036L0000FDT000dW00026P007SD006lb07jc
003ZE@00o`000>a=002=]`00078/000Q=`000aX000`V001FB`0ZVP00fHl00?`>003h8000cJl000>;
0000@dT000HP00057@00=D80088?0<K1003e;@00oPL00=im0010X@0005a6000?:@000QT001`d001^
<`1o/`00jU<00?l0003[DP00P;@0001^<P0073@0008I000?:@00GDH0A:800=mi003n1@00lc400;k3
0000OQL002ho00047000228004m>01RC003DV`00na800?TK003?ZP001X`00013B@001Ql000DN000j
A@00Q`H0b[H00?LR003l3@00f94002>G0000DTd000TS00036`00;3d007dJ0;_2003c<@00oPH00=im
000kW`0005Y8000=9`00A@000aX002<h001f9P2R_000l3d00?l2003RL000CJD0001OA0003bT0008J
000N=@00LRd0T[P00>i5003o0@00i6P005NX0000HD80014[00026@0073@0070`08fg003^A`00o`40
0>EW001IZ@000652000A:`000QT001dd001a;P2B^000kT@00?l1003TJ`00DJH0001OA0003bT0008J
000P=P00M2T0X;`00?4l003o0`00h7H004:Q0000FTP000`W00036P009c/007/N0;S2003d<000oPP0
0=^6000[VP0005=<00098`0011`0039100233@3:^000n2400?/A003DW@003i000015BP0200067`11
0014BP0>S`00dih00?/A003h8@00bKT000233P00<40000<L000:9000ET/0=Id00=im003n1000lCX0
0:2l0000Lb/001he00026@004R`006Dn06b^003YE`00o`000>MN001PZ`000691000@:P000QX0028h
001h8`2b`000m3000?d8003IS00089H0001?CP001b4000DN0010B00:SP00dil00?`@003g8`00akl0
001o5P00:S`000PQ001MAP1AYP00iFL00?l0003[DP00L:l0001U?@004R`0008I000P=P00MbD0//00
0?@_003m2P00f94001RC0000BD`00P001Ql0J@00Bdd079D00=V>003m2000lc<00:Zn0000M2T001de
00026@0052h006Xh08>d003^AP00o`800>1g000gWP0005E;00098`0011d003]600J<003CW`00o0l0
0?HW0031a00007XO000S>0000QX0018/001V?01g/@00kD`00?l1003QL`00>il0001EB`002B<000@M
000mAP0:SP00e9/00?`=003e;000]<40001f9P007SD0008I000E;`00K3D0S[L00?0n003n1@00g8D0
02:G0000CDh000HO00068000Cdh09iT00=f1003o0`00kd<008Be0000JCT001<]00026@008cP007/M
0<K1003g8P00na@00<j]0000Q@X002ho00036`003RP0065206R]003[DP00o`000>9b000iW`0005A<
00088@001Ah004I;01^D003JR@00oPD00?0o0029]P0006Ti000C;0000QX002Di001n6039^`00nA`0
0?TK0039^@0007hG000V>P000QX001</001Z>00:ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool0o`00?TL000LQ00036`009CT0074_07Ja003VI000o`<00?@^0039^@0018/0001=
CP002R@000<J000M=000JSP0GjX00>5c003n1`00mbD00<j/000BT@00059=000<9P000QX001Tb001V
?@1CY`00ggX00?d9003h8@00d:L001NC0000E4`000`V00026P006C4006Hm05:W003ONP00o@T00?LQ
003?Z@005980001BC@002bH0008J000K<P00J3X0G:T00>5c003n1P00mRL00<bb0009S@0004m>0009
90000aX0020f001^<`1`[`00iVD00?l2003c<`00a/4000261`00@4P000LP00047000:S`007LU096h
003[D000o`000>i6002S_00007/M000_?`0011d000HO000jA@00P`h0`<<00?8g003o0P00iV<0076`
0000KC@001le00036P002bD0059=01JB003AY@00nAd00?`=003KR000>Yl0001MAP004B/0008I000E
;P00HT40C:D00=mj003n2000mRL00<^d0003R`0004M;00088@000a`002Tl001g902H^P00kDX00?l0
003[D@00RkH0001d:P0093T000<K00098`00Cdh0L9`00?PM003l3P00fX/003BM0000FTP000lY0002
6@006C4006Pj06B/003UJ000o`800?8h002i`P0007lE000c@@0011d000HO000oA`00Q`D0bKX00?DZ
003n1`00gg/004NS0000H4<0018/00026@005Rl006Dn05^Y003SK@00o`<00?8e002l`P0007lE000b
@@0011d000HP0012B@00RP00bk<00?LT003m2`00fhH003JN0000FTP000hX00026P0073@006dd07Vb
003YF@00o`000>e:002C^00007@Z000S>0000aX000/U001EB`0VV000ei800?`?003h7P00cZ`000N<
0000AT/000LP00047@00<d40084B0<C4003d;`00oPH00=mj0015XP0005i5000@:P000QT001/c001/
=@1i/P00jUL00?l0003/C`00Q[D0001`<0007SD0008J000>:000G4L0?j400=im003n1P00m2l00<C4
0000P1@0031000047000224004i>01BB003CW`00na@00?TI003@Y`002Xh00016B`001b0000DM000h
A000Q@T0bKT00?LU003m3000fHd002NI0000E4`000XT00036`00:S`007/M0;G1003c=000oPD00=mj
0010X@0005]7000=:000l`000QX0024g001d:@2L^`00l4000?l2003SK000DjL0001P@`0042X0008I
000M=000L300SKL00>i8003o0000iFD005fZ0000Hd00018/00026@006c<006hb08Re003]BP00o`00
0>IT001NZP0006=0000B;0000QT001/c001_<@2<]`00kTL00?l1003UJ000EZP0001P@`0042X0008I
000O=@00Lb/0V[X00?0o003o0P00hG8004NS0000G4L000dW00036P009CT007TQ0;;0003c<`00oPH0
0=b3000_V`0005E;000:90000a`0031000224038^`00mb<00?`?003EVP004i400018C0001R0000DN
0011B@0:SP00dZ400?/C003h7`00bkH000242`00<d4000@L00098`00E4`0<9`00=f1003n1@00lSL0
0:Fm0000MBP001lf00026@004B/006@o06J/003XFP00o`000>QK001U[00006=0000A:`000QX0024g
001f9P2/_`00lc<00?h7003KR0009IP0001@CP001b4000DM000mA`06S000dZ800?/B003g8@00b;/0
00204`00;3d000PQ001LA`1<Y@00i6X00?l0003/C`00M[40001W?0004b`0008I000O=@00MBP0[;l0
0?<b003m2000fHd001fE0000C4d000HP00067`00B4`069<00=RA003m2P00m3000:no0000MRL001lf
00026@004bd006Pj07fc003]B@00o`400>5d000lX00005I;00098`0011`003U400>;003BX`00na40
0?LU0035``0007`M000T>@000QX0014[001U?P1b/000k4l00?l1003RL000@:40001GBP002B<000@L
000jA@06S000dih00?`>003e:@00^/80001h8`0083H0008I000D;P00JSL0RKH00>m1003o1000gH80
02JH0000Cdh000HP00067`00CDh08iL00=b4003n1000l40008Zf0000JSL001@]00026@008CL007XP
0<C4003g9000na<00<nY0000QPL0031000036`003BL005m406:[003ZEP00o`000>=^000nX00005E;
00088P001Ah004A:01NC003IS000oPH00?4l002>]`0006/g000D;@000QT002<h001l6`37_P00n1h0
0?XH003;]@00080D000W>`000QX0018[001X>P0:ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool0o`00@DP000LQ00036`008cP006la076_003UJ000o`@00?D/003;]@0028d0001?
CP002R@000<J000L<`00J3X0FZT00>1f003n2000mb800<nY000FTP0005=<000<9P000QT001Pa001U
?P1>Y@00gWd00?d;003h7P00dJ@001bD0000ED/000dW00026@005c0006@o04fU003NOP00o@X00?PO
003AYP006I<0001DC00032H0008J000I<P00Ic`0EZP00>1f003n1`00mbD00<f^000=S`00051>000:
90000aX001he001/=@1[[P00iFP00?l3003d<000akh000271000@dT000LQ00037000:3/007DX08bg
003ZD`00o`000>m3002X_P0007dJ000a@@001Ad000HO000hA000PA40^/800?4j003o0@00iel007Na
0000Kc80020f00036P002R@0051=01:A003@Z000n1l00?d<003LQ000?j40001NA0004R`0008I000C
;@00HD80B:<00=in003m2@00mb@00<ba0007S00004Y<00088P000a/002Lk001f9`2C^000k4d00?l0
003/CP00TKP0001e:0009SX000<K00098P00CDh0KId00?PP003m3000fhL003RN0000G4L000lZ0002
6@00630006Ll05nZ003TJ`00o`<00?<e002o``00084B000e@P001Ah000HO000lAP00Q@P0akh00?D/
003n1P00h7P004bU0000HD8001</00026@005Bh006@o05FX003RL@00oP@00?<c0032a000084B000d
@P001Ad000HO0010B000R080b[L00?HV003m2@00g8<003^O0000FdL000lY00026@006c<006`f07>`
003XG000o`000>i6002H^P0007DW000U>@000a/000XT001CC00QU`00eYH00?/A003i6`00d:P000^>
0000BD`000LQ00047000<D0007lE0;o3003c<P00oPD00>1f001:Y00005m4000@:P000QT001Tb001[
=`1d/000jEX00?l0003/C000RkL0001a;P007cH0008J000=:000FTP0>Yl00=f1003n1`00mB`00<K2
0000PA4003=100047@001b4004]=012@003BXP00nQH00?XG003AY0003Xl00019C0001b0000@M000e
@`00Q0`0b;`00?HW003m2P00fXX002bJ0000ED/000XU00036`00:3/007XP0:no003b=`00oP@00>1f
0015X`0005e6000>:000l`000QX0020f001c:`2F^@00kd<00?l1003TJ@00F:P0001R@P004B/0008I
000K<`00Kc80QkD00>e;003o0000iV8006:[0000I3l001</00026@006S8006dd08:d003/CP00o`00
0>MP001S[00006@o000C;0000QT001Xb001^<`26]@00kD/00?l0003VI@00G:T0001R@@004B/0008I
000M=000LBh0U;T00>m2003o0P00hfl004^U0000GDH000hX00036P008cP007LT0:bo003b=@00oPD0
0=eo000dW@0005I;000:90000a/002ho00204`37_`00mRD00?`=003FUP005i<0001;C@001b0000DN
000oA`06S000dJD00?/D003i7000c;8000262000=D8000@L00098`00Dd`0;9X00=b4003n1P00lcD0
0:^n0000MRH0024g00026P0042X00691066[003XGP00o`000>UH001Z[P0006Dn000B;0000QT001lf
001e:02W_@00lSH00?h6003LQ@00:IT0001BC@00228000@M000kA@02R`00dJH00?/D003h7`00bKP0
00224000;Sl000LQ001JB017X`00hfd00?l1003/C000Nk80001X>P0052d0008I000M=000M2X0Y[d0
0?<e003n1`00fXX0026F0000CTh000LP00057P00ADX04i400=NE003m2`00m2d00;G10000Mb@0020g
00026@004R`006Ll07Ra003/C@00o`400>9`0011X@0005M:000:900011`003M30029003@YP00na80
0?LR0036`00007dJ000V>P000QX0010Z001S@01][P00je800?l0003SK000A:80001HB@002R@000@L
000hA002RP00dZ800?`@003f9`00`<<0001i8@008CL0008I000C;@00JCT0Pk@00>m4003o0`00gWh0
02^J0000D4h000LP00067`00BT`07YH00=^8003n1@00l3d0092h0000K3D001D^00026@0083H007PS
0;k3003f9P00na400=2V0000R0<003=100036`0032H005i505fZ003YF@00o`000>A[0013XP0005I:
00098`0011d0045801>A003HT000oPL00?4i002D^@0006`e000E;P000QT0024g001k7P36`@00n200
0?XF003</P00088A000Y?0000aX0014[001W?00:ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool0CP00A4X000PR00036`008CL006hc06b^003TJ`00oPD00?DY003</P0038l0001@
C@002bD0008J000J<P00Ic`0EJL00=mi003m2@00n2000=6V000JU00005E;000=9`000QT001L`001S
@019Y000gH400?d<003i7000dZ00022F0000ETX000hX00026@005Rl006=004RT003MP@00o@`00?TM
003BXP007ID0001EB`003BL0008I000H<@00ICh0DJH00=mj003m2@00mb800<n[000AT@00055=000;
9@000aX001dd001[=`1V[000i6`00?h4003d;P00b;/000290000AT/000PQ00036`009SX007<Z08Je
003ZE`00o`000?10002^_`0007hH000d@P8000DN03d003I300205@2d`@00l3d00?l1003XG000O;80
001`;`008SL000<K00098`00Cdh03Xl00<j/003g8@00o@X00=f10014XP000613000C;0000QT0018/
001P@`13XP00gH400?d:003g8P00cZh000^>0000CDh000TS00036`009CX007@Y08fg003[D000o`00
0>e;002F^@0007LU000X>`000a/000PR001:C@1[WP00mb800?d;003LQ000?J00001MAP0042X0008I
000F;`00ISd0FZT00>=_003o1000lc800<C40000PPl003M4008000DN0?l003Y500243036`@00m2l0
0?h5003QM000DJH0001R@@0052d0008I000C;@00HT40DJH00>5d003n1@00m3000<G30000P`l003M3
00057P001Ql003e600271P39^P00mRP00?h8003MO`00?j40001MAP0042X0008I000I<P00JSP0KZl0
0>MO003o0000kd<009jk0000MbD002Hj00036`002R@0059=01fE003EV@00na<00?TI003AY@003i00
001<C@00224000@L000^?`00OQP0^L800?<e003o1000hG<004jU0000H4<0014[00026@00634006Ti
06n_003XG@00o`000>e9002A^00007</000Q=`000aX000dW001IB@0eW@00g8@00?d9003e:P00akl0
00233P00=D8000@M00078000B4/038h00=6U003j6000nQD00=>P000BT@0004a=00078@0011d003=1
00224036`000mBX00?d9003KQP00<9`0001GBP002bD000<J000V>P00N280Z[h00?4j003o0`00hG<0
04ZT0000GTD000lY00026P007SD0074^096h003^AP00o`400>EV001MZP0006=0000B;0000QT001Xb
001]=022]000k4h00?l0003WGP00Ijd0001V?@0052d0008I000H<@00JcH0OK<00>]A003o0000j5d0
06R]0000ISd001@]00026@006C4006`e086d003/CP00o`000>MQ001QZ`0006=0000B;0000QT001`c
001`<02?]`00kTD00?l1003TK000D:H0001OA0003bT0008J000R=`00MRH0Ykd00?8h003n1000gg`0
03VO0000EdX000/U00036`00;3d007lF0<K2003f:000o@`00=NC000KU00004i>00078@001Ad003a6
00::003@Z000nQH00?TJ003=[`0008L4000g@`0011d000PR001BC@0WV@00fhP00?h7003c<P00/L00
001h8`008cP0008J000?:@00HD80G:T00>MQ003o0000jU@0072_0000ISd001</00026@007CD007<[
0:6l003b>@00oPD00=f1000^V`0005=<00088P0011d003Q40029003?Z@00nQD00?TM003;]@0008<=
000`@0001b0005U904:R003RL@00o`400>e90021]00006Xh000E;P000QT001`c001b;02P_000lSP0
0?h6003KQP009IP0001@CP001b4000DN0012B@0?T000eIP00?d<003e:`0006@0^l80001i8@008SP0
008J000A:`00ICd0L[000>]@003o0000hfd004FS0000FDT000XT00047000=48008P40<nY003k5000
n2000<Rm0000OaL002Pk00036P003bT0069106N]003ZE@00o`000>AY0019Y00005U8000:9@0011`0
03I30029003AY@00na400?LT0035a00007/N000S>0000QX0018/001X>`1n/`00kTL00?l2003ON`00
;i/0001BC@001b4000DN0017B`0JU000fX/00?h6003a>P00UKT0001]<`005Rl0008I000N=@00MbD0
^L800?HY003l3`00dZ<000290000=D8000<K000;9P00GDH0F:P00>QL003o0000iFL004RS0000F4X0
00TS00047@00?TL03i000=NC003m2000lSH009Zj0000KS<001H_00026@0083H007TQ0<G4003g8`00
naD00<f_0000P`d002/m00036P0042X006Dn2_ooool1o`00007ooooo000Nooooo`03o`000?oooooo
oooo00Oooooo04h004I;00088P000a/0020f001/=@1W[@00hfh00?h6003f9`00cJl0012@0000DTd0
00/V00026P006C4006Hm052V003NO@00o@/00?PN003BXP007YD0001FB`003RP0008I000F;`00HT40
AJ800=b4003l3@00nAX00=BM000TV00005Q:000>:@000QT001D^001Q@P13XP00g8@00?`=003i6`00
dil0026F0000EdX000hX00026@005c0006@o04fU003NO@00o@X00?PP003@Z0005I80001BC@002bH0
008J000K<`00JCT0HJ/00>=_003n1@00mB/00<Zh0002RP0004U<00088P000a/002@i001b;@21]000
jEX00?l0003`?@00]<4000205@00=T<200057P0m000c@P00OQP0[kl00?10003o0000jET0086d0000
LRd002<h00036`002B<004e>00Z>003=[`00mb@00?d9003NO@00B:@0001Q@P0052d0008I000A:`00
GTD0?Z000=b4003m2`00n2000<nZ000>S`0004m>00098`000a/002@i001c;028]P00jU<00?l0003^
B000W;/0001h8`00:S`000@L00088@00B4/0JIl00?LT003m2@00gH0004:Q0000Gd@0014[00026@00
5Bl006@o05FW003RLP00oPD00?@_0036`@0008@<000jA@0200057P0C000gA000PPl0aL@00?<a003n
1000hW4005JX0000I3l001D^00026@004R`0065204bU003PM`00oPH00?@]0036`00008@;000iA@02
00057P2U000kA@00Q@T0akd00?D[003n1`00gg`004BR0000GTD0010Z00026@00634006Tj06V]003V
H`00o`400?10002S_@0007PR000X>`000a/000TS001AC@0IU000e9`00?/D003j5`00dZ8001>A0000
CTh000PR00047000;3h007`K0;?0003b>000o`<00>9_001CY`000691000B;0000QT001L`001X>P1Z
[@00if000?l0003^AP00U[T0001d:@008SP000<J000<9P00EdX0<I`00=^7003m2P00mRL00<Rk0000
Q0/003M400057@001R0004E:00R=003?Z@00nAX00?/C003DW@005Y80001?CP00228000@L000a@000
PA<0aL<00?D/003n2000g8<003FM0000F4T000`V00036P0093T007LU0:Bm003a?@00o`800>9`001?
YP0005m4000@:P000QT001dd001`<02;]P00kDT00?l0003VHP00HZ/0001T?`004bd0008I000I<@00
K3H0O;<00>]A003o0000j5/006b^0000Ic`001D^00026@005c0006Xh07Na003ZE000o`000>UJ001]
[P0006Lk000E;P000QT001P`001[=`1k/P00je400?l0003WGP00IZ`0001U?P004b`0008I000J<P00
KS80RKH00>e8003o0@00i6P005FW0000H4<000lZ00026P0083H007@Y0:6l003a>`00o`@00>1i000m
X00005U9000;9P000a/002Xl001m6@34a000mBX00?d;003HS`007iH0001@CP001b4000@M000jA@00
R@00cZ`00080nQP00:L0cZ`000290@00>DD000@M00088@00D4d08iL00=Z;003m2@00m2l00;O10000
NB4002@i00026P003RT005m405NX003VI000o`000>]A001e/@0006Lk000D;@000QT001`d001b;@2K
^`00lC`00?h4003NOP00<Y`0001DC0002B<000@L000f@`00R0@0cZ`00?XG003i6`00c;8000252@00
<T4000LP001GBP0nX000hG@00?l2003^AP00Q[D0001[=P005Rl0008I000K<P00LBl0VkX00?4j003n
1@00g8<002ZI0000DDd000LQ00057P00@4P038h00=BL003l3P00mRP00<740000NQl002@i00026P00
42X006@o06f^003[D`00o`000>AY001:Y00005Y8000;9@000a/0039100261`3>[@00nQH00?PN0039
^@00080D000Z?0000aX000hX001Q@`1RZ`00jET00?l0003UIP00CZD0001KA`002bD000<K000c@P00
Q`@0cjT00?/C003g8P00a/40001l6`009CT0008J000A:`00ISd0N;400>e:003o0P00h7L003BM0000
Dd`000PQ00057P00A4X05Y800=R?003n1`00lSL009^j0000Kc4001L`00026@007C@007DX0;?0003e
:`00o0h00=>O0003R`0003M3000470002bD005]705>W003WH000o`000>IT001<Y@0005U9000:9000
11`003a600^>003FU`00o@X00?<c002O_00006la000G<0000QT001he001h902o``00mbD00?/C003>
Z`0008D:000]?P000aX000lY001T?`0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool0
1oooool0o`00BD`000TS00036P007SD006/g066[003RLP00oPL00?LT003>Z`005980001CC00032H0
008I000H<000I3l0Bj@00=f0003m3000nA`00=>O000RU`0005M:000>:@000QT001D^001Q@`10X@00
fhP00?`?003j6000eIX002RI0000FDT000lY00026@0052d0061303nQ003KR000o0l00?XI003DV`00
9IP0001HBP003RT0008I000F;`00HT40B:<00=f1003m2`00n1h00=6T000IU00005A<000<9P000QX0
01Xb001X>`1LZ@00hW800?h6003f:@00bk@000J<0000Bdd000TS00036`008SP0074_07bb003XG@00
o`400?4k002i`P00084B000hA0001Ql000DM000a@000OAX0ZKh00>m2003o0000jUD008Ne0000Lb/0
02Di00036`00228004Y=00J<003</P00mRH00?h8003ONP00CJD0001S@0005Bh0008I000A:`00GDH0
>Yl00=^8003l3@00n1h00=2W000BT@00051>000:90000aX0028h001a;P22]000jUL00?l0003^A@00
XK`0001j8000;3d000@L00078@00ADX0IZ000?HW003m2000gWd004JS0000H4<0018/00026@0052h0
06=0052V003QM@00oPH00?D]0037_P0008D8000lAP001Ql000DN000e@P00PA80`<<00?<d003o0`00
hfh005^Y0000ICh001H_00026@004R/005m404NS003ON`00oPL00?D[0038_@0008H8000kAP001Al0
00DN000hA000Q0`0a/000?@]003n1P00h7T004VT0000H4<0014[00026@005c0006Lk06B/003UIP00
o`400?0n002Y_P0007XO000Z?0000a/000TS001?CP0ETP00dj000?XF003j5@00dih001NC0000D4h0
00TS00036`00:cd007/N0:jo003a>P00o`800>=/001HZ00006=0000C;@000QT001H_001W?01T[000
iV@00?l1003_@`00W;/0001f9`0093T000<J000;9@00ET/0;I/00=Z;003m2`00mbD00<Vh0000QPL0
03Y500057P001Ql0049900B;003>[000nA`00?/B003EV@006Y@0001@CP00228000@L000_?`00OaH0
`/@00?@_003n1`00gH0003VO0000FDT000`W00036P008cP007DW09nk003`?`00o`800>=/001DY`00
0652000A:`00l`000QT001/c001^<P26]@00k4`00?l0003WG`00Ijd0001V?@0052h0008I000G<000
JSP0Mk400>YD003o0000jEP0076`0000J3X001H_00026@005Rl006Tj07:`003YE`00o`000>YF001c
/00006Tj000F;`000QT001H_001Y>@1f/@00jU@00?l0003XF`00Jjh0001V?@0052d0008I000I<@00
KC@0Q;D00>e;003o0000iFD005ZY0000HD80010Z00026@007cD007<[09bk003`?P00o`<00>5e0012
X@0005Y8000<9P000aX002Pk001l702n``00mBd00?d9003IS0008iL0001AC@00228000@M000hA000
Q`@0cJl00?TJ003j5P00d:P000::0000?4H000DM00078@00Cdh07iH00=V>003m2P00mBd00;c30000
Nah002Hj00036P003RP005i505:W003UJ000o`000>a>001j/P0006Ti000E;P000QT001/c001`;`2F
^@00l3h00?l3003ON`00=Yh0001FB`002B@000@L000d@P00QPL0cK000?TI003j6@00cJh000261P00
=48000LP001FB`0iW`00h7P00?l2003_@`00RkH0001]=0005c00008I000I<P00Kc40UKT00?0m003n
1000gGl002jK0000DTd000PR00047@00?DL028d00=>O003l3`00mRH00<G30000O1`002Dj00026P00
42X006=006R]003ZEP00o`000>EV001?YP0005a7000<9P000a/0031000252P3=/000nQP00?TL003:
]P00088A000/?@000aX000dX001OA01MZP00j5`00?l0003VHP00DjL0001LAP0032H000<K000a@000
QPL0cZ`00?XE003h8000akd0001n60009SX0008J000@:P00ICh0Lk000>a=003o0@00hG@003RN0000
E4`000PR00057@00@TT04Y400=NB003m2@00lc@00:2l0000L2l001Pa00026@006c<007@Z0:fo003d
;P00o@`00=BL0007S00003U5000470002R@005Y804jU003VH`00o`000>MQ001AYP0005]8000:9@00
11`003U500R=003EVP00o@/00?@a002U_@00074_000H<@000QT001dd001f9P2i`P00mRL00?/A003@
Z00008H7000_?`000a/000hX001R@@0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool0
1oooool0o`00C4d000TS00036P007C@006Xi05fZ003QM@00oPP00?LR003@Z00069<0001DC0003BL0
008I000G<000Hd00Aj<00=b4003l3@00nAX00=BL000VV00005U9000?:@000QT001@]001OA00kW`00
fX/00?`A003j5P00eYH002bJ0000FTP0010Z00026@004bd005m403ZO003JR`00o1000?XG003EV000
:IT0001IB@003bT0008I000E;P00HD80@j800=b4003l3@00nA`00=:Q000MU@0005E;000=9`000QT0
01Ta001V?01GZ000hGH00?h7003f9P00c;4000V=0000CTh000TS00036P008CL006la07Ja003WH000
o`400?8h002o``0008<?000jA@001Ql000@M000_?`00Nad0Y;d00>i5003o0000je8008bg0000MBT0
02Lj00036`00228004Q;00>;003;]P00mRP00?h7003PM`00DZH0001T?`005Rl0008I000@:P00FdL0
=Id00=Z;003l3P00nA`00=6T000FTP00059=000:90000aX0024g001`<01m/`00jEX00?l0003_@P00
Ykd0001k7P00;Sh000@L00078000@TT0IJ410?HY003n1`00ggX004^T0000HD8001<]00026@004bd0
065204bU003PN@00oPL00?DZ0038^`0008L5000oA`001Ql000@M000c@@00OaD0^/800?8g003o0P00
i6X005nZ0000Ic`001L`00026@004B/005i504:R003NOP00oPP00?HX0039^P0008L5000nA`001Ql0
00DN000f@`00PQ00aL<00?@`003n1@00hGD004jU0000HD80018/00026@005Rl006Hm05nZ003TJ@00
o`800?4k002^_`0007/M000/?@0011`000PR001>CP0AT@00dJ<00?XH003k5000e9/001ZD0000DDd0
00TS00036`00:C`007TQ0:Rn003`?@00o`800>AY001MZP0006Dn000D;P000QT001D^001U?P1PZ`00
iFL00?l1003`@000XK`0001g90009SX000<K000;9@00ED/0:9T00=V>003l3@00mb<00<^e0000Q`@0
03a600057P001Ql00418006:003=[`00n1h00?`@003FUP007YD0001AC@002B<000<L000]?P00OQT0
_<<00?<a003n1P00gW`003jP0000FdP000dW00026P008CL007@Z09Vj003_@P00o`400>AY001HZ000
0691000B:`00X0000QT001Xb001]=021]000jdl00?l0003XG000K:h0001W>`005Bh0008I000F;`00
JCT0L[000>UH003o0000jUD007Ja0000JSP001L`00026@005Bh006Lk06f^003YFP00o`000>YC001h
/@0006Xh000G<0000QT001D_001X>P1a[`00jEL00?l0003YF000L:l0001X>`005Bh0008I000H<@00
K3H0Ok<00>a>003o0000iV8005nZ0000Hd00014[00026@007C@0078]09Ji003_@@00o`800>9b0016
X`0005]7000=9`000aX002Hj001j7`2h`P00m2l00?h8003KR@009iT0001BC@00228000@L000e@`00
QPL0c;800?TL003k5@00dJD000F<0000?TL000DN00078000CDh06i@00=RB003m2`00mBX00<;40000
O1/002Pk00036P003BL005e604fU003TJ`00o`400>e;001o/`0006Xh000F;`000QT001Tb001_<@2A
^000kd400?l3003PM`00>il0001GBP002R@000<L000b@@00Q@X0c;<00?TK003j5`00cZ/000280`00
=T<000LP001EB`0eW@00gg/00?l3003`@000TKP0001^<P006340008I000H<@00KS<0T;P00?10003o
0`00gW`003:L0000E4`000PR00047@00>dD018/00=:R003k4@00mb<00<K00000OAT002Lk00036P00
3bT0065206>/003YF@00o`000>IS001DY`0005e6000<9`000a/002ho00233@3;/`020?TJ001A0<^c
0000P`h002hn00036`003BL005i505RX003WG`00o`000>MO001HZ00005e5000<9`000a/002lo0024
2P3=[`00nQL00?PN0039^P0007lF000X>`000aX000lZ001S@01^[`00je000?l1003RL@00?J00001E
B`002B8000@M000oA`0>S`00eYH00?d:003c<P00Y[d0001b;@006S80008I000J<P00LR`0Z;h00?@`
003m2`00eIT000Z>0000?4H000@L000:9000FDT0BZ@00>EV003o0000j5h005JX0000G4L000/U0004
7000=d@018/00=BM003l3000m2h00:Zn0000LR`001Tb00026@0073<007DX0;C1003e:P00o0l00=6U
0000R0@0035000036`003BP0065200[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07
ooooo`3o001>CP002R@000<J000L<`00J3X0F:P00>1h003m2@00n2000=6U000LU00005I;000>:000
0QT001H_001Q@P12XP00fhL00?`?003j6000eIP002ZJ0000FTP0010Z00026@004b`005i503NN003I
SP00na800?/D003GT`00<I`0001LA`004B/0008I000B;000GDD0=Yh00=V>003k4P00nQD00=JE000]
V`0005Y8000@:P000QT001@]001P@`0oX@00fhL00?`>003i6P00dih0026F0000ETX000dX00026@00
630006Dn05:W003PN@00oPP00?LT003=[P003Hl0001?CP002R@000<J000O=P00KS<0LK000>IS003o
0P00lSD00<C40000Q0/003e60006800011d002dn001j802N^`00kDP00?l0003/C`00TKP0001f9P00
:3/000@L00078@00ADX008T00<Vi003e:`00oPH00>5d001FZ00006Dm000G<0000QT000lY001JB00a
W000fHh00?`@003i6P00dZ4001ZD0000Dd`000/U00036P007cH006hb07Ra003XG@00o`000?0o002/
_`0007`K000`@00011d000HP0010B01TX@<0mB/00?h6003PMP00D:H0001S@00052h0008I000B;000
H4<0Aj<00=il003n2000mRP00<Zh0000R08004580006800011d00350001n602e`@00lCT00?l2003U
I`00I:`0001X>P006340008I000@:P00GDH0?Z000=f1003m2@00mRH00<Zf0000R080041800068000
1Ad003A200214P31a000lc<00?h4003RLP00DZL0001R@@004bd0008I000E;P00I3l0FZT00>=/003o
0`00lSP00;C10000OAX002ho00047000224004]=00j?003@YP00nAX00?/B003EV0007YH0001BC@00
2R@000<K000W>`00N2<0Xk`00?10003o0@00iFH006:[0000ISd001D_00026@0052d006@o05^Y003T
JP00o`800?0m002W_@0007TR000W>`000a/000XT001CC00TV000f9400?`>003h8000c;8000290@00
?TL000HO00057P00?DL008P10<bb003h8000o0h00=NC000RU`00059=00098`000a/002/m001l6`2g
`@00lc@00?h5003ON@00@Z80001LA`003RP0008J000P=P00Lb`0U;T00>i5003o0@00iFH005fZ0000
Hd0001</003c00026@006C4006`f07^b003[DP00o`000>UI001a[`0006Tj000F;`000QT001D_001W
>`1][P00j5/00?l0003[DP00Nk80001[=P006340008I000D;@00ISd0J:d00>QM003o0000je0007fc
0000JcH001Pa00026@0052h006Ll06b^003YFP00o`000>YE001e/@0006Ti000F;`000QT001L`001Z
>01j/P00je400?l0003WG`00I:`0001T?`004R`0008I000L<`00L2l0TKP00>m4003o0@00hfl004^T
0000GDH000dX00036P009CT007TQ0;?0003c<P00oPL00=b5000/VP0005=<00098`0011`003=10025
2P3;]@00n1h00?/C003BXP002Hd00011B0001Ah000HP001;C@0GT`00eYD00?`<003f:000aL<0001n
6@00:C`000<K000<9`00FdL0BJ@00>=^003o0@00kDP008Fe0000K3H001L`00026@00634006dc08^g
003_A000o`800>5d000oX@0005Q9000;9@000a/0031000233@3:]P00n1d00?XE003@Z00008T0000i
A0001R0005A<032L003NOP00oP@00?0m002F^@00070`000J<P000QT001L`001]=@2;]P00kd<00?l3
003PN@00=Yh0001EB`002B<000@L000iA001RP00dJD00?/C003g8@00akd0001o5P00:C`000<J000>
:000H4<0GZX00>QL003o0000if0005VX0000GTD000dW00036`00;3h0088@0<Zf003i7000nQP00<f`
0000Q0X0031000036`0032H005a605BW003VHP00o`000>QL001LZP0005m4000=9`000a/002dn0023
3P3</P00nQT00?TL003:]`00084C000Z?0000aX000lY001R@@1Y[@00jU<00?l0003SKP00@J40001G
BP002B<000@M000mAP0;SP00eIT00?d;003d;`00Zkh0001c:`006c<0008I000I<@00LBl0X[`00?<c
003m2P00eYD000j?0000?TL000@M00098`00EdX0AJ<00>AY003o0000j5/005^Y0000GDH000`V0003
6`00=D800HX00=:Q003l3P00mB`00;300000M2X001/c00026@006S8007<[0:jo003e;000o0h00=:R
0000R@0003=100036`003BL0061300[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07
ooooo`3o001@CP002bD0008J000J<P00Ic`0DjL00=mk003m2P00n1h00=:R000OUP0005M:000>:000
0QT001@^001P@`0nX000fXX00?`@003j5P00eYD002nK0000FdL0014[00026@004R`005e603>M003H
TP00na@00?/C003HT000=Id0001MAP004R`0008I000A:`00G4L0<Y`00=RB003k5000na<00=RB000b
W00005a7000A:`000QT001</001NA@0jW`00fX/00?`@003j6000e9/002FH0000F4X000hX00026@00
5Rl006@o04fU003OO000o@T00?LR003?Z`004I00001AC@002R@000<J000N=@00K3D0K:h00>EV003o
0`00lc<00<K10000Q@P003m70007800011`002/m001h8P2I^P00kD/00?l0003/C000UkT0001g9000
:S`000@L00078@00@TT008P30<Rl003e;@00oPD00>9`001KZ@0006Ll000H<@000QT000hX001IB@0]
V`00f9800?/B003j6000e9d001jE0000E4`000/V00026P007SD006dd07>`003WH000o`400?4l002a
`00007hH000b@@0011d000HO000mA`1TXP@0m2h00?h5003QL`00E:L0001T?`005Bh0008I000A:`00
Gd@0@Z800=eo003m2@00mRH00<^e0000RP0004A:0007800011`002lo001m6`2__`00lC`00?l1003V
I000JJd0001Y>@006C80008I000?:@00FdL0>Il00=b5003m2P00mb@00<^c0001RP0004=900078000
11d00391001o5@2l`P00lSD00?l3003SK`00EjP0001T?`0052h0008I000D;@00Hd00EJP00>9`003o
0`00lSH00;W20000OQL00310000470001b4004U<00Z>003?Z@00nA`00?`@003GU@008YL0001CC000
2R@000<K000U>P00MRH0WK/00>m3003o0@00iV<006N]0000Ic/001H_00026@004b`006=105JX003S
K@00o`800?4j002/_`0007XO000Y?0000a/000TT001BC@0PUP00eiD00?`@003h7P00cJl000::0000
@DP000HO00057P00>dH008L50<^e003g8`00o0d00=R@000VV00005A<000:90000a/002Tl001k7P2b
`000lSH00?h4003PMP00Aj<0001MAP003bT0008J000N=@00LBh0SkL00>e8003o0000iV<006:[0000
ICh001<]003c00026@00630006Xh07Ja003ZE@00o`000>YF001f/@0006Xh000G<0000QT001@^001V
?@1X[@00j5h00?l0003/C`00P;@0001]=@006C80008I000C;@00I3l0Hj`00>MP003o0000k4d008:d
0000KC@001Tb00026@004bd006Dn06N]003XG@00o`000>]B001j/P0006Xh000G<0000QT001H_001Y
>P1e/000jU@00?l0003XF`00JJd0001U?P004bd0008I000K<`00Kc80S;L00>i6003o0@00i6/0052V
0000GTD000hX00026P008cP007PT0:jo003c=000oPH00=f2000`W00005E<00098`0011`003500023
3@39^000n2000?/A003CW`0038l00013B@001Al000HO0018B`0CT@00eIP00?`>003f9P00a/00001o
5P00:cd000<K000<9P00FTP0A:800>9a003o0P00kTD008Zf0000KC@001Pa00026@005c0006`e08Je
003^A`00o`400>9a0014XP0005U8000;9@000a/002ho00224039^@00n1l00?/C003AY@000h/0000k
A@001R00059=02bJ003MP@00oPD00?4k002K^`00074^000K<`000QT001H_001[=`26]@00kTH00?l2
003PMP00>il0001FB`002B<000@L000f@`00R@40cjT00?/D003h7`00bKX000204`00:cd000<J000=
9`00Gd@0FJT00>MO003o0000j5d005fZ0000H4<000hX00036P00:Sd0080C0<Vi003h7P00nQH00<j]
0000QPL0039100036`002bH005]704nV003UI@00o`000>UI001QZ`000613000>:0000aX002/m0022
4@3;]@00nA/00?TJ003;]000088@000/?@000aX000hX001Q@P1T[000jUH00?l0003TJP00AZ<0001H
B@002R@000@L000jA@07S@00e9`00?`=003e;@00/<00001e:@0073@0008I000H<000Kc40WK/00?8f
003m2000ei8001:A0000@DP000@M00098`00ET/0@J400>=/003o0000jEL005n[0000Gd@000`W0003
6`00<d4008P20=6T003l3`00mBT00;G10000MBP001`d00026@006C40078]0:Vn003d;P00o0d00=>N
0002RP0003E300036`0032H005i500[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07
ooooo`3o001AC@002bD0008J000I<@00ICd0CjD00=io003m3000nA`00=>O000SU`0005Q9000?:@00
0QT001<]001OA00iW`00fHd00?/B003k5000ei8003>M0000GDH0018/00026@004B/005]702nK003F
U@00nQH00?/A003IS@00>Il0001NA@004bd0008I000@:P00FdP0;Y/00=JE003j5@00na800=V>000f
WP0005e6000B;0000QT0018/001MAP0fWP00fHh00?/A003j5P00eYP002VI0000FDT000lY00026@00
5Bl0069104VT003NO`00o@X00?PP003@Z0005980001BC@002bD000<J000M=000JcL0J:d00>AZ003o
0`00m3000<Nn0000Q`D0049900078@0011`002Xl001g9@2D^@00k4h00?l0003]BP00W;/0001i8@00
;3h000@L00078000@4P008H60<No003d;`00oP@00>=]001PZ`0006Pj000I<P000QT000dX001HBP0Y
V@00eYD00?/C003j5P00eIX002:G0000ED/000`V00026P0073@006`f06j_003VH`00o`400?4j002g
`@0007lE000d@P001Ad000HO000kA@1SX`H0m3000?h4003RL000FJT0001U?P005Rl0008I000@:P00
GDD0?Z000=b3003m2P00mb@00<bb0004R`0004I;00078@0011`002dn001k7@2Z_P00l3l00?l1003W
H@00KZl0001[=`006S80008I000>:000FTP0=Id00=^8003m3000mb800<f`0004R`0004E:00078000
11`00310001n602f`@00lSP00?l3003SK000G:T0001U?P005Bh0008I000C;000HT40DJH00>5c003n
1000lc<00;o30000P1D0039100047@001b0004I;00J<003>[@00n1h00?`?003HT@009YP0001EB`00
2bD000<J000T>@00MBP0V;X00>i5003o0000iel006b^0000JCX001P`00026@004R`00652056V003R
L000o`<00?8h002a`00007/M000[?@000a/000TS001AC@0LU@00eIP00?/A003i7000cZ`000F<0000
@dT000HP00057P00>D@008H80<Vh003g9@00o@`00=V<000ZV@0005E;000:9@000a/002Lk001i8@2/
_`00lCT00?l3003QL`00Bj@0001NA0003bX0008I000M=000L300R[H00>e;003o0000if0006N]0000
ISd001@^001?00026@005c0006Ti076`003YF000o`000>]C001k/P0006/f000H<@000QT001<]001U
?P1S[000if400?l0003/C000Q[D0001^<`006c<0008I000B;000Hd00GZX00>IS003o0000kD/008Ne
0000KS8001Xb00026@004R`006@o06:[003WH000o`000>a?001o/`0006`f000H<@000QT001D^001W
>`1`[`00jEL00?l0003YF000KZl0001W?00052h0008I000I<P00KC<0QkD00>e9003o0@00i6P005BW
0000Gd@000lY00026P008SL007HV0:Rn003b=`00oPD00=io000dW@0005I;000:90000a/002lo0022
4038^`00mb<00?`@003DV`0049000016B`0200067`2R0015BP0@T000e9/00?`?003g8`00b;d00020
4`00;Ch000<K000;9@00FDT0@:400>5d003o0P00kd<008ng0000KS8001Tb00026@005Rl006/g086d
003]BP00o`400>=^0018Y00005]7000<9P000a/002`n00204`38_000mb800?/B003BXP001X`0000m
A`001al0055=02RI003LQ@00oPH00?8h002P_000078/000L=0000QT001D^001Z>021]000kDP00?l1
003QLP00?j40001GBP002R@000@L000d@P00Q`D0cZ`00?XF003h7@00b[L000224@00;3h000<K000=
9`00GDD0EJL00>IR003o0000jEX006:[0000HD8000hY00036P00:3`007lF0<Rl003h8000na@00<nZ
0000Q`@003A2000370002bD005Y804ZT003TJ000o`000>YF001V[0000652000>:@000aX002Xl0020
4`39^000nAd00?XH003</@0008<=000^?P000a/000dW001OA01OZP00jET00?l0003UI`00BZ@0001I
B@002R@000@L000hA004R`00dil00?`>003e:P00]/40001f9P007SD0008I000G<000KS<0V;X00?8h
003n1`00f8l001FB0000@dT000DN00088P00ED/0?:000>9`003o0000jU@006B/0000H4<000dW0003
6`00<D0008L50=2W003k4@00mRL00;[20000MRH001dd00026@006340070_0:Bm003d<@00o@/00=BK
0006S00003M4000470002bH005e62_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo07T0059=000<9P000QX001Pa001T?`1:Y000gH800?`=003i6P00e9`002NI0000FDP0010Z0002
6@004b`005i503FM003HT000na@00?/C003HS`00=ih0001NA@004b`0008I000@:P00FTP0:iX00=FH
003j5`00o1000=Z9000mX0000613000D;@000QT000lZ001IB00ZV@00eIP00?XG003l4000fX/003ZO
0000GTD001</00026@004B/005a703:L003HT@00na<00?/E003GU000;I/0001JB00042X0008I000D
;P00HD80AJ800=f2003m3000n1h00=6U000HT`0005=<000;9P000QX001/c001Z>01SZ`00hfd00?h4
003d;P00b;`000280P00A4X000LQ00037000:3/007HW08ng003[D@00o`000>i7002Q_00007XO000^
?`0011d000HP000nA`00Q@T0a/400?<b003o0`00i6X006F/0000JCT001/c00026P003BL005I:02FH
003EV000nQD00?/D003FU`009YP0001FBP003BL0008J000K<`00JSP0JJd00>EV003o0P00lSL00;c2
0000PA<003I3008000DN0?l003U406>T1`3c<`00o`<00>=]001MZP0006Ll000G<0000QT0010Z001L
AP0jW`00fhH00?d;003g8@00cJl000N=0000BD`000PQ00047000:cd007XP0:Fm003_@@00o`000>MN
001c/00006`e000L<`000QX000dX001IB@0aW000fX/00?`=003h8000cZd000N=0000B4/000LQ0004
7000;Sl007`K0;70003a>P00o`800>AY001PZ`0006Hl000F;`000QT0018/001P@`1<Y@00h7H00?h5
003d<@00a<@000214P00=48000@M00068000@dT00h/00<f`003h8000o0d00=V>000ZVP0005I;000;
9P000aX0028h001d:P2C^000kDP00?l0003XG000L:l0001Z>0006C40008I000A:`00H4<0CJD00>5c
003o1000lSD00;O10000OAX002dn000470002280051>01VC003DV`00na<00?TJ003?Z@002Hd00016
BP001b0000DM000g@`00Q0/0b;/00?HW003m2P00fXT002jK0000ET/000/U00036P009SX007PS0:Nm
003a?000o`800>9`001@YP000613000@:P000QT001`c001^<P25]@00k4h00?l0003XG@00K:h0001W
>`005Bl0008I000F;`00J3/0KJh00>QK003o0000je00082c0000KCD001Xb00026@004R`006=005nZ
003VI000o`000>e9002;]P0006la000L<`000QT0014[001R@@1JZ@00iFH00?l1003^B000S;L0001_
<@0073<0008I000A:`00Hd00GZX00>IS003o0000k4`008Be0000KC@001Tb00026@0052d006Hm06^^
003XFP00o`000>YE001b/00006Pj000E;P000QT001Pa001/=@22]000k4`00?l0003UI@00FJT0001Q
@P0042X0008J000P=P00MBP0Xkd00?4j003n1000gg`003RN0000EdX000XU00036`00;Ch0080C0<Nn
003g9@00o0h00=FH000DTP0004Q<00067`001Ah004=900b?003CW`00na400?LQ0039^P00088@000_
?`000a/000XU001GBP0lX000h7P00?l3003`@000U;T0001`<0006S80008I000E;P00JCT0O;<00>a<
003o0000i6/004fU0000G4H000`W00036`00:Sd007lF0<No003g9000o1000=>O000:SP0004180006
8000D4h099P00=^8003n1`0007P0lSD00:Jm0000M2X001dd00026@0052d006Pj07bb003]B`00o`40
0>9_0013XP0005U9000:9@000a/003910026203=[`00nQP00?TK003;]00008<>000^?`000a/000`V
001LAP1@YP00iFD00?l0003YE`00Ijd0001R@@003bT000<J000W>`00OAT0akl00?LR003k4`00d:L0
00290@00=T<000@L000:9000FDT0AZ<00>A[003o0000jU<006^^0000Hd0000lY00036P00:3/007lF
0<Rk003h7P00nQH00<f^0000Q@X002lo00036`0032L005i505^Y003XG000o`000>IT001?Y@0005Y8
000;9@0011`003I3006:003BXP00o0l00?HX002k`P0007LT000O=P000QT001D_001]=02C^000lC/0
0?h6003JS0006I@00015BP001Ah000PQ001DC00hWP00hG<00?l1003[DP00JJd0001Q@P003RP000<K
000_?`00QPP0cjX00?/B003g9@00`<<0001h8`007cD0008I000G<000Kc40Wk/00?<c003m2P00eIP0
00V=0000>TD000@L000;9@00G4L:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0N@00Dd`000`W00026@005c0006=004JS003LQ@00o0h00?XH003EV000:iX0001KB0004B/0008I
000B;000G4H0<I`00=ND003j5@00na400=Z<000kW`0005m4000D;@000QT000lY001IB@0WV000e9/0
0?TI003l3P00fhH004:Q0000HD8001D^00026@003bT005Q902JH003DV`00nQT00?`?003KR000?Z00
001P@`0052d0008I000@:P00FdP0;Y/00=ND003k5000na<00=RA000aW00005]7000@:P000QT001<]
001P@`10X@00g8D00?`=003i7000dZ8001bD0000E4`000`V00026P006S8006Pj05jZ003RL000oPD0
0?D[0039^@0008X00017B`00228000<K000V>P00M2T0R[H00>YD003o0000kd@00:Jm0000O1`00310
00047@001Ql003]600243034a000lc@00?l2003UI`00JJd0001[=`0073<0008J000<9P00ED/08IH0
0=BK003j5`00na<00=ND000ZV@0005Q:000=:0000QT001Xb001Y>@1U[000i6T00?l3003c=@00`L@0
00224000>4@00P001Ah0o`00=d<0H:890?8e003o0`00i6X006:[0000J3/001Pa00026@003bT005]7
03JN003JR@00o0`00?PO003>[0002hh0001;C@00228000<K000Y?000N280X;`00>m4003o0000j5/0
07Ra0000KC@001dd00026P003BL005Q:02fK003ISP00o0h00?PN003?ZP002hh0001:C@00224000@L
000/?P00Nad0[;l00?0m003o0@00iFH006F/0000J3/001L`00026@004B/005m404RS003ON@00oPH0
0?@^0035`P00088?000f@`001Ad000HO0011B000R@00c;<00?LR003m3000fX/002jK0000EdX000`V
00036P008CL0078/08jg003]B`00o`000>UJ001e/@0006/f000J<P000QT0010Z001OA019Y000h7L0
0?h5003c<`00_<80001n6000;Sl000@L00088P00Cdh05I800=>N003k5000nQT00=6V000<S`0004Q<
0007800011d003E200233P37_P00mRT00?d9003KQP00<Y`0001GBP0032H000<J000T>@00MbD0X[`0
0?0n003o0P00hfd005BW0000HD80014[00026@006S8006dd082c003[D@00o`000>UJ001`[`0006Tj
000G<0000QT001D^001V?01X[@00ieh00?l0003/C@00Q;D0001^<`006c<0008I000A:`00HT40FZT0
0>EW003o0@00kTH008nh0000LBl001dd00026@0042X0065305FX003TJ@00o`400>i5002A^000074_
000M=0000QT0014[001Q@P1IZ@00iFH00?l0003]B@00RKH0001^<P006S80008I000C;000ICh0IZ`0
0>QM003o0000je<007Na0000JCT001H_00026@005c0006/g07fc003/C`00o`000>IR001MZP000691
000A:`000QT001le001c:P2N^`00lC`00?l3003PN@00?:00001HB@002bD000<K000/?@00OaH0a/40
0?HW003l3@00eYD001NC0000Bdd000HP00057P00@4P02Hd00=:R003k4P00n1l00<Zg0000P`d00350
000370002R@005I;03NN003ON`00o`<00?0m002I^P00074^000L<`000QT001@^001X>P1g/@00k4l0
0?l0003UJ000DJH0001MA@003BL000<J000X?000OQT0a/800?HV003l3`00e9`000f?0000@TT000HO
001?CP0PUP00fX/00?h80000N03c<`00Zkh0001e:0007cD0008I000C;@00Ic`0Mk400>a>003o0000
hf`004RS0000FTP000/U00036`00<40008@;0<bb003i6P00nAT00<ba0000Q0/0031000036`002bH0
05]704bU003TJ000o`000>YD001[[P0006=0000@:P000QX002Dj001l6`35`P00mb@00?/A003AY000
0HX0000hA00011`000XT001GBP12XP00hfh00?l0003[D000Kjl0001T?`0042X0008J000V>P00OAT0
akh00?PP003k5000cj/000261`00<D0000<K000<9P00GDH0EZP00>MO003o0000if4005>W0000G4L0
00/U00036`00=48008P20=6U003k4@00mRH00<330000NB80020f00026@0052h006/f08jg003`?@00
oPD00=^9000MU@0004Q<00057P001b40059=03BM003PMP00o`400>a?001^[`000691000>:@000aX0
02dn00242`3>[@00na@00?LS0035a00007TQ000P=P000QT001H_001^<`2J^P00lSH00?d9003FU@00
38l0000lAP0011`000XT001KB0[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07oooo
o`3o001DC0003BL0008I000F;`00HT80@J400=^8003l4000nQL00=JE000_V`0005a7000A:`000QT0
014[001KA`0]V`00eYL00?XG003l4000fhT003nQ0000H4<001D^00026@003RT005Q:02>G003CWP00
nA/00?`=003LP`00AZ<0001R@@005Rl0008I000>:000EdX08YL00=>N003i6`00o0d00=b50012XP00
0652000D;P000QT000lY001IB@0ZVP00eYL00?XF003k4@00fHh003FM0000GDH0014[00026@004b`0
05m403bP003KR@00o0h00?TJ003CW`007iH0001FB`003BL0008I000I<@00Ic`0FZT00>5c003n1P00
mBT00<Zf0003R`0004U<00088P000a/002Di001c:`25]@00jUL00?l0003_@@00Zkh0001m6P00<T40
00DM00067`00>DD0088?0;o3003b=`00o`800>IT001^[`0006`e000M=0000QX000/V001DC00MU@00
dih00?XH003k4@00f94002fK0000FDT000hX00026@006C4006Pk062[003SK000o`<00?<b0035``00
08<=000jA@001Ql000DN000e@P1NX@X0lSP00?l2003UI`00Ijd0001Y>@006S80008I000>:000FTP0
<Y`00=V<003l3P00n1h00<nY000>S`0004i>00088P000a/002Pk001g902K^P00kTL00?l0003YF000
O;<0001_<P007SD0008J000<9P00ETX0:IT00=RA003l4000nA`00=2W000>S`0004e>00088P000a`0
02Xm001j802W_@00l3l00?l1003VH`00JJd0001Y>@006340008I000@:P00GTD0A:800=ml003n1`00
mB`00<No0000Q0`003Q400057P001Ql003m700280P3;]@00mb@00?d;003KR000<Y`0001HB@003BL0
008J000O=P00LBh0RKH00>a>003o0000jUL007Zb0000KC@001/c00026@003bT005e504BR003ONP00
oPD00?@`0031a00007lE000`@00011`000PQ001=CP0AT@00dZ400?XF003j5`00dZ<000n@0000Bdd0
00LQ00047@00<d40088A0<K1003e:`00oPP00=b3000fWP0005Q9000<9P000aX002<h001e:02M^`00
kd400?l1003TJP00F:P0001R@@004R`0008I000I<P00K3H0Nk800>YC003o0000jEL007Fa0000JSP0
01P`003c00026@0052d006Dn06>/003VH@00o`000>e:0029]P0006la000L=0000QT0014[001Q@P1F
Z000i6X00?l1003_A000U;T0001b;@007SD0008J000?:P00Gd@0DJH00>=/003o0@00kd8009Ji0000
LRd001he00026@0042X0061305FW003TJ@00o`400>i6002>]`00070`000L<`000QT0018/001T@01R
Z`00if000?l0003[D000O;80001[=`005c00008I000F;`00JCT0N;400>]B003o0000iel006:[0000
Hd00014[00026@007CD0078]09Vj003`?`00o`<00>5e0011X@0005U8000<9P000a/002Xl001n6@35
a000mRT00?d;003GTP006i@0001>CP001b0000DN000nA`05S000dJD00?/D003h7@00bk@000252P00
<d4000@L00098`00ED/0<id00=in003n1000lC/009jk0000LR`001dd00026@004bd006Ll07>`003[
DP00o`000>IU001EZ00005m4000>:0000aX002Lk001l6`34a000mRP00?`=003EV0004I000014BP00
1Ql004e>01fE003ISP00o@T00?@a002``00007HV000P=P000QT0018/001V?@1b/000je400?l0003T
J@00C:D0001KA`0032H000<K000^?`00P`h0bkD00?TK003j6000cJh000262000<T4000<K000;9@00
FTP0B:<00>A[003o0000je40072_0000ICh0014[00026P0093T007/N0<C4003f9P00o1000=:Q0005
R`0003Y5000470002B<005I;03jP003RL@00o`400>a=001d/00006Dn000A:`000QX002Di001l6`36
`@00mb<00?/C003@Z00008P4000c@P000a/000/U001LA`1BYP00iV800?l0003WGP00EjP0001MAP00
32H000<K000b@@00Q`D0d:P00?/B003g9000aL@0001j7`008SL0008I000D;@00JSP0RKH00?10003n
1000g8D0022F0000Bdd000HO00078000DDd0<9`00>1i003o0P00k4`007:`0000I3l000lY00036P00
:cd008<>0<f`003j5P00n2400<K10000Nah0024g00026@005Bh006`e09Fi003b>000oPP00=NB000@
T00003i700047@002R@005U900[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07oooo
o`1I001FB`003RP0008I000E;P00H4<0?J000=Z;003k4@00nQD00=NB000cW@0005e6000B;0000QT0
010Z001JB00YV@00eIX00?XI003l3P00fhH004>R0000HT4001H_00026@003RP005I:01nF003BX@00
nAd00?d<003MP000BZ@0001S@0005c00008I000=:000ET/07YD00=:Q003i7000o@`00=f20017X`00
0691000E;`000QT000hY001HB@0VV000eIX00?XH003l4000fX/003VO0000GTD0018/00026@004R`0
05e503RN003JS000o1000?XH003DW0008iL0001GBP003BP0008I000H<@00ISd0EJP00>1f003n1`00
mRL00<bc0007S00004a=00098`000a/002<h001b;@20]000jET00?l0003`?`00/<00001n5`00<d80
0P001Ah0o`00=d@0084B0;[2003a>@00o`400>MQ001c/00006dd000N=@000aX000/U001CC00IU000
dZ400?TJ003l4000fHh0036L0000FTP000lY00026@00630006Hl05bY003RK`00oP@00?@`0036`@00
08D:000lAP001Ql000DM000c@@1KX0/0lCX00?l1003VI000Jjh0001Z=`006c<0008J000=:000F4T0
;Y/00=R?003l3`00nA`00=2V000AT@0004m>00098`000a/002Hj001f9`2F^@00kDT00?l0003ZE@00
PK@0001`<00083H000<J000<9P00ED/09IP00=ND003k4@00nAX00=6T000BT@0004m>00098`000a/0
02Tl001h8P2R_000kd800?l0003WH000KZl0001Z>0006S80008I000?:P00GDH0@:400=io003n2000
mBX00<Rl0000Q@T003Y500057P001Al003a600271@39^000mRH00?d:003LQ@00=Yh0001JB0003BP0
008J000N=@00L300Q;D00>]A003o0000jU@007nc0000KS<001`d00026@003bT005a6042Q003NO@00
oPH00?@^0035a000084B000b@@0011d000LQ001:C00>S`00dJ@00?XH003j5@00dj0001>A0000CDh0
00PQ00047000<D00080C0<G4003d;P00oPL00=f0000jW`0005Y8000=9`000aX0024g001d:P2H^P00
kd<00?l1003UI`00GJX0001T?`004bd0008I000H<@00JSL0M[400>YF003o0000jU@007Zb0000JcH0
01Ta00026@004b`006@o05nZ003VI000o`000>i8002>]`00074_000M=0000QT0010Z001P@`1AYP00
hfd00?l2003_@@00VKX0001c:`0083H0008J000?:@00GTD0CJD00>9_003o0P00l40009^j0000LbX0
020f00026P003bT005m4052V003SK000o`400>m4002B^000074^000M=0000QT0014[001R@@1MZP00
iV<00?l0003/C@00PK@0001/=P006340008I000E;P00J3X0Lk000>YD003o0000j5`006J/0000I3l0
018/00026@0073@0074_09Bi003_@@00o`800>5b0015XP0005]8000<9P000aX002Pk001l6`31a000
mB/00?d:003HS`007iH0001?CP001b4000DM000lAP02R`00d:P00?XF003i6`00c;4000261`00=D80
00@L00098`00V000E4`0;i/00=f1003n1@00lSP00:>l0000M2X001he00026@004R`006Hm06j_003Z
E@00o`000>IR001JZ@000613000>:@000aX002Dj001k7P2o``00mBX00?d<003FU@0059800017B`00
1Ql004Y<01VD003HT@00o@X00?@^002e`@0007PS000Q=`000QX0014[001U?P1^[P00jU@00?l0003U
IP00D:H0001LAP0032H000<K000]?P00PQ00b[L00?PM003j5P00cZ`000271@00=48000@L000:9000
F4T0@j800>=^003o0@00k4h007F`0000ISd0018[00026P008SP007TP0;k3003f:000o0h00=>N0008
S@0003a600047@002B<005E;03ZO003QM000o`400>e;001i/P0006Ll000B;0000QX002<h001k7P35
a000mbD00?/A003AY@0008T1000e@`0011`000/U001JB01>Y@00iFD00?l0003XF`00G:T0001NA@00
32L000<K000`@000QPP0cZ/00?/D003g8P00a/40001k7@008cP0008J000C;000JCX0Q;D00>m2003o
1000g88002BH0000CDh000HO00078000D4h0;9X00=ml003o0P00kDT007Na0000ICh0010Z00036P00
:S`0088A0<bc003j5`00n1l00<No0000O1`002<h00026@0052d006/f092h003a>`00oPL00=R?000C
T@00041800047@002B<005Q92_ooool1o`00007ooooo000Nooooo`?o00001oooool01`00EdX000hY
00026@0052d005m403VO003ISP000P3k4`00D03HS`00=ih0001NA@004bd0008I000?:@00FDT09IP0
0=BM003i6P00o0d00=b30018X`0006=0000G<0000QT000dW001EB`0LU000dJ@00?PO003m2P00gWd0
04jU0000ICh001P`00026@003BL005E;01^D003AY000n1h00?d;003NO`00Bj@0001S@0005Rl0008I
000>:000EdX08YL00=BM003i6@00o0h00=^8000mX00005m4000C;@000QT0014[001LAP0dW@00fHl0
0?/A003j5`00eIT002NH0000F4X000hX00026@005c0006Dn056V003PN@00oPP00?LU003=/0002Xh0
001>CP002B<000<K000R=`00L2l0O;800>QL003o0@00lC`00;G10000P1D003E30P001Ah0o`00=D<0
080E0;G1003a?000o`400>MN001g/@0006lb000P=P000aX000XU001BC@0FTP00dJ@00?TL003l3P00
fX/003FM0000FdL0010Z00026@005c0006Dn05NX003RLP00oPD00?@^0037_P0008H7000nA`001Ql0
00@M000a@01IW`d0lC`00?l1003WH@00L:l0001/=P0073<0008J000=9`00EdX0:YX00=NB003k4@00
nAX00=:S000ETP00051=00098`000a/002Di001d:@2A^000k4`00?l0003[D`00Q[D0001a;P008CL0
00<J000;9@00E4`08YL00=JG003k4`00nQP00=:Q000ETP00051>00098`000a/002Lk001g902M^`00
kTD00?l0003XG@00L[00001[=P006c<0008I000?:@00G4L0>il00=f2003m2@00mRP00<Vj0000QPH0
03a600057`001Ah003Y500252038^`00mRP00?d9003MPP00>Yl0001KA`003RP0008J000M=000KS80
P;<00>YC003o0000je4008>d0000Kc4001de00026P003RP005]703bP003MP000oPL00?D/0036`@00
088@000d@P0011d000LP0018B`0;SP00d:L00?TI003k5000e9d001JC0000Cdh000PR00047000;cl0
07lF0<34003d<000oPH00=im000nX00005]7000=:0000QX0020f001c;02C^@00kTH00?l0003VI000
HJ/0001U?P0052d0008I000G<000JCT0L[000>UI003o0000je4007jc0000KCD001Xb00026@004R`0
06=105^Y003UI`00o`400>i5002C^000078]000O=@000QX000lY001NA01=Y@00hW000?l2003`?`00
W[/0001e:@008CL0008J000>:000GDH0B:@00>5b003o0`00l3d00:2l0000MBP0024g00026P003RT0
05i504bU003RK`00o`800>m1002G^P00078/000N=@000QT0010Z001Q@P1IZ@00iFH00?l0003]BP00
QKD0001]=0006C80008I000D;P00Ic`0Kjl00>UG003o0000jEX006^^0000ISd001<]00026@006c<0
070`092h003_A000o`800>9`0019Y00005a7000=9`000aX002Lj001k7P2l`P00m2d00?d9003IS000
8YL0001@CP00224000@M000jA@00R@00cjX00?XG003i6P00cJl000271000=d<000@L00088P00N@00
Dd`0;9X00=b4003n1P00lSH00:Rn0000MBP001lf00026@004B/006@o06Z]003YF000o`000>MO001N
ZP000652000?:@000QX002@i001j802j`P00mB`00?d;003GT`0069<00019C0001Ql004Q;01JB003G
U000o@/00?D/002j`P0007TQ000S>0000QX0010Z001S@01Y[@00jUH00?l0003VH`00EJL0001NA@00
3BL000<K000[?@00P1<0bKX00?PO003k5000cjT000280P00=T<000@L000:9000EdX0?j400>9a003o
0@00kD/007Vb0000Ic/0018/00026@008CL007PS0;[2003e:P00o0d00=BK000;SP0003i700047@00
228005A<03JN003PM`00o`800>e8001m/`0006Pk000B;0000QT0028g001i8031a000mRL00?`@003B
XP000XX0000gA00011`000XT001IB@19Y000iFP00?l0003YF@00H:/0001OA0003BL000<K000^?`00
Q0/0cJh00?XF003h8000akl0001m6P009CT0008J000B;000J3/0P;<00>i5003o0`00gGl002RI0000
Cdh00P001R007@00Cdh0:9T00=io003o0`00kTL007bb0000ISd0014[00026P00:3/0080C0<Zf003i
6@00nAd00<Rl0000OAT002@i00026P004bd006Xh08^f003`?@00oPH00=V<000GT`0004=900057@00
2B<005M:00Sooooo0ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1I001HB@003bT0
008I000C;@00GTD0=Ih00=RA003k5000na800=V<000kW`0005m4000D;P000QT000lY001GBP0RU`00
dj000?TL003m3000gH0004bU0000I3l001P`00026@0032L005A<01RC003@Y`00n2000?d9003ONP00
DZL0001V?@006C40008J000<9P00E4`05i<00=2W003h8000o@X00=il001?YP0006Dn000G<0000QT0
00dW001FB`0OUP00dj000?TK003l3@00g8D0046Q0000H4<001@]00026@0042X005]7032L003HT@00
na<00?XE003FUP00:YX0001IB@003bT0008I000F;`00Hd00CJD00=ml003m2@00mb<00<j]000=S`00
04m>000:90000aX0024g001_<@1g/@00iel00?l1003a>P00^/8000214P00=d@00P001Ah0o`00<d80
07hG0;70003`?P00o`000>QL001l/P00070`000Q=`000aX000XT001AC@0CT@00d:L00?PN003l3@00
fhP003VO0000G4H0010Z00026@005Rl006@o05>W003QM@00oPH00?D/0038^`0008L40010B0001R00
00@M000_?`1FWPh0l3l00?l1003WGP00M;00001]=0007C@0008J000<9P00ET/09YP00=JE003k4P00
nQP00=>P000HT`00055=000:90000a/002<h001c:`2<]`00k4l00?l0003[D000R[H0001c;0008SP0
00<J000:9@00Dd`07YD00=FJ003k5000nQL00=>N000IT`00055=000:90000a/002Hj001f9`2H^P00
kTL00?l0003YFP00Mk40001]=00073<0008J000>:000FTP0>9h00=b5003m2P00mRD00<Zg0000R0<0
03i700067`001Ah003Q400242`37_P00mB/00?h8003NO`00?Z00001LA`003bT0008I000L<`00KC@0
Nk800>YF003o0000k4h008Rf0000L2l001le00026P003BP005Y803RN003LP`00o@P00?DZ0037_P00
08<=000f@`001Ad000LP0015BP07S@00cjX00?TK003k4P00eIX001ZD0000D4h000TR00047000;Ch0
07hI0;c2003c<P00oPD00=mj0012X@0005a7000>:0000QX001le001a;P2?]`00kDT00?l0003WH@00
IZ`0001V?@005Bh0008I000F;`00J3/0KJh00>QL003o0000k4h008>d0000KS<001/c00026@004B/0
065205JX003TJP00o`400>m2002H^P0007<[000P=P000QX000hY001MA@19Y000hG<00?l3003a?000
Xk`0001f9`008SP000<J000=:000G4L0A:800>5e003o0`00lC/00:Bm0000MRH0028h00026P003RP0
05e604RT003RLP00o`800?0o002L^`0007@Z000O=P000QX000lZ001P@`1EY`00i6T00?l1003^B000
R[H0001^<P006S80008I000C;@00ISd0JZh00>UJ003o0000jEL006n_0000Ic`001@]00026@006S80
06hb08^f003^AP00o`400>=]001=Y@0005e6000=:0000aX002Dj001j802g`@00m3000?h8003JR@00
9YP0001AC@00228000@M000hA000R0<0cZd00?TI003j6000cZ`000290@00>D@000@M00088P00Q`00
DTd0:9T00=^7003n1`00lc<00:bo0000MRH0024g00026P004B/006=006F/003XFP00o`000>QL001S
Z`000691000@:P000QX0028h001h8P2e`@00m2h00?d:003HT0006i@0001<C@001R0004E:01:A003F
U`00o@`00?DZ002o``0007XO000T>@000QX0010Z001R@@1U[000jET00?l0003WH@00FJT0001OA000
3RP000<J000Y?000OaH0b;d00?LQ003k4`00dJH0002:0000>4@000@L00098`00ET/0>il00>5d003o
0@00kDT007jc0000J3X001<]00026@0083H007LU0;G1003e;@00o@`00=FH000>S`00041800057@00
228005=<03:L003ONP00o`800>i60022]00006Ti000C;@000QT0020g001h8`2l`P00mRT00?`>003C
W`001H`0000iA@0011`000XT001HB@15X`00i6/00?l0003ZEP00IJ`0001Q@P003RP000<J000]?P00
P`d0c;400?XG003h7P00b;`0001n60009SX0008J000A:`00IS`0Nk800>i8003o0P00gWd002bJ0000
D4h000LP00067`00CDh09IP00=f2003o0`00kd@0082d0000Ic/0014[00026P009SX007lF0<Vh0002
0?TK000?0<Vi0000OQL002Hj00026P004R`006Tj08Ne003`@000oPD00=Z9000JU00004E:00057P00
228005I;00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o001IB@0042X0
008I000B;000GDH0<Y`00=ND003j5P00o1000=Z:000oX@000652000E;P000QT000hX001FBP0NU@00
dZ800?PN003m2P00gWd0052V0000ICh001Ta00026P0032H005=<01FB003?ZP00mb800?d8003PM`00
EjP0001W?0006S80008J000;9P00DTd059800<nZ003g8P00o@T00=mi001CY`0006Hm000H<@000QT0
00dW001EB`0KU000dZ<00?TM003m3000gH8004FS0000HD8001D^00026@003bX005Y802fK003GU000
na@00?/C003GT`00;Y/0001JB0003bX0008I000E;P00HT40BJ@00=io003m2P00mb400<nZ000@T000
051=000:90000aX001lf001^<`1c/000iV800?l2003b>000_l<000223`00>DD000HO00057@00<D40
07dJ0:bo003_@@00o`000>UI0020]000074^000R>0000a/000TS001?CP0?T000cjX00?PO003m3000
g8D003fP0000GTD0014[00026@005Bh006=004nV003PN000oPL00?DY0039^00008T10013B@001b00
00@L000]?P1DW0l0kd400?l0003XG000NK80001^<P007SD000<J000<9P00ED/08iL00=FH003k5000
nQL00=BM000LU@0005==000:9@000aX0028g001b;@28]P00je400?l0003/C@00SkL0001d:P0093T0
00<K000:9000DTd06i@00=BM003j5P00nQD00=BL000LU@00059=000:90000a/002@i001e:@2D^@00
kDX00?l0003YE`00Nk80001^<`007C@0008J000=:000FDT0=9d00=^8003m2`00mb@00<^d0000R@00
041800067`001Ad003I300233P36`@00mBd00?h7003NO000@Z80001MAP003bX0008I000K<`00K3D0
Mk400>UI003o0000k4`008bg0000LRd0020f00026P003BL005U903BM003LQ@00o@T00?HX0038_000
08D:000hA0001Ah000HP0013B@04R`00cZd00?TM003k4@00eYL001fE0000DDd000TS00036`00;3d0
07`K0;O1003c=000oP@00>1g0016X`0005e6000?:@000QX001de001`<02:]P00kD/00?l0003WGP00
JZh0001W>`005Rl0008I000E;P00Ic`0JJd00>MN003o0000k4`008Ne0000Kc4001`d003c00026@00
42X0061305:W003SK@00o`800?10002L^`0007@Y000Q=`000QX000hX001LAP15X`00hGD00?l3003a
>P00Z;h0001g900093T000<J000=9`00FdP0@:400>1h003n1000lSP00:Vn0000Mb@002@i00036P00
3BL005]704BR003QM@00o`<00?4l002Q_00007DX000Q=`000QX000lY001OA01@YP00hf`00?l1003^
A@00SkL0001`<0006c<0008I000B;000ICh0IZ`00>QM003o0000jU@007B`0000J3X001D^00026@00
6C4006dd08Je003]B@00o`400>AZ001AYP0005i5000>:0000aX002@i001h8P2b`000lc800?h7003K
QP00:IT0001BC@00228000@L000f@`00Q`H0cK000?TK003j5P00cjT0006:0000>dD000@M00088@00
D4d099P00=Z:003n2000lc400;700000N2@0028h00026P0042X00691066[003XG@00o`000>UI001W
[@0006=0000A:`000QX0024g001g9@2a`000m3400?d8003IS@007iH0001>CP001Ql004=900n@003E
VP00o0h00?HX0033a00007`L000V>P000aX000lY001Q@P1PZ`00j5`00?l0003WGP00GJX0001P@`00
3RP000<J000X>`00OQP0a/000?LS003k4@00dZ<000>;0000>TD000@M00098`00ED/0=ih00>1g003o
0P00kTH008:d0000JSP001@^00026@007SD007HW0;30003d;`00o@X00=JE000BT@0004=900057P00
1b40059=02jK003NO@00o`<00>m30027]@0006Xh000D;P000QT001lf001g9@2g`@00mB/00?`=003D
W@0028d0000kAP0011d000TS001GBP11X@00hfh00?l0003ZD`00JJd0001R@@003RT000<J000[?@00
PQ00bk@00?XI003i7000bKT0001o5@00:3/0008J000@:P00ICh0M[400>e:003o0P00ggX002nK0000
DDd000LP00067`00Bdd08IL00=b5003n1000kd8008Fe0000JCX0018/00026P009CT007hI0<Rk003i
7@00nAT00<Zf0000P1@002Lk00026P004B/006Lk08:d003_@P00oP@00=^6000NU@0004M;00057P00
228005E;00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`28001JB0004B/0
008I000A:`00G4L0;Y/00=JG003j5`00o0l00=^70013XP000691000F;`000QT000dX001EB`0KU000
dJD00?PP003m2@00ggX005BW0000Ic`001Xb00026P002bH0059=016A003>[000mb@00?h7003QM@00
FjT0001X>P006c<0008J000;9@00DDd049000<j]003g9000oPP00>1f001GZ00006Ll000J<P000QX0
00`V001DC00HT`00dJH00?PO003m2`00gH0004VT0000Hd4001H_00026@003bT005U902VI003FU`00
nQH00?/B003HT000<Y`0001KA`0042X0008I000D;P00HD80AJ<00=f1003m2`00n1l00=2X000DTP00
055=000;9@000aX001he001]=@1^[`00iVD00?l2003b=@00`l@000233@00>dH000HO00047@00<400
07`L0:Nm003_@`00o`000>YF0025]@00078/000T>@000a/000TS001>CP0<S`00cZd00?LQ003m2`00
gH80046Q0000Gd@0018/00026@0052d0069104^T003ONP00oPP00?HW003:]P000HX00015BP001b40
00@L000/?@1AVa00kd@00?l0003YF@00OK<0001_<@0083H000<J000;9@00E4`07iH00=FJ0080nQD0
0?l0eIX001nF0000E4`000/U00036P008CL0074_08>d003ZE000o`000>e;002D^@0007DX000U>@00
0a/000TT001AC@0GT`00dj000?XG003k4`00eIT001nF0000Dd`000/U00036P008cP007<[08ng003/
C000o`000>YE0020/`0006la000N=@000QX000dW001HB@0`W000fX/00?d<003g8P00c;4000::0000
@TT000HP00047@00=480088@0<G3003d;`00oPH00=mi0016X`0005i5000@:P000QT001Tb001[=`1b
/000j5/00?l0003]B@00TKP0001c:`008CL000<J000<9P00F4X0<I`00=^8003m2P00mRH00<Vi0000
QPL003Y500057P001Ql00458006:003=[`00n1l00?`?003GU0008IH0001BC@002B<000<K000Z?000
Nad0//000?8g003o1000hG@004ZT0000GTD000lZ00026@0073@006la08Fe003/CP00o`000>QK001^
[`0006Pj000F;`000QT001@^001V?@1U[000if400?l0003]B@00S;L0001`;`007C@0008I000@:P00
Gd@0CZD00>9`003o0P00l3h00:6l0000MRL0028h00036P003BL005]7046Q003PN000oP@00?8g002/
_`0007PR000U>P000aX000`V001IB00mX000gg/00?h5003b=P00[[l0001i8P009CT000<J000<9`00
FTP0@:400>1h003o1000lCX00:Fm0000MRH0028h00026P003RP005i504bU003SKP00o`800>m3002C
^000074^000M=0000QT0018[001S@01RZ`00iel00?l0003[DP00N;40001Y>@005Rl0008I000H<000
K3H0P[@00>e;003o0000iFL005FW0000Gd@000lY00026P008SP007LT0:fo003c=000oPH00=b4000]
V`0005A<00098`0011`003A200252@3</`00nA`00?XE003@YP0018/0000mAP001Ad000LQ001?CP0Q
UP00fH`00?d9003d;`00]/40001i8@008cP0008J000?:@00HD80GJX00>MP003o0000jUL006^^0000
ICh0014[00026@0083H007HW0:bo003c<`00oPL00=Z:000RU`0004m>00068000@DP038h00=BM003l
3`00mRH00<G20000OAX002Lk00036P003RP0061305bZ003WG`00o`000>QK001QZ`000652000?:@00
0aX006T002Hj001m6`35`P00mbD00?`@003CX0001X`0000lAP0011d000PR001DC00dW@00ggX00?l3
003_A000QkD0001[=`005Bh0008I000M=000M2T0Zkh00?@a003m2@00ei8001FB0000ADX000DN0007
8@00DDd0:YX00=f0003o1000kd4008^f0000JcH001D^00026@007SD007HW0;;0003e;@00o@`00=FJ
000;SP0003e700047@002B<005I;03fP003RL000o`400>]A001][P0006=0000?:@000aX002Tl0021
4`3:]P00nA/00?TJ003:]P00080C000Y?0000aX000lZ001T?`1b/000k4d00?l1003PM`00<id0001B
C@001b4000DN0018C00NU@00fhL00?h5003`?`00RKH0001Z>0004bd0008I000T>@00O1/0akh00?PN
003j6000bk@000214P00:C`000<J000A:`00IS`0O[<00>i5003o0`00g8<0026F0000BT`000DN0007
8@00E4`02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l005]7000A:`00
0QT0014[001JB00ZVP00eIT00?XI003l3P00g8@004NS0000Hd0001L`00026@003BL005A<01RC003@
Z000mb800?d8003PM`00F:P0001X>`006c<0008J000;9@00DDd03Xl00<f_003f9P00oPH00>9b001O
ZP0006Ti000L=0000aX000XU001@CP0=S`00cJl00?HV003n1`00hG@005^Y0000J3X001/c00026P00
2bH0059=01FB003@Z000n2400?d:003NO@00CJD0001T?`005c00008I000>:000F4X09IP00=FJ003j
5`00o1400=V=000eWP0005a6000A:`000QT001<]001P@`11X@00g8@00?d<003h7@00dJD001NC0000
Ddd000/U00026P007C@006/f06Z^003UI`00o`<00?<c0035`P0008D:000mA`001R0000@M000^?`00
Nah0Xk`00>i5003o0000jU@008Vf0000M2X002Di00036`002B8004a=00V=003=[`00mb<00?d9003M
O`00AJ80001P@`004b`0008I000C;@00HD<0Aj<00=im003m2000mRD00<^c0004R`0004M;00088@00
11`002Xm04nJ4@3^AP00o`000>YF0021]000074_000Q=`000aX000/U001CC00LU@00e9d00?XG003k
4`00eYP002>G0000ED/000/V00036P007cH0070`07nc003YE`00o`000>e8002H^P0007HV000W>P00
0a/000TS001@CP0DTP00dZ<00?TI003k4P00eYH002>G0000E4`000/U00036P008CL0078]08^f003/
C`00o`000>]B0024]@00070_000O=P000aX000`V001GBP0/VP00fHd00?`=003h8000cJl000F;0000
ADX000LP00047@00<d40080C0<;4003d<@00oPD00>1g001:Y00005m4000A:`000QT001Pa001Z>@1^
[`00ieh00?l0003^A`00U[T0001d:@008cP000<J000<9P00ETX0;I/00=Z;003m3000mb@00<Zf0000
Q`D003a600057P001Ql003m700290@3</P00n2400?`>003HT@0099P0001CC0002R@000<K000X?000
NR00[Kl00?4i003o0`00hW8004jU0000Gd@0010Z00026@006c<006hc086d003[D000o`000>UI001c
/00006Xi000G<0000QT001<]001T?`1PZ`00iV@00?l0003^A`00T;P0001a;P007SD00?<0008J000?
:@00GTD0BZ@00>5b003o0`00lC/00:Fm0000MbD002@i00036P003BL005Y803fP003ON`00oPD00?8e
002a`00007XP000W>P000aX000`V001HB@0iW`00gWh00?h5003c=000//00001j80009cX000<J000<
9P00FDT0?:000=mj003n1000lSP00:Zn0000Mb@002<h00036P003BP005a604RT003RL@00o`800?10
002H^P00078]000N=@000QT0014[001R@@1NZP00iV800?l0003/C`00O;<0001Z=`005c00008I000G
<000JcL0OK<00>a>003o0000iV@005VY0000HD<000lZ00026P008CL007HV0:Vn003b=P00oPD00=f1
000aW00005E;00098`0011`0039100242`3;]@00n1h00?/C003AX`001h`0000oA`001Ah000LP001>
CP0MU@00f8l00?d:003e;@00^l80001j7`009CT000<J000>:@00H4<0FJT00>IS003o0000jU@006n_
0000ISd0018/00026@007cD007DY0:Nn003b=@00oPL00=^7000VV000051=00067`00?dL02Hd00=>O
003l4000mb@00<K00000OQP002Tl00036P003RP005m405RX003VH@00o`000>UI001U[0000691000@
:P000QX002Di001k7@34a000mRL00?`?003DW@002Hd0000nA`001Ad000PR001CC00`W000gWd00?l3
003_@@00RkH0001/=@005Rl0008I000L=000Lb/0Ykd00?<c003m2000f8l001RC0000Ad/000DO0007
8000D4h09iT00=b3003n1000l3h008nh0000KCD001H_00026@007C@007@Y0:jo003d;`00o@/00=JG
000>S`0003m800047@00228005E;03ZO003QL`00o`400>a>001a/00006@o000@:P000aX002Pk001o
5@39^@00nA`00?XI003;]000088@000[?@000aX000lY001S@01^[`00k4l00?l1003QM000=ih0001C
C000224000DN0016B`0JU000fXX00?h6003`?@00S[L0001[=`0052d0008I000R>000Nad0a/000?PP
003j5P00c;4000223`00:Sd000<J000@:P00ICh0NK800>i7003o0`00gH0002FH0000C4d000HO0007
8@00Ddd02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l005a6000B;000
0QT0010Z001IB00WV@00e9`00?TJ003l3@00gH4004ZT0000I3l001P`00026@0032H005=<01BB003?
Z`00mb<00?h7003QM000G:T0001Y>@0073<000<J000:9000D4h02hh00<bb003f:000oPD00>9_001S
Z`0006/g000M=0000aX000XT001?CP0:SP00c;800?HX003n1P00hW4005nZ0000JCT001`c00026P00
2bD0055=01:A003?Z`00mb800?d9003ONP00DJH0001U?P005c00008I000=:000EdX08YL00=BM003i
6@00o0l00=Z;000iW`0005i5000B;0000QT0018/001OA00mX000fhL00?`=003i7000dZ8001ZD0000
E4`000`V00026P0073<006Xh06J/003TJP00o`<00?@a0036`00008H7000oB0001b0000@L000/?P00
NB00W[/00>i8003o0000je4008fg0000MBP002Hj00036`00228004Y<00J<003</P00mbD00?d8003N
O@00BJ@0001Q@P004bd0008I000B;000Gd@0@j800=f0003m2@00mb@00<ba0007S00004U<00088P00
0a/002Tl04fI4P3]B@00o`000>YD0026]@00078]000R>0000aX000XT001BC@0IT`00dj000?XH003k
4P00eYD002JH0000ET/000`V00026P007SD006hb07^b003YF@00o`000>i6002M^`0007LT000X>`00
0a/000TS001?CP0AT000dJD00?TK003k4@00ei<002JH0000ED/000`V00036P0083H0074^08Je003[
D@00o`000>]@0029]P00078^000Q=`000aX000`V001FB`0YV@00f9000?`?003h7P00cZ`000R=0000
Ad/000LQ00047@00<D0007lE0;k3003c<`00oP@00>5d001>Y@000653000B:`000QT001L`001X>P1Z
[@00if400?l0003^A000V[X0001e9`0093T000<J000;9@00ED/0:IT00=V>003l3@00mb800<^d0000
R08003i700067`001Ah003e600280`3;]@00mb800?`=003IS`00:9T0001DC0002R@000<K000W>`00
NB80ZKh00?4k003o0P00hfl0056V0000HD<0014[00026@006S8006de07fc003[D`00o`000>YF001g
/@0006/g000H<@000QT001</001S@01LZP00iFL00?l1003^A000UKT0001c;00083H00?<0008J000>
:000GDH0AZ<00>5e003o0`00lCT00:Zn0000N2<002Dj00036P0032H005U903ZO003NOP00oPH00?<c
002e`@0007/N000X>`000a/000/U001GBP0eW@00gH400?h6003c<P00]l40001k7P00:3/000<K000;
9P00F4T0>Il00=im003n1@00lSD00:jo0000N28002Di00036P003BL005]704FR003QM000o`<00?0n
002L^`0007<[000O=P000QX0010Z001Q@P1JZ@00iFD00?l0003/C@00PK@0001/=P006300008I000F
;`00JCT0NK800>]A003o0000iV8005fZ0000HT40010Z00026P0083H007DX0:Bm003b>@00oPD00=in
000dW@0005I;000:90000a`0035000233P3:^000n2000?/B003BX@002Xh00011B0001Ah000LP001<
C@0JU000ei800?d;003e:`00_l<0001k7@009SX000<J000>:000GT@0EJL00>EU003o0000je4007B`
0000Ic`001<]00026@007CD007<[0:>l003b=`00oPH00=b4000YV@00055=00077`00?DH01X`00=:R
003k4@00mb800<Nm0000OaD002Xl00036P003BL005i505BW003VI000o`000>YF001Z[@0006=0000@
:P000QX002@i001j7`2o``00mRT00?`=003DV`0038l00010B0001Ah000PQ001BC@0/VP00gGl00?l4
003`?`00T;P0001]=0005c00008I000K<`00LRd0X[`00?8e003n1`00fHd001^D0000BD`000HO0006
8000CTh08iL00=^6003n1@00lC`009Bi0000KS<001L`00026@0073<007<[0:Vn003c<@00o@X00=ND
000AT@00045900057@00228005A<03JN003PMP00o`400>e;001f/@0006Dn000@:`000QX002Hj001n
6038_000n1h00?XG003</@0008<>000/?P000aX000hX001R@@1Z[@00je800?l0003RL@00>Yl0001D
C000228000DN0014BP0GT`00fHd00?h6003a>P00T[P0001/=@005Bh0008I000Q=`00NQl0aL<00?LR
003j5@00cJh000233@00;3d000<J000?:@00I3l0MK400>e:003o0P00gWh002RI0000CTh000HO0007
8000DDd02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l005i5000C;@00
0QT000lY001HB@0TU`00dil00?TL003m2`00gWh004jU0000ICh001Ta00026P0032H0059=016A003>
[@00mRD00?h7003RLP00H:/0001Z>0007C@000<J000:9000Cdh028d00<^d003e:P00oPD00>=/001W
[@0006`f000N=@000aX000TT001>CP07S@00bk@00?DZ003n1@00hfh006>/0000JSL001dd00036P00
2RD0051=00n@003>[P00mb@00?h8003PM`00EJL0001V?@006340008I000=9`00ED/07iH00=>O003i
6P00o0h00=^8000mX00005m4000B;0000QT0018/001NA@0jW`00fXX00?`?003i6P00dj0001fE0000
ED/000`V00026P006c<006Ti06:[003SK@00oP@00?@_0037_@0008L50011B@001b0000@L000[?@00
N2<0V[X00>e:003o0000k4l009:h0000MRH002Pk00036`00228004M;00>;003;]000mRL00?h7003O
NP00C:D0001R@@0052h0008I000A:`00GTD0@:400=b3003m2`00mb800<f^000:SP0004a=00088P00
0a/002Lk04^H4`3]B`00o`000>]A002:]P0007<[000S>0000a/000XT001AC@0ETP00dZ<00?TJ003k
4@00ei8002VI0000EdX000dW00026P007C@006dd07Na003XG000o`000>m3002Q_00007TR000Y?000
0a/000PR001=CP0>S`00d:P00?TL003l3`00f94002ZJ0000EdX000`V00026P007cH0070`08:d003Z
E000o`000>a=002=]`0007</000R=`000aX000/U001EB`0VV000ei<00?`@003i7000cjT000Z>0000
BD`000LQ00047000;cl007hH0;W2003b=@00o`<00>9a001BYP000691000B;0000QT001L`001W>`1V
[000iV<00?l1003_@P00W[/0001g9@009CX000<K000:9@00E4`09YP00=RA003l3P00n2000<ba0000
RP00041800067`001Ah003]500261P3:]`00mb@00?d<003IS000:iX0001EB`002bD000<K000V>P00
Mb@0Y;d00?0m003o0P00hf`005FX0000HT40018/00026@006C4006/f07Vb003ZE@00o`000>YD001k
/P0006`f000I<P000QT0018/001R@@1HZ000i6T00?l1003_@P00VKX0001d:P008CL00:D0008J000>
:000G4L0@j800>1h003n1000lSL00:jo0000NB4002Lj00036P002bH005Q:03JN003MP@00oPH00?@a
002j`P0007`L000Z?0000a/000/U001FB`0bW000g8<00?h7003d<000^l80001l6`00:C`000<K000;
9@00EdX0=Id00=f0003n1P00lc<00;?00000NR0002Hj00036P0032L005Y8046Q003PM`00o`<00?4l
002Q_00007@Y000P=P000QX000lZ001P@`1FZ000iFL00?l0003]BP00QKD0001]=0006C40008I000E
;P00J3X0MK400>]C003o0000iel0066[0000Hd00014[00026@007cD007@Z0:2l003a>`00oP@00=mk
000hWP0005M:000:90000a/002lo00224039^`00mb800?`A003CWP003Hl00013B@001Ah000HP001:
C00GT`00eiD00?d<003f:@00a<@0001l6`00:3/000<J000=9`00GDD0DJH00>EX003o0000k4l007Ra
0000J3X001@]00026@0073@0078/09jk003a>P00oPD00=f2000]V`00059=00068000>dD00h/00=6U
003k4`00n2000<Rk0000P1<002`m00036`0032L005a6052V003UI`00o`000>YC001^[`0006Dn000A
:`000QX0028h001i8@2k`P00mB/00?d<003EV0003i000012B@001Ah000LQ001AC@0YV@00gH800?h4
003`?@00U;T0001^<P006340008I000J<P00LBl0W[/00?8h003n1`00fXX001nF0000C4d00P001Ql0
C000C4d089H00=^8003n1P00lCX009Rj0000Kc4001Pa00026@006c<0078]0:Fm003c<`00o@T00=RA
000DTP0004A:00057P00224005==03:M003PN@00o`800>e9001j/P0006Hl000A:`000QX002Di001m
6P37_P00n2000?XF003=[`0008@;000^?`000a/000hX001Q@`1V[000jU@00?l0003SK`00?Z00001E
B`00228000DM0012B@0DTP00f9000?h7003b>000U[T0001]=0005Rl0008I000P=P00NB80`l@00?LT
003k4`00cZ`000252P00;Ch000<J000>:@00Hd00LJl00>a<003o0P00gg/002^J0000Cdh000HO0006
8000D4d:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`00Gd@001@]0002
6@003bT005M:022F003BX@00n1h00?d:003OO000DZL0001V?0006S80008J000;9@00DDd03Xl00<f`
003f9`00oPH00>9_001T[00006/g000N=@000aX000TS001=CP05S000b[L00?D/003n1000i6X006^^
0000KC@0020f00036P002B<004a=00B;003:]`00mB`00?h4003SK000Ijd0001/=P007SD000<J000:
9000Cdh038h00<f`003f9P00oPL00>5e001IZ00006Ll000I<P000QX000`W001DC00LU000dZ800?TL
003l3@00g8D0042Q0000H4<001<]00026@004B/005e603JN003IS000o1000?XI003DW@008IH0001F
B`003BL0008J000J<P00J3/0GZX00>9_003n1@00mBd00<Rk0000R08004=900078@0011`002Tl001g
9@2E^@00k4d00?l0003/C000U[T0001g9000:C`000@L00078@00ADX008X00<Zg003f:@00oPL00>1g
001@YP0006=0000E;P000QT0014[001MAP0lX000g8D00?d<003h8000cZ/000b?0000CTh000TS0003
6`009SX0BILD0>a>003o0000k4l008jg0000M2T002Di00036`002B<0051>01:A003AY@00nA/00?`?
003HS`00;I/0001HB@003BL0008J000L<`00K3D0L[000>MN003o0000kd400:Fm0000NR0002/m0004
7000228004]=00^>003?Z`00n1h00?`>003ISP00;I/0001HBP003BL0008J000N=@00Kc80O[<00>YF
003o0000kD/0096h0000M2X002<h00036P002bD005A<02:G003FUP00na400?TK003@Y`003Hl0001;
C@00224000@L000^?`00OAX0]L400?8g003o0`00hfl005FX0000Hd0001<]00026@005Rl006Hm06:[
003UIP00o`400?10002S_00007PS000W>P000a/000XT001CC00SU`00ei<00?`?003h7P00cJh000>;
0000@TT000HO00057P00>D@008D90<Vj003f9P00o@/00=Z9000^V`0005I:000;9P000aX002@i001f
9P2P_000l4000?l1003TJP00FJT0001S@0004R`0008I000H<@00JSP0M;000>UH003o0000je4007nc
0000KC@001Xb00026@004B/0065205BW003SK000o`800?10002N^`0007DX000R>000F@000aX000dW
001KB00oX@00ggX00?h5003c=@00/l00001j7`00:3/000<K000;9@00EdX0<Yd00=b3003n1`00m2l0
0;k30000OAT002/m00036`002R@005E;02jK003KQP00oPP00?@^0030``0007dI000[?@000a/000XU
001FB`0bW000g8<00?h7003c<@00]l40001k7P009c/000<J000<9P00FDT0?J000=mi003n1000lCX0
0:Fm0000MRL0024g00026P003bT005m405:W003TJP00o`400>i80029]P0006hc000J<P000QT001@^
001W>`1a[`00jUD00?l0003XG@00IJ`0001T?`004R`0008I000M=@00LR`0Vk/00?0m003o0`00h7T0
03^O0000F4X000/U00036`00;Ch0084C0<Rm003g8`00o0l00=BK000@T00004E:008000HO09P004Q;
01BB003FU`00o0d00?HW0035`P0007hI000Y?0000aX000dW001LAP1=Y@00i6X00?l0003/C@00O;80
001Y>@005Bh0008I000K<`00LBh0V[X00?4l003n1000gWl0032L0000Dd`000HP000iA000RP00d:L0
0?/D003h7`00bKP000224000;Ch000<K000<9P00FdL0C:D00>AY003o0000je4007:`0000ISd0018/
00026@008CL007PS0;K1003e;@00o@/00=JE000BT@0004A:00057P001b00051>02JH003LQ@00oPD0
0?4k002H^P0006la000I<@000QT001Ta001`<02I^P00lCX00?h6003KQ`008YL0001>CP001R0000HO
001:C00MU@00fX/00?h7003b=`00WK/0001`<0006C40008I000J<P00LBh0X;`00?8e003n2000f8l0
01NC0000ATX000DN00078@00DTd0;i/00=mk003o0P00kTL007jc0000J3/0018/00026P0093T007`L
0<K1003g8@00na@00<j/0000Q@T002lo00036`003BL005m406:[003YE`00o`000>=/0012X@0005I:
00098`0011d00418016@003GTP00o@P00?8f002K^P0006hb000F;`000QT001le001h902n``00mRH0
0?/B003?Z@0008H8000_?`000a/000hX001R@@1][P00k4h00?l1003PN000;i/0001@CP001R0000HO
001?CP[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o001P@`0052h0008I
000>:000ET/07ID00=6T003h7`00o@T00=mi001FZ00006Lk000K<`000QX000/U001@CP0;SP00c;80
0?HY003n1@00hfd006R]0000K3D001lf00036P002B<004]=00>;0039^@00m2h00?l3003UI`00Kjl0
001^<`008CL000<K00098`00BT`00XX00<Vi003d;P00o`@00>AY001[[P0006de000O=P000aX000TT
001>CP09S@00c;<00?HX003n1P00hW8005bZ0000J3X001Xb00026P0032H005=<01RC003AY@00n1h0
0?d<003LP`00A:80001Q@P0052h0008I000@:P00FdL0<id00=R?003k4@00nQL00=FJ000TU`0005M:
000=:0000QT001Ta001W?01JZ@00hW800?h5003e:`00bKT000290000ATX000PQ00037000:3/007HV
096h003/C`00o`000>e:002J^P0007PS000[?@0011`000LQ0013B@00R@40bKT00?D[003n1P00hGD0
05BW0000I3l001H_00026@0042X005a603RN003KR000o0d00?PN003?Z@003i00001?CP002B<000<K
000U>@17UQD0je000?l0003/C000T[P0001e:0009SX000<K00098`00Cdh03i000=2X003i7@00o0h0
0=V=000`W00005U9000>:0000QX001/c001[=`1^[`00if400?l1003`?`00Z[h0001k7P00;3h000@L
00078@00BD`028d00<j]003h8000o0d00=Z;000aW00005U9000=9`000QX001dd001^<`1j/P00jET0
0?l0003]B000UKT0001e:00093T000<K000:9000Dd`07iH00=FH003k4`00nAT00=6T000@T00004i>
00088P0011`002`n001l702``000lCX00?l2003SK000FJT0001T?`0052d0008I000E;P00ICh0GZX0
0>AX003o0P00l3h00:Nm0000NB4002Pk00036`002R@0059=022F003FUP00o1000?TM003>[0001X`0
0014BP001R0000DM000g@`00Q0/0b;`00?HX003m2P00fhL003:L0000F4X000`V00036P008cP007DX
09bk003_@P00o`400>EW001MZP0006@o000C;@000QT001L`001Y>@1`[`00j5X00?l0003/C`00Pk@0
001^<P006c<0008I000@:P00H4<0DJH00>=^003o0P00l3h00::l0000MRH002<h001I00036P0032L0
05Y803^O003NO@00oPH00?<c002g`@0007`M000Y?0000a/000XU001FB`0_V`00fhH00?d8003e;@00
`l@0001n5`00;Ch000<K000:9000E4`0:iX00=^9003m2@00mB`00<C40000OQL002`n00036`002R@0
05E;02jK003LQ@00oPP00?@_002l`P0007`L000Y?0000a/000/U001HB@0jW`00gg`00?h5003b=`00
ZKh0001g9@008cP0008J000>:000GTD0CZD00>=]003o0@00kTD008fg0000Kc4001/c00026@004bd0
06Hm06f^003YF000o`000>UJ001Y[@0006Dn000B;0000QT001`d001a;P2G^@00l3l00?l3003PMP00
?j40001IB@002bD000<K000/?@00OaD0akl00?HU003l3P00eIT001>A0000Ad/00P001Ql0V000ATX0
4I000=FJ003l3P00mRD00<K00000OaH002Xm00036`0032H005]704VT003SK@00o`400>e:0020]000
06Xh000F;`000QT001Xb001`<02F^@00l3h00?l4003NO000<id0001DC0001b0003M300280P3?ZP00
nQH00?TM003:]P0008<>000_?`000a/000/V001JB019Y000hf`00?l0003/C`00M[40001W?0004R`0
008I000P=P00MbD0//000?@_003m2P00ei<001FB0000AT/000DO00078000Cdh08YL00=^7003n1P00
lSP009fk0000LBl001Xb00026@00634006lb09Fi003a?000oPD00=b5000UV00004m>000780001Ql0
04Q<01ZD003ISP00oPP00?8e002Q_000074^000J<P000QT001Ta001`<02L^`00lSL00?h7003IS000
6Y@00018B`001Ah000LP001AC@0/VP00gWh00?l3003^A000P[@0001Y>P004b`0008I000S>000Nah0
aL<00?LS003k4`00cjT000261P00<D0000<K000<9`00GTD0GZX00>UI003o0000i6T004FS0000EdX0
00TS00047@00?TL03Xl00=JE003m2@00lc@009nk0000L30001L`00026@007CD007HV0;[2003f9`00
na400=2W0000Q`D0035000036`003BP0065206V]003[D@00o`400>1f000bW000055=000780001Ql0
04i>2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l00652000E;`000QT0
00dX001EB`0JU000d:L00?LQ003m2000h7L005ZY0000JCX001`c00036P002R@004m>00R=003;]@00
mB/00?h4003TJP00K:h0001]=00083H000<K00098`00BD`008T00<Rl003d<000o`<00>EU001c/000
06la000R>0000a/000PR0017B`00R@00b;`00?@`003o0`00iFL006n_0000KS<0020f00036P002B<0
04a=00J<003;]@00mBX00?h5003RL000H:/0001Y>@006c<0008J000;9@00DTd05I800=2W003h7`00
o@/00=f00018X`000691000E;P000QT0010Z001JB00_V`00f9800?/B003j5P00eIP002NI0000F4X0
00hX00026@00630006Hm05JX003QM000oPH00?HY003:]P000X/00018B`00228000<K000W>P00MBP0
SKL00>]A003o0000kTP009jk0000NB4002`n000470001b00045800271038_000mBd00?h5003RLP00
F:P0001U?@005c00008I000?:P00FdL0=Id00=Z;003l3P00nAd00=2V000BT@00051>000990000a/0
02<h04BE5P3[DP00o`000>e:002G^@0007HV000W>`000a/000PR001=CP0<S`00cjX00?PO003l3@00
fXX003>M0000FTP000hX00026@006S8006Xh06^^003VH`00o`400?4m002^_`0007`L000^?`0011`0
00LQ0016B`05S000cK000?LQ003m3000fXT003BM0000FTP000hX00026P0073<006`e07Ja003XF`00
o`000>i6002J^P0007HV000V>P000a/000XT001BC@0LU@00e9/00?/D003j6000dZ8001>A0000Cdh0
00PR00036`00:cd007/N0:bo003a?000o`800>AY001MZP0006Dn000E;P000QT001@]001T?`1JZ@00
i6/00?l2003a>`00Zkh0001j7`00:C`000<K00098`00DDd079D00=FH003k4P00nA/00<nY0008S@00
04I;0007800011d003E300233P37_`00mBX00?d9003LQ000=Id0001IB@0032L000<J000R=`00M2T0
V;X00>m4003o0@00iVD0066[0000ICh001@]00026@005Rl006Pj06f^003XG@00o`000>a<0027]@00
06la000L=0000QT0010Z001OA01=Y@00hW400?l3003a>`00Y[d0001g90009CT00?<000<J000<9P00
FDT0>9h00=f0003n1P00m3400;c20000OAX002/m00036`002R@005E;02bJ003KR000o@T00?D[0035
``0007lE000^?`000a/000TS001CC00WV@00fX/00?d:003e:P00aL8000205@00;Sl000<K00099000
E4`0:iX00=^8003m2000m2d00<330000OAX002Xm00036`002bD005M:03JN003NOP00oPD00?8e002]
_`0007PS000T>@000aX000hX001MAP1;Y000hVl00?l2003_@`00TKP0001`<00073<0008I000C;000
ICh0JJd00>QJ003o0000jEP006f^0000ISd001<]00026@006c<0070_09>h003_@@00o`800>5c0013
XP0005Y8000<9P000a/002Xm001n5`36`P00mRL00?`=003FUP005Y800019C0001R0000DO0013B@0>
S`00e9d00?`@003g8`00akh000205000;3d000<K000<9P00FTP0AZ<00>9`003o0@00kTP008Be0000
JcH001H_00026@006C8006la09:h003`@000o`<00=mj000gWP0005E;00078000=D<008L40<j/003j
5`00nA/00<^c0000Q0`0031000036`002bD005U904FS003SKP00o`400>a<001j/P0006Pk000C;@00
0QT001le001e9`2^_`00m3400?d9003HT0006I<00018C0001Ql000HP001=CP0OUP00fXX00?h7003b
=P00XK`0001b;@006c<0008I000G<000KC<0TKP00?0n003n1000gH8002RI0000D4h000LP00057P00
AT/05i<00=R@003m2@00lc<00:Fm0000LR`001/c00026@00630006lb09Rj003a>P00oPH00=Z:000M
U@0004Y<00067`001b00051>02RI003MP000o`<00>m20026]@0006Xh000C;@000QT0024g001j8033
a000mbD00?/B003@Y`0008P3000c@@000a/000`V001MA@1JZ@00j5`00?l0003UI`00BJ@0001HB@00
2R@000@L000lAP0;SP00eYP00?d:003c<P00Xkd0001a;`006340008I000L=000MBL0]/400?DY003l
3`00dJ@000280P00<T4000<K000=9`00H4<0IJ`00>YC003o0@00hG<003JN0000DTd000LQ00067`00
C4d02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo04T00691000F;`000QT0
00dW001DC00GT`00cjT00?LS003n2000hG@005fZ0000JST001dd00036P002R@004i>00J<003:]`00
mBd00?l4003UJ000Kjl0001^<P008SL000<K00088P00Ad/008P20<Nn003c<P00o`800>IR001g/@00
070_000S>0000a/000PR0015BP00R0<0akh00?<b003o0P00iV@007>`0000Kc40024g00036`002B<0
04Y=00>;003:]`00mB`00?h5003SK@00I:`0001Z>00073@000<J000;9@00DDd04Y400<nZ003h8@00
o@X00=im001;Y00006=0000F;`000QT000lY001IB00/VP00ei@00080na@00?l0eYD002ZJ0000FDT0
00hY00026@005c0006Dn05>W003PM`00oPL00?HW003;]0001H`0001:C000228000<K000U>P00M2X0
RKH00>YD003o0000kTD00:>l0000NQl002hn000470001R0003m800261`37_P00m2l00?h4003RL000
FjT0001W?0006300008I000?:@00FTP0<Y`00=V=003l3`00nA/00=6T000ETP00055=000:90000aX0
028h04:D5`3ZE@00o`000>i8002K^P0007LT000Y?0000a/000PR001;C@0:SP00cZd00?PP003m3000
fhP003NN0000FdL000lY00026@006C4006Tj06N]003UIP00o`800?4k002b`00007dI000_?`0011`0
00LP0014BP02R`00c;800?LS003m2`00fhH003NN0000FdP000hY00026@006c<006/f07:`003XGP00
o`000>m4002N^`0007LT000W>`000a/000TS001AC@0IT`00e9d00?XE003j5P00dil001JB0000D4h0
00TS00036`00:C`007TP0:Rn003`?P00o`400>EW001QZ`0006Hm000F;`000QT001<]001S@01GZ000
hfd00?l2003a>@00[kl0001k7@00:cd000<K00098`00D4h06I@00=BK003k4`00nAX00=2W000;SP00
04Q<00078@0011d003A200224036`@00mB`00?h8003MP@00>Il0001JB0003BL0008J000Q=`00Lb/0
U;T00>i6003o0000iV8006F/0000ISd001D^00026@005Bl006Ll06V]003WG`00o`000>e:002;]P00
070_000N=@000QX000lY001NA@19Y000hG<00?l3003a>@00Z[h0001h8P009SX000<J000;9P00F4X0
=Id00=f2003n1`00m2l00<330000OQP002`n00036`002R@005A<02RI003JR`00o@X00?HY0036`@00
084C000`@00011`000TS001BC@0TV000fHh00?d;003f:000a/0000214P00;cl000@L00098`00Dd`0
:9T00=Z:003m2@00mB/00<C40000OQL002`m00036`002R@005I;03>M003MP@00oPH00?<c002b`000
07TQ000U>@000aX000dW001LA`17X`00hW800?l2003_@@00UKT0001a;P007C@0008I000B;000I3l0
IJ`00>QM003o0000jUD0076_0000Ic`001@]00026@006S8006la08ng003_A00004L0o`800>9a0016
X`0005]7000<9P000aX002Tl001m6@35a000mRT00?d<003GU00069<0001;C@001R0000DN0012B@0;
SP00dil00?/A003g8P00b;/000214P00;Ch000<K000;9@00FDT0@Z800>9b003o0P00kTH008Rf0000
K3D001L`00026@00634006hc08jg003_@P00o`800>1g000jW`0005I:00078000=48008H70<f_003j
6@00nAX00<ba0000Q@T0039100036`002RD005Q904:Q003RL@00o`400>e:001n/`0006Ti000D;@00
0QT001he001d:@2Y_P00lc<00?d8003ISP0079@0001:C@0200067`1O001;C@0LU@00fHd00?h8003c
=000YKd0001c:`0073<0008I000F;`00K3D0SKL00?10003o1000gGl002bJ0000DDd000LQ00057P00
A4X059800=NC003m2@00lc400:Vn0000LbX001`c00026@005c0006hc09Bi003a?000oPD00=^7000Q
UP0004a=00067`001R0004m>02FH003LP`00oP@00?10002:]P0006/g000D;P000QT0020f001h8P2n
``00mRL00?`@003AY00008T1000d@P000a/000/V001LAP1FZ000ieh00?l0003VI@00C:D0001IB000
2R@000@L000jA@08S@00eIX00?d;003d<000Ykh0001b;@006C80008I000K<`00M2T0/L000?D[003l
3P00dZ8000290000=48000<K000<9P00Gd@0HJ/00>YF003o0000hW4003VO0000Dd`000LQ00057P00
BTd02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l006=0000G<0000QT0
00`W001CC00DTP00cZ/00?LU003n1`00hW80066[0000JcL001he00036P002B<004a=00>;0039^@00
m2l00?l3003UI@00Lk00001`<0008cP000<K00088P00ADX008L40<K0003c=000o`800>MP001k/P00
074^000T>@000a/000PQ0013B@00Q`D0a/000?<d003o0P00iV8007Na0000L300028h00036`002280
04Q<006:0039^P00m2d00?h4003TJ`00J:d0001[=P007CD000<J000:9000DDd049000<j/003g8`00
o@T00=mk001?YP0006@o000F;`000QT000hY001HB@0YV@00eYL00?XE003k4`00ei<002fK0000FTP0
00lY00026@005Rl006@o04nV003ON@00oPP00?HU003</@0028d0001<C@002B<000<K000T>@00Lb`0
QKD00>YF003o0000kd<00:Nm0000O1d002lo00047@001Ql003i700252@36`000m3000?l4003SK@00
GjX0001X>`006C40008I000>:000FDT0;Y/00=R@003l4000nAX00=:Q000HT`00059=000:90000aX0
024g046C603YE`00o`000>i6002O^`0007TR000Z?00011`000PQ0019C007S000cJl00?LR003m2`00
g8D003ZO0000G4H000lZ00026@00634006Pk06>/003TJ000o`800?8i002f`@0007hG000a@00011d0
00LP0012B@00RP00bk@00?LU003m2P00g8@003^O0000G4L000lY00026@006S8006Xh06j_003WH000
o`400>m2002R_00007PR000X>`000a/000TS001@CP0FTP00dj000?XG003j5@00e9d001VD0000DDd0
00TS00036`00:3/007PR0:Bm003`@000o`400>IU001U[00006Ll000F;`000QT0018/001R@@1CY`00
hW000?l3003b=`00]<00001l6`00;3h000@L00088P00Cdh05Y<00=BM003k5000nQP00=6U000>S`00
04Y<00078@0011`0039100214P35``00m2d00?h7003NO`00?:00001KB0003BP0008J000P=P00LRd0
T;P00>e9003o0000if0006R]0000Ic`001H_00026@005Bh006Hm06F/003VH@00o`000>i8002?^000
074^000O=@000QX000hY001MAP16X`00h7H00?l4003b=`00[[l0001i80009c/00?<000<K000;9@00
EdX0<I`00=b5003n2000mBd00<C40000OaH002hn00036`002B<005=<02FH003IS@00o@/00?HW0037
_P00088@000a@00011`000PR001AC@0QU`00f9000?d<003f9P00akh000224000<D0000@L00098`00
DTd09IP00=V=003m2P00mBT00<G20000OaD002dn00036`002R@005E;032L003LP`00oPL00?<a002f
`@0007XO000V>P000aX000`W001KA`14XP00hG@00?l2003`?`00VKX0001b;0007SD0008I000A:`00
Hd00HJ/00>MO003o0000je<007F`0000J3X001D^00026@006C8006hc08^f003^AP00o`400>=^0019
Y00005a7000=9`000aX002Pk001l7031a000mB/00?d;003HT@006i@0001=CP001b0000DN0010B008
S@00dZ400?/B003h8000bKT000224000;cl000<K000;9@00F4T0?j400>5e003o0P00kd@008bg0000
KC<001Pa00026@005c0006dd08Zf003^A000o`800>5e000nX00005M:00078000<T4008D90<ba003i
6P00nQP00<f_0000QPL003=2000470002R@005M:03jP003QL`00o`400>i80022]00006Xh000E;P00
0QT001dd001c:`2U_@00lcD00?h7003JR`007iH0001=CP001R0000HO0019C00IU000f8l00?d9003c
<P00ZKh0001d:P007C@0008I000E;`00JcH0RKH00>m2003o0`00gWd002nK0000DTd000PQ00057P00
@TT04I000=JE003m2P00m2l00:fo0000MBT001dd00026@005Rl006de092h003`?P00oPD00=b5000T
U`0004i>000680001Ql004e>02:G003LQ@00oPD00?0n002>]`0006`f000E;P000QT001lf001g902j
`P00mRP00?`?003BXP000HX0000f@`0011`000/U001KA`1CY`00if000?l0003VHP00D:H0001JB000
2RD000@L000hA006S000e9d00?d<003d;P00Zkl0001c:`006S80008I000J<P00Lb/0[Kl00?D]003l
3@00dil000::0000=D<000<K000<9P00GTD0GJX00>UH003o0000hfh003bP0000E4`000PQ00057P00
B4`02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l006@o000H<0000QX0
00`V001BC@0AT@00cZh00?HV003n1P00hVl006F/0000K3H001lf00036P002B<004Y<006:0038_000
m3400?l2003VH`00Mk40001a;`0093T000<K00088@00@dT008H70<G3003b=P00o`400>QN001n/`00
078/000V>P000a/000LQ0012B@00QPL0aL<00?8e003o0P00iel007^b0000LBh002@i00036`002280
04I;00290@38_000m2l00?l3003TJ000Jjh0001/=@007cD000<J000:9000D4h03Hl00<f^003g9000
oPP00>1h001BY`0006Dn000G<0000QT000hX001GBP0VV000eIT00?XF003k4P00f900036L0000FdP0
010Z00026@005Bh006=004bU003OO000o@T00?LT003=[`002Xh0001>CP002B<000<K000S>000LRd0
PK@00>UH003o0000kd400:^n0000OAX0035000047@001Ql003a600242`35``00lc800?l3003TJ`00
Hj/0001Y>P006S80008I000>:000F4T0:iX00=NB003k4@00nQP00=>O000KU00005=<000;9@000aX0
020f03nA6@3YF@00o`000>m4002S_00007XP000[?@0011`000LQ0017B`04R`00c;800?LT003m2P00
g8<003fP0000GDH0010Z00026@005c0006Ll05nZ003TJ`00o`<00?8g002j`P0007lE000b@@0011d0
00HP0011B000R080b[L00?HV003m2@00gH4003jP0000GDH0010Z00026@006C4006Ti06Z^003VHP00
o`400?10002V_@0007TQ000Z?0000a/000TR001?CP0CT@00dZ800?XH003k5000eIX001bE0000DTd0
00XT00036`009cX007LT0:2l003_@P00o`400>IR001X[@0006Pj000G<0000QT0018/001Q@P1?YP00
hG800?l4003b=@00^<40001m6@00;Sh000@L00088P00CTh059400=>P003j5P00nQL00=:R000AT000
04a=00088@0011`0035000205033a000m2l00?h6003NO000?j40001LA`003RP0008J000N=@00LBl0
S;L00>e;003o0000j5d006b^0000J3X001H_00026@0052d006Dn066[003VI000o`000>i6002C^@00
078/000P=P000QX000hX001LA`13XP00h7P00?h4003b=@00//00001j7P00:3/00?<000<K000;9@00
ET/0;Y/00=^7003m2@00mB/00<G20000P1@002lo000470002B<0059=02:G003HT000o@`00?HV0038
_00008<>000c@@0011`000PR001@CP0NU@00ei<00?`=003g9@00b;/000233P00<T4000@L00088P00
DDd08YL00=R?003m2`00mRP00<K00000P1<002lo00036`002B@005A<02fK003KQP00oPP00?@`002j
`P0007/M000X>`000aX000`V001JB010X@00h7H00?l3003`?@00WK/0001c:`007cD0008I000A:`00
HT40GZX00>IQ003o0000je4007Ra0000JCT001D_00026@00634006dd08Ne003^B000o`400>=/001=
Y@0005e6000=9`000aX002Hj001k7P2m``00mBd00?d:003IS`007YH0001?CP001b4000DN000nA`06
S000dJ@00?/C003h7`00b[L000233@00<40000<K000:9000EdX0?:000>1g003o0P00kd40092h0000
Kc8001Ta00026@005c0006`f08Je003^A`00o`400>5b0011X@0005Q900078000<D0008@<0<^d003i
6`00nQL00<j/0000Q`@003E2000470002R@005I:03^O003PMP00o`800>i60025]@0006/g000E;`00
0QT001`c001b;02Q_000lSL00?h7003KR@008YL0001>CP001b0000DO0017B`0FT`00f9800?d9003d
<000[Kl0001e:0007SD0008I000E;P00JSP0QKD00>i4003o0P00ggX003:L0000Dd`000PR00057@00
@4P03Xl00=JH003m2`00m2h00;700000MRL001he00026@005Bh006`f08bg003`@000oP@00=f2000W
V00004m>000680001Ql004]=01nF003KR000oPD00?4l002B^00006dd000F;`000QT001he001f9P2f
`@00mBX00?`>003CX0000h/0000gA00011`000XU001JB01?YP00iV<00?l0003WH000DjL0001KA`00
2bD000@L000g@`03R`00dil00?`=003e;000[kl0001d:P006c<0008I000I<P00LRd0ZKh00?@_003m
3000e9d000B;0000=d<000@L000;9@00GDH0FZT00>UJ003o0000hf`0042Q0000ED/000PR00057P00
AT/02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l006Dn000I<@000QX0
00/V001AC@0?T000cK000?HX003n1@00hfd006R]0000KC@0020f00036`002B8004Q;00290@37_P00
lc800?l2003WH000Nk80001b;@009CT000<K00078@00@DP008D90<C4003b>000o`400>QK0022]000
07<[000W>`0011`000LQ0010B000Q@X0a<@00?8g003o0@00j5d007jc0000LRd002Di00036`002240
04A:00280`37_P00lc400?l3003UIP00Kjl0001]<`0083H000<J00099000Cdh02Xh00<ba003f9P00
oPL00>1f001FZ00006Hm000H<@000QT000dX001GBP0SU`00e9/00?XH003l4@00fHh003BM0000G4L0
010Z00026@0052h0069104RT003NOP00o@X00?LR003>[@003Hl0001?CP002B<000<K000R=`00LBl0
O[<00>QK003o0000l3l00:no0000OQP0039100057@001Ql003Y500233P34a000lc@00?l3003TJ000
IZ`0001Z>@006S80008J000=9`00EdX0:9T00=ND003k4`00nQL00=BM000NU@0005A<000;9@000aX0
01le03f@6@3XF`00o`000>m1002W_@0007/N000]?P0011`000LQ0015BP02RP00bk@00?HU003m2@00
gH00046Q0000GTD0014[00026@005Rl006Hm05bY003SK@00o`<00?<e002n``00080C000d@P001Ad0
00HO000oA`00Q`@0bKT00?HX003n2000gWl0046Q0000GTD0010Z00026@00634006Pj06N]003VI@00
o`400?0n002Z_P0007XO000[?@000a`000PR001>CP0@T000dJ@00?TI003k4P00eIP001nF0000Dd`0
00XT00036`009CX007HV09bk003_A000o`000>MP001/[P0006Ti000H<@000QT0014[001P@`1<Y@00
hGD00?h4003c<`00_<80001n5`00;cl000@L00088@00CDh04I000=:R003j5`00nQH00=>P000CT@00
04i>00088P0011`002lo001o5P2o``00lc400?h5003ONP00@Z80001LAP003bT0008J000M=@00L300
R;H00>a=003o0000j5/0072_0000JCT001L`00026@004bd006@o05jZ003UIP00o`400>m4002G^@00
07@Z000Q=`000QX000dX001KA`0oX@00gg/00?h5003c<`00]/40001l7000:S`00?<000<K000:9000
ED/0:iX00=Z:003m2P00mBT00<K00000PA800350000470002280055=01nF003GTP00o0d00?LT0039
^P0008@<000d@P0011`000PR001?CP0KU000eYD00?`>003g8`00bKT000243000=48000@L00088P00
D4h07iH00=RB003m3000mRH00<Nn0000PA400310000470002B<005=<02ZI003KR000o@P00?@^002n
``0007`K000Y?0000a/000/V001IB@0mX000ggT00?l4003a>`00XK`0001d:@0083H0008J000@:P00
HD80FZT00>IT003o0000k4l007bb0000JSP001H_00026@00630006`e08>d003]BP00o`400>AZ001@
YP0005i5000>:0000aX002Dj001j7`2i`P00m2h00?d9003IS0008IL0001@CP001b4000DM000lAP03
R`00d:H00?/E003h7@00bk@000242`00<T4000@L000:9000ET/0>9h00=mi003o0`00l3l009Bi0000
L30001Xb00026@005Rl006/g08:d003]B@00o`400>9`0014XP0005U800078000;cl008<>0<Zf003i
7@00nQH00<nZ0000R08003M3000470002B<005E;03RN003PN000o`800>m40029]P0006`e000F;`00
0QT001/c001a;P2M^`00lST00?h6003KQP0099P0001?CP001b0000DN0015BP0DT@00ei@00?d:003d
;`00/L00001f9P007cD0008I000D;@00JCT0PK@00>i7003o0P00h7P003FM0000E4`000PR00047@00
?TL02hh00=FJ003l3000mB`00;G10000MbD001lf00026@0052h006/g08Rf003_@P00o`<00=f0000Z
VP00051>000780001Ql004U<01bE003JRP00oPH00?4j002F^@0006hc000G<0000QT001dd001e:02b
`000mB`00?`=003DW@001X`0000iA@0011`000XT001IB01<Y@00iFD00?l0003XG@00EjP0001LAP00
2bH000<K000e@`00RP00dZ400?`>003e:`00/l00001e:00073@0008I000I<@00LBh0YKd00?@a003m
2`00eIX000N<0000>D@000@L000;9@00G4L0EZP00>QL003o0000i6T004>R0000ET/000PR00057@00
A4X02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo06@006Hm000I<P000QX0
00/U001AC@0<SP00c;800?DZ003n1@00i6/006b^0000KS<0024g00036`00228004I;00280`36`000
lc@00?l2003WGP00O[<0001c;0009SX000<L00078@00?dL008@;0<33003a>P00o`400>UI0026]@00
07@Y000X>`0011`000LP000nA`00Q0`0`<<00?4i003o0@00j5/008:d0000Lb/002Hj00036`001b40
049900271P36`000lc<00?l2003VI000Lk00001^<P008CL000<K00098`00CDh028d00<bc003f:000
oPH00>5d001IZ@0006Ll000I<@000QT000dW001FB`0PUP00dih00?TI003l3`00fX`003NN0000GDH0
014[00026@0052d0065204FS003MP@00o@X00?PQ003?ZP004900001@CP002R@000<J000Q=`00L300
N[800>QM003o0@00l3d00;?00000OaH003A20P001Ah0o`00>4@0088@0<33003b=P00o`800>EV001Z
[@0006/g000K<`000QX000dW001FB`0UV000eYL00?/D003j5P00eIX0026F0000ED/000`V00026P00
7SD0>hlJ0>QN003o0@00l3l00:^n0000O1`002ho000470001b0004=90029003:]P00mRL00?d8003N
OP00A:80001OA0004B/0008I000F;`00ICh0F:P00>9_003o1000lc<00<;40000PA4003I300057P00
1Ql003e600261P38^`00mBX00?h7003NO000A:80001OA0004B/0008I000G<000Ic/0Hj`00>EW003o
0P00lC`00:jo0000Nad002`n00047000228004a=00j?003@Y`00nA/00?/A003FUP008YL0001DC000
2RD000<K000T>@00MBP0V;X00>i6003o0000j5h006n_0000JSP001Ta00026@0042/005m404VT003P
M`00oPD00?<b0030``0007lE000`@00011`000LQ001;C@0>S`00dJ@00?XH003k5000did001JB0000
Cdh000PR00047000;Sh007hI0;_2003c<`00oPD00>1h0016X`0005e5000?:@000QT001`d001_<P24
]@00k4l00?l0003YF@00Lk00001Z>0006340008I000C;000Hd00FZT00>AX003o0@00kd8009^j0000
MBT0028g00036P003BL005Y803bP003NO@00oPH00?<b002j`P0007dK000[?@000a/000XT001DC00X
V@00fH`00?d;003f:000akh000224000<T4000@L00088P00D4h07ID00=NE003l3P00mb800<Zh0000
Q@X003I300047@001b4004i>01VC003FU`00o0l00?LQ003:]`0008D9000f@`0011d000PQ001?CP0L
U@00ei@00?`=003g9000b;`000223`00<D4000@L00098`00DTd09iP00=Z;003m2@00mB`00<;40000
OAT002Xl00036`002bD005Q:03ZO003ON`00oP@00?4i002U_@0007DW000Q=`000QX000lY001P@`1G
Z000iFH00?l0003/C000P;<0001[=P005c00008I000G<000JcL0P;<00>a<003o0000iFL005BW0000
Gd@000hY00036P0093T007TQ0;G1003d<000o@P00=Z:000TV000055=00088@0011d003Y5006:003?
Z@00nQH00?TL003</P0008D9000c@P0011`000TS001EB`00S@0eW@00gg`00?l4003`?@00V;X0001a
;`006c<0008I000E;P00JSP0O[<00>e;003o0@00hfh004NS0000FTP000LQ000^?`00PQ00b[P00?PN
003k5000d:P000290000>4@000@L00098`00ED`0=Id00=mj003o0`00kd4008fg0000KC@001L`0002
6@006S80070_09Zj003a>`00oPD00=b4000WV@00051>00078@001Ah004=9016@003FUP00o@/00?D]
002e`@0007LU000P=P000QT001<]001X>P1n/`00kDT00?l2003PMP00>9h0001EB`002B8000@M000m
AP09S@00e9`00?`=003e:P00^L80001h8`0083H0008I000D;@00JST0Q;D00>m4003o0`00gWd002fK
0000DDd000LQ00057P00Ad/06I@00=V=003n1`00lSP009Zj0000Kc4001L`00026@0073@007@Y0:jo
003d;P00o@`00=BK0008S@0003]5000470002R@005Q904VT003UI`00o`000>QK001JZ@0005e5000<
9P000a/003A200290@3AY000o0l00?HY002g`@0007HV000M=0000QT001P`001`<02Q_000lc800?d:
003EV0002Xh0000jA@0011`000XT001KB01CY`00iel00?l0003UI`00AZ<0001GBP002B<000DM0012
B@0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0I000Ic`001Xb00026P00
2bD0051>00V=003;]@00mB/00?h4003TJ000Kjl0001_<P008SP000<K00088P00A4X008L60<G2003b
=P00o`400>QL0022]00007@Z000W>`0011`000LP000mA`00P`d0_<800?4l003o0000jEL008Zf0000
MBL002Tl000470001R0003a600233P2l`P00lC/00?l1003YF@00Q[D0001d:P009c/000@L00078@00
@DP008H80<G3003c=@00o`800>IQ001f/@0006la000R=`000a/000TS001;C@05S000bkD00?DY003n
1P00hW4005bZ0000J3/001Xb00026P0032L005E;01fE003CX000nAX00?`>003JR@00>Yl0001NA@00
4B/0008I000C;@00H4<0@Z800=b3003m2`00n1l00=2X000BT@00055=000:90000aX0020f001_<P1f
/@00iel00?l1003a>`00]/4000205000=D8200057P3o000g@`00PA80_<800?8h003o0P00iV@006f^
0000K3H001`d00026P0032H005E;02:G003EV@00nQD00?/D003EV00099L0001FB`0032H0008J000M
=00iSQ/0if000?l1003`?@00[[l0001m6P00<40000@M00078000@DP008P20<Vh003f:000oPL00=ml
0017X`000613000B;0000QT001D^001T?`1EY`00hW800?h4003d<@00aL@000223`00=d<000DN0006
7`00>dH008D90<Nm003e:`00oPL00=mj0018X`0005m4000A:`000QT001H_001V?01PZ`00i6T00?l2
003a>P00/L00001l6`00;Sh000@L00088@00BT`02hh00<nY003i7000o1000=NC000UV00005A<000;
9@000aX002<h001d:@2D^@00kDP00?l0003XF`00Lk00001[=`006S80008I000@:P00GTD0AZ<00=mi
003n1P00m3000<?40000P1<0039100047@001b4004U<00b>003@Y`00nAX00?/C003DV`006I<0001@
CP002B<000<L000/?P00OAX0]l400?<e003n1000hGD004VT0000GTD0010Z00026@0073<006hc086d
003[D@00o`000>UG001g/@0006/g000I<@000QT0018/001R@@1GZ000i6/00?l1003`@000Wk/0001f
9`008cP000<J000<9`00FDT0>Il00=eo003n1P00m3000;k30000OQT002`n00036`002B<005=<02FH
003ISP00o@`00?HV0038_00008<>000c@P0011`000PR001?CP0JU000eYL00?`?003h8@00bkD00026
1`00=d@000@M00078@00CDh05Y800=FJ003l4000n2000<^e0000QPL003M300047@001b4004i>01VD
003FUP00o0h00?LS0039^@0008<=000c@@0011`000PR001AC@0TU`00fHd00?d:003e:P00aL@0001n
5`00:cd000<K000;9@00EdX0=ih00=in003n1@00lSL00:Vn0000MRH0028g00026P003bT005m405BW
003TJ000o`000>e:0023]00006`e000H<@000QT001H_001Z>01l/P00k4h00?l0003UI@00EjP0001P
@`003bT0008J000S>000N2<0/L000?<b003n1`00fhP002NI0000DDd000PR00047@00>D@008T10<n[
003j5`00nAX00<f`0000QPH003E2000470002B<005A<002=03:L003NOP00oP@00?4k002K^`00078]
000L<`000QT001@^001Y>P1k/P00k4d00?l0003TJ`00Bj@0001KA`00224002`n00214P39^P00n200
0?/C003AY@000XX0000jA@0011d000PR001DC00bW000gWd00?l3003`@000TKP0001^<`006340008I
000I<@00Kc40U[T00?4l003n1000gH8002ZJ0000DDd000LQ00057P00@DP03Xl00=FI003m3000mB/0
0;W20000N2<0024g00026@004R`006Lk07Zb003]B`00o`400>5c000kW`0005I;00098`0011d003]5
00J<003CW`00o0h00?HX002m``0007TR000Q=`000QT001<]001Y>P21]000kTH00?l2003ON`00<9`0
001BC@001b4000DN0015BP0GT`00f8l00?h8003b=P00W[/0001`<0006340008I000K<`00Lb/0Zkh0
0?@`003m2`00eIT000^>0000?4H000@M00098`00F4X0AJ<00>AZ003o0000jET005jZ0000GTD000`W
00036`00<T4008P30=2V003k4@00mRL00;_20000MbD001he00026@005c0006la09jk003c=000o@T0
0=JF000<S`0003a6000470002R@005Y8052V003WH@00o`000>EU0019Y00005Q900098`0011d00458
00[ooooo0Ol00001ooooo`007_ooool3o`0000Oooooo06@006Pk000K<`000aX000XT001?CP07S000
b[L00?D]003o0`00iFH007>`0000L30002<h00036`002240049900262034a000lSP00?l1003YFP00
Q[D0001e:@00:C`000@L00068000?4H0088@0;S2003`?P00o`000>YE002=]`0007HV000[?@0011`0
00HO000kA@00PQ00^<800?0m003o0000jUL008Vf0000MBP002Pk000470001b0003m700252P34a000
lSL00?l1003WG`00N[80001`;`008cP000<K00088P00BD`00h/00<Zg003e:`00oPD00>9_001PZ`00
06Ti000K<`000QX000`V001DC00KU000dZ800?TL003l3@00fhL003fP0000GT@0018/00026@004R`0
05m403nQ003LQ@00o@`00?PN003@YP005I80001BC@002bD000<J000O=@00KS<0Lk000>MQ003o0@00
lCT00;[20000PA8003M30P001Ah0<P00=D<0080D0;S2003a>P00o`400>IR001a[`0006de000M=000
0QX000`V001EC00PUP00e9/00?XF003k4`00eYH002JH0000EdX000dW00026P0073<0=hdK0>IR003o
0@00lC`00;;00000OQP0035000047@001R00041800271039^P00mBX00?h7003ON@00BZ@0001Q@P00
4b`0008I000D;P00Hd00DZH00>5d003n1@00m2l00<K10000P`d003U40P001Ah0o`00>TD008@;0<No
003e;@00oPH00>1h001;Y0000613000B;0000QT001H_001U?P1LZP00i6/00?l2003b>000]L40001m
6@00;cl000@L00078@00B4`02Hd00<j[003h7P00o0l00=RA000XV@0005E;000;9@000aX0028h001c
:`2A^000kDX00?l0003YF@00M[40001/=@006c<0008I000?:@00GDH0@Z800=ml003n1P00m2h00<G3
0000PA4003=200047@001b0004M;00V=003?Z@00nA/00?/B003EV@0079@0001AC@002B<000<K000[
?@00O1`0/l000?8g003o1000hG<004bU0000Gd@0010Z00026@006c<006dd07fc003ZD`00o`000>YE
001j/P0006`e000J<P000QT0014[001Q@P1DY`00hfd00?l2003`?P00X[`0001g9@0093T000<J000<
9P00F4T0=Yh00=f2003n1`00m2h00<;40000OaL002hn000370002B<0059=02:G003HT000o0d00?LT
0039^P0008@;000e@P0011d000LQ001>CP0GT`00eIT00?`@003h7`00bk<000271@00>D@000DM0007
8000Bdd04i400=BL003k4@00n1h00<bb0000Q`D003U400047@001b4004e>01JC003EV@00o0l00?LQ
003:]`0008@;000d@P0011`000PR001AC@0QUP00f8l00?d;003f:@00a/80001o5@00;Ch000<K000:
9000ET/0=9d00=f0003n1@00lSD00:fo0000Mb@002<h00026P003RP005i5052V003TJP00o`400>e8
0027]@0006dd000I<@000QT001D_001Y>@1h/@00je000?l0003VH`00FZT0001Q@P003bX0008J000R
=`00MbD0[Kl00?<d003n1`00g8D002ZJ0000DTd000PR00047@00=d@008P30<j]003j6000nQT00<j^
0000Q`@003I3000470002B<005A<02nK003MP000oPD00?4j002O^`0007</000M=0000QT001@]001X
>`1g/@00k4l00?l0003TJ@00CZD0001LAP00224002/m00205038_000mb400?/B003AX`0018/0000k
AP0011d000PR001CC00_V`00gWl00?h4003`?P00U;T0001_<@006C40008I000H<@00KS80T[P00?0n
003n1000gGl002fK0000DTd000PQ00057@00?dP038h00=BK003l3@00mBX00;c30000F@00NB40028h
00026P004R`006Hl07Na003/C@00o`400>9a000nX00005M:00098`0011`003U500B;003BX@00o0l0
0?HW0031a00007XP000R>0000QT0018/001X>`1m/`00kTP00?l2003ON@00<id0001CC000224000DN
0013B@0DTP00f9400?d8003c=000XK`0001a;P006C40008I000J<P00LR`0Ykd00?<a003m2P00eYH0
00f?0000?TL000@M00098`00EdX0@Z800>=/003o0000jEL0066[0000Gd@000dW00036`00<D0008L6
0=2X003k4P00mRH00;o30000N2<001lf00026@005Rl006hb09Zj003b=P00o@P00=ND000?T00003i7
00047@002R@005U904bU003VH`00o`000>IS001=Y@0005U90009900011d003m700Sooooo0ol00001
ooooo`007_ooool00ol0003oooooooooo`07ooooo`1T001Y>P0073@000<J000:9000CTh01H/00<Vi
003d;`00o`<00>IT001f/@00074_000T>@000a/000LQ0011B000Q@X0`L@00?4j003o0@00jEP008Vf
0000MRL002Xl000470001Ql003Y500214P2e`@00l3l00?l0003[D`00TKP0001g9000;3d000@M0006
7`00>DD0084B0;C1003`?`00o`000>YD002=]`0007HV000Z?00011`000HP000mA`00Q0`0`<<00?8h
003o0@00j5d007fc0000LBh002@i00036`00228004Q;002:0039^@00mBd00?h4003SK@00Hj`0001Z
>00073<0008J000;9P00Dd`069<00=6T003h7@00o0`00=b50010X@0005m4000C;0000QT0018/001N
A@0lX000fhL00?`=003i7000dJ@001RC0000DTd000/U00036P007SD006de06n_003VH`00o`800?8g
002n``00088@000hA08000DN038003A2001o5P2d`@00lC`00?l1003WH000M;00001]<`007SD000<J
000;9@00E4`07ID00=>N003j6000na800=NC000YV@0005M:000=9`000QX001/c03J=703VI000o`80
0?4j002f`@0007lF000b@@0011d000HO000nA`00QPL0b;`00?D/003n1P00h7L004fU0000HT4001<]
00026@004bd0069104nV003PMP00oPD00?@^0037_`0008@;000jA@8000DN0?l003Q400233@36`@00
m2l00?h5003PMP00CZD0001Q@P004b`0008I000E;P00I3l0FJT00>=]003o0`00lSH00;W20000OQL0
0310000470001b4004I;00J<003>[@00n1l00?`>003HS`00:YX0001FB`0032H000<J000Q=`00LR`0
SKL00>a<003o0000jEL007Zb0000KC@001/c00026@003bT005a603nQ003NOP00oPL00?D/0036`@00
088?000e@P0011d000LP0015BP07S000cj/00?TL003k4@00eYL001jE0000DTd000TS00036`00:S`0
07/N0:no003b>000o`<00>9a001?YP000613000A:`000QT001Xb001/=P1j/P00jUD00?l0003[D`00
O[<0001]=0006c<0008I000A:`00H4<0DJH00>9_003o0P00lC`00:Jm0000Mb@002Dj00036P002bH0
05M:03>M003LQ000oPP00?D/0035a000080E000_?`0011`000TS001AC@0PUP00ei<00?`>003g8`00
b[P000252@00=T<000@M00078@00C4d05I800=BK003k4@00n1h00<ba0000R0<003Y500057P001b00
04U<016@003CWP00na800?TM003=/00008P3000jA@001Ad000LP001;C@0DTP00e9/00?`@003h8000
bkD000252000=T<000@M00088P00D4h07YD00=RA003m3000mRL00<K00000P1<002ho00036`002R@0
05E;036L003MPP00oPH00?<c002``00007PR000T>@000aX000hX001MA@1=Y@00hfd00?l1003^AP00
RkH0001^<`006S80008I000E;P00J3X0MK400>]B003o0000if4005jZ0000HT80010Z00026P008CL0
07HV0:Zn003b=@00oPH00=b3000]V`0005=<00098`0011`003I300271@3=[`00nAX00?XH003>[000
08P2000hA00011d000PR001CC00/VP00g8<00?h5003b>000Xk`0001c:P007SD0008I000C;@00Ic`0
M;000>]A003o0000iFL0056V0000GDH000PQ000Z?000OaH0akh00?LS003k4@00dZ4000N<0000?DH0
00DM00088P00DTd0;9X00=f1003n1@00lC`009Rj0000L30001Xb00026@005c0006dd08ng003`@000
o`<00=im000`W00005=<00088P0011d003i700V=003DW@00o0h00?HX0030``0005T007XO000S>000
0QX0014[001U?P1c/000k4l00?l1003RK`00@J40001GBP002R@000@L000hA002RP00dJ<00?`A003f
9@00a<@0001k7P008cP0008J000B;000Ic`0N[800>e:003o0P00h7L003JN0000E4`000PR00057@00
@TT04Y400=NC003m2@00lc<00:Fm0000LRd001Xb00026@006C80074^0:>m003c<`00o@T00=ND000@
T000041800047@002B<005I;03nQ003SKP00o`000>YE001T[0000613000=9`000a/002lo0026203?
ZP00na<00?LT0033a00007TQ000P=P000QT001D_001]=02F^@00lSP00?h8003HT@004I40000oB000
11d000TS001HB@19Y000iFD00?l0003WH@00D:H0001JB0002R@000@L000mA`0:ooooo`7o00000Ooo
ool001kooooo00?o0000ooooooooool01oooool0o`00JST001dd00036P002B<004a=00:;0038^`00
m3000?l2003VHP00N[80001b;@009CX000<K00078@00?dL008@<0;g3003a?000o`000>YF002=]`00
07HU000[?@0011`000HO000iA000P1@0/L000>m1003o0000je4009Bi0000N28002dn00047@001Ql0
03Q40020502a`000kd400?l0003[DP00T;P0001g9@00:cd000@L00068000?4H008<>0;g3003a>P00
o`400>QK0021]000078/000U>@000a/000PR0016B`00R@40b;/00?@^003o1000i6/006J/0000JcL0
01dd00026P002bD0059=01FB003@Y`00n1l00?d;003LP`00@j80001P@`004bd0008I000A:`00GDH0
>Il00=Z:003l3P00nA/00=:R000JU00005=<000;9P000QX001dd001/=P1/[P00iFD00?l2003b=P00
`L@000233P00>TD000HO00057@00<T4007hH0;70003`?P00o`400>QM001g/@0006hb000O=P000aX0
00/U001CC00JU000dj000?XI003k4@00f94002bJ0000F4T000hX00026@006S80=8`L0>EV003o0P00
lSP00;W20000P1D003A200057@001Ql003a600252@37_P00m2d00?h5003QM@00DJH0001S@00052h0
008I000C;@00HD80C:D00>1h003n1P00mB`00<Nm0000Q@P003a600067`001Ah003M300223`35``00
m3000?h5003QM000DJH0001R@@004bd0008I000D;P00I400EZP00>9`003o0`00lc@00;c30000OaD0
039100047@001b0004E:00B;003=[`00n2000?`=003IS@00;I/0001GBP0032H000<J000P=P00LBh0
R[H00>a>003o0000jUD007fc0000KS<001`d00026P003RP005]703bP003MP000oPP00?D[0037_`00
08<=000f@`001Ad000HP0013B@04R`00cZd00?PN003l4000eiD0026F0000Ddd000XT00036`00:C`0
07XP0:bo003a>P00o`<00>=_001BY`000652000A:`000QT001Ta001[=`1f/@00jEL00?l0003[D@00
PK@0001^<`006c<0008I000@:P00Gd@0CJD00>9a003o0`00lCX00:Zn0000N28002Hj00036`002bD0
05I:032L003KQP00o@T00?D[0036`P00084C000`@000l`0011`000PR001@CP0MU@00eYD00?`?003g
8@00b[H000261`00>4@000DM00078000BTd04Y400=>N003k4P00nAd00<f_0000R@4003a600057P00
1R0004M;00j?003BX000na@00?TL003=[P0008T0000lAP001Ah000LP0019C00AT@00e9d00?/B003h
7P00bk<000261P00=d@000@M00078@00Cdh079@00=ND003l3@00mRD00<Nn0000PA4002lo00037000
2B@005A<02jK003LQ000oPL00?<b002d`@0007TQ000U>P000aX000dW001LAP1:Y000hfl00?l1003^
A000S[L0001_<@006S80008I000D;@00Ic/0L[000>YD003o0000iel0066[0000HT40014[00026P00
83H007DX0:Jm003b=`00oPD00=f1000`W00005A<00098`0011`003A200261`3</@00nA/00?XF003?
ZP0008T0000iA@0011d000PR001BC@0ZV@00g8D00?h6003b=P00Y[d0001d:@007SD0008I000B;000
ISd0L:l00>]C003o0000iFD005BW0000GTD000PQ000Y?000OQP0a/000?LT003l4000dil000V=0000
?dL000DM00088@00DDd0:IT00=b3003n1@00lCX009^k0000LBl001Xb00026@005c0006`e08^f003_
@P00o`<00=mk000cW@0005A<00088P0011d003a600N<003CW`00o0l00?HV0034a00007/N000T>@00
0QX0014[001T?`1`[`00je400?l0003SK@00A:80001HB@002R@000@L000f@`00R@00dJD00?/B003g
9000aL80001l700093T0008J000A:`00ISd0M[400>a<003o0@00hG@003RN0000E4`000PR00057@00
@4P03i000=JF003m2P00m3400:Rn0000Lb`001/c00026@006C40070_0:2l003c=@00o@P00=NB000B
T@00045900057@00228005E;03bP003RL000o`000>]C001X[@000652000>:0000a/002ho00252P3>
[000na@00?LS0035``0007XP000Q=`000QT001D^001/=@2C^000lCX00?h7003HS`0059400011B000
11d000TS001GBP16X`00iFL00?l0003WG`00DjL0001KB0002R@000@L000lAP0:ooooo`7o00000Ooo
ool001kooooo00?o0000ooooooooool01oooool0o`00JSL001he00036P002B<004Y<002:0038_@00
lc800?l2003WH000OK<0001b;0009SX000@L00078000?DL008<>0;[2003`?@00o`000>YD002@^000
07LT000/?P0011d000HO000gA000OaD0[Kl00>m3003o0000k4l009Rj0000NB4002ho00047@001Al0
03I3001o5P2]_`00kd<00?l0003[D000U;T0001h8`00;3h000@M00067`00>TD0088@0;W2003a?000
o`000>UI0024]@0007<[000V>P000a/000PQ0014BP00R0<0akd00?@`003o0`00i6T006V]0000K3H0
01de00036P002bD0055=01>A003?Z@00n2000?d;003MP000AZ<0001Q@P0052h0008I000A:`00G4H0
=Yh00=Z<003l3`00nAX00=>P000MU@0005A<000<9P000QX001`d001[=`1Y[@00iFP00?l3003c=000
aL@000243000>dD000HO00047@00<D0007dJ0:fo003`?`00o`000>QK001k/P0006la000P=P000aX0
00XU001BC@0HT`00dZ800?TJ003l4000f8l002nK0000FDT000hX00026@006C80<h/M0>AX003o0P00
lSH00;g30000PA<003E200057P001Ql003]500242`36`000m2l00?h5003QL`00E:L0001S@0005Bh0
008I000B;000H4<0BJ@00=mj003n1`00mBX00<Rk0000QPH003e700067`001Ah003E300214@33a000
lc800?h4003RL@00E:L0001S@00052d0008I000D;@00Hd00DjL00>9b003n1000lc<00<330000P1<0
03=100047@001R0004=900::003</@00mb800?d<003JRP00<9`0001HB@003BL0008J000O=P00L2l0
Q[D00>]@003o0000jU<0086d0000Kc8001dd00026P003RP005Y803ZO003MPP00o@P00?DY0038_@00
08@;000hA0001Ah000HO0012B@02RP00cJl00?PO003l3`00ei8002>G0000Dd`000XT00036`009c/0
07TR0:Rn003a?000o`800>=]001EZ0000691000B;0000QT001Pa001Z>01c/000jET00?l0003/C`00
QKD0001_<P0073@0008I000@:P00GT@0BZ@00>5c003o0`00lSP00:fo0000NB0002Lk00036`002bD0
05I;02jK003KR000o@T00?DY0036`000084A000b@@00l`0011`000PR001@CP0JU000eYL00?`?003h
8000bk@000271@00>DD000DM00078000BD`049000=>P003k5000nA/00<j]0000RP0003e700057P00
1Ql004E:00b>003BXP00naD00?TJ003>[0000HX0000mA`001Ah000HP0017B`0?T000dil00?/C003h
7@00c;4000271000>D@000@M00078@00CTh06I@00=JF003l3P00mb@00<Rl0000PPl0035000047000
2B<005A<02^J003KQP00oPP00?@`002h`@0007XO000V>P000aX000dW001LA`17X`00hW400?l2003_
@`00TKP0001`<0006c<0008I000C;@00IS`0KZl00>YF003o0000j5d006B/0000Hd00014[00026@00
7cD007@Y0:>l003a>@00oPD00=io000bW00005E;00098`0011`003=100252P3;/`00nA`00?XE003@
Y`000XX0000kA@0011d000PR001AC@0WV@00fhL00?h7003c=000Z[h0001e9`007cH0008I000B;000
ICh0KJh00>YE003o0000iV<005NX0000Gd@000TQ000X>`00OAX0aL800?HV003l3`00e9d000^>0000
@4P000DN00078@00D4h09YP00=b5003n1P00lSP009nk0000LRd001/c00026@005Rl006/f08Rf003_
A000o`800>1i000fWP0005A<00098`0011d003]500F<003BX@00o1000?LU0035``0007`L000U>@00
0QX0010Z001T?`1][P00je<00?l0003TJ`00Aj<0001IB@002RD000@L000e@P00R080d:L00?/C003g
8P00a/00001m6`009CX0008J000A:`00ICh0Lk000>a>003o0@00hG8003^O0000ED/000TR00047@00
?TL03Hl00=FH003m2`00m2l00:bo0000M2X001`c00026@00634006la09bk003b=P00oPP00=R@000E
TP0004=900057P00228005A<03VO003QLP00o`400>]A001[[P000691000>:0000aX002dn0024303=
[P00nQD00?LQ0036`@0007/N000R>0000QT001@^001[=P2@^000lC/00?h6003IS@005Y800013B@00
1Ad000TR001FBP13XP00i6T00?l0003XG@00EZP0001KA`002bD000@L000jA@0:ooooo`7o00000Ooo
ool001kooooo00?o0000ooooooooool01oooool0P`00JcH001le00036P002B<004Q<00290@37_`00
lc@00?l2003WGP00P;@0001c:`009c/000@L00068000?4H0088@0;K1003`?`00o`000>]B002C^@00
07PR000]?P0011d000DO000f@`00OQL0Z[h00>i5003o0000k4d009^j0000NQl0031000057@001Ah0
03E2001n602Z_P00kT@00?l0003/C`00UkT0001i8P00;Ch000@M00067`00>D@0084B0;K1003`?P00
o`000>UG0027]@0007@Y000W>`000a`000LQ0012B@00Q`D0akl00?<a003o0`00iFL006f^0000KCD0
01he00036P002R@0055=012@003?Z`00mb400?d:003NOP00BJ@0001R@@005Bh0008I000@:P00FdL0
<id00=V>003l4000nQP00=>M000OUP0005E;000<9P000QX001/c001Z>01V[000i6X00?l3003c<P00
aL8000252P00?DH000HO00047@00<40007`K0:Zn003_@@00o`000>UJ001n/`00070_000Q=`000aX0
00XT001AC@0ETP00dJ@00?TK003l3`00fHd0036L0000FTP000lY00026@006C40<HXN0>AZ003o0`00
lcD00<330000PQ4003M3008000DN0?l003U500233@35`P00m3400?h4003RL@00EjP0001T?`005Bl0
008I000B:`00Gd@0AZ<00=il003n1`00mRT00<Vi0000Q`@003m700067`001Ad003A200214`2o``00
lc@00?l3003RK`00EjP0001T?`005Bh0008I000C;@00HT40D:H00>5d003n1000lc400<C40000PA40
03A200057@001R0004580029003;/`00mb<00?d;003KR000<id0001IB@003BL0008J000N=@00L300
Pk@00>]B003o0000je4008Be0000L30001he00026P003BP005Y803NN003LQ000o@T00?HX0038^`00
08D9000iA@001Ah000HO0010B000RP00c;400?PP003l3P00f90002JH0000E4`000XU00036`009SX0
07PS0:Fm003`?P00o`800>A[001HZ00006=0000C;0000QT001L`001Y>@1`[`00j5/00?l0003/C@00
R;H0001`<0007C@0008J000?:@00GTD0B:<00>5e003o1000lSL00;700000NQl002Pl00036`002R@0
05E;02^J003JRP00o@X00?HX0037_P00088?000c@@0011`000PQ001?CP0HT`00eIT00?`@003h7`00
c;8000280`00>dD000DN00068000Ad/03Hl00=:R003k5@00nAX00<n[0003R`0003m700057P001Ql0
04A:00Z>003AY000nQH00?TI003?ZP000h/0000oA`001Ah000HO0015BP0=S`00dZ400?/D003i7000
cJl000280P00>TD000DM00078@00C4d05i<00=FH003l3`00mb<00<Vj0000P`h00391000470002B<0
05=<02VI003KR000o@P00?@_002k`P0007/M000W>`000aX000`W001KB014XP00hG<00?l2003_@@00
UKT0001a;`0073@0008I000C;000ICd0Jjh00>UH003o0000j5/006N]0000I3l0018/00026@007SD0
07<[09nl003a>`00oP@00=im000eW@0005I;000:900011`003910024303;]@00n1h00?/D003AY@00
18/0000lAP001Ad000LQ001@CP0TV000fXT00?h7003c<`00[Kl0001f9P0083H0008I000A:`00I3l0
JZh00>UG003o0000if4005ZY0000H4<000TQ000V>P00O1/0aL@00?HW003l3P00e9/000j?0000@TT0
00DN00078@00Cdh099L00=^8003n1P0006h0lSL00::l0000Lb`001`d00026@005Bh006/g08Fe003^
AP00o`800>1g000iW`0005E;00098`0011`003U500:;003AX`00na400?LS0036`@0007dJ000V>P00
0QX000lZ001S@01Y[@00jUD00?l0003TJ@00BZ@0001JB0002bD000<K000d@P00Q`@0cjT00?/D003h
8@00akh0001m6@009SX0008J000@:P00I3l0L:l00>]@003o0@00hW0003jP0000ET/000TS00047@00
?DH02Xh00=FJ003m3000m2h00:no0000MBT001`d00026@005c0006lb09Vj003b>000oPL00=V>000G
T`0004E:00057P00224005=<03NN003QM000o`400>a?001^[`0006=0000?:@000aX002`m00233P3=
/000nQH00?PP0036`00007`L000S>0000QT001<]001Z=`2<]`00l3d00?h6003JR`006I<00014BP00
1Ah000PR001EB`10X@00i6/00?l0003XF`00FJT0001LAP002bD000@L000iA0[ooooo0Ol00001oooo
o`007_ooool00ol0003oooooooooo`07ooooo`0S001/=@0083H000<K00088P00Ad/008P30<K1003b
=@00o`400>QL0023]00007@Y000Y?00011`000HP000jA@00PA80/l000>m1003o0000je0009Ni0000
NB4002lo00057@001Ah003A2001m6@2W_@00kTL00?l0003]B`00W[/0001k7@00<D000P001Ah0GP00
=48007dJ0:Jm003^AP00o`000>a=002J^P0007XP000^?`0011d000HO000gA000P1@0//000?0o003o
0000jUD008Zf0000MBP002Pk000470001b40045800261`36`@00lc<00?l2003UI@00L:l0001]=000
7cH000<J000:9000D4h03Xl00<j]003g8`00o@T00=il001<Y@0006=0000E;`000QT0010Z001KB00a
W000f9000?/A003j5`00e9/002:G0000ET/000dW00026P006S8006Ti06>[003TK000o`<00?@a0036
`00008D8000nA`001R0000@M000_?`00Nad0Y[d00>m3003o0000jEP0086d0000LBh0028h00036P00
2R@0051=01>A003@YP00nAd00?`>003JR`00=9d0001KA`003bT0008I000H<@0_RAh0hf`00?l3003c
<`00a<@000223`00>4@200057P3o000hA000P`l0aL@00?<b003o1000hfl005ZY0000ICh001H_0002
6@004B/005i404>R003NOP00o@P00?HW003:^00008P20010B0001R0000@M000c@@00P1D0_<800?8e
003o0`00hfd005ZY0000ICh001D_00026@004R`0065204fU003PMP00oPD00?@`0035``00088?000f
@`001Ad000HO0010B000R080bkD00?LU003m2P00fhH003FM0000FTP000dX00026P007C@006lb082c
003ZE000o`000>]?0027]@00074_000O=P000QX000dW001IB@0dW@00fhH00?d:003f9P00bKT00026
1`00>dD000DN00067`00?dL008T10<^c003g8P00o0d00=V>000YV@0005E;000;9@000a/002Dj001g
9@2R_000l3l00?l1003TJ@00FjT0001T?`004bd0008I000G<000J3X0KJh00>QM003o0000kD/008^f
0000LBl001he00026P003bT005e604FR003PM`00oP@00?8e002d`@0007/M000Z?0000a/000XT001D
C00XV@00fH`00?d;003f9P00b;`000233@00=48000@M00078@00CTh05Y800=BK003k4P00n1d00<f`
0000R@4003a600057P001R0004E:00^>003AY000nQH00?XI003?Z@001H`00011B0001Al000HO0012
B@07S@00d:H00?XG003j6000d:P000F<0000@4P000DN00067`00A4X02Xh00=6S003j5@00nA/00<j]
0000R@0003a600057P001b0004Y=01BB003EVP00o1000?LQ003:^00008@<000c@@0011`000PR001B
C@0VV000fXX00?d9003e;@00_/<0001l6`00:3/000<K000<9P00FTP0@J400>5e003o0`00l3l009Rj
0000LRd001dd00026@004R`006Dn06R]003XFP00o`000>UI001Z[P0006Dn000B;0000QT001dd001b
;02L^`00lC`00?l4003ON`00>9h0001FBP002R@000<K000`@000P`d0b[L00?PO003k4`00dJ<000J<
0000?TL000DM00078@00D4h08YL00=Z;003n2000lc400;300000Mb@0024g00026P004B/006=006N]
003YF@00o`000>MO001MZP00061300098P009CX007/M0<74003f:@00o0d00=FI000@T00004=90005
7P001b0004m>026G003JRP00oPL0001^0?<e002V_@0007@Z000M=0000QT001@^001Z>021]000kTP0
0?l2003QM@00>il0001FB`002B<000@L000hA000RP00dJD00?/B003g8P00akl0001n60009c/000<J
000?:@00HT40IZ`00>YF003o0000iFL004fU0000FdL000/U00036`00<T4008H60<j[003j5@00n200
0<Rm0000OQL002Lk00036P003bX006=006f^003[DP00o`000>=^0011X@0005M:00098`0011d003]6
00R=003DW000o0d00?D/002c`00007DW000M=0000QT001H_001^<`2F^@00lCX00?h6003JS0006Y@0
0016B`001Ah000LQ001CC@0dW@00h7H00?l1003/C@00LJl0001T@0003bT000<J000[?@00PQ00c;80
0?XG003h7`00akh0001m6`0093T0008J000C;@00JST0RKH00?0o003n1@00fXT001^D0000AT/000DN
00088P00ED/0?Z000>=]003o0000jET005bY0000GDH000/V00047000=d@:ooooo`7o00000Oooool0
01kooooo00?o0000ooooooooool01oooool08`00KC@0024g00036`00228004E:00271@35`P00lSL0
0?l1003YFP00Q[D0001e:000:S`000@L00067`00>D@0080D0;30003_@`00o`000>a>002J^P0007XO
000`@0001Ad000DN000c@@00O1/0Xkd00>e9003o0000kDT00::l0000O1`00391008000DN05h00391
001l6`2S_000kDP00?l0003]B`00WK/0001k7P00<40000DM00057P00=T<007lF0:no003_@@00o`00
0>YC002>]`0007HV000Y?00011`000LP000oB000Q@T0aL<00?<e003o0P00iV<007>`0000KS80020f
00036P002R@004m>00b>003=[`00mb@00?d8003ONP00CjD0001T?`005Rl0008I000?:@00FTP0;Y/0
0=NB003k4P00nQH00=FI000TV00005M:000=9`000QT001Xb001X>P1PZ`00hfd00?h4003d;`00akh0
00261P00@4P000HP00047000;Ch007XO0:>l003^A@00o`000>YF0024]@00078]000S>0000a/000TS
001@CP0AT000d:P00?PN003l3@00fXT003NN0000G4L000lZ00026@005c00;XPO0>=^003o1000lc40
0<G30000P`d003U50P001Ah0V000=d<0088@0<;4003c=000o`<00>=]001MZP0006Hm000G<0000QT0
010[001NA@10X@00gH000?d9003f9P00b[H000290000@TT000HP00047@00<D4007lF0;W2003b=`00
o`<00>A[001MZP0006Hm000F;`000QT0018/001P@`1:Y000h7P00?h6003d;P00a/4000233P00=d<0
00DN00067`00?TL008P40<Zg003f9P00o@X00=b4000hWP0005Y8000>:0000QX001dd001^<`1m/`00
jUH00?l0003/CP00R[H0001a;P0083H0008J000<9`00F4T0<I`00=^8003m2`00mbD00<Zg0000Q`D0
03a600057P001Al003e600280`3;]@00mb<00?d<003IS000:iX0001FB`002bD000<J000T>@00MRH0
W[/00>m1003o0@00iFL005jZ0000I3l001@]00026@005Rl006Lk06Z]003WG`00o`000>e9002>]`00
074^000O=@000QX000hX001LA`12XP00ggT00?h5003c=000]l40001l7000:cd000<K000:9000Dd`0
9YP00=V>003m3000mbD00<Vj0000Q0/003I300047@001b4004a=01>A003DW@00na<00?TL003=[P00
08X0000nA`001Ah000HO0014BP09S@00dJH00?XG003j6000d:L000N<0000@TT000HO00057`00@DP0
1H`00=2X003j6000nQL00=2V0007S@0004990P001Ql0d`00@TT028d00=6U003j5P00nAT00<j[0001
RP0003e600057P001R0004U<01:A003DW000na400?PP003:]P0008D:000e@P0011`000PR001AC@0T
U`00fH`00?d:003e:`00`/@0001m6P00:C`000<K000<9P00FDT0?j400>1g003o0`00l3d009^k0000
Lb`001he00026@004R/006@o06F/003XG000o`000>UG001][P0006Hm000C;@000QT001`d001a;P2I
^P00l3h00?l3003PN@00>Yl0001GBP002RD000<K000_?`00PPl0bKT00?PP003k4P00dZ4000R=0000
?dL000DN00078@00Cdh07iH00=V=003m2@00m3000;C10000N2<0028h00026P0042X0069106B/003X
F`00o`000>QM001PZ`00065200098P0093T007XO0;k3003e:P00o@`00=JG000BT@0004E:00057P00
1R0004i>01nF003JS000oPP00?<c002Y_P0007@Y000N=@000QT001@]001Y>@1n/`00kDT00?l1003Q
L`00?Z00001GBP002R@000@L000f@`00R@40d:L00?/C003h8@00akd0001o5`00:3/000<J000>:@00
HD80Hj`00>UH003o0000iFD0052V0000G4L000`V00036`00<D0008H80<j]003j5P00n1h00<Rk0000
OaD002Pl00036P003bT0069106Z]003ZD`00o`000>=/0014XP0005Q:000:900011`003Y500J<003C
WP00o0h00?D[002f`@0007HV000N=@000QT001H_001]=02B^000lC/00?h6003JRP0079D00018C000
1Ah000LQ001BC@0aW000h7P00?l2003]B`00M;00001T?`0042X000<J000Y?000PA80bk@00?XI003h
7@00b;`0001m6@009CT0008J000B;000JCX0Q[D00>m1003n1000fhL001fE0000Ad/000DN00088@00
E4`0>il00>9_003o0000jEL005nZ0000GTD000`V00036`00=T<02_ooool1o`00007ooooo000Noooo
o`03o`000?oooooooooo00Oooooo01P006hc000R=`000a/000PR0013B@00QPL0aL@00?8h003o0@00
jEP008Zf0000MRH002/m000470001Ql003Q4001o5@2/_`00kd@00?l0003/C000WK/0001k7P00<D02
00057P09000b@@00O1`0X;`00>e:003o0000kTP00:Fm0000OAX003=2008000DN0?l00350001k7@2P
_000kDX00?l0003]B@00XK`0001k7@00<D0000DM00057P00=D8007hG0:bo003_@`00o`000>]B002A
^00007LU000Z?@0011`000LP000nA`00Q0/0a<@00?8f003o0P00if4007Ja0000Kc40024g00036`00
2B<004i>00Z>003=/000mRD00?h8003PN000DJH0001T?`005c00008I000?:@00FDT0;9X00=ND003k
4`00nQD00=JG000WV00005M:000=:0000QT001Ta001W>`1MZP00hVl00?h4003d;P00b;d000271@00
@DP000LP00047000;3h007XP0:2l003^AP00o`000>YD0027]@0007<[000T>@000a/000TS001?CP0?
T000cjX00?PO003m3000fhL003VO0000G4H0010Z00026@005Rl0;HLO0>9`003n1000m3000<K10000
Q0/003]500067`001Ah003E300214P2n``00lSD00?l3003TJ`00GjX0001W?0005c00008I000@:P00
GDH0?J000=f2003m2P00mbD00<^d0001RP0004=90007800011d00310001n602e`@00lST00?l2003T
J@00H:/0001V?0005c00008I000A:`00Gd@0B:<00=mj003n1P00mBd00<No0000Q0`003Q400057P00
1Ql003e600271P39^@00mRL00?d9003MPP00>il0001KA`003RT0008I000L<`00KC@0N[800>UH003o
0000k4`008fg0000LR`0024g00036P0032H005M:02nK003JRP00o@/00?LT003;]@0008P3000mA`00
1Ql000DN000lAP00Q`D0b[L00?LT003m2`00fXX002jK0000EdX000/V00036P008cP007DX09^k003_
@`00o`400>EU001QZ`0006Dn000D;P000QT001D_001W?01W[@00if400?l0003^A`00TKP0001b;000
83H0008J000>:000FdL0?j400=mk003n1@00lc800;[20000OAX002`m00036`002B<005==02>G003H
T000o0d00?LT0039^00008D9000g@`0011d000LQ001:C00AT000dil00?/D003i6`00cZ`000:;0000
?dL000DN00067`00@TT01h`00=2X003j6000nQL00=6U0009S@0004A:00067`001Ah003m700>;003?
ZP00nAT00?XF003AY0002Hd00013B@001Ql000DO0011B006S000d:L00?XG003j60000<h0cjT000>;
0000?dL000DN00068000Ad/049000=>N003k4P00n1l00<^d0000QPP003I300047@002280051=026G
003ISP00o@X00?DZ0035a00007hH000[?@000a/000/U001HB@0lX000ggT00?l3003a?000Wk/0001c
:`007SD0008I000A:`00Hd00HZ/00>MN003o0000jUD0072_0000Ic`001<]00026@006c<0074_09Fi
003`@000o`<00>1g000mX00005Q9000;9@000a/002ho00214@38^`00mb400?/A003CW`002Xh00011
B0001Ah000LP001>CP0MU@00f8l00?d:003d;P00]l40001i8@008cP0008J000@:P00HT40HJ/00>QM
003o0000j5/006>/0000HT4000TR000S>000NB00^l800?D/003m2`00eiD001FB0000Ad/000HO0006
8000C4d079D00=V>003m2000lc800:bo0000MBP001le00026@004bd006Pj07^b003]B`00o`400>9a
0011X@0005Q:000:900011`003E200280`3?Z@00na@00?PP0038^`0007lE000Y?0000aX000hX001P
@`1PZ`00jEX00?l0003VH`00DjL0001LAP0032H000<K000`@000Q@X0cJl00?XG003h7@00bKT00020
5000:S`000<J000>:@00HT80Ijd00>YE003o0000i6X004JS0000F4T000XT00047000>D@018/00=>P
003l3P00mBT00;W20000Mb@001lf00026@005Bh006`e08ng003`?@00oPD00=^8000NUP0004Y<0006
7`001b00055=02nK003ONP00o`800>e:001g/@0006Dn000@:P000aX002Pk00204`3:]P00nAX00?TL
0039^P0007hG000V>P000QX0018/001X>`23]000kd800?h4003LQ@0089H00019C0001Ah000LQ001C
C00hWP00hW400?l0003ZE@00HZ/0001OA00032H000<K000e@P[ooooo0Ol00001ooooo`007_ooool0
0ol0003oooooooooo`07ooooo`0H001_<P008SP000<K00088@00@TT008D90<;4003a>P00o`000>YF
002=]`0007LU000/?@0011d000HO000f@`00OQL0ZKh00>i6003o0000kD/00:2l0000O1`003910P00
1Ah05000<D0007/N09fk003/C000o`000>i6002X_P0007hI000e@P001Ah000DM000`@000NQh0WK/0
0>e;003o0000kTP00:Bm0000O1/003910P001Ah09000<d8007dI0:Vn003^A@00o`000>]@002D^@00
07PT000[?@0011`000HP000lAP00P`d0`L@00?8h003o0@00iel007Vb0000L300028g00036`002B<0
04e>00R=003</P00mRL00?h7003PMP00E:L0001U?P005c00008I000>:000F4T0:IT00=JF0080na@0
05L0eYH002VI0000F4T000hX00026@00634006Ll05ZY003RL@00oPD00?D/0038^`0008P30013B@00
1b4000@L000[?@00NB80WK/00>i8003o0000je8008Zf0000M2X002Di00036`002B<004i>00b?003>
[000n2000?d;003LQ@00?:00001MAP0042/0008I000F;`0[Qal0hW800?h5003d;P00akl000252@00
?4H000HO00057@00=480080D0;_2003b=`00o`800>AY001RZ`0006Pk000H<@000QT000lZ001LAP0k
W`00g8@00?d:003g8`00c;8000>;0000ADX000LP00047000;cl007dJ0;;0003a>P00o`800>EX001S
Z`0006Lk000G<0000QT0014[001OA015XP00gg`00?h7003e:`00akh000252P00>TD00P001Ah0FP00
>dH008H70<Rk003f:@00o@P00=f0000mX00005a7000?:@000QT001/c001/=@1g/@00jET00?l0003]
BP00T;P0001c:`008SL000<J000<9P00EdX0;9X00=V<003m3000mb800<^d0000R@4003m700067`00
1Ah003Y500261`39^@00mRH00?d:003KR000<9`0001GBP0032H000<J000R>000M2T0V;X00>i4003o
0@00iV<006B/0000ISd001D^00026@005Bh006Hm06B/003VH`00o`000>i6002D^@0007<[000Q=`00
0QX000dW001JB00mX000gWd00?h6003d<@00_/<0001n6000;Ch000<K00098`00DTd08IH00=NB003l
3P00mb800<Zg0000QPL003Q400057@001b0004U<00n@003BX@00naD00?TJ003?ZP0018/00011B080
00HO07<0045800F;003?Z@00nAT00?XE003AX`002hh00015BP001Ql000DN000nA`01RP00cZ`00?TJ
003k5@00dZ8000^>0000ADX000HO00057P00?dP018/00<nY003j6000nQL00=2W0005S00004180005
7P001Ql004I:00j?003CX000na<00?PM003</P0008L6000g@`0011d000PQ001@CP0OUP00f9000?d;
003f:@00aL80001o5P00;3d000<K000;9@00F4X0>Il00=mk003n1000lCX00::l0000M2T001lf0002
6@0042X0069105nZ003WH000o`000>YC001c/00006Lk000D;@000QT001/c001`<02B^000kd400?l2
003QM@00@:40001IB@002bD000<K000]?P00P1<0b;d00?LS003l4000dih000b?0000@TT000DN0006
8000C4d06i@00=RA003m2P00mBd00;[20000NR0002@i00026P003bT0065205jZ003WGP00o`000>UI
001V[00006=000098P008cP007TR0;S1003e;@00o@/00=NC000GT`0004Q<008000HO05P004Y=01ZD
003HS`00o@T00?@`002__`0007HV000O=P000QT001</001W>`1h/@00k4d00?l1003SK`00@j80001H
B@002R@000@L000d@P00Q`D0cj/00?XE003h7P00bKX000204`00:Sd000<J000>:000Gd@0GZX00>QL
003o0000if4005JX0000GDH000`W00036`00;cl008@<0<ba003j6000nA`00<Zg0000PA8002/m0003
6P003RP0065206B/003YE`00o`000>AY0019Y00005U9000:900011`003M400::003BXP00o0l00?HX
002l``0007PS000P=P000QT001@^001[=`2<]`00l3l00?h5003KQP008IH0001;C@001Ql000LP001@
CP0/VP00gW`00?l2003^B000N[80001V?@004B/0008J000W>`00OaD0b[P00P3i6`006039^00007lE
000W>`000QX0014[001W?020/`00kd@00?l4003LP`008YL0001;C@001Al000LQ001BC@0fWP00hG<0
0?l1003ZD`00IJ`0001OA0003BL000<K000d@P[ooooo0Ol00001ooooo`007_ooool00ol0003ooooo
ooooo`07ooooo`0^001`<0008cP000<K00078@00@DP008@;0;o3003a>`00o`000>YE002@^00007PT
000]?P0011d000DO000e@P00OQT0Y[d00>i8003o0000kDT00:>m0000OAX003=200057P001Ad00310
001j7`2J^P00k4h00?l0003_A000Zkh0001n5`00=T<000DO00047@00;cl007XP09Zj003/C@00o`00
0>i6002W_@0007dJ000c@@8000DN07d00391001l6`2V_@00kTH00?l0003/CP00UkT0001h8P00;3h0
00@M00067`00>dH008<>0;k3003a>@00o`400>QM001l/P00074_000S>0000a/000TS001;C@06S000
bk@00?HX003n1P00hGD005NX0000ISd001Pa00026@003RP005Q:02NI003FV000nQD00?/C003GU000
:iX0001IB@003RT0008I000G<000ISd0EjP00>5c003n1P00mB/00<Vi0000R@4004A:00078@0011`0
02Xm001h8`2J^P00kDX00?l0003[D000SKL0001d:@009SX000<K00088P00CDh02Xh00<j]003g8@00
o@/00=b3000nX00005i5000A:`000QT001D^02Z6803QM000oPD00?D]0037_P0008H7000mA`001Ql0
00DM000c@@00OaH0^<800?8h003o0P00iFL006F/0000J3X001Ta00026@003bT005]703RN003KQP00
o@/00?LR003=/0001H`00016B`001b4000@L000^?`00O1/0[kl00?4l003o0@00iFH006F/0000J3X0
01Pa00026@0042X005i504:R003NOP00oPL00?DZ0038_00008H8000kA@0200057P3?000jA@00Q@T0
b;d00?DZ003n2000gWl0042Q0000GDH000lY00026@006S8006/f07B`003XF`00o`000>e9002C^@00
07@Z000S>0000aX000/V001FB`0ZVP00fHh00?`=003h8@00c;8000290000@4P000HO00057P00>D@0
08D90<Vk003f9`00o@X00=^7000cW@0005Q9000<9P000aX0028g001d:P2E^@00kTH00?l0003WH@00
Ijd0001W?0005Rl0008I000D;P00ICh0HJ/00>IU003o0@00kd@009Rj0000M2X0024g00036P003BL0
05Y803ZO003NO`00oPL00?@_0031a00007lG000^?`0011`000TS001AC@0OUP00ei@00?`>003g8@00
bkD000271P00>DD000DM00068000Ad/03Hl00=:S003j5P00nQT00=2X0006S000049900067`001Ah0
03m800>;003>Z`00nAX00?/D003BX@003Hl00017B`001R0000DN000lAP00R@00cJh00?TK003k5000
dZ4000j?0000AT/000HP00057P00?TL00XX00<n[003i6@00nQH00=6V0007S@00045800057`001Ql0
04A:00^>003BX@00na@00?TL003</@0008L4000hA00011d000LQ001?CP0MU@00ei800?d<003f9`00
a/40001o5@00;Ch000<K000:9@00EdX0=ih00=im003n1000lST00:Fm0000MBP0020f00026P0042X0
065205fZ003VHP00o`000>]B001f/@0006Pj000E;P000QT001Xb001_<@2?^000kd<00?l2003QL`00
@Z80001JB0002bH000<K000/?@00P1@0akh00?LT003l3`00e9`000j?0000A4X000DN00068000Bdd0
69<00=NC003m2`00mB/00;g30000Nah002Di00036P003bT0061305bY003WH000o`000>UH001Y[@00
06@o000:8`008SL007PS0;G1003d;P00o@X00=RA000IU00004Y<008000HO078004U<01RC003HT@00
o@X00?@_002b`00007LU000P=P000QT0018/001V?01e/@00k4h00?l0003SK@00AZ<0001IB@002bD0
00<K000c@@00QPL0cZd00?XF003h7@00b[P000214P00:cd000<J000=9`00Gd@0FjT00>MN003o0000
iel005RX0000GTD000dW00036`00;Sh008<=0<bc003i6@00nA/00<^e0000PQ0002`m00036P003RP0
0613066[003YF@00o`000>EW001<Y@0005Y8000:9@0011`003I3002:003AY000o1000?HW0030``00
07TQ000Q=`000QT001@]001Z>029]P00l4000?h4003LQ0008iL0001=CP001Ql000HP001@CP0ZVP00
gWh00?l3003^AP00OK<0001W?0004B/0008J000V>P00OaL0bKX00?TL003i6P00b[H000205000:3/0
008J000A:`00IS`0OK<00>i6003o0`00gH4002BH0000C4d000HO00078000DTd0<id00>5e003o0@00
je4006N]0000H4<000dW00036`00<T4:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool0
1oooool0o`00L2l002@i00036`001b4003m700243@2l`P00l3d00?l0003[D`00TkP0001h8P00;Sl0
00@M00057P00=48007dJ0:>m003]B@00o`000>i7002V_@0007dI000e@P001Ah000@M000^?`00NB40
UkT00>a?003o0000kd<00:jo0000OaD003M300067`0011d002hn001i8@2G^@00k4l00?l0003_A000
Z[h0001n6000=48000DN00057@00<D0007`L0:>l003^B000o`000>a<002J^P0007TQ000]?P0011d0
00HO000jA@00PQ00^/800?4k003o0@00j5`007jc0000LBh002@i00036`00228004Y<00B;003:]P00
mBT00?h6003QL`00FJT0001W?0006C40008I000=:000EdX09IP00=FI003j5P00na800=NB000^V`00
05Y8000?:@000QT001L`001U?P1EY`00hGD00?h6003e:P00b[L0002:0000ADX000LQ00047000:C`0
07LT09Ni003]B`00o`000>a?002@^00007DX000W>P000a/000PR001;C@08S@00cJl00?LS003m2P00
gH40046Q0000Gd@0014[00026@005Bh0:HDP0>1f003n1P00mB`00<Rl0000Q`H003m700067`0011d0
0391001n5`2e`@00lCX00?l2003UIP00J:d0001Y>@006C80008I000?:@00FdP0=Yh00=^8003m3000
n2400<f^0007S00004Q;00078@0011`002dn001k7@2/_`00l3d00?l1003VI000J:d0001Y>P006C40
008I000@:P00GDH0@:400=eo003n2000mRT00<Vj0000QPH003a600067`001Ah003U400242`37_P00
mB/00?h7003NO@00@Z80001MA@0042X0008I000J<P00JcL0LJl00>QM003o0000kTL009Ji0000MBT0
02<h00036P002bD005E;02RI003HT000o0h00?PP003=/0000XX00012B@001Ql000DN000hA000Q0/0
b;`00?HX003m2@00g8D003FM0000FDT000dW00036P008CL007<[09:h003^B000o`000>MO001Z[@00
06Pk000F;`000QT001@]001T?`1NZP00iFH00?l1003_@P00V[X0001e:0008SP000<J000<9`00FDT0
>9h00=f1003n1`00m2h00<C40000OaD002lo000470002280051=01fE003FUP00o0l00?PP003</`00
08P4000kA@00:0001Ah000HP0016BP0;SP00dJD00?XG003j6000d:L000R=0000@dT000HO00057P00
?TL00HX00<j]003i6`00na@00=>P000?T00004Q<000780001Ah003]500280P3=/000nAd00?/C003C
W`0049000018B`001R0000DN000mAP00RP00cZ`00?TJ003j5@00dJ@000V=0000@dT200067`0i0013
B@09S@00dJ<00?/E003i6`00cJl000280P00>TD000DM00078@00CTh06Y@00=ND003l3@00mRH00<No
0000P1<002ho00036`002R@005I;03FM003NO`00oPD00?8g002X_P0007HW000Q=`000QX0010Z001Q
@P1JZ@00iV<00?l0003[D000NK80001Y>@005Bh0008I000I<P00KS80S;L00>i4003o0P00hW4004FR
0000FTP000`V00036`00:cd007lF0<K0003f9@00o0h00=FJ000@T00004E:008000HO04D004U<01JC
003GU@00o@`00?DZ0030``0007/M000V>P000aX000hX001OA01IZ@00iV800?l0003ZEP00Jjh0001T
?`002R<0024g001g9@2b`000m3000?d9003HS`006i@0001;C@001R0000HO0017B`0FTP00ei<00?d:
003d;P00]L40001h8`008CL0008I000B;000ISd0L[000>]@003o0000i6/004RT0000FTP000/U0003
6`00<T4008D80<f_003j5`00nA`00<Zf0000PQ0002`n00036`003BL005i505RX003WH000o`000>QN
001KZ@0005m4000=9`000a/002dn00223`3;]0000P3i6P00A`3;]00008<?000]?P000a/000dW001O
A01NZP00j5X00?l0003UI@00CZD0001KB0002bD000<L000e@P00R@40dJD00?/A003f9@00`l@0001j
80008SL0008I000C;@00JST0Q[D00>m2003o1000gH8002FH0000CTh000HO00068000Cdh0:9T00=f0
003o0`00kTD0082d0000J3/0018/00026P009CX007hH0<Rk003h7@00nQT00<^e0000PA8002Tl0003
6P0042X006Hm07Zb003^A`00o`<00=eo000WV00004i>00067`001b00055=036L003PM`00o`400>]@
001Z[P000652000=:0000a/0035000[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07
ooooo`3o001a;P009CT000<L00078000?TL008<>0;W2003`?`00o`000>]A002E^@0007TQ000_?`00
1Ad000DN000c@@00O1`0X;`00>e;003o0000kTH00:Vn0000OQL003I300067`0011d002dn001h8P2D
^@00je400?l0003_@@00/L0000205000>4@000HO00047@00;Ch007PS09Bi003[D000o`000>m3002]
_`0007lG000f@`001Ah000DM000`@000Nah0X;`00>e9003o0000kD/009fk0000NQl002lo00047@00
1Ql003U400214P2h`@00lC`00?l1003YFP00PK@0001b;00093T000<K00088P00B4`00XX00<Zg003e
:`00oPD00>9a001LZ@0006Pk000I<P000QT000dW001FB`0RU`00e9/00?XG003k4@00f900032L0000
FTP000lY00026@005Rl006@o05:W003PM`00oPL00?HX003:]P000XX00017B`00224000<L000X>`00
MRH0U;T00>a=003o0000k4d009>i0000MRH002Pk00036`00228004U<00J<003</@00mb@00?d9003M
P000@j80001OA0004R`0008I000D;P0WQ240h7P00?h6003e:P00bKX000271000@4P000HP00047@00
<D0007hI0;;0003a>`00o`400>IT001Z[P0006Xh000J<P000QT000hX001JB00dW@00fXX00?`=003h
8000cZd000V=0000BD`000PQ00047000;3d007/N0:Vn003`?`00o`400>IR001[[P0006Xi000I<P00
0QT000lY001LAP0mX000gH400?d9003f9`00bKT000271@00?TL000HO00057P00>4@008<=0<K0003e
;@00oPH00=mk0015XP0005i5000@:P000QT001Ta001Z>01^[`00ieh00?l0003^A@00VKX0001e9`00
93T000<J000;9@00E4`09YP00=RB003l3`00n1l00<f^0004R`0004=9000680001Ad003M300243037
_P00mBX00?d8003LP`00=ih0001IB0003BL0008J000P=P00LRd0SkL00>e9003o0000ieh006b^0000
J3X001L`00026@004bd006@o05bY003UJ000o`400>m1002M^`0007DW000S>0000aX000`V001HB@0e
W@00g8<00?h8003e;000aL<000205000<40000@L00088P00D4h06Y@00=JH003l4000n1l00<ba0000
R08003a6001S00057P001Ql004A:00V=003@YP00nQP00?XG003AY@002Xh00015BP001Ql000DN000m
AP00R@00cJl00?TL003k4`00dih0016A0000BT`000LP00057@00>TD008P30<ba003h7P00na800=BM
000BT@0004U<000780001Ah003]600290@3=[P00nA/00?/D003BXP002hh00014BP001Ql000DO0011
B@08S@00dJD00?XF003i6P00cZd000290000>dD000DM00078@00CDh069<00=JF003l3P00mbD00<Nm
0000PA8002lo00036`002R@005E;03:L003MP000oPD00?8f002[_P0007LU000R=`000QX000lY001P
@`1GZ000iFD00?l0003/CP00O;80001Z>0005Rl0008I000I<@00KC<0R[H00>i6003o0@00hVl004NS
0000FdL000`V00036`00:S`007hH0<K2003f9`00o0h00=FH000BT@0004I;008000HO08h004Q;01BB
003FUP00o0`00?HY0033a00007`K000W>`000aX000hX001OA01FZ000iV@00?l0003ZE000KZl0001U
?P002R<0020f001f9P2__`00lc400?d8003IS@007ID0001=CP001R0000HO0016B`0DTP00eYD00?d;
003e;000^<80001h8P008SL0008J000A:`00ICh0L:l00>]B003o0000i6X004^T0000FdP000/U0003
6`00<40008D:0<f`003j6000nA/00<^d0000P`h002dn00036`0032L005e505JX003WH@00o`000>QL
001NZP0005m4000=:0000aX002/m00214@3:]P00nA/00?XI003</P0008<=000^?`000a/000dW001O
A01LZ@00j5`00?l0003VH`00DJH0001KA`002bD000<K000d@P00R0<0d:L00?/B003g9000aL@0001j
7`008SP0008I000C;@00JCT0Pk@00>m3003o0`00gH0002RI0000Cdh000HP00067`00CTh09IP00=f2
003o0`00kd<008>d0000J3X0018/00026P009CT007dJ0<Rm003h7P00nQP00<bc0000PQ4002Xl0003
6P0042X006Dn07Na003]B@00o`800=in000YV@0004m>00067`001b00051=02nK003PN@00o`400>a>
001][P000691000>:0000a/003102_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo00d0078]000V>P0011`000LP000mAP00PQ00]/400?10003o0000je0009Rj0000NQl003100080
00DN0?l00391001k7@2M^`00k4`00?l0003^A000[;l0001o5P00=d<000HO00047@00;3h007PS096h
003[D`00o`000?10002d`@00084B000iA@001Ql000@M000/?@00Mb@0TKP00>]B003o0000kd400;30
0000OaD003M300067`0011d002lo001j7`2M^`00kD/00?l0003]B@00Wk`0001k7P00<40000@M0006
7`00=d@0080C0;G1003`?P00o`000>UH0024]@0007<[000U>P000a/000PR0017B`00RP00bKT00?D/
003n1@00hVl005nZ0000J3X001Xb00026P003BL005E;022F003DW@00nQP00?`@003ISP00<Y`0001K
A`0042X0008I000F;`00I3l0D:H00>1h003n1`00mRL00<^d0004R`0004Q<00088P000a/002Lk001f
9`2A^000k4h00?l0003]C000U[T0001g9@00:3`000<L00088P00B4`01H/00<bc003g9@00o@T00=in
0016X`000613000B;0000QT001@]02J48@3ON@00oPL00?DY0039^@0008P20011B0001b0000@M000`
@000OAX0[kl00?4m003o0@00iV8006f^0000JcL001/c00026@003RP005U9036L003JR`00o0d00?PO
003?Z`002hh0001;C@00228000@L000[?@00NR00Y[d00?10003o0@00if4006f^0000JSP001Xb0002
6@003bT005a703^O003LP`00o@T00?HV003:]`0008P3000oA`001Ql000DN000f@`00P`h0a/800?@^
003n1P00ggT004NS0000Gd@0014[00026@00634006Ti06b^003WH000o`000>m4002L^`0007HV000U
>P000a/000XT001DC00SU`00ei<00?`@003h7P00cZd000F<0000A4X000HP00047@00=D<008<>0<No
003e:`00oPP00=f1000jW`0005Y8000=:0000QX001lf001a;P2<]`00kD/00?l0003XG000Kjl0001Y
>@005c00008I000C;000Hd00FJT00>AZ003o0@00l3l00:2l0000MRH002@i00036P0032H005Q:03>M
003LQ@00o@P00?D[0036`P00084B000a@00011`000PR001?CP0HT`00eIT00?/A003h7P00cK000029
0000?DL000DN00067`00@dT01h`00=2X003j6@00nQH00=6S000<S`0004I;000680001Ah003]60028
0P3=/00005@0n1d00?/B003DW0004i40001;C@001b0000DM000iA000Q`D0c;<00?PO003k4@00e9/0
01BA0000Bdd000LP00057@00>TD008P20<f`003i7000na<00=:P000=S`0004I:00067`001Ah00418
00J<003@Y`00nQH00?TI003>Z`0008X0000lAP001Ah000LP001;C@0FTP00eYL00?`>003g9000b;`0
00224000<40000<L000:9000ED/0<9`00=f2003n1P00lc@00:fo0000Mb@002<h00026P003bT005m4
05FW003UI`00o`000>a=001n/`0006Xg000F;`000QT001Pa001]=027]@00kTP00?l1003SKP00BZ@0
001LA`0032L000<J000Y?000OAT0aL<00?HX003l3@00eYH001BB0000B4/200067`220016B`0BT@00
eIP00?`=003f9`00aL<0001m6P00:3/000<J000=:000GTD0E:L00>EU003o0000je<0076_0000ISd0
00XS000O=P00MBL0[;l00?<c003n2000fX`001nF0000CTh000LP00057P00A4X04Y400=JG003m3000
mB/00;_20000NB4002<h00026P004B/006@o06f^003ZD`00o`000>EX001=Y@0005]7000<9P000a/0
02lo0024303</P00nAT00?TJ003</`0008<=000_?`000a/000`V001MAP1CY`00iV<00?l0003XFP00
H:/0001P@`003RP000<J000[?@00PA80b[P00?TL003j6000cK0000242`00;cl000<K000<9`00GTD0
FJT00>QN003o0000iV8005>W0000G4H000/V00036`00<T4008L50<nY003k4`00mb<00<G20000Nad0
02<h00026P004R`006Pj086d003^A@00o`<00=io000ZVP00051>000680001Ql004e>02>G003LP`00
oP@00>m20025]@0006Ti000C;0000QX002@i001l6`37_`00n1l00?XG003</@00088?000[?@000aX0
00lY001T?`1e/000kDX00?l2003OO000:iX0001?CP8000HP00X0051>02bJ003ONP00o`800>a=001`
[`000691000>:0000a/002lo2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo
00d007</000W>`0011`000HP000kAP00PA40/l000>m1003o0000k4h009^j0000Nah00350008000DN
0?l00350001j7P2K^P00k4h00?l0003_@`00[kl000205000>4@000HO00047@00:cd007LU08ng003Z
E000o`000?0n002g`@00088A000kA@001Ql000@L000[?@00MbD0SkL00>YD003o0000l4000;;00000
P1@003Q400067`0011d002ho001i802J^P00k4`00?l0003^B000X[`0001k7@00<D0000DM00057P00
=T<007lE0;;0003`?`00o`000>UG0027]@0007@Z000V>P000a/000PQ0015BP00R@40bK/00?@]003n
1000hfh0066[0000JCT001/c00026P0032H005E;01jE003CW`00nAT00?`@003IS@00=9d0001LA`00
42X0008I000E;P00Hd00CJD00=mj003n2000mRH00<bc0006S00004Y<00088P000a/002Hj001e:02?
]`00je000?l0003]BP00VKX0001g9000:C`000@L00088@00Ad/00h/00<^d003f9P00oPP00=il0018
Y0000652000C;@000QT001<]02F38@3ON`00oPL00?HX003:]`0008T00013B@001b0000@L000^?`00
O1`0[;l00?0n003o0@00if40072_0000JcH001/c00026P003BP005U902nK003IS@00o0h00?PN003?
Z@0038l0001<C@00228000<L000Z?000NB40Y;d00>m2003o0000iel0072_0000JcL001Xb00026@00
3bT005]703VO003LQ@00o@X00?LU003;]@0008T10010B0001Ql000DM000e@`00PQ00aL<00?@_003n
1@00h7P004VT0000Gd@0014[00026@00630006Pj06V]003VHP00o`400>m2002O^`0007LU000V>P00
0a/000XT001CC00QU`00eYD00?`@003i7@00cj/000N=0000ATX000LP00047@00=480088?0<K1003e
;000oPL00=eo000lX00005]7000>:0000QX001he001a;`2:]P00k4`00?l0003XF`00L[00001Z>000
6340008I000B;000HT40EjP00>A[003o0P00l3h00:>l0000MbD002Di00036P002bH005M:036L003K
QP00o@T00?DZ0036`000088@000b@@0011`000PQ001>CP0FT`00e9/00?/B003i7@00cJh0006:0000
?TL000DN00067`00@TT01H`00<nZ003i6P00nQD00=:Q000>S`0004Q;000780001Ah003Y50028103<
/P0005@0n1l00?/A003DV`005I80001<C@001b4000@M000gA000QPL0bkD00?PP003l4000eIX001JB
0000C4d000LQ00057@00>D@008L40<ba003h7@00na800=>O000?T00004M;000680001Ah003m700B;
003@Z000nQL00?XH003?ZP000XX0000mA`001Ah000LP001:C00DTP00eIT00?`?003g8`00bKX00023
3`00<D0000@L00098`00E4`0;Y/00=b4003n1P00lc<00;300000N2<002<h00026P003RP005m405:W
003TJ000o`000>e;0021]00006/f000G<0000QT001L`001/=@24]@00kDT00?l1003SK000C:D0001L
AP003BL000<J000X>`00OA/0a<@00?HY003m3000eYD001JC0000BD`200067`2>0015BP0@T000eIX0
0?`>003f9P00aL80001n6@00:C`000<J000=9`00GDD0DJH00>EW003o0000je4007>`0000Ic`000/S
000N=@00MBP0ZKh00?<d003n1`00fXX0026G0000Cdh000LP00057P00@dT049000=FH003l3@00mBX0
0;k30000NQl002<h00026P0042X006A006^^003ZE@00o`000>EV001@YP0005a7000<9P000a/002ho
00233@3;]000nAX00?XI003</@0008@;000`@0000a/000`V001LA`1AYP00iVD00?l0003YF@00Hj/0
001Q@P003RP000<J000Z?000P1@0bKT00?PM003j5`00cJl000252P00<40000<K000<9P00GDH0EjP0
0>MO003o0000if0005JX0000GDH000`V00036`00<D4008H60<nZ003k5000mb800<K10000O1`002@i
00026P004R`006Lk07jc003^AP00o`<00=im000/VP00051>000780001Ql004]=026G003LQ@00oP@0
0?100028]P0006Xh000C;@000QT002<h001k7@36`000n2000?XF003=/00008<=000/?@000aX000lY
001S@01b/000k4`00?l2003ONP00;I/0001@CP001R0000HO001?CP0ZVP00gg`00?l2003]B`00L[00
001S@0003RT000<J000^?`[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`0i
001c:`00:3/000@L00068000>TD0084C0;30003_@`00o`000>a=002N^`0007/M000b@@001Ah000DM
000`@000NR00V;X00>a?003o0000kd400;700000P1<003U500067`0011`002/m001f9P2<]`00jUH0
0?l0003`?@00^L8000223`00?4H000HP00047000:S`007HW08bg003ZE@00o`000?0n002e`@00084B
000iA0001Ql000@M000]?P00NB80UkX00>a>003o0000kTH00:Fm0000O1/00391008000DN0<@003E3
001o5P2__`00kd400?l0003ZE@00RKH0001d:@009c/000<K00078@00A4X008P20<Rl003d;P00oP@0
0>=/001T[00006Xh000K<`000QX000`V001DC00LU@00dj000?TJ003l3`00fX/003NN0000G4H0010Z
00026@005Bh0069104^T003OO000o@P00?LU003</@001hd0001;C@00228000<K000V>P00M2T0S;L0
0>]A003o0000kDT009^k0000N2<002Xm000470001b4004E:006:003:]P00mRL00?h8003ON`00BZ@0
001Q@P004bd0008I000C;00TPR80gWd00?h8003f9`00bkH0002:0000A4X000LP00047000;Sh007/M
0:Zn003`?`00o`400>MO001b/00006`e000L=0000QX000dW001HB@0]V`00f8l00?`?003i7@00d:P0
00j?0000CTh000PR00036`00:C`007PR0:6l003_@`00o`000>QM001c/00006`f000K<`000QT000hX
001JB00gWP00fhH00?d;003g9000bk@000290000@DT000HP00047@00=480084A0<C4003d<@00oPD0
0>1f001<Y@000613000B:`000QT001L`001X>`1W[@00iV<00?l1003_@@00XK`0001h90009c/000<K
000:9000DTd07iH00=JG003k4@00nA`00<nY0009S@0004M;0007800011d003=200214@35`P00m2d0
0?h7003NOP00?Z00001KA`003RP0008J000N=@00L300QkD00>a>003o0000jET007B`0000JcL001Ta
00026@004R`0069205BW003SK@00o`800?4m002V_@0007PS000V>P000aX000/U001FB`0_V`00fhP0
0?d:003f:@00akh000223`00<d8000@M00078@00CDh059800=BM003k4`00nA`00<j/0002R`000418
0P001Ql0l@00@4P00h/00<n[003i6`00na@00=>P000@T00004U<000780001Ad003U400271@3;]000
n2000?`@003EV@005i<0001>CP001b4000@M000f@`00Q@T0b[H00?PQ003l3`00eIP001NC0000CTh0
00LQ00047@00>4@008L60<bc003h7P00na800=BM000AT00004Q<000680001Ah003i700::003?ZP00
nQP00?XG003@Z00018/0000oA`001Ah000HP0019C00BT@00e9/00?`@003g8@00bKT000233@00<T40
00@L00098`00Dd`0;9X00=b5003n1`00lc800;?00000NB4002@i00036P003RP005i5052V003TJP00
o`400>e:0023]00006`f000G<0000QT001L`001[=P22]000kDX00?l1003TJP00CZD0001MAP003BL0
00<J000W>`00O1`0`L@00?DZ003m2`00ei<001RC0000Bdd000HP00057P00@dT03Xl00=BK003l3`00
mbD00<K00000OQL002Xl00036P003BL005e604nV003TJ000o`000>]@001f/@0006Lk000;8`007SD0
07@Z0:Jm003b=@00oPL00=^8000SU`0004m>00078@001Ah0049900j?003EVP00o0d00?HX0031a000
07/N000T>@000QX0010Z001S@01X[@00jUH00?l0003VI@00DZL0001MAP0032H000<K000]?P00PPl0
bkD00?TK003j6000cK0000252P00<D0000<K000;9P00FdL0CZD00>EV003o0000jEL006F/0000HD80
00lY00036P00:C`007lE0<Rk003h7`00nQH00<j]0000QPP0035000036`0032H005a605BW003WH@00
o`000>MN001HZ00005e5000<9P000a/003100026203>[000naD00?PQ0037_`0007dJ000U>@000QX0
014[001W?01l/P00kTP00?l2003ON`00;Y/0001AC@001b0000HO001:C00OUP00fhL00?h5003`?`00
RkH0001Z=`0052d0008I000R>000Nah0a/800?LQ003j5@00cJh000243000;Ch000<J000?:@00Hd00
Kjl00>a=003o0@00h7T002nK0000DDd000LP00067`00CTh0:9T00=in003o0P00kDX007F`0000I3l0
00lY00036P00;Ch02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo03T007@Z
000Y?00011`000HO000iA000P1@0[[l00>m4003o0000kD/00:2l0000O1/003=100057P001Ad002lo
001i8@2E^@00je400?l0003`@000]<4000214P00>TD000HP00047000:S`007HW08Zf003YE`00o`00
0?4l002l`P0008<>000mAP001b0000@L000Y?000MBP0RKH00>YG003o0000l3d00;S10000PQ4003Y5
00067`0011d002`n001h8`2E^@00k4l00?l0003^A@00Z;h0001m6P00<d400P001Ah0o`00=48007hH
0:bo003_@P00o`000>YD002<]`0007DX000X>`0011`000LQ0013B@00Q`@0akh00?@`003o1000i6X0
06J/0000JSP001`c00026P0032H005A<01ZD003BXP00nA/00?`>003JR@00>Il0001MAP004B/0008I
000D;P00HT80BJ@00=im003m2@00mb@00<f_0009S@0004a=00098`000a/002Di001c:P29]P00je<0
0?l0003^A`00W[/0001i8@00:cd000@L00078@00A4X008T00<Zg003f:@00oPL00=mi001=Y@000691
000D;@000QT0018/02>18P3NOP00o@T00?HV003;]0000XX00015BP001b4000@L000]?P00Nah0Ykd0
0>m1003o0000j5d007F`0000KC@001dd00026P003BL005M:02^J003HT000o1000?TL003@YP004900
001?CP002B8000<K000X>`00N2<0W[/00>i4003o0000j5`007Fa0000K3D001`c00026P003RP005Y8
03BM003KR000o@/00?LS003</P000HX00013B@001R0000@M000c@@00P1<0`L@00?<b003n1000hG@0
04jU0000HD80018/00026@005c0006Ll06B/003UI@00o`400?10002T_@0007PR000X>`000a/000TT
001BC@0MU@00eIP00?/B003i6`00d:P000^>0000B4`000LQ00047@00<T40084B0<G4003d;`00oPH0
0=il0010X@0005a6000>:@000QX001dd001_<@25]@00k4l00?l0003YE`00Mk40001[=P006C80008I
000A:`00HD80DZL00>=_003o0P00lC/00:Rn0000N28002Hj00036`002bD005I;02fK003JR@00o@X0
0?HX0038_@0008<=000d@P0011d000LQ001<C@0CT@00dih00?/C003i6`00cj/000B;0000@DP000HO
00057P00?dL00XX00<j]003i6`00na<00=>N000BT@0004Y=0007800011d003Q400261`3;]@00n240
0?`?003FU`006I@0001?CP00224000@M000e@`00Q@X0b[P00?LR003l3`00eYH001VD0000Cdh000LQ
00047@00=d<008H70<^e003h7`00na400=BL000CT@0004Y<000780001Ah003a6002:003>[000nAT0
0?XF003@Y`001X`00010B0001Ah000HP0017B`0AT000e9`00?/A003h8000b[L000242`00^000<d40
00@L00098`00Dd`0:YX00=^7003n2000m3400;K10000NR0002Di00036P003RP005e604jU003SK000
o`400>e80026]@0006de000H<@000QT001H_001[=`1o/`00k4`00?l0003TJ@00DJH0001NA@003RP0
00<J000V>P00Nad0_/<00?D[003m2`00f98001ZD0000C4d000LP00057P00@TT03Hl00=BM003l3`00
mb@00<No0000OaH002Xm00036`0032L005a704fU003TJP00o`000>a>001h/@0006Pk000;8`007C@0
07<[0:Bm003b=P00oPH00=^7000UV000051>00078@001Ah0045800b?003DW000o0h00?HW0033a000
07/M000U>@000QX000lZ001R@@1V[000jEP00?l0003VH`00E:L0001MA@003BL000<K000/?P00PQ00
b[L00?TL003j5`00cJh000262000<T4000<K000;9@00FdP0C:D00>EX003o0000jUH006N]0000HT40
00lY00036P00:3/007lG0<Rl003h8000nQD00<j/0000QPH0039100036`002bH005a705:W003VHP00
o`000>QM001JZ@0005i5000<9`000a/002lo00252@3>[@00nQD00?PP0037_P0007dI000V>P000QX0
014[001V?@1i/P00kDT00?l2003ONP00<9`0001AC@001b4000DN0019C00MU@00fhP00?h5003`?@00
SKL0001[=`0052h0008I000Q=`00NQl0aL<00?LS003k5000cZd000252P00;Sh000<J000>:000HT40
KJh00>a?003o0@00h7L0036L0000DDd000LP00067`00CDh09YP00=eo003o0`00kDP007Na0000I3l0
00lY00036P00;3h:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0>@00MBT0
02Tl000470001Ql003Q4001o5P2[_P00kTH00?l0003]BP00Xk`0001m6P00=48000DN00047@00;Sl0
07PR09>h003[DP00o`000?0o002g`@00088@000kAP001R0000@L000Y?000MBP0QkD00>UI003o0@00
lCX00;o30000Q0`003i70007800011`002Pk001d:@27]@00jEP00?l0003a?000^/8000223`00>dH0
00HP00047000:cd007LT09:h003[D@00o`000>m4002Z_P0007hI000d@P0200057P3o000c@@00OAT0
Z[h00>m3003o0000je8008jg0000MRL002Tl000470001b40049900271P37_`00m3400?l3003TJ@00
J:d0001[=`007C@0008J000;9@00Dd`069<00=6S003i7000o0d00=^8000kW`0005i5000A:`000QT0
01@]001Q@P17X`00gWl00?d:003g8`00cJh000^>0000CTh000TS00036`0093T007</08Ne003ZE000
o`000>i6002P_00007XP000/?P0011`000LP0013B@00R@40bKT00?DZ003n1P00h7L004nV0000Hd00
01@^00026@004R`08X4R0=f0003m2@00mbD00<bc0004R`0004I;00078@0011`002`m001j7`2T_@00
kd800?l0003XG000Mk40001]<`007C@0008J000<9`00EdX0:IT00=NB003l4000nA/00=6U000BT@00
04m>00098`000a/002Lk001g9@2L^`00kTH00?l0003XFP00Mk40001]=00073@0008J000=:000FDT0
<Yd00=Z9003m3000mb800<ba0003R`0004A:0007800011d003910020502o``00lc<00?h4003QL`00
D:H0001Q@P004R`0008I000F;`00IS`0HZ/00>EV003o0@00l3h00:Nm0000NB4002Tl00036`002B<0
055=01bD003EVP00na<00?TJ003@YP003Hl0001:C0001b4000@L000a@000P1@0`l@00?@`003n1P00
gg/004:R0000GDH000lY00026@0073@006lb08:d003[D@00o`000>YF001i/P0006`f000J<P000QT0
014[001P@`1@YP00hW000?l3003a>P00Zkh0001i8@009c/000<K000:9@00ED/0:iX00=Z;003m2`00
mRH00<Rl0000Q0`003E300047@001b4004]=016@003CX000na@00?TJ003?Z@001X`00012B@001Ql0
00DN000nA`00RP00cJh00?TL003k4P00e9d001>A0000C4d000LQ00047@00=d<008D80<Zg003g8P00
o0l00=JF000KU00004m>00088P0011`003A200243039^@00mb<00?`>003FU@006i@0001?CP002240
00@M000f@`00Q@T0b[H00?PP003l4000eIX001BB0000Bdd000LP00057P00>dH008T00<j]003i6P00
nQD00=6U0007S@00045800057P001Ql004I;00n@003CWP00na400?PO003:]P0008D:002h000d@P00
11`000TR001BC@0XV@00fhT00?h8003d;`00^<80001j7`009SX000<J000=9`00GDH0C:D00>=]003o
0@00kTL008Rf0000KC@001Ta00026@005Rl006Xh07fc003/C@00o`000>EW001CY`0005i5000>:000
0aX002Dj001j7P2l`P00mB`00?d:003HT00079D0001=CP001b0000DN0011B00;SP00dih00?`@003g
8`00akh000205000:cd000<K000<9P00FdL0Bj@00>=/003o0000k4d007^b0000JCX000/T000L=000
Lb`0XK`00?8h003n1P00g8D002NI0000DDd000LQ00057P00?dP02Xh00=BM003l3`00mRH00<G40000
O1`002Hj00036P003bT0069206>/003YF@00o`000>IR001GZ00005i5000=9`000a/002`m00214P39
^000n1d00?XF003>[@0008H6000c@@000a/000/U001JB01:Y000i6T00?l0003ZE000JZd0001S@000
3bX000<J000W>`00OQP0akh00?PQ003k5000cjX000271@00<d4000<K000;9@00FdL0D:H00>IT003o
0000j5/005fZ0000Gd@000dW00036`00;cl008@;0<f_003j5P00n1l00<Rl0000OQP002Hj00026P00
4B/006Dn07Na003]B`00o`800>1h000bW000059=00078@001Ah004M;01^D003JRP00oPH00?4l002@
^00006`f000E;P000QT0024g001i8034a000mb@00?/C003?Z`0008D9000_?`000a/000hX001Q@P1[
[P00je000?l1003QM@00<id0001BC@001b4000HO001<C@0TV000gH400?l3003^A`00NK80001U?P00
42X000<J000[?@[ooooo0Ol00001ooooo`007_ooool3o`0000Oooooo03T007DX000Z?@0011`000HO
000g@`00OQL0Z;h00>i7003o0000kDT00:Fm0000OAT003E200057`0011d002dn001h8`2A^000jU@0
0?l0003`?@00^L8000223`00?DH000LP00047000:3/007@Y08Fe003YFP00o`400?4i0031a00008@;
000oA`001b0000@L000W>`00M2X0QKD00>UI003o0@00lC/00;g30000P`h003a60006800011`002Xm
001g9@2@^000je800?l0003_@P00[Kl0001n5`00=D800P001Ah0mP00<T4007dJ0:Nn003^A@00o`00
0>]A002A^00007HV000Z?00011`000LP0010B000QPL0a/000?<b003o0`00iFP006^^0000K3H001dd
00036P002bD0059=01NC003AY@00nAd00?`=003KQP00?J00001NA@004R`0008I000C;@00H4<0A:80
0=f0003m2P00mb800<j/000=S`0004m>00098`000a/002<h001b;@24]@00jUH00?l0003^A@00Xk`0
001j7`00;Ch000@L00078000@TT008P30<Vj003e:`00oPH00>1f001AYP0006=0000E;P000QT0014[
02208`3MP@00o@X00?LT003</@001H`00018B`00224000@L000[?@00NB40X[`00>m3003o0000j5/0
07Vb0000KS<001he00026P0032H005I;02NI003GT`00na400?TJ003AX`005940001@CP002B<000<K
000W>P00MRH0VKX00>i7003o0000jET007Zb0000KS<001dd00026P003BL005Q9032L003JR`00o0d0
0?PQ003=[`0018/00015BP001b0000@M000a@000OaH0_<<00?<d003o1000hW4005:W0000HT4001<]
00026@005Rl006Hm062[003UJ000o`800?0m002Y_P0007XP000Y?0000a/000TS001AC@0JU000e9/0
0?/C003j6@00dJD000j?0000Bdd000LQ00047000<40007lE0<33003d<@00oPD00=mi0015XP0005e5
000?:@000QT001`c001^<`20/`00je800?l0003ZE@00Nk80001]=@006S80008I000@:P00H4<0CZD0
0>9b003o0`00lST00:fo0000NR0002Pk00036`002R@005A<02VI003IS@00o@/00?HU0039^P0008@;
000f@`0011d000LP0019C00?T000dZ400?XE003j6@00d:P000N=0000@dT000HO00057P00?DH008T0
0<f`003h7@00na400=BK000ETP0004e>00078@0011d003I300252P3:^000mb<00?`>003GU0007ID0
001@CP00228000@L000c@P00P`d0bK/00?LT003l3@00ei<001fE0000D4h000PR00047000=D8008D:
0<Zg003g8@00o0l00=FH000FTP0004a=00078@001Ad003Y500280P3=[P00nA/00?/E003AY0002Hd0
0012B@8000HO0;l004E:00f?003CW`00na800?PN003;]00008D9000e@P0011`000PR001BC@0VV000
fXX00?d9003d;P00^l80001k7P009cX000<J000=9`00G4L0BZ@00>=_003o0@00kTH008^f0000KS<0
01Ta00026@005Bl006Ti07Zb003/C`00o`000>EV001EY`0005m4000>:0000aX002Di001j802i`P00
m2h00?d:003ISP007YD0001>CP001b0000DN0010B009S@00dj000?/A003g8P00b;`000204`00;3h0
00<K000<9P00FdP0B:@00>=]003o0@00kD/007fc0000JCT000`T000L<`00LRd0Wk/00?4i003n1@00
g8@002VI0000DDd000PQ00057@00?TL02Hd00=>O003l3`00mRD00<G20000OAX002Lj00036P003bT0
0652066[003XF`00o`000>MP001IZ@0005i4000=9`000aX002/m00204`39^P00n1h00?XE003?Z`00
08L5000c@P000a`000/U001IB018X`00i6/00?l0003[D`00K:h0001S@00042X0008J000V>P00OAT0
akl00?LR003k4`00cjT000280`00=48000<K000;9@00FdP0CZD00>EU003o0000jEX005nZ0000Gd@0
00dW00036`00;Sh008@<0<f`003j5`00n1h00<Rk0000OaH002Lk00026P0042X006Dn07B`003/C000
o`400>1g000dW@0005=<00078@001Ah004I;01ZD003JR`00oPH00?4k002B^00006`e000E;P000QT0
020f001i8P32a000mbD00?/B003?ZP0008H7000_?`000a/000dX001Q@P1X[@00je800?l1003QM000
=Ih0001BC@001b4000DO001;C@0RU`00gH800?l3003^A@00O;80001V?@0042X000<J000Z?@08oooo
o`?o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`00MRH002/m00047@001Ql003I3
001n602V_@00kDP00?l0003^A`00Z;h0001n6000=T<000HO00047@00;3h007LT08jg003ZE@00o`00
0?4l002l`P0008<=000nA`001b0000@L000W>`00M2X0P[@00>QK003o0@00lSP00<C40000Q@T00418
00078@000a`002Hj001c:`22]000j5/00?l1003a>@00_l<000243@00?DL000LP00047000:S`007HV
08jg003ZD`00o`000>m1002__`0007lF000f@`001Ah000DM000a@000O1/0YKd00>i6003o0000je00
09>h0000Mb@002Xm000470001b0003m800252036`P00lc<00?l3003UIP00KJh0001/=@007SD000<J
000;9@00DTd05I800=2V003h7P00o@`00=b5000oX@0005m4000B;0000QT001</001P@`12XP00gH80
0?d;003h8@00cj/000j?0000Cdh000TS00036`008cP0078]08:d003YE`00o`000>m3002U_@0007/N
000^?`0011`000LP0011B000Q`@0b;/00?D/003n1P00hGD005>W0000I3l001D_00026@004B/07glS
0=b3003m2P00mb<00<f`0007S00004U<00088@0011`002Xl001i8P2P_000kTD00?l0003YF@00O;80
001_<P007cD000<J000<9P00ET/09IP00=JE003k4P00nQT00=:R000ETP00051>00098`000a/002Hj
001f9`2G^@00kDP00?l0003YF000O;80001^<P007SD0008J000=9`00F4T0;i/00=V<003l3@00n200
0<f^0006S00004I;00078@0011`00310001o5`2j`P00lSD00?l3003RL000E:L0001S@0004bd0008I
000E;P00ICh0GZX00>AY003o0P00lC`00:^o0000NQl002Xl00036`002B<0051>01RC003DW@00na@0
0?XH003AX`004900001<C@00224000@L000_?`00OaH0_/<00?<b003n1@00h7P004NS0000GTD0010Z
00026@006c<006dd07jc003ZD`00o`000>YC001n/`0006dd000K<`000QT0010Z001OA01<Y@00hG<0
0?l3003b>000/<00001j7`00:C`000<K000:9000E4`09iT00=V>003m3000mb@00<Vi0000Q@T003M4
00057@001b0004Q<00f?003BX`00nQH00?XH003@Y`002Hd00014BP00<P001Ql000DN000lAP00R080
c;400?PN003k4@00eIX001NC0000CTh000LQ00047@00=D8008@;0<Vi003g9000o0d00=NC000NUP00
051=00088P0011`0039100233P38_000mbD00?`=003GTP007iH0001@CP00228000@L000d@P00Q0`0
bKT00?LR003l3`00eYL001RC0000CDh000LQ00047@00>DD008P30<f`003i7000na@00=:R000:SP00
04=90P001Ql0_`00A4X02hh00=:Q003k4`00n1d00<bc0000QPL003I3000470002280055=02BH003J
S000o@T00?D]002m``0007/M000W>`000aX000dW001KA`17X`00hW000?l2003^A000SKL0001_<P00
6S80008I000E;P00JCX0N;400>]@003o0000iVD005NX0000Gd@000lY00026P0093T007TQ0;O1003d
;`00o@T00=V=000PUP0004m>00078@001Ah003m700R=003BX@00na800?PQ0038^`00084B000]?P00
0a/000/V001JB016X`00hfh00?l1003]BP00Ok<0001Z>00032@001/c001a;P2L^`00lCX00?h5003M
PP00:iX0001BC@00228000DM000mA`07S@00dj000?`@003g9000a/40001m6@009c/000<J000>:@00
H4<0GjX00>QL003o0000iel005^Y0000Gd@000hX00036P00:S`0080D0<Rk003h7`00naD00<nZ0000
R0<003A2000470002R@005U904JS003SK000o`000>]A001^[`0006@o000@:P000QX002Dj001m6`36
`@00mb<00?/C003@Y`0008P2000e@P0011`000/U001JB01<Y@00iFL00?l0003YF@00HJ/0001P@`00
3BP000<K000]?P00P`h0c;800?XH003i7@00bKT0001o5@00:3/000<J000@:P00I3l0L[000>a=003o
0@00hGD003JN0000Dd`000PQ00057P00ADX069<00=V=003n1`00lCX009Fi0000KC@001H_00026@00
7cH007PS0;o3003f9P00na800=2X0000Q`H0031000036`003BL0061306J/003[D`00o`000>5b000g
WP0005=<00078@001Ah004U<026F003LQ000o`@00>m4001n/`0006Hl000@:P000aX002Xl00[ooooo
0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3j001g9@00;3d000@M00067`00=D80
07dI0:Bm003]B@00o`000>i6002Z_P0007lF000g@`001Ql000@M000[?@00MRH0S;L00>YF003o0000
lC/00;k30000Q0`003m70007800011`002Hj001c:`20]000j5d00?l1003b=`00aL@000262000@DP0
00LQ00036`009SX007</082d003XG000o`400?8h0032a00008@;000nA`001b0000@L000Y?000MBL0
RkH00>YE003o0000l4000;700000P1D003M300057P001Ad00310001k7@2S_000kTL00?l0003/CP00
UKT0001h8`00:cd000@L00068000?TL008D:0<G3003c=000o`800>IU001_[`0006dd000N=@000aX0
00XU001AC@0CT@00d:P00?PO003m3000g8<0046Q0000Gd@001</00026@004R`005m4042Q003LP`00
o@/00?PP003?ZP004900001@CP002R@000<K000R=`00LBh0P;@00>UH003o0000kd800:Rn0000O1d0
02lo00047@001R00041800271P38_@00mBd00?h5003QL`00EJL0001T?`005Rl0008I000@:`0OOb<0
g8@00?d;003g8P00cJh000R=0000BT`000PR00037000:C`007PS09fk003^AP00o`000>UH001n/`00
06la000O=P000aX000`V001EB`0TU`00eYH00?/C003j6000dZ0001NC0000DDd000TT00036`009CX0
07DX09Fi003]BP00o`000>YF001n/`0006la000N=@000QX000`W001GBP0]V`00fHh00?`>003h7`00
cZd000R=0000Ad/000LQ00047000;cl007hH0;S1003b=P00o`<00>=^001FZ00006=0000D;@000QT0
01D^001U?P1LZ@00i6/00?l2003a>`00[[l0001k7P00:cd000<K00098P00D4h05Y<00=>N003j5@00
nQL00=:R000AT@0004e>00088P0011`002lo001n602k`P00lc<00?h4003PMP00BJ@0001NA00042X0
008I000K<`00KCD0Nk800>YE003o0000je80082c0000KS<001`c00026@0042X005i404ZT003QM@00
o`@00?8f002b`00007/N000Z?0000a/000XT001CC00UV000f8l00?`=003g8`00b[L000262000>4@0
00DM00078000Ad/038h00=6T0080nQL003D0dJD000Z>0000ATX000HP00057P00>dD008P30<bb003h
7`00o1000=FH000IT`0004m>00088@0011`003A200243@38^`00mbD00?`=003HT@0089H0001AC@00
228000@L000a@@00PQ00akd00?HV003m3000f900026F0000DDd000PR00047000<d4008<=0<Vj003g
8`00o0h00=JF000JU00004i>00078@0011d003Q400271@3</@00nAd00?/C003BX@0038l00014BP02
00067`2o0013B@0:SP00dZ800?/D003i7@00c;4000271P00=d<000@M00088P00DDd08YL00=V=003m
2P00mB`00<330000O1/002Pk00036P0032L005]704JS003RL@00o`800>m3002?^00006la000J<P00
0QT001@^001X>P1f/@00je400?l0003VH`00FJT0001P@`003bT0008J000S>000NB80]L400?@`003m
2000fX`0026G0000D4h000LQ00057@00?TL01X`00=:S003k4P00n2000<Vi0000PQ0002ho00036`00
2bD005Y804BR003RL000o`400>e90022]00006Xg000<90006c<0074_09Zj003a>`00oPD00=f1000]
V`00059=00088P0011d003a600J<003BX@00na400?LS0036`00007hH000X>`000aX000hX001P@`1M
ZP00j5h00?l0003XG@00GJX0001P@`003RP000<J000Y?000OaH0b;`00?PP003k5000d:P000280P00
=D<000@L000:9000F4T0A:800>=]003o0000je00072_0000ICh0010[00026P009CT007`L0<K2003g
8`00na800=6V0000R@4003I3000470002RD005U804ZT003TJ000o`000>UG001S[0000613000>:000
0aX002`n00223`3;/`00nQT00?TL003:^000080D000Y?0000aX000lZ001T?`1`[`00k4l00?l1003Q
M000>9h0001DC000228000DN0014BP0FTP00fHh00?h7003b>000UkT0001^<`005Rl0008I000O=@00
Mb@0_L<00?HW003k4@00d:L000271@00<D0000<K000=9`00H4<0I:`00>YD003o0000hW4003VO0000
E4`000PQ00057P00B4`07iH00=b5003n1000kd<0082d0000Ic`0014[00026P00:C`02_ooool1o`00
007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0<L007LT000]?P0011d000DN000d@P00OA/0
X[`00>e;003o0000kTD00:bo0000OaD003Q400067`0011`002Xm001f9`2:]P00jEP00?l1003a>P00
`<<000242`00@4P000LQ000370009SX0078/07jc003WGP00o`400?8f0035`P0008H70012B@001b40
00<K000U>@00LRd0O[<00>QN003o0@00lSL00<C40000Q@X003m80007800011`002Pk001e:029]P00
jUH00?l0003`?`00]<0000205000=d@000HO00047@00<40007/N0:2l003]B000o`000>a=002H^P00
07PR000/?P0011`000HP000mA`00Q0/0a<@00?8e003o0P00iV<0076_0000KC<001lf00036P002R@0
055=01:A003?Z@00n2000?d;003MPP00@j80001P@`004bd0008I000B;000Gd@0?j400=b5003m3000
n1l00=2X000AT@00051>000:90000aX0024g001`;`1n/`00jEX00?l0003_@@00Z[h0001l6`00;cl0
00@M00068000?TL008H70<Nn003d;P00oPD00>9b001GZ00006Dn000F;`000QT0010Z01in8`3KQP00
o@/00?PQ003>[@002Xh0001;C@00228000<K000Y?000Mb@0VkX00>i7003o0000jUL0082c0000L300
020f00036P002bD005A<02:G003EV000na<00?XG003CW`006I<0001AC@002R@000<K000T>@00MBT0
T[P00>e;003o0000jUD0082d0000L30001le00026P0032H005M:02^J003HS`00o0h00?PN003>Z`00
2Hd00019C0001b4000@L000_?`00OAT0]L400?8h003o0`00hfd005RX0000I3l001@^00026@0052h0
06@o05VY003SK000o`800?4i002``00007`M000/?@000a`000PR001?CP0ETP00dil00080nQH00?l0
dZ4001>A0000CTh000PR00047000;Sl007dI0;W2003c=000oP@00>5e001:Y00005m4000@:P000QT0
01Xb001/=@1i/P00jUH00?l0003[D@00P[@0001^<P0073@0008I000?:@00GTD0B:<00>1f003n1000
lSD00;C10000O1`002Xm00036`002B@005=<02>G003HT@00o0d00?LR003:]P0008H6000iA@001Ah0
00HP0016B`0:SP00dJD00?XG003j5P00dJ@000b>0000Ad/000HP00057P00>TD008L50<^d003h8000
o0l00=JG000JU00004m>00088P0011`003=100233P38_000mRH00?d<003HT0008YL0001AC@002B<0
00@L000a@000PA40akh00?HW003m2`00f8l002:G0000DDd000PR00047000<T4008<>0<Rk003g9000
o0d00=ND000KU00004m>00078@0011d003M400271P3</`00n1h00?/B003CW`003Xl00015BP001Ql0
00DO0012B@08S@00dJ@00?/D003i7000cK0000271000>4@000@M00088@00D4h08IH00=V>003m2P00
mB/00<;40000OAX002Tl00036`0032H005Y804BR003QL`00o`800>m2002B^000070`000K<`000QT0
01@]001X>`1d/000je<00?l0003VHP00FjT0001Q@P003bT0008J000S>000N2<0//000?@a003n2000
fXX002>G0000D4h000LQ00057@00?DH01H`00=6T003k4`00n1l00<Zh0000PPl002lo00036`002bD0
05U904>R003RL@00o`400>i70024]@0006/g000<90006S80070_09Rj003a?000oP@00=io000_V`00
05=<00088P0011d003]600B;003BX`00na800?LR0037_P0007lG000Y?0000aX000hX001OA01KZ@00
iel00?l0003XG000GjX0001P@`003RP000<J000X>`00OaL0akh00?LQ003k4`00d:L000290@00=T<0
00@L000:9000F4X0@Z800>=_003o0@00k4l007>`0000ICh0014[00026P0093T007/M0<G3003g9000
na400=6T0000RP0003I3000470002R@005U904RS003TJP00o`000>YF001U[0000652000>:0000aX0
02/m0022403;]@00nAX00?TK003:]`00084C000Y?0000aX000lY001S@01^[`00je000?l1003QLP00
02X0>Yl0001DC000228000DN0013B@0ETP00f9000?h8003b=`00VKX0001^<P005c00008I000N=@00
MbD0^l800?HX003l4000dJD000280`00<T4000<K000=9`00Gd@0HZ/00>YE003o0000hW0003^O0000
E4`000PQ00057P00Ad/07ID00=^7003n1000kd8008>d0000J3/0014[00026P00:3/:ooooo`7o0000
0Oooool001kooooo00?o0000ooooooooool01oooool0o`00N2<002dn00047@001Ah003=2001l702O
_000k4`00?l0003_A000[[l000205000>D@000HO00047000:S`007DX08Rf003YF@00o`400?4i0033
a00008D90011B0001b4000<K000U>P00LRd0O;800>MO003o0P00lc@00<K10000Q`D004=900088@00
0a/002@i001a;P1l/P00iel00?l1003b=P00aL<000252@00@4P000LQ000470009c/007@Y08Ne003Y
E`00o`000?0m002f`@00084B000hA0001Ql000@M000_?`00NQl0W[/00>e9003o0000k4`009Zj0000
NB4002dn00047@001R0003a600243032a000lSH00?l2003VHP00Lk00001^<`0083H000<J000:9000
D4h049000<nZ003h8@00o@X00=f10015XP000613000C;@000QT0018[001NA@0mX000fhH00?`<003h
7P00d:L001>A0000DDd000XT00036P008CL0070`07bb003XF`00o`000?10002/_`0007dJ000`@000
11d000HO000nA`00Q@P0akl00?@_003n1000hW0005VY0000ISd001L`00026@0042X07GhS0=^7003m
3000n2000<j/000;SP0004a=00088P000a/002Pk001g9@2I^P00kDP00?l0003ZE@00P[@0001a;`00
83L000<J000;9@00E4`089H00=FI003k5000nQH00=>N000JU000059=000:90000a/002@i001d:P2@
^000k4`00?l0003ZE000P[@0001`<0007cH000<J000<9P00ET/0:IT00=R@003l3`00n1d00<nZ000:
SP0004Y<00088@0011`002ho001m6P2c`000lST00?l2003SK000FZT0001T?`005Bh0008I000D;@00
Hd00F:P00>=]003o0`00lSP00;;00000O1/002`n00047000228004m>01>A003BX@00nQL00?XF003C
W`005I80001?CP00228000@L000]?P00OAX0]l400?8e003o1000hG@004bU0000H4<0014[00026@00
6S8006`f07Na003YE`00o`000>]?0024]@0006la000M=0000QT000lY001MA@16X`00h7L00?h4003c
=000]l40001l6`00:cd000<K00098`00DTd08YL00=NB003l3P00mb800<^e0000Q`D003Y500057P00
1R0004E:00V=003@Y`00nQP00?XF003BXP003Hl00018B`00_@001b0000DM000iA000QPH0bkD00?PQ
003l3`00eYH001bE0000D4h000PR00047000<T40088?0<Nm003f9P00o@`00=V?000TU`00059=0009
8`0011`0031000214P36`000mRP00?d;003ISP0099L0001BC@002B<000@L000a@000PQ00b;d00?HU
003l3@00ei<001fE0000Cdh000PQ00047@00=T<008H70<^d003h7`00na800=>N000?T00004I;0006
7`001Ah0045800N<003AY@00nQD00?TK003=[`0008P3000iA00011d000PQ001@CP0OUP00f9000?d;
003e:P00a<@0001m6@00:S`000<K000<9P00FTP0@Z800>5d003o0P00kd4009Bi0000L2l001/c0002
6@0052d006Ll07:`003ZE000o`000>MQ001MZP000652000@:P000QX0028h001g902``000lc800?h8
003JR@009IP0001AC@00224000DM000lAP03R`00dJD00?/D003h7P00b[L000233P00;cl000<K000;
9@00F4T0@J400>5c003o0P00kTH008Je0000K3H000`T000J<P00L300U[T00?0n003o1000gWh0032L
0000Dd`000PR00047@00>TD00h/00=6T003k4P00mb400<Rm0000OaH002Xl00036P003BP005m405VY
003WH000o`000>QK001QZ`000652000>:@000aX002Pk001n6037_`00mb800?/B003AYP0008T0000g
A00011`000XT001GBP10X@00hW000?l1003/CP00MK00001V?@004B/0008J000S>000Nah0a<@00?HU
003l4000dJ<0006:0000=d@000@L000:9000F4T0AZ<00>A[003o0000jUD006N]0000HT8000hY0003
6P00:Sd0084A0<Zf00020?TJ000d0<^f0000PA8002Xm00036P003bT0069106b^003[D@00o`400>9a
000kW`0005E;00088P001Ad0049901>A003HT@00oPP00?8f002K^`0006lb000G<0000QT001he001f
9P2h`P00mRT00?`@003AY00008P2000c@@000a/000`W001OA01PZ`00jEL00?l0003SKP00?J00001E
B`00228000DN0016B`0LU@00fhP00?h5003_@@00QKD0001X>P004R/0008J000W>`[ooooo0Ol00001
ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o001h8P00;Sl000DM00057P00<T4007/M09fk
003/C@00o`000>m2002a`000080C000jA@001R0000@L000Y?000MBP0Q[D00>UJ003o0@00lSP00<C4
0000QPP0049900078@000a/002@i001a;P1j/P00if400?l2003c<`00a/0000271000A4X000PR0003
6`0093T0074^07Zb003WH000o`800?<e0035`P0008H70011B@001b4000<L000W>P00M2X0QKD00>UI
003o0000lC`00;S20000PA4003U500067`0011d002ho001j802L^`00kD/00?l0003]B`00W;/0001i
8000;Ch000@M00067`00>dH008<>0<33003b=`00o`400>MQ001e/@0006lb000P=P000aX000XT001@
CP0?T000cZ/00?LQ003m2P00gGl004JS0000HD8001@]00026@004B/005e503^O003KQ`00o0d00?PM
003AYP005980001AC@002R@000<J000P=P00Kc40N[800>QL003o0@00l3l00:jo0000OAT003500004
7@001Ql003e600252P36`000m3000?h4003RK`00FjT0001V?@005c00008I000?:P0LOB@0fhP00?`=
003h7`00cjX000f?0000CDh000PR00036`009c/007HV09Ni003]BP00o`000>YD0024]@00074^000Q
=`000aX000/U001CC00OUP00eIX00?/E003j5P00e9`001bE0000DTd000XT00036P008cP007<[08jg
003/C@00o`000>]C0025]@00074_000P=P000aX000`V001FB`0XV@00ei800?`@003i7000cjT000b>
0000Bdd000PQ00047000;Ch007`K0;70003a>P00o`800>A[001LZP0006Dn000E;P000QT001<]001S
@01FZ000hfl00?l3003b=`00]<40001m6P00;Ch000@L00088P00CTh04Y400=:R003j5`00nQD00=>N
000FTP0004m>00088P000a`002`n001l6`2e`@00lSH00?l3003QLP00CZD0001P@`004B/0008I000I
<P00JcL0MK400>UI003o0000k4h008Je0000Kc4001dd00026P003bT005e604BR003PN@00oPD00?<c
002i`P0007dJ000/?@000a/000TS001BC@0PUP00ei<00?`>003h8@00bk@000271000>dD000DN0006
7`00A4X01hd00=2X003i6@00nQD00=:Q000?T00004U<003c000780001Ad003Q400261`3:]P00mb80
0?`>003GU0007ID0001@CP00228000@L000a@@00PQ00akh00?HW003m2`00fHd002FH0000DTd000TS
00047000;cl0080C0<K1003f:@00o@X00=V<000UV000059=00098`0011`0031000214@37_P00mRH0
0?d<003HTP007YH0001@CP00228000@M000f@`00Q@T0bkD00?PO003k4@00e9d0016@0000B4/000HP
00057P00@4P01X`00=2V003j5P00nAX00<j^0000R08003Y500047@001b4004m>01fE003HT@00o@/0
0?HY0035``0007hH000Z?@000a/000/V001IB@10X@00hGD00?l3003`@000U[T0001a;`0073<0008I
000C;@00IS`0L:l00>YE003o0000iel005nZ0000HT40010Z00026P008CL007LU0:jo003c<`00oPL0
0=^8000VV000055=00088P0011d003]500::003@Y`00na@00?PM003:]P0008<=000`@0000a/000XU
001HB@0oX@00hG@00?l2003^A@00R;H0001/=@003BD001Tb001_<@2C^@00l3l00?l3003NO@00<Y`0
001DC0002B8000@M000iA@01RP00dJD00?/C003h8@00b;`000205000:Sd000<J000=9`00GTD0EjP0
0>IQ003o0000jEX006>[0000HD8000lY00036P009c/007dI0<K0003g8`00na800=6T0001RP0003Q4
000470002B<005M:03jP003RL@00o`400>a=001g/@0006Hm000B:`000QX002<h001j7`32a000mRH0
0?`@003BXP000h/0000hA00011`000XT001HBP14XP00hf`00?l0003ZE000JJd0001R@@003bT000<J
000Z?000PA<0b[L00?TK003i6@00bk@000224000:cd000<J000>:@00HT40JZd00>]B003o0000hW00
03fP0000ED/000PR00057@00@DP04Y400=NB003m2000lSD009fk0000Kc4001L`00026@007C@007HW
0;K1003e:@00o0l00=:S0000R@4003A200036`0032H005i505jZ003YF000o`000>=]000oX@0005E;
00088P001Ah004E:01ZD003JR@00oPD00?100027]@0006Tj000B;0000QX002Lj00[ooooo0Ol00001
ooooo`007_ooool00ol0003oooooooooo`07ooooo`2C001i8@00;cl000DM00057P00<T4007/N09^k
003/CP00o`000>m1002c`000084B000kA@001R0000@L000X>`00M2T0Q;@00>QK003o0@00lSL00<G3
0000QPL004=900088@000a/002@i001a;`1h/@00iV800?l2003c<P00akl000280`00ADX000PR0003
6`008cP0070_07Ra003WH@00o`800?<d0036`@0008H60012B@001b4000<K000V>P00Lb/0Pk@00>UJ
003o0@00lC/00;[20000PQ0003Y500067`0011d002dn001i8@2J^P00k4`00?l0003]BP00W[/0001j
7`00;Sl000@M00067`00>TD0088?0;k3003b>000o`400>MP001g/@0006la000Q=`000aX000XT001?
CP0=S`00cZd00?LR003m2@00gWh004RS0000HD8001@^00026@004B/005e603VO003KR@00o0h00?TL
003AY@005Y80001BC@002RD000<J000P=P00Kc80N;400>QM003o0@00l3h00;300000OQP003910005
7@001Ql003a600242`36`P00m3400?l4003SKP00GJX0001W?0006300008I000?:@0KOB@0fXX00?`=
003h7P00cjT000j?0000CTh000TS00036`009SX007HW09Fi003]B`00o`000>]C0026]@00078]000R
=`000aX000/U001CC00MU@00e9`00080nQD00?l0e9/001fE0000Dd`000XU00036P008cP007<[08bg
003/CP00o`000>]A0026]@00074^000Q=`000aX000/V001EB`0VV000ei<00?`@003i6`00d:L000f?
0000C4d000PR00047000;3h007`L0:no003a>`00o`800>AY001NZP0006Dm000E;`000QT001<]001R
@@1DY`00hW000?l3003b=P00]/40001m6@00;Sl000@L00088P00CDh049000=6S003j6000na@00=BM
000HT`00051>00098`000a/002`m001l702c`000lSL00?l3003RL@00D:H0001Q@P004B/0008I000I
<@00JSL0Lk000>UJ003o0000k4d008Rf0000L30001he00026P003RT005a604:R003ONP00oPD00?<b
002k`P0007dI000]?P000a/000TS001AC@0OUP00eiD00?`?003h8000c;8000280`00?4H000DN0006
7`00@dT01X`00<nY003i6P00na@00=>P000@T00004Y<0007800011d003M400252@3:]`00mb<00?`>
003GT`007iH0001AC@00228000@L000a@000PA40a/000?HX003m2P00fH`002NH0000Dd`000TS0003
7000;Sl0080D0<G2003e:P00o@X00=Z;000WV@0005=<00098`0011`0031000214P37_`00mRL00?d<
003HT00089H0001@C@00228000@L000e@P00Q@X0b[H00?PP003l4000e9`001:A0000BD`000HP0005
7P00?dL018/00=2W003j5`00nAT00<j/0000R@0003Y500057@001b4004m>01bE003GTP00o@`00?HX
0035`P0007hG000[?@000a/000/U001IB@0nX000h7L00?l3003`?`00V;X0001a;P0073@0008I000C
;@00ISd0KZl00>YF003o0000ieh0066[0000HT40010Z00026P008CL007HV0:bo003c=000oPL00=^6
000XV@00055=00088P0011d003Y5006:003@Z000nQD00?TM003;]00008@<000a@0000a/000XT001G
BP0mX000hGD00?l2003_A000R[H0001]=@003BD001Ta001_<P2B^000l4000?l3003ON`00=9d0001D
C0002B<000@L000hA000RP00d:L00?/D003h8000b;/000204`00:cd000<K000=9`00GTD0EJL00>IS
003o0000jEP006F/0000HT4000lY00036P009SX005h007dJ0<K1003g9000na400=6S0002R`0003U4
000470002B<005I;03fP003QL`00o`400>e;001h/P0006Ll000B;0000QX0028h001j8030``00mRL0
0?`?003BX@0018/0000iA@0011`000TT001GBP12XP00hfd00?l0003[DP00Jjh0001S@@003bT000<J
000Y?000P1@0bKP00?TL003j6@00bk<000223`00;3d000<J000>:000HD80J:d00>YC003o0000hfl0
03nQ0000ET/000TS00047@00@4P049000=ND003m2@00lc@009nl0000L30001Pa00026@0073@007DX
0;C1003e:P00o0h00=:R0000R@0003E200036`0032H005i505bZ003YF@00o`000>=/0010X@0005I;
00088P001Ah004A:01VC003JRP00oPD00?0n0029]P0006Ti000B;0000QX002Hj2_ooool1o`00007o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0?l007TQ000`@0001Ah000DN000a@000NQl0VKX0
0>a?003o0000l4000;G10000PQ4003a60006800011`002Pk001d:P22]000j5`00?l1003b=P00aL80
00271P00A4X000PQ00036`008cP0070`07Ja003VH`00o`800?<b0037_P0008P20016B`00228000<K
000S>000L300M[400>IR003o0P00lc<00<K00000Q`D004=900078@000a/002Dj001c;021]000j5/0
0?l1003a>P00_<8000223`00>dD000HO00047@00;Ch007TR09Rj003/C@00o`000>e9002P_00007/N
000_?`0011d000HO000jA@00PQ00_<800?4i003o0@00iel007Vb0000L300024g00036`002B<004m>
00b?003>[P00mb<00?d9003NO@00BZ@0001R@@0052h0008I000A:`00G4H0>9h00=Z:003l3P00nA`0
0=6S000GT`00059=000;9@000aX001lf001^<P1f/@00iel00?l1003a?@00//00001n5`00<d4000DM
00067`00>dD008@<0<G3003c<P00o`<00>=]001OZP0006Lk000H<@000QT000lY01Yl903JR`00o0h0
0?PM003@Z0003i00001?CP002B<000<K000V>P00MBP0TkP00>e<003o0000je8008Rf0000LRd0028h
00036P002R@0059=01bE003DW@00nQH00?/D003EVP007iH0001CC0002bD000<J000R>000LR`0R[H0
0>]?003o0000je0008Rf0000LRd0024g00036P002bD005E;02FH003GU000na400?TK003@YP003i00
001=CP00228000@L000/?@00Nad0[Kl00?4l003o0P00i6P0062[0000ISd001H_00026@004b`00691
05:W003RL@00o`<00?8e002h`P0007hH000_?`0011`000PQ001<C@0?T000dJ@00?XI003k5000e9`0
01VD0000D4h000TS00036`00:cd007/M0;70003b>000o`<00>9`001BYP000652000B;0000QT001Pa
001Z>01a/000j5/00?l0003/C000R[H0001a;`007SD0008J000>:000G4L0@J400=mk003n1@00lc40
0;g30000OQP002dn000370002B<0055=01fE003FUP00o1000?PO003</@0008T1000mAP001Ah000HO
0012B@05S000cjX00?TJ003k5000dil001:A0000Bdd00?<000LQ00047@00=T<008D:0<Vi003g8`00
o0d00=NB000PUP00055=00098`0011`0031000214P36`@00mBT00?d:003JR`00:9T0001CC0002B<0
00<K000^?P00OaD0aL<00?D[003m2@00fXX002VI0000Dd`000TS00037000;cl0080C0<K0003f:000
o@/00=R?000QU`00055=00088P0011`003A200242`3:]`00n2400?`@003EVP004i40001:C0001b00
00DN000nA`03R`00cjT00?XG003j6@00cZ/000290000>dH000DM00078@00CTh06Y@00=NC003m3000
mRL00<K10000OaH002`m00036`002bD005Q903fP003PN000o`<00?0n002J^P00078]000M=0000QT0
018/001U?P1/[P00jEL00?l0003XG@00Hj/0001S@0004B/0008J000P=P00MRL0Z[h00?<e003n1P00
g8D002VI0000DTd000PR00047@00>DD008T00<nY003j5P00nA`00<^c0000Q0X00391000370002R@0
05M:03bP003PMP00o`800>m3002<]`0006dd000=9@00634006hc092h003_@@00o`<00=mj000eW@00
05E;00098`0011`003Q40029003@Z000na@00?PO0039^P00084B000/?@000a/000dW001MAP1DY`00
iV@00?l0003YE`00Ijd0001R@@003bX0008J000V>P00O1/0aL800?LT003l4@00dZ8000B;0000>TD0
00@L00098`00ET/0>il00>5d003o0@00kDX007Zb0000Ic/0018/00026@008SL007TQ0;k3003f:000
o0l00=>O0005S00003Y5000470002B<005M:046Q003SK`00o`000>]A001][P0006=0000?:@000aX0
02Pk00205@39^@00nAd00?XH003</P0008<>000/?P000aX000hX001Q@P1V[000jU@00?l0003SK@00
@J40001FB`002B<000@M000oA`0?T000eYD00?d9003c<`00XK`0001`;`006340008I000L=000MBT0
//000?D[003l3P00dZ40006:0000=D<000<K000<9P00GDH0FjT00>QJ003o0000i6/004:R0000ET/0
00PR00057@00@dT05i<00=Z<003n1P00l3d008^f0000JSP001</00026P009CX02_ooool1o`00007o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0?l007XP000`@0001Ah000DN000`@000NR00UkX0
0>]@003o0000l3l00;K10000PQ0003a60007800011`002Lk001c:`20/`00j5d00?l1003c=@00a/40
00271@00ADX000PR00036`008cP0070`07B`003VI000o`<00?@a0038_@0008T00017B`00228000<K
000R>000Kc40M;000>IS003o0P00lc800<No0000R0@004A:00088@000a/002Di001b;@1o/`00j5`0
0?l1003a>@00_/<000233P00?4H000HP00047000;3h007PS09Ji003/CP00o`000>i8002R_00007/M
000`@00011d000HO000iA000PA40^/800?4j003o0@00j5d007^b0000L300028g00036`002B<004i>
00^>003=[`00mb@00?d9003OO000BjD0001R@@005Bh0008I000@:P00G4H0=Yh00=Z;003l3`00nA/0
0=:R000IT`0005==000;9@000aX001he001^<`1d/000if000?l1003a?000]<40001o5P00<d8000DM
00067`00>TD008<=0<G4003c<`00o`<00>=/001PZ`0006Pk000H<@000QT000lY01Ul903IS000o0h0
0?TM003@Y`004I00001?CP002B<000<K000U>P00MBP0TKP00>a=003o0000je4008Zf0000Lb`002<h
00036P002R@0059=01ZD003CWP00nQL00?/D003EV@0089H0001DC0002bD000<J000Q=`00LRd0R;H0
0>]@003o0000k4l008Zf0000LR`0028g00036P002bD005A<02>G003FU@00na400?TJ003AY@004900
001>CP00228000<L000[?@00Nah0Zkh00?0m003o0@00iFL006:[0000IS`001H_00026@004R`00652
056V003RLP00o`@00?<d002j`P0007hG000_?`0011`000LQ001;C@0>S`00dJH00?TI003k4`00eI/0
01ZD0000DDd000TS00036`00:Sd007/N0:no003a>@00o`<00>=_001CY`000692000B;0000QT001Pa
001Y>@1`[`00j5`00?l0003]B`00S;L0001a;P007cD0008J000>:000FdL0?j400=il003n1P00m340
0;o30000OQL002ho000470002B80051=01bE003FU`00o1000?PN003=/00008T0000nA`001Ah000HO
0011B004R`00cZ`00?TK003k4`00dih001>A0000C4d003L000LQ00047@00=T<008@;0<Vj003g9000
o0d00=RA000RU`00059=00098`0011`002lo00205036`P00mBX00?d:003JRP00:YX0001DC0002R@0
00<K000]?P00OaH0aL@00?D/003m2@00fXT002ZJ0000E4`000TS00036`00;Sl0080D0<K1003f:@00
o@/00=V>000SU`00055=00088P0011`003=100243039^000mb800?`?003EV@005I80001;C@001b00
00DN000mAP02RP00cjX00080nQP00;X0cjX0006:0000?4H000DN00078000CDh06I@00=NE003l3@00
mRL00<K00000OaD002`n00036`002bD005Q:03^O003ON@00o`<00?0m002L^`00078/000M=0000QT0
018/001U?P1Z[P00jEP00?l0003XG000I:`0001S@0004B/0008I000P=P00MBP0Z;h00?8f003n1P00
g8@002^J0000DTd000PR00047@00>4@008T10<nZ003j5P00nA/00<bb0000Q@T00391000470002R@0
05M:03ZO003PM`00o`800>m2002>]`0006hc000=9@00634006hc08jg003_@P00o`<00=mi000gWP00
05E;00098`0011`003M300290@3?Z@00nQD00?PN0039^000084A000/?P000a/000`W001MAP1BYP00
iFD00?l0003ZEP00J:d0001S@00042X0008J000U>P00O1`0aL<00?HU003l4000dZ4000F<0000>dD0
00@M00098`00ED/0>Il00>5e003o0@00kDT007bb0000J3/001</00026@008CL007TR0;c3003f:@00
o0h00=>N0006S00003]5000470002B<005I:03nQ003RL000o`400>]@001_[`0006A0000@:P000aX0
02Pk001o5P39^P00n1d00?XG003</@0008<=000]?P000a/000hX001P@`1T[000jUH00?l0003SK000
@Z80001GBP002B<000@M000nA`0=S`00eYH00?d:003c<P00Xkd0001a;P006C40008I000L<`00M2T0
/<000?D/003l3@00dil000:;0000=T<000<L000;9P00GDH0FJT00>QK003o0000i6X004BR0000ETX0
00TS00057@00@TT05Y800=V=003n1P00lC`008bg0000JSP001<]00026P009CT:ooooo`7o00000Ooo
ool001kooooo00?o0000ooooooooool01oooool0o`00NQl0035000057P001Ad00310001i802F^@00
je400?l0003`?P00^<8000233`00?DL000LP000470009cX007</07jc003WG`00o`800?<d0036`000
08P40015BP00228000<K000R>000Kc40Lk000>EU003o0`00m3000<Rl0000R@0004Q<00088P000a/0
028g001_<@1b/000iVD00?l3003c<@00akh000280`00ADX000PR00036`0093T0078]07jc003XG@00
o`400?8i0030``0008<=000mAP001R0000@L000[?@00N2<0UKT00>a?003o0000kTL00:>m0000O1d0
031000057@001Ql003Q400214P2h`P00lC/00?l1003XG000O;<0001a;`008SP000<K00098`00CTh0
2Xh00<f`003g9@00o@P00=mk001=Y@0006=0000E;P000QT0010Z001LA`0eW@00fH`00?`?003i6P00
dZ4001ZD0000Dd`000/U00036P007SD006dd07:`003WH@00o`400?4k002f`@0007lE000d@P001Ah0
00DO000iA@00P`h0a<@00?<d003o0`00i6/006:[0000J3X001Ta00026@003RT06G/T0=V=003l3`00
nA`00=2V000BT@00051>00098`000a/002Di001d:@2?^000k4h00?l0003[D000S;L0001c:`008cP0
00<K000:9000DTd06I@00=>O003j5`00na<00=FH000QU`0005A<000;9@000aX0024g001a;P27]@00
je800?l0003/CP00S;L0001c;0008SP000<J000;9@00E4`08YL00=JF003k4P00nAT00=6T000AT@00
04i>00088P000a/002Xm001j7`2Y_P00l3h00?l1003UIP00Hj`0001W?0005Rl0008I000B;000HD80
CjH00>5c003n1000lc@00;c30000OaH00310000470001b4004Y<00b?003@Y`00nAX00?/B003EV@00
79D0001AC@002B<000<K000Z?000NQl0[Kl00?4j003o0P00hfh005FW0000HT40018/00026@005c00
06Ti06j_003XG@00o`000>e:002>]`00074^000O=P000QX000hX001KA`0nX000gWd00?h6003d<000
`L@0001o5P00;cl000@L00088P00D4h06i@00=FH003k4@00n1h00<f_0000RP0003m700057P001Ql0
041800:;003>[@00nA`00?/B003DW@005980001=CP00l`001b4000@M000e@P00Q0`0b;/00?LU003m
3000f90002>G0000DTd000TS00047000;cl0080E0<G3003e:`00o@T00=Z9000[VP0005A<000:9000
0a/002`n001n5`33a000mB`00?d9003KR000:iX0001DC0002R@000<K000^?P00OaD0aL800?DY003m
2P00fHd002BH0000DTd000TR00047000<T4008<=0<Vi003g8`00o0l00=FH000FTP0004]=00078000
1Ah003a6006:003?Z`00nQP00?XG003?Z@000XX0000mAP001Ah000LP001<C@0HT`00eYH00?`=003f
9P00akl000205000;Ch000<K000;9@00EdX0>Yl00=mj003o1000lC`009fk0000Lb/001he00026@00
4R`006@o06V]003YF@00o`000>QK001V[00006@o000A:`000QT001lf001e:02V_@00lSL00?h6003L
P`00;9X0001CC000228000@L000hA000R080cZ/00?XG003i6`00c;4000252000<d4000@L000:9000
ET/0>Il00>1i003o0`00kd4008nh0000KS8000dU000G<000KC@0S;L00>m3003o0P00h7P003RN0000
ET/000TS00047000=T<008P20<nZ003j5@00n1h00<Zg0000PQ0002dn00036`0032H005a6052V003U
IP00o`000>YE001Z[@0006=0000@:P000QX002Di001k7@35a000mRH00?`?003CX0001X`0000kAP00
11d000TS001EB`0hWP00h7H00?l2003]B000O[<0001X>P004bd0008I000Q=`00N2<0^l800?DZ003l
3P00e9d000R=0000?4H000@M00098`00ET/0?Z000>9a003o0@00k4l0072_0000I3l0010Z00026P00
9c/007lG0<Rk003h7P00nQL00<f`0000Q0`002hn00036`003BP0061306>[003ZE`00o`000>A[0014
XP0005M:00098`0011d003e600b?003FU`00o@X00?<b002U_@00074^000I<@000QT001/c001d:P2^
_`00mBd00?`=003CWP000h/0000g@`0011`000/U001LAP1GZ000j5`00?l0003TJ000AJ<0001GBP00
2B<000@M0011B@0ETP00fHh00?h6003a?000S[L0001[=`004bd0008J000T>@0:ooooo`7o00000Ooo
ool001kooooo00?o0000ooooooooool01oooool0K`00Nah0039100057P001Ad002lo001i8@2D^@00
je800?l0003`?P00^/8000233P00?TL000LP000370009SX0078/07fc003WH000o`800?<c0037_`00
08P20016B`00228000<K000R=`00Kc80LJl00>EV003o0`00m2l00<Vk0001RP0004U<00098`000a/0
024g001^<P1a[`00iFH00?l3003d<000b;d000280P00AT/000PR00036`0093T0074^07bb003WGP00
o`400?8h0032a00008@<000mA`001R0000@L000[?@00Mb@0TkP00>]@003o0000kTH00:Fm0000O1`0
035000057@001Al003M400204`2g`@00lC`00?l1003XF`00O[<0001a;P008cP000<K00098`00CDh0
28d00<ba003f9@00oPP00=mj001>Y@0006=0000F;`000QT0010Z001KA`0cW@00fHd00?`@003i6P00
dj0001^D0000Dd`000/U00036P007SD006dd076_003VHP00o`400?4j002h`@00080D000e@P020005
7P3o000hA000PPl0`/@00?<d003o0`00i6T006B/0000JCX001Tb00026@003RP067/U0=V>003l3`00
nA/00=6U000CT@00051>00098`000a/002@i001d:P2>]`00k4l00?l0003/C`00SKL0001d:P0093T0
00<K000:9000DDd069<00=>P003j6000na<00=JG000SU`0005E;000;9@000aX0020g001a;P25]@00
je800?l0003/C@00S[L0001c:`008cP000<J000;9@00E4`089H00=JH003k4`00nQT00=6S000BT@00
04m>00088P000a/002Xl001j802W_P00l3l00?l1003UI@00IJ`0001W>`005c00008I000B;000HD<0
CJD00>5d003n1000lc<00;k30000OaD00350000470001b4004U<00^>003@Z000nA/00?/B003EV000
7ID0001BC@002B<000<K000Y?000NR00Zkh00?4k003o0P00hfd005JX0000HT4001</00026@005c00
06Tj06b^003WGP00o`000>e9002?^000078]000P=P000QX000dX001JB00lX000gWh00?h6003d;`00
`/@0001o5@00;cl000@L00088P00D4h06I@00=FI003k4@00n1d00<f^0001RP0003m800067`001Al0
03m8006:003>[P00nA`00?/B003DW0005Y80001>CP001b4000@M000d@P00P`d0b;`00?HV003m3000
fHl002BH0000DTd000TS00037000;Sl007lE0<G4003e;000o@T00=^8000/VP0005E;000:90000a/0
02`m001n6031a000m2d00?d8003KQ`00;I/0001EC0002R@000<K000]?P00OaH0aL<00?DZ003m2P00
fH`002JH0000DTd000TS00047000<T4008<>0<Vj003g8`00o0h00=JG000GT`0004a=000780001Ad0
03]60029003>[000nAT00?XG003@Z0000h/0000nA`001Ah000LP001;C@0GT`00eYL00?`>003g9@00
akh000204`00;Sh000<K000:9@00EdX0>9h00=mk003n1000lC/009nl0000Lb/001he00026@004R/0
06@o06N]003XFP00o`000>UJ001X[@0006@o000A:`000QT001le001d:@2T_@00lSL00?h5003MPP00
;Y/0001CC0002B<000@L000g@`00R0<0cZ`00?XH003i6P00cK0000261`00=48000@L00099000ET/0
=ih000220=mj003o0`00l400096h0000Kc8000hU000G<000KCD0R[H00>m4003o0P00h7L003ZO0000
ET/000TT00047000=D<008P30<n[003j5P00nAd00<Zf0000PPl002hn00036`0032H005a704nV003U
I`00o`000>YD001/[P0006@o000@:P000QX002@i001k7P33a000mRL00?`?003CW`001hd0000lAP00
11d000PR001DC00gWP00h7L00?l2003^A`00P;<0001Y>P004bd0008I000P=P00N2<0^L800?DZ003l
3@00e9`000V=0000?4H000@M00098`00ET/0?:000>9b003o0@00k4h007:`0000I3l0010Z00026P00
9cX007hH0<Rl003h7`00nQH00<f_0000Q0/002ho00036`003BL00613066[003YF000o`000>AZ0015
X`0005Q:00098`0011d003a600^>003EV000o@/00?@a002W_@00078]000J<P000QT001/c001c:`2]
_`00m2h00?`<003DW@001H/0000hA00011`000/U001LA`1FZ000j5d00?l0003UI`00Aj<0001GBP00
2B<000@M0011B00CT@00f8l00?h7003a>`00T;P0001[=`0052d0008I000T>@[ooooo0Ol00001oooo
o`007_ooool00ol0003oooooooooo`07ooooo`1_001k7@00<T4000DN00057@00;Sl007PR09:h003Z
D`00o`000?0m002l`P0008<=000oA`001b4000<L000U>P00LRd0Nk800>MQ003o0P00lc800<Nn0000
R@4004M;00088P000a/0024g001^<P1_[`00iFL00?l3003d;P00bKX000::0000BT`000TS00036`00
8CL006hc06n_003UI`00o`<00?@`0038_00008T00017B`00228000<K000S>000LBl0N[800>MO003o
0@00lSL00<?40000Q0/003i70007800011`002Xl001g9@2A^000je400?l0003^A@00Ykd0001l6`00
<T4000DM00057P00=d<0080D0;G1003`?@00o`000>QJ0020/`00074^000S>0000a/000TS001<C@07
S@00c;800?HV003n2000h7T0052V0000I3l001H_00026@003bX005]703:L003ISP00o1000?TI003C
W`0079D0001DC0002bH0008J000M=000K3D0Kjl00>IS003o0@00lCT00;[20000P1<003E3008000DN
0?l003Q400224030``00lSD00?l2003TJ000IJ`0001Y>@006S80008I000>:00GNRD0f8l00?`@003i
6`00dJ@001BB0000D4d000XT00036`0093T007<[08bg003[D000o`000>a>002?]`0007@Z000T>@00
0a/000XT001AC@0GT`00dZ400?XH003k4P00eYH002BH0000ED/000/V00036P0083H0070_08>d003Z
D`00o`000>a<002?^00007@Z000S>0000aX000XU001CC00OUP00eIT00?/C003j6000dZ8001BA0000
Cdh000TS00036`00:C`007TQ0:Jm003`?`00o`400>IT001V[00006Pk000G<0000QT0014[001P@`1<
Y@00hGD00?h5003c<P00`<<000205@00<D0000@M00078@00B4`02Xh00<nY003i6`00na400=JG000N
U@00059=000990000a/002Tl001i8@2Y_P00lC`00?l2003SK000F:P0001S@0004bd0008I000G<000
J3X0Jjh00>MO003o0000kDP0096h0000LR`0020f00026P003BL005Y803^O003MO`00oPL00?@^0034
a000080D000`@00011`000PR001?CP0HT`00eIX00?/B003i7000cZd000:;0000@4P000HO00057P00
?dL008X00<f_003h7@00na400=FJ000GT`0004i>00088@0011`003=200233P38_@00mRH00?d;003I
SP009YP0001CC0002B<000<K000]?P00OaH0a<@00?D/003m2000fhL002jK0000ED/000XT00036`00
:cd007dI0<33003d;P00oPP00=^6000^V`0005E;000:90000a/002`n001n5`35a000mB/00?d:003J
R`009iT0001CC@002B<000@L000a@000PPl0b;/00?LT003l3P00eYH001RC0000CDh000LQ00057@00
>dD008T10<j]003i6P00nQH00=2W0004R`0003i700057P001b0004Y=01FB003EV000o0h00?LT0037
_@00084B000^?`000a/000XT001GBP0gWP00gW`00?h4003a>P00XK`0001d:P007cD0008I000A:`00
I3l0IJ`00>QK003o0000jET006V]0000I3h0018/00026@007SD007@Z0:>l003b>000oPD00=f1000_
V`0005A<00098`0011`003I30027103>[@00nQP00?TI003=[`0008H6000e@P0011`000TS001EB`0f
WP000880gg/00?l3003`?`00TkP0001_<@003RH001L`001/=@29]P00kT@00?l2003PMP00>il0001G
BP002R@000@L000e@P00Q`@0cZ`00?XG003i7000bkD000233P00;Sl000<K000<9P00FdL0CJD00>EX
003o0000jU<006f^0000I3l0014[00026P0093T007XO0<74003f:000o0h00=>N0008S@0003e60004
7@00228005A<03FM003PN000o`800>i60021]00006Ti000D;@000QT0020f001g902g`@00mB/00?`=
003DV`002Xh0000mAP0011d000TS001EB`0kW`00hG<00?l1003/C@00Lk00001U?P0042X0008J000V
>P00OQT0akd00?PO003j5P00cJh000252P00;cl000<K000=9`00Gd@0H:/00>UI003o0000i6T004NS
0000F4T000TT00047000?4H02Xh00=FI003m2`00m3000:Rn0000LR`001Xb00026@006S8007</0:^n
003d;P00o@`00=BL0006S00003Q4000470002bD005]705BW003WGP00o`000>EV0018X`0005Q:0009
8`0011d0041801:A003HT000oPL00?4j002A^00006/f000D;@000QT002<h2_ooool1o`00007ooooo
000Nooooo`03o`000?oooooooooo00Oooooo04@007`L000c@@001Ah000@M000^?`00N2<0TKP00>YD
003o0000lC`00;g30000Q0`003m800078@000a/002Di001a;P1i/P00iV400?l2003c<P00akd00029
0000B4/000PR00036`008CL006hc06j_003UJ000o`@00?@]0039^@000h/0001;C@002B<000<K000P
=P00KS<0KZl00>EX003o0`00m2l00<Rk0000R@0004Q;00088P000a/002<h001`;`1i/P00if000?l2
003b=P00aL@000252P00?dL000LP00047000:S`007HV092h003[DP00o`000>m4002X_P0007dJ000b
@@8000DN02T003I300205@2c`000l3h00?l0003YF@00PK@0001b;@0093T000<K00098P00Bdd01X`0
0<bc003f9`00oPL00>1h001AYP0006@o000F;`000QT000lY001JB00aW000f8l00?`A003j6000dih0
01jE0000E4`000`V00026P007C@006`f06j_003VI000o`800?8h002k`P00084B000f@`0200057P3f
000gA000PA40_l<00?8f003o0P00iFP006N]0000JCT001Xb00026@003RP05gXU0=R@003l4000nAX0
0=:S000FTP00055=000:90000a/002<h001c:`2:]P00je400?l0003/C@00T;P0001d:@009CT000<K
00098`00D4d05I800=:R003i6@00na800=JE000UV00005E;000<9P000aX0020f001`<022]000jU@0
0?l0003]C000TKP0001d:P0093T000<J000:9000Dd`07YD00=FJ003k5000nQP00=:Q000ETP00051>
00098`000a/002Tl001i8P2T_@00l4000?l1003VH`00J:d0001X>P006300008I000A:`00H4<0Bj@0
0>1f003n1@00lc400<740000P1@0039100047@001b4004M;00V=003?ZP00nA`00?/A003FUP007iH0
001BC@002R@000<K000X>`00NB40Z;h00?4m003o0P00i6/005VY0000Hd0001<]00026@005Rl006Pk
06V]003WH000o`000>i7002B^00007</000Q=`000QX000dW001JB00iW`00gH000?h7003d;@00aL@0
00205000<40000@L00088P00Cdh05i<00=BK003k4P00nA`00<j/0003R`00045800067`001Ah003i7
0029003=/000n1h00?/A003EVP0069<0001?CP00228000@L000c@@00PPl0akh00?HW003m2`00fHd0
02NI0000Dd`000TS00036`00;Ch007hG0<;4003e;@00oPP00=^6000_V`0005E;000:90000a/002/m
001m6P2n``00m2l00?h8003LQ@00;i/0001EB`002R@000<K000/?@00OQP0`l@00?D/003m2@00fXX0
02RI0000Dd`000TS00047000<D00088@0<Rl003g9@00o0d00=JE000JU00004i>00078@001Ad003Y5
00280P3>[P00nAX00?XF003@YP001H`0000oA`001Ah000HP0019C00DTP00eIT00?`?003g9000b;`0
00214@00;cl000<K000:9000ET/0=Yh00=im003n1000lCT00::l0000M2T001lf00026@004B/006=0
06B/003XG000o`000>UH001[[P0006Dn000B;0000QT001he001c:P2Q_000lCT00?h5003MP000<9`0
001DC0002B<000@L000f@`00Q`D0cJh00P3j6@00R@3=[P0008L5000e@P0011`000TS001EB`0eW@00
gg`00?l3003`?`00U;T0001_<@003RH001H_001/=P27]@00kTD00?l2003QM@00?:00001GBP002R@0
00@L000d@P00Q`D0cZd00?XG003i7000bkD000233@00;cl000<K000<9P00FdL0C:D00>AY003o0000
je8006n_0000ICh0014[00026P008cP007XO0<33003f:000o0h00=BM0009S@0003i700047@002280
05A<03BM003ON@00o`800>i60023]00006Ti000D;@000QT001lf001g9@2e`@00mB`00?`<003EVP00
2hh0000nA`0011d000PR001EB`0jW`00hG@00?l1003/C000MK40001U?P004B/0008J000V>P00OAT0
akh00?PP003j5@00cZd000252@00;cl000<K000=9`00Gd@0GZX00>UI003o0000i6P004RS0000F4T0
00XT00047000>dD02Hd00=FJ003m2`00m2l00:Zn0000Lb`001Xb00026@006S80078/0:Vn003d;`00
o@`00=BK0007S00003U4000470002bD005]705>W003WG`00o`000>EU0019Y00005Q900098`0011d0
03m7016@003HT@00oPL00?4i002C^00006`f000D;P000QT002<h00[ooooo0Ol00001ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`14001l7000=48000DN00047@00;Ch007PT08ng003ZE@00o`00
0?4k002o``0008@;0010B0001b4000<K000U>@00LBh0N;400>IR003o0P00m3400<Rl0000R@0004U<
00098`000a/0020f001]<`1][P00i6T00?l4003e;@00b[P000B;0000C4d000TS00036P0083H006dd
06b^003TJ000o`@00?@^0039^P000HX00018C000228000<K000R>000L300Mk400>MQ003o0P00lSD0
0<G30000Q@T004180007800011`002Tl001f9P2>]`00je<00?l0003_@`00Z[h0001m6@00<d420005
7P0Y000e@`00OaH0//000?0o003o0000jET008>d0000LR`002@i00036`00228004Y<00F<003;]000
mRL00?h7003PM`00DjL0001U?P005c00008I000?:@00FTP0<9`00=R@003k4@00nQP00=BM000OUP00
05E<000<9P000QX001`d001[=P1/[P00iVD00?l2003b=`00_L<000214P00=d<00P001Ah0o`00=d<0
084B0;g3003b=`00o`800>EW001X[@0006Xh000J<P000QX000dX01Ii9@3HT@00o1400?TJ003BXP00
5i<0001AC@002R@000<J000S>000Lb`0RKH00>]A003o0000k4`009:h0000MBP002Dj00036`002B<0
051>01BB003BX`00nAX00?/A003GU0009YP0001FB`0032H000<J000O=P00L300P;@00>YE003o0000
kD/009:h0000M2T002@i00036`002R@0059=01fE003EVP00na@00?XG003CX0005Y80001@CP002B<0
00<K000X>`00N280Xk`00>m1003o0@00iV8006V]0000JCX001Pa00026@004B/005m404VT003PM`00
oPD00?@`0033a000080C000c@@0011d000LP0017B`08S@00cj/00?TL003l4000eYD0022F0000Dd`0
00XT00036`009c/007TR0:Jm003`?@00o`800>AZ001KZ@0006@o000C;@000QT001H_001W>`1X[@00
if400?l0003^A`00U;T0001c:`008CL000<J000=9`00FDT0>9h00=f1003n1`00mBd00<G30000PA<0
035000047000228004i>01JB003DW000na<00?TK003>Z`0018/00012B@001Ql000DN000mAP00R@40
cK000?PN003l4@00eIT001VD0000Cdh000PR00047000<T40088@0<Nn003f:000o@/00=Z<000XV@00
05A<000:90000a/002`n001n6031a000m2h00?h8003LQ@00<9`0001FB`002RD000<K000Z?000O1/0
_<<00?@_003n1`00g8@0036L0000ET/000XT00036`00:cd007hH0<;4003e;000o@T00=Z9000YV@00
05=<00098`0011`0031000224@37_@00mRD00?`=003GU0006i@0001?CP001b4000@M000iA@00R080
cJl00?TK003j5@00dJD000J<0000@4P000DN00068000BD`04i400=FJ003l3`00mb<00<Rk0000PQ00
02lo00036`002R@005I;03BM003NOP00oPD00?8h002T_@0007DY000O=P000QT0014[001S@01SZ`00
j5d00?l0003YE`00K:h0001U?P004R`0008I000N=@00Lb/0X;`00?4j003n1000gWl003:L0000E4`0
00TS00047000=D8008L60<f_003i6@00nQP00<j]0000Q`@003I3000470002B<005E;03>M0000PP3N
O@00o`@00?0n002F^@00070`000>9P005Rl006/f08Je003^AP00o`800>5d000nX00005M:000:9000
11`003A200261P3>[P00nQP00?TK003;]00008@<000_?`000a/000/V001KB01;Y000i6X00?l0003[
D@00L:l0001U?P004B/0008J000S>000NR00_/<00?HY003l3P00e9`000Z>0000?TL000DM00088P00
Dd`0<id00=mj003o0P00kTD008Be0000JSP001@^00026@007cD007HV0;C1003e;@00o@`00=FI000<
S`0003i700047@00228005A<03RN003QM@00o`400>e<001f/@0006Hm000A:`000QX002Dj001m6P37
_`00n2400?/E003>[00008H8000`@0000a/000dW001NA@1MZP00j5X00?l0003UI`00BJ@0001IB@00
2R@000@L000jA@08S@00e9/00?d<003d;`00[;l0001c:`006c<0008I000J<P00LRd0Z;h00?@`003m
2`00eIX000R=0000>TD000@L000:9@00FdP0DJH00>MP003o0000iVD004^T0000F4T000TS00047@00
?TL049000=NB003n2000lSP009Fi0000K3D001@^00026@008SP:ooooo`7o00000Oooool001kooooo
00?o0000ooooooooool01oooool0A000O1/003A200057P0011d002dn001g902>]`00jUH00?l0003a
>P00`<@000252P00@DP000LQ00036`0093T0074_07Na003VH`00o`<00?@`0038^`0008X00019C000
2B<000<K000P=P00KC@0Jjh00>AZ003n1000mB`00<Zg0005S00004a=00098`000aX001lf001]=01[
[P00i6T00?l4003d;P00bKT0006:0000BD`000PR00036`008SP0070`07Ja003VHP00o`800?<e0035
`P0008H80010B0001b0000@L000Y?000MRL0SKL00>YC003o0000kd800:^o0000OQP003=20P001Ah0
:@00=D8007lF0;30003`?`00o`000>UH0024]@0007</000U>@000a/000PR0019C004R`00bkD00?HX
003n1`00h7H005BW0000ICh001L`00026@003bT005Y802jK003HT@00na400?XG003DW00089H0001E
B`0032H0008J000L=000JcL0Jjh00>EU003o0P00lSL00;k30000PA4003M4008000DN0?l003I30021
4P2l`P00lSP00?l2003UIP00JJd0001Z>0006c<0008J000=9`0FNBD0ei800?/A003i6@00dZ4001RC
0000DTd000XT00036P008SP0078]08Ne003[DP00o`000>e;002C^@0007DX000V>P000a/000TS001@
CP0CT@00dJ@00?TJ003k4@00ei<002NI0000ET/000`V00026P007cD006la07nc003ZEP00o`000>e:
002D^@0007DX000T>@000a/000XT001BC@0LU@00e9/00?/D003j5`00dil001NC0000D4h000TS0003
6`00:3/007PS0:6l003_@P00o`400>MQ001[[P0006Ti000H<@000QT0014[001OA018X`00h7P00?h5
003d<000a<@000214P00<d4000@M00078000AT/01h`00<j[003i7@00o1000=NE000RU`0005=<000:
90000a/002Lk001h8`2U_@00l3h00?l1003TJ@00G:T0001T?`0052d0008I000F;`00Ic`0Ijd00>IR
003o0000kTH009Fi0000M2X0024g00036P003BL005U903NN003MPP00oPP00?D/0035`P00084B000b
@@0011`000PQ001>CP0ETP00e9d00?/C003i6`00cjX000F<0000@TT000HO00057P00?4H008P20<ba
003h7`00o1000=FH000JU00004m>00088P0011`0039100224037_`00mRP00?d:003JR`00:IT0001D
C0002R@000<K000/?@00OQT0_l<00?@^003n1`00g8@0036L0000ET/000/U00036`00:S`007`L0;_2
003d<000oPL00=b3000bW00005I;000:9@000a/002/m001m6@30``00mBd00?d8003KR000:YX0001D
C0002B<000<L000_?`00PA80akh00?HV003l3@00ei<001bE0000Cdh000LQ00047@00>D@008P30<f`
003i6`00naD00=6T0007S@00045800057P001R0004Q;01:A003EVP00o0l00?LR0038^`00088@000`
@0000a/000XT001EB`0cW@00gWl00?h5003b>000YKd0001e:00083H0008J000@:`00HT40HJ/00>MN
003o0000jUH006f^0000ISd001</00026@007C@007</09jk003a>`00oP@00=in000cW@0005E;0009
8`0011`003A200261`3=/000nAX00?XH003>[00008P3000f@`0011`000TS001DC00bW0000880gWd0
0?h4003`?@00UkX0001`;`003RH001H_001[=`24]@00kTL00?l2003QL`00?j40001HBP002R@000@L
000c@@00QPL0cJl00?XH003i6`00c;<000243000<40000<K000;9@00FTP0BJ@00>A[003o0000je40
076`0000ICh0014[00026P008SP007TQ0;g3003e:P00o0d00=BK000;SP0003m700057@00228005=<
03:L003ON`00o`<00>m40026]@0006Xh000D;P000QT001he001f9P2b`000m2d00?d<003EV0003Hl0
000oA`001Ad000PR001DC00gWP00h7H00?l1003]B`00N;40001V?@004B/0008J000U>@00O1/0a/00
0?LQ003k5000cj/000261`00<D0000<K000<9`00GTD0G:T00>QK003o0000iFH004ZT0000FDT000XT
00047000>TD01h`00=BL003m3000m2h00:fo0000LbX001/c00026@006C80078]0:Jm003d<@00o@/0
0=FI0009S@0003Y5000470002R@005Y8052V003WH@00o`000>IT001<Y@0005U9000:900011d003i7
00n@003GT`00oPP00?8h002F^@0006dd000E;P000QT0028h2_ooool1o`00007ooooo000Nooooo`03
o`000?oooooooooo00Oooooo04@007dJ000e@P001Al000@M000/?P00MbD0S;L00>UG003o0000lCX0
0<;40000Q@T0045900078@000a/002@i001`;`1e/@00iV@00?l3003d<000b;/0006:0000BT`000TS
00036P0083H006dd06Z]003TJ`00oP@00?D[003:]P001X`0001=CP002B<000<J000O=P00K3D0JZd0
0>AZ003n1000mBd00<Vi0002R`0004Y<00098`000a/0028g001_<@1e/000iV800?l2003c=000a/80
00261`00@DP000LQ00047000:3/007DX08^g003ZE000o`000>m2002]_`0007hH000d@P8000DN02T0
03A2001n5`2__`00l4000?l0003YE`00QKD0001c:`009CT000<K00088P00BD`00h/00<^e003f:@00
oPH00>5e001EY`0006Dn000G<0000QT000lY001IB@0]V`00ei800?/B003j5`00e9/0026F0000ED/0
00`V00026P0073<006/g06Z]003UIP00o`800?8f0030``00088@000hA00200057P3o000e@`00P1<0
^/800?8h003o0P00iFD006^^0000JcL001/c00026P003BL05GTU0=NC003k4@00nQT00=:P000IT`00
059=000:90000aX0028h001b;@26]@00je<00?l0003]B`00UKT0001f9`009SX000<K00098`00Cdh0
4Y400=6U003i6`00o1000=NB000YV@0005I:000<9P000QX001he001_<@1n/`00jEL00?l0003]B@00
UKT0001e:0009CT000<K000:9000DTd06i@00=BL003j5@00nQH00=>N000HT`00055=00098`000a/0
02Lk001h902P_000kd<00?l0003WH000K:h0001Y>@006C40008I000@:P00Gd@0Aj<00=mi003n1P00
m2l00<G40000PA4003A200047@001b0004E:00J<003>[000n1d00?`@003GU0008iL0001CC0002R@0
00<K000W>P00N2<0Y;d00?0o003o0@00iFP005fZ0000I3l001@]00026@005Rl006Ll06F/003VHP00
o`000>i5002G^@0007@Z000R=`000aX000`W001IB@0fWP00g8<00?h8003e:`00a/4000214@00<T40
00@L00088@00CDh059800=>N003k5000nAX00<nZ0006S00004=900067`001Ah003a600280P3</P00
n1l00?`@003FU`006i@0001@CP00228000@L000a@000PA40a/000?HY003m2P00fXX002ZJ0000E4`0
00XT00036`00:cd007dI0;k3003d;`00oPL00=b3000bW@0005I:000;9@000a/002Tl001l702i`P00
m3400?h7003MPP00<id0001FBP002bD000<K000Z?@00OAX0_l<00?@^003m2000fhL002^J0000E4`0
00TS00037000;cl0084B0<No003f9P00o@`00=NB000MU@0004m>00078@0011d003Q40027103=/000
nA`00?/D003AX`0028d00011B0001Ah000HO0017B`0AT@00e9/00?`@003g8P00bKX000223`00<400
00<L000:9000ED/0<Y`00=f0003n1@00lSL00:Nm0000MBL0020f00026P0042X00691062[003WG`00
o`000>YE001_[`0006Hm000C;0000QT001dd001b;02M^`00lC/00?h4003NO@00=9d0001EB`002B<0
00@L000d@P00QPP0c;400?TJ003j5`00cZ`000280`00=d<000@L00098`00E4`0<I`000220=in003n
1000lC`009Vj0000LBl000lV000F;`00JcL0Pk@00>i8003o0@00hW80042Q0000F4T000XT00037000
<T4008H80<f`003j6@00nAX00<bb0000Q0/0031000036`002bD005Y804RT003TK000o`000>]@001c
/00006Hm000A:`000QX0028g001i8@2k`P00mBX00?`=003EVP0038l00010B0001Ad000PR001CC@0`
W000gg`00?l3003_@`00QkD0001[=`005Bh0008I000N=@00MRL0/L000?@^003m2`00eYL000j?0000
@4P000DM00088P00E4`0=Yh00>1f003o0P00kDX007Vb0000IS`0014[00026P0093T007`L0<K1003g
8P00na@00<nZ0000QPH0035000036`0032H005i505ZY003XG000o`000>EV001<Y@0005U8000:9000
11`003U400J<003DW@00o0d00?@]002^_`0007@Z000K<`000QT001Ta001a;P2U_@00lc400?d;003E
V@002Xh0000kA@0011`000XT001JB01?YP00iV800?l0003VH`00CJD0001IB@002R@000@L000mAP0>
S`00ei@00?d8003b=`00UkX0001]=0005Bh0008I000R=`[ooooo0Ol00001ooooo`007_ooool3o`00
00Oooooo04@007dI000e@`001Ql000@M000/?@00MbD0RkH00>UG003o0@00lCT00<?40000Q@P00499
00088@000a/002<h001`<01d/000iFD00?l3003d;`00bKX000::0000Bdd000TS00036P007cH006`e
06V]003TJ`00oP@00?D[003;]@001h`0001>CP002B@000<J000O=@00K3D0JJd00>A[003n1000mB`0
0<Zh0003R`0004Y=00098`000a/0024g001_<@1c/000iV<00?l2003c<`00a/4000261`00@DT000LQ
00047000:3/007DX08Zf003ZE@00o`000>m1002^_`0007hG000d@P8000DN02T003A2001n602^_`00
kd400?l0003ZEP00QkD0001c:`009CX000<K00088P00B4`00h/00<Zf003e:@00oPH00>5d001FZ000
06Hm000G<0000QT000hY001IB@0/VP00ei<00?/B003j5`00e9/002:G0000ET/000`W00026P006c<0
06Xh06V]003UI`00o`800?8e0031a000088?000hA00200057P3o000e@P00P1@0^L800?8i003o0P00
iV@006b^0000JcL001/c00026P003BL05GPU0=ND003k4P00nQP00=>O000JU000059=000:90000aX0
028g001a;P25]@00jU@00?l0003]BP00U[T0001f9P009SX000<K00098`00Cdh04I400=6U003i6`00
o1000=RA000ZV@0005M:000<9`000QX001he001_<P1l/`00jEP00?l0003]B000U[T0001e9`009CX0
00<K000:9000DDd06Y@00=BM003j5@00nQH00=>N000IT`00055=00098`000a/002Lk001g902N^`00
kd<00?l0003WH000KJh0001Z>0006C40008I000@:P00GTD0AZ<00=mj003n1P00m2l00<G30000PQ40
03A200047@001b0004A:00F<003>[@00n1h00?`?003GT`0099L0001DC0002R@000<K000V>P00Mb@0
X[`00?10003o0@00iFL005jZ0000ICh001@^00026@005Bl006Hm06B/003VH`00o`400>i4002H^P00
07@Y000R>0000aX000`V001HB@0eW@00g8@00?d8003e:`00a/4000224000<d4000@L00078@00CDh0
4i400=>O003k5000nAX00<nY0007S00004=900067`001Ah003]600280`3</`00n2000?`?003FUP00
79D0001@CP00228000@L000a@000PA80a/400?DZ003m2P00fXT002^J0000ED/000XT00036`00:cd0
07dJ0;g3003d<000oPL00=f2000cW@0005M:000;9@000a/002Tl001k7@2h`P00lc400?h6003MP@00
=9d0001GBP002bD000<K000Z?000OA/0_/<00?@^003n2000fhH002bJ0000E4`000XT00036`00;Sl0
080C0<K0003f9`00o@`00=RB000NU@0004m>00088@0011d003Q400271@3</@00nA`00?/D003BX`00
2Hd00012B@001Ah000HO0017B`0@T000e9`00?`@003g8@00bKT000233P00<D0000@L00099000ED/0
<I`00=f1003n1@00lSH00:Rn0000MRL0024g00026P0042X0069105nZ003WH000o`000>YE001`[`00
06Hl000C;@000QT001`d001b;@2K^`00lC`00?h4003NO000=Id0001EB`002B<000@L000c@P00Q@P0
c;800?TK003j5`00cj/000280P00=d@000@L00098`00E4`0<9`000220=io003n1000lC`009Zj0000
LBh000lV000E;`00JSP0P[@00>e8003o0@00hW40046Q0000F4T000XU00036`00<T4008D90<f`003i
6@00nAX00<ba0000Q@X0035000036`002bD005Y804NS003SK000o`000>a?001d/00006Hm000B;000
0QT0024g001h8P2j`P00mB/00?`=003EV@003Hl00010B0001Ad000PQ001BC@0_V`00gWd00?l3003_
@`00R;H0001[=`005Bh0008I000N=@00MBL0/<000?@^003m2`00eYL000n@0000@4P000DM00088P00
Dd`0=Id00>1g003o0P00kDT007Zb0000Ic`0018[00026P0093T007`L0<K1003g8P00na<00<nZ0000
Q`H0039100036`0032H005e505VY003XG@00o`000>EU001=Y@0005Y8000:900011`003U400F<003C
WP00o0d00?D]002``00007@Y000L<`000QT001Ta001a;P2T_@00lc800?d:003EV0002Xh0000kAP00
11`000XT001IB01>Y@00iV<00?l0003VHP00CZD0001IB0002R@000@L000mAP0=S`00ei@00?d9003b
=P00VKX0001]=0005Bl0008I000Q=`Sooooo0ol00001ooooo`007_ooool00ol0003oooooooooo`07
ooooo`14001n6@00=T<000HO00047@00:cd007HV08Zf003YF000o`400?8h0034a00008H80013B@00
224000<K000S>000L300Lk000>EV003o0`00m2h00<Vi0003R`0004]=00098`000aX001lf001/=@1X
[@00hf`00?h5003e:P00bkD000N=0000CTh000XT00036P007SD006`f06N]003SK000oP@00?D/003:
]`0018/0001;C@002B<000<K000Q=`00Kc80L[000>IT003o0P00lc<00<K00000Q`H0049900078@00
0a`002Lk001d:@29]P00jUH00?l0003`@000[kl0001o5P00=D8200057P3o000c@P00OQP0[;l00>m1
003o0000jUH008Rf0000M2X002Hj00036`00228004M;00::003:]`00mBX00?h6003QM000EjP0001V
?@006300008I000>:000FDT0:iX00=NC003k4`00nQH00=FJ000SU`0005I;000<9`000QX001/c001Z
>01W[@00iFP00?l2003c=@00`/@000233`00>D@000DO00057P00=480080E0;S1003a>@00o`400>IS
001][P0006/f000L<`000QX000dW01Ah9@3GU000na800?XH003CW`006i@0001BC@002RD000<J000Q
=`00LBh0Q;@00>YD003o0000kDT009Nj0000MRH002Lk00036`002B<004m>016@003@YP00nA`00?`@
003HT@00:iX0001GBP0032L0008J000N=@00KS80Nk800>UH003o0000kTP009Rj0000MRL002Hj0003
6`002R@0055=01VD003CWP00nQH00?XE003DW@006Y@0001AC@002B@000<K000W>P00MbD0WK/00>m4
003o0000iel006j_0000JSP001Ta00026@0042X005i504FR003ONP00oPH00?@^0035`P00088@000e
@P0011d000HP0014BP04R`00cZh00?PN003l3`00ei8002FH0000E4`000XT00036`009SX007LT0:6l
003`@000o`400>EW001PZ`0006Dn000D;P000QT001D^001V?@1S[000iV@00?l1003_A000VKX0001e
:@008cP000<J000<9P00F4T0=9d00=b4003m2@00mBX00<K00000PQ0003=100047@001b4004a=01:A
003CW`00na@00?TI003@Z00028d00014BP001Ql000DN000kA@00Q`@0bk@00?PP003l3`00eYD001fE
0000D4h000PR00047000<400084C0<K1003e:P00o@T00=^8000/VP0005E;000:90000a/002Xm001l
6`2k`P00m3000?h7003MP@00=9d0001GBP002bD000<K000X>`00Nad0]l400?<b003n1P00gH0003FM
0000EdX000/U00036`00:C`007`K0;c3003d;`00oPP00=^6000]V`0005E<000:90000a/002ho0020
5036`000mRP00?d<003HT@007iH0001@CP00224000@M000g@`00Q`H0c;800?TM003k4`00dZ8000Z>
0000@TT000DO00067`00AT/03i000=BM003k4@00n2400<Vh0000P`d00350000n000470002B<005E<
032L003MP@00oPH00?8f002Y_P0007HV000Q=`000QX0010Z001Q@P1NZP00if000?l0003ZE000LJl0
001W?0004bd0008I000L=000LRd0V[X00?4m003o1000gg`003JN0000ET/000XT00047000<d4008D9
0<bb003i6`00nQH00<nZ0000R@4003Q400047@00228005=<02nK003MP000oP@00?4k002K^`00074^
000?9P005Bh006Xh082d003]B@00o`400>9a0012XP0005U9000;9@000a/0035100252P3</@020?TI
001]0<ba0000Q@T0035100036`002bD005U904JS003SK@00o`000>a>001e/@0006Hm000B;0000QT0
024g001h8`2i`P00mB/00?d<003EV@003Xl00011B0001Ah000PQ001BC@0^V`00gWd00?l3003_@P00
RKH0001[=P005Bh0008I000M=@00MBP0[[l00?@_003m2`00eYH0012@0000@DP000DM00088P00Dd`0
=9d00>1h003o0P00kDT007^b0000Ic`0018/00026P0093T007/M0<G2003g8`00na<00<nY0000Q`D0
039100036`0032H005e605RX003XG@00o`000>IT001>Y@0005Y8000:9@0011`003Q400B;003CWP00
o0d00?D/002a`00007DY000L<`000QT001Pa001a;`2R_000lc800?d:003FU`002hh0000lAP0011`0
00XT001IB@1=Y@00iV<00?l0003VH@00CjH0001JB0002R@000@L000lAP0<S`00eYD00?d9003b=P00
V[X0001^<`005Rl0008I000Q=`0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0A000OQP003I300067`0011d002/m001f9P29]P00jET00?l1003b>000aL@000261`00@dT000PR
00036`008cP006la07:`003UIP00o`<00?@^0039^@0018/0001<C@002B<000<J000O=@00K3H0Ijd0
0>=]003n1@00mBX00<^d0008S@0004m>000:90000aX001he001[=P1V[000hf`00?h5003e:`00b[H0
00F<0000C4d000TS00036`008CL006hb076`003VI@00o`800?<b0036`00008L50013B@001b4000<L
000W>`00M2T0R;H00>YF003o0000l4000;700000OaH003E30P001Ah0m@00<d4007dI0:^n003_@P00
o`000>YE0029]P0007@Z000V>P000a/000PR0017B`01RP00b[P00?DZ003n1P00hG<005RX0000ISd0
01Pa00026@003RP005Q902ZJ003GU000na<00?XF003EV@0099L0001FB`003BL0008J000K<`00JSP0
IZ`00>AX003o0`00lc@00<?40000P`h003U500067`001Ah003A2001o5@2g`@00lCX00?l1003VH`00
KZl0001/=P0073@0008J000=9`0DN2D0eYD00?/C003j5`00dih001^D0000Dd`000/U00036P008CL0
074_08>d003ZE@00o`000>e9002H^P0007LU000W>`000a/000TS001?CP0@T000d:L00?TL003l3`00
f90002^J0000EdX000dW00026P007CD006hc07Zb003YF@00o`000>i7002I^P0007HV000V>P000a/0
00TS001AC@0HT`00dih00?XF003j5@00e9`001^D0000DDd000XT00036`009SX007LU09bk003^A000
o`000>MN001_[`0006Xh000I<P000QT0010Z001NA@14XP00gg/00?h6003d;@00a/8000223`00=D80
00DM00068000@dT018/00<f^003h7`00o0l00=RA000UV00005A<000:9@000a/002Dj001g9@2P_000
kd400?l1003UIP00HJ/0001U?P005Bh0008I000E;P00ISd0HZ/00>IU003o0@00kd<009Zj0000MBP0
02<h00036P0032H005Q:03>M003LQ@00o@T00?DZ0037_`00088?000d@P0011d000LQ001;C@0AT@00
dj000?/E003j6@00d:L000V=0000ADX000HP00057P00>TD008L50<^d003h8@00o0l00=NE000NU@00
055=00088P0011`0031000204`35`P00mB/00?d9003KR000;I/0001EB`002R@000<K000Z?000O1/0
^/800?@a003n1P00gH4003FN0000EdX000/U00036`00:3/007/N0;K1003c<P00oPH00=f0000fWP00
05M:000;9@000a/002Tl001l702k`P00m2l00?h7003LQ@00;Y/0001EB`002R@000<K000^?P00P1@0
a/400?HX003m2`00f900022F0000D4h000PR00047@00=d<008H60<bb003h7@00na<00=:Q000;SP00
04=9008000HO0;D004E:00n@003CWP00na400?PP003:^00008<=000b@@0011`000TS001DC00_V`00
gH800?h6003b=@00Zkh0001f9P008CL0008J000@:P00HD80GJX00>MQ003o0000jU<007:`0000Ic`0
01<]00026@0073<0074^09Vj003`?@00o`<00=mk000gWP0005I;000:900011`0039100252P3</`00
nA`00?XF003?Z@0008T0000hA00011d000PR001CC00^V`00gH400?h5003a>P00W;/0001b;@003bH0
01D^001Z>01o/`00kDX00?l1003RL000@j80001IB@002bD000<K000a@000Q@X0c;800?TJ003j6@00
cK0000252@00<T4000<K000;9@00FDT0AJ<00>=^003o0@00k4h007Ja0000Ic`0018/00026@008CL0
07PS0;O1003e;000o@`00=FH000?T000045800057P002240059=02jK003NOP00o`<00>m1002:]P00
06`f000E;`000QT001dd001e:@2]_`00m3000?d:003FU@004I000011B@001Ah000PR001CC00cW@00
h7T00?l2003]B000OK<0001W>`004R`0008J000S>000Nad0aL<00?LS003k4P00d:P000271000<T40
00<K000<9P00GDH0EjP00>MN003o0000iV<004nV0000FTP000XU00047000>4@018/00=>O003l3P00
mB`00;;00000MBP001`d00026@006340070_0:6l003c<`00o@X00=JF000<S`0003a6000470002R@0
05U904bU003VI000o`000>MQ001@YP0005Y8000:900011`003]600b>003FUP00o@T00?8e002K^P00
06hc000F;`000QT0024g00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`14
001n6000=d<000HO00047@00:cd007HW08Rf003YF@00o`400?8g0035``0008H60014BP00228000<K
000R>000Kc40LJl00>EW003o0`00m2d00<Zh0004R`0004e>00098`000aX001he001[=P1V[000hfh0
0?h5003e:@00bk<000V=0000Cdh000XT00036P007SD006/g06F/003SK@00oPD00?D[003:]P001H`0
001<C@002B<000<J000P=P00KS<0L:l00>EU003o0`00lc800<No0000Q`@004=900078@000a/002Lj
001d:P27]@00jEL00?l0003`?`00//00001o5@00=T<200057P3e000b@@00OAX0Z[h00>m3003o0000
jU@008Zf0000M2T002Lj00036`00224004I;002:0039^000mB/00?h5003RLP00FJT0001V?0006340
008I000>:000F4T0:YT00=NE003k4`00nQD00=FI000TV00005I:000=9`000QX001/b001Y>@1U[000
i6T00?l3003c=000a<@000233@00>TD000HO00057@00<d8007lF0;G1003a>`00o`400>IR001_[`00
06`f000L=0000QX000`W01=g9P3FUP00na<00?XG003DW@0079D0001CC0002bD000<J000Q=`00LBl0
P[@00>YF003o0000kTP009Vj0000MbD002Pk00036`002B8004i>00n@003@Z000nA`00?`?003HS`00
;9X0001HBP003BL0008J000M=000KS<0NK800>UJ003o0000kTL009Zj0000MRH002Hj00036`002B<0
055=01NC003CW`00nQL00?/E003DW0006i@0001BC@002R@000<K000V>P00MRH0VkX00>i5003o0000
j5h0072_0000JcL001Xb00026@0042X005e504>R003OO000oPH00?D]0036`@0008<?000f@`001Ad0
00HP0013B@03R`00cJl00?PO003l3P00f94002JH0000E4`000/U00036`009CT007HU09nk003_@@00
o`400>EU001RZ`0006Hm000E;P000QT001D^001U?P1QZ`00iFD00?l1003_@P00Vk/0001e:0008cP0
00<J000<9P00EdX0<Y`00=^6003m2@00mBT00<No0000P`h003A200047@001b4004]=012@003BX@00
nQD00?XH003@Y`002Hd00015BP001R0000DN000jA@00Q`D0bkD00?LQ003l3P00ei@001nF0000DDd0
00TR00047000;cl0080D0<G3003e:`00o@T00=^7000^V`0005E;000:9@000a/002Xl001l702i`P00
lc400?h6003MP000=Yh0001HBP002bH000<K000X>`00NQl0]L400?<c003n1P00gWl003NN0000F4X0
00/U00036`00:C`007`L0;[2003d<000oPL00=b4000_V`0005E;000:90000a/002dn001o5@36`P00
mRT00?d;003HS`0089H0001@CP00228000@M000f@`00QPL0bk<00?PN003k4`00dZ4000b>0000@dT0
0P001Ql0]@00ADX03Xl00=>N003k4@00n2000<Zg0000Q0`00391000470002B<005A<02jK003LP`00
oPH00?<e002/_`0007LU000R=`000QX0010Z001Q@P1LZ@00iV800?l0003[D`00Lk00001W>`0052d0
008I000L<`00LBh0V;X00?0n003o0`00ggX003RN0000ET/000XT00047000<T4008@;0<^d003i7000
nQH00<nY0000R@0003U400047@00228005=<02fK003MP@00oPD00?4j002M^`00078]000?9P005Bh0
06Ti07jc003]BP00o`400>9_0014XP0005U9000;9@000a/0035000242`3</P00nAX00?XH003=[`00
08H8000b@@000a/000XU001IB@14XP00hfh00?l1003/C@00Mk40001W?0004R`0008I000Q=`00N2@0
]/400?D/003m3000eYL0012@0000@TT000DN00078@00DDd0;I/00=io003o0`00kd4008bg0000K3H0
01H_00026@007C@007@Y0:bo003d<000o@X00=NE000AT@00049900057P00224005=<03:L003ON@00
o`800>i7001n/`0006Pk000B;0000QX002<h001k7P35``00mb@00?/B003@Y`0008P4000c@@000a/0
00`V001LAP1FZ000iel00?l0003VH`00D:H0001KB0002bD000@L000g@`03R`00dj000?`>003e:`00
/l00001e:00073@0008I000H<@00L300X;`00?<d003m2@00eYH000f?0000?DH000@M000:9000FDT0
Bj@00>IU003o0000if00056V0000FTP000XT00047000>dD02hh00=JG003m2@00lcD009bk0000KS80
01H_00026@0083H02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l007hG
000g@`001Ql000@L000Z?@00MBL0QkD00>UJ003o0@00lSL00<G30000Q`H004A:00088P000a/0028h
001_<P1`[`00iFL00?l4003e;@00b[L000F<0000CDh000TT00036P007SD006/f06F/003SKP00oPD0
0?HY003</`002Xh0001?CP002R@000<J000M=@00JcL0I:`00>=^003n1@00mBX00<^e0006S00004e>
00098`000aX0020f001^<`1_[`00iFH00?l3003c<@00akh000271000A4X000LQ00036`009SX007@Z
08Je003YE`00o`000?0o002c`000080E000f@`001Ah000DM000b@@00OAX0ZKh00>m3003o0000jU@0
08^f0000MBT002Lk00036`00224004I;00290039^@00mB/00?h5003RLP00FZT0001W?0006340008I
000>:000F4X0:IT00=JE003k5000nQD00=FH000UV00005M:000=9`000QX001Xb001Y>@1T[000i6X0
0?l3003c<`00aL@000233@00>TD000HO00057@00<d4007lF0;C1003a>`00o`400>IR001`[`0006`e
000L=0000QX000`W01=g9P3FUP00na<00?XG003DW@007ID0001CC0002bD000<J000P=P00L2l0PK@0
0>YF003o0000kTL009Zj0000Mb@002Pk00036`00228004i>00j?003@Z000nAd00?`?003IS`00;I/0
001HBP003BL0008J000M=000KC<0N;400>UJ003o0000kTH009^j0000MbD002Lj00036`002B<0051=
01NC003CX000nQL00?/D003DV`0079D0001BC@002R@000<K000U>P00MRH0V[X00>i6003o0000j5d0
076`0000JcL001Xb00026@0042X005e604:R003NO000oPL00?D/0036`00008<>000f@`001Ad000HP
0012B@02R`00cK000?PP003l3P00f90002NI0000ED/000/U00036P009CT007HV09jk003_@P00o`40
0>IU001RZ`0006Hm000E;P000QT001@^001U?P1PZ`00iFH00?l1003_@P00W;/0001e9`008cP000<J
000<9P00EdX0<I`00=^6003m2@00mRT00<Nn0000P`h003A200047@001b4004Y=012@003BX@00nQD0
0?XH003@YP002Xh00016BP001R0000DN000iA@00QPH0bkD00?LR003l3P00ei<001nF0000DDd003`0
00TS00047000;cl0080D0<G3003e;000o@T00=^6000_V`0005I;000:9@000a/002Tl001l702h`P00
lc800?h6003MO`00=ih0001HB@002bH000<K000W>`00NQl0]<000?<c003n1P00gWh003RN0000F4X0
00/U00036`00:3/007/M0;W2003d<000oPL00=b4000`W00005E;000:90000a/002dn001o5@35`P00
mRT00?d;003HS`008IH0001AC@00228000@M000f@`00QPP0bk@00?PN003k4P00dj0000b?0000A4X2
00067`2e0014BP0=S`00dil00?/B003h8000b[L000242`00<d4000@L00098`00E4`0;I/00=b3003n
1P00lc@00:fo0000MbD0028g00026P003bT0065205^Y003VHP00o`000>]B001d/00006Lk000D;@00
0QT001/c001a;`2G^@00l3h00?l3003ONP00>Il0001FBP002R@000<L000b@@00Q0/0bk@00?TM003j
5@00d:P0002:0000>DD000@M00088P00Ddd0;9X00=f2003n1@00lCT009jk0000LRd000lW000D;P00
JCT0OK<00>e;003o0@00hfl004FS0000FDP000/U00036`00<40008@;0<bc003i6`00nQP00<f_0000
QPL003=1000370002RD005U904>R003RK`00o`400>a=001h/@0006Ll000B;0000QT0020f001g902e
`@00mBd00?d;003FU`0049000012B@001Ah000LQ001AC@0/VP00gGl00?l4003`@000SKL0001/=@00
5Rl0008I000M=000M2T0Zkh00?@a003m2P00ei@001:A0000@TT000DN00088@00DTd0<I`00=mj003o
0P00kTL007nc0000J3/0018/00026@008cP007XO0<G4003g9000na800=2W0000R0<003=200036`00
2bH005a605FW003WG`00o`000>IR001AYP0005]7000;9@0011`003M300::003BX000o0h00?D[002d
`@0007DW000M=0000QT001P`001`<02O_000lc@00?d9003FU@003Xl0000mA`0011d000TT001HB@1:
Y000iFD00?l0003WH000DZL0001KB0002R@000@L000kA@0:SP00eYL00?d:003c=000WK/0001_<P00
5Rl0008I000P=P0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`00OaL0
03M400067`0011`002Xl001e:026]@00j5/00?l1003b=P00aL8000271@00ADX000PR00036`008SL0
06hb06n_003UJ000o`@00?D/003:]`001X`0001>CP002R@000<J000N=@00JcL0I:`00>=_003n1@00
mRP00<bb000:SP0004m>000:90000aX001dd001[=`1T[000hfh00?h5003e:P00bkD000N<0000CDh0
00TS00036P0083H006dc06j_003UIP00o`<00?@a0037_P0008P30014BP00224000<K000V>P00Lb/0
QKD00>UH003o0000l3h00;C00000P1@003M300057P001Ad00391001m6`2X_P00kd@00?l0003ZD`00
S;L0001e:0009c/000<K00088@00ADX008T00<Vi003e;000oPD00>9a001KZ@0006Ll000I<@000QT0
00hX001HBP0XV@00eYH00?/D003k5@00eYL002JH0000EdX000dW00026P006S8006Ti06B/003TJP00
o`<00?<c0035``0008@<000kA@001Ql000DM000c@@00OQL0/l000?4l003o0@00if40076_0000K3D0
01dd00026P0032H04WLV0=JG003k4`00nQH00=BL000NU@0005=<000;9@000aX0020f001`<020/`00
jEL00?l0003^A`00Vk/0001g9000:3/000<K00088P00CDh03Xl00<nY003h7@00o0h00=V>000^V`00
05Q9000=9`000QX001dd001]=01g/@00j5/00?l0003^AP00W;/0001g9@009c/000<K00098`00D4h0
5Y800=:P003j5`00na@00=FJ000MU@00059=000:90000a/002Dj001f9`2I^P00kTH00?l0003XG000
L[00001[=`006S80008I000?:P00GDH0@J400=im003n1`00mB`00<K00000P`d003I300057@001R00
049900::003=/000n2000?`>003HT000:9T0001EB`002bD000<J000T>@00MRH0WK/00>m2003o0@00
iV@006>/0000ISd001D_00026@0052h006Dn05nZ003UIP00o`400>m1002M^`0007HW000T>@000aX0
00`V001GBP0aW000fhL00?d:003f:000akh000233@00=D8000@M00078@00BT`03i000=:R003j5P00
nQP00=6V000;SP0004I;000680001Ad003U400261`3:]P00mb800?`>003GT`0089H0001AC@00?000
2B<000@L000_?`00OaD0aL@00?D/003m2000fhH0032L0000ET/000/U00036`00:C`007/M0;O1003c
<P00oPH00=io000hWP0005Q9000<9P000aX002Lk001j802c`000lc@00?h5003NOP00>9h0001HB@00
2bH000<K000X>`00Nad0^<800?@a003n1`00g8<0036L0000ET/000XT00036`00;Ch007lF0<G3003e
:@00o@/00=V>000RU`00055=00088P0011`003E30025203;]000n1h00?/B003CW`003Hl00014BP80
00HO0;D004A:00b?003CW`00na800?PO003:]P0008@;000c@@0011`000TS001DC00]V`00g8@00?h6
003c=000[[l0001g90008SP0008J000?:@00H4<0FZT00>IS003o0000je8007Fa0000J3/001@^0002
6@006c<0074_09Ji003`?`00o`<00=mi000iW`0005M:000:90000a`003500024303;]@00nAd00?XE
003@Z0000HX0000jA@0011d000PR001BC@0/VP00gH800?h5003a>@00Wk`0001b;0003bL001@^001Y
>@1l/`00kD/00?l1003SKP00AZ<0001JB0002bD000<K000`@000Q0`0bk<00?TK003j6000cJh00026
1`00<d4000<L000:9000F4T0@Z800>9`003o0@00k4`007Vb0000Ic/001</00026@0083H007LU0;C1
003d;@00o@/00=JF000AT00004=900057P001b40055=02^J003MP000o`@00?10002=]`0006`e000F
;`000QT001`d001d:P2Z_P00m3400?d:003GT`004i400013B@001Ah000PQ001BC@0aW000gg/00?l2
003^AP00Ok<0001X>P004b`0008I000R>000NQl0a<@00?LU003k4P00d:H000280P00=48000<K000;
9P00G4L0E:L00>MP003o0000iV80056V0000FdL000/U00047000=T<00XX00=:Q003l3P00mBX00;G1
0000MRL001dd00026@005c0006la09jk003c=@00o@T00=ND000>S`0003i700047@002B<005Q904VT
003UIP00o`000>MO001CY`0005]7000:9@0011`003Y500V=003EV000o@X00?<d002N^`0006lb000F
;`000QT0020f00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1O001o5P00
>4@000HO00047000:S`007DX08Fe003XF`00o`400?8f0036`P0008L50015BP00228000<K000Q=`00
KS80KZl00>AY003n1000mB`00<Zf0006S00004i>000:90000aX001he001[=`1S[000hVl00?h6003f
:000c;8000^>0000Cdh000XT00036P007C@006Xg06>[003SK`00oPD00?DY003;]0001hd0001>CP00
2B<000<J000O=P00KC@0KZl00>EW003o0`00m3000<Nm0000R0<004A:00088@000a/002Hj001c:`24
]@00jEP00?l0003`?P00]L4000205000=d<000DN00057@00<D0007`K0:Nm003_A000o`000>]C002=
]`0007DX000W>`000a`000LQ0015BP00R@40bKX00?D/003n1@00hW0005bY0000Ic/001Ta00026@00
3BP005M:02NI003FUP000P3k5000fP3FU`009iP0001GBP003BL0008I000J<P00JCX0Hj/00>A[003o
0`00lc800<G30000Q0`003]600067`001Ad00391001n5`2c`000lC`00?l1003WH000L[00001]=@00
7C@0008J000<9P0BMbH0eYL00?/D003j5P00e9`001jE0000E4`000/U00036P0083H0070`07nc003Y
E`00o`000>i6002L^`0007PT000X?0000a/000PR001=CP0=S`00cjT00?PM003l3P00fHd002jK0000
F4T000dW00026P0073@006dd07Ja003XF`00o`000>i5002M^`0007LT000W>`000a/000TS001@CP0E
TP00dZ400?XH003k5000eIX001fE0000DTd000XT00036`009CT007HW09Rj003^A`00o`000>QL001c
/00006/f000J<P000QT000lY001MAP10X@00gWh00?h7003e;000akl000233@00=d<000DM00067`00
@DT00HX00<ba003h8000o0d00=R?000XV@0005E;000;9@000aX002@i001f9`2L^`00kd<00?l1003V
I000I:`0001V?0005Bl0008I000D;P00ICh0GZX00>EW003o0@00kd4009jk0000MRH002@i00036P00
2bH005M:032L003KR000o@X00?HX0038_@0008<=000e@P0011d000LQ0019C00?T000dZ800?XF003j
5`00dJD000^>0000Ad/000LP00057@00>D@008H70<Zg003g8P00o0h00=NB000QUP00059=00098`00
11`002ho001o5@35a000mB`00?d8003LQ@00<9`0001FB`002bD000<K000Y?000Nad0]/400?<c003n
1P00gWh003VO0000F4T000`V00036P009cX007XP0;;0003c=000oPD00=im000iW`0005Q9000;9P00
0a/002Pk001k7P2g`@00lc400?h7003LP`00<I`0001FB`002R@000<K000/?P00OaH0aL<00?DZ003m
2P00fHh002:G0000DDd000PR00047000=D8008D90<^e003h7`00na800=>O000=S`0004E:0P001Ql0
]@00A4T038h00=>P003k4P00n1l00<^e0000Q@X003=2000470002B<005=<02bJ003LQ@00oPL00?<c
002__`0007LT000R>0000QX000lY001P@`1IZ@00iV<00?l0003[D@00M[40001X>`0052h0008I000K
<`00L2l0UKT00?0o003o0`00h7P003ZO0000EdX000XT00036`00<D0008@<0<^e003h7@00naD00=2W
0001RP0003Y500047@002280059=02^J003LP`00oPD00?8h002P_00007</000?9`0052h006Tj07bb
003/C000o`400>=^0017X`0005Y8000;9@000a/0031000243@3;]000nA/00?XG003>[P0008H6000c
@P0011`000XT001HB@12X@00hW000?l1003]C000N[80001X>`004bd0008I000P=P00MbD0/l000?@^
003m2`00eYD001:A0000@dT000DN00078@00DDd0:YX00=f0003n1000l3l008jg0000KCD001H_0002
6@0073@007@Z0:Vn003c<@00o@T00=NC000CT@0004=900057P001b40059=032L003ON`00o`800>i6
0020]00006Pj000C;0000QT0028h001j7`33a000mbD00?/A003@YP0008P2000d@P000a/000/U001L
A`1DY`00if000?l0003WH@00DZL0001KA`002bD000@L000f@`01RP00dZ400?`?003e:P00]/40001f
9`007C@0008I000G<000Kc40WK/00?<e003m2@00ei@000n@0000?TL000@M00098`00F4T0B:@00>EV
003o0000ieh005BW0000FdL000/U00047000>TD02Hd00=FH003m2P00lc<009nk0000Kc4001L`0002
6@007cH02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l007lF000hA000
1Ql000@L000Y?000MBT0Q;D00>QK003o0@00lSH00<K10000Q`@004I:00088P000a/0024g001^<`1]
[P00i6T00?h4003e;000b[H000N<0000CTh000XT00036P007C@006/g06:[003RL000oPH00?HX003<
/@002hh0001@CP002R@000<J000M=000JSP0HZ/00>9_003n1@00mRT00<^d0008S@0004i>00098`00
0aX001lf001]=01][P00iFL00?l3003d<000b;d000280P00ADX000PQ00036`009CX007<[08>d003Y
F@00o`000?0m002e`@00080C000gA0001Al000DM000a@000O1/0Y[d00>i5003o0000je8008fg0000
MBL002Pk000370001b4004E:00290@39^P00mB`00?h5003RL000GJX0001W>`006C40008I000=:000
EdX09iT00=JG003k5@00na@00=JF000WV@0005M:000=:0000QT001Xb001Y>P1RZ`00i6/00?l3003c
<P00aL8000242`00>dH000HO00057@00<T4007hH0;;0003a?000o`400>MP001b/00006dd000M=000
0QX000`V019f9P3EV000na@00?XF003DV`007iH0001DC0002bD000<J000P=P00L300O[<00>UH003o
0000kTH009fk0000N2<002Tl00036`00228004e>00b?003?ZP00n1h00?`>003IS@00;i/0001HB@00
3BL0008J000L=000KC@0M[400>QL003o0000kTD009fk0000Mb@002Pk00036`002B<0051>01FB003B
X@00nQP00?/C003EV@007YD0001CC@002R@000<K000U>@00MBL0UkX00>i7003o0000j5`007B`0000
JcH001Xb00026@003bT005e6042Q003NOP00oPL00?D[0037_`0008@<000g@`001Ah000HO0011B001
RP00c;400?PQ003l3@00fHl002VI0000ED/000/U00036P0093T007HW09^k003_@`00o`400>IS001U
[00006Ll000F;`000QT001@]001T?`1NZP00iFL00?l1003_@@00Wk/0001f9P0093T000<J000;9P00
EdX0;i/00=^8003m2P00mRP00<Rm0000Q0`003E300047@001b0004U<00j?003BX`00nQH00?XG003A
Y@0038h00017B`001b0000DM000hA000QPP0b[L00?LS003l3@00f980026G0000DTd003`000TS0003
7000;Sl007lF0<C4003e;@00oPP00=b5000aW00005I;000;9@000a/002Pk001k7P2e`@00lc<00?h6
003NOP00>Il0001IB@0032H000<J000V>P00NB00/L000?<e003n1@00gWd003ZO0000F4T000`V0003
6`009c/007/N0;K1003c<P00oPH00=f2000bW00005I;000:90000a/002`n001n5`35a000mBX00?d:
003IS@008iL0001AC@00228000@L000e@P00Q@T0bkD00?PO003k4P00dih000j?0000ADX200067`2e
0013B@0;SP00dZ000?/B003h7`00bkD000252P00=48000@L00098`00Dd`0:iX00=b5003n1`00lc<0
0:no0000N2@002<h00026P003bT0061305RX003VI000o`000>]A001g/@0006Pj000D;P000QT001/c
001`<02D^@00l4000?l3003PN000>il0001GBP002R@000<K000a@000P`d0b[H00?PN003k5000d:L0
00::0000>TD000@M00088P00DTd0:YX00=b3003n1@00lSP00:6l0000Lb/0010W000D;@00J3X0Nk80
0>a<003o0@00hfd004NS0000FTP000/U00036`00;cl008<=0<^d003i7000nQL00<j]0000Q`H003A2
000470002R@005Q9046Q003RL@00o`400>e;001k/P0006Pk000C;@000QT0020f001g9@2c`000m2h0
0?d;003FU@004Y400013B@001Ah000LQ001AC@0ZVP00gH400?h4003`?`00SkL0001]=0005Rl0008I
000L=000Lb/0ZKh00?<b003m2@00ei8001BB0000A4X000DN00078@00DTd0;i/00=ml003o0P00kTD0
086d0000JCX001<]00026@008SL007XP0<?4003f9@00na400=6U0000R@4003A200036`002bD005a7
05>W003WH@00o`000>MQ001CY`0005]7000;9@000a`003I3002:003BXP00o0l00?DY002g`@0007HV
000M=@000QT001L`001_<@2M^`00lSD00?d9003GT`003i00000oA`0011d000TS001HBP18X`00iFL0
0?l0003WGP00EJL0001KA`002bD000@L000iA@08S@00eIT00?d:003c<`00X;`0001_<@005c00008I
000O=P0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0l000OaD003Q40006
7`0011`002Tl001d:@24]000j5`00?l1003b=@00a/4000281000AT/000PR00036`008CL006hc06f^
003TJ@00oP@00?D[003;]@001hd0001?CP002R@000<J000M=000JSP0HZ/00>9`003n1P00mRL00<ba
000<SP00051>000:90000aX001dd001Z>01QZ`00hW000?h5003f:@00bk<000R=0000CTh000TT0003
6P007cH006dd06b^003UJ000o`<00?@`0038_@0008P20015BP00224000<K000U>P00Lb`0Pk@00>UI
003o0000l3d00;K10000P1<003Q400067`001Ad00350001l702V_@00kTD00?l0003[DP00S[L0001e
9`00:3/000<L00078@00A4X008P10<Rk003e;@00oPD00>9`001MZP0006Pk000I<@000QT000dX001G
BP0VV000eYL00?XE003k5000eYH002RI0000EdX000dX00026@006C8006Pj066[003SK000o`<00?<b
0035`P0008@;000lAP001Ql000@M000b@@00OQP0/L000?0m003o0@00if0007>`0000KC@001dd0002
6P0032H04WHV0=FH003k5000nQD00=BK000OUP0005A<000;9@000aX001lf001_<@1m/`00jEP00?l0
003^AP00W[/0001h8`00:C`000<K00088P00C4d038l00<nZ003h7P00o0h00=V<000`W00005U9000=
:0000QX001`d001]=@1e/@00j5`00?l0003_A000W[/0001h9000:3/000<K00098`00D4h059800=:R
003j6000na<00=FI000OUP0005=<000:90000a/002@i001e:02G^@00kTL00?l0003XF`00M;00001/
=P006c<0008I000?:@00G4H0?j400=io003n1`00mB/00<No0000Q0`003M400057P001Ql00458002:
003</P00n2400?`=003ISP00:YX0001EB`002bD000<J000T>@00MBL0V[X00>m4003o0@00iV<006J/
0000Ic`001H_00026@0052d006@o05fZ003UJ000o`400?10002P_00007HV000T>@000aX000/U001F
BP0_V`00fhT00?d:003f9`00b;`000243000=T<000@M00078000BD`03Hl00=6S0080nQL004T0dJ@0
00b?0000Ad/000LP00057@00>4@008H80<Zg003g8`00o0d00=RA000RU`00059=00098`000a`002ho
001o5P33a000m2d00?h8003LQ000<I`0001FBP002bD000<K000X>`00Nah0]L400?<c003n1@00gWd0
03ZO0000FDT000`V00036P009SX007TQ0;30003b=@00oPD00=il000jW`0005U9000<9P000aX002Lk
001j7`2f`@00lc800?h6003MPP00<id0001FB`002RD000<K000/?@00OQL0aL@00?DZ003m2P00fHd0
02BG0000DDd000PR00047000=48008D:0<Zf003h7`00na400=>N000?T00004I:008000HO0;D004=9
00^>003BX@00na<00?PN003;]@0008D9000d@P0011`000TS001CC00[VP00g8D00?h7003c<`00/<00
001h8`008cP0008J000?:@00H4<0F:P00>IT003o0000je0007Na0000J3X001@^00026@006c<0070`
09Bi003`@000o`<00>1h000kW`0005M:000:90000a/0031000233@3:]P00n1h00?/D003@YP000XX0
000kA@0011d000PR001BC@0ZVP00g8@00?h6003b>000X[`0001c:`0042L001@]001X>P1j/P00k4d0
0?l1003SK@00B:<0001JB0002bD000<K000_?`00P`d0bkD00?TL003j5`00cZd000271@00=48000@L
000:9000F4X0@:400>9a003o0@00kD/007^b0000J3/001<]00026@007cH007HV0;;0003d;P00o@/0
0=NE000CT@0004A:00057P001b40051=02VI003MP@00oP@00?0n002@^00006dd000F;`000QT001`c
001c:`2X_P00lc800?d9003GTP0059800014BP001Ah000LQ001BC@0_V`00gg`00?l3003^A@00P[@0
001Y>P004bd0008I000R=`00NR00`/@00?HV003k4@00dJD000290@00=D8000<K000;9@00FdL0DZL0
0>IQ003o0000if0005BW0000G4L000/U00037000=D<008X00=:R003l3`00mRT00;S10000MRH001he
00026@005c0006la09bk003b=P00o@P00=NC000@T00003m700047@002B<005Q:04NS003UI`00o`00
0>QN001EY`0005]7000;9@0011`003U500R=003EV@00o@X00?<b002P_00006la000G<0000QT001lf
00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3`001o5@00>D@000HO0004
7000:C`007@Y08>d003XG000o`400?<e0036`00008P30016B`00228000<K000Q=`00KS<0K:h00>AZ
003n1000mB/00<^e0008S@0004m>000:90000aX001dd001Z>01QZ`00hW400?h6003f9`00c;0000b?
0000D4h000XT00036P0073@006Xh066[003RL000oPH00?HX003</`002Hd0001?CP002R@000<J000O
=P00KCD0K:h00>AX003o0`00m2l00<Rl0000R@4004I:00088P000a/002Di001c;022]000jEX00?l0
003a?000]l4000214P00>4@000HO00057@00<40007`L0:Fm003^A@00o`000>]A002?]`0007HW000X
>`0011`000LQ0014BP00R080b;/00?D]003n1@00hVl005jZ0000J3/001Tb00026@003BL005M:02JH
003EV000nQD00?/D003FUP00:9T0001HBP003BP0008I000I<P00J3X0HJ/00>=/003o0`00lc400<K2
0000Q@X003a600067`0011d00351001n602``000l3d00?l1003WG`00M;00001]=0007CD0008J000<
9P0AMRH0eIT00?/D003j5@00eIX0022F0000E4`000/U00036P007cH006la07fc003YF@00o`000>i5
002N^`0007PS000Y?0000a/000PR001<C@0<SP00cjX00?PN003l3P00fH`0032L0000FDT000dX0002
6P0073<006`e07B`003XG000o`000>m4002O^`0007PS000X>`000a/000TS001?CP0DTP00dZ800?XH
003k4`00eIP001nF0000Dd`000XT00036`0093T007DX09Ji003^B000o`000>QK001e/@0006`f000K
<`000QT000lY001LAP0oX@00gWl00?h7003e:`00akh000243000>4@000DN00067`00@4P008T00<bb
003g8@00o0d00=V>000ZVP0005I;000;9@000aX002@i001e:02J^P00kd@00?l0003VHP00IZ`0001W
?0005Rl0008I000D;@00I3l0G:X00>AX003o0@00l4000:2l0000MbD002Di00036P002bD005I;02jK
003JR@00o@X00?HW0038_00008@<000f@`0011d000LP0018C00=S`00dJ@00P3j5`00o`3AY0003Hl0
0018B`001b0000DM000hA000Q@P0b[P00?LS003l3@00f94002:G0000DTd000TS00037000;Sh007lG
0<?4003d;@00oPP00=b4000bW00005M:000;9@000a/002Pk001k7P2d`@00lc@00?h5003NO@00>Yl0
001IB@0032H000<J000V>P00NB40/<000?8e003n1@00gg`003^O0000FDT000`V00036P009c/007XO
0;G1003c<P00oPH00=f1000cW@0005I;000:9@000a/002/m001n6034a000mB/00?d:003IS00099P0
001AC@00228000@L000d@P00Q@X0b[H00?PP003k4@00dih000n@0000AT/000HO00057`00@TT02Xh0
0=:Q003k4`00n1h00<^d0000Q@T003A2000470002B<005=<02ZJ003KQP00oPL00?<b002a`00007PS
000S>0000QX000lY001P@`1GZ000iVD00?l0003[D000N;40001Y>P005Bh0008I000J<P00L300TkP0
0?10003o0`00h7L003bP0000EdX000XT00036`00<40008<=0<Zg003h7P00na@00=2V0003R`0003]5
00047@002280059=02VI003LQ000oPH00?8g002R_00007<[000@9`0052d006Pj07Zb003/C@00o`40
0>=/0018Y00005Y8000;9P000a/002lo00233P3;]@00nA`00?XG003>[00008L5000d@P0011`000XT
001HBP10X@00hW400?l1003]BP00O;80001X>P004bd0008I000O=P00MRH0/L000?@_003m2P00ei@0
01>A0000A4X000DN00078@00D4h0:IT00=f2003n1000l3h0092h0000KC@001L`00026@0073<007<[
0:Nm003c<P00o@T00=RA000ETP0004A:00057P001b40055=02jK003NO000o`<00>i50022]00006Ti
000C;@000QT0024g001i8031a000mRH00?/A003AY00008T0000e@P000a`000/U001KA`1BYP00iV80
0?l0003WH000E:L0001LA`002bD000<K000e@P00R@00dZ<00?`?003f:@00^<80001f9P007SD0008I
000G<000Kc80Vk/00?8f003m2000ei<0012@0000?dL000@M00098`00EdX0Aj<00>EX003o0000j5d0
05JX0000G4L000/U00047000>D@01hd00=FJ003m2`00lc800:6l0000L30001L`00026@01000O=P[o
oooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3`00205@00>D@000HO00047000
:C`007@Y08:d003XG@00o`400?<e0036`00008P30016B`00228000<K000Q=`00KC<0K:h00>AZ003n
1000mB/00<^e0008S@0004m>000:90000aX001dd001Z>01PZ`00hW400?h6003f9`00cK0000f?0000
D4h000XU00036P0073@006Xh062[003RL000oPH00?HX003</`002Hd0001?CP002R@000<J000O=@00
K3D0Jjh00>AY003o0`00m2l00<Rl0000R@4004I;00088P000a/002Di001b;021]000jEX00?l1003a
?000]l4000214P00>4@000HO00057@00<40007`L0:Bm003^AP00o`000>]A002?^00007HW000X>`00
11`000LQ0014BP00R080b;/00?@]003n1000hfl005jZ0000J3/001Tb00026@003BL005M:02FH003E
V000nQD00?/D003FU@00:IT0001HBP003RP0008I000I<P00J3X0H:/00>=/003o1000m3400<K10000
Q@X003a600067`0011d00350001m6@2``000l3d00?l1003WG`00M;00001]=0007SD0008J000<9P0A
MRH0eIT00?/E003j5@00eIX0022F0000E4`000/V00036P007cH006la07bc003YF@00o`000>i5002O
^`0007PR000Y?0000a/000PR001<C@0;SP00cj/00?PO003l3@00fH`0036L0000FDT000dX00026P00
73<006`e07B`003XG@00o`000>m4002O_00007PS000X>`000a/000TS001?CP0CT@00dZ800?XI003k
4`00eIP001nF0000Dd`000XT00036`0093T007DX09Fi003]B000o`000>QJ001f/@0006`e000K<`00
0QT000lY001LAP0nX000gGl00?h8003e:P00akh000242`00>4@000DN00067`00@4P008T00<bb003g
8P00o0d00=V=000[VP0005I;000;9@000aX002<h001e:02I^P00kT@00?l0003VHP00Ijd0001W?000
5Rl0008I000D;@00I3l0G:T00>AY003o0@00l4000:6l0000MbD002Di00036P002bD005I;02jK003J
R@00o@X00?HW0038^`0008@;000f@`0011d000LP0018B`0=S`00dJ@00P3j5`00o`3AX`003Hl00018
C0001b0000DM000gA000Q@T0b[P00?LT003l3@00f94002>G0000DTd000TS00036`00;Ch007hG0<;4
003d;P00oPP00=b4000bW@0005M:000;9@000a/002Pk001j7`2c`000lc@00?h5003NO@00>il0001I
B@0032H000<J000V>P00NB40[kl00?8f003n1@00gg`003^O0000FDT000`V00036P009c/007XO0;C1
003c<`00oPH00=f1000dW@0005I:000:9@000a/002/m001n6034a000mB/00?d:003IS0009IP0001B
C@00228000@L000d@P00Q0X0b[H00?PP003k4@00e9d000n@0000AT/000HO00057`00@TT02Xh00=:R
003k4`00n1h00<^d0000Q@T003A2000470002B<005=<02ZJ003KQP00oPL00?<b002a`00007PS000S
>0000QX000lY001OA01GZ000iFD00?l0003[D000N;40001Y>P005Bh0008I000J<P00L300TkP00>m1
003o0`00h7L003bP0000F4X000XU00036`00<40008<>0<Zg003h7P00na@00=6U0003R`0003]60004
7@002280055=02VI003LQ@00oPH00?8g002S_00007<[000@9`0052d006Pk07Vb003/C@00o`000>=/
0019Y00005Y8000;9P000a/002lo00233P3;]P00nA`00?XF003>[00008L5000d@P0011`000XT001G
BP0oX@00hW800?l1003]BP00O;<0001X>P004bd0008I000O=P00MRH0/L000?@_003m2P00ei@001BA
0000A4X000DN00078@00D4h0:9T00=f2003n1000l3h0096h0000KC@001L`00026@006c<007<[0:Nm
003c<`00o@T00=RA000ETP0004E:00057P001b40055=02jK003NO@00o`<00>i40023]00006Ti000C
;@000QT0024g001i8@31a000mRH00?`@003AY00008T0000e@P000a`000/U001KA`1AYP00iV800?l0
003WG`00EJL0001LA`002bD000<K000e@P00R@00dZ<00?`?003f:@00^L80001g9@007SD0008I000G
<000KS80VkX00?8f003m2000ei80016@0000?dP000@M00098`00EdX0AZ<00>EX003o0000j5d005JX
0000G4L000/U00047000>D@01hd00=FJ003m2`00lc800::l0000L30001L`00026@01000O=@[ooooo
0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1n00205000>DD000HO00047000:3`0
07@Z08:d003XG@00o`400?<d0036`00008P30017B`00228000<K000Q=`00KC@0Jjh00>A[003n1000
mB/00<^d0008S@0004m>000:90000aX001dd001Z>01PZ`00hW400?h6003f9`00cK0000f?0000D4h0
00XU00036P0073@006Xi062[003RL@00oPH00?HX003</P002Hd0001?CP002R@000<J000O=@00K3D0
Jjh00>AY003o0`00m2l00<Rl0000R@4004I;00088P000a/002Di001b;021]000j5X00?l1003a?000
^<4000214P00>4@000HO00047@00<40007/M0:Bm003^AP00o`000>]A002@^00007HV000Y?00011`0
00LQ0013B@00R0<0b;`00?@^003n1000hfh005nZ0000J3X001Xb00026@003BL005M:02FH003EV000
nQD00?/C003FU@00:IT0001HBP003RP0008I000I<@00J3/0H:/00>=]003o1000m3400<K10000Q@X0
03e600067`0011d00350001m6@2__`00l3h00?l1003WG`00MK00001]=0007SD0008J000<9P0AMRH0
eIT00P3j5@00o`3EVP008IH0001DC0002bH000<J000O=P00Kc40O;800>UI003o0000kTD009nl0000
N28002Xl00037000228004]=00^>003?Z`00n1l00?`=003JR`00<I`0001IB@003RP0008J000L<`00
K3D0Lk000>QM003o0000kd<00:2l0000N2<002Pk00036`002B<004m>01>A003BX`00nQT00?/C003E
V00089H0001CC0002R@000<J000T>@00MBT0UKT00>e8003o0000jEX007Ja0000K3D001/c00026@00
3bT005a703jP003MP000oPP00?DZ0037_P0008@;000hA0001Ah000HO0010B000R@00c;<00?LR003l
3@00fHd002^J0000ET/000/U00036P008cP007DX09Vj003^A@00o`000>IR001W[@0006Lk000F;`00
0QT001<]001T?`1KZ@00i6T00?l1003`?`00X[`0001g9@009CT000<J000;9@00ET/0;I/00=Z:003m
2P00mRL00<Rk0000Q0/003I300047@001b0004Q;00b?003AY000nQL00?XF003AX`003Hl00018C000
1b0000DM000gA000Q@T0bKP00?LT003l3@00f90002>G0000DTd000TS00036`00;Ch007hG0<74003d
;P00oPL00=b3000cW@0005M:000;9@000a/002Pk001j7`2c`000lc@00?h5003NO000>il0001IB@00
32H000<J000V>P00NB80[[l00?8f003n1@00gg/003bP0000FDT000`V00036P009cX007XO0;C1003c
<`00oPH00=f1000dW@0005I:000;9@000a/002/m001n6034a000mB/00?d:003JS0009IP0001BC@00
228000@L000d@P00Q0/0b[L00?PP003k4@00e9d0012@0000AT/000HO00057P00@TT02Xh00=:R003k
4`00n1h00<^d0000Q@P003E2000470002B8005==02VI003KQ`00oPL00?<b002b`00007PR000S>000
0QX000lY001OA01FZ000iFD00?l0003/C`00NK80001Y>P005Bh0008I000J<P00Kc40T[P00>m1003o
0P00h7H003fP0000F4X000XU00036`00<40008<>0<Zg003h7`00na@00=6U0003R`0003a600047@00
2280055=02VI003LQ@00oPH00?8g002T_@0007<Z000@9`004bd006Pk07Rb003/CP00o`000>=/0019
Y00005]8000;9P00L`000a/002ho00233P3:]P00nAd00?XF003>[00008L4000e@P0011`000XT001G
BP0oX@00hW800?l1003]BP00OK<0001X>P004bd0008I000O=@00MRH0/<000?@_003m2P00ei<001BB
0000ADX000DN00078@00D4h0:9T00=b2003n1000l3h009:h0000KC<001L`00026@006c<007</0:Jm
003c<`00o@T00=RA000FTP0004E:00057P001b40055=02fK003NO@00o`<00>m40023]00006Ti000C
;@000QT0024g001i8@30``00mRH00?`@003AY00008T0000e@`000a`000/U001KA`1AYP00iV800?l0
003WG`00EJL0001LAP002bH000<K000e@P00R@00dJ<00?`@003f:000^L80001g9@007SD0008I000G
<000KS80V[X00?8g003n2000ei80016@0000@4P000@M00098`00EdX0AZ<00>AX003o0000j5d005NX
0000G4L000/U00047000>4@01h`00=FJ003m2`00lc800::l0000L30001L`00026@007cD02_ooool1
o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo07h0080D000iA@001R0000@L000X>`00
M2X0PK@00>QM003o0P00lc@00<No0000R08004M;00088P000a/0020g001]=01[[P00i6/00?h4003e
:P00bk@000V=0000Cdh000XT00036P007C@006Xh062[003RL@00oPH00?HW003=/0003Hl0001@CP00
2RD000<J000L=000JCT0GjX00>9a003n1P00mRP00<bb000:SP0004m>000:90000aX001he001/=@1Z
[P00i6T00?l4003d;`00b;/000290000AT/000PR00036`009CT0078/082d003XF`00o`400?4l002h
`P00084B000hA0001Ql000@M000`@000Nad0Xkd00>i6003o0000je40092h0000MRH002Tl00047000
1b4004=900280`38_000m2h00?h4003SKP00GjX0001X>P006S80008J000=9`00EdX09IP00=FI003j
5@00na<00=NE000YV@0005Q9000>:0000QT001Ta001X>`1OZP00hfd00?l4003d<@00a/4000252@00
?DH000HO00047@00<D0007dI0:no003`?P00o`400>MN001e/@0006dc000N=@000QX000`V015f9P3E
VP020?XE003o0=FI000QUP0005E<000;9P000aX001le001_<P1k/P00jET00?l0003^A000X;`0001i
8P00:S`000<L00088P00Bdd02hh00<j[003h7`00o0d00=Z;000aW00005U9000>:0000QX001`c001/
=@1c/000j5d00?l0003_@`00X;`0001h8`00:C`000<K00098`00Cdh04i400=:S003j6@00na800=JH
000PUP0005=<000:9@000aX002@i001e:@2E^@00kDT00?l0003YFP00M[40001/=@006c<0008I000?
:@00G4L0?J000=f0003n2000mBX00<Nm0000Q0/003Q400057P001Ql004180029003</`00mb800?`=
003IS@00:iX0001FB`002bH000<J000S>000MBP0V;X00>i5003o0000iV4006R]0000Ic/001H_0002
6@004bd006@o05^Y003TJ@00o`400?0o002R_00007LU000U>P000aX000/U001FB`0]V`00fXX00?d;
003f9P00b;/000242`00=d<000@M00078000Ad/038h00=6U003j5`00nQH00=:S000>S`0004Q<0007
800011d003M300252@39^@00mb@00?`=003HT0008iL0001BC@002B<000<K000]?P00OQL0`L@00?@^
003n1`00g8<003>M0000EdX000/U00036`009c/007XO0;;0003c=000oPD00=ml000lX00005U9000<
9P000aX002Dj001i8P2^_`00lSH00?h5003ON`00?:00001IB@0032H000<J000W>P00NR00/l000?<c
003n1P00gH0003BM0000EdX000/U00036`00:cd007hH0<?4003e:`00o@X00=Z;000UV000059=0008
8P0011`003=200242`3:]`00n2000?/A003DW@0049000017B`001Ql000DN0012B@09S@00dZ800?/C
003h7@00bk<000262000=D8000@L00098P00DTd0:IT00=^7003n1`00lc800;;00000N28002<h0002
6P003bT005m405JX003UIP00o`000>a?001i/P0006Ti000E;P000QT001Xb001_<@2B^000kd400?l2
003PMP00?J00001HBP002RD000<K000_?`00P`h0b[L00?PO003k4`00dJD000B;0000?4H000@M0008
8@00DDd0:9T00=b5003n1P00lSL00:Bm0000M2X0010W000C;@00J3/0N;400>a>003o0000i6/004ZT
0000FdP000`V001c00036`00;Sl008<?0<Zf003i7@00nQH00<j[0000Q`@003E2000470002R@005M:
03nQ003QLP00o`400>e:001m/`0006Tj000C;@000QT001le001f9`2``000m2l00?d:003GT`005980
0015BP001Ah000LP001@CP0XV@00g8<00?h4003`?@00T[P0001^<`005c00008I000K<`00Lb`0Y[d0
0?<c003m2@00f94001JB0000ADX000DN00078@00DDd0;I/00=im003o0`00kd@008Be0000JCT001<]
00026@008CL007TQ0<33003f9`00o1000=6T0000R@0003I3000470002bD005]7052V003VH`00o`00
0>MO001FZ00005a6000;9P000a/003A20029003AY000o1000?HX002j`P0007LU000N=@000QT001H_
001^<P2J^P00lSL00?h8003HTP004I400010B00011d000TS001GBP15X`00i6T00?l0003XG000EjP0
001LA`002bD000@L000hA006S000e9/00?d;003c<@00Xk`0001`<0005c00008I000O=@0:ooooo`7o
00000Oooool001kooooo00?o0000ooooooooool01oooool0o`00P1@003U50006800011`002Pk001d
:P21]000j5d00?l2003c=000akl000280P00Ad/000PR00036`0083H006dd06Z^003TJ`00oPD00?DZ
003;]0002Hd0001?CP002R@000<J000M=000JSP0GjX00>9b003n1P00mRH00<f_000>S`00051=000;
9@000aX001`d001Y>@1OZP00hW400?h6003f:000c;8000Z>0000Cdh000XT00036P007SD006`e06Z]
003TJ@00o`@00?@^0038^`0008T00016B`00228000<K000T>@00LRd0P;@00>QK003o0@00lC`00;W2
0000PA4003U400067`0011d00310001k7@2S_000kTH00?l0003[D000TKP0001f9P00:C`000@L0007
8@00@dT008P30<Rl003d;P00oP@00>=^001PZ`0006Pj000J<P000QX000dW001FBP0TV000eIT00?XF
003k4`00ei@002ZJ0000F4T000hX00026@006C4006Pk05nZ003SK@00o`@00?@`0036`@0008D9000m
AP001Ql000@M000a@000OAT0[[l00?0n003o0@00ieh007Fa0000KS<001he00026P0032H04GHV0=FJ
003j5@00naD00=FI000QU`0005E;000;9P000aX001le001_<P1k/P00jEX00?l0003_A000X;`0001i
8P00:S`000<L00088P00Bdd02Xh00<j/003h7`00o0d00=Z;000bW00005U9000>:0000QX001/c001/
=P1c/000j5h00?l0003_@`00XK`0001h8P00:C`000<K00098`00Cdh04Y400=6S003i6@00na800=JG
000PUP0005=<000:9@000aX002@i001d:@2D^@00kDT00?l0003YFP00Mk40001/=@006c<0008I000?
:@00G4L0?J000=f0003n2000mBX00<Nm0000Q0/003Q400057P001Ql004180029003;/`00mb800?`<
003IS@00;9X0001FB`002bH000<J000S>000MBT0V;X00>i5003o0000if4006R]0000Ic/001H_0002
6@004bd006@o05^Y003TJ@00o`400?0o002R_00007LU000U>P000aX000/U001FB`0]V`00fXX00?d;
003f9P00b;/000242`00=d<000DM00078000Ad/038h00=6U003j5`00nQH00=:S000>S`0004U<0007
800011d003M300252P39^@00mb@00?`<003HT00099L0001BC@00l`002B<000<K000]?P00OQP0`L@0
0?@^003n1`00g8<003BM0000EdX000/U00036`009c/007XO0;;0003c=@00oPD00=ml000lX00005U9
000<9P000aX002Dj001i8P2^_`00lSH00?h5003ON`00?:00001IB@0032H000<J000V>P00NR00/l00
0?<c003n1P00gH0003FM0000EdX000/U00036`00:cd007hI0<?4003e;000o@T00=Z;000VV000059=
00088P0011`003=200242`3:]`00n2000?/A003DW00049000017B`001Ql000DN0012B@09S@00dZ80
0?/C003h7@00bk<000262000=D8000@L00088P00DTd0:IT00=^7003n1`00lc400;?00000N28002@i
00026P003RT005m405JX003UIP00o`000>a?001j/P0006Ti000E;P000QT001Xb001_<@2A^000kd40
0?l2003PMP00?J00001HBP002bD000<K000_?`00P`h0b[P00?PO003k4`00dJD000B;0000?4H000@M
00088@00DDd0:9T00=b5003n1P00lSH00:Bm0000M2X0010W000C;@00J3/0N;400>a>003o0000i6/0
04ZT0000FdL000`V00036`00;Sl0088?0<Zf003i7@00nQH00<n[0000Q`@003E2000470002R@005M:
03jP003QL`00o`400>e9001n/`0006Tj000D;@000QT001le001f9`2__`00m2l00?d:003GT`005980
0015BP001Ah000LP001@CP0WV@00g8<00?h5003`?@00T[P0001^<`005c00008I000K<`00Lb`0YKd0
0?<c003m2@00f90001JB0000ADX000DN00078@00DDd0;I/00=in003o0`00kd@008Be0000JCT001<]
00026@008CL007TQ0;o3003f9`00o1000=6S0000R@0003I3000470002bD005]7052V003VH`00o`00
0>MO001FZ00005a6000;9P000a/003A200290@3AY000o1000?HX002j`P0007LU000N=@000QT001H_
001^<P2I^P00lSL00?h8003HT@004Y400010B00011d000TS001GBP15X`00i6T00?l0003XG000EjP0
001LAP002bD000@L000hA006S000e9/00?d;003c<@00Xk`0001`<0005c00008I000N=@0:ooooo`7o
00000Oooool001Cooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo0?l0080D000jA@001R00
00@L000X>`00M2X0PK@00>QN003o0P00lc@00<No0000R08004M;00088P000a/0020f001]=01Z[P00
i6/00?h5003e:P00bk@000V=0000Cdh000XT00036P0073@006Xh05nZ003RLP00oPH00?HV003=[`00
3Xl0001@C@002bD0008J000L<`00JCT0GjX00>9a003n1P00mRP00<bb000:SP0004m>000:90000aX0
01he001/=@1Z[@00i6X00?l4003d;P00b;/000290000Ad/000PR00036`0093T0078]082c003XF`00
o`400?4k002i`P00084A000iA0001Ql000@M000`@000Nad0Xk`00>i6003o0000je00096h0000MRH0
02Tl000470001b4004=900280`38_000m2h00?h4003SKP00H:/0001X>P006S80008J000=9`00ETX0
99P00=FI003j5P00na<00=ND000ZVP0005Q9000>:0000QT001Ta001X>`1OZP00hfd00?l4003d<000
a/0000252@00?DH000HO00047@00<D0007dJ0:jo003`?P00o`400>MN001f/@0006hc000N=@000aX0
00`V015f9P3EVP00nQD00?/E003EV@008IL0001EB`0032H000<J000O=@00Kc80Nk800>UJ003o0000
kd@00:6l0000NB8002Xl00037000228004]=00Z>003>[000n1l00?`=003JR`00<Y`0001IB@003RP0
008J000K<`00K3H0L[000>QN003o0000kd<00:6l0000N28002Tl00036`002B<004m>01:A003AX`00
nAT00?/B003FU`008IH0001CC0002RD000<J000T>@00M2T0U;T00>e9003o0000jET007Na0000K3D0
01/c00026@003bT005a703fP003MP000oPP00?DZ0038_@0008@:000iA0001Ah000HO000oB000R@40
bk<00?LR003m3000fH`002bJ0000ET/000/V00036P008cP007DY09Rj003^A@00o`000>MQ001X[@00
06Lk000F;`000QT001<]001T@01JZ@00i6X00?l2003`?`00Xk`0001g90009CX000<J000;9@00ET/0
;9X00=Z:003m2`00mRH00<Vk0000Q@X003M300057@001b0004M;00b>003AY@00nQP00?XF003BXP00
3Xl00019C0001b0000@M000g@`00Q@X0bKT00?LT003l3000f90002BH0000Ddd00?<000TS00036`00
;Ch007hH0<33003d;P00oPL00=b3000dW@0005M:000;9@000a/002Lk001j7`2b`000lcD00?h5003O
O000?:00001IB00032H000<J000U>P00N280[Kl00?8f003n1@00gg/003fP0000FDT000`V00036P00
9SX007XP0;?0003c<`00oPH00=f0000eW@0005M:000;9@000a/002/m001n6@32a000mB`00?d9003J
R`009YP0001BC@002B8000@L000c@@00Q0/0b[L00?PQ003l4@00e9`0012@0000Ad/000HO00057P00
@DT02Hd00=:S003k5000n1d00<bc0000QPP003E2000470002280059=02VI003KQ`00oPL00?<a002c
`00007TR000T>@000QX000hY001OA01EZ000iFH00?l0003/C`00N[80001Y>@005Bh0008I000J<P00
Kc40TKP00>m1003o0P00h7H003jP0000F4T000/U00036`00;cl008<?0<Zh003h7`00na<00=6U0004
R`0003a600047@002240055=02RI003KQP00oPH00?8f002U_@0007@Z000@9`004bd006Pk07Na003/
CP00o`000>A[001:Y00005]7000<9P000a/002ho00223`3:]P00nAd00?XF003?Z`0008P4000e@P00
11`000XT001GBP0nX000hG<00?l1003]B@00O[<0001Y>P0052d0008I000O=@00MRL0[kl00?@`003m
2P00ei<001FB0000ADX000DN00078000D4h09iT00=b3003n1@00l3d009>h0000KS<001L`00026@00
6c<0078/0:Fm003c<`00o@P00=R@000FT`0004E:00057P001b40055=02bJ003NOP00o`<00>m40025
]@0006Ti000C;@000QT0024g001i8@2o``00mRL00?`@003AX`0008X0000f@`0011`000/U001KB01@
YP00iV<00?l0003WG`00EZP0001LAP002bH000<K000d@P00R@40dJ@00?`@003f:000^l80001g9@00
7SD0008I000F;`00KS<0VKX00?8g003n2000f94001:A0000@4P000@M00098`00EdX0AJ800>AY003o
0000j5`005RX0000G4H000/U00047000>4@01X`00=BK003m2`00lc400:>m0000L30001P`00026@00
7SD02_ooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool01oooool0o`00P1@003Y50006800011`002Pk001d:P21]000j5h00?l2003c=000akl000280P00
Ad/000PR00036`0083H006dd06Z]003TJ`00oPD00?DZ003;]0002Hd0001?CP002R@000<J000L=000
JST0GjX00>9b003n1P00mRH00<f_000>S`00055=000;9@000QX001`c001Y>@1OZP00hW400?h6003f
9`00c;8000Z>0000Cdh000XT00036P007SD006`e06V]003TJP00o`@00?@^0038^`0008T00017B`00
228000<K000T>@00LRd0P;<00>QK003o0@00lC/00;W20000PA4003U400067`0011d00310001k7@2S
_000kTL00?l0003[D000TKP0001f9P00:C`000@L00078@00@dT008P30<Rl003d;P00oP@00>=^001P
Z`0006Pj000J<P000QX000dW001FBP0TV000eIT00?XF003k4`00ei@002ZJ0000F4T000hX00026@00
6C4006Pk05nZ003SKP00oP@00?@`0036`00008D9000mA`001Ql000@M000a@000OAX0[[l00?0n003o
0@00ieh007Ja0000KS<001he00036P002bH047DV0=FJ003j5@00na@00=FI000RU`0005E;000<9P00
0aX001le001_<P1j/P00jEX00?l0003_A000XK`0001i8@00:S`000<L00088P00Bdd02Xh00<j/003h
7`00o0d00=Z;000bW00005U9000>:0000QX001/c001/=P1b/000ieh00?l0003_@`00XK`0001h8P00
:C`000<K00098`00Cdh04Y400=6T003i6@00na800=JG000QUP0005=<000:9@000aX002@i001d:@2D
^@00kDT00?l0003YF@00Mk40001/=@006c<0008I000?:@00G4L0?J000=f0003n2000mBX00<Rm0000
Q@X003U400057P001Ql003m800290@3;/`00mb800?d<003IS000;9X0001FB`002bH000<J000S>000
MBT0UkX00>i5003o0000if4006R]0000J3/001H_00026@004bd006=005ZY003TJP00o`800?0o002S
_00007LT000U>P000aX000/U001FB`0/VP00fXX00?d;003f9P00bKX000252P00=d<000DM00078000
Ad/02hh00=6U003j6000nQH00=:R000>S`0004U<0007800011d003M300252P39^@00mb@00?d<003H
S`0099P0001CC@00l`002B<000<K000]?P00OQP0`<<00?@_003n1`00gH8003BM0000EdX000/U0003
6`009c/007XP0;;0003c=@00oPD00=mk000lX00005U8000<9P000aX002Dj001h8P2]_`00lSL00?h4
003ON`00?J00001IB@0032H000<J000V>P00NR00/l000?<c003n1P00gH0003FM0000EdX000/U0003
6`00:cd007dI0<;4003e;000o@T00=Z;000VV000059=00098P0011`003=10024303:]`00n2400?`@
003DW0004I000017B`001Ql000DN0011B009S@00dZ<00?/D003h7@00c;<000262000=D8000@L0008
8P00DTd0:9T00=^7003n1`00lc400;?00000NB8002@i00026P003RT005m405FW003UIP00o`000>a?
001j/P0006Ti000E;P000QT001Xb001_<@2A^000kd800?l2003PMP00?Z00001HB@002bD000<K000_
?`00PPl0b[P00?PO003k4`00dJ@000B;0000?4H000DM00088@00DDd0:9T00=^6003n1P00lSH00:Fm
0000M2X0010W000C;@00Ic/0Mk400>a>003o0000i6/004ZT0000FdL000`V00036`00;Sl0088?0<Zg
003h7@00nQH00<n[0000R0<003E3000470002R@005M:03jP003QL`00o`400>e9001n/`0006Tj000D
;@000QT001le001f9`2__`00m3000?d:003GT`005I800015BP001Ah000LP001@CP0WV@00g8<00?h5
003`?@00TkP0001^<`005c00008I000K<`00LR`0YKd00?<d003m2000f90001NC0000ATX000DN0007
8@00DDd0;9X00=in003o0`00kd<008Fe0000JST001@]00026@008CL007TR0;o3003f9`00o1000=6S
0000RP0003I3000470002bD005]8052V003VH`00o`000>MN001FZ00005a6000;9P000a/003A20029
0@3AY000o1000?HX002k`P0007LT000N=@000QT001H_001^<`2I^P00lSL00?h8003HT@004Y400010
B00011d000TS001GBP15XP00i6T00?l0003XG000F:P0001LAP002bD000@L000hA006S000e9/00?d;
003d<@00Xkd0001`;`006300008I000N=@0:ooooo`7o00000Oooool001?ooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`07ooooo`3o00205000>TD000HP00047000:3/007@Z082d
003WGP00o`800?<d0037_`0008P20017B`00228000<K000P=P00KC@0JZd00>A[003n1@00mBX00<^d
0009S@0004m>000:90000aX001`d001Z>@1OZP00hW800?h6003f9P00cJl000j?0000DDd000/U0002
6P0073<006Ti05nZ003RLP00oPH00?HW003</@002Xh0001?CP002R@000<J000N=@00K3D0JJd00>AZ
003o1000m2h00<Rk0000R@0004M;00088P000a/002@i001b;@20/`00j5/00?l1003a>`00^L800021
4@00>D@000HO00047@00<40007/M0::l003^A`00o`000>]@002A^00007HV000Y?00011`000LQ0013
B@00R0<0b;d00?@^003n1000hfh0062[0000J3X001Xb00026P003BL005I:02BG003EV@00nQH00?/C
003GU000:YX0001HB@003RP0008I000I<@00J3/0GZX00>=^003n1000m3000<K00000Q@T003e70006
7`0011d00350001m6P2^_`00l3h00?l1003XGP00M[40001^<`007SD000<J000;9P0@MBH0eIX00?XE
003k5000eIT002:G0000ED/000`V00036P007cD006lb07Zb003YFP00o`000>m4002Q_00007TQ000Z
?0000a`000PR001:C@0:SP00cZ`00?PO003l3@00fX/003:L0000FDP000hX00026P006c<006`f07:`
003WGP00o`000>m3002Q_00007PR000Y?0000a/000TR001?CP0BT@00dJ@00?TI003k4P00eYL0026F
0000E4`000XU00036P0093T007@Y09Bi003]B@00o`000>UI001g/@0006de000K<`000QT000lY001L
A`0mX000gH000?h8003e:P00b;d000252P00>D@000DN00067`00?dP008T10<^d003g8P00o@`00=V<
000/VP0005I;000;9P000aX002<h001d:@2G^P00kTD00?l0003WH@00J:d0001X>`005Rl0008I000C
;@00Hd00FZT00>AZ003o0P00l3l00:>l0000Mb@002Dj00036P002bD005I;02bJ003JR`00o@/00?HV
0039^P0008D:000g@`001Ad000LP0017B`0;SP00dJD00?XH003j5P00dZ8000j?0000BD`000LP0004
7@00=d<008D:0<Vi003g9000o@`00=R?000TV00005=<003c00098`000a/002dn001n6030``00m2l0
0?h7003MPP00=9d0001GBP002bD000<K000W>`00NR00/L000?<e003n1@00gg/003bP0000FDP000`V
00036P009CX007PR0:fo003b=`00oP@00=mj000mX00005U8000<9P000aX002Hj001j802b`000lc@0
0?h6003MP000=Id0001GBP002bD000<K000[?@00OAT0`/@00?D/003m2@00fX/002JH0000DTd000TR
00047000<d4008@<0<Zg003h8@00o1000=BL000AT00004M;00067`001Ah0045800V=003BX`00na@0
0?TM003</`0008H8000e@`0011`000PR001BC@0XV@00fhL00?h7003c<@00/l00001i8P0093T0008J
000>:@00Gd@0EJL00>EV003o0000k4l007Zb0000JCT001D^00026@006S8006la096h003_@P00o`80
0>1f000nX00005Q9000;9@000a/002lo00223`3:^000n1l00?/C003AY00018/0000lAP001Ad000PQ
001AC@0WV@00fhH00?h6003b=P00YKd0001d:P0042L001<]001W>`1g/@00k4h00?l0003TJ`00Bj@0
001KA`0032H000<K000^?`00PPl0b[L00?PM003j5P00cj/000280`00=D<000@L000:9000EdX0?Z00
0>5c003o0@00kDT007jc0000JCX001@]00026@007SD007HW0:no003d<000o@X00=NC000ETP0004E:
00057P001b00051>02NI003LP`00oPD00?0m002C^00006hc000G<0000QT001/c001b;02U_@00lc@0
0?d8003HT0005i<00016BP001Ah000LQ001AC@0/VP00gWh00?l3003_@`00QKD0001Z>@0052d0008I
000Q=`00NB80_l<00?HW003l4000dZ<0002:0000=T<000@L000;9@00FdP0CjH00>IS003o0000ieh0
05JX0000G4H000/V00036`00=48008T10=6T003l4000mRP00;_20000Mb@001he00026@005Rl006hc
09Vj003b=`00oPP00=RA000BT@00041800047@002B<005M:04BR003TJ@00o`000>QL001HZ00005a6
000;9@0011`003Q400J<003DV`00o@/00?@a002T_@00070_000H<0000QT001he00[ooooo0Ol00001
ooooo`004oooool01?l0003oooooooooool00007ooooo`Co00001_ooool0o`00P1@003Y500068000
11`002Pk001d:P20]000ieh00?l2003c=000akl000280P00Ad/000PR00036`0083H006dd06Z]003T
J`00oPD00?DZ003;]0002Hh0001?CP002R@000<J000L=000JST0GjX00>9b003n1P00mRH00<f_000>
S`00055=000;9@000QX001`c001Y>@1NZP00hW800?h6003f9`00c;4000Z>0000Cdh000XT00036P00
7SD006`e06V]003TJP00o`@00?@^0038^`0008T00017B`00228000<K000T>@00LRd0Ok<00>QK003o
0@00lC/00;W20000PA4003U400067`0011d002lo001k7@2R_000kTL00?l0003[D000TKP0001f9P00
:C`000@L00078@00@dT008P30<Rm003d;P00oP@00>=^001PZ`0006Pj000J<P000QX000dW001FB`0T
U`00eIT00?XF003k4`00ei@002ZJ0000F4T000hX00026@006C4006Pk05jZ003SKP00oP@00?@`0036
`00008D9000mA`001Ql000@M000a@000OAX0[[l00?0n003o0@00j5h007Ja0000KS<001he00036P00
2bH047DV0=FJ003j5@00na@00=FI000RU`0005E;000<9P000aX001le001_<P1j/P00jEX00?l0003_
A000XK`0001i8@00:S`000<L00088P00BTd02Xh00<j/003h7`00o0d00=Z:000bW00005U8000>:000
0QX001/c001/=P1b/000ieh00?l0003_@`00XK`0001h8P00:C`000<K00098P00Cdh04Y400=6T003i
6@00na800=JG000QUP0005A<000:9@000aX002<h001d:@2C^@00kDT00?l0003YF@00N;40001]=@00
6c<0008I000?:@00G4L0?:000=f1003n2000mBT00<Rm0000Q@X003U400057P001Ql003m800290@3;
]000mb800?d<003IS000;9X0001FB`002bH000<J000S>000M2T0UkX00>i5003o0000if4006V]0000
J3/001H_00026@004bd006=005ZY003TJP00o`800?0n002S_00007LT000U>P000aX000/U001FB`0/
VP00fX/00?d;003f9P00bKX000252P00=d<000DM00078000Ad/02hh00=6U003j6000nQH00=:R000>
S`0004U<0007800011d003M300252P39^@00mb@00?d<003HS`0099P0001CC000l`002B<000<K000]
?P00OQP0`<<00?@_003n1`00gH8003BM0000EdX000/U00036`009c/007XP0;70003b=@00oPD00=mk
000mX00005U8000<9P000aX002Dj001h8P2]_`00lSL00?h4003ONP00?J00001IB00032H000<J000V
>P00NR00//000?<d003n1P00gH0003FM0000EdX000/U00036`00:cd007dI0<;4003e;000o@T00=Z;
000VV000059=00098P0011`003=10024303:^000n2400?`@003DW0004I000017B`001Ql000DN0011
B009S@00dZ<00?/D003i7@00c;<000262000=D<000@L00088P00DTd0:9T00=^7003n1`00lc400;?0
0000NB8002@i00026P003RT005m405FW003UIP00o`000>a>001j/P0006Ti000E;P000QT001Xb001_
<@2A^000kd800?l2003QMP00?Z00001HB@002bD000<K000_?`00PPl0b[P00?PO003k4`00dJ@000B;
0000?4H000DM00088@00DDd09iT00=^6003n1P00lSH00:Fm0000M2X0010W000C;@00Ic/0Mk400>a>
003o0000i6/004^T0000FdL000`V00036`00;Sl0088?0<Zg003h7@00nQH00<n[0000R0<003E30004
70002R@005M:03jP003QL`00o`400>e9001n/`0006Tj000D;@000QT001he001e9`2__`00m3000?d:
003GT`005I800015BP001Ah000LP001@CP0WV@00g8<00?h5003`?@00TkP0001^<`005c00008I000K
<`00LR`0YKd00?<d003m2000f90001NC0000ATX000DN00078@00DDd0;9X00=in003o0`00kd<008Fe
0000JST001@]00026@008CL007TR0;o3003f9`00o1000=:S0000RP0003I3000470002bD005]804nV
003VH`00o`000>MN001FZ00005a6000;9P000a/003A200290@3AY000o1000?HX002k`P0007LT000N
=@000QT001H_001^<`2I^P00lSL00?h8003HT@004Y400010B00011d000TS001GBP14XP00i6T00?l0
003XG000F:P0001LAP002bD000@L000hA006S000e9/00?d;003d<@00Y;d0001`;`006300008I000N
=@07ooooo`Co00000Oooool001?ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`07ooooo`3o00205000>TD000HP00047000:3/007@Z082d003WGP00o`800?<d0037_`0008P20017
B`00228000<K000P=P00KC@0JZd00>A[003n1@00mBX00<^d0009SP0004m>000:90000aX001`d001Z
>@1OZP00hW800?h6003f9P00cJl000j?0000DDd000/U00026P0073<006Ti05jZ003RLP00oPH00?HW
003</@002Xh0001?CP002R@000<J000N=@00K3D0JJd00>AZ003o1000m2h00<Rk0000R@0004M;0008
8P000a/002@i001b;@1o/`00j5/00?l1003a>`00^L8000214@00>D@000HO00047@00;cl007/M0::l
003^A`00o`000>]@002A^00007HV000Y?00011`000LQ0013B@00R0<0b;d00?@^003n1000hfh0062[
0000J3X001Xb00026P003BL005I;02BG003EV@00nQH00?/C003GU000:YX0001HB@003RP0008I000I
<@00J3/0GZX00>=^003n1000m3000<K00000Q@T003e700067`0011d00350001m6P2^_`00l3h00?l1
003XGP00M[40001^<`007SD000<J000;9P0@MBH0eIX00?XE003k5000eIT002:G0000ED/000`V0003
6P007cD006lb07Zb003YFP00o`000>m4002Q_00007TQ000Z?0000a`000PR001:C@0:SP00cZ`00?PO
003l3@00fXX003:L0000FDP000hX00026P006c<006`f07:`003WGP00o`000>m3002Q_00007PR000Y
?0000a/000TR001?CP0BT@00dJ@00?TI003k4P00eYL0026F0000E4`000XU00036P008cP007@Y09>i
003]B@00o`000>UI001h/@0006de000K<`000QT000lY001LA`0lX000gH400?h8003e:@00b;d00025
2P00>D@000DN00067`00?dP008T10<^d003g8P00o@`00=V<000/VP0005I;000;9P000aX002<h001d
:@2G^P00kTD00?l0003WH@00JJd0001X>`005Rl0008I000C;@00Hd00FZT00>AZ003o0P00l3h00:>l
0000Mb@002Dj00036P002bD005I;02bJ003JR`00o@/00?HV0039^P0008D:000g@`001Ad000LP0017
B`0;SP00dJD00?XH003j5P00dZ8000j?0000BD`000LP00047@00=d<008D:0<Vi003g9000o@`00=R?
000TV00005=<003c00098`000a/002dn001n6030``00m2l00?h7003MPP00=9d0001GBP002bD000<K
000W>`00NR00/L000?8e003n1@00gg/003fP0000FDP000`V00036P009CX007PR0:fo003b=`00oP@0
0=mj000mX00005U8000<9P000aX002Hj001j802b`000lc@00?h6003MP000=Id0001GBP002bD000<K
000[?@00OAT0`/@00?D/003m2@00fX/002JH0000DTd000TR00047000<d4008@<0<Zh003h8@00o100
0=BL000AT00004M;00067`001Ah0045800V=003BX`00na@00?TM003</`0008H8000e@`0011`000PR
001BC@0XV@00fhL00?h7003c<@00/l00001i8P0093T0008J000>:@00Gd@0EJL00>EV003o0000k4h0
07Zb0000JCT001D^00026@006S8006la096h003_@P00o`800>5f000nX00005Q9000;9@000a/002lo
00223`3:^000n1l00?/C003AY00018/0000lAP001Ad000PQ001AC@0WV@00fhH00?h6003b=P00YKd0
001d:P0042L001<]001W>`1g/@00k4h00?l0003TJ`00Bj@0001KA`0032H000<K000^?`00PPl0b[L0
0?PM003j5P00cj/000280`00=D<000@L000:9000EdX0?Z000>5c003o0@00kDT007jc0000JCX001@]
00026@007SD007DW0:no003d<000o@X00=NC000ETP0004E:00057P001b00051>02NI003LP`00oPD0
0?0m002C^00006hc000G<0000QT001/c001b;02U_@00lc@00?d8003HT0005i<00016BP001Ah000LQ
001AC@0/VP00gWh00?l3003_@`00QKD0001Z>@0052d0008I000Q=`00NB80_l<00?HW003l4000dZ<0
002:0000=T<000@L000;9@00FdP0CjH00>IS003o0000ieh005JX0000G4H000/V00036`00=48008T1
0=6T003l4000mRP00;_20000Mb@001he00026@005Rl006hc09Vj003b=`00oPP00=RA000BT@000418
00047@002B<005M:04BR003TJ@00o`000>QL001HZ00005a6000;9@0011`003Q400J<003DV`00o@/0
0?@a002T_@00070_000H<0000QT001he00[ooooo0Ol00001ooooo`004oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00Oooooo0?l0080D000jA@001R0000@L000X>`00M2X0P;@0
0>MN003o0P00lc@00<No0000R08004M;00088P000a/0020f001]=01Z[@00i6/00?h5003e:P00bk@0
00V=0000Cdh000XT00036P0073@006Xi05nZ003RLP00oPH00?HV003=[`003Xl0001AC@002bD0008J
000L<`00JCT0GjX00>9b003n1P00mRL00<ba000:SP0004m>000:90000aX001he001/=@1Y[@00i6X0
0?l4003d;P00b;/000290000Ad/000PR00036`0093T0078]082c003XF`00o`400?4k002i`P00084A
000iA0001Ql000@M000`@000Nad0X[`00>i7003o0000je00096h0000MRH002Tl000470001b4004=9
00280`38_@00m2h00?h4003SKP00H:/0001X>P006S80008J000=9`00ETX099L00=FI003j5P00na<0
0=ND000ZVP0005Q9000>:0000QT001Ta001X>`1NZP00hfh00?h4003d<000a/0000252@00?DL000HO
00047@00<D0007dJ0:jo003`?P00o`400>QN001f/@0006hc000N=@000aX000/V011e9P3EVP00nQD0
0?/D003EV@008YL0001EB`0032H000<J000O=@00Kc80N[800>UJ003o0000kd@00:6l0000NB4002Xl
00037000228004Y=00Z>003>[000n1l00?`=003JR`00<Y`0001IB0003RP0008J000K<`00K3H0L[00
0>MN003o0000kd<00:6l0000N28002Tl00036`002B8004m>01:A003AY000nAT00?/B003FU`008IH0
001DC0002RD000<J000T>@00M2T0U;T00>e9003o0000jET007Na0000KCD001/c00026@003bT005a7
03fP003MP000oPP00?DZ0038_@0008D:000iA0001Ah000HO000oB000R@40bk@00?LR003m3000fH`0
02bJ0000ET/000/V00036P008cP007@Y09Nj003^A@00o`000>MQ001X[@0006Pk000F;`000QT001<]
001S@01JZ@00i6X00?l2003`?`00Xk`0001g90009CX000<J000;9@00ET/0;9X00=Z;003m2`00mRH0
0<Vj0000Q@X003M300057@001b0004M;00^>003AY@00nQP00?XF003BXP003Xl00019C0001b0000@M
000g@`00Q@X0bKT00?LT003m3000f8l002BH0000Dd`00?<000TS00036`00;Ch007hH0<33003d;`00
oPL00=f2000dW@0005M:000;9@000a/002Lk001j802a`000lcD00?h5003ON`00?:00001IB00032H0
00<J000U>P00N280[Kl00?8g003n1000ggX003fP0000FDP000`V00036P009SX007XP0;;0003c=000
oPH00=f0000eW@0005M:000;9@000a/002/m001m6@32a000mB`00?d9003JR`009YP0001BC@002B80
00@L000c@@00Q0`0b[L00?PQ003l4000e9`0016@0000Ad/000HO00057P00@DP02Hd00=:S003k5000
nAd00<bc0000QPP003E3000470002280059=02RI003KQ`00oPL00?<a002c`00007TR000T>@000QX0
00hY001OA01EY`00iFH00?l0003/C`00N[80001Y>@005Bh0008I000J<P00Kc40TKP00>m2003o0P00
h7H003jP0000F4T000/U00036`00;cl0088?0<Zh003h7`00na<00=6T0004R`0003a600057@002240
055=02NI003KQP00oPH00?8f002U_@0007@Z000@9`004bd006Lk07Na003/CP00o`000>A[001;Y000
05]7000<9P000a/002ho00223`3:]`00n1d00?XF003?Z`0008P3000e@`0011`000XT001GBP0nX000
hG<00?l1003]B@00O[<0001Y>P0052d0008I000N=@00MRL0[kl00?@`003m2P00ei<001FB0000ADX0
00DN00078000D4h09iT00=b3003n1@00l3d009>h0000KS<001L`00026@006c<0078/0:Fm003c=000
o@P00=R@000GT`0004I:00057P001b40055=02bJ003NOP00o`<00>m30025]@0006Xi000D;@000QT0
024g001i8P2o``00mRL00?`@003BX`0008X0000f@`0011`000/U001KB01?YP00iV<00?l0003WGP00
EZP0001LAP002bH000<K000d@P00R@40dJ@00?`@003f:000^l80001g90007SD0008I000F;`00KS<0
VKX00?8g003n2000f94001:A0000@4P000@M00098`00EdX0A:800>AY003o0000j5`005RX0000G4H0
00/U00047000>4@01X`00=BK003m2`00m3400:Bm0000L2l001P`00026@007SD02_ooool1o`00007o
oooo000Dooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`3o00205000>TD000HP00047000
:3/007@Z086d003XGP00o`800?<d0037_`0008P20017B`00228000<K000P=P00KC@0JZd00>A[003n
1@00mBX00<^d0009S@0004m>000:90000aX001`d001Z>@1OZP00hW800?h6003f9P00cJl000j?0000
DDd000/U00026P0073<006Ti05nZ003RL@00oPH00?HW003</P002Xh0001?CP002R@000<J000N=@00
K3D0JJd00>AZ003o1000m2h00<Rk0000R@0004M;00088P000a/002@i001b;@20/`00j5/00?l1003a
>`00^L8000214@00>D@000HO00047@00<40007/M0:>l003^A`00o`000>]@002A^00007HV000Y?000
11`000LQ0013B@00R0<0b;`00?@^003n1000hfh0062[0000J3X001Xb00026P003BL005I:02BH003E
V@00nQH00?/C003GU000:YX0001HB@003RP0008I000I<@00J3/0GjX00>=^003n1000m3000<K00000
Q@T003e700067`0011d00350001m6P2^_`00l3h00?l1003WGP00M[40001^<`007SD000<J000;9P0@
MBH0eIX00?XE003k5000eIT002:G0000ED/000`V00036P007cD006lb07Zb003YFP00o`000>m4002Q
_00007TQ000Z?0000a`000PR001;C@0:SP00cZ`00?PO003l3@00fX/003:L0000FDT000hX00026P00
6c<006`f07:`003WGP00o`000>m3002Q_00007PR000Y?0000a/000TS001?CP0BT@00dJ@00?TI003k
4P00eYL0026F0000Dd`000XU00036P0093T007@Y09Bi003]B@00o`000>UI001g/@0006`e000K<`00
0QT000lY001LA`0mX000gH000?h8003e:P00b;d000252P00>D@000DN00067`00?dP008T10<^c003g
8P00o@`00=V<000/VP0005I;000;9P000aX002<h001e:@2G^P00kTD00?l0003WH@00J:d0001X>`00
5Rl0008I000C;@00Hd00FZT00>AZ003o0P00l3l00:>l0000Mb@002Dj00036P002bD005I;02bJ003J
RP00o@/00?HV0039^P0008D:000g@`001Ad000LP0017B`0;SP00dJD00?XH003j5P00dZ8000j?0000
BD`000LP00047@00=d<008D:0<Vi003g9000o@`00=R?000TV00005==003c00098`000a/002dn001n
6030``00m2l00?h7003MPP00=9d0001GBP002bD000<K000W>`00NR00//000?<e003n1@00gg/003bP
0000FDP000`V00036P009CX007PR0:fo003b=`00oP@00=mk000mX00005U9000<9P000aX002Hj001j
802c`000lc<00?h6003MP000=Id0001GBP002bD000<K000[?@00OAT0`/@00?D/003m2@00fX/002JH
0000DTd000TR00047000<d4008@<0<Zg003h8@00o1000=BL000AT00004M;00067`001Ah0045800V=
003BX`00na@00?PM003</`0008H8000e@P0011`000PR001BC@0XV@00fhL00?h7003c<@00/l00001i
8P0093T0008J000>:@00Gd@0EJL00>EV003o0000k4l007Zb0000JCT001D^00026@006S8006la096h
003_@P00o`800>1f000nX00005Q9000;9@000a/002lo00223`3:^000n1l00?/C003AY00018/0000l
AP001Ad000PQ001AC@0XV@00fhH00?h6003b=P00YKd0001d:P0042L001<]001W>`1g/@00k4h00?l0
003TJ`00BZ@0001KA`0032H000<K000^?`00PPl0b[L00?PM003j5P00cj/000280`00=D<000@L000:
9000EdX0?Z000>5c003o0@00kDT007jc0000JCX001@]00026@007cD007HW0:no003d<000o@X00=NC
000ETP0004E:00057P001b00051>02NI003LP`00oPD00?0m002C^00006hc000G<0000QT001/c001b
;02U_@00lc@00?d8003HT0005i<00016BP001Ah000LQ001AC@0/VP00gWh00?l3003_@`00QKD0001Z
>@0052d0008I000Q=`00NB80_l<00?HW003l4000dJ<0002:0000=T<000@L000;9@00FdP0D:H00>IS
003o0000ieh005JX0000G4H000/V00036`00=48008T10=6T003l4000mRP00;_20000Mb@001he0002
6@005Rl006hc09Vj003b=`00oPP00=RA000BT@00041800047@002B<005M:04FR003TJ@00o`000>QL
001HZ00005a6000;9@0011`003Q400J<003DV`00o@/00?@a002S_@00070_000H<0000QT001he00[o
oooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o00205000>TD000HP00047000
:3/007@Z086d003XGP00o`800?<d0037_`0008P20017B`00228000<K000P=P00KC@0JZh00>A[003n
1@00mBX00<^d0009S@0004m>000:90000aX001`d001Z>01OZP00hW800?h6003f9P00cJl000j?0000
D4d000/U00026P0073<006Ti05nZ003RL@00oPH00?HX003</P002Xh0001?CP002R@000<J000N=@00
K3D0JZd00>AZ003o1000m2h00<Rk0000R@0004M;00088P000a/002@i001b;@20/`00j5/00?l1003a
>`00^L8000214@00>D@000HO00047@00<40007/M0:>l003^AP00o`000>]@002A^00007HV000Y?000
11`000LQ0013B@00R0<0b;`00?@^003n1000hfh0062[0000J3X001Xb00026P003BL005I:02BH003E
V@00nQH00?/C003GU000:YX0001HB@003RP0008I000I<@00J3/0GjX00>=]003o1000m3000<K00000
Q@T003e600067`0011d00350001m6P2^_`00l3h00?l1003WGP00M[40001^<`007SD000<J000<9P0A
MRH0eIX00?XE003k5@00eIT0026G0000ED/000`V00036P007cD006lb07^b003YFP00o`000>m4002Q
_00007TR000Z?0000a`000PR001;C@0:SP00cZ`00?PO003l3@00fX/003:L0000FDT000hX00026P00
6c<006`f07:`003XGP00o`000>m3002Q_00007PR000Y?0000a/000TS001?CP0BT@00dJ<00?TI003k
4P00eYL0026F0000Dd`000XU00036P0093T007@Y09Bi003]B@00o`000>UI001g/@0006`e000K<`00
0QT000lY001LA`0mX000gH000?h8003e:P00b;d000242P00>D@000DN00067`00?dP008T10<^c003g
8P00o@`00=V<000/VP0005I;000;9P000aX002<h001e:@2H^P00kTD00?l0003WH@00J:d0001W>`00
5Rl0008I000C;@00I400FZT00>AZ003o0P00l3l00:>l0000Mb@002Dj00036P002bD005I;02bJ003J
RP00o@/00?HV0039^`0008D:000g@`001Ad000LP0017B`0<SP00dJD00?XH003j5P00dZ8000j?0000
BD`000LP00047@00=d<008D:0<Vi003g9000o0`00=R@000TV00005==003c00098`000a/002dn001n
6030``00m2h00?h7003LP`00=9d0001GBP002bD000<K000W>`00NQl0//000?<e003n1@00gg`003bP
0000FDP000`V00036P009CX007PR0:fo003b=P00oPD00=mk000mX00005U9000<9P000aX002Hj001j
802c`000lc<00?h6003MP000=Id0001GBP002bD000<K000[?@00OQT0`/@00?D/003m2@00fX/002JH
0000DTd000TR00047000<d4008@;0<Zg003h8@00o1400=BL000@T00004M;00067`001Ah0045900V=
003BX`00na@00?PM003</`0008H8000e@P0011`000PR001BC@0YV@00fhL00?h7003c<@00/l00001i
8P0093T0008J000>:@00Gd@0EJP00>EV003o0000k4l007Zb0000JCT001D^00026@006S8006la096h
003_@@00o`800>1f000nX00005Q9000;9@000a/002lo00233`3:^000n1l00?/C003AY@0018/0000l
AP0011d000PQ001AC@0XV@00fhH00?h6003b=P00YKd0001d:P0042L001<]001X>`1g/@00k4h00?l0
003TJ`00BZ@0001KA`0032H000<K000^?`00PPl0b[H00?TM003j5P00cj/000281000=D8000@L000:
9000EdX0?Z000>5c003o0@00kDT007jc0000JCX001@]00026@007cD007HW0:no003d<000o@X00=NC
000ETP0004E:00057P001b00051>02NI003LP`00oPD00?0m002C^00006hc000G<0000QT001/c001b
;02U_@00lc<00?d8003HT0005Y<00015BP001Ah000LQ001AC@0/VP00gWh00?l3003_A000QKD0001Y
>@004bd0008I000Q=`00NB40_l<00?HW003l4000dJ<0002:0000=T<000@L000;9@00FdP0D:H00>IS
003o0000iel005JX0000G4H000/V00036`00=48008T10=6T003l4000mRP00;_20000MbD001he0002
6@005Rl006hc09Vj003b=`00oPP00=RA000BT@00041800047@002B<005M:04FR003TJ@00o`000>QL
001HZ00005a6000;9@0011`003Q400J<003DV`00o@/00?<a002S_@00070`000H<0000QT001he00[o
oooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o00205000>DD000HP00047000
:3/007@Z086d003XG@00o`800?<d0037_`0008P20017B`00228000<K000P=P00KC@0JZh00>A[003n
1@00mBX00<^d0009S@0004m>000:90000aX001dd001Z>01OZP00hW800?h6003f9P00cJl000j?0000
D4d000/U00036P0073@006Ti05nZ003RL@00oPH00?HX003</P002Xh0001?CP002R@000<J000N=@00
K3D0JZd00>AY003o1000m2h00<Rk0000R@0004I;00088P000a/002@i001b;@20]000j5/00?l1003a
?000^L8000214@00>D@000HO00047@00<40007/M0:>l003^AP00o`000>]@002A^00007HV000Y?000
11`000LQ0013B@00R0<0b;`00?@^003n1000hfh0062[0000J3X001Xb00026P003BL005I:02BH003E
V@00nQH00?/C003GU000:YX0001HB@003RP0008I000I<@00J3/0GjX00>=]003o1000m3000<K10000
Q@T003e600067`0011d00350001m6@2^_`00l3h00?l1003WGP00MK40001^<`007SD0008J000<9P0A
MRH0eIX00?XE003k5@00eIT0026G0000ED/000/V00036P007cD006lb07^b003YFP00o`000>m4002P
_00007TR000Z?0000a`000PR001;C@0:SP00cZ`00?PO003l3@00fX/003:L0000FDT000hX00026P00
6c<006`f07>`003XGP00o`000>m3002Q_00007PR000Y?0000a/000TS001?CP0BT@00dJ<00?TI003k
4P00eYL0022F0000Dd`000XU00036P0093T007@Y09Bi003]B@00o`000>UJ001g/@0006`e000K<`00
0QT000lY001LA`0mX000gH000?h8003e:P00akd000242`00>4@000DN00067`00@4P008T00<^c003g
8P00o0`00=V=000/VP0005I;000;9P000aX002<h001e:@2H^P00kTD00?l0003WH@00J:d0001W>`00
5Rl0008I000C;@00I3l0FjT00>AY003o0@00l3l00::l0000MbD002Dj00036P002bD005I;02fK003J
RP00o@/00?HV0038^`0008@;000g@`001Ad000LP0017B`0<SP00dJD00?XG003j5P00dZ<000j?0000
BD`000LP00047@00=d<008D:0<Vi003g9000o0`00=R@000TU`00059=003c00098`000a/002dn001n
6031a000m2h00?h7003LP`00=9d0001GBP002bD000<K000W>`00NQl0//000?<e003n1@00gg`003bP
0000FDT000`V00036P009CX007TR0:jo003b=P00oPD00=mk000lX00005U9000<9P000aX002Hj001j
802c`000lc<00?h6003MP000=Id0001GBP002bD000<K000[?@00OQT0`l@00?D/003m2@00fX/002JH
0000DTd000PR00047000<d8008@;0<Zg003h8000na400=BL000@T00004M;00067`001Ah0049900V=
003BXP00na<00?PM003;/`0008H8000e@P0011`000PR001BC@0YV@00fhL00?h7003c<@00/l00001h
8P0093T0008J000>:@00Gd@0EZP00>EV003o0000k4l007Zb0000JCT001D^00026@006S8006la096h
003_@@00o`800>1f000mX00005Q:000;9@000a/002lo00233P3:^000n1l00?/C003AY@0018/0000l
AP0011d000PQ001AC@0XV@00g8D00?h6003b=P00Y;d0001d:P0042L001<]001X>`1h/@00k4h00?l0
003TJ`00BZ@0001KA`0032H000<K000^?`00PPl0b[H00?TM003j5P00cj/000271000=D8000@L000:
9000EdX0?Z000>5c003o0@00kDT007jc0000JCX001@]00026@007cD007HW0:no003d;`00o@X00=NC
000DTP0004E:00057P001b00051>02NI003LP`00oPD00?0m002B^00006hc000G<0000QT001/c001c
;02U_@00lc<00?d9003HT0005Y800015BP001Ah000LQ001AC@0]V`00gWh00?l3003_A000Q;D0001Y
>@004bd0008I000Q=`00NB40_l<00?HW003l4000dJ<000290000=T<000@L000;9@00FdL0D:H00>IS
003o0000iel005JX0000G4H000/V00036`00=48008T10=6T003l4000mRP00;[20000MbD001he0002
6@005Rl006hb09Vj003b=`00oPP00=RA000BT@00041800047@002B<005M:04FS003TJ@00o`000>QL
001GZ00005a6000;9@0011`003Q400J<003DV`00o@/00?<a002S_000070`000G<0000QT001he00[o
oooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1n00205000>DD000HP00047000
:3/007@Z086d003XG@00o`800?<d0037_`0008P20017B`00228000<K000P=`00KC@0Jjh00>A[003n
1000mBX00<^d0009S@0004m>000:90000aX001dd001Z>01PZ`00hW400?h6003f9`00cK0000f?0000
D4h000XU00036P0073@006Ti05nZ003RL@00oPH00?HX003</P002Xh0001?CP002R@000<J000N=@00
K3D0JZh00>AY003o1000m2l00<Rk0000R@0004I;00088P000a/002Di001b;020]000j5/00?l1003a
?000^<8000214P00>4@000HO00047@00<40007/M0:>m003^AP00o`000>]A002@^00007HV000Y?000
11`000LQ0013B@00R0<0b;`00?@^003n1000hfh005nZ0000J3X001Xb00026P003BL005M:02FH003E
V@00nQD00?/C003GU@00:IT0001HB@003RP0008I000I<@00J3/0GjX00>=]003o1000m3400<K10000
Q@T003e600067`0011d00350001m6@2__`00l3h00?l1003WGP00MK40001]<`007SD0008J000<9P0A
MRH0eIX00P3j5@00o`3EV@008IH0001EC0002bH000<J000O=@00Kc80Nk800>UI003o0000kT@00:2l
0000NB8002Xl00037000228004]=00^>003>Z`00n1l00?`=003JR`00<I`0001IB@003RP0008J000L
<`00K3D0Lk000>QM003o0000kd<00:2l0000N2<002Tl00036`002B<004m>01>A003BX`00nQT00?/B
003FV00089H0001CC0002RD000<J000T>@00MBT0UKT00>e9003o0000jEX007Ja0000K3D001/c0002
6@003bT005a703fP003MP000oPP00?DZ0037_@0008@;000hA0001Ah000HO0010B000R@00c;<00?LR
003l3@00fHd002^J0000ET/000/V00036P008cP007DX09Rj003^A@00o`000>IQ001X[@0006Lk000F
;`000QT001<]001T?`1KZ@00i6T00?l1003`?`00X[`0001g9@009CX000<J000;9@00ET/0;I/00=Z:
003m2`00mRH00<Rk0000Q0/003M300047@001b0004M;00b>003AY@00nQL00?XF003BX`003Xl00018
C0001b0000@M000g@`00Q@T0bKT00?LT003l3@00f90002>G0000DTd000TS00036`00;Ch007hG0<74
003d;P00oPL00=b3000cW@0005M:000;9@000a/002Lk001j7`2b`000lc@00?h5003OO000?:00001I
B@0032H000<J000U>P00NB80[[l00?8f003n1@00gg/003bP0000FDT000`V00036P009cX007XP0;?0
003c<`00oPH00=f0000dW@0005M:000;9@000a/002/m001n6033a000mB/00?d:003JR`009IP0001B
C@00228000@L000c@P00Q0/0b[L00?PP003k4@00e9d0012@0000Ad/000HO00057P00@TT02Hd00=:R
003k4`00n1d00<^c0000QPP003E2000470002B80059=02VI003KQ`00oPL00?<b002b`00007PR000S
>0000QX000lY001OA01FZ000iFH00?l0003/C`00NK80001Y>@005Bh0008I000J<P00Kc40T[P00>m1
003o0P00h7H003fP0000F4X000XU00036`00;cl008<>0<Zg003h7`00na<00=6U0004R`0003a60004
7@002240055=02RI003LQ@00oPH00?8g002T_@0007@Z000@9`004bd006Pk07Ra003/CP00o`000>A[
001:Y00005]8000<9P00L`000a/002ho00233`3:]P00nAd00?XF003>Z`0008L4000e@P0011`000XT
001GBP0oX@00hG800?l1003]BP00OK<0001Y>P004bd0008I000O=@00MRL0/<000?@_003m2P00ei<0
01BB0000ADX000DN00078000D4h0:9T00=b3003n1000l3d009:h0000KS<001L`00026@006c<007</
0:Jm003c<`00o@T00=RA000FTP0004E:00057P001b40055=02fK003NO@00o`<00>m40024]@0006Ti
000C;@000QT0024g001i8@30``00mRL00?`@003AY00008T0000f@`0011`000/U001KA`1@YP00iV<0
0?l0003WG`00EZP0001LAP002bH000<K000d@P00R@00dJ@00?`@003f:000^/80001g9@007SD0008I
000F;`00KS80V[X00?8g003n2000f980016A0000@4P000@M00098`00EdX0AJ<00>AY003o0000j5`0
05NX0000G4L000/U00047000>4@01X`00=BK003m2`00lc400:>l0000L30001L`00026@007cD02_oo
ool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo07h0080D000iA@001Ql000@L000X
?000M2X0P[@00>QM003o0@00lc@00<K00000R0<004M;00088P000a/0024g001]=01[[P00i6/00?h4
003e:`00bk@000R=0000Cdh000XT00036P007C@006Xh062[003RL@00oPH00?HW003=/0003Hl0001@
CP002RD000<J000L=000JST0H:/00>9a003n1P00mRP00<bb0009S@0004m>000:90000aX001le001/
=@1[[P00i6T00?l3003d;`00b;`000290@00AT/000PR00036`009CT0078/086d003XFP00o`400?4l
002h`@00084B000hA0001Ql000@M000`@000Nad0Y;d00>i6003o0000je40092h0000MRH002Tl0004
70001b4004=900280`38_000m2h00?h4003SKP00GjX0001X>P006S80008I000=9`00EdX09IP00=FH
003j5@00na<00=JE000YV@0005Q:000>:0000QT001Ta001X>`1PZ`00hfd00?l4003d<@00a/400025
2P00?DH000HO00047@00<D0007dI0:no003`?P00o`400>MO001e/00006dd000N=@000QX000`V015f
9P3EV@020?XE003o0=FJ000QUP0005A<000;9P000aX001lf001_<@1l/P00jET00?l0003^A@00Wk`0
001h8P00:S`000<L00088P00Bdd02hh00<n[003h7`00o0d00=Z;000aW00005U9000>:0000QX001`c
001/=@1c/000j5d00?l0003_@`00X;`0001h8`00:3/000<K00098`00Cdh04i400=:S003j6@00na<0
0=FH000PUP0005=<000:90000aX002@i001e:@2E^@00kDP00?l0003YFP00M[40001/=@006c<0008I
000?:@00G4L0?Z000=f0003n2000mBX00<Nn0000Q0/003Q400057P001Ql004180029003</`00mb80
0?`=003IS@00:iX0001FB`002bD000<J000S>000MBP0VKX00>i5003o0000iV8006N]0000Ic/001H_
00026@004bd006@o05^Y003TJ@00o`400?0o002R_00007LU000U>@000aX000/U001FB`0]V`00fXX0
0?d:003f9`00b;/000242`00=T<000@M00078000B4/038l00=6T003j5`00nQH00=6S000=S`0004Q<
000780001Ad003M400252@39^000mb@00?`=003HT0008iL0001BC@002B<000<K000]?P00OQL0`L@0
0?@^003n1`00g8<003>M0000EdX000/U00036`00:3/007XO0;?0003c=000oPD00=il000kW`0005U9
000<9P000aX002Hj001i8P2^_`00lSH00?h5003ON`00?:00001IB@0032H000<J000W>P00NQl0]<40
0?<c003n1P00gH4003BM0000ETX000/U00036`00:cd007hH0<C4003e:`00o@X00=Z<000UV000059=
00088P0011`003A200242`3:]`00n2000?/A003DW@0049000016B`001Ql000DN0012B@0:SP00dZ80
0?/C003h7P00bk@000252000=D8000@L00098P00Ddd0:IT00=^7003n1`00lc800;;00000N28002<h
00026P003bT005m405JX003UI@00o`000>a?001i/P0006Tj000E;P000QT001Xb001_<@2B^000kd40
0?l2003PMP00?J00001HBP002RD000<K000`@000P`h0b[L00?PO003k5000dJD000>;0000?4H000@M
00088P00DDd0:IT00=b5003n1P00lSL00:Bm0000LbX0010W000C;@00J3/0N;800>a>003o0000hf`0
04VT0000FdP000/V001c00036`00;Sl008<>0<Zf003i7@00nQH00<j/0000Q`@003E2000470002R@0
05M:03nQ003RLP00o`400>e:001m/`0006Pj000C;@000QT001le001f9P2``000m2l00?d:003GT`00
59800015BP001Ah000LQ001@CP0XV@00g8800?h4003`?P00T[P0001]<`005c00008I000K<`00Lb`0
Y[d00?<c003m2@00f94001JB0000ADX000DN00078@00DDd0;I/00=im003o0`00kd@008>d0000JCT0
01<]00026@008CL007TQ0<33003f9P00o1000=6T0000R@0003E3000370002bD005]7056V003VHP00
o`000>MO001EY`0005a6000;9P000a/003E20029003AX`00o1000?HX002i`P0007LU000N=@000QT0
01L`001^<P2J^P00lSL00?h8003GTP004I000010B00011d000TS001GBP16X`00i6P00?l0003XG@00
EjP0001LA`002bD000@L000hA007S000eIX00?d;003c<P00X[`0001`<0005c00008I000O=@0:oooo
o`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0l000P1D003U400067`0011`002Tl
001d:@22]000j5d00?l1003c=@00a/0000280`00AT/000PR00036`008CL006dc06b^003TJP00oP@0
0?D[003;]@0028d0001?CP002R@000<J000M=000JSP0H:/00>9a003n1P00mRL00<f`000=S`00051>
000:9@000aX001`d001Z>01PZ`00hW000?h6003f:000c;<000V=0000Cdh000XT00036P007cD006`e
06^^003TJ@00o`<00?@_0038_00008T10016B`00228000<K000U>@00LR`0PK@00>UJ003o0@00lC`0
0;O10000PA8003Q400067`001Ad00310001l702T_@00kTH00?l0003[D@00SkP0001f9`00:3/000@L
00078@00A4X008P20<Rk003d;@00oP@00>=_001NZP0006Pk000I<P000QT000dW001GBP0UV000eIP0
0?XE003k5000eYD002VI0000F4X000hX00026@006C8006Pj062[003SK000o`@00?@a0036`@0008D:
000lAP001Ql000@M000a@000OAT0/<000?0m003o0@00iel007B`0000KC@001he00026P0032H04GHV
0=FI003k5@00nQD00=FJ000PUP0005A<000;9P000aX001lf001_<@1l/`00jET00?l0003^A@00Wk/0
001h8P00:C`000<K00088P00C4d02hh00<n[003h7`00o0d00=V<000aW00005U9000=:0000QX001`c
001/=@1d/000j5d00?l0003_A000Wk`0001h8`00:3/000<K00098`00Cdh04i400=:R003j6@00na<0
0=FH000OUP0005=<000:90000a/002@i001e:02E^@00kDP00?l0003XFP00M[40001/=@006c<0008I
000?:@00G4H0?Z000=eo003n2000mBX00<Nn0000Q0/003Q400057P001Ql004180029003</P00mb80
0?`=003IS@00:iX0001FB`002bD000<J000S>000MBP0VKX00>i4003o0000iV8006N]0000Ic`001H_
00026@0052d006@o05bY003TJ@00o`400?10002Q_00007LU000U>@000aX000/U001FB`0^V`00fXT0
0?d:003f9`00b;/000242`00=T<000@M00078000B4/03Hl00=6T0080nQL00?l0dJ<000f?0000B4`0
00LP00057@00=d@008D90<Zh003g9000o0d00=RA000SU`00059=00098`000a/002dn001n5`32a000
m2h00?h8003LQ000<Yd0001GBP002bD000<K000X>`00NQl0/l000?<d003n1@00gWd003^O0000FDT0
00`V00036P009SX007TQ0:no003b=P00oPD00=ml000kW`0005U9000<9P000aX002Lk001j7`2d`@00
lc<00?h6003MP@00=9d0001FBP002RD000<K000[?@00OQP0a<@00?D[003m2P00fH`002FH0000DTd0
00PR00047000=48008@:0<Zf003h8000na400=BM000?T00004I;00067`001Al0049900Z>003BXP00
na<00?PN003;]00008D9000d@P0011`000TS001CC00ZVP00fhH00?h7003c<P00/L00001h8`008cP0
008J000?:@00Gd@0EjP00>EU003o0000je0007Ra0000JCX001D^00026@006S80070`09>h003_@@00
o`<00>1g000lX00005Q:000:9@000a/0031000233P3:]`00n1h00?/D003AY@000h/0000kAP0011d0
00PR001AC@0YV@00g8D00?h6003b=`00Xk`0001c:`0042L001@]001X>`1i/P00k4d00?l0003SK000
BJ@0001JB0002bH000<K000_?`00P`h0bkH00?TL003j5P00cZ`000271@00=48000@L000:9000EdX0
?j400>9b003o0@00kDX007bc0000J3X001<]00026@007cH007HV0;70003d;`00o@X00=ND000DT@00
04A:00057P001b40051>02RI003MPP00oP@00?0n002A^00006dd000G<0000QT001/c001c:`2W_@00
lc<00?d9003HT@005I800015BP001Ah000LQ001AC@0^V`00gWd00?l3003^A000Pk@0001Y>@004bd0
008I000Q=`00NB40`L@00?HV003l4000dJ@000290000=D8000<L000;9@00FdL0DJH00>IR003o0000
iel005FW0000G4L000/U00036`00=D8008T00=:S003l3`00mRT00;W20000MbD001he00026@005c00
06hb09^j003b=P00o@P00=NB000AT00003m800047@002B<005M:04JS003UJ000o`000>QM001FZ000
05a7000;9@0011`003U400N=003EVP00o@/00?<b002R_000070`000G<0000QT00@007cD:ooooo`7o
00000Oooool001kooooo00?o0000ooooooooool01oooool0l000OaD003U400067`0011`002Tl001d
:@23]000j5`00?l1003c=@00a/0000280`00AT/000PR00036`008CL006hc06b^003TJP00oP@00?D[
003;]@0028d0001?CP002R@000<J000M=000JSP0HJ/00>9a003n1P00mRL00<b`000<S`00051>000:
90000aX001`d001Z>01QZ`00hW000?h6003f:000c;<000V=0000Cdh000XT00036P007cH006de06b^
003TJ000o`<00?@_0038_00008T10016BP00228000<K000U>@00Lb`0P[@00>UJ003o0000lC`00;O1
0000PA8003Q400067`001Ad00310001l702U_@00kTD00?l0003[D@00SkL0001f9`00:3/000@L0007
8@00A4X008P20<Rk003e;@00oPD00>9_001NZP0006Pk000I<P000QT000dW001GBP0VV000eIP00?XE
003k5000eYH002RI0000F4X000dX00026@006C8006Pj066[003SK000o`<00?<a0036`P0008D:000l
AP001Ql000@M000a@@00OQP0/<000?0m003o0@00iel007B`0000KC@001de00026P0032H04GHV0=FI
003k5000nQD00=FJ000PUP0005A<000;9@000aX001lf001_<@1m/`00jET00?l0003^A@00W[/0001h
8`00:C`000<K00088P00C4d038h00<nZ003h7P00o0h00=V<000`W00005U9000=:0000QX001`c001/
=@1d/000j5`00?l0003_A000Wk/0001h8`00:3/000<K00098`00Cdh059800=:R003j6000na<00=FH
000OUP0005=<000:90000a/002@i001e:02F^@00kTP00?l0003XF`00MK40001/=P006c<0008I000?
:@00G4H0?j400=io003n1`00mB/00<Nn0000Q0`003Q400057P001Ql004180029003</P00mb400?`=
003ISP00:YX0001FB`002bD000<J000T>@00MBP0V[X00>m4003o0000iV8006J/0000Ic`001H_0002
6@0052d006@o05bZ003TJ000o`400?10002P_00007LU000U>@000aX000/U001FB`0^V`00fXT00?d:
003f9`00b;`000243000=T<000@M00078000B4`03Hl00=6T0080nQL00?l0dJ@000f?0000B4/000LP
00057@00>4@008D80<Zh003g8`00o0d00=RA000RU`00059=00098`000a`002hn001o5`33a000m2d0
0?h8003LQ000<Y`0001GBP002bD000<K000X>`00Nah0]<400?<d003n1@00gWd003ZO0000FDT000`V
00036P009SX007TQ0;30003b=@00oPD00=ml000kW`0005U9000<9P000aX002Lk001j7`2e`@00lc80
0?h6003MP@00<id0001FB`002RD000<K000[?@00OQP0a<@00?D[003m2P00fH`002BH0000DDd000PR
00047000=48008D:0<Zf003h8000na400=>N000?T00004I;00067`001Al0049900Z>003BX@00na<0
0?PN003;]00008D9000d@P0011`000TS001CC00ZVP00fhH00?h7003c<P00/L00001h8`008cP0008J
000?:@00H4<0EjP00>IU003o0000je0007Ra0000JCX001D^00026@006S80070`09>h003`@000o`<0
0>1g000lX00005M:000:90000a/0031000233@3:]`00n1h00?/D003@YP000h/0000kA@0011d000PR
001BC@0YV@00g8@00?h6003b=`00X[`0001c:`0042L001@]001X>P1j/P00k4d00?l1003SK000B:@0
001JB0002bH000<K000_?`00P`h0bkD00?TL003j5`00cZ`000271@00=48000@L000:9000F4X0@:40
0>9a003o0@00kDX007bb0000J3X001<]00026@007cH007HV0;70003d;`00o@X00=ND000CT@0004A:
00057P001b40051>02VI003MPP00oP@00?0n002@^00006dd000G<0000QT001`c001c:`2W_@00lc80
0?d9003HT@005I800014BP001Ah000LQ001AC@0^V`00gW`00?l3003^A@00P[@0001Y>@004bd0008I
000Q=`00NB00`L@00?HV003k4@00dJ@000290000=D8000<L000;9@00FdL0DZH00>IR003o0000if00
05BW0000G4L000/U00036`00=D8008T00=:S003l3`00mRT00;S20000MRH001he00026@005c0006lb
09^k003b=P00o@P00=NC000@T00003m700047@002B<005M:04NS003UJ000o`000>QM001FZ00005a7
000;9@0011`003U400N=003EVP00o@/00?<b002Q_000070`000G<0000QT00@007cH:ooooo`7o0000
0Oooool001kooooo00?o0000ooooooooool01oooool0l000OaD003Q400067`0011`002Tl001d:@24
]000j5`00?l1003b=@00a/4000281000AT/000PR00036`008CL006hc06f^003TJ@00oP@00?D[003;
]@001hd0001?CP002R@000<J000M=000JSP0HZ/00>9`003n1P00mRL00<ba000<SP00051>000:9000
0aX001dd001Z>01QZ`00hW000?h5003f:@00bk<000R=0000CTh000TT00036P007cH006dd06b^003U
J000o`<00?@`0038_@0008P20015BP00224000<K000U>P00Lb`0Pk@00>UI003o0000l3d00;K10000
P1<003Q400067`001Ad00350001l702V_@00kTD00?l0003[DP00S[L0001e9`00:3/000<L00078@00
A4X008P10<Rk003e;@00oPD00>9`001MZP0006Pk000I<@000QT000dX001GBP0VV000eYL00?XE003k
5000eYH002RI0000EdX000dX00026@006C8006Pj066[003SK000o`<00?<b0035`P0008@;000lAP00
1Ql000@M000b@@00OQP0/L000?0m003o0@00if0007>`0000KC@001dd00026P0032H04WHV0=FH003k
5000nQD00=BK000OUP0005A<000;9@000aX001lf001_<@1m/`00jEP00?l0003^AP00W[/0001h8`00
:C`000<K00088P00C4d038l00<nZ003h7P00o0h00=V<000`W00005U9000=:0000QX001`d001]=@1e
/@00j5`00?l0003_A000W[/0001h9000:3/000<K00098`00D4h059800=:R003j6000na<00=FI000O
UP0005=<000:90000a/002@i001e:02G^@00kTL00?l0003XF`00M;00001/=P006c<0008I000?:@00
G4H0?j400=io003n1`00mB/00<No0000Q0`003M400057P001Ql00458002:003</P00n2400?`=003I
SP00:YX0001EB`002bD000<J000T>@00MBL0V[X00>m4003o0@00iV<006J/0000Ic`001H_00026@00
52d006@o05fZ003UJ000o`400?10002P_00007HV000T>@000aX000/U001FBP0_V`00fhT00?d:003f
9`00b;`000243000=T<000@M00078000BD`03Hl00=6S0080nQL004T0dJ@000b?0000Ad/000LP0005
7@00>4@008H80<Zg003g8`00o0d00=RA000RU`00059=00098`000a`002ho001o5P33a000m2d00?h8
003LQ000<I`0001FBP002bD000<K000X>`00Nah0]L400?<c003n1@00gWd003ZO0000FDT000`V0003
6P009SX007TQ0;30003b=@00oPD00=il000jW`0005U9000<9P000aX002Lk001j7`2f`@00lc800?h6
003MPP00<id0001FB`002RD000<K000/?@00OQL0aL@00?DZ003m2P00fHd002BG0000DDd000PR0004
7000=48008D:0<Zf003h7`00na400=>N000?T00004I:008000HO0;D004=900^>003BX@00na<00?PN
003;]@0008D9000d@P0011`000TS001CC00[VP00g8D00?h7003c<`00/<00001h8`008cP0008J000?
:@00H4<0F:P00>IT003o0000je0007Na0000J3X001@^00026@006c<0070`09Bi003`@000o`<00>1h
000kW`0005M:000:90000a/0031000233@3:]P00n1h00?/D003@YP000XX0000kA@0011d000PR001B
C@0ZVP00g8@00?h6003b>000X[`0001c:`0042L001@]001X>P1j/P00k4d00?l1003SK@00B:<0001J
B0002bD000<K000_?`00P`d0bkD00?TL003j5`00cZd000271@00=48000@L000:9000F4X0@:400>9a
003o0@00kD/007^b0000J3/001<]00026@007cH007HV0;;0003d;P00o@/00=NE000CT@0004A:0005
7P001b40051=02VI003MP@00oP@00?0n002@^00006dd000F;`000QT001`c001c:`2X_P00lc800?d9
003GTP0059800014BP001Ah000LQ001BC@0_V`00gg`00?l3003^A@00P[@0001Y>P004bd0008I000R
=`00NR00`/@00?HV003k4@00dJD000290@00=D8000<K000;9@00FdL0DZL00>IQ003o0000if0005BW
0000G4L000/U00037000=D<008X00=:R003l3`00mRT00;S10000MRH001he00026@005c0006la09bk
003b=P00o@P00=NC000@T00003m700047@002B<005Q:04NS003UI`00o`000>QN001EY`0005]7000;
9@0011`003U500R=003EV@00o@X00?<b002P_00006la000G<0000QT001lf00[ooooo0Ol00001oooo
o`007_ooool00ol0003oooooooooo`07ooooo`3o001o5P00>4@000HO00047000:C`007DY08Be003X
F`00o`400?8f0036`@0008L40016BP00228000<K000Q=`00KS<0KJh00>AY003n1000mB`00<Zf0007
S00004i>000:90000aX001dd001[=`1RZ`00hW000?h6003f:000c;4000^>0000D4h000XT00036P00
7C@006Xh06:[003RK`00oPD00?HY003;]00028d0001>CP002B<000<J000O=P00KC@0KJh00>EW003o
0`00m3000<Rm0000R08004E:00088@000a/002Dj001c:`23]000jET00?l0003`?@00]L4000204`00
=d@000DO00057@00<D0007`K0:Jm003^A@00o`000>]B002=]`0007DW000X>`000a`000LQ0015BP00
R@40bKX00?D/003n1@00hW0005fZ0000Ic/001Ta00026@003BP005M:02NI003FU`00naD00?/D003F
UP009iT0001GBP003BP0008I000J<P00JCX0HZ/00>A[003o0`00lc800<G20000Q0/003]600067`00
1Ad00391001n602b`000lC`00?l1003WH000L[00001]=0007C@0008J000<9P0BMRH0eIP00?/D003j
5P00e9/001nF0000E4`000/U00036P0083H0070`07jc003YF000o`000>i6002M^`0007PS000Y?000
0a/000PR001=CP0<S`00cjX00?PN003l3P00fHd002nK0000F4T000dW00026P0073@006dd07Ja003X
G000o`000>i5002M^`0007LT000X>`000a/000TS001@CP0ETP00dZ400?XH003k4`00eIT001jE0000
Ddd000XT00036`009CT007DW09Nj003^A`00o`000>QL001d/00006/f000J<P000QT000lY001MAP10
X@00gWh00?h7003e:`00akl000243000=d<000DN00067`00@DP00HX00<ba003h8@00o0d00=V?000Y
V@0005E;000;9@000aX002@i001f9`2K^`00kd<00?l1003VH`00IJ`0001W?0005Rl0008I000D;@00
I3l0GZX00>EW003o0@00kd4009nk0000MRH002@i00036P002bH005M:02nK003KR000o@X00?HX0038
_@0008@<000e@`0011d000LP0019C00>S`00dZ<00?XF003j5`00dJD000b>0000Ad/000LP00057@00
>4@008H80<Zg003g8`00o0d00=RB000QU`00059=000l00098`000a`002ho001o5P34a000mBd00?h8
003LQ@00<I`0001FB`002bD000<K000X>`00Nah0]L400?<c003n1P00gWh003VO0000FDT000`V0003
6P009SX007TP0;70003c=@00oPD00=im000jW`0005Q9000<9P000a/002Lk001k7P2f`@00lc800?h6
003MPP00<Y`0001FB`002R@000<K000/?P00OQL0aL@00?DZ003m2P00fHd002>G0000DDd000PR0004
7000=D8008D90<^e003h7`00na800=>N000>S`0004E:0P001Ql0]@00@dT02hh00=:P003k4P00n1l0
0<^e0000Q@X003A2000470002B<005=<02^J003LQ@00oPL00?<c002__`0007PT000S>0000QX000lY
001P@`1HZ000iV@00?l0003[D@00Mk40001X>P0052h0008I000K<`00L300U;T00?10003o0`00h7P0
03^O0000EdX000XT00036`00<D0008<=0<Zf003h7P00na@00=2W0002RP0003Y500047@002280059=
02ZJ003LP`00oPD00?8h002Q_00007<[000@9`0052d006Pj07^b003/C000o`400>=]0017X`0005Y8
000;9@000a/002lo00233@3;]000nA`00?XG003>[@0008L6000d@P0011`000XT001HB@11X@00hW40
0?l1003]B`00Nk80001X>`004bd0008I000P=P00MbD0/l000?@^003m2`00eYD001:A0000@dT000DN
00078@00DDd0:YX00=f1003n1000l3l008ng0000KC@001H_00026@0073@007<[0:Vn003c<P00o@T0
0=NB000DTP0004A:00057P001b40059=02nK003OO000o`800>i50021]00006Tj000C;@000QT0028g
001j8033a000mRD00?/A003AY@0008T1000d@P000a/000/U001LA`1CY`00if400?l0003WH@00DjL0
001KA`002bD000<L000f@`00RP00dZ800?`?003e:@00]l40001f9P007CD0008I000G<000Kc40WK/0
0?8e003m2@00ei<000n@0000?dL000@M00098`00F4X0B:<00>EW003o0000ieh005FW0000FdL000/U
00047000>DD028d00=FI003m2P00lc<00:2l0000Kc4001L`00026@007cH02_ooool1o`00007ooooo
000Nooooo`03o`000?oooooooooo00Oooooo05l007lF000hA0001Ql000@L000Z?000MBP0QKD00>QK
003o0@00lSH00<K20000Q`D004E:00088P000a/0024g001^<P1^[`00i6T00?h4003e;000b[H000J<
0000CTh000XT00036P007SD006/g06>/003RK`00oPH00?HX003</P002hh0001?CP002R@000<J000M
=000JSL0Hj/00>=_003n1@00mBT00<^d0007S@0004i>00098`000aX001lf001]=01^[`00iFL00?l3
003d<000akd000280`00A4X000PQ00036`009SX007<[08Be003YF000o`000?0n002e`@00080D000g
@`001Ah000DM000a@000O1/0Ykd00>m4003o0000je<008fg0000MBP002Lk000370001b4004E:0029
0@39^P00mB`00?h5003RL000G:T0001W>`006C40008I000=:000EdX09iT00=JF00020?/D003J0=JG
000WV00005M:000=9`000QT001Xb001Y>P1SZ`00i6/00?l3003c<P00aL<000243000>dH000HO0005
7@00<T4007hG0;?0003a?000o`400>MP001b/00006de000M=0000QX000`V019g9P3FU`00na@00?XF
003DW0007YD0001DC0002bD000<J000P=P00L300Ok<00>UG003o0000kTH009bk0000N2@002Pl0003
6`00228004e>00f?003?Z@00n1d00?`>003IS@00;Y/0001HB@003BL0008J000L=000KC@0M[400>QK
003o0000kTD009fk0000Mb@002Lk00036`002B<0051>01FB003BX@00nQP00?/D003EVP007ID0001B
C@002R@000<K000U>@00MRL0V;X00>i7003o0000j5`007>`0000JcH001Xb00026@003bT005e6042Q
003NOP00oPL00?D/0037_`0008<=000g@`001Ad000HO0011B@01RP00c;400?PP003l3@00f8l002RI
0000ED/000/U00036P0093T007HW09bk003_@`00o`400>IT001T[00006Hl000E;`000QT001@^001U
?P1NZP00iFL00?l1003_@@00W[/0001f9P0093T000<J000;9P00EdX0<9`00=^8003m2P00mRP00<Rm
0000P`d003E200047@001b4004U<00n@003BXP00nQH00?XG003AY@002hh00017B`001b0000DM000i
A000QPL0b[L00?LR003l3P00ei80026F0000DTd000TS00047000;Sl007lE0<G4003e;000o@P00=b5
000`W00005I;000;9@000a/002Tl001k7@2f`@00lc<00?h6003NOP00>Il0001HB@0032H000<J000W
>P00NR00//000?<d003n1@00gWd003VO0000F4T000/V00036`00:3/007/N0;O1003c<@00oPL00=b3
000aW00005I;000:90000a/002`n001o5P35``00mBX00?d:003ISP008YL0001AC@00228000@L000e
@P00Q@T0bkD00?PO003k4P00dil000f?0000ADX200067`2e0014B@0<SP00dj000?/B003h7`00bkD0
00252P00<d8000@L00098`00Dd`0;9X00=b5003n1`00lc<00:no0000Mb@0028h00026P003bT00613
05VY003VH`00o`000>]A001f/@0006Pk000D;P000QT001/c001`;`2E^@00l3l00?l3003PN000>Yl0
001GBP002R@000<K000a@000Q0`0bkD00?PM003k5@00d:L0006:0000>TD000@M00088P00DTd0:iX0
0=b3003n1@00lSP00:2l0000Lb`000lW000D;P00JCX0O;800>a<003o0@00hfh004NS0000FTP000/U
00036`00<40008@=0<^d003i6`00nQL00<j^0000QPH003=2000470002R@005Q904:Q003RL000o`40
0>e<001j/P0006Pk000C;@000QT0020f001g9@2c`000m2h00?d;003FU@004Y400013B@001Ah000LQ
001AC@0ZVP00gH000?h4003`?`00S[L0001]=@005Rl0008I000L=000M2X0ZKh00?<a003m2@00ei<0
01>A0000@dT000DN00078@00DTd0<9`00=mk003o0P00kTH0082d0000J3X001</00026@008SP007XO
0<?4003g9@00na400=2V0000R08003A200036`002bD005a705BW003WH000o`000>MQ001BY`0005]7
000;9@0011`003I3006:003BX@00o0l00?DZ002f`@0007HW000M=0000QT001L`001_<@2M^`00lcD0
0?d9003GU0003i00000nA`0011d000TS001HB@18Y000iFH00?l0003WGP00E:L0001KA`002bD000@L
000jA@09S@00eIP00?d:003c<`00Wk/0001_<@005c00008I000O=P0:ooooo`7o00000Oooool001ko
oooo00?o0000ooooooooool01oooool0o`00OaL003M400067`0011`002Xl001e:026]@00j5/00?l1
003b=P00aL8000271@00ADX000PR00036`008SL006hb06n_003UJ000o`@00?D/003:]`001X`0001>
CP002R@000<J000N=@00JcL0I:`00>=_003n1@00mRP00<bb000:SP0004m>000:90000aX001dd001[
=`1T[000hfh00?h5003e:P00bkD000N<0000CDh000TS00036P0083H006dc06j_003UIP00o`<00?@a
0037_P0008P30014BP00224000<K000V>P00Lb/0QKD00>UH003o0000l3h00;C00000P1@003M30005
7P001Ad00391001m6`2X_P00kd@00?l0003ZD`00S;L0001e:0009c/000<K00088@00ADX008T00<Vi
003e;000oPD00>9a001KZ@0006Ll000I<@000QT000hX001HBP0XV@00eYH00?/D003k5@00eYL002JH
0000EdX000dW00026P006S8006Ti06B/003TJP00o`<00?<c0035``0008@<000kA@001Ql000DM000c
@@00OQL0/l000?4l003o0@00if40076_0000K3D001dd00026P0032H04WLV0=JG003k4`00nQH00=BL
000NU@0005=<000;9@000aX0020f001`<020/`00jEL00?l0003^A`00Vk/0001g9000:3/000<K0008
8P00CDh03Xl00<nY003h7@00o0h00=V>000^V`0005Q9000=9`000QX001dd001]=01g/@00j5/00?l0
003^AP00W;/0001g9@009c/000<K00098`00D4h05Y800=:P003j5`00na@00=FJ000MU@00059=000:
90000a/002Dj001f9`2I^P00kTH00?l0003XG000L[00001[=`006S80008I000?:P00GDH0@J400=im
003n1`00mB`00<K00000P`d003I300057@001R00049900::003=/000n2000?`>003HT000:9T0001E
B`002bD000<J000T>@00MRH0WK/00>m2003o0@00iV@006>/0000ISd001D_00026@0052h006Dn05nZ
003UIP00o`400>m1002M^`0007HW000T>@000aX000`V001GBP0aW000fhL00?d:003f:000akh00023
3@00=D8000@M00078@00BT`03i000=:R003j5P00nQP00=6V000;SP0004I;000680001Ad003U40026
1`3:]P00mb800?`>003GT`0089H0001AC@00?0002B<000@L000_?`00OaD0aL@00?D/003m2000fhH0
032L0000ET/000/U00036`00:C`007/M0;O1003c<P00oPH00=io000hWP0005Q9000<9P000aX002Lk
001j802c`000lc@00?h5003NOP00>9h0001HB@002bH000<K000X>`00Nad0^<800?@a003n1`00g8<0
036L0000ET/000XT00036`00;Ch007lF0<G3003e:@00o@/00=V>000RU`00055=00088P0011`003E3
0025203;]000n1h00?/B003CW`003Hl00014BP8000HO0;D004A:00b?003CW`00na800?PO003:]P00
08@;000c@@0011`000TS001DC00]V`00g8@00?h6003c=000[[l0001g90008SP0008J000?:@00H4<0
FZT00>IS003o0000je8007Fa0000J3/001@^00026@006c<0074_09Ji003`?`00o`<00=mi000iW`00
05M:000:90000a`003500024303;]@00nAd00?XE003@Z0000HX0000jA@0011d000PR001BC@0/VP00
gH800?h5003a>@00Wk`0001b;0003bL001@^001Y>@1l/`00kD/00?l1003SKP00AZ<0001JB0002bD0
00<K000`@000Q0`0bk<00?TK003j6000cJh000261`00<d4000<L000:9000F4T0@Z800>9`003o0@00
k4`007Vb0000Ic/001</00026@0083H007LU0;C1003d;@00o@/00=JF000AT00004=900057P001b40
055=02^J003MP000o`@00?10002=]`0006`e000F;`000QT001`d001d:P2Z_P00m3400?d:003GT`00
4i400013B@001Ah000PQ001BC@0aW000gg/00?l2003^AP00Ok<0001X>P004b`0008I000R>000NQl0
a<@00?LU003k4P00d:H000280P00=48000<K000;9P00G4L0E:L00>MP003o0000iV80056V0000FdL0
00/U00047000=T<00XX00=:Q003l3P00mBX00;G10000MRL001dd00026@005c0006la09jk003c=@00
o@T00=ND000>S`0003i700047@002B<005Q904VT003UIP00o`000>MO001CY`0005]7000:9@0011`0
03Y500V=003EV000o@X00?<d002N^`0006lb000F;`000QT0020f00[ooooo0Ol00001ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`3o001n5`00=d<000HO00047000:Sd007DW08Ne003YFP00o`40
0?8g0035``0008L60014BP00228000<K000R>000Kc80L:l00>EW003o1000mBd00<Zg0005S00004e>
000990000aX001he001[=P1U[000hfh00?h5003f:@00c;<000Z>0000Cdh000XT00036P007CD006/g
06B/003SKP00oPD00?DZ003;]@001X`0001=CP002B<000<J000P=P00KS<0Kjl00>EV003o0`00lc40
0<Nn0000Q`@004A:00078@000a/002Hj001d:P26]@00jEL00?l0003`?`00/l0000205@00=T<000DN
00057@00<T4007dJ0:Vn003_@`00o`000>YD002;]P0007DY000W>`000a/000PQ0016B`00R@00bKT0
0?D[003n1@00hW8005ZY0000Ic`001Pa00026@003RP005Q:02VI003FU@00na@00?XE003EV0009IP0
001GBP003BL0008J000J<P00JCT0I:`00>AZ003o0`00lc<00<G40000P`d003Y500067`001Ad003=1
001o5P2d`@00lC/00?l1003VHP00L:l0001/=@0073@0008J000<9`0CMbH0eYH00?/C003j5`00e9d0
01fE0000Dd`000/U00036P0083H0070_086d003ZEP00o`000>i7002J^P0007LT000X>`000a/000PR
001>CP0>S`00d:P00?TM003l3`00fHl002fK0000F4X000dW00026P007C@006dc07Ra003YFP00o`00
0>i6002K^P0007LU000W>P000a/000TS001@C@0GT`00dj000?XG003k5000e9/001bE0000DTd000XT
00036`009CX007HV09Zj003^AP00o`000>QM001a/00006/g000J<P000QT0010Z001MAP12XP00gW`0
0?h7003e;000a/0000233P00=T<000DM00068000@TT00X/00<f`003h8000o0h00=R@000WV@0005E;
000;9@000aX002Di001f9P2N^`00kd800?l1003VI@00HZ/0001V?@005Bh0008I000D;P00ICh0H:/0
0>EV003o0@00kd8009bk0000MBL002<h00036P0032H005M:036L003KQP00o@T00?HY0037_P0008<>
000d@P0011d000LQ001:C@0@T000dZ400?XE003j6000d:H000Z>0000ATX000HP00057P00>DD008H6
0<^e003g8P00o0h00=NC000OUP00055=000l00098`0011`002lo00205035``00mB`00?d9003KQP00
;i/0001FB`002RD000<K000Y?000O1`0^<800?<b003n1P00gGl003NN0000F4T000/V00036`009c/0
07XO0;C0003c<`00oPH00=in000hWP0005Q:000;9@000a/002Pk001k7@2i`P00m3000?h7003LQ000
<9`0001EB`002R@000<K000]?P00OaD0aL800?HY003m2`00f8l0026F0000DDd000PR00047@00=T<0
08H80<^d003h7P00na800=>P000<S`0004A:0P001Ql0]@00A4X03Hl00=>O003k4P00n2000<Zg0000
Q0/003=1000470002B<005A<02fK003LP`00oPH00?<d002]_`0007LU000R=`000QX000lY001Q@P1K
Z@00iV800?l0003[DP00M;00001W>`0052d0008I000K<`00LBl0UkT00?0n003o0`00ggX003VO0000
ETX000XT00037000<T4008@;0<^d003i7@00nQD00=2X0000RP0003U500047@00228005==02bJ003M
PP00oPD00?4i002N^`00078]000?9`0052h006Ti07fc003]B`00o`400>=_0015X`0005U8000;9@00
0a/0031000242`3</`00nA/00?XH003=[`0008H7000c@@000a`000XU001IB@13XP00hVl00?l1003/
C@00N;40001W?0004R`0008I000P=P00Mb@0]L400?D]003m2`00eYL0012@0000@TT000DN00078@00
DDd0;9X00=eo003o1000l40008fg0000K3D001H_00026@007C@007@Y0:^n003d<@00o@X00=ND000B
T@00049900057P002240059=036L003ONP00o`800>i7001o/`0006Pk000B;0000QT002<h001j7`35
a000mb@00?/B003@Y`0008P3000c@P000a/000/V001LAP1EY`00iel00?l0003VHP00DJH0001KA`00
2bD000@L000g@`02RP00dZ000?`>003e:`00]<40001e9`007C@0008I000H<000L300Wk`00?<d003m
2@00eYD000j?0000?DL000@M00099000F4T0BZ@00>EU003o0000if0005:W0000FdP000XT00047000
>dD02Xh00=JG003m2P00lc@009fk0000Kc8001H_00026@0083H02_ooool1o`00007ooooo000Noooo
o`03o`000?oooooooooo00Oooooo04@007hH000g@`001Ql000@M000[?@00MRL0R;H00>UI003o0@00
lSL00<G30000QPH004A:00088P000a/0028h001_<@1a[`00iFL00?l3003d;@00b[P000B;0000CDh0
00TS00036P007SD006/f06J/003SKP00oPD00?DY003;/`002Hd0001?CP002R@000<J000N=@00JcL0
IJ`00>=]003n1@00mB/00<Zf0005S00004a=00098`000aX0020f001^<`1`[`00iFD00?l3003c<P00
akl000271000@dT000LQ00036`009cX007@Z08Ne003YE`00o`000?0o002b`00007lE000f@`8000DN
0?D00391001m6P2Z_P00kd<00?l0003ZE000R[H0001d:@009cX000<K00088@00AT/008X00<Vh003e
:`00oPD00>9b001IZ@0006Hl000H<@000QT000hX001HB@0ZV@00eiD00?/C003j5@00eIT002BH0000
ETX000dW00026P006c8006Ti06F/003TJ@00o`<00?<d0034a00008<=000jA@001Ql000DM000c@P00
OaH0]L400?4k003o0@00iV8006n_0000K3H001`d00026P0032L04gLV0=JF003k4`00nQL00=BM000L
U@0005=<000;9@000aX0024g001a;`22]000jUH00?l0003^B000VKX0001g9@00:3/000<K00098P00
CTh03i000=2X003i7000o0l00=R?000/VP0005Q:000=9`000QX001dd001^<`1i/P00jEX00?l0003^
A`00V[X0001f9P009SX000<K00098`00DDd05i<00=>O003j5`00naD00=BL000KU000059=000:9000
0a/002Hj001f9P2K^P00kTD00?l0003XGP00L:l0001[=`006S80008I000@:P00GDD0@j800=ml003n
1P00mBd00<K10000P`l003I300057@001R0004=900>;003=[`00n1l00?`>003HT@009YP0001DC000
2bD000<K000U>@00MRD0Wk/00>m1003o0@00iFD006:[0000ISd001D^00026@005Bh006Dn066[003U
I@00o`400>m2002K^`0007DX000S>0000aX000`V001GBP0bW000fhH00?d9003e:@00akl000233P00
=48000@M00078@00Bdd049000=:Q003j5@00nQP00=2W0009S@0004E:000680001Ah003Y500271@3;
]@00mb400?`>003GU0007iH0001AC@002B8000@L000_?`00P1@0aL<00?D[003m2@00fhL002jK0000
ED/000XU00036`00:S`007`L0;W2003c<@00oPH00=f0000fWP0005Q:000;9P000a/002Pk001j7`2e
`@00lc<00?h6003NO`00=ih0001HBP002bD000<K000Y?000O1`0^/800?@`003n1`00g8@002nK0000
ED/000XT00036`00;Ch007lE0<K2003f:@00o@/00=R?000PUP00051>00088P0011d003I300261`3;
/`00n1h00?/C003BX@0038h00013B@0200067`2e0015BP0>S`00dih00?/A003h8000b[L000243000
<T4000@L00098`00E4`0;Y/00=b3003n1P00lcD00:bo0000MbD0028g00026P0042X0065205bY003V
HP00o`000>]C001c/00006Lk000D;@000QT001`c001a;P2H^P00l3h00?l3003ONP00>9h0001FB`00
2R@000@L000b@@00Q0/0bk@00?TL003j5P00cjT000290000>D@000@M00088P00Dd`0;I/00=f1003n
1@00lCX009fk0000LRd000lV000E;P00JCT0O[<00>e:003o0@00hVl004BR0000FDT000/U00036`00
<D0008@;0<bb003i6P00nQP00<f_0000QPP0039100036`002RD005U904BR003SKP00o`400>a=001g
/@0006Ll000B;0000QT0024g001h902f`@00mB`00?d<003FU`0049000012B@001Ah000LQ001AC@0]
V`00gWl00?l3003_@@00S;L0001/=P005Rl0008I000M=000M2T0[;l00?@`003m2P00eiD0016A0000
@TT000DN00088@00Dd`0<Y`00=mi003o0P00kTL007jc0000J3/0018/00026P008cP007/N0<G3003g
9000na800=2W0000R0@003=100036`0032H005a605JX003WG`00o`000>IS001@YP0005]8000;9@00
11`003M300>;003CX000o0h00?D[002c`00007DX000L=0000QT001Pa001`<02P_000lc@00?d9003F
UP003Hl0000mAP0011d000XT001IB@1;Y000iVD00?l0003WH000DJH0001JB0002R@000@L000kA@0;
SP00eYL00?d9003c=@00W;/0001^<P005Rl0008I000P=P0:ooooo`7o00000Oooool001kooooo00?o
0000ooooooooool01oooool0A000OQP003I300067`0011d002/m001f9P29]P00jET00?l1003b>000
aL@000261`00@dT000PR00036`008cP006la07:`003UIP00o`<00?@^0039^@0018/0001<C@002B<0
00<J000O=@00K3H0Ijd00>=]003n1@00mBX00<^d0008S@0004m>000:90000aX001he001[=P1V[000
hf`00?h5003e:`00b[H000F<0000C4d000TS00036`008CL006hb076`003VI@00o`800?<b0036`000
08L50013B@001b4000<L000W>`00M2T0R;H00>YF003o0000l4000;700000OaH003E30P001Ah0m@00
<d4007dI0:^n003_@P00o`000>YE0029]P0007@Z000V>P000a/000PR0017B`01RP00b[P00?DZ003n
1P00hG<005RX0000ISd001Pa00026@003RP005Q902ZJ003GU000na<00?XF003EV@0099L0001FB`00
3BL0008J000K<`00JSP0IZ`00>AX003o0`00lc@00<?40000P`h003U500067`001Ah003A2001o5@2g
`@00lCX00?l1003VH`00KZl0001/=P0073@0008J000=9`0DN2D0eYD00?/C003j5`00dih001^D0000
Dd`000/U00036P008CL0074_08>d003ZE@00o`000>e9002H^P0007LU000W>`000a/000TS001?CP0@
T000d:L00?TL003l3`00f90002^J0000EdX000dW00026P007CD006hc07Zb003YF@00o`000>i7002I
^P0007HV000V>P000a/000TS001AC@0HT`00dih00?XF003j5@00e9`001^D0000DDd000XT00036`00
9SX007LU09bk003^A000o`000>MN001_[`0006Xh000I<P000QT0010Z001NA@14XP00gg/00?h6003d
;@00a/8000223`00=D8000DM00068000@dT018/00<f^003h7`00o0l00=RA000UV00005A<000:9@00
0a/002Dj001g9@2P_000kd400?l1003UIP00HJ/0001U?P005Bh0008I000E;P00ISd0HZ/00>IU003o
0@00kd<009Zj0000MBP002<h00036P0032H005Q:03>M003LQ@00o@T00?DZ0037_`00088?000d@P00
11d000LQ001;C@0AT@00dj000?/E003j6@00d:L000V=0000ADX000HP00057P00>TD008L50<^d003h
8@00o0l00=NE000NU@00055=00088P0011`0031000204`35`P00mB/00?d9003KR000;I/0001EB`00
2R@000<K000Z?000O1/0^/800?@a003n1P00gH4003FN0000EdX000/U00036`00:3/007/N0;K1003c
<P00oPH00=f0000fWP0005M:000;9@000a/002Tl001l702k`P00m2l00?h7003LQ@00;Y/0001EB`00
2R@000<K000^?P00P1@0a/400?HX003m2`00f900022F0000D4h000PR00047@00=d<008H60<bb003h
7@00na<00=:Q000;SP0004=9008000HO0;D004E:00n@003CWP00na400?PP003:^00008<=000b@@00
11`000TS001DC00_V`00gH800?h6003b=@00Zkh0001f9P008CL0008J000@:P00HD80GJX00>MQ003o
0000jU<007:`0000Ic`001<]00026@0073<0074^09Vj003`?@00o`<00=mk000gWP0005I;000:9000
11`0039100252P3</`00nA`00?XF003?Z@0008T0000hA00011d000PR001CC00^V`00gH400?h5003a
>P00W;/0001b;@003bH001D^001Z>01o/`00kDX00?l1003RL000@j80001IB@002bD000<K000a@000
Q@X0c;800?TJ003j6@00cK0000252@00<T4000<K000;9@00FDT0AJ<00>=^003o0@00k4h007Ja0000
Ic`0018/00026@008CL007PS0;O1003e;000o@`00=FH000?T000045800057P002240059=02jK003N
OP00o`<00>m1002:]P0006`f000E;`000QT001dd001e:@2]_`00m3000?d:003FU@004I000011B@00
1Ah000PR001CC00cW@00h7T00?l2003]B000OK<0001W>`004R`0008J000S>000Nad0aL<00?LS003k
4P00d:P000271000<T4000<K000<9P00GDH0EjP00>MN003o0000iV<004nV0000FTP000XU00047000
>4@018/00=>O003l3P00mB`00;;00000MBP001`d00026@006340070_0:6l003c<`00o@X00=JF000<
S`0003a6000470002R@005U904bU003VI000o`000>MQ001@YP0005Y8000:900011`003]600b>003F
UP00o@T00?8e002K^P0006hc000F;`000QT0024g00[ooooo0Ol00001ooooo`007_ooool3o`0000Oo
oooo04@007hI000f@`001Ql000@M000[?@00MRH0R[H00>UH003o0@00lSP00<C40000QPP004=90008
8@000a/002<h001`<01c/000iFH00?l3003d;P00bKT000>;0000Bdd000TS00036P007cH006`e06R]
003SK000oPD00?DZ003;]@001hd0001>CP002R@000<J000N=@00K3H0Ijd00>=/003n1000mB`00<Zg
0004R`0004]=00098`000a/0024g001_<P1b/000iV@00?l2003c<`00a/0000271P00@TT000LQ0003
70009c/007@Y08Vf003ZEP00o`000?10002__`0007lF000e@P8000DN0?l003=2001n602/_`00kd40
0?l0003ZEP00R;H0001d:P009SX000<K00088P00Ad/00XX00<Zg003e:P00oPH00>5d001GZ00006Hm
000H<0000QT000hX001IB@0[VP00ei<00?/C003j5P00eIX002>G0000ET/000`W00026P006c<006Xh
06N]003UJ000o`800?<e0032a00008<?000iA0001Al000DN000d@P00P1D0^<400?4i003o0@00iV<0
06f^0000JcH001`c00026P003BL057PU0=ND003k4P00nQP00=>O000KU000059=000:9@000aX0024g
001a;P24]000jU@00?l0003]B@00UkX0001f9P009c/000<K00098`00Cdh04I000=2V003i7000o100
0=RA000[VP0005M:000<9`000QX001he001^<P1k/P00jEP00?l0003^B000V;X0001f9`009SX000<K
000:9000DDd06I@00=>N003j5P00nQD00=BM000JU000055=000990000a/002Lj001g9@2M^`00kd@0
0?l0003WG`00KZl0001Z>0006C40008I000@:P00GTD0AJ800=mj003n1P00m2h00<G20000PQ0003E2
00047@001R0004A:00B;003>[P00n1h00?`?003GTP009IP0001DC0002R@000<K000V>P00Mb@0XK`0
0?10003o0@00iFL0062[0000ICh001@^00026@005Bh006Hm06>/003VI000o`400>m4002I^P0007DY
000S>0000aX000`V001HB@0dW@00g8@00?d9003e:P00a/0000224000<d4000@M00078@00C4d04Y40
0=>O003k5000nAT00=2X0008S@0004A:00067`001Ah003]50027103;]000n2000?`?003FU@007ID0
001@CP00228000@L000`@000PA<0a/400?DZ003m2@00fhP002bJ0000ED/000XT00036`00:Sd007`K
0;_2003d<000oPL00=f1000dW@0005M:000;9@000a/002Pk001k7@2g`@00lc800?h6003MP000=Id0
001GBP002bD000<K000Y?000O1/0_<<00?@_003n2000fhH002fK0000ED`000XT00036`00;Sl0080D
0<K0003f:000o@`00=RA000OUP00051>00088@0011d003M300271P3</P00nAd00?/C003BXP002Xh0
0012B@001Al000HO0016B`0?T000e9d00?/A003h8@00bKP000233@00<D0003h000@L00098`00ED`0
<9`00=f1003n1P00lSH00:Vn0000MRH0024g00026P0042X0065205jZ003WH000o`000>YD001a[`00
06Ll000C;@000QT001`d001b;@2J^P00lCd00?l4003OO000=Yh0001FB`002R@000@L000c@@00Q@T0
c;800?TK003j5P00cjX000290@00>4@000@M00088P00Dd`0;i/00=f0003n1000lC/009^k0000LBh0
00lV000E;P00JSP0P;@00>e9003o0@00hW4004:R0000FDT000/U00036`00<D4008D:0<ba0080nAT0
06d0c;4000252@00<D4000<K000;9@00FDT0AZ<00>=]003o0000k4h007Fa0000ISd0018/00026@00
8CL007PS0;W2003e:`00o@`00=FI000>S`00045800057P002240059=02jK003NO@00o`<00>m20029
]P0006/f000E;P000QT001de001e:02^_`00m2l00?d;003FUP0049000011B0001Ad000PR001CC00d
W@00h7P00?l2003]B@00Nk80001W?0004R`0008J000T>@00Nad0aL800?LS003k4`00cjT000271@00
<T4000<K000<9P00GDH0F:P00>QM003o0000iV@004jU0000FTP000XU00047000>4@018/00=>N003l
3@00mB`00;700000MBT001`c00026@006340074_0::l003c<P00o@X00=JG000;SP0003a600047000
2R@005U904fU003VH`00o`000>IQ001?YP0005Y8000:900011`003a600b?003FU@00o@T00?8f002J
^P0006hc000F;`000QT0024g00Sooooo0ol00001ooooo`007_ooool00ol0003oooooooooo`07oooo
o`14001m6@00=D<000HO00047@00;3d007LU08^f003YE`00o`400?4i0033a00008D80012B@002240
00<K000S>000L300M;000>EU003o0`00m2l00<Vj0002RP0004]=00098`000aX001lf001/=@1Y[@00
i6/00?h4003e:`00bkD000N<0000CTh000TT00036P007cD006`e06V]003TJ`00oP@00?D/003:^000
0h/0001:C@002B<000<K000Q=`00Kc40Lk000>IS003o0P00lc<00<K10000QPL0045900078@0011`0
02Pk001e:02:]P00jUD00?l0003_@@00[[l0001n5`00=48200057P0Y000d@P00OQP0[[l00>m1003o
0000jUH008Ne0000Lb/002Dj00036`00228004Q<00>;003:]P00mBT00?h6003QM000EZP0001V?@00
5c00008I000>:@00FDT0;9X00=NC003k4P00nQL00=BK000RU`0005I;000<9`000QX001/c001Z>01Y
[@00iFL00?l2003b=@00`L@000223`00>4@00P001Ah0o`00=D80080D0;W2003b>@00o`800>IT001/
[P0006/g000K<`000QX000dW01Eh9@3GU000na800?XH003CW`006Y@0001BC@002R@000<J000R=`00
LBh0QKD00>YD003o0000kDX009Ji0000MRH002Hj00036`002B<004m>016A003AY@00nA/00?`@003H
T@00:YT0001GBP0032L0008J000N=@00Kc80O;<00>UH003o0000kDP009Ji0000MBL002Dj00036`00
2R@0055=01ZD003DW@00nQD00?XF003CWP006I<0001AC@002B<000<K000W>`00Mb@0W[/00>m3003o
0000if0006f^0000JSP001Ta00026@0042X005i504JS003ONP00oPH00?@_0035``00088A000d@P00
11d000LP0014BP05S000cZd00?PN003l3`00ei<002BG0000E4`000XT00036`009SX007LT0::l003`
@000o`400>EW001NZP0006Dn000D;P000QT001D_001V?@1T[000iV<00?l1003^A000V;X0001d:@00
8SP000<J000<9P00F4T0=Id00=b4003m2000mB/00<K10000PQ0003=1000470001b4004e>01>A003C
W`00na@00?TJ003?Z@001h`00013B@001Ql000DN000kAP00R0<0c;<00?PP003l3`00eYH001bE0000
D4h000PR00047000<D00084B0<K1003e:P00o@X00=Z9000[VP0005E;000:90000a/002/m001m6P2m
``00m3000?h7003MPP00<id0001GBP002bD000<K000Y?000Nad0^<800?<a003n1P00gH4003BM0000
EdX000/U00036`00:S`007dK0;k3003d;P00oPP00=^6000/VP0005A<000:90000a/002ho00204`36
`000mRL00?d<003HTP007YD0001?CP00224000@M000hA000Q`D0c;400?TL003k5000dZ<000V=0000
@TT000DN00067`00Ad/049000=BL003l4000mb400<Vi0000P`h00350000470002B@005E;036L003M
P@00oPD00?8f002X_P0007HW000Q=`000QX0010Z001R@@1OZP00if000?l0003ZE@00L:l0001V?000
4bd0008I000L=000LRd0Vk/00?4l003n1000gW`003FM0000ED/000TS00047000<d8008D80<bb003i
6`00nQL00<n[0000R08003M4000470002B<005A<032L0000PP3NO`00oP@00?4l002J^P00074^000?
9P005Bl006Xh08:d003]B000o`400>9a0011X@0005Q9000:9@000a/0039100252@3=/000nAT00?TJ
003</@0008D:000a@0000a/000/U001JB017X`00hf`00?l0003/C`00M;00001V?@004R`0008I000Q
=`00N280^/800?D[003l3@00eIT000f?0000@4P000DM00088@00DTd0;i/00=im003o0`00kd<008Rf
0000JcL001D^00026@007SD007DW0;30003d;P00o@/00=JG000?T000041800057@00228005=<03FM
003PM`00o`800>e9001j/P0006Ll000B:`000QX002@i001l7036`@00mb800?/C003?ZP0008L6000b
@@000a/000`V001MA@1IZ@00j5d00?l0003UI@00CJD0001JB0002R@000@L000iA005S000dih00?`=
003e;@00/<00001d:@0073<0008I000I<@00LBh0Y;d00?<b003m2P00eIP000Z>0000>dH000@L000:
9000FDP0CZD00>IS003o0000iV8004jU0000FDP000XT00047000?DH03Hl00=ND003m2@00lSH009Vj
0000KC@001D_00026@008CL:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0
A000OAX003E200057`0011d002`n001g9@2<]`00jEL00?l0003a>P00`/@000252@00@DT000LQ0003
6`0093T0070_07Fa003VI000o`<00?@`0038^`000HX0001:C0002B<000<J000P=P00KC@0JZd00>A[
003n1000mB/00<Zf0006S00004e>00098`000aX001lf001/=@1Z[@00i6X00?h4003e;@00bKT000:;
0000BT`000TS00036`008SL006la07F`003VHP00o`800?<d0036`P0008H70011B0001b4000@L000X
>`00MBP0RkL00>YD003o0000kd800:fo0000OQP003A20P001Ah0:@00=48007hG0:no003`@000o`00
0>UG0025]@0007<[000U>@000a/000PR0019C003R`00bkD00?HY003n1P00hGD005FW0000ICh001L`
00026@003bT005U902fK003GTP00na800?XG003DV`008IH0001EB`0032H0008J000L<`00JcL0JZd0
0>EV003o0P00lSH00<330000PQ0003Q4008000DN0?l003E300204`2j`P00lSP00?l2003UI@00Jjh0
001[=`006c<0008J000=9`0ENBD0ei<00?/A003j6@00dZ0001VC0000DTd000XT00036P008SP0078]
08Je003[D`00o`000>e;002E^@0007HW000V>P000a/000TS001?CP0BT@00dJD00?TK003l4000ei80
02VI0000ETX000`V00026P007SD006la07jc003YE`00o`000>e9002E^@0007DX000U>@000a/000XT
001BC@0KU000e9`00?XE003j5P00dih001RC0000DDd000TS00036`009c/007PT0:2l003_@`00o`00
0>MP001/[P0006Ti000I<@000QT0010Z001OA017X`00ggT00?h6003d;`00aL@000214@00=48000@M
00078000ADX01X`00<j/003h7@00o1000=ND000SU`0005=<000:90000a/002Lj001h8`2T_@00l3l0
0?l1003UJ000GJX0001T?`0052d0008I000F;`00Ic`0IJ`00>IR003o0000kTD009Ni0000M2X0028g
00036P0032L005U903JN003LP`00oPP00?D[0036`@00084A000b@@0011`000PQ001=CP0DTP00dih0
0?/D003i6P00cjX000J<0000@dT000HO00057P00?4H008P20<bb003h7`00o1000=JG000KU000051>
00088P0011`0035000214@36`000mRT00?d:003JRP00:YX0001DC0002R@000<K000[?@00OAT0_/<0
0?@_003n1`00g8<003:M0000ETX000/U00036`00:C`007`L0;W2003d<@00oPL00=f2000cW@0005I:
000;9@000a/002Xm001m6P2o``00m2h00?d8003KQ`00:iX0001DC0002B<000<L000_?`00PA80akl0
0?HV003m3000ei8001fE0000Cdh000LQ00047@00>4@008L40<f`003i7000na@00=6S0008S@000458
00057P001Ql004M;016A003DV`00o1000?LR0039^P00088?000`@0000a`000XT001EB`0bW000gH00
0?h5003b=`00Ykd0001e9`0083H0008J000@:P00HT40H:/00>MO003o0000jUD006n_0000ISd001</
00026@007C@0078/09fk003a>`00oP@00=im000dW@0005E;00098`0011`003A20026203</@00nAX0
0?XG003>[00008P3000g@`0011`000TS001DC00aW0000880gWh00?h4003a?000VKX0001a;`003bH0
01H_001[=`23]000kTP00?l1003RLP00@:40001HB@002R@000<L000b@@00QPP0cK000?XI003i6P00
c;8000242`00<40000<K000;9@00FTP0B:@00>A/003o0000je0007>`0000ISd0014[00026P008SL0
07TQ0;_2003e:P00o0d00=FJ000<S`00041800057@00228005==032L003OO000o`<00>m30027]@00
06/g000E;P000QT001he001f9`2a`000m2h00?d;003FU`003Xl00010B0001Ad000PR001DC00fWP00
h7H00?l2003]BP00NK80001V?0004B/0008J000T>@00O1`0a/400?LR003k5000cjX000261P00<D00
00<K000<9P00GTD0FZT00>QL003o0000iFH004bU0000FDP000XT00047000>D@01X`00=BM003l3@00
m2d00:jo0000M2X001/c00026@006C40074^0:Fm003c<@00o@/00=FI000:SP0003]5000470002R@0
05Y804nV003VHP00o`000>IS001=Y@0005U9000:900011`003e600j?003GU000o@P00?8g002G^P00
06dd000E;P000QT0028g2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo04@0
07`K000d@P001Ah000@M000]?P00Mb@0S[L00>YF003o0000lCX00<340000Q@X0045800078@000a/0
02@i001a;`1g/@00iV<00?l3003d<000b;/0002:0000BD`000TS00036`0083H006dd06^^003TJP00
oP@00?D/003:]`001H`0001<C@002B<000<J000O=P00KC@0Jjh00>AY003o1000m2h00<Vi0001RP00
04U<00088P000a/0028h001`<01f/@00iV800?l2003c=@00aL8000262000@4P000LP00047000:C`0
07HW08fg003ZD`00o`000>m2002[_`0007hH000c@P8000DN02T003E2001o5P2``000l3l00?l0003Y
F000Q;D0001c;0009CT000<K00088P00BD`018/00<^e003f:000oPL00>1f001DY`0006Dn000G<000
0QT000lY001JB00^V`00f9400?/A003j5`00e9`0022F0000ED/000`V00026P0073@006/g06^^003U
I@00o`800?8g002n``00084A000gA00200057P3o000f@`00PA80_<800?8h003o0P00iFH006V]0000
JSP001/c00026P003BL05WTU0=NB003k4@00nAT00=:Q000HT`00059=000:90000aX0028h001b;@27
]@00je800?l0003]B`00TkT0001e:0009SX000<K00098`00D4h04i400=6T003i6P00na400=NC000W
V@0005I;000<9P000QX001le001_<@1o/`00jUH00?l0003]BP00U;T0001e:00093T000<K000:9000
DTd079D00=BK003k5000nQL00=>O000GT`00051>00098`000a/002Pk001h8`2Q_000kd800?l1003W
H@00Jjh0001Y>@006340008I000A:`00Gd@0B:<00>1h003n1@00m3000<C40000PA8003=100047@00
1b0004I;00N<003>Z`00nAd00?`@003GU@008YL0001CC0002R@000<K000W>`00N2<0YKd00?0n003o
0@00i6T005bY0000I3l001@]00026@005Rl006Ll06N]003VHP00o`000>i6002E^@0007@Z000Q=`00
0aX000dW001IB@0gWP00gH800?h8003e;000aL8000214P00<T4000@L00088@00CTh05I800=BM003k
4`00nA/00<nZ0005S000049900067`001Ah003a600280P3</@00n1l00?`@003EV0006Y@0001?CP00
228000@L000b@@00PQ00akl00?HX003m2P00fX/002VI0000E4`000XT00036`00;3d007hI0;o3003d
;P00oPL00=b4000aW00005I;000;9@000a/002Xl001l702k`P00m3000?h7003LP`00<Y`0001FB`00
2RD000<K000[?@00OAT0`<<00?D]003m2000fhP002ZJ0000E4`000TS00037000;cl0084B0<Nn003f
9P00o0d00=NC000LU@0004m>00078@0011d003U400280`3=/000nA/00?/E003AY0001hd00011B000
1Ah000HP0018B`0BT@00eIX00?`?003g8P00b;/000224000<40000<K000:9000ED/0<id00=io003n
1@00lSP00:Fm0000MBP0020f00026P0042/00691066[003WGP00o`000>YF001][P0006Hm000C;000
0QT001dd001c;02N^`00lC/00?h4003NOP00<id0001EB`002B<000@L000d@P00QPL0cK000?TJ003j
6000cZ`000280`00=T<000@L00098`00E4`0<Y`000220=im003n1000l3d009Nj0000L2l000hV000F
;`00JcL0Q;D00>i7003o0P00hG<003nQ0000F4X000XT00047000<d4008H70<f_003j6000nA/00<bc
0000Q0`0031000036`002bD005Y804VT003TJ`00o`000>]A001a/00006Dn000A:`000QX0028h001i
8@2m``00mBX00?`=003DV`002hh0000oA`001Ad000PR001CC00bW000gg/00?l3003_A000Q[D0001Z
>00052h0008I000N=@00MRH0//000?@]003m3000eIP000f?0000?dL000DM00088P00E4`0=ih00>1f
003o0@00kD/007Ra0000ISd0014[00026P009CT007`K0<K0003g8@00na@00<n[0000QPL003500003
6`0032L005i505bY003XF`00o`000>EV001:Y00005U9000:900011`003Y500N<003DW000o@`00?@^
002]_`0007<Z000K<`000QT001Tb001b;@2V_@00m3400?d;003EV@002Hd0000jA@0011`000XT001J
B01@YP00if400?l0003VI000C:D0001IB@002R@000@M000nA`0?T000ei<00?h8003b>000U[T0001]
=0005Bh0008I000R>0[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`14001l
7000=48000DN00047@00;Ch007PT08ng003ZE@00o`000?4k002o``0008@;0010B0001b4000<K000U
>@00LBh0N;400>IR003o0P00m3400<Rl0000R@0004U<00098`000a/0020f001]<`1][P00i6T00?l4
003e;@00b[P000B;0000C4d000TS00036P0083H006dd06b^003TJ000o`@00?@^0039^P000HX00018
C000228000<K000R>000L300Mk400>MQ003o0P00lSD00<G30000Q@T004180007800011`002Tl001f
9P2>]`00je<00?l0003_@`00Z[h0001m6@00<d4200057P0Y000e@`00OaH0//000?0o003o0000jET0
08>d0000LR`002@i00036`00228004Y<00F<003;]000mRL00?h7003PM`00DjL0001U?P005c00008I
000?:@00FTP0<9`00=R@003k4@00nQP00=BM000OUP0005E<000<9P000QX001`d001[=P1/[P00iVD0
0?l2003b=`00_L<000214P00=d<00P001Ah0o`00=d<0084B0;g3003b=`00o`800>EW001X[@0006Xh
000J<P000QX000dX01Ii9@3HT@00o1400?TJ003BXP005i<0001AC@002R@000<J000S>000Lb`0RKH0
0>]A003o0000k4`009:h0000MBP002Dj00036`002B<0051>01BB003BX`00nAX00?/A003GU0009YP0
001FB`0032H000<J000O=P00L300P;@00>YE003o0000kD/009:h0000M2T002@i00036`002R@0059=
01fE003EVP00na@00?XG003CX0005Y80001@CP002B<000<K000X>`00N280Xk`00>m1003o0@00iV80
06V]0000JCX001Pa00026@004B/005m404VT003PM`00oPD00?@`0033a000080C000c@@0011d000LP
0017B`08S@00cj/00?TL003l4000eYD0022F0000Dd`000XT00036`009c/007TR0:Jm003`?@00o`80
0>AZ001KZ@0006@o000C;@000QT001H_001W>`1X[@00if400?l0003^A`00U;T0001c:`008CL000<J
000=9`00FDT0>9h00=f1003n1`00mBd00<G30000PA<0035000047000228004i>01JB003DW000na<0
0?TK003>Z`0018/00012B@001Ql000DN000mAP00R@40cK000?PN003l4@00eIT001VD0000Cdh000PR
00047000<T40088@0<Nn003f:000o@/00=Z<000XV@0005A<000:90000a/002`n001n6031a000m2h0
0?h8003LQ@00<9`0001FB`002RD000<K000Z?000O1/0_<<00?@_003n1`00g8@0036L0000ET/000XT
00036`00:cd007hH0<;4003e;000o@T00=Z9000YV@0005=<00098`0011`0031000224@37_@00mRD0
0?`=003GU0006i@0001?CP001b4000@M000iA@00R080cJl00?TK003j5@00dJD000J<0000@4P000DN
00068000BD`04i400=FJ003l3`00mb<00<Rk0000PQ0002lo00036`002R@005I;03BM003NOP00oPD0
0?8h002T_@0007DY000O=P000QT0014[001S@01SZ`00j5d00?l0003YE`00K:h0001U?P004R`0008I
000N=@00Lb/0X;`00?4j003n1000gWl003:L0000E4`000TS00047000=D8008L60<f_003i6@00nQP0
0<j]0000Q`@003I3000470002B<005E;03>M0000PP3NO@00o`@00?0n002F^@00070`000>9P005Rl0
06/f08Je003^AP00o`800>5d000nX00005M:000:900011`003A200261P3>[P00nQP00?TK003;]000
08@<000_?`000a/000/V001KB01;Y000i6X00?l0003[D@00L:l0001U?P004B/0008J000S>000NR00
_/<00?HY003l3P00e9`000Z>0000?TL000DM00088P00Dd`0<id00=mj003o0P00kTD008Be0000JSP0
01@^00026@007cD007HV0;C1003e;@00o@`00=FI000<S`0003i700047@00228005A<03RN003QM@00
o`400>e<001f/@0006Hm000A:`000QX002Dj001m6P37_`00n2400?/E003>[00008H8000`@0000a/0
00dW001NA@1MZP00j5X00?l0003UI`00BJ@0001IB@002R@000@L000jA@08S@00e9/00?d<003d;`00
[;l0001c:`006c<0008I000J<P00LRd0Z;h00?@`003m2`00eIX000R=0000>TD000@L000:9@00FdP0
DJH00>MP003o0000iVD004^T0000F4T000TS00047@00?TL049000=NB003n2000lSP009Fi0000K3D0
01@^00026@008SP:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0A000O1`0
03=100057P0011d002ho001h8`2A^000jU@00?l0003a?000_L<000243000?dP000LQ00036`009CT0
074^07Vb003VH@00o`800?<b0037_@0008T00018B`00228000<K000Q=`00KS<0KZl00>EX003o1000
m2d00<Vi0003R`0004]=00098`000a/0020f001^<`1^[`00iFP00?l3003d;`00b;/000290000B4/0
00PR00036`008cP0070_07Vb003WH000o`800?8f0035a00008D:000oA`001b0000@L000Z?000MRH0
T;P00>]B003o0000kd@00:Rn0000OAX003910P001Ah0:@00=T<0080E0;?0003`?P00o`000>UI0021
]000078]000T>@000a/000TR001;C@06S000c;<00?HW003n1`00h7P0056V0000I3l001H_00026@00
3bT005Y8036L003HS`00o1400?XH003CWP007YD0001DC00032H0008J000M=000K3H0KZl00>IT003o
0P00lSP00;_20000PA8003I3008000DN0?H003M400214@2o``00lSH00?l2003UJ000Ijd0001Y>@00
6S80008I000>:00GNRD0f9000?`@003i6P00dZ<001JB0000DDd000XT00036`008cP007<[08Zf003[
D@00o`000>a=002@^00007@Y000U>@000a/000TS001@C@0ETP00dZ800?TI003k4P00eYD002FH0000
ED/000`V00036P0083H0070`08:d003ZE000o`000>e<002A^00007@Z000T>@000aX000XT001CC00N
U@00eIX00?/D003j6000dZ4001FB0000D4h000TS00036`00:C`007TR0:Bm003`@000o`400>IS001X
[@0006Pj000H<0000QT0014[001P@`1;Y000h7H00?h5003c<@00`L@000205000<T4000@M00078@00
Ad/02Hd00<nZ003i7000na400=JF000OUP00059=000:90000a/002Pk001i8@2X_P00lCd00?l2003T
J`00FJT0001S@0004bd0008I000F;`00J3/0JJd00>MP003o0000kTL009:h0000Lb`0024g00026P00
3BL005Y803VO003MP000oPL00?@]0035a000080D000`@00011`000PR001?CP0GT`00e9/00?/B003i
7000cZ`000>;0000@DP000HO00057P00?TL008T00<f`003h7P00na400=FJ000HT`0004m>00088P00
11`003=100223`37_P00mRL00?d;003IS@009iT0001CC0002B<000<K000]?P00OQL0`/@00?D]003n
2000fhH002nK0000ED/000XT00036`00:cd007dJ0;k3003d;`00oPP00=b5000_V`0005E;000:9000
0a/002`m001n6033a000mB`00?d9003JRP00:9T0001CC0002B<000@L000a@000PQ00b;`00?LU003l
3@00eYD001ZD0000CTh000LQ00057@00>TD008P20<j^003i6P00nQH00=2V0005S00003m700057P00
1R0004U<01BB003EV@00o0l00?LT0038_000084A000_?`000a/000XT001FB`0fWP00gWd00?h4003a
>@00X[`0001d:@007cH0008I000A:`00Hd00I:`00>QL003o0000jEP006^^0000ICh0018/00026@00
7SD007<Z0:6l003a>@00oPD00=f0000`W00005A<00098`0011`003I300271@3=[P020?XI00290<f^
0000Q`D003E2000470002B<005E;03FM003OO000o`<00?0o002D^@0006la000>9P005Rl006`f08Ne
003^A@00o`800>5e000lX00005M:000:900011`003A200271@3>[@00nQL00?TL003;]@0008<=000_
?`000a/000`V001KA`1<Y@00i6T00?l0003[DP00Kjl0001U?P004B/0008J000S>000NQl0`<<00?HX
003l3P00e9d000V=0000?TL000@M00088P00E4`0=9d00=mi003o0P00kTH008>d0000JCT001@]0002
6@007cH007LU0;G1003e;000o0`00=FJ000;SP0003i700047@00228005E;03ZO003QM000o`400>a<
001e/@0006Dn000A:`000QX002Hj001m6@37_P00n2000?XE003>[@0008D9000_?`000a/000dW001O
A01NZP00jET00?l0003TJ000B:<0001HB@002R@000@L000kA@09S@00eIX00?d;003d;`00Z[h0001c
;0006S80008I000J<P00LR`0ZKh00?@_003m3000e9/000N<0000>D@000@L000;9@00FdL0DjL00>MO
003o0000iFD004VT0000F4T000TS00047@00?dL04I000=RA003n1`00lCT009>h0000K3H001@^0002
6@008cP02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo06l007/M000b@@00
1Ah000DM000^?`00N280T[P00>YC003o0000l3d00;c20000P`d003m700078@000a`002Dj001b;@1k
/P00if400?l2003c<P00akh000290@00Ad/000PR00036`008CL006hb06n_003UI`00o`<00?@^0039
^P000XX0001:C0002B<000<K000Q=`00KS<0Kjl00>EW003o0`00m3000<Rl0000R@0004M;00088P00
0a/002<h001a;`1j/P00iel00?l1003b=`00`l@000242`00?TL000LP00047000:S`007LU096h003[
D@00o`000>i5002W_@0007`K000b@@001Ad000DN000g@`00P1@0]L400?0m003o0000j5X0082c0000
LBh002<h00036`002B<004a=00N=003</P00mRH00?h8003PN@00D:H0001T?`005Rl0008I000?:P00
FdL0<Y`00=V>003l4000nAT00=>O000LU@0005A<000;9P000QX001dd001/=@1_[`00iV<00?l1003a
>@00^/8000204`00=D<00P001Ah0o`00>4@0088@0<33003b=@00o`800>AX001U[00006Ti000J<P00
0QT000hX01Mj9@3HS`00o1000?TK003AY0005980001@C@002R@000<K000T>@00Lb/0S;L00>]@003o
0000k4h008ng0000M2X002@i00036`002R@0055=01NC003BX@00nQP00?/B003FUP0099P0001EB`00
2bH000<J000P=P00L2l0Pk@00>YC003o0000k4`008nh0000M2X002<h00036P002RD005=<01nF003E
V@00na<00?XH003BXP005940001?CP002B<000<K000Y?000NB40Y[d00?0o003o0@00iV@006J/0000
J3/001L`00026@004B/0061304bU003QM@00oPD00?<b0030``00080E000a@00011d000LQ0018C00:
SP00cjT00?TK003k4@00eYL001jE0000DTd000TT00036`00:C`007TQ0:Vn003a?000o`800>=/001H
Z00006=0000C;@000QT001L`001X>P1[[P00iel00?l0003]B000TKP0001b;00083H0008J000=9`00
FTP0>il00=eo003n1`00m2h00<C40000P1@0031000047000228004m>01RC003EVP00na800?TL003>
[@000X/00010B0001Ql000DN000oA`00RP00cJl00?PM003k4@00eIX001NC0000CTh000PQ00047000
<d8008<>0<Rm003f9P00o@/00=V>000VV00005=<00098`000a/002dn001o5P34a000mB`00?d8003K
Q`00;Y/0001EB`002R@000<K000[?@00OAT0`<<00?@^003n2000fhH002jK0000ED/000XT00036`00
;3h007hG0<G4003e:`00o@X00=Z;000WV@0005==00098`0011`0035000223`38^`00mb@00?`>003F
UP0069<0001=CP001b4000DM000kA@00R@40cZd00?TJ003j5P00d:L000B;0000?TL000DN00078000
BTd05I800=FH003l3P00mb@00<Nm0000PA8002ho00036`002R@005M:03NN003NO000oP@00?4j002Q
_00007@Z000O=@000QT0014[001T?`1U[000j5/00?l0003YF@00JJd0001T?P004R`0008I000N=@00
M2X0Xk`00?8h003n1@00gH4002nK0000E4`000TS00047000=T<008L40<j]003j6000nAT00<f_0000
QPH003E2000470002B<005E;03JN0000PP3ON`00o`<00?0o002C^00006la000>9P005c0006`e08Vf
003^A000o`800>1f000kW`0005M:000:900011`003E20027103>[000nQL00?TL003;]@0008<>000^
?`000a/000`V001KA`1=Y@00iFP00?l0003ZD`00KJh0001T?`004B/0008J000T>@00NQl0`L@00?HX
003l3P00dih000R=0000?DH000@M00088P00E4`0=Id00>1h003o0P00kTH0086d0000JCT001@]0002
6@0083H007LT0;O1003e:`00o0d00=BK000:SP0003e600047@002B<005E;03^O003QL`00o`400>a=
001c/00006Dn000@:P000QX002Hj001n6@37_@00n1l00?XF003=[P0008D:000_?`000a/000dW001O
A01PZ`00jET00?l0003TJ@00Aj<0001HB@002B@000@L000lAP0:SP00eIT00?d;003d<000Z;h0001b
;0006S80008I000J<P00Lb`0Zkh00?@^003m3000e9`000J<0000>4@000@L000;9@00FdL0E:L00>MN
003o0000iFH004RS0000F4X000TS00047@00@4P04Y400=R@003n1`00lCX0096h0000JcH001@]0002
6@008cP:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0K`00Nah003910005
7P001Ad002lo001i8@2D^@00je800?l0003`?P00^/8000233P00?TL000LP000370009SX0078/07fc
003WH000o`800?<c0037_`0008P20016B`00228000<K000R=`00Kc80LJl00>EV003o0`00m2l00<Vk
0001RP0004U<00098`000a/0024g001^<P1a[`00iFH00?l3003d<000b;d000280P00AT/000PR0003
6`0093T0074^07bb003WGP00o`400?8h0032a00008@<000mA`001R0000@L000[?@00Mb@0TkP00>]@
003o0000kTH00:Fm0000O1`0035000057@001Al003M400204`2g`@00lC`00?l1003XF`00O[<0001a
;P008cP000<K00098`00CDh028d00<ba003f9@00oPP00=mj001>Y@0006=0000F;`000QT0010Z001K
A`0cW@00fHd00?`@003i6P00dj0001^D0000Dd`000/U00036P007SD006dd076_003VHP00o`400?4j
002h`@00080D000e@P0200057P3o000hA000PPl0`/@00?<d003o0`00i6T006B/0000JCX001Tb0002
6@003RP067/U0=V>003l3`00nA/00=6U000CT@00051>00098`000a/002@i001d:P2>]`00k4l00?l0
003/C`00SKL0001d:P0093T000<K000:9000DDd069<00=>P003j6000na<00=JG000SU`0005E;000;
9@000aX0020g001a;P25]@00je800?l0003/C@00S[L0001c:`008cP000<J000;9@00E4`089H00=JH
003k4`00nQT00=6S000BT@0004m>00088P000a/002Xl001j802W_P00l3l00?l1003UI@00IJ`0001W
>`005c00008I000B;000HD<0CJD00>5d003n1000lc<00;k30000OaD00350000470001b4004U<00^>
003@Z000nA/00?/B003EV0007ID0001BC@002B<000<K000Y?000NR00Zkh00?4k003o0P00hfd005JX
0000HT4001</00026@005c0006Tj06b^003WGP00o`000>e9002?^000078]000P=P000QX000dX001J
B00lX000gWh00?h6003d;`00`/@0001o5@00;cl000@L00088P00D4h06I@00=FI003k4@00n1d00<f^
0001RP0003m800067`001Al003m8006:003>[P00nA`00?/B003DW0005Y80001>CP001b4000@M000d
@P00P`d0b;`00?HV003m3000fHl002BH0000DTd000TS00037000;Sl007lE0<G4003e;000o@T00=^8
000/VP0005E;000:90000a/002`m001n6031a000m2d00?d8003KQ`00;I/0001EC0002R@000<K000]
?P00OaH0aL<00?DZ003m2P00fH`002JH0000DTd000TS00047000<T4008<>0<Vj003g8`00o0h00=JG
000GT`0004a=000780001Ad003]60029003>[000nAT00?XG003@Z0000h/0000nA`001Ah000LP001;
C@0GT`00eYL00?`>003g9@00akh000204`00;Sh000<K000:9@00EdX0>9h00=mk003n1000lC/009nl
0000Lb/001he00026@004R/006@o06N]003XFP00o`000>UJ001X[@0006@o000A:`000QT001le001d
:@2T_@00lSL00?h5003MPP00;Y/0001CC0002B<000@L000g@`00R0<0cZ`00?XH003i6P00cK000026
1`00=48000@L00099000ET/0=ih000220=mj003o0`00l400096h0000Kc8000hU000G<000KCD0R[H0
0>m4003o0P00h7L003ZO0000ET/000TT00047000=D<008P30<n[003j5P00nAd00<Zf0000PPl002hn
00036`0032H005a704nV003UI`00o`000>YD001/[P0006@o000@:P000QX002@i001k7P33a000mRL0
0?`?003CW`001hd0000lAP0011d000PR001DC00gWP00h7L00?l2003^A`00P;<0001Y>P004bd0008I
000P=P00N2<0^L800?DZ003l3@00e9`000V=0000?4H000@M00098`00ET/0?:000>9b003o0@00k4h0
07:`0000I3l0010Z00026P009cX007hH0<Rl003h7`00nQH00<f_0000Q0/002ho00036`003BL00613
066[003YF000o`000>AZ0015X`0005Q:00098`0011d003a600^>003EV000o@/00?@a002W_@00078]
000J<P000QT001/c001c:`2]_`00m2h00?`<003DW@001H/0000hA00011`000/U001LA`1FZ000j5d0
0?l0003UI`00Aj<0001GBP002B<000@M0011B00CT@00f8l00?h7003a>`00T;P0001[=`0052d0008I
000T>@[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o001j7`00<D0000DN
00057@00<40007TP09Ji003[D@00o`000?0n002h`P0008<?000mA`001b0000@L000W>P00Lb`0O[<0
0>MO003o0P00lc@00<K00000R0@004E:00088P000a/0028h001_<@1c/000iFD00?l3003d<000b;`0
00290000B4`000PR00036`008SL006la07:`003VI@00o`<00?<a0037_P0008P30015BP00228000<K
000T>@00LRd0O[<00>QM003o0@00lST00<330000P`d003e60006800011`002/m001h8`2E^@00k4l0
0?l0003^A`00Xkd0001l7@00<40000DM00067`00>4@0084B0;S2003a>`00o`400>QL001l/`00074_
000R>0000a/000TS001>CP0:SP00cK000?LU003m2000gg/004fU0000Hd0001D^00026@0042X005a7
03FM003IS000o0l00?TJ003BX@006Y@0001CC0002bD000<J000N=@00KC@0L[000>MQ003o0@00lC/0
0;K10000OaD003A200057P001Al003U500233P34a000lc@00?l3003TJ`00HZ/0001X>P006C40008I
000>:@0INb@0fHd00?`?003i7000d:H001:A0000D4h000TS00036`009CT007@Y08nh003/CP00o`00
0>]@002<]`0007<[000S>0000a/000XT001BC@0IU000dil00?XG003k4`00eIP0026G0000E4`000/U
00036P008CL0074^08Ne003[DP00o`000>a>002<]`0007</000R>0000aX000/U001DC00RU`00eYH0
0?/B003i6@00dJ@0016A0000CTh000PR00036`00:Sd007XO0:Vn003`?P00o`400>EV001S[00006Ll
000F;`000QT0018/001Q@P1?YP00hG<00?h4003c=000_<<0001o5P00<40000@L00078@00BT`038l0
0=2W003i6P00na800=FI000LU@00055=00098`000a/002Xl001j7`2]_`00lCX00?l2003SKP00EJL0
001R@@004R`0008I000G<000JCT0KZl00>QM003o0000kDX008jg0000LBh001lf00026P003RP005]7
03jP003NO@00oPH00?@`0031a00007lF000_?`0011`000PR001@CP0KU000eIP00?/A003h7P00cJl0
002:0000?dL000DN00067`00@4P00X/00<j]003i7000na800=BM000DTP0004e>003c00078@0011d0
03E200243038^`00mbD00?d<003HT0008iL0001BC@002B<000@L000_?`00P1D0aL<00?D[003m2@00
fXT002^J0000E4`000XT00036`00;3h007hG0<?4003e;000o@T00=^8000[VP0005A<000:90000a/0
02hn001o5@35`P00mBT00?d:003IS@0099P0001BC@002B8000@L000b@@00P`d0bKT00?LS003l3`00
eIP001JB0000Bdd000LP00057P00?4H00HX00<n[003j6000nQL00<nY0002RP0003e600057P001b00
04a=01RC003FUP00o0d00?HV0037_`00080D000]?P000a/000/U001GBP0jW`00ggX00?l4003a?000
WK/0001c:`007SD0008I000B;000I3l0JJd00>UI003o0000j5/006J/0000I3l0014[00026@007cH0
07DX0:Jm003b=`00oPH00=b3000/VP0005=<00088P0011`003Q400280P3>Z`00nQL00?TK003</@00
08D8000c@@0011`000XT001FB`0iW`00h7T00?l3003_@@00SkP0001^<P003BD001L`001]=02<]`00
kd<00?l2003PN000>9h0001FB`002B<000@L000f@`00R080cjX00?XE003h7P00b[L000224000;Ch0
00<K000<9P00G4H0D:H00>EV003o0000jUD006Z]0000Hd00010Z00026P009CT007/M0<G4003f9P00
o0l00=>P0006S00003]600047@002B<005E;03RN003PMP00o`800>e8001n/`0006Pj000C;@000QT0
024g001h8`2k`P00mBX00?`>003DW@0028d0000lAP0011d000TS001FB`0nX000hW400?l1003/C`00
L:l0001T?`0042X0008J000W>`00OaL0b;/00?PN003j5`00cK0000243000;Sh000<K000=:000H4<0
Hj/00>YG003o0000i6/004BR0000EdX000TS00047@00?DH038l00=JG003m2P00lc800:Fm0000LBh0
01Ta00026@006c<007@Z0:jo003e;@00o0d00=>N0003R`0003M3000470002bD005a605NX003XG000
o`000>AX0015X`0005M:00098`0011d0045901FB003ISP00oPH00?4l002>]`0006/g000C;@000QX0
02@i00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o001j8000<40000DN
00057P00<40007XP09Nj003[D000o`000?0o002f`@00088@000lAP001b0000@L000W>`00Lb/0P;<0
0>QM003o0@00lcD00<K10000Q`D004E:00088P000a/002<h001`<01d/000iV@00?l3003d<@00b;d0
00290000Ad/000PR00036`008SP006la07B`003VH`00o`800?<b0037_`0008P40014BP00224000<K
000U>@00LRd0Ok<00>QL003o0@00lCT00;k30000P`h003a60006800011`002`n001h8`2F^@00k4h0
0?l0003^B000X[`0001k7@00<40000@M00067`00>D@0084A0;[2003a>P00o`400>QM001k/P00070`
000R=`000a/000TS001>CP0;SP00cJl00?LT003m2@00gg`004^U0000HT4001D^00026@0042X005a6
03JN003JR`00o0l00?TK003BXP006I<0001CC@002bD000<J000N=@00KS<0M;000>MP003o0@00lC`0
0;C10000OaH003=200057@001Ql003Y500233@35a000lc<00?l3003SK000H:/0001X>`006340008I
000?:@0IO2@0fH`00?`>003i7@00d:L0016@0000Cdh000TS00036`009CX007DX096h003/C@00o`00
0>]A002:]P0007</000S>0000aX000XT001BC@0JU000dih00?XG003k5000eIT0022F0000E4`000/U
00036P008CL0078]08Rf003[D000o`000>a?002:]P00078/000R=`000aX000/U001DC00SU`00eYD0
0?/A003i6P00dJD0012@0000CTh000PR00037000:cd007/N0:^n003`?@00o`400>EW001RZ`0006Hl
000F;`000QT0018/001Q@P1AYP00hW800?l4003c=000^/80001n5`00;cl000@L00078@00Bdd03Xl0
0=6V003i6@00na<00=FK000JU000055=00098`000a/002Xm001k7P2__`00lCT00?l3003SK`00DjL0
001R@P004R`0008I000H<@00JCT0L:l00>QL003o0000kD/008bg0000LBh001le00026P003RP005]7
03nQ003NO000oPH00?@a002o``0007hG000^?`0011`000TR001@C@0LU@00eYL00?`@003h7P00cK00
00290000?TL000DN00067`00@DP018/00<j/003i6`00na<00=>N000CT@0004a=000g00078@0011d0
03I300242`39^P00mb@00?`=003HT@008YL0001BC@002B<000@L000_?`00P1@0a/800?DZ003m2P00
fXX002ZJ0000E4`000XT00036`00;Ch007lF0<G4003e;000o@T00=Z9000ZVP0005A<00098`000a/0
02ho00205036`@00mRT00?d;003ISP008iL0001AC@00228000@L000c@@00Q0`0bKP00?LR003l3`00
eIT001FB0000Bdd000LP00057P00?DH00XX00<nZ00020?XH002j0<nZ0001RP0003a600057P001b00
04e>01VD003GU@00o0d00?HW0036`00007lE000/?P000a/000/U001HBP0kW`00ggT00?l3003`?@00
W;/0001b;0007C@0008I000B;000ICh0JZh00>UH003o0000j5`006B/0000Hd00014[00026@0083H0
07DX0:Rn003b=P00oPH00=b4000[VP00059=00088P0011d003Q400290@3?ZP00nQH00?TK003</P00
08D9000b@@0011`000XT001GBP0jW`00h7L00?l2003_@P00S[L0001^<`003BD001Pa001^<`2>]`00
kd800?l3003ON@00=ih0001EB`002B<000@L000g@`00R@40cjT00?XE003h7P00bKP000214@00;3h0
00<K000<9`00GDH0DZH00>EU003o0000jUH006R]0000Hd00010Z00026P009CX007`L0<G3003f9@00
o1000=:Q0005S00003]500047@002B<005E;03VO003QM@00o`400>e9001l/P0006Pk000C;0000QT0
024g001i8P2l``00mRT00?`>003CWP001X`0000kA@0011`000TS001FBP0oX@00hW000?l1003[D000
Kjl0001T@00042X000<J000X>`00OaH0bKX00?PM003j5`00c;4000233@00;Ch000<K000>:000H4<0
I:`00>YF003o0000hf`004:R0000EdX000TS00047@00?TL03Hl00=JF003m2P00lc800:>m0000LBh0
01Ta00026@0073<007@Y0;30003e;000o0d00=>O0002R`0003I3000370002bH005e605VY003XF`00
o`000>AZ0014XP0005I:00098`001Ad0049901JB003IS@00oPH00?4l002<]`0006Xh000C;@000QX0
02Di2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l007TQ000`@0001Ah0
00DN000a@000NQl0VKX00>a?003o0000l4000;G10000PQ4003a60006800011`002Pk001d:P22]000
j5`00?l1003b=P00aL8000271P00A4X000PQ00036`008cP0070`07Ja003VH`00o`800?<b0037_P00
08P20016B`00228000<K000S>000L300M[400>IR003o0P00lc<00<K00000Q`D004=900078@000a/0
02Dj001c;021]000j5/00?l1003a>P00_<8000223`00>dD000HO00047@00;Ch007TR09Rj003/C@00
o`000>e9002P_00007/N000_?`0011d000HO000jA@00PQ00_<800?4i003o0@00iel007Vb0000L300
024g00036`002B<004m>00b?003>[P00mb<00?d9003NO@00BZ@0001R@@0052h0008I000A:`00G4H0
>9h00=Z:003l3P00nA`00=6S000GT`00059=000;9@000aX001lf001^<P1f/@00iel00?l1003a?@00
//00001n5`00<d4000DM00067`00>dD008@<0<G3003c<P00o`<00>=]001OZP0006Lk000H<@000QT0
00lY01Yl903JR`00o0h00?PM003@Z0003i00001?CP002B<000<K000V>P00MBP0TkP00>e<003o0000
je8008Rf0000LRd0028h00036P002R@0059=01bE003DW@00nQH00?/D003EVP007iH0001CC0002bD0
00<J000R>000LR`0R[H00>]?003o0000je0008Rf0000LRd0024g00036P002bD005E;02FH003GU000
na400?TK003@YP003i00001=CP00228000@L000/?@00Nad0[Kl00?4l003o0P00i6P0062[0000ISd0
01H_00026@004b`0069105:W003RL@00o`<00?8e002h`P0007hH000_?`0011`000PQ001<C@0?T000
dJ@00?XI003k5000e9`001VD0000D4h000TS00036`00:cd007/M0;70003b>000o`<00>9`001BYP00
0652000B;0000QT001Pa001Z>01a/000j5/00?l0003/C000R[H0001a;`007SD0008J000>:000G4L0
@J400=mk003n1@00lc400;g30000OQP002dn000370002B<0055=01fE003FUP00o1000?PO003</@00
08T1000mAP001Ah000HO0012B@05S000cjX00?TJ003k5000dil001:A0000Bdd00?<000LQ00047@00
=T<008D:0<Vi003g8`00o0d00=NB000PUP00055=00098`0011`0031000214P36`@00mBT00?d:003J
R`00:9T0001CC0002B<000<K000^?P00OaD0aL<00?D[003m2@00fXX002VI0000Dd`000TS00037000
;cl0080C0<K0003f:000o@/00=R?000QU`00055=00088P0011`003A200242`3:]`00n2400?`@003E
VP004i40001:C0001b0000DN000nA`03R`00cjT00?XG003j6@00cZ/000290000>dH000DM00078@00
CTh06Y@00=NC003m3000mRL00<K10000OaH002`m00036`002bD005Q903fP003PN000o`<00?0n002J
^P00078]000M=0000QT0018/001U?P1/[P00jEL00?l0003XG@00Hj/0001S@0004B/0008J000P=P00
MRL0Z[h00?<e003n1P00g8D002VI0000DTd000PR00047@00>DD008T00<nY003j5P00nA`00<^c0000
Q0X00391000370002R@005M:03bP003PMP00o`800>m3002<]`0006dd000=9@00634006hc092h003_
@@00o`<00=mj000eW@0005E;00098`0011`003Q40029003@Z000na@00?PO0039^P00084B000/?@00
0a/000dW001MAP1DY`00iV@00?l0003YE`00Ijd0001R@@003bX0008J000V>P00O1/0aL800?LT003l
4@00dZ8000B;0000>TD000@L00098`00ET/0>il00>5d003o0@00kDX007Zb0000Ic/0018/00026@00
8SL007TQ0;k3003f:000o0l00=>O0005S00003Y5000470002B<005M:046Q003SK`00o`000>]A001]
[P0006=0000?:@000aX002Pk00205@39^@00nAd00?XH003</P0008<>000/?P000aX000hX001Q@P1V
[000jU@00?l0003SK@00@J40001FB`002B<000@M000oA`0?T000eYD00?d9003c<`00XK`0001`;`00
6340008I000L=000MBT0//000?D[003l3P00dZ40006:0000=D<000<K000<9P00GDH0FjT00>QJ003o
0000i6/004:R0000ET/000PR00057@00@dT05i<00=Z<003n1P00l3d008^f0000JSP001</00026P00
9CX02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo09<007TQ000_?`001Ad0
00DN000b@@00Nah0Vk/00>a>003o0000kd400;?00000PA8003]50006800011`002Pk001d:@24]000
j5/00?l1003b=`00aL<000261`00@dT000PQ00036`0093T0074_07Ra003VHP00o`800?<b0037_`00
08P30015BP00228000<K000S>000L2l0N;400>MQ003o0P00lc@00<K10000QPH0049900078@000a/0
02Hj001c:`23]000jEX00?l1003a>`00^/8000224000>TD000HO00047@00;Ch007TQ09Zj003/C000
o`000>e:002N^`0007XO000^?`0011d000HO000jA@00PPl0_/<00?8h003o0@00if0007Na0000Kc40
024g00036P002R@004m>00f?003>[@00mb800?d9003NOP00B:<0001Q@P0052h0008I000A:`00GDH0
>Il00=^9003l3P00nA`00=6U000FTP00059=000:9@000aX0020f001_<P1h/@00j5d00?l1003`?P00
/<00001n6000<T4000DM00067`00?4H008@;0<K2003d<@00o`@00>=^001MZP0006Ll000H<0000QT0
00lY01]m903JRP00o0d00?PN003?Z@003Xl0001>CP002B<000<K000V>P00MRL0UKT00>e;003o0000
je<008Je0000LRd0028g00036P002bD005=<01fE003DW0000P3j5@00o`3DV`007ID0001CC0002RD0
00<J000S>000Lb/0S;L00>a>003o0000je4008Je0000LBh0024g00036P002bH005E;02JH003GT`00
o1000?TK003@Y`003Hl0001<C@00228000@L000/?P00O1`0[kl00?4k003o0P00i6T005jZ0000ICd0
01D_00026@004bd0069105BW003RL000o`<00?8f002f`@0007dI000^?`0011`000PR001=CP0@T000
dJ<00?XH003k5000e9d001RC0000D4h000TS00036`00;3d007`L0;?0003b=`00o`<00>9a001@YP00
0652000A:`000QT001Ta001Z=`1c/000jEX00?l0003/C@00R;H0001`<0007SD0008J000>:@00G4H0
@Z800=mj003n1@00lc800;_20000OAT002dn00036`002B<0055=01nF003GU@00o0l00?PP003</P00
08P3000lAP001Ah000HO0013B@06S000cjT00?TJ003k5000dj00012@0000BT`000LP00047@00=d@0
08D90<Zg003g8`00o0h00=NC000OUP00055=00088P0011`0035000214@36`000mRP00?d:003IS000
9iP0001CC0002B<000<L000^?`00P1@0aL800?DZ003m2P00fX/002NI0000Dd`000TS00047000<400
084B0<No003f9`00o@`00=R@000PUP00051=00088P0011`003E200252P3:]P00n2000?`@003DW000
4Y400019C0001R0000DN000oA`04R`00d:L00?XG003i6@00cZ`000290000>TD000DM00078@00Cdh0
79D00=NB003m3000mRP00<G20000OQL002/m00036`002bD005U903jP003PM`00o`<00?0o002H^P00
074^000L=0000QT001<]001V?@1^[`00jUH00?l0003WGP00HJ/0001R@@0042X0008J000Q=`00MRH0
[;l00?<d003n1`00fhH002RI0000DDd000PR00047@00>TD00HX00=2X003j5@00nAd00<^d0000Q0`0
035000036`002R@005M:03fP003QM@00o`800>m4002:]P0006de000=9@006C4006lb09:h003`@000
o`<00=mk000dW@0005A<00098`0011`003Q4002:003@Y`00na@00?PP0038^`00080C000[?@000a/0
00dW001NA@1EY`00iV<00?l0003YF000IJ`0001R@@003bT000<J000V>P00GP00OAX0a/400?LT003k
4@00dJ<000:;0000>D@000@L00098`00ET/0?J000>5c003o0@00kD/007Rb0000Ic`0018/00026P00
8SP007XP0<33003f9`00o0l00=:Q0004R`0003U5000470002B@005M:04:R003SK@00o`000>]B001[
[P0006=1000?:@000aX002Tl00205039^000nA`00?XI003;/`00088?000/?@000aX000hX001Q@P1X
[@00jU<00?l0003SK`00?j40001FB`002B<000@M0010B00@T000ei@00?d9003c=000Wk`0001`<000
6340008I000L=000MBP0]<400?DZ003l3P00dZ8000290000=D8000<K000<9P00GTD0G:X00>UI003o
0000hf`0042Q0000ET/000PR00057P00A4X06I<00=Z:003n1@00l3h008Vf0000JCT0018/00026P00
9SX:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`00N28002ho00057@00
1Ah00391001k7@2M^`00k4d00?l0003_@P00/L0000204`00>TD000HP00047000:C`007DX08Je003Y
FP00o`400?8h0034a00008H80012B@001b4000<K000T>@00LBh0N[800>MQ003o0P00lc<00<K00000
Q`@004A:00088P000a/002@i001a;P1j/P00if000?l2003c=@00aL8000261`00@DT000LQ00037000
9cX007@Z08Fe003YF@00o`000?4l002h`P00084A000iA@001Ql000@M000^?`00NR00W;/00>e;003o
0000kD/009bk0000NB0002dn00047@001Ql003]600233P30``00lSL00?l1003WH@00MK40001_<P00
83H000<J000:9000D4h03i000<j[003g8@00o@X00=eo0016X`000652000D;@000QT0014[001MA@0k
W`00fhL00?`=003h7@00dJH001BB0000DDd000XT00036P0083H006la07Zb003XG000o`400?0o002^
_`0007dI000a@00011d000HO000mAP00Q@X0a/000?@`003n1000hVl005^Y0000ISd001L`00026@00
3bX077dT0=^8003l3@00n1l00<nZ000=S`0004e>00088P000a/002Lk001f9P2G^@00kDX00?l0003Z
E000Q;D0001a;P008CL000<J000;9@00Dd`07iH00=FJ003k5@00nQH00=BL000LU@00059=000:9000
0aX002<h001c:`2>]`00k4d00?l0003[D`00QKD0001a;`0083H000<J000<9P00ET/0:9T00=NB003l
4000nA`00<nY000<SP0004]=00088@0011`002dn001l6`2a`000lCX00?l2003TJ`00G:X0001U?P00
5Bh0008I000C;@00Hd00EZP00>=_003o0`00lSL00;C10000OAX002dn00047000228004i>01:A003B
XP00nQL00?XE003CWP005Y80001?CP00228000<L000/?P00O1/0]L400?8f003o0`00hG8004jU0000
H4<0014[00026@006C8006/g07Fa003YF@00o`000>a>0026]@0006la000M=0000QX000lY001MAP14
XP00h7T00?h5003c<`00^L80001m6P00;3d000<K00098`00DTd089H00=NC003l3P00n2400<^d0000
Q`@003]500057P001Ql004A:00N=003@Z000nAT00?XE003BX@003i000019C000l`001b0000DM000h
A000QPL0b[H00?LR003l3P00ei@001fE0000D4h000PR00047000<D40088@0<Nn003f9`00o@/00=V=
000UV000059=00098`0011`002lo00204`36`@00mRT00?d:003IS0009IP0001BC@002B<000@L000`
@000PA40akh00?HV003m3000f98001jF0000D4h000PR00047@00=T<008D90<^e003h7`00na400=BM
000AT00004Q;000680001Ah0041800J<003@YP00nQH00?TJ003>[P0008P2000jA@0011d000LQ001?
CP0MU@00f9400?d;003f:@00aL<0001n6000:Sd000<K000;9P00FDT0@:400>5e003o0`00l40009Ji
0000LBl001`c00026@004bd006Hl072_003ZE@00o`000>MO001OZP000691000@:P000QX0024g001g
9@2^_`00lc<00?h7003KR0009YP0001AC@00228000@M000kA@02RP00d:L00?/D003h7@00b[H00023
3@00<40000<K000:9@00F4T0?j400>5d003o0P00kTD008Rf0000K3D000dU000I<P00Kc40TkT00?0o
003o0`00gWd003:L0000E4`000TR00047@00>DD00HX00=6U003k4`00n2400<Rl0000P1@002Xm0003
6P003BL005i505NX003VH@00o`000>UJ001SZ`000652000?:@000aX002Lk001m6@36`000mb<00?/B
003AY0000HX0000hA00011`000TS001GBP0nX000hW400?l1003/C@00Mk40001V?@004R/0008J000S
>000NQl0`/@00?HV003l4000dZ8000>;0000>4@000@L000:9000F4X0A:800>=/003o0000jU@006V]
0000HT4000lY00036P00:S`0084C0<Zg003i6`00nAT00<^d0000PQ0002/m00036P003RT0069106Z]
003[DP00o`000>9`000mX00005E;00088P001Ad0045801:A003GTP00o@P00?8e002M^`0006la000G
<0000QT001dd001f9`2f`@00mBT00?`?003BX`0008T1000d@P000a/000`V001NA@1NZP00jEP00?l0
003SK@00?j40001EB`00228000DN0015BP0JU000fXT00?h5003`@000QkD0001Y>P004R`0008J000W
>P0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`00N2<002dn00047@00
1Ah003=2001l702O_000k4`00?l0003_A000[[l000205000>D@000HO00047000:S`007DX08Rf003Y
F@00o`400?4i0033a00008D90011B0001b4000<K000U>P00LRd0O;800>MO003o0P00lc@00<K10000
Q`D004=900088@000a/002@i001a;P1l/P00iel00?l1003b=P00aL<000252@00@4P000LQ00047000
9c/007@Y08Ne003YE`00o`000?0m002f`@00084B000hA0001Ql000@M000_?`00NQl0W[/00>e9003o
0000k4`009Zj0000NB4002dn00047@001R0003a600243032a000lSH00?l2003VHP00Lk00001^<`00
83H000<J000:9000D4h049000<nZ003h8@00o@X00=f10015XP000613000C;@000QT0018[001NA@0m
X000fhH00?`<003h7P00d:L001>A0000DDd000XT00036P008CL0070`07bb003XF`00o`000?10002/
_`0007dJ000`@00011d000HO000nA`00Q@P0akl00?@_003n1000hW0005VY0000ISd001L`00026@00
42X07GhS0=^7003m3000n2000<j/000;SP0004a=00088P000a/002Pk001g9@2I^P00kDP00?l0003Z
E@00P[@0001a;`0083L000<J000;9@00E4`089H00=FI003k5000nQH00=>N000JU000059=000:9000
0a/002@i001d:P2@^000k4`00?l0003ZE000P[@0001`<0007cH000<J000<9P00ET/0:IT00=R@003l
3`00n1d00<nZ000:SP0004Y<00088@0011`002ho001m6P2c`000lST00?l2003SK000FZT0001T?`00
5Bh0008I000D;@00Hd00F:P00>=]003o0`00lSP00;;00000O1/002`n00047000228004m>01>A003B
X@00nQL00?XF003CW`005I80001?CP00228000@L000]?P00OAX0]l400?8e003o1000hG@004bU0000
H4<0014[00026@006S8006`f07Na003YE`00o`000>]?0024]@0006la000M=0000QT000lY001MA@16
X`00h7L00?h4003c=000]l40001l6`00:cd000<K00098`00DTd08YL00=NB003l3P00mb800<^e0000
Q`D003Y500057P001R0004E:00V=003@Y`00nQP00?XF003BXP003Hl00018B`00_@001b0000DM000i
A000QPH0bkD00?PQ003l3`00eYH001bE0000D4h000PR00047000<T40088?0<Nm003f9P00o@`00=V?
000TU`00059=00098`0011`0031000214P36`000mRP00?d;003ISP0099L0001BC@002B<000@L000a
@000PQ00b;d00?HU003l3@00ei<001fE0000Cdh000PQ00047@00=T<008H70<^d003h7`00na800=>N
000?T00004I;00067`001Ah0045800N<003AY@00nQD00?TK003=[`0008P3000iA00011d000PQ001@
CP0OUP00f9000?d;003e:P00a<@0001m6@00:S`000<K000<9P00FTP0@Z800>5d003o0P00kd4009Bi
0000L2l001/c00026@0052d006Ll07:`003ZE000o`000>MQ001MZP000652000@:P000QX0028h001g
902``000lc800?h8003JR@009IP0001AC@00224000DM000lAP03R`00dJD00?/D003h7P00b[L00023
3P00;cl000<K000;9@00F4T0@J400>5c003o0P00kTH008Je0000K3H000`T000J<P00L300U[T00?0n
003o1000gWh0032L0000Dd`000PR00047@00>TD00h/00=6T003k4P00mb400<Rm0000OaH002Xl0003
6P003BP005m405VY003WH000o`000>QK001QZ`000652000>:@000aX002Pk001n6037_`00mb800?/B
003AYP0008T0000gA00011`000XT001GBP10X@00hW000?l1003/CP00MK00001V?@004B/0008J000S
>000Nah0a<@00?HU003l4000dJ<0006:0000=d@000@L000:9000F4T0AZ<00>A[003o0000jUD006N]
0000HT8000hY00036P00:Sd0084A0<Zf00020?TJ000d0<^f0000PA8002Xm00036P003bT0069106b^
003[D@00o`400>9a000kW`0005E;00088P001Ad0049901>A003HT@00oPP00?8f002K^`0006lb000G
<0000QT001he001f9P2h`P00mRT00?`@003AY00008P2000c@@000a/000`W001OA01PZ`00jEL00?l0
003SKP00?J00001EB`00228000DN0016B`0LU@00fhP00?h5003_@@00QKD0001X>P004R/0008J000W
>`[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`37001g9000;Ch000@M0005
7P00=48007dK0::l003]B`00o`000>i5002/_`0007lE000hA0001Ql000@L000Z?@00MRL0R[H00>UH
003o0@00lCX00<330000Q0/0041800078@000a`002Hj001b;01n/`00ieh00?l1003b=P00aL800026
1`00@TT000LQ00036`009CT0078]07jc003XGP00o`400?8g0034a00008D:000oB0001b0000@L000X
>`00MBP0RKH00>YF003o0000l3l00;C00000P1@003M400067`0011d00310001k7P2P_000kDP00?l0
003/C@00V;X0001h8P00;3h000@L00068000?DL008@;0<C4003b=@00o`800>IS001a[`0006dc000O
=P000aX000XT001AC@0BT@00cjT00?PP003m2`00gH8004>R0000H4<001<]00026@004R`005m403nQ
003LQ@00o@`00?PO003@Z0004I40001@CP002R@000<J000Q=`00L2l0O[<00>UJ003o0000kd400:Zn
0000O1/002lo00047@001R0003i700261`37_P00m2h00?h5003RLP00EjP0001U?P005Rl0008I000@
:P0NOR<0fhH00?d;003h8@00cZd000Z>0000Bdd000PR00036`00:C`007LT09^j003^A`00o`000>YG
0020/`00070`000P=P000aX000/U001DC00RU`00eIP00?/C003j5`00dil001VC0000DDd000XT0003
6`0093T007DY09:h003]B`00o`000>YE0020]000070`000O=@000QX000`V001GBP0[VP00f8l00?`>
003h7P00cZ/000V=0000BD`000LQ00047000;cl007dI0;G1003b>000o`<00>=]001HZ00006@o000D
;P000QT001@^001T?`1IZ@00hf`00?l2003a>@00/<00001l7@00;3d000<L00088P00Cdh05I800=>O
00020?XF003o0=:Q000CT@0004i>00088P0011`002ho001m6@2i`P00lc@00?h4003QM@00BZ@0001O
A00042X0008I000J<P00K3D0NK800>YF003o0000je4008:d0000KS8001`d00026@003bT005i504RS
003PMP00oP@00?8e002d`@0007`L000Z?@000a/000TT001CC00SU`00f9400?`=003g8P00b[H00026
1P00>DD000DN00068000AT/02Xh00=6U003j5`00nQH00=6T000<SP0004M;000680001Ah003Y50027
1@3;]000n2000?`?003FU`006Y@0001?CP00228000@L000c@@00P`h0b;`00?HV003m3000f90002:G
0000DDd000TS00047000<D00084A0<Nn003f9`00o@/00=R?000RU`00055=00088P0011`003910023
3P38^`00mb@00?`=003GU0006i@0001?CP001b4000@M000gA000Q`H0c;<00?PN003k4P00dil000j?
0000ADX000HO00057`00@TT028d00=6T003k5000nA`00<f`0000Q`@003Q400047@002240051>026F
003ISP00o@X00?D[0032a00007dJ000Y?0000a/000`V001JB014XP00hG<00?l2003_@P00T[P0001`
<0006c<0008I000D;@00J3/0M;000>]C003o0000iV8005^Y0000HD8000lY00026P008cP007PS0;;0
003d<@00oPP00=Z:000SU`00051>00078@001Ad003e600F<003AY000na<00?PO003:^000088?000_
?`000a/000/U001IB@13XP00hW400?l1003^A`00Q;D0001[=`0032@001Xb001`;`2H^P00lC`00?h4
003NO`00;i/0001CC000228000@M000kAP04R`00dZ<00?/B003g8P00akh0001o5`00:C`000<J000>
:000Gd@0FjT00>MO003o0000j5`005nZ0000H4<000hX00036P00:3/007lG0<Nn003g8@00na<00=2W
0000R@4003I3000470002R@005Q:04:R003SK`00o`400>a?001c/00006Dn000A:`000QX002@i001k
7@35``00mb@00?/A003AY00008X0000f@`0011`000XT001IB@18X`00i6X00?l0003ZEP00IJ`0001Q
@P003RP000<J000[?@00PQ00bkD00?TJ003i6`00b[L000214`00:C`000<J000?:@00Hd00KZl00>]@
003o0@00hG80000Z03ZO0000E4`000PR00057P00@dT05I800=R@003n2000lSL009Vj0000KS8001L`
00026@007SD007LU0;_2003f:000o1000=6U0000R0<0039100036`003BL005m406:[003ZE@00o`00
0>9`000kW`0005A<00088@001Ah004M;01fE003KQ`00oP@00>m20023]00006Pk000A:`000QX002Pk
2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?X007LU000/?@0011d000HO
000e@P00OAT0Y;d00>e9003o0000kTH00:Zn0000OaH003M300067`0011d002/m001f9P2<]`00jUH0
0?l0003a>`00_/<000243000?dL000LP000470009SX007<[082d003XG@00o`400?8g0035a00008H8
0011B0001b4000<K000V>P00Lb`0P;@00>QL003o0@00lSP00<;40000Q0/003i70007800011`002Tl
001e9`2;]P00jUD00?l0003`@000/L0000205@00=d<000DN00057@00<40007/M0:>l003^A`00o`00
0>a>002E^@0007PS000[?@0011`000HP000nA`00Q@X0aL<00?<d003o0P00iVD006n_0000KC@001he
00036P002RD0055=01>A003@Z000n1l00?d<003LP`00@J40001OA0004b`0008I000B;000Gd@0@:40
0=b3003m2`00n2000<nZ000@T000051>000:90000a/0028g001a;P20]000jEP00?l0003_@P00Z;h0
001l7@00;cl000@M00068000@4P008L60<Rm003e;@00oPD00>5c001EY`0006@o000F;`000QT0010[
01mo8`3LQ000o@/00?LR003=[P0028d0001:C000228000<L000Y?000N2<0WK/00>i6003o0000jEP0
07jc0000Kc4001lf00036P0032H005E;02BG003FUP00na<00?XH003BX0005i<0001AC@002B@000<K
000U>P00MBP0UKT00>e:003o0000jUH007jc0000Kc4001he00026P0032L005M:02fK003ISP00o0h0
0?PO003>[@0028d00017B`001b4000@L000_?`00OQP0^<400?8f003o0`00hfh005JX0000Hd0001@]
00026@005Bh006Dn05bY003TJ`00o`800?4k002^_`0007/N000[?@000a/000TR001@CP0FT`00dih0
0?XE003j5`00dZ80016A0000CDh000PR00047000;cl007hH0;_2003c<`00oP@00>1f0019Y00005i4
000@:P000QT001/c001]=@1k/P00jUD00?l0003[DP00P;<0001^<`0073<0008I000@:P00GT@0BZ@0
0>5e003o1000lSH00;;00000Nah002Xl00036`002R@005=<02FH003HS`00o0d00?LS003:]`0008H8
000hA0001Ad000LP0017B`0<SP00dJ@00P3j5`00=@3AY@002Xh00016BP001R0000DN000kA@00R0<0
c;800?PO003l4000eIP001VC0000Cdh000PQ00047000=48008@=0<Rk003g9@00o0d00=RA000PUP00
055=00088P0011`0035100224037_@00mRH00?d<003HT0008IH0001AC@00228000@L000c@@00P`d0
bKX00?LS003l3P00eYH001ZD0000CTh000LQ00047@00>4@008L50<ba003i7@00na<00=:Q000<S`00
04A:008000HO0;l004=900Z>003BXP00na@00?TM003</@0008L6000g@`0011d000PR001AC@0RU`00
fHd00?d:003e;000`<<0001l6`00:3/000<J000<9`00FdL0AZ<00>9a003o0P00kd<008nh0000Kc40
01Xb00026@0052h006Pj07Ja003[D@00o`000>IS001IZ@000613000?:@000QX002<h001i8P2e`@00
m3000?d8003JS0008IL0001@CP001b4000DM000nA`06S000dZ<00?/B003h8000bKT000224000;Sl0
00<K000;9@00FTP0A:800>9`003o0@00kDT008:d0000JSL000`T000K<`00LBl0V[X00?4k003n1@00
gH4002fK0000DTd000PR00047@00?4H01X`00=:Q003k4@00mb<00<K00000OQP002Pk00036P003RP0
061305fZ003XGP00o`000>QM001MZP000613000>:0000aX002Tl001o5P38_000n2000?/D003@Z000
08P2000e@`0011`000XT001HB@14XP00hfd00?l0003[D000L:l0001U?P0042/0008J000U>@00O1`0
a/800?LS003k4P00dJH000290@00=T<000@L000:9@00FDP0BZ@00>AX003o0000jEL006>/0000H4<0
00hX00036P00;3h0088?0<^c003j6@00nA`00<Zh0000P1@002Tl00036P003bX006@o072_003/C`00
o`400>5d000hWP0005A<00088P001Ah004A:01JB003ISP00oPL00?8h002G^@0006hc000F;`000QT0
01le001g902m``00mRL00?/A003@Y`0008L5000a@0000a/000dW001P@`1T[000jU@00?l0003RL@00
>Il0001DC000224000DN0018C00OUP00g8D00?h4003_@`00P;@0001W?0004B/0008J000Y?00:oooo
o`7o00000Oooool001kooooo0ol00007ooooo`3o001f9P00:cd000@M00067`00=T<007hH0:Jm003]
B000o`000>i7002X_P0007hH000f@`001Ql000@M000/?P00Mb@0S[L00>YE003o0000lC`00;c20000
P`d003i70007800011`002Lk001d:P22]000j5/00?l1003b>000a<@000252@00@4P000LQ00037000
9SX007<[08:d003XF`00o`400?4i002o``0008@=000mA`001b0000@L000Z?000MRH0S[L00>YC003o
0000kd400:no0000OaH003I300057P001Ad00350001l6`2U_@00kTH00?l0003[D000TkP0001g9000
:Sd000@L00078000?dP008D80<K2003c<`00o`<00>EV001][P0006`e000N=@000aX000/U001BC@0E
TP00d:H00?PN003m3000g8D003nQ0000Gd@0018/00026@004b`0061304:R003MPP00o@/00?PQ003?
Z`003Xl0001?CP002B<000<K000S>000LRd0P[@00>UG003o0000kd<00:Fm0000Nah002ho00047000
1b00045800271038^`00mB`00?h6003QM@00DjL0001T?`005Bl0008I000A:`0OOb<0g8<00?d:003g
8`00cK0000N<0000BD`000PQ00047000:S`007TR0:2l003^A@00o`000>UI001l/P0006lb000O=@00
0aX000`V001FB`0UV000eYD00?/B003j6@00dZ8001FB0000D4h000TS00036`009SX007HW09Ni003]
B000o`000>UH001l/P0006hb000N=@000QX000dW001HB@0_V`00fH`00?`=003h8000cJh000J<0000
AT/000LQ00047000<40007lG0;[2003b=@00o`<00>9`001DY`0006=0000C;@000QT001D^001U?P1N
ZP00i6T00?l2003a?000Zkl0001j7`00:S`000<K00098`00D4h069<00=BM003k5000nQP00=6S000@
T00004a=00088@0011`002lo001o5P2n``00lc800?h5003PN000Aj<0001NA@0042X0008I000K<`00
KC@0O[<00>YC003o0000jU<007jc0000KC@001/c00026@0042X005m404bU003QL`00o`<00?8h002`
`00007XO000Y?0000a/000XT001DC00WV@00fHh00?d<003g9000bKT000252@00=d@000DM00078000
B4`03Hl00=:S003j5P00nQP00=2W0009S@0004A:000b00067`001Ah003a600280P3</@00n1h00?/A
003EVP005i<0001>CP001b4000@M000e@P00Q0/0bKT00?LT003l3@00ei<001jF0000D4d000PR0004
7000<T4008<>0<Rl003g9@00o0d00=NB000OUP00051>00088P0011`003A200243039^@00mb800?`?
003FU`0069<0001=CP001b4000@M000iA@00R0<0cK000?TL003k5000dZ8000Z>0000@dT200067`2o
0014BP0;SP00dZ400?/C003h7@00c;<000261`00=T<000@L00088P00DDd099P00=Z<003m2@00mBd0
0;g30000Nad002Lk00036P003BL005]704NS003RL000o`800>i4002=]`0006lb000J<P000QT001D^
001Y>P1h/@00je000?l0003VI@00EjP0001OA0003bT0008J000T>@00NB40]l400?@_003m2@00fHd0
022F0000Cdh000LQ00057P00?dL028d00=:Q003k4P00n2400<Rk0000PA8002dn00036`002bH005Y8
04JS003SKP00o`400>e:001o/`0006Xh000<90006c<0074^09bk003a>P00oPD00=f2000[VP00059=
00088P001Ad003e700N=003CX000o1000?LT0036`@0007dI000W>`000aX000hY001P@`1OZP00j5`0
0?l0003WG`00FjT0001OA0003RP000<J000Z?000P1@0b;/00?PO003k5@00cjX000280`00=48000@L
000:9000FDT0AZ<00>=/003o0000je4006j_0000I3l0010Z00026P009CX007dK0<K1003g8`00na<0
0=2W0000R08003E2000470002bD005Y804bU003UI`00o`000>UI001QZ`000613000=:0000a/002dn
00233P3</P00nQP00?TM0039^@0007lE000X>`000aX0010Z001T?`1b/000k4d00?l1003QM@00=Yh0
001CC000224000DN0015BP0HT`00fHd00?h7003a>P00UKT0001]=0005Rl0008I000O=P00N2<0_l<0
0?HV003k4P00d:P000271P00<40000<K000=9`00H4<0IZ`00>]C003o0000hG8003NN0000Dd`000LQ
00057P00BD`08IH00=b4003o1000kd@007jc0000IS`0010Z00036P00:S`02?ooool3o`00007ooooo
000Nooooo`03o`000?oooooooooo00Oooooo03T007DX000Z?@0011`000HO000g@`00OQL0Z;h00>i7
003o0000kDT00:Fm0000OAT003E200057`0011d002dn001h8`2A^000jU@00?l0003`?@00^L800022
3`00?DH000LP00047000:3/007@Y08Fe003YFP00o`400?4i0031a00008@;000oA`001b0000@L000W
>`00M2X0QKD00>UI003o0@00lC/00;g30000P`h003a60006800011`002Xm001g9@2@^000je800?l0
003_@P00[Kl0001n5`00=D800P001Ah0mP00<T4007dJ0:Nn003^A@00o`000>]A002A^00007HV000Z
?00011`000LP0010B000QPL0a/000?<b003o0`00iFP006^^0000K3H001dd00036P002bD0059=01NC
003AY@00nAd00?`=003KQP00?J00001NA@004R`0008I000C;@00H4<0A:800=f0003m2P00mb800<j/
000=S`0004m>00098`000a/002<h001b;@24]@00jUH00?l0003^A@00Xk`0001j7`00;Ch000@L0007
8000@TT008P30<Vj003e:`00oPH00>1f001AYP0006=0000E;P000QT0014[02208`3MP@00o@X00?LT
003</@001H`00018B`00224000@L000[?@00NB40X[`00>m3003o0000j5/007Vb0000KS<001he0002
6P0032H005I;02NI003GT`00na400?TJ003AX`005940001@CP002B<000<K000W>P00MRH0VKX00>i7
003o0000jET007Zb0000KS<001dd00026P003BL005Q9032L003JR`00o0d00?PQ003=[`0018/00015
BP001b0000@M000a@000OaH0_<<00?<d003o1000hW4005:W0000HT4001<]00026@005Rl006Hm062[
003UJ000o`800?0m002Y_P0007XP000Y?0000a/000TS001AC@0JU000e9/00?/C003j6@00dJD000j?
0000Bdd000LQ00047000<40007lE0<33003d<@00oPD00=mi0015XP0005e5000?:@000QT001`c001^
<`20/`00je800?l0003ZE@00Nk80001]=@006S80008I000@:P00H4<0CZD00>9b003o0`00lST00:fo
0000NR0002Pk00036`002R@005A<02VI003IS@00o@/00?HU0039^P0008@;000f@`0011d000LP0019
C00?T000dZ400?XE003j6@00d:P000N=0000@dT000HO00057P00?DH008T00<f`003h7@00na400=BK
000ETP0004e>00078@0011d003I300252P3:^000mb<00?`>003GU0007ID0001@CP00228000@L000c
@P00P`d0bK/00?LT003l3@00ei<001fE0000D4h000PR00047000=D8008D:0<Zg003g8@00o0l00=FH
000FTP0004a=00078@001Ad003Y500280P3=[P00nA/00?/E003AY0002Hd00012B@8000HO0;l004E:
00f?003CW`00na800?PN003;]00008D9000e@P0011`000PR001BC@0VV000fXX00?d9003d;P00^l80
001k7P009cX000<J000=9`00G4L0BZ@00>=_003o0@00kTH008^f0000KS<001Ta00026@005Bl006Ti
07Zb003/C`00o`000>EV001EY`0005m4000>:0000aX002Di001j802i`P00m2h00?d:003ISP007YD0
001>CP001b0000DN0010B009S@00dj000?/A003g8P00b;`000204`00;3h000<K000<9P00FdP0B:@0
0>=]003o0@00kD/007fc0000JCT000`T000L<`00LRd0Wk/00?4i003n1@00g8@002VI0000DDd000PQ
00057@00?TL02Hd00=>O003l3`00mRD00<G20000OAX002Lj00036P003bT00652066[003XF`00o`00
0>MP001IZ@0005i4000=9`000aX002/m00204`39^P00n1h00?XE003?Z`0008L5000c@P000a`000/U
001IB018X`00i6/00?l0003[D`00K:h0001S@00042X0008J000V>P00OAT0akl00?LR003k4`00cjT0
00280`00=48000<K000;9@00FdP0CZD00>EU003o0000jEX005nZ0000Gd@000dW00036`00;Sh008@<
0<f`003j5`00n1h00<Rk0000OaH002Lk00026P0042X006Dn07B`003/C000o`400>1g000dW@0005=<
00078@001Ah004I;01ZD003JR`00oPH00?4k002B^00006`e000E;P000QT0020f001i8P32a000mbD0
0?/B003?ZP0008H7000_?`000a/000dX001Q@P1X[@00je800?l1003QM000=Ih0001BC@001b4000DO
001;C@0RU`00gH800?l3003^A@00O;80001V?@0042X000<J000Z?@0:ooooo`7o00000Oooool001ko
oooo00?o0000ooooooooool01oooool0>@00MBT002Tl000470001Ql003Q4001o5P2[_P00kTH00?l0
003]BP00Xk`0001m6P00=48000DN00047@00;Sl007PR09>h003[DP00o`000?0o002g`@00088@000k
AP001R0000@L000Y?000MBP0QkD00>UI003o0@00lCX00;o30000Q0`003i70007800011`002Pk001d
:@27]@00jEP00?l0003a?000^/8000223`00>dH000HP00047000:cd007LT09:h003[D@00o`000>m4
002Z_P0007hI000d@P0200057P3o000c@@00OAT0Z[h00>m3003o0000je8008jg0000MRL002Tl0004
70001b40049900271P37_`00m3400?l3003TJ@00J:d0001[=`007C@0008J000;9@00Dd`069<00=6S
003i7000o0d00=^8000kW`0005i5000A:`000QT001@]001Q@P17X`00gWl00?d:003g8`00cJh000^>
0000CTh000TS00036`0093T007</08Ne003ZE000o`000>i6002P_00007XP000/?P0011`000LP0013
B@00R@40bKT00?DZ003n1P00h7L004nV0000Hd0001@^00026@004R`08X4R0=f0003m2@00mbD00<bc
0004R`0004I;00078@0011`002`m001j7`2T_@00kd800?l0003XG000Mk40001]<`007C@0008J000<
9`00EdX0:IT00=NB003l4000nA/00=6U000BT@0004m>00098`000a/002Lk001g9@2L^`00kTH00?l0
003XFP00Mk40001]=00073@0008J000=:000FDT0<Yd00=Z9003m3000mb800<ba0003R`0004A:0007
800011d003910020502o``00lc<00?h4003QL`00D:H0001Q@P004R`0008I000F;`00IS`0HZ/00>EV
003o0@00l3h00:Nm0000NB4002Tl00036`002B<0055=01bD003EVP00na<00?TJ003@YP003Hl0001:
C0001b4000@L000a@000P1@0`l@00?@`003n1P00gg/004:R0000GDH000lY00026@0073@006lb08:d
003[D@00o`000>YF001i/P0006`f000J<P000QT0014[001P@`1@YP00hW000?l3003a>P00Zkh0001i
8@009c/000<K000:9@00ED/0:iX00=Z;003m2`00mRH00<Rl0000Q0`003E300047@001b4004]=016@
003CX000na@00?TJ003?Z@001X`00012B@001Ql000DN000nA`00RP00cJh00?TL003k4P00e9d001>A
0000C4d000LQ00047@00=d<008D80<Zg003g8P00o0l00=JF000KU00004m>00088P0011`003A20024
3039^@00mb<00?`>003FU@006i@0001?CP00224000@M000f@`00Q@T0b[H00?PP003l4000eIX001BB
0000Bdd000LP00057P00>dH008T00<j]003i6P00nQD00=6U0007S@00045800057P001Ql004I;00n@
003CWP00na400?PO003:]P0008D:002h000d@P0011`000TR001BC@0XV@00fhT00?h8003d;`00^<80
001j7`009SX000<J000=9`00GDH0C:D00>=]003o0@00kTL008Rf0000KC@001Ta00026@005Rl006Xh
07fc003/C@00o`000>EW001CY`0005i5000>:0000aX002Dj001j7P2l`P00mB`00?d:003HT00079D0
001=CP001b0000DN0011B00;SP00dih00?`@003g8`00akh000205000:cd000<K000<9P00FdL0Bj@0
0>=/003o0000k4d007^b0000JCX000/T000L=000Lb`0XK`00?8h003n1P00g8D002NI0000DDd000LQ
00057P00?dP02Xh00=BM003l3`00mRH00<G40000O1`002Hj00036P003bT0069206>/003YF@00o`00
0>IR001GZ00005i5000=9`000a/002`m00214P39^000n1d00?XF003>[@0008H6000c@@000a/000/U
001JB01:Y000i6T00?l0003ZE000JZd0001S@0003bX000<J000W>`00OQP0akh00?PQ003k5000cjX0
00271@00<d4000<K000;9@00FdL0D:H00>IT003o0000j5/005fZ0000Gd@000dW00036`00;cl008@;
0<f_003j5P00n1l00<Rl0000OQP002Hj00026P004B/006Dn07Na003]B`00o`800>1h000bW000059=
00078@001Ah004M;01^D003JRP00oPH00?4l002@^00006`f000E;P000QT0024g001i8034a000mb@0
0?/C003?Z`0008D9000_?`000a/000hX001Q@P1[[P00je000?l1003QM@00<id0001BC@001b4000HO
001<C@0TV000gH400?l3003^A`00NK80001U?P0042X000<J000[?@[ooooo0Ol00001ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`0i001d:P00:C`000@L00067`00>D@0080D0:jo003_A000o`00
0>e;002P_00007`K000c@@001Ah000DM000_?`00NB40UKT00>]A003o0000l4000;C10000PA8003Y5
0006800011`002Xl001f9`2:]P00jEL00?l0003a?000_<8000233P00?DH000LP00047000:C`007DX
08Vf003ZE`00o`000?0m002h`@00088A000jA@001Ql000@M000/?P00N2<0UKT00>a?003o0000kTD0
0:Rn0000OAX003=1008000DN0?l003A2001n602/_`00kd800?l0003ZE000S;L0001e:000:3/000@L
00078@00@dT008L40<Nn003d<000o`@00>AZ001V[00006Xh000L<`000QX000`V001DC00JU000dZ80
0?TK003l3P00fXT003VO0000GDH0014[00026@0052h0069204VT003NO@00o@T00?LT003=[`002Hd0
001<C@002B<000<K000U>@00LbX0RKH00>]C003o0000kTL009jk0000NB4002/m000470001b4004A:
0029003:]`00mRT00?h7003ON@00CJD0001R@@0052d0008I000B;00SPB80gWh00?d9003f9P00bk@0
00::0000ADX000LQ00047000;Ch007/N0:Nm003_@@00o`000>QM001e/00006dd000M=0000QX000dW
001GBP0[VP00f9000?`@003i7000d:H0012@0000Cdh000TR00036`00:3/007PS09jk003^A000o`00
0>QL001e/@0006`e000L<`000QX000hX001JB00dW@00fhP00?d;003g8`00c;80006:0000@dT000HP
00047@00<d40080C0<74003c<P00oP@00>5d001>Y@000652000B;0000QT001L`001W?01T[000iFD0
0?l1003`@000Y;d0001h8P00:3/000<K00099000DTd07ID00=FH003k4P00nA/00=2X000;SP0004Q<
00078@0011d0039100214P35a000m2l00?h6003NO000@:40001LAP003RT0008J000M=000Kc40QKD0
0>a?003o0000jEL007Na0000JcH001Tb00026@004B/0065205:W003SK`00o`800?4k002X_P0007PR
000V>P000a/000/U001FB`0]V`00fXT00?d:003f:000b;d000233@00=48000@M00078@00C4d04i40
0=>N003k4`00nA/00<n[0004R`00045800067`001Ah003m700::003>[@00nA/00?/C003CWP004Y40
001:C@001b0000@M000hA000QPL0bkD00?PQ003l3`00eYL001VD0000Cdh000PQ00047@00=D<008D:
0<Zh003g8P00o0l00=JF000IU00004m>00078@0011d003M300261`3;]@00n1l00?/A003DW0004i40
001:C0001b0000DN000lAP00RP00cZ`00?TI003j5P00d:L000J<0000@4P000DN00068000Ad/04I00
0=BL003k4@00n2000<Zg0000Q0/00;P003=1000470002B<005=<02ZJ003KQ`00oPP00?@a002f`@00
07XP000U>@000aX000hX001MAP1>Y@00hf`00?l1003]B000Q[D0001]=@006340008I000F;`00JcL0
Ok<00>a<003o0000i6T0056V0000GTD000hX00036P009SX007/M0;k3003e:`00o@/00=RB000JU000
04a=000780001Ah0049900f?003DW@00o0l00?LT0037_`0007lF000Z?@000a/000`W001LA`1=Y@00
i6X00?l0003/CP00N;40001X>`002b<001dd001c:`2T_@00lSH00?h6003KQ`009IP0001@CP001b40
00DN0011B00<S`00e9`00?`>003f9`00`l@0001k7@009CT0008J000?:P00HT40IZ`00>UH003o0000
iV<005BW0000GDD000dW00036`00;3h0088@0<Zg003i7000nQL00<f^0000QPP0039100036`002bD0
05]804bU003UJ000o`000>YF001W[@000691000?:@000aX002Pk001o5`38_000n2000?XE003>[000
08H6000b@@000a/000/V001LA`1BY`00iV800?l0003XG@00FZT0001NA@0032L000<K000_?`00Q@T0
cZd00?XE003h8000akh0001m6@009SX0008J000A:`00ISd0NK800>e9003o0P00ggX0032L0000DDd0
00LQ00057P00BD`07ID00=^8003n1@00l3d008fg0000JcL001@^00026@008CL007XO0<G3003g8`00
na@00<j]0000Q@X002hn00036P003RP0069106f^003/C`00o`400>1g000aW000055=000780001Ql0
04e>02JH003MO`00o`<00>e8001g/@0006@o000?:@000aX002`n2_ooool1o`00007ooooo000Noooo
o`03o`000?oooooooooo00Oooooo03T007<[000X>`0011`000HP000jA@00PA<0/<000>m3003o0000
k4d009jk0000Nad0039100057P001Ad00310001j802H^P00k4l00?l0003_@@00/L0000204`00>DD0
00HO00047000:cd007HV08bg003ZEP00o`000?0m002i`P00088?000lAP001R0000@L000Z?000MRL0
S;L00>YE003o0000l3h00;G10000PA8003U400067`0011d002dn001i8P2G^P00k4h00?l0003^AP00
YKd0001l6`00<T400P001Ah0a000=D<007lF0:no003_@@00o`000>YE0029]P0007@Y000W>`000a/0
00LQ0014BP00R080b;`00?@^003n1000hf`006B/0000JSP001/c00026P0032H005A<01bE003CX000
nAX00?`?003JR`00=ih0001LAP0042X0008I000E;P00HT40Bj@00=ml003m2000mbD00<ba0007S@00
04]=00088P000a/002Hj001d:@2<]`00je400?l0003]B@00Vk/0001h8`00:Sd000@L00078@00ADX0
0HX00<Zf003f9`00oPP00=mk001:Y0000652000C;@000QT001</02B28P3NO@00oPP00?HW003;]P00
08X00014BP001b0000@L000^?P00Nad0Z[h00?0o003o0@00iel007:`0000K3D001`d00026P003BL0
05Q902fK003HS`00o0l00?TM003@Z0003Xl0001>CP00228000<K000Y?000N280XK`00>m3003o0000
j5d007>`0000K3H001/c00026@003RP005Y803NN003KQP00o@/00?LT003;]00008T00011B@001R00
00@M000d@P00PA40a<@00?@a003n1@00h7H004bU0000H4<0018[00026@005c0006Pk06N]003VH`00
o`400>m1002Q_00007PT000W>`000a/000XT001BC@0OUP00eYL00?/A003i7000cjT000V=0000Ad/0
00LP00047@00<d80084A0<G2003d;@00oPL00=in000nX00005]7000>:0000QX001he001`<027]@00
k4h00?l0003YF@00M;00001[=`006C40008I000B;000HT80E:L00>=]003o0P00lCd00:Jm0000N2<0
02Hj00036P002bD005I;02nK003KR000o@X00?HY0037_P00088?000c@P0011d000LQ001=CP0DTP00
e9d00?/C003i7000cZ`000:;0000@4P200067`3a0010B003R`00cj/00?TK003k5000dj00012@0000
BD`000LP00057@00>D@008L50<^d003h8000o1000=FI000GT`0004i>00078@0011d003I300252@3:
]P00n2400?`?003EV0005i<0001>CP001b4000@M000hA000Q`H0c;<00?PN003k4P00e9d0016@0000
B4`000HP00057P00?TL00XX00<nZ003j6000nQL00=2X0004R`0003m700057P001R0004U<01:A003D
V`00o1000?LQ0039^@0008<=000b@@0011`000TS001CC00/VP00g8D00?h7003c<P00/l00001i8@00
93T000<J000>:000GTD0D:H00>AZ003o0@00kDX008>d0000K3H001L`00026@005c0006/f08:d003]
BP00o`400>AZ001>Y@0005e6000=9`000aX002Lk001l7031a000mBX00?d;003GT`0069<0001;C@00
1R0000DN0013B@0>S`00e9/00?`?003g9@00a/00001n5`00:S`000<J000=9`00GDH0CjH00>AX003o
0000je0007Ja0000Ic/000/S000N=@00M2X0Y[d00?8e003n1`00fhP002>G0000Cdh000LQ00057P00
@TT03Xl00=FJ003l3@00mRP00<740000Nah002@i00026P0042X006=006R]003ZEP00o`000>IU001B
Y`0005e6000<9P000a/002dn00223`3;]@00nA/00?XH003=/00008D:000a@0000a/000/V001KA`1>
Y@00iFH00?l0003YE`00IJ`0001Q@P003bT000<J000Y?000OaD0b;/00?PO003j5P00cZd000262000
<D0000<K000<9P00G4H0E:L00>MQ003o0000ieh005RX0000GDD000`V00036`00<40008H80<j/003k
5@00n2400<No0000OAX002Di00026P004B/006Ll07bb003^B000o`800=mk000^V`00055=00078000
1Ql004Y<01nF003KQ`00oPD00?0o002;]P0006Xg000D;@000QT0028h001k7P36`P00mb400?XE003=
[P0008@<000]?P000aX000lY001S@01_[`00k4d00?l1003PN@00;i/0001AC@001b0000HO001>CP0X
V@00gWh00?l2003]BP00MK00001T?`003bT000<J000]?P0:ooooo`7o00000Oooool001kooooo00?o
0000ooooooooool01oooool03@00Lb`002Lk000470001R0003]600214@2c`000kd400?l0003/CP00
VkX0001k7P00<D000P001Ah0o`00<D0007XN09^j003/CP00o`000>m3002__`00080D000hA0001Ql0
00@M000[?@00MbD0SkL00>YD003o0000l3h00;O10000PQ4003]500067`0011`002/m001g9@2?]`00
jU@00?l0003`@000//0000205000>4@000HO00047@00;Sl007TP09Zj003/C000o`000>i8002R_000
07/M000a@0001Ad000DN000f@`00OaD0//000?0o003o0000jEL008Ne0000M2X002Hj00036`002240
04E:00290@39^`00m2d00?h4003SKP00HJ/0001Y>@006c<0008J000<9P00ED/07YD00=>O003i6@00
o1000=V=000dW@0005a7000@:P000QT001D^001S@01=Y@00ggX00?h8003f9P00c;<000J<0000BT`0
00PR00036`009SX007DX08ng003[D000o`000>e:002I^P0007LT000Y?00011`000PQ0017B`03R`00
bk@00?HV003n2000gW`004RT0000HD8001<]00026@004bd09H<Q0=mk003n1`00mRP00<Zg0000R@00
04=90007800011`002ho001l702/_`00l3h00?l1003WH@00L:l0001[=P006c<0008J000=:000FDT0
;i/00=V=003l3P00n1h00<nY000<S`0004a=00088P000a`002Xl001i8@2T_@00kd800?l0003WG`00
L:l0001[=`006S80008I000?:@00FdL0>Il00=b5003m2P00mbD00<^e0000R@40041800067`001Ad0
03E300224035``00m2l00?h5003PN000BJ@0001OA0004B/0008I000H<000J3X0JJd00>IR003o0@00
kd8009nk0000MbD002Hj00036`002R@005=<026G003FU@00o1000?TM003?Z`001hd00016BP001b00
00@M000d@P00PPl0a/400?D/003n1`00gGl003bP0000FdL000hX00026P007SD0074_08Zf003/C000
o`000>QK001b/00006Xh000H<@000QT0018/001R@@1GZ000i6/00?l2003`?P00Xk`0001g9@009CT0
00<J000;9P00EdX0<I`00=^6003m2@00mBX00<K00000PQ00039100047000224004i>01JC003DV`00
na800?TM003=[P000HX0000nA`001Ah000HO0012B@05S000cjX00?TJ003j5@00dZ4000j?0000B4/0
00LP00057P00>TD008P40<bb0000E03h7`00na400=BK000ETP0004a=00078@0011d003M400261`3;
]@00n2000?`@003EVP005Y80001<C@001b4000DM000iA000Q`@0c;400?PM003k4P00dil000n@0000
Ad/000HP00057P00?dL018/00=2X003j5`00nQP00<nZ0002RP0003e700057P001b0004Y<01BB003E
V@00o0l00?LS0039^P0008<?000a@00011`000TS001DC00^V`00g8@00?h6003c<`00/<00001h8`00
8cP0008J000>:000Gd@0DZL00>AX003o0000kD/0086d0000JcH001L`00026@005c0006`e08Be003]
B@00o`400>=/001<Y@0005a6000=9`000aX002Pk001m6`34a000mRT00?d<003FU@005Y<00019C080
00HO08h004E:012@003EVP00o0h00?HV0035`P0007hI000Y?0000aX000dW001MA@1AYP00iFL00?l0
003[D@00Lk00001W?0002b<001he001e:02Y_P00lc@00?h7003JRP008IL0001?CP001b0000DN0013
B@0@T000eIP00?`=003e:P00_/<0001j7`008cP0008J000@:P00I400Jjh00>YE003o0000iFH0052V
0000G4L000`V00036`00;Sl008<=0<^d003i6P00nQT00<ba0000Q0/0031000036`0032H005a7056V
003VI@00o`000>UI001SZ`000652000>:0000aX002Xl00205039^@00n1d00?XG003=[`0008D:000`
@0000a/000`V001MAP1GZ000iel00?l0003WH000EZP0001MAP0032H000<K000a@@00QPH0cjX00?/D
003g8P00a/40001l700093T0008J000B;000Ic/0O[<00>i6003o0`00gWd002bJ0000D4h000LP0006
7`00Bdd08IL00=b5003n1000l40008Rf0000JSP001<]00026@008cP007/M0<K0003h8000nQH00<f`
0000P`d002`m00036P003bT006=007:`003/C000o`800=mj000]V`00051>000680001Ql004m>02ZJ
003OO000o`800>e;001b/00006=0000>:@000aX002ho2_ooool1o`00007ooooo000Nooooo`03o`00
0?oooooooooo00Oooooo00d0078]000V>P0011`000LP000mAP00PQ00]/400?10003o0000je0009Rj
0000NQl00310008000DN0?l00391001k7@2M^`00k4`00?l0003^A000[;l0001o5P00=d<000HO0004
7@00;3h007PS096h003[D`00o`000?10002d`@00084B000iA@001Ql000@M000/?@00Mb@0TKP00>]B
003o0000kd400;300000OaD003M300067`0011d002lo001j7`2M^`00kD/00?l0003]B@00Wk`0001k
7P00<40000@M00067`00=d@0080C0;G1003`?P00o`000>UH0024]@0007<[000U>P000a/000PR0017
B`00RP00bKT00?D/003n1@00hVl005nZ0000J3X001Xb00026P003BL005E;022F003DW@00nQP00?`@
003ISP00<Y`0001KA`0042X0008I000F;`00I3l0D:H00>1h003n1`00mRL00<^d0004R`0004Q<0008
8P000a/002Lk001f9`2A^000k4h00?l0003]C000U[T0001g9@00:3`000<L00088P00B4`01H/00<bc
003g9@00o@T00=in0016X`000613000B;0000QT001@]02J48@3ON@00oPL00?DY0039^@0008P20011
B0001b0000@M000`@000OAX0[kl00?4m003o0@00iV8006f^0000JcL001/c00026@003RP005U9036L
003JR`00o0d00?PO003?Z`002hh0001;C@00228000@L000[?@00NR00Y[d00?10003o0@00if4006f^
0000JSP001Xb00026@003bT005a703^O003LP`00o@T00?HV003:]`0008P3000oA`001Ql000DN000f
@`00P`h0a/800?@^003n1P00ggT004NS0000Gd@0014[00026@00634006Ti06b^003WH000o`000>m4
002L^`0007HV000U>P000a/000XT001DC00SU`00ei<00?`@003h7P00cZd000F<0000A4X000HP0004
7@00=D<008<>0<No003e:`00oPP00=f1000jW`0005Y8000=:0000QX001lf001a;P2<]`00kD/00?l0
003XG000Kjl0001Y>@005c00008I000C;000Hd00FJT00>AZ003o0@00l3l00:2l0000MRH002@i0003
6P0032H005Q:03>M003LQ@00o@P00?D[0036`P00084B000a@00011`000PR001?CP0HT`00eIT00?/A
003h7P00cK0000290000?DL000DN00067`00@dT01h`00=2X003j6@00nQH00=6S000<S`0004I;0006
80001Ah003]600280P3=/00005@0n1d00?/B003DW0004i40001;C@001b0000DM000iA000Q`D0c;<0
0?PO003k4@00e9/001BA0000Bdd000LP00057@00>TD008P20<f`003i7000na<00=:P000=S`0004I:
00067`001Ah0041800J<003@Y`00nQH00?TI003>Z`0008X0000lAP001Ah000LP001;C@0FTP00eYL0
0?`>003g9000b;`000224000<40000<L000:9000ED/0<9`00=f2003n1P00lc@00:fo0000Mb@002<h
00026P003bT005m405FW003UI`00o`000>a=001n/`0006Xg000F;`000QT001Pa001]=027]@00kTP0
0?l1003SKP00BZ@0001LA`0032L000<J000Y?000OAT0aL<00?HX003l3@00eYH001BB0000B4/20006
7`220016B`0BT@00eIP00?`=003f9`00aL<0001m6P00:3/000<J000=:000GTD0E:L00>EU003o0000
je<0076_0000ISd000XS000O=P00MBL0[;l00?<c003n2000fX`001nF0000CTh000LP00057P00A4X0
4Y400=JG003m3000mB/00;_20000NB4002<h00026P004B/006@o06f^003ZD`00o`000>EX001=Y@00
05]7000<9P000a/002lo0024303</P00nAT00?TJ003</`0008<=000_?`000a/000`V001MAP1CY`00
iV<00?l0003XFP00H:/0001P@`003RP000<J000[?@00PA80b[P00?TL003j6000cK0000242`00;cl0
00<K000<9`00GTD0FJT00>QN003o0000iV8005>W0000G4H000/V00036`00<T4008L50<nY003k4`00
mb<00<G20000Nad002<h00026P004R`006Pj086d003^A@00o`<00=io000ZVP00051>000680001Ql0
04e>02>G003LP`00oP@00>m20025]@0006Ti000C;0000QX002@i001l6`37_`00n1l00?XG003</@00
088?000[?@000aX000lY001T?`1e/000kDX00?l2003OO000:iX0001?CP8000HP00X0051>02bJ003O
NP00o`800>a=001`[`000691000>:0000a/002lo2_ooool1o`00007ooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0?l0074^000U>@000a`000LP000nA`00P`h0^L800?0o003o0000je4009Fi0000
NB4002lo00057@001Ah003=1001l702P_000kD/00?l0003^AP00ZKh0001n5`00=T<000HO00047@00
;Ch007PR09Bi003[D@00o`000>m1002a`000080D000hA0001Ql000@M000]?P00N2<0U;T00>]@003o
0000kd<00:fo0000OaL003I300057P001Ad00310001k7P2P_000kDT00?l0003]B`00WK/0001j7`00
;cl000@M00067`00>D@0084B0;S1003a?000o`400>UJ0021]000078/000T>@000a/000PR0018C002
RP00b[L00?D[003n1@00hW4005bY0000J3/001Tb00026@003BL005I;02:G003DV`00nQL00?/A003H
T000<9`0001JB0003bT0008I000F;`00I3l0DZL00>1g003n1`00mRP00<Zf0002RP0004M;00088@00
0a`002Pk001f9P2D^@00k4d00?l0003/C@00TkT0001f9P00:3/000<K00088P00BD`01X`00<ba003g
9000o@T00=f00013XP0005m4000B;0000QT001@^02N48@3PN000oPH00?DZ0039^P0008L40010B000
1R0000@M000a@000OQT0//000?4k003o0@00iV@006Z^0000JSP001Xb00026@003RP005Y803BM003J
RP00o0d00?PP003>[@002Hd00019C000224000@L000/?@00Nah0ZKh00?0o003o0@00iV8006^^0000
JST001Tb00026@003bT005a603fP003MP@00o@T00?HW0039^@0008L5000nA`001Ql000DN000hA000
P`d0a/000?D]003n1P00gg/004FR0000GTD0010Z00026@006C4006Xh06j_003WGP00o`000>i5002I
^P0007DW000T>@000aX000/U001DC00VV000f9800?`?003h7`00cJh000B;0000@dT000HP00057@00
=d<008@<0<Nn003e:P00o@P00=b3000gWP0005U8000=9`000QX0020f001b;@2?]`00kDT00?l0003W
GP00K:h0001X>P005c00008I000C;@00I3l0G:T00>EX003o0@00kd4009fk0000MBL002<h00036P00
32H005Q903FM003LP`00oPP00?D/0035``00080D000`@00011`000PR001@CP0JU000eYP00?`@003h
7`00c;4000280P00?4H006<000DN00067`00A4X02Hd00=2V003j6000nQL00=6U000:SP0004E:0006
7`001Ah003e60029003=[`00nA`00?/C003CWP004I40001:C0001b0000DM000jA@00R0<0c;400?PN
003k4P00e9d001:A0000BD`000LP00057P00>dH008T10<f^003i6`00na@00=:R000;SP0004A:0006
7`001Al0045900R=003AY@00nQH00?TJ003>[@0008T0000kA@001Ad000LQ001=CP0HT`00eYH00?`>
003g9@00akd000214P00;cl000<K000:9000ED/0<Y`00=f0003n1@00lSH00:^n0000MbD0028g0002
6P003bT0061305NX003UI@00o`000>a>001l/P0006Xh000F;`000QT001Ta001]<`2:]P00kTH00?l1
003RK`00Aj<0001KA`0032H000<K000Z?000OQP0a/800?HW003l3P00eIP001:A0000AT/00P001Ql0
SP00B4/059800=JF003l3000mRT00<?40000O1/002Lk00036P003RP005m405JX003VI000o`000>YD
001^[`0006Dn000:8`0083H007HV0:no003c<@00o@P00=V=000MU@0004e>000680001Ql004I;01BB
003FU@00o@/00?D/002h`P0007PR000R=`000QX0014[001U?P1`[`00je800?l0003TJP00Bj@0001K
B0002bD000<K000`@000Q@X0cK000?XH003i6`00bk@000233P00;Ch000<K000<9`00GDD0EZP00>MQ
003o0000j5`005jZ0000Gd@000dX00036P00:cd0084A0<Zf003i6`00nQT00<bb0000P`d002ho0003
6`003BL005m405bY003XG000o`000>IS001AYP0005]7000;9@000a/003A200280`3@Y`00na800?LT
0035a00007XO000R>0000QT001<]001Y>@23]000kd<00?l3003MP000:9T0001?CP001R0000HO001>
CP0UV000gH800?l3003_@`00Pk@0001X>P004R`0008J000U>@00OAX0b;d00?PN003j6000c;<00022
4@00:S`000<J000@:P00ICh0Mk400>e9003o0P00gWh002VI0000Cdh000HO00078000D4d0;i/00>1i
003o0@00k4h006f^0000HT4000hX00036`00<40:ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool0o`00L2l002@i00036`001b4003m700243@2l`P00l3d00?l0003[D`00TkP0001h
8P00;Sl000@M00057P00=48007dJ0:>m003]B@00o`000>i7002V_@0007dI000e@P001Ah000@M000^
?`00NB40UkT00>a?003o0000kd<00:jo0000OaD003M300067`0011d002hn001i8@2G^@00k4l00?l0
003_A000Z[h0001n6000=48000DN00057@00<D0007`L0:>l003^B000o`000>a<002J^P0007TQ000]
?P0011d000HO000jA@00PQ00^/800?4k003o0@00j5`007jc0000LBh002@i00036`00228004Y<00B;
003:]P00mBT00?h6003QL`00FJT0001W?0006C40008I000=:000EdX09IP00=FI003j5P00na800=NB
000^V`0005Y8000?:@000QT001L`001U?P1EY`00hGD00?h6003e:P00b[L0002:0000ADX000LQ0004
7000:C`007LT09Ni003]B`00o`000>a?002@^00007DX000W>P000a/000PR001;C@08S@00cJl00?LS
003m2P00gH40046Q0000Gd@0014[00026@005Bh0:HDP0>1f003n1P00mB`00<Rl0000Q`H003m70006
7`0011d00391001n5`2e`@00lCX00?l2003UIP00J:d0001Y>@006C80008I000?:@00FdP0=Yh00=^8
003m3000n2400<f^0007S00004Q;00078@0011`002dn001k7@2/_`00l3d00?l1003VI000J:d0001Y
>P006C40008I000@:P00GDH0@:400=eo003n2000mRT00<Vj0000QPH003a600067`001Ah003U40024
2`37_P00mB/00?h7003NO@00@Z80001MA@0042X0008I000J<P00JcL0LJl00>QM003o0000kTL009Ji
0000MBT002<h00036P002bD005E;02RI003HT000o0h00?PP003=/0000XX00012B@001Ql000DN000h
A000Q0/0b;`00?HX003m2@00g8D003FM0000FDT000dW00036P008CL007<[09:h003^B000o`000>MO
001Z[@0006Pk000F;`000QT001@]001T?`1NZP00iFH00?l1003_@P00V[X0001e:0008SP000<J000<
9`00FDT0>9h00=f1003n1`00m2h00<C40000OaD002lo000470002280051=01fE003FUP00o0l00?PP
003</`0008P4000kA@00:0001Ah000HP0016BP0;SP00dJD00?XG003j6000d:L000R=0000@dT000HO
00057P00?TL00HX00<j]003i6`00na@00=>P000?T00004Q<000780001Ah003]500280P3=/000nAd0
0?/C003CW`0049000018B`001R0000DN000mAP00RP00cZ`00?TJ003j5@00dJ@000V=0000@dT20006
7`0i0013B@09S@00dJ<00?/E003i6`00cJl000280P00>TD000DM00078@00CTh06Y@00=ND003l3@00
mRH00<No0000P1<002ho00036`002R@005I;03FM003NO`00oPD00?8g002X_P0007HW000Q=`000QX0
010Z001Q@P1JZ@00iV<00?l0003[D000NK80001Y>@005Bh0008I000I<P00KS80S;L00>i4003o0P00
hW4004FR0000FTP000`V00036`00:cd007lF0<K0003f9@00o0h00=FJ000@T00004E:008000HO04D0
04U<01JC003GU@00o@`00?DZ0030``0007/M000V>P000aX000hX001OA01IZ@00iV800?l0003ZEP00
Jjh0001T?`002R<0024g001g9@2b`000m3000?d9003HS`006i@0001;C@001R0000HO0017B`0FTP00
ei<00?d:003d;P00]L40001h8`008CL0008I000B;000ISd0L[000>]@003o0000i6/004RT0000FTP0
00/U00036`00<T4008D80<f_003j5`00nA`00<Zf0000PQ0002`n00036`003BL005i505RX003WH000
o`000>QN001KZ@0005m4000=9`000a/002dn00223`3;]0000P3i6P00A`3;]00008<?000]?P000a/0
00dW001OA01NZP00j5X00?l0003UI@00CZD0001KB0002bD000<L000e@P00R@40dJD00?/A003f9@00
`l@0001j80008SL0008I000C;@00JST0Q[D00>m2003o1000gH8002FH0000CTh000HO00068000Cdh0
:9T00=f0003o0`00kTD0082d0000J3/0018/00026P009CX007hH0<Rk003h7@00nQT00<^e0000PA80
02Tl00036P0042X006Hm07Zb003^A`00o`<00=eo000WV00004i>00067`001b00055=036L003PM`00
o`400>]@001Z[P000652000=:0000a/0035000[ooooo0Ol00001ooooo`007_ooool00ol0003ooooo
ooooo`07ooooo`0^001`<0008cP000<K00078@00@DP008@;0;o3003a>`00o`000>YE002@^00007PT
000]?P0011d000DO000e@P00OQT0Y[d00>i8003o0000kDT00:>m0000OAX003=200057P001Ad00310
001j7`2J^P00k4h00?l0003_A000Zkh0001n5`00=T<000DO00047@00;cl007XP09Zj003/C@00o`00
0>i6002W_@0007dJ000c@@8000DN07d00391001l6`2V_@00kTH00?l0003/CP00UkT0001h8P00;3h0
00@M00067`00>dH008<>0;k3003a>@00o`400>QM001l/P00074_000S>0000a/000TS001;C@06S000
bk@00?HX003n1P00hGD005NX0000ISd001Pa00026@003RP005Q:02NI003FV000nQD00?/C003GU000
:iX0001IB@003RT0008I000G<000ISd0EjP00>5c003n1P00mB/00<Vi0000R@4004A:00078@0011`0
02Xm001h8`2J^P00kDX00?l0003[D000SKL0001d:@009SX000<K00088P00CDh02Xh00<j]003g8@00
o@/00=b3000nX00005i5000A:`000QT001D^02Z6803QM000oPD00?D]0037_P0008H7000mA`001Ql0
00DM000c@@00OaH0^<800?8h003o0P00iFL006F/0000J3X001Ta00026@003bT005]703RN003KQP00
o@/00?LR003=/0001H`00016B`001b4000@L000^?`00O1/0[kl00?4l003o0@00iFH006F/0000J3X0
01Pa00026@0042X005i504:R003NOP00oPL00?DZ0038_00008H8000kA@0200057P3?000jA@00Q@T0
b;d00?DZ003n2000gWl0042Q0000GDH000lY00026@006S8006/f07B`003XF`00o`000>e9002C^@00
07@Z000S>0000aX000/V001FB`0ZVP00fHh00?`=003h8@00c;8000290000@4P000HO00057P00>D@0
08D90<Vk003f9`00o@X00=^7000cW@0005Q9000<9P000aX0028g001d:P2E^@00kTH00?l0003WH@00
Ijd0001W?0005Rl0008I000D;P00ICh0HJ/00>IU003o0@00kd@009Rj0000M2X0024g00036P003BL0
05Y803ZO003NO`00oPL00?@_0031a00007lG000^?`0011`000TS001AC@0OUP00ei@00?`>003g8@00
bkD000271P00>DD000DM00068000Ad/03Hl00=:S003j5P00nQT00=2X0006S000049900067`001Ah0
03m800>;003>Z`00nAX00?/D003BX@003Hl00017B`001R0000DN000lAP00R@00cJh00?TK003k5000
dZ4000j?0000AT/000HP00057P00?TL00XX00<n[003i6@00nQH00=6V0007S@00045800057`001Ql0
04A:00^>003BX@00na@00?TL003</@0008L4000hA00011d000LQ001?CP0MU@00ei800?d<003f9`00
a/40001o5@00;Ch000<K000:9@00EdX0=ih00=im003n1000lST00:Fm0000MBP0020f00026P0042X0
065205fZ003VHP00o`000>]B001f/@0006Pj000E;P000QT001Xb001_<@2?^000kd<00?l2003QL`00
@Z80001JB0002bH000<K000/?@00P1@0akh00?LT003l3`00e9`000j?0000A4X000DN00068000Bdd0
69<00=NC003m2`00mB/00;g30000Nah002Di00036P003bT0061305bY003WH000o`000>UH001Y[@00
06@o000:8`008SL007PS0;G1003d;P00o@X00=RA000IU00004Y<008000HO078004U<01RC003HT@00
o@X00?@_002b`00007LU000P=P000QT0018/001V?01e/@00k4h00?l0003SK@00AZ<0001IB@002bD0
00<K000c@@00QPL0cZd00?XF003h7@00b[P000214P00:cd000<J000=9`00Gd@0FjT00>MN003o0000
iel005RX0000GTD000dW00036`00;Sh008<=0<bc003i6@00nA/00<^e0000PQ0002`m00036P003RP0
0613066[003YF@00o`000>EW001<Y@0005Y8000:9@0011`003I3002:003AY000o1000?HW0030``00
07TQ000Q=`000QT001@]001Z>029]P00l4000?h4003LQ0008iL0001=CP001Ql000HP001@CP0ZVP00
gWh00?l3003^AP00OK<0001W?0004B/0008J000V>P00OaL0bKX00?TL003i6P00b[H000205000:3/0
008J000A:`00IS`0OK<00>i6003o0`00gH4002BH0000C4d000HO00078000DTd0<id00>5e003o0@00
je4006N]0000H4<000dW00036`00<T4:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool0
1oooool06000Kc80028h00036`002240049900252@32a000lCX00?l0003ZEP00SKL0001g9@00;3d0
00@M00067`00=T<007hG0:Vn003^AP00o`000>e;002P_00007`L000b@@8000DN01@00350001k7P2M
^`00k4`00?l0003^AP00Z;h0001n6@00=D8000DN00057@00<40007XN09fk003]B`00o`000>i8002T
_@0007`K000b@@8000DN02@003=2001m6@2Y_P00kTD00?l0003[D000U;T0001h9000:cd000@L0006
8000?4H008<=0<74003b>000o`400>MO001i/P00070`000R=`000a/000TS001=CP08S@00c;800?HW
003n1`00h7H005BW0000ICh001L`00026@003RP005Q902VI003FUP020?/D001G0=JF000YV@0005Q9
000>:0000QT001Pa001W?01JZ@00hW400?h5003e;000b;/000280`00@dT000LQ00047000:cd007TR
09fk003^B000o`000>]B002:]P0007@Z000U>@000a/000TS001>CP0<S`00cZ`00?PP003m2`00g8D0
03bP0000GDH0010[00026@005Rl0:hLO0>9b003n1@00m2h00<No0000Q@T003a600067`001Ad003A2
0020502k`P00lSL00?l2003TJ@00HZ/0001X>`006340008I000?:P00G4H0>il00=b4003m2P00mb<0
0<bb0003R`0004E:0007800011`002lo001m6P2b`000lCX00?l2003UJ000Hj/0001W>`005c00008I
000A:`00Gd@0AJ800=ml003n1`00mB/00<Nn0000Q@X003Y5008000DN05X003]600261`38^`00mRT0
0?d8003MP000?J00001LA`003bT0008I000K<`00K3D0Mk400>UI003o0000kDX0092h0000Lb/0028g
00036P0032H005M:02bJ003IS000o@`00?LR003;]00008T1000oA`001Ql000DN000jA@00QPL0bKT0
0?HV003m2P00fhP0032L0000EdX000`V00036P008SP007@Y09Rj003^A000o`400>IS001T[00006Hm
000E;P000QT001D^001V?@1T[000iV<00?l0003^AP00U;T0001c:`008CL0008J000=9`00FTP0?J00
0=im003n1P00m3400;k30000OQP002dn00036`002B<0059=026F003GTP00o0h00?LR003:]`0008H7
000hA0001Ad000LP0019C00?T000dZ400?/E003i6P00cjX000B;0000@DP200067`1c0011B005R`00
cjT00?TI003j5@00dJ<000^>0000ADX000HO00057P00?TL00HX00<j/003i6P00naD00=:R000;SP00
04E:00067`001Ah003m800B;003?Z@00nQP00?XG003@Y`001H`00010B0001Ah000HO0016BP0>S`00
dj000?/C003h7@00c;8000271P00=d<000@M00088@00D4h07iH00=R@003m2`00mRT00<G20000OaH0
02`m00036`002bD005Q:03VO003ON`00oP@00?4j002R_00007@Y000O=P000QT0010Z001R@@1OZP00
if000?l0003ZD`00Lk00001W>`0052d0008I000K<`00L300T[P00>m1003o0P00hGD0042Q0000FDT0
00/U00036`00;Ch0080C0<Rm003g8`00o1000=>N000<S`00049900057P001R0004a=01^D003HT@00
o@X00?D]002j`P0007XP000T>@000QX000lY001Q@P1NZP00ieh00?l0003YF@00IZ`0001S@0002B80
02<h001i8P2h`@00mBd00?d;003GT`005i<00018C00200067`1H001:C@0JU000f8l00?d9003d<000
[kl0001f9P007cH0008I000C;000Ic/0N;400>a=003o0@00hfl004>R0000F4T000XT00047000=480
08L50<n[003j5@00n1h00<Vj0000P1<002Xm00036P003RP005m405jZ003XG000o`000>MQ001FZ000
05e6000<9`000a/002lo0024303</@00nQP00?TL003:]`00084B000[?@000aX000hX001Q@P1T[000
jEL00?l0003TJ@00BJ@0001IB@002R@000@L000gA002RP00dZ800?`?003f:000_<<0001h8`0083H0
008I000D;P00JcL0S;L00?0o003n1@00fhH0026F0000Bdd000HO00078000D4h0;9X00=il003o0P00
kTP007Zb0000ISd0014[00026P009c/007lE0<Zh0080nA/001P0bKP0001o5@009c/0008J000A:`00
Ic`0P;<00>m4003o1000g8<002:G0000Bdd000DO00078@00DTd0=Yh00>5c003o0@00jU<006F/0000
Gd@000dW00036`00=48:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool06000
KS<0028g00036`00228004=900261`35a000lSP00?l1003YF000R[H0001f9P00:cd000@L00067`00
>4@007lE0:bo003_A000o`000>a<002M^`0007/N000a@08000DN00T00391001l702P_000kDX00?l0
003^B000YKd0001m6P00<d800P001Ah0o`00<D0007/M0:2l003]BP00o`000>e9002Q_00007/M000a
@0001Ad000DN000e@P00OQL0[;l00>m3003o0000je80096h0000MbD002Xm000470001b0003i70024
2`34a000lSH00?l2003WH@00M[40001_<@008CL000<K00098`00CTh02Xh00<f`003f9@00oPP00>1h
001AYP0006@o000G<0000QT000lY001IB@0/VP00ei@00?/C003j5@00eYL002NH0000EdX000dX0002
6@006C4006Lk05fZ003RK`00oP@00?@^0038_@0008L50011B0001b0000@L000/?P00NR00X;`00>i6
003o0000jU@008Ne0000Lb/002@i00036`002B<004m>00n@003?ZP00n1l00?d<003KQ`00>Il0001L
AP0042X0008I000F;`0]Qal0hW000?h4003d<000a/4000242`00>dD000HO00057P00=D<0084B0;k3
003b=@00o`<00>A[001OZP0006Ll000G<0000QT0010Z001MAP0mX000gH800?d:003g9@00bk@0006:
0000@dT000LP00047@00<40007hH0;G1003b>@00o`800>AY001PZ`0006Hl000G<0000QT0014[001O
A018X`00ggX00?h6003e;@00akl000243000>4@000DN00067`00?DH008L60<Vi003f9`00o@T00=f2
000kW`0005]7000>:@000QT001`c001]=01j/P00jEP00?l0003/C000SKL0001b;0008CL000<J000<
9P00EdX0;i/00=Z:003m2`00mb@00<^e0000R0<003e700067`001Ah003a600271@3:]`00mb@00?d;
003JRP00;Y/0001GBP002bH000<J000S>000MBP0Vk/00>m3003o0@00iFD0066[0000ICh001@^0002
6@005Bl006Ll06N]003WH@00o`000>i7002A^000078/000P=P000QX000hX001KA`0oX@00gg/00?h5
003c<P00^/80001m6P00;3d000<K00098`00Ddd08iL00=R@003l3@00mb@00<Vh0000Q@T003M30004
7@001b4004Y<016@003CW`00na@00?TK003>[0000X/0000oA`001Ah000HO0012B@07S000d:P00?XH
003j5`00dJD000V=0000A4X000HO00057P00?dL00h/00<nZ003i6@00nQH00=6T0009S@0004=90006
7`001Al0045800J<003@Y`00nQL00?XH0000cP3?Z@000h/0000oA`001Ah000HP0017B`0@T000dih0
0?/B003h7`00bk@000262000=T<000@M00088P00D4d08IL00=V>003m2P00mBX00<G40000OQP002/m
00036`002bD005Q903bP003ON@00o`<00?4l002O^`0007<[000N=@000QT0014[001S@01RZ`00ieh0
0?l0003ZE@00L:l0001W?0004bd0008I000K<`00LBl0UKT00?10003o0`00h7L003fP0000F4T000/U
00036`00;Sl0084A0<Rk003g8@00na400=>O000:SP00045800057P001b0004i>01fE003HS`00o@X0
0?@^002g`@0007TQ000S>0000QX0010Z001R@@1QZ`00j5d00?l0003XF`00Hj`0001R@@002B8002<h
001i802k`P00mB`00?d;003GU@005I800017B`001Ql000HP001<C@0LU@00fHh00?d8003c<P00[;l0
001e:0007cD0008I000C;@00J3X0Nk800>e;003o0@00hW40046Q0000F4X000XT00047000=D8008P3
0<nY003k5000n2000<Rk0000OaD002Tl00036P003RP00613062[003YFP00o`000>IS001CY`0005a6
000<9P000a/0031000252P3=[`00nQL00?PM0039^@00080D000Z?0000aX000hY001R@P1W[@00jUD0
0?l0003TJP00AZ<0001HB@002R@000@L000iA004R`00dj000?`>003e:@00^L80001g90007cH0008I
000E;P00K3D0SkL00?0m003n1@00fhP001jF0000BT`000HO00078000DDd0;i/00=mj003o0P00kDX0
07Na0000ICh0010Z00036P00:3/0080C0<Zf003i6P00nA`00<Vj0000OQL002Hj00026P004R`006Pk
08>d003_@P00oP@00=b5000PUP0004U<00057P001b4005=<03RN003RL@00o`000>YE001RZ`0005m4
000<9P000a/003E22_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo02<006dd
000Q=`000a/000PR0015BP00Q`D0aL800?8g003o0@00jEX008Je0000MBP002Xl000470001Ql003U4
0020502``000kd<00?l0003/CP00V[X0001j7`00<40000DM00057P00<d4007`K0:>m003]B@00o`00
0>e9002R_00007`L000b@@0200057P1N000b@@00O1/0Xk`00>e8003o0000kD/009fk0000Nah00310
00057@001Ah003I3001o5P2__`00kd400?l0003ZD`00S[L0001f9P00:C`000@L00078000?dP008D9
0<G3003c=@00o`800>IS001c/00006hb000P=P000aX000XT001?CP0<SP00cJl00?LT003m2000ggX0
04nU0000I3l001H_00026@003bT005Y802jK003GTP00na800?XF003EV@0099P0001GBP003BL0008I
000J<P00J3X0H:/00>=]003n1000m2l00<Nn0000QPH004180006800011`002dn001j7`2S_000kTD0
0?l0003ZEP00Q;D0001b;@008cP000<K00098`00D4h04I000=2X003h7P00o0d00=Z9000gWP0005a7
000?:P000QT001L`02j87`3SKP00o`@00?<a0035``0008<=000iA@8000DN09P003M300224032a000
lc@00?l3003SK@00GJX0001V?@005c00008I000@:`00GTD0@:400=f0003m2@00mRH00<Zf0000R@00
04990006800011d00351001o5P2i`P00lSL00?l3003TJ`00GJX0001V?@005Rl0008I000B;000H4<0
BZ@00>1h003n1P00m2h00<K10000P`h003M300057P001Ql003i70028103:]`00mRH00?d:003LQ000
>9h0001JB0003RP0008J000M=000KS<0OK<00>YF003o0000k4h008Zf0000LBh0020f00026P0032L0
05Q9036L003KR000o@/00?LU003:]`0008L5000lAP001Ah000DO000mAP00R0<0bkD00?LS003m3000
fH`002^J0000ET/000/U00036P0093T007HV09jk003_@@00o`400>EW001NZP0006@o000D;@000QT0
01H_001W>`1Z[@00iel00?l0003]B@00S[L0001a;P007cD0008J000>:000G4L0@Z800=mi003n1@00
lc@00;O10000O1`002/m00036`002R@005=<02JH003ISP00o@`00?LU0039^P0008@;000f@`0011d0
00LQ001<C@0CT@00e9d00?/C003i7000cJh0002:0000?TL000DN00067`00A4X02Hd00=6V003j5`00
nQP00=2W0007S000049900067`001Al0045800F<003@Z000nQP00?XG003@YP001hd00012B@8000HO
0=<0049900R=003AY@00nQH00?TI003>Z`000HX0000mAP001Ah000HP0019C00BT@00e9`00?/A003h
8000b[H000252P00=D8000@L00088P00DDd099L00=V<003m2P00mB/00<;40000OAX002Tl00036`00
32H005U903nQ003PM`00o`<00?0m002K^`0007</000N=@000QT0018[001T?`1U[000j5`00?l0003Y
E`00KJh0001V?@004bd0008I000L=000LBh0VKX00?0n003o0`00h7T003ZO0000EdX000XU00036`00
;cl0088?0<Vi003h8000na800=:Q0008S@0003m700057P001b4004m>01nF003IS@00o@T00?@`002d
`@0007PS000R>0000QX0010Z001R@@1T[000j5/00?l0003XG@00H:/0001Q@P002B8002@i001j7`2n
``00mBX00?d<003FU`004Y400015BP001Ah000HP001>CP0OUP00fX`00?h8003c<`00ZKh0001d:@00
7SD0008I000D;@00JCT0O[<00>e9003o0@00hG<003jP0000EdX000XT00047000=T<008T10=2W003k
4`00n2400<Nm0000OaL002Pk00036P003RT0065206>/003YF000o`000>EU001@YP0005a7000<9P00
0a/003500026203>[@00nQH00?PN0038^`0007lE000X?0000aX000lY001R@@1Z[@00jU<00?l0003S
K000A:80001HBP002R@000@L000jA@06S000dih00?`>003e:`00]/40001f9P007SD0008I000F;`00
KC@0T[P00?4k003n1P00fXX001bE0000B4`000DN00078@00DTd0<I`00>1h003o0P00kD/007B`0000
I3l0010Z00036P00:C`0084B0<^d003j6@00n1d00<Rl0000OAT002Di00026P004R`006Tj08Je003_
@@00oP@00=^7000MU@0004M;00057P00224005A<03^O003RK`00o`000>UG001OZP0005i5000<9P00
0a/003I300[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`0S001/=@0083H0
00<K00088P00Ad/008P30<K1003b=@00o`400>QL0023]00007@Y000Y?00011`000HP000jA@00PA80
/l000>m1003o0000je0009Ni0000NB4002lo00057@001Ah003A2001m6@2W_@00kTL00?l0003]B`00
W[/0001k7@00<D000P001Ah0GP00=48007dJ0:Jm003^AP00o`000>a=002J^P0007XP000^?`0011d0
00HO000gA000P1@0//000?0o003o0000jUD008Zf0000MBP002Pk000470001b40045800261`36`@00
lc<00?l2003UI@00L:l0001]=0007cH000<J000:9000D4h03Xl00<j]003g8`00o@T00=il001<Y@00
06=0000E;`000QT0010Z001KB00aW000f9000?/A003j5`00e9/002:G0000ET/000dW00026P006S80
06Ti06>[003TK000o`<00?@a0036`00008D8000nA`001R0000@M000_?`00Nad0Y[d00>m3003o0000
jEP0086d0000LBh0028h00036P002R@0051=01>A003@YP00nAd00?`>003JR`00=9d0001KA`003bT0
008I000H<@0_RAh0hf`00?l3003c<`00a<@000223`00>4@200057P3o000hA000P`l0aL@00?<b003o
1000hfl005ZY0000ICh001H_00026@004B/005i404>R003NOP00o@P00?HW003:^00008P20010B000
1R0000@M000c@@00P1D0_<800?8e003o0`00hfd005ZY0000ICh001D_00026@004R`0065204fU003P
MP00oPD00?@`0035``00088?000f@`001Ad000HO0010B000R080bkD00?LU003m2P00fhH003FM0000
FTP000dX00026P007C@006lb082c003ZE000o`000>]?0027]@00074_000O=P000QX000dW001IB@0d
W@00fhH00?d:003f9P00bKT000261`00>dD000DN00067`00?dL008T10<^c003g8P00o0d00=V>000Y
V@0005E;000;9@000a/002Dj001g9@2R_000l3l00?l1003TJ@00FjT0001T?`004bd0008I000G<000
J3X0KJh00>QM003o0000kD/008^f0000LBl001he00026P003bT005e604FR003PM`00oP@00?8e002d
`@0007/M000Z?0000a/000XT001DC00XV@00fH`00?d;003f9P00b;`000233@00=48000@M00078@00
CTh05Y800=BK003k4P00n1d00<f`0000R@4003a600057P001R0004E:00^>003AY000nQH00?XI003?
Z@001H`00011B0001Al000HO0012B@07S@00d:H00?XG003j6000d:P000F<0000@4P000DN00067`00
A4X02Xh00=6S003j5@00nA/00<j]0000R@0003a600057P001b0004Y=01BB003EVP00o1000?LQ003:
^00008@<000c@@0011`000PR001BC@0VV000fXX00?d9003e;@00_/<0001l6`00:3/000<K000<9P00
FTP0@J400>5e003o0`00l3l009Rj0000LRd001dd00026@004R`006Dn06R]003XFP00o`000>UI001Z
[P0006Dn000B;0000QT001dd001b;02L^`00lC`00?l4003ON`00>9h0001FBP002R@000<K000`@000
P`d0b[L00?PO003k4`00dJ<000J<0000?TL000DM00078@00D4h08YL00=Z;003n2000lc400;300000
Mb@0024g00026P004B/006=006N]003YF@00o`000>MO001MZP00061300098P009CX007/M0<74003f
:@00o0d00=FI000@T00004=900057P001b0004m>026G003JRP00oPL0001^0?<e002V_@0007@Z000M
=0000QT001@^001Z>021]000kTP00?l2003QM@00>il0001FB`002B<000@L000hA000RP00dJD00?/B
003g8P00akl0001n60009c/000<J000?:@00HT40IZ`00>YF003o0000iFL004fU0000FdL000/U0003
6`00<T4008H60<j[003j5@00n2000<Rm0000OQL002Lk00036P003bX006=006f^003[DP00o`000>=^
0011X@0005M:00098`0011d003]600R=003DW000o0d00?D/002c`00007DW000M=0000QT001H_001^
<`2F^@00lCX00?h6003JS0006Y@00016B`001Ah000LQ001CC@0dW@00h7H00?l1003/C@00LJl0001T
@0003bT000<J000[?@00PQ00c;800?XG003h7`00akh0001m6`0093T0008J000C;@00JST0RKH00?0o
003n1@00fXT001^D0000AT/000DN00088P00ED/0?Z000>=]003o0000jET005bY0000GDH000/V0004
7000=d@:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0P`00JcH001le0003
6P002B<004Q<00290@37_`00lc@00?l2003WGP00P;@0001c:`009c/000@L00068000?4H0088@0;K1
003`?`00o`000>]B002C^@0007PR000]?P0011d000DO000f@`00OQL0Z[h00>i5003o0000k4d009^j
0000NQl0031000057@001Ah003E2001n602Z_P00kT@00?l0003/C`00UkT0001i8P00;Ch000@M0006
7`00>D@0084B0;K1003`?P00o`000>UG0027]@0007@Y000W>`000a`000LQ0012B@00Q`D0akl00?<a
003o0`00iFL006f^0000KCD001he00036P002R@0055=012@003?Z`00mb400?d:003NOP00BJ@0001R
@@005Bh0008I000@:P00FdL0<id00=V>003l4000nQP00=>M000OUP0005E;000<9P000QX001/c001Z
>01V[000i6X00?l3003c<P00aL8000252P00?DH000HO00047@00<40007`K0:Zn003_@@00o`000>UJ
001n/`00070_000Q=`000aX000XT001AC@0ETP00dJ@00?TK003l3`00fHd0036L0000FTP000lY0002
6@006C40<HXN0>AZ003o0`00lcD00<330000PQ4003M3008000DN0?l003U500233@35`P00m3400?h4
003RL@00EjP0001T?`005Bl0008I000B:`00Gd@0AZ<00=il003n1`00mRT00<Vi0000Q`@003m70006
7`001Ad003A200214`2o``00lc@00?l3003RK`00EjP0001T?`005Bh0008I000C;@00HT40D:H00>5d
003n1000lc400<C40000PA4003A200057@001R0004580029003;/`00mb<00?d;003KR000<id0001I
B@003BL0008J000N=@00L300Pk@00>]B003o0000je4008Be0000L30001he00026P003BP005Y803NN
003LQ000o@T00?HX0038^`0008D9000iA@001Ah000HO0010B000RP00c;400?PP003l3P00f90002JH
0000E4`000XU00036`009SX007PS0:Fm003`?P00o`800>A[001HZ00006=0000C;0000QT001L`001Y
>@1`[`00j5/00?l0003/C@00R;H0001`<0007C@0008J000?:@00GTD0B:<00>5e003o1000lSL00;70
0000NQl002Pl00036`002R@005E;02^J003JRP00o@X00?HX0037_P00088?000c@@0011`000PQ001?
CP0HT`00eIT00?`@003h7`00c;8000280`00>dD000DN00068000Ad/03Hl00=:R003k5@00nAX00<n[
0003R`0003m700057P001Ql004A:00Z>003AY000nQH00?TI003?ZP000h/0000oA`001Ah000HO0015
BP0=S`00dZ400?/D003i7000cJl000280P00>TD000DM00078@00C4d05i<00=FH003l3`00mb<00<Vj
0000P`h00391000470002B<005=<02VI003KR000o@P00?@_002k`P0007/M000W>`000aX000`W001K
B014XP00hG<00?l2003_@@00UKT0001a;`0073@0008I000C;000ICd0Jjh00>UH003o0000j5/006N]
0000I3l0018/00026@007SD007<[09nl003a>`00oP@00=im000eW@0005I;000:900011`003910024
303;]@00n1h00?/D003AY@0018/0000lAP001Ad000LQ001@CP0TV000fXT00?h7003c<`00[Kl0001f
9P0083H0008I000A:`00I3l0JZh00>UG003o0000if4005ZY0000H4<000TQ000V>P00O1/0aL@00?HW
003l3P00e9/000j?0000@TT000DN00078@00Cdh099L00=^8003n1P0006h0lSL00::l0000Lb`001`d
00026@005Bh006/g08Fe003^AP00o`800>1g000iW`0005E;00098`0011`003U500:;003AX`00na40
0?LS0036`@0007dJ000V>P000QX000lZ001S@01Y[@00jUD00?l0003TJ@00BZ@0001JB0002bD000<K
000d@P00Q`@0cjT00?/D003h8@00akh0001m6@009SX0008J000@:P00I3l0L:l00>]@003o0@00hW00
03jP0000ET/000TS00047@00?DH02Xh00=FJ003m3000m2h00:no0000MBT001`d00026@005c0006lb
09Vj003b>000oPL00=V>000GT`0004E:00057P00224005=<03NN003QM000o`400>a?001^[`0006=0
000?:@000aX002`m00233P3=/000nQH00?PP0036`00007`L000S>0000QT001<]001Z=`2<]`00l3d0
0?h6003JR`006I<00014BP001Ah000PR001EB`10X@00i6/00?l0003XF`00FJT0001LAP002bD000@L
000iA0[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o001Z=`007SD000<J
00098`00BT`008X00<Rm003c<P00o`800>MP001m/`00078/000V>P0011`000LP000mA`00P`h0^/80
0?0m003o0000jU@0092h0000Mb@002`n00047@001Ql003M4001o5@2]_`00kd<00?l0003/C`00V;X0
001i8@00;Sl000@M00057`00=T<007lF0:fo003_@`00o`000>]@002D^@0007PS000/?P0011d000HO
000jA@00PQ00^L800?4l003o0000jET008Be0000Lb/002Hj00036`00224004A:00280`37_@00m300
0?l3003TJ@00JJd0001/=P007CD000<J000;9@00DDd04i400<nY003h8000o@/00=f00016X`000652
000D;P000QT0014[001LAP0fWP00fX`00?`?003i6P00dj0001fE0000E4`000`V00026P0073@006/g
06V]003UJ000o`<00?<d0035a00008@<000kA@001Ql000@M000a@000OAX0[Kl00?0o003o0000j5/0
07^b0000Kc40020f00036P002RD0059=01RC003BXP00nAX00?`@003HS`00;i/0001IB@003RP0008I
000I<P0cRad0i6P00?l2003b=P00_L<000214`00=D8000DN00067`00>dD008@;0<K0003d;`00oPD0
0>5c001DY`0006=0000E;P000QT0018/001P@`19Y000ggX00?h7003e:P00b;/000261P00?DL000HO
00057P00=D<0084A0<?4003c<P00oP@00>9a001DY`0006=0000D;@000QT001@]001S@01CY`00hW80
0?h4003c<`00`<<000204`00<d4000@M00068000@dT00XX00<ba003g8P00o@`00=Z:000`W00005Q9
000=9`000QX001lf001`;`26]@00je000?l0003ZD`00PK@0001_<P007C@0008J000>:000FTP0>Yl0
0=f2003m2000mBT00<Rm0000Q0/003Q400057P001Ql0049900::003=[`00n1l00?`?003GTP008iL0
001CC0002R@000<K000W>`00NB80Z;h00?4l003o0P00hfd005FX0000HT40018/00026@00634006Xh
07>`003YF@00o`000>a?0025]@0006lb000L=0000QT0010Z001NA01:Y000hG<00?l3003b>000[Kl0
001i80009c/000<K000;9@00ET/0;Y/00=^8003m2@00mBT00<K00000PA400391003c000470002280
051>01ZD003FU`00o0l00?PP003;]00008L5000iA@001Ad000LP0019C00@T000dj000?/D003i6`00
cZd0002:0000?DL000DN00067`00ADX038h00=:R003k5@00nAX00<j/0001RP0003e700057P001R00
04M;00n@003CW`00na<00?PM003</@0008L4000iA00011d000LQ001>CP0IU000eYH00?`>003g9000
b;`000223`00<D0000@L00098`00E4`0:iX00=^6003n2000m3000;S10000NQl002Hj00036P003BL0
05a704NS003RL@00o`800>m3002A^000070`000K<`000QT001<]001V?01^[`00jUH00?l0003XG@00
I:`0001S@0004B/0008I000O=@00M2T0Xk`00?4i003n1@00gWl003:L0000ED/000TS00047000<d40
08D:0<^c003i7000nQD00=2W0002RP0003]500047@002280055=02NI003KQ`00oPL00?<d002Z_P00
07DW000O=P000QT0018/001U?P1][P00jUD00?l0003VH`00EjP0001OA0002B4002Pk001m6P35`P00
mRH00?`?003DW@002hh00010B0001Ah000LQ001@CP0VV000g8D00?h6003b>000Wk/0001b;@006c<0
008I000F;`00JcH0R;H00>m4003o0P00h7T003JN0000E4`000TS00047@00>dD01H`00=:Q003l4000
mbD00<G30000O1`002Di00026P0042X006@o06f^003[D`00o`000>A[0017X`0005U9000:9@0011`0
03E200280P3@Y`00na<00?LR0036`00007dK000U>P000QX0014[001U?P1c/000k4h00?l1003QLP00
>il0001EB`002B8000@M000nA`0=S`00eIP00?d;003d;`00[;l0001d:P0073<0008I000H<@00Kc40
W;/00?8f003n2000f90001FB0000@dT000DN00088P00E4`0>Il00>5b003o0@00je4006^^0000HT40
00hX00036P00;Ch008@<0<f^003j5@00mb400<K10000Nah0028h00026@0052h006/f092h003a>`00
oPH00=V=000FTP0004=900057@002B8005I:04>R003TJ@00o`000>QM001FZ00005]7000;9@0011`0
03Y500[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o001Z>@007C@000<J
00098`00C4d00X/00<Rk003d<000o`800>IR001j/P00078]000U>P000a/000LQ000oA`00Q0`0_L<0
0?4l003o0000jUH008fg0000MRD002/m000470001Ql003U40020502a`000kd400?l0003[D@00U;T0
001h8P00;Ch000@M00067`00>4@0080D0;70003_@@00o`000>]B002@^00007LU000[?@0011`000HP
000lAP00P`h0_L<00?4j003o0@00j5/0086d0000LR`002Di00036`00228004I;00290@38^`00m2h0
0?l4003TJ`00IZ`0001[=`007C@0008J000;9@00DTd05I800=2W003h7`00o@/00=b30013XP000613
000C;@000QT0014[001MAP0iW`00fXX00?`>003i6`00dZ8001ZD0000Dd`000/V00026P007C@006`f
06b^003UI@00o`800?8f0031a00008<>000jA@001Ql000DM000b@@00OQP0/L000?0n003o0@00j5d0
07Na0000KS8001lf00036P002bD005=<01ZD003CX000nQT00?/A003HT@00;9X0001HB@003RP0008I
000J<P0dS1`0iFH00?l2003b>000^L8000205@00=48000DM00067`00?4H008D90<Nn003d;@00oPD0
0>5e001AYP0006=0000D;P000QT001<]001Q@P1<Y@00h7P00?h6003e;000akd000252000?4H000HO
00057P00=d<0088?0<G3003d<000oPD00>5d001AYP000691000C;@000QT001@^001T@01FZ000hW00
0?l3003c=000_<<0001o5@00<T4000@M00078000ADX018/00<f_003h8000o0d00=V=000]V`0005M:
000<9P000aX0020f001a;P2:]P00k4h00?l0003ZE@00OK<0001^<`0073@0008J000>:000FdL0?:00
0=f0003n2000mB/00<No0000P`d003I300057@001R0004=900B;003>[@00n1h00?`@003GU@008IH0
001CC@002R@000<K000Y?000NR00[;l00?4j003o0`00hfl005:W0000HD80014[00026@006C4006/g
07Ja003YE`00o`000>]A0021]00006hc000K<`000QT0010Z001OA01=Y@00hW400?l3003a>P00Z[h0
001h8P009SX000<K000;9@00ETX0<9`00=^6003m2@00mB/00<K20000PA<00310003c000470002280
051>01fE003FU@00o0l00?LQ003:]P0008H7000hA0001Ad000LP001:C@0BT@00dih00?/B003i7@00
cJl000290@00?4H000DN00068000Ad/03Xl00=:P003k5000nA`00<f^0000R@0003a600057P001b00
04U<016A003DW@00na800?PN003;/`0008H6000gA00011d000LQ001?CP0LU000ei@00?`=003f9@00
akh000214@00;cl000<L00099000E4`0;Y/00=b4003n1`00lc800;C10000NB4002Dj00036P003BL0
05a604ZT003SK`00o`400>i4002>]`0006la000J<P000QT001@]001W>`1b/000jU@00?l0003WG`00
HJ/0001R@@004B/0008J000P=P00MBP0Y[d00?8g003n1@00gH40032L0000E4`000TS00047000=480
08H70<ba003i6`00nQH00<nZ0000R@0003U500047@002280059=02ZI003LQ@00oPH00?8f002V_@00
07@Y000N=@000QT0018/001V?@1`[`00je<00?l0003UI@00E:L0001NA@00224002Tl001n6036`000
mb@00?`@003CW`002Hd0000oA`001Ad000PQ001AC@0YV@00g8<00?h5003a>P00Vk/0001a;`006S80
008I000G<000K3D0RkH00>m2003o0`00gg/003>M0000E4`000PR00047@00?4H01h`00=>O003l3`00
mRH00<C40000Nah002@i00026P004B/006@o072_003[D@00o`000>=]0014XP0005Q9000:900011`0
03I30029003AY@00na800?LT0035`P0007`L000T>@000QX0014[001V?@1f/@00k4`00?l1003QM000
>9h0001DC000228000DM0010B00?T000eYH00?d:003d<@00Z;h0001c;0006c<0008I000I<@00L2l0
X;`00?<e003m2000ei8001:A0000@DT000DM00088P00ED/0?:000>9`003o0000je<006R]0000HD80
00hX00036`00;Sl008D:0<j/003k5000mb<00<G30000NR00024g00026@005Bh006`e09>h003a>P00
oPL00=R?000DT@00045800047@002B<005M:04JS003UI`00o`000>MO001CY`0005]8000:900011`0
03a600[ooooo0Ol00001ooooo`007_ooool3o`0000Oooooo06@006Tj000L=0000aX000XT001>CP05
R`00bKT00?@_003o0`00iV@007Ja0000LBl002@i00036`001b40045800252P31a000lCX00?l1003Y
F000RKH0001f9`00:S`000@L00067`00>TD0084B0;G1003`?`00o`000>]C002A^00007LT000/?@00
11d000HO000iA@00PA80]<400?0o003o0000jU@008fg0000MRH002Xl000470001R0003e700243030
``00lSP00?l1003XG@00OK<0001a;P0093T000<K00088P00B4/008X00<Vi003e;@00oP@00>=]001S
[00006Xh000L<`000QX000/V001CC00HT`00dJ@00?PM003l3000g8D0042Q0000Gd@001</00026@00
4R`005i503bP003KQ`00o0d00?TL003AY00069<0001BC@002bD000<J000N=@00KCD0Kjl00>IS003o
0P00lSL00;k30000PQ0003Q40P001Ah0<P00=48007lF0;C1003a?000o`400>MP001d/00006dc000N
=@000aX000/U001DC00MU@00dih00?XH003k4P00ei<002VI0000EdX000dW00026P006c<0=XdL0>IT
003o0P00lCX00;K10000OaH0039100047@001Ql003i700261`38_000mB`00?h6003PM`00CJD0001R
@@004bd0008I000C;@00HT40CjH00>1f003n1@00m2h00<No0000Q0/003Y50P001Ah0o`00>4@008<=
0<K1003d;`00oPD00>1f001>Y@000652000C;0000QT001D^001T?`1IZ@00hfd00?l3003b=P00^L80
001n5`00<40000@L00078@00AT/01X`00<j]003h7`00o0h00=R?000ZVP0005I;000<9P000aX0024g
001b;02=]`00k4`00?l0003YE`00N[80001]=0006c<0008I000?:@00G4H0?j400=in003n1`00mB`0
0<K10000PPl003E200047@001b0004E:00N<003?Z`00nA`00?/A003FU`007YD0001BC@002B<000<K
000Z?000Nah0[kl00?8h003o0`00hW4004nV0000H4<0014[00026@006S8006`f07Zb003ZE@00o`00
0>]C001n/`0006dd000K<`000QT0014[001P@`1AYP00hVl00?l2003a?000Y[d0001g90009CX000<J
000;9P00EdX0<id00=b4003n2000mB`00<G40000P1D002lo000470002B<0055=022F003GT`00o0h0
0?LS003:^00008D9000f@`0011d000LQ001<C@0ETP00e9/00?/A003h7P00c;4000280`00>TD000DN
00078000BD`04I000=>N003k4P00nAd00<f`0000R0<003Y500057@001b0004]=01BB003DV`00o100
0?PP003;]@0008D8000f@`0011d000PR001@CP0NU@00f9400?d<003f9`00a/0000204`00;Sl000<K
000:9000ED/0<I`00=f2003n1P00lc<00;300000N28002@i00036P003RP005e504fU003SK@00o`40
0>i6002;]P0006hc000J<P000QT001D^001X>P1e/@00je800?l0003WH@00GZX0001R@P0042X0008J
000Q=`00MRH0Z[h00?8e003n1P00g8<002fK0000Dd`000TS00047000=T<008L50<f_003i6P00nQP0
0<j/0000R08003Q400047@00228005=<02bJ003LP`00oPD00?8h002S_00007<Z000N=@000QT001<]
001W?01d/000je400?l0003UI`00DJH0001MAP00224002Xl001o5P37_P00mb<00?/A003BX@001h`0
000mAP001Ad000PR001BC@0/VP00gH400?h5003a?000V;X0001`<0006S80008I000G<000KC@0SkL0
0?10003o0`00gWd0032L0000Dd`000PR00047@00?TL02Hd00=BM003l3P00mRP00<330000F@00NQl0
02<h00026P004B/006Dn07>`003/C`00o`400>9_0011X@0005M:000:900011`003Q400::003AX`00
o1400?HU0034a00007/N000S>0000QX0018/001W?01j/P00kDX00?l2003PM`00=Yh0001DC0002280
00DM0012B@0BT@00ei<00?d9003c<`00YKd0001b;@006S80008I000I<P00LBh0Xkd00?<c003m2@00
ei@0012@0000@4P000@M00098`00ET/0?j400>=^003o0000jUD006B/0000H4<000dW00036`00;cl0
08H80<nZ003k4`00mb@00<?40000NB40020f00026@005Bl006dd09Ji003b>000oPP00=RA000AT@00
03m800047@002B<005Q904VT003UI@00o`000>MQ001@YP0005Y8000:900011`003e700Sooooo0ol0
0001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1T001X>`006c<000<J000:9000Cdh01h`0
0<Zg003e;@00o`<00>EV001c/000070`000S>0000a/000PQ0012B@00QPP0a<@00?8h003o0@00jEX0
08Je0000MBT002Tl000470001R0003a60022402h`P00l3h00?l0003ZE@00SKL0001f9P00:cd000@L
00067`00>dD0088@0;S2003`?@00o`000>YG0029]P0007DX000X>`0011`000LP000oA`00Q@X0a<@0
0?8g003o0@00iel007Zb0000L2l002<h00036`00228004U<00>;003:]`00mB/00?h5003RK`00H:/0
001Y>@006c<0008J000<9P00E4`06i@00=:R003i7000o0d00=^7000mX00005i4000B;0000QT0018/
001OA00oX@00g8D00?d<003h7P00d:H001FB0000DTd000/U00036P007cD006hc07>`003WH@00o`40
0?4i002j`P00084B000g@`8000DN038003E30020502h`P00lCX00?l1003VHP00LJl0001]=@007C@0
008J000<9P00ED`089H00=BK003j5P00na<00=JF000VV00005M:000=9`000QX001`c03N=6`3VHP00
o`400?4l002b`00007hH000a@00011d000HP0010B000Q`@0bKX00?DZ003n1`00ggT004ZT0000HD80
01</00026@0052h006=005:V003QM000oPD00?@_0036`@0008<=000iA08000DN0?l003Y500242`37
_`00mBd00?h6003PN000Bj@0001P@`004R`0008I000F;`00ICh0G:X00>A[003o0P00lSP00;G10000
OAT002lo000470001b4004Q<00V=003>Z`00n1h00?`?003HT@00:9T0001EB`002bD000<J000R>000
Lb/0TKP00>e:003o0000jET007Ja0000K3D001/c00026@003bT005e604:R003OO000oPH00?@^0035
``00084A000c@P0011d000LP0017B`09S@00cjT00?TK003k4P00eIT001bD0000DDd000TS00036`00
:cd007`L0;?0003b=`00o`@00>5c001<Y@0005m4000@:P000QT001/c001]=01m/`00jU<00?l0003Z
E@00N[80001/=@006S80008I000A:`00HD80E:L00>=]003o0P00l3h00::l0000MbD002@i00036P00
32H005Q903JN003MPP00oPL00?@^0032a00007lG000^?P000a`000TS001BC@0RU`00f9000?`=003g
9000bKX000242`00=D8000@M00078@00CTh05i<00=FI003l4000n1l00<^c0000Q`D003U400057@00
1b0004]=01>A003DW000na400?PN003</P0008L5000iA00011d000LQ001=CP0FT`00eIT00?`?003g
8@00b[L000242`00=48000@L00088P00DDd08IH00=R?003m2`00mRT00<K20000OaD002dn00036`00
2R@005I;03BM003MP000oPD00?8e002]_`0007LT000S>0000QX000hX001NA@1@YP00i6X00?l1003]
B000QkD0001]=0006C40008I000E;`00JCT0N;400>]@003o0000iV<005ZY0000HD8000lZ00026P00
8SL007LU0:fo003c=000oPL00=b5000ZVP00059=00088P0011d003M400280`3>[@00nQP00?XI003>
[P0008L4000f@`0011`000TS001DC00_V`00gH000?h5003a>P00Wk/0001c;0007C@0008I000D;@00
J3/0Mk400>a?003o0000i6T004jU0000G4H000PQ000[?@00P1@0b;`00?LQ003k4P00dJ<000B;0000
>dH000@M00088P00Dd`0;i/00=io003n1000l3h009Bi0000Kc4001Ta00026@00634006hb09:h003`
?P00oP@00=eo000]V`00059=00088@001Ad003m800b>003DV`00o0d00?DZ002l``0005T007TQ000R
>0000QX0018/001V?01g/@00k4d00?l1003RL@00?Z00001GBP002B<000@L000iA@04R`00dZ400?`?
003f9`00`L@0001j80008SP0008I000B;000J3/0OK<00>i8003o0P00ggT003>M0000Dd`000PQ0005
7P00@dT059800=RA003m2000lc@00:6l0000LBh001Ta00026@006S80078/0:Nm003c<@00o@X00=JF
000=S`0003i700047@002B<005M:04:R003SK000o`000>UG001QZ`0005m4000=9`000a/003500027
1P3@Z000na800?HV002o``0007PS000O=P000QT001H_001^<P2J^P00lSH00?d8003GU0003i00000n
A`0011d000XT001IB@1<Y@00iV<00?l0003VH`00CJD0001IB@002B@000@M000oA`0:ooooo`7o0000
0Oooool001kooooo00?o0000ooooooooool01oooool0I000Ic`001Xb00026P002bD0051>00V=003;
]@00mB/00?h4003TJ000Kjl0001_<P008SP000<K00088P00A4X008L60<G2003b=P00o`400>QL0022
]00007@Z000W>`0011`000LP000mA`00P`d0_<800?4l003o0000jEL008Zf0000MBL002Tl00047000
1R0003a600233P2l`P00lC/00?l1003YF@00Q[D0001d:P009c/000@L00078@00@DP008H80<G3003c
=@00o`800>IQ001f/@0006la000R=`000a/000TS001;C@05S000bkD00?DY003n1P00hW4005bZ0000
J3/001Xb00026P0032L005E;01fE003CX000nAX00?`>003JR@00>Yl0001NA@004B/0008I000C;@00
H4<0@Z800=b3003m2`00n1l00=2X000BT@00055=000:90000aX0020f001_<P1f/@00iel00?l1003a
>`00]/4000205000=D8200057P3o000g@`00PA80_<800?8h003o0P00iV@006f^0000K3H001`d0002
6P0032H005E;02:G003EV@00nQD00?/D003EV00099L0001FB`0032H0008J000M=00iSQ/0if000?l1
003`?@00[[l0001m6P00<40000@M00078000@DP008P20<Vh003f:000oPL00=ml0017X`000613000B
;0000QT001D^001T?`1EY`00hW800?h4003d<@00aL@000223`00=d<000DN00067`00>dH008D90<Nm
003e:`00oPL00=mj0018X`0005m4000A:`000QT001H_001V?01PZ`00i6T00?l2003a>P00/L00001l
6`00;Sh000@L00088@00BT`02hh00<nY003i7000o1000=NC000UV00005A<000;9@000aX002<h001d
:@2D^@00kDP00?l0003XF`00Lk00001[=`006S80008I000@:P00GTD0AZ<00=mi003n1P00m3000<?4
0000P1<0039100047@001b4004U<00b>003@Y`00nAX00?/C003DV`006I<0001@CP002B<000<L000/
?P00OAX0]l400?<e003n1000hGD004VT0000GTD0010Z00026@0073<006hc086d003[D@00o`000>UG
001g/@0006/g000I<@000QT0018/001R@@1GZ000i6/00?l1003`@000Wk/0001f9`008cP000<J000<
9`00FDT0>Il00=eo003n1P00m3000;k30000OQT002`n00036`002B<005=<02FH003ISP00o@`00?HV
0038_00008<>000c@P0011`000PR001?CP0JU000eYL00?`?003h8@00bkD000261`00=d@000@M0007
8@00CDh05Y800=FJ003l4000n2000<^e0000QPL003M300047@001b4004i>01VD003FUP00o0h00?LS
0039^@0008<=000c@@0011`000PR001AC@0TU`00fHd00?d:003e:P00aL@0001n5`00:cd000<K000;
9@00EdX0=ih00=in003n1@00lSL00:Vn0000MRH0028g00026P003bT005m405BW003TJ000o`000>e:
0023]00006`e000H<@000QT001H_001Z>01l/P00k4h00?l0003UI@00EjP0001P@`003bT0008J000S
>000N2<0/L000?<b003n1`00fhP002NI0000DDd000PR00047@00>D@008T10<n[003j5`00nAX00<f`
0000QPH003E2000470002B<005A<002=03:L003NOP00oP@00?4k002K^`00078]000L<`000QT001@^
001Y>P1k/P00k4d00?l0003TJ`00Bj@0001KA`00224002`n00214P39^P00n2000?/C003AY@000XX0
000jA@0011d000PR001DC00bW000gWd00?l3003`@000TKP0001^<`006340008I000I<@00Kc40U[T0
0?4l003n1000gH8002ZJ0000DDd000LQ00057P00@DP03Xl00=FI003m3000mB/00;W20000N2<0024g
00026@004R`006Lk07Zb003]B`00o`400>5c000kW`0005I;00098`0011d003]500J<003CW`00o0h0
0?HX002m``0007TR000Q=`000QT001<]001Y>P21]000kTH00?l2003ON`00<9`0001BC@001b4000DN
0015BP0GT`00f8l00?h8003b=P00W[/0001`<0006340008I000K<`00Lb/0Zkh00?@`003m2`00eIT0
00^>0000?4H000@M00098`00F4X0AJ<00>AZ003o0000jET005jZ0000GTD000`W00036`00<T4008P3
0=2V003k4@00mRL00;_20000MbD001he00026@005c0006la09jk003c=000o@T00=JF000<S`0003a6
000470002R@005Y8052V003WH@00o`000>EU0019Y00005Q900098`0011d0045800[ooooo0Ol00001
ooooo`007_ooool00ol0003oooooooooo`07ooooo`1T001V?@006C80008J000;9@00DDd038h00<bb
003e:P00oPD00>A[001/[P0006hc000Q=`000a/000PR0016B`00R0<0a/000?<d003o0P00ieh007jc
0000Lb`002Hj000370001b4003m700242`30``00lCX00?l1003YF@00Q[D0001d:@00:3/000@L0007
8000?TL008@<0<33003a>@00o`400>QK0022]00007<[000V>P000a/000LQ0012B@00Q`H0a/000?<c
003o0P00iV@007>`0000KS80024g00036`002B<004e>00R=003</`00mRP00?h6003QM000FJT0001W
?0006C40008I000=9`00ET/089H00=>N003i6@00o0l00=Z<000gWP0005e6000A:`000QT001@]001Q
@P15X`00gH400?d:003h8@00cjX0012@0000D4h000XT00036P008CL0070`07Zb003XG@00o`400?0m
002c`00007lF000d@P8000DN0?l003Q400224030``00lSH00?l2003UIP00JZd0001[=`006c<0008J
000=9`00ET/09IP00=JG003k5000nQH00=FJ000QUP0005E;000<9P000QX001he03^?6P3XGP00o`40
0?0o002[_P0007`L000^?`0011`000LP0013B@00R@00b[H00?HW003m2000gWh004BR0000Gd@0014[
00026@005Rl006Dn05RX003RK`00o`@00?<c0032a000084A000f@`001Ah000HO000mAP00QPH0b;/0
0?DZ003n1`00gW`004BR0000Gd@0014[00026@005c0006Lk06>/003UI`00o`800?4l002^_`0007/M
000/?P0011`000PR001<C@0>S`00d:L00?TK003k4@00eYH002:G0000E4`000XU00036`0093T007DX
09Rj003^AP00o`000>QN001_[`0006Xh000I<@000QT0010[001OA019Y000h7L00?h5003c<P00`<<0
001o5@00<40000@L00078@00Bdd03Xl00=6T003j6000na@00=>M000FTP0004m>00088P0011`002hn
001n6@2k`P00lc<00?h5003PN000AZ<0001MA@003bT0008I000L=000Kc80Q;D00>a?003o0000jET0
07>`0000JSP001Pa00026@004b`006=005ZY003TJ000o`400>m2002K^P0007DY000R=`000aX000dW
001JB00lX000gWd00?h6003c<P00^/80001m6`00:cd000<K000:9000E4`0:9T00=V<003m2`00mRP0
0<Nn0000PQ000391000470002280051>01fE003GU@00o0h00?LR003:^00008D:000f@`0011d000LQ
001>CP0IT`00eYL00?`?003g8@00b[L000252@00=T<000@M00088@00Cdh079D00=ND003l3@00mb@0
0<Rl0000PPl00351000470002B<0059=02NH003JR`00o@T00?D/0032a00007dI000Z?0000a/000/U
001HBP0jW`00gg/00?h4003a>@00YKd0001e9`008CL0008J000?:@00H4<0EjP00>EV003o0000k4`0
082c0000JcH001L`00026@005c0006/g082c003/C000o`000>EW001DY`0005m4000>:@000aX002@i
001i8@2e`@00m3000?d8003JRP0099P0001AC@00224000@M000jA@01RP00cjT00?XF003i7000c;80
00252@00<d8000@L00098`00ED/008d0=Id00=ml003o1000l3d009Rj0000LBl001/c00026@005Bh0
06Xh07jc003]B`00o`400>=^0017X`0005Y800078@00;Sl0088@0<Zh003h7P00na@00=2X0000R@00
03Q4000470002B<005E<03FM003ONP00o`<00>m1002=]`0006dd000G<0000QT001Xb001`;`2J^P00
lC/00?h5003LQ0009iT0001@CP001b4000DN0013B@0AT000eYH00?d;003e;@00]L40001g9@0083H0
008I000C;@00J3X0O[<00>e9003o0P00h7H003RN0000ED/000TR00047@00?DH02Hd00=BL003l3@00
mBX00;W20000N2<0020f00026@0052d006Xi08Be003_A000o`<00=im000]V`00055=00078@001Ah0
04M;01VD003IS@00oPL00?8h002J^P0006la000G<0000QT001`d001d:@2^_`00m2h00?d<003DV`00
28d0000kA@0011`000XT001HB@19Y000iFL00?l0003XF`00FZT0001MA@0032H000<K000d@P00R@40
dJ@00?`?003f:@00]l40001f9P007C@0008I000H<000L300XK`00?<b003m2P00eIP000Z>0000>TD0
00@L000:9000FdP0DjL00>MO003o0000iFL004JS0000EdX000TS00057@00@TT02_ooool1o`00007o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0?l006Dn000I<@000QX000/V001AC@0?T000cK00
0?HX003n1@00hfd006R]0000KC@0020f00036`002B8004Q;00290@37_P00lc800?l2003WH000Nk80
001b;@009CT000<K00078@00@DP008D90<C4003b>000o`400>QK0022]00007<[000W>`0011`000LQ
0010B000Q@X0a<@00?8g003o0@00j5d007jc0000LRd002Di00036`00224004A:00280`37_P00lc40
0?l3003UIP00Kjl0001]<`0083H000<J00099000Cdh02Xh00<ba003f9P00oPL00>1f001FZ00006Hm
000H<@000QT000dX001GBP0SU`00e9/00?XH003l4@00fHh003BM0000G4L0010Z00026@0052h00691
04RT003NOP00o@X00?LR003>[@003Hl0001?CP002B<000<K000R=`00LBl0O[<00>QK003o0000l3l0
0:no0000OQP0039100057@001Ql003Y500233P34a000lc@00?l3003TJ000IZ`0001Z>@006S80008J
000=9`00EdX0:9T00=ND003k4`00nQL00=BM000NU@0005A<000;9@000aX001le03f@6@3XF`00o`00
0>m1002W_@0007/N000]?P0011`000LQ0015BP02RP00bk@00?HU003m2@00gH00046Q0000GTD0014[
00026@005Rl006Hm05bY003SK@00o`<00?<e002n``00080C000d@P001Ad000HO000oA`00Q`@0bKT0
0?HX003n2000gWl0046Q0000GTD0010Z00026@00634006Pj06N]003VI@00o`400?0n002Z_P0007XO
000[?@000a`000PR001>CP0@T000dJ@00?TI003k4P00eIP001nF0000Dd`000XT00036`009CX007HV
09bk003_A000o`000>MP001/[P0006Ti000H<@000QT0014[001P@`1<Y@00hGD00?h4003c<`00_<80
001n5`00;cl000@L00088@00CDh04I000=:R003j5`00nQH00=>P000CT@0004i>00088P0011`002lo
001o5P2o``00lc400?h5003ONP00@Z80001LAP003bT0008J000M=@00L300R;H00>a=003o0000j5/0
072_0000JCT001L`00026@004bd006@o05jZ003UIP00o`400>m4002G^@0007@Z000Q=`000QX000dX
001KA`0oX@00gg/00?h5003c<`00]/40001l7000:S`00?<000<K000:9000ED/0:iX00=Z:003m2P00
mBT00<K00000PA800350000470002280055=01nF003GTP00o0d00?LT0039^P0008@<000d@P0011`0
00PR001?CP0KU000eYD00?`>003g8`00bKT000243000=48000@L00088P00D4h07iH00=RB003m3000
mRH00<Nn0000PA400310000470002B<005=<02ZI003KR000o@P00?@^002n``0007`K000Y?0000a/0
00/V001IB@0mX000ggT00?l4003a>`00XK`0001d:@0083H0008J000@:P00HD80FZT00>IT003o0000
k4l007bb0000JSP001H_00026@00630006`e08>d003]BP00o`400>AZ001@YP0005i5000>:0000aX0
02Dj001j7`2i`P00m2h00?d9003IS0008IL0001@CP001b4000DM000lAP03R`00d:H00?/E003h7@00
bk@000242`00<T4000@L000:9000ET/0>9h00=mi003o0`00l3l009Bi0000L30001Xb00026@005Rl0
06/g08:d003]B@00o`400>9`0014XP0005U800078000;cl008<>0<Zf003i7@00nQH00<nZ0000R080
03M3000470002B<005E;03RN003PN000o`800>m40029]P0006`e000F;`000QT001/c001a;P2M^`00
lST00?h6003KQP0099P0001?CP001b0000DN0015BP0DT@00ei@00?d:003d;`00/L00001f9P007cD0
008I000D;@00JCT0PK@00>i7003o0P00h7P003FM0000E4`000PR00047@00?TL02hh00=FJ003l3000
mB`00;G10000MbD001lf00026@0052h006/g08Rf003_@P00o`<00=f0000ZVP00051>000780001Ql0
04U<01bE003JRP00oPH00?4j002F^@0006hc000G<0000QT001dd001e:02b`000mB`00?`=003DW@00
1X`0000iA@0011`000XT001IB01<Y@00iFD00?l0003XG@00EjP0001LAP002bH000<K000e@`00RP00
dZ400?`>003e:`00/l00001e:00073@0008I000I<@00LBh0YKd00?@a003m2`00eIX000N<0000>D@0
00@L000;9@00G4L0EZP00>QL003o0000i6T004>R0000ET/000PR00057@00A4X02_ooool1o`00007o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0?l006@o000H<0000QX000`V001BC@0AT@00cZh0
0?HV003n1P00hVl006F/0000K3H001lf00036P002B<004Y<006:0038_000m3400?l2003VH`00Mk40
001a;`0093T000<K00088@00@dT008H70<G3003b=P00o`400>QN001n/`00078/000V>P000a/000LQ
0012B@00QPL0aL<00?8e003o0P00iel007^b0000LBh002@i00036`00228004I;00290@38_000m2l0
0?l3003TJ000Jjh0001/=@007cD000<J000:9000D4h03Hl00<f^003g9000oPP00>1h001BY`0006Dn
000G<0000QT000hX001GBP0VV000eIT00?XF003k4P00f900036L0000FdP0010Z00026@005Bh006=0
04bU003OO000o@T00?LT003=[`002Xh0001>CP002B<000<K000S>000LRd0PK@00>UH003o0000kd40
0:^n0000OAX0035000047@001Ql003a600242`35``00lc800?l3003TJ`00Hj/0001Y>P006S80008I
000>:000F4T0:iX00=NB003k4@00nQP00=>O000KU00005=<000;9@000aX0020f03nA6@3YF@00o`00
0>m4002S_00007XP000[?@0011`000LQ0017B`04R`00c;800?LT003m2P00g8<003fP0000GDH0010Z
00026@005c0006Ll05nZ003TJ`00o`<00?8g002j`P0007lE000b@@0011d000HP0011B000R080b[L0
0?HV003m2@00gH4003jP0000GDH0010Z00026@006C4006Ti06Z^003VHP00o`400?10002V_@0007TQ
000Z?0000a/000TR001?CP0CT@00dZ800?XH003k5000eIX001bE0000DTd000XT00036`009cX007LT
0:2l003_@P00o`400>IR001X[@0006Pj000G<0000QT0018/001Q@P1?YP00hG800?l4003b=@00^<40
001m6@00;Sh000@L00088P00CTh059400=>P003j5P00nQL00=:R000AT00004a=00088@0011`00350
00205033a000m2l00?h6003NO000?j40001LA`003RP0008J000N=@00LBl0S;L00>e;003o0000j5d0
06b^0000J3X001H_00026@0052d006Dn066[003VI000o`000>i6002C^@00078/000P=P000QX000hX
001LA`13XP00h7P00?h4003b=@00//00001j7P00:3/00?<000<K000;9@00ET/0;Y/00=^7003m2@00
mB/00<G20000P1@002lo000470002B<0059=02:G003HT000o@`00?HV0038_00008<>000c@@0011`0
00PR001@CP0NU@00ei<00?`=003g9@00b;/000233P00<T4000@L00088P00DDd08YL00=R?003m2`00
mRP00<K00000P1<002lo00036`002B@005A<02fK003KQP00oPP00?@`002j`P0007/M000X>`000aX0
00`V001JB010X@00h7H00?l3003`?@00WK/0001c:`007cD0008I000A:`00HT40GZX00>IQ003o0000
je4007Ra0000JCT001D_00026@00634006dd08Ne003^B000o`400>=/001=Y@0005e6000=9`000aX0
02Hj001k7P2m``00mBd00?d:003IS`007YH0001?CP001b4000DN000nA`06S000dJ@00?/C003h7`00
b[L000233@00<40000<K000:9000EdX0?:000>1g003o0P00kd40092h0000Kc8001Ta00026@005c00
06`f08Je003^A`00o`400>5b0011X@0005Q900078000<D0008@<0<^d003i6`00nQL00<j/0000Q`@0
03E2000470002R@005I:03^O003PMP00o`800>i60025]@0006/g000E;`000QT001`c001b;02Q_000
lSL00?h7003KR@008YL0001>CP001b0000DO0017B`0FT`00f9800?d9003d<000[Kl0001e:0007SD0
008I000E;P00JSP0QKD00>i4003o0P00ggX003:L0000Dd`000PR00057@00@4P03Xl00=JH003m2`00
m2h00;700000MRL001he00026@005Bh006`f08bg003`@000oP@00=f2000WV00004m>000680001Ql0
04]=01nF003KR000oPD00?4l002B^00006dd000F;`000QT001he001f9P2f`@00mBX00?`>003CX000
0h/0000gA00011`000XU001JB01?YP00iV<00?l0003WH000DjL0001KA`002bD000@L000g@`03R`00
dil00?`=003e;000[kl0001d:P006c<0008I000I<P00LRd0ZKh00?@_003m3000e9d000B;0000=d<0
00@L000;9@00GDH0FZT00>UJ003o0000hf`0042Q0000ED/000PR00057P00AT/02_ooool1o`00007o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0?l006=0000G<0000QT000`W001CC00DTP00cZ/0
0?LU003n1`00hW80066[0000JcL001he00036P002B<004a=00>;0039^@00m2l00?l3003UI@00Lk00
001`<0008cP000<K00088P00ADX008L40<K0003c=000o`800>MP001k/P00074^000T>@000a/000PQ
0013B@00Q`D0a/000?<d003o0P00iV8007Na0000L300028h00036`00228004Q<006:0039^P00m2d0
0?h4003TJ`00J:d0001[=P007CD000<J000:9000DDd049000<j/003g8`00o@T00=mk001?YP0006@o
000F;`000QT000hY001HB@0YV@00eYL00?XE003k4`00ei<002fK0000FTP000lY00026@005Rl006@o
04nV003ON@00oPP00?HU003</@0028d0001<C@002B<000<K000T>@00Lb`0QKD00>YF003o0000kd<0
0:Nm0000O1d002lo00047@001Ql003i700252@36`000m3000?l4003SK@00GjX0001X>`006C40008I
000>:000FDT0;Y/00=R@003l4000nAX00=:Q000HT`00059=000:90000aX0024g046C603YE`00o`00
0>i6002O^`0007TR000Z?00011`000PQ0019C007S000cJl00?LR003m2`00g8D003ZO0000G4H000lZ
00026@00634006Pk06>/003TJ000o`800?8i002f`@0007hG000a@00011d000LP0012B@00RP00bk@0
0?LU003m2P00g8@003^O0000G4L000lY00026@006S8006Xh06j_003WH000o`400>m2002R_00007PR
000X>`000a/000TS001@CP0FTP00dj000?XG003j5@00e9d001VD0000DDd000TS00036`00:3/007PR
0:Bm003`@000o`400>IU001U[00006Ll000F;`000QT0018/001R@@1CY`00hW000?l3003b=`00]<00
001l6`00;3h000@L00088P00Cdh05Y<00=BM003k5000nQP00=6U000>S`0004Y<00078@0011`00391
00214P35``00m2d00?h7003NO`00?:00001KB0003BP0008J000P=P00LRd0T;P00>e9003o0000if00
06R]0000Ic`001H_00026@005Bh006Hm06F/003VH@00o`000>i8002?^000074^000O=@000QX000hY
001MAP16X`00h7H00?l4003b=`00[[l0001i80009c/00?<000<K000;9@00EdX0<I`00=b5003n2000
mBd00<C40000OaH002hn00036`002B<005=<02FH003IS@00o@/00?HW0037_P00088@000a@00011`0
00PR001AC@0QU`00f9000?d<003f9P00akh000224000<D0000@L00098`00DTd09IP00=V=003m2P00
mBT00<G20000OaD002dn00036`002R@005E;032L003LP`00oPL00?<a002f`@0007XO000V>P000aX0
00`W001KA`14XP00hG@00?l2003`?`00VKX0001b;0007SD0008I000A:`00Hd00HJ/00>MO003o0000
je<007F`0000J3X001D^00026@006C8006hc08^f003^AP00o`400>=^0019Y00005a7000=9`000aX0
02Pk001l7031a000mB/00?d;003HT@006i@0001=CP001b0000DN0010B008S@00dZ400?/B003h8000
bKT000224000;cl000<K000;9@00F4T0?j400>5e003o0P00kd@008bg0000KC<001Pa00026@005c00
06dd08Zf003^A000o`800>5e000nX00005M:00078000<T4008D90<ba003i6P00nQP00<f_0000QPL0
03=2000470002R@005M:03jP003QL`00o`400>i80022]00006Xh000E;P000QT001dd001c:`2U_@00
lcD00?h7003JR`007iH0001=CP001R0000HO0019C00IU000f8l00?d9003c<P00ZKh0001d:P007C@0
008I000E;`00JcH0RKH00>m2003o0`00gWd002nK0000DTd000PQ00057P00@TT04I000=JE003m2P00
m2l00:fo0000MBT001dd00026@005Rl006de092h003`?P00oPD00=b5000TU`0004i>000680001Ql0
04e>02:G003LQ@00oPD00?0n002>]`0006`f000E;P000QT001lf001g902j`P00mRP00?`?003BXP00
0HX0000f@`0011`000/U001KA`1CY`00if000?l0003VHP00D:H0001JB0002RD000@L000hA006S000
e9d00?d<003d;P00Zkl0001c:`006S80008I000J<P00Lb/0[Kl00?D]003l3@00dil000::0000=D<0
00<K000<9P00GTD0GJX00>UH003o0000hfh003bP0000E4`000PQ00057P00B4`02_ooool1o`00007o
oooo000Nooooo`03o`000?oooooooooo00Oooooo04T00691000F;`000QT000dW001DC00GT`00cjT0
0?LS003n2000hG@005fZ0000JST001dd00036P002R@004i>00J<003:]`00mBd00?l4003UJ000Kjl0
001^<P008SL000<K00088P00Ad/008P20<Nn003c<P00o`800>IR001g/@00070_000S>0000a/000PR
0015BP00R0<0akh00?<b003o0P00iV@007>`0000Kc40024g00036`002B<004Y=00>;003:]`00mB`0
0?h5003SK@00I:`0001Z>00073@000<J000;9@00DDd04Y400<nZ003h8@00o@X00=im001;Y00006=0
000F;`000QT000lY001IB00/VP00ei@00080na@00?l0eYD002ZJ0000FDT000hY00026@005c0006Dn
05>W003PM`00oPL00?HW003;]0001H`0001:C000228000<K000U>P00M2X0RKH00>YD003o0000kTD0
0:>l0000NQl002hn000470001R0003m800261`37_P00m2l00?h4003RL000FjT0001W?0006300008I
000?:@00FTP0<Y`00=V=003l3`00nA/00=6T000ETP00055=000:90000aX0028h04:D5`3ZE@00o`00
0>i8002K^P0007LT000Y?0000a/000PR001;C@0:SP00cZd00?PP003m3000fhP003NN0000FdL000lY
00026@006C4006Tj06N]003UIP00o`800?4k002b`00007dI000_?`0011`000LP0014BP02R`00c;80
0?LS003m2`00fhH003NN0000FdP000hY00026@006c<006/f07:`003XGP00o`000>m4002N^`0007LT
000W>`000a/000TS001AC@0IT`00e9d00?XE003j5P00dil001JB0000D4h000TS00036`00:C`007TP
0:Rn003`?P00o`400>EW001QZ`0006Hm000F;`000QT001<]001S@01GZ000hfd00?l2003a>@00[kl0
001k7@00:cd000<K00098`00D4h06I@00=BK003k4`00nAX00=2W000;SP0004Q<00078@0011d003A2
00224036`@00mB`00?h8003MP@00>Il0001JB0003BL0008J000Q=`00Lb/0U;T00>i6003o0000iV80
06F/0000ISd001D^00026@005Bl006Ll06V]003WG`00o`000>e:002;]P00070_000N=@000QX000lY
001NA@19Y000hG<00?l3003a>@00Z[h0001h8P009SX000<J000;9P00F4X0=Id00=f2003n1`00m2l0
0<330000OQP002`n00036`002R@005A<02RI003JR`00o@X00?HY0036`@00084C000`@00011`000TS
001BC@0TV000fHh00?d;003f:000a/0000214P00;cl000@L00098`00Dd`0:9T00=Z:003m2@00mB/0
0<C40000OQL002`m00036`002R@005I;03>M003MP@00oPH00?<c002b`00007TQ000U>@000aX000dW
001LA`17X`00hW800?l2003_@@00UKT0001a;P007C@0008I000B;000I3l0IJ`00>QM003o0000jUD0
076_0000Ic`001@]00026@006S8006la08ng003_A00004L0o`800>9a0016X`0005]7000<9P000aX0
02Tl001m6@35a000mRT00?d<003GU00069<0001;C@001R0000DN0012B@0;SP00dil00?/A003g8P00
b;/000214P00;Ch000<K000;9@00FDT0@Z800>9b003o0P00kTH008Rf0000K3D001L`00026@006340
06hc08jg003_@P00o`800>1g000jW`0005I:00078000=48008H70<f_003j6@00nAX00<ba0000Q@T0
039100036`002RD005Q904:Q003RL@00o`400>e:001n/`0006Ti000D;@000QT001he001d:@2Y_P00
lc<00?d8003ISP0079@0001:C@0200067`1O001;C@0LU@00fHd00?h8003c=000YKd0001c:`0073<0
008I000F;`00K3D0SKL00?10003o1000gGl002bJ0000DDd000LQ00057P00A4X059800=NC003m2@00
lc400:Vn0000LbX001`c00026@005c0006hc09Bi003a?000oPD00=^7000QUP0004a=00067`001R00
04m>02FH003LP`00oP@00?10002:]P0006/g000D;P000QT0020f001h8P2n``00mRL00?`@003AY000
08T1000d@P000a/000/V001LAP1FZ000ieh00?l0003VI@00C:D0001IB0002R@000@L000jA@08S@00
eIX00?d;003d<000Ykh0001b;@006C80008I000K<`00M2T0/L000?D[003l3P00dZ8000290000=480
00<K000<9P00Gd@0HJ/00>YF003o0000hW4003VO0000Dd`000LQ00057P00BTd02_ooool1o`00007o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0?l00652000E;`000QT000dX001EB`0JU000d:L0
0?LQ003m2000h7L005ZY0000JCX001`c00036P002R@004m>00R=003;]@00mB/00?h4003TJP00K:h0
001]=00083H000<K00098`00BD`008T00<Rl003d<000o`<00>EU001c/00006la000R>0000a/000PR
0017B`00R@00b;`00?@`003o0`00iFL006n_0000KS<0020f00036P002B<004a=00J<003;]@00mBX0
0?h5003RL000H:/0001Y>@006c<0008J000;9@00DTd05I800=2W003h7`00o@/00=f00018X`000691
000E;P000QT0010Z001JB00_V`00f9800?/B003j5P00eIP002NI0000F4X000hX00026@00630006Hm
05JX003QM000oPH00?HY003:]P000X/00018B`00228000<K000W>P00MBP0SKL00>]A003o0000kTP0
09jk0000NB4002`n000470001b00045800271038_000mBd00?h5003RLP00F:P0001U?@005c00008I
000?:P00FdL0=Id00=Z;003l3P00nAd00=2V000BT@00051>000990000a/002<h04BE5P3[DP00o`00
0>e:002G^@0007HV000W>`000a/000PR001=CP0<S`00cjX00?PO003l3@00fXX003>M0000FTP000hX
00026@006S8006Xh06^^003VH`00o`400?4m002^_`0007`L000^?`0011`000LQ0016B`05S000cK00
0?LQ003m3000fXT003BM0000FTP000hX00026P0073<006`e07Ja003XF`00o`000>i6002J^P0007HV
000V>P000a/000XT001BC@0LU@00e9/00?/D003j6000dZ8001>A0000Cdh000PR00036`00:cd007/N
0:bo003a?000o`800>AY001MZP0006Dn000E;P000QT001@]001T?`1JZ@00i6/00?l2003a>`00Zkh0
001j7`00:C`000<K00098`00DDd079D00=FH003k4P00nA/00<nY0008S@0004I;0007800011d003E3
00233P37_`00mBX00?d9003LQ000=Id0001IB@0032L000<J000R=`00M2T0V;X00>m4003o0@00iVD0
066[0000ICh001@]00026@005Rl006Pj06f^003XG@00o`000>a<0027]@0006la000L=0000QT0010Z
001OA01=Y@00hW400?l3003a>`00Y[d0001g90009CT00?<000<J000<9P00FDT0>9h00=f0003n1P00
m3400;c20000OAX002/m00036`002R@005E;02bJ003KR000o@T00?D[0035``0007lE000^?`000a/0
00TS001CC00WV@00fX/00?d:003e:P00aL8000205@00;Sl000<K00099000E4`0:iX00=^8003m2000
m2d00<330000OAX002Xm00036`002bD005M:03JN003NOP00oPD00?8e002]_`0007PS000T>@000aX0
00hX001MAP1;Y000hVl00?l2003_@`00TKP0001`<00073<0008I000C;000ICh0JJd00>QJ003o0000
jEP006f^0000ISd001<]00026@006c<0070_09>h003_@@00o`800>5c0013XP0005Y8000<9P000a/0
02Xm001n5`36`P00mRL00?`=003FUP005Y800019C0001R0000DO0013B@0>S`00e9d00?`@003g8`00
akh000205000;3d000<K000<9P00FTP0AZ<00>9`003o0@00kTP008Be0000JcH001H_00026@006C80
06la09:h003`@000o`<00=mj000gWP0005E;00078000=D<008L40<j/003j5`00nA/00<^c0000Q0`0
031000036`002bD005U904FS003SKP00o`400>a<001j/P0006Pk000C;@000QT001le001e9`2^_`00
m3400?d9003HT0006I<00018C0001Ql000HP001=CP0OUP00fXX00?h7003b=P00XK`0001b;@006c<0
008I000G<000KC<0TKP00?0n003n1000gH8002RI0000D4h000LP00057P00AT/05i<00=R@003m2@00
lc<00:Fm0000LR`001/c00026@00630006lb09Rj003a>P00oPH00=Z:000MU@0004Y<00067`001b00
051>02RI003MP000o`<00>m20026]@0006Xh000C;@000QT0024g001j8033a000mbD00?/B003@Y`00
08P3000c@@000a/000`V001MA@1JZ@00j5`00?l0003UI`00BJ@0001HB@002R@000@L000lAP0;SP00
eYP00?d:003c<P00Xkd0001a;`006340008I000L=000MBL0]/400?DY003l3`00dJ@000280P00<T40
00<K000=9`00H4<0IJ`00>YC003o0@00hG<003JN0000DTd000LQ00067`00C4d02_ooool1o`00007o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0?l00613000D;P000QT000hX001FB`0MU@00dJ@0
0?PO003m2@00ggT005JX0000Ic/001/c00026P002bD0051>00^>003</P00mRT00?h5003SK@00J:d0
001/=@007cH000<J00098`00Bdd00h/00<Vi003d;P00o`<00>EW001_[`0006hc000Q=`000a/000TS
001:C002RP00bKT00?@^003o1000i6T006^^0000KCD001lf00036P002B@004i>00V=003</`00mRP0
0?h6003RLP00G:X0001X>P006S80008J000<9P00Dd`069<00=6U003h7P00o@`00=b30014XP000652
000D;P000QT0010Z001KA`0cW@00f8l00?/A003j5`00eIX002BG0000EdX000dX00026@006C4006Ll
05ZY003RLP00oPD00?D[0039^@0008T00016BP00224000<L000X>`00MRH0TKP00>a?003o0000kDX0
09Zj0000N2<002/m000470001b4004=900290@39^@00mB/00?h6003QM@00E:L0001T?`005Rl0008I
000@:P00G4H0>9h00=^8003l3@00n1h00<nY000?T00004m>00098`000a/002Di04NF5@3[D000o`00
0>a<002B^00007DX000V>P000a/000TS001?CP0?T000d:P00?TM003l3P00fHd0032L0000FDT000hX
00026P006c<006/g06j_003WH@00o`400?0o002Z_P0007/N000/?P0011`000LQ0019C008S@00cZd0
0?PP003l3@00fX/0036L0000FDT000dW00026P007C@006hc07Zb003YF@00o`000>e8002E^@0007DX
000T>@000a/000XT001CC00OUP00eIP00?/C003i6@00dJ@0012@0000CTh000PR00047000;3h007`L
0;30003a>P00o`800>=/001IZ@0006@o000D;@000QT001D^001U?P1NZP00i6P00?l2003`?P00Ykd0
001i8@00:3/000<K000:9000DTd089H00=JF003l4000nAd00<j/0006S00004A:000680001Ad003M3
00242`38_000mRP00?d:003KQ`00<Y`0001HBP0032H000<J000S>000MBP0W;/00>m2003o0@00iFL0
05fZ0000I3l001<]00026@005c0006Ti072_003XFP00o`000>a?0023]00006hb000K<`000QT0010Z
001P@`1AYP00hfh00?l2003`?P00X[`0001f9P008cP005T000<J000<9`00FTP0>il00=im003n1P00
lc<00;O10000O1d002Tl00036`002RD005I;02nK003KQP00o@P00?D]0033a00007hG000]?P000a/0
00XT001DC00[VP00fhT00?d9003e;000a<@0001n5`00;3h000<K000:9000ED/0;Y/00=b5003n2000
m2l00;c20000O1`002Tl00036`002bD005Q903ZO003OO000oPD00?8g002Y_P0007LU000S>0000QX0
00hX001NA@1>Y@00hfd00?l1003^A@00SKL0001_<@006c<0008I000C;@00ISd0KJh00>UH003o0000
jEX006V]0000ICh0018/00026@0073@0074^09Ni003`?`00o`<00>1f000oX@0005U9000;9@000a/0
02`m001o5@37_`00mRD00?`>003EV@004i400017B`0200067`2H0016BP0AT000eIX00?`>003f9@00
a/00001o5P00:Sd000<K000<9P00FdL0BJ@00>=]003o0@00kDX0082d0000JSP001H_00026@006S80
070`09Ji003`?P00o`@00=il000cW@0005A<00078000=d<008P20<nZ003j5P00nAd00<Zf0000P`h0
02lo00036`002bH005Y804VT003SK000o`000>a?001f/@0006Ll000B;0000QT0020f001g9@2b`000
m2l00?d:003GT`005I800016B`001Al000LP001?CP0RU`00fhL00?h6003b>000WK/0001a;`006S80
008I000H<@00Kc80UKT00?4l003n1@00g8D002FH0000Cdh000LP00067`00B4`06Y@00=V>003n2000
lSD00:6l0000LBh001Xb00026@006C40070`09bk003b=`00oPL00=V<000JU00004Q;00057P001b00
055=02bJ003NOP00o`<00>i40022]00006Tj000C;0000QT002<h001k7P35``00mb<00?/C003?Z@00
08H6000a@0000a/000`W001NA@1NZP00jET00?l0003TJ@00AJ<0001GBP002B<000@M000nA`0>S`00
eYD00?d9003c=000Wk/0001`<0005c00008I000M=@00MRH0^/800?HW003k4@00d:L000271@00<D00
00<K000=:000HD80JJd00>]A003o0@00h7H003:L0000DDd000LP00067`00CTh:ooooo`7o00000Ooo
ool001kooooo00?o0000ooooooooool01oooool0o`00Gd@001@]00026@003bT005M:022F003BX@00
n1h00?d:003OO000DZL0001V?0006S80008J000;9@00DDd03Xl00<f`003f9`00oPH00>9_001T[000
06/g000N=@000aX000TS001=CP05S000b[L00?D/003n1000i6X006^^0000KC@0020f00036P002B<0
04a=00B;003:]`00mB`00?h4003SK000Ijd0001/=P007SD000<J000:9000Cdh038h00<f`003f9P00
oPL00>5e001IZ00006Ll000I<P000QX000`W001DC00LU000dZ800?TL003l3@00g8D0042Q0000H4<0
01<]00026@004B/005e603JN003IS000o1000?XI003DW@008IH0001FB`003BL0008J000J<P00J3/0
GZX00>9_003n1@00mBd00<Rk0000R08004=900078@0011`002Tl001g9@2E^@00k4d00?l0003/C000
U[T0001g9000:C`000@L00078@00ADX008X00<Zg003f:@00oPL00>1g001@YP0006=0000E;P000QT0
014[001MAP0lX000g8D00?d<003h8000cZ/000b?0000CTh000TS00036`009SX0BILD0>a>003o0000
k4l008jg0000M2T002Di00036`002B<0051>01:A003AY@00nA/00?`?003HS`00;I/0001HB@003BL0
008J000L<`00K3D0L[000>MN003o0000kd400:Fm0000NR0002/m00047000228004]=00^>003?Z`00
n1h00?`>003ISP00;I/0001HBP003BL0008J000N=@00Kc80O[<00>YF003o0000kD/0096h0000M2X0
02<h00036P002bD005A<02:G003FUP00na400?TK003@Y`003Hl0001;C@00224000@L000^?`00OAX0
]L400?8g003o0`00hfl005FX0000Hd0001<]00026@005Rl006Hm06:[003UIP00o`400?10002S_000
07PS000W>P000a/000XT001CC00SU`00ei<00?`?003h7P00cJh000>;0000@TT000HO00057P00>D@0
08D90<Vj003f9P00o@/00=Z9000^V`0005I:000;9P000aX002@i001f9P2P_000l4000?l1003TJP00
FJT0001S@0004R`0008I000H<@00JSP0M;000>UH003o0000je4007nc0000KC@001Xb00026@004B/0
065205BW003SK000o`800?10002N^`0007DX000R>000F@000aX000dW001KB00oX@00ggX00?h5003c
=@00/l00001j7`00:3/000<K000;9@00EdX0<Yd00=b3003n1`00m2l00;k30000OAT002/m00036`00
2R@005E;02jK003KQP00oPP00?@^0030``0007dI000[?@000a/000XU001FB`0bW000g8<00?h7003c
<@00]l40001k7P009c/000<J000<9P00FDT0?J000=mi003n1000lCX00:Fm0000MRL0024g00026P00
3bT005m405:W003TJP00o`400>i80029]P0006hc000J<P000QT001@^001W>`1a[`00jUD00?l0003X
G@00IJ`0001T?`004R`0008I000M=@00LR`0Vk/00?0m003o0`00h7T003^O0000F4X000/U00036`00
;Ch0084C0<Rm003g8`00o0l00=BK000@T00004E:008000HO09P004Q;01BB003FU`00o0d00?HW0035
`P0007hI000Y?0000aX000dW001LAP1=Y@00i6X00?l0003/C@00O;80001Y>@005Bh0008I000K<`00
LBh0V[X00?4l003n1000gWl0032L0000Dd`000HP000iA000RP00d:L00?/D003h7`00bKP000224000
;Ch000<K000<9P00FdL0C:D00>AY003o0000je4007:`0000ISd0018/00026@008CL007PS0;K1003e
;@00o@/00=JE000BT@0004A:00057P001b00051>02JH003LQ@00oPD00?4k002H^P0006la000I<@00
0QT001Ta001`<02I^P00lCX00?h6003KQ`008YL0001>CP001R0000HO001:C00MU@00fX/00?h7003b
=`00WK/0001`<0006C40008I000J<P00LBh0X;`00?8e003n2000f8l001NC0000ATX000DN00078@00
DTd0;i/00=mk003o0P00kTL007jc0000J3/0018/00026P0093T007`L0<K1003g8@00na@00<j/0000
Q@T002lo00036`003BL005m406:[003YE`00o`000>=/0012X@0005I:00098`0011d00418016@003G
TP00o@P00?8f002K^P0006hb000F;`000QT001le001h902n``00mRH00?/B003?Z@0008H8000_?`00
0a/000hX001R@@1][P00k4h00?l1003PN000;i/0001@CP001R0000HO001?CP[ooooo0Ol00001oooo
o`007_ooool00ol0003oooooooooo`07ooooo`3o001NA@004bd0008I000?:@00F4T099L00=>O003i
7000o@/00=in001>Y@0006Dn000I<@000QX000`V001BC@0AT@00cZd00?HU003n1`00hW80062[0000
JSP001dd00036P002R@004m>00R=003;]000mBX00?h5003SK000Ijd0001/=P007SD000<J00099000
CTh01hd00<^d003e:P00oPD00>=^001S[00006Xg000M=0000aX000XU001@C@0?T000cZh00?LT003n
2000h7L005FW0000ISd001Pa00026@003BL005E;01nF003CW`00nAX00?`>003KR000?J00001OA000
4R`0008I000B;000GTD0>Yl00=Z:003l3`00nAX00=>P000MU@0005E;000<9P000QX001/c001Y>@1R
Z`00hfd00?h4003d;`00akd000271@00@DT000LP00047000:cd007PS09Zj003]BP00o`000>a?002B
^00007HV000X>`000a/000PR0017B`03R`00bk@00?HW003n1`00ggX004bU0000HT4001@^00026@00
4B/005i5042Q003LP`00o@/00?LR003=[P002Xh0001<C@00228000<K000W>`1;V1<0kD/00?l0003[
D@00R[H0001c:`008cP000<K000:9000DDd05I800=:S003i6P00na400=NB000YV@0005M:000=9`00
0QX001dd001]=01g/@00j5`00?l0003_@`00XK`0001i8P00:C`000<K00088P00CDh03Xl00=2X003i
7000o0l00=RA000ZVP0005M:000<9P000QX001lf001`<022]000jU@00?l0003/C@00SKL0001c;000
8SL000<J000;9@00ED/09YP00=NC003l4000nA`00<nY000:SP0004U<00078@0011`002lo001n602i
`P00lSD00?l3003RL@00DZH0001R@@004R`0008I000G<000Ic/0IZ`00>IS003o0@00kd8009jk0000
MbD002Dj00036`002RD005A<02JH003HT@00o0h00?PP003</@0008X00010B0001Ql000DN000kA@00
QPH0b[L00?LT003m3000fH`002^J0000ED/000/U00036`009SX007LT0:Bm003`?@00o`800>=/001E
Z0000691000B;0000QT001Ta001[=P1i/P00jUD00?l0003ZE000Nk80001/=P006C80008I000B;000
HT40F:P00>AY003o0@00kd8009Vj0000M2X0024g002U00026P003RP005a704>R003PN000oP@00?8g
002^_`0007TQ000W>P000aX000/V001HBP0fWP00gH400?h6003d<@00^/80001l7000:S`000<K000;
9@00ET/0<Y`00=b3003n1`00m3000;_20000O1/002Tl00036`002bD005M:03FM003MP000oPH00?<c
002c`00007XP000V>P000aX000`W001JB011X@00h7L00?l3003a?000XK`0001d:@0083H0008J000?
:P00H4<0EZP00>EW003o0000kDX008Fe0000KC@001Ta00026@005Bh006Pj07Fa003[D`00o`000>MO
001QZ`0006=0000A:`000QT001le001d:P2P_000lC/00?h4003ON`00>9h0001GBP002R@000<K000_
?`00PQ00bK/00?LR003l4@00dih000f?0000@dT000DN00068000BT`05i<00=NE003m3000mRT00<C4
0000O1/002Pk00036P003BL005e5056V003UJ000o`000>a?001h/@0006Pj000D;@000QT001`d001b
;02N^`00lCX00?h5003MPP00;I/0001BC@001R0003]500>;003AY@00na<00?PP0038^`00080C000/
?@000a/000`W001LAP1@YP00iFL00?l0003ZD`00KZl0001U?P004B/0008J000R>000NB40^l800?D[
003m3000eIP000n@0000@TT000DN00078@00DDd0:IT00=f2003n1000l3d009Bi0000KS8001Pa0002
6@006S80074_09jk003b>000oPL00=Z:000OUP0004a=008000HO04`004a=022F003KR000oPH00?4j
002H^P0006la000H<@000QT001/c001b;@2U_@00lc<00?d9003HT@0059800014BP001Ah000PQ001C
C@0bW@00h7T00?l2003]B@00N[80001V?0004B/0008J000U>@00OAX0akh00?PP003j5P00cJl00024
2`00;Sl000<K000>:000HD<0IZ`00>YD003o0000hfl003jP0000ED/000PR00057@00@TT059800=R@
003n1`00lSP009Ji0000KC@001H_00026@0083H007TR0<?4003g9000na<00<j/0000Q@X002dn0003
6P003RT006=0076_003/C000o`800=mk000[VP0004m>00067`001R00051=2_ooool1o`00007ooooo
000Nooooo`03o`000?oooooooooo00Oooooo0?l005a6000B;0000QT0010Z001IB00WV@00e9`00?TJ
003l3@00gH4004ZT0000I3l001P`00026@0032H005=<01BB003?Z`00mb<00?h7003QM000G:T0001Y
>@0073<000<J000:9000D4h02hh00<bb003f:000oPD00>9_001SZ`0006/g000M=0000aX000XT001?
CP0:SP00c;800?HX003n1P00hW4005nZ0000JCT001`c00026P002bD0055=01:A003?Z`00mb800?d9
003ONP00DJH0001U?P005c00008I000=:000EdX08YL00=BM003i6@00o0l00=Z;000iW`0005i5000B
;0000QT0018/001OA00mX000fhL00?`=003i7000dZ8001ZD0000E4`000`V00026P0073<006Xh06J/
003TJP00o`<00?@a0036`00008H7000oB0001b0000@L000/?P00NB00W[/00>i8003o0000je4008fg
0000MBP002Hj00036`00228004Y<00J<003</P00mbD00?d8003NO@00BJ@0001Q@P004bd0008I000B
;000Gd@0@j800=f0003m2@00mb@00<ba0007S00004U<00088P000a/002Tl04fI4P3]B@00o`000>YD
0026]@00078]000R>0000aX000XT001BC@0IT`00dj000?XH003k4P00eYD002JH0000ET/000`V0002
6P007SD006hb07^b003YF@00o`000>i6002M^`0007LT000X>`000a/000TS001?CP0AT000dJD00?TK
003k4@00ei<002JH0000ED/000`V00036P0083H0074^08Je003[D@00o`000>]@0029]P00078^000Q
=`000aX000`V001FB`0YV@00f9000?`?003h7P00cZ`000R=0000Ad/000LQ00047@00<D0007lE0;k3
003c<`00oP@00>5d001>Y@000653000B:`000QT001L`001X>P1Z[@00if400?l0003^A000V[X0001e
9`0093T000<J000;9@00ED/0:IT00=V>003l3@00mb800<^d0000R08003i700067`001Ah003e60028
0`3;]@00mb800?`=003IS`00:9T0001DC0002R@000<K000W>`00NB80ZKh00?4k003o0P00hfl0056V
0000HD<0014[00026@006S8006de07fc003[D`00o`000>YF001g/@0006/g000H<@000QT001</001S
@01LZP00iFL00?l1003^A000UKT0001c;00083H00?<0008J000>:000GDH0AZ<00>5e003o0`00lCT0
0:Zn0000N2<002Dj00036P0032H005U903ZO003NOP00oPH00?<c002e`@0007/N000X>`000a/000/U
001GBP0eW@00gH400?h6003c<P00]l40001k7P00:3/000<K000;9P00F4T0>Il00=im003n1@00lSD0
0:jo0000N28002Di00036P003BL005]704FR003QM000o`<00?0n002L^`0007<[000O=P000QX0010Z
001Q@P1JZ@00iFD00?l0003/C@00PK@0001/=P006300008I000F;`00JCT0NK800>]A003o0000iV80
05fZ0000HT40010Z00026P0083H007DX0:Bm003b>@00oPD00=in000dW@0005I;000:90000a`00350
00233P3:^000n2000?/B003BX@002Xh00011B0001Ah000LP001<C@0JU000ei800?d;003e:`00_l<0
001k7@009SX000<J000>:000GT@0EJL00>EU003o0000je4007B`0000Ic`001<]00026@007CD007<[
0:>l003b=`00oPH00=b4000YV@00055=00077`00?DH01X`00=:R003k4@00mb800<Nm0000OaD002Xl
00036P003BL005i505BW003VI000o`000>YF001Z[@0006=0000@:P000QX002@i001j7`2o``00mRT0
0?`=003DV`0038l00010B0001Ah000PQ001BC@0/VP00gGl00?l4003`?`00T;P0001]=0005c00008I
000K<`00LRd0X[`00?8e003n1`00fHd001^D0000BD`000HO00068000CTh08iL00=^6003n1@00lC`0
09Bi0000KS<001L`00026@0073<007<[0:Vn003c<@00o@X00=ND000AT@00045900057@00228005A<
03JN003PMP00o`400>e;001f/@0006Dn000@:`000QX002Hj001n6038_000n1h00?XG003</@0008<>
000/?P000aX000hX001R@@1Z[@00je800?l0003RL@00>Yl0001DC000228000DN0014BP0GT`00fHd0
0?h6003a>P00T[P0001/=@005Bh0008I000Q=`00NQl0aL<00?LR003j5@00cJh000233@00;3d000<J
000?:@00I3l0MK400>e:003o0P00gWh002RI0000CTh000HO00078000DDd02_ooool1o`00007ooooo
000Nooooo`03o`000?oooooooooo00Oooooo0?l005]7000A:`000QT0014[001JB00ZVP00eIT00?XI
003l3P00g8@004NS0000Hd0001L`00026@003BL005A<01RC003@Z000mb800?d8003PM`00F:P0001X
>`006c<0008J000;9@00DDd03Xl00<f_003f9P00oPH00>9b001OZP0006Ti000L=0000aX000XU001@
CP0=S`00cJl00?HV003n1`00hG@005^Y0000J3X001/c00026P002bH0059=01FB003@Z000n2400?d:
003NO@00CJD0001T?`005c00008I000>:000F4X09IP00=FJ003j5`00o1400=V=000eWP0005a6000A
:`000QT001<]001P@`11X@00g8@00?d<003h7@00dJD001NC0000Ddd000/U00026P007C@006/f06Z^
003UI`00o`<00?<c0035`P0008D:000mA`001R0000@M000^?`00Nah0Xk`00>i5003o0000jU@008Vf
0000M2X002Di00036`002B8004a=00V=003=[`00mb<00?d9003MO`00AJ80001P@`004b`0008I000C
;@00HD<0Aj<00=im003m2000mRD00<^c0004R`0004M;00088@0011`002Xm04nJ4@3^AP00o`000>YF
0021]000074_000Q=`000aX000/U001CC00LU@00e9d00?XG003k4`00eYP002>G0000ED/000/V0003
6P007cH0070`07nc003YE`00o`000>e8002H^P0007HV000W>P000a/000TS001@CP0DTP00dZ<00?TI
003k4P00eYH002>G0000E4`000/U00036P008CL0078]08^f003/C`00o`000>]B0024]@00070_000O
=P000aX000`V001GBP0/VP00fHd00?`=003h8000cJl000F;0000ADX000LP00047@00<d40080C0<;4
003d<@00oPD00>1g001:Y00005m4000A:`000QT001Pa001Z>@1^[`00ieh00?l0003^A`00U[T0001d
:@008cP000<J000<9P00ETX0;I/00=Z;003m3000mb@00<Zf0000Q`D003a600057P001Ql003m70029
0@3</P00n2400?`>003HT@0099P0001CC0002R@000<K000X?000NR00[Kl00?4i003o0`00hW8004jU
0000Gd@0010Z00026@006c<006hc086d003[D000o`000>UI001c/00006Xi000G<0000QT001<]001T
?`1PZ`00iV@00?l0003^A`00T;P0001a;P007SD00?<0008J000?:@00GTD0BZ@00>5b003o0`00lC/0
0:Fm0000MbD002@i00036P003BL005Y803fP003ON`00oPD00?8e002a`00007XP000W>P000aX000`V
001HB@0iW`00gWh00?h5003c=000//00001j80009cX000<J000<9P00FDT0?:000=mj003n1000lSP0
0:Zn0000Mb@002<h00036P003BP005a604RT003RL@00o`800?10002H^P00078]000N=@000QT0014[
001R@@1NZP00iV800?l0003/C`00O;<0001Z=`005c00008I000G<000JcL0OK<00>a>003o0000iV@0
05VY0000HD<000lZ00026P008CL007HV0:Vn003b=P00oPD00=f1000aW00005E;00098`0011`00391
00242`3;]@00n1h00?/C003AX`001h`0000oA`001Ah000LP001>CP0MU@00f8l00?d:003e;@00^l80
001j7`009CT000<J000>:@00H4<0FJT00>IS003o0000jU@006n_0000ISd0018/00026@007cD007DY
0:Nn003b=@00oPL00=^7000VV000051=00067`00?dL02Hd00=>O003l4000mb@00<K00000OQP002Tl
00036P003RP005m405RX003VH@00o`000>UI001U[0000691000@:P000QX002Di001k7@34a000mRL0
0?`?003DW@002Hd0000nA`001Ad000PR001CC00`W000gWd00?l3003_@@00RkH0001/=@005Rl0008I
000L=000Lb/0Ykd00?<c003m2000f8l001RC0000Ad/000DO00078000D4h09iT00=b3003n1000l3h0
08nh0000KCD001H_00026@007C@007@Y0:jo003d;`00o@/00=JG000>S`0003m800047@00228005E;
03ZO003QL`00o`400>a>001a/00006@o000@:P000aX002Pk001o5@39^@00nA`00?XI003;]000088@
000[?@000aX000lY001S@01^[`00k4l00?l1003QM000=ih0001CC000224000DN0016B`0JU000fXX0
0?h6003`?@00S[L0001[=`0052d0008I000R>000Nad0a/000?PP003j5P00c;4000223`00:Sd000<J
000@:P00ICh0NK800>i7003o0`00gH0002FH0000C4d000HO00078@00Ddd02_ooool1o`00007ooooo
000Nooooo`03o`000?oooooooooo00Oooooo08P005Y8000A:`000QT0014[001LA`0^V`00eYL00?XG
003l3`00fhL004>R0000HT4001H_00026@003BP005E;01^D003AY@00n2000?d9003ONP00E:L0001W
?0006S80008J000;9P00DTd04I400<j/003g9000oPL00>5e001KZ@0006Pj000K<`000QX000/U001A
C@0@T000cZd00?LT003n2000h7H005NX0000Ic`001Xb00026P0032H005A<01RC003AYP00n1l00?d;
003MP000BJ@0001S@@005Rl0008I000?:@00FDT0:IT00=JG003j5P00na800=R@000bW00005]7000@
:P000QT001@^001Q@P15X`00gH400?d;003h7`00d:P001BB0000DDd000/U00036P007SD006de06j_
003VI@00o`800?8e0033a00008<=000kAP001Ql000@M000`@000O1`0Ykd00>m3003o0000jUH008Fe
0000LR`002@i00036`002B<004i>00b?003>[@00mb400?d;003MPP00@J40001OA0004R`0008I000D
;@00HT40Bj@00=mj003n2000mRL00<Zf0001RP0004E:00078@0011`002`m056K403_A000o`000>UI
001m/`0006la000P=P000aX000/U001DC00OUP00eIX00P3j5@00o`3EVP007iH0001DC0002bD000<J
000Q=`00LBl0Pk@00>YD003o0000kD/009Bi0000MBP002Di00036`002B@0055=01NC003CX000nQL0
0?/C003EV@007iH0001CC0002bD000<J000S>000Lb/0SkL00>a<003o0000jUD0082c0000Kc4001he
00026P003BL005Q9032L003JR`00o@`00?LR003</@000XX00012B@001R0000@M000d@P00PQ00aL<0
0?@_003n1P00ggT004JS0000GTD0010Z00026@006C8006/g07:`003XF`00o`000>e9002A^00007<[
000Q=`000aX000`V001HBP0aW000fhP00?d:003f9P00bKT000261`00>TD000DN00067`00@DP00HX0
0<f_003h7`00o0l00=ND000QUP00059=00098`000a/002Xl001k7@2b`000lSL00?l4003QM000BZ@0
001NA@003bX0008I000L=000Kc40QKD00>a>003o0000j5/006j_0000J3X001H_00026@0052h006Hm
06F/003WH@00o`000>e9002<]`00070_000M=0000QT0010Z001OA01>Y@00hW000?l2003`?P00XK`0
001f9`008SP000<J000=9`00FdL0@J400>1h003n1000lSL00:bo0000N28002Dj00036P0032H005U8
03fP003ON`00oPD00?8f002^_`0007TR000U>@000aX000`W001JB010X@00h7P00?l4003a>P00YKd0
001f9P008SP0008J000>:000GTD0C:D00>=^003o0P00kd<009>h0000LBh001dd00026@004R/006=0
06:[003WG`00o`000>]B001h/@0006Ti000F;`000QT001P`001/=P22]000kD/00?l0003UI`00EJL0
001OA0003bT0008J000R>000Mb@0[Kl00?<d003n1P00g8@002fK0000E4`000TS00047000=48008D9
0<bc003i7000nQD00=2V0004R`0003e600057@001b4004m>026F003IS000o@T00?@_002f`@0007TQ
000S>0000QX000lY001Q@P1MZP00if000?l0003ZE`00Jjh0001U?P004B/0008I000P=P00MRL0[;l0
0?<c003n1`00fXX002:G0000Cdh000HP0011B00<SP00e9d00?`?003f9P00aL80001m6P009c/000<J
000>:000H4<0G:X00>MO003o0000j5/0066[0000HD8000lY00036P00J@009SX007dK0<G2003g9@00
o1000=>P0006S00003a600047@00228005A<03BM003ONP00o`<00>m40027]@0006/g000E;P000QT0
01dd001d:@2[_P00m3400?d9003GTP005I800015BP001Ah000LQ001AC@0ZVP00gH000?l4003_@@00
RkH0001[=P005Bh0008I000N=@00MRL0//000?D]003m3000eIX000^>0000?DL000@M00098`00ET/0
?J000>9`003o0@00je4006f^0000Hd0000lY00036P00:C`0084C0<Zf003i6`00nAX00<Zf0000P1<0
02Tl00036P003bX006@o07:`003/C@00o`400>1g000cW@00059=00078@001Ah004Q<01jE003KQ`00
oPD00?0o0029]P0006Xh000C;@000QT002@i001l6`37_P00n1h00?XH003;]000084B000Y?0000aX0
014[001V?01n/`00kTD00?l3003LP`008IH0001:C0001Ah000LQ001DC00:ooooo`7o00000Oooool0
01kooooo00?o0000ooooooooool01oooool0o`00FDT0010Z00026@004R`005e603:L003GU000nQH0
0?`@003JRP00?j40001Q@P005Bh0008I000>:000ETX07YD00=:R003h7P00o@X00=im001@YP0006Dn
000I<@000QX000`V001CC00ETP00cjX00?LR003m2000h7L005NX0000Ic`001Xb00026P002bH0059=
01BB003?ZP00mb800?d9003ON@00DjL0001V?@006340008I000=9`00ED/06i@00=:S003i7@00o@`0
0=f20015X`000652000E;P000QT000lZ001JB00]V`00ei@00?/D003k4`00ei<002jK0000FTP000lZ
00026@005Bh0069104VT003NO`00o@X00?LQ003?ZP004900001@C@002R@000<J000O=P00KS<0Lk00
0>IR003o0P00lSP00;o30000PPl003U500067`001Ad00351001m6P2/_`00kd400?l0003YF@00P;@0
001a;P008SP000<K00098`00Cdh03i000<nZ003h7`00o@`00=b5000mX00005i5000A:`000QT001D^
001S@01?YP00h7P00?h7003e:@00bKP000290@00@dT000LP00047000;Ch0E9`?0>m1003o0000j5`0
07Vb0000KS8001he00036P0032H005E;02>G003EV000na@00?XG003DW@0079D0001CC@002RD000<J
000R=`00LRd0R;H00>]A003o0000k4d008ng0000M2X002@i00036`002R@0059=01^D003DW@00nQH0
0?XE003DW00079D0001BC@002R@000<K000T>@00MBT0U;T00>e:003o0000jEL007^b0000KS<001dd
00026P003BP005U903BM003KR000o@/00?LT003;]00008T00010B0001Ql000DM000f@`00P`h0a/40
0?D]003n1`00gW`004:R0000GDH000lZ00026@006c<006`e07Na003YF@00o`000>a<002<]`00078]
000P=P000QX000dW001IB@0dW@00g8D00?d9003f:000b;`000252P00>4@000DN00068000@dT018/0
0<j]003i7@00na400=JG000MU@00055=00098`000a/002`m001l6`2g`@00lc@00?h4003PM`00AZ<0
001MAP003bT0008J000M=@00L300R[H00>e;003o0000ieh006Z^0000Ic/001H_00026@005Bh006Ll
06V]003WGP00o`000>a<0027]@0006la000L=000l`000QT0010Z001P@`1BY`00hfd00?l2003`@000
W;/0001d:@008CL0008J000>:000G4H0AJ<00>5e003o0`00lCX00:Rn0000Mb@002@i00036P003BL0
05]8042Q003PN000oP@00?8h002Y_P0007LT000T>@000aX000dW001KA`14XP00hGD00?l3003a?000
XK`0001e:0008CL0008J000?:@00Gd@0D:H00>=/003o0@00kTD008ng0000L30001/c00026@004R`0
06Dn06J/003XG@00o`000>YD001d/00006Pj000E;P000QT001Ta001]=026]@00kDT00?l1003TJP00
DJH0001NA@003RP000<J000T>@00N280//000?<b003n1`00fhH002VI0000DTd000PR00047000=T<0
08L60<f`003i6`00nQH00<nY0001RP0003]500047@002240051=02BH003JRP00oPP00?<a002a`000
07PT000R>0000QX0010Z001R@@1QZ`00j5d00?l0003YF@00Ijd0001S@0004B/0008J000Q=`00MbD0
/L000?@a003m2000fHd001nF0000CTh000HO0013B@0?T000eIX00?`>003f:000`l@0001l70009SX0
00<J000?:@00HD80H:/00>QL003o0000ieh005fZ0000H4<000hX00036P00:3/007hH0<K0003g8`00
na400=:S0003R`0003Y500047@002B<005E;03NN003PM`00o`800>i60022]00006Xh000D;P000QT0
01he001f9`2``000m2l00?d:003FU@004Y400013B@001Ah000LQ001BC@0^V`00gWd00?l3003_@`00
QkD0001Z>00052h0008I000O=P00MbD0]l400?D[003l3@00e9d000R=0000>dH000@M00098`00EdX0
@J400>=^003o0000jU<006V]0000HT4000hY00036P00:cd0088@0<^d003j6@00nA`00<Vi0000OaD0
02Pk00026P0042X006Dn07Ja003]BP00o`800=mj000_V`00055=000780001Ql004]=026G003LQ@00
oP@00>m20025]@0006Tj000B;0000QX002Di001n6@38^`00nAd00?TI003:]P00080D000W>`000QX0
014[001W>`22]000kd800?h4003KQP007YD00017B`001Ah000PR001EB`0:ooooo`7o00000Oooool0
01kooooo0ol00007ooooo`1I001HB@003bT0008I000C;@00GTD0=Ih00=RA003k5000na800=V<000k
W`0005m4000D;P000QT000lY001GBP0RU`00dj000?TL003m3000gH0004bU0000I3l001P`00026@00
32L005A<01RC003@Y`00n2000?d9003ONP00DZL0001V?@006C40008J000<9P00E4`05i<00=2W003h
8000o@X00=il001?YP0006Dn000G<0000QT000dW001FB`0OUP00dj000?TK003l3@00g8D0046Q0000
H4<001@]00026@0042X005]7032L003HT@00na<00?XE003FUP00:YX0001IB@003bT0008I000F;`00
Hd00CJD00=ml003m2@00mb<00<j]000=S`0004m>000:90000aX0024g001_<@1g/@00iel00?l1003a
>P00^/8000214P00=d@00P001Ah0o`00<d8007hG0;70003`?P00o`000>QL001l/P00070`000Q=`00
0aX000XT001AC@0CT@00d:L00?PN003l3@00fhP003VO0000G4H0010Z00026@005Rl006@o05>W003Q
M@00oPH00?D/0038^`0008L40010B0001R0000@M000_?`1FWPh0l3l00?l1003WGP00M;00001]=000
7C@0008J000<9P00ET/09YP00=JE003k4P00nQP00=>P000HT`00055=000:90000a/002<h001c:`2<
]`00k4l00?l0003[D000R[H0001c;0008SP000<J000:9@00Dd`07YD00=FJ003k5000nQL00=>N000I
T`00055=000:90000a/002Hj001f9`2H^P00kTL00?l0003YFP00Mk40001]=00073<0008J000>:000
FTP0>9h00=b5003m2P00mRD00<Zg0000R0<003i700067`001Ah003Q400242`37_P00mB/00?h8003N
O`00?Z00001LA`003bT0008I000L<`00KC@0Nk800>YF003o0000k4h008Rf0000L2l001le00026P00
3BP005Y803RN003LP`00o@P00?DZ0037_P0008<=000f@`001Ad000LP0015BP07S@00cjX00?TK003k
4P00eIX001ZD0000D4h000TR00047000;Ch007hI0;c2003c<P00oPD00=mj0012X@0005a7000>:000
0QX001le001a;P2?]`00kDT00?l0003WH@00IZ`0001V?@005Bh0008I000F;`00J3/0KJh00>QL003o
0000k4h008>d0000KS<001/c00026@004B/0065205JX003TJP00o`400>m2002H^P0007<[000P=P00
0QX000hY001MA@19Y000hG<00?l3003a?000Xk`0001f9`008SP000<J000=:000G4L0A:800>5e003o
0`00lC/00:Bm0000MRH0028h00026P003RP005e604RT003RLP00o`800?0o002L^`0007@Z000O=P00
0QX000lZ001P@`1EY`00i6T00?l1003^B000R[H0001^<P006S80008I000C;@00ISd0JZh00>UJ003o
0000jEL006n_0000Ic`001@]00026@006S8006hb08^f003^AP00o`400>=]001=Y@0005e6000=:000
0aX002Dj001j802g`@00m3000?h8003JR@009YP0001AC@00228000@M000hA000R0<0cZd00?TI003j
6000cZ`000290@00>D@000@M00088P00Q`00DTd0:9T00=^7003n1`00lc<00:bo0000MRH0024g0002
6P004B/006=006F/003XFP00o`000>QL001SZ`000691000@:P000QX0028h001h8P2e`@00m2h00?d:
003HT0006i@0001<C@001R0004E:01:A003FU`00o@`00?DZ002o``0007XO000T>@000QX0010Z001R
@@1U[000jET00?l0003WH@00FJT0001OA0003RP000<J000Y?000OaH0b;d00?LQ003k4`00dJH0002:
0000>4@000@L00098`00ET/0>il00>5d003o0@00kDT007jc0000J3X001<]00026@0083H007LU0;G1
003e;@00o@`00=FH000>S`00041800057@00228005=<03:L003ONP00o`800>i60022]00006Ti000C
;@000QT0020g001h8`2l`P00mRT00?`>003CW`001H`0000iA@0011`000XT001HB@15X`00i6/00?l0
003ZEP00IJ`0001Q@P003RP000<J000]?P00P`d0c;400?XG003h7P00b;`0001n60009SX0008J000A
:`00IS`0Nk800>i8003o0P00gWd002bJ0000D4h000LP00067`00CDh09IP00=f2003o0`00kd@0082d
0000Ic/0014[00026P009SX007lF0<Vh00020?TK000?0<Vi0000OQL002Hj00026P004R`006Tj08Ne
003`@000oPD00=Z9000JU00004E:00057P00228005I;00Sooooo0ol00001ooooo`007_ooool00ol0
003oooooooooo`07ooooo`07001GBP003RT0008I000D;@00Gd@0>Il00=V>00020?/C001@0=R?000g
WP0005i5000C;@000QT000lY001IB@0UV000e9d00?TJ003l3@00g8<004RS0000Hd0001L`00026@00
3BL005E;01bD003AY000n1l00?d:003NO@00CZD0001U?P006300008I000=9`00ED/06i@00=6T003h
7P00o@/00=io001;Y00006=0000F;`000QT000hX001GBP0RU`00e9d00?TI003l3P00fhP003fP0000
Gd@001<]00026@004B/005a603BM003IS`00na400?XG003EV@009iP0001HBP003RP0008I000G<000
ICh0DJH00>1i003n2000mbD00<f`000:SP0004i>00098`000a/0028g001`;`1l/P00j5`00?l1003a
?000]L4000205@00=D<200057P3o000e@`00P1D0]L400?4l003o0@00ieh007Na0000Kc80020f0003
6P002RD0059=01JB003AY000nA`00?`>003JR`00=Id0001KA`0042X0008I000G<000ICh0EjP00>9b
003n1@00m2h00<Nn0000QPL003i700067`0011d0035005VO3@3a?000o`400>MQ001`[`0006`f000L
<`000QX000dW001GBP0ZVP00ei800?/A003i6P00dZ<001FB0000D4d000TS00036`009CT007@Y096h
003/C000o`000>]C0026]@00074^000Q=`000aX000/U001DC00RU`00eYL00?/C003j6000dZ4001FB
0000D4h000TS00036`009c/007LT09fk003^A@00o`000>QM001b/00006/f000K<`000QT000lY001L
A`0kW`00gH800?d9003f:000bKX000261P00?4H000DO00057P00>TD008D80<Rk003f:000o@T00=f2
000jW`0005]7000>:0000QX001dd001^<P20/`00jU<00?l0003[D@00Pk@0001_<@007CD0008J000>
:000FdL0?:000=f0003n1`00mB`00<K10000PQ0003A200047@001b0004Q;00^>003@Y`00nAT00?/D
003DW@005Y<0001?CP00228000@L000_?`00OaH0`<@00?@`003n1P00gWd003jP0000FdL000dX0002
6P0083H007</09>i003^AP00o`000>IT001QZ`0006Dn000D;@000QT001L`001Y>@1b/000jET00?l0
003[D@00O[<0001]=@006S80008I000B;000Hd40FjT00>EW003o0@00kTD009>h0000LRd001le0002
6P003bT005i404fU003RL000o`800?0o002N^`0007DY000Q=`000QX000hX001MAP18Y000hG800?l3
003`?@00X;`0001e:0008CL0008J000>:@00GTD0C:D00>9_003o0P00kd4009Nj0000LR`001he0002
6@0042X0065205VY003UIP00o`000>e:0025]@0006dd000I<P000QT001@^001W?01_[`00jEL00?l0
003YFP00Jjh0001V?@004bd0008I000K<`00L300T;P00>m4003o0P00hW0004VT0000G4L000dW0003
6P009cX007/N0;c2003d;@00o@T00=V<000RU`00051>00088@0011d003Y50029003?ZP00nQL00?TJ
003=[`0008L4000g@`0011`000PR001i001CC00/VP00g8@00?h6003b=P00Z;h0001e:0007cH0008I
000A:`00I3l0JZd00>UH003o0000iel005jZ0000HD8000lY00026P0093T007XP0;[2003e;000o@/0
0=NC000HT`0004U<00067`00B4/05Y800=ND003m2`00mB`00;[20000NB4002<h00026P0042X006=0
06V]003ZEP00o`000>IS001EY`0005i5000=9`000a/002/m00204`39^P00n1l00?/D003?Z@0008P2
000f@`0011`000XT001GBP0oX@00hW400?l1003]B`00NK80001W>`004R`0008I000Q=`00N2<0^/80
0?DZ003l3@00e9/000^>0000?TL000@M00088P00E4`0=Yh00>1g003o0P00kDP007fc0000J3/0018/
00026@008SL007TP0<74003f9`00o1000=:R0002RP0003M4000470002R@005U904VT003UJ000o`00
0>UI001PZ`0005m4000=9`000a/002ho00242`3=[P00nQH00?PP0037_`0007dJ000U>@000QX0018/
001X>`20/`00kTD00?l3003MO`00:9T0001?CP020006800M001?CP0XV@00gWl00?l3003^A`00O;80
001V?@004B/0008J000X>`00P1<0b[H00?TI003i7@00b;`0001m6@0093T0008J000C;@00JSP0RkH0
0?0m003n1P00fH`001NC0000@dT000DM00098`00EdX02_ooool1o`00007ooooo000Nooooo`03o`00
0?oooooooooo00Oooooo05T005I;000>:0000QT001D^001P@`0mX000fX/00?/A003j5@00ei8003>M
0000GDH0018/00026@0042X005Y802VI003EVP00nQT00?`>003KQP00@j80001R@@005Rl0008I000>
:000ETX07iH00=:Q003i7@00o@`00=f0001:Y00006=0000G<0000QT000dX001FB`0NU@00dZ400?TL
003m3000gH8004NS0000HT4001D_00026@003RT005Q902JH003EVP00nQP00?`@003JR`00>Il0001N
A@004R`0008I000B;000GDD0>9h00=Z<003l4000nQP00=BL000SU`0005M:000=:0000QT001Pa001V
?@1EZ000h7H00?h7003f9`00c;<000N<0000C4d000TS00036`008cP0078]082d003YF@00o`000?0o
002``00007hG000c@P0200057P3o000gA000PA80^/800?4i003o0@00if4007>`0000KC@001he0003
6P002bD005=<01VD003BX@00nAX00?`@003ISP00<I`0001JB0003bT0008I000H<000IS`0G:T00>9_
003n1000m3000<K10000Q@X003a600067`001Ad003=105^P2`3a>P00o`400>IT001[[P0006Xg000K
<`000QX000dX001HB@0^V`00f8l00?`?003i7000d:H0016A0000Cdh000TS00036`009SX007HW09Ji
003]B@00o`000>YE0021]000070`000P=P000aX000`V001EB`0UV000ei@00?/A003i6P00dJ@001:A
0000Cdh000TS00036`00:C`007PR0::l003_@P00o`000>MP001^[`0006Xh000J<P000QT000lZ001M
AP10X@00gWl00?h8003e:P00b;`000252@00>TD000DN00057`00?4H008L50<Vh003f9P00o@X00=b5
000fWP0005Y8000=:0000QX001he001`<024]@00je400?l0003ZE000Ok<0001^<`0073@0008I000?
:@00G4H0@:400=im003n1P00m2h00<G40000PA80039100047@001b4004Y<00j?003AY000nQP00?XE
003CX0004i40001=CP00224000@L000a@000P1<0aL@00?@^003n1`00gH0003ZO0000FTP000dW0003
6P008CL007@Z09Rj003_@`00o`400>EW001MZP0006@o000C;@000QT001Pa001Z=`1f/@00jUH00?l0
003ZE000N[80001[=P006C40008I000C;000I3l0GjX00>IT003o0000kTP008jg0000LBl001dd0002
6@0042X00613056V003SK@00o`800>m1002I^P0007<[000P=P000QX000lY001NA@1=Y@00hVl00?l2
003`@000VkX0001c:P0083H0008J000?:@00Gd@0D:H00>=/003o0@00kd@009:h0000LBh001dd0002
6@004B/0069105fZ003VH`00o`000>a=0021]00006`f000H<@000QT001D^001X>P1c/000jU@00?l0
003XG000IZ`0001T?`004R`0008I000L=000LBl0U;T00>m1003o0P00hG8004FR0000FdP000`V0003
6P00:3/007`K0<74003e:`00o@X00=R?000OUP0004m>00078@001Ad003a600:;003@Z000nQH00?TK
003</@0008H7000e@P0011`000TS002H001DC00_V`00gH400?h5003b>000Xk`0001d:P007SD0008I
000B;000ISd0KZl00>YE003o0000iV8005ZY0000H4<000hY00036P009CX007/N0;o3003e:P00o@`0
0=JE000DTP0004M;00067`00BT`06I@00=RA003m2P00m2h00;G10000N2<0024g00026P004B/006Dn
06j^003ZE000o`000>EV001@YP0005a6000<9P000a/002dn0022403:]`00n1d00?XF003>[00008L5
000d@P0011`000XT001HB@13XP00hfh00?l1003/CP00MK00001V?@004R/0008J000R>000NB00_/<0
0?HX003l3P00dih000R=0000?4H000@M00098`00ED/0>Yl00>5d003o0@00kD/007Vb0000Ic`0018/
00026P008cP007/N0<G4003g9@00na400=6U0000R@4003E3000470002bD005Y804jU003UI@00o`00
0>QK001LZ@0005i5000<9`000a/003100026203>Z`00na@00?LR0036`@0007/M000S>0000QX001</
001Y>P24]@00kd800?l4003LPP0099P0001=CP001Ql000LP001@CP0/VP00gg`00?l2003]B@00Mk40
001U?P0042X000<J000Z?000PQ40c;<00?XG003h7`00akl0001l70008cP0008I000D;@00JcH0T;P0
0?4k003n1`00f8l001>A0000@4P000@M00098`00F4T:ooooo`7o00000Oooool001kooooo00?o0000
ooooooooool01oooool0o`00E4`000dW00026@005Rl00692046Q003KR000o1000?XG003FU@00;i/0
001LA`004B/0008I000A:`00FdL0;I/00=JG003j5`00o1000=^9000oX@000613000E;P000QT000hY
001HBP0SU`00dih00?TK003l3@00g8<004JS0000HT4001H_00026@003RP005M:02:G003CWP00nA/0
0?`=003LQ@00@Z80001Q@P0052h0008I000?:@00FDT0:YX00=JG003j5P00na400=V>000eW@0005e6
000A:`000QT001</001OA00lX000fhT00?`>003i6P00dil001nF0000ET/000dW00026@006C4006Ll
05ZY003QL`00oPH00?DY003:]P000h/00019C000228000<K000U>@00Lb/0QKD00>YG003o0000kd40
0:^n0000OAX0039100057@001Ql003U500223`2o``00lSL00?l2003VI000KZl0001/=@007C@0008J
000;9P00E4`07ID00=>N003j6000na400=RA000]V`0005U9000>:0000QT001Ta001X>`1PZ`00hf`0
0?l3003c<P00aL<000233@00>TD000HO00057P00=D80GZ4:0?8h003o0P00iFL006N]0000JCT001Xb
00026@003RP005Y803:L003IS000o0h00?PN003?Z@003Xl0001>CP00228000<K000X>`00Mb@0VkX0
0>i7003o0000jEP007bc0000Kc8001he00026P0032H005I:02VI003HT@00o1000?TL003@Y`003Xl0
001=CP00228000<L000Z?@00NR00Ykd00?0o003o0@00iV<006V]0000JCT001Pa00026@0042X005i5
04BR003OO000oPL00?D/0037_`0008@<000hA0001Ah000HO000oA`00R080bkD00?LT003m2`00fhP0
03:L0000F4T000dW00026P007cH0074^08Vf003/CP00o`000>YG001j/P0006dd000K<`000QT000lY
001MA@14XP00ggX00?h5003d<000`L@0001o5@00<40000@L00088@00CDh04I400=:Q003j5P00nQL0
0=:S000?T00004]=00078@0011d003=100224@36`@00mB/00?h8003LP`00=Yh0001HB@0032H000<J
000S>000MBP0WK/00>m1003o0@00i6X005RX0000HT40018/00026@006C8006`f07^b003ZD`00o`00
0>UG001e/@0006Xh000H<000l`000QT001@]001U?P1S[000iV400?l0003]BP00RKH0001_<@0073@0
008I000A:`00HD80EZP00>AZ003o0@00kd@009Bi0000LRd001he00026P003bX005m4056V003SK000
o`400>m2002F^@00078]000N=@000QT0010Z001P@`1EY`00i6T00?l1003^AP00S[L0001`<00073<0
008I000B;000I400HZ/00>MP003o0000je0007bb0000JcL001L`00026@005Rl006Ti07Ra003[DP00
o`000>MO001RZ`0006=0000A:`000QT001de001b;@2I^P00l3l00?l3003QM@00@J40001IB00032H0
00<K000Z?000OQT0aL@00?HY003m2`00ei8001^D0000CTh000LP00057P00?TL01H`00=6U003k5000
n1d00<^d0000Q@X003=1000470002B<005E;03>M003NOP00oP@00?4k002N^`00078/000M=0000QT0
01<]001W?01c/000je800?l0003VI@00EJP0001OA0003RP000<J000W>`00O1/0a<@00?HX003l3@00
eIP0016@0000A4X000HO001=CP0MU@00fHh00?d9003d<@00/<00001f9P0083H0008I000B;000ISd0
L[000>]A003o0000i6T004bU0000FdL000`V00036`00;Sl008<>0<^e003i6`00nQP00<f^0000QPP0
039100036`002bD005Y804RS003TJ`00o`000>]A001`[`0006Dn000A:`000QX002@i001k7P34a000
mRH00?`@003BX@001H/0000jA@0011`000TS001FB`0nX000hW400?l1003/C@00M;00001U?P004B/0
008J000U>@00O1/0a/400?LS003k4`00d:P000281000<d8000<K000;9@00G4L0DZH00>IR003o0000
ieh005NX0000GDH000`V00036`00<T4008L50=2X003k4P00mb@00<G40000NQl0028g00026@0052d0
06Xh08Vf003`@000oP@00=b5000PUP0004]=00067`001b00055=032L003PN@00o`800>a<001b/000
06@o000?:@000aX002/m00233P3=/000nQH00?PQ0036`@0007/N000Q=`000QT001D^001/=@2E^@00
lSP00?h8003GTP004900000nA`0011d000XT001IB@0:ooooo`7o00000Oooool001kooooo00?o0000
ooooooooool01oooool0N@00Dd`000`W00026@005c0006=004JS003LQ@00o0h00?XH003EV000:iX0
001KB0004B/0008I000B;000G4H0<I`00=ND003j5@00na400=Z<000kW`0005m4000D;@000QT000lY
001IB@0WV000e9/00?TI003l3P00fhH004:Q0000HD8001D^00026@003bT005Q902JH003DV`00nQT0
0?`?003KR000?Z00001P@`0052d0008I000@:P00FdP0;Y/00=ND003k5000na<00=RA000aW00005]7
000@:P000QT001<]001P@`10X@00g8D00?`=003i7000dZ8001bD0000E4`000`V00026P006S8006Pj
05jZ003RL000oPD00?D[0039^@0008X00017B`00228000<K000V>P00M2T0R[H00>YD003o0000kd@0
0:Jm0000O1`0031000047@001Ql003]600243034a000lc@00?l2003UI`00JJd0001[=`0073<0008J
000<9P00ED/08IH00=BK003j5`00na<00=ND000ZV@0005Q:000=:0000QT001Xb001Y>@1U[000i6T0
0?l3003c=@00`L@000224000>4@00P001Ah0o`00=d<0H:890?8e003o0`00i6X006:[0000J3/001Pa
00026@003bT005]703JN003JR@00o0`00?PO003>[0002hh0001;C@00228000<K000Y?000N280X;`0
0>m4003o0000j5/007Ra0000KC@001dd00026P003BL005Q:02fK003ISP00o0h00?PN003?ZP002hh0
001:C@00224000@L000/?P00Nad0[;l00?0m003o0@00iFH006F/0000J3/001L`00026@004B/005m4
04RS003ON@00oPH00?@^0035`P00088?000f@`001Ad000HO0011B000R@00c;<00?LR003m3000fX/0
02jK0000EdX000`V00036P008CL0078/08jg003]B`00o`000>UJ001e/@0006/f000J<P000QT0010Z
001OA019Y000h7L00?h5003c<`00_<80001n6000;Sl000@L00088P00Cdh05I800=>N003k5000nQT0
0=6V000<S`0004Q<0007800011d003E200233P37_P00mRT00?d9003KQP00<Y`0001GBP0032H000<J
000T>@00MbD0X[`00?0n003o0P00hfd005BW0000HD80014[00026@006S8006dd082c003[D@00o`00
0>UJ001`[`0006Tj000G<0000QT001D^001V?01X[@00ieh00?l0003/C@00Q;D0001^<`006c<0008I
000A:`00HT40FZT00>EW003o0@00kTH008nh0000LBl001dd00026@0042X0065305FX003TJ@00o`40
0>i5002A^000074_000M=0000QT0014[001Q@P1IZ@00iFH00?l0003]B@00RKH0001^<P006S80008I
000C;000ICh0IZ`00>QM003o0000je<007Na0000JCT001H_00026@005c0006/g07fc003/C`00o`00
0>IR001MZP000691000A:`000QT001le001c:P2N^`00lC`00?l3003PN@00?:00001HB@002bD000<K
000/?@00OaH0a/400?HW003l3@00eYD001NC0000Bdd000HP00057P00@4P02Hd00=:R003k4P00n1l0
0<Zg0000P`d00350000370002R@005I;03NN003ON`00o`<00?0m002I^P00074^000L<`000QT001@^
001X>P1g/@00k4l00?l0003UJ000DJH0001MA@003BL000<J000X?000OQT0a/800?HV003l3`00e9`0
00f?0000@TT000HO001?CP0PUP00fX/00?h80000N03c<`00Zkh0001e:0007cD0008I000C;@00Ic`0
Mk400>a>003o0000hf`004RS0000FTP000/U00036`00<40008@;0<bb003i6P00nAT00<ba0000Q0/0
031000036`002bH005]704bU003TJ000o`000>YD001[[P0006=0000@:P000QX002Dj001l6`35`P00
mb@00?/A003AY0000HX0000hA00011`000XT001GBP12XP00hfh00?l0003[D000Kjl0001T?`0042X0
008J000V>P00OAT0akh00?PP003k5000cj/000261`00<D0000<K000<9P00GDH0EZP00>MO003o0000
if4005>W0000G4L000/U00036`00=48008P20=6U003k4@00mRH00<330000NB80020f00026@0052h0
06/f08jg003`?@00oPD00=^9000MU@0004Q<00057P001b40059=03BM003PMP00o`400>a?001^[`00
0691000>:@000aX002dn00242`3>[@00na@00?LS0035a00007TQ000P=P000QT001H_001^<`2J^P00
lSH00?d9003FU@0038l0000lAP0011`000XT001KB0[ooooo0Ol00001ooooo`007_ooool00ol0003o
ooooooooo`07ooooo`1i001BC@0032H0008J000H<@00I3l0BZ@00=f2003l3@00nAX00=BL000WV@00
05U8000@:P000QT001</001NA@0eW@00f9000?/D003k4`00f8l003NN0000GTD001</00026@0042X0
05Y802^J003EV000nQL00?`@003JR@00?J00001P@`0052d0008I000?:P00FDP0:YT00=FH003j5`00
o1000=Z;000jW`0005i5000C;0000QT0014[001LA`0bW000f9400?/C003k5@00ei@002fK0000FTP0
010Z00026@0052h0065204FR003MPP00o@`00?PN003AY@0069<0001CC0002bH0008J000K<`00JSP0
Hj/00>=]003n1000m2h00<Rl0000R08004A:00078@000a`002Pk001f9`2?]`00je400?l0003^A`00
XK`0001j7`00;Sl000@M00068000?TL008D90<K1003c<P00o`<00>AZ001U[00006Ti000K<`000QX0
00dW001FBP0UV000eIP00?XE003k5000eYL002JH0000ETX000dW00026P006c<006Xh06V]003UIP00
o`800?8g002l`P00084C000f@`0200057P3o000iA01SY0L0lc<00?l3003SK@00GJX0001W?0005c00
008I000@:P00G4H0>Yl00=^6003m2`00mb400<f_0007S@0004U<00088@0011`002/m001j802U_@00
kd400?l0003WGP00Lk00001/=@0073<0008J000=:000FDT0<I`00=Z;003l3@00n2000<j]0007S@00
04Q;00078@0011`002ho001l6`2a`000lCX00?l2003TJ@00H:/0001V?0005Rl0008I000B;000H4<0
C:D00>1f003n1@00m3400<C40000PA8003A200047@001R0004=900>;003=/000n2000?`=003ISP00
:YX0001FB`002bH000<J000R>000M2X0TkP00>e8003o0000j5`0072_0000JSP001Ta00026@004B/0
061304fU003QL`00o`@00?8e002g`@0007dJ000]?P0011`000PR001@CP0IT`00e9/00?/C003i6P00
cjT000V=0000ATX000LP00057@00=d<008@;0<Rk003f9`00o@X00=Z9000^V`0005I;000;9@000aX0
02Hj001h8`2W_@00lC`00?l2003RL000D:H0001P@`0042X0008I000L<`00KS80QKD00>a>003o0000
j5d006b^0000Ic/001D_00026@005Rl006Pk06f^003XF`00o`000>]@0020/`0006de000J<P000QT0
018/001S@01OZP00iV@00?l0003]B@00RkH0001_<@0073<0008I000A:`00HT40FZT00>EV003o0@00
kTP008bg0000Kc4001`c00026@004B/006=005jZ003VH`00o`000>a<0024]@0006dd000I<P000QT0
01@]001V?@1[[P00j5X00?l0003ZE@00L[00001X>P005Bh0008I000H<@00K3D0P[@00>a<003o0000
iFD005VY0000HD80010Z00026P0083H007DX0:>m003a>P00oP@00=ml000hWP0005M:000:9@000a/0
02dn00204`37_P00mbD00?`>003EV00059800018C0001Ql000DN0013B@0<S`00dil00?/A003g8@00
bKX000224000;cl000<K000:9@00EdX0?:000>1h003o0`00l40009Bi0000L30001Xb00026@005Bh0
06Ti07bc003/C000o`000>A[001=Y@0005a6000<9`000a/002Xm001o5P37_`00mb@00?`@003CW`00
2Xh00010B0001R00051>02BH003KR000oPL0001h0?8e002V_@0007@Z000M=0000QT001@]001X>P1l
/P00kD/00?l1003RK`00@j80001IB@002RD000<K000b@@00QPP0cJl00?XH003i6`00bk@000233P00
;Sl000<K000<9P00G4H0D:H00>EU003o0000jEL006N]0000HT4000lY00036P009c/007dI0<No003g
8P00na<00=2W0000R@4003I3000470002R@005U904JS003TJ`00o`000>YC001[[P0006=0000?:@00
0aX002Pk001o5P38^`00n1h00?XF003=[P0008D:000_?`000a/000`W001NA@1KZ@00j5`00?l0003V
I000CjD0001JB0002bD000@L000f@`01RP00dZ800?`?003f:000^l80001g90007cH0008I000E;`00
KC@0TkP00?4k003n1P00fX`001VD0000ADX000DN00088@00E4`0>9h00>5c003o0@00je8006V]0000
HD8000hX00036`00;cl008H80<nZ003k4P00mbD00<330000N2<001le00026@005c0006la09nk003c
<`00o@X00=FH0009S@0003Y5000470002bD005a72_ooool1o`00007ooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0?l0055=000;9@000QX001Ta001U?@1?Y@00gWl00?d<003i7000dil002>G0000
F4T000lY00026@004bd005m403VO003IS@00na800?/D003GTP00<id0001MAP004R`0008I000A:`00
FdL0;i/00=JE003j5P00na400=V=000iW`0005i5000C;@000QT0010Z001KB00^V`00eYD00?XE003k
4P00fHh003JN0000GDH0018/00026@004R`005e603JN003ISP00na400?XF003FV000:IT0001IB@00
3bT0008I000E;`00HT40BJ@00=io003m2P00n2000=2X000DTP00059=000;9@000aX001dd001[=`1X
[@00i6X00?l3003d<000akh000271@00@TT000LQ00047000:S`007LU09Bi003/CP00o`000>e:002L
^`0007TQ000/?P0011`000LP0010B000QPH0akl00?@_003n1000hfd0062[0000J3X001Tb00026@00
3BP005Q:02VI003FU@00na<00?XF003EVP008YL0001EB`0032H0008J000L=000K3H0KZl00>IS003o
0@00lCX00;O10000OaD003A200057@001Ql003]506>S1P3d<000oP@00>9`001IZ@0006Dn000F;`00
0QT0010Z001MA@0nX000g8<00?d:003g9000c;8000B;0000AT/000LQ00047000;Ch007/M0:Zn003`
?`00o`400>MQ001^[`0006/g000J<P000QT000hX001JB00eW@00fhP00?d<003g8P00cK0000B;0000
ADX000LP00047000<40007hH0;K1003b>000o`<00>=/001LZ@0006Dn000E;P000QT001</001R@@1A
YP00hG<00?h4003c<`00_l<000205@00<T4000@M00078000AT/01X`00<j]003h7P00o0l00=RA000V
V00005E;000;9@000aX002@i001e:02H^P00kTD00?l0003WG`00K:h0001Y>P006300008I000B;000
HD80DJH00>9`003o0`00lSP00;700000Nad002/m00036`002B<0055=01bE003EV000na400?TL003>
[0001H`00013B@001R0000DN000iA000QPP0bKP00?LU003m3000fH`002ZI0000ED/000XU00036`00
9c/007TQ0:bo003a>@00o`<00>5c001;Y00005i4000?:P000QT001dd001`<02:]P00kD/00?l0003W
H000Ijd0001V?@0052h004l0008I000G<000JCT0LK000>UH003o0000je<007^b0000JcH001Pa0002
6@004bd006Dn06>/003WH@00o`000>a<0026]@0006hc000K<`000QT0018/001S@01NZP00iV<00?l0
003]B`00QkD0001^<P006S80008I000B;000I3l0HZ/00>MP003o0000k4l007nc0000K3H001Pa0002
6@005Bh006Lk072_003YE`00o`000>UH001^[`0006Ll000D;P000QT001Tb001]<`27]@00kDT00?l1
003TJ000E:L0001OA0003bT0008J000R=`00MRH0Z;h00?8g003n1@00gWl003BM0000ET/000XT0003
6`00;cl0088@0<Rk003g8`00o1000=BK000@T00004I;008000HO0:8004E:012@003DV`00o0l00?LS
0038_@00080C000]?P000a/000/U001IB@10X@00hG@00?l2003_@`00SkL0001^<P006C80008I000F
;`00JcL0PK@00>e:003o0@00hfh004RT0000FdL000`V00036`00;3h0080C0<Rl003g8P00na800=:R
0006S00003e700077`00DDd0:9T00=b5003n1P00lSP00:2l0000LR`001`d00026@005Bh006Xh086d
003]B000o`400>5b000oX@0005M:000:900011`003A200271@3>[000nQH00?PM003:]`00088A000/
?P000a/000dW001MA@1EY`00iV800?l0003YFP00HZ/0001Q@P003RT000<J000X?000OaH0b;`00?PP
003k5000cjX000271000=48000<L000;9@00FTP0BZ@00>AX003o0000jUH006J/0000HD8000hY0003
6P00:S`0080C0<Vh003i7@00nQP00<ba0000P`d002hn00036`003BL005m405nZ003YF@00o`000>EW
001:Y00005U9000:900011`003Q400B;003CW`00o0h00?DZ002f`@0007HV000N=@000QT001L`001^
<`2H^P00lSP00?h7003HS`005I800013B@001Ah000PR001EB`0lX000hW000?l0003ZE000I:`0001P
@`003BL000<K000a@000Q`D0d:L00?/A003f9`00^/80001f9P007C@0008I000H<@00L2l0Y;d00?@a
003m2`00e9/000J<0000=d@000@L000;9P00GDH:ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool0o`00D4h000/U00026P006S8006Ll05>W003ON`00o@X00?PN003BXP007iH0001G
BP003RP0008I000D;P00H4<0?Z000=Z:003l4000nQH00=JE000_V`0005]7000A:`000QT0018/001M
AP0cW@00f9800?/D003k4`00f90003FM0000GDH0018/00026@004B/005a703:L003HTP00na@00?/C
003HTP00<Y`0001LA`004B/0008I000C;000GTD0>Yl00=Z;003l4000nQP00=BK000UV00005Q:000>
:0000QT001H_001T?`1=Y@00gg`00?d9003g8P00cj/0016@0000DDd000XT00036P007SD006`e06b^
003UIP00o`<00?<c0036`@0008D8000oA`001b0000@L000[?@00N280VKX00>e;003o0000k4`009Ni
0000Mb@002Xl000470001b40049900280`38_000mBd00?h5003RL000FjT0001W?0006340008I000>
:000FDT0;I/00=RB003k4P00nQP00=BM000NU@0005A<000;9P000QX001he001]=01c/000if000?l1
003a?000/L00001n6000<T4000@M00067`00?DL0I:840?@^003n1@00hG<005BW0000I3l001D^0002
6@004B/005m404:R003MO`00o@T00?HV003;]@0008X00014BP001b0000@L000_?`00OA/0[kl00?4l
003o0@00iV@006V]0000JCT001Tb00026@003bT005]703VO003LQ@00o@X00?LT003;/`000HX00013
B@001b0000@M000b@@00OaD0_<800?8e003o0`00hfl005NX0000I3l001@^00026@0052d006=005FX
003RL000o`<00?8f002i`P0007hG000`@00011`000LQ0019C00:SP00cjT00?TL003l4000eiD002:G
0000Dd`000XT00036`009CX007HV09fk003_@`00o`400>IS001W[@0006Lk000F;`000QT001</001S
@@1FZ000hfd00?l2003a>P00[;l0001j7`00:C`000<K00099000DTd089H00=NE003l4000n1h00<f_
0002RP00045800067`001Ah003]600271@3;]@00mb<00?`=003HT0009YP0001DC0002R@000<K000Y
?000Nah0//000?8f003n1000h7H004NS0000GDH000lY00026P007SD0074^08ng003]B000o`000>IS
001RZ`0006Dn000C;@00l`000QT001P`001Z>01f/@00jUD00?l0003ZEP00M[40001Z>0005c00008I
000D;P00ISd0J:d00>QN003o0000k4l0082d0000KCD001Tb00026@004bd006@o06>/003WH000o`00
0>a=0022]00006dd000I<P000QT001<]001U?P1W[@00j5d00?l0003[DP00N[80001Z>0005c00008I
000F;`00JCX0MK000>YD003o0000j5/006V]0000ICh001<]00026@006c<006lb08bg003^AP00o`40
0>A[001@YP0005i5000>:0000QX002<h001h902^_`00lc@00?h6003MPP00<9`0001EC0002B<000@L
000a@000P`d0bKP00?PP003k4@00dil000b?0000@dT000DO00067`00B4/04i400=FH003l3P00mRH0
0<K00000OaH002/m00036`0032H005Y804BR003RL@00o`800>i5002:]P0006dd000H<@000QT001L`
001/=@26]@00kTL00?l1003RL@00A:80001IB0002bD000<K000^?`00PQ00bKT00?PO003k4`00dJD0
00>;0000>dD000HP001BC@0/VP00gH400?h5003a>`00Vk/0001a;P006c<0008I000F;`00JcL0Q[D0
0>i6003o0P00h7H003^O0000ET/000TS00047000=T<008T10<nY003k5000n1l00<Vj0000P1<002/m
00036P003BL005m405VY003WG`00o`000>QM001MZP000613000>:0000aX002Xm00204`39^@00n1h0
0?XF003>[@0008H7000b@@000a/000/V001KA`1?YP00iFD00?l0003YF@00HJ/0001P@`003RP000<J
000[?@00PQ40bkD00?TK003i6P00bk@000224000;3d000<J000>:000HD80I:`00>YF003o0000i6X0
04JS0000F4T000XT00047000>TD01hd00=BL003l3@00mBd00;300000MBT001`d00026@00630006la
09fk003b=P00o@P00=NB000BT@00045800047@002B<005I;046Q003SK000o`000>UG001OZ`0005m4
000<9`000a/003=100280P3AY000o0l00?DY002e`@0007DX000L=0000QT001Ta001b;@2Y_P00m2h0
0?`=003CWP000XX0000e@`000a/000`V001NA@0:ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool0o`00CTh000XT00036P0073<006Pj05RX003PN000o@T00?PP003AY@0079@0001F
B`003RP0008I000F;`00HD80@Z800=^7003l3`00nQP00=FH000ZVP0005Y8000@:P000QT001</001N
A@0gWP00fHh00?/B003k5000ei<0036L0000G4L0014[00026@004R`005e503JN003ISP00na800?XE
003FU@00;I/0001JB00042X0008I000D;@00H4<0?j400=^7003l3P00nAX00=>N000QUP0005I:000=
:0000QT001P`001U?P1BY`00h7T00?h8003g9000cJh000f?0000Cdh000XT00036P007cH006hc076`
003VH`00o`800?8e0034a00008@;000mAP001R0000@M000]?P00NR00W[/00>e8003o0000k4l0096h
0000MRH002Pk000470001b4004E:00290039^@00mB/00?h6003QM000EZP0001U?@005c00008I000?
:@00FTP0<I`00=V>003l4000nAX00=:Q000JU00005=<000;9@000aX001lf001^<P1h/@00j5d00?l0
003`?`00[;l0001l6`00<40000@M00068000@4P0I:430?D[003n1P00h7H0052V0000Hd0001@^0002
6@004R`0061304NS003NO000oPP00?HX003:^00008P20011B0001R0000@M000a@000OQP0]L400?4i
003o0P00iFL006B/0000J3X001Pa00026@0042X005e603jP003MP@00o@T00?HV003:]P0008P20010
B0001R0000DM000d@P00PA80`L@00?<c003n1000hW8005:W0000HT4001<]00026@005Bh006@o05ZY
003SK000o`<00?8h002d`@0007dJ000^?`0011`000PQ001;C@0>S`00d:H00?TJ003k4P00eIP001jF
0000DTd000XT00036`009c/007PS0:>l003`@000o`400>EV001RZ`0006Hm000E;`000QT001@]001T
?`1KZ@00i6X00?l2003`?@00Ykd0001i8P009c/000<K000:9000Dd`099P00=RA003l3P00n2000<bb
0000R@4003i700067`001Ah003e700280@3</P00n2000?`>003GT`008YL0001BC@002B<000<K000[
?@00O1/0]l400?<d003n1@00ggT004:R0000G4L000hX00026P0083H007</09Bi003^A@00o`400>EV
001MZP0006=0000C;000l`000QT001Ta001/=P1k/P00je800?l0003YF@00LJl0001Y>P005Rl0008I
000E;`00Ic/0KJh00>QK003o0000je8007^b0000JcH001Pa00026@0052d006Hm06R]003XG@00o`00
0>]@001m/`0006/f000H<@000QT001@^001W?01/[P00jEX00?l0003ZE@00MK40001Y>@005Rl0008I
000G<000JSP0N[800>]A003o0000iel006B/0000I3l0018/00026@0073<0070_096h003_A000o`40
0>=_001;Y00005e6000=:0000aX002Di001i8@2c`000lc800?h7003LQ@00;9X0001CC0002B<000@L
000c@@00Q@X0bkD00?PN003k4`00dZ8000V=0000@DP000DN00068000Bdd05i<00=JE003l3000mRP0
0<G30000OQT002Tl00036`0032L005]704VT003SKP00o`400>e80025]@0006`f000G<0000QT001Pa
001]<`2;]`00kd@00?l2003QM000?j40001HB@002bD000<K000`@000P`d0b[H00?PM003j5@00d:P0
00290000>D@000HP001DC00`W000gWh00?h4003`?@00U[T0001`<0006S80008I000G<000KCD0RkH0
0>m3003o0`00h7T003JN0000ED/000TS00047000>D@00HX00=6U003k4`00mb400<Nm0000OaH002Tl
00036P003RP0061305jZ003XG000o`000>MP001IZ00005i5000=9`000a/002`n0022403:]P00nA`0
0?XH003=/00008@:000`@0000a/000`V001LAP1DY`00iV800?l0003XG000G:X0001OA0003BL000<K
000]?P00P`h0c;800?XI003i7000b[L000214`00:S`000<J000?:@00HT40JJd00>YC003o0000hfh0
046Q0000EdX000TS00047@00?DH02hh00=FI003m2`00m2l00:^n0000Lb/001/c00026@006C40074_
0::l003c<`00o@X00=JE000>S`0003i700047@002B<005M:04FS003TJ@00o`000>QK001KZ@0005e6
000<9P000a/003E2006:003BX@00o0h00?D/002``00007@Z000K<`000QT001Xb001c:`2^_`00mB`0
0?`>003BXP0008T0000c@@000a/000dW001P@`0:ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool0o`00C4d000TS00036P007C@006Xi05fZ003QM@00oPP00?LR003@Z00069<0001D
C0003BL0008I000G<000Hd00Aj<00=b4003l3@00nAX00=BL000VV00005U9000?:@000QT001@]001O
A00kW`00fX/00?`A003j5P00eYH002bJ0000FTP0010Z00026@004bd005m403ZO003JR`00o1000?XG
003EV000:IT0001IB@003bT0008I000E;P00HD80@j800=b4003l3@00nA`00=:Q000MU@0005E;000=
9`000QT001Ta001V?01GZ000hGH00?h7003f9P00c;4000V=0000CTh000TS00036P008CL006la07Ja
003WH000o`400?8h002o``0008<?000jA@001Ql000@M000_?`00Nad0Y;d00>i5003o0000je8008bg
0000MBT002Lj00036`00228004Q;00>;003;]P00mRP00?h7003PM`00DZH0001T?`005Rl0008I000@
:P00FdL0=Id00=Z;003l3P00nA`00=6T000FTP00059=000:90000aX0024g001`<01m/`00jEX00?l0
003_@P00Ykd0001k7P00;Sh000@L00078000@TT0IJ410?HY003n1`00ggX004^T0000HD8001<]0002
6@004bd0065204bU003PN@00oPL00?DZ0038^`0008L5000oA`001Ql000@M000c@@00OaD0^/800?8g
003o0P00i6X005nZ0000Ic`001L`00026@004B/005i504:R003NOP00oPP00?HX0039^P0008L5000n
A`001Ql000DN000f@`00PQ00aL<00?@`003n1@00hGD004jU0000HD80018/00026@005Rl006Hm05nZ
003TJ@00o`800?4k002^_`0007/M000/?@0011`000PR001>CP0AT@00dJ<00?XH003k5000e9/001ZD
0000DDd000TS00036`00:C`007TQ0:Rn003`?@00o`800>AY001MZP0006Dn000D;P000QT001D^001U
?P1PZ`00iFL00?l1003`@000XK`0001g90009SX000<K000;9@00ED/0:9T00=V>003l3@00mb<00<^e
0000Q`@003a600057P001Ql00418006:003=[`00n1h00?`@003FUP007YD0001AC@002B<000<L000]
?P00OQT0_<<00?<a003n1P00gW`003jP0000FdP000dW00026P008CL007@Z09Vj003_@P00o`400>AY
001HZ0000691000B:`00X0000QT001Xb001]=021]000jdl00?l0003XG000K:h0001W>`005Bh0008I
000F;`00JCT0L[000>UH003o0000jUD007Ja0000JSP001L`00026@005Bh006Lk06f^003YFP00o`00
0>YC001h/@0006Xh000G<0000QT001D_001X>P1a[`00jEL00?l0003YF000L:l0001X>`005Bh0008I
000H<@00K3H0Ok<00>a>003o0000iV8005nZ0000Hd00014[00026@007C@0078]09Ji003_@@00o`80
0>9b0016X`0005]7000=9`000aX002Hj001j7`2h`P00m2l00?h8003KR@009iT0001BC@00228000@L
000e@`00QPL0c;800?TL003k5@00dJD000F<0000?TL000DN00078000CDh06i@00=RB003m2`00mBX0
0<;40000O1/002Pk00036P003BL005e604fU003TJ`00o`400>e;001o/`0006Xh000F;`000QT001Tb
001_<@2A^000kd400?l3003PM`00>il0001GBP002R@000<L000b@@00Q@X0c;<00?TK003j5`00cZ/0
00280`00=T<000LP001EB`0eW@00gg/00?l3003`@000TKP0001^<P006340008I000H<@00KS<0T;P0
0?10003o0`00gW`003:L0000E4`000PR00047@00>dD018/00=:R003k4@00mb<00<K00000OAT002Lk
00036P003bT0065206>/003YF@00o`000>IS001DY`0005e6000<9`000a/002ho00233@3;/`020?TJ
001A0<^c0000P`h002hn00036`003BL005i505RX003WG`00o`000>MO001HZ00005e5000<9`000a/0
02lo00242P3=[`00nQL00?PN0039^P0007lF000X>`000aX000lZ001S@01^[`00je000?l1003RL@00
?J00001EB`002B8000@M000oA`0>S`00eYH00?d:003c<P00Y[d0001b;@006S80008I000J<P00LR`0
Z;h00?@`003m2`00eIT000Z>0000?4H000@L000:9000FDT0BZ@00>EV003o0000j5h005JX0000G4L0
00/U00047000=d@018/00=BM003l3000m2h00:Zn0000LR`001Tb00026@0073<007DX0;C1003e:P00
o0l00=6U0000R0@0035000036`003BP0065200[ooooo0Ol00001ooooo`007_ooool00ol0003ooooo
ooooo`07ooooo`3o0019C0002B<000<J000N=@00JcL0HJ/00>9b003n1`00mb@00<j[000DTP0005=<
000<9P000QT001P`001T?`1;Y000gH000?d<003i7000dil002:G0000EdX000hY00026@005Bh00653
042Q003KR000o0l00?XH003EVP00:9T0001IB@003bT0008I000D;@00H4<0?j400=^8003l3`00nQT0
0=BK000UV00005Q:000>:@000QT001H_001R@@18X`00gH400?d;003h7P00dJ@001VD0000E4`000`V
00026P006S8006Pk05bY003RLP00oPH00?HY003;]0001X`0001;C@002B<000<K000R>000LBl0O;80
0>QM003o0@00lC/00;W20000PA8003Q400067`001Ad00350001m6P2Y_P00kd800?l0003ZE@00QkD0
001c:`009CT000<K00088P00BTd01X`00<bb003f9P00oPP00=mj001=Y@0006=0000E;P000QT0014[
001MAP0jW`00fhP00?`=003h7P00d:L001:A0000D4h000XT00036P008SP0074^08:d003ZE`00o`00
0>i5002Q_00007XP000/?@0011`000LQ0015BP1VX000mRL00?d8003NO@00AZ<0001P@`004R`0008I
000D;P00Hd00D:H00>5e003n1P00mBd00<Nn0000Q@P003a600067`001Ah003E200214P30``00lc@0
0?l3003SKP00FjT0001U?P005Rl0008I000B:`00Gd@0Aj<00=mk003n1`00mB/00<Rm0000QPP003]6
00057`001Ah003Q400243036`000m2d00?h6003PN@00BJ@0001P@`004B/0008I000G<000Ic/0I:`0
0>EV003o0@00l3h00:Vn0000NQl002Xl00036`002B<004m>01FB003CX000nQH00?XE003CWP005i<0
001@CP002B<000<K000[?@00Nah0[[l00?4j003o0P00hf`005RX0000Hd0001<]00026@005Rl006Ll
06B/003VI000o`400>m3002L^`0007HW000T>@000aX000/U001FB`0]V`00fX/00?d;003g9@00bKP0
00261`00>TD000DN00067`00@TT018/00<j/003i7000na800=FI000JU000051>00088P0011`002lo
001o5P32a000m2l00?h7003MP000>Il0001IB@0032L000<J000S>000MBL0Wk/00?0o003o0P00hf`0
05BW0000HD80014[003c00026@006c<006hb08Je003/C000o`000>MO001W[@0006Hm000D;P000QT0
01L`001Z>01g/@00jU@00?l0003YF000LK00001X>P005Rl0008I000F;`00JCX0L[000>UG003o0000
jUH007>`0000JCX001H_00026@005Rl006Ti07Ja003ZE000o`000>QK001[[P0006Hm000D;@000QT0
01Ta001]=024]@00kD/00?l0003UI@00FZT0001Q@P0042X0008I000O=@00Lb/0W;/00?0n003o0`00
hGD004:Q0000FTP000`V00036P00:3/007`L0;k3003e;@00o@T00=V<000SU`00055=00088P0011d0
03Q40027103=[`00nAX00?XF003@Z0000XX0000lAP001Ad000LQ001?CP0OUP00fHh00?d:003e;@00
_<<0001k7P009SX000<J000>:000GTD0DZL00>EX003o0000k4h007Zb0000JCT001D^00026@006c<0
070_09Ji003`?P00o`<00=mk000fWP0005I;0009900011`003A200261`3=/000nAT00?XI003=[P00
08H6000d@P001b0005I;03VO003PN000o`800>m3002;]P0006dd000G<0000QT001Tb001_<@2E^@00
l3d00?h4003MO`00;Y/0001BC@00228000@M000mA`08S@00dil00?`?003f9P00aL<0001l70009CX0
008J000@:P00Hd00J:d00>YF003o0000iFH004nV0000G4L000`V00036`00<40008D:0<f`003j6000
nA`00<Zf0000PQ4002`m00036P003BP005m405fZ003XG000o`000>IR001CY`0005a6000<9P000a/0
035000261`3>[000nQD00?PP0037_@0007hH000V>P000QX0010Z001U?P1c/000k4d00?l1003QM000
>9h0001DC000228000DM0012B@0BT@00ei800?d9003c=000X;`0001`;`006340008I000K<`00M2X0
[Kl00?@^003m3000e9`000N<0000>DD000@L000:9000FTP0CZD00>IS003o0000if40056V0000FdP0
00XU00047000>DD028d00=FJ003m2`00m3400:Fm0000LBl001Pa00026@007C@007HV0;W2003f9`00
na400=2X0000QPL002lo00036`003RP0069100[ooooo0Ol00001ooooo`007_ooool00ol0003ooooo
ooooo`07ooooo`1>0016B`00228000<K000P=P00K3D0Ijd00>=^003n1P00mRL00<f_000@T000059=
000;9P000QX001Ta001V?@1@YP00gWd00?d;003h7P00dZ8001jE0000ET/000hX00026@005Rl00691
04FR003LQ000o0d00?TJ003DW@0099P0001HBP003RT0008I000E;P00HD80@j800=b4003l3@00nA/0
0=>O000QUP0005M:000>:0000QT001L`001T?`1=Y@00gWd00?d:003h8000d:P001FB0000DTd000/V
00026P006c<006Ti066[003SK`00oPD00?D[003:^0000XX00019C000228000<K000T>@00LRd0PK@0
0>UJ003o0000l3d00;C10000P1D003I30P001Ah0?@00<d8007hH0:no003`@000o`000>UI0021]000
078]000S>0000a/000TS001=CP0:SP00cJl00?LT003m2@00gWd004RT0000HD8001@]00026@004B/0
05i503jP003LQ000o@/00?PP003?ZP003Xl0001?CP002B<000<K000T>@00Lb`0R;H00>YC003o0000
kTP009bk0000N2<002Xl00047000224004Q;06VO003g9000o@T00=f00012X@0005m4000A:`000QT0
01D_001T?`1EY`00hW800?h5003d;`00a/4000243000>TD00P001Ah04`00=d@0088?0<G4003c<@00
oP@00>9a001FZ00006@o000E;P000QT0018/001Q@P1<Y@00h7L00?h6003d;@00a/0000242`00>DD0
0P001Ah0Y@00>dD008D90<Nm003e:`00oPL00=ml0014XP0005i5000@:P000QT001Pa001Y>P1Y[@00
iV<00?l1003`@000Xkd0001h8P00:3/000<K00098`00DDd06I@00=BL003k5000nQL00=:R000CT@00
04i>00088P0011`002`n001l6`2c`000lSP00?l3003RK`00DjL0001R@@004R`0008I000G<000J3X0
JZd00>MP003o0000kTH009Ji0000M2T0028h00036P0032H005M:036L003KQ`00o@X00?HW0038^`00
08@;000gA0001Ad000HP0015BP08S@00cjT00?TJ003k4`00e9d001JB0000Cdh000PR00047000<D00
084C0<G3003e;000oPP00=b3000eW@0005Q9000<9P000aX002@i001g9@2T_@00lCd00?l2003RL000
CjH0001OA00042X0008I000M=000L300RkH00>e9003o0000iV8006:[0000I3l001<]00026@006C40
06`f07bc003[D@00o`000>QK001/[P0006Ll000E;P000QT001L`001Z>01g/@00jU@00?l0003YFP00
KJh0001W>`005Bh0008I000H<000JcL0Nk800>]A003o0000ieh006J/0000ICh001</00026@006S80
06hb08Vf003]B000o`400>AX001EY`000613000?:P000QX0020f001d:@2Q_000lC/00?l4003PN@00
?J00001IB@002bH000<K000Z?000OAT0a<@00?DZ003m2`00f8l001nF0000D4h000LQ00047@00>TD0
08T00<j/00020?XH002W0<j/0000R@4003U500047@002240051=02>G003JR`00o@T00?@_002g`@00
07TQ000T>@000QX000hY001OA01GZ000iV@00?l0003[D@00MK40001W>`0052d0008I000L=000LRd0
Vk/00?4l003n1000gWh003:L0000E4`000TS00047000=T<008P40<j/003j5`00nA/00<bb0000Q@T0
039100078000EdX0?Z000>5d003o0P00kTH008Je0000JcH001H_00026@006c80074_09^j003a>P00
oPD00=b3000ZV@00055=00078@001Ah0041800b>003DW000o0h00?HX0031a00007XO000T>@000QX0
010Z001T?`1][P00je<00?l0003TJ@00BZ@0001JB0002bD000<K000b@@00QPL0cZd00?XF003h7P00
bKT000205000:S`000<J000>:000HD<0HZ/00>UI003o0000iFH004jU0000FdL000/U00036`00<d80
08L40<nY003k4`00mb800<K10000O1/002Di00026P004B/006Hm07Ra003]BP00o`800>1g000dW@00
05=<00088@001Ah004A:01JB003HS`00oPL00?8g002K^P0006la000G<0000QT001dd001e:02c`000
mB/00?`>003CW`000h/0000g@`0011`000/U001KA`1CY`00if000?l0003VI000C:D0001IB@002R@0
00@L000lAP0;SP00eYL00?d:003c<`00Wk`0001_<@005c00008I000N=@00N2@0_l<00?LU003k4`00
cZ/000252P00;Ch000<J000?:@00I3l02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo
00Oooooo04h004A:00088P000a/0024g001^<`1/[P00i6/00?h5003e:@00c;8000b?0000D4d000/U
00026P006S8006Ll05FW003ON@00o@T00?PP003AYP006Y@0001EB`003BL0008I000G<000Hd00BJ@0
0=f1003m3000nA`00=:P000PUP0005I:000>:0000QT001H_001S@018Y000gH400?d<003i7@00dZ80
01fE0000ED/000dW00026@00634006Dn056V003ONP00o@T00?LR003?Z`004I40001AC@002bD000<J
000M=000JcL0IZ`00>A/003n1000m2h00<Rk0000R@0004I;00088@000a/002Hj001c:P26]@00jUL0
0?l0003`@000[[l0001n6000=48200057P0m000f@`00P1D0]<400?0m003o0@00j5`007bb0000L2l0
028g00036`002B<004m>00j?003>[000mb400?d:003MP@00A:80001P@`004b`0008I000B;000H4<0
@j800=f1003m2P00mb800<j^000;SP0004e>00098`000a/002Dj001d:@2=]`00je000?l0003]B`00
U[T0001g9@00:3/000<K00088P00BTd0Jih00?LR003m2`00g8@003fP0000GDH0010Z00026@005Rl0
06Hm05ZY003SK`00o`@00?<b0034a000088?000gA00200057P3o000jA@00Q0`0a/400?@_003n1@00
hG@0056V0000HT4001@]00026@004bd00691056V003QM000oPD00?@`0035``0008<?000g@`001Ah0
00HO000mAP00Q`H0bKX00?HX003n2000gGl003nQ0000GDH0010Z00026@006C8006Xh06j_003WG`00
o`000>m3002N^`0007LU000V>P000a/000XT001BC@0MU@00eIT00?/C003i6@00dJD000n@0000C4d0
00PQ00047000;Sl007hH0;W2003c=@00o`@00>5c001>Y@000613000A:`000QT001Pa001Y>@1_[`00
j5d00?l0003]B@00TKP0001c;0008CL000<J000=9`00FDT0=Id00=b4003m2@00mBX00<No0000P`h0
03E200047@001b0004Q;00b>003AY@00nQP00?XE003CX0004Y40001<C@001b4000@M000c@@00PQ00
a/000?DZ003m2@00fhH0032L0000EdX000/U00036P009SX007PR0:Zn003a>P00o`<00>5c001:Y000
05i5000?:@000QX001he001a;P2A^000kTH00?l1003UIP00GJX0001S@0004R`0008I000J<P00KC@0
P[@00>a>003o0000ieh006N]0000ISd001@]00026@00634006/f07fc003[D@00o`000>QM001X[@00
06Hm000D;@000QT001Ta001/=@21]000k4h00?l0003WH@00HJ/0001S@0004R`0008I000L<`00L300
SkL00>i5003o0@00i6`0052V0000Gd@000lY00026P008SL007HV0:Nm003b>000oP@00=ml000iW`00
05M:000;9@000a/002`m001o5P36`P00mRP00?d<003GT`006i@0001>CP001b4000DM000lAP02RP00
d:P00?XF003i6P00cJl000271000=d<000@M00088P00DTd09iT00=^8003n1`00lc800;700000N2<0
02<h00026P003bT0065205bY003WH@00o`000>YD001`[`0006Hm000C;0000QT001de001c:`2Q_000
lST00?h5003MP@00;Y/0001CC000228000@M000hA000R@00cjT00?XE003i7@00bkD000233@00<400
00LP001IB@12XP00hW400?l1003]B@00PK@0001Z>0005Bh0008I000L<`00LR`0X;`00?8h003n1P00
fhH002FH0000D4h000LQ00057P00@TT03i000=FH003m3000mB/0001T0;_20000NB40028h00026P00
4B/006Dm07:`003[D000o`000>=]0015X`0005U9000:900011`003A20028103?Z@00na@00?PP0038
_@0007lG000X>`000aX000lY001R@@1W[@00jUD00?l0003TJ@00BJ@0001IB0002RD000@L000f@`00
R@00dJD00?/A003g9000aL@0001k7P008cP0008J000B;000J3/0O[<00>i7003o0P00gg/002nK0000
DTd000LQ00057P00Ad/06Y@00=Z;003n1P00lCX009Fi0000KC<001H_00026@007SD007LU0;W2003f
:@00o0l00=:S0000R@0003E200036`002bH005e605RX003XG000o`000>EW0018X`0005Q:00098`00
11d003i700n@003GT`00o@P00?8f002J^P0006hc000F;`000QT0020f001i8@35a000mb<00?/E003=
[`0008<=000[?@000aX0010Z001U?P[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07
ooooo`3o0011B0001b4000<K000S>000Kc40LJl00>EX003o1000mB`00<^e0008S@0004m>000:9000
0aX001`c001X>P1JZ@00h7H00?h8003g8P00cjT001JB0000Dd`000`V00026@00634006Dn04jU003N
O@00o@/00?PN003AY00079@0001EB`003BL0008I000G<000I3l0CJD00=in003m2P00n1l00=6V000I
T`0005A<000<9P000QX001Tb001W?01FZ000h7H00?h7003g9@00cJh000f?0000D4h000XT00036P00
7SD006`e06^^003UJ000o`<00?@`0037_P0008L40013B@001b4000<L000X>`00MBP0S;L00>YC003o
0000kd<00:Rn0000OAX0035100057@001Ql003Q400214@2j`P00lCX00?l1003WG`00Mk40001_<P00
83H000<J000:9000D4d04Y400=2X003h7`00o@`00=b4000oX@0005i4000B;0000QT001<]001Q@P18
X`00gWh00?d9003g9000c;4000N<0000BT`000PR00036`009c/007HW09>h003/C@00o`000>a>002A
^00007DX000V>P000a/000TR001=CP1]W@00n2000?d<003KQ`00>9h0001LA`003bX0008I000H<000
Ic`0GjX00>A[003o0`00lcD00;o30000PA8003E200057P001Ql003a600252037_P00mB`00?h6003P
N000C:D0001Q@P004b`0008I000E;P00I3l0EJP00>9a003n1000lc<00<;40000PA8003A200057@00
1Ql0041800280P3:]`00mRH00?d9003LP`00>il0001KA`003bT0008I000K<`00K3H0Lk000>QL003o
0000kTH009Rj0000MBL002Di00036`002R@005=<026G003FUP00na400?TK003@Z0002hh00019C000
1b4000@L000a@000OaD0_l<00?<b003n1@00h7H004ZT0000Gd@0010Z00026@006C8006/g07B`003Y
FP00o`000>a<002;]`00074^000O=P000QX000dX001JB00jW`00gH400?h7003e;000a/8000214@00
<d4000@M00078@00Bdd049000=:R003j5P00nQL00=6T000>S`0004U<0007800011d003E300243038
_000mRL00?d:003JRP00;9X0001EB`002RD000<K000X>`00NR00[kl00?8g003n1000h7H004FS0000
GDH000hX003c00026P0083H007<[09Ji003_@`00o`400>AY001HZ0000692000A:`000QT001/c001_
<P27]@00kD/00?l0003VHP00HZ/0001T?`004b`0008I000J<P00KC@0P[@00>a>003o0000if0006>/
0000I3l001</00026@006S8006hc08Je003]B`00o`000>IU001LZ@000691000A:`000QT001dd001a
;P2D^@00kd800?l2003SK`00BjD0001MAP003RP000<J000S>000Mb@0[;l00?8e003n1@00gGl003BM
0000ET/000XT00036`00;Sl0080C0<No003f9@00o0d00=JF000GT`0004]=000780001Ah003m700J<
003AY@00na@00?TL003</P0008H8000e@P0011`000TS001CC00/VP00g8@00?h6003c=@00Zkh0001f
9P008CL0008J000@:P00HT40HJ/00>QN003o0000jEP006Z^0000ICh0018/00026@007cH007DX0:Nm
003b=P00oPH00=b5000YV@00059=00088P0011d003]500:;003AYP00na@00?PO0039^000088@000^
?`001b4005Y804NS003SK@00o`400>a<001k/P0006Pj000D;@000QT001dd001d:P2V_@00lcD00?h7
003JRP008IH0001>CP001b0000DN0015BP0CT@00eiD00?d;003d;@00]L40001g900083L0008I000B
;000Ic`0N;400>a=003o0@00hW00046Q0000EdX000XT00047000=d<008T00=2V003k4P00mb800<K0
0000OAX002Hj00026P0042X006=006f^003[DP00o`000>=/0014XP0005Q9000:900011`003Q400::
003BXP00o1000?HW0030``0007TQ000Q=`000QT001<]001Y>@23]000kd@00?l3003NOP00:iX0001@
CP001b0000HO001:C00NUP00fhP00?h5003`?@00T;P0001/=@005Bh0008I000P=P00N2<0_/<00?HV
003k4@00d:H000280`00<d4000<K000<9P00GTD0GJX00>UI003o0000i6/004>R0000ETX000TS0004
7@00@DP04i400=R@003n1`00lCT009Bi0000K3D001D^00026@008CL007/N0<K1003h8000nQH00<bb
0000PQ4002Tl00036P004B/006Ll00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07
ooooo`3o000nA`001b4000<K000U>@00LBl0M[400>IT003o0`00m2h00<Vi0004R`0004e>000:9000
0aX001dd001Z>01OZP00hG<00?h7003g9@00cZ`001:A0000DTd000`V00026P006C8006Hm05>W003O
NP00o@T00?PQ003@Y`005i<0001DC00032H0008J000I<@00ISd0DZL00=mj003m2@00mb400<nY000D
TP00059=000;9P000QX001/b001X>P1LZ@00hG<00?h6003f9`00c;8000V=0000Cdh000TT00036P00
83H006hc072_003VI@00o`800?<c0036`@0008H70010B0001b0000@L000Z?000MbD0TKP00>]@003o
0000kTH00:>l0000Nad002lo00047@001Ql003Y500233P30``00lSL00?l2003VH`00LK00001]=000
7cD000<J000;9@00DTd05Y800=6U003i7@00o0d00=^8000jW`0005e6000A:`000QT001D^001R@@1<
Y@00ggX00?h8003f9`00bk@000>;0000Ad/000PQ00037000:C`007LT09Rj003]BP00o`000>]A002;
]P0007@Z000T>@000a/000TS001?CP1`W000n1d00?`>003JR`00=9d0001JB0003bT0008I000I<@00
J3X0I:`00>EX003o0P00lSP00;W20000OaD003=100047@001Ql003m700271@39^P00mBX00?h7003O
N`00Aj<0001P@`004R`0008I000F;`00ICh0FjT00>=]003o0`00lSD00;c20000OaD0039100047@00
1R000499002:003;/`00mb@00?d;003KQP00=Yh0001JB0003RP0008J000L=000KC@0NK800>UI003o
0000kDX009>h0000M2X002<h00036P002bD005E;02JH003GTP00o0l00?PN003>[0001h`00016B`00
1b0000@M000c@@00PA80a<@00?@_003n1P00ggX004FR0000GTD0010Z00026@006c<006`e07Vb003Z
E`00o`000>a?0026]@00070`000N=@000QX000hX001LA`0oX@00gWd00?h6003d;`00a<@000205000
<40000@L00088@00CTh059800=>O003k5000nAT00=2W000:SP0004I;000780001Ad003Q400252@39
^@00mbD00?d<003IS@009iT0001DC0002R@000<K000Z?000Nad0]L400?<d003n1@00ggX0042Q0000
FdL000dX003c00026P008CL007@Y09bk003`@000o`800>=/001CY`000613000@:P000QT001dd001`
<02=]`00kTP00?l0003UI@00GJX0001S@0004R`0008I000K<`00KS80R;D00>e:003o0000iV@005jZ
0000Hd00018/00026@006c<006la08bg003^A`00o`400>EX001FZ0000613000@:P000QT001le001c
:`2J^P00l3l00?l2003QLP00Aj<0001LA`003BL000<J000U>@00NB40//000?<c003n1P00g8<002nK
0000ED/000XT00037000<400088@0<Rk003g8`00o0l00=FJ000CT@0004Q<000680001Ah0045900Z>
003BX@00na<00?PO003;]P0008@;000c@@0011`000TS001DC00`W000gH400?h5003b=`00YKd0001e
:0007cH0008I000A:`00I3l0IZ`00>QJ003o0000j5/006F/0000Hd00014[00026P008CL007HV0:bo
003c<`00oPL00=^8000UV000051>00078@001Ad003e700J<003BXP00na800?LQ0038^`00080C000/
?@00224005a704bU003TJP00o`000>a?001f/@0006Ll000C;0000QT001le001e:02/_`00lc800?d8
003IS@007ID0001<C@001R0000HO0018C00HT`00f9400?d:003d<000[kl0001f9`007cH0008I000C
;@00J3X0OK<00>e9003o0@00hG@003bP0000ET/000TS00047000>D@00h/00=:S003k4@00mbD00<G3
0000O1d002@i00026P004B/006Dn07:`003/C`00o`400>9`0010X@0005M:00098`0011`003Y500J<
003CWP00o0h00?DY002j`P0007PS000P=P000QT001@^001Z=`29]P00kd400?l4003MPP009YP0001?
CP001R0000HO001=CP0SU`00g8@00?h4003`@000R[H0001Z=`0052d0008I000Q=`00NR00a<@00?LT
003k4`00cjT000261`00<40000<K000=9`00Gd@0HZ/00>YF003o0000hfh003jP0000ED/000PR0005
7P00A4X05i<00=V<003n1P00lC`008jg0000JcL001@]00026@008cP007`K0<Nn003h7P00nQP00<^e
0000P1@002Lk00026P004R/006Pj00[ooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Sooooo00?o0000ooooooooool01oooool0o`00?4H000LP00047000
9SX0078/07bb003WH@00o`800?<a0038_0000HX0001:C@002B<000<J000O=@00JcH0I:`00>9_003n
1P00mRL00<f`000>S`00055=000;9@000QX001/c001X>`1HZ000h7H00?h8003g8`00cj/001>A0000
DTd000/V00026P006S8006Ll05NX003PM`00oPP00?LT003>[0004900001AC@002bD0008J000L<`00
JST0HJ/00>9_003n1@00mBX00<^e0005S00004a=00098`000a/0024g001_<@1f/@00iV400?l2003b
=P00a<@000242`00?TL000HP00047000:cd007PS09Ni003/C@00o`000>e:002M^`0007XP000]?P00
11d000HP000mAP00Q0/0aL@00?<d003o0P00iFH006b^0000K3H001dd00026P002bD005=<01ZD003B
XP00nA/00?`?003JR`00=Id0001LA`0042X0008I000F;`00I3l0DZH00>1g003n1P00mBT00<Zh0000
R@0004A:00078@0011`002/m001i8@2N^`00kTL00?l0003ZE@00QKD0001b;@008cP000<K000:9000
DDd0Li/00?TK003l3`00fHh002nK0000FDT000hX00026@006S8006Xh06Z]003VI000o`400?4k002c
`00007hH000a@00011d000HP0011B000R@40b[L00?HW003m2000gWl004:R0000GTD0014[00026@00
5c0006Ll062[003TJP00o`800?8h002f`@0007hH000`@00011`000LP0015BP04R`00cK000?LQ003m
3000fXX0036L0000FDT000dW00026P007SD006lb07jc003ZE@00o`000>a=002=]`00078/000Q=`00
0aX000`V001FB`0ZVP00fHl00?`>003h8000cJl000>;0000@dT000HP00057@00=D80088?0<K1003e
;@00oPL00=im0010X@0005a6000?:@000QT001`d001^<`1o/`00jU<00?l0003[DP00P;@0001^<P00
73@0008I000?:@00GDH0A:800=mi003n1@00lc400;k30000OQL002ho00047000228004m>01RC003D
V`00na800?TK003?ZP001X`00013B@001Ql000DN000jA@00Q`H0b[H00?LR003l3@00f94002>G0000
DTd000TS00036`00;3d007dJ0;_2003c<@00oPH00=im000kW`0005Y8000=9`00A@000aX002<h001f
9P2R_000l3d00?l2003RL000CJD0001OA0003bT0008J000N=@00LRd0T[P00>i5003o0@00i6P005NX
0000HD80014[00026@0073@0070`08fg003^A`00o`400>EW001IZ@000652000A:`000QT001dd001a
;P2B^000kT@00?l1003TJ`00DJH0001OA0003bT0008J000P=P00M2T0X;`00?4l003o0`00h7H004:Q
0000FTP000`W00036P009c/007/N0;S2003d<000oPP00=^6000[VP0005=<00098`0011`003910023
3@3:^000n2400?/A003DW@003i000015BP0200067`110014BP0>S`00dih00?/A003h8@00bKT00023
3P00<40000<L000:9000ET/0=Id00=im003n1000lCX00:2l0000Lb/001he00026@004R`006Dn06b^
003YE`00o`000>MN001PZ`000691000@:P000QX0028h001h8`2b`000m3000?d8003IS00089H0001?
CP001b4000DN0010B00:SP00dil00?`@003g8`00akl0001o5P00:S`000PQ001MAP1AYP00iFL00?l0
003[DP00L:l0001U?@004R`0008I000P=P00MbD0//000?@_003m2P00f94001RC0000BD`00P001Ql0
J@00Bdd079D00=V>003m2000lc<00:Zn0000M2T001de00026@0052h006Xh08>d003^AP00o`800>1g
000gWP0005E;00098`0011d003]600J<003CW`00o0l00?HW0031a00007XO000S>0000QX0018/001V
?01g/@00kD`00?l1003QL`00>il0001EB`002B<000@M000mAP0:SP00e9/00?`=003e;000]<40001f
9P007SD0008I000E;`00K3D0S[L00?0n003n1@00g8D002:G0000CDh000HO00068000Cdh09iT00=f1
003o0`00kd<008Be0000JCT001<]00026@008cP007/M0<K1003g8P00na@00<j]0000Q@X002ho0003
6`003RP0065206R]003[DP00o`000>9b000iW`0005A<00088@001Ah004I;01^D003JR@00oPD00?0o
0029]P0006Ti000C;0000QX002Di001n6039^`00nA`00?TK0039^@0007hG000V>P000QX001</001Z
>00:ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo0?l003U500067`0011`002Pk001d:P21]000j5d00?l2
003c=000akl000280P00Ad/000PR00036`0083H006dd06Z]003TK000oPD00?DZ003;/`002Xh0001?
CP002R@000<J000L=000JCT0GZX00>5c003n1`00mRD00<f^000?T000055=000;9@000QX001/c001Y
>P1LZP00hG<00?h7003f9P00cK0000b?0000D4h000XT00036P007CD006/g06J/003SK000oP@00?D/
0039^@000XX00019C000228000<K000S>000LBl0Nk800>MN003o0@00lST00;k30000P`h003]50006
7`0011d002hn001j802M^`00kDX00?l0003/C@00UkX0001h8`00:cd000@L00078000@4P008H70<K0
003c<@00o`<00>AY001W[@0006Xh000L<`000QX000`V001EC00NU@00dih00?XI003l4000f8l0036L
0000FTP000lY00026@005c0006Dn05NX003QL`00oPD00?D/0038^`0008P30011B@001b0000@L000]
?P00NQl0Y;d00>m4003o0000jEP0082c0000L2l0024g00036P002R@0059=07FJ003i6@00na400=NB
000ZVP0005M:000=9`000QX001`c001[=P1_[`00if400?l1003`?P00[Kl0001l6`00;Sl000@L0007
8000A4X00HX00<^d003g9@00o@X00=f2000mX00005e6000@:P000QT001Pa001X>P1U[000iFH00?l2
003a>`00/<00001l6`00;Sl000@L00078@00B4`028d00<j]003h7`00o0h00=V>000]V`0005M:000<
9`000QX001lf001`<024]@00je800?l0003[D000QkD0001a;`0083H0008J000<9`00EdX0;i/00=Z;
003m3000mb800<bc0000R@00041800067`001Ah003M400243037_P00mBX00?h8003MP@00>il0001K
A`003RP0008J000N=@00Kc40QKD00>]@003o0000jUH007^b0000KCD001/c00026@0042X005i404VT
003PMP00oP@00?<d002h`@0007dJ000/?P000a/000TS001AC@0LU@00eYL00?/A003h7@00cJh000::
0000@DP000HO00057P00?DH008P20<bb003h8000o0l00=NE000OUP00055=00098`0011`002ho001o
5`31a000m2l00?h7003MP@00=ih0001HB@0032H00?<000<J000U>@00N2@0Z;h00?4j003o0`00hG<0
04RT0000GDH000hY00026P0083H007<[09Rj003_@P00o`400>=/001BY`000613000@:P000QT001he
001a;P2C^000kd@00?l1003TJ`00DjL0001P@`0042X0008J000N=@00LR`0UkX00>m1003o0P00hVl0
04bU0000GTD000hX00026P008SL007HV0:Jm003a>@00oP@00=mi000mX00005U9000<9P000a/002Tl
001l6`2n``00m2d00?d9003JRP009YP0001BC@00228000@L000d@P00Q@T0bkD00?PN003k4`00dZ40
00^>0000@dT000DO00067`00Ad/04Y400=FJ003l3`00mb<00<Rl0000PA8002ho00036`002RD005M:
03ZO003ON@00o`<00?0m002J^P00078]000L=0000QT001<]001W?01a[`00jU@00?l0003VHP00FjT0
001P@`003bT0008J000T>@00NB40^<800?@^003m2P00f90001bE0000CDh000LP00057P00@dT03Xl0
0=BK003l3P00mRH00<G20000OAT002Pk00098@00GT@0EZP00>IS003o0000jUH006^^0000I3l0014[
00026P008SP007PR0;S1003e;@00o@/00=ND000DTP0004I;00057`001R0004i>022F003JRP00oPL0
0?8e002T_@0007</000L<`000QT001H_001[=P28]P00kd<00?l3003ON`00<Yd0001CC000228000@M
000nA`0:SP00e9`00?`=003e:P00^l80001h8P008CL0008I000C;000J3/0OK<00>e9003o0P00h7L0
03JN0000E4`000PR00057@00?dP03Xl00=JG003m2`00m2l00:jo0000MBT001dd00026@005Rl006hc
09Bi003a>`00oPH00=Z9000NU@0004Y<00067`001b00051>02bJ003NO@00o`<00>i6001o/`0006Lk
000B;0000QX002Di001m6P37_P00n1l00?XF003=/00008<=000/?P000aX000hY001R@@1][P00k4l0
0?l1003QM@00=9d0001BC@001b4000DN0019C00PUP00g8D00?h4003_@P00Pk@0001X>`004R`0008J
000W>P00OaD0b[L00?TJ003i7@00b;`0001m6P0093T0008I000D;@00JcL02_ooool1o`00007ooooo
0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool4o`0000Kooooo
0?l003M300067`0011`002Xm001e9`27]@00jEX00?l1003b=`00aL<000271P00A4X000PR00036`00
8SL006lb06n_003UJ000o`@00?D/003:]`001X`0001>CP002R@000<J000N=@00JcL0Hj`00>9_003n
1P00mRP00<bb000;SP00051>000:90000aX001dd001Z>01RZ`00hVl00?h5003f:@00bk<000R=0000
CTh000XT00036P007cH006dd06b^003TJ000o`<00?@_0038_00008T10016B`00228000<K000U>@00
LR`0PK@00>QJ003o0@00lC`00;S20000PA8003U400067`0011d00310001k7@2S_000kTH00?l0003[
D000TKP0001f9P00:C`000@L00078@00@TT008L40<Rm003d;`00oP@00>=]001QZ`0006Tj000J<P00
0QX000dW001FB`0SU`00eIX00?XF003k4P00ei<002bJ0000FDT000hX00026@00634006Ll05bZ003R
K`00oP@00?@_0037_P0008H7000oA`001R0000@M000_?`00O1`0Z[h00?10003o0000j5/007Zb0000
Kc4001lf00036P002bD005=<07VI003j5`00na<00=JF000VV00005I;000<9P000QX001dd001]=01e
/000j5h00?l0003_@@00Ykd0001k7P00;3h000@L00078@00Ad/01H`00<f`003g8P00o@/00=^6000h
WP0005]7000?:@000QT001Tb001Z>01[[P00iV<00?l1003`?P00Z[h0001k7P00;3d000@L00088P00
Bdd038h00<nY003i7@00o0l00=RA000XV@0005I;000<9P000aX0024g001b;@2:]P00k4l00?l0003Z
D`00PK@0001_<@007SD0008J000=9`00FDT0=9d00=^7003m2`00mbD00<Zf0000R0<003i700067`00
1Ah003Y500262039^`00mRL00?d9003LQ@00=Yh0001IB@003BL0008J000O=P00LBh0R[H00>a=003o
0000jET007Fa0000JcL001Tb00026@004B/0061304jU003QLP00o`<00?8g002b`00007/M000Z?@00
0a/000TS001BC@0QUP00ei@00?`?003h8000c;4000290@00?TL000DN00067`00?dP00HX00<f_003h
7P00na400=FH000JU000051>00088P0011`0031000205035``00mB`00?d8003LQ@00<Y`0001GBP00
2bD006`000<K000W>P00NB40[[l00?8g003n1000h7L004>R0000G4L000hX00026P008CL007DX09jk
003`?`00o`800>9`001=Y@0005i5000?:@000QX001lf001c:`2I^P00kd400?l2003SKP00CZD0001N
A0003bT0008J000P=P00M2X0WK/00?0n003o0P00hG<004NS0000G4H000dX00036P0093T007PT0:bo
003b=P00oPD00=im000hWP0005M:000;9@000a/002/m001n6034a000mB/00?d:003ISP008YL0001A
C@00228000@M000g@`00Q`H0c;400?TL003k5000dJ@000N<0000@4P000DN00068000BT`05Y800=JG
003l3@00mRH00<K00000OaD002`n00036`002bD005U903nQ003PMP00o`<00?10002D^@00070`000K
<`000QT001@^001X>P1g/@00je000?l0003UI@00EJP0001OA0003RP000<J000V>P00Nah0_/<00?D[
003m2`00ei<001RC0000BT`200067`250016BP0BT@00eYL00?`=003f:@00`l@0001l70009SX000TR
001P@`1LZ@00if000?l0003YF@00IJ`0001R@@0042X0008J000T>@00NQl0_/<00?DZ003l3000eIP0
012@0000@dT000DN00078000D4h09IP00=^6003n1P00lSP009jk0000LBh001Xb00026@005c0006dd
08jg003`@000o`<00=in000^V`00059=00088@001Ah0045800j?003EV000o@`00?D/002e`@0007LU
000O=P000QT001@]001Y>@23]000kTD00?l2003ON`00<I`0001BC@00224000DN0012B@0BT@00ei@0
0?d:003c<@00Z;h0001c:`006c<0008I000H<000Kc40V[X00?8h003n1`00fHd001VD0000Ad/000DN
00078@00DTd0<9`00=mj003o0P00kDT007Vb0000ISd0014[00026P009SX007hG0<Rk003i7@00nQP0
0<^d0000PQ4002Xl00036P003bT006@o07>`003/C000o`800=mi000`W000055=000780001Ql004a=
02BH003MPP00o`<00>i5001m/`0006Hl000A:`000QX002Tl00214P3;]000nQP00?PO0037_`0007/M
000R>0000QT001D^001]=007ooooo`Co00000Oooool000Oooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo04<003A200057P0011d002`n
001g902=]`00jUH00?l0003a>P00`/@000252@00@DT000LQ00036`0093T0070`07Fa003VI000o`<0
0?@_0039^P000XX0001;C@002B<000<J000O=P00K3D0JJd00>=/003n1@00mB/00<^e0007S@0004i>
000:90000aX001he001/=P1W[@00hf`00?h4003e;000b[L000B;0000Bdd000TS00036`008CL006hb
076`003UI@00o`<00?<b0037_`0008L50013B@001b4000<K000W>P00M2X0QkD00>UG003o0000l3l0
0;;00000OaD003I3008000DN01T00391001m6P2Y_P00kd<00?l0003ZD`00RkH0001e:0009c/000<K
00088@00ADX008T00<Vi003e;000oPD00>9a001LZ@0006Lk000I<@000QT000dX001GBP0WV@00eYL0
0080na@00?l0eYH002NI0000EdX000dX00026@006S8006Pj066[003SK000o`<00?<a0036`P0008@;
000lAP001Ql000@M000a@@00OQT0/<000?0m003o0@00iel007B`0000KC@001he00026P0032H005E;
07^I003j5@00naD00=FI000QU`0005E;000;9P000aX001le001_<P1j/P00jEX00?l0003_A000XK`0
001i8@00:Sd000@L00088P00BT`02Hd00<j]003h8000o0d00=Z:000cW@0005Y8000>:0000QT001/c
001[=P1`[`00iel00?l0003_@@00Y;d0001i8@00:S`000<K00088P00CTh049000=6U003i6P00na40
0=JE000TU`0005A<000;9@000aX0028h001c:`2@^000kD/00?l0003YE`00O;80001^<`007C@0008J
000>:000FTP0>9h00=b4003m2@00mRL00<Vj0000QPL003]500057P001Al003e600271@3:]`00mbD0
0?d;003KR000<I`0001HBP0032L000<J000Q=`00Lb`0T;P00>e9003o0000j5`006n_0000JST001Pa
00026@004R`0065205>W003SK`00o`<00?4j002/_`0007XP000X>`000a/000XT001DC00UV000f900
0?`=003g8P00bkD000271000>dH000DN00067`00@TT01H/00<j[003i6`00na<00=BL000FTP0004i>
00088@0011`0039100224036`000mBT00?d:003KR000;I/0001EB`002RD000<K000Y?000Nah0]<00
0?<d003n1@00gg/003jP0000FTP000dW00036P008cP007HV0:Bm003a?000o`<00>5c0018X`0005e6
000>:0000QX0024g001e:@2O^`00l3h00?l2003RLP00BJ@0001MAP003RP0008J000R=`00MRL0Xkd0
0?4k003o0`00h7H004:R0000FdP000dW00036P009CX007TQ0;;0003c<`00oPH00=f1000cW@0005I;
000:90000a/002dn001o5@36`@00mRP00?d<003HT@007ID0001?CP001b4000@M000iA@00R080cZh0
0?TJ003j5P00d:P000>;0000?DH000DN00078000CDh06Y@00=NC003m3000mRP00<G30000OQP002Xl
00036`0032H005Y804BR003RLP00o`800>m4002>]`0006hb000I<P000QT001D_001Z>01l/`00k4d0
0?l0003TJ@0000`0D:H0001MA@003BL000<J000X>`00OA/0a<@00?HX003l3@00eYL001>A0000Ad/2
00067`1Q0019C00FT`00ei@00?d;003e:`00_<<0001j7`0093T000TR001Q@P1QZ`00j5`00?l0003X
G@00H:/0001Q@P003bT000<J000V>P00O1`0a<@00?HW003l3P00e9`000b>0000@4P000DN00078@00
DDd0:IT00=b3003n1@00lC/009Rj0000L30001Ta00026@00634006hb09Bi003`?@00oP@00=f2000Y
V@00055=00078@001Ah004A:01>A003GU000o@X00?@_002__`0007DX000N=@000QT001D^001[=`28
]P00kd800?l3003NOP00;9X0001AC@001b4000DN0015BP0FTP00f9000?d8003c=000X[`0001a;P00
6S80008I000I<@00LBl0X;`00?8e003m2000f90001FB0000A4X000DN00088@00Dd`0=Id00>1f003o
0@00k4`007>`0000I3l0010Z00036P00:3/0080D0<Zg00020?TK000R0<Zg0000P1@002Pk00036P00
42X006Dm07Ra003]B@00o`800=im000[VP00051>000680001Ql004m>02VI003NOP00o`800>e8001h
/@0006Dn000@:P000aX002/m00233`3=/000nQD00?LQ0035``0007XP000P=P000QT001H_001^<P[o
oooo0Ol00001ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool0@`00<T4000DN00057@00;cl007TR09>h003[D`00o`000?0m
002k`P0008<=000oA`001b4000<L000U>P00LRd0Nk800>MQ003o0P00lc800<Nn0000R@4004Q;0008
8P000a/0024g001^<`1^[`00iFP00?l4003d;@00bKT000>;0000Bdd000TS00036P0083H006dd06f^
003UJ000o`<00?@^0039^P0008X00018C000228000<K000R>000L300Mk400>MQ003o0P00lcD00<G3
0000Q@P004180007800011`002Tl001f9`2=]`00jU<00?l0003_@P00[;l0001n6000=4800P001Ah0
o`00=48007hG0:no003`@000o`000>UG0025]@0007<[000U>P000a/000PR0018C003R`00b[H00?HY
003n1P00hG@005JX0000ISd001L`00026@003RT005U902bJ003GT`00na800?XF003EVP008iL0001F
B`0032L0008J000K<`00JSP0Ijd00>EX003o0`00lc@00<?40000P`h003U500067`001Ah003A2001o
5@2f`@00lCX00?l1003VHP00Kjl0001/=P0073@0008J000<9`00ET/0OYL00?/C003j5`00e9d001fE
0000Dd`000/U00036P0083H0070_082d003ZE`00o`000>i7002K^`0007LT000X>`000a/000PR001=
CP0=S`00cjT00?PM003l3P00fHh002jK0000F4T000dW00026P0073@006dd07Ja003XG000o`000>i5
002N^`0007LT000X>`000a/000TS001@CP0DTP00dZ800?XH003k4`00eIT001nF0000Dd`000XT0003
6`0093T007DX09Ji003]B000o`000>QJ001f/@0006`e000K<`000QT000lY001LA`0mX000gH000?h8
003e:P00akd000242`00>4@000DN00067`00?dP008T10<^d003g8P00o@`00=V<000/VP0005I:000<
9P000aX002<h001d:@2F^@00kTH00?l0003WH000JZd0001X>`005c00008I000C;@00Hd00F:P00>A[
003o0P00l3d00:Fm0000N2<002Hj00036`002bD005E;02ZJ003IS000o@`00?LU0039^00008H8000i
A0001Ad000HP0015BP09S@00d:P00?TI003k5000dj00016A0000Bdd000LQ00047@00=D8008<=0<Rl
003f9`00o@/00=V<000XV@0005A<000:90000a/002/m001l6`2j`P00lc400?h6003NOP00>Il0001I
B@0032H000<J000U>@00N2<0Z[h00?8h003o1000h7L004>R0000FdL000dW00036P008cP007HV0:Fm
003a>`00o`<00>5e0014XP0005]7000=9`000aX002@i001g902Y_P00lSP00?h4003ONP00?J00001I
B@0032H000<J000W>`00Nah0^<400?@a003n1`00g8D002jK0000ED`000XT00036`00;cl0084B0<Nn
003f9@00o0d00=JE000IT`0004e>000780001Ad003a6006:003?ZP00nQP00?XI003>[00008T0000j
A@00[P001Ad000LQ001?CP0OUP00f8l00?d:003e:`00`L@0001l6`00:3/000<J000=9`00G4L0BJ@0
0>=^003o0@00kTL008Rf0000KC@001Pa00026@005c0006/f08:d003]BP00o`400>=/001;Y00005a7
000<9`000aX002Xl001n5`36`@00mRH00?`>003DV`003i000014BP001Ah000HP001<C@0KU000f900
0?d:003d;P00]/40001h8P008SP000TR001S@01W[@00jEP00?l0003WH000FZT0001OA0003RP000<J
000W>`00OAT0a/400?LU003l4000dil000R=0000?DL000DM00088P00DTd0;Y/00=io003o1000l3l0
09:h0000KS<001P`00026@006C80070`09Zj003a>P00oPD00=^6000TV00004m>000780001Al004M;
01NC003HT@00o@T00?<b002Y_P0007@Z000L=0000QT001H_001]=@2>]`00l3l00?h4003MPP00:9T0
001@CP001b0000HO0018C00KU000fH`00?h7003b=`00W;/0001`<0006340008I000J<P00LR`0Y[d0
0?<b003m2@00ei@0016@0000@DP000DM00088P00ED`0>Yl00>5b003o0@00je0006j_0000Hd0000lY
00036P00:Sd0088@0<^d003j6000nAd00<Rk0000OQL002Hj00026P004B/006Ll07jc003^A@00o`<0
0=f0000VV00004i>00067`001b00051>02jK003ONP00o`800>e<001b/00006=0000?:@000aX002dn
00242`3>[@00na<00?LT0031a00007PS000O=@000QT001L`001`<0[ooooo0Ol00001ooooo`001ooo
ool01?l0003oooooooooool00008ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`1^000_
?`001Ah000DN000a@000NQl0VKX00>]?003o0000l4000;G10000PQ0003a60007800011`002Lk001c
:`21]000j5d00?l1003b=@00a/4000271@00ADX000PR00036`008cP0070`07B`003VI000o`<00?@`
0038_00008T00018B`00228000<K000R=`00Kc40Lk000>IT003o0`00lc400<Nn0000R08004E:0008
8P000a/002@i001a;P1m/`00j5h00?l1003b>000`L@000243000?DL000HP00047000:cd007LT09>h
003[D000o`000>i5002V_@0007`K000a@0001Ad000DN000g@`00P1@0]L400?0m003o0@00j5X0082c
0000LRh002<h00036`002B<004a=00N<003</P00mRH00?h7003PN000DJH0001T?`005Rl0008I000?
:@00FTP0<I`00=R?003k4@00nQP00=>N000NU@0005A<000<9P000QX001`d001/=P1][P00iV@00?l2
003b=`00_L<000214P00=d<200057P1o000f@`00PA80_<<00?8g003o0P00iFH006V]0000JSP001/c
00026P003BL005Q:086F003k4@00nAT00=:Q000HT`00059=000:90000aX0028h001b;@26]@00je<0
0?l0003]BP00UKT0001f9`009SX000<K00098`00Cdh04Y400=6U003i6`00o1000=RA000ZVP0005M:
000<9`000QX001he001^<P1l/P00jEP00?l0003^B000V;X0001f9`009SX000<K00099000DDd06I<0
0=>N003j5P00nQD00=BL000JU000055=000:90000a/002Hj001f9@2L^`00kTD00?l0003WGP00L:l0
001Z=`006S80008I000@:P00GDD0@j800=il003n1`00mBd00<K10000P`h003I300057@001R000499
00::003=/000n2000?`>003HT000:9T0001EB`002bD000<J000T>@00MRL0W;/00>m3003o0@00iV@0
06B/0000IS`001D_00026@0052h006Dn05jZ003UI`00o`400>m1002O_00007HV000T>@000aX000/V
001FBP0_V`00fhT00?d:003f9`00b;`000243000=T<000@M00078000B4`03Hl00=6T00020?XG003o
0=6S000=S`0004Q<000780001Ad003M400252@39^@00mb@00?`=003HT00099L0001BC@002B<000<K
000]?P00OQP0`<<00?@_003n1`00gH8003BM0000EdX000/U00036`009c/007XP0;70003b=@00oPD0
0=mk000nX00005Y8000<9`000aX002Di001h8`2[_P00lSP00?h4003ON@00?j40001JB00032L000<J
000U>P00NB40/<000?<e003n1@00gWh003RN0000F4X000/U00036`00:C`007`K0;k3003d;P00o@P0
0=^8000YV@0005=<00098`0011`0035000233P39^P00mb<00?`?003EV@005980001:C0001R0000DN
000oA`05S000d:H00?XF003i6`00cJl000271000>4@000@M00088P00DDd08iL00=Z<003m2@00m2h0
0;[20000Nah002Hj00036P003BP005e604jU003TJ`00o`400>e:0022]00006/f000G<0000QT001Pa
001]=028]P00kTH00?l1003RL000AJ<0001JB00032H000<K000/?@00P1@0akd00?LS003l4000dih0
00^>0000@DP000DN00078000Cdh07iH00=V<003m2000m3400;300000MbD0024g000:8P00ICh0K:h0
0>YE003o0000iV@005FW0000GTD000dW00036P00:S`007lF0<Nn003g8P00na800=6S0004R`0003]5
00047@00228005A<03>M003ON`00o`<00>m2002<]`0006`e000F;`000QT001/c001b;@2P_000lSL0
0?h7003JRP0089H0001=CP001R0000HO001:C00KU000fHd00?h8003b=@00X[`0001b;@006c<0008I
000G<000KS80U;T00?4l003n1@00fhH002>G0000CTh000HP00067`00Bdd07iH00=^9003n1P00lCX0
09Ji0000KS8001L`00026@0073@007@Z0:bo003d;`00o@/00=FH000<S`0003i700047@002B<005I;
03nQ003SK`00o`000>YC001X[@000652000>:0000aX002dn00233@3=/000nQH00?PO0037_P0007dK
000T>@000QX0018/001Y>P24]@00kd800?h4003LQ0008YL0001;C@001Ql000LQ001BC@0bW@00h7H0
0?l1003/C`00K:h0001R@@003RP000<K000_?`00QPP0cjT00?/B003f9`00^l80001f9P007C@0008I
004001Ta0@00LBh:ooooo`7o00000Oooool000Sooooo0_l0000:ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool0o`00;Ch000@M00057P00<d8007`L09nl003/C000o`000>m3
002__`00080D000iA@001Ql000@L000Y?000MBP0QkD00>UJ003o0@00lSP00<C40000Q@P004990007
8@000a/002Di001a;P1j/P00if400?l2003c<`00a/0000271000ADX000PR00036`008cP0074_07Vb
003WH@00o`800?<d0036`@0008H60012B@001b4000<K000V>P00Lb/0Pk@00>UJ003o0@00lC/00;_2
0000PQ0003Y500067`0011d002dn001i8@2I^P00k4d00?l0003]B@00Wk`0001j7P00;cl000@M0006
7`00>TD0088@0;c2003a>P00o`400>MN001j/P00070`000R=`000a/000TS001?CP0;SP00cJl00?LT
003m2@00gg`004^U0000HT4001D^00026@0042X005a703JN003JR`00o0l00?TK003BXP006I@0001C
C0002bD000<J000N=@00KC@0Lk000>MQ003o0@00lC/00;K10000OaD003A200057P001Al003U40023
3`33a000lc@00?l3003TJP00Hj`0001Y>P006C80008I000>:000FDT0Q9D00?`?003i6`00dJ@001BB
0000D4h000TT00036`0093T007<Z08bg003[D000o`000>a>002?]`0007@Z000T>@000a/000XT001A
C@0FTP00dZ400?XI003k4P00eYD002FH0000ED/000`V00036P0083H0070`08:d003ZE000o`000>e;
002A^00007@Y000T>@000a/000XT001CC@0MU@00eIX00?/D003j5`00dj0001JB0000D4h000TS0003
6`00:3/007PS0::l003_@@00o`400>IR001Z[P0006Ti000H<@000QT0014[001OA018X`00h7P00?h5
003d<000aL@000214P00<d8000@M00078000ADX01X`00<j/003h7@00o1000=ND000SU`0005=<000:
90000a/002Hj001h902S_000l3l00?l1003UI`00GZX0001U?P0052h0008I000E;P00ISd0I:`00>IT
003o0@00kd@009Vj0000MBT0028h00036P0032H005Q903BM003LQ@00o@T00?DZ0037_`00088?000c
@P0011d000LQ001;C@0AT@00dj000?XE003j6@00d:L000V=0000ADX000HP00057P00>TD008L50<^e
003g8@00o0h00=ND000OUP00055=00098`00l`0011`002lo00205035``00mB`00?d8003KQP00;i/0
001FB`002bD000<K000Y?000Nad0]l400?<b003n1P00gWh003RN0000F4T000`V00036P009cX007XP
0;70003c=@00oPD00=im000jW`0005Q9000<9P000aX002Lk001k7P2f`@00lc800?h6003MPP00<id0
001FB`002RD000<K000[?@00OQP0a<@00?D[003m2P00fH`002BH0000DTd000PR00047000=48008@;
0<Zg003h8000na400=BM000@T00004M;00067`001Ah0049900V=003BX`00na@00?PM003</`0008H8
000e@`0011`000PR001BC@0XV@00fhP00?h8003d<@00]<40001i8@0093T000<J000>:000Gd@0E:L0
0>EW003o0000k4h007bb0000JSP001D_00026@006C8006hb08jg003_@`00o`800>5d0010X@0005U9
000;9@000a/002ho00224@39^P00n2000?/B003BXP001h`0000nA`001Ad000LQ001@CP0TV000fhP0
0?h7003c=000Z[h0001e:0007cH000XS001V?@1b/000je400?l0003UJ000CjH0001LAP0032L000<K
000/?@00PA<0bKX00?PP003k5000d:L000290000>4@000@L00098`00ED/0>9h00>1g003o0P00kTD0
08Je0000JcL001D^00026@0073@007<[0:Jm003c=000oPP00=V=000KU00004Y<00067`001R0004e>
022F003JR@00oPH00?8h002L^`00070_000I<P000QT001Ta001`<02K^P00lST00?h6003JRP007YD0
001;C@001Ql000HP001>CP0TU`00g8D00?h5003`?P00T;P0001]=@005Rl0008I000N=@00MRL0/l00
0?D/003l3@00e9`000R=0000>dH000@L00098`00F4X0A:800>A[003o0000jEL006:[0000H4<000dW
00036`00;cl008D90<j/003k5000mb800<K20000Nah0028h00026@004bd006Xh08Zf003`?`00oPD0
0=^8000MU@0004Q;00057P001b4005=<03RN003QL`00o`400>]C001V[0000613000=9`000a/00350
0028103AY@00o1000?DY002e`@0007DX000K<`000QT001Xb001c:`0:ooooo`7o00000Oooool001ko
oooo00?o0000ooooooooool01oooool0o`00:cd000@M00067`00=T<007hH0:Jm003]B000o`000>i7
002X_P0007hG000g@`001Ql000@M000/?@00MbD0SKL00>YF003o0000lC/00;k30000Q0`003m70007
800011`002Hj001c:`20/`00j5d00?l1003b=P00aL<000262000@TT000LQ00036`009CX0078/07nc
003XG@00o`400?8g0034a00008D:000oB0001b0000@L000X>`00MBP0RKH00>YF003o0000l3h00;C1
0000P1<003Q400067`0011d002lo001k7P2O_000kDT00?l0003/C000VKX0001i8@00;Ch000@L0006
8000?4H008@<0<;4003b=`00o`800>IR001d/00006hb000P=P000aX000XT001@CP0?T000cj/00?LQ
003m2P00gH0004JS0000HD8001@]00026@004B/005e503^O003KQ`00o0d00?TM003AY@005I80001A
C@002R@000<J000P=P00Kc40NK800>QM003o0@00l3h00;300000OQP0039100057@001Ql003a60024
2`36`P00lc400?l4003SKP00GZX0001W?0006340008I000?:@00FdL0Qi@00?`=003h7P00d:P000n@
0000Cdh000TS00036`009SX007DX09:h003/C000o`000>]A0029]P00078/000R>0000aX000XT001B
C@0KU000dih00?XG003k5000eIT0022F0000E4`000/U00036P008CL0078]08Rf003[D@00o`000>a?
002;]P00078/000R>0000aX000/U001DC00RU`00eYH00?/B003i6@00dJ@0016A0000Cdh000PR0003
6`00:Sd007XP0:Rn003`?P00o`400>EU001T[00006Lk000G<0000QT0018/001Q@`1=Y@00hG@00?h4
003c<`00_l<0001o5@00<D0000@L00078@00B4`02Xh00=2X003i6`00na400=JG000NU@00059=0009
90000a/002Pk001i8@2Y_P00lC`00?l2003TJ`00FJT0001S@0004bd0008I000F;`00J3/0JJd00>MP
003o0000kTL009>h0000Lb/0024g00026P003BL005U803VO003MP@00oPL00?D]0035``00084C000a
@00011`000PR001>CP0FTP00e9`00?/C003i6`00cj/000F<0000@TT000HO00057P00?DH008P20<ba
003h7`00o1000=JH000JU000051>00088P00>`0011`0035100214@36`000mRT00?d:003JRP00:YX0
001DC0002R@000<K000[?@00OAX0_L<00?@_003n1`00gH8003>M0000EdX000/U00036`00:C`007/M
0;S1003c<@00oPH00=f1000dW@0005M:000;9@000a/002Tl001l6`2l``00m2l00?h8003LQ@00;Y/0
001EB`002R@000<K000^?`00P1@0a/400?HX003m2`00f900022F0000D4h000PR00047@00=T<008H7
0<bc003h7P00na<00=:Q000<SP0004A:008000HO0;H004E:00f?003CW`00na800?PP003:]P0008@;
000c@@0011`000TS001DC00]V`00g8@00?h6003c=000[[l0001g90008SP0008J000?:@00H4<0FJT0
0>IS003o0000je4007Ja0000J3X001@^00026@006c<0070`09Bi003`@000o`<00>1h000kW`0005M:
000:90000a/0031000233@3:]P00n1h00?/D003@YP000h/0000kAP0011d000PR001BC@0YV@00g8D0
0?h6003b=`00Xkd0001c:P007C@000/S001X>`1h/@00k4h00?l0003TJ`00BZ@0001KA`0032H000<K
000^?`00PPl0b[L00?PM003j5P00cj/000280`00=D<000@L000:9000EdX0?J000>5d003o0@00kDP0
082c0000JCT001@]00026@007SD007DX0:fo003d<@00o@T00=RA000FT`0004M;00057`001b0004m>
02FH003LQ@00oPD00?4k002F^@0006lb000H<@000QT001Xb001a;P2Q_000lSD00?h8003IS@006Y@0
0018B`001Al000LP001@CP0YV@00gH400?l4003_@@00R[H0001[=`005Bh0008I000O=P00Mb@0^L80
0?DZ003l3P00dil000B;0000>4@000@L000:9000FDT0BZ@00>EW003o0000j5X005fZ0000GTD000`W
00036`00<D0008L60<nY003k4P00mb@00<?40000NB40024g00026@005Bh006`f092h003a>`00oPH0
0=V<000HT`0004E:00057P00228005E;03fP003SK`00o`000>YF001QZ`0005m4000<9P000a/003A2
0029003BX@00o0h00?D/002^_`0007<[000J<P000QT001/c001e:0[ooooo0Ol00001ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`3o000Y?00011`000HO000iA000OaD0[;l00>i5003o0000kDX0
0::l0000OAX003A200057P0011d002ho001h8P2C^000je800?l0003`?`00]l4000224000?4H000HP
00047000:C`007DY08Je003YF@00o`400?4j0030``0008@;000oA`001b0000@L000W>`00M2X0QKD0
0>UI003o0@00lC/00;g30000P`h003a60006800011`002Xm001f9@2?]`00je<00?l0003_@P00[[l0
001o5`00=D<000DN00057@00<T4007`K0:Jm003^AP00o`000>]@002C^00007LT000Z?@0011`000LP
000oA`00Q@T0aL800?<c003o0P00iFH006j_0000KCD001he00036P002bD0055=01BB003@Y`00n1l0
0?d<003LQ000@J40001OA0004b`0008I000B;000Gd@0@:400=b4003m2`00n1l00<nY000@T000051>
000:90000aX0028g001a;`1o/`00jET00?l0003_@@00Z[h0001l7000;cl000@M00068000?TL008H7
0<Nn003d;P00oPD00>9a001HZ00006Dn000F;`000QT0010Z001LAP2;T`00o@`00?PP003>[0002hh0
001<C@00228000<K000X>`00MbD0VKX00>e9003o0000jUD008>d0000LBl0024g00036P002bD005A<
01nF003EVP00na@00?XF003DW@006i@0001BC@002R@000<J000S>000Lb/0S[L00>a=003o0000je80
08Fe0000LBl0020f00036P0032H005I;02NI003GT`00o1000?TL003@Z0003Hl0001<C@00228000@L
000/?P00O1`0[kl00?4k003o0P00i6T005nZ0000ISd001D_00026@004bd0069105>W003RL@00o`<0
0?8f002h`P0007hH000_?`0011`000PQ001<C@0?T000dJD00?XI003k4`00e9/001VD0000D4d000TS
00036`00:cd007/N0:no003a>@00o`<00>9_001CY`000692000B;0000QT001Pa001Y>@1_[`00j5`0
0?l0003]B`00SKL0001a;P007cH0008J000>:000FdL0?Z000=im003n1P00m3000<340000OaH002lo
000470002280051>01ZD003EV000na400?PM003=[`000HX0000oA`001Al000HO000oB001RP00cZh0
0?TL003k4P00e9/001JB0000CTh000PQ003c00047@00=48008<=0<Rl003f9P00o@/00=V>000UV000
05=<00098`000a/002dn001o5P34a000mB`00?d8003KQP00;Y/0001EB`002R@000<K000[?@00OAX0
_/<00?@_003n2000g8D002nK0000ED/000XT00036`00;3d007hH0<?4003e;000o@T00=Z9000YV@00
05=<00098`0011`0031000224@37_@00mRD00?`=003GU0006i@0001?CP001b4000@M000iA000R0<0
cJl00?TK003j5@00dJ@000N=0000@DP000DN00068000B4/04Y400=BK003l4000mb800<Vj0000PPl0
0310000370002R@005E;03:L003MP000oPD00?8g002W_P0007HW000P=`000QX0010Z001R@@1OZP00
if000?l0003ZE@00L:l0001V?0004bd0008I000L=000LRd0VkX00?4l003o1000gg`003JN0000ET/0
00XT00047000<d4008D90<bc003i7000nQH00<nZ0000R@0003Q400047@00228005=<02jK003MP@00
oPD00?4j002M^`00078]000L<`0032@006Ti07jc003]BP00o`400>9_0015XP0005U9000;9@000a/0
031000242`3</`00nA/00?XH003=[P0008H7000c@@000a`000XT001HB@12XP00hW000?l1003/C000
NK80001W>`004bd0008I000P=P00MbD0/l000?@^003m2`00eYD001:A0000@dT000DN00078@00DDd0
:YX00=f1003n1000l3l0092h0000KC@001L`00026@0073<007<[0:Nn003c<P00o@T00=RA000ETP00
04E:00057P001b40055=02jK003NO@00o`<00>m40024]00006Ti000C;@000QT0024g001i8@2o``00
mRL00?`@003AX`0008X0000f@`0011`000/U001KB01?YP00iV<00?l0003WGP00EjP0001MAP0032H0
00<K000d@P00R080dJD00?`@003f9`00_<<0001h90007cD0008I000F;`00KC<0UkT00?8h003n1`00
f90001BB0000@DT000DM00098`00ET/0@Z800>A[003o0000jEX005^Y0000GDH000/V00037000=T<0
0h/00=>N003m3000m2l00:Rn0000LBh001Ta00026@007C@007LU00[ooooo0Ol00001ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`0<000W>`0011`000HP000kAP00PA40/l000>m2003o0000k4h0
09bk0000Nah003510P001Ah0:P00<40007XO09Vj003/C`00o`000>m2002a`000080C000iA0001Ql0
00@L000[?@00MRH0S;L00>YF003o0000l3d00;[20000PPl003a60006800011`002Xl001f9`2;]P00
jUH00?l0003`?P00]/4000214@00>TD000HO00047@00;3h007PS09Fi003/C`00o`000>i5002W_P00
07dJ000c@@8000DN0?l003A2001n602/_`00kd800?l0003ZD`00SKL0001e9`00:3/000@L00078@00
@TT008L50<Nn003d<000o`<00>AY001X[@0006/g000L=0000QX000/U001CC00HT`00dJ<00?TL003l
3@00fhP003^O0000GTD0014[00026@004bd0065204JS003MP000o@X00?LR003>[@0038h0001>CP00
2B<000<K000S>000LR`0QKD00>YF003o0000kTD00:>l0000NQl002dn000470001b00045900280`39
^`00mB/00?h6003QM@00DZL0001T?`005Bh0008I000A:`00GTD0SY800?d:003g8`00cK0000N<0000
BD`000PQ00047000:S`007TR09nl003^A@00o`000>UI001l/`0006la000O=@000aX000`V001EB`0T
V000eYH00?/B003j6000dZ4001NC0000DDd000TT00036`009CX007DX09Bi003]BP00o`000>YF001o
/`0006la000N=@000QX000`W001GBP0/VP00fHl00?`>003h7P00cZ`000V=0000B4`000LQ00047000
;cl007dI0;G1003b>000o`<00>=]001IZ@0006@o000D;P000QT001@^001T?`1IZ000hfd00?l2003b
>@00//00001l7000;3h000@L00088P00Cdh04i400=:Q003j5`00nQH00=>O000ETP0004m>00088P00
11`002dn001m6P2f`@00lSH00?l4003QL`00CJD0001P@`004B/0008I000I<P00JcL0MK400>UH003o
0000k4h008Je0000L30001dd00026P003bT005e604>R003ON@00oPD00?<c002j`P0007dJ000/?P00
0a/000TS001AC@0OUP00eiD00?`?003h8000c;8000280P00?4H000DN00067`00@TT01X`00<nZ003i
6P00na@00=>O000AT@0004]=00078@0011d003I300252P39^000mb<00?`=003GTP008IH0001AC@00
2B<000@L000`@000P1<0a/400?DZ003m2P00fXX002VI0000E4`000XT00036`00;Ch007lF0<G4003e
;000o@T00=Z9000ZVP0005A<000990000a/002ho00205@36`P00mRT00?d:003IS@0099L0001BC@00
228000@L000c@@00P`d0bKX00?LS003l3`00eIP001JC0000C4d000LP00057P00?4H008X00<j[003i
6@00nQL00=2X0003R`000;T003i700057P001b0004]=01JC003FU`00o0h00?LU0037_P00084C000^
?`000a/000XT001GBP0gWP00gg`00?h4003a>P00XK`0001d:P007cD0008I000A:`00Hd00IJ`00>QL
003o0000jEP006Z^0000ICh0018/00026@007SD007<Z0:6l003a>@00oPD00=f0000aW00005A<0009
8`0011`003E300271P3=[`00nAT00?XH003>[@0008L4000f@`0011`000TS001EC00cW@00gWd00?l4
003`?@00UkT0001`<0006S8000`T001[=`24]@00kTL00?l2003QL`00?j40001HBP002R@000<L000c
@@00QPP0cJl00?XH003i6P00c;8000242`00<40000<K000;9@00FTP0B:<00>=/003o0000je0007>`
0000ISd0018/00026@008SL007PR0;[2003e:`00o0`00=FI000=S`00041800057P002240059=02nK
003NO@00o`<00>m20029]P0006/f000E;P000QT001dd001e:02^_`00m2l00?d:003FU@0049000011
B@001Ah000PR001CC00cW@00ggT00?l2003^B000OK<0001X>`004R`0008J000S>000Nah0aL@00?LT
003k4P00d:L000280`00<d4000<K000;9P00G4H0EJL00>MO003o0000iV80056V0000FdL000/U0004
7000=T<00HX00=:Q003l3P00mBX00;K10000MRL001dd00026@005c0006la09fk003b=@00o@T00=ND
000?T00003i700047@002B<005Q:04NS003UI`00o`000>QN001EY`0005]7000;9@0011`003U400R=
003EVP00o@/00?<b002Q_000070`000G<0000QT001le001h8P0:ooooo`7o00000Oooool001kooooo
00?o0000ooooooooool01oooool0o`009CT000<K00078@00?TL008<>0;W2003`?P00o`000>]A002E
^@0007TQ000_?`001Ad000DN000c@@00O1`0X;`00>e;003o0000kTD00:Zn0000OQL003I300067`00
11d002dn001h8`2C^000je800?l0003`@000/l0000214`00>D@000HO00047@00;3d007LT096h003[
DP00o`000>m1002``00007lE000g@`001Ql000@M000_?`00NQl0W;/00>e;003o0000kDT00:6l0000
Nad0031000057@001Al003M30020502c`000l3l00?l0003YE`00Q[D0001d:P009SX000<K00088@00
ADX008T10<Rk003d;@00oP@00>=]001RZ`0006Ti000K<`000QX000`V001DC00MU@00dil00?TJ003l
3`00fX`003JN0000G4H0010Z00026@005Bh0069104^T003OO000o@P00?LU003</@0028d0001;C@00
228000<K000U>P00M2X0RkH00>]B003o0000kDP009fk0000NB8002/m000470001b4004E:002:003:
]`00mRP00?h7003ON@00C:D0001R@@0052d0008I000B;000H4<0TI400?d9003f9@00bk@000:;0000
ATX000LQ00047000;3h007XO0:Jm003_@P00o`000>QL001f/@0006dd000M=0000QX000`W001GBP0Y
V@00ei800?`@003i6`00dJD001:A0000Cdh000TS00036`009c/007LU09^j003^AP00o`000>UJ001i
/P0006dc000M=0000QX000dW001IB@0aW000fX/00?`<003h8@00cJl000B;0000ADX000LP00047@00
<D0007lF0;c2003c=000o`@00>9a001CY`000691000C;@000QT001D_001U?@1NZP00i6T00?l2003a
?000Zkh0001j7`00:S`000<K00098`00D4h069<00=BM003k5000nQP00=6S000@T00004a=00088@00
11`002lo001n5`2m``00lc<00?h5003PM`00B:<0001NA@0042X0008I000K<`00KC@0O;800>YE003o
0000je80082d0000KS<001`c00026@0042X005i504VT003QM@00oP@00?8f002c`00007/M000Z?000
0a/000XT001CC00TU`00f9400?`=003g8`00b[H000261P00>DD000DN00068000ATX02Xh00=2V003j
6000nQH00=6S000=S`0004M;00078000l`001Ad003U500271P3;]@00n2400?`?003FUP0079D0001@
CP00228000@L000b@@00PPl0akd00?HW003m2`00fHh002BH0000DTd000TS00047000;cl0080C0<K1
003f:@00o@/00=V=000UV000059=00098`0011`0031000214@37_P00mRH00?d<003HT@007iH0001@
CP00228000@L000e@P00Q@T0b[H00?PP003k4@00e9`001:A0000B4`000HP00057P00?dL018/00=2X
003j5`00nAT00<j/0000R@0003]500057@001b4004i>01^D003GT`00o@`00?HX0036`@0007lF000/
?@000a/000/U001HB@0mX000h7P00?l3003`?@00V[X0001b;@007C@0008I000B;000ICh0Jjh00>UH
003o0000j5`006B/0000Hd00014[00026@0083H007DX0:Rn003b=P00oPH00=b4000[VP0005==0008
8P0011d003Q400280P3?Z`00nQL00?TK003</@0008D8000c@@0011`000XT001FB`0hWP00h7T00?l3
003_@@00T;P0001^<P006C4000dU001]=02;]P00kd<00?l2003PM`00>Yl0001FB`002B@000@L000e
@`00R0@0cZ/00?XF003i7@00b[H000233`00;Sl000<K000<9P00FdL0CZD00>EX003o0000jU<006f^
0000I3l0014[00026P008cP007XO0<74003f:000o0h00=BM0009S@0003e700047@00228005A<03BM
003ON@00o`800>i50023]00006Xi000D;@000QT001lf001g9@2d`@00mB`00?d<003EV@0038l0000n
A`0011d000PR001DC00hWP00hGD00?l1003]B`00Mk40001V?@004B/0008J000U>@00O1/0a/000?LQ
003k5000cj/000261`00<D0000<K000<9`00GTD0FjT00>QL003o0000iFH004^U0000FDP000XT0004
7000>D@01X`00=BM003l3@00mBd00:no0000M2X001`c00026@006C40074^0:Bm003c<P00o@X00=JH
000;SP0003a6000470002R@005U904fU003VH`00o`000>IQ001?YP0005Y8000:900011`003a600b>
003FUP00o@T00?8e002K^P0006hc000F;`000QT0024g001j7`0:ooooo`7o00000Oooool001kooooo
00?o0000ooooooooool01oooool0;@008cP000<K00078@00@DP008D:0<33003a>`00o`000>YE002?
]`0007LT000]?P0011d000DO000e@`00OQP0Y[d00>i7003o0000kDT00:>m0000OAX003A200057P00
1Ad002lo001j802I^P00k4h00?l0003_A000[;l0001o5P00=T<000HO00047@00;Sl007TQ09Rj003/
CP00o`000>i5002Y_P0007hH000d@P0200057P3o000a@000O1`0Xk`00>i8003o0000k4`009Zj0000
NB4002ho00047@001Ql003U500224@2i`P00lC/00?l1003XF`00P;<0001b;@0093T000<K00088P00
BD`00X/00<Zg003e:P00oPD00>9a001LZ@0006Lk000I<P000QT000dW001FB`0RU`00e9/00?XG003k
4@00f900036L0000FTP000lY00026@005Rl006@o056V003PN000oPL00?HX003;]@000h/00018B`00
228000<K000W>`00MRL0T[P00>a>003o0000kD`009Ji0000MbD002Tl00037000224004Q;00B;003<
/`00mRD00?d8003NO@00Aj<0001P@`004b`0008I000C;@00HD80UHl00?h7003f:000b[P000290@00
@TT000LP00047000;cl007`L0:bo003`?P00o`400>MP001`[`0006`f000L<`000QX000dX001HB@0^
V`00fHh00?`>003h7@00cjT000f?0000CDh000PR00036`00:C`007TR0:6l003_@`00o`000>QN001b
/00006`f000K<`000QT000hX001JB00fWP00fhL00?d;003g8`00bk<0002:0000@TT000HP00047@00
=480084B0<?4003c<@00oPD00>5e001=Y@000652000B;0000QT001L`001W?01T[000iFD00?l1003`
@000Y;d0001h8P00:3/000<K00098`00DTd07ID00=FI003k4P00nAX00=2W000<SP0004U<00078@00
11`0039100204`33a000m2l00?h6003ON`00@Z80001MAP003bT0008I000L=000KS80P[@00>]A003o
0000jUH007Zb0000K3D001Xb00026@004B/0061304nV003RL@00o`<00?4i002]_`0007XP000X>`00
0a/000XT001DC00YV@00fHd00?d;003f9@00bKX000252P00=d<000@M00078000BD`03i000=:R003j
5@00nQP00=2W0008S@0004A:00067`001Ah003a600280P3</@00n1h00?/A003EVP005i<0001>CP00
1b4000@M000e@P00Q0/0bKX00?LT003l3@00ei8001nF0000DDd000PR00047000<T40088?0<Rm003f
9P00o@`00=RA000PUP00055=00088P0011`003=100233@39^P00mb<00?`>003FU@006Y@0001?CP00
1b4000@M000hA000Q`D0c;800?PM003k4`00dj00003400f?0000ADX000HO00057`00@TT02Hd00=6T
003k5000nA`00<f`0000Q`@003Q400047@002240051>022F003HS`00o@X00?D[0033a00007dJ000Y
?0000a/000`V001JB012XP00hG@00?l2003_@@00U;T0001`;`006c<0008I000C;@00Ic`0LJl00>YD
003o0000if0005jZ0000HD80010Z00026P008SL007LU0:jo003c<`00oPL00=^8000VV000055=0008
8P0011d003]500::003@Y`00naD00?PM003;]@0008@<000a@0000a/000XT001HBP0nX000hGD00?l2
003^A000R[H0001]=@005c0000hU001^<P2A^000l4000?l3003ON`00=9d0001EC0002B<000@L000h
A000R@00d:L00?/D003h7`00bKX000214P00;3d000<K000=9`00GDH0DjL00>IT003o0000jEL006N]
0000HT40010Z00026P009CX007`L0<G3003g9@00o1000=:Q0005S00003Y500047@002B<005E;03VO
003QM@00o`400>e9001m/`0006Pk000C;0000QT0024g001h8P2k`P00mBT00?`>003DW@0028d0000l
AP0011d000TS001FB`0mX000hW400?l1003/C`00LJl0001T?`0042X0008J000W>`00OQL0b;`00?PO
003j5P00cJl000242`00;Sl000<K000=9`00Gd@0HJ/00>UH003o0000i6X004JS0000F4X000TS0004
7000?4H02Xh00=FI003m2`00m3000:Rn0000LR`001Xb00026@006S8007</0:Zn003d;`00o@`00=BL
0006S00003U4000470002bD005]705>W003WG`00o`000>EU001:Y00005Q900098`0011d003m7012@
003HTP00oPP00?8h002D^@0006`e000D;P000QT0028h001l70[ooooo0Ol00001ooooo`007_ooool0
0ol0003oooooooooo`07ooooo`0G000Q=`000a/000PR0014BP00Q`H0aL<00?8h003o0@00jET008Rf
0000MRL002Xm000470001Ql003Q4001o5@2]_`00kd@00?l0003/C@00WK/0001k7P00<D000P001Ah0
5000<T4007`L0:2l003]BP00o`000>i7002V_@0007dJ000d@P001Ah000DM000a@000Nah0Wk/00>e;
003o0000kDP00::l0000O1`003910P001Ah0o`00=48007hI0:Vn003_A000o`000>]@002D^@0007PT
000[?@0011`000HP000lAP00P`d0`<<00?8h003o0@00iel007Zb0000L300028h00036`002B<004a=
00N<003;/`00mRL00?h7003QM@00EZP0001V?@006300008I000>:000F4X09iT00=JG003j5@00na<0
0=ND000[VP0005U9000>:@000QT001L`001V?@1GZ000hG@00?h6003e:`00bKT000290000ADX000LQ
00047000:S`007PT09Rj003]B`00o`000>a?002?^00007DX000V>P000a/000PR001;C@09S@00cJl0
0?LS003m2P00gH40046Q0000Gd@0018[00026@005Bh006=009R>003n1P00mB/00<Rk0000Q`D003m8
0006800011d00350001n602c`000lC/00?l1003VI000JZd0001Z>0006S80008I000>:000FTP0=9d0
0=Z:003l3@00n2000<j]0009S@0004Y<00088@0011`002`m001j7`2X_P00l3l00?l1003VHP00K:h0
001Z>0006S80008I000?:@00G4L0?:000=f2003m2@00mRH00<Zg0000R0<003m700067`001Ah003I3
00233P36`P00m2h00?h6003ON@00B:<0001OA0004B/0008I000H<@00JCT0Jjh00>MQ003o0000kd<0
09jk0000MbD002Hj00036`002R@005=<02:G003FU@00o1000?TM003?Z`001hd00016BP001b0000@M
000d@P00PQ00a/400?D/003n1`00gWl003fP0000FdL000hX00026P007SD0070_08Rf003/C@00o`00
0>UI001c/00006Xh000I<@000QT0018/001R@P1DY`00hfd00?l2003a?@00Y[d0001h8`009SX000<J
000;9@00ET/0;Y/00=^8003m2P00mRP00<Nn0000P`h003A200047@001b4004a=01>A003CWP00na<0
0?TK003?Z`0018/00011B0001Ql000DN000oA`02RP00cZd00?TL003k4`00dih001:A0000Bdd000LQ
00047@00=d@008H80<Zf003g8@00o0l00=JF000JU00004m>00088@0011d003A200242`39^@00mb<0
0?`>003FU@006i@0001?CP00224000@M000e@`00Q@T0b[H00?PQ003l4000eIT001FB0000Bdd000LP
00057@00>dD008T10<f^003i6`00nQD00=6T000100V=004004990P001Ql0`000ADX03Hl00=>P003k
4P00n1h00<^d0000QPP003E3000470002280055=02FH003JR`00o@T00?@^002l``0007/M000W>`00
0aX000dW001KA`18X`00hW000?l1003^A000SKL0001_<P006S80008I000E;P00JCX0Mk400>]@003o
0000iV@005RX0000H4<000lY00026P0093T007TR0;G1003d<000o@T00=V<000QU`0004m>00078@00
1Ad003i700J<003BX`00na<00?PP0039^@00088@000^?`000a/000/U001IB@13XP00hW400?l1003^
B000Pk@0001[=`005Rl000hV001`;`2H^P00lC`00?h4003NO`00;i/0001CC000228000@M000kA@04
R`00dJ<00?/B003g8P00akh0001o5P00:C`000<J000=:000Gd@0FJT00>MP003o0000j5/0066[0000
HD8000lY00036P00:3/007hH0<No003g8P00na800=6U0000RP0003Q4000470002B@005M:03nQ003R
L@00o`400>a=001f/@0006Hm000B:`000QX002<h001j7`32a000mRH00?`@003BX@000h/0000iA000
11`000XT001HBP13XP00hfd00?l0003[D`00Jjh0001S@@003bT000<J000Y?000P1@0bKP00?TL003j
6@00c;<000223`00;3d000<J000>:000HD80Ijd00>YD003o0000hfh0042Q0000ET/000TS00047@00
?dL03i000=JE003m2@00lc<00::l0000LBl001Pa00026@0073<007@Y0;70003e;000o0h00=>P0002
RP0003I3000370002bH005e605VY003XF`00o`000>AY0014XP0005M:00098`001Ad0049901FB003I
SP00oPH00?4l002>]`0006/g000C;@000QX002@i001n6@[ooooo0Ol00001ooooo`007_ooool00ol0
003oooooooooo`07ooooo`0R000O=P000aX000TS0018B`00R080akl00?<d003o0@00j5d008:d0000
M2X002Pk000470001R0003]500214@2d`@00l4000?l0003[D000U[T0001i8@00;cl000DM00057P00
=D8007dI0:Nm003^A`00o`000>e;002O^`0007/M000a@08000DN0?l003=1001m6P2U_@00kTL00?l0
003/C000W;/0001j7`00;cl000@M00057`00=d<007lE0;30003_@@00o`000>YD002=]`0007HW000Y
?00011`000LP000oB000Q@T0aL<00?<e003o0P00iV<007>`0000KS80020f00036P002B@004m>00^>
003=[`00mbD00?h8003ON@00D:H0001T?`005Rl0008I000?:@00FDT0;9X00=NC003k4`00nQD00=FH
000VV00005M:000=:0000QT001Ta001W>`1MZP00hVl00?h5003d;P00b;`000271000@DP000LP0004
7000;3h007TQ09nk003^A`00o`000>YC0029]P0007<[000T>@000a/000TS001>CP0=S`00cj/00?PP
003m3000g8H003^O0000GDH0010Z00026@005Rl006Dn09b=003n1@00m2h00<No0000Q@T003a60006
7`001Ad003A20020502j`P00lSL00?l2003TJ000I:`0001X>P006340008I000?:@00G4L0>Il00=^6
003m2`00mb800<ba0004R`0004I;00078@0011`002ho001l6`2__`00lC`00?l1003UIP00IZ`0001X
>P006340008I000@:P00GTD0@J400=in003n2000mBT00<Rk0000QPL003a600057`001Ah003U50024
2`37_P00mB/00?h7003NO@00@Z80001MA@0042X0008I000J<P00JcL0LJl00>QM003o0000kTL009Ni
0000MBP002@i00036P002bD005E;02NI003HT@00o0h00?PO003=[`000h/00012B@001R0000DM000g
@`00Q0`0akh00?DY003m2@00g8<003NN0000FDP000dW00026P0083H0078]08ng003]BP00o`000>QM
001][P0006Tj000G<0000QT001<]001S@01JZ@00i6T00?l1003`@000Wk/0001f9P0093T000<J000<
9P00F4X0<id00=b4003m2000mB/00<K20000PA80035000047000228004m>01RC003EVP00na400?PM
003=[`0008T0000nA`001Ah000HO0012B@06S000cjT00?TI003j5@00dZ8000f?0000Ad/000HP0005
7P00>TD008P30<bb003h7P00na400=FJ000ETP0004e>00078@0011d003M400261`3;]@00n2000?`@
003EV@005Y<0001=CP001b4000@M000hA000Q`D0c;800?PN003k4P000<l0did0016@0000B4`000HP
00057P00?TL00XX00<nZ003j6000nQL00=2X0004R`0003m700057P001R0004Q<01:A003DV`00o100
0?PQ003:^00008@<000c@@0011`000TS001CC00ZVP00fhL00?h7003d<@00]L40001i80009CT000<J
000=:000GDH0CZD00>=/003o0@00kDP008Ne0000KC@001Pa00026@005Rl006Xh07jc003/C@00o`00
0>EX001BY`0005i5000>:0000aX002Hj001k7P2l`P00mB`00?d:003HT00079D0001=CP001b0000DN
0011B00:SP00dil00?`@003g8`00b;d000205000;3d000<K000<9P00FdL0BJ@00>=]003o0@00kD`0
07fc0000JCT001D^000?9P00LRd0W[/00?4i003n1@00g8<002ZJ0000DDd000PQ00057@00?TL028d0
0=>O003l4000mbD00<K10000OAX002Lk00036P003RT0061305nZ003XG000o`000>MO001KZ@0005m4
000>:0000aX002Xl00205@38^`00n2000?/D003?Z@0008P3000e@P0011`000XT001HB@14XP00hfd0
0?l0003[D000L:l0001T?`0042X0008J000U>@00O1`0aL800?LT003k4P00dJD000290000=T<000@L
000:9000FDT0BJ@00>AY003o0000jUH006F/0000HD8000hX00036P00:cd0088@0<^d003i6P00nA/0
0<Zg0000PA<002Xl00036P003bT006=006f^003[D000o`400>9b000kW`0005E;00088P001Ad00499
01>A003HT@00oPP00?8f002K^P0006lb000G<0000QT001de001f9P2h`@00mRT00?`?003AY00008T1
000c@P000a/000`V001NA@1OZP00jEP00?l0003SK@00?Z00001EB`00228000DN0015BP0JU000fXT0
0?h5003`?`00QkD0001Y>P004R`0008J000V>P00OaD02_ooool1o`00007ooooo000Nooooo`03o`00
0?oooooooooo00Oooooo088001dd00036P002B<004]=00::0038^`00m3400?l2003WH@00Nk80001b
;@009SX000<L00078000?TL008<=0;_2003`?@00o`000>YD002?]`0007LT000/?P0011d000HO000g
A000OaD0[Kl00>m3003o0000k4l009Rj0000NB4002ho00047@001Al003I3001o5`2/_`00kd<00?l0
003[D000UKT0001h8P00;Ch000@M00067`00>DD0084A0;O1003`?@00o`000>UH0026]@0007@Z000W
>`000a`000LQ0013B@00Q`D0akl00?<a003o0`00iFL006f^0000KCD001he00036P002R@0051=012@
003?Z`00mb800?d:003NOP00BZ@0001R@@005Bh0008I000@:P00FdL0<Y`00=R?003k4@00nQP00=BL
000QUP0005I;000<9`000QX001Xb001Y>@1S[000i6/00?l3003d<@00a/0000252000?TL000HP0004
7@00;Sl007/M0:Jm003_@`00o`000>UG0022]000074^000R>0000a/000XT001@CP0BT@00d:L00?PM
003l3@00fXX003JN0000FdL000lY00026@005c0006Hl0:2<003o1000lc800<G30000P`d003U50P00
1Ah0O`00=T<0088A0<74003c=000o`<00>=/001MZP0006Hl000G<0000QT0010Z001MA@0oX@00gH40
0?d9003f9@00bkD0002:0000@dT000LP00047@00<D0007hH0;K1003b>000o`800>AZ001PZ`0006Hl
000G<0000QT0014[001OA017X`00ggX00?h6003e;000akl000242`00>D@000DN00067`00?4H008H6
0<Vj003f:000o@T00=f1000lX00005a7000?:@000QT001/c001/=@1g/@00jET00?l0003]BP00T;P0
001c:`008SL000<J000<9P00ETX0;9X00=V<003l3000mb800<^c0000R@4003m800067`001Ah003Y5
00262039^P00mRH00?d:003KQ`00<Y`0001HBP0032H000<J000R=`00M2X0U[T00>i6003o0000iV40
06N]0000Ic`001H_00026@0052h006Dn066[003UI@00o`400>m4002H^P0007@Y000R=`000aX000dW
001IB@0iW`00gH000?h7003d;P00`l@0001o5P00;cl000@L00088P00DDd07ID00=JF003l3`00n200
0<^c0000Q`@003]500057P001R0004E:00Z>003AY@000P3j5`00k@3@YP002Hd00014BP001Ql000DN
000mA`00R@00cJh00?TL003k4`00dil0016@0000BD`000LP00057@00>TD008P30<ba003h7P00na80
0=BM000BT@0004U<000780001Ah003]600290@3=[P00nA`00?/D003BXP0038h00015BP001Ql000DN
0011B007S000d:H00?XF003i6P00cZ`000290000?4H000DN00078000C4d05i<00=JG003l3P00mb@0
0<Rl0000PQ000310000370002B@005E;032L003LPP00oPH00?<d002^_`0007PS000S>0000QX000hY
001OA01CY`00iFP00?l0003/C000P;@0001[=`005c00008I000H<000K3D0Q;D00>e9003o0@00hf`0
04bU0000G4H000dW00036P00:3/007`K0<?4003e:@00o@`00=ND000GT`0004Y<000680001Al004A:
00n@003DV`00o0l00?HU0036`@0007hG000Y?0000aX000dW001MAP1?YP00i6T00?l0003/C`00M[40
001W>`004bd0010W001d:P2U_@00lSH00?h7003KQ`009IP0001@CP001b4000DN0011B00=S`00e9/0
0?`>003f:000`l@0001k7@009CT0008J000?:P00HT40IJ`00>UH003o0000iV<005FW0000GDD000dW
00036`00;3h0084A0<Zg003i7@00nQL00<j]0000QPL0039100036`002bD005Y804ZT003TJ@00o`00
0>YD001Z[@0006=0000?:P000aX002Lk001n6037_P00n2400?/D003?Z@0008L4000c@@000a/000/U
001KA`1?YP00iFD00?l0003XFP00GZX0001OA0003BL000<K000^?`00Q0`0cK000?XG003h7P00b;/0
001o5P009c/0008J000@:P00ICh0Lk000>a<003o0@00h7H003FM0000Dd`000PQ00057P00ADX069<0
0=V=003n1`00lCX009Bi0000KC@001H_00026@007cH007PS0;o3003f9P00na800=2X0000Q`D00350
00036`003BL0061306F/003ZE000o`000>9a000iW`0005=<00088@001Ah004Q<01nF003LQ@00oP@0
0>m30021]00006Ll000A:`000QX002Tl00214@0:ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool0PP006c<000<J000:9000Cdh01X`00<Zh003d;P00o`<00>EU001e/000070_000T
>@000a/000LQ0011B000Q@T0`/@00?4i003o0@00jEP008Vf0000MBL002Xl000470001R0003Y50021
4P2d`@00l4000?l0003[D`00TKP0001g9000;3h000@M00067`00>D@0080C0;?0003`@000o`000>YD
002>]`0007HV000Z?@0011`000HP000lAP00P`h0_/<00?4j003o0@00j5`0082c0000LRd002Di0003
6`00228004I;00290@38^`00m2h00?l4003TJ`00IZ`0001[=`007C@0008J000;9@00DTd05I800=2W
003h7`00o@/00=f20014XP000652000D;@000QT0014[001MAP0gWP00fX/00?`?003i6P00dZ0001bE
0000E4`000`V00026P0073@006/g06V]003UI`00o`<00?<d0035a00008@<000kAP001Ql000@M000a
@000OAX0[Kl00?10003o0000j5/007bb0000L300020f00036P002R@0059=01NC003BX`00nA/00?`?
003ISP00<9`0001JB0003RT0008I000I<@00J3X0Xh/00?l3003c=@00`<<000214@00=T<200057P17
000iA@00P`d0aL800?@a003n1000hW4005NX0000ICh001H_00026@004B/005m404FR003NO@00oPP0
0?HX0039^@0008P30010B0001Ql000@M000c@@00P1@0_L<00?<e003o0`00hfh005ZY0000ICh001D^
00026@004R`0065204fU003PMP00oPD00?@_0035``00088?000f@`001Ad000HO000oB000R080b[H0
0?LU003m2P00g8D003NN0000FTP000hX00026P007C@006hb07jc003ZE@00o`000>a>0029]P00074^
000P=P000QX000`W001HB@0bW000fhP00?d;003g9@00b[L000271@00?4H00P001Ah0>`00?DH008P4
0<Zf003g8`00o@`00=Z<000/VP0005I;000;9@000aX002@i001f9`2L^`00kd800?l1003UI@00H:/0
001U?P0052h0008I000F;`00Ic`0Ijd00>MQ003o0000kTL009:h0000LR`0020f00026P003RP005]7
03nQ003OO000oPH00?<b002l`P0007dI000/?P000a/000TS001BC@0RU`00f9400?`=003g8`00b[L0
00262000>4@000DM00078000BD`03i000=:Q003k5000nAX00<nZ0004R`000458008000HO05L00418
00B;003?ZP00nAT00?XE003BX`0038h00016BP001R0000DN000mAP00RP00cZd00?TK003k5000dZ40
00f?0000AT/000HO00057P00?TL00X/00<nZ003i6@00nQH00=6V0007S@00045800057`001Ql004A:
00^>003BXP00na@00?TL003=/00008P3000iA00011d000LQ001?CP0LU000ei<00?`<003f9`00a/00
00205000;Ch000<K000:9000ET/0=Id00=in003n1@00lSL00:Nn0000MRL0024g00026P003bX00653
05ZY003VI000o`000>]@001j/P0006Ti000E;`000QT001Ta001^<`2;]P00kTD00?l1003RL000AZ<0
001KB00032H000<K000Z?000OQL0a/400?HV003l3P00eIP001:A0000AT/00P001Ql0S`00Ad/05980
0=JG003l3@00mRP00<C40000O1/002Lk00036P003RP005i505FW003VI000o`000>YC001`[`0006Hm
000B;0004BP007HW0:bo003c<P00oPP00=Z<000OUP0004i>000780001Ah004A:016A003FU`00o@`0
0?D[002l`P0007TP000S>0000QX0014[001T?`1/[P00jU@00?l0003UI`00CjH0001LA`0032H000<K
000_?`00P`d0bk<00?TJ003i6@00c;4000242`00<40000<K000<9P00G4L0D:H00>EU003o0000jEP0
06>/0000HD8000hY00036P00:C`0080E0<Vj003h7P00nQH00<j^0000Q@T0035000036`0032H005e6
05FW003WH@00o`000>MN001HZ00005e5000<9P000a/003100026203>[000nQD00?PP0037_`0007dJ
000U>P000QX0014[001V?01j/P00kDT00?l2003ONP00<9`0001AC@001b4000DN0019C00MU@00fhP0
0?h5003`?@00S[L0001[=P0052h0008I000Q=`00NR00aL@00?LS003k5000cZ`000252P00;Sl000<K
000>:000HT40Jjh00>]@003o0@00h7H003>M0000DTd000LQ00067`00C4d099P00=f1003o0`00kTL0
07Zb0000ICh0010Z00036P00:cd008<>00[ooooo0Ol00001ooooo`007_ooool00ol0003ooooooooo
o`07ooooo`1S000J<P000QX000/U001@CP0;SP00bk@00?D[003n1000i6T006j_0000KS80028g0003
6`00228004A:00271@36`P00lSH00?l1003XG000P[@0001d:P009c/000@L00078000?DL008<>0;c2
003a?000o`000>YF002:]P0007HW000Z?00011`000HP000lAP00PPl0^/800?4l003o0000jEP008Ne
0000MBT002Pk000470001b00041800252P35a000lSH00?l2003WH000NK80001`;`008cP000<K0008
8P00BD`00h/00<Zg003e:`00oPD00>9_001PZ`0006Ti000K<`000QX000`V001DC00JU000dZ<00?TL
003l3@00fhH003jP0000Gd@0018/00026@004R`005i403fP003KQP00o0d00?TM003AY0005i<0001B
C@002bD000<J000N=@00KC@0L:l00>IS003o0P00lSL00;k30000PQ0003Q4008000DN0;L003A2001o
5P2d`@00lC`00?l1003WG`00MK40001^<`007SD000<J000;9@00Dd`079D00=>O003j6000na400=NB
000[VP0005Q9000=:0000QX001Xb001Z>02WRP00o`800?8h002i`P00080E000d@P001Ad000HO000l
AP00Q@T0akl00?@]003n1@00hGD0056V0000Hd0001@^00026@004b`0065204^T003ON@00oPH00?D[
0038_@0008H7000mAP001Ql000DN000f@`00PQ00a<@00?<b003n1000hW8005>W0000Hd0001@]0002
6@0052d006=005>W003RLP00oP@00?<c0030``00080C000c@@0011d000HP0013B@01RP00c;800?LR
003m3000fXX0036L0000F4T000dW00026P007cD0070`08Fe003[D@00o`000>]B0023]00006la000N
=@000QX000dX001JB00gWP00g8@00?d9003f:000b;/000252@00>DD000DN00067`00@4P008T00<bb
003h8@00o0h00=R@000WV@0005A<000:9@000a/002Hj001g902S_@00l3l00?l2003TJP00FZT0001S
@0004bd0008I000G<000JCX0KJh00>QM003o0000kD/008^f0000L2l001he00026P003bT005e604FR
003PN000oP@00?<e002e`@0007/M000Z?0000a/000XT001DC00WV@00fHd00?d;003f9P00b;/00024
3000=D8000@M00078@00C4d059800=BL003k4P00nA`00<f^0000R@0003i700057P001Ql004A:00V=
003AYP00nQL00?XH003@Y`001hd00012B@001Ql000DO0010B005S000cjT00?XH003j5P00dJD000R=
0000@dT00P001Ql0G`00@DT01h`00=2V003j5`00nQT00<nZ0003R`0003i700057P001R0004M;012@
003CWP00na800?PO003;]00008H8000f@`0011d000PR001@CP0QUP00f8l00?d;003e:P00aL@0001n
6000:cd000<K000;9@00F4T0>il00=mj003o1000lC/00:6l0000M2X001lf00026@004B/00691062[
003WH000o`000>YC001c/00006Lk000D;P000QT001/c001`<02B^000kd800?l2003QM000@:40001I
B@002bD000<K000/?P00P1@0akd00?LS003l4000e9d000j?0000@dT000DN00068000Bdd06I@00=NB
003m2`00mB/00;g30000NQh002Di00036P003bT0061305^Y003WH000o`000>UG001Y[@0006@o000A
:`004RT007LT0;?0003d;`00o@T00=R@000JU00004]=008000HO07<004Q;01JC003GT`00o@X00?@^
002e`@0007PT000Q=`000QT0018/001V?@1b/000je000?l0003TJ`00BJ@0001JB0002bD000<K000a
@000Q@T0cJl00?XH003i6`00bkD000223`00;Ch000<K000=9`00GTD0EZP00>MQ003o0000j5`005fZ
0000Gd@000dX00036P00;3d0084A0<Zf003i6`00nQT00<bb0000P`d002ho00036`003BL005i505^Y
003XG@00o`000>IR001BY`0005a7000;9P000a/003=10027103@Z000na<00?LS0035`P0007/M000S
>0000QX0018/001X>P21]000kTD00?l3003NOP00:YX0001@CP001b0000HO001<C@0RU`00g8@00?h4
003_@@00QkD0001Y>@004bd0008I000S>000O1`0a/000?PP003j5P00cK0000233P00;3d000<J000?
:@00Hd00L[000>a<003o0P00ggX002jK0000D4h000HP00067`00Cdh0:YT00=im003o0P00kDX007>`
0000Hd0000lY00036P00;Ch008D900[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07
ooooo`1S000H<@000QX000`V001BC@0?T000cJl00?HW003n1@00hfd006R]0000KCD0020f00036`00
2B8004Q;00290@37_P00lc800?l2003WH000Nk80001b;@009CX000<K00078@00@4P008D:0<?4003b
>000o`400>QK0024]00007@Z000W>`0011`000LP000oA`00Q0/0`L@00?8h003o0@00j5`0086d0000
Lb`002Hj00036`001b4004=900271@36`000lc<00?l2003VI000L[00001^<P008CL000<K00098`00
CDh01hd00<^c003f:000oPH00>5c001JZ@0006Lk000I<P000QX000dW001EB`0OUP00dil00?TJ003l
3`00fXX003RO0000GDH0014[00026@004bd0061304>R003MPP00o@/00?PP003?Z@004Y40001AC@00
2R@000<J000P=P00Kc80M[400>MO003o0@00lC/00;O10000P1@003E3008000DN038003M300214P2k
`P00lST00?l2003VH`00KZl0001/=@007C@0008J000<9P00ED/08IH00=FJ003j5P00na@00=JG000U
V00005I;000<9`000QX001`d001/=P2[R@00o`400?4l002b`00007hH000a@00011d000HP000oB000
Q`@0bK/00?DZ003n1`00ggT004^T0000HD8001<]00026@0052d006=1056V003QM@00oPD00?@^0036
`00008@<000iA@8000DN0?l003U400243036`@00m2h00?h5003PMP00CJD0001Q@P004b`0008I000E
;P00ICh0FJT00>=]003o0`00lSH00;W20000OQL0031000047@001b0004I;00J<003=[P00n1l00?`>
003ISP00:iX0001GBP0032H000<J000Q=`00LRd0RkH00>a=003o0000jUH007bb0000KS<001`d0002
6P003RT005a703fP003MP000oPP00?D[0037_`0008<=000f@`001Ad000HP0013B@04R`00cZd00?PN
003l4000ei@0026G0000Dd`000XT00036`00:3/007TP0:Zn003a>`00o`800>=^001DY`000692000B
;0000QT001Pa001Z>01d/000jET00?l0003/C`00Q;D0001_<P0073@0008I000@:P00GT@0Bj@00>5c
003o0`00lSP00:fo0000NB0002Pk00036`002bD005E;02fK003JR@00o@X00?HY0037_`00088@000b
@@0011`000PR001?CP0IU000eIP00?`@003h7`00c;8000281000>TD000DN00068000Ad/03Xl00=:Q
003k5@00nAX00<n[0003R`0003m700057P001Ql004A:00V=003AY@00nQH00?XI003?ZP0018/0000o
A`001Ah000HO0015BP0<SP00dZ800?/D003i6`00cJh000290@00>dD000DM00078000Bdd05I800=FI
003l4000mb800<Vh0000Q0`003=1000470002B80059=02JH003JR`00o@T00?D]002o``0007`K000Y
?0000a/000`V001JB011X@00h7H00?l3003`?P00V[X0001b;@007C@0008I000B;000I3l0IZ`00>QL
003o0000jEP006b^0000ISd001</00026@0073@0078]09Vj003`?P00o`<00>1i000kW`0005M:000:
9@000a/002lo00224039^@00n2400?/B003BX@002Hd00010B0001Ah000LP001>CP0NU@00fHh00?d9
003d;`00]/40001i8P008cP0008J000@:P00HT40HZ/00>QL003o0000j5/006>/0000HT40010Z000C
:@00NB00^/800?D/003m2`00ei@001FB0000Ad/000HO00068000Bdd079@00=V>003m2@00m3400:jo
0000MRL001lf00026@004bd006Lk07Vb003/C000o`400>9_0013XP0005Q9000:900011`003A20027
1@3?Z`00nQD00?PN0039^@0005X0080C000[?@000aX000dX001OA01MZP00j5d00?l0003WH000EjP0
001NA@0032L000<K000^?`00P`d0c;800?XI003i6`00b[H000224@00:cd000<J000>:000H4<0HJ/0
0>UI003o0000iFL004bU0000FTP000/U00047000=T<008T00=6T003l4000mRH00<740000NB40024g
00026@0052d006Xh08Ne003_@@00oP@00=b3000UV00004i>00067`001R0004m>02RI003MP000o`<0
0>i50020]00006Pk000B;0000QX002Dj001n6@38_000n1d00?XH003;]000084B000Y?0000aX0010Z
001U?P1h/@00kDP00?l2003NOP00:9T0001?CP001Ql000LP001@C@0_V`00h7P00?l1003/CP00KJh0
001R@@003RP000<K000`@000Q`D:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0o`005c00008I000<9`00Dd`059800<n[003g9000oPL00>9b001QZ`0006/g000N=@000aX000TS
001<C@03R`00bKX00?@_003o0`00iVD007B`0000L30002<h00036`00228004A:00271@36`@00lcD0
0?l2003WG`00OK<0001b;@009CT000<K00078@00@TT008H70<G2003b=@00o`800>MP001j/P00074_
000T>@000a/000PR0016B`00R@40b;`00?@_003o0`00iFP006b^0000KCD001le00036P002R@004m>
00b?003=[`00mbD00?h8003PN000DjL0001U?P006300008I000>:000EdX099P00=FJ003j5`00na40
0=R?000cW@0005]7000@:P000QT001D^001R@@19Y000gWh00?d9003g8P00cZd000f?0000Cdh000TS
00036`008SL0070_07fc003XF`00o`000?0o002__`0007hH000b@@001Ad000HO000jA@00P`h0`/@0
0?8e003o0P00iFL006R]0000JSP001/c00026P003BL005M:02JH003FUP00na<00?XF003DV`0089H0
001EC00032H0008J000N=@00KS<0[hP00?l1003`?`00Zkh0001l7000;Sl000@L00078000@dT008T0
0<Zf003f9`00oPP00=im0015X`0005m4000B:`000QT001D_001T?`1GZ000hW000?h4003c<P00a<@0
00224000=T<000DN00067`00?4H008H80<Rm003e:`00oPL00=mk0017X`0005m4000A:`000QT001H_
001V?01PZ`00i6T00?l2003a>P00//00001m6`00;Sl000@L00078@00BD`02Xh00<nZ003i7@00o100
0=NB000VV00005E;000;9@000aX002<h001d:P2B^000kDT00?l0003YFP00MK40001/=P006S80008I
000?:P00GDD0@j800=mk003n1P00m2h00<G30000PA4003=200047@001b0004M;00V=003?Z@00nA/0
0?/B003EV00079D0001AC@002B<000<K000[?@00Nad0//000?8g003o0`00hW8004jU0000H4<0014[
00026@006S8006`e07^b003ZE@00o`000>YC001m/`0006dd000J<P000QT0014[001P@`1AYP00hVl0
0?l2003a?000Y[d0001h90009CX000<J000;9P00EdX0<Yd00=b4003m2000mB`00<G30000P1@002lo
00047000f0002280055=01jE003GU000o0h00?LR003:]`0008H8000gA00011d000LQ001;C@0CT@00
e9d00?/B003i7@00cJl000290@00?4H000DN00068000Ad/03Xl00=:P003k5000nA/00<f^0000R@00
03a600057P001R0004Q<016@003CWP00na800?PN003</P0008L5000hA00011d000LQ001>CP0JU000
eYD00?`>003g9000b;`000224000<40000@L00098`00E4`0;9X00=^6003n1`00m3000;S10000NQl0
02Hj00036P003BL005]704NS003RL@00o`800>m2002B^000070_000K<`000QT001<]001V?@1][P00
jEL00?l0003XG000IZ`0001T?`004B/0008I000N=@00Lb/0X;`00?4j003n1000gWd003FM0000ET/0
00XT00047000<T4008@<0<^e003h7P00na@00=6U0004R`0003e600057@001b40051>02>G003JRP00
oPP00?<b002__`0007LU000Q=`000QX0014[001T?`1X[@00jEP00?l0003WG`00GJX0001P@`003bT0
01DZ001k7@32a000mRT00?`=003EV@0049000013B@001Ah000LP001?CP0QUP00fXX00?h7003c=000
Ykd0001d:P007C@0008I000D;P00JCT0P;<00>e8003o0@00hG<003fP0000EdX000TT00047000=d<0
08T00=2W003k4`00n2400<Nm0000OQL002Pk00036P003RT0065206>/003YF@00o`000>IU001AYP00
05a7000<9P000a/0035000252@3=[P00nQH00?PN0039^P00080E000Y?0000aX000lY001R@@1X[@00
jUD00?l0003TJ`00AZ<0001HB@002R@000@L000iA004R`00dj000?`>003e:@00^/80001g90007cH0
008I000E;P00K3H0S[L00?0n003n1@00fhL001nF0000BTd000HO00078000DDd0;I/00=mk003o0P00
kDP007Vb0000ISd0014[00026P00:3/0080E0<Zh0080nA/001T0bKP0001o5P009c/0008J000A:`00
Ic`0Ok<00>m4003o0`00g8<002>G0000Bdd000HO00078@00DTd0=Id00>5d003o0@00je8006J/0000
H4<000dW00036`00<d4008T100[ooooo0Ol00001ooooo`007_ooool3o`0000Oooooo0?l001D_0002
6@003BP005E;01ZD003@Y`00mb400?d8003PMP00FjT0001Y>@0073@000<J000:9000Cdh01hd00<Zf
003e;000oP@00>AY001^[`0006hc000Q=`000a/000PR0017B`00R@40akd00?<a003o0P00iV<007Ja
0000L30002<h00036`00228004I:00280P37_P00lc800?l2003VI000Lk00001_<@008CL000<K0009
8`00BT`00h/00<Zh003e;000oP@00>=/001U[00006/g000M=0000aX000/U001AC@0AT@00cj/00?LR
003m2@00gg`004fU0000I40001H_00026@003bT005U902ZJ003FUP00naD00?/C003GT`00;I/0001J
B0003bT0008I000F;`00I3l0CjH00=mi003n2000mRD00<ba0008S@0004a=00098`000a/002@i001b
;024]@00jEL00?l0003_@P00Z;h0001l7000<40000@M00067`00?DH008D:0<K2003c<P00o`<00>=/
001QZ`0006Pj000I<P000QT000hX001HB@0/VP00f9800?/A003j6000dil001^D0000Dd`000/U0003
6P0083H006la0;>6003o0000kd<00:>m0000NR0002`m000470001b4004I;00B;003</P00mb@00?d:
003MPP00?j40001MA@0042X0008I000G<000ISd0GJX00>=/003o0`00lSD00;g30000P1@003A20005
7@001Ql003m700281039^@00mRP00?d8003NO`00@J40001NA@0042X0008I000H<@00J3X0IZ`00>EU
003o0@00l3d00:^n0000Nah002/m00047000228004e>00n@003AY@00nAX00?/B003FU`0089H0001C
C0002R@000<K000U>@00MRL0VKX00>i5003o0000ieh006n_0000JSP001Ta00026@004B/005m404VT
003PM`00oPD00?<b0030``0007lE000a@00011`000LQ001:C@0>S`00dJD00?XI003k5000e9d001NC
0000Cdh000PR00047000;Ch007dI0;W2003c=000oP@00>1f0018X`0005i5000?:P000QT001`c001^
<P22]000je400?l0003YE`00M[40001[=`006C40008I000B;000HT40EjP00>A[003o0P00l40009nk
0000MRL002<h00036P0032L005U903RN003MP000oPL00?@_002o``0007hH000]?P000a/00?<000TS
001BC@0TU`00f8l00?d<003g9@00b;/000243000=48000@M00088@00CTh069<00=FI003l4000n200
0<^d0000Q`D003U400057@001b0004]=01>A003DW000na400?PN003</P0008L4000iA0001Ad000LQ
001<C@0FTP00eIT00?`@003h8@00b[H000252P00=D8000@L00088P00D4h07iH00=RA003m3000mRP0
0<K00000P1@002ho00036`002R@005E;036L003MPP00oPH00?<d002``00007PR000T>@000aX000hX
001MAP1=Y@00hfd00?l1003^AP00RkL0001^<P006S80008I000D;P00J3/0M;000>YC003o0000if00
05nZ0000HT40010Z00026P0083H007DW0:Nm003b=`00oPD00=f1000_V`0005A<00098`0011`003A2
00261`3</@00nA/00?XF003?Z@0008T0000iA@0011d000PR001BC@0YV@00g8D00?h6003b=@00Ykh0
001e:0007cD0008I000B;000ICd0Kjl00>YD003o0000iV@005JX0000GT@000hX000F:`00OAT0aL80
0?HV003l3`00e9d000^>0000@4P000DN00078@00D4h09YP00=^6003n1P00lSP009nl0000LRd001/c
00026@005Rl006/f08Ne003^A@00o`800>1h000gWP0005E;00098`0011d003Y500>;003BX`00na40
0?LT0036`@0007dK000V>P000QX0010Z001S@01Z[@00jU@00?l0003TJ@00BZ@0001JB0002bD000<K
000c@P00Q`@0cjX00?/D003h8@00akh0001n60009cX0008J000@:P00I3l0KZl00>]A003o0000hVl0
042Q0000EdX000TS00047@00?4H02Hd00=BK003l3000mB`00;;00000MBL001dd00026@005Rl006hc
09Fi003a>P00oPH00=Z;000JU00004M;00057P001b40059=03>M003PM`00o`400>a<001b/00006@o
000?:P000aX002Xl00214@3;]000nQP00?PN0038_00007dI000U>@000QX0018/001Y>@26]@00l400
0?h5003KQ`007ID00018B`001Ah000PQ001DC00kW`00hW000?l0003ZEP00H:/0001NA@0032H000<K
000f@`03R`002?ooool3o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0=0001@]0002
6@003RT005M:01nF003BX`00n1l00?d:003ONP00E:L0001W?0006S80008J000;9@00D4d038l00<bb
003f:@00oPD00>=]001W[@0006`e000O=P000aX000TS001;C@03R`00bKT00?@^003o0`00iFL006n_
0000KS<0024g00036`002B<004U<006:0039^P00m2h00?l3003TJ000K:h0001]=0007cH000<J0009
8`00CTh01hd00<^d003f:@00oPH00>9a001OZP0006Ti000K<`000QX000/V001CC00FTP00d:H00?PO
003m2`00gH0004NS0000HT4001D^00026@0042X005]8032L003HT@00na800?XF003FV0009iT0001H
BP003RP0008I000H<000ISd0EZP00>5e003n1P00mRP00<^e0003R`0004Q<00088P000a/002Hj001d
:@2;]P00je<00?l0003^AP00XK`0001j7`00;Ch000@L00078000@4P008L60<Nn003d;P00oP@00>9`
001KZ@0006Hl000H<0000QT000lY001JB00bW000fHd00?`?003i6`00dJ@001JB0000DDd000XT0003
6P008SL0074^0;N5003o0000kTL009bk0000N2<002Tl00037000228004Y<00R=003=[P00mb400?d;
003KQP00>Il0001LA`003bT0008I000H<@00J3X0I:`00>EX003o0P00lST00;K10000OQP003500004
7@001b0004=9002:003;]000mbD00?d:003LP`00>il0001LA`003bT0008I000J<P00JSP0KJh00>MQ
003o0@00kd400:>m0000NB8002Tl00036`002B<004m>01BB003BX@00nQL00?/D003DV`006i@0001A
C@002B@000<K000W>`00N2@0XK`00>m2003o0@00iV<006R]0000J3/001L`00026@004R`0065204nV
003QLP00o`@00?8e002h`P0007dI000^?`0011`000PR001>CP0CT@00dZ400P3j5P00o`3BX@004Y40
001=CP00224000@L000`@000OaH0`<<00?@`003n1P00gg/0046Q0000G4H000hY00026P007SD0070`
08Vf003/C@00o`000>QK001_[`0006Ti000G<0000QT001<]001T?`1NZP00iFH00?l1003_@`00V;X0
001d:P008CL0008J000=9`00FdP0?Z000=ml003n1@00lc<00;S20000O1`002Xm00036`002R@005A<
02VI003JR`00o@X00?HX0037_`00088@000b@@0011`000PR001@CP0MU@00ei@00?`>003g8P00b[P0
00252P00=T<000@M00078@00CTh069<00=FH003l3`00n2400<Zf0000Q@T003I300047@00224004m>
01^D003FU@00o0h00?LT0039^`0008<>000b@@0011`000TR001BC@0UV000fH`00?d:003e:`00a<@0
001n6000:cd000<K000;9@00EdX0=ih00=im003n1@00lSL00:Vn0000MRH0028h00026P003bT005m4
05>W003TJ@00o`000>e:0024]@0006`e000H<@000QT001H_001Z>@1j/P00k4l00?l0003VI000FJT0
001P@`003bT0008J000R>000Mb@0[[l00?<c003n1`00fhH002VI0000DTd000PR00047@00=d@008P3
0<j]003j6000nQT00<j^0000Q`@003I3000470002B<005=<02nK003MP@00oPD00?4i002P_00007<[
000M=0000QT001<]001W>`1f/@00je000?l0003UJ000D:H0001MAP003BL001L/001o5P37_P00mb<0
0?/A003BX@001X`0000mAP0011d000PR001BC@0/VP00gH400?h5003a?000V;X0001`<0006S80008I
000G<000KC@0S[L00>m1003o0`00gW`0036L0000Dd`000PR00047@00?DH028d00=>N003l3`00mRL0
0<;40000Nah002@i00026P004B/006Dn072_003[D000o`000>=]0014XP0005Q9000:900011`003I3
0029003AY@00na800?LT0035`P0007`L000T>@000QX0014[001U?@1e/@00k4d00?l1003QM000>Yl0
001EB`00228000@M000oA`0>S`00eYL00?d;003d<000Zkh0001c:`006c<0008I000H<@00L300WK/0
0?8f003n2000f90001FB0000@dT000DN00088P00E4`0>Il00>5c003o0@00je0006b^00008@00HT40
00hY00036P00;3h008<=0<f_003j5P00n2400<K00000Nad002<h00026@0052d006/g08fg003`?@00
oPH00=Z;000HT`0004A:00057P00228005I;046Q003TJ`00o`000>QJ001IZ@0005a6000;9@0011`0
03U400N=000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`004b`0008I
000?:P00FDT099P00=>N003i7000o@`00=io001>Y@0006Dn000I<@000QX000`V001BC@0AT@00cZd0
0?HU003n1P00hW80062[0000JSP001dd00036P002R@004m>00R=003;]@00mB/00?h4003SK000J:d0
001/=@007cD000<J00098`00CDh01X`00<Zf003e:`00oPD00>=]001V[00006/g000M=@000aX000XT
001@CP0<S`00cJl00?HV003n1`00hGD005RX0000Ic`001Tb00026P0032L005A<01bD003BXP00nA`0
0?`=003LQ@00@J40001P@`004bd0008I000A:`00G4H0=Id00=V=003l4000nQP00=BL000RU`0005I;
000=9`000QT001Tb001W>`1LZP00hW400?h5003e;000bKX000290000ADX000LQ00047000:3/007HV
09:h003/CP00o`000>e:002J^P0007PS000[?@0011`000LQ0013B@00R@40bKT00?D[003n1P00hG@0
05BW0000ICh001H_00026@0042X005a703RN003JR@00o0d00?PN003@Z0004900001?CP002B<000<K
000T>@00Lb/0^h@00?l0003]B`00UKT0001f9P009c/000<K00098P00CTh03Hl00<nZ003h7P00o0d0
0=Z;000cW@0005Y8000>:0000QT001Xb001Z>01[[P00iV<00?l1003a?@00[[l0001l6`00;Sl000@L
00078@00AT/01H/00<f`003g8P00o@`00=^8000eW@0005Y8000>:0000QT001/c001/=@1d/000j5`0
0?l0003^A@00W;/0001g9@009cX000<K00098`00DDd06Y@00=BM003j5@00nQL00=>P000FTP00051>
00098`000a/002Tl001j802X_P00l3h00?l1003UI`00HJ/0001V?@005Rl0008I000C;@00Hd00EZP0
0>=^003o0`00lST00;700000Nad002/m00036`002B<0051>01RC003DW000na@00?TI003AYP003Hl0
0019C0001b4000@M000c@@00PA80aL<00?D]003n1`00gGl003^O0000FTP000dX00026P0083H0078]
092h003]B@00o`000>MP001Y[@0006Ll000F;`000QT001D^001V?@1T[000iV800?l0003^A`00TKP0
001b;@007cH0008J000>:000G4H0A:800>1g003n1000lSH00;700000NQl002Pk00036`00l`002bD0
05I;02nK003KQP00o@T00?D[0035``00080D000_?`0011`000TS001BC@0RU`00f9000?d<003f9@00
b;`000233P00<d4000@L00088P00D4h07YD00=NC003l3@00mb@00<Vk0000P`d003=1000470002280
055=022F003HT000o@`00?HW0037_`00084B000_?`0011`000TS001DC00ZVP00fhP00?d8003d;P00
_L<0001l7000:C`000<K000<9P00FDT0?J000=mi003o1000lC/00::l0000MBT0020f00026P0042X0
065205ZY003VI000o`000>a>001m/`0006/g000G<0000QT001L`001/=P21]000kD/00?l0003TJ000
DZL0001NA@003RP000<J000T>@00NB40]/400?@`003m2000fXX002BG0000D4d000PQ00047@00>TD0
0HX00<nY003j5P00nA/00<bb0000Q@P003=2000470002B<005E;03BM003NO000o`@00?0m002I^P00
074^000K<`000QT001D^001Y>@1m/`00k4`00?l1003SK000BJ@0001KA`0032H001P]00214P39^P00
n2000?/C003AYP000XX0000jA@0011d000PR001DC00bW000gWd00?l3003`?`00TKP0001^<`006340
008I000I<@00Kc40UKT00?0m003n1000gH4002^J0000DDd000PQ00057P00@4P03Hl00=FJ003l3@00
mBX00;_20000NB80028g00026@004R`006Ll07Na003/C000o`400>9b000nX00005I:00098`0011`0
03U500B;003BX@00o1000?HW0031a00007XP000R>0000QT0018/001W>`1l/P00kDT00?l2003PN000
=9d0001CC000228000DN0012B@0CT@00ei800?d9003c<`00Y;d0001a;P006S80008I000J<P00LBh0
Y;d00?<c003m2@00ei@0012@0000@4P000@M00098`00ET/0?j400>=^003o0000jUD006F/0000H4<0
00dX00036`00;cl008D80<n[003k4`00mb@00<C40000NB40020g00026@005Bh006de09Bi003a>@00
oPL00=R@000CT@00041800047@002B<005M:04NS003UI`00o`000>MO001CY`0005]8000:900011`0
03a600b?000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`004B/0008I
000A:`00FTP0:YX00=FJ003i6@00o0h00=b30017X`0006=0000G<0000QT000dW001DC00GT`00cjT0
0?LR003n2000h7H005ZY0000J3X001/c00026P002bD0051>00b?003</@00mRL00?h6003RL000HZ/0
001Z>0007C@000<J000:9000Cdh02hh00<ba003f:000oPH00>9a001OZP0006Ti000L<`000QX000/U
001AC@0AT@00cj/00?LS003m2@00ggX0056V0000ICh001P`00026@003BP005I;026F003CWP00nAT0
0?`?003JR@00>il0001NA@004R`0008I000B;000GTD0>il00=^8003l3P00nA/00=:Q000LU@0005A<
000<9P000QX001/c001Y>@1SZ`00hf`00?l4003d;`00akh000271@00@DP000LP00047000:cd007PS
09Zj003]BP00o`000>a>002B^00007HV000X>`000a/000PQ0017B`02R`00bkD00?HX003n1`00ggT0
04jU0000Hd0001D^00026@004B/005i503jP003LQ000o@/00?PQ003>[0002hh0001=CP002B8000<K
000V>P00MBP0_h<00?l0003/C`00S[L0001d:P009CT000<K00098`00D4h04Y400=6U003i6`00o0l0
0=R?000]V`0005Q9000=9`000QX001`c001/=P1a/000iel00?l1003`@000Ykd0001j7`00:cd000@L
00088@00BT`02Hh00<j/003h7`00o0d00=V<000_V`0005Q9000=9`000QX001dd001^<`1k/P00jEP0
0?l0003]B@00UKT0001e:00093T000<K000:9000Dd`07iH00=FH003k4`00nAT00=6T000AT00004i>
00088P0011`002`n001k7@2__`00lCX00?l2003TJ`00FZT0001T?`0052h0008I000D;P00ICh0G:X0
0>AZ003o0P00lC`00:Vn0000NB0002Tl00036`002B<0059=01fE003FV000na400?TL003?ZP0028d0
0016BP001b0000@M000e@`00P`d0akh00?DZ003m2@00g8@003FM0000FDT000`W00036P008SL007@Z
09Ni003^A@00o`400>IT001RZ`0006Dn000D;P000QT001H_001X>`1[[P00j5h00?l0003]B`00RKH0
001`<0007C@0008I000?:@00GTD0Bj@00>5c003o0`00lCX00:Vn0000N2<002Hj00036P00l`0032H0
05Q:03FM003MPP00oPL00?@_0030``0007hH000/?P000a/000XT001DC00XV@00fX/00?d:003f:@00
a/0000214P00<40000@L00098`00DTd08iL00=V?003m2`00mRL00<No0000PA400310000470002B<0
059=02JH003IS000o@X00?DZ0035``0007lF000]?P000a/000XT001EB`0`W000g8<00?h7003c<P00
]/40001j7`009SX000<J000<9`00FdP0@j800>5d003o0`00l3l009Zj0000Lb`001he00026@004B/0
06=0062[003WH000o`000>]B001f/@0006Tj000E;P000QT001Ta001]<`29]P00kTL00?l1003SK@00
C:D0001MAP003BL000<J000W>P00Nad0_L<00?D/003m2P00f8l001jE0000Cdh000LQ00057P00?TL0
1H`00=6T003k4`00n1h00<Zf0000P`d0035000036`002R@005M:03ZO003PN000o`<00>m1002B^000
06la000I<P000QT001H_001[=`24]000kTP00?l1003RL@00@j80001IB@002bD001T]00233@3;]@00
nAd00?XF003?ZP0008P2000g@`0011`000TS001EB`0hWP00h7P00?l2003_@`00R[H0001/=@005Rl0
008I000J<P00LBh0W;/00?4i003n1P00g8D002JH0000D4h000LQ00057P00A4X04Y400=JE003m2`00
m2h00;?00000MbD0020f00026@004bd006Pj07jc003]B000o`800>1f000hWP0005E;00098P0011d0
03e600V=003DW000o0d00?DZ002j`P0007PS000P=P000QT001<]001Y>@23]000kTD00?l3003NO@00
;Y/0001AC@001b4000DN0016B`0HT`00fHh00?h7003b=`00W;/0001`<0006340008I000K<`00Lb/0
Zkl00?@_003m2`00eIT000^>0000?4H000@M00098`00F4X0AJ<00>AZ003o0000jET005jZ0000GT@0
00`W00036`00<T4008L40=2W003k4@00mRL00;g30000Mb@001he00026@005c0006lb09bk003b=@00
o@T00=ND000>S`0003e6000470002R@005U904fU003VH`00o`000>IS001<Y@0005U900098`0011d0
03m7016A000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`0042X0008I
000B;000G4H0<9`00=JE003j5P00o1000=^80011X@000652000E;`000QT000hX001FB`0LU@00dJ@0
0?PO003m2P00gg/005>W0000IS`001Tb00026P002bH0059=01:A003>[000mb@00?h7003QM@00FjT0
001X>P006c<0008J000;9@00DDd049000<j]003g9000oPL00>1f001HZ00006Lk000J<P000QX000`V
001CC00GT`00d:L00?PP003m2P00gWh004^T0000Hd0001H_00026@003RT005Q902NH003EV@00nQL0
0?/A003ISP00=9d0001LAP004B/0008I000C;@00H4<0@Z400=b4003m3000n1h00=6U000GT`0005==
000;9@000QX001dd001[=P1Z[@00iFP00?l3003c<`00aL8000252@00?TL000HP00047@00;Sh007XO
0:6l003^AP00o`000>]C002;]P0007@Y000V>P000a/000PR001;C@07S@00c;400?LT003m2@00gWh0
04NS0000HD8001<]00026@004R`0061304BR003MP000o@T00?LT003</@001X`00019C000228000<K
000Y?000Mb@0`h800?l0003ZD`00Q[D0001b;@008SP000<J000:9000DDd069<00=:Q003j6@00na80
0=ND000WV@0005I;000<9P000QX001he001^<`1i/P00j5/00?l0003^A000Wk`0001h8`00:C`000<K
00088P00CTh03i000=2W003i7000o1000=RA000YV@0005I:000<9P000QX001lf001`<022]000jU@0
0?l0003/C@00SKL0001c;0008SP000<J000;9@00ED/09IP00=ND003l4000nA`00<nY000;SP0004Y<
00078@0011`002lo001n6@2g`@00lSH00?l3003RL000E:L0001R@@004bd0008I000F;`00IS`0Hj`0
0>EU003o0@00l4000::l0000Mb@002Hj00036`002R@005=<02>G003GT`00o0l00?PN003=[P000h/0
0012B@001Ql000DN000iA000Q@T0bKX00?HV003m2P00fhP002nK0000EdX000/V00036P0093T007HV
09jk003_@@00o`400>AX001KZ@0006=0000C;@000QT001P`001Z>@1b/000jET00?l0003[D000P[@0
001^<`006c<0008I000@:`00H4<0DJH00>=^003o0P00l3h00::l0000MRH002<h00036P00l`0032L0
05U803^O003NO@00oPH00?<b002h`P0007`L000Z?0000a/000XT001EB`0^V`00fhL00?d9003e;000
a<@0001o5P00;Ch000<K00098`00E4`0:IT00=Z:003m2P00mBX00<G30000OaD002dn00036`002R@0
05A<02bJ003KQ`00o@P00?@]0030``0007dJ000Z?@000a/000/U001GBP0fWP00gWl00?h5003b=@00
[[l0001h8`0093T000<J000=:000G4H0BZ@00>9`003o0P00kd8009>h0000LBl001`d00026@004R`0
06Dn06N]003XG000o`000>YF001_[`0006Ll000D;@000QT001/c001_<@2@^000kd<00?l2003RL@00
AJ<0001KB00032H000<K000Y?000OAT0aL@00?HY003m3000ei<001VC0000Bdd000LP00057P00@DP0
2Xh00=>P003k4@00mb400<Vk0000PA4002ho00036`002bD005U9046Q003QL`00o`800>i5002:]P00
06dd000H<0000QT001P`001]=02;]P00kd@00?l2003QM@00?J00001GBP002R@001/_00252@3</@00
nAX00?XH003=[`0008H7000d@P0011`000XT001GBP0nX000hG@00?l2003^A`00Pk@0001Z>0005Bh0
008I000L=000Lb/0Y;d00?8f003n1`00fXX0022F0000CTh000HP00067`00Ad/05i<00=RA003m2@00
m3400:bo0000MBP001he00026@005Bh006Xh08Je003_A000o`<00=mk000bW00005=<00088P001Ad0
041800j?003EV000o@`00?@]002b`00007HW000N=@000QT001D^001[=P2:]P00kd400?l4003MP@00
:9T0001@CP001b0000HO001:C00MU@00fXT00?h6003a>`00UKT0001^<`005Rl0008I000M=000MBL0
/l000?D/003l3@00did000J<0000>D@000@L000:9000FDT0C:D00>EU003o0000j5d005RX0000GDH0
00/V00036`00=D8008T00=:R003l3`00mBX00;G10000MBL001dd00026@006340074_0:>m003c<P00
o@/00=FI0009S@0003Y5000470002RD005]705BW003WGP00o`000>EX0016X`0005M:00098`001Ad0
049901NC000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`003bT0008I
000C;@00GTD0=Yh00=R@003k5000na800=V=000kW`0005m4000D;P000QT000lY001GBP0RU`00dj00
0?TL003m2`00gWl004bU0000I3l001Pa00026@0032L005A<01NC003@Z000mb400?d9003ON@00E:L0
001V?0006C80008J000<9P00Dd`05I800<nY003g8@00o@T00=mj001AYP0006Dn000H<@000QT000dW
001EB`0LU@00dZ800?TM003m3000g8<004FR0000HD8001D^00026@003bX005Y802fK003GU000na@0
0?/C003GT`00;Y/0001JB00042X0008I000E;P00HT40B:<00=io003m2P00n2400<nZ000AT@00055=
000:90000aX001le001]=01a[`00iV<00?l2003b=P00`L@000233P00>TD000HO00047@00<40007`K
0:Vn003_@P00o`000>UG0024]000078]000S>0000a/000TS001>CP0<S`00cZ`00?LQ003m2`00gH80
046Q0000Gd@0018/00026@0052d0069204ZT003ON`00oPP00?HW003;]@000HX00015BP001b4000@L
000[?@00NB40b8400?l0003YF000Ok<0001`<00083H000<J000;9@00Dd`07ID00=BL003j5P00na@0
0=FH000RU`0005A<000;9P000aX0020f001`<020/`00jUH00?l0003]B000V;X0001f9P009SX000<K
00098`00D4h059800=:S003i6@00na800=JF000SU`0005E;000;9@000aX0024g001b;@29]P00je00
0?l0003[D@00Q[D0001a;`0083H000<J000<9P00ETX0:iX00=R?003l3P00n1l00<j]0006S00004I;
0007800011d0035100205@2o``00lc<00?h4003QM000CJD0001P@`004B/0008I000H<000J3X0JZh0
0>MQ003o0000kd@009Zj0000MBL002@i00036P002bD005E;02VI003ISP00o0d00?LQ003</`0008T1
000oA`001Ql000DN000lAP00Q`@0b[H00?LS003m3000fHd002VI0000ED/000/U00036`009SX007PS
0:Jm003`?@00o`800>=]001DY`000652000B:`000QT001Tb001/=P1i/P00jUD00?l0003ZE000Nk80
001/=@006C80008I000B;000HT40F:P00>AZ003o0@00kd8009Zj0000M2T0024g00026P00F0003BP0
05]7046Q003PN@00oP@00?8f002``00007XP000W>`000a/000/U001GBP0dW@00gH800?h7003d<000
_L<0001m6P00:cd000<K000:9000ED/0;i/00=b5003n2000m2h00;o30000OAT002/m00036`002RD0
05I;03:L003LP`00oPL00?@a002h`@0007/N000X>`000aX000`V001IB@0lX000ggX00?h4003b>@00
Y[d0001f9P008SL0008J000>:@00GTD0D:H00>A[003o0@00kTH008^g0000Kc8001Xb00026@0052d0
06Hl06j_003YE`00o`000>QK001X[@0006Dn000B;0000QT001`d001a;P2G^P00l3l00?l3003PMP00
?j40001IB@002bD000<K000/?@00OaD0a/000?HV003l3P00eIP001>A0000B4/200067`0g0015BP0@
T000e9/00?`?003g9000akl0001o5@00:cd000<K000<9P00FdP0Aj<00>=_003o0@00kDT008>d0000
JcL001H_00026@006C8006la09:h003`@000o`<00=mj000gWP0005E;00098`007C0008L40<j]003j
5`00nA/00<bc0000Q0/0035000036`002bD005U904BR003RK`00o`400>e;001k/P0006Pj000D;@00
0QT001he001e:02[_P00lc800?d9003IS`006Y@0001:C00200067`0T001;C@0MU@00fH`00?h8003c
=@00Y;d0001c;00073<0008I000F;`00K3D0SKL00?10003o1000gWl002bJ0000DDd000LQ00057P00
A4T04i400=NC003m2P00m3400:^n0000M2X001`d00026@005Rl006dd09:h003a?@00oPD00=^6000R
U`0004e>0P001Ql0>P00CTh08iL00=b5003n1@00l3h008fg0000K3H001D^00026@007cH007LT0;_2
003f:000o0l00=:R0001RP0003I3000470002bD005]705:W003WH@00o`000>IR001AYP0005]8000;
9@0011`003Q400F;003CWP00o0d00?@]002]_`0007<[000K<`000QT001Xb001c;02[_P00m2h00?`<
003CWP0018/0000g@`000a`000/V001MAP1JZ@00jEX00?l0003SK000@:40001EB`00228000DN0016
B`0LU@0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0F0003RP0008I000E
;P00H4<0?:000=V<003k4P00na@00=RA000eW@0005i5000C;0000QT0010Z001IB@0WV@00e9/00?TJ
003l3@00g8@004JS0000HT4001H_00026@003BP005I;01fE003AX`00n1h00?d;003NOP00CJD0001T
?`006300008I000=9`00ED/06i@00=6T003h7P00o@/00=io001;Y00006=0000G<0000QT000hX001G
BP0RU`00dih00?TJ003l3P00fhP003jP0000Gd@001<]00026@004B/005a703>M003HT000na800?XF
003FU`00:IT0001HB@003RT0008I000F;`00I3l0CjD00=mk003m2000mb@00<f^000<S`0004m>0009
90000aX0024g001_<@1h/@00iel00?l1003a>P00^L8000214P00=d@200057P3m000c@P00OQL0/<00
0?0n003o0000j5/007bc0000L300024g00036P002R@0051>01:A003@Z000n1h00?`<003KQ`00>il0
001MAP004B/0008I000E;P00Hd00DJH00>1f003n1P00mBX00<Vj0000R08004990007800011`002ho
001k7@3<P000o`000>QL001h/@0006hc000N=@000QX000`V001EB`0SU`00eYP00?/D003j5P00e9d0
01bE0000Dd`000XU00036P008SL0078]08Ne003[DP00o`000>a=002@^00007@Y000T>@000a/000XT
001BC@0IU000dih00?XF003k5000eIX001jE0000Dd`000XT00036P008cP007@Z096h003]B`00o`00
0>YF001o/`0006lb000N=@000QX000dW001HB@0aW000fXX00?d<003g8P00c;80006:0000@TT000HP
00047@00=480088A0<G3003d;`00oPH00=mi0017X`0005i4000@:P000QT001Tb001Z=`1a[`00j5`0
0?l0003]B000TkP0001c:P008SL000<J000<9P00EdX0;i/00=Z:003m2`00mbD00<Zg0000Q`H003]6
00057P001Ql003m70029003</@00n2000?`>003GTP0099L0001CC0002R@000<K000Y?000NQl0[[l0
0?4i003o0`00hW8004jU0000H4<0010Z00026@006c<006hc082d003[D@00o`000>UH001d/00006Xh
000H<0000QT001<]001T?`1OZP00iFD00?l1003^AP00TkP0001b;@007cH0008J000>:@00GDH0B:<0
0>5d003o0`00lCX00:Vn0000N2<002Di00036P0032H005U903ZO003NO@00oPD00?<c002e`@0007/N
000X>`000a/000/U001GBP0eW@00gH400?h6003c<@00^<40001k7@00:3/000<K000;9@00F4X0>9h0
0=in003n1@00lcD00;300000NB4002Dj00036P003BL005]704>R003QM@00o`<00?0m002O^`0007@Z
000P=P000QX0010Z001P@`1GZ000iFL00?l0003]B`00Q;D0001]=@006340008I000E;P00J3X0MK40
0>]C003o0000iel0066[0000Hd00014[00026@007SD007<[09nk003a>`00o`@00=mk000iW`0005M:
000:9@000a/002ho00214@38_000mb800?`@003DW@003Xl00014BP0200067`2I0019C00ETP00eYH0
0?`=003f:000aL<0001m6@00:C`000<J000=9`00G4H0CZD00>AZ003o0000k4d007bb0000JCT001D^
00026@006c<0074^09Zj003a?000oP@00=io000aW00005A<00098P007S0008T00=2X003k5@00n1h0
0<Zg0000PQ0002ho00036`0032H005]704^T003TJ`00o`000>]@001d/00006Hl000B;0000QT0020f
001g9@2c`000m2h00?d:003GT`005I800016B`001Ah000LP001?CP0SU`00fhL00?h6003b>000WK/0
001a;`006S80008I000H<000KS80U;T00?4l003n1@00g8@002JH0000Cdh000LP00057`00Ad/069<0
0=V?003n2000lc@00:>l0000LRd001Xb00026@00634006la09Vj003b>@00oPH00=Z:000MU@0004U<
00067`001b00051>02VI003MP000o`<00>m20026]@0006Xh000C;@000QT0024g001i8032a000mbD0
0?/A003@Y`0008P3000c@@000a/000`V001MAP1IZ@00j5`00?l0003UIP00BZ@0001IB@002R@000@L
000kAP0:SP00eIT00?d;003d<@00Y[d0001a;P006C40008I000L<`00MBT0//000?D[003l3P00dZ80
00290000=48000<K000<9P00Gd@0HJ/00>YE003o0000hW4003VO0000Dd`000LQ00057P00BT`08YL0
00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1H000=9`000QT001H_001R
@@13XP00fhL00?`?003j5`00eYH002jK0000G4L0014[00026@004B/005]702fK003FUP00nQL00?`@
003KR@00?j40001Q@`005Bh0008I000>:@00EdX08YL00=>O003i6`00o0d00=b20017X`000691000F
;`000QT000hX001GBP0PUP00dil00?TK003l3@00g8@004BR0000HD8001D^00026@003bT005U902RI
003EV@00nQL00?`@003IS000>9h0001MA@004R`0008I000B;000GTD0>Il00=Z;003l4000nQP00=BL
000SU`0005M:000=:0000QT001Pa001V?@1EZ000h7H00?h7003f9`00c;<000N=0000C4d000TS0003
6`008cP0074^07nc003XFP00o`000?0n002b`00007lF000d@P8000DN0?l003I300204`2h`P00lCX0
0?l1003WH000MK40001^<`007cH000<J000;9@00DTd05i<00=6S003i6`00o0l00=Z<000dW@0005]7
000?:P000QT001L`001U?@1HZ000hW800?h5003d;P00akh000261`00?TL000HO00047@00<D0007dI
0=1o003o0@00if40076_0000K3D001`d00026P003BL005M:02VI003GT`00na400?TI003BXP005Y<0
001AC@002R@000<K000T>@00M2X0SkL00>a>003o0000je4008Vf0000LRd0028g00036P002bD005=<
01nF003EVP00na@00?XG003CW`0069<0001AC@002B@000<K000V>P00MRL0V;X00>i7003o0000jEX0
07Na0000KC@001`c00026P003RP005Y803NN003LQP00o@X00?LU003:]P0008P2000oA`001Ql000DN
000hA000Q0`0akl00?D[003n1`00gWh0042Q0000GDH000lY00026@006c<006`e07Ra003YF000o`00
0>a=002;]P00074^000P=P000QX000dW001IB@0eW@00g8D00?d9003f:000b;`000252P00>4@000DN
00068000@dT018/00<j]003h7@00o1000=JF000NU@00055=00098`000a/002/m001l702e`@00lSD0
0?h4003PMP00Aj<0001NA@003bT0008I000M=000L300R;H00>a<003o0000j5d006f^0000J3/001H_
00026@005Bh006Hm06J/003WH000o`000>e:002;]P00070`000M=0000QT0010Z001OA01>Y@00hVl0
0?l2003`?P00XK`0001f9`008cP000<J000=9`00FdL0@:400>1i003n1000lSL00:fo0000NB8002Hj
00036P0032H005U903^O003OO000oPD00?8e002``00007TQ000V>P000aX000`V001JB00nX000ggT0
0?h4003b>000Z;h0001g9@008cP000<J000>:000GDH0BJ@00>9a003o0P00kd4009Nj0000LRd001he
00026@004B/0069105jZ003VHP00o`000>a?001m/`0006/g000G<0000QT001L`001Z=`1l/`00k4l0
0?l0003VI000FZT0001Q@P0042X0008J000Q=`00MBL0Ykd00?8g003n1@00gGl003>M0000ED/000XT
00047000<D0008<=0<Zg003h7`00na800=:Q0009S@00041800057P001b0004X004e>01ZD003HTP00
o@/00?D[002o``0007/M000V>P000aX000hX001NA@1DY`00iFH00?l0003[D@00M;00001W?0004bd0
008I000M=000Lb/0XK`00?8h003n1@00g8<002ZJ0000DTd000PR000P<P04R`00dJ<00?/B003h8@00
b;`000205000:cd000<K000=9`00GDH0DJH00>EV003o0000jU@006f^0000I3l0014[00026P008SP0
07TQ0;_2003e:`00o@`00=FH000@T000049900057P001b40051=02RI003LP`00oPD00?4l002E^@00
06lb000H<@000QT001Tb001`;`2L^`00lSP00?h6003KR@0089H0001=CP8000HO04d004]=01jE003J
RP00oPH00?8h002K^`00070`000I<@000QT001Xb001a;P2Q_000lSD00?h8003HS`005i<00016BP00
1Ah000LQ001BC@0_V`00gg/00?l2003^AP00Ok<0001X>`004R`0008J000T>@00O1d0a/400?LR003k
5000cj/000262000<40000<K000=9`00Gd@0H:/00>UH003o0000i6/004BR0000EdX000TS00047@00
?dL03i000=ND003m2@00lcD009jk0000Kc4001L`00026@007SD007LU0;[2003f9`00na400=2W0000
Q`D0035000036`003BL0065206R]003[D@00o`400>5e000cW@00059=000780001Ql004i>02RI000:
ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0]P0032H0008J000H<@00I3l0
BJ@00=f2003l3@00nAX00=BK000XV@0005Y8000@:P000QT0018/001MAP0cW@00ei800?/D003k4P00
fHd003VO0000Gd@001<]00026@0042X005U902RI003EVP00nQP00?`?003KQ`00@:40001Q@`0052h0
008I000?:@00F4T09YP00=BK003j6000o0l00=^8000nX0000613000C;@000QT0010Z001KB00^V`00
ei@00?/D003k4`00f94003:L0000G4L0014[00026@004bd0061303nQ003KQP00o0d00?TK003BX@00
7ID0001EB`0032L0008J000J<P00J3/0G:X00>9a003n1@00mBX00<Zg0002RP0004Q<00088P000a/0
02Dj001c:`27]@00jUH00?l0003_@P00Z[h0001m6P00<D0000DM00067`00>TD0088?0<33003b=`00
o`800>IT001^[`0006`e000M=0000QX000/V001DC00MU@00dil00?XH003k4@00f90002jK0000FDT0
00hX00026@00634006Lk05nZ003SK@00o`@00?<a0035`P0008@<000kA@001Ql000DM000d@P00OaD0
eGh00?l2003UI@00JJd0001Z>0006S80008I000>:000FDT0;i/00=V>003l3`00nA`00=2V000AT000
04m>00098`000a/002Hj001f9`2F^@00kDT00?l0003ZE@00PK@0001`<00083H000<J000;9P00ED/0
9IP00=JE003k4@00nAX00=6T000CT@0004m>00098`000a/002Pk001h8`2P_000kd<00?l0003WG`00
L:l0001[=`006S80008I000?:@00G4H0?J000=f1003m2000mRP00<Vj0000QPL003]60P001Ah0o`00
>dD008H80<Vk003f:000o@T00=b2000jW`0005]8000>:0000QX001dd001^<P20/`00jU<00?l0003[
D@00Q;@0001_<@007SD0008J000>:000FdL0>il00=f0003n2000mB/00<K00000PPl003E200047@00
1b0004M;00V=003@Z000nAX00?/C003DV`0069<0001@CP00228000@L000^?`00OQP0_L<00?<a003n
1@00gg/0046Q0000G4L000hX00026P007cH0078]08nh003]B000o`000>MQ001U[00006Hm000E;P00
0QT001H_001X>`1][P00j5`00?l0003/CP00Q;@0001^<`006c<0008I000A:`00HD80EJL00>A[003o
0@00kd8009Vj0000M2X0020f00026P003RP005e604NS003QM000o`<00?4k002V_@0007LU000S>000
0aX000dW001KA`12X@00h7L00?l4003a>@00Z;h0001g9@008cP000<J000=9`00G4L0AJ800>5e003o
0`00lC`00:6l0000MBP0024g00026P003bT005m4052V003SK000o`400>i5002?^000070`000L<`00
0QT0018/001T?`1U[000j5h00?l0003ZD`00MK40001Y>P005Bl0008I000H<@00K3D0Q;D00>e:003o
0000i6P005BW0000Gd@000lY00026P008cP007LT0:jo003c=000oPH00=b4000/VP0005=<00098`00
11`003A20025203</`00nA`00?XE003@YP0018/0000mAP001Ad000LQ001?CP0PUP00fHd00?d9003d
;`00]l40001i8@0093T0008J000?:@00H4<0FjT00>MQ003o0000jUD006f^0000ICh0018/00026@00
7cH007DX0:Vn003c=000oPL00=^8000UV000051>00078@008S<02Hd00=>O003l4000mb@00<K00000
OQP002Pl00036P003RP005m405RX003VH@00o`000>UH001V[0000691000@:P000QX002Di001k7@33
a000mRL00?`>003DW@002Xh0000oA`001Ad000PR001BC@0_V`00gWh00?l3003`@000SKL0001]=@00
5Rl0008I000K<`00LR`0Y;d00?<e003n2000fHd001ZD0000BD`000HO00068000Cdh099P00=b5003n
1@00lC`009Bi0000KS<001L`00026@0073<007<[0:Vn003c<@00o@X00=ND000BT@00049900057P00
=`00228005=<03FM003PM`00o`400>e;001g/@0006Hm000A:`000QX002Hj001n6@38_@00n1l00?XF
003=/00008@<000]?P000aX000hX001Q@P1W[@00jU@00?l0003RK`00?J00001EB`00228000DM0012
B@0DTP00f8l00?h7003b>000U[T0001]=0005Rl0008I000P=P00NB80`/@00?LT003k4`00cZ/00025
2P00;Sl000<J000>:@00Hd40Kjl00>a=003o0P00ggX002fK0000D4h00P001R000`00D4h0;Y/0oooo
o`09ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0N0002bD0008J000J<P00
ISd0D:H00=in003m2`00nAd00=>P000RU`0005Q:000?:@000QT001@]001OA00jW`00fHd00?/B003k
5000ei8003>M0000GDH0018/00026@004B/005]702jK003FU@00nQH00?/A003IS000>Yl0001OA000
4bd0008I000@:P00FTP0;9X00=JF003j5P00na400=V=000gWP0005i5000B;0000QT0014[001LAP0d
W@00f8l00?/B003j5@00eYH002^J0000FTP000lY00026@005Bh0069204JS003MP@00o@/00?PN003A
Y@005i<0001CC0002bH0008J000L<`00JSP0Hj`00>=/003n1000m2h00<Rl0000R08004A:00078@00
0a`002Pk001e9`2>]`00je400?l0003^AP00X[`0001k7P00;Sl000@M00067`00?DH008D:0<G2003c
<`00o`<00>AY001W[@0006Xh000K<`000QX000`W001FB`0SU`00eIX00?XF003k4`00eYD002RI0000
EdX000dW00026P006S8006Ti06J/003TJ000o`800?8e0030``00088@000gA08000DN0?l003M30022
4@3IO000o`<00>AZ001RZ`0006Pk000I<@000QT000lY001KB00eW@00fXT00?`=003h7`00cj/000^>
0000C4d000PR00036`00:C`007PS09jk003^A@00o`000>UJ001j/P0006hc000N=@000QX000`W001G
BP0[VP00f9000?`?003i7000d:P000f?0000C4d000PR00037000:cd007XO0:Rn003`?`00o`400>IS
001Y[@0006Tj000H<@000QT0010Z001NA@14XP00gg`00?h7003e;000akl000243000>4@000DN0006
7`00?TL008P30<Zf003g9@00o@/00=^7000cW@0005U9000=9`000QX001lf001`;`27]@00k4l00?l0
003ZE@00O;80001]=00073<0008I000?:@00GDH0@Z800=ml003n1P00m2l00<C40000P1<003910004
70001b4004]=00n@003AY000nQL00?XE003CX0004i40001=CP00224000@L000a@000P1<0aL@00?@^
003n1`00gH0003ZO0000FTP000dW00036P008CL007@Z09Ni003_A000o`400>EV001NZP0006@o000C
;@000QT001P`001Z>01d/000jEL00?l0003[D`00O;80001/=@006C80008I000B;000Hd00G:X00>EV
003o0@00kTH009:h0000LRd001he00026P003bT005m404jU003RK`00o`800?0o002N^`0007DY000Q
=`000QX000hX001MAP18Y000hG<00?l3003`?@00X;`0001e:0008CL0008J000>:000GDD0Bj@00>9`
003o0P00l40009Vj0000Lb`001le00026@0042X0065305NX003UI`00o`000>e90028]P0006hc000J
<P000QT001@]001V?@1/[P00jET00?l0003YF000KZl0001W?00052d0008I000J<P00KS80RkL00>i6
003o0@00hfd004fU0000GDH000dX00036P009CT007XP0;K1003d<000oPP00=Z9000VV000059=0008
8P0011d003M40028103=[P00nAT00?XG003?Z`0008T0000iA@0011d000PR001AC@0VV000fhP00?h7
003c<P00[kl0001g9@008CL0008J000@:P00HT40HZ/00>QL003o0000jEX006J/0000Hd00014[0002
6P008CL007LT0;70003d<000o@T00=V=000OUP0004i>0007800093@03i000=FJ003l3P0007T0mRL0
0<C40000O1`002Hj00036P003bT0065205nZ003XG@00o`000>QM001OZP000613000>:@000aX002Lk
001m6@36`@00mb@00?`A003BX@001H`0000kAP0011d000PR001DC00eW@00ggT00?l2003^A000Q[D0
001[=`005Bh0008I000M=000M2T0[;l00?@a003m2@00ei8001FB0000ADX000DN00078@00D4d0:YX0
0=f0003o1000l40008bg0000K3H001D_00026@007SD007DW0;70003d;P00o@`00=FI000<S`0003i7
00047@002B8005E;03bP003RLP00o`400>a?001`[`0006@o000@:P000aX002Pk00205039^000nA`0
0?TI003;]000088A000Z?@000aX000lY001S@01^[`00k4l00?l1003QM000=ih0001CC000224000DN
0016B`0JU000fX/00?h6003a?000SkL0001[=P0052h0008I000R=`00Nah0a/400?PQ003j5P00cK00
00233P00:cd000<J000?:P00ICh0Mk400>e9003o0P00gWl002NH0000CDh000HO00078000DTd0=9d0
00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`0L000:90000aX001/c001X
>`1GZ000h7T00?d9003h8000dJ@001fE0000ET/000hX00026@005Bh00652042Q003KR000o0l00?XG
003FU`00;9X0001KB0004B/0008I000B;000GDH0=Id00=R@0080na<00?l0f94003>M0000GDH0018/
00026@004B/005a603>M003HT@00na<00?/D003GTP00<I`0001LA`004B/0008I000C;000GT@0>Yl0
0=Z:003l4000nQP00=BK000UV00005Q:000>:0000QT001H_001T@01=Y@00gWd00?d9003g8@00cjX0
01:A0000DDd000XU00036P007SD006`f06^^003UJ000o`<00?<b0036`00008H70010B0001b0000@L
000Z?@00N2@0U[T00>a=003o0000kD/009Zj0000N28002/m000470001b00045800271P37_P00m2l0
0?h4003SKP00GjX0001X>`006C80008I000=:000F4X0:IT00=JE003k4`00nQH00=FJ000RU`0005E;
000<9P000QX001`d001[=P1][P00iV@00?l2003a>@00^<8000205@00=48000DN00067`00>TD008@<
0=aj003o1000hfl005^Y0000ISd001L`00026@0042X005e603bP003LQ000o@/00?LR003=/0001X`0
0018C000224000@L000/?@00NQl0Y[d00>m1003o0000ieh007:`0000K3D001`c00026P003BP005U9
036L003JR`00o0d00?PP003>[@0028d00018C0001b4000@L000^?P00O1/0/<000?4k003o0P00iFP0
06:[0000Ic`001L`00026@004R/0061304ZT003PM`00oPD00?@_0035``00088@000e@P001Ad000HP
0012B@01RP00c;400?LQ003l3@00fH`002fK0000EdX000`V00036P008CL007</08ng003]B`00o`00
0>UJ001e/00006/f000J<P000QT0010Z001OA018Y000h7L00?h5003c<`00_<<0001n5`00;cl000@L
00088P00CTh059800=>O003j5@00nQP00=6U000=S`0004U<00078@0011d003A200223`36`000mBX0
0?d9003LQ@00=9d0001HBP0032H000<J000S>000MRL0Wk/00?10003o0@00i6X005NX0000HT40018/
00026@006C8006`e07bb003[D`00o`000>UG001e/00006Xh000H<0000QT001@]001U?P1S[000iV40
0?l0003]BP00R[H0001_<@0073@0008I000@:`00HD80EJL00>A[003o0@00kd<009Ji0000LR`001le
00026P003bT005m404nV003SKP00o`800>m1002H^P0007<[000O=P000QX00=D000lZ001OA01BY`00
i6/00?l1003^A000TKP0001a;`007C@0008I000A:`00Hd40GZX00>IS003o0000k4d0082d0000K3H0
01Pa00026@005Bh006Pj07>`003ZE@00o`000>QL001W[@0006Dn000B;0000QT001`c001a;`2C^@00
kd800?l2003RLP00AZ<0001KA`0032L000<J000X>`00O1`0_/<00?D/003m2P00fHh0022F0000D4h0
00LQ00047@00>dD008X00<nY003j5`00nAX00<f_0000Q`D003I3000470002B8005=<02bJ003LP`00
oPH00?8f002W_@0007DX000O=P000QT0014[001T?`1Z[@00jEP00?l0003WG`00GjX0001Q@P003bT0
008J000T>@00NB40^L800?D]003m2P00f98001VC0000BT`000HO000W=@0DTP00eYD00?d<003e:`00
_<80001j800093T0008J000@:P00Hd00IZ`00>UH003o0000iV8005RX0000GT@000dX00036P00:S`0
07lE0<Rm003h8@00na<00=2V0000RP0003Q4000470002B<005I;03^O003QM000o`400>e9001n/`00
06Tj000C;@000QT001lf001g9@2d`000m2d00?d;003FU`003i000011B0001Ah000PQ001BC@0`W000
gg`00?l3003^A000Q;D0001Z>00052d0008I000P=P00Mb@0^L800?DZ003l3P00did000N<0000>dD0
00@L00098`00EdX0@Z800>=]003o0000jU<006R]0000HT4000hY00036P00:cd0088@0<^d003i6@00
nA`00<Vi0000OaD002Pk00036P0042X006Dn07Ja003]B`00o`800=mi000`W000055=00078@001Al0
04Y<022F003KQP00oP@00?100027]@0006Ti000C;0000QX002@i001m6P38_@00n1h00?XH003;]@00
084C000X>`000QX0014[001W?01n/`00kd@00?l4003LQ0008IH00019C0001Ah000LQ001DC00kW`00
2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l000TS00036P007CD006Xh
05jZ003QM000oPL00?LS003?Z@005i<0001DC0003BL0008I000G<000Hd00Aj<00=b3003l3@00nAX0
0=BL000VV00005U9000?:@000QT001@]001OA00kW`00fX/00?/A003j5P00eYH002fK0000FdP0010Z
00026@004b`005i503VO003IS000na400?XF003FU`00:iX0001JB0003bX0008I000D;P00H4<0@J40
0=^6003l3@00nA/00=>O000OUP0005I;000=9`000QT001Pa001V?@1DY`00h7P00?h8003g9@00cJl0
00b?0000Cdh000XT00036P0083H006hc07:`003VH`00o`800?8e0034a00008@<000mAP001R0000@M
000]?P00NR00W[/00>e9003o0000k4l009:h0000MRH002Tl000470001b4004A:00290@39^@00mB/0
0?h5003QLP00F:P0001V?@005c00008I000?:@00FTP0;i/00=R@003k4@00nQT00=>O000LU@0005A<
000;9@000aX001he001^<`1e/000iel00?l1003`?@00/<00001n6@00<D0000@M00067`00?TL008H7
0=if003n1@00hG<005BW0000I3l001D^00026@004B/005m404:R003MP000o@T00?HV003;]0000HX0
0014BP001b0000@L000^?`00O1/0[[l00?0m003o0@00iV<006^^0000JSP001Xb00026@003bT005]7
03NN003KQP00o@/00?LS003</P000h/00014BP001b0000@M000a@000OQL0^<800?8g003o0`00hfd0
05ZY0000ICh001D^00026@004bd00691056V003QLP00oP@00?<c002n``00080E000b@@0011d000LP
0016B`06S000cZd00?PN003l3`00f94002NI0000ED/000/U00036P008cP007DX09Ni003^AP00o`00
0>MN001][P0006Ti000H<@000QT0014[001Q@P1?YP00hW800?l3003b=`00]<40001l6`00;3d000<K
00098`00D4h06Y@00=FJ003k4P00nA/00<nZ0008S@0004E:000680001Ad003M400242P38^`00mRL0
0?d:003JR@00;I/0001FB`002bD000<K000V>P00N2<0Ykd00?4l003o0P00hVl0052V0000H4<0010Z
00026@006c<006hc08>d003/CP00o`000>QL001][P0006Pk000F;`000QT00>4001D^001W?01[[P00
j5d00?l0003/CP00P[@0001]=0006S80008I000B;000Hd00G:T00>EV003o0@00kTL008jg0000L2l0
01dd00026@0042X0065205JX003TJ@00o`400>i5002@^000074_000M=0000QT0014[001Q@P1IZ@00
iFH00?l0003]B@00RKH0001_<P006c<0008I000C;000ICh0IJ`00>MN003o0000je8007Vb0000JSP0
01H_00026@005c0006Xh07^b003[D000o`000>MQ001OZP0006=1000A:`000QT001he001c;02K^P00
l3h00?l3003PMP00?j40001IB@002bH000<K000Z?@00OQP0aL<00?HY003m3000ei<001^D0000CDh0
00LP00057P00?TL01H`00=6U003k5000n1d00<^d0000Q@X003=1000470002B<005E;03>M003NOP00
oP@00?4j002O_00007<[000M=0000QT001</001V?01a[`00jU<00?l0003VH`00F:P0001OA0003RP0
00<J000V>P00Nad0`L@00?DY003m3000eYL001>A0000AT/000HO000Y=`0JU000f9000?d:003d;`00
]<40001h90008CL0008J000A:`00ICh0KZl00>YD003o0000iFH0056V0000G4H000`W00036`00;3h0
084A0<Zh003h7P00nQH00<n[0000Q`@003E2000470002R@005Q904:R003RL000o`400>a=001g/@00
06Ll000B;0000QT0028g001i8P2l`P00mBX00?`=003DW0002Xh0000mA`0011d000PR001DC00gWP00
h7L00?l2003]B@00OK<0001X>`004R`0008I000R=`00NR00`L@00?HW003l4000dZ8000::0000=d@0
00@L000:9000FDT0BJ@00>AX003o0000jEP0066[0000H4<000dX00036`00;Sl008@;0<f_003j5P00
n1l00<Nm0000OAT002Dj00026P004B/006Ll07fc003^AP00o`<00=in000ZVP00051>000680001Ql0
04i>02JH003MP@00o`<00>i5001o/`0006Ll000A:`000QX002Lj001o5P39^0000P3i6`004039^@00
07hG000V>P000QX0018/001Y>P26]@00l4000?h5003KR@006i@00015BP001Ah000PR001EB`11X@0:
ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`00228000<K000P=P00K3D0
IZ`00>9_003n1P00mRH00<j^000AT000059=000<9P000QX001Ta001U?P1>Y@00gWh00?d;003i7@00
dZ40022F0000EdX000hX00026@005Bh0065204:R003KQP00o0h00?XI003DV`009iT0001IB@003bT0
008I000D;P00H4<0@:400=^7003l3P00nAT00=BL000TV00005Q:000>:@000QT001H_001R@@18X`00
gH400?d;003h7P00dJ@001VD0000E4`000`V00026P006S8006Pk05^Y003QL`00oPH00?HX003;]000
1h`0001<C@002B<000<K000R>000L300N[800>MN003o0@00lCT00;c20000PQ0003U500067`0011d0
0310001l702V_@00kd@00?l0003ZE000R[H0001d:@009SX000<K00088P00B4`00h/00<^e003f:000
oPL00>1g001AYP0006@o000F;`000QT0010Z001KA`0eW@00fX/00?`>003i6`00dJ@001JB0000DTd0
00XT00036P0083H0070`07bc003YFP00o`000>m1002X_P0007/M000^?`0011`000LP0011B@00R0<0
gg800?h7003PN000CJD0001R@@0052d0008I000C;000HD80BJ@00=mk003n1`00mRT00<Vi0000R0<0
04180006800011d00351001n5`2f`@00lST00?l2003UJ000Hj`0001X>`006340008I000@:P00GDH0
?Z000=f1003m2@00mRH00<Zf0000R08004180006800011d003A200204`30``00lc<00?h4003RL@00
DjL0001S@0004bd0008I000D;P00I3l0F:P00>=]003o0`00lSL00;K10000OAT002lo000470001b40
04Y<00b>003@Z000nA/00?/A003FUP008IH0001CC0002R@000<K000V>P00MbD0Wk/00>m2003o0@00
iV<006J/0000Ic`001H_00026@004bd006=005JX003SK@00o`800?4k002/_`0007XO000Y?0000a/0
00TT001BC@0PUP00eYD00?`@003h7P00cJh000:;0000@DP000HO00057P00>dD008L60<Zf003g8`00
o0`00=V>000WV@0005A<000:90000a/002Pk001j7`2__`00lSP00?l3003QM000BJ@0001NA@003bT0
008I000M=000L2l0RkH00>e:003o0000if0006J/0000ISd001@^00026@00l`005c0006Ti07:`003Y
F000o`000>]C001j/P0006/f000H<@000QT001<]001U?P1S[000if400?l0003]C000Q[D0001^<P00
6c<0008I000B;000Hd00GJX00>IT003o0000kDX008Vf0000Kc8001/c00026@004R`006=0062[003V
HP00o`000>a=0021]00006`e000I<@000QT001@^001W?01][P00jET00?l0003ZEP00LJl0001X>`00
5Bh0008I000H<@00K3D0Pk@00>e<003o0000iFH005RX0000HD<0010Z00026P0083H007DX0:>l003a
>P00oP@00=mk000iW`0005M:000;9@000a/002dn00205037_`00mRD00?`>003FV0005I800019C000
1R0000DN0012B@0;SP00dj000?/B003h8000bKT000233`00<40000<K000:9000EdX0>Il00=mi003o
0`00l3h009Nj0000LBl001/c00026@0052h006Pj07Vb003/C`00o`000>EX001@YP0005e6000=9`00
0aX002Tl001n6@36`P00mRH00?`?003DV`003Xl00012B@001Ah002/g022F003JR`00oPP00?<b002/
_`0007DW000O=P000QT001</001W?01e/@00k4l00?l0003TJ`00BZ@0001JB0002bH000<K000_?`00
Q0`0bk<00?TK003j6000cK0000252@00<D4000<K000;9@00FTP0BJ@00>A[003o0000je8006n_0000
I3l0014[00026P0093T007/N0<C4003f9P00o1000=:Q0005R`0003Y5000470002B<005I;03fP003R
LP00o`400>a=001e/@0006Hm000A:`000QX002@i001l7036`P00mb<00?/B003@Y`0008P2000d@P00
0a/000/U001KA`1@YP00iV@00?l0003XG@00FZT0001NA@0032H000<K000a@000QPL0cjX00?/D003g
8P00aL80001k7@008cP0008I000C;@00JCT0QKD00>m2003o1000g8<002BH0000CDh000HO00078000
D4h0;9X00=ml003o0P00kDT007Ra0000ICh0010Z00036P00:C`0084A0<^d003j6000n1h00<Nn0000
O1/002<h00026@004bd006/g08jg003a?000oPH00=V=000ETP00049900047@002B<005M:04RS000:
ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0C@00228000<K000R=`00KS80
KJh00>AZ003n1000mBX00<bc000;SP00051>000;9@000QX001Xb001W?01EY`00ggT00?d9003h8000
dJH001ZD0000ED/000dW00026@005c0006=004VT003MP@00o@`00?TL003CX0008IH0001GBP003RP0
008I000F;`00HT40Aj<00=f2003m3000nA`00=:Q000NUP0005I;000=9`000QT001L`001T?`1?YP00
gg`00?d9003g8@00cjT001BA0000DTd000/U00026P0073<006Xh06:[003SKP00oPD00?D/0039^000
0HX00018C000228000<K000T>@00LR`0PK@00>UJ003o0000l3h00;C10000P1D003I3008000DN0?h0
03=2001n602^_`00l4000?l0003YF000P[@0001b;@0093T000<K00098`00CDh02Hd00<f`003g9000
o@T00=il001:Y0000691000D;P000QT0014[001NA@0lX000fhH00?d<003h7`00cjT0016@0000D4h0
00TT00036`008cP0078]08Be003ZEP00o`000>i6002P_00007TQ000[?@0011`000LQ0015BP02RP00
hFh00?d8003NO@00AZ<0001P@`004R`0008I000D;P00Hd00D:H00>1f003n1P00mBd00<Nn0000QPP0
03e600067`001Ad003E200214`2n``00lcD00?l3003SK@00G:X0001V?@005Rl0008I000A:`00Gd@0
AJ<00=il003n1`00mBX00<Rk0000QPH003e600067`001Ah003M300233P35`P00m2l00?h5003PMP00
C:D0001Q@P004R`0008I000F;`00ISd0H:/00>AY003o0P00lC/00:jo0000Nad002`m000470002280
04i>016A003AX`00nQP00?/D003DV`006i@0001AC@002B<000<K000X?000NB40Ykd00?0n003o0@00
iFP005jZ0000ICh001D^00026@0052h006Dn05jZ003UJ000o`400?0o002T_@0007PS000V>P000a/0
00XT001DC00VV000f9000?`>003g8@00c;<000280P00?DL000DN00057`00?TL008T10<bb003h8000
o0l00=NC000QUP00059=00098`000a/002/m001l6`2g`@00lc@00?h5003ON@00@Z80001LA`003RP0
008J000O=P00LR`0TkP00>i6003o0@00iFD005jZ0000I3l001</00026@006C4006/f07Zb003ZE000
o`000>UH001c/00006Ti000G<0000QT001D^001W?01[[P00j5`00?l0003[D000O[<0001/=@006C40
008I000C;@00ICh0IJ`00>MO003o0000k4h0086d0000K3D001Ta00026@004bd006Hm06R]003XG@00
o`000>]B001j/P0006Xh000G<0000QT001H_001Y>P1d/000jUD00?l0003XF`00JJd0001V?@004bd0
008I000J<P00KS80R[H00>i7003o0@00i6X0056V0000GT@000hY00026P008SP007LU0:^n003b=P00
oPD00=f0000bW00005E;000:90000a`0031000223`39^P00mb800?`@003DW0003i000015BP8000HO
0:<004I;012@003DV`00o0l00?LT0037_@00080C000]?P000a/000/U001IB@10X@00hGD00?l2003_
@P00SkL0001_<P006C80008I000F;`00JSL0P;@00>e:003o0@00hfd004VT0000FdL000`V00036`00
:cd0080D0<Rm003g8P00na400=:P0008S@0003i700057@00;3L09YP00=^6003n1P00lSH00:Bm0000
Lb/001dd00026@0052h006Ti07fc003]B`00o`400>9`0013XP0005Q9000:9@000a`003910026203=
[`00nQP00?TK003;]00008<>000^?`000a/000`V001LA`1@YP00iFH00?l0003ZEP00J:d0001R@@00
3bT000<J000V>P00OAX0a/000?LS003k4P00dJH000290000=d<000@L000:9000F4T0A:800>=]003o
0000je8006f^0000Hd00010Z00026P009c/007hH0<Nm003h8000nQD00<j/0000QPL0035000036`00
32H005e605NX003WG`00o`000>IQ001CY`0005a7000;9@000a/003A200280P3AYP00na400?HV0031
a00007TQ000Q=`000QT001@^001[=`2=]`00l3h00?h5003KR0007YD00019C0001Ah000LQ001BC@0b
W@00h7L00?l1003/C@00L:l0001S@0003bT000<J000/?P00P`d0cJl00?XE003g8P00aL80001j7`00
8CL0008I000E;P00KC@0U[T00?8h003n2000ei8000n@0000?TL000@M000:9000FDP0CjH000[ooooo
0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1=00078@000a/002@i001`;`1e/000
iFD00?l3003d;@00b[L000J<0000CTh000XT00036P0073@006Ti05bZ003QM000oPL00?LS003?Z`00
5980001CC00032H0008J000I<@00ICh0D:H00=il003m2P00n1l00=6U000KU00005E;000=9`000QT0
01P`001T?`1>Y@00gWd00?d:003h7`00dJH001RC0000E4`000`V00026P006C4006Ll05JX003PM`00
oPP00?LU003=[P003Xl0001@CP002R@000<J000N=@00K3H0JZd00>AY003o0`00m3000<Rm0000R0<0
04A:00078@000a/002Lk001d:@29]P00jUD00?l0003_@P00Zkl0001m6@00<d400P001Ah0?@00=d<0
080C0;O1003a?000o`400>QM001k/P00070`000Q=`000aX000TT001?CP0>S`00cZ/00?PQ003m2P00
gH4004>R0000H4<001</00026@004R`0061304>R003MP@00o@X00?LR003>[@002hh0001=CP002B<0
00<K000U>@00M2X0S;L00>]A003o0000kDX009Rj0000MbD002Pl00036`00228004U<00N<003RJP00
o@X00=f2000oX@0005i5000A:`000QT001H_001U?P1GZ000hW400?h4003d<000aL8000233@00>D@0
0P001Ah04`00>4@008<>0<G3003d<@00oP@00>9b001EY`0006@o000E;P000QT001</001Q@P1<Y@00
h7L00?h6003d;@00a/0000242`00>DD00P001Ah0o`00>TD008D:0<Nn003e:`00oPL00=mk0015X`00
05m4000A:`000QT001P`001X>P1W[@00iV@00?l1003`?`00Y[d0001i8@00:C`000<K00098`00D4h0
5i<00=>N003j5@00nQH00=>P000ETP0004m>00088P000a/002/m001k7@2__`00lCX00?l2003SK@00
EjP0001S@0004bd0008I000F;`00Ic`0IJ`00>IS003o0@00kd<009bk0000MRL002@i00036P002bD0
05I;02bJ003JR`00o@/00?LU003:^00008H7000jA@001Ah000HO0012B@04R`00cZd00?TM003k4@00
eIP001^D0000D4h000PR00047000;Sl007hG0<33003d<000oPH00=in000kW`0005Y8000=9`000aX0
028g001e:@2K^`00kd400?l1003TJP00EjP0001R@@004B/0008I000J<P00KC@0P[@00>a?003o0000
j5`006^^0000Ic`001D^00026@005Rl006Ti07:`003YF000o`000>YE001g/@0006Xh000G<0000QT0
01D^001W?01/[P00j5/00?l0003[D`00NK80001Z>0005c00008I000E;P00J3/0Kjl00>UH003o0000
jUH007:`0000J3X001D_00026@005c0006/g07bb003[D000o`000>MP001RZ`0006A0000B;0000QT0
01`d001a;`2B^000kd<00?l2003RK`00BZ@0001LAP003BP000<J000U>@00NB40]<000?<b003n1`00
g8D002bJ0000Dd`000TS00047000<d4008@;0<^e003h7`00na<00=:Q0009S@00045800057P001R00
04Y<01JB003FUP00o0d00?HW0035`P0007hH000Z?0000a/000`V001KB017X`00hW000?l1003^A`00
QkD0001/=@005c00008I000H<000KCD0R;H00>i6003o0P00hW8004:R0000FDT000/U00036`00;Sl0
088@0<Vh003h7`00na<00=6U0003R`0003]500047@00;CP0;9X00=f1003n1@00lCX009^k0000LBh0
01/c00026@005Rl006/g08Fe003^AP00o`800>5e000lX00005M:000:900011`003I300280`3?ZP00
nQD00?PN0039^@00084B000[?@000a/000dW001NA@1GZ000if400?l0003XF`00H:/0001P@`003RP0
00<J000Y?000OaD0b;`00?PO003k5@00cjX000271@00D000<d8000<K000;9@00FTP0Bj@00>EX003o
0000jUH006J/0000HD8000hY00036P00:C`0080D0<Vi003i7@00nQP00<ba0000Q0`002ho00036`00
3BL005m405jZ003YFP00o`000>EV001<Y@0005Y8000:900011`003M400:;003BX@00o0l00?DY002h
`P0007LU000N=@000QT001H_001]=02E^@00lCX00?h7003IS@0069<00015BP001Ah000PR001DC00i
W`00hW800?l1003[DP00J:d0001Q@P003RP000<K000_?`00QPP0cjX00?/B003g9@00`<<0001h8`00
7cD0008I000G<000Kc40W[/00?<d003m2P00eYL000Z>0000>TD000@L000;9@00FdL0EZP02_ooool1
o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l000HP000470009c/007</07fc003W
H000o`800?<a0038_0000HX0001:C0002B<000<J000O=@00JcH0I:`00>9_003n1P00mRL00<f_000>
S`00055=000;9@000QX001Xb001W>`1GZ000h7L00?d8003g8P00cjX001FB0000Dd`000`V00026P00
6C8006Ll05FW003PN000o@P00?LS003?Z`004Y40001BC@002bD0008J000K<`00JCX0GZX00>9b003n
1P00mRP00<bc0008S@0004i>00098`000aX0020f001^<`1a/000iV@00?l2003c<`00a/8000262000
@4P000LP00047000:S`007LU096h003[D000o`000>i6002S_00007/M000_?`0011d000HO000jA@00
PPl0_l<00?8h003o0P00iV8007>`0000KS<001lf00036P002RD0055=01BB003@YP00n1h00?`=003K
QP00?:00001NA@004B/0008I000D;P00HT40BZ@00=ml003m2000mRD00<bb0005S00004U<00088P00
0a/002Pk001f9P2D^@00k4`00?l0003/C`00T;P0001e:0009SX000<K00098`00CTh038l00>AV003m
3000fhL003RN0000G4L000lZ00026@00630006Ll05nZ003SK000o`<00?<d0030``00084B000f@`00
1Ah000HO000kAP00Q@T0akl00?D]003n1P00h7L004jU0000HT8001<]00026@0052h006=005>W003Q
LP00oP@00?<a0034a000088@000f@`001Ah000HO000nA`00Q`D0bKT00?HX003m2000gH0003jP0000
G4H000lY00026@006S8006Xh06n_003WG`00o`000>m4002M^`0007LU000V>P000a/000XT001BC@0M
U@00eIT00?/C003i6@00dJD000n@0000C4d000PR00047000;Sl007dI0;S1003b=@00o`@00>9b001@
YP000652000B;0000QT001P`001Y>@1][P00ieh00?l0003^A`00TkT0001c:`008CL000<J000<9P00
F4T0<id00=^6003m2@00mRP00<Rm0000Q0`003I300057@001b0004I;00V=003@Z000nAX00?/D003D
W@005I80001>CP00228000@L000a@000PA<0aL800?D/003n2000g8<003FM0000F4T000`V00036P00
93T007LU0:>m003`?@00o`800>9_001@YP000613000@:P000QT00?<001`d001`<02:]P00kDX00?l0
003WH@00Hj`0001U?P004bd0008I000H<@00JcL0N[800>]C003o0000jET006n_0000J3/001D_0002
6@005Rl006Ti07B`003ZEP00o`000>UG001a[`0006Pj000F;`000QT001L`001Z>01g/@00jU<00?l0
003XF`00JZh0001V?@0052d0008I000I<P00KC@0Q;D00>e;003o0000iVD005^Y0000HD80010Z0002
6@007SD007</09^j003`?P00o`<00>5d0013XP0005Y8000<9P000aX002Lk001k7@2l`P00m2h00?d9
003JRP009IP0001AC@00228000@M000f@`00Q`H0c;400?TK003j5@00d:H000B;0000?DL000DN0007
8@00CTh079D00=RA003m2`00mB/00<740000O1`002Lk00036P003BL005e604jU003TJ`00o`400>e;
001o/`0006Xh000F;`000QT001Tb001_<P2@^000kd400?l2003PM`00?:00001GBP002R@000<K000a
@000Q0/0bk@00?TL003j5P00cjX000280P00=d@000@L000_>00cW@00gW`00?l3003`?`00TkT0001_
<@006C40008I000G<000KC@0SKL00>m2003o0`00ggX003FM0000ED`000TS00047000>DD00XX00=6U
003k4P00mb800<Nn0000OaL002Tl00036P003RP0061305jZ003XG000o`000>MP001IZ@0005i5000=
9`000a/002`m00214@3:]`00nA`00?XH003=[`0008D:000`@0000a/000`V001LAP1BY`00iV<00?l0
003XF`00GZX0001OA0003BP000<K000/?P00PPl0bk@00?TJ003i6`00bkH000214@00:cd000<J000>
:000HD80IZ`00>YE003o0000i6/004BR0000F4X000TT00047000>dD028d00=BL003l3000mBd00;30
0000MBT001`d00026@00630006la09fk003b=P00o@P00=NB000BT@00045800057@002B8005I;042Q
003SK@00o`000>UG001QZ`0005m4000<9`000a/0039100280`3AY@00o1000?HY002g`@0007HW000M
=0000QT001Pa001a;P2V_@00m3000?d<003DW00018/0000g@`000a`000`V001MA@1NZP002_ooool1
o`00007ooooo000Nooooo`?o00001oooool0o`001Ql000@L000Z?000MBP0QKD00>QK003o0@00lSD0
0<K10000R0@004I;00088P000a/0024g001^<`1/[P00i6X00?h4003e:`00bk@000V=0000Cdh000XT
00036P0073@006Xi05nZ003QLP00oPL00?HV003=[P003i00001AC@002bD0008J000K<`00JCX0G:X0
0>5c003n1`00mRH00<f`000=S`00051>000:90000aX001dd001[=`1U[000hfd00?h4003e;000b[P0
00>;0000BT`000TR00036`008SP0070_07Vb003WG`00o`400?8h0031a00008<=000lAP001R0000@L
000/?P00NB80V[X00>e<003o0000kD/009^j0000NB4002`n000470001R0003i700252P35``00lc<0
0?l3003UI`00Jjh0001/=P007C@0008J000;9P00Dd`06Y@00=:Q003i6`00o0l00=Z<000eW@0005a7
000@:P000QT001H_001T?`1AYP00h7L00?h7003f:@00b[L0002:0000ADX000LQ00047000:Sd007PR
09bk003^B000o`000>YC0027]@0007</000S>0000a/000TS001@CP0BT@00iF400?`>003IS000<Y`0
001JB0003RP0008I000I<P00JCT0IZ`00>EW003o0P00lST00;O10000OaH0039100047@001Ql003m7
00271039^P00mBT00?h7003OO000AZ<0001OA0004R/0008I000F;`00ICh0FjT00>=]003o0`00lSD0
0;c20000P1D0039100047@001R0004990029003;]000mb@00?d:003LQP00=ih0001JB0003RP0008J
000L<`00KCD0Mk400>UJ003o0000kDP009Fi0000MBT002@i00036P002bD005A<02>G003GU000o100
0?TL003?ZP002Hd00018B`001b4000@L000a@000P1D0`<<00?<a003n1@00h7L004VT0000Gd@0010Z
00026@006S8006/g07F`003YFP00o`000>a<002;]P00074^000O=P000QX000dX001JB00jW`00gH40
0?h8003e;000a/4000224000<d4000@M00078@00BT`03i000=:S003j5`00nQH00=:R000?T00004Y<
00078@0011d003A200233P37_P00mRP00?d:003KR000;Y/0001FB`002bD000<K000W>`00NB40[;l0
0?8i003o0`00hG@004RT0000GTD000lY00026P00B@007cD0078]09:h003^AP00o`400>EV001LZ@00
06=0000B;0000QT001Xb001]=022]000k4h00?l0003WGP00Ijd0001V?@0052d0008I000H<@00JcH0
O;800>]A003o0000j5`006V]0000ISd001@]00026@00634006`f07nc003/C`00o`000>MP001SZ`00
06@o000B;0000QT001/c001_<@2<]`00kTL00?l1003TJP00DjL0001OA0003bT0008J000Q=`00MBP0
Xk`00?4j003o1000ggT003bP0000F4T000/U00036`00:Sd007hI0<C4003e:P00o@/00=R@000OUP00
04m>00078@0011d003Y50029003>[0000P3j6000Z03>Z`0008T0000jA@0011d000PQ001@CP0RU`00
fX`00?d9003d;`00^<80001j80009CT000<J000>:000Gd@0EJL00>EV003o0000je0007Na0000J3X0
01@^00026@006c<0074^09Rj003`?@00o`@00=ml000eW@0005E;00098`0011`003E200271P3=[`00
nQT00?TI003=[`0008H7000d@P0011`0030h03ZO003PM`00o`800>m3002;]P0006dd000G<0000QT0
01Tb001_<@2E^@00l3d00?h4003NO`00;Y/0001CC@00228000@M000mAP07S@00dj000?`@003g9@00
aL80001l6`009SX000<J000?:@00HT40IZ`00>UG003o0000iVD0056V0000G4H000`V00036`00;cl0
08@<0<bb003i6@00nAX00<^d0000P`l002dn00036`003BL005i505ZY003WGP00o`000>MP001GZ000
05e5000<9P000a/002lo00252P3=[`00nQL00?PN0039^P0007lF000X>`000aX000lY001S@01^[P00
je400?l1003RL000?Z00001FB`002B<000@M000nA`0>S`00eYL00?d:003d<@00Ykh0001b;0006S80
008I000J<P00LRd0YKd00?<b003m2P00eYL000b?0000?DH000@M00098`00F4X0Aj<00>EX003o0000
j5`005VY0000GDH000/V00036`00=D<00HX00=>P003l3P00mB`00:no0000M2X001/c00026@006S80
07<[0:no003e;000o0h00=:R0000R@0003=200036`003BL0061306F/00Sooooo0ol00001ooooo`00
7_ooool00ol0003oooooooooo`07ooooo`3o00057P0011d002`n001g9@2=]`00jUL00?l1003a>P00
`/@000252@00@TT000PQ00036`008cP0070`07B`003UI@00o`<00?@^0039^@000h/0001<C@002B<0
00<J000O=@00K3H0IZ`00>=]003n1@00mBT00<^c0009S@0004m>000:90000aX001de001[=`1T[000
hfh00?h5003e:P00bkD000N=0000CTh000TS00036P007cH006dd06f^003UJ000o`<00?@`0038_@00
08P20015BP00228000<K000U>@00LR`0PK@00>QJ003o0@00lC`00;S20000PA4003U400067`0011d0
02lo001k7@2R_000kTL00?l0003[C`00T[P0001g9@00:S`000@L00078@00@TT008L50<Nn003d;`00
o`@00>=/001S[00006Ti000K<`000QX000`W001EB`0PUP00e9`00?XH003k4@00f94002nK0000FTP0
00lY00026@005c0006Hm05RX003RLP00oPD00?D]0038_00008L40011B0001b0000@L000]?P00Nah0
YKd00>m3003o0000jEP007nc0000L2l0024g00036P002R@0059=01RC003VG@00na400=RB000[VP00
05Q:000=9`000QX001/c001[=`1^[`00iV800?l1003`?@00[kl0001m6P00;cl000@L00078000@dT0
08X00<^e003f9P00o@T00=f1000oX@0005e5000@:P000QT001L`001W>`1RZ`00i6P00?l2003a>@00
]<00001m6@00;cl000@L00078@00AT/01H`00<f_003h8@00o0`00=Z;000aW00005Q9000=9`000QX0
01he001_<P1o/`00jUD00?l0003/C@00SKL0001b;0008CL000<J000<9P00ET/0:YX00=R?003l3P00
n1l00<f_0004R`0004A:0006800011d003E200224035`P00m2h00?h6003NO000@J40001MAP003bT0
008I000L<`00KC@0OK<00>YE003o0000je4008>d0000Kc4001dd00026P003RT005a6046Q003OO000
oPH00?@`0032a00007lE000`@00011`000PR001>CP0ETP00dih00?/D003i6@00d:L000V=0000AT/0
00HP00057@00>4@008D90<Vi003g9@00o@`00=V=000XV@0005A<000:90000a/002Xl001k7@2d`@00
lcD00?h5003ON@00@J40001KA`003RP0008J003c000Q=`00M2X0V[X00>m1003o0@00i6/005BW0000
HD80014[00026@0073@006la08Zf003]BP00o`000>IS001OZP0006A0000B;0000QT001Xb001]<`24
]@00k4`00?l0003WH@00HZ/0001T?`004R`0008I000J<P00KS80QkD00>e:003o0000iFD005^Y0000
HT40014[00026@007C@0074^09Bi003_@P00o`800>=_001<Y@0005e5000>:0000QX002<h001g902[
_`00lSH00?h5003NO`00=Id0001FBP002R@000<K000]?P00P1@0a/000?HV003l3@00eYD001VC0000
C4d000LP00057P00?TL018/00=2W003j5@00nA/00<f`0000Q`H003I3000470002280059=02VI003K
Q`00oPL00?<c002__`0007LT000R>0000QX000lZ001Q@P1MZP00if400?l0003ZE@00Kjl0001V?@00
4b`0008I000M=@00Lb/0XK`00?8i003n1@00gH4002jK0000Dd`000PR00047@00>4@008T10<nZ003j
5P00nA`00<^d0000Q0`0035000036`00<CL0@J400>9b003o0@00kTP008>d0000JcL001D_00026@00
6c<0074^09fk003a>@00oPD00=b4000XV@00055=00078@001Ah0045800f?003DV`00o0d00?HY002o
``0007XO000S>0000QX0014[001T?`1^[`00je<00?l0003TJP00BZ@0001JB0002bD000<K000b@@00
QPL0cZd00?XF003h7P00bKT000204`00:S`000<J000>:000H4<0HJ/00>UI003o0000iFD004nV0000
FdL000/U00036`00<d4008L50<nZ003k5000mb400<No0000OAX002Dj00026P004B/006Dn07Fa003/
C000o`400>5e000gWP0005A<00088P001Ah0049901>A003HT@00o@P00?<e002O^`00070`000H<@00
0QT001/c001d:P2^_`00m2h00?d<003DW0001h`0000iA@0011`000XT001JB01>Y@00iV<00?l0003W
H000DZH0001KA`002RD000@L000iA007S000e9/00?d;003d<000Y[d0001a;P006C40008I000L=000
MRL0]l400?HX003l4000d:L000271@00<40000<K000>:000HT40KJh000[ooooo0Ol00001ooooo`00
7_ooool00ol0003oooooooooo`07ooooo`1200057P001Ad002lo001i8@2E^@00je800?l0003`?P00
^/8000233P00?TL000LP000370009SX0078]07bb003WH000o`800?<b0037_P0008T10017B`002280
00<K000Q=`00KS<0KZl00>EX003o1000m2d00<Vh0003R`0004]=00098`000aX0020f001]=01/[P00
i6T00?l4003d;P00bKT000::0000BD`000TR00036`008SL006la07F`003VH`00o`800?<d0036`@00
08H70011B0001b4000@L000X>`00MBT0RKH00>YE003o0000l4000;300000OaH003E20P001Ah0o`00
<d4007dI0:^n003_@P00o`000>YD002:]P0007@Y000W>`000a/000PQ0016BP00R@00bKT00?D/003n
1@00hW4005bY0000Ic/001Ta00026@003BP005M:02NI003FU`00naD00?/D003FUP00:9T0001HBP00
3BP0008I000I<P00J3X0H:/00>=]003o1000m3400<K10000Q@T003e600067`0011d00350001m6P2]
_`00l3l00?l1003XG@00Mk40001^<P007cD000<J000;9@00E4`07YH00>MI003k4`00eYL002BH0000
ET/000`V00026P007CD006dd07Ja003XG@00o`000>m1002V_@0007XO000/?P0011`000LQ0017B`05
S000cK000?LR003m2`00fhH003RN0000FdL000lY00026@006C8006Ti06Z]003VH`00o`400?0n002[
_P0007/M000/?P0011`000PQ001:C00;SP00cjX00?PM003l3`00f90002ZJ0000ETX000`V00036P00
83H0074^08Ne003[D000o`000>]B0024]@00070`000O=P000QX000dW001HB@0`W000fXX00?d<003g
8`00bk@000290@00@4P000HO00057P00>4@008@;0<Nm003e:P00o@P00=f1000jW`0005]8000>:000
0QX001he001`<025]@00je000?l0003ZE@00Nk80001]=0006c<0008I000@:P00GTD0B:<00>1g003n
1000lc@00;W20000OAX002dn000370002B<0051>01^D003EV@00na400?TL003>[@0018/00012B@00
1Ql000DN000kAP00Q`@0bk@00?LQ003l3P00ei<0026F0000DTd000TS00036`00;3h007dI0;g3003d
<@00oPH00=in000jW`0005U8000<9`000aX002<h001f9P2S_000l3d00?l2003RL000CJD0001OA000
3bT0008J000N=@00LRd0T[P00>i5003o0@00i6P005RX0000HD80014[00026@0073@0070`08bg003^
B000o`000>EV001JZ@000691000A:`000QT001`d001`;`2@^000kTD00?l1003TJP00DjL0001P@`00
3bX0008J000O=P00M2X0WK/00?0n003o0`00hG@004FR0000FdL000dW00036P009SX007XP0;C1003c
<P00oPL00=b4000^V`0005A<00098`0011`0031000223`38^`00mb<00?`?003EVP004i400018C000
[`001R0000DN0011B@0:SP00dZ800?/C003h7P00bkD000242`00<d4000@L00098`00E4`0<9`00=f1
003n1@00lSL00:Nm0000MBP0020f00026@004B/006=006B/003XG000o`000>UJ001W[@0006@o000A
:`000QT0020f001e9`2Y_P00lcD00?h7003KQP009iT0001AC@00224000@M000lAP04R`00dJD00?/C
003h7`00bKT000224@00;Sh000<K000c=`18X`00hfd00?l1003/C000Nk80001X>P0052d0008I000M
=000M2X0Y[d00?<e003n1`00fXT0026G0000Cdh000LP00057P00ADX04i400=JE003m2`00mBd00;O1
0000N2<0024g00026@004R`006Hl07Ja003/CP00o`400>=_0013XP0005Q9000:900011`003E30028
0P3@Z000na<00?PQ0037_P0007hH000W>`000aX000lY001R@@1Y[@00jU@00?l0003TJP00B:<0001I
B@002R@000@L000f@`00R@00dJD00?/A003g9@00aL@0001k7P008cP0008J000B;000J3/0OK<00>i7
003o0P00gg/0032L0000DTd000LQ00057P00Ad/06I@00=V<003n1`00lCT009Ni0000KS<001H_0002
6@007SD007HV0;K1003e:P00o0l00=:Q0001RP0003I3000370002bD005a705JX003WGP00o`000>EU
001:Y00005U9000:900011`003e600b?003FUP00o@T00?<d002N^`0006la000G<0000QT001le001h
8`30``00mbD00?/C003>[00008D:000]?P000aX000lY001T?`1e/@002_ooool1o`00007ooooo000N
ooooo`03o`000?oooooooooo00Oooooo0<0000DM00057P00<d4007`L09jk003/C@00o`000>m2002a
`000084B000jA@001R0000@L000Y?000M2T0Q;D00>QK003o0@00lSL00<G30000QPH004=900088@00
0a/002<h001`;`1f/@00iV<00?l2003c<@00akd000290@00Ad/000PR00036`008SP006la07B`003V
I000o`800?<b0037_P0008P30015BP00228000<K000T>@00LRd0OK<00>QN003o0@00lSP00<740000
Q0`003e70006800011`002Xm001g9@2B^000je400?l0003^A@00Ykd0001m6`00<T4000DM00057P00
=T<0080E0;?0003`?P00o`000>UI0022]000078/000T>@000a/000PR001:C005S000bk@00?HX003n
1`00h7H005BW0000ICh001L`00026@003bT005U802fK003GTP00na800?XG003DV`008IL0001EB`00
32L0008J000K<`00JSP0J:d00>EX003o0P00lcD00<?40000P`h003U500067`001Ah003A2001o5@2f
`@00lCX00?l1003VHP00Kjl0001/=P0073@0008J000<9`00ET/09IP00>UE003j5P00e9`001jE0000
E4`000/U00036P0083H0070`07jc003YF000o`000>i6002N^`0007PS000Y?0000a/000PR001<C@0;
SP00cj/00?PO003l3@00fX/0036L0000FDT000hX00026P006c<006`f07:`003WGP00o`000>m2002R
_00007TR000Y?0000a/000PR001>CP0AT000dJD00?TJ003k4@00eYD002>G0000E4`000/U00036P00
8SP007<[08nh003]C000o`000>YF001l/`0006hc000M=0000QX000hX001JB00gWP00g8@00?d:003f
9`00bKT000271P00?4H200057P21000lAP00Q`H0bKP00?HV003m2P00fhL003>M0000FDT000dW0002
6P0083H0078]08fg003]B`00o`000>QJ001c/00006/g000I<@000QT0014[001P@`1?YP00hW400?l3
003b>000/<00001k7P00:S`000<K00098`00DTd08IH00=NC003l3`00n2000<bb0000R@4003i70005
7P001Ql003m7006:003=[`00n1h00?`@003EV0006i@0001@CP00228000@L000`@000P1@0aL@00?D]
003n2000g8@003>M0000EdX000/V00036P009SX007PR0:^n003b>@00o`<00>5e0016X`0005a6000>
:0000QX0024g001d:P2K^P00l4000?l2003SK@00D:H0001OA0003bX0008J000N=@00LRd0UKT00>m3
003o0@00i6/005:W0000H4<0010Z00026P007cD007</09Rj003_@@00o`800>9_001<Y@0005i5000>
:0000QX0028g001f9`2U_@00lCX00?l4003ON@00?J00001IB@0032H000<K000X>`00O1`0_L<00?@^
003m2000fXT002RI0000DTd000TS00047000=48008@:0<Zf003h7`00na800=>O000=S`0004A:0080
00HO044004I:00n@003DW000o1000?LR0039^P00088@000`@0000a/000XT001FB`0fWP00gW`00?h4
003a>`00W[/0001c:`007SD0008I000B;000ICh0K:h00>UG003o0000ieh0062[0000HT40010Z0002
6P008SP007PS0;;0003d<@00o@P00=Z<000QUP0004m>00078@001Ah0041800V=003CW`00o1400?LS
0037_P0007lE000[?@000a/003Dg04nV003UJ000o`000>]A001c/00006Hm000B;0000QT0020f001f
9P2^_`00m3400?d9003IS`006i@0001;C@0200067`1Z0019C00IT`00f9000?d9003d<000[[l0001f
9`007cD0008I000D;@00JCX0O[<00>e9003o0@00hG@003bP0000ET/000TS00047000>D@00h/00=:S
003k4@00mbD00<G30000O1`002Di00026P0042/006Dn076_003[D000o`000>9_0011X@0005M:0009
8`0011`003U500F;003CX000o0l00?HX002m``0007PR000P=`000QT001@]001Z>026]@00kd<00?l3
003MP000:IT0001@CP001b0000HO001;C@0PUP00fhL00?h5003`?P00S[L0001/=P005Bh0008I000P
=P00N280_l<00?HV003k4@00d:H000280`00<T4000<K000<9P00GTD0GJX00>UI003o0000i6/004>R
0000EdX000TS00047@00@4P04Y400=R@003n1`00lSP009Fi0000KC@001D^00026@008CL007XO0<G2
003g8@00nQH00<ba0000PPl002Xl00036P0042X006Hm07fc00[ooooo0Ol00001ooooo`007_ooool0
0ol0003oooooooooo`07ooooo`1]00047@001Ql003I3001n602V_@00kDP00?l0003^A`00Z;h0001n
5`00=d<000HO00047@00:cd007LU08bg003ZEP00o`000?4k002o``0008@<000oA`001b4000<L000V
>P00LR`0O[<00>MN003o0@00lSD00<G20000QPH004=900088@000a/002Di001b;@1l/P00iel00?l1
003b=P00aL<000262000@DP000LQ000370009c/007@Z08Fe003YF@00o`000?4l002i`P00084A000j
A@001Ql000@M000]?P00NB40V[X00>a<003o0000kDT009jk0000NQl002lo00047@001Ql003Y50022
402l`P00lCX00?l1003WGP00N[80001`<0008SL000<K00098`00CTh02hh00<f_003g9000o@P00=mk
001<Y@0006=0000E;P000QT0010Z001KA`0dW@00fHd00?`?003i6P00dZ0001^D0000Dd`000/V0002
6P007CD006de072_003VHP00o`400?4i002j`P00080C000f@`0200057P3o000gA000PQ40_l<00?8f
003o0P00iFL006N]0000JSP001Xb00026@003BP005Q902bJ003ZD@00nAT00=:Q000HT`00059=000:
90000aX0028h001b;@26]@00je<00?l0003]BP00UKT0001f9`009SX000<K00098`00Cdh04I400=6V
003i6`00o1000=RA000[VP0005M:000=9`000QX001de001^<`1j/P00jET00?l0003^A`00V[X0001f
9P009SX000<K00098`00D4d05i<00=>P003j5`00na@00=FJ000MU@00059=000:90000a/002Di001e
9`2H^P00kTL00?l0003XF`00M;00001/=P006c<0008I000?:@00G4H0?Z000=io003n2000mBX00<Nn
0000Q0/003Q400057P001Ql0041800290@3;/`00mb800?d<003IS000;I/0001FBP0032H000<J000R
>000M2X0UKT00>i7003o0000iel006^^0000J3X001L`00026@004b`006=105NX003SK000o`800?4l
002X_P0007TR000W>`000a/000XT001DC00XV@00fHh00?`<003g8`00b[L000261P00>TD000DN0006
7`00@dT01X`00<nZ003i6`00na<00=BM000DTP0004i>00088@0011`003=100224037_`00mRT00?d:
003JR@00;9X0001EB`002RD000<K000Y?000Nah0]<400?<d003n1@00gg/003jP0000FTP000dW0003
6P008cP007HV0:>m003a?000o`<00>5c0019Y00005e6000>:0000QX0024g001d:@2M^`00l3l00?l2
003RL@00Bj@0001MA@003RT0008J000Q=`00MBP0XK`00?4l003o0`00hG@004FR0000FdL000dW0003
6P0093T007PS0:jo003b=@00oPD00=in000fWP0005M:000;9@000a/002/m001n6035a000mBX00?d:
003ISP008IH0001@CP00228000@M000g@`00Q`D0c;400?TL003k5000dJ@000N<0000@4P000DN0006
8000BT`05I800=JG003l3P00mRD00<No0000P1@002`n00036`002bD005Q903fP003PM`00o`<00?0o
002F^@00074_000K<`000QT001@]001W>`1d/000je800?l0003VI000F:P0001OA0003RT000<J000U
>@00NQl0^l800?D]003m2P00f94001^D0000C4d000HP00057P00A4X03i0000240=FJ003l3P00mRH0
0<G30000OAX002Pk00036P00=cH0EjP00>IS003o0000jUH006^^0000I3l0014[00026P008SP007PR
0;O1003e;@00o@/00=ND000ETP0004I;00067`001R0004e>01nF003JR`00oPL00?<e002U_@0007<[
000L=0000QT001D^001[=`26]@00kT@00?l2003ON@00=Id0001DC000228000@M000mAP08S@00dih0
0?`>003f:000_l<0001i80008SP0008J000B;000Ic`0NK800>e;003o0@00hG@003ZO0000ED/000TS
00047@00?DL02Xh00=FK003l3000mB`00;C10000MRH001he00026@005Bl006`e08jg003`?P00oPD0
0=b5000RU`0004e>00067`001R0004m>02JH003MPP00o`@00>m20026]@0006Ti000C;@000QT0028h
001k7P35`P00mb800?/D003>Z`0008D9000_?`000a/000dX001P@`1U[000jU@00?l0003RL000?:00
001EC000228000DN0015BP0IT`00fX/00?h6003`?@00SKL0001[=`004bd0008I000S>000O1/0akd0
0?PN003j6@00b[H0002050009c/0008J000B:`00J3X0QKD02_ooool1o`00007ooooo000Nooooo`03
o`000?oooooooooo00Oooooo0?l000@L00068000>TD0080C0:no003_A000o`000>e<002P_00007`L
000c@@001Ah000DM000_?`00NB40UKT00>]A003o0000l3l00;K10000PQ4003]60006800011`002Tl
001e:027]@00jET00?l1003a>P00`<<000242`00?dL000LP000470009c/007@Z08Be003YFP00o`40
0?4j002n``0008<=000mAP001R0000@L000Z?000MRH0S[L00>YD003o0000kd400;300000OaH003I3
00057P001Ad00350001l702S_000kTL00?l0003/CP00U[T0001h8`00:cd000@L00068000?TL008@;
0<G4003b=@00o`800>IS001a/00006hc000O=P000aX000XT001@C@0AT000cjX00?PQ003m2P00gH40
04FS0000HD8001@]00026@004B/005i503^O003KQ`00o0d00?PM003AYP005I80001AC@002R@000<J
000P=P00Kc80N;400>QM003o0@00l3d00;700000OQP0039100057@001Ql003]500243035``00lc80
0?l3003SK000GjX0001W>`006340008I000?:@00FTP0<Yd00>]=003i7@00d:L0016A0000D4h000TS
00036`009CT007@Y08ng003/CP00o`000>a?002=]`0007<Z000T>@000a/000XT001AC@0GT`00dZ40
0?XH003k4P00eYH002BH0000ED/000/V00036P0083H0070_08:d003ZE000o`000>e<002A^00007@Y
000T>@000a/000XT001BC@0MU@00e9/00?/D003j5`00dj0001NC0000D4h000TS00036`00:3/007PS
0:2l003_@P00o`400>MP001/[P0006Ti000I<@000QT0010Z001NA@16X`00ggX00?h6003d;P00aL<0
00224000=D8000@M00068000A4X018/00<f^003h7`00o0l00=RA000VV00005A<000;9@000a/002Di
001f9P2N^`00kd800?l1003VI@00Hj/0001V?@005Bl0008I000D;P00ICh0GjX00>EW003o0@00kd40
09nk0000MRH002@i00036P002bH005I:02jK003JR@00o@X00?HW0038_00008@;000f@`0011d000LP
0018B`0<SP00dJD00?XG003j5P00dZ8000j?0000BD`000LP00047@00=T<008@;0<Vj003g9@00o@`0
0=V>000VV00005=<000990000a/006/002`m001m6@2m``00m3000?h6003MP000=ih0001HB@0032H0
00<J000V>P00NB80[;l00?8h003n1000h7P0046Q0000FdL000dW00036P008cP007LU0:Jm003a>P00
o`<00>1f0014XP0005]7000=9`000aX002@i001g902Y_P00lSP00?h4003ONP00?J00001IB@0032H0
00<J000W>`00Nah0]l400?<a003n1`00g8@002nK0000ED/000XT00036`00;Sl0080C0<No003f9P00
o0d00=ND000KU00004i>00078@001Ad003]50029003>[000nQT00?XG003?ZP000HX0000lAP001Ad0
00LQ001>CP0LU@00ei800?d;003e:@00aL@0001m6@00:C`000<K000<9P00FTP0AJ800>9b003o0P00
kd@008fg0000KS8001Tb00026@005Bl006Xh07fc003/C@00o`000>AY001@YP0005e5000=:0000aX0
02Lk001l6`34a000mRT00?`<003FUP0059800017B`0200067`260018B`0ETP00eYD00?d<003e:P00
_l<0001k7P009CT0008J000h=P1OZP00j5h00?l0003XF`00Hj/0001R@@003bX0008J000T>@00Nah0
`<<00?HY003l3@00eIT000n@0000@TT000DN00078@00D4h09YP00=b6003n1P00lCT009fk0000LBh0
01Xb00026@005c0006dd08ng003`@000o`@00=in000^V`00059=00088@001Ah0045800j?003EV000
o@`00?D/002f`@0007LU000P=P000QT001<]001Y>@21]000kTH00?l2003ONP00<id0001CC0002280
00DM0011B00@T000eYD00?d:003d<000Zkh0001d:P0073<0008I000G<000KS80UkT00?4j003n1P00
fXX001bE0000B4`000DO00078000DDd0;I/00=il003o0P00kTL007fc0000Ic`0018[00026P009CT0
07dJ0<Nn003h7`00nQL00<ba0000P`h002`n00036P003RT0069106f^003/C`00o`400>5e000eW@00
059=00078@001Ah004U<01nF003KQP00oP@00>m10024]@0006Pj000B;0000QX002Hj001o5P39^000
nAX00?TL0038^`0007hI000T>@000QX001<]001Z=`2>]`0:ooooo`7o00000Oooool001kooooo00?o
0000ooooooooool01oooool0=`000a`000LP000nA`00P`h0^<400?0o003o0000je4009Ni0000NR00
031000057@001Ah00391001k7@2M^`00k4`00?l0003_A000[Kl0001o5@00>4@000HO00047@00;3d0
07LT08ng003ZE000o`000?0n002g`@00088@000kA@001R0000@L000Z?@00MRH0SKL00>YE003o0000
l3l00;G10000PA8003U400067`0011d002dn001h8P2F^@00k4l00?l0003^A@00Ykd0001m6P00<d40
0P001Ah0F000=48007hH0:bo003_@P00o`000>]C002=]`0007HW000X?00011`000LQ0012B@00Q`H0
akl00?@a003o0`00i6P006V]0000JcH001dd00036P002bD0059=01NC003AY@00n1d00?`=003KQP00
?Z00001NA0004R`0008I000C;@00H4<0@j800=f2003m2`00n2400<n[000?T00004m>00098`000a/0
028h001a;P20]000jEP00?l0003_@P00Z;h0001l7000;cl000@M00068000?dL008H70<Nn003d;P00
oPD00>9b001GZ00006Dn000F;`000QT0010Z001LAP0jW`00k4X00?PP003>[0002hh0001=CP002280
00<K000W>`00MbD0V;X00>e9003o0000jU@008Be0000LBh0024g00036P002bD005=<01jE003DV`02
0?XE003o0=BK000MU@0005=<000:9@000aX0028h001c;02;]P00k4l00?l0003[D000RKH0001b;@00
8CL000<J000;9@00ED`099L00=JE003k4@00nAX00=6U000@T00004i>00088P000a`002/m001j7`2Y
_P00l3h00?l1003UIP00I:`0001W?0005c00008I000B;000HD<0CJD00>5e003n1000lc800;o30000
P1D00350000470001b4004Q<00Z>003?Z@00nA`00?/A003FU`007iH0001BC@002R@000<K000X>`00
NB80Ykd00?0m003o0P00i6X005^Y0000I3l001@]00026@005Rl006Ll06N]003VHP00o`000>i5002F
^@0007@Z000R=`000aX000`W001IB@0eWP00g8<00?d8003e:`00a/4000224000<d4000@M00078@00
C4d04Y400=>O003k5000nAT00=2X0008S@0004E:000680001Ah003Y500271@3;]@00mb400?`>003G
U0007iH0001AC@002B<000@L000_?`00OaD0aL@00?D/003m2000g8D0032L0000ET/000/U00036`00
:3`007/N0;G1003c<`00oPD00=im000jW`0005U9000<9P000aX002Hj001i8@2__`00lSH00?h5003O
N`00?:00001IB@0032H000<J000V>P00NR00//000?<d003n1P00gWl003JN0000EdX000/U00036`00
:S`007dJ0<33003e;@00o@T00=Z9000XV@0005=<00098`0011`0039100233P39^P00mb<00?`?003E
V@005980001:C0001R0000DN000oA`05S000d:L00?XF003i6`00cJl000280`00>4@000@M00088P00
D4d08YL00=V<003m2@00mBd00;c30000Nad002Lj00036P003BL005e604bU003SK000o`400>e90025
]@0006`e000G<0000QT001L`001/=@25]@00kDP00?l1003SKP00BJ@0001KA`0032H000<K000Z?@00
OaH0a/000?LU003l3`00e9/000j?0000@dT000DN00068000C4d079@00=R@003m2P00m2h00;K10000
N280028h00026P00>SD0Ijd00>UI003o0000if0005^Y0000H4<000hX00036P009c/007dJ0<K2003f
9@00o0l00=>O0009S@0003i700057@002280059=02bJ003MP000oP@00?0m002D^@0006lb000H<@00
0QT001Ta001P001_<@2G^P00lC/00?h5003LQ0009iT0001@CP001b0000DN0015BP0DTP00ei<00?d:
003d<000[Kl0001e:0007C@0008I000E;P00JcH0R[H00>m1003o0`00gWl002bJ0000DDd000LQ0005
7P00ADX05Y<00=R@003m2000lc@00::l0000LBh001Xb00026@006C40074_09nl003b=@00oPP00=R@
000FTP0004A:00057P00224005=<03BM003PM`00o`400>e;001e/@0006Dn000@:P000QX002Pk001o
5@39^@00nA`00?TJ003:]P00084C000Y?0000aX0010Z001U?P1e/@00kDX00?l2003ONP00;Y/0001@
C@001b0000HO001=CP0VV000gH000?l3003^AP00O;80001V?@0042X000<J000Y?000PA80bk<00?XG
003h7`00a/00001k7@008SL0008I000E;P00KC@0U[T02_ooool1o`00007ooooo000Nooooo`03o`00
0?oooooooooo00Oooooo0?l000<K00088@00@TT008D90<74003a>P00o`000>YF002>]`0007LT000]
?P0011d000HO000e@`00OQT0Y[d00>i8003o0000kDT00:Bm0000OAX003A200057P001Ad002lo001i
802H^P00k4l00?l0003_@`00[[l0001o5@00=d<000HO00047@00;Ch007TR09Ji003[D000o`000>m3
002/_`0007hG000e@`001Ah000DM000`@000Nah0Wk/00>e:003o0000kDX009jk0000NQl002lo0004
7@001Ql003Q400204`2e`@00l3h00?l0003YF000QKD0001c:`009SX000<K00088P00AT/008T00<Vj
003e;@00oP@00>=^001QZ`0006Ti000K<`000QX000`V001EC00MU@00dil00?TJ003l3`00fX/003JN
0000G4H0010Z00026@005Bh0069104ZT003NO000o@T00?LT003=/0002Hd0001<C@002B8000<K000U
>@00Lb/0RKH00>YC003o0000kTL009nk0000NB4002`m000470001b4004=900290@39^@00mBX00?h6
003PM`00D:H0001S@0005Bh0008I000A:`00GT@0@J400>e6003g9000c;4000F<0000B4`000PQ0004
7000:Sd007TQ0:2l003^A000o`000>UI001l/P0006lb000O=@000aX000`V001EB`0TV000eYH00?/B
003j6000dZ4001NC0000DDd000XT00036`009CT007DX09Bi003]BP00o`000>YE0020]00006la000O
=@000QX000`V001GBP0ZVP00f9000?`?003h7@00cjX000Z>0000BT`000PQ00047000;Sl007dK0;;0
003a>@00o`800>A[001LZ@0006Dn000E;P000QT001<]001S@01EY`00hVl00?l3003b=`00]/40001m
6P00;Sl000@L00088P00C4h049000=6T003j6000na@00=BL000IT`00051>00098`000a/002/m001k
7@2``000lST00?l3003RK`00DjL0001R@P004R`0008I000H<000JCT0Kjl00>QM003o0000kDX008fg
0000LRh001lf00026P003RP005]803fP003NOP00oPH00?@_0032a00007lE000_?`0011`000PR001?
CP0HT`00eIX00?/B003i7000cZd000>;0000@4P000HO00057P00?TL008T00<f`003h7P00na400=FI
000IT`0004m>00088P0011`003X0039100224037_`00mRP00?d:003JR`00:IT0001DC0002R@000<K
000[?@00OAT0_/<00?@_003n1`00g8<003>M0000EdX000/U00036`00:C`007/M0;S1003c<P00oPH0
0=f1000eW@0005M:000;9@000a/002Tl001l702k`P00m3000?h7003LQ000;i/0001EB`002R@000<K
000]?P00OaD0aL800?HY003m2`00fHh002:G0000DDd000PR00047000=D8008D90<^e003h7`00na80
0=>N000>S`0004E:0P001Ql0]`00@dT02hh00=:Q003k4`00n1h00<^d0000Q@T003E2000470002B80
059=02VI003KQ`00oPL00?<a002c`00007TR000T>@000QX000hX001OA01DY`00iFL00?l0003/CP00
O;80001Z>0005Rl0008I000I<P00KS80S[L00>m3003o0P00hG<0046Q0000FDT000/U00036`00;Ch0
084B0<Rk003g8@00na400=:Q0008S@0003m700057P001b4004m>02:G003JRP00oPP00?<b002]_`00
07HV000P=P000QT003`e06n_003ZE000o`000>EU001CY`0005e5000=9`000aX002Xm001o5@38_@00
mb400?/B003AY0000h/0000jA@0011d000TR001DC00cW@00gg/00?l3003_@P00RkH0001/=@005Rl0
008I000K<`00LRd0X;`00?8g003n1`00fXT0022F0000CDh000HP00067`00BD`06i@00=V>003n2000
lc@00:Bm0000LR`001/c00026@005c0006hc09:h003`?@00oPD00=b4000UV00004m>000680001Ql0
04Y<01fE003JRP00oPH00?8i002I^P0006la000H<@000QT001/c001c:`2X_P00lc400?d:003FU@00
3i000010B0001Ad000PR001EB`0kW`00hW800?l1003[D000KJh0001S@0003bT000<J000[?@00PQ00
bk<00?XH003i7@00b;/0001n5`009SX0008J000A:`00Ic`0O[<00>i6003o0`00gH0002NI0000CTh0
00HO00068000D4h0;9X00=mk003o0P00kD/007B`0000I3l000lY00036P00;3h008@=0<f^003k5000
mb<00<C40000NB4001lf00026@005c0006la09nk000:ooooo`7o00000Oooool001kooooo00?o0000
ooooooooool01oooool05P000a/000PR0016B`00Q`@0a/400?8f003o0@00j5/008Je0000MBP002Tl
000470001Ql003U40020502__`00kd<00?l0003/CP00VkX0001j7P00<40200057P0D000b@@00O1`0
XK`00>e:003o0000kTP00:Fm0000OAX003=200057P001Ad00350001k7P2N^`00kD/00?l0003]B000
Xk`0001l7000<T4200057P3o000c@P00OAT0Z;h00>i5003o0000k4l009Fi0000N2<002`n00047000
1Ql003]600233P2n``00lCT00?l1003XG@00O;80001a;P008cP000<K00098P00BTd01H/00<^e003f
:@00oPH00>5c001IZ@0006Ll000I<@000QT000dW001GBP0TU`00eIX00?XG003k4P00f94002nK0000
FTP000lY00026@005Rl006@o05:W003PM`00oPL00?HX003;]@000h/00018B`00228000<K000X>`00
MRL0T[P00>a>003o0000kD`009Ji0000MbD002Tl00037000224004M;00B;003;/`00mRH00?d8003N
O@00B:<0001Q@P004bd0008I000C;@00HD80B:@00>m2003f9`00b[H000290000A4X000LP00047000
;Sh007/M0:Vn003`@000o`400>MN001c/00006`e000L=0000QX000dW001GBP0[VP00f9000?`@003i
6`00d:H0016@0000Cdh000TS00036`00:3/007LT09bk003^AP00o`000>QK001h/@0006dd000M=000
0QX000dX001IB@0aW000fXX00?`<003h8@00cK0000B;0000ADX000LP00047@00<D0007lF0;_2003c
=@00o`<00>9`001DY`0006=0000C;@000QT001D^001U?P1MZP00i6X00?l2003a>`00[Kl0001k7P00
:cd000<K00098P00D4h05Y800=>N003j5@00nQL00=:Q000BT@0004i>00088P0011`002ho001m6@2i
`P00lc@00?h4003QM000Bj@0001OA00042/0008I000J<P00K3H0Mk400>UG003o0000k4l008Fe0000
Kc4001dd00026P003bT005e604BR003PN@00oPD00?<c002i`P0007dJ000/?P000a/000TS001AC@0O
UP00eiD00?`?003h8000c;8000280P00?4H000DN00067`00@TT01H`00<nZ003i6P00na@00=>N000B
T@0004]=00078@0011d003I300242`39^P00mb@00?`<003HT0008YL0001BC@002B<000@L000_?`00
P1D0aL<00?D[003m2@00fhP002bJ0000ED/000XT00036`00;3d007hH0<74003d;@00oPP00=^6000^
V`0005E;000:90000a/002`n001n5`34a000mB/00?d9003JRP00:9T0001CC0002B<000@L000`@000
PQ00b;d00?HU003l3@00ei@0003501^D0000Cdh000LQ00047@00>D@008P30<f`003i7000naD00=6T
0008S@00045800057P001Ql004M;016@003DW000o1000?LQ0039^@0008<>000a@00011`000TS001E
C00`W000gH800?h6003b=P00Z[h0001f9P008CL0008J000@:P00HD80G:T00>IR003o0000je<007B`
0000Ic/001@]00026@006c<0074_09Ji003`?`00o`<00>1i000jW`0005M:000:90000a/003500024
3@3:]P00n1h00?/D003@YP000X/0000kA@0011d000PR001BC@0YV@00g8D00?h6003b=`00Y;d0001d
:P007CD0008I000n=01g/@00k4l00?l0003TJ`00Bj@0001KA`0032H000<K000]?P00PQ00b[P00?PN
003j5@00cjT000280P00=T<000@L00098`00ET/0>il00>5e003o0P00kTL008>d0000JSP001D^0002
6@007C@007@Z0:Vn003c<`00o@P00=V?000JU00004U<00067`001R0004i>026G003KR000oPH00?8i
002K^P00070`000I<@000QT001Ta001`<02K^`00lSP00?h6003JRP007YD0001;C@001Ql000HP001>
CP0TU`00g8D00?h5003`?@00TKP0001]=0005Rl0008I000M=000MBP0/L000?D]003m3000e9/000V=
0000?4H000@M00098`00EdX0@j800>=/003o0000jUD006F/0000H4<000hX00036`00;Sl008@;0<f^
003j5@00n2000<K00000O1`002<h00026P004b`006Ti08Je003_@@00oP@00=b5000PUP0004Y<0005
7`001b40059=03BM003PMP00o`400>]@001[[P000692000>:0000a/002lo00261`3?Z@00na400?HW
002k`P0007HV000M=0000QT001Pa001a;P2X_P002_ooool1o`00007ooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0?l000<J000:9000CDh018/00<Vj003d<000o`<00>IS001i/P00078^000V>P00
11`000LQ000oA`00Q0d0_L<00?4l003o0@00jUH008jg0000MbD002`m00047@001Ql003Q400205@2_
_`00kd<00?l0003/C`00V;X0001i8@00;cl000DM00067`00=T<007lG0:bo003_A000o`000>a@002F
^@0007TR000]?P0011d000HO000iA000PA<0]/400?4n003o0@00jUL008Rf0000MBT002Pk00047000
1b40049900271P36`@00m3<00?l3003VIP00L:l0001^=0007cH000<J000:9000D4h03Xl00<j]003g
8`00oPT00=ml001=Y@0006=0000F;`000QT000lZ001JB00_V`00f9800?/C003k5`00eIT002FH0000
Ed/000hX00026P006C8006Pk05jZ003SK`00o`D00?D^0038_@0008L50011B0001b4000@L000]?P00
NR40X;`00>i7003o0000je@008Vf0000Lb/002Di00036`002B<004i>00f?003>[000n2400?d<003L
Q@00?J00001MA@004B/0008I000F;`00I3l0E:L00?0m003e;@00akh000262000?DL000HP00057@00
<d4007lF0;O1003b>@00o`800>EW001W[@0006Tj000I<P000QT000lY001KB00fWP00fhP00?d<003h
8@00cJh000N=0000BD`000PR00047000;Ch007/N0:Zn003`?`00o`400>IS001[[P0006Xi000I<P00
0QT0010Z001LA`0mX000gH800?h9003g9`00b[P000280`00?dL000HP00057P00=T<008<?0<K2003e
;P00oPH00>1i0018Y00005m4000A:`000QT001Pa001Y>P1Z[@00if800?l1003_@`00X;`0001g9000
9cX000<K000:9000Ddd089H00=JF003l4@00nA`00<nZ0009SP0004M;00078@0011d003=100214P34
``00mBh00?h7003NO@00@:40001LA`003bT0008J000M=000Kc40Q;D00>a@003o0000jUL007Ra0000
K3H001Xb00026@004B/00613052V003RL@00o`<00?8j002/_`0007XQ000X>`000a/000/U001EC00Z
VP00fHd00?d<003g9@00bKX000252P00=d<000DM00078@00BD`03Y000=:S003k5P00nQT00=2W0009
SP0004E:000680001Ah006H003]600280`3</P00n1l00?`A003EV@006I@0001?CP00228000@M000d
@P00Q0d0b;`00?LU003m3000f94002:G0000DDh000TS00047000<D00088B0<No003f9`00o@/00=V?
000TV000059=00098`0011`0035000224038_@00mbH00?d=003GTP007YH0001@CP00228000@M000f
@`00QPT0bkH00?PP003l4@00e9`001:A0000BD`000LP00057P00?dL018`00=2X003j5`00nQX00<j/
0001R@8003]500057P001b4004i>01^D003GU000o@d00?LW0036`@0007lF000]?P000a/000/U001H
BP0kX000h7X00?l4003a?@00WK/0001c;0007SD0008I000B;000ICl0J:d00>UJ003o0000jE/006N]
0000I3l0018/00026P007cH007@Y0:Bm003b>000oPD00=f1000_W00005A<00098`0011d003I30027
1@3>[P020?XI002;0<f_0000Q`D003E3000470002R@005E<03BM003OO@00o`@00?4n002G^@00070`
000J<P000QT0044c08Be003^B000o`800>9c0010X@0005Q:000;9@0011`003=100262@3=/000nQT0
0?XJ003</P0008D:000a@0000a`000/U001IB@16X`00hfd00?l1003/C`00M[40001W?@004R`0008J
000Q=`00N2@0]l400?D/003m3000eYL0012@0000@TT000DN00088@00DDh0;9X00=f0003o1000l400
08jg0000KCD001H`00026@0073@007@Z0:Vn003d<P00o@T00=NB000ETP0004A:00057P002240059=
02jK003NO@00o`<00>m50024]@0006Ti000D;@000QT0024g001i8P2o``00mbL00?`@003BX`000XX1
000f@`0011`000/U001JB01>YP00iV@00?l0003XGP00F:T0001MAP0032H000<K000c@@00R0<0d:H0
0?`A003g9P00_l<0001h8`0083H0008I000E;`00KCD0U;T00?8j003n1`00fHh001NC0000@dT000DN
00098`00ED`0?j400>=^003o0000jUP005n[0000GTD000`W00037000=D800XX10=:Q003l3P00mBd0
0:jo0000Lb`001Xb00026@0073@007DX0;K1000:ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool0P@000QX000/U001AC@0=S`00c;800?DY003n1@00i6/006b^0000KS<0024g0003
6`00228004E:00271036`@00lSD00?l1003XG@00P;@0001c:`009c/000@L00078000?TL008<=0;c3
003a?000o`000>UG002:]P0007HW000Z?00011`000HP000lAP00PPl0^/800?4l003o0000jEL008Rf
0000MBP002Pk000470001b0003m700252P34a000lSL00?l1003WG`00Nk80001a;`008cP000<K0008
8P00B4`00HX00<Vi003e;000oP@00>=]001SZ`0006Xh000L<`000QX000/V001CC00GT`00dJD00?PN
003m3000g8@004:Q0000H4<001<]00026@004B/005e503VO003JR@00o0h00?TK003BX@006Y@0001C
C0002bH0008J000M=000JcH0Jjh00>EW003o0P00lcD00<C40000P`d003]500067`0011d00350001m
6P2]_`00l4000?l0003XF`00O;80001`<00083L000<J000:9000DDd05Y800=6S003i6`00o0l00=V=
000aW00005Y8000?:@000QT001Pa001X>`1PZ`00lSL00?<d0032a000088@000gA00200057P3o000h
A000P`h0aL@00?<b003o1000hfl005ZY0000ICd001H_00026@004B/005i5046Q003MP000o@T00?HV
003:]P0008T00012B@001R0000@M000a@000OaL0^<400?8g003o0P00i6/005jZ0000ISd001H_0002
6@004B/005m404RS003ONP00oPH00?D]0037_`0008@;000iA0001Ah000HO000lAP00QPL0bKX00?HX
003m2000gH4003fP0000G4L000lY00026@006c<006`e07Ja003YFP00o`000>e9002B^00007<Z000R
>0000aX000/V001FB`0ZVP00fHh00?`=003h8@00c;80002:0000@DP000HO00057P00>4@008D:0<Rk
003f:000o@T00=b5000eW@0005U9000=9`000aX0024g001c;02A^000kDP00?l0003WG`00Jjh0001X
>P005c00008I000C;@00I3l0G:T00>EX003o0@00kd4009jk0000MRL002<h00036P0032H005Q:03BM
003LQ000o@P00?D[0036`P00084B000a@00011`000PR001?CP0HT`00eIX00?/A003h7@00cJl0002:
0000?TL000DN00067`00@TT01H`00<nZ003i6P00naD00=:Q000?T00004Q<000780001Ad003U50027
1@3;/`00n2000?`@003EV@005i<0001>CP001b4000@M000f@`00Q@T0b[L00?LR003l3`00eYL001VD
0000Cdh000LQ00047@00=T<008H80<^e003h8000o1000=BK000DTP0004]=000780001Ah003]60029
003>[@00nAX00?XE003AY00028d00012B@001Al000HO0015BP0=S`00dil00?/B003h7P00bk@00026
2000=D<000@L00088P00DDd09IP00=Z;003m2@00m2d00;g30000O1`002Pk00036P0032L005]704JS
003RL@00o`800>m3002?]`0006la000J<P000QT001@^001X>`1e/@00je800?l0003VHP00FjT0001Q
@`003bT0008J000S>000N2<0//000?<a003n2000fXT002BH0000D4d000PQ00057@00?4H00h/00=6V
003k5000n1h00<Zf0000P`d0031000036`002RD005Q903nQ003QM000o`800>i50029]P0006`e000G
<0000QT004@b096h003`@000o`<00=mk000dW@0005E;00098`0011`003Q40029003@Z000na@0001`
0?PO0039^@00084B000/?P000a/000`W001MAP1BYP00iFD00?l0003ZEP00JJd0001S@00042X0008J
000U>@00Nad0a<@00?HV003l3`00dil000N<0000?4H000@M00098P00E4`0=Yh00>1g003o0P00kTL0
082d0000JCT001<]00026@0083H007LT0;O1003e:`00o0d00=FJ000;SP0003i700047@00228005E;
03VO003QM000o`400>e<001f/@0006Hm000A:`000QX002Di001m6`36`000mb400?/D003?Z`0008H7
000a@0000a/000`V001NA@1JZ@00j5`00?l0003UI@00C:D0001JB0002R@000@L000hA005S000dih0
0?`=003e;000/L00001e:@0073@0008I000H<@00L2l0XK`00?<c003m2P00eYH000f?0000?DH000@M
000:9000F4T0BZ@00>EU003o0000iel005>W0000FdL000XU00047000>TD02Hd00=FH003m2P00lc<0
09nl0000Kc4001L`00026@007cH007TR0<C400[ooooo0Ol00001ooooo`007_ooool00ol0003ooooo
ooooo`07ooooo`1R00026@0032H005=<01>A003>[000mRD00?h6003RL000Hj`0001[=P007cD000<J
00098`00BT`00HX00<Rl003d<@00o`800>IS001h/@00074_000T>@000a/000LQ0012B@00QPP0aL@0
0?8g003o0@00j5`0086d0000Lb/002Lj000470001b40041800252P33a000lSP00?l1003XG@00Ok<0
001b;0009CX000<K00078@00@dT008L50<K0003c<P00o`800>IT001b/00006hb000Q=`000a/000TS
001=CP07S@00bk<00?HX003n1P00hG<005ZY0000Ic/001Tb00026P0032L005E;01jE003CW`00nAX0
0?`>003JR@00>Yl0001NA@004R/0008I000C;@00H4<0@J400=b4003m3000n1h00=2W000DTP00055=
000:9@000aX001lf001^<`1c/000if400?l1003a>@00^l8000214P00=d<200057P1V000e@P00P1D0
]/400?4k003o0@00if0007>`0000KC@001he00036P002bD005A<01fE003CWP00nQP00?/B003GT`00
:YX0001HBP003BP0008J000K<P00JSP0JJd00?8d003b>000^L8000205@00=48000DM00067`00?4H0
08D90<No003d;P00oPD00>5d001BY`0006=0000D;P000QT0018/001P@`19Y000ggX00?h7003e:P00
b;/000261P00?TL000HO00057@00=D80084B0<74003c<`00o`@00>9`001FZ00006@o000D;P000QT0
01<]001R@@1@YP00hG@00?h5003d<@00a<@000224@00=D8000DM00067`00@4P008T10<^e003g9000
o@/00=^7000eW@0005Y8000=:0000QX001dd001^<P1o/`00jUD00?l0003/C`00RKH0001a;P0083H0
008J000=9`00F4T0<Y`00=^8003m2`00mbD00<Zg0000Q`D003a60P001Ah0o`00?4H008L40<Zf003g
9000o@/00=Z;000]V`0005I:000;9P000aX002<h001e:02J^P00kd<00?l1003VI000Hj/0001V?@00
5Bh0008I000E;P00ISd0I:`00>IS003o0000kTH009Fi0000Lb/0024g00026P003BL005Y803^O003N
OP00oPH00?@`0030``0007hG000^?`0011`000TS001AC@0NUP00ei@00?`?003h8@00bk@000271@00
>TD000DN00068000AT/02hh00=6T003j5P00nQP00=2V0009S@0004A:00067`001Ah003e70029003=
[P00nA`00?/C003CWP004I000019C0001b0000DM000jA@00Q`@0c;800?PN003k4P00e9`001>A0000
BT`000LP00057@00>TD008P20<f`003i7000na<00=>P000=S`0004I;00067`001Ah003m800F<003@
Z000nQL00?XH003?ZP000XX0000mA`001Ah000LP001:C00DTP00eIX00?`?003g8P00bKT000233@00
<T4000@L00098`00Dd`0;9X00=b6003n1`00lc400;C10000NB4002Di00036P003RP005e504jU003T
J`00o`400>e80026]@0006dd000H<@000QT001H_001Z>01n/`00k4d00?l0003UJ000DjL0001NA@00
3RP000<J000U>P00NQl0^l800?D]003m2P00f8l001fE0000CTh000LP00057P00@4P02Hd00=>P003k
4@00mb800<Rl0000PA8002dn00036`0032H005Y804NS003SKP00o`400>e:0020]00006Xh000E;P00
0QT004Ha09^j003a>`00oPD00=f1000]V`00059=00088P0011d003a600F<003BXP00na400?LR0037
_P0007lG000Y?0000aX000hX001OA01JZ@00if000?l0003XF`00HJ/0001Q@P003RT000<J000X>`00
OQP0akl00?LR003k4P00dJD0006:0000>4@000@L00098`00EdX0?Z000>9b003o0@00k4`007Ra0000
Ic`0018/00026P008SP007XP0<33003f9`00o0l00=>P0005S00003Y5000470002B<005M:046Q003S
K`00o`000>]A001^[`0006=0000?:P000aX002Pk001o5P39^`00n1h00?XG003=/00008@<000]?P00
0a/000dX001P@`1SZ`00jEL00?l0003TJ`00A:80001GBP002B<000@M000lAP009`0;SP00eIP00?d;
003d<000Z;h0001b;@006S80008I000J<P00Lb`0Z[h00?@_003m3000e9`000N<0000>D@000@L000:
9@00FdL0DZL00>MP003o0000iVD004^T0000FDT000TT00047@00?TL03i000=NC003n2000lSL009Ji
0000KC@001D^00026@008SL007/M0<K0000:ooooo`7o00000Oooool001kooooo00?o0000oooooooo
ool01oooool0LP000QT000dX001EB`0JU000d:L00?LQ003m2000h7H005^Y0000JCT001`d00036P00
2R@004m>00N<003:]P00mB`00?l4003UJ000Kjl0001^<P008CL000<K00088P00AT/008P20<No003c
<P00o`800>IQ001h/@00074_000T>@000a/000PQ0014BP00Q`@0a/000?<c003o0P00iV8007Ja0000
L30002<h00036`00228004Q;002:0039^P00m2h00?l4003TJP00JJd0001/=@007SD000<J000:9000
D4h03Hl00<f^003g9000oPP00>1i001BY`0006Dn000G<0000QT000hX001GBP0UV000eIX00?XG003k
4@00f8l003:M0000FdL0010Z00026@005Bh0069104VT003NOP00o@X00?LR003>[0003Hl0001?CP00
2B<000<J000Q=`00L300O;800>QL003o0@00l3h00;700000OQL003=100057P001Al003U400224030
``00lSH00?l2003UIP00JZh0001[=`0073<0008J000<9`00ET/099L00=FH0080naD00280eIT002>G
0000ED/000`V00026P007C@006`e076`003c<@00l3d00;300000OAX0031000047@001R0004180028
0`39^P00mBX00?h7003ONP00BZ@0001Q@P004b`0008I000D;P00Hd00DJH00>5d003n1@00m2l00<K1
0000Q0`003U50P001Ah0S@00>D@008@<0<K1003d;`00oPD00>1f001>Y@000652000C;0000QT001D^
001T?`1HZ000hfh00?l3003b=@00^l80001o5P00<D0000@M00078000ADX018/00<f_003h8000o0d0
0=V<000^V`0005M:000<9`000aX0020f001a;P28]P00k4l00?l0003ZE000P;<0001_<P007C@0008J
000>:000FTP0>Il00=b2003m2@00mRT00<Rl0000Q@X003Q400057P001Ql00458006:003</@00n200
0?`>003HT0009YP0001DC0002RD000<K000V>P00N2@0Y;d00?0n003o0P00i6X005ZY0000Hd0001<]
00026@005c0006Pj06f^003XG@00o`000>e;002<]`00074_000N=@000QX000hY001LAP13XP00h7T0
0?h5003c=000]l40001l7000:cd000<K000:9000Dd`09IP00=V?003m3000mbD00<Vi0000Q@X003I3
00047@001b4004]=01:A003CW`00na<00?TK003>[0000X/0000oB0001Ah000HO0012B@06S000d:P0
0?XI003j5P00dJ@000^>0000ADX000HO00057P00?TL00HX00<j/003i6`00na@00=:R000<S`0004E:
00067`001Ah003i700>;003?ZP00nAT00?XF003AYP001hd00011B@0200067`2C0014BP0;SP00dZ80
0?/D003i7000cJl000280`00>DD000@M00078@00CTh06Y@00=ND003l3@00mRH00<No0000PA<002ho
00036`002R@005I;03>M003MP000oPD00?8f002Z_P0007LU000R=`000QX000lY001P@`1FZ000iFH0
0?l0003/C@00OK<0001Z>0005Rl0008I000H<@00KC@0QkD00>i8003o0@00hfd004^T0000G4L000dW
00036P00:3/007dJ0<C4003f:@00o@`00=JE000GT`0004U<000680001Ql004A:00n@003DV`00o0h0
0?HU0036`@0007hG000Y?0000aX000dW001MAP1?Y@00i6T00?l0003/C`00Mk40001X>`004bd0008I
0018;`2T_@00lSH00?h6003KQP009YP0001@CP001b4000DN0010B00;SP00e9d00?`?003f9P00aL@0
001l70009SX000<J000?:@00HD80HZ/00>UJ003o0000if4005RX0000GTD000dW00036P00:cd0080C
0<Vj003h7`00nQD00<nZ0000Q`@003A2000470002R@005U904JS003SK000o`000>]A001_[`0006@o
000@:P000QX002Di001l6`36`P00mb<00?/B003AYP0008T0000f@`0011`000XT001IB@19Y000i6T0
0?l0003ZEP00IJ`0001Q@P003RP000<J000[?@00PA40bkD00080nAX003H0b[H000214P00:Sd000<J
000?:@00HT40Jjh00>]B003o0000hW0003fP0000ED/000PR00057@00@DP04I400=NC003m2@00lcD0
09nk0000L30001P`00026@007C@007DX0;C1003e:`00o0h00=:Q0001RP0003E200036`0032H005e6
05ZY003XFP00o`000>AZ0013XP0005I:00098`001Ad0049901JB003IS@00oPH00?4l002=]`0006Xg
000C;@000QX002@i001n6@39^P0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0A`000QT000lY001GBP0QUP00dZ400?PN003m2P00gg`005>W0000Ic`001Xb00026P002bD0055=
00f?003</@00mRP00?h5003SKP00IZ`0001/=P007cH000<J00098`00Bdd00h/00<Vi003d;P00o`<0
0>EW001_[`0006hb000Q=`000a/000TR0019C001RP00bK/00?@_003o0`00iFP006j_0000KC<0020f
00036P002B<004e>00J<003;]@00mBX00?h5003RK`00HJ/0001Z>@0073<0008J000;9@00DTd05980
0=2X003h8000o@X00=in001:Y00006=0000E;`000QT000lY001IB00/VP00ei@00080na@00=80eYD0
02^J0000FDT000lY00026@005c0006@o056V003PN000oPL00?HV003</P001hd0001;C@002B8000<K
000T>@00Lb`0QKD00>YF003o0000kd<00:Rn0000O1`0031000047@001Ql003e600252P36`P00lc80
0?l3003TJ`00HZ/0001X>P006C80008I000>:000F4T0:iX00=NB003k4P00nQP00=>N000LU@0005=<
000;9@000aX001lf001_<@1j/P00m2h00>m2002V_@0007/N000]?P0011`000LQ0015BP01RP00bk@0
0?HV003m2@00gH0004:R0000GT@0014[00026@005Rl006Dn05VY003SK`00o`@00?<c0032a000084A
000f@`001Ah000HO000mAP00QPL0b;`00?DZ003n1`00gg/004JS0000Gd@0014[00026@005c0006Ll
062[003TJ@00o`800?4j002b`00007dK000^?`0011`000LQ0019C00:SP00cjX00?TM003l3`00ei80
02JH0000ED/000/U00036P008SP007<[096h003]BP00o`000>UI001g/@0006`e000K<`000QT000lY
001MAP11X@00gWd00?h7003e;@00a/8000224000=D8000@M00078000ADX01h`00<j[003i7@00na40
0=JF000OUP00059=00098`000a/002Tl001j7`2]_`00lCX00?l3003RK`00DZL0001Q@P004B/0008I
000I<@00JcL0M[400>UH003o0000je0008>d0000KS8001`c00026@0042X005m404^T003QL`00o`<0
0?8i002]_`0007TP000W>`000a/000/U001EB`0]V`00fXT00?d:003f:@00akl000224000<T4000@L
00088P00Cdh069<00=FI003l4@00n1l00<ba0000R08003]600057P001R0004I;00b?003BX`00nQD0
0?TI003?ZP0018/00010B0001Al000HO0012B@07S@00d:L00?XG003j6000d:P000J<0000@DP20006
7`130013B@09S@00dJD00?XF003i6P00cZ/0006:0000?DL000DN00068000B4`04I400=BM003k4@00
n1l00<^e0000Q@T003E3000470002280055=026G003ISP00o@/00?DZ0035a00007hH000[?@000a/0
00/U001HB@0kW`00ggX00?l4003a>`00XK`0001d:@007cH0008I000@:P00HT40GjX00>MP003o0000
je<007B`0000J3/001@^00026@006S8006la092h003_@`00o`800>5c0013XP0005Y8000;9P000a/0
02/m001o5@37_`00mbD00?`?003EVP0049000015BP0200067`2@0019C00FTP00eYD00?d<003e:P00
`/@0001l70009SX000<J000>:000Gd@0EjP00>IS003o0000jU@006j_0000ICh0018/00026@00Bbh0
[Kl00?<b003n2000fH`001nF0000CTh000LP00057P00A4X04Y400=JG003m3000mBX00;c30000NR00
02<h00026P0042X006@o06^^003ZE@00o`000>EV001@YP0005a6000<9P000a/002ho00233P3;]000
nA/00?XH003=/00008D:000`@0000a/000/V001KA`1>Y@00iFL00?l0003ZEP00IZ`0001R@@003bT0
00<J000X>`00OaL0b;`00?PP003j5@00cj/000261P00<T4000<K000;9P00FdL0DJH00>IT003o0000
j5/005fZ0000Gd@000dW00036`00;Sl008@;0<f`003j5`00n1h00<Rk0000OaL002Lk00026P0042X0
06Dn07B`003/C000o`400>1f000eW@0005=<00088@001Ah004E:01RC003IS@00oPL00?4i002E^@00
06dd000F;`000QT001lf001h902m``00mRH00?/A003@Y`0008L4000a@@000a/000dW001OA01SZ`00
jUD00?l0003RL000>il0001DC000228000DN0017B`0MU@00fhL00?h5003_@@00Q;D0001X>P004R/0
008J000W>`00P1@0bkD02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l0
008I000@:P00FTP0:9T00=BL003i6P00o0d00=f1001:Y00006@o000H<@000QT000`V001CC00DT@00
cZ/00?LT003n1`00hG<005jZ0000JCT001`d00036P002R@004m>00V=003;]000mBX00?h5003SK@00
Ijd0001/=P007SD000<J00099000CTh01h`00<^e003e:P00oPD00>=]001U[00006/g000M=0000aX0
00XT001@CP0<S`00cK000?HV003n1`00hGD005RX0000Ic`001Tb00026P0032H005A<01^D003BX`00
nAd00?`<003LQ000@Z80001P@`0052d0008I000@:`00G4L0=9d00=V>003k4@00nQL00=BK000TU`00
05M:000=:0000QT001Ta001W?01IZ@00hG<00?h6003e:P00b[L0006:0000Ad/000PQ00036`009c/0
07DX08jg003[D@00o`000>i8002N^`0007TQ000/?P0011`000LP0011B000Q`D0b;d00?@]003n1@00
hW4005VY0000ISd001L`00026@003bT005Y803:M003IS@00o0l00?TK003AY0005I80001AC@002R@0
00<J000R=`00LBh0Pk@00?D[003^A`00WK/0001h8`00:C`000<L00088P00BD`028d00<f_003g8P00
o@/00=b5000jW`0005a6000@:P000QT001Pa001W>`1RZ`00i6T00?l2003b>000^<80001o5P00<T40
00@M00068000@DP008T10<Zf003f9P00o@T00=f1000nX00005e6000@:P000QT001Ta001Y>@1Y[@00
iV<00?l1003`?`00Z;h0001j7`00:cd000<L00088P00CTh04I000=6T003i6@00na800=FH000OUP00
05=<000:90000a/002Di001f9P2J^P00kTD00?l0003WG`00KZl0001Z>0006C40008I000A:`00Gd@0
BJ@00>1g003n1@00lc400<330000P1D00350000470001b4004Y<00f?003AYP00nAT00?/C003DW000
69<0001@CP002B8000<L000/?P00OAX0]l400?<e003n1000hGD004ZT0000Gd@0010Z00026@006c<0
06dd07jc003[DP00o`000>YE001j/P0006`f000J<P000QT0014[001Q@P1CY`00hfd00?l2003`?@00
Y;d0001g9@009CT000<J000<9P00F4X0=9d00=b3003n2000mBd00<G40000OaD002lo000470002B<0
07d0055=01nF003GT`00o0h00?LR003:]`0008D8000gA00011d000LQ001;C@0CT@00e9d00?/B003i
7@00cJl000290@00?4H000DN00068000Ad/03Hl00=:Q003k5000nA/00<j]0000RP0003e600057P00
1R0004M;00n@003CW`00na<00?PM003</@0008L4000iA0001Ad000LQ001=CP0HT`00eYL00?`>003g
8`00bKX000233P00<T4000@L00098`00Dd`0:IT00=^9003m2000m2h00;c20000Nad002Pk00036P00
32H005Y804:R003QM000o`800?0o002H^P00078]000M=0000QT0018/001T?`1W[@00j5/00?l0003Y
F000K:h0001U?@004b`0008I000L=000LRd0VKX00?0n003o0`00h7T003^O0000EdX000XU00036`00
;cl0088@0<Vj003h8@00na400=>P000:SP00041800057P001b0004i>01fE003HS`00o@X00?@^002h
`@0007TQ000T>@000QX000lY001Q@P1OZP00ieh00?l0003YFP00IZ`0001S@00042X0008J001=;@2g
`@00m2h00?d:003GTP0069<00019C00200067`1d0019C00HT`00f9400?d:003d;`00/l00001g9@00
83L0008I000B;000ISd0M;000>]?003o0000hf`004RS0000FTP000/U00036`00<D4008D90<f_003j
6000nA`00<^e0000PPl002dn00036`003BL005e505JX003WH@00o`000>QL001NZP0005m4000>:000
0aX002/m00214@3:]`00nA`00?XH003</@0008@<000_?`000a/000`W001NA@1IZ@00ieh00?l0003W
H@00E:L0001LAP0032H000<K000b@@00Q`H0cjX00?/D003g8P00a/40001l700093T0008J000B;000
Ic`0OK<00>i7003o0P00gg`002jK0000DDd000LP00067`00BT`07iH00=^7003n1@00l3h008bg0000
JcL001@]00026@008SL007XO0<G3003g8`00na@00<j/0000Q@X002ho00036`003RP0069106^^003[
D000o`400>5f000cW@00059=00078@001Ql004a=02BG003MP@00o`<00>i6001k/P0006Hm000@:P00
0aX002Xm00233P3=/00:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`00
0QT0018/001LAP0_V`00eYH00?XG003l3`00fhL004:R0000HT4001H_00026@003BL005E;01ZD003A
YP00n2000?d9003ON@00EJL0001W?0006S80008J000;9@00DDd03i000<f^003f9P00oPL00>5b001N
ZP0006Ti000L=0000aX000XU001@CP0=S`00cK000?HV003n1`00hG<005bZ0000JCX001/c00026P00
2bD0059=01>A003?ZP00mb800?d9003ON`00D:H0001U?P005c00008I000=:000EdX08YL00=BM003i
6@00o0l00=Z:000jW`0005i5000B;0000QT0018/001NA@0kW`00fhT00?`>003i6`00dZ0001fE0000
E4`000`V00026P006c<006Ti06:[003SK@00oP@00?@_0038_@0008L40012B@001b4000@L000Z?@00
N2@0UkX00>e<003o0000k4d009Fi0000MbD002Tl000470001b4004E:002:003:]`00mRT00?h7003P
M`00DJH0001T?`005Bl0008I000@:P00GDH0>Yl00=^7003m3000n1l00<nZ000?T00004m>00098`00
0a/002Di001d:P2=]`00mBP00>a<002C^@0007HW000V>P000a/000TS001>CP0>S`00cjT00?PN003l
3P00fX/003>M0000FTP000hX00026@006S8006Xh06^^003VH`00o`400?4l002__`0007`K000^?`00
11`000LQ0016BP04R`00c;400?LR003m2`00fhL003JN0000FTP000hX00026@006c<006/f07:`003X
GP00o`000>m4002N^`0007LT000W>`000a/000TS001@C@0GT`00dil00?XF003j5@00dih001RC0000
DDd000TS00036`00:3/007PR0:Bm003`@000o`400>IT001U[00006Lk000G<0000QT0018/001Q@P1A
YP00hW400?l3003b=P00]/40001m6P00;Ch000@L00088P00Cdh059400=>P003j5P00nQL00=:R000A
T@0004e>00088@0011`00310001o5@30``00m3000?h6003ON`00@Z40001LAP003RT0008J000M=@00
L300R;H00>a=003o0000j5/0076_0000JCT001P`00026@004bd006=005bY003UJ000o`400>m2002J
^P0007@Y000R=`000aX000dW001JB00lX000gWd00?h6003c<@00^l80001m6P00;3d000<K000:9000
i@00Dd`09YP00=V=003m2`00mRH00<Rl0000P`h003=200047000228004m>01VD003FU`00o0l00?PP
003;]@0008H7000hA00011d000LQ001<C@0DTP00e9/00?/A003h7`00c;<000271@00>D@000@M0007
8@00C4d05Y800=FI003l4000n2400<Zf0000Q@T003E200047@002280051>01nF003HT@00o@`00?HW
0036`000080C000^?`000a/000XT001EB`0`W000g8<00?h6003c<`00//00001i8@009CT000<J000=
:000GDH0Bj@00>=_003o0@00kT@008jg0000Kc4001Xb00026@0052d006Ll072_003ZE@00o`000>QN
001SZ`0006=0000A:`000QT001lf001d:@2S_000lCT00?h5003NOP00<id0001EB`002B<000@L000b
@@00Q0/0bk@00?PM003k5000d:H000>;0000?4H000DM00078@00D4h099P00=Z9003n2000lc800:jo
0000MbD0024g00026P004B/006@o06R]003YF000o`000>MO001MZP000613000?:@000aX0050/0<34
003e:@00o0d00=JH000AT@0004A:00057P001b0004i>01nF003JR`00oPP00?<c002Y_P0007@Y000N
=@000QT001@]001Y>P1m/`00kDX00?l1003RL@00@:40001GBP002R@000@L000e@`00R0<0cjT00?/D
003h7`00b;/000205000:S`000<J000>:000H4<0GjX00>QK003o0000iV4005FX0000GDH000`W0003
6`00;Sl008@<0<ba003j6@00nA/00<Zf0000PA4002/m00036P003RP00613066[003YF@00o`000>EW
001<Y@0005Y8000;9@0011`003E30029003AY000na400?HV0032a00007TP000Q=`000QT001<]001Z
>@26]@00kd800?l4003MPP009YP0001?CP001R0000HO001>CP0VV000gH400?l3003_@`00Pk@0001X
>P004R`0008J000T>@00OAX0akh00?PO003j5`00c;8000223`00:cd000<J000?:@00I3l0M;000>e:
003o0P00gg/002bJ0000D4h00P001R003000Cdh0:iX00=ml003o0P00kD/007:`0000Hd0000lY0003
6P00;Sl008D90<nZ00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o0002
6@004bd005i403NN003HT000na@00?/B003IS@00>Yl0001OA00052d0008I000?:@00EdX08YL00=>P
003i7000o@/00=io001=Y@0006Dn000H<@000QT000`V001DC00FTP00d:P00?LR003m2@00h7P005JX
0000Ic`001Xb00026P0032H0059=01BB003?ZP00mb800?d8003PN@00E:L0001V?@006C40008J000<
9`00E4`06Y@00=6T003h7P00o@/00=f10018X`000691000E;`000QT000lY001IB@0YV@00eYL00?XF
003k4P00f90003:L0000G4L0010Z00026@0052d0065304>R003LP`00o@`00?PN003@YP005Y80001B
C@002bD000<J000M=000K3H0Jjh00>EW003o0`00lc<00<G20000Q@X003i70006800011d002hn001j
7`2Q_000kTH00?l0003[DP00RkL0001d:@009SX000<K00088P00BTd01h`00<ba003g9@00o@P00=im
0019Y0000652000D;@000QT0018/001OA012XP00gH400?d:003g8`00cJl000R=0000Bdd000PR0003
6`00:3/007HV09Ji003f9P00je4008Zf0000Lb/002<h00036`002R@0055=01FB003AX`00nAX00?`@
003HT@00:iX0001GBP003BL0008J000L=000K3D0Lk000>MN003o0000kd400:Fm0000NR0002/m0004
7000228004Y=00Z>003?Z`00n1h00?`>003IS@00;i/0001HB@003BL0008J000M=000KS<0Nk800>UH
003o0000kDT009Fi0000MBP002@i00036`002R@005=<01jF003EV@00na<00?XI003AX`004Y40001>
CP00228000<L000[?@00Nah0[Kl00?4k003o0P00i6X005fZ0000ICh001D^00026@0052d006@o05ZY
003TJ`00o`800?4k002]_`0007XO000Z?0000a/000TS001AC@0KU000eIX00?/C003i6P00d:L000^>
0000B4/000LQ00047@00=480088@0<K1003e;000oPL00=f1000jW`0005Y8000=9`000QX0020f001b
;02A^000kTP00?l0003WH000J:d0001W?0005Rl0008I000E;P00ISd0I:`00>IR003o0000kTL0096h
0000LRd001lf00026P003RP005a604BR003PN000oP@00?8f002b`00007XO000X>`000a/000/U003G
001FB`0^V`00fhP00?d9003e:P00a/8000204`00<40000@L00098`00DDd089H00=RB003l3@00mb@0
0<Vj0000Q0`003A200047000228004m>01^D003FU@00o0h00?LR0039^00008@;000e@P0011`000PR
001@CP0MU@00ei<00?`=003g9@00b;`000223`00<D4000@L00098`00DTd09YP00=Z;003m2P00mB/0
0<?40000OQP002/m00036`002bD005M:03RN003NO@00oPD00?8g002Y_P0007HV000R>0000QX000lY
001OA01CY`00i6T00?l1003]BP00QKD0001]=@006340008I000F;`00JCT0NK800>]@003o0000iV<0
05ZY0000HD8000lZ00026P008SL007LU0:bo003c=000oPH00=b4000[VP0005=<00098P0011`003I3
00271@3=[`00nAX00?XH003>[00008P2000hA00011d000PR001BC@0[VP00g8<00?h6003b=`00YKd0
001d:P007SD0008I000B;000ISd0LJl00>]C003o0000iVD005FW0000GTD000dX00036P00DbX0a/40
0?LU003l3`00did000^>0000@4P000DN00078@00D4h09YP00=b6003n1P00lSP00:2l0000LRd001/c
00026@005Rl006/g08Je003^A@00o`800>1g000hWP0005E;00098`0011`003U500:;003AY000na40
0?LS0036`00007dJ000W>P000aX000lY001R@@1W[@00jUH00?l0003UI`00CJD0001KA`002bD000<K
000b@@00QPH0cZ`00?XE003h7`00b;`0001o5P00:3/000<J000?:@00Hd40JZh00>YC003o0000hf`0
04BR0000F4X000XT00047000>DD01H`00=>O003l3P00mBX00;S20000MbD001le00026@005Bh006`e
08ng003`?@00oPD00=^7000OUP0004Y<00067`001b00055=02fK003ON`00o`800>e8001j/P0006Hm
000A:`000QX002Lk001o5@39^0000P3i6`006P3:^000080E000W>`000QX0014[001W?01m/`00kTD0
0?l3003MP@0099P0001<C@001Ql000LP001BC@0cW@00h7H00?l1003[D000JJd0001Q@P003BL000<K
000a@000R0<0dJ@02_ooool1o`00007ooooo000Nooooo`?o00001oooool0o`000QT001D_001Q@P0o
X@00fXX00?/A003j5@00ei<003:M0000GDH0018/00026@0042X005Y802VI003EVP00nAT00?`>003L
Q@00AJ80001R@@005Rl0008I000=:000ET/07ID00=:S003h7P00o@/00=in001=Y@0006@o000H<000
0QT000dW001EB`0KU000dJ@00?PN003m2`00gWl004^U0000I3l001L`00026@003RP005I:026F003C
WP00nAX00?`>003KQP00@:40001P@`0052d0008I000@:P00FdL0<I`00=RA003k4`00nQD00=JF000[
VP0005U9000?:@000QT001H_001S@01<Y@00gWd00?d9003g8P00cZ`000n@0000D4h000XT00036P00
83H006hb07B`003VH@00o`800?8h002n``00088?000iA@001Ql000DM000a@000OAX0Zkh00>m1003o
0000jEP008:d0000LRd002<h00036`002B<004m>00f?003>[000n2400?d;003LP`00@J40001OA000
4R`0008I000D;@00HT80BZ@00=mk003n2000mRL00<^e0002RP0004I;00078@0011`002/m001i8@2P
_000mb<00>UG0021]000070_000Q=`000aX000/U001CC00LU000dih00?XG003k4`00eYL002BG0000
ED/000`V00036P007cD006la07fc003YF000o`000>i6002K^`0007LT000X>`000a/000TS001?CP0A
T000dJD00?TK003l4000ei<002NI0000ET/000`V00036P0083H0070_08Be003[D`00o`000>a>002<
]`00078/000R=`000aX000/U001EB`0VV000ei<00?`@003i7000cjT000^>0000BT`000LQ00047000
;cl007hI0;O1003b=P00o`<00>9`001DY`000691000C;@000QT001H_001V?01RZ`00iFH00?l1003`
@000Xk`0001h8`009c/000<K000:9000Dd`08YL00=ND003l4000n1h00<j]0004R`0004=900068000
1Ad003M400242`38_000mRP00?d:003KQ`00<Y`0001HBP0032H000<J000S>000MBP0VkX00>m3003o
0@00iFH005nZ0000I3l001@]00026@005c0006Pj06f^003XG000o`000>a=0027]@0006la000M=000
0QT0010Z001OA01<Y@00hW800?l3003a>`00Z;h0001h8`009CX000<J000<9P00l`00F4X0=Ih00=f2
003n1`00m2l00;o30000OQP002`n00036`002R@005=<02RI003JS000o@X00?HX0036`000084B000`
@00011`000TS001AC@0RU`00f9000?d<003f9P00akh000224000<D0000@L00098`00DTd099P00=V=
003m2`00mRT00<K10000P1@002ho00036`002R@005E<02jK003LQ@00oPL00?@`002i`P0007/M000X
>`000aX000`V001JB010X@00h7L00?l3003a?000Wk/0001d:P007cH0008J000@:P00HD80FjT00>IS
003o0000k4l007bb0000JSP001H_00026@00630006`f08:d003]B`00o`000>AY001BYP0005i5000>
:0000aX002@i001i8@2f`@00m3000?d8003JRP0099P0001AC@00224000@M000jA@00RP00cjT00?XF
003i6`00c;4000262000=48000@L00098`00ED/0<id00=im003n1000lC`009^j0000LRh001`c0002
6@0052h006Tj07Zb003/C@00o`000>AZ001<Y@0005a7000<9P000a/005HY0<Rl003g8@00na800=6S
0004R`0003]600047@00228005==02jK003MP000oP@00?0m002F^@0006la000I<P000QT001P`001^
<`2?^000l4000?l3003NO@00<9`0001CC000228000@M000mA`09S@00dih00?`?003f9`00`/@0001k
7P0093T0008J000A:`00ICh0L:l00>]A003o0000hfd004FR0000F4T000XT00047000=T<008T00=2V
003k4P00mb<00<K10000O1/002Di00026P004B/006Dn07>`003/CP00o`400>9b000lX00005E;0009
8`0011d003i700b>003EV@00o@/00?@^002^_`0007@Y000L=0000QT001L`001_<P2I^P00lSP00?h7
003IS@0069<00015BP001Ah000PQ001CC00eW@00h7H00?l1003/CP00LJl0001S@0003bT000<J000Z
?@00PQ00c;<00?XH003h7P00b;d0001m6P0093T0008J000C;000JCT0QkD00?10003n1@00fhL001fE
0000Ad/000DN00088@00E4`0>Yl00>9`003o0000jUH0062[0000GTD000`V00036`00=D800XX00=>N
0008ooooo`?o00000Oooool001kooooo00?o0000ooooooooool01oooool0E`000QT001L`001S@017
X`00g8@00?`>003j6@00eIT002^J0000FdP0014[00026@004R`005a6032L003GU000nQH00?/A003J
R`00?:00001P@`0052h0008I000?:@00F4T09IP00=BM003i6P00o0d00=b40015XP000691000F;`00
0QT000hX001GBP0RU`00dih00?TK003l3@00g8D004>R0000HD8001D^00026@003bT005U902RI003E
V000nQL00?`A003IS000>9h0001MA@004R`0008I000B;000GTD0>Il00=Z;003l4000nQP00=BL000S
U`0005M:000=:0000QT001P`001U?@1DY`00h7L00?h7003f9P00c;8000R=0000CDh000TS00036`00
8SP0074_07fc003XG000o`400?4m002e`@00080E000e@`0200057P3o000e@P00OaD0]<400?4l003o
0@00j5d007Vb0000Kc40020f00036P002R@0055=01BB003@YP00n1d00?`=003KR@00>9l0001LAP00
42X0008I000F;`00I3l0DjL00>5e003n1P00mB/00<Vk0000R0<004580007800011`002ho001l702Y
_P00n2000>QL001g/@0006hc000N=@000QX000`V001EB`0SU`00eIP00?/D003j5P00e9d001bE0000
Dd`000/U00036P008CL0078^08Je003[D`00o`000>a<002B^00007DY000U>@000a/000XT001AC@0H
T`00dj000?XG003k4`00eIT0022F0000Dd`000/U00036P008SP007<[08jg003/C@00o`000>YD0022
]000070`000O=P000QX000`W001GBP0]V`00fHd00?`=003h8000cJl000B;0000ADX000LP00047@00
<T40080C0<74003c<P00oPD00>1f001<Y@000613000A:`000QT001Pa001Y>P1[[P00if000?l0003^
A@00VKX0001e:00093T000<J000;9@00ED/0:IT00=V>003l3@00mb400<bc0000R@4003m700067`00
1Ah003a600271@3:]P00mb@00?d<003IS@00:YX0001EB`002bD000<K000V>P00Mb@0Y;d00?0n003o
0P00hf`005JX0000HT40018/00026@006C4006/g07Ja003YE`00o`000>]B001n/`0006dd000J<P00
0QT0014[001Q@P1EY`00hf`00?l2003`@000W[/0001e:0008SP000<J000=9`00FTP0?J000=ml003n
1@00lc<00;K10000Nad002Tl00036`002bD005I;02nK003KQP00o@P00?D]0033a00007hG000]?P00
0a/000XT001DC00ZV@00fXX00?d9003e:`00aL<0001o5P00;Ch000<K000:9000E4`0;9X00=^7003m
2000m2d00<330000OAX002Xm00036`002bD005M:03FM003MO`00oPH00?<d002__`0007PR000U>@00
0aX000dW001LAP18X`00hW400?l2003_@@00UKT0001a;P007C@0008I000B;000I3l0I:`00>QM003o
0000jU@007>`0000J3/001@^00026@006S8006hb08bg003^A@00o`400>=_0019Y00005a7000=9`00
0aX002Lk001l7030``00mB/00?d:003HT0007ID0001>CP001b0000DN002J000nA`06S000dJ<00?/C
003h7`00b[L000233@00<40000<K000:9000EdX0>il00>1h003o0`00kd40096h0000Kc4001Tb0002
6@005Rl006/g08>d003]B000o`400>9`0014XP0005U9000;9@000a/005TW0<Zf003h7@00nQD00<nY
0000R@4003M4000470002B<005E;03JN003ONP00o`<00>m2002<]`0006dd000G<0000QT001Xb001`
<02I^P00lC/00?h5003LP`00:IT0001AC@001b4000DN0012B@0?T000eIP00?d<003e;000^<80001h
8`008CL0008I000B;000Ic/0NK800>e;003o0@00hG<003bP0000ET/000TS00047000>TD01H`00=>P
003l3`00mRL00<330000NR00028h00026@004R`006Lk07bc003]B000o`800>1h000dW@0005=<0008
8P001Ah0049901:A003GT`00o@T00?<c002T_@00078]000J<P000QT001Tb001a;P2R_000lc<00?d9
003GT`004I000011B0001Ad000PR001EB`0mX000hW000?l0003ZD`00J:d0001Q@P003RP000<K000^
?`00Q@X0cZd00?/D003g8P00aL<0001j7`008SL0008I000D;P00K3H0T;P00?4k003n1P00fHd001JB
0000@dT000DM00088P00ET/0@Z800>AZ003o0000j5`005RX0000G4L000/U00047000>DD028d00=FH
00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`0a00026P006C8006Hm04nV
003NOP00o@/00?TL003CW`008iL0001HB@003bT0008I000C;@00Gd@0>9h00=V>003k4P00na@00=RA
000dW@0005e5000B;0000QT0010Z001KB00/VP00eYL00?XG003l4000fXX003fP0000Gd@001@]0002
6@003bX005U802VI003EV000nQL00?`@003JR`00>il0001OA0004bd0008I000@:P00FdL0<9`00=NB
00020?/D003o0=NB000`W00005]7000@:P000QT001@]001P@`11X@00g8D00?`=003i7000dZ8001bE
0000E4`000`V00026P006S8006Pk05fZ003RL@00oPD00?DZ003:]`000XX00018C000228000<K000U
>P00Lb/0Q[D00>YF003o0000kd800:^n0000OAX0039100057@001Ql003U40022402n``00lSL00?l2
003VH`00L:l0001]=@007SD000<J000;9@00Dd`06i@00=>P003i6@00o1000=V?000aW00005Y8000?
:@000QT001P`001V?01KZ@00hVl00?h4003d<000a/0000252@00?DH000HO00047@00<T4007hG0;?0
003h7P00iV8006j_0000JcH001`c00026P003BL005M:02ZJ003HTP00na400?TJ003BX`005I80001A
C@002R@000<K000T>@00M2T0T;P00>a=003o0000je4008Rf0000LRd0028g00036P002bD005=<01nF
003EVP00na@00?XG003CW`0069<0001AC@002R@000<K000U>P00MRL0UkX00>i8003o0000jET007Vb
0000KC@001`d00026P003RP005Y803FM003KQ`00o@/00?LT003;]@0008T10010B0001Ql000DM000f
@`00P`h0a/400?D]003n1P00gg`004>R0000GDD0010Z00026@006S8006/f07B`003XFP00o`000>e:
002@^00007</000Q=`000aX000`V001HBP0aW000fhP00?d;003f9P00bKT000261`00>TD000DN0006
7`00@4P008X00<ba003h8000o0l00=NC000SU`0005=<000:90000a/002Tl001j7`2^_`00lST00?l3
003RLP00CZD0001P@`0042X0008I000K<`00KC<0P;<00>]A003o0000jEP007F`0000JSP001Pa0002
6@004bd006@o05fZ003UIP00o`400>i5002D^@0007</000P=P000QX000hX001MAP16X`00h7H00?l4
003b>000[;l0001i8P009SX000<J000<9P00F4T0=ih00=f0003n1P00lc400;W20000O1`002Tl0003
6`002bD005I;036L003LQ000oPL00?@_002m``0007`K000Z?0000a/000/U001FBP0cW@00gH400?h6
003c<P00]/40001j7P009c/000<J000<9P00FDT0?J000=mi003n1000lCT00:Jm0000MRL0028g0002
6P003bT005i40030052V003TJ`00o`400>i6002<]`0006lb000J<P000QT001<]001V?@1][P00jEP0
0?l0003YFP00JJd0001U?P004b`0008I000L=000LBh0U[T00?10003o0P00hGD0046Q0000FDP000/V
00036`00:cd007hG0<K1003f9`00o0d00=JF000FTP0004U<000680001Ah004=900f?003DW@00o100
0?LS0038_@00080C000]?P000a/000/U001IB013XP00hW800?l1003^AP00R;H0001/=@005c00008I
000H<@00KS<0SKL00>m3003o0P00h7H003bP0000EdX000XT00047000G2D0c;400?TJ003j6@00cJl0
00261`00<d8000@L000:9000EdX0?Z000>5d003o0P00kTL008>d0000JSP001D^00026@0073@007</
0:>l003b=P00oPL00=Z9000QUP0004i>000780001Ql004M;01JB003GTP00o@X00?@`002^_`0007DW
000N=@000QT001@^001Z>023]000kTH00?l2003PN@00=9d0001DC000228000@M000nA`0;SP00eIX0
0?`=003e:`00]/40001g9@007cH0008I000D;P00JSP0Q[D00>m3003o0`00gWh002bJ0000DDd000LQ
00057P00Ad/06I@00=V=003n1`00lSP009^j0000Kc4001P`00026@0073<007@Z0:bo003d;`00o@/0
0=FI000:SP0003a600047@002B<005Q:04FS003TJP00o`000>UI001OZP0005m4000<9`000a/00391
0027103@Y`00na400?HV002n``0007PS000O=@000QT001H_001^<P2J^P00lSH00?d8003GT`003i00
000nA`0011d000TS001HB@1;Y000iV@00?l0003VH@00CjH0001JB0002R@000@L000mA`0?T000ei80
2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo01/000<J000L<`00J3X0F:P0
0>1h003m2@00n2000=6U000LU@0005I;000>:0000QT001D_001Q@P11X@00fhP00?`?003j5`00eYL0
02fK0000FdL0014[00026@004R`005e603BM003HT@000P3k4`00FP3HT000=Id0001MAP004R`0008I
000A:`00G4L0<I`00=NB003k5000na<00=RA000cW@0005a6000A:`000QT0018/001NA@0hWP00fH`0
0?/A003j5`00eIP002RI0000FDT000lY00026@005Rl0069104VT003NO`00o@X00?PP003@Y`005I80
001BC@002bD0008J000L=000JcL0IZ`00>A[003o1000m2l00<Rm0000R0<004=900078@0011`002Pk
001f9`2@^000je400?l0003^A`00XK`0001j7`00;Sl000@M00068000?DL008D:0<G2003c<`00o`<0
0>AY001V[@0006Xh000K<`000QX000`W001FB`0RU`00eIX00?XF003k4`00eiD002VI0000F4X000dX
00026@006S8006Ti06B/003TJ@00o`<00?<d0032a000088?000hA08000DN03`003I300214P2m``00
nA`00>EX001U[00006Tj000I<P000QT000hY001JB00bW000fX`00?`>003h7@00cjT000j?0000CTh0
00TR00036`009c/007LU09Vj003^B000o`000>UG001o/`0006la000O=P000aX000`V001FB`0VV000
ei@00?/A003i6P00dJD0016A0000Cdh000TS00036`00:C`007PR0:6l003_@`00o`000>MO001_[`00
06/g000J<P000QT000lY001LAP0mX000gH400?d8003f:000bKX000261`00?4H200057P2O000jA@00
QPP0b;/00?HY003m2000gH8003^O0000FdL000hX00026P0073@006hc07jc003ZE@00o`000>]@0026
]@00070`000N=@000QX000dX001JB00iW`00gH800?d8003e:P00akh000233@00=T<000DM00068000
ADX01h`00<n[003i7000na400=FI000KU000055=00098`000a/002`n001m6P2h`P00lc@00?h5003P
N000AJ<0001MAP003bT0008J000M=@00L300RKH00>e<003o0000j5d006^^0000J3/001H_00026@00
5Bh006Hm06J/003WH000o`000>e:002;]P00070`000M=0000QT0010Z001OA01>Y@00hW000?l2003`
?@00X[`0001f9`008cP000<J000=9`00FdP0?j400=mj003n1000lSH00:no0000NB4002Hj00036P00
32H005Q903VO003NOP00oPD00?<d002c`00007XP000W>P000aX000`V001IB@0kW`00gg/00?h5003b
=`00[;l0001h8`0093T000<J000=9`00G4L0AZ<00>5c003o0P00l3h009bk0000Lb/001lf00026P00
42X0065205VY003UI@00o`000>a<0022]00006`e000H<@000QT001D_001Y>@1f/@00je800?l0003W
H000H:/0001S@0004B/0008I000O=@00M2X0Wk`00?4k003o1000gg/003VO0000EdX000XU00036`00
;Sl0084A0<Rl003g8`00o1000=BL000?T00004A:008000HO03L004Q;01BB003FU`00o0d00?HW0035
`P0007hH000Y?0000aX000`W001LA`1<Y@00hf`00?l1003]B`00O[<0001Z>0005Bl0008I000J<P00
L300U[T00?0n003o1000gW`003BM0000ED/000TS00047000H2<0cj/00?XF003i7000bkD000233@00
<40000<K000;9@00FTP0AZ<00>=^003o0@00k4`007Vb0000J3/001<]00026@007cD007DX0:fo003c
<@00o@T00=R?000JU00004U<008000HO064004a=01fE003IS000oPL00?<e002T_@0007</000L<`00
0QT001H_001/=@2<]`00kd400?l3003NO`00;I/0001AC@001b4000DN0013B@0BT@00ei@00?d:003d
<000[;l0001d:@007C@0008I000F;`00KCD0SkP00?0n003n1@00g8@002BH0000Cdh000HP00067`00
C4d08IH00=^7003n1@00lCd0096h0000KCD001H_00026@007SD007HV0;K1003e:P00o0h00=>O0004
R`0003Q4000470002R@005Y804jU003VI000o`000>MN001FZ00005a6000;9@000a`003E3006:003B
X@00o0h00?DZ002d`@0007DX000L=0000QT001Pa001a;`2T_@00lc800?d;003EV@002Hd0000jA@00
11`000XU001KA`1CY`00iel00?l0003UI`00Aj<0001GBP002B<000@M0012B@0FTP00fH`000[ooooo
0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o00036P007SD006/g066[003RLP00
oPL00?LT003?Z`005I80001CC00032L0008I000G<000I3l0BJ@00=f2003l3@00nA/00=BM000UV000
05Q9000?:@000QT001@]001OA00lX000fX/00?`@003j5P00eYH002fK0000FdP0010Z00026@004b`0
05i503VO003IS000na400?XF003FU`00:iX0001JB00042X0008I000D;@00H4<0@:400=^6003l3P00
nAX00=>O000PUP0005I;000=:0000QT001P`001U?P1BYP00ggT00?d8003g9000cZd000j?0000D4h0
00XT00036P007cD006dd06n_003UI@00o`800?<d0035`P0008D9000nA`001R0000@L000/?@00NB80
V[X00>e;003o0000k4`009Ni0000N2@002Xm000470001b00049900271038_@00m2h00?h4003RK`00
GJX0001W>`006C40008I000>:000F4T0:YX00=ND003k4`00nQH00=BK000QU`0005E;000<9P000QX0
01`d001/=P1^[`00iV<00?l2003a>@00^<8000205000=48000DN00067`00>TD008@<0<G3003i6`00
hfh005bY0000ISd001L`00026@0042X005a603ZO003LQP00o@/00?LQ003=[`0028d00019C0002240
00@L000[?@00NB00Xk`00>m2003o0000j5d007Fa0000KC@001`d00026P003BL005Q902jK003IS@00
o0h00?PN003?Z`002hh0001:C@00224000@L000/?P00Nah0Zkh00?0m003o0@00iFD006J/0000J3X0
01P`00026@004B/005m404JS003ON`00oPH00?D]0036`00008<=000gA0001Ah000HO000oA`00R080
bkD00?LT003m2`00fhP003>M0000FDT000dW00026P007cH0074_08Ne003/C`00o`000>YE001m/`00
06dc000L<`000QT000lY001LAP11X@00gW`00?h6003d;P00aL@000214P00<T4000@M00078@00BT`0
3Hl00=6U003j6000naD00=>O000DTP0004i>00088P0011`00310001o5@32a000m2l00?h6003NOP00
?J00001KB0003BP0008J000P=P00Lb`0TkP00>i6003o0000iV<006:[0000ICh001@]00026@005c00
06Tj072_003XFP00o`000>]@0021]00006dc000K<`000QT0014[003c001R@P1GZ000i6X00?l1003_
@P00V;X0001c:`0083H0008J000>:000GDH0B:<00>5d003o0`00lC/00:Fm0000MbD002<h00036P00
3BL005]704:Q003PM`00o`@00?8i002Y_P0007LT000T>@000aX000dW001KA`14XP00hGD00?l3003a
?000X[`0001e:0008CL0008J000>:@00GTD0CZD00>=]003o0@00kd@009:h0000LBl001`d00026@00
4R`006=006:[003WG`00o`000>]A001i/P0006Xi000F;`000QT001L`001[=P20]000k4d00?l0003U
IP00F:P0001P@`003bT0008J000Q=`00MRH0ZKh00?8f003n1@00gH40036L0000ED/000TS00047000
<T4008@<0<Zf003h7`00na<00=:R0008S@00041800057P001b0004e>01^D003HT@00o@/00?D[002o
``0007/M000V>P000aX000hX001NA@1DY`00iFH00?l0003[D@00MK40001W>`004bd0008I000M=000
Lb`0X;`00?8i003n1@00gH8002bJ0000DTd000PR00047@02Hb<0dJD00?/C003h8000bKX000214P00
;3h000<K000<9P00G4H0CjD00>EX003o0000je80072_0000ICh0014[00026P008CL007PS0;O1003e
;@00o@/00=JE000CT@0004A:00057P001b0004m>02FH003KQP00oPH00?4j002J^P00070`000I<P00
0QT001Pa001_<@2F^@00lC/00?h5003LQ@009IP0001?CP001b0000HO0018B`0IU000fHh00?h8003c
=@00X[`0001b;@006S80008I000H<@00Kc40VKX00?4i003n1P00fXX001fE0000BT`000HO00078000
D4h0:9T00=f1003o1000kd8008Ne0000JSP001@]00026@008CL007TQ0<33003f9P00na400=6U0000
R08003A200036`002bH005a605JX003WGP00o`000>IT001=Y@0005Y8000:900011`003Y500N=003D
V`00o@`00?@_002Z_P00078/000J<P000QT001/c001c:`2^_`00mBd00?`=003CW`000XX0000f@`00
0a/000`V001MA@1LZP00jET00?l0003SK@00?Z00001EB`00228000DN0017B`0MU@00fhH000[ooooo
0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o00036`008CL006dc06Z^003SK000
oPD00?HX003</@003Xl0001AC@002bD0008J000J<P00ISd0DZH00=ml003m2P00n1h00=:S000MU@00
05I;000>:0000QT001H_001R@@14XP00g8D00?`>003i6P00e9`002FH0000F4T000lY00026@005Bh0
0652046Q003KQP00o0h00?TJ003DW@008iL0001GBP003RP0008I000F;`00Hd00BJ@00=f0003m2`00
n1h00=6U000IU00005A<000<9P000QX001Xb001X>`1KZ@00hG<00?h6003f:000bk<000N=0000CDh0
00TS00036`008SL0070`07Ra003WG`00o`400?8i002n``00088?000jA@001Ql000@M000_?`00Nad0
Y;d00>i6003o0000je8008fg0000MBP002Lk00036`00224004M;006:003:]`00mBT00?h6003QM@00
E:L0001U?P005c00008I000?:@00FTP0<Y`00=V>003l4000nAX00=:Q000JU00005=<000;9@000aX0
01lf001^<P1g/@00j5d00?l1003`?P00[[l0001m6P00<40000@M00068000?TL008H70<Nm003j6@00
hG@005>W0000I3l001D^00026@004B/005m404>R003MO`00o@T00?HV003;]0000HX00014BP001b00
00@L000^?`00O1`0[Kl00?0m003o0@00iV8006b^0000JSP001Xb00026@003RT005Y803JN003KQ`00
o@/00?LR003</00018/00015BP001b4000@L000`@000OQT0]L400?8h003o0P00i6/005fZ0000ISd0
01H_00026@004R`0065204jU003QM@00oPD00?<a0032a000084B000c@P0011d000LP0014BP03R`00
cK000?PP003l3@00fHh002^J0000ET/000`V00036P008SL007<[096h003]B@00o`000>QK001c/000
06/g000I<P000QT0010Z001OA019Y000h7H00?h4003c<`00^l80001n6000;Sl000@L00088P00Cdh0
59800=>O003j5@00nQP00=6U000=S`0004U<00078@0011d003A200224036`000mB/00?d8003LQ000
=Id0001HB@0032H000<J000S>000MBP0WK/00>m1003o0@00i6T005VY0000Hd40018/00026@006C40
06/f07Vb003ZE@00o`000>YE001h/@0006/g000H<@000QT001<]002S001T?`1PZ`00iV@00?l0003^
B000S[L0001a;`007C@0008I000@:P00Gd@0D:H00>=^003o0P00l40009^j0000M2X0020f00026P00
3RT005e504ZT003RL@00o`800?0n002O^`0007DY000Q=`000QX000hY001NA@1<Y@00hVl00?l2003_
@@00V;X0001c;0007SD0008I000@:P00HD80EjP00>EW003o0000kDT008Rf0000KS<001Xb00026@00
4bd006Hm06^^003YFP00o`000>UG001_[`0006Ll000D;P000QT001Xb001^<`2:]P00kTL00?l1003T
K000CjH0001NA@003RP000<J000T>@00NB40/l000?<a003n1`00fhL002VI0000DTd000PR00047000
=T<008L60<f`003i6`00nQH00=2X0001RP0003]600057@001b40051>02:G003JR`00o@P00?@`002d
`@0007PR000S>0000QX000lY001Q@P1MZP00if000?l0003ZEP00K:h0001U?P004R/0008I000O=P00
MBL0Z[h00?<d003n1`00fhP002BH0000D4h000LQ00057P05Ib@0dil00?`@003g9000a/00001n6000
:C`000<J000=:000Gd@0EjP00>IR003o0000jEP006N]0000Hd00010Z00026P0093T007/N0<74003f
:000o0h00=BK000<SP00041800057@002240059=02bJ003MP000oP@00?0o002@^00006dc000G<000
0QT001Xb001a;P2P_000lSH00?h7003JR`007ID0001;C@0200067`1>001=CP0QUP00fhP00?h6003a
>P00V;X0001_<@006340008I000J<P00LRd0Xkd00?<d003m2000f90001JB0000ADX000DN00078@00
DTd0<9`00=mk003o0P00kTL007jc0000Ic/0018/00026P0093T007`L0<K1003g8P00na@00<n[0000
QPP0031000036`003BL005m405nZ003YF000o`000>AZ0014XP0005M:00098`0011d003i700j?003F
U@00o@T00?<d002P_000070`000H<0000QT001dd001f9P2h`@00mRP00?`@003AY@0008P3000b@@00
0a/000dW001P@`1U[000jU<00?l1003QL`00=Yh0001BC@001b4000HO001<C@0UV000gH002_ooool1
o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo04`000<K000T>@00L300M;000>EV003o
0`00mBd00<Zg0007S00004m>000:90000aX001`c001Y>P1KZ@00h7H00?h8003g8P00cjT001JB0000
E4`000`W00026@00634006@o04fU003NOP00o@/00?PN003BXP007ID0001FB`003BP0008I000G<000
Hd00BZ@00=f0003m2`00n1h00=:S000LU@0005E;000=9`000QT001Pa001U?P1AYP00ggX00?d9003g
8P00cj/001:A0000DDd000/U00026P0073@006Xh06B/003SK@00oP@00?D/0039^@000HX00017B`00
228000<K000U>@00LR`0P[@00>UI003o0000l3h00;?00000P1D003I30P001Ah0o`00<d4007hH0:jo
003`@000o`000>UH0023]000078/000T>@000a/000TS001<C@08S@00c;400?LU003m2000gg/004bU
0000HT4001D^00026@004B/005e603ZO003KR000o0d00?PM003@Y`004i40001@C@002R@000<J000R
=`00LBh0PK@00>UH003o0000kd@00:Bm0000NQl002dn000470001b0004=90029003:]`00nQP00=mj
001:Y0000652000C;@000QT001<]001Q@P1;Y000ggT00?h7003e:P00bKX000271000?dP000HP0004
7@00<T4007lF0;O1003b>000o`800>AX001SZ`0006Pk000H<0000QT0010Z001MAP0nX000gH400?d9
003f9P00b[H000290@00@DP000HP00047@00<d80080C0;o3003c<`00o`@00>9a001DY`0006=0000D
;@000QT001@^001T?`1GZ000hfl00?l3003b=P00^<80001n6000<40000@L00078@00BD`02Xh00<nZ
003i7000o1000=ND000SU`0005A<000:9@000a/002Di001f9`2K^P00kd@00?l0003WH@00JZd0001X
>P005c00008I000B;000HD80DZL00>9`003o0`00lSP00;700000Nad002/m00036`002B<0055=01bD
003EV@00na800?TL003?Z`001X`00014BP001R0000DM000hA000Q@X0bKX00?HV003m2`00fXX002fK
0000ET/000/U00036`009SX007PS0:Nm003a?000o`800>9_001@YP000613000@:P000QT001/c001^
<`23]000k4l00?l0003XF`00KZl0001X>P005Rl0008I000E;P00Ic`0JJd00>MN003o0000k4d008Be
0000KS<001/c00026@004B/0069105VY003UI`00o`400>i6002A^000074^000N=@000QT0010Z001P
@`1CY`00i6/00?l1003_@`00UKT0001b;@007SD0008I000@:P00H4<0EJL00>AY003o0@00kTH008jg
0000L30001`c00026@004R`006=0062[003VH@00o`000>a>001n/`0006/f000H<0000QT001D_001Y
>P1e/000jU@00?l0003XG@00IZ`0001T?`004R`0008I000L=000LBl0TkT00>m2003o0P00hW8004JS
0000FdL000`W00036P009c/007`L0;k3003e;@00o@X00=V=000QU`00051>00088@00X00011d003Y5
0029003?ZP00nQL00?TJ003=[P0008L4000g@`0011`000PR001BC@0ZVP00g8D00?h6003c=@00Z[h0
001f9`0083H0008J000A:`00Hd00IZ`00>UJ003o0000j5`006:[0000HT40010Z00026P008SP007PS
0;G1003d;`00o@T00=V?000LU@0004e>000680001Ah026XU0=FI003l3@00mRP00<;40000Nad002Dj
00036P003bT00652062[003XG000o`000>QN001NZP000613000>:@000aX002Lk001m6@36`@00mb@0
0?/A003BX@001H`0000kAP0011d000PR001DC00dW@00ggT00?l2003_A000QkD0001[=`005Bh0008I
000M=000M2T0Z[h00?<b003m2@00f94001JB0000AT/000DN00078000D4h0:9T00=f2003n1000l3l0
08jg0000K3D001H_00026@007C@007@Y0:fo003d;`00o@/00=JF000?T000041800057@00228005A<
03RN003QM000o`400>a=001d/00006Dn000@:P000QX002Lk001n5`38^`00n1h00?XG003</@0008<>
000/?P000aX000hX001Q@P1Y[@00je<00?l0003RL000?:00001EB`00228000DM0013B@0ETP00f8l0
0?h7003b>@00U[T0001]=0005Rl0008I000P=P00NB80`/@00?LT003k4`00cZ/000252@00;Sl000<J
000>:000HT40Kjl00>a=003o0@00ggT002jK0000D4h200068003001@CP0/VP00ggX000[ooooo0Ol0
0001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o000470009c/007<[07fc003WH000o`80
0?<b0038_00008X0001:C0002B<000<J000O=@00JcH0I:`00>9`003n1P00mRL00<f_000?T000055=
000;9@000QX001Xb001W?01FZ000h7P00?d9003g8P00d:P001JB0000Dd`000`V00026P006C4006Hm
05>W003ONP00o@T00?LR003?Z@005I80001CC@002bH0008J000J<P00J3/0FZT00>5d003n1`00mRH0
0<ba000;SP0004m>000:90000aX001lf001]=01][P00iFL00?l3003c<@00akl000271@00@TT000LQ
00047000:3/007DX08bg003ZD`00o`000>m3002Y_P0007dJ000b@@001Ad000DN000gA000PA<0^<80
0?4k003o0@00j5h007Zb0000L300024g00036P002R@0051>00n@003?Z`00n2400?d;003MP@00@j80
001P@`004b`0008I000B;000Gd@0@Z800=f2003m2P00mb800<j]000<SP0004i>00098`000a/002Di
001d:P2:]P00je800?l0003]B@00V[X0001h9000:C`000<L00088@00B4`01H`00<bb003j5`00gH00
04:Q0000Gd@0014[00026@005Bh006@o05BW003QL`00oPD00?@_0036`00008D:000kA@001Ql000DN
000f@`00PQ40`/@00?<c003o0`00hfh005VY0000ICh001H_00026@004R/0061304NS003ON`00oPL0
0?D[0038_00008H8000lAP001Ql000DN000hA000P`h0a/400?@_003n1@00h7L004^T0000H4<0018/
00026@005Rl006Hm062[003TJ000o`800?4k002^_`0007/M000/?@0011`000PR001>CP0AT000dJ@0
0?XI003k4`00eIX001bE0000DDd000TS00036`00:3/007TR0:Fm003`?`00o`400>EW001PZ`0006Hm
000E;P000QT001@]001T?`1KZ@00i6X00?l2003`?@00Ykd0001i8P009c/000<K000:9000Dd`08iL0
0=NB003l3`00n2000<ba0000RP0003m800067`001Ah003a60028103;]000mb800?`=003HT0009IP0
001CC0002R@000<K000Y?000Nah0/L000?8g003o1000hGD004RS0000GTD000lY00026P007SD0074_
08bg003]B@00o`000>MQ001U[00006Hm000D;P000QT001L`001d001Y>@1b/000jEP00?l0003[D`00
N[80001[=P006340008I000C;@00ICh0HZ/00>IQ003o0000kD/008Ne0000Kc8001/c00026@004B/0
069105bY003UI@00o`000>e9002;]P0006la000K<`000QT0018[001S@01NZP00iV<00?l0003]C000
Q;D0001]=0006C80008I000C;@00ISd0JJd00>QK003o0000jU@007F`0000JCX001H_00026@005c00
06/f07jc003/CP00o`000>IS001MZP000691000@:`000QT001le001c:`2N^`00lCd00?l3003PN000
?Z00001IB@002bD000<K000[?@00OQL0aL800?HX003m3000ei<001ZD0000CDh000LP00057P00?dL0
1X`00=6T003k5000n1d00<^d0000Q@X003=1000470002B<005E;03:L003NO`00oPD00?4j002P_000
07<[000M=@000QT001</001V?@1`[`00jU@00?l0003VHP00FJT0001P@`003RT000<J000U>P00Nah0
_l<00?DZ003m3000eYD001FB0000Ad/200067`1m00a^9P3GTP00o@X00?D]002h`@0007TR000R>000
0QX0010[001T?`1Z[@00jUH00?l0003VI000EJL0001NA@003BL000<J000[?@00P1@0b;/00?PP003k
5000d:P000290000=d<000@L00098`00ETX0?J000>5c003o0@00kDX007fc0000J3X001<]00026@00
83H007LU0;C1003e;@00o@/00=JG000?T000045800057P002240059=032L003OO000o`<00>m40025
]@0006Xh000D;@000QT001lf001g902h`@00mB/00?`=003DW@0028d0000kAP0011d000TS001GBP10
X@00hfh00?l0003[DP00Jjh0001R@@003bT000<J000Z?000PA80bkH00?TJ003i6`00b[L000204`00
:C`000<J000@:P00I3l0L[000>a=003o0@00h7H003BM0000DTd000LQ00057P00B4/079D00=Z9003n
1@00l3h008bg0000JcL001@]00026@008cP007/M0<K0003h8000nQH00<ba0000PPl002Xm00036P00
42X006Dn07Ra003^B000o`<00=eo000VV00004e>00067`001b00059=03BM003QM0002_ooool1o`00
007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l000@M000[?@00MRL0QkD00>UJ003o0@00
lSL00<G20000Q`D004E:00088P000a/0024g001^<`1][P00i6T00?h4003e:`00bkD000R=0000Cdh0
00XT00036P007C@006Xh05nZ003RLP00oPH00?HV003=[`003i00001AC@002bD0008J000K<`00JCX0
G:T00>5c003n1`00mRH00<f_000=S`00051>000:90000aX001dd001Z=`1T[000hfh00?h5003e:`00
b[L000B;0000Bdd000TS00036`008SL0070`07Na003WH@00o`800?8f0034a00008@;000nA`001R00
00@L000[?@00N2<0U[T00>a>003o0000kDT009nk0000NQl002ho00047@001Ql003a600233@33a000
lSH00?l2003VI000L:l0001]=0007SD000<J000;9@00DTd05Y800=6U003i7@00o0d00=^8000kW`00
05e5000A:`000QT001@^001R@@1;Y000gg/00?h8003f9P00c;<000F<0000BD`000PR00036`00:3/0
07HV09Bi003/C000o`000>a?002@^00007DX000V>P000a/000TS001=CP0<S`00cZ/00?/F003KQ`00
>Il0001LAP0042X0008I000G<000IS`0GJX00>=]003o0`00lc<00<;40000PQ0003M300057P001Al0
03Y500242`36`000m2h00?h5003QM@00D:H0001R@@0052d0008I000C;@00HT40D:H00>5e003n1@00
m2l00<G20000P`h003Q400057P001Ql003a600262038_000mBX00?h7003NO@00@j80001NA@0042X0
008I000H<@00JCT0JJd00>IR003o0@00l4000:Bm0000NB8002Pk00036`002B<0051=01RC003CW@00
nQD00?XG003BX0005980001?CP00228000<L000[?@00Nad0/<000?4i003o0P00hfd005NX0000Hd00
01<]00026@005Rl006Ll06B/003VI000o`400>m2002M^`0007HV000T>@000aX000/U001FB`0[VP00
fH`00?d<003g9000b[L000271@00>dD000DN00067`00@DP00XX00<f^003h7P00o1000=JF000MU@00
055=00098`000a`002dn001m6@2l`P00lc800?h5003OO000?j40001KA`003BP0008J000P=`00Lb/0
U[T00>m4003o0@00iFL005bY0000Hd00018/00026@006C4004d006`f07bb003[DP00o`000>UI001a
[`0006Tj000F;`000QT001D^001W>`1/[P00j5/00?l0003[D@00OK<0001/=P006C40008I000C;@00
ICh0IJ`00>MO003o0000k4h0086d0000K3D001Ta00026@004bd006Dm06N]003XG@00o`000>]A001k
/P0006/g000G<0000QT001D_001X>P1c/000jUH00?l0003YFP00Jjh0001V?@0052d0008I000J<P00
KS<0R;H00>e9003o0@00i6T005BW0000Gd@000lY00026P008CL007HV0:Rn003b=`00oPD00=in000e
W@0005I;000:90000a/002ho00214P38_@00mb@00?`?003EVP004Y400018B`0200067`2T0013B@0=
S`00dih00?/A003g8@00bKX000224000;cl000<K000:9000EdX0>il00>1h003o0`00l3l009Ji0000
L2l001/c00026@0052h006Tj07Vb003/CP00o`000>AX001@YP0005e6000=9`000aX002Tl001n6@36
`P00mRH00?`>003DV`003Xl00012B@001Ah000LP011b9`3IS000o@P00?<b002]_`0007HW000O=P00
0QT0018/001V?@1c/000je000?l0003TJP00C:D0001KA`0032H000<K000^?`00P`h0bkD00?TL003j
5`00cZh000261`00<d4000<L000:9@00FDT0AJ<00>=]003o0000k4l007>`0000ISd0014[00026P00
8SP007XP0;o3003f:000o0h00=>N0008S@0003a600047@002B8005E;03RN003QM@00o`400>e:001k
/P0006Lk000B;0000QX0028h001j7`32a000mRH00?`@003BX`000HX0000g@`0011`000XT001IB@19
Y000i6P00?l0003YF000HJ/0001P@`003BP000<K000^?P00Q0`0cK000?XF003h7`00b;d0001n6@00
9SX0008J000A:`00Ic`0O;800>i7003o0P00gWd002bJ0000D4h000LP00067`00CDh099L00=f2003o
1000kd<008:d0000J3/0018/00026P009SX007hH0<Vj003i7000nAX00<Zg0000OaD002Lk00026P00
4B/006Pk08:d003_@P00oP@00=^6000NU@0004Q;00057P00228005A<03fP003SKP0:ooooo`7o0000
0Oooool001kooooo00?o0000ooooooooool01oooool0o`001Ad002ho001h8P2A^000jU@00?l0003a
?000_/<000242`00@4P000LQ00036`0093T0074_07Na003VH`00o`<00?@`0038^`000HX0001:C000
2B<000<J000O=P00K3D0J:d00>=/003n1@00mBX00<^e0008S@0004m>000:90000aX001he001[=P1U
[000hfd00?h5003e:P00bkD000J<0000CDh000TS00036P007cH006dd06f^003UI`00o`<00?@`0038
_00008P10016BP00228000<K000U>@00LR`0P;@00>QK003o0@00lC/00;[20000PQ4003U500067`00
11d002lo001k7P2P_000kDP00?l0003/CP00UKT0001g9000:Sd000@L00078000@4P008H70<K0003d
<@00o`<00>AZ001V[00006Xh000L<`000QX000`V001DC00MU@00dil00?TI003l4000fHh003:L0000
FdP000lY00026@005Rl006Dn05BW003QM@00oPH00?DZ0039^@0008T10014BP001b4000@L000[?@00
NB40Wk/00>i7003o0000jUD008Je0000LRd002<h00036`002R@0051>01>A003AY@00naH00=V=000a
W00005Y8000>:0000QT001Tb001Y>@1V[000iFL00?l2003b>000^<40001o5P00<T4000@M00067`00
?dL008L50<Vj003e:P00oPL00=mk0018X`000613000B;0000QT001D_001U?P1IZ@00hfh00?l3003c
=000_/<000204`00<d8000@M00068000@DP008T10<Zf003f9@00o@X00=b4000jW`0005]7000?:@00
0QT001/c001[=P1c/000j5`00?l0003^AP00VKX0001f9`009CX000<K000:9000Dd`089H00=JG003k
4P00nAX00=2W000=S`0004]=00088@0011`002lo001n602j`P00lc@00?h4003QL`00CZD0001P@`00
4B/0008I000H<@00JCT0KZl00>QN003o0000kTP009>h0000Lb/0024g00036P0032L005Q903>M003K
QP00o@T00?HX0038_00008@<000g@`001Ad000LP0016BP09S@00d:P00?TJ003k4`00e9d001JB0000
Cdh000PR00047000<D00080C0<G3003e;@00oPL00=f2000fWP0005Q9000<9P000aX002<h001f9P2Q
_000l3h00?l2003SK@00DZL0001P@`004B/0008I000L<`00l`00Kc80Q[D00>a<003o0000iel006N]
0000ISd001@^00026@005c0006Xh07Ja003ZEP00o`000>YG001d/00006Ti000G<0000QT001D_001X
>`1_[`00jET00?l0003ZE000Mk40001Z>0005c00008I000E;`00J3X0LJl00>UG003o0000jEL0076_
0000J3/001D^00026@00630006/g07fc003[D000o`000>MP001RZ`0006=0000B;0000QT001`d001a
;`2B^000kd<00?l2003RK`00Bj@0001MAP003BP000<J000T>@00NB40//000?<b003n1`00g8@002fK
0000E4`000TS00047000<T4008@<0<Zg003h8000na800=>P000;SP00049900057P001Ql004Q<01BB
003EV000o0h00?HV0036`00007lF000[?@000a/000/V001JB013XP00hW800?l2003^A000S;L0001^
<`006C40008I000F;`00JcH0Pk@00>e9003o0@00hfh004NS0000FdP000`V00036`00;3h0080C0<Rl
003g8P00na400=:Q0007S00003i700057@001b4057DW0=^6003n1P00lSL00:>l0000Lb/001dd0002
6@0052h006Ti07fc003]B`00o`400>9`0013XP0005U9000:9@000a/003910026203=[`00nQP00?TK
003;]00008<=000_?`000a/000`V001KA`1>Y@00iFL00?l0003ZE@00JZd0001S@00042X0008J000V
>P00O1/0a/800?LT003k4@00dJ@0006:0000>4@000@L000:9000EdX0@J400>9_003o0@00k4l0076_
0000ICh0010Z00026P009CX007dJ0<K0003g8P00na<00<nY0000Q`@003=100036`002bH005a705:W
003VHP00o`000>MN001HZ00005e6000<9P000a/0039100271P3?Z@00na<00?LS0035``0007/N000S
>0000QT001<]001Y>@26]@00kd800?l4003LP`0099L0001=CP001Ql000LP001@CP0/VP00gW`00?l2
003]B@00N;40001U?P0042X000<J000Y?000PA80bk@00?XH003h7P00b;d0001m6P0093T0008I000C
;@00JSP0S;L00?0m003n1P00fH`001NC0000@dT000DM00098`00EdX0AJ<00>EW000:ooooo`7o0000
0Oooool001kooooo00?o0000ooooooooool01oooool0@@001Ah00391001k7@2K^`00k4h00?l0003_
@@00]<0000214@00>dH000HP00047000:3/007<Z086d003XG@00o`400?<e0036`@0008L40015BP00
228000<K000R>000Kc40L[000>EV003o0`00m2l00<Vk0001RP0004U<00098`000a/0024g001^<`1_
[`00iFL00?l3003d;`00b;/000290000B4/000PR00036`008SP0070`07Na003VH@00o`800?<e0035
`P0008H80011B0001b4000@L000X>`00MBP0R[H00>YE003o0000kd400:no0000OaH003E2008000DN
0?l003=1001m6@2[_P00kd<00?l0003ZE000RkH0001e:@009c/000<K00088@00ADX008T00<Vj003e
;000oPD00>9`001MZP0006Pk000I<P000QT000dW001GBP0UV000eIP00?XE003k4`00ei@002ZJ0000
F4T000hX00026@006C4006Lk05fZ003SK`00oP@00?@_0037_`0008H7000oA`001R0000@M000_?`00
O1`0ZKh00>m1003o0000j5X007bb0000Kc40020f00036P002bD005=<01^D003CW`00naD00=NC000Y
V@0005M:000=9`000QX001`c001/=P1`[`00if400?l1003`?P00[Kl0001l6`00;cl000@L00078000
A4X00HX00<^d003f9@00o@T00=f1000oX@0005e6000@:P000QT001L`001W>`1RZ`00i6P00?l2003a
>@00]<40001m6@00;cl000@L00078@00ATX018/00<f`003g8@00o@`00=Z:000bW00005U9000=9`00
0QX001dd001^<P1m/`00jUH00?l0003]C000SkL0001c:`008SP000<J000;9@00ED/09iT00=RA003l
3`00n1h00<j]0006S00004E:0007800011d003=100214P34a000m2l00?h6003ON@00AJ<0001NA@00
42X0008I000J<P00K3D0N;400>UH003o0000k4h008Rf0000L2l001he00026P003RP005]803bP003M
O`00oPL00?D]0035`P00084A000b@@0011d000LQ001;C@0@T000dZ800?XF003j5`00dZ<000j?0000
BT`000LQ00047@00=D8008<>0<Nn003f:000o@X00=^8000^V`0005I;000;9@000a/002Lj001i8P2[
_P00lCT00?l3003QL`00BJ@0001NA@003bT0008J000N=@00LBh0T;P00>i7003o0000iFD005jZ0000
Hd00018/00026@006C8006de07nc003[D000o`000>QM001Z[@0006Ll000D;P000QT001L`001Z>01h
/@00jU<00?l0003YFP00KJh0001W?0005Bh0008I000H<000JcL0Nk800>]A003o0000j5d006N]0000
ICh001<]00026@006S8006hc08Ne003]BP00o`000>EV001HZ0000652000@:P000QT001lf001c:`2L
^`00l3h00?l3003QM@00@Z80001JB00032H000<J000X>`00O1`0_L<00?@]003m2@00fX/002FH0000
DDd00;0000PR00047@00=T<008L60<ba003i7000nQD00=2V0004R`0003i700057P001b0004i>01^D
003HTP00o@/00?DZ0032a00007`K000X>`000aX000dW001LAP1<Y@00hf`00?l1003]BP00P[@0001[
=`005Rl0008I000I<@00KS<0SKL00>m3003o0P00hGD003jP0000F4T000/U00036`00<40008<=0<Zf
003h7@00naD00=2X0000RP0003U500047@00228067LV0=eo003n1000lC`009Vj0000L2l001Xb0002
6@005Rl006`f08Ne003^A@00o`800>1f000jW`0005I;00098`0011`003I300280P3?Z@00naD00?PO
0039^P00084C000[?@000aX000dW001NA@1GZ000if400?l0003XF`00H:/0001P@`003RP000<J000Y
?000OaH0b;`00?PP003k5000cjX000271000=48000<L000;9@00FTP0BZ@00>AY003o0000jUD006N]
0000HT4000lY00036P00:C`007lE0<Vj003h7P00nQL00<f_0000Q0/002lo00036`003BL005i505^Y
003XG000o`000>IT001?YP0005]8000;9@0011`003I30029003AX`00o1000?HW002m``0007PS000P
=P000QT001D^001/=P2@^000lC`00?h6003JR@0079D00018B`001Ah000LQ001BC@0dW@00h7H00?l1
003/CP00KZl0001S@0003bT000<J000]?P00Q0`0cJh00?/E003g8P00aL<0001j7`008CL0008I000E
;P00KC@0U[T00?8h003n2000ei8000n@0000?TL000@M000:9000FDT0CZD00>IQ00[ooooo0Ol00001
ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o00067`00=T<007hH0:Jm003]B000o`000>i7
002Y_P0007lG000g@`001Ql000@M000[?@00MRH0RkH00>UG003o0@00lCX00<330000Q0/004180007
8@000a/002Dj001b;@1l/P00iel00?l2003c=000a/0000271@00A4X000PR00036`0093T0074_07Vb
003WH@00o`800?<d0036`@0008L60013B@001b4000<K000V>P00Lb`0PK@00>QK003o0@00lCX00;k3
0000P`h003a60006800011`002`m001h8`2E^@00k4l00?l0003^AP00YKd0001l7000<D0000DM0005
7P00=d<0080D0;G1003`?@00o`000>UJ0020]000078]000T>@000a/000PR001:C@05S000bk@00?HW
003n1`00h7H005BW0000ICh001L`00026@003bT005U902fK003GTP00na800?XG003DV`008YL0001F
B`0032L0008J000K<`00JSP0Ijd00>AX003o0`00lc@00<C40000P`d003Y500067`001Ad003=1001o
5`2d`000lC`00?l1003WH@00L[00001]=@007C@0008J000<9P00ED/08YL00=FI003k5@00eIX0026F
0000ED`000/V00036P007cD006hb07Zb003XF`00o`000>m3002S_00007TP000[?@0011`000PQ0019
C008S@00cJh00?PQ003m3000fhP003JN0000FdP000lY00026@006S8006Xh06b^003VHP00o`400?0o
002Y_P0007/N000/?@0011`000PR001;C@0;SP00cjX00?TM003l3`00f90002VI0000ET/000`V0003
6P0083H0074^08Ne003[D000o`000>]A0025]@00070_000O=P000QX000`W001HBP0`W000fXX00?d<
003g8P00c;<000290000@4P000HO00057P00=d@008@<0<Nn003e:`00oPP00=f0000lX00005]7000>
:0000QX001dd001_<P22]000je800?l0003ZE000O[<0001^<`0073<0008I000?:@00GDH0A:800=mi
003n1@00lc800;k30000OQL002ho00047000228004m>01NC003DW000na<00?TJ003?Z@001hd00014
BP001R0000DN000iA000QPP0b[P00?LT003m3000fHl002JH0000E4`000XT00036`00:S`007`L0;K1
003c=000oPD00=mj0011X@0005]7000=:0000QX0024g002a001d:@2J^P00kd400?l1003TJ`00E:L0
001Q@P004B/0008I000L=000Kc40RKH00>e:003o0000iV<0062[0000I3l001</00026@006S8006dd
08:d003/C@00o`000>MP001T[00006@o000C;0000QT001Xb001]<`25]@00kD`00?l0003VH`00GZX0
001S@@004B/0008I000L=000L2l0TKP00>i4003o0@00hf`004nV0000GTD000hY00026P008SL007HV
0:Nm003b>000oP@00=ml000iW`0005Q:000;9@000a/002/m001n5`35``00mRT00?d;003HT@007ID0
001?CP001b4000DM000kA@00R@00cj/00?XH003j6@00cZ`000290@00>DD000@M00088@00D4d08iL0
0=Z;003m2@00m2l00;O10000NR0002Di00036P003RP005m405FW003UIP00o`000>]@001h/@0006Pj
000D;P000QT001/c001a;`2G^P00l3h00?l3003ON`00=Yh0001EB`002B<000@L000d@P00QPL0cK00
0?TJ003j6000cZh000271@00=D8000@L00098`0LNRH0ggT00?l3003_@@00S[L0001^<`006340008I
000H<@00KS80TKP00?0o003o0`00gW`003:L0000E4`000PR00047@00>dD018/00=:S003k4@00mb<0
0<K00000OQP002Pk00036P003RT00652066[003XF`00o`000>MQ001GZ00005i5000=9`000a/002`n
0022403:]P00nA`00?XH003=/00008@:000`@0000a/000`V001LAP1CY`00iV<00?l0003XF`00GZX0
001OA0003BP000<K000/?P00PPl0bk@00080nAX00400bkD000224@00:cd000<J000>:000HD80IJ`0
0>YF003o0000i6X004JS0000F4T000XT00047000>TD01X`00=BM003l3@00mB`00;;00000MBP001dd
00026@005c0006lb09Zj003b=`00oPP00=R@000DTP00049900057@00228005E;03fP003RK`00o`00
0>YD001U[0000613000=9`000a/0031000271P3@Z000na400?HV002m``0007LT000N=@000QT001L`
001`<02P_000lc<00?d:003EV@0028d0000iA@0011`000/U001LA`1HZ000j5/02_ooool1o`00007o
oooo000Nooooo`03o`000?oooooooooo00Oooooo06`000HP000kA@00PA80/<000>m3003o0000k4`0
09jk0000O1`003=100057P001Ad002lo001i8@2E^@00je400?l0003`?`00]/4000224@00>dH000HP
00047000:C`007DY08Je003YF@00o`400?4i0031a00008@;000oB0001b0000@L000W>`00Lb/0Pk@0
0>QK003o0@00lCT00<330000Q0`003i70007800011`002Tl001e9`2;]P00jUD00?l0003`?`00/l00
00205000=d@000HO00047@00;cl007/N09nk003]B@00o`000>a<002J^P0007TQ000]?P0011d000HO
000kAP00P`h0`<<00?8h003o0@00if0007Ja0000Kc40024g00036P002B@004m>00b?003>[P00mb<0
0?d9003NO@00BZ@0001R@@005Bh0008I000@:P00G4L0=Yh00=Z<003l3`00nAX00=:Q000JU00005=<
000;9@000aX001he001]=01`[`00iV800?l1003a>@00^L8000204`00=T<200057P1A000gA000PA40
_/<00?8f003o0P00iFL006R]0000JSP001/c00026P003BL005Q:02ZJ003GTP00naD00=>P000IU000
059=000:90000aX0024g001a;P24]@00jU@00?l0003]B@00V;X0001g9@009c/000<K00098P00CTh0
3i000=2X003i7@00o0l00=V>000^V`0005Q9000=9`000QX001`d001]=01f/@00j5`00?l0003_A000
Wk/0001h8`00:3/000<K00098`00Cdh04i400=6S003i6@00na800=JG000QU`0005A<000;9@000aX0
02<h001d:P2A^000kD/00?l0003YE`00Nk80001^<`0073@0008J000>:000FTP0>9h00=b4003m2@00
mRL00<Vi0000QPH003a6008000DN0?l003a600271P39^@00mRH00?d:003KQP00=9d0001IB@003BL0
008J000P=P00LBh0S;L00>a<003o0000jEX007B`0000JcL001Tb00026@004B/0061304fU003QL`00
o`<00?8g002c`00007`M000[?@000a/000TS001BC@0OUP00eYD00?`@003h7P00cJl0006:0000?dP0
00HO00057P00?DL008T10<bb003h7`00o0l00=JE000NU@00055=00098`0011`002ho001n5`30``00
m2l00?h7003MP000>9h0001IB@0032H000<J000T>@00MbD0YKd00?4l003o0`00hW4004^T0000GTD0
00lY00026P007cD0078]09Bi003_A000o`400>AY001GZ0000652000A:`000QT001`d001`<02<]`00
kTP00?l0003UIP00FZT0001R@@004B/0008I000L=000L2l0SkL00>i6003o0@00i6T005BW0000H4<0
010Z00026P007cH007<[09^k003`?`00o`800>5c0016X`0005a7000=9`000aX002Di001i8@2a`000
lc<00?h6003MPP00<I`0001EB`002R@000<K000_?`00PA40b;d00?LT003l3P00eYP001FB0000BT`0
00HP00057P00?dP01h`00=6T003k5000nAd00<bb0000QPP003E2000470002B<005=<02^J003LQ@00
oPH00?<d002]_`0007LU000Q=`000QX0010Z001Q@P1NZP00iel00?l0003ZEP00KZl0001V?@004R`0
008I000N=@00LbX0X[`00?8h003n1@00gH8002fK0000Dd`000PR00047@00>4@008T10<nZ003j5P00
nA`00<^d0000Q0`0035000036`002RD087dU0>5c003o0@00kTL008Be0000JcL001H_00026@006c<0
074^09bk003a>P00oPD00=b3000ZV@00055=00078@001Ad003m800^>003DW000o0h00?HW0033a000
07/N000T>@000QX0010Z001S@01Z[P00jUD00?l0003UI`00CJD0001KA`002bH000<K000`@000Q@X0
cK000?XH003i7000b[H000224000;3d000<K000=9`00Gd@0G:X00>QM003o0000iV4005FW0000GDH0
00`V00036`00<40008D90<f^003j5P00n1h00<Rk0000OaH002Pk00036P0042X006=006j_003[D000
o`400>9a000mX00005I;00098`0011d0038003m700j?003FU`00o@X00?@a002X_P00078/000J<P00
0QT001Tb001a;P2T_@00lc800?d:003FUP003Hl0000nA`0011d000TS001GBP15X`00i6T00?l0003X
FP00FjT0001MA@0032H000<K000d@P00R@00dZ800?`>003e:`00//00001d:@006c<0008I000J<P00
LR`0Zkh00?@^003l3@00dil0006:0000=D8000<K000<9P00GT@0HJ/00>YE00[ooooo0Ol00001oooo
o`007_ooool00ol0003oooooooooo`07ooooo`0f00078@00?dP008@<0;_2003`?@00o`000>]B002D
^@0007TQ000_?`001Ad000DN000c@@00O1`0X;`00>e;003o0000kTD00:^n0000OaH003M300067`00
11d002`n001g902@^000jU<00?l0003`?`00]/4000214@00>dD000HP00047000:Sd007HV08fg003Z
E@00o`000?0o002e`@00084B000iA@001Ql000@M000]?P00N2<0UKT00>a?003o0000kTD00:Rn0000
OAT003=10P001Ah0o`00<d8007dI0:Zn003_A000o`000>]B002@^00007HV000Y?00011`000LP0010
B000QPL0a/400?<c003o0`00iFH006f^0000K3D001he00036P002bD0055=01BB003@Y`00n1l00?d<
003LP`00@J40001P@`004bd0008I000B;000Gd@0?Z000=b5003m3000n1h00=2W000CT@00055=000:
90000aX0020g001_<@1j/P00j5`00?l0003`?`00[kl0001m6@00<D4000@M00067`00?4H008@;0<K2
003c<@00o`@00>=]001NZP0006Lk000H<@000QT000lY001JB00cW@00fH`00?/F003@Y`004I40001@
CP002B<000<K000U>@00M2X0S[L00>a?003o0000k4l008jg0000M2X002@i00036`002R@0055=01JB
003BXP00nQT00?/B003GU@009YP0001FB`0032H000<J000O=P00L300P;<00>YF003o0000kDX009Bi
0000MBP002Di00036`002R@0059=01ZD003DW@00nQD00?XF003DW@006Y@0001AC@002B@000<K000V
>P00MbD0W;/00>i5003o0000j5d0076_0000JcL001Xb00026@003bX005e6046Q003NO@00oPL00?D[
0037_`0008@<000gA0001Ah000HO0010B000R@00c;800?LR003l3@00fHd002^J0000ET/000/V0003
6P008cP007@Y09Ji003^AP00o`000>MP001Z[P0006Pj000G<0000QT001</001R@@1GZ000hf`00?l2
003a?000Z;h0001i8P009c/000<K000:9000E4`09iP00=R?003l3@00mb<00<Zf0000Q`D003]50005
7P001Ql0049900F<003>Z`00nA/00?/B003DW0005Y<0001?CP00228000@L000b@@00PA40a/400?DZ
003m2@00fhL002nK0000ET/000/U00036`009c/007XP0;30003b=P00oP@00>1h0012XP0005]7000=
:0000QX0028g001e:02N^`00l3l00?l2003RK`00CZD0001OA0003bT0008J000O=P00Lb`0UkT00>m2
003o0@00hfd0056V0000Gd@000lY00026P007cH007<[09Vj003`@000o`800>9`001;Y00005e5000>
:0000QX0028h001f9P2V_@00lCT00?h4003ON@00?J00001IB@0032H000<K000X>`00O1`0_<<00?@^
003m2000fhT002RI00002`00Ddd000TS00047000<d4008@;0<Zg003h8000na400=>N000>S`0004E:
008000HO0:h004A:00j?003CWP00na400?PQ0039^@0008<>000a@0000a`000XT001EB`0dW@00gWh0
0?h5003a>@00X[`0001d:P007cD0008I000A:`00I3l0J:d00>UI003o0000j5`006B/0000Hd00014[
00026P008CL007HV0:fo003c<`00oPL00=^8000UV000055=00088@001Ad003e600F<003AX`00na80
0?PP0039^P00084B000]?P000a/000`V02F0903SK000o`400>a=001j/P0006Pj000D;@000QT001de
001d:P2V_@00lcD00?h7003JR@008IL0001?CP001b0000DN0014BP0BT@00eYH00?d;003e;000^<40
001h8`008CL0008I000B;000ISd0M;000>a?003o0000hfh004BR0000FDT000XT00047000=48008P3
0<nY003k5000n2000<Rl0000OaH002Pk00036P003bT0069206J/003ZEP00o`000>EX001;Y00005Y8
000;9@000a`003A200280`3@Z000na<00?LS0036`@0007`L000T>@000QX0014[001V?@1h/@00kDX0
0?l2003PM`00=9d0001CC000224000DN0014BP0ETP00f9000?h8003b=P00WK/0001`<0006340008I
000L<`00M2T0[kl00?D]003l3@00e9d000J<0000>D@000@L000:9000FTP0CjD00>IS003o0000if00
05:V0000FdL000/U00047000>D@01X`00=BK003m3000m3000:Nm0000LRd001Ta00026@0073@007DX
0;K1003f:@00o1000=6V0000Q`@0035000036`003BP0065206^^003/C`0:ooooo`7o00000Oooool0
01kooooo00?o0000ooooooooool01oooool0T000228004A:00261P35``00lSP00?l1003YF000R[H0
001f9P00:cd000@M00067`00=d<007lF0:Zn003^A@00o`000>e;002P_00007`L000c@@001Ah000DM
000`@000NQl0VkX00>a=003o0000kd@00:^n0000OaL003I300067`0011d002ho001i8@2G^P00k4l0
0?l0003_A000Z[h0001n6000=D8000DN00057@00<40007/M0:2l003]B@00o`000>e:002N^`0007XO
000_?`0011d000HO000hA000P1<0]<400?0n003o0000jEP008Fe0000Lb/002Hj00036`00224004E:
00290@38^`00m2h00?h4003SK@00Hj/0001Z>@006c<0008J000<9P00E4`079@00=:Q003i6`00o0h0
0=Z:000iW`0005e6000A:`000QT001@]001Q@P17X`00gWl00?d9003g8`00cZh000^>0000CTh000TS
00036`0093T0078/08Fe003ZEP00o`000>m4002T_@0007/N000^?P0011`000LP0011B000Q`@0b;`0
0?D/003n1@00hG@005FW0000I3l001H_00026@0042X005e603^O003LQ@00naH00<j]000:SP0004a=
00088P000a/002Pk001g9@2I^P00kDT00?l0003ZE@00Pk@0001a;P008CL000<J000;9@00Dd`07YD0
0=BK0080nQD00?<0e9/001jE0000Dd`000/U00036P008SP0078/08Zf003[D000o`000>]@002:]P00
078/000R=`000aX000/U001DC00RU`00eYH00?/B003i6@00dJ@001:A0000Cdh000PR00036`00:S`0
07TP0:Jm003`?`00o`400>IT001W[@0006Pj000G<0000QT0014[001P@`1:Y000h7L00?h5003d<000
`l@000214P00<d4000@M00078000ATX01X`00<j/003h7@00o1000=NC000SU`0005A<000:90000a/0
02Hj001g902Q_000l4000?l1003UIP00HJ/0001U?@005Bh0008I000E;P00ICh0H:/00>EV003o0@00
kd8009jk0000MRL002@i00036P002bH005M:02nK003KR000o@X00?HW0038_00008@;000f@`0011d0
00LP0017B`0<SP00dJD00?XH003j5P00dZ8000n@0000BD`000LQ00047@00=T<008@;0<Rk003f9P00
o@`00=V=000WV@0005A<000:90000a/002/m001m6`2j`P00lc400?h6003NOP00>Il0001IB@0032H0
00<J000U>@00N2<0ZKh00?4i003o0`00h7H004FR0000G4L000hX00026P008SP007DW0::l003a?000
o`<00>5c0017X`0005e6000>:0000QX0028h001f9`2T_@00lC/00?l3003PMP00@Z80001KB0003BL0
00<J000U>P00NB40/<000?<d003n1P00gH0003FM0000ETX000XU00036`00;3d007lG0<G3003e:@00
o@/00=R?000PUP00051>00088P0011d003M400271@3</@00nA`00?/E003AY0001h`00010B0001Ah0
00HP001:C00ETP00eYL00?`>003g9@00akl000205000;Ch000<K000;9@00F4T0?:000>1h003o0`00
l3l009Rj0000LBh001`c00026@004bd006Ll07:`003ZD`00o`000>IR001JZ@000613000?:@000QX0
02@i001i8@2g`@00m2h00?d9003IS`007ID0001>CP001b0000DN0012B@0<S`00e9d00?`?003g9@00
a/00001n5`00:C`000<J000=9`0YPR<0iFH00?l0003[D`00L:l0001U?@004R`0008I000P=P00MbD0
/L000?@`003m2@00f90001ZD0000BT`00P001Ql0J`00BT`06Y@00=R?003m2@00lc400:fo0000MBP0
01he00026@0052d006Tj07jc003]B@00o`400>5d000lX00005I;00098`0011`003U400:;003AX`00
na400?LT0035`P0007`L000U>@000QX0010Z001T?`1`[`00je000?l0003SKP00@Z80001GBP002R@0
00@L000iA003R`00dZ400?`?003f9`00_l<0001i8@008CL0008I000C;@00JCT0Pk@00>i4003o0`00
gWh002bJ0000DDd000LP00057`00BD`07ID00=Z9003n1P00lC/009>h0000KC@001H_00026@007cD0
07LU0;[2003f:000o0l00=6S0000R@0003E200036`002bH005e605RX003XG@00o`000>EW0019Y000
05Q900098`0011d003e700j?003FU@00o@T00?<e002M^`0006lb000G<0000QT001le001h8`31a000
mb@00?/C003>[00008@;000]?P000aX000lY001T?`1e/000kDT000[ooooo0Ol00001ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`0P00098`00BT`008T00<Nm003c<`00o`800>MO001o/`0007<[
000W>`0011`000HP000lAP00PQ00]L400?10003o0000je4009Ji0000NB4002lo00057@001Ah003A2
001m6@2V_@00kTL00?l0003]BP00XK`0001l7000<T4200057P3o000b@@00O1`0X[`00>e9003o0000
kDX00:2l0000Nad0035000057@001Ah003E2001n602[_P00kd@00?l0003[D000TkP0001g9000:cd0
00@L00068000?4H008<=0;o3003b>000o`400>MN001k/P00074_000S>0000a/000TS001;C@05S000
bkD00?HY003n1P00hG<005VY0000Ic`001Ta00026@003BL005M:02BG003EVP00nQL00?/A003HT000
<9`0001JB0003bT0008I000F;`00I3l0DJH00>1h003n1`00mRL00<^d0004R`0004U<00088P000a/0
02Lk001e:02?]`00je000?l0003]BP00VKX0001h8`00:S`000@L00078@00ATX00HX00<Zf003f:000
oPL00=mj001;Y@000691000D;@000QT0018/001P@`14XP00gWl00?XG003;/`000h/00016B`001b40
00@L000/?@00NR00Xkd00>m3003o0000j5/007Vb0000KS8001he00026P0032H005I;02JH003GU@00
na800?XI003BXP005Y80001AC@002B<000<K000U>P00MBP0UKT00>e:003o0000jUH007nc0000Kc40
01le00026P0032H005M:02ZJ003HT000o0l00?PM003?ZP002hh0001:C000224000@L000]?P00O1/0
/L000?4j003o0P00i6X005fZ0000ICh001D_00026@004bd0069105>W003RL000o`<00?8f002h`P00
07hH000_?`0011`000PQ001;C@0>S`00dJH00?TI003k4`00eIX001^D0000DDd000TS00036`00:C`0
07XO0:bo003a>`00o`800>=/001GZ00006=0000C;@000QT001L`001X>`1Z[P00if000?l0003^A`00
TkP0001c:`008CL000<J000=9`00FDT0>9h00=f2003n2000mB`00<K20000PA800391000470002240
04e>01>A003CWP00na@00?TJ003@Z00028d00014BP001R0000DN000jA@00Q`D0bk@00?LQ003l3P00
ei@001nF0000DDd000TS00047000;cl007lE0<G4003e;000o@P00=b5000aW00005I;000;9@000a/0
02Pk001k7P2d`@00lc@00?h5003NO000?:00001IB@0032H000<J000U>P00N280[;l00?8g003n1000
ggX003jP0000FTP000`W00036P009CX007TR0:no003b=@00oPD0000L0=im000iW`0005Q9000;9P00
0a/002Tl001l702k`P00m2l00?h8003KQP00;9X0001DC0002B<000<L000`@000PA40b;d00?LU003l
3P00eYH001RC0000CDh000LP00057@00?4H00HX00<nZ0080nQP002X0cj/0002:0000>dD000DM0007
8@00Cdh07ID00=RA003m2`00mBX00<C40000OAX002Tl00036`0032H005]804FS003RL@00o`800>m4
002=]`0006hb000I<P000QT001D_001Z>01l/P00k4d00?l0003TJ000DJH0001NA@003BP000<J000W
>`00O1`0`/@00?DY003m3000eYD001FB0000B4`200067`1C0017B`0DTP00eYH00?d<003e:@00`L@0
001k7@009SX000<J000>:@0^QB80if000?l0003YF@00IZ`0001S@00042X0008J000S>000NR00_<80
0?D[003m3000eYL001:A0000A4X000DN00078000Cdh08YL00=Z9003n1`00lSH00::l0000LR`001`c
00026@005Rl006`f08Vf003_@`00o`<00=mk000cW@0005=<00088P0011d003e700V=003DW@00o0h0
0?HY002m``0007TQ000R=`000QT0018/001W?01j/P00kDX00?l1003QM@00>Il0001EB`002B8000@M
000mA`0:SP00e9/00?`<003e;000]<40001f9P007SD0008I000E;P00K3H0SKL00?0o003n1000g8@0
02BG0000CTh00P001Ql0<P00CTh09IP00=b3003n1000kd4008Rf0000JSP001@]00026@008SL007XO
0<G4003g9000na<00<nY0000QPH0031000036`003BL005m406:[003ZEP00o`000>=]000oX@0005I;
00088P001Ad0049901FB003ISP00oPL00?4j002B^00006`e000D;P000QT0028g001k7P36`@00n200
0?XG003</P00088A000Y?0000aX0014[001V?01o/`00kd@02_ooool1o`00007ooooo000Nooooo`?o
00001oooool0a0002R@004m>00J<003:]`00m2h00?l3003UI@00MK40001`;`0093T000<K00078@00
@DP008D:0<33003a>P00o`000>UG002;]P0007HV000[?@0011`000HO000iA000P1@0/L000>m2003o
0000je0009Ji0000NB4002ho00047@001Ql003I3001o5P2]_`00kd<00?l0003[D000UKT0001h8P00
;Ch000@M00067`00>D@0084B0;K1003`?P00o`000>YG0028]P0007DY000X>`0011`000LQ0011B000
QPL0a/400?<c003o0P00iV@0076_0000KS<0020f00036P002R@004m>00b?003=[P00mb@00?d8003O
NP00D:H0001T?`005Rl0008I000?:@00FDT0;9X00=ND003k4`00nQD00=JG000XV@0005Q:000>:000
0QT001Pa001W?01JZ@00hW400?h5003e;000bKX000280P00@dT000LQ00047000:Sd007PS09Zj003]
BP00o`000>]@002?]`0007DX000V>P000a/000PR001;C@08S@00cJl00?LS003m2P00gH4004:R0000
Gd@0018/00026@0052h0069104jU003PN000nQT00<Vi0000R0<004580007800011d002lo001m6P2^
_`00l3d00?l1003WH@00Kjl0001[=P006c<0008J000=:000F4T0;Y/00=V>003l3`00nAd00=2X000>
S`0004i>00088P000a/002Tl001h8`2O_000kd@00?l0003XG000MK40001]=@0073@0008J000>:000
FDT0<id00=Z9003m3000mb400<f`0003R`0004A:0007800011d00351001o5@2l`P00lc@00?l4003R
L@00E:L0001S@@004bd0008I000E;P00ICh0GJX00>AZ003o0P00lC/00:fo0000Nah002/m00036`00
228004m>01FB003CW`020?XF000/0=:P000DT@0004m>00088P0011`002dn001m6P2g`@00lSH00?l4
003QL`00CZD0001P@`004B/0008I000I<@00JcL0M;000>UI003o0000k4d008Rf0000L30001he0002
6P003RP005a7046Q003ON`00oPH00?@a002n``0007hG000^?`0011`000PR001@CP0KU000eIP00?/A
003h7P00cJl0006:0000?dL200057`3n000oA`01RP00cJh00?TM003k4P00eIX001NC0000Cdh000PQ
00047000<d40088?0<Nn003f:000o@/00=Z<000XV@0005A<000:90000a/002`m001m6@2o``00m2l0
0?h7003LP`00<id0001GBP002bD000<K000Y?000Nad0]l400?<b003n1P00gH0003JN0000EdX000/U
00036`00:C`007`L0;[2003d<000oPL00=b3000`W00005E;000:90000a/002`n001o5`35``00mBX0
0?d:003IS@0099L0001AC@00228000@L000d@P00Q0/0b[L00?PP003k4@00e9`0016@0000Ad/000HO
00057P00@DP028d00=6T003k5000nA`00<ba0000Q`H003I300047@002280055=02FH003JRP00o@T0
0?@_002i`P0007XO000V>P000aX000dX001MA@1?Y@00i6/00?l1003]BP00P[@0001[=P005c00008I
000H<000K3D0QkD00>i7003o0@00hfl004RS0000FdL000`V00036`00:cd007lF0<K0003g9@00o0l0
0=BL000>S`0004=900057P001R0004a=01^D003HT000o@X00?@^002f`@0007PR000S>0000QX0010Z
03>8803YF@00o`000>MO001LZP000613000>:@000aX002Lj001l6`35``00mRH00?`?003DW@002Xh0
000oB0001Ad000PQ001AC@0ZVP00gH800?h5003a?000UkX0001`<0006C40008I000H<@00KS80TkT0
0?0m003n1000gH4002ZJ0000DDd000LQ00057P00@TT04I000=JF003m2`00m2h00;;00000MRH001le
00026@0052h006Xh08Be003^A@00o`<00=mk000aW000059=00088@001Ah0049901:A003GU000o@X0
0?@a002Y_P0007<[000L<`000QT001L`001_<P2H^P00lCT00?h6003JR`0079@00018C0001Ah000LP
001AC@0]V`00gW`00?l2003^A`00O[<0001W>`004R`0008J000U>@00OAX0akh00?PO003j5P00cK00
00233@00;3h000<J000>:000HT40Jjh00>]@003o0@00hG@003NN0000Dd`000LQ00057P00B4/07ID0
0=^8003n1@00l40008Ne0000JCT0018/00026P009CT007hH0<Vj003i7000nAX00<Vh0000OaL002Hj
00026P004R`006Ti08Vf003`?P08ooooo`?o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0o`002bH0055=00j?003</@00mRT00?h5003TJ`00Jjh0001]<`008CL000<K00088P00AT/008P4
0<K1003c=@00o`400>QM0020]00007<[000W>`0011`000LP000mA`00P`h0_<800?4l003o0000jUH0
08^f0000MRH002Xl000470001R0003]50022402h`P00l3d00?l0003ZEP00R[H0001e9`00:C`000@L
00078000?TL008@<0<74003b>000o`400>QM001n/`00078]000T>@000a/000PR0016B`00R@00b;/0
0?@^003o1000i6/006N]0000JcL001dd00036P002bD0059=01BB003@Z000n2000?d;003MP000AZ<0
001Q@P0052h0008I000@:P00G4L0=9d00=V=003l4000nQT00=>N000OUP0005E;000<9`000QX001/c
001Y>@1T[000i6/00?l3003d<@00a/0000252000?TL000HP00047@00;Sl007/N0:Fm003_A000o`00
0>YF0024]@00078]000S>0000a/000TS001?CP0@T000cjT00?PO003l3000fhL003VO0000G4H0010Z
00026@005Rl006Dn05NX003RL@00nAX00<K00000Q@T003a600067`001Ad003A200205@2i`P00lSP0
0?l2003UJ000IJ`0001X>P006C40008I000?:@00FdL0=ih00=^7003m3000n2400<f_0007S00004Q<
00078@0011`002`n001k7P2Z_P00l3h00?l1003VHP00Jjh0001Z>0006C80008I000?:@00G4L0?:00
0=b3003m2@00mRH00<Zg0000R08003m800067`001Ad003I300224035``00m2l00?h5003PM`00BZ@0
001P@`004B/0008I000G<000J3/0Ijd00>IS003o0@00kd400:>l0000N2<002Lk00036`002R@0059=
01fE003EV@00na800?TJ003@Y`0038h00019C0001b4000@L000a@000P1@0`/@00?@`003n1@00ggX0
04BR0000GDD000lY00026@0073<006hc07jc003ZD`00o`000>YC001n/`0006dd000K<`000QT0010Z
001OA01:Y000hGD00?l4003b=P00/l00001k7@00:S`000<K000:9000Dd`08iL00=RA003l3P00mb80
0<^e0000Q`D003Y500057P001R0004A:00R=003@Z000nQT00?XE003BX@003i000019C0001b0000@M
000gA000l`00Q@T0b[P00?LS003l3@00ei80022F0000DDd000TS00047000<400080C0<K1003e:P00
o@X00=Z:000ZVP0005A<000:90000a/002`n001n6032a000mBd00?d8003KQ`00;I/0001EB`002R@0
00<K000/?P00OaL0aL@00?D[003m2@00fXX002RI0000Dd`000TS00047000<400088A0<Nm003f9@00
o0d00=ND000LU00004m>00078@0011d003Q40027103=/000nA`00?/D003BX`002Hd00012B@001Al0
00HO0016B`0?T000e9d00?/A003h8000b[P000243000<T4000@L00098`00E4`0;I/00=b4003n1P00
lc@00:jo0000Mb@0028h00026P003bT0061305RX003VI000o`000>]@001h/@0006Tj000E;P000QT0
01Xb001_<@2A^000kd800?l2003QM@00?Z00001HB@002bD000<K000^?`00PQ00bKT00?PP003k4P00
dZ8000N<0000?TL000DM00078@00D4h099L00=Z9003n1`00lc<00:^n0000MRL001lf00026@004R`0
>8XO0>YC003o0000iFH005>W0000GDD000dW00036P00:Sd007lE0<Rm003g8P00na800=6T0003R`00
03Y500047@00228005A<03>M003ON`00o`<00>m1002=]`0006dd000G<0000QT001Xb001a;P2N^`00
lSP00?h6003KR0008YL0001>CP001R0000HO0018B`0HT`00f8l00?d8003c<`00Ykh0001c:`0073@0
008I000F;`00KCD0SkL00?0o003n1000gH8002RI0000D4h000LP00057`00Ad/06I@00=V=003n1`00
lSH009jk0000L2l001Ta00026@006S80074^0::l003c=000o@T00=RA000DTP0004=900057P002280
05=<03JN003PMP00o`400>a<001c/00006@o000@:P000aX002Pk0020503:^000nA/00?TJ003:]P00
080C000Y?0000aX0010Z001U?P1f/@00kDX00?l2003ONP00;Y/0001@C@001b0000HO001=CP0UV000
gH400?l3003^A@00OK<0001V?0004B/0008J000X?000PA80bk@00?XH003h7`00akl0001l70008SP0
008I000D;P00K3D0U;T00?8h000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0P0003BL005A<01FB003?ZP00mb@00?h7003RLP00HJ/0001[=`007SD000<J00098`00Bdd00XX0
0<Vj003d<000o`<00>IT001f/@00070_000T>@000a/000PQ0013B@00QPL0aL<00?8g003o0@00j5`0
086d0000Lb/002Hj000370001b40041800252P33a000lSP00?l1003XG000P;<0001b;0009CX000<K
00078@00@dT008L50<K0003c<`00o`800>IS001d/00006lb000Q=`000a/000TS001<C@06S000bkD0
0?HY003n1P00hW4005fZ0000J3X001Xb00026P0032H005A<01bD003BX@00nA/00?`>003KQ`00?J00
001OA0004R`0008I000B;000Gd@0?J000=^6003l3@00nAd00=6T000GT`00059=000;9@000aX001he
001/=@1^[`00iV@00?l2003b=P00`<@000223`00>DD000HO00057@00<T4007hH0;30003`?P00o`40
0>QL001j/P0006la000P=P000aX000XU001BC@0GT`00dZ800?TJ003l3`00fHh0032L0000FTP000hY
00026@006C4006Pk066[003TJ`00nA`00<;40000PQ0003M40P001Ah0:000>4@008<?0<C4003c<P00
o`@00>=^001KZ@0006Hm000F;`000QT0014[001NA@10X@00gH400?d9003f9P00bkD000290000@dT0
00LP00047@00<40007hH0;G1003b>@00o`800>AY001QZ`0006Ll000G<0000QT0014[001OA015XP00
gg`00?h7003e:`00b;d000252@00>TD200057P27000jA@00Q@T0b;d00?DZ003n1`00gWh0046Q0000
GDH0010Z00026@006S8006/g076_003XG@00o`000>i6002H^P0007DX000T>@000aX000/U001DC00U
V000ei800?`?003h7P00cZd000F<0000A4X000HP00057@00=D<008<>0<K0003e:`00oPP00=f0000k
W`0005]8000>:0000QX001he001`;`29]P00k4d00?l0003YFP00Lk00001Z=`006C40008I000B:`00
HD80DjL00>=^003o0P00lC`00:Rn0000N28002Lj00036`002bD005E;02bJ003JR`00o@/00?HW0038
_00008@<000f@`0011d000LQ001:C00@T000dZ400?XE003j6@00d:P000R=0000A4X000HO00057P00
?4H008P20<ba003h7`00o1400=FI000HT`0004m>00088@0011`003A200233@38^`00mRD00?d<003H
T0008YL0001AC@002B<000@L000`@000PA80akl00?HX003m2`00fHh002BH0000DTd000TS00047000
<400084A0<Nn003f9P00o@`00=RA000PUP00051>00088P0011`003A200252P3:]`00n2400?`@003E
VP005980001:C0001b0000DN000mAP02RP00cjX00080nQP007H0cjT000::0000?DH000DN00078000
C4d05i<00=JG003l3P00mbD00<Nn0000PA8002ho00036`002R@005I:03JN003NO@00oP@00?4i002S
_00007@Y000O=P000QT0014[001S@01RZ`00ieh00?l0003ZEP00KZl0001V?@004b`0008I000M=000
LR`0W;/00?4l003n1000gW`003FM0000ET/000XT00047000<d4008D:0<bc003i7000nQH00<nY0000
R@0003U500047@002280059=02bJ003MPP00oPD00?8i002P_00007</000M=0000QT001@]03f=7@3/
C@00o`000>=/0019Y00005]8000<9P000a/002ho00223`3:]`00n1d00?XF003?ZP0008P3000f@`00
11`000TT001FBP0lX000hGD00?l2003^A`00P[@0001Z>0005Bh0008I000M=000M2T0ZKh00?<c003m
2000fHl001ZD0000BD`000HO00068000CDh08IH00=^9003n1P00lSP009bk0000L2l001Tb00026@00
6C4006la09Vj003a>@00oPH00=^8000PUP0004a=0P001Ql0A@00CDh08YL00=^7003n1@00lC`009Bi
0000KS<001L`00026@0073@007@Y0:fo003d;`00o@/00=FH000<S`0003i700047@002B<005I;03nQ
003RK`00o`000>]C001Y[@000691000>:0000aX002`m00233P3</P00nQL00?PN0038_00007dI000U
>P000QX0018/001X>`20]000kT@00?l3003MP@009IP0001>CP001Ql000LP001@CP0^V`00ggX00?l2
003]B`00Lk00001T@0003bT000<J000/?P00Q0`0cZh00?/D003g8`00a<@0001i8P007cH0008I000G
<000Kc40Wk/00?<c000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0H@00
3RP005I:01fE003AY000n2000?d9003PN@00EjP0001X>`006c<0008J000:9000Cdh02Hd00<^d003e
:`00oP@00>AZ001/[P0006dc000Q=`000a/000PR0018B`00R@00b;d00?<a003o0P00iV<007Ja0000
L30002<h00036`00228004E:00280`37_`00lc800?l2003VH`00MK40001`<0008SP000<K00088P00
B4`008X00<Vj003d;P00o`@00>AZ001Y[@0006`f000N=@000aX000XT001@CP0=S`00cJh00?LT003n
2000h7P005>W0000ICh001P`00026@003RP005M:02BG003DV`00nQL00?/A003ISP00=9d0001LA`00
42X0008I000D;P00HD80Aj<00=f0003m2P00n2400<n[000?T000051>000:90000aX0020g001_<@1h
/@00ieh00?l1003a?000]L40001o5@00=D800P001Ah0b`00=d<0084B0;_2003b>@00o`800>IS001_
[`0006`e000M=0000QX000`V001EC00PUP00e9`00?XG003k4`00eYD002RI0000EdX000dW00026P00
6c<006/g06^^003VI000n1h00;O10000OaH003=100057@001Ql003e600262037_P00m2d00?h5003Q
M@00DJH0001S@00052h0008I000B;000H4<0BJ@00=mj003n1`00mBX00<Rk0000QPH003i700067`00
1Ad003E200214P31a000lc<00?l4003RL000EjP0001T?`005Bh0008I000C;000HD80CZD00>5e003n
1@00m3000<G30000PQ0003I300057@001Ql003m700280P3:]P00mRD00?d:003LQ@00>9h0001JB000
3RP0008J000L=000KS<0Nk800>UG003o0000k4`008fg0000LRd0024g00036P0032H005M:02jK003J
R`00o@`00?LS003;]00008T1000oA`001Ql000DN000jA@00QPP0bKX00?HV003m2P00fhL003:L0000
F4T000`V00036P008CL007<[09Bi003^A`00o`000>MP001Y[@0006Pk000F;`000QT001@]001T?`1M
ZP00iFL00?l1003_@@00WK/0001e9`008cP000<J000<9P00F4T0=9d00=b4003m2000mB/00<K20000
PA80035000047000228004m>01NC003EVP00na800?TM003=[P000HX0000oA`001Ah000HO0011B004
R`00cj/00?TJ003k5000dj00012@0000BD`000LP00057@00>4@008H60<^e003h8@00o0l00=JG000J
U00004m>00088@0011d003E200242`39^@00mb<00?`>003GU00079D0001@CP00228000@L000e@P00
Q0/0b[P00?LR003l3`00eYP001NC0000CDh000LQ00047@00>D@008P40<ba003i7@00na<00=:Q000<
S`0004A:008000HO0500049900V=003AX`00na@00?TL003=/00008L4000hA00011d000PQ001@CP0O
UP00f9000?d;003e:P00aL@0001n6000:Sd000<K000;9P00FDT0?j400>1f003o0`00l3l009Rj0000
LBh001`d00026@004b`006Hm06b^003YE`00o`000>QM001T[00006=0000A:`000QT0020f001e:02W
_@00lSH00?h6003LP`00;I/0001CC000228000@L000g@`00R0<0cZd00?XH003i6P00cJl000261P00
=D8000@L00098`00ED/0=Id00=ml003o0`00l3h009Fi0000L30001Xb00026@005Rl0@Y0L0>i7003o
0@00hG<0042Q0000F4T000XT00037000<T4008D90<f`0080nAT00700c;4000252@00<D4000<K000;
9@00FDT0AJ800>=^003o0@00k4d007Ra0000Ic`0018/00026@0083H007LU0;C1003d;@00o@/00=JE
000BT@0004=900057P001b40051=02VI003MPP00oP@00?0n002A^00006dc000G<0000QT001/c001b
;02T_@00lc@00?d8003HS`0069<00016B`001Ah000LP001@CP0ZVP00gH000?l4003_@@00RKH0001[
=`0052h0008I000O=P00Mb@0^L800?DZ003l3P00dil000F<0000>D@000@L000:9000FDT0B:<00>AX
003o0000jET005nZ0000Gd@000dW00036`00<40008H80<n[003k5000mb<00<G30000Nah0028h0002
6@0052d006Xh08^f003`?`00oPD00=^8000MU@0004Q;00057P001b4005=<03JN003QL`00o`400>]B
001X[@000652000=:0000a/0031000271P3@Y`00na400?HX002h`P0007HW000M=0000QT001Ta001b
;@2Z_P00m2h02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo04H0010Z001I
B@0VV000e9d00?TK003m3000gH0004fU0000ICh001Ta00026P0032H0059=016@003>[P00mRH00?h6
003RL@00HJ/0001[=`007SD000<J000:9000CTh01X`00<Zg003e;000oP@00>AZ001/[P0006dd000P
=P000aX000TS001;C@03R`00bKT00?@]003o1000i6T006^^0000KCD001lf00036P002B<004i>00R=
003;]000mRT00?h6003RL000GjX0001Y>@006c<0008J000;9@00DTd05I800=2X003h8000o@X00=io
0019Y0000691000E;`000QT000lY001JB00/VP00ei@00P3k5000C@3FU@00:iX0001IB@003bT0008I
000F;`00I3l0D:H00=mi003n2000mRH00<ba0008S@0004a=00098`000a/002@i001b;@23]000jEL0
0?l0003_@P00Z[h0001l6`00<D0000@M00067`00>dH008@<0<G3003c<`00o`<00>AY001U[00006Ti
000J<P000QX000dW001GBP0XV@00eYD00?/C003j5P00e9`001nF0000E4`000`V00026P007SD006hc
07Ja003WGP00n2000:bo0000O1`002lo000470001b00049900290@3:^000mRP00?h7003OO000B:<0
001P@`004R`0008I000D;P00Hd00DjL00>5c003n1@00m2l00<K20000P`d003U4008000DN0?l003U5
00243036`000m2h00?h5003PMP00CJD0001Q@P004b`0008I000E;P00I3l0F:P00>=^003o0`00lSD0
0;_20000OaH0035100047@001b0004A:00B;003=/000n2400?`=003JR`00;i/0001HBP0032L0008J
000O=P00L2l0Q[D00>]@003o0000je<008:d0000Kc4001he00026P003BP005Y803NN003LQ000o@T0
0?HW0039^P0008H8000jA@001Ah000HO000oA`00R@40bk<00?LR003l3@00fHh002VI0000ED/000/U
00036P009CT007HV09nk003_@@00o`400>EW001OZP0006Dn000D;P000QT001H_001W?01W[@00if40
0?l0003^A`00T[P0001b;00083H0008J000=:000FdP0?J000=im003n1P00m3000;k30000OQP002dn
000370002B<0055=01nF003GU000o0h00?LQ003;]@0008L5000jA@001Ah000HP0016B`0;SP00dJ@0
0?XF003j6000d:H000V=0000A4X000HO00057P00?DH008T00<f^003i7000na<00=>N000BT@0004Y<
000780001Ad003U400271@3</`00n1l00?/A003DV`005980001;C@001b0000DM000iA@00Q`@0c;40
0?PM003k4P00dih0012@0000Ad/000HP00057P00?TL00X/00<nZ003j6000nQL00=2X0005S00003m7
00057P001R0004M;016@003DW@00na400?PP003:]P0008@;000d@P0011`000TR001BC@0WV@00fXT0
0?d8003d;`00^/80001k7P009cX000<J000=9`00G4L0BJ@00>9_003o0@00kTD008fg0000Kc8001Xb
00026@005Bh006Pj07Na003[D@00o`000>IS001JZ@000613000?:@000QX002<h001h8`2b`000m340
0?h8003JRP0099P0001@C@00224000DM000lAP03R`00d:H00?/D003h7P00b[H000233@00<40000<K
000:9@00F4X0?Z000>5e003o0P00kd@008Zf0000KC@001L`00026@006340B9<J0>m1003o0`00ggT0
03NN0000ED/000TS00047000=d<008P20<nZ003j5@00n1d00<Zg0000PQ0002dn00036`0032H005a7
04jU003UI`00o`000>YC001][P0006@o000A:`000QX002<h001j7`2o``00mRP00?`>003DW00005`0
2Xh0000nA`001Ad000PR001CC00bW000gg/00?l3003_A000QkD0001[=`005Bh0008I000N=@00MBL0
/<000?@_003m2`00eYH0012@0000@DP000DN00088P00Dd`0<id00=mi003o0P00kTL007jc0000J3/0
018/00026@008SP007XO0<C4003g9@00na400=6V0000R@4003A200036`002bD005]705:V003VHP00
o`000>MO001EY`0005a6000;9P000a/003A200290@3AY000o1000?HW002l``0007PT000O=P000QT0
01H_001]=02F^@00lCT00?h7003IS`005I800012B@001Ad000PR001FB`10X@00hfd00?l0003YF000
GZX0001NA@0032H000<K000d@P00RP00dZ000?`>003e;@00[Kl0001c:`006S80008I000L<`00MBP0
]L400?HY00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o000B;000G4L0
;Y/00=JF003j5`00o0l00=^60014XP000691000F;`000QT000dW001EB`0IT`00d:L00?LQ003m2@00
h7P005NX0000J3/001/c00026P002bD0055=00f?003=/000mRL00?h6003RL000HJ/0001Z>0007C@0
00<J000:9000Cdh02Xh00<bb003f:000oPH00>9`001QZ`0006Xh000L=0000aX000/U001AC@0?T000
cZd00?LT003n2000h7L005FW0000ISd001Ta00026@003BL005E;01fE003BX@00nA`00?`=003KQP00
@:40001P@`004bd0008I000A:`00G4H0=Id00=V=003l4000nQP00=BL000SU`0005I:000=9`000QT0
01Ta001W?01JZ@00hW800?h5003e:P00b[P0006:0000AT/000PQ00036`009c/007DX08jg003[D@00
o`000>i8002O^`0007TP000/?P0011`000LP0010B000Q`D0akd00?@^003n1@00hW0005^Y0000IS`0
01P`00026@003bT005Y8036L003ISP00o1000?TJ003BXP005i<0001BC@002R@000<J000Q=`00L2l0
P;@00>UG003g8`00X;`0001i8@00:cd000@L00078@00Ad/01H`00<ba003g9000o@X00=f2000nX000
05e5000@:P000QT001L`001V?@1MZP00hf`00?l3003c=@00_/<000204`00=48000DM00067`00?TL0
08L50<Vj003f:@00oPP00=im0014XP0005i4000A:`000QT001L`001W?01RZ`00iFP00?l2003a>`00
/<00001l6`00;Ch000@L00088@00BT`02hh00<nY003i7000o1000=NB000VV00005E;000;9@000aX0
028h001c:`2A^000kDX00?l0003YF@00Mk40001/=@006c<0008I000?:@00G4H0@:400=im003n1`00
mB`00<K10000P`l003E300047@001R0004A:00F<003>[@00n1d00?`@003GU@008IH0001CC0002R@0
00<K000X>`00NB40Z[h00?4k003o0P00hfd005FW0000HT40018/00026@00634006Xh07:`003XFP00
o`000>a=0027]@00070`000M=0000QX000lY001MA@17X`00h7H00?h4003b=P00/l00001k7P00:C`0
00<K000:9000E4`0:9T00=V=003m2`00mRH00<Rk0000Q0`003E200047@001b4004a=000U01>A003D
W@00na<00?TL003>[@000HX0000oA`001Ah000HO0012B@07S000d:P00?XH003j5P00dJ@000Z>0000
A4X000HO00057P00?TL00HX00<j/003i6P00na@00=:R000<S`0004I:00067`001Ah003i700::003?
Z`00nAT00?XF003AY@0028d00012B@0200067`3<0013B@0:SP00dJ<00?/E003i6`00cJh000280@00
>TD000DM00078@00CDh069<00=JF003l3P00mbD00<Rm0000PA4002lo00036`002R@005E;032L003M
PP00oPH00?<d002__`0007PS000S>0000QX000hY001OA01BY`00i6T00?l0003]B`00P[@0001/=P00
5c00008I000G<000JcH0PK@00>e;003o0000i6X0052V0000GDD000dX00036P009SX007/M0;k3003e
;000o@X00=RA000LU@0004e>000780001Ah0045800Z>003CW`00na400?LR0038_000080C000/?P00
0a/000`V001JB017X`00hfh00?l1003]BP00P;<0001Z>0005Bh0008I000K<`1=UQL0lC/00?h4003M
P000;Y/0001CC@00228000@M000kAP04R`00dJ<00?/B003g8P00akh0001o5P00:C`000<J000=:000
Gd@0F:P00>MQ003o0000jEX006>[0000HD8000lY00036P009cX007dJ0<K1003g9000na400=:S0003
R`0003U5000470002B<005I;03^O003QM000o`400>e:001l/P0006Pk000C;0000QT0024g001h8P2k
`P00mBX00?`>003DW@0028d0000lAP0011d000TS001FB`0lX000hG800?l1003/C@00M;00001U?P00
4B/0008J000V>P00OAT0akh00?PP003j5@00cZ`000262000<40000<K000<9`00GTD0G:T00>QK003o
0000iFH004^U0000FDP000XT00047000>D@01H`00=>N003l3@00mB`00;700000MBT001`d00026@00
6340070_0:6l003c<`00o@T00=JE000=S`0003e700047@002B<005Q904VT003UIP00o`000>MN001D
Y`0005]7000;9@0011`003U400R=003EVP00o@/00?<b002R_000070`000G<0000QT001he001h8`30
a000mb@02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l001@]001OA00g
WP00f8l00?/D003k4P00fHd003ZO0000Gd@001@]00026@003bT005M:026G003CX000nAd00?d;003N
OP00CZD0001U?P006340008J000<9P00Dd`05I800<nY003g8P00o@P00>1g001GZ00006Lk000J<P00
0QX000/U001BC@0BT@00cZ/00?LS003n2000h7L005NX0000Ic`001Xb00026P0032H005=<01NC003@
YP00n1l00?d:003NOP00Bj@0001S@0005Rl0008I000>:000F4X09YP00=FJ003j5`00o1000=V=000g
WP0005e6000A:`000QT001<]001OA00oX000fhH00?`=003i7000dZ8001ZD0000E4`000`V00026P00
6c<006Xh06B/003TJ`00o`@00?@`0037_P0008L50011B0001b0000@L000[?@00N2<0VKX00>e;003o
0000k4h009Bi0000MRD002Tl000470001b4004I;006:003:]`00mRT00?h7003PM`00DJH0001T?`00
5Bl0008I000@:P00GDH0>Yl00=^7003l3000n1l00<nY000?T00004m>00098`000a/002@i001c:P2;
]P00je400?HV002E^@0007HV000W>`000a/000PR001=CP0<S`00cj/00?PO003l3@00fXT003FM0000
FdP000lY00026@006C8006Ti06N]003UIP00o`800?4j002c`00007dI000`@00011d000LP0013B@01
RP00bk@00?LT003m2P00g8@003ZO0000G4L000lY00026@006S8006Xh06f^003WH@00o`400>m1002U
_@0007TQ000Y?0000a/000TR001?CP0CT@00dZ<00?XH003k4`00eIT001jE0000DTd000XT00036`00
9SX007HV09bk003_A000o`000>MO001][P0006Ti000H<@000QT0014[001OA01:Y000h7L00?h5003c
<P00`<<0001o5@00<D0000@L00078@00BT`03Hl00=2V003i6@00na<00=BL000IT`00051>00098`00
0a`002`n001l6`2e`@00lSH00?l4003QM000Bj@0001OA00042X0008I000K<`00KC@0O;<00>YD003o
0000jU@007bc0000KCD001Xb00026@004B/00613052V003RK`00o`800?4k002W_P0007PS000V>P00
0aX000/U001GBP0aW000fhH00?d9003e:`00a/4000214P00<D0000@L00088P00D4h006006i@00=JG
003l3`00n2000<^d0000Q`D003Y500057@001b0004Q;00j?003BX@00na@00?TJ003>Z`000h/0000o
A`001Ah000HO0013B@09S@00dJD00?XG003j6000cjT000F<0000@4P000DN00067`00@dT02Xh00=6T
003j5@00nAX00<j/0001RP0003e600057P001R0004U<016A003DW@00na400?PO003;]@0008D8000f
@`0011d000PR001@C@0QUP00f8l00?d;003e:@00aL<0001n5`00:cd000<K000;9@00F4X0>Il00=mk
003n1000lCX00:>m0000MBP0020f00026P0042X0065205bZ003VHP00o`000>]A001g/@0006Tj000E
;P000QT001Tb001^<P2<]`00kTD00?l1003RL000AZ<0001KB00032H000<K000Z?000OQP0a/800?HW
003l3@00eYL001BA0000Ad/200067`2A0016B`0BT@00eIP00?`=003f9`00aL<0001m6@00:3/000<J
000=9`00GDH0DJH00>EW003o0000je0007Fa0000Ic`001<]00026@007SD0DiTE0?8f003n1P00fhL0
02FH0000D4h000LQ00057P00@4P038h00=BL003l3P00mRL00<G40000O1`002Hj00036P003bT00652
06:[003XFP00o`000>MP001IZ@0005m4000=:0000aX002Xm00205039^`00n1l00?/E003?ZP0008P3
000e@P0011`000XT001HB@14XP00hfd00?l0003[D000LK00001U?P004B/0008J000T>@00Nad0aL<0
0?LU003k4@00dJ@0006:0000=d@000@L000:9000F4T0AJ<00>=/003o0000jU@006V]0000HT4000lY
00036P00:C`0080C0<Zh003i7000nQT00<bc0000PPl002`n00036P003RP0065206J/003ZE@00o`00
0>=]0012XP0005M:00098`0011d003i700f?003FU`00o@X00?<a002V_@00078]000I<P000QT001/c
001c:`2/_`00m2h00?d<003DW0001X`0000hA00011`000/U001KA`1CY`00iel00?l0003UI@00BZ@0
001HB@002B@000@M000nA`0?T000ei<00?d8003b=`00UkT0001]=0005Bh0008I000Q=`00Nah0a/00
0?PO000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0>`005Rl00652046Q
003KR@00o1000?XF003GU000<I`0001LAP004R`0008I000@:P00FTP0:YX00=FI003j6@00o0h00=b5
0014XP000691000F;`000QT000hX001FB`0MU@00dZ<00?PN003m2`00gWh004fU0000I3l001P`0002
6@003BL005E<01ZD003AY@00n1l00?d:003NOP00CJD0001T?`005c00008I000=:000ET/07iH00=>P
003i6`00o0d00=b50012X@000613000D;P000QT0010Z001JB00^V`00ei<00080na@00?l0ei@002jK
0000FTP000lZ00026@005Bh0069104RS003MO`00o@X00?PP003?Z@004Y40001AC@002RD000<J000N
=@00KC@0Kjl00>IU003o0P00lSD00<C40000Q0`003a600067`0011d002lo001k7@2T_@00kTD00?l0
003ZE000RKH0001c:P009CT000<K00088P00C4d028d00<f`003g9000o@T00=in0017X`000652000C
;@000QT0018/001OA013XP00gH000?d:003g8`00cK0000R=0000BTd000PR00036`00:3/007HV09Ji
003]B`00mBT008Zf0000Lb/002@i00036`002R@0051>01BB003AY000nA/00?`@003HT000;9X0001H
BP003BL0008J000L<`00K3D0L[000>MO003o0@00l4000:Nn0000NQl002`m00047000224004U<00R=
003>[@00n2000?`=003JR`00<I`0001IB@003BP0008J000L=000KC@0Mk400>QJ003o0000kTL009Vj
0000MRH002Hj00036`002R@0059=01^D003DW000naD00?XG003CX0005I80001@CP002B<000<K000Y
?000NB00Ykh00?0n003o0@00iFH006:[0000IS`001H_00026@004b`0069105>W003RL000o`<00?8g
002d`@0007`K000]?P0011`000PR001?CP0ETP00dil00?XE003j5`00dZ80016@0000C4d000PQ0004
7000<40007lE0<74003d<000oPH00=mk0012X@0005a6000>:@000QX001de001`<027]@00k4d00?l0
003YFP00L[00001Z>0006300008I000C;000Hd00FZT00>AY003o0@00kd4009bk0000MBP0028h0003
6P003BL005U803ZO003NO`00oPH00?@`002n``0007hH000]?P000a/000TS001BC@0TU`00f9000?d<
003g9@00bKX000242`00=D8000@M00078@00CTh05Y800=FJ003k4@00n1h00<bb0000R0@003Y50005
7@001b0004U<012@003CW`00na<00?TL003=[`0008T1000kAP001Ah000LP0019C00AT@00e9d00?/B
003h7P00c;8000271@00>4@000@M00078@00CTh06I@00=JF003l3P00mb@00<Rk0000PPl003500004
70002B<005=<02VI003KR000o@P00?@_002k`P0007/M000X>`000aX000`V001JB013XP000;H0hG@0
0?l2003`?`00V;X0001b;@007C@0008I000B;000I3l0Ijd00>QK003o0000jEL006f^0000ISd001<]
00026@0073@0074^09Nj003`?`00o`<00>1g000mX00005Q9000;9@000a/002ho00214P38^`00mb80
0?`@003CWP0038h00012B@001Ah000HP001<C@0JU000f9400?d;003e;000_<80001j7`009CT000<J
000?:@00H4<0FjT00>MQ003o0000jEL006Z^0000I3l0014[00026P008CL0FI`C0?@`003m2@00fHh0
01bE0000C4d000HP00067`00AT/059400=JE003m2`00mB`00;[20000NB40028h00026P004B/006@o
06f^003ZE000o`000>EW001?YP0005a7000<9P000a/002ho00233@3;]000nA/00?XH003=/00008D:
000`@0000a/000/V001KA`1>Y@00iFL00?l0003ZEP00Ijd0001R@@003bT000<J000X>`00OQL0b;d0
0?PP003k5000cjX000271@00<d4000<K000;9@00FdL0CjH00>EU003o0000jEX005nZ0000Gd@000dW
00036`00;Ch008<=0<ba003j6000nAd00<Vi0000OaD002Pk00036P0042X006@o072_003/CP00o`40
0>5c000hW`0005A<00088P001Ah004=901FB003HT000oPP00?8g002J^P0006lb000G<0000QT001de
001f9P2g`@00mRT00?`?003AX`0008T1000d@P000a/000`V001NA@1MZP00jET00?l0003SK000@J40
001FB`00228000DM0013B@0GT`00fH`00?h6003`?@00S;L0001Z>0004bd0008J000U>@00OQP0bKX0
0?TK00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1F000H<@00I3l0Bj@0
0=f2003l3@00nAX00=BK000XV@0005Y8000@:P000QT0018/001MAP0cW@00ei800?/E003k4P00fH`0
03ZO0000Gd@001@]00026@003bT005U902JH003DW000nAX00?`>003LQ@00A:80001R@P005Bl0008I
000>:000EdX08YL00=>N003i6P00o0d00=b50013XP000652000E;P000QT000lY001IB@0XV@00eIT0
0?XG003l4000fH`003RN0000GTD0018/00026@004R`005e503NN003IS000o1000?XH003EV`009IP0
001GBP003RP0008I000G<000ICh0DZL00>1h003n2000mbD00<f`000:SP0004i>00098`000a/0024g
001`<01i/P00ieh00?l1003a>`00^L8000214P00=d<200057P3o000c@@00OQL0/<000?0o003o0000
j5/007jc0000L2l0028g00036P002R@0051>012@003?Z@00n1l00?d<003LQ@00?Z00001NA@004B/0
008I000D;P00HT40CJD00=mi003n1`00mRP00<Zf0000RP0004E:00078@0011`002`m001j802Q_000
kTD00?@/001o/`00070`000P=P000aX000/U001CC00LU@00e9d00?XG003k4`00eYL002>G0000ED/0
00`V00036P007cD006la07bc003YF000o`000>i6002L^`0007LT000X>`000a/000TR001?CP0@T000
d:H00?TK003l4000ei8002RI0000ET/000`V00036P007cH0070`08:d003ZE000o`000>a=002>]`00
07<[000R>0000aX000/U001DC00SU`00eYD00?/A003i6`00d:L000f?0000C4d000PR00047000;Ch0
07`K0;?0003b>000o`<00>=]001HZ00006@o000D;@000QT001D^001U?P1NZP00i6T00?l2003`?@00
ZKh0001i8000:C`000<K00098`00DTd07ID00=FH003k4P00nA/00<nY0009S@0004M;0007800011d0
03A200223`36`000mB/00?h8003MPP00>9h0001JB0003BL0008J000P=`00Lb`0T[P00>i7003o0000
if4006N]0000Ic`001D_00026@005Bh006Hm06F/003VHP00o`000>i7002A^000078]000O=P000QX0
00hX001LAP13XP00h7P00?h4003b=@00/l00001k7P00:C`000<K000:9@00ED/0;9X00=^9003m2@00
mBX00<K10000PA800350000470002280055=01jF003GT`00o0h00?LS0039^00008D:000e@`0011d0
00LQ001>CP0HT`00eIP00?`?003h8@00b[H000252000=T<000@M00078@00Cdh06I@00=JF003l3P00
mb<00<Vi0000Q0`003=2000470002280055=02:G003IS`00o@/00?HY0036`P0007lE000]?P000a/0
00XT001FB`0bW000gH400?h6003c=000/<00001h8P0093T000<J000>:000GDH0C:D00>=^003o0@00
kTD008fg0000Kc8001Xb00026@0052d006Ll076`003ZE@00o`000>MN001RZ`0006=0000A:`000QT0
01lf001d:@2S_000lCT00?h5003NOP00<id0001EB`002B@000@L002K000b@@00Q0/0bkD00?PN003k
5000dJD000B;0000?DH000DM00078@00D4h08iL00=Z:003n2000lc400;700000Mb@0024g00026P00
42X006=006F/003YFP00o`000>QM001PZ`000652000?:@000QX002@i05nO403e:`00o@`00=JE000D
TP0004I;00067`001R0004a=01bE003ISP00o@T00?@a002^_`0007HW000O=P000QT001</001W?01g
/@00k4d00?l1003SKP00AJ<0001IB@002bD000<K000c@@00QPL0cZd00?XG003i7@00b[L000224@00
;3h000<K000=9`00GTD0F:P00>MP003o0000j5d005bZ0000Gd@000dX00036P00;3d0084A0<Zf003i
7000nQP00<ba0000Q0`002ho00036`003BL005i505VY003WGP00o`000>MQ001EY`0005a6000<9P00
0a/0035100261P3?Z`00na@00?LQ0036`00007`K000U>@000QX0014[001W?01k/P00kDP00?l2003O
NP00;i/0001AC@001b4000DN0018C00MU@00fXT00?h5003a?@00SkL0001/=P005Bh0008I000Q=`00
NB40`l@00?LT003k4`00cjX000262000;cl000<K000=:000HD80Ijd00>]B003o0@00hG<003NN0000
Dd`000LQ00057P00BD`089H00=b5003n1000kd<0086d0000Ic`0014[00026P00:3/0084B0<^c003j
5`002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l001/c001W>`1EY`00
gg/00?d:003h7P00dZ8001nF0000EdX000hY00026@0052h0061303bP003JR`00na400?XE003GT`00
<I`0001LAP004R/0008I000A:`00FdL0;i/00=JE003j5P00na400=V<000jW`0005m4000C;@000QT0
010Z001JB00[VP00eYL00?XF003k4@00fH`003VO0000GTD001</00026@004B/005a7036L003HTP00
na<00?/D003GT`00;i/0001KA`0042X0008I000D;@00H4<0@J400=b5003l3@00nA`00=:Q000LU@00
05E<000<9`000QX001Xb001X>`1LZP00hW400?h5003e:P00b[L000>;0000BD`000PR00036`009CT0
07</08Be003YE`00o`000>m1002]_`0007hI000b@@001Ad000DN000hA000PA40^l800?4i003o0@00
if4007>`0000KC<001le00036P002bD0059=01RC003BX`00nA/00?`?003IS000=9d0001KA`003bX0
008I000G<000ICh0EjP00>5b003n1@00m2d00<Rm0000Q`H003m70006800011d00310001m6`2]_`00
l3h00?<`001d/00006dd000M=0000QX000`V001FB`0UV000eYH00?/C003j5`00dih001^D0000DTd0
00XT00036P008SP0078]08Re003[DP00o`000>a<002A^00007@Y000T>@000a/000XT001AC@0HT`00
dil00?XG003k5000eIT0022F0000Dd`000/U00036P008SP007<[08fg003/C@00o`000>YC0023]000
070`000O=P000QX000`V001GBP0/VP00fHh00?`>003h7`00cZh000J<0000AT/000LP00047@00<T40
080E0;k3003c<`00oP@00>5d001>Y@000652000B;0000QT001L`001X>`1X[@00iV800?l1003_@`00
WK/0001f9P009CX000<K000:9@00E4`09YP00=RA003l3P00n2000<f`0001RP00045800067`001Ah0
03U500262039^@00mRH00?d:003JR@00;i/0001GBP002bH000<J000T>@00MRL0W[/00>m1003o0@00
iFP005fZ0000I3l001<]00026@005c0006Ti06n_003XF`00o`000>a>0026]@0006la000L=0000QT0
010Z001OA01=Y@00hW400?l3003a>`00Ykd0001h90009CT000<J000<9P00F4X00?<0=Yh00=f2003n
1`00m2l00<330000OQP002`n00036`002B@005=<02NI003IS000o@/00?HX0037_`00084A000a@000
11`000PR001AC@0QUP00f9400?d<003f9P00b;d000223`00<T4000@L00088P00DDd08YL00=R?003m
2`00mRL00<K00000PA<002lo000370002B<005A<02^J003KR000o@P00?@^002n``0007`K000Y?000
0a/000/V001HB@0lX000ggX00?h4003a>P00Y;d0001e:0008CL0008J000?:@00H4<0EZP00>EW003o
0000kD`008:d0000K3H001P`00026@005Rl006Xh07bb003/CP00o`000>IU001HZ0000613000?:@00
0QX0028h001g902^_`00lc<00?h7003LQ@00:YX0001BC@00228000@L000g@`00Q`@0cJh00?TI003j
6000cZ`000280P00>4@000@M00088P00Ddd0:iX00=b3003n1P00lSL00:Fm0000M2T001he00026@00
4R`006Hm072_003ZD`00o`000>IT001FZ00005i4000>:0000aX002Pk06>P3@3f9P00o0l00=BL000<
S`00045800057P001b40051>02BH003KQ`00oPH00?8f002S_00007<[000L=0000QT001D^001Z>022
]000kTL00?l2003QM@00>il0001FB`002B<000@L000gA000R@00d:L00?/C003h8@00akd0001o5`00
:3/000<J000>:@00HD80HZ/00>UI003o0000iV@005:W0000G4H000`V00036`00<40008D:0<f`003j
6000nA`00<Zh0000PA8002Xm00036P003RP0065206>/003YE`00o`000>EX001;Y00005Y8000:9@00
11`003I30029003AY000o1000?HV0031a00007TQ000Q=`000QT001<]001Z>@26]@00kd800?l4003M
P@009YP0001?CP001R0000HO001>CP0UV000gH800?l4003_@`00Q;D0001Y>P004R`0008J000T>@00
O1/0akl00?PO003j5P00c;4000233P00:cd000<J000?:@00Hd00L[000>a<003o0P00ggX002jK0000
D4d000LP00067`00Cdh0:9T00=in003o0P00kDT007Ja0000I3l000lY00036P00;3h008@<0<j]003k
4`002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l001he001Z>01OZP00
hG@00?h7003g8`00cjT001NC0000E4`000dW00026@005c0006=004JS003LQ000o0h00?TI003EVP00
:9T0001IB00042X0008I000C;@00GTD0>9h00=V>003k4P00naD00=NC000aW00005a7000A:`000QT0
018/001MAP0dW@00f9000?/C003k5000ei<0032L0000FdL0014[00026@004b`005i403ZO003JR`00
o1000?XH003EVP009YP0001HB@003RT0008I000F;`00Hd00Bj@00=in003m2P00n2000=2X000DTP00
059=000;9@000QX001dd001[=`1W[@00i6X00?l4003d;`00akd000281000@dT000LQ00047000:3/0
07HW092h003[D@00o`000>i7002Q_00007XN000^?`0011d000HO000mAP00Q0/0aL<00?<c003o0`00
iFP006R]0000JSL001`c00026P0032H005E;022F003DW000nQL00?/B003GT`00:iX0001HB@003RP0
008I000I<P00J3X0HJ/00>A[003o0`00lc<00<G30000P`d003Y500067`001Ah003A20020502i`P00
lST00?8d001Y[@0006Xh000J<P000QT000hX001HB@0^V`00f8l00?`?003i6`00dJD001:A0000D4h0
00TS00036`009CX007DX09>h003]B`00o`000>]C0025]@00074^000Q=`000aX000/U001DC00QUP00
eIP00?/C003j5`00dj0001NC0000DDd000TS00036`009SX007HV09Rj003^A`00o`000>UJ001h/@00
06dd000L=0000QX000hX001JB00eW@00fhL00?d;003g9000bk@000290@00@4P000HO00057@00=T<0
08<>0<K1003d;@00oPH00=mk0014XP0005i5000@:P000QT001Xb001[=`1c/000j5/00?l0003]B@00
T[P0001c:`008SL000<J000<9P00EdX0;i/00=Z:003m2`00mb@00<Zg0000Q`D003a600057P001Ql0
03i700290@3</`00mb400?`=003HT0009YP0001DC0002R@000<K000W>`00NB40ZKh00?4k003o0P00
hfh005:W0000HD80014[00026@006S8006`f07Zb003ZE000o`000>YD001k/P0006`f000I<P000QT0
018/001R@@1GZ000i6X00?l1003_@@00W;/0001e:@008SL000<J000=9`00FdP00=H0?j400=mk003n
1@00lc@00;C10000Nah002Pl00036`002bD005I;032L003LQ@00oPP00?D]0033a00007hG000]?P00
0a/000XT001DC00ZV@00fXX00?d9003e:`00aL<0001o5@00;Sh000<K000:9000E4`0:iX00=^8003m
2@00mBd00<;40000OQT002/m00036`002RD005I:03BM003MP@00oPH00?<c002b`00007TQ000U>P00
0aX000dW001KA`15X`00hG<00?l2003`?`00VKX0001b;0007SD0008I000A:`00Hd00HJ/00>MP003o
0000je8007Na0000JCX001D^00026@006C4006dd08Ne003]B000o`400>=/001>Y@0005e6000=:000
0aX002Hj001j7`2j`P00m2h00?d9003IS0008IL0001@CP001b4000DM000kAP02RP00d:L00?XE003i
7000c;<000252@00<d4000@L00098`00ED/0=Id00=il003o1000lCd009Vj0000LBh001/c00026@00
52h006Tj07^b003/C@00o`000>A[001<Y@0005a7000<9P000a/002`m06BN2P3g8@00na800=6S0005
R`0003a600047@002280059=02fK003MP000oP@00?4l002G^P00070`000J<P000QT001L`001]=02=
]`00kd400?l3003OO000<Y`0001CC000228000@M000lAP07S000dj000?`?003f9P00aL@0001k7@00
9CT0008J000@:P00I3l0KJh00>]C003o0000i6X004RT0000FDP000/U00037000=48008P30<nY003k
5000n2400<Nn0000OQT002Lj00026P0042X006@o06j_003[D@00o`000>=_0011X@0005M:00098`00
11`003]500N=003DW@00o0d00?D[002e`@0007HV000N=@000QT001H_001]=@2A^000lC`00?h5003K
R0007YD00019C0001Al000LP001AC@0^V`00gg/00?l2003]B@00NK80001V?@004B/0008J000W>`00
OaD0bKP00P3i6`006`3:]`00080E000W>`000QX0014[001V?01m/`00kTH00?l3003MP@009IP0001=
CP001Ql000LP001AC@0aW000h7L00?l1003[C`00Jjh0001Q@P003RP000<K000`@000Q`D0dJH00?`@
000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0MP008CL006dd06V]003S
K@00oPD00?HX003=/0003i00001AC@002bH0008J000I<@00ISd0D:H00=im003m2`00n1d00=:R000O
UP0005M:000>:0000QT001D^001Q@P12X@00fhL00?`>003j6@00eIX002RI0000FDT000lY00026@00
52d0061303jP003JR@00o0l00?XH003EVP009iT0001IB@003bT0008I000E;P00HD80A:800=b4003l
3@00nA`00=:Q000MU@0005E;000=9`000QT001Pa001V?@1EY`00h7L00?h7003g9@00cJl000b>0000
Cdh000XT00036P0083H006hc076`003VI000o`800?<e0035a00008@;000nA`001R0000@L000/?P00
NB40Vk/00>e:003o0000k4d009Ji0000Mb@002Xl000470001b40049900281038_000m2h00?h4003R
K`00GJX0001W>`006C40008I000>:000F4X0:IT00=NE003k4`00nQH00=FJ000RU`0005E;000<9P00
0QX001`c001[=P1/[P00iV@00?l2003b>000^/8000204`00=D<200057P0l000iA000P`h0a<@00?<c
003a>000GjX0001W?0006340008I000?:@00FdL0=ih00=^8003m3000n2000<j/000:SP0004]=0008
8P000a/002Tl001h8`2N^`00kTD00?l0003YFP00N[80001^<P007SD0008J000<9`00EdX0:YT00=RA
003l4000nA`00=2W000?T00004i>00088P000a/002Xl001i8@2T_@00kd400?l1003WH@00KJh0001Z
>0006C80008I000?:P00GDH0?j400=f0003n2000mRT00<Rk0000QPP003]50P001Ah0o`00>dD008H8
0<Rk003f:000o@T00=f2000kW`0005]7000>:0000QX001`d001^<`1n/`00jUD00?l0003/C`00QkD0
001`;`007cD0008J000=:000FTP0>9h00=b3003m2@00mBT00<Nm0000Q0`003M300057@001R0004A:
00F<003>[000nAd00?/A003FU`007ID0001AC@002B<000<K000[?@00O1`0]L400?8e003n1000hGH0
04RT0000GTD000lY00026@0073@006la08Fe003/CP00o`000>QK001`[`0006Ti000G<0000QT001@]
001U?P1RZ`00iV<00?l0003^A`00T;P0001a;P007SD0008J000?:@00GTD0BJ@00>5c003o0`00lCX0
0:Rn0000N2@002Di00036P0032H005U903ZO003NOP00oPH00?<b002g`@0007/M000Y?0000a/000/U
001GBP0cW@00g8<00?h7003d<000^l80001l6`00:S`000<K000;9@00EdX0=9d00=f1003n1P00lc80
0;K10000NQl002Lk00036P0032H005U903fP003ON@00oP@00?4i002V_@0007HV000R=`000QX000hY
001NA@1?YP00hf`00?l1003^AP00SKL0001_<@006c<0008I000C;@00ISd0Jjh00>UI003o0000jET0
06b^0000ISd001<]00026@006c<0070`09:h003_@P00o`800>5c0014XP0005Y8000<9P000a/002Tl
001m6@35a000mRT00?d<003GT`006I<0001<C@001b0000DN0011B00:SP00dZ000?/B003h8@00bKT0
00224000;cl000<K000;9@00F4T0?Z000>5e003o0P00kd<008jg0000KS<001Ta00026@005c0006`f
08Je003^A`00o`400>9b0012XP0005U9000;9@000a/0031006JL1`3i7@00nQH00<nZ0000R08003M3
000470002B<005E;03JN003ON@00o`<00>m2002<]`0006dd000G<0000QT001Xb001`<02I^P00lC/0
0?h5003LP`00:IT0001AC@001b4000DN0011B@0?T000eIT00?d<003e:`00^L80001h8P008CL0008I
000B;000Ic`0N;400>a<003o0@00hW4003jP0000EdX000TS00047000>D@00h/00=:R003l4000mRH0
0<C40000NQh002<h00026P004R`006Ll07Vb003]B`00o`400>5f000gWP0005A<00088P00?@001Ad0
041800n@003FUP00o@X00?@`002Z_P0007<[000K<`000QT001Pa001`<02M^`00lSH00?h8003HT000
5I800014B@001Ah000PR001DC00hWP00hG@00?l1003/C`00KZl0001S@0003bT000<J000[?@00PPl0
c;400?XG003h7`00akh0001l6`0093T0008J000C;000JCT0R;H00?10003n1@00fhP001fE0000Ad/0
00DN00088@00E4`0>il00>9`003o0000jUH0062[0000GTD000`V00036`00=D800XX00=>O003l3@00
2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l002@i001`;`1d/000iFH0
0?l3003e;@00b[L000N<0000Cdh000XT00036P0073<006Tj05ZY003PMP00oPP00?LR003?Z@005i<0
001DC00032L0008I000H<000I3l0C:D00=eo003m2`00nAd00=:Q000OUP0005I;000>:0000QT001H_
001S@018X`00gH800?d<003i7000dZ4001jE0000ET/000dW00026@005c0006@o04jU003NO000o@X0
0?PQ003@Z0005I80001BC@002bH0008J000K<`00JCT0GjX00>9`003n1@00mBX00<Zf0004R`0004Y<
00098P000a/002<h001a;`1l/`00j5d00?l1003a>`00^/8000214@00>D@000HO00057@00<D0007`L
0:Nm003_A000o`000>YD002:]P0007@Y000V>P000a/000PR0018B`03R`00b[H00?HX003n1`00h7H0
05>W0000I3l001H_00026@003bT005]803>M003IS@00o0l00?TJ003BX@006I@0001CC0002bD000<J
000O=P00KS80Mk400>QN003o0@00l3h00:jo0000OAT0035000047@001Ql003i700261`37_P00m2d0
0?0l001DY`0006@o000E;`000QT0014[001NA@11X@00gH400?d9003g9@00c;<000>;0000ADX000LQ
00047000;Ch007/M0:Zn003`?`00o`400>MP001_[`0006/g000K<`000QT000hX001IB00cW@00fXX0
0?`=003h8000cZh000N=0000B4/000LQ00047000;Sl007`K0;30003a>`00o`800>EW001RZ`0006Ll
000G<0000QT0014[001P@`19Y000h7P00?h6003d;P00a/8000233`00=T<000DM00067`00@4P008T0
0<^d003g8`00o@/00=Z9000aW00005Q9000=9`000QX0020f001a;P29]P00k4h00?l0003ZEP00Nk80
001]=00073<0008I000?:@00GDH0@Z400=ml003n1P00m2l00<G40000PA80039100047@001b4004U<
00f?003AY@00nQP00?/D003CWP005I80001?CP00228000@L000_?`00OaH0`L@00?@`003n1P00gWd0
03jP0000FdL000hX00026P007cH0078]096h003^B000o`000>IR001U[00006Hm000E;P000QT001H_
001X>`1/[P00j5`00?l0003/CP00QKD0001^<P0073<0008I000A:`00H4<005H0DjL00>=/003o0P00
l40009fk0000MBT0024g00026P003RP005a704>R003PM`00o`@00?8h002[_P0007PS000U>@000aX0
00`V001IB00lX000gg/00?h5003b=P00[kl0001i8@009SX000<J000<9P00FTP0?J000=mj003n1000
lSP00:Zn0000Mb@002<h00036P003BP005a604NS003QLP00o`800?0o002K^P0007<[000O=@000QT0
010Z001Q@P1JZ@00iFD00?l0003/C000P[@0001/=@006340008I000E;`00JCX0M[400>]B003o0000
iel0066[0000Hd00014[00026@007SD007<[09jk003a?000o`@00=mj000jW`0005M:000;9@000a/0
02dn00214`37_@00mb@00?`?003DV`004I000016B`8000HO09/004I;01:A003EV@00o0h00?HU0036
`00007lF000[?@000a/000`V001KA`18X`00hfh00?l1003]B@00Pk@0001[=`005Rl0008I000I<P00
Kc40TKP00?10003o0`00ggT003RN0000ET/000XT00047000=480IiX30?XH003i6P00c;4000252@00
<T4000<L000:9000F4T0@:400>9b003o0@00kDP0086d0000JSP001D^00026@007C@007<[0:Fm003b
=@00oPL00=Z:000PUP0004i>000680001Ql004M;01NC003HT@00o@T00?@`002^_`0007DX000N=@00
0QT001@^001Z>023]000kTH00?l2003PN000=Id0001DC000228000@M000nA`0;SP00e9/00?`=003e
:`00^<40001g900083H0008I000D;@00JST0Q;D00>m4003o0`00gWd002jK0000DDd000LQ00057P00
ATX05i<00=V?003n2000lSH009jk0000L30001Pa00026@006c<007</0:Rn003d<@00o@X00=JG000=
S`0003i700047@002B<005I:046Q003SK@00o`000>YF001S[0000613000=9`000a/002lo0026203?
Z`00na<00?LT0034a00007TQ000Q=`000QT001D^001/=@2C^@00lCX00?h7003HS`0059800011B@00
11d000TS001GBP14XP00i6T00?l0003XG@00EZP0001KA`002bD000@L000jA@09S@00eYP00?d:000:
ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0B`00:3/007<[07nc003WG`00
o`800?<c0037_@0008T00019C0002B<000<J000O=P00K3H0IJ`00>=_003n1P00mRL00<f_000>S`00
055=000;9@000QX001Xb001W?01FZ000h7P00?d9003g8P00d:P001JB0000Dd`000`V00026P006C40
06Hm05:W003ONP00o@T00?PQ003@Z0005Y80001CC00032H0008J000J<P00Ic/0F:P00>5e003n1`00
mRD00<f_000=S`00051>000:90000aX001he001/=@1Z[P00i6T00?l3003d;`00b;d000280P00A4X0
00PQ00036`009SX007@Z08Rf003ZEP00o`000>m1002^_`0007hH000d@P0200057P3o000e@`00OaD0
/l000?0n003o0000j5X007nc0000LBh002<h00036`002B<004i>00Z>003=[`00mb<00?d9003NO@00
BJ@0001R@P0052h0008I000A:`00GTD0?:000=^6003m3000n1h00=2X000AT@00051>000:90000a/0
028h001a;P22]000jEL00?l0003^A000Xk`0001j7`00;3h000@L00078@00A4T008T00<Zg003f:000
kd4004ZT0000HD8001<]00026@004bd0065204^T003ONP00oPL00?DZ0039^P0008P40010B0001R00
00@M000a@@00OQL0]/400?4i003o0P00iFL006B/0000J3X001Pa00026@0042X005a603bP003LP`00
o@X00?LU003;]@0008T00012B@001R0000@M000b@@00OaD0_<800?8e003o0`00hfh005RX0000I3l0
01@^00026@004bd0069105>W003RL@00o`@00?<d002m``0007lE000a@@0011d000LP0016B`06S000
cZd00?PN003l3P00f90002RI0000ED/000/U00036P008cP007@Y09Bi003^B000o`000>QM001`[`00
06Xh000I<@000QT0014[001P@`1<Y@00hGD00?h4003c=000^L80001n6@00;Sl000@L00088P00Cdh0
5I800=>N003k5000nQP00=6U000=S`0004U<00078@0011d003A200223`36`000mBX00?d8003LQ000
=Id0001HB@0032H000<J000S>000MBP0W;/00>m1003o0@00i6T005ZY0000Hd00018/00026@006C40
06/g07Na003ZEP00o`000>YD001j/P0006/f000I<@000QT001</001S@01MZP00iFD00?l1003^AP00
TKP0001a;P007SD0008J000?:@00Gd@0CJD00>9`003o0P00l3h009nk0000MBP0028g00026P003RP0
05a604JS003QM000o`<00?4k002S_@0007HW000R>0000QX000hX001LAP17X`00hG<00?l3003`?P00
W[/0001d:@0083H0008J000?:@00Gd@0DJH00>A[003o0@00kTD008ng0000L30001`c00026@004R`0
06@o06B/003WGP00o`000>]C001g/@0006Ti000F;`000QT001P`001/=P21]000k4`00?l0003UIP00
EjP0001P@`003bT0008J000R=`00MRH0Z[h00?8f003n1@00gH40036L0000ED/000TS002V00047000
<T4008@<0<Zf003h7`00na<00=:R0009S@00041800057P001b0004a=01ZD003GTP00o@/00?D[0030
``0007`L000W>P000aX000dX001NA@1BY`00iFL00?l0003/C`00Mk40001X>P0052d0008I000L=000
LRd0WK/00?4j003n1@00gH0002nK0000Dd`000PR00047@00>D@0J9T00?/D003h7P00b[P000224000
;Sl000<K000<9P00FdL0BZ@00>A[003o0000k4l007Fa0000Ic`0018/00026@0083H007HV0;30003d
<000o@X00=RA000GT`0004Q;00067`001R0004e>01nF003JRP00oPL00?8f002R_000078]000K<`00
0QT001L`001]=02>]`00l4000?l4003MP000;9X0001AC@001b4000DN0013B@0CT@00ei@00?d:003d
<000[;l0001d:@007C@0008I000F;`00KCD0SkP00?0n003n1000g8@002FH0000Cdh000HP00067`00
C4d089H00=^7003n1@00lC`009:h0000KC@001H_00026@007SD007HW0;C1003e:`00o0d00=>N0005
S00003U4000470002R@005U904^T003UIP00o`000>QM001IZ00005e6000<9P000a/003A200290@3A
Y000o0l00?HY002h`P0007HV000M=0000QT001L`001`<02O^`00lc@00?d9003FUP0038l0000lAP00
11`000XT001JB01>Y@00iV800?l0003VI000C:D0001IB@002B<000@M000oA`0AT@00f9000?h700[o
oooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o000/?@00MbD0RkH00>UH003o
0@00lSP00<G40000QPL004=900088P000a/0028h001_<P1`[`00iFP00?l4003e;000b[H000J<0000
CTh000XT00036P007C@006Xh066[003RL@00oPH00?HV003=[`003Xl0001AC@002bD0008J000K<`00
JCX0G:X00>5c003n1`00mRH00<f_000=S`00051>000:9@000aX001dd001Z>01S[000hfh00?h5003e
:`00b[H000F<0000Bdd000TS00036`008CL006la07Fa003VHP00o`800?8e0035``0008D:000oA`00
1b0000@L000Z?@00Mb@0TkT00>a?003o0000kTL00::l0000Nah002lo00047@001Ql003Y500223`2o
``00lSP00?l1003WH@00M;00001^<`007cH000<J000:9000DDd04i400=2X003h7`00o@`00=b5000o
X@0005m4000B;0000QT001<]001Q@`16X`00gWl00?d9003g8`00cJl000V=0000C4d000PR00036`00
9SX007@Y08jg003[D000o`000>e;002G^@0007LU000X>`000a/000PR0019C007S000cK000?LS003]
AP00@:40001NA@004B/0008I000E;`00I3l0EJL00>5b003n1@00m2l00<K00000Q0/003]500067`00
1Ah003I300224@32a000lc<00?l3003SKP00FZT0001U?P005Rl0008I000A:`00Gd@0AZ<00=ml003n
1`00mBX00<Rk0000QPL003e600067`001Ah003M300233`35``00m2l00?h5003PMP00CJD0001Q@P00
4R`0008I000F;`00ICd0GJX00>AZ003o0P00lCX00;700000O1/002dn00047000228004a=00j?003@
YP00nAX00?/B003FV0007iH0001BC@002R@000<K000V>P00Mb@0X;`00>m1003o0@00iV@006F/0000
Ic`001H_00026@004bd006=105JX003SK@00o`800?4j002]_`0007XO000Z?0000a/000TS001BC@0N
U@00eYL00?/A003i7@00cZ`000F<0000@dT000HO00057P00>D@008D80<Vi003f9@00o@/00=Z;000[
VP0005E;000;9@000a/002Hj001h8P2X_P00lC/00?l2003RL000D:H0001P@`0042X0008I000K<`00
KS<0Pk@00>a?003o0000j5/006j_0000J3X001H_00026@005Bh006Hl003c06R]003WGP00o`000>a=
0025]@0006hb000K<`000QT0014[001R@P1HZ000i6T00?l1003^A000TkT0001b;@007SD0008J000?
:P00Gd@0D:H00>=]003o0P00kd8009Rj0000Lb`001lf00026P003bX005m405:V003SK000o`400>m4
002B^000074^000M=0000QT0014[001R@@1LZ@00iV@00?l0003]C000Pk@0001]=0006C40008I000D
;P00Ic`0Kjl00>UG003o0000jET006b^0000ISd001<]00026@006S8006la08fg003^A@00o`400>=]
001<Y@0005e6000=:0000aX002Di001i802f`@00m3000?h8003KR0009iT0001BC@00228000@L000f
@`00Q`D0cK000?TJ003j5P00cjT0006:0000>dD000@M00088@00D4h08iL00=Z;003m2000m3000;C1
0000N28002<h00026P003bT0065205fZ003WH000o`000>YF001/[P0006Dn000B;0000QT001lf001e
:02Y_P00lcD00?h7003KQ`009IP0001@C@001b4000DM000nA`1]U`00na400?LS0037_P0007lF000Z
?0000aX000dW001NA@1DY`00iV@00?l0003ZEP00JZh0001T?`0042X0008J000S>000NB00_<<00?DZ
003l3000eIP000n@0000@TT000DN00078@00D4d0:9T00=b3003n1@00lC`009Ji0000Kc4001Pa0002
6@006C40070`09Zj003a>P00oPH00=^7000RU`0004i>000680001Ql004U<01^D003IS@00oPL00?8f
002P_000074^000J<P000QT001Ta001`<02K^P00lSP00?h7003JR`0079D00019C0001Ql000LP001@
CP0YV@00gH000?l3003_@P00QkD0001Z>00052d0008I000Q=`00NB40`<<00?HV003k4@00dJD00029
0@00=48000<K000;9P00G4H0EZP00>MO003o0000iV<004jU0000FTP000XT00047000>D@01X`00=BL
003m3000m2h00:bo0000Lb/001Xb00026@006S8007</0:^n003d;P00o0`00=BM0004R`0003M30004
70002bD005a605VY003XF`00o`000>A[0012X@0005I;00088P001Ah004E:01ZD003JR@00oPD000[o
oooo0Ol00001ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00007ooooo`03
o`000?oooooooooo00Oooooo0;T00310001j802G^@00je400?l0003`?P00^L8000233P00?TL000LP
000370009SX0078]07^b003WH@00o`800?<b0037_@0008T00018C0002B<000<K000P=P00KC@0Jjh0
0>AZ003n1000mB`00<Zf0006S00004e>00098`000aX001he001/=P1W[@00hf`00?h4003e:`00b[H0
00F<0000C4d000TS00036P0083H006dc06j_003UI`00o`<00?@`0038_@0008P20015BP00228000<K
000U>@00LR`0P;@00>QK003o0@00lC/00;[20000PQ0003Y500067`0011d002lo001j7`2O^`00kDT0
0?l0003/C@00U[T0001h8`00:cd000@L00078000?dP008H80<K1003c<P00o`<00>AX001Y[@0006/g
000L=0000QX000/V001DC00KU000dZ400?TJ003l3`00fH`003FM0000G4L0010Z00026@005Rl006A0
052V003PN000oPL00?HX003:]P000HX00016B`001b4000@L000Z?000N2@0VKX00>e:003o0000je40
08^f0000M2X002Di00036`002B<004m>00n@003?Z@00n1h00>];000fWP0005]7000?:@000QT001Pa
001W>`1PZ`00i6/00?l3003c=@00`<<000214P00=T<000DN00067`00>dH008D:0<No003d;P00oPD0
0>1f001?YP000691000C;@000QT001@]001R@@1@YP00hG@00?h5003d;`00aL8000233P00>4@000DN
00067`00?4H008H80<Rl003e:P00oPL00=im0013XP0005i5000@:P000QT001Pa001Y>P1X[@00iV<0
0?l1003`@000YKd0001i8@00:C`000<K00098`00D4h05Y<00=>O00020?XF003o0=>O000FTP00051>
00098`000a/002Xm001j7`2/_`00lC/00?l2003TJ`00FjT0001T?`0052d0008I000E;P00ISd0HJ/0
0>EV003o0@00l4000:6l0000Mb@002Hj00036`002RD005A<02NI003HS`00o0d00?LQ003;/`0008P2
000nA`001Ah000DO000nA`00R@40c;800?PP003l3P00ei8002:G0000Ddd000TT00036`00:Sd007/M
0;C1003b=@00oP@00>1g0015X`0005e6000?:@000QX001he001a;P2>]`00kDP00?l0003VHP00Hj`0
001U?P0052d0008I000G<000JCT0Lk000>UH003o0000jU<007Zb0000JcH001Pa00026@004bd006Dn
06:[003VHP00o`000>e;0028]P0006lb000K<`000QT0014[001R@@1KZ@00iFH00?l0003^B000S;L0
001`<00073<0008I000A:`00HT40G:X00>IT003o0000kDX008Ne0000KS<001Xb00026@004bd006Dn
06J]003XG@00o`000>]B001h/@0006Xh000F;`000QT001L`001Z>01j/P00je400?l0003WH000HJ/0
001S@0004B/0008I000M=@00LRd0VKX00?0o003o0P00hGD004:R0000FTP000`V00036`00:C`007dJ
0<;4003e:`00o@X00=R?000NUP0004m>00078@001Ad003]6006:003?Z@00nQH00?TK003=/00008L6
000f@`0011`000TR001CC00/VP00g8@00?h6003b=P00Z;h0001e9`0083H0008I000A:`00I3l0Ijd0
0>UI003o0000j5d0066[0000HT40010Z00026P008SP007PS0;G1003d;`00o@T00=V?000MU@0004e>
000680001Ah004A:07>E003l3@00mRP00<?40000O1`002Hj00036P003bT0065205nZ003XG@00o`00
0>QL001PZ`000652000?:@000aX002Lj001m6P35`P00mbD00?`@003CX0001h`0000mAP0011d000PR
001CC00bW000gg`00?l3003_@P00R[H0001/=P005Rl0008I000L<`00Lb/0Y[d00?<d003n2000fHh0
01ZD0000B4`000HO00068000Cdh099P00=b5003n1@00lC`009Bi0000KS<001L`00026@006c<007<[
0:Nm003c<P00o@T00=NB000CT@0004=900057P00224005==03:L003ON@00o`80000h0>e8001k/P00
06Ll000B:`000QX002@i001l6`36`000mb400?/D003>[00008D9000`@0000a/000dW001OA01PZ`00
jEP00?l0003TJ`00A:80001GBP002B<000@M000nA`0>S`00eYD00?d9003c=000X;`0001`<0006300
008I000M=000MRL0]l400?HY003l4000dJ@000280P00<T4000<K000=9`00Gd@0I:`00>YD003o0000
hW8003RN0000Dd`000LQ00057P00BTd08iL00=f2003o0`0:ooooo`7o00000Oooool000Oooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Oo
oooo040003E2001m6P2R_000kDX00?l0003^A@00[Kl000205@00>D@000HO00047000:S`007DX08Je
003YFP00o`400?8h0035a00008H80012B@00224000<K000T>@00L2l0Mk400>IS003o0P00lc400<Nm
0000R@4004M;00088P000a/0028g001_<@1b/000iFD00?l3003d<@00b;d000290@00AT/000PR0003
6`008cP0074_07Vb003WH000o`800?8f0035a00008D90010B0001b0000@L000Y?000MBL0S;L00>YD
003o0000kd400:jo0000OQL003E20P001Ah0o`00<d4007dI0:^n003_@P00o`000>YD002:]P0007DY
000W>`000a/000PQ0015BP00R@40bKX00?D/003n1@00hVl005jZ0000J3/001Tb00026@003BL005I:
02BH003EV@00nQH00?/C003GT`00;9X0001IB@003RP0008I000H<@00Ic`0FjT00>9`003n1@00m2h0
0<Rm0000Q`D004180007800011`002ho001k7P2U_@00kd<00?l0003YF000P;<0001`;`008CL000<J
000:9000DTd05i<00=:R003i6P00jU0002fK0000F4T000dX00026P006c<006Xh06^^003VI000o`40
0?4k002c`00007hH000a@00011d000HP0011B000R0<0bKP00?HX003n2000gWd004FS0000Gd@0014[
00026@005Rl006Dn05^Y003SK@00o`<00?8e002l``00080D000c@@0011d000HP0011B000R@00bkD0
0?LU003m2P00g8@003VO0000FdL000hY00026@006c<006`f07>`003XG000o`000>i6002I^P0007HW
000U>P000a/000XT001CC00OUP00eYP00?/B003i6P00d:H000j?0000Bdd000PQ00047000;cl007hI
0;S2003b=@00o`@00>9b001@YP000652000B;0000QT001P`001Y>P1[[P00iel00?l0003^AP00U[T0
001d:P008SP000<J000<9P00EdX0<9`00=^8003m2P00mRH00<Vj0000Q@T003Q400057P001R0004=9
00J<003?Z`00nA`00?/B003EVP006I@0001@CP00228000@L000^?`00OaH0`<<00?@`003n1P00gWh0
03^O0000FTP000dW00036P008SL007@Y09Zj003_@P00o`400>AY001IZ@000691000B;0000QT001Xb
001]=@1o/`00je400?l0003YFP00Kjl0001X>P005Rl0008I000E;`00J3/0KJh00>QK003o0000je40
07bc0000K3H001Ta00026@004bd006Dn06J/003WG`00o`000>a>0020]00006`e000I<@000QT001<]
001U?P1W[@00j5d00?l0003[D@00Nk80001[=`005c00008I000E;P00J3X0L[000>YF003o0000jET0
06f^0000Ic`001@]00026@006C8006dd08Je003]BP00o`000>EW001FZ0000613000?:@000QX0024g
001e:02T_@00lCT00?h4003OO000>9h0001GBP00<@002bD000<K000]?P00P1@0akl00?HV003l3P00
eYL001JB0000BT`000HP00057P00@DP02Hd00=:Q003k4P00n1l00<Zg0000P`d00350000370002R@0
05I;03FN003NO000oP@00?4l002L^`00078]000M=0000QT001<]001W?01c/000je800?l0003VI000
EjP0001OA0003RP000<J000V>P00Nad0`L@00?DY003m3000eYH001BB0000Ad/00P001Ql0OP00BT`0
N9<00?d:003d;@00]l40001h8P008SP0008J000A:`00I3l0JZd00>YF003o0000iV<005FW0000GTD0
00dW00036P00:cd0080D0<Rk003h8000na<00=2W0000R@0003M4000470002B<005I;03^O003QM000
o`400>e8001o/`0006Tj000D;@000QT001lf001f9P2b`000m2h00?d;003FUP004I400012B@001Ah0
00LQ001BC@0]V`00gWh00?l3003_@P00R;H0001[=`005Bh0008I000N=@00MRH0/l000?D]003m3000
eIX000^>0000?TL000@M00098`00ED/0?:000>9b003o0@00k4l0072_0000I3l0010Z00036P00:3/0
07lE0<Vi003i7000nQT00<^c0000PQ0002/m00036P003RT0069106^^003[D@00o`400>9b000jW`00
05A<00088P001Ah004A:01JC003ISP00oPL00?4j002D^@0006dd000E;`000QT0020f001i8@33a000
mb@00?/C003>[00008D:000^?`000aX000hX001R@@1_[`00k4d00?l1003ON@00;Y/0001@CP001R00
00HO001?CP0/VP00gg/00?l200[ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00Oooooo1?l00006ooooo`3o000jA@00P1<0[kl00>m4003o0000kD/0
0:6l0000O1/003A200057P0011d002ho001h8P2B^000je<00?l0003`?P00^L8000233`00?DH000LP
000470009c/007@Z08:d003XG000o`400?8g0035a00008H80011B@001b4000<K000U>P00LRd0O[<0
0>MN003o0@00lSH00<G40000Q@T0045800078@0011`002Lk001d:P25]@00jET00?l0003a?000^/80
00224000>TD000HO00047@00;Ch007TR09Rj003/C@00o`000>i8002R_00007/M000`@00011d000HO
000hA000PA80]l400?4l003o0@00j5/007nc0000LBh002<h00036`002B<004]=00J<003;/`00mRL0
0?h7003PM`00DjL0001U?P005c00008I000?:@00FDP0;I/00=NB003k4P00nQL00=FJ000RU`0005I;
000=9`000QX001/c001Z>01V[000i6T00?l3003c<`00aL@000243000>dD000HO00057@00<T4007hH
0;70003`?@00o`400>MO001d/00006dd000N=@000QX000`V001DC00PUP00e9/00?XF003YEP0099L0
001EB`0032H0008J000N=@00KC<0M[400>QM003o0000kd400:Nm0000Nah002dn000470001b4004I;
00B;003</@00mb<00?d:003LQ000>il0001LAP003bX0008I000H<@00J3X0IZ`00>EV003o0P00lC/0
0;300000O1/002ho000470001b4004M;00J<003=[P00n2000?`=003JS000<9`0001HB@003BL0008J
000N=@00Kc80Ok<00>YE003o0000k4d008fg0000Lb`0028g00036P002bH005I;02RI003HT000o0h0
0?PO003>[@001X`00015BP001b0000@M000c@@00PA80a<@00?@`003n1P00ggT004JS0000GTD0010Z
00026@006S8006`f07Na003YF000o`000>a=002:]P00074_000O=P000QX000dX001JB00jW`00gH40
0?h8003e;000a/4000224000<d8000@M00078@00BD`03Xl00=6T003j5`00nQH00=:Q000AT00004]=
00078@0011d003=100224036`000mBX00?d9003KQP00<Y`0001GBP002bH000<J000U>@00Mb@0Y[d0
0?4l003o0P00hW0004jU0000Gd@0010Z00026@007C@0070`001<08Zf003]BP00o`000>MQ001T[000
06Dn000D;@000QT001Pa001[=`1i/P00jU@00?l0003YF000LJl0001X>P005Rl0008I000F;`00J3X0
LJl00>UH003o0000jUD007Fa0000JCT001H_00026@005Rl006Pj07:`003ZE`00o`000>UH001`[`00
06Pk000E;P000QT001P`001[=`1m/`00je000?l0003WH000HZ/0001T@0004R`0008I000L=000L2l0
T[P00>m3003o0@00hfh004^U0000GDH000hX00036P0093T007PR0;70003c<`00oPH00=b3000^V`00
05A<00098`0011`0035000233@39^000n2400?/A003CWP003Hl00014BP8000HO0:D004M;016A003E
VP00o0l00?LT0037_P00080C000]?P000a/000/U001IB@0oX@00hGD00?l2003_@P00T;P0001_<@00
6S80008I000E;`00JSP0O[<00>e<003o0@00i6/004bU0000G4L000`W00036`00:S`007lG0<K0003g
9000o0l00=BM000<SP00045800057P001b0004m>07jA003n2000lc<00:^n0000MBP001le00026@00
4b`006Ll07Fa003/C`00o`000>A[001:Y00005]7000;9P000a/002lo00233@3;]000nA/00?XG003=
[P0008H7000c@@000a/000/U001IB@15X`00hfd00?l0003/C`00Lk00001V?@004B/0008J000R>000
NB00_/<00?HY003l3P00e9d000V=0000?DH000@M00088P00E4`0=ih00>1g003o0P00kDT007fc0000
J3/001</00026@008SL007TQ0;o3003f9`00o0l00=:Q0003R`0003Q4000470002R@005Q904JS003T
JP00o`000>YF001U[0000652000>:0000aX002`n00233P3</P00nQP00?TM0039^P0007lF000W>`00
0QX0010Z001U?P1f/@00kDX00?l2003ON@00<9`0001AC@001b4000DO001:C00OUP00fhH00?h5003`
@000R;H0001Z>0004bd0008I000S>000O1/0akh00?PO003j5`00c;<000224@00:S`000<J000@:P00
ICd0N[800>i7003o0`00gH0002FH0000C4d000HO00078@00DTd0=Id00>5c003o00001oooool4o`00
007ooooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`1[000oA`00P`d0^l800?0n003o0000je8009Fi0000NB4002lo00057@00
1Ah00391001l7@2N^`00k4`00?l0003_A000[Kl0001o5@00>4@000HO00047@00:cd007LU08jg003Z
E@00o`000?0m002i`P00088?000lAP001R0000@L000Y?000MBL0RKH00>UG003o0000lCd00;W20000
PQ0003]50006800011`002/m001g9@2A^000je800?l0003_@P00[Kl0001o5`00=D<000DN00057@00
<D0007`L0:Bm003^A`00o`000>a>002F^@0007PS000/?@0011`000HP000mA`00Q0/0a<@00?8f003o
0P00iV8007>`0000KS80020f00036P002R@0051>00j?003>[000mb800?d:003NOP00BJ@0001R@@00
52h0008I000A:`00G4H0=ih00=Z;003l3`00nA/00=:R000IU00005=<000;9@000aX001he001]=01a
[`00iV800?l1003a>@00^L8000204`00=T<00P001Ah0o`00=d<0084A0;k3003b=`00o`800>EV001Y
[@0006Xh000K<`000QX000dW001GBP0YV@00ei<00?/B003WG0006i@0001CC@002bD000<J000Q=`00
LBl0PK@00>YF003o0000kTL009^k0000Mb@002Pk00036`00228004a>00b?003?ZP00n1h00?`>003J
S000<I`0001IB@003RP0008J000K<`00K3H0LK000>MO003o0000kd400:Bm0000NB4002Xl00036`00
228004e>00n@003@Y`00nA/00?`@003GT`009YP0001EB`002bH000<J000Q=`00LRd0RkH00>a>003o
0000jU<008:d0000Kc4001he00026P003BL005Q903:L003JR@00o@/00?LS003;]00008T1000oB000
1Ql000DN000hA000Q0/0akh00?DZ003n2000gH4003^O0000FdL000hX00026P007C@006la08:d003[
D@00o`000>YD001n/`0006hc000L<`000QT000lY001MAP14XP00ggT00?h5003c<@00_/<0001o5`00
;cl000@L00088P00Cdh05Y800=BM003k4`00nAX00=2X0009S@0004E:000680001Ad003Q400252@39
^@00mbD00?d<003IS@00:9T0001DC0002R@000<K000Y?000Nah0//000?8f003n1000h7P004BR0000
G4H000hX00026P0083H007<[09Ji003_A000o`400>AX001IZ@000691000A:`000QT001/c001^<`24
]@00k4d00?l0003WG`00IZ`0001U?P0052d0008I000H<@00JcH0O;<00>]A003o0000j5`006Z]0000
ISd001@^00026@00634006`f07jc003[D000o`000>MO001U[00006Dn000C;0000QT001Xb001^<P29
]P00kDT00?l0003UI`00EjP0001P@`0042X0008J000O=P00M2X0WK/00?0m003o0`00h7H0046Q0000
FTP000`V00036P00:3/007`L0;g3003d;@00o@T00=Z;000UV000055=00088P0011`003I300261P3<
/@00nA`00?XE003AY@001H`0000nA`001Ah000LP001=CP0JU000ei<00?d<003e:@00a<@0001m6P00
:C`000<J000<9`00G4L0BZ@00>=^003o0@00kDP008Fe0000K3H001L`00026@00634006dd08Zf003^
A@00o`800>5b0012XP0005U9000;9@000a/002ho00224000QP39^@00n1l00?/C003AY@0018/0000k
AP0011d000PR001BC@24S`00oPD00?4i002O^`00078]000L<`000QT001D^001Z>021]000kDT00?l1
003RLP00@:40001HBP002R@000@L000c@P00QPH0cZd00?XG003i7000bkD000233P00;Sl000<K000<
9P00G4L0D:H00>EV003o0000jUH006R]0000Hd0000lZ00026P009SX007dJ0<K1003g8`00na400=6T
0001RP0003Q4000470002R@005M:046Q003RK`00o`400>a?001a/00006Dn000@:P000QX002Dj001l
6`36`000mb800?/C003@Z00008P4000c@P000a/000/U001KA`1AYP00iV<00?l0003XG@00FZT0001N
A@0032L000<K000a@000QPL0cj/00?/D003g8P00a/40001l70008cP0008J000B;000J3X0P[@00>m4
003o0`00gH4002NI0000Cdh000HO00068000Cdh0:9T00=io003o0`00kTH007fc0000Ic`0014[0002
6P009c/007lE0<Zg003i6P00nA`00<Vj0000OQL002Hj00026P004R`006Tj08Je003`@000oPD00=^8
000LU@0004I;00057P00228005E;03nQ003SK000o`002_ooool1o`00007ooooo0007ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00Oooooo0?l004E:00271@35``00lSL00?l1003YF@00RKH0001f9`00:cd000@M00067`00=d@007lF
0:Zn003^AP00o`000>e;002Q_00007`L000c@@001Ah000DM000`@000NQl0V[X00>a>003o0000kd@0
0:fo0000OaH003M300067`0011d002dn001i8P2E^@00je000?l0003_@`00[Kl0001o5P00=T<000DN
00057@00;cl007XO09fk003]B`00o`000>e9002Q_00007/M000`@0001Ad000DN000f@`00OaH0/<00
0?10003o0000jUD008Zf0000MBP002Lk000370001b4004=900271037_P00m3000?l3003TJ@00J:d0
001[=`007C@0008J000;9@00Ddd05i<00=6U003h7@00o0d00=^6000nX00005m4000B;0000QT001</
001OA011X@00g8<00?d;003h8000cjT0016@0000D4h000XT00036P008CL0070`07bc003XF`00o`00
0?0o002]_`0007dJ000a@00011d000HO000lAP00Q@X0a/400?@a003o1000hfh005jZ0000Ic`001Pa
00026@003bT005Y803>M003IS000o0h00>EQ000BT@00051>00098`000a/002@i001d:P2=]`00k4l0
0?l0003/CP00SkL0001d:@009CT000<K00098`00D4h05I800=:S003i6P00na400=NC000WV@0005I;
000<9P000QX001he001_<P1m/`00jEP00?l0003^B000V;X0001f9P009SX000<K00098`00DDd05i<0
0=>O003j5`00na@00=FJ000MU@00059=000:90000a/002Di001e:02F^@00kTP00?l0003XFP00M[40
001/=@006c<0008I000?:@00FdL0?:000=f1003m2000mRT00<Rk0000Q@P003Y500057P001Ql003e7
0027103:]`00mbD00?d;003KR000<Y`0001HB@0032L000<J000P=`00LRd0S[L00>e;003o0000j5/0
07>`0000JSL001Ta00026@004B/0061304nU003RLP00o`<00?8g002b`00007/M000Z?@000a/000TS
001BC@0OUP00eYD00?`@003h7P00cJl0006:0000@4P000HO00057P00?DL008T10<bb003h8000o0l0
0=ND000OUP00055=00098`000a`002dn001n602o``00m3000?h6003NO`00>Yl0001IB@0032L000<J
000S>000MRH00?<0X[`00?0m003o0P00hW0004jU0000Gd@000lZ00026@007SD0074^092h003^AP00
o`400>EW001KZ@000691000A:`000QT001/c001_<P28]P00kDX00?l0003VH`00GjX0001S@0004R`0
008I000K<`00Kc80RKH00>e9003o0000iFH005ZY0000HD80014[00026@007C@0074^09Fi003_@P00
o`800>=_001<Y@0005e5000>:0000QX002<h001g9@2Z_P00lSL00?h5003NO@00=ih0001GBP002bD0
00<K000/?P00OaH0a/800?HX003m3000ei8001bE0000Cdh000LQ00057@00>dH008X00<nZ003j5`00
nAT00<j]0000R08003U400047@002240051=02>G003JR`00o@T00?@_002h`@0007XP000U>@000aX0
00hX001OA01DY`00iFH00?l0003/C`00NK80001Y>P005Bh0008I000K<`00L2l0U[T00?0o003o0`00
ggX003RN0000ET/000XT00047000<d4008D90<bb003i6`00nQL00<j/0000R0<003I3000470002B<0
05E;08Z<003o0`00l3l009:h0000Kc8001Ta00026@005c0006dd08bg003_@P00o`<00=mi000fWP00
05E;00098`0011`003Q4002:003@YP00na<00?PQ0038_00007lE000Z?0000aX000hX001OA01KZ@00
iel00?l0003XG@00GJX0001P@`003RP000<J000Z?000P1@0bKX00?PO003j5@00cZ/000271P00<d40
00<K000;9@00FTP0Bj@00>EX003o0000jUH006J/0000HT8000lY00036P00:C`0080D0<Vj003h7@00
nQL00<f`0000Q0/002lo00036`003BL005i505^Y003XG000o`000>IT001?YP0005]7000;9@000a`0
03E30029003AY000o1000?HW002n``0007PR000P=P000QT001D^001[=P2>]`00l3d00?h5003KR000
7YD00019C0001Ah000LQ001BC@0bW000h7P00?l1003/C@00LK00001S@0003bT000<J000[?@00P`h0
cK000?XF003h8000a/40001k7@008SP0008I000D;P00K3H0TKP00?4j003n1`00f8l001>A0000@4P0
00@M00098`00F4T0BZ@00>IU003o00002_ooool1o`00007ooooo0007ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Oooooo01l0
04]=006:0038_000lc400?l2003WH000OK<0001c;0009cX000@L00078000?4H0088@0;O1003`?`00
o`000>]A002D^@0007TR000^?`0011d000DN000e@P00OAT0Y[d00>i7003o0000kDX00:2l0000O1`0
0391008000DN00T00391001l702R_000kDT00?l0003]B@00XK`0001k7@00<D000P001Ah0H`00=480
07hI0:Vn003^A@00o`000>a?002E^@0007PS000/?P0011`000HO000kAP00PPl0_L<00?4j003o0@00
j5`007jc0000LBh002@i00036`00228004U<00>;003:]`00mB/00?h5003RL@00GJX0001X>`006S80
008J000=9`00ED/089H00=BM003j6@00o1000=V=000dW@0005a7000@:P000QT001D^001R@@1;Y@00
gg`00?d8003g9@00cK0000R=0000C4d000TR00036`009CT007<[08Rf003ZE000o`000>i6002Q_000
07XP000/?P0011`000LP0012B@00R0<0bKX00?D[003n1P00hGD005>W0000I3l001D_00026@004B/0
05e503fP003LQ000o@/00>=X0009S@0004]=00088P000a/002Pk001g9@2I^P00kDP00?l0003ZE@00
Pk@0001a;P008CL000<J000;9@00Dd`07YD00=BK00020?XE003o0=BK000NU@0005=<000;9@000aX0
028g001b;@29]P00je400?l0003/C`00S;L0001c;0008SP000<J000;9@00E4`089H00=FH003k4`00
nQP00=:R000DTP0004m>00098`000a/002Tl001h8P2S_000kd400?l1003VH@00Jjh0001Y>@006340
008I000@:P00GT@0AZ<00=mj003n1P00m2h00<G20000PQ0003E200057@001R0004=900>;003=[`00
n2000?`>003HT000:9T0001EB`002bD000<J000T>@00MBL0V[X00>m4003o0000iV8006N]0000Ic/0
01H_00026@004bd006=005VY003TJ`00o`800?0m002V_@0007PS000V>P000a/000XU001EB`0XV@00
fHh00?d<003g8`00b[L000261P00>TD000DN00067`00@dT01H`00<n[003i6`00na<00=BL000FTP00
04i>00088P0011`0039100214@36`@00mBX00?d9003KQ`00<9`0001FB`002bD000<K000W>`00NB00
[kl00?8g003n1000h7L004>R0000G4L000hX00026P008CL007@Y09bk003`@000o`800>=^001@YP00
05m4000?:P000QX001he001b;@2D^@00kd@00?l1003TJ`00E:L0001P@`0042X0008I000N=@00LRd0
UKT00>m2003o0@00hfd004nV0000GT@000lY00026P008CL007DX0:6l003a?000o`<00>1f0012XP00
05Y8000<9`000aX002Hj001j7`2f`@00m3400?h7003LQ@00;I/0001DC0002B<000@L000`@000PPl0
b;/00?LS003l3`00eIX001>A0000BD`000HP00057P00@DP028d00=:S003k4`00n1h00<^d0000Q@T0
03A2000470002B<005=<02fK003LQ000oPH00?<e002[_`0007HV000Q=`000QX0010Z001R@@1OZP00
iel00?l0003ZEP00KJh0001U?@004R`0008I000N=@00LbX0X[`00?8h003n1@00gH4002jK0000Dd`0
00PR00047000>4@008T10<nZ003j5P00nA`00<^c0000Q0/0035100036`002R@005Q:092:003o0P00
kTH008Ne0000K3H001H_00026@006S80070_09Vj003a?000oP@00=f1000/VP00059=00088P001Ad0
03i700R=003CW`00o0l00?HV0035``0007`K000V>P000QX000lY000<001R@@1V[000jEP00?l0003V
I000DZL0001LAP0032H000<K000^?`00P`d0bk<00P3i6P00E03</`0008<=000^?`000a/000`W001M
A@1FZ000if400?l0003XG@00FjT0001NA0003BL000<K000]?P00P`h0c;800?XI003i6`00b[L00021
4P00:Sd000<J000>:000HD80IZ`00>YE003o0000i6/004FR0000F4X000XT00047000>TD01hd00=BL
003l3@00mB`00;;00000MBP001dd00026@005c0006lb09Zj003b=`00oPP00=R?000ETP0004=90005
7@00228005E;03bP003RL000o`000>YD001V[0000613000=:0000a/0031000261`3?Z@00na800?HU
002o``0007PS000O=@000QT001L`001_<@2N^`00lc@00?d:003FU`002hh0000kA@0011`000XU001K
A`1DY`00j5d00?l000[ooooo0Ol00001ooooo`002?ooool2o`0000Wooooo0ol00008ooooo`03o`00
0?oooooooooo00Oooooo0500051>00V=003;]@00mB`00?l4003UI`00LK00001_<@008cP000<K0008
8@00@TT008D80<?4003b>@00o`400>UI0028]P0007DW000Z?00011`000HO000jA@00PA80/l000>m1
003o0000je4009Bi0000N28002dn00047@001Ql003M3001o5P2^_`00kd800?l0003[D000U;T0001h
8`00;Ch000@M00067`00>D@0084B0;G1003`?P00o`000>YF0029]P0007DX000X>`0011`000LQ0011
B000QPP0a/800?<d003o0P00iV<007:`0000KS80020f00036P002B<004m>00^>003=/000mRD00?h8
003PN000DZL0001U?P005c00008I000>:000F4T0:IT00=JF0080na@009X0eiD002ZJ0000FDT000hX
00026@005c0006Hm05JX003QM000oPH00?DZ003:^00008X00016BP001b4000<L000Y?000MbD0U;T0
0>a=003o0000k4d009Bi0000MRH002Pk00036`00228004Q;00B;003;/`00mRH00?d8003NO000B:@0
001Q@P004bd0008I000C;000H4<0Aj<00=im003m2000hFh0006:0000ADX000LQ00047000;3h007XO
0:Jm003_@P00o`000>QL001g/@0006hc000N=@000QX000`V001FB`0WV@00ei@00?/A003i6@00dZ80
01FB0000D4d000TS00036`009CX007DX09Fi003]BP00o`000>YF0020/`0006la000O=@000QX000`V
001FBP0ZVP00f9000?`?003i7@00cjT000b>0000Bdd000PQ00047000;Ch007`L0:no003a>`00o`80
0>AY001OZP0006Hm000F;`000QT0018/001R@P1AYP00hG800?h4003c=000_<80001o5P00<40000@L
00078@00BD`02hh00=2X003i6`00na400=JG000OUP00059=000:90000a/002Pk001i8P2W_@00l3h0
0?l2003TJ@00G:T0001T?`0052d0008I000F;`00IS`0I:`00>IS003o0@00kd@009Vj0000MBP002<h
00036P0032H005Q:03:L003KQP00o@T00?HY0037_P0008<=000e@P0011d000LP0019C00>S`00dJ<0
0P3j5`00o`3AX`003Hl00018C0001b0000@M000g@`00Q@X0bKX00?LU003m3000fHh002JH0000Dd`0
00XT00036`00:cd007dJ0;_2003d<@00oPH00=io000iW`0005U9000<9P000aX002Di001h902Y_P00
lCT00?l3003QM@00AJ<0001LAP003RP0008J000R=`00MBP0X;`00?0m003o0P00hW8004VT0000GDH0
00hX00026P008CL007DX0::l003a?000o`<00>5e0014XP0005]7000=9`000aX002@i001h8`2]_`00
lSH00?h5003NO@00>9h0001GBP002bD000<K000Z?@00OAT0`l@00?D[003m2P00fH`002BG0000DDd0
00PR00047000=D<008H80<^d003h7P00na<00=:Q000;SP0004=900057`001Ql004M;016@003DV`00
o1000?LR0038^`00088@000_?`000a/000XT001FB`0fWP00gW`00?h4003a>`00Wk/0001c:`007SD0
008I000B;000ICh0JZh00>UH003o0000j5d006:[0000HT40010Z00026P008CL007LU0:jo003c<P00
oPL00=Z9000TV000051>00078@001Ad003e600J<003BX`00na800?PP0039^P00084B000]?P000a/0
00`V001KB02FR@00o`400>a<001k/P0006Pj000D;@000QT001dd001d:P2U_@00lSH00?h7003KR000
8iL0001?CP001b0000DN0013B@0AT000eYL00?d<003e:`00^/80001i8@008SP0008J000A:`00ICh0
LK000>]A003o0000i6/004NS0000FDP000/U00036`00<d4008L60<j/003j5P00n1h00<Vj0000P1@0
02Xl00036P003RP00613066[003YF@00o`000>IT001@YP0005]7000;9P000a/0039100261P3?Z`00
naD00?PP0037_P0007hH000V>P000QX0010Z001T?`1b/000k4h00?l1003QL`00>Yl0001EB`002280
00DM0010B00?T000eYD00?d:003c<P00YKd0001b;@006S80008I000J<P00LRd0Y[d00?<a003m2P00
eYL000b?0000?DH000@M00098`00F4X0AZ<00>AY003o0000j5/005^Y0000GDD000`V00036`00=480
08T00=:R003l3P00mB/00;;00000M2T001`c00026@006C80078]0:Zn003d;P00o0d00=>N0002R`00
03I300036`001@0032H005i505nZ003ZEP00o`0000[ooooo0Ol00001ooooo`007_ooool00ol0003o
ooooooooo`07ooooo`3o001CC@0BT@00cZh00?HV003n1P00hfl006J/0000K3D001lf00036`002B<0
04Q<00290@37_P00lc<00?l2003WH000O;<0001b;@009SX000<L00078@00?dL008@;0;o3003a>P00
o`400>UH0028]P0007DX000Y?00011`000HP000lAP00P`l0^l800?4l003o0000jEL008Rf0000MBP0
02Pk000470001b0003i700242`32a000lSP00?l1003XG@00OK<0001a;P0093T000<K00088P00Ad/0
08T00<Rk003d;P00oP@00>A[001W[@0006/g000M=0000aX000/U001BC@0CT@00cjT00?PP003m2P00
gH0004NS0000HT8001@^00026@0042X005]703>M003ISP00na400?XH003DW0008IH0001FB`003BL0
008J000J<P00JCX0HJ/00>=]003n1000m3000<No0000QPH004180007800011`002dn001j802Q_000
kTH00?l0003ZE000R;H0001c:`0093T000<K00098`00CTh038l00<j/003h8@00o@/00=b4000nX000
05i5000A:`000QT001D^001T@01BYP00hGD00?h6003OM00008L5000oA`001R0000@M000a@000OQP0
//000?4k003o0@00iV<006b^0000JSL001/c00026@003RP005U9036L003IS000o0h00?PN003?ZP00
3Hl0001=CP00228000<K000Y?000NB80XK`00>m3003o0000j5d007B`0000K3D001`c00026P003RP0
05U803>M003JR@00o@`00?LR003</@000h/00014BP001b0000@M000a@000OaH0_<800?<e003o0`00
hW0005BW0000Hd0001<]00026@005Bh006Dn05bY003TJ`00o`800?4j002__`0007/M000/?@000a`0
00PR001?CP0DT@00dZ400?XG003j5@00dil001JB0000Cdh000PR00037000;3h007`L0;?0003b=`00
o`<00>9a001AYP000652000B;0000QT001Pa001Z>01`[`00j5`00?l0003]B`00SKL0001a;P007cH0
008J000=:000FdP0?:000=io003n1`00m2h00<C40000P1@0031000047000228004m>01JC003DW000
na<00?TK003?Z`001H`00012B@001Ql000DN000lAP00R0<0c;<00?PP003l3`00eYH001fE0000D4d0
00PR00047000<400080D00250<G3003e:`00o@T00=^6000_V`0005I;000;9@000a/002Tl001k7P2e
`@00lc<00?h5003NO@00>il0001IB@0032H000<J000U>P00N280[Kl00?8g003n1000ggX003jP0000
FTP000`W00036P009CX007TR0:jo003b=P00oPD00=il000jW`0005Q9000;9P000a/002Pk001k7@2j
`P00m3000?h7003LQ@00;Y/0001DC0002R@000<K000_?`00PA80akh00?HV003l3@00ei@001^D0000
CTh000LQ00057@00>TD008T00<j/003i6@00nQL00<nY0002R`0003e600057P001b0004e>01ZD003G
U000o@`00?HX0035`P0007hG000[?@000a/000/V001IB@11X@00hGD00?l2003_@@00TkP0001`<000
6c<0008I000D;P00J3X0M[400>]A003o0000iV@005NX0000Gd@000hY00036P009CT007XO0;_2003e
;@00o@X00=R@000KU00004a=000780001Ah004=900j?003DV`00o0l00?HU0036`@0007hH000Y?000
0aX000dW001NA@2LQP00o`000>YC001_[`0006Dn000B:`000QT0020g001g9@2a`000m3000?d9003H
T0006Y@0001:C00200067`1/001:C00JU000f9000?d9003d<@00[[l0001f9`007cD0008I000C;@00
J3X0OK<00>e:003o0@00hG<003fP0000ETX000TS00047000>4@00HX00=6U003k4P00mb<00<K10000
OAX002Hj00026P0042X006=006b^003[DP00o`000>=/0015X`0005Q9000:900011`003M3002:003A
Y000na400?HU0034a00007XO000S>0000QX0018/001X>`1n/`00kTL00?l2003ONP00<9`0001BC@00
1b4000DN0016B`0HT`00fHd00?h7003b>000VKX0001_<P005c00008I000M=000MBP0/l000?D/003l
3@00dil000B;0000>4@000@L000;9@00FdP0DJH00>IQ003o0000iV80052V0000FTP000XT00047000
>TD028d00=FJ003m2`00m3000:Jm0000LBh001Ta00026@0073@007DW0;O1003f:@00o1000=2V0000
Q`@0035000036`003BP0065206^^003/C`00o`402_ooool1o`00007ooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0?l005I;01^D003@YP00n2400?d8003PMP00FjT0001Y>@0073@000<J000:9000
CTh01X`00<Zg003e;@00o`@00>EW001a[`0006la000R>0000a/000PR0015BP00Q`@0a/000?<d003o
0P00iel007bb0000LRd002Di00036`001b40049900261`35``00lSH00?l1003WG`00O;<0001b;@00
93T000<K00088@00A4X008P40<No003c<P00o`<00>EU001a[`0006hb000P=`000aX000TS001=CP07
S@00bk@00?HX003n1P00hG8005^Y0000J3/001Xb00026P0032H005A<01bE003BX@00nA/00?`>003K
Q`00?J00001NA0004R`0008I000B;000GT@0?J000=^7003l3@00nA`00=6T000HT`0005=<000;9@00
0aX001dd001/=@1][P00iFD00?l2003b=@00`/@000233P00>TD000HO00057@00<D4007dI0:fo003`
@000o`000>QK001l/`00070`000Q=`000aX000XT001AC@0ETP00dJ@00?TL003l3P00fH`003BM0000
FdP000lY00026@00630006Ll05fZ003SKP00o`@00=ak0000P`d003Y500057`001Ah003I300214P2o
``00lSD00?l3003TJ`00H:/0001W>`006300008I000@:P00G4H0>il00=b5003m2`00mb<00<ba0004
R`0004I;00078@0011`002hn001l702]_`00lCd00?l1003VI000J:d0001Y>@006C40008I000?:P00
GDH0?Z000=f1003m2@00mRL00<Zh0000R0@003m700067`001Ah003I300223`35`P00m2l00?h5003P
N000BJ@0001P@`004B/0008I000G<000J3/0Ijd00>IS003o0@00l4000:>l0000N2<002Pk00036`00
2B@0059=01fE003EV@00na800?TJ003@YP003Hl0001:C0001b4000@L000a@000OaD0`<<00?<a003n
1@00h7P004JS0000GTD0010Z00026@006c<006dd07bb003ZE@00o`000>]B0021]00006hb000L=000
0QT000lY001NA@17X`00h7L00?h4003c=000]l40001l6`00;3d000<K00098`00DTd07iH00=ND003l
3`00n2000<bb0000R08003e600057P001Ql0049900B;003>Z`00nA/00?/C003DW@005980001=CP00
1b4000@M000d@P00P`d006T0b;`00?HV003m3000fHh002JH0000Dd`000TS00036`00;Ch007hG0<;4
003d;@00oPP00=b5000aW00005I;000;9@000a/002Tl001l702i`P00m3400?h6003MP@00=9d0001G
BP002bD000<K000Y?000O1`0^l800?@`003n1`00g8@0032L0000ED/000XT00036`00;3h007lF0<G3
003e:P00o@X00=V=000TV000059=00088P0011`003A200242`3:]`00n2400?`@003DW0004Y400018
C0001R0000DN0010B007S000dJD00?XE003i6`00cK0000271000=d@000@M00088P00DDd08iL00=V<
003m2@00m2d00;c30000Nad002Lj00036P003BL005a604^T003SK@00o`400>i80027]@0006de000H
<@000QT001L`001[=P22]000kDX00?l1003SK000C:D0001LAP003BL000<J000Y?000OAT0aL<00?HW
003l3@00eIP001:A0000AT/00P001Ql0R000BD`05i<00=ND003m2`00mB/00;g30000NQl002Di0002
6P003bT006520:>4003o0000j5X006>/0000HT40010Z00026P0093T007XO0;k3003e:P00o0`00=JH
000AT00004A:00057P001b0004m>02>G003KR000oPH00?8g002Q_000078/000K<`000QT001H_001/
=P29]P00kd<00?l3003ON`00<id0001DC000228000@M000mA`09S@00e9d00?`>003f:000_/<0001i
8@008SP0008J000B;000Ic`0N;400>e;003o0@00hG<003^O0000ED/000TS00047@00?4H02Hd00=BL
003l3@00mB/00;O10000MbD001lf00026@0052h006/g08Zf003_@@00oP@00=f2000WV00004m>0006
80001Ql004a=026G003KQP00oPD00?0n002=]`0006/f000E;P000QT0020f001i8P2o``00mRH00?/A
003@YP0008P3000c@@000a/000`V001NA@1LZ@00jEX00?l0003TJ@00AJ<0001GBP002B<000@M000o
A`0@T000ei<00?d8003b=P00VKX0001^<`005Rl0008I000P=P00NB80`l@00?LS003k5000cZd00024
3000;3h000<J000?:@00I3l0M[400>e8003o0`0:ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool0H000FDT099P00=>O003i7000o@/00=in001?YP0006Hm000I<P000QX000/U001A
C@0?T000cK000?HW003n1P00hfl006F/0000K3H001le00036P002B<004]=00>;0039^@00m2h00?l3
003UI`00L:l0001^<P008CL000<K00088P00B4`008T00<Rl003d<000o`<00>EV001`[`0006hb000Q
=`000a/000TS001;C@03R`00b[P00?D/003n1000hf`006J/0000JcL001dd00036P002RD0055=012@
003>[000mb<00?d9003ONP00D:H0001U?P005c00008I000>:000EdX09YP00=FI003j5`00na400=R?
000bW@0005]7000@:P000QT001@^001R@@18X`00gWl00?d:003g8@00cZ/000n@0000D4h000XT0003
6P008CL006la07Vb003WGP00o`400?4l002e`@00080E000e@P8000DN09@003I300214`2j`P00lCT0
0?l1003VHP00L:l0001]=@007C@0008J000;9P00E4`07YD00=BM003j5`00na800=NC000ZVP0005Q:
000=9`000QX001Xb001Z>01X[@00iFH00?l2003FO@00080D000d@P001Ah000HO000kA@00Q0/0a/00
0?@_003n1@00hW8005FW0000I3l001D^00026@004R/005m404FS003NO@00oPP00?HX0039^00008P3
0010B0001R0000@M000b@@00OaD0^/800?8f003o0`00hf`005fZ0000ISd001H_00026@004R/00613
04RT003ON@00oPH00?D/0037_`0008@;000iA0001Ah000DO000lAP00QPL0b;/00?HY003n2000gGl0
03nQ0000G4H000lY00026@006S8006/g07>`003XG000o`000>i7002F^@0007DX000T>@000aX000/U
001EB`0VV000f9400?`?003h7P00cZh000B;0000A4X000HP00057@00=D<008<>0<K0003e:`00oPL0
0=f0000lX00005]7000>:0000QX001he001`<028]P00k4h00?l0003YF@00MK40001[=`006C40008I
000A:`00HD80DJH00>9_003o0`00lCX00:^n0000NB4002Lk00036`002R@005E;02VI003IS@00o@`0
0?LU0039^@0008D:000gA0001Ad000LP0018B`0=S`00dJ@00P3j5`00nP3AY@002hh00016B`001R00
00DN000jA@00Q`D0bk@00?PQ003l3`00eYH001bE0000D4h000PR00047000<D40088@0<No003f:000
o@/00=V<000WV@0005=<00098`000a/002hn001o5P35``00mB/00?d9003JR@00:YX0001DC0002R@0
00<K000]?P00OaD0aL<00?DZ003m2P00fX`002JH0000DTd000TS00047000<D00088@0<Rl003g9@00
o0d00=ND000KU00004m>00078@0011d003U40028103=/000nA`00?/D003AX`002Hd00012B@001Al0
00HO0016B`0?T000e9d00?/A003h8000b[L000243000<T4000@L00098`00E4`0;I/00=b4003n1`00
lc<00:no0000N2<002<h00026P003bT005m405JX003UIP00o`000>a?001j/P0006Ti000E;`000QT0
01Tb001^<P2>]`00kd<00?l2003QL`00@J40001IB@002bD000<K000]?P00PA80b;`00?LR003k4@00
dj0000Z>0000@4P000DN00078000Cdh089H00=V<003m2000m3400;700000MbD0024g00026P004B/0
06@o0:Z3003o0000iV8005RX0000Gd@000hX00036P00:3/007hI0<K1003g9000o1000=>O0008S@00
03i700057@002280059=02bJ003MP000oP@00?0m002E^@0006la000I<@000QT001Pa001_<@2E^@00
lC`00?h5003MPP00:IT0001AC@001b4000DN0013B@0BT@00eYD00?d;003d;P00//00001f9P007cD0
008I000D;P00JSP0Q;D00>i5003o0`00gg/0036L0000DTd000PQ00057P00@TT04I400=NE003m2P00
m3000:^n0000M2X001`c00026@005c0006hc09Ji003a>P00oPH00=Z:000MU@0004U<00067`001b00
051>02^J003NOP00o`<00>i50021]00006Pj000B;0000QX002@i001l7036`000n2400?XE003>[P00
08@;000^?`000a/000hX001Q@P1W[@00je<00?l0003RL@00>il0001DC000228000DN0015BP0IU000
fX/00?h6003`?@00SKL0001[=`0052d0008I000S>000O1/0akh00?PN003j6000bkD000204`00:3/0
008J000A:`00Ic/0P[@00>m2003n100:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool0
1oooool0o`00G4L0;Y/00=JG003j6000o0l00=^60015XP000691000F;`000QT000dW001DC00HT`00
d:P00?LR003m2000h7H005ZY0000J3X001/c00026P002RD0051>00^>003</P00mRP00?h5003SKP00
IJ`0001[=P007SD000<J000:9000CTh028d00<^e003e:P00oPD00>=]001U[00006/g000M=@000aX0
00XT001@CP0<SP00cK000?HV003n1`00hG@005ZY0000J3/001Xb00026P0032H005A<01VC003AY@00
n1h00?d;003MPP00AJ<0001Q@P005Bh0008I000@:P00FdP0;i`00=RB003k4`00nQD00=JG000YV@00
05Q9000>:0000QT001L`001U?P1CY`00h7L00?h7003f9`00c;<000J<0000Bdd000PR00036`0093T0
07</08Fe003ZEP00o`000>m2002Y_P0007`K000`@00011d000HO000lAP00Q0/0aL<00?<c003o0`00
i6X006F/0000JCT001Xb00026P003BL005M:02RI003FU@00na<00?XF003DV`0089H0001EC00032H0
008J000N=@00KC@0M;000>MO003o0@00cgl0001m6`00<40000@M00068000@DP008P30<Vi003e:@00
oPL00=mj001:Y0000652000C;0000QT001@]001R@@1@YP00hGD00?h5003d;P00akl000252P00>dD0
00DO00057P00=d@008<>0<G3003d<000oPD00>5c001BYP0006=1000D;@000QT001@]001S@01CY`00
hW800?h4003c<P00`L@000214P00=48000@M00068000@DP008T00<^d003g9000o@/00=^7000dW@00
05U8000=:0000QX001dd001^<P1o/`00jUD00?l0003/CP00R[H0001a;P0083H000<J000<9`00F4X0
<9`00=Z:003m2`00mb@00<^e0000R0<003i700067`001Ah003]500261`39^@00mRH00?d:003KR000
<I`0001HBP0032H000<J000R=`00LbX0U;T00>i7003o0000if0006V]0000J3/001H_00026@004bd0
06@o05fZ003UJ000o`400>m1002N^`0007HW000T>@000aX000`V001HBP0cW@00g8D00?d9003e:`00
a/4000214@00<T4000@L00088@00CTh05I800=BL003k4P00nA`00<j/0003R`00041800067`001Al0
03m700::0000l`3>[@00nA`00?/C003DW@004i40001<C@001b4000@M000f@`00Q@T0b[P00?LS003l
3P00ei@001fE0000D4h000PR00047000<T4008<?0<Rl003f9P00o@`00=RA000QUP00055=00088P00
11`0039100233P38_000mbD00?`=003GT`007ID0001?CP00224000@M000f@`00Q@P0bkD00?PP003k
4@00e9`001:A0000B4`000HP00057P00?TL00h/00<nY003j5`00nQP00<n[0001RP0003a600057P00
1b0004a=01RC003FUP00o0d00?HU0037_P00080C000^?`000a/000XT001GBP0gWP00gWd00?h4003a
>@00Xk`0001d:@007cH0008I000A:`00Hd00HZ/00>MN003o0000jUH006n_0000ISd001<]00026@00
73@0078]09^j003a?@00o`@00=mk000gWP0005I;000:900011`0039100242`3;]000nAd00?XE003@
Y`000HX0000jA@0011d000PR001BC@0YV@00g8@00?h6003b=`00Y;d0001d:P007SD0008I000C;@00
Ic/0/H000?l0003TJ@00CJD0001LA`0032H000<K000/?P00PA80bKX00?PO003k5000d:L0002:0000
>4@000@L00098`00ED/0=ih00>1i003o0P00kd@008Rf0000K3H001H_00026@006c<0078/0::l003b
=P00oPL00=Z:000OUP0004e>000680001Ql004U<01^D003ISP00oPP00?<d002U_@0007</000K<`00
0QT001L`001]=02@^000l3h00?h4003LP`009iT0001@CP001b0000HO0018C00JU000fHd00?h7003b
=`00W[/0001`;`006C40008I000J<P00LBh0X[`00?<d003m2@00f94001BB0000@dT000DN00088P00
Dd`0=Id00>1f003o0@00k4`007F`0000ICh0010Z00026P00:3/007lE0<Vi003i7000nAT00<^e0000
PA8002Xl00036P003bX006@o07>`003/C000o`800>1i000`W000055=000780001Ql004]=02:G003L
P`00o`@00>m30021]00006Lk000A:`000QX002Lk00205@3:]`00nAX00?TM0038_00007dJ000T>@00
0QT001<]001[=`2?]`00lC/00?h7000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool0
1oooool0o`00Gd@0>9h00=R?003k4`00na800=V=000jW`0005m4000D;@000QT000lY001GBP0QUP00
dZ000?TM003m2`00gWh004jU0000ICh001Pa00026P0032H005=<01BB003?ZP00mb<00?h8003PMP00
FJT0001X>`006c<0008J000;9@00DDd049000<j]003g9@00oPL00>5e001IZ@0006Pk000J<P000QX0
00/V001CC@0ETP00cjT00?PQ003m2@00gg`004nV0000I3l001L`00026@003BP005M:02:G003DW@00
nAT00?`?003JR@00>il0001NA@004R`0008I000B;000GTD0>Yl00=Z:003l3`00nAX00=>O000OUP00
05E;000<9`000QX001Xb001X>P1NZP00hW000?h5003e;000bKX000290@00ADX000LQ00037000:3/0
07HV096h003/C`00o`000>e9002L^`0007TR000/?@0011`000LP0012B@00Q`@0b;`00?D]003n1@00
hW4005VY0000ISd001L`00026@003bT005Y803:L003IS@00o0l00?TK003BX`005i<0001BC@002R@0
00<J000Q=`00LBl0P;@00>UG003o0000b840001i8@00:cd000@L00078@00Ad/018/00<bb003g9000
o@X00=f2000oX@0005i5000A:`000QT001H_001V?@1KZ@00hfh00?l3003c=000`L@000214P00=D<0
00DN00067`00?DH008H70<Rl003e:P00oPL00=mk0017X`0005m4000A:`000QT001H_001V?@1NZP00
i6X00?l2003b>@00]<40001m6@00;cl000@L00078@00Ad/028d00<j/003h7`00o0h00=R?000ZVP00
05I:000<9P000aX0024g001b;@2;]P00k4h00?l0003ZE@00O[<0001^<`007C@0008J000>:000FdL0
>Yl00=f2003m2000mRT00<Rl0000Q@X003Q400057P001Ql00418002:003</@00n2400?`>003HS`00
9iT0001EB`002bD000<K000U>P00MbD0XK`00?10003o0@00iFL005jZ0000I3l001@]00026@005Rl0
06Lk06R]003WH000o`000>i8002A^000078/000P=P000QX000dX001KB00mX000gWd00?h6003d<000
_/<0001n6000;Ch000<L00098`00DDd07iH00=ND003l3`00n2400<^d0000Q`@003Y500057P001R00
04E:00Z>00010=6U0080nQL002/0dJD000Z>0000ADX000HP00057P00?4H008T10<f`003h7@00na80
0=BL000DTP0004a=00078@0011d003M400261`3;]@00n2000?`@003EV0005i<0001>CP001b4000@M
000gA000QPL0bk@00?PO003k4@00e9/001>A0000BTd000LP00057P00>dH008T00<j^003i6`00nQD0
0=6T0009S@000499008000HO0<<004A:00b>003BX@00na<00?PM003</P0008H6000g@`0011d000PR
001@CP0QU`00fHh00?d:003e:`00`/@0001m6P00:C`000<K000<9P00FTP0@J400>5e003o0P00l400
09Ji0000LBh001`d00026@004bd006Hm06f^003YE`00o`000>QM001SZ`0006=0000A:`000QT0020f
001e:02W_P00lSH00?h6003LP`00;I/0001CC0002B8000@L000g@`00R0<0cZd00?XH003i6@00cJl0
00271P00=D8000@L00098`00ED/0<id00=im003o1000l3d009Nj0000L2l001Xb00026@005Rl006Xg
0;Qn003o0@00hW4004:R0000FDT000/U00036`00<D0008@;0<bb003i6`00nQP00<f^0000QPL003=1
000470002R@005Q9046Q003RL@00o`400>e:001l/`0006Pj000C;@000QT001le001f9`2__`00m300
0?d:003GTP005Y800016B`001Al000LP001?CP0TV000fhH00?h5003a>P00V;X0001_<@006340008I
000I<P00L2l0WK/00?8h003n1`00fX/001fE0000BTd000HO00068000CTh099L00=b5003n1@00l3d0
096h0000KC@001H_00026@007C@007DX0:no003d;P00o@`00=FI000;SP0003e700047@002B<005I;
03nQ003SK`00o`000>]C001Y[@000692000>:0000aX002`m00233P3</P00nQL00?PN0038_00007hI
000U>P000QX0018[001W>`1o/`00kTD00?l3003MP0009YP0001>CP001Ql000HP001@CP0/VP00gg/0
0?l2003]BP00MK00001T?`003bT000<J000[?@00P`h0cJl00?XE003g8P00aL<0001j800083H0008I
000F;`00KS<0VkX00?<e003m2@002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo0?l0069104>R003KQ`00o0l00?XG003FU@00<9`0001LAP004R`0008I000@:`00FTP0:iX00=FI
003j6000o0h00=^60013XP000691000F;`000QT000hX001FB`0MU@00dZ<00?PN003m2`00gWh004jU
0000ICh001Pa00026@003BL005A<01VD003AY@00n1l00?d:003NO@00CZD0001T?`005c00008I000=
9`00ET/07YD00=:Q003i7000o0`00=b30014XP000652000E;P000QT000lY001JB00/VP00eYD00?XE
003k4`00f940036L0000FdL0010Z00026@0052h0065204BR003MPP00o@/00?PN003@YP005Y80001B
C@002bD000<J000M=000JcH0JZd00>EX003o0`00lc800<K10000Q@T003m70006800011`002dn001i
802N^`00kDP00?l0003[D000SkP0001e9`009c/000<K00088P00B4/00h/00<^e003f9`00oPL00=mi
001>Y@0006=0000E;P000QT0014[001MA@0lX000fhH00?d<003h8000cjX000j?0000Cdh000TS0003
6`009CT007@Z08fg003[D000o`000<230000MRL002Lk00036`00228004e>00f?003?ZP00n1l00?`=
003JR@00=Id0001KB0003bT0008I000I<@00JCT0Ijd00>EV003o0P00lCX00;C00000OQP003100004
7@001b0004=9002:003;]000mbD00?d:003LP`00?:00001LAP003bT0008I000I<@00JCT0JZh00>IS
003o0@00l3l00:Rn0000NQl002/m00037000228004i>012@003AY@00nAX00?/B003FU`008IH0001C
C0002R@000<K000T>@00MBP0UkX00>i7003o0000j5d007:`0000JcL001Xb00026@0042X005i504FR
003ONP00oPH00?@_0035a000084B000c@@0011d000LP0017B`08S@00cjX00?TL003k4@00eYL001jE
0000DTd000TS00036`00:C`007XO0:jo003a>P00o`<00>9_001BY`000652000B:`000QT001Ta001Z
=`1d/000jET00?l0003/C`00QKD0001_<@007C@0008I000?:@00GTD0B:<00>5e003o1000lSH00;70
0000Nah002Tl00036`002R@005A<02RI003IS@00o@/00?HV0038^`0008@<000e@P0011d000LQ001<
C@0CT@000?<0dih00?/C003i6`00cZd000::0000?dL000DN00067`00@TT01X`00<nY003j6@00nQH0
0=6S000;SP0004E:000680001Ah003e60029003>[P00nA/00?/D003CX0003Xl00017B`001R0000DN
000mAP00RP00cZd00?TK003k5@00dZ<000^>0000A4X000HO00057`00@DP01h`00=2V003j5P00nAT0
0<j[0001RP0003a600057P001b0004Y=01FB003EV@00o0l00?LR0039^P0008<>000b@@0011`000TS
001CC00[VP00fhH00?h7003d<@00]L40001j80009CX000<J000=:000GDH0C:D00>=]003o0@00kTL0
08Zf0000KS<001Ta00026@005Bl006Ti07Vb003[D000o`000>IU001GZ0000613000?:@000QX002<h
001i8P2d`@00m3000?d8003JR`008iL0001@CP001b4000DM000lAP04R`00dJD00?/D003h7P00b[H0
00233@00<40000<K000:9@00F4X0?Z000>5e003o0P00kd@008^f0000KC@001P`00026@00634006hc
0;mm003o0`00h7T003RN0000ET/000TS00047000=T<008P30<n[003j5P00nAd00<Zf0000P`h002ho
00036`0032H005]704bU003TJ@00o`000>]B001`[`0006Dn000A:`000QX0028h001i8@2l`P00mBX0
0?`=003EVP003Hl00010B0001Ah000PQ001BC@0^V`00gWh00?l3003_@@00S;L0001/=@005Rl0008I
000L=000M2X0Z[h00?<a003m2@00ei8001BB0000A4X000DN00078@00DDd0;I/00=im003o0`00kd@0
08Fe0000JSP001@]00026@0083H007PS0;c3003f:000o0l00=:Q0003R`0003Q4000470002R@005U9
04ZT003UI`00o`000>UJ001MZP0005i4000<9`000a/0035000261`3?ZP00na<00?LS0035``0007XO
000R=`000QT001@]001[=`2;]`00l3h00?h5003KR0007ID00018B`001Ah000LQ001CC00fWP00hG@0
0?l1003[D@00JJd0001Q@P003BP000<K000`@000QPH0d:P00?/A003f9`00^/80001f9P007C@0008I
000H<@00LBh0Z;h00?@_003l30002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo0?l006Dn04jU003MO`00o@`00?TK003DW@009YP0001IB@0042X0008I000C;000GTD0=Id00=RA
003k5000na800=V>000iW`0005m4000C;@000QT000lZ001IB@0WV@00e9/00?TI003l3P00fhH004>R
0000HD8001D^00026@003RP005M:02>G003CWP00nAX00?`=003LQ@00@j80001Q@P005Bh0008I000?
:@00FDT0:9T00=FI003j5`00o1000=Z;000iW`0005i5000B;0000QT0014[001MAP0fWP00fHd00?/A
003j5`00eIT002JH0000F4T000hX00026@005c0006@o04nV003ONP00o@P00?LT003=[P003Hl0001?
CP002R@000<J000P=P00Kc80M[400>MP003o0@00lSP00;g30000PQ0003U400067`001Ad00350001m
6P2[_P00kd400?l0003YE`00Pk@0001b;@008cP000<K00098`00CTh038h00<j]003g8P00o@X00=f1
0013XP000613000B;0000QT001<]001Q@`17X`00gWh00?d9003g9@00c;8000F<0000B4`000PR0003
7000:C`007LT09Vj003]B@00o`000;V40000LR`002<h00036`002R@0055=01JB003BX`00nAX00?`@
003HT@00:iX0001GBP003BL0008J000L=000K3D0Lk000>MN003o0000kd400:Nm0000NQl002`m0004
7000224004U<00R=003>[@00n2000?`=003JR`00<Y`0001IB@003BP0008J000L=000KC@0M[400>QK
003o0000kTH009^j0000MRD002Hj00036`002B<0055=01VD003DW@00nQD00?XF003CW`005i<0001@
CP002B<000<K000X>`00NB80Y;d00?10003o0@00iV@006J/0000Ic/001L`00026@004R`00652052V
003QLP00o`@00?<e002i`P0007hH000^?`0011`000PR001=CP0AT@00dZ800?XG003j5@00dil001FB
0000Cdh000PR00047000;Sl007hH0;_2003c<`00oPD00>1g0017X`0005i5000?:P000QT001`c001^
<`20]000je800?l0003ZEP00NK80001/=P006C80008I000A:`00HD80DjL00>=^003o0P00l3d00:Fm
0000Mb@002Di00036P002bH005M:03:M003LQ@00o@P00?D/0035`P00080C000`@00011`000PR001@
CP0LU@0001X0eYH00?`?003h8000bk@000271@00>DD000DM00078000B4/03Xl00=:Q003k5000nAX0
0<n[0003R`0003m800057P001Ql004=900R=003@YP00nQL00?XH003@Z0001X`00011B08000HO0=L0
04=900R=003AY@00nQH00?TI003?Z`000XX0000nA`001Ah000HP0017B`0?T000dih00?/B003h7P00
c;<000261P00=d<000@M00088@00D4h07YD00=RA003m3000mRP00<K10000P1D002dn00036`002R@0
05I:03FM003NOP00oPD00?8g002X_P0007HV000Q=`000QX000lY001P@`1GZ000iFD00?l0003/CP00
OK<0001Z>0005Rl0008I000H<@00K3D0Q[D00>e8003o0@00hf`004bU0000G4H000dW00036P009c/0
07`L0<74003e:P00o@/00=NB000IU00004a=000680001Ah0049900b?003CWP00o1000?LS0037_P00
080D000[?@000a/000`V001KA`19Y000hfd00?l1003]B`00O[<0001Z>0005Bh0008I000K<`00LBh0
aW/00?h5003MP@00;I/0001CC@00228000@M000kAP04R`00dJ<00?/B003g8P00akd0001o5P00:S`0
00<J000=9`00GTD0EjP00>IR003o0000jET006B/0000HT4000lY00036P009SX007`K0<G2003g9@00
o1000=:Q0005S00003]500047@002B<005E;03RN003PMP00o`800>i8001o/`0006Tj000C;@000QT0
020f001g902g`@00mB/00?`<003EVP002hh0000nA`0011d000PR001DC00hWP00hGD00?l1003]B`00
NK80001V?0004B/0008J000T>@00O1`0a/800?LS003k4`00cjT000271000<d4000<K000<9P00G4H0
EZP00>MO003o0000iV8005:V0000FdL000/U00037000=T<008X00=:R003l3`00mRT00;W20000MbD0
01he00026@005Rl006hc09Rj003b>000oPL00=R@000DT@00049900057@002B8005I;046Q003SK000
o`000>UI001MZP0005i5000<9P000a/003E2006:003CX000o0d00?D]002]_`0007<[000J<P000QT0
01/c001e:02e`@00mRT00?`@000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01ooo
ool0E@00JCX0FJT00>1h003m2@00n2000=6U000LU@0005I;000>:0000QT001D^001Q@P0oX@00fXT0
0?`@003j5P00eYH002jK0000FdL0014[00026@004B/005a6036L003GT`00naD00?/B003ISP00>9h0
001NA@004b`0008I000@:P00FTP0;I/00=JF003j5P00na400=V=000hWP0005i5000B;0000QT0014[
001LA`0bW000f9400?/C003k5000ei<002nK0000FdL0010Z00026@0052d00613046Q003LQ@00o0d0
0?TL003BX@007ID0001EB`0032L0008J000I<P00Ic/0FjT00>5b003n1P00mBT00<^e0004R`0004Y<
00088P000a/002@i001b;@22]000jET00?l0003`?`00/<00001n5`00=4800P001Ah0o`00=T<0080C
0;S1003a>`00o`400>MO001g/@0006lb000P=P000aX000XT001AC@0ETP00dJD00?TM003l3@00fXT0
03RN0000G4H0010Z00026@005Rl006@o05:W003PMP00oPH00?DZ0039^@0008P20012B@001b0000@L
000]?P00Nah0Y[d00>m2003o0000/XH0001_<@007cH000<J000;9@00E4`07iH00=BK003j5@00na@0
0=FI000QUP0005A<000;9@000aX0020f001`<01o/`00jEL00?l0003^A`00V[X0001g9@009c/000<K
00098`00Cdh04I400=6U003i6`00o1000=NC000WV@0005I;000<9P000aX001lf001`<022]000jU@0
0?l0003/C@00S[L0001c:`008SP000<J000;9@00E4`08iL00=JE003k4@00nA/00=2V000>S`0004a=
00088P0011`002dn001l702a`000lCT00?l2003SK000FZT0001T?`0052h0008I000D;P00I3l0FjT0
0>A[003o0P00lC/00:bo0000NQl002Xl00036`002B<0055=01ZD003EVP00na<00?TJ003@Y`0038h0
0019C0001b4000@M000c@@00PA40aL<00?@]003n1`00gWl003bP0000FdL000hX00026P007cH0074^
08fg003]BP00o`000>QM001][P0006Pj000G<0000QT001@]001T?`1OZP00iFH00?l1003_A000V;X0
001d:P008CL0008J000=9`00FTP0?J000=im003n1P00lc800;_20000OAX002/m00036`002B@005=<
02JH003ISP00o@`00?HV0038_00008<=000d@P0011d000PQ001>CP0GT`00eIT00?`@003h7`00c;<0
00271000>TD000DM00078000BD`04I000=>N003k4`00nAd00<f`0000R08003]500057P001b0004U<
016A003DW@00na800?PN003</P0008L5000hA00011d000LQ001>CP0IT`00eYH00?`>003g8`00bKX0
00233P00<T4000@L00098`00Ddd0:9T00=Z9003m2@00m2d00;k30000O1`002Pl00036`0032H005Y8
042Q003PMP00o`<00?0n002K^`0007</000N=@000QT0014[001S@01SZ`00ieh00?l0003ZE@00LJl0
001W?00052d0008I000K<`00L300T[P00>m2003o0P00hG@0046Q0000FDT000/V00036`002000;3d0
07lE0<No003g9@00o0l00=FJ000@T00004E:0P001Ql0TP00B4`05I800=JF003l3000mRT00<C40000
O1/002Lk00036P003RP005i505BW003UI@00o`000>]B001b/00006Hl000C;0000QT001he001e:@3>
NP00oPL00=^8000SU`00051>00078@001Ah0045800f?003DV`00o0h00?HW0034a00007`L000V>P00
0aX000lY001Q@P1SZ`00jEX00?l0003WH000FJT0001OA0003BP000<J000Z?@00P1@0b;/00?PO003k
5000cjT000280`00=D8000@L000:9000F4T0@j800>=^003o0@00k4l007>`0000ICh0014[00026P00
93T007/N0<C4003f9P00o1000=:R0003R`0003Q4000470002R@005M:04:R003SKP00o`000>]B001/
[P0006=0000?:@000aX002Pk001o5P39^P00n1h00?XG003=/00008@<000^?`000a/000dW001P@`1Q
Z`00jEP00?l0003TJ@00Aj<0001HB@002R@000@L000kA@09S@00e9/00?d<003d;P00[;l0001c:`00
6c<0008I000I<@00LBh0YKd00?<a003m2P00eIP000^>0000?4H000@L000:9000FDT0C:D00>IT003o
0000if0005:V0000FdP000XT00047000>TD02Hd00=FH003m2P00lc<00:2l0000Kc4001L`00026@00
7cD007PS0<;4003g8`00na@02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo
0?l006`e06F/003RL000oPH00?HU003>[@004i40001CC00032H0008I000H<000I3l0BZ@00=f1003l
3000nA/00=>N000TV00005Q9000?:@000QT001@]001OA00lX000fX/00?/A003j5P00eYD002jK0000
FdL0014[00026@004R`005i503NN003ISP00na800?XE003GU@00;Y/0001KA`0042X0008I000C;@00
Gd@0?:000=Z9003l3`00nQP00=BK000UV00005Q:000>:0000QT001H_001S@01<Y@00gWh00?d:003h
8@00cjT001>A0000DTd000/U00036P007C@006/g06N]003TJ`00o`@00?@_0038_@0008P30013B@00
1b4000@L000X>`00MRL0SkL00>]A003o0000kTH00:>l0000Nah002lo00047@001Ql003a600243035
a000lc@00?l2003UI`00JZh0001[=P0073@0008J000<9P00E4`07YD00=>N003j6000na400=RA000^
V`0005U9000>:@000QT001Pa001W?01MZP00hfh00?h4003d<000a/4000252P00?4H000HO00057@00
<T4007hG0;?0003a>`00o`400:^90000K3H001`c00026P003BL005M:02VI003GT`00na400?TI003B
X@005i<0001AC@002R@000<K000S>000Lb/0RkL00>]@003o0000k4l008fg0000Lb/002<h00036`00
2R@0059=01ZD003CW@00nQH00?/D003EVP007YD0001CC0002R@000<J000S>000LbX0SkL00>a<003o
0000jU@0086d0000L30001le00026P0032L005M:02fK003IS@00o0d00?PP003=[P001H`00016BP00
1b0000@M000b@@00P1D0_/<00?<c003n1000hG@004jU0000HD80018/00026@005c0006Pk06N]003V
H`00o`400>m2002O^`0007LU000V>P000a/000XT001DC00TV000ei800?`?003h7`00cJl000>;0000
@TT000HO00057P00>4@008D:0<Rk003f9`00o@X00=^7000bW00005Q:000<9P000aX002<h001e:@2J
^P00kd<00?l1003UI@00HJ/0001U?P0052h0008I000F;`00J3/0Jjh00>MN003o0000kD/008^f0000
L2l001he00026P003bT005i504RS003QM@00o`@00?8h002^_`0007TP000W>`000a/000/U001FB`0`
W00007/0fhH00?d9003e:`00aL<000205000;cl000@L00098`00DDd08IH00=RA003l3@00mb@00<Vj
0000Q0`003A200047@00224004m>01ZD003FUP00o0l00?LR003:]`0008D9000f@`0011d000PQ001?
CP0JU000eYD00?`>003g8`00bKX000233@00<d4000@L00088P00DDd08YL00=V>003m2`00mRT00<K2
0000OaD002dn00036`002R@005I;03:L003MP@00oPH00?<d002a`00007TR000T>@000aX000dX001M
AP1;Y000hfl00?l1003^A000SkL0001_<@006c<0008I000C;@00Ic`0Kjl00>YF003o0000j5`006F/
0000I3l0014[00026@007SD007<[09nk003a>`00oP@00=ml000fWP0005I;000:90000a/003100023
3P3:^000n1l00?/C003BXP001hd0000oA`001Ah000LQ001?CP0OUP00fHh00?d9003d;`00]/40001i
8@008cP0008J000?:P00HD80H:/00>MN003o0000jET006J/0000Hd00010Z00026P008SP007PS0=Eh
003m2P00f90001ZD0000BTd00P001Ql0MP00Ad/05Y800=NC003m2`00mBd00;O10000N2<0028g0002
6P004B/006Dn06n_003[D`00o`000>EX001=Y@0005]7000<9P000a/002lo00233@3;/`00nAX00?XI
003</@0008@:000`@0000a/000/V001KA`1>Y@00iFL00?l0003ZEP00Ijd0001R@@003bT000<J000X
>`00OQL0akd00?PP003k5000cjX000271000<d4000<K000;9@00FdP0CZD00>EV003o0000jET0066[
0000H4<000dX00036P00;3h008<?0<bc003j6@00nA`00<Zh0000P1<002Tl00036P003bT006=006f^
003[D000o`400>9a000lX00005E;00088P001Ad00458016A003GT`00o@T00?<e002O^`00070`000H
<@000QT001`d001e:02b`000mB/00?`>003CX0000XX0000f@`000a`000/U001LAP1GZ000j5d00?l0
003UJ000AZ<0001GBP002B<000@M0010B00BT@00f9000?h7003a>@00TkP0001/=@0052h0008I000R
>000O1`0akl00?PN003j600:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0
M@00Kc40LJl00>EX003n1000mB/00<^d000:SP00051>000:9@000QX001/c001W>`1FZ000ggT00?d9
003h8000dJD001^D0000ED/000dW00026@005Rl006=004NS003LP`00o0d00?TK003CW@0099L0001H
BP003bT0008I000E;P00HD80@Z800=^6003l3P00nAX00=BM000TU`0005Q:000>:0000QT001H_001R
@@17X`00gH400?d<003h7@00dJ<001^D0000E4`000`W00026P006C4006Ll05NX003QMP00oPL00?HV
003</0002Xh0001?CP002B@000<J000P=P00KS80Lk000>IS003o0P00lSD00<G40000Q0/003e70006
800011`002dn001i8@2K^`00kDX00?l0003/C@00U[T0001g9000:Sd000@L00078@00@TT008L40<Rm
003d;P00oP@00>=^001NZP0006Pk000I<P000QT000dX001GBP0XV@00eYH00?/D003j5@00eIT002BG
0000ET/000dW00026P006c<006Xg06V]003UIP00o`800?8g002n``00084A000g@`0200057P3o000g
A000PQ00`L@00?<e003o0`00Y8/0001X>P006C40008I000?:@00FTP0<id00=Z;003l3P00n1h00<nY
000>S`0004i>00098`000a/002Lk001g9@2H^P00kDP00?l0003ZEP00P;@0001`<00083H000<J000;
9P00ED/099P00=JE003k4P00nAT00=:R000DTP00051>00098`000a/002Lk001g9@2L^`00kTD00?l0
003XG000MK40001/=@006c<0008I000>:000FTP0=ih00=b5003m2P00mbD00<Zf0000R08003m80006
7`001Ah003M300233@36`000mBd00?h6003OO000@j80001NA@0042X0008I000J<P00JcL0Lk000>QK
003o0000kDT009:h0000Lb/0028g00036P0032H005M:02jK003JRP00o@/00?LT003:]P0008L4000l
AP001Ah000DO000nA`00R080bk@00?LR003l3@00f8l002RI0000E4`000XU00036`009cX007PS0:Nm
003a?@00o`800>=]001EY`000691000B;0000QT001Ta001[=`1g/@00jUL00?l0003[DP00O[<0001]
=0006S80008I000A:`00HD80DjL00>=]003o0P00l3h00:6l0000MRH002<h00036P0032L005U803ZO
003NOP00oPH00?<a002j`P0007`K000[?@000a/000XT001DC00[VP00fXT00?d9003e:P00a/800020
4`00;cl000@L00098`00DTd099L00=V>003m2`00mRL00<No0000PA400350000470002B<0059=02BH
003IS@00o@/00?HY0036`@00080D000^?`000a/000XT001DC00/VP00fhH00?h8003d;`00_<80001l
7000:C`000<K000<9P00FDT0?:000=mi003o1000lCX00:>m0000MBP0024g00026P003bT0061305JX
003UI`00o`000>e;0022]00006`f000H<0000QT001H_001Z>01k/P00k4l00?l0003VI000FJT0001P
@`003bT0008J000R=`00MbD0[;l00?<d003n1P00g8@002bJ0000Dd`000TS00047000=D<008L60<f`
003i6P00nQL00<nZ0000R@0003U500047@002280059=02RI003KQP00oPH00?<e002Y_P0007DW000O
=P000QT0014[001U?P1[[P00jUH00?l0003WH@00FZT0001P@`003RT000<J000V>P00O1d0g7L0001l
0?`=003EV00049000014BP001Ah000LP001>CP0OUP00fX/00?h8003c<`00Z[h0001e:0007SD0008I
000C;@00J3X0Nk800>e;003o0@00hW0004:R0000F4T000XT00047000=48008L50<j/003j5P00n1h0
0<Vh0000PA8002/m00036P003BL005i405ZY003WG`00o`000>QN001KZ@0005m4000=9`000a/002`n
0022403:]P00nA/00?XI003</@0008@<000^?`000a/000dW001NA@1IZ@00ieh00?l0003WH@00EJL0
001MAP0032H000<K000a@000QPL0cZ/00?/D003h8@00akl0001m6P009CT0008J000A:`00ISd0NK80
0>e9003o0P00ggT0036L0000DTd000LQ00057P00Ad/06i@00=Z;003n1P00lC/009:h0000K3D001D_
00026@0083H007PR0;o3003f9P00na400=2X0000Q`D0035000036`003BL005m406>/003ZE@00o`00
0>9`000lX00005A<00088P001Ah004I;01^D003KR000oPD00?100026]@0006Tj000B;0000QX002Hj
001o5P3:]`00nAT00?PM00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o
001c:`1m/`00if000?l2003c<@00b;`0006:0000Bdd000TS00036P007SD006/g06:[003RL@00oPH0
0?HU003>[@004I40001BC@002bH0008J000I<P00ISd0DZL00=mk003m2P00n2000=6U000JU00005E;
000=9`000QT001L`001T?`1=Y@00gWh00?d;003h7`00dJD001ZD0000E4`000`W00026@00634006Hm
05>W003ON@00o@T00?LR003?Z`004Y40001AC@002bD0008J000L=000JSP0Hj/00>=^003n1@00mB`0
0<Zh0002RP0004Q<00088P000a/002@i001b;@1o/`00j5/00?l1003a?000]l4000214P00>4@000DO
00057@00<D0007dK0:Vn003_@`00o`000>YD0029]P0007@Z000V>P000a/000PR0018C003R`00bkD0
0?HX003n1`00h7H005>W0000I3l001H_00026@003bT005]803:L003ISP00o1000?TJ003BX@006Y@0
001CC0002bD000<J000O=@00KS<0M[400>MN003o0@00l3d00;300000OQT0035100047@001Ql003e6
00252@37_`00m2l00?h5002MS@0006Dn000F;`000QT0014[001MA@0nX000g8<00?d:003g8`00c;40
00F<0000Ad/000LQ00047000;3d007XO0:Fm003_@@00o`000>QN001d/00006`e000L=0000QX000dW
001HB@0^V`00fHd00?`>003h7P00cjX000^>0000Bdd000PR00047000:cd007XN0:Vn003`?P00o`40
0>IS001Y[@0006Ti000H<@000QT0010Z001NA@12XP00gWd00?h7003e:`00akd000252P00>TD000DN
00067`00?4H008L60<Vi003f9`00o@T00=b4000hWP0005Y8000>:0000QX001dd001^<P20/`00jU@0
0?l0003[D000QKD0001`<0007SD0008J000=:000FTP0>Il00=f2003m2000mBX00<Nn0000Q0`003M3
00057@001R0004A:00F<003>[000nAd00?/A003FU`007YD0001AC@002B<000<K000[?@00O1`0]<40
0?8f003o1000hGD004VT0000GTD0010Z00026@0073@006hb08>d003/C`00o`000>UI001b/00006Xi
000G<0000QT001<]001T?`1OZP00iFD00?l1003^A@00U;T0001b;0007cH0008J000>:000GDH0AJ<0
003c0>1f003o1000lSP00:fo0000NB4002Hj00036P002bH005Q:03FN003MP@00oPL00?@`002l``00
07dJ000[?@000a/000XT001EB`0^V`00fhH00?d8003e;@00`/@0001n6000;3d000<K000:9000ED/0
;Y/00=b5003n2000m2l00;g30000O1/002Xl00036`002bD005M:03NN003NOP00oPD00?<e002__`00
07PR000T>@000aX000dW001LA`18X`00hW400?l2003_@@00U[T0001b;@007C@0008I000A:`00Hd00
HZ/00>MO003o0000je<007Fa0000J3X001D^00026@006C4006dd08Rf003^B000o`400>=/001>Y@00
05e6000=:0000aX002Hj001j7`2i`P00m2h00?d9003IS0008YL0001@CP001b4000@M000kA@01RP00
d:P00?XF003i6`00c;8000262000=48000@L00098`00ED/0<id00=in003n1000lC/009bk0000LRd0
01`d00026@0052d006Pk07Ra003/C`00o`000>AY001?YP0005a6000=9`000aX002Xm001o5P3OL@00
na400=:P0008S@0003i700057@002240055=02VI003LP`00oPD00?4i002M^`00074^000K<`000QT0
01H_001[=P28]P00kd@00?l2003PN000=ih0001EB`002B<000@L000iA@02RP00dJ@00?/B003g8`00
a/00001m6@009c/000<J000?:@00HT40IJ`00>UG003o0000iFD004nV0000FdL000`V00036`00<D00
08D90<f^003j5`00n1d00<Vi0000P1@002Xl00036P003RT0065206F/003ZE`00o`000>AX0019Y000
05U8000:900011`003I3002:003AX`00o1000?HV0031a00007TQ000Q=`000QT001<]001Z>@26]@00
kd800?l4003MP@009iT0001?CP001R0000HO001>CP0UV000g8<00?l4003_@P00QKD0001Y>@004b`0
008I000S>000O1`0a/000?PP003j5P00cJl000233@00;3h000<J000?:@00Hd00Kjl00>a>003o0@00
h7P0036L0000DDd000LP00067`00CDh09IP00=f0003o0`00kTL007Zb0000ICh0010Z00036P00:cd0
08<>0<f_003j5@00mb8000[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`1:
001f9P2:]P00jEP00?l1003b>000aL<000261P00A4X000PR00036`008SL006hb06j_003TJ@00oP@0
0?D[003;]@0028d0001?CP002R@000<J000L=000JCT0GZX00>5c003n1`00mbD00<j]000@T000059=
000;9@000QX001Xb001X>`1IZ@00h7H00?h8003g9000cZ`0016@0000DDd000/U00026P006c<006Ti
05jZ003RL@00oPH00?HX003</`002Hd0001>CP002B<000<J000P=P00KC<0Kjl00>EV003o0`00lc80
0<K00000Q`D0049900078@0011`002Pk001e:02<]`00jU@00?l0003_@`00Z[h0001m6P00<T420005
7P3o000g@`00P1@0]/400?4l003o0@00j5`007bc0000L2l0028h00036`002B<004m>00b>003>[P00
mb<00?d9003NOP00Aj<0001Q@P0052d0008I000A:`00GTD0?J000=b6003m3000n1l00<nY000AT000
051>000:90000a/0028h001a;P22]000jEL00?l0003_A000Xk`0001j7`00;Ch000@L00078000@dT0
08T10<Zh003f:@00oPL009F@0000HT8001<]00026@004bd0065204VT003ON`00oPL00?HY0039^000
08P20011B0001R0000@M000`@000OQT0/l000?4k003o0P00iFD006R]0000JCT001Ta00026@003bT0
05]703VO003LQ@00o@/00?LS003</P000X/00014BP001b0000@M000`@000OQP0]/400?8h003o0P00
i6/005fZ0000ICd001H_00026@004R`0065204jU003QM@00oPD00?@a0034a000084A000d@P0011d0
00HP0012B@01RP00c;400?LQ003l3000fX`002jK0000EdX000`V00036P008CL0078]08bg003/C000
o`000>UH001h/@0006`e000K<`000QT000lZ001MA@14XP00ggX00?h6003d<000`l@000205000<D40
00@L00078@00BTd03Xl00=6T003j6000nQD00=>O000DTP0004i>00088P0011`00310001o5@31a000
m3000?h6003NO@00?Z00001KA`003RP0008J000O=P00LRd0T;P00>i8003o0000if4006J/0000ISd0
01D^00026@005Rl006Lk06^^003XG@00o`000>a=0027]@0006la000L=0000QT0010Z001P@`1AYP00
hfh00?l2003`?`00Wk`0001e9`008SP000<J000=9`00FdL0@:400=mi003n1000lSH00:no0000NB40
02Hj00036P0032H005Q903VO003NOP00oPH00?<c002d`@0007XO000W>`000a/000/V001HB@0iW`00
gWd00?h5003c=@00/<00001i8@009CX000<J000=9`00FTP0@Z400>1f003o0`00lC`00:6l0000MBP0
024g00026P003bT005m405>W003TJP00o`400>i80029]P0006hb000J<P000QT001@]001W?01^[`00
jEL00?l0003XFP00JJd0001U?P004b`0008I000L=000LBl0UKT00>m1003o0P00hG@004:R0000FTP0
00`V002W00036`00:S`007hH0<G3003f:000o@`00=ND000HT`0004]=000680001Ah0045800Z>003B
X000na800?PQ0039^@00088@000_?`000a/000/U001HB@0nX000h7H00?l2003_@P00SkL0001^<P00
6C40008I000F;`00JcH0Q;D00>i8003o0@00hW4004>R0000FDT000/U00036`00;cl008<>0>5[003j
5@00d:P000290000>4@000@L00098`00E4`0=9d00=mk003o0`00l400092h0000KS<001Pa00026@00
6C4006la09Bi003`?@00oP@00=f0000]V`00059=00088@001Ad003m700^>003DW000o0h00?HX002o
``0007XP000S>0000QX0014[001U?P1b/000je000?l0003SK@00A:80001HB@002R@000@L000f@`00
R@40d:H00?/B003g8`00a/40001m6`009CX0008J000@:P00I3l0LJl00>a?003o0@00hW0003jP0000
ET/000TS00047@00?4H02Hd00=BK003l3@00mB`00;?00000MRL001he00026@005Rl006dd09>h003a
>`00oPH00=Z9000MU@0004U<00057`001b40055=02nK003ON`00o`800>e9001i/P0006Hm000A:`00
0QX002Lk001o5@39^000nA/00?TJ003:]`00080D000X>`000QX0014[001V?@1l/P00kTH00?l3003M
P0009iP0001>CP001Ql000LP001AC@0`W000h7P00?l1003/CP00KJh0001R@@003RP000<K000_?`00
QPH0d:P00?/A003f:0002_ooool1o`00007ooooo000Nooooo`?o00001oooool0o`00NR00UkT00>]A
003o0000l3h00;W20000P`h003i7000780000a`002Hj001b;@1j/P00if400?l2003c<@00b;d00029
0000BD`000TS00036`0083H006dd06Z]003TJ`00oP@00?D[003;]@001hd0001>CP002R@000<J000N
=@00JcL0IJ`00>=^003n1@00mBX00<^d0008S@0004i>000990000aX001le001/=@1Z[P00i6T00?l4
003d;P00bKX0002:0000B4/000PR00036`008cP0074^07bb003WGP00o`400?8h0030``0008<=000l
AP001R0000@L000/?P00NB80VKX00>a<003o0000kDX009fk0000NR0002dn00047@001Ql003a60024
3033a000lSH00?l2003VI000L:l0001]=0007SD000<J000;9@00DTd05I800=6V003h7@00o0d00=^7
000lX00005i5000A:`000QT001@]001Q@P18Y000gWd00?d9003g9000cK0000R=0000Bdd000PR0003
6`009SX007DX08ng003/C`00o`000>e;002F^@0007LU000X>`000a/000PR001:C007S@00cK000?LS
003m2P00Si80001NA@004B/0008I000E;`00I3l0EJL00>5c003n1@00m2l00<K00000Q@X003]50006
7`001Ah003I300214@30``00lc@00?l3003SK@00G:T0001V?@005Rl0008I000A:`00Gd@0A:800=im
003n2000mRT00<Vj0000Q`D003i700067`001Ad003E300224@34a000lc400?h4003QL`00DJH0001R
@@004bd0008I000E;P00I3l0FJT00>=]003o0`00lSL00;K10000OQT002lo000470001b4004U<00Z>
003?Z@00nA`00?`@003GU00099L0001DC0002bD000<J000T>@00MBL0VKX00>i5003o0000if0006b^
0000JCT001Pa00026@004B/0065204nV003RLP00o`@00?8f002f`@0007dK000]?P0011`000PR001@
CP0HT`00e9`00?/C003i6@00d:L000^>0000B4/000LP00047@00=D8008<>0<No003e:P00o@T00=b5
000cW@0005Q:000<9P000aX002<h001e9`2M^`00kd400?l1003TJ@00FZT0001S@0004R`0008I000I
<@00JcL0Mk400>YF003o0000jU@007Zb0000JcH001Ta00026@004R`006=005fZ0000E@3UIP00o`40
0>i6002B^000078]000O=@000QX000lY001NA@1<Y@00hW400?l2003`?@00XK`0001f9`008SP000<J
000=:000G4L0A:800>1f003o0`00lCX00:Nm0000MbD002<h00036P003BL005]704BR003QM@00o`<0
0?4k002R_00007DW000Q=`000QX000hY001NA@1=Y@00hfh00?l2003_@P00U;T0001a;P007C@0008I
000A:`00Hd40GjX00>IR003o0000k4l007fc0000JcL001L`00026@005Rl006Xh07^b003[D000o`00
0>IR001MZP000691000@:P000QX001lf001d:@2R_000lCX00?h4003OO000=ih0001GBP002R@000<K
000_?`00PA40b;`00?LS003l4000e9`000n@0000ADX00P001Ql0W000Ad/04i400=FH003l3P00mRH0
0<K10000OQL002Xl00036`0032H005]704VT003SKP00o`400>e90022]00006/g000F;`000QT001Tb
001_<@2A^000kd400?l3003PN@00>9h0001FB`002R@000@L000d@P00QPL0i6@00?TI003=/00008H8
000c@@0011`000XT001GBP0oX000hG<00?l1003^A`00Pk@0001Z>0005Bh0008I000L<`00LR`0X[`0
0?8g003n1P00fhP002:G0000Cdh000LP00057P00ADX059800=ND003m2P00m2h00;;00000MRH001lf
00026@004bd006Pj07jc003]B000o`800>5e000iW`0005E;00098`0011d003]600N<003CWP00o0h0
0?HX002n``0007TQ000Q=`000QT001</001X>`1n/`00kTP00?l2003PN000<id0001CC000228000DN
0012B@0BT@00ei<00?d9003c<P00Y[d0001b;0006S80008I000I<@00L2l0X;`00?<e003m2000f940
01>A0000@TT000DM00088P00E4`0>Il00>5b003o0@00je0006b^0000HT4000hY00036P00;3d008<>
0<ba003j5P00n1l00<No0000O1/002@i00026P004bd006Xi08Rf003`?`00oPD00=^8000MU@0004M;
00057P00224005A<03ZO003RL000o`000>YF001QZ`0005m4000<9P000a/003A2006:003CX000o0d0
0?@^00Sooooo0ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o001m6@2T_@00kDT0
0?l0003^A@00Zkl0001o5@00>4@000HO00047000:S`007DX08Ne003YF@00o`400?8h0035a00008H8
0012B@00224000<K000T>@00L2l0M[400>IS003o0P00m3400<Rm0000R@0004Q;00088P000a/0024g
001_<P1a[`00iFH00?l3003d<000b;`000290000Ad/000PR00036`008cP0070`07Na003VH@00o`80
0?<d0035`P0008H70011B0001b4000@L000W>`00M2T0R;H00>YF003o0000l3l00;;00000P1D003I3
00057P001Ad00350001l6`2V_@00kTD00?l0003[D@00T;P0001f9P00:C`000@L00078@00@TT008L4
0<Nm003d;`00o`@00>=/001S[00006Ti000K<`000QX000`V001EB`0OUP00dih00?XH003l4000fHl0
036L0000FTP000lY00026@005Rl006Dn05BW003QM@00oPH00?DZ0039^00008T00014BP001b4000@L
000[?@00N280W;/00>i8003o0000je<008Vf0000Lb/002@i00036`002B<004m>012@003@Z000n1h0
0?`=0028U00005]7000?:@000QT001Pa001W>`1PZ`00i6/00?l3003c=@00_l<000214P00=D<000DN
00067`00>dH008D:0<No003d;P00oPD00>5e001@YP000691000D;@000QT001<]001R@@1?YP00hGD0
0?h5003d;`00a/4000233@00>4@000DN00057`00>dD008D90<Nm003e:`00oPL00=mk0015X`0005m4
000A:`000QT001L`001X>`1U[000iFD00?l1003`?P00ZKh0001j7`00:Sd000<K00088P00Cdh04i40
0=:Q003j5`00na@00=BL000JU000055=00098`000a/002Tl001i8@2W_@00l3h00?l1003UI`00H:/0
001U?@005Bh0008I000D;@00I3l0FjT00>AZ003o0P00lCd00:Rn0000NB4002Pk00036`002R@005=<
026G003GU000o0l00?PN003=[`000XX00011B0001Ql000DN000jA@00QPH0b[L00?LT003m3000fHd0
02VI0000ED/000XU00036`009c/007TQ0:^n003a>P00o`<00>9a001>Y@0005m4000@:P000QT001`c
001^<P24]@00k4h00?l0003XG000KJh0001X>P005Rl0008I000E;P00Ic`0JJd0003c0>MN003o0000
k4d008Fe0000KS8001/c00026@004B/0065205NX003TJ@00o`400>m4002D^@00078]000O=@000QX0
00lY001OA01?YP00hfh00?l2003_@@00V[X0001c:`007cH0008J000?:@00Gd@0CjH00>=]003o0@00
kd8009Fi0000LRd001he00026@0042X0065205VX003UIP00o`000>e:0027]@0006hc000J<P000QT0
01<]001V?@1[[P00jEX00?l0003ZE`00L:l0001W>`0052h0008I000I<P00KS<0R;H00>e8003o0@00
i6X0056V0000GTD000hX00026P008cP007PS0:no003c<`00oPH00=b4000]V`0005=<00098`0011`0
03A200252@3;]000n1d00?/D003AY0001X`0000nA`001Ah000LP001>CP0MU@00f9000?d:003e;000
_L<0001k7P009SX000<J000>:000GT@0E:L00>EV003o0000je4007Fa0000Ic/001@]00026@007C@0
078/09nk003a>P00oPD00=f1000^V`0005=<00088P0011d003U5006:003VGP00n1h00<Zh0000PQ00
02hn00036`0032H005]704ZT003TJ`00o`000>a?001f/@0006Ll000C;0000QT001lf001f9P2__`00
m3000?d9003HT0006I<00019C0001Ql000HP001<C@0NU@00fX`00?h7003c=@00Y;d0001c;00073<0
008I000F;`00K3D0RkH00>m1003o0`00gWh002jK0000DTd000PQ00057P00@TT049000=JF003m2`00
m2h00;300000MBL001he00026@005Bh006/f08Zf003_@@00o`@00=f1000YV@00051>000780001Ql0
04U<01bD003JR`00oPL00?8i002H^P0006lb000G<0000QT001`d001d:P2]_`00m2h00?d<003EVP00
2Xh0000lAP0011d000TS001GBP15XP00i6X00?l0003YF000H:/0001OA0003BL000<K000a@000QPH0
cjT00?/B003g9@00`L@0001i8P0083H0008I000E;`00KC@0UKT00?8i003n1`00f90001>A0000@DP0
00@M00098`00EdX0AJ<00>AX003o0000j5d005FW0000FdL000/U00047000>TD02Hd00=JG003m2P00
lc@000[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o00214P2b`000kd80
0?l0003/C@00W[/0001l7000<d4000DN00057@00;cl007TQ09Bi003[DP00o`000?0o002g`@00088?
000lAP001b0000@L000X>`00M2X0Pk@00>QK003o0@00lSL00<G40000Q@P0045800078@000a/002Dj
001b;@1n/`00ieh00?l1003b=P00aL<000252000@DP000LQ000370009cX007<Z08Be003YFP00o`40
0?4k002k`P00088?000kA@001Ql000@L000/?P00N2<0U[T00>a?003o0000kTH00:Bm0000O1`00350
00057@001Ah003M30020502d`@00l3h00?l0003YF@00P[@0001b;00093T000<K00088P00BD`00h/0
0<Zf003f:@00oPH00>5d001GZ00006Hm000H<@000QT000hX001HB@0YV@00eYD00?/D003k5@00eYL0
02NI0000EdX000dX00026@006C8006Pj062[003SK@00o`@00?@`0036`00008D8000nA`001R0000@M
000_?`00O1`0Z[h00>m1003o0000j5X007bb0000Kc40020f00036P002bD0059=01ZD003CX000nQT0
0?/A0021UP0005Q:000=9`000QX001/c001[=`1][P00iV<00?l1003a?000/L00001m6@00<40000@M
00068000@DP008P20<Zh003f:000oPP00=im0014XP0005m4000A:`000QT001H_001U?@1KZ@00hfd0
0?l3003b=@00_<<000205000<d4000@M00068000@DP008T10<^e003f9@00o@X00=b4000jW`0005]7
000?:@000QT001Xb001[=P1b/000j5d00?l0003^A@00Vk/0001f9P009SX000<K000:9000DTd07ID0
0=FI003k4`00nQT00=6T000@T00004e>00088P0011`002dn001m6P2d`@00lSL00?l3003RK`00E:L0
001R@@004b`0008I000G<000Ic/0Ijd00>IR003o0@00kd@009^j0000MBL002@i00036P002bD005I;
02bJ003IS000o@`00?LT003:]`0008L5000kA@001Ah000HO0010B001RP00cJl00?PN003l4000eYD0
01nF0000DTd000TS00036`00;3d007dK0;S2003c<`00oPD00=mi0012XP0005a6000>:0000QX001lf
001b;@2A^000kTL00?l0003VH`00HJ/0001U?P004bd0008I000H<000JSP0MK40001@0>YF003o0000
jU@007Ra0000JcL001Pa00026@004bd006Dn06>/003WH@00o`000>e;0027]@0006lb000K<`000QT0
014[001R@@1KZ@00iFH00?l0003^B000S;L0001`<00073@0008I000A:`00HT40FjT00>EU003o0000
kDX008Rf0000KS8001Xb00026@004b`006@o06F/003WGP00o`000>]A001j/P0006Xh000G<0000QT0
01H_001Y>@1h/@00je800?l0003WGP00I:`0001T?`004R`0008I000L=000LBh0UKT00>m1003o0P00
hW8004JS0000FdL000`W00036P009c/007/M0;g3003e;@00o@T00=V<000RU`00051>00088@0011d0
03U400290@3>[0020?XH002Q0<j/0000R08003Q400047@002280055=02NH003KR000oPL00?<b002_
_`0007LT000R=`000QX0010Z001R@@1PZ`00ieh00?l0003YF000JJd0001T?`004B/0008I000P=P00
MRH0[;l00?<c003n1`00fXT002>G0000D4h000LQ00057P00?dP02Hd00>QH003g9000a/00001n5`00
:C`000<J000=:000GTD0EZP00>IS003o0000jUH006Z]0000Hd00010Z00026P008cP007XP0;g3003e
:P00o0d00=FH000?T000049900057P001b40051=02RI003LP`00oPD00?4k002G^@0006la000I<@00
0QT001Ta001_<@2H^P00lCX00?h5003KQP0099P0001?CP001b0000HO0018C00IU000fHh00?h8003c
=@00Xk`0001b;@006c80008I000H<@00Kc40V;X00?4j003n1P00fXT001nF0000Bdd000HO00068000
Cdh09YP00=b3003n1000l40008^f0000JcL001D^00026@007cH007PT0;_2003f:000o0l00=:R0001
RP0003I3000470002bD005]8052V003VHP00o`000>MP001DY`0005a7000;9@000a`003I3006:003B
X@00o0h00?D[002d`00007DX000L=0000QT001Pa001a;`2S_000lc800?d:003EV0002Xh0000kA@00
11`000XT001JB01AYP00if000?l0003UI@00BZ@0001HB@002B<000@M0010B00CT@00f8l00?h7003a
>`002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo06X008D:0<33003a>`00
o`000>YD002A^00007PS000^?P0011d000DN000d@P00O1/0X[`00>e:003o0000kTH00:Zn0000OQL0
03I300067`0011d002`n001g902@^000jU@00?l0003`?P00]l4000224000>dH000HP00047000:S`0
07HW08^f003ZEP00o`000?0m002h`P00088@000kA@001Ql000@L000[?@00MbD0TKP00>]B003o0000
kd800:jo0000OaH003E300057P001Ad00350001l702S_000kTL00?l0003/CP00UkT0001h8P00;3h0
00@L00068000?4H008<=0<;4003b=`00o`800>MQ001f/@0006la000Q=`000aX000TT001?CP0<S`00
cJh00?LS003m2@00gg`004bU0000Hd0001D^00026@0042X005]703BM003IS@00o1000?TI003CW`00
7ID0001DC00032H0008J000M=000K3H0K:h00>EU003o0P00lSL00;o30000PQ0003Q40P001Ah0o`00
=D80080E0;O1003a>P00o`400>IR001_[`0006`e000L=0000QX000`V001FB`0TU`00eIP00?/D003j
5@00NiP0001DC0002bH000<J000O=@00KS80NK800>QK003o0000kd<00:Bm0000NR0002/m00047000
1b4004Q;00J<003=/000mb800?d;003KQP00>Il0001LA`003bT0008I000I<@00JCT0J:d00>EU003o
0@00lC`00:no0000O1/002ho000470001b4004Q;00N<003>[P00n2000?`=003IS000;i/0001HB@00
3BL0008J000N=@00Kc80O[<00>YE003o0000k4`008jg0000Lb/0028g00036P002bD005E;02NI003H
T@00o0l00?PN003>[0001h`00016B`001b0000@M000b@@00P1<0`/@00?@a003n1@00h7P004RS0000
Gd@0010Z00026@006C8006/g07B`003XFP00o`000>e;002=]`00078]000P=P000QX000dW001IB@0f
WP00g8@00?d9003e:P00akh000233@00=D<000@M00078000Ad/02Xh00=2W003i6@00na@00=>M000E
TP0004i>00088P0011`0035000204`35a000mBd00?h7003MP@00=ih0001IB@0032L000<J000S>000
MBL0Wk/00?10003o0P00i6`005FW0000HD80014[00026@006c<006hc08:d003/C`00o`000>QL001/
[P0006Lk000E;`000QT001H_001X>P1`[`00jET00?l0003[D`00N[80001[=`006340008I000D;@00
ISd0Ijd00>MN003o0000k4l007nc0000K3D001Ta00026@0052d006Hm06R]003XG@00o`000>]A001k
/P0006/g000G<0000QT001D^001X>`1a/000jUL00?l0003YF@00KZh0001W?00052h0008I000I<@00
KC@0Q;D00>e;003o0000iFH005RX0000H4<0010Z00026P0083H007DY0::l003a>P00oP@00=mj000j
W`0005Q:000;9@000a/002`m001o5P36`@00mRL00?`=003GU@0069<0001<C@001b0000DN000oA`06
S000dJ@00?/D003h7@00bk@000252P00<d4000@L00098`00ED`0<I`00=f0003n1@00lST00::l0000
M2X001he00026@004R`006Dn06f^003ZEP00o`000>MP001MZP000652000?:@000QX002@i001j8000
Q`2j`P00mBd00?d:003HT@006I@0001;C@001R0000HO0016BP0CT@00jU800?DZ0030``0007/N000U
>@000QX000lY001Q@P1RZ`00j5/00?l0003WGP00GJX0001P@`003RT000<J000W>`00OAT0a/400?LT
003l4000dZ4000J<0000?4H000@M00088P00E4`0<id00=mk003o0`00kd8008Zf0000K3H001H_0002
6@0073@007<[0:Jm003c=000oPP00=V>000JU00004U<00067`001R0004m>02>G003KQP00oPD00?4k
002E^@0006hb000G<0000QT001/c001b;02U_@00lc<00?d9003HT@005I800014BP001Ah000LQ001B
C@0`W000gg/00?l2003^A`00O[<0001X>`004R`0008J000S>000Nad0aL800?LS003k4`00cjX00026
1P00<D0000<K000<9`00GTD0G:X00>QK003o0000iFP004RT0000F4T000XT00047000?4H02Xh00=FI
003m2`00m3400:Jm0000LBh001Ta00026@006c<007@Y0;30003e;000o0h00=:P0001RP0003E20003
6`0032H005i505fZ003YF000o`000>=]000nX00005E;00088P001Ah004I;01bE003KQ`00oP@00>m2
000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool04`00R080a/000?<e003o
0@00j5`008>d0000M2T002Tl000470001Ql003U50020502__`00kd<00?l0003/C@00W;/0001k7P00
<D000P001Ah0o`00<D0007/M09jk003/C000o`000>i5002Y_P0007hH000e@`001Ah000@M000^?`00
NB40V;X00>a>003o0000kd@00:^n0000OQL003E200057P001Ad00310001k7P2N^`00kDX00?l0003]
B@00X;`0001k7@00<40000DM00057P00=T<007lE0;70003`@000o`000>YE002:]P0007DX000X>`00
11`000LQ0013B@00Q`D0akh00?@`003o0`00i6T006V]0000JcH001dd00036P002bD0059=01JB003@
YP00n1h00?d<003LQ000@:40001OA0004b`0008I000B;000Gd@0?j400=b5003m3000n1h00=2W000C
T@00055=000:90000aX0020f001_<@1i/P00j5d00?l1003`?@00/L00001n5`00<d4000DM00067`00
>TD008<=0<G4003c<`00o`<00>AZ001SZ`0006Pj000I<P000QT000hX001IB@0^V`00f9000?`@003i
6P00M9/0001AC@002R@000<J000R>000LRd0Q[D00>YC003o0000kDX009Ji0000MRH002Lk00036`00
2B<004i>00n@003@Z000nAd00?`?003ISP00;Y/0001HB@003BL0008J000L=000K3D0M;000>QM003o
0000kd<00:6l0000N28002Tl00036`00228004i>012@003AYP00nA/00?/A003GU0009IP0001EB`00
2bD000<J000Q=`00LR`0S;L00>a>003o0000jU@0086d0000Kc4001he00026P003BL005U903:L003J
R@00o@/00?LS003;]00008T10010B0001Ql000DN000hA000Q0`0akh00?DZ003n2000gH0003fP0000
FdL000hX00026P007C@006hb082d003[D`00o`000>]B0020]00006hb000L=0000QT000lY001LAP12
X@00gg/00?h6003d<000`/@0001o5@00<40000@L00088P00CTh04i400=>O003k5@00nQP00=6V000<
SP0004Q;0007800011d003I300243038_000mRL00?d:003JRP00;9X0001EB`002bD000<K000W>`00
NB40[;l00?8i003o0`00hG@004VT0000GTD000lY00026P007SD0074^08ng003^A`00o`000>IT001O
ZP0006@o000C;0000QT001Ta001/=P1m/`00je400?l0003XF`00KJh0001X>`005Bl0008I000F;`00
JCT0M;000>YF0000=P3o0000jEL007:`0000JCX001H_00026@005Rl006Ti07B`003ZE@00o`000>UI
001^[`0006Lk000E;P000QT001Pa001[=P1n/`00k4l00?l0003WH@00HJ/0001S@0004R`0008I000L
=000L2l0T[P00>m3003o0@00hfh004bU0000GDH000hX00036P0093T007PS0;30003c=000oPH00=b3
000_W00005E<00098`0011`0035000233P39^@00mb400?`@003DW@003i000015BP8000HO0:H004E:
012@003DW000o1000?LS0038_000084B000^?`000a/000/U001HBP0lX000h7L00?l3003`@000U;T0
001`<0006c<0008I000E;P00JCX0NK800>a>003o0000iFP0056V0000GDD000dW00036P00:3/007dI
0<G3003f9`00o0h00=FJ000@T00004A:00057P001R0004e>01bE003[C000m3000;;00000MbD0024g
00026@004B/006Dn06j_003ZE000o`000>EV001AYP0005e6000<9`000a/002`m00214P39^@00n1l0
0?/D003?Z@0008P2000f@`0011`000XT001GBP0nX000hG<00?l1003]BP00OK<0001X>P004bd0008I
000O=P00MbD0/l000?@]003m2`00eYH0012@0000@TT000DN00078@00DTd0;Y/00=im003o0`00kd80
08Rf0000JcL001D^00026@007SD007HV0;?0003e;@00o@`00=FI000;SP0003i700047@002B8005E;
03^O003QLP00o`400>a>001a/00006@o000@:P000aX002Lk001o5P39^P00n1d00?XH003</P0008<>
000/?P000aX000hX001Q@P1X[@00je<00?l0003RL000?J00001EB`00228000DM0012B@0DT@00f900
0?h8003b=`00V;X0001^<`005Rl0008I000O=@00N2<0_/<00?HV003k4P00cjT000261`00<40000<K
000=:000HD80JJd00>]A003o0@00hGD003>M0000DTd000LP00067`00CDh09iP00=io003o0P00kDT0
2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l01X`00<Zh003d;P00o`<0
0>IT001f/@00074_000U>@000a/000LQ000oB000Q0`0_L<00?4l003o0000jUD008ng0000Mb@002`n
00047@001Ql003M3001o5P2[_P00kTD00?l0003/C@00W;/0001j7`00<40000DM00057P00=48007dJ
0:Jm003^A`00o`000>e;002M^`0007/N000`@0001Ad000DN000e@`00OQL0[;l00>m3003o0000je40
09:h0000Mb@002/m000470001R0003a600233P2n``00lCT00?l1003XG@00OK<0001a;P008cP000<K
00088P00BD`00h/00<Zg003e:P00oPD00>9a001MZP0006Pk000J<P000QX000dW001EB`0PUP00dih0
0?XI003l4000fHd003FM0000G4L0010Z00026@005Bh0069104ZT003NO@00o@T00?LT003=[`002Xh0
001=CP002B<000<K000T>@00Lb`0Q[D00>YE003o0000kTD00:>m0000Nah002dn000470001b000418
00271@38_000mBd00?h5003QL`00EZP0001U?P005Rl0008I000@:P00G4H0>Il00=^7003m3000n1l0
06jM0000CTh000TS00036`009SX007HW09Bi003]B`00o`000>]B0029]P0007</000S>0000aX000XT
001BC@0IT`00dil00?XH003k4`00eYH002BG0000ED/000/V00036P0083H0070`086d003ZE@00o`00
0>e:002D^@0007DX000U>@000a/000XT001BC@0JU000e9d00?XF003j5@00e9`001^D0000DTd000XT
00036`009CX007HV09Vj003^AP00o`000>QL001d/00006`f000K<`000QT000lY001LA`0mX000gH00
0?d8003e:@00b;`000252@00>TD000DN00067`00?TL008P40<Zf003g9@00o@/00=^8000aW00005Q9
000<9`000aX0020f001b;@2>]`00kD/00?l0003XFP00Lk00001[=`006C80008I000A:`00H4<0CJD0
0>5c003o1000lSH00;C10000O1`002/m00036`002B<0055=01fE003FU`00o1000?PM003>[P000X/0
0011B0001Ql000DN000lAP00R0@0bk@00?LQ003l3P00ei8002:G0000DTd000TS00036`00;3d007dJ
0;[2003c<P00oPD00=ml000nX00005Y8000=9`000aX0028g001e:02M^`000?<0l4000?l2003SK000
DjL0001P@`0042X0008I000L=000Kc40R[H00>e:003o0000iV80066[0000I3l001</00026@006C80
06dd086d003/CP00o`000>MO001V[00006Dn000C;@000QT001Ta001]=@21]000k4h00?l0003WH@00
HZ/0001T?`004R`0008I000K<`00Kc40RkH00>i7003o0@00i6T005FW0000H4<000lZ00026P0083H0
07@Y09nl003a?000o`<00>1g0010X@0005Y8000<9P000aX002Pk001l702n``00m2d00?d9003JR`00
9IP0001AC@00228000@L000f@`00QPH0c;400?TL003k5@00dJD000J<0000?dL000DN00078000C4d0
6I@00=NC003m3000mRT00<G40000OAT002Tl00036`0032H005]704RS003RK`00o`400>i70027]@00
06`e000H<0000QT001L`001/=@27]@00kTL00?l1003RL000AJ80001JB0002bH000<K000]?P00PA80
b;/00?PQ003k4P00dZ8000J<0000?DL000DM00078@00DDd09iP00>e6003b=P00Y;d0001c:P007C@0
008I000D;@00J3X0Nk800>a<003o0@00hfh004FS0000FDP000/U00036`00<D0008D:0<bb003i6P00
nAT00<ba0000Q@X0035000036`002bD005Y804VT003TJ`00o`000>]A001`[`0006Dn000A:`000QX0
02<h001j7`31a000mRL00?`?003CW`001h`0000lAP0011d000TS001EB`0iW`00hGD00?l1003]BP00
Nk80001W>`004R`0008I000R>000NR00`L@00?HW003l4000dZ8000:;0000>4@000@L000:9000F4T0
AZ<00>AZ003o0000jUH006F/0000HD8000hX00036P00;3h008<?0<bc003j6000nAd00<Vj0000OaH0
02Pk00026P0042X006Dn07Fa003]B`00o`800>1h000bW000059=00078@001Ah004Q<01fE003KR000
oPD00?0n002;]P0006Xh000D;@000QT002<h001k7@36`000n2000?XF003</@0008<?000[?@000aX0
00lZ001T?`1f/@00kDT00?l2003NOP00:9T0001>CP001Ql000LP001AC@0aW000h7H00?l1003[D@00
2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo04l03i000<f`003f:000oPD0
0>=/001Z[@0006dd000Q=`000a/000PR0016B`00Q`@0a/400?8e003o0@00j5d0086d0000M2X002Pk
000470001b0003e600223`2i`P00l3d00?l0003ZE000S[L0001g9@00:cd000@L00067`00>DD0084C
0;?0003`@000o`000>YC002?^00007LU000[?@0011`000HP000kA@00PQ00^/800?4l003o0000jET0
08Fe0000M2X002Lj000370001b40049900271P36`000lc800?l3003UI@00L:l0001]<`007cH000<J
000:9000Cdh038l00<f_003g9000oPP00=mi001@YP0006@o000G<0000QT000hY001IB@0ZVP00eYD0
0080na@00?l0eYD002ZJ0000F4T000hX00026@005c0006Hm05JX003QM000oPH00?DZ003:]`000HX0
0016B`00224000<L000X>`00MRH0TkT00>a>003o0000k4`009Ji0000MbD002Tl00037000224004M;
00>;003;]000mRL00?h8003ON`00BZ@0001Q@P0052d0008I000B;000H4<0AJ800=io003m2@00mbD0
06RO0000Ad/000LQ00047000:cd007TQ0:6l003_A000o`000>UI001l/P0006la000O=P000aX000`V
001EB`0SU`00eYL00?/C003j5`00dil001VD0000DTd000XT00036`0093T007@Z08jg003/C@00o`00
0>]B0026]@00074^000Q=`000aX000/U001EB`0TV000eYD00?/A003i6P00dJD0016@0000CTh000PR
00036`00:S`007XP0:Nm003`?`00o`400>IT001W[@0006Pj000H<0000QT0014[001OA019Y000h7P0
0?h5003d;`00aL@000214@00=48000@M00068000A4X018/00<f^003h7`00o0h00=RA000WV00005E;
000;9@000aX002@i001f9`2K^`00kd@00?l1003VHP00Ijd0001W>`005Rl0008I000C;@00Hd00FJT0
0>A[003o0P00l3d00:Jm0000N2<002Lj00036`002RD005A<02RI003ISP00o0d00?LS003:]P0008L5
000kA@001Ah000HO0012B@04R`00cZ`00?TL003k4P00eIX001RC0000Cdh000PR00047000<D00080C
0<G2003e;000o@P00=b4000bW@0005M:000;9P000aX002Hj001h8P2Z_P00lCT00?l3003QM000Aj<0
001MAP003RT0008J000P=P00Lb/0UkX00>m3003o0@00i6/005FW0000HD<0010Z00026@007C@0070_
08jg003^A`00o`400>EW001IZ@000691000A:`000QT001`d001`<02>]`00kTH00?l1003TJ@00EJP0
001P@`0042X0008I000O=@00Lb`0VKX00?10003o0P00hW4004VT0000G4H000hX00036P0093T007PS
0:fo003b=@00oPD00=io000eW@0005I:000:90000a/002dn00205@36`000mRL00?d<003GT`006i@0
001>CP001b4000DM000lAP01RP00cjT00?XG003i6@00cZd000280P00>D@000@M00088P00DDd08iL0
0=Z;003m2@0007l0m2l00;S10000NR0002Di00036P003RP005i405BW003UI`00o`000>a>001j/P00
06Ti000E;P000QT001Xb001`<02D^@00l4000?l3003PN@00>Il0001GBP002R@000<L000b@@00Q@X0
bk<00?TL003j5P00cjX000290@00>4@000@L00098`00E4`0<I`00>i1003`?@00U[T0001`<0006S80
008I000F;`00K3H0R;H00>i4003o0P00h7H003ZO0000ET/000TS00047000=T<008P20<nY003j5@00
n1h00<Vi0000PA8002`m00036`003BL005e505FW003VHP00o`000>UI001S[0000652000?:@000aX0
02Pk001n6037_P00mb800?/C003@Y`0008T1000f@`0011`000XT001HB@14XP00hfd00?l0003[D@00
KZl0001T?`0042X0008J000V>P00OAT0akl00?PQ003k5000cjX000271@00<T4000<K000;9P00G4L0
DZL00>IR003o0000ieh005RX0000GDD000`V00036`00<D0008H70<nZ003k5000mb800<K10000Nad0
02<h00026P004R`006Pj08:d003_A000o`<00=f0000WV@0004m>008000HP00`004m>02RI003MO`00
o`<00>i6001n/`0006Ll000A:`000QX002Lk001o5P39^0020?TK000C0<Vi0000OaH002Hj00026P00
4R`006Pk08>d003_@P00oP@00=^6000NU@0004Q;00057P00224005A<03bP003SKP00o`000>UI000:
ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`0IU000d:P00?LR003n2000
hGD005fZ0000JSP001dd00036P002R@004e>00B;0039^@00m2l00?l3003UI@00M;00001`<0008cP0
00<K00088@00@dT008H70<G3003b=P00o`400>QL0021]00007<[000W>P0011`000LP000oB000Q0/0
`L@00?8i003o0@00j5/008:d0000Lb/002Hj000370001b40045800262035``00lSD00?l2003WH@00
N;40001`<0008cP000<K00088P00BD`00XX00<Vh003e;000oPD00>=]001SZ`0006Xh000L<`000QX0
00/U001BC@0FTP00d:H00?PO003m2`00gH8004FR0000HD8001@]00026@004B/005a603FM003IS@00
o1000?XI003CWP007iH0001EB`0032L0008J000K<`00JCT0Hj/00>=/003o1000m3000<No0000QPL0
03m80006800011`002dn001j7`2Q_000kTH00?l0003ZE000R;H0001c:`0093T000<K00098`00CTh0
38h00<j/003h8@00o@/00=b3000oX@0005i5000A:`000QT001D^001S@01@YP00h7H00?h6003e:`00
I:420010B0001R0000@M000`@000OAX0[kl00?0m003o0@00iV4006n_0000JcH001/c00026P003BP0
05Q902jK003IS`00o0l00?TL003@Y`004900001?CP002B<000<K000X>`00Mb@0W;/00>i6003o0000
jEX007Vb0000KS<001dd00026P003BL005Q902nK003IS000o0d00?PO003>[@001hd00018B`001b40
00@L000_?`00OAT0]L400?8h003o0P00hf`005^Y0000ICh001D^00026@004bd006=005FW003RL000
o`<00?8f002h`@0007hH000_?`0011`000PQ001;C@0=S`00d:H00?TJ003k4P00eIT001bE0000DDd0
00TS00036`00:C`007TQ0:Vn003a?000o`800>AZ001JZ@0006@o000D;@000QT001H_001W?01V[000
iV800?l0003^A000V;X0001d:@008SP000<J000<9P00F4X0<Y`00=^6003m2@00mRT00<Nn0000P`d0
03E200047@001b0004U<00f?003AY000nQL00?XF003BX`003Xl00019C0001b0000@M000f@`00Q0/0
b;/00?HV003m2`00fHd002RI0000E4`000XT00036`00:Sd007`K0;S20000l`3c<P00oPH00=im000l
X00005Y8000<9`000aX002@i001g9@2U_@00lC/00?l3003QL`00BJ@0001MAP003RP0008J000P=P00
M2X0W;/00?10003o0P00hVl004fU0000GTD000lY00026P0083H007@Z09bk003`?`00o`800>9a0019
Y00005e6000>:0000QX0028h001f9P2V_@00lCT00?h4003ON@00?J00001IB@0032H000<K000X>`00
Nad0^l800?@_003n2000fhL002ZJ0000Dd`000TS00047000<T4008<=0<Vi003g8@00o1000=BL000A
T00004M;00067`001Ah0049900Z>003BX@00na<00?PN003;]@0008@:000c@@0011`000TS001DC00^
V`00g8<00?h6003b=@00Z[h0001f9P008CL0008J000@:P00HT40H:/00>MO003o0000jUH006f^0000
ICh0018/00026@007SD007<Z0::l003b>@00oPD00=f1000^V`0005=<00098P0011`003M400280P3?
Z`00nQL00?TK003</P0008D:000b@@000a`000XT001GBP0mX000l3`00>i40029]P0006`e000G<000
0QT001Tb001`<02F^@00l3d00?h4003NO`00;i/0001CC000228000@M000lAP06S000dZ400?`A003g
9000a/40001m6@009c/000<J000?:@00HD80HJ/00>QJ003o0000if4005NX0000GTD000dW00036`00
;3h0088@0<Zg003i7000nQL00<f_0000Q@T0035000036`0032H005a7052V003VI@00o`000>UI001Q
Z`000613000>:0000aX002/m00214P3:]`00nA`00?XI003</P0008<=000]?P000a/000dW001OA01O
ZP00jEX00?l0003UIP00C:D0001JB0002RD000@L000f@`01RP00dZ800?`?003f:000_<80001h8`00
7cH0008I000E;P00K3D0T;P00?4m003n1@00fXT001fE0000B4`000DN00078@00DTd0<id00>1g003o
0@00k4d0076_0000Hd0000lY00036P00:cd008<>0<f`003j5P00n2000<K00000Nad0028h00026@00
52h006/f096h003a>`00oPL00=V?000DTP00045800047@002B<005Q:04RS003UIP00o`000>MQ000:
ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`0SU`00dil00?TM003m2`00
gWd0056V0000ISd001Xb00026P002bD0055=00f?003</@00mRP00?h5003SK@00Ijd0001/=@007cH0
00<J00098`00BT`00HX00<Rk003d<000o`<00>IU001d/00006la000R>0000a/000PR0016B`00R080
akh00?<b003o0P00iV<007Fa0000L300028h00036`00228004Q;002:0038^`00m2h00?l4003TJ@00
Jjh0001/=@007cD000<J000:9000Cdh02hh00<f`003f9P00oPL00>1f001FZ00006Hl000I<@000QT0
00dW001FB`0PUP00dih00?TI003l3`00fXX003VO0000GDD0014[00026@004bd005m4042Q003LQ000
o@`00?PN003@YP005I80001BC@002bD000<J000N=@00KC@0Kjl00>IT003o0P00lSL00<330000PPl0
03U500067`001Ad00391001n602__`00l3l00?l0003XG000Nk80001`<00083L000<J000:9000DDd0
5Y800=6T003i7000o0l00=V<000cW@0005]8000?:@000QT001P`001W?01MZP00hfh00?l4003c<@00
Hj@6000jA@001Al000DN000e@`00PA80_L<00?8f003o0`00i6X006:[0000J3/001Pa00026@003bT0
05a703VO003KQP00o@/00?LR003=[`001X`00018B`001b4000@L000/?P00Nah0Z[h00?0o003o0@00
iV8006b^0000JSP001Xb00026@003bT005]703ZO003LQ000o@X00?LU003;]@0008T00011B0001R00
00DM000d@P00PA80`l@00?<a003n1000hG@004nU0000HD80018/00026@005Rl006Hm066[003UI`00
o`400?0m002Z_P0007XO000Z?0000a/000TS001@CP0GT`00dih00?XE003j5`00dZ8001:A0000CTh0
00PR00047000;Ch007dJ0;O1003b=@00o`@00>5c001>Y@000613000A:`000QT001Ta001Z>01c/000
j5X00?l0003/C000RkH0001a;`007cD0008J000>:000FdL0?Z000=im003n1P00m2l00<?40000OaD0
031000047000228004m>01NC003DV`00na800?TK003?Z`001H`00012B@001Ql000DN000lAP00R0<0
c;<00?PP003l3`00eYD001fE0000DDd000PR00047000;cl0080D0<G30000l`3e;000o@P00=b5000`
W00005I;000;9@000a/002Pk001j7`2c`000lc@00?h5003ON`00?J00001JB00032L000<J000T>@00
N2@0ZKh00?8i003o1000h7L0046Q0000FdL000dW00036P0093T007LT0:Zn003b>000oP@00=mj000n
X00005U8000<9P000aX002Lj001j7`2d`@00lc800?h6003MPP00<Y`0001FB`002R@000<K000]?P00
OaH0a/800?HY003m2`00f90001nF0000D4h000PQ00047@00=d@008L50<ba003i7000na@00=6T0007
S@00041800057P001R0004U<01BB003EV@00o0h00?LT0037_@00084B000^?`000a/000XU001GBP0i
W`00ggX00?l4003a?000W;/0001b;0007C@0008I000B;000ICd0KJh00>YG003o0000ieh0062[0000
HT40010Z00026P008SL007LT0;30003c<P00oPP00=Z:000TU`00051>00078@001Ad003e700J<003B
X`00na800?PP0039^P00084B000]?P000a/000`V001KB018Y000lCL00>a<001k/P0006Tj000D;P00
0QT001dd001c:`2S_@00lSH00?h6003KQ`0099P0001@CP001b4000DN0012B@0?T000eIT00?`=003e
:P00_L<0001j80008cP0008J000A:`00I3l0KZl00>]B003o0000i6T004^T0000FTP000/U00036`00
<D0008D80<f^003j5`00nA`00<Zg0000PA4002`m00036P003BP005m405bZ003XG@00o`000>MQ001E
Y`0005e6000<9P000a/0031000252P3=[`00nQL00?PN0039^P0007lE000Y?0000aX000lY001S@01[
[P00je800?l0003SKP00@J40001GBP002B<000@M000lAP0:SP00eIX00?d<003d;P00[[l0001d:P00
73<0008I000H<@00L300WK/00?8f003m2000f94001>A0000@DT000DM00088P00ED/0?Z000>=_003o
0000jUD006B/0000H4<000dW00036`00<40008H60=2X003k4P00mRH00;k30000Mb@001he00026@00
5c0006la09jk003c=000o@X00=JG000:SP0003]5000470002RD005]705BW003XGP00o`000>AY000:
ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0G`0^V`00eYL00?XH003l3`00
fhH004FR0000Hd4001L`00026@003BL005A<01NC003?Z@00mb800?h8003QMP00FjT0001Y>P0073<0
00<J000:9000Cdh02Xh00<bc003e:@00oPD00>=]001W[@0006`f000O=@000aX000TS001=CP06S000
b[H00?D[003n1000i6/006R]0000K3H001he00036P002R@004m>00V=003</`00mRP00?h6003RL@00
GZX0001Y>@006c<0008J000;9@00DTd05I800=2X003h8000o@X00=in001:Y00006=0000F;`000QT0
00lY001IB@0[VP00eYH00?/E003k4`00ei<002jK0000FTP000lY00026@005Rl006=004bU003OO000
o@T00?LS003=[P0038h0001?CP002B<000<K000R=`00L2l0OK<00>QK003o0@00l3h00;;00000OaL0
03A2008000DN04L003Q400214@2m``00lSP00?l2003VI000KZl0001/=P007C@0008J000<9P00ED/0
89H00=BL003j5`00na<00=ND000XV@0005M:000=9`000QX001/c001Z>01Y[@00iFH00?l2003b>000
GJ4:000d@P001Ad000HO000kAP00Q0/0a/400?@_003n1@00hW8005JX0000I3l001D_00026@004B/0
05m404BR003NOP00oPP00?HW003:]`0008P20011B0001R0000@M000b@@00OaH0^<800?8g003o0P00
i6X005nZ0000IS`001L`00026@004B/005m404JS003ON`00oPL00?D[0038_@0008D9000kA@020005
7P3I000jA@00Q@X0akh00?D[003n1`00gWd004>R0000GTD0010Z00026@006C4006Xh06j_003WG`00
o`000>m4002L^`0007HV000U>P000a/000XT001CC00QU`00eYD00?/A003i7000cjX000V=0000Ad/0
00LP00047@00<d40084B0<G4003d;`00oPH00=mk0012XP0005e6000?:@000QT001`d001^<`20/`00
je800?l0003ZE000OK<0001]=0006c<0008I000@:P00GT@0BJ@00>5e003n1000lSH00;C10000O1`0
02/m00036`002B<0059=026G003GT`00o0h00?PQ003;/`0008P3000lAP001Ah000HO0012B@05S000
cjX00?TK003k4`00dih001>A0000C4d000LQ00047@00=D8008@<0<Rk003f9P00o@`00=V>000VV000
05=<00098`000a/002dn001n6031a000m2h00?h8003LQ000<Y`0001FBP002bD000<K000Y?000Nad0
^<400?<b003n1P00gH0003JN0000EdX000/U00036`00:3/007/M0;S2003c<@00oPL00=f2000bW000
05I;000:9@000a/002/m001n6033a000mB`00?d9003JRP009iT0001BC@002B<000@L000b@@00P`h0
bKX00?LS003l3`00eIP001FB0000Bdd000LP00057P00?DL00h/00=2X003j5`00nAT00<j/0000R@40
03Y500047@001b4004m>01jE003HT000o@/00?DZ0033a00007dJ000Y?0000a/000`V001JB015XP00
hW800?l2003_A000S[L0001_<P006S80008I000E;P00JCT0N[800>a?003o0000iFH005BW0000GT@0
00hX00036P009SX007/N0;k3003e:`00o@/00=NB000IU00004]=000680001Ah004A:00n@003EVP00
o0h00?HV0035`P0007dI000X>`000aX000dX001NA@1DY`00lc<00>YD001^[`0006Dn000B:`000QT0
020g001g9@2a`000m3000?d9003HT0006Y@0001:C00200067`1]0019C00IT`00f9000?d9003d<000
[kl0001f9`007cH0008I000C;@00J3/0Nk800>e;003o0@00hW8003nQ0000EdX000XT00047000=d<0
08T00=2V003k4`00mb800<No0000OQT002Lk00036P003bT006=106V]003ZE000o`000>AY0019Y000
05U8000:9@0011`003E200290@3@Y`00na800?LS0035`P0007`L000T>@000QX0014[001V?@1h/@00
kDX00?l1003PM`00=Id0001CC000228000DN0013B@0DT@00f9400?d8003c=@00X;`0001`;`006C40
008I000K<`00Lb/0Zkh00?@_003m2`00eIX000V=0000>dD000@L000:9000FDT0BZ@00>EV003o0000
j5d005NX0000G4H000/V00037000=T<00XX00=>P003l3P00mB`00:no0000M2X001/c00026@006S80
07</0:bo003d;@00o0d00=>P0001RP0003E200036`0032H005i5062[003ZEP00o`000>9a000:oooo
o`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`0iW`00fHh00?/C003k4`00fHh0
03VO0000Gd@001@]00026@003bT005M:026G003BX000nAd00?d;003NOP00CZD0001U?P006340008J
000<9P00Dd`059800<n[003g8`00oPP00>5e001JZ@0006Pj000K<`000QX000/U001AC@0?T000cJh0
0?HU003n1`00hG@005^Y0000J3X001/c00026P002bD0059=01>A003?ZP00mb800?d9003ONP00DZH0
001U?P006340008I000=9`00ET/07iH00=>O003i6`00o0h00=^7000nX00005m4000C;@000QT0014[
001LAP0fWP00fHd00?`@003j6000e9/002>G0000EdX000dW00026@00634006Ll05VX003QL`00oPH0
0?DY003:]P000X/00018B`00228000<K000V>P00M2T0R[H00>YC003o0000kTD00:>m0000Nah002ho
00047@001R0003i700252@36`@00m3400?l4003SK000HJ/0001X>P006C80008I000>:000F4T0:YX0
0=NC003k4P00nQL00=BM000NU@0005A<000;9P000aX001he001^<`1f/@00j5d00?l1003`?`00EYh>
000_?`0011d000LP0011B@00R080bKT00?HY003n1`00ggX004VT0000HD8001</00026@0052d006=1
052V003QM@00oPD00?@^0037_`0008D:000kA@001Al000DN000gA000PPl0aL<00?@a003n1000hG<0
05>W0000Hd0001@]00026@004bd0069105:V003QL`00oP@00?<a0034a000084A000e@P001Ad000HO
0010B000R@40bkH00?LU003m2P00g8D003NN0000FTP000hX00026P0073@006dc07^b003YE`00o`00
0>a<002>]`0007</000Q=`000aX000`V001GBP0/VP00fHd00?`=003g8@00c;8000290000@4P000HO
00057P00>4@008D:0<Rl003f:000o@T00=b4000fWP0005U9000=9`000QX0020f001b;@2=]`00kD/0
0?l0003XG000L:l0001Z>@006340008I000B;000HT40EZP00>=]003o0P00lCd00:Jm0000N2<002Hj
00036`002bD005I;02bJ003JRP00o@/00?HV0038^`0008@;000f@`0011d000LP0019C00?T000dZ80
0?XF003j6000d:H000Z>0000ADX000HP00057P00>TD008L40<^c0000=`3h8000o0l00=JF000KU000
051>00088P0011`0039100224037_P00mRP00?d;003IS0009iP0001CC0002B<000<K000^?P00OaH0
aL@00?D[003m2@00fhT002^J0000E4`000XT00036`00;Ch007lF0<G3003e:`00o@X00=Z;000WV@00
05=<00098`0011`0031000214@37_P00mRH00?`=003GT`007ID0001?CP00224000@M000gA000Q`H0
c;800?PM003k4`00dZ4000^>0000A4X00P001Ql0^P00A4X038l00=>P003k4P00n1h00<^e0000Q@T0
03A2000470002B80059=02VI003KR000oPP00?@a002e`@0007TQ000U>@000aX000hX001NA@1AYP00
i6T00?l0003]B`00PK@0001[=`005c00008I000H<@00KCD0QkD00>i7003o0@00hfl004RS0000FdL0
00`V00036`00:Sd007lG0<K0003f9@00o0h00=BK000?T00004A:00057`001R0004]=01VD003GTP00
o@/00?D/002j`P0007XP000T>@000QX000lZ001Q@P1QZ`00m2h00>QL001QZ`000692000?:@000QX0
02Di001k7P30``00mBT00?`=003EV00049000013B@001Ah000LP001?CP0SU`00fhP00?h6003b=`00
XK`0001b;@006c<0008I000F;`00K3H0RKH00>m3003o0`00ggX003>M0000E4`000PR00047@00?DH0
28d00=>N003l3P00mRP00<330000NR0002<h00026P004R/006Hm07Ja003/C@00o`400>9b000mX000
05I;00098`0011d003]500N<003CWP00o0h00?DY002k`P0007PS000P=P000QT001@]001Z>026]@00
kd<00?l3003NO`00:YX0001@CP001b0000HO001:C00NU@00fXT00?h6003a?000T[P0001]=0005Rl0
008I000O=@00MbD0^L800?HY003l3`00dZ80002:0000=D<000<L000;9@00G4H0EZP00>MN003o0000
iFD004^T0000FDT000XT00047000?4H02hh00=JG003m2P00lc<00:6l0000L30001P`00026@007C@0
07HV0;[2003f9`00na400=2X0000QPH002lo00036`003RP0069106f^003/CP00o`400=mj00[ooooo
0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o04FS003KQP00o0l00?XG003FU`00
;Y/0001LA`004B/0008I000A:`00FdL0;9X00=FH003j6000o0l00=^70012XP000692000F;`000QT0
00hX001FB`0NU@00dZ800?PN003m2`00gWh004jU0000ICh001Pa00026@0032L005A<01VC003AYP00
n2000?d:003NO000CjH0001U?P006300008I000=9`00ED/07ID00=:R003i7@00o@`00=f20016X`00
0691000E;P000QT000lY001IB@0ZVP00eYL00?XF003k4P00f8l003>M0000G4L0014[00026@004bd0
0613046Q003LQ000o0`00?TM003AY0006I<0001CC0002bH0008J000L<`00JSP0IJ`00>A[003o1000
m3000<Nn0000Q`D004580007800011`002/m001h8`2H^P00kD`00?l0003/C@00UKT0001g9@00:C`0
00@L00078@00A4X008T00<Vi003e:P00oPH00>5e001DY`0006Dn000F;`000QT0010Z001KA`0fWP00
fX/00?`>003i7000dJD001BA0000DDd000XT00036P008SP0078]08Be003ZE@00o`000>i7001?VQ40
02Xl00047000224004Q<00J<003=/000mb<00?d:003LP`00?J00001MAP0042X0008I000G<000ISd0
GJX00>=]003o0`00lc@00;o30000PA8003E200057@001Ql003e700261P38^`00mBX00?h7003ON`00
Aj<0001OA0004B/0008I000F;`00ISd0GZX00>AZ003o0P00lSP00;G10000OQT002lo000470001b40
04M;00N<003>[@00n1l00?`>003ISP00;9X0001GBP0032H000<J000P=P00LBh0R;H00>a?003o0000
jU@0082d0000Kc4001de00026P003RP005Y803NN003LQ000o@T00?HW0039^P0008H8000jA@001Ah0
00HO000nA`00R080bk@00?LS003m3000fH`002^J0000ET/000/U00036P0093T007DW09^k003_@`00
o`400>IT001S[00006Hm000E;P000QT001D^001V?@1RZ`00iV@00?l1003_A000V;X0001d:@008SL0
00<J000<9`00FDT0=ih00=f2003n1`00mBd00<G30000P1<0031000047000228004m>01RC003EVP00
na400?PM003=[`0008X0000nA`001Ah000HO0011B004R`00cj/0000b0?TK003k5000dil0016A0000
BT`000LP00047@00=d@008H80<Zf003g8P00o0h00=JE000LU@00051>00088P0011`003=100233P38
_000mRD00?`<003HT@0089H0001AC@00228000@L000b@@00P`h0b;/00?LU003l3@00ei<001fE0000
D4h000PQ00047@00=T<008D90<^e003h8000na400=BK000BT@0004U<000680001Ah003e700:;003?
ZP020?XH002o0<nY0002RP0003e600057P001b0004]=01JB003FU`00o0h00?LT0038_@00084A000_
?`000a/000XT001FB`0dW@00gWl00?h5003b=`00Ykd0001e9`0083L0008J000@:P00HD80GJX00>MQ
003o0000je<007>`0000Ic/001@]00026@006c<0070_09Fi003`@000o`<00>1g000lX00005Q:000:
9@000a/002lo00223`39^000n1l00?/C003AX`001X`0000nA`001Ad000LQ001@CP0TU`00fXT00?h7
003c<`00[;l0001f9`0083H0008I000B;000ICh0KZl00?DZ003VI000EJL0001NA@003BP000<J000Y
?000OQL0akl00?LS003k4@00dZ4000J<0000?DH000@M00088P00DTd0;Y/00=io003n1000l3h009>h
0000KS8001Pa00026@006C4006la09Ji003a?000oPD00=b3000XV@00051=00078@001Ah004=901:A
003FU@00o@/00?@^002b`00007HV000O=@000QT001@^001Z>024]000kTD00?l2003ONP00<Y`0001C
C000228000DN0011B00@T000eYH00?d:003d<000[;l0001d:@0073@0008I000G<000KC<0TkT00?4l
003n1@00fhP001nF0000Bdd000HO00078000Cdh0:9T00=f0003o0`00kd<008Be0000JCT001<]0002
6@008SP007/N0<G3003g8`00na<00<n[0000QPP0031000036`003BL0061306>[003ZEP00o`000>=]
000oX@0005I;00088P001Ad0049901FB003HS`00oPL00?4j002C^@0006`e000E;P000QT0024g001j
7`35`P00mb400?XF003=/000088?000Z?@000aX0010Z001U?P1k/P00kTH00?l3003MPP002_ooool1
o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo00d0DJH00=im003m2`00nAd00=>O000S
U`0005Q9000?:@000QT001<]001NA@0gWP00f8l00080na<00?l0f8l003NN0000GTD001<]00026@00
42X005U802VI003EVP00nQT00?`>003KQ`00@Z40001Q@P005Bh0008I000>:@00F4X08iL00=BM003i
6P00o0h00=b50013XP000652000E;P000QT000lY001IB@0WV@00eIT00?XH003l4000fX/003ZO0000
GTD0018/00026@004B/005e603FM003ISP00na400?XF003EV000:9T0001HB@003RT0008I000F;`00
I400CJD00=ml003m2@00mb<00<j/000?T000051>000:90000aX001lf001^<`1b/000iV800?l2003b
=`00`L@000233P00>dD000HO00047@00<40007`L0:Jm003_A000o`000>YE0028]P0007<[000U>@00
0a/000PR001<C@08S@00cK000?LT003m2@00gWd004RT0000HD8001@]00026@004R`005m4046Q003M
PP00o@X00?LR003=[P002Xh0001<C@00228000<K000V>P00MBL0T[P00>a=003o0000k4h004RG5@00
9CX000<K00098`00Cdh03i000=2X003h7@00o0h00=V<000bW00005Y8000>:0000QT001Xb001Z>01Z
[@00iV@00?l1003a>`00/L00001m6P00;cl000@L00078000A4X00HX00<^c003g9000o@X00=b4000k
W`0005a7000?:@000QT001Tb001Z>01[[P00iV800?l1003`?`00Ykd0001j8000:Sd000<K00088P00
CTh049000=6U003i6P00na800=JG000QUP0005=<000:9@000aX002@i001e:02F^@00kTL00?l0003X
G000Lk00001[=`006S80008I000@:P00GDD0@j800=mk003n1P00m2h00<G20000PQ0003A200047@00
1b0004E:00J<003>[000nAd00?`@003FU@0089H0001CC@002R@000<K000X>`00NB40ZKh00?4l003o
0P00hf`005JX0000HT40018/00026@00630006Ti06n_003XG000o`000>e<002:]P00070_000N=@00
0QX000hY001LAP13XP00ggT00?h5003c<`00^<80001l6`00:cd000<K00098`00DTd08iL00=RA003l
3@00mb<00<Zg0000QPL003Q400057@001b0004Q;00f?003BX`00nQH00?XH003@Z0001hd00013B@00
1Ql000DN000nA`00RP00cJh00?TL003k4`00dih001:A0000BTd001h000LP00057@00>D@008L60<^d
003h7`00o1000=FJ000FTP0004e>00078@0011d003Q400271P3;/`00n1l00?/A003DW0004i40001:
C0001b0000DN000lAP00R@00cZd00?TJ003j5@00dJ@000V=0000@TT200067`1X0014BP0<SP00dZ40
0?/C003i7@00c;8000271P00=d<000@M00088P00D4h089H00=R?003m2P00mBX00<C40000OAT002Xl
00036`002bH005U903nQ003PMP00o`<00?0o002I^P00078]000M=0000QT0018/001U?P1Z[P00jET0
0?l0003XF`00IZ`0001T?`004B/0008I000O=@00M2T0Xk`00?8h003n1@00gH00032L0000E4`000TS
00047000=D8008H70<f`003i6P00nQL00<j/0000R08003M4000470002B8005=<02nK003MP000oPD0
0?4j002N^`00078]000L=0000QT001@^001Y>P1k/P00mRL00>=]0019Y00005]8000;9P000a/002ho
00223`3:]`00n1h00?XE003?Z@0008P2000f@`0011`000TS001FB`0jW`00h7H00?l2003^A@00QKD0
001[=`005Bl0008I000L=000Lb/0YKd00?<e003n1`00fX`001jE0000C4d200067`1J001:C@0LU@00
fHd00?h8003c=@00Xkd0001b;0006c<0008I000G<000KC@0TKP00?0n003n1000g8<002NH0000Cdh0
00LP00067`00B4`06Y@00=V=003n1`00lSH009jk0000L2l001Ta00026@006S80074^0:6l003c=000
o@P00=RA000ETP0004A:00057P00224005=<03BM003PM`00o`800>e;001g/@0006Dm000A:`000QX0
02Lj001o5`39^`00n1d00?XH003;/`00088@000[?@000aX000lY001S@01`[`00k4h00?l1003PMP00
=9d0001BC@001b4000DN0019C00OUP00fhH00?h4003_@@00Q[D0001Y>P004R`0008J000U>P00OQP0
bKX00?TL003i6`00bKP0001o5P009SX0008J000B;000JCT0R;H00?0o003n1@00fX/02_ooool1o`00
007ooooo000Nooooo`03o`000?oooooooooo00Oooooo05@0GZX00>5d003n2000mb800=2X000HT`00
05E;000=9`000QT001H_001R@@13XP00fhH00?`?003j6000eIP002^J0000FTP0010Z00026@004R`0
05e603BM003HT@00na@00?/C003HS`00=Yh0001MA@004R`0008I000A:`00FdL0;Y/00=NE003j5@00
na800=V>000gWP0005i5000B;0000QT0014[001LAP0cW@00f9400?/C003k5000ei@002jK0000FdP0
010Z00026@0052d00613046Q003LQP00o0d00?TK003BX@007ID0001EB`0032L0008J000I<P00Ic/0
FZT00>5c003n1P00mRT00<^e0005S00004]=00098P000a/002<h001b;@20/`00jEX00?l0003`?P00
//00001o5P00=D8200057P2c000e@`00OaD0]<400?4l003o0@00j5d007Zb0000L300024g00036P00
2R@0051>01:A003@Z000n1h00?d<003KQP00?:00001NA@004B/0008I000E;P00HT40CJD00=mi003n
1`00mRP00<Zf0001RP0004E:00078@0011`002/m001i8@2P_000kTH00?l0003ZEP00@I<H000Q=`00
0aX000XU001BC@0JU000dil00?XH003k4P00ei@002NI0000ET/000`V00026P007C@006dc07Na003X
G000o`000>m3002S_00007TQ000Z?@0011`000PR001;C@0;SP00cj/00?PN003l3P00fHd002nK0000
F4T000dW00026P007C@006dd07Ra003YFP00o`000>i7002I^P0007HV000V>P000a/000XT001AC@0J
U000e9`00?XE003j5P00dil001NC0000D4h000TS00036`00:C`007TR0:Bm003`@000o`400>IT001V
[00006Lk000G<0000QT0018/001Q@P1?YP00hG<00?l4003c=000^/80001n6000;cl000@L00088@00
C4d049000=6S003j6000naD00=>N000FTP0004m>00088P0011`002dn001m6P2h`@00lcD00?h4003Q
M@00BZ@0001OA00042X0008I000K<`00KC@0OK<00>YD003o0000jU@007fc0000KC@001Xb00026@00
4B/0061304nV003RL000o`<00?4j002Z_P0007TR000W>P000a/000/U001FB`0^V`00fhP00?d:003f
:@00akl000224000<d4000@L00088@00Cdh05i<00=FJ003k4@00n1h00<f`0000R@4003e600057P00
1Ql004A:00V=003AYP000P3j5`005`3@YP0028d00013B@001Ql000DN000oA`02R`00cZ/00?TJ003j
5@00dZ8000b>0000ADX000HO00057P00?TL00XX00<n[003i6@00nQH00=6U0009S@0004=9008000HO
0;@0049900R=003AY@00nQH00?TJ003>[00008T0000lAP001Ah000LP001;C@0ETP00eIP00?`?003g
8`00bKX000233P00<D4000@L00098`00Dd`0:iX00=^6003n1`00m3400;K10000NR0002Dj00036P00
3BP005e604^T003SKP00o`400>i6002;]P0006hc000I<P000QT001D^001Y>P1h/@00je400?l0003V
H`00FJT0001P@`003bT0008J000S>000N2<0/L000?<a003n2000fXT002FH0000DDd000PQ00047@00
>dD00HX00=2X003j5@00nAd00<^d0000Q0/00391000370002R@005M:03ZO003PN000o`<00>m1002@
^00006hb000I<@000QT001L`001/=@29]P00mb@00>5e000mX00005M:000:900011`003=200261`3=
[`00nQP00?TJ003</P0008D:000a@0000a/000/U001IB@15X`00hfh00?l1003/C@00N;40001W?000
4b`0008I000P=P00MbD0/l000?@^003m2`00ei@001>A0000ADX000DN00078000D4h09iP00=b4003n
1@00lC`009Fi0000Kc8001Pa00026@006S80074^09nl003b=P00oPL00=V<000LU@0004U<00067`00
1R0004m>02FH003LQ000oPD00?0n002@^00006dd000F;`000QT001dd001e:02``000m2h00?d<003E
V@002hh0000mA`0011d000TS001FB`0oX@00hfl00?l0003[D`00JJd0001R@@003RT000<J000[?@00
PPl0c;800?XH003h7@00b;/0001n60009SX0008J000A:`00Ic`0OK<00>i6003o0`00gWl002RI0000
Cdh20006800H001?CP0ZVP00gWd00?l2003]B000N;40001U?P0042X000<J000Z?000PQ00c;800?XG
003h8000a/40001k7P008SL0008I000E;P00KC@0U[T00?8g003m2000ei@02_ooool1o`00007ooooo
000Nooooo`03o`000?oooooooooo00Oooooo0?l0Jjh00>=/003n1@00mRP00<f`000>S`00055=000;
9P000QX001Ta001V?@1?YP00gWh00?d;003h7@00dZ40022F0000EdX000hX00026@005Bh0065303nQ
003KR000o0l00?XG003EV000:iX0001JB00042X0008I000C;@00Gd@0>Yl00=V<003k4@00nQH00=JG
000/VP0005Y8000@:P000QT001@]001P@`0nX000fhP00?`?003i6@00e9`002>G0000EdX000hX0002
6@005c0006@o04fU003NO@00o@X00?PQ003?Z@004i40001BC@002bD000<J000M=000JcL0Ijd00>AZ
003o1000m2l00<Rm0000R0<004=900078@0011`002Pk001e9`2>]`00je800?l0003^A@00Y;d0001k
7@00;cl000@M00067`00>dH008<=0<?4003b=@00o`800>EU001][P0006`f000M=0000QX000/V001D
C00LU@00dil00?TI003l4000fHl0036L0000FTP000lY00026@005c0006Hm05ZY003RL000oPD00?@^
0037_P0008H7000nA`001R0000@M000`@000OAX0[[l00?0n003o0@00iel003Z?6P007C@0008J000<
9P00ET/099P00=JG003k4`00nQL00=BM000LU@0005=<000;9@000aX0024g001a;P25]@00jU@00?l0
003]BP00U;T0001e9`009SX000<K00098`00D4h05I800=:R003i6@00na800=JE000TV00005E;000;
9P000aX0020g001a;P26]@00je800?l0003/C`00RkH0001b;0008CL000<J000;9@00ED/09IP00=ND
003l4000nA`00=2X000=S`0004]=00088@0011`002dn001m6`2c`000lSP00?l3003SK@00FJT0001T
?`0052h0008I000E;P00ICh0G:T00>AZ003o0P00lC`00:^o0000NQl002Xl00036`002B<0055=01ZD
003DV`00na<00?TJ003@YP0038l00019C0001b4000@M000b@@00PA80aL<00?@^003n1`00gWh003jP
0000FdL000hX00026P007SD0074_08Zf003]C000o`000>QL001_[`0006Ti000G<0000QT001<]001S
@01LZ@00iFP00?l1003_@P00Vk/0001e:0008SP000<J000=9`00FDT0>Il00=eo003n1`00m2l00<33
0000OQL002dn000370002B<0059=02:G003HT@000?<0o0d00?LS0039^00008D9000g@`0011d000LQ
001;C@0CT@00e9d00?/B003i7@00cJl000290000?DH000DN00068000ATX038h00=:S003j5@00nAX0
0<n[0002R`0003m700057P001Ql004E:00^>003BXP00naD00?TK003>[@0008T0000lAP001Ah000LP
0019C00BT@00e9`00?/A003h7`00bkD000252000=T<000@M00088P00D4h089H00=R@003m2`00mRT0
0<G20000OaH002`n00036`002RD005M:03NN003NO@00oPD00?8h002W_@0007HW000Q=`000QX000lY
001P@`1HZ000iFD00?l0003/CP00OK<0001Z>0005Rl0008I000H<@00K3D0QKD00>e9003o0@00hf`0
04fU0000GDH000dW00036P009c/007`L0<33003e:`00o@/00=RB000KU00004e>000780001Ah00458
00^>003CW`00na400?LR0038_000080C000/?P000a/000`V001JB016X`00hVl00?l1003]B@00P[@0
001[=`005Rl0008I000J<P00L300UkT00?LQ003NOP00<I`0001DC0002B8000@M000iA@01RP00d:H0
0?/D003h8000bKX000214P00;3d000<K000<9`00GDH0DZH00>EU003o0000jUD006Z^0000Hd00010Z
00026P0093T007/N0<74003f:000o0h00=BM000:SP0003i700047@00228005=<03:L003ON`00o`<0
0>m30027]@0006/g000E;P000QT001he001e:02^_`00m3000?d:003GU@004Y400012B@001Ah000PQ
001BC@0`W000gg/00?l3003^A@00P[@0001Y>@004bd0008I000Q=`00NB80_/<00?HW003l4000dZ80
00::0000=d<000@L000:9000FTP0Bj@00>EV003o0000j5/005bZ0000GTD000`W00036`00<D0008H7
0<nZ003k4`00mb<00<G30000NQl0028g00026@0052d006Xg08^f003`?`00oPD00=^7000NU@0004Q<
00057P001b4005==03FM003QM@00o`400>]@001[[P000652000>:0000a/002lo0026203?Z@00na80
0?HV002m``0007LU000N=@000QT001P`001`;`2T_@00m3400?d<003DW0002_ooool1o`00007ooooo
000Nooooo`03o`000?oooooooooo00Oooooo07@0N;400>IS003o0`00m2l00<Vi0005S00004i>000:
90000aX001`d001Y>@1LZP00hGD00?h8003g8`00cjT001JB0000E4`000`W00026@00630006@o04bU
003MP000o@/00?TM003BX@0089H0001FBP003RP0008I000F;`00HT40AZ<00=b3003l3@00nA/00=>O
000QUP0005M:000>:0000QT001H_001S@01:Y000gWl00?d;003h7`00dJD001VC0000E4`000`V0002
6P006S8006Lk05VY003QM000oPL00?HW003</P002Hd0001>CP002B<000<J000Q=`00Kc80M;000>IR
003o0P00lSH00<C40000Q0`003e60006800011`002dn001i8@2L^`00kDX00?l0003/C@00U[T0001g
9000:Sd000@L00078000@TT008L40<Nm003d;P00oP@00>=^001OZP0006Pj000I<P000QT000dW001G
BP0WV000eYL00?/D003k5@00eYL002FH0000EdX000dW00026P006c<006Xh06N]003UJ000o`800?8e
0031a000088@000hA08000DN0>L003I300214P2m``00lSL00?l2003UI`00=8/M000J<P000QT000hX
001IB@0_V`00fHh00?`?003i7000d:H001:A0000Cdh000TS00036`009CX007DX09>h003]C000o`00
0>]B0026]@00078]000Q=`000aX000/U001CC00OUP00eIX00?/D003j5P00dih001VD0000DTd000XT
00036`009CT007DX09Bi003]BP00o`000>UG001m/`0006hb000N=@000QX000dW001HB@0`W000fX/0
0?`<003g8@00cK0000>;0000A4X000LP00047@00<d40080C0<;4003c<@00oPD00>5e001<Y@000613
000A:`000QT001L`001X>P1Y[@00iV800?l1003_@`00WK/0001f9P009CX000<K000:9@00E4`09IP0
0=NB003l3`00n1l00<f_0003R`00049900067`001Ah003Q400252P38^`00mRL00?d:003KQ`00<Y`0
001HBP0032H000<J000R>000M2T0VKX00>m4003o0@00iV@006:[0000ICh001@^00026@005Rl006Lk
06V]003WG`00o`000>e9002=]`00074^000N=@000QX000hY001MAP15X`00h7L00?h4003b=P00/L00
001j7`00:3/000<K000:9@00ED/0;I/00=^8003m2@00mBX00<K00000PA800350000470002280051>
01fE003GU000o0h00?LR003:]`0008D9000f@`0011d000LQ001=CP0FTP00eIX00?`A003h7`00bk<0
00271P00>4@000@M00078@00C4d05I800=FJ003l4000n2000<^e0000Q@P003I300047@00224004m>
01bE003GT`00o0d00?HU0037_@00088A000`@00011`000TS001DC00[VP00fhL00?h8003d;`00^/80
001k7@009c/000<J000<9P00FTP0@Z800>5e003o0`00l3l009Vj0000LRd001dd00026@004R/006@o
06F/003XG@00o`000>YF001_[`0006Ll000C;@000QT001/c001`<02C^@00kd400?l2003QM@00@J40
001IB@002bD000<K000/?@00P1D0akl00?LU003l3`00eIX0012@0000ADX00P001Ql0T`00B4`05I80
0=JF003l3@00mRP00<G40000OAX002Pk00036P003BP005i505:W003UIP00o`000>]A001d/00006Ll
000C;@000QT001he001d:P2U_@00n1h00=^7000VV000051>00078@001Ah003m800Z>003CWP00o0l0
0?HU0035`P0007dJ000W>`000aX000hY001P@`1OZP00j5d00?l0003XGP00GJX0001P@`003RP000<J
000X?000OQL0akh00?LR003k4P00dJH0002:0000>4@000@L00098`00EdX0?Z000>5b003o0@00kD/0
07Vb0000Ic`0018/00026@008CL007TR0;c3003f:@00o0h00=BM0008S@0003a600047@002B<005E;
03^O003QL`00o`400>a=001e/00006Dn000A:`000QX002Di001m6`36`000mb400?/D003?ZP0008H6
000a@@000a/000`V001MAP1HZ000ieh00?l0003VH`00D:H0001KB0002bD000@L000f@`01RP00dZ40
0?`?003e:@00^<40001f9P007SD0008I000G<000KS80VKX00?8g003n2000f90001>A0000@DP000DM
00098P00ET/0@J400>=/003o0000jEP005jZ0000GTD000`V00036`00=48008X00=:Q003l3P00mB`0
0:jo0000Lb/001Xb00026@006c<007@Y0;?0003e:P00o0l00=6U000:ooooo`7o00000Oooool001ko
oooo0ol00007ooooo`3o08Je003XF`00o`400?8f0036`@0008P30016B`00228000<K000P=P00KC@0
JJd00>=/003n1@00mRT00<bb000<SP00051>000;9@000QX001/c001X>`1HZ000h7L00?d8003g8P00
cjT001FB0000Dd`000`V00026P006C4006Hm05:W003ONP00o@T00?PQ003@Z0005Y80001CC00032H0
008J000J<P00Ic`0EjP00>1f003n2000mb@00<j^000>S`00051=000:90000aX001dd001[=`1V[@00
i6/00?h4003d;@00bKX000290000Ad/000PR00036`009CT0078/08:d003YFP00o`000?0m002e`@00
080D000g@`001Ah000DM000b@@00OAX0Z[h00>m2003o0000jUD008Rf0000M2X002Hj00036`002280
04U<00B;003;]@00mRP00?h7003PM`00DjL0001T?`005Rl0008I000?:@00FdP0<Y`00=V>003l4000
nAX00=:P000KU00005=<000;9@000aX001he001^<`1d/000iel00?l1003a?000//00001n6000<T40
00DM00067`00?4H008D:0<K1003d<000oP@00>9`000]R1l001L`00026@0042X005e603^O003LQ@00
o@/00?LQ003=[P0028d0001:C000228000@L000Z?000NB40XK`00>m4003o0000j5/007Vb0000KS<0
01de00026P0032L005M:02ZJ003HT@00o1000?TL003@Y`003i00001>CP00228000<K000Y?000NB80
X[`00>m2003o0000iel006n_0000JcL001Xb00026@003bT005a703bP003MPP00o@T00?HW0039^@00
08L5000mAP001Ql000DN000iA000Q0/0akh00?D[003n1`00gWh0042Q0000GDH000lY00026@006c<0
06`e07Ja003YF@00o`000>e;002?]`00078/000Q=`000aX000`V001GBP0`W000fXT00?d;003g9@00
b[L000271@00>dH000DN00067`00?TL008T10<bc003g8@00o0d00=R?000WV@0005A<000:90000a/0
02Lj001h8P2W_@00lC`00?l2003SK@00EJL0001R@@004R`0008I000I<@00JcL0M[400>UG003o0000
je4007nc0000KC@001/c00026@004B/0061305:V003SKP00o`800?0m002S_00007HV000T>@000aX0
00`V001IB@0hWP00gH00003c0?h6003d<000_L<0001m6@00;3d000<K000:9000E4`0:9T00=Z;003m
2P00mRP00<No0000PA400350000470002280055=022F003HT@00o0`00?LU0038_00008<>000b@@00
11`000PR001AC@0PUP00f9400?d<003f9P00akh000224@00<40000@L00098`00Dd`09iT00=Z:003m
2@00mB`00<?40000OQP002/m00036`002bD005M:03JN003NOP00oPD00?8f002[_`0007LT000S>000
0QX000hX001NA@1?YP00hf`00?l1003^A`00RkH0001^<P006S80008I000D;P00Ic/0L[000>YD003o
0000ieh006:[0000Hd00014[00026@007cD007@Z0::l003a>P00oP@00=im000eW@0005I;000:9000
0a`0035000233@3:]`00n1l00?/C003AX`001h`0000nA`001Ah000LQ001?CP0OUP00fHd00?d9003d
;`00]/40001i8P008cP0008J000?:P00HD80GjX00>MN003o0000jET006N]0000Hd00010[00026P00
8SL007PS0;C1003i7000f8l001^D0000Bdd000HP00067`00AT/059800=JE003m2`00mB`00;[20000
NB4002<h00026P004B/006@o06b^003ZE000o`000>EV001@YP0005a6000<9P000a/002dn00223`3:
]P00nA`00?XG003=[P0008H8000b@@000a/000/U001JB01:Y000i6X00?l0003ZD`00K:h0001S@000
42X0008J000V>P00OAX0a/400?LS003k4P00d:H000290@00=T<000@L000:9000FDT0B:<00>AZ003o
0000jUD006N]0000HT4000lY00036P00:S`0080C0<Zh003i7000nQT00<bc0000PPl002`n00036P00
3RP0065206F/003ZE@00o`000>=/0013XP0005M:00098`0011d003a600^>003EV@00o@/00?@`002Y
_P0007</000J<P000QT001Xb001b;@2W_P00m3000?d;003EV@002Hd0000kA@0011`000XT001IB01=
Y@00iV<00?l0003WH@00DJH0001JB0002R@000@L000jA@0:SP00eIP00?d:003c<`00X;`0001_<@00
5c00008I000O=@00N2<0`/@00?LT003k5000cZh000Sooooo0ol00001ooooo`007_ooool00ol0003o
ooooooooo`07ooooo`3o09Bi003[DP00o`000?0m002l`P0008@<000oB0001b4000<K000T>@00LBl0
Mk400>IS003o0`00m2l00<Vj0002R`0004]=00098`000aX001le001/=P1U[000hfh00?h5003f:@00
c;8000^>0000D4h000XT00036P0073@006Xi05nZ003RL@00oPH00?HW003</@0038h0001@CP002R@0
00<J000M=000JcL0I:`00>=^003n1@00mB/00<Zf0005S00004]=00098`000a/0024g001_<@1d/000
iV<00?l2003c=000aL8000252000@4P000LP00047000:C`007HV092h003[D@00o`000>i5002V_@00
07`K000a@0001Ad000HO000hA000PA80^L800?4k003o0@00j5h007Zb0000L300024g00036P002B<0
04m>00f?003>[000mb800?d:003MO`00AZ<0001Q@P004bd0008I000B;000GTD0?Z000=b5003m3000
n1l00<nY000@T000051>000990000a/0028h001a;P22]000jEL00?l0003_A000Xkd0001j7`00;Ch0
00@L00078000@dT008T10<Vh003e:@00oPL00>1i000WQ24001@]00026@004R`0061304NS003NO000
oPP00?HX003:]`0008T10012B@001b0000@M000_?`00OAX0[kl00?4l003o0@00iV<006^^0000JSP0
01Xb00026@003RT005Y803JN003KR000o@`00?LQ003=[`001H`00017B`001b4000@L000^?`00OAX0
/L000?4j003o0P00iFP006:[0000Ic`001L`00026@004B/005m404RT003ON@00oPH00?@^0036`@00
08<>000g@`001Ah000HO000oA`00R080bkH00?LT003m2`00fhL003BM0000FDT000dW00026P007SD0
070`08Be003[D@00o`000>]C0021]00006lb000M=0000QX000hX001KA`0lX000gH000?h8003e:`00
a/0000233P00=D<000@M00078000ADX01hd00<nZ003i7000na400=FH000LU@00055=00098`000a/0
02`m001l6`2f`@00lSD00?h4003PMP00B:@0001NA@003bX0008I000L=000Kc80Q;D00>a?003o0000
jEX0076`0000JCT001L`00026@004bd006@o05nZ003UI@00o`400>i5002D^@0007</000P=P000QX0
00hX001LAP14XP00h7L0003c0?h4003b=`00[[l0001i8@009c/000<K000;9@00EdX0=9d00=b3003n
1`00m2l00;o30000OAT002`m00036`002R@005A<02^J003KR000o@T00?D[0035a00007lF000]?P00
0a/000XT001DC00[VP00fhP00?d9003e;@00`/@0001n6000:cd000<K000:9@00ET/0<id00=f2003n
1P00lc800;C10000NR0002Hj00036P0032L005Y804:R003QM@00o`<00?0m002M^`0007<[000O=@00
0QT0010Z001Q@P1LZ@00iV<00?l0003/C`00OK<0001Z=`005c00008I000G<000JcH0P;<00>a<003o
0000iFL005FW0000Gd@000lY00026P008cP007PS0;30003c<P00oPL00=^6000YV@00059=00088P00
11`003M30027103=[P00nAT00?XH003>[00008P2000hA00011d000PR001BC@0ZVP00g8D00?h6003b
=P00Ykh0001e:0007cH0008I000B;000ICh0KJh00>YF003o0000iV4005ZY0000H4<000hX00036P00
9SX007`L0<?4003i6`00eIP0016@0000A4X000DN00078000CTh07iH00=V<003n2000lc<00:^n0000
MBP001he00026@004bd006Pk07Vb003/C000o`400>=_0014XP0005U9000:9@000a`003=100261`3>
[@00nQL00?TL003:]`00088@000]?P000a/000dW001NA@1FZ000if400?l0003XG000GjX0001P@`00
3RP000<J000Z?@00PA<0bKT00?PM003j5`00cJl000252@00<40000<K000<9P00GDH0E:L00>IQ003o
0000j5d005ZY0000GTD000dW00036`00;cl008@;0<f_003j5`00n1h00<Rk0000OaL002Lk00026P00
42X006@o07:`003/C@00o`400>5d000gWP0005A<00088P001Ah004=901FB003HT000oPP00?8g002K
^P0006lb000G<0000QT001dd001f9`2f`@00mBX00?`?003BXP0008X0000e@P000a/000`V001MAP1J
Z@00j5/00?l0003TJ@00A:80001GBP002B<000@M0011B00DT@00f8l00?h7003a>P00TKP0001/=P00
52h0008I000S>000O1`0akh00?PN003j6@00b[H000[ooooo0Ol00001ooooo`007_ooool00ol0003o
ooooooooo`07ooooo`3F0:>l003]BP00o`000>i5002]_`00080D000iA0001Ql000@L000Y?000MBT0
QKD00>QK003o0@00lSL00<G20000Q`H004A:00088P000a/002<h001_<@1c/000iFD00?l3003d;`00
bKX0006:0000BT`000TS00036`0083H006dd06f^003TJ@00o`@00?@^0039^@000XX0001:C0002B<0
00<K000Q=`00KS80L[000>EU003o0`00lc400<Nn0000R0@004A:00088@000a/002Dj001c;022]000
jEX00?l1003a?000^L8000214@00>DD000HO00047@00;Sl007XO09jk003]B@00o`000>a=002H^P00
07PS000/?@0011`000HP000nA`00Q@T0aL800?<c003o0P00iFH006b^0000K3D001dd00036P002bD0
05==01RC003AY000nA`00?`>003KR000>Yl0001MAP004B/0008I000D;P00HT40BZ@00=ml003m2000
mbD00<bb0006S00004Y<00088P000a/002Lj001e:02@^000k4l00?l0003/C000UKT0001f9P00:3/0
00<K00088P00BT`01hd00<f`003g8`00o@X00=f2000PP2<0014[00026@005Bh006@o05BW003QL`00
oPD00?@^0037_`0008D9000lAP001Ql000DN000e@P00PA80_/<00?8e003o0`00hf`005jZ0000ISd0
01L`00026@004B/005i504:Q003NO`00o@P00?HW003:^00008P30010B0001Ql000DM000d@P00PA<0
`<<00?<c003o1000hW4005FW0000Hd0001@]00026@0052d006=005FW003RL000o`<00?<e002l`P00
07lF000a@00011d000LP0016B`06S000cZd00?PO003l3P00f90002RI0000ET/000/U00036P008SP0
07@Z09:h003]B@00o`000>QK001c/00006/g000J<P000QT0010Z001OA018X`00h7L00?h5003c<P00
_/<0001o5P00<40000@L00088@00CDh04I400=:R0080nQH00?l0dZ40016A0000CDh000PQ00047000
<D00080D0<C4003d;P00oPL00=in000lX00005Y8000=:0000QX0020f001b;02B^000kTL00?l0003V
HP00I:`0001V?@0052h0008I000F;`00J3/0K:h00>QM003o0000k4d008Je0000Kc8001`c00026@00
42X00613056V003SKP00o`800?0n002P_00007DW000R>0000aX000dW001KB010X@00ggX00?h4003b
=P00/<00001i80009cX000<J000;9P00F4T0=ih00=eo003n1P00lc800;K10000Nah002Pk00036`00
2bD005Q:03NN003NO`00oPH00?<c002c`00007XP000V>P000aX000`V001JB00nX000h7T00?l4003a
>@00Y[d0001f9P008SL0008J000>:@00GTD0CjH00>=/003o0@00kTD008jg0000L30001/c00026@00
4b`006Dn06V]003XF`00o`000>UG001_[`0006Ll000D;@000QT001Xb001_<@2>]`00kT@00?l1003R
L000B:@0001LA`003BL000<J000W>`00O1`0_l<00?D/003m2P00f8l001jE0000Cdh000LQ00057@00
?DH018/00=6U003k5000n1d00<^d0000Q0/00391000470002R@005I;03JN003OO000o`@00?0m002I
^P00074^000K<`000QT001@^001Y>P1j/P00k4d00?l0003TJP00CJD0001LA`0032L000<K000[?@00
P1D0akd00?TJ003BX@001h`0000mA`001Ad000PQ001AC@0ZVP00g8<00?h5003a>P00W;/0001a;P00
6c<0008I000F;`00JcH0QkD00>i4003o0P00h7P003RN0000ED/000TS00047000>D@00HX00=6U003k
4P00mb800<No0000OQP002Pk00036P003bT0065206>/003YF@00o`000>IT001BYP0005a6000<9P00
0a/0031000242`3=/000nQP00?TL003:]`00084B000[?@000aX000hX001P@`1QZ`00jET00?l0003U
IP00CJD0001JB0002bD000<L000d@P00R080d:H00?/B003g9000aL@0001k7P008cP0008J000B;000
J3X0P;@00>i5003o0`00gWd002bJ0000D4h000LP00067`00BTd07iH00=^7003n1@00l3h008bg0000
JcL001@^00026@008CL007XP0<G4003g8`00na<00<n[0000QPP001/002lo00036`003BP0065206N]
003[D`00o`000>9b000hWP0005=<00088@001Ah004Q<01jE003KQP00oP@00>m20023]00006Pk000A
:`000QX002Lk0020503;]P00nQP00?PN0037_P002_ooool1o`00007ooooo000Nooooo`03o`000?oo
oooooooo00Oooooo03h0//000>m2003o0000k4d009jk0000O1`003=100057P001Ad002ho001i8P2C
^000je<00?l0003`?P00^L8000233P00?DH000LP000470009c/007<[086d003XG@00o`400?8f0035
``0008H70013B@00224000<K000T>@00LBh0N[800>MP003o0P00lc@00<K10000Q`H004=900078@00
0a/002Dj001b;01o/`00j5`00?l1003b>@00`<<000243000?DL000HP00047000:S`007LU092h003[
DP00o`000>m3002Z_P0007hI000c@P8000DN05d003A2001n602]_`00kd400?l0003ZE@00RKH0001d
:@009cX000<K00088@00ADX008T10<Vj003e;@00oPD00>9_001OZP0006Pj000J<P000QX000dW001F
B`0RU`00e9/00?XG003k4P00f94002jK0000FDP000lY00026@005c0006Hm05NX003QL`00oPD00?D[
0039^P0008P20013B@001b4000@L000/?@00NB40Wk/00>i7003o0000jU@008Ne0000LR`002<h0003
6`002B<0051>016A003@Y`00n1d00?`>003JR`006W`T000?:@000QT001Pa001X>`1QZ`00i6/00?l3
003b=@00_l<000214P00=T<000DN00067`00>dD008D:0<K0003d;P00oPD00>5e001AYP0006=1000D
;@000QT001<]001R@@1>Y@00h7H00?h5003d;P00a/0000243000>DD00P001Ah0]000>TD008@:0<No
003e;000oPH00=mi0018X`000613000A:`000QT001L`001W?01RZ`00iFL00?l2003a?000[Kl0001k
7@00;3d000@L00088P00CDh049000=6T003i6@00na<00=FI000MU@00059=000:90000a/002Lk001h
902Q_000kd400?l1003VI000IJ`0001W?0005Rl0008I000C;000HT40EJL00>=^003o0`00lCT00:no
0000Nah002Xm00036`002B<0055=01bD003EV@00na800?TK003?ZP001hd00015BP001R0000DM000g
@`00Q0/0b;`00?HX003m2P00fhL0032L0000EdX000/V00036P0093T007HV0:6l003`?`00o`800>A[
001GZ0000691000B;0000QT001Tb001/=P1j/P00jU@00?l0003ZE@00N;40001[=`006340008I000C
;000I3l0GZX00>EU003o0@00kTH0096h0000LRd001he00026P003bT005i504bU003RL@00o`800?0m
002Q_00007HW000R>0000aX000dX001KA`13XP00h7H00?l4003a>@00Z;h0001g9@0093T000<J000=
9`00FdL0@j800>1f003o0`00lC/00:Bm0000MRL0028h00026P003RP005e604^T003RL000o`800>m1
002G^@00078]000N=@000QT0014[001R@@1LZ@00iV@00?l0003/C@00P;@0001/=P006300008I000F
;`00JCT0Mk400>]B003o0000iel0066[0000Hd00014[00026@007SD007<[09bk003`?@00o`<00>1h
000lX00005Q9000;9@000a/002`n00205037_`00mRD00?`>003EV00059400018C08000HO09d004A:
00j?003DW@00o1000?LS0038_@00080C000]?P000a/000/U001IB@12XP00hG<00?l2003^A@00R[H0
001]=0006340008I000G<000K3D0R;H00>i5003o0P00hG<0042Q0000F4T000/U00036`00<40008<=
0<^e003j6@00cjX000280P00=d<000@L00098`00ED/0=Ih00=mj003o0`00kd4008jg0000KC@001P`
00026@006C4006la09Ji003`?@00oP@00=f1000/VP00059=00088@001Ad003m700^>003DW000o0h0
0?HX002o``0007XO000S>0000QX0014[001U?P1a[`00je000?l0003SK@00AJ<0001IB@002R@000@L
000e@`00R080d:L00?/C003g8P00akl0001m6P009SX0008J000@:P00I3l0Kjl00>]A003o0000hfl0
046Q0000EdX000TS00047000>dD01h`00=>N003l3P00mBX00;O10000MbD001le00026@005Bh006`f
08jg003`?P00oPD00=^6000PUP0004]=00067`001b00051>02^J003NOP00o`<00>i6001n/`0006Lk
000A:`000QX002Dj001n6@38_000n1h00?XH003;/`00088A000Z?0000aX0010Z001T?`1e/000kDX0
0?l2003ON`00;9X0001@CP001R0000HO001?CP0YV@00gWd00?l2003]B@00MK40001T?`003bT000<J
000/?P00Q0`0cZd00?/D003g9000`<<000[ooooo0Ol00001ooooo`007_ooool00ol0003ooooooooo
o`07ooooo`3o0<74003a>`00o`000>YE002@^00007PS000]?P0011d000DN000d@P00O1/0X[`00>e:
003o0000kTH00:Zn0000OaL003M300067`0011d002`n001g902?]`00jU@00?l0003`?P00^L800022
3`00?4H000HP00047000:C`007DX08Vf003YE`00o`000?4l002k`P0008<?000lAP001R0000@L000Z
?000MRH0S[L00>YD003o0000l4000;700000P1D003M300067`0011d002lo001k7P2O^`00kDX00?l0
003]B`00W;/0001j8000;Sl000@M00067`00>TD0088@0;c2003a>P00o`400>QM001k/P00070_000R
>0000a/000TS001=CP08S@00c;800?HV003n1`00h7P005:V0000I3l001L`00026@003bT005Y802jK
003GTP00na800?XG003EVP008iL0001FB`003BL0008J000J<P00JCT0I:`00>AZ003o0`00lc800<G2
0000Q0/003a600067`0011d00350001m6P2^_`00l3l00?l0003XG@00N;80001_<P007cH000<J000;
9@00Dd`079D00=>N003j6000na800=ND000EN2D000dW00026P0073<006/f06j_003VHP00o`400?4l
002``00007dJ000`@00011d000LP0012B@00R@40b[L00?HW003n2000gWh004BR0000Gd@0014[0002
6@005Rl006Dn05^Y003SK@00o`<00?<e002m``00080D000c@@0011d000HP0010B000R080b[H00?HV
003m2@00g88003bP0000G4L000lY00026@006S8006/g06n_003WG`00o`000>m3002N^`0007LT000W
>`000a/000TS001AC@0KU000e9/00?/D003j6000dZ8001>A0000Cdh000PR00037000;3d007/M0;30
003a>@00o`800>=]001HZ00006=0000C;@000QT001D_001V?@1RZ`00iFD00?l1003_@@00XK`0001g
9@009SX000<K000:9@00E4`09iP00=R@003l3@00n2400<bc0000R@4003i700067`001Ah003e60028
0`3;]000mb400?`=003HT@009IP0001CC0002R@000<K000Y?000NQl0/<000?8h003o0`00hG@004ZT
0000GTD000lZ00026@007C@006la08Rf003/C000o`000>MN001Z[P0006Ll000E;`000QT001D_001W
>`1[[P00j5d0003c0?l0003/CP00Pk@0001^<`006c<0008I000A:`00HT40FJT00>EX003o0@00kTD0
09>h0000LRd001he00026P003bX005m4052V003SK@00o`800>m1002I^P0007<[000O=P000QX000lY
001OA01?YP00hfd00?l1003_@P00U[T0001b;@007SD0008I000@:P00HD80F:P00>EW003o0000kDT0
08Rf0000KS8001Xb00026@004bd006Dm06V]003XF`00o`000>YE001b/00006Pk000E;P000QT001Ta
001]=025]@00kDX00?l0003UJ000E:L0001OA0003bT0008J000R>000MbD0Zkh00?8e003n1P00gH40
032L0000ED`000TS00047000<T4008@<0<Zg003h7`00na800=:Q0009S@00045800057P001R0004]=
01RC003GU000o@`00?DY0033a00007dK000X>`000aX000dW001MAP1>Y@00i6X00?l0003/C@00O;<0
001Y>@005Bh0008I000K<`00L2l0UkT00?0n003o1000gg`003BM0000ED/000TS00047000=T<008L4
0<j/003j6@00c;<000242`00<D0000<K000:9@00F4T0@Z400>9a003o0@00kDT0082c0000JST001D^
00026@007C@007<[0:Bm003b=@00oPL00=Z:000QUP0004i>000780001Al004I;01FB003GT`00o@X0
0?@_002``00007HV000O=P000QT001@]001Y>P1o/`00kDP00?l2003PMP00>Il0001EB`002B<000@M
000kAP07S000dil00?`?003f:000_/<0001i8@008SL0008I000B;000J3/0OK<00>e8003o0P00h7P0
03FM0000Dd`000PR00057@00@DP04I000=NE003m2P00lc400:Rn0000Lb/001/c00026@006340070`
09fk003b=P00oPP00=R?000FTP0004A:00057P00228005=<03JN003QM@00o`400>a>001`[`0006=0
000?:@000aX002Xm00224@3;/`00nQP00?PM0038_00007hI000U>P000QX0018/001X>P23]000kd80
0?h4003LQ0008IH0001:C@001Al000LQ001BC@0eW@00hG@00?l1003[DP00J:d0001P@`003BL000<K
000b@@00R0<0dJ@00?`?003e:P00/L0000[ooooo0Ol00001ooooo`007_ooool00ol0003ooooooooo
o`07ooooo`0B0<Nn003c<`00o`800>QM0022]00007@Z000X>`0011`000HP000jA@00P1<0/L000>m2
003o0000k4h009^k0000Nah003500P001Ah0E@00<D4007/M09jk003/C000o`000>i5002Z_P0007hG
000f@`001Al000@M000^?`00NB40UkX00>a?003o0000kd<00:bo0000OaL003I300057P001Ad002lo
001j7`2L^`00kD`00?l0003^B000X[`0001l7000<D0000DM00057P00=D8007hG0:jo003_@P00o`00
0>YC002=]`0007HW000Y?00011`000LP0011B000QPL0a/400?<b003o0`00iFH006f^0000KCD001he
00036P002RD0055=01:A003?Z@00n2000?d;003MP@00AJ80001Q@P0052d0008I000A:`00GDH0>Yl0
0=Z9003l3P00nA`00=6S000HT`00059=000;9@000aX001he001]=01b/000iV400?l1003a>@00^L80
00204`00=T<00P001Ah0o`00=d<0084B0;g3003b=`00o`800>EU001[[P0006/g000K<`000QX000dW
001GBP0WV@00eYD00?/C003j5`00e9d000me9P002bD000<J000O=P00Kc40O;<00>UI003o0000kd@0
0:6l0000NB4002/m00047000224004U<00N=003=[`00mb400?d;003KQ`00>9h0001KA`003bT0008I
000I<@00JCT0JJd00>IT003o0@00lC`00:jo0000O1`002hn000470001b4004Q;00N<003>[P00n200
0?`=003JS000<9`0001HB@003BL0008J000N=@00KS80OK<00>YF003o0000kD/0092h0000Lb/0028h
00036P002bD005E;02JH003GTP00o1000?TM003?Z`002Hd00017B`001b4000@L000a@000OaD0_l<0
0?<b003n1@00hGH004^T0000H4<0014[00026@006C4006Xh072_003XG@00o`000>e8002B^00007<[
000Q=`000aX000`V001HB@0bW000fhL00?d:003f9`00b;/000252P00>4@000DM00068000A4X01X`0
0<n[003i7000na800=FJ000JU000051>00088P0011`002ho001n5`2o``00m3000?h6003NO@00?J00
001KB0003BP0008J000Q=`00Lb/0U[T00>m4003o0@00iFH005fZ0000Hd0001</00026@006C4006/f
07Vb003ZE000o`000>YG001e/00006Xh000G<0000QT001@^001V?@1V[000iel00?l0003/C@00Q;D0
001^<`006c80008I000B;000Hd00GJX00>IU003o0000kDT008Zf0000Kc4001`c00026@004B/00691
05fZ003VI000o`000>e:0027]@0006hc000J<P000QT001</001U?P1U[000ieh00?l0003[D@00N[80
001Z>0005c00008I000F;`00JCT0Mk400>]C003o0000ieh006F/0000I3l0018/00026@0073@0074_
09>h003_@P00o`800>9a0017X`0005a7000=9`000aX002Lj001k7P2j`P00m2h00?d9003JR`009IP0
001AC@00228000@M000hA000R0<0cJh00?TJ003j5`00cjX000290000>TD000@M00088@00D4h08iL0
0=Z;003m2000m3000;C10000NB8002<h00026P003bT0061305^Y003WH@00o`000>YE001^[`0006Hm
000B;0000QT001he001d:@00R02V_@00lSH00?h6003LQ@00:IT0001AC@00228000@M000lAP05R`00
dJ<00?XJ0038^`00080C000/?@000a/000`V001LAP1>Y@00i6P00?l0003[D@00L[00001V?@004R`0
008I000P=`00Mb@0/l000?@^003m2P00ei<001JB0000Ad/000HO00068000CTh089H00=Z:003n1`00
lSH00::l0000LRd001/c00026@005Rl006de08fg003`@000o`@00=io000]V`00059=00078@001Ah0
0499016@003FUP00o@/00?@_002__`0007DX000N=@000QT001D^001[=P2;]P00kd400?l4003MP@00
:IT0001@CP001b0000HO0018C00KU000fX`00?h7003b>000VKX0001_<@006300008I000L<`00M2X0
[;l00?@_003m2`00eIP000^>0000?DH000@M00098`00EdX0@j800>=/003o0000jUH006:[0000H4<0
00dW00036`00;cl008H80<n[003k4`00mb<00<G40000NR00024g00026@005Bh006`f096h003a>`00
oPH00=V=000FTP0004=900057@00228005I;046Q003TJ`00o`000>UJ001JZ@0005e6000;9@0011`0
03M400F<003DV`00o@/00?<a002R_00:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool0
1oooool0o`3:]P00mB`00?l3003UIP00Lk00001`<00093T000<K00078@00@DP008@:0<33003a>`00
o`000>YF002=]`0007LU000[?@0011d000HO000gA000OaH0[Kl00>m4003o0000k4d009^j0000NQl0
031000057@001Ah003A2001m6P2V_@00kTL00?l0003]B`00WK/0001k7P00<40000DM00057P00=D80
07hG0:^n003_@`00o`000>]@002D^@0007PS000/?@0011`000HO000kAP00P`l0_L<00?4j003o0@00
j5`007nc0000LRd002@i00036`00228004Q;006:0039^000mB`00?h5003RK`00H:/0001Y>P006S80
008J000<9P00E4`07ID00=>P003i6P00o0l00=Z:000hWP0005e6000A:`000QT001@]001Q@P16X`00
gH000?d:003g8P00cZ`000f?0000Cdh000TS00036`008SP0074^082d003YF@00o`000>m1002Z_P00
07`K000`@00011d000HO000mAP00Q@T0a/000?@`003n1000hfh005fZ0000Ic`001Pa00026@003bT0
05Y803>M003IS000o0h00?TL003AYP002W4W00098`000a/002@i001c:`2;]P00je400?l0003/C000
T[P0001e:0009SX000<K00098`00Cdh04I400=6V003i6`00o0l00=R@000/VP0005Q:000=9`000QX0
01dd001]=01f/@00j5`00?l0003_A000Wk`0001h8`00:3`000<K00098P00Cdh04I400=6U003i6P00
na400=NE000TV00005E;000;9@000aX0028g001b;02<]`00k4h00?l0003ZE000PK@0001_<@007SD0
008J000=9`00F4T0<I`00=Z9003m3000mb<00<^c0000R@00041800067`001Ah003M300233@37_`00
mB/00?h7003NO`00?Z00001LA`003bT0008I000L=000KS<0O[<00>YD003o0000je4008>d0000Kc40
01dd00026P003RP005a703jP003NOP00oPL00?@^0035a000084C000b@@0011`000LQ001;C@0@T000
dZ800?XF003j5`00dZ<000n@0000BTd000LQ00047@00=480088?0<No003e:P00o@T00=^6000aW000
05M:000;9P000aX002Di001g902U_@00lC`00?l2003RK`00CjH0001P@`0042X0008I000L=000Kc40
R;H00>e<0000l`3o0000iel006N]0000ISd001@^00026@005c0006Xi07B`003ZE`00o`000>YE001f
/@0006Xh000G<0000QT001D^001W?01[[P00j5`00?l0003[D@00O;80001[=P006340008I000D;P00
ISd0JZh00>QL003o0000je8007Vb0000JSP001L`00026@005Rl006Pj07>`003ZEP00o`000>UJ001/
[P0006Hl000D;@000QT001Tb001]=025]@00kDX00?l0003UI`00EjP0001P@`0042X0008J000P=P00
MBT0X[`00?4j003o1000ggX003^O0000F4T000/U00036`00:cd007lF0<K2003f:000o@`00=ND000J
U00004e>000780001Ah003i700F<003AY@00naD00?TL003</`0008D8000d@P0011`000TS001DC00_
V`00gH400?h5003b=`00YKd0001e:@007cH0008I000A:`00I3l0JJd00>UH003o0000j5d0066[0000
HT40010Z00026P008SP007PS0;G1003d;`00o@T00=V>000MU@0004e>000780001Ah004=900n@003E
VP00nA/00<G40000O1/002Lk00036P003RP0061305^Y003WG`00o`000>UJ001T[0000691000?:P00
0QX002Di001k7@32a000mRP00?`>003DW00038h00010B0001Ad000PQ001AC@0/VP00gH400?h4003`
?P00TkP0001^<P006300008I000J<P00L2l0W;/00?8i003n1P00fhP0026G0000CTh000HP00067`00
BT`06i@00=V<003n1`00lSH00:2l0000LBh001Xb00026@00634006la09Vj003a>@00oPH00=Z:000N
U@0004Y=00067`001R0004m>02JH003MPP00oP@00?10002;]P0006/g000E;P000QT001lf001h902k
`P00mRP00?`?003BX@000XX0000g@`0011`000/U001JB01?YP00iV<00?l0003WG`00EJL0001LA`00
2bD000<K000e@`00RP00dZ800?`?003e:P00]/40001f9`007C@0008I000H<000L300X;`00?<c003m
2P00eYH000b>0000?4H000@L000:9000FDP0CZD00>IR003o0000iV<004fU0000FDT000XT00047@00
?TL03i000=NB003n2000lST009Bi000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool0
1oooool0o`3>[@00mRH00?h6003RK`00IZ`0001/=@007cH000<K00098`00B4/008T10<No003c<`00
o`800>MO001n/`0007</000W>P0011`000LP000nA`00P`d0_<800?4l003o0000jUH008bg0000MRH0
02/m000470001Ql003Y500214P2e`@00l3l00?l0003ZE000S[L0001g9@00:cd000@L00068000>dH0
088?0;[2003a?000o`000>UI0025]@0007@Z000W>P000a`000LQ0012B@00Q`H0a/000?<c003o0P00
iVD0076_0000KS<0020f00036P002R@004m>00^>003=/000mbD00?h8003PN000DZL0001U?P005c00
008I000>:000F4T0:9T00=JG003j5@00na<00=NC000/VP0005U9000?:@000QT001L`001U?P1CY`00
h7H00?h7003f:000bkD000>;0000B4`000PR00036`009c/007DX08ng003[D000o`000>e9002K^P00
07PR000[?@0011`000LQ0014BP00R@00b[P00?DY003n1`00h7L0052V0000Hd0001D^00026@004B/0
05i503nQ003LP`00o@/00?LR003=[P001F`W00088P000a/002Pk001g902I^P00kDP00?l0003ZE@00
Q;D0001a;P008CL000<J000;9@00Dd`079D00=BM003j5P00na@00=FI000PUP0005A<000;9@000aX0
024g001a;P25]@00jU<00?l0003/C000T;P0001d:P0093T000<K000:9000DTd079D00=BL003j5@00
nQH00=>N000IU000055=000990000a/002Hj001f9P2K^P00kTH00?l0003XG000Lk00001[=P006c80
008I000?:@00G4H0?Z000=f0003n2000mBT00<Rl0000Q@T003Y500057P001Ql003e70027103:]`00
mbD00?d;003KR000<Y`0001HB@003BL0008J000P=P00LRd0S;L00>a<003o0000jET007Fa0000JcH0
01Xb00026@0042X005m404^T003QM000oP@00?8e002g`@0007dJ000/?P000a`000TS001@C@0KU000
eIT00?/B003i7000cZ/000F<0000@dT000HO00057P00>TD008H60<Zg003g8`00o0d00=R?000VV000
05=<000:90000a/002Xl001k7@2d`@00lcD00?h4003PN000@j80001LA`003RP0008J000P=P00Lb/0
U[T00>m40000BP3o0@00iFP005VY0000HT40018[00026@006S8006dc08:d003/CP00o`000>MN001X
[@0006Hm000D;P000QT001P`001Z=`1i/P00jU<00?l0003YFP00KZl0001W>`005Bh0008I000G<000
JSP0N;400>YC003o0000j5/006^^0000IS`001@]00026@006C4006`e086d003/C@00o`000>IR001O
ZP0006=0000A:`000QT001dd001a;P2D^@00kd800?l2003RL000BZ@0001MAP003BP000<J000T>@00
NB80/L000?<c003n1P00g8<002nK0000E4`000TS00047000<D0008<>0<Vi003g8@00o1000=BM000?
T00004E:0P001Ql09@00ADX03i000=BL003l4000mb800<Rk0000PA4002ho00036`002RD005M:03^O
003PN000o`<00?0o002F^@00074_000K<`000QT001@^001X>P1g/@00je000?l0003UIP00DjL0001N
A@003RP000<J000W>`00O1/0a<@00?HX003l3@00eYL001>A0000AT/00P001Ql0P000BTd06I@00=RA
003i7000]l40001h8P008SP0008J000@:P00Hd00JJd00>UG003o0000iV<005JX0000GTD000dX0003
6P00:S`007lF0<Nm003g8@00na800=6U0002RP0003U4000470002B<005E;03NN003PM`00o`800>i6
0024]@0006Xh000E;P000QT001dd001d:@2[_P00lc400?d9003HT@005Y<00016B`001Ah000LP001@
CP0WV000g8<00?h5003`?@00T[P0001]=0005c00008I000L<`00Lb/0Z;h00?<b003m2@00ei<001>A
0000@dT000DN00088@00Ddd0<Y`00=mi003o0P00kTP007bc0000Ic/0018/00026P0093T007`L0<K1
003g8P00na@00<nZ0000QPL0035000036`0032L005i505fZ003XFP00o`000>EX0018Y00005Q9000:
900011`003]600Z>003EV@00o@/00?@a002W_@00078]000I<P000QT001/c001d:P2__`00mB`00?`=
003CW`000XX0000f@`000a/000/V001MAP1KZ@00jEX00?l0003SK000@:40001EB`00228000DN0015
BP0JU000fXT00?h5003`@000QKD02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo0?l0dJ@00?PP003m2@00h7P005RX0000J3X001`c00036P002R@004m>00N=003:]P00mB`00?l4
003UJ000L:l0001_<P008SP000<K00088P00ADX008L40<K1003c=@00o`800>MN001n/`00078/000V
>P000a/000LQ0011B000Q@T0a<@00?8g003o0@00j5`0082c0000Lb`002Hj00036`001b4004990026
1`36`P00lc@00?l2003VH@00Mk40001`<0008SP000<K00088P00BD`00X/00<Zh003e;000oPD00>=^
001SZ`0006Xh000L<`000QX000/U001BC@0FTP00d:L00?PO003m2`00gH4004FS0000HD8001@^0002
6@0042X005a703BM003ISP00o1000?XH003DW0008IH0001FB`003BL0008J000J<P00JCX0H:/00>=]
003n1000m2l00<Nn0000Q`D004580007800011`002`m001i8@2M^`00kTP00?l0003[D@00S;L0001d
:@009SX000<K00088P00C4d02Hd00<f_003g8`00o@X00=f00013XP0005m4000B;0000QT001@]001R
@@1;Y@00ggX00?h7003f:000b[L0001V9@001b0000@L000^?P00Nad0Z;h00?10003o0000j5d007Fa
0000KC@001dd00026P0032L005I:02NI003GU000na400?TI003BXP005I80001@C@002B<000<K000U
>@00MBP0TkT00>e;003o0000jUD008:d0000L300020f00036P0032H005I;02NI003GT`00o1000?TK
003@Y`003Xl0001=CP00228000<L000[?@00NQl0Z[h00?0n003o0@00iFD006F/0000J3/001L`0002
6@004B/0061304ZT003PM`00oPD00?@`0034a000084B000d@P0011d000LP0014BP05S000cZh00?PO
003l3`00f94002JH0000ED/000/U00036P0093T007HW09^j003_A000o`000>IR001W[@0006Lk000F
;`000QT001<]001S@01HZ000i6/00?l2003a?000Z;h0001i8P009c/000<K000:9000E4`09YP00=R@
003l3@00mb800<^d0000R0<003a600057P001Ql0041800::003=[P00n1d00?/A003EV0006Y@0001@
CP00228000@L000_?`00OaD0a<@00?@^003n1`00gH8003JN0000F4T000`V00036P0093T007LU0:Fm
003a?0000?<0o`<00>9a001<Y@0005i4000?:@000QX001he001a;P2A^000kTH00?l1003UI`00FZT0
001R@@004B/0008I000K<`00KS80QkD00>e;003o0000iV80062[0000I3l0018/00026@006S8006hc
08Je003]B`00o`000>IT001MZP000691000A:`000QT001`d001`;`2@^000kTD00?l1003TJ`00DJH0
001OA0003bT0008J000Q=`00MBP0Xk`00?4k003o1000h7T003fP0000FDT000`V00036`00:C`007dK
0<33003e;000o@X00=V<000SU`00055=00088P0011d003M300271@3</000nA/00?XE003@YP001H`0
000nA`001Ah000LP001=CP0JU000ei<00?d<003f:@00aL@0001m6@00:C`000<K000<9P00FdL0B:<0
0>9_003o0@00kTL008Rf0000KC@001P`00026@005c0006`f08Fe003^B000o`400>9_0016X`0005Y8
000<9P000a/002`n00204`38_000mb800?/A003BX00028d0000oA`001Ah000LQ001@CP0TV000fhP0
0?TN002X_P0007@Y000N=@000QT001<]001W>`1g/@00k4h00?l0003TJ`00BJ@0001JB0002bH000<K
000_?`00P`d0bkD00?TL003j5`00cZh000261`00<d4000<L000:9@00FDT0A:800>=^003o0@00k4h0
07Ja0000IS`0018/00026@008CL007PR0;[2003e:P00o0d00=FJ000<SP0003m700057@00228005=<
03:M003ONP00o`800>i50023]00006Ti000D;@000QT0020f001g902h`@00mB/00?`=003DW0002Hd0
000lAP0011d000TS001FB`0nX000hW000?l1003[D000KZl0001S@0003bX000<J000X>`00P1D0bKT0
0?TL003j6@00bk<000223`00:cd000<J000>:@00HT40JZh00>]B003o0000hW4003bP0000ED/000PR
00057@00@TT059800=R@003n1`00lSP009Rj0000KS<001H_00026@007cH007PS0;k3003f9P00na80
0=2X0000QPH0031000036`003BP0065206V]003[D@00o`400>5e000dW@00059=00078@001Ql004a=
02FH003MP000o`<00>e8001g/@002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo0?l0e9/00?TJ003l3@00gH4004^T0000I3l001Pa00026P0032H0059=01:A003>[@00mRH00?h6
003RL@00HZ/0001[=`007SD000<J00098`00CDh018/00<Zh003d;@00o`<00>EW001_[`0006hb000Q
=`000a/000PR0018C000R@00b;`00?@`003o0`00iFD0076`0000Kc80024g00036`002B<004U<00::
0039^@00mBd00?h4003TJP00JJd0001/=P007SD000<J000:9000D4h03Hl00<f_003g9@00oPL00>1g
001EY`0006Hm000H<@000QT000dW001FB`0QUP00dih00?TI003l3`00fX/003VO0000GDD0014[0002
6@004bd005m4042Q003LQ000o@`00?PN003AYP005Y80001BC@002bD000<J000N=@00K3D0KZl00>IT
003o0P00lSH00<;40000P`h003Y500067`001Ad00350001m6P2/_`00l4000?l0003YFP00O[<0001`
;`008CL000<J000:9000DDd04i400=2V003i7@00o0h00=Z:000fWP0005a7000@:P000QT001L`001V
?@1IZ@00hW400?h4003d;`00a/00001Q:0001Ql000DM000c@@00OaD0^<400?8i003o0P00iFH006N]
0000JCT001Xb00026@003RT005Y803>M003JRP00o0d00?PO003?Z`002hh0001;C@00228000<L000Z
?000NB40X[`00>m3003o0000j5d007>`0000K3D001`c00026P003RP005U803>M003JR@00o@`00?LQ
003=/00018/00015BP001b0000@M000`@000OQL0^L800?8f003o0`00hfh005NX0000I3l001@^0002
6@0052d006A005NX003SKP00o`<00?8g002e`@0007dJ000^?`0011`000PR001<C@0?T000dJD00?TI
003k4`00eIX001^D0000DDd000TS00036`00:C`007XP0:Zn003a?000o`800>A[001JZ@0006A0000C
;@000QT001H_001W?01V[000iV800?l0003^A000VKX0001e:@008cP000<J000<9P00EdX0<Y`00=^7
003m2@00mRP00<Rm0000Q0`003I300047@001b0004Q;00b?003AY@00nQP00?XF003BX@004900001:
C@001b4000@M000e@P00P`d0b;`00?HW003m2`00fX/002ZJ0000ED/000XT00036`00:C`007/M0;C1
003c=0000?<0oPD00=mj000oX@0005]8000=9`000aX0028h001e9`2P_000l3h00?l2003RL000CJD0
001NA0003bT0008J000O=@00LR`0U[T00>m3003o0@00i6/005>W0000H4<0010Z00026@007SD0078]
09Fi003_@`00o`400>=]001@YP0005m4000?:@000QX0020f001d:@2O^`00l3d00?l3003QM000A:80
001KA`003BL000<J000U>P00NB40//000?<c003n1P00gH80036L0000ED/000XT00036`00;Sl0084C
0<Nn003f9@00o0d00=JF000HT`0004a=000780001Ah003e700>;003@Z000nQH00?TJ003=[`0008P4
000hA00011d000PR001AC@0UV000fXX00?d8003d<000]/40001i8@0093T000<J000>:000Gd@0EJL0
0>EV003o0000k4l007Vb0000JCX001D^00026@006S80070`09Bi003`@000o`<00>1h000jW`0005M:
000:90000a`0039100242`3;]000nA`00?XF003?Z@0008T1000hA00011d000TR001CC00`W000gWl0
0?PP002H^P00070_000J<P000QT001H_001[=P25]@00kTH00?l2003QM@00?J00001GBP002R@000@L
000e@P00Q`@0cZ`00?XF003i7@00b[H000223`00;Ch000<K000<9P00G4H0DJH00>EU003o0000jUH0
06R]0000Hd4000lZ00026P009SX007`K0<K2003g9000na400=6S0002RP0003Q4000470002B<005M:
03nQ003RL@00o`400>a=001e/00006Hm000A:`000QX002@i001k7@35``00mb@00?/A003AY@0008T0
000f@`0011`000XU001JB01;Y000iFL00?l0003YF@00H:/0001P@`003BL000<K000^?P00Q0`0cK00
0?XG003h7P00b;`0001n60009SX0008J000A:`00ISd0N;400>e9003o0P00ggX002nK0000DDd000LQ
00067`00BT`07iH00=^6003n1@00l3l008Vf0000JSP001<]00026@008cP007`L0<No003h8000nQL0
0<ba0000PPl002/m00036P0042X006Dn07Na003]B@00o`800=in000XV@0004i>00067`001b00055=
036L003PM`00o`400>]@001Y[@002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo04<0f9800?/E003k4@00fX/003jP0000HD<001D^00026@003RP005I;01bE003AY000n1l00?d9
003ONP00E:L0001W?0006S80008J000;9@00DDd03Xl00<f_003f9`00oPH00>9a001QZ`0006Xh000M
=0000aX000XT001?CP09S@00bk<00?HY003n1@00hfh006>/0000JcL001dd00036P002R@0051>00b>
003=/000mRH00?h7003QM000FjT0001X>`006S80008J000<9P00Dd`05i<00=2V003h7`00o@/00=f0
0018X`000691000E;P000QT000lY001JB00/VP00ei@00080na@001T0ei@002fK0000FTP000lY0002
6@005Rl006=004fU003ON`00o@T00?LT003=[`002hh0001?CP002B<000<K000R=`00L2l0OK<00>QL
003o0@00l3h00;;00000OaH003A2008000DN01d003M400214@2l`P00lSP00?l2003VH`00Kjl0001/
=@007C@0008J000<9P00E4`07YD00=BM003j5`00na800=NC000ZVP0005Q:000=:0000QT001Xb001Y
>@1V[000iFP00?l2003b=P00_L<0001L:`0200057P30000iA@00P`d0aL<00?<a003n1000hVl005ZY
0000ICh001H_00026@004B/005i5042Q003MP@00o@T00?LU003;]0000HX00014BP001b0000@L000_
?`00OAX0//000?4k003o0P00iFH006F/0000J3X001Pa00026@0042X005e603nQ003MP000o@P00?HX
0039^@0008L4000nA`001Ql000DN000f@`00PPl0aL800?@_003n1@00h7L004ZT0000H4<0014[0002
6@005c0006Lk06F/003UI@00o`400?0o002V_@0007TQ000Y?0000a/000TS001AC@0JU000e9`00?/D
003j6000dJ<0012@0000CDh000PR00047000;Sl007hH0;W2003c=000oP@00>5d001<Y@000613000A
:`000QT001Tb001[=`1d/000jEX00?l0003/C@00R[H0001a;`007SD0008J000>:000FdL0?Z000=im
003n1P00m2l00<?40000OaD0031000047000228004m>01NC003DW000na<00?TK003?Z`001H`00013
B@001Ql000DN000kAP00R0@0bk@00?PQ003l3`00ei@001nF0000DDd000TS00047000;Sl007lF0<C4
003d;@00oPP00=b4000cW@0005M:000;9@000a/002Lk001i802__`00lSH00?h4003ON@00@:40001K
A`003BL000<J000S>000MRH0YKd00?4k003o0`00hG@004JS0000G4H000hX00026P008SP007HV0:Bm
003a>`00o`<00>1f0013XP0005]7000=9`000aX002Di001h8P2^_`00lSH00?h5003NOP00>9h0001G
BP002bD000<K000Z?000OAT0`L@00?D/003m2@00fX/002FH0000DTd000PR00047000=48008D:0<^f
003h7`00na800=>O000=S`0004E:0P001Ql0/@00A4X03Hl00=>N003k4@00n2000<Zh0000P`d00391
000470002B<005E;036L003MP@00oPD00?8g002W_@0007DX000P=P000QX0014[001S@@1RZ`00j5d0
0?l0003YE`00Jjh0001U?P004R`0008I000N=@00M2X0Xk`00?8h003n1@00gH8002jK0000Dd`000PR
00047000>4@008P20<n[003j5`00nA/00<bb0000Q@X00391000370002R@005M:03bP003PMP00mb<0
08Zf0000K3D001L`00026@006C8006la09Bi003`?P00o`@00=in000`W00005=<00088P0011d003]5
00B;003BX`00na400?LS0037_`0007hH000X>`000aX000hX001P@`1NZP00j5`00?l0003WG`00FZT0
001OA0003BP000<J000[?@00PA<0bKT00?PN003j5P00cZ`000261P00<T4000<K000;9@00FTP0C:D0
0>EX003o0000jUH006J]0000HT4000lY00036P00:C`007lE0<Vj003h7P00nQH00<f^0000Q@T00310
00036`0032H005e505RX003WGP00o`000>IR001CY`0005a7000;9P000a/003=200280`3@Y`00na80
0?LT0034a00007XO000R=`000QT001<]001Z>027]@00kd400?h4003LP`0099L0001=CP001Ql000HP
001@CP0[VP00gWd00?l2003^B000N[80001V?@004B/0008J000X>`00P1@0b[L00?TJ003i7000bKX0
001n5`009SX0008J000B;000J3X0QKD00>m1003n1@00fhL001fE0000Ad/000DN00088P00ED`0?J00
0>=]003o0000jET005^Y000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0
o`3KR000o1000?XF003GU000<Y`0001MAP004R`0008I000@:P00FTP0:9T00=BK003i6P00o0d00=b3
0017X`0006=0000G<0000QT000dW001EB`0IU000d:H00?PP003m2@00ggX005BW0000IS`001Tb0002
6P0032H0059=01BA003?ZP00mb<00?d8003PN000EZP0001W?0006C80008J000<9P00Dd`05i<00=2W
003h8000o@X00=im001=Y@0006@o000G<0000QT000hX001GBP0RU`00e9d00?TI003l3`00fXT003^O
0000GTD0018/00026@004R/005e503RN003JR`00o0l00?XI003DW@008IH0001FB`003BL0008I000I
<@00Ic/0FjT00>9b003n1P00mBX00<Zg0001RP0004M;00088P000a/002Hj001d:@2;]P00je<00?l0
003^AP00Xk`0001k7P00;Sl000@M00068000?TL008D90<K1003d<@00o`@00>=/001QZ`0006Pj000I
<P000QT000dX001HBP0ZVP00ei@00?/B003j5`00e9`001nF0000E4`000/V00026P007SD006dd07F`
003WG`00o`400?0n002^_`0005L]00047@001R00041800271039^P00mBX00?h6003PN000C:D0001R
@P004bd0008I000C;@00HT80CJD00>1h003n1P00mB`00<Rm0000QPL003e600067`001Ah003E30021
4P31a000lc<00?l4003RK`00F:P0001T?`005Bh0008I000B;000HD80C:D00>1g003n1@00m2h00<K1
0000P`d003Q400057P001Ql003e600271P39^P00mRP00?d8003MP@00?J00001LAP003bT0008I000J
<P00JcH0Lk000>QL003o0000kTL009Ji0000MBP002@i00036P002bD005A<02FH003GTP00o0l00?PN
003>[0001X`00015BP001b0000@M000d@P00PQ00aL800?@]003n1`00gWd003nQ0000G4L000hY0002
6P007C@006lb08:d003[D@00o`000>YE001k/P0006de000K<`000QT0010Z001OA01;Y000hG@00?l4
003b=P00/l00001k7@00:Sd000<K00098`00DTd08YL00=NB003l3P00n2400<^c0000R0<003a60005
7P001Ql0049900F<003?Z`00nA/00?/C003CW@005980001=CP001b4000@M000d@P00P`d0b;`00?HV
0000l`3m2`00fHd002NI0000Dd`000XT00036`00;3h007hI0;o3003d;`00oPL00=f2000dW@0005M:
000;9@000a/002Pk001j7P2d`@00lc<00?h5003NOP00>Il0001HB@0032H000<J000W>`00NQl0]<40
0?<c003n1P00gGl003JN0000EdX000/U00036`00:C`007`K0;g3003d;P00oPP00=^7000/VP0005A<
00098`000a`002lo00214@37_P00mRD00?`=003GU0006Y@0001>CP001b4000DM000jA@00R@40cZd0
0?TI003j5`00d:P000>;0000?DL000DN00078000C4d069<00=JE003l3@00mRH00<K00000OaD002`n
00036`002bD005Q903fP003PM`00o`<00?0o002H^P00074^000L=0000QT001<]001V?01`[`00jU@0
0?l0003WH000GJX0001Q@P003bX0008J000R>000N2<0//000?@a003m2000fX/002:G0000D4h000LQ
00057P00?TL01hd00=:R003k4P00mb400<Rk0000PA8002`n00036`0032H005]704VT003SK000mRL0
07^b0000JCX001@]00026@007C@007<[0:>m003b=P00oPH00=^7000TV000051>00078@001Ah00499
00j?003EV@00o0d00?DY002o``0007XO000S>0000QX0010Z001T?`1/[P00jU@00?l0003UJ000CJD0
001KA`002bH000<K000`@000Q@X0cK000?XH003i6`00bkD000223`00;Ch000<K000=9`00GTD0FJT0
0>MO003o0000iel005VY0000GTD000dW00036`00;Sl008<=0<bb003j6000nA`00<Zg0000PA8002Xm
00036P003RP0065206J/003ZE@00o`000>A[0016X`0005Q9000:900011`003Y500J<003CWP00o0d0
0?D[002e`@0007HV000N=@000QT001H_001^<`2F^@00lCT00?h7003IS@0069<00015BP001Ah000PQ
001CC00gWP00hG@00?l1003[D000K:h0001R@@003RP000<J000]?P00Q0`0cZh00?/E003g8P00aL<0
001j7`008CL0008I000E;P00K3D0U;T00?4i003n1`00f94001:A0000@4P000@M00098`00F4T0BZ@0
0>IT003o0000iV8004fU000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0
o`3NO`00o@`00?TK003DW@009YP0001IB@0042X0008I000C;000GDD0=9d00=RB003k5000na800=V=
000jW`0005m4000D;@000QT000lY001HB@0UV000e9d00?TJ003l3@00g8<004JS0000HT4001H_0002
6@003RP005I;01nF003BX@00nAd00?d<003MP@00B:@0001S@0005Rl0008I000>:000EdX08YL00=>N
003i6P00o0h00=^60010X@000613000D;@000QT0010Z001JB00^V`00ei<00?/D003k4`00ei<002nK
0000FdP0010Z00026@0052h0065204FS003MPP00o@/00?PO003@YP005Y80001BC@002bD0008J000M
=000JcL0JJd00>AY003o0`00lc400<K00000QPL004180007800011`002`m001i8P2J^P00kDX00?l0
003/CP00TkT0001g9@00:C`000@L00078@00ADX008T00<Zh003e:P00oPH00>5e001DY`0006@o000F
;`000QT0010Z001LA`0fWP00fXX00?`>003i7000dJD001BB0000DDd000XT00036P008SP0074^08>d
003ZEP00o`000>i6002N^`00058`00047000224004M;00F<003</@00mb@00?d:003MPP00?j40001N
A@004B/0008I000F;`00ICd0FZT00>=^003o1000lc<00<?40000PQ0003I300057P001Ql003a60025
2@37_P00mB`00?h6003PN@00BZ@0001P@`004R`0008I000E;`00ICh0FZT00>=]003o0`00lSH00;_2
0000OaH0035100047@001b0004A:00>;003</@00mb800?d<003JRP00<I`0001HB@003BL0008J000N
=@00Kc40P[@00>YC003o0000je0008Ne0000LBl001lf00026P003BL005Q9036L003JR@00o@/00?LT
003;]@0008P3000nA`001Ql000DN000jA@00QPL0bKT00?HV003m2P00fhL003>M0000F4T000`W0003
6P008CL007</096h003]B000o`000>MN001][P0006Tj000G<0000QT001</001S@01HZ000i6/00?l2
003`?P00Y;d0001g90009CX000<J000;9@00ET/0;Y/00=Z9003m2P00mRL00<Rl0000Q0`003E30004
7@001b4004Y<00n@003BX@00nQD00?XH003@Y`002Hd00015BP001R0000DN000kA@00Q`@0bk<00?PP
0000I`3l3`00eYH001^D0000D4h000PR00047000<T40088@0<No003f:000o@X00=Z<000XV@0005=<
00098`000a/002dn001o5`34a000mB`00?d9003KQ`00;I/0001EB`002R@000<K000/?P00OQL0`l@0
0?D/003m2@00fXT002ZJ0000E4`000TS00037000;cl0080C0<K0003f9`00o@`00=R@000PUP00051>
00088P0011`003E30025203;]@00n1l00?/A003CWP003i000016B`001Ql000DN0011B008S@00dJ@0
0?/D003i7000c;4000271@00=d<000@M00088P00DDd08iL00=V<003m2@00m2d00;c30000Nad002Lk
00036P003BL005a604ZT003SKP00o`400>i70029]P0006dd000H<@000QT001H_001Z>01o/`00k4`0
0?l0003TJ@00D:H0001MA@003BP000<J000W>`00O1`0`/@00?DZ003m3000ei@001NC0000BD`00P00
1Ql06P00ADX04Y400=FH003l3@00mRP00<G40000OA/002Lk00036P003RP005m405JX003VH`00mB/0
06f^0000ICh0014[00026P008CL007LT0;?0003d;`00o@X00=RA000IU00004Y<0P001Ql0KP00BD`0
6I@00=R@003m2@00m3000:no0000MRL001lf00026@004bd006Pk07^b003]B`00o`400>9a0010X@00
05M:000:900011`003I300290@3@Y`00na<00?LQ0037_P0007hH000X>`000aX000lY001R@@1W[@00
jUH00?l0003UJ000Bj@0001JB0002bD000<K000d@P00R0@0cjT00?/C003g8P00a/00001m6P009CX0
008J000A:`00ICh0M;000>a=003o0@00hG@003VO0000E4`000PR00057@00@4P049000=NE003m2P00
lc800:Fm0000LRd001Xb00026@006S80078]0:Fm003c<P00o@X00=JF000>S`0003i700047@002B<0
05M:04BR003TJ`00o`000>UI001NZP0005i5000<9P000a/003=100280P3AY@00o1000?HX002h`P00
07HV000M=0000QT001Pa001`;`2S_@00lc400?d;003EVP001hd0000iA00011`000/U001LA`1HZ000
j5/00?l0003TJ`00@:402_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l0
hGD00?d8003g8@00d:L001ZD0000ED/000dX00026@005Bl00652046Q003KR000o1000?XG003FUP00
;Y/0001KA`004B/0008I000A:`00G4H0<I`00=ND003j5@00na400=V=000jW`0005m4000C;@000QT0
010Z001JB00ZVP00eIP00?XG003l4000fXX003bP0000Gd@001<]00026@0042X005]802jK003GU@00
nQD00?/B003HT000=9d0001LAP004B/0008I000B;000GTD0>il00=Z:003l3`00nQT00=BL000SU`00
05M:000>:0000QT001L`001U?P1BY`00h7P00?h8003g9@00cJl000^>0000Cdh000TS00036P008CL0
06la07Na003WH000o`400?4i002m``00088@000iA0001Ql000DM000a@000OAX0Z[h00>m2003o0000
jUL008Be0000LR`002@i00036`002B<004e>00Z>003=[`00mb<00?d9003NO`00AZ<0001Q@`004bd0
008I000B;000Gd@0@Z800=f1003m2P00mb800<f_0009S@0004a=00088P000a/002Lj001e9`2B^000
k4d00?l0003/C`00SkL0001=<P000a/000TS001?CP0?T000d:P00?PN003l3P00fX/003>M0000FTP0
00hY00026@006S8006Ti06R]003UI@00o`800?4j002c`00007hI000`@00011d000LP0013B@00R@00
bkD00?HU003m2@00gH8003fP0000GDH0010Z00026@006C4006Tj06R]003VI000o`400?0m002[_P00
07/N000/?@0011`000PR001<C@0=S`00d:P00?TL003l4000ei<002FH0000ED/000/U00036P008SP0
07<[096h003]BP00o`000>UH001i/P0006dd000K<`000QT000lY001LA`0mX000gH000?h8003e:`00
akh000243000=d@000DN00067`00@DT00HX00<f`003h8000o0h00=R@000WV00005A<000;9@000a/0
02Dj001g9@2Q_000l4000?l1003UI`00GjX0001U?P0052h0008I000F;`00Ic`0IZ`00>IR003o0000
kTH009Bi0000Lb/0024g00026P003BL005Y803ZO003MP000oPL00?@^0033a00007lE000_?`0011`0
00PR001@CP0JU000eIP00?`A003h7P00cK0000290000?TL000DN00067`00@DT01H`00<nZ003i6P00
0?<0na@00=>P000@T00004Y<0007800011d003Q40026203:]P00mb800?`>003FU@0079D0001@CP00
228000@L000c@@00P`h0b;`00?HV003m3000f940026F0000DDd000PR00047000<T40088?0<Rl003f
9@00o0d00=NB000NU@00051>00088P0011`003E200252P3:]`00n2400?`@003EVP005I80001;C@00
1b0000DN000lAP00RP00cZ`00?TI003j5P00d:L000F<0000?dL000DN00068000BD`04i400=FJ003l
4000mb800<Vj0000P`h00350000470002B<005A<02nK003MPP00oPH00?<d002]_`0007LT000R>000
0QX000lY001P@`1HZ000iFD00?l0003/C`00N[80001Y>@005Bh0008I000I<P00KS80S[L00>m4003o
0P00hG<004:R0000FDP000/V00036`00;3h0080D0<Nm003g8`00o1000=>N000<SP00049900057P00
1b0004e>01fE003HS`00o@T00?@^002f`@0007PR000S>0000QX0010Z001R@@1T[000j5X00?<_001N
ZP000652000?:@000aX002Dj001k7@32a000mRP00?`=003EVP003Xl00012B@001Ah000LQ001@CP0U
V000fhL00?h6003b>000Wk`0001b;@006c<0008I000F;`00K3H0RKH00>m3003o0`00gg/003>M0000
E4`000PR00047@00?DH028d00=>N003l3P00mRP00<330000NQl002<h00026P004B/006Hm07Fa003/
C@00o`400>9a000nX00005I:00098`0011`003Y500F<003CW`00o0l00?HX002m``0007TR000Q=`00
0QT001<]001Y>@23]000kT@00?l3003NO@00;I/0001AC@001b4000DN0018B`0KU000fX/00?h6003a
>P00U[T0001^<`005c00008I000M=000MRL0]L400?D[003l3P00dil000>;0000=d@000@L000;9@00
FdP0DJH00>IQ003o0000iV80052V0000FTP000XU00047000>D@01X`00=BK003m3000m2l00:Rn0000
LRd001Tb00026@0073<007@Y0;?0003e:P00o0l00=6S0000R08003=100036`003BL0061306J/003[
D`00o`400>5d000dW@002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo05<0
hf`00?h5003f:000cK0000n@0000DTd000/V00026P006C4006Dn04jU003NO`00o@/00?TL003CW`00
8YL0001HBP003bT0008I000D;P00H4<0?J000=Z:003l4000nQH00=JF000]V`0005]7000@:`000QT0
018/001NA@0gWP00fHh00?/B003j5@00ei@002nK0000FdL0014[00026@004b`005i503ZO003JR`00
o1000?XG003EV@00:9T0001IB@003bT0008I000E;`00HT40Aj<00=f1003m2`00n1h00=6U000HT`00
05=<000<9P000QX001/c001Y>@1PZ`00hfl00?h5003e;000bKP0006:0000Ad/000PR00036`009CX0
07<[08Je003YE`00o`000>m1002]_`0007hI000c@@0200057P3F000gA000PA80^L800?4j003o0@00
if0007Ja0000KS80020f00036P002R@0055=01BB003AYP00n1d00?`=003KR000>Il0001MAP004B/0
008I000E;P00Hd00D:H00>1g003n1`00mRT00<Zh0000R@0004A:00078@0011`002`m001j802Q_000
kTD00?l0003YE`00P;@00019<`000aX000XU001BC@0JU000dil00?XH003k4P00eiD002NH0000ET/0
00`V00026P007C@006dd07Na003XG000o`000>m2002S_@0007TP000[?@0011`000PR001:C@0:SP00
cZ`00?PO003l3@00fX/0036L0000FDT000dX00026P0073@006dd07Ja003XF`00o`000>i5002L^`00
07LU000W>P000a/000TS001AC@0HT`00dih00?XF003j5@00e9d001VD0000DDd000TS00036`009c/0
07PT0:2l003_@P00o`400>IQ001Z[P0006Tj000H<@000QT0014[001P@`1:Y000h7H00?h5003c<P00
`<<000205@00<D0000@L00078@00BD`038h00=2W003i6P00na800=FJ000KU000055=00098`000a/0
02Xm001k7P2``000lSP00?l3003RL000DJH0001Q@P004B/0008I000I<@00JcL0MK000>UI003o0000
k4l008Fe0000Kc4001dd00026@003bT005i504NS003PMP00oP@00?8e002d`@0007/M000Z?0000a/0
00XT001CC00VV000fHl00?d<003g9000bKT000252@00=d<000@M00078000BD`03i000=:Q003j5@00
nAT00<nY0006S000049900067`001Ah003i7006:003>[@00nA`00?/C003CW`004I00001:C0001b00
00DM000iA000Q`D0bk<00?PO003l4000eIX001JB0000C4d000LQ00047@00>4@008L60<^d003h7`00
na400=BL000CT@0004Y<000780001Ah003]500290@3=[P00nA/00?/E003BX`002Xh00013B@8000HO
0<D004=900Z>003BX`00na@00?TL003=/00008L4000hA00011d000PQ001?CP0NU@00f9400?d;003f
:@00aL<0001n5`00:cd000<K000;9@00F4T0?:000=mi003o0`00lC`009fk0000Lb/001he00026@00
4B/006@o06J/003XG000o`000>UH001[[P0006Dn000B;0000QT001dd001b;02M^`00lC`00?h4003N
O000=Yh0001FB`002R@000@L000b@@00Q0/0bk@00?TM003j5@00d:L000::0000>dD000@M00088P00
DDd0:9T00=b5003n1P00lSH00:Jm0000M2T001he00026@004b`006Hl07>`003[D@00lS@0056V0000
GDH000dW00036`00:Sd0080E0<Rm003g8P00na800=6S0004R`0003]500047@00228005=<036L003N
O@00o`<00?10002@^00006hc000H<0000QT001Tb001`<02I^P00lC/00?h5003LQ0009iT0001@CP00
1b4000DN0014BP0CT@00ei@00?d:003d;`00/L00001f9`007SD0008I000D;P00JSP0Q;D00>i5003o
0P00ggX003:L0000Dd`000PR00057@00@DP049000=JF003m2`00m2l00:fo0000M2T001dd00026@00
5Rl006dd09:h003a?000oPD00=^7000QUP0004a=00067`001R0004m>02NH003MPP00o`@00>m20027
]@0006Xh000C;@000QT0028g001j8034a000mb@00?/B003?Z@0008L5000a@0000a/000`W001OA01O
ZP00jEP00?l0003TJ`00@j80001GBP002B<000@M0010B00AT000ei800?h8003b=`00VKX0001^<`00
5Rl0008I000O=P00NB80`/@00?LT003k4`00cZ`000242`00;Ch000<J000?:@00I3l0M;000>e:003o
0P00gWh002RI000:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`3VH`00
o`<00?@_0039^@001H`0001>CP002R@000<J000L=000JCT0G:T00>5e003n2000mb800<nY000GT`00
05A<000=9`000QT001L`001T?`1:Y000gH400?d<003i7000dil0026G0000EdX000hX00026@005Bl0
069204BR003LQ@00o0d00?TJ003DW@008iL0001GBP003RP0008I000F;`00HT40Aj<00=f2003m3000
nAd00=:R000LU@0005E;000=9`000QT001Ta001V?@1EY`00h7L00?h8003g9@00cJl000f?0000D4h0
00XT00036P007cH006dd06j_003UIP00o`800?<c0036`@0008H80010B0001b0000@L000Z?@00Mb@0
UKT00>a>003o0000kDT009fk0000NB0002dn000470001R0003i700252@36`P00lc800?l3003TJ@00
Ijd0001Z>00073<0008J000<9P00ED/089H00=BL003j5`00na800=RB000]V`0005U9000>:0000QT0
01Pa001W>`1NZP00hfh00?h4003d<000a/0000252@00?DH000HO00047@00<D4007hH0;70003a?@00
o`400>MP001b/00004De00026P0032L005I;02JH003FUP00na<00?XG003CWP006i@0001CC@002RD0
00<J000Q=`00LBh0QKD00>YC003o0000kD/009Bi0000MBP002Hj00036`002B<0051>01FB003BX`00
nAT00?/B003FU@009IP0001EB`002bH000<J000P=P00LBl0QKD00>]B003o0000k4h008bg0000Lb`0
028h00036P002bD005A<02>G003FU@00na400?TK003@YP003Xl0001<C@00228000@L000/?P00O1`0
/<000?4j003o0P00i6X005bZ0000ICh001D^00026@0052d006=005RX003SK@00o`800?4i002``000
07/M000[?@000a`000PR001?CP0FT`00dih00?/E003j6000dJ<0012@0000C4d000PQ00047000<400
07lF0<33003d<@00oPD00=mj0013XP0005e6000?:@000QT001dd001_<P23]000je000?l0003YE`00
M[40001[=`006C40008I000B:`00HD80E:L00>=]003o0P00l3d00:Bm0000Mb@002Di00036P002bH0
05M:03:L003LQ@00o@T00?D[0036`P00084B000a@00011`000PR001@CP0JU000eYP00?`@00008P3h
7`00c;8000280`00>dD000DN00068000ATX02hh00=6T003j5P00nQP00=2X0007S000049900067`00
1Ah0041800B;003?ZP00nAT00?XE003AX`002hh00015BP001Ql000DN000oA`03R`00cjX00?TI003j
5P00dJD000R=0000@dT200067`1b0012B@08S@00dJD00?XF003i6P00cZ`000290000?4H000DN0007
8000Bdd05I800=FI003l3`00mb800<Vi0000P`d00391000470002B<005=<02ZJ003KQ`00oPP00?@`
002h`P0007XO000V>P000aX000dW001LA`19Y000hVl00?l1003^A000S[L0001_<@006S80008I000D
;P00J3/0M;000>]C003o0000if4005fZ0000HD80010Z00026P008CL007LU0:bo003c=000oPL00=^6
000YV@00059=00088P0011d003Q400290@3?Z`00nQL00?TJ003=/00008H7000d@P0011`000TS001E
B`0eW@00gg`00?l4003`?P00UkT0001`;`006S80008I000E;`00JSP0PK@00>e9003a>@00@j80001I
B@002bD000<K000`@000Q0`0bk@00?TL003j5`00cZd000271@00=48000@L000:9000EdX0?J000>5d
003o0@00kTP0086d0000JSP001@^00026@007C@007@Z0:Rn003c<`00oPP00=V>000KU00004Y<0P00
1Ql0F`00C4d07YD00=Z;003n1`00lSH00:6l0000LRd001/c00026@005c0006hc09>h003`?@00oPD0
0=b4000VV00004m>000780001Ql004U<01^D003IS000oPL00?8g002N^`00070_000I<@000QT001Xb
001a;P2Q_000lcD00?d8003HT0005I800014BP001Ah000PQ001CC@0cW@00h7P00?l2003]BP00N;40
001V?@004B/0008J000V>P00OQP0b;`00?PN003j5`00c;8000233`00;3d000<J000?:@00HT40KJh0
0>]@003o0@00hG@003JN0000Dd`000LQ00057P00Ad/079D00=^8003n1@00l3l008Zf0000JSP001<]
00026P0093T007dJ0<Rm003h7@00nQT00<^f0000P1@002Pk00026P004B/006Pk08>d003_@P00oP@0
0=^7000LU@002_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo07<0jEX00?l1
003b=P00a/8000271000AT/000PR00036`0083L006dd06Z]003SK000oPD00?HY003</P0038h0001@
CP002bD0008J000K<`00J3/0F:P00>1g003m2000mb800<nY000FTP0005=<000<9P000QX001Ta001U
?@1AYP00gg/00?d:003h8000d:L001RC0000E4`000`V00026P006C4006Hm05FW003PN000o@P00?LS
003>[0004I00001AC@002bD000<J000L=000JSP0Hj`00>=^003n1@00mB`00<Zh0002R`0004U<0008
8P000a/002<h001a;P1m/`00j5`00?l1003a>`00^/8000214@00>D@000HO00047@00<40007/M0:Bm
003^A@00o`000>]B002>]`0007DW000X>`000a`000PQ0015BP00R@00bKT00?D[003n1@00hW8005VY
0000IS`001Pa00026@003RP005U902bJ003GT`00na800?XG003DV`008IH0001EB`0032H0008J000L
=000JcH0K:h00>EU003o0P00lSP00;c20000PA8003I3008000DN0?l003Q400224031a000lcD00?l3
003TJP00Hj`00011=P000QT000hY001JB00bW000fH`00?`>003i7@00d:L0012@0000Cdh000TS0003
6`009SX007HW09Fi003]B`00o`000>YC0025]@00074^000Q=`000aX000/U001DC00PUP00eIT00?/D
003j5`00dih001VD0000DDd000XT00036`009CT007DX09Bi003]BP00o`000>UG001m/`0006lb000N
=@000QX000dW001HB@0_W000fX/00?`=003h8@00cK0000B;0000ADX000LP00047@00<T40080D0;o3
003c<P00oP@00>5d001>Y@000652000B;0000QT001L`001W>`1V[000iV<00?l1003_@@00X;`0001g
90009SX000<K000:9000Dd`08YL00=ND003l4000n1d00<j/0006S00004A:000680001Ad003I30023
3@37_P00mBX00?d8003LP`00=ih0001IB@003BL000<J000Q=`00Lb/0TkP00>i7003o0000if0006R]
0000Ic`001H_00026@0052h006Dn06:[003VI000o`000>i5002E^@0007<[000P=P000QX000dX001K
A`0oX000gg`00?h5003c<P00^/80001m6P00:cd000<K000:9000Dd`09YP00=V>003m3000mRD00<Rk
0000Q0`003E200047@001b4004i>01JB003EVP00na400?PN003</@0008P2000kA@001Ah000HP0017
B`0>S`00dZ400?/D003i6`00cZd0006:0000?DL000DN00068000AT/03Hl00=:Q003k5000nA/00<f^
0000R@4003]600057P001b0004Y<01>A003DV`00na400?PP003;]@0008D9000e@`0011d000PR001@
CP0PUP00f9000?d;003f:@00aL80001o5P00;3h000<K000:9@00EdX0=Yh00=in003n1@00lSL00:Rn
0000MRH0024g00026P003bT0061305JX003UIP00o`000>a=001o/`0006/g000G<0000QT001L`001/
=P23]000kDX00?l1003TJP00CjH0001MA@003BP000<J000V>P00Nah0_<<00?D]003m2P00f8l001jE
0000CTh000LP00057P00?dL028d00=:R003k4P00n2000<Vi0000PQ0002ho00036`002bD005U9046Q
003QLP00o`800>i60028]@0006`e000G<0000QT001Ta001^<P2A^00007h0kd400>lo000gWP0005E;
00098`0011`003I300280`3?Z`00nQH00?TM003:]P0008<>000_?`000a/000/V001KA`1;Y000i6X0
0?l0003[D000L[00001V?@004R`0008I000Q=`00N2<0^<800?D/003m3000eYL0012@0000@TT000DN
00078@00DDd0:YX00=f1003n1000l3h009:h0000KS<001L`00026@006c<0078]0:>l003c=@00oPP0
0=V>000JU00004Q<00067`001b0004m>02JH003LP`00oP@00?0o002>]`0006`e000F;`000QT001de
001e:02a`000m2d00?d<003EVP002hh0000mAP0011d000TS001FB`0oX@00hfl00?l0003[D`00JJd0
001R@@003RT000<J000[?@00PPl0c;<00?XH003h7@00b;/0001n5`009SX0008J000A:`00IS`0Nk80
0>i7003o0P00gWh002ZJ0000Cdh000HP00067`00Cdh0:9T00=io003o0`00kTL007^b0000ISd0010Z
00036P00:C`0084B0<^d003j6000n1l00<Nn0000O1`002<h00026@0052h006`f09:h003a>P00oPL0
0=RA000AT00:ooooo`7o00000Oooool001kooooo0ol00007ooooo`180>]A003o0000l3h00;[20000
P`d003i700078@000a/002Di001a;P1h/@00iV<00?l3003d<000b;/0006:0000Bdd000TS00036P00
7cD006`f06J/003SKP00oPD00?HY003</P002hh0001@CP002R@000<J000L=000JCT0GjX00>9b003n
1P00mRL00<f`000=S`00051>000:90000aX001dd001Z>01SZ`00hfl00?h5003e:P00bkD000J<0000
CDh000TS00036P0083L006hb076`003VI000o`800?<c0036`@0008H60011B0001b4000@L000X>`00
MBL0S;L00>YC003o0000kd<00:Zn0000OAT003=10P001Ah0QP00=T<0080D0;C1003`?@00o`000>QK
001o/`00074^000S>0000a/000TS001=CP09S@00cK000?LT003m2000gg`004^U0000HT4001D^0002
6@0042/005a603RN003JR@00o0h00?TL003AY@005I80001AC@002R@000<J000P=P00Kc40N[800>QL
003o0000l4000:bo0000OA/0031000047@001R0003m700261`37_P00m2d00?h5003QL`00EJL0000m
=`000QT0014[001NA@0oX@00g8800?d:003g8`00c;4000F<0000B4/000LQ00047000:cd007XP0:Bm
003_@P00o`000>QL001f/@0006dd000M=0000QX000dW001GBP0/VP00f8l00?`?003i7000d:P000j?
0000CDh000PR00036`00:S`007TQ0:Bm003_@@00o`400>MP001^[`0006Xg000J<P000QT000lY001L
A`0lX000gH800?d9003f9`00bKT000271@00?DL000HO00057P00>4@008@;0<Nn003e:`00oPL00=im
0011X@0005e6000?:@000QT001Xb001/=P1e/000j5X00?l0003]BP00TKP0001c:`008SL000<J000<
9P00EdX0;Y/00=Z;003m3000mb@00<^f0000R0<003e60P001Ah0RP00?DH008P40<^e003g8`00o@`0
0=V=000ZVP0005E;000;9@000aX002Dj001g9@2R_000l3l00?l1003TJP00FZT0001S@0004b`0008I
000H<000JCT0LJl00>QJ003o0000k4h008Fe0000Kc4001`d00026@0042X005m404bU003RLP00o`<0
0?4j002Z_P0007PR000V>P000aX000/U001GBP0bW000g8@00?h8003e;000aL@0001o5@00;cl000@L
00098`00DTd08YL00=RA003l3@00mb@00<Vj0000Q0`003A200047@00224004m>01VD003FU`00o0l0
0?PQ003:]P0008H8000g@`0011d000LQ001>CP0HT`00eYP00?`?003g8P00b[L000252P00=D8000@L
00088P00D4h07YD00=NB003m3000mRH00<Nn0000PA8002lo000370002B<005A<02bJ003KQP00oPP0
0?@`002i`P0007/N000W>`000aX000`W001JB013XP00hG@00?l2003`?`00V;X0001b;@007C@0008I
000B:`00I3l0IJ`00>QM003o0000jUH0072_0000Ic`001@]00026@006c<0070`09:h003_@P00o`80
0>5d0012XP0005Y8000;9P000a/002/m001o5P36`000mRH00?`>003EV@004Y400017B`8000HO09@0
04M;01:A003EV000o0h00?HW0035`P0007hI000Y?0000aX000dW001MAP1?YP00i6T00?l0003/CP00
N;80001X>P0052d0008I000L=000Lb`0X;`00?8i003]A000:YX0001BC@00228000DM000mAP06S000
dZ400?/A003g8`00akl0001o5`00:C`000<J000=:000Gd@0F:P00>MQ003o0000jET006B/0000HT40
00lY00036P009SX007`K0<G2003g9@00o1000=:Q0006S00003]600047@002B8005A<03JN003PN000
o`800>i60022]00006Xi000D;@000QT001le001f9P2b`000m2h00?d;003FU`003i000011B0001Ad0
00PR001CC00cW@00ggT00?l2003^A`00Ok<0001X>P004b`0008I000R=`00NB00`L@00?HV003l4000
dJ<0002:0000=T<000@L000:9@00FTP0CJD00>EU003o0000j5`005^Y0000GTD000`W00036`00<D00
08H60<nZ003k4`00mb<00<G40000NQl0028g00026@0052d006Xg08^f003`?`00oPD00=^7000NU@00
04U<00057P001b40059=03BM003QM@00o`400>]?001/[P000691000>:0000a/002ho00252@3?Z`00
na<00?LU002o``0007PS000N=@000QT001L`001`<02Q_000lc800?d;003EVP001X`02?ooool3o`00
007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l0kDP00?l0003^AP00Z[h0001o5P00>4@0
00HO00047000:S`007DW08Ne003YF@00o`400?8h0035a00008H70013B@00224000<K000S>000L300
MK000>IT003o0`00m3000<Rk0001RP0004U<00098`000a/0020f001^<`1][P00i6P00?l4003d;P00
bKT000::0000BT`000TS00036`008CL006hb076_003UI@00o`<00?<a0037_P0008P30015BP002240
00<K000U>@00LR`0P;@00>QK003o0@00lC/00;_20000PQ0003Y500067`0011d002hn001i802L^`00
kD/00?l0003]B`00VkX0001i8@00;Ch000@L00068000?DH008@<0<C4003b=@00o`800>IT001`[`00
06dd000N=@000aX000XU001AC@0DTP00d:L00?PN003m3000g8D003jP0000GT@0018/00026@004bd0
061304FS003MP000o@X00?LR003=[P002hh0001=CP002B<000<K000U>@00LbX0R[H00>]C003o0000
kTP009bk0000N28002Xm000470001b4004I;00::003;]@00mRH00?h8003NO@00Aj<0000j>0000QT0
01<]001R@P1<Y@00ggT00?h7003e:P00bKX000281000@4P000HP00047@00<D0007hH0;C1003a>P00
o`800>EV001W[@0006Ti000I<@000QT000lY001KA`0hW`00fhH00?d;003g8`00c;4000>;0000ADX0
00LQ00047000;cl007dI0;C0003a>@00o`800>AY001PZ`0006Hl000F;`000QT0014[001P@`19Y000
h7P00?h6003d;P00a/8000233P00=T<000DN00067`00?dP008P20<^e003g9000o@/00=^7000dW@00
05U9000=9`000QX001he001`<024]@00je400?l0003[DP00P[@0001_<@007C@0008J000>:000FdP0
>il00=f1003n2000mBX00<No0000P`d003I300057@001R0004A:00J<003>[000nAd00?/A003FU`00
7YD0001BC@002B<000<K000Z?@00Nad0//000?8g003o0`00hG<004bU0000Gd@0010Z00026@006c<0
06dc082c003[D@00o`000>UG001f/@0006/g000I<@000QT0018/001S@01JZ@00i6T00?l1003_@P00
V[X0001d:@008CL0008J000=9`00FdP0?j400=mk003n1@000?<0lc@00;G10000Nad002Tl00036`00
2RD005E;02jK003KQ`00o@T00?D[0035``00080E000^?`000a`000TS001BC@0UV000fHh00?d;003f
:000akl000214@00<40000@L00098`00DTd099L00=V>003m2`00mRP00<K00000P1<002lo00037000
2B<005A<02ZJ003KR000o@P00?@]002o``0007dJ000Z?0000a/000/U001HBP0iW`00gW`00?h5003b
=`00ZKh0001g9@008SP0008J000>:@00GTD0DJH00>A[003o0@00kTP008Vf0000KS<001Tb00026@00
52h006Pk07>`003ZE000o`000>MO001RZ`0006=0000A:`000QT001lf001d:P2R_000lCX00?h4003N
O@00=Id0001FB`002R@000<L000a@000P`d0b[L00?PO003k4`00dZ8000N=0000?dL000DN00078000
CTh07YD00=V?003m2P00m2h00;S20000NB0002@i00026P003bT0065205fZ003WH000o`000>UG001Z
[@0006@o000A:`000QX0024g001g9@2``000m3400>];000NU@0004i>000780001Ah004A:016@003E
V000o0d00?DZ002o``0007XO000T>@000QX0010Z001S@@1V[@00jEP00?l0003VHP00EZP0001NA@00
3BL000<K000[?@00PA<0bKX00?PO003j5@00cjX000280`00=D8000@L000:9000F4T0@j800>=^003o
0@00k4l007>`0000ICd0014[00026P008cP007XO0<;4003f9`00o0l00=:Q0004R`0003Y500047000
2B<005M:042Q003RL000o`400>]?001`[`0006@o000@:P000QX002Hj001n6037_@00n2000?XE003>
[@0008D8000`@0000a/000`W001NA@1KZ@00j5`00?l0003UI@00CJD0001JB0002RD000@L000gA003
R`00dj000?`>003e:P00]/40001f9P007CD0008I000G<000Kc80V[X00?8g003n2000f94001>A0000
@DP000DM00098P00ET/0@J400>=/003o0000jEP005jZ0000GTD000`V00036`00=48008T00=:Q003l
3P00mB`00:no0000LbX001Xb00026@006c<007@Z0;70003e:`00o0l00=6T0000R0<02_ooool1o`00
007ooooo000Nooooo`03o`000?oooooooooo00Oooooo00H0l4000?l0003/C`00V[X0001k7P00<D02
00057P0e000`@000NR00UkT00>]@003o0000l4000;G10000PQ0003a60006800011`002Pk001d:@24
]000j5/00?l1003b=`00aL@000262000@TT000LQ00036`009CT0078]07bb003WG`00o`800?8e0035
`P0008H70012B@001b4000<K000V>P00Lb`0P;@00>QL003o0@00lST00<330000Q0`003e700068000
11`002Xl001g9@2@^000je800?l0003_@`00Zkh0001n6000=4800P001Ah0B000=48007hH0:bo003_
@P00o`000>YD002;]P0007DX000W>`000a`000LQ0014BP00R080b;`00?@^003n1000hfd0066[0000
JCT001Xb00026P0032L005E;022F003DW@00nQP00?/A003HS`00<I`0001JB0003bT0008I000F;`00
I3l0DjL00>1f003n1P00mBT00<Zg0000RP0004E:00078@0011`002Xl001h902I^P00kDX00?l0003[
D@00SKL0001d:@009CX000<K00098`00CTh03Hl00<j[003h8000o@`00=^6000jW`0003Hh00026@00
5c0006Hm05ZY003RK`00oP@00?<a0035``0008<=000iA08000DN0?l003M400223`34a000lc800?l4
003RK`00FJT0001U?P005Rl0008I000A:`00Gd@0AZ<00=il003n1`00mBT00<Vj0000Q`D003i70006
7`001Ad003E300224@34a000lc400?h4003QL`00DZH0001R@@004bd0008I000D;P00I3l0EjP00>=_
003o0`00lSH00;[20000OQL00310000470001b4004M;00N=003>[000n1h00?`?003HT@00:9T0001E
B`002bD000<J000S>000M2X0TkP00>e9003o0000j5/007>`0000JcL001Xb00026@0042X005m404RS
003PM`00oPD00?<b002o``0007lF000`@00011`000PQ001<C@0@T000dZ<00?XG003j5P00dj0001>A
0000CTh000PR00047000<40007lE0<;4003d;`00oPH00=im000nX00005]7000>:0000QX001lf001b
;@2?]`00kDT00?l0003WH000Ijd0001W?0005Bh0008I000E;P00Ic`0J:d00>MO003o0000kDX008^f
0000L30001dd00026@003bX005m404bU003RL@00o`<00?4l002U_@0007LU000T>@000aX000`V001I
B@0jW`00gWh00?h6003c<`00]l40001k7@00:C`000<K000;9@00ET/0<I`00=b4003n1`00m2l00;k3
0000OAX002/m00036`002R@005I;032L003LQ000oPL00?@_002l`P0007`K000Y?0000a/000/U001G
BP0gWP00gWh00?h5003c=@00[kl0001i8P009CT000<J000=9`00G4L0AZ<00>5c003o0P00l3l009Vj
0000LR`001he00026@004B/0069105nZ003VH@00o`000>]@001j/P0006Xh000F;`000QT001P`001/
=P22]000kD/00?l0003UJ000DjL0001OA0003RT0008J000S>000N2<0//000?<b003n1`00fhL002RI
0000DTd000PR00047@00=d<008L40<f^003i6@00nQP00<j/0000R08003Q400047@002280059=02ZJ
003LQ@00oPH00?8e002X_P0007DX000O=P000QT0014[001U?P1[[P00jUL00?l0003WH000FjT0001P
@`003bT000<J000U>P00Nah0`<<00?DZ003ZDP004i400016BP001Ql000HP001<C@0LU@00fHh00?d9
003d<@00[kl0001f9P0083H0008I000B;000Ic`0MK400>a?003o000006X0hf`004RS0000FTP000/U
00036`00<D0008D:0<f`003j6@00nAX00<^c0000P`d002lo00036`0032H005a6056V003UI@00o`00
0>UH001U[0000652000?:@000aX002Pk001o5`38_@00n2000?/D003?ZP0008L5000c@@000a/000/U
001KB01=Y@00iFH00?l0003YF000HZ/0001P@`003RP000<J000/?@00PQ00bk@00?TJ003i6`00b[H0
00214P00:Sd000<J000>:@00HT40JJd00>]C003o0000hfh0042Q0000ET/000TS00047@00?TL03Hl0
0=JF003m2P00lc400:Jm0000LRd001Xb00026@006S8007</0:Zn003d;`00o@/00=FK0008S@0003Y5
000470002R@005Y804nV003VHP00o`000>IR001@YP0005Y8000:900011`003]500Z>003FV000o@X0
0?<c002O_00006la000G<0000QT001le001h8`31a000mb@00?/D003>[@0008@<2_ooool1o`00007o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0?l0lSP00?l1003YF000R[H0001f9P00:cd000@M
00067`00=T<007hH0:Nm003^B000o`000>e8002U_@0007dI000e@P001Ah000@M000^?P00N280TkP0
0>]B003o0000l3l00;G10000PA4003Y50006800011`002Xl001f9P2<]`00jUH00?l0003`?@00^<80
00224000>dD000HP00047000:cd007LU092h003[D`00o`000>m1002``00007lE000f@`001Al000DM
000`@000Nah0Wk`00>e9003o0000kD/009^k0000NR0002ho00047@001Ql003Y50022402l`P00lCX0
0?l1003XG@00O;80001a;`008cP000<K00098`00C4d01hd00<bb003f9`00oPL00>1g001CY`0006Dn
000G<0000QT000hY001IB@0/VP00ei<00?/C003j5P00eIT002FH0000EdX000dW00026P006S8006Pj
066[003SK000o`@00?@`0036`00008D9000nA`001R0000@M000_?`00O1`0ZKh00>m1003o0000jEX0
07fc0000L300024g00036P002R@0059=01RC003BXP00nAX00?`@003HT000;I/0000d>@000QT001Xb
001Z>01X[@00iFH00?l2003a>@00]l40001o5P00<d4000@M00067`00?TL008L60<Rl003e:`00oPH0
0=mi001;Y0000652000C;0000QT001@^001S@01CY`00hG800?h4003d<@00aL<000223`00=d<000DN
00067`00?4H008H70<Rl003e:P00oPL00=il0014XP0005i4000A:`000QT001P`001X>`1V[000iFD0
0?l1003`?P00ZKh0001j7`00:cd000<K00088P00Cdh04Y400=:S003j6000na@00=FJ000LU000059=
000990000a/002Lk001h8`2S_000l4000?l1003UI@00I:`0001W?0005Rl0008I000C;@00Hd40EZP0
0>=^003o0`00lCT00:no0000Nah002Xm00036`002B<0055=01bD003EV@00na800?TK003?ZP0028d0
0015BP001b0000DM000f@`00Q0`0b;d00?HX003m2@00fhL0036L0000EdX000`V00036P0093T007HW
09nk003`@000o`400>AY001IZ@0006=0000B;0000QT001Ta001[=`1g/@00jUH00?l0003ZD`00Nk80
001/=P006C80008I000B;000Hd40FZT00>EX003o0@000:@0kd@009Ji0000Lb`0020f00026P003RT0
05e604RS003QM000o`<00?4j002W_@0007LT000T>@000aX000dW001JB00nX000ggX00?h4003b=P00
[[l0001i8P009SX000<J000<9P00FDP0?J000=mj003n1000lSL00:bo0000N2<002@i00036P003BL0
05]704BR003QM@00o`<00?4m002O_00007@Y000P=P000QX000lY001P@`1DY`00i6T00?l1003^B000
RKH0001^<P006S80008I000D;@00IS`0KJh00>UH003o0000jET006^^0000ISd001<]00026@006c<0
070`09:h003_@P00o`800>9b0016X`0005]7000<9`000aX002Pk001l6`32a000mB/00?d;003HT@00
7ID0001>CP001b4000DN000nA`05S000dJ@00?/D003h7P00bkD000242`00<T4000@L000:9000ET/0
=Yh00=mk003o1000l3d009Vj0000LBh001/c00026@0052h006Tj07Zb003/CP00o`000>AZ001=Y@00
05a6000<9`000a/002Xm001o5@37_P00mb<00>MI0008S@0003i700057@002240055=02RI003LQ000
oPH00?8h002O^`00078]000K<`000QT001D_001[=`24]@00kTH00?l2003QMP00>il0001FB`002B<0
00@L000gA000R@00d:L00?/C003h8@00b;`0001o5P00:C`000<J000>:000H4<0GjX00>QK003o0000
if4005JX0000GDD000dW00036`00;Ch008<>0<^d0080nAX004d0bk@000233P00;Ch000<K000=9`00
GT@0FjT00>QM003o0000iV8005BW0000G4H000`V00036`00<D4008H70<n[003k5000n2400<No0000
OAX002Dj00026P004B/006Hm07Ra003]BP00o`800>1h000cW@00059=00078@001Ah004I:01RC003I
S@00oPL00?4i002F^@0006hc000F;`000QT001he001g9@2j`P00mRP00?`@003AY00008T1000c@P00
0a/000`V001NA@1MZP00jET00?l0003TJ`00@Z80001FB`002B8000DM0012B@0ETP00fHh00?h6003a
>`00T;P0001[=P0052d0008I000S>000O1/0akd00?PM003i6@00b[L0001o5@0:ooooo`7o00000Ooo
ool001kooooo00?o0000ooooooooool01oooool0J03d<000o`800>IQ001k/P00078]000V>P0011`0
00LP000mAP00PPl0]l400?0o003o0000je4009Fi0000NB4002lo00057@001Ah003A2001m6`2S_000
kDT00?l0003^B000YKd0001m6P00=48000DN00057@00<40007XO09^k003/C@00o`000>i6002X_P00
07hI000d@P001Ah000DM000`@000Nad0Wk`00>e:003o0000kDX00:2l0000Nah0031000057@001Ah0
03I3001o5P2__`00kd400?l0003ZE000S;L0001e:000:3/000@L00078@00@DP008H60<K0003c<P00
o`<00>EV001][P0006`e000N=@000aX000XU001AC@0BT@00cjT00?PP003m2`00gH4004FS0000HD80
01@]00026@004B/005e603VO003JRP00o0h00?TK003BXP006I@0001CC0002bD000<J000N=@00KCD0
L:l00>IS003o0P00lSP00;c20000PA8003M30P001Ah0j000=D<0080C0;W2003a>@00o`400>IS001^
[`0006`f000L=0000QX000`V001FB`0TU`00eIP00?/D003j5@00eIX0026F0000<CT0008J000N=@00
KS<0Mk400>QL003o0000kd400:Nm0000Nah002dn000470001b4004I;00>;003</P00mb@00?d:003L
P`00?J00001MAP0042X0008I000H<000Ic/0HZ/00>AY003o0P00lSP00;K10000OQP0035000047@00
1b0004=9006:003</`00mb<00?d;003KQP00=ih0001JB0003RP0008I000K<`00K3D0M;000>QL003o
0000kTH009Vj0000MRH002Dj00036`002R@0059=01jE003EV@00na<00?TI003AY0004900001=CP00
228000@L000]?P00O1/0/l000?8h003o0`00hfh005JX0000Hd0001<]00026@005Rl006Ll06B/003V
I000o`400>m2002O^`0007LU000U>P000a/000/U001EB`0XV@00f8l00?`=003g8@00bk<000280@00
?TL000DO00057P00?DH008P20<^d003g8@00o0d00=R@000UV00005=<000:90000a/002Tl001j7`2_
_`00lSP00?l3003QL`00Bj@0001OA00042X0008I000L=000Kc40Q[D00>a=003o0000j5`006b^0000
J3/001H_00026@005Bh006Ll06V]003WGP00o`000>a=0026]@0006lb000K<`000QT0014[001Q@P1F
Z000i6X00?l1003_@`00UkT0001c:`007cH0008J000?:@00GTD0C:D00>9`003o0P00l3h009jk0000
MBT0024g00026P003RP005e504ZT003RL@00o`800?0o002L^`0007@Z000P=P000QX000lY001OA01B
YP00i6/00?l1003^A@00T;P0001`<00073<0008I000B;000I400HZ/00>MP003o0000je4007Zb0000
JSP001H_00026@005c0006Xg07bc003/C`00o`000>IS001LZP000692000@:P000QX001lf001d:@2Q
_000lCX00?h4003ON`00>9h0001GBP002RD000<K000^?`00PA80b;d00?LT003l3`00eIX0016@0000
AT/200067`2N0015BP0@T000e9/00?`?003g9000akh000205000;3h000<K000;9P00FTP0A:800>9b
003o0P00kTH008Vf0000KC@001P`00026@00630006dd08Vf003^A@00o`800>5c0010X@0005Q9000;
9@000a/003100024303;]@00nAd00>EP0000R04003M4000470002B<005E;03FM003ON`00o`<00>m1
002?]`0006hc000H<0000QT001Ta001_<@2D^@00l3h00?h4003NO`00;Y/0001BC@00228000DM000n
A`09S@00e9d00?`?003f9`00`l@0001k7P0093T0008J000@:P00I3l0KZl00>]B003o0000i6X004RT
0000FTP000/U00037000<d8008L40<nZ003k5000n2000<Rm0000OQL002Pk00036P003bT0069106Z]
003ZE000o`000>A[0016X`0005Q9000:900011`003Q400:;003BXP00o0l00?HW002n``0007TR000Q
=`000QT001@]001Z>027]@00kd800?l4003MPP009YP0001?CP001R0000HO001>CP0TV000g8<00?h4
003_@@00Q[D0001Y>@004bd0008I000S>000Nad0a/400?LQ003j5@00cZh000242`00;Ch000<J000>
:000HT40Jjh00>]@003o0@00hGD003FM0000DTd000LQ00057P00BT`08IH00=b4003o1000kd<0082d
0000Ic`0014[00026P00:3/0084C0<^d003j6000n1l00<K00000Nad:ooooo`7o00000Oooool001ko
oooo00?o0000ooooooooool01oooool0o`3f:@00oPD00>A[001/[P0006hc000Q=`000a/000PR0014
BP00Q`H0aL<00?8g003o0@00jEX008Je0000MBP002Tl000470001R0003Y500214P2c`000kd400?l0
003[D@00UKT0001i8P00;Sl000@M00067`00=T<007lG0:^n003_A000o`000>a>002H^P0007TQ000^
?`0011d000HO000g@`00OaD0[kl00>m1003o0000je80092h0000MbD002Xm000470001R0003e60023
3@30``00lST00?l1003XGP00O;80001a;P008cP000<K00088P00BD`00h/00<Zg003e:`00oPD00>9`
001NZP0006Pj000J<P000QX000`V001EB`0NU@00dil00?TJ003l3`00fXX003RN0000GDH0014[0002
6@0052d0065204JS003MP000o@X00?LR003>[0003Xl0001?CP002B<000<K000R>000LBl0Ok<00>UI
003o0000l4000:^o0000OAX0035000047@001Ql003a600252P36`P00lc400?l4003SK@00GjX0001X
>`006C40008I000>:@00FDP0<9`00=V>003l3`00nA/00=6S000ETP0002hi00036P008SP0078]08Ne
003ZD`00o`000>e:002G^@0007HV000W>`000a/000TR001>CP0>S`00cjT00?PN003l3P00fH`0032L
0000FDT000hX00026P006c<006/f072_003WG`00o`400>m1002V_@0007XP000[?@0011`000PR001;
C@0<S`00cjT00?TM003l3`00f90002ZJ0000EdX000`V00036P007cH0070`08Bd003[D`00o`000>a?
002:]P00078]000Q=`000aX000`V001FB`0ZVP00f8l00?`>003h7`00cZh000F<0000ADX000LP0004
7@00<d40084C0<?4003d<000oPD00>1h0018X`0005m4000@:P000QT001Tb001[=`1c/000j5/00?l0
003]BP00SkL0001b;00083L000<J000=9`00FDT0=9d00=b5003m2@00mRP00<Rl0000Q0/003M30005
7@001R0004E:00N<003?ZP00nA/00?/B003EVP006I@0001@CP00228000@L000^?`00OQL0_l<00?@`
003n1P00gWd003jP0000FdP000dX00026P0083L007<[09Ji003^A000o`400>EV001NZP0006@o000C
;@000QT001Pa001[=`1h/@00jUD00?l00000l`3ZEP00Mk40001Z>0006300008I000D;@00ICh0I:`0
0>MQ003o0000kD/008Ne0000Kc8001/c00026@004B/0069105ZY003UI`00o`400>i7002>]`00070_
000M=0000QT0014[001Q@P1HZ000iFL00?l1003^B000S;L0001_<@0073<0008I000B;000Hd00H:/0
0>IR003o0000k4h0082d0000K3H001Pa00026@005Bh006Pk076_003ZEP00o`000>UJ001[[P0006Hm
000C;@000QT001Xb001_<P2<]`00kTH00?l1003SK000CZD0001NA@003RP000<J000T>@00N280//00
0?<b003n1`00g8D002bJ0000Dd`000TS00047000=48008D90<^d003h7@00na@00=6T0006S00003m7
00057P001b0004i>01bD003HT@00o@/00?D[002o``0007/M000W>P000aX000dX001NA@1AYP00iFP0
0?l0003/CP00NK80001Y>P0052h0008I000K<`00LBh0VKX00?4m003n1000gWd003>M0000E4`000TS
00047000=T<008P30<j[003j5`00hVL000242`00<D0000<K000;9@00FDT0@Z800>9a003o0@00kDT0
082c0000JST001D^00026@007C@007<[0:Bm003b=P00oPL00=Z9000QU`0004m>000780001Ah004I:
01BB003GU000o@X00?@^002b`00007HU000O=P000QT001<]001X>P1m/`00kDT00?l1003QM000>il0
001FB`002B<000@L000jA@05S000dZ400?`?003f9`00`/@0001j7`008cP0008J000B;000Ic`0NK80
0>e;003o0@00hGD003RN0000ED`000PR00047@00?dL03Hl00=FH003m2`00m2l00:jo0000M2T001`d
00026@005c0006hb09Ni003a>@00oPH00=Z;000JU00004M;00057P001b40059=036L003ON@00o`80
0>e:001g/@0006Dn000@:P000QX002Pk001o5@3:^000nA/00?TJ003:]`00080D000X>`000QX0010Z
001V?@1j/P00kTL00?l3003NOP00:9T0001?CP001Ql000HP001@CP0]V`00ggX00?l2003/C000LJl0
001S@0003RT000<J000^?P00Q@T0cj/00?/B003f9P00_L<0001g9@0:ooooo`7o00000Oooool001ko
oooo00?o0000ooooooooool01oooool0C@3g8P00oPP00>5e001MZP0006Xh000M=0000aX000TT001<
C@03R`00bKX00?@_003o0`00iV@007Ja0000LBl002@i00036`001b40045900252@34a000lSP00?l1
003YFP00QKD0001d:@00:3/000@L00078000?DH008<>0;c2003a?000o`000>UG0028]P0007DX000Y
?00011`000LP000nA`00Q0`0`<<00?4i003o0@00j5`0082d0000LR`002Dj00036`00224004A:0028
0`37_P00m3400?l3003UI`00KJh0001]=0007cD000<J000:9000D4h03Hl00<j^003g9000o@P00=mj
001@YP0006@o000G<0000QT000hY001IB@0ZVP00eYH00080na@00?l0ei@002^J0000FDT000hY0002
6@005c0006Dn05BW003PMP00oPL00?HX003;]@000h/00018B`00228000<K000W>`00MBP0SkL00>]@
003o0000kDT009^k0000N28002/m000470001b4004A:00290@39^000mBX00?h6003PMP00DJH0001S
@0005Bh0008I000A:`00GDD0?J000=b4003m2`00n2400<j]000:SP0002Xh00036`009c/007HV09Ji
003]BP00o`000>]C0027]@00078]000R>0000aX000XT001BC@0IU000dil00?XH003k4`00eYH002BG
0000ED/000`V00036P007cH0070`082c003ZEP00o`000>e9002F^@0007HW000V>P000a/000TS001A
C@0GT`00dj000?XG003k5000eIX001jE0000Dd`000XT00036`0093T007@Y09>i003]BP00o`000>UH
001j/P0006dc000L=0000QX000hX001JB00gWP00g8D00?d:003f9P00b[L000271000?TL000HO0005
7P00>DD008D90<Rl003f:@00o@P00=f2000jW`0005]8000>:0000QX001dd001_<@22]000je800?l0
003ZD`00Ok<0001^<`0073@0008I000?:@00G4H0@J400=mk003n1P00m2l00<?40000P1@003500004
7000224004e>01:A003BX@00nQH00?XG003AY0003Xl00019C0001b4000@M000d@P00P`h0akh00?HY
003m2@00fhL0032L0000EdX000/V00036P009CX007LT0:Jm003a?000o`800>9`001?YP000613000@
:P000QT001`d001_<@27]@00k4`00?l0003WG`00J:d0001V?@0052h0008I000G<000JCT0Lk000>UG
003o0000jU@007Ra0000JSL001P`00026@0052h006Hm06R]003XG@00o`000>]@001o/`0006`e000I
<@000QT001<]001U?@1W[@00j5h00?l0003[D000O;<0001[=P006340008I000E;P00Ic/0Kjl00>UH
003o0000jEL0076_0000J3/001D^00026@00634006`f082d003/C@00o`000>IS001LZP000691000A
:`000QT001he001c:`2L^`00l3h00?l3003PMP00@:40001JB00032H000<K000Y?000OAX0`/@00?D[
003m2P00f8l001nF0000Cdh000LQ00047@00>dD008T00<nZ003j5`000:@0nAT00<j^0000R0<003Q4
00047@002280059=02RI003KQ`00oPL00?<c002__`0007LT000R=`000QX0010Z001R@@1PZ`00ieh0
0?l0003YE`00JZh0001T?`004B/0008I000O=P00MBP0ZKh00?<d003n1`00fhL002JH0000DDd000LQ
00057@00?DL01X`00=:R003k4P00h70000205000:cd000<K000<9`00G4H0D:H00>EW003o0000je80
072_0000ICh0018/00026@008CL007LT0;C1003d;P00o@X00=NC000FTP0004M;00067`001R0004i>
022F003JRP00oPL00?8f002R_000078/000K<`000QT001H_001/=@2<]`00kd400?l3003NOP00;Y/0
001BC@00224000DN0011B00?T000eYL00?d;003d;P00//00001f9`007SD0008I000E;P00JcL0R;H0
0>m2003o0`00gWl002bJ0000DDd000LQ00057P00AT/069<00=V>003n1`00lSH009jk0000L30001Ta
00026@006c80078/0:Nm003c<P00o@X00=JE000?T00003m800047@002B8005I;03jP003RK`00o`00
0>]C001X[@000652000>:0000aX002dn0024303=[`00nQD00?PQ0036`00007`L000S>0000QT001<]
001Z>02:]P00l3l00?h5003KR00079D00017B`001Ah000PQ001DC00jW`00hW000?l0003ZE@00HZ/0
001OA00032L000<K000d@P00R@00dZ400?`>003e;@00[;l0001b;0[ooooo0Ol00001ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`3o0?TL003m3000gWl004nV0000ISd001Tb00026P002bD0055=
00j?003=/000mRP00?h5003SK@00Ijd0001/=@007cH000<J00098`00BD`008X00<Rl003d<000o`<0
0>IS001f/@00070`000S>0000a/000PR0014BP00Q`@0a/000?<d003o0P00if4007Vb0000LBl002@i
00036`00228004E:00280P37_P00lc400?l3003UI@00LJl0001^<P0083L000<K00098`00C4d01X`0
0<^e003e:@00oPH00>9a001NZP0006Tj000K<`000QX000`V001CC00IT`00dJ@00?PM003m3000g8@0
04:R0000H4<001<]00026@004B/005e603NN003IS000o0l00?TI003CWP007iH0001EB`0032L0008J
000K<`00JCT0HZ/00>=/003o1000m3000<No0000QPH004180007800011`002`n001i802O^`00kTL0
0?l0003[DP00RkL0001d:@009SX000<K00088P00C4d02Hd00<f_003g8`00o@X00=f00013XP0005m4
000B;0000QT001@]001Q@P1;Y000ggX00?h7003f:000b[L0002900009SH000@L000]?P00Nah0Y[d0
0>m2003o0000j5`007Ra0000KS<001he00026P0032H005I;02FH003FU@00na800?XH003CX00069<0
001AC@002R@000<K000T>@00M2X0SkP00>a=003o0000je8008Je0000LBh0024g00036P002bD005E<
02>G003FUP00na800?TI003AY0004Y40001?CP002B<000<K000Y?000NB80Xkd00>m1003o0@00iV40
06^^0000JCT001Ta00026@0042X005i504BR003ON`00oPH00?D]0036`00008<=000g@`001Ad000HO
0011B000R@00c;<00?LR003m3000fH`002fK0000EdX000`V00036P008SL007<[09:h003]B@00o`00
0>QL001`[`0006Xh000H<@000QT0014[001P@`1?YP00hW800?l3003b=`00//00001k7@00:cd000<K
00098`00DDd07ID00=JG003l4000n1d00<j^0003R`00045800067`001Ah003]500271@3;]@00mb80
0?`=003HT@0099L0001CC0002R@000<K000Z?@00O1`0]/400?<d003n1@00ggT0046Q0000G4L000hX
00026P0083H007<[09Ni003_@`00o`40003c0>AX001IZ@000691000B:`000QT001Xb001]<`22]000
k4h00?l0003XGP00JJd0001V?@0052h0008I000G<000JSP0Mk400>YD003o0000jET006n_0000J3/0
01D_00026@005c0006Xi07Ja003ZE000o`000>UJ001][P0006Ll000D;P000QT001Pa001[=P1n/`00
k4l00?l0003WH000HZ/0001T?`004R`0008I000L<`00L300T;P00>i5003o0@00hfd004jU0000GTD0
00hX00026P008cP007LT0:bo003b=P00oPD00=f0000cW@0005I;000:90000a/002lo00214P38_@00
mb@00?`?003EV@0059400019C0001R0000DN0012B@0:SP00dZ400?/B003h7`00b[L000233@00<D00
00@L000:9000ET/0=9d00=im003n1000lCX009nk0000Lb/001dd00026@004R`006Hm06n_003ZE@00
o`000>MQ001LZ@000613000?:@000QX002@i001j802j`P00mBd00?d:003HT@006Y@0001;C@001R00
00DO0015BP0AT@00eIP00?`=003LM`0007/M000V>P000aX000lY001Q@`1NZP00j5h00?l0003XF`00
HJ/0001Q@P003bT000<J000V>P00O1`0a<@00?HW003l3P00e9d000Z>0000?dL000DM00088@00DTd0
;IX00=f0003n1000l3h009:h0000KS<001P`00026@006S80074_09bk003b>@00oPH00=^8000RU`00
04i>000680001Ql004U<01^D003IS@00oPL00?8e002Q_000078]000J<P000QT001Pa001_<@2H^P00
lCX00?h6003KR@007iH0001;C@001Ql000HP001>CP0TV000g8@00?h4003`?`00S[L0001/=P005Bh0
008I000O=@00MbD0]l400?DZ003l3P00dil000B;0000>4@000@L000:9000FDP0BjD00>EV003o0000
j5`005VY0000GDH000`V00036`00<d4008P20=6U003l4000mRL00;c20000Mb@001he00026@005Rl0
06hb09Zj003b=`00o@P00=NB000@T00003m700047@002B<005Q:04RS003UI`00o`000>MN001DY`00
05]7000:9@0011`003Y500Z>003FU`00o@X00?<d002L^`0006hb00[ooooo0Ol00001ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`3o0?XF003l4000fhT0046Q0000HD8001H_00026@003BL005E;
01VD003@Y`00mb400?d8003PM`00FJP0001X>P006c<0008J000:9@00D4h02hh00<bb003f:@00oPD0
0>=]001V[@0006`f000O=@000aX000TS001=CP05S000b[L00?D/003n1000i6X006Z]0000K3D001lf
00036P002B<004i>00N<003;]@00mBX00?h5003SK`00HZ/0001Z>00073@000<J000;9@00DDd04I40
0<n[003g8P00o@T00=mk001@YP0006@o000G<0000QT000hX001GBP0UV000eIX00?XG003k4@00fHh0
03FM0000G4H0014[00026@0052d0065204BR003MPP00o@/00?PO003@Z0004i40001AC@002RD000<J
000O=@00KC@0LK000>IR003o0P00lSL00;k30000PQ0003U400067`001Ad00391001n602__`00l3l0
0?l0003XF`00O;80001`<0008CL000<J000:9000DDd059800=6U003i7000o0h00=Z:000fWP0005]7
000@:P000QT001L`001V?@1IZ@00hW400?h4003d;`00a/0000252@008C<000DM000c@@00OaH0]l40
0?4i003o0P00iFD006V]0000JSP001Xb00026@003RP005Y803:L003JR`00o0h00?PN003?ZP0038l0
001=CP00228000<K000Y?000N2<0Wk`00>m4003o0000j5/007Na0000KC@001`d00026P003BL005Q9
032L003IS000o0d00?PO003>[@001hd00017B`001b4000@L000_?`00OAX0]<400?8i003o0P00i6/0
05bZ0000ICh001D^00026@004bd0069105:W003RL@00o`@00?<d002k`P0007lF000`@00011`000LQ
0018C00:SP00cjT00?TL003k4@00eYH0026F0000Dd`000XT00036`009cX007PT0::l003`@000o`40
0>EV001QZ`0006Hm000E;P000QT001@^001U?P1NZP00iFP00?l1003`?`00X[`0001g90009SX000<K
000;9@00ED/0:YX00=V=003m3000mb@00<Zg0000QPH003Y500057P001Ql0049900F<003>[000nA`0
0?/B003DV`0069<0001?CP00228000@L000`@000P1<0aL<00?D/003n2000g8<003BM0000F4X000`V
00036P009CT007PT0:Nm003a>`00o`<0003c0>9b001;Y00005i5000?:@000QX001he001b;@2B^000
kTD00?l1003UI`00FZT0001R@@004B/0008I000K<`00KS80QkD00>e;003o0000iV80066[0000I3l0
018/00026@006S8006hc08Je003]B`00o`000>IS001NZP0006=0000B:`000QT001`c001`<02>]`00
kTH00?l1003TJP00DjL0001P@`003bT0008J000P=P00M2T0X;`00?4l003o0`00h7L0042Q0000FTP0
00`V00036P00:3/007`L0;c3003d;P00o@T00=Z:000VV000059=00088P0011`003E20026203;/`00
n1d00?/C003BX`0028d00011B0001Ah000HP001:C00FTP00eYL00?`=003f9P00a/00001o5P00:cd0
00<K000;9P00FDP0@Z800>5c003o0P00kd<008ng0000Kc8001Tb00026@005Rl006Xh07jc003/C000
o`000>AZ001=Y@0005a6000=9`000aX002Tl001n6036`@00mRH00?`>003DV`003Xl00013B@001Ah0
00LP001=CP0MU@00fHh00?d9003CN00007LT000Q=`000QX0014[001U?P1][P00jU@00?l0003UI@00
DjL0001MA@003BL000<K000[?@00P1@0b;/00?PP003k4`00d:L000290000>4@000@L00098`00ET/0
>Yl00>1f003o0P00kTL008:d0000JSP001@^00026@007SD007DX0:bo003d<@00o@T00=NB000FTP00
04I:00057P001b00051>02NI003LP`00oP@00?0n002A^00006dd000G<0000QT001`c001c:`2X_P00
lc800?d9003GT`004i400013B@001Ah000PQ001BC@0aW000ggX00?l2003^A`00O[<0001X>`004R`0
008J000S>000Nad0aL<00?LS003k4`00cjT000271@00<T4000<K000<9P00GDD0FZT00>QL003o0000
iFH004^T0000FDT000XT00047000>TD01hd00=BK003m3000m2l00:^n0000Lb/001Xb00026@006S80
078/0:Zn003d;`00o@`00=BL0005S00003Q4000470002bD005a705JX003XG@00o`000>EX0016X`00
05M:00098`0011d0049901FB003IS@00oPH00?4m002<]`0006Xh00[ooooo0Ol00001ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`300?/A003j5@00ei<003>M0000GDD001</00026@0042X005U9
02JH003DW@00nA/00?`<003MP@00BZ@0001T?`006300008I000<9`00E4`05Y800<nY003g8P00o@P0
0>1g001HZ00006Pk000K<`000QX000/U001AC@0@T000cZd00?LU003n1`00hG@005^Y0000J3X001/c
00026P002bD0059=01:A003?Z`00mb<00?d8003PN@00DjL0001V?@006340008I000=9`00ED/07ID0
0=:Q003i7000o0d00=b50012XP000613000D;@000QT0010Z001KA`0bW000f9000?/B003j5P00eIP0
02RI0000F4T000hX00026@005c0006Dn05:W003PN000oPL00?HV003</P0028d0001<C@002B<000<K
000S>000LRd0PK@00>UI003o0000l4000:jo0000OQT0039100057@001Ql003U400223`2o``00lSL0
0?l2003UI@00K:h0001/=P0073@0008J000<9P00ED/089H00=BL003j5`00na<00=ND000YV@0005M:
000=9`000QX001Xb001Z>01X[@00iFL00?l2003b=`00_<<000214`007C4000DO000jA@00P`d0aL<0
0?<a003n1000hVl005ZY0000ICd001H_00026@004B/005i503nQ003MP@00o@T00?LU003;/`000XX0
0014BP001b0000@L000_?`00OA/0/<000?4l003o0@00iFD006N]0000JCX001Ta00026@003bX005a6
03fP003MPP00o@T00?HV003:]`0008P20010B0001Ql000DM000e@P00PA40a<@00?@a003n1@00hGD0
04jU0000HD80018/00026@005Rl006Hm066[003UJ000o`800?4l002[_P0007XO000Z?@000a/000TS
001?CP0ETP00dil00P3j5P00o`3CX0005I80001?CP00228000<L000/?P00O1`0//000?8h003o0`00
hW0005>W0000HT80018/00026@005c0006Tj06f^003WGP00o`000>e8002B^00007</000Q=`000aX0
00dW001IB@0gWP00g8<00?d8003e:`00a/0000224000<d8000@M00078@00Bdd049000=:R003j5P00
nQL00=6T000<S`0004Q;0007800011d003M300252P39^P00mRD00?d<003IS@009iT0001DC0002R@0
00<K000Z?@00O1`0^<400?<c003n1@00gW`003fP0000FTP000dW00036P008cP007HV0::l003`?@00
o`800>9a001<Y@0005i5000?:@000QX001lf001c;02G^@00kd800?l1003SK000DZL0001P@`0042X0
008J000N=@00LRd0U[T00>m2003o0@00hfd0052V0000Gd@000lY00026P0083H007@Z09jk003`?P00
o`<00>5d0015X`0005]7000=9`000aX002Di001i8P2``000lc@00?h6003MP@00<id0001FB`002R@0
00<K000]?P00P1@0a/000?HW003l3@00ei@001ZD0000CTh000LQ00057@00?4H00HX00<nZ003j5`00
nAT00<j/0000R@4003U500047@002240051>02:G003IS@00o@T00?@]002k`P0007/N000V>P000aX0
00dX001MA@1@YP00i6X00?l0003]C000Ok<0001Z>0005Rl0008I000I<@00KS80S[L00>m3003o0P00
hG@003nQ0000F4T000/U00036`00;cl0088?0<Zh003h7`00na<00=6U0004R`0003a600047@002280
059=02VI003LQ000oPH00<Yj0000Lb`001dd00026@0052h006Tj07bc003]B`00o`400>=_0015XP00
05U9000;9@000a/0035000242`3</P00nAX00?XI003=/00008D9000a@0000a/000/U001JB017X`00
hf`00?l0003[D000Lk00001V?@004B/0008J000R>000NB40_L<00?DY003l3@00e9`000Z>0000?TL0
00@M00088P00E4`0=9d00=mi003o0P00kTH0086d0000JCT001<]00026@0083H007PT0;W2003e:P00
o0d00=BM0008S@0003a600047@002B<005I;03jP003RL000o`400>]@001^[`0006=0000?:P000aX0
02Pk001o5@39^@00nAd00?XH0000<@3</`00088?000/?@000aX000hX001Q@P1Y[@00je<00?l0003R
L000?J00001EB`00228000DM0011B00BT@00f9400?h8003b=P00VkX0001_<P005c00008I000N=@00
MbD0^/800?HW003l4000d:H000271000<T4000<K000=9`00H4<0I:`00>YD003o0000hW8003RN0000
Dd`000LQ00057P00BT`08IL00=b3003o0`00kTD007bc0000ISd02_ooool1o`00007ooooo000Noooo
o`03o`000?oooooooooo00Oooooo0?l0o@`00?TK003DW@009iP0001IB@0042X0008I000B;000GDH0
<Yd00=NC003j5@00na400=Z;000lX0000613000D;P000QT000lY001HBP0RU`00dil00?TL003m3000
gH4004VT0000Hd0001L`00026@003BL005E;01bE003AY000n1h00?d;003NOP00C:D0001T?`005c00
008I000=9`00ET/07YD00=:Q003i7000o@`00=b30015X`000692000E;P000QT000lY001IB@0YV@00
eYL00?XF003k4@00fHl003BM0000G4H0014[00026@004bd005m403nQ003KQP00o0d00?TL003BXP00
6i@0001DC00032H0008J000K<`00JCT0HJ/00>=^003n1000m2d00<Rk0000R08004A:00078@0011`0
02Pk001f9P2A^000je000?l0003]B000WK/0001i8@00;3h000@L00078000@4P008L60<Nn003d;`00
oP@00>=_001MZP0006Lk000I<@000QT000hX001IB@0]V`00f9800?/A003j6000dih001bE0000Dd`0
00/U00036P007cD006hc07Na003XG@00o`400?0o002/_`0007`K000J;P001b00045800280`39^@00
mBX00?h7003ON@00Bj@0001Q@P004bd0008I000C;@00HT40CJD00>1g003n1P00mB`00<Rm0000QPP0
03e600067`001Ad003E200214P31a000lc@00?l3003SK`00F:P0001U?P005Bh0008I000B;000HD<0
Bj@00>1h003n1P00m2d00<K00000Q0`003Q400057P001Ql003a600261`38^`00mBT00?h8003NO`00
@:40001MAP003bX0008I000J<P00JSL0L:l00>MN003o0000kTD009Zj0000MRH002Di00036`002R@0
05=<026G003FU@00na400?TL003?Z@002Hd00018B`001b4000@M000b@@00P1<0`l@00?@`003n1P00
ggX004BR0000GDD000lZ00026@006c<006dd07bb003ZE@00o`000>]A0022]00006hb000L=0000QT0
00lY001MAP14XP00h7T00?h5003c<P00^l80001n6@00;Ch000@L00098`00D4d06i@00=FH003k4@00
n1d00<f^0002RP00041800067`001Ah003i70029003=/000n1h00?`@003FU`006i@0001@CP002280
00@L000`@000P1<0aL800?D[003m2@0003l0fhH0032L0000ET/000/U00036`00:3/007XO0;?0003c
=@00oPD00=mk000nX00005Y8000=9`000aX002@i001g902W_P00lCX00?l3003PMP00A:80001LA`00
3BP000<J000S>000MRH0Y[d00?4j003o0`00h7L004:R0000FdP000dW00036P009CT007PR0:jo003b
=@00oPD00=in000hWP0005M:000;9@000a/002Xl001m6P31a000mB`00?d9003JR`009YP0001BC@00
228000@L000d@P00Q0/0b[H00?PP003k4@00dih000n@0000ATX00P001Ql0:P00@dT038h00=>P003k
4P00n1l00<Zf0000Q0/003=1000470002B<005A<02jK003LP`00oPH00?8e002[_P0007HV000Q=`00
0QX0010Z001R@P1NZP00if000?l0003ZE@00Kjl0001V?@004bd0008I000M=000LR`0W[/00?4k003n
1000gWh003:L0000E4`000TS00047000=D<008L50<f^0080nQT007d0cJl000271P00=D8000@L0009
8`00ED/0=Yh00=mj003o0`00`G`0001^<P006C40008I000G<000KC@0S;L00>m2003o0`00h7T003NN
0000ED/000TS00047000=d@008T10=2X003k5000n1l00<Vj0000PA<002/m00036`003BL005i505FX
003VHP00o`000>UI001S[0000652000?:@000aX002Lk001n6@37_`00mb800?/B003AYP0008T0000g
@`0011`000XT001GBP12X@00hVl00?l1003/C`00L[00001U?P004B/0008J000U>@00O1`0a/800?LS
003k4P00d:H000290@00=D8000@L000;9@00FTP0C:D00>EV003o0000jET005nZ0000Gd@000dW0003
6`00;Sl008@<0<f`003j5`00n1h00<Rl0000OQP002Hj00026P004B/006Hm07Ra003]BP00o`800=mi
000`W000055=00078@001Al004U<01jE003KQ`00oPD00?0o002;]P0006Xh000D;@000QT0028h001k
7@36`@00n2400?XF003=/00008<>000/?@000aX000lY001T?`1d/000kD/00?l2003OO000:iX0001?
CP0200068007001@CP0^V`00ggT00?l1003/CP00KJh0001R@@0:ooooo`7o00000Oooool001kooooo
00?o0000ooooooooool01oooool0o`3m2000mb400=2V000JU00005E;000=:0000QT001D_001Q@P10
X@00fXT00?`@003j5P00eYD002nK0000G4L0014[00026@004B/005a702nK003FU@00nQH00?/A003J
R`00?:00001OA00052d0008I000?:P00FDT0:9T00=FJ003j6000o0l00=^8000nX0000613000D;@00
0QT000lZ001JB00ZVP00eYL00?XF003k4@00fHd003NN0000GDD0018/00026@004R/005e603JN003I
S@00na400?XG003EV@009iT0001HB@003RT0008I000F;`00Hd00CJD00=il003m2@00mb800<j/000@
T000051>000:90000aX001le001]=01`[`00iV@00?l2003b=@00a<@000243000?4H000HO00047@00
;Sl007XO0:6l003^A`00o`000>]B002=]`0007DX000W>P000a/000PR0018C004R`00bk@00?HW003n
1`00h7T004nV0000Hd0001D^00026@0042/005e603ZO003KQ`00o0d00?PN003@Z0004I00001@CP00
2B<000<K000S>000LR`0QkD00>YD003o0000kTP009^k0000N2<001H/00088P00BD`01h`00<f`003g
8`00o@X00=b3000mX00005e6000@:P000QT001L`001V?@1LZ@00hfd00?l3003c=000`L@000214@00
=T<000DN00067`00?4H008D80<Nm003e;000oPH00>1i001:Y0000613000B;0000QT001D_001U?P1I
Z@00hfh00?l3003b=@00^l80001o5@00<T4000@M00078000@dT00XX00<bb003g8P00o@`00=Z9000b
W00005U9000=9`000QX001he001_<P1o/`00jU@00?l0003/CP00R[H0001b;@0083H000<J000<9P00
EdX0;Y/00=Z;003m3000mb800<^c0000R@00041800067`001Ah003U400252P38_000mRP00?d9003L
Q000=ih0001IB0003BL0008J000O=P00LBh0S;L00>e<003o0000j5/007:`0000JSP001Pa00026@00
4R/0065205>W003SK`00o`800?4k002Z_P0007TQ000X>`000a/000XT001DC00XV@00fHh00?d<003g
9000b[P000262000>D@000DM00068000ADX02Hd00=2W003j6000nQD00=:Q000?T00004U<00078000
11d003M300252P39^@00mb@00?`=0000l`3HT0008iL0001BC@002B<000<L000^?P00OaH0a<@00?D]
003n2000g8D0032L0000ET/000/U00036`00:C`007/M0;S2003c<P00oPH00=f0000fWP0005Q:000;
9@000a/002Pk001k7P2g`@00lc800?h6003MP@00=9d0001GBP002bD000<K000Z?000OAX0_l<00?@^
003m2000fhP002ZJ0000E4`000TS00047000<400084A0<Nm003g9@00o0d00=JE000JU00004i>0007
8@001Ad003Y500290@3>[@00nAX00?XF003@Z00018/0000nA`001Ah000LP001;C@0GT`00eYH00?`=
003f9P00akl000205000;Ch000<K000;9@00F4X0>il00>1i003o0`00l3d009Zj0000LRd001dd0002
6@004b`006Hm06f^003ZEP00o`000>MN001PZ`000691000@:P000QX0024g001g9@2^_`00lc<00?h7
003KR0009IP0001AC@00224000DM000lAP04R`00dJD00?/C003h7`00b[P000223`00;Sl000<K000;
9@00FDP0A:800>9`003o0@00]gl0001Z>0005Bh0008I000K<`00LBh0W;/00?4j003n1@00g8<002ZJ
0000DDd000PQ00057@00?TL02Hd00=>N003l3`00mRH00<G30000O1/002Hj00036P003bT0069106B/
003YF@00o`000>IS001EY`0005e5000=9`000a/002dn0022403:]P00nA`00?XH003=[`0008D9000`
@0000a/000`V001LA`1@YP00iFD00?l0003YF000Hj/0001Q@P003RP000<J000Z?000P1<0bKP00?TM
003j5`00cK0000242`00;cl000<K000=9`00GTD0FjT00>QM003o0000iV<0056V0000FdL000/U0003
6`00=48008P20=2V003k4@00mbD00<?40000NR00024g00026@0052d006Xh08Rf003_@@00oP@00=b4
000SU`0004e>00067`001b00051>02^J003NO@00o`800>i7001k/P0006Hm000A:`000QX002Lk0020
5@3:]`00nAX00?TK0039^@0007lG000V>P000QX0018/001X>P23]000kd800?h4003KQP007YH00018
C0001Ah000PQ001DC00kW`00hVl00?l0003YE`00GZX0001NA@0:ooooo`7o00000Oooool001kooooo
00?o0000ooooooooool01oooool0DP3n1@00mRP00<f`000?T000055=000;9P000QX001Ta001U?P1>
Y@00gWl00?d;003i7000dil002:G0000F4X000lY00026@0052h0061303bP003JR`00na400?XF003F
U@00;Y/0001KA`004B/0008I000B;000GDH0=Id00=R@003k4`00na@00=NB000aW00005a7000A:`00
0QT0018/001NA@0hWP00fHd00?/A003j5P00eYL002ZJ0000FDP000lY00026@005Bh0065204BR003L
P`00o@`00?TM003BX`006i@0001DC00032H0008J000J<P00J3/0FjT00>9b003n1P00mBT00<^e0004
R`0004Y=00088P000a/002<h001b;@20/`00j5X00?l0003`?@00]<00001o5@00=D<200057P3o000d
@P00OaH0//000?0n003o0000j5/007fc0000L2l0028g00036`002B<004m>00n@003?Z`00n2000?d;
003LP`00@J40001OA0004R`0008I000C;@00HD80B:<00=im003m2@00mbD00<bb0005S00004U<0008
8P000a/002Pk001g9@2G^@00kDX00?l0003[D@00RkH0001c:`0052X000TS001@CP0BT@00d:H00?TL
003l3`00fHd0032L0000FDT000hX00026@006S8006Xh06^^003VI000o`400?4l002``00007dJ000_
?`0011`000LP0014BP01RP00bk@00?LU003m2P00g8<003bP0000G4H000lZ00026@006C4006Ti06R]
003VI000o`400?0n002[_P0007/N000/?@0011`000PR001<C@0=S`00d:P00?TL003l4000ei<002FH
0000ED/000/U00036P008SP007<[08nh003]B`00o`000>UG001j/P0006dd000L=0000QX000hY001K
A`0lX000gH400?d8003e:@00b;d000252P00>4@000DN00067`00@4P008T00<bb003g8@00o0d00=V>
000ZV@0005E;000;9@000aX002@i001f9`2L^`00kd<00?l1003VI000Hj/0001V?@005Bh0008I000E
;P00ICh0HJ/00>EU003o0@00kd<009Zj0000MBP002<h00036P0032H005Q903FM003LQ000o@P00?D[
0036`@00084A000b@@0011`000PQ001>CP0ETP00e9d00?/C003i6`00cZ/000B;0000@DP000HO0005
7P00?TL008T00<f_003h7@00na400=FJ000GT`0004i>00088@0011d003A200233@38_000mRH00?d<
003HS`008iL0001BC@002B<000@L000_?`00P1@0aL800?DZ003m2P00fXX002VI0000E4`000TS0003
6`00;Sh007lE0<G3003e:P00o@X00=Z;000WV@0005=<00098`0011`0031000214@37_P00mRH00?d<
003GTP007YD0001@CP00224000@M000f@`00QPL0bk@00?PN003k4P00dil000j?0000ATX000HO0005
7`00@TT02Hd00=:S003k5000nA`00<ba0000Q`H003M300047@002280055=02>G003IS000o@T00?@]
002m``0007/M000W>`000aX000dW001LA`19Y000hfl00?l1003^AP00R[H0001^<`006C40008I002O
000F;`00JSP0OK<00>a=003o0000iFP005:V0000GTD000hX00036P009SX007/M0;o3003e:`00o@/0
0=NC000IT`0004]=000680001Ah004A:00n@003DV`00o0h00?HV0036`P0007hH000Y?0000aX000dW
001MA@1BY`00iFH00?l0002^P@0006Hm000B;0000QT001lf001f9`2]_`00lc800?d8003IS@007YD0
001=CP001R0000HO0016B`0ETP00ei@00?d;003e;@00]/40001h8`008CL0008I000B;000ISd0M;00
0>a?003o0000hf`004JS0000FDT000/U00036`00<d4008L60<j/003j5P00n1h00<Vi0000P1<002/m
00036P003RP0061305jZ003XF`00o`000>IR001DY`0005e6000<9P000a/0031000252P3=[`00nQL0
0?PN0039^P00080E000Y?0000aX000lY001R@@1Z[@00jU<00?l0003SK@00@j80001GBP002B<000@L
000kA@08S@00e9`00?`=003e;000//00001e:0007C@0008I000G<000KS80V;X00?8h003n1`00fHh0
01NC0000A4X000DN00088P00E4`0>9h00>5c003o0@00je0006^^0000HT4000hX00036P00;Ch008@;
0<j^003k5@00mb800<G30000NQl0024g00026@005Bh006`e09>i003a>@00oPL00=R@000BT@000418
00047@002B<005Q:04VT003UI@00o`000>MQ001?YP0005U800[ooooo0Ol00001ooooo`007_ooool0
0ol0003oooooooooo`07ooooo`3m0?l2003d<000bKX000>;0000CDh000XT00036P007C@006Ti05fZ
003QM@00oPP00?LS003?Z@005Y80001DC00032L0008I000G<000I3l0BZ@00=f1003m3000nA`00=>O
000QU`0005M:000>:0000QT001D^001Q@P13XP00g8D00?`>003i6P00e9d002BH0000F4X000hY0002
6@005Bl0069104FS003LP`00o0`00?TL003BX@007YD0001EB`003BL0008I000H<@00ICh0DZL00=mi
003m2000mb<00<j]000?T000051=000:90000aX001he001/=@1[[P00iFP00?l3003d<@00akl00027
1@00@TT000LQ00047000:C`007HV092h003[D@00o`000>i6002S_00007/N000_?`0011d000HO000k
AP00P`d0`l@00?8e003o0P00iFD006f^0000K3D001dd00026P002bD005=<01ZD003BX@00nAX00?`?
003IS@00<id0001KA`003bT0008I000G<000ICh0EZP00>5c003n1@00mB`00<Rk0000Q`@004580007
800011`002ho001k7@2X_P00kd800?l0003XF`00Nk80001_<@004BP000/U001DC00NU@00e9`00?XF
003k5000eYP002>G0000ED/000`V00036P007SD006hb07Zb003YFP00o`000>i4002P_00007PR000Y
?0000a/000PR001<C@0<SP00cjX00?PN003l3P00fHd002nK0000F4T000dW00026P007C@006dd07Ra
003YFP00o`000>i6002J^P0007HV000V>P000a/000TS001AC@0IT`00dih00?XF003j5@00e9d001VD
0000DDd000TS00036`009c/007PT0:2l003_@P00o`400>MQ001[[P0006Ti000H<@000QT0014[001O
A01:Y000h7L00?h5003d<@00`L@000205000<T4000@M00078@00B4`02Xh00<nY003i6`00na800=FH
000MU@00055=00098`000a/002Tl001j7`2]_`00lCX00?l2003SKP00E:L0001R@@004R`0008I000H
<@00JSP0LJl00>QK003o0000k4`008Zf0000L2l001he00026P003RT005a604:R003ON@00oPD00?<c
002i`P0007dJ000/?@000a/000TS001BC@0QUP00ei<00?`>003g8P00bkD000271@00>TD000DN0006
8000ATX02Xh00=6U00020?XG003c0=6T000;SP0004I;000680001Ah003]500280`3</P00n1l00?`@
003EV@005i<0001>CP001b4000@M000e@`00Q0/0bKT00?LS003l3P00ei@001fE0000D4h000PR0004
7000=48008@<0<Vi003g8`00o0h00=JE000KU00004m>00088@0011d003I30026203;]@00n1l00?/A
003DW0004Y400019C0001R0000DN000mA`02RP00cjX00?XH003j5`00cjT000>;0000?TL000DN0007
8000BT`059800=FI003l3`00mb<00<Rk0000PPl00310000370002R@005E;032L003MPP00oPH00?8e
002/_`0007LU000R>0000QX000lY001P@`1HZ000iVD00?l0003/C`00N[80001Y>@005Bl0008I000I
<P00KS80SKL00>m4003o0P00hW8004>R0000FTP000/V00036`00;3d0080D0<Nn003g9000o1000=BM
000=S`0004=900057P001R0004a=01^D003HT@00o@X00?@]002i`P0007TQ000S>0000QX000lZ001R
@P1QZ`00j5`00?l0002UQ0000691000?:P000QX002@i001j7`2n``00mBX00?d<003FU`004Y400014
BP001Ah000LP001>CP0QUP00fXX00?h7003c=@00YKd0001c:`007C@0008I000E;P00JSP0Pk@00>i6
003o0P00h7L003RO0000ED/000TS00047000>TD00h/00=:R003k4@00mb@00<G20000O1`002Dj0002
6P0042X006@o06j^003[DP00o`000>=/0015X`0005U9000:900011`003I30029003AY@00na400?LT
0035``0007/M000T>@000QX0018[001W?01i/P00kDX00?l2003PM`00=Id0001CC000228000DN0012
B@0CT@00ei800?d9003c=000XK`0001a;`006C40008I000J<P00Lb`0Z;h00?@`003m2`00eIP000^>
0000?DH000@M00098`00F4X0AZ<00>AY003o0000jEX005bZ0000GTD000`V00036`00<d8008T10=6T
003l3`00mRT00;O10000MRL001dd00026@006340074_0:Bm003c<@00o@/00=FJ0007S@0003U40004
70002bD005a705NX003XG000o`000>A[0011X@0005E;00[ooooo0Ol00001ooooo`007_ooool00ol0
003oooooooooo`07ooooo`1R0?l1003b>000aL<000261P00A4X000PR00036`008CL006hc06b^003T
JP00oPD00?DZ003;/`002hh0001@CP002RD0008J000K<`00J3X0FJT00>1f003n2000mb800<nY000E
TP0005=<000<9P000QX001Ta001V?@1AYP00gg/00?d:003h8000d:L001RC0000E4`000`V00026P00
6C4006Hm05BW003PN@00o@P00?LS003?Z`004Y40001AC@002bD0008J000L<`00JSP0HJ/00>=_003n
1@00mB/00<Zf0004R`0004Y=00098`000a/0028h001`;`1j/P00ieh00?l1003a>@00_/<000223`00
>TD000HO00047@00;Sl007XO0:2l003^B000o`000>a?002B^00007LU000Y?00011`000LQ0013B@00
R0<0b;`00?@^003n1000hfl005jZ0000J3/001Tb00026@003BP005M:02NI003FU`020?/D003o0=JG
000VV00005M:000=9`000QX001Xb001Y>@1U[000i6T00?l3003c=000a<@000233P00>DD000DO0005
7P00=480080D0;S2003a>@00o`800>IT001[[P0006/g000?9`003BL005Q:02^J003GTP00na400?TI
003BXP005i<0001AC@002R@000<K000S>000Lb/0R[H00>]@003o0000k4d008ng0000M2X002@i0003
6`002R@0055=01RC003CX000nQP00?/C003FU`008YL0001DC0002bD000<J000Q=`00LRd0R;H00>]A
003o0000je0008Zf0000LRd0024g00036P002bD005E;02FH003GU000o1400?TK003@Y`003Hl0001<
C@00228000@L000]?P00O1`0/L000?4j003o0P00i6/005^Y0000ICh001D^00026@0052d006A005RX
003SK@00o`800?4i002``00007`L000/?@000a`000PR001?CP0FTP00dih00?XE003j5`00dZ80016@
0000CDh000PR00047000;cl007lG0;k3003c<P00oPD00>1h0015X`0005i5000?:@000QT001`c001^
<`20]000je800?l0003ZE@00N[80001/=@006S80008I000A:`00H4<0DJH00>9_003o0P00lC/00:Rn
0000N28002Hj00036`002bD005I;02jK003KR000o@X00?HY0037_`00088?000c@@0011`000PQ001>
CP0FTP00e9/00?/B003i7@00cJh0002:0000?TL000DN00067`00@TT01h`00=2X003j6@00nQH00=6S
000<SP0004I:000680001Ah003a60029003=[`00nA`00?/C003CWP004I000019C0001b0000DN000k
A@00R080cK000?TM003k4`00dil000n@0000Ad/000HP00057P00?TL00XX00<n[003i6@00nQH00=2V
0007S000045800057P001Ql004E:00f?003CX000na<00?PN003</`0008H7000g@`0011d000PR001@
CP0QUP00fHl00?d;003e:P00a<@0001n6@00:Sd000<K000;9P00FDT0?Z000>1g003o0`00l3d009^j
0000LR`001de00026@004R`006@o06N]003XF`00o`000>UI001Z[P0006Dn000B;0000QT001dd001c
;02M^`00lC/00?h4003NO000=Ih0001FB`002R@000@L000b@@00Q0/0bk@00?TM003k5@00d:L0002?
00::0000>dD000@M00088P00DDd09iT00=^6003n1P00lSD00:Rn0000MBP001le00026@004R`006Hm
076_003[D`00o`0009b60000GTD000dW00036P00:C`007lF0<No003g8`00na400=:Q0006S00003e6
00047@002280059=02fK003MP000oP@00?0m002E^@0006la000I<@000QT001Pa001_<P2D^@00l3d0
0?h4003MP@00:iX0001AC@001b4000DN0011B00?T000eIP00?d<003e;000]l40001h900083H0008I
000C;@00J3X0OK<00>e9003o0P00h7H003RN0000ED`000PR00047@00?DL02Xh00=BK003l3@00mB/0
0;K10000MbD001lf00026@005Bh006/g08Vf003_@@00o`@00=f1000XV@0004m>000780001Ql004]=
01nF003KR000oPD00?4l002A^00006`e000E;`000QT001le001g9@2i`P00mRT00?`?003BXP0008X0
000f@`000a`000/U001LA`1DY`00iel00?l0003VI000CJD0001JB0002R@000@L000jA@08S@00eIX0
0?d;003d<@00Y[d0001a;P006C40008I000L=000MBP0]L400?DZ003l3`00dJ@000280`00<T4000<K
000=9`00H4<0Ijd00>]B003o0@00hGD003>M0000DTd02_ooool1o`00007ooooo000Nooooo`03o`00
0?oooooooooo00Oooooo04L0o`000?10002e`@00088@000mAP001b0000@L000V>P00LR`0O;800>MQ
003o0P00lc800<Rm0000R@0004U<00098`000aX001lf001/=@1X[@00hf`00?h5003e:P00bk<000Z>
0000Cdh000XT00036P007C@006Xh062[003RL@00oPH00?HW003</@0038h0001@CP002R@000<J000M
=000JSP0Hj/00>=^003n1@00mBX00<^e0006S00004e>00098`000aX0020f001^<`1a[`00iFD00?l2
003c<P00a/0000271P00@TT000LQ00047000:3/007DX08Zf003ZE@00o`000>m1002]_`0007hH000d
@P0200057P3=000e@P00OaH0/L000?0o003o0000jET008:d0000LRd002@i00036`002B8004]=00N<
003</P00mRH00?h8003ON@00CjH0001T@0005Rl0008I000@:P00FdL0=9d00=V<003l3`00nAX00=:Q
000JU00005=<000;9@000aX001he001^<`1e/000iel00?l1003a?000/l00001n5`00<T4000DM0006
7`00>dH008@;0<K2003d<@00oP@00>=^001LZ@0006Hl000=9@003bX005a703RN003KR000o@`00?PP
003>[0002hh0001<C@00228000<K000X>`00Mb@0VkX00>i7003o0000jEL007nc0000L30001lf0003
6P002bH005E;02BG003FUP00na800?XH003BX@005Y80001@CP002B<000<K000V>P00MRH0V;X00>i7
003o0000jET007Zb0000KS<001dd00026P003BP005U903:L003JR@00o@`00?LR003</@000XX00013
B@001b0000@M000c@@00P1<0`/@00?<a003n1@00hGD004fU0000H4<0018/00026@005c0006Pk06N]
003VH`00o`400>m2002P_00007LU000V>P000a/000XT001CC00RU`00ei@00?`@003h7@00cZ`000J<
0000A4X000HP00057@00=T<008<=0<No003e:P00o@P00=b3000hWP0005U8000=9`000QX0020f001b
;02A^000kDP00?l0003WG`00JZd0001X>`005Rl0008I000D;@00ICh0H:/00>EU003o0@00kd@009Rj
0000M2X0024g00036P003BL005Y803^O003NOP00oPH00?@`002n``0007hH000]?P000a/000TS001B
C@0RU`00f9400?`=003g8`00b[P000252@00=d<000@M00078@00Bdd04Y400=>N003k4`00nA`00<j]
0000RP0003i700057P001Ql004A:00V=003AY@00nQH00?XH003@Z0001H`00011B00200067`3J0012
B@08S@00dJH00?XF003j6000cjT000B;0000?dL000DN00067`00ADX03Hl00=:Q003k4`00nA`00<f`
0000R0<003U500057@001b4004i>01VD003FUP00o0h00?LT0038_000088@000`@00011`000TS001D
C00^V`00g8@00?h7003c<P00/l00001i8@009CT000<J000=:000GDH0C:D00>=]003o0@00kTH008^f
0000KS<001Tb00026@005Bh006Pj07Na003[D@00o`000>IR001KZ@000652000?:P000QX0028g001g
902^_`00lc<00?h7003KQ`00:9T0001BC@00228000@M000iA000R@40cj/00?XG003i6`00c;400026
1`00=48000@L00098`00ED/0=Id00=ml003o1000l3d009Nj0000L2l001/c00026@005Bl006Xh082d
003]B@00o`4009B90000FDP000/U00036`00;cl008<=0<^e003i7000nQH00<n[0000R0<003E30004
70002B@005I;03^O003QM@00o`800>i60024]@0006/g000E;P000QT001`d001c:`2T_@00lSD00?h7
003JR`007YH0001<C@001R0000HO0019C00JU000fHh00?h8003c=000Y[d0001c:`0073<0008I000F
;`00K3D0SKL00?10003o1000gH0002ZJ0000DDd000LQ00057P00ADX05Y800=RA003m2@00lc<00:Fm
0000LR`001/c00026@00634006la09Zj003b>000oPL00=Z;000KU00004Q<00057`001b00055=02bJ
003NO@00o`<00>i50021]00006Pj000B;0000QX002<h001k7@36`@00mb800?/D003>[00008D9000_
?`000a/000dW001P@`1S[000jUH00?l0003SKP00?j40001FB`00228000DM0012B@0DTP00f8l00?h7
003b>@00UKT0001]=0005Bl0008I000P=`00NR00aL@00?LR003k5000cJh000233@00;3d000<J000?
:@00I3l0M[400>e9003o0P00gWl002JH0000CDh:ooooo`7o00000Oooool001kooooo0ol00007oooo
o`2`0?l0003]B@00Y;d0001m6@00=D<000HO00047@00;3d007LU08bg003YE`00o`000?4j0031a000
08D:0011B0001b4000<K000T>@00LBh0N;400>IR003o0P00lc400<Rm0000R@0004Q;00088P000a/0
024g001^<P1`[`00iFL00?l3003d;`00bKX0006:0000BD`000TR00036`008CL006lb07:`003VI000
o`<00?<b0037_`0008P30014BP00224000<K000U>@00LR`0PK@00>QK003o0@00lC/00;_20000PQ00
03Y500067`0011d002dn001i8@2K^P00kD/00?l0003]BP00W;/0001i8000;Ch000@M00067`00?4H0
08<=0<;4003b=P00o`800>IS001b/00006hc000O=P000aX000XT001AC@0BT@00d:P00?PO003m2`00
g8<0046Q0000Gd@0018/00026@004b`005m404:R003MPP00o@/00?PQ003>Z`003Xl0001?CP002B<0
00<K000S>000LRd0QKD00>YF003o0000kTD00::l0000NR0002`n000470001b0004=900290@3:^000
mRT00?h7003PN@00CJD0001R@@002b<0018/001P@`16X`00gWd00?d8003f9`00bkH0002:0000A4X0
00LP00047000;Sl007`L0:bo003`?P00o`400>MQ001_[`0006/f000K<`000QX000hX001IB@0aW000
fX`00?`=003h7`00cZ`000Z>0000BT`000PQ00047000;3d007/N0:Vn003`?`00o`400>IS001Z[@00
06Ti000I<@000QT0010Z001MAP10X@00gWl00?h8003f:@00b;/000261`00?4H200057P0M000jA@00
Q@T0b;`00?DZ003n2000gGl003jP0000G4H000lY00026@006c<006`e07Na003YF@00o`000>e;002?
]`0007</000Q=`000aX000`V001GBP0_V`00fXX00?d;003g9000b[H000271000?DH00P001Ah0o`00
?DH008P30<^e003g8`00o@`00=V=000ZVP0005E;000;9@000aX002Dj001g9@2Q_000l3l00?l1003T
J@00FjT0001S@0004bd0008I000G<000JCT0Kjl00>QK003o0000k4d008Ne0000Kc4001dd00026@00
3bT005i504ZT003QM000o`<00?8h002]_`0007TQ000W>`000a/000/U001FB`0_V`00fhL00?d9003e
:`00a/8000214`00<40000@L00088P00DDd07YD00=ND003l3P00mb800<Zg0000Q@T003M300047@00
1b4004e>01FB003DV`00na400?PO003</P0008L4000iA@001Ad000LP001;C@0CT@00e9`00?/A003h
7`00bk<000271P00>4@000@M00078@00CTh06I<00=JF003l3P00mb<00<Vj0000P`d0039100047000
2B80059=02JH003JR`00o@T00?D/0032a00007dI000Z?0000a/000/U001HB@0kW`00ggX00?h4003a
>P00X[`0001e:@0083H0008J000@:P00HD80FjT00>IS003o0000jdl007Zb0000JSP001H_00026@00
634006dd08Ne003^B000o`400>=/001<Y@0005e6000=9`000aX002Lk001l702o``00mB/00?d;003H
T@0079@0001=CP001b0000DN0010B009S@00dZ000?/A003h8@00bKX000214@00;Sl000<K000;9@00
FDT0@Z800>9b003o0@00kTH008Ne0000K3D001L`00026@006C4006lb096h003`@000o`<008^<0000
ED/000TS00047000=T<008P30<n[003j5P00nA`00<^e0000P`d002lo00036`002bH005Y804VT003T
J`00o`000>a?001d/00006Hm000B;0000QT0024g001g902e`@00mBd00?d;003FU@004Y400014BP00
1Ah000LQ001@CP0WV@00g8@00?h5003a?000UKT0001_<P006340008I000J<P00LBl0W[/00?8g003n
1`00fX/001fE0000Bdd000HO00068000CTh08YL00=^6003n1@00lC`009Bi0000KS<001L`00026@00
73<007@Z0:^n003d<000o@X00=JF000?T000041800057@00228005E<03VO003QL`00o`400>a>001a
[`0006@o000@:P000aX002Tl0020503:^000nA/00?TJ003:]P00084B000Y?0000aX0010Z001T?`00
8P1c/000k4`00?l1003PN000<I`0001BC@001b4000DO001:C00PUP00g8D00?h4003_@@00QKD0001Y
>P004R`0008J000U>P00OQP0bKX00?TL003i6P00b[P0001o5P009SX0008J000B;000JCX0Q[D00?10
003n1@00fXT001ZD0000A4X8ooooo`?o00000Oooool001kooooo00?o0000ooooooooool01oooool0
?03o0000je<009Bi0000NB4002lo00057@001Ah00391001k7@2M^`00k4d00?l0003_@`00/<000020
4`00>DD000HO00047000:S`007DW08Rf003YF000o`400?4j0031a00008@;0010B0001b4000<L000V
>P00Lb`0P;<00>QM003o0@00lSL00<G40000Q@T0045800078@000a`002Hj001c:`22]000j5/00?l1
003a>P00_/<000233P00?4H000HP00047000:cd007LU096h003[D@00o`000>m3002Z_P0007hI000c
@P8000DN0?l003A2001n602/_`00kd800?l0003ZE000RkH0001e:0009c/000<L00078@00A4X008P3
0<Rl003d;P00oP@00>=]001RZ`0006Ti000K<`000QX000`V001EB`0NUP00dih00?XI003l4000fHh0
03>M0000FdL0010Z00026@005Rl006@o052V003PN000oPL00?HX003;]@000X/00017B`00224000<L
000X>`00MbD0UKT00>a<003o0000k4h0096h0000MBL002Lj00036`00228004]=00V=003=[P00mb80
0?d:003LP`00?j40001NA@002R8001D_001T?`1EY`00hG<00?h5003d;P00akl000252@00?4H000HO
00057@00=480080C0;g3003b=P00o`<00>A[001PZ`0006Ll000G<0000QT0010Z001MAP0oX@00gH40
0?d9003f9P00bkD000290000@TT000HP00047@00<T4007lF0;[2003b=P00o`<00>=]001JZ@0006Dn
000E;P000QT0018/001Q@P1>Y@00hGD00?h5003d<@00a<@000214@00=48000DM00068000@TT008X0
0<bc003g8`00o@`00=Z:000aW00005Q9000=9`000QX001lf001a;`27]@00jdl00?l0003ZE000Ok<0
001^<P007C@0008J000>:000FdL0?J000=f0003n1`00mB/00<K00000P`h003E300047@001b0004E:
00N<003?Z`00nA`00?/A003FU`007ID0001AC@002B<000<K000[?@00Nad0//000?8g003o0`00hG<0
04bU0000Gd@0010Z00026@006c<006dd07nc003[DP00o`000>YF001g/@0006/g000I<@000QT0018/
001R@@1HZ000i6X00?l1003_@@00W;/0001e:0008SP000<J000=9`00FTP0?J000=il003n1@00lc80
0;S20000O1`002Xm00036`002R@005E<02^J003JR@00o@X00?DZ0036`@00084C000`@00011`000TS
001AC@0QU`00f9000?d<003f9@00b;`000233P00<T4000@L00088P00DDd089H00=RA003m3000mRH0
0<Rm0000PQ000350000470002B<0059=02FH003IS000o@X00?DZ0035``0007lG000/?P000a/000XT
001FB`0cW@00gH400?h6003c=000/L00001i8P009CT000<J000=:000G4H0BJ@00>9`003o0P00kd<0
09:h0000L30001h001`c00026@004b`006Dn06Z^003YF@00o`000>UI001[[P0006Dn000C;0000QT0
01`d001a;P2G^P00l3l00?l3003PM`00?Z00001HB@002bD000<K000]?P00P1<0akh00?LT003l3`00
e9/000n@0000ADX200067`2E0018C00ETP00eYH00?`=003f:000aL@0001m6P00:3/000<J000=9`00
GDD0DJH00>EX003o0000je0007Na0000J3/001<]00026@007C@007<[0:6l003b>000oPH008>?0000
DDd000PQ00057@00?DH01h`00=:Q003k4@00mb<00<No0000OaL002Tl00036P003BP005m405RX003W
H@00o`000>UI001U[0000691000?:@000QX002Hj001l7035``00mRH00?`@003CX0001h`0000lAP00
11d000PR001DC00dW@00ggT00?l2003^A@00QKD0001Z>0005Bh0008I000N=@00MBP0[kl00?@_003m
2P00eYD0016A0000@TT000DN00088@00DTd0;i/00=ml003o0`00kT@008Bd0000JCT001@]00026@00
83H007PS0;c2003f:@00o0l00=>P0004R`0003U4000470002R@005U904RS003TJ@00o`000>UH001Q
Z`000613000=9`000a/002ho00252P3>[P00nQD00?PP0036`00007`K000T>@000QX0018/001X>P23
]000kd<00?l4003MPP0099P0001=CP001Ql000LP001@CP0]V`00gg/00?l2003]BP00MK00001T?`00
3bT000<J000[?@00P`h0cK000?XF003h8@00a/80001j7`008CL0008I000E;P00KC@0UkT00?8g003m
2000ei@000j?0000?4H02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo09/0
o`400>QM0023]00007@Y000Y?00011`000HO000iA000P1@0[[l00>m4003o0000k4`009nk0000O1`0
039100057P001Ad00310001j802I^P00k4l00?l0003_@P00[kl000205000>4@000HO00047@00;3d0
07LT092h003ZD`00o`000?0o002d`@00084B000iA@001Ql000@M000/?P00N2<0TkP00>]A003o0000
kd<00:fo0000OQL003E300057P001Ad00350001k7@2R_000kTP00?l0003/C@00VKX0001i8@00;Ch0
00@M00067`00>dD0088?0;g3003a>@00o`400>QN001k/P00070_000R>0000a/000TS001<C@07S@00
c;800?HW003n1`00h7L005>W0000ICh001L`00026@003RT005U902^J003GU000na<00?XE003EV000
9YP0001GBP003BL0008I000I<P00J3X0GjX00>=]003n1000m2l00<No0000QPL003m70006800011d0
02ho001k7@2V_@00kd<00?l0003YF000P;@0001a;`008SL000<J000:9000DDd05I800=6T003i6`00
o0l00=V=000aW00005Y800088@006C4006Pj06B/003TJ@00o`800?8f002m``00080C000e@P001Ah0
00HO000lAP00Q@T0akl00?@^003n1@00hGD0052V0000Hd4001@]00026@004bd0065204fU003PM`00
oPH00?@]0037_`0008@:000jA@0200057P0g000iA000Q0`0a/000?@^003n1P00h7L004^U0000HD<0
018/00026@005Rl006Hm05fZ003TJ`00o`800?4i002c`00007dJ000^?`0011`000PQ001:C00;SP00
cjT00?TL003l4000ei@002>G0000E4`000/U00036P0093T007DX09Rj003^AP00o`000>MN001_[`00
06Xh000I<@000QT0014[001P@`1;Y000hGD00?h4003c<`00_<80001n5`00;cl000@L00088P00CDh0
4Y400=:Q00020?XF003o0=:R000AT@0004a=00088@0011`0035000205034a000m2l00?h6003NOP00
?J00001KA`003RP0008J000O=P00LRd0T;P00>e8003o0000if0006N]0000Ic`001D^00026@005Bh0
06Ll06R]003WH000o`000>e:002;]P00070_000M=0000QT000lY001NA@1;Y000hW800?l3003a>`00
Ykd0001g90009CT000<J000<9P00FDT0>9l00=io003n1P00lc400;[20000O1/002Xl00036`002R@0
05E;02nK003KQP00o@P00?D]0032a00007hH000/?P000a/000XT001EB`0]V`00fhL00?d8003d;@00
`L@0001m6@00:cd000<K000:9@00ET/0<id00=f2003n1P00lc800;G10000NQl002Lj00036P0032H0
05Y8046Q003PM`00o`<00?4l002P_00007@Y000P=P000QX0010Z001Q@`1HZ000iFH00?l0003/C000
PK@0001/=P006300008I000F;`00JSP0N[800>]@003o0000iV<005^Y0000HD80010Z00026P008CL0
07HW0:Rn003b=P00oPD00=f1000`W00005A<00098`0011`003=100252P3;]000n1d00?/D003AY@00
18/0000mAP001Ad000LQ001@CP0QU`00fH`00?d9003d<000]<40001h8P008cP0008J000@:P00HT80
H:/00>QN003o0000jET006N]0000Hd00014[00026P008CL007LT0;?0003d<000o@T007^B0000C4d0
00HP00057`00ADX04Y400=JG003m3000mBX00;g30000NQl002@i00026P0042X006=006N]003YE`00
o`000>IS001EZ00005i5000=9`000a/002/m00214`39^P00n1l00?XE003?ZP0008P3000e@P0011`0
00XT001HB@12XP00hVl00?l1003/CP00MK00001V?@004B/0008J000S>000NR00`<<00?HW003l3`00
dil000J<0000>dD000@M00098`00ET/0?J000>9b003o0@00k4h007>`0000ICh0014[00026P009CX0
07dJ0<K0003g8@00na@00<nZ0000Q`H0039100036`0032H005e605JX003WG`00o`000>IR001BYP00
05]7000;9@000a`003E20029003AY000o1000?HX002l`P0007PT000O=P000QT001D_001]=02C^@00
lCX00?h6003IS@0069<0000M0014BP001Ah000PR001DC00kW`00hW000?l0003ZE000IJ`0001P@`00
3BL000<K000a@000Q`@0d:H00?`@003f:000^<80001f9`007C@0008I000I<@00LBh0Z;h00?@_003m
3000dih000:;0000=D<02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo01/0
o`@00>EW001c/000070`000T>@000a/000LQ0010B000Q0/0_l<00?4k003o0000jUD008jg0000Mb@0
02`n00047@001Ql003I3001n5`2Z_P00kTD00?l0003]B`00W[/0001k7@00<D400P001Ah02@00<T40
07`L0:6l003]BP00o`000>e8002S_00007`K000b@@0200057P0o000b@@00O1/0Y;d00>i7003o0000
k4`009bk0000NR0002lo00047@001Ql003M40020502c`000l3l00?l0003ZEP00RKH0001d:@009c/0
00<L00078@00@TT008L50<No003d<@00o`<00>EX001[[P0006`e000N=@000aX000/U001AC@0CT@00
d:P00?PP003m2`00gH4004BR0000HD8001@]00026@004B/005e603VO003JR@00o0h00?TK003BXP00
6I@0001CC0002bD000<J000N=@00K3D0Kjl00>IS003o0P00lSP00;g30000PA4003M4008000DN04`0
03E20020502g`@00lCX00?l1003VHP00L:l0001/=@007C@0008J000<9P00ED/08IL00=FJ003j5@00
na@00=FH000TU`0005I;000780007C@006dd07B`003WG`00o`400?0o002[_P0007`L000^?`0011`0
00LP0013B@00RP00bkD00?HV003m2@00gGl004:R0000GTD0014[00026@005Rl006Hm05bZ003SK@00
o`<00?8e002m``00080D000c@@0011d000HP0010B000R080b[L00?HV003m2@00gH8003fP0000G4H0
00lY00026@006C8006Xh06f^003WH000o`400>m2002R_00007PS000X>`000a/000TS001@CP0GT`00
dih00P3j5P00o`3CWP005i<0001@CP002B<000<K000Y?000NR00ZKh00?0m003o0P00iFP005nZ0000
ICh001D^00026@0052d006@o05ZY003TJ`00o`800?4l002Z_P0007XP000Y?0000a/000TS001BC@0N
UP00eYL00?/A003i7@00cZ`000J<0000A4X000HP00057@00=d@008D:0<Rk003f9`00o@X00=^8000`
W00005M:000;9P000aX002@i001f9P2P_000l3l00?l2003TJP00F:P0001R@@004R`0008I000I<@00
JcL0N;400>YF003o0000jU@007^b0000K3H001Tb00026@004R`006=105ZY003UJ000o`400>m4002F
^@0007<[000P=P000QX000hX001MAP17X`00hGD00?l3003a>P00Z;h0001h900093T000<J000<9`00
FTP0?:000=ml003n1@00lSD00;700000NB0002Hj00036P0032H005U903ZO003NO000oPD00?8e002_
_`0007TQ000U>P000aX000`W001JB010X@00h7L00?l3003a>P00Y;d0001f9`008CL0008J000>:@00
GTD0CjH00>=/003o0@00kTD008ng0000L30001/c00026@004b`006Dn06R]003XG000o`000>YF001a
[`0006Lk000D;P000QT001Xb001^<P2;]P00kTH00?l1003SK@00C:D0001MAP003BP000<J000V>P00
NQl0^L800?@^003m2@00fX/002>G0000D4h000PQ00047@00>TD008T00<nZ003j5`00nAX00<f`0000
Q`H003I3000470002B<005=<02jK003MP@00oPD00?8h002S_00007@Z000N=@000QT0018/001V?@1`
[`00jU@00?l0003VH`00EjP0001OA0003RP000<J000W>P00O1`0a<@00?HX003l3@00LiD00014BP00
1Ah000LP001>CP0NUP00fH`00?d8003c<P00[;l0001e9`007cH0008I000C;000Ic`0Mk400>a>003o
0000hfd004JS0000FDP000/U00036`00<D0008D90<f`003j6000nA/00<^d0000P`d002ho00036`00
32H005a6056V003UI@00o`000>UH001U[0000692000?:@000aX002Pk001n5`37_@00n2000?/D003?
ZP0008L4000d@P000a/000/U001JB01<Y@00iFL00?l0003YE`00I:`0001Q@P003RP000<J000[?@00
PA40b[H00?TK0000?03i6P00bk@000224000:cd000<J000>:000HD80IZ`00>YE003o0000hf`004>R
0000EdX000TS00047@00?4H02Xh00=FI003m2`00m2l00:^n0000Lb/001/c00026@006C40074^0:Bm
003c<P00o@X00=JG000<SP0003e600047@002B@005Q904VT003UIP00o`000>QN001EZ00005a7000;
9@0011`003Q400F<003DW000o@`00?@`002W_@00074^000I<@000QT001dd001f9P2i`P00mRL00?/A
003@Z00008H7000_?`[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o0?h7
003RL@00Hj`0001[=P007cD000<J00098`00BD`008T00<Nn003c<`00o`800>MO001n/`0007</000V
>P0011`000LP000nA`00P`h0^l800?4l003o0000jUD008fg0000MbD002/m000470001Ql003U40020
4`2b`000kd400?l0003[DP00T[P0001h9000;3h000@M00067`00>DD0084B0;G1003`?P00o`000>YE
002;]P0007DW000Y?00011`000LP000oA`00Q@X0a<@00?8f003o0P00if0007Ra0000L300028h0003
6`002B<004]=00F<003;]@00mBT00?h6003RLP00FjT0001X>`006C80008J000=9`00ED/07iH00=>N
003i6@00o0l00=V<000fWP0005a6000A:`000QT001@^001Q@P17X`00gWl00?d:003g8P00cZd000f?
0000Cdh000TS00036`008SP0074^07nc003YF@00o`000?10002/_`0007dJ000a@00011d000HO000l
AP00Q0/0aL800?<b003o0`00hf`0062[0000J3/001Ta00026@003RP005U902nK003HS`00o1000?TJ
003BXP005i<0001AC@001al0028g001a;P24]@00jUD00?l0003^B000V[X0001g9000:3/000<K0008
8P00C4d02hh00<j[003h7`00o0d00=Z:000dW@0005Y8000>:0000QT001Xb001Z>01/[P00iV800?l1
003`?P00Zkh0001k7@00;Ch000@L00078@00BD`028d00<j]003h7`00o0d00=V<000_V`0005Q9000=
9`000QX001he001^<P1m/`00jUL00?l0003]B`00TKP0001d:P008cP000<J000;9@00E4`099L00=ND
003l4000nA`00<nY000;SP0004U<00078@0011`002lo001n5`2j`P00lcD00?l4003QLP00D:H0001Q
@P004R`0008I000G<000J3X0JZd00>MQ003o0000kTD009Vj0000MBP002@i00036P002bD005I;02^J
003IS000o@`00?LS003:]P0008L4000lAP001Ah000HO000oA`00R@00c;400?PP003l3P00ei<002:G
0000Dd`000XT00036`00:S`007/N0;;0003b=`00o`@00>5e0019Y00005i5000?:@000QT001dd001`
<028]P00k4`00?l0003XG@00Jjh0001W>`005Rl0008I000E;P00Ic`0JZd00>MN003o0000k4d0002S
08Fe0000KS8001/c00026@004B/0065205JX003TJP00o`400>m2002G^P0007<[000P=P000QX000lY
001NA@1;Y000hW400?l2003`?P00X;`0001e:0008CL0008J000>:000GDH0BJ@00>9b003o0P00l3h0
09jk0000M2T0020f00026P003bT005i404nV003SK@00o`400>m3002C^000074^000M=0000QT0014[
001S@@1NZP00iV800?l0003/CP00O[<0001[=P005c00008I000F;`00JCT0N;400>]B003o0000iel0
066[0000Hd00014[00026@007SD007</09^k003`?@00o`<00>1g000nX00005U9000;9@000a/002/m
001o5P36`@00mRL00?`=003FUP005Y80001:C0001R0000DN0012B@0;SP00dj000?/A003h8@00bKX0
00224000;cl000<K000:9@00F4X0?:000>1g003o0`00kd4009:h0000Kc4001Xb00026@005Rl006Xh
082c003]BP00o`400>=]0018Y00005]7000<9P000a/002`n00214`38^`00n2400?/B001[V00003a6
00047@002280059=02bJ003MPP00oPD00?4k002K^P00074^000K<`000QT001H_001/=P28]P00kT@0
0?l2003PM`00>9h0001EB`002B<000@L000hA000RP00dJH00?/C003g8@00akh0001o5`00:3`000<J
000>:000H4<0H:/00>QK003o0000iV8005FX0000GDD000`W00036`00;Sl008<>0<^c00020?TJ001>
0<^d0000P`h002dn00036`003BL005i505^Y003XG@00o`000>MQ001DY`0005a6000<9P000a/00350
00261`3>[000nQD00?PP0037_P0007dI000V>P000QX0014[001U?P1f/@00kD`00?l1003PMP00=Id0
001CC000224000DN0014BP0FTP00f8l00?h7003b=`00V[X0001_<P005c00008I000M=000MRL0]/40
0?DZ003l3`00dZ40006:0000=D<000<K000;9P00GDH0F:P00>QL003o0000iFP004NS0000F4X000TS
00047@00?dP04I000=RB003n2000lSP009Ji0000KC@001D^00026@008CL007XN0<K1003h8000nQL0
0<bb0000PA4002Tl2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l0o@X0
0=mk001DY`0006Ll000J<P000QX000/U001@CP0:SP00bk@00?D[003n1000i6T006f^0000KS<0024g
00036`00228004I;00280`36`000lc@00?l2003WG`00OK<0001b;@009SX000<K00078@00@DP008D9
0<C4003b>000o`400>QL0021]00007<[000V>P000a`000LQ0011B000QPP0aL<00?8f003o0P00iel0
07Zb0000LBl002<h00036`00228004M;00290038^`00m2h00?l4003TJP00J:d0001[=P007CD000<J
000:9@00DDd04I000<n[003g8P00o@T00=im001<Y@0006=0000F;`000QT000lY001JB00]V`00ei<0
0?/C003j5@00eYH002VI0000F4T000hX00026@00630006Hm05JX003QM000oPH00?DY003:]`000XX0
0017B`00224000<K000W>`00MBL0T;P00>]@003o0000kDX009Zj0000N2<002/m000470001b4004A:
00290039^000mBX00?h6003PMP00DJH0001T@0005Bh0008I000A:`00GDD0?:000=b5003m2`00n240
0<j/000;SP0004e>00067`009c/007HV09Fi003]B`00o`000>]A0029]P0007</000S>0000a/000XT
001AC@0GT`00dZ400?XI003k4P00ei@002JH0000ET/000`V00026P007SD006lb07bb003YF000o`00
0>i7002J^P0007LU000W>`000a/000TS001@CP0DTP00dZ800?XI003k4P00eYL002:G0000E4`000/U
00036P008SP007<[08jg003/C@00o`000>YD0020]00006la000N=@000QX000dW001HB@0aW000fXX0
0?d<003g8`00c;<000290000@DP000HO00057@00=T<008<>0<K0003e;000oPL00=im0011X@0005e6
000?:@000QT001/c001]=@1j/P00jEL00?l0003/CP00R;H0001a;`007cD0008J000=:000FTP0>Il0
0=f2003n2000mB/00<K00000P`h003E200047@001b0004M;00Z>003@Y`00nAT00?/D003DW@005Y80
001?CP00228000@L000`@000P1D0`l@00?@^003n1`00gWl003ZO0000FTP000dW00036P008CL007@Z
09Vj003_@`00o`400>EX001KZ@0006=0000B;0000QT001Ta001[=P1j/P00jU@00?l0003ZE`000?<0
MK40001Z>0005c00008I000D;@00ICh0IJ`00>MP003o0000k4`008Je0000KS8001/c00026@004B/0
069105ZY003UI`00o`400>i7002?]`00070_000M=0000QT0014[001Q@P1HZ000iFP00?l1003^A`00
SKL0001`<00073<0008I000A:`00Hd00GZX00>IS003o0000k4d008:d0000K3D001Ta00026@0052h0
06Ll06j_003YF000o`000>UH001^[`0006Ll000D;@000QT001Tb001^<`28]P00kDP00?l1003TJP00
DZH0001OA0003RT0008J000S>000Mb@0[Kl00?<e003n1P00gH80032L0000E4`000TS00047000<T40
08@<0<Zg003h8000na800=:P000:SP00049900057P001R0004Y<01NC003FU@00o0`00?HX0035``00
07dI000Y?0000aX000`W001LA`1;Y000hfd00?l1003]BP00PK@0001[=`005Rl0008I000I<P00Kc80
TKP00>m1003o0`00h7P003ZO0000EdX000XT00047000<d4008D90<ba003i6P00nQP006NJ0`00=D80
00@L00099000ET/0>Il00>1g003o0P00kd<008Zf0000K3D001L`00026@006S80070`09Rj003a>`00
oPD00=f2000ZVP00055=00088@001Ah0041800b>003DV`00o0h00?HY002o``0007XO000S>0000QX0
014[001U?P1`[`00je400?l0003SK000Aj<0001IB@002RD000@L000d@P00R0<0cjT00?/D003h8000
akd0001n60009c/000<J000?:@00Hd00JZh00>YC003o0000i6/004FS0000F4T000XT00047000>4@0
0X/00=:R003l4000mRL00;o30000NB80024g00026@0052d006Xh08Je003_@P00o`<00=f1000XV@00
04m>000680001Ql004e>02>G003LQ000oP@00?100029]P0006Xh000D;@000QT0028g001j7`35``00
mb<00?/D003>[00008D9000_?`000a/000hX001Q@P1X[@00je800?l1003RLP00>9h0001CC0002240
00DN0018B`0MU@00fhL00?h5003_@@00QKD0001X>P004R`0008J000V>P00OaH0b[L00?TJ003i7@00
b;`0001m6P008cP02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l0o0l0
0=^60015XP0006=1000G<0000QT000dW001DC00FTP00cjX00?LS003n1`00hG@005jZ0000JST001dd
00036P002R@004i>00N<003:]P00mB`00?h4003TJ@00KJh0001^<`0083L000<K00098`00BD`008X0
0<Rk003d;`00o`<00>EV001a[`0006hb000Q=`000a/000TS0019C002RP00bKT00?@^003o1000i6X0
06Z]0000K3D001le00036P002R@004m>00^>003</@00mRH00?h7003QM@00F:P0001W?0006C80008J
000<9`00ED/07ID00=:Q003i6`00o0h00=^7000mX00005m4000B;0000QT0018/001NA@0jW`00fXT0
0?`>003i6`00dZ4001bE0000E4`000`V00026P0073<006Xh06J/003TJP00o`<00?<a0036`00008H8
000oA`001R0000@L000]?P00NQl0XK`00>i6003o0000jU<008Vf0000M2X002Di00036`002B<004e>
00Z>003=[P00mb800?d:003MP@00@Z80001OA0004R`0008I000D;@00HT40Bj@00=mj003n1`00mRP0
0<Zg0000R@0004A:00067`00;Ch007/N0:Jm003_@P00o`000>QK001i/P0006hb000N=@000QX000`V
001EB`0TV000eYH00?/C003j5`00dil001VD0000DTd000XT00036`008cP007<[08fg003/C`00o`00
0>]@0029]P00078]000R=`000aX000/U001DC00PUP00eIP00?/C003j6000dZ4001FB0000D4h000TS
00036`009c/007LT09nk003_A000o`000>MN001`[`0006/g000J<P000QT000lY001MAP0oX@00gWl0
0?h8003e:P00b;d000252P00>DD000DN00067`00?TL008P40<Zg003g9@00o@/00=^7000cW@0005U9
000=9`000QX0020f001a;P2:]P00k4d00?l0003YF000N;40001/=@006S80008I000@:P00GTD0B:<0
0>1g003n1@00lc<00;c20000OQP002ho00047000228004m>01JC003DW@00na@00?TJ003@Y`002Xh0
0016B`001b0000DM000g@`00Q0/0b;/00?HW003m2P00fXX002fK0000ET/000/U00036`009cX007TR
0:Zn003a>P00o`<00>9b001<Y@0005m4000@:P000QT001dd001`<02:]P00kDX00?l0003WH@000>00
IJ`0001U?@0052d0008I000G<000JSP0MK400>YF003o0000jUD007Ja0000JSP001L`00026@0052h0
06Hl06Z]003XG@00o`000>]@001n/`0006`f000I<@000QT001@]001V?@1W[@00j5h00?l0003[D000
O;<0001[=P006340008I000E;P00Ic/0KZl00>UI003o0000jUH007:`0000J3X001D^00026@006300
06/f07jc003/CP00o`000>IR001NZP000691000A:`000QT001he001b;02I^P00l3l00?l2003QM000
@j80001JB00032H000<J000X>`00O1`0_/<00?D]003m2@00fHd002:G0000D4d000PR00047@00>D@0
08P20<j]003i6@00nQP00<n[0000R@0003Y500047@002240051=02>G003JR`00o@P00?@`002e`@00
07TR000T>@000QX000lY001P@`1JZ@00iV800?l0003ZE000LJl0001V?@004b`0008I000M=@00Lb/0
X[`00?8h003n1@00gH8002bJ0000DTd000PR00047@00>TD00HX00=2W003k5000n1h006FM2000;Sl0
00<K000;9P00FTP0B:<00>=]003o0@00k4d007Vb0000J3/001<]00026@007SD007DY0:Zn003c<`00
oPP00=V<000MU@0004a=000680001Ql004Q<01RC003HT@00o@T00?@`002^_`0007DW000N=@000QT0
01@]001Y>@20]000kTL00?l2003PMP00>9h0001EB`002B<000@M000kAP07S000dil00?`?003f:000
_l<0001i80008SP0008I000B;000Ic`0N[800>e:003o0@00h7H003NN0000E4`000PR00057@00?dP0
3Xl00=JG003m2`00m2l00:fo0000M2T001`d00026@005c0006hb09Ni003a>@00oPH00=Z;000KU000
04M;00057P001b40059=032L003ONP00o`800>e9001h/@0006Hm000A:`000QX002Lk001o5P39^@00
nA`00?TJ003:]P00080C000Y?0000aX0010Z001U?P1h/@00kDT00?l2003NO@00:iX0001?CP8000HP
014004m>02ZJ003NO000o`800>e:001e/00006@o000?:@000aX002`n0024303>[@00na@00?LT0032
a00007PS000O=@0:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0G03k5000
f90003JN0000GTD001<]00026@003bT005Q902>G003CW`00nA`00?d;003NOP00CZD0001U?P006C40
008J000<9P00DTd04i400<j/003g9000oPL00>5d001MZP0006Ti000L<`000aX000XU001@CP0<SP00
c;400?HX003n1P00hW00066[0000JSP001dd00036P002R@0051>00f?003=[`00mRH00?h7003QM000
FZT0001X>`006S80008J000<9P00Dd`05i<00=2V003h7`00o@/00=io0019Y00006=1000F;`000QT0
00lY001IB@0ZVP00eYH00?XE003k4`00f98002nK0000FdP0010Z00026@005Bh0069104VT003NOP00
o@X00?LQ003>Z`003i00001@CP002R@000<J000P=P00Kc80M[400>MP003o0@00lCX00;[20000PA80
03M40P001Ah0Q@00=48007lF0;?0003`?@00o`400>QM001i/P0006la000P=P000aX000XT001BC@0F
TP00dJ@00?TL003l3P00fX`003BM0000FdL000lY00026@005c0006Hm05ZY003RL000oP@00?@`0036
`00008D:000lAP001Qh003=1001o5@2g`@00lCT00?l2003UIP00J:d0001Z>0006S80008I000>:000
FDP0<I`00=V<003l3P00n1h00<nY000=S`0004e>00088P000a/002Tl001h8`2N^`00kTD00?l0003X
FP00N;40001^<`007C@0008J000=9`00F4X0;Y/00=V=003l3P00n1h00<j[0009S@0004U<00078@00
11`002dn001l6`2``000lC/00?l2003TJ@00H:/0001V?@005Rl0008I000B;000HD80CZD00>5d003n
1000lc800<740000P1@0039100047@001b0004I:00J<003>[000n1h00?`?003GTP009IP0001DC000
2bD000<J000U>@00MRL0Vk/00>m4003o0000iV8006R]0000J3/001L`00026@004b`006=005NX003S
K@00o`800?4k002Z_P0007TQ000X>`000a/000XT001CC00SU`00ei800?`>003h8000c;8000290@00
?TL00P001Al0o`00?TL008T10<ba003h8000o0l00=ND000OUP00059=00098`000a/002`n001m6@2l
`P00lc400?h6003NO@00?J00001JB0003BL000<J000R=`00M2T0Vk/00>m1003o0@00i6/005FX0000
HD80014[00026@006c<006hb08Je003/C000o`000>MO001V[00006Dm000D;@000QT001Pa001[=`1j
/P00je<00?l0003YFP00KZh0001W>`005Bh0008I000G<000JSP0Mk400>YD003o0000j5X006b^0000
Ic`001@^00026@00634006`f07nc003/C`00o`000>MP001RZ`0006@o000B;0000QT001`c001`<02?
^000kTD00?l1003SK000CjH0001NA@003RP0008J000R>000MbD0Z[h00?8f003n1@00gWl003FM0000
ET/000XT00036`00;Sl0084C0<Nn003g9@00o0h00=JG000FTP0004Y<000680001Ah0041800R=003B
X`00na<00?PN003;]@0008@;000c@@0011`000TS001DC00aW000gH000?h5003b>000Y;d0001d:@00
7cD0008I000B:`00I3l0JZd00>UH003o0000j5h0066[0000HT40010Z00026P008SP007PS0;?0003d
<000o@T00=V=000OUP0004i>000780001Ah0049900b?003DW000o0l00?HU001SX0d002Pk00036P00
3RP005i405NX003VH`00o`000>YG001Y[@0006=0000@:P000QX002<h001i8@2k`P00mB/00?d<003F
U`004I000013B@001Ah000LP001?CP0UV000fhH00?h6003a>@00W;/0001a;`006S80008I000G<000
KS<0TKP00?0n003n1000gH4002ZJ0000DDd000LQ00057P00@dT04Y400=ND003m2P00m3000:jo0000
MBP001dd00026@005Bl006`f08^f003`@000o`@00=f0000YV@00051>000780001Al004Q;01ZD003I
S@00oPL00?8g002L^`00070`000H<@000QT001/c001c;02X_P00m3400?d:003FUP003Xl0000oA`00
11d000TS001FB`0nX000hVl00?l0003ZD`00J:d0001Q@P003RP000<J000]?P00Q0`0cJl00?XF003h
8000a/00001l70008cP0008I000C;@00JSP0R;H00?10003n1@00fhL001fE0000B4/000DN00078@00
Dd`0>9h00>9b00003P3o0000jU@006F/0000H4<000dW00036`00<T4008P20=:S003l3`00mB/00;30
0000Lb/001Xb2_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0?l0nAX00=BK
000XV@0005Y8000@:P000QT0018/001LAP0`W000eYD00?XF003l4000fXT003nQ0000HD8001D^0002
6@003RP005M:01nF003BX@00n1d00?d;003NOP00CJD0001U?P006340008I000<9`00E4`069<00=2W
003h8000o@T00=mk001AYP0006Dm000H<@000QT000`W001DC00IU000dJD00?PO003m2`00gWl004^T
0000Hd0001H_00026@003RP005M:02BG003DW000nQT00?`?003JRP00>il0001NA@004R`0008I000B
:`00GDD0>9h00=Z;003l4000nQT00=BL000RU`0005I;000=9`000QT001Ta001W?01HZ000hG@00?h6
003f:@00bkD000B;0000BD`000PR00036`009CT007<[08Ne003ZEP00o`000>m3002X_P0007`K000`
@00011d000HO000kA@00P`d0a<@00?<d003o0P00iFL006R]0000JSL001/c00026P0032L005I;02>G
003EV@00nQD00?/D003FUP009YP0001GBP003BL0008J000K<`00JcL0JZh00>EU003o0P00lSP00;[2
0000P1@003E200067`00>TD008@<0<K2003d<@00oP@00>9`001IZ@0006Dn000F;`000QT0014[001N
A@10X@00gH400?d9003g9@00bk@000::0000A4X000LP00047000;cl007`K0:no003a?000o`400>IT
001X[@0006Ti000I<@000QT000lY001LAP0lX000g8<00?d9003f9@00b[H000290@00@DP000HP0004
7@00=480084B0<;4003c<P00oP@00>5c001@YP000691000C;0000QT001D_001U?P1MZP00i6X00?l2
003a>P00[kl0001k7@00;3d000@L00088P00CTh04Y400=:R003j5`00na@00=BM000HT`00051>0009
8`000a/002Xl001j7`2]_`00lC/00?l2003SK000F:P0001S@0004bd0008I000F;`00Ic`0IZ`00>IR
003o0000kT@009Vj0000MBT002<h00036P0032H005M:036L003KR000o@X00?HW0038_00008@;000g
@`001Ad000LP0016B`0:SP00d:L00?TI003k5000dil001>A0000CDh000LQ00047000<d40088@0<No
003e:@00o@T00=^7000_V`0005I;000;9@000a/002Lk001i8@2]_`00lSP00?l4003QM@0006l0AZ<0
001MAP003RP0008J000P=P00Lb/0UkT00>m3003o0@00i6X005JX0000HD80014[00026@0073@006la
08^f003]B@00o`000>IT001NZP0006=0000B;0000QT001/c001_<P28]P00kDX00?l0003VI000G:X0
001R@@004B/0008I000L=000L2l0SkP00>i5003o0@00i6/005:W0000Gd@000lY00026P0083H007DY
0:2l003a?000o`<00>1g0010X@0005Y8000<9P000aX002Pk001k7@2l`P00m2h00?d8003JR@009iT0
001BC@00228000@L000d@P00Q@T0bk@00?PN003k4`00dZ8000V>0000@DT000DN00068000BD`05980
0=FH003l3P00mbD00<No0000P1@002`n00036`002bD005U903nQ003QM@00o`800>m1002B^000070`
000J<P000QT001D^001Y>@1j/P00k4h00?l0003UJ000DJH0001NA@003BP000<J000X>`00OA/0aL@0
0?HX003l3@00eYP001:A0000AT/00P001Ql0;@00BT`06I<00=NB003m2P00mBd005bN4@008cP0008J
000@:P00Hd00Ijd00>UH003o0000if4005VY0000Gd@000hX00036P00:3/007hH0<K0003g8`00na40
0=:R0005S00003]600047@00228005A<03:L003ON`00o`<00>m2002;]P0006`e000F;`000QT001/c
001b;02S_000lSD00?h7003JS0007ID0001;C@0200067`1C001<C@0OUP00fXX00?h6003b>000W;/0
001`;`006C80008I000I<@00L300W;/00?8h003n1`00fX/001bE0000BD`000HO00078000Cdh09iT0
0=f2003n1000l40008Zf0000JcL001D^00026@007cH007LT0;[2003f:@00o0l00=:Q0003R`0003M4
000470002RD005Y804fU003UI@00o`000>QM001HZ00005e6000<9P000a/003A200280P3AY@00o100
0?HW002k`P0007LT000N=@000QT001H_001^<P2J^P00lSL00?h8003GTP004I00000oB00011d000TS
001GBP17X`00iFL00?l0003XGP00EJL0001KA`002bD000@L000jA@09S@00eIP00?d:003c<`00W[/0
001_<@005Rl02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo0:D0n2400=6V
000KU00005I;000>:0000QT001D^001Q@`0nX000fXX00?/A003j5P00ei@0036L0000G4H0018/0002
6@004B/005]702fK003FU`00nQL00?`@003JR@00?j00001P@`0052h0008I000?:@00F4T09IP00=BL
003i6P00o0h00=b60012XP000652000E;P000QT000lY001HB@0VV000eIX00?XH003l3`00fXT003bP
0000Gd@001<]00026@004B/005]7036L003HT@00na<00?/E003GU@00;I/0001JB0003bX0008I000E
;P00HT40Aj<00=f1003m2`00n1l00=2W000ETP00059=000;9@000QX001dd001[=`1X[@00i6T00?l3
003d<@00akl000261P00@DP000LP00047000:cd007PS09Rj003/C000o`000>a<002G^@0007PT000Z
?00011`000LQ0013B@00R080b;/00?D/003n1@00hW8005VX0000ISd001L`00026@003bT005Y8032L
003IS`00o1000?TJ003BX@006I@0001CC@002bD000<J000P=P00Kc40Nk800>QK003o0000kd400:Rn
0000Nad002ho00067P00@TT008T10<Zh003f:@00oPL00=mk0019Y0000652000C;0000QT001@]001R
@@1?Y@00h7H00?h6003e;000akh000262000?4H000HO00057P00=D<0084A0<74003c<`00o`<00>9_
001HZ00006Dn000E;P000QT0018/001P@`1;Y000h7P00?h6003d;@00a/0000243000>D@00P001Ah0
o`00>dH008H80<Rl003e:P00oPL00=in0011X@0005e5000@:P000QT001Ta001Z>01][P00if000?l0
003_A000WK/0001g9@009SX000<K000:9000DTd07iH00=JG003k4P00nAX00=2W000<S`0004Y<0007
8@0011`00310001o5P2n``00lc800?h5003PM`00BJ@0001OA00042X0008I000J<P00K3H0Mk400>UH
003o0000k4h008Re0000L30001he00026P003RP005]703nQ003NO@00oPH00?@_0032a00007lE000`
@00011`000PR001?CP0FTP00e9`00?/C003i6P00cjT000N<0000A4X000HO00057P00>TD008L60<^e
003g8P00o0h00=NB000RU`00059=00098`000a/002dn001n602o``00m3000?h7003MP000>9h0001H
B@0032H000<J000U>@00N2@0Z;h00?4j003o0`00hG@004NS0000GDH000hX00026P008CL007@Z09bk
003`@000o`800>=_001>Y@0005m4000?:@000QX001lf001c:`2I^P00l4000?l2003RK`00CJD0001N
A@003RT0008J000Q=`00MBP0XK`00?4l003o0`00hGD004>R0000FdL000dW00036P009CX007TQ0;;0
003c<`00oPH00=f2000bW00005I;000:90000a/002ho00204`37_`00mRH00?`=003GU0006Y@0001>
CP001b4000DM000lAP01RP00cjX00?XG003j6@00cZ`000290@00>TD000@M00088@00D4h08IH00=V=
003m2P00mBd00;g30000Nad002Hj00036P003BL005e604jU003TJ`00o`400>e:0021]00006/g000F
;`000QT001Pa001]<`2;]P00kTD00?l2003QLP00@Z80001IB@002bD000<K000]?P00PA40bKX00?PQ
003k4P00dZ8000J<0000?TL000DM00078@00D4d09YP00=^7003n1`00lSD005BI5@007SD0008I000C
;@00Ic/0Mk400>a>003o0000i6/004ZT0000FdL000`V00036`00;Sl008<>0<Zf003i7000nQH00<j/
0000Q`D003A2000470002R@005Q:046Q003RL@00o`400>e;001j/P0006Pk000C;@000QT0020f001g
9@2d`@00m2d00?d;003FUP004I000012B@001Ah000LQ001AC@0/VP00gWl00?l3003_@@00RkH0001/
=P00C0005Bl0008I000M=000MBP0[[l00?@_003m2`00eYH0012@0000@DP000DM00088P00Dd`0=Id0
0>1g003o0P00kDX007Zb0000Ic`0014[00026P0093T007`K0<K0003g8P00na@00<n[0000QPL00350
00036`0032L005i505bZ003XFP00o`000>EW0019Y00005U9000:900011`003]500V=003EVP00o@/0
0?@_002Z_P00078/000J<P000QT001Xb001c;02[_P00m2h00?d<003DW@001H`0000hA00011`000/U
001LA`1FZ000j5d00?l0003UJ000AZ<0001GBP002B<000@M0011B@0ETP00fHh00?h6003a?000SKL0
001Z>0004bd:ooooo`7o00000Oooool001kooooo00?o0000ooooooooool01oooool0o`3f:000cK00
00n@0000DTd000/V00026P006C4006Dn04fU003MO`00o@`00?TL003CWP008iL0001HB@003bT0008I
000D;@00Gd@0>il00=V<003k4@00nQD00=ND000`W00005a7000A:`000QT0018[001LAP0cW@00f980
0?/D003k4`00f90003BM0000GDH0018[00026@004R/005e603BM003HT000na800?/E003GU000;Y/0
001KB00042X0008I000D;@00H4<0@:400=^6003l3P00nA/00=>O000OUP0005I;000=9`000QT001Pa
001V?@1FZ000h7H00?h7003f9P00c;4000V=0000CTh000TS00036`008CL0070`07Ra003WG`00o`40
0?4i002l`P00088A000iA0001Ql000DM000a@000OA/0ZKh00>m2003o0000jUH008Je0000Lb/002@i
00036`002B8004a=00R=003</000mb@00?d9003NO@00BJ@0001Q@P0052d0008I000B:`00GTD0?j40
0=b4003m2`00n2000<j[000=S`0004i>00098`000a/002Di001d:P2;]`00je400?l0003]BP00UkT0
001g9@00:3/000HO001;C@09S@00cZh00?LQ003m2`00g8D003^O0000G4H0010Z00026@005c0006Ll
05jZ003SK000o`<00?<e002o``00084B000e@P001Ad000HO000mAP00QPL0b;`00?D[003n1P00ggX0
04VT0000H4<0018/00026@005Bl006Dn05ZY003SK@00o`<00?8e002k`P0007lE000b@@0011d000LP
0013B@02RP00c;800?LR003m2`00fhT003>M0000FDT000dX00026P007C@006hb07jc003ZE@00o`00
0>a=002<]`00078]000Q=`000aX000`V001GBP0/VP00fHd00?`=003g8@00c;80006:0000@DP000HO
00057P00=d@008@<0<Nn003e:P00oPP00=f1000jW`0005Y8000>:0000QX001he001`;`28]P00k4h0
0?l0003YF000Mk40001[=P006S80008I000A:`00H4<0CZD00>9b003o0`00lSP00;300000Nah002Xl
00036`002R@005=<02>G003GTP00o0h00?LQ003;]00008P3000lAP001Ah000HO0012B@05R`00cj/0
0?TK003k4`00e9d001FB0000CTh000PQ00047000<d8008<?0<Nn003f:000o@X00=Z;0000?P0ZVP00
05A<000:90000a/002Xm001l6`2j`P00lc400?h6003NO`00>9h0001HB@0032H000<J000V>P00NB80
[Kl00?8g003n1000ggT003nQ0000FTP000dW00036P0093T007PS0:^n003b>000oP@00=mj000nX000
05Y8000<9P000aX002Hj001j802b`000lc<00?h6003MP000=Id0001GBP002bD000<K000[?@00OQP0
a<@00?D[003m2P00fH`002BH0000DDd000PR00047000=48008D90<^e003h7`00na800=>O000>S`00
04E:0P001Ql0/`00A4X038l00=>O003k4P00n1l00<Zf0000Q0/00391000470002B<005A<02jK003L
P`00oPH00?8e002[_P0007HV000Q=`000QX0010Z001Q@P1NZP00if000?l0003ZE000LJl0001V?000
4bd0008I000M=000LRd0W;/00?4l003n1000gWd003BM0000ED/000TS00047000=48008H70<f`003i
6P00nQP00<j]0000Q`@003I3000470002B<005E<03>M003NO000o`@00?0n001;UAP001Xb00026@00
5Rl006`f08Rf003^A@00o`800>1f000kW`0005M:000:900011`003E20027103>Z`00nQH00?TM003:
]P00088?000^?P000a/000`V001LAP1@YP00iFH00?l0003ZE@00JZd0001S@00042X0008J000U>@00
O1`0aL@00?HU003l4000dZ4000F<0000>TD000@M00098`00ED/0>Yl00>5d003o0@00kDX007Zb0000
Ic`0018/00026@008SP007TP0<33003f9`00o0l00=:Q0004R`0003U4000470002R@005Q:04>R003S
K@00o`000>YC001Y[@000691000?:@000aX002Xl00214P3:]P00nA/00?TJ003;]@00084A000Z?@00
0aX000lY001S@@1/[P00je000?l1003RLP00>Yl0001DC000228000DM0013B@0ETP00f8l00?h7003b
>000V;X0001^<`005Rl0008I000O=@00Mb@0_L<00?HW003k4@00d:L000271@00<D0000<K000=9`00
H4<0IZ`00>YC003o0000hG8003NN0000Dd`000LQ00057P00BT`08YL00=b3003o0`00kTD007bb0000
ISd0010Z00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o0?@`0039^P00
0h/0001<C@002R@000<J000M=000JCT0GJX00>5e003n2000mb<00<nY000FT`0005A<000=9`000QT0
01L`001T?`19Y000gH400?d<003i6`00dih002>G0000F4X000hY00026@005Bh00652046Q003KQ`00
o0h00?TI003DV`009YP0001HB@003bT0008I000E;P00HD80@j800=b5003l3@00nA/00=>O000PUP00
05I:000=:0000QT001L`001T?`1?Y@00gg`00?d9003g8@00cjX001:A0000DDd000/U00036P007C@0
06/g06J/003TJ`00oP@00?@^0038^`0008T10015BP00224000<K000W>P00M2T0RKH00>YE003o0000
kd800:Zn0000OAX0039100057@001Al003Q400214@2k`P00lCT00?l1003WH000MK40001^<P007cH0
00<J000:9000DDd059800=2V003h7@00o0d00=^7000jW`0005e6000A:`000QT001D^001S@01>Y@00
ggT00?h7003f:000b[H0006:0000ATX000LQ00047000:Sd007PR09fk003^A`00o`000>YD0025]@00
078]000R>0001b00055=01FB003AX`00nAX00?`@003HT000;9X0001HB@003BP0008J000K<`00JcL0
KZl00>IQ003o0@00l3h00:fo0000O1`002ho000470001b4004E:00>;003</P00mb<00?d:003LQ000
>Yl0001LA`003bT0008I000I<P00JCT0JZh00>IS003o0@00l3h00:Vn0000NQh002/m000470002280
04a=00f?003@Y`00nA/00?`@003GT`009IP0001EB`002bD000<J000R>000Lb/0SkL00>e;003o0000
jEL007^b0000KC<001`d00026P003RP005]703ZO003MPP00o@P00?HY0038_00008D9000iA@001Ah0
00HO000oA`00R@40bk@00?LR003m3000fH`002bJ0000ET/000/V00036P008cP007DX09Vj003^A000
o`000>IR001V[00006Ll000F;`000QT001@]001T?`1MZP00iFP00?l1003_@@00Wk/0001f9P0093T0
00<J000;9P00EdX0<9`00=^7003m2@00mRT00<Nn0000P`h003A200047@001b4004]=012@003BX@00
nQD00?XI003@Y`002Hd00015BP001R0000DN000kA@00Q`@0bk@00?PP003l3`00eYH0003c01bE0000
D4h000PR00047000<D00084B0<K0003e:@00o@X00=Z:000ZVP0005A<000:90000a/002`m001m6@2o
``00m2h00?h7003LQ000<I`0001FB`002RD000<K000Z?000OA/0_L<00?@_003n1`00g8@0032L0000
ED/000XT00036`00;3d007hG0<C4003e:`00o@T00=Z;000WV@00059=00098`0011`0035100233P38
^`00mb<00?`>003FU`005i<0001<C@001b0000DN000lAP00RP00cj/00?XH003j5`00cjT000::0000
?DH000DN00078000CDh06I<00=NE003l3@00mRL00<K00000OaD002`n00036`002bD005Q903fP003P
N000o`<00?0n002I^P00078]000M=0000QT001</001V?@1^[`00jUH00?l0003WGP00H:/0001R@@00
42X0008J000Q=`00MbD0[[l00?<c003n1`00fhP002JH0000DDd000PQ00047@00>dH00h/00=6V003k
5000n1h00<Zg0000P`h002lo00036`002bD005U904:R003RLP00o`400>i70012T1`001H_00026@00
6S80070_09Vj003a?000oP@00=f0000]V`00059=00088P0011d003a600J<003BX@00o1400?LT0036
`00007dI000X>`000aX000hY001P@`1OZP00j5`00?l0003WG`00FZT0001OA0003BP000<J000[?@00
P1<0bKX00?PN003j5@00cZ/000271@00<d4000<K000;9@00FTP0BJ@00>AZ003o0000jU@006Z]0000
Hd0000lY00036P009c/007hH0<Nm003h8000naD00<n[0000QPH0039100036`002bH005a705>W003V
HP00o`000>QM001IZ@0005i5000<9`000a/003100026203>[000naD00?PQ0037_`0007`K000U>@00
0QX0018[001W?01m/`00kTL00?l2003NO@00;9X0001@CP001b0000HO001;C@0RU`00g8D00?h4003_
@@00QkD0001Y>@004bd0008J000T>@00O1/0akl00?PO003j5`00c;8000223`00:Sd000<J000@:P00
I3l0M[400>e9003o0P00gWd002VI0000Cdh000HO00078000D4d0;i/00>1h003o0@00k4l006b^0000
HD8000dX00[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o0?8i0034a000
08H70014BP00228000<K000R=`00KS<0KJh00>AZ003n1000mBX00<^c000:SP00051>000:9@000QX0
01/c001X>P1IZ@00h7H00?h8003g8P00cjT001JB0000Dd`000`V00026P00634006Dn052V003OO000
o@X00?PP003AYP006I<0001DC00032L0008I000H<@00ISd0DZH00=mj003m2@00mb800<nZ000DT@00
059=000;9@000QX001/c001Y>P1NZP00hW400?h6003f:@00bk@000J<0000C4d000TS00036`008CL0
06la07Ja003WH@00o`800?8g0033a00008@<000mAP001R0000@L000]?P00NB40VkX00>e;003o0000
k4`009Rj0000N2<002/m000470001b00041800261`36`000m3400?l3003TJ`00I:`0001Z>@006c<0
008J000<9`00ED/08IL00=BK003j5`00na800=NB000/VP0005U9000>:0000QT001Pa001W?01MZP00
hfh00?h4003d<000a/0000252@00?DL000HO00047@00<D0007dI0:no003`?P00o`400>MO001e/000
06dd000N=@001b0005E;02:G003EV000na@00?XF003DV`007iH0001DC0002bD000<J000P=P00L300
Ok<00>UG003o0000kTL009^k0000Mb@002Pk00036`00228004i>00n@003@Z000nA`00?`?003HS`00
;9X0001GBP003BL0008J000M=@00KS<0Nk800>UI003o0000kTP009Rj0000MRL002Hj00036`002R@0
055=01ZD003DW@00nQD00?XF003CWP0069<0001AC@002B<000<K000W>`00N2<0XK`00>m2003o0@00
iV4006Z^0000JCT001Pa00026@004B/005m404VT003PM`00oPD00?@a0032a000080C000b@@0011d0
00LQ0017B`09S@00cjT00?TK003k4@00eYL001jE0000DTd000TS00036`00:C`007XP0:^n003a>`00
o`800>=]001FZ0000691000B;0000QT001L`001Y>P1^[P00j5d00?l0003]BP00SKL0001a;P007cH0
008J000>:000FdL0?j400=il003n1P00m3400;k30000OQP002hn000470002B<0055=01fE003FUP00
o0l00?PO003</P0008P2000lAP001Ah000HO0013B@06S000cjT00?TJ003k5000dZ00000d012@0000
BD`000LP00057@00>4@008H80<Zf003g8P00o0h00=NE000MU@00051>00088P0011`0039100223`37
_@00mRH00?d<003HS`008iL0001BC@002B<000@L000`@000PA40akl00?HW003m2`00f8l002:G0000
DDd000PR00047000<T4008<>0<Vk003g9000o0h00=JF000JU00004i>00078@0011d003U40027103<
/000nA`00?/D003BXP002hh00013B@8000HO0;d004A:00b?003BX000na<00?PN003;]00008H8000e
@P0011`000PR001BC@0VV000fXX00?d8003d;`00^/80001j7P009SX000<J000=9`00G4H0C:D00>=]
003o0@00kTL008Rf0000KC@001Pa00026@005Rl006Xh07jc003/C000o`000>AY001AYP0005i5000=
:0000aX002Lj001k7@30``00mB/00?d;003GT`006I<0001;C@001R0000DN0014BP0?T000e9/00?`?
003f9@00a/40001n6000:C`000<J000=9`00GDH0DJH00>EW003o0000je4003Z;7P004R`0008I000O
=@00MBP0Zkh00?<c003n2000fX/0022F0000CTh000LP00057P00ADX04Y400=JF003m3000mB/00;[2
0000NB80028h00026P004B/006Dn072_003[DP00o`000>AZ001:Y00005Y8000;9@000a/003500025
2@3=[`00nQP00?TL003:]P00088@000]?P000a/000dW001NA@1IZ@00iel00?l0003WGP00FZT0001N
A@003BL000<K000]?P00P`h0c;<00?TI003i6`00bkD000224000:cd000<J000>:000H4<0HZ/00>UH
003o0000iFP004ZT0000FDT000XT00047000=d@00XX00=:Q003l3`00mRP00;c20000N2<001lf0002
6@005Bh006`f08jg003`?@00oPD00=^7000OUP0004Y<00067`001b40055=02nK003ONP00o`800>e:
001f/@0006Dn000@:P000aX002Tl00214P3;]@00nQT00?PM0038_00007dI000U>@000QX0018/001Y
>@27]@00l4000?h5003KR00079D00016B`001Ah000PR001EB`0nX000hfd00?l0003YF@00FjT0001M
AP002bD02_ooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo04H0kd800;?00000
PA4003]60007800011`002Lk001c;01n/`00iel00?l2003c<`00akh000290000B4`000TS00036`00
83H006dd06V]003SK000oPD00?DZ003;]0002Hd0001?CP002R@000<J000M=000JSP0H:/00>9a003n
1P00mRL00<f`000<S`00051>000:90000aX001dd001Z>01RZ`00hVl00?h5003e:@00bk@000N=0000
CTh000TS00036P0083H006dc06n_003UIP00o`<00?<a0037_P0008L40013B@001b4000<K000W>P00
M2X0QkD00>YG003o0000l4000;700000OaH003E20P001Ah0:@00<d4007hH0:fo003_@@00o`000>YF
0027]@0007<[000U>P000a/000PR0018C003R`00bkD00?HY003n1P00hGD005BW0000ICh001L`0002
6@003bT005Y802nK003HT000na400?XH003DW@007iH0001DC00032H0008J000M=000K3H0KZh00>IT
003o0P00lSP00;_20000P1<003I3008000DN0?l003Q400224031a000lSD00?l3003TJ@00I:`0001Y
>P006C8000PQ001IB@0`W000fHh00?`?003i7000dJH001:A0000D4h000TS00036`009CT007@Y092h
003/C@00o`000>]A002:]P0007</000S>0000aX000XT001BC@0KU000e9d00?XF003k5000eIX001jF
0000Dd`000/U00036P008SP007</08bg003/C`00o`000>]B0026]@00074^000P=P000aX000`V001F
B`0WV@00ei800?`@003i7000cjT000b>0000BTd000PQ00047000;Sh007dK0;;0003b>@00o`800>=/
001JZ@0006@o000D;P000QT001@]001T?`1IZ@00hf`00?l2003a>@00/<00001k7@00;3d000<L0008
8P00Cdh05Y800=>O003j5@00nQL00=:R000AT@0004e>00088P0011`002lo001n5`2m``00lc800?h5
003PM`00Aj<0001NA@0042X0008I000K<`00KC<0O[<00>]C003o0000jU@007bb0000KC@001Xb0002
6@0042X0061304jU003RL@00o`<00?4i002/_`0007TQ000X>`000a/000XU001EB`0[VP00fX/00?d;
003f9`00b;`000243000=D8000@M00078@00Bdd04Y400=>O003k5000nA/00<n[0004R`0004580006
7`001Al0041800>;003>[000nA/00?/D003CW`0049000019C0001b0000DM000iA@00Q`D0bk<00?PO
003l4000eIX001JB0000CDh000LQ00047@00=d@008H70<^e003h8000o1000=FJ000ETP0004a=0007
80001Ad003Y500280`3=/000nA`00?/C003BX0003Hl00015BP001Ql000DN0010B006S000d:H00?XF
003i6P00cZ`000290000>dD000DM00078@00CDh069<00=JE003l3@00mRD00<Nn0000PA8002ho0003
6`002R@005I;03BM003NO`00oPD00?8g002X_P0007HW000Q=`000QX0010Z001Q@P1KZ@00iV<00?l0
003[D@00Mk40001X>P005Bh0008I000J<P00Kc40T;P00>m3003o0P00hG@0046Q0000FDT000/U0003
6`00;3h0080C0<Rm003g8`00o1000=>M000<S`00049900057P001b0004a>01^D003HT000o@X00?@]
002h`P0007TQ000S>0000QX000lZ001R@P1QZ`000800j5d00?l0003XF`00<XLQ000@:P000QX002@i
001j802m``00mB/00?d<003FUP004i400015BP001Ah000HP001>CP0OUP00fX/00?h8003c=000Z;h0
001d:P007C@0008I000D;P00JCT0P;@00>i8003o0P00hG@003^O0000ET/000TS00047000>4@00HX0
0=6U003k4P00mb<00<K00000OAT002Lj00036P003bT006=106V]003ZE@00o`000>AY001:Y00005Y8
000;9@000a`003A200280`3@Z000na<00?LR0036`00007dJ000V>P000QX0010Z001U?P1c/000k4h0
0?l1003QL`00>il0001EB`00228000@M000oA`0>S`00eYL00?d:003d<000Z[h0001c:`006c<0008I
000I<@00L2l0X;`00?<e003m2@00ei8001:A0000@DP000DM00088P00ED/0?Z000>9_003o0000jU@0
06F/0000H4<000dX00036`00;cl008H80<nZ003k4`00mb@00<;40000NB80020f00026@005Rl006hc
09Rj003b=`00o@P00=NC000?T00003i700047@002R@005U904fU003VH`00o`000>IS001<Y@0005U9
00098`[ooooo0Ol00001ooooo`007_ooool00ol0003oooooooooo`07ooooo`3o0>e<002Q_00007`K
000d@P001Ah000@M000]?P00N2@0SkL00>YE003o0000lC/00;k30000Q0/0041800078@000a/002Di
001a;P1j/P00if400?l2003c<P00akh000290@00Ad/000PR00036`008CL006lb072_003UIP00o`<0
0?@_0038^`000HX00019C0002B8000<K000Q=`00Kc80L[000>IU003o0`00lc400<Nn0000R0<004E:
00088@000a/002Di001b;@1o/`00j5`00?l1003a>P00_L<000233`00>dH000HO00047@00;Ch007TR
09Vj003/C000o`000>e9002O^`0007XO000^?`0011d000HO000kA@00P`l0_l<00?8h003o0@00if00
07Ja0000Kc80020f00036P002R@0051>00n@003?Z`00n2400?d:003MP000AJ<0001Q@`004bd0008I
000B:`00GTD0?J000=b6003m3000n1h00=2X000BT@00051>000:90000aX0024g001`;`1n/`00jET0
0?l0003_@@00ZKh0001l7000;cl000@M00068000@4P008L50<Rl003e;@00oPD00>5d001DY`0006@o
000E;`002R8005i503nQ003LP`00o@X00?LS003=/0001X`00018C000224000@L000[?@00NB40X[`0
0>m3003o0000j5/007Vb0000KS<001he00026P0032L005I:02VI003GTP00o1000?TK003AY@004Y40
001?CP002B<000<K000X>`00Mb@0WK/00>i5003o0000j5`007Fa0000K3D001`c00026P003RP005Y8
03FM003KQ`00o@/00?LS003;/`0008X00012B@001R0000@M000d@P00PA40a<@00?@`003n1@00h7L0
04^T0000H4<0014[00026@00630006Pj06V]003VHP00o`400>m3002N^`0007LU000V>P000a/000XT
001CC00SU`00ei@00?`@003h7@00cZd000F<0000A4X000HP00057@00=T<008<=0<No003e:P00o@P0
0=f2000hWP0005Y8000=9`000QX0020f001b;@2@^000kDT00?l0003WGP00Jjh0001X>P005c00008I
000C;@00I3l0GZX00>EW003o0@00kd<009Zj0000MBT0028h00036P003BL005U903VO003MP000oPL0
0?@_0032a00007lF000^?`0011`000TS001AC@0OUP00ei@00?`>003g8P00bkD0000<00261P00>D@0
00DM00078000B4`03Xl00=:Q003k5@00nAX00<nZ0004R`0004180P001Ql04P00@DP01H`00<nY003j
6000nQH00=6U000:SP0004A:00067`001Ah003m700>;003?ZP00nAT00?XF003AY@002Hd00013B@80
00HO0=40049900N=003AYP00nQH00?TI003?Z`000HX0000mAP001Ah000HP0019C00CT@00e9/00?`@
003h8@00b[L000242`00=48000@L00088P00DTd09YP00=Z;003m2@00mBd00;k30000O1`002Pk0003
6P0032H005Y804>R003QM000o`800?10002F^@00074^000L=0000QT001</001U?@1[[P00jEP00?l0
003XF`00IZ`0001T?`004B/0008I000N=@00M2X0XK`00?4i003n1@00gWh003>M0000ED/000TS0004
7000<d4008D90<bc003i7000nQH00=2X0001RP0003Y500047@002280059=02VI003LQ@00oPH00?8f
002V_@0007@Y000N=@000QT0018/001V?@1a/000je800?l0003UIP00:X8S000=9`000aX002Tl001o
5P37_`00mb<00?/A003BX@001h`0000mAP0011d000PR001BC@0]V`00gH000?h4003a?@00U[T0001_
<@006C40008I000H<@00KS<0T[P00?0n003n1000gGl002fK0000DTd000PQ00057@00@4P03Hl00=FJ
003l3@00mBX00;[20000N280024g00026@004R`006Ll07Zb003]B`00o`400>5d000kW`0005I;0009
8`0011d003]600N=003CWP00o0h00?DY002k`P0007PS000P=P000QT001<]001Y>@24]@00kd@00?l3
003NO@00;9X0001AC@001b4000DN0017B`0JU000fH`00?h7003a>@00V;X0001^<P005c00008I000M
=000MBP0//000?D/003l3@00e9d000J<0000>D@000@L000:9000FTP0CJD00>IT003o0000iel005FW
0000G4L000/U00047000=T<00X/00=>O003l3@00mB`00;300000M2X001/c00026@006S80078/0:Zn
003d;P00o0`00=>N0003R`0003I3000370002bH005e505bZ003YF000o`000>=^000mX00005A<0008
8@0:ooooo`7o00000Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008
ooooo`03o`000?oooooooooo00Oooooo03/0jUH008ng0000N2@002dn00047@001Ah003A2001l6`2Q
_000kD/00?l0003^A@00[;l0001o5@00>4@000HO00047000:cd007HV08^f003YE`00o`000?4k002n
``0008@<000oA`001b0000@L000W>`00Lb/0PK@00>QL003o0@00lSP00<C40000Q@T0041800078@00
0a`002Lj001c:P23]000jEX00?l1003a>P00_L<000233P00?4H000HP00047000:cd007LU096h003[
DP00o`000>m3002[_P0007hH000d@P0200057P3o000c@P00OAT0Zkh00>m3003o0000je<008fg0000
MBL002Pk000470001b4004=900271037_P00m2l00?l4003TJ`00IJ`0001Z>00073<0008J000<9P00
E4`079D00=:P003i6P00o0l00=Z;000fWP0005a6000@:P000QT001D^001S@@1<Y@00gg/00?h8003f
9P00c;8000J<0000BT`000PR00036`009cX007DX092h003/C`00o`000>e;002G^@0007LU000Y?000
0a`000PR0018C005S000c;800?LU003m2@00gWl004FR0000H4<0018/000;8`00HT40CZD00>1h003n
1P00mB/00<Rk0000Q`@004180006800011d00350001n602d`@00lCX00?l2003UI@00J:d0001Y>@00
6C80008I000?:@00FdL0=ih00=^7003m3000mb800<f`0005S00004M;00078@0011`002ho001l6`2_
_`00lC/00?l2003UIP00IJ`0001X>`006300008I000A:`00GTD0A:800=il003n1`00mB/00<Nn0000
Q@X003Y500057P001Al003a600261`39^P00mRP00?d9003MPP00>il0001KA`003RT0008I000L<`00
KC@0N[800>UG003o0000k4`008bg0000LRd0020g00036P0032L005Q:036L003JR@00o@/00?LU003:
]`0008L5000lAP001Ah000DO000mA`00R0<0bk@00?LS003l3000fHd002ZJ0000ED/000/U00036P00
9CX007LU0:6l003`?`00o`400>AY001KZ@0006=0000C;@000QT001L`001Y>P1^[`00j5`00?l0003/
C000RKH0001`<0007C@0008J000?:@00GTD0B:<00>5e003o1000lSL00:no0000NQl002Pk00036`00
2bD005E;02fK003JR@00o@X00?HY0036`000084A000b@@0011`000PR001@CP0KU000eYH00?`?003h
8@00bkD000261P00>4@000DM00078000BT`04Y400=>N003k4`00nAd00<f_0000R@4003a600057P00
1R0004Q;00n@003CW`00na<00?TL003=/00008P2000kA@001Ad000LP001:C@0DTP00e9/00?`@003h
8000bkH000252@00=D<000@M00088P00D4h089H00=R@003m2`00mRP00<K10000OaD002dn00036`00
2R@005I;03BM003MP000oPD00?8f002/_`0007LT002f000S>0000QX000hY001OA01BY`00i6T00?l1
003]BP00Q;D0001/=@006340008I000F;`00JSP0O;<00>a>003o0000iFH005JX0000Gd@000lY0002
6P008cP007PR0;?0003d<@00oPP00=Z9000UV000055=00088@0011d003Y5006:003@Z000nQH00?TL
003</`0008D9000c@@0011`000XT001FB`0gWP00ggX00?l3003`?`00UKT0001`<0006S80008I000F
;`00JcL0P[@00>e8003o0@00hW40029n9@002bD000<K000`@000Q0d0bk@00?TL003j5`00cZ`00027
1000=D<000@L000:9000ETX0>il00>5e003o0P00kTH008Be0000JcL001D^00026@0073@007</0:Bm
003b=@00oPL00=Z:000OUP0004e>000680001Ql004U<01VD003HS`00o@P00?<c002X_P0007@Z000L
=0000QT001H_001/=P2;]P00kd400?l3003NOP00;I/0001AC@001b4000DN0014BP0CT@00ei<00?d9
003c<@00ZKh0001c:`0073<0008I000G<000KS<0UKT00?4k003n1P00fhP001nF0000Bdd000HO0007
8000Cdh0:9T00=f1003o1000kd8008Je0000JSP001<]00026@008SL007XP0<C4003g9000na800=2X
0000Q`D0039100036`0032H005i505fZ003YFP00o`000>AY0016X`0005M:00098`0011d003i700j?
003GU@00o@T00?<e002N^`0006la000G<0000QT001he001g902l``00mRH00?/B003?Z@0008H7000_
?`000a/000hX001R@@1][P00k4h00?l1003PN@00;Y/0001@CP001R0:ooooo`7o00000Oooool000Oo
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool01oooool03`3WH000OK<0001c:`009c/000@L00068000>dH0084A0;?0003_@@00o`00
0>a>002J^P0007XO000a@00200057P15000a@000Nah0WK/00>a=003o0000kT@00:bo0000OaH003M3
00067`0011d002dn001h8`2C^000je800?l0003_@@00//0000205000>4@000HO00047@00;Ch007PR
09Fi003[D000o`000>m3002[_P0007hH000e@P001Ah000DM000a@000O1`0Xk`00>i8003o0000k4d0
09Vj0000NB4002dn00047@001Ql003]500223`2m``00lCX00?l1003XG@00O;80001a;`008cP000<K
00098`00C4d01h`00<^c003f9`00oPL00>1f001EY`0006Dn000G<0000QT000hX001HB@0YV@00eYD0
0080na@002d0eYH002RI0000F4X000hX00026@006C4006Lk05bZ003RL000oPD00?@^0038_@0008L5
0011B0001b0000@L000]?P00NQl0X[`00>i5003o0000jUD008Fe0000LRd002<h00036`002B<0051>
016@003@Y`00n1d00?`=003JRP00=Yh0001KA`003bT000dU001W?01NZP00hfd00?l3003c<`00a<@0
00223`00>4@00P001Ah0o`00>4@008<>0<G3003c<@00oP@00>9`001HZ00006Dn000E;`000QT0018[
001OA016X`00gW`00?h7003e:@00bKX000271@00?TL000HO00057@00=D80084B0<;4003c<`00oP@0
0>9a001DY`0006=0000D;@000QT001@]001S@01DY`00hW400?l4003c<`00_/<000205000<T4000@M
00078000A4X00h/00<f`003h8000o0d00=V=000]V`0005M:000<9P000aX0020g001b;@2;]P00k4d0
0?l0003ZEP00Nk80001]=00073<0008I000?:@00G4H0?j400=in003n1`00mBd00<K10000PQ0003A2
00047@001b0004I;00R=003?ZP00nA/00?/B003EV00079D0001AC@002B<000<K000[?@00O1`0/l00
0?8f003o1000hG@004^T0000Gd@0010Z00026@006c<006dc07nc003[DP00o`000>YF001g/@0006/g
000I<@000QT0018/001R@@1HZ000i6X00?l1003`@000WK/0001e:0008SP000<J000=9`00FTP0>il0
0=in003n1P00lc400;_20000OAX002/m00036`002R@005A<02VI003JR`00o@X00?HX0037_`00088A
000a@00011`000PR001AC@0OUP00ei<00?`=003g9000bKX000243000=48000@L00088P00Cdh079D0
0=ND003l3P00mb@00<Vj0000P`d003=1000470002280055=026F003HT000o@/00?HW0036`000080C
000^?`000a/000XT001DC00]V`00g8D00?h7003d<000^<80001k7P009c/000<J000<9`00FTP0@j80
0>5e003o0`00l3l009Zj0000LR`001he00026@004B/006=006:[003WGP00o`000>YD001c/00006Pk
000D;P000QT001Xb001_<P2>]`00kd@00?l2003RL@00AZ<0001KA`0032H000<J000Y?000OAT0aL@0
0?HX003m3000ei@001NC0000BTd000HP00057P00@dT03Hl00=BM003l4000mb<00<Nm0000P1@002`n
00036`0032H005Y804JS003RK`00o`400>e80023]00006/g000F;`000QT001Xb001_<@2D^@00l3l0
0?l3003ON`006WTV00098`0011`003M300280P3?ZP00nQH00?PM003:]P0008<?000^?`000a/000/V
001KA`1:Y000i6/00?l00000803[D000Lk00001V?@004R`0008I000Q=`00N2@0]/400?D]003m2`00
eYD001:A0000A4X000DN00078@00D4h09iP00=b4003n1@00lC`009Ji0000Kc4001Pa00026@006C80
070_09fk003b>000oPH00=Z9000OUP0004a=0P001Ql0BP00CDh08IH00=^8003n1P00lCX009Ni0000
Kc8001P`00026@006c<007</0:Nm003c<P00o@T00=NC000BT@00049900057P00228005A<03JN003P
MP00o`400>a<001e/@0006Dn000@:P000QX002Lk001o5`39^`00n1d00?XH003</`00088?000[?@00
0aX000lY001S@@1][P00je000?l1003QM000=ih0001CC000224000DN0017B`0KU000fXT00?h5003`
?P00S;L0001Z=`004bd0008I000S>000O1`0akl00?PO003j5`00bk<000214@00:C`000<J000@:`00
IS`0O[<00>i4003o1000g8@0022F0000BD`000DN2_ooool1o`00007ooooo0007ooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool01Oooool4o`0000Kooooo02D0i6/006b^0000KS<0
028g00036`00228004=900261`35a000lSP00?l1003YF@00R;H0001f9`00:Sd000@L00067`00>D@0
080D0:no003_@`00o`000>a>002J^P0007XO000`@0001Ad000DN000d@P00OAX0YKd00>i8003o0000
kDX009nl0000Nad00350008000DN0?l003A2001m6P2W_@00kTH00?l0003/C@00VKX0001i8@00;Sl0
00@M00067`00>4@0084C0;G1003`?P00o`000>UG0027]@0007@Y000W>`000a`000LQ0013B@00Q`@0
akh00?@a003o0`00iFP006^^0000K3H001he00036P002bD0055=01>A003@Z000n2000?d;003MP@00
AJ<0001Q@P0052d0008I000A:`00GDH0>9h00=Z:003l3`00nA/00=:Q000JU00005=<000;9P000QX0
01dd001/=P1][P00iFD00?l2003b=P00`<<000223`00>D@000DO00057P00<d8007lF0;C1003a?000
o`400>MP001d/00006dd000N=@000aX000/V001DC00NU@00e9d00?XG003k4`00eYD002NI0000EdX0
00dW000?9`00JcH0KZl00>IR003o0@00lC`00;700000OAT0035000047@001R00041800280`39^@00
mRT00?h7003ON`00B:<0001P@`004R`0008I000E;P00I3l0EJP00>9a003n1000lc400<G40000PQ00
03I300057P001Ql003a600261`38_000mBX00?h7003OO000AJ80001OA0004B/0008I000G<000Ic/0
I:`00>EV003o0@00lC`00:bo0000Nah002`m00047000228004e>012@003AY@00nAX00?/B003EV000
7iH0001CC0002R@000<K000V>P00MRD0WK/00>m3003o0000if4006Z^0000JCX001P`00026@004R/0
065204nV003QL`00o`@00?8e002h`@0007dI000^?P0011`000PR001?CP0DTP00dil00?XE003j5`00
dJ<000n@0000Bdd000LQ00047000<T40084C0<G4003d;P00oPL00=io000lX00005Y8000=:0000QX0
020f001b;@2A^000kTP00?l0003WH@00Ijd0001V?0005Bh0008I000E;`00Ic`0J:d00>MP003o0000
kDX008^g0000L2l001de00026P003bT005i504ZT003QL`00o`<00?4j002X_P0007PS000U>P000aX0
00`V001HB@0gWP00gH000?h6003d<000_<80001m6P00:cd000<K000:9000ED/0;9X00=^8003m2@00
mB`00<G40000OaH002dn00036`002B@005A<02ZJ003JR@00o@T00?D[0035a00007lG000/?P000a/0
00XT001EB`0_V`00g8D00?h7003d<0000:l0^/80001k7@00:3/000<K000<9P00FDT0?:000=mj003n
1000lCT00:Jm0000MRL0024g00026P003bT005m405:W003TJP00o`400>e80028]P0006hc000I<P00
0QT001@^001X>`1c/000jU@00?l0003WGP00HZ/0001S@0004B/0008I000N=@00LbX0Wk`00?4k003n
1000gg`003NN0000EdX000XT00036`00;cl0088?0<Vj003h8@00na400=>O000;SP00045900057P00
1R0004a=01VD003GTP00o@/00?D[002o``0007/M000V>P000aX000hX001OA01FZ000iV@00?l0003[
DP00L[00001V?0004b`0008I000N=@00M2T0Y[d00?8f003n1P00fhL001=d9`001b4000DM000oA`09
S@00dil00?`@003g9000a/00001n6000:3/000<J000>:000Gd@0FZT00>MP003o0000jEX006>[0000
HD8000lY00036P009SX007`K0<G2003g9@00o1000=:P0006S00003a600047@00228005A<03FM003O
N@00o`800>i50025]@0006Xh000E;P000QT001he001e:02__`00m2l00?d:003GU@004Y400013B@00
1Ah000LQ001BC@0^V`00gWd00?l3003_A000QKD0001Z>00052d0008I000P=P00N2@0^L800?DZ003l
3P00dih000J<0000>TD000@L000:9000F4X0AJ<00>A[003o0000jUH006B/0000H4<000hX00036`00
;Ch008<=0<f`003j5`00n1l00<Rm0000OAT002Dj00026P004B/006Ll07jc003^AP00o`<00=io000X
V@0004m>008000HP01/004m>02VI003NOP00o`<00>i7001k/P0006Hm000@:P000aX002Tl00214P3;
]000nQP00?PN0037_P0007`K000S>0000QT001@]001[=`2?]`00lC/00?h7003HS`004i400010B000
11d01oooool4o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo0_l00008ooooo`03
o`000?oooooooooo0?ooooooooooool5ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooooooool5ooooo`7o
00000Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0ooooooooooooo`Gooooo0Ol00001ooooo`002?ooool2o`0000Wo
oooo0ol00008ooooo`03o`000?oooooooooo0?ooooooooooool5ooooo`7o00000Oooool001kooooo
00?o0000ooooooooool0ooooooooooooo`Gooooo0Ol00001ooooo`007_ooool00ol0003ooooooooo
o`3ooooooooooooo1Oooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`07ooooo`7o00000Oooool001kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01oooool1o`00007ooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`00
7_ooooooo`000?oo00002Ol00001ooooo`00ooooooooooooobSooooo003ooooooooooooo:?ooool0
0?oooooooooooolXooooo`00ooooooooooooobSooooo003ooooooooooooo:?ooool00?oooooooooo
oolXooooo`00oooooomNooooo`?o0000a_ooool00?ooooooGoooool00ol0003oooooooooo`35oooo
o`00goooool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00000oooool3o`00
00;ooooo0ol00003ooooo`Go00000_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3o`00
0004ooooool0003o0000ooooo`?o00000oooool3o`0000Sooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l0
0002ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool0a?ooool00>7ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo
00001_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005
ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo0<Cooooo003Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01_l0003o
ooooooooool0003oooooo`0000Gooooo1Ol00009ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01?l0003ooooooooo
ool00002ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool00000aOooool00>7ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o
00001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00003oooo
o`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000_ooool01_l0003oooooooooool0003oooooo`0000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo00000<Gooooo003Qooooo`04o`000?oooooo
ooooooooo`Co00000_ooool4o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_oo
ool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l0
0003ooooo`?o00000oooool3o`0000[ooooo00Co0000oooooooooooooooo1?l00002ooooo`Co0000
0oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0003o00000oooool4o`0000;o
oooo0_l000000ooooooo0000o`000034ooooo`00hOooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0boooool00=oooooo1Ol00008ooooo`03o`000?oo
oooooooo017ooooo0_l0000[ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0boooool00001\
\>"],
  ImageRangeCache->{{{0, 549}, {549, 0}} -> {-0.657075, -0.330645, \
0.00140528, 0.00120453}},
  CellTags->{"AOG6.3.1", "AOG6.3", "AOG6.", "AOG0."}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(InterferenceFunction \[Rule] 
          "CompiledFunction[-intensity data-]"\), ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"InterferenceFunction", "\[Rule]", 
            RowBox[{"(", 
              
              TagBox[\(\[SkeletonIndicator]  
                  DensityGraphics  \[SkeletonIndicator]\),
                False,
                Editable->False], ")"}]}]}], 
        ",", \(ResidualFitError \[Rule] {1.9653737448513654`*^-10, 
            1.5756648257792838`*^-11}\), ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(SpatialScale \[Rule] 1\), 
        ",", \(OpticalPathRange \[Rule] {99.99693506202541`, 
            100.11238081006073`}\), 
        ",", \(RayBoundary \[Rule] {{\(-1.7458610351843245`\), 
              1.7470806113397281`}, {\(-1.746199350250952`\), 
              1.746199350250952`}}\)}], "}"}]], "Output",
  CellLabel->"Out[34]=",
  CellTags->{"AOG6.3.1", "AOG6.3", "AOG6.", "AOG0."}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2", "Subsubsection",
  CellTags->{"AOG0.", "6.3.2", "AOG6.", "AOG6.3", "AOG6.3.2"}],

Cell["\<\
L1=PlanoConcaveLens[-30,20,2,\"L1\",CurvatureDirection->Back];
L2=PlanoConvexLens[160,30,6.5,\"L2\"];\
\>", "Input",
  CellLabel->"In[21]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],

Cell["\<\
sys1 = {
Move[GridOfRays[{3,3}],-50],
L1,
Move[L2,130],
MoveReflected[Mirror[75],{130,0},{200,0},{70,75}],
MoveDirected[Screen[50],{70,75},{200,0}]};\
\>", "Input",
  CellLabel->"In[23]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],

Cell[CellGroupData[{

Cell["DrawSystem[sys1,PlotType->TopView,FormatType->OutputForm];", "Input",
  CellLabel->"In[24]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .56705 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.207171 0.00366724 0.174156 0.00366724 [
[.21084 .10869 -6 -4.5 ]
[.21084 .10869 6 4.5 ]
[.69583 .09035 -6 -4.5 ]
[.69583 .09035 6 4.5 ]
[.8976 .0135 -3 -4.5 ]
[.8976 .0135 3 4.5 ]
[.52408 .55355 -3 -4.5 ]
[.52408 .55355 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .56705 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.20717 .13748 m
.22785 .13748 L
.22001 .14971 L
.20717 .14971 L
.20717 .13748 L
F
.20717 .14971 m
.22001 .14971 L
.21583 .16193 L
.20717 .16193 L
.20717 .14971 L
F
.20717 .16193 m
.21583 .16193 L
.21451 .17416 L
.20717 .17416 L
.20717 .16193 L
F
.20717 .17416 m
.21451 .17416 L
.21583 .18638 L
.20717 .18638 L
.20717 .17416 L
F
.20717 .18638 m
.21583 .18638 L
.22001 .1986 L
.20717 .1986 L
.20717 .18638 L
F
.20717 .1986 m
.22001 .1986 L
.22785 .21083 L
.20717 .21083 L
.20717 .1986 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.20717 .13748 m
.20717 .14971 L
.20717 .16193 L
.20717 .17416 L
.20717 .18638 L
.20717 .1986 L
.20717 .21083 L
.22785 .21083 L
.22001 .1986 L
.21583 .18638 L
.21451 .17416 L
.21583 .16193 L
.22001 .14971 L
.22785 .13748 L
.20717 .13748 L
s
.5 g
.20717 .17416 m
.22785 .17416 L
.22001 .17416 L
.20717 .17416 L
.20717 .17416 L
F
.20717 .17416 m
.22001 .17416 L
.21583 .17416 L
.20717 .17416 L
.20717 .17416 L
F
.20717 .17416 m
.21583 .17416 L
.21451 .17416 L
.20717 .17416 L
.20717 .17416 L
F
.20717 .17416 m
.21451 .17416 L
.21583 .17416 L
.20717 .17416 L
.20717 .17416 L
F
.20717 .17416 m
.21583 .17416 L
.22001 .17416 L
.20717 .17416 L
.20717 .17416 L
F
.20717 .17416 m
.22001 .17416 L
.22785 .17416 L
.20717 .17416 L
.20717 .17416 L
F
0 g
.20717 .17416 m
.20717 .17416 L
.20717 .17416 L
.20717 .17416 L
.20717 .17416 L
.20717 .17416 L
.20717 .17416 L
.22785 .17416 L
.22001 .17416 L
.21583 .17416 L
.21451 .17416 L
.21583 .17416 L
.22001 .17416 L
.22785 .17416 L
.20717 .17416 L
s
.20717 .21083 m
.22785 .21083 L
.22785 .20958 L
.20717 .20958 L
.20717 .21083 L
s
.20717 .20958 m
.22785 .20958 L
.22785 .20592 L
.20717 .20592 L
.20717 .20958 L
s
.20717 .20592 m
.22785 .20592 L
.22785 .20009 L
.20717 .20009 L
.20717 .20592 L
s
.20717 .20009 m
.22785 .20009 L
.22785 .19249 L
.20717 .19249 L
.20717 .20009 L
s
.20717 .19249 m
.22785 .19249 L
.22785 .18365 L
.20717 .18365 L
.20717 .19249 L
s
.20717 .18365 m
.22785 .18365 L
.22785 .17416 L
.20717 .17416 L
.20717 .18365 L
s
.20717 .17416 m
.22785 .17416 L
.22785 .16466 L
.20717 .16466 L
.20717 .17416 L
s
.20717 .16466 m
.22785 .16466 L
.22785 .15582 L
.20717 .15582 L
.20717 .16466 L
s
.20717 .15582 m
.22785 .15582 L
.22785 .14822 L
.20717 .14822 L
.20717 .15582 L
s
.20717 .14822 m
.22785 .14822 L
.22785 .1424 L
.20717 .1424 L
.20717 .14822 L
s
.20717 .1424 m
.22785 .1424 L
.22785 .13873 L
.20717 .13873 L
.20717 .1424 L
s
.20717 .13873 m
.22785 .13873 L
.22785 .13748 L
.20717 .13748 L
.20717 .13873 L
s
.20717 .13748 m
.22785 .13748 L
.22785 .13873 L
.20717 .13873 L
.20717 .13748 L
s
.20717 .13873 m
.22785 .13873 L
.22785 .1424 L
.20717 .1424 L
.20717 .13873 L
s
.20717 .1424 m
.22785 .1424 L
.22785 .14822 L
.20717 .14822 L
.20717 .1424 L
s
.20717 .14822 m
.22785 .14822 L
.22785 .15582 L
.20717 .15582 L
.20717 .14822 L
s
.20717 .15582 m
.22785 .15582 L
.22785 .16466 L
.20717 .16466 L
.20717 .15582 L
s
.20717 .16466 m
.22785 .16466 L
.22785 .17416 L
.20717 .17416 L
.20717 .16466 L
s
.20717 .17416 m
.22785 .17416 L
.22785 .18365 L
.20717 .18365 L
.20717 .17416 L
s
.20717 .18365 m
.22785 .18365 L
.22785 .19249 L
.20717 .19249 L
.20717 .18365 L
s
.20717 .19249 m
.22785 .19249 L
.22785 .20009 L
.20717 .20009 L
.20717 .19249 L
s
.20717 .20009 m
.22785 .20009 L
.22785 .20592 L
.20717 .20592 L
.20717 .20009 L
s
.20717 .20592 m
.22785 .20592 L
.22785 .20958 L
.20717 .20958 L
.20717 .20592 L
s
.20717 .20958 m
.22785 .20958 L
.22785 .21083 L
.20717 .21083 L
.20717 .20958 L
s
.5 g
.68892 .11915 m
.70775 .11915 L
.70775 .13748 L
.68613 .13748 L
.68892 .11915 L
F
.68613 .13748 m
.70775 .13748 L
.70775 .15582 L
.68446 .15582 L
.68613 .13748 L
F
.68446 .15582 m
.70775 .15582 L
.70775 .17416 L
.68391 .17416 L
.68446 .15582 L
F
.68391 .17416 m
.70775 .17416 L
.70775 .19249 L
.68446 .19249 L
.68391 .17416 L
F
.68446 .19249 m
.70775 .19249 L
.70775 .21083 L
.68613 .21083 L
.68446 .19249 L
F
.68613 .21083 m
.70775 .21083 L
.70775 .22916 L
.68892 .22916 L
.68613 .21083 L
F
0 g
.68892 .11915 m
.68613 .13748 L
.68446 .15582 L
.68391 .17416 L
.68446 .19249 L
.68613 .21083 L
.68892 .22916 L
.70775 .22916 L
.70775 .21083 L
.70775 .19249 L
.70775 .17416 L
.70775 .15582 L
.70775 .13748 L
.70775 .11915 L
.68892 .11915 L
s
.5 g
.68892 .17416 m
.70775 .17416 L
.70775 .17416 L
.68613 .17416 L
.68892 .17416 L
F
.68613 .17416 m
.70775 .17416 L
.70775 .17416 L
.68446 .17416 L
.68613 .17416 L
F
.68446 .17416 m
.70775 .17416 L
.70775 .17416 L
.68391 .17416 L
.68446 .17416 L
F
.68391 .17416 m
.70775 .17416 L
.70775 .17416 L
.68446 .17416 L
.68391 .17416 L
F
.68446 .17416 m
.70775 .17416 L
.70775 .17416 L
.68613 .17416 L
.68446 .17416 L
F
.68613 .17416 m
.70775 .17416 L
.70775 .17416 L
.68892 .17416 L
.68613 .17416 L
F
0 g
.68892 .17416 m
.68613 .17416 L
.68446 .17416 L
.68391 .17416 L
.68446 .17416 L
.68613 .17416 L
.68892 .17416 L
.70775 .17416 L
.70775 .17416 L
.70775 .17416 L
.70775 .17416 L
.70775 .17416 L
.70775 .17416 L
.70775 .17416 L
.68892 .17416 L
s
.68892 .22916 m
.70775 .22916 L
.70775 .22729 L
.68892 .22729 L
.68892 .22916 L
s
.68892 .22729 m
.70775 .22729 L
.70775 .22179 L
.68892 .22179 L
.68892 .22729 L
s
.68892 .22179 m
.70775 .22179 L
.70775 .21305 L
.68892 .21305 L
.68892 .22179 L
s
.68892 .21305 m
.70775 .21305 L
.70775 .20166 L
.68892 .20166 L
.68892 .21305 L
s
.68892 .20166 m
.70775 .20166 L
.70775 .18839 L
.68892 .18839 L
.68892 .20166 L
s
.68892 .18839 m
.70775 .18839 L
.70775 .17416 L
.68892 .17416 L
.68892 .18839 L
s
.68892 .17416 m
.70775 .17416 L
.70775 .15992 L
.68892 .15992 L
.68892 .17416 L
s
.68892 .15992 m
.70775 .15992 L
.70775 .14665 L
.68892 .14665 L
.68892 .15992 L
s
.68892 .14665 m
.70775 .14665 L
.70775 .13526 L
.68892 .13526 L
.68892 .14665 L
s
.68892 .13526 m
.70775 .13526 L
.70775 .12652 L
.68892 .12652 L
.68892 .13526 L
s
.68892 .12652 m
.70775 .12652 L
.70775 .12102 L
.68892 .12102 L
.68892 .12652 L
s
.68892 .12102 m
.70775 .12102 L
.70775 .11915 L
.68892 .11915 L
.68892 .12102 L
s
.68892 .11915 m
.70775 .11915 L
.70775 .12102 L
.68892 .12102 L
.68892 .11915 L
s
.68892 .12102 m
.70775 .12102 L
.70775 .12652 L
.68892 .12652 L
.68892 .12102 L
s
.68892 .12652 m
.70775 .12652 L
.70775 .13526 L
.68892 .13526 L
.68892 .12652 L
s
.68892 .13526 m
.70775 .13526 L
.70775 .14665 L
.68892 .14665 L
.68892 .13526 L
s
.68892 .14665 m
.70775 .14665 L
.70775 .15992 L
.68892 .15992 L
.68892 .14665 L
s
.68892 .15992 m
.70775 .15992 L
.70775 .17416 L
.68892 .17416 L
.68892 .15992 L
s
.68892 .17416 m
.70775 .17416 L
.70775 .18839 L
.68892 .18839 L
.68892 .17416 L
s
.68892 .18839 m
.70775 .18839 L
.70775 .20166 L
.68892 .20166 L
.68892 .18839 L
s
.68892 .20166 m
.70775 .20166 L
.70775 .21305 L
.68892 .21305 L
.68892 .20166 L
s
.68892 .21305 m
.70775 .21305 L
.70775 .22179 L
.68892 .22179 L
.68892 .21305 L
s
.68892 .22179 m
.70775 .22179 L
.70775 .22729 L
.68892 .22729 L
.68892 .22179 L
s
.68892 .22729 m
.70775 .22729 L
.70775 .22916 L
.68892 .22916 L
.68892 .22729 L
s
.5 g
.90505 .04131 m
.90505 .04131 L
.9169 .0856 L
.9169 .0856 L
.90505 .04131 L
F
.9169 .0856 m
.9169 .0856 L
.92876 .12988 L
.92876 .12988 L
.9169 .0856 L
F
.92876 .12988 m
.92876 .12988 L
.94062 .17416 L
.94062 .17416 L
.92876 .12988 L
F
.94062 .17416 m
.94062 .17416 L
.95248 .21844 L
.95248 .21844 L
.94062 .17416 L
F
.95248 .21844 m
.95248 .21844 L
.96433 .26272 L
.96433 .26272 L
.95248 .21844 L
F
.96433 .26272 m
.96433 .26272 L
.97619 .307 L
.97619 .307 L
.96433 .26272 L
F
0 g
.90505 .04131 m
.9169 .0856 L
.92876 .12988 L
.94062 .17416 L
.95248 .21844 L
.96433 .26272 L
.97619 .307 L
.97619 .307 L
.96433 .26272 L
.95248 .21844 L
.94062 .17416 L
.92876 .12988 L
.9169 .0856 L
.90505 .04131 L
.90505 .04131 L
s
.5 g
.94062 .17416 m
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
F
.94062 .17416 m
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
F
.94062 .17416 m
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
F
.94062 .17416 m
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
F
.94062 .17416 m
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
F
.94062 .17416 m
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
F
0 g
.94062 .17416 m
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
s
.5 g
.94062 .17416 m
.95248 .21844 L
.95207 .21693 L
.94062 .17416 L
.94062 .17416 L
F
.95248 .21844 m
.96433 .26272 L
.96353 .2597 L
.95207 .21693 L
.95248 .21844 L
F
.96433 .26272 m
.97619 .307 L
.97498 .30247 L
.96353 .2597 L
.96433 .26272 L
F
.94062 .17416 m
.95207 .21693 L
.95089 .2125 L
.94062 .17416 L
.94062 .17416 L
F
.95207 .21693 m
.96353 .2597 L
.96116 .25085 L
.95089 .2125 L
.95207 .21693 L
F
.96353 .2597 m
.97498 .30247 L
.97142 .2892 L
.96116 .25085 L
.96353 .2597 L
F
.94062 .17416 m
.95089 .2125 L
.949 .20547 L
.94062 .17416 L
.94062 .17416 L
F
.95089 .2125 m
.96116 .25085 L
.95739 .23678 L
.949 .20547 L
.95089 .2125 L
F
.96116 .25085 m
.97142 .2892 L
.96577 .26809 L
.95739 .23678 L
.96116 .25085 L
F
.94062 .17416 m
.949 .20547 L
.94655 .1963 L
.94062 .17416 L
.94062 .17416 L
F
.949 .20547 m
.95739 .23678 L
.95248 .21844 L
.94655 .1963 L
.949 .20547 L
F
.95739 .23678 m
.96577 .26809 L
.9584 .24058 L
.95248 .21844 L
.95739 .23678 L
F
.94062 .17416 m
.94655 .1963 L
.94369 .18562 L
.94062 .17416 L
.94062 .17416 L
F
.94655 .1963 m
.95248 .21844 L
.94676 .19708 L
.94369 .18562 L
.94655 .1963 L
F
.95248 .21844 m
.9584 .24058 L
.94983 .20854 L
.94676 .19708 L
.95248 .21844 L
F
.94062 .17416 m
.94369 .18562 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
F
.94369 .18562 m
.94676 .19708 L
.94062 .17416 L
.94062 .17416 L
.94369 .18562 L
F
.94676 .19708 m
.94983 .20854 L
.94062 .17416 L
.94062 .17416 L
.94676 .19708 L
F
.94062 .17416 m
.94062 .17416 L
.93755 .1627 L
.94062 .17416 L
.94062 .17416 L
F
.94062 .17416 m
.94062 .17416 L
.93448 .15123 L
.93755 .1627 L
.94062 .17416 L
F
.94062 .17416 m
.94062 .17416 L
.93141 .13977 L
.93448 .15123 L
.94062 .17416 L
F
.94062 .17416 m
.93755 .1627 L
.93469 .15202 L
.94062 .17416 L
.94062 .17416 L
F
.93755 .1627 m
.93448 .15123 L
.92876 .12988 L
.93469 .15202 L
.93755 .1627 L
F
.93448 .15123 m
.93141 .13977 L
.92283 .10774 L
.92876 .12988 L
.93448 .15123 L
F
.94062 .17416 m
.93469 .15202 L
.93223 .14285 L
.94062 .17416 L
.94062 .17416 L
F
.93469 .15202 m
.92876 .12988 L
.92385 .11153 L
.93223 .14285 L
.93469 .15202 L
F
.92876 .12988 m
.92283 .10774 L
.91547 .08022 L
.92385 .11153 L
.92876 .12988 L
F
.94062 .17416 m
.93223 .14285 L
.93035 .13581 L
.94062 .17416 L
.94062 .17416 L
F
.93223 .14285 m
.92385 .11153 L
.92008 .09746 L
.93035 .13581 L
.93223 .14285 L
F
.92385 .11153 m
.91547 .08022 L
.90981 .05911 L
.92008 .09746 L
.92385 .11153 L
F
.94062 .17416 m
.93035 .13581 L
.92917 .13138 L
.94062 .17416 L
.94062 .17416 L
F
.93035 .13581 m
.92008 .09746 L
.91771 .08861 L
.92917 .13138 L
.93035 .13581 L
F
.92008 .09746 m
.90981 .05911 L
.90626 .04584 L
.91771 .08861 L
.92008 .09746 L
F
.94062 .17416 m
.92917 .13138 L
.92876 .12988 L
.94062 .17416 L
.94062 .17416 L
F
.92917 .13138 m
.91771 .08861 L
.9169 .0856 L
.92876 .12988 L
.92917 .13138 L
F
.91771 .08861 m
.90626 .04584 L
.90505 .04131 L
.9169 .0856 L
.91771 .08861 L
F
.94062 .17416 m
.92876 .12988 L
.92917 .13138 L
.94062 .17416 L
.94062 .17416 L
F
.92876 .12988 m
.9169 .0856 L
.91771 .08861 L
.92917 .13138 L
.92876 .12988 L
F
.9169 .0856 m
.90505 .04131 L
.90626 .04584 L
.91771 .08861 L
.9169 .0856 L
F
.94062 .17416 m
.92917 .13138 L
.93035 .13581 L
.94062 .17416 L
.94062 .17416 L
F
.92917 .13138 m
.91771 .08861 L
.92008 .09746 L
.93035 .13581 L
.92917 .13138 L
F
.91771 .08861 m
.90626 .04584 L
.90981 .05911 L
.92008 .09746 L
.91771 .08861 L
F
.94062 .17416 m
.93035 .13581 L
.93223 .14285 L
.94062 .17416 L
.94062 .17416 L
F
.93035 .13581 m
.92008 .09746 L
.92385 .11153 L
.93223 .14285 L
.93035 .13581 L
F
.92008 .09746 m
.90981 .05911 L
.91547 .08022 L
.92385 .11153 L
.92008 .09746 L
F
.94062 .17416 m
.93223 .14285 L
.93469 .15202 L
.94062 .17416 L
.94062 .17416 L
F
.93223 .14285 m
.92385 .11153 L
.92876 .12988 L
.93469 .15202 L
.93223 .14285 L
F
.92385 .11153 m
.91547 .08022 L
.92283 .10774 L
.92876 .12988 L
.92385 .11153 L
F
.94062 .17416 m
.93469 .15202 L
.93755 .1627 L
.94062 .17416 L
.94062 .17416 L
F
.93469 .15202 m
.92876 .12988 L
.93448 .15123 L
.93755 .1627 L
.93469 .15202 L
F
.92876 .12988 m
.92283 .10774 L
.93141 .13977 L
.93448 .15123 L
.92876 .12988 L
F
.94062 .17416 m
.93755 .1627 L
.94062 .17416 L
.94062 .17416 L
.94062 .17416 L
F
.93755 .1627 m
.93448 .15123 L
.94062 .17416 L
.94062 .17416 L
.93755 .1627 L
F
.93448 .15123 m
.93141 .13977 L
.94062 .17416 L
.94062 .17416 L
.93448 .15123 L
F
.94062 .17416 m
.94062 .17416 L
.94369 .18562 L
.94062 .17416 L
.94062 .17416 L
F
.94062 .17416 m
.94062 .17416 L
.94676 .19708 L
.94369 .18562 L
.94062 .17416 L
F
.94062 .17416 m
.94062 .17416 L
.94983 .20854 L
.94676 .19708 L
.94062 .17416 L
F
.94062 .17416 m
.94369 .18562 L
.94655 .1963 L
.94062 .17416 L
.94062 .17416 L
F
.94369 .18562 m
.94676 .19708 L
.95248 .21844 L
.94655 .1963 L
.94369 .18562 L
F
.94676 .19708 m
.94983 .20854 L
.9584 .24058 L
.95248 .21844 L
.94676 .19708 L
F
.94062 .17416 m
.94655 .1963 L
.949 .20547 L
.94062 .17416 L
.94062 .17416 L
F
.94655 .1963 m
.95248 .21844 L
.95739 .23678 L
.949 .20547 L
.94655 .1963 L
F
.95248 .21844 m
.9584 .24058 L
.96577 .26809 L
.95739 .23678 L
.95248 .21844 L
F
.94062 .17416 m
.949 .20547 L
.95089 .2125 L
.94062 .17416 L
.94062 .17416 L
F
.949 .20547 m
.95739 .23678 L
.96116 .25085 L
.95089 .2125 L
.949 .20547 L
F
.95739 .23678 m
.96577 .26809 L
.97142 .2892 L
.96116 .25085 L
.95739 .23678 L
F
.94062 .17416 m
.95089 .2125 L
.95207 .21693 L
.94062 .17416 L
.94062 .17416 L
F
.95089 .2125 m
.96116 .25085 L
.96353 .2597 L
.95207 .21693 L
.95089 .2125 L
F
.96116 .25085 m
.97142 .2892 L
.97498 .30247 L
.96353 .2597 L
.96116 .25085 L
F
.94062 .17416 m
.95207 .21693 L
.95248 .21844 L
.94062 .17416 L
.94062 .17416 L
F
.95207 .21693 m
.96353 .2597 L
.96433 .26272 L
.95248 .21844 L
.95207 .21693 L
F
.96353 .2597 m
.97498 .30247 L
.97619 .307 L
.96433 .26272 L
.96353 .2597 L
F
0 g
.97619 .307 m
.97498 .30247 L
.97142 .2892 L
.96577 .26809 L
.9584 .24058 L
.94983 .20854 L
.94062 .17416 L
.93141 .13977 L
.92283 .10774 L
.91547 .08022 L
.90981 .05911 L
.90626 .04584 L
.90505 .04131 L
.90626 .04584 L
.90981 .05911 L
.91547 .08022 L
.92283 .10774 L
.93141 .13977 L
.94062 .17416 L
.94983 .20854 L
.9584 .24058 L
.96577 .26809 L
.97142 .2892 L
.97498 .30247 L
.97619 .307 L
s
.50969 .52861 m
.49442 .50214 L
.47915 .47567 L
.46388 .4492 L
.44861 .42273 L
.43333 .39626 L
.41806 .36979 L
.41806 .36979 L
.43333 .39626 L
.44861 .42273 L
.46388 .4492 L
.47915 .47567 L
.49442 .50214 L
.50969 .52861 L
.50969 .52861 L
s
.46388 .4492 m
.46388 .4492 L
.46388 .4492 L
.46388 .4492 L
.46388 .4492 L
.46388 .4492 L
.46388 .4492 L
.46388 .4492 L
.46388 .4492 L
.46388 .4492 L
.46388 .4492 L
.46388 .4492 L
.46388 .4492 L
.46388 .4492 L
.46388 .4492 L
s
.41806 .36979 m
.41962 .37249 L
.4242 .38043 L
.43148 .39305 L
.44097 .40949 L
.45202 .42865 L
.46388 .4492 L
.47574 .46975 L
.48679 .48891 L
.49627 .50535 L
.50355 .51797 L
.50813 .52591 L
.50969 .52861 L
.50813 .52591 L
.50355 .51797 L
.49627 .50535 L
.48679 .48891 L
.47574 .46975 L
.46388 .4492 L
.45202 .42865 L
.44097 .40949 L
.43148 .39305 L
.4242 .38043 L
.41962 .37249 L
.41806 .36979 L
s
.039 .916 .04 r
.02381 .16866 m
.20717 .16866 L
s
% Start of user PostScript
-50. -1.5 0 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20717 .16866 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17416 m
.20717 .17416 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20717 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17966 m
.20717 .17966 L
s
% Start of user PostScript
-50. 1.5 0 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20717 .17966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16866 m
.20717 .16866 L
s
% Start of user PostScript
-50. -1.5 0 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20717 .16866 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17416 m
.20717 .17416 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20717 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17966 m
.20717 .17966 L
s
% Start of user PostScript
-50. 1.5 0 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20717 .17966 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16866 m
.20717 .16866 L
s
% Start of user PostScript
-50. -1.5 0 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20717 .16866 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17416 m
.20717 .17416 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20717 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17966 m
.20717 .17966 L
s
% Start of user PostScript
-50. 1.5 0 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20717 .17966 Mdot
.039 .916 .04 r
.5 Mabswid
.20717 .16866 m
.21504 .16866 L
s
% Start of user PostScript
0 -1.5 2.14526 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21504 .16866 Mdot
.039 .916 .04 r
.5 Mabswid
.20717 .17416 m
.21477 .17416 L
s
% Start of user PostScript
0 0 2.07246 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21477 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.20717 .17966 m
.21504 .17966 L
s
% Start of user PostScript
0 1.5 2.14526 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21504 .17966 Mdot
.039 .916 .04 r
.5 Mabswid
.20717 .16866 m
.21477 .16866 L
s
% Start of user PostScript
0 -1.5 2.07246 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21477 .16866 Mdot
.039 .916 .04 r
.5 Mabswid
.20717 .17416 m
.21451 .17416 L
s
% Start of user PostScript
0 0 2. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21451 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.20717 .17966 m
.21477 .17966 L
s
% Start of user PostScript
0 1.5 2.07246 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21477 .17966 Mdot
.039 .916 .04 r
.5 Mabswid
.20717 .16866 m
.21504 .16866 L
s
% Start of user PostScript
0 -1.5 2.14526 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21504 .16866 Mdot
.039 .916 .04 r
.5 Mabswid
.20717 .17416 m
.21477 .17416 L
s
% Start of user PostScript
0 0 2.07246 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21477 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.20717 .17966 m
.21504 .17966 L
s
% Start of user PostScript
0 1.5 2.14526 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.21504 .17966 Mdot
.039 .916 .04 r
.5 Mabswid
.21504 .16866 m
.68679 .14465 L
s
% Start of user PostScript
2.14526 -1.5 130.784 -8.04599 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68679 .14465 Mdot
.039 .916 .04 r
.5 Mabswid
.21477 .17416 m
.68532 .17416 L
s
% Start of user PostScript
2.07246 0 130.384 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68532 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.21504 .17966 m
.68679 .20366 L
s
% Start of user PostScript
2.14526 1.5 130.784 8.04599 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68679 .20366 Mdot
.039 .916 .04 r
.5 Mabswid
.21477 .16866 m
.68532 .14491 L
s
% Start of user PostScript
2.07246 -1.5 130.384 -7.97386 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68532 .14491 Mdot
.039 .916 .04 r
.5 Mabswid
.21451 .17416 m
.68391 .17416 L
s
% Start of user PostScript
2. 0 130. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68391 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.21477 .17966 m
.68532 .2034 L
s
% Start of user PostScript
2.07246 1.5 130.384 7.97386 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68532 .2034 Mdot
.039 .916 .04 r
.5 Mabswid
.21504 .16866 m
.68679 .14465 L
s
% Start of user PostScript
2.14526 -1.5 130.784 -8.04599 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68679 .14465 Mdot
.039 .916 .04 r
.5 Mabswid
.21477 .17416 m
.68532 .17416 L
s
% Start of user PostScript
2.07246 0 130.384 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68532 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.21504 .17966 m
.68679 .20366 L
s
% Start of user PostScript
2.14526 1.5 130.784 8.04599 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68679 .20366 Mdot
.039 .916 .04 r
.5 Mabswid
.68679 .14465 m
.70775 .14465 L
s
% Start of user PostScript
130.784 -8.04599 136.5 -8.04487 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70775 .14465 Mdot
.039 .916 .04 r
.5 Mabswid
.68532 .17416 m
.70775 .17416 L
s
% Start of user PostScript
130.384 0 136.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70775 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.68679 .20366 m
.70775 .20366 L
s
% Start of user PostScript
130.784 8.04599 136.5 8.04487 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70775 .20366 Mdot
.039 .916 .04 r
.5 Mabswid
.68532 .14491 m
.70775 .14491 L
s
% Start of user PostScript
130.384 -7.97386 136.5 -7.97453 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70775 .14491 Mdot
.039 .916 .04 r
.5 Mabswid
.68391 .17416 m
.70775 .17416 L
s
% Start of user PostScript
130. 0 136.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70775 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.68532 .2034 m
.70775 .2034 L
s
% Start of user PostScript
130.384 7.97386 136.5 7.97453 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70775 .2034 Mdot
.039 .916 .04 r
.5 Mabswid
.68679 .14465 m
.70775 .14465 L
s
% Start of user PostScript
130.784 -8.04599 136.5 -8.04487 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70775 .14465 Mdot
.039 .916 .04 r
.5 Mabswid
.68532 .17416 m
.70775 .17416 L
s
% Start of user PostScript
130.384 0 136.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70775 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.68679 .20366 m
.70775 .20366 L
s
% Start of user PostScript
130.784 8.04599 136.5 8.04487 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.70775 .20366 Mdot
.039 .916 .04 r
.5 Mabswid
.70775 .14465 m
.93274 .14472 L
s
% Start of user PostScript
136.5 -8.04487 197.851 -8.02663 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.93274 .14472 Mdot
.039 .916 .04 r
.5 Mabswid
.70775 .17416 m
.94062 .17416 L
s
% Start of user PostScript
136.5 0 200. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.94062 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.70775 .20366 m
.9485 .20359 L
s
% Start of user PostScript
136.5 8.04487 202.149 8.02535 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.9485 .20359 Mdot
.039 .916 .04 r
.5 Mabswid
.70775 .14491 m
.93278 .14487 L
s
% Start of user PostScript
136.5 -7.97453 197.862 -7.98472 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.93278 .14487 Mdot
.039 .916 .04 r
.5 Mabswid
.70775 .17416 m
.94062 .17416 L
s
% Start of user PostScript
136.5 0 200. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.94062 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.70775 .2034 m
.94846 .20344 L
s
% Start of user PostScript
136.5 7.97453 202.138 7.98544 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.94846 .20344 Mdot
.039 .916 .04 r
.5 Mabswid
.70775 .14465 m
.93274 .14472 L
s
% Start of user PostScript
136.5 -8.04487 197.851 -8.02663 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.93274 .14472 Mdot
.039 .916 .04 r
.5 Mabswid
.70775 .17416 m
.94062 .17416 L
s
% Start of user PostScript
136.5 0 200. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.94062 .17416 Mdot
.039 .916 .04 r
.5 Mabswid
.70775 .20366 m
.9485 .20359 L
s
% Start of user PostScript
136.5 8.04487 202.149 8.02535 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.9485 .20359 Mdot
.039 .916 .04 r
.5 Mabswid
.93274 .14472 m
.44925 .42385 L
s
% Start of user PostScript
197.851 -8.02663 66.0115 68.0867 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.44925 .42385 Mdot
.039 .916 .04 r
.5 Mabswid
.94062 .17416 m
.46388 .4492 L
s
% Start of user PostScript
200. 0 70. 75. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46388 .4492 Mdot
.039 .916 .04 r
.5 Mabswid
.9485 .20359 m
.4785 .47455 L
s
% Start of user PostScript
202.149 8.02535 73.9885 81.9133 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.4785 .47455 Mdot
.039 .916 .04 r
.5 Mabswid
.93278 .14487 m
.4492 .42375 L
s
% Start of user PostScript
197.862 -7.98472 65.9972 68.0618 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.4492 .42375 Mdot
.039 .916 .04 r
.5 Mabswid
.94062 .17416 m
.46388 .4492 L
s
% Start of user PostScript
200. 0 70. 75. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46388 .4492 Mdot
.039 .916 .04 r
.5 Mabswid
.94846 .20344 m
.47856 .47464 L
s
% Start of user PostScript
202.138 7.98544 74.0028 81.9382 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.47856 .47464 Mdot
.039 .916 .04 r
.5 Mabswid
.93274 .14472 m
.44925 .42385 L
s
% Start of user PostScript
197.851 -8.02663 66.0115 68.0867 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.44925 .42385 Mdot
.039 .916 .04 r
.5 Mabswid
.94062 .17416 m
.46388 .4492 L
s
% Start of user PostScript
200. 0 70. 75. MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46388 .4492 Mdot
.039 .916 .04 r
.5 Mabswid
.9485 .20359 m
.4785 .47455 L
s
% Start of user PostScript
202.149 8.02535 73.9885 81.9133 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.4785 .47455 Mdot
[(L1)] .21084 .10869 0 0 Mshowa
[(L2)] .69583 .09035 0 0 Mshowa
[(M)] .8976 .0135 0 0 Mshowa
[(S)] .52408 .55355 0 0 Mshowa
0 0 m
1 0 L
1 .56705 L
0 .56705 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{288, 163.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Xb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00noooool3o`000003ooooool0003ooooo00?o00007?ooool00?cooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Kooooo`00o?ooool01ol0003ooooo
o`000?oooooo0000ooooool000007Oooool00?cooooo00Oo0000ooooool0003oooooo`000?oooooo
000001gooooo003looooo`;o00000oooool2o`0001gooooo003looooo`;o00000oooool2o`0001go
oooo003kooooo`;o00001Oooool2o`0001cooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooo`?ooooo00?o0000ooooooooool06oooool00?oooooo0oooool00ol0003ooooo
ooooo`0Kooooo`00ooooool3ooooo`03o`000?oooooooooo01_ooooo003oooooo`?ooooo00?o0000
ooooooooool06oooool00?oooooo0oooool2o`0001cooooo003oooooo`Cooooo00?o0000oooooooo
ool06_ooool00?oooooo1?ooool00ol0003oooooooooo`0Jooooo`00ooooool4ooooo`03o`000?oo
oooooooo01[ooooo003oooooo`Cooooo00?oOgmoo`000?ooool06_ooool00?oooooo1Oooool00ol0
003oooooooooo`0Iooooo`00ooooool5ooooo`03o`000?oooooooooo01Wooooo003oooooo`Gooooo
00?oOgmoo`000?ooool06Oooool00<7ooooo2Ol0000kooooo`03o`000?oooooooooo01Sooooo0032
ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo01Sooooo0032ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Hooooo`00`_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03[ooooo00?oOgmoo`000?ooool06?ooool00<;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo01Oooooo000gooooo`Ko000000Coooooo`000?l0003o
0000POooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000003cooooo00?o0000oooooooo
ool05oooool003Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo07oo
oooo0ol00004ooooo`03o`000?oooooooooo03_ooooo00?oOgmoo`000?ooool05oooool003Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`34ooooo`03ogmoOol0003ooooo01Oooooo
000hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0aOooool00ol0003ooooooooo
o`0Fooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<Gooooo00?o0000
ooooooooool05_ooool003Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`35oooo
o`03ogmoOol0003ooooo01Kooooo000gooooo`?o00001?ooool2o`0008Gooooo1_l0000mooooo`03
o`000?oooooooooo01Gooooo0035ooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Eooooo`00aOooool6o`0003gooooo0_l0000Fooooo`00a?ooool2
o`0000CoOgmo00?o0000ooooooooool0>oooool2o`0001Kooooo0034ooooo`Oo0000?_ooool00ol0
003oooooooooo`0Dooooo`00??ooool7o`0007Sooooo1?l9jPX3ooooo`?o2NX:00?o0000ogmoOomo
Ogl00_moOgl00ol0003oooooooooo`0eooooo`?o2NX:1?ooool00ol0003oooooooooo`0Dooooo`00
??ooool7o`0007[ooooo3?l9jPX2o`0003Sooooo1_l9jPX2o`0001Gooooo000looooo`03o`000?mo
OgooOgmo00;oOgmo0_l0001gooooo`oo2NX:00?o0000o`WZ2_l9jPX0?ol9jPXEooooo`00??ooool7
o`0006Cooooo4ol9jPX3ooooo`Go2NX:00?oooooo`WZ2_l9jPX00ol9jPX3o`0003Sooooo1_l9jPX2
o`0001Gooooo000looooo`07o`000?moOgooOgmoogmoOol0003oooooo`00001Aoooooa?o2NX:5Ooo
ool2o`WZ2PCooooo0_l9jPX00omoOgoo0000ogmoO`03ogmoO`03o`000?oooooooooo03Gooooo0_l9
jPX2ooooo`05o`WZ2_ooooooooooooooool000005Oooool003cooooo1ol0000noooooa?o2NX:;ooo
ool00ol0003oOgmoo`000004ogmoO`03o`000?oooooooooo03Oooooo0_l9jPX4ooooo`;o00005?oo
ool003cooooo00Co0000ogmoOomoOgoo00000_ooool00ol0003oooooooooo`0Yoooooa?o2NX:@_oo
ool00ol0003oOgmoo`000005o`0003Oooooo0_l9jPX7ooooo`03o`000?oooooooooo01;ooooo000d
ooooo`Go2NX:0oooool00ol0003oOgmoo`000003ooooo`03o`000?oooooooooo01Kooooo4ol9jPYE
ooooo`03o`000?moOgoo000000CoOgmo00?o0000ooooooooool0<oooool2o`WZ2PWooooo00?o0000
ooooooooool04_ooool003Cooooo2Ol9jPX6o`0000Gooooo4ol9jPYPooooo`Co2NX:0oooool3o`WZ
2P03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0<_ooool00ol9jP[oooooooooo`02oooo
o`?o2NX:1?ooool00ol0003oooooooooo`0Booooo`002?oooom0o`WZ2WCooooo3Ol9jPX00omoOgoo
0000ooooo`0aooooo`;o2NX:1_ooool6o`WZ2P03ooooool0003ooooo01;ooooo0008oooool7o2NX:
00?o0000o`WZ2_l9jPX0@Ol9jPX00ol0003oooooooooo`0@ooooo`00=?ooool9o`WZ2P?o00000_oo
ool00ol0003oooooooooo`1gooooo`Ko2NX:00?oooooo`WZ2_l9jPX00ol9jPX00omoOgoo0000o`00
000_ooooo`03o`WZ2_oooooooooo00Sooooo1_l9jPX00ooooooo0000o`00000Booooo`002?oooom1
o`WZ2W;ooooo0ol9jPX4ooooo`;o2NX:00?oOgmoo`000?moOgl00omoOgl00ol0003oooooooooo`0[
ooooo`;o2NX:2_ooool2o`WZ2P;ooooo00Go2NX:ooooooooooooooooo`00000Cooooo`00=Oooool7
o`WZ2POo00001_oooolCo`WZ2VOooooo00?o0000ogmoOol000001?moOgl00ol0003oooooooooo`0Y
ooooo`;o2NX:3_ooool2o`WZ2PGooooo00?o0000ooooooooool04?ooool003Cooooo1?l9jPX4oooo
o`03o`000?moOgoo000000?ooooo00?o0000ooooooooool05ooooolCo`WZ2UCooooo00?o0000ogmo
Ool000001Ol0000Yooooo`;o2NX:3_ooool2o`WZ2POooooo00?o0000ooooooooool04?ooool003co
oooo00?o0000ogmoOol000000oooool00ol0003oooooooooo`0Zoooooa?o2NX:@Oooool00ol0003o
Ogmoo`000004ogmoO`03o`000?oooooooooo02Kooooo00?o2NX:ooooooooool03?ooool2o`WZ2PWo
oooo00?o0000ooooooooool04?ooool003cooooo1ol0000ooooooa?o2NX:9oooool2o`WZ2PGooooo
00?o0000ogmoOol000001?moOgl00ol0003oooooooooo`0Tooooo`;o2NX:3_ooool00ol9jP[ooooo
ooooo`09ooooo`03ogmoOol0003ooooo013ooooo000looooo`07o`000?moOgooOgmoogmoOol0003o
ooooo`00001Boooooa?o2NX:5Oooool4o`WZ2P05ooooool9jP[o2NX:o`WZ2_l000001?moOgl00ol0
003oooooooooo`0Rooooo`;o2NX:3_ooool2o`WZ2PGooooo0ol9jPX4ooooo`03ogmoOol0003ooooo
013ooooo000looooo`Oo0000IOoooolCo`WZ2P;ooooo3?l9jPX2o`0002;ooooo0_l9jPX>ooooo`;o
2NX:2?ooool6o`WZ2P03ooooool0003o0000013ooooo000looooo`Oo0000N?ooool>o`WZ2P03o`00
0?l9jP[o2NX:04?o2NX:00?o0000ooooooooool03_ooool003cooooo1ol0001hooooo`Go2NX:0ooo
ool5o`WZ2P;oOgmo00?o0000ooooooooool07Oooool2o`WZ2Pkooooo0_l9jPX;ooooo`Ko2NX:00?o
ooooogmoOol000004?ooool003cooooo1ol0001oooooo`;o2NX:1ol0000Mooooo`;o2NX:3_ooool2
o`WZ2Pcooooo0_l9jPX2ooooo`06o`WZ2_oooooooooooooooomoOgoo00004?ooool00<Cooooo0_l0
0004ogmoO`03o`000?oooooooooo01Wooooo0_l9jPX>ooooo`;o2NX:4?ooool2o`WZ2PGooooo00?o
0000ooooooooool03_ooool00<Cooooo0_l00004ogmoO`03o`000?oooooooooo01Sooooo00?o2NX:
ooooooooool03Oooool00ol9jP[oooooooooo`0>ooooo`;o2NX:1oooool00omoOgoo0000ooooo`0>
ooooo`00aOooool6o`0001Sooooo0_l9jPX>ooooo`;o2NX:3oooool2o`WZ2PWooooo00?oOgmoo`00
0?ooool03_ooool00<Gooooo1_l0000Fooooo`;o2NX:3_ooool2o`WZ2Q3ooooo00?o2NX:oooooooo
ool02_ooool00ol0003oooooooooo`0=ooooo`00aOooool6o`0001Gooooo00?o2NX:ooooooooool0
3?ooool2o`WZ2Q3ooooo0_l9jPX=ooooo`03o`000?oooooooooo00gooooo003Nooooo`;o2NX:3_oo
ool00ol9jP[oooooooooo`0>ooooo`;o2NX:3oooool00ol0003oooooooooo`0=ooooo`00g?ooool2
o`WZ2Pkooooo0_l9jPX@ooooo`03o`WZ2_oooooooooo013ooooo00?o0000ooooooooool03?ooool0
0=[ooooo0_l9jPX>ooooo`;o2NX:4?ooool2o`WZ2Q?ooooo00?o0000ooooooooool03?ooool00=Wo
oooo00?o2NX:ooooooooool03Oooool00ol9jP[oooooooooo`0>ooooo`;o2NX:5Oooool00ol0003o
ooooooooo`0<ooooo`00eoooool2o`WZ2Pkooooo0_l9jPX?ooooo`;o2NX:5oooool2o`0000gooooo
003Eooooo`;o2NX:3_ooool2o`WZ2Q3ooooo00?o2NX:ooooooooool06?ooool00ol0003ooooooooo
o`0;ooooo`00doooool2o`WZ2Pkooooo0_l9jPX@ooooo`;o2NX:6oooool00ol0003oooooooooo`0;
ooooo`00d_ooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00kooooo0_l9jPXMoooo
o`;o00003?ooool00=3ooooo0_l9jPX>ooooo`;o2NX:3oooool2o`WZ2Qoooooo0_l0000<ooooo`00
c_ooool2o`WZ2Pkooooo0_l9jPX@ooooo`03o`WZ2_oooooooooo023ooooo00?o0000ooooooooool0
2_ooool00<cooooo0_l9jPX>ooooo`;o2NX:4?ooool2o`WZ2R?ooooo00?o0000ooooooooool02_oo
ool00<_ooooo00?o2NX:ooooooooool03Oooool00ol9jP[oooooooooo`0>ooooo`;o2NX:9Oooool2
o`0000_ooooo0039ooooo`;o2NX:3_ooool2o`WZ2Q3ooooo00?o2NX:ooooooooool09_ooool00ol0
003oooooooooo`09ooooo`00aoooool2o`WZ2Pkooooo0_l9jPX@ooooo`;o2NX::Oooool00ol0003o
ooooooooo`09ooooo`00aOooool2o`WZ2Pkooooo0_l9jPX@ooooo`;o2NX::oooool00ol0003ooooo
ooooo`09ooooo`00a?ooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00kooooo0_l9
jPX^ooooo`03o`000?oooooooooo00Sooooo0032ooooo`;o2NX:3_ooool2o`WZ2Q3ooooo00?o2NX:
ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`00`?ooool2o`WZ2Pkooooo0_l9jPX@oooo
o`;o2NX:<Oooool00ol0003oooooooooo`08ooooo`00_oooool00ol9jP[oooooooooo`0=ooooo`03
o`WZ2_oooooooooo00kooooo0_l9jPXcooooo`03o`000?oooooooooo00Sooooo002mooooo`;o2NX:
3_ooool2o`WZ2Poooooo0_l9jPXeooooo`03ogmoOol0003ooooo00Sooooo002kooooo`;o2NX:3_oo
ool2o`WZ2Q3ooooo00?o2NX:ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`00^Oooool2
o`WZ2Pkooooo0_l9jPX@ooooo`;o2NX:>Oooool00ol0003oooooooooo`07ooooo`00^?ooool00ol9
jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00kooooo0_l9jPY5ooooo`00]_ooool2o`WZ2Pko
oooo0_l9jPX@ooooo`03o`WZ2_oooooooooo04Gooooo002dooooo`;o2NX:3_ooool2o`WZ2Q3ooooo
0_l9jPY8ooooo`00/_ooool2o`WZ2Pkooooo0_l9jPX@ooooo`;o2NX:B_ooool00;7ooooo00?o2NX:
ooooooooool03Oooool00ol9jP[oooooooooo`0>ooooo`;o2NX:C?ooool00:oooooo0_l9jPX>oooo
o`;o2NX:4?ooool00ol9jP[oooooooooo`1<ooooo`00[Oooool2o`WZ2Pkooooo0_l9jPX@ooooo`;o
2NX:Coooool00:_ooooo0_l9jPX?ooooo`03o`WZ2_oooooooooo00kooooo0_l9jPYAooooo`00Z_oo
ool00ol9jP[oooooooooo`0=ooooo`;o2NX:3oooool2o`WZ2U?ooooo002Xooooo`;o2NX:3_ooool2
o`WZ2Q3ooooo00?o2NX:ooooooooool0Doooool00:Kooooo0_l9jPX>ooooo`;o2NX:4?ooool2o`WZ
2UKooooo002Uooooo`03o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool03_ooool2o`WZ2USo
oooo002Sooooo`;o2NX:3_ooool2o`WZ2Q3ooooo00?o2NX:ooooooooool0F?ooool00:7ooooo0_l9
jPX>ooooo`;o2NX:4?ooool2o`WZ2U_ooooo002Oooooo`;o2NX:3_ooool2o`WZ2Q3ooooo0_l9jPYM
ooooo`00W_ooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00kooooo0_l9jPYOoooo
o`00W?ooool2o`WZ2Pkooooo0_l9jPX@ooooo`03o`WZ2_oooooooooo05oooooo001hooooo`03o`00
0?oooooooooo01oooooo0_l9jPX>ooooo`;o2NX:4?ooool2o`WZ2V;ooooo001hooooo`03o`000?oo
oooooooo01gooooo0_l9jPX>ooooo`;o2NX:4?ooool2o`WZ2VCooooo001hooooo`;o00007Oooool0
0ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00kooooo0_l9jPYVooooo`00NOooool00ol0
003oooooooooo`0Iooooo`;o2NX:3_ooool2o`WZ2Q3ooooo00?o2NX:ooooooooool0I_ooool007[o
oooo00?o0000ooooooooool05_ooool2o`WZ2Pkooooo0_l9jPX@ooooo`;o2NX:JOooool007_ooooo
00?o0000ooooooooool04oooool2o`WZ2Poooooo00?o2NX:ooooooooool03_ooool2o`WZ2V_ooooo
001kooooo`;o00004oooool00ol9jP[oooooooooo`0=ooooo`;o2NX:4?ooool00ol9jP[ooooooooo
o`1[ooooo`00O?ooool00ol0003oooooooooo`0?ooooo`;o2NX:3_ooool2o`WZ2Q3ooooo0_l9jPY^
ooooo`00O?ooool2o`0000kooooo0_l9jPX>ooooo`;o2NX:4?ooool2o`WZ2W3ooooo001mooooo`03
o`000?oooooooooo00Kooooo00?o2NX:ooooooooool00_ooool00ol9jP[oooooooooo`0=ooooo`03
o`WZ2_oooooooooo00kooooo0_l9jPYbooooo`00OOooool00ol0003oooooooooo`06ooooo`03o`WZ
2_oooooooooo00;o2NX:3_ooool2o`WZ2Q3ooooo00?o2NX:ooooooooool0L_ooool007kooooo00?o
0000ooooooooool01?ooool4o`WZ2Pkooooo0_l9jPX@ooooo`;o2NX:MOooool007kooooo00?o0000
ooooooooool00oooool4o`WZ2Pgooooo0_l9jPX@ooooo`;o2NX:Moooool007oooooo00Co0000oooo
oooooooooooo1_l9jPX;ooooo`03o`WZ2_oooooooooo00kooooo0_l9jPYiooooo`00Ooooool00ol0
003oooooooooo`04o`WZ2Pcooooo0_l9jPX@ooooo`03o`WZ2_oooooooooo07Wooooo0020ooooo`;o
000000?o2NX:ooooooooool02oooool2o`WZ2Q3ooooo0_l9jPYlooooo`00P?ooool2o`0000gooooo
00?o2NX:ooooooooool03_ooool2o`WZ2Wkooooo0021ooooo`03o`000?oooooooooo00Kooooo0_l9
jPX00ooooooo2NX:o`WZ2P0@ooooo`03o`WZ2_oooooooooo07kooooo0021ooooo`;o00001_ooool4
o`WZ2Q3ooooo0_l9jPZ1ooooo`00P_ooool2o`0000Cooooo1Ol9jPX>ooooo`;o2NX:Poooool008?o
oooo00Co0000oooooooooooooooo1ol9jPX;ooooo`;o2NX:QOooool008Cooooo00?o0000ooooool9
jPX01?l9jPX=ooooo`03o`WZ2_oooooooooo08Gooooo0024ooooo`;o000000?o2NX:ooooooooool0
3Oooool2o`WZ2XSooooo0024ooooo`;o00003_ooool2o`WZ2X[ooooo0026ooooo`03o`000?oooooo
oooo00Kooooo00?o2NX:ooooooooool00_l9jPZ<ooooo`00Q_ooool00ol0003oooooooooo`05oooo
o`;o2NX:00?oooooo`WZ2_ooool0SOooool008Oooooo00?o0000ooooooooool00oooool4o`WZ2Xoo
oooo0027ooooo`03o`000?oooooooooo00;ooooo1_l9jPZ>ooooo`00R?ooool00ol0003ooooooooo
o`05o`WZ2Y3ooooo0028ooooo`;o00000ol9jPZCooooo`00R?ooool2o`0009Kooooo0029ooooo`03
o`000?oooooooooo09Cooooo002:ooooo`03o`000?oooooooooo09?ooooo002:ooooo`03o`000?oo
oooooooo09?ooooo002;ooooo`03o`000?oooooooooo09;ooooo002;ooooo`;o0000Toooool008co
oooo00?o0000ooooooooool0TOooool008gooooo00?o0000ooooooooool0T?ooool008gooooo0_l0
002Aooooo`00S_ooool00ol0003oooooooooo`2?ooooo`00Soooool00ol0003oooooooooo`2>oooo
o`00Soooool00ol0003oooooooooo`2>ooooo`00T?ooool00ol0003oooooooooo`2=ooooo`00T?oo
ool00ol0003oooooooooo`2=ooooo`00TOooool00ol0003oooooooooo`2<ooooo`00T_ooool00ol0
003oooooooooo`2;ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00U?ooool3
o`0008Wooooo002Dooooo`04o`000?ooooooooooo`0008Sooooo002Gooooo`03o`000?oooooooooo
08Kooooo002Eooooo`;o0000ROooool009Cooooo00?o0000ooooooooool0ROooool009Cooooo00Co
0000oooooooooooo0000R?ooool009Gooooo0ol00028ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {162.25, 0}} -> {-58.0456, -48.1334, 0.960945, \
0.960945}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],

Cell["\<\
sys2 = {
Move[GridOfRays[{3,3}],-50],
L1,
Move[L2,130],
MoveReflected[LensSurface[75],{130,0},{200,0},{70,75}],
Move[MoveReflected[Mirror[75],{130,0},{200,0},{70,75}],10],
MoveReflected[LensSurface[75],{130,0},{200,0},{70,75}],
MoveDirected[Screen[50],{70,75},{200,0}]};\
\>", "Input",
  CellLabel->"In[25]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],

Cell[CellGroupData[{

Cell["DrawSystem[sys2,PlotType->TopView,FormatType->OutputForm];", "Input",
  CellLabel->"In[26]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .54739 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.200373 0.00353126 0.168413 0.00353126 [
[.2039 .10467 -6 -4.5 ]
[.2039 .10467 6 4.5 ]
[.67091 .08701 -6 -4.5 ]
[.67091 .08701 6 4.5 ]
[.86502 .01303 -6 -4.5 ]
[.86502 .01303 6 4.5 ]
[.90033 .01303 -3 -4.5 ]
[.90033 .01303 3 4.5 ]
[.86502 .01303 -6 -4.5 ]
[.86502 .01303 6 4.5 ]
[.50589 .53435 -3 -4.5 ]
[.50589 .53435 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .54739 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 g
.20037 .1331 m
.22028 .1331 L
.21273 .14487 L
.20037 .14487 L
.20037 .1331 L
F
.20037 .14487 m
.21273 .14487 L
.20871 .15664 L
.20037 .15664 L
.20037 .14487 L
F
.20037 .15664 m
.20871 .15664 L
.20744 .16841 L
.20037 .16841 L
.20037 .15664 L
F
.20037 .16841 m
.20744 .16841 L
.20871 .18018 L
.20037 .18018 L
.20037 .16841 L
F
.20037 .18018 m
.20871 .18018 L
.21273 .19195 L
.20037 .19195 L
.20037 .18018 L
F
.20037 .19195 m
.21273 .19195 L
.22028 .20373 L
.20037 .20373 L
.20037 .19195 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.20037 .1331 m
.20037 .14487 L
.20037 .15664 L
.20037 .16841 L
.20037 .18018 L
.20037 .19195 L
.20037 .20373 L
.22028 .20373 L
.21273 .19195 L
.20871 .18018 L
.20744 .16841 L
.20871 .15664 L
.21273 .14487 L
.22028 .1331 L
.20037 .1331 L
s
.5 g
.20037 .16841 m
.22028 .16841 L
.21273 .16841 L
.20037 .16841 L
.20037 .16841 L
F
.20037 .16841 m
.21273 .16841 L
.20871 .16841 L
.20037 .16841 L
.20037 .16841 L
F
.20037 .16841 m
.20871 .16841 L
.20744 .16841 L
.20037 .16841 L
.20037 .16841 L
F
.20037 .16841 m
.20744 .16841 L
.20871 .16841 L
.20037 .16841 L
.20037 .16841 L
F
.20037 .16841 m
.20871 .16841 L
.21273 .16841 L
.20037 .16841 L
.20037 .16841 L
F
.20037 .16841 m
.21273 .16841 L
.22028 .16841 L
.20037 .16841 L
.20037 .16841 L
F
0 g
.20037 .16841 m
.20037 .16841 L
.20037 .16841 L
.20037 .16841 L
.20037 .16841 L
.20037 .16841 L
.20037 .16841 L
.22028 .16841 L
.21273 .16841 L
.20871 .16841 L
.20744 .16841 L
.20871 .16841 L
.21273 .16841 L
.22028 .16841 L
.20037 .16841 L
s
.20037 .20373 m
.22028 .20373 L
.22028 .20252 L
.20037 .20252 L
.20037 .20373 L
s
.20037 .20252 m
.22028 .20252 L
.22028 .19899 L
.20037 .19899 L
.20037 .20252 L
s
.20037 .19899 m
.22028 .19899 L
.22028 .19338 L
.20037 .19338 L
.20037 .19899 L
s
.20037 .19338 m
.22028 .19338 L
.22028 .18607 L
.20037 .18607 L
.20037 .19338 L
s
.20037 .18607 m
.22028 .18607 L
.22028 .17755 L
.20037 .17755 L
.20037 .18607 L
s
.20037 .17755 m
.22028 .17755 L
.22028 .16841 L
.20037 .16841 L
.20037 .17755 L
s
.20037 .16841 m
.22028 .16841 L
.22028 .15927 L
.20037 .15927 L
.20037 .16841 L
s
.20037 .15927 m
.22028 .15927 L
.22028 .15076 L
.20037 .15076 L
.20037 .15927 L
s
.20037 .15076 m
.22028 .15076 L
.22028 .14344 L
.20037 .14344 L
.20037 .15076 L
s
.20037 .14344 m
.22028 .14344 L
.22028 .13783 L
.20037 .13783 L
.20037 .14344 L
s
.20037 .13783 m
.22028 .13783 L
.22028 .1343 L
.20037 .1343 L
.20037 .13783 L
s
.20037 .1343 m
.22028 .1343 L
.22028 .1331 L
.20037 .1331 L
.20037 .1343 L
s
.20037 .1331 m
.22028 .1331 L
.22028 .1343 L
.20037 .1343 L
.20037 .1331 L
s
.20037 .1343 m
.22028 .1343 L
.22028 .13783 L
.20037 .13783 L
.20037 .1343 L
s
.20037 .13783 m
.22028 .13783 L
.22028 .14344 L
.20037 .14344 L
.20037 .13783 L
s
.20037 .14344 m
.22028 .14344 L
.22028 .15076 L
.20037 .15076 L
.20037 .14344 L
s
.20037 .15076 m
.22028 .15076 L
.22028 .15927 L
.20037 .15927 L
.20037 .15076 L
s
.20037 .15927 m
.22028 .15927 L
.22028 .16841 L
.20037 .16841 L
.20037 .15927 L
s
.20037 .16841 m
.22028 .16841 L
.22028 .17755 L
.20037 .17755 L
.20037 .16841 L
s
.20037 .17755 m
.22028 .17755 L
.22028 .18607 L
.20037 .18607 L
.20037 .17755 L
s
.20037 .18607 m
.22028 .18607 L
.22028 .19338 L
.20037 .19338 L
.20037 .18607 L
s
.20037 .19338 m
.22028 .19338 L
.22028 .19899 L
.20037 .19899 L
.20037 .19338 L
s
.20037 .19899 m
.22028 .19899 L
.22028 .20252 L
.20037 .20252 L
.20037 .19899 L
s
.20037 .20252 m
.22028 .20252 L
.22028 .20373 L
.20037 .20373 L
.20037 .20252 L
s
.5 g
.66426 .11544 m
.68239 .11544 L
.68239 .1331 L
.66157 .1331 L
.66426 .11544 L
F
.66157 .1331 m
.68239 .1331 L
.68239 .15076 L
.65997 .15076 L
.66157 .1331 L
F
.65997 .15076 m
.68239 .15076 L
.68239 .16841 L
.65944 .16841 L
.65997 .15076 L
F
.65944 .16841 m
.68239 .16841 L
.68239 .18607 L
.65997 .18607 L
.65944 .16841 L
F
.65997 .18607 m
.68239 .18607 L
.68239 .20373 L
.66157 .20373 L
.65997 .18607 L
F
.66157 .20373 m
.68239 .20373 L
.68239 .22138 L
.66426 .22138 L
.66157 .20373 L
F
0 g
.66426 .11544 m
.66157 .1331 L
.65997 .15076 L
.65944 .16841 L
.65997 .18607 L
.66157 .20373 L
.66426 .22138 L
.68239 .22138 L
.68239 .20373 L
.68239 .18607 L
.68239 .16841 L
.68239 .15076 L
.68239 .1331 L
.68239 .11544 L
.66426 .11544 L
s
.5 g
.66426 .16841 m
.68239 .16841 L
.68239 .16841 L
.66157 .16841 L
.66426 .16841 L
F
.66157 .16841 m
.68239 .16841 L
.68239 .16841 L
.65997 .16841 L
.66157 .16841 L
F
.65997 .16841 m
.68239 .16841 L
.68239 .16841 L
.65944 .16841 L
.65997 .16841 L
F
.65944 .16841 m
.68239 .16841 L
.68239 .16841 L
.65997 .16841 L
.65944 .16841 L
F
.65997 .16841 m
.68239 .16841 L
.68239 .16841 L
.66157 .16841 L
.65997 .16841 L
F
.66157 .16841 m
.68239 .16841 L
.68239 .16841 L
.66426 .16841 L
.66157 .16841 L
F
0 g
.66426 .16841 m
.66157 .16841 L
.65997 .16841 L
.65944 .16841 L
.65997 .16841 L
.66157 .16841 L
.66426 .16841 L
.68239 .16841 L
.68239 .16841 L
.68239 .16841 L
.68239 .16841 L
.68239 .16841 L
.68239 .16841 L
.68239 .16841 L
.66426 .16841 L
s
.66426 .22138 m
.68239 .22138 L
.68239 .21958 L
.66426 .21958 L
.66426 .22138 L
s
.66426 .21958 m
.68239 .21958 L
.68239 .21429 L
.66426 .21429 L
.66426 .21958 L
s
.66426 .21429 m
.68239 .21429 L
.68239 .20587 L
.66426 .20587 L
.66426 .21429 L
s
.66426 .20587 m
.68239 .20587 L
.68239 .1949 L
.66426 .1949 L
.66426 .20587 L
s
.66426 .1949 m
.68239 .1949 L
.68239 .18212 L
.66426 .18212 L
.66426 .1949 L
s
.66426 .18212 m
.68239 .18212 L
.68239 .16841 L
.66426 .16841 L
.66426 .18212 L
s
.66426 .16841 m
.68239 .16841 L
.68239 .1547 L
.66426 .1547 L
.66426 .16841 L
s
.66426 .1547 m
.68239 .1547 L
.68239 .14193 L
.66426 .14193 L
.66426 .1547 L
s
.66426 .14193 m
.68239 .14193 L
.68239 .13096 L
.66426 .13096 L
.66426 .14193 L
s
.66426 .13096 m
.68239 .13096 L
.68239 .12254 L
.66426 .12254 L
.66426 .13096 L
s
.66426 .12254 m
.68239 .12254 L
.68239 .11725 L
.66426 .11725 L
.66426 .12254 L
s
.66426 .11725 m
.68239 .11725 L
.68239 .11544 L
.66426 .11544 L
.66426 .11725 L
s
.66426 .11544 m
.68239 .11544 L
.68239 .11725 L
.66426 .11725 L
.66426 .11544 L
s
.66426 .11725 m
.68239 .11725 L
.68239 .12254 L
.66426 .12254 L
.66426 .11725 L
s
.66426 .12254 m
.68239 .12254 L
.68239 .13096 L
.66426 .13096 L
.66426 .12254 L
s
.66426 .13096 m
.68239 .13096 L
.68239 .14193 L
.66426 .14193 L
.66426 .13096 L
s
.66426 .14193 m
.68239 .14193 L
.68239 .1547 L
.66426 .1547 L
.66426 .14193 L
s
.66426 .1547 m
.68239 .1547 L
.68239 .16841 L
.66426 .16841 L
.66426 .1547 L
s
.66426 .16841 m
.68239 .16841 L
.68239 .18212 L
.66426 .18212 L
.66426 .16841 L
s
.66426 .18212 m
.68239 .18212 L
.68239 .1949 L
.66426 .1949 L
.66426 .18212 L
s
.66426 .1949 m
.68239 .1949 L
.68239 .20587 L
.66426 .20587 L
.66426 .1949 L
s
.66426 .20587 m
.68239 .20587 L
.68239 .21429 L
.66426 .21429 L
.66426 .20587 L
s
.66426 .21429 m
.68239 .21429 L
.68239 .21958 L
.66426 .21958 L
.66426 .21429 L
s
.66426 .21958 m
.68239 .21958 L
.68239 .22138 L
.66426 .22138 L
.66426 .21958 L
s
.87237 .0405 m
.88379 .08314 L
.89521 .12577 L
.90662 .16841 L
.91804 .21105 L
.92946 .25369 L
.94088 .29633 L
.94088 .29633 L
.92946 .25369 L
.91804 .21105 L
.90662 .16841 L
.89521 .12577 L
.88379 .08314 L
.87237 .0405 L
.87237 .0405 L
s
.90662 .16841 m
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
s
.94088 .29633 m
.93971 .29197 L
.93629 .27919 L
.93085 .25886 L
.92375 .23237 L
.91549 .20152 L
.90662 .16841 L
.89776 .13531 L
.8895 .10446 L
.8824 .07796 L
.87696 .05764 L
.87354 .04486 L
.87237 .0405 L
.87354 .04486 L
.87696 .05764 L
.8824 .07796 L
.8895 .10446 L
.89776 .13531 L
.90662 .16841 L
.91549 .20152 L
.92375 .23237 L
.93085 .25886 L
.93629 .27919 L
.93971 .29197 L
.94088 .29633 L
s
.5 g
.90768 .0405 m
.90768 .0405 L
.9191 .08314 L
.9191 .08314 L
.90768 .0405 L
F
.9191 .08314 m
.9191 .08314 L
.93052 .12577 L
.93052 .12577 L
.9191 .08314 L
F
.93052 .12577 m
.93052 .12577 L
.94194 .16841 L
.94194 .16841 L
.93052 .12577 L
F
.94194 .16841 m
.94194 .16841 L
.95336 .21105 L
.95336 .21105 L
.94194 .16841 L
F
.95336 .21105 m
.95336 .21105 L
.96477 .25369 L
.96477 .25369 L
.95336 .21105 L
F
.96477 .25369 m
.96477 .25369 L
.97619 .29633 L
.97619 .29633 L
.96477 .25369 L
F
0 g
.90768 .0405 m
.9191 .08314 L
.93052 .12577 L
.94194 .16841 L
.95336 .21105 L
.96477 .25369 L
.97619 .29633 L
.97619 .29633 L
.96477 .25369 L
.95336 .21105 L
.94194 .16841 L
.93052 .12577 L
.9191 .08314 L
.90768 .0405 L
.90768 .0405 L
s
.5 g
.94194 .16841 m
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
F
.94194 .16841 m
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
F
.94194 .16841 m
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
F
.94194 .16841 m
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
F
.94194 .16841 m
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
F
.94194 .16841 m
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
F
0 g
.94194 .16841 m
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
s
.5 g
.94194 .16841 m
.95336 .21105 L
.95297 .2096 L
.94194 .16841 L
.94194 .16841 L
F
.95336 .21105 m
.96477 .25369 L
.96399 .25078 L
.95297 .2096 L
.95336 .21105 L
F
.96477 .25369 m
.97619 .29633 L
.97502 .29197 L
.96399 .25078 L
.96477 .25369 L
F
.94194 .16841 m
.95297 .2096 L
.95183 .20534 L
.94194 .16841 L
.94194 .16841 L
F
.95297 .2096 m
.96399 .25078 L
.96171 .24227 L
.95183 .20534 L
.95297 .2096 L
F
.96399 .25078 m
.97502 .29197 L
.9716 .27919 L
.96171 .24227 L
.96399 .25078 L
F
.94194 .16841 m
.95183 .20534 L
.95001 .19856 L
.94194 .16841 L
.94194 .16841 L
F
.95183 .20534 m
.96171 .24227 L
.95808 .22871 L
.95001 .19856 L
.95183 .20534 L
F
.96171 .24227 m
.9716 .27919 L
.96616 .25886 L
.95808 .22871 L
.96171 .24227 L
F
.94194 .16841 m
.95001 .19856 L
.94765 .18973 L
.94194 .16841 L
.94194 .16841 L
F
.95001 .19856 m
.95808 .22871 L
.95336 .21105 L
.94765 .18973 L
.95001 .19856 L
F
.95808 .22871 m
.96616 .25886 L
.95906 .23237 L
.95336 .21105 L
.95808 .22871 L
F
.94194 .16841 m
.94765 .18973 L
.94489 .17945 L
.94194 .16841 L
.94194 .16841 L
F
.94765 .18973 m
.95336 .21105 L
.94785 .19048 L
.94489 .17945 L
.94765 .18973 L
F
.95336 .21105 m
.95906 .23237 L
.9508 .20152 L
.94785 .19048 L
.95336 .21105 L
F
.94194 .16841 m
.94489 .17945 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
F
.94489 .17945 m
.94785 .19048 L
.94194 .16841 L
.94194 .16841 L
.94489 .17945 L
F
.94785 .19048 m
.9508 .20152 L
.94194 .16841 L
.94194 .16841 L
.94785 .19048 L
F
.94194 .16841 m
.94194 .16841 L
.93898 .15738 L
.94194 .16841 L
.94194 .16841 L
F
.94194 .16841 m
.94194 .16841 L
.93603 .14634 L
.93898 .15738 L
.94194 .16841 L
F
.94194 .16841 m
.94194 .16841 L
.93307 .13531 L
.93603 .14634 L
.94194 .16841 L
F
.94194 .16841 m
.93898 .15738 L
.93623 .14709 L
.94194 .16841 L
.94194 .16841 L
F
.93898 .15738 m
.93603 .14634 L
.93052 .12577 L
.93623 .14709 L
.93898 .15738 L
F
.93603 .14634 m
.93307 .13531 L
.92481 .10446 L
.93052 .12577 L
.93603 .14634 L
F
.94194 .16841 m
.93623 .14709 L
.93386 .13826 L
.94194 .16841 L
.94194 .16841 L
F
.93623 .14709 m
.93052 .12577 L
.92579 .10811 L
.93386 .13826 L
.93623 .14709 L
F
.93052 .12577 m
.92481 .10446 L
.91772 .07796 L
.92579 .10811 L
.93052 .12577 L
F
.94194 .16841 m
.93386 .13826 L
.93205 .13149 L
.94194 .16841 L
.94194 .16841 L
F
.93386 .13826 m
.92579 .10811 L
.92216 .09456 L
.93205 .13149 L
.93386 .13826 L
F
.92579 .10811 m
.91772 .07796 L
.91227 .05764 L
.92216 .09456 L
.92579 .10811 L
F
.94194 .16841 m
.93205 .13149 L
.93091 .12723 L
.94194 .16841 L
.94194 .16841 L
F
.93205 .13149 m
.92216 .09456 L
.91988 .08604 L
.93091 .12723 L
.93205 .13149 L
F
.92216 .09456 m
.91227 .05764 L
.90885 .04486 L
.91988 .08604 L
.92216 .09456 L
F
.94194 .16841 m
.93091 .12723 L
.93052 .12577 L
.94194 .16841 L
.94194 .16841 L
F
.93091 .12723 m
.91988 .08604 L
.9191 .08314 L
.93052 .12577 L
.93091 .12723 L
F
.91988 .08604 m
.90885 .04486 L
.90768 .0405 L
.9191 .08314 L
.91988 .08604 L
F
.94194 .16841 m
.93052 .12577 L
.93091 .12723 L
.94194 .16841 L
.94194 .16841 L
F
.93052 .12577 m
.9191 .08314 L
.91988 .08604 L
.93091 .12723 L
.93052 .12577 L
F
.9191 .08314 m
.90768 .0405 L
.90885 .04486 L
.91988 .08604 L
.9191 .08314 L
F
.94194 .16841 m
.93091 .12723 L
.93205 .13149 L
.94194 .16841 L
.94194 .16841 L
F
.93091 .12723 m
.91988 .08604 L
.92216 .09456 L
.93205 .13149 L
.93091 .12723 L
F
.91988 .08604 m
.90885 .04486 L
.91227 .05764 L
.92216 .09456 L
.91988 .08604 L
F
.94194 .16841 m
.93205 .13149 L
.93386 .13826 L
.94194 .16841 L
.94194 .16841 L
F
.93205 .13149 m
.92216 .09456 L
.92579 .10811 L
.93386 .13826 L
.93205 .13149 L
F
.92216 .09456 m
.91227 .05764 L
.91772 .07796 L
.92579 .10811 L
.92216 .09456 L
F
.94194 .16841 m
.93386 .13826 L
.93623 .14709 L
.94194 .16841 L
.94194 .16841 L
F
.93386 .13826 m
.92579 .10811 L
.93052 .12577 L
.93623 .14709 L
.93386 .13826 L
F
.92579 .10811 m
.91772 .07796 L
.92481 .10446 L
.93052 .12577 L
.92579 .10811 L
F
.94194 .16841 m
.93623 .14709 L
.93898 .15738 L
.94194 .16841 L
.94194 .16841 L
F
.93623 .14709 m
.93052 .12577 L
.93603 .14634 L
.93898 .15738 L
.93623 .14709 L
F
.93052 .12577 m
.92481 .10446 L
.93307 .13531 L
.93603 .14634 L
.93052 .12577 L
F
.94194 .16841 m
.93898 .15738 L
.94194 .16841 L
.94194 .16841 L
.94194 .16841 L
F
.93898 .15738 m
.93603 .14634 L
.94194 .16841 L
.94194 .16841 L
.93898 .15738 L
F
.93603 .14634 m
.93307 .13531 L
.94194 .16841 L
.94194 .16841 L
.93603 .14634 L
F
.94194 .16841 m
.94194 .16841 L
.94489 .17945 L
.94194 .16841 L
.94194 .16841 L
F
.94194 .16841 m
.94194 .16841 L
.94785 .19048 L
.94489 .17945 L
.94194 .16841 L
F
.94194 .16841 m
.94194 .16841 L
.9508 .20152 L
.94785 .19048 L
.94194 .16841 L
F
.94194 .16841 m
.94489 .17945 L
.94765 .18973 L
.94194 .16841 L
.94194 .16841 L
F
.94489 .17945 m
.94785 .19048 L
.95336 .21105 L
.94765 .18973 L
.94489 .17945 L
F
.94785 .19048 m
.9508 .20152 L
.95906 .23237 L
.95336 .21105 L
.94785 .19048 L
F
.94194 .16841 m
.94765 .18973 L
.95001 .19856 L
.94194 .16841 L
.94194 .16841 L
F
.94765 .18973 m
.95336 .21105 L
.95808 .22871 L
.95001 .19856 L
.94765 .18973 L
F
.95336 .21105 m
.95906 .23237 L
.96616 .25886 L
.95808 .22871 L
.95336 .21105 L
F
.94194 .16841 m
.95001 .19856 L
.95183 .20534 L
.94194 .16841 L
.94194 .16841 L
F
.95001 .19856 m
.95808 .22871 L
.96171 .24227 L
.95183 .20534 L
.95001 .19856 L
F
.95808 .22871 m
.96616 .25886 L
.9716 .27919 L
.96171 .24227 L
.95808 .22871 L
F
.94194 .16841 m
.95183 .20534 L
.95297 .2096 L
.94194 .16841 L
.94194 .16841 L
F
.95183 .20534 m
.96171 .24227 L
.96399 .25078 L
.95297 .2096 L
.95183 .20534 L
F
.96171 .24227 m
.9716 .27919 L
.97502 .29197 L
.96399 .25078 L
.96171 .24227 L
F
.94194 .16841 m
.95297 .2096 L
.95336 .21105 L
.94194 .16841 L
.94194 .16841 L
F
.95297 .2096 m
.96399 .25078 L
.96477 .25369 L
.95336 .21105 L
.95297 .2096 L
F
.96399 .25078 m
.97502 .29197 L
.97619 .29633 L
.96477 .25369 L
.96399 .25078 L
F
0 g
.97619 .29633 m
.97502 .29197 L
.9716 .27919 L
.96616 .25886 L
.95906 .23237 L
.9508 .20152 L
.94194 .16841 L
.93307 .13531 L
.92481 .10446 L
.91772 .07796 L
.91227 .05764 L
.90885 .04486 L
.90768 .0405 L
.90885 .04486 L
.91227 .05764 L
.91772 .07796 L
.92481 .10446 L
.93307 .13531 L
.94194 .16841 L
.9508 .20152 L
.95906 .23237 L
.96616 .25886 L
.9716 .27919 L
.97502 .29197 L
.97619 .29633 L
s
.87237 .0405 m
.88379 .08314 L
.89521 .12577 L
.90662 .16841 L
.91804 .21105 L
.92946 .25369 L
.94088 .29633 L
.94088 .29633 L
.92946 .25369 L
.91804 .21105 L
.90662 .16841 L
.89521 .12577 L
.88379 .08314 L
.87237 .0405 L
.87237 .0405 L
s
.90662 .16841 m
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
.90662 .16841 L
s
.94088 .29633 m
.93971 .29197 L
.93629 .27919 L
.93085 .25886 L
.92375 .23237 L
.91549 .20152 L
.90662 .16841 L
.89776 .13531 L
.8895 .10446 L
.8824 .07796 L
.87696 .05764 L
.87354 .04486 L
.87237 .0405 L
.87354 .04486 L
.87696 .05764 L
.8824 .07796 L
.8895 .10446 L
.89776 .13531 L
.90662 .16841 L
.91549 .20152 L
.92375 .23237 L
.93085 .25886 L
.93629 .27919 L
.93971 .29197 L
.94088 .29633 L
s
.49168 .50973 m
.47697 .48424 L
.46227 .45875 L
.44756 .43326 L
.43286 .40777 L
.41815 .38228 L
.40344 .35679 L
.40344 .35679 L
.41815 .38228 L
.43286 .40777 L
.44756 .43326 L
.46227 .45875 L
.47697 .48424 L
.49168 .50973 L
.49168 .50973 L
s
.44756 .43326 m
.44756 .43326 L
.44756 .43326 L
.44756 .43326 L
.44756 .43326 L
.44756 .43326 L
.44756 .43326 L
.44756 .43326 L
.44756 .43326 L
.44756 .43326 L
.44756 .43326 L
.44756 .43326 L
.44756 .43326 L
.44756 .43326 L
.44756 .43326 L
s
.40344 .35679 m
.40495 .3594 L
.40936 .36703 L
.41637 .37919 L
.4255 .39502 L
.43614 .41347 L
.44756 .43326 L
.45898 .45305 L
.46962 .47149 L
.47876 .48733 L
.48577 .49948 L
.49017 .50712 L
.49168 .50973 L
.49017 .50712 L
.48577 .49948 L
.47876 .48733 L
.46962 .47149 L
.45898 .45305 L
.44756 .43326 L
.43614 .41347 L
.4255 .39502 L
.41637 .37919 L
.40936 .36703 L
.40495 .3594 L
.40344 .35679 L
s
.039 .916 .04 r
.02381 .16312 m
.20037 .16312 L
s
% Start of user PostScript
-50. -1.5 0 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20037 .16312 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16841 m
.20037 .16841 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20037 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17371 m
.20037 .17371 L
s
% Start of user PostScript
-50. 1.5 0 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20037 .17371 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16312 m
.20037 .16312 L
s
% Start of user PostScript
-50. -1.5 0 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20037 .16312 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16841 m
.20037 .16841 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20037 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17371 m
.20037 .17371 L
s
% Start of user PostScript
-50. 1.5 0 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20037 .17371 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16312 m
.20037 .16312 L
s
% Start of user PostScript
-50. -1.5 0 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20037 .16312 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .16841 m
.20037 .16841 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20037 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .17371 m
.20037 .17371 L
s
% Start of user PostScript
-50. 1.5 0 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20037 .17371 Mdot
.039 .916 .04 r
.5 Mabswid
.20037 .16312 m
.20795 .16312 L
s
% Start of user PostScript
0 -1.5 2.14526 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20795 .16312 Mdot
.039 .916 .04 r
.5 Mabswid
.20037 .16841 m
.20769 .16841 L
s
% Start of user PostScript
0 0 2.07246 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20769 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.20037 .17371 m
.20795 .17371 L
s
% Start of user PostScript
0 1.5 2.14526 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20795 .17371 Mdot
.039 .916 .04 r
.5 Mabswid
.20037 .16312 m
.20769 .16312 L
s
% Start of user PostScript
0 -1.5 2.07246 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20769 .16312 Mdot
.039 .916 .04 r
.5 Mabswid
.20037 .16841 m
.20744 .16841 L
s
% Start of user PostScript
0 0 2. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20744 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.20037 .17371 m
.20769 .17371 L
s
% Start of user PostScript
0 1.5 2.07246 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20769 .17371 Mdot
.039 .916 .04 r
.5 Mabswid
.20037 .16312 m
.20795 .16312 L
s
% Start of user PostScript
0 -1.5 2.14526 -1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20795 .16312 Mdot
.039 .916 .04 r
.5 Mabswid
.20037 .16841 m
.20769 .16841 L
s
% Start of user PostScript
0 0 2.07246 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20769 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.20037 .17371 m
.20795 .17371 L
s
% Start of user PostScript
0 1.5 2.14526 1.5 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.20795 .17371 Mdot
.039 .916 .04 r
.5 Mabswid
.20795 .16312 m
.6622 .14 L
s
% Start of user PostScript
2.14526 -1.5 130.784 -8.04599 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6622 .14 Mdot
.039 .916 .04 r
.5 Mabswid
.20769 .16841 m
.66079 .16841 L
s
% Start of user PostScript
2.07246 0 130.384 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.66079 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.20795 .17371 m
.6622 .19683 L
s
% Start of user PostScript
2.14526 1.5 130.784 8.04599 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6622 .19683 Mdot
.039 .916 .04 r
.5 Mabswid
.20769 .16312 m
.66079 .14026 L
s
% Start of user PostScript
2.07246 -1.5 130.384 -7.97386 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.66079 .14026 Mdot
.039 .916 .04 r
.5 Mabswid
.20744 .16841 m
.65944 .16841 L
s
% Start of user PostScript
2. 0 130. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.65944 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.20769 .17371 m
.66079 .19657 L
s
% Start of user PostScript
2.07246 1.5 130.384 7.97386 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.66079 .19657 Mdot
.039 .916 .04 r
.5 Mabswid
.20795 .16312 m
.6622 .14 L
s
% Start of user PostScript
2.14526 -1.5 130.784 -8.04599 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6622 .14 Mdot
.039 .916 .04 r
.5 Mabswid
.20769 .16841 m
.66079 .16841 L
s
% Start of user PostScript
2.07246 0 130.384 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.66079 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.20795 .17371 m
.6622 .19683 L
s
% Start of user PostScript
2.14526 1.5 130.784 8.04599 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.6622 .19683 Mdot
.039 .916 .04 r
.5 Mabswid
.6622 .14 m
.68239 .14 L
s
% Start of user PostScript
130.784 -8.04599 136.5 -8.04487 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68239 .14 Mdot
.039 .916 .04 r
.5 Mabswid
.66079 .16841 m
.68239 .16841 L
s
% Start of user PostScript
130.384 0 136.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68239 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.6622 .19683 m
.68239 .19682 L
s
% Start of user PostScript
130.784 8.04599 136.5 8.04487 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68239 .19682 Mdot
.039 .916 .04 r
.5 Mabswid
.66079 .14026 m
.68239 .14025 L
s
% Start of user PostScript
130.384 -7.97386 136.5 -7.97453 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68239 .14025 Mdot
.039 .916 .04 r
.5 Mabswid
.65944 .16841 m
.68239 .16841 L
s
% Start of user PostScript
130. 0 136.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68239 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.66079 .19657 m
.68239 .19657 L
s
% Start of user PostScript
130.384 7.97386 136.5 7.97453 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68239 .19657 Mdot
.039 .916 .04 r
.5 Mabswid
.6622 .14 m
.68239 .14 L
s
% Start of user PostScript
130.784 -8.04599 136.5 -8.04487 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68239 .14 Mdot
.039 .916 .04 r
.5 Mabswid
.66079 .16841 m
.68239 .16841 L
s
% Start of user PostScript
130.384 0 136.5 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68239 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.6622 .19683 m
.68239 .19682 L
s
% Start of user PostScript
130.784 8.04599 136.5 8.04487 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.68239 .19682 Mdot
.039 .916 .04 r
.5 Mabswid
.68239 .14 m
.89904 .14007 L
s
% Start of user PostScript
136.5 -8.04487 197.851 -8.02663 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.89904 .14007 Mdot
.039 .916 .04 r
.5 Mabswid
.68239 .16841 m
.90662 .16841 L
s
% Start of user PostScript
136.5 0 200. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.90662 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.68239 .19682 m
.91421 .19675 L
s
% Start of user PostScript
136.5 8.04487 202.149 8.02535 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.91421 .19675 Mdot
.039 .916 .04 r
.5 Mabswid
.68239 .14025 m
.89907 .14022 L
s
% Start of user PostScript
136.5 -7.97453 197.862 -7.98472 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.89907 .14022 Mdot
.039 .916 .04 r
.5 Mabswid
.68239 .16841 m
.90662 .16841 L
s
% Start of user PostScript
136.5 0 200. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.90662 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.68239 .19657 m
.91418 .19661 L
s
% Start of user PostScript
136.5 7.97453 202.138 7.98544 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.91418 .19661 Mdot
.039 .916 .04 r
.5 Mabswid
.68239 .14 m
.89904 .14007 L
s
% Start of user PostScript
136.5 -8.04487 197.851 -8.02663 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.89904 .14007 Mdot
.039 .916 .04 r
.5 Mabswid
.68239 .16841 m
.90662 .16841 L
s
% Start of user PostScript
136.5 0 200. 0 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.90662 .16841 Mdot
.039 .916 .04 r
.5 Mabswid
.68239 .19682 m
.91421 .19675 L
s
% Start of user PostScript
136.5 8.04487 202.149 8.02535 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.91421 .19675 Mdot
.039 .916 .04 r
.5 Mabswid
.89904 .14007 m
.93351 .13695 L
s
% Start of user PostScript
197.851 -8.02663 207.614 -8.91099 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.93351 .13695 Mdot
.039 .916 .04 r
.5 Mabswid
.90662 .16841 m
.9411 .16528 L
s
% Start of user PostScript
200. 0 209.763 -0.886205 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.9411 .16528 Mdot
.039 .916 .04 r
.5 Mabswid
.91421 .19675 m
.94869 .19362 L
s
% Start of user PostScript
202.149 8.02535 211.911 7.1373 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.94869 .19362 Mdot
.039 .916 .04 r
.5 Mabswid
.89907 .14022 m
.93355 .13708 L
s
% Start of user PostScript
197.862 -7.98472 207.624 -8.87196 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.93355 .13708 Mdot
.039 .916 .04 r
.5 Mabswid
.90662 .16841 m
.9411 .16528 L
s
% Start of user PostScript
200. 0 209.763 -0.886205 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.9411 .16528 Mdot
.039 .916 .04 r
.5 Mabswid
.91418 .19661 m
.94865 .19349 L
s
% Start of user PostScript
202.138 7.98544 211.901 7.10026 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.94865 .19349 Mdot
.039 .916 .04 r
.5 Mabswid
.89904 .14007 m
.93351 .13695 L
s
% Start of user PostScript
197.851 -8.02663 207.614 -8.91099 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.93351 .13695 Mdot
.039 .916 .04 r
.5 Mabswid
.90662 .16841 m
.9411 .16528 L
s
% Start of user PostScript
200. 0 209.763 -0.886205 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.9411 .16528 Mdot
.039 .916 .04 r
.5 Mabswid
.91421 .19675 m
.94869 .19362 L
s
% Start of user PostScript
202.149 8.02535 211.911 7.1373 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.94869 .19362 Mdot
.039 .916 .04 r
.5 Mabswid
.93351 .13695 m
.90209 .15147 L
s
% Start of user PostScript
207.614 -8.91099 198.715 -4.79813 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.90209 .15147 Mdot
.039 .916 .04 r
.5 Mabswid
.9411 .16528 m
.90967 .1798 L
s
% Start of user PostScript
209.763 -0.886205 200.864 3.22481 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.90967 .1798 Mdot
.039 .916 .04 r
.5 Mabswid
.94869 .19362 m
.91726 .20813 L
s
% Start of user PostScript
211.911 7.1373 203.012 11.2465 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.91726 .20813 Mdot
.039 .916 .04 r
.5 Mabswid
.93355 .13708 m
.90212 .1516 L
s
% Start of user PostScript
207.624 -8.87196 198.725 -4.76197 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.90212 .1516 Mdot
.039 .916 .04 r
.5 Mabswid
.9411 .16528 m
.90967 .1798 L
s
% Start of user PostScript
209.763 -0.886205 200.864 3.22481 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.90967 .1798 Mdot
.039 .916 .04 r
.5 Mabswid
.94865 .19349 m
.91723 .20801 L
s
% Start of user PostScript
211.901 7.10026 203.002 11.2123 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.91723 .20801 Mdot
.039 .916 .04 r
.5 Mabswid
.93351 .13695 m
.90209 .15147 L
s
% Start of user PostScript
207.614 -8.91099 198.715 -4.79813 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.90209 .15147 Mdot
.039 .916 .04 r
.5 Mabswid
.9411 .16528 m
.90967 .1798 L
s
% Start of user PostScript
209.763 -0.886205 200.864 3.22481 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.90967 .1798 Mdot
.039 .916 .04 r
.5 Mabswid
.94869 .19362 m
.91726 .20813 L
s
% Start of user PostScript
211.911 7.1373 203.012 11.2465 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.91726 .20813 Mdot
.039 .916 .04 r
.5 Mabswid
.90209 .15147 m
.43917 .41872 L
s
% Start of user PostScript
198.715 -4.79813 67.6248 70.8829 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.43917 .41872 Mdot
.039 .916 .04 r
.5 Mabswid
.90967 .1798 m
.45325 .44312 L
s
% Start of user PostScript
200.864 3.22481 71.6115 77.7933 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.45325 .44312 Mdot
.039 .916 .04 r
.5 Mabswid
.91726 .20813 m
.46733 .46752 L
s
% Start of user PostScript
203.012 11.2465 75.5983 84.7037 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46733 .46752 Mdot
.039 .916 .04 r
.5 Mabswid
.90212 .1516 m
.43911 .41862 L
s
% Start of user PostScript
198.725 -4.76197 67.6078 70.8535 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.43911 .41862 Mdot
.039 .916 .04 r
.5 Mabswid
.90967 .1798 m
.45325 .44312 L
s
% Start of user PostScript
200.864 3.22481 71.6115 77.7933 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.45325 .44312 Mdot
.039 .916 .04 r
.5 Mabswid
.91723 .20801 m
.46739 .46763 L
s
% Start of user PostScript
203.002 11.2123 75.6153 84.7331 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46739 .46763 Mdot
.039 .916 .04 r
.5 Mabswid
.90209 .15147 m
.43917 .41872 L
s
% Start of user PostScript
198.715 -4.79813 67.6248 70.8829 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.43917 .41872 Mdot
.039 .916 .04 r
.5 Mabswid
.90967 .1798 m
.45325 .44312 L
s
% Start of user PostScript
200.864 3.22481 71.6115 77.7933 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.45325 .44312 Mdot
.039 .916 .04 r
.5 Mabswid
.91726 .20813 m
.46733 .46752 L
s
% Start of user PostScript
203.012 11.2465 75.5983 84.7037 MAarrowhead1
% End of user PostScript
0 0 0 r
2 Mabswid
.46733 .46752 Mdot
[(L1)] .2039 .10467 0 0 Mshowa
[(L2)] .67091 .08701 0 0 Mshowa
[(L1)] .86502 .01303 0 0 Mshowa
[(M)] .90033 .01303 0 0 Mshowa
[(L2)] .86502 .01303 0 0 Mshowa
[(S)] .50589 .53435 0 0 Mshowa
0 0 m
1 0 L
1 .54739 L
0 .54739 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 157.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000WB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00lOooool:o`000007ooooool0003o0000o`000?oooooo0000ooooo`03
o`0001_ooooo003booooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo01[ooooo003booooo`03o`000?oooooo
oooo00?ooooo0_l00003ooooo`07o`000?oooooo0000ooooool0003oooooo`00000Looooo`00l_oo
ool00ol0003oooooooooo`03ooooo`;o00000oooool01ol0003oooooo`000?oooooo0000ooooool0
00007?ooool00?;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0000?o
oooo0_l0000Looooo`00l_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo
0_l00003ooooo`;o00007?ooool00?7ooooo0ol00004ooooo`;o00000_ooool2o`0000Gooooo0_l0
000Kooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00n?ooool2o`0000Sooooo
0_l0000Looooo`00n?ooool2o`0000Sooooo00?oOgmoo`000?ooool06oooool00?Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Jooooo`00nOooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01[ooooo003iooooo`;o00002?ooool00omoOgoo0000ooooo`0Jooooo`00
n_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo003jooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool06Oooool00?[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Iooooo`00n_ooool2o`0000Sooooo0_l0000Jooooo`00noooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Sooooo003kooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06?ooool00;[ooooo2Ol0000hooooo`;o00002?ooool2o`0001Wooooo002k
ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`0eooooo`;o00002?oo
ool2o`0001Wooooo002kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=oooool2
o`0000Sooooo0_l0000Iooooo`00^oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`00^oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Oooooo0_l00008ooooo`;o00006?ooool003Kooooo
1_l000001?oooooo0000o`000?l0001kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
0000>Oooool2o`0000Sooooo0_l0000Hooooo`00=oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool0NOooool3o`0000Cooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0_?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo
000gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0_?ooool2o`0000Sooooo0_l0
000Gooooo`00=oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Eooooo`00=oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo07gooooo1_l0000jooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05Oooool003Kooooo0ol00004ooooo`;o0000Ooooool6o`0003[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Eooooo`00__ooool6o`0003_ooooo00?o0000ooooooooool0
1_ooool00omoOgoo0000ooooo`0Eooooo`00_Oooool2o`0000CoOgmo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo002mooooo`;o00001?moOgl0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool0
03[ooooo1ol0001jooooo`?o2NX:1_l0000dooooo`?o2NX:1?ooool2o`000003ooooool9jP[o2NX:
00Co2NX:00?oooooogmoOol000005Oooool003[ooooo1ol0001cooooo`Ko2NX:0_ooool6o`WZ2P03
ogmoOol0003ooooo03Cooooo1_l9jPX01?oooooo0000ooooooooool8o`WZ2QGooooo000jooooo`Oo
0000Loooool8o`WZ2P03o`000?l9jP[o2NX:00?o2NX:00?o0000o`WZ2_l9jPX0>_l9jPX00ol0003o
2NX:o`WZ2P09o`WZ2QGooooo000jooooo`Oo0000H?oooolCo`WZ2P?ooooo2_l9jPX3o`0003Gooooo
1Ol9jPX01Ooooooo0000o`000?l0003ooooo00Ko2NX:00?oooooo`000?ooool05?ooool003[ooooo
00Oo0000ogmoOomoOgooOgmoo`000?oooooo000004kooooo4_l9jPXEooooo`?o2NX:0_ooool2o`WZ
2P03ogmoOol0003oOgmo00?oOgmo00?o0000ooooooooool0<_ooool2o`WZ2PKooooo0_l00008o`WZ
2P03ogmoOol0003ooooo01?ooooo000jooooo`Oo0000>ooooolCo`WZ2RKooooo00?o2NX:oooooooo
ool01?ooool00ol0003oOgmoo`000004ogmoO`03o`000?oooooooooo03[ooooo0_l00005o`WZ2P?o
oooo00?oOgmoo`000?ooool04oooool003[ooooo00Co0000ogmoOomoOgoo00000_ooool00ol0003o
ooooooooo`0Woooooa;o2NX:@?ooool00ol0003oOgmoo`000005o`0003cooooo0ol9jPX8ooooo`03
o`000?oooooooooo01;ooooo000booooo`Go2NX:0oooool01?l0003oOgmoogmoOol00002ooooo`03
o`000?oooooooooo01Gooooo4_l9jPYBooooo`03o`000?moOgoo000000CoOgmo00?o0000oooooooo
ool0>?ooool2o`WZ2P03ooooool0003ooooo00Sooooo00?o0000ooooooooool04_ooool003;ooooo
2Ol9jPX6o`0000Cooooo4ol9jPYLooooo`Co2NX:0oooool3o`WZ2P03o`000?moOgooOgmo00;oOgmo
00?o0000ooooooooool0=?ooool4o`WZ2P?ooooo00?o0000ooooooooool01_l9jPX00ooooooo0000
ooooo`0Cooooo`002?oooolmo`WZ2W3ooooo3Ol9jPX00omoOgoo0000ooooo`0fooooo`Ko2NX:00Co
ooooo`000?oooooooooo2?l9jPXCooooo`002?oooonjo`WZ2P03o`000?l9jP[o2NX:04Ko2NX:0_l0
000Cooooo`00<_ooool9o`WZ2P?o00000_ooool00ol0003oooooooooo`1booooo`Ko2NX:00?ooooo
o`WZ2_l9jPX00ol9jPX00omoOgoo0000o`00000cooooo`;o2NX:0_ooool5o`WZ2P;ooooo0_l00000
0ooooooo2NX:o`WZ2P04o`WZ2P03ooooool0003ooooo01;ooooo0008oooood3o2NX:K?ooool3o`WZ
2PCooooo0_l9jPX00omoOgoo0000ogmoO`03ogmoO`03o`000?oooooooooo033ooooo00Co2NX:oooo
oooooooooooo0_l9jPX6ooooo`03o`000?oooooo2NX:00Oo2NX:00?o0000ooooooooool04Oooool0
03?ooooo1ol9jPX7o`0000Oooooo5Ol9jPYOooooo`03o`000?moOgoo000000CoOgmo00?o0000oooo
ooooool0;_ooool2o`WZ2Pgooooo0_l00004o`WZ2PCooooo00?o0000ooooooooool04?ooool003;o
oooo1?l9jPX4ooooo`04o`000?moOgooOgmoo`0000;ooooo00?o0000ooooooooool06_oooolFo`WZ
2TWooooo00?o0000ogmoOol000001Ol0000^ooooo`;o2NX:3_ooool2o`WZ2P03o`000?oooooooooo
00Kooooo00?o0000ooooooooool04?ooool003[ooooo1ol0000boooooaGo2NX:=?ooool00ol0003o
Ogmoo`000004ogmoO`03o`000?oooooooooo02[ooooo0_l9jPX>ooooo`;o2NX:00?oooooo`000?oo
ool02?ooool00ol0003oooooooooo`0@ooooo`00>_ooool01ol0003oOgmoogmoOomoOgoo0000oooo
ool00000AooooolFo`WZ2QOooooo0ol9jPX3ooooo`?o2NX:00?o0000ogmoOomoOgl00_moOgl00ol0
003oooooooooo`0Yooooo`03o`WZ2_oooooooooo00[ooooo1?l9jPX3ooooo`;o000000?oooooo`WZ
2_l9jPX01Ol9jPX00omoOgoo0000ooooo`0@ooooo`00>_ooool7o`0005gooooo5Ol9jPX3ooooo`co
2NX:00?oOgmoo`000?ooool0:?ooool2o`WZ2Pkooooo1_l9jPX01?oooooo0000ooooooooool8o`WZ
2P03o`000?oooooooooo00kooooo000jooooo`07o`000?moOgooOgmoogmoOol0003oooooo`00001b
ooooo`Wo2NX:00?o0000o`WZ2_l9jPX00ol9jPX00ol0003o2NX:o`WZ2P1:o`WZ2P03o`000?oooooo
oooo00kooooo000jooooo`Oo0000M?ooool6o`WZ2P03ooooool9jP[o2NX:00?o2NX:00?oOgmoo`00
0?l000009Oooool2o`WZ2Pkooooo0_l9jPX2ooooo`Go2NX:0_ooool2o`000003ooooool9jP[o2NX:
00Co2NX:00?oooooogmoOol000004?ooool003[ooooo1ol0001cooooo`?o2NX:1?ooool2o`WZ2P;o
00001?moOgl00ol0003oooooooooo`0Rooooo`03o`WZ2_oooooooooo00gooooo00Co2NX:oooooooo
oooooooo0_l9jPX6ooooo`;o00002?l9jPX00omoOgoo0000ooooo`0?ooooo`00_Oooool7o`0002;o
oooo0_l9jPX>ooooo`;o2NX:3Oooool2o`0000Co2NX:1?ooool00ol0003oooooooooo`0>ooooo`00
_Oooool2o`0000CoOgmo00?o0000ooooooooool07_ooool2o`WZ2Pkooooo0_l9jPX>ooooo`;o2NX:
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`00__ooool6o`0001kooooo0_l9
jPX>ooooo`;o2NX:3_ooool2o`WZ2P03ooooool0003o000000Sooooo00?oOgmoo`000?ooool03_oo
ool00;kooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`0Kooooo`03o`WZ2_oooooo
oooo00gooooo00?o2NX:ooooooooool03Oooool01?l9jP[oooooooooooooool2o`0000Sooooo00?o
Ogmoo`000?ooool03_ooool00;kooooo1_l0000Kooooo`;o2NX:3_ooool2o`WZ2Pkooooo0_l9jPX5
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00=gooooo0_l9jPX>oooo
o`;o2NX:3_ooool2o`WZ2POooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=oooo
o`00foooool2o`WZ2Pkooooo0_l9jPX>ooooo`;o2NX:2Oooool2o`0000Sooooo00?oOgmoo`000?oo
ool03Oooool00=[ooooo00?o2NX:ooooooooool03Oooool00ol9jP[oooooooooo`0=ooooo`03o`WZ
2_oooooooooo00[ooooo00?o0000ooooooooool01_ooool00omoOgoo0000ooooo`0=ooooo`00f?oo
ool2o`WZ2Pkooooo0_l9jPX>ooooo`;o2NX:3Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00cooooo003Fooooo`;o2NX:3_ooool2o`WZ2Pkooooo0_l9jPX?ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03?ooool00=Cooooo0_l9jPX>ooooo`;o2NX:3_ooool2o`WZ
2Q;ooooo00?o0000ooooooooool01_ooool00omoOgoo0000ooooo`0<ooooo`00doooool00ol9jP[o
ooooooooo`0=ooooo`03o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool04_ooool00ol0003o
ooooooooo`06ooooo`03ogmoOol0003ooooo00cooooo003Aooooo`;o2NX:3_ooool2o`WZ2Pkooooo
0_l9jPXEooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00<oooooo0_l9
jPX>ooooo`;o2NX:3_ooool2o`WZ2QOooooo0_l00008ooooo`;o00003?ooool00<gooooo0_l9jPX?
ooooo`03o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool06?ooool00ol0003oooooooooo`06
ooooo`03ogmoOol0003ooooo00_ooooo003<ooooo`03o`WZ2_oooooooooo00gooooo0_l9jPX>oooo
o`;o2NX:6oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo003:ooooo`;o
2NX:3_ooool2o`WZ2Pkooooo0_l9jPXMooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool00<Sooooo0_l9jPX>ooooo`;o2NX:3_ooool2o`WZ2R3ooooo00?o0000ooooooooool0
1_ooool00omoOgoo0000ooooo`0:ooooo`00a_ooool2o`WZ2Poooooo00?o2NX:ooooooooool03Ooo
ool00ol9jP[oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ooo
ool00<Gooooo00?o2NX:ooooooooool03Oooool2o`WZ2Pkooooo0_l9jPXSooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02Oooool00<?ooooo0_l9jPX>ooooo`;o2NX:3_ooool2o`WZ
2RGooooo0_l00008ooooo`03ogmoOol0003ooooo00Wooooo0031ooooo`;o2NX:3_ooool2o`WZ2Pko
oooo0_l9jPXXooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00;oooooo
0_l9jPX?ooooo`03o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool0:?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo002nooooo`03o`WZ2_oooooooooo00gooooo0_l9
jPX>ooooo`;o2NX::oooool2o`0000Sooooo00?oOgmoo`000?ooool02?ooool00;cooooo0_l9jPX>
ooooo`;o2NX:3_ooool2o`WZ2Rgooooo0_l00008ooooo`03ogmoOol0003ooooo00Sooooo002joooo
o`;o2NX:3_ooool2o`WZ2Pkooooo0_l9jPX`ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00;Wooooo00?o2NX:ooooooooool03Oooool00ol9jP[oooooooooo`0=ooooo`03
o`WZ2_oooooooooo033ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`00
]oooool2o`WZ2Pkooooo0_l9jPX>ooooo`;o2NX:Aoooool00;Gooooo0_l9jPX>ooooo`;o2NX:3_oo
ool2o`WZ2TWooooo002cooooo`;o2NX:3_ooool2o`WZ2Pkooooo0_l9jPY;ooooo`00/_ooool00ol9
jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool0Boooool00;3o
oooo0_l9jPX>ooooo`;o2NX:3_ooool2o`WZ2Tkooooo002^ooooo`;o2NX:3_ooool2o`WZ2Pkooooo
0_l9jPY@ooooo`00[?ooool2o`WZ2Pkooooo0_l9jPX>ooooo`;o2NX:D_ooool00:_ooooo00?o2NX:
ooooooooool03Oooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo05;ooooo002Yoooo
o`;o2NX:3_ooool2o`WZ2Pkooooo0_l9jPYEooooo`00Yoooool2o`WZ2Pkooooo0_l9jPX>ooooo`;o
2NX:Eoooool00:Gooooo0_l9jPX>ooooo`;o2NX:3_ooool2o`WZ2UWooooo002Tooooo`03o`WZ2_oo
oooooooo00gooooo00?o2NX:ooooooooool03Oooool00ol9jP[oooooooooo`1Iooooo`00X_ooool2
o`WZ2Pkooooo0_l9jPX>ooooo`;o2NX:G?ooool00:3ooooo0_l9jPX>ooooo`;o2NX:3_ooool2o`WZ
2Ukooooo002Nooooo`;o2NX:3_ooool2o`WZ2Poooooo00?o2NX:ooooooooool0G_ooool007Cooooo
00?o0000ooooooooool09_ooool00ol9jP[oooooooooo`0=ooooo`03o`WZ2_oooooooooo00gooooo
0_l9jPYQooooo`00M?ooool00ol0003oooooooooo`0Tooooo`;o2NX:3_ooool2o`WZ2Pkooooo0_l9
jPYSooooo`00M?ooool00ol0003oooooooooo`0Rooooo`;o2NX:3_ooool2o`WZ2Pkooooo0_l9jPYU
ooooo`00MOooool00ol0003oooooooooo`0Oooooo`;o2NX:3_ooool2o`WZ2Poooooo00?o2NX:oooo
ooooool0IOooool007Gooooo00?o0000ooooooooool07_ooool00ol9jP[oooooooooo`0=ooooo`03
o`WZ2_oooooooooo00gooooo0_l9jPYXooooo`00MOooool2o`0001gooooo0_l9jPX>ooooo`;o2NX:
3_ooool2o`WZ2V[ooooo001fooooo`;o00006_ooool2o`WZ2Pkooooo0_l9jPX>ooooo`;o2NX:K?oo
ool007Oooooo00?o0000ooooooooool05_ooool2o`WZ2Poooooo00?o2NX:ooooooooool03Oooool0
0ol9jP[oooooooooo`1/ooooo`00Moooool2o`0001Kooooo00?o2NX:ooooooooool03Oooool2o`WZ
2Pkooooo0_l9jPY_ooooo`00N?ooool00ol0003oooooooooo`0Booooo`;o2NX:3_ooool2o`WZ2Pko
oooo0_l9jPYaooooo`00NOooool00ol0003oooooooooo`0?ooooo`;o2NX:3_ooool2o`WZ2Pkooooo
0_l9jPYcooooo`00NOooool00ol0003oooooooooo`0=ooooo`;o2NX:3oooool00ol9jP[ooooooooo
o`0=ooooo`03o`WZ2_oooooooooo07?ooooo001jooooo`03o`000?oooooooooo00_ooooo00?o2NX:
ooooooooool03Oooool2o`WZ2Pkooooo0_l9jPYfooooo`00N_ooool2o`0000Oooooo0_l9jPX00ooo
oooo2NX:o`WZ2P0>ooooo`;o2NX:3_ooool2o`WZ2WSooooo001kooooo`03o`000?oooooooooo00Co
oooo1?l9jPX>ooooo`;o2NX:3_ooool2o`WZ2W[ooooo001looooo`03o`000?oooooooooo00;ooooo
1Ol9jPX=ooooo`03o`WZ2_oooooooooo00gooooo00?o2NX:ooooooooool0N_ooool007cooooo00Co
0000oooooooooooooooo1ol9jPX:ooooo`;o2NX:3_ooool2o`WZ2Wgooooo001mooooo`03o`000?oo
oooo2NX:00Co2NX:2oooool2o`WZ2Pkooooo0_l9jPYoooooo`00OOooool2o`000003o`WZ2_oooooo
oooo00_ooooo0_l9jPX>ooooo`;o2NX:POooool007gooooo0_l00009ooooo`05o`WZ2_oooooooooo
ooooool9jPX03oooool00ol9jP[oooooooooo`21ooooo`00Ooooool00ol0003oooooooooo`05oooo
o`;o2NX:00?oooooo`WZ2_l9jPX03_ooool2o`WZ2XCooooo001oooooo`03o`000?oooooooooo00Co
oooo1?l9jPX>ooooo`;o2NX:Q_ooool0083ooooo00?o0000ooooooooool00_ooool5o`WZ2Pgooooo
00?o2NX:ooooooooool0Q_ooool0083ooooo00Co0000oooooooooooooooo1ol9jPX:ooooo`;o2NX:
ROooool0087ooooo00?o0000ooooool9jPX01?l9jPX;ooooo`;o2NX:Roooool0087ooooo0_l00000
0ol9jP[oooooooooo`0;ooooo`;o2NX:SOooool0087ooooo0_l00009ooooo`05o`WZ2_oooooooooo
ooooool9jPX0Soooool008;ooooo00?o0000ooooooooool01_ooool2o`WZ2P03ooooool9jP[o2NX:
093ooooo0023ooooo`03o`000?oooooooooo00Cooooo1?l9jPZBooooo`00Poooool00ol0003ooooo
ooooo`03ooooo`Go2NX:T_ooool008Cooooo00Co0000oooooooooooooooo1ol9jPZAooooo`00Q?oo
ool2o`000003ooooool9jP[o2NX:00?o2NX:U?ooool008Gooooo0_l000000ol9jP[oooooooooo`2F
ooooo`00QOooool2o`0009Wooooo0026ooooo`03o`000?oooooooooo09Oooooo0027ooooo`03o`00
0?oooooooooo09Kooooo0027ooooo`;o0000Uoooool008Sooooo00?o0000ooooooooool0UOooool0
08Sooooo0_l0002Fooooo`00ROooool00ol0003oooooooooo`2Dooooo`00R_ooool00ol0003ooooo
ooooo`2Cooooo`00Roooool00ol0003oooooooooo`2Booooo`00Roooool00ol0003oooooooooo`2B
ooooo`00S?ooool00ol0003oooooooooo`2Aooooo`00SOooool00ol0003oooooooooo`2@ooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00Soooool3o`0008kooooo002?ooooo`04
o`000?ooooooooooo`0008gooooo002Booooo`03o`000?oooooooooo08_ooooo002@ooooo`;o0000
S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00Co0000oooooooooooo0000SOoo
ool0093ooooo0ol0002=ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {156.625, 0}} -> {-58.6564, -48.5031, 1.00004, \
1.00004}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["wavefront1 = FindWaveFronts[sys1,ZernikeFit->True]//Timing", "Input",
  CellLabel->"In[27]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 4, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 1, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 4, SurfaceNumber -> 1, 
        WaveFrontID -> 1, Source -> 1}],
      Editable->False]], "Print",
  CellLabel->"From In[27]:=",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -117 0 ]
[.5 .82364 117 9 ]
[.13865 .20246 -11.9543 -9 ]
[.13865 .20246 .04573 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.54594 .04229 -5.19627 -9 ]
[.54594 .04229 .80373 0 ]
[.7636 .09113 0 -6.16761 ]
[.7636 .09113 12 2.83239 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93774 .35781 0 -5.91554 ]
[.93774 .35781 6 3.08446 ]
[.01618 .31482 -42 -2.78435 ]
[.01618 .31482 0 6.21565 ]
[.00564 .38091 -42 -2.84042 ]
[.00564 .38091 0 6.15958 ]
[-0.00536 .44984 -42 -2.89917 ]
[-0.00536 .44984 0 6.10083 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Length \\(absolute distance\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.14789 .21178 m
.15252 .21643 L
s
[(-5)] .13865 .20246 .99238 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.5537 .05288 m
.55757 .05817 L
s
[(5)] .54594 .04229 .73209 1 Mshowa
.125 Mabswid
.18577 .19694 m
.18851 .19978 L
s
.22422 .18189 m
.22691 .18476 L
s
.26324 .16661 m
.2659 .16952 L
s
.30285 .1511 m
.30546 .15404 L
s
.3839 .11937 m
.38642 .12239 L
s
.42536 .10313 m
.42784 .10619 L
s
.46747 .08664 m
.4699 .08974 L
s
.51024 .06989 m
.51262 .07303 L
s
.11057 .22639 m
.11338 .22915 L
s
.07378 .2408 m
.07662 .24352 L
s
.03752 .255 m
.0404 .25768 L
s
.59784 .03559 m
.60011 .03881 L
s
.64269 .01803 m
.64491 .02128 L
s
.68828 .00018 m
.69043 .00347 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75129 .09569 m
.74514 .09797 L
s
[(-5)] .7636 .09113 -1 .37058 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92522 .36174 m
.91896 .36371 L
s
[(5)] .93774 .35781 -1 .31456 Mshowa
.125 Mabswid
.7709 .12568 m
.7672 .12703 L
s
.78996 .15483 m
.78625 .15616 L
s
.80849 .18319 m
.80478 .18449 L
s
.82652 .21077 m
.8228 .21206 L
s
.86116 .26375 m
.85743 .265 L
s
.8778 .28921 m
.87406 .29044 L
s
.89402 .31401 m
.89027 .31522 L
s
.90982 .33818 m
.90607 .33938 L
s
.73112 .06483 m
.72743 .06622 L
s
.71035 .03306 m
.70667 .03447 L
s
.68895 .00033 m
.68529 .00177 L
s
.94025 .38473 m
.93649 .38589 L
s
.9549 .40714 m
.95114 .40829 L
s
.96921 .42902 m
.96544 .43016 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02844 .31015 m
.03457 .30781 L
s
[(404.605)] .01618 .31482 1 -0.38126 Mshowa
.01795 .37637 m
.0241 .3741 L
s
[(404.606)] .00564 .38091 1 -0.3688 Mshowa
.007 .44544 m
.01318 .44324 L
s
[(404.606)] -0.00536 .44984 1 -0.35574 Mshowa
.125 Mabswid
.02638 .32317 m
.03006 .32178 L
s
.0243 .3363 m
.02798 .33492 L
s
.0222 .34955 m
.02589 .34817 L
s
.02008 .3629 m
.02377 .36153 L
s
.0158 .38995 m
.01949 .38859 L
s
.01363 .40364 m
.01733 .4023 L
s
.01144 .41746 m
.01514 .41612 L
s
.00923 .43139 m
.01294 .43006 L
s
.03049 .29723 m
.03416 .29582 L
s
.03252 .28442 m
.03619 .28301 L
s
.03453 .27172 m
.0382 .27029 L
s
.03653 .25912 m
.0402 .25768 L
s
.00476 .45962 m
.00847 .45831 L
s
.00249 .47392 m
.00621 .47261 L
s
.0002 .48834 m
.00392 .48705 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.847 .563 0 r
.38877 .76545 .39977 .75678 .41651 .76942 .40574 .77439 Metetra
.9 .389 0 r
.40574 .77439 .41651 .76942 .43365 .77757 .42307 .77902 Metetra
.937 .254 0 r
.42307 .77902 .43365 .77757 .4511 .78187 .4407 .78002 Metetra
.961 .164 0 r
.4407 .78002 .4511 .78187 .46881 .78295 .45855 .77801 Metetra
.973 .115 0 r
.45855 .77801 .46881 .78295 .48671 .78139 .47658 .77361 Metetra
.976 .102 0 r
.47658 .77361 .48671 .78139 .50478 .77773 .49475 .76737 Metetra
.972 .116 0 r
.49475 .76737 .50478 .77773 .52298 .7725 .51303 .7598 Metetra
.964 .149 0 r
.51303 .7598 .52298 .7725 .5413 .76613 .5314 .75136 Metetra
.953 .194 0 r
.5314 .75136 .5413 .76613 .55971 .75904 .54986 .74245 Metetra
.94 .243 0 r
.54986 .74245 .55971 .75904 .57822 .75158 .5684 .73343 Metetra
.928 .291 0 r
.5684 .73343 .57822 .75158 .59682 .74406 .58703 .7246 Metetra
.916 .335 0 r
.58703 .7246 .59682 .74406 .61553 .73671 .60575 .71619 Metetra
.905 .371 0 r
.60575 .71619 .61553 .73671 .63435 .72975 .62458 .70842 Metetra
.898 .398 0 r
.62458 .70842 .63435 .72975 .6533 .72332 .64354 .70141 Metetra
.893 .415 0 r
.64354 .70141 .6533 .72332 .6724 .71752 .66264 .69528 Metetra
.891 .421 0 r
.66264 .69528 .6724 .71752 .69165 .71241 .68191 .69008 Metetra
.893 .415 0 r
.68191 .69008 .69165 .71241 .71106 .70798 .70136 .68581 Metetra
.898 .398 0 r
.70136 .68581 .71106 .70798 .73066 .7042 .721 .68243 Metetra
.905 .371 0 r
.721 .68243 .73066 .7042 .75045 .70097 .74085 .67984 Metetra
.916 .335 0 r
.74085 .67984 .75045 .70097 .77043 .69814 .76092 .67792 Metetra
.928 .291 0 r
.76092 .67792 .77043 .69814 .79058 .69551 .7812 .67645 Metetra
.94 .243 0 r
.7812 .67645 .79058 .69551 .81091 .69283 .80169 .67521 Metetra
.953 .194 0 r
.80169 .67521 .81091 .69283 .83139 .68979 .82236 .67387 Metetra
.964 .149 0 r
.82236 .67387 .83139 .68979 .85196 .68602 .84319 .67209 Metetra
.972 .116 0 r
.84319 .67209 .85196 .68602 .87259 .68108 .86413 .66942 Metetra
.976 .102 0 r
.86413 .66942 .87259 .68108 .8932 .67449 .88511 .66539 Metetra
.973 .115 0 r
.88511 .66539 .8932 .67449 .9137 .66569 .90605 .65944 Metetra
.961 .164 0 r
.90605 .65944 .9137 .66569 .93399 .65409 .92685 .65096 Metetra
.937 .254 0 r
.92685 .65096 .93399 .65409 .95392 .63903 .94739 .63928 Metetra
.9 .389 0 r
.94739 .63928 .95392 .63903 .97336 .61983 .9675 .6237 Metetra
.847 .563 0 r
.9675 .6237 .97336 .61983 .99211 .59578 .98702 .60347 Metetra
.9 .389 0 r
.37773 .7696 .38877 .76545 .40574 .77439 .39491 .77502 Metetra
.94 .245 0 r
.39491 .77502 .40574 .77439 .42307 .77902 .41243 .77632 Metetra
.963 .153 0 r
.41243 .77632 .42307 .77902 .4407 .78002 .43023 .77419 Metetra
.974 .108 0 r
.43023 .77419 .4407 .78002 .45855 .77801 .44822 .76929 Metetra
.975 .105 0 r
.44822 .76929 .45855 .77801 .47658 .77361 .46637 .76223 Metetra
.968 .133 0 r
.46637 .76223 .47658 .77361 .49475 .76737 .48464 .75357 Metetra
.956 .184 0 r
.48464 .75357 .49475 .76737 .51303 .7598 .50299 .74384 Metetra
.939 .247 0 r
.50299 .74384 .51303 .7598 .5314 .75136 .52142 .73348 Metetra
.921 .315 0 r
.52142 .73348 .5314 .75136 .54986 .74245 .53992 .72289 Metetra
.902 .382 0 r
.53992 .72289 .54986 .74245 .5684 .73343 .55849 .71243 Metetra
.884 .443 0 r
.55849 .71243 .5684 .73343 .58703 .7246 .57713 .70239 Metetra
.868 .496 0 r
.57713 .70239 .58703 .7246 .60575 .71619 .59586 .693 Metetra
.855 .538 0 r
.59586 .693 .60575 .71619 .62458 .70842 .61469 .68447 Metetra
.845 .569 0 r
.61469 .68447 .62458 .70842 .64354 .70141 .63365 .67693 Metetra
.838 .588 0 r
.63365 .67693 .64354 .70141 .66264 .69528 .65275 .67049 Metetra
.836 .594 0 r
.65275 .67049 .66264 .69528 .68191 .69008 .67202 .66519 Metetra
.838 .588 0 r
.67202 .66519 .68191 .69008 .70136 .68581 .69148 .66104 Metetra
.845 .569 0 r
.69148 .66104 .70136 .68581 .721 .68243 .71115 .65801 Metetra
.855 .538 0 r
.71115 .65801 .721 .68243 .74085 .67984 .73105 .656 Metetra
.868 .496 0 r
.73105 .656 .74085 .67984 .76092 .67792 .75118 .65488 Metetra
.884 .443 0 r
.75118 .65488 .76092 .67792 .7812 .67645 .77155 .65447 Metetra
.902 .382 0 r
.77155 .65447 .7812 .67645 .80169 .67521 .79216 .65452 Metetra
.921 .315 0 r
.79216 .65452 .80169 .67521 .82236 .67387 .813 .65474 Metetra
.939 .247 0 r
.813 .65474 .82236 .67387 .84319 .67209 .83404 .65477 Metetra
.956 .184 0 r
.83404 .65477 .84319 .67209 .86413 .66942 .85523 .65419 Metetra
.968 .133 0 r
.85523 .65419 .86413 .66942 .88511 .66539 .87654 .65251 Metetra
.975 .105 0 r
.87654 .65251 .88511 .66539 .90605 .65944 .89787 .6492 Metetra
.974 .108 0 r
.89787 .6492 .90605 .65944 .92685 .65096 .91912 .64362 Metetra
.963 .153 0 r
.91912 .64362 .92685 .65096 .94739 .63928 .94019 .63512 Metetra
.94 .245 0 r
.94019 .63512 .94739 .63928 .9675 .6237 .96092 .62295 Metetra
.9 .389 0 r
.96092 .62295 .9675 .6237 .98702 .60347 .98114 .60635 Metetra
.937 .254 0 r
.36664 .76986 .37773 .7696 .39491 .77502 .38403 .77196 Metetra
.963 .153 0 r
.38403 .77196 .39491 .77502 .41243 .77632 .40175 .77013 Metetra
.975 .106 0 r
.40175 .77013 .41243 .77632 .43023 .77419 .4197 .76508 Metetra
.974 .108 0 r
.4197 .76508 .43023 .77419 .44822 .76929 .43784 .75748 Metetra
.965 .147 0 r
.43784 .75748 .44822 .76929 .46637 .76223 .4561 .74796 Metetra
.949 .211 0 r
.4561 .74796 .46637 .76223 .48464 .75357 .47446 .73708 Metetra
.928 .291 0 r
.47446 .73708 .48464 .75357 .50299 .74384 .49289 .72535 Metetra
.904 .376 0 r
.49289 .72535 .50299 .74384 .52142 .73348 .51138 .71322 Metetra
.879 .461 0 r
.51138 .71322 .52142 .73348 .53992 .72289 .52991 .70109 Metetra
.855 .538 0 r
.52991 .70109 .53992 .72289 .55849 .71243 .5485 .68931 Metetra
.832 .606 0 r
.5485 .68931 .55849 .71243 .57713 .70239 .56715 .67816 Metetra
.812 .662 0 r
.56715 .67816 .57713 .70239 .59586 .693 .58588 .66788 Metetra
.795 .705 0 r
.58588 .66788 .59586 .693 .61469 .68447 .60471 .65865 Metetra
.783 .736 0 r
.60471 .65865 .61469 .68447 .63365 .67693 .62366 .65062 Metetra
.776 .754 0 r
.62366 .65062 .63365 .67693 .65275 .67049 .64276 .64388 Metetra
.773 .76 0 r
.64276 .64388 .65275 .67049 .67202 .66519 .66202 .63848 Metetra
.776 .754 0 r
.66202 .63848 .67202 .66519 .69148 .66104 .68149 .63443 Metetra
.783 .736 0 r
.68149 .63443 .69148 .66104 .71115 .65801 .70117 .6317 Metetra
.795 .705 0 r
.70117 .6317 .71115 .65801 .73105 .656 .72108 .6302 Metetra
.812 .662 0 r
.72108 .6302 .73105 .656 .75118 .65488 .74126 .6298 Metetra
.832 .606 0 r
.74126 .6298 .75118 .65488 .77155 .65447 .7617 .63032 Metetra
.855 .538 0 r
.7617 .63032 .77155 .65447 .79216 .65452 .78241 .63153 Metetra
.879 .461 0 r
.78241 .63153 .79216 .65452 .813 .65474 .80337 .63314 Metetra
.904 .376 0 r
.80337 .63314 .813 .65474 .83404 .65477 .82458 .63481 Metetra
.928 .291 0 r
.82458 .63481 .83404 .65477 .85523 .65419 .846 .63613 Metetra
.949 .211 0 r
.846 .63613 .85523 .65419 .87654 .65251 .86758 .63661 Metetra
.965 .147 0 r
.86758 .63661 .87654 .65251 .89787 .6492 .88924 .63571 Metetra
.974 .108 0 r
.88924 .63571 .89787 .6492 .91912 .64362 .9109 .63281 Metetra
.975 .106 0 r
.9109 .63281 .91912 .64362 .94019 .63512 .93244 .62725 Metetra
.963 .153 0 r
.93244 .62725 .94019 .63512 .96092 .62295 .95372 .61826 Metetra
.937 .254 0 r
.95372 .61826 .96092 .62295 .98114 .60635 .97458 .60507 Metetra
.961 .164 0 r
.35552 .76682 .36664 .76986 .38403 .77196 .37312 .76582 Metetra
.974 .108 0 r
.37312 .76582 .38403 .77196 .40175 .77013 .39102 .76108 Metetra
.974 .108 0 r
.39102 .76108 .40175 .77013 .4197 .76508 .40913 .75334 Metetra
.964 .152 0 r
.40913 .75334 .4197 .76508 .43784 .75748 .42741 .74326 Metetra
.945 .226 0 r
.42741 .74326 .43784 .75748 .4561 .74796 .44579 .73147 Metetra
.92 .32 0 r
.44579 .73147 .4561 .74796 .47446 .73708 .46424 .71855 Metetra
.891 .42 0 r
.46424 .71855 .47446 .73708 .49289 .72535 .48274 .70499 Metetra
.861 .52 0 r
.48274 .70499 .49289 .72535 .51138 .71322 .50128 .69126 Metetra
.83 .612 0 r
.50128 .69126 .51138 .71322 .52991 .70109 .51985 .67773 Metetra
.8 .693 0 r
.51985 .67773 .52991 .70109 .5485 .68931 .53846 .66475 Metetra
.773 .76 0 r
.53846 .66475 .5485 .68931 .56715 .67816 .55713 .65259 Metetra
.685 .749 0 r
.55713 .65259 .56715 .67816 .58588 .66788 .57586 .64149 Metetra
.606 .73 0 r
.57586 .64149 .58588 .66788 .60471 .65865 .59468 .63162 Metetra
.551 .716 0 r
.59468 .63162 .60471 .65865 .62366 .65062 .61362 .62314 Metetra
.517 .707 0 r
.61362 .62314 .62366 .65062 .64276 .64388 .6327 .61612 Metetra
.506 .704 0 r
.6327 .61612 .64276 .64388 .66202 .63848 .65196 .61062 Metetra
.517 .707 0 r
.65196 .61062 .66202 .63848 .68149 .63443 .67141 .60665 Metetra
.551 .716 0 r
.67141 .60665 .68149 .63443 .70117 .6317 .69109 .60417 Metetra
.606 .73 0 r
.69109 .60417 .70117 .6317 .72108 .6302 .71102 .60311 Metetra
.685 .749 0 r
.71102 .60311 .72108 .6302 .74126 .6298 .73122 .60333 Metetra
.773 .76 0 r
.73122 .60333 .74126 .6298 .7617 .63032 .75171 .60468 Metetra
.8 .693 0 r
.75171 .60468 .7617 .63032 .78241 .63153 .77249 .60693 Metetra
.83 .612 0 r
.77249 .60693 .78241 .63153 .80337 .63314 .79356 .60979 Metetra
.861 .52 0 r
.79356 .60979 .80337 .63314 .82458 .63481 .81491 .61293 Metetra
.891 .42 0 r
.81491 .61293 .82458 .63481 .846 .63613 .83651 .61594 Metetra
.92 .32 0 r
.83651 .61594 .846 .63613 .86758 .63661 .85831 .61837 Metetra
.945 .226 0 r
.85831 .61837 .86758 .63661 .88924 .63571 .88026 .61966 Metetra
.964 .152 0 r
.88026 .61966 .88924 .63571 .9109 .63281 .90227 .61921 Metetra
.974 .108 0 r
.90227 .61921 .9109 .63281 .93244 .62725 .92423 .61634 Metetra
.974 .108 0 r
.92423 .61634 .93244 .62725 .95372 .61826 .94601 .61029 Metetra
.961 .164 0 r
.94601 .61029 .95372 .61826 .97458 .60507 .96743 .60026 Metetra
.973 .115 0 r
.34435 .76106 .35552 .76682 .37312 .76582 .36216 .7572 Metetra
.975 .105 0 r
.36216 .7572 .37312 .76582 .39102 .76108 .38024 .74979 Metetra
.965 .147 0 r
.38024 .74979 .39102 .76108 .40913 .75334 .39852 .73957 Metetra
.945 .226 0 r
.39852 .73957 .40913 .75334 .42741 .74326 .41692 .72723 Metetra
.917 .329 0 r
.41692 .72723 .42741 .74326 .44579 .73147 .43542 .71338 Metetra
.884 .443 0 r
.43542 .71338 .44579 .73147 .46424 .71855 .45396 .6986 Metetra
.849 .556 0 r
.45396 .6986 .46424 .71855 .48274 .70499 .47254 .6834 Metetra
.812 .662 0 r
.47254 .6834 .48274 .70499 .50128 .69126 .49113 .6682 Metetra
.776 .754 0 r
.49113 .6682 .50128 .69126 .51985 .67773 .50975 .65341 Metetra
.651 .741 0 r
.50975 .65341 .51985 .67773 .53846 .66475 .52838 .63934 Metetra
.528 .71 0 r
.52838 .63934 .53846 .66475 .55713 .65259 .54706 .62628 Metetra
.429 .683 0 r
.54706 .62628 .55713 .65259 .57586 .64149 .5658 .61443 Metetra
.353 .662 0 r
.5658 .61443 .57586 .64149 .59468 .63162 .58461 .60399 Metetra
.299 .646 0 r
.58461 .60399 .59468 .63162 .61362 .62314 .60354 .59509 Metetra
.268 .636 0 r
.60354 .59509 .61362 .62314 .6327 .61612 .62261 .58781 Metetra
.257 .632 0 r
.62261 .58781 .6327 .61612 .65196 .61062 .64185 .58221 Metetra
.268 .636 0 r
.64185 .58221 .65196 .61062 .67141 .60665 .66129 .57829 Metetra
.299 .646 0 r
.66129 .57829 .67141 .60665 .69109 .60417 .68096 .57603 Metetra
.353 .662 0 r
.68096 .57603 .69109 .60417 .71102 .60311 .7009 .57534 Metetra
.429 .683 0 r
.7009 .57534 .71102 .60311 .73122 .60333 .72111 .57611 Metetra
.528 .71 0 r
.72111 .57611 .73122 .60333 .75171 .60468 .74163 .57818 Metetra
.651 .741 0 r
.74163 .57818 .75171 .60468 .77249 .60693 .76246 .58133 Metetra
.776 .754 0 r
.76246 .58133 .77249 .60693 .79356 .60979 .78361 .58529 Metetra
.812 .662 0 r
.78361 .58529 .79356 .60979 .81491 .61293 .80507 .58974 Metetra
.849 .556 0 r
.80507 .58974 .81491 .61293 .83651 .61594 .82682 .59427 Metetra
.884 .443 0 r
.82682 .59427 .83651 .61594 .85831 .61837 .84882 .59844 Metetra
.917 .329 0 r
.84882 .59844 .85831 .61837 .88026 .61966 .87102 .6017 Metetra
.945 .226 0 r
.87102 .6017 .88026 .61966 .90227 .61921 .89333 .60346 Metetra
.965 .147 0 r
.89333 .60346 .90227 .61921 .92423 .61634 .91566 .60302 Metetra
.975 .105 0 r
.91566 .60302 .92423 .61634 .94601 .61029 .93787 .59965 Metetra
.973 .115 0 r
.93787 .59965 .94601 .61029 .96743 .60026 .95981 .59252 Metetra
.976 .102 0 r
.33314 .75312 .34435 .76106 .36216 .7572 .35115 .74664 Metetra
.968 .133 0 r
.35115 .74664 .36216 .7572 .38024 .74979 .36941 .7368 Metetra
.949 .211 0 r
.36941 .7368 .38024 .74979 .39852 .73957 .38784 .72434 Metetra
.92 .32 0 r
.38784 .72434 .39852 .73957 .41692 .72723 .40639 .70995 Metetra
.884 .443 0 r
.40639 .70995 .41692 .72723 .43542 .71338 .425 .69424 Metetra
.845 .569 0 r
.425 .69424 .43542 .71338 .45396 .6986 .44364 .6778 Metetra
.803 .687 0 r
.44364 .6778 .45396 .6986 .47254 .6834 .46229 .66111 Metetra
.73 .76 0 r
.46229 .66111 .47254 .6834 .49113 .6682 .48095 .64461 Metetra
.562 .719 0 r
.48095 .64461 .49113 .6682 .50975 .65341 .4996 .62868 Metetra
.418 .68 0 r
.4996 .62868 .50975 .65341 .52838 .63934 .51827 .61364 Metetra
.299 .646 0 r
.51827 .61364 .52838 .63934 .54706 .62628 .53696 .59975 Metetra
.206 .616 0 r
.53696 .59975 .54706 .62628 .5658 .61443 .55571 .58725 Metetra
.136 .592 0 r
.55571 .58725 .5658 .61443 .58461 .60399 .57452 .57628 Metetra
.089 .574 0 r
.57452 .57628 .58461 .60399 .60354 .59509 .59344 .567 Metetra
.061 .563 0 r
.59344 .567 .60354 .59509 .62261 .58781 .6125 .55948 Metetra
.051 .56 0 r
.6125 .55948 .62261 .58781 .64185 .58221 .63172 .55378 Metetra
.061 .563 0 r
.63172 .55378 .64185 .58221 .66129 .57829 .65115 .54989 Metetra
.089 .574 0 r
.65115 .54989 .66129 .57829 .68096 .57603 .67081 .5478 Metetra
.136 .592 0 r
.67081 .5478 .68096 .57603 .7009 .57534 .69074 .54744 Metetra
.206 .616 0 r
.69074 .54744 .7009 .57534 .72111 .57611 .71096 .54868 Metetra
.299 .646 0 r
.71096 .54868 .72111 .57611 .74163 .57818 .7315 .55137 Metetra
.418 .68 0 r
.7315 .55137 .74163 .57818 .76246 .58133 .75237 .55531 Metetra
.562 .719 0 r
.75237 .55531 .76246 .58133 .78361 .58529 .77358 .56023 Metetra
.73 .76 0 r
.77358 .56023 .78361 .58529 .80507 .58974 .79513 .56582 Metetra
.803 .687 0 r
.79513 .56582 .80507 .58974 .82682 .59427 .81701 .57169 Metetra
.845 .569 0 r
.81701 .57169 .82682 .59427 .84882 .59844 .83917 .57739 Metetra
.884 .443 0 r
.83917 .57739 .84882 .59844 .87102 .6017 .86157 .58241 Metetra
.92 .32 0 r
.86157 .58241 .87102 .6017 .89333 .60346 .88414 .58614 Metetra
.949 .211 0 r
.88414 .58614 .89333 .60346 .91566 .60302 .90679 .5879 Metetra
.968 .133 0 r
.90679 .5879 .91566 .60302 .93787 .59965 .92939 .58693 Metetra
.976 .102 0 r
.92939 .58693 .93787 .59965 .95981 .59252 .95177 .58242 Metetra
.972 .116 0 r
.32188 .7435 .33314 .75312 .35115 .74664 .34008 .73466 Metetra
.956 .184 0 r
.34008 .73466 .35115 .74664 .36941 .7368 .35852 .72263 Metetra
.928 .291 0 r
.35852 .72263 .36941 .7368 .38784 .72434 .37711 .70816 Metetra
.891 .42 0 r
.37711 .70816 .38784 .72434 .40639 .70995 .39579 .69192 Metetra
.849 .556 0 r
.39579 .69192 .40639 .70995 .425 .69424 .41452 .67456 Metetra
.803 .687 0 r
.41452 .67456 .425 .69424 .44364 .6778 .43326 .65662 Metetra
.708 .755 0 r
.43326 .65662 .44364 .6778 .46229 .66111 .45199 .63861 Metetra
.517 .707 0 r
.45199 .63861 .46229 .66111 .48095 .64461 .47071 .62095 Metetra
.353 .662 0 r
.47071 .62095 .48095 .64461 .4996 .62868 .48942 .60401 Metetra
.216 .619 0 r
.48942 .60401 .4996 .62868 .51827 .61364 .50812 .5881 Metetra
.108 .581 0 r
.50812 .5881 .51827 .61364 .53696 .59975 .52684 .57349 Metetra
.024 .549 0 r
.52684 .57349 .53696 .59975 .55571 .58725 .54559 .56039 Metetra
0 .523 .036 r
.54559 .56039 .55571 .58725 .57452 .57628 .56441 .54896 Metetra
0 .504 .076 r
.56441 .54896 .57452 .57628 .59344 .567 .58333 .53933 Metetra
0 .492 .099 r
.58333 .53933 .59344 .567 .6125 .55948 .60238 .53159 Metetra
0 .488 .107 r
.60238 .53159 .6125 .55948 .63172 .55378 .62159 .52578 Metetra
0 .492 .099 r
.62159 .52578 .63172 .55378 .65115 .54989 .641 .52192 Metetra
0 .504 .076 r
.641 .52192 .65115 .54989 .67081 .5478 .66066 .51997 Metetra
0 .523 .036 r
.66066 .51997 .67081 .5478 .69074 .54744 .68058 .51987 Metetra
.024 .549 0 r
.68058 .51987 .69074 .54744 .71096 .54868 .7008 .5215 Metetra
.108 .581 0 r
.7008 .5215 .71096 .54868 .7315 .55137 .72135 .52473 Metetra
.216 .619 0 r
.72135 .52473 .7315 .55137 .75237 .55531 .74225 .52934 Metetra
.353 .662 0 r
.74225 .52934 .75237 .55531 .77358 .56023 .76351 .53509 Metetra
.517 .707 0 r
.76351 .53509 .77358 .56023 .79513 .56582 .78513 .54167 Metetra
.708 .755 0 r
.78513 .54167 .79513 .56582 .81701 .57169 .8071 .54871 Metetra
.803 .687 0 r
.8071 .54871 .81701 .57169 .83917 .57739 .8294 .55577 Metetra
.849 .556 0 r
.8294 .55577 .83917 .57739 .86157 .58241 .85198 .56232 Metetra
.891 .42 0 r
.85198 .56232 .86157 .58241 .88414 .58614 .87478 .56779 Metetra
.928 .291 0 r
.87478 .56779 .88414 .58614 .90679 .5879 .8977 .57149 Metetra
.956 .184 0 r
.8977 .57149 .90679 .5879 .92939 .58693 .92063 .57267 Metetra
.972 .116 0 r
.92063 .57267 .92939 .58693 .95177 .58242 .94342 .57051 Metetra
.964 .149 0 r
.31054 .73265 .32188 .7435 .34008 .73466 .32893 .72171 Metetra
.939 .247 0 r
.32893 .72171 .34008 .73466 .35852 .72263 .34755 .70773 Metetra
.904 .376 0 r
.34755 .70773 .35852 .72263 .37711 .70816 .36629 .69147 Metetra
.861 .52 0 r
.36629 .69147 .37711 .70816 .39579 .69192 .38512 .6736 Metetra
.812 .662 0 r
.38512 .6736 .39579 .69192 .41452 .67456 .40396 .65477 Metetra
.73 .76 0 r
.40396 .65477 .41452 .67456 .43326 .65662 .42281 .63552 Metetra
.517 .707 0 r
.42281 .63552 .43326 .65662 .45199 .63861 .44163 .61634 Metetra
.331 .655 0 r
.44163 .61634 .45199 .63861 .47071 .62095 .46042 .59765 Metetra
.176 .606 0 r
.46042 .59765 .47071 .62095 .48942 .60401 .47918 .57982 Metetra
.052 .56 0 r
.47918 .57982 .48942 .60401 .50812 .5881 .49793 .56315 Metetra
0 .519 .044 r
.49793 .56315 .50812 .5881 .52684 .57349 .51668 .5479 Metetra
0 .484 .114 r
.51668 .5479 .52684 .57349 .54559 .56039 .53545 .53427 Metetra
0 .456 .163 r
.53545 .53427 .54559 .56039 .56441 .54896 .55428 .52242 Metetra
0 .436 .194 r
.55428 .52242 .56441 .54896 .58333 .53933 .5732 .51248 Metetra
0 .423 .211 r
.5732 .51248 .58333 .53933 .60238 .53159 .59225 .50454 Metetra
0 .419 .217 r
.59225 .50454 .60238 .53159 .62159 .52578 .61146 .49863 Metetra
0 .423 .211 r
.61146 .49863 .62159 .52578 .641 .52192 .63086 .49476 Metetra
0 .436 .194 r
.63086 .49476 .641 .52192 .66066 .51997 .6505 .49292 Metetra
0 .456 .163 r
.6505 .49292 .66066 .51997 .68058 .51987 .67042 .49303 Metetra
0 .484 .114 r
.67042 .49303 .68058 .51987 .7008 .5215 .69064 .495 Metetra
0 .519 .044 r
.69064 .495 .7008 .5215 .72135 .52473 .7112 .49867 Metetra
.052 .56 0 r
.7112 .49867 .72135 .52473 .74225 .52934 .73212 .50386 Metetra
.176 .606 0 r
.73212 .50386 .74225 .52934 .76351 .53509 .75342 .51032 Metetra
.331 .655 0 r
.75342 .51032 .76351 .53509 .78513 .54167 .7751 .51775 Metetra
.517 .707 0 r
.7751 .51775 .78513 .54167 .8071 .54871 .79715 .52579 Metetra
.73 .76 0 r
.79715 .52579 .8071 .54871 .8294 .55577 .81957 .53401 Metetra
.812 .662 0 r
.81957 .53401 .8294 .55577 .85198 .56232 .8423 .5419 Metetra
.861 .52 0 r
.8423 .5419 .85198 .56232 .87478 .56779 .86528 .54888 Metetra
.904 .376 0 r
.86528 .54888 .87478 .56779 .8977 .57149 .88844 .55428 Metetra
.939 .247 0 r
.88844 .55428 .8977 .57149 .92063 .57267 .91167 .55734 Metetra
.964 .149 0 r
.91167 .55734 .92063 .57267 .94342 .57051 .93481 .55724 Metetra
.953 .194 0 r
.29911 .72097 .31054 .73265 .32893 .72171 .31769 .70819 Metetra
.921 .315 0 r
.31769 .70819 .32893 .72171 .34755 .70773 .33648 .6925 Metetra
.879 .461 0 r
.33648 .6925 .34755 .70773 .36629 .69147 .35539 .67467 Metetra
.83 .612 0 r
.35539 .67467 .36629 .69147 .38512 .6736 .37435 .65538 Metetra
.776 .754 0 r
.37435 .65538 .38512 .6736 .40396 .65477 .39332 .63526 Metetra
.562 .719 0 r
.39332 .63526 .40396 .65477 .42281 .63552 .41228 .61486 Metetra
.353 .662 0 r
.41228 .61486 .42281 .63552 .44163 .61634 .43119 .59466 Metetra
.176 .606 0 r
.43119 .59466 .44163 .61634 .46042 .59765 .45006 .57508 Metetra
.033 .552 0 r
.45006 .57508 .46042 .59765 .47918 .57982 .46889 .55647 Metetra
0 .504 .076 r
.46889 .55647 .47918 .57982 .49793 .56315 .48769 .53913 Metetra
0 .46 .156 r
.48769 .53913 .49793 .56315 .51668 .5479 .50647 .52332 Metetra
0 .423 .211 r
.50647 .52332 .51668 .5479 .53545 .53427 .52528 .50922 Metetra
0 .394 .247 r
.52528 .50922 .53545 .53427 .55428 .52242 .54413 .49701 Metetra
0 .372 .268 r
.54413 .49701 .55428 .52242 .5732 .51248 .56306 .48679 Metetra
0 .359 .279 r
.56306 .48679 .5732 .51248 .59225 .50454 .58211 .47865 Metetra
0 .355 .282 r
.58211 .47865 .59225 .50454 .61146 .49863 .60132 .47264 Metetra
0 .359 .279 r
.60132 .47264 .61146 .49863 .63086 .49476 .62072 .46877 Metetra
0 .372 .268 r
.62072 .46877 .63086 .49476 .6505 .49292 .64036 .467 Metetra
0 .394 .247 r
.64036 .467 .6505 .49292 .67042 .49303 .66028 .46729 Metetra
0 .423 .211 r
.66028 .46729 .67042 .49303 .69064 .495 .6805 .46952 Metetra
0 .46 .156 r
.6805 .46952 .69064 .495 .7112 .49867 .70107 .47356 Metetra
0 .504 .076 r
.70107 .47356 .7112 .49867 .73212 .50386 .72201 .47923 Metetra
.033 .552 0 r
.72201 .47923 .73212 .50386 .75342 .51032 .74333 .48628 Metetra
.176 .606 0 r
.74333 .48628 .75342 .51032 .7751 .51775 .76506 .49443 Metetra
.353 .662 0 r
.76506 .49443 .7751 .51775 .79715 .52579 .78719 .50332 Metetra
.562 .719 0 r
.78719 .50332 .79715 .52579 .81957 .53401 .80969 .51253 Metetra
.776 .754 0 r
.80969 .51253 .81957 .53401 .8423 .5419 .83255 .52156 Metetra
.83 .612 0 r
.83255 .52156 .8423 .5419 .86528 .54888 .8557 .52983 Metetra
.879 .461 0 r
.8557 .52983 .86528 .54888 .88844 .55428 .87907 .53669 Metetra
.921 .315 0 r
.87907 .53669 .88844 .55428 .91167 .55734 .90255 .54138 Metetra
.953 .194 0 r
.90255 .54138 .91167 .55734 .93481 .55724 .92599 .54307 Metetra
.94 .243 0 r
.28757 .70883 .29911 .72097 .31769 .70819 .30634 .69445 Metetra
.902 .382 0 r
.30634 .69445 .31769 .70819 .33648 .6925 .3253 .67728 Metetra
.855 .538 0 r
.3253 .67728 .33648 .6925 .35539 .67467 .34436 .6581 Metetra
.8 .693 0 r
.34436 .6581 .35539 .67467 .37435 .65538 .36347 .63759 Metetra
.651 .741 0 r
.36347 .63759 .37435 .65538 .39332 .63526 .38257 .61637 Metetra
.418 .68 0 r
.38257 .61637 .39332 .63526 .41228 .61486 .40164 .59498 Metetra
.216 .619 0 r
.40164 .59498 .41228 .61486 .43119 .59466 .42066 .5739 Metetra
.052 .56 0 r
.42066 .5739 .43119 .59466 .45006 .57508 .43961 .55355 Metetra
0 .504 .076 r
.43961 .55355 .45006 .57508 .46889 .55647 .45852 .53426 Metetra
0 .452 .169 r
.45852 .53426 .46889 .55647 .48769 .53913 .47738 .51635 Metetra
0 .407 .232 r
.47738 .51635 .48769 .53913 .50647 .52332 .49621 .50004 Metetra
0 .368 .272 r
.49621 .50004 .50647 .52332 .52528 .50922 .51506 .48554 Metetra
0 .337 .294 r
.51506 .48554 .52528 .50922 .54413 .49701 .53394 .473 Metetra
0 .315 .305 r
.53394 .473 .54413 .49701 .56306 .48679 .5529 .46254 Metetra
0 .292 .301 r
.5529 .46254 .56306 .48679 .58211 .47865 .57196 .45423 Metetra
0 .282 .296 r
.57196 .45423 .58211 .47865 .60132 .47264 .59118 .44812 Metetra
0 .292 .301 r
.59118 .44812 .60132 .47264 .62072 .46877 .61059 .44422 Metetra
0 .315 .305 r
.61059 .44422 .62072 .46877 .64036 .467 .63023 .4425 Metetra
0 .337 .294 r
.63023 .4425 .64036 .467 .66028 .46729 .65015 .44292 Metetra
0 .368 .272 r
.65015 .44292 .66028 .46729 .6805 .46952 .67038 .44536 Metetra
0 .407 .232 r
.67038 .44536 .6805 .46952 .70107 .47356 .69096 .4497 Metetra
0 .452 .169 r
.69096 .4497 .70107 .47356 .72201 .47923 .71191 .45575 Metetra
0 .504 .076 r
.71191 .45575 .72201 .47923 .74333 .48628 .73327 .46329 Metetra
.052 .56 0 r
.73327 .46329 .74333 .48628 .76506 .49443 .75504 .47203 Metetra
.216 .619 0 r
.75504 .47203 .76506 .49443 .78719 .50332 .77722 .48162 Metetra
.418 .68 0 r
.77722 .48162 .78719 .50332 .80969 .51253 .79981 .49166 Metetra
.651 .741 0 r
.79981 .49166 .80969 .51253 .83255 .52156 .82278 .50164 Metetra
.8 .693 0 r
.82278 .50164 .83255 .52156 .8557 .52983 .84607 .511 Metetra
.855 .538 0 r
.84607 .511 .8557 .52983 .87907 .53669 .86961 .51909 Metetra
.902 .382 0 r
.86961 .51909 .87907 .53669 .90255 .54138 .89331 .52515 Metetra
.94 .243 0 r
.89331 .52515 .90255 .54138 .92599 .54307 .91702 .52835 Metetra
.928 .291 0 r
.27591 .69652 .28757 .70883 .30634 .69445 .29486 .68079 Metetra
.884 .443 0 r
.29486 .68079 .30634 .69445 .3253 .67728 .31398 .66239 Metetra
.832 .606 0 r
.31398 .66239 .3253 .67728 .34436 .6581 .3332 .64207 Metetra
.773 .76 0 r
.3332 .64207 .34436 .6581 .36347 .63759 .35246 .62052 Metetra
.528 .71 0 r
.35246 .62052 .36347 .63759 .38257 .61637 .3717 .59836 Metetra
.299 .646 0 r
.3717 .59836 .38257 .61637 .40164 .59498 .39089 .57614 Metetra
.108 .581 0 r
.39089 .57614 .40164 .59498 .42066 .5739 .41001 .55432 Metetra
0 .519 .044 r
.41001 .55432 .42066 .5739 .43961 .55355 .42906 .53331 Metetra
0 .46 .156 r
.42906 .53331 .43961 .55355 .45852 .53426 .44805 .51345 Metetra
0 .407 .232 r
.44805 .51345 .45852 .53426 .47738 .51635 .46698 .49504 Metetra
0 .359 .279 r
.46698 .49504 .47738 .51635 .49621 .50004 .48588 .47832 Metetra
0 .319 .303 r
.48588 .47832 .49621 .50004 .51506 .48554 .50478 .46347 Metetra
0 .262 .287 r
.50478 .46347 .51506 .48554 .53394 .473 .5237 .45064 Metetra
0 .214 .264 r
.5237 .45064 .53394 .473 .5529 .46254 .54269 .43996 Metetra
0 .187 .25 r
.54269 .43996 .5529 .46254 .57196 .45423 .56178 .43149 Metetra
0 .179 .245 r
.56178 .43149 .57196 .45423 .59118 .44812 .58102 .42528 Metetra
0 .187 .25 r
.58102 .42528 .59118 .44812 .61059 .44422 .60044 .42135 Metetra
0 .214 .264 r
.60044 .42135 .61059 .44422 .63023 .4425 .6201 .41966 Metetra
0 .262 .287 r
.6201 .41966 .63023 .4425 .65015 .44292 .64003 .42017 Metetra
0 .319 .303 r
.64003 .42017 .65015 .44292 .67038 .44536 .66027 .42277 Metetra
0 .359 .279 r
.66027 .42277 .67038 .44536 .69096 .4497 .68087 .42734 Metetra
0 .407 .232 r
.68087 .42734 .69096 .4497 .71191 .45575 .70184 .4337 Metetra
0 .46 .156 r
.70184 .4337 .71191 .45575 .73327 .46329 .72322 .44162 Metetra
0 .519 .044 r
.72322 .44162 .73327 .46329 .75504 .47203 .74503 .45083 Metetra
.108 .581 0 r
.74503 .45083 .75504 .47203 .77722 .48162 .76727 .46099 Metetra
.299 .646 0 r
.76727 .46099 .77722 .48162 .79981 .49166 .78993 .47169 Metetra
.528 .71 0 r
.78993 .47169 .79981 .49166 .82278 .50164 .81299 .48245 Metetra
.773 .76 0 r
.81299 .48245 .82278 .50164 .84607 .511 .83641 .4927 Metetra
.832 .606 0 r
.83641 .4927 .84607 .511 .86961 .51909 .86011 .50178 Metetra
.884 .443 0 r
.86011 .50178 .86961 .51909 .89331 .52515 .88399 .50897 Metetra
.928 .291 0 r
.88399 .50897 .89331 .52515 .91702 .52835 .90794 .51342 Metetra
.916 .335 0 r
.2641 .6843 .27591 .69652 .29486 .68079 .28321 .66747 Metetra
.868 .496 0 r
.28321 .66747 .29486 .68079 .31398 .66239 .30251 .64805 Metetra
.812 .662 0 r
.30251 .64805 .31398 .66239 .3332 .64207 .32189 .6268 Metetra
.685 .749 0 r
.32189 .6268 .3332 .64207 .35246 .62052 .34129 .6044 Metetra
.429 .683 0 r
.34129 .6044 .35246 .62052 .3717 .59836 .36067 .58148 Metetra
.206 .616 0 r
.36067 .58148 .3717 .59836 .39089 .57614 .37999 .55857 Metetra
.024 .549 0 r
.37999 .55857 .39089 .57614 .41001 .55432 .39923 .53613 Metetra
0 .484 .114 r
.39923 .53613 .41001 .55432 .42906 .53331 .41839 .51458 Metetra
0 .423 .211 r
.41839 .51458 .42906 .53331 .44805 .51345 .43747 .49425 Metetra
0 .368 .272 r
.43747 .49425 .44805 .51345 .46698 .49504 .45648 .47542 Metetra
0 .319 .303 r
.45648 .47542 .46698 .49504 .48588 .47832 .47546 .45834 Metetra
0 .242 .278 r
.47546 .45834 .48588 .47832 .50478 .46347 .49442 .44319 Metetra
0 .179 .245 r
.49442 .44319 .50478 .46347 .5237 .45064 .5134 .43013 Metetra
0 .138 .221 r
.5134 .43013 .5237 .45064 .54269 .43996 .53243 .41925 Metetra
0 .116 .206 r
.53243 .41925 .54269 .43996 .56178 .43149 .55156 .41064 Metetra
0 .109 .202 r
.55156 .41064 .56178 .43149 .58102 .42528 .57083 .40434 Metetra
0 .116 .206 r
.57083 .40434 .58102 .42528 .60044 .42135 .59028 .40036 Metetra
0 .138 .221 r
.59028 .40036 .60044 .42135 .6201 .41966 .60996 .39867 Metetra
0 .179 .245 r
.60996 .39867 .6201 .41966 .64003 .42017 .62991 .39923 Metetra
0 .242 .278 r
.62991 .39923 .64003 .42017 .66027 .42277 .65018 .40194 Metetra
0 .319 .303 r
.65018 .40194 .66027 .42277 .68087 .42734 .67079 .40668 Metetra
0 .368 .272 r
.67079 .40668 .68087 .42734 .70184 .4337 .69179 .41326 Metetra
0 .423 .211 r
.69179 .41326 .70184 .4337 .72322 .44162 .7132 .42148 Metetra
0 .484 .114 r
.7132 .42148 .72322 .44162 .74503 .45083 .73505 .43105 Metetra
.024 .549 0 r
.73505 .43105 .74503 .45083 .76727 .46099 .75734 .44165 Metetra
.206 .616 0 r
.75734 .44165 .76727 .46099 .78993 .47169 .78007 .45286 Metetra
.429 .683 0 r
.78007 .45286 .78993 .47169 .81299 .48245 .80321 .46422 Metetra
.685 .749 0 r
.80321 .46422 .81299 .48245 .83641 .4927 .82674 .47516 Metetra
.812 .662 0 r
.82674 .47516 .83641 .4927 .86011 .50178 .85057 .48504 Metetra
.868 .496 0 r
.85057 .48504 .86011 .50178 .88399 .50897 .87462 .49311 Metetra
.916 .335 0 r
.87462 .49311 .88399 .50897 .90794 .51342 .89876 .49854 Metetra
.905 .371 0 r
.25211 .67236 .2641 .6843 .28321 .66747 .2714 .65468 Metetra
.855 .538 0 r
.2714 .65468 .28321 .66747 .30251 .64805 .29085 .63447 Metetra
.795 .705 0 r
.29085 .63447 .30251 .64805 .32189 .6268 .31039 .61249 Metetra
.606 .73 0 r
.31039 .61249 .32189 .6268 .34129 .6044 .32994 .58943 Metetra
.353 .662 0 r
.32994 .58943 .34129 .6044 .36067 .58148 .34947 .5659 Metetra
.136 .592 0 r
.34947 .5659 .36067 .58148 .37999 .55857 .36892 .54244 Metetra
0 .523 .036 r
.36892 .54244 .37999 .55857 .39923 .53613 .38829 .51951 Metetra
0 .456 .163 r
.38829 .51951 .39923 .53613 .41839 .51458 .40756 .49753 Metetra
0 .394 .247 r
.40756 .49753 .41839 .51458 .43747 .49425 .42675 .47681 Metetra
0 .337 .294 r
.42675 .47681 .43747 .49425 .45648 .47542 .44586 .45765 Metetra
0 .262 .287 r
.44586 .45765 .45648 .47542 .47546 .45834 .46492 .44028 Metetra
0 .179 .245 r
.46492 .44028 .47546 .45834 .49442 .44319 .48396 .42488 Metetra
0 .123 .211 r
.48396 .42488 .49442 .44319 .5134 .43013 .503 .4116 Metetra
0 .089 .187 r
.503 .4116 .5134 .43013 .53243 .41925 .5221 .40056 Metetra
0 .071 .172 r
.5221 .40056 .53243 .41925 .55156 .41064 .54128 .39182 Metetra
0 .065 .167 r
.54128 .39182 .55156 .41064 .57083 .40434 .56059 .38542 Metetra
0 .071 .172 r
.56059 .38542 .57083 .40434 .59028 .40036 .58009 .38139 Metetra
0 .089 .187 r
.58009 .38139 .59028 .40036 .60996 .39867 .5998 .37969 Metetra
0 .123 .211 r
.5998 .37969 .60996 .39867 .62991 .39923 .61978 .38027 Metetra
0 .179 .245 r
.61978 .38027 .62991 .39923 .65018 .40194 .64008 .38304 Metetra
0 .262 .287 r
.64008 .38304 .65018 .40194 .67079 .40668 .66072 .38789 Metetra
0 .337 .294 r
.66072 .38789 .67079 .40668 .69179 .41326 .68175 .39462 Metetra
0 .394 .247 r
.68175 .39462 .69179 .41326 .7132 .42148 .7032 .40304 Metetra
0 .456 .163 r
.7032 .40304 .7132 .42148 .73505 .43105 .72509 .41287 Metetra
0 .523 .036 r
.72509 .41287 .73505 .43105 .75734 .44165 .74743 .42377 Metetra
.136 .592 0 r
.74743 .42377 .75734 .44165 .78007 .45286 .77022 .43536 Metetra
.353 .662 0 r
.77022 .43536 .78007 .45286 .80321 .46422 .79345 .44716 Metetra
.606 .73 0 r
.79345 .44716 .80321 .46422 .82674 .47516 .81706 .4586 Metetra
.795 .705 0 r
.81706 .4586 .82674 .47516 .85057 .48504 .84101 .46906 Metetra
.855 .538 0 r
.84101 .46906 .85057 .48504 .87462 .49311 .8652 .47777 Metetra
.905 .371 0 r
.8652 .47777 .87462 .49311 .89876 .49854 .88952 .48392 Metetra
.898 .398 0 r
.23994 .66087 .25211 .67236 .2714 .65468 .25938 .64258 Metetra
.845 .569 0 r
.25938 .64258 .2714 .65468 .29085 .63447 .27899 .6218 Metetra
.783 .736 0 r
.27899 .6218 .29085 .63447 .31039 .61249 .29869 .59929 Metetra
.551 .716 0 r
.29869 .59929 .31039 .61249 .32994 .58943 .31839 .57574 Metetra
.299 .646 0 r
.31839 .57574 .32994 .58943 .34947 .5659 .33806 .55176 Metetra
.089 .574 0 r
.33806 .55176 .34947 .5659 .36892 .54244 .35766 .52789 Metetra
0 .504 .076 r
.35766 .52789 .36892 .54244 .38829 .51951 .37716 .5046 Metetra
0 .436 .194 r
.37716 .5046 .38829 .51951 .40756 .49753 .39656 .48228 Metetra
0 .372 .268 r
.39656 .48228 .40756 .49753 .42675 .47681 .41586 .46126 Metetra
0 .315 .305 r
.41586 .46126 .42675 .47681 .44586 .45765 .43508 .44184 Metetra
0 .214 .264 r
.43508 .44184 .44586 .45765 .46492 .44028 .45424 .42424 Metetra
0 .138 .221 r
.45424 .42424 .46492 .44028 .48396 .42488 .47337 .40864 Metetra
0 .089 .187 r
.47337 .40864 .48396 .42488 .503 .4116 .4925 .39519 Metetra
0 .06 .162 r
.4925 .39519 .503 .4116 .5221 .40056 .51166 .384 Metetra
0 .045 .147 r
.51166 .384 .5221 .40056 .54128 .39182 .53091 .37514 Metetra
0 .04 .142 r
.53091 .37514 .54128 .39182 .56059 .38542 .55029 .36866 Metetra
0 .045 .147 r
.55029 .36866 .56059 .38542 .58009 .38139 .56983 .36456 Metetra
0 .06 .162 r
.56983 .36456 .58009 .38139 .5998 .37969 .5896 .36282 Metetra
0 .089 .187 r
.5896 .36282 .5998 .37969 .61978 .38027 .60963 .3634 Metetra
0 .138 .221 r
.60963 .3634 .61978 .38027 .64008 .38304 .62996 .36619 Metetra
0 .214 .264 r
.62996 .36619 .64008 .38304 .66072 .38789 .65065 .37108 Metetra
0 .315 .305 r
.65065 .37108 .66072 .38789 .68175 .39462 .67172 .3779 Metetra
0 .372 .268 r
.67172 .3779 .68175 .39462 .7032 .40304 .69321 .38643 Metetra
0 .436 .194 r
.69321 .38643 .7032 .40304 .72509 .41287 .71515 .39641 Metetra
0 .504 .076 r
.71515 .39641 .72509 .41287 .74743 .42377 .73754 .40751 Metetra
.089 .574 0 r
.73754 .40751 .74743 .42377 .77022 .43536 .76039 .41933 Metetra
.299 .646 0 r
.76039 .41933 .77022 .43536 .79345 .44716 .78369 .4314 Metetra
.551 .716 0 r
.78369 .4314 .79345 .44716 .81706 .4586 .80739 .44317 Metetra
.783 .736 0 r
.80739 .44317 .81706 .4586 .84101 .46906 .83144 .45399 Metetra
.845 .569 0 r
.83144 .45399 .84101 .46906 .8652 .47777 .85576 .46312 Metetra
.898 .398 0 r
.85576 .46312 .8652 .47777 .88952 .48392 .88022 .46972 Metetra
.893 .415 0 r
.22756 .64993 .23994 .66087 .25938 .64258 .24714 .63128 Metetra
.838 .588 0 r
.24714 .63128 .25938 .64258 .27899 .6218 .2669 .61014 Metetra
.776 .754 0 r
.2669 .61014 .27899 .6218 .29869 .59929 .28675 .5873 Metetra
.517 .707 0 r
.28675 .5873 .29869 .59929 .31839 .57574 .30661 .56343 Metetra
.268 .636 0 r
.30661 .56343 .31839 .57574 .33806 .55176 .32643 .53916 Metetra
.061 .563 0 r
.32643 .53916 .33806 .55176 .35766 .52789 .34617 .51502 Metetra
0 .492 .099 r
.34617 .51502 .35766 .52789 .37716 .5046 .36582 .49148 Metetra
0 .423 .211 r
.36582 .49148 .37716 .5046 .39656 .48228 .38535 .46892 Metetra
0 .359 .279 r
.38535 .46892 .39656 .48228 .41586 .46126 .40478 .4477 Metetra
0 .292 .301 r
.40478 .4477 .41586 .46126 .43508 .44184 .42412 .42809 Metetra
0 .187 .25 r
.42412 .42809 .43508 .44184 .45424 .42424 .4434 .41031 Metetra
0 .116 .206 r
.4434 .41031 .45424 .42424 .47337 .40864 .46263 .39456 Metetra
0 .071 .172 r
.46263 .39456 .47337 .40864 .4925 .39519 .48185 .38097 Metetra
0 .045 .147 r
.48185 .38097 .4925 .39519 .51166 .384 .50111 .36966 Metetra
0 .031 .132 r
.50111 .36966 .51166 .384 .53091 .37514 .52044 .3607 Metetra
0 .027 .127 r
.52044 .3607 .53091 .37514 .55029 .36866 .53989 .35412 Metetra
0 .031 .132 r
.53989 .35412 .55029 .36866 .56983 .36456 .55951 .34995 Metetra
0 .045 .147 r
.55951 .34995 .56983 .36456 .5896 .36282 .57933 .34816 Metetra
0 .071 .172 r
.57933 .34816 .5896 .36282 .60963 .3634 .59942 .34869 Metetra
0 .116 .206 r
.59942 .34869 .60963 .3634 .62996 .36619 .61981 .35146 Metetra
0 .187 .25 r
.61981 .35146 .62996 .36619 .65065 .37108 .64054 .35635 Metetra
0 .292 .301 r
.64054 .35635 .65065 .37108 .67172 .3779 .66167 .36318 Metetra
0 .359 .279 r
.66167 .36318 .67172 .3779 .69321 .38643 .68321 .37175 Metetra
0 .423 .211 r
.68321 .37175 .69321 .38643 .71515 .39641 .7052 .38178 Metetra
0 .492 .099 r
.7052 .38178 .71515 .39641 .73754 .40751 .72765 .39295 Metetra
.061 .563 0 r
.72765 .39295 .73754 .40751 .76039 .41933 .75057 .40487 Metetra
.268 .636 0 r
.75057 .40487 .76039 .41933 .78369 .4314 .77393 .41706 Metetra
.517 .707 0 r
.77393 .41706 .78369 .4314 .80739 .44317 .79772 .42897 Metetra
.776 .754 0 r
.79772 .42897 .80739 .44317 .83144 .45399 .82186 .43995 Metetra
.838 .588 0 r
.82186 .43995 .83144 .45399 .85576 .46312 .84628 .44926 Metetra
.893 .415 0 r
.84628 .44926 .85576 .46312 .88022 .46972 .87087 .45606 Metetra
.891 .421 0 r
.21495 .63959 .22756 .64993 .24714 .63128 .23467 .62081 Metetra
.836 .594 0 r
.23467 .62081 .24714 .63128 .2669 .61014 .25457 .59955 Metetra
.773 .76 0 r
.25457 .59955 .2669 .61014 .28675 .5873 .27457 .57657 Metetra
.506 .704 0 r
.27457 .57657 .28675 .5873 .30661 .56343 .29458 .55257 Metetra
.257 .632 0 r
.29458 .55257 .30661 .56343 .32643 .53916 .31455 .52816 Metetra
.051 .56 0 r
.31455 .52816 .32643 .53916 .34617 .51502 .33445 .50388 Metetra
0 .488 .107 r
.33445 .50388 .34617 .51502 .36582 .49148 .35424 .4802 Metetra
0 .419 .217 r
.35424 .4802 .36582 .49148 .38535 .46892 .37392 .45752 Metetra
0 .355 .282 r
.37392 .45752 .38535 .46892 .40478 .4477 .39349 .43617 Metetra
0 .282 .296 r
.39349 .43617 .40478 .4477 .42412 .42809 .41296 .41644 Metetra
0 .179 .245 r
.41296 .41644 .42412 .42809 .4434 .41031 .43236 .39854 Metetra
0 .109 .202 r
.43236 .39854 .4434 .41031 .46263 .39456 .45171 .38268 Metetra
0 .065 .167 r
.45171 .38268 .46263 .39456 .48185 .38097 .47105 .36899 Metetra
0 .04 .142 r
.47105 .36899 .48185 .38097 .50111 .36966 .49041 .35758 Metetra
0 .027 .127 r
.49041 .35758 .50111 .36966 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .027 .127 r
.52938 .34187 .53989 .35412 .55951 .34995 .54908 .33761 Metetra
0 .04 .142 r
.54908 .33761 .55951 .34995 .57933 .34816 .56898 .33575 Metetra
0 .065 .167 r
.56898 .33575 .57933 .34816 .59942 .34869 .58914 .33621 Metetra
0 .109 .202 r
.58914 .33621 .59942 .34869 .61981 .35146 .6096 .33892 Metetra
0 .179 .245 r
.6096 .33892 .61981 .35146 .64054 .35635 .6304 .34374 Metetra
0 .282 .296 r
.6304 .34374 .64054 .35635 .66167 .36318 .65158 .35052 Metetra
0 .355 .282 r
.65158 .35052 .66167 .36318 .68321 .37175 .67319 .35904 Metetra
0 .419 .217 r
.67319 .35904 .68321 .37175 .7052 .38178 .69524 .36902 Metetra
0 .488 .107 r
.69524 .36902 .7052 .38178 .72765 .39295 .71775 .38015 Metetra
.051 .56 0 r
.71775 .38015 .72765 .39295 .75057 .40487 .74074 .39203 Metetra
.257 .632 0 r
.74074 .39203 .75057 .40487 .77393 .41706 .76417 .40418 Metetra
.506 .704 0 r
.76417 .40418 .77393 .41706 .79772 .42897 .78803 .41605 Metetra
.773 .76 0 r
.78803 .41605 .79772 .42897 .82186 .43995 .81226 .42698 Metetra
.836 .594 0 r
.81226 .42698 .82186 .43995 .84628 .44926 .83678 .43625 Metetra
.891 .421 0 r
.83678 .43625 .84628 .44926 .87087 .45606 .86146 .44299 Metetra
.893 .415 0 r
.20211 .62985 .21495 .63959 .23467 .62081 .22194 .6112 Metetra
.838 .588 0 r
.22194 .6112 .23467 .62081 .25457 .59955 .24198 .59003 Metetra
.776 .754 0 r
.24198 .59003 .25457 .59955 .27457 .57657 .26211 .56712 Metetra
.517 .707 0 r
.26211 .56712 .27457 .57657 .29458 .55257 .28228 .54316 Metetra
.268 .636 0 r
.28228 .54316 .29458 .55257 .31455 .52816 .3024 .51876 Metetra
.061 .563 0 r
.3024 .51876 .31455 .52816 .33445 .50388 .32245 .49449 Metetra
0 .492 .099 r
.32245 .49449 .33445 .50388 .35424 .4802 .3424 .47079 Metetra
0 .423 .211 r
.3424 .47079 .35424 .4802 .37392 .45752 .36223 .44808 Metetra
0 .359 .279 r
.36223 .44808 .37392 .45752 .39349 .43617 .38195 .42669 Metetra
0 .292 .301 r
.38195 .42669 .39349 .43617 .41296 .41644 .40157 .4069 Metetra
0 .187 .25 r
.40157 .4069 .41296 .41644 .43236 .39854 .42111 .38896 Metetra
0 .116 .206 r
.42111 .38896 .43236 .39854 .45171 .38268 .44059 .37303 Metetra
0 .071 .172 r
.44059 .37303 .45171 .38268 .47105 .36899 .46005 .35927 Metetra
0 .045 .147 r
.46005 .35927 .47105 .36899 .49041 .35758 .47953 .34778 Metetra
0 .031 .132 r
.47953 .34778 .49041 .35758 .50984 .34853 .49907 .33865 Metetra
0 .027 .127 r
.49907 .33865 .50984 .34853 .52938 .34187 .51872 .3319 Metetra
0 .031 .132 r
.51872 .3319 .52938 .34187 .54908 .33761 .53852 .32756 Metetra
0 .045 .147 r
.53852 .32756 .54908 .33761 .56898 .33575 .55851 .3256 Metetra
0 .071 .172 r
.55851 .3256 .56898 .33575 .58914 .33621 .57876 .32596 Metetra
0 .116 .206 r
.57876 .32596 .58914 .33621 .6096 .33892 .5993 .32856 Metetra
0 .187 .25 r
.5993 .32856 .6096 .33892 .6304 .34374 .62018 .33328 Metetra
0 .292 .301 r
.62018 .33328 .6304 .34374 .65158 .35052 .64145 .33993 Metetra
0 .359 .279 r
.64145 .33993 .65158 .35052 .67319 .35904 .66312 .34831 Metetra
0 .423 .211 r
.66312 .34831 .67319 .35904 .69524 .36902 .68525 .35815 Metetra
0 .492 .099 r
.68525 .35815 .69524 .36902 .71775 .38015 .70783 .36912 Metetra
.061 .563 0 r
.70783 .36912 .71775 .38015 .74074 .39203 .73088 .38082 Metetra
.268 .636 0 r
.73088 .38082 .74074 .39203 .76417 .40418 .75439 .39277 Metetra
.517 .707 0 r
.75439 .39277 .76417 .40418 .78803 .41605 .77832 .40442 Metetra
.776 .754 0 r
.77832 .40442 .78803 .41605 .81226 .42698 .80263 .41511 Metetra
.838 .588 0 r
.80263 .41511 .81226 .42698 .83678 .43625 .82722 .42409 Metetra
.893 .415 0 r
.82722 .42409 .83678 .43625 .86146 .44299 .852 .43052 Metetra
.898 .398 0 r
.18902 .62068 .20211 .62985 .22194 .6112 .20895 .60241 Metetra
.845 .569 0 r
.20895 .60241 .22194 .6112 .24198 .59003 .2291 .58156 Metetra
.783 .736 0 r
.2291 .58156 .24198 .59003 .26211 .56712 .24937 .55891 Metetra
.551 .716 0 r
.24937 .55891 .26211 .56712 .28228 .54316 .26968 .53517 Metetra
.299 .646 0 r
.26968 .53517 .28228 .54316 .3024 .51876 .28996 .51095 Metetra
.089 .574 0 r
.28996 .51095 .3024 .51876 .32245 .49449 .31016 .48681 Metetra
0 .504 .076 r
.31016 .48681 .32245 .49449 .3424 .47079 .33027 .46322 Metetra
0 .436 .194 r
.33027 .46322 .3424 .47079 .36223 .44808 .35026 .44058 Metetra
0 .372 .268 r
.35026 .44058 .36223 .44808 .38195 .42669 .37014 .41924 Metetra
0 .315 .305 r
.37014 .41924 .38195 .42669 .40157 .4069 .38991 .39948 Metetra
0 .214 .264 r
.38991 .39948 .40157 .4069 .42111 .38896 .4096 .38153 Metetra
0 .138 .221 r
.4096 .38153 .42111 .38896 .44059 .37303 .42923 .36558 Metetra
0 .089 .187 r
.42923 .36558 .44059 .37303 .46005 .35927 .44884 .35179 Metetra
0 .06 .162 r
.44884 .35179 .46005 .35927 .47953 .34778 .46845 .34025 Metetra
0 .045 .147 r
.46845 .34025 .47953 .34778 .49907 .33865 .48812 .33105 Metetra
0 .04 .142 r
.48812 .33105 .49907 .33865 .51872 .3319 .50789 .32422 Metetra
0 .045 .147 r
.50789 .32422 .51872 .3319 .53852 .32756 .5278 .31978 Metetra
0 .06 .162 r
.5278 .31978 .53852 .32756 .55851 .3256 .54791 .3177 Metetra
0 .089 .187 r
.54791 .3177 .55851 .3256 .57876 .32596 .56826 .31793 Metetra
0 .138 .221 r
.56826 .31793 .57876 .32596 .5993 .32856 .5889 .32039 Metetra
0 .214 .264 r
.5889 .32039 .5993 .32856 .62018 .33328 .60987 .32493 Metetra
0 .315 .305 r
.60987 .32493 .62018 .33328 .64145 .33993 .63123 .33139 Metetra
0 .372 .268 r
.63123 .33139 .64145 .33993 .66312 .34831 .65299 .33956 Metetra
0 .436 .194 r
.65299 .33956 .66312 .34831 .68525 .35815 .67519 .34915 Metetra
0 .504 .076 r
.67519 .34915 .68525 .35815 .70783 .36912 .69786 .35984 Metetra
.089 .574 0 r
.69786 .35984 .70783 .36912 .73088 .38082 .72098 .37122 Metetra
.299 .646 0 r
.72098 .37122 .73088 .38082 .75439 .39277 .74456 .38282 Metetra
.551 .716 0 r
.74456 .38282 .75439 .39277 .77832 .40442 .76857 .39405 Metetra
.783 .736 0 r
.76857 .39405 .77832 .40442 .80263 .41511 .79295 .40428 Metetra
.845 .569 0 r
.79295 .40428 .80263 .41511 .82722 .42409 .81761 .41274 Metetra
.898 .398 0 r
.81761 .41274 .82722 .42409 .852 .43052 .84245 .41859 Metetra
.905 .371 0 r
.17568 .61197 .18902 .62068 .20895 .60241 .19568 .59433 Metetra
.855 .538 0 r
.19568 .59433 .20895 .60241 .2291 .58156 .21593 .57403 Metetra
.795 .705 0 r
.21593 .57403 .2291 .58156 .24937 .55891 .23632 .55186 Metetra
.606 .73 0 r
.23632 .55186 .24937 .55891 .26968 .53517 .25677 .52853 Metetra
.353 .662 0 r
.25677 .52853 .26968 .53517 .28996 .51095 .27719 .50465 Metetra
.136 .592 0 r
.27719 .50465 .28996 .51095 .31016 .48681 .29756 .48079 Metetra
0 .523 .036 r
.29756 .48079 .31016 .48681 .33027 .46322 .31783 .45743 Metetra
0 .456 .163 r
.31783 .45743 .33027 .46322 .35026 .44058 .33798 .43497 Metetra
0 .394 .247 r
.33798 .43497 .35026 .44058 .37014 .41924 .35803 .41377 Metetra
0 .337 .294 r
.35803 .41377 .37014 .41924 .38991 .39948 .37797 .3941 Metetra
0 .262 .287 r
.37797 .3941 .38991 .39948 .4096 .38153 .39782 .37621 Metetra
0 .179 .245 r
.39782 .37621 .4096 .38153 .42923 .36558 .41761 .3603 Metetra
0 .123 .211 r
.41761 .3603 .42923 .36558 .44884 .35179 .43737 .3465 Metetra
0 .089 .187 r
.43737 .3465 .44884 .35179 .46845 .34025 .45714 .33494 Metetra
0 .071 .172 r
.45714 .33494 .46845 .34025 .48812 .33105 .47695 .32568 Metetra
0 .065 .167 r
.47695 .32568 .48812 .33105 .50789 .32422 .49686 .31877 Metetra
0 .071 .172 r
.49686 .31877 .50789 .32422 .5278 .31978 .5169 .31422 Metetra
0 .089 .187 r
.5169 .31422 .5278 .31978 .54791 .3177 .53714 .31201 Metetra
0 .123 .211 r
.53714 .31201 .54791 .3177 .56826 .31793 .55761 .31208 Metetra
0 .179 .245 r
.55761 .31208 .56826 .31793 .5889 .32039 .57836 .31433 Metetra
0 .262 .287 r
.57836 .31433 .5889 .32039 .60987 .32493 .59945 .31865 Metetra
0 .337 .294 r
.59945 .31865 .60987 .32493 .63123 .33139 .6209 .32485 Metetra
0 .394 .247 r
.6209 .32485 .63123 .33139 .65299 .33956 .64276 .33271 Metetra
0 .456 .163 r
.64276 .33271 .65299 .33956 .67519 .34915 .66506 .34195 Metetra
0 .523 .036 r
.66506 .34195 .67519 .34915 .69786 .35984 .68781 .35223 Metetra
.136 .592 0 r
.68781 .35223 .69786 .35984 .72098 .37122 .71102 .36315 Metetra
.353 .662 0 r
.71102 .36315 .72098 .37122 .74456 .38282 .73468 .37422 Metetra
.606 .73 0 r
.73468 .37422 .74456 .38282 .76857 .39405 .75876 .38486 Metetra
.795 .705 0 r
.75876 .38486 .76857 .39405 .79295 .40428 .7832 .39441 Metetra
.855 .538 0 r
.7832 .39441 .79295 .40428 .81761 .41274 .80793 .40211 Metetra
.905 .371 0 r
.80793 .40211 .81761 .41274 .84245 .41859 .83282 .4071 Metetra
.916 .335 0 r
.1621 .60357 .17568 .61197 .19568 .59433 .18214 .58683 Metetra
.868 .496 0 r
.18214 .58683 .19568 .59433 .21593 .57403 .20247 .56733 Metetra
.812 .662 0 r
.20247 .56733 .21593 .57403 .23632 .55186 .22296 .54585 Metetra
.685 .749 0 r
.22296 .54585 .23632 .55186 .25677 .52853 .24353 .52311 Metetra
.429 .683 0 r
.24353 .52311 .25677 .52853 .27719 .50465 .2641 .49975 Metetra
.206 .616 0 r
.2641 .49975 .27719 .50465 .29756 .48079 .28462 .47632 Metetra
.024 .549 0 r
.28462 .47632 .29756 .48079 .31783 .45743 .30505 .45331 Metetra
0 .484 .114 r
.30505 .45331 .31783 .45743 .33798 .43497 .32538 .43115 Metetra
0 .423 .211 r
.32538 .43115 .33798 .43497 .35803 .41377 .3456 .41017 Metetra
0 .368 .272 r
.3456 .41017 .35803 .41377 .37797 .3941 .36571 .39068 Metetra
0 .319 .303 r
.36571 .39068 .37797 .3941 .39782 .37621 .38574 .37292 Metetra
0 .242 .278 r
.38574 .37292 .39782 .37621 .41761 .3603 .4057 .35708 Metetra
0 .179 .245 r
.4057 .35708 .41761 .3603 .43737 .3465 .42563 .34332 Metetra
0 .138 .221 r
.42563 .34332 .43737 .3465 .45714 .33494 .44556 .33176 Metetra
0 .116 .206 r
.44556 .33176 .45714 .33494 .47695 .32568 .46553 .32246 Metetra
0 .109 .202 r
.46553 .32246 .47695 .32568 .49686 .31877 .48559 .31547 Metetra
0 .116 .206 r
.48559 .31547 .49686 .31877 .5169 .31422 .50579 .3108 Metetra
0 .138 .221 r
.50579 .3108 .5169 .31422 .53714 .31201 .52617 .30843 Metetra
0 .179 .245 r
.52617 .30843 .53714 .31201 .55761 .31208 .54677 .3083 Metetra
0 .242 .278 r
.54677 .3083 .55761 .31208 .57836 .31433 .56766 .31032 Metetra
0 .319 .303 r
.56766 .31032 .57836 .31433 .59945 .31865 .58887 .31434 Metetra
0 .368 .272 r
.58887 .31434 .59945 .31865 .6209 .32485 .61044 .3202 Metetra
0 .423 .211 r
.61044 .3202 .6209 .32485 .64276 .33271 .63241 .32766 Metetra
0 .484 .114 r
.63241 .32766 .64276 .33271 .66506 .34195 .65481 .33644 Metetra
.024 .549 0 r
.65481 .33644 .66506 .34195 .68781 .35223 .67766 .34619 Metetra
.206 .616 0 r
.67766 .34619 .68781 .35223 .71102 .36315 .70096 .3565 Metetra
.429 .683 0 r
.70096 .3565 .71102 .36315 .73468 .37422 .7247 .36686 Metetra
.685 .749 0 r
.7247 .36686 .73468 .37422 .75876 .38486 .74885 .3767 Metetra
.812 .662 0 r
.74885 .3767 .75876 .38486 .7832 .39441 .77336 .38535 Metetra
.868 .496 0 r
.77336 .38535 .7832 .39441 .80793 .40211 .79814 .39203 Metetra
.916 .335 0 r
.79814 .39203 .80793 .40211 .83282 .4071 .82307 .39588 Metetra
.928 .291 0 r
.14829 .59529 .1621 .60357 .18214 .58683 .16834 .57972 Metetra
.884 .443 0 r
.16834 .57972 .18214 .58683 .20247 .56733 .18872 .56125 Metetra
.832 .606 0 r
.18872 .56125 .20247 .56733 .22296 .54585 .20929 .54069 Metetra
.773 .76 0 r
.20929 .54069 .22296 .54585 .24353 .52311 .22997 .51875 Metetra
.528 .71 0 r
.22997 .51875 .24353 .52311 .2641 .49975 .25067 .49608 Metetra
.299 .646 0 r
.25067 .49608 .2641 .49975 .28462 .47632 .27133 .47324 Metetra
.108 .581 0 r
.27133 .47324 .28462 .47632 .30505 .45331 .29193 .45072 Metetra
0 .519 .044 r
.29193 .45072 .30505 .45331 .32538 .43115 .31243 .42897 Metetra
0 .46 .156 r
.31243 .42897 .32538 .43115 .3456 .41017 .33283 .40832 Metetra
0 .407 .232 r
.33283 .40832 .3456 .41017 .36571 .39068 .35312 .38909 Metetra
0 .359 .279 r
.35312 .38909 .36571 .39068 .38574 .37292 .37333 .37152 Metetra
0 .319 .303 r
.37333 .37152 .38574 .37292 .4057 .35708 .39348 .35582 Metetra
0 .262 .287 r
.39348 .35582 .4057 .35708 .42563 .34332 .41359 .34214 Metetra
0 .214 .264 r
.41359 .34214 .42563 .34332 .44556 .33176 .4337 .33059 Metetra
0 .187 .25 r
.4337 .33059 .44556 .33176 .46553 .32246 .45384 .32126 Metetra
0 .179 .245 r
.45384 .32126 .46553 .32246 .48559 .31547 .47407 .3142 Metetra
0 .187 .25 r
.47407 .3142 .48559 .31547 .50579 .3108 .49443 .3094 Metetra
0 .214 .264 r
.49443 .3094 .50579 .3108 .52617 .30843 .51497 .30685 Metetra
0 .262 .287 r
.51497 .30685 .52617 .30843 .54677 .3083 .53573 .30648 Metetra
0 .319 .303 r
.53573 .30648 .54677 .3083 .56766 .31032 .55676 .3082 Metetra
0 .359 .279 r
.55676 .3082 .56766 .31032 .58887 .31434 .57811 .31187 Metetra
0 .407 .232 r
.57811 .31187 .58887 .31434 .61044 .3202 .59981 .3173 Metetra
0 .46 .156 r
.59981 .3173 .61044 .3202 .63241 .32766 .62191 .32427 Metetra
0 .519 .044 r
.62191 .32427 .63241 .32766 .65481 .33644 .64442 .33246 Metetra
.108 .581 0 r
.64442 .33246 .65481 .33644 .67766 .34619 .66738 .34154 Metetra
.299 .646 0 r
.66738 .34154 .67766 .34619 .70096 .3565 .69078 .35108 Metetra
.528 .71 0 r
.69078 .35108 .70096 .3565 .7247 .36686 .7146 .36056 Metetra
.773 .76 0 r
.7146 .36056 .7247 .36686 .74885 .3767 .73883 .36939 Metetra
.832 .606 0 r
.73883 .36939 .74885 .3767 .77336 .38535 .76339 .3769 Metetra
.884 .443 0 r
.76339 .3769 .77336 .38535 .79814 .39203 .78822 .3823 Metetra
.928 .291 0 r
.78822 .3823 .79814 .39203 .82307 .39588 .81317 .38473 Metetra
.94 .243 0 r
.13427 .58684 .14829 .59529 .16834 .57972 .15429 .57272 Metetra
.902 .382 0 r
.15429 .57272 .16834 .57972 .18872 .56125 .17468 .55555 Metetra
.855 .538 0 r
.17468 .55555 .18872 .56125 .20929 .54069 .19531 .53614 Metetra
.8 .693 0 r
.19531 .53614 .20929 .54069 .22997 .51875 .21607 .51522 Metetra
.651 .741 0 r
.21607 .51522 .22997 .51875 .25067 .49608 .23689 .49342 Metetra
.418 .68 0 r
.23689 .49342 .25067 .49608 .27133 .47324 .25769 .47133 Metetra
.216 .619 0 r
.25769 .47133 .27133 .47324 .29193 .45072 .27845 .44946 Metetra
.052 .56 0 r
.27845 .44946 .29193 .45072 .31243 .42897 .29912 .42824 Metetra
0 .504 .076 r
.29912 .42824 .31243 .42897 .33283 .40832 .31969 .40803 Metetra
0 .452 .169 r
.31969 .40803 .33283 .40832 .35312 .38909 .34018 .38915 Metetra
0 .407 .232 r
.34018 .38915 .35312 .38909 .37333 .37152 .36058 .37185 Metetra
0 .368 .272 r
.36058 .37185 .37333 .37152 .39348 .35582 .38091 .35633 Metetra
0 .337 .294 r
.38091 .35633 .39348 .35582 .41359 .34214 .40122 .34277 Metetra
0 .315 .305 r
.40122 .34277 .41359 .34214 .4337 .33059 .42152 .33128 Metetra
0 .292 .301 r
.42152 .33128 .4337 .33059 .45384 .32126 .44185 .32194 Metetra
0 .282 .296 r
.44185 .32194 .45384 .32126 .47407 .3142 .46227 .31479 Metetra
0 .292 .301 r
.46227 .31479 .47407 .3142 .49443 .3094 .48281 .30985 Metetra
0 .315 .305 r
.48281 .30985 .49443 .3094 .51497 .30685 .50352 .30709 Metetra
0 .337 .294 r
.50352 .30709 .51497 .30685 .53573 .30648 .52445 .30645 Metetra
0 .368 .272 r
.52445 .30645 .53573 .30648 .55676 .3082 .54564 .30782 Metetra
0 .407 .232 r
.54564 .30782 .55676 .3082 .57811 .31187 .56714 .31106 Metetra
0 .452 .169 r
.56714 .31106 .57811 .31187 .59981 .3173 .58899 .31598 Metetra
0 .504 .076 r
.58899 .31598 .59981 .3173 .62191 .32427 .61123 .32234 Metetra
.052 .56 0 r
.61123 .32234 .62191 .32427 .64442 .33246 .63387 .32983 Metetra
.216 .619 0 r
.63387 .32983 .64442 .33246 .66738 .34154 .65694 .33808 Metetra
.418 .68 0 r
.65694 .33808 .66738 .34154 .69078 .35108 .68044 .34667 Metetra
.651 .741 0 r
.68044 .34667 .69078 .35108 .7146 .36056 .70436 .35507 Metetra
.8 .693 0 r
.70436 .35507 .7146 .36056 .73883 .36939 .72866 .36268 Metetra
.855 .538 0 r
.72866 .36268 .73883 .36939 .76339 .3769 .75328 .3688 Metetra
.902 .382 0 r
.75328 .3688 .76339 .3769 .78822 .3823 .77813 .37265 Metetra
.94 .243 0 r
.77813 .37265 .78822 .3823 .81317 .38473 .8031 .37334 Metetra
.953 .194 0 r
.12007 .57791 .13427 .58684 .15429 .57272 .14001 .56553 Metetra
.921 .315 0 r
.14001 .56553 .15429 .57272 .17468 .55555 .16038 .54993 Metetra
.879 .461 0 r
.16038 .54993 .17468 .55555 .19531 .53614 .18103 .53192 Metetra
.83 .612 0 r
.18103 .53192 .19531 .53614 .21607 .51522 .20186 .51222 Metetra
.776 .754 0 r
.20186 .51222 .21607 .51522 .23689 .49342 .22277 .4915 Metetra
.562 .719 0 r
.22277 .4915 .23689 .49342 .25769 .47133 .2437 .47035 Metetra
.353 .662 0 r
.2437 .47035 .25769 .47133 .27845 .44946 .2646 .44927 Metetra
.176 .606 0 r
.2646 .44927 .27845 .44946 .29912 .42824 .28543 .42872 Metetra
.033 .552 0 r
.28543 .42872 .29912 .42824 .31969 .40803 .30619 .40906 Metetra
0 .504 .076 r
.30619 .40906 .31969 .40803 .34018 .38915 .32686 .39063 Metetra
0 .46 .156 r
.32686 .39063 .34018 .38915 .36058 .37185 .34746 .37367 Metetra
0 .423 .211 r
.34746 .37367 .36058 .37185 .38091 .35633 .36799 .35841 Metetra
0 .394 .247 r
.36799 .35841 .38091 .35633 .40122 .34277 .3885 .34502 Metetra
0 .372 .268 r
.3885 .34502 .40122 .34277 .42152 .33128 .409 .33361 Metetra
0 .359 .279 r
.409 .33361 .42152 .33128 .44185 .32194 .42954 .32427 Metetra
0 .355 .282 r
.42954 .32427 .44185 .32194 .46227 .31479 .45015 .31704 Metetra
0 .359 .279 r
.45015 .31704 .46227 .31479 .48281 .30985 .47089 .31195 Metetra
0 .372 .268 r
.47089 .31195 .48281 .30985 .50352 .30709 .49179 .30895 Metetra
0 .394 .247 r
.49179 .30895 .50352 .30709 .52445 .30645 .5129 .30799 Metetra
0 .423 .211 r
.5129 .30799 .52445 .30645 .54564 .30782 .53427 .30895 Metetra
0 .46 .156 r
.53427 .30895 .54564 .30782 .56714 .31106 .55594 .31168 Metetra
0 .504 .076 r
.55594 .31168 .56714 .31106 .58899 .31598 .57795 .31599 Metetra
.033 .552 0 r
.57795 .31599 .58899 .31598 .61123 .32234 .60034 .32162 Metetra
.176 .606 0 r
.60034 .32162 .61123 .32234 .63387 .32983 .62312 .32826 Metetra
.353 .662 0 r
.62312 .32826 .63387 .32983 .65694 .33808 .64632 .33554 Metetra
.562 .719 0 r
.64632 .33554 .65694 .33808 .68044 .34667 .66993 .343 Metetra
.776 .754 0 r
.66993 .343 .68044 .34667 .70436 .35507 .69394 .35011 Metetra
.83 .612 0 r
.69394 .35011 .70436 .35507 .72866 .36268 .71831 .35625 Metetra
.879 .461 0 r
.71831 .35625 .72866 .36268 .75328 .3688 .74298 .36072 Metetra
.921 .315 0 r
.74298 .36072 .75328 .3688 .77813 .37265 .76786 .36273 Metetra
.953 .194 0 r
.76786 .36273 .77813 .37265 .8031 .37334 .79282 .36139 Metetra
.964 .149 0 r
.10574 .5681 .12007 .57791 .14001 .56553 .12556 .55776 Metetra
.939 .247 0 r
.12556 .55776 .14001 .56553 .16038 .54993 .14585 .54401 Metetra
.904 .376 0 r
.14585 .54401 .16038 .54993 .18103 .53192 .16648 .52765 Metetra
.861 .52 0 r
.16648 .52765 .18103 .53192 .20186 .51222 .18734 .50942 Metetra
.812 .662 0 r
.18734 .50942 .20186 .51222 .22277 .4915 .20832 .49 Metetra
.73 .76 0 r
.20832 .49 .22277 .4915 .2437 .47035 .22935 .46996 Metetra
.517 .707 0 r
.22935 .46996 .2437 .47035 .2646 .44927 .25038 .44985 Metetra
.331 .655 0 r
.25038 .44985 .2646 .44927 .28543 .42872 .27137 .43011 Metetra
.176 .606 0 r
.27137 .43011 .28543 .42872 .30619 .40906 .2923 .41113 Metetra
.052 .56 0 r
.2923 .41113 .30619 .40906 .32686 .39063 .31316 .39324 Metetra
0 .519 .044 r
.31316 .39324 .32686 .39063 .34746 .37367 .33396 .37672 Metetra
0 .484 .114 r
.33396 .37672 .34746 .37367 .36799 .35841 .3547 .36178 Metetra
0 .456 .163 r
.3547 .36178 .36799 .35841 .3885 .34502 .37541 .3486 Metetra
0 .436 .194 r
.37541 .3486 .3885 .34502 .409 .33361 .39613 .33731 Metetra
0 .423 .211 r
.39613 .33731 .409 .33361 .42954 .32427 .41688 .32799 Metetra
0 .419 .217 r
.41688 .32799 .42954 .32427 .45015 .31704 .4377 .32069 Metetra
0 .423 .211 r
.4377 .32069 .45015 .31704 .47089 .31195 .45865 .31542 Metetra
0 .436 .194 r
.45865 .31542 .47089 .31195 .49179 .30895 .47975 .31215 Metetra
0 .456 .163 r
.47975 .31215 .49179 .30895 .5129 .30799 .50106 .31081 Metetra
0 .484 .114 r
.50106 .31081 .5129 .30799 .53427 .30895 .52262 .31129 Metetra
0 .519 .044 r
.52262 .31129 .53427 .30895 .55594 .31168 .54448 .31343 Metetra
.052 .56 0 r
.54448 .31343 .55594 .31168 .57795 .31599 .56666 .31703 Metetra
.176 .606 0 r
.56666 .31703 .57795 .31599 .60034 .32162 .58921 .32181 Metetra
.331 .655 0 r
.58921 .32181 .60034 .32162 .62312 .32826 .61215 .32745 Metetra
.517 .707 0 r
.61215 .32745 .62312 .32826 .64632 .33554 .63548 .33357 Metetra
.73 .76 0 r
.63548 .33357 .64632 .33554 .66993 .343 .65921 .3397 Metetra
.812 .662 0 r
.65921 .3397 .66993 .343 .69394 .35011 .68331 .3453 Metetra
.861 .52 0 r
.68331 .3453 .69394 .35011 .71831 .35625 .70775 .34973 Metetra
.904 .376 0 r
.70775 .34973 .71831 .35625 .74298 .36072 .73247 .35228 Metetra
.939 .247 0 r
.73247 .35228 .74298 .36072 .76786 .36273 .75736 .35214 Metetra
.964 .149 0 r
.75736 .35214 .76786 .36273 .79282 .36139 .7823 .34844 Metetra
.972 .116 0 r
.09135 .55697 .10574 .5681 .12556 .55776 .11097 .54897 Metetra
.956 .184 0 r
.11097 .54897 .12556 .55776 .14585 .54401 .13114 .53735 Metetra
.928 .291 0 r
.13114 .53735 .14585 .54401 .16648 .52765 .15171 .52292 Metetra
.891 .42 0 r
.15171 .52292 .16648 .52765 .18734 .50942 .17255 .5064 Metetra
.849 .556 0 r
.17255 .5064 .18734 .50942 .20832 .49 .19357 .48849 Metetra
.803 .687 0 r
.19357 .48849 .20832 .49 .22935 .46996 .21468 .46978 Metetra
.708 .755 0 r
.21468 .46978 .22935 .46996 .25038 .44985 .23582 .4508 Metetra
.517 .707 0 r
.23582 .4508 .25038 .44985 .27137 .43011 .25695 .43203 Metetra
.353 .662 0 r
.25695 .43203 .27137 .43011 .2923 .41113 .27805 .41387 Metetra
.216 .619 0 r
.27805 .41387 .2923 .41113 .31316 .39324 .29909 .39664 Metetra
.108 .581 0 r
.29909 .39664 .31316 .39324 .33396 .37672 .32008 .38065 Metetra
.024 .549 0 r
.32008 .38065 .33396 .37672 .3547 .36178 .34103 .36611 Metetra
0 .523 .036 r
.34103 .36611 .3547 .36178 .37541 .3486 .36195 .3532 Metetra
0 .504 .076 r
.36195 .3532 .37541 .3486 .39613 .33731 .38289 .34205 Metetra
0 .492 .099 r
.38289 .34205 .39613 .33731 .41688 .32799 .40386 .33277 Metetra
0 .488 .107 r
.40386 .33277 .41688 .32799 .4377 .32069 .42491 .3254 Metetra
0 .492 .099 r
.42491 .3254 .4377 .32069 .45865 .31542 .44607 .31994 Metetra
0 .504 .076 r
.44607 .31994 .45865 .31542 .47975 .31215 .46739 .31636 Metetra
0 .523 .036 r
.46739 .31636 .47975 .31215 .50106 .31081 .48891 .31459 Metetra
.024 .549 0 r
.48891 .31459 .50106 .31081 .52262 .31129 .51068 .31452 Metetra
.108 .581 0 r
.51068 .31452 .52262 .31129 .54448 .31343 .53273 .31597 Metetra
.216 .619 0 r
.53273 .31597 .54448 .31343 .56666 .31703 .5551 .31873 Metetra
.353 .662 0 r
.5551 .31873 .56666 .31703 .58921 .32181 .57782 .32252 Metetra
.517 .707 0 r
.57782 .32252 .58921 .32181 .61215 .32745 .60092 .327 Metetra
.708 .755 0 r
.60092 .327 .61215 .32745 .63548 .33357 .62439 .33178 Metetra
.803 .687 0 r
.62439 .33178 .63548 .33357 .65921 .3397 .64824 .33637 Metetra
.849 .556 0 r
.64824 .33637 .65921 .3397 .68331 .3453 .67244 .34021 Metetra
.891 .42 0 r
.67244 .34021 .68331 .3453 .70775 .34973 .69696 .34266 Metetra
.928 .291 0 r
.69696 .34266 .70775 .34973 .73247 .35228 .72171 .343 Metetra
.956 .184 0 r
.72171 .343 .73247 .35228 .75736 .35214 .7466 .34041 Metetra
.972 .116 0 r
.7466 .34041 .75736 .35214 .7823 .34844 .7715 .33402 Metetra
.976 .102 0 r
.07698 .54398 .09135 .55697 .11097 .54897 .09633 .53864 Metetra
.968 .133 0 r
.09633 .53864 .11097 .54897 .13114 .53735 .11631 .52945 Metetra
.949 .211 0 r
.11631 .52945 .13114 .53735 .15171 .52292 .13676 .51721 Metetra
.92 .32 0 r
.13676 .51721 .15171 .52292 .17255 .5064 .15754 .50267 Metetra
.884 .443 0 r
.15754 .50267 .17255 .5064 .19357 .48849 .17856 .4865 Metetra
.845 .569 0 r
.17856 .4865 .19357 .48849 .21468 .46978 .19971 .46933 Metetra
.803 .687 0 r
.19971 .46933 .21468 .46978 .23582 .4508 .22094 .45169 Metetra
.73 .76 0 r
.22094 .45169 .23582 .4508 .25695 .43203 .24219 .43406 Metetra
.562 .719 0 r
.24219 .43406 .25695 .43203 .27805 .41387 .26343 .41685 Metetra
.418 .68 0 r
.26343 .41685 .27805 .41387 .29909 .39664 .28464 .40041 Metetra
.299 .646 0 r
.28464 .40041 .29909 .39664 .32008 .38065 .30582 .38504 Metetra
.206 .616 0 r
.30582 .38504 .32008 .38065 .34103 .36611 .32698 .37098 Metetra
.136 .592 0 r
.32698 .37098 .34103 .36611 .36195 .3532 .34812 .3584 Metetra
.089 .574 0 r
.34812 .3584 .36195 .3532 .38289 .34205 .36928 .34745 Metetra
.061 .563 0 r
.36928 .34745 .38289 .34205 .40386 .33277 .39047 .33822 Metetra
.051 .56 0 r
.39047 .33822 .40386 .33277 .42491 .3254 .41175 .33077 Metetra
.061 .563 0 r
.41175 .33077 .42491 .3254 .44607 .31994 .43314 .3251 Metetra
.089 .574 0 r
.43314 .3251 .44607 .31994 .46739 .31636 .45469 .32117 Metetra
.136 .592 0 r
.45469 .32117 .46739 .31636 .48891 .31459 .47644 .31892 Metetra
.206 .616 0 r
.47644 .31892 .48891 .31459 .51068 .31452 .49842 .3182 Metetra
.299 .646 0 r
.49842 .3182 .51068 .31452 .53273 .31597 .52068 .31886 Metetra
.418 .68 0 r
.52068 .31886 .53273 .31597 .5551 .31873 .54325 .32065 Metetra
.562 .719 0 r
.54325 .32065 .5551 .31873 .57782 .32252 .56615 .3233 Metetra
.73 .76 0 r
.56615 .3233 .57782 .32252 .60092 .327 .58941 .32645 Metetra
.803 .687 0 r
.58941 .32645 .60092 .327 .62439 .33178 .61303 .32968 Metetra
.845 .569 0 r
.61303 .32968 .62439 .33178 .64824 .33637 .63701 .3325 Metetra
.884 .443 0 r
.63701 .3325 .64824 .33637 .67244 .34021 .66131 .33433 Metetra
.92 .32 0 r
.66131 .33433 .67244 .34021 .69696 .34266 .68589 .33453 Metetra
.949 .211 0 r
.68589 .33453 .69696 .34266 .72171 .343 .71067 .33236 Metetra
.968 .133 0 r
.71067 .33236 .72171 .343 .7466 .34041 .73555 .327 Metetra
.976 .102 0 r
.73555 .327 .7466 .34041 .7715 .33402 .76039 .31757 Metetra
.973 .115 0 r
.06272 .52856 .07698 .54398 .09633 .53864 .08173 .52618 Metetra
.975 .105 0 r
.08173 .52618 .09633 .53864 .11631 .52945 .10144 .51971 Metetra
.965 .147 0 r
.10144 .51971 .11631 .52945 .13676 .51721 .12171 .50996 Metetra
.945 .226 0 r
.12171 .50996 .13676 .51721 .15754 .50267 .14238 .49766 Metetra
.917 .329 0 r
.14238 .49766 .15754 .50267 .17856 .4865 .16334 .48349 Metetra
.884 .443 0 r
.16334 .48349 .17856 .4865 .19971 .46933 .1845 .46807 Metetra
.849 .556 0 r
.1845 .46807 .19971 .46933 .22094 .45169 .20578 .45197 Metetra
.812 .662 0 r
.20578 .45197 .22094 .45169 .24219 .43406 .22712 .43565 Metetra
.776 .754 0 r
.22712 .43565 .24219 .43406 .26343 .41685 .24848 .41956 Metetra
.651 .741 0 r
.24848 .41956 .26343 .41685 .28464 .40041 .26985 .40405 Metetra
.528 .71 0 r
.26985 .40405 .28464 .40041 .30582 .38504 .29121 .38941 Metetra
.429 .683 0 r
.29121 .38941 .30582 .38504 .32698 .37098 .31256 .37591 Metetra
.353 .662 0 r
.31256 .37591 .32698 .37098 .34812 .3584 .33392 .36373 Metetra
.299 .646 0 r
.33392 .36373 .34812 .3584 .36928 .34745 .3553 .35301 Metetra
.268 .636 0 r
.3553 .35301 .36928 .34745 .39047 .33822 .37672 .34386 Metetra
.257 .632 0 r
.37672 .34386 .39047 .33822 .41175 .33077 .39824 .33633 Metetra
.268 .636 0 r
.39824 .33633 .41175 .33077 .43314 .3251 .41986 .33042 Metetra
.299 .646 0 r
.41986 .33042 .43314 .3251 .45469 .32117 .44165 .3261 Metetra
.353 .662 0 r
.44165 .3261 .45469 .32117 .47644 .31892 .46362 .32329 Metetra
.429 .683 0 r
.46362 .32329 .47644 .31892 .49842 .3182 .48583 .32184 Metetra
.528 .71 0 r
.48583 .32184 .49842 .3182 .52068 .31886 .50831 .32159 Metetra
.651 .741 0 r
.50831 .32159 .52068 .31886 .54325 .32065 .53109 .32227 Metetra
.776 .754 0 r
.53109 .32227 .54325 .32065 .56615 .3233 .55418 .32361 Metetra
.812 .662 0 r
.55418 .32361 .56615 .3233 .58941 .32645 .57762 .32523 Metetra
.849 .556 0 r
.57762 .32523 .58941 .32645 .61303 .32968 .60139 .3267 Metetra
.884 .443 0 r
.60139 .3267 .61303 .32968 .63701 .3325 .62549 .32751 Metetra
.917 .329 0 r
.62549 .32751 .63701 .3325 .66131 .33433 .64988 .32707 Metetra
.945 .226 0 r
.64988 .32707 .66131 .33433 .68589 .33453 .67452 .32473 Metetra
.965 .147 0 r
.67452 .32473 .68589 .33453 .71067 .33236 .69932 .31973 Metetra
.975 .105 0 r
.69932 .31973 .71067 .33236 .73555 .327 .72417 .31127 Metetra
.973 .115 0 r
.72417 .31127 .73555 .327 .76039 .31757 .74893 .29848 Metetra
.961 .164 0 r
.0487 .51007 .06272 .52856 .08173 .52618 .06728 .51094 Metetra
.974 .108 0 r
.06728 .51094 .08173 .52618 .10144 .51971 .08665 .5075 Metetra
.974 .108 0 r
.08665 .5075 .10144 .51971 .12171 .50996 .10665 .50051 Metetra
.964 .152 0 r
.10665 .50051 .12171 .50996 .14238 .49766 .12714 .49072 Metetra
.945 .226 0 r
.12714 .49072 .14238 .49766 .16334 .48349 .148 .4788 Metetra
.92 .32 0 r
.148 .4788 .16334 .48349 .1845 .46807 .16911 .46538 Metetra
.891 .42 0 r
.16911 .46538 .1845 .46807 .20578 .45197 .19039 .45102 Metetra
.861 .52 0 r
.19039 .45102 .20578 .45197 .22712 .43565 .21179 .43622 Metetra
.83 .612 0 r
.21179 .43622 .22712 .43565 .24848 .41956 .23325 .4214 Metetra
.8 .693 0 r
.23325 .4214 .24848 .41956 .26985 .40405 .25475 .40695 Metetra
.773 .76 0 r
.25475 .40695 .26985 .40405 .29121 .38941 .27627 .39317 Metetra
.685 .749 0 r
.27627 .39317 .29121 .38941 .31256 .37591 .29781 .38033 Metetra
.606 .73 0 r
.29781 .38033 .31256 .37591 .33392 .36373 .31937 .36861 Metetra
.551 .716 0 r
.31937 .36861 .33392 .36373 .3553 .35301 .34096 .35817 Metetra
.517 .707 0 r
.34096 .35817 .3553 .35301 .37672 .34386 .36262 .34912 Metetra
.506 .704 0 r
.36262 .34912 .37672 .34386 .39824 .33633 .38437 .34151 Metetra
.517 .707 0 r
.38437 .34151 .39824 .33633 .41986 .33042 .40624 .33534 Metetra
.551 .716 0 r
.40624 .33534 .41986 .33042 .44165 .3261 .42826 .33058 Metetra
.606 .73 0 r
.42826 .33058 .44165 .3261 .46362 .32329 .45048 .32713 Metetra
.685 .749 0 r
.45048 .32713 .46362 .32329 .48583 .32184 .47292 .32485 Metetra
.773 .76 0 r
.47292 .32485 .48583 .32184 .50831 .32159 .49562 .32355 Metetra
.8 .693 0 r
.49562 .32355 .50831 .32159 .53109 .32227 .51861 .32298 Metetra
.83 .612 0 r
.51861 .32298 .53109 .32227 .55418 .32361 .5419 .32283 Metetra
.861 .52 0 r
.5419 .32283 .55418 .32361 .57762 .32523 .56551 .32272 Metetra
.891 .42 0 r
.56551 .32272 .57762 .32523 .60139 .3267 .58944 .32219 Metetra
.92 .32 0 r
.58944 .32219 .60139 .3267 .62549 .32751 .61366 .32074 Metetra
.945 .226 0 r
.61366 .32074 .62549 .32751 .64988 .32707 .63815 .31775 Metetra
.964 .152 0 r
.63815 .31775 .64988 .32707 .67452 .32473 .66284 .31256 Metetra
.974 .108 0 r
.66284 .31256 .67452 .32473 .69932 .31973 .68764 .30443 Metetra
.974 .108 0 r
.68764 .30443 .69932 .31973 .72417 .31127 .71244 .29255 Metetra
.961 .164 0 r
.71244 .29255 .72417 .31127 .74893 .29848 .7371 .27606 Metetra
.937 .254 0 r
.03507 .48779 .0487 .51007 .06728 .51094 .05311 .49221 Metetra
.963 .153 0 r
.05311 .49221 .06728 .51094 .08665 .5075 .07205 .49208 Metetra
.975 .106 0 r
.07205 .49208 .08665 .5075 .10665 .50051 .09171 .48815 Metetra
.974 .108 0 r
.09171 .48815 .10665 .50051 .12714 .49072 .11195 .48114 Metetra
.965 .147 0 r
.11195 .48114 .12714 .49072 .148 .4788 .13262 .47173 Metetra
.949 .211 0 r
.13262 .47173 .148 .4788 .16911 .46538 .15363 .46054 Metetra
.928 .291 0 r
.15363 .46054 .16911 .46538 .19039 .45102 .17487 .44815 Metetra
.904 .376 0 r
.17487 .44815 .19039 .45102 .21179 .43622 .19628 .43505 Metetra
.879 .461 0 r
.19628 .43505 .21179 .43622 .23325 .4214 .2178 .42169 Metetra
.855 .538 0 r
.2178 .42169 .23325 .4214 .25475 .40695 .23941 .40845 Metetra
.832 .606 0 r
.23941 .40845 .25475 .40695 .27627 .39317 .26106 .39565 Metetra
.812 .662 0 r
.26106 .39565 .27627 .39317 .29781 .38033 .28276 .38356 Metetra
.795 .705 0 r
.28276 .38356 .29781 .38033 .31937 .36861 .30451 .37238 Metetra
.783 .736 0 r
.30451 .37238 .31937 .36861 .34096 .35817 .32632 .36228 Metetra
.776 .754 0 r
.32632 .36228 .34096 .35817 .36262 .34912 .3482 .35335 Metetra
.773 .76 0 r
.3482 .35335 .36262 .34912 .38437 .34151 .37018 .34565 Metetra
.776 .754 0 r
.37018 .34565 .38437 .34151 .40624 .33534 .39229 .33919 Metetra
.783 .736 0 r
.39229 .33919 .40624 .33534 .42826 .33058 .41455 .33392 Metetra
.795 .705 0 r
.41455 .33392 .42826 .33058 .45048 .32713 .43701 .32975 Metetra
.812 .662 0 r
.43701 .32975 .45048 .32713 .47292 .32485 .45969 .32653 Metetra
.832 .606 0 r
.45969 .32653 .47292 .32485 .49562 .32355 .48262 .32406 Metetra
.855 .538 0 r
.48262 .32406 .49562 .32355 .51861 .32298 .50582 .32207 Metetra
.879 .461 0 r
.50582 .32207 .51861 .32298 .5419 .32283 .52931 .32024 Metetra
.904 .376 0 r
.52931 .32024 .5419 .32283 .56551 .32272 .5531 .31818 Metetra
.928 .291 0 r
.5531 .31818 .56551 .32272 .58944 .32219 .57718 .31542 Metetra
.949 .211 0 r
.57718 .31542 .58944 .32219 .61366 .32074 .60153 .31143 Metetra
.965 .147 0 r
.60153 .31143 .61366 .32074 .63815 .31775 .62609 .30561 Metetra
.974 .108 0 r
.62609 .30561 .63815 .31775 .66284 .31256 .65082 .29729 Metetra
.975 .106 0 r
.65082 .29729 .66284 .31256 .68764 .30443 .67562 .28571 Metetra
.963 .153 0 r
.67562 .28571 .68764 .30443 .71244 .29255 .70036 .27009 Metetra
.937 .254 0 r
.70036 .27009 .71244 .29255 .7371 .27606 .72489 .2496 Metetra
.9 .389 0 r
.02197 .46101 .03507 .48779 .05311 .49221 .03938 .46924 Metetra
.94 .245 0 r
.03938 .46924 .05311 .49221 .07205 .49208 .05779 .47268 Metetra
.963 .153 0 r
.05779 .47268 .07205 .49208 .09171 .48815 .07702 .47207 Metetra
.974 .108 0 r
.07702 .47207 .09171 .48815 .11195 .48114 .09692 .46811 Metetra
.975 .105 0 r
.09692 .46811 .11195 .48114 .13262 .47173 .11734 .46146 Metetra
.968 .133 0 r
.11734 .46146 .13262 .47173 .15363 .46054 .13817 .45275 Metetra
.956 .184 0 r
.13817 .45275 .15363 .46054 .17487 .44815 .15931 .44255 Metetra
.939 .247 0 r
.15931 .44255 .17487 .44815 .19628 .43505 .18068 .43136 Metetra
.921 .315 0 r
.18068 .43136 .19628 .43505 .2178 .42169 .20222 .41963 Metetra
.902 .382 0 r
.20222 .41963 .2178 .42169 .23941 .40845 .22389 .40776 Metetra
.884 .443 0 r
.22389 .40776 .23941 .40845 .26106 .39565 .24565 .39607 Metetra
.868 .496 0 r
.24565 .39607 .26106 .39565 .28276 .38356 .26749 .38484 Metetra
.855 .538 0 r
.26749 .38484 .28276 .38356 .30451 .37238 .28941 .37428 Metetra
.845 .569 0 r
.28941 .37428 .30451 .37238 .32632 .36228 .31141 .36455 Metetra
.838 .588 0 r
.31141 .36455 .32632 .36228 .3482 .35335 .3335 .35576 Metetra
.836 .594 0 r
.3335 .35576 .3482 .35335 .37018 .34565 .3557 .34797 Metetra
.838 .588 0 r
.3557 .34797 .37018 .34565 .39229 .33919 .37804 .34119 Metetra
.845 .569 0 r
.37804 .34119 .39229 .33919 .41455 .33392 .40055 .33536 Metetra
.855 .538 0 r
.40055 .33536 .41455 .33392 .43701 .32975 .42325 .33038 Metetra
.868 .496 0 r
.42325 .33038 .43701 .32975 .45969 .32653 .44616 .32611 Metetra
.884 .443 0 r
.44616 .32611 .45969 .32653 .48262 .32406 .46932 .32231 Metetra
.902 .382 0 r
.46932 .32231 .48262 .32406 .50582 .32207 .49274 .31873 Metetra
.921 .315 0 r
.49274 .31873 .50582 .32207 .52931 .32024 .51643 .31503 Metetra
.939 .247 0 r
.51643 .31503 .52931 .32024 .5531 .31818 .5404 .31079 Metetra
.956 .184 0 r
.5404 .31079 .5531 .31818 .57718 .31542 .56462 .30555 Metetra
.968 .133 0 r
.56462 .30555 .57718 .31542 .60153 .31143 .58908 .29877 Metetra
.975 .105 0 r
.58908 .29877 .60153 .31143 .62609 .30561 .61372 .28983 Metetra
.974 .108 0 r
.61372 .28983 .62609 .30561 .65082 .29729 .63847 .27807 Metetra
.963 .153 0 r
.63847 .27807 .65082 .29729 .67562 .28571 .66324 .26275 Metetra
.94 .245 0 r
.66324 .26275 .67562 .28571 .70036 .27009 .68789 .2431 Metetra
.9 .389 0 r
.68789 .2431 .70036 .27009 .72489 .2496 .71228 .21833 Metetra
.847 .563 0 r
.00961 .42897 .02197 .46101 .03938 .46924 .02629 .44122 Metetra
.9 .389 0 r
.02629 .44122 .03938 .46924 .05779 .47268 .04406 .44848 Metetra
.937 .254 0 r
.04406 .44848 .05779 .47268 .07702 .47207 .06276 .45144 Metetra
.961 .164 0 r
.06276 .45144 .07702 .47207 .09692 .46811 .08223 .45077 Metetra
.973 .115 0 r
.08223 .45077 .09692 .46811 .11734 .46146 .10231 .44713 Metetra
.976 .102 0 r
.10231 .44713 .11734 .46146 .13817 .45275 .12289 .44114 Metetra
.972 .116 0 r
.12289 .44114 .13817 .45275 .15931 .44255 .14386 .43334 Metetra
.964 .149 0 r
.14386 .43334 .15931 .44255 .18068 .43136 .16512 .42426 Metetra
.953 .194 0 r
.16512 .42426 .18068 .43136 .20222 .41963 .18662 .41435 Metetra
.94 .243 0 r
.18662 .41435 .20222 .41963 .22389 .40776 .20831 .404 Metetra
.928 .291 0 r
.20831 .404 .22389 .40776 .24565 .39607 .23013 .39355 Metetra
.916 .335 0 r
.23013 .39355 .24565 .39607 .26749 .38484 .25208 .38329 Metetra
.905 .371 0 r
.25208 .38329 .26749 .38484 .28941 .37428 .27414 .37342 Metetra
.898 .398 0 r
.27414 .37342 .28941 .37428 .31141 .36455 .29631 .36412 Metetra
.893 .415 0 r
.29631 .36412 .31141 .36455 .3335 .35576 .31859 .3555 Metetra
.891 .421 0 r
.31859 .3555 .3335 .35576 .3557 .34797 .34101 .34761 Metetra
.893 .415 0 r
.34101 .34761 .3557 .34797 .37804 .34119 .36357 .34047 Metetra
.898 .398 0 r
.36357 .34047 .37804 .34119 .40055 .33536 .38631 .33401 Metetra
.905 .371 0 r
.38631 .33401 .40055 .33536 .42325 .33038 .40924 .32813 Metetra
.916 .335 0 r
.40924 .32813 .42325 .33038 .44616 .32611 .43238 .32267 Metetra
.928 .291 0 r
.43238 .32267 .44616 .32611 .46932 .32231 .45576 .31741 Metetra
.94 .243 0 r
.45576 .31741 .46932 .32231 .49274 .31873 .47939 .31206 Metetra
.953 .194 0 r
.47939 .31206 .49274 .31873 .51643 .31503 .50328 .30627 Metetra
.964 .149 0 r
.50328 .30627 .51643 .31503 .5404 .31079 .52741 .29964 Metetra
.972 .116 0 r
.52741 .29964 .5404 .31079 .56462 .30555 .55178 .29167 Metetra
.976 .102 0 r
.55178 .29167 .56462 .30555 .58908 .29877 .57634 .28183 Metetra
.973 .115 0 r
.57634 .28183 .58908 .29877 .61372 .28983 .60104 .2695 Metetra
.961 .164 0 r
.60104 .2695 .61372 .28983 .63847 .27807 .6258 .25403 Metetra
.937 .254 0 r
.6258 .25403 .63847 .27807 .66324 .26275 .65052 .2347 Metetra
.9 .389 0 r
.65052 .2347 .66324 .26275 .68789 .2431 .67506 .21076 Metetra
.847 .563 0 r
.67506 .21076 .68789 .2431 .71228 .21833 .69927 .18148 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14789 .21178 m
.15252 .21643 L
s
[(-5)] .13865 .20246 .99238 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.5537 .05288 m
.55757 .05817 L
s
[(5)] .54594 .04229 .73209 1 Mshowa
.125 Mabswid
.18577 .19694 m
.18851 .19978 L
s
.22422 .18189 m
.22691 .18476 L
s
.26324 .16661 m
.2659 .16952 L
s
.30285 .1511 m
.30546 .15404 L
s
.3839 .11937 m
.38642 .12239 L
s
.42536 .10313 m
.42784 .10619 L
s
.46747 .08664 m
.4699 .08974 L
s
.51024 .06989 m
.51262 .07303 L
s
.11057 .22639 m
.11338 .22915 L
s
.07378 .2408 m
.07662 .24352 L
s
.03752 .255 m
.0404 .25768 L
s
.59784 .03559 m
.60011 .03881 L
s
.64269 .01803 m
.64491 .02128 L
s
.68828 .00018 m
.69043 .00347 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00d_ooool2o`0004cooooo003?ooooo`Go0000C?ooool00<gooooo0_l00004ooooo`;o0000
Boooool00:cooooo0ol0000Kooooo`?o00001_ooool00ol0003oooooo`00001:ooooo`00Zoooool0
1Ol0003ooooooooooooooooo000001Sooooo0_l00009ooooo`03o`000?oooooo000004[ooooo002_
ooooo`03o`000?oooooooooo01?ooooo0ol0000;ooooo`04o`000?ooooooooooo`0004Wooooo002_
ooooo`03o`000?oooooooooo017ooooo0_l00003ooooo`03o`000?oooooooooo00Sooooo00Go0000
ooooooooooooooooo`000018ooooo`00Zoooool4o`00017ooooo0ol0000@ooooo`05o`000?oooooo
ooooooooool00000B?ooool00:_ooooo00?o0000ooooooooool04?ooool2o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`15ooooo`00Zoooool5o`0000_ooooo0ol0000Eoooo
o`07o`000?ooooooooooooooool0003oooooo`000016ooooo`00^?ooool3o`0000;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Cooooo002foooo
o`;o00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo002cooooo`?o
00007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo002aooooo`;o0000
8Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo002^ooooo`?o000000?o
ooooo`000?ooool08?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo002/
ooooo`;o00001Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0@Oooool00:Wooooo0ol0000Xooooo`03o`000?oooooooooo00Gooooo0_l00012oooo
o`00Yoooool2o`0002_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0oooooo`00
Y?ooool3o`000003ooooool0003ooooo02[ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0;ooooo`?o0000<Oooool00:;ooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000033ooooo002Oooooo`?o0000<_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo1Ol00005ooooo`03o`000?oo
oooooooo02kooooo002Mooooo`;o0000=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0;_ooool009[ooooo1?l0000fooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01oooool4o`00037ooooo001iooooo`;o00007Oooool2o`0003[o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03;o
oooo001hooooo`04o`000?ooooooooooo`0001Wooooo0ol0000looooo`03o`000?oooooooooo00Wo
oooo0ol00008ooooo`Go0000<?ooool007Sooooo00Co0000oooooooooooo00005_ooool3o`0003oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0jooooo`00N?ooool01?l0003ooooo
ooooool0000Dooooo`Co0000@?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Wo
oooo001hooooo`04o`000?ooooooooooo`0001;ooooo0_l00014ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0>Oooool007Sooooo00Co0000oooooooooooo00003oooool3o`0004Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0hooooo`00NOooool2o`0000gooooo
0ol00019ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>?ooool008Kooooo1?l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=oooool008?ooooo0ol0001?
ooooo`03o`000?oooooooooo00kooooo0_l0000hooooo`00POooool2o`0005;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0fooooo`00O_ooool3o`0005Cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0eooooo`00O?ooool3o`0005Kooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0dooooo`00NOooool3o`0000?ooooo00?o0000ooooooooool0Dooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Cooooo001gooooo`;o0000G?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo03?ooooo001dooooo`?o0000G_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo03;ooooo001booooo`;o000000?oooooo`000?oo
ool0G_ooool00ol0003oooooooooo`0Booooo`;o0000=?ooool006oooooo0ol0001Sooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0<Oooool006gooooo0_l0001Vooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0<?ooool006[ooooo0ol0001Xooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0<?ooool004Sooooo0ol0000Mooooo`;o00000_ooool00ol0
003oooooooooo`1Vooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;oooool004Oo
oooo00Go0000ooooooooooooooooo`00000Iooooo`?o0000KOooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo02kooooo0011ooooo`Go00001Oooool00ol0003oooooooooo`0Eooooo`;o
0000L?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02kooooo001;ooooo`03o`00
0?oooooooooo01;ooooo0ol0001booooo`03o`000?oooooooooo01Oooooo0_l0000_ooooo`00Aooo
ool4o`0001?ooooo0_l0001eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;Ooo
ool004Oooooo00?o0000ooooooooool04Oooool3o`0007Kooooo0ol0000Jooooo`03o`000?oooooo
oooo02cooooo0017ooooo`Go00003?ooool3o`0007Sooooo00Co0000omR@0?l0003o00006oooool0
0ol0003oooooooooo`0[ooooo`00E_ooool4o`0007Sooooo00?o0000omR@0?oHT0000_l0000Koooo
o`03o`000?oooooooooo02_ooooo001Dooooo`;o0000Noooool01ol0003of900omR@0?oHT03o0000
omR@0?l000006oooool00ol0003oooooooooo`0Zooooo`00DOooool3o`0007cooooo00?o0000omR@
0?oHT0000ooHT002o`0001cooooo00?o0000ooooooooool0:Oooool004kooooo0ol0001nooooo`03
o`000?oHT03of90000Cof9000_l0000Kooooo`;o0000:oooool004cooooo0_l00002ooooo`03o`00
0?oooooooooo07_ooooo0_l00006omR@0003o`000?oHT03o000001cooooo00?o0000ooooooooool0
1_ooool2o`00023ooooo0019ooooo`?o0000POooool01?l0003oiV<0onIS0?l00005omR@0003o`00
0?oHT03o000001gooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Oooooo`00
Aoooool2o`0008?ooooo00Go0000onIS0?oVH`3oiV<0o`000005omR@00?o00007Oooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001oooooo0014ooooo`?o0000Q?ooool00ol0003o
iV<0onIS0002onIS0003o`000?oHT03of90000?of90000Co0000onIS0?oVH`3o00007Oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0001oooooo0012ooooo`;o0000Q_ooool00ol0
003oiV<0onIS0004onIS0004o`000?oHT03of900omR@00;o00000_oVH`000ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007oooool003oooooo0ol00026
ooooo`;o00001ooVH`001_l0003of900omR@0?l0003oiV<0o`0000?oiV<000?o0000ooooooooool0
6oooool2o`0000?ooooo00Co0000oooooooooooo00007oooool003gooooo0_l00028ooooo`03o`00
0?o_@@3o000000OoiV<000?o0000omR@0?l000000_oVH`001Ol0003oiV<0onIS0?oVH`3o000001co
oooo00?o0000ooooool000001?ooool2o`00023ooooo000jooooo`Co0000Qoooool2o`0000?okd40
00?o0000onIS0?oVH`001?oVH`02o`0000;oiV<00_l00003onIS0003o`000?oooooooooo01gooooo
00?o0000ooooooooool08oooool003Sooooo0_l0002:ooooo`03o`000?o_@@3okd4000?okd4000?o
0000onIS0?oVH`000ooVH`000ol0003ol3h0o`000002o`000003onIS0?l0003oiV<000;oiV<00_l0
000Nooooo`03o`000?oooooooooo02?ooooo000eooooo`?o0000R_ooool2o`0000Ookd4000?o0000
onIS0?oVH`001?l000000oo`?P3o0000onIS0002onIS0005o`000?oVH`3o0000onm10?l000007ooo
ool00ol0003oooooooooo`0Rooooo`00=?ooool2o`0008_ooooo00?o0000ooHY0?l000001oo_@@04
o`0000Col3h000?o0000onIS0?oVH`000_oVH`001Ol0003okd40onm10?o_@@3o000001kooooo00?o
0000ooooooooool08_ooool003Cooooo00?o0000ooooool00000R?ooool2o`0000?omRT000?o0000
onm10?o_@@000_o_@@04o`0000Ool3h000Ko0000onIS0?oVH`3o0000onm10?l00002onm10003o`00
0?oooooooooo01gooooo00?o0000ooooooooool08Oooool003Cooooo00Co0000oooooooooooo0000
Q_ooool00ol0003omRT0ooHY0003ooHY0003o`000?o_@@3o000000;o000000Cokd40o`000?of9`3o
00001oo`?P000ol0003oiV<0o`000002onm10005o`000?o_@@3okd40onm10?l000007_ooool2o`00
02;ooooo000dooooo`05o`000?ooooooooooooooool00000Poooool2o`0000GomRT00ol00002onm1
00;o00000oof9`000ol0003ol3h0oo0n0004oo0n00;o00001?o_@@001?l0003okd40onm10?l0000O
ooooo`03o`000?oooooooooo023ooooo000cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0O_ooool2o`000003ooTM0?l0003omRT000;omRT00_l00002ooHY0003o`000?o_@@3o0000
00GomRL000?o0000oo0n0?o`?P000oo`?P000ol0003omRL0o`000005onm10003o`000?o_@@3o0000
023ooooo00?o0000ooooooooool07oooool003?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1kooooo`;o00001?oi7@03o`0000ComRT00_l00007ooHW0003o`000?o`?P3ol3h000;o
00000oof9`000ol0003okd40onm10002onm10004o`000?o_@@3o0000o`00023ooooo00?o0000oooo
ooooool07_ooool003?ooooo0_l00006ooooo`03o`000?oooooooooo07Sooooo0_l00003ooTM00?o
000000?onAd0o`000?of:@000_of:@02o`000003ooTK0?l0003omRL000KomRL000?o0000oo0n0?l0
00001Oof9`000ol0003okd40onm10003onm10003o`000?of:@3o0000023ooooo00?o0000oooooooo
ool07_ooool003?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1dooooo`?o0000
00?onAX0o`000?l000000_l00004ooTM0004o`000?of:@3o0000o`0000ConA/000?o0000ooHW0?of
9`001?of9`02o`0000OomRL000?o0000onm10?o_@@000_l000001?of:@3o0000ooHY0?l0000Poooo
o`03o`000?oooooooooo01gooooo000cooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0L?ooool3o`0000;onAX01?l00006ooTM00;o00001ooi6`001?l0003omRL0ooHW0?of9`02o`00
0003ooTK0?l0003omRL000KomRL000?o0000onm10?l000001?of:@000ol0003omRT0o`00000Ooooo
o`;o00007_ooool003?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1/ooooo`?o
000000?on1d0o`000?l000000_l00004ooTJ0003o`000?oi7@3onAd000?o000000?onAX0o`000?oi
6`001_oi6`001?l0003omRL0o`000?l00004ooTK0003o`000?of9`3omRL000ComRL00_l00005ooHY
0003o`000?of:@3o0000023ooooo00?o0000ooooooooool07?ooool003;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Xooooo`?o00000ooh7@03o`0000KonAX00ol00005ooTJ0003
o`000?oi6`3onA/000ConA/00_l00007ooTK0004o`000?of9`3omRL0ooHW00;o000000?onA/0o`00
0?of:@001Oof:@03o`00023ooooo00?o0000ooooooooool06oooool003;ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1Tooooo`?o00000oof9P03o`0000?on1d000?o0000ooTJ0?oi
6P000ol00002ooLR0003o`000?oi6P3onAX000ConAX000?o0000ooTK0?oi6`000ol000000ooi6`3o
0000ooTK0006ooTK0004o`000?of9`3o0000o`0000ConA/000?o0000ooHY0?of:@000_of:@04o`00
027ooooo00?o0000ooooooooool06_ooool003;ooooo0_l0000=ooooo`;o0000H?ooool4o`0000?o
mRH00ol000000oof9P3o0000ooPM0002ooPM00Co00001_og8P001?l0003onAX0ooTJ0?oi6P05o`00
00GonA/000?o0000ooTK0?oi6`001?oi6`02o`0000OonA/000Co0000ooHY0?l0003o00000ooi7@02
o`00023ooooo00?o0000ooooooooool06_ooool003;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`1Gooooo`Ko00001?oc<@03o`0000;omRH01_l00004oo@_0004o`000?og8P3omb80
ooLR00Ko00001?og9@000ol0003onA/0ooTK0004ooTK0003o`000?oi6`3onA/000?o00000_oi6`00
0ol0003onA/0ooTK0004ooTK00;o00001Ooi7@000ol0003onAd0o`00000Pooooo`03o`000?oooooo
oooo01Wooooo0007ooooo`?o00000oooool2o`0000Cooooo0ol00003ooooo`03o`000?oooooooooo
00;ooooo0ol00004ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Cooooo`Go00000oo`?P000ol0003olc40o`000007o`0000Gol3l000Co0000oo@_
0?od;`3om2l01Ol00004oo8f0003o`000?og9@3ombD000CombD000Co0000ooTK0?oi6`3onA/01Ol0
0006ooTK0003o`000?oi6`3onA/000?o000000?onAX0o`000?oi7@001Ooi7@02o`00023ooooo0_l0
000Jooooo`002?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo04kooooo1ol00003oo0n00Ko00000oo[D00<o`0000CokDX000?o0000oo8f
0?ob=P000oob=P001?l0003ombD0ooLU0?og9@06o`0000GomRH000Co0000ooTK0?oi6`3onA/01Ol0
0005ooTJ0003o`000?oi7@3onAd000ConAd00_l0000Pooooo`03o`000?oooooooooo01Sooooo0005
ooooo`Go00000_ooool01Ol0003oooooooooool0003ooooo00Go00001oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooooooool2o`00
01?ooooo00?o0000ooooooooool0BOooool5o`0000CokDX0:?l00005oo4i0004o`000?of9P3omRH0
ooHV00Ko00001?og9@000ol0003onAX0ooTJ0004ooTJ0003o`000?oi7@3onAd000?o000000?onAX0
o`000?ooool08?ooool00ol0003oooooooooo`0Gooooo`001Oooool01?l0003oooooooooool00003
ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`06ooooo`Co0000
0oooool01?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool000005Oooool00ol0
003oooooooooo`14ooooo`Co00000ooZE@0=o`000004o`0@:_l0003o0000o`0000;o00XT00Co0000
o`0;9Ol02bGo00/U8?l00004oo4i0003o`000?og9@3ombD000CombD000Co0000ooTJ0?oi6P3onAX0
1Ol00004ooTJ00;o00008?ooool00ol0003oooooooooo`0Gooooo`001_ooool00ol0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000002?ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooo`000?ooool01?l00004ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0@?ooool3o`000003onMN0?l0003o000000go00000ol04R`2o`0000Go
00XT1?l00003o`078@03o`000?l02bGo00/U00;o00/U00?o0000o`0B;?l04R`00_l04R`01?l0003o
01ddo`0M=?l07C@=o`000003onYD0?l0003olCT000ColCT000Co0000ooLU0?og9@3ombD01_l00004
ooLR0003o`000?oi6P3onAX000?onAX00_l0000Pooooo`03o`000?oooooooooo01Kooooo0007oooo
o`;o00000oooool01?l0003oooooooooool00003ooooo`;o00002Oooool00ol0003oooooooooo`03
ooooo`06o`000?ooooooooooo`000?oooooo00001oooool2o`0001Kooooo00?o0000ooooooooool0
>_ooool=o`0000;o03I32?l000001?l04Rco0000o`000?l00002o`0;9@03o`000?l02RCo000000;o
00000_l01R000ol0003o00LQo`078@03o`078@03o`000?l02bGo00/U00co00000ol0;clCo`0000Co
lSH000?o0000ooLR0?og8P001?og8P001?l0003onAX0ooTJ0?oi6P04o`00023ooooo00?o0000oooo
ooooool05Oooool000Sooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000oooooooo
ool02?ooool2o`0000Cooooo0_l00002ooooo`Go00000oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo03Gooooo1?l00002onEU00Go000000Ko05m4o`000?l0D4ko051>o`000?l0=T<3
o`000003o`0S>?l0003o000000?o01H_0ol00004o`0;9@?o00001Ol01R001?l0003o00LQo`078Ol0
1b44o`0000?o00XT00?o0000o`0@:_l042X00_l042X00ol0003o01/co`0K<`06o`0000;o04Y=0ol0
00000ol0GdCo0000o`000007o`000003on]A0?l0003olSH000ColSH000Co0000ooLR0?og8P3omb80
1_l00002ooPM00;o00008?ooool2o`0000Kooooo0ol0000=ooooo`00<Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo037ooooo0ol00002onAZ017o000000?o02<ho`000?l05Rl00_l0
5Rl2o`0000?o00lY00Co0000o`0;9Ol0003o00000ol01b401?l0003o00HPo`068?l01R05o`0000;o
00HP00?o0000o`0:9?l02R@00ol02R@00ol0003o010Zo`0@:P02o`0@:P05o`000?l06c?o01/co`0K
<ol000000_l0;Ch4o`000003o`1:COl0003o000000Oo00000_oTJ`0;o`0000?om2l000?o0000ooPM
0?oh7@000ooh7@02o`00023ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000cooooo000aooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;_ooool;o`00
00;o06@o0_l000000ol0ET_o0000o`000003o`0000;o02dn1?l000000ol05Roo0000o`0?:@04o`0?
:@;o00001Ol01b44o`0000;o00DN00?o0000o`068?l01R000ol01R001?l0003o00XTo`0:9?l02R@<
o`0000?o02dn00?o0000o`18Bol000000_l00002o`1KA`;o000000?o06lao`000?l000001?l00000
0ooTJ`3o0000one:0004one:0003o`000?od;`3om2l000?om2l000Co0000ooPM0?oh7@3on1d01?l0
000Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool0033ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Zooooo`_o000000Co07@Yo`000?l0I3oo06@o1?l0
0002o`13B@05o`000?l0;Cko02dno`0]?_l000000ol07cH3o`0000?o00lY0_l00002o`0;9@03o`00
0?l01b7o000000;o00000_l01R000ol0003o00DNo`057P02o`057P04o`000?l01R3o00HPo`0680Go
00000_l02bD00ol0003o018/o`0B;002o`0B;004o`000?l07CCo01ddo`0M=0Ko00000ol0B4/2o`00
0003o`1KAol0003o000001Oo00000oof9P02o`0001oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0:ooooo`00<?ooool00ol0003oooooooooo`0Kooooo`;o00009oooool9o`000005
odbU0?l0003o08D9o`000?l0M2T03?l000001?l0;Cko0000o`0O=_l07cH2o`0000?o01H_00?o0000
o`0?:Ol000001?l02bD2o`0000Ko00HP00?o0000o`057_l01Ah01Ol00003o`078@03o`000?l02bGo
00/U00;o00/U00?o0000o`0B;?l04R`00_l04R`01Ol0003o01ddo`0M=?l07CCo000000?o02lo0ol0
00000ol0B4_o0000o`1JB003o`000004o`1/=_l0003o0000o`214`_o000000?oif00o`000?o`?`00
0oo`?`000ol0003omRH0ooHV0002ooHV0003o`000?of9P3o000001oooooo00Co0000oooooooooooo
oooo1?l0000=ooooo`00<?ooool2o`0001kooooo00?o0000ooooooooool08Oooool3o`000003onAZ
0?l0003o000000Oo000000?o08D9o`000?l000001?l000001Ol0GTGo0000o`1ACOl0DDgo000000?o
03e70ol000000ol07cKo0000o`0F;`04o`0F;`?o00000ol02bD01?l0003o00XTo`0:9?l00005o`06
80?o00000ol01R000ol0003o00LQo`078@03o`078@05o`000?l02bGo00/Uo`0;9Ol000001?l04R`0
0ol0003o01ddo`0M=002o`0M=006o`000?l0;coo02loo`0_?ol0003o04Y=0ol00003o`1JB0;o0000
00Co06`fo`000?l0003o084C1ol00002on5f00Ko000000?ol3l0o`000?of9P000_of9P04o`0001oo
oooo00Co0000oooooooooooo00004?ooool0033ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0NoooooaCo00000_l0GTD01?l0003o055=o`1ACOl00003o`0mA`04o`000?l0;Cko02dn
o`0]?P;o00000ol05Rl2o`0000?o018/00?o0000o`0;9Ol000001?l02R@00ol0003o00HPo`000002
o`000003o`078Ol0003o00HP00Co00HP00Co0000o`078Ol01b7o00LQ4?l00004o`0_?`04o`000?l0
BTgo04Y=o`1:C@;o000000?o05Y8o`000?l0JcL02_l000000oo5`P3o0000o`000002o`000004on5f
0?l0003oje00on]@00Go00000_oc<@000ol0003olc40o`00000Mooooo`;o00000_ooool5o`0000co
oooo000`ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06_ooool3o`0000;oiFD0
3_l00002o`1/=P04o`000?l0GTGo05i5o`0000;o055=00Go0000o`0mAol0?DOo03e7o`000003o`0]
?P06o`000?l08cSo02<ho`000?l05Roo00001Ol04R`2o`0000Go00XT0_l00005o`078@03o`000?l0
1R3o00HP00;o00HP1?l00002o`0;9@05o`000?l03bWo00lYo`0?:Ol000001?l05Rl01?l0003o02<h
o`0S>?l08cP6o`0000Co04Y=1?l00003o`1[=`;o000000?o07dIo`000?l000001Ol000000oo5`P3o
0000o`000005o`000003on]@0?l0003olc4000?olc4000?o0000oo<a0?l000007_ooool00ol0003o
ooooooooo`0@ooooo`00<?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Oooooo
1?l000000ooUI@3o0000o`00000Ho`000003o`0mAol0003o02dn00;o02dn00Co0000o`0S>?l08cSo
02<h0_l00005o`0B;003o`000?l042[o000000?o00XT0_l000000ol02bGo0000o`078@04o`078@03
o`000?l01R3o000000;o000000?o00XTo`000?l02bD01?l02bD01Ol0003o00lYo`0?:Ol03bWo0000
00Co01H_00Go0000o`0S>?l08cSo02<ho`000003o`0f@`Go000000Co04Y=o`000?l0FdOo05]70ol0
00000ol0JcOo0000o`00000:o`000005omBK0?l0003o0000o`000?oVH@002_l0000Nooooo`03o`00
0?oooooooooo00oooooo000_ooooo`?o00008_ooool00ol0003oooooooooo`0Dooooo`;o00000ooW
GP0?o`0000;o07DW00Co0000o`1X>ol0J3_o00000ol0FdL00ol0003o055=o`1AC@04o`000003o`0]
?_l0003o02<h00;o02<h00Co0000o`0M=?l07CCo00000ol04R`01ol0003o010Zo`0@:_l042[o0000
o`0:9?l000001?l02bD00ol0003o00LQo`078@02o`078@;o00001Ol02R@00ol0003o00/Uo`0;9@02
o`0;9@03o`000?l03bWo00lY00;o00lY00?o0000o`0F;ol05Rl00_l05Rl01Ol0003o02<ho`0S>?l0
8cSo000000?o03I300Co0000o`1@C_l0D4ko051>1Ol00002o`1/=P?o000000Co07`Ko`000?l0003o
3i002Ol000001_oDV`3o0000o`000?l0003oiV40o`0000?ol3h000?o0000oo0n0?l000007_ooool0
0ol0003oooooooooo`0?ooooo`001?ooool3o`0000?ooooo0_l00004ooooo`?o00000oooool00ol0
003oooooooooo`02ooooo`?o00001?ooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool04Oooool2o`0000;oieh00ol000000ooJR@3o0000o`000008o`00
00;o08@;00Co0000o`1e9ol0MBOo00000_l0J3/01Ol0003o05]7o`1KAol0FdOo000000;o055=00?o
0000o`13BOl0@dT00_l0@dT01Ol0003o02<ho`0S>?l08cSo000000Co01dd00?o0000o`0B;?l00000
1Ol042X00ol0003o00/Uo`0;9@03o`0;9@03o`000?l01b7o000000;o000000?o00/Uo`000?l02R@0
1?l02R@01?l0003o00/Uo`0;9Ol02bDAo`0000?o03I300?o0000o`1@C_l0D4h00_l0D4h01?l0003o
05m4o`000?l00004o`1/=P;o000000Co07`Ko`000?l0003o3i000ol000000onK^P3o0000o`000004
o`000004on9a0?l0003o0000o`0000?ol3h000?o0000oo0n0?l000007_ooool00ol0003ooooooooo
o`0>ooooo`001Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00kooooo2ol000000on__`3o0000o`000003o`000005oa^D0?l0003o08@;
o`242ol000000_l0MBL01?l0003o06Pko`1X>ol00003o`1KA`04o`000?l0DDgo055=o`0000Co04=9
00Go0000o`0f@ol0003o02<ho`000005o`0M=0;o00001Ol042X2o`0000Go00/U0_l00005o`0;9@03
o`000?l02RCo00XT00;o00XT1?l00002o`0B;003o`000?l05Roo01H_00;o01H_00?o0000o`0O=_l0
7cH00_l07cH01?l0003o02dno`0]?_l0;Ch6o`0000Co051>00Co0000o`1OA?l0GdCo00000ol0K3H0
1Ol0003o07dIo`000?l0003o3Hl000;o000000?oA:80o`000?l000000_l000000onK^P3o0000o`00
0004o`000003on9a0?l0003o000000Go00007Oooool2o`0000oooooo0002ooooo`Go00000_ooool0
1Ol0003oooooooooool0003ooooo00Go00001oooool01Ol0003ooooooooooooooooo000000;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo0_l0000Voooo
o`03o`000?oooooooooo00[ooooo0ol00002onYE00;o00000_oNOP07o`0000;oC:D000?o0000oa^D
0?l000000_l0Q0/9o`000005o`1KAol0003o055=o`1ACOl000001?l0@dT01?l0003o03I3o`0f@ol0
=T<2o`0000?o01dd0_l00002o`0K<`05o`000?l042[o010Zo`0@:_l000000_l04R`01ol0003o00/U
o`0;9Ol02bGo0000o`0?:Ol000001_l02bD01_l0003o00XTo`000?l0003o010Zo`0000Go018/00?o
0000o`0F;ol05Rl00_l05Rl00ol0003o01lfo`0O=P02o`0O=P05o`000?l0;Cko02dno`0]?_l00000
0ol0@dT3o`0000;o051>00Co0000o`1OA?l0GdCo05m40_l00002o`1/=P04o`000?l0OAWo07dIo`00
00;o3Hl000?o0000odBR0?m4XP001Ol000000oo;]03o0000o`000004o`0000;okDX000?o0000one:
0?l000007_ooool00ol0003oooooooooo`0=ooooo`000_ooool01?l0003oooooooooool00003oooo
o`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`06ooooo`Co00000ooo
ool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00Oooooo1?l00002onYE0003o`000?oNOP3ogWh000Ko000000CoQkD0o`000?m<Y@3o
C:D01ol000001Ol0PA?o0000o`1c:ol0Lb_o000000;o06Pk1_l00003o`13B@03o`000?l0=T?o03I3
00;o03I300Go0000o`0_?ol0003o01ddo`000005o`0K<`03o`000?l042[o000000Co018/00?o0000
o`0;9Ol000000ol03bT00ol0003o00/Uo`0;9@03o`0;9@;o00001?l042X00ol0003o018/o`0B;003
o`0B;005o`000?l05Roo01H_o`0F;ol000001?l07cH00ol0003o02dno`0]?P02o`0]?P06o`000?l0
@dWo04=9o`13BOl0003o05I;0ol00003o`1OA003o`000?l0Kc7o000000;o00000ol0OAT2o`000003
o`f?0?l0003o000000;oA:800_l000000on=]`3o0000o`000002ol^d00Oo000000?okDX0o`000?oo
ool07Oooool00ol0003oooooooooo`0<ooooo`000oooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`04ooooo`06
o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00Cooooo0_l00004one:00So000000?oaL80o`000?n7]@001_l000000ol=S`3o0000o`214`02
o`214`04o`000?l0Lb_o07<[o`0000;o06Pk00Go0000o`1NAOl0GTGo05i5o`000002o`1FB`03o`00
0?l0@dWo000000Co03I300Go0000o`0_?ol0;coo02loo`000006o`0K<`;o00001Ol04R`2o`0000Go
00lY00?o0000o`0;9Ol000000_l000000ol04Rco0000o`0@:P04o`0@:P03o`000?l04Rco018/00;o
018/00Go0000o`0F;ol05Roo01H_o`000004o`0O=P03o`000?l0;Cko02dn00;o02dn00?o0000o`13
BOl0@dT00_l0@dT01?l0003o05I;o`1FBol0ET/2o`0000;o05m400Co0000o`1_<Ol0Kc7o06la0_l0
00000ol0OAWo0000o`n@0006o`000004ohBd0?l0003o0000olRl00?o00000_oJR@03o`000004onYE
0?l0003o0000o`0001gooooo00?o0000ooooooooool03?ooool000Cooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000?ooooo0_l00009ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool00_ooool00ol0003okDX0one:0002one:00;o000000?ohW40o`000?l000000ol00002olG2
00Go00000_lgWP000ol0003o3Hl0o`000003o`214`04o`000?l0Lb_o07<[o`0000;o06Pk00Go0000
o`1NAOl0GTGo05i5o`000004o`1FB`;o00000ol0=T<01ol0003o02loo`0_?ol0;coo0000o`0]?_l0
00000ol06c<2o`000003o`0M=?l0003o018/00;o018/0_l000000ol05Roo0000o`0?:@04o`0?:@;o
00001Ol04R`00ol0003o010Zo`0@:P02o`0@:P04o`000?l04Rco018/o`0B;1Go00000ol0ET/00ol0
003o06@oo`000002o`0000?o06la00?o0000o`214ol000000_l00002o`n@00;o000000?o@J40o`00
0?l000000_n4]0000ol0003ob;`0olRl0002o`0000CofXT00ol000000ooZE@3o0000ooooo`0Loooo
o`03o`000?oooooooooo00_ooooo0005ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03
o`000?oooooooooo00Sooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo00?o0000oooooooo
ool0:_ooool6o`000004one:0?l0003o0000on9a00?o00000_oDV`05o`0000;oJjh000Ko0000ocNN
0?lgWP3o0000o`f?0?l00003o`214`04o`000?l0Lb_o07<[o`0000;o06Pk00Go0000o`1NAOl0GTGo
05i5o`000004o`1FB`06o`000?l0D4ko051>o`000?l0=T?o00000ol0;cl01ol0003o02dno`0]?_l0
;Cko0000o`0K<ol000001?l07C@00ol0003o018/o`000004o`0F;`03o`000?l03bWo00lY00;o0000
00?o01H_o`000?l04R`01?l04R`01?l0003o010Zo`0@:_l042X5o`0000;o01dd00Go0000o`0S>?l0
8cSo02<ho`000004o`0]?P03o`000?l0?DOo03e700;o03e700Co0000o`1ACOl0DDgo055=0ol00002
o`1FB`04o`000?l0I3oo06@oo`1T?`?o000000Co06lao`000?l0PA?o084C0_l00003o`n@00;o0000
00Co@J40o`000?l0003oQ;@00_l00002olRl00?o000000?ofXT0o`000?oWGP001?l0000Mooooo`03
o`000?oooooooooo00[ooooo000^ooooo`03o`000?oooooooooo02Wooooo0ol00003oo0n00co0000
00GoY[d0o`000?m[[P3oJjh0o`000002ocNN00oo000000?o05i5o`000?l0ET/00ol0ET/01?l0003o
051>o`1@C_l0D4h2o`0000?o02lo00?o0000o`0]?_l0;Ch00ol0;Ch00ol0003o01ddo`0M=004o`0M
=003o`000?l05Roo01H_00?o01H_00?o0000o`0?:Ol000001?l05Rl00ol0003o018/o`0B;002o`0B
;0Co00000_l06c<00ol0003o01ddo`0M=003o`0M=005o`000?l08cSo02<ho`0S>?l000001?l0;Ch0
0ol0003o03e7o`0mA`02o`0mA`06o`000?l0DDgo055=o`1ACOl0003o05i50ol00003o`1T?`03o`00
0?l0M2Wo07@Y00?o00000ol0PA<2o`000003o`n@0?l0003oA:8000;o000000?oPK@0o`000?l00000
1?l00002omRA00?o000000Goieh0o`000?oWGP3oieh0o`00000Looooo`;o00002oooool002kooooo
00?o0000ooooooooool09_ooool3o`0000Col3h01_l00002omZ900;o000000Coc;40o`000?l0003o
Y[d02Ol00003o`R=0004o`000?l0PA?o084Co`0000;o07DW00Co0000o`1/=_l0K3Ko06`f0_l00003
o`1FB`05o`000?l0D4ko051>o`1@C_l000000_l0BTd00ol0003o02loo`000005o`0]?P;o00001Ol0
7C@2o`0000Go01H_0_l00006o`0F;`06o`000?l04Rco018/o`000?l07CCo00001Ol06c<00ol0003o
01ddo`0M=002o`0M=003o`000?l08cSo02<h00;o02<h00?o0000o`0]?_l0;Ch00_l0;Ch00ol0003o
03e7o`0mA`02o`0mA`05o`000?l0DDgo055=o`1ACOl000000ol0GTD3o`000003o`1T?ol0003o07@Y
00?o07@Y0_l000000ol0PA?o0000oaJB0003o`0000;oA:8000?o0000oh6d0?n1]0000_l000000oo6
`@3o0000o`000004omRA00Co000000?oieh0o`000?ooool06oooool00ol0003oooooooooo`09oooo
o`00;_ooool00ol0003oooooooooo`0Tooooo`;o00000ooc<@02o`000006oo0n0?l0003o0000o`00
0?oVH@3o00000ooJR@000ol0003oc;40olba0006o`0000;oFZT000Co0000obfK0?l]V`3o00000ol8
S@001?l0003o084Co`214ol00002o`1e9`05o`000?l0K3Ko06`fo`1/=_l000000_l0I3l00ol0003o
05I;o`000003o`1@CP03o`000?l0BTgo04Y=00;o04Y=00?o0000o`0]?_l0;Ch00ol0;Ch01?l0003o
02loo`0_?ol00003o`0M=004o`000?l08cSo02<ho`0000?o01H_00?o0000o`0O=_l000001_l05Rl0
0ol0003o018/o`000003o`0M=003o`000?l06c?o01/c00;o01/c00?o0000o`0M=?l07C@00_l07C@0
0ol0003o02<ho`0S>002o`0S>003o`000?l0;Cko02dn00;o02dn00?o0000o`0mAol0?DL00_l0?DL0
0ol0003o055=o`1AC@02o`1AC@04o`000?l0GTGo05i5o`0000;o06`f0ol00003o`1d:@03o`000?l0
Q@Wo000000;o00000_lFTP001?l0003oA:80odBR0?m4XP02o`0000;oPK@01_l000001OoHT@3o0000
onEU0?l0003oiFD000?o00007?ooool00ol0003oooooooooo`08ooooo`00;_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oc<@3olc4000?olc404?l00002ohnh0004o`000?mJZ@3oFZT0o`0000;o
;I/000Go0000o`R=0?l8S@3o28d0o`000002o`214`04o`000?l0MBOo07DWo`0000?o06`f00?o0000
o`1T?ol0I3l00_l0I3l3o`000003o`1@C_l0003o04Y=00Co04Y=0_l00003o`0]?P03o`000?l0;coo
02lo00;o02lo00?o0000o`0M=?l000001?l08cP00ol0003o01H_o`000003o`0O=P03o`000?l05Roo
01H_00?o01H_0_l00004o`0M=003o`000?l06c?o01/c00;o01/c00Co0000o`0M=?l07CCo01dd5_l0
0003o`1NA@03o`000?l0K3Ko06`f00;o06`f0_l00002o`1d:@04o`000?l0Q@Wo08D9o`0000?o5Y80
0ol000000om4XP3o0000o`000002o`0000;oaL801_l000001OoUI@3o0000onEU0?oUI@3o000001co
oooo00?o0000ooooooooool02?ooool002kooooo00?o0000ooooooooool08Oooool4o`000003oo<a
0?l0003o000000;o00000_o[D002o`0000?ohGH000Co0000omBL0?oDW03o00000_o6`@001?l0003o
SkP0ohnh0?l00002oeZY0004o`000?l]V`3o;I/0o`0000?o28d000Co0000o`214ol0PA?o00000_l0
MBL01Ol0003o06`fo`1/=_l0K3Ko000000Co06@o00Go0000o`1OA?l0GdCo05m4o`000005o`1:C@06
o`000?l0B4_o04Q;o`000?l0;Cko00001Ol0;cl2o`0000Go02<h0_l00005o`0O=P03o`000?l05Roo
000000;o000000?o02<ho`000?l07C@01?l07C@01?l0003o01/co`0K<ol06c<4o`0000;o02lo00?o
0000o`0f@ol0=T<00_l0=T<00ol0003o04=9o`13B@02o`13B@03o`000?l0DDgo055=00;o055=00Co
0000o`1KAol0FdOo05]70ol00002o`1NA@06o`000?l0K3Ko06`fo`1/=_l0003o07/M0ol00003o`25
2@?o000000?o5Y80o`000?m<Y@000ol000000on4]03o0000o`000004olG200;o000000?oeYH0o`00
0?l000000_l000000ooUI@3o0000ooooo`0Kooooo`03o`000?oooooooooo00Oooooo000]ooooo`;o
00008?ooool3o`0000;omRH01_l00002on]@0004o`000?oQMP3ohGH0on5f00;o00000_oDW0001?l0
003oa/40olK10?l00002ohnh01?o000000?o06`fo`000?l0I3l00ol0I3l00ol0003o05m4o`1OA002
o`1OA0;o00000ol0BTd01?l0003o04Q;o`18Bol0B4/2o`0000Go02lo00?o0000o`0f@ol000001?l0
8cP00ol0003o02dno`000005o`0O=P;o00001Ol08cP00ol0003o01ddo`0M=002o`0M=006o`000?l0
6c?o0000o`000?l0;Cko00001Ol0;cl00ol0003o03I3o`0f@`02o`0f@`03o`000?l0@dWo04=900;o
04=900?o0000o`1ACOl0DDd00_l0DDd01_l0003o05]7o`1KAol0FdOo0000o`1X>`?o00001?l0K3H0
1?l0003o07/Mo`1k7Ol0Nad2o`000004o`252Ol0003o8YL0ob:G00?o00000om<Y@02o`000003ohBd
0?l0003o000000;oaL8000?o0000omJH0?l000000ol000001?oTJP3o0000o`000?l0000Jooooo`?o
00002?ooool002gooooo00?o0000omR@0?l000007Oooool3o`000003ooHV0?l0003o000000?o0000
1?o`?`04o`000003on5f0?l0003oe9`000;oe9`02?l000001On4]03o0000oeBW0?mDY`3o000000?o
;I/000Co0000o`f?0?l=S`3o00000ol0Q0/00ol0003o07/Mo`1k7@02o`0000?o06@o00?o0000o`1O
A?l0Gd@00_l0Gd@01_l0003o05]7o`1KAol0003o04Y=o`0000?o04Q;00Co0000o`1:COl0BTgo0000
0ol0;cl01Ol0003o03I3o`0f@ol0=T?o000000;o02<h00Go0000o`0]?_l0;Cko02dno`000002o`0O
=P;o000000?o02dno`000?l08cP01?l08cP00ol0003o01ddo`0M=002o`0M=0;o00001?l0;Ch00ol0
003o02loo`0_?`02o`0_?`03o`000?l0=T?o03I300;o03I300?o0000o`13BOl0@dT00_l0@dT00ol0
003o055=o`1AC@02o`1AC@03o`000?l0FdOo05]700;o05]700Co0000o`1X>ol0J3_o06Pk0_l00002
o`1/=P06o`000?l0Nago07/Mo`1k7Ol0003o1X`00ol00004ob:G00;o000000?oC:D0o`000?n=]`00
1Ol000001?o5`P3o0000omJH0?oFV003o`0000?oi6X000?o0000ooooooooool05?ooool3o`0000;o
oooo00?o0000ooooooooool01_ooool002gooooo0_l000000ooHT03o0000ooooo`0Hooooo`?o0000
0_oh7@03o`000003ooHV0?l0003ol3l000Col3l000Co0000onMP0?oWH03oif002?l00002ok[20005
o`000?n4]03oQ;@0ohBd0?l000000_mDY`001Ol0003o;I/0obfK0?l]V`3o000000;o3Hl000Go0000
o`242ol0Q0_o08@;o`000003o`1k7@05o`000?l0M2Wo0000o`1T?ol000001?l0Gd@00ol0003o05]7
o`1KA`02o`1KA`05o`000?l0B4_o04Q;o`18Bol000001?l0BTd00ol0003o02loo`000004o`0f@`03
o`000?l08cSo000000Co02dn00?o0000o`0O=_l000001?l0;Ch00ol0003o02<ho`0S>002o`0S>003
o`000?l07CCo000000;o000000?o02loo`000?l0;Ch00ol0;Ch00ol0003o02loo`0_?`03o`0_?`05
o`000?l0=T?o03I3o`0f@ol000001?l0@dT00ol0003o055=o`1AC@02o`1AC@03o`000?l0FdOo05]7
00;o05]700Ko0000o`1X>ol0J3_o06Pko`000?l0MBL3o`0000Co07/M00Co0000o`J<0?l6S03o0000
1?lRU`000ol0003oFZT0o`000002o`0000;oSKL00_l000000oo6`@3o0000o`000004omJH00Co0000
00?oi6X0o`000?ooool04Oooool3o`0000Gooooo00?o0000ooooooooool01_ooool002gooooo0_l0
0002omR@00;o00005?ooool3o`0000;on1d00ol00002ooPM00?o00000oo`?`02o`0000;oif000_l0
0003omb50004o`000?o?Z@3ocjT0o`0000;o^/8000Go0000ohBd0?n4]03oQ;@0o`000002oeBW0005
o`000?l]V`3o;I/0obfK0?l000000_l=S`001Ol0003o08@;o`242ol0Q0_o000000?o07/M00Co0000
o`1d:Ol0M2Wo07@Y0_l00003o`1OA003o`000?l0FdOo05]700;o05]700Go0000o`1JB?l0003o04Q;
o`000006o`1:C@03o`000?l0=T?o03I300?o03I30_l00006o`0]?P03o`000?l0;Cko02dn00?o02dn
00?o0000o`0S>?l08cP00_l08cP2o`0000Go02lo00?o0000o`0]?_l0;Ch00_l0;Ch00ol0003o02lo
o`0_?`02o`0_?`03o`000?l0=T?o03I300_o000000?o055=o`000?l0FdL00_l0FdL00ol0003o06Pk
o`1X>`02o`1X>`04o`000?l0MBOo07DWo`1e9`;o00000_l0Nad01?l0003o1X`0o`J<0?l6S002o`00
00?o8YL000Co0000oeZY0?mJZ@3o00001?n=]`02o`000009olK10?l0003o0000o`000?oFV03o0000
onA[0?l0003oi6/000?o00003Oooool4o`0000Sooooo00?o0000ooooooooool01_ooool000;ooooo
0ol00003ooooo`;o00001?ooool3o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo
0_l00003ooooo`?o00001Oooool2o`0000;of90000?o0000onIS0?l000000_l0000<ooooo`Go0000
0_oi6P03o`0000?on1d00_l00003oo@_0003o`000?o`?`3o000000?oif0000?o0000omb50?oLQ@00
0_oLQ@001?l0003ocjT0olnY0?l00002ok[20005o`000?n4]03oQ;@0ohBd0?l000000_mDY`001Ol0
003o;I/0obfK0?l]V`3o000000;o3Hl000Go0000o`242ol0Q0_o08@;o`000003o`1k7@05o`000?l0
M2Wo07@Yo`1d:Ol000000_l0Kc400ol0003o05m4o`000004o`1KA`05o`000?l0FTSo05Y8o`1JB?l0
00001_l0BTd2o`0000Co03I300?o0000o`13BOl000001Ol0;Ch2o`0000Go02dn00?o0000o`0S>?l0
00000_l000000ol0=T?o0000o`0_?`04o`0_?`03o`000?l0;Cko02dn00;o02dn00Co0000o`0_?ol0
;coo02lo1?l00002o`1@CP03o`000?l0ET_o05I;00;o05I;00Co0000o`1NAOl0GTGo05i51Ol00000
0ol0FdOo0000o`1X>`02o`1X>`06o`000?l0MBOo07DWo`1e9ol0003o08@;0ol00003o`J<0006o`00
0?ldW@3o0000o`000?lRU`3o00000omJZ@02o`0000;oSKL000Co0000olRl0?l0003o00000_oFUP04
o`0000?oi6/000?o0000ooooooooool02?ooool3o`0000gooooo00?o0000ooooooooool01Oooool0
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_oHT0001?l0003o
iV<0onIS0?oVH`0<o`0000;onAd000?o0000ooTJ0?l000000_l00002ooTJ0004o`000?oh7@3o0000
o`0000Gom2l02?l00002omb501Oo000000?o08@;o`000?l0Nad00_l0Nad01Ol0003o07@Yo`1d:Ol0
M2Wo000000Co06la0_l00003o`1KA`03o`000?l0FTSo05Y800;o05Y800?o0000o`1:COl0BTd00ol0
BTd01?l0003o051>o`1@C_l00002o`0f@`05o`000?l0@dWo04=9o`13BOl000000ol0;Ch01?l0003o
03e7o`0mAol00004o`0]?P;o00001Ol0=T<00ol0003o02loo`0_?`02o`0_?`04o`000?l0;Cko02dn
o`0]?PGo00000_l0BTd00ol0003o051>o`1@CP02o`1@CP03o`000?l0ET_o05I;00;o05I;00Go0000
o`1NAOl0GTGo05i5o`000003o`1X>`Ko00001?l0MBL01?l0003o08@;o`242ol0Q0/2o`0000;o1X`0
00?o0000ocBM0?ldW@000_l00003oeZY0006o`000?nK^P3o0000o`000?n=]`3o00000_o8_0000ol0
003oeYH0omJF0002omJF00Co000000?oi6/0o`000?ooool01Oooool3o`00013ooooo00?o0000oooo
ooooool01Oooool000Go00000_ooool01Ol0003oooooooooool0003ooooo00Go00001oooool01Ol0
003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003of900omR@0?l00003onIS0005o`000?o_@@3okd40
onm10?l000001?of:@001?l0003onAd0ooTM0?oi7@03o`0000GonAX00ol00004oo@_00;o00000oo]
BP000ol0003oi6/0onA[0002onA[00Co00000oo=[`001Ol0003o]L40okG10?ne`@3o000000;oQ;@0
00Go0000oeZY0?mJZ@3oFZT0o`000003ocNN0003o`000?lKU03o6i@000?o000000?o07/Mo`000?l0
M2T00_l0M2T00ol0003o06lao`1_<@02o`1_<@06o`000?l0K3Ko06`fo`000?l0FdOo00001?l0FTP0
0ol0003o05]7o`000003o`1:C@07o`000?l0D4ko051>o`1@C_l0003o03I3o`000005o`13B@03o`00
0?l0;Cko000000Co03e700Ko0000o`0]?_l0;Cko0000o`13BOl00006o`0f@`04o`000?l0;coo02lo
o`0_?`Co00000_l0B4/00ol0003o04Y=o`1:C@03o`1:C@05o`000?l0D4ko051>o`1@C_l000001?l0
ET/00ol0003o05i5o`1NA@02o`1NA@05o`000?l0J3_o06Pko`1X>ol000000ol0Lb/4o`0000;o07DW
00Go0000o`242ol0Q0_o0000oa^D0002o`000003o`J<0?l0003o=9d000;o=9d00ol000001?mJZ@3o
0000oi^j0?nK^P02o`0000?ob;`00ol000001OoFUP3o0000onAZ0?l0003oi6X000?o000000?ooooo
o`000?l000000_l0000Cooooo`03o`000?oooooooooo00Gooooo00001?l0003oooooooooool00003
ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`06ooooo`Co0000
0oooool01Ol0003oooooooooool0003ooooo00Co00001?ooool2o`000003ooooool0003of90000;o
f90000Go0000onIS0?oVH`3oiV<0o`000003onm10003o`000?of:@3omRT000;omRT00ol00003ooTM
0003o`000?oi6P3o000000;o00000oog8P02o`000003oo@_0?l0003okDX000?okDX000Co0000onA[
0?oTJ`3oi6/00_l00002omV>0005o`000?o=[`3ocJl0olf_0?l000000one`@001?l0003oQ;@0ohBd
0?l00003oeZY0005o`000?lgWP3o=ih0ocNN0?l000000_lKU0001?l0003o1X`0o`J<0?l6S003o`00
0003o`1d:Ol0003o06la00?o06la00?o0000o`1/=_l0K3H00_l0K3H00ol0003o05Y8o`1JB002o`1J
B007o`000?l0FdOo05]7o`1KAol0003o04Y=o`000005o`1@CP03o`000?l0@dWo04=900Co04=90_l0
0005o`0mA`03o`000?l0;Cko000000?o04=900?o0000o`0f@ol0=T<00ol0=T<01_l0003o02loo`00
0?l0003o04Y=o`0000Go04Q;00?o0000o`1:COl0BTd00_l0BTd00ol0003o051>o`1@CP02o`1@CP03
o`000?l0ET_o05I;00;o05I;00Go0000o`1NAOl0GTGo05i5o`000004o`1X>`05o`000?l0Lb_o07<[
o`1c:ol000000_l0PA<3o`0000?o08@;00?o0000oa^D0?lKU0000_l00003ocBM0003o`000?m][P3o
KJh000?o00000onK^P02o`000004olRl0?l0003of940omRA00?o000000Coi6X0o`000?oTJP3oi6X0
0_l0000Gooooo`03o`000?oooooooooo00Gooooo00001?oooooo0000ooooool00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`04ooooo`06
o`000?ooooooooooo`000?oooooo00001oooool01?l0003oooooooooooooool2o`000003omR@0?l0
003oiV<000;oiV<000?o0000onm10?o_@@000_o_@@001_l0003omRT0o`000?l0003omRT0o`0000?o
nAd01?l00006ooLR00Co00000_o]BP001Ol0003oi6/0onA[0?oTJ`3o000000?ofHh000Go0000olf_
0?o=[`3ocJl0o`000003okG10004o`000?n4]03oQ;@0o`0000?oFZT000Go0000ocNN0?lgWP3o=ih0
o`000002oa^D0003o`000?l6S03o1X`000;o1X`000?o0000o`252Ol0Q@T00_l00003o`1_<@03o`00
0?l0K3Ko06`f00;o06`f00?o0000o`1[=ol000000ol0FTP00ol0003o05]7o`1KA`02o`1KA`03o`00
0?l0D4ko051>00Co051>00?o0000o`13BOl0@dT00ol0@dT00ol0003o055=o`000005o`0mA`;o0000
1?l0@dT00ol0003o03I3o`0f@`03o`0f@`;o00001?l0BTd00ol0003o04Q;o`18B`02o`18B`03o`00
0?l0BTgo04Y=00;o04Y=00?o0000o`1@C_l0D4h00_l0D4h00ol0003o05I;o`1FB`02o`1FB`03o`00
0?l0GTGo05i500;o05i500Go0000o`1X>ol0J3_o06Pko`000004o`1c:`03o`000?l0PA?o084C00;o
084C0_l00002o`242`04o`000?lKU03o6i@0oa^D00;o00000_ldW@000ol0003oKJh0off^0002off^
00;o000000?oVkX0o`000?o;]0000ol00004omRA00?o00000_oTJP000ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Gooooo0002ooooo`;o00000oooool01?l0003oooooooooool00003oooo
o`;o00002Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01?ooool01_l0003ooooooooooooooooo0000onIS00;o00001?oVH`000ol0003okd40
onm10003o`0000;omRT01Ol00004ooTJ00;o000000Comb80o`000?l0003o00001?ob=P08o`000003
omV>0?l0003ocJl000;ocJl000Go0000okG10?ne`@3o]L40o`000002ohBd0005o`000?mJZ@3oFZT0
oeZY0?l000000olgWP001?l0003o6i@0oa^D0?l00004o`J<0009o`000?l0Q@Wo08D9o`252Ol0003o
084Co`000?l0Kc7o000000Co06`f00Oo0000o`1[=ol0JcOo06/go`000?l0FTSo000000Co05]70_l0
0005o`1@CP03o`000?l0ET_o000000?o04=900Go0000o`1ACOl0DDgo055=o`000003o`0mA`03o`00
0?l0DDgo000000Go04=900?o0000o`0f@ol0=T<00_l000000ol0D4ko0000o`1:C@03o`1:C@03o`00
0?l0B4_o04Q;00;o04Q;00?o0000o`1:COl0BTd00ol0BTd00ol0003o051>o`1@CP0<o`0000Co06Pk
00Go0000o`1c:ol0Lb_o07<[o`000004o`214`03o`000?l=S`3o000000;o00000olKU0000ol0003o
C:D0o`000002o`0000CoKJh000?o0000ojno0?l000000_l00002ol^d00;o00000ooHT@000ol0003o
iFD0o`000003o`0001Oooooo00?o0000ooooooooool01Oooool000?ooooo00?o0000ooooooooool0
0_ooool2o`0000Gooooo00?o0000ooooooooool02?ooool2o`0000Cooooo0_l00004ooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oVH`3oiV<000Oo000000?okd40o`000?l00000
0_l00003ooTK0003o`000?oi6P3onAX000ConAX00ol00004oo8f00;o00000oo[D@001?l0003ohW40
on9a0?oRL@0Co`000005ocNN0?l0003o6i@0oa^D0?l000001?l6S0001Ol0003o08D9o`252Ol0Q@Wo
000000?o084C0_l00003o`1/=P03o`000?l0JcOo06/g00?o06/g00?o0000o`1KAol0FdL00_l0FdL0
1?l0003o05m4o`1OA?l00003o`1@CP07o`000?l0ET_o05I;o`1FBol0003o04=9o`000004o`1AC@04
o`000?l0?DOo03e7o`0000?o055=00?o0000o`13BOl0@dT00_l0@dT00ol0003o03I3o`000004o`1@
CP03o`000?l0BTgo04Y=00;o04Y=00?o0000o`18Bol0B4/00_l0B4/00ol0003o04Y=o`1:C@05o`00
00;o05m400?o0000o`1T?ol0I3l00_l0I3l01?l0003o06`fo`1/=_l0K3H6o`0000Co07<[00?o0000
o`214ol0PA<00_l0PA<01?l0003o3Hl0o`f?0?l=S`02o`0000;o6i@000Co0000odbU0?m<Y@3oC:D0
0_l00003off^0004o`000?n__`3o[kl0o`0000Cobk@00ol000001?oHT@3o0000onEU0?l00002onEU
0003o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool002_ooooo0_l00004ooooo`03
o`000?oVH`3oiV<000So00000_of9`000ol0003onA/0ooTK0003ooTK0004o`000?oi6P3onAX0ooTJ
00;o00000oog9@02o`000003oo8f0?l0003oje4000?oje4000Go0000on9a0?oRL@3ohW40o`000003
omRA0003o`000?o=[`3ocJl000;ocJl000Co0000ok[20?nj`P3o00001?n?^0000ol0003oJjh0of^^
0005o`0000?o1X`000Go0000o`252Ol0Q@Wo08D9o`000004o`214`05o`000?l0OAWo0000o`1/=_l0
00001Ol0JcL2o`0000?o05]700?o0000o`1OA?l0Gd@00_l0Gd@00ol0003o051>o`000005o`1FB`03
o`000?l0DDgo055=00?o055=00?o0000o`0mAol000001?l0DDd00ol0003o04=9o`13B@02o`13B@;o
00001Ol0D4h00ol0003o04Y=o`1:C@02o`1:C@03o`000?l0B4_o04Q;00Go00000_l0FdL00ol0003o
05m4o`1OA003o`1OA005o`000?l0I3oo06@oo`1T?ol000001?l0K3H01?l0003o07DWo`1e9ol0MBL6
o`0000Co084C00Ko0000o`f?0?l=S`3o3Hl0o`000?lgWP03o`0000?oC:D000Ko0000ohNe0?l0003o
0000off^0?l00003ojno00;o00000_o;]0000ol0003ofXT0omZ90003o`000005onEU0?l0003oiFD0
onEU0?l000005_ooool00ol0003oooooooooo`04ooooo`00;?ooool00ol0003oooooooooo`03oooo
o`Co00000oo`?P000ol0003omRL0ooHW0003ooHW0003o`000?oi6`3onA/000?onA/000?o0000ooTJ
0?l000001_og9@04o`0000;oje4000Go0000on9a0?oRL@3ohW40o`000003omRA0003o`000?o=[`3o
cJl000;ocJl000Co0000ok[20?nj`P3o00001?n?^0001?l0003oJjh0of^^0?l00003odbU0005o`00
0?ldW@3o0000o`J<0?l000000ol0Q@T00ol0003o084Co`214`02o`214`05o`000?l0OAWo07dIo`1m
6Ol000001Ol0JcL01_l0003o06`fo`1/=_l0003o05]7o`0000Ko05m400?o0000o`1FBol0ET/00ol0
ET/2o`0000Ko055=00?o0000o`1ACOl0DDd00ol0DDd00ol0003o04=9o`13B@02o`000003o`1FBol0
003o051>00Co051>00?o0000o`1:COl0BTd00_l0BTd3o`0000;o05Y800?o0000o`1KAol0FdL00ol0
FdL00ol0003o05m4o`1OA002o`1OA003o`000?l0I3oo06@o00;o06@o00?o0000o`1/=_l0K3H00_l0
K3H01Ol0003o07DWo`1e9ol0MBOo000000?o084C0ol00002o`214`03o`000?l=S`3o3Hl000;o3Hl0
00Co0000ocNN0?lgWP3o00001?m<Y@000ol0003oQkD0ohNe0002o`0000?o[kl000Ko0000olnY0?l0
003o0000ol^d0?l00004omZ900Co000000?oiFD0o`000?ooool05?ooool00ol0003oooooooooo`04
ooooo`00:oooool01?l0003oooooooooooooool4o`0000?oiV<000Go0000oo0n0?o`?P3ol3h0o`00
0005ooHW0004o`000?oi6`3onA/0ooTK00Co00001?og9@02o`0000ColCT01?l000000ooRL@3o0000
omRA0002omRA0003o`000?o=[`3ocJl000;ocJl000Co0000ok[20?nj`P3o00001?n?^0001?l0003o
Jjh0of^^0?l00003odbU0004o`000?ldW@3o=9d0ocBM00?o000000?o08D9o`000?l0PA<00ol0PA<0
0ol0003o07dIo`1m6@02o`1m6@;o00000ol0JcL00ol0003o06`fo`1/=P02o`1/=P03o`000?l0GdCo
05m400Co05m40_l00004o`1FB`04o`000?l0GTGo05i5o`0000Co055=0_l00006o`1AC@;o00001?l0
ET/00ol0003o051>o`1@CP03o`1@CPCo000000?o05]7o`000?l0FTP00ol0FTP00ol0003o05]7o`1K
A`02o`1KA`03o`000?l0GdCo05m400;o05m400?o0000o`1T?ol0I3l00_l0I3l00ol0003o06`fo`1/
=P02o`1/=P03o`000?l0MBOo07DW00;o07DW00Ko0000o`214ol0PA?o084Co`000?l8S@04o`0000?o
3Hl000Co0000ocNN0?lgWP3o=ih00ol00002odbU0004o`000?n7]@3oQkD0ohNe00?o000000Co[kl0
o`000?o?Z@3ocjT00_l00004omZ90004o`000?oWGP3o0000onMN00?o00005?ooool00ol0003ooooo
ooooo`04ooooo`00:oooool4o`0000Cooooo1Ol00003oo0n0004o`000?of9`3omRL0ooHW00Go0000
1?oi6`02o`000003ooLU0?l0003olCT000ColCT000Co0000onYD0?oZE03ojU@02?l00002olf_0004
o`000?nj`P3o^/80o`0000CoSkP000Co0000of^^0?m[[P3o00000om<Y@001Ol0003o=9d0ocBM0?ld
W@3o000000?o8YL00_l00003o`214`03o`000?l0OAWo07dI00;o07dI00Ko0000o`1l6ol0O1_o0000
o`1[=ol00005o`1/=P03o`000?l0GdCo05m400?o05m400Co0000o`1T?ol0I3oo00000_l0ET/00ol0
003o05i5o`1NA@02o`1NA@04o`000?l0DDgo055=o`0000;o05]700?o0000o`1ACOl0DDd00_l0DDd2
o`0000Go05I;00?o0000o`1@C_l0D4h00_l0D4h2o`0000Go05]700Go0000o`1JB?l0FTSo05Y8o`00
0005o`1KA`03o`000?l0GdCo05m400;o05m400Go0000o`1T?ol0I3oo06@oo`000004o`1/=P03o`00
0?l0MBOo07DW00;o07DW00?o0000o`214ol0PA<00_l0PA<01?l0003o28d0o`R=0?l8S@02o`0000;o
3Hl000Go0000ocNN0?lgWP3o=ih0o`000002of^^00?o00000on7]@000ol0003oaL80olG20003o`00
00?ocjT00ol00002omZ90003o`000?oWGP3o000000;oieh000?o0000ooooooooool04_ooool00ol0
003oooooooooo`04ooooo`00:oooool2o`0000Kooooo00Co0000onm10?o_@@3okd402?l00004ooTK
0003o`000?oi6`3onA/000?onA/00ol00004oo4i0005o`000?oZE03ojU@0onYD0?l000001?oRL@00
1?l0003ofHh0omV>0?oISP07o`0000;oSkP000Co0000of^^0?m[[P3o00000om<Y@001Ol0003o=9d0
ocBM0?ldW@3o000000Co8YL000Go0000oaJB0?l0003o084Co`000004o`1m6@03o`000?l0O1_o07`K
00;o07`K00?o0000o`1/=_l0K3H00ol0K3H00ol0003o06lao`000003o`1OA007o`000?l0I3oo06@o
o`1T?ol0003o05I;o`000005o`1NA@03o`000?l0DDgo000000Co05]700Ko0000o`1ACOl0DDgo0000
o`1NAOl00005o`1FB`03o`000?l0D4ko000000;o000000?o05m4o`000?l0FdL01?l0FdL00ol0003o
05Y8o`1JB002o`1JB003o`000?l0FdOo05]700;o05]700?o0000o`1OA?l0Gd@01_l000000ol0I3oo
0000o`1/=P03o`1/=P05o`000?l0MBOo07DWo`1e9ol000001?l0PA<01_l0003o28d0o`R=0?l8S@3o
0000obfK00Co00000olgWP000ol0003oJjh0of^^0002of^^00;o00000_n7]@000ol0003oaL80olG2
0002olG200;o000000CocjT0o`000?oNOP3ogWh00ol000000ooWGP3o0000onMN0002onMN0003o`00
0?oooooooooo017ooooo00?o0000ooooooooool01?ooool002gooooo00?o0000ooooooooool01?oo
ool01Ol0003okd40onm10?o_@@3o000000ComRL000?o0000ooTK0?oi6`001?oi6`000ol0003onA/0
o`000002o`0000?omRH00_l000000ooa>@3o0000onYD0002onYD0003o`000?oRL@3ohW4000;ohW40
00Go0000omV>0?oISP3ofHh0o`000003olnY0004o`000?o6`@3oa/40olK100Oo000000?oC:D0o`00
0?ldW@000_ldW@000ol0003o8YL0ob:G0002ob:G0004o`000?lFTP3o5Y80oaJB00;o00000ol0OAT0
0ol0003o07`Ko`1l6`03o`1l6`;o00000ol0K3H01ol0003o06lao`1_<Ol0Kc7o0000o`1OA?l00000
1Ol0I3l00ol0003o05i5o`1NA@04o`1NA@;o00001Ol0FdL00ol0003o055=o`000003o`1NA@03o`00
0?l0ET_o05I;00;o05I;0_l00005o`1OA003o`000?l0FdOo05]700;o05]700?o0000o`1JB?l0FTP0
0_l0FTP01?l0003o05]7o`1KAol0FdL4o`0000;o06la00Co0000o`1d:Ol0M2Wo07@Y2_l000000ol0
MBOo0000o`214`02o`214`03o`000?l8S@3o28d000;o28d000Co0000obfK0?l]V`3o;I/00ol00002
ocNN0006o`000?m[[P3oJjh0of^^0?l0003oY[d00ol00004olG20003o`000?oDV`3o000000;o0000
1?oNOP04o`000003onMN0?l0003ooooo01;ooooo00?o0000ooooooooool01?ooool002kooooo00?o
0000ooooooooool01?ooool01Ol0003okd40onm10?o_@@3o000000ComRL000?o0000ooTK0?oi6`00
0ooi6`02o`0000OomRH01?l000000ooZE03o0000on9a0003on9a0005o`000?oISP3ofHh0omV>0?l0
00000oo?Z@001Ol0003oa/40olK10?o6`@3o000000CoY[d000?o0000ohNe0?n7]@000ol000000old
W@3o0000ob:G0003ob:G0003o`000?lFTP3o5Y8000;o5Y8000Go0000o`n@0?l0003o07dIo`000005
o`1l6`06o`000?l0OAWo07dIo`000?l0K3Ko00001Ol0Kc400ol0003o06@oo`1T?`04o`1T?`03o`00
0?l0GTGo05i500?o05i500?o0000o`1X>ol000001Ol0FdL2o`0000Go05i500Ko0000o`1FBol0ET_o
0000o`1T?ol00005o`1OA003o`000?l0FdOo05]700?o05]700?o0000o`1JB?l0FTP01Ol00002o`1/
=P03o`000?l0Kc7o06la00;o06la00Go0000o`1d:Ol0M2Wo07@Yo`000004o`1k7@04o`000?l0Q0_o
08@;o`242`Go000000?o084Co`000?l8S@000_l8S@001Ol0003o;I/0obfK0?l]V`3o000000;oFZT0
0ol00004of^^0004o`000?nV_@3oY[d0o`0000GoaL8000Co0000omBK0?oDV`3o00001?oNOP000ol0
003ojUD0onYE0004o`0001;ooooo00?o0000ooooooooool01?ooool002oooooo00?o0000oooooooo
ool00oooool00ol0003okd40onm10002onm10003o`000?of9`3omRL000;omRL000?o0000ooTK0?l0
00000_l00002ooTK0003o`000?of9P3omRH000;omRH00_l00003oo4i00Co00000_oRL@001Ol0003o
fHh0omV>0?oISP3o000000?ocjT000Go0000olK10?o6`@3oa/40o`000004ojJm0005o`000?n7]@3o
QkD0ohNe0?l000000_m][P02o`0000?o8YL000?o0000oaJB0?lFTP000_lFTP001Ol0003o3i00o`n@
0?l?T03o000000Go07`K00?o0000o`1m6Ol0OAT00_l0OAT00ol0003o06lao`1_<@03o`1_<@;o0000
1Ol0I3l00ol0003o06`fo`000003o`1NA@05o`000?l0J3_o06Pko`1X>ol000000ol0FdL00ol0003o
06Pko`000005o`1NA@03o`000?l0ET_o000000?o06@o00?o0000o`1OA?l0Gd@00_l0Gd@00ol0003o
05]7o`1KA`02o`1KA`Co00000_l0JcL00ol0003o06`fo`1/=P02o`1/=P03o`000?l0Kc7o06la00;o
06la00?o0000o`1d:Ol0M2T00_l0M2T00ol0003o07/Mo`1k7@02o`1k7@05o`000?l0Q0_o08@;o`24
2ol000000ol=S`03o`0000;o28d000?o0000obfK0?l]V`000_l]V`000ol0003oFZT0oeZY0002oeZY
00;o00000_m[[P001?l0003oY[d0ojJm0?nV_@03o`0000;oaL8000Co0000omBK0?oDV`3oe9/01?l0
00001ooNOP3o0000onYE0?oZE@3o0000onYE0?l000004oooool00ol0003oooooooooo`03ooooo`00
<?ooool2o`0000Cooooo00Go0000onm10?o_@@3okd40o`000003ooHW00Co00001Ooi6`001?l0003o
mRH0o`000?l00003oo4i00;o00001?o[D@04o`000003omV>0?l0003ocjT000;ocjT000Go0000olK1
0?o6`@3oa/40o`000004ojJm0005o`000?n7]@3oQkD0ohNe0?l000000om][P001Ol0003oFZT0o`00
0?lRU`3o000000Co5Y8000?o0000o`n@0?l?T0000_l?T002o`0000?o07`K00?o0000o`1m6Ol0OAT0
0ol0OAT00ol0003o06lao`1_<@02o`1_<@04o`000?l0M2Wo07@Yo`0000?o06@o00Oo0000o`1/=_l0
K3Ko06`fo`000?l0GTGo000000Co06Pk00Co0000o`1KAol0FdOo00000ol0J3/00ol0003o05i5o`1N
A@02o`1NA@;o00001?l0I3l00ol0003o05m4o`1OA003o`1OA0Co000000?o06`fo`000?l0JcL01?l0
JcL00ol0003o06`fo`1/=P02o`1/=P03o`000?l0Kc7o06la00;o06la00Go0000o`1d:Ol0M2Wo07@Y
o`000004o`1k7@03o`000?l0Q0_o08@;00;o08@;00Ko0000o`f?0?l=S`3o3Hl0o`000?l]V`04o`00
00?o;I/000?o0000oeZY0?mJZ@000_mJZ@000ol0003oSkP0o`000002o`0000?oY[d000?o0000olba
0?o</@000ol00003omBK0004o`000?oRL@3ohW40on9a00Ko000000?ojUD0o`000?ooool04Oooool0
0ol0003oooooooooo`03ooooo`00<_ooool00ol0003oooooooooo`02ooooo`Oo00001?oi6`000ol0
003onA/0ooTK0002ooTK00Co00000_oa>@000ol0003oje40on]A0003on]A0004o`000?oTJ`3oi6/0
onA[00So000000?oa/40o`000?nV_@000onV_@001Ol0003oQkD0ohNe0?n7]@3o000000?oKJh000Co
0000oeZY0?mJZ@3oFZT00_l00004oaJB0005o`000?l?T03o3i00o`n@0?l000000_l=S`000ol0003o
07`Ko`000005o`1m6@03o`000?l0PA?o000000;o06la00?o0000o`1d:Ol0M2T00_l0M2T00ol0003o
06@oo`000005o`1/=P03o`000?l0J3_o06Pk00?o06Pk00?o0000o`1KAol000001?l0J3/01ol0003o
05i5o`1NAOl0GTGo0000o`1/=_l000001Ol0I3l01?l0003o05m4o`1OA?l0Gd@2o`0000Go06`f00?o
0000o`1[=ol0JcL00_l0JcL00ol0003o06`fo`1/=P02o`1/=P03o`000?l0Kc7o06la00;o06la00?o
0000o`1d:Ol0M2T00_l0M2T00ol0003o07/Mo`1k7@02o`1k7@05o`000?l0Q0_o08@;o`242ol00000
1?l=S`001?l0003o;I/0obfK0?l]V`03o`0000;o;I/000?o0000oeZY0?mJZ@000_mJZ@001?l0003o
SkP0ohnh0?n?^003o`000003ojJm0?l0003oc;4000?oc;400ol000000ooDV`3o0000on9a0003on9a
0003o`000?o]BP3okDX000Co00004Oooool00ol0003oooooooooo`03ooooo`00<oooool01Ol0003o
oooooooooooooooo000000ComRT000?o0000ooTK0?oi6`001?oi6`001?l0003onA/0o`000?l00004
ooLU00?o00001?o[D@001Ol0003oi6/0onA[0?oTJ`3o000000Cog8D000Co0000omBL0?oDW03oe9`0
0ol00002ojJm0005o`000?n7]@3oQkD0ohNe0?l000000om][P000ol0003oFZT0oeZY0002oeZY0006
o`000?m<Y@3o0000o`000?lFTP3o00000ol?T0000ol0003o3Hl0o`f?0002o`f?0003o`000?l0OAWo
07dI00?o07dI00Ko0000o`214ol0PA?o0000o`1_<Ol00006o`1d:@03o`000?l0K3Ko06`f00?o06`f
0_l00006o`1X>`03o`000?l0J3_o06Pk00?o06Pk00Co0000o`1NAOl0GTGo00000_l0K3H00ol0003o
06@oo`1T?`03o`1T?`06o`000?l0GdCo05m4o`000?l0Kc7o00001Ol0K3H00ol0003o06/go`1[=`02
o`1[=`03o`000?l0K3Ko06`f00;o06`f00?o0000o`1_<Ol0Kc400_l0Kc400ol0003o07@Yo`1d:@02
o`1d:@03o`000?l0Nago07/M00;o07/M00?o0000o`242ol0Q0/00_l0Q0/01Ol0003o3Hl0o`f?0?l=
S`3o000000?o;I/000?o0000oeBW0?mDY`000ol00004oeZY0005o`000?n?^03oSkP0ohnh0?l00000
0_o6`@03o`0000?oc;4000?o0000omZ90?oJR@000ol00004on9a0006o`000?o]BP3okDX0o`000?o]
BP3o00004Oooool00ol0003oooooooooo`03ooooo`00=?ooool01Ol0003ooooooooooooooooo0000
00ComRT000?o0000ooTK0?oi6`000ooi6`03o`0000?ombD00_l00003oo8f00;o000000?oje40o`00
0?oTJ`000_oTJ`000ol0003og8D0omb50002omb50005o`000?oDW03oe9`0omBL0?l000000oo</@04
o`000003ohNe0?l0003oKJh000;oKJh000?o0000oeZY0?mJZ@000_mJZ@000ol0003oC:D0odbU0002
odbU0005o`000?l?T03o3i00o`n@0?l000001Ol=S`02o`0000?o07dI00?o0000o`214ol0PA<00_l0
PA<00ol0003o07@Yo`1d:@04o`1d:@;o00001?l0K3H01?l0003o07DWo`1e9ol00005o`1X>`03o`00
0?l0J3_o06Pk00Co06Pk0_l00004o`1/=P03o`000?l0I3oo06@o00;o06@o00?o0000o`1OA?l00000
0ol0Kc400ol0003o06`fo`1/=P03o`1/=P03o`000?l0JcOo06/g00;o06/g00?o0000o`1/=_l0K3H0
0_l0K3H00ol0003o06lao`1_<@0Ao`0000Co3Hl000Go0000obfK0?l]V`3o;I/0o`000004oeBW00Go
00001?n?^0000ol0003oa/40olK10002olK100;o00000_o</@000ol0003ofXT0omZ90002omZ900Co
000000OohW40o`000?o]BP3okDX0o`000?o]BP3o0000013ooooo00?o0000ooooooooool00oooool0
03Gooooo0_l00002ooooo`03o`000?of:@3omRT000;omRT000?o0000ooTK0?l000000_l00003ooTJ
0003o`000?og9@3o000000KolSH01?l000000ooTJ`3o0000omb50003omb50005o`000?oDW03oe9`0
omBL0?l000001?o</@001?l0003oaL80olG20?o5`P03o`000003off^0?l0003oFZT000?oFZT000?o
0000odbU0?m<Y@000om<Y@02o`000003o`n@0?l0003o3Hl000Co3Hl000Ko0000o`n@0?l?T03o0000
o`1m6Ol00005o`214`03o`000?l0M2Wo07@Y00?o07@Y00Co0000o`1k7Ol0Nago00000_l0K3H01Ol0
003o07DWo`1e9ol0MBOo000000Co06Pk00?o0000o`1c:ol000001Ol0J3/00ol0003o06`fo`1/=P03
o`1/=P03o`000?l0I3oo06@o00;o06@o0_l00004o`1_<@03o`000?l0K3Ko06`f00?o06`f00Co0000
o`1[=ol0JcOo06/g2Ol00002o`214`03o`000?l0Q@Wo08D900;o08D900?o0000o`J<0?l6S0000_l6
S0001?l0003o6i@0oa^D0?lKU006o`0000?o;I/000?o0000oeBW0?mDY`000_mDY`001?l0003oQ;@0
ohBd0?n4]004o`0000;oSkP000Ko0000olK10?o6`@3oa/40o`000?oDW003o`0000CofXT000Co0000
onIQ0?oVH@3oiV401ol0000@ooooo`03o`000?oooooooooo00?ooooo000gooooo`03o`000?oooooo
oooo00Ko00001_oi6P03o`0000ColSH00_l00003one:00Co00000_oLQ@001Ol0003oe9`0omBL0?oD
W03o000000Coc;4000Go0000olG20?o5`P3oaL80o`000003ojno00;o00001?mJZ@000ol0003oC:D0
odbU0002odbU0004o`000?m4XP3oA:80o`0000Go3Hl000?o0000o`n@0?l?T0000_l?T0000ol0003o
084Co`214`03o`214`03o`000?l0Q@Wo000000?o07@Y00Oo0000o`1k7Ol0Nago07/Mo`000?l0K3Ko
000000Go07DW00Co0000o`1X>ol0J3_o00000_l0Lb/00ol0003o06Pko`1X>`02o`1X>`;o00001Ol0
K3H00ol0003o06@oo`1T?`02o`000003o`1d:Ol0003o06la00Co06la00?o0000o`1/=_l0K3H00_l0
K3H01_l0003o06/go`000?l0003o07`Ko`0000Co07dI00?o0000o`214ol0PA<00_l0PA<00ol0003o
08D9o`252@02o`252@03o`000?l6S03o1X`000;o1X`000?o0000oa^D0?lKU0000_lKU0001?l0003o
=ih0ocNN0?lgWP03o`0000;o;I/000?o0000oeBW0?mDY`000_mDY`001Ol0003oQ;@0ohBd0?n4]03o
000000;o^/800ol00004olK10004o`000?oDW03oe9`0omBL00?o00000_oJR@000ol0003oiV40onIQ
0002onIQ0003o`000?o`?P3ol3h000?o00003oooool00ol0003oooooooooo`03ooooo`00>?ooool0
1?l0003oooooooooool00004ooTM0004o`000?oi6P3onAX0ooTJ00;o00000oog8P02o`000003oo8f
0?l0003okDX000?okDX000?o0000onMP0?oWH0000_oWH004o`000003omBL0?l0003oc;4000?oc;40
00Go0000olG20?o5`P3oaL80o`000004ojno0006o`000?nK^P3o0000o`000?mJZ@3o00001?m<Y@00
1?l0003oA:80odBR0?m4XP02o`0000?o3Hl000?o0000o`n@0?l?T0000ol?T0000ol0003o084Co`21
4`02o`214`07o`000?l0Q@Wo08D9o`252Ol0003o07@Yo`000005o`1k7@03o`000?l0MBOo07DW00Co
07DW00?o0000o`1X>ol000001?l0Lb/01?l0003o06Pko`1X>ol00002o`1e9`03o`000?l0K3Ko06`f
00?o06`f0_l00004o`1d:@03o`000?l0Kc7o06la00;o06la00?o0000o`1/=_l0K3H00_l0K3H2o`00
00Co07`K00?o0000o`1m6Ol0OAT00_l0OAT00ol0003o084Co`214`02o`214`03o`000?l0Q@Wo08D9
00;o08D900?o0000o`J<0?l6S0000_l6S0001Ol0003o6i@0oa^D0?lKU03o000000Co=ih000?o0000
oeZY0?l000000_l00004oeBW0003o`000?n4]03oQ;@000;oQ;@000?o0000ok[20?nj`P000_nj`P02
o`0000;oa/4000Go0000omBL0?oDW03oe9`0o`000002on5f00?o00001OoVH@000ol0003ol3h0oo0n
0002o`00013ooooo00?o0000ooooooooool00_ooool003Wooooo00Co0000oooooooooooo00001?oi
7@000ol0003onAX0o`000006ooLR00?o00000oo]BP000ol0003oif00onMP0002onMP0003o`000?oQ
MP3ohGH000;ohGH00ol00002olba0005o`000?o5`P3oaL80olG20?l000001?n__`000ol0003oVkX0
oi^j0002oi^j00;o00000om<Y@001Ol0003oA:80odBR0?m4XP3o000000;o@J4000?o0000o`f?0?l0
00001Ol?T0000ol0003o5Y80o`000003o`214`03o`000?l0Q@Wo08D900;o08D900?o0000o`1k7Ol0
Nad01?l0Nad00ol0003o07DWo`1e9`04o`1e9`;o00001Ol0Lb/00ol0003o06Pko`000003o`1e9`03
o`000?l0K3Ko06`f00;o06`f0_l00005o`1d:@03o`000?l0Kc7o06la00;o06la00?o0000o`1/=_l0
00000_l000000ol0OAWo0000o`1l6`03o`1l6`03o`000?l0OAWo07dI00;o07dI00?o0000o`214ol0
PA<00_l0PA<00ol0003o08D9o`252@02o`252@03o`000?l6S03o1X`000;o1X`000?o0000oa^D0?lK
U0000_lKU0001Ol0003o=ih0ocNN0?lgWP3o000000CoFZT01Ol00004ohBd0003o`000?nj`P3o^/80
00;o^/8000?o0000olnY0?l000000_l00004omBL0003o`000?oQMP3ohGH000;ohGH01?l000001ooV
H@3o0000oo0n0?o`?P3o0000oo0n0?l000003oooool00ol0003oooooooooo`02ooooo`00>_ooool2
o`000004ooooool0003onAd0ooTM00Co00001?og8P02o`0000?om2l000?o0000one:0?l000001?oW
H0000ol0003ohGH0on5f0002on5f0004o`000?oJR@3ofXT0omZ900Co000000?oaL80o`000?n__`00
0on__`000ol0003oVkX0oi^j0003oi^j0005o`000?n=]`3o0000odbU0?l000000om4XP000ol0003o
@J40od6Q0002od6Q0003o`000?l?T03o3i0000?o3i0000Oo0000oaJB0?lFTP3o5Y80o`000?l0PA?o
000000Co08D90_l00005o`1k7@03o`000?l0Q0_o000000Co07DW00?o0000o`214ol000001Ol0Lb/2
o`0000Go07DW00Ko0000o`1/=_l0K3Ko0000o`1k7Ol00005o`1d:@03o`000?l0Kc7o06la00;o06la
0_l00004o`1m6@03o`000?l0O1_o07`K00?o07`K00Go0000o`1m6Ol0OAWo07dIo`000004o`214`03
o`000?l0Q@Wo08D900;o08D900?o0000o`J<0?l6S0000_l6S0000ol0003o6i@0oa^D0002oa^D0003
o`000?lgWP3o=ih000;o=ih000Go0000oeZY0?mJZ@3oFZT0o`000003ohBd00?o00000_n4]0000ol0
003o^/80ok[20003ok[20004o`000?o?Z@3ocjT0olnY00?o00000_oDW0001Ol0003ohGH0on5f0?oQ
MP3o000000?oje001ol0000?ooooo`03o`000?oooooooooo00;ooooo000looooo`04o`000?oooooo
0000o`0000ConAX00_l000000oog8P3o0000oo@_0004oo@_00Co00000_oWH0000ol0003ohGH0on5f
0002on5f0003o`000?oJR@3ofXT000;ofXT000Co0000omBK0?oDV`3oe9/00_l00003ojno0003o`00
0?nK^P3oVkX000?oVkX000Co0000ohfg0?n=]`3oSKL00_l00003odBR0003o`000?m1X@3o@J4000;o
@J400_l00003o`n@0003o`000?lFTP3o5Y8000?o5Y8000?o0000o`252Ol0Q@T00_l0Q@T01?l0003o
1X`0o`J<0?l00003o`1k7@05o`000?l0Q0_o08@;o`242ol000000_l0MBL01Ol0003o084Co`214ol0
PA?o000000?o07<[00?o0000o`214ol000001Ol0MBL00ol0003o06`fo`000003o`1k7@03o`000?l0
M2Wo07@Y00?o07@Y1?l000000ol0PA?o0000o`1m6@04o`1m6@03o`000?l0O1_o07`K00;o07`K00?o
0000o`1m6Ol0OAT00_l0OAT00ol0003o084Co`214`02o`214`03o`000?l0Q@Wo08D900;o08D900?o
0000o`J<0?l6S0000_l6S0001Ol0003o6i@0oa^D0?lKU03o000000Co=ih000?o0000oeZY0?mJZ@00
0_mJZ@001_l0003oQ;@0ohBd0?n4]03o0000okG100Co00001?nj`P001Ol0003ocjT0olnY0?o?Z@3o
000000;og8D00ol00004on5f0003o`000?o[D03oje0000;oje0000Co0000oo<a0?oc<@3olc400_l0
000>ooooo`03o`000?oooooooooo00;ooooo000mooooo`03o`000?oooooo000000GonAX00ol00003
oo@_00;o00001?o`?`03o`0000?ohGH000?o0000omZ90?oJR@000_oJR@000ol0003oe9/0omBK0002
omBK0005o`000?o?Z@3o0000ojno0?l000001OnK^P000ol0003oSKL0ohfg0002ohfg0005o`000?n4
]03o0000odBR0?l000001?m1X@001_l0003oA:80odBR0?l0003o3i00o`0000Go5Y800_l00003o`25
2@03o`000?l6S03o1X`000;o1X`000?o0000o`1k7Ol000001?l0Q0/00ol0003o07DWo`000004o`21
4`04o`000?l0Lb_o07<[o`0000?o084C00?o0000o`1e9ol0MBL00_l0MBL2o`0000Co07/M00?o0000
o`1d:Ol0M2T00_l0M2T2o`0000Co084C00?o0000o`1m6Ol0OAT00ol0OAT00ol0003o07`Ko`1l6`02
o`1l6`03o`000?l0OAWo07dI01Go000000?o6i@0o`000?lgWP000_lgWP000ol0003oFZT0oeZY0002
oeZY0003o`000?n4]03oQ;@000;oQ;@000Co0000okG10?ne`@3o]L400ol00002ok[20003o`000?o?
Z@3ocjT000;ocjT000?o0000omb50?oLQ@000_oLQ@05o`0000Goje0000Co0000oo<a0?oc<@3olc40
0_l0000=ooooo`03o`000?oooooooooo00;ooooo000nooooo`04o`000?oooooo0000ooTJ00?o0000
0ooh7@000ol0003om2l0o`000005oo0o0007o`000?o[D03oje00on]@0?l0003ohGH0o`000004omZ9
0003o`000?oDV`3oe9/000;oe9/000Co0000olnY0?o?Z@3ocjT00_l00004oi^j0003o`000?n=]`3o
SKL000;oSKL000Go0000ohBd0?n4]03oQ;@0o`000004od6Q0003o`000?m4XP3oA:8000;oA:8000?o
0000oaJB0?lFTP000olFTP001_l0003o8YL0ob:G0?l0003o08D9o`0000Ko1X`000?o0000o`242ol0
Q0/01?l0Q0/00ol0003o084Co`214`03o`214`03o`000?l0Lb_o000000Co084C00Oo0000o`1e9ol0
MBOo07DWo`000?l0Q0_o000000Go07/M00Ko0000o`1d:Ol0M2Wo0000o`252Ol00005o`214`03o`00
0?l0OAWo07dI00;o07dI00?o0000o`1l6ol0O1/00_l0O1/3o`0000;o3i0000?o0000oaJB0?lFTP00
0_lFTP000ol0003o8YL0ob:G0002ob:G0003o`000?ldW@3o=9d000;o=9d000Co0000odbU0?m<Y@3o
C:D01Ol000000olgWP3o0000oeZY0002oeZY0003o`000?n4]03oQ;@000;oQ;@000Go0000okG10?ne
`@3o]L40o`000002olf_00Co00000oo?Z@000ol0003og8D0omb50002omb50004o`000?oWH03oif00
onMP00Go000000?oje00o`000?oc<@000_oc<@000ol0003olc40o`00000<ooooo`03o`000?oooooo
oooo00;ooooo000oooooo`Co00001Ooh7@03o`0000Col3l000?o0000on]@0?o[D0000_o[D004o`00
00;ofXT000?o0000omBK0?oDV`000_oDV`001Ol0003ocjT0olnY0?o?Z@3o000000;obk@00_l00000
0onK^P3o0000ohfg0003ohfg0003o`000?n4]03oQ;@000;oQ;@00_l00003od6Q0003o`000?m4XP3o
A:8000;oA:800_l00003oaJB0003o`000?lRU`3o8YL000;o8YL000?o0000o`J<0?l6S0001Ol6S000
0ol0003o08@;o`242`03o`242`;o00001_l0PA<00ol0003o084Co`214`03o`214`04o`000?l0MBOo
07DWo`0000?o08@;00?o0000o`1k7Ol0Nad00_l0Nad00ol0003o07@Yo`000003o`252@03o`000?l0
PA?o084C00;o084C00?o0000o`1m6Ol0OAT00ol0OAT4o`000003o`f?0?l0003o3i0000?o3i0000?o
0000oaJB0?lFTP000_lFTP000ol0003o8YL0ob:G0002ob:G0003o`000?ldW@3o=9d000;o=9d000Go
0000odbU0?m<Y@3oC:D0o`000003of^^00Go000000?oFZT0o`000?n4]0000on4]0001Ol0003o]L40
okG10?ne`@3o000000CocJl01Ol00005omb50005o`000?oWH03oif00onMP0?l000000oo`?`09o`00
00_ooooo00?o0000ooooooooool00_ooool0047ooooo00?o0000ooooool000000ooh7@001?l0003o
mRH0ooHV0?of9P02o`000003oo0o0?l0003oje0000?oje0000?o0000onIQ0?oVH@000_oVH@03o`00
00?oe9/000Go0000olnY0?o?Z@3ocjT0o`000005ol^d00;o00000on=]`000ol0003oQ;@0ohBd0002
ohBd0006o`000?n1]03oPK@0o`000?m1X@3o00001?m4XP001_l0003oC:D0odbU0?l0003o5Y80o`00
00Go8YL000?o0000o`J<0?l6S0001?l6S0000ol0003o6i@0o`000003o`242`04o`000?l=S`3o3Hl0
o`0000Co084C0_l00006o`214`;o00001?l0Q0/00ol0003o07/Mo`1k7@02o`1k7@;o00001?l0Q@T0
0ol0003o084Co`214`02o`214`03o`000?l0OAWo07dI00;o07dI0_l00004o`f?0003o`000?l?T03o
3i0000;o3i0000?o0000oaJB0?lFTP000_lFTP000ol0003o8YL0ob:G0002ob:G0003o`000?ldW@3o
=9d000;o=9d000?o0000odbU0?m<Y@000_m<Y@001Ol0003oJjh0of^^0?m[[P3o000000?oSkP01Ol0
00000on4]03o0000okG10002okG10003o`000?o=[`3ocJl000;ocJl000Co0000omV>0?oISP3ofHh0
1?l00002omb50003o`000?oWH03oif0000;oif0000?o0000oo0o0?o`?`000_o`?`000ol0003omRH0
ooHV0002ooHV00;o00003?ooool00ol0003oooooooooo`01ooooo`00@_ooool01Ol0003oooooo`00
0?oh7@3o000000GomRH00ol00003on]@0003o`000?oVH@3oiV4000?oiV4000Ko0000on9a0?oRL@3o
0000omBK0?l00003olnY0003o`000?o;]03obk@000?obk@000Ko0000olRl0?o8_03o0000ohfg0?l0
0004ohBd0003o`000?n1]03oPK@000;oPK@000?o0000odBR0?m4XP000_m4XP000ol0003oC:D0odbU
0002odbU0003o`000?lRU`3o8YL000?o8YL000?o0000ocBM0?l000001?l6S0001?l0003o6i@0oa^D
0?l00002o`242`05o`000?l=S`3o3Hl0o`f?0?l000000ol0PA<01?l0003o28d0o`R=0?l00005o`21
4`03o`000?l0Q0_o08@;00?o08@;00?o0000o`1k7Ol0Nad00_l000000ol6S03o0000o`252@04o`25
2@03o`000?l0PA?o084C00;o084C1?l000000ol?T03o0000o`f?0004o`f?0003o`000?l?T03o3i00
00;o3i0000?o0000oaJB0?lFTP000_lFTP000ol0003o8YL0ob:G0002ob:G0003o`000?ldW@3o=9d0
00;o=9d000Go0000odbU0?m<Y@3oC:D0o`000004of^^0005o`000?n?^03oSkP0ohnh0?l000000onj
`P04o`0000;o]L4000?o0000olf_0?o=[`000_o=[`001Ol0003ofHh0omV>0?oISP3o000000;oi6/0
0ol00005onMP0003o`000?o`?`3ol3l000;ol3l000?o0000ooHV0?of9P000_of9P02o`0000_ooooo
00?o0000ooooooooool00Oooool004?ooooo00Co0000ooooool0003o00000oof9P02o`0000?olc40
00?o0000on]@0?l000001OoVH@001?l0003ohW40on9a0?oRL@04o`000003olnY0?l0003obk@000Co
bk@000?o0000olRl0?o8_0000_o8_002o`0000?oQ;@000?o0000oh6d0?n1]0000_n1]002o`0000?o
A:8000?o0000odbU0?m<Y@000om<Y@000ol0003o8YL0ob:G0002ob:G0005o`000?ldW@3o=9d0ocBM
0?l000000_l6S0001ol0003o6i@0oa^D0?lKU03o0000o`242ol000001?l=S`001?l0003o084Co`21
4ol00003o`R=0003o`000?l0PA?o084C00;o084C0_l00006o`242`;o00001?l6S0000ol0003o08D9
o`252@02o`252@04o`000?l0PA?o084Co`214`;o00001Ol?T0000ol0003o3Hl0o`f?0002o`f?0003
o`000?l?T03o3i0000;o3i0000?o0000oaJB0?lFTP000_lFTP000ol0003o8YL0ob:G0002ob:G0003
o`000?ldW@3o=9d000;o=9d000?o0000odbU0?m<Y@000_m<Y@001Ol0003oJjh0of^^0?m[[P3o0000
00CoSkP000?o0000ok[20?nj`P000_nj`P000ol0003ocJl0o`000002o`0000CocJl000?o0000omV>
0?oISP000_oISP000ol0003oi6/0onA[0002onA[00Co000000?oif00o`000?o`?`000oo`?`001?l0
003omRH0ooHV0?of9P04o`0000[ooooo00?o0000ooooooooool00Oooool004Cooooo00Ko0000oooo
oooooooo0000ooHV0?l00005oo<a00?o00001?oVH@001Ol0003ohW40on9a0?oRL@3o000000CogWh0
0_l00004ol^d0003o`000?o8_03ob;`000;ob;`000Ko0000olK10?o6`@3o0000ohBd0?l00004oh6d
0006o`000?n4]03oQ;@0o`000?m4XP3o00001Om<Y@000ol0003oFZT0o`000003ob:G0007o`000?ld
W@3o=9d0ocBM0?l0003o1X`0o`000005oa^D0003o`000?l=S`3o3Hl000Co3Hl00_l00005o`R=0004
o`000?l0PA?o084Co`0000;o3Hl000?o0000o`242ol0Q0/00ol0Q0/00ol0003o1X`0o`J<0003o`J<
0003o`000?l0Q@Wo08D900;o08D900Ko0000o`214ol0003o0000oaJB0?l00005o`n@0003o`000?l=
S`3o3Hl000;o3Hl000?o0000o`n@0?l?T0000_l?T0000ol0003o5Y80oaJB0002oaJB0003o`000?lR
U`3o8YL000;o8YL000?o0000ocBM0?ldW@000_ldW@000ol0003oC:D0odbU0002odbU0003o`000?m[
[P3oJjh000;oJjh000Go0000ohnh0?n?^03oSkP0o`000005ok[20004o`000?o=[`3ocJl0olf_00Go
00001OoISP001Ol0003oi6/0onA[0?oTJ`3o000000?okDX02_l00002ooPM00;o00002_ooool00ol0
003oooooooooo`01ooooo`00AOooool2o`000003ooooool0003o000000Colc4000Co0000oo0n0?o`
?P3ol3h00_l000000ooVH@3o0000on9a0002on9a0003o`000?oNOP3ogWh000;ogWh000?o0000omZ9
0?oJR@000_l000000oo;]03o0000olRl0003olRl0003o`000?o6`@3oa/4000;oa/400_l00003oh6d
0003o`000?n4]03oQ;@000;oQ;@000?o0000odbU0?m<Y@000om<Y@001ol0003oFZT0oeZY0?mJZ@3o
0000ob:G0?l000001OldW@000ol0003o6i@0oa^D0004oa^D0003o`000?l=S`3o3Hl000Co3Hl000?o
0000o`R=0?l8S@001?l8S@000ol0003o084Co`000003o`f?0003o`000?l0Q0_o08@;00;o08@;0_l0
0005o`J<0003o`000?l0Q@Wo08D900;o08D90_l00004oaJB0003o`000?l?T03o3i0000?o3i0000?o
0000o`f?0?l=S`000_l=S`000ol0003o3i00o`n@000Ko`0000CoSkP000?o0000ok[20?nj`P000_nj
`P001Ol0003ocJl0olf_0?o=[`3o000000?of9401Ol000000ooISP3o0000onA[0003onA[0003o`00
0?o]BP3okDX000;okDX000?o0000oo@_0?od;`000_od;`000ol0003on1d0ooPM0003ooPM00;o0000
2Oooool00ol0003oooooooooo`01ooooo`00Aoooool00ol0003oooooooooo`02o`000003oo<a0?l0
003ol3h000Col3h01?l000000ooRL@3o0000omin0003omin0003o`000?oJR@3ofXT000?ofXT00_l0
0003olRl0003o`000?o6`@3oa/4000;oa/4000Ko0000olG20?o5`P3o0000oh6d0?l00005ohBd00;o
00000om<Y@000ol0003oFZT0oeZY0003oeZY0003o`000?ldW@3o=9d000?o=9d00_l00005oa^D0003
o`000?lgWP3o000000Co3Hl00_l00006o`R=00;o00001Ol=S`001?l0003o08@;o`242ol00002oa^D
0003o`000?l6S03o1X`000?o1X`01?l000000olRU`3o0000oaJB0003oaJB0003o`000?l?T03o3i00
00?o3i0000Co0000o`f?0?l=S`3o3Hl01?l00002odBR0003o`000?m<Y@3oC:D000;oC:D000?o0000
oeZY0?mJZ@000_mJZ@000ol0003oKJh0off^0002off^0003o`000?n7]@3oQkD000;oQkD000Co0000
ojJm0?nV_@3oY[d01_l00004ok[20003o`000?o=[`3ocJl000;ocJl000Go0000omRA0?oHT@3of940
o`000003on9a00Oo00001Oo]BP000ol0003om2l0oo@_0002oo@_0004o`000?oh7@3on1d0ooPM00Co
00002?ooool00ol0003oooooooooo`01ooooo`00B?ooool01?l0003oooooooooooooool2o`0000?o
l3h00_l00003one:00?o00000ooNOP000ol0003ofXT0omZ90003omZ90006o`000?oHT@3of940o`00
0?o8_03o00001?o6`@000ol0003oaL80olG20002olG20003o`000?n4]03oQ;@000?oQ;@000Ko0000
ohfg0?n=]`3o0000odbU0?l00006oeZY0003o`000?ldW@3o=9d000;o=9d000Co0000odbU0?m<Y@3o
00000olKU0001Ol0003o=ih0ocNN0?lgWP3o000000;o3Hl000Co0000obfK0?l]V`3o00001?l8S@00
0ol0003o;I/0o`000005o`f?0003o`000?l0Q0_o000000?o6i@000?o0000o`J<0?l6S0000ol6S000
0ol0003o8YL0ob:G0002ob:G0003o`000?lFTP3o5Y8000?o5Y8000?o0000o`n@0?l?T0000_l?T000
1_l0003o3Hl0o`000?l0003o@J40o`0000CoA:8000?o0000odbU0?m<Y@000_m<Y@000ol0003oFZT0
oeZY0003oeZY0003o`000?m][P3oKJh000;oKJh000Go0000ohNe0?n7]@3oQkD0o`000004ojJm0004
o`000?o6`@3oa/40olK100Go000000?o^/80o`000?o=[`000_o=[`000ol0003of940omRA0002omRA
0003o`000?oRL@3ohW4000;ohW4000Co0000on]A0?o[D@3oje401Ol000000oo]BP3o0000oo@_0002
oo@_00Go00000_oi6P02o`0000Sooooo00?o0000ooooooooool00Oooool004Wooooo00?o0000oooo
ooooool00_ooool00ol0003ol3h0o`000004one:0007o`000?oZE@3ojUD0onYE0?l0003ogWh0o`00
0005omZ90003o`000?oHT@3of94000;of9400_l00003olK10003o`000?o5`P3oaL8000?oaL800_l0
0003ohBd0003o`000?n=]`3oSKL000;oSKL000?o0000oeZY0?mJZ@001?mJZ@000ol0003oKJh0o`00
0002ocBM0003o`000?m<Y@3oC:D000;oC:D000?o0000oa^D0?l000001?lgWP000ol0003o3Hl0o`00
0004obfK0004o`000?l8S@3o28d0o`0000?o;I/000?o0000o`f?0?l=S`000_l=S`02o`0000Go6i@0
00Co0000o`J<0?l6S03o1X`00_l00005ob:G0003o`000?lFTP3o5Y8000;o5Y8000Co0000o`n@0?l?
T03o3i000ol00004od6Q0003o`000?m4XP3oA:8000;oA:8000?o0000odbU0?m<Y@000_m<Y@000ol0
003oFZT0oeZY0002oeZY0003o`000?m][P3oKJh000;oKJh000?o0000ohNe0?n7]@000_n7]@000ol0
003oY[d0ojJm0002ojJm0005o`000?o6`@3oa/40olK10?l000000oo?Z@06o`0000Gof94000?o0000
on9a0?oRL@000_oRL@001Ol0003oje40on]A0?o[D@3o000000?olSH01Ol00002ooLR0003o`000?oi
6P3onAX000?onAX00_l00008ooooo`7o00000Oooool1ooooo`00B_ooool2o`0000?ooooo0_l00003
one:0003o`000?oZE@3ojUD000?ojUD00_l00004omZ90003o`000?oHT@3of94000;of94000Ko0000
omJF0?oFUP3o0000olK10?l00005olG20006o`000?o6`@3oa/40o`000?n4]03o00001On=]`000ol0
003oFZT0oeZY0003oeZY0006o`000?m][P3oKJh0o`000?ldW@3o00001_m<Y@000ol0003o=ih0ocNN
0004ocNN0003o`000?l]V`3o;I/000?o;I/000?o0000o`R=0?l000001?l]V`001ol0003o3Hl0o`f?
0?l=S`3o0000ocNN0?l000001OlKU0001?l0003o1X`0o`J<0?l00002ocBM0003o`000?lRU`3o8YL0
00;o8YL000?o0000oaJB0?lFTP000_lFTP04o`0000;oA:8000?o0000od6Q0?m1X@000_m1X@000ol0
003oA:80odBR0002odBR0003o`000?m<Y@3oC:D000;oC:D000?o0000oeZY0?mJZ@000_mJZ@000ol0
003oKJh0off^0002off^0003o`000?n7]@3oQkD000;oQkD000?o0000ojJm0?nV_@000_nV_@000ol0
003oa/40olK10002olK10005o`000?o?Z@3ocjT0olnY0?l000000ooISP05o`000003omRA0?l0003o
hW4000?ohW4000?o0000on]A0?o[D@000_o[D@000ol0003olSH0oo8f0002oo8f0003o`000?og8P3o
mb8000?omb8000Co0000ooTJ0?oi6P3onAX01?l00007ooooo`7o00000Oooool1ooooo`00C?ooool0
0ol0003oooooooooo`02ooooo`03o`000?o]BP3o000000GojUD000?o0000onMN0?oWGP000_l00000
0ooJR@3o0000omRA0003omRA0003o`000?oFUP3oeYH000;oeYH000?o0000olG20?o5`P000oo5`P00
0ol0003oa/40olK10002olK10003o`000?n=]`3oSKL000?oSKL000?o0000oi^j0?l000000omJZ@00
0ol0003oKJh0off^0002off^0003o`000?m<Y@3oC:D000GoC:D000?o0000ocNN0?lgWP000olgWP02
o`0000Ko;I/000?o0000obfK0?l]V`000ol]V`001?l0003o3Hl0o`f?0?l00003ocNN0003o`000?lK
U03o6i@000;o6i@000?o0000o`J<0?l000000oldW@000ol0003o8YL0ob:G0002ob:G0003o`000?lF
TP3o5Y8000;o000000?oC:D0o`000?m4XP000om4XP000ol0003o@J40od6Q0003od6Q0005o`000?m4
XP3oA:80odBR0?l000001?m<Y@000ol0003oFZT0oeZY0003oeZY0003o`000?m][P3oKJh000;oKJh0
00Go0000ohNe0?n7]@3oQkD0o`000004ojJm0003o`000?o6`@3oa/4000;oa/4000?o0000olnY0?o?
Z@000_o?Z@001Ol0003ofHh0omV>0?oISP3o000000?ohW401ol00005on]A0003o`000?ob=P3olSH0
00;olSH000Co0000ooLR0?og8P3omb801Ol00002ooTM0003o`000?oi7@3o000000Gooooo0_l00002
ooooo`00COooool00ol0003oooooooooo`02ooooo`;o00001?oZE@000ol0003oieh0onMN0003onMN
00;o00000ooHT@000ol0003oeYH0omJF0003omJF00;o00000oo5`P000ol0003oa/40olK10003olK1
0003o`000?n=]`3oSKL000;oSKL000Oo0000oi^j0?nK^P3oVkX0o`000?mJZ@3o000000GoKJh000?o
0000odbU0?m<Y@001?m<Y@000ol0003oJjh0o`000003ocNN0004o`000?mJZ@3oFZT0o`0000Co;I/0
0_l00006obfK00;o00001?lgWP000ol0003o6i@0oa^D0002oa^D00;o00001OldW@000ol0003o8YL0
ob:G0002ob:G00;o00000om<Y@000ol0003oA:80odBR0003odBR0003o`000?m1X@3o@J4000;o@J40
00?o0000odBR0?m4XP000_m4XP000ol0003oC:D0odbU0002odbU0003o`000?mJZ@3oFZT000_o0000
00?oQkD0o`000?nV_@000onV_@001Ol0003oa/40olK10?o6`@3o000000CocjT000?o0000omV>0?oI
SP000_oISP000ol0003ohW40on9a0002on9a0004o`000?oZE03ojU@0onYD00oo00000_oi6P000ol0
003onAd0ooTM0003ooTM00?o00000oooool3o`0000;ooooo001>ooooo`03o`000?oooooooooo00?o
oooo0_l000000ooZE@3o0000onMN0004onMN0006o`000?oUI@3oiFD0o`000?oHT@3o00001OoFUP00
1_l0003oeYP0omJH0?l0003oaL80o`0000Goa/4000?o0000olRl0?l000000_n=]`000ol0003oVkX0
oi^j0003oi^j0003o`000?m][P3oKJh000?oKJh000?o0000ohNe0?l000001?m<Y@001?l0003oJjh0
of^^0?l00002ocNN0005o`000?mJZ@3oFZT0oeZY0?l000000ol]V`001?l0003oE:L0oeBW0?l00005
obfK0003o`000?lgWP3o=ih000?o=ih000?o0000oa^D0?lKU0000_l000000om<Y@3o0000ocBM0004
ocBM0004o`000?lRU`3o8YL0ob:G00;o00001Om<Y@000ol0003oA:80odBR0002odBR0003o`000?m1
X@3o@J4000;o@J4000?o0000odBR0?m4XP002_l00002oi^j0003o`000?n__`3o[kl000;o[kl000Co
0000olG20?o5`P3oaL802_l000000oo6`@3o0000olnY0002olnY0003o`000?oISP3ofHh000?ofHh0
00?o0000on9a0?oRL@000_oRL@001Ol0003ojU@0onYD0?oZE03o000000GolCT000?o0000ooLU0?og
9@000_og9@000ol0003onAX0ooTJ0003ooTJ0003o`000?oi7@3onAd000Wo000000?oooooo`000?oo
ool00Oooool004oooooo0_l00005ooooo`03o`000?oWGP3oieh000?oieh000?o0000onEU0?oUI@00
0_oUI@000ol0003oeYH0omJF0003omJF0003o`000?oFV03oeYP000;oeYP000?o0000olK10?o6`@00
0oo6`@001_l0003ob;`0olRl0?l0003oSKL0o`0000GoVkX00_l00004off^0005o`000?n7]@3oQkD0
ohNe0?l000000_m<Y@001ol0003oJjh0of^^0?m[[P3o0000ocNN0?l000001?mJZ@001?l0003o;I/0
obfK0?l00003oeBW0003o`000?l]V`3o;I/000;o;I/00_l00006ocNN00;o00001?m<Y@000ol0003o
=9d0ocBM0002ocBM0006o`000?lRU`3o0000o`000?mJZ@3o00001Om<Y@000ol0003oA:80odBR0002
odBR0003o`000?m1X@3o@J4000;o@J400ol00002ohBd0003o`000?n=]`3oSKL000;oSKL000?o0000
oi^j0?nK^P000onK^P001Ol0003o[kl0ojno0?n__`3o000000CoaL8000?o0000olba0?o</@000_o<
/@001?l0003oe9`0omBL0?oDW005o`000003olnY0?l0003ofHh000?ofHh000?o0000on9a0?oRL@00
0_oRL@000ol0003ojU@0onYD0002onYD0003o`000?oa>@3olCT000?olCT000?o0000ooLU0?og9@00
0_og9@000ol0003onAX0ooTJ0002ooTJ00?o00000_of:@04o`000005onIS0?l0003oooooooooool0
00000_ooool0057ooooo00?o0000ooooooooool00oooool01Ol0003oieh0onMN0?oWGP3o000000Co
iFD000?o0000onAZ0?l000000ooFUP000ol0003oeYP0omJH0002omJH0003o`000?oFUP3o000000?o
a/4000?o0000olRl0?o8_0000_o8_0000ol0003oVkX0oi^j0003oi^j0004o`000?n__`3o[kl0o`00
00?oKJh000Oo0000ohNe0?n7]@3oQkD0o`000?m<Y@3o000000GoJjh000?o0000oeZY0?mJZ@001?mJ
Z@02o`0000GoE:L000Co0000obfK0?l]V`3o00000_mJZ@000ol0003o=ih0ocNN0003ocNN0003o`00
0?m<Y@3oC:D000?oC:D000?o0000ocBM0?ldW@000_ldW@02o`0000CoFZT000?o0000odbU0?m<Y@00
0_m<Y@000ol0003oA:80odBR0003odBR00Co000000?oPK@0o`000?n4]0000on4]0000ol0003oSKL0
ohfg0002ohfg0003o`000?nK^P3oVkX000;oVkX000?o0000ojno0?n__`000_n__`000ol0003oaL80
olG20002olG20003o`000?o</@3oc;4000;oc;4000Go0000omBL0?oDW03oe9`0o`000003omb500co
00001?oZE0000ol0003olCT0oo4i0003oo4i0003o`000?og9@3ombD000;ombD000?o0000ooTJ0?l0
00000_l00002ooTK0003o`000?of:@3o000000;okd4000?o0000onIS0?l000000oooool1o`00007o
oooo0Oooool005;ooooo00?o0000ooooooooool00oooool00ol0003oieh0o`000004onEU0007o`00
0?oTJP3oi6X0onAZ0?l0003oeYH0o`000004omJH0007o`000?oFUP3oeYH0omJF0?l0003oa/40o`00
0005olRl00;o00000onK^P000ol0003o[kl0ojno0002ojno0003o`000?m][P3o000000GoQkD000?o
0000of^^0?m[[P001?m[[P000ol0003oFZT0oeZY0004oeZY0003o`000?mDY`3oE:L000CoE:L000?o
0000obfK0?l000000omJZ@000ol0003o=ih0ocNN0002ocNN00;o00001Om<Y@000ol0003o=9d0ocBM
0002o`000003off^0?l0003oFZT000?oFZT000?o0000odbU0?m<Y@000om<Y@000ol0003oA:80odBR
0003o`0000CoPK@000?o0000ohBd0?n4]0000_n4]0000ol0003oSKL0ohfg0002ohfg0003o`000?nK
^P3oVkX000?oVkX000Go0000ojno0?n__`3o[kl0o`000004olG20003o`000?o</@3oc;4000;oc;40
00?o0000omBL0?oDW0000_oDW0001Ol0003og8D0omb50?oLQ@3o000000Goi6/000Co0000on]A0?o[
D@3oje404_l00005ooTK00?o000000Cokd40o`000?oVH`3o00001Oooool1o`00007ooooo001Coooo
o`03o`000?oooooooooo00?ooooo0_l00003onEU0003o`000?oTJP3oi6X000;oi6X00ol00003omJH
0003o`000?oFUP3oeYH000?oeYH000?o0000olRl0?o8_0000oo8_0001_l0003obk@0ol^d0?l0003o
VkX0o`0000Ko[kl000?o0000ohNe0?n7]@000on7]@02o`0000GoJjh000?o0000ohnh0?l000001?mJ
Z@02o`0000KoE:L00_l00005oeZY0004o`000?lgWP3o=ih0o`0000;oJjh000?o0000odbU0?m<Y@00
0om<Y@02o`0000?oKJh000?o0000oeZY0?mJZ@000omJZ@001?l0003oC:D0odbU0?m<Y@04o`0000;o
Q;@000?o0000oh6d0?n1]0000on1]0000ol0003oQ;@0ohBd0002ohBd0003o`000?n=]`3oSKL000;o
SKL000?o0000oi^j0?nK^P000_nK^P001Ol0003o[kl0ojno0?n__`3o000000CoaL8000?o0000olba
0?o</@000_o</@000ol0003oe9`0omBL0002omBL0003o`000?oLQ@3og8D000;og8D000?o0000onA[
0?oTJ`000ooTJ`001Ol0003oje40on]A0?o[D@3o000000ColCT000?o0000ooHV0?of9P000oof9P00
0ol0003onA/0ooTK0003ooTK0003o`000?oi6`3o000000;o00000_of9`04o`000003ooooool0003o
oooo00?ooooo0Ol00001ooooo`00E?ooool2o`0000Gooooo00?o0000onEU0?l000001?oTJP001ol0
003oi6/0onA[0?oTJ`3o0000omJH0?l000001OoFUP000ol0003of940o`000003olRl0003o`000?o;
]03obk@000;obk@000?o0000ojno0?n__`001?n__`02o`0000CoQkD000Co0000ojJm0?nV_@3o0000
0om[[P001Ol0003oSkP0ohnh0?n?^03o000000;oFZT000Co0000ohBd0?n4]03o00001?mDY`000ol0
003oQ;@0o`000005oeZY0003o`000?lgWP3o000000?oJjh000?o0000odbU0?m<Y@000_m<Y@02o`00
00GoKJh000?o0000oeZY0?mJZ@000_mJZ@001_l0003oC:D0o`000?l0003oSKL0o`0000GoQ;@000?o
0000oh6d0?n1]0000_n1]0000ol0003oQ;@0ohBd0002ohBd0003o`000?n=]`3oSKL000;oSKL000?o
0000oi^j0?nK^P000_nK^P000ol0003o[kl0ojno0002ojno0003o`000?o5`P3oaL8000;oaL8000?o
0000olba0?o</@000_o</@000ol0003oe9`0omBL0002omBL0003o`000?oLQ@3og8D000;og8D000?o
0000onA[0?oTJ`000_oTJ`000ol0003oje40on]A0002on]A0003o`000?oa>@3olCT000;olCT000?o
0000ooHV0?of9P000oof9P000ol0003onA/0ooTK0002ooTK00;o00000oof9`02o`000003oo0n0?l0
003o000000?ooooo00Go0000ooooooooooooooooo`000001ooooo`00E_ooool00ol0003ooooooooo
o`03ooooo`;o00000ooTJP000ol0003oi6/0onA[0003onA[0003o`000?oFUP3oeYH000?oeYH000Oo
0000omRA0?oHT@3of940o`000?o8_03o000000Gobk@000?o0000ojno0?n__`000on__`001?l0003o
aL80olG20?l00002ohNe0003o`000?nV_@3oY[d000;oY[d000?o0000of^^0?l000001?n?^0000ol0
003oFZT0o`000004ohBd0004o`000?mDY`3oE:L0o`0000?oQ;@000?o0000oeZY0?mJZ@000_mJZ@02
o`0000GoJjh000Ko0000odbU0?m<Y@3o0000ohNe0?l00005off^0003o`000?mJZ@3oFZT000;oFZT0
0_l00004ohfg0003o`000?n4]03oQ;@000;oQ;@000?o0000oh6d0?n1]0000_n1]0000ol0003oQ;@0
ohBd0002ohBd0004o`000?n=]`3oSKL0ohfg01Wo000000?oe9`0o`000?oLQ@000ooLQ@000ol0003o
i6/0onA[0002onA[0003o`000?o[D@3oje4000;oje4000?o0000oo4i0?oa>@000ooa>@000ol0003o
mRH0ooHV0002ooHV0003o`000?oi6`3o000000;o00000_oi6`000ol0003omRL0o`000002oo0n00;o
00001?ooool01Ol0003ooooooooooooooooo0000007ooooo001Gooooo`03o`000?oooooooooo00Co
oooo00?o0000onAZ0?l000001OoTJ`000ol0003oi6X0o`000003omJF0003o`000?oHT@3of94000?o
f94000?o0000ol^d0?o;]0000oo;]0000ol0003ocjT0o`000003ojno0007o`000?o5`P3oaL80olG2
0?l0003oQkD0o`000006ojJm0003o`000?n?^03oSkP000CoSkP000?o0000ohBd0?n4]0000on4]000
0ol0003oE:L0o`000004ohBd0003o`000?mJZ@3oFZT000;o000000?oSkP0o`000?m[[P001?m[[P00
0ol0003oC:D0o`000003ohNe0003o`000?m][P3oKJh000;oKJh000?o0000oeZY0?mJZ@000_l00000
0onK^P3o0000ohfg0003ohfg0003o`000?n4]03oQ;@000;oQ;@000?o0000oh6d0?n1]0000on1]000
0ol0003oQ;@0ohBd0005o`0000;ob;`000?o0000ol^d0?o;]0000_o;]0001Ol0003ocjT0olnY0?o?
Z@3o000000Coe9/000?o0000omZ90?oJR@000_oJR@001?l0003ohGH0on5f0?oQMP0Mo`0000GonA/0
0ol000000oo`?P3o0000o`000006ooooo`04o`000?ooooooooooo`00007ooooo001Hooooo`03o`00
0?oooooooooo00Cooooo00?o0000onA[0?oTJ`000ooTJ`001ol0003oi6X0onAZ0?oTJP3o0000omJF
0?l000001OoHT@000ol0003ofXT0o`000003ol^d0007o`000?o?Z@3ocjT0olnY0?l0003o[kl0o`00
0005olG20003o`000?nV_@3oY[d000CoY[d00_l00005ohnh00;o00001On4]002o`0000GoQ;@000?o
0000oeZY0?l000001?n?^0000ol0003oJjh0of^^0002of^^00;o00001?n7]@000ol0003oKJh0off^
0003off^00;o00000onK^P000ol0003oSKL0ohfg0003ohfg0003o`000?n4]03oQ;@000;oQ;@000?o
0000oh6d0?n1]0001Ol00002olK10003o`000?o8_03ob;`000;ob;`000?o0000ol^d0?o;]0000oo;
]0001Ol0003ocjT0olnY0?o?Z@3o000000Coe9/000?o0000omZ90?oJR@000_oJR@000ol0003ohGH0
on5f0002on5f0003o`000?oWH03oif0000;oif0000?o0000one:0?o]BP000_o]BP000ol0003olSH0
oo8f0002oo8f0003o`000?og9@3ombD000?ombD000?o0000ooTK0?oi6`000ooi6`000ol0003onA/0
o`000002o`0000;omRL00ol00008ooooo`03o`000?oooooo0000007ooooo001Iooooo`;o00001Ooo
ool01Ol0003oi6/0onA[0?oTJ`3o000000Coi6X00_l00005omRA0007o`000?oJR@3ofXT0omZ90?l0
003obk@0o`000005olnY0003o`000?o5`P3oaL8000CoaL8000?o0000ojJm0?nV_@000onV_@001?l0
003oa/40olK10?l00003ohnh0004o`000?nj`P3o^/80o`0000?oQ;@000?o0000okG10?l000001On4
]002o`0000GoSkP000Oo0000of^^0?m[[P3oJjh0o`000?nV_@3o000000GoQkD000Co0000off^0?m]
[P3oKJh00_l00005oi^j0003o`000?n=]`3oSKL000;oSKL000Co0000ohBd0?n4]03oQ;@01?l00002
olG20003o`000?o6`@3oa/4000?oa/4000?o0000olRl0?o8_0000_o8_0000ol0003obk@0ol^d0002
ol^d0005o`000?o?Z@3ocjT0olnY0?l000001?oDV`000ol0003ofXT0omZ90002omZ90003o`000?oQ
MP3ohGH000?ohGH000?o0000onMP0?oWH0000_oWH0000ol0003okDX0one:0002one:0003o`000?ob
=P3olSH000;olSH000?o0000ooLU0?og9@000oog9@000ol0003onA/0ooTK0002ooTK00;o00000oof
9`03o`0000[ooooo00?o0000ooooool000000Oooool005_ooooo00?o0000ooooooooool00oooool0
0ol0003oi6/0o`000004onAZ0004o`000?oUI@3oiFD0o`0000?of94000?o0000omZ90?oJR@000ooJ
R@000ol0003ocjT0olnY0003olnY00;o00001Oo5`P000ol0003oc;40o`000003ojJm0005o`000?o6
`@3oa/40olK10?l000000_n?^0001Ol0003o^/80ok[20?nj`P3o000000;oQ;@000Go0000okG10?ne
`@3o]L40o`000003ohBd0003o`000?nj`P3o000000GoSkP000Co0000of^^0?m[[P3o00000onV_@00
0ol0003oQkD0ohNe0002ohNe0006o`000?m][P3o0000o`000?n__`3o00001OnK^P000ol0003oSKL0
ohfg0002ohfg0006o`000?n4]03o0000o`000?o6`@3o00001Oo5`P000ol0003oa/40olK10002olK1
0003o`000?o8_03ob;`000;ob;`000?o0000ol^d0?o;]0000_o;]0000ol0003ocjT0olnY0002olnY
0003o`000?oDV`3oe9/000;oe9/000?o0000omZ90?oJR@000_oJR@000ol0003ohGH0on5f0002on5f
0003o`000?oWH03oif0000;oif0000?o0000one:0?o]BP000_o]BP000ol0003olSH0oo8f0002oo8f
0003o`000?og9@3ombD000?ombD000?o0000ooTK0?l000000_l00002ooTK0005o`000?of9`3o0000
onm10?l000003?ooool1o`00007ooooo0Ol0000005cooooo00?o0000ooooooooool00oooool2o`00
00?oi6X000?o0000onEU0?oUI@000_oUI@000ol0003of940o`000005omZ900;o00001?o?Z@001?l0
003oe9/0omBK0?l00003olG20007o`000?o</@3oc;40olba0?l0003oY[d0o`000004olK10003o`00
0?n?^03o000000Co^/8000?o0000ohBd0?l000001?ne`@001?l0003oQ;@0ohBd0?l00003ok[20003
o`000?n?^03oSkP000?oSkP00_l00004ojJm0003o`000?n7]@3oQkD000;oQkD00_l00004ojno0003
o`000?nK^P3oVkX000;oVkX000?o0000ohfg0?n=]`000_n=]`02o`0000Coa/4000?o0000olG20?o5
`P000_o5`P000ol0003oa/40olK10002olK10003o`000?o8_03ob;`000;ob;`000?o0000ol^d0?o;
]0000oo;]0001Ol0003ocjT0olnY0?o?Z@3o000000Coe9/000?o0000omZ90?oJR@000_oJR@000ol0
003ohGH0on5f0002on5f0003o`000?oWH03oif0000;oif0000?o0000one:0?o]BP000_o]BP001?l0
003olSH0oo8f0?ob=P09o`0000GonA/00_l000000oo_@@3o0000ooooo`0=ooooo`;o0000001Moooo
o`03o`000?oooooooooo00Cooooo00?o0000onAZ0?l000001OoUI@02o`0000GofXT000Co0000omin
0?oNOP3o00000_o?Z@000ol0003oe9/0omBK0002omBK0003o`000?o5`P3o000000Goc;4000?o0000
olK10?o6`@001?o6`@000ol0003o^/80ok[20004ok[20003o`000?ne`@3o]L4000?o]L4000?o0000
ohBd0?l000001?nj`P000ol0003oSkP0ohnh0002ohnh00;o00001OnV_@000ol0003oQkD0ohNe0002
o`000003olG20?l0003o[kl000?o[kl000?o0000oi^j0?nK^P000onK^P04o`000003olRl0?l0003o
a/4000?oa/4000?o0000olG20?o5`P000oo5`P000ol0003oa/40olK10002olK10003o`000?o8_03o
b;`000;ob;`000?o0000ol^d0?o;]0008ol00002ooLR0003o`000?oi6P3onAX000ConAX000?o0000
ooTK0?l000000_l000000oof:@3o0000o`00000>ooooo`?o0000001Nooooo`;o00001Oooool00ol0
003oiFD0onEU0003onEU0004o`000?oWGP3oieh0o`0000?ofXT000Oo0000omin0?oNOP3ogWh0o`00
0?o?Z@3o000000Goe9/00_l00005olba00;o00001_o6`@000ol0003o^/80ok[20004ok[20003o`00
0?ne`@3o]L4000Co]L4000?o0000ok[20?nj`P000onj`P000ol0003oSkP0ohnh0002o`000003olK1
0?l0003oY[d000GoY[d00_l00003olG20003o`000?n__`3o[kl000?o[kl000Co0000oi^j0?nK^P3o
VkX00_l00005olRl0003o`000?o6`@3oa/4000;oa/4000?o0000olG20?o5`P000_o5`P000ol0003o
a/40olK1000:o`0000;ofXT000?o0000omin0?oNOP000_oNOP000ol0003ohW40on9a0002on9a0003
o`000?oVH@3oiV4000;oiV4000?o0000on]@0?o[D0000_o[D0000ol0003ol3l0oo0o0002oo0o0003
o`000?od;`3om2l000;om2l000?o0000ooLR0?og8P000oog8P000ol0003onAX0ooTJ0003ooTJ00;o
00000_of:@02o`0000cooooo1?l00003ooooo`00H?ooool00ol0003oooooooooo`03ooooo`05o`00
0?oUI@3oiFD0onEU0?l000001?oWGP000ol0003ofXT0o`000005omin0003o`000?oDV`3oe9/000?o
e9/000?o0000omZ90?l000001?o</@001?l0003oe9`0omBL0?l00004olK10003o`000?o?Z@3o0000
00Co^/8000?o0000olf_0?l000001One`@000ol0003o^/80ok[20004ok[200;o00001?o6`@000ol0
003oY[d0ojJm0002ojJm00;o00001Oo5`P000ol0003o[kl0ojno0002ojno0006o`000?nK^P3o0000
o`000?o;]03o00001Oo8_0000ol0003oa/40olK10002olK10003o`000?o5`P3oaL8000;oaL800ol0
0002omJF0003o`000?oHT@3of94000;of94000?o0000omZ90?oJR@000ooJR@000ol0003ogWh0omin
0002omin0003o`000?oRL@3ohW4000;ohW4000?o0000onIQ0?oVH@000_oVH@000ol0003oje00on]@
0002on]@0003o`000?o`?`3ol3l000;ol3l000?o0000oo@_0?od;`000_od;`000ol0003omb80ooLR
0003ooLR0003o`000?oi6P3o000000;o000000ConAd0o`000?of:@3o00002_ooool4o`0000Oooooo
001Qooooo`03o`000?oooooooooo00?ooooo00?o0000onEU0?l000001OoWGP02o`0000GogWh000?o
0000on9a0?l000000ooDV`001Ol0003ofXT0omZ90?oJR@3o000000;oc;4000?o0000omBL0?oDW000
0_oDW0001?l0003oa/40olK10?l00003olnY0004o`000?nj`P3o^/80o`0000;ocJl000?o0000okG1
0?ne`@000_ne`@000ol0003ocJl0o`000005ok[20003o`000?o6`@3oa/4000?oa/4000Oo0000ojJm
0?nV_@3oY[d0o`000?o</@3o000000GoaL8000?o0000ojno0?n__`000_n__`02o`0000Cobk@000?o
0000olRl0?o8_0000_o8_0000ol0003oa/40olK10002olK10003o`000?o5`P3o000000;o000000?o
eYP0o`000?oFUP000ooFUP000ol0003of940omRA0002omRA0003o`000?oJR@3ofXT000;ofXT000?o
0000omin0?oNOP000_oNOP000ol0003ohW40on9a0002on9a0003o`000?oVH@3oiV4000;oiV4000?o
0000on]@0?o[D0000_o[D0000ol0003ol3l0oo0o0002oo0o0004o`000?od;`3om2l0oo@_00Wo0000
1?oi7@02o`0000Oooooo1?l0000;ooooo`00H_ooool00ol0003oooooooooo`03ooooo`03o`000?oW
GP3oieh000?oieh000Co0000onYE0?oZE@3o00000ooNOP001ol0003ohW40on9a0?oRL@3o0000omBK
0?l000001?oJR@000ol0003oc;40o`000005omBL0003o`000?o6`@3o000000CocjT000?o0000ok[2
0?l000001?o=[`001?l0003o]L40okG10?l00002olf_0003o`000?nj`P3o^/8000;o^/800_l00005
olK10004o`000?nV_@3oY[d0o`0000?oc;4000?o0000olG20?o5`P000_o5`P000ol0003o[kl0ojno
0002o`000003olnY0?l0003obk@000?obk@000?o0000olRl0?o8_0000oo8_0000ol0003oa/40olK1
0003o`0000CoeYP000?o0000omJF0?oFUP000_oFUP000ol0003of940omRA0002omRA0003o`000?oJ
R@3ofXT000;ofXT000?o0000omin0?oNOP000_oNOP000ol0003ohW40on9a0002on9a0003o`000?oV
H@3oiV4000;oiV4000?o0000on]@0?o[D0000_o[D0001?l0003ol3l0oo0o0?o`?`05o`0000;on1d0
00?o0000ooTJ0?oi6P000ooi6P000ol0003onAd0o`000002o`0000Kooooo0ol0000?ooooo`00Hooo
ool2o`0000Cooooo00Go0000onMN0?oWGP3oieh0o`000004onYE0003o`000?oNOP3o000000GohW40
00?o0000omZ90?oJR@001?oJR@000ol0003oe9`0omBL0004omBL00;o00001Oo?Z@02o`0000GocJl0
00?o0000okG10?l000001?o=[`001?l0003o^/80ok[20?l00002olnY0003o`000?o6`@3oa/4000?o
a/400_l00004olba0003o`000?o5`P3oaL8000?oaL800_l00004olnY0003o`000?o;]03obk@000;o
bk@000Co0000olRl0?o8_03ob;`01?l00002omJF0003o`000?oFV03oeYP000?oeYP000?o0000omJF
0?oFUP000_oFUP000ol0003of940omRA0002omRA0003o`000?oJR@3ofXT000;ofXT000?o0000omin
0?oNOP000_oNOP000ol0003ohW40on9a000?o`0000;omRH000?o0000ooPM0?oh7@000ooh7@001?l0
003onAX0ooTJ0?oi6P03o`0000Gooooo1?l0000Booooo`00IOooool00ol0003oooooooooo`02oooo
o`03o`000?oWGP3o000000GojUD00_l00005on9a00;o00001OoJR@02o`0000Goe9`000?o0000omb5
0?l000001?o?Z@000ol0003ofHh0o`000005olf_00;o00001Oo=[`000ol0003o^/80o`000003olnY
0003o`000?o6`@3oa/4000;oa/400_l00005olba0003o`000?o5`P3oaL8000;oaL800_l00005olnY
0003o`000?o;]03obk@000;obk@000Ko0000olRl0?l0003o0000omRA0?l00005omJF0003o`000?oF
V03oeYP000;oeYP000?o0000omJF0?oFUP000_oFUP000ol0003of940omRA0002omRA0003o`000?oJ
R@3ofXT000[o00000_o]BP000ol0003ol3h0oo0n0002oo0n0003o`000?oc<@3olc4000;olc4000?o
0000ooHV0?of9P000oof9P000ol0003on1d0ooPM0002ooPM00Co00001?ooool4o`0001Kooooo001V
ooooo`03o`000?oooooooooo00;ooooo00?o0000onYE0?oZE@000ooZE@000ol0003okDX0o`000004
on9a0004o`000?oVH@3oiV40o`0000?ofXT000Co0000on5f0?oQMP3o00000ooDW0001Ol0003og8D0
omb50?oLQ@3o000000;ocjT000Go0000omV>0?oISP3ofHh0o`000003olf_0003o`000?oHT@3o0000
00GocJl00_l00005olnY0006o`000?o6`@3oa/40o`000?oDW03o00001_o</@04o`000003omBK0?l0
003ocjT000CocjT000?o0000ol^d0?o;]0000_o;]002o`0000Cof94000?o0000omJF0?oFUP000_oF
UP000ol0003oeYP0omJH0002omJH0003o`000?oFUP3oeYH000;oeYH02?l00002onMN0003o`000?oZ
E@3ojUD000;ojUD000?o0000one:0?o]BP000oo]BP000ol0003ol3h0oo0n0002oo0n0003o`000?oc
<@3olc4000;olc4000?o0000ooHV0?of9P000_of9P000ol0003on1d0o`000002o`0000Cooooo1?l0
000Jooooo`00Ioooool00ol0003oooooooooo`02ooooo`05o`000?oZE@3ojUD0onYE0?l000000oo]
BP001?l0003ohW40on9a0?l00004onIQ0003o`000?oJR@3o000000CohGH000?o0000omBL0?l00000
1?oLQ@000ol0003ocjT0o`000004omV>0004o`000?o=[`3ocJl0o`0000?of94000Oo0000olf_0?o=
[`3ocJl0o`000?oISP3o000000GocjT000?o0000olK10?l000000ooDW0000ol0003oc;40olba0002
olba00;o00001OoDV`000ol0003ocjT0olnY0003olnY00Co000000?ofXT0o`000?oHT@000ooHT@00
0ol0003oeYH0omJF0002omJF0003o`000?oFV03oeYP000?oeYP01?l000000ooTJP3o0000onEU0003
onEU0003o`000?oWGP3oieh000;oieh000?o0000onYE0?oZE@000_oZE@000ol0003okDX0one:0002
one:0003o`000?o`?P3ol3h000;ol3h000Co0000oo<a0?oc<@3olc402?l00003ooooo`Co00007_oo
ool006Sooooo0_l00003ooooo`03o`000?oZE@3o000000CokDX000?o0000on9a0?l000001OoVH@02
o`0000KohGH000?o0000omb50?oLQ@001?oLQ@000ol0003ofHh0omV>0003omV>0003o`000?o=[`3o
000000Cof94000Co0000olf_0?o=[`3o00000ooISP000ol0003ocjT0olnY0002olnY00;o00001OoD
W0001_l0003oc;40olba0?l0003ofXT0o`0000Goe9/000?o0000olnY0?o?Z@000_o?Z@02o`0000Go
fXT000?o0000omRA0?oHT@000_oHT@000ol0003oeYH0omJF0002omJF0003o`000?oFV03oeYP000?o
00001OoTJP000ol0003oiFD0onEU0002onEU0003o`000?oWGP3oieh000;oieh000?o0000onYE0?oZ
E@000_oZE@001Ol0003okDX0one:0?o]BP3o000000?ol3h01Ol00007ooooo`Co00008_ooool006[o
oooo00Go0000ooooooooooooooooo`000005one:00;o00001OoVH@000ol0003oje00o`000005on5f
00;o00001OoLQ@02o`0000GofHh00_l00005omRA0003o`000?o=[`3o000000CofHh000?o0000olnY
0?o?Z@000_l000000ooLQ@3o0000omBL0004omBL0003o`000?o</@3o000000?ofXT000?o0000omBK
0?oDV`000_oDV`000ol0003ocjT0olnY0002o`000003omin0?l0003ofXT000CofXT000?o0000omRA
0?oHT@000_oHT@000ol0003oeYH0omJF0005o`0000;oi6/000?o0000onAZ0?oTJP000ooTJP000ol0
003oiFD0onEU0002onEU0003o`000?oWGP3oieh000;oieh000Co0000onYE0?oZE@3ojUD02Ol00008
ooooo`Co00009_ooool006_ooooo00Go0000ooooooooooooooooo`000003one:0004o`000?o`?P3o
l3h0o`0000?oiV4000Go0000on]@0?o[D03oje00o`000003on5f0004o`000?oWH03oif00o`0000?o
g8D000Co0000onA[0?oTJ`3o00000ooISP000ol0003ohW40o`000005omRA00;o00001OoISP000ol0
003ocjT0o`000004omb50003o`000?oDW03oe9`000;oe9`00_l00004omZ90003o`000?oDV`3oe9/0
00?oe9/00_l00004omin0003o`000?oJR@3ofXT000;ofXT000?o0000omRA0?oHT@000_oHT@03o`00
00;oi6X000?o0000onA[0?oTJ`000ooTJ`000ol0003oi6X0onAZ0002onAZ0003o`000?oUI@3oiFD0
00;oiFD000Co0000onMN0?oWGP3oieh01Ol0000>ooooo`?o0000:_ooool006cooooo00Oo0000oooo
ooooooooooooo`000?o]BP3o000000Col3h000?o0000onIQ0?l000001Oo[D0000ol0003ohGH0o`00
0004onMP0003o`000?oLQ@3o000000Coi6/000?o0000omV>0?l000000ooRL@001ol0003of940omRA
0?oHT@3o0000on9a0?l000001OoISP02o`0000Gog8D000?o0000omBL0?oDW0000_l000000ooQMP3o
0000omZ90004omZ90004o`000?oDV`3oe9/0omBK00;o00001OoNOP000ol0003ofXT0omZ90003omZ9
00Co000000?oiFD0o`000?oTJP000ooTJP000ol0003oi6/0onA[0002onA[0003o`000?oTJP3oi6X0
00?oi6X000?o0000onEU0?oUI@001Ol0000?ooooo`Co0000;Oooool006gooooo0_l00002ooooo`03
o`000?o`?P3ol3h000?ol3h00_l00006on]@00;o00001OoWH002o`0000Goi6/00_l00005on9a0003
o`000?oHT@3o000000?ohW4000Oo0000omV>0?oISP3ofHh0o`000?oTJ`3o000000Gog8D000?o0000
omBL0?l000001?oQMP000ol0003ofXT0omZ90002omZ90006o`000?oDV`3o0000o`000?oRL@3o0000
1OoNOP000ol0003ofXT0omZ90002omZ900;o00001OoUI@000ol0003oi6X0onAZ0002onAZ0005o`00
0?oTJ`3oi6/0onA[0?l000000ooTJP05o`00013ooooo1?l0000aooooo`00Koooool01?l0003ooooo
ooooool00003oo0n0004o`000?oc<@3olc40o`0000?oje000_l000000oo`?`3o0000onMP0002onMP
00;o000000?okDX0o`000?oTJ`000ooTJ`000ol0003oje40o`000005on9a00;o00001OoRL@000ol0
003ofHh0o`000003onA[0003o`000?oLQ@3og8D000;og8D00_l00005on5f0003o`000?oJR@3ofXT0
00;ofXT00_l00004on9a0003o`000?oNOP3ogWh000?ogWh01?l000000ooWGP3o0000onEU0004onEU
0003o`000?oTJP3oi6X000;oi6X000?o0000onA[0?oTJ`001Ol0000Aooooo`Co0000=Oooool0073o
oooo00Ko0000oooooooooooo0000oo0n0?l00004oo<a0003o`000?o[D03o000000Col3l000?o0000
onMP0?l000001?o]BP001?l0003oi6/0onA[0?l00003on]A0007o`000?oRL@3ohW40on9a0?l0003o
jU@0o`000005on9a00;o00001OoTJ`001_l0003og8D0omb50?l0003oif00o`0000GohGH000?o0000
omZ90?oJR@000_l000000ooVH@3o0000on9a0004on9a0004o`000?oNOP3ogWh0omin00;o00001OoW
GP000ol0003oiFD0onEU0002onEU0003o`000?oTJP3oi6X000;oi6X00ol0000Booooo`Co0000>Ooo
ool0077ooooo00Co0000oooooooooooo00001Ooc<@02o`0000Gol3l00_l00005one:0003o`000?oT
J`3o000000Coje4000Co0000on9a0?oRL@3o00000ooZE0001ol0003ohW40on9a0?oRL@3o0000on]A
0?l000001OoTJ`000ol0003og8D0o`000003onMP0003o`000?oQMP3ohGH000?ohGH00_l00004onIQ
0003o`000?oRL@3ohW4000;ohW4000Ko0000omin0?l0003o0000onYE0?l00005onMN0003o`000?oU
I@3oiFD000?oiFD01?l0000Aooooo`Co0000?Oooool007;ooooo0ol00003oo<a00;o00000_of9P00
1ol0003ol3l0oo0o0?o`?`3o0000oo@_0?l000001Oo]BP02o`0000Goje4000?o0000on9a0?l00000
1?oZE0001?l0003ohW40on9a0?l00003on]A0003o`000?oTJ`3oi6/000;oi6/00_l00005onMP0004
o`000?oQMP3ohGH0on5f00;o00001OoVH@000ol0003ohW40on9a0002on9a00;o00001?oZE@000ol0
003oieh0onMN0002onMN0004o`000?oUI@3oiFD0onEU00?o00004?ooool4o`00047ooooo001doooo
o`;o000000?olc40o`000?of9P001?of9P000ol0003ol3l0o`000003oo@_0007o`000?o]BP3okDX0
one:0?l0003olSH0o`000005on]A00;o00001OoZE0000ol0003ohW40o`000004on]A0003o`000?oT
J`3oi6/000;o000000?okDX0o`000?oWH0001?oWH0001_l0003ohGH0o`000?l0003oje00o`0000Go
iV4000?o0000on9a0?l000000_l000000oo]BP3o0000onYE0004onYE0004o`000?oWGP3oieh0onMN
00Co00003oooool4o`0004Gooooo001eooooo`;o00001_of9P02o`0000Gom2l000?o0000one:0?l0
00000oob=P001Ol0003oje40on]A0?o[D@3o000000;olCT000?o0000onYD0?oZE0000_oZE002o`00
00Goje4000?o0000onA[0?l000001?o]BP000ol0003oif00onMP0002onMP00;o00001?o[D0000ol0
003oiV40onIQ0002onIQ00;o00001Oo]BP000ol0003ojUD0onYE0002onYE0004o`000?oWGP3o0000
o`00013ooooo0ol00019ooooo`00M_ooool2o`0000?omRH00_l000000ooh7@3o0000oo@_0004oo@_
00;o00001Oob=P000ol0003oje40o`000004oo4i0006o`000?oZE03o0000o`000?oa>@3o00001Oo[
D@02o`0000GokDX000?o0000onMP0?oWH0000_l000000oo`?`3o0000on]@0004on]@0006o`000?oV
H@3o0000o`000?o`?P3o00001Oo]BP000ol0003ojUD0onYE0002onYE00;o00003_ooool4o`0004co
oooo001gooooo`;o000000?omRH0o`000?oh7@000ooh7@000ol0003om2l0o`000002o`000003ooLR
0?l0003olSH000ColSH00_l00005oo4i00;o00001?oa>@001ol0003oje40on]A0?o[D@3o0000oo8f
0?l000001Oo]BP000ol0003oif00o`000004oo0o0003o`000?o[D03oje0000;oje000_l00004oo0n
0003o`000?o]BP3okDX000;okDX000?o0000onYE0?l000000_l0000<ooooo`Co0000D?ooool007So
oooo0ol00004ooPM00;o00001Oog8P000ol0003olSH0o`000002o`0000;ombD000Oo0000oo4i0?oa
>@3olCT0o`000?of9P3o000000GolCT000?o0000on]A0?l000000oob=P000ol0003okDX0one:0002
one:00;o00001Oo`?`000ol0003oje00o`000002o`000003oo<a0?l0003ol3h000Col3h000Co0000
one:0?o]BP3okDX00_l0000;ooooo`Co0000E?ooool007[ooooo0_l000000ooh7@3o0000o`000002
ooTJ0003o`000?og8P3omb8000;omb800_l00006ooLU0003o`000?oa>@3o000000?omRH000?o0000
oo4i0?oa>@000_oa>@02o`0000GolSH000Ko0000one:0?l0003o0000oo@_0?l00005oo0o00;o0000
1Ooc<@000ol0003ol3h0oo0n0002oo0n0004o`000?o]BP3o0000o`0000Wooooo1?l0001Hooooo`00
Noooool3o`0000ConAX000Co0000ooLR0?l0003o00000_oi6P000ol0003ombD0ooLU0003ooLU00;o
00001Oof9P001_l0003olCT0o`000?l0003ombD0o`0000GolSH00_l00004oo@_0007o`000?o`?`3o
l3l0oo0o0?l0003omRH0o`000005oo<a0004o`000?o`?P3ol3h0oo0n00?o00001oooool4o`0005co
oooo001looooo`03o`000?oooooo000000;onAX01?l00004ooTJ0003o`000?og9@3o000000;o0000
00?onA/0o`000?of9P001?of9P02o`0000CombD000?o0000oo8f0?l000000_l000000oog8P3o0000
oo@_0004oo@_0003o`000?o`?`3o000000?omRH000?o0000oo<a0?oc<@000_oc<@04o`0000Kooooo
1?l0001Pooooo`00OOooool4o`0000ConAd000?o0000ooTJ0?oi6P001?l00004ooTK0003o`000?of
9P3o000000;o000000?onA/0o`000?og9@000oog9@02o`0000Gomb8000Co0000oo@_0?od;`3om2l0
0ol00005ooHV0004o`000?oc<@3o0000o`0000Kooooo1?l0001Tooooo`00Ooooool00ol0003ooooo
o`000006o`0000ConA/000?o0000ooTK0?oi6`001?l00004ooTK0004o`000?og9@3o0000o`0000;o
nAX000?o0000ooLR0?og8P000_og8P04o`0000;on1d000?o0000ooHV0?of9P000oof9P02o`0000Go
oooo0ol0001Xooooo`00P?ooool01?l0003oooooooooooooool;o`0000ConA/000?o0000ooTK0?oi
6`001?l00004ooTJ0004o`000?og8P3o0000o`0000;onAX000?o0000ooPM0?oh7@000_oh7@000ol0
003omRH0o`000002o`0000?ooooo1?l0001[ooooo`00POooool00ol0003oooooooooo`06ooooo`Go
00000ooi6`04o`0000ConA/000?o0000ooTJ0?oi6P000ol00005ooTJ0003o`000?oh7@3on1d000?o
00000_ooool4o`0006oooooo0022ooooo`;o00002?ooool00ol0003oooooo`00000>o`0000?onAd0
00Co0000ooTJ0?oi6P3onAX01?l000000ooooooo0000o`000002o`0007?ooooo0024ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02Oooool<o`000003ooooool0003o000000;o0000
Moooool008Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000Nooo
ool008Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000Ooooool0
08Oooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo0ol00023ooooo`00ROooool01?l0003o
ooooooooool00009ooooo`Co0000Q_ooool008[ooooo00?o0000ooooool000001Oooool4o`0008[o
oooo002;ooooo`;o000000?oooooo`000?l000000_l0002>ooooo`00S?ooool2o`0009;ooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo000fooooo`?o0000F?ooool3o`0001Oooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`08ooooo`00=oooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`07ooooo`00<Oooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003
ooooo`Co000000?oooooo`000?l000000ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002
ooooo`Ko00001_ooool5o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo1?l0
0003ooooo`;o00000_ooool6o`0000Oooooo00?o0000ooooooooool00oooool4o`000003ooooool0
003o000000;o00000_ooool4o`0000?ooooo0ol00002ooooo`Go00000oooool2o`000004ooooool0
003oooooooooo`;o00000oooool3o`0000Wooooo1?l000000ooooooo0000o`000003o`000003oooo
ool0003o000000;o00001?ooool2o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o
000000Coooooo`000?l0003o00000oooool3o`0000Gooooo00?o0000ooooooooool01_ooool0033o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool00000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Kooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000?ooooo00Go0000oooooooo
ooooooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000oooo
ool0000;ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`06
ooooo`00<?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool5o`0000;o
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`?o00000oooool01?l0003ooooo
ooooool00002ooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00007
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo00?o
0000ooooooooool00oooool3o`0000?ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`Go
00001?ooool00ol0003oooooooooo`06ooooo`00<?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0033ooooo
00Ko0000ooooooooooooooooo`000?ooool4o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`00
00?ooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool2
o`0000?ooooo1?l00003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool4
o`0000?ooooo2Ol00003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool3
o`0000?ooooo1?l00002ooooo`?o00001?ooool01?l0003oooooooooooooool2o`000004ooooool0
003o0000ooooo`Co00000oooool3o`0000Wooooo0ol00002ooooo`?o00001?ooool4o`000003oooo
ool0003o000000;o00000oooool2o`0000?ooooo1?l00003ooooo`?o00000oooool3o`0000Gooooo
00?o0000ooooooooool01_ooool0033ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07ooooo`00
<Oooool3o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`?o0000
2Oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`0000[ooooo0ol0000Fooooo`03o`00
0?oooooooooo00;ooooo0_l0000=ooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`?o0000
2_ooool00ol0003oooooooooo`0@ooooo`;o00001?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.169289, 0.0200793, \
0.003909, 0.003909}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.13865 .20246 -11.9543 -9 ]
[.13865 .20246 .04573 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.54594 .04229 -5.19627 -9 ]
[.54594 .04229 .80373 0 ]
[.7636 .09113 0 -6.16761 ]
[.7636 .09113 12 2.83239 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93774 .35781 0 -5.91554 ]
[.93774 .35781 6 3.08446 ]
[.02245 .27557 -24 -2.75115 ]
[.02245 .27557 0 6.24885 ]
[.01509 .32168 -18 -2.79015 ]
[.01509 .32168 0 6.20985 ]
[.00751 .36918 -24 -2.83045 ]
[.00751 .36918 0 6.16955 ]
[-0.0003 .41815 -18 -2.87213 ]
[-0.0003 .41815 0 6.12787 ]
[-0.00836 .46865 -24 -2.91524 ]
[-0.00836 .46865 0 6.08476 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.14789 .21178 m
.15252 .21643 L
s
[(-5)] .13865 .20246 .99238 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.5537 .05288 m
.55757 .05817 L
s
[(5)] .54594 .04229 .73209 1 Mshowa
.125 Mabswid
.18577 .19694 m
.18851 .19978 L
s
.22422 .18189 m
.22691 .18476 L
s
.26324 .16661 m
.2659 .16952 L
s
.30285 .1511 m
.30546 .15404 L
s
.3839 .11937 m
.38642 .12239 L
s
.42536 .10313 m
.42784 .10619 L
s
.46747 .08664 m
.4699 .08974 L
s
.51024 .06989 m
.51262 .07303 L
s
.11057 .22639 m
.11338 .22915 L
s
.07378 .2408 m
.07662 .24352 L
s
.03752 .255 m
.0404 .25768 L
s
.59784 .03559 m
.60011 .03881 L
s
.64269 .01803 m
.64491 .02128 L
s
.68828 .00018 m
.69043 .00347 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75129 .09569 m
.74514 .09797 L
s
[(-5)] .7636 .09113 -1 .37058 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92522 .36174 m
.91896 .36371 L
s
[(5)] .93774 .35781 -1 .31456 Mshowa
.125 Mabswid
.7709 .12568 m
.7672 .12703 L
s
.78996 .15483 m
.78625 .15616 L
s
.80849 .18319 m
.80478 .18449 L
s
.82652 .21077 m
.8228 .21206 L
s
.86116 .26375 m
.85743 .265 L
s
.8778 .28921 m
.87406 .29044 L
s
.89402 .31401 m
.89027 .31522 L
s
.90982 .33818 m
.90607 .33938 L
s
.73112 .06483 m
.72743 .06622 L
s
.71035 .03306 m
.70667 .03447 L
s
.68895 .00033 m
.68529 .00177 L
s
.94025 .38473 m
.93649 .38589 L
s
.9549 .40714 m
.95114 .40829 L
s
.96921 .42902 m
.96544 .43016 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03468 .27081 m
.04079 .26844 L
s
[(0.15)] .02245 .27557 1 -0.38863 Mshowa
.02735 .31701 m
.03349 .31468 L
s
[(0.2)] .01509 .32168 1 -0.37997 Mshowa
.01981 .36462 m
.02596 .36233 L
s
[(0.25)] .00751 .36918 1 -0.37101 Mshowa
.01203 .41369 m
.0182 .41145 L
s
[(0.3)] -0.0003 .41815 1 -0.36175 Mshowa
.00402 .46429 m
.0102 .46211 L
s
[(0.35)] -0.00836 .46865 1 -0.35217 Mshowa
.125 Mabswid
.03323 .27994 m
.0369 .27852 L
s
.03177 .28913 m
.03545 .28771 L
s
.03031 .29837 m
.03398 .29696 L
s
.02884 .30766 m
.03251 .30626 L
s
.02586 .32642 m
.02955 .32503 L
s
.02436 .33588 m
.02805 .3345 L
s
.02286 .3454 m
.02654 .34402 L
s
.02134 .35498 m
.02503 .35361 L
s
.01827 .37431 m
.02197 .37295 L
s
.01673 .38406 m
.02042 .38271 L
s
.01517 .39388 m
.01887 .39253 L
s
.01361 .40375 m
.01731 .40241 L
s
.01045 .42368 m
.01415 .42235 L
s
.00886 .43374 m
.01256 .43241 L
s
.00725 .44386 m
.01096 .44254 L
s
.00564 .45404 m
.00935 .45273 L
s
.03611 .26174 m
.03978 .2603 L
s
.00238 .4746 m
.0061 .4733 L
s
.00074 .48497 m
.00446 .48368 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .476 .129 r
.39285 .65799 .40402 .63513 .41888 .69101 .40727 .72817 Metetra
.443 .687 0 r
.40727 .72817 .41888 .69101 .43523 .71501 .42364 .75886 Metetra
.77 .767 0 r
.42364 .75886 .43523 .71501 .45242 .71756 .4411 .76284 Metetra
.789 .722 0 r
.4411 .76284 .45242 .71756 .46988 .71376 .4589 .75896 Metetra
.791 .717 0 r
.4589 .75896 .46988 .71376 .48748 .70901 .47684 .75394 Metetra
.79 .718 0 r
.47684 .75394 .48748 .70901 .50519 .70416 .4949 .74884 Metetra
.79 .719 0 r
.4949 .74884 .50519 .70416 .52302 .69927 .51308 .74373 Metetra
.79 .72 0 r
.51308 .74373 .52302 .69927 .54097 .69434 .53138 .73862 Metetra
.789 .721 0 r
.53138 .73862 .54097 .69434 .55903 .68938 .5498 .73349 Metetra
.789 .721 0 r
.5498 .73349 .55903 .68938 .57721 .68438 .56834 .72836 Metetra
.789 .722 0 r
.56834 .72836 .57721 .68438 .59552 .67934 .587 .72322 Metetra
.789 .722 0 r
.587 .72322 .59552 .67934 .61394 .67427 .60579 .71807 Metetra
.788 .723 0 r
.60579 .71807 .61394 .67427 .63249 .66916 .62471 .71291 Metetra
.788 .723 0 r
.62471 .71291 .63249 .66916 .65116 .66401 .64375 .70774 Metetra
.788 .723 0 r
.64375 .70774 .65116 .66401 .66995 .65883 .66293 .70256 Metetra
.788 .723 0 r
.66293 .70256 .66995 .65883 .68887 .6536 .68224 .69736 Metetra
.788 .723 0 r
.68224 .69736 .68887 .6536 .70792 .64834 .70168 .69216 Metetra
.788 .723 0 r
.70168 .69216 .70792 .64834 .72709 .64304 .72125 .68693 Metetra
.788 .723 0 r
.72125 .68693 .72709 .64304 .7464 .6377 .74097 .6817 Metetra
.789 .723 0 r
.74097 .6817 .7464 .6377 .76584 .63232 .76082 .67646 Metetra
.789 .722 0 r
.76082 .67646 .76584 .63232 .7854 .6269 .78082 .6712 Metetra
.789 .722 0 r
.78082 .6712 .7854 .6269 .8051 .62144 .80095 .66593 Metetra
.789 .721 0 r
.80095 .66593 .8051 .62144 .82494 .61593 .82124 .66064 Metetra
.789 .72 0 r
.82124 .66064 .82494 .61593 .84491 .61039 .84167 .65535 Metetra
.79 .719 0 r
.84167 .65535 .84491 .61039 .86502 .6048 .86225 .65004 Metetra
.79 .719 0 r
.86225 .65004 .86502 .6048 .88527 .59917 .88298 .64473 Metetra
.791 .717 0 r
.88298 .64473 .88527 .59917 .90566 .59349 .90386 .6394 Metetra
.791 .718 0 r
.90386 .6394 .90566 .59349 .92616 .58755 .92487 .63379 Metetra
.785 .731 0 r
.92487 .63379 .92616 .58755 .94653 .57936 .9457 .62544 Metetra
.687 .75 0 r
.9457 .62544 .94653 .57936 .96549 .55946 .96478 .60249 Metetra
.227 .623 0 r
.96478 .60249 .96549 .55946 .9804 .51009 .97883 .54278 Metetra
.119 .585 0 r
.38224 .65944 .39285 .65799 .40727 .72817 .39638 .73419 Metetra
.822 .635 0 r
.39638 .73419 .40727 .72817 .42364 .75886 .41273 .76686 Metetra
.914 .342 0 r
.41273 .76686 .42364 .75886 .4411 .76284 .43031 .77116 Metetra
.933 .27 0 r
.43031 .77116 .4411 .76284 .4589 .75896 .44827 .76714 Metetra
.934 .266 0 r
.44827 .76714 .4589 .75896 .47684 .75394 .46638 .76195 Metetra
.933 .27 0 r
.46638 .76195 .47684 .75394 .4949 .74884 .4846 .75667 Metetra
.932 .275 0 r
.4846 .75667 .4949 .74884 .51308 .74373 .50295 .75141 Metetra
.931 .279 0 r
.50295 .75141 .51308 .74373 .53138 .73862 .52141 .74616 Metetra
.93 .283 0 r
.52141 .74616 .53138 .73862 .5498 .73349 .54 .74091 Metetra
.929 .286 0 r
.54 .74091 .5498 .73349 .56834 .72836 .55871 .73567 Metetra
.928 .288 0 r
.55871 .73567 .56834 .72836 .587 .72322 .57754 .73042 Metetra
.928 .29 0 r
.57754 .73042 .587 .72322 .60579 .71807 .59651 .72519 Metetra
.927 .292 0 r
.59651 .72519 .60579 .71807 .62471 .71291 .6156 .71995 Metetra
.927 .293 0 r
.6156 .71995 .62471 .71291 .64375 .70774 .63482 .71472 Metetra
.927 .294 0 r
.63482 .71472 .64375 .70774 .66293 .70256 .65418 .70949 Metetra
.927 .294 0 r
.65418 .70949 .66293 .70256 .68224 .69736 .67367 .70426 Metetra
.927 .294 0 r
.67367 .70426 .68224 .69736 .70168 .69216 .6933 .69902 Metetra
.927 .294 0 r
.6933 .69902 .70168 .69216 .72125 .68693 .71307 .69379 Metetra
.927 .293 0 r
.71307 .69379 .72125 .68693 .74097 .6817 .73297 .68856 Metetra
.928 .291 0 r
.73297 .68856 .74097 .6817 .76082 .67646 .75303 .68332 Metetra
.928 .289 0 r
.75303 .68332 .76082 .67646 .78082 .6712 .77322 .67809 Metetra
.929 .287 0 r
.77322 .67809 .78082 .6712 .80095 .66593 .79357 .67286 Metetra
.929 .284 0 r
.79357 .67286 .80095 .66593 .82124 .66064 .81407 .66763 Metetra
.93 .281 0 r
.81407 .66763 .82124 .66064 .84167 .65535 .83471 .6624 Metetra
.931 .278 0 r
.83471 .6624 .84167 .65535 .86225 .65004 .85552 .65717 Metetra
.932 .273 0 r
.85552 .65717 .86225 .65004 .88298 .64473 .87648 .65196 Metetra
.934 .269 0 r
.87648 .65196 .88298 .64473 .90386 .6394 .8976 .64674 Metetra
.934 .265 0 r
.8976 .64674 .90386 .6394 .92487 .63379 .91885 .64126 Metetra
.93 .283 0 r
.91885 .64126 .92487 .63379 .9457 .62544 .93992 .63288 Metetra
.891 .421 0 r
.93992 .63288 .9457 .62544 .96478 .60249 .95916 .60903 Metetra
.687 .75 0 r
.95916 .60903 .96478 .60249 .97883 .54278 .97311 .54604 Metetra
.209 .617 0 r
.37182 .65232 .38224 .65944 .39638 .73419 .38577 .72773 Metetra
.859 .525 0 r
.38577 .72773 .39638 .73419 .41273 .76686 .40208 .76054 Metetra
.953 .196 0 r
.40208 .76054 .41273 .76686 .43031 .77116 .41971 .76477 Metetra
.972 .117 0 r
.41971 .76477 .43031 .77116 .44827 .76714 .43776 .76066 Metetra
.973 .114 0 r
.43776 .76066 .44827 .76714 .46638 .76195 .45596 .75538 Metetra
.971 .12 0 r
.45596 .75538 .46638 .76195 .4846 .75667 .47428 .75003 Metetra
.97 .127 0 r
.47428 .75003 .4846 .75667 .50295 .75141 .49272 .74469 Metetra
.969 .132 0 r
.49272 .74469 .50295 .75141 .52141 .74616 .51128 .73936 Metetra
.967 .137 0 r
.51128 .73936 .52141 .74616 .54 .74091 .52996 .73404 Metetra
.966 .141 0 r
.52996 .73404 .54 .74091 .55871 .73567 .54877 .72872 Metetra
.966 .144 0 r
.54877 .72872 .55871 .73567 .57754 .73042 .5677 .7234 Metetra
.965 .147 0 r
.5677 .7234 .57754 .73042 .59651 .72519 .58676 .7181 Metetra
.964 .149 0 r
.58676 .7181 .59651 .72519 .6156 .71995 .60596 .7128 Metetra
.964 .151 0 r
.60596 .7128 .6156 .71995 .63482 .71472 .62528 .7075 Metetra
.964 .152 0 r
.62528 .7075 .63482 .71472 .65418 .70949 .64474 .7022 Metetra
.963 .152 0 r
.64474 .7022 .65418 .70949 .67367 .70426 .66434 .6969 Metetra
.964 .152 0 r
.66434 .6969 .67367 .70426 .6933 .69902 .68408 .69161 Metetra
.964 .152 0 r
.68408 .69161 .6933 .69902 .71307 .69379 .70395 .68631 Metetra
.964 .15 0 r
.70395 .68631 .71307 .69379 .73297 .68856 .72397 .68102 Metetra
.964 .148 0 r
.72397 .68102 .73297 .68856 .75303 .68332 .74414 .67573 Metetra
.965 .146 0 r
.74414 .67573 .75303 .68332 .77322 .67809 .76445 .67044 Metetra
.966 .143 0 r
.76445 .67044 .77322 .67809 .79357 .67286 .78491 .66516 Metetra
.967 .139 0 r
.78491 .66516 .79357 .67286 .81407 .66763 .80553 .65988 Metetra
.968 .135 0 r
.80553 .65988 .81407 .66763 .83471 .6624 .8263 .6546 Metetra
.969 .13 0 r
.8263 .6546 .83471 .6624 .85552 .65717 .84723 .64933 Metetra
.97 .124 0 r
.84723 .64933 .85552 .65717 .87648 .65196 .86831 .64407 Metetra
.972 .118 0 r
.86831 .64407 .87648 .65196 .8976 .64674 .88957 .63881 Metetra
.973 .113 0 r
.88957 .63881 .8976 .64674 .91885 .64126 .91095 .63328 Metetra
.969 .131 0 r
.91095 .63328 .91885 .64126 .93992 .63288 .93216 .62487 Metetra
.93 .283 0 r
.93216 .62487 .93992 .63288 .95916 .60903 .95156 .60091 Metetra
.785 .731 0 r
.95156 .60091 .95916 .60903 .97311 .54604 .96571 .53746 Metetra
.225 .622 0 r
.36134 .64345 .37182 .65232 .38577 .72773 .37511 .71882 Metetra
.864 .509 0 r
.37511 .71882 .38577 .72773 .40208 .76054 .39138 .75145 Metetra
.957 .177 0 r
.39138 .75145 .40208 .76054 .41971 .76477 .40906 .75555 Metetra
.977 .099 0 r
.40906 .75555 .41971 .76477 .43776 .76066 .42718 .75138 Metetra
.977 .096 0 r
.42718 .75138 .43776 .76066 .45596 .75538 .44546 .74604 Metetra
.976 .102 0 r
.44546 .74604 .45596 .75538 .47428 .75003 .46386 .74063 Metetra
.974 .109 0 r
.46386 .74063 .47428 .75003 .49272 .74469 .48238 .73523 Metetra
.973 .114 0 r
.48238 .73523 .49272 .74469 .51128 .73936 .50102 .72984 Metetra
.972 .119 0 r
.50102 .72984 .51128 .73936 .52996 .73404 .51978 .72446 Metetra
.971 .123 0 r
.51978 .72446 .52996 .73404 .54877 .72872 .53867 .71908 Metetra
.97 .127 0 r
.53867 .71908 .54877 .72872 .5677 .7234 .55769 .7137 Metetra
.969 .13 0 r
.55769 .7137 .5677 .7234 .58676 .7181 .57684 .70833 Metetra
.969 .132 0 r
.57684 .70833 .58676 .7181 .60596 .7128 .59612 .70296 Metetra
.968 .134 0 r
.59612 .70296 .60596 .7128 .62528 .7075 .61554 .6976 Metetra
.968 .135 0 r
.61554 .6976 .62528 .7075 .64474 .7022 .63509 .69223 Metetra
.968 .135 0 r
.63509 .69223 .64474 .7022 .66434 .6969 .65478 .68686 Metetra
.968 .135 0 r
.65478 .68686 .66434 .6969 .68408 .69161 .67461 .6815 Metetra
.968 .135 0 r
.67461 .6815 .68408 .69161 .70395 .68631 .69458 .67613 Metetra
.968 .133 0 r
.69458 .67613 .70395 .68631 .72397 .68102 .7147 .67077 Metetra
.969 .131 0 r
.7147 .67077 .72397 .68102 .74414 .67573 .73496 .6654 Metetra
.969 .129 0 r
.73496 .6654 .74414 .67573 .76445 .67044 .75537 .66004 Metetra
.97 .126 0 r
.75537 .66004 .76445 .67044 .78491 .66516 .77594 .65468 Metetra
.971 .122 0 r
.77594 .65468 .78491 .66516 .80553 .65988 .79665 .64932 Metetra
.972 .117 0 r
.79665 .64932 .80553 .65988 .8263 .6546 .81753 .64397 Metetra
.973 .112 0 r
.81753 .64397 .8263 .6546 .84723 .64933 .83856 .63862 Metetra
.975 .106 0 r
.83856 .63862 .84723 .64933 .86831 .64407 .85976 .63327 Metetra
.976 .1 0 r
.85976 .63327 .86831 .64407 .88957 .63881 .88112 .62793 Metetra
.978 .094 0 r
.88112 .62793 .88957 .63881 .91095 .63328 .90261 .62233 Metetra
.973 .113 0 r
.90261 .62233 .91095 .63328 .93216 .62487 .92395 .61385 Metetra
.934 .265 0 r
.92395 .61385 .93216 .62487 .95156 .60091 .94351 .58991 Metetra
.791 .718 0 r
.94351 .58991 .95156 .60091 .96571 .53746 .9579 .52649 Metetra
.228 .623 0 r
.35074 .6343 .36134 .64345 .37511 .71882 .36432 .70957 Metetra
.864 .51 0 r
.36432 .70957 .37511 .71882 .39138 .75145 .38055 .74202 Metetra
.956 .181 0 r
.38055 .74202 .39138 .75145 .40906 .75555 .39829 .74601 Metetra
.975 .104 0 r
.39829 .74601 .40906 .75555 .42718 .75138 .41648 .74177 Metetra
.976 .101 0 r
.41648 .74177 .42718 .75138 .44546 .74604 .43484 .73637 Metetra
.975 .107 0 r
.43484 .73637 .44546 .74604 .46386 .74063 .45331 .7309 Metetra
.973 .114 0 r
.45331 .7309 .46386 .74063 .48238 .73523 .47191 .72545 Metetra
.972 .119 0 r
.47191 .72545 .48238 .73523 .50102 .72984 .49063 .72 Metetra
.971 .124 0 r
.49063 .72 .50102 .72984 .51978 .72446 .50948 .71455 Metetra
.97 .128 0 r
.50948 .71455 .51978 .72446 .53867 .71908 .52845 .70911 Metetra
.969 .132 0 r
.52845 .70911 .53867 .71908 .55769 .7137 .54756 .70367 Metetra
.968 .134 0 r
.54756 .70367 .55769 .7137 .57684 .70833 .56679 .69823 Metetra
.967 .137 0 r
.56679 .69823 .57684 .70833 .59612 .70296 .58616 .6928 Metetra
.967 .138 0 r
.58616 .6928 .59612 .70296 .61554 .6976 .60567 .68736 Metetra
.967 .139 0 r
.60567 .68736 .61554 .6976 .63509 .69223 .62531 .68193 Metetra
.967 .14 0 r
.62531 .68193 .63509 .69223 .65478 .68686 .64509 .67649 Metetra
.967 .14 0 r
.64509 .67649 .65478 .68686 .67461 .6815 .66501 .67105 Metetra
.967 .139 0 r
.66501 .67105 .67461 .6815 .69458 .67613 .68508 .66562 Metetra
.967 .138 0 r
.68508 .66562 .69458 .67613 .7147 .67077 .70529 .66018 Metetra
.968 .136 0 r
.70529 .66018 .7147 .67077 .73496 .6654 .72565 .65474 Metetra
.968 .133 0 r
.72565 .65474 .73496 .6654 .75537 .66004 .74616 .64929 Metetra
.969 .13 0 r
.74616 .64929 .75537 .66004 .77594 .65468 .76683 .64386 Metetra
.97 .127 0 r
.76683 .64386 .77594 .65468 .79665 .64932 .78765 .63842 Metetra
.971 .122 0 r
.78765 .63842 .79665 .64932 .81753 .64397 .80863 .63298 Metetra
.972 .117 0 r
.80863 .63298 .81753 .64397 .83856 .63862 .82976 .62755 Metetra
.974 .111 0 r
.82976 .62755 .83856 .63862 .85976 .63327 .85107 .62212 Metetra
.975 .105 0 r
.85107 .62212 .85976 .63327 .88112 .62793 .87253 .61669 Metetra
.976 .1 0 r
.87253 .61669 .88112 .62793 .90261 .62233 .89414 .611 Metetra
.972 .118 0 r
.89414 .611 .90261 .62233 .92395 .61385 .91559 .60246 Metetra
.934 .269 0 r
.91559 .60246 .92395 .61385 .94351 .58991 .93532 .57853 Metetra
.791 .717 0 r
.93532 .57853 .94351 .58991 .9579 .52649 .94995 .51515 Metetra
.228 .623 0 r
.34001 .625 .35074 .6343 .36432 .70957 .35341 .70021 Metetra
.863 .512 0 r
.35341 .70021 .36432 .70957 .38055 .74202 .3696 .7325 Metetra
.955 .187 0 r
.3696 .7325 .38055 .74202 .39829 .74601 .38738 .73638 Metetra
.974 .111 0 r
.38738 .73638 .39829 .74601 .41648 .74177 .40565 .73207 Metetra
.975 .107 0 r
.40565 .73207 .41648 .74177 .43484 .73637 .42408 .72662 Metetra
.973 .114 0 r
.42408 .72662 .43484 .73637 .45331 .7309 .44263 .72109 Metetra
.972 .12 0 r
.44263 .72109 .45331 .7309 .47191 .72545 .46131 .71558 Metetra
.97 .125 0 r
.46131 .71558 .47191 .72545 .49063 .72 .48012 .71006 Metetra
.969 .13 0 r
.48012 .71006 .49063 .72 .50948 .71455 .49905 .70456 Metetra
.968 .134 0 r
.49905 .70456 .50948 .71455 .52845 .70911 .51811 .69905 Metetra
.967 .137 0 r
.51811 .69905 .52845 .70911 .54756 .70367 .5373 .69354 Metetra
.967 .14 0 r
.5373 .69354 .54756 .70367 .56679 .69823 .55662 .68803 Metetra
.966 .142 0 r
.55662 .68803 .56679 .69823 .58616 .6928 .57607 .68253 Metetra
.966 .144 0 r
.57607 .68253 .58616 .6928 .60567 .68736 .59567 .67703 Metetra
.965 .145 0 r
.59567 .67703 .60567 .68736 .62531 .68193 .6154 .67153 Metetra
.965 .146 0 r
.6154 .67153 .62531 .68193 .64509 .67649 .63528 .66602 Metetra
.965 .145 0 r
.63528 .66602 .64509 .67649 .66501 .67105 .65529 .66051 Metetra
.965 .145 0 r
.65529 .66051 .66501 .67105 .68508 .66562 .67545 .65499 Metetra
.966 .143 0 r
.67545 .65499 .68508 .66562 .70529 .66018 .69576 .64948 Metetra
.966 .142 0 r
.69576 .64948 .70529 .66018 .72565 .65474 .71622 .64396 Metetra
.967 .139 0 r
.71622 .64396 .72565 .65474 .74616 .64929 .73683 .63844 Metetra
.968 .136 0 r
.73683 .63844 .74616 .64929 .76683 .64386 .7576 .63292 Metetra
.968 .133 0 r
.7576 .63292 .76683 .64386 .78765 .63842 .77852 .6274 Metetra
.969 .128 0 r
.77852 .6274 .78765 .63842 .80863 .63298 .79961 .62188 Metetra
.971 .123 0 r
.79961 .62188 .80863 .63298 .82976 .62755 .82085 .61637 Metetra
.972 .118 0 r
.82085 .61637 .82976 .62755 .85107 .62212 .84226 .61086 Metetra
.974 .111 0 r
.84226 .61086 .85107 .62212 .87253 .61669 .86384 .60534 Metetra
.975 .106 0 r
.86384 .60534 .87253 .61669 .89414 .611 .88556 .59956 Metetra
.97 .124 0 r
.88556 .59956 .89414 .611 .91559 .60246 .90713 .59095 Metetra
.932 .273 0 r
.90713 .59095 .91559 .60246 .93532 .57853 .92702 .56701 Metetra
.79 .719 0 r
.92702 .56701 .93532 .57853 .94995 .51515 .9419 .50365 Metetra
.229 .623 0 r
.32916 .61557 .34001 .625 .35341 .70021 .34236 .69075 Metetra
.862 .515 0 r
.34236 .69075 .35341 .70021 .3696 .7325 .3585 .7229 Metetra
.954 .192 0 r
.3585 .7229 .3696 .7325 .38738 .73638 .37633 .72668 Metetra
.972 .116 0 r
.37633 .72668 .38738 .73638 .40565 .73207 .39467 .72231 Metetra
.973 .113 0 r
.39467 .72231 .40565 .73207 .42408 .72662 .41318 .71679 Metetra
.972 .119 0 r
.41318 .71679 .42408 .72662 .44263 .72109 .43182 .71121 Metetra
.97 .125 0 r
.43182 .71121 .44263 .72109 .46131 .71558 .45058 .70562 Metetra
.969 .131 0 r
.45058 .70562 .46131 .71558 .48012 .71006 .46947 .70005 Metetra
.968 .135 0 r
.46947 .70005 .48012 .71006 .49905 .70456 .48848 .69447 Metetra
.967 .139 0 r
.48848 .69447 .49905 .70456 .51811 .69905 .50762 .68891 Metetra
.966 .143 0 r
.50762 .68891 .51811 .69905 .5373 .69354 .5269 .68333 Metetra
.965 .146 0 r
.5269 .68333 .5373 .69354 .55662 .68803 .54631 .67776 Metetra
.965 .148 0 r
.54631 .67776 .55662 .68803 .57607 .68253 .56586 .67219 Metetra
.964 .149 0 r
.56586 .67219 .57607 .68253 .59567 .67703 .58554 .66662 Metetra
.964 .15 0 r
.58554 .66662 .59567 .67703 .6154 .67153 .60537 .66104 Metetra
.964 .151 0 r
.60537 .66104 .6154 .67153 .63528 .66602 .62533 .65546 Metetra
.964 .151 0 r
.62533 .65546 .63528 .66602 .65529 .66051 .64545 .64987 Metetra
.964 .15 0 r
.64545 .64987 .65529 .66051 .67545 .65499 .66571 .64428 Metetra
.964 .149 0 r
.66571 .64428 .67545 .65499 .69576 .64948 .68611 .63869 Metetra
.965 .147 0 r
.68611 .63869 .69576 .64948 .71622 .64396 .70667 .63309 Metetra
.965 .145 0 r
.70667 .63309 .71622 .64396 .73683 .63844 .72738 .62749 Metetra
.966 .142 0 r
.72738 .62749 .73683 .63844 .7576 .63292 .74825 .62188 Metetra
.967 .138 0 r
.74825 .62188 .7576 .63292 .77852 .6274 .76928 .61628 Metetra
.968 .134 0 r
.76928 .61628 .77852 .6274 .79961 .62188 .79047 .61068 Metetra
.969 .129 0 r
.79047 .61068 .79961 .62188 .82085 .61637 .81182 .60508 Metetra
.971 .123 0 r
.81182 .60508 .82085 .61637 .84226 .61086 .83334 .59949 Metetra
.972 .117 0 r
.83334 .59949 .84226 .61086 .86384 .60534 .85503 .59388 Metetra
.973 .112 0 r
.85503 .59388 .86384 .60534 .88556 .59956 .87687 .58801 Metetra
.969 .13 0 r
.87687 .58801 .88556 .59956 .90713 .59095 .89856 .57933 Metetra
.931 .278 0 r
.89856 .57933 .90713 .59095 .92702 .56701 .91861 .55537 Metetra
.79 .719 0 r
.91861 .55537 .92702 .56701 .9419 .50365 .93373 .49198 Metetra
.23 .624 0 r
.31817 .606 .32916 .61557 .34236 .69075 .33118 .68117 Metetra
.862 .517 0 r
.33118 .68117 .34236 .69075 .3585 .7229 .34727 .71321 Metetra
.952 .196 0 r
.34727 .71321 .3585 .7229 .37633 .72668 .36515 .7169 Metetra
.971 .122 0 r
.36515 .7169 .37633 .72668 .39467 .72231 .38356 .71246 Metetra
.972 .119 0 r
.38356 .71246 .39467 .72231 .41318 .71679 .40215 .70689 Metetra
.97 .124 0 r
.40215 .70689 .41318 .71679 .43182 .71121 .42087 .70123 Metetra
.969 .13 0 r
.42087 .70123 .43182 .71121 .45058 .70562 .43971 .69559 Metetra
.968 .136 0 r
.43971 .69559 .45058 .70562 .46947 .70005 .45868 .68995 Metetra
.967 .14 0 r
.45868 .68995 .46947 .70005 .48848 .69447 .47778 .68431 Metetra
.966 .144 0 r
.47778 .68431 .48848 .69447 .50762 .68891 .49701 .67868 Metetra
.965 .147 0 r
.49701 .67868 .50762 .68891 .5269 .68333 .51637 .67303 Metetra
.964 .15 0 r
.51637 .67303 .5269 .68333 .54631 .67776 .53587 .66739 Metetra
.964 .152 0 r
.53587 .66739 .54631 .67776 .56586 .67219 .55551 .66175 Metetra
.963 .154 0 r
.55551 .66175 .56586 .67219 .58554 .66662 .57529 .6561 Metetra
.963 .155 0 r
.57529 .6561 .58554 .66662 .60537 .66104 .5952 .65045 Metetra
.963 .155 0 r
.5952 .65045 .60537 .66104 .62533 .65546 .61527 .6448 Metetra
.963 .155 0 r
.61527 .6448 .62533 .65546 .64545 .64987 .63547 .63914 Metetra
.963 .154 0 r
.63547 .63914 .64545 .64987 .66571 .64428 .65583 .63347 Metetra
.963 .153 0 r
.65583 .63347 .66571 .64428 .68611 .63869 .67634 .6278 Metetra
.964 .151 0 r
.67634 .6278 .68611 .63869 .70667 .63309 .697 .62212 Metetra
.964 .149 0 r
.697 .62212 .70667 .63309 .72738 .62749 .71781 .61643 Metetra
.965 .146 0 r
.71781 .61643 .72738 .62749 .74825 .62188 .73878 .61075 Metetra
.966 .143 0 r
.73878 .61075 .74825 .62188 .76928 .61628 .75992 .60506 Metetra
.967 .139 0 r
.75992 .60506 .76928 .61628 .79047 .61068 .78121 .59937 Metetra
.968 .134 0 r
.78121 .59937 .79047 .61068 .81182 .60508 .80267 .59369 Metetra
.969 .128 0 r
.80267 .59369 .81182 .60508 .83334 .59949 .82431 .58801 Metetra
.971 .122 0 r
.82431 .58801 .83334 .59949 .85503 .59388 .84611 .58231 Metetra
.972 .117 0 r
.84611 .58231 .85503 .59388 .87687 .58801 .86806 .57636 Metetra
.968 .135 0 r
.86806 .57636 .87687 .58801 .89856 .57933 .88988 .5676 Metetra
.93 .281 0 r
.88988 .5676 .89856 .57933 .91861 .55537 .91009 .54359 Metetra
.789 .72 0 r
.91009 .54359 .91861 .55537 .93373 .49198 .92546 .48015 Metetra
.23 .624 0 r
.30705 .5963 .31817 .606 .33118 .68117 .31985 .67149 Metetra
.861 .518 0 r
.31985 .67149 .33118 .68117 .34727 .71321 .33589 .70344 Metetra
.951 .2 0 r
.33589 .70344 .34727 .71321 .36515 .7169 .35382 .70704 Metetra
.97 .126 0 r
.35382 .70704 .36515 .7169 .38356 .71246 .37231 .70254 Metetra
.971 .123 0 r
.37231 .70254 .38356 .71246 .40215 .70689 .39098 .6969 Metetra
.969 .129 0 r
.39098 .6969 .40215 .70689 .42087 .70123 .40978 .69118 Metetra
.968 .135 0 r
.40978 .69118 .42087 .70123 .43971 .69559 .4287 .68547 Metetra
.967 .14 0 r
.4287 .68547 .43971 .69559 .45868 .68995 .44775 .67976 Metetra
.966 .144 0 r
.44775 .67976 .45868 .68995 .47778 .68431 .46694 .67406 Metetra
.965 .148 0 r
.46694 .67406 .47778 .68431 .49701 .67868 .48626 .66835 Metetra
.964 .151 0 r
.48626 .66835 .49701 .67868 .51637 .67303 .50571 .66263 Metetra
.963 .154 0 r
.50571 .66263 .51637 .67303 .53587 .66739 .5253 .65693 Metetra
.963 .156 0 r
.5253 .65693 .53587 .66739 .55551 .66175 .54502 .65121 Metetra
.962 .157 0 r
.54502 .65121 .55551 .66175 .57529 .6561 .56489 .64549 Metetra
.962 .158 0 r
.56489 .64549 .57529 .6561 .5952 .65045 .58491 .63977 Metetra
.962 .159 0 r
.58491 .63977 .5952 .65045 .61527 .6448 .60506 .63404 Metetra
.962 .159 0 r
.60506 .63404 .61527 .6448 .63547 .63914 .62537 .6283 Metetra
.962 .158 0 r
.62537 .6283 .63547 .63914 .65583 .63347 .64582 .62255 Metetra
.962 .157 0 r
.64582 .62255 .65583 .63347 .67634 .6278 .66643 .6168 Metetra
.963 .155 0 r
.66643 .6168 .67634 .6278 .697 .62212 .68719 .61104 Metetra
.963 .153 0 r
.68719 .61104 .697 .62212 .71781 .61643 .70811 .60527 Metetra
.964 .15 0 r
.70811 .60527 .71781 .61643 .73878 .61075 .72919 .5995 Metetra
.965 .147 0 r
.72919 .5995 .73878 .61075 .75992 .60506 .75043 .59373 Metetra
.966 .143 0 r
.75043 .59373 .75992 .60506 .78121 .59937 .77183 .58795 Metetra
.967 .138 0 r
.77183 .58795 .78121 .59937 .80267 .59369 .79341 .58218 Metetra
.968 .133 0 r
.79341 .58218 .80267 .59369 .82431 .58801 .81515 .57641 Metetra
.97 .127 0 r
.81515 .57641 .82431 .58801 .84611 .58231 .83706 .57063 Metetra
.971 .122 0 r
.83706 .57063 .84611 .58231 .86806 .57636 .85913 .56458 Metetra
.967 .139 0 r
.85913 .56458 .86806 .57636 .88988 .5676 .88108 .55575 Metetra
.929 .284 0 r
.88108 .55575 .88988 .5676 .91009 .54359 .90146 .53168 Metetra
.789 .721 0 r
.90146 .53168 .91009 .54359 .92546 .48015 .91706 .46815 Metetra
.231 .624 0 r
.2958 .58645 .30705 .5963 .31985 .67149 .30838 .66169 Metetra
.861 .52 0 r
.30838 .66169 .31985 .67149 .33589 .70344 .32437 .69358 Metetra
.951 .203 0 r
.32437 .69358 .33589 .70344 .35382 .70704 .34234 .6971 Metetra
.969 .13 0 r
.34234 .6971 .35382 .70704 .37231 .70254 .36091 .69252 Metetra
.97 .127 0 r
.36091 .69252 .37231 .70254 .39098 .6969 .37966 .68682 Metetra
.968 .133 0 r
.37966 .68682 .39098 .6969 .40978 .69118 .39854 .68103 Metetra
.967 .138 0 r
.39854 .68103 .40978 .69118 .4287 .68547 .41755 .67525 Metetra
.966 .143 0 r
.41755 .67525 .4287 .68547 .44775 .67976 .43669 .66948 Metetra
.965 .148 0 r
.43669 .66948 .44775 .67976 .46694 .67406 .45596 .66371 Metetra
.964 .151 0 r
.45596 .66371 .46694 .67406 .48626 .66835 .47536 .65793 Metetra
.963 .155 0 r
.47536 .65793 .48626 .66835 .50571 .66263 .4949 .65214 Metetra
.962 .157 0 r
.4949 .65214 .50571 .66263 .5253 .65693 .51458 .64636 Metetra
.962 .159 0 r
.51458 .64636 .5253 .65693 .54502 .65121 .5344 .64058 Metetra
.961 .161 0 r
.5344 .64058 .54502 .65121 .56489 .64549 .55436 .63478 Metetra
.961 .162 0 r
.55436 .63478 .56489 .64549 .58491 .63977 .57447 .62898 Metetra
.961 .162 0 r
.57447 .62898 .58491 .63977 .60506 .63404 .59473 .62317 Metetra
.961 .162 0 r
.59473 .62317 .60506 .63404 .62537 .6283 .61513 .61735 Metetra
.961 .161 0 r
.61513 .61735 .62537 .6283 .64582 .62255 .63568 .61153 Metetra
.962 .16 0 r
.63568 .61153 .64582 .62255 .66643 .6168 .65639 .60569 Metetra
.962 .159 0 r
.65639 .60569 .66643 .6168 .68719 .61104 .67726 .59985 Metetra
.963 .156 0 r
.67726 .59985 .68719 .61104 .70811 .60527 .69828 .594 Metetra
.963 .154 0 r
.69828 .594 .70811 .60527 .72919 .5995 .71947 .58815 Metetra
.964 .15 0 r
.71947 .58815 .72919 .5995 .75043 .59373 .74081 .58228 Metetra
.965 .146 0 r
.74081 .58228 .75043 .59373 .77183 .58795 .76233 .57642 Metetra
.966 .142 0 r
.76233 .57642 .77183 .58795 .79341 .58218 .78401 .57055 Metetra
.968 .136 0 r
.78401 .57055 .79341 .58218 .81515 .57641 .80587 .5647 Metetra
.969 .13 0 r
.80587 .5647 .81515 .57641 .83706 .57063 .8279 .55882 Metetra
.97 .126 0 r
.8279 .55882 .83706 .57063 .85913 .56458 .85009 .55269 Metetra
.966 .143 0 r
.85009 .55269 .85913 .56458 .88108 .55575 .87216 .54377 Metetra
.929 .287 0 r
.87216 .54377 .88108 .55575 .90146 .53168 .8927 .51963 Metetra
.789 .722 0 r
.8927 .51963 .90146 .53168 .91706 .46815 .90855 .45598 Metetra
.231 .624 0 r
.2844 .57646 .2958 .58645 .30838 .66169 .29676 .65177 Metetra
.86 .521 0 r
.29676 .65177 .30838 .66169 .32437 .69358 .3127 .68362 Metetra
.95 .206 0 r
.3127 .68362 .32437 .69358 .34234 .6971 .33071 .68707 Metetra
.968 .133 0 r
.33071 .68707 .34234 .6971 .36091 .69252 .34936 .68242 Metetra
.969 .13 0 r
.34936 .68242 .36091 .69252 .37966 .68682 .36819 .67665 Metetra
.968 .136 0 r
.36819 .67665 .37966 .68682 .39854 .68103 .38715 .6708 Metetra
.966 .141 0 r
.38715 .6708 .39854 .68103 .41755 .67525 .40625 .66495 Metetra
.965 .146 0 r
.40625 .66495 .41755 .67525 .43669 .66948 .42547 .65911 Metetra
.964 .15 0 r
.42547 .65911 .43669 .66948 .45596 .66371 .44483 .65326 Metetra
.963 .154 0 r
.44483 .65326 .45596 .66371 .47536 .65793 .46432 .64741 Metetra
.962 .157 0 r
.46432 .64741 .47536 .65793 .4949 .65214 .48395 .64155 Metetra
.962 .16 0 r
.48395 .64155 .4949 .65214 .51458 .64636 .50372 .63569 Metetra
.961 .162 0 r
.50372 .63569 .51458 .64636 .5344 .64058 .52364 .62983 Metetra
.961 .163 0 r
.52364 .62983 .5344 .64058 .55436 .63478 .54369 .62396 Metetra
.961 .164 0 r
.54369 .62396 .55436 .63478 .57447 .62898 .5639 .61808 Metetra
.96 .165 0 r
.5639 .61808 .57447 .62898 .59473 .62317 .58425 .61219 Metetra
.96 .165 0 r
.58425 .61219 .59473 .62317 .61513 .61735 .60475 .6063 Metetra
.961 .164 0 r
.60475 .6063 .61513 .61735 .63568 .61153 .62541 .60039 Metetra
.961 .163 0 r
.62541 .60039 .63568 .61153 .65639 .60569 .64622 .59447 Metetra
.961 .161 0 r
.64622 .59447 .65639 .60569 .67726 .59985 .66719 .58855 Metetra
.962 .159 0 r
.66719 .58855 .67726 .59985 .69828 .594 .68832 .58261 Metetra
.963 .156 0 r
.68832 .58261 .69828 .594 .71947 .58815 .70961 .57667 Metetra
.963 .153 0 r
.70961 .57667 .71947 .58815 .74081 .58228 .73107 .57072 Metetra
.964 .149 0 r
.73107 .57072 .74081 .58228 .76233 .57642 .75269 .56477 Metetra
.965 .145 0 r
.75269 .56477 .76233 .57642 .78401 .57055 .77449 .55881 Metetra
.967 .139 0 r
.77449 .55881 .78401 .57055 .80587 .5647 .79646 .55286 Metetra
.968 .133 0 r
.79646 .55286 .80587 .5647 .8279 .55882 .81861 .5469 Metetra
.969 .129 0 r
.81861 .5469 .8279 .55882 .85009 .55269 .84092 .54067 Metetra
.965 .146 0 r
.84092 .54067 .85009 .55269 .87216 .54377 .86312 .53166 Metetra
.928 .289 0 r
.86312 .53166 .87216 .54377 .8927 .51963 .88383 .50743 Metetra
.789 .722 0 r
.88383 .50743 .8927 .51963 .90855 .45598 .89992 .44363 Metetra
.232 .624 0 r
.27287 .56633 .2844 .57646 .29676 .65177 .285 .64174 Metetra
.86 .522 0 r
.285 .64174 .29676 .65177 .3127 .68362 .30087 .67356 Metetra
.949 .208 0 r
.30087 .67356 .3127 .68362 .33071 .68707 .31894 .67695 Metetra
.968 .135 0 r
.31894 .67695 .33071 .68707 .34936 .68242 .33766 .67223 Metetra
.968 .132 0 r
.33766 .67223 .34936 .68242 .36819 .67665 .35657 .66639 Metetra
.967 .138 0 r
.35657 .66639 .36819 .67665 .38715 .6708 .37562 .66047 Metetra
.966 .144 0 r
.37562 .66047 .38715 .6708 .40625 .66495 .3948 .65455 Metetra
.964 .148 0 r
.3948 .65455 .40625 .66495 .42547 .65911 .41411 .64863 Metetra
.963 .153 0 r
.41411 .64863 .42547 .65911 .44483 .65326 .43355 .64271 Metetra
.963 .156 0 r
.43355 .64271 .44483 .65326 .46432 .64741 .45314 .63679 Metetra
.962 .16 0 r
.45314 .63679 .46432 .64741 .48395 .64155 .47286 .63085 Metetra
.961 .162 0 r
.47286 .63085 .48395 .64155 .50372 .63569 .49272 .62492 Metetra
.961 .164 0 r
.49272 .62492 .50372 .63569 .52364 .62983 .51273 .61898 Metetra
.96 .166 0 r
.51273 .61898 .52364 .62983 .54369 .62396 .53288 .61303 Metetra
.96 .166 0 r
.53288 .61303 .54369 .62396 .5639 .61808 .55318 .60707 Metetra
.96 .167 0 r
.55318 .60707 .5639 .61808 .58425 .61219 .57363 .6011 Metetra
.96 .167 0 r
.57363 .6011 .58425 .61219 .60475 .6063 .59424 .59512 Metetra
.96 .166 0 r
.59424 .59512 .60475 .6063 .62541 .60039 .61499 .58913 Metetra
.96 .165 0 r
.61499 .58913 .62541 .60039 .64622 .59447 .63591 .58313 Metetra
.961 .163 0 r
.63591 .58313 .64622 .59447 .66719 .58855 .65698 .57712 Metetra
.961 .161 0 r
.65698 .57712 .66719 .58855 .68832 .58261 .67822 .5711 Metetra
.962 .159 0 r
.67822 .5711 .68832 .58261 .70961 .57667 .69962 .56507 Metetra
.963 .155 0 r
.69962 .56507 .70961 .57667 .73107 .57072 .72119 .55904 Metetra
.964 .151 0 r
.72119 .55904 .73107 .57072 .75269 .56477 .74293 .55299 Metetra
.965 .147 0 r
.74293 .55299 .75269 .56477 .77449 .55881 .76484 .54694 Metetra
.966 .142 0 r
.76484 .54694 .77449 .55881 .79646 .55286 .78693 .5409 Metetra
.968 .136 0 r
.78693 .5409 .79646 .55286 .81861 .5469 .8092 .53484 Metetra
.969 .131 0 r
.8092 .53484 .81861 .5469 .84092 .54067 .83162 .52852 Metetra
.964 .148 0 r
.83162 .52852 .84092 .54067 .86312 .53166 .85395 .51942 Metetra
.928 .291 0 r
.85395 .51942 .86312 .53166 .88383 .50743 .87483 .49508 Metetra
.789 .723 0 r
.87483 .49508 .88383 .50743 .89992 .44363 .89117 .43111 Metetra
.232 .624 0 r
.26119 .55604 .27287 .56633 .285 .64174 .27308 .63158 Metetra
.86 .523 0 r
.27308 .63158 .285 .64174 .30087 .67356 .28889 .66341 Metetra
.949 .21 0 r
.28889 .66341 .30087 .67356 .31894 .67695 .307 .66673 Metetra
.967 .137 0 r
.307 .66673 .31894 .67695 .33766 .67223 .3258 .66195 Metetra
.968 .134 0 r
.3258 .66195 .33766 .67223 .35657 .66639 .3448 .65603 Metetra
.967 .14 0 r
.3448 .65603 .35657 .66639 .37562 .66047 .36393 .65004 Metetra
.965 .145 0 r
.36393 .65004 .37562 .66047 .3948 .65455 .38319 .64405 Metetra
.964 .15 0 r
.38319 .64405 .3948 .65455 .41411 .64863 .40259 .63806 Metetra
.963 .154 0 r
.40259 .63806 .41411 .64863 .43355 .64271 .42213 .63206 Metetra
.962 .158 0 r
.42213 .63206 .43355 .64271 .45314 .63679 .4418 .62606 Metetra
.961 .161 0 r
.4418 .62606 .45314 .63679 .47286 .63085 .46161 .62005 Metetra
.961 .164 0 r
.46161 .62005 .47286 .63085 .49272 .62492 .48157 .61404 Metetra
.96 .166 0 r
.48157 .61404 .49272 .62492 .51273 .61898 .50167 .60802 Metetra
.96 .167 0 r
.50167 .60802 .51273 .61898 .53288 .61303 .52192 .60199 Metetra
.96 .168 0 r
.52192 .60199 .53288 .61303 .55318 .60707 .54232 .59595 Metetra
.959 .168 0 r
.54232 .59595 .55318 .60707 .57363 .6011 .56287 .58989 Metetra
.96 .168 0 r
.56287 .58989 .57363 .6011 .59424 .59512 .58357 .58383 Metetra
.96 .168 0 r
.58357 .58383 .59424 .59512 .61499 .58913 .60444 .57776 Metetra
.96 .167 0 r
.60444 .57776 .61499 .58913 .63591 .58313 .62545 .57167 Metetra
.96 .165 0 r
.62545 .57167 .63591 .58313 .65698 .57712 .64664 .56558 Metetra
.961 .163 0 r
.64664 .56558 .65698 .57712 .67822 .5711 .66798 .55947 Metetra
.962 .16 0 r
.66798 .55947 .67822 .5711 .69962 .56507 .68949 .55335 Metetra
.962 .157 0 r
.68949 .55335 .69962 .56507 .72119 .55904 .71117 .54723 Metetra
.963 .153 0 r
.71117 .54723 .72119 .55904 .74293 .55299 .73303 .54109 Metetra
.964 .149 0 r
.73303 .54109 .74293 .55299 .76484 .54694 .75505 .53495 Metetra
.966 .143 0 r
.75505 .53495 .76484 .54694 .78693 .5409 .77726 .52882 Metetra
.967 .138 0 r
.77726 .52882 .78693 .5409 .8092 .53484 .79965 .52266 Metetra
.968 .133 0 r
.79965 .52266 .8092 .53484 .83162 .52852 .8222 .51624 Metetra
.964 .15 0 r
.8222 .51624 .83162 .52852 .85395 .51942 .84466 .50704 Metetra
.927 .293 0 r
.84466 .50704 .85395 .51942 .87483 .49508 .8657 .48258 Metetra
.788 .723 0 r
.8657 .48258 .87483 .49508 .89117 .43111 .88229 .4184 Metetra
.232 .624 0 r
.24937 .54561 .26119 .55604 .27308 .63158 .26101 .62131 Metetra
.86 .523 0 r
.26101 .62131 .27308 .63158 .28889 .66341 .27675 .65315 Metetra
.949 .211 0 r
.27675 .65315 .28889 .66341 .307 .66673 .29491 .65642 Metetra
.967 .139 0 r
.29491 .65642 .307 .66673 .3258 .66195 .31379 .65157 Metetra
.968 .136 0 r
.31379 .65157 .3258 .66195 .3448 .65603 .33287 .64558 Metetra
.966 .141 0 r
.33287 .64558 .3448 .65603 .36393 .65004 .35208 .63951 Metetra
.965 .147 0 r
.35208 .63951 .36393 .65004 .38319 .64405 .37144 .63344 Metetra
.964 .151 0 r
.37144 .63344 .38319 .64405 .40259 .63806 .39092 .62737 Metetra
.963 .156 0 r
.39092 .62737 .40259 .63806 .42213 .63206 .41055 .6213 Metetra
.962 .159 0 r
.41055 .6213 .42213 .63206 .4418 .62606 .43031 .61522 Metetra
.961 .162 0 r
.43031 .61522 .4418 .62606 .46161 .62005 .45022 .60913 Metetra
.96 .165 0 r
.45022 .60913 .46161 .62005 .48157 .61404 .47027 .60304 Metetra
.96 .167 0 r
.47027 .60304 .48157 .61404 .50167 .60802 .49047 .59694 Metetra
.96 .168 0 r
.49047 .59694 .50167 .60802 .52192 .60199 .51081 .59082 Metetra
.959 .169 0 r
.51081 .59082 .52192 .60199 .54232 .59595 .53131 .5847 Metetra
.959 .17 0 r
.53131 .5847 .54232 .59595 .56287 .58989 .55196 .57857 Metetra
.959 .169 0 r
.55196 .57857 .56287 .58989 .58357 .58383 .57277 .57242 Metetra
.959 .169 0 r
.57277 .57242 .58357 .58383 .60444 .57776 .59373 .56626 Metetra
.96 .168 0 r
.59373 .56626 .60444 .57776 .62545 .57167 .61486 .56009 Metetra
.96 .166 0 r
.61486 .56009 .62545 .57167 .64664 .56558 .63615 .5539 Metetra
.961 .164 0 r
.63615 .5539 .64664 .56558 .66798 .55947 .6576 .54771 Metetra
.961 .161 0 r
.6576 .54771 .66798 .55947 .68949 .55335 .67922 .5415 Metetra
.962 .158 0 r
.67922 .5415 .68949 .55335 .71117 .54723 .70102 .53528 Metetra
.963 .154 0 r
.70102 .53528 .71117 .54723 .73303 .54109 .72299 .52906 Metetra
.964 .15 0 r
.72299 .52906 .73303 .54109 .75505 .53495 .74513 .52282 Metetra
.965 .145 0 r
.74513 .52282 .75505 .53495 .77726 .52882 .76746 .51659 Metetra
.967 .139 0 r
.76746 .51659 .77726 .52882 .79965 .52266 .78997 .51034 Metetra
.968 .135 0 r
.78997 .51034 .79965 .52266 .8222 .51624 .81264 .50383 Metetra
.964 .152 0 r
.81264 .50383 .8222 .51624 .84466 .50704 .83524 .49452 Metetra
.927 .294 0 r
.83524 .49452 .84466 .50704 .8657 .48258 .85644 .46993 Metetra
.788 .723 0 r
.85644 .46993 .8657 .48258 .88229 .4184 .87329 .4055 Metetra
.232 .624 0 r
.2374 .53503 .24937 .54561 .26101 .62131 .24878 .6109 Metetra
.859 .524 0 r
.24878 .6109 .26101 .62131 .27675 .65315 .26445 .64279 Metetra
.948 .212 0 r
.26445 .64279 .27675 .65315 .29491 .65642 .28265 .64601 Metetra
.967 .139 0 r
.28265 .64601 .29491 .65642 .31379 .65157 .30161 .64108 Metetra
.967 .136 0 r
.30161 .64108 .31379 .65157 .33287 .64558 .32077 .63502 Metetra
.966 .142 0 r
.32077 .63502 .33287 .64558 .35208 .63951 .34008 .62887 Metetra
.965 .147 0 r
.34008 .62887 .35208 .63951 .37144 .63344 .35952 .62273 Metetra
.964 .152 0 r
.35952 .62273 .37144 .63344 .39092 .62737 .37909 .61658 Metetra
.963 .156 0 r
.37909 .61658 .39092 .62737 .41055 .6213 .39881 .61043 Metetra
.962 .16 0 r
.39881 .61043 .41055 .6213 .43031 .61522 .41866 .60427 Metetra
.961 .163 0 r
.41866 .60427 .43031 .61522 .45022 .60913 .43866 .5981 Metetra
.96 .165 0 r
.43866 .5981 .45022 .60913 .47027 .60304 .45881 .59192 Metetra
.96 .167 0 r
.45881 .59192 .47027 .60304 .49047 .59694 .4791 .58574 Metetra
.959 .169 0 r
.4791 .58574 .49047 .59694 .51081 .59082 .49955 .57954 Metetra
.959 .17 0 r
.49955 .57954 .51081 .59082 .53131 .5847 .52014 .57333 Metetra
.959 .17 0 r
.52014 .57333 .53131 .5847 .55196 .57857 .5409 .56711 Metetra
.959 .17 0 r
.5409 .56711 .55196 .57857 .57277 .57242 .56181 .56088 Metetra
.959 .169 0 r
.56181 .56088 .57277 .57242 .59373 .56626 .58288 .55463 Metetra
.96 .168 0 r
.58288 .55463 .59373 .56626 .61486 .56009 .60411 .54837 Metetra
.96 .167 0 r
.60411 .54837 .61486 .56009 .63615 .5539 .62551 .5421 Metetra
.96 .165 0 r
.62551 .5421 .63615 .5539 .6576 .54771 .64707 .53581 Metetra
.961 .162 0 r
.64707 .53581 .6576 .54771 .67922 .5415 .66881 .52951 Metetra
.962 .159 0 r
.66881 .52951 .67922 .5415 .70102 .53528 .69072 .5232 Metetra
.963 .155 0 r
.69072 .5232 .70102 .53528 .72299 .52906 .7128 .51689 Metetra
.964 .151 0 r
.7128 .51689 .72299 .52906 .74513 .52282 .73507 .51056 Metetra
.965 .145 0 r
.73507 .51056 .74513 .52282 .76746 .51659 .75752 .50423 Metetra
.967 .14 0 r
.75752 .50423 .76746 .51659 .78997 .51034 .78015 .49789 Metetra
.968 .135 0 r
.78015 .49789 .78997 .51034 .81264 .50383 .80295 .49127 Metetra
.964 .152 0 r
.80295 .49127 .81264 .50383 .83524 .49452 .82568 .48186 Metetra
.927 .294 0 r
.82568 .48186 .83524 .49452 .85644 .46993 .84706 .45711 Metetra
.788 .723 0 r
.84706 .45711 .85644 .46993 .87329 .4055 .86415 .39242 Metetra
.232 .624 0 r
.22527 .52429 .2374 .53503 .24878 .6109 .23639 .60037 Metetra
.859 .524 0 r
.23639 .60037 .24878 .6109 .26445 .64279 .25198 .63232 Metetra
.948 .212 0 r
.25198 .63232 .26445 .64279 .28265 .64601 .27023 .6355 Metetra
.967 .14 0 r
.27023 .6355 .28265 .64601 .30161 .64108 .28926 .6305 Metetra
.967 .136 0 r
.28926 .6305 .30161 .64108 .32077 .63502 .30852 .62436 Metetra
.966 .142 0 r
.30852 .62436 .32077 .63502 .34008 .62887 .32791 .61813 Metetra
.965 .147 0 r
.32791 .61813 .34008 .62887 .35952 .62273 .34743 .61191 Metetra
.964 .152 0 r
.34743 .61191 .35952 .62273 .37909 .61658 .3671 .60568 Metetra
.963 .156 0 r
.3671 .60568 .37909 .61658 .39881 .61043 .38691 .59945 Metetra
.962 .16 0 r
.38691 .59945 .39881 .61043 .41866 .60427 .40685 .59321 Metetra
.961 .163 0 r
.40685 .59321 .41866 .60427 .43866 .5981 .42695 .58695 Metetra
.96 .166 0 r
.42695 .58695 .43866 .5981 .45881 .59192 .44719 .58069 Metetra
.96 .168 0 r
.44719 .58069 .45881 .59192 .4791 .58574 .46758 .57442 Metetra
.959 .169 0 r
.46758 .57442 .4791 .58574 .49955 .57954 .48813 .56814 Metetra
.959 .17 0 r
.48813 .56814 .49955 .57954 .52014 .57333 .50882 .56184 Metetra
.959 .17 0 r
.50882 .56184 .52014 .57333 .5409 .56711 .52968 .55554 Metetra
.959 .17 0 r
.52968 .55554 .5409 .56711 .56181 .56088 .55069 .54921 Metetra
.959 .17 0 r
.55069 .54921 .56181 .56088 .58288 .55463 .57187 .54288 Metetra
.959 .168 0 r
.57187 .54288 .58288 .55463 .60411 .54837 .59321 .53653 Metetra
.96 .167 0 r
.59321 .53653 .60411 .54837 .62551 .5421 .61472 .53016 Metetra
.96 .165 0 r
.61472 .53016 .62551 .5421 .64707 .53581 .6364 .52378 Metetra
.961 .162 0 r
.6364 .52378 .64707 .53581 .66881 .52951 .65825 .51739 Metetra
.962 .159 0 r
.65825 .51739 .66881 .52951 .69072 .5232 .68027 .51099 Metetra
.963 .155 0 r
.68027 .51099 .69072 .5232 .7128 .51689 .70248 .50458 Metetra
.964 .151 0 r
.70248 .50458 .7128 .51689 .73507 .51056 .72486 .49815 Metetra
.965 .146 0 r
.72486 .49815 .73507 .51056 .75752 .50423 .74743 .49173 Metetra
.967 .14 0 r
.74743 .49173 .75752 .50423 .78015 .49789 .77019 .48529 Metetra
.968 .135 0 r
.77019 .48529 .78015 .49789 .80295 .49127 .79311 .47858 Metetra
.963 .152 0 r
.79311 .47858 .80295 .49127 .82568 .48186 .81598 .46905 Metetra
.927 .294 0 r
.81598 .46905 .82568 .48186 .84706 .45711 .83753 .44413 Metetra
.788 .723 0 r
.83753 .44413 .84706 .45711 .86415 .39242 .85488 .37914 Metetra
.232 .624 0 r
.21299 .5134 .22527 .52429 .23639 .60037 .22384 .5897 Metetra
.859 .523 0 r
.22384 .5897 .23639 .60037 .25198 .63232 .23935 .62174 Metetra
.949 .211 0 r
.23935 .62174 .25198 .63232 .27023 .6355 .25764 .62489 Metetra
.967 .139 0 r
.25764 .62489 .27023 .6355 .28926 .6305 .27675 .61982 Metetra
.968 .136 0 r
.27675 .61982 .28926 .6305 .30852 .62436 .29609 .61359 Metetra
.966 .141 0 r
.29609 .61359 .30852 .62436 .32791 .61813 .31557 .60728 Metetra
.965 .147 0 r
.31557 .60728 .32791 .61813 .34743 .61191 .33518 .60098 Metetra
.964 .152 0 r
.33518 .60098 .34743 .61191 .3671 .60568 .35494 .59466 Metetra
.963 .156 0 r
.35494 .59466 .3671 .60568 .38691 .59945 .37484 .58835 Metetra
.962 .16 0 r
.37484 .58835 .38691 .59945 .40685 .59321 .39488 .58202 Metetra
.961 .163 0 r
.39488 .58202 .40685 .59321 .42695 .58695 .41507 .57568 Metetra
.96 .165 0 r
.41507 .57568 .42695 .58695 .44719 .58069 .43541 .56933 Metetra
.96 .167 0 r
.43541 .56933 .44719 .58069 .46758 .57442 .4559 .56298 Metetra
.959 .169 0 r
.4559 .56298 .46758 .57442 .48813 .56814 .47654 .55661 Metetra
.959 .169 0 r
.47654 .55661 .48813 .56814 .50882 .56184 .49735 .55022 Metetra
.959 .17 0 r
.49735 .55022 .50882 .56184 .52968 .55554 .5183 .54383 Metetra
.959 .17 0 r
.5183 .54383 .52968 .55554 .55069 .54921 .53942 .53742 Metetra
.959 .169 0 r
.53942 .53742 .55069 .54921 .57187 .54288 .56071 .53099 Metetra
.96 .168 0 r
.56071 .53099 .57187 .54288 .59321 .53653 .58216 .52455 Metetra
.96 .166 0 r
.58216 .52455 .59321 .53653 .61472 .53016 .60378 .51809 Metetra
.961 .164 0 r
.60378 .51809 .61472 .53016 .6364 .52378 .62557 .51162 Metetra
.961 .162 0 r
.62557 .51162 .6364 .52378 .65825 .51739 .64753 .50513 Metetra
.962 .158 0 r
.64753 .50513 .65825 .51739 .68027 .51099 .66968 .49863 Metetra
.963 .155 0 r
.66968 .49863 .68027 .51099 .70248 .50458 .692 .49212 Metetra
.964 .15 0 r
.692 .49212 .70248 .50458 .72486 .49815 .71451 .4856 Metetra
.965 .145 0 r
.71451 .4856 .72486 .49815 .74743 .49173 .7372 .47908 Metetra
.967 .139 0 r
.7372 .47908 .74743 .49173 .77019 .48529 .76008 .47254 Metetra
.968 .135 0 r
.76008 .47254 .77019 .48529 .79311 .47858 .78314 .46573 Metetra
.964 .152 0 r
.78314 .46573 .79311 .47858 .81598 .46905 .80614 .45609 Metetra
.927 .294 0 r
.80614 .45609 .81598 .46905 .83753 .44413 .82787 .43099 Metetra
.788 .723 0 r
.82787 .43099 .83753 .44413 .85488 .37914 .84547 .36566 Metetra
.232 .624 0 r
.20056 .50234 .21299 .5134 .22384 .5897 .21111 .57891 Metetra
.86 .523 0 r
.21111 .57891 .22384 .5897 .23935 .62174 .22654 .61105 Metetra
.949 .211 0 r
.22654 .61105 .23935 .62174 .25764 .62489 .24487 .61417 Metetra
.967 .138 0 r
.24487 .61417 .25764 .62489 .27675 .61982 .26406 .60902 Metetra
.968 .135 0 r
.26406 .60902 .27675 .61982 .29609 .61359 .28349 .60271 Metetra
.966 .14 0 r
.28349 .60271 .29609 .61359 .31557 .60728 .30306 .59632 Metetra
.965 .146 0 r
.30306 .59632 .31557 .60728 .33518 .60098 .32276 .58993 Metetra
.964 .151 0 r
.32276 .58993 .33518 .60098 .35494 .59466 .34261 .58353 Metetra
.963 .155 0 r
.34261 .58353 .35494 .59466 .37484 .58835 .3626 .57713 Metetra
.962 .159 0 r
.3626 .57713 .37484 .58835 .39488 .58202 .38274 .57072 Metetra
.961 .162 0 r
.38274 .57072 .39488 .58202 .41507 .57568 .40303 .56428 Metetra
.961 .164 0 r
.40303 .56428 .41507 .57568 .43541 .56933 .42346 .55785 Metetra
.96 .166 0 r
.42346 .55785 .43541 .56933 .4559 .56298 .44405 .55141 Metetra
.96 .168 0 r
.44405 .55141 .4559 .56298 .47654 .55661 .4648 .54495 Metetra
.959 .169 0 r
.4648 .54495 .47654 .55661 .49735 .55022 .4857 .53847 Metetra
.959 .169 0 r
.4857 .53847 .49735 .55022 .5183 .54383 .50677 .53199 Metetra
.959 .169 0 r
.50677 .53199 .5183 .54383 .53942 .53742 .52799 .52548 Metetra
.96 .168 0 r
.52799 .52548 .53942 .53742 .56071 .53099 .54939 .51896 Metetra
.96 .167 0 r
.54939 .51896 .56071 .53099 .58216 .52455 .57095 .51243 Metetra
.96 .166 0 r
.57095 .51243 .58216 .52455 .60378 .51809 .59268 .50588 Metetra
.961 .163 0 r
.59268 .50588 .60378 .51809 .62557 .51162 .61458 .49931 Metetra
.961 .161 0 r
.61458 .49931 .62557 .51162 .64753 .50513 .63667 .49273 Metetra
.962 .157 0 r
.63667 .49273 .64753 .50513 .66968 .49863 .65893 .48613 Metetra
.963 .154 0 r
.65893 .48613 .66968 .49863 .692 .49212 .68137 .47953 Metetra
.964 .149 0 r
.68137 .47953 .692 .49212 .71451 .4856 .704 .47291 Metetra
.966 .144 0 r
.704 .47291 .71451 .4856 .7372 .47908 .72682 .46629 Metetra
.967 .138 0 r
.72682 .46629 .7372 .47908 .76008 .47254 .74983 .45965 Metetra
.968 .134 0 r
.74983 .45965 .76008 .47254 .78314 .46573 .77302 .45273 Metetra
.964 .151 0 r
.77302 .45273 .78314 .46573 .80614 .45609 .79616 .44297 Metetra
.927 .293 0 r
.79616 .44297 .80614 .45609 .82787 .43099 .81806 .41767 Metetra
.788 .723 0 r
.81806 .41767 .82787 .43099 .84547 .36566 .83593 .35198 Metetra
.232 .624 0 r
.18797 .49112 .20056 .50234 .21111 .57891 .19822 .56797 Metetra
.86 .522 0 r
.19822 .56797 .21111 .57891 .22654 .61105 .21355 .60025 Metetra
.949 .209 0 r
.21355 .60025 .22654 .61105 .24487 .61417 .23192 .60335 Metetra
.967 .136 0 r
.23192 .60335 .24487 .61417 .26406 .60902 .2512 .59812 Metetra
.968 .133 0 r
.2512 .59812 .26406 .60902 .28349 .60271 .27071 .59173 Metetra
.967 .139 0 r
.27071 .59173 .28349 .60271 .30306 .59632 .29037 .58525 Metetra
.965 .144 0 r
.29037 .58525 .30306 .59632 .32276 .58993 .31017 .57877 Metetra
.964 .149 0 r
.31017 .57877 .32276 .58993 .34261 .58353 .33011 .57228 Metetra
.963 .153 0 r
.33011 .57228 .34261 .58353 .3626 .57713 .35019 .56579 Metetra
.962 .157 0 r
.35019 .56579 .3626 .57713 .38274 .57072 .37043 .55929 Metetra
.962 .16 0 r
.37043 .55929 .38274 .57072 .40303 .56428 .39081 .55276 Metetra
.961 .163 0 r
.39081 .55276 .40303 .56428 .42346 .55785 .41134 .54624 Metetra
.96 .165 0 r
.41134 .54624 .42346 .55785 .44405 .55141 .43204 .53971 Metetra
.96 .166 0 r
.43204 .53971 .44405 .55141 .4648 .54495 .45288 .53316 Metetra
.96 .167 0 r
.45288 .53316 .4648 .54495 .4857 .53847 .47389 .52659 Metetra
.96 .168 0 r
.47389 .52659 .4857 .53847 .50677 .53199 .49506 .52001 Metetra
.96 .167 0 r
.49506 .52001 .50677 .53199 .52799 .52548 .5164 .51341 Metetra
.96 .167 0 r
.5164 .51341 .52799 .52548 .54939 .51896 .5379 .5068 Metetra
.96 .166 0 r
.5379 .5068 .54939 .51896 .57095 .51243 .55957 .50017 Metetra
.961 .164 0 r
.55957 .50017 .57095 .51243 .59268 .50588 .58142 .49352 Metetra
.961 .162 0 r
.58142 .49352 .59268 .50588 .61458 .49931 .60344 .48686 Metetra
.962 .159 0 r
.60344 .48686 .61458 .49931 .63667 .49273 .62564 .48018 Metetra
.963 .156 0 r
.62564 .48018 .63667 .49273 .65893 .48613 .64802 .47349 Metetra
.964 .152 0 r
.64802 .47349 .65893 .48613 .68137 .47953 .67059 .46678 Metetra
.965 .148 0 r
.67059 .46678 .68137 .47953 .704 .47291 .69334 .46006 Metetra
.966 .142 0 r
.69334 .46006 .704 .47291 .72682 .46629 .71629 .45335 Metetra
.967 .137 0 r
.71629 .45335 .72682 .46629 .74983 .45965 .73943 .4466 Metetra
.969 .132 0 r
.73943 .4466 .74983 .45965 .77302 .45273 .76275 .43958 Metetra
.964 .149 0 r
.76275 .43958 .77302 .45273 .79616 .44297 .78603 .42969 Metetra
.927 .292 0 r
.78603 .42969 .79616 .44297 .81806 .41767 .80811 .40418 Metetra
.788 .723 0 r
.80811 .40418 .81806 .41767 .83593 .35198 .82624 .3381 Metetra
.231 .624 0 r
.17521 .47974 .18797 .49112 .19822 .56797 .18515 .55689 Metetra
.86 .522 0 r
.18515 .55689 .19822 .56797 .21355 .60025 .20038 .58933 Metetra
.95 .207 0 r
.20038 .58933 .21355 .60025 .23192 .60335 .21879 .59241 Metetra
.968 .134 0 r
.21879 .59241 .23192 .60335 .2512 .59812 .23815 .58711 Metetra
.969 .131 0 r
.23815 .58711 .2512 .59812 .27071 .59173 .25775 .58062 Metetra
.967 .137 0 r
.25775 .58062 .27071 .59173 .29037 .58525 .2775 .57406 Metetra
.966 .142 0 r
.2775 .57406 .29037 .58525 .31017 .57877 .29739 .56748 Metetra
.965 .147 0 r
.29739 .56748 .31017 .57877 .33011 .57228 .31742 .56091 Metetra
.964 .151 0 r
.31742 .56091 .33011 .57228 .35019 .56579 .33761 .55433 Metetra
.963 .155 0 r
.33761 .55433 .35019 .56579 .37043 .55929 .35793 .54773 Metetra
.962 .158 0 r
.35793 .54773 .37043 .55929 .39081 .55276 .37842 .54112 Metetra
.961 .161 0 r
.37842 .54112 .39081 .55276 .41134 .54624 .39905 .5345 Metetra
.961 .163 0 r
.39905 .5345 .41134 .54624 .43204 .53971 .41984 .52788 Metetra
.961 .164 0 r
.41984 .52788 .43204 .53971 .45288 .53316 .4408 .52123 Metetra
.96 .165 0 r
.4408 .52123 .45288 .53316 .47389 .52659 .46191 .51457 Metetra
.96 .166 0 r
.46191 .51457 .47389 .52659 .49506 .52001 .48319 .5079 Metetra
.96 .165 0 r
.48319 .5079 .49506 .52001 .5164 .51341 .50463 .5012 Metetra
.96 .165 0 r
.50463 .5012 .5164 .51341 .5379 .5068 .52624 .49449 Metetra
.961 .164 0 r
.52624 .49449 .5379 .5068 .55957 .50017 .54803 .48777 Metetra
.961 .162 0 r
.54803 .48777 .55957 .50017 .58142 .49352 .56999 .48102 Metetra
.962 .16 0 r
.56999 .48102 .58142 .49352 .60344 .48686 .59213 .47426 Metetra
.962 .157 0 r
.59213 .47426 .60344 .48686 .62564 .48018 .61445 .46748 Metetra
.963 .154 0 r
.61445 .46748 .62564 .48018 .64802 .47349 .63695 .46069 Metetra
.964 .15 0 r
.63695 .46069 .64802 .47349 .67059 .46678 .65964 .45388 Metetra
.965 .146 0 r
.65964 .45388 .67059 .46678 .69334 .46006 .68252 .44706 Metetra
.967 .14 0 r
.68252 .44706 .69334 .46006 .71629 .45335 .7056 .44024 Metetra
.968 .134 0 r
.7056 .44024 .71629 .45335 .73943 .4466 .72887 .43339 Metetra
.969 .13 0 r
.72887 .43339 .73943 .4466 .76275 .43958 .75232 .42627 Metetra
.965 .147 0 r
.75232 .42627 .76275 .43958 .78603 .42969 .77575 .41625 Metetra
.928 .29 0 r
.77575 .41625 .78603 .42969 .80811 .40418 .79801 .3905 Metetra
.789 .722 0 r
.79801 .3905 .80811 .40418 .82624 .3381 .81641 .32399 Metetra
.231 .624 0 r
.16229 .46819 .17521 .47974 .18515 .55689 .17191 .54569 Metetra
.86 .52 0 r
.17191 .54569 .18515 .55689 .20038 .58933 .18702 .5783 Metetra
.95 .205 0 r
.18702 .5783 .20038 .58933 .21879 .59241 .20547 .58138 Metetra
.969 .131 0 r
.20547 .58138 .21879 .59241 .23815 .58711 .22491 .57599 Metetra
.97 .128 0 r
.22491 .57599 .23815 .58711 .25775 .58062 .24461 .56942 Metetra
.968 .134 0 r
.24461 .56942 .25775 .58062 .2775 .57406 .26445 .56276 Metetra
.967 .139 0 r
.26445 .56276 .2775 .57406 .29739 .56748 .28443 .5561 Metetra
.965 .144 0 r
.28443 .5561 .29739 .56748 .31742 .56091 .30456 .54943 Metetra
.964 .149 0 r
.30456 .54943 .31742 .56091 .33761 .55433 .32484 .54275 Metetra
.963 .152 0 r
.32484 .54275 .33761 .55433 .35793 .54773 .34526 .53607 Metetra
.963 .156 0 r
.34526 .53607 .35793 .54773 .37842 .54112 .36584 .52936 Metetra
.962 .158 0 r
.36584 .52936 .37842 .54112 .39905 .5345 .38658 .52265 Metetra
.962 .16 0 r
.38658 .52265 .39905 .5345 .41984 .52788 .40748 .51592 Metetra
.961 .162 0 r
.40748 .51592 .41984 .52788 .4408 .52123 .42853 .50918 Metetra
.961 .163 0 r
.42853 .50918 .4408 .52123 .46191 .51457 .44975 .50243 Metetra
.961 .163 0 r
.44975 .50243 .46191 .51457 .48319 .5079 .47114 .49566 Metetra
.961 .163 0 r
.47114 .49566 .48319 .5079 .50463 .5012 .49269 .48887 Metetra
.961 .162 0 r
.49269 .48887 .50463 .5012 .52624 .49449 .51442 .48206 Metetra
.961 .161 0 r
.51442 .48206 .52624 .49449 .54803 .48777 .53631 .47523 Metetra
.962 .16 0 r
.53631 .47523 .54803 .48777 .56999 .48102 .55839 .46839 Metetra
.962 .157 0 r
.55839 .46839 .56999 .48102 .59213 .47426 .58065 .46152 Metetra
.963 .155 0 r
.58065 .46152 .59213 .47426 .61445 .46748 .60309 .45465 Metetra
.964 .151 0 r
.60309 .45465 .61445 .46748 .63695 .46069 .62572 .44775 Metetra
.965 .147 0 r
.62572 .44775 .63695 .46069 .65964 .45388 .64853 .44084 Metetra
.966 .143 0 r
.64853 .44084 .65964 .45388 .68252 .44706 .67154 .43392 Metetra
.967 .137 0 r
.67154 .43392 .68252 .44706 .7056 .44024 .69475 .427 Metetra
.969 .132 0 r
.69475 .427 .7056 .44024 .72887 .43339 .71815 .42005 Metetra
.97 .127 0 r
.71815 .42005 .72887 .43339 .75232 .42627 .74174 .41281 Metetra
.966 .144 0 r
.74174 .41281 .75232 .42627 .77575 .41625 .76531 .40266 Metetra
.928 .288 0 r
.76531 .40266 .77575 .41625 .79801 .3905 .78775 .37665 Metetra
.789 .722 0 r
.78775 .37665 .79801 .3905 .81641 .32399 .80643 .30969 Metetra
.23 .624 0 r
.1492 .45646 .16229 .46819 .17191 .54569 .15848 .53433 Metetra
.861 .519 0 r
.15848 .53433 .17191 .54569 .18702 .5783 .17348 .56715 Metetra
.951 .202 0 r
.17348 .56715 .18702 .5783 .20547 .58138 .19197 .57022 Metetra
.97 .128 0 r
.19197 .57022 .20547 .58138 .22491 .57599 .21149 .56476 Metetra
.97 .124 0 r
.21149 .56476 .22491 .57599 .24461 .56942 .23127 .55809 Metetra
.969 .13 0 r
.23127 .55809 .24461 .56942 .26445 .56276 .2512 .55133 Metetra
.968 .136 0 r
.2512 .55133 .26445 .56276 .28443 .5561 .27128 .54458 Metetra
.966 .141 0 r
.27128 .54458 .28443 .5561 .30456 .54943 .29151 .53781 Metetra
.965 .145 0 r
.29151 .53781 .30456 .54943 .32484 .54275 .31188 .53104 Metetra
.964 .149 0 r
.31188 .53104 .32484 .54275 .34526 .53607 .33241 .52426 Metetra
.963 .152 0 r
.33241 .52426 .34526 .53607 .36584 .52936 .35309 .51745 Metetra
.963 .155 0 r
.35309 .51745 .36584 .52936 .38658 .52265 .37393 .51065 Metetra
.962 .157 0 r
.37393 .51065 .38658 .52265 .40748 .51592 .39492 .50382 Metetra
.962 .159 0 r
.39492 .50382 .40748 .51592 .42853 .50918 .41609 .49699 Metetra
.962 .16 0 r
.41609 .49699 .42853 .50918 .44975 .50243 .43741 .49013 Metetra
.962 .16 0 r
.43741 .49013 .44975 .50243 .47114 .49566 .45891 .48326 Metetra
.962 .16 0 r
.45891 .48326 .47114 .49566 .49269 .48887 .48057 .47637 Metetra
.962 .159 0 r
.48057 .47637 .49269 .48887 .51442 .48206 .50241 .46946 Metetra
.962 .158 0 r
.50241 .46946 .51442 .48206 .53631 .47523 .52443 .46253 Metetra
.963 .156 0 r
.52443 .46253 .53631 .47523 .55839 .46839 .54662 .45559 Metetra
.963 .154 0 r
.54662 .45559 .55839 .46839 .58065 .46152 .569 .44862 Metetra
.964 .151 0 r
.569 .44862 .58065 .46152 .60309 .45465 .59156 .44164 Metetra
.965 .148 0 r
.59156 .44164 .60309 .45465 .62572 .44775 .61431 .43465 Metetra
.966 .144 0 r
.61431 .43465 .62572 .44775 .64853 .44084 .63725 .42763 Metetra
.967 .139 0 r
.63725 .42763 .64853 .44084 .67154 .43392 .66039 .42062 Metetra
.968 .134 0 r
.66039 .42062 .67154 .43392 .69475 .427 .68373 .41358 Metetra
.97 .128 0 r
.68373 .41358 .69475 .427 .71815 .42005 .70727 .40652 Metetra
.971 .123 0 r
.70727 .40652 .71815 .42005 .74174 .41281 .73099 .39918 Metetra
.966 .141 0 r
.73099 .39918 .74174 .41281 .76531 .40266 .75472 .38888 Metetra
.929 .286 0 r
.75472 .38888 .76531 .40266 .78775 .37665 .77734 .36261 Metetra
.789 .721 0 r
.77734 .36261 .78775 .37665 .80643 .30969 .79629 .29515 Metetra
.23 .624 0 r
.13594 .44455 .1492 .45646 .15848 .53433 .14487 .52282 Metetra
.861 .517 0 r
.14487 .52282 .15848 .53433 .17348 .56715 .15974 .55587 Metetra
.952 .198 0 r
.15974 .55587 .17348 .56715 .19197 .57022 .17826 .55895 Metetra
.971 .123 0 r
.17826 .55895 .19197 .57022 .21149 .56476 .19787 .5534 Metetra
.971 .12 0 r
.19787 .5534 .21149 .56476 .23127 .55809 .21774 .54664 Metetra
.97 .126 0 r
.21774 .54664 .23127 .55809 .2512 .55133 .23777 .53979 Metetra
.969 .132 0 r
.23777 .53979 .2512 .55133 .27128 .54458 .25794 .53293 Metetra
.967 .137 0 r
.25794 .53293 .27128 .54458 .29151 .53781 .27826 .52607 Metetra
.966 .142 0 r
.27826 .52607 .29151 .53781 .31188 .53104 .29873 .5192 Metetra
.965 .145 0 r
.29873 .5192 .31188 .53104 .33241 .52426 .31936 .51232 Metetra
.964 .149 0 r
.31936 .51232 .33241 .52426 .35309 .51745 .34014 .50541 Metetra
.964 .151 0 r
.34014 .50541 .35309 .51745 .37393 .51065 .36108 .49851 Metetra
.963 .153 0 r
.36108 .49851 .37393 .51065 .39492 .50382 .38219 .49158 Metetra
.963 .155 0 r
.38219 .49158 .39492 .50382 .41609 .49699 .40345 .48465 Metetra
.963 .156 0 r
.40345 .48465 .41609 .49699 .43741 .49013 .42489 .47769 Metetra
.963 .156 0 r
.42489 .47769 .43741 .49013 .45891 .48326 .44649 .47072 Metetra
.963 .156 0 r
.44649 .47072 .45891 .48326 .48057 .47637 .46827 .46373 Metetra
.963 .156 0 r
.46827 .46373 .48057 .47637 .50241 .46946 .49023 .45672 Metetra
.963 .154 0 r
.49023 .45672 .50241 .46946 .52443 .46253 .51236 .44969 Metetra
.963 .153 0 r
.51236 .44969 .52443 .46253 .54662 .45559 .53467 .44264 Metetra
.964 .15 0 r
.53467 .44264 .54662 .45559 .569 .44862 .55717 .43557 Metetra
.965 .148 0 r
.55717 .43557 .569 .44862 .59156 .44164 .57986 .42848 Metetra
.966 .144 0 r
.57986 .42848 .59156 .44164 .61431 .43465 .60273 .42138 Metetra
.967 .14 0 r
.60273 .42138 .61431 .43465 .63725 .42763 .6258 .41427 Metetra
.968 .135 0 r
.6258 .41427 .63725 .42763 .66039 .42062 .64907 .40714 Metetra
.969 .13 0 r
.64907 .40714 .66039 .42062 .68373 .41358 .67254 .4 Metetra
.971 .124 0 r
.67254 .4 .68373 .41358 .70727 .40652 .69622 .39283 Metetra
.972 .119 0 r
.69622 .39283 .70727 .40652 .73099 .39918 .72008 .38537 Metetra
.967 .137 0 r
.72008 .38537 .73099 .39918 .75472 .38888 .74396 .37494 Metetra
.93 .283 0 r
.74396 .37494 .75472 .38888 .77734 .36261 .76677 .34838 Metetra
.789 .721 0 r
.76677 .34838 .77734 .36261 .79629 .29515 .78601 .28038 Metetra
.229 .623 0 r
.12251 .43247 .13594 .44455 .14487 .52282 .13106 .51116 Metetra
.862 .515 0 r
.13106 .51116 .14487 .52282 .15974 .55587 .1458 .54446 Metetra
.953 .194 0 r
.1458 .54446 .15974 .55587 .17826 .55895 .16436 .54756 Metetra
.972 .119 0 r
.16436 .54756 .17826 .55895 .19787 .5534 .18405 .54193 Metetra
.973 .115 0 r
.18405 .54193 .19787 .5534 .21774 .54664 .20401 .53507 Metetra
.971 .121 0 r
.20401 .53507 .21774 .54664 .23777 .53979 .22413 .52812 Metetra
.97 .127 0 r
.22413 .52812 .23777 .53979 .25794 .53293 .2444 .52116 Metetra
.968 .133 0 r
.2444 .52116 .25794 .53293 .27826 .52607 .26482 .5142 Metetra
.967 .137 0 r
.26482 .5142 .27826 .52607 .29873 .5192 .28539 .50723 Metetra
.966 .141 0 r
.28539 .50723 .29873 .5192 .31936 .51232 .30612 .50024 Metetra
.965 .144 0 r
.30612 .50024 .31936 .51232 .34014 .50541 .327 .49324 Metetra
.965 .147 0 r
.327 .49324 .34014 .50541 .36108 .49851 .34805 .48623 Metetra
.964 .149 0 r
.34805 .48623 .36108 .49851 .38219 .49158 .36926 .47921 Metetra
.964 .151 0 r
.36926 .47921 .38219 .49158 .40345 .48465 .39063 .47217 Metetra
.964 .152 0 r
.39063 .47217 .40345 .48465 .42489 .47769 .41218 .46511 Metetra
.964 .152 0 r
.41218 .46511 .42489 .47769 .44649 .47072 .43389 .45803 Metetra
.964 .152 0 r
.43389 .45803 .44649 .47072 .46827 .46373 .45579 .45093 Metetra
.964 .151 0 r
.45579 .45093 .46827 .46373 .49023 .45672 .47786 .44382 Metetra
.964 .15 0 r
.47786 .44382 .49023 .45672 .51236 .44969 .50011 .43668 Metetra
.964 .148 0 r
.50011 .43668 .51236 .44969 .53467 .44264 .52254 .42953 Metetra
.965 .146 0 r
.52254 .42953 .53467 .44264 .55717 .43557 .54516 .42236 Metetra
.966 .143 0 r
.54516 .42236 .55717 .43557 .57986 .42848 .56797 .41517 Metetra
.967 .14 0 r
.56797 .41517 .57986 .42848 .60273 .42138 .59097 .40796 Metetra
.968 .136 0 r
.59097 .40796 .60273 .42138 .6258 .41427 .61418 .40074 Metetra
.969 .131 0 r
.61418 .40074 .6258 .41427 .64907 .40714 .63758 .3935 Metetra
.97 .125 0 r
.63758 .3935 .64907 .40714 .67254 .4 .66118 .38625 Metetra
.972 .119 0 r
.66118 .38625 .67254 .4 .69622 .39283 .685 .37897 Metetra
.973 .114 0 r
.685 .37897 .69622 .39283 .72008 .38537 .709 .3714 Metetra
.969 .132 0 r
.709 .3714 .72008 .38537 .74396 .37494 .73303 .36081 Metetra
.931 .279 0 r
.73303 .36081 .74396 .37494 .76677 .34838 .75603 .33395 Metetra
.79 .72 0 r
.75603 .33395 .76677 .34838 .78601 .28038 .77556 .26539 Metetra
.229 .623 0 r
.1089 .4202 .12251 .43247 .13106 .51116 .11706 .49935 Metetra
.863 .513 0 r
.11706 .49935 .13106 .51116 .1458 .54446 .13166 .53294 Metetra
.954 .189 0 r
.13166 .53294 .1458 .54446 .16436 .54756 .15024 .53605 Metetra
.973 .113 0 r
.15024 .53605 .16436 .54756 .18405 .54193 .17002 .53034 Metetra
.974 .11 0 r
.17002 .53034 .18405 .54193 .20401 .53507 .19008 .52338 Metetra
.972 .116 0 r
.19008 .52338 .20401 .53507 .22413 .52812 .2103 .51632 Metetra
.971 .122 0 r
.2103 .51632 .22413 .52812 .2444 .52116 .23066 .50926 Metetra
.97 .127 0 r
.23066 .50926 .2444 .52116 .26482 .5142 .25118 .5022 Metetra
.969 .132 0 r
.25118 .5022 .26482 .5142 .28539 .50723 .27185 .49512 Metetra
.968 .136 0 r
.27185 .49512 .28539 .50723 .30612 .50024 .29268 .48804 Metetra
.967 .139 0 r
.29268 .48804 .30612 .50024 .327 .49324 .31367 .48093 Metetra
.966 .142 0 r
.31367 .48093 .327 .49324 .34805 .48623 .33482 .47381 Metetra
.965 .144 0 r
.33482 .47381 .34805 .48623 .36926 .47921 .35613 .46669 Metetra
.965 .146 0 r
.35613 .46669 .36926 .47921 .39063 .47217 .37762 .45954 Metetra
.965 .147 0 r
.37762 .45954 .39063 .47217 .41218 .46511 .39927 .45238 Metetra
.965 .147 0 r
.39927 .45238 .41218 .46511 .43389 .45803 .4211 .44519 Metetra
.965 .147 0 r
.4211 .44519 .43389 .45803 .45579 .45093 .44311 .43799 Metetra
.965 .147 0 r
.44311 .43799 .45579 .45093 .47786 .44382 .46529 .43077 Metetra
.965 .145 0 r
.46529 .43077 .47786 .44382 .50011 .43668 .48766 .42353 Metetra
.966 .144 0 r
.48766 .42353 .50011 .43668 .52254 .42953 .51022 .41627 Metetra
.966 .141 0 r
.51022 .41627 .52254 .42953 .54516 .42236 .53296 .40899 Metetra
.967 .138 0 r
.53296 .40899 .54516 .42236 .56797 .41517 .5559 .40169 Metetra
.968 .135 0 r
.5559 .40169 .56797 .41517 .59097 .40796 .57903 .39438 Metetra
.969 .13 0 r
.57903 .39438 .59097 .40796 .61418 .40074 .60237 .38704 Metetra
.97 .125 0 r
.60237 .38704 .61418 .40074 .63758 .3935 .6259 .3797 Metetra
.972 .12 0 r
.6259 .3797 .63758 .3935 .66118 .38625 .64964 .37233 Metetra
.973 .114 0 r
.64964 .37233 .66118 .38625 .685 .37897 .6736 .36495 Metetra
.974 .109 0 r
.6736 .36495 .685 .37897 .709 .3714 .69775 .35726 Metetra
.97 .127 0 r
.69775 .35726 .709 .3714 .73303 .36081 .72193 .34651 Metetra
.932 .275 0 r
.72193 .34651 .73303 .36081 .75603 .33395 .74512 .31932 Metetra
.79 .719 0 r
.74512 .31932 .75603 .33395 .77556 .26539 .76495 .25016 Metetra
.228 .623 0 r
.09511 .40773 .1089 .4202 .11706 .49935 .10287 .48738 Metetra
.863 .511 0 r
.10287 .48738 .11706 .49935 .13166 .53294 .1173 .52129 Metetra
.956 .183 0 r
.1173 .52129 .13166 .53294 .15024 .53605 .13592 .52443 Metetra
.975 .107 0 r
.13592 .52443 .15024 .53605 .17002 .53034 .15578 .51864 Metetra
.976 .104 0 r
.15578 .51864 .17002 .53034 .19008 .52338 .17594 .51157 Metetra
.974 .11 0 r
.17594 .51157 .19008 .52338 .2103 .51632 .19625 .50441 Metetra
.972 .116 0 r
.19625 .50441 .2103 .51632 .23066 .50926 .21671 .49724 Metetra
.971 .121 0 r
.21671 .49724 .23066 .50926 .25118 .5022 .23733 .49007 Metetra
.97 .126 0 r
.23733 .49007 .25118 .5022 .27185 .49512 .2581 .48289 Metetra
.969 .13 0 r
.2581 .48289 .27185 .49512 .29268 .48804 .27903 .47569 Metetra
.968 .134 0 r
.27903 .47569 .29268 .48804 .31367 .48093 .30012 .46848 Metetra
.967 .137 0 r
.30012 .46848 .31367 .48093 .33482 .47381 .32138 .46126 Metetra
.967 .139 0 r
.32138 .46126 .33482 .47381 .35613 .46669 .34281 .45402 Metetra
.966 .14 0 r
.34281 .45402 .35613 .46669 .37762 .45954 .3644 .44677 Metetra
.966 .141 0 r
.3644 .44677 .37762 .45954 .39927 .45238 .38617 .4395 Metetra
.966 .142 0 r
.38617 .4395 .39927 .45238 .4211 .44519 .40811 .43221 Metetra
.966 .142 0 r
.40811 .43221 .4211 .44519 .44311 .43799 .43023 .4249 Metetra
.966 .141 0 r
.43023 .4249 .44311 .43799 .46529 .43077 .45254 .41757 Metetra
.967 .14 0 r
.45254 .41757 .46529 .43077 .48766 .42353 .47503 .41022 Metetra
.967 .138 0 r
.47503 .41022 .48766 .42353 .51022 .41627 .49771 .40285 Metetra
.968 .136 0 r
.49771 .40285 .51022 .41627 .53296 .40899 .52058 .39546 Metetra
.968 .133 0 r
.52058 .39546 .53296 .40899 .5559 .40169 .54364 .38805 Metetra
.969 .129 0 r
.54364 .38805 .5559 .40169 .57903 .39438 .56691 .38063 Metetra
.97 .124 0 r
.56691 .38063 .57903 .39438 .60237 .38704 .59037 .37318 Metetra
.972 .119 0 r
.59037 .37318 .60237 .38704 .6259 .3797 .61404 .36572 Metetra
.973 .114 0 r
.61404 .36572 .6259 .3797 .64964 .37233 .63792 .35825 Metetra
.975 .107 0 r
.63792 .35825 .64964 .37233 .6736 .36495 .66202 .35075 Metetra
.976 .102 0 r
.66202 .35075 .6736 .36495 .69775 .35726 .68632 .34294 Metetra
.971 .12 0 r
.68632 .34294 .69775 .35726 .72193 .34651 .71065 .33203 Metetra
.933 .27 0 r
.71065 .33203 .72193 .34651 .74512 .31932 .73404 .30449 Metetra
.79 .718 0 r
.73404 .30449 .74512 .31932 .76495 .25016 .75417 .23468 Metetra
.227 .622 0 r
.08114 .39501 .09511 .40773 .10287 .48738 .08848 .47517 Metetra
.864 .509 0 r
.08848 .47517 .10287 .48738 .1173 .52129 .10275 .50941 Metetra
.957 .178 0 r
.10275 .50941 .1173 .52129 .13592 .52443 .12139 .5126 Metetra
.976 .1 0 r
.12139 .5126 .13592 .52443 .15578 .51864 .14134 .50672 Metetra
.977 .097 0 r
.14134 .50672 .15578 .51864 .17594 .51157 .16159 .49954 Metetra
.976 .104 0 r
.16159 .49954 .17594 .51157 .19625 .50441 .182 .49227 Metetra
.974 .11 0 r
.182 .49227 .19625 .50441 .21671 .49724 .20256 .485 Metetra
.973 .115 0 r
.20256 .485 .21671 .49724 .23733 .49007 .22327 .47772 Metetra
.971 .12 0 r
.22327 .47772 .23733 .49007 .2581 .48289 .24415 .47043 Metetra
.97 .124 0 r
.24415 .47043 .2581 .48289 .27903 .47569 .26518 .46312 Metetra
.97 .128 0 r
.26518 .46312 .27903 .47569 .30012 .46848 .28638 .4558 Metetra
.969 .131 0 r
.28638 .4558 .30012 .46848 .32138 .46126 .30774 .44847 Metetra
.968 .133 0 r
.30774 .44847 .32138 .46126 .34281 .45402 .32928 .44112 Metetra
.968 .135 0 r
.32928 .44112 .34281 .45402 .3644 .44677 .35098 .43376 Metetra
.968 .136 0 r
.35098 .43376 .3644 .44677 .38617 .4395 .37286 .42638 Metetra
.967 .136 0 r
.37286 .42638 .38617 .4395 .40811 .43221 .39492 .41898 Metetra
.967 .136 0 r
.39492 .41898 .40811 .43221 .43023 .4249 .41716 .41156 Metetra
.968 .136 0 r
.41716 .41156 .43023 .4249 .45254 .41757 .43958 .40412 Metetra
.968 .134 0 r
.43958 .40412 .45254 .41757 .47503 .41022 .4622 .39665 Metetra
.968 .132 0 r
.4622 .39665 .47503 .41022 .49771 .40285 .485 .38917 Metetra
.969 .13 0 r
.485 .38917 .49771 .40285 .52058 .39546 .50799 .38167 Metetra
.97 .127 0 r
.50799 .38167 .52058 .39546 .54364 .38805 .53119 .37415 Metetra
.971 .123 0 r
.53119 .37415 .54364 .38805 .56691 .38063 .55458 .36661 Metetra
.972 .119 0 r
.55458 .36661 .56691 .38063 .59037 .37318 .57818 .35905 Metetra
.973 .113 0 r
.57818 .35905 .59037 .37318 .61404 .36572 .60199 .35148 Metetra
.975 .107 0 r
.60199 .35148 .61404 .36572 .63792 .35825 .62601 .34389 Metetra
.976 .101 0 r
.62601 .34389 .63792 .35825 .66202 .35075 .65025 .33627 Metetra
.977 .096 0 r
.65025 .33627 .66202 .35075 .68632 .34294 .67469 .32835 Metetra
.973 .114 0 r
.67469 .32835 .68632 .34294 .71065 .33203 .69918 .31727 Metetra
.934 .266 0 r
.69918 .31727 .71065 .33203 .73404 .30449 .72277 .28935 Metetra
.791 .717 0 r
.72277 .28935 .73404 .30449 .75417 .23468 .74322 .21887 Metetra
.219 .62 0 r
.0671 .38134 .08114 .39501 .08848 .47517 .07404 .46167 Metetra
.863 .514 0 r
.07404 .46167 .08848 .47517 .10275 .50941 .08815 .49611 Metetra
.956 .182 0 r
.08815 .49611 .10275 .50941 .12139 .5126 .1068 .49932 Metetra
.976 .103 0 r
.1068 .49932 .12139 .5126 .14134 .50672 .12683 .49337 Metetra
.976 .1 0 r
.12683 .49337 .14134 .50672 .16159 .49954 .14716 .4861 Metetra
.975 .107 0 r
.14716 .4861 .16159 .49954 .182 .49227 .16766 .47873 Metetra
.973 .113 0 r
.16766 .47873 .182 .49227 .20256 .485 .18831 .47136 Metetra
.972 .119 0 r
.18831 .47136 .20256 .485 .22327 .47772 .20912 .46398 Metetra
.971 .123 0 r
.20912 .46398 .22327 .47772 .24415 .47043 .23009 .45659 Metetra
.97 .128 0 r
.23009 .45659 .24415 .47043 .26518 .46312 .25122 .44918 Metetra
.969 .131 0 r
.25122 .44918 .26518 .46312 .28638 .4558 .27252 .44175 Metetra
.968 .134 0 r
.27252 .44175 .28638 .4558 .30774 .44847 .29398 .43431 Metetra
.967 .136 0 r
.29398 .43431 .30774 .44847 .32928 .44112 .31562 .42686 Metetra
.967 .138 0 r
.31562 .42686 .32928 .44112 .35098 .43376 .33743 .41938 Metetra
.967 .139 0 r
.33743 .41938 .35098 .43376 .37286 .42638 .35941 .41189 Metetra
.967 .14 0 r
.35941 .41189 .37286 .42638 .39492 .41898 .38158 .40437 Metetra
.967 .139 0 r
.38158 .40437 .39492 .41898 .41716 .41156 .40393 .39683 Metetra
.967 .139 0 r
.40393 .39683 .41716 .41156 .43958 .40412 .42646 .38927 Metetra
.967 .137 0 r
.42646 .38927 .43958 .40412 .4622 .39665 .44919 .38169 Metetra
.968 .135 0 r
.44919 .38169 .4622 .39665 .485 .38917 .47211 .37409 Metetra
.968 .133 0 r
.47211 .37409 .485 .38917 .50799 .38167 .49522 .36647 Metetra
.969 .13 0 r
.49522 .36647 .50799 .38167 .53119 .37415 .51854 .35882 Metetra
.97 .126 0 r
.51854 .35882 .53119 .37415 .55458 .36661 .54206 .35115 Metetra
.971 .122 0 r
.54206 .35115 .55458 .36661 .57818 .35905 .56578 .34346 Metetra
.972 .116 0 r
.56578 .34346 .57818 .35905 .60199 .35148 .58972 .33575 Metetra
.974 .111 0 r
.58972 .33575 .60199 .35148 .62601 .34389 .61387 .32803 Metetra
.975 .104 0 r
.61387 .32803 .62601 .34389 .65025 .33627 .63824 .32027 Metetra
.977 .099 0 r
.63824 .32027 .65025 .33627 .67469 .32835 .66282 .3122 Metetra
.972 .117 0 r
.66282 .3122 .67469 .32835 .69918 .31727 .68746 .30093 Metetra
.933 .27 0 r
.68746 .30093 .69918 .31727 .72277 .28935 .71125 .27269 Metetra
.789 .722 0 r
.71125 .27269 .72277 .28935 .74322 .21887 .73202 .20176 Metetra
.17 .603 0 r
.05365 .3622 .0671 .38134 .07404 .46167 .06051 .44022 Metetra
.844 .572 0 r
.06051 .44022 .07404 .46167 .08815 .49611 .07456 .47369 Metetra
.937 .258 0 r
.07456 .47369 .08815 .49611 .1068 .49932 .09321 .4767 Metetra
.956 .182 0 r
.09321 .4767 .1068 .49932 .12683 .49337 .11325 .47072 Metetra
.957 .178 0 r
.11325 .47072 .12683 .49337 .14716 .4861 .13361 .46343 Metetra
.956 .183 0 r
.13361 .46343 .14716 .4861 .16766 .47873 .15414 .45603 Metetra
.954 .189 0 r
.15414 .45603 .16766 .47873 .18831 .47136 .17482 .44861 Metetra
.953 .194 0 r
.17482 .44861 .18831 .47136 .20912 .46398 .19566 .44118 Metetra
.952 .198 0 r
.19566 .44118 .20912 .46398 .23009 .45659 .21667 .43372 Metetra
.951 .202 0 r
.21667 .43372 .23009 .45659 .25122 .44918 .23783 .42624 Metetra
.95 .205 0 r
.23783 .42624 .25122 .44918 .27252 .44175 .25917 .41873 Metetra
.95 .207 0 r
.25917 .41873 .27252 .44175 .29398 .43431 .28068 .4112 Metetra
.949 .209 0 r
.28068 .4112 .29398 .43431 .31562 .42686 .30236 .40364 Metetra
.949 .211 0 r
.30236 .40364 .31562 .42686 .33743 .41938 .32421 .39605 Metetra
.949 .211 0 r
.32421 .39605 .33743 .41938 .35941 .41189 .34625 .38844 Metetra
.948 .212 0 r
.34625 .38844 .35941 .41189 .38158 .40437 .36846 .38079 Metetra
.948 .212 0 r
.36846 .38079 .38158 .40437 .40393 .39683 .39086 .37312 Metetra
.949 .211 0 r
.39086 .37312 .40393 .39683 .42646 .38927 .41345 .36541 Metetra
.949 .21 0 r
.41345 .36541 .42646 .38927 .44919 .38169 .43623 .35767 Metetra
.949 .208 0 r
.43623 .35767 .44919 .38169 .47211 .37409 .45921 .34989 Metetra
.95 .206 0 r
.45921 .34989 .47211 .37409 .49522 .36647 .48238 .34209 Metetra
.951 .203 0 r
.48238 .34209 .49522 .36647 .51854 .35882 .50575 .33425 Metetra
.951 .2 0 r
.50575 .33425 .51854 .35882 .54206 .35115 .52932 .32638 Metetra
.952 .196 0 r
.52932 .32638 .54206 .35115 .56578 .34346 .55311 .31848 Metetra
.954 .192 0 r
.55311 .31848 .56578 .34346 .58972 .33575 .5771 .31055 Metetra
.955 .187 0 r
.5771 .31055 .58972 .33575 .61387 .32803 .60131 .30258 Metetra
.956 .181 0 r
.60131 .30258 .61387 .32803 .63824 .32027 .62574 .29458 Metetra
.957 .177 0 r
.62574 .29458 .63824 .32027 .66282 .3122 .65038 .28625 Metetra
.953 .196 0 r
.65038 .28625 .66282 .3122 .68746 .30093 .67508 .27477 Metetra
.914 .342 0 r
.67508 .27477 .68746 .30093 .71125 .27269 .69903 .2467 Metetra
.77 .767 0 r
.69903 .2467 .71125 .27269 .73202 .20176 .72017 .17712 Metetra
0 .531 .016 r
.04283 .32486 .05365 .3622 .06051 .44022 .05077 .39206 Metetra
.712 .756 0 r
.05077 .39206 .06051 .44022 .07456 .47369 .0652 .42042 Metetra
.844 .572 0 r
.0652 .42042 .07456 .47369 .09321 .4767 .08379 .42228 Metetra
.863 .514 0 r
.08379 .42228 .09321 .4767 .11325 .47072 .10366 .41629 Metetra
.864 .509 0 r
.10366 .41629 .11325 .47072 .13361 .46343 .12384 .40912 Metetra
.863 .511 0 r
.12384 .40912 .13361 .46343 .15414 .45603 .14419 .40181 Metetra
.863 .513 0 r
.14419 .40181 .15414 .45603 .17482 .44861 .1647 .39446 Metetra
.862 .515 0 r
.1647 .39446 .17482 .44861 .19566 .44118 .18537 .38705 Metetra
.861 .517 0 r
.18537 .38705 .19566 .44118 .21667 .43372 .20621 .3796 Metetra
.861 .519 0 r
.20621 .3796 .21667 .43372 .23783 .42624 .22721 .3721 Metetra
.86 .52 0 r
.22721 .3721 .23783 .42624 .25917 .41873 .24839 .36453 Metetra
.86 .522 0 r
.24839 .36453 .25917 .41873 .28068 .4112 .26973 .35693 Metetra
.86 .522 0 r
.26973 .35693 .28068 .4112 .30236 .40364 .29125 .34927 Metetra
.86 .523 0 r
.29125 .34927 .30236 .40364 .32421 .39605 .31295 .34155 Metetra
.859 .523 0 r
.31295 .34155 .32421 .39605 .34625 .38844 .33482 .33378 Metetra
.859 .524 0 r
.33482 .33378 .34625 .38844 .36846 .38079 .35688 .32595 Metetra
.859 .524 0 r
.35688 .32595 .36846 .38079 .39086 .37312 .37912 .31807 Metetra
.86 .523 0 r
.37912 .31807 .39086 .37312 .41345 .36541 .40154 .31013 Metetra
.86 .523 0 r
.40154 .31013 .41345 .36541 .43623 .35767 .42416 .30213 Metetra
.86 .522 0 r
.42416 .30213 .43623 .35767 .45921 .34989 .44696 .29407 Metetra
.86 .521 0 r
.44696 .29407 .45921 .34989 .48238 .34209 .46996 .28595 Metetra
.861 .52 0 r
.46996 .28595 .48238 .34209 .50575 .33425 .49316 .27777 Metetra
.861 .518 0 r
.49316 .27777 .50575 .33425 .52932 .32638 .51655 .26953 Metetra
.862 .517 0 r
.51655 .26953 .52932 .32638 .55311 .31848 .54015 .26122 Metetra
.862 .515 0 r
.54015 .26122 .55311 .31848 .5771 .31055 .56395 .25286 Metetra
.863 .512 0 r
.56395 .25286 .5771 .31055 .60131 .30258 .58796 .24443 Metetra
.864 .51 0 r
.58796 .24443 .60131 .30258 .62574 .29458 .61218 .23593 Metetra
.864 .509 0 r
.61218 .23593 .62574 .29458 .65038 .28625 .6366 .2271 Metetra
.859 .525 0 r
.6366 .2271 .65038 .28625 .67508 .27477 .66112 .21549 Metetra
.822 .635 0 r
.66112 .21549 .67508 .27477 .69903 .2467 .68504 .18947 Metetra
.443 .687 0 r
.68504 .18947 .69903 .2467 .72017 .17712 .70668 .12745 Metetra
0 .35 .286 r
.03634 .26033 .04283 .32486 .05077 .39206 .04718 .30442 Metetra
0 .531 .016 r
.04718 .30442 .05077 .39206 .0652 .42042 .0627 .32166 Metetra
.17 .603 0 r
.0627 .32166 .0652 .42042 .08379 .42228 .0812 .32081 Metetra
.219 .62 0 r
.0812 .32081 .08379 .42228 .10366 .41629 .10065 .31456 Metetra
.227 .622 0 r
.10065 .31456 .10366 .41629 .12384 .40912 .12036 .30747 Metetra
.228 .623 0 r
.12036 .30747 .12384 .40912 .14419 .40181 .14024 .30023 Metetra
.229 .623 0 r
.14024 .30023 .14419 .40181 .1647 .39446 .16029 .29291 Metetra
.229 .623 0 r
.16029 .29291 .1647 .39446 .18537 .38705 .1805 .28551 Metetra
.23 .624 0 r
.1805 .28551 .18537 .38705 .20621 .3796 .20087 .27802 Metetra
.23 .624 0 r
.20087 .27802 .20621 .3796 .22721 .3721 .22141 .27046 Metetra
.231 .624 0 r
.22141 .27046 .22721 .3721 .24839 .36453 .24212 .2628 Metetra
.231 .624 0 r
.24212 .2628 .24839 .36453 .26973 .35693 .26299 .25507 Metetra
.232 .624 0 r
.26299 .25507 .26973 .35693 .29125 .34927 .28404 .24725 Metetra
.232 .624 0 r
.28404 .24725 .29125 .34927 .31295 .34155 .30526 .23935 Metetra
.232 .624 0 r
.30526 .23935 .31295 .34155 .33482 .33378 .32665 .23136 Metetra
.232 .624 0 r
.32665 .23136 .33482 .33378 .35688 .32595 .34822 .22328 Metetra
.232 .624 0 r
.34822 .22328 .35688 .32595 .37912 .31807 .36996 .21512 Metetra
.232 .624 0 r
.36996 .21512 .37912 .31807 .40154 .31013 .39189 .20687 Metetra
.232 .624 0 r
.39189 .20687 .40154 .31013 .42416 .30213 .41399 .19854 Metetra
.232 .624 0 r
.41399 .19854 .42416 .30213 .44696 .29407 .43628 .19011 Metetra
.231 .624 0 r
.43628 .19011 .44696 .29407 .46996 .28595 .45875 .18159 Metetra
.231 .624 0 r
.45875 .18159 .46996 .28595 .49316 .27777 .48141 .17298 Metetra
.23 .624 0 r
.48141 .17298 .49316 .27777 .51655 .26953 .50426 .16427 Metetra
.23 .624 0 r
.50426 .16427 .51655 .26953 .54015 .26122 .5273 .15547 Metetra
.229 .623 0 r
.5273 .15547 .54015 .26122 .56395 .25286 .55052 .14657 Metetra
.228 .623 0 r
.55052 .14657 .56395 .25286 .58796 .24443 .57395 .13757 Metetra
.228 .623 0 r
.57395 .13757 .58796 .24443 .61218 .23593 .59756 .12846 Metetra
.225 .622 0 r
.59756 .12846 .61218 .23593 .6366 .2271 .62137 .11907 Metetra
.209 .617 0 r
.62137 .11907 .6366 .2271 .66112 .21549 .6453 .10775 Metetra
.119 .585 0 r
.6453 .10775 .66112 .21549 .68504 .18947 .66892 .08664 Metetra
0 .476 .129 r
.66892 .08664 .68504 .18947 .70668 .12745 .69112 .04105 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14789 .21178 m
.15252 .21643 L
s
[(-5)] .13865 .20246 .99238 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.5537 .05288 m
.55757 .05817 L
s
[(5)] .54594 .04229 .73209 1 Mshowa
.125 Mabswid
.18577 .19694 m
.18851 .19978 L
s
.22422 .18189 m
.22691 .18476 L
s
.26324 .16661 m
.2659 .16952 L
s
.30285 .1511 m
.30546 .15404 L
s
.3839 .11937 m
.38642 .12239 L
s
.42536 .10313 m
.42784 .10619 L
s
.46747 .08664 m
.4699 .08974 L
s
.51024 .06989 m
.51262 .07303 L
s
.11057 .22639 m
.11338 .22915 L
s
.07378 .2408 m
.07662 .24352 L
s
.03752 .255 m
.0404 .25768 L
s
.59784 .03559 m
.60011 .03881 L
s
.64269 .01803 m
.64491 .02128 L
s
.68828 .00018 m
.69043 .00347 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00c?ooool2o`0005;ooooo0039
ooooo`Ko0000DOooool00<Oooooo0_l00004ooooo`;o0000DOooool00:Cooooo0ol0000Mooooo`?o
00001_ooool00ol0003oooooo`00001@ooooo`00Xoooool01Ol0003ooooooooooooooooo000001[o
oooo0_l00009ooooo`03o`000?oooooo0000053ooooo002Wooooo`03o`000?oooooooooo01Gooooo
0ol0000;ooooo`04o`000?ooooooooooo`0004oooooo002Wooooo`03o`000?oooooooooo01?ooooo
0_l00003ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00001>ooooo`00
Xoooool4o`0001?ooooo0ol0000@ooooo`05o`000?ooooooooooooooool00000C_ooool00:?ooooo
00?o0000ooooooooool04Oooool3o`0001?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1;ooooo`00Xoooool5o`0000gooooo0_l0000Gooooo`04o`000?ooooooooooooooo`;o0000
C?ooool00;;ooooo0ol000000ooooooo0000ooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0B_ooool00;3ooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0BOooool00:gooooo0ol0000Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0B?ooool00:_ooooo0_l0000Pooooo`;o00001_ooool00ol0003oooooooooo`18ooooo`00
Z?ooool3o`0002;ooooo0_l00007ooooo`03o`000?oooooooooo04Oooooo002Vooooo`;o00000ooo
ool00ol0003oooooooooo`0Nooooo`04o`000?l0NB7o0000o`0000Oooooo00?o0000ooooooooool0
A_ooool00:?ooooo0ol0000Vooooo`04o`000?l0NB7o0000o`0000Oooooo00?o0000ooooooooool0
A_ooool00:7ooooo0_l0000Xooooo`03o`000?l0NB7o07TQ00;o00002?ooool00ol0003ooooooooo
o`15ooooo`00W_ooool3o`0002[ooooo00?o0000o`1i8Ol0NB400_l00007ooooo`03o`000?oooooo
000004Kooooo002Looooo`;o000000?oooooo`000?ooool0:Oooool01?l0003o07TQo`1i8Ol0NB42
o`0000Wooooo00?o0000ooooooooool0A?ooool009Wooooo0ol0000^ooooo`04o`000?l0NB7o07TQ
o`1i8@;o00002_ooool00ol0003oooooooooo`0;ooooo`?o0000=Oooool009Kooooo0ol0000`oooo
o`03o`000?l0NB7o07TQ00;o07TQ00?o0000o`1i8Ol000002_ooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool00000=?ooool009Cooooo0_l0000cooooo`03o`000?l0NB7o07TQ
00;o07TQ00?o0000o`1i8Ol000002_ooool00ol0003oooooooooo`03ooooo`Go00001Oooool00ol0
003oooooooooo`0booooo`00TOooool4o`0003;ooooo0_l00005o`1i8@03o`000?l0NB7o000000_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`00Soooool2o`0000?ooooo
00?o0000ooooooooool0;oooool00ol0003o7YD0o`000005o`1i8@03o`000?l0NB7o000000cooooo
00?o0000ooooooooool01oooool4o`0003Gooooo001]ooooo`;o00007Oooool3o`0003Kooooo00Co
0000oajE0?lNU@3o00001_l0NB42o`0000cooooo0_l00008ooooo`03o`000?oooooooooo03Kooooo
001/ooooo`04o`000?ooooooooooo`0001[ooooo0_l0000hooooo`05o`000?lNU@3o7YD0oajE0?l0
00001_l0NB400ol0003o07TQo`00000:ooooo`03o`000?oooooo000000Sooooo1Ol0000dooooo`00
K?ooool01?l0003oooooooooool0000Gooooo`?o0000>Oooool00ol0003o7YD0oajE0003oajE0003
o`000?l0NB7o07TQ00?o07TQ00?o0000o`1i8Ol000003Oooool00ol0003oooooooooo`0nooooo`00
K?ooool01?l0003oooooooooool0000Eooooo`;o00000_ooool00ol0003oooooooooo`0eooooo`;o
00001_lNU@000ol0003o07TQo`1i8@03o`1i8@03o`000?l0NB7o000000gooooo00?o0000oooooooo
ool0?_ooool006cooooo00Co0000oooooooooooo00004_ooool3o`0003[ooooo0_l000000oleW@3o
0000oajE0005oajE0003o`000?l0NB7o07TQ00?o07TQ00?o0000o`1i8Ol000003_ooool00ol0003o
ooooooooo`0mooooo`00K?ooool01?l0003oooooooooool0000@ooooo`;o0000>oooool2o`0000?o
=Id000?o0000oajE0?lNU@001?lNU@000ol0003o07TQo`1i8@03o`1i8@03o`000?l0NB7o000000ko
oooo00?o0000ooooooooool0?Oooool006gooooo0_l0000>ooooo`?o0000>oooool2o`0000Go=Id0
00?o0000oajE0?lNU@001?lNU@000ol0003o07TQo`1i8@03o`1i8@03o`000?l0NB7o000000oooooo
00?o0000ooooooooool0??ooool007_ooooo0_l000000ooooooo0000ooooo`0iooooo`;o000000?o
>Il0o`000?leW@001?leW@000ol0003o7YD0oajE0004oajE0003o`000?l0NB7o07TQ00?o07TQ00Co
0000o`1i8Ol0NB7o00003oooool00ol0003oooooooooo`0kooooo`00N?ooool3o`0003cooooo0_l0
0003ocVO0003o`000?leW@3o=Id000Co=Id000?o0000oajE0?lNU@000olNU@000ol0003o07TQo`1i
8@03o`1i8@04o`000?l0NB7o07TQo`0000oooooo0_l0000looooo`00MOooool3o`0003cooooo0ol0
0005ocVO0003o`000?leW@3o=Id000Co=Id000?o0000oajE0?lNU@001?lNU@000ol0003o07TQo`1i
8@02o`1i8@04o`000?l0NB7o07TQo`00013ooooo00?o0000ooooooooool0>_ooool007?ooooo0_l0
000looooo`?o00000_ljW`000ol0003o>Il0ocVO0003ocVO0003o`000?leW@3o=Id000Co=Id000?o
0000oajE0?lNU@001?lNU@000ol0003o07TQo`1i8@02o`1i8@04o`000?l0NB7o07TQo`00017ooooo
00?o0000ooooooooool0>Oooool0073ooooo1?l0000jooooo`?o00001OljW`000ol0003o>Il0ocVO
0004ocVO0003o`000?leW@3o=Id000?o=Id000?o0000oajE0?lNU@001?lNU@000ol0003o07TQo`1i
8@02o`1i8@04o`000?l0NB7o0000o`00017ooooo00?o0000ooooooooool0>Oooool006kooooo0_l0
0004ooooo`03o`000?oooooooooo03Gooooo0_l000000oljW`3o0000ocZO0005ocZO0003o`000?li
W`3o>Il000Co>Il000?o0000ocFM0?leW@000oleW@000ol0003o7YD0oajE0004oajE0003o`000?l0
NB7o07TQ00;o07TQ00Go0000o`1i8Ol0003oLJl0o`00000Aooooo`03o`000?oooooooooo03Sooooo
001[ooooo`?o0000??ooool2o`0000?o>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o>Il0ocVO
0004ocVO0003o`000?leW@3o=Id000?o=Id000?o0000oajE0?lNU@001?lNU@000ol0003o07TQo`1i
8@02o`1i8@05o`000?l0NB7o0000og6_0?l000004_ooool00ol0003oooooooooo`0gooooo`00JOoo
ool2o`0003gooooo0_l00005ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocVO0?liW`001?li
W`000ol0003o=Id0ocFM0003ocFM0003o`000?lNU@3o7YD000Co7YD000?o0000o`1i8Ol0NB400_l0
NB42o`0000;oLJl000?o0000ooooooooool04?ooool00ol0003oooooooooo`0gooooo`00I_ooool4
o`0003_ooooo0ol000000oljW`3o0000ocZO0005ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000
ocVO0?liW`000oliW`000ol0003o=Id0ocFM0004ocFM0003o`000?lNU@3o7YD000?o7YD000?o0000
o`1i8Ol0NB400_l0NB42o`0000?oLJl000?o0000ooooooooool04?ooool00ol0003oooooooooo`0f
ooooo`00I?ooool2o`0003cooooo0ol00004ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocZO
0?ljW`001?ljW`000ol0003o>Il0ocVO0003ocVO0003o`000?leW@3o=Id000Co=Id000?o0000oajE
0?lNU@001?lNU@000ol0003o07TQo`1i8@02o`1i8@05o`000?ma[`3oLJl0og6_0?l000004_ooool2
o`0003Oooooo001Qooooo`?o0000>oooool3o`000003ocZO0?l0003o>Yl000Co>Yl000?o0000ocZO
0?ljW`001?ljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?liW`3o>Il000?o>Il000?o0000ocFM
0?leW@001?leW@000ol0003o7YD0oajE0004oajE0004o`000?l0NB7o07TQo`1i8@;o00000oma[`00
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Gooooo001Oooooo`;o0000>oooool3o`00
00Co>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl0
00Co>Yl000?o0000ocVO0?liW`001?liW`000ol0003o=Id0ocFM0003ocFM0003o`000?lNU@3o7YD0
00Co7YD000Co0000o`1i8Ol0NB7o07TQ0_l00004og6_0003o`000?oooooooooo017ooooo00?o0000
ooooooooool0=?ooool005cooooo0ol0000jooooo`?o000000?o>Yl0o`000?ljW`001?ljW`000ol0
003o>Yl0ocZO0004ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`001?ljW`000ol0
003o>Il0ocVO0004ocVO0003o`000?leW@3o=Id000?o=Id000?o0000oajE0?lNU@001?lNU@001_l0
003o07TQo`1i8Ol0003oLJl0o`0000CoLJl000?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0cooooo`00>Oooool3o`0001kooooo0_l00003ooooo`03o`000?oooooooooo03Cooooo0ol00004
ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO0003
ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocVO0?liW`001?liW`000ol0003o=Id0ocFM0003
ocFM0003o`000?lNU@3o7YD000Co7YD000Ko0000o`1i8Ol0NB7o0000og6_0?l00004og6_0003o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0<oooool003Sooooo00Go0000oooooooooooooooo
o`00000Jooooo`?o0000>_ooool2o`000003oc^O0?l0003o>Yl000Co>Yl000?o0000ocZO0?ljW`00
1?ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`00
1?ljW`000ol0003o>Il0ocVO0004ocVO0003o`000?leW@3o=Id000?o=Id000?o0000oajE0?lNU@00
1?lNU@001_l0003o07TQo`1i8Ol0003oLJl0o`0000GoLJl000?o0000ooooooooool04_ooool00ol0
003oooooooooo`0booooo`00<_ooool5o`0000Gooooo00?o0000ooooooooool05Oooool3o`0003_o
oooo0_l00003oc^O0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o
>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o
>Il0ocVO0004ocVO0003o`000?leW@3o=Id000Co=Id000?o0000oajE0?lNU@000olNU@000ol0003o
07TQo`000002og6_0003o`000?ma[`3oLJl000?oLJl000?o0000ooooooooool04oooool00ol0003o
ooooooooo`0aooooo`00??ooool00ol0003oooooooooo`0Cooooo`Co0000>_ooool2o`0000Go>il0
00?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?ljW`3o>Yl000?o>Yl0
00?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?liW`3o>Il000Co>Il0
00?o0000ocFM0?leW@001?leW@000ol0003o7YD0oajE0004oajE00;o00000_ma[`000ol0003oLJl0
og6_0003og6_0003o`000?oooooooooo01?ooooo0_l0000booooo`00>?ooool4o`0001?ooooo0ol0
000kooooo`?o000000?o>il0o`000?lkW`001?lkW`000ol0003o>Yl0ocZO0004ocZO0003o`000?lj
W`3o>Yl000?o>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?lj
W`3o>Yl000Co>Yl000?o0000ocVO0?liW`000oliW`000ol0003o=Id0ocFM0004ocFM0003o`000?lN
U@3o7YD000Co7YD00_l00002og6_0003o`000?ma[`3oLJl000;oLJl000?o0000olG40?l000005Ooo
ool00ol0003oooooooooo`0`ooooo`00>?ooool00ol0003oooooooooo`0Booooo`;o0000>oooool3
o`0000Co>il000?o0000oc^O0?lkW`000olkW`000ol0003o>Yl0ocZO0004ocZO0003o`000?ljW`3o
>Yl000?o>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o
>Yl000Co>Yl000?o0000ocVO0?liW`001?liW`000ol0003o=Id0ocFM0003ocFM0003o`000?lNU@3o
7YD000Co7YD000Go0000og6_0?ma[`3oLJl0o`000004og6_0003o`000?o5a03o000001Kooooo00?o
0000ooooooooool0;oooool003Sooooo1Ol0000=ooooo`?o0000>_ooool3o`000003oc^O0?l0003o
>il000Co>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o
>Yl000?o>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o
>Yl000Co>Yl000?o0000ocVO0?liW`001?liW`000ol0003o=Id0ocFM0003ocFM0003o`000?lNU@3o
7YD000Co7YD000Go0000og6_0?ma[`3oLJl0o`000004og6_0004o`000?o5a03oaL@0o`0001Gooooo
00?o0000ooooooooool0;oooool004Sooooo1?l0000iooooo`;o00001?lkW`000ol0003o>il0oc^O
0003oc^O0003o`000?lkW`3o>il000Co>il000?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO
0004ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO
0004ocZO0003o`000?liW`3o>Il000Co>Il000?o0000ocFM0?leW@000oleW@000ol0003o7YD0oajE
0003oajE00;o00000oma[`001Ol0003oLJl0og6_0?ma[`3o000000?oaL@000?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0^ooooo`00AOooool3o`0003[ooooo0ol000000olkW`3o0000oc^O
0003oc^O0003o`000?lkW`3o>il000Co>il000?o0000oc^O0?lkW`000olkW`000ol0003o>Yl0ocZO
0003ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO
0003ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocVO0?liW`001?liW`000ol0003o=Id0ocFM
0003ocFM0003o`000?lNU@3o7YD000;o7YD000Co0000om:R0?oBXP3o00000_ma[`001Ol0003oLJl0
og6_0?ma[`3o000000CoaL@000?o0000ooooooooool05?ooool00ol0003oooooooooo`0]ooooo`00
@oooool2o`0003[ooooo0ol00004oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lkW`00
1?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`00
1?ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocZO0?ljW`00
0oljW`000ol0003o>Il0ocVO0004ocVO0003o`000?leW@3o=Id000Co=Id000Co0000oajE0?lNU@3o
00000ooBXP001?l0003oLJl0og6_0?l00003og6_0003o`000?o5a03oaL@000;oaL@000?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0]ooooo`00@?ooool3o`0003Wooooo0ol000000olkW`3o
0000oc^O0004oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o
>il0oc^O0003oc^O0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o
>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o
>Il0ocVO0004ocVO0003o`000?leW@3o=Id000Co=Id000?o0000oajE0?l000001?oBXP001?l0003o
LJl0og6_0?l00002og6_0003o`000?o5a03oaL@000;oaL@000?o0000olVh0?l000005_ooool00ol0
003oooooooooo`0/ooooo`00?_ooool3o`0003Sooooo0ol00004oc^O0003o`000?lkW`3o>il000?o
>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o
>il000?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?ljW`3o>Yl000?o
>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?liW`3o>Il000Co
>Il000?o0000ocFM0?leW@001?leW@02o`0000GodZ8000Co0000og6_0?ma[`3o00000_ma[`000ol0
003oaL@0olG40002olG40004o`000?o9^03obKP0o`0001Cooooo00?o0000ooooool00000;Oooool0
03_ooooo0ol00003ooooo`03o`000?oooooooooo03?ooooo0_l000000olkW`3o0000oc^O0004oc^O
0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O
0003o`000?lkW`3o>il000?o>il000?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO0004ocZO
0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO0003ocZO
0003o`000?liW`3o>Il000Go>Il000?o0000ocFM0?leW@000_leW@02o`0000OodZ8000Ko0000og6_
0?ma[`3o0000og6_0?l00004olG40005o`000?o9^03obKP0olVh0?l000005Oooool00ol0003ooooo
ooooo`06ooooo`;o00008oooool003Wooooo0_l0000kooooo`05o`000?lkW`3o>il0oc^O0?l00000
1OlkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`00
0olkW`000ol0003o>il0oc^O0003oc^O0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocZO0?ljW`00
0oljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`00
1?ljW`000ol0003o>Il0ocVO0004ocVO0003o`000?leW@3o=Id000;o000000?ofhH0o`000?oBXP00
1_oBXP000ol0003oLJl0og6_0002o`0000CoaL@000?o0000olVh0?o9^0000_o9^0000ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00008_ooool003Kooooo
0ol0000kooooo`;o00001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il0
00?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il0
00?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?ljW`3o>Yl000?o>Yl0
00?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?liW`3o>Il000Co>Il0
0ol00003om^60003o`000?oBXP3odZ8000GodZ8000?o0000og6_0?ma[`000_l00004olG40003o`00
0?o9^03obKP000;obKP00_l0000Fooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00008_ooool003?ooooo0ol000000ooooooo0000ooooo`0hooooo`?o000000?o>il0o`000?lkW`00
0olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000Co>il000?o0000oc^O0?lkW`00
0_lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000Co>il000?o0000ocZO0?ljW`00
0oljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`00
0oljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?liW`3o>Il000;o>Il00ol00006om^60003o`00
0?oBXP3odZ8000GodZ8000Co0000og6_0?l0003o00001?o5a0001ol0003obKP0olVh0?o9^03o0000
olZg0?l000005_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0002;ooooo000a
ooooo`;o0000>oooool3o`0000Co>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002
oc^O0003o`000?lkW`3o>il000Co>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003
oc^O0003o`000?lkW`3o>il000Co>il000?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO0004
ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO0003
ocZO0003o`000?liW`3o000000;o00000_oMPP000ol0003ofhH0om^60004om^60003o`000?oBXP3o
dZ8000GodZ8000?o0000og6_0?l000001?o5a0000ol0003obKP0olVh0002olVh0003o`000?o:]`3o
000001Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Rooooo`00;_ooool3
o`0003[ooooo0ol000000olkW`3o0000oc^O0004oc^O0003o`000?lkW`3o>il000?o>il000?o0000
oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000
oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?ljW`3o>Yl000?o>Yl000?o0000
ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000
ocZO0?ljW`000_ljW`03o`0000GogH8000?o0000om^60?oKQP001?oKQP000ol0003odZ80om:R0005
om:R0003o`000?ma[`3o000000CoaL@000?o0000olVh0?o9^0000_o9^0001?l0003ob[L0olZg0?l0
000Fooooo`;o00000oooool01?l0003oooooooooool0000Rooooo`00;?ooool2o`0003[ooooo0ol0
0004oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O
0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O
0004oc^O0003o`000?lkW`3o>il000?o>il000?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO
0004ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0o`00
0002o`000003omf20?l0003ogH8000KogH8000?o0000om^60?oKQP000ooKQP000ol0003odZ80om:R
0005om:R0003o`000?ma[`3o000000CoaL@000Go0000olVh0?o9^03obKP0o`000003olZg0003o`00
0?oooooooooo01?ooooo00?o0000ooooool000001?ooool2o`0002?ooooo000Yooooo`?o00000_oo
ool00ol0003oooooooooo`0dooooo`?o000000?o>il0o`000?lkW`001?lkW`000ol0003o>il0oc^O
0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O
0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O
0003oc^O0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO
0004ocZO0003o`000?ljW`3o>Yl000;o>Yl00ol00004omf20003o`000?oMPP3ogH8000GogH8000?o
0000om^60?oKQP001?oKQP000ol0003odZ80om:R0005om:R00;o00000oo5a0000ol0003obKP0olVh
0002olVh0004o`000?o:]`3ob[L0olZg00;o00005oooool00ol0003oooooooooo`0Vooooo`009ooo
ool2o`0003[ooooo0_l00004oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olk
W`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olk
W`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olk
W`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocZO0?ljW`001?lj
W`000ol0003o>Yl0o`000002o`000003omb30?l0003ogH8000GogH8000?o0000omf20?oMPP001?oM
PP000ol0003ofhH0om^60004om^60003o`000?oBXP3odZ8000;odZ801Ol00003olG40003o`000?o9
^03obKP000;obKP000Co0000olZg0?o:]`3o00000_o:]`000ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02Gooooo000Tooooo`?o0000>Oooool3o`000003oc^O0?l0003o>il000?o>il000?o
0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000;o>il000?o
0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o
0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?ljW`3o>Yl000?o>Yl000?o
0000ocZO0?ljW`001OljW`000ol0003o>Yl0ocZO0002ocZO00?o00001?oLP`000ol0003ogH80omf2
0004omf20003o`000?oMPP3ogH8000CogH8000?o0000om^60?oKQP001?oKQP000ol0003odZ80o`00
0002o`0000?odZ8000?o0000olG40?l000000_o5a0001Ol0003obKP0olVh0?o9^03o000000?ob[L0
00Go0000olZg0?o:]`3ob[L0o`00000Fooooo`03o`000?oooooooooo02Gooooo000Sooooo`;o0000
>?ooool3o`0000Co>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000Co>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000?o>il000?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO0004ocZO0003o`00
0?ljW`3o000000;o000000?og8<0o`000?oLP`001OoLP`000ol0003ogH80omf20003omf20003o`00
0?oMPP3ogH8000CogH8000?o0000om^60?oKQP000ooKQP03o`0000GodZ8000Co0000onUG0?l0003o
aL@00_l00004olVh0005o`000?o:]`3ob[L0olZg0?l000000oo:]`000ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02Cooooo000Sooooo`?o0000=?ooool3o`000003oc^O0?l0003o>il000Co
>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000?o
>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o
>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o
>il000?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO0003ocZO00?o00001?oLP`000ol0003o
g8<0omb30004omb30003o`000?oMPP3ogH8000?ogH8000?o0000omf20?oMPP001OoMPP000ol0003o
fhH0o`000002o`0000;ofhH000?o0000om:R0?oBXP000_oBXP001?l0003ojEL0onUG0?l00002olG4
0003o`000?o9^03obKP000;obKP000Co0000olZg0?o:]`3o00001?o:]`02o`0001Oooooo00?o0000
ooooooooool08oooool002?ooooo00Co0000oooooooooooo0000<Oooool2o`0000Co>il000?o0000
oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000Co>il000?o0000
oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000
oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000
oc^O0?lkW`001?lkW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000?o000000?og8@0
o`000?oLP`001OoLP`000ol0003og8<0omb30003omb30003o`000?oMPP3ogH8000CogH8000?o0000
omf20?oMPP000ooMPP03o`0000GofhH000Go0000om:R0?oBXP3odZ80o`000004onUG0003o`000?o5
a03o000000?obKP000Go0000olZg0?o:]`3ob[L0o`000003olZg0004o`000?o:^03ob[P0o`0001Go
oooo0_l0000Uooooo`008oooool2o`0000;ooooo00?o0000ooooooooool0:oooool3o`000003oc^O
0?l0003o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000;o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>Yl0ocZO0003ocZO00?o0000
1?oLQ0000ol0003og8<0omb30004omb30003o`000?oLP`3og8<000?og8<000?o0000omf20?oMPP00
1?oMPP000ol0003ogH80omf20003o`000003omf20?l0003ofhH000GofhH000Co0000om:R0?oBXP3o
00001OoYE`02o`000005olVh0?l0003obKP0olVh0?l000000oo:]`001Ol0003ob[L0olZg0?o:]`3o
000000?ob[P000?o0000ooooooooool05?ooool00ol0003oooooooooo`0Rooooo`008_ooool3o`00
00?ooooo00?o0000ooooooooool09oooool3o`0000Co>il000?o0000oc^O0?lkW`000_lkW`000ol0
003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0
003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`000ol0
003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`001?lkW`000ol0
003o>il0oc^O0003oc^O0003o`000?ljW`3o>Yl000;o>Yl00_l00007omb40003o`000?oLP`3og8<0
00?og8<000?o0000omb30?oLP`001?oLP`000ol0003ogH80omf20003omf200?o00001?oMPP000ol0
003ofhH0om^60005om^600;o00001ooYE`001_l0003obKP0olVh0?l0003obKP0o`0000?ob[L000Go
0000olZg0?o:]`3ob[L0o`000003olZh00;o00005_ooool00ol0003oooooooooo`0Qooooo`002_oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol00004ooooo`?o00001?oo
ool00ol0003oooooooooo`0Sooooo`?o000000?o>Yl0o`000?lkW`001?lkW`000ol0003o>il0oc^O
0002oc^O0003o`000?lkW`3o>il000Co>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O
0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O
0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O
0004oc^O0003o`000?lkW`3o>il000?o>il000?o0000ocZO0?l000000_l000000ooLQ03o0000omb4
0006omb40003o`000?oLP`3og8<000?og8<000?o0000omb30?oLP`001?oLP`001?l0003ogH80omf2
0?oMPP04o`0000GogH8000?o0000om^60?oKQP001?oKQP02o`0000SojEL000?o0000olVh0?o9^000
0_l00003olZg0005o`000?o:]`3ob[L0olZg0?l000001?o:^0000ol0003ob[P0o`00000Eooooo`03
o`000?oooooooooo027ooooo0009ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooooooo`?o00001Oooool00ol0003oooooooooo`0P
ooooo`;o00001?ljW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000
oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000
oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000
oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000
oc^O0?lkW`000_lkW`03o`0000Cog8@000?o0000omb40?oLQ0001OoLQ0000ol0003og8<0omb30003
omb30003o`000?oLP`3og8<000Cog8<01?l00003omf20003o`000?oMPP3ogH8000CogH8000?o0000
om^60?oKQP000ol000000ooc<P3o0000onUG0006onUG0003o`000?o^A@3o000000;obKP000Go0000
olZg0?o:]`3ob[L0o`000003olZg0005o`000?o:^03ob[P0olZh0?l000000oo:^0000ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo023ooooo0009ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool01Oooool01ol0003ooooooooooooooooo0000ooooool000001_ooool00ol0
003oooooooooo`0Looooo`?o000000?o>Yl0o`000?ljW`000oljW`000ol0003o>il0oc^O0003oc^O
0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O
0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O
0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O
0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?l000000_l000000ooLQ@3o0000omb40005omb4
0003o`000?oLQ03og8@000Cog8@000?o0000omb30?oLP`001?oLP`001?l0003og8<0omb30?oLP`04
o`0000GogH8000?o0000omf20?oMPP001?oMPP03o`0000Golc8000?o0000onUG0?oYE`000ooYE`00
1_l0003okTD0oni50?o^A@3o0000olVh00;o00000_o:]`001Ol0003ob[L0olZg0?o:]`3o000000?o
b[P000Go0000olZh0?o:^03ob[P0o`00000Fooooo`03o`000?oooooooooo01oooooo0009ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool4
o`0000Kooooo00?o0000ooooooooool06Oooool2o`0000Co>Yl000?o0000ocZO0?ljW`000_ljW`00
0ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`00
0ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`00
0ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`00
0ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il00ol00004omb50003o`000?oLQ03o
g8@000Cog8@000?o0000omb40?oLQ0001?oLQ0000ol0003og8<0omb30004omb300Co00000ooLP`00
0ol0003ogH80omf20003omf20003o`000?oMPP3ogH8000?ogH800_l00007oo<b0003o`000?oYE`3o
jEL000;ojEL000?o0000oni50?o^A@000_o^A@02o`0000;ob[L000?o0000olZg0?l000000oo:]`00
1Ol0003ob[P0olZh0?o:^03o000000?ob[P00_l0000Eooooo`03o`000?oooooooooo01oooooo0009
ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooooooo1?l00004ooooo`04o`00
0?oooooo0000o`0000Oooooo00?o0000ooooooooool05Oooool3o`000003ocZO0?l0003o>Yl000?o
>Yl000?o0000ocZO0?ljW`000_ljW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o
>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o
>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o
>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o000000;o
000000?og8D0o`000?oLQ@001OoLQ@000ol0003og8@0omb40003omb40003o`000?oLQ03og8@000Go
g8@000Co0000omb30?oLP`3og8<00ol00006omb30003o`000?oMPP3ogH8000CogH8000?o0000omf2
0?l000000_l000000ood;@3o0000oo<b0007oo<b0005o`000?oYE`3ojEL0onUG0?l000001Oo^A@00
0ol0003ob[L0olZg0002o`0000?ob[L000Go0000olZh0?o:^03ob[P0o`000003olZh0003o`000?o9
^03o000001Gooooo0_l0000Pooooo`002Oooool01?l0003oooooooooool00008ooooo`;o00000ooo
ool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000ooooooooool0
4Oooool3o`0000Co>Yl000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0002ocZO0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000;o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000;o>il00ol00004omb50003o`000?oLQ@3og8D000Cog8D000?o0000omb40?oLQ000
1?oLQ0000ol0003og8@0omb40004omb400Co00000_oLP`000ol0003og8<0omb30004omb30003o`00
0?oMPP3ogH8000?ogH800ol00005oo@]0003o`000?oc<P3olc8000Golc8000Co0000onUG0?oYE`3o
00001_o^A@001Ol0003ob[L0olZg0?o:]`3o000000?ob[L000Go0000olZh0?o:^03ob[P0o`000003
olZh0004o`000?o9^03obKP0o`0001Kooooo00?o0000ooooooooool07Oooool000[ooooo0_l0000:
ooooo`04o`000?ooooooooooooooo`Go00000_ooool5o`0000Wooooo00?o0000ooooooooool03Ooo
ool3o`000003ocZO0?l0003o>Yl000Co>Yl000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO
0003ocZO0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O
0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O
0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O
0003oc^O0003o`000?lkW`3o000000;o000000?og8D0o`000?oLQ@001OoLQ@000ol0003og8D0omb5
0003omb50003o`000?oLQ03og8@000Cog8@000?o0000omb40?oLQ0000ooLQ002o`0000Gog8<000?o
0000omb30?oLP`001OoLP`000ol0003ogH80o`000002o`000003oo@^0?l0003om2d000Gom2d000?o
0000oo<b0?oc<P001Ooc<P000ol0003ojEL0o`000006oni50003o`000?o_A03o000000;ob[L00_l0
0002olZg0005o`000?o:^03ob[P0olZh0?l000000oo:^0001?l0003obKP0olVh0?l0000Fooooo`03
o`000?oooooooooo01gooooo000Qooooo`06o`000?ooooooooooo`000?l0FDWo00002Oooool00ol0
003oooooooooo`0:ooooo`;o00001?ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl0
00;o>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il0
00?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il0
00?o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il0
00;o>il000?o0000oc^O0?lkW`000_lkW`03o`0000Cog8D000?o0000omb50?oLQ@001?oLQ@000ol0
003og8D0omb50004omb50003o`000?oLQ03og8@000?og8@000?o0000omb40?oLQ0000ol000000ooL
Q03o0000omb30005omb30003o`000?oLP`3og8<000;og8<01?l00005oo@^0003o`000?od;@3om2d0
00Com2d000?o0000oo<b0?oc<P001?oc<P02o`0000KokTD000Co0000onm40?o_A03okd@00_l00002
olZg0003o`000?o:]`3o000000;ob[P000Go0000olZh0?o:^03ob[P0o`000003olVh00;o00005_oo
ool00ol0003oooooooooo`0Looooo`008Oooool2o`000004ooooool0003o05U9o`0000[ooooo00?o
0000ooooooooool01_ooool3o`000003ocZO0?l0003o>Yl000?o>Yl000?o0000ocZO0?ljW`000olj
W`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000oc^O0?lkW`000_lk
W`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lk
W`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000Co>il000?o0000oc^O0?lkW`000olk
W`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o000000;o000000?og8D0o`000?oLQ@001OoL
Q@000ol0003og8D0omb50003omb50003o`000?oLQ@3og8D000Cog8D000?o0000omb40?oLQ0000ooL
Q003o`0000Cog8@000?o0000omb30?oLP`001?oLP`000ol0003og8<0o`000002o`0000;om2l000?o
0000oo@^0?od;P001?od;P000ol0003om2d0oo@]0005oo@]0004o`000?oc<P3olc80oo<b00;o0000
00?on1d0o`000?o^A@001?o^A@000ol0003okd@0onm40003onm40003o`000?o:]`3ob[L000;o0000
0oo:^0001Ol0003ob[P0olZh0?o:^03o000000;obKP000Co0000olVh0?o9^03o00005_ooool00ol0
003oooooooooo`0Kooooo`008Oooool01Ol0003oooooooooool0003o05U900;o00002_ooool00ol0
003oooooooooo`02ooooo`?o00001?ljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl0
00?o>Yl000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?lkW`3o>il0
00;o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il0
00;o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il0
00?o>il000Co0000oc^O0?lkW`3o>il00ol00004omb50003o`000?oLQ@3og8D000Cog8D000?o0000
omb50?oLQ@000ooLQ@000ol0003og8D0omb50004omb50003o`000?oLQ03og8@000?o000000?og8@0
o`000?oLQ0001OoLQ0000ol0003og8<0omb30002omb300?o00001_od;`000ol0003om2h0oo@^0004
oo@^0003o`000?od;@3om2d000Com2d000Co0000oo<b0?l0003o00001?oh7@001Ol0003okTD0oni5
0?o^A@3o000000Kokd@000Go0000olZg0?o:]`3ob[L0o`000003olZh0005o`000?o:^03ob[P0olZh
0?l000000_o9^0001Ol0003obKP0olVh0?o9^03o000001Gooooo00?o0000ooooooooool06oooool0
027ooooo0_l00002ooooo`;o000000?o08L4o`000?ooool02Oooool4o`0000;o>Yl000?o0000ocZO
0?ljW`000_ljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO
0?ljW`000_ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?lkW`3o>il000;o>il000?o0000oc^O
0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O
0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il01?l000000ooL
Q@3o0000omb50005omb50003o`000?oLQ@3og8D000?og8D000?o0000omb50?oLQ@000ooLQ@000ol0
003og8D0omb50004omb500?o00001?oLQ0000ol0003og8@0omb40004omb40003o`000?oLP`3o0000
00;o000000?om340o`000?od;`001_od;`000ol0003om2h0oo@^0004oo@^0003o`000?od;@3om2d0
00?om2d00ol00007ooPM0003o`000?o^A@3o000000Kokd@000?o0000oni50?l000000_o:]`02o`00
00;ob[P000Go0000olZh0?o:^03ob[P0o`000002olVh0005o`000?o9^03obKP0olVh0?l000005_oo
ool00ol0003oooooooooo`0Jooooo`008Oooool01?l0003oooooooooooooool2o`0000;o08L400?o
0000ooooooooool01?ooool3o`000003ocRN0?l0003o>Yl000?o>Yl000?o0000ocZO0?ljW`000_lj
W`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`000_lj
W`000ol0003o>Yl0ocZO0003ocZO0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lk
W`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olk
W`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il00_l00004omb50003o`000?oL
Q@3og8D000Cog8D000?o0000omb50?oLQ@000ooLQ@000ol0003og8D0omb50004omb50003o`000?oL
Q@3og8D000?o000000?og8D0o`000?oLQ0001?oLQ0000ol0003og8@0omb40003omb400?o00001Ood
<@000ol0003om2l0oo@_0005oo@_0003o`000?od;P3om2h000?om2h000?o0000oo@]0?od;@000ol0
0002ooXI0003o`000?oh7@3on1d000Gon1d00_l00006onm40004o`000?o^A@3okTD0oni500;o0000
00Cob[P0o`000?o:^03o00000oo:^0001?l0003obKP0olVh0?l00004olVh00;o00005?ooool00ol0
003oooooo`00000Kooooo`003_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004oooo
o`04o`000?ooooooooooooooo`;o00000ol0Q`@6o`0000Co>9h000?o0000ocZO0?ljW`000_ljW`00
0ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`000_ljW`00
0ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000oc^O0?lkW`000olkW`00
0ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`00
0ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?l000000_l00000
0ooKQP3o0000omb50004omb50003o`000?oLQ@3og8D000?og8D000?o0000omb50?oLQ@000ooLQ@00
0ol0003og8D0omb50004omb500?o00001?oLQ@000ol0003og8@0omb40004omb40003o`000?oLQ03o
000000;o000000?olc80o`000?od<@001Ood<@000ol0003om2l0oo@_0005oo@_0003o`000?od;P3o
m2h000?om2h00ol00006ooXI0003o`000?oh7@3on1d000;on1d00_l000000ooi7@3o0000onm40004
onm40003o`000?o^A@3okTD000?okTD000?o0000olZh0?o:^0000_l00003olZh0004o`000?o9^03o
bKP0o`0000?obKP000Co0000olVh0?o9^03o00005Oooool00ol0003oooooooooo`0Iooooo`003Ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l00003ooooo`;o
00000ol0Q`@00ol0003o:iX0ob^J0002ob^J0003o`000?lhWP3o>9h000;o>9h000?o0000ocZO0?lj
W`000_ljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?lj
W`000_ljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000Co>il000?o0000oc^O0?lk
W`000_lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il00ol00004om^60003
o`000?oLQ@3og8D000?og8D000?o0000omb50?oLQ@000ooLQ@000ol0003og8D0omb50004omb50004
o`000?oLQ@3og8D0omb500?o00001_oLQ@000ol0003og8@0omb40003omb400?o00001Ooc<P000ol0
003om340oo@a0004oo@a0003o`000?od;`3om2l000Com2l000?o0000oo@^0?od;P000ol000000ooi
6P3o0000ooXI0007ooXI0004o`000?oh7@3o0000o`0000ConAd000Go0000onm40?o_A03okd@0o`00
0006oni500;o00000_o:^0001Ol0003ob[P0olZh0?o:^03o000000;obKP000Go0000olVh0?o9^03o
bKP0o`000003olVh0003o`000?oooooooooo01?ooooo00?o0000ooooooooool06?ooool000gooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo0_l00003o`271003o`000?l[VP3o:iX000;o:iX000?o0000ocRN0?lhWP000_lhWP000ol0003o
>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o
>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o
>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o
>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?l000000_l000000ooKQP3o
0000om^60005om^60003o`000?oLQ@3og8D000;og8D000?o0000omb50?oLQ@000ooLQ@000ol0003o
g8D0omb50004omb500Co00000_oLQ@000ol0003og8D0omb50005omb50003o`000?oLQ03o000000;o
000000?olc<0o`000?oc<P001Ooc<P000ol0003om340oo@a0004oo@a0003o`000?od;`3om2l000?o
m2l01?l00005ooTJ0003o`000?oj6@3onQT000ConQT00ol00007ooTM0003o`000?o_A03o000000Ko
kTD000?o0000oni60?o^AP000_l000001Oo:^03o0000olZh0?o:^03o000000;obKP000Go0000olVh
0?o9^03obKP0o`000003olVh0003o`000?oooooooooo01?ooooo00?o0000ooooooooool06?ooool0
00gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo0_l00003o`271003o`000?l[VP3o:iX000;o:iX000?o0000ocRN0?lhWP000_lhWP00
0ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000oljW`00
0ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`000_ljW`00
0ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`00
0ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000;o>il00ol00004om^60003o`000?oKQP3o
fhH000CofhH000?o0000omb50?oLQ@000_oLQ@000ol0003og8D0omb50004omb50004o`000?oLQ@3o
g8D0omb500?o00001OoLQ@000ol0003og8D0omb50004omb500?o00001Ooc<`000ol0003olc80oo<b
0004oo<b0003o`000?od<@3om34000?om34000?o0000oo@_0?od;`000ol00002ooTL0003o`000?oi
6P3onAX000GonAX000?o0000ooXI0?oj6@000ol00002ooXH0003o`000?oi7@3onAd000GonAd00_l0
0006oni50003o`000?o^AP3okTH000;okTH000Go0000olZh0?l0003ob[P0o`000002olVh0005o`00
0?o9^03obKP0olVh0?l000001?o9^002o`0001Gooooo00?o0000ooooooooool05oooool000gooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003oooo
o`;o00000ol0Q`@00ol0003o:iX0ob^J0002ob^J0003o`000?lhWP3o>9h000;o>9h000?o0000ocZO
0?ljW`000_ljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO
0?ljW`000_ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000oc^O
0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O
0?lkW`000_lkW`000ol0003o>il0o`000002o`000003om^50?l0003ofhH000GofhH000?o0000om^6
0?oKQP000ooKQP000ol0003og8D0omb50003omb50003o`000?oLQ@3og8D000?og8D01?l00002omb5
0003o`000?oLQ@3og8D000Cog8D000?o0000omb50?oLQ@000ol000000ooc<`3o0000oo<c0005oo<c
0003o`000?oc<P3olc8000Colc8000?o0000oo@a0?od<@000ood<@03o`0000KonA`000?o0000ooTJ
0?oi6P001?oi6P03o`0000KonQP000?o0000ooTM0?oi7@000_oi7@02o`000003ooPN0?l0003okTD0
00CokTD000?o0000oni60?o^AP000oo^AP000ol0003ob[P0olZh0002o`0000;obKP000Go0000olVh
0?o9^03obKP0o`000003olVh0004o`000?o9^03obKP0o`0001Gooooo00?o0000ooooooooool05_oo
ool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool2o`0000?o08L400?o0000ob^J0?l[VP000_l[VP000ol0003o>9h0
ocRN0002ocRN0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0
ocZO0003ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0
ocZO0002ocZO0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0
oc^O0003oc^O0004o`000?lkW`3o>il0oc^O00?o00001?oKQ@000ol0003ofhH0om^60004om^60003
o`000?oKQP3ofhH000?ofhH000?o0000omb50?oLQ@000ooLQ@001?l0003og8D0omb50?oLQ@03o`00
00Gog8D000?o0000omb50?oLQ@001?oLQ@03o`0000Golc<000?o0000oo<c0?oc<`001?oc<`000ol0
003olc80oo<b0003oo<b0003o`000?od<@3om34000?o00000_oh7@000ol0003onA`0ooTL0005ooTL
0003o`000?oi6P3onAX000?o000000?onAT0o`000?oj60001ooj60001?l0003onAd0o`000?l00004
ooPN0005o`000?o^A@3okTD0oni50?l000001Oo^AP000ol0003okTL0o`000002olZh0004o`000?o9
^03obKP0o`0000?obKP000Go0000olVh0?o9^03obKP0o`000002olVh0003o`000?oooooooooo01;o
oooo0_l00007ooooo`?o00003_ooool000kooooo0_l00009ooooo`?o00001?ooool2o`0000Cooooo
00Go0000o`271?l0Q`Co08L4o`000004ob^J0003o`000?lhWP3o>9h000;o>9h000?o0000ocZO0?lj
W`000_ljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?lj
W`000oljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il01?l000000ooLQ@3o
0000om^50005om^50003o`000?oKQP3ofhH000?ofhH000?o0000om^60?oKQP000ooKQP000ol0003o
g8D0omb50003omb500Co00000_oLQ@000ol0003og8D0omb50004omb50003o`000?oLQ@3og8D000;o
g8D00_l00007oo<c0003o`000?oc<`3olc<000Colc<000?o0000oo<b0?oc<P000ooc<P03o`0000Ko
n1d000?o0000ooTL0?oi70001?oi7003o`0000GonAT000?o0000ooXH0?oj60001?oj6003o`0000Oo
n1h000?o0000oni50?l000001Oo^AP001?l0003okTL0oni70?o^A`02o`000004olVh0?l0003obKP0
o`0000?obKP000Go0000olVh0?o9^03obKP0o`000002olVh00;o00005Oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000003Oooool0023ooooo00?o0000ooooooooool00ooo
ool01Ol0003o08L4o`271?l0Q`Co000000Co:iX000?o0000ocRN0?lhWP000_lhWP000ol0003o>Yl0
ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0
ocZO0003ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>il0
oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`02o`0000Cog8D0
00?o0000om^50?oKQ@001?oKQ@000ol0003ofhH0om^60003om^60003o`000?oKQP3ofhH000CofhH0
00?o0000omb50?oLQ@001?l00004omb50003o`000?oLQ@3og8D000Cog8D000?o0000omb50?l00000
0_l000000ooc=03o0000oo<c0007oo<c0003o`000?oc<`3olc<000?olc<000?o0000oo<b0?oc<P00
0ol000000ooh7`3o0000ooPM0007ooPM0003o`000?oi703onA`000?o000000?onA/0o`000?oi6@00
1_oi6@000ol0003onQP0ooXH0003o`0000?onAX000?o0000ooPN0?oh7P001?oh7P02o`0000GokTH0
00?o0000oni70?o^A`000oo^A`001?l0003obKP0o`000?l00003olVh0005o`000?o9^03obKP0olVh
0?l000000_o9^0001?l0003obKT0olVi0?l0000Eooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02oooool001oooooo00?o0000ooooooooool01?ooool2o`0000;o08L400?o0000ob^J
0?l[VP000_l[VP000ol0003o>9h0ocRN0002ocRN0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO
0?ljW`000_ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO
0?ljW`000_ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?lkW`3o>il000;o>il000?o0000oc^O
0?lkW`000olkW`000ol0003o>il0o`000002o`000003omb50?l0003og8D000Cog8D000?o0000om^5
0?oKQ@000ooKQ@000ol0003ofhH0om^60003om^60003o`000?oKQP3ofhH000CofhH00ol00003omb5
0003o`000?oLQ@3og8D000?og8D000?o0000omb50?oLQ@000_oLQ@03o`0000Golc@000?o0000oo<c
0?oc<`001Ooc<`000ol0003olc<0oo<c0003oo<c00?o00001Ooh7`000ol0003on1d0ooPM0004ooPM
00Co00001Ooi6`000ol0003onAT0ooTI0004ooTI00?o00001ooi6P000ol0003on1h0ooPN0003o`00
00;on20000Go0000oni60?o^AP3okTH0o`000006oni70004o`000?o9^03obKP0o`0000?obKP000Go
0000olVh0?o9^03obKP0o`000002olVh0005o`000?o9^@3obKT0olVi0?l000005?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo000Oooooo`;o00001Oooool2o`0000;o08L4
00?o0000ob^J0?l[VP000_l[VP000ol0003o>9h0ocRN0002ocRN0003o`000?ljW`3o>Yl000;o>Yl0
00?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl0
00?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?lkW`3o>il000;o>il0
00?o0000oc^O0?lkW`000_lkW`03o`0000Cog8D000?o0000omb50?oLQ@000ooLQ@000ol0003ofhD0
om^50003om^50003o`000?oKQP3ofhH000CofhH000Co0000om^60?oKQP3ofhH00ol00005omb50003
o`000?oLQ@3og8D000?og8D000?o0000omb50?l000000_l000000oob=@3o0000oo<d0006oo<d0003
o`000?oc<`3olc<000Colc<000?o0000oo<c0?oc<`000ol000000ooh803o0000ooPO0006ooPO0003
o`000?oh7@3on1d000?o00000_oi70000ol0003onA/0ooTK0005ooTK0003o`000?oi6@3onAT000?o
00000_oi6`000ol0003onAX0ooTJ0004ooTJ00Co00001_oh80000ol0003okTH0o`000006oni70004
o`000?o^B03o0000olVh00;o00000_o9^0001Ol0003obKP0olVh0?o9^03o000000;obKP000Go0000
olVi0?o9^@3obKT0o`00000Eooooo`04o`000?ooooooooooooooo`Co00003_ooool001oooooo00?o
0000ooooooooool01?ooool2o`0000;o08L400?o0000ob^J0?l[VP000_l[VP000ol0003o>9h0ocRN
0002ocRN0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO
0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO
0003ocZO0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?l000000_l000000ooLQ@3o0000omb5
0005omb50003o`000?oLQ@3og8D000;og8D000?o0000om^50?oKQ@000ooKQ@000ol0003ofhH0om^6
0004om^600Co00000_oKQP000ol0003og8D0omb50003omb50003o`000?oLQ@3og8D000;og8D00ol0
0005oo8e0003o`000?oc=03olc@000Colc@000?o0000oo<c0?oc<`001?oc<`03o`0000Gon20000?o
0000ooPO0?oh7`001?oh7`03o`0000KonA`000?o0000ooTK0?oi6`001?oi6`03o`0000KonA/000?o
0000ooTJ0?oi6P000ol00002ooTK0003o`000?oh803on20000Gon2000_l00006oni70003o`000?o^
B03okTP000;o00000_o9^0000ol0003obKP0o`000002olVh0004o`000?o9^03obKP0o`0000CobKT0
0_l0000Eooooo`04o`000?ooooooooooo`00017ooooo000Oooooo`;o00001Oooool2o`0000;o08L4
00?o0000ob^J0?l[VP000_l[VP000ol0003o>9h0ocRN0002ocRN0003o`000?ljW`3o>Yl000?o>Yl0
00?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl0
00?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0003ocZO0004o`000?lkW`3o>il0oc^O00?o
00001?oLQ@000ol0003og8D0omb50004omb50003o`000?oLQ@3og8D000;og8D000?o0000om^50?oK
Q@001?oKQ@001?l0003ofhH0om^60?oKQP03o`0000GofhH000?o0000omb50?oLQ@001?oLQ@04o`00
0003oo8e0?l0003olSD000KolSD000?o0000oo<d0?oc=0001?oc=0000ol0003olc<0oo<c0003o`00
0003ooPQ0?l0003on20000Kon20000?o0000ooPO0?oh7`000ol00002ooPN0003o`000?oi703onA`0
00GonA`000?o0000ooTK0?oi6`000ol00002ooTM0003o`000?oi6`3onA/000ConA/00ol00006ooTK
0003o`000?oh803on20000;on2000_l000000ooh8@3o0000oni70004oni70003o`000?o^B03okTP0
00;okTP000?o0000olVh0?o9^0000_l00003olVh0004o`000?o9^03obKP0o`0000?obKT000?o0000
olVi0?l000004oooool3o`0000;ooooo1Ol0000=ooooo`001_ooool2o`0000Cooooo00Co0000oooo
oooooooooooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`;o00000_l0Q`@0
0ol0003o:iX0ob^J0002ob^J0003o`000?lhWP3o>9h000?o>9h000?o0000ocZO0?ljW`000_ljW`00
0ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000oljW`00
0ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl01?l000000ooLQ@3o0000omb50005
omb50003o`000?oLQ@3og8D000?og8D000?o0000omb50?oLQ@000_oLQ@000ol0003ofhD0om^50004
om^500Co00000_oKQP000ol0003ofhH0om^60004om^60003o`000?oLQ@3og8D000;og8D00_l00005
oo8e0003o`000?ob=@3olSD000ColSD000?o0000oo<d0?oc=0001?oc=003o`0000Gon24000?o0000
ooPP0?oh80001?oh8003o`0000Kon1h000?o0000ooTL0?oi70001?oi7003o`0000KonAd000?o0000
ooTK0?oi6`000ol000000ooi7@3o0000ooTK0007ooTK0004o`000?oh803o0000o`0000Con24000Go
0000oni70?o^A`3okTL0o`000005oni80005o`000?o9^03obKP0olVh0?l000000oo9^0001?l0003o
bKP0olVh0?l00003olVi0004o`000?o9^@3obKT0o`0001Gooooo00?o0000ooooooooool04Oooool0
00Gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`;o00000_l0Q`@00ol0003o:iX0
ob^J0002ob^J0003o`000?lhWP3o>9h000?o>9h000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0
ocZO0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0
ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl00_l00004omb50003o`000?oLQ@3og8D000Cog8D0
00?o0000omb50?oLQ@000ooLQ@000ol0003og8D0omb50003omb50004o`000?oKQ@3ofhD0om^500?o
00001OoKQP000ol0003ofhH0om^60004om^60003o`000?oLQ@3o000000;o000000?olSH0o`000?ob
=@001Oob=@000ol0003olSD0oo8e0004oo8e0003o`000?oc=03olc@000?o000000?omb80o`000?oh
8@001_oh8@000ol0003on200ooPP0003o`0000;on1l000?o0000ooPN0?oh7P001Ooh7P000ol0003o
nA`0ooTL0003o`0000;on1h000?o0000ooTM0?oi7@001?oi7@03o`0000GonAd000?o0000ooTK0?oi
6`001?oi6`03o`0000Oon24000?o0000oni70?l000001Oo^B0000ol0003okDT0o`000002olVh00;o
00000_o9^0001?l0003obKP0olVh0?l00003olVi0003o`000?o9^@3obKT000;o00005Oooool00ol0
003oooooooooo`0@ooooo`001Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooooooo0_l00006ooooo`;o00000ol0Q`@00ol0003o:iX0ob^J0002
ob^J0003o`000?lhWP3o>9h000;o>9h000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0002
ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0002
ocZO0003o`000?ljW`3o000000;o000000?og8@0o`000?oLQ@001?oLQ@000ol0003og8D0omb50003
omb50003o`000?oLQ@3og8D000?og8D000?o0000omb50?oLQ@000ooLQ@04o`0000;ofhD000?o0000
om^60?oKQP001?oKQP000ol0003ofhH0om^60002om^600?o00001Oob=P000ol0003olSD0oo8e0003
oo8e0003o`000?ob=@3olSD000ColSD00ol00005ooLR0003o`000?oh8@3on24000Con2400ol00006
ooPO0003o`000?oh7P3on1h000Con1h00ol00006ooPN0003o`000?oi7@3onAd000?o000000?on1h0
o`000?oi7@001_oi7@000ol0003onA/0ooTK0003o`0000;onAd000?o0000ooPQ0?oh8@001Ooh8@02
o`0000GokTP000Co0000one90?o]B@3okDT00_l000001?o9^03o0000olVh0?l00002olVh0005o`00
0?o9^@3obKT0olVi0?l000000oo9^@000ol0003obKT0o`00000Dooooo`03o`000?oooooooooo013o
oooo0005ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Sooooo00Go0000o`271?l0Q`Co08L4o`000004ob^J0003o`000?lhWP3o
>9h000;o>9h000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o
>Yl000?o>Yl000?o0000ocZO0?ljW`000_ljW`001?l0003o>Yl0ocZO0?ljW`03o`0000Cog8@000?o
0000omb50?oLQ@000ooLQ@000ol0003og8D0omb50003omb50003o`000?oLQ@3og8D000Cog8D000?o
0000omb50?oLQ@000ol00005om^50003o`000?oKQP3ofhH000CofhH000?o0000om^60?l000000_l0
00000oob=P3o0000oo8f0005oo8f0003o`000?ob=@3olSD000ColSD000?o0000oo8e0?ob=@000ol0
00000oog8P3o0000ooLR0006ooLR0003o`000?oh8@3on24000?o000000?on200o`000?oh7`001ooh
7`000ol0003on1h0ooPN0003o`0000;on1l000?o0000ooPN0?oh7P001?oh7P03o`0000Gon1h000?o
0000ooTM0?oi7@001?oi7@03o`0000KonAd000Co0000ooPQ0?oh8@3on2400ol000000oog8`3o0000
oni80003oni80003o`000?o]B@3okDT000?okDT000?o0000olVh0?o9^0000_l00002olVh0005o`00
0?o9^@3obKT0olVi0?l000000_o9^@001Ol0003obKT0olVi0?o9^@3o000001Cooooo00?o0000oooo
ooooool03oooool000Gooooo00Co0000oooooooooooo00001oooool01_l0003ooooooooooooooooo
0000ooooo`Co00001?ooool2o`0000Oooooo00Go0000o`271?l0Q`Co08L4o`000004ob^J0003o`00
0?lhWP3o>9h000;o>9h000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0002ocZO0003o`00
0?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`000_ljW`04o`000003omb40?l0003og8@000Gog8@0
00?o0000omb50?oLQ@000_oLQ@000ol0003og8D0omb50003omb50003o`000?oLQ@3og8D000Cog8D0
0ol00002omb50003o`000?oKQ@3ofhD000CofhD000?o0000om^60?oKQP000_oKQP03o`0000GolSH0
00?o0000oo8f0?ob=P001?ob=P000ol0003olSD0oo8e0003oo8e00?o00001Oog8P000ol0003omb80
ooLR0004ooLR00?o00001Ooh80000ol0003on1l0ooPO0004ooPO00Co00001_oh7`000ol0003on1h0
ooPN0003o`000003ooPO0?l0003on1h000Kon1h000?o0000ooTM0?oi7@000ol000000ooh7P3o0000
ooTM0006ooTM0004o`000?oh8@3o0000o`0000Gomb<000Go0000oni80?o^B03okTP0o`000004one9
0003o`000?o]B@3o000000;obKP000Co0000olVh0?o9^03o00000oo9^@001?l0003obKT0olVi0?l0
0003olVi0003o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool000Gooooo00Co0000
oooooooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000001oooool00ol0003o
ooooooooo`06ooooo`05o`000?l0Q`Co08L4o`271?l000001?l[VP000ol0003o>9h0ocRN0002ocRN
0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0003ocZO
0004o`000?ljW`3o>Yl0ocZO00;o00001?oLQ0000ol0003og8@0omb40004omb40003o`000?oLQ@3o
g8D000;og8D000?o0000omb50?oLQ@001?oLQ@001?l0003og8D0omb50?oLQ@03o`0000Cog8D000?o
0000om^50?oKQ@001?oKQ@000ol0003ofhH0o`000002o`000003oo8f0?l0003olSH000GolSH000?o
0000oo8f0?ob=P001?ob=P000ol0003olSD0oo8e0003o`000003ooLS0?l0003omb8000Komb8000?o
0000ooLR0?og8P000ol00002ooPQ0003o`000?oh803on20000Con20000?o0000ooPO0?oh7`000ol0
0003ooPQ0003o`000?oh7`3on1l000Con1l00ol00005ooPO0003o`000?oh7P3on1h000Con1h00ol0
0005ooPN0003o`000?oi7@3onAd000ConAd00_l00008ooLS0003o`000?o^B03o000000CokDT000Co
0000one90?o]B@3okDT00_l000001?o9^03o0000olVh0?l00002olVi0005o`000?o9^@3obKT0olVi
0?l000000oo9^@02o`0001?ooooo0_l0000@ooooo`001_ooool2o`0000Wooooo0ol00002ooooo`Go
00000oooool00ol0003oooooooooo`06ooooo`05o`000?l0Q`Co08L4o`271?l000001?l[VP000ol0
003o>9h0ocRN0002ocRN0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000_ljW`000ol0
003o>Yl0ocZO0003ocZO00Co000000?og8<0o`000?oLQ0001?oLQ0000ol0003og8@0omb40003omb4
0003o`000?oLQ@3og8D000;og8D000?o0000omb50?oLQ@001?oLQ@04o`0000;og8D000?o0000omb5
0?oLQ@000ooLQ@000ol0003ofhD0om^50002om^500?o00001Oob=P000ol0003olSH0oo8f0004oo8f
0003o`000?ob=P3olSH000?olSH00ol00005ooLS0003o`000?og8P3omb8000Comb800ol00006ooPQ
0004o`000?oh803on200ooPP00Go00001ooh8@000ol0003on1l0ooPO0003o`000003ooPQ0?l0003o
n1l000Kon1l000?o0000ooPN0?oh7P000ol000000ooh7`3o0000ooPN0006ooPN0003o`000?oi7@3o
nAd000?o00000_oh7P000ol0003omb<0ooLS0004ooLS00?o00001?o]B@000ol0003okDT0one90003
one90004o`000?o9^03o0000o`0000?obKT000Go0000olVi0?o9^@3obKT0o`000002olVi0003o`00
0?o9^@3o000001Gooooo00?o0000ooooooooool03Oooool001kooooo0_l00007ooooo`05o`000?l0
Q`Co08L4o`271?l000001?l[VP000ol0003o>9h0ocRN0002ocRN0003o`000?ljW`3o>Yl000;o>Yl0
00?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0002ocZO00;o00001?oLP`000ol0003og8@0
omb40003omb40003o`000?oLQ03og8@000?og8@000?o0000omb50?oLQ@000ooLQ@001?l0003og8D0
omb50?oLQ@03o`0000Gog8D000?o0000omb50?oLQ@000ooLQ@000ol0003ofhD0o`000002o`000003
oo8f0?l0003olSH000GolSH000?o0000oo8f0?ob=P001?ob=P000ol0003olSH0oo8f0003o`000003
ooLS0?l0003omb<000Komb<000?o0000ooLR0?og8P000ol00002ooLQ0003o`000?oh8@3on24000Co
n2401?l00005ooLR0003o`000?oh8@3on24000Con2400ol00005ooPQ0003o`000?oh7`3on1l000Co
n1l00ol00005ooPO0003o`000?oh7P3on1h000Con1h00ol00006ooPN0003o`000?og8`3omb<000?o
00000_og90001Ol0003okDT0one90?o]B@3o000000KokDT000Co0000olVh0?o9^03o00000oo9^@00
1?l0003obKT0olVi0?l00003olVi0004o`000?o9^@3obKT0o`0001Gooooo00?o0000ooooooooool0
3?ooool001kooooo00?o0000ooooooooool01_ooool01Ol0003o08L4o`271?l0Q`Co000000Co:iX0
00?o0000ocRN0?lhWP000_lhWP000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl0
00?o0000ocZO0?l000000_l000000ooLP`3o0000omb30004omb30003o`000?oLQ03og8@000;og8@0
00?o0000omb40?oLQ0000ooLQ0000ol0003og8D0omb50003omb500Co00000_oLQ@000ol0003og8D0
omb50004omb50004o`000?oLQ@3og8D0omb500?o00001Oob=P000ol0003olSH0oo8f0004oo8f0003
o`000?ob=P3olSH000?olSH00ol00005ooLS0003o`000?og8`3omb<000Comb<00ol00006ooLQ0003
o`000?oh8@3on24000?o00000_og8P000ol0003omb80ooLR0005ooLR0003o`000?oh8@3on24000?o
000000?omb80o`000?oh8@001_oh8@000ol0003on1l0ooPO0003o`0000;on24000?o0000ooPO0?oh
7`001?oh7`000ol0003on1h0ooPN0003o`0000;on1l000?o0000ooPN0?oh7P001?oh7P03o`0000Ko
mb@000?o0000one90?l000001_o]B@001?l0003okDX0o`000?o9^002o`0000;obKT000Co0000olVi
0?o9^@3o00000oo9^@001?l0003obKT0olVi0?l0000Eooooo`03o`000?oooooooooo00cooooo000M
ooooo`;o00002?ooool2o`0000;o08L400?o0000ob^J0?l[VP000_l[VP000ol0003o>9h0ocRN0002
ocRN0003o`000?ljW`3o>Yl000;o>Yl000Co0000ocZO0?ljW`3o>Yl00ol00004omb30003o`000?oL
P`3og8<000?og8<000?o0000omb40?oLQ0000_oLQ0000ol0003og8@0omb40004omb40003o`000?oL
Q@3og8D000?o00001OoLQ@000ol0003og8D0omb50004omb500Co000000?olSH0o`000?ob=P001Oob
=P000ol0003olSH0oo8f0004oo8f0003o`000?ob=P3olSH000?o000000?omb<0o`000?og8`001_og
8`000ol0003omb<0ooLS0003o`0000?omb8000?o0000ooLQ0?og8@000oog8@03o`0000Komb8000?o
0000ooLR0?og8P001?og8P03o`0000Gomb8000?o0000ooPQ0?oh8@001?oh8@03o`0000Kon24000Co
0000ooPO0?oh7`3on1l01Ol00006ooPO0003o`000?oh7P3on1h000?o000000?on1l0o`000?og9000
1_og9002o`0000KokDT000?o0000one:0?o]BP000_l00002olVi00;o00000oo9^@001?l0003obKT0
olVi0?l00003olVi00;o00005Oooool00ol0003oooooooooo`0;ooooo`007Oooool00ol0003ooooo
ooooo`07ooooo`;o00000_l0Q`@00ol0003o:iX0ob^J0002ob^J0003o`000?lhWP3o>9h000;o>9h0
00?o0000ocZO0?ljW`000_ljW`04o`000003omb20?l0003og8<000Cog8<000?o0000omb30?oLP`00
0ooLP`000ol0003og8@0omb40002omb40003o`000?oLQ03og8@000Cog8@00ol00002omb50003o`00
0?oLQ@3og8D000Cog8D000?o0000omb50?oLQ@000_oLQ@02o`0000GolSH000?o0000oo8f0?ob=P00
1?ob=P000ol0003olSH0oo8f0003oo8f00?o00001Oog8`000ol0003omb<0ooLS0004ooLS00?o0000
1oog8P000ol0003omb40o`000002o`0000;omb<000?o0000ooLR0?og8P001Oog8P000ol0003omb80
ooLR0003o`000003ooLS0?l0003omb8000Komb8000?o0000ooPQ0?oh8@000ol00002ooLR0003o`00
0?oh8@3on24000Con2401?l00004ooPQ0003o`000?oh7`3on1l000Con1l00ol00005ooPO0003o`00
0?og903omb@000;omb@00_l000000oog903o0000one90004one90003o`000?o]BP3okDX000;okDX0
00?o0000olVi0?o9^@000_l00003olVi0004o`000?o9^@3obKT0o`0000;obKT000Co0000olVi0?o9
^@3o00005Oooool00ol0003oooooooooo`0:ooooo`007Oooool00ol0003oooooooooo`08ooooo`;o
000000?o08L4o`000?l[VP000ol[VP000ol0003o>9h0ocRN0002ocRN0004o`000?ljW`3o>Yl0ocZO
00;o00001?oLPP000ol0003og8<0omb30004omb30003o`000?oLP`3og8<000;og8<000?o0000omb4
0?oLQ0000ooLQ0001?l0003og8@0omb40?oLQ003o`0000Cog8D000?o0000omb50?oLQ@001?oLQ@00
0ol0003og8D0o`000002o`000003oo8e0?l0003olSH000GolSH000?o0000oo8f0?ob=P000oob=P00
0ol0003olSH0oo8f0003o`0000;omb<000?o0000ooLS0?og8`001?og8`000ol0003omb<0ooLS0003
o`0000?omb8000?o0000ooLR0?og8P001?og8P02o`0000Komb<000?o0000ooLR0?og8P001?og8P03
o`0000Gomb<000?o0000ooLR0?og8P001?og8P03o`0000Komb8000?o0000ooPQ0?oh8@000ol00000
0oog8P3o0000ooPQ0006ooPQ0003o`000?oh7`3on1l000?o000000?on200o`000?oh7`001_oh7`00
1?l0003omb@0o`000?l00004ooLT0005o`000?o]B@3okDT0one90?l000001Oo]BP02o`0000;obKT0
00Go0000olVi0?o9^@3obKT0o`000002olVi0004o`000?o9^@3obKT0o`0000;obKT00_l0000Coooo
o`;o00003?ooool001gooooo0_l00009ooooo`04o`000?nf`@3o0000o`0000Co:iX000?o0000ocRN
0?lhWP000_lhWP04o`000003omf20?l0003og88000Cog88000?o0000omb30?oLP`000ooLP`000ol0
003og8<0omb30002omb30003o`000?oLQ03og8@000?og8@01?l00002omb40003o`000?oLQ@3og8D0
00?og8D000?o0000omb50?oLQ@000_oLQ@03o`0000GolSD000?o0000oo8f0?ob=P000oob=P000ol0
003olSH0oo8f0003oo8f00?o00001_og8`000ol0003omb<0ooLS0003ooLS00?o00001oog8P000ol0
003omb80ooLR0003o`000003ooLS0?l0003omb<000Komb<000?o0000ooLR0?og8P000ol00002ooLT
0003o`000?og8`3omb<000Comb<000?o0000ooLR0?og8P000ol00002ooLS0003o`000?og8P3omb80
00Comb800ol00005ooLR0003o`000?oh8@3on24000Con2400ol00005ooPP0003o`000?oh7`3on1l0
00Con1l00_l00007ooLT0003o`000?o]B@3o000000GokDX000?o0000one:0?o]BP000_l000001?o9
^@3o0000olVi0?l00002olVi0005o`000?o9^@3obKT0olVi0?l000000_o9^@000ol0003obKT0o`00
000Dooooo`03o`000?oooooooooo00Wooooo000:ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?nf`@3o0000o`0000Co:iX000?o
0000ocRN0?lhWP000ol00004omf20003o`000?oLPP3og88000?og88000?o0000omb30?oLP`000ooL
P`000ol0003og8<0omb30003omb30003o`000?oLQ03og8@000?o00001OoLQ0000ol0003og8D0omb5
0003omb50003o`000?oLQ@3o000000;o000000?olc@0o`000?ob=@001Oob=@000ol0003olSH0oo8f
0004oo8f0003o`000?ob=P3o000000;o00000_og8`000ol0003omb<0ooLS0005ooLS0003o`000?og
8`3o000000;o00000oog8P000ol0003omb80ooLR0004ooLR00?o00001Oog8`000ol0003omb<0ooLS
0004ooLS00?o00001_og90001?l0003omb<0ooLS0?og8`05o`0000Komb<000?o0000ooLR0?og8P00
0ol000000oog8`3o0000ooLR0006ooLR0003o`000?oh8@3on24000?o000000?omb80o`000?oh8000
1_oh80000ol0003on1l0ooPO0003o`0000;on20000?o0000ooLT0?og90001?og9002o`0000GokDX0
00?o0000one:0?o]BP000_o]BP001Ol0003obKT0o`000?o9^@3o000000;obKT000Oo0000olVi0?o9
^@3obKT0o`000?o9^@3o000000?obKT000?o0000ooooooooool04_ooool00ol0003oooooooooo`08
ooooo`002Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`08ooooo`03o`000?nf`@3o]/4000So00000_oLP`000ol0003ogH80omf2
0003omf20003o`000?oLPP3og88000;og88000?o0000omb30?oLP`000ooLP`000ol0003og8<0omb3
0003omb300?o00000_oLQ0000ol0003og8@0omb40004omb40003o`000?oLQ@3og8D000Co00001Ooc
=0000ol0003olSD0oo8e0004oo8e0003o`000?ob=P3olSH000?olSH00_l00006ooLS0003o`000?og
8`3omb<000Comb<00_l00007ooLR0003o`000?og8P3omb8000?o000000?omb@0o`000?og8`001_og
8`000ol0003omb<0ooLS0003o`0000;omb@000?o0000ooLT0?og90001?og9004o`0000Comb@000?o
0000ooLS0?og8`001?og8`03o`0000Gomb<000?o0000ooLR0?og8P001?og8P03o`0000Gomb8000?o
0000ooPP0?oh80001?oh8003o`0000Kon20000?o0000ooLT0?og90000ol00002ooLU0005o`000?o]
BP3okDX0one:0?l000001Oo]BP000ol0003obKT0olVi0002o`0000;obKT000Co0000olVi0?o9^@3o
00000_o9^@001Ol0003obKT0olVi0?o9^@3o000001Cooooo00?o0000ooooooooool02?ooool000Wo
oooo00Co0000oooooooooooo00002oooool01?l0003oooooooooooooool2o`0000[ooooo00Co0000
okK10?nf`@3o00001?oHTP000ol0003og8<0omb30002omb30003o`000?oMPP3ogH8000?ogH8000?o
0000omb20?oLPP000_oLPP000ol0003og8<0omb30003omb30003o`000?oLP`3og8<000Co00001?oL
Q0000ol0003og8@0omb40003omb400Co00000_oc=0000ol0003olc@0oo<d0004oo<d0003o`000?ob
=@3olSD000ColSD000?o0000oo8f0?ob=P000ol00002ooLS0003o`000?og8`3omb<000Comb<000?o
0000ooLS0?og8`000ol00002ooLR0003o`000?og8P3omb8000Comb800ol00005ooLT0003o`000?og
8`3omb<000Comb<00ol00006ooLT0003o`000?og903omb@000?o000000?ombD0o`000?og90001_og
90000ol0003omb<0ooLS0003o`000003ooLT0?l0003omb<000Komb<000?o0000ooLR0?og8P000ol0
0002ooLS0003o`000?og8P3omb8000Comb8000?o0000ooPP0?oh80000ol00002ooPQ0003o`000?oh
803on20000Con2000ol00006ooLU0003o`000?o]BP3o000000GokDX000?o0000one;0?l000000_o9
^@001?l0003obKT0olVi0?l00002olVi0004o`000?o9^@3obKT0o`0000?obKT00_l0000Dooooo`03
o`000?oooooooooo00Oooooo0009ooooo`04o`000?ooooooooooo`0000Wooooo0_l00004ooooo`03
o`000?oooooooooo00Wooooo00Co0000okK10?nf`@3o00001?oHTP000ol0003og8<0omb30002omb3
0003o`000?oMPP3ogH8000?ogH8000?o0000omb20?oLPP000_oLPP000ol0003og8<0omb30003omb3
00?o00000ooLP`000ol0003og8@0omb40003omb40003o`000?oLQ03o000000;o000000?olc<0o`00
0?oc=0001?oc=0000ol0003olc@0oo<d0004oo<d0003o`000?ob=@3olSD000?olSD00ol00006ooLS
0004o`000?og8`3omb<0ooLS00Go00001_og8P000ol0003omb80ooLR0003o`000003ooLT0?l0003o
mb@000Komb@000?o0000ooLS0?og8`000ol00002ooLU0003o`000?og903omb@000Comb@00ol00005
ooLU0003o`000?og903omb@000Comb@00ol00005ooLT0003o`000?og8`3omb<000Comb<00ol00006
ooLS0004o`000?og8P3omb80ooLR00Go00001_oh8@000ol0003on200ooPP0003o`000003ooPQ0?l0
003ombD000KombD00_l00005one:0004o`000?o]B`3okD/0one;00;o000000?obKT0o`000?l00000
0oo9^@001?l0003obKT0olVi0?l00002olVi0003o`000?o9^@3o000001?ooooo0ol00008ooooo`00
2Oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooooooo`;o00002oooool00ol0
003o]/40o`000004omRB0003o`000?oLP`3og8<000?og8<000?o0000omf20?oMPP000_oMPP000ol0
003og880omb20003omb20003o`000?oLP`3o000000?o00001OoLP`000ol0003og8@0omb40002omb4
00?o00001Ooc<`000ol0003olc@0oo<d0003oo<d0003o`000?oc=03olc@000?olc@000?o0000oo8e
0?ob=@000ol00003ooLR0003o`000?og8`3omb<000?omb<01?l00004ooLR0003o`000?og8P3omb80
00Comb800ol00005ooLT0003o`000?og903omb@000Comb@00ol00006ooLU0003o`000?og903omb@0
00?o000000?omRD0o`000?og9@001_og9@000ol0003omb@0ooLT0003o`0000;ombD000?o0000ooLT
0?og90001?og90000ol0003omb<0ooLS0003o`0000;omb@000?o0000ooLS0?og8`001?og8`04o`00
00Comb<000?o0000ooPQ0?oh8@001?oh8@03o`0000Gon24000?o0000ooLU0?og9@000_og9@02o`00
0003ooHV0?l0003okDX000?okDX000?o0000one;0?o]B`000oo]B`001?l0003obKT0o`000?l00003
olVi0003o`000?o9^@3o000000?obKT000Co0000olVi0?o9^@3o00003oooool4o`000003ooooool0
003ooooo00Oooooo0009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00[ooooo00Co0000okK10?nf`@3o00000ooHTP000ol0003o
g8<0omb30003omb30003o`000?oMPP3ogH8000;ogH8000?o0000omb20?oLPP000ooLPP02o`0000Co
g8<000?o0000omb30?oLP`000ooLP`04o`000003oo<b0?l0003olc<000Golc<000?o0000oo<d0?oc
=0000ooc=0000ol0003olc@0oo<d0003oo<d00?o00001oog8P000ol0003omb<0o`000002o`0000;o
mb8000?o0000ooLR0?og8P001?og8P000ol0003omb80ooLR0003o`0000?omb@000?o0000ooLT0?og
90000oog90000ol0003omb@0ooLT0003o`0000;ombD000?o0000ooLU0?og9@001?og9@03o`0000Go
mRD000?o0000ooLU0?og9@001?og9@03o`0000KombD000Co0000ooLT0?og903omb@01Ol00006ooLT
0003o`000?og8`3omb<000?o000000?omb@0o`000?og8`001_og8`000ol0003on240ooPQ0003o`00
0003ooLR0?l0003on24000Kon24000Co0000ooLU0?l0003o00001?of9P001?l0003okDX0one:0?l0
0005one;00;o00000_o9^@001ol0003obKT0olVi0?o9^@3o0000olVi0?l000000oo9^@001?l0003o
bKT0olVi0?l0000<ooooo`?o00001Oooool00ol0003oooooooooo`06ooooo`002_ooool2o`0000Wo
oooo0ol00004ooooo`03o`000?oooooooooo00[ooooo00Co0000okK10?nf`@3o00001?oHTP000ol0
003og8<0omb30002omb30003o`000?oMPP3ogH8000?ogH8000?o0000omb20?l000000ol00005omb3
0003o`000?oLP`3og8<000;og8<00_l00005oo<b0003o`000?oc<`3olc<000Colc<000?o0000oo<d
0?oc=0000ooc=0000ol0003olc@0o`000002o`0000?omb8000?o0000ooLR0?og8P001?og8P02o`00
00Komb8000?o0000ooLR0?og8P000oog8P03o`0000Oomb@000Co0000ooLT0?og903omb@01?l00006
ooLU0003o`000?og9@3ombD000?o000000?omRH0o`000?of9@001_of9@000ol0003ombD0ooLU0003
o`0000;omRH000?o0000ooLU0?og9@001?og9@04o`0000CombD000?o0000ooLT0?og90001?og9003
o`0000Gomb@000?o0000ooLS0?og8`001?og8`03o`0000Gomb8000?o0000ooPQ0?oh8@001?oh8@02
o`0000KomRH000?o0000one:0?l000001Oo]B`000ol0003okD/0one;0002o`000004olVi0?l0003o
bKT0o`0000;obKT000Co0000olVi0?o9^@3o00000oo9^@02o`0000Oooooo1?l00008ooooo`03o`00
0?oooooooooo00Kooooo000Looooo`;o00002oooool01?l0003o]/40okK10?l00004omRB0003o`00
0?oLP`3og8<000;og8<000?o0000omf20?oMPP000_oMPP03o`0000?og88000?o0000omb30?oLP`00
0ooLP`000ol0003og8<0o`000002o`000003oo<a0?l0003olc8000Golc8000?o0000oo<c0?oc<`00
0ooc<`001?l0003olc@0oo<d0?oc=004o`0000Oomb8000?o0000ooLR0?og8P000ol000000oog8P3o
0000ooLR0006ooLR0003o`000?og8P3o000000;o00000oog90000ol0003omb@0ooLT0004ooLT00Co
00001?og9@000ol0003ombD0ooLU0003ooLU00?o00001Oof9P000ol0003omRD0ooHU0004ooHU00?o
00001_of9P000ol0003ombD0ooLU0003o`000003ooHV0?l0003ombD000KombD000?o0000ooLT0?og
90000ol000000oog9@3o0000ooLT0006ooLT0003o`000?og8`3omb<000?o000000?omb<0o`000?og
8P001_og8P000ol0003on240ooPQ0003o`000003ooPQ0?l0003omRH000GomRH00_l00005one;0003
o`000?o]B`3okD/000;okD/000?o0000olVi0?o9^@000_l00002olVi0004o`000?o9^@3obKT0o`00
00;obKT000Co0000olVi0?o9^@3o00000oooool3o`0000cooooo00?o0000ooooooooool01_ooool0
01cooooo00?o0000ooooooooool02oooool00ol0003o]/40o`000004omRB0003o`000?oLP`3og8<0
00;og8<000?o0000omf20?l000000_l000000ooMPP3o0000omb20003omb20003o`000?oLP`3og8<0
00;og8<00ol00005oo<a0003o`000?oc<P3olc8000?olc8000?o0000oo<c0?oc<`000ooc<`04o`00
00Con24000?o0000ooLR0?og8P001?og8P03o`0000Gomb8000?o0000ooLR0?og8P001?og8P02o`00
00Oomb@000?o0000ooLT0?og90000ol000000oog9@3o0000ooLU0006ooLU0003o`000?og9@3o0000
00;o00000oof9P000ol0003omRH0ooHV0003ooHV0003o`000?of9@3omRD000?o00000_of9`000ol0
003omRH0ooHV0004ooHV00?o00001Oof9P000ol0003ombD0ooLU0004ooLU00?o00001Oog9@000ol0
003omb@0ooLT0004ooLT00?o00001Oog8`000ol0003omb80ooLR0004ooLR00?o00001Ooh8@000ol0
003omRH0ooHV0003o`0000;omRH000Go0000one;0?o]B`3okD/0o`000005one;0003o`000?o9^@3o
bKT000;o00000_o9^@001?l0003obKT0olVi0?l00002olVi0003o`000?o9^@3obKT000Co00004?oo
ool00ol0003oooooooooo`05ooooo`007?ooool00ol0003oooooooooo`0;ooooo`03o`000?nf`@3o
000000Cof98000Co0000omb30?oLP`3og8<00ol00004omf20003o`000?oLPP3og88000?og8801?l0
00000ood<03o0000oo<a0005oo<a0003o`000?oc<P3olc8000Colc8000?o0000oo<c0?l000000_l0
0002ooPP0003o`000?oh8@3on24000Con24000?o0000ooLR0?og8P000ol00002ooPQ0003o`000?og
8P3omb8000Comb8000?o0000ooLR0?og8P000ol00002ooLS0003o`000?og903omb@000Comb@00ol0
0005ooLU0003o`000?og9@3ombD000CombD00_l00007ooHV0004o`000?of9P3omRH0ooHV00Co0000
1_of9`000ol0003omRH0ooHV0003o`000003ooHW0?l0003omRH000KomRH000?o0000ooLU0?og9@00
0ol00002ooHV0003o`000?og9@3ombD000CombD000?o0000ooLT0?og90000ol00002ooLU0003o`00
0?og8`3omb<000Comb<000?o0000ooLR0?og8P000ol000000oog8`3o0000ooPQ0005ooPQ00?o0000
1_of9P000ol0003okD/0o`000005one;0003o`000?o]B`3o000000;obKT000?o0000olVi0?l00000
0_o9^@001Ol0003obKT0olVi0?o9^@3o000000;obKT000?o0000olVh0?l000004Oooool00ol0003o
ooooooooo`05ooooo`006oooool00ol0003oooooooooo`0=ooooo`;o00001?oHTP04o`000003omb3
0?l0003ogH8000CogH8000?o0000omb20?oLPP000_oLPP02o`0000Gom30000?o0000oo<a0?oc<@00
1?oc<@000ol0003olc80oo<b0003oo<b00;o00001_oh80000ol0003on240ooPQ0003ooPQ00?o0000
1_oh8@000ol0003omb80ooLR0003ooLR00?o00001_og8`000ol0003omb@0ooLT0003o`000003ooLU
0?l0003ombD000KombD000?o0000ooLU0?og9@000ol00002ooHV0003o`000?of9P3omRH000ComRH0
1?l00003ooHW0003o`000?of9`3omRL000ComRL00ol00005ooHW0003o`000?of9P3omRH000ComRH0
0ol00006ooHV0004o`000?og9@3ombD0ooLU00Go00001_og9@001?l0003omb<0ooLS0?og8`05o`00
00Gomb<000?o0000ooPQ0?oh8@000ol000000oog8P3o0000ooHV0006ooHV00;o00001Oo]B`001?l0
003okD/0one;0?o]B`02o`000003olVi0?l0003o000000;obKT000Oo0000olVi0?o9^@3obKT0o`00
0?o9^@3o000000?obKP000?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`006ooo
ool00ol0003oooooooooo`0=ooooo`;o00000_oHTP03o`0000Gog8<000?o0000omf20?oMPP000ooM
PP04o`000003oo@^0?l0003om30000Gom30000?o0000oo<a0?oc<@000ooc<@000ol0003olc80oo<b
0003o`000003ooPO0?l0003on20000Kon20000?o0000ooPQ0?l000000_l00003ooPP0003o`000?oh
8@3on24000Con24000?o0000ooLR0?l000000_l00003ooLS0003o`000?og8`3omb<000?omb<00ol0
0005ooLU0003o`000?og9@3ombD000CombD00ol00006ooHV0003o`000?of9P3omRH000?o000000?o
mRL0o`000?of9`001Oof9`000ol0003omRL0ooHW0003o`0000;omRL000?o0000ooHW0?of9`001?of
9`000ol0003omRH0ooHV0003o`0000;omRL000?o0000ooHV0?of9P001?of9P04o`0000ComRH000?o
0000ooLU0?og9@001?og9@04o`0000?omb@000?o0000ooLS0?og8`001?og8`03o`0000Gomb8000?o
0000ooHV0?of9P000_of9P02o`000003ooHV0?l0003okD/000?okD/000?o0000one;0?o]B`000oo]
B`001?l0003obKT0o`000?l00002olVi0004o`000?o9^@3obKT0o`0000;obKT000Go0000olVh0?o9
^03obKP0o`00000@ooooo`03o`000?oooooooooo00Gooooo000Kooooo`;o00003_ooool01?l0003o
]/40o`000?l00002omRB0003o`000?oLP`3og8<000?og8<000?o0000omf20?oMPP000_oMPP02o`00
00Gom2h000?o0000oo@`0?od<0000ood<0000ol0003olc40oo<a0003oo<a00?o00001Ooh7`000ol0
003on200ooPP0004ooPP00;o00001ooh80001?l0003on240ooPQ0?oh8@04o`0000Oomb<000?o0000
ooLS0?l000000_l00003ooLU0003o`000?og9@3ombD000?ombD000?o0000ooLU0?og9@000ol00002
ooHV0003o`000?of9P3omRH000ComRH00ol00005ooHW0003o`000?of9`3omRL000?omRL00ol00006
ooHW0004o`000?of9`3omRL0ooHW00Go00001_of9`000ol0003omRH0ooHV0003o`000003ooHW0?l0
003omRH000KomRH000?o0000ooLU0?og9@000ol000000oog9@3o0000ooLT0005ooLT0003o`000?og
8`3omb<000?o000000?omb<0o`000?og8P001_og8P001?l0003omRH0o`000?l00004ooHV0005o`00
0?o]B`3okD/0one;0?l000001?o]B`02o`0000;obKT000Co0000olVi0?o9^@3o00000_o9^@001?l0
003obKT0olVi0?l00003olVh00;o00003oooool00ol0003oooooooooo`05ooooo`000_ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo
00cooooo1?l00004omRB0003o`000?oLP`3og8<000;og8<000?o0000omf20?l000000_l000000ood
;@3o0000oo@^0004oo@^0003o`000?od<03om30000Com30000?o0000oo<a0?l000000_l00002ooPN
0003o`000?oh7`3on1l000Con1l000?o0000ooPP0?oh80000ol00002ooPO0003o`000?oh803on200
00Con2001?l00004ooLS0003o`000?og8`3omb<000Comb<00_l00007ooLU0004o`000?og9@3ombD0
ooLU00Co00001_of9P000ol0003omRH0ooHV0003o`000003ooHW0?l0003omRL000KomRL000?o0000
ooHW0?l000000_l00003ooHX0003o`000?of9`3omRL000?omRL01?l00004ooHX0003o`000?of9`3o
mRL000ComRL00ol00005ooHW0003o`000?of9P3omRH000ComRH00ol00005ooLU0003o`000?og903o
mb@000?omb@00ol00005ooLS0003o`000?og8P3omb8000Comb800_l00007ooHV0003o`000?o]B`3o
000000CokD/000?o0000one;0?o]B`000_l000000oo9^@3o0000o`000003olVi0004o`000?o9^@3o
bKT0o`0000;obKP000Co0000olVh0?o9^03o00003_ooool00ol0003oooooooooo`05ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`07o`000?ooooooooooooooool0003oooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool3o`0000;ooooo0_l00004omRB
0004o`000?oLP`3og8<0omb300?o00001Ood;@000ol0003om2h0oo@^0003oo@^0003o`000?od<03o
m30000?om3000_l00006ooPN0003o`000?oh7`3on1l000?on1l00ol00006ooPO0003o`000?oh803o
n20000?o000000?omb80o`000?og8`001_og8`000ol0003omb<0ooLS0003o`0000;omb@000?o0000
ooLU0?og9@001?og9@04o`0000ComRH000?o0000ooHV0?of9P000oof9P03o`0000GomRL000?o0000
ooHW0?of9`001?of9`02o`0000OomRP000?o0000ooHW0?l000000_l000000oof:03o0000ooHX0006
ooHX0003o`000?of9`3omRL000?o000000?omRP0o`000?of9`001_of9`000ol0003omRH0ooHV0003
o`000003ooHV0?l0003ombD000GombD000?o0000ooLT0?og90000ol00002ooLT0003o`000?og8`3o
mb<000Comb<000?o0000ooLR0?og8P000ol00002ooLR0003o`000?of9P3omRH000ComRH00_l00004
one;0003o`000?o]B`3okD/000;okD/000Co0000olVi0?o9^@3o00000oo9^@000ol0003obKT0o`00
0003olVh0004o`000?o9^03obKP0o`0000kooooo00?o0000ooooooooool01Oooool00005ooooool0
003oooooooooool000002oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o
00002?ooool3o`0000Kooooo1?l000000ooHTP3o0000o`000002o`000003oo@^0?l0003om2d000Go
m2d000?o0000oo@^0?od;P000ood;P000ol0003om300oo@`0003o`0000;onA`000?o0000ooPN0?oh
7P001?oh7P000ol0003on1l0o`000002o`0000?on1h000?o0000ooPO0?oh7`000ooh7`03o`0000Go
mb8000?o0000ooLS0?og8`001?og8`03o`0000Komb@000?o0000ooLU0?og9@000ol000000oof9P3o
0000ooHV0006ooHV0003o`000?of9P3o000000;o00000_of9`000ol0003omRL0ooHW0004ooHW0003
o`000?of9`3omRL000?o00000_of:0000ol0003omRP0ooHX0004ooHX00;o00001Oof:0000ol0003o
mRP0ooHX0004ooHX00?o00001Oof:0000ol0003omRL0ooHW0004ooHW00?o00001Oof9P001?l0003o
mbD0ooLU0?og9@05o`0000Komb@000Co0000ooLS0?og8`3omb<01Ol00006ooLR0003o`000?of9P3o
mRH000?o000000?omRH0o`000?o]B`000_o]B`000ol0003okD/0one;0003one;0004o`000?o9^@3o
bKT0o`0000;obKT000Co0000olVi0?o9^@3o00000oo9^0000ol0003obKP0olVh0002o`0000kooooo
00?o0000ooooooooool01?ooool00005ooooool0003oooooooooool000002Oooool2o`0000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`?o00002Oooool01?l0003okd80
onm20?o_@P02o`0000Gom2h000?o0000oo@]0?od;@001?od;@000ol0003om2h0oo@^0002oo@^00?o
00001_oi70000ol0003on1h0ooPN0003ooPN00?o00001_oh7P000ol0003on1l0o`000002o`0000;o
n24000?o0000ooLR0?og8P001?og8P000ol0003omb<0ooLS0003o`0000;omb@000?o0000ooLT0?og
90001?og9003o`0000GomRH000?o0000ooHV0?of9P001?of9P02o`0000KomRL000Co0000ooHW0?of
9`3omRL01Ol00006ooHX0003o`000?of:03omRP000?o000000?omRT0o`000?of:0001Oof:0000ol0
003omRP0ooHX0003o`0000;omRP000?o0000ooHX0?of:0001?of:0000ol0003omRL0ooHW0003o`00
00;omRL000?o0000ooHV0?of9P000oof9P04o`0000ComRH000?o0000ooLT0?og90001?og9004o`00
00Comb<000?o0000ooLR0?og8P001?og8P03o`0000GomRH000?o0000one;0?l000001Oo]B`002?l0
003okD/0o`000?l0003obKT0o`000?o9^@3o00000_o9^@002Ol0003obKP0olVh0?o9^03o0000olVh
0?l0003obKP0o`00000>ooooo`03o`000?oooooooooo00Cooooo00001Ooooooo0000oooooooooooo
000000_ooooo00?o0000ooooool000000ol00004ooooo`;o00000_ooool3o`0000gooooo00Go0000
onm20?o_@P3okd80o`000006oo@^0003o`000?od;@3om2d000?om2d000?o0000oo@^0?l000000_l0
0002ooTK0003o`000?oi703onA`000GonA`000?o0000ooPN0?l000000_l00003ooTM0003o`000?oh
7P3on1h000?on1h00ol00005ooPQ0003o`000?og8P3omb8000?omb800ol00006ooLT0003o`000?og
903omb@000?o000000?omRH0o`000?of9P001_of9P000ol0003omRH0ooHV0003o`0000;omRL000?o
0000ooHW0?of9`000oof9`04o`0000ComRP000?o0000ooHX0?of:0001?of:003o`0000GomRT000?o
0000ooHX0?of:0000oof:003o`0000KomRP000Co0000ooHX0?of:03omRP01Ol00006ooHW0003o`00
0?of9P3o000000;o000000?omRL0o`000?of9P001_of9P000ol0003omb@0ooLT0003o`000003ooLU
0?l0003omb<000Komb<000?o0000ooLR0?og8P000ol000000oog8P3o0000ooHV0005ooHV00;o0000
1Oo]B`001Ol0003okD/0one;0?o]B`3o000000;obKT00_l00002olVi0004o`000?o9^03obKP0o`00
00;obKP000Co0000olVh0?o9^03o00003Oooool00ol0003oooooooooo`04ooooo`0000Goooooo`00
0?ooooooooooo`000007ooooo`07o`000?ooooooooooooooool0003oooooo`000007ooooo`Co0000
4Oooool01Ol0003okd80onm20?o_@P3o000000Gom2h000?o0000oo@]0?od;@000ood;@02o`0000Ko
nA/000?o0000ooTL0?oi70001?oi7002o`0000OonAd000?o0000ooPN0?l000000_l00003ooPP0003
o`000?oh8@3on24000?on24000?o0000ooLR0?l000000_l00003ooLS0003o`000?og903omb@000?o
mb@00ol00005ooHV0003o`000?of9P3omRH000ComRH00ol00006ooHW0003o`000?of9`3o000000;o
00000_of:0000ol0003omRP0ooHX0004ooHX0003o`000?of:03omRP000?o00000_of:@000ol0003o
mRT0ooHY0004ooHY0003o`000?of:03o000000;o00000_of:@000ol0003omRP0ooHX0004ooHX00Co
00001?of:0000ol0003omRL0ooHW0004ooHW00;o00001Oof9`000ol0003omRH0ooHV0004ooHV00?o
00001Oog9@000ol0003omb<0ooLS0004ooLS00?o00001Oog8P000ol0003omRH0ooHV0003o`0000;o
mRH000Go0000one;0?o]B`3okD/0o`000004one;00;o00000_o9^@001?l0003obKT0olVi0?l00002
olVh0004o`000?o9^03obKP0o`0000;obKP000?o0000ooooooooool02oooool00ol0003ooooooooo
o`04ooooo`000_ooool2o`0000Wooooo0ol00002ooooo`Go00000oooool2o`0001?ooooo00?o0000
onm20?o_@P000_o_@P000ol0003om2h0oo@^0003oo@^0003o`000?od;@3o000000;o00000_oi6@00
0ol0003onA/0ooTK0004ooTK0003o`000?oi703onA`000?o00000_oi70000ol0003onAd0ooTM0004
ooTM00;o00001ooh80001?l0003on240ooPQ0?oh8@04o`0000Komb<000?o0000ooLT0?l000000_l0
0003ooLU0003o`000?of9P3omRH000?omRH000?o0000ooHV0?of9P000ol00002ooHW0003o`000?of
9`3omRL000ComRL00_l00006ooHX0003o`000?of:03omRP000?omRP00ol00006ooHY0004o`000?of
:@3omRT0ooHY00Co00001_of:@000ol0003omRP0ooHX0003o`000003ooHY0?l0003omRP000KomRP0
00?o0000ooHW0?of9`000ol000000oof:03o0000ooHW0005ooHW0003o`000?of9P3omRH000?o0000
0_of9P000ol0003ombD0ooLU0004ooLU0003o`000?og8`3omb<000?o000000?omb<0o`000?og8P00
1Oog8P03o`0000KomRH000?o0000one;0?l000001?o]B`000ol0003okD/0one;0003o`000003olVi
0?l0003obKP000;obKP000Co0000olVh0?o9^03o00000_o9^002o`0000cooooo00?o0000oooooooo
ool01?ooool001cooooo00?o0000ooooooooool04Oooool01Ol0003okd80onm20?o_@P3o000000Go
m2h00ol00005ooTI0003o`000?oi6`3onA/000?onA/00ol00006ooTL0003o`000?oi7@3onAd000?o
00000_oh7P000ol0003on200ooPP0004ooPP00Co00001?og8P000ol0003omb<0ooLS0003ooLS00;o
00001oog9@001?l0003omRH0ooHV0?of9P04o`0000KomRL000?o0000ooHW0?of9`000ol00002ooHX
0003o`000?of:03omRP000ComRP000?o0000ooHX0?l000000_l00002ooHY0003o`000?of:@3omRT0
00ComRT01?l00004ooHY0003o`000?of:@3omRT000?omRT00ol00005ooHY0003o`000?of:03omRP0
00ComRP00ol00005ooHX0004o`000?of9`3omRL0ooHW00Go00001_of9P001?l0003ombD0ooLU0?og
9@05o`0000Gomb<000?o0000ooLR0?og8P000ol000000oog8P3o0000ooHV0006ooHV00;o00001?o]
B`000ol0003okD/0one;0002one;0004o`000?o9^@3o0000o`0000?obKP000?o0000olVh0?l00000
0_o9^0001?l0003obKP0olVh0?l0000;ooooo`03o`000?oooooooooo00Cooooo000Mooooo`03o`00
0?oooooooooo017ooooo1Ol000001?od;P3o0000o`000?l00003ooTJ0003o`000?oi6@3onAT000?o
nAT000?o0000ooTK0?l000000_l00003ooTJ0003o`000?oi703onA`000?onA`00ol00006ooPN0003
o`000?oh803on20000?o000000?on240o`000?og8P001_og8P000ol0003omb<0o`000002o`0000;o
mb@000?o0000ooLU0?og9@001?og9@04o`0000ComRL000?o0000ooHW0?of9`000oof9`03o`0000Ko
mRP000Co0000ooHX0?of:03omRP01?l00006ooHY0003o`000?of:@3omRT000?o00000_oe:P000ol0
003omRT0ooHY0004ooHY0003o`000?of:@3o000000;o00000_of:@000ol0003omRT0ooHY0004ooHY
0003o`000?of:03omRP000?o00000_of:@000ol0003omRP0ooHX0003ooHX00Co00001?of9`000ol0
003omRH0ooHV0004ooHV00Co00000oog9@000ol0003omb<0ooLS0004ooLS00?o00001Oog8P000ol0
003omRH0ooHV0002ooHV00;o000000?omRH0o`000?o]B`000_o]B`000ol0003okD/0one;0003one;
0004o`000?o9^@3obKT0o`0000?obKP000?o0000olVh0?l000000_o9^0001?l0003obKP0olVh0?l0
000;ooooo`03o`000?oooooooooo00Cooooo000Nooooo`03o`000?oooooooooo017ooooo00?o0000
oo@^0?od;P000_l00007ooTJ0004o`000?oi6@3onAT0ooTI00Co00001_oi6P000ol0003onA`0o`00
0002o`0000?on1d000?o0000ooPN0?oh7P000ooh7P03o`0000Gon24000?o0000ooLR0?og8P001?og
8P02o`0000Komb@000?o0000ooLU0?og9@000ol00002ooHV0003o`000?of9`3omRL000ComRL000?o
0000ooHW0?l000000_l00002ooHX0003o`000?of:03omRP000ComRP01?l00004ooHY0003o`000?of
:@3omRT000?omRT00ol00006ooDZ0004o`000?of:@3omRT0ooHY00Co00001_of:@001?l0003omRT0
ooHY0?of:@05o`0000KomRT000?o0000ooHX0?l000000_l000000oof:03o0000ooHW0006ooHW0003
o`000?of9P3omRH000?o000000?omRH0o`000?og9@001Oog9@000ol0003omb<0ooLS0003o`0000;o
mb<000?o0000ooLR0?og8P001?og8P001?l0003omRH0o`000?l00004ooHV0004o`000?o]B`3okD/0
o`0000CokD/000Go0000one:0?l0003obKT0o`000002olVh0004o`000?o9^03obKP0o`0000;obKP0
00?o0000olVh0?o9^0000_l0000;ooooo`03o`000?oooooooooo00?ooooo000Oooooo`;o00004_oo
ool01Ol0003om2h0oo@^0?od;P3o000000KonAX01?l00004ooXH0003o`000?oi6P3onAX000?onAX0
0ol00006ooPM0003o`000?oh7P3o000000;o00000ooh80000ol0003on240ooPQ0003ooPQ0003o`00
0?og8P3omb8000?o00000_og90000ol0003omb@0ooLT0003ooLT00?o00001_of9P001?l0003omRL0
ooHW0?of9`04o`0000KomRP000?o0000ooHX0?of:0000ol000000oof:@3o0000ooHY0006ooHY0003
o`000?of:@3o000000;o00000_oe:P000ol0003omBX0ooDZ0004ooDZ00Co00001?oe:P000ol0003o
mRT0ooHY0003ooHY00Co00001?of:@000ol0003omRT0ooHY0004ooHY00;o00001Oof:0000ol0003o
mRL0ooHW0004ooHW00?o00001Oof9P001?l0003ombD0ooLU0?og9@05o`0000Komb<000Co0000ooLR
0?og8P3omb801?l00006ooHV0003o`000?o]B`3o000000CokD/000?o0000one:0?o]BP000_l00000
1?o9^03o0000olVh0?l00002olVh0006o`000?o9^03obKP0o`000?o9^03o00000_o:^0000ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00?ooooo000Qooooo`03o`000?oooooooooo013ooooo
1Ol00002ooTJ00?o000000?onAT0o`000?oj60001_oj60000ol0003onAX0o`000002o`0000?onA`0
00?o0000ooPM0?oh7@000ooh7@02o`0000Oon20000Co0000ooPQ0?oh8@3on2401?l00006ooLT0003
o`000?og903o000000;o00000oof9P000ol0003omRH0ooHV0003ooHV00Co00001?of:0000ol0003o
mRP0ooHX0003ooHX00?o00001Oof:@000ol0003omRT0ooHY0004ooHY00;o00001_oe:P000ol0003o
mBX0ooDZ0003o`000003ooDZ0?l0003omBX000KomBX000?o0000ooHY0?l000000_l00002ooDZ0003
o`000?of:@3omRT000ComRT000?o0000ooHY0?of:@000ol000000oof:@3o0000ooHX0005ooHX0003
o`000?of9`3omRL000?o00000_of9`000ol0003omRH0ooHV0003ooHV00Co00001?og9@000ol0003o
mb<0ooLS0004ooLS00Co00000oog8P000ol0003omRH0ooHV0004ooHV00;o00001?o]B`000ol0003o
kDX0one:0002one:0003o`000?o9^03obKP000;o00000_o9^0000ol0003obKP0o`000002olVh0004
o`000?o:^03ob[P0o`0000Wooooo0_l00005ooooo`008_ooool00ol0003oooooooooo`0Aooooo`03
o`000?od;@3o000000;o00001Ooi6@000ol0003onQP0ooXH0004ooXH00;o00001ooi70000ol0003o
n1d0o`000002o`0000;on1l000?o0000ooPP0?oh80001?oh8004o`0000Comb<000?o0000ooLT0?og
90000oog9002o`0000OomRH000?o0000ooHV0?l000000_l00002ooHW0003o`000?of:03omRP000Co
mRP000?o0000ooHX0?l000000_l00003ooHY0003o`000?of:@3omRT000?omRT000?o0000ooHY0?of
:@000ol00002ooDZ0003o`000?oe:P3omBX000?omBX00ol00005ooDZ0003o`000?oe:P3omBX000Co
mBX00_l00006ooDZ0004o`000?of:@3omRT0ooHY00Go00001Oof:@001?l0003omRP0ooHX0?of:005
o`0000KomRL000?o0000ooHV0?l000000_l000000oof9P3o0000ooLU0006ooLU0003o`000?og8`3o
mb<000?o000000?omb<0o`000?og8P001Oog8P000ol0003omRH0ooHV0003o`000003ooHV0?l0003o
kD/000;okD/000?o0000one:0?o]BP000oo]BP02o`0000;obKP000?o0000olVh0?l000000_o9^000
1?l0003obKP0olVh0?l00002olZh00;o00002?ooool2o`0000Gooooo000Sooooo`03o`000?oooooo
oooo017ooooo00Go0000oo@]0?od;@3om2d0o`000005ooTI0003o`000?oj603onQP000?o00000_oi
6P000ol0003onA`0ooTL0004ooTL00;o00001_oh7`000ol0003on200ooPP0003o`000003ooLR0?l0
003omb<000Komb<000?o0000ooLT0?l000000_l00002ooLU0003o`000?of9P3omRH000ComRH00_l0
0006ooHW0003o`000?of:03omRP000?omRP00_l00007ooHY0004o`000?of:@3omRT0ooHY00Co0000
1_oe:P000ol0003omBX0o`000002o`0000;omBX000?o0000ooDZ0?oe:P001?oe:P000ol0003omBX0
ooDZ0003o`0000;omBX000?o0000ooDZ0?oe:P000ooe:P04o`0000ComRT000?o0000ooHY0?of:@00
0oof:@04o`0000ComRP000?o0000ooHW0?of9`001?of9`02o`0000GomRH000?o0000ooLU0?og9@00
1?og9@03o`0000Gomb<000?o0000ooLR0?og8P000oog8P03o`0000GomRH000?o0000one;0?l00000
1Oo]BP000ol0003okDT0one90003o`000005olVh0?l0003obKP0olVh0?l000000_o9^0000ol0003o
b[P0o`000002olZh0003o`000?oooooooooo00Gooooo0_l00005ooooo`009?ooool00ol0003ooooo
ooooo`0Aooooo`Go00000ooi6@04o`0000KonAX000?o0000ooTL0?oi70000ol00002ooPM0003o`00
0?oh7`3on1l000?on1l00ol00005ooLR0003o`000?og8`3omb<000Comb<00_l00006ooLU0003o`00
0?of9P3omRH000?o00000_of9P000ol0003omRL0ooHW0004ooHW0003o`000?of:03o000000;o0000
0_of:0000ol0003omRT0ooHY0004ooHY00Co00000ooe:P000ol0003omBX0ooDZ0004ooDZ00;o0000
1_oe:P001?l0003omBX0ooDZ0?oe:P05o`0000KomBX000?o0000ooDZ0?l000000_l000000ooe:P3o
0000ooHY0006ooHY0003o`000?of:@3o000000;o00000_of:@000ol0003omRP0ooHX0004ooHX0003
o`000?of9`3omRL000?o000000?omRL0o`000?of9P001Oof9P000ol0003ombD0ooLU0003o`000003
ooLU0?l0003omb<000Gomb<000?o0000ooLR0?og8P000ol00002ooLR0003o`000?of9P3omRH000?o
mRH00_l00005one:0003o`000?o]B@3okDT000;okDT000Co0000olVh0?l0003o00000_o9^0000ol0
003obKP0o`000002olZh0003o`000?o:^03ob[P000;o00001Oooool3o`0000Gooooo000Uooooo`;o
00004oooool00ol0003om2h0o`000003o`0000ConA/000?o0000ooTJ0?oi6P000ooi6P03o`0000Ko
n1d000?o0000ooPO0?l000000_l00003ooPP0003o`000?og8P3omb8000?omb8000?o0000ooLS0?og
8`000ol00002ooLT0003o`000?og9@3ombD000?ombD00ol00006ooHV0004o`000?of9`3omRL0ooHW
00Co00001_of:0000ol0003omRT0ooHY0003o`0000;omRT000?o0000ooDZ0?oe:P000ooe:P000ol0
003omBX0ooDZ0003o`0000;omB/000?o0000ooDZ0?oe:P000ooe:P04o`0000ComB/000?o0000ooDZ
0?oe:P001?oe:P02o`0000GomBX000?o0000ooHY0?of:@001?of:@02o`0000KomRT000Co0000ooHX
0?of:03omRP01Ol00005ooHW0004o`000?of9P3omRH0ooHV00Go00001Oog9@001?l0003omb<0ooLS
0?og8`05o`0000Komb8000?o0000ooHV0?l000000_l00002ooHU0005o`000?o]BP3okDX0one:0?l0
00001?o]B@02o`0000;obKP000?o0000olVh0?l000000_o9^0001?l0003ob[P0olZh0?l00002olZh
0003o`000?o:]`3o000000Cooooo0ol00005ooooo`009oooool00ol0003oooooooooo`0Aooooo`05
o`000?od;P3om2h0oo@^0?l000001Ooi6`000ol0003onAX0o`000002o`0000?onA`000?o0000ooPM
0?oh7@000ooh7@03o`0000Kon20000Co0000ooLR0?og8P3omb801?l00006ooLT0003o`000?og9@3o
000000;o00000oof9P000ol0003omRH0ooHV0003ooHV00Co00001?of:0000ol0003omRP0ooHX0003
ooHX00?o00001_of:@001?l0003omBX0ooDZ0?oe:P04o`0000KomB/000?o0000ooDZ0?l000000_l0
0002ooD[0003o`000?oe:`3omB/000ComB/000?o0000ooDZ0?oe:P000ol000000ooe:`3o0000ooDZ
0005ooDZ0003o`000?of:@3omRT000?o000000?omBX0o`000?of:@001Oof:@04o`0000ComRP000?o
0000ooHW0?of9`000oof9`04o`0000ComRH000?o0000ooLU0?og9@000oog9@04o`0000Comb<000?o
0000ooLR0?og8P001?og8P02o`0000KomRD000?o0000one:0?l000001?o]B@000ol0003okDT0one9
0002o`000003olVh0?l0003o000000;obKP000Co0000olZh0?o:^03o00000_o:^0001?l0003ob[L0
olZg0?l00003ooooo`?o00001Oooool002Sooooo00?o0000ooooooooool04Oooool5o`0000?onA/0
1?l00006ooTL0003o`000?oh7@3o000000;o00000ooh7P000ol0003on200ooPP0003ooPP00Co0000
1?og8`000ol0003omb@0ooLT0003ooLT00;o00001oof9P000ol0003omRH0o`000002o`0000;omRL0
00?o0000ooHX0?of:0001?of:0000ol0003omRP0o`000002o`0000;omRT000?o0000ooHY0?of:@00
1?of:@04o`0000?omBX000?o0000ooD[0?oe:`001?oe:`02o`0000KomB/000Co0000ooD[0?oe:`3o
mB/01Ol00005ooD[0004o`000?oe:P3omBX0ooDZ00Go00001Ooe:P000ol0003omRT0ooHY0003o`00
0003ooHY0?l0003omRP000KomRP000?o0000ooHW0?l000000_l00002ooHW0003o`000?of9P3omRH0
00ComRH000?o0000ooLU0?l000000_l00002ooLT0003o`000?og8`3omb<000Comb<000?o0000ooLR
0?og8P000ol000000ooh8@3o0000ooHU0005ooHU00;o00001?o]B@000ol0003okDT0one90002one9
0004o`000?o9^03o0000o`0000;obKP000?o0000olZh0?l000000_o:^0001?l0003ob[L0olZg0?o:
]`02o`000006ooooool0003o>Yl0o`000?oooooo00001?ooool002Wooooo00?o0000ooooooooool0
4_ooool00ol0003om300o`000003o`0000ConA`000?o0000ooTL0?oi70000ooi7002o`0000Oon1h0
00?o0000ooPP0?l000000_l00002ooPQ0003o`000?og8`3omb<000Comb<000?o0000ooLT0?l00000
0_l00002ooLU0003o`000?of9P3omRH000ComRH00_l00006ooHW0004o`000?of:03omRP0ooHX00Co
00001_of:@000ol0003omRT0ooHY0003o`0000;omBX000?o0000ooDZ0?oe:P000ooe:P000ol0003o
mB/0ooD[0003o`0000;omB/000?o0000ooD[0?oe:`000ooe:`04o`0000ComB/000?o0000ooD[0?oe
:`000ooe:`04o`0000ComBX000?o0000ooDZ0?oe:P000ooe:P03o`0000GomRT000?o0000ooHX0?of
:0001?of:002o`0000KomRL000Co0000ooHV0?of9P3omRH01?l00006ooLT0004o`000?og8`3omb<0
ooLS00Go00001Ooh8@000ol0003omRD0ooHU0003o`000003ooLU0?l0003okDT000;okDT000?o0000
one90?o]B@000_o]B@02o`0000;obKP000?o0000olVh0?l000000_o:^0001?l0003ob[P0olZh0?l0
0003olZg0008o`000?o:]`3o0000o`000?ljW`3o0000ooooool00004ooooo`00:_ooool2o`0001?o
oooo00Go0000oo@`0?od<03om300o`000005ooTL0003o`000?oi703o000000;o00000_oi7@000ol0
003on1h0ooPN0004ooPN00;o00001_oh8@001?l0003omb<0ooLS0?og8`04o`0000KombD000?o0000
ooHV0?of9P000ol00002ooHV0003o`000?of9`3omRL000?omRL01?l00004ooHY0003o`000?of:@3o
mRT000?omRT00ol00006ooDZ0004o`000?oe:P3omBX0ooDZ00Co00001_oe:`000ol0003omB/0o`00
0002o`000003ooD[0?l0003omB/000KomB/000?o0000ooD[0?l000000_l00002ooD[0003o`000?oe
:P3omBX000ComBX000?o0000ooDZ0?l000000_l00002ooDZ0003o`000?of:@3omRT000ComRT000?o
0000ooHX0?of:0000ol000000oof:03o0000ooHW0005ooHW00Co00000oof9P000ol0003omb@0ooLT
0004ooLT00Co00000oog8P000ol0003on240ooPQ0004ooPQ00?o00001Oog9@000ol0003okDT0o`00
0004one90003o`000?o]B03okDP000;o000000?obKP0o`000?l000000_o:^0001?l0003ob[P0olZh
0?l00002olZg0003o`000?o:]`3ob[L000;o000000Co>Yl0o`000?oooooo00001?ooool002cooooo
00?o0000ooooooooool04Oooool5o`0000?onA`00ol00006ooTM0003o`000?oh7P3on1h000?o0000
0_oh80000ol0003on240ooPQ0003ooPQ00Co00001?og90000ol0003ombD0ooLU0003ooLU00?o0000
1_of9P000ol0003omRL0o`000002o`0000?omRP000?o0000ooHY0?of:@000oof:@000ol0003omRT0
o`000002o`0000;omBX000?o0000ooDZ0?oe:P001?oe:P04o`0000?omB/000?o0000ooD[0?oe:`00
1?oe:`02o`0000GomB/000?o0000ooD[0?oe:`001?oe:`02o`0000KomB/000Co0000ooDZ0?oe:P3o
mBX01?l00006ooDZ0004o`000?of:@3omRT0ooHY00Go00001Oof:0000ol0003omRL0ooHW0003o`00
0003ooHW0?l0003omRH000GomRH000?o0000ooLT0?og90000ol000000oog903o0000ooLR0005ooLR
0003o`000?oh8@3on24000?o000000?on240o`000?og9@001Oog9@02o`0000CokDT000?o0000one8
0?o]B0000_o]B0001?l0003obKP0o`000?l00002olZh0004o`000?o:^03ob[P0o`0000;ob[L000?o
0000olZg0?o:]`001?l000000ooooooo0000ooooo`03ooooo`00;Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oc<@3olc4000Co00000ooh7P000ol0003onAd0ooTM0003ooTM00?o00001_oh8000
0ol0003on240o`000002o`0000?omb8000?o0000ooLT0?og90000oog90000ol0003ombD0o`000002
o`0000?omRH000?o0000ooHV0?of9P000oof9P02o`0000OomRP000Co0000ooHY0?of:@3omRT00ol0
0006ooDZ0003o`000?oe:P3omBX000?o00000_oe:`000ol0003omB/0ooD[0003ooD[0003o`000?oe
:`3omB/000?o00000_oe:`000ol0003omB/0ooD[0003ooD[0003o`000?oe:`3omB/000?o00000_oe
:`000ol0003omB/0ooD[0003ooD[00Co00001?oe:P000ol0003omBX0ooDZ0003ooDZ00Co00001?of
:@000ol0003omRP0ooHX0003ooHX00?o00001Oof9`000ol0003omRH0ooHV0003ooHV00?o00001Oog
90000ol0003omb80ooLR0003ooLR00?o00001Ooh8@000ol0003ombD0ooLU0003o`000003ooLT0?l0
003okDT000;okDT000?o0000one80?o]B0000oo]B0001_l0003obKP0olVh0?l0003ob[P0o`0000?o
b[P000co0000olZg0?o:]`3o0000olZg0?l0003ob;/0o`000?n__`3o0000ooooool00004ooooo`00
;_ooool00ol0003oooooooooo`0Aooooo`05o`000?oc<@3olc40oo<a0?l000001Ooh7P000ol0003o
nAd0o`000002o`0000?on1h000?o0000ooPP0?oh80000ooh8003o`0000Komb8000Co0000ooLT0?og
903omb@00ol00007ooHV0003o`000?of9P3o000000;o00000_of9`000ol0003omRP0ooHX0004ooHX
00Co00000oof:@000ol0003omBX0ooDZ0003ooDZ00?o00001_oe:`001?l0003omB/0ooD[0?oe:`04
o`0000KomB/000Co0000ooD[0?oe:`3omB/01?l00006ooD[0003o`000?oe:`3o000000;o00000_oe
:`000ol0003omBX0ooDZ0004ooDZ0003o`000?oe:P3o000000;o00000_of:@000ol0003omRT0ooHY
0004ooHY0003o`000?of:03o000000;o00000_of:0000ol0003omRL0ooHW0003ooHW0003o`000?of
9P3omRH000?o00000_og9@000ol0003omb@0ooLT0003ooLT0003o`000?og8P3omb8000?o00000_og
8P000ol0003on240ooPQ0003ooPQ00?o00001Oog90000ol0003okDT0o`000005one80005o`000?o^
A`3o0000o`000?o:^0000_l00002olZh000=o`000?o:]`3ob[L0olZg0?l0003ob[L0o`000?o8^`3o
0000ojno0?l0003oooooo`000004ooooo`00;oooool00ol0003oooooooooo`0Aooooo`Go00000ooh
7P04o`0000Kon1h000?o0000ooPP0?l000000_l00003ooPQ0003o`000?og8P3omb8000?omb801?l0
0003ooLT0003o`000?of9P3omRH000ComRH00_l00006ooHW0003o`000?of:03omRP000?o00000_of
:0000ol0003omRT0ooHY0003ooHY0003o`000?oe:P3o000000;o00000ooe:P000ol0003omB/0ooD[
0003ooD[00Co00000ooe:`000ol0003omB/0ooD[0004ooD[00Co00000ooe:`000ol0003omB/0ooD[
0004ooD[00;o00001_oe:`001?l0003omBX0ooDZ0?oe:P04o`0000KomRT000Co0000ooHY0?of:@3o
mRT01?l00006ooHX0004o`000?of9`3omRL0ooHW00Co00001_og9@001?l0003omb@0ooLT0?og9004
o`0000Komb8000?o0000ooPQ0?l000000_l000000ooh803o0000ooLT0005ooLT00;o00001Oo]B000
1Ol0003okTL0oni70?o^A`3o000000;ob[P000Co0000olZh0?o:^03o00000_o:]`001Ol0003ob[L0
olZg0?l0003ob;/000;o00000_ooool00ol0003oooooooooo`02ooooo`00<?ooool2o`0001?ooooo
00?o0000oo<b0?l000000ol00004ooPO0003o`000?oh7P3on1h000?on1h00_l00007ooPQ0003o`00
0?og8P3o000000;o00000_og8`000ol0003omb@0ooLT0003ooLT0003o`000?of9P3omRH000?o0000
0_of9P000ol0003omRL0ooHW0003ooHW00?o00001_of:0001?l0003omRT0ooHY0?of:@03o`0000Oo
mBX000?o0000ooD[0?l000000_l00002ooD[0003o`000?oe:`3omB/000?omB/000?o0000ooD[0?oe
:`000ol00002ooD[0003o`000?oe:`3omB/000?omB/000?o0000ooD[0?oe:`000ol00002ooD[0003
o`000?oe:`3omB/000?omB/01?l00003ooDZ0003o`000?of:@3omRT000ComRT01?l00003ooHX0003
o`000?of:03omRP000ComRP01?l00003ooHV0003o`000?og9@3ombD000CombD01?l00003ooLS0003
o`000?og8P3omb8000Comb800_l00005ooPP0004o`000?og903omb@0ooLT00;o00000_og8`001Ol0
003okDP0one80?o]B03o000000CokTL000Co0000olZh0?o:^03o00000_o:^0001?l0003ob[L0olZg
0?l00002olZg0004o`000?o8^`3o0000o`0000?ooooo00?o0000ooooooooool00Oooool003;ooooo
00?o0000ooooooooool04Oooool01Ol0003olc80oo<b0?oc<P3o000000Gon1l000?o0000ooPN0?l0
00000_l00002ooPO0003o`000?oh8@3on24000Con2400_l00006ooLS0004o`000?og903omb@0ooLT
00Co00001_of9P000ol0003omRL0o`000002o`0000?omRP000?o0000ooHX0?of:0000oof:004o`00
00?omRT000?o0000ooDZ0?oe:P001?oe:P02o`0000KomB/000Co0000ooD[0?oe:`3omB/01?l00006
ooD[0004o`000?oe:`3omB/0ooD[00Co00001_oe:`000ol0003omB/0o`000002o`0000;omB/000?o
0000ooDZ0?oe:P000ooe:P000ol0003omRT0ooHY0003o`0000;omRT000?o0000ooHX0?of:0000oof
:0000ol0003omRP0ooHX0003o`000003ooHW0?l0003omRH000GomRH000?o0000ooLU0?og9@000ol0
00000oog9@3o0000ooLS0005ooLS0003o`000?og8P3omb8000?o000000?on240o`000?oh80001Ooh
80000ol0003omb@0o`000005ooLS0003o`000?o]B03o000000CokTL000So0000oni70?l0003o0000
olZh0?l0003ob[P0o`0000;ob[L000Oo0000olZg0?l0003ob;/0o`000?n__`3o000000?ooooo00?o
0000ooooooooool00Oooool003?ooooo00?o0000ooooooooool04Oooool5o`0000?on1l00ol00006
ooPO0003o`000?oh8@3on24000?o00000_og8P000ol0003omb<0ooLS0003ooLS00Co00001?og9@00
0ol0003omRH0ooHV0003ooHV00;o00001oof:0000ol0003omRP0o`000002o`0000;omRT000?o0000
ooHY0?of:@000oof:@000ol0003omBX0ooDZ0003o`0000;omBX000?o0000ooD[0?oe:`000ooe:`04
o`0000?omB/000?o0000ooD[0?oe:`001?oe:`04o`0000?omB/000?o0000ooD[0?oe:`001?oe:`02
o`0000KomB/000Co0000ooDZ0?oe:P3omBX01?l00006ooHY0004o`000?of:03omRP0ooHX00Co0000
1Oof9`001?l0003omRH0ooHV0?of9P05o`0000GombD000Co0000ooLS0?og8`3omb<01Ol00005ooPQ
0004o`000?oh803on200ooPP00Co00001_og8`02o`0000CokTL000Go0000oni70?o^A`3okTL0o`00
0002olZh00;o00000_o:]`001ol0003ob[L0o`000?o8^`3o0000ojno0?l000000oooool00ol0003o
ooooooooo`01ooooo`00=?ooool00ol0003oooooooooo`0Aooooo`03o`000?oc<`3olc<000Co0000
0ooh80000ol0003on1l0ooPO0003ooPO00?o00001_og8P000ol0003omb<0o`000002o`0000?omb@0
00?o0000ooLU0?og9@000oog9@000ol0003omRH0o`000002o`0000;omRL000?o0000ooHX0?of:000
1?of:002o`0000KomRT000Co0000ooHY0?of:@3omRT01?l00006ooDZ0003o`000?oe:`3o000000;o
00000_oe:`000ol0003omB/0ooD[0003ooD[0003o`000?oe:`3omB/000?o00000_oe:`000ol0003o
mB/0ooD[0003ooD[0003o`000?oe:`3omB/000?o000000?omB/0o`000?oe:`001Ooe:`04o`0000?o
mBX000?o0000ooHY0?of:@001?of:@04o`0000?omRP000?o0000ooHW0?of9`000oof9`04o`0000Co
mRH000?o0000ooLU0?og9@000oog9@04o`0000?omb8000?o0000ooPQ0?oh8@001?oh8@04o`0000?o
n1l000?o0000ooLS0?og8`000_og8`02o`000003ooLR0?l0003okTL000;okTL000?o0000oni70?o^
A`000_o^A`02o`000005olZh0?l0003o0000olZg0?l000000_o:]`001?l0003ob;/0o`000?l00004
ooooo`03o`000?oooooooooo007ooooo000eooooo`;o00004_ooool01Ol0003olc<0oo<c0?oc<`3o
000000Gon20000?o0000ooPO0?l000000_l00003ooPP0003o`000?og8P3omb8000?omb800_l00007
ooLT0004o`000?og9@3ombD0ooLU00?o00001_of9`000ol0003omRP0ooHX0003o`0000;omRP000?o
0000ooHY0?of:@000oof:@04o`0000?omBX000?o0000ooDZ0?oe:P001?oe:P02o`0000KomB/000Co
0000ooD[0?oe:`3omB/01?l00006ooD[0004o`000?oe:`3omB/0ooD[00Co00001Ooe:`000ol0003o
mB/0ooD[0003o`0000;omBX000?o0000ooDZ0?oe:P000ooe:P000ol0003omRT0ooHY0003o`000003
ooHY0?l0003omRP000GomRP000?o0000ooHW0?l000000_l00002ooHW0003o`000?of9P3omRH000Co
mRH000?o0000ooLU0?l000000_l00002ooLT0003o`000?og8P3omb8000?omb8000?o0000ooPQ0?oh
8@000ol000000ooh803o0000ooPO0005ooPO0004o`000?og8`3o0000o`0000Comb8000?o0000oni7
0?l000001?o^A`000ol0003okTD0oni50003o`000006olZg0?l0003ob[L0olZg0?l0003ob;/00_l0
0004ooooo`03o`000?oooooooooo007ooooo000gooooo`03o`000?oooooooooo013ooooo1Ol00003
ooPP00Co00001_oh80000ol0003omb80o`000002o`0000;omb<000?o0000ooLT0?og90001?og9004
o`0000?omRH000?o0000ooHW0?of9`000oof9`03o`0000KomRP000?o0000ooHY0?l000000_l00002
ooHY0003o`000?oe:P3omBX000?omBX000?o0000ooDZ0?oe:P000ol00002ooD[0003o`000?oe:`3o
mB/000?omB/01?l00003ooD[0003o`000?oe:`3omB/000ComB/01?l00003ooD[0003o`000?oe:`3o
mB/000?omB/00ol00006ooDZ0004o`000?oe:P3omBX0ooDZ00Co00001Oof:@001?l0003omRP0ooHX
0?of:004o`0000KomRL000Co0000ooHV0?of9P3omRH01?l00006ooLT0004o`000?og8P3omb80ooLR
00Co00001Ooh80001?l0003on1l0ooPO0?oh7`04o`0000Komb800_l00004oni70003o`000?o^A@3o
kTD000;okTD000Co0000olZg0?l0003o00000_o:]`001?l0003ob;/0o`000?l00004ooooo`03o`00
0?oooooooooo007ooooo000hooooo`03o`000?oooooooooo017ooooo00?o0000oo<d0?l000000ol0
0004ooPQ00;o00000ooh8003o`0000Komb<000?o0000ooLT0?og90000ol00002ooLT0003o`000?of
9P3omRH000?omRH000?o0000ooHW0?l000000_l00002ooHW0003o`000?of:03omRP000ComRP00_l0
0006ooHY0004o`000?oe:P3omBX0ooDZ00Co00001_oe:`000ol0003omB/0o`000002o`0000;omB/0
00?o0000ooD[0?oe:`000ooe:`000ol0003omB/0ooD[0003o`000003ooD[0?l0003omB/000GomB/0
00?o0000ooD[0?l000000_l00002ooD[0003o`000?oe:P3omBX000ComBX01?l00003ooHY0003o`00
0?of:@3omRT000?omRT01?l00003ooHW0003o`000?of9`3omRL000ComRL01?l00003ooLU0003o`00
0?og903omb@000Comb@01?l00003ooLR0003o`000?oh803on20000?on2001?l00003ooPM0003o`00
0?og8P3omb8000;omb800_l000000ooh8@3o0000oni70002oni70003o`000?o^A@3okTD000;okTD0
0_l00002olZg0004o`000?o:]`3o0000olRk00;o00001Oooool00ol0003oooooooooo`01ooooo`00
>Oooool00ol0003oooooooooo`0Aooooo`05o`000?oc=03olc@0oo<d0?l000001Ooh8@04o`0000?o
n24000?o0000ooLS0?og8`000oog8`03o`0000Komb@000Co0000ooHV0?of9P3omRH01?l00005ooHW
0003o`000?of:03omRP000?o00000_of:0000ol0003omRT0ooHY0003ooHY00Co00000ooe:P000ol0
003omB/0ooD[0004ooD[00;o00001_oe:`001?l0003omB/0ooD[0?oe:`04o`0000GomB/000Co0000
ooD[0?oe:`3omB/01?l00006ooD[0003o`000?oe:P3omBX000?o000000?omBX0o`000?of:@001Oof
:@000ol0003omRT0o`000002o`0000;omRP000?o0000ooHW0?of9`000oof9`000ol0003omRL0ooHW
0003o`000003ooHV0?l0003ombD000GombD000?o0000ooLT0?og90000ol000000oog8`3o0000ooLR
0005ooLR0003o`000?oh803o000000;o00000_oh7`000ol0003on1d0ooPM0003ooPM0004o`000?og
8P3o0000o`0000Con24000?o0000oni70?l000001?o^A@000ol0003okd@0onm40002o`000004olZg
0?l0003o0000olRk00;o00001Oooool00ol0003oooooooooo`01ooooo`00>_ooool00ol0003ooooo
ooooo`0Aooooo`Go000000Con240o`000?l0003o00000_og8P000ol0003on240ooPQ0003ooPQ0003
o`000?og8`3o000000;o00000oog8`000ol0003omb@0ooLT0003ooLT00Co00001?of9P001?l0003o
mRL0ooHW0?of9`04o`0000KomRP000?o0000ooHY0?l000000_l00002ooHY0003o`000?oe:P3omBX0
00?omBX000?o0000ooD[0?oe:`000ol00002ooDZ0003o`000?oe:`3omB/000?omB/01?l00003ooD[
0003o`000?oe:`3omB/000?omB/01?l00004ooD[0003o`000?oe:`3omB/000?omB/00ol00005ooDZ
0004o`000?of:@3omRT0ooHY00Co00001_of:0001?l0003omRL0ooHW0?of9`04o`0000GomRH000Co
0000ooLU0?og9@3ombD01Ol00005ooLS0004o`000?og8P3omb80ooLR00Co00001_oh7`001?l0003o
n1d0ooPM0?oh7@03o`0000Kon2400_l00004oni50003o`000?o_A03okd@000;okd@000Go0000olZg
0?l0003o0000olRk0002o`0000Kooooo0Ol00001ooooo`7ooooo000kooooo`;o00004_ooool00ol0
003olc@0oo<d0002o`0000Komb8000Co0000ooPQ0?oh8@3on2401?l00006ooLS0003o`000?og903o
000000;o00000_og9@000ol0003omRH0ooHV0003ooHV00Co00001?of9`000ol0003omRP0ooHX0003
ooHX00;o00001_of:@001?l0003omBX0ooDZ0?oe:P04o`0000KomBX000?o0000ooD[0?l000000_l0
0002ooD[0003o`000?oe:`3omB/000?omB/000?o0000ooD[0?l000000_l00002ooD[0003o`000?oe
:`3omB/000ComB/000?o0000ooD[0?l000000_l00002ooDZ0003o`000?oe:P3omBX000?omBX01?l0
0003ooHY0003o`000?of:03omRP000ComRP01?l00003ooHW0003o`000?of9P3omRH000?omRH01?l0
0003ooLT0003o`000?og8`3omb<000Comb<01?l00003ooPP0003o`000?oh7`3on1l000Con1l01?l0
0003ooTL0004o`000?oh8@3on240ooPQ00;o000000?on1l0o`000?o^A@000_o^A@000ol0003okd@0
onm40003onm40005o`000?o:]`3ob[L0o`000?o8^`000_l00006ooooo`7o00000Oooool1ooooo`00
?Oooool00ol0003oooooooooo`0@ooooo`05o`000?oc=03olc@0oo<d0?l000001Oog8P04o`0000Co
mb8000?o0000ooLS0?og8`000oog8`02o`0000KombD000?o0000ooHV0?l000000_l00002ooHV0003
o`000?of9`3omRL000ComRL000?o0000ooHX0?l000000_l00002ooHX0003o`000?of:@3omRT000?o
mRT01?l00003ooDZ0003o`000?oe:P3omBX000ComBX00_l00006ooD[0004o`000?oe:`3omB/0ooD[
00?o00001_oe:`001?l0003omB/0ooD[0?oe:`04o`0000KomBX000?o0000ooDZ0?l000000_l00002
ooHY0003o`000?of:@3omRT000?omRT000?o0000ooHX0?of:0000ol000000oof9`3o0000ooHW0005
ooHW0003o`000?of9P3o000000;o00000_og9@000ol0003omb@0ooLT0003ooLT0003o`000?og8`3o
mb<000?o000000?omb80o`000?oh80001Ooh80000ol0003on1l0ooPO0003o`000003ooPM0?l0003o
nA`000GonA`000?o0000ooPQ0?l000001?oh7`000ol0003okTD0o`000005onm40005o`000?o_@`3o
0000o`000?o8^`000_l00007ooooo`7o00000Oooool1ooooo`00?_ooool00ol0003oooooooooo`0@
ooooo`Go000000Comb80o`000?l0003o00000oog8P000ol0003omb80ooLR0003ooLR0003o`000?og
8`3o000000;o00000_og8`000ol0003ombD0ooLU0003ooLU00;o00001_of9P001?l0003omRL0ooHW
0?of9`04o`0000KomRP000?o0000ooHY0?l000000_l00002ooHY0003o`000?oe:P3omBX000?omBX0
00?o0000ooDZ0?oe:P000ol00002ooDZ0003o`000?oe:`3omB/000?omB/01?l00003ooD[0003o`00
0?oe:`3omB/000?omB/01?l00004ooDZ0004o`000?oe:P3omBX0ooDZ00Co00001_of:@001?l0003o
mRT0ooHY0?of:@04o`0000GomRL000Co0000ooHW0?of9`3omRL01?l00006ooLU0004o`000?og903o
mb@0ooLT00Co00001Oog8P001?l0003on200ooPP0?oh8005o`0000Gon1d000Co0000ooTL0?oi703o
nA`01?l00005ooPO00;o00001Oo_A0001_l0003okd<0onm30?o_@`3o0000olRk00;o00001oooool1
o`00007ooooo0Oooool003oooooo00?o0000ooooooooool04Oooool00ol0003olSD0o`000002o`00
00Komb8000Co0000ooLR0?og8P3omb801?l00005ooLS0003o`000?og9@3o000000;o00000_og9@00
0ol0003omRH0ooHV0003ooHV00Co00001?of9`000ol0003omRP0ooHX0003ooHX00;o00001_of:@00
1?l0003omBX0ooDZ0?oe:P04o`0000KomBX000?o0000ooD[0?l000000_l00002ooDZ0003o`000?oe
:`3omB/000?omB/000?o0000ooD[0?l000000_l00002ooDZ0003o`000?oe:P3omBX000?omBX01?l0
0003ooHY0003o`000?of:@3omRT000ComRT01?l00003ooHX0003o`000?of9`3omRL000?omRL01?l0
0003ooHV0003o`000?og9@3ombD000CombD01?l00003ooLS0003o`000?og8P3omb8000?omb801?l0
0003ooPO0003o`000?oh7@3on1d000Con1d01?l00003ooTK0004o`000?oh7`3on1l0ooPO00;o0000
0_oh7P001Ol0003okd@0onm40?o_A03o000000Cokd<01?l00007ooooo`7o00000Oooool1ooooo`00
@?ooool2o`0001;ooooo00Co0000oo8e0?ob=@3olSD00_l00003ooLR00Go00001?og8P001?l0003o
mb<0ooLS0?og8`03o`0000KombD000?o0000ooHV0?l000000_l00003ooHV0003o`000?of9`3omRL0
00?omRL000?o0000ooHX0?l000000_l00002ooHX0003o`000?of:@3omRT000?omRT01?l00004ooDZ
0004o`000?oe:P3omBX0ooDZ00Co00001_oe:P001?l0003omB/0ooD[0?oe:`03o`0000KomBX000?o
0000ooDZ0?l000000_l00002ooDZ0003o`000?of:@3omRT000?omRT000?o0000ooHY0?of:@000ol0
00000oof:03o0000ooHX0005ooHX0003o`000?of9`3o000000;o00000_of9`000ol0003omRH0ooHV
0003ooHV0003o`000?og9@3ombD000?o000000?omb@0o`000?og8`001Oog8`000ol0003omb80o`00
0002o`0000;on24000?o0000ooPO0?oh7`000ooh7`000ol0003on1d0ooPM0003o`000003ooTL0?l0
003onA/000GonA/000?o0000ooPO0?l000001Ooh7P000ol0003okd@0o`000004onm30006o`000?o^
B03okTP0o`000?oooooo00001_ooool1o`00007ooooo0Oooool004;ooooo00?o0000ooooooooool0
4?ooool8o`0000?omb<000?o0000ooLR0?og8P000oog8P04o`0000?omb@000?o0000ooLU0?og9@00
0oog9@02o`0000OomRH000Co0000ooHW0?of9`3omRL01?l00005ooHX0003o`000?of:@3o000000;o
00000_of:@000ol0003omBX0ooDZ0003ooDZ00Co00000ooe:P000ol0003omBX0ooDZ0004ooDZ00Co
00000ooe:P000ol0003omBX0ooDZ0003ooDZ00;o00001_oe:P001?l0003omRT0ooHY0?of:@04o`00
00GomRP000Co0000ooHX0?of:03omRP01?l00006ooHW0004o`000?of9P3omRH0ooHV00Co00001Oog
90001?l0003omb<0ooLS0?og8`04o`0000Kon24000Co0000ooPO0?oh7`3on1l01?l00005ooTL0004
o`000?oi6`3onA/0ooTK00Co00001_oh7P02o`0000Cokd<000Go0000oni80?o^B03okTP0o`000002
ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oooooooooo
017ooooo00Go0000oo8f0?ob=P3olSH0o`000005ooLS0003o`000?og8P3o000000;o00000_og8P00
0ol0003omb@0ooLT0003ooLT0003o`000?og9@3o000000;o00000_og9@000ol0003omRH0ooHV0004
ooHV00Co00001?of9`001?l0003omRP0ooHX0?of:003o`0000KomRT000?o0000ooDZ0?l000000_l0
0002ooHY0003o`000?oe:P3omBX000?omBX000?o0000ooDZ0?oe:P000ol000000ooe:P3o0000ooDZ
0005ooDZ0003o`000?oe:P3o000000;o00000_oe:P000ol0003omBX0ooDZ0003ooDZ00Co00000oof
:@000ol0003omRP0ooHX0003ooHX00Co00000oof9`000ol0003omRL0ooHW0004ooHW00Co00000oog
9@000ol0003omb@0ooLT0003ooLT00Co00000oog8P000ol0003on240ooPQ0004ooPQ00Co00000ooh
7P000ol0003onA`0ooTL0003ooTL00Co00000ooi6@000ol0003on1h0ooPN0002ooPN00;o000000?o
nA`0o`000?o_@`000_o_@`001Ol0003okTP0oni80?o^B03o000000?ooooo00?o0000ooooooooool0
1?ooool1o`00007ooooo0014ooooo`03o`000?oooooooooo017ooooo1Ol00003ooLS00?o00001_og
8P001?l0003omb@0ooLT0?og9004o`0000GombD000?o0000ooHV0?of9P000ol00002ooHV0003o`00
0?of9`3omRL000?omRL01?l00003ooHX0003o`000?of:@3omRT000?omRT00_l00006ooHY0004o`00
0?oe:P3omBX0ooDZ00Co00001Ooe:P001?l0003omBX0ooDZ0?oe:P05o`0000GomBX000?o0000ooDZ
0?l000000_l00002ooHY0003o`000?of:@3omRT000?omRT000?o0000ooHX0?l000000_l00002ooHX
0003o`000?of9`3omRL000?omRL000?o0000ooHW0?of9`000ol000000oof9P3o0000ooLU0005ooLU
0003o`000?og903o000000;o00000_og8`000ol0003omb80ooLR0003ooLR0003o`000?oh8@3on240
00?o000000?on1l0o`000?oh7P001Ooh7P000ol0003onA`0o`000002o`000003ooTJ0?l0003onAT0
00GonAT000Co0000ooPN0?l0003o00001?oi70000ol0003okd<0o`000003oni80003o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool1o`00007ooooo0015ooooo`;o00004_ooool00ol0
003olSH0oo8f0004o`0000?omb<000?o0000ooLR0?og8P000oog8P04o`0000Comb@000Co0000ooLU
0?og9@3ombD01?l00006ooHV0003o`000?of9`3o000000;o00000_of9`000ol0003omRP0ooHX0003
ooHX0003o`000?of:@3o000000;o00000_of:@000ol0003omRT0ooHY0003ooHY00Co00000oof:@00
0ol0003omBX0ooDZ0003ooDZ00Co00001Oof:@001?l0003omBX0ooDZ0?oe:P03o`0000KomRT000Co
0000ooHY0?of:@3omRT00ol00006ooHX0004o`000?of9`3omRL0ooHW00Co00001Oof9P001?l0003o
mbD0ooLU0?og9@04o`0000Komb<000Co0000ooLR0?og8P3omb801?l00005ooPO0004o`000?oh7P3o
n1h0ooPN00Co00001Ooi6P001?l0003onAT0ooTI0?oi6@04o`0000KonA`00_l00003oni80003o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool1o`00007ooooo0017ooooo`03o`000?oo
oooooooo013ooooo00Go0000oo8f0?ob=P3olSH0o`000005ooLS0003o`000?og8P3o000000;o0000
0_og8P000ol0003omb@0ooLT0003ooLT00Co00001?og9@000ol0003omRH0ooHV0003ooHV00;o0000
1_of9`001?l0003omRP0ooHX0?of:004o`0000GomRT000?o0000ooHY0?l000000_l00002ooHY0003
o`000?of:@3omRT000?omRT000?o0000ooDZ0?l000000_l00002ooHY0003o`000?of:@3omRT000Co
mRT01?l00002ooHY0003o`000?of:@3omRT000ComRT01?l00003ooHX0003o`000?of:03omRP000?o
mRP01?l00004ooHV0004o`000?of9P3omRH0ooHV00Go00001?og90001?l0003omb<0ooLS0?og8`06
o`0000Con20000Co0000ooPO0?oh7`3on1l01Ol00004ooTL0004o`000?oi6P3onAX0ooTJ00Go0000
1?oj60000ol0003onA`0ooTL0003o`0000;on24000?o0000oni80?l000002Oooool01Ol0003ooooo
oooooooooooo0000007ooooo0018ooooo`03o`000?oooooooooo013ooooo1Ol00003ooLS00?o0000
1_og8P000ol0003omb@0o`000002o`0000?omb@000?o0000ooLU0?og9@000oog9@000ol0003omRH0
o`000002o`0000;omRH000?o0000ooHW0?of9`000oof9`04o`0000ComRP000Co0000ooHY0?of:@3o
mRT00ol00006ooHY0004o`000?of:@3omRT0ooHY00Co00001Oof:@000ol0003omRT0ooHY0003o`00
0003ooHY0?l0003omRT000ComRT000?o0000ooHY0?of:@000ol000000oof:03o0000ooHX0005ooHX
0003o`000?of:03o000000;o00000_of9`000ol0003omRH0ooHV0003ooHV00Co00000oog9@000ol0
003omb@0ooLT0003ooLT00Co00000oog8P000ol0003on200ooPP0004ooPP00Co00000_oh7@000ol0
003onA`0ooTL0004ooTL00Co00000ooi6@000ol0003onQP0ooXH0003ooXH00?o00001Ooh8@02o`00
00[ooooo00Go0000ooooooooooooooooo`000001ooooo`00BOooool00ol0003oooooooooo`0Aoooo
o`03o`000?ob=P3o000000?o00000oog8`000ol0003omb80ooLR0003ooLR00?o00001_og90001?l0
003ombD0ooLU0?og9@04o`0000GomRH000?o0000ooHW0?l000000_l00002ooHW0003o`000?of:03o
mRP000?omRP01?l00003ooHX0003o`000?of:@3omRT000?omRT01?l00004ooHY0004o`000?of:@3o
mRT0ooHY00Co00001Oof:@001?l0003omRT0ooHY0?of:@04o`0000GomRP000Co0000ooHX0?of:03o
mRP01?l00006ooHW0003o`000?of9P3o000000;o000000?ombD0o`000?og9@001Oog9@000ol0003o
mb@0o`000002o`0000;omb8000?o0000ooLR0?og8P000oog8P000ol0003on200ooPP0003o`000003
ooPO0?l0003on1d000Con1d000?o0000ooTL0?oi70000ol000000ooi6`3o0000ooTI0005ooTI0003
o`000?oj603o000000;o000000?onA`0o`000?oh8@000ooh8@02o`0000gooooo00Co0000oooooooo
oooo00000Oooool004[ooooo00?o0000ooooooooool04Oooool01?l0003olSH0oo8f0?l00005ooLS
0003o`000?og8P3o000000;o00000oog8P000ol0003omb@0ooLT0003ooLT00Co00001?og9@001?l0
003omRH0ooHV0?of9P04o`0000GomRL000?o0000ooHX0?l000000_l00002ooHW0003o`000?of:03o
mRP000?omRP000?o0000ooHY0?l000000_l00002ooHX0003o`000?of:@3omRT000?omRT01?l00003
ooHY0003o`000?of:@3omRT000?omRT01?l00004ooHX0004o`000?of:03omRP0ooHX00Go00001?of
9`001?l0003omRL0ooHW0?of9`04o`0000GombD000Co0000ooLU0?og9@3ombD01?l00006ooLR0004
o`000?og8P3omb80ooLR00Co00001Ooh7`001?l0003on1d0ooPM0?oh7@04o`0000GonA/000Co0000
ooTI0?oi6@3onAT01?l00005ooTL0004o`000?oh8@3o0000o`00013ooooo00?o0000ooooool00000
0Oooool004_ooooo0_l0000Booooo`Co00000oog8`04o`0000Komb8000?o0000ooLT0?l000000_l0
0002ooLT0003o`000?og9@3ombD000?ombD01?l00004ooHV0004o`000?of9`3omRL0ooHW00?o0000
1_of9`001?l0003omRP0ooHX0?of:004o`0000GomRP000?o0000ooHY0?l000000_l00002ooHX0003
o`000?of:@3omRT000?omRT000?o0000ooHY0?l000000_l00002ooHX0003o`000?of:03omRP000?o
mRP01?l00003ooHW0003o`000?of9`3omRL000?omRL01?l00003ooHV0003o`000?og9@3ombD000?o
mbD01?l00003ooLS0003o`000?og8P3omb8000Comb801?l00002ooPP0003o`000?oh7`3on1l000Co
n1l01?l00003ooTL0003o`000?oi6`3onA/000?onA/01?l00004ooPN0004o`000?oi703onA`0ooTL
00?o00004_ooool00ol0003oooooooooo`01o`000000COooool00ol0003oooooooooo`0@ooooo`03
o`000?ob=P3o000000?o00001?og8`02o`0000?omb801?l00005ooLT0003o`000?og9@3o000000;o
00000_og9@000ol0003omRH0ooHV0003ooHV00Co00000oof9`000ol0003omRL0ooHW0003ooHW00Co
00001?of:0001?l0003omRP0ooHX0?of:003o`0000KomRP000Co0000ooHY0?of:@3omRT01?l00005
ooHX0003o`000?of:03o000000;o00000_of9`000ol0003omRL0ooHW0003ooHW0003o`000?of9`3o
000000;o00000_of9P000ol0003omRH0ooHV0003ooHV0003o`000?og9@3o000000;o00000_og9000
0ol0003omb<0ooLS0003ooLS0003o`000?og8P3omb8000?o000000?on240o`000?oh80001?oh8000
0ol0003on1l0ooPO0003o`000003ooPM0?l0003onA`000GonA`000?o0000ooTK0?l000000_l00002
ooPO0004o`000?oh7P3on1h0ooPN00Ko00005_ooool1o`00007ooooo0Ol0000004kooooo00?o0000
ooooooooool04?ooool01Ol0003olSH0oo8f0?ob=P3o000000Gomb<01?l00004ooLR0004o`000?og
903omb@0ooLT00?o00001_og9@000ol0003omRH0o`000002o`0000;omRD000?o0000ooHW0?of9`00
0oof9`000ol0003omRL0o`000002o`0000;omRL000?o0000ooHX0?of:0000oof:004o`0000?omRP0
00?o0000ooHX0?of:0000oof:004o`0000ComRP000Co0000ooHX0?of:03omRP00ol00006ooHW0004
o`000?of9`3omRL0ooHW00?o00001_of9P001?l0003omRH0ooHV0?of9P04o`0000Gomb@000Co0000
ooLS0?og8`3omb<01?l00005ooPQ0004o`000?oh803on200ooPP00Co00001Ooh7@001?l0003onA`0
ooTL0?oi7004o`0000Gon1l01?l0000Mooooo`;o0000001?ooooo`03o`000?oooooooooo013ooooo
1Ol000001?og8`3o0000o`000?l00002ooLS0003o`000?og8P3omb8000?omb801?l00003ooLS0003
o`000?og9@3ombD000?ombD00_l00006ooHU0004o`000?of9`3omRL0ooHW00Co00001Oof9`000ol0
003omRP0o`000002o`0000;omRL000?o0000ooHX0?of:0000oof:0000ol0003omRP0o`000002o`00
00;omRL000?o0000ooHX0?of:0000oof:004o`0000?omRL000?o0000ooHW0?of9`000oof9`04o`00
00?omRH000?o0000ooHV0?of9P000oof9P04o`0000Comb@000Co0000ooLT0?og903omb@01Ol00004
ooLR0004o`000?oh8@3on240ooPQ00Go00001?oh7`001?l0003on1d0ooPM0?oh7@05o`0000Con240
00?o0000ooPO0?l000000_l0000Pooooo`?o0000001@ooooo`;o00004_ooool00ol0003olSH0o`00
0002o`0000Gomb<000?o0000ooLR0?l000000_l00002ooLR0003o`000?og8`3omb<000?omb<000?o
0000ooLU0?l000000_l00002ooLT0003o`000?of9@3omRD000?omRD01?l00004ooHV0004o`000?of
9`3omRL0ooHW00?o00001_of9`001?l0003omRP0ooHX0?of:003o`0000KomRL000?o0000ooHX0?l0
00000_l000000oof9`3o0000ooHW0005ooHW0003o`000?of9`3o000000;o000000?omRH0o`000?of
9P001Oof9P000ol0003omRH0o`000002o`000003ooLU0?l0003omb@000Gomb@01?l00002ooLR0003
o`000?og8P3omb8000Comb801?l00002ooPP0003o`000?oh7`3on1l000Con1l01?l00003ooLR0004
o`000?oh8@3on240ooPQ00Co00007oooool4o`0000?ooooo001Booooo`03o`000?oooooooooo013o
oooo1Ol00003ooLS00?o00001_og8P001?l0003omb<0ooLS0?og8`04o`0000Gomb@000?o0000ooHU
0?l000000_l00002ooLU0003o`000?of9P3omRH000?omRH01?l00003ooHV0003o`000?of9`3omRL0
00?omRL01?l00003ooHW0004o`000?of9`3omRL0ooHW00Co00001Oof9`001?l0003omRL0ooHW0?of
9`04o`0000GomRH000Co0000ooHV0?of9P3omRH01?l00005ooLU0003o`000?og903omb@000?o0000
00?omb<0o`000?og8P001?og8P000ol0003omb80ooLR0003o`000003ooPQ0?l0003on20000Con200
00?o0000ooPO0?oh7`000ol00002ooLS0004o`000?og8P3omb80ooLR00Go00007oooool4o`0000Oo
oooo001Cooooo`03o`000?oooooooooo013ooooo00?o0000oo8e0?ob=@001?l00003ooLS0003o`00
0?og8P3omb8000?omb801?l00004ooLS0004o`000?og903omb@0ooLT00Co00001Oog9@000ol0003o
mRH0o`000002o`000003ooLU0?l0003omRH000GomRH000?o0000ooHW0?l000000_l000000oof9P3o
0000ooHW0004ooHW00Co00000oof9P000ol0003omRL0ooHW0003ooHW00Co00001?of9P001?l0003o
mRH0ooHV0?of9P05o`0000CombD000Co0000ooLU0?og9@3ombD01?l00005ooLS0004o`000?og8P3o
mb80ooLR00Co00001Ooh8@001?l0003on200ooPP0?oh8004o`0000Gomb<01?l0000Qooooo`?o0000
2oooool005Cooooo00?o0000ooooooooool04?ooool01Ol0003olSD0oo8e0?ob=@3o000000Gomb<0
00?o0000ooLR0?l000000_l00002ooLQ0003o`000?og8`3omb<000?omb<01?l00004ooLT0004o`00
0?og9@3ombD0ooLU00?o00001Oog9@001?l0003omRH0ooHV0?of9P04o`0000GomRH000?o0000ooHW
0?l000000_l00002ooHV0003o`000?of9P3omRH000?omRH000?o0000ooHW0?l000000_l00002ooHV
0003o`000?of9P3omRH000?omRH01?l00003ooLU0003o`000?og9@3ombD000?ombD01?l00003ooLS
0003o`000?og8`3omb<000?omb<01?l00003ooPQ0003o`000?oh8@3on24000?on2401?l00004ooLT
0003o`000?og8`3o000000;o00008Oooool4o`0000kooooo001Eooooo`03o`000?oooooooooo013o
oooo1Ol00003ooLS00Co00001Oog8@000ol0003omb<0o`000002o`0000;omb8000?o0000ooLT0?og
90000oog9004o`0000;omb@000?o0000ooLU0?og9@000oog9@04o`0000CombD000Co0000ooHV0?of
9P3omRH00ol00006ooHV0004o`000?of9P3omRH0ooHV00Co00001Oof9P000ol0003omRH0o`000002
o`0000;ombD000?o0000ooLU0?og9@000oog9@000ol0003ombD0o`000002o`0000;omb<000?o0000
ooLS0?og8`000oog8`000ol0003omb<0o`000002o`0000;omb8000?o0000ooPQ0?oh8@000ooh8@00
0ol0003on240o`000002o`0000;ombD000Co0000ooLT0?og903omb@01?l0000Pooooo`Co00004_oo
ool005Kooooo0_l0000Aooooo`03o`000?ob=@3olSD000Co00001?og8P001?l0003omb40ooLQ0?og
8@04o`0000Gomb8000?o0000ooLT0?l000000_l000000oog8`3o0000ooLT0004ooLT0003o`000?og
9@3o000000;o00000_og90000ol0003ombD0ooLU0003ooLU00Co00000oog9@000ol0003omRH0ooHV
0003ooHV00Co00001?og9@001?l0003omRH0ooHV0?of9P03o`0000KombD000Co0000ooLU0?og9@3o
mbD00ol00006ooLS0004o`000?og8`3omb<0ooLS00?o00001_og8P001?l0003on240ooPQ0?oh8@03
o`0000GombD01?l0000Pooooo`Co00005_ooool005Sooooo00?o0000ooooooooool03oooool01Ol0
003olSD0oo8e0?ob=@3o000000Gomb801?l00004ooPQ0004o`000?og8P3omb80ooLR00?o00001Oog
8`001?l0003omb@0ooLT0?og9004o`0000Gomb@000?o0000ooLU0?l000000_l00002ooLT0003o`00
0?og9@3ombD000?ombD000?o0000ooHV0?l000000_l00002ooLU0003o`000?og9@3ombD000?ombD0
1?l00003ooLT0003o`000?og9@3ombD000?ombD01?l00003ooLS0004o`000?og8`3omb<0ooLS00Ko
00000oog8P001?l0003omb80ooLR0?og8P06o`0000?omRD000?o0000ooLU0?l000000_l0000Poooo
o`Co00006_ooool005Wooooo00?o0000ooooooooool03oooool5o`000004ooLR0?l0003o0000o`00
00;omb8000?o0000ooPQ0?oh8@000ooh8@04o`0000?omb8000?o0000ooLS0?og8`000_og8`04o`00
00Comb<000Co0000ooLT0?og903omb@01?l00005ooLT0004o`000?og9@3ombD0ooLU00Co00001Oog
9@000ol0003ombD0o`000002o`0000;omb@000?o0000ooLT0?og90000oog90000ol0003ombD0o`00
0002o`000003ooLS0?l0003omb<000Comb<01?l00003ooLR0003o`000?og8P3omb8000?omb801?l0
0004ooHV0004o`000?of9@3omRD0ooHU00?o00007oooool4o`0001kooooo001Jooooo`03o`000?oo
oooooooo013ooooo00?o0000oo<d0?l000000_l00005ooLR0003o`000?oh8@3o000000;o00000_oh
80000ol0003omb80ooLR0003ooLR0004o`000?og8`3o0000o`0000;omb8000?o0000ooLS0?og8`00
0oog8`04o`0000Comb<000Co0000ooLT0?og903omb@01Ol00004ooLT0004o`000?og9@3ombD0ooLU
00Co00001Oog90001?l0003omb@0ooLT0?og9003o`0000Gomb<000?o0000ooLS0?l000000_l00002
ooLR0003o`000?og8P3omb8000?omb8000?o0000ooLR0?l000000_l00003ooHV0004o`000?of9P3o
mRH0ooHV00Go00007_ooool4o`0002;ooooo001Kooooo`;o00004Oooool5o`0000?omb800ol00006
ooPP0004o`000?og8P3omb80ooLR00?o00001Oog8P000ol0003omb<0o`000002o`0000;omb8000?o
0000ooLS0?og8`000oog8`04o`0000?omb<000?o0000ooLT0?og90000oog9004o`0000Comb<000Co
0000ooLT0?og903omb@01Ol00003ooLS0004o`000?og8`3omb<0ooLS00Co00001Oog8P001?l0003o
mb80ooLR0?og8P04o`0000GomRH01?l0000Pooooo`?o00009_ooool005gooooo00?o0000oooooooo
ool03oooool00ol0003olc<0oo<c0004o`0000?on24000?o0000ooPP0?oh80000ooh8004o`0000?o
n24000Co0000ooLR0?og8P3omb801?l00005ooLR0003o`000?og8`3o000000;o00000_og8P000ol0
003omb<0ooLS0003ooLS0003o`000?og903o000000;o000000?omb<0o`000?og8`001Oog8`04o`00
00;omb<000?o0000ooLS0?og8`000oog8`04o`0000Comb8000Co0000ooLR0?og8P3omb801Ol00004
ooHV0003o`000?of9P3o000000;o00008?ooool4o`0002Wooooo001Nooooo`03o`000?oooooooooo
00oooooo00Go0000oo<c0?oc<`3olc<0o`000005ooPQ0003o`000?oh803o000000;o00000_oh7`00
0ol0003on240ooPQ0002ooPQ00Co00001?oh8@001?l0003omb80ooLR0?og8P03o`0000Komb8000Co
0000ooLS0?og8`3omb<01?l00004ooLS0003o`000?og8`3omb<000?o000000?omb80o`000?og8`00
1?og8`000ol0003omb<0o`000002o`0000;omb8000?o0000ooLR0?og8P000oog8P04o`0000?omRH0
00Co0000ooHV0?of9P3omRH01?l0000Oooooo`Co0000;Oooool005oooooo00?o0000ooooooooool0
3oooool5o`0000?on2401?l00005ooPO0004o`000?oh8@3o0000o`0000;on1l000?o0000ooPQ0?oh
8@000ooh8@04o`0000?on24000?o0000ooLR0?og8P000oog8P04o`0000Comb8000?o0000ooLS0?og
8`001?l00005ooLR0004o`000?og8`3omb<0ooLS00Co00001Oog8P000ol0003omb80o`000002o`00
00;omRH000Co0000ooHV0?of9P3omRH01Ol0000Oooooo`Co0000<Oooool0063ooooo0_l0000Aoooo
o`03o`000?oc<`3o000000?o00001?oh80001?l0003on1l0ooPO0?oh7`03o`0000Gon1l000?o0000
ooPQ0?l000000_l00002ooPO0003o`000?oh8@3on24000?on24000?o0000ooLR0?l000000_l00002
ooPQ0003o`000?og8P3omb8000?omb800ol00004ooPQ0004o`000?og8P3omb80ooLR00Go00001?oh
8@001?l0003omb80ooLR0?og8P03o`0000GomRH01?l0000Pooooo`Co0000=Oooool006;ooooo00?o
0000ooooooooool03oooool5o`0000?on2001Ol00003ooPN0004o`000?oh7`3on1l0ooPO00Co0000
1Ooh7`001?l0003on240ooPQ0?oh8@04o`0000Gon24000?o0000ooLR0?l000000_l000000ooh803o
0000ooPQ0004ooPQ00Co00000ooh8@000ol0003on240ooPQ0003ooPQ00Co00000oof9P000ol0003o
mRH0o`000002o`00023ooooo1?l0000iooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03o`00
0?oc<P3olc8000Co00000ooh7`000ol0003on1h0ooPN0002ooPN00Co00001?oh7P001?l0003on1l0
ooPO0?oh7`05o`0000Con1l000Co0000ooPQ0?oh8@3on2400ol00005ooPP0003o`000?oh8@3o0000
00;o00000_oh80000ol0003on240ooPQ0003ooPQ0003o`000?oh8@3o000000;o00000_of9P001?l0
003omRH0ooHV0?of9P03o`0001oooooo1?l0000mooooo`00I?ooool00ol0003oooooooooo`0?oooo
o`05o`000?oc<P3olc80oo<b0?l000001Ooh7`001?l0003on1h0o`000?l00002ooTL0003o`000?oh
7P3on1h000?on1h01?l00003ooPN0003o`000?oh7`3on1l000?on1l01?l00003ooPO0004o`000?oh
803on200ooPP00Co00001Ooh80001?l0003on240ooPQ0?oh8@04o`0000?omRH01Ol0000Oooooo`?o
0000@Oooool006Gooooo00?o0000ooooooooool03oooool5o`0000?on1l00ol00005ooTL0003o`00
0?oh7P3o000000;o00000_oi7@000ol0003on1h0ooPN0003ooPN0003o`000?oh7`3o000000;o0000
00?on1h0o`000?oh7`001?oh7`04o`0000Con1l000Co0000ooPP0?oh803on2001Ol00003ooLU00Co
00008?ooool4o`0004Cooooo001Vooooo`;o00004Oooool00ol0003om340o`000003o`0000?on1d0
00Co0000ooTL0?oi703onA`01?l00005ooTM0004o`000?oh7P3on1h0ooPN00?o00001Ooh7P000ol0
003on1l0o`000002o`0000;on1h000?o0000ooPO0?oh7`000ooh7`04o`0000?omb@000?o0000ooLU
0?l000000_l0000Pooooo`Co0000B?ooool006Sooooo00?o0000ooooooooool03oooool5o`0000;o
n1d01Ol00004ooTK0004o`000?oi7@3onAd0ooTM00Go00000ooi7@001?l0003on1h0ooPN0?oh7P04
o`0000Gon1h000?o0000ooPO0?l000000_l00002ooLT0004o`000?og903omb@0ooLT00?o00007ooo
ool4o`0004cooooo001Yooooo`03o`000?oooooooooo00oooooo00?o0000oo@_0?od;`000ol00003
ooTL0003o`000?oi6`3onA/000?onA/01?l00004ooTK0003o`000?oi7@3onAd000Go00001?oi7@00
1?l0003on1h0ooPN0?oh7P04o`0000Comb@01?l0000Nooooo`Co0000D?ooool006[ooooo00?o0000
ooooooooool03oooool01Ol0003om2l0oo@_0?od;`3o000000ConA`000?o0000ooTK0?l000000_l0
0002ooTI0003o`000?oi6`3onA/000?onA/00ol00003ooTK0003o`000?oi7@3onAd000?onAd01?l0
0004ooLS0004o`000?og903o0000o`0001kooooo1?l0001Dooooo`00Joooool2o`00013ooooo1Ol0
0002ooTL00Co00001Ooi6@000ol0003onA/0o`000002o`000003ooTJ0?l0003onA/000ConA/000?o
0000ooTM0?l000000_l00003ooPQ0004o`000?og8`3omb<0ooLS00?o00007?ooool4o`0005Sooooo
001]ooooo`03o`000?oooooooooo00oooooo00?o0000oo@^0?l000000_l00004ooTJ0004o`000?oi
6@3onAT0ooTI00Co00001?oi6P001?l0003onA/0ooTK0?oi6`05o`0000?on2401Ol0000Looooo`?o
0000G?ooool006kooooo00?o0000ooooooooool03oooool4o`0000?onAX01Ol00004ooXH0003o`00
0?oi6P3onAX000Go00001?oh8004o`0001gooooo1?l0001Oooooo`00Koooool00ol0003ooooooooo
o`0?ooooo`03o`000?od;@3o000000?o00000ooj6@000ol0003onQP0ooXH0003ooXH00?o00001?oh
7P000ol0003on200o`000002o`0001gooooo1?l0001Sooooo`00L?ooool00ol0003oooooooooo`0?
ooooo`04o`000?od;@3om2d0o`0000GonQT000?o0000ooXH0?l000000_l00002ooTM0004o`000?oh
7P3on1h0ooPN00?o00007?ooool4o`0006Oooooo001aooooo`;o00003_ooool00ol0003oooooo`00
0003o`0000?onQT01Ol00002ooTM00Go00006oooool4o`0006_ooooo001cooooo`03o`000?oooooo
oooo00_ooooo00Co0000oooooooooooooooo1Ol00003ooPM00Co00007?ooool4o`0006oooooo001d
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool4o`0001cooooo1?l0001c
ooooo`00MOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo0ol0001goooo
o`00M_ooool2o`0000Wooooo00?o0000ooooooooool07_ooool4o`0007[ooooo001hooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06_ooool4o`0007kooooo001iooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05_ooool4o`0008;ooooo001jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool4o`0008Kooooo001kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03_ooool4o`0008[ooooo001looooo`;o00000oooool00ol0003o
ooooooooo`0:ooooo`Co0000S_ooool007kooooo00Co0000oooooooooooo00002Oooool3o`0009;o
oooo001oooooo`03o`000?oooooo000000Gooooo1?l0002Eooooo`00P?ooool2o`000003ooooool0
003o000000;o0000VOooool0087ooooo0_l0002Mooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00d_ooool3o`0004_ooooo003Cooooo`03o`000?oooooooooo04[ooooo001Qoooo
o`03o`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol00008oooo
o`?o00000oooool3o`0000Cooooo0ol00002ooooo`?o000000?oooooo`000?l000000_ooool2o`00
00Sooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000?ooooo0ol00002
ooooo`?o000000?oooooo`000?l000001?l00002ooooo`Go00000oooool2o`0000Cooooo00?o0000
ooooooooool0BOooool0067ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04o`000?ooooooooooo`0000Go
oooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool0BOooool0067ooooo00?o0000ooooool000000oooool3o`0000?ooooo00?o0000oooo
ool000000_ooool5o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001:ooooo`00
H?ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000Sooooo0ol00003ooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooo
ool0003oooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000004[ooooo001Pooooo`05o`000?oooooo0000ooooool000000_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000002ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`;o
000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l00002ooooo`Co00002_ooool01?l0003o
ooooooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000?ooooo1?l000001?oo
oooo0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o000004Wooooo001Poooo
o`05o`000?oooooo0000ooooool000006_ooool01?l0003oooooooooool0000Dooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo053ooooo001Pooooo`Ko00006?ooool5o`0001Cooooo00?o0000ooooooooool02?ooool5
o`0000Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo053ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0956244, 0.0487702, \
0.00365233, 0.00365233}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.13865 .20246 -11.9543 -9 ]
[.13865 .20246 .04573 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.54594 .04229 -5.19627 -9 ]
[.54594 .04229 .80373 0 ]
[.7636 .09113 0 -6.16761 ]
[.7636 .09113 12 2.83239 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93774 .35781 0 -5.91554 ]
[.93774 .35781 6 3.08446 ]
[.02412 .26509 -6 -2.7423 ]
[.02412 .26509 0 6.2577 ]
[.01324 .33326 -6 -2.79997 ]
[.01324 .33326 0 6.20003 ]
[.00187 .40451 -6 -2.86051 ]
[.00187 .40451 0 6.13949 ]
[-0.01002 .47906 -6 -2.92415 ]
[-0.01002 .47906 0 6.07585 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.14789 .21178 m
.15252 .21643 L
s
[(-5)] .13865 .20246 .99238 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.5537 .05288 m
.55757 .05817 L
s
[(5)] .54594 .04229 .73209 1 Mshowa
.125 Mabswid
.18577 .19694 m
.18851 .19978 L
s
.22422 .18189 m
.22691 .18476 L
s
.26324 .16661 m
.2659 .16952 L
s
.30285 .1511 m
.30546 .15404 L
s
.3839 .11937 m
.38642 .12239 L
s
.42536 .10313 m
.42784 .10619 L
s
.46747 .08664 m
.4699 .08974 L
s
.51024 .06989 m
.51262 .07303 L
s
.11057 .22639 m
.11338 .22915 L
s
.07378 .2408 m
.07662 .24352 L
s
.03752 .255 m
.0404 .25768 L
s
.59784 .03559 m
.60011 .03881 L
s
.64269 .01803 m
.64491 .02128 L
s
.68828 .00018 m
.69043 .00347 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75129 .09569 m
.74514 .09797 L
s
[(-5)] .7636 .09113 -1 .37058 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92522 .36174 m
.91896 .36371 L
s
[(5)] .93774 .35781 -1 .31456 Mshowa
.125 Mabswid
.7709 .12568 m
.7672 .12703 L
s
.78996 .15483 m
.78625 .15616 L
s
.80849 .18319 m
.80478 .18449 L
s
.82652 .21077 m
.8228 .21206 L
s
.86116 .26375 m
.85743 .265 L
s
.8778 .28921 m
.87406 .29044 L
s
.89402 .31401 m
.89027 .31522 L
s
.90982 .33818 m
.90607 .33938 L
s
.73112 .06483 m
.72743 .06622 L
s
.71035 .03306 m
.70667 .03447 L
s
.68895 .00033 m
.68529 .00177 L
s
.94025 .38473 m
.93649 .38589 L
s
.9549 .40714 m
.95114 .40829 L
s
.96921 .42902 m
.96544 .43016 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26032 m
.04245 .25793 L
s
[(0)] .02412 .26509 1 -0.3906 Mshowa
.02552 .32862 m
.03165 .3263 L
s
[(1)] .01324 .33326 1 -0.37779 Mshowa
.0142 .40002 m
.02037 .39777 L
s
[(2)] .00187 .40451 1 -0.36433 Mshowa
.00236 .47472 m
.00855 .47256 L
s
[(3)] -0.01002 .47906 1 -0.35019 Mshowa
.125 Mabswid
.03421 .27374 m
.03788 .27232 L
s
.03207 .28728 m
.03574 .28587 L
s
.0299 .30094 m
.03358 .29953 L
s
.02772 .31472 m
.0314 .31332 L
s
.02329 .34265 m
.02698 .34126 L
s
.02105 .3568 m
.02474 .35542 L
s
.01879 .37107 m
.02248 .36971 L
s
.0165 .38548 m
.0202 .38412 L
s
.01188 .41469 m
.01558 .41335 L
s
.00953 .42949 m
.01324 .42816 L
s
.00716 .44443 m
.01087 .44311 L
s
.00477 .45951 m
.00849 .4582 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.846 .563 0 r
.38877 .76543 .39977 .75676 .41652 .7694 .40574 .77437 Metetra
.9 .389 0 r
.40574 .77437 .41652 .7694 .43365 .77755 .42307 .77901 Metetra
.937 .254 0 r
.42307 .77901 .43365 .77755 .4511 .78186 .4407 .78001 Metetra
.961 .164 0 r
.4407 .78001 .4511 .78186 .46881 .78294 .45855 .77801 Metetra
.973 .115 0 r
.45855 .77801 .46881 .78294 .48671 .78138 .47658 .77361 Metetra
.976 .102 0 r
.47658 .77361 .48671 .78138 .50478 .77773 .49475 .76737 Metetra
.972 .116 0 r
.49475 .76737 .50478 .77773 .52298 .7725 .51303 .7598 Metetra
.964 .149 0 r
.51303 .7598 .52298 .7725 .5413 .76614 .5314 .75136 Metetra
.953 .194 0 r
.5314 .75136 .5413 .76614 .55971 .75905 .54986 .74246 Metetra
.941 .242 0 r
.54986 .74246 .55971 .75905 .57822 .75159 .5684 .73344 Metetra
.928 .291 0 r
.5684 .73344 .57822 .75159 .59682 .74407 .58703 .72461 Metetra
.916 .335 0 r
.58703 .72461 .59682 .74407 .61553 .73673 .60575 .71621 Metetra
.905 .371 0 r
.60575 .71621 .61553 .73673 .63435 .72976 .62458 .70843 Metetra
.898 .398 0 r
.62458 .70843 .63435 .72976 .65331 .72333 .64354 .70143 Metetra
.893 .415 0 r
.64354 .70143 .65331 .72333 .6724 .71754 .66264 .6953 Metetra
.891 .42 0 r
.66264 .6953 .6724 .71754 .69165 .71242 .68191 .69009 Metetra
.893 .415 0 r
.68191 .69009 .69165 .71242 .71106 .708 .70136 .68582 Metetra
.898 .398 0 r
.70136 .68582 .71106 .708 .73066 .70422 .721 .68244 Metetra
.905 .371 0 r
.721 .68244 .73066 .70422 .75045 .70098 .74085 .67985 Metetra
.916 .335 0 r
.74085 .67985 .75045 .70098 .77043 .69815 .76092 .67793 Metetra
.928 .291 0 r
.76092 .67793 .77043 .69815 .79059 .69552 .7812 .67646 Metetra
.941 .242 0 r
.7812 .67646 .79059 .69552 .81091 .69284 .80169 .67522 Metetra
.953 .194 0 r
.80169 .67522 .81091 .69284 .83139 .6898 .82236 .67388 Metetra
.964 .149 0 r
.82236 .67388 .83139 .6898 .85196 .68602 .84319 .67209 Metetra
.972 .116 0 r
.84319 .67209 .85196 .68602 .87259 .68108 .86413 .66942 Metetra
.976 .102 0 r
.86413 .66942 .87259 .68108 .8932 .67448 .88511 .66538 Metetra
.973 .115 0 r
.88511 .66538 .8932 .67448 .9137 .66568 .90605 .65943 Metetra
.961 .164 0 r
.90605 .65943 .9137 .66568 .93399 .65408 .92685 .65095 Metetra
.937 .254 0 r
.92685 .65095 .93399 .65408 .95392 .63902 .94739 .63927 Metetra
.9 .389 0 r
.94739 .63927 .95392 .63902 .97335 .61981 .9675 .62368 Metetra
.846 .563 0 r
.9675 .62368 .97335 .61981 .99211 .59575 .98702 .60345 Metetra
.9 .389 0 r
.37773 .76959 .38877 .76543 .40574 .77437 .39491 .77501 Metetra
.94 .246 0 r
.39491 .77501 .40574 .77437 .42307 .77901 .41243 .77631 Metetra
.963 .153 0 r
.41243 .77631 .42307 .77901 .4407 .78001 .43023 .77418 Metetra
.974 .108 0 r
.43023 .77418 .4407 .78001 .45855 .77801 .44822 .76929 Metetra
.975 .105 0 r
.44822 .76929 .45855 .77801 .47658 .77361 .46637 .76223 Metetra
.968 .133 0 r
.46637 .76223 .47658 .77361 .49475 .76737 .48464 .75357 Metetra
.956 .184 0 r
.48464 .75357 .49475 .76737 .51303 .7598 .50299 .74384 Metetra
.939 .247 0 r
.50299 .74384 .51303 .7598 .5314 .75136 .52142 .73348 Metetra
.921 .315 0 r
.52142 .73348 .5314 .75136 .54986 .74246 .53992 .7229 Metetra
.902 .382 0 r
.53992 .7229 .54986 .74246 .5684 .73344 .55849 .71244 Metetra
.884 .443 0 r
.55849 .71244 .5684 .73344 .58703 .72461 .57713 .7024 Metetra
.868 .496 0 r
.57713 .7024 .58703 .72461 .60575 .71621 .59586 .69301 Metetra
.855 .538 0 r
.59586 .69301 .60575 .71621 .62458 .70843 .61469 .68448 Metetra
.845 .569 0 r
.61469 .68448 .62458 .70843 .64354 .70143 .63365 .67694 Metetra
.838 .587 0 r
.63365 .67694 .64354 .70143 .66264 .6953 .65275 .6705 Metetra
.836 .594 0 r
.65275 .6705 .66264 .6953 .68191 .69009 .67202 .6652 Metetra
.838 .587 0 r
.67202 .6652 .68191 .69009 .70136 .68582 .69148 .66105 Metetra
.845 .569 0 r
.69148 .66105 .70136 .68582 .721 .68244 .71115 .65802 Metetra
.855 .538 0 r
.71115 .65802 .721 .68244 .74085 .67985 .73105 .65601 Metetra
.868 .496 0 r
.73105 .65601 .74085 .67985 .76092 .67793 .75118 .65489 Metetra
.884 .443 0 r
.75118 .65489 .76092 .67793 .7812 .67646 .77155 .65448 Metetra
.902 .382 0 r
.77155 .65448 .7812 .67646 .80169 .67522 .79216 .65453 Metetra
.921 .315 0 r
.79216 .65453 .80169 .67522 .82236 .67388 .813 .65474 Metetra
.939 .247 0 r
.813 .65474 .82236 .67388 .84319 .67209 .83404 .65477 Metetra
.956 .184 0 r
.83404 .65477 .84319 .67209 .86413 .66942 .85523 .65419 Metetra
.968 .133 0 r
.85523 .65419 .86413 .66942 .88511 .66538 .87654 .65251 Metetra
.975 .105 0 r
.87654 .65251 .88511 .66538 .90605 .65943 .89786 .64919 Metetra
.974 .108 0 r
.89786 .64919 .90605 .65943 .92685 .65095 .91912 .64362 Metetra
.963 .153 0 r
.91912 .64362 .92685 .65095 .94739 .63927 .94019 .63511 Metetra
.94 .246 0 r
.94019 .63511 .94739 .63927 .9675 .62368 .96092 .62294 Metetra
.9 .389 0 r
.96092 .62294 .9675 .62368 .98702 .60345 .98114 .60634 Metetra
.937 .254 0 r
.36664 .76985 .37773 .76959 .39491 .77501 .38403 .77195 Metetra
.963 .153 0 r
.38403 .77195 .39491 .77501 .41243 .77631 .40175 .77012 Metetra
.975 .106 0 r
.40175 .77012 .41243 .77631 .43023 .77418 .4197 .76508 Metetra
.974 .108 0 r
.4197 .76508 .43023 .77418 .44822 .76929 .43784 .75748 Metetra
.965 .147 0 r
.43784 .75748 .44822 .76929 .46637 .76223 .4561 .74796 Metetra
.949 .211 0 r
.4561 .74796 .46637 .76223 .48464 .75357 .47446 .73708 Metetra
.928 .291 0 r
.47446 .73708 .48464 .75357 .50299 .74384 .49289 .72535 Metetra
.904 .376 0 r
.49289 .72535 .50299 .74384 .52142 .73348 .51138 .71322 Metetra
.879 .46 0 r
.51138 .71322 .52142 .73348 .53992 .7229 .52991 .7011 Metetra
.855 .538 0 r
.52991 .7011 .53992 .7229 .55849 .71244 .5485 .68932 Metetra
.832 .606 0 r
.5485 .68932 .55849 .71244 .57713 .7024 .56715 .67817 Metetra
.812 .662 0 r
.56715 .67817 .57713 .7024 .59586 .69301 .58588 .66789 Metetra
.795 .705 0 r
.58588 .66789 .59586 .69301 .61469 .68448 .60471 .65866 Metetra
.783 .736 0 r
.60471 .65866 .61469 .68448 .63365 .67694 .62366 .65063 Metetra
.776 .754 0 r
.62366 .65063 .63365 .67694 .65275 .6705 .64276 .64389 Metetra
.773 .76 0 r
.64276 .64389 .65275 .6705 .67202 .6652 .66202 .63849 Metetra
.776 .754 0 r
.66202 .63849 .67202 .6652 .69148 .66105 .68149 .63444 Metetra
.783 .736 0 r
.68149 .63444 .69148 .66105 .71115 .65802 .70117 .63171 Metetra
.795 .705 0 r
.70117 .63171 .71115 .65802 .73105 .65601 .72108 .6302 Metetra
.812 .662 0 r
.72108 .6302 .73105 .65601 .75118 .65489 .74126 .6298 Metetra
.832 .606 0 r
.74126 .6298 .75118 .65489 .77155 .65448 .7617 .63032 Metetra
.855 .538 0 r
.7617 .63032 .77155 .65448 .79216 .65453 .78241 .63154 Metetra
.879 .46 0 r
.78241 .63154 .79216 .65453 .813 .65474 .80337 .63315 Metetra
.904 .376 0 r
.80337 .63315 .813 .65474 .83404 .65477 .82458 .63482 Metetra
.928 .291 0 r
.82458 .63482 .83404 .65477 .85523 .65419 .846 .63613 Metetra
.949 .211 0 r
.846 .63613 .85523 .65419 .87654 .65251 .86758 .63661 Metetra
.965 .147 0 r
.86758 .63661 .87654 .65251 .89786 .64919 .88924 .63571 Metetra
.974 .108 0 r
.88924 .63571 .89786 .64919 .91912 .64362 .9109 .63281 Metetra
.975 .106 0 r
.9109 .63281 .91912 .64362 .94019 .63511 .93244 .62724 Metetra
.963 .153 0 r
.93244 .62724 .94019 .63511 .96092 .62294 .95372 .61825 Metetra
.937 .254 0 r
.95372 .61825 .96092 .62294 .98114 .60634 .97458 .60506 Metetra
.961 .164 0 r
.35552 .76681 .36664 .76985 .38403 .77195 .37312 .76581 Metetra
.974 .108 0 r
.37312 .76581 .38403 .77195 .40175 .77012 .39102 .76108 Metetra
.974 .108 0 r
.39102 .76108 .40175 .77012 .4197 .76508 .40913 .75334 Metetra
.964 .152 0 r
.40913 .75334 .4197 .76508 .43784 .75748 .42741 .74326 Metetra
.945 .226 0 r
.42741 .74326 .43784 .75748 .4561 .74796 .44579 .73147 Metetra
.92 .32 0 r
.44579 .73147 .4561 .74796 .47446 .73708 .46424 .71855 Metetra
.891 .42 0 r
.46424 .71855 .47446 .73708 .49289 .72535 .48274 .705 Metetra
.861 .52 0 r
.48274 .705 .49289 .72535 .51138 .71322 .50128 .69126 Metetra
.83 .612 0 r
.50128 .69126 .51138 .71322 .52991 .7011 .51985 .67774 Metetra
.8 .693 0 r
.51985 .67774 .52991 .7011 .5485 .68932 .53846 .66475 Metetra
.773 .76 0 r
.53846 .66475 .5485 .68932 .56715 .67817 .55713 .6526 Metetra
.685 .749 0 r
.55713 .6526 .56715 .67817 .58588 .66789 .57586 .64149 Metetra
.607 .73 0 r
.57586 .64149 .58588 .66789 .60471 .65866 .59468 .63163 Metetra
.551 .716 0 r
.59468 .63163 .60471 .65866 .62366 .65063 .61362 .62314 Metetra
.517 .707 0 r
.61362 .62314 .62366 .65063 .64276 .64389 .6327 .61613 Metetra
.506 .704 0 r
.6327 .61613 .64276 .64389 .66202 .63849 .65196 .61063 Metetra
.517 .707 0 r
.65196 .61063 .66202 .63849 .68149 .63444 .67141 .60666 Metetra
.551 .716 0 r
.67141 .60666 .68149 .63444 .70117 .63171 .69109 .60418 Metetra
.607 .73 0 r
.69109 .60418 .70117 .63171 .72108 .6302 .71102 .60311 Metetra
.685 .749 0 r
.71102 .60311 .72108 .6302 .74126 .6298 .73122 .60334 Metetra
.773 .76 0 r
.73122 .60334 .74126 .6298 .7617 .63032 .75171 .60469 Metetra
.8 .693 0 r
.75171 .60469 .7617 .63032 .78241 .63154 .77249 .60693 Metetra
.83 .612 0 r
.77249 .60693 .78241 .63154 .80337 .63315 .79356 .60979 Metetra
.861 .52 0 r
.79356 .60979 .80337 .63315 .82458 .63482 .81491 .61293 Metetra
.891 .42 0 r
.81491 .61293 .82458 .63482 .846 .63613 .83651 .61594 Metetra
.92 .32 0 r
.83651 .61594 .846 .63613 .86758 .63661 .85831 .61837 Metetra
.945 .226 0 r
.85831 .61837 .86758 .63661 .88924 .63571 .88026 .61966 Metetra
.964 .152 0 r
.88026 .61966 .88924 .63571 .9109 .63281 .90227 .61921 Metetra
.974 .108 0 r
.90227 .61921 .9109 .63281 .93244 .62724 .92423 .61633 Metetra
.974 .108 0 r
.92423 .61633 .93244 .62724 .95372 .61825 .94601 .61028 Metetra
.961 .164 0 r
.94601 .61028 .95372 .61825 .97458 .60506 .96743 .60025 Metetra
.973 .115 0 r
.34435 .76105 .35552 .76681 .37312 .76581 .36216 .75719 Metetra
.975 .105 0 r
.36216 .75719 .37312 .76581 .39102 .76108 .38024 .74979 Metetra
.965 .147 0 r
.38024 .74979 .39102 .76108 .40913 .75334 .39852 .73957 Metetra
.945 .226 0 r
.39852 .73957 .40913 .75334 .42741 .74326 .41692 .72723 Metetra
.917 .329 0 r
.41692 .72723 .42741 .74326 .44579 .73147 .43542 .71338 Metetra
.884 .443 0 r
.43542 .71338 .44579 .73147 .46424 .71855 .45396 .69861 Metetra
.849 .556 0 r
.45396 .69861 .46424 .71855 .48274 .705 .47254 .6834 Metetra
.812 .662 0 r
.47254 .6834 .48274 .705 .50128 .69126 .49113 .66821 Metetra
.776 .754 0 r
.49113 .66821 .50128 .69126 .51985 .67774 .50975 .65341 Metetra
.651 .741 0 r
.50975 .65341 .51985 .67774 .53846 .66475 .52838 .63935 Metetra
.528 .71 0 r
.52838 .63935 .53846 .66475 .55713 .6526 .54706 .62628 Metetra
.429 .683 0 r
.54706 .62628 .55713 .6526 .57586 .64149 .5658 .61444 Metetra
.353 .662 0 r
.5658 .61444 .57586 .64149 .59468 .63163 .58461 .604 Metetra
.3 .646 0 r
.58461 .604 .59468 .63163 .61362 .62314 .60354 .59509 Metetra
.268 .636 0 r
.60354 .59509 .61362 .62314 .6327 .61613 .62261 .58782 Metetra
.258 .632 0 r
.62261 .58782 .6327 .61613 .65196 .61063 .64185 .58221 Metetra
.268 .636 0 r
.64185 .58221 .65196 .61063 .67141 .60666 .66129 .5783 Metetra
.3 .646 0 r
.66129 .5783 .67141 .60666 .69109 .60418 .68096 .57603 Metetra
.353 .662 0 r
.68096 .57603 .69109 .60418 .71102 .60311 .7009 .57535 Metetra
.429 .683 0 r
.7009 .57535 .71102 .60311 .73122 .60334 .72111 .57612 Metetra
.528 .71 0 r
.72111 .57612 .73122 .60334 .75171 .60469 .74163 .57819 Metetra
.651 .741 0 r
.74163 .57819 .75171 .60469 .77249 .60693 .76246 .58134 Metetra
.776 .754 0 r
.76246 .58134 .77249 .60693 .79356 .60979 .78361 .5853 Metetra
.812 .662 0 r
.78361 .5853 .79356 .60979 .81491 .61293 .80507 .58974 Metetra
.849 .556 0 r
.80507 .58974 .81491 .61293 .83651 .61594 .82682 .59427 Metetra
.884 .443 0 r
.82682 .59427 .83651 .61594 .85831 .61837 .84882 .59844 Metetra
.917 .329 0 r
.84882 .59844 .85831 .61837 .88026 .61966 .87102 .6017 Metetra
.945 .226 0 r
.87102 .6017 .88026 .61966 .90227 .61921 .89333 .60346 Metetra
.965 .147 0 r
.89333 .60346 .90227 .61921 .92423 .61633 .91566 .60302 Metetra
.975 .105 0 r
.91566 .60302 .92423 .61633 .94601 .61028 .93787 .59965 Metetra
.973 .115 0 r
.93787 .59965 .94601 .61028 .96743 .60025 .9598 .59251 Metetra
.976 .102 0 r
.33314 .75312 .34435 .76105 .36216 .75719 .35115 .74664 Metetra
.968 .133 0 r
.35115 .74664 .36216 .75719 .38024 .74979 .36941 .73681 Metetra
.949 .211 0 r
.36941 .73681 .38024 .74979 .39852 .73957 .38784 .72434 Metetra
.92 .32 0 r
.38784 .72434 .39852 .73957 .41692 .72723 .40639 .70995 Metetra
.884 .443 0 r
.40639 .70995 .41692 .72723 .43542 .71338 .425 .69425 Metetra
.845 .569 0 r
.425 .69425 .43542 .71338 .45396 .69861 .44364 .6778 Metetra
.803 .687 0 r
.44364 .6778 .45396 .69861 .47254 .6834 .46229 .66111 Metetra
.73 .76 0 r
.46229 .66111 .47254 .6834 .49113 .66821 .48095 .64461 Metetra
.562 .719 0 r
.48095 .64461 .49113 .66821 .50975 .65341 .4996 .62868 Metetra
.418 .68 0 r
.4996 .62868 .50975 .65341 .52838 .63935 .51827 .61364 Metetra
.3 .646 0 r
.51827 .61364 .52838 .63935 .54706 .62628 .53696 .59976 Metetra
.206 .616 0 r
.53696 .59976 .54706 .62628 .5658 .61444 .55571 .58725 Metetra
.137 .592 0 r
.55571 .58725 .5658 .61444 .58461 .604 .57452 .57629 Metetra
.089 .574 0 r
.57452 .57629 .58461 .604 .60354 .59509 .59344 .56701 Metetra
.061 .563 0 r
.59344 .56701 .60354 .59509 .62261 .58782 .6125 .55949 Metetra
.052 .56 0 r
.6125 .55949 .62261 .58782 .64185 .58221 .63172 .55378 Metetra
.061 .563 0 r
.63172 .55378 .64185 .58221 .66129 .5783 .65115 .5499 Metetra
.089 .574 0 r
.65115 .5499 .66129 .5783 .68096 .57603 .67081 .54781 Metetra
.137 .592 0 r
.67081 .54781 .68096 .57603 .7009 .57535 .69074 .54744 Metetra
.206 .616 0 r
.69074 .54744 .7009 .57535 .72111 .57612 .71096 .54868 Metetra
.3 .646 0 r
.71096 .54868 .72111 .57612 .74163 .57819 .7315 .55137 Metetra
.418 .68 0 r
.7315 .55137 .74163 .57819 .76246 .58134 .75237 .55531 Metetra
.562 .719 0 r
.75237 .55531 .76246 .58134 .78361 .5853 .77358 .56023 Metetra
.73 .76 0 r
.77358 .56023 .78361 .5853 .80507 .58974 .79513 .56582 Metetra
.803 .687 0 r
.79513 .56582 .80507 .58974 .82682 .59427 .81701 .57169 Metetra
.845 .569 0 r
.81701 .57169 .82682 .59427 .84882 .59844 .83917 .5774 Metetra
.884 .443 0 r
.83917 .5774 .84882 .59844 .87102 .6017 .86157 .58241 Metetra
.92 .32 0 r
.86157 .58241 .87102 .6017 .89333 .60346 .88414 .58614 Metetra
.949 .211 0 r
.88414 .58614 .89333 .60346 .91566 .60302 .90679 .5879 Metetra
.968 .133 0 r
.90679 .5879 .91566 .60302 .93787 .59965 .92939 .58693 Metetra
.976 .102 0 r
.92939 .58693 .93787 .59965 .9598 .59251 .95177 .58242 Metetra
.972 .116 0 r
.32188 .7435 .33314 .75312 .35115 .74664 .34008 .73467 Metetra
.956 .184 0 r
.34008 .73467 .35115 .74664 .36941 .73681 .35852 .72264 Metetra
.928 .291 0 r
.35852 .72264 .36941 .73681 .38784 .72434 .37711 .70816 Metetra
.891 .42 0 r
.37711 .70816 .38784 .72434 .40639 .70995 .39579 .69193 Metetra
.849 .556 0 r
.39579 .69193 .40639 .70995 .425 .69425 .41452 .67456 Metetra
.803 .687 0 r
.41452 .67456 .425 .69425 .44364 .6778 .43326 .65663 Metetra
.708 .755 0 r
.43326 .65663 .44364 .6778 .46229 .66111 .45199 .63861 Metetra
.517 .707 0 r
.45199 .63861 .46229 .66111 .48095 .64461 .47071 .62095 Metetra
.353 .662 0 r
.47071 .62095 .48095 .64461 .4996 .62868 .48942 .60401 Metetra
.216 .619 0 r
.48942 .60401 .4996 .62868 .51827 .61364 .50812 .58811 Metetra
.108 .581 0 r
.50812 .58811 .51827 .61364 .53696 .59976 .52684 .5735 Metetra
.024 .549 0 r
.52684 .5735 .53696 .59976 .55571 .58725 .54559 .56039 Metetra
0 .523 .036 r
.54559 .56039 .55571 .58725 .57452 .57629 .56441 .54897 Metetra
0 .504 .076 r
.56441 .54897 .57452 .57629 .59344 .56701 .58333 .53934 Metetra
0 .492 .099 r
.58333 .53934 .59344 .56701 .6125 .55949 .60238 .5316 Metetra
0 .488 .107 r
.60238 .5316 .6125 .55949 .63172 .55378 .62159 .52579 Metetra
0 .492 .099 r
.62159 .52579 .63172 .55378 .65115 .5499 .641 .52192 Metetra
0 .504 .076 r
.641 .52192 .65115 .5499 .67081 .54781 .66066 .51997 Metetra
0 .523 .036 r
.66066 .51997 .67081 .54781 .69074 .54744 .68058 .51987 Metetra
.024 .549 0 r
.68058 .51987 .69074 .54744 .71096 .54868 .7008 .52151 Metetra
.108 .581 0 r
.7008 .52151 .71096 .54868 .7315 .55137 .72135 .52473 Metetra
.216 .619 0 r
.72135 .52473 .7315 .55137 .75237 .55531 .74225 .52935 Metetra
.353 .662 0 r
.74225 .52935 .75237 .55531 .77358 .56023 .76351 .5351 Metetra
.517 .707 0 r
.76351 .5351 .77358 .56023 .79513 .56582 .78513 .54168 Metetra
.708 .755 0 r
.78513 .54168 .79513 .56582 .81701 .57169 .8071 .54871 Metetra
.803 .687 0 r
.8071 .54871 .81701 .57169 .83917 .5774 .8294 .55577 Metetra
.849 .556 0 r
.8294 .55577 .83917 .5774 .86157 .58241 .85198 .56232 Metetra
.891 .42 0 r
.85198 .56232 .86157 .58241 .88414 .58614 .87478 .56779 Metetra
.928 .291 0 r
.87478 .56779 .88414 .58614 .90679 .5879 .8977 .57149 Metetra
.956 .184 0 r
.8977 .57149 .90679 .5879 .92939 .58693 .92063 .57267 Metetra
.972 .116 0 r
.92063 .57267 .92939 .58693 .95177 .58242 .94342 .57051 Metetra
.964 .149 0 r
.31054 .73265 .32188 .7435 .34008 .73467 .32893 .72171 Metetra
.939 .247 0 r
.32893 .72171 .34008 .73467 .35852 .72264 .34755 .70774 Metetra
.904 .376 0 r
.34755 .70774 .35852 .72264 .37711 .70816 .36629 .69147 Metetra
.861 .52 0 r
.36629 .69147 .37711 .70816 .39579 .69193 .38512 .67361 Metetra
.812 .662 0 r
.38512 .67361 .39579 .69193 .41452 .67456 .40396 .65477 Metetra
.73 .76 0 r
.40396 .65477 .41452 .67456 .43326 .65663 .42281 .63552 Metetra
.517 .707 0 r
.42281 .63552 .43326 .65663 .45199 .63861 .44163 .61634 Metetra
.331 .655 0 r
.44163 .61634 .45199 .63861 .47071 .62095 .46042 .59765 Metetra
.176 .606 0 r
.46042 .59765 .47071 .62095 .48942 .60401 .47918 .57982 Metetra
.052 .56 0 r
.47918 .57982 .48942 .60401 .50812 .58811 .49793 .56315 Metetra
0 .519 .044 r
.49793 .56315 .50812 .58811 .52684 .5735 .51668 .5479 Metetra
0 .484 .114 r
.51668 .5479 .52684 .5735 .54559 .56039 .53545 .53427 Metetra
0 .456 .163 r
.53545 .53427 .54559 .56039 .56441 .54897 .55428 .52242 Metetra
0 .436 .194 r
.55428 .52242 .56441 .54897 .58333 .53934 .5732 .51249 Metetra
0 .423 .211 r
.5732 .51249 .58333 .53934 .60238 .5316 .59225 .50454 Metetra
0 .419 .217 r
.59225 .50454 .60238 .5316 .62159 .52579 .61146 .49863 Metetra
0 .423 .211 r
.61146 .49863 .62159 .52579 .641 .52192 .63086 .49477 Metetra
0 .436 .194 r
.63086 .49477 .641 .52192 .66066 .51997 .6505 .49292 Metetra
0 .456 .163 r
.6505 .49292 .66066 .51997 .68058 .51987 .67042 .49304 Metetra
0 .484 .114 r
.67042 .49304 .68058 .51987 .7008 .52151 .69064 .495 Metetra
0 .519 .044 r
.69064 .495 .7008 .52151 .72135 .52473 .7112 .49868 Metetra
.052 .56 0 r
.7112 .49868 .72135 .52473 .74225 .52935 .73212 .50386 Metetra
.176 .606 0 r
.73212 .50386 .74225 .52935 .76351 .5351 .75342 .51032 Metetra
.331 .655 0 r
.75342 .51032 .76351 .5351 .78513 .54168 .7751 .51775 Metetra
.517 .707 0 r
.7751 .51775 .78513 .54168 .8071 .54871 .79715 .52579 Metetra
.73 .76 0 r
.79715 .52579 .8071 .54871 .8294 .55577 .81957 .53401 Metetra
.812 .662 0 r
.81957 .53401 .8294 .55577 .85198 .56232 .8423 .5419 Metetra
.861 .52 0 r
.8423 .5419 .85198 .56232 .87478 .56779 .86528 .54888 Metetra
.904 .376 0 r
.86528 .54888 .87478 .56779 .8977 .57149 .88844 .55428 Metetra
.939 .247 0 r
.88844 .55428 .8977 .57149 .92063 .57267 .91167 .55735 Metetra
.964 .149 0 r
.91167 .55735 .92063 .57267 .94342 .57051 .93481 .55725 Metetra
.953 .194 0 r
.29911 .72098 .31054 .73265 .32893 .72171 .31769 .70819 Metetra
.921 .315 0 r
.31769 .70819 .32893 .72171 .34755 .70774 .33648 .6925 Metetra
.879 .46 0 r
.33648 .6925 .34755 .70774 .36629 .69147 .35539 .67467 Metetra
.83 .612 0 r
.35539 .67467 .36629 .69147 .38512 .67361 .37435 .65539 Metetra
.776 .754 0 r
.37435 .65539 .38512 .67361 .40396 .65477 .39332 .63527 Metetra
.562 .719 0 r
.39332 .63527 .40396 .65477 .42281 .63552 .41228 .61487 Metetra
.353 .662 0 r
.41228 .61487 .42281 .63552 .44163 .61634 .43119 .59467 Metetra
.176 .606 0 r
.43119 .59467 .44163 .61634 .46042 .59765 .45006 .57508 Metetra
.033 .552 0 r
.45006 .57508 .46042 .59765 .47918 .57982 .46889 .55647 Metetra
0 .504 .076 r
.46889 .55647 .47918 .57982 .49793 .56315 .48769 .53914 Metetra
0 .46 .156 r
.48769 .53914 .49793 .56315 .51668 .5479 .50647 .52332 Metetra
0 .423 .211 r
.50647 .52332 .51668 .5479 .53545 .53427 .52528 .50922 Metetra
0 .394 .247 r
.52528 .50922 .53545 .53427 .55428 .52242 .54413 .49701 Metetra
0 .372 .268 r
.54413 .49701 .55428 .52242 .5732 .51249 .56306 .48679 Metetra
0 .359 .279 r
.56306 .48679 .5732 .51249 .59225 .50454 .58211 .47866 Metetra
0 .355 .282 r
.58211 .47866 .59225 .50454 .61146 .49863 .60132 .47265 Metetra
0 .359 .279 r
.60132 .47265 .61146 .49863 .63086 .49477 .62072 .46877 Metetra
0 .372 .268 r
.62072 .46877 .63086 .49477 .6505 .49292 .64036 .467 Metetra
0 .394 .247 r
.64036 .467 .6505 .49292 .67042 .49304 .66028 .46729 Metetra
0 .423 .211 r
.66028 .46729 .67042 .49304 .69064 .495 .6805 .46952 Metetra
0 .46 .156 r
.6805 .46952 .69064 .495 .7112 .49868 .70107 .47356 Metetra
0 .504 .076 r
.70107 .47356 .7112 .49868 .73212 .50386 .72201 .47923 Metetra
.033 .552 0 r
.72201 .47923 .73212 .50386 .75342 .51032 .74333 .48628 Metetra
.176 .606 0 r
.74333 .48628 .75342 .51032 .7751 .51775 .76506 .49443 Metetra
.353 .662 0 r
.76506 .49443 .7751 .51775 .79715 .52579 .78719 .50332 Metetra
.562 .719 0 r
.78719 .50332 .79715 .52579 .81957 .53401 .80969 .51253 Metetra
.776 .754 0 r
.80969 .51253 .81957 .53401 .8423 .5419 .83255 .52156 Metetra
.83 .612 0 r
.83255 .52156 .8423 .5419 .86528 .54888 .8557 .52984 Metetra
.879 .46 0 r
.8557 .52984 .86528 .54888 .88844 .55428 .87907 .53669 Metetra
.921 .315 0 r
.87907 .53669 .88844 .55428 .91167 .55735 .90255 .54139 Metetra
.953 .194 0 r
.90255 .54139 .91167 .55735 .93481 .55725 .92599 .54308 Metetra
.941 .242 0 r
.28757 .70884 .29911 .72098 .31769 .70819 .30634 .69446 Metetra
.902 .382 0 r
.30634 .69446 .31769 .70819 .33648 .6925 .3253 .67729 Metetra
.855 .538 0 r
.3253 .67729 .33648 .6925 .35539 .67467 .34436 .65811 Metetra
.8 .693 0 r
.34436 .65811 .35539 .67467 .37435 .65539 .36347 .6376 Metetra
.651 .741 0 r
.36347 .6376 .37435 .65539 .39332 .63527 .38257 .61637 Metetra
.418 .68 0 r
.38257 .61637 .39332 .63527 .41228 .61487 .40164 .59498 Metetra
.216 .619 0 r
.40164 .59498 .41228 .61487 .43119 .59467 .42066 .57391 Metetra
.052 .56 0 r
.42066 .57391 .43119 .59467 .45006 .57508 .43961 .55355 Metetra
0 .504 .076 r
.43961 .55355 .45006 .57508 .46889 .55647 .45852 .53427 Metetra
0 .452 .169 r
.45852 .53427 .46889 .55647 .48769 .53914 .47738 .51635 Metetra
0 .407 .232 r
.47738 .51635 .48769 .53914 .50647 .52332 .49621 .50004 Metetra
0 .368 .272 r
.49621 .50004 .50647 .52332 .52528 .50922 .51506 .48554 Metetra
0 .337 .294 r
.51506 .48554 .52528 .50922 .54413 .49701 .53394 .473 Metetra
0 .315 .305 r
.53394 .473 .54413 .49701 .56306 .48679 .5529 .46254 Metetra
0 .292 .301 r
.5529 .46254 .56306 .48679 .58211 .47866 .57196 .45423 Metetra
0 .282 .297 r
.57196 .45423 .58211 .47866 .60132 .47265 .59118 .44812 Metetra
0 .292 .301 r
.59118 .44812 .60132 .47265 .62072 .46877 .61059 .44422 Metetra
0 .315 .305 r
.61059 .44422 .62072 .46877 .64036 .467 .63023 .44251 Metetra
0 .337 .294 r
.63023 .44251 .64036 .467 .66028 .46729 .65015 .44292 Metetra
0 .368 .272 r
.65015 .44292 .66028 .46729 .6805 .46952 .67038 .44536 Metetra
0 .407 .232 r
.67038 .44536 .6805 .46952 .70107 .47356 .69096 .4497 Metetra
0 .452 .169 r
.69096 .4497 .70107 .47356 .72201 .47923 .71191 .45576 Metetra
0 .504 .076 r
.71191 .45576 .72201 .47923 .74333 .48628 .73327 .4633 Metetra
.052 .56 0 r
.73327 .4633 .74333 .48628 .76506 .49443 .75504 .47203 Metetra
.216 .619 0 r
.75504 .47203 .76506 .49443 .78719 .50332 .77722 .48163 Metetra
.418 .68 0 r
.77722 .48163 .78719 .50332 .80969 .51253 .79981 .49166 Metetra
.651 .741 0 r
.79981 .49166 .80969 .51253 .83255 .52156 .82278 .50164 Metetra
.8 .693 0 r
.82278 .50164 .83255 .52156 .8557 .52984 .84607 .51101 Metetra
.855 .538 0 r
.84607 .51101 .8557 .52984 .87907 .53669 .86961 .51909 Metetra
.902 .382 0 r
.86961 .51909 .87907 .53669 .90255 .54139 .89331 .52516 Metetra
.941 .242 0 r
.89331 .52516 .90255 .54139 .92599 .54308 .91702 .52836 Metetra
.928 .291 0 r
.27591 .69653 .28757 .70884 .30634 .69446 .29486 .6808 Metetra
.884 .443 0 r
.29486 .6808 .30634 .69446 .3253 .67729 .31398 .66239 Metetra
.832 .606 0 r
.31398 .66239 .3253 .67729 .34436 .65811 .3332 .64207 Metetra
.773 .76 0 r
.3332 .64207 .34436 .65811 .36347 .6376 .35246 .62052 Metetra
.528 .71 0 r
.35246 .62052 .36347 .6376 .38257 .61637 .3717 .59837 Metetra
.3 .646 0 r
.3717 .59837 .38257 .61637 .40164 .59498 .39089 .57614 Metetra
.108 .581 0 r
.39089 .57614 .40164 .59498 .42066 .57391 .41001 .55432 Metetra
0 .519 .044 r
.41001 .55432 .42066 .57391 .43961 .55355 .42906 .53331 Metetra
0 .46 .156 r
.42906 .53331 .43961 .55355 .45852 .53427 .44805 .51346 Metetra
0 .407 .232 r
.44805 .51346 .45852 .53427 .47738 .51635 .46698 .49505 Metetra
0 .359 .279 r
.46698 .49505 .47738 .51635 .49621 .50004 .48588 .47832 Metetra
0 .319 .303 r
.48588 .47832 .49621 .50004 .51506 .48554 .50478 .46347 Metetra
0 .262 .287 r
.50478 .46347 .51506 .48554 .53394 .473 .5237 .45064 Metetra
0 .214 .264 r
.5237 .45064 .53394 .473 .5529 .46254 .54269 .43996 Metetra
0 .187 .25 r
.54269 .43996 .5529 .46254 .57196 .45423 .56178 .43149 Metetra
0 .179 .245 r
.56178 .43149 .57196 .45423 .59118 .44812 .58102 .42529 Metetra
0 .187 .25 r
.58102 .42529 .59118 .44812 .61059 .44422 .60044 .42135 Metetra
0 .214 .264 r
.60044 .42135 .61059 .44422 .63023 .44251 .6201 .41966 Metetra
0 .262 .287 r
.6201 .41966 .63023 .44251 .65015 .44292 .64003 .42017 Metetra
0 .319 .303 r
.64003 .42017 .65015 .44292 .67038 .44536 .66027 .42277 Metetra
0 .359 .279 r
.66027 .42277 .67038 .44536 .69096 .4497 .68087 .42734 Metetra
0 .407 .232 r
.68087 .42734 .69096 .4497 .71191 .45576 .70184 .4337 Metetra
0 .46 .156 r
.70184 .4337 .71191 .45576 .73327 .4633 .72322 .44162 Metetra
0 .519 .044 r
.72322 .44162 .73327 .4633 .75504 .47203 .74503 .45083 Metetra
.108 .581 0 r
.74503 .45083 .75504 .47203 .77722 .48163 .76727 .46099 Metetra
.3 .646 0 r
.76727 .46099 .77722 .48163 .79981 .49166 .78993 .47169 Metetra
.528 .71 0 r
.78993 .47169 .79981 .49166 .82278 .50164 .81299 .48245 Metetra
.773 .76 0 r
.81299 .48245 .82278 .50164 .84607 .51101 .83641 .4927 Metetra
.832 .606 0 r
.83641 .4927 .84607 .51101 .86961 .51909 .86011 .50179 Metetra
.884 .443 0 r
.86011 .50179 .86961 .51909 .89331 .52516 .88399 .50898 Metetra
.928 .291 0 r
.88399 .50898 .89331 .52516 .91702 .52836 .90794 .51343 Metetra
.916 .335 0 r
.2641 .68431 .27591 .69653 .29486 .6808 .28321 .66748 Metetra
.868 .496 0 r
.28321 .66748 .29486 .6808 .31398 .66239 .30251 .64806 Metetra
.812 .662 0 r
.30251 .64806 .31398 .66239 .3332 .64207 .32189 .6268 Metetra
.685 .749 0 r
.32189 .6268 .3332 .64207 .35246 .62052 .34129 .60441 Metetra
.429 .683 0 r
.34129 .60441 .35246 .62052 .3717 .59837 .36067 .58148 Metetra
.206 .616 0 r
.36067 .58148 .3717 .59837 .39089 .57614 .37999 .55857 Metetra
.024 .549 0 r
.37999 .55857 .39089 .57614 .41001 .55432 .39923 .53613 Metetra
0 .484 .114 r
.39923 .53613 .41001 .55432 .42906 .53331 .41839 .51458 Metetra
0 .423 .211 r
.41839 .51458 .42906 .53331 .44805 .51346 .43747 .49425 Metetra
0 .368 .272 r
.43747 .49425 .44805 .51346 .46698 .49505 .45648 .47543 Metetra
0 .319 .303 r
.45648 .47543 .46698 .49505 .48588 .47832 .47546 .45834 Metetra
0 .242 .278 r
.47546 .45834 .48588 .47832 .50478 .46347 .49442 .44319 Metetra
0 .179 .245 r
.49442 .44319 .50478 .46347 .5237 .45064 .5134 .43013 Metetra
0 .138 .221 r
.5134 .43013 .5237 .45064 .54269 .43996 .53243 .41925 Metetra
0 .116 .207 r
.53243 .41925 .54269 .43996 .56178 .43149 .55156 .41064 Metetra
0 .109 .202 r
.55156 .41064 .56178 .43149 .58102 .42529 .57083 .40434 Metetra
0 .116 .207 r
.57083 .40434 .58102 .42529 .60044 .42135 .59028 .40036 Metetra
0 .138 .221 r
.59028 .40036 .60044 .42135 .6201 .41966 .60996 .39867 Metetra
0 .179 .245 r
.60996 .39867 .6201 .41966 .64003 .42017 .62991 .39923 Metetra
0 .242 .278 r
.62991 .39923 .64003 .42017 .66027 .42277 .65018 .40195 Metetra
0 .319 .303 r
.65018 .40195 .66027 .42277 .68087 .42734 .67079 .40668 Metetra
0 .368 .272 r
.67079 .40668 .68087 .42734 .70184 .4337 .69179 .41327 Metetra
0 .423 .211 r
.69179 .41327 .70184 .4337 .72322 .44162 .7132 .42148 Metetra
0 .484 .114 r
.7132 .42148 .72322 .44162 .74503 .45083 .73505 .43106 Metetra
.024 .549 0 r
.73505 .43106 .74503 .45083 .76727 .46099 .75734 .44165 Metetra
.206 .616 0 r
.75734 .44165 .76727 .46099 .78993 .47169 .78007 .45287 Metetra
.429 .683 0 r
.78007 .45287 .78993 .47169 .81299 .48245 .80322 .46423 Metetra
.685 .749 0 r
.80322 .46423 .81299 .48245 .83641 .4927 .82674 .47517 Metetra
.812 .662 0 r
.82674 .47517 .83641 .4927 .86011 .50179 .85057 .48505 Metetra
.868 .496 0 r
.85057 .48505 .86011 .50179 .88399 .50898 .87462 .49312 Metetra
.916 .335 0 r
.87462 .49312 .88399 .50898 .90794 .51343 .89876 .49855 Metetra
.905 .371 0 r
.25211 .67238 .2641 .68431 .28321 .66748 .2714 .6547 Metetra
.855 .538 0 r
.2714 .6547 .28321 .66748 .30251 .64806 .29085 .63448 Metetra
.795 .705 0 r
.29085 .63448 .30251 .64806 .32189 .6268 .31039 .6125 Metetra
.607 .73 0 r
.31039 .6125 .32189 .6268 .34129 .60441 .32994 .58943 Metetra
.353 .662 0 r
.32994 .58943 .34129 .60441 .36067 .58148 .34946 .5659 Metetra
.137 .592 0 r
.34946 .5659 .36067 .58148 .37999 .55857 .36892 .54244 Metetra
0 .523 .036 r
.36892 .54244 .37999 .55857 .39923 .53613 .38828 .51952 Metetra
0 .456 .163 r
.38828 .51952 .39923 .53613 .41839 .51458 .40756 .49753 Metetra
0 .394 .247 r
.40756 .49753 .41839 .51458 .43747 .49425 .42675 .47681 Metetra
0 .337 .294 r
.42675 .47681 .43747 .49425 .45648 .47543 .44586 .45765 Metetra
0 .262 .287 r
.44586 .45765 .45648 .47543 .47546 .45834 .46492 .44028 Metetra
0 .179 .245 r
.46492 .44028 .47546 .45834 .49442 .44319 .48396 .42488 Metetra
0 .123 .211 r
.48396 .42488 .49442 .44319 .5134 .43013 .503 .4116 Metetra
0 .089 .187 r
.503 .4116 .5134 .43013 .53243 .41925 .5221 .40056 Metetra
0 .071 .172 r
.5221 .40056 .53243 .41925 .55156 .41064 .54128 .39182 Metetra
0 .065 .167 r
.54128 .39182 .55156 .41064 .57083 .40434 .56059 .38542 Metetra
0 .071 .172 r
.56059 .38542 .57083 .40434 .59028 .40036 .58009 .38139 Metetra
0 .089 .187 r
.58009 .38139 .59028 .40036 .60996 .39867 .5998 .37969 Metetra
0 .123 .211 r
.5998 .37969 .60996 .39867 .62991 .39923 .61978 .38027 Metetra
0 .179 .245 r
.61978 .38027 .62991 .39923 .65018 .40195 .64008 .38305 Metetra
0 .262 .287 r
.64008 .38305 .65018 .40195 .67079 .40668 .66072 .38789 Metetra
0 .337 .294 r
.66072 .38789 .67079 .40668 .69179 .41327 .68175 .39463 Metetra
0 .394 .247 r
.68175 .39463 .69179 .41327 .7132 .42148 .7032 .40304 Metetra
0 .456 .163 r
.7032 .40304 .7132 .42148 .73505 .43106 .72509 .41287 Metetra
0 .523 .036 r
.72509 .41287 .73505 .43106 .75734 .44165 .74743 .42378 Metetra
.137 .592 0 r
.74743 .42378 .75734 .44165 .78007 .45287 .77022 .43537 Metetra
.353 .662 0 r
.77022 .43537 .78007 .45287 .80322 .46423 .79345 .44717 Metetra
.607 .73 0 r
.79345 .44717 .80322 .46423 .82674 .47517 .81706 .45861 Metetra
.795 .705 0 r
.81706 .45861 .82674 .47517 .85057 .48505 .84101 .46907 Metetra
.855 .538 0 r
.84101 .46907 .85057 .48505 .87462 .49312 .86521 .47778 Metetra
.905 .371 0 r
.86521 .47778 .87462 .49312 .89876 .49855 .88952 .48393 Metetra
.898 .398 0 r
.23994 .66089 .25211 .67238 .2714 .6547 .25938 .6426 Metetra
.845 .569 0 r
.25938 .6426 .2714 .6547 .29085 .63448 .27899 .62181 Metetra
.783 .736 0 r
.27899 .62181 .29085 .63448 .31039 .6125 .29869 .5993 Metetra
.551 .716 0 r
.29869 .5993 .31039 .6125 .32994 .58943 .31839 .57574 Metetra
.3 .646 0 r
.31839 .57574 .32994 .58943 .34946 .5659 .33806 .55177 Metetra
.089 .574 0 r
.33806 .55177 .34946 .5659 .36892 .54244 .35766 .5279 Metetra
0 .504 .076 r
.35766 .5279 .36892 .54244 .38828 .51952 .37716 .5046 Metetra
0 .436 .194 r
.37716 .5046 .38828 .51952 .40756 .49753 .39656 .48228 Metetra
0 .372 .268 r
.39656 .48228 .40756 .49753 .42675 .47681 .41586 .46127 Metetra
0 .315 .305 r
.41586 .46127 .42675 .47681 .44586 .45765 .43508 .44184 Metetra
0 .214 .264 r
.43508 .44184 .44586 .45765 .46492 .44028 .45424 .42424 Metetra
0 .138 .221 r
.45424 .42424 .46492 .44028 .48396 .42488 .47337 .40864 Metetra
0 .089 .187 r
.47337 .40864 .48396 .42488 .503 .4116 .4925 .39519 Metetra
0 .06 .162 r
.4925 .39519 .503 .4116 .5221 .40056 .51166 .384 Metetra
0 .045 .147 r
.51166 .384 .5221 .40056 .54128 .39182 .53091 .37514 Metetra
0 .04 .142 r
.53091 .37514 .54128 .39182 .56059 .38542 .55029 .36866 Metetra
0 .045 .147 r
.55029 .36866 .56059 .38542 .58009 .38139 .56983 .36456 Metetra
0 .06 .162 r
.56983 .36456 .58009 .38139 .5998 .37969 .5896 .36282 Metetra
0 .089 .187 r
.5896 .36282 .5998 .37969 .61978 .38027 .60963 .3634 Metetra
0 .138 .221 r
.60963 .3634 .61978 .38027 .64008 .38305 .62996 .36619 Metetra
0 .214 .264 r
.62996 .36619 .64008 .38305 .66072 .38789 .65065 .37108 Metetra
0 .315 .305 r
.65065 .37108 .66072 .38789 .68175 .39463 .67172 .3779 Metetra
0 .372 .268 r
.67172 .3779 .68175 .39463 .7032 .40304 .69321 .38644 Metetra
0 .436 .194 r
.69321 .38644 .7032 .40304 .72509 .41287 .71515 .39642 Metetra
0 .504 .076 r
.71515 .39642 .72509 .41287 .74743 .42378 .73754 .40752 Metetra
.089 .574 0 r
.73754 .40752 .74743 .42378 .77022 .43537 .76039 .41934 Metetra
.3 .646 0 r
.76039 .41934 .77022 .43537 .79345 .44717 .78369 .43141 Metetra
.551 .716 0 r
.78369 .43141 .79345 .44717 .81706 .45861 .80739 .44318 Metetra
.783 .736 0 r
.80739 .44318 .81706 .45861 .84101 .46907 .83145 .454 Metetra
.845 .569 0 r
.83145 .454 .84101 .46907 .86521 .47778 .85576 .46313 Metetra
.898 .398 0 r
.85576 .46313 .86521 .47778 .88952 .48393 .88022 .46974 Metetra
.893 .415 0 r
.22756 .64994 .23994 .66089 .25938 .6426 .24714 .63129 Metetra
.838 .587 0 r
.24714 .63129 .25938 .6426 .27899 .62181 .2669 .61015 Metetra
.776 .754 0 r
.2669 .61015 .27899 .62181 .29869 .5993 .28675 .58731 Metetra
.517 .707 0 r
.28675 .58731 .29869 .5993 .31839 .57574 .30661 .56344 Metetra
.268 .636 0 r
.30661 .56344 .31839 .57574 .33806 .55177 .32643 .53917 Metetra
.061 .563 0 r
.32643 .53917 .33806 .55177 .35766 .5279 .34617 .51503 Metetra
0 .492 .099 r
.34617 .51503 .35766 .5279 .37716 .5046 .36582 .49148 Metetra
0 .423 .211 r
.36582 .49148 .37716 .5046 .39656 .48228 .38535 .46893 Metetra
0 .359 .279 r
.38535 .46893 .39656 .48228 .41586 .46127 .40478 .4477 Metetra
0 .292 .301 r
.40478 .4477 .41586 .46127 .43508 .44184 .42412 .42809 Metetra
0 .187 .25 r
.42412 .42809 .43508 .44184 .45424 .42424 .4434 .41031 Metetra
0 .116 .207 r
.4434 .41031 .45424 .42424 .47337 .40864 .46263 .39456 Metetra
0 .071 .172 r
.46263 .39456 .47337 .40864 .4925 .39519 .48185 .38097 Metetra
0 .045 .147 r
.48185 .38097 .4925 .39519 .51166 .384 .50111 .36966 Metetra
0 .031 .132 r
.50111 .36966 .51166 .384 .53091 .37514 .52044 .3607 Metetra
0 .027 .127 r
.52044 .3607 .53091 .37514 .55029 .36866 .53989 .35412 Metetra
0 .031 .132 r
.53989 .35412 .55029 .36866 .56983 .36456 .55951 .34995 Metetra
0 .045 .147 r
.55951 .34995 .56983 .36456 .5896 .36282 .57933 .34816 Metetra
0 .071 .172 r
.57933 .34816 .5896 .36282 .60963 .3634 .59942 .34869 Metetra
0 .116 .207 r
.59942 .34869 .60963 .3634 .62996 .36619 .61981 .35147 Metetra
0 .187 .25 r
.61981 .35147 .62996 .36619 .65065 .37108 .64054 .35635 Metetra
0 .292 .301 r
.64054 .35635 .65065 .37108 .67172 .3779 .66167 .36318 Metetra
0 .359 .279 r
.66167 .36318 .67172 .3779 .69321 .38644 .68321 .37175 Metetra
0 .423 .211 r
.68321 .37175 .69321 .38644 .71515 .39642 .7052 .38178 Metetra
0 .492 .099 r
.7052 .38178 .71515 .39642 .73754 .40752 .72765 .39296 Metetra
.061 .563 0 r
.72765 .39296 .73754 .40752 .76039 .41934 .75057 .40487 Metetra
.268 .636 0 r
.75057 .40487 .76039 .41934 .78369 .43141 .77393 .41707 Metetra
.517 .707 0 r
.77393 .41707 .78369 .43141 .80739 .44318 .79772 .42898 Metetra
.776 .754 0 r
.79772 .42898 .80739 .44318 .83145 .454 .82186 .43996 Metetra
.838 .587 0 r
.82186 .43996 .83145 .454 .85576 .46313 .84629 .44927 Metetra
.893 .415 0 r
.84629 .44927 .85576 .46313 .88022 .46974 .87087 .45608 Metetra
.891 .42 0 r
.21495 .6396 .22756 .64994 .24714 .63129 .23467 .62083 Metetra
.836 .594 0 r
.23467 .62083 .24714 .63129 .2669 .61015 .25457 .59956 Metetra
.773 .76 0 r
.25457 .59956 .2669 .61015 .28675 .58731 .27457 .57658 Metetra
.506 .704 0 r
.27457 .57658 .28675 .58731 .30661 .56344 .29458 .55257 Metetra
.258 .632 0 r
.29458 .55257 .30661 .56344 .32643 .53917 .31455 .52816 Metetra
.052 .56 0 r
.31455 .52816 .32643 .53917 .34617 .51503 .33445 .50389 Metetra
0 .488 .107 r
.33445 .50389 .34617 .51503 .36582 .49148 .35424 .48021 Metetra
0 .419 .217 r
.35424 .48021 .36582 .49148 .38535 .46893 .37392 .45752 Metetra
0 .355 .282 r
.37392 .45752 .38535 .46893 .40478 .4477 .39349 .43617 Metetra
0 .282 .297 r
.39349 .43617 .40478 .4477 .42412 .42809 .41296 .41644 Metetra
0 .179 .245 r
.41296 .41644 .42412 .42809 .4434 .41031 .43236 .39854 Metetra
0 .109 .202 r
.43236 .39854 .4434 .41031 .46263 .39456 .45171 .38268 Metetra
0 .065 .167 r
.45171 .38268 .46263 .39456 .48185 .38097 .47105 .36899 Metetra
0 .04 .142 r
.47105 .36899 .48185 .38097 .50111 .36966 .49041 .35758 Metetra
0 .027 .127 r
.49041 .35758 .50111 .36966 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .027 .127 r
.52938 .34187 .53989 .35412 .55951 .34995 .54908 .33761 Metetra
0 .04 .142 r
.54908 .33761 .55951 .34995 .57933 .34816 .56898 .33575 Metetra
0 .065 .167 r
.56898 .33575 .57933 .34816 .59942 .34869 .58914 .33621 Metetra
0 .109 .202 r
.58914 .33621 .59942 .34869 .61981 .35147 .6096 .33892 Metetra
0 .179 .245 r
.6096 .33892 .61981 .35147 .64054 .35635 .6304 .34374 Metetra
0 .282 .297 r
.6304 .34374 .64054 .35635 .66167 .36318 .65158 .35052 Metetra
0 .355 .282 r
.65158 .35052 .66167 .36318 .68321 .37175 .67319 .35904 Metetra
0 .419 .217 r
.67319 .35904 .68321 .37175 .7052 .38178 .69524 .36903 Metetra
0 .488 .107 r
.69524 .36903 .7052 .38178 .72765 .39296 .71776 .38016 Metetra
.052 .56 0 r
.71776 .38016 .72765 .39296 .75057 .40487 .74074 .39203 Metetra
.258 .632 0 r
.74074 .39203 .75057 .40487 .77393 .41707 .76417 .40419 Metetra
.506 .704 0 r
.76417 .40419 .77393 .41707 .79772 .42898 .78803 .41606 Metetra
.773 .76 0 r
.78803 .41606 .79772 .42898 .82186 .43996 .81226 .42699 Metetra
.836 .594 0 r
.81226 .42699 .82186 .43996 .84629 .44927 .83678 .43626 Metetra
.891 .42 0 r
.83678 .43626 .84629 .44927 .87087 .45608 .86146 .44301 Metetra
.893 .415 0 r
.20211 .62986 .21495 .6396 .23467 .62083 .22194 .61122 Metetra
.838 .587 0 r
.22194 .61122 .23467 .62083 .25457 .59956 .24197 .59004 Metetra
.776 .754 0 r
.24197 .59004 .25457 .59956 .27457 .57658 .26211 .56713 Metetra
.517 .707 0 r
.26211 .56713 .27457 .57658 .29458 .55257 .28228 .54316 Metetra
.268 .636 0 r
.28228 .54316 .29458 .55257 .31455 .52816 .3024 .51877 Metetra
.061 .563 0 r
.3024 .51877 .31455 .52816 .33445 .50389 .32245 .49449 Metetra
0 .492 .099 r
.32245 .49449 .33445 .50389 .35424 .48021 .3424 .4708 Metetra
0 .423 .211 r
.3424 .4708 .35424 .48021 .37392 .45752 .36223 .44808 Metetra
0 .359 .279 r
.36223 .44808 .37392 .45752 .39349 .43617 .38195 .42669 Metetra
0 .292 .301 r
.38195 .42669 .39349 .43617 .41296 .41644 .40157 .40691 Metetra
0 .187 .25 r
.40157 .40691 .41296 .41644 .43236 .39854 .42111 .38896 Metetra
0 .116 .207 r
.42111 .38896 .43236 .39854 .45171 .38268 .44059 .37303 Metetra
0 .071 .172 r
.44059 .37303 .45171 .38268 .47105 .36899 .46005 .35927 Metetra
0 .045 .147 r
.46005 .35927 .47105 .36899 .49041 .35758 .47953 .34778 Metetra
0 .031 .132 r
.47953 .34778 .49041 .35758 .50984 .34853 .49907 .33865 Metetra
0 .027 .127 r
.49907 .33865 .50984 .34853 .52938 .34187 .51872 .3319 Metetra
0 .031 .132 r
.51872 .3319 .52938 .34187 .54908 .33761 .53852 .32756 Metetra
0 .045 .147 r
.53852 .32756 .54908 .33761 .56898 .33575 .55851 .3256 Metetra
0 .071 .172 r
.55851 .3256 .56898 .33575 .58914 .33621 .57876 .32596 Metetra
0 .116 .207 r
.57876 .32596 .58914 .33621 .6096 .33892 .5993 .32856 Metetra
0 .187 .25 r
.5993 .32856 .6096 .33892 .6304 .34374 .62018 .33328 Metetra
0 .292 .301 r
.62018 .33328 .6304 .34374 .65158 .35052 .64145 .33993 Metetra
0 .359 .279 r
.64145 .33993 .65158 .35052 .67319 .35904 .66312 .34832 Metetra
0 .423 .211 r
.66312 .34832 .67319 .35904 .69524 .36903 .68525 .35816 Metetra
0 .492 .099 r
.68525 .35816 .69524 .36903 .71776 .38016 .70783 .36913 Metetra
.061 .563 0 r
.70783 .36913 .71776 .38016 .74074 .39203 .73088 .38083 Metetra
.268 .636 0 r
.73088 .38083 .74074 .39203 .76417 .40419 .75439 .39278 Metetra
.517 .707 0 r
.75439 .39278 .76417 .40419 .78803 .41606 .77832 .40443 Metetra
.776 .754 0 r
.77832 .40443 .78803 .41606 .81226 .42699 .80263 .41512 Metetra
.838 .587 0 r
.80263 .41512 .81226 .42699 .83678 .43626 .82723 .4241 Metetra
.893 .415 0 r
.82723 .4241 .83678 .43626 .86146 .44301 .852 .43054 Metetra
.898 .398 0 r
.18902 .62069 .20211 .62986 .22194 .61122 .20895 .60242 Metetra
.845 .569 0 r
.20895 .60242 .22194 .61122 .24197 .59004 .2291 .58157 Metetra
.783 .736 0 r
.2291 .58157 .24197 .59004 .26211 .56713 .24937 .55892 Metetra
.551 .716 0 r
.24937 .55892 .26211 .56713 .28228 .54316 .26968 .53517 Metetra
.3 .646 0 r
.26968 .53517 .28228 .54316 .3024 .51877 .28995 .51096 Metetra
.089 .574 0 r
.28995 .51096 .3024 .51877 .32245 .49449 .31016 .48682 Metetra
0 .504 .076 r
.31016 .48682 .32245 .49449 .3424 .4708 .33027 .46323 Metetra
0 .436 .194 r
.33027 .46323 .3424 .4708 .36223 .44808 .35026 .44059 Metetra
0 .372 .268 r
.35026 .44059 .36223 .44808 .38195 .42669 .37014 .41924 Metetra
0 .315 .305 r
.37014 .41924 .38195 .42669 .40157 .40691 .38991 .39948 Metetra
0 .214 .264 r
.38991 .39948 .40157 .40691 .42111 .38896 .4096 .38153 Metetra
0 .138 .221 r
.4096 .38153 .42111 .38896 .44059 .37303 .42923 .36558 Metetra
0 .089 .187 r
.42923 .36558 .44059 .37303 .46005 .35927 .44884 .35179 Metetra
0 .06 .162 r
.44884 .35179 .46005 .35927 .47953 .34778 .46845 .34025 Metetra
0 .045 .147 r
.46845 .34025 .47953 .34778 .49907 .33865 .48812 .33105 Metetra
0 .04 .142 r
.48812 .33105 .49907 .33865 .51872 .3319 .50789 .32422 Metetra
0 .045 .147 r
.50789 .32422 .51872 .3319 .53852 .32756 .5278 .31978 Metetra
0 .06 .162 r
.5278 .31978 .53852 .32756 .55851 .3256 .54791 .3177 Metetra
0 .089 .187 r
.54791 .3177 .55851 .3256 .57876 .32596 .56826 .31794 Metetra
0 .138 .221 r
.56826 .31794 .57876 .32596 .5993 .32856 .5889 .32039 Metetra
0 .214 .264 r
.5889 .32039 .5993 .32856 .62018 .33328 .60987 .32493 Metetra
0 .315 .305 r
.60987 .32493 .62018 .33328 .64145 .33993 .63123 .33139 Metetra
0 .372 .268 r
.63123 .33139 .64145 .33993 .66312 .34832 .65299 .33956 Metetra
0 .436 .194 r
.65299 .33956 .66312 .34832 .68525 .35816 .67519 .34915 Metetra
0 .504 .076 r
.67519 .34915 .68525 .35816 .70783 .36913 .69786 .35985 Metetra
.089 .574 0 r
.69786 .35985 .70783 .36913 .73088 .38083 .72098 .37123 Metetra
.3 .646 0 r
.72098 .37123 .73088 .38083 .75439 .39278 .74457 .38282 Metetra
.551 .716 0 r
.74457 .38282 .75439 .39278 .77832 .40443 .76857 .39406 Metetra
.783 .736 0 r
.76857 .39406 .77832 .40443 .80263 .41512 .79295 .40429 Metetra
.845 .569 0 r
.79295 .40429 .80263 .41512 .82723 .4241 .81762 .41276 Metetra
.898 .398 0 r
.81762 .41276 .82723 .4241 .852 .43054 .84246 .4186 Metetra
.905 .371 0 r
.17568 .61198 .18902 .62069 .20895 .60242 .19568 .59434 Metetra
.855 .538 0 r
.19568 .59434 .20895 .60242 .2291 .58157 .21593 .57404 Metetra
.795 .705 0 r
.21593 .57404 .2291 .58157 .24937 .55892 .23632 .55187 Metetra
.607 .73 0 r
.23632 .55187 .24937 .55892 .26968 .53517 .25677 .52853 Metetra
.353 .662 0 r
.25677 .52853 .26968 .53517 .28995 .51096 .27719 .50466 Metetra
.137 .592 0 r
.27719 .50466 .28995 .51096 .31016 .48682 .29756 .4808 Metetra
0 .523 .036 r
.29756 .4808 .31016 .48682 .33027 .46323 .31783 .45743 Metetra
0 .456 .163 r
.31783 .45743 .33027 .46323 .35026 .44059 .33798 .43498 Metetra
0 .394 .247 r
.33798 .43498 .35026 .44059 .37014 .41924 .35803 .41377 Metetra
0 .337 .294 r
.35803 .41377 .37014 .41924 .38991 .39948 .37797 .3941 Metetra
0 .262 .287 r
.37797 .3941 .38991 .39948 .4096 .38153 .39782 .37621 Metetra
0 .179 .245 r
.39782 .37621 .4096 .38153 .42923 .36558 .41761 .3603 Metetra
0 .123 .211 r
.41761 .3603 .42923 .36558 .44884 .35179 .43737 .3465 Metetra
0 .089 .187 r
.43737 .3465 .44884 .35179 .46845 .34025 .45714 .33494 Metetra
0 .071 .172 r
.45714 .33494 .46845 .34025 .48812 .33105 .47695 .32568 Metetra
0 .065 .167 r
.47695 .32568 .48812 .33105 .50789 .32422 .49686 .31877 Metetra
0 .071 .172 r
.49686 .31877 .50789 .32422 .5278 .31978 .5169 .31422 Metetra
0 .089 .187 r
.5169 .31422 .5278 .31978 .54791 .3177 .53714 .31201 Metetra
0 .123 .211 r
.53714 .31201 .54791 .3177 .56826 .31794 .55761 .31208 Metetra
0 .179 .245 r
.55761 .31208 .56826 .31794 .5889 .32039 .57836 .31433 Metetra
0 .262 .287 r
.57836 .31433 .5889 .32039 .60987 .32493 .59945 .31865 Metetra
0 .337 .294 r
.59945 .31865 .60987 .32493 .63123 .33139 .6209 .32485 Metetra
0 .394 .247 r
.6209 .32485 .63123 .33139 .65299 .33956 .64276 .33271 Metetra
0 .456 .163 r
.64276 .33271 .65299 .33956 .67519 .34915 .66506 .34195 Metetra
0 .523 .036 r
.66506 .34195 .67519 .34915 .69786 .35985 .68781 .35224 Metetra
.137 .592 0 r
.68781 .35224 .69786 .35985 .72098 .37123 .71102 .36316 Metetra
.353 .662 0 r
.71102 .36316 .72098 .37123 .74457 .38282 .73468 .37423 Metetra
.607 .73 0 r
.73468 .37423 .74457 .38282 .76857 .39406 .75876 .38487 Metetra
.795 .705 0 r
.75876 .38487 .76857 .39406 .79295 .40429 .7832 .39442 Metetra
.855 .538 0 r
.7832 .39442 .79295 .40429 .81762 .41276 .80793 .40212 Metetra
.905 .371 0 r
.80793 .40212 .81762 .41276 .84246 .4186 .83282 .40711 Metetra
.916 .335 0 r
.1621 .60358 .17568 .61198 .19568 .59434 .18214 .58684 Metetra
.868 .496 0 r
.18214 .58684 .19568 .59434 .21593 .57404 .20247 .56734 Metetra
.812 .662 0 r
.20247 .56734 .21593 .57404 .23632 .55187 .22296 .54586 Metetra
.685 .749 0 r
.22296 .54586 .23632 .55187 .25677 .52853 .24353 .52312 Metetra
.429 .683 0 r
.24353 .52312 .25677 .52853 .27719 .50466 .2641 .49975 Metetra
.206 .616 0 r
.2641 .49975 .27719 .50466 .29756 .4808 .28462 .47633 Metetra
.024 .549 0 r
.28462 .47633 .29756 .4808 .31783 .45743 .30505 .45332 Metetra
0 .484 .114 r
.30505 .45332 .31783 .45743 .33798 .43498 .32538 .43115 Metetra
0 .423 .211 r
.32538 .43115 .33798 .43498 .35803 .41377 .3456 .41017 Metetra
0 .368 .272 r
.3456 .41017 .35803 .41377 .37797 .3941 .36571 .39068 Metetra
0 .319 .303 r
.36571 .39068 .37797 .3941 .39782 .37621 .38574 .37292 Metetra
0 .242 .278 r
.38574 .37292 .39782 .37621 .41761 .3603 .4057 .35708 Metetra
0 .179 .245 r
.4057 .35708 .41761 .3603 .43737 .3465 .42563 .34333 Metetra
0 .138 .221 r
.42563 .34333 .43737 .3465 .45714 .33494 .44556 .33176 Metetra
0 .116 .207 r
.44556 .33176 .45714 .33494 .47695 .32568 .46553 .32246 Metetra
0 .109 .202 r
.46553 .32246 .47695 .32568 .49686 .31877 .48559 .31547 Metetra
0 .116 .207 r
.48559 .31547 .49686 .31877 .5169 .31422 .50579 .3108 Metetra
0 .138 .221 r
.50579 .3108 .5169 .31422 .53714 .31201 .52617 .30843 Metetra
0 .179 .245 r
.52617 .30843 .53714 .31201 .55761 .31208 .54677 .3083 Metetra
0 .242 .278 r
.54677 .3083 .55761 .31208 .57836 .31433 .56766 .31032 Metetra
0 .319 .303 r
.56766 .31032 .57836 .31433 .59945 .31865 .58887 .31434 Metetra
0 .368 .272 r
.58887 .31434 .59945 .31865 .6209 .32485 .61044 .3202 Metetra
0 .423 .211 r
.61044 .3202 .6209 .32485 .64276 .33271 .63241 .32766 Metetra
0 .484 .114 r
.63241 .32766 .64276 .33271 .66506 .34195 .65481 .33644 Metetra
.024 .549 0 r
.65481 .33644 .66506 .34195 .68781 .35224 .67766 .34619 Metetra
.206 .616 0 r
.67766 .34619 .68781 .35224 .71102 .36316 .70096 .3565 Metetra
.429 .683 0 r
.70096 .3565 .71102 .36316 .73468 .37423 .7247 .36687 Metetra
.685 .749 0 r
.7247 .36687 .73468 .37423 .75876 .38487 .74885 .37671 Metetra
.812 .662 0 r
.74885 .37671 .75876 .38487 .7832 .39442 .77336 .38536 Metetra
.868 .496 0 r
.77336 .38536 .7832 .39442 .80793 .40212 .79814 .39204 Metetra
.916 .335 0 r
.79814 .39204 .80793 .40212 .83282 .40711 .82307 .3959 Metetra
.928 .291 0 r
.14829 .5953 .1621 .60358 .18214 .58684 .16834 .57972 Metetra
.884 .443 0 r
.16834 .57972 .18214 .58684 .20247 .56734 .18872 .56126 Metetra
.832 .606 0 r
.18872 .56126 .20247 .56734 .22296 .54586 .20929 .5407 Metetra
.773 .76 0 r
.20929 .5407 .22296 .54586 .24353 .52312 .22997 .51876 Metetra
.528 .71 0 r
.22997 .51876 .24353 .52312 .2641 .49975 .25067 .49608 Metetra
.3 .646 0 r
.25067 .49608 .2641 .49975 .28462 .47633 .27133 .47324 Metetra
.108 .581 0 r
.27133 .47324 .28462 .47633 .30505 .45332 .29193 .45073 Metetra
0 .519 .044 r
.29193 .45073 .30505 .45332 .32538 .43115 .31243 .42897 Metetra
0 .46 .156 r
.31243 .42897 .32538 .43115 .3456 .41017 .33283 .40832 Metetra
0 .407 .232 r
.33283 .40832 .3456 .41017 .36571 .39068 .35312 .38909 Metetra
0 .359 .279 r
.35312 .38909 .36571 .39068 .38574 .37292 .37333 .37152 Metetra
0 .319 .303 r
.37333 .37152 .38574 .37292 .4057 .35708 .39348 .35582 Metetra
0 .262 .287 r
.39348 .35582 .4057 .35708 .42563 .34333 .41359 .34214 Metetra
0 .214 .264 r
.41359 .34214 .42563 .34333 .44556 .33176 .4337 .33059 Metetra
0 .187 .25 r
.4337 .33059 .44556 .33176 .46553 .32246 .45384 .32127 Metetra
0 .179 .245 r
.45384 .32127 .46553 .32246 .48559 .31547 .47407 .3142 Metetra
0 .187 .25 r
.47407 .3142 .48559 .31547 .50579 .3108 .49443 .3094 Metetra
0 .214 .264 r
.49443 .3094 .50579 .3108 .52617 .30843 .51497 .30685 Metetra
0 .262 .287 r
.51497 .30685 .52617 .30843 .54677 .3083 .53573 .30648 Metetra
0 .319 .303 r
.53573 .30648 .54677 .3083 .56766 .31032 .55676 .3082 Metetra
0 .359 .279 r
.55676 .3082 .56766 .31032 .58887 .31434 .57811 .31187 Metetra
0 .407 .232 r
.57811 .31187 .58887 .31434 .61044 .3202 .59981 .31731 Metetra
0 .46 .156 r
.59981 .31731 .61044 .3202 .63241 .32766 .62191 .32427 Metetra
0 .519 .044 r
.62191 .32427 .63241 .32766 .65481 .33644 .64443 .33247 Metetra
.108 .581 0 r
.64443 .33247 .65481 .33644 .67766 .34619 .66738 .34155 Metetra
.3 .646 0 r
.66738 .34155 .67766 .34619 .70096 .3565 .69078 .35108 Metetra
.528 .71 0 r
.69078 .35108 .70096 .3565 .7247 .36687 .7146 .36056 Metetra
.773 .76 0 r
.7146 .36056 .7247 .36687 .74885 .37671 .73883 .3694 Metetra
.832 .606 0 r
.73883 .3694 .74885 .37671 .77336 .38536 .76339 .37691 Metetra
.884 .443 0 r
.76339 .37691 .77336 .38536 .79814 .39204 .78822 .38231 Metetra
.928 .291 0 r
.78822 .38231 .79814 .39204 .82307 .3959 .81317 .38474 Metetra
.941 .242 0 r
.13426 .58685 .14829 .5953 .16834 .57972 .15429 .57273 Metetra
.902 .382 0 r
.15429 .57273 .16834 .57972 .18872 .56126 .17468 .55556 Metetra
.855 .538 0 r
.17468 .55556 .18872 .56126 .20929 .5407 .19531 .53615 Metetra
.8 .693 0 r
.19531 .53615 .20929 .5407 .22997 .51876 .21607 .51522 Metetra
.651 .741 0 r
.21607 .51522 .22997 .51876 .25067 .49608 .23689 .49342 Metetra
.418 .68 0 r
.23689 .49342 .25067 .49608 .27133 .47324 .25769 .47134 Metetra
.216 .619 0 r
.25769 .47134 .27133 .47324 .29193 .45073 .27845 .44947 Metetra
.052 .56 0 r
.27845 .44947 .29193 .45073 .31243 .42897 .29912 .42824 Metetra
0 .504 .076 r
.29912 .42824 .31243 .42897 .33283 .40832 .31969 .40803 Metetra
0 .452 .169 r
.31969 .40803 .33283 .40832 .35312 .38909 .34018 .38915 Metetra
0 .407 .232 r
.34018 .38915 .35312 .38909 .37333 .37152 .36058 .37185 Metetra
0 .368 .272 r
.36058 .37185 .37333 .37152 .39348 .35582 .38091 .35634 Metetra
0 .337 .294 r
.38091 .35634 .39348 .35582 .41359 .34214 .40122 .34277 Metetra
0 .315 .305 r
.40122 .34277 .41359 .34214 .4337 .33059 .42152 .33128 Metetra
0 .292 .301 r
.42152 .33128 .4337 .33059 .45384 .32127 .44185 .32194 Metetra
0 .282 .297 r
.44185 .32194 .45384 .32127 .47407 .3142 .46227 .31479 Metetra
0 .292 .301 r
.46227 .31479 .47407 .3142 .49443 .3094 .48281 .30986 Metetra
0 .315 .305 r
.48281 .30986 .49443 .3094 .51497 .30685 .50352 .3071 Metetra
0 .337 .294 r
.50352 .3071 .51497 .30685 .53573 .30648 .52445 .30645 Metetra
0 .368 .272 r
.52445 .30645 .53573 .30648 .55676 .3082 .54564 .30782 Metetra
0 .407 .232 r
.54564 .30782 .55676 .3082 .57811 .31187 .56714 .31106 Metetra
0 .452 .169 r
.56714 .31106 .57811 .31187 .59981 .31731 .58899 .31598 Metetra
0 .504 .076 r
.58899 .31598 .59981 .31731 .62191 .32427 .61123 .32234 Metetra
.052 .56 0 r
.61123 .32234 .62191 .32427 .64443 .33247 .63387 .32983 Metetra
.216 .619 0 r
.63387 .32983 .64443 .33247 .66738 .34155 .65694 .33809 Metetra
.418 .68 0 r
.65694 .33809 .66738 .34155 .69078 .35108 .68044 .34668 Metetra
.651 .741 0 r
.68044 .34668 .69078 .35108 .7146 .36056 .70436 .35508 Metetra
.8 .693 0 r
.70436 .35508 .7146 .36056 .73883 .3694 .72866 .36268 Metetra
.855 .538 0 r
.72866 .36268 .73883 .3694 .76339 .37691 .75328 .3688 Metetra
.902 .382 0 r
.75328 .3688 .76339 .37691 .78822 .38231 .77813 .37265 Metetra
.941 .242 0 r
.77813 .37265 .78822 .38231 .81317 .38474 .8031 .37335 Metetra
.953 .194 0 r
.12007 .57792 .13426 .58685 .15429 .57273 .14001 .56553 Metetra
.921 .315 0 r
.14001 .56553 .15429 .57273 .17468 .55556 .16038 .54994 Metetra
.879 .46 0 r
.16038 .54994 .17468 .55556 .19531 .53615 .18103 .53192 Metetra
.83 .612 0 r
.18103 .53192 .19531 .53615 .21607 .51522 .20186 .51223 Metetra
.776 .754 0 r
.20186 .51223 .21607 .51522 .23689 .49342 .22277 .49151 Metetra
.562 .719 0 r
.22277 .49151 .23689 .49342 .25769 .47134 .2437 .47035 Metetra
.353 .662 0 r
.2437 .47035 .25769 .47134 .27845 .44947 .2646 .44928 Metetra
.176 .606 0 r
.2646 .44928 .27845 .44947 .29912 .42824 .28543 .42872 Metetra
.033 .552 0 r
.28543 .42872 .29912 .42824 .31969 .40803 .30619 .40907 Metetra
0 .504 .076 r
.30619 .40907 .31969 .40803 .34018 .38915 .32686 .39063 Metetra
0 .46 .156 r
.32686 .39063 .34018 .38915 .36058 .37185 .34746 .37367 Metetra
0 .423 .211 r
.34746 .37367 .36058 .37185 .38091 .35634 .36799 .35842 Metetra
0 .394 .247 r
.36799 .35842 .38091 .35634 .40122 .34277 .3885 .34502 Metetra
0 .372 .268 r
.3885 .34502 .40122 .34277 .42152 .33128 .409 .33361 Metetra
0 .359 .279 r
.409 .33361 .42152 .33128 .44185 .32194 .42954 .32427 Metetra
0 .355 .282 r
.42954 .32427 .44185 .32194 .46227 .31479 .45015 .31705 Metetra
0 .359 .279 r
.45015 .31705 .46227 .31479 .48281 .30986 .47089 .31195 Metetra
0 .372 .268 r
.47089 .31195 .48281 .30986 .50352 .3071 .49179 .30895 Metetra
0 .394 .247 r
.49179 .30895 .50352 .3071 .52445 .30645 .5129 .30799 Metetra
0 .423 .211 r
.5129 .30799 .52445 .30645 .54564 .30782 .53427 .30895 Metetra
0 .46 .156 r
.53427 .30895 .54564 .30782 .56714 .31106 .55594 .31168 Metetra
0 .504 .076 r
.55594 .31168 .56714 .31106 .58899 .31598 .57795 .31599 Metetra
.033 .552 0 r
.57795 .31599 .58899 .31598 .61123 .32234 .60034 .32162 Metetra
.176 .606 0 r
.60034 .32162 .61123 .32234 .63387 .32983 .62312 .32827 Metetra
.353 .662 0 r
.62312 .32827 .63387 .32983 .65694 .33809 .64632 .33554 Metetra
.562 .719 0 r
.64632 .33554 .65694 .33809 .68044 .34668 .66993 .343 Metetra
.776 .754 0 r
.66993 .343 .68044 .34668 .70436 .35508 .69394 .35011 Metetra
.83 .612 0 r
.69394 .35011 .70436 .35508 .72866 .36268 .71831 .35625 Metetra
.879 .46 0 r
.71831 .35625 .72866 .36268 .75328 .3688 .74298 .36073 Metetra
.921 .315 0 r
.74298 .36073 .75328 .3688 .77813 .37265 .76786 .36273 Metetra
.953 .194 0 r
.76786 .36273 .77813 .37265 .8031 .37335 .79282 .36139 Metetra
.964 .149 0 r
.10574 .56811 .12007 .57792 .14001 .56553 .12556 .55777 Metetra
.939 .247 0 r
.12556 .55777 .14001 .56553 .16038 .54994 .14585 .54401 Metetra
.904 .376 0 r
.14585 .54401 .16038 .54994 .18103 .53192 .16648 .52765 Metetra
.861 .52 0 r
.16648 .52765 .18103 .53192 .20186 .51223 .18734 .50943 Metetra
.812 .662 0 r
.18734 .50943 .20186 .51223 .22277 .49151 .20832 .49 Metetra
.73 .76 0 r
.20832 .49 .22277 .49151 .2437 .47035 .22935 .46996 Metetra
.517 .707 0 r
.22935 .46996 .2437 .47035 .2646 .44928 .25038 .44985 Metetra
.331 .655 0 r
.25038 .44985 .2646 .44928 .28543 .42872 .27137 .43011 Metetra
.176 .606 0 r
.27137 .43011 .28543 .42872 .30619 .40907 .2923 .41113 Metetra
.052 .56 0 r
.2923 .41113 .30619 .40907 .32686 .39063 .31316 .39325 Metetra
0 .519 .044 r
.31316 .39325 .32686 .39063 .34746 .37367 .33396 .37672 Metetra
0 .484 .114 r
.33396 .37672 .34746 .37367 .36799 .35842 .3547 .36179 Metetra
0 .456 .163 r
.3547 .36179 .36799 .35842 .3885 .34502 .37541 .3486 Metetra
0 .436 .194 r
.37541 .3486 .3885 .34502 .409 .33361 .39613 .33731 Metetra
0 .423 .211 r
.39613 .33731 .409 .33361 .42954 .32427 .41688 .32799 Metetra
0 .419 .217 r
.41688 .32799 .42954 .32427 .45015 .31705 .4377 .32069 Metetra
0 .423 .211 r
.4377 .32069 .45015 .31705 .47089 .31195 .45865 .31542 Metetra
0 .436 .194 r
.45865 .31542 .47089 .31195 .49179 .30895 .47975 .31216 Metetra
0 .456 .163 r
.47975 .31216 .49179 .30895 .5129 .30799 .50106 .31082 Metetra
0 .484 .114 r
.50106 .31082 .5129 .30799 .53427 .30895 .52262 .3113 Metetra
0 .519 .044 r
.52262 .3113 .53427 .30895 .55594 .31168 .54448 .31344 Metetra
.052 .56 0 r
.54448 .31344 .55594 .31168 .57795 .31599 .56666 .31703 Metetra
.176 .606 0 r
.56666 .31703 .57795 .31599 .60034 .32162 .58921 .32181 Metetra
.331 .655 0 r
.58921 .32181 .60034 .32162 .62312 .32827 .61215 .32746 Metetra
.517 .707 0 r
.61215 .32746 .62312 .32827 .64632 .33554 .63548 .33358 Metetra
.73 .76 0 r
.63548 .33358 .64632 .33554 .66993 .343 .65921 .33971 Metetra
.812 .662 0 r
.65921 .33971 .66993 .343 .69394 .35011 .68331 .3453 Metetra
.861 .52 0 r
.68331 .3453 .69394 .35011 .71831 .35625 .70775 .34973 Metetra
.904 .376 0 r
.70775 .34973 .71831 .35625 .74298 .36073 .73247 .35228 Metetra
.939 .247 0 r
.73247 .35228 .74298 .36073 .76786 .36273 .75736 .35214 Metetra
.964 .149 0 r
.75736 .35214 .76786 .36273 .79282 .36139 .7823 .34844 Metetra
.972 .116 0 r
.09135 .55697 .10574 .56811 .12556 .55777 .11097 .54897 Metetra
.956 .184 0 r
.11097 .54897 .12556 .55777 .14585 .54401 .13114 .53735 Metetra
.928 .291 0 r
.13114 .53735 .14585 .54401 .16648 .52765 .15171 .52292 Metetra
.891 .42 0 r
.15171 .52292 .16648 .52765 .18734 .50943 .17255 .5064 Metetra
.849 .556 0 r
.17255 .5064 .18734 .50943 .20832 .49 .19357 .48849 Metetra
.803 .687 0 r
.19357 .48849 .20832 .49 .22935 .46996 .21468 .46978 Metetra
.708 .755 0 r
.21468 .46978 .22935 .46996 .25038 .44985 .23582 .45081 Metetra
.517 .707 0 r
.23582 .45081 .25038 .44985 .27137 .43011 .25695 .43204 Metetra
.353 .662 0 r
.25695 .43204 .27137 .43011 .2923 .41113 .27805 .41387 Metetra
.216 .619 0 r
.27805 .41387 .2923 .41113 .31316 .39325 .29909 .39665 Metetra
.108 .581 0 r
.29909 .39665 .31316 .39325 .33396 .37672 .32008 .38065 Metetra
.024 .549 0 r
.32008 .38065 .33396 .37672 .3547 .36179 .34103 .36611 Metetra
0 .523 .036 r
.34103 .36611 .3547 .36179 .37541 .3486 .36195 .3532 Metetra
0 .504 .076 r
.36195 .3532 .37541 .3486 .39613 .33731 .38289 .34206 Metetra
0 .492 .099 r
.38289 .34206 .39613 .33731 .41688 .32799 .40386 .33278 Metetra
0 .488 .107 r
.40386 .33278 .41688 .32799 .4377 .32069 .42491 .3254 Metetra
0 .492 .099 r
.42491 .3254 .4377 .32069 .45865 .31542 .44607 .31994 Metetra
0 .504 .076 r
.44607 .31994 .45865 .31542 .47975 .31216 .46739 .31637 Metetra
0 .523 .036 r
.46739 .31637 .47975 .31216 .50106 .31082 .48891 .3146 Metetra
.024 .549 0 r
.48891 .3146 .50106 .31082 .52262 .3113 .51068 .31452 Metetra
.108 .581 0 r
.51068 .31452 .52262 .3113 .54448 .31344 .53273 .31597 Metetra
.216 .619 0 r
.53273 .31597 .54448 .31344 .56666 .31703 .5551 .31873 Metetra
.353 .662 0 r
.5551 .31873 .56666 .31703 .58921 .32181 .57782 .32252 Metetra
.517 .707 0 r
.57782 .32252 .58921 .32181 .61215 .32746 .60092 .32701 Metetra
.708 .755 0 r
.60092 .32701 .61215 .32746 .63548 .33358 .62439 .33178 Metetra
.803 .687 0 r
.62439 .33178 .63548 .33358 .65921 .33971 .64824 .33637 Metetra
.849 .556 0 r
.64824 .33637 .65921 .33971 .68331 .3453 .67244 .34021 Metetra
.891 .42 0 r
.67244 .34021 .68331 .3453 .70775 .34973 .69696 .34267 Metetra
.928 .291 0 r
.69696 .34267 .70775 .34973 .73247 .35228 .72171 .343 Metetra
.956 .184 0 r
.72171 .343 .73247 .35228 .75736 .35214 .7466 .34041 Metetra
.972 .116 0 r
.7466 .34041 .75736 .35214 .7823 .34844 .7715 .33402 Metetra
.976 .102 0 r
.07698 .54398 .09135 .55697 .11097 .54897 .09633 .53863 Metetra
.968 .133 0 r
.09633 .53863 .11097 .54897 .13114 .53735 .11631 .52945 Metetra
.949 .211 0 r
.11631 .52945 .13114 .53735 .15171 .52292 .13676 .51721 Metetra
.92 .32 0 r
.13676 .51721 .15171 .52292 .17255 .5064 .15754 .50267 Metetra
.884 .443 0 r
.15754 .50267 .17255 .5064 .19357 .48849 .17856 .48651 Metetra
.845 .569 0 r
.17856 .48651 .19357 .48849 .21468 .46978 .19971 .46933 Metetra
.803 .687 0 r
.19971 .46933 .21468 .46978 .23582 .45081 .22094 .45169 Metetra
.73 .76 0 r
.22094 .45169 .23582 .45081 .25695 .43204 .24219 .43406 Metetra
.562 .719 0 r
.24219 .43406 .25695 .43204 .27805 .41387 .26343 .41685 Metetra
.418 .68 0 r
.26343 .41685 .27805 .41387 .29909 .39665 .28464 .40042 Metetra
.3 .646 0 r
.28464 .40042 .29909 .39665 .32008 .38065 .30582 .38505 Metetra
.206 .616 0 r
.30582 .38505 .32008 .38065 .34103 .36611 .32698 .37098 Metetra
.137 .592 0 r
.32698 .37098 .34103 .36611 .36195 .3532 .34812 .3584 Metetra
.089 .574 0 r
.34812 .3584 .36195 .3532 .38289 .34206 .36928 .34745 Metetra
.061 .563 0 r
.36928 .34745 .38289 .34206 .40386 .33278 .39047 .33823 Metetra
.052 .56 0 r
.39047 .33823 .40386 .33278 .42491 .3254 .41175 .33077 Metetra
.061 .563 0 r
.41175 .33077 .42491 .3254 .44607 .31994 .43314 .3251 Metetra
.089 .574 0 r
.43314 .3251 .44607 .31994 .46739 .31637 .45469 .32118 Metetra
.137 .592 0 r
.45469 .32118 .46739 .31637 .48891 .3146 .47644 .31892 Metetra
.206 .616 0 r
.47644 .31892 .48891 .3146 .51068 .31452 .49842 .31821 Metetra
.3 .646 0 r
.49842 .31821 .51068 .31452 .53273 .31597 .52068 .31886 Metetra
.418 .68 0 r
.52068 .31886 .53273 .31597 .5551 .31873 .54325 .32065 Metetra
.562 .719 0 r
.54325 .32065 .5551 .31873 .57782 .32252 .56615 .3233 Metetra
.73 .76 0 r
.56615 .3233 .57782 .32252 .60092 .32701 .58941 .32645 Metetra
.803 .687 0 r
.58941 .32645 .60092 .32701 .62439 .33178 .61303 .32968 Metetra
.845 .569 0 r
.61303 .32968 .62439 .33178 .64824 .33637 .63701 .3325 Metetra
.884 .443 0 r
.63701 .3325 .64824 .33637 .67244 .34021 .66131 .33433 Metetra
.92 .32 0 r
.66131 .33433 .67244 .34021 .69696 .34267 .68589 .33453 Metetra
.949 .211 0 r
.68589 .33453 .69696 .34267 .72171 .343 .71067 .33235 Metetra
.968 .133 0 r
.71067 .33235 .72171 .343 .7466 .34041 .73554 .32699 Metetra
.976 .102 0 r
.73554 .32699 .7466 .34041 .7715 .33402 .76039 .31756 Metetra
.973 .115 0 r
.06272 .52856 .07698 .54398 .09633 .53863 .08173 .52617 Metetra
.975 .105 0 r
.08173 .52617 .09633 .53863 .11631 .52945 .10145 .51971 Metetra
.965 .147 0 r
.10145 .51971 .11631 .52945 .13676 .51721 .12171 .50996 Metetra
.945 .226 0 r
.12171 .50996 .13676 .51721 .15754 .50267 .14238 .49766 Metetra
.917 .329 0 r
.14238 .49766 .15754 .50267 .17856 .48651 .16334 .48349 Metetra
.884 .443 0 r
.16334 .48349 .17856 .48651 .19971 .46933 .1845 .46807 Metetra
.849 .556 0 r
.1845 .46807 .19971 .46933 .22094 .45169 .20578 .45197 Metetra
.812 .662 0 r
.20578 .45197 .22094 .45169 .24219 .43406 .22712 .43566 Metetra
.776 .754 0 r
.22712 .43566 .24219 .43406 .26343 .41685 .24848 .41956 Metetra
.651 .741 0 r
.24848 .41956 .26343 .41685 .28464 .40042 .26985 .40405 Metetra
.528 .71 0 r
.26985 .40405 .28464 .40042 .30582 .38505 .29121 .38942 Metetra
.429 .683 0 r
.29121 .38942 .30582 .38505 .32698 .37098 .31256 .37592 Metetra
.353 .662 0 r
.31256 .37592 .32698 .37098 .34812 .3584 .33392 .36373 Metetra
.3 .646 0 r
.33392 .36373 .34812 .3584 .36928 .34745 .35529 .35302 Metetra
.268 .636 0 r
.35529 .35302 .36928 .34745 .39047 .33823 .37672 .34387 Metetra
.258 .632 0 r
.37672 .34387 .39047 .33823 .41175 .33077 .39823 .33634 Metetra
.268 .636 0 r
.39823 .33634 .41175 .33077 .43314 .3251 .41986 .33043 Metetra
.3 .646 0 r
.41986 .33043 .43314 .3251 .45469 .32118 .44165 .32611 Metetra
.353 .662 0 r
.44165 .32611 .45469 .32118 .47644 .31892 .46362 .32329 Metetra
.429 .683 0 r
.46362 .32329 .47644 .31892 .49842 .31821 .48583 .32185 Metetra
.528 .71 0 r
.48583 .32185 .49842 .31821 .52068 .31886 .50831 .32159 Metetra
.651 .741 0 r
.50831 .32159 .52068 .31886 .54325 .32065 .53109 .32228 Metetra
.776 .754 0 r
.53109 .32228 .54325 .32065 .56615 .3233 .55418 .32361 Metetra
.812 .662 0 r
.55418 .32361 .56615 .3233 .58941 .32645 .57762 .32523 Metetra
.849 .556 0 r
.57762 .32523 .58941 .32645 .61303 .32968 .60139 .3267 Metetra
.884 .443 0 r
.60139 .3267 .61303 .32968 .63701 .3325 .62549 .32751 Metetra
.917 .329 0 r
.62549 .32751 .63701 .3325 .66131 .33433 .64988 .32707 Metetra
.945 .226 0 r
.64988 .32707 .66131 .33433 .68589 .33453 .67452 .32472 Metetra
.965 .147 0 r
.67452 .32472 .68589 .33453 .71067 .33235 .69932 .31972 Metetra
.975 .105 0 r
.69932 .31972 .71067 .33235 .73554 .32699 .72417 .31126 Metetra
.973 .115 0 r
.72417 .31126 .73554 .32699 .76039 .31756 .74893 .29847 Metetra
.961 .164 0 r
.04871 .51006 .06272 .52856 .08173 .52617 .06728 .51093 Metetra
.974 .108 0 r
.06728 .51093 .08173 .52617 .10145 .51971 .08665 .50749 Metetra
.974 .108 0 r
.08665 .50749 .10145 .51971 .12171 .50996 .10665 .50051 Metetra
.964 .152 0 r
.10665 .50051 .12171 .50996 .14238 .49766 .12714 .49072 Metetra
.945 .226 0 r
.12714 .49072 .14238 .49766 .16334 .48349 .148 .4788 Metetra
.92 .32 0 r
.148 .4788 .16334 .48349 .1845 .46807 .16911 .46538 Metetra
.891 .42 0 r
.16911 .46538 .1845 .46807 .20578 .45197 .19039 .45102 Metetra
.861 .52 0 r
.19039 .45102 .20578 .45197 .22712 .43566 .21179 .43622 Metetra
.83 .612 0 r
.21179 .43622 .22712 .43566 .24848 .41956 .23325 .42141 Metetra
.8 .693 0 r
.23325 .42141 .24848 .41956 .26985 .40405 .25475 .40696 Metetra
.773 .76 0 r
.25475 .40696 .26985 .40405 .29121 .38942 .27627 .39318 Metetra
.685 .749 0 r
.27627 .39318 .29121 .38942 .31256 .37592 .29781 .38033 Metetra
.607 .73 0 r
.29781 .38033 .31256 .37592 .33392 .36373 .31937 .36862 Metetra
.551 .716 0 r
.31937 .36862 .33392 .36373 .35529 .35302 .34096 .35818 Metetra
.517 .707 0 r
.34096 .35818 .35529 .35302 .37672 .34387 .36262 .34913 Metetra
.506 .704 0 r
.36262 .34913 .37672 .34387 .39823 .33634 .38437 .34152 Metetra
.517 .707 0 r
.38437 .34152 .39823 .33634 .41986 .33043 .40624 .33535 Metetra
.551 .716 0 r
.40624 .33535 .41986 .33043 .44165 .32611 .42826 .33059 Metetra
.607 .73 0 r
.42826 .33059 .44165 .32611 .46362 .32329 .45048 .32713 Metetra
.685 .749 0 r
.45048 .32713 .46362 .32329 .48583 .32185 .47292 .32486 Metetra
.773 .76 0 r
.47292 .32486 .48583 .32185 .50831 .32159 .49562 .32356 Metetra
.8 .693 0 r
.49562 .32356 .50831 .32159 .53109 .32228 .51861 .32299 Metetra
.83 .612 0 r
.51861 .32299 .53109 .32228 .55418 .32361 .5419 .32284 Metetra
.861 .52 0 r
.5419 .32284 .55418 .32361 .57762 .32523 .56551 .32272 Metetra
.891 .42 0 r
.56551 .32272 .57762 .32523 .60139 .3267 .58944 .3222 Metetra
.92 .32 0 r
.58944 .3222 .60139 .3267 .62549 .32751 .61366 .32074 Metetra
.945 .226 0 r
.61366 .32074 .62549 .32751 .64988 .32707 .63815 .31775 Metetra
.964 .152 0 r
.63815 .31775 .64988 .32707 .67452 .32472 .66284 .31256 Metetra
.974 .108 0 r
.66284 .31256 .67452 .32472 .69932 .31972 .68764 .30442 Metetra
.974 .108 0 r
.68764 .30442 .69932 .31972 .72417 .31126 .71244 .29254 Metetra
.961 .164 0 r
.71244 .29254 .72417 .31126 .74893 .29847 .7371 .27605 Metetra
.937 .254 0 r
.03507 .48778 .04871 .51006 .06728 .51093 .05311 .4922 Metetra
.963 .153 0 r
.05311 .4922 .06728 .51093 .08665 .50749 .07205 .49207 Metetra
.975 .106 0 r
.07205 .49207 .08665 .50749 .10665 .50051 .09171 .48814 Metetra
.974 .108 0 r
.09171 .48814 .10665 .50051 .12714 .49072 .11195 .48113 Metetra
.965 .147 0 r
.11195 .48113 .12714 .49072 .148 .4788 .13262 .47172 Metetra
.949 .211 0 r
.13262 .47172 .148 .4788 .16911 .46538 .15363 .46054 Metetra
.928 .291 0 r
.15363 .46054 .16911 .46538 .19039 .45102 .17487 .44815 Metetra
.904 .376 0 r
.17487 .44815 .19039 .45102 .21179 .43622 .19628 .43505 Metetra
.879 .46 0 r
.19628 .43505 .21179 .43622 .23325 .42141 .2178 .4217 Metetra
.855 .538 0 r
.2178 .4217 .23325 .42141 .25475 .40696 .23941 .40846 Metetra
.832 .606 0 r
.23941 .40846 .25475 .40696 .27627 .39318 .26106 .39566 Metetra
.812 .662 0 r
.26106 .39566 .27627 .39318 .29781 .38033 .28276 .38357 Metetra
.795 .705 0 r
.28276 .38357 .29781 .38033 .31937 .36862 .30451 .37239 Metetra
.783 .736 0 r
.30451 .37239 .31937 .36862 .34096 .35818 .32632 .36229 Metetra
.776 .754 0 r
.32632 .36229 .34096 .35818 .36262 .34913 .3482 .35336 Metetra
.773 .76 0 r
.3482 .35336 .36262 .34913 .38437 .34152 .37018 .34566 Metetra
.776 .754 0 r
.37018 .34566 .38437 .34152 .40624 .33535 .39229 .3392 Metetra
.783 .736 0 r
.39229 .3392 .40624 .33535 .42826 .33059 .41455 .33393 Metetra
.795 .705 0 r
.41455 .33393 .42826 .33059 .45048 .32713 .43701 .32976 Metetra
.812 .662 0 r
.43701 .32976 .45048 .32713 .47292 .32486 .45969 .32654 Metetra
.832 .606 0 r
.45969 .32654 .47292 .32486 .49562 .32356 .48262 .32407 Metetra
.855 .538 0 r
.48262 .32407 .49562 .32356 .51861 .32299 .50582 .32208 Metetra
.879 .46 0 r
.50582 .32208 .51861 .32299 .5419 .32284 .52931 .32025 Metetra
.904 .376 0 r
.52931 .32025 .5419 .32284 .56551 .32272 .5531 .31818 Metetra
.928 .291 0 r
.5531 .31818 .56551 .32272 .58944 .3222 .57718 .31542 Metetra
.949 .211 0 r
.57718 .31542 .58944 .3222 .61366 .32074 .60153 .31143 Metetra
.965 .147 0 r
.60153 .31143 .61366 .32074 .63815 .31775 .62609 .30561 Metetra
.974 .108 0 r
.62609 .30561 .63815 .31775 .66284 .31256 .65082 .29728 Metetra
.975 .106 0 r
.65082 .29728 .66284 .31256 .68764 .30442 .67561 .2857 Metetra
.963 .153 0 r
.67561 .2857 .68764 .30442 .71244 .29254 .70035 .27008 Metetra
.937 .254 0 r
.70035 .27008 .71244 .29254 .7371 .27605 .72489 .24959 Metetra
.9 .389 0 r
.02198 .46099 .03507 .48778 .05311 .4922 .03939 .46922 Metetra
.94 .246 0 r
.03939 .46922 .05311 .4922 .07205 .49207 .05779 .47267 Metetra
.963 .153 0 r
.05779 .47267 .07205 .49207 .09171 .48814 .07703 .47206 Metetra
.974 .108 0 r
.07703 .47206 .09171 .48814 .11195 .48113 .09692 .4681 Metetra
.975 .105 0 r
.09692 .4681 .11195 .48113 .13262 .47172 .11734 .46146 Metetra
.968 .133 0 r
.11734 .46146 .13262 .47172 .15363 .46054 .13817 .45275 Metetra
.956 .184 0 r
.13817 .45275 .15363 .46054 .17487 .44815 .15931 .44255 Metetra
.939 .247 0 r
.15931 .44255 .17487 .44815 .19628 .43505 .18068 .43136 Metetra
.921 .315 0 r
.18068 .43136 .19628 .43505 .2178 .4217 .20222 .41964 Metetra
.902 .382 0 r
.20222 .41964 .2178 .4217 .23941 .40846 .22389 .40777 Metetra
.884 .443 0 r
.22389 .40777 .23941 .40846 .26106 .39566 .24565 .39608 Metetra
.868 .496 0 r
.24565 .39608 .26106 .39566 .28276 .38357 .26749 .38485 Metetra
.855 .538 0 r
.26749 .38485 .28276 .38357 .30451 .37239 .28941 .37429 Metetra
.845 .569 0 r
.28941 .37429 .30451 .37239 .32632 .36229 .31141 .36456 Metetra
.838 .587 0 r
.31141 .36456 .32632 .36229 .3482 .35336 .3335 .35578 Metetra
.836 .594 0 r
.3335 .35578 .3482 .35336 .37018 .34566 .3557 .34799 Metetra
.838 .587 0 r
.3557 .34799 .37018 .34566 .39229 .3392 .37804 .3412 Metetra
.845 .569 0 r
.37804 .3412 .39229 .3392 .41455 .33393 .40055 .33537 Metetra
.855 .538 0 r
.40055 .33537 .41455 .33393 .43701 .32976 .42325 .33039 Metetra
.868 .496 0 r
.42325 .33039 .43701 .32976 .45969 .32654 .44616 .32612 Metetra
.884 .443 0 r
.44616 .32612 .45969 .32654 .48262 .32407 .46932 .32232 Metetra
.902 .382 0 r
.46932 .32232 .48262 .32407 .50582 .32208 .49274 .31874 Metetra
.921 .315 0 r
.49274 .31874 .50582 .32208 .52931 .32025 .51643 .31503 Metetra
.939 .247 0 r
.51643 .31503 .52931 .32025 .5531 .31818 .5404 .31079 Metetra
.956 .184 0 r
.5404 .31079 .5531 .31818 .57718 .31542 .56462 .30555 Metetra
.968 .133 0 r
.56462 .30555 .57718 .31542 .60153 .31143 .58908 .29876 Metetra
.975 .105 0 r
.58908 .29876 .60153 .31143 .62609 .30561 .61372 .28982 Metetra
.974 .108 0 r
.61372 .28982 .62609 .30561 .65082 .29728 .63847 .27806 Metetra
.963 .153 0 r
.63847 .27806 .65082 .29728 .67561 .2857 .66324 .26273 Metetra
.94 .246 0 r
.66324 .26273 .67561 .2857 .70035 .27008 .68789 .24308 Metetra
.9 .389 0 r
.68789 .24308 .70035 .27008 .72489 .24959 .71228 .21831 Metetra
.846 .563 0 r
.00962 .42894 .02198 .46099 .03939 .46922 .02629 .4412 Metetra
.9 .389 0 r
.02629 .4412 .03939 .46922 .05779 .47267 .04406 .44846 Metetra
.937 .254 0 r
.04406 .44846 .05779 .47267 .07703 .47206 .06277 .45142 Metetra
.961 .164 0 r
.06277 .45142 .07703 .47206 .09692 .4681 .08223 .45076 Metetra
.973 .115 0 r
.08223 .45076 .09692 .4681 .11734 .46146 .10231 .44713 Metetra
.976 .102 0 r
.10231 .44713 .11734 .46146 .13817 .45275 .12289 .44114 Metetra
.972 .116 0 r
.12289 .44114 .13817 .45275 .15931 .44255 .14386 .43334 Metetra
.964 .149 0 r
.14386 .43334 .15931 .44255 .18068 .43136 .16512 .42427 Metetra
.953 .194 0 r
.16512 .42427 .18068 .43136 .20222 .41964 .18662 .41436 Metetra
.941 .242 0 r
.18662 .41436 .20222 .41964 .22389 .40777 .20831 .40401 Metetra
.928 .291 0 r
.20831 .40401 .22389 .40777 .24565 .39608 .23013 .39357 Metetra
.916 .335 0 r
.23013 .39357 .24565 .39608 .26749 .38485 .25208 .3833 Metetra
.905 .371 0 r
.25208 .3833 .26749 .38485 .28941 .37429 .27414 .37344 Metetra
.898 .398 0 r
.27414 .37344 .28941 .37429 .31141 .36456 .29631 .36414 Metetra
.893 .415 0 r
.29631 .36414 .31141 .36456 .3335 .35578 .31859 .35552 Metetra
.891 .42 0 r
.31859 .35552 .3335 .35578 .3557 .34799 .341 .34763 Metetra
.893 .415 0 r
.341 .34763 .3557 .34799 .37804 .3412 .36357 .34048 Metetra
.898 .398 0 r
.36357 .34048 .37804 .3412 .40055 .33537 .3863 .33403 Metetra
.905 .371 0 r
.3863 .33403 .40055 .33537 .42325 .33039 .40923 .32815 Metetra
.916 .335 0 r
.40923 .32815 .42325 .33039 .44616 .32612 .43238 .32269 Metetra
.928 .291 0 r
.43238 .32269 .44616 .32612 .46932 .32232 .45576 .31742 Metetra
.941 .242 0 r
.45576 .31742 .46932 .32232 .49274 .31874 .47939 .31207 Metetra
.953 .194 0 r
.47939 .31207 .49274 .31874 .51643 .31503 .50328 .30628 Metetra
.964 .149 0 r
.50328 .30628 .51643 .31503 .5404 .31079 .52741 .29964 Metetra
.972 .116 0 r
.52741 .29964 .5404 .31079 .56462 .30555 .55178 .29167 Metetra
.976 .102 0 r
.55178 .29167 .56462 .30555 .58908 .29876 .57634 .28182 Metetra
.973 .115 0 r
.57634 .28182 .58908 .29876 .61372 .28982 .60104 .26949 Metetra
.961 .164 0 r
.60104 .26949 .61372 .28982 .63847 .27806 .6258 .25402 Metetra
.937 .254 0 r
.6258 .25402 .63847 .27806 .66324 .26273 .65052 .23468 Metetra
.9 .389 0 r
.65052 .23468 .66324 .26273 .68789 .24308 .67506 .21074 Metetra
.846 .563 0 r
.67506 .21074 .68789 .24308 .71228 .21831 .69927 .18145 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.14789 .21178 m
.15252 .21643 L
s
[(-5)] .13865 .20246 .99238 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.5537 .05288 m
.55757 .05817 L
s
[(5)] .54594 .04229 .73209 1 Mshowa
.125 Mabswid
.18577 .19694 m
.18851 .19978 L
s
.22422 .18189 m
.22691 .18476 L
s
.26324 .16661 m
.2659 .16952 L
s
.30285 .1511 m
.30546 .15404 L
s
.3839 .11937 m
.38642 .12239 L
s
.42536 .10313 m
.42784 .10619 L
s
.46747 .08664 m
.4699 .08974 L
s
.51024 .06989 m
.51262 .07303 L
s
.11057 .22639 m
.11338 .22915 L
s
.07378 .2408 m
.07662 .24352 L
s
.03752 .255 m
.0404 .25768 L
s
.59784 .03559 m
.60011 .03881 L
s
.64269 .01803 m
.64491 .02128 L
s
.68828 .00018 m
.69043 .00347 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oa_ooool2
o`0005Sooooo0033ooooo`?o000000?oooooo`000?ooool0Eoooool00<7ooooo0_l00004ooooo`;o
0000Eoooool009cooooo0ol0000Oooooo`?o00001_ooool00ol0003oooooo`00001Fooooo`00Vooo
ool01Ol0003ooooooooooooooooo000001_ooooo0ol00009ooooo`03o`000?oooooo000005Kooooo
002Oooooo`03o`000?oooooooooo01Oooooo0_l0000<ooooo`04o`000?ooooooooooo`0005Gooooo
002Oooooo`03o`000?oooooooooo01Cooooo0ol00002ooooo`03o`000?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`00001Dooooo`00Voooool4o`0001Gooooo0_l0000Aooooo`05o`000?oo
ooooooooooooool00000E?ooool009_ooooo00?o0000ooooooooool04oooool3o`0001?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Aooooo`00Voooool5o`0000oooooo0_l0000F
ooooo`04o`000?ooooooooooooooo`?o0000D_ooool00:cooooo1?l0000Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0D?ooool00:Wooooo0ol0000Kooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Coooool00:Oooooo0_l0000Oooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0C_ooool00:Cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0C_ooool00:;ooooo0_l0000Tooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0COooool009oooooo1?l0000Uooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0C?ooool009gooooo0_l00004ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1<ooooo`00V_ooool3o`0002_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1;ooooo`00V?ooool2o`0002kooooo00?o0000ooooooooool0
1_ooool2o`0004gooooo002Eooooo`?o0000<?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04[ooooo002Booooo`?o00000_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02oooool3o`0003_ooooo002@ooooo`;o0000=_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000j
ooooo`00SOooool3o`0003Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03oooo
o`Go00001Oooool00ol0003oooooooooo`0hooooo`00Roooool2o`0003_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Sooooo0028ooooo`Co0000
??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo1?l0000kooooo`00Q_oo
ool2o`00043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03cooooo001Sooooo`;o00007_ooool3o`0004;ooooo00?o0000ooooooooool03?ooool2
o`0000Sooooo1Ol0000jooooo`00H_ooool01?l0003oooooooooool0000Jooooo`?o0000AOooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooo000004Oooooo001Rooooo`04o`000?oooooooooo
o`0001Sooooo0_l00018ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0A?ooool0
06;ooooo00Co0000oooooooooooo00005Oooool3o`0000;ooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04?ooooo001Rooooo`04o`000?oooooooooo
o`0001?ooooo0_l0001=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@oooool0
06;ooooo00Co0000oooooooooooo00004?ooool3o`0004oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`12ooooo`00Hoooool2o`0000oooooo0_l0001Booooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0@Oooool0077ooooo0ol000000ooooooo0000ooooo`1Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0@Oooool006kooooo0ol0001Hooooo`03o`00
0?oooooooooo013ooooo0_l00012ooooo`00K?ooool2o`0005_ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0oooooo`00JOooool3o`0005gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0oooooo`00Ioooool3o`0005oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0nooooo`00I?ooool3o`0000?ooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo03gooooo001Rooooo`;o0000IOooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03gooooo001Oooooo`?o0000Ioooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo03cooooo001Mooooo`;o0000J_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo03_ooooo001Jooooo`?o00000_ooool00ol0003oooooooooo`1Woooo
o`03o`000?oooooooooo01Gooooo0_l0000mooooo`00Eoooool3o`0006oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0jooooo`00EOooool2o`0007;ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0iooooo`00D_ooool3o`0007Cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0iooooo`00D?ooool2o`0000;ooooo00?o0000ooooooooool0L_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Sooooo000/ooooo`?o00007_ooool3o`00
07Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0hooooo`00:oooool01Ol0003o
oooooooooooooooo000001_ooooo0_l0001looooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0=oooool002Gooooo1Ol00005ooooo`03o`000?oooooooooo01Kooooo0ol0001nooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0=_ooool002oooooo00?o0000ooooooooool0
4oooool3o`000003ooooool0003ooooo07kooooo00?o0000ooooooooool06_ooool2o`0003Sooooo
000[ooooo`Co00005?ooool2o`0008?ooooo0ol0000Mooooo`03o`000?oooooooooo03Gooooo000[
ooooo`03o`000?oooooooooo01;ooooo0ol00024ooooo`04o`000?oHT03o0000o`0001kooooo00?o
0000ooooooooool0=?ooool002_ooooo1Ol0000>ooooo`;o0000Q_ooool00ol0003of900omR@0002
o`0001kooooo00?o0000ooooooooool0=?ooool003_ooooo0ol000000ooooooo0000ooooo`25oooo
o`06o`000?oHT03of900o`000?oHT03o00007_ooool00ol0003oooooooooo`0cooooo`00>Oooool2
o`0008[ooooo00Oo0000omR@0?oHT03of900o`000?oHT03o000001oooooo00?o0000ooooooooool0
<_ooool003Kooooo0ol0002;ooooo`03o`000?oHT03of90000;of90000Co0000omR@0?oHT03o0000
7_ooool00ol0003oooooooooo`0booooo`00<oooool3o`0008gooooo00?o0000omR@0?oHT0001?oH
T0000ol0003of900o`00000Nooooo`;o0000<oooool0037ooooo0_l000000ooooooo0000ooooo`2<
ooooo`;o00001_oHT0000ol0003of900o`00000Pooooo`03o`000?oooooooooo033ooooo000^oooo
o`?o00001?ooool00ol0003oooooooooo`29ooooo`04o`000?oVH`3oiV<0o`0000Gof90000Co0000
omR@0?oHT03o00007oooool00ol0003oooooooooo`06ooooo`;o0000:?ooool002cooooo0_l0002B
ooooo`05o`000?oVH`3oiV<0onIS0?l000001OoHT0001?l0003of900o`000?l0000Pooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00009oooool002Wooooo0ol0002Cooooo`03o`00
0?oVH`3oiV<000;oiV<000?o0000omR@0?oHT0000ooHT002o`0000;oiV<000?o0000ooooooooool0
7_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0002Oooooo000Wooooo`;o0000
00?oooooo`000?ooool0T_ooool00ol0003oiV<0onIS0004onIS0003o`000?oHT03of90000;of900
00Go0000onIS0?oVH`3oiV<0o`00000Pooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00009oooool002Cooooo0ol0002Fooooo`03o`000?oVH`3oiV<000GoiV<000Co0000omR@0?oH
T03of9000_l00003onIS0003o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Wooooo`008_ooool2o`0009Oooooo0_l00008onIS0006o`000?oHT03of900
o`000?oVH`3o00001?oVH`000ol0003oooooooooo`0Nooooo`;o00000oooool01?l0003ooooooooo
ool0000Wooooo`007oooool3o`0009Sooooo00?o0000onm10?l000002OoVH`02o`0000;oiV<000?o
0000onIS0?oVH`000_oVH`000ol0003oooooooooo`0Mooooo`03o`000?oooooo000000Cooooo0_l0
000Xooooo`007?ooool3o`000003ooooool0003ooooo09Oooooo00Go0000onm10?o_@@3okd40o`00
0007onIS00;o00000ooVH`000ol0003oiV<0onIS0002onIS0003o`000?oooooooooo023ooooo00?o
0000ooooooooool0:oooool001[ooooo0_l0002Looooo`03o`000?o_@@3okd4000;okd4000?o0000
onIS0?oVH`001?oVH`000ol0003ol3h0o`000002onIS00;o00001OoVH`000ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02[ooooo000Gooooo`?o0000WOooool00ol0003okd40onm10004onm1
0003o`000?oVH`3oiV<000;oiV<000?o0000oo0n0?o`?P000ol000000ooVH`3o0000onIS0003onIS
00;o00008_ooool00ol0003oooooooooo`0Zooooo`005_ooool2o`0009gooooo0_l00008onm10003
o`000?oVH`3oiV<000Co000000?ol3h0o`000?oVH`000_oVH`001_l0003oiV<0onIS0?l0003okd40
o`0002?ooooo00?o0000ooooooooool0:Oooool001Kooooo0ol0002Jooooo`;o000000?omRT0o`00
0?o_@@001oo_@@04o`0000Gol3h000Co0000onIS0?oVH`3oiV<00_l00003onm10003o`000?oooooo
oooo027ooooo00?o0000ooooooooool0:?ooool001Kooooo00Co0000oooooooooooo0000V?ooool0
0ol0003omRT0ooHY0002ooHY0003o`000?o_@@3okd4000?okd401?l00008oo0n0003o`000?oVH`3o
iV<000;o00000oo_@@000ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo000>oooo
o`;o00001_ooool01Ol0003ooooooooooooooooo000009Gooooo0_l00005ooHY0003o`000?o_@@3o
kd4000Go000000?omRL0o`000?o`?P001oo`?P001Ol0003oiV<0o`000?o_@@3o000000Cokd4000?o
0000ooooooooool07oooool3o`0002Wooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2@ooooo`;o00001oof:@03o`0000;okd4000?o
0000ooHW0?of9`000_of9`000ol0003ol3h0oo0n0005oo0n00;o00000oo_@@000ol0003okd40onm1
0002onm10003o`000?oooooooooo027ooooo00?o0000ooooooooool09_ooool000gooooo00Co0000
oooooooooooo00001?ooool2o`0000Gooooo00?o0000ooooooooool0S?ooool3o`000003ooTM0?l0
003omRT000?omRT00ol000000oof:@3o0000onm10002o`0000GomRL000?o0000oo0n0?o`?P000oo`
?P02o`000003ooHW0?l0003okd4000?okd4000Go0000onm10?o_@@3okd40o`00000Sooooo`03o`00
0?oooooooooo02Kooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`29ooooo`;o00001Ooi7@001?l0003omRT0o`000?l00004ooHY00;o
00002?of9`001Ol0003ol3h0oo0n0?o`?P3o000000ComRL000?o0000onm10?o_@@000_o_@@000ol0
003okd40onm10002o`0002?ooooo00?o0000ooooooooool09Oooool000gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Kooooo0_l00006ooTM
00?o00001?of:@02o`000003ooTK0?l0003omRL000OomRL000Co0000oo0n0?l0003o00001Oof9`00
0ol0003okd40onm10002onm100?o000000?omRT0o`000?ooool08_ooool00ol0003oooooooooo`0U
ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0P_ooool3o`000003ooTJ0?l0003onAd000;onAd00ol00002ooTM0005o`000?of:@3o
mRT0ooHY0?l000001?oi6`000ol0003omRL0ooHW0005ooHW00;o00002?of9`001?l0003okd40onm1
0?o_@@02o`0000?omRT000?o0000ooooooooool08Oooool00ol0003oooooooooo`0Tooooo`003_oo
ool2o`0000Cooooo0_l0000:ooooo`03o`000?oooooooooo07oooooo0_l00005ooTJ00?o00001Ooi
7@001?l0003omRT0o`000?l00005ooTK0003o`000?of9`3omRL000?omRL00_l000000ooi6`3o0000
ooHW0007ooHW0004o`000?o_@@3o0000o`0000;omRT000Co0000ooHY0?of:@3o00009?ooool00ol0
003oooooooooo`0Sooooo`005Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07co
oooo0_l00004ooTJ00?o000000?onAX0o`000?oi7@001Ooi7@02o`0000SonA/000Go0000ooHW0?of
9`3omRL0o`000004ooTK0003o`000?of9`3omRL000GomRL00_l00004ooHY0005o`000?of:@3omRT0
ooHY0?l000008_ooool2o`0002Gooooo000Dooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0N?ooool3o`0000;on1d01?l00005ooTJ0003o`000?oi7@3onAd000?o00000_oi6P000ol0
003onA/0ooTK0005ooTK0004o`000?of9`3o0000o`0000GonA/000?o0000ooHW0?of9`000oof9`02
o`000003ooTK0?l0003omRT000ComRT000Co0000ooHY0?of:@3o00009?ooool00ol0003ooooooooo
o`0Rooooo`005?ooool2o`0000gooooo00?o0000ooooooooool0Loooool4o`0000?on1d01?l00006
ooTJ00Co00001_oi6P000ol0003onA/0ooTK0004ooTK00;o00002?oi6`001Ol0003omRL0ooHW0?of
9`3o000000ConA/000?o0000ooHY0?of:@000oof:@001?l0003omRT0o`000?l0000Tooooo`03o`00
0?oooooooooo027ooooo000Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Kooo
ool3o`0000?omRH01?l00004ooPM0003o`000?oi6P3onAX000?o00000oog8P000ol0003onAX0ooTJ
0005ooTJ0003o`000?oi6`3onA/000?o00000_oi6`000ol0003onA/0ooTK0005ooTK0004o`000?of
9`3o0000o`0000KonA/000Co0000ooHY0?of:@3omRT00ol000000ooi7@3o0000ooooo`0Sooooo`03
o`000?oooooooooo027ooooo000Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
J_ooool4o`0000ComRH01?l00004ooPM00Go00001oog8P000ol0003onAX0ooTJ0002ooTJ00Go0000
1_oi6`000ol0003onA/0ooTK0004ooTK00;o00002?oi6`001?l0003omRT0o`000?l00002ooTM0004
o`000?oi7@3onAd0o`0002Cooooo00?o0000ooooooooool08?ooool001Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1Sooooo`Oo00000ooc<@04o`000003ooHV0?l0003o000000Go
00001?od;`000ol0003omb80ooLR0004ooLR00Ko00001?og9@000ol0003onA/0ooTK0005ooTK0003
o`000?oi6`3onA/000?o000000?onA/0o`000?oi6`001ooi6`02o`0000GonAd000Co0000ooTM0?oi
7@3o00009?ooool00ol0003oooooooooo`0Oooooo`004oooool2o`0001;ooooo0_l0001Oooooo`Wo
00001?oc<@06o`0000Gol3l00_l00005oo@_0003o`000?og8P3omb8000?o00000oob=P000ol0003o
mbD0ooLU0005ooLU0003o`000?oi6`3onA/000;onA/01Ol00005ooTK0003o`000?oi6`3onA/000;o
nA/00ol000000ooi6P3o0000ooTM0005ooTM0003o`000?oi7@3o000002?ooooo0_l0000Qooooo`00
4oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Sooooo1ol00003oo0m00Oo0000
1Oo[D0000ol0003ol3l0oo0o0002oo0o00co00001_ob=P000ol0003ombD0ooLU0002ooLU00Oo0000
1?of9P000ol0003onA/0ooTK0004ooTK0004o`000?oi6`3o0000o`0000GonAX000?o0000ooTM0?oi
7@001?oi7@03o`0002Cooooo00?o0000ooooooooool07_ooool001?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Dooooo`Go00000_o]BP06o`000003onIQ0?l0003o000000ko0000
1OoWH0000ol0003okDX0one:0002one:00go00001?oa>@000ol0003omRH0ooHV0005ooHV0004o`00
0?oi6`3onA/0ooTK00Go00001ooi6P001?l0003onAd0ooTM0?oi7@03o`000003ooTJ0?l0003ooooo
02Cooooo00?o0000ooooooooool07Oooool001?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`1@ooooo`[o00001?oRL@0Qo`000003onA[0?l0003oje4000Coje4000?o0000oo4i0?oa
>@001?oa>@000ol0003omRH0ooHV0002ooHV00Ko00001Oog9@000ol0003onAX0ooTJ0004ooTJ0004
o`000?oi7@3o0000o`0000?onAX000?o0000ooTJ0?l000009?ooool00ol0003oooooooooo`0Moooo
o`004oooool2o`0001Oooooo00?o0000ooooooooool0Boooool4o`0000?ojUD02ol00003o`0B;003
o`000?l042[o010Z00?o00000_l02R@01?l0003o00/Uo`0;9Ol02bD6o`0000?o00/U00?o0000o`0B
;?l04R`00ol04R`Fo`0000ColCT000?o0000ooLU0?og9@001Oog9@001?l0003onAX0ooTJ0?oi6P04
o`0000KonAX000?o0000ooTJ0?l000009?ooool00ol0003oooooooooo`0Looooo`002_ooool3o`00
00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`?o00000_oWGP0>o`00
00Go018/0ol00005o`0:90Co00001?l01b400ol0003o00/Uo`0;9@03o`0;9@03o`000?l04Rco018/
00?o018/00Go0000o`0M=?l07CCo01ddo`000002o`0_?`_o000000?ojU@0o`000?oa>@001Ooa>@00
0ol0003ombD0ooLU0002ooLU00Ko00001?og8P000ol0003onAX0ooTJ0004ooTJ00;o00009Oooool0
0ol0003oooooooooo`0Kooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0@Oooool>o`0000;o03I31?l000000ol08cSo0000o`000002o`00
0004o`0B;?l0003o0000o`0000?o00/U00?o0000o`0:9?l000000_l00002o`068003o`000?l01b7o
00LQ00Co00LQ00Co0000o`0;9Ol02bGo00/U3Ol00004o`0_?`03o`000?l0BTgo000001;o00001?ob
=P000ol0003omb80ooLR0004ooLR0003o`000?oi6P3onAX000;onAX01?l0000Tooooo`03o`000?oo
oooooooo01_ooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0kooooo`Go00000_oUI@05o`000005o`1OA?l0003o051>o`1@C_l000000_l0
=T<3o`0000;o02<h0_l00003o`0F;`?o00001Ol02bD2o`0000Ko00HP00Co0000o`078Ol01b7o00LQ
1_l00003o`0:9003o`000?l042[o010Z00;o010Z00Co0000o`0K<ol06c?o01/c1Ol000000ol0;coo
0000o`1:C@02o`1:C@go000000?oje40o`000?ob=P001Oob=P001?l0003omb80ooLR0?og8P07o`00
00;on1d00_l0000Tooooo`;o00007?ooool000_ooooo00?o0000ooooooooool01?ooool2o`0001co
oooo00?o0000ooooooooool0=oooool3o`0000;oi6X04ol000000ol08cSo0000o`000003o`0F;`;o
00000ol03bT00ol0003o00/Uo`000002o`0000;o00LQ00?o0000o`068?l01R000ol01R04o`0000Co
00HP00?o0000o`0:9?l02R@00ol02R@00ol0003o010Zo`0@:P02o`0@:P03o`000?l06c?o01/c00;o
01/c00?o0000o`0]?_l0;Ch01Ol000000ol0BTgo0000o`1KA`08o`0000;oi6/03?l00003oo@_0003
o`000?oh7@3on1d000Con1d00_l0000Uooooo`03o`000?oooooooooo00Cooooo0ol0000Booooo`00
2oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
<ooooolAo`0000;o05I;1?l00003o`0]?PCo000000?o01H_o`000?l000001Ol03bT2o`0000Ko00LQ
00?o0000o`068?l000000_l00002o`057P03o`000?l01R3o00HP00Co00HP00Co0000o`0:9?l02RCo
00XT1ol00005o`0K<`05o`000?l0;Cko02dno`0]?_l000000_l0B4`3o`0000?o05]72_l000000ooT
J`3o0000one:0003one:0003o`000?od;`3om2l000Com2l000?o0000ooPM0?oh7@001?oh7@02o`00
02Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000017ooooo000:oooo
o`;o00001_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02oooooo0ol00002onA[
00;o000000?oeYP0o`000?l000001_l000001?l0I3oo0000o`000?l0ET/3o`000003o`13BOl0003o
02dn00;o02dn00Co0000o`0O=_l07cKo01lf0ol00004o`0?:@;o00000_l02bD00ol0003o00LQo`07
8@03o`078@;o00001_l01Ah01?l0003o00HPo`068?l01R06o`0000;o00/U00Co0000o`0B;?l04Rco
018/2_l000000ol0;Cko0000o`18C003o`18C0;o000000?o05]7o`000?l0K3H03_l000000oo]BP3o
0000oo@_0005oo@_0003o`000?oh7@3on1d000;on1d01?l0000Tooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03oooool000_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02_ooooo1?l00002onA[00_o00000_l0I3l4o`0000?o04=9
00Go0000o`0]?_l0;Cko02dno`000003o`0O=P04o`000?l05Roo01H_o`0F;`;o000000?o00lYo`00
0?l02bD01?l02bD00ol0003o00LQo`000002o`0000;o00HP00?o0000o`057_l01Ah00ol01Ah4o`00
00?o00LQ00?o0000o`0;9Ol02bD00ol02bD01Ol0003o018/o`0B;?l04Rco000000Go01dd00?o0000
o`0_?ol0;cl00ol00003o`18C003o`000?l0FTSo000000;o00000_l0K3H;o`000003onMP0?l0003o
000000_o00000_of9P000ol0003omRH0o`00000Tooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03oooool0017ooooo0_l0000Qooooo`03o`000?oooooooooo02Sooooo0_l00004onAZ
01So000000?o02dno`000?l07cH00_l07cH00ol0003o01H_o`0F;`03o`0F;`;o00001_l02bD2o`00
00Ko00HP00?o0000o`057_l000000_l000000ol01R3o0000o`078@05o`078@03o`000?l02bGo00/U
00?o00/U00Go0000o`0B;?l04Rco018/o`000005o`0M=003o`000?l0;coo02lo00;o02lo0_l00002
o`18C004o`000?l0FTSo05Y8o`1JB0;o00000_l0K3H=o`000003onMP0?l0003ol3l000Gol3l000?o
0000ooHV0?of9P000_of9P000ol0003omRH0o`00000Sooooo`04o`000?ooooooooooooooo`Co0000
4_ooool001;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Uooooo`;o00000ooT
JP0@o`0000;o05i500Go0000o`1ACOl0DDgo055=o`000003o`0mA`Co000000?o01lfo`000?l05Rl0
1?l05Rl01?l0003o018/o`0B;?l00003o`0;9@;o00000_l02R@00ol0003o00HPo`068003o`0680;o
00001Ol01R000ol0003o00LQo`078@03o`078@04o`000?l02bGo00/Uo`0;9@So00001Ol07C@01_l0
003o02loo`0_?ol0;coo0000o`1:C@?o00000ol0FTP00ol0003o06/go`000002o`000003o`1m6Ol0
003o000001[o00008_ooool2o`0000;ooooo00?o0000ooooooooool04oooool0017ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Roooooa3o000000Ko07/Mo`000?l0003o0000o`1/
=_l00002o`1NA@03o`000?l0DDgo055=00;o00000ol0?DL01?l0003o02dno`0]?_l0;Ch3o`0000?o
01H_0_l00004o`0B;003o`000?l02bGo000000Go00XT00?o0000o`068?l000000_l000000ol01b7o
0000o`068005o`068004o`000?l01b7o00LQo`078@Go00000ol03bT01?l0003o01H_o`0F;ol05Rl9
o`0000;o02lo00Co0000o`1:COl0BTgo04Y=0ol000001?l0FTSo0000o`1[=ol0JcL2o`0000;o07dI
1_l000000oo5`P3o0000o`000005o`0000Goje0000Go0000oo<a0?oc<@3olc40o`000002oo<a0003
o`000?oooooooooo01kooooo00Go0000oooooooooooo0000ooooo`05o`00017ooooo000Aooooo`;o
00009?ooool2o`0001oooooo0ol00002onEU00[o000000?o1X`0o`000?l000000_l00003o`1/=P04
o`000?l0GTGo05i5o`0000;o055=00?o0000o`0mAol0?DL00_l0?DL01Ol0003o02dno`0]?_l0;Cko
000000?o02<h00?o0000o`0F;ol000001_l04R`2o`0000Ko00XT0_l00005o`078@03o`000?l01R3o
00HP00?o00HP1?l00002o`0;9@03o`000?l03bWo00lY00Co00lY00Go0000o`0F;ol05Roo01H_o`00
0005o`0S>003o`000?l0=T?o000000;o00000ol0BTd00ol0003o05]7o`1KA`03o`0000?o06/g0_l0
0002o`1m6@Oo000000?oaL80o`000?l000001ol000000oo[D03o0000oo<a0002oo<a0004o`000?oc
<@3olc40o`0002;ooooo00?o0000ooooooooool05Oooool0017ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Iooooo`Co00000_oUI@0;o`000003o`J<0?l0003o000000ko00000_l0
?DL01Ol0003o02dno`0]?_l0;Cko000000Go02<h00?o0000o`0B;?l04R`01?l04R`00ol0003o010Z
o`000004o`0:90;o000000?o00/Uo`000?l01b401Ol01b400ol0003o00HPo`000002o`000003o`0:
9?l0003o00/U00Co00/U00?o0000o`0?:Ol03bT00ol03bT00ol0003o01H_o`0F;`02o`0F;`03o`00
0?l08cSo02<h00?o02<h00Co0000o`0f@ol0=T?o03I30ol000000ol0BTgo0000o`1KA`03o`1KA`;o
000000?o06/go`000?l0O1/00ol000000ol?T03o0000o`00000;o`0000;oiV402_l0000Rooooo`03
o`000?oooooooooo01Cooooo000Aooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
5_ooool2o`0000Coieh02_l000000oldW@3o0000o`000003o`0000?o07DW00Co0000o`1X>ol0J3_o
00000ol0FdL01?l0003o055=o`1ACOl0DDd4o`000003o`0]?_l0003o02<h00Co02<h00?o0000o`0M
=?l000000ol04R`2o`0000?o010Z00Co0000o`0:9?l0003o00001?l02bD00ol0003o00LQo`078@03
o`078@;o00001Ol02R@00ol0003o00/Uo`0;9@03o`0;9@03o`000?l03bWo00lY00;o00lY00?o0000
o`0F;ol05Rl00ol05Rl00ol0003o02<ho`0S>002o`0S>005o`000?l0=T?o03I3o`0f@ol000000_l0
D4h3o`0000?o05]700?o0000o`1/=_l000000_l00002o`1l6`;o00000_l?T009o`000003omBK0?l0
003o000000;o00000_oVH@001?l0003ol3d0oo0m0?l00002oo0m0003o`000?oooooooooo027ooooo
00?o0000ooooooooool04oooool0017ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Cooooo`;o00000ooWGP09o`000003off^0?l0003o000000Co000000?o08@;o`000?l0MBL00_l0
MBL01?l0003o06Pko`1X>ol00003o`1KA`05o`000?l0DDgo055=o`1ACOl000000ol0@dT2o`0000Go
02<h00Oo0000o`0M=?l07CCo01ddo`000?l04Rco000000Go010Z0_l00007o`0;9@03o`000?l01b7o
000000;o000000?o00/Uo`000?l02R@01Ol02R@00ol0003o00/Uo`0;9@02o`0;9A7o00001?l0=T<0
0ol0003o051>o`1@CP02o`1@CP?o000000Co05]7o`000?l0K3Ko06`f0_l00003o`1l6`;o00000_l?
T00;o`000003on9a0?l0003o000000;o00000_o`?@001?l0003ol3d0oo0m0?l0000Rooooo`03o`00
0?oooooooooo01?ooooo000Aooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04?oo
ool<o`0000;o[kl01Ol00002oa^D0003o`000?l0Q0_o000000?o07DW00Co0000o`1X>ol0J3_o0000
0ol0FdL01Ol0003o055=o`1ACOl0DDgo000000?o04=900Co0000o`0f@ol0=T?o00000ol08cP00ol0
003o01ddo`0M=002o`0M=0;o00001Ol042X00ol0003o018/o`000007o`0;9@;o00001Ol02bD00ol0
003o00XTo`0:9003o`0:9003o`000?l02bGo000000;o000000?o018/o`000?l05Rl00ol05Rl00ol0
003o01lfo`0O=P03o`0O=P04o`000?l0;Cko02dno`0]?PGo000000?o03I3o`000?l0D4h00_l0D4h0
0ol0003o05m4o`1OA003o`0000?o06`f0_l000000ol0O1_o0000o`f?0005o`000004odbU0?l0003o
0000oi^j00Go00000ooRL@08o`0002;ooooo00?o0000ooooooooool04_ooool0013ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0=ooooo`;o00000_oZE@02o`0000;ogWh00_l00002
olnY0003o`000?n__`3o000000;o00000_m<Y@001_l0003o6i@0oa^D0?l0003o08@;o`0000?o07DW
00Co0000o`1X>ol0J3_o00000ol0FdL01Ol0003o055=o`1ACOl0DDgo000000?o04=900?o0000o`0f
@ol0=T<00_l0=T<00ol0003o02<ho`000004o`0M=004o`000?l06c?o01/co`0000?o010Z00Go0000
o`0B;?l04Rco018/o`000004o`0;9@;o000000?o00lYo`000?l02bD01Ol02bD01?l0003o00XTo`0:
9?l02R@3o`0000Go018/00?o0000o`0F;ol05Rl00_l05Rl00ol0003o01lfo`0O=P03o`0O=P05o`00
0?l0;Cko02dno`0]?_l000000ol0@dT5o`000003o`1@C_l0003o05m400?o05m40_l000000ol0K3Ko
0000o`1m6@03o`0000?o3Hl01?l000001On=]`3o0000o`000?l0003obk@000Ko000000GohW40o`00
0?o]BP3okDX0o`000002one:0003o`000?oooooooooo01kooooo0_l0000Dooooo`004?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo0_l00002onYE00;o00000ooNOP001?l0
003ocjT0olnY0?o?Z@05o`0000;oC:D000?o0000oa^D0?lKU0004?l000000ol0DDgo0000o`13B@02
o`13B@03o`000?l0=T?o03I300?o03I30ol00003o`0M=003o`000?l06c?o01/c00;o01/c00?o0000
o`0@:_l000001Ol04R`01?l0003o00/Uo`000?l00004o`0?:@03o`000?l02bGo00/U00?o00/U1?l0
0002o`0@:P03o`000?l04Rco018/00?o018/00?o0000o`0F;ol05Rl00ol05Rl00ol0003o01lfo`0O
=P03o`0O=P05o`000?l0;Cko02dno`0]?_l000001?l0@dT00ol0003o05I;o`1FB`03o`0000?o05m4
00?o0000o`1_<Ol000000_l00002o`1m6@;o00001?l=S`03o`0000;oSKL00_l00002ol^d00;o0000
0_oNOP07o`000003one:0?l0003ooooo023ooooo00?o0000ooooooooool04Oooool0013ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`07oooooa7o000000CoQkD0o`000?m<Y@3oC:D0
1_l00002o`214`05o`000?l0Lb_o07<[o`1c:ol000000_l0J3/00ol0003o05i5o`1NA@02o`1NA@?o
000000?o04=9o`000?l0=T<01?l0=T<01ol0003o02loo`0_?ol0;coo0000o`0M=?l000001Ol06c<2
o`0000Ko018/0_l00006o`0?:@04o`000?l02bGo00/Uo`0;9@;o000000?o018/o`000?l042X01?l0
42X00ol0003o018/o`0B;003o`0B;003o`000?l05Roo01H_00;o01H_00?o0000o`0O=_l07cH00ol0
7cH00ol0003o02dno`0]?P02o`0]?P03o`000?l0@dWo04=900;o04=900?o0000o`1FBol0ET/00_l0
ET/3o`000004o`1OA?l0003o06lao`1_<@;o00000ol0OAT2o`0000;o3Hl000?o0000od:Q0?l00000
0_l00002ohfg00;o00000_o;]003o`0000;ogWh000Co0000onYE0?l0003ojUD00ol0000Qooooo`03
o`000?oooooooooo013ooooo000@ooooo`;o0000;_ooool00ol0003oooooooooo`04ooooo`;o0000
0oo]BP000ol0003ohW40on9a0002on9a0003o`000?oDV`3o000000;o000000CoaL80o`000?l0003o
QkD01_l00002o`f?0004o`000?l0PA?o084Co`0000?o07<[00Co0000o`1X>ol0J3_o00001?l0GTD0
1?l0003o05I;o`1FBol0ET/2o`0000Co03I300?o0000o`0_?ol0;cl00ol0;cl00ol0003o01/co`0K
<`03o`0K<`03o`000?l07CCo000000Go018/00?o0000o`0F;ol000001_l03bT01?l0003o00/Uo`00
0?l00004o`0B;003o`000?l042[o010Z00?o010Z00?o0000o`0B;?l04R`00_l04R`01?l0003o01H_
o`0F;ol05Rl=o`0000Go04=900Go0000o`1FBol0ET_o05I;o`000002o`1T?`?o00000ol0Kc42o`00
0003o`1m6Ol0003o3i0000;o000000?o3Hl0o`000?m2X@002_l000000ooJR@3o0000o`000002o`00
0003onYE0?l0003ojUD000;ojUD000?o0000ooooooooool07_ooool00ol0003oooooooooo`0@oooo
o`001_ooool5o`0000Gooooo00?o0000ooooooooool0;_ooool01?l0003oooooooooooooool2o`00
00?okDX00_l00003on9a00Go00000_o5`P06o`0000;o=ih000Co0000o`f?0?l=S`3o00000_l0PA<0
1Ol0003o07<[o`1c:ol0Lb_o000000;o06Pk00?o0000o`1NAOl0GTD00_l0GTD00ol0003o05I;o`1F
B`02o`1FB`06o`000?l0D4ko0000o`000?l0=T?o00001Ol0;cl00ol0003o02dno`000003o`0K<`05
o`000?l07CCo01ddo`0M=?l000000ol04R`01Ol0003o01H_o`0F;ol05Roo000000Go00lY0_l00006
o`0B;003o`000?l042[o010Z00?o010Z00Co0000o`0B;?l04Rco018/1Ol00002o`0S>003o`000?l0
;Cko02dn00?o02dn00Co0000o`0mAol0?DOo03e71Ol000000ol0@dWo0000o`1FB`03o`1FB`03o`00
0?l0I3oo06@o00;o06@o0_l000000ol0Kc7o0000o`214`03o`0000;o3i000_l00003od:Q0003o`00
0?n4]03oQ;@000;o00000_o8_002o`0000?ofXT01_l000000ooZE@3o0000ooooo`0Oooooo`03o`00
0?oooooooooo00oooooo0007ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
;oooool5o`0000;okDX000Co0000on9a0?oRL@3ohW402ol000000om[[P3o0000o`000002ocNN0004
o`000?l=S`3o3Hl0o`0000;o084C00Go0000o`1c:ol0Lb_o07<[o`000002o`1X>`03o`000?l0GTGo
05i500;o05i500?o0000o`1FBol0ET/00_l0ET/00ol0003o051>o`1@CP02o`1@CP03o`000?l0;coo
02lo00?o02lo00Oo0000o`0]?_l0;Cko02dno`000?l06c?o000000Go01dd00?o0000o`0B;?l00000
1Ol05Rl00ol0003o00lYo`0?:@02o`000003o`0F;ol0003o018/00Go018/00Co0000o`0@:_l042[o
010Z1_l00002o`0M=003o`000?l08cSo02<h00?o02<h00?o0000o`0]?_l0;Ch00ol0;Ch01Ol0003o
03e7o`0mAol0?DOo000000?o055=1?l00002o`1FB`03o`000?l0I3oo06@o00;o06@o00?o0000o`1d
:Ol000000_l00002o`214`;o00000ol?T002o`0000;o@Z400_l00002ohBd00;o00000_o8_003o`00
00;ofXT00_l00002onMN00?o00008?ooool00ol0003oooooooooo`0>ooooo`002?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02gooooo0ol00004oo0m00Wo00000oo</@001_l0003o
Y[d0o`000?l0003oJjh0o`0000?o=ih04?l00002o`1NA@03o`000?l0ET_o05I;00;o05I;00?o0000
o`1@C_l0D4h00_l0D4h00ol0003o04Y=o`000003o`0_?`03o`000?l0;Cko02dn00?o02dn00?o0000
o`0M=?l07C@01?l07C@2o`0000Ko01H_00?o0000o`0?:Ol000001?l05Rl00ol0003o018/o`0B;003
o`0B;0Co00000ol06c<00ol0003o01ddo`0M=003o`0M=003o`000?l08cSo02<h00;o02<h00?o0000
o`0]?_l0;Ch00ol0;Ch00ol0003o03e7o`0mA`02o`0mA`03o`000?l0DDgo055=00;o055=00?o0000
o`1NAOl000000_l00005o`1T?`04o`000?l0M2Wo07@Yo`0000Co084C0_l000000ol?T03o0000odBR
000<o`000003omRA0?l0003o000000?o00000ooWGP000ol0003oooooooooo`0Mooooo`;o00004?oo
ool000Wooooo00?o0000ooooooooool00oooool2o`0002cooooo0ol00005oo0m00Oo000000?ofXT0
o`000?l000000_o</@02o`000003ojJm0?l0003o000000So00000ol8S@001?l0003o084Co`214ol0
0004o`1e9`03o`000?l0K3Ko06`f00?o00000ol0ET/00ol0003o051>o`1@CP02o`1@CP07o`000?l0
BTgo04Y=o`1:COl0003o02loo`000005o`0]?P;o00001Ol07C@00ol0003o02<ho`000006o`0F;`;o
00001_l05Rl00ol0003o018/o`0B;002o`000003o`0M=?l0003o01/c00Go01/c00?o0000o`0M=?l0
7C@00ol07C@00ol0003o02<ho`0S>002o`0S>003o`000?l0;Cko02dn00;o02dn00?o0000o`0mAol0
?DL00_l0?DL00ol0003o055=o`1AC@03o`1AC@04o`000?l0GTGo05i5o`1NA@?o00000_l0I3l01?l0
003o07@Yo`1d:Ol0M2T2o`0000;o084C00?o0000oaJB0?l000000_l00003odBR00;o00000_n1]002
o`0000;oa/400_l00003omRA00Co00000_oWGP000ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00gooooo0006ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Y
ooooo`;o00000ooc<@03o`000005oo0m0?l0003o0000o`000?oVH@000_l00002omZ90004o`000?o<
/@3oc;40olba00Ko00000omJZ@001?l0003o;I/0obfK0?l00003o`R=0004o`000?l0PA?o084Co`00
00Co07DW00Go0000o`1/=_l0K3Ko06`fo`000002o`1T?`03o`000?l0ET_o000000Co051>00?o0000
o`1:COl0BTd00_l0BTd2o`0000Go02dn00Co0000o`0_?ol0;coo00000ol07C@01Ol0003o02<ho`0S
>?l08cSo000000?o01H_0_l000000ol07cKo0000o`0F;`05o`0F;`03o`000?l04Rco000000Co01dd
00?o0000o`0K<ol06c<00ol06c<00ol0003o01ddo`0M=003o`0M=003o`000?l08cSo02<h00;o02<h
00?o0000o`0]?_l0;Ch00ol0;Ch00ol0003o03e7o`0mA`02o`0mA`03o`000?l0DDgo055=00;o055=
00Go0000o`1NAOl0GTGo05i5o`000002o`1/=P?o00000ol0M2T00ol0003o08D9o`000003o`0000;o
5Y800_l00004odBR00;o00000_n1]002o`0000;oa/400ol000000ooHT@3o0000onEU0004o`00027o
oooo00?o0000ooooooooool03?ooool000Kooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo02Oooooo0_l00006oo<a017o00000_n?^0001Ol0003oFZT0oeZY0?mJZ@3o0000
00;o;I/000Go0000o`R=0?l8S@3o28d0o`000002o`214`03o`000?l0MBOo07DW00;o07DW00Go0000
o`1/=_l0K3Ko06`fo`000004o`1T?`;o00000ol0D4h00ol0003o04Y=o`1:C@02o`1:C@04o`000?l0
B4co04Q<o`0000?o02dn00?o0000o`0_?ol0;cl00_l0;cl00ol0003o01ddo`000005o`0S>003o`00
0?l05Roo000000Co01lf00?o0000o`0F;ol05Rl00ol05Rl2o`0000Go01dd00?o0000o`0K<ol06c<0
0ol06c<01?l0003o01ddo`0M=?l07C@Ao`000003o`0mAol0003o055=00?o055=00?o0000o`1NAOl0
GTD00_l0GTD00ol0003o06`fo`1/=P02o`1/=P;o00000_l0M2T01?l0003o08D9o`252Ol0Q@T2o`00
00?o5Y800_l00002odBR0003o`000?n4]03o000000;o000000CoaL80o`000?l0003o00000_oFUP04
o`0000?oiFD000?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`001oooool3o`00
00Gooooo00?o0000ooooooooool09Oooool3o`0000Colc401?l00003on]@0005o`000?oQM@3ohGD0
on5e0?l000000ooDW0001?l0003oa/40olK10?l00002ohnh0005o`000?mJZ@3oFZT0oeZY0?l00000
0_l]V`001Ol0003o28d0o`R=0?l8S@3o000000;o084C00?o0000o`1e9ol0MBL00_l0MBL01Ol0003o
06`fo`1/=_l0K3Ko000000Go06@o00Go0000o`1OA?l0003o051>o`000004o`1:C@03o`000?l0B4co
04Q<00;o04Q<00?o0000o`0]?_l000001_l0;cl00ol0003o02<ho`0S>004o`0S>0;o00001_l07cH0
0ol0003o01H_o`0F;`02o`000003o`0S>?l0003o01dd00Go01dd00?o0000o`0K<ol06c<00_l06c<4
o`0000?o02lo00?o0000o`0f@ol0=T<00_l0=T<00ol0003o04=9o`13B@02o`13B@04o`000?l0DDgo
055=o`1AC@Ko000000?o055=o`000?l0GTD00_l0GTD00ol0003o06`fo`1/=P02o`1/=P06o`000?l0
Nago0000o`000?l0M2Wo00001?l0Q@T2o`000003oaJB0?l0003oC:D000;o000000CoA:80o`000?n4
]03oQ;@00_l00002olG200;o00001?oFUP03o`0000;oiFD000?o0000ooooooooool07_ooool00ol0
003oooooooooo`0;ooooo`003_ooool2o`0002Gooooo0_l00003ooHV00Ko00000oo[D002o`0000;o
hGD00_l00002omBL00;o00000_o6`@001?l0003oSkP0ohnh0?l00003oeZY00go00000_l0MBL01Ol0
003o06`fo`1/=_l0K3Ko000000Go06@o00Co0000o`1OA?l0GdCo05m40_l00003o`1:C@03o`000?l0
B4co04Q<00Co04Q<00?o0000o`0_?ol0;cl01?l0;cl2o`0000Go02<h00?o0000o`0]?_l000001_l0
7cH00ol0003o01H_o`000004o`0S>003o`000?l07CCo01dd00?o01dd00?o0000o`0K<ol000000_l0
00000ol0;Cko0000o`0_?`04o`0_?`03o`000?l0=T?o03I300?o03I300?o0000o`13BOl0@dT00_l0
@dT00ol0003o055=o`1AC@02o`1AC@04o`000?l0FdOo05]7o`1KA`Co00000_l0GTD00ol0003o06`f
o`1/=P02o`1/=P03o`000?l0Nago07/M00;o00001?l0Q@T00ol0003o8iL0o`000002o`0000;oC:D0
0_l00004ohBd00;o00000_o5`P03o`0000;oeYH01_l0000Nooooo`?o00003?ooool000kooooo0ol0
000Sooooo`03o`000?of9P3omRH000;omRH00_l000000oof9P3o0000o`000002o`0000;oje0000Go
0000on5e0?oQM@3ohGD0o`000003omBL0004o`000?o6`@3oa/40olK100Wo000000?oE:L0o`000?l]
V`000_l]V`001Ol0003o3Hl0o`f?0?l=S`3o000000;o08@;1?l000000ol0K3Ko0000o`1T?`04o`1T
?`03o`000?l0GdCo05m400;o05m400Go0000o`1KAol0003o04Y=o`000006o`18C0;o00001Ol0;cl0
1?l0003o03I3o`0f@ol00003o`0S>005o`000?l0;Cko02dno`0]?_l000001Ol07cH2o`0000Ko02<h
00?o0000o`0M=?l07C@00_l07C@2o`0000Go02dn00?o0000o`0_?ol0;cl00ol0;cl00ol0003o03I3
o`0f@`02o`0f@`03o`000?l0@dWo04=900;o04=900?o0000o`1ACOl0DDd00ol0DDd01Ol0003o05]7
o`1KAol0FdOo000000;o06Pk0ol00004o`1/=P03o`000?l0Nago07/M00;o07/M0_l00003o`252@03
o`000?lSU`3o8iL000;o00000om<Y@02o`0000;oQ;@000?o0000olK10?l000000ol000000ooFV03o
0000o`000002o`0000?oi6X00_l0000Jooooo`?o000000?oooooo`000?l000003?ooool000kooooo
0_l000000ooHT03o0000ooooo`0Oooooo`?o000000GomRH0o`000?l0003o0000ooHV0002o`0000Co
l3l03ol000000onj`P3o0000ohBd0002ohBd0004o`000?mDY`3oE:L0o`0000?o;I/000Go0000o`f?
0?l=S`3o3Hl0o`000003o`242`04o`000?l0Nago07/Mo`1k7@;o00001?l0I3l00ol0003o05m4o`1O
A002o`1OA004o`000?l0FdOo05]7o`1KA`;o00001Ol0B4`01?l0003o04Y=o`1:COl00003o`0_?`03
o`000?l0=T?o03I300;o03I300?o0000o`0S>?l000001Ol0;Ch00ol0003o01lfo`0O=P02o`000003
o`0]?_l0003o02<h00Go02<h00?o0000o`0M=?l000000_l000000ol0;coo0000o`0]?P04o`0]?P03
o`000?l0;coo02lo00?o02lo00?o0000o`0f@ol0=T<00ol0=T<00ol0003o04=9o`13B@02o`13B@03
o`000?l0DDgo055=00;o055=00?o0000o`1KAol0FdL00_l0FdL00ol0003o06Pko`1X>`02o`1X>`?o
00000_l0K3H01_l0003o07/Mo`1k7Ol0Nago0000o`J<00;o000000?o08D9o`000?lSU`000olSU`02
o`000003odbU0?l0003oSKL000Co00000oo6`@02o`0000?oeYP01?l000000ooTJP3o0000ooooo`0F
ooooo`?o00001Oooool00ol0003oooooooooo`0:ooooo`003_ooool2o`0000;of90000?o0000oooo
ooooool06_ooool3o`000003ooPM0?l0003o000000;o000000?omRH0o`000?l000001Oo`?`001Ol0
003oif00onMP0?oWH03o000000Cog8D000Go0000olnY0?o?Z@3ocjT0o`000002ok[20005o`000?n4
]03oQ;@0ohBd0?l000000_mDY`001Ol0003o;I/0obfK0?l]V`3o000000?o3Hl000Go0000o`242ol0
Q0_o08@;o`000004o`1k7@06o`000?l0M2Wo0000o`000?l0I3oo00001?l0Gd@00ol0003o05]7o`1K
A`02o`1KA`03o`000?l0FTSo000000?o04Q<00?o0000o`1:COl0BTd00_l0BTd00ol0003o02loo`00
0006o`0f@`03o`000?l0;Cko02dn00Co02dn00?o0000o`0O=_l000001?l0;Ch00ol0003o02<ho`0S
>003o`0S>0;o00001Ol0;cl00ol0003o02dno`0]?P03o`0]?P03o`000?l0;coo02lo00;o02lo00?o
0000o`0f@ol0=T<00ol0=T<00ol0003o04=9o`13B@02o`13B@03o`000?l0DDgo055=00?o055=00Go
0000o`1KAol0FdOo05]7o`000004o`1X>`03o`000?l0MBOo07DW00?o00001?l0Nad00ol0003o1X`0
o`J<0002o`0000Co8iL000?o0000oeZY0?l000000_l00003ohfg00;o00001?o6`@02o`0000;oeYP0
0_l000001?oTJ`3o0000o`000?l0000Cooooo`?o00002?ooool00ol0003oooooooooo`0:ooooo`00
3_ooool3o`0000;of9000_l0000Eooooo`Go000000Con1d0o`000?l0003o00000ooh7@03o`0000Co
l3l00_l00002onMP00;o00001?oLQ@001Ol0003ocjT0olnY0?o?Z@3o000000;o^/8000Go0000ohBd
0?n4]03oQ;@0o`000002oeBW0005o`000?l]V`3o;I/0obfK0?l000000ol=S`001Ol0003o08@;o`24
2ol0Q0_o000000Co07/M00?o0000o`1d:Ol0M2T00_l0M2T2o`0000?o05m400?o0000o`1KAol0FdL0
0_l0FdL01ol0003o05Y8o`1JB?l0FTSo0000o`18C?l000001_l0BTd00ol0003o03I3o`0f@`04o`0f
@`;o00001_l0;Ch2o`0000Ko02dn00?o0000o`0S>?l08cP00_l000000ol0=T?o0000o`0_?`04o`0_
?`03o`000?l0;Cko02dn00?o02dn00?o0000o`0_?ol0;cl00ol0;cl00ol0003o03I3o`0f@`0<o`00
0003o`1ACOl0003o05]700?o05]700?o0000o`1X>ol0J3/00_l0J3/00ol0003o07DWo`1e9`02o`1e
9`?o00000_l0Nad01?l0003o1X`0o`J<0?l6S002o`0000?o8iL000?o0000oeZY0?mJZ@000_l00004
ohfg00;o00000_o6`@001Ol0003oeYH0o`000?l0003oeYP000;o00000ooTJ`000ol0003ooooooooo
o`0<ooooo`Co00002oooool00ol0003oooooooooo`0:ooooo`003_ooool00ol0003oooooo`000002
omR@0003o`000?oVH`3o000000;o00003Oooool5o`0000?onAX00ol00004ooPM00;o00000ood;`02
o`000003oo0o0?l0003oif0000;oif0000?o0000omb50?oLQ@000ooLQ@001Ol0003ocjT0olnY0?o?
Z@3o000000;o^/8000Go0000ohBd0?n4]03oQ;@0o`000002oeBW0005o`000?l]V`3o;I/0obfK0?l0
00000ol=S`001Ol0003o08@;o`242ol0Q0_o000000Co07/M00?o0000o`1d:Ol0M2T00_l0M2T01_l0
003o06lao`1_<Ol0003o05m4o`0000Co05]700?o0000o`1JB?l0FTP00ol0FTP00ol0003o04Y=o`1:
C@04o`1:C@;o00001Ol0=T<01?l0003o04=9o`13BOl00004o`0]?P03o`000?l0?DOo000000Ko02dn
00?o0000o`0S>?l000001?l0=T<00ol0003o02loo`0_?`03o`0_?`03o`000?l0;Cko02dn00;o02dn
00Co0000o`0_?ol0;coo02lo1Ol00003o`1@CP03o`000?l0ET_o05I;00;o05I;00Co0000o`1NAOl0
GTGo05i51ol00004o`1X>`03o`000?l0MBOo07DW00;o07DW00?o0000o`242ol0Q0/00ol00003o`J<
0006o`000?ldW@3o0000o`000?lSU`3o00001?mJZ@02o`0000;oSKL000Ko0000olRl0?l0003o0000
olK10?l00002omJF00?o00000ooTJ`000ol0003oooooooooo`09ooooo`?o00004?ooool00ol0003o
ooooooooo`09ooooo`003_ooool00ol0003oooooo`000003omR@0004o`000?oVH`3oiV<0onIS00go
00000ooi7@000ol0003onAX0o`000002o`0000?onAX000Co0000ooPM0?l0003o00001_od;`09o`00
00;og8D000Co0000olnY0?o?Z@3ocjT05Ol000000ol0Q0_o0000o`1k7@03o`1k7@03o`000?l0M2Wo
07@Y00;o07@Y00?o0000o`1_<Ol0Kc400_l0Kc42o`0000?o05]700?o0000o`1JB?l0FTP00ol0FTP2
o`0000Go04Y=00Co0000o`1@C_l0D4ko00000ol0=T<00ol0003o04=9o`13B@02o`13B@04o`000?l0
;Cko02dno`0000?o03e700?o0000o`0]?_l0;Ch00ol0;Ch2o`0000Go03I300?o0000o`0_?ol0;cl0
0ol0;cl01?l0003o02dno`0]?_l0;Ch5o`0000;o04Y=00?o0000o`1@C_l0D4h00ol0D4h00ol0003o
05I;o`1FB`03o`1FB`03o`000?l0GTGo05i500;o05i500Co0000o`1X>ol0J3_o06Pk1?l00002o`1X
>`03o`000?l0MBOo07DW00;o07DW00?o0000o`242ol0Q0/00_l0Q0/2o`0000;o1X`000?o0000ocBM
0?ldW@000_l00004oeZY0006o`000?nK^P3o0000o`000?n=]`3o00000_o8_002o`0000CoeYH00ol0
0002onA[0003o`000?oooooooooo00Gooooo0ol0000Cooooo`03o`000?oooooooooo00Wooooo000>
ooooo`04o`000?ooooooooooo`0000;of90000Go0000onIS0?oVH`3oiV<0o`000004onm10003o`00
0?of:@3omRT000;omRT000?o0000ooTM0?oi7@000_oi7@03o`0000KonAX00ol00005oo@_00;o0000
0oo]BP000ol0003oi6/0onA[0003onA[00So00000one`@000ol0003oQ;@0ohBd0002ohBd0005o`00
0?mJZ@3oFZT0oeZY0?l000000_lgWP001?l0003o6i@0oa^D0?lKU003o`0000;o07/M00?o0000o`1d
:Ol0M2T00_l0M2T00ol0003o06lao`1_<@03o`1_<@05o`000?l0K3Ko0000o`1KAol000001Ol0FTP0
1?l0003o05]7o`1KAol00003o`1:C@03o`000?l0D4ko051>00;o051>00?o0000o`0f@ol000001Ol0
@dT00ol0003o02dno`000004o`0mA`03o`000?l0;Cko02dn00;o02dn00?o0000o`13BOl000001_l0
=T<00ol0003o02loo`0_?`02o`0_?`Co00000_l0B4`00ol0003o04Y=o`1:C@03o`1:C@03o`000?l0
D4ko051>00?o051>00?o0000o`1FBol0ET/00_l0ET/00ol0003o05i5o`1NA@03o`1NA@05o`000?l0
J3_o06Pko`1X>ol000000_l0Lb/3o`0000Co07DW00?o0000o`242ol0Q0/00_l0Q0/01_l0003o6i@0
o`000?l0003o1X`0o`0000?o=9d00_l00003oeZY0003o`000?nK^P3oVkX000;o00001?o8_002o`00
00;oeYH000?o0000onAZ0?l000001?l00003ooooo`?o00005_ooool00ol0003oooooooooo`09oooo
o`003Oooool2o`0000;ooooo00Go0000omR@0?oHT03of900o`000003onIS0003o`000?o_@@3okd40
00;okd4000?o0000ooHY0?of:@000_of:@04o`0000?onAd000?o0000ooTJ0?oi6P000ol00003ooLR
00;o000000?om2l0o`000?l000001?o]BP000ol0003oi6/0onA[0003onA[0005o`000?oISP3ofHh0
omV>0?l000000_o=[`001Ol0003o]L40okG10?ne`@3o000000CoQ;@000Go0000oeZY0?mJZ@3oFZT0
o`000002ocNN0003o`000?lKU03o6i@000;o6i@000?o0000o`J<0?l6S0000ol00003o`1d:@03o`00
0?l0Kc7o06la00?o06la00Go0000o`1/=_l0K3Ko06`fo`000005o`1JB003o`000?l0FdOo05]700;o
05]700?o0000o`1:COl000001Ol0D4h2o`0000Oo04=900?o0000o`0mAol0?DL01?l0?DL01?l0003o
02dno`0]?_l00003o`13B@03o`000?l0=T?o03I300?o03I300?o0000o`0_?ol000000_l000000ol0
BTgo0000o`18C004o`18C003o`000?l0BTgo04Y=00;o04Y=00?o0000o`1@C_l0D4h00ol0D4h00ol0
003o05I;o`1FB`03o`1FB`03o`000?l0GTGo05i500;o05i500?o0000o`1X>ol0J3/00_l0J3/00ol0
003o07<[o`1c:`02o`1c:`?o00000_l0MBL00ol0003o08@;o`242`02o`242`03o`000?lKU03o6i@0
00;o00000oldW@000ol0003oKJh0o`000002o`000003oeZY0?l0003oVkX000;oVkX00_l00002olRl
0003o`000?oHT@3o000000?o000000Coi6X0o`000?oTJP3oi6X01?l0000Iooooo`03o`000?oooooo
oooo00Wooooo000=ooooo`03o`000?oooooooooo00;ooooo0_l000000ooHT03o0000onIS0002onIS
0003o`000?o_@@3okd4000?okd4000?o0000ooHY0?of:@000ol00005ooTM00?o00001oog8P05o`00
00;okDX000?o0000onA[0?oTJ`000_oTJ`02o`0000;ofHh00_l00002olf_0005o`000?ne`@3o]L40
okG10?l000001?n4]0001Ol0003oFZT0oeZY0?mJZ@3o000000;o=ih000?o0000oa^D0?lKU0000_lK
U0001Ol0003o1X`0o`J<0?l6S03o000000;o08D900?o0000o`1d:Ol000001Ol0Kc400ol0003o06`f
o`1/=P02o`1/=P;o00000ol0FTP00ol0003o05]7o`1KA`04o`1KA`03o`000?l0D4ko051>00?o051>
00?o0000o`1FBol000001_l0@dT2o`0000Ko03e700?o0000o`0]?_l000001?l0@dT00ol0003o03I3
o`0f@`03o`0f@`;o00001Ol0BTd00ol0003o04Q<o`18C002o`18C003o`000?l0BTgo04Y=00?o04Y=
00?o0000o`1@C_l0D4h00_l0D4h00ol0003o05I;o`1FB`03o`1FB`03o`000?l0GTGo05i500;o05i5
00?o0000o`1X>ol0J3/00_l0J3/00ol0003o07<[o`1c:`02o`1c:`03o`000?l0PA?o084C00?o0000
1?l0Q0/00ol0003o6i@0oa^D0002oa^D00;o00000_ldW@001?l0003oKJh0off^0?m][P02o`0000?o
VkX000?o0000ol^d0?l000000ol00003omRA00?o00001?oTJP000ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Wooooo000=ooooo`03o`000?oooooooooo00;ooooo00Co0000onIS0?l0003o
00001?oVH`000ol0003okd40onm10002onm100?o00000oof:@000ol0003onAd0o`000002o`0000?o
nAX00_l00003ooLR00;o00001Oob=P04o`0000;oi6/000Go0000omV>0?oISP3ofHh0o`000003olf_
0005o`000?ne`@3o]L40okG10?l000001?n4]0001Ol0003oFZT0oeZY0?mJZ@3o000000;o=ih000?o
0000oa^D0?lKU0000_lKU0001Ol0003o1X`0o`J<0?l6S03o000000Co08D90_l00004o`1_<@03o`00
0?l0K3Ko06`f00;o06`f00Ko0000o`1[=ol0JcOo0000o`1JB?l00006o`1KA`;o00001?l0D4h01Ol0
003o05I;o`1FBol0ET_o000000Co04=900Co0000o`1ACOl0DDgo00001Ol0?DL2o`0000Ko04=900?o
0000o`0f@ol0=T<00_l000000ol0D4ko0000o`1:C@04o`1:C@03o`000?l0B4co04Q<00?o04Q<00?o
0000o`1:COl0BTd00_l0BTd00ol0003o051>o`1@CP03o`1@CP03o`000?l0ET_o05I;00;o05I;00?o
0000o`1NAOl0GTD00ol0GTD00ol0003o06Pko`1X>`02o`1X>`03o`000?l0Lb_o07<[00;o07<[00?o
0000o`214ol0PA<00_l0PA<3o`0000;o08@;00Ko0000oa^D0?lKU03o6i@0o`000?m<Y@02o`000003
ocBM0?l0003oKJh000?oKJh00_l00002oi^j0004o`000?o;]03obk@0ol^d00;o00001?oHT@05o`00
0003onAZ0?l0003ooooo01Sooooo00?o0000ooooooooool02Oooool000gooooo00?o0000oooooooo
ool00oooool00ol0003oiV<0onIS0005o`000006onm10?l0003o0000o`000?o_@@3o00000oof:@03
o`0000SonAX000?o0000ooLR0?l000001_ob=P000ol0003oje40on]A0002on]A013o00000_n4]000
1Ol0003oFZT0oeZY0?mJZ@3o000000;o=ih000?o0000oa^D0?lKU0000_lKU0001Ol0003o1X`0o`J<
0?l6S03o000000Go08D900Ko0000o`214ol0003o0000o`1_<Ol00004o`1/=P03o`000?l0JcOo06/g
00;o06/g00?o0000o`1KAol0FdL01?l0FdL01?l0003o05m4o`1OA?l00002o`1@CP03o`000?l0ET_o
05I;00?o05I;00Co0000o`13BOl0@dWo00000ol0DDd00ol0003o03e7o`0mA`02o`0mA`03o`000?l0
DDgo000000Ko04=900?o0000o`0f@ol000000ol0D4h00ol0003o04Y=o`1:C@04o`1:C@03o`000?l0
B4co04Q<00;o04Q<00Co0000o`1:COl0BTgo04Y=5_l000000ol0J3_o0000o`1c:`03o`1c:`03o`00
0?l0PA?o084C00;o084C00?o0000o`f?0?l=S`000ol00004oa^D0003o`000?m<Y@3oC:D000;o0000
1?m][P001_l0003o[kl0o`000?l0003oVkX0o`0000Cobk@00_l00002omRA0003o`000?oUI@3o0000
00;oiFD00ol0000Hooooo`03o`000?oooooooooo00Wooooo000=ooooo`;o00001?ooool01?l0003o
iV<0onIS0?l00002oo0n00_o00000ooi6`000ol0003onAX0ooTJ0005ooTJ00?o00001?ob=P02o`00
00Coje4000Go0000on9a0?oRL@3ohW40o`000004omRA0005o`000?o=[`3ocJl0olf_0?l000000onj
`P0;o`0000;o6i@000Go0000o`J<0?l6S03o1X`0o`000005o`252@03o`000?l0PA?o084C00;o084C
0_l00003o`1/=P03o`000?l0JcOo06/g00?o06/g00?o0000o`1KAol0FdL00ol0FdL01ol0003o05m4
o`1OA?l0GdCo0000o`1@C_l000001_l0ET/00ol0003o04=9o`000005o`1AC@04o`000?l0?DOo03e7
o`0000?o055=00?o0000o`13BOl0@dT00ol0@dT2o`0000Go051>00?o0000o`1:COl0BTd00ol0BTd0
0ol0003o04Q<o`18C002o`18C0Co00000_l0FdL00ol0003o05m4o`1OA002o`1OA003o`000?l0I3oo
06@o00?o06@o00?o0000o`1/=_l0K3H00_l0K3H01?l0003o07DWo`1e9ol0MBL5o`0000;o07<[00?o
0000o`214ol0PA<00_l0PA<00ol0003o3Hl0o`f?0002o`f?00;o00000_lKU0000ol0003oC:D0odbU
0002odbU00;o00000om][P000ol0003o[kl0ojno0002o`0000Cobk@000So0000omZ90?l0003o0000
omRA0?l0003oiFD0o`0000?oiFD000?o0000ooooooooool05oooool00ol0003oooooooooo`08oooo
o`001?ooool3o`0000Gooooo0_l00006ooooo`03o`000?oVH`3o000000;o00000_o`?P000ol0003o
mRL0ooHW0004ooHW0003o`000?oi6`3onA/000?onA/000?o0000ooTJ0?oi6P000_oi6P02o`0000?o
mbD00_l000000oob=P3o0000on]A0003on]A00;o00000ooRL@000ol0003of940omRA0002omRA0005
o`000?o=[`3ocJl0olf_0?l000000onj`P000ol0003oSkP0ohnh0002ohnh0005o`000?m[[P3oJjh0
of^^0?l000000_m<Y@04o`000003o`J<0?l0003o08D900Co08D900?o0000o`214ol0PA<00_l0PA<0
1_l0003o07dIo`1m6Ol0003o06`fo`0000Go06/g00?o0000o`1/=_l000000ol0FdL00ol0003o05m4
o`1OA003o`1OA003o`000?l0ET_o05I;00Go05I;0_l00006o`1AC@03o`000?l0?DOo000000Co055=
00?o0000o`13BOl0@dT00_l0@dT00ol0003o05I;o`000005o`1@CP03o`000?l0BTgo04Y=00?o04Y=
00?o0000o`18C?l000000_l000000ol0FTSo0000o`1KA`04o`1KA`03o`000?l0GdCo05m400;o05m4
00?o0000o`1T?ol0I3l00ol0I3l00ol0003o06`fo`1/=P02o`1/=P03o`000?l0MBOo07DW00;o07DW
00?o0000o`214ol0PA<00ol00004o`214`03o`000?l=S`3o3Hl000;o3Hl000Ko0000ocNN0?l0003o
0000oa^D0?l00003odbU0006o`000?n7]@3o0000o`000?m][P3o00001?n__`02o`0000?obk@000?o
0000omZ90?oJR@000_l000000ooUI@3o0000onEU0003onEU0003o`000?oooooooooo01Kooooo00?o
0000ooooooooool02?ooool000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo00?ooooo0ol000000ooVH`3o0000oo0n0003oo0n0003o`000?of9`3omRL000ComRL000?o
0000ooTK0?oi6`000ooi6`001?l0003onAX0o`000?l00006ooLU00Co00000_o[D@000ol0003ohW40
on9a0002on9a0003o`000?oHT@3of94000;of94000Go0000olf_0?o=[`3ocJl0o`000003ok[20003
o`000?n?^03oSkP000;oSkP000Go0000of^^0?m[[P3oJjh0o`000004odbU0003o`000?ldW@3o=9d0
00;o00001?l0Q@T00ol0003o084Co`214`02o`214`03o`000?l0OAWo07dI00;o07dI00?o0000o`1[
=ol0JcL00ol0JcL01ol0003o06`fo`1/=_l0K3Ko0000o`1KAol000001_l0Gd@00ol0003o05I;o`1F
B`04o`1FB`03o`000?l0GTGo000000Ko055=0_l00005o`1AC@03o`000?l0@dWo04=900;o00000_l0
ET/00ol0003o051>o`1@CP03o`1@CP03o`000?l0BTgo04Y=00?o04Y=0_l00005o`1JB003o`000?l0
FdOo05]700;o05]700?o0000o`1OA?l0Gd@00_l0Gd@00ol0003o06@oo`1T?`03o`1T?`03o`000?l0
K3Ko06`f00;o06`f00?o0000o`1e9ol0MBL00ol0MBL00ol0003o084Co`214`02o`214`;o00000_l0
PA<00ol0003o3Hl0o`f?0003o`f?0003o`000?lgWP3o=ih000;o00001?m<Y@000ol0003oQkD0ohNe
0002o`0000Co[kl000?o0000olnY0?l000000_l000000oo;]03o0000omZ90002omZ900Go000000?o
iFD0o`000?ooool05oooool00ol0003oooooooooo`08ooooo`001oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?oVH`000_oVH`000ol0003ol3h0oo0n
0002oo0n0003o`000?of9`3omRL000ComRL000Co0000ooTK0?oi6`3onA/01?l00005ooLU00;o0000
1?oa>@04o`0000;ohW4000?o0000omRA0?oHT@000_oHT@001Ol0003ocJl0olf_0?o=[`3o000000?o
^/8000?o0000ohnh0?n?^0000_n?^0001Ol0003oJjh0of^^0?m[[P3o000000CoC:D000Ko0000ocBM
0?ldW@3o=9d0o`000?lSU`02o`000003o`252Ol0003o084C00?o084C00?o0000o`1m6Ol0OAT00ol0
OAT2o`0000?o06/g00?o0000o`1/=_l0K3H00ol0K3H00ol0003o05m4o`1OA004o`1OA003o`000?l0
I3oo000000Co05I;00Go0000o`1NAOl0GTGo05i5o`000004o`1AC@03o`000?l0FdOo000000Ko055=
0_l00005o`1FB`03o`000?l0D4ko051>00?o051>00?o0000o`1:COl000000_l000000ol0FdOo0000
o`1JB004o`1JB003o`000?l0FdOo05]700?o05]700?o0000o`1OA?l0Gd@00_l0Gd@00ol0003o06@o
o`1T?`03o`1T?`03o`000?l0K3Ko06`f00;o06`f00?o0000o`1e9ol0MBL00_l0MBL00ol0003o084C
o`214`02o`214`03o`000?l8S@3o000000?o00001?l=S`000ol0003o=ih0ocNN0002ocNN00?o0000
0_m<Y@001?l0003oQkD0ohNe0?n7]@02o`0000?o[kl000Co0000olnY0?o?Z@3ocjT00_l00003omZ9
0005o`000?oWGP3oieh0o`000?oWGP000ol0000Gooooo`03o`000?oooooooooo00Sooooo0005oooo
o`;o00001Oooool4o`0000Gooooo0_l00002onIS0003o`000?o`?P3ol3h000;ol3h000Co0000ooHW
0?of9`3omRL01_l00004ooTK00;o000000?ombD0o`000?l000001Ooa>@000ol0003ojU@0onYD0002
onYD00Co00000_oHT@001Ol0003ocJl0olf_0?o=[`3o000000?o^/8000?o0000ohnh0?n?^0000_n?
^0001Ol0003oJjh0of^^0?m[[P3o000000CoC:D000Go0000ocBM0?ldW@3o=9d0o`000004ob>G00;o
00000ol0PA<00ol0003o07dIo`1m6@03o`1m6@06o`000?l0O1_o07`Ko`000?l0JcOo00001_l0K3H0
0ol0003o05m4o`1OA003o`1OA005o`000?l0I3oo06@oo`1T?ol000000_l0ET/00ol0003o05i5o`1N
A@02o`1NA@03o`000?l0DDgo055=00;o00000ol0FdL00ol0003o055=o`1AC@02o`1AC@;o00001_l0
ET/00ol0003o051>o`1@CP02o`1@CP?o00001?l0FdL00ol0003o05Y8o`1JB004o`1JB003o`000?l0
FdOo05]700;o05]700?o0000o`1OA?l0Gd@00_l0Gd@00ol0003o06@oo`1T?`03o`1T?`03o`000?l0
K3Ko06`f00;o06`f00?o0000o`1e9ol0MBL00ol0MBL01Ol0003o084Co`214ol0PA?o000000Co28d0
0ol00002o`f?0003o`000?lgWP3o=ih000;o=ih000?o0000of^^0?m[[P000ol00003ohNe0003o`00
0?o5`P3o000000;o000000?o[kl0o`000?o?Z@000oo?Z@03o`000004omZ90?l0003oieh0o`0000?o
ieh000?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`001oooool00ol0003ooooo
ooooo`02ooooo`;o00001oooool00ol0003okd40o`000002o`0000?ol3h01Ol00004ooTK0003o`00
0?oi6`3onA/000ConA/00ol00004oo4i00;o00001?oZE0000ol0003ohW40on9a0002on9a00co0000
0_n?^0000ol0003oJjh0of^^0002of^^0005o`000?m<Y@3oC:D0odbU0?l000000oldW@000ol0003o
8iL0ob>G0003ob>G0005o`000?lFTP3o0000o`214ol000001Ol0OAT00ol0003o07`Ko`1l6`02o`1l
6`03o`000?l0K3Ko06`f00Co06`f00?o0000o`1_<Ol000000ol0Gd@00ol0003o06@oo`1T?`02o`1T
?`03o`000?l0ET_o000000Go05i500?o0000o`1ACOl000001Ol0FdL01ol0003o055=o`1ACOl0DDgo
0000o`1NAOl000001_l0ET/00ol0003o051>o`1@CP02o`000003o`1OA?l0003o05]700Go05]700?o
0000o`1JB?l0FTP00ol0FTP00ol0003o05]7o`1KA`02o`1KA`03o`000?l0GdCo05m400;o05m400?o
0000o`1T?ol0I3l00ol0I3l00ol0003o06`fo`1/=P02o`1/=P03o`000?l0MBOo07DW00?o07DW00?o
0000o`214ol0PA<00_l0PA<01Ol0003o28d0o`R=0?l8S@3o000000;o;I/01?l00004ocNN0003o`00
0?m[[P3oJjh000;oJjh00_l00002ohNe0004o`000?o5`P3oaL80olG200;o00001?o?Z@000ol0003o
gWh0omin0003o`000003onMN0?l0003oieh000;oieh000?o0000ooooooooool05?ooool00ol0003o
ooooooooo`08ooooo`000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool01Oooool01?l0003okd40onm10?o_@@03o`0000;omRL000?o0000ooTK0?oi6`001Ooi6`001?l0
003onA/0ooTK0?oi6`02o`0000?omRH00_l000000ooa>@3o0000onYD0003onYD00;o00001?oRL@00
1Ol0003ofHh0omV>0?oISP3o000000CocjT000Co0000olK10?o6`@3oa/401?l00002of^^0005o`00
0?m<Y@3oC:D0odbU0?l000000oldW@000ol0003o8iL0ob>G0003ob>G0005o`000?lFTP3o5Y80oaJB
0?l000001Ol0OAT00ol0003o07`Ko`1l6`03o`1l6`03o`000?l0K3Ko06`f00?o06`f00Oo0000o`1_
<Ol0Kc7o06lao`000?l0GdCo000000Ko06@o00?o0000o`1NAOl0GTD01Ol0GTD00ol0003o05]7o`1K
A`04o`1KA`04o`000?l0DDgo055=o`0000?o05i500?o0000o`1FBol0ET/01?l0ET/2o`0000Co05m4
00?o0000o`1KAol0FdL00ol0FdL00ol0003o05Y8o`1JB003o`1JB004o`000?l0FdOo05]7o`1KAaKo
000000?o07DWo`000?l0PA<00ol0PA<00ol0003o28d0o`R=0002o`R=0003o`000?l]V`3o;I/000;o
;I/00_l00003ocNN0003o`000?m[[P3oJjh000;oJjh000Ko0000ojJm0?l0003o0000ohNe0?l00004
olG200?o00000_o?Z@000ol0003ogWh0omin0002omin00Go000000?oieh0o`000?ooool05?ooool0
0ol0003oooooooooo`08ooooo`001?ooool3o`0000Sooooo00?o0000ooooooooool01Oooool01?l0
003okd40onm10?l00005ooHW0003o`000?oi6`3onA/000GonA/000?o0000ooTK0?l000001_of9P04
o`0000;ojU@000?o0000on9a0?oRL@000_oRL@02o`0000?ofHh000?o0000olnY0?o?Z@000_o?Z@00
0ol0003oa/40olK10002olK10004o`000?nV_@3oY[d0ojJm00Co000000?oC:D0o`000?ldW@000old
W@000ol0003o8iL0ob>G0002ob>G0003o`000?lFTP3o5Y8000;o5Y800_l00003o`1m6@03o`000?l0
O1_o07`K00?o07`K00?o0000o`1m6Ol000000ol0K3H00ol0003o06lao`1_<@03o`1_<@03o`000?l0
I3oo06@o00Go06@o00?o0000o`1NAOl0GTD01?l0GTD2o`0000Oo05]70_l00004o`1NA@03o`000?l0
ET_o05I;00?o05I;0_l00005o`1OA003o`000?l0FdOo05]700?o05]700?o0000o`1JB?l0FTP00ol0
FTP4o`0000;o06`f00?o0000o`1_<Ol0Kc400_l0Kc400ol0003o07@Yo`1d:@03o`1d:@03o`000?l0
Nago07/M00;o07/M00Co0000o`242ol0Q0_o08@;1?l00002o`214`03o`000?l8S@3o28d000;o28d0
00?o0000obfK0?l]V`000_l]V`001_l0003oFZT0o`000?l0003o=ih0o`0000GoJjh000?o0000ojJm
0?nV_@000_l00004olG20003o`000?oDV`3oe9/000?o00001?oNOP001Ol0003ojUD0onYE0?l0003o
jUD000?o00005?ooool00ol0003oooooooooo`08ooooo`004?ooool00ol0003oooooooooo`04oooo
o`05o`000?o_@@3okd40onm10?l000001Oof9`000ol0003onA/0ooTK0004ooTK00?o00001?of9P02
o`0000ColCT01?l00002on9a0003o`000?oISP3ofHh000;ofHh000?o0000olnY0?o?Z@000_o?Z@00
0ol0003oa/40olK10002olK10003o`000?nV_@3oY[d000;oY[d000Co0000ohNe0?n7]@3oQkD00ol0
0002ocBM0003o`000?lSU`3o8iL000;o8iL000?o0000oaJB0?lFTP000_lFTP001_l0003o3i00o`n@
0?l0003o07dIo`0000Go07`K00Oo0000o`1m6Ol0OAWo07dIo`000?l0K3Ko000000Ko06la00?o0000
o`1T?ol0I3l01?l0I3l00ol0003o06`fo`000004o`1NA@04o`000?l0J3_o06Pko`0000Go05]70_l0
0006o`1NA@03o`000?l0ET_o05I;00;o000000?o06@oo`000?l0Gd@01Ol0Gd@00ol0003o05]7o`1K
A`03o`1KA`03o`000?l0FTSo000000;o000000?o06/go`000?l0K3H01?l0K3H00ol0003o06lao`1_
<@02o`1_<@03o`000?l0M2Wo07@Y00;o07@Y00?o0000o`1k7Ol0Nad00ol0Nad00ol0003o08@;o`24
2`02o`242`03o`000?l=S`3o000000?o00001?l8S@000ol0003o;I/0obfK0002obfK0003o`000?mJ
Z@3oFZT000?o00001?m[[P000ol0003oY[d0ojJm0002ojJm00;o00000oo5`P000ol0003oe9/0omBK
0002omBK00?o00000_oNOP000ol0003ojUD0o`000003onYE0003o`000?oooooooooo01?ooooo00?o
0000ooooooooool01oooool0017ooooo0_l00005ooooo`05o`000?o_@@3okd40onm10?l000001Oof
9`000ol0003onA/0ooTK0003o`0000?onA/00_l000000oof9P3o0000oo4i0004oo4i0003o`000?o[
D@3oje4000;oje401?l00002omV>0003o`000?o?Z@3ocjT000;ocjT000?o0000olK10?o6`@000_o6
`@000ol0003oY[d0ojJm0002ojJm0003o`000?n7]@3oQkD000;oQkD000?o0000off^0?m][P000ol0
0003ob>G0003o`000?lFTP3o5Y8000;o5Y8000?o0000o`n@0?l?T0000_l?T002o`0000Co07`K00?o
0000o`1m6Ol0OAT00ol0OAT00ol0003o06lao`1_<@04o`1_<@03o`000?l0M2Wo000000Co06@o00Go
0000o`1/=_l0K3Ko06`fo`000002o`1NA@05o`000?l0J3_o06Pko`1X>ol000001?l0FdL00ol0003o
06Pko`000006o`1NA@03o`000?l0ET_o000000Co06@o00?o0000o`1OA?l0Gd@00ol0Gd@00ol0003o
05]7o`1KA`02o`1KA`?o00001?l0JcL00ol0003o06`fo`1/=P03o`1/=P03o`000?l0Kc7o06la00;o
06la00?o0000o`1d:Ol0M2T00ol0M2T00ol0003o07/Mo`1k7@02o`1k7@03o`000?l0Q0_o08@;00;o
08@;00?o0000o`f?0?l=S`000_l=S`04o`000003o`R=0?l0003o;I/000?o;I/000?o0000oeZY0?mJ
Z@000_mJZ@03o`0000;oJjh000?o0000ojJm0?nV_@000_nV_@001_l0003oc;40o`000?l0003oaL80
o`0000Coe9/000?o0000on9a0?oRL@001?l000000ooZE@3o0000onYE0002onYE0003o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01oooool001?ooooo00?o0000ooooooooool00oooool5o`00
00?omRL01?l00007ooTK00?o00001?oa>@000ol0003oje40on]A0003on]A0004o`000?oTJ`3oi6/0
onA[00Co00000_o?Z@000ol0003oa/40olK10002olK10003o`000?nV_@3oY[d000;oY[d000?o0000
ohNe0?n7]@000_n7]@001Ol0003oKJh0off^0?m][P3o000000;oFZT000?o0000ob>G0?l000001?lF
TP000ol0003o3i00o`n@0003o`n@0003o`000?l=S`3o000000?o07`K00?o0000o`1m6Ol0OAT00ol0
OAT00ol0003o06lao`1_<@03o`1_<@05o`000?l0M2Wo07@Yo`1d:Ol000000_l0I3l00ol0003o06`f
o`1/=P02o`1/=P03o`000?l0GTGo000000Go06Pk00Co0000o`1KAol0FdOo00000ol0J3/00ol0003o
05i5o`1NA@03o`1NA@;o00001Ol0I3l00ol0003o05m4o`1OA003o`1OA003o`000?l0FdOo000000;o
000000?o06`fo`000?l0JcL01Ol0JcL00ol0003o06`fo`1/=P02o`1/=P03o`000?l0Kc7o06la00?o
06la00?o0000o`1d:Ol0M2T00_l0M2T00ol0003o07/Mo`1k7@03o`1k7@03o`000?l0Q0_o08@;00;o
08@;00Go0000o`f?0?l=S`3o3Hl0o`000003obfK00Go00000_l]V`001Ol0003oFZT0oeZY0?mJZ@3o
000000;oSkP01?l00004ojJm0003o`000?o</@3oc;4000;o00001OoDV`000ol0003ohW40on9a0002
on9a00Go000000?ojUD0o`000?ooool04oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0
003oooooooooo`02ooooo`04o`000?of:@3omRT0ooHY00Co00001?oi6`000ol0003onA/0ooTK0002
ooTK00;o00000oog9@02o`000003oo4i0?l0003oje4000Coje4000?o0000onA[0?oTJ`000_oTJ`00
1?l0003og8D0omb50?oLQ@04o`0000;oa/4000?o0000ojJm0?nV_@000_nV_@000ol0003oQkD0ohNe
0002ohNe0005o`000?m][P3oKJh0off^0?l000001?mJZ@02o`0000Co5Y8000?o0000o`n@0?l?T000
0_l?T0001ol0003o3Hl0o`f?0?l=S`3o0000o`1l6ol000001Ol0OAT00ol0003o084Co`000003o`1_
<@03o`000?l0M2Wo07@Y00;o07@Y00?o0000o`1T?ol000001_l0K3H00ol0003o06Pko`1X>`04o`1X
>`03o`000?l0FdOo000000Co06Pk00?o0000o`1NAOl0GTD00_l0GTD00ol0003o06`fo`000006o`1T
?`03o`000?l0GdCo05m400;o05m40_l00005o`1/=P03o`000?l0JcOo06/g00?o06/g00?o0000o`1/
=_l0K3H00ol0K3H00ol0003o06lao`1_<@02o`1_<@03o`000?l0M2Wo07@Y00;o07@Y00?o0000o`1k
7Ol0Nad00ol0Nad00ol0003o08@;o`242`02o`242`03o`000?l=S`3o3Hl000;o3Hl000?o0000obfK
0?l]V`000_l]V`000ol0003oE:L0oeBW0003o`0000CoFZT000?o0000ohnh0?n?^0000_n?^002o`00
00?oY[d000?o0000olba0?o</@000_o</@03o`0000?oe9/000?o0000on9a0?oRL@000_oRL@000ol0
003okDX0one:0004o`0001?ooooo00?o0000ooooooooool01oooool001Gooooo00?o0000oooooooo
ool00_ooool00ol0003omRT0ooHY0002ooHY0003o`000?oi6`3onA/000ConA/000Co0000ooTK0?l0
003o00001_og9@03o`0000Coje4000?o0000onA[0?oTJ`000_oTJ`000ol0003og8D0omb50002omb5
0004o`000?oDW03oe9`0omBL00Co00000_nV_@000ol0003oQkD0ohNe0002ohNe0005o`000?m][P3o
KJh0off^0?l000001OmJZ@001_l0003oC:D0o`000?l0003o5Y80o`0000Co3i0000?o0000o`f?0?l=
S`000ol=S`000ol0003o07dIo`1m6@03o`1m6@07o`000?l0PA?o084Co`214ol0003o06lao`000006
o`1d:@03o`000?l0K3Ko06`f00Go06`f00?o0000o`1X>ol0J3/01Ol0J3/00ol0003o06Pko`1X>`04
o`1X>`04o`000?l0GTGo05i5o`0000?o06`f00?o0000o`1T?ol0I3l00ol0I3l00ol0003o05m4o`1O
A002o`000003o`1_<Ol0003o06`f00Co06`f00?o0000o`1[=ol0JcL00ol0JcL00ol0003o06`fo`1/
=P03o`1/=P03o`000?l0Kc7o06la00;o06la00?o0000o`1d:Ol0M2T00ol0M2T00ol0003o07/Mo`1k
7@02o`1k7@03o`000?l0Q0_o08@;00;o08@;00?o0000o`f?0?l=S`000_l=S`000ol0003o;I/0obfK
0003obfK0003o`000?mDY`3oE:L000;oE:L00_l00002oeZY0003o`000?n?^03oSkP000;oSkP000?o
0000olK10?l000000_l000000onV_@3o0000olba0002olba0003o`000?oJR@3ofXT000Co00001OoR
L@000ol0003okDX0o`000002one:0003o`000?oooooooooo017ooooo00?o0000ooooooooool01ooo
ool001Kooooo0_l00003ooooo`03o`000?of:@3omRT000;omRT000?o0000ooTK0?oi6`000ooi6`03
o`0000KombD000Co0000oo8f0?ob=P3olSH00_l000000oo[D@3o0000onA[0003onA[0003o`000?oL
Q@3og8D000;og8D000?o0000omBL0?oDW0000_oDW0001?l0003oc;40olba0?o</@04o`0000;oQkD0
00Go0000off^0?m][P3oKJh0o`000005oeZY0003o`000?m<Y@3oC:D000;oC:D00_l00003o`n@0003
o`000?l=S`3o3Hl000?o3Hl000?o0000o`n@0?l000000ol0OAT00ol0003o084Co`214`03o`214`03
o`000?l0M2Wo07@Y00Co07@Y0_l00006o`1/=P03o`000?l0MBOo000000Go06Pk0_l00006o`1X>`03
o`000?l0GTGo000000Co06`f00?o0000o`1T?ol0I3l00ol0I3l00ol0003o05m4o`000004o`1_<@03
o`000?l0K3Ko06`f00?o06`f00?o0000o`1[=ol0JcL00_l0JcL00ol0003o06`fo`1/=P03o`1/=P04
o`000?l0Kc7o06lao`1_<A7o000000?o08@;o`000?l=S`000ol=S`000ol0003o;I/0obfK0002obfK
0003o`000?mDY`3oE:L000;oE:L000Ko0000ohBd0?l0003o0000oeZY0?l00004ohnh0004o`000?o6
`@3oa/40olK100;o00001?o</@000ol0003ofXT0omZ90002omZ900Go000000GohW40o`000?o]BP3o
kDX0o`000002one:0003o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool001Sooooo
00Go0000ooooooooooooooooo`000004ooHY0003o`000?oi6`3o000000;o00000ooi6P001?l0003o
mbD0ooLU0?og9@02o`0000GolSH01?l00002onA[0003o`000?oLQ@3og8D000;og8D000?o0000omBL
0?oDW0000_oDW0000ol0003oc;40olba0002olba0004o`000?o5`P3oaL80olG200Co000000?oKJh0
o`000?mJZ@001?mJZ@000ol0003oC:D0odbU0002odbU0006o`000?m4XP3oA:80o`000?l?T03o0000
1Ol=S`001ol0003o3i00o`n@0?l?T03o0000o`1m6Ol000001_l0PA<00ol0003o07@Yo`1d:@03o`1d
:@04o`000?l0Nago07/Mo`0000Co06`f00Co0000o`1e9ol0MBOo00001?l0J3/01?l0003o07<[o`1c
:ol00005o`1X>`;o00001_l0K3H00ol0003o06@oo`1T?`02o`1T?`;o00001Ol0Kc400ol0003o06`f
o`1/=P03o`1/=P03o`000?l0JcOo06/g00?o06/g00?o0000o`1/=_l0K3H01_l00002o`214`03o`00
0?l0Q@Wo08D900;o08D900?o0000o`J<0?l6S0000ol6S0001?l0003o6i@0oa^D0?lKU004o`0000;o
3Hl000?o0000obfK0?l]V`000ol]V`000ol0003oE:L0oeBW0002oeBW0003o`000?n4]03oQ;@000;o
00001?n?^0000ol0003oa/40olK10003olK100?o00000_o</@000ol0003ofXT0omZ90002omZ90004
o`000?oVH@3oiV40onIQ00Oo000000?okDX0o`000?ooool04?ooool00ol0003oooooooooo`07oooo
o`006Oooool01?l0003oooooooooooooool7o`0000KonAX000?o0000ooLU0?l000001_ob=P000ol0
003okDX0one:0002one:00Co00000_oLQ@000ol0003oe9`0omBL0002omBL0003o`000?o</@3oc;40
00;oc;4000?o0000olG20?o5`P000_o5`P001?l0003o[kl0ojno0?n__`02o`0000CoFZT000?o0000
odbU0?m<Y@000_m<Y@000ol0003oA:80odBR0002odBR0003o`000?l=S`3o3Hl000?o3Hl000?o0000
o`n@0?l?T0000ol?T0000ol0003o084Co`214`04o`214`03o`000?l0Q@Wo000000?o07@Y00?o0000
o`1k7Ol0Nad00_l0Nad01?l0003o06`fo`1/=_l00004o`1e9`04o`000?l0J3_o06Pko`0000?o07<[
00?o0000o`1X>ol0J3/00_l0J3/00ol0003o07DWo`000006o`1/=P03o`000?l0I3oo06@o00;o0000
00?o07@Yo`000?l0Kc401Ol0Kc400ol0003o06`fo`1/=P02o`1/=P04o`000?l0JcOo06/go`1[=`Go
00000ol0OAT00ol0003o084Co`214`03o`214`03o`000?l0Q@Wo08D900;o08D900?o0000o`J<0?l6
S0000ol6S0001Ol0003o6i@0oa^D0?lKU03o000000;o=ih00ol00005obfK0003o`000?mDY`3oE:L0
00;oE:L000?o0000ohBd0?n4]0000_n4]003o`0000;oSkP000?o0000olK10?o6`@000_o6`@000ol0
003oe9`0omBL0003o`0000GofXT000?o0000onIQ0?oVH@000_oVH@001?l0003ol3d0oo0m0?o`?@04
o`00013ooooo00?o0000ooooooooool01oooool001[ooooo00Co0000oooooooooooo00001_oi7@00
0ol0003onAX0ooTJ0003ooTJ00?o00001?ob=P02o`0000CokDX000?o0000onMP0?oWH0000_oWH004
o`0000;oe9`000?o0000olba0?o</@000_o</@000ol0003oaL80olG20002olG20003o`000?n__`3o
[kl000;o[kl000Ko0000oi^j0?l0003o0000oeZY0?l00004odbU0003o`000?m4XP3oA:8000?oA:80
0_l00003o`f?0003o`000?l?T03o3i0000Co3i0000?o0000o`214ol0PA<00ol0PA<01ol0003o08D9
o`252Ol0Q@Wo0000o`1d:Ol000001Ol0Nad00ol0003o06`fo`000005o`1e9`03o`000?l0J3_o0000
00Go07<[00Co0000o`1X>ol0J3_o00000ol0MBL00ol0003o06`fo`1/=P03o`1/=P03o`000?l0I3oo
000000Co07@Y00?o0000o`1_<Ol0Kc400ol0Kc400ol0003o06`fo`1/=P02o`1/=PCo00000_l0O1/0
0ol0003o07dIo`1m6@03o`1m6@03o`000?l0PA?o084C00?o084C00?o0000o`252Ol0Q@T00_l0Q@T0
0ol0003o1X`0o`J<0003o`J<0003o`000?lKU03o6i@000;o6i@000?o0000ocNN0?lgWP000_lgWP04
o`000003obfK0?l0003oE:L000CoE:L000Go0000ohBd0?n4]03oQ;@0o`000002ok[200?o00001Oo6
`@000ol0003oe9`0omBL0002omBL00?o00000_oJR@000ol0003oiV40onIQ0003onIQ0004o`000?o`
?@3ol3d0o`0000;ol3d000?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`006ooo
ool2o`000003ooooool0003onAd000GonAd000?o0000ooTJ0?l000000_l00003ooLR00;o000000?o
lSH0o`000?o]BP001?o]BP000ol0003oif00onMP0002onMP0003o`000?oQM@3ohGD000;ohGD00ol0
0003olba0003o`000?o5`P3oaL8000;oaL8000?o0000ojno0?n__`000_n__`000ol0003oVkX0oi^j
0002oi^j00;o00000om<Y@000ol0003oA:80odBR0003odBR0006o`000?m2X@3o@Z40o`000?l=S`3o
00001_l?T0000ol0003o5Y80o`000003o`214`03o`000?l0Q@Wo08D900?o08D900?o0000o`1k7Ol0
Nad01Ol0Nad00ol0003o07DWo`1e9`05o`1e9`03o`000?l0Lb_o07<[00Co07<[00?o0000o`1X>ol0
00001?l0MBL00ol0003o06`fo`1/=P03o`1/=P;o00001Ol0M2T00ol0003o06lao`1_<@03o`1_<@03
o`000?l0K3Ko000000;o000000?o07dIo`000?l0O1/01?l0O1/00ol0003o07dIo`1m6@03o`1m6@03
o`000?l0PA?o084C00;o084C00?o0000o`252Ol0Q@T00_l0Q@T00ol0003o1X`0o`J<0003o`J<0003
o`000?lKU03o6i@000;o6i@000?o0000ocNN0?lgWP000_lgWP001?l0003oFZT0oeZY0?mJZ@05o`00
00;oE:L000?o0000ohBd0?n4]0000_n4]0000ol0003o^/80ok[20002ok[200?o00000_o6`@000ol0
003oe9`0omBL0002omBL0003o`000?oQM@3ohGD000?o00001_oVH@001?l0003ol3d0oo0m0?l00002
oo0m0003o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool001gooooo00?o0000oooo
ool000001Ooi7@03o`0000Komb800ol00004one:0003o`000?oWH03oif0000;oif0000?o0000on5e
0?oQM@000ooQM@001_l0003ofXT0omZ90?l0003oc;40o`0000CoaL8000?o0000ojno0?n__`000_n_
_`000ol0003oVkX0oi^j0003oi^j0005o`000?n=]`3o0000odbU0?l000001Om4XP000ol0003o@Z40
od:Q0002od:Q0003o`000?l?T03o3i0000Co3i0000Oo0000oaJB0?lFTP3o5Y80o`000?l0PA?o0000
00Ko08D900?o0000o`1k7Ol0Nad01?l0Nad2o`0000Ko07DW0_l00007o`1c:`03o`000?l0MBOo07DW
00Co07DW00Oo0000o`1/=_l0K3Ko06`fo`000?l0Nago000000Ko07@Y00?o0000o`1_<Ol0Kc400_l0
Kc42o`0000Go07dI00?o0000o`1l6ol0O1/00_l0O1/00ol0003o07dIo`1m6@03o`1m6@03o`000?l0
PA?o084C00?o084C00?o0000o`252Ol0Q@T00_l0Q@T00ol0003o1X`0o`J<0003o`J<0005o`000?lK
U03o6i@0oa^D0?l000001OlgWP000ol0003oFZT0oeZY0002oeZY0003o`000?n4]03oQ;@000?o0000
1?n4]0000ol0003o^/80ok[20002ok[20003o`000?o?Z@3ocjT000?o00001OoDW0000ol0003ohGD0
on5e0002on5e00Go000000?oiV40o`000?o`?@000_o`?@000ol0003ol3d0o`00000@ooooo`03o`00
0?oooooooooo00Kooooo000Nooooo`04o`000?oooooo0000ooTM00?o00000ooi6P001?l0003omb80
ooLR0?og8P02o`0000?om2l00_l000000oo]BP3o0000onMP0003onMP0003o`000?oQM@3ohGD000?o
hGD000?o0000omZ90?oJR@000_oJR@03o`0000;oaL8000?o0000ojno0?n__`000_n__`000ol0003o
VkX0oi^j0003oi^j0004o`000?n=]`3oSKL0ohfg00;o00001?m4XP000ol0003o@Z40od:Q0003od:Q
0003o`000?l?T03o3i0000?o3i0000?o0000oaJB0?lFTP000olFTP000ol0003o08D9o`252@04o`25
2@03o`000?l6S03o000000Co07/M00Co0000o`242ol0Q0_o00001?l0MBL01?l0003o084Co`214ol0
0005o`1c:`;o00001_l0MBL01?l0003o06`fo`1/=_l00003o`1k7@03o`000?l0M2Wo07@Y00?o07@Y
00?o0000o`1_<Ol0Kc400_l000000ol0PA?o0000o`1m6@04o`1m6@03o`000?l0O1_o07`K00?o07`K
00?o0000o`1m6Ol0OAT00_l0OAT00ol0003o084Co`214`03o`214`03o`000?l0Q@Wo08D900;o08D9
00?o0000o`J<0?l6S0000ol6S0000ol0003o6i@0oa^D0002oa^D0003o`000?lgWP3o=ih000;o=ih0
00?o0000oeZY0?mJZ@000omJZ@000ol0003oQ;@0ohBd0002ohBd00?o00000_n4]0000ol0003o^/80
ok[20002ok[20003o`000?o?Z@3ocjT000;ocjT00ol00003omBL0005o`000?oQM@3ohGD0on5e0?l0
00001?o[D009o`0000oooooo00?o0000ooooooooool01_ooool001oooooo00?o0000ooooool00000
1ooi6P000ol0003omb80o`000006oo@_00Co00000_oWH0000ol0003ohGD0on5e0003on5e0003o`00
0?oJR@3ofXT000;ofXT000Co0000omBK0?oDV`3oe9/00ol00004ojno0003o`000?nK^P3oVkX000;o
VkX000?o0000ohfg0?n=]`000_n=]`000ol0003oQ;@0o`000003odBR0003o`000?m2X@3o@Z4000;o
@Z4000?o0000odBR0?l000000ol?T0000ol0003o5Y80oaJB0004oaJB0003o`000?l0Q@Wo08D900?o
08D900Go0000o`J<0?l6S03o1X`0o`000002o`1k7@03o`000?l0Q0_o08@;00;o08@;00Co0000o`1e
9ol0MBOo00000ol0PA<00ol0003o07<[o`1c:`02o`1c:`04o`000?l0PA?o084Co`0000Go07DW00?o
0000o`1/=_l000001?l0Nad00ol0003o07@Yo`1d:@03o`1d:@03o`000?l0Kc7o000000Co084C00?o
0000o`1m6Ol0OAT00_l0OAT00ol0003o07`Ko`1l6`03o`1l6`03o`000?l0OAWo07dI00?o07dI00?o
0000o`214ol0PA<00_l0PA<00ol0003o08D9o`252@02o`252@03o`000?l6S03o1X`000?o1X`000?o
0000oa^D0?lKU0000_lKU0000ol0003o=ih0ocNN0003ocNN0003o`000?mJZ@3oFZT000;oFZT000?o
0000ohBd0?n4]0000_n4]0000ol0003o]L40okG10003o`0000Co^/8000?o0000olnY0?o?Z@000_o?
Z@000ol0003og8D0omb50004o`0000CohGD000?o0000on]@0?o[D0000oo[D0001ol0003olc40oo<a
0?oc<@3o0000oo<a0?l000003oooool00ol0003oooooooooo`06ooooo`008?ooool00ol0003ooooo
o`000006ooTJ00?o00001?od;`02o`0000Col3l00ol00004on5e0003o`000?oJR@3ofXT000;ofXT0
00?o0000omBK0?oDV`000ooDV`001_l0003ocjT0o`000?l0003o[kl0o`0000CoVkX000?o0000ohfg
0?n=]`000_n=]`001ol0003oQ;@0ohBd0?n4]03o0000odBR0?l000001?m2X@001ol0003oA:80odBR
0?m4XP3o0000o`n@0?l000001_lFTP000ol0003o8iL0o`000003o`252@03o`000?l6S03o1X`000;o
1X`000?o0000o`1k7Ol000001Ol0Q0/00ol0003o07DWo`000005o`214`04o`000?l0Lb_o07<[o`00
00?o084C00?o0000o`1e9ol0MBL00ol0MBL2o`0000Ko07/M00?o0000o`1d:Ol0M2T00_l0M2T2o`00
00Go084C00?o0000o`1m6Ol0OAT00ol0OAT00ol0003o07`Ko`1l6`02o`1l6`04o`000?l0OAWo07dI
o`1m6ASo00001OlgWP000ol0003oFZT0oeZY0003oeZY0005o`000?n4]03oQ;@0ohBd0?l000001One
`@03o`0000;o^/8000?o0000olnY0?o?Z@000_o?Z@000ol0003og8D0omb50002omb500Go000000?o
hGD0o`000?o[D0001?o[D0001ol0003olc40oo<a0?oc<@3o0000oo<a0?l000003_ooool00ol0003o
ooooooooo`06ooooo`008Oooool3o`0000;onAX00ol00003ooPM00;o000000?om2l0o`000?o`?`00
1?o`?`001?l0003oje00on]@0?o[D002o`000003on5e0?l0003ofXT000?ofXT000?o0000omBK0?oD
V`000ooDV`000ol0003ocjT0olnY0002olnY00;o00000onK^P000ol0003oSKL0ohfg0002ohfg0003
o`000?n4]03oQ;@000?oQ;@000?o0000od:Q0?m2X@000_m2X@000ol0003oA:80odBR0003odBR0003
o`000?lFTP3o5Y8000Co5Y8000Go0000ob>G0?lSU`3o8iL0o`000002o`252@03o`000?l6S03o1X`0
00?o1X`000?o0000o`242ol0Q0/01Ol0Q0/00ol0003o084Co`214`04o`214`03o`000?l0Lb_o0000
00Go084C00Oo0000o`1e9ol0MBOo07DWo`000?l0Q0_o000000Ko07/M00?o0000o`1d:Ol0M2T00_l0
00000ol0Q@Wo0000o`214`04o`214`03o`000?l0OAWo07dI00?o07dI00?o0000o`1l6ol0O1/00_l0
O1/4o`0000;o3i0000?o0000oaJB0?lFTP000olFTP000ol0003o8iL0ob>G0002ob>G0003o`000?ld
W@3o=9d000?o=9d000Co0000odbU0?m<Y@3oC:D01Ol000000olgWP3o0000oeZY0004oeZY0003o`00
0?n4]03oQ;@000;oQ;@000?o0000okG10?ne`@000_ne`@000ol0003ocJl0olf_0003o`0000CocjT0
00?o0000omb50?oLQ@000ooLQ@001?l0003oif00onMP0?oWH006o`000003on]@0?l0003olc4000?o
lc400_l0000>ooooo`03o`000?oooooooooo00Kooooo000Sooooo`?o00001ooh7@03o`0000Col3l0
00?o0000on]@0?o[D0000oo[D004o`0000;ofXT000?o0000omBK0?oDV`000ooDV`000ol0003ocjT0
olnY0002olnY0006o`000?o;]03obk@0o`000?nK^P3o00001?n=]`000ol0003oQ;@0ohBd0003ohBd
0003o`000?n1]03o000000?o@Z4000?o0000odBR0?m4XP000om4XP02o`0000Co5Y8000?o0000ob>G
0?lSU`000_lSU`000ol0003o08D9o`000006o`J<0003o`000?l0Q0_o08@;00Go08@;00?o0000o`21
4ol0PA<01Ol0PA<00ol0003o084Co`214`04o`214`04o`000?l0MBOo07DWo`0000?o08@;00?o0000
o`1k7Ol0Nad00ol0Nad00ol0003o07@Yo`000004o`252@03o`000?l0PA?o084C00?o084C00?o0000
o`1m6Ol0OAT00_l0OAT00ol0003o07`Ko`000002o`000003o`f?0?l0003o3i0000Co3i0000?o0000
oaJB0?lFTP000_lFTP000ol0003o8iL0ob>G0003ob>G0003o`000?ldW@3o=9d000;o=9d000?o0000
odbU0?m<Y@000_m<Y@001?l0003oJjh0of^^0?m[[P06o`000003oeZY0?l0003oQ;@000?oQ;@000?o
0000okG10?ne`@000one`@000ol0003ocJl0olf_0002olf_00?o00000_o?Z@000ol0003og8D0omb5
0003omb50003o`000?oWH03oif0000;oif0000Co0000oo0o0?o`?`3ol3l02Ol0000>ooooo`03o`00
0?oooooooooo00Gooooo000Tooooo`03o`000?oooooo000000Con1d00_l00003ooHV00;o000000?o
l3l0o`000?o[D0001?o[D0000ol0003oiV40onIQ0002onIQ00?o00001?oDV`000ol0003ocjT0olnY
0002olnY0003o`000?o;]03obk@000;obk@00_l00004ohfg0003o`000?n4]03oQ;@000;oQ;@000Oo
0000oh6d0?n1]03oPK@0o`000?m2X@3o000000GoA:8000Co0000odbU0?m<Y@3o00000olFTP000ol0
003o8iL0ob>G0003ob>G0003o`000?l6S03o1X`000Co1X`000?o0000oa^D0?l000001Ol0Q0/00ol0
003o3Hl0o`000005o`214`;o00001_l0PA<00ol0003o07DWo`000004o`242`03o`000?l0Nago07/M
00?o07/M0_l00005o`252@03o`000?l0PA?o084C00?o084C00?o0000o`1m6Ol0OAT00_l0OAT2o`00
00Go3Hl000?o0000o`n@0?l?T0000_l?T0000ol0003o5Y80oaJB0003oaJB0003o`000?lSU`3o8iL0
00;o8iL000?o0000ocBM0?ldW@000oldW@000ol0003oC:D0odbU0002odbU0003o`000?m[[P3oJjh0
00;oJjh000Co0000ohnh0?n?^03oSkP01?l00002ohBd0003o`000?ne`@3o]L4000?o]L4000?o0000
olf_0?o=[`000_o=[`000ol0003ofHh0omV>0003o`0000Gog8D000?o0000onMP0?oWH0000ooWH000
0ol0003ol3l0oo0o0002oo0o0003o`000?of9P3omRH000;omRH00_l0000>ooooo`03o`000?oooooo
oooo00Gooooo000Uooooo`04o`000?oooooo0000ooPM00;o00001_of9P03o`0000Coje0000?o0000
onIQ0?oVH@000_oVH@001?l0003ohW40on9a0?oRL@02o`000003omBK0?l0003ocjT000?ocjT000?o
0000ol^d0?o;]0000oo;]0001_l0003ob;`0o`000?l0003oSKL0o`0000CoQ;@000?o0000oh6d0?n1
]0000on1]0000ol0003oA:80odBR0003odBR0003o`000?m<Y@3oC:D000;oC:D000?o0000oaJB0?l0
00001_lSU`000ol0003o1X`0o`J<0003o`J<0004o`000?lKU03o6i@0o`0000Co08@;00Co0000o`f?
0?l=S`3o00001?l0PA<01?l0003o28d0o`R=0?l00005o`214`;o00001_l0Q0/01ol0003o07/Mo`1k
7Ol0Nago0000o`J<0?l000001_l0Q@T00ol0003o084Co`214`02o`214`03o`000?l0OAWo000000;o
000000?o3i00o`000?l=S`001?l=S`000ol0003o3i00o`n@0002o`n@0003o`000?lFTP3o5Y8000?o
5Y8000?o0000ob>G0?lSU`000olSU`000ol0003o=9d0ocBM0002ocBM0003o`000?m<Y@3oC:D000;o
C:D000?o0000of^^0?m[[P000om[[P000ol0003oSkP0ohnh0002ohnh0003o`000?nj`P3o000000?o
00001?ne`@000ol0003ocJl0olf_0003olf_0003o`000?oISP3ofHh000;ofHh01?l000000ooLQ@3o
0000onMP0004onMP0003o`000?o`?`3ol3l000?ol3l000?o0000ooHV0?of9P000_of9P02o`0000go
oooo00?o0000ooooooooool01Oooool002Kooooo1?l00006ooHV0004o`000?oc<@3olc40oo<a00;o
000000?oje00o`000?oVH@000ooVH@000ol0003ohW40on9a0003on9a00?o00000oo?Z@000ol0003o
bk@0ol^d0003ol^d0003o`000?o8_03ob;`000;ob;`00_l00003ohBd0003o`000?n1]03oPK@000?o
PK@000?o0000ohBd0?l000000om4XP000ol0003oC:D0odbU0004odbU0003o`000?lSU`3o8iL000Co
8iL000?o0000ocBM0?l000000ol6S0000ol0003o6i@0oa^D0002oa^D0004o`000?l0Q0_o08@;o`00
00Co3Hl000Co0000o`214ol0PA?o00000ol8S@000ol0003o084Co`214`02o`214`03o`000?l=S`3o
000000Ko08@;00Co0000o`1k7Ol0Nago00000_l6S0000ol0003o08D9o`252@04o`252@03o`000?l0
PA?o084C00;o084C0_l00005o`n@0003o`000?l=S`3o3Hl000;o3Hl000?o0000o`n@0?l?T0000ol?
T0000ol0003o5Y80oaJB0002oaJB0003o`000?lSU`3o8iL000?o8iL000?o0000ocBM0?ldW@000_ld
W@000ol0003oC:D0odbU0003odbU0003o`000?m[[P3oJjh000;oJjh000?o0000ohnh0?n?^0000_n?
^0000ol0003o^/80ok[20002ok[200Co00000_ne`@000ol0003ocJl0olf_0002olf_0003o`000?oI
SP3ofHh000;ofHh000Co0000onA[0?oTJ`3oi6/01_l000000ooWH03o0000oo0o0005oo0o0003o`00
0?of9P3omRH000;omRH00_l0000<ooooo`03o`000?oooooooooo00Gooooo000Xooooo`03o`000?oo
oooo000000?omRH00_l00005oo<a00?o00000ooVH@000ol0003ohW40on9a0003on9a0007o`000?oN
OP3ogWh0omin0?l0003ocjT0o`000005ol^d0003o`000?o8_03ob;`000;ob;`000Ko0000olK10?o6
`@3o0000ohBd0?l00005oh6d0007o`000?n4]03oQ;@0ohBd0?l0003oA:80o`000006odbU00;o0000
1OlSU`001ol0003o=9d0ocBM0?ldW@3o0000o`J<0?l000001OlKU0000ol0003o08@;o`000005o`f?
0003o`000?l0PA?o000000Go28d000Co0000o`214ol0PA?o00000ol=S`000ol0003o08@;o`242`03
o`242`03o`000?l0Nago000000Co1X`000?o0000o`252Ol0Q@T00ol0Q@T00ol0003o084Co`000002
o`000003oaJB0?l0003o3i0000Co3i0000?o0000o`f?0?l=S`000ol=S`000ol0003o3i00o`n@0002
o`n@0003o`000?lFTP3o5Y8000?o5Y8000?o0000ob>G0?lSU`000_lSU`000ol0003o=9d0ocBM0003
ocBM0003o`000?m<Y@3oC:D000;oC:D000?o0000of^^0?m[[P000om[[P000ol0003oSkP0ohnh0002
ohnh0005o`000?nj`P3o^/80ok[20?l000000oo=[`05o`0000;ocJl000?o0000omV>0?oISP000ooI
SP000ol0003oi6/0onA[0002onA[0004o`000?o]BP3okDX0one:013o00002oooool00ol0003ooooo
ooooo`05ooooo`00:Oooool01Ol0003oooooo`000?of9P3o000000Kolc4000Oo0000oo0m0?o`?@3o
l3d0o`000?oVH@3o000000GohW4000?o0000omin0?oNOP000ooNOP02o`0000Cobk@000?o0000olRl
0?o8_0000_o8_0000ol0003oa/40olK10002olK10003o`000?n1]03oPK@000?oPK@000?o0000ohBd
0?n4]0000on4]0000ol0003oC:D0odbU0004odbU0004o`000?mJZ@3oFZT0o`0000?o8iL000?o0000
ocBM0?ldW@000oldW@000ol0003o6i@0oa^D0005oa^D0003o`000?l=S`3o3Hl000Go3Hl000?o0000
o`R=0?l8S@001?l8S@000ol0003o084Co`000004o`f?0003o`000?l0Q0_o08@;00?o08@;0_l00005
o`J<0003o`000?l0Q@Wo08D900?o08D90_l00004oaJB0003o`000?l?T03o3i0000Co3i0000?o0000
o`f?0?l=S`000_l=S`000ol0003o3i00o`n@0002o`n@0004o`000?lFTP3o5Y80oaJB017o000000?o
C:D0o`000?m[[P001?m[[P000ol0003oSkP0ohnh0002ohnh0003o`000?nj`P3o^/8000;o^/8000?o
0000olf_0?o=[`000_o=[`000ol0003of940omRA0004o`0000GofHh000?o0000onA[0?oTJ`000_oT
J`000ol0003okDX0one:0002one:0003o`000?od;`3om2l000Com2l000?o0000ooPM0?oh7@000_oh
7@02o`0000_ooooo00?o0000ooooooooool01Oooool002[ooooo00Co0000ooooool0003o00001?oc
<@02o`0000Gol3d00_l00004on9a0003o`000?oNOP3ogWh000?ogWh000?o0000omZ90?oJR@000_l0
00000oo;]03o0000olRl0003olRl0003o`000?o6`@3oa/4000?oa/400_l00003oh6d0003o`000?n4
]03oQ;@000CoQ;@000?o0000odbU0?m<Y@000om<Y@000ol0003oFZT0oeZY0002oeZY0003o`000?lS
U`3o000000Ko=9d000?o0000oa^D0?lKU0001?lKU002o`0000Ko3Hl00_l00007o`R=0003o`000?l=
S`3o3Hl000Co3Hl000Oo0000o`242ol0Q0_o08@;o`000?lKU03o000000Go1X`000Co0000o`252Ol0
Q@Wo08D90_l000000olSU`3o0000oaJB0004oaJB0003o`000?l?T03o3i0000?o3i0000?o0000o`f?
0?l=S`000_l=S`001?l0003o3i00o`n@0?l?T005o`0000;oC:D000?o0000oeZY0?mJZ@000omJZ@00
0ol0003oKJh0off^0002off^0004o`000?n7]@3oQkD0ohNe00Ko000000?oJjh0o`000?n?^0000on?
^0000ol0003o^/80ok[20002ok[20003o`000?o=[`3ocJl000?ocJl000?o0000omRA0?oHT@000_oH
T@05o`000003omV>0?l0003oi6/000Coi6/000?o0000one:0?o]BP000_o]BP000ol0003om2l0oo@_
0004oo@_0003o`000?oh7@3on1d000;on1d00_l0000:ooooo`03o`000?oooooooooo00Gooooo000[
ooooo`;o000000Goooooo`000?l0003olc40o`000006oo0m0003o`000?o]BP3okDX000;o000000?o
hW40o`000?oNOP001?oNOP000ol0003ofXT0omZ90002omZ900?o00000oo8_0000ol0003oa/40olK1
0003olK10006o`000?o5`P3oaL80o`000?n1]03o00001_n4]0000ol0003oSKL0o`000003odbU0003
o`000?mJZ@3oFZT000CoFZT000?o0000ocBM0?ldW@001?ldW@000ol0003oC:D0o`000004oa^D0004
o`000?lgWP3o=ih0o`0000Co3Hl000Co0000obfK0?l]V`3o00001Ol8S@02o`0000Ko3Hl000Co0000
o`242ol0Q0_o00000_lKU0000ol0003o1X`0o`J<0004o`J<00?o00000olSU`000ol0003o5Y80oaJB
0003oaJB0003o`000?l?T03o3i0000?o3i0000Co0000o`f?0?l=S`3o3Hl01Ol00002odBR0003o`00
0?m<Y@3oC:D000?oC:D000?o0000oeZY0?mJZ@000omJZ@000ol0003oKJh0off^0002off^0003o`00
0?n7]@3oQkD000;oQkD000Co0000ojJm0?nV_@3oY[d01_l000000on?^03o0000ok[20003ok[20003
o`000?o=[`3ocJl000;ocJl000?o0000omRA0?oHT@000_oHT@000ol0003ohW40on9a0002on9a00Ko
000000?oi6/0o`000?o]BP001?o]BP000ol0003om2l0oo@_0003oo@_0004o`000?oh7@3on1d0ooPM
00Co00002Oooool00ol0003oooooooooo`05ooooo`00;Oooool00ol0003oooooooooo`02o`0000Go
l3d000?o0000one:0?o]BP000oo]BP02o`0000CogWh000?o0000omZ90?oJR@000_oJR@001ol0003o
f940omRA0?oHT@3o0000olRl0?l000001Oo6`@000ol0003oaL80olG20002olG20003o`000?n4]03o
Q;@000CoQ;@000Oo0000ohfg0?n=]`3oSKL0o`000?m<Y@3o000000KoFZT00_l00005ocBM0005o`00
0?m<Y@3oC:D0odbU0?l000000_lKU0000ol0003o=ih0ocNN0002ocNN0004o`000?l=S`3o3Hl0o`00
00?o;I/000?o0000o`R=0?l8S@000_l8S@000ol0003o;I/0o`000006o`f?0003o`000?l0Q0_o0000
00Co6i@000?o0000o`J<0?l6S0000_l6S002o`0000Ko8iL000?o0000oaJB0?lFTP000_lFTP000ol0
003o3i00o`n@0003o`n@00Co00000_m2X@000ol0003oA:80odBR0003odBR0003o`000?m<Y@3oC:D0
00;oC:D000?o0000oeZY0?mJZ@000omJZ@000ol0003oKJh0off^0002off^0003o`000?n7]@3oQkD0
00?oQkD000?o0000ojJm0?nV_@000_nV_@001?l0003oa/40olK10?o6`@05o`000003ok[20?l0003o
cJl000CocJl000?o0000omRA0?oHT@000_oHT@000ol0003ohW40on9a0003on9a0004o`000?o[D@3o
je40on]A00Ko000000?okDX0o`000?od;`000_od;`06o`0000;onAX00_l0000:ooooo`03o`000?oo
oooooooo00Cooooo000^ooooo`05o`000?ooooooooooooooool000000oo`?@000ol0003okDX0one:
0003one:0003o`000?oZE@3ojUD000;o000000?ogWh0o`000?oJR@000ooJR@000ol0003of940omRA
0003omRA00;o00001?o6`@000ol0003oaL80olG20003olG200;o00001?n4]0000ol0003oSKL0ohfg
0003ohfg0003o`000?mJZ@3oFZT000CoFZT000Co0000off^0?m][P3o00000oldW@000ol0003oC:D0
odbU0002odbU0003o`000?lKU03o000000Go=ih000?o0000o`f?0?l000001Ol]V`001?l0003o28d0
o`R=0?l00003obfK0003o`000?l=S`3o3Hl000?o3Hl00_l00005oa^D0007o`000?l6S03o1X`0o`J<
0?l0003o=9d0o`000006ob>G0003o`000?lFTP3o5Y8000?o5Y8000?o0000o`n@0?l000000_l00000
0om4XP3o0000od:Q0004od:Q0003o`000?m4XP3oA:8000;oA:8000?o0000odbU0?m<Y@000_m<Y@00
0ol0003oFZT0oeZY0003oeZY0003o`000?m][P3oKJh000;oKJh000?o0000ohNe0?n7]@000on7]@00
0ol0003oY[d0ojJm0002ojJm0003o`000?o6`@3oa/4000;oa/4000Co0000olnY0?o?Z@3ocjT01_l0
00000oo=[`3o0000omRA0004omRA0003o`000?oRL@3ohW4000?ohW4000?o0000on]A0?o[D@000_o[
D@001?l0003olSH0oo8f0?ob=P05o`0000?omb8000?o0000ooTJ0?oi6P000ooi6P02o`0000Wooooo
00?o0000ooooooooool01?ooool002oooooo00Oo0000ooooooooooooooooo`000?o`?@3o000000Go
kDX000?o0000onYE0?oZE@000_oZE@03o`0000?ofXT000?o0000omRA0?oHT@001?oHT@000ol0003o
eYH0o`000003olK10003o`000?o5`P3oaL8000;oaL8000Co0000olK10?o6`@3o00000on4]0000ol0
003oSKL0ohfg0003ohfg0003o`000?mJZ@3oFZT000?oFZT000?o0000off^0?m][P000_m][P000ol0
003o=9d0o`000006odbU0003o`000?lgWP3o=ih000Go=ih000?o0000obfK0?l]V`001?l]V`000ol0
003o28d0o`000004obfK0003o`000?l=S`3o3Hl000;o3Hl000?o0000ocNN0?l000001OlKU0001?l0
003o1X`0o`J<0?l00003ocBM0003o`000?lSU`3o8iL000?o8iL000?o0000oaJB0?lFTP000_lFTP03
o`0000CoA:8000?o0000od:Q0?m2X@000om2X@000ol0003oA:80odBR0002odBR0003o`000?m<Y@3o
C:D000?oC:D000?o0000oeZY0?mJZ@000omJZ@000ol0003oKJh0off^0002off^0003o`000?n7]@3o
QkD000?oQkD000?o0000ojJm0?nV_@000_nV_@000ol0003oa/40olK10002olK10003o`000?o?Z@3o
cjT000;ocjT000Co0000omV>0?oISP3ofHh01_l000000ooHT@3o0000on9a0004on9a0003o`000?o[
D@3oje4000?oje4000?o0000oo8f0?ob=P000_ob=P000ol0003omb80ooLR0004ooLR0003o`000?oi
6P3onAX000?onAX00_l00008ooooo`03o`000?oooooooooo00Cooooo000`ooooo`;o00000_ooool2
o`0000CokDX000?o0000onYE0?oZE@000_oZE@001ol0003oieh0onMN0?oWGP3o0000omZ90?l00000
1_oHT@001ol0003oeYH0omJF0?oFUP3o0000olK10?l000001?o5`P000ol0003oa/40olK10002olK1
0003o`000?n4]03o000000GoSKL000?o0000oi^j0?l000000omJZ@000ol0003oKJh0off^0004off^
0003o`000?m<Y@3oC:D000CoC:D00_l00007ocNN0003o`000?l]V`3o;I/000Go;I/000?o0000obfK
0?l]V`000ol]V`000ol0003o3Hl0o`f?0002o`0000?o=ih000?o0000oa^D0?lKU0000olKU002o`00
00Co=9d000?o0000ob>G0?lSU`000olSU`000ol0003o5Y80oaJB0002o`000003odbU0?l0003oA:80
00GoA:8000?o0000od:Q0?m2X@000_m2X@000ol0003oA:80odBR0003odBR0003o`000?m<Y@3oC:D0
00;oC:D000?o0000oeZY0?mJZ@000omJZ@000ol0003oKJh0off^0002off^0003o`000?n7]@3oQkD0
00?oQkD000?o0000ojJm0?nV_@000_nV_@000ol0003oa/40olK10002olK10003o`000?o?Z@3ocjT0
00?ocjT000?o0000omV>0?oISP000_oISP001?l0003ohW40on9a0?oRL@06o`000003on9a0?l0003o
je4000Coje4000?o0000oo8f0?ob=P000oob=P000ol0003omb80ooLR0003ooLR0003o`000?oi6P3o
nAX000?o000000?onAd0o`000?l000001oooool00ol0003oooooooooo`04ooooo`00<_ooool01?l0
003oooooooooooooool2o`000003one:0?l0003ojUD000?ojUD000?o0000onMN0?oWGP000ooWGP02
o`0000Gof94000?o0000omJF0?oFUP000_oFUP02o`0000CoaL8000?o0000olK10?o6`@001?o6`@00
0ol0003oSKL0ohfg0003ohfg0007o`000?nK^P3oVkX0oi^j0?l0003oFZT0o`000006off^00;o0000
1Om<Y@001?l0003oJjh0of^^0?l00005ocNN0003o`000?mJZ@3o000000Go;I/00_l00006obfK00;o
00001OlgWP000ol0003o6i@0oa^D0002oa^D00;o00001OldW@000ol0003o8iL0ob>G0004ob>G00;o
00001?m<Y@000ol0003oA:80odBR0003odBR0003o`000?m2X@3o@Z4000?o@Z4000?o0000odBR0?m4
XP000_m4XP000ol0003oC:D0odbU0002odbU0003o`000?mJZ@3oFZT000?oFZT000?o0000off^0?m]
[P000_m][P000ol0003oQkD0ohNe0003ohNe0003o`000?nV_@3oY[d000;oY[d000?o0000olK10?o6
`@000oo6`@000ol0003ocjT0olnY0002olnY0003o`000?oISP3ofHh000?ofHh000?o0000on9a0?oR
L@000_oRL@001?l0003ojU@0onYD0?oZE006o`000003on]A0?l0003olSH000ColSH000Co0000ooLR
0?og8P3omb801Ol00004ooTM00Co00001Oooool00ol0003oooooooooo`04ooooo`00<oooool00ol0
003oooooooooo`02ooooo`;o00000ooZE@000ol0003oieh0onMN0003onMN0004o`000?oUI@3oiFD0
o`0000?of94000?o0000omJF0?oFUP000_oFUP001?l0003oeYP0omJH0?l00003olG20003o`000?o6
`@3oa/4000?oa/4000?o0000olRl0?l000000on=]`000ol0003oVkX0oi^j0003oi^j0003o`000?m]
[P3oKJh000CoKJh000Co0000ohNe0?n7]@3o00000om<Y@001Ol0003oJjh0of^^0?m[[P3o000000Co
=ih000Co0000oeZY0?mJZ@3o00001?l]V`001?l0003oE:L0oeBW0?l00004obfK00;o00001_lgWP00
0ol0003o6i@0oa^D0002o`000003odbU0?l0003o=9d000Go=9d000?o0000ob>G0?lSU`000_lSU`02
o`0000GoC:D000?o0000odBR0?m4XP000om4XP000ol0003o@Z40od:Q0003od:Q0003o`000?m4XP3o
A:8000;oA:8000Co0000odbU0?m<Y@3oC:D05ol000000onV_@3o0000olK10003olK10003o`000?o?
Z@3ocjT000?ocjT000?o0000omV>0?oISP000_oISP000ol0003ohW40on9a0003on9a0003o`000?oZ
E03ojU@000;ojU@000Co0000oo4i0?oa>@3olCT02ol00003ooTJ0003o`000?oi7@3onAd000;onAd0
0ol000001Oof:@3o0000o`000?l0003ooooo00?o00001_ooool003Cooooo00?o0000ooooooooool0
0oooool00ol0003ojUD0o`000005onMN0003o`000?oUI@3oiFD000;oiFD000?o0000omRA0?l00000
1?oFUP000ol0003oeYP0omJH0002omJH0003o`000?o5`P3o000000Goa/4000Oo0000olRl0?o8_03o
b;`0o`000?n=]`3o000000KoVkX000?o0000off^0?m][P000om][P001Ol0003oQkD0ohNe0?n7]@3o
000000;oC:D000?o0000of^^0?m[[P000om[[P001?l0003o=ih0ocNN0?l00004oeZY0004o`000?l]
V`3o;I/0o`0000?oE:L000Oo0000obfK0?l]V`3o;I/0o`000?mJZ@3o000000Oo=ih00_l00004odbU
0003o`000?ldW@3o=9d000?o=9d000?o0000ob>G0?lSU`000_l000000omJZ@3o0000odbU0004odbU
0003o`000?m4XP3oA:8000?oA:8000?o0000od:Q0?m2X@000om2X@001?l0003oA:80odBR0?m4XP05
o`0000;oSKL000?o0000oi^j0?nK^P000onK^P000ol0003o[kl0ojno0002ojno0003o`000?o5`P3o
aL8000?oaL8000Co0000olba0?o</@3oc;402ol000000oo?Z@3o0000omV>0004omV>0003o`000?oR
L@3ohW4000;ohW4000?o0000onYD0?oZE0000ooZE0000ol0003olCT0oo4i0002oo4i0003o`000?og
9@3ombD000CombD000?o0000ooTJ0?oi6P000ooi6P001?l0003onAd0o`000?l00003ooHY0003o`00
0?o_@@3okd4000?o000000?oooooo`000?ooool01Oooool003Gooooo0_l00004ooooo`;o00001?oW
GP000ol0003oiFD0onEU0004onEU00;o00000ooFUP000ol0003oeYP0omJH0004omJH0003o`000?o6
`@3oa/4000?oa/4000?o0000olRl0?o8_0000oo8_0000ol0003oVkX0oi^j0004oi^j0003o`000?n_
_`3o000000?oKJh000?o0000ohNe0?n7]@000_n7]@000ol0003oC:D0o`000006of^^0003o`000?lg
WP3o000000GoFZT000?o0000obfK0?l000001?mDY`001?l0003o;I/0obfK0?l00003oeZY0003o`00
0?lgWP3o=ih000Co=ih000?o0000odbU0?m<Y@000om<Y@000ol0003o=9d0ocBM0003ocBM0003o`00
0?lSU`3o000000CoFZT000?o0000odbU0?m<Y@000om<Y@000ol0003oA:80odBR0003odBR0003o`00
0?m2X@3o@Z4000Ko00000_n4]0000ol0003oSKL0ohfg0003ohfg0003o`000?nK^P3oVkX000;oVkX0
00?o0000ojno0?n__`000on__`000ol0003oaL80olG20002olG20003o`000?o</@3oc;4000;oc;40
00?o0000omBL0?oDW0000ooDW0001?l0003og8D0omb50?oLQ@06o`000003omV>0?l0003ohW4000Co
hW4000?o0000onYD0?oZE0000ooZE0000ol0003olCT0oo4i0002oo4i0003o`000?og9@3ombD000Co
mbD000Co0000ooTJ0?oi6P3onAX01?l00003ooHY0003o`000?o_@@3o000000?o00000_ooool00ol0
003oooooooooo`04ooooo`00=oooool00ol0003oooooooooo`03ooooo`;o000000?oieh0o`000?oU
I@001OoUI@001_l0003oi6X0onAZ0?l0003oeYH0o`0000KoeYP000?o0000omJF0?l000000oo6`@00
0ol0003ob;`0olRl0004olRl0003o`000?nK^P3oVkX000?oVkX000Oo0000ojno0?n__`3o[kl0o`00
0?m][P3o000000KoQkD000?o0000of^^0?m[[P001Om[[P02o`0000KoFZT00_l00006oeBW00;o0000
1?mJZ@000ol0003o=ih0ocNN0003ocNN00;o00001_m<Y@000ol0003o=9d0ocBM0002ocBM00;o0000
1OmJZ@000ol0003oC:D0odbU0003odbU0003o`000?m4XP3oA:8000;oA:801?l00003oh6d0003o`00
0?n4]03oQ;@000?oQ;@000?o0000ohfg0?n=]`000_n=]`000ol0003oVkX0oi^j0003oi^j0003o`00
0?n__`3o[kl000;o[kl000?o0000olG20?o5`P000oo5`P000ol0003oc;40olba0002olba0003o`00
0?oDW03oe9`000?oe9`000?o0000omb50?oLQ@000_oLQ@001?l0003oi6/0onA[0?oTJ`06o`000003
on9a0?l0003ojU@000CojU@000?o0000oo4i0?oa>@000ooa>@001?l0003ombD0ooLU0?og9@06o`00
00ConA/000Co0000ooHY0?l0003okd401?l00004ooooo`03o`000?oooooooooo00?ooooo000hoooo
o`03o`000?oooooooooo00Cooooo0_l00005onEU0003o`000?oTJP3oi6X000;oi6X00_l00005omJH
0007o`000?oFUP3oeYH0omJF0?l0003oa/40o`000006olRl0003o`000?o;]03o000000?oVkX000?o
0000ojno0?n__`000on__`000ol0003oQkD0ohNe0005ohNe0003o`000?m[[P3oJjh000CoJjh000?o
0000ohnh0?l000001OmJZ@000ol0003oQ;@0o`000006oeBW0003o`000?mJZ@3oFZT000CoFZT000Go
0000ocNN0?lgWP3o=ih0o`000002of^^0003o`000?m<Y@3oC:D000?oC:D000?o0000ocBM0?ldW@00
0_l000000om][P3o0000oeZY0005oeZY0003o`000?m<Y@3oC:D000;oC:D000?o0000odBR0?l00000
0_l000000on4]03o0000oh6d0004oh6d0003o`000?n4]03oQ;@000?oQ;@000?o0000ohfg0?n=]`00
0on=]`000ol0003oVkX0oi^j0002oi^j0003o`000?n__`3o[kl000?o[kl000?o0000olG20?o5`P00
0_o5`P000ol0003oc;40olba0002olba0003o`000?oDW03oe9`000?oe9`000?o0000omb50?oLQ@00
0ooLQ@000ol0003oi6/0onA[0002onA[0004o`000?o[D@3oje40on]A017o00000ooi6`000ol0003o
nA/0ooTK0004ooTK00;o000000?okd40o`000?oVH`000_l00005ooooo`03o`000?oooooooooo00?o
oooo000iooooo`03o`000?oooooooooo00Gooooo00Go0000onEU0?oUI@3oiFD0o`000005onAZ0003
o`000?oTJ`3o000000?oeYP000?o0000omJF0?oFUP000ooFUP02o`0000Gob;`000Oo0000ol^d0?o;
]03obk@0o`000?nK^P3o000000Ko[kl000?o0000ohNe0?n7]@001?n7]@000ol0003oY[d0o`000004
of^^0005o`000?n?^03oSkP0ohnh0?l000000omJZ@001Ol0003oQ;@0ohBd0?n4]03o000000CoE:L0
0_l00006oeZY0004o`000?lgWP3o=ih0o`0000?oJjh000?o0000odbU0?m<Y@000om<Y@000ol0003o
=9d0o`000004off^0003o`000?mJZ@3oFZT000?oFZT000?o0000odbU0?m<Y@000_m<Y@02o`0000Go
Q;@000?o0000oh6d0?n1]0000on1]0000ol0003oQ;@0ohBd0003ohBd0003o`000?n=]`3oSKL000;o
SKL000?o0000oi^j0?nK^P000_nK^P000ol0003o[kl0ojno0003ojno0003o`000?o5`P3oaL8000;o
aL8000?o0000olba0?o</@000oo</@000ol0003oe9`0omBL0003omBL0003o`000?oLQ@3og8D000;o
g8D000?o0000onA[0?oTJ`000ooTJ`000ol0003oje40on]A0002on]A0003o`000?oa>@3olCT000?o
lCT000?o0000ooHV0?of9P000oof9P000ol0003onA/0ooTK0004ooTK0003o`000?oi6`3onA/000?o
000000?omRL0o`000?l000000ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00?o
oooo000jooooo`;o00001_ooool00ol0003oiFD0o`000005onAZ0007o`000?oTJ`3oi6/0onA[0?l0
003oeYP0o`000005omJF0004o`000?oHT@3of940o`0000?ob;`000?o0000ol^d0?o;]0000oo;]000
0ol0003o[kl0ojno0004ojno0003o`000?o5`P3o000000CoQkD000Go0000ojJm0?nV_@3oY[d0o`00
0002of^^0003o`000?n?^03oSkP000;oSkP000Co0000oeZY0?mJZ@3o00001?n4]0001Ol0003oE:L0
oeBW0?mDY`3o000000;oQ;@000?o0000oeZY0?mJZ@000omJZ@000ol0003o=ih0o`000005of^^0003
o`000?m<Y@3oC:D000;oC:D00_l00005off^0003o`000?mJZ@3oFZT000?oFZT000?o0000odbU0?l0
00000_l000000on=]`3o0000ohBd0004ohBd0003o`000?n1]03oPK@000?oPK@000?o0000ohBd0?n4
]0000on4]0000ol0003oSKL0ohfg0002ohfg0003o`000?nK^P3oVkX000?oVkX000?o0000ojno0?n_
_`000_n__`000ol0003oaL80olG20003olG20003o`000?o</@3oc;4000;oc;4000?o0000omBL0?oD
W0000ooDW0000ol0003og8D0omb50002omb50003o`000?oTJ`3oi6/000?oi6/000?o0000on]A0?o[
D@000oo[D@000ol0003olCT0oo4i0003oo4i0003o`000?of9P3omRH000?omRH000?o0000ooTK0?oi
6`000ooi6`03o`0000;omRL00_l000001?o`?P3o0000onIS0?l00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool003cooooo00?o0000ooooooooool01?ooool00ol0003o
i6X0onAZ0003onAZ0003o`000?oTJ`3oi6/000;oi6/00_l00005omJF0003o`000?oHT@3of94000;o
f94000?o0000olRl0?l000001_o;]0000ol0003o[kl0ojno0003ojno0005o`000?o5`P3oaL80olG2
0?l000000_n7]@000ol0003oY[d0ojJm0002ojJm0003o`000?m[[P3o000000GoSkP000?o0000oeZY
0?l000001On4]0001?l0003oE:L0oeBW0?l00003ohBd0003o`000?mJZ@3oFZT000?oFZT00_l00006
of^^0003o`000?m<Y@3oC:D000;o000000?oQkD0o`000?m][P001Om][P000ol0003oFZT0oeZY0002
oeZY00;o00001On=]`000ol0003oQ;@0ohBd0002ohBd0003o`000?n1]03oPK@000?oPK@000?o0000
ohBd0?n4]0000on4]0001?l0003oSKL0ohfg0?n=]`0Lo`000003omBL0?l0003og8D000Cog8D000?o
0000onA[0?oTJ`000_oTJ`000ol0003oje40on]A0003on]A0003o`000?oa>@3olCT000?olCT000?o
0000ooHV0?of9P000oof9P000ol0003onA/0ooTK0003o`0000;onA/000?o0000ooHW0?l000000_o`
?P000ol0003oiV<0o`000004ooooo`05o`000?ooooooooooooooool000001Oooool003gooooo00?o
0000ooooooooool01?ooool01Ol0003oi6X0onAZ0?oTJP3o000000Coi6/000Co0000onAZ0?oTJP3o
00000ooFUP000ol0003of940omRA0004omRA0003o`000?o;]03obk@000Cobk@000?o0000olnY0?l0
00000on__`000ol0003oaL80olG20002olG20003o`000?n7]@3o000000KoY[d000?o0000ohnh0?n?
^0001On?^0000ol0003oQ;@0ohBd0005ohBd00;o00001On4]0001ol0003oFZT0oeZY0?mJZ@3o0000
ohnh0?l000001_m[[P000ol0003oC:D0o`000004ohNe0003o`000?m][P3oKJh000?oKJh000?o0000
oeZY0?mJZ@000_l000000onK^P3o0000ohfg0004ohfg0003o`000?n4]03oQ;@000?oQ;@000?o0000
oh6d0?n1]0000on1]0000ol0003oQ;@0ohBd0006o`0000;ob;`000?o0000ol^d0?o;]0000_o;]000
0ol0003ocjT0olnY0003olnY0003o`000?oDV`3oe9/000;oe9/000?o0000omZ90?oJR@000ooJR@00
1?l0003ohGD0on5e0?oQM@0;o`0000;oi6/000?o0000on]A0?o[D@000_o[D@001?l0003olCT0oo4i
0?oa>@0;o`0000GonA/00ol000001?o`?P3o0000onIS0?l00006ooooo`04o`000?ooooooooooo`00
00Gooooo000nooooo`03o`000?oooooooooo00Cooooo00?o0000onAZ0?l000001?oTJ`000ol0003o
i6X0onAZ0002onAZ0003o`000?oFUP3o000000Kof9400_l00005ol^d0007o`000?o?Z@3ocjT0olnY
0?l0003o[kl0o`000006olG20003o`000?nV_@3oY[d000GoY[d000?o0000ohnh0?n?^0001On?^000
0ol0003oQ;@0ohBd0005ohBd0003o`000?n4]03oQ;@000CoQ;@000Co0000oeZY0?mJZ@3o00000on?
^0000ol0003oJjh0of^^0003of^^00;o00001On7]@000ol0003oKJh0off^0003off^0003o`000?mJ
Z@3o000000CoVkX000?o0000ohfg0?n=]`000_n=]`000ol0003oQ;@0ohBd0003ohBd0003o`000?n1
]03oPK@000;oPK@01?l00003olK10003o`000?o8_03ob;`000?ob;`000?o0000ol^d0?o;]0000_o;
]0000ol0003ocjT0olnY0003olnY0003o`000?oDV`3oe9/000;oe9/000?o0000omZ90?oJR@000ooJ
R@000ol0003ohGD0on5e0002on5e0003o`000?oWH03oif0000;oif0000Co0000one:0?o]BP3okDX0
2ol00003ooLU0003o`000?oi6`3onA/000?onA/000?o0000ooTK0?oi6`000_oi6`02o`0000;omRL0
1?l00008ooooo`03o`000?oooooo000000Gooooo000oooooo`;o00001Oooool2o`0000?oi6/000?o
0000onAZ0?oTJP001?oTJP000ol0003of940omRA0004omRA0004o`000?oJR@3ofXT0o`0000?obk@0
00?o0000olnY0?o?Z@000oo?Z@000ol0003oaL80olG20005olG20003o`000?nV_@3oY[d000CoY[d0
00?o0000olK10?l000001On?^0000ol0003o^/80o`000005ohBd00;o00001_n4]0000ol0003oFZT0
o`000004ohnh0003o`000?m[[P3oJjh000;oJjh000?o0000ojJm0?l000001_n7]@000ol0003oKJh0
off^0002off^00;o00001OnK^P000ol0003oSKL0ohfg0003ohfg0003o`000?n4]03oQ;@000;oQ;@0
00?o0000oh6d0?l000000_l000000oo5`P3o0000olK10004olK10003o`000?o8_03ob;`000?ob;`0
00?o0000ol^d0?o;]0000_o;]0000ol0003ocjT0olnY0003olnY0003o`000?oDV`3oe9/000;oe9/0
00?o0000omZ90?oJR@000ooJR@000ol0003ohGD0on5e0003on5e0003o`000?oWH03oif0000;oif00
00?o0000one:0?o]BP000_o]BP000ol0003olSH0oo8f0003oo8f0003o`000?og9@3ombD000CombD0
00?o0000ooTK0?oi6`000ooi6`001?l0003onA/0o`000?l00003ooHW0003o`000?o_@@3o000000[o
oooo00Co0000oooooooooooo00001?ooool0047ooooo00?o0000ooooooooool01?ooool00ol0003o
i6/0o`000006onAZ00;o00001OoHT@000ol0003ofXT0omZ90002omZ90003o`000?o;]03o000000Ko
cjT000?o0000olG20?o5`P001?o5`P000ol0003oc;40o`000004ojJm0004o`000?o6`@3oa/40o`00
00CoSkP000Co0000ok[20?nj`P3o00001?n4]0001?l0003o]L40okG10?l00005ohBd00;o00001_n?
^0001?l0003oJjh0of^^0?l00003ojJm0003o`000?n7]@3oQkD000?oQkD000?o0000off^0?m][P00
0_l000000on__`3o0000oi^j0004oi^j0003o`000?n=]`3oSKL000?oSKL000?o0000ohBd0?n4]000
0_n4]002o`0000GoaL8000?o0000olK10?o6`@000oo6`@000ol0003ob;`0olRl0002olRl0003o`00
0?o;]03obk@000?obk@000?o0000olnY0?o?Z@000oo?Z@000ol0003oe9/0omBK0002omBK0003o`00
0?oJR@3ofXT000?ofXT000?o0000on5e0?oQM@000_oQM@000ol0003oif00onMP0002onMP0003o`00
0?o]BP3okDX000?okDX000?o0000oo8f0?ob=P000oob=P000ol0003ombD0ooLU0003ooLU0004o`00
0?oi6`3onA/0ooTK00Co00000oof9`04o`0000cooooo00?o0000ooooool000001?ooool004;ooooo
00?o0000ooooooooool01?ooool2o`0000Goi6X000Co0000onEU0?oUI@3o00000ooHT@000ol0003o
fXT0omZ90004omZ90003o`000?o?Z@3ocjT000CocjT000?o0000omBK0?l000001?o5`P001Ol0003o
c;40olba0?o</@3o000000;oY[d000?o0000olK10?o6`@000_o6`@001?l0003oSkP0ohnh0?l00004
ok[20004o`000?n4]03oQ;@0o`0000?o]L4000?o0000ohBd0?n4]0000_n4]0000ol0003o^/80o`00
0006ohnh0003o`000?m[[P3o000000CoY[d000?o0000ohNe0?n7]@000on7]@000ol0003oKJh0o`00
0004ojno0003o`000?nK^P3oVkX000?oVkX000?o0000ohfg0?n=]`000_n=]`000ol0003oQ;@0o`00
0002o`000003olK10?l0003oaL8000CoaL8000?o0000olK10?o6`@000oo6`@000ol0003ob;`0olRl
0003olRl0003o`000?o;]03obk@000;obk@000?o0000olnY0?o?Z@000oo?Z@000ol0003oe9/0omBK
0002omBK0003o`000?oJR@3ofXT000?ofXT000?o0000on5e0?oQM@000_oQM@000ol0003oif00onMP
0003onMP0003o`000?o]BP3okDX000?okDX000?o0000oo8f0?ob=P000oob=P001?l0003ombD0ooLU
0?og9@05o`0000ConA/000Go0000ooHW0?l0003okd40o`00000?ooooo`;o00001?ooool004?ooooo
00?o0000ooooooooool01Oooool01Ol0003oi6X0onAZ0?oTJP3o000000CoiFD000?o0000omRA0?l0
00001_oJR@02o`0000GocjT000Go0000omBK0?oDV`3oe9/0o`000002olG20003o`000?o</@3oc;40
00;oc;4000?o0000ojJm0?l000001Oo6`@000ol0003oSkP0o`000005ok[20003o`000?n4]03o0000
00Go]L4000Co0000ohBd0?n4]03o00000onj`P000ol0003oSkP0ohnh0003ohnh00;o00001_nV_@00
0ol0003oQkD0ohNe0002ohNe00;o00001On__`000ol0003oVkX0oi^j0003oi^j0003o`000?n=]`3o
SKL000;oSKL00_l00005olK10003o`000?o5`P3oaL8000?oaL8000?o0000olK10?o6`@000_o6`@00
0ol0003ob;`0olRl0003olRl0003o`000?o;]03obk@000;obk@000?o0000olnY0?o?Z@000oo?Z@00
0ol0003oe9/0omBK0002omBK0003o`000?oJR@3ofXT000?ofXT000?o0000on5e0?oQM@000ooQM@00
0ol0003oif00onMP0002onMP0003o`000?o]BP3okDX000?okDX000Co0000oo8f0?ob=P3olSH01_l0
0003ooTJ0003o`000?oi6`3onA/000?onA/01?l0000?ooooo`?o00001?ooool004Cooooo00?o0000
ooooooooool01Oooool00ol0003oi6X0o`000005onEU00?o00001OoJR@001?l0003ogWh0omin0?l0
0003olnY0003o`000?oDV`3oe9/000;oe9/000?o0000olG20?l000001_o</@000ol0003oa/40olK1
0005olK10003o`000?nj`P3o^/8000Go^/8000?o0000okG10?ne`@001?ne`@000ol0003oQ;@0o`00
0004ok[20003o`000?n?^03oSkP000;oSkP000?o0000olK10?l000001_nV_@000ol0003oQkD0ohNe
0002o`000003olG20?l0003o[kl000Go[kl000?o0000oi^j0?nK^P000_nK^P000ol0003oSKL0o`00
0002o`000003olRl0?l0003oa/4000Coa/4000?o0000olG20?o5`P000oo5`P000ol0003oa/40olK1
0003olK10003o`000?o8_03ob;`000;ob;`000Co0000ol^d0?o;]03obk@09ol00003ooLR0003o`00
0?oi6P3onAX000ConAX000?o0000ooTK0?l000000_l000000oof:@3o0000ooooo`0<ooooo`Co0000
1oooool004Gooooo0_l00006ooooo`03o`000?oUI@3oiFD000?oiFD000Go0000onMN0?oWGP3oieh0
o`000003omZ90003o`000?oNOP3ogWh000;ogWh000?o0000olnY0?l000001_oDV`000ol0003oc;40
olba0004olba00;o00001_o6`@02o`0000Ko^/800_l00007okG10003o`000?nj`P3o^/8000Co^/80
00Co0000ohnh0?n?^03o00000oo6`@000ol0003oY[d0ojJm0003ojJm0003o`000?n7]@3o000000Co
aL8000?o0000ojno0?n__`000on__`000ol0003oVkX0oi^j0002oi^j00;o00001Oo8_0000ol0003o
a/40olK10003olK10003o`000?o5`P3oaL8000;oaL8000Co0000olK10?o6`@3oa/402ol00002omZ9
0003o`000?oNOP3ogWh000?ogWh000?o0000on9a0?oRL@000_oRL@000ol0003oiV40onIQ0003onIQ
0003o`000?o[D03oje0000;oje0000?o0000oo0o0?o`?`000oo`?`000ol0003om2l0oo@_0003oo@_
0003o`000?og8P3omb8000Comb8000?o0000ooTJ0?oi6P000ooi6P02o`0000?omRT000?o0000oooo
ooooool02Oooool3o`0000_ooooo0017ooooo`03o`000?oooooooooo00Cooooo00Go0000onEU0?oU
I@3oiFD0o`000005onMN0003o`000?oJR@3o000000KogWh000?o0000omBK0?oDV`001?oDV`02o`00
00Goc;4000Co0000omBL0?oDW03o00001?o6`@001?l0003ocjT0olnY0?l00004ok[20004o`000?o=
[`3ocJl0o`0000Go]L400_l00006ok[20003o`000?n?^03o000000Coa/4000?o0000ojJm0?nV_@00
0onV_@02o`0000GoaL8000?o0000ojno0?n__`000on__`000ol0003oVkX0o`000002o`000003ol^d
0?l0003ob;`000Cob;`000?o0000olK10?o6`@000oo6`@000ol0003oaL80olG20002olG200Co0000
0_oFUP000ol0003of940omRA0003omRA0003o`000?oJR@3ofXT000?ofXT000?o0000omin0?oNOP00
0ooNOP000ol0003ohW40on9a0002on9a0003o`000?oVH@3oiV4000?oiV4000?o0000on]@0?o[D000
0_o[D0000ol0003ol3l0oo0o0003oo0o0003o`000?od;`3om2l000?om2l000?o0000ooLR0?og8P00
0oog8P000ol0003onAX0ooTJ0003o`0000;onAd000?o0000ooHY0?l000002?ooool4o`0000kooooo
0018ooooo`03o`000?oooooooooo00Cooooo00?o0000onEU0?l000001_oWGP02o`0000KogWh00_l0
0005omBK0004o`000?oJR@3ofXT0o`0000?oc;4000?o0000omBL0?oDW0000_oDW0001?l0003oa/40
olK10?l00004olnY0004o`000?nj`P3o^/80o`0000?ocJl000?o0000okG10?ne`@000_ne`@001?l0
003ocJl0olf_0?l00005ok[200;o00001_o6`@001ol0003oY[d0ojJm0?nV_@3o0000olba0?l00000
1_o5`P000ol0003o[kl0ojno0002ojno00;o00001?o;]0000ol0003ob;`0olRl0004olRl0003o`00
0?o6`@3oa/4000;oa/4000?o0000olG20?l000000_l000000ooFV03o0000omJF0004omJF0003o`00
0?oHT@3of94000?of94000?o0000omZ90?oJR@000_oJR@000ol0003ogWh0omin0003omin0003o`00
0?oRL@3ohW4000;ohW4000?o0000onIQ0?oVH@000ooVH@000ol0003oje00on]@0003on]@0003o`00
0?o`?`3ol3l000?ol3l000?o0000oo@_0?od;`000_od;`001?l0003omb80ooLR0?og8P05o`0000Go
nAd00_l00005ooooo`Co00004_ooool004Wooooo00?o0000ooooooooool01?ooool00ol0003oieh0
onMN0004onMN0003o`000?oZE@3o000000GogWh000Co0000on9a0?oRL@3o00000ooDV`000ol0003o
fXT0omZ90002omZ90003o`000?o</@3o000000Goe9`000?o0000olK10?l000001Oo?Z@000ol0003o
^/80o`000005olf_0004o`000?ne`@3o]L40o`0000?ocJl000?o0000ok[20?nj`P000_nj`P000ol0
003ocjT0o`000006olK10004o`000?nV_@3oY[d0o`0000?oc;4000?o0000olG20?o5`P000oo5`P00
0ol0003o[kl0ojno0002o`000003olnY0?l0003obk@000Cobk@000?o0000olRl0?o8_0000oo8_000
0ol0003oa/40olK10002olK100;o00001OoFV0000ol0003oeYH0omJF0002omJF0003o`000?oHT@3o
f94000?of94000?o0000omZ90?oJR@000ooJR@000ol0003ogWh0omin0002omin0003o`000?oRL@3o
hW4000?ohW4000?o0000onIQ0?oVH@000_oVH@000ol0003oje00on]@0003on]@0004o`000?o`?`3o
l3l0oo0o00_o00001?oi6P000ol0003onAd0ooTM0003o`0000?ooooo1?l0000Fooooo`00B_ooool2
o`0000Cooooo00?o0000onMN0?oWGP000ooWGP001Ol0003ojUD0onYE0?oZE@3o000000?ogWh000?o
0000on9a0?oRL@000_oRL@000ol0003oe9/0o`000006omZ90003o`000?oDW03oe9`000Goe9`000?o
0000olnY0?o?Z@001Oo?Z@000ol0003ocJl0olf_0004olf_0003o`000?ne`@3o000000GocJl000Co
0000ok[20?nj`P3o00000oo?Z@000ol0003oa/40olK10003olK10003o`000?nV_@3o000000Coc;40
00?o0000olG20?o5`P000oo5`P000ol0003o[kl0o`000003olnY0003o`000?o;]03obk@000?obk@0
00?o0000olRl0?o8_0000oo8_0000ol0003oa/40o`000002o`000003omJF0?l0003oeYP000CoeYP0
00?o0000omJF0?oFUP000ooFUP000ol0003of940omRA0002omRA0003o`000?oJR@3ofXT000?ofXT0
00?o0000omin0?oNOP000ooNOP000ol0003ohW40on9a0002on9a0004o`000?oVH@3oiV40onIQ00_o
00000oof9P000ol0003on1d0ooPM0002ooPM0003o`000?oi6P3onAX000ConAX00ol00002ooooo`Co
00006_ooool004cooooo00?o0000ooooooooool00_ooool01Ol0003oieh0onMN0?oWGP3o000000Go
jUD000?o0000omin0?l000001OoRL@02o`0000KofXT00_l00006omBL00;o00001_o?Z@02o`0000Ko
cJl00_l00006olf_0003o`000?nj`P3o000000CocjT000?o0000olK10?o6`@000oo6`@02o`0000Ko
c;4000?o0000olG20?o5`P000_o5`P02o`0000GocjT000?o0000ol^d0?o;]0000_o;]0000ol0003o
b;`0olRl0003olRl00;o00001OoFUP000ol0003oeYP0omJH0003omJH0003o`000?oFUP3oeYH000;o
eYH000?o0000omRA0?oHT@000ooHT@000ol0003ofXT0omZ9000Ao`0000;ol3d000?o0000oo<a0?oc
<@000ooc<@000ol0003omRH0ooHV0004ooHV0003o`000?oh7@3on1d000;on1d000?o0000ooTJ0?oi
6P000ol00002ooooo`?o00007_ooool004gooooo00?o0000ooooooooool00_ooool00ol0003oieh0
o`000006onYE00;o00001OoRL@000ol0003oiV40o`000005omZ90004o`000?oQM@3ohGD0o`0000Co
e9`000Co0000omb50?oLQ@3o00001?o?Z@001?l0003ofHh0omV>0?l00004olf_0003o`000?oHT@3o
000000OocJl000?o0000olnY0?o?Z@001?o?Z@001ol0003oa/40olK10?o6`@3o0000omBL0?l00000
1_o</@000ol0003oaL80olG20002o`000003omBK0?l0003ocjT000CocjT000?o0000ol^d0?o;]000
0oo;]0000ol0003ob;`0o`000002o`000003omRA0?l0003oeYH000CoeYH000?o0000omJH0?oFV000
0ooFV0000ol0003oeYH0omJF0002omJF0004o`000?oHT@3of940omRA00Go00000ooWGP000ol0003o
jUD0onYE0002onYE0003o`000?o]BP3okDX000?okDX000?o0000oo0m0?o`?@000oo`?@000ol0003o
lc40oo<a0003oo<a0003o`000?of9P3omRH000?omRH000Co0000ooPM0?oh7@3on1d01?l000000ooo
oooo0000o`000002o`00027ooooo001>ooooo`03o`000?oooooooooo00;ooooo0_l00005onYE0004
o`000?o]BP3okDX0o`0000?ohW4000Go0000onIQ0?oVH@3oiV40o`000003omZ90003o`000?oQM@3o
hGD000;ohGD000Co0000omBL0?oDW03o00001?oLQ@001?l0003ocjT0olnY0?l00004omV>0004o`00
0?o=[`3ocJl0o`0000?of94000?o0000olf_0?o=[`000oo=[`02o`0000KocjT000Co0000olK10?o6
`@3o00000ooDW0000ol0003oc;40olba0003olba0003o`000?o5`P3o000000?oe9/000?o0000olnY
0?o?Z@000oo?Z@000ol0003obk@0ol^d0002ol^d00?o00001OoHT@000ol0003oeYH0omJF0003omJF
0003o`000?oFV03oeYP000;oeYP000Co0000omJF0?oFUP3oeYH01Ol00002onEU0003o`000?oWGP3o
ieh000Coieh000?o0000onYE0?oZE@000_oZE@000ol0003okDX0one:0003one:0003o`000?o`?@3o
l3d000?ol3d000?o0000oo<a0?oc<@000_oc<@001?l0003omRH0ooHV0?of9P06o`000003ooooool0
003o000000;o00009Oooool004oooooo0_l00004ooooo`05o`000?oZE@3ojUD0onYE0?l000001?o]
BP000ol0003ohW40o`000005onIQ0003o`000?oJR@3o000000GohGD000?o0000omBL0?l000001OoL
Q@000ol0003ocjT0o`000005omV>0003o`000?o=[`3o000000Cof94000?o0000olf_0?o=[`000_o=
[`001?l0003ofHh0omV>0?l00005olnY0003o`000?o6`@3o000000Coe9`000?o0000olba0?o</@00
0oo</@02o`0000Goe9/000?o0000olnY0?o?Z@000oo?Z@04o`000003omZ90?l0003of94000Gof940
00?o0000omJF0?oFUP000ooFUP000ol0003oeYP0omJH0002omJH00Co00000_oTJP000ol0003oiFD0
onEU0003onEU0003o`000?oWGP3oieh000?oieh000?o0000onYE0?oZE@000ooZE@000ol0003okDX0
one:0002one:0003o`000?o`?@3ol3d000?ol3d000Co0000oo<a0?oc<@3olc401Ol00003ooooo`Co
0000:Oooool0057ooooo00?o0000ooooooooool00_ooool00ol0003ojUD0o`000005one:00;o0000
1_oVH@02o`0000KohGD00_l00006omb500;o00001ooISP000ol0003of940omRA0004omRA0004o`00
0?o=[`3ocJl0o`0000?ofHh000?o0000olnY0?o?Z@000oo?Z@02o`0000Goe9`000Co0000olba0?o<
/@3oc;400_l000000ooJR@3o0000omBK0004omBK0003o`000?o?Z@3ocjT000;ocjT00_l00005omZ9
0003o`000?oHT@3of94000?of94000?o0000omJF0?oFUP000ooFUP000ol0003oeYP0o`000002o`00
0003onA[0?l0003oi6X000Coi6X000?o0000onEU0?oUI@000_oUI@000ol0003oieh0onMN0003onMN
0003o`000?oZE@3ojUD000?ojUD000?o0000one:0?o]BP000_o]BP001?l0003ol3d0oo0m0?o`?@06
o`0000Cooooo1?l0000]ooooo`00D_ooool00ol0003oooooooooo`02ooooo`03o`000?o]BP3okDX0
00?okDX000?o0000oo0m0?l000001OoVH@000ol0003oje00o`000005on5e0003o`000?oWH03o0000
00Gog8D000?o0000onA[0?l000001_oISP02o`0000Kof94000?o0000olf_0?l000001OoISP000ol0
003ocjT0olnY0002o`000003omb50?l0003oe9`000Goe9`00ol00004omZ90003o`000?oDV`3oe9/0
00;oe9/000?o0000olnY0?o?Z@000_l000000ooNOP3o0000omZ90004omZ90003o`000?oHT@3of940
00Cof94000?o0000omJF0?oFUP001?l00005onA[0003o`000?oTJP3oi6X000;oi6X000?o0000onEU
0?oUI@000ooUI@000ol0003oieh0onMN0003onMN0003o`000?oZE@3ojUD000_o00001oooool3o`00
037ooooo001Cooooo`03o`000?oooooooooo00;ooooo00Go0000one:0?o]BP3okDX0o`000003oo0m
0005o`000?oVH@3oiV40onIQ0?l000000oo[D0001Ol0003ohGD0on5e0?oQM@3o000000?oif0000Go
0000omb50?oLQ@3og8D0o`000003onA[0003o`000?oISP3ofHh000;ofHh000Co0000on9a0?oRL@3o
00001OoHT@02o`0000KofHh000?o0000olnY0?l000001?oLQ@000ol0003oe9`0omBL0002omBL00;o
00001_oJR@000ol0003oe9/0omBK0003omBK00;o00001?oNOP000ol0003ofXT0omZ90003omZ90003
o`000?oHT@3of94000;of9401?l00003onAZ0003o`000?oTJ`3oi6/000?oi6/000?o0000onAZ0?oT
JP000ooTJP000ol0003oiFD0onEU0002onEU0004o`000?oWGP3oieh0onMN00Go00003_ooool4o`00
03Cooooo001Dooooo`;o00000oooool00ol0003okDX0o`000005oo0m0003o`000?oVH@3o000000Go
je0000?o0000on5e0?l000001OoWH0000ol0003og8D0o`000005onA[0004o`000?oISP3ofHh0o`00
00?ohW4000?o0000omRA0?oHT@000_oHT@000ol0003ohW40o`000006omV>00;o00001OoLQ@001ol0
003oe9`0omBL0?oDW03o0000on5e0?l000001_oJR@000ol0003oe9/0omBK0002omBK00;o00001OoN
OP000ol0003ofXT0omZ90003omZ90003o`000?oHT@3o000000;o000000?oiFD0o`000?oTJP001OoT
JP000ol0003oi6/0onA[0002onA[0003o`000?oTJP3oi6X000?oi6X000Co0000onEU0?oUI@3oiFD0
1Ol0000?ooooo`Co0000>?ooool005Kooooo00Go0000ooooooooooooooooo`000006oo0m00;o0000
1_o[D002o`0000Koif000_l00006onA[0003o`000?oISP3o000000GohW4000Co0000omRA0?oHT@3o
00000ooRL@000ol0003ofHh0omV>0002omV>0003o`000?oTJ`3o000000Gog8D000Co0000omBL0?oD
W03o00000ooQM@000ol0003ofXT0omZ90004omZ900Co000000?ohW40o`000?oNOP001OoNOP000ol0
003ofXT0omZ90002omZ900;o00001OoUI@000ol0003oi6X0onAZ0003onAZ0003o`000?oTJ`3oi6/0
00?oi6/000?o0000onAZ0?oTJP001_l0000@ooooo`Co0000??ooool005Oooooo00Co0000oooooooo
oooo00001Oo`?@000ol0003olc40o`000005on]@0003o`000?o`?`3o000000Goif0000?o0000one:
0?l000001_oTJ`02o`0000KohW4000?o0000omRA0?l000001OoRL@001?l0003ofHh0omV>0?l00003
onA[0003o`000?oLQ@3og8D000?og8D00_l00004on5e0003o`000?oJR@3ofXT000?ofXT00_l00005
on9a0003o`000?oNOP3ogWh000?ogWh000?o0000omZ90?l000000_l000000ooWGP3o0000onEU0004
onEU0003o`000?oTJP3oi6X000?oi6X000?o0000onA[0?oTJ`000_oTJ`04o`0001;ooooo1?l00010
ooooo`00F?ooool01?l0003oooooooooool00003oo0m0005o`000?oc<@3olc40oo<a0?l000000oo[
D0001Ol0003ol3l0oo0o0?o`?`3o000000?oif0000Go0000one:0?o]BP3okDX0o`000004onA[0003
o`000?o[D@3o000000KohW400_l00006on9a0003o`000?oISP3o000000Coi6/000?o0000omb50?oL
Q@000_oLQ@02o`0000KohGD000?o0000omZ90?oJR@000_l000000ooVH@3o0000on9a0004on9a0003
o`000?oNOP3ogWh000?ogWh00_l00005onMN0003o`000?oUI@3oiFD000?oiFD000?o0000onAZ0?oT
JP000ooTJP04o`0001?ooooo0ol00014ooooo`00FOooool2o`000004ooooool0003ol3d0o`0000Go
lc4000?o0000on]@0?l000001Oo`?`000ol0003oif00o`000005one:0004o`000?oTJ`3oi6/0o`00
00?oje4000Co0000on9a0?oRL@3ohW400_l000000ooZE03o0000on9a0005on9a00;o00001OoTJ`00
0ol0003og8D0omb50002o`000003onMP0?l0003ohGD000GohGD000?o0000omZ90?l000001?oVH@00
0ol0003ohW40on9a0003on9a0003o`000?oNOP3ogWh000;o000000?ojUD0o`000?oWGP001?oWGP00
0ol0003oiFD0onEU0003onEU0004o`000?oTJP3oi6X0onAZ00?o00004_ooool4o`0004Oooooo001K
ooooo`03o`000?oooooo000000Kolc400_l00006oo0o00;o00001_o]BP000ol0003oi6/0o`000005
on]A0003o`000?oRL@3o000000CojU@000Co0000on9a0?oRL@3ohW400_l000000oo[D@3o0000onA[
0005onA[00;o00001?oWH0000ol0003ohGD0on5e0003on5e00;o00001OoVH@000ol0003ohW40on9a
0003on9a0003o`000?oNOP3o000000CojUD000?o0000onMN0?oWGP000ooWGP000ol0003oiFD0onEU
0002onEU00Co00004Oooool4o`0004_ooooo001Looooo`03o`000?oooooo000000?olc400_l00002
ooHV0004o`000?o`?`3ol3l0oo0o00;o000000?om2l0o`000?o]BP001Oo]BP02o`0000Koje400_l0
0006onYD0003o`000?oRL@3o000000Coje4000?o0000onA[0?oTJ`000_oTJ`02o`0000Koif0000?o
0000on5e0?oQM@000_l000000oo[D03o0000onIQ0005onIQ0003o`000?oRL@3ohW4000;ohW400_l0
0005onYE0003o`000?oWGP3oieh000?oieh000?o0000onEU0?l000000_l0000Aooooo`Co0000Cooo
ool005gooooo00Go0000ooooool0003olc40o`000005ooHV0003o`000?o`?`3o000000Com2l000Co
0000one:0?o]BP3okDX00_l000000oob=P3o0000on]A0004on]A0003o`000?oa>@3o000000KojU@0
0_l00005on]A0003o`000?oTJ`3oi6/000;o000000?okDX0o`000?oWH0001OoWH0000ol0003ohGD0
o`000004on]@0003o`000?oVH@3oiV4000?oiV4000?o0000on9a0?l000000_l000000oo]BP3o0000
onYE0005onYE0003o`000?oWGP3oieh000;oieh00_l0000@ooooo`Co0000Doooool005kooooo0ol0
0006ooHV00;o00001_od;`000ol0003okDX0o`000004oo8f0005o`000?o[D@3oje40on]A0?l00000
0ooa>@000ol0003ojU@0onYD0002onYD0003o`000?oa>@3o000000Goje4000?o0000onA[0?l00000
1?o]BP000ol0003oif00onMP0003onMP00;o00001_o[D0000ol0003oiV40onIQ0002onIQ00;o0000
1Oo]BP000ol0003ojUD0onYE0003onYE0003o`000?oWGP3o000000;o00003oooool3o`0005Oooooo
001Pooooo`;o00000oof9P02o`000003ooPM0?l0003om2l000Gom2l00_l00006oo8f0003o`000?o[
D@3o000000GolCT000Co0000onYD0?oZE03o00000ooa>@000ol0003oje40on]A0002on]A00;o0000
1_o]BP000ol0003oif00onMP0002o`000003oo0o0?l0003oje0000Goje0000?o0000onIQ0?l00000
0_l000000oo`?@3o0000one:0005one:0003o`000?oZE@3ojUD000;ojUD00_l0000>ooooo`Co0000
F_ooool0067ooooo0_l000000oof9P3o0000ooPM0003ooPM0004o`000?od;`3om2l0oo@_00;o0000
0_og8P000ol0003olSH0oo8f0003oo8f00;o00001_oa>@000ol0003ojU@0o`000004oo4i0003o`00
0?o[D@3oje4000;o000000?olSH0o`000?o]BP001Oo]BP000ol0003oif00o`000004oo0o0003o`00
0?o[D03oje0000?oje000_l00005oo0m0003o`000?o]BP3okDX000?okDX000?o0000onYE0?l00000
0_l0000<ooooo`Co0000G_ooool006;ooooo0ol00005ooPM0003o`000?od;`3o000000Gomb8000?o
0000oo8f0?l000000_l00002ooLU0003o`000?oa>@3olCT000?olCT00_l00005oo4i0003o`000?o[
D@3o000000ColSH000?o0000one:0?o]BP000oo]BP02o`0000Kol3l000?o0000on]@0?o[D0000_l0
00000ooc<@3o0000oo0m0005oo0m0003o`000?o]BP3okDX000;okDX00_l0000;ooooo`Co0000H_oo
ool006?ooooo0ol00003ooPM00Co00001Oog8P02o`0000KombD000?o0000oo4i0?l000000_l00000
0oof9P3o0000oo4i0004oo4i00;o00001_ob=P000ol0003okDX0o`000002o`000003oo@_0?l0003o
l3l000Gol3l000?o0000on]@0?l000001?oc<@000ol0003ol3d0oo0m0003oo0m0003o`000?o]BP3o
000000;o00002_ooool3o`0006Kooooo001Uooooo`Co00001?oi6P000ol0003omb80o`000002o`00
0003ooTJ0?l0003ombD000GombD00_l00005ooHV0003o`000?oa>@3olCT000;o000000?ombD0o`00
0?ob=P001Oob=P02o`0000Gom2l000?o0000oo0o0?o`?`000oo`?`02o`0000Kolc4000?o0000oo0m
0?o`?@000_o`?@02o`0000Wooooo1?l0001Yooooo`00I_ooool2o`0000GonAX00_l00005ooTJ0004
o`000?og9@3ombD0ooLU00;o000000?onA/0o`000?of9P001?of9P000ol0003olCT0o`000004ooLU
0004o`000?ob=P3olSH0oo8f00;o000000?omb80o`000?od;`001Ood;`000ol0003ol3l0o`000002
o`000003ooHV0?l0003olc4000Golc4000?o0000oo0m0?l000000_l00007ooooo`Co0000KOooool0
06Oooooo0_l000001?oi6P3o0000o`000?l00002ooTM0003o`000?oi6P3onAX000?onAX000?o0000
ooLU0?l000001?oi6`000ol0003omRH0ooHV0002ooHV00;o00001_og9@000ol0003olSH0o`000004
ooLR0003o`000?od;`3om2l000?om2l00_l00005ooHV0003o`000?oc<@3olc4000?olc400_l00006
ooooo`Co0000LOooool006Sooooo1?l00004ooTM0004o`000?oi6P3onAX0ooTJ00Co00001Ooi6`00
1?l0003omRH0o`000?l00002ooTK0003o`000?og9@3ombD000?ombD00_l00006ooLR0003o`000?od
;`3o000000;o000000?on1d0o`000?of9P001Oof9P000ol0003olc40o`000002o`0000Cooooo1?l0
001eooooo`00JOooool2o`000003ooooool0003o000000Ko00001?oi6`001?l0003onA/0ooTK0?oi
6`03o`0000GonA/000?o0000ooLU0?l000000_l00002ooTJ0003o`000?og8P3omb8000?omb800_l0
0005ooPM0003o`000?of9P3omRH000?omRH00_l00004ooooo`?o0000NOooool006_ooooo00Co0000
oooooooooooooooo3Ol00003ooTK0004o`000?oi6`3onA/0ooTK00Co00001Ooi6P000ol0003omb80
o`000002o`0000;onAX000?o0000ooPM0?oh7@000ooh7@000ol0003omRH0o`000002o`0000;ooooo
1?l0001looooo`00K?ooool00ol0003oooooooooo`07ooooo`Ko00000_oi6`05o`0000ConA/000Co
0000ooTJ0?oi6P3onAX01?l00005ooTJ0004o`000?oh7@3on1d0ooPM00?o000000?oooooo`000?l0
00000_l00020ooooo`00KOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So0000
0ooi6`05o`0000ConAd000Co0000ooTJ0?oi6P3onAX02Ol00024ooooo`00K_ooool2o`0000Sooooo
00?o0000ooooooooool01ooooolAo`000003ooooool0003o000000;o0000R?ooool0073ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000S?ooool0077ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000Soooool007;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000Toooool007?ooooo0_l00003ooooo`03
o`000?oooooooooo00[ooooo1?l0002Gooooo`00MOooool01?l0003oooooooooool00008ooooo`Co
0000Voooool007Kooooo00?o0000ooooool000001Oooool3o`0009oooooo001gooooo`;o000000?o
ooooo`000?l000000_l0002Rooooo`00N?ooool2o`000:Kooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo000Zooooo`?o0000R_ooool00ol0003oooooooooo`0[ooooo`?o00005Ooo
ool00ol0003oooooooooo`0Pooooo`00:oooool00ol0003oooooooooo`28ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`009Oooool3o`00
00?ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003ooooo`Co000000?oooooo`00
0?l000000ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001_ooool4o`00
00;ooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o00000_ooool3o`00
00;ooooo0ol00004ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`?o00000oooool3
o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`Co00000oooool0
0ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000Cooooo
o`000?l0003ooooo1?l00003ooooo`;o00000_ooool:o`0000Gooooo00?o0000ooooooooool07_oo
ool002Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_oo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool002Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`Go
00000_ooool01_l0003oooooooooool0003oooooo`0000Gooooo1Ol00008ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o00000oooool00ol0003oooooo`00
0002ooooo`Go00000oooool01?l0003oooooooooooooool5o`0000;ooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00000_oo
ool3o`0000Gooooo00?o0000ooooooooool07_ooool002Cooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Sooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000000oooool01?l0003oooooooooool00005ooooo`06o`000?ooooooooooo`00
0?oooooo00002?ooool00ol0003oooooooooo`0Nooooo`009?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000oooool2o`0000Gooooo00?o
0000ooooooooool02?ooool01?l0003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo
0ol00009ooooo`05o`000?ooooooooooo`000?ooool00ol00004ooooo`Co00000_ooool4o`0000;o
oooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l00003ooooo`?o
00000oooool3o`0000Wooooo00?o0000ooooooooool00_ooool6o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o
00000_ooool4o`0000?ooooo2Ol00003ooooo`?o00000oooool4o`0000Cooooo00?o0000oooooooo
ool07_ooool002Cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01oooooo000Uooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00gooooo0ol00009ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool4o`00
00Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0000^ooooo`03o`000?oooooooooo
01Sooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000;ooooo`03o`000?oooooooooo
023ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0426235, 0.0647328, \
0.00350953, 0.00350953}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(15.599999999999994`\ Second\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            
            RowBox[{\(ComponentNumber \[Rule] 4\), 
              ",", \(Energy \[Rule] 100.`\), 
              ",", \(Offset \[Rule] 404.60460957382384`\), ",", 
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                
                TagBox[\(CompiledFunction[
                    If[#1 == 0 && #2 == 0, 
                      404.6046047205401`, \(\(404.60584531819734`\)\(\
\[InvisibleSpace]\)\) + 
                        0.0006497225325793415`\ \((\(-1\) + 
                              0.015586020716804094`\ \((#1\^2 + #2\^2)\))\) - 
                        0.0006015161578868928`\ \((1 - 
                              0.04675806215041228`\ \((#1\^2 + #2\^2)\) + 
                              0.0003643860626769696`\ \((#1\^2 + #2\^2)\)\^2)\
\) + 2.008720187412277`*^-7\ Cos[
                            4\ ArcTan[#1, #2]]\ \((\(-0.000303655052230808`\)\
\ \((#1\^2 + #2\^2)\)\^2 + 
                              2.8396643608989616`*^-6\ \((#1\^2 + \
#2\^2)\)\^3)\) - 0.000010641033219342808`\ \((\(-1\) + 
                              0.09351612430082457`\ \((#1\^2 + #2\^2)\) - 
                              0.001821930313384848`\ \((#1\^2 + #2\^2)\)\^2 + 
                              9.465547869663206`*^-6\ \((#1\^2 + #2\^2)\)\^3)\
\)], "-CompiledCode-"]\),
                  False,
                  Editable->False]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                
                TagBox[\(CompiledFunction[
                    If[#1 == 0 && #2 == 
                          0, \(-0.009122710859336653`\), \
\(\(2.3228277717345365`\)\(\[InvisibleSpace]\)\) + 
                        2.5944485516529135`*^-8\ Cos[
                            4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 + 
                        1.2212829571875525`\ \((\(-1\) + 
                              0.015586020716804094`\ \((#1\^2 + #2\^2)\))\) - 
                        1.1306694658429235`\ \((1 - 
                              0.04675806215041228`\ \((#1\^2 + #2\^2)\) + 
                              0.0003643860626769696`\ \((#1\^2 + #2\^2)\)\^2)\
\) + 0.0003775808781546684`\ Cos[
                            4\ ArcTan[#1, #2]]\ \((\(-0.000303655052230808`\)\
\ \((#1\^2 + #2\^2)\)\^2 + 
                              2.8396643608989616`*^-6\ \((#1\^2 + \
#2\^2)\)\^3)\) - 0.0200019404366029`\ \((\(-1\) + 
                              0.09351612430082457`\ \((#1\^2 + #2\^2)\) - 
                              0.001821930313384848`\ \((#1\^2 + #2\^2)\)\^2 + 
                              9.465547869663206`*^-6\ \((#1\^2 + #2\^2)\)\^3)\
\)], "-CompiledCode-"]\),
                  False,
                  Editable->False]}], 
              ",", \(OpticalPathRange \[Rule] {404.6046095738237`, 
                  404.6062675366269`}\), ",", 
              RowBox[{"OutputGraphics", "\[Rule]", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"OpticalLengthFunction", "\[Rule]", 
                      RowBox[{"(", 
                        
                        TagBox[\(\[SkeletonIndicator]  
                            SurfaceGraphics  \[SkeletonIndicator]\),
                          False,
                          Editable->False], ")"}]}], ",", 
                    RowBox[{"WaveFrontIntensity", "\[Rule]", 
                      RowBox[{"(", 
                        
                        TagBox[\(\[SkeletonIndicator]  
                            SurfaceGraphics  \[SkeletonIndicator]\),
                          False,
                          Editable->False], ")"}]}], ",", 
                    RowBox[{"OpticalPathDifference", "\[Rule]", 
                      RowBox[{"(", 
                        
                        TagBox[\(\[SkeletonIndicator]  
                            SurfaceGraphics  \[SkeletonIndicator]\),
                          False,
                          Editable->False], ")"}]}]}], "}"}]}], 
              ",", \(RayBoundary \[Rule] {{\(-8.009997405593364`\), 
                    8.009997405593406`}, {\(-8.009997405593413`\), 
                    8.009997405593413`}}\), 
              ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
              ",", \(ResidualFitError \[Rule] 0.00012449664901403496`\), 
              ",", \(Source \[Rule] 1\), ",", \(SpatialScale \[Rule] 1\), 
              ",", \(SurfaceNumber \[Rule] 1\), 
              ",", \(WaveFrontID \[Rule] 1\), ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                
                TagBox[\(InterpolatingFunction[{{\(-10.750491754535453`\), 
                        10.750491754535496`}, {\(-10.750491754535503`\), 
                        10.750491754535503`}}, "<>"]\),
                  False,
                  Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
              ",", \(WaveTilt \[Rule] WaveTilt\), 
              ",", \(ZernikeFit \[Rule] True\)}], "}"}], "}"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[27]=",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["wavefront2 = FindWaveFronts[sys2]//Timing", "Input",
  CellLabel->"In[28]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 6, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 1, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 6, SurfaceNumber -> 1, 
        WaveFrontID -> 1, Source -> 1}],
      Editable->False]], "Print",
  CellLabel->"From In[28]:=",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.23085e-12 1.04977 -0.0679587 1.04977 [
[.5 .82364 -117 0 ]
[.5 .82364 117 9 ]
[.07261 .22845 -18 -8.83299 ]
[.07261 .22845 0 .16701 ]
[.26329 .15343 -11.4506 -9 ]
[.26329 .15343 .54943 0 ]
[.46894 .07256 -5.33495 -9 ]
[.46894 .07256 .66505 0 ]
[.76362 .09117 0 -6.16757 ]
[.76362 .09117 12 2.83243 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93772 .35778 0 -5.91556 ]
[.93772 .35778 6 3.08444 ]
[.01634 .31384 -42 -2.78352 ]
[.01634 .31384 0 6.21648 ]
[.00581 .37984 -42 -2.83952 ]
[.00581 .37984 0 6.16048 ]
[-0.00518 .44869 -42 -2.89818 ]
[-0.00518 .44869 0 6.10182 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Length \\(absolute distance\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.08206 .23755 m
.08679 .24211 L
s
[(-10)] .07261 .22845 1 .96289 Mshowa
.27211 .16314 m
.27652 .16799 L
s
[(-5)] .26329 .15343 .90843 1 Mshowa
.477 .08291 m
.48103 .08809 L
s
[(0)] .46894 .07256 .77832 1 Mshowa
.125 Mabswid
.11896 .22311 m
.12176 .22587 L
s
.1564 .20844 m
.15917 .21125 L
s
.1944 .19357 m
.19713 .19641 L
s
.23297 .17847 m
.23565 .18134 L
s
.31185 .14758 m
.31445 .15053 L
s
.35219 .13178 m
.35475 .13477 L
s
.39315 .11574 m
.39567 .11877 L
s
.43475 .09945 m
.43722 .10252 L
s
.51991 .06611 m
.52228 .06925 L
s
.5635 .04904 m
.56582 .05222 L
s
.60779 .03169 m
.61005 .03492 L
s
.6528 .01407 m
.655 .01734 L
s
.04569 .2518 m
.04856 .25449 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75132 .09573 m
.74517 .09801 L
s
[(-5)] .76362 .09117 -1 .37057 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9252 .36171 m
.91895 .36368 L
s
[(5)] .93772 .35778 -1 .31457 Mshowa
.125 Mabswid
.77092 .12571 m
.76722 .12706 L
s
.78997 .15485 m
.78627 .15618 L
s
.8085 .1832 m
.80479 .18451 L
s
.82653 .21078 m
.82281 .21206 L
s
.86116 .26374 m
.85742 .26499 L
s
.87779 .28919 m
.87406 .29043 L
s
.894 .31399 m
.89026 .3152 L
s
.9098 .33815 m
.90605 .33935 L
s
.73115 .06488 m
.72747 .06627 L
s
.71038 .03311 m
.70671 .03452 L
s
.689 .0004 m
.68533 .00183 L
s
.94023 .38469 m
.93647 .38586 L
s
.95488 .40711 m
.95111 .40826 L
s
.96918 .42898 m
.96541 .43011 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.0286 .30917 m
.03473 .30683 L
s
[(433.532)] .01634 .31384 1 -0.38144 Mshowa
.01812 .3753 m
.02427 .37303 L
s
[(433.532)] .00581 .37984 1 -0.369 Mshowa
.00719 .44429 m
.01337 .44209 L
s
[(433.533)] -0.00518 .44869 1 -0.35596 Mshowa
.125 Mabswid
.02654 .32217 m
.03022 .32078 L
s
.02446 .33529 m
.02814 .3339 L
s
.02236 .34851 m
.02605 .34713 L
s
.02025 .36185 m
.02394 .36048 L
s
.01597 .38886 m
.01966 .38751 L
s
.0138 .40254 m
.0175 .4012 L
s
.01161 .41634 m
.01532 .415 L
s
.00941 .43025 m
.01312 .42892 L
s
.03064 .29627 m
.03432 .29485 L
s
.03267 .28347 m
.03634 .28205 L
s
.03468 .27078 m
.03835 .26936 L
s
.03668 .2582 m
.04034 .25676 L
s
.00494 .45844 m
.00865 .45713 L
s
.00268 .47272 m
.00639 .47142 L
s
.0004 .48713 m
.00411 .48583 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.846 .565 0 r
.38878 .76525 .39978 .75654 .41652 .76925 .40574 .77426 Metetra
.9 .39 0 r
.40574 .77426 .41652 .76925 .43365 .77747 .42307 .77894 Metetra
.937 .255 0 r
.42307 .77894 .43365 .77747 .4511 .78181 .4407 .77997 Metetra
.961 .164 0 r
.4407 .77997 .4511 .78181 .46881 .78292 .45855 .77799 Metetra
.973 .115 0 r
.45855 .77799 .46881 .78292 .48671 .78138 .47658 .7736 Metetra
.976 .102 0 r
.47658 .7736 .48671 .78138 .50478 .77773 .49475 .76736 Metetra
.972 .116 0 r
.49475 .76736 .50478 .77773 .52298 .7725 .51303 .75979 Metetra
.964 .149 0 r
.51303 .75979 .52298 .7725 .5413 .76613 .5314 .75135 Metetra
.953 .194 0 r
.5314 .75135 .5413 .76613 .55971 .75904 .54986 .74244 Metetra
.94 .243 0 r
.54986 .74244 .55971 .75904 .57822 .75157 .5684 .73341 Metetra
.928 .291 0 r
.5684 .73341 .57822 .75157 .59682 .74403 .58703 .72457 Metetra
.915 .335 0 r
.58703 .72457 .59682 .74403 .61553 .73667 .60575 .71615 Metetra
.905 .372 0 r
.60575 .71615 .61553 .73667 .63435 .7297 .62458 .70836 Metetra
.897 .399 0 r
.62458 .70836 .63435 .7297 .6533 .72326 .64354 .70135 Metetra
.892 .416 0 r
.64354 .70135 .6533 .72326 .67239 .71744 .66264 .69521 Metetra
.891 .422 0 r
.66264 .69521 .67239 .71744 .69164 .71232 .68191 .68999 Metetra
.892 .416 0 r
.68191 .68999 .69164 .71232 .71106 .70788 .70135 .68571 Metetra
.897 .4 0 r
.70135 .68571 .71106 .70788 .73066 .70409 .721 .68232 Metetra
.905 .373 0 r
.721 .68232 .73066 .70409 .75044 .70084 .74085 .67973 Metetra
.915 .337 0 r
.74085 .67973 .75044 .70084 .77042 .698 .76091 .67779 Metetra
.927 .293 0 r
.76091 .67779 .77042 .698 .79057 .69536 .78119 .67632 Metetra
.94 .245 0 r
.78119 .67632 .79057 .69536 .8109 .69268 .80168 .67507 Metetra
.953 .196 0 r
.80168 .67507 .8109 .69268 .83137 .68962 .82235 .67373 Metetra
.964 .152 0 r
.82235 .67373 .83137 .68962 .85195 .68584 .84318 .67193 Metetra
.972 .119 0 r
.84318 .67193 .85195 .68584 .87257 .68089 .86411 .66926 Metetra
.975 .105 0 r
.86411 .66926 .87257 .68089 .89318 .67428 .88509 .66522 Metetra
.972 .118 0 r
.88509 .66522 .89318 .67428 .91368 .66547 .90603 .65925 Metetra
.96 .167 0 r
.90603 .65925 .91368 .66547 .93396 .65384 .92683 .65076 Metetra
.937 .257 0 r
.92683 .65076 .93396 .65384 .95389 .63875 .94736 .63906 Metetra
.899 .392 0 r
.94736 .63906 .95389 .63875 .97331 .6195 .96747 .62344 Metetra
.845 .567 0 r
.96747 .62344 .97331 .6195 .99206 .59538 .98698 .60316 Metetra
.9 .391 0 r
.37773 .76943 .38878 .76525 .40574 .77426 .39491 .7749 Metetra
.939 .247 0 r
.39491 .7749 .40574 .77426 .42307 .77894 .41244 .77625 Metetra
.963 .154 0 r
.41244 .77625 .42307 .77894 .4407 .77997 .43023 .77414 Metetra
.974 .109 0 r
.43023 .77414 .4407 .77997 .45855 .77799 .44822 .76926 Metetra
.975 .105 0 r
.44822 .76926 .45855 .77799 .47658 .7736 .46637 .76221 Metetra
.968 .133 0 r
.46637 .76221 .47658 .7736 .49475 .76736 .48464 .75356 Metetra
.956 .184 0 r
.48464 .75356 .49475 .76736 .51303 .75979 .50299 .74382 Metetra
.939 .247 0 r
.50299 .74382 .51303 .75979 .5314 .75135 .52142 .73346 Metetra
.921 .315 0 r
.52142 .73346 .5314 .75135 .54986 .74244 .53992 .72287 Metetra
.902 .382 0 r
.53992 .72287 .54986 .74244 .5684 .73341 .55849 .7124 Metetra
.884 .444 0 r
.55849 .7124 .5684 .73341 .58703 .72457 .57713 .70235 Metetra
.868 .497 0 r
.57713 .70235 .58703 .72457 .60575 .71615 .59586 .69296 Metetra
.854 .539 0 r
.59586 .69296 .60575 .71615 .62458 .70836 .61469 .68441 Metetra
.844 .57 0 r
.61469 .68441 .62458 .70836 .64354 .70135 .63365 .67687 Metetra
.838 .588 0 r
.63365 .67687 .64354 .70135 .66264 .69521 .65275 .67041 Metetra
.836 .595 0 r
.65275 .67041 .66264 .69521 .68191 .68999 .67202 .66511 Metetra
.838 .589 0 r
.67202 .66511 .68191 .68999 .70135 .68571 .69148 .66095 Metetra
.844 .57 0 r
.69148 .66095 .70135 .68571 .721 .68232 .71115 .65791 Metetra
.854 .54 0 r
.71115 .65791 .721 .68232 .74085 .67973 .73104 .65589 Metetra
.868 .498 0 r
.73104 .65589 .74085 .67973 .76091 .67779 .75117 .65477 Metetra
.884 .445 0 r
.75117 .65477 .76091 .67779 .78119 .67632 .77154 .65435 Metetra
.902 .384 0 r
.77154 .65435 .78119 .67632 .80168 .67507 .79215 .65439 Metetra
.921 .317 0 r
.79215 .65439 .80168 .67507 .82235 .67373 .81299 .65461 Metetra
.939 .249 0 r
.81299 .65461 .82235 .67373 .84318 .67193 .83402 .65463 Metetra
.955 .186 0 r
.83402 .65463 .84318 .67193 .86411 .66926 .85522 .65405 Metetra
.968 .136 0 r
.85522 .65405 .86411 .66926 .88509 .66522 .87652 .65237 Metetra
.975 .107 0 r
.87652 .65237 .88509 .66522 .90603 .65925 .89785 .64904 Metetra
.974 .111 0 r
.89785 .64904 .90603 .65925 .92683 .65076 .91911 .64346 Metetra
.963 .156 0 r
.91911 .64346 .92683 .65076 .94736 .63906 .94017 .63494 Metetra
.939 .249 0 r
.94017 .63494 .94736 .63906 .96747 .62344 .96089 .62274 Metetra
.899 .392 0 r
.96089 .62274 .96747 .62344 .98698 .60316 .98111 .60611 Metetra
.937 .256 0 r
.36665 .7697 .37773 .76943 .39491 .7749 .38404 .77184 Metetra
.963 .154 0 r
.38404 .77184 .39491 .7749 .41244 .77625 .40175 .77005 Metetra
.975 .107 0 r
.40175 .77005 .41244 .77625 .43023 .77414 .41971 .76503 Metetra
.974 .109 0 r
.41971 .76503 .43023 .77414 .44822 .76926 .43784 .75745 Metetra
.965 .147 0 r
.43784 .75745 .44822 .76926 .46637 .76221 .4561 .74793 Metetra
.949 .212 0 r
.4561 .74793 .46637 .76221 .48464 .75356 .47446 .73705 Metetra
.928 .291 0 r
.47446 .73705 .48464 .75356 .50299 .74382 .49289 .72532 Metetra
.904 .377 0 r
.49289 .72532 .50299 .74382 .52142 .73346 .51138 .71319 Metetra
.879 .461 0 r
.51138 .71319 .52142 .73346 .53992 .72287 .52991 .70106 Metetra
.855 .539 0 r
.52991 .70106 .53992 .72287 .55849 .7124 .5485 .68927 Metetra
.832 .606 0 r
.5485 .68927 .55849 .7124 .57713 .70235 .56715 .67812 Metetra
.812 .662 0 r
.56715 .67812 .57713 .70235 .59586 .69296 .58588 .66783 Metetra
.795 .706 0 r
.58588 .66783 .59586 .69296 .61469 .68441 .60471 .65859 Metetra
.783 .737 0 r
.60471 .65859 .61469 .68441 .63365 .67687 .62366 .65055 Metetra
.775 .755 0 r
.62366 .65055 .63365 .67687 .65275 .67041 .64276 .6438 Metetra
.773 .761 0 r
.64276 .6438 .65275 .67041 .67202 .66511 .66202 .6384 Metetra
.775 .755 0 r
.66202 .6384 .67202 .66511 .69148 .66095 .68148 .63434 Metetra
.783 .737 0 r
.68148 .63434 .69148 .66095 .71115 .65791 .70116 .6316 Metetra
.795 .706 0 r
.70116 .6316 .71115 .65791 .73104 .65589 .72108 .63009 Metetra
.811 .663 0 r
.72108 .63009 .73104 .65589 .75117 .65477 .74125 .62969 Metetra
.831 .607 0 r
.74125 .62969 .75117 .65477 .77154 .65435 .76169 .6302 Metetra
.854 .54 0 r
.76169 .6302 .77154 .65435 .79215 .65439 .7824 .63141 Metetra
.879 .462 0 r
.7824 .63141 .79215 .65439 .81299 .65461 .80336 .63302 Metetra
.903 .378 0 r
.80336 .63302 .81299 .65461 .83402 .65463 .82457 .63469 Metetra
.927 .293 0 r
.82457 .63469 .83402 .65463 .85522 .65405 .84599 .636 Metetra
.948 .213 0 r
.84599 .636 .85522 .65405 .87652 .65237 .86756 .63648 Metetra
.964 .149 0 r
.86756 .63648 .87652 .65237 .89785 .64904 .88922 .63558 Metetra
.974 .11 0 r
.88922 .63558 .89785 .64904 .91911 .64346 .91088 .63268 Metetra
.974 .109 0 r
.91088 .63268 .91911 .64346 .94017 .63494 .93242 .6271 Metetra
.963 .155 0 r
.93242 .6271 .94017 .63494 .96089 .62274 .9537 .61809 Metetra
.937 .257 0 r
.9537 .61809 .96089 .62274 .98111 .60611 .97455 .60487 Metetra
.96 .166 0 r
.35552 .76666 .36665 .7697 .38404 .77184 .37312 .7657 Metetra
.974 .11 0 r
.37312 .7657 .38404 .77184 .40175 .77005 .39102 .761 Metetra
.974 .109 0 r
.39102 .761 .40175 .77005 .41971 .76503 .40914 .75327 Metetra
.963 .152 0 r
.40914 .75327 .41971 .76503 .43784 .75745 .42741 .74321 Metetra
.945 .227 0 r
.42741 .74321 .43784 .75745 .4561 .74793 .44579 .73143 Metetra
.92 .32 0 r
.44579 .73143 .4561 .74793 .47446 .73705 .46424 .71851 Metetra
.891 .421 0 r
.46424 .71851 .47446 .73705 .49289 .72532 .48274 .70495 Metetra
.86 .52 0 r
.48274 .70495 .49289 .72532 .51138 .71319 .50128 .69122 Metetra
.83 .613 0 r
.50128 .69122 .51138 .71319 .52991 .70106 .51985 .67769 Metetra
.8 .693 0 r
.51985 .67769 .52991 .70106 .5485 .68927 .53846 .6647 Metetra
.773 .761 0 r
.53846 .6647 .5485 .68927 .56715 .67812 .55713 .65254 Metetra
.684 .749 0 r
.55713 .65254 .56715 .67812 .58588 .66783 .57586 .64143 Metetra
.606 .73 0 r
.57586 .64143 .58588 .66783 .60471 .65859 .59468 .63156 Metetra
.55 .716 0 r
.59468 .63156 .60471 .65859 .62366 .65055 .61362 .62307 Metetra
.516 .707 0 r
.61362 .62307 .62366 .65055 .64276 .6438 .6327 .61605 Metetra
.505 .704 0 r
.6327 .61605 .64276 .6438 .66202 .6384 .65195 .61054 Metetra
.516 .707 0 r
.65195 .61054 .66202 .6384 .68148 .63434 .67141 .60656 Metetra
.549 .716 0 r
.67141 .60656 .68148 .63434 .70116 .6316 .69109 .60408 Metetra
.605 .73 0 r
.69109 .60408 .70116 .6316 .72108 .63009 .71102 .60301 Metetra
.683 .749 0 r
.71102 .60301 .72108 .63009 .74125 .62969 .73122 .60323 Metetra
.773 .761 0 r
.73122 .60323 .74125 .62969 .76169 .6302 .7517 .60457 Metetra
.8 .694 0 r
.7517 .60457 .76169 .6302 .7824 .63141 .77248 .60681 Metetra
.829 .613 0 r
.77248 .60681 .7824 .63141 .80336 .63302 .79355 .60967 Metetra
.86 .521 0 r
.79355 .60967 .80336 .63302 .82457 .63469 .8149 .61281 Metetra
.891 .422 0 r
.8149 .61281 .82457 .63469 .84599 .636 .8365 .61583 Metetra
.919 .321 0 r
.8365 .61583 .84599 .636 .86756 .63648 .8583 .61825 Metetra
.944 .228 0 r
.8583 .61825 .86756 .63648 .88922 .63558 .88025 .61954 Metetra
.963 .154 0 r
.88025 .61954 .88922 .63558 .91088 .63268 .90226 .61909 Metetra
.974 .11 0 r
.90226 .61909 .91088 .63268 .93242 .6271 .92422 .61621 Metetra
.974 .11 0 r
.92422 .61621 .93242 .6271 .9537 .61809 .94599 .61015 Metetra
.96 .166 0 r
.94599 .61015 .9537 .61809 .97455 .60487 .96741 .60009 Metetra
.972 .117 0 r
.34436 .7609 .35552 .76666 .37312 .7657 .36217 .75708 Metetra
.975 .106 0 r
.36217 .75708 .37312 .7657 .39102 .761 .38024 .7497 Metetra
.965 .148 0 r
.38024 .7497 .39102 .761 .40914 .75327 .39852 .73949 Metetra
.944 .227 0 r
.39852 .73949 .40914 .75327 .42741 .74321 .41693 .72716 Metetra
.917 .33 0 r
.41693 .72716 .42741 .74321 .44579 .73143 .43542 .71332 Metetra
.884 .444 0 r
.43542 .71332 .44579 .73143 .46424 .71851 .45396 .69855 Metetra
.849 .557 0 r
.45396 .69855 .46424 .71851 .48274 .70495 .47254 .68334 Metetra
.812 .662 0 r
.47254 .68334 .48274 .70495 .50128 .69122 .49113 .66815 Metetra
.775 .755 0 r
.49113 .66815 .50128 .69122 .51985 .67769 .50975 .65336 Metetra
.651 .741 0 r
.50975 .65336 .51985 .67769 .53846 .6647 .52838 .63929 Metetra
.528 .71 0 r
.52838 .63929 .53846 .6647 .55713 .65254 .54706 .62622 Metetra
.428 .683 0 r
.54706 .62622 .55713 .65254 .57586 .64143 .5658 .61438 Metetra
.352 .661 0 r
.5658 .61438 .57586 .64143 .59468 .63156 .58461 .60393 Metetra
.299 .645 0 r
.58461 .60393 .59468 .63156 .61362 .62307 .60354 .59502 Metetra
.267 .635 0 r
.60354 .59502 .61362 .62307 .6327 .61605 .62261 .58774 Metetra
.257 .632 0 r
.62261 .58774 .6327 .61605 .65195 .61054 .64185 .58214 Metetra
.267 .635 0 r
.64185 .58214 .65195 .61054 .67141 .60656 .66129 .57821 Metetra
.298 .645 0 r
.66129 .57821 .67141 .60656 .69109 .60408 .68096 .57594 Metetra
.352 .661 0 r
.68096 .57594 .69109 .60408 .71102 .60301 .70089 .57525 Metetra
.427 .683 0 r
.70089 .57525 .71102 .60301 .73122 .60323 .72111 .57602 Metetra
.527 .71 0 r
.72111 .57602 .73122 .60323 .7517 .60457 .74162 .57808 Metetra
.65 .741 0 r
.74162 .57808 .7517 .60457 .77248 .60681 .76246 .58123 Metetra
.775 .755 0 r
.76246 .58123 .77248 .60681 .79355 .60967 .78361 .58519 Metetra
.811 .663 0 r
.78361 .58519 .79355 .60967 .8149 .61281 .80507 .58963 Metetra
.848 .558 0 r
.80507 .58963 .8149 .61281 .8365 .61583 .82681 .59416 Metetra
.884 .445 0 r
.82681 .59416 .8365 .61583 .8583 .61825 .84881 .59832 Metetra
.917 .331 0 r
.84881 .59832 .8583 .61825 .88025 .61954 .87101 .60159 Metetra
.944 .228 0 r
.87101 .60159 .88025 .61954 .90226 .61909 .89332 .60334 Metetra
.964 .148 0 r
.89332 .60334 .90226 .61909 .92422 .61621 .91564 .60291 Metetra
.975 .107 0 r
.91564 .60291 .92422 .61621 .94599 .61015 .93785 .59953 Metetra
.972 .117 0 r
.93785 .59953 .94599 .61015 .96741 .60009 .95979 .59238 Metetra
.975 .104 0 r
.33315 .75296 .34436 .7609 .36217 .75708 .35116 .74651 Metetra
.968 .135 0 r
.35116 .74651 .36217 .75708 .38024 .7497 .36941 .7367 Metetra
.948 .213 0 r
.36941 .7367 .38024 .7497 .39852 .73949 .38785 .72425 Metetra
.92 .321 0 r
.38785 .72425 .39852 .73949 .41693 .72716 .40639 .70987 Metetra
.884 .444 0 r
.40639 .70987 .41693 .72716 .43542 .71332 .425 .69417 Metetra
.844 .569 0 r
.425 .69417 .43542 .71332 .45396 .69855 .44364 .67773 Metetra
.802 .687 0 r
.44364 .67773 .45396 .69855 .47254 .68334 .46229 .66104 Metetra
.729 .76 0 r
.46229 .66104 .47254 .68334 .49113 .66815 .48095 .64455 Metetra
.561 .719 0 r
.48095 .64455 .49113 .66815 .50975 .65336 .4996 .62862 Metetra
.417 .68 0 r
.4996 .62862 .50975 .65336 .52838 .63929 .51827 .61358 Metetra
.299 .645 0 r
.51827 .61358 .52838 .63929 .54706 .62622 .53696 .5997 Metetra
.205 .616 0 r
.53696 .5997 .54706 .62622 .5658 .61438 .55571 .58719 Metetra
.136 .591 0 r
.55571 .58719 .5658 .61438 .58461 .60393 .57452 .57623 Metetra
.088 .574 0 r
.57452 .57623 .58461 .60393 .60354 .59502 .59344 .56694 Metetra
.06 .563 0 r
.59344 .56694 .60354 .59502 .62261 .58774 .6125 .55942 Metetra
.051 .559 0 r
.6125 .55942 .62261 .58774 .64185 .58214 .63172 .55371 Metetra
.06 .563 0 r
.63172 .55371 .64185 .58214 .66129 .57821 .65115 .54982 Metetra
.088 .574 0 r
.65115 .54982 .66129 .57821 .68096 .57594 .67081 .54773 Metetra
.136 .591 0 r
.67081 .54773 .68096 .57594 .70089 .57525 .69074 .54735 Metetra
.205 .615 0 r
.69074 .54735 .70089 .57525 .72111 .57602 .71096 .54859 Metetra
.298 .645 0 r
.71096 .54859 .72111 .57602 .74162 .57808 .7315 .55128 Metetra
.417 .68 0 r
.7315 .55128 .74162 .57808 .76246 .58123 .75237 .55521 Metetra
.56 .718 0 r
.75237 .55521 .76246 .58123 .78361 .58519 .77358 .56013 Metetra
.728 .76 0 r
.77358 .56013 .78361 .58519 .80507 .58963 .79513 .56571 Metetra
.802 .688 0 r
.79513 .56571 .80507 .58963 .82681 .59416 .817 .57158 Metetra
.844 .57 0 r
.817 .57158 .82681 .59416 .84881 .59832 .83916 .57729 Metetra
.884 .444 0 r
.83916 .57729 .84881 .59832 .87101 .60159 .86156 .58231 Metetra
.919 .321 0 r
.86156 .58231 .87101 .60159 .89332 .60334 .88413 .58603 Metetra
.948 .213 0 r
.88413 .58603 .89332 .60334 .91564 .60291 .90678 .58779 Metetra
.968 .135 0 r
.90678 .58779 .91564 .60291 .93785 .59953 .92937 .58682 Metetra
.975 .104 0 r
.92937 .58682 .93785 .59953 .95979 .59238 .95176 .5823 Metetra
.972 .118 0 r
.32189 .74333 .33315 .75296 .35116 .74651 .34009 .73452 Metetra
.955 .185 0 r
.34009 .73452 .35116 .74651 .36941 .7367 .35852 .72251 Metetra
.927 .292 0 r
.35852 .72251 .36941 .7367 .38785 .72425 .37711 .70805 Metetra
.891 .422 0 r
.37711 .70805 .38785 .72425 .40639 .70987 .39579 .69183 Metetra
.848 .557 0 r
.39579 .69183 .40639 .70987 .425 .69417 .41452 .67447 Metetra
.802 .687 0 r
.41452 .67447 .425 .69417 .44364 .67773 .43326 .65654 Metetra
.706 .755 0 r
.43326 .65654 .44364 .67773 .46229 .66104 .45199 .63854 Metetra
.516 .707 0 r
.45199 .63854 .46229 .66104 .48095 .64455 .47071 .62088 Metetra
.352 .661 0 r
.47071 .62088 .48095 .64455 .4996 .62862 .48942 .60395 Metetra
.216 .619 0 r
.48942 .60395 .4996 .62862 .51827 .61358 .50812 .58804 Metetra
.107 .581 0 r
.50812 .58804 .51827 .61358 .53696 .5997 .52684 .57344 Metetra
.024 .549 0 r
.52684 .57344 .53696 .5997 .55571 .58719 .54559 .56033 Metetra
0 .522 .036 r
.54559 .56033 .55571 .58719 .57452 .57623 .56441 .54891 Metetra
0 .503 .077 r
.56441 .54891 .57452 .57623 .59344 .56694 .58333 .53928 Metetra
0 .492 .1 r
.58333 .53928 .59344 .56694 .6125 .55942 .60238 .53154 Metetra
0 .488 .107 r
.60238 .53154 .6125 .55942 .63172 .55371 .62159 .52573 Metetra
0 .492 .1 r
.62159 .52573 .63172 .55371 .65115 .54982 .641 .52186 Metetra
0 .503 .077 r
.641 .52186 .65115 .54982 .67081 .54773 .66065 .5199 Metetra
0 .522 .036 r
.66065 .5199 .67081 .54773 .69074 .54735 .68057 .51979 Metetra
.024 .548 0 r
.68057 .51979 .69074 .54735 .71096 .54859 .7008 .52142 Metetra
.107 .581 0 r
.7008 .52142 .71096 .54859 .7315 .55128 .72135 .52464 Metetra
.215 .619 0 r
.72135 .52464 .7315 .55128 .75237 .55521 .74225 .52925 Metetra
.352 .661 0 r
.74225 .52925 .75237 .55521 .77358 .56013 .7635 .535 Metetra
.516 .707 0 r
.7635 .535 .77358 .56013 .79513 .56571 .78512 .54158 Metetra
.706 .754 0 r
.78512 .54158 .79513 .56571 .817 .57158 .8071 .54861 Metetra
.802 .688 0 r
.8071 .54861 .817 .57158 .83916 .57729 .82939 .55566 Metetra
.848 .558 0 r
.82939 .55566 .83916 .57729 .86156 .58231 .85197 .56222 Metetra
.891 .422 0 r
.85197 .56222 .86156 .58231 .88413 .58603 .87477 .56769 Metetra
.927 .292 0 r
.87477 .56769 .88413 .58603 .90678 .58779 .89769 .57139 Metetra
.955 .185 0 r
.89769 .57139 .90678 .58779 .92937 .58682 .92062 .57257 Metetra
.972 .118 0 r
.92062 .57257 .92937 .58682 .95176 .5823 .94341 .57039 Metetra
.964 .152 0 r
.31055 .73247 .32189 .74333 .34009 .73452 .32894 .72156 Metetra
.939 .249 0 r
.32894 .72156 .34009 .73452 .35852 .72251 .34755 .7076 Metetra
.903 .378 0 r
.34755 .7076 .35852 .72251 .37711 .70805 .3663 .69135 Metetra
.86 .521 0 r
.3663 .69135 .37711 .70805 .39579 .69183 .38512 .6735 Metetra
.811 .663 0 r
.38512 .6735 .39579 .69183 .41452 .67447 .40397 .65467 Metetra
.728 .76 0 r
.40397 .65467 .41452 .67447 .43326 .65654 .42281 .63543 Metetra
.516 .707 0 r
.42281 .63543 .43326 .65654 .45199 .63854 .44163 .61626 Metetra
.33 .655 0 r
.44163 .61626 .45199 .63854 .47071 .62088 .46042 .59758 Metetra
.175 .605 0 r
.46042 .59758 .47071 .62088 .48942 .60395 .47918 .57975 Metetra
.051 .559 0 r
.47918 .57975 .48942 .60395 .50812 .58804 .49793 .56309 Metetra
0 .519 .045 r
.49793 .56309 .50812 .58804 .52684 .57344 .51668 .54784 Metetra
0 .484 .114 r
.51668 .54784 .52684 .57344 .54559 .56033 .53545 .53422 Metetra
0 .456 .163 r
.53545 .53422 .54559 .56033 .56441 .54891 .55428 .52237 Metetra
0 .436 .194 r
.55428 .52237 .56441 .54891 .58333 .53928 .5732 .51244 Metetra
0 .423 .211 r
.5732 .51244 .58333 .53928 .60238 .53154 .59225 .50449 Metetra
0 .419 .217 r
.59225 .50449 .60238 .53154 .62159 .52573 .61145 .49858 Metetra
0 .423 .211 r
.61145 .49858 .62159 .52573 .641 .52186 .63086 .49471 Metetra
0 .436 .194 r
.63086 .49471 .641 .52186 .66065 .5199 .6505 .49286 Metetra
0 .456 .163 r
.6505 .49286 .66065 .5199 .68057 .51979 .67042 .49297 Metetra
0 .484 .115 r
.67042 .49297 .68057 .51979 .7008 .52142 .69064 .49493 Metetra
0 .519 .045 r
.69064 .49493 .7008 .52142 .72135 .52464 .7112 .4986 Metetra
.051 .559 0 r
.7112 .4986 .72135 .52464 .74225 .52925 .73212 .50378 Metetra
.175 .605 0 r
.73212 .50378 .74225 .52925 .7635 .535 .75341 .51023 Metetra
.33 .655 0 r
.75341 .51023 .7635 .535 .78512 .54158 .77509 .51766 Metetra
.516 .707 0 r
.77509 .51766 .78512 .54158 .8071 .54861 .79715 .52569 Metetra
.728 .76 0 r
.79715 .52569 .8071 .54861 .82939 .55566 .81956 .53391 Metetra
.811 .663 0 r
.81956 .53391 .82939 .55566 .85197 .56222 .84229 .5418 Metetra
.86 .521 0 r
.84229 .5418 .85197 .56222 .87477 .56769 .86527 .54878 Metetra
.904 .378 0 r
.86527 .54878 .87477 .56769 .89769 .57139 .88843 .55418 Metetra
.939 .248 0 r
.88843 .55418 .89769 .57139 .92062 .57257 .91165 .55724 Metetra
.964 .151 0 r
.91165 .55724 .92062 .57257 .94341 .57039 .93479 .55713 Metetra
.952 .196 0 r
.29912 .72079 .31055 .73247 .32894 .72156 .3177 .70802 Metetra
.921 .317 0 r
.3177 .70802 .32894 .72156 .34755 .7076 .33649 .69235 Metetra
.879 .462 0 r
.33649 .69235 .34755 .7076 .3663 .69135 .35539 .67454 Metetra
.829 .613 0 r
.35539 .67454 .3663 .69135 .38512 .6735 .37435 .65526 Metetra
.775 .755 0 r
.37435 .65526 .38512 .6735 .40397 .65467 .39333 .63516 Metetra
.56 .718 0 r
.39333 .63516 .40397 .65467 .42281 .63543 .41228 .61477 Metetra
.352 .661 0 r
.41228 .61477 .42281 .63543 .44163 .61626 .43119 .59458 Metetra
.175 .605 0 r
.43119 .59458 .44163 .61626 .46042 .59758 .45006 .57501 Metetra
.033 .552 0 r
.45006 .57501 .46042 .59758 .47918 .57975 .46889 .5564 Metetra
0 .503 .077 r
.46889 .5564 .47918 .57975 .49793 .56309 .48769 .53907 Metetra
0 .46 .156 r
.48769 .53907 .49793 .56309 .51668 .54784 .50647 .52326 Metetra
0 .423 .211 r
.50647 .52326 .51668 .54784 .53545 .53422 .52528 .50917 Metetra
0 .394 .247 r
.52528 .50917 .53545 .53422 .55428 .52237 .54413 .49696 Metetra
0 .372 .268 r
.54413 .49696 .55428 .52237 .5732 .51244 .56306 .48675 Metetra
0 .359 .279 r
.56306 .48675 .5732 .51244 .59225 .50449 .58211 .47862 Metetra
0 .355 .282 r
.58211 .47862 .59225 .50449 .61145 .49858 .60132 .4726 Metetra
0 .359 .279 r
.60132 .4726 .61145 .49858 .63086 .49471 .62072 .46872 Metetra
0 .372 .268 r
.62072 .46872 .63086 .49471 .6505 .49286 .64036 .46695 Metetra
0 .394 .247 r
.64036 .46695 .6505 .49286 .67042 .49297 .66028 .46723 Metetra
0 .423 .211 r
.66028 .46723 .67042 .49297 .69064 .49493 .6805 .46946 Metetra
0 .46 .156 r
.6805 .46946 .69064 .49493 .7112 .4986 .70107 .47349 Metetra
0 .503 .077 r
.70107 .47349 .7112 .4986 .73212 .50378 .722 .47915 Metetra
.033 .552 0 r
.722 .47915 .73212 .50378 .75341 .51023 .74333 .4862 Metetra
.175 .605 0 r
.74333 .4862 .75341 .51023 .77509 .51766 .76505 .49434 Metetra
.352 .661 0 r
.76505 .49434 .77509 .51766 .79715 .52569 .78718 .50322 Metetra
.56 .718 0 r
.78718 .50322 .79715 .52569 .81956 .53391 .80969 .51243 Metetra
.775 .755 0 r
.80969 .51243 .81956 .53391 .84229 .5418 .83254 .52146 Metetra
.829 .613 0 r
.83254 .52146 .84229 .5418 .86527 .54878 .85569 .52973 Metetra
.879 .462 0 r
.85569 .52973 .86527 .54878 .88843 .55418 .87906 .53659 Metetra
.921 .316 0 r
.87906 .53659 .88843 .55418 .91165 .55724 .90253 .54128 Metetra
.953 .195 0 r
.90253 .54128 .91165 .55724 .93479 .55713 .92598 .54296 Metetra
.94 .245 0 r
.28759 .70863 .29912 .72079 .3177 .70802 .30635 .69427 Metetra
.902 .384 0 r
.30635 .69427 .3177 .70802 .33649 .69235 .32531 .67713 Metetra
.854 .54 0 r
.32531 .67713 .33649 .69235 .35539 .67454 .34437 .65796 Metetra
.8 .694 0 r
.34437 .65796 .35539 .67454 .37435 .65526 .36348 .63747 Metetra
.65 .741 0 r
.36348 .63747 .37435 .65526 .39333 .63516 .38258 .61626 Metetra
.416 .68 0 r
.38258 .61626 .39333 .63516 .41228 .61477 .40165 .59488 Metetra
.215 .619 0 r
.40165 .59488 .41228 .61477 .43119 .59458 .42066 .57381 Metetra
.051 .559 0 r
.42066 .57381 .43119 .59458 .45006 .57501 .43962 .55347 Metetra
0 .503 .077 r
.43962 .55347 .45006 .57501 .46889 .5564 .45852 .5342 Metetra
0 .452 .169 r
.45852 .5342 .46889 .5564 .48769 .53907 .47738 .51629 Metetra
0 .406 .232 r
.47738 .51629 .48769 .53907 .50647 .52326 .49622 .49999 Metetra
0 .368 .272 r
.49622 .49999 .50647 .52326 .52528 .50917 .51506 .4855 Metetra
0 .337 .294 r
.51506 .4855 .52528 .50917 .54413 .49696 .53394 .47297 Metetra
0 .315 .305 r
.53394 .47297 .54413 .49696 .56306 .48675 .5529 .46251 Metetra
0 .292 .301 r
.5529 .46251 .56306 .48675 .58211 .47862 .57196 .4542 Metetra
0 .282 .296 r
.57196 .4542 .58211 .47862 .60132 .4726 .59118 .44809 Metetra
0 .292 .301 r
.59118 .44809 .60132 .4726 .62072 .46872 .61059 .44418 Metetra
0 .315 .305 r
.61059 .44418 .62072 .46872 .64036 .46695 .63023 .44247 Metetra
0 .337 .294 r
.63023 .44247 .64036 .46695 .66028 .46723 .65015 .44287 Metetra
0 .368 .272 r
.65015 .44287 .66028 .46723 .6805 .46946 .67038 .44531 Metetra
0 .406 .233 r
.67038 .44531 .6805 .46946 .70107 .47349 .69095 .44964 Metetra
0 .452 .169 r
.69095 .44964 .70107 .47349 .722 .47915 .71191 .45569 Metetra
0 .503 .077 r
.71191 .45569 .722 .47915 .74333 .4862 .73326 .46322 Metetra
.051 .559 0 r
.73326 .46322 .74333 .4862 .76505 .49434 .75503 .47195 Metetra
.215 .619 0 r
.75503 .47195 .76505 .49434 .78718 .50322 .77721 .48154 Metetra
.417 .68 0 r
.77721 .48154 .78718 .50322 .80969 .51243 .7998 .49156 Metetra
.65 .741 0 r
.7998 .49156 .80969 .51243 .83254 .52146 .82277 .50154 Metetra
.8 .694 0 r
.82277 .50154 .83254 .52146 .85569 .52973 .84606 .5109 Metetra
.854 .539 0 r
.84606 .5109 .85569 .52973 .87906 .53659 .8696 .51899 Metetra
.902 .383 0 r
.8696 .51899 .87906 .53659 .90253 .54128 .8933 .52505 Metetra
.94 .244 0 r
.8933 .52505 .90253 .54128 .92598 .54296 .91701 .52825 Metetra
.927 .294 0 r
.27592 .69632 .28759 .70863 .30635 .69427 .29487 .68061 Metetra
.884 .445 0 r
.29487 .68061 .30635 .69427 .32531 .67713 .31399 .66222 Metetra
.831 .608 0 r
.31399 .66222 .32531 .67713 .34437 .65796 .33321 .64192 Metetra
.772 .762 0 r
.33321 .64192 .34437 .65796 .36348 .63747 .35247 .62039 Metetra
.526 .71 0 r
.35247 .62039 .36348 .63747 .38258 .61626 .3717 .59824 Metetra
.298 .645 0 r
.3717 .59824 .38258 .61626 .40165 .59488 .39089 .57603 Metetra
.107 .581 0 r
.39089 .57603 .40165 .59488 .42066 .57381 .41001 .55423 Metetra
0 .519 .045 r
.41001 .55423 .42066 .57381 .43962 .55347 .42907 .53323 Metetra
0 .46 .156 r
.42907 .53323 .43962 .55347 .45852 .5342 .44805 .51339 Metetra
0 .406 .233 r
.44805 .51339 .45852 .5342 .47738 .51629 .46698 .49499 Metetra
0 .359 .279 r
.46698 .49499 .47738 .51629 .49622 .49999 .48588 .47827 Metetra
0 .319 .303 r
.48588 .47827 .49622 .49999 .51506 .4855 .50478 .46343 Metetra
0 .262 .287 r
.50478 .46343 .51506 .4855 .53394 .47297 .5237 .45061 Metetra
0 .214 .264 r
.5237 .45061 .53394 .47297 .5529 .46251 .54269 .43994 Metetra
0 .187 .25 r
.54269 .43994 .5529 .46251 .57196 .4542 .56178 .43147 Metetra
0 .178 .245 r
.56178 .43147 .57196 .4542 .59118 .44809 .58102 .42526 Metetra
0 .187 .25 r
.58102 .42526 .59118 .44809 .61059 .44418 .60044 .42133 Metetra
0 .214 .264 r
.60044 .42133 .61059 .44418 .63023 .44247 .6201 .41963 Metetra
0 .262 .287 r
.6201 .41963 .63023 .44247 .65015 .44287 .64003 .42013 Metetra
0 .319 .303 r
.64003 .42013 .65015 .44287 .67038 .44531 .66027 .42273 Metetra
0 .359 .279 r
.66027 .42273 .67038 .44531 .69095 .44964 .68086 .42729 Metetra
0 .406 .233 r
.68086 .42729 .69095 .44964 .71191 .45569 .70184 .43364 Metetra
0 .46 .156 r
.70184 .43364 .71191 .45569 .73326 .46322 .72322 .44155 Metetra
0 .519 .045 r
.72322 .44155 .73326 .46322 .75503 .47195 .74503 .45075 Metetra
.107 .581 0 r
.74503 .45075 .75503 .47195 .77721 .48154 .76726 .46091 Metetra
.298 .645 0 r
.76726 .46091 .77721 .48154 .7998 .49156 .78993 .4716 Metetra
.527 .71 0 r
.78993 .4716 .7998 .49156 .82277 .50154 .81299 .48235 Metetra
.773 .761 0 r
.81299 .48235 .82277 .50154 .84606 .5109 .8364 .4926 Metetra
.832 .607 0 r
.8364 .4926 .84606 .5109 .8696 .51899 .8601 .50169 Metetra
.884 .444 0 r
.8601 .50169 .8696 .51899 .8933 .52505 .88398 .50887 Metetra
.927 .292 0 r
.88398 .50887 .8933 .52505 .91701 .52825 .90792 .51331 Metetra
.915 .338 0 r
.26411 .68409 .27592 .69632 .29487 .68061 .28323 .66728 Metetra
.867 .498 0 r
.28323 .66728 .29487 .68061 .31399 .66222 .30252 .64788 Metetra
.811 .664 0 r
.30252 .64788 .31399 .66222 .33321 .64192 .3219 .62664 Metetra
.683 .749 0 r
.3219 .62664 .33321 .64192 .35247 .62039 .3413 .60426 Metetra
.427 .683 0 r
.3413 .60426 .35247 .62039 .3717 .59824 .36067 .58136 Metetra
.205 .615 0 r
.36067 .58136 .3717 .59824 .39089 .57603 .37999 .55846 Metetra
.023 .548 0 r
.37999 .55846 .39089 .57603 .41001 .55423 .39923 .53604 Metetra
0 .484 .115 r
.39923 .53604 .41001 .55423 .42907 .53323 .41839 .5145 Metetra
0 .423 .211 r
.41839 .5145 .42907 .53323 .44805 .51339 .43747 .49418 Metetra
0 .368 .272 r
.43747 .49418 .44805 .51339 .46698 .49499 .45648 .47537 Metetra
0 .319 .303 r
.45648 .47537 .46698 .49499 .48588 .47827 .47546 .4583 Metetra
0 .242 .278 r
.47546 .4583 .48588 .47827 .50478 .46343 .49442 .44317 Metetra
0 .178 .245 r
.49442 .44317 .50478 .46343 .5237 .45061 .5134 .4301 Metetra
0 .138 .221 r
.5134 .4301 .5237 .45061 .54269 .43994 .53243 .41923 Metetra
0 .116 .206 r
.53243 .41923 .54269 .43994 .56178 .43147 .55156 .41062 Metetra
0 .109 .202 r
.55156 .41062 .56178 .43147 .58102 .42526 .57083 .40432 Metetra
0 .116 .206 r
.57083 .40432 .58102 .42526 .60044 .42133 .59028 .40034 Metetra
0 .138 .221 r
.59028 .40034 .60044 .42133 .6201 .41963 .60996 .39865 Metetra
0 .178 .245 r
.60996 .39865 .6201 .41963 .64003 .42013 .62991 .39921 Metetra
0 .242 .278 r
.62991 .39921 .64003 .42013 .66027 .42273 .65017 .40191 Metetra
0 .319 .303 r
.65017 .40191 .66027 .42273 .68086 .42729 .67079 .40663 Metetra
0 .368 .272 r
.67079 .40663 .68086 .42729 .70184 .43364 .69179 .41321 Metetra
0 .423 .211 r
.69179 .41321 .70184 .43364 .72322 .44155 .7132 .42141 Metetra
0 .484 .115 r
.7132 .42141 .72322 .44155 .74503 .45075 .73505 .43098 Metetra
.024 .548 0 r
.73505 .43098 .74503 .45075 .76726 .46091 .75734 .44157 Metetra
.205 .615 0 r
.75734 .44157 .76726 .46091 .78993 .4716 .78006 .45277 Metetra
.428 .683 0 r
.78006 .45277 .78993 .4716 .81299 .48235 .80321 .46413 Metetra
.683 .749 0 r
.80321 .46413 .81299 .48235 .8364 .4926 .82673 .47507 Metetra
.811 .663 0 r
.82673 .47507 .8364 .4926 .8601 .50169 .85056 .48494 Metetra
.868 .497 0 r
.85056 .48494 .8601 .50169 .88398 .50887 .87461 .49301 Metetra
.915 .336 0 r
.87461 .49301 .88398 .50887 .90792 .51331 .89875 .49843 Metetra
.905 .374 0 r
.25213 .67215 .26411 .68409 .28323 .66728 .27141 .65449 Metetra
.854 .54 0 r
.27141 .65449 .28323 .66728 .30252 .64788 .29086 .6343 Metetra
.795 .707 0 r
.29086 .6343 .30252 .64788 .3219 .62664 .3104 .61233 Metetra
.604 .73 0 r
.3104 .61233 .3219 .62664 .3413 .60426 .32995 .58928 Metetra
.351 .661 0 r
.32995 .58928 .3413 .60426 .36067 .58136 .34947 .56577 Metetra
.135 .591 0 r
.34947 .56577 .36067 .58136 .37999 .55846 .36892 .54233 Metetra
0 .522 .037 r
.36892 .54233 .37999 .55846 .39923 .53604 .38829 .51942 Metetra
0 .456 .163 r
.38829 .51942 .39923 .53604 .41839 .5145 .40756 .49745 Metetra
0 .394 .247 r
.40756 .49745 .41839 .5145 .43747 .49418 .42675 .47675 Metetra
0 .337 .294 r
.42675 .47675 .43747 .49418 .45648 .47537 .44586 .4576 Metetra
0 .261 .287 r
.44586 .4576 .45648 .47537 .47546 .4583 .46492 .44024 Metetra
0 .178 .245 r
.46492 .44024 .47546 .4583 .49442 .44317 .48396 .42486 Metetra
0 .123 .211 r
.48396 .42486 .49442 .44317 .5134 .4301 .503 .41159 Metetra
0 .089 .187 r
.503 .41159 .5134 .4301 .53243 .41923 .5221 .40055 Metetra
0 .071 .172 r
.5221 .40055 .53243 .41923 .55156 .41062 .54128 .39181 Metetra
0 .065 .167 r
.54128 .39181 .55156 .41062 .57083 .40432 .56059 .38542 Metetra
0 .071 .172 r
.56059 .38542 .57083 .40432 .59028 .40034 .58009 .38138 Metetra
0 .089 .187 r
.58009 .38138 .59028 .40034 .60996 .39865 .5998 .37967 Metetra
0 .123 .211 r
.5998 .37967 .60996 .39865 .62991 .39921 .61978 .38025 Metetra
0 .178 .245 r
.61978 .38025 .62991 .39921 .65017 .40191 .64008 .38302 Metetra
0 .262 .287 r
.64008 .38302 .65017 .40191 .67079 .40663 .66072 .38785 Metetra
0 .337 .294 r
.66072 .38785 .67079 .40663 .69179 .41321 .68175 .39457 Metetra
0 .394 .247 r
.68175 .39457 .69179 .41321 .7132 .42141 .7032 .40298 Metetra
0 .456 .163 r
.7032 .40298 .7132 .42141 .73505 .43098 .72509 .4128 Metetra
0 .522 .036 r
.72509 .4128 .73505 .43098 .75734 .44157 .74743 .4237 Metetra
.136 .591 0 r
.74743 .4237 .75734 .44157 .78006 .45277 .77022 .43528 Metetra
.352 .661 0 r
.77022 .43528 .78006 .45277 .80321 .46413 .79344 .44707 Metetra
.605 .73 0 r
.79344 .44707 .80321 .46413 .82673 .47507 .81705 .45851 Metetra
.795 .706 0 r
.81705 .45851 .82673 .47507 .85056 .48494 .841 .46896 Metetra
.854 .539 0 r
.841 .46896 .85056 .48494 .87461 .49301 .86519 .47767 Metetra
.905 .373 0 r
.86519 .47767 .87461 .49301 .89875 .49843 .88951 .48381 Metetra
.897 .401 0 r
.23996 .66065 .25213 .67215 .27141 .65449 .25939 .64239 Metetra
.844 .571 0 r
.25939 .64239 .27141 .65449 .29086 .6343 .279 .62162 Metetra
.782 .738 0 r
.279 .62162 .29086 .6343 .3104 .61233 .2987 .59913 Metetra
.548 .715 0 r
.2987 .59913 .3104 .61233 .32995 .58928 .3184 .57559 Metetra
.298 .645 0 r
.3184 .57559 .32995 .58928 .34947 .56577 .33807 .55163 Metetra
.087 .574 0 r
.33807 .55163 .34947 .56577 .36892 .54233 .35766 .52778 Metetra
0 .503 .077 r
.35766 .52778 .36892 .54233 .38829 .51942 .37716 .50451 Metetra
0 .436 .194 r
.37716 .50451 .38829 .51942 .40756 .49745 .39656 .4822 Metetra
0 .372 .268 r
.39656 .4822 .40756 .49745 .42675 .47675 .41586 .46121 Metetra
0 .315 .305 r
.41586 .46121 .42675 .47675 .44586 .4576 .43508 .4418 Metetra
0 .214 .264 r
.43508 .4418 .44586 .4576 .46492 .44024 .45424 .42421 Metetra
0 .138 .221 r
.45424 .42421 .46492 .44024 .48396 .42486 .47337 .40862 Metetra
0 .089 .187 r
.47337 .40862 .48396 .42486 .503 .41159 .4925 .39518 Metetra
0 .06 .162 r
.4925 .39518 .503 .41159 .5221 .40055 .51166 .384 Metetra
0 .045 .147 r
.51166 .384 .5221 .40055 .54128 .39181 .53091 .37514 Metetra
0 .04 .142 r
.53091 .37514 .54128 .39181 .56059 .38542 .55029 .36866 Metetra
0 .045 .147 r
.55029 .36866 .56059 .38542 .58009 .38138 .56983 .36456 Metetra
0 .06 .162 r
.56983 .36456 .58009 .38138 .5998 .37967 .5896 .36281 Metetra
0 .089 .187 r
.5896 .36281 .5998 .37967 .61978 .38025 .60962 .36338 Metetra
0 .138 .221 r
.60962 .36338 .61978 .38025 .64008 .38302 .62996 .36617 Metetra
0 .214 .264 r
.62996 .36617 .64008 .38302 .66072 .38785 .65064 .37105 Metetra
0 .315 .305 r
.65064 .37105 .66072 .38785 .68175 .39457 .67172 .37785 Metetra
0 .372 .268 r
.67172 .37785 .68175 .39457 .7032 .40298 .69321 .38638 Metetra
0 .436 .194 r
.69321 .38638 .7032 .40298 .72509 .4128 .71514 .39635 Metetra
0 .503 .077 r
.71514 .39635 .72509 .4128 .74743 .4237 .73753 .40743 Metetra
.088 .574 0 r
.73753 .40743 .74743 .4237 .77022 .43528 .76039 .41925 Metetra
.298 .645 0 r
.76039 .41925 .77022 .43528 .79344 .44707 .78368 .43131 Metetra
.549 .716 0 r
.78368 .43131 .79344 .44707 .81705 .45851 .80738 .44307 Metetra
.783 .737 0 r
.80738 .44307 .81705 .45851 .841 .46896 .83143 .45389 Metetra
.844 .57 0 r
.83143 .45389 .841 .46896 .86519 .47767 .85575 .46301 Metetra
.897 .4 0 r
.85575 .46301 .86519 .47767 .88951 .48381 .88021 .46961 Metetra
.892 .418 0 r
.22758 .6497 .23996 .66065 .25939 .64239 .24716 .63107 Metetra
.838 .59 0 r
.24716 .63107 .25939 .64239 .279 .62162 .26692 .60996 Metetra
.775 .756 0 r
.26692 .60996 .279 .62162 .2987 .59913 .28676 .58713 Metetra
.515 .707 0 r
.28676 .58713 .2987 .59913 .3184 .57559 .30662 .56329 Metetra
.266 .635 0 r
.30662 .56329 .3184 .57559 .33807 .55163 .32644 .53903 Metetra
.059 .563 0 r
.32644 .53903 .33807 .55163 .35766 .52778 .34618 .51491 Metetra
0 .492 .1 r
.34618 .51491 .35766 .52778 .37716 .50451 .36582 .49138 Metetra
0 .423 .212 r
.36582 .49138 .37716 .50451 .39656 .4822 .38535 .46885 Metetra
0 .359 .279 r
.38535 .46885 .39656 .4822 .41586 .46121 .40479 .44764 Metetra
0 .292 .301 r
.40479 .44764 .41586 .46121 .43508 .4418 .42413 .42804 Metetra
0 .187 .25 r
.42413 .42804 .43508 .4418 .45424 .42421 .4434 .41028 Metetra
0 .116 .206 r
.4434 .41028 .45424 .42421 .47337 .40862 .46263 .39454 Metetra
0 .071 .172 r
.46263 .39454 .47337 .40862 .4925 .39518 .48185 .38096 Metetra
0 .045 .147 r
.48185 .38096 .4925 .39518 .51166 .384 .50111 .36966 Metetra
0 .031 .132 r
.50111 .36966 .51166 .384 .53091 .37514 .52044 .3607 Metetra
0 .027 .127 r
.52044 .3607 .53091 .37514 .55029 .36866 .53989 .35412 Metetra
0 .031 .132 r
.53989 .35412 .55029 .36866 .56983 .36456 .55951 .34995 Metetra
0 .045 .147 r
.55951 .34995 .56983 .36456 .5896 .36281 .57933 .34815 Metetra
0 .071 .172 r
.57933 .34815 .5896 .36281 .60962 .36338 .59942 .34868 Metetra
0 .116 .206 r
.59942 .34868 .60962 .36338 .62996 .36617 .61981 .35144 Metetra
0 .187 .25 r
.61981 .35144 .62996 .36617 .65064 .37105 .64054 .35632 Metetra
0 .292 .301 r
.64054 .35632 .65064 .37105 .67172 .37785 .66167 .36314 Metetra
0 .359 .279 r
.66167 .36314 .67172 .37785 .69321 .38638 .68321 .37169 Metetra
0 .423 .211 r
.68321 .37169 .69321 .38638 .71514 .39635 .7052 .38171 Metetra
0 .492 .1 r
.7052 .38171 .71514 .39635 .73753 .40743 .72765 .39288 Metetra
.06 .563 0 r
.72765 .39288 .73753 .40743 .76039 .41925 .75056 .40478 Metetra
.267 .635 0 r
.75056 .40478 .76039 .41925 .78368 .43131 .77393 .41697 Metetra
.516 .707 0 r
.77393 .41697 .78368 .43131 .80738 .44307 .79771 .42887 Metetra
.775 .755 0 r
.79771 .42887 .80738 .44307 .83143 .45389 .82185 .43985 Metetra
.838 .589 0 r
.82185 .43985 .83143 .45389 .85575 .46301 .84627 .44915 Metetra
.892 .416 0 r
.84627 .44915 .85575 .46301 .88021 .46961 .87085 .45595 Metetra
.89 .423 0 r
.21497 .63936 .22758 .6497 .24716 .63107 .23468 .62061 Metetra
.835 .596 0 r
.23468 .62061 .24716 .63107 .26692 .60996 .25459 .59937 Metetra
.772 .762 0 r
.25459 .59937 .26692 .60996 .28676 .58713 .27458 .57641 Metetra
.504 .704 0 r
.27458 .57641 .28676 .58713 .30662 .56329 .29459 .55242 Metetra
.256 .632 0 r
.29459 .55242 .30662 .56329 .32644 .53903 .31456 .52803 Metetra
.05 .559 0 r
.31456 .52803 .32644 .53903 .34618 .51491 .33445 .50377 Metetra
0 .488 .107 r
.33445 .50377 .34618 .51491 .36582 .49138 .35424 .48011 Metetra
0 .419 .217 r
.35424 .48011 .36582 .49138 .38535 .46885 .37392 .45744 Metetra
0 .355 .282 r
.37392 .45744 .38535 .46885 .40479 .44764 .39349 .43611 Metetra
0 .282 .296 r
.39349 .43611 .40479 .44764 .42413 .42804 .41296 .41639 Metetra
0 .178 .245 r
.41296 .41639 .42413 .42804 .4434 .41028 .43236 .39851 Metetra
0 .109 .202 r
.43236 .39851 .4434 .41028 .46263 .39454 .45171 .38266 Metetra
0 .065 .167 r
.45171 .38266 .46263 .39454 .48185 .38096 .47105 .36898 Metetra
0 .04 .142 r
.47105 .36898 .48185 .38096 .50111 .36966 .49041 .35758 Metetra
0 .027 .127 r
.49041 .35758 .50111 .36966 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .027 .127 r
.52938 .34187 .53989 .35412 .55951 .34995 .54908 .33761 Metetra
0 .04 .142 r
.54908 .33761 .55951 .34995 .57933 .34815 .56898 .33574 Metetra
0 .065 .167 r
.56898 .33574 .57933 .34815 .59942 .34868 .58914 .3362 Metetra
0 .109 .202 r
.58914 .3362 .59942 .34868 .61981 .35144 .6096 .33889 Metetra
0 .178 .245 r
.6096 .33889 .61981 .35144 .64054 .35632 .6304 .34371 Metetra
0 .282 .296 r
.6304 .34371 .64054 .35632 .66167 .36314 .65158 .35048 Metetra
0 .355 .282 r
.65158 .35048 .66167 .36314 .68321 .37169 .67319 .35898 Metetra
0 .419 .217 r
.67319 .35898 .68321 .37169 .7052 .38171 .69524 .36896 Metetra
0 .488 .107 r
.69524 .36896 .7052 .38171 .72765 .39288 .71775 .38008 Metetra
.051 .559 0 r
.71775 .38008 .72765 .39288 .75056 .40478 .74073 .39194 Metetra
.256 .632 0 r
.74073 .39194 .75056 .40478 .77393 .41697 .76417 .40409 Metetra
.505 .704 0 r
.76417 .40409 .77393 .41697 .79771 .42887 .78802 .41595 Metetra
.773 .761 0 r
.78802 .41595 .79771 .42887 .82185 .43985 .81225 .42688 Metetra
.836 .595 0 r
.81225 .42688 .82185 .43985 .84627 .44915 .83677 .43614 Metetra
.891 .422 0 r
.83677 .43614 .84627 .44915 .87085 .45595 .86145 .44288 Metetra
.892 .418 0 r
.20213 .62963 .21497 .63936 .23468 .62061 .22196 .611 Metetra
.838 .59 0 r
.22196 .611 .23468 .62061 .25459 .59937 .24199 .58985 Metetra
.775 .756 0 r
.24199 .58985 .25459 .59937 .27458 .57641 .26213 .56696 Metetra
.515 .707 0 r
.26213 .56696 .27458 .57641 .29459 .55242 .28229 .54301 Metetra
.266 .635 0 r
.28229 .54301 .29459 .55242 .31456 .52803 .30241 .51864 Metetra
.059 .563 0 r
.30241 .51864 .31456 .52803 .33445 .50377 .32246 .49438 Metetra
0 .492 .1 r
.32246 .49438 .33445 .50377 .35424 .48011 .3424 .4707 Metetra
0 .423 .212 r
.3424 .4707 .35424 .48011 .37392 .45744 .36223 .448 Metetra
0 .359 .279 r
.36223 .448 .37392 .45744 .39349 .43611 .38195 .42663 Metetra
0 .292 .301 r
.38195 .42663 .39349 .43611 .41296 .41639 .40157 .40686 Metetra
0 .187 .25 r
.40157 .40686 .41296 .41639 .43236 .39851 .42111 .38892 Metetra
0 .116 .206 r
.42111 .38892 .43236 .39851 .45171 .38266 .44059 .37301 Metetra
0 .071 .172 r
.44059 .37301 .45171 .38266 .47105 .36898 .46005 .35926 Metetra
0 .045 .147 r
.46005 .35926 .47105 .36898 .49041 .35758 .47953 .34778 Metetra
0 .031 .132 r
.47953 .34778 .49041 .35758 .50984 .34853 .49907 .33865 Metetra
0 .027 .127 r
.49907 .33865 .50984 .34853 .52938 .34187 .51872 .3319 Metetra
0 .031 .132 r
.51872 .3319 .52938 .34187 .54908 .33761 .53852 .32756 Metetra
0 .045 .147 r
.53852 .32756 .54908 .33761 .56898 .33574 .55851 .32559 Metetra
0 .071 .172 r
.55851 .32559 .56898 .33574 .58914 .3362 .57876 .32595 Metetra
0 .116 .206 r
.57876 .32595 .58914 .3362 .6096 .33889 .5993 .32854 Metetra
0 .187 .25 r
.5993 .32854 .6096 .33889 .6304 .34371 .62018 .33324 Metetra
0 .292 .301 r
.62018 .33324 .6304 .34371 .65158 .35048 .64144 .33988 Metetra
0 .359 .279 r
.64144 .33988 .65158 .35048 .67319 .35898 .66312 .34826 Metetra
0 .423 .211 r
.66312 .34826 .67319 .35898 .69524 .36896 .68524 .35809 Metetra
0 .492 .1 r
.68524 .35809 .69524 .36896 .71775 .38008 .70783 .36905 Metetra
.06 .563 0 r
.70783 .36905 .71775 .38008 .74073 .39194 .73088 .38074 Metetra
.267 .635 0 r
.73088 .38074 .74073 .39194 .76417 .40409 .75438 .39268 Metetra
.516 .707 0 r
.75438 .39268 .76417 .40409 .78802 .41595 .77832 .40432 Metetra
.775 .755 0 r
.77832 .40432 .78802 .41595 .81225 .42688 .80262 .41501 Metetra
.838 .589 0 r
.80262 .41501 .81225 .42688 .83677 .43614 .82722 .42398 Metetra
.892 .416 0 r
.82722 .42398 .83677 .43614 .86145 .44288 .85198 .43041 Metetra
.897 .401 0 r
.18904 .62046 .20213 .62963 .22196 .611 .20896 .60221 Metetra
.844 .571 0 r
.20896 .60221 .22196 .611 .24199 .58985 .22911 .58138 Metetra
.782 .738 0 r
.22911 .58138 .24199 .58985 .26213 .56696 .24938 .55875 Metetra
.548 .715 0 r
.24938 .55875 .26213 .56696 .28229 .54301 .26969 .53502 Metetra
.298 .645 0 r
.26969 .53502 .28229 .54301 .30241 .51864 .28996 .51083 Metetra
.087 .574 0 r
.28996 .51083 .30241 .51864 .32246 .49438 .31017 .4867 Metetra
0 .503 .077 r
.31017 .4867 .32246 .49438 .3424 .4707 .33027 .46313 Metetra
0 .436 .194 r
.33027 .46313 .3424 .4707 .36223 .448 .35026 .44051 Metetra
0 .372 .268 r
.35026 .44051 .36223 .448 .38195 .42663 .37014 .41918 Metetra
0 .315 .305 r
.37014 .41918 .38195 .42663 .40157 .40686 .38992 .39943 Metetra
0 .214 .264 r
.38992 .39943 .40157 .40686 .42111 .38892 .4096 .38149 Metetra
0 .138 .221 r
.4096 .38149 .42111 .38892 .44059 .37301 .42923 .36556 Metetra
0 .089 .187 r
.42923 .36556 .44059 .37301 .46005 .35926 .44884 .35177 Metetra
0 .06 .162 r
.44884 .35177 .46005 .35926 .47953 .34778 .46845 .34024 Metetra
0 .045 .147 r
.46845 .34024 .47953 .34778 .49907 .33865 .48812 .33104 Metetra
0 .04 .142 r
.48812 .33104 .49907 .33865 .51872 .3319 .50789 .32422 Metetra
0 .045 .147 r
.50789 .32422 .51872 .3319 .53852 .32756 .5278 .31977 Metetra
0 .06 .162 r
.5278 .31977 .53852 .32756 .55851 .32559 .54791 .31769 Metetra
0 .089 .187 r
.54791 .31769 .55851 .32559 .57876 .32595 .56826 .31791 Metetra
0 .138 .221 r
.56826 .31791 .57876 .32595 .5993 .32854 .5889 .32036 Metetra
0 .214 .264 r
.5889 .32036 .5993 .32854 .62018 .33324 .60987 .32489 Metetra
0 .315 .305 r
.60987 .32489 .62018 .33324 .64144 .33988 .63122 .33134 Metetra
0 .372 .268 r
.63122 .33134 .64144 .33988 .66312 .34826 .65299 .3395 Metetra
0 .436 .194 r
.65299 .3395 .66312 .34826 .68524 .35809 .67519 .34908 Metetra
0 .503 .077 r
.67519 .34908 .68524 .35809 .70783 .36905 .69785 .35976 Metetra
.088 .574 0 r
.69785 .35976 .70783 .36905 .73088 .38074 .72098 .37113 Metetra
.298 .645 0 r
.72098 .37113 .73088 .38074 .75438 .39268 .74456 .38272 Metetra
.549 .716 0 r
.74456 .38272 .75438 .39268 .77832 .40432 .76856 .39396 Metetra
.783 .737 0 r
.76856 .39396 .77832 .40432 .80262 .41501 .79294 .40418 Metetra
.844 .57 0 r
.79294 .40418 .80262 .41501 .82722 .42398 .81761 .41264 Metetra
.897 .4 0 r
.81761 .41264 .82722 .42398 .85198 .43041 .84244 .41848 Metetra
.905 .374 0 r
.1757 .61175 .18904 .62046 .20896 .60221 .1957 .59414 Metetra
.854 .54 0 r
.1957 .59414 .20896 .60221 .22911 .58138 .21595 .57386 Metetra
.795 .707 0 r
.21595 .57386 .22911 .58138 .24938 .55875 .23634 .55171 Metetra
.604 .73 0 r
.23634 .55171 .24938 .55875 .26969 .53502 .25678 .52839 Metetra
.351 .661 0 r
.25678 .52839 .26969 .53502 .28996 .51083 .2772 .50453 Metetra
.135 .591 0 r
.2772 .50453 .28996 .51083 .31017 .4867 .29756 .48069 Metetra
0 .522 .037 r
.29756 .48069 .31017 .4867 .33027 .46313 .31783 .45734 Metetra
0 .456 .163 r
.31783 .45734 .33027 .46313 .35026 .44051 .33799 .43489 Metetra
0 .394 .247 r
.33799 .43489 .35026 .44051 .37014 .41918 .35803 .4137 Metetra
0 .337 .294 r
.35803 .4137 .37014 .41918 .38992 .39943 .37797 .39405 Metetra
0 .261 .287 r
.37797 .39405 .38992 .39943 .4096 .38149 .39782 .37617 Metetra
0 .178 .245 r
.39782 .37617 .4096 .38149 .42923 .36556 .41761 .36027 Metetra
0 .123 .211 r
.41761 .36027 .42923 .36556 .44884 .35177 .43737 .34648 Metetra
0 .089 .187 r
.43737 .34648 .44884 .35177 .46845 .34024 .45714 .33492 Metetra
0 .071 .172 r
.45714 .33492 .46845 .34024 .48812 .33104 .47695 .32567 Metetra
0 .065 .167 r
.47695 .32567 .48812 .33104 .50789 .32422 .49686 .31876 Metetra
0 .071 .172 r
.49686 .31876 .50789 .32422 .5278 .31977 .5169 .31421 Metetra
0 .089 .187 r
.5169 .31421 .5278 .31977 .54791 .31769 .53714 .31199 Metetra
0 .123 .211 r
.53714 .31199 .54791 .31769 .56826 .31791 .55761 .31205 Metetra
0 .178 .245 r
.55761 .31205 .56826 .31791 .5889 .32036 .57836 .3143 Metetra
0 .262 .287 r
.57836 .3143 .5889 .32036 .60987 .32489 .59944 .3186 Metetra
0 .337 .294 r
.59944 .3186 .60987 .32489 .63122 .33134 .6209 .32479 Metetra
0 .394 .247 r
.6209 .32479 .63122 .33134 .65299 .3395 .64276 .33264 Metetra
0 .456 .163 r
.64276 .33264 .65299 .3395 .67519 .34908 .66505 .34187 Metetra
0 .522 .036 r
.66505 .34187 .67519 .34908 .69785 .35976 .6878 .35215 Metetra
.136 .591 0 r
.6878 .35215 .69785 .35976 .72098 .37113 .71101 .36306 Metetra
.352 .661 0 r
.71101 .36306 .72098 .37113 .74456 .38272 .73467 .37412 Metetra
.605 .73 0 r
.73467 .37412 .74456 .38272 .76856 .39396 .75875 .38476 Metetra
.795 .706 0 r
.75875 .38476 .76856 .39396 .79294 .40418 .78319 .39431 Metetra
.854 .539 0 r
.78319 .39431 .79294 .40418 .81761 .41264 .80792 .402 Metetra
.905 .373 0 r
.80792 .402 .81761 .41264 .84244 .41848 .83281 .40699 Metetra
.915 .338 0 r
.16212 .60336 .1757 .61175 .1957 .59414 .18216 .58665 Metetra
.867 .498 0 r
.18216 .58665 .1957 .59414 .21595 .57386 .20249 .56716 Metetra
.811 .664 0 r
.20249 .56716 .21595 .57386 .23634 .55171 .22298 .5457 Metetra
.683 .749 0 r
.22298 .5457 .23634 .55171 .25678 .52839 .24354 .52298 Metetra
.427 .683 0 r
.24354 .52298 .25678 .52839 .2772 .50453 .26411 .49963 Metetra
.205 .615 0 r
.26411 .49963 .2772 .50453 .29756 .48069 .28463 .47621 Metetra
.023 .548 0 r
.28463 .47621 .29756 .48069 .31783 .45734 .30506 .45322 Metetra
0 .484 .115 r
.30506 .45322 .31783 .45734 .33799 .43489 .32539 .43107 Metetra
0 .423 .211 r
.32539 .43107 .33799 .43489 .35803 .4137 .3456 .4101 Metetra
0 .368 .272 r
.3456 .4101 .35803 .4137 .37797 .39405 .36572 .39063 Metetra
0 .319 .303 r
.36572 .39063 .37797 .39405 .39782 .37617 .38574 .37288 Metetra
0 .242 .278 r
.38574 .37288 .39782 .37617 .41761 .36027 .4057 .35705 Metetra
0 .178 .245 r
.4057 .35705 .41761 .36027 .43737 .34648 .42563 .3433 Metetra
0 .138 .221 r
.42563 .3433 .43737 .34648 .45714 .33492 .44556 .33173 Metetra
0 .116 .206 r
.44556 .33173 .45714 .33492 .47695 .32567 .46553 .32244 Metetra
0 .109 .202 r
.46553 .32244 .47695 .32567 .49686 .31876 .4856 .31545 Metetra
0 .116 .206 r
.4856 .31545 .49686 .31876 .5169 .31421 .50579 .31078 Metetra
0 .138 .221 r
.50579 .31078 .5169 .31421 .53714 .31199 .52617 .3084 Metetra
0 .178 .245 r
.52617 .3084 .53714 .31199 .55761 .31205 .54677 .30827 Metetra
0 .242 .278 r
.54677 .30827 .55761 .31205 .57836 .3143 .56766 .31027 Metetra
0 .319 .303 r
.56766 .31027 .57836 .3143 .59944 .3186 .58886 .31429 Metetra
0 .368 .272 r
.58886 .31429 .59944 .3186 .6209 .32479 .61044 .32014 Metetra
0 .423 .211 r
.61044 .32014 .6209 .32479 .64276 .33264 .63241 .32759 Metetra
0 .484 .115 r
.63241 .32759 .64276 .33264 .66505 .34187 .65481 .33636 Metetra
.024 .548 0 r
.65481 .33636 .66505 .34187 .6878 .35215 .67765 .3461 Metetra
.205 .615 0 r
.67765 .3461 .6878 .35215 .71101 .36306 .70095 .3564 Metetra
.428 .683 0 r
.70095 .3564 .71101 .36306 .73467 .37412 .72469 .36676 Metetra
.683 .749 0 r
.72469 .36676 .73467 .37412 .75875 .38476 .74884 .3766 Metetra
.811 .663 0 r
.74884 .3766 .75875 .38476 .78319 .39431 .77335 .38525 Metetra
.868 .497 0 r
.77335 .38525 .78319 .39431 .80792 .402 .79813 .39193 Metetra
.915 .336 0 r
.79813 .39193 .80792 .402 .83281 .40699 .82306 .39577 Metetra
.927 .294 0 r
.14831 .59508 .16212 .60336 .18216 .58665 .16836 .57954 Metetra
.884 .445 0 r
.16836 .57954 .18216 .58665 .20249 .56716 .18873 .56109 Metetra
.831 .608 0 r
.18873 .56109 .20249 .56716 .22298 .5457 .20931 .54055 Metetra
.772 .762 0 r
.20931 .54055 .22298 .5457 .24354 .52298 .22998 .51862 Metetra
.526 .71 0 r
.22998 .51862 .24354 .52298 .26411 .49963 .25068 .49596 Metetra
.298 .645 0 r
.25068 .49596 .26411 .49963 .28463 .47621 .27134 .47313 Metetra
.107 .581 0 r
.27134 .47313 .28463 .47621 .30506 .45322 .29194 .45063 Metetra
0 .519 .045 r
.29194 .45063 .30506 .45322 .32539 .43107 .31243 .42889 Metetra
0 .46 .156 r
.31243 .42889 .32539 .43107 .3456 .4101 .33283 .40825 Metetra
0 .406 .233 r
.33283 .40825 .3456 .4101 .36572 .39063 .35313 .38903 Metetra
0 .359 .279 r
.35313 .38903 .36572 .39063 .38574 .37288 .37334 .37147 Metetra
0 .319 .303 r
.37334 .37147 .38574 .37288 .4057 .35705 .39348 .35578 Metetra
0 .262 .287 r
.39348 .35578 .4057 .35705 .42563 .3433 .41359 .3421 Metetra
0 .214 .264 r
.41359 .3421 .42563 .3433 .44556 .33173 .4337 .33056 Metetra
0 .187 .25 r
.4337 .33056 .44556 .33173 .46553 .32244 .45384 .32123 Metetra
0 .178 .245 r
.45384 .32123 .46553 .32244 .4856 .31545 .47408 .31417 Metetra
0 .187 .25 r
.47408 .31417 .4856 .31545 .50579 .31078 .49443 .30937 Metetra
0 .214 .264 r
.49443 .30937 .50579 .31078 .52617 .3084 .51497 .30681 Metetra
0 .262 .287 r
.51497 .30681 .52617 .3084 .54677 .30827 .53573 .30644 Metetra
0 .319 .303 r
.53573 .30644 .54677 .30827 .56766 .31027 .55676 .30815 Metetra
0 .359 .279 r
.55676 .30815 .56766 .31027 .58886 .31429 .57811 .31181 Metetra
0 .406 .233 r
.57811 .31181 .58886 .31429 .61044 .32014 .59981 .31724 Metetra
0 .46 .156 r
.59981 .31724 .61044 .32014 .63241 .32759 .62191 .32419 Metetra
0 .519 .045 r
.62191 .32419 .63241 .32759 .65481 .33636 .64442 .33238 Metetra
.107 .581 0 r
.64442 .33238 .65481 .33636 .67765 .3461 .66738 .34145 Metetra
.298 .645 0 r
.66738 .34145 .67765 .3461 .70095 .3564 .69077 .35098 Metetra
.527 .71 0 r
.69077 .35098 .70095 .3564 .72469 .36676 .7146 .36046 Metetra
.773 .761 0 r
.7146 .36046 .72469 .36676 .74884 .3766 .73882 .36929 Metetra
.832 .607 0 r
.73882 .36929 .74884 .3766 .77335 .38525 .76339 .3768 Metetra
.884 .444 0 r
.76339 .3768 .77335 .38525 .79813 .39193 .78821 .3822 Metetra
.927 .292 0 r
.78821 .3822 .79813 .39193 .82306 .39577 .81316 .38462 Metetra
.94 .245 0 r
.13429 .58664 .14831 .59508 .16836 .57954 .15431 .57255 Metetra
.902 .384 0 r
.15431 .57255 .16836 .57954 .18873 .56109 .1747 .5554 Metetra
.854 .54 0 r
.1747 .5554 .18873 .56109 .20931 .54055 .19532 .53601 Metetra
.8 .694 0 r
.19532 .53601 .20931 .54055 .22998 .51862 .21608 .51509 Metetra
.65 .741 0 r
.21608 .51509 .22998 .51862 .25068 .49596 .2369 .49331 Metetra
.416 .68 0 r
.2369 .49331 .25068 .49596 .27134 .47313 .2577 .47123 Metetra
.215 .619 0 r
.2577 .47123 .27134 .47313 .29194 .45063 .27845 .44937 Metetra
.051 .559 0 r
.27845 .44937 .29194 .45063 .31243 .42889 .29912 .42816 Metetra
0 .503 .077 r
.29912 .42816 .31243 .42889 .33283 .40825 .3197 .40796 Metetra
0 .452 .169 r
.3197 .40796 .33283 .40825 .35313 .38903 .34018 .38909 Metetra
0 .406 .232 r
.34018 .38909 .35313 .38903 .37334 .37147 .36058 .37179 Metetra
0 .368 .272 r
.36058 .37179 .37334 .37147 .39348 .35578 .38092 .35629 Metetra
0 .337 .294 r
.38092 .35629 .39348 .35578 .41359 .3421 .40122 .34273 Metetra
0 .315 .305 r
.40122 .34273 .41359 .3421 .4337 .33056 .42152 .33124 Metetra
0 .292 .301 r
.42152 .33124 .4337 .33056 .45384 .32123 .44185 .3219 Metetra
0 .282 .296 r
.44185 .3219 .45384 .32123 .47408 .31417 .46227 .31475 Metetra
0 .292 .301 r
.46227 .31475 .47408 .31417 .49443 .30937 .48281 .30981 Metetra
0 .315 .305 r
.48281 .30981 .49443 .30937 .51497 .30681 .50352 .30704 Metetra
0 .337 .294 r
.50352 .30704 .51497 .30681 .53573 .30644 .52445 .30639 Metetra
0 .368 .272 r
.52445 .30639 .53573 .30644 .55676 .30815 .54564 .30776 Metetra
0 .406 .233 r
.54564 .30776 .55676 .30815 .57811 .31181 .56714 .31099 Metetra
0 .452 .169 r
.56714 .31099 .57811 .31181 .59981 .31724 .58899 .3159 Metetra
0 .503 .077 r
.58899 .3159 .59981 .31724 .62191 .32419 .61123 .32225 Metetra
.051 .559 0 r
.61123 .32225 .62191 .32419 .64442 .33238 .63387 .32974 Metetra
.215 .619 0 r
.63387 .32974 .64442 .33238 .66738 .34145 .65694 .33799 Metetra
.417 .68 0 r
.65694 .33799 .66738 .34145 .69077 .35098 .68044 .34657 Metetra
.65 .741 0 r
.68044 .34657 .69077 .35098 .7146 .36046 .70436 .35497 Metetra
.8 .694 0 r
.70436 .35497 .7146 .36046 .73882 .36929 .72865 .36257 Metetra
.854 .539 0 r
.72865 .36257 .73882 .36929 .76339 .3768 .75327 .36869 Metetra
.902 .383 0 r
.75327 .36869 .76339 .3768 .78821 .3822 .77813 .37254 Metetra
.94 .244 0 r
.77813 .37254 .78821 .3822 .81316 .38462 .80309 .37323 Metetra
.952 .196 0 r
.12009 .57772 .13429 .58664 .15431 .57255 .14003 .56537 Metetra
.921 .317 0 r
.14003 .56537 .15431 .57255 .1747 .5554 .1604 .54979 Metetra
.879 .462 0 r
.1604 .54979 .1747 .5554 .19532 .53601 .18104 .53179 Metetra
.829 .613 0 r
.18104 .53179 .19532 .53601 .21608 .51509 .20187 .51211 Metetra
.775 .755 0 r
.20187 .51211 .21608 .51509 .2369 .49331 .22278 .4914 Metetra
.56 .718 0 r
.22278 .4914 .2369 .49331 .2577 .47123 .24371 .47026 Metetra
.352 .661 0 r
.24371 .47026 .2577 .47123 .27845 .44937 .2646 .44919 Metetra
.175 .605 0 r
.2646 .44919 .27845 .44937 .29912 .42816 .28544 .42864 Metetra
.033 .552 0 r
.28544 .42864 .29912 .42816 .3197 .40796 .30619 .40899 Metetra
0 .503 .077 r
.30619 .40899 .3197 .40796 .34018 .38909 .32686 .39056 Metetra
0 .46 .156 r
.32686 .39056 .34018 .38909 .36058 .37179 .34746 .37361 Metetra
0 .423 .211 r
.34746 .37361 .36058 .37179 .38092 .35629 .368 .35836 Metetra
0 .394 .247 r
.368 .35836 .38092 .35629 .40122 .34273 .3885 .34497 Metetra
0 .372 .268 r
.3885 .34497 .40122 .34273 .42152 .33124 .409 .33356 Metetra
0 .359 .279 r
.409 .33356 .42152 .33124 .44185 .3219 .42954 .32422 Metetra
0 .355 .282 r
.42954 .32422 .44185 .3219 .46227 .31475 .45015 .31699 Metetra
0 .359 .279 r
.45015 .31699 .46227 .31475 .48281 .30981 .47089 .31189 Metetra
0 .372 .268 r
.47089 .31189 .48281 .30981 .50352 .30704 .49179 .30889 Metetra
0 .394 .247 r
.49179 .30889 .50352 .30704 .52445 .30639 .5129 .30792 Metetra
0 .423 .211 r
.5129 .30792 .52445 .30639 .54564 .30776 .53427 .30887 Metetra
0 .46 .156 r
.53427 .30887 .54564 .30776 .56714 .31099 .55594 .3116 Metetra
0 .503 .077 r
.55594 .3116 .56714 .31099 .58899 .3159 .57795 .3159 Metetra
.033 .552 0 r
.57795 .3159 .58899 .3159 .61123 .32225 .60034 .32153 Metetra
.175 .605 0 r
.60034 .32153 .61123 .32225 .63387 .32974 .62312 .32817 Metetra
.352 .661 0 r
.62312 .32817 .63387 .32974 .65694 .33799 .64632 .33544 Metetra
.56 .718 0 r
.64632 .33544 .65694 .33799 .68044 .34657 .66993 .34289 Metetra
.775 .755 0 r
.66993 .34289 .68044 .34657 .70436 .35497 .69394 .35 Metetra
.829 .613 0 r
.69394 .35 .70436 .35497 .72865 .36257 .71831 .35614 Metetra
.879 .462 0 r
.71831 .35614 .72865 .36257 .75327 .36869 .74298 .36062 Metetra
.921 .316 0 r
.74298 .36062 .75327 .36869 .77813 .37254 .76785 .36262 Metetra
.953 .195 0 r
.76785 .36262 .77813 .37254 .80309 .37323 .79281 .36127 Metetra
.964 .152 0 r
.10577 .56793 .12009 .57772 .14003 .56537 .12557 .55761 Metetra
.939 .249 0 r
.12557 .55761 .14003 .56537 .1604 .54979 .14587 .54388 Metetra
.903 .378 0 r
.14587 .54388 .1604 .54979 .18104 .53179 .1665 .52754 Metetra
.86 .521 0 r
.1665 .52754 .18104 .53179 .20187 .51211 .18735 .50932 Metetra
.811 .663 0 r
.18735 .50932 .20187 .51211 .22278 .4914 .20833 .4899 Metetra
.728 .76 0 r
.20833 .4899 .22278 .4914 .24371 .47026 .22936 .46988 Metetra
.516 .707 0 r
.22936 .46988 .24371 .47026 .2646 .44919 .25039 .44977 Metetra
.33 .655 0 r
.25039 .44977 .2646 .44919 .28544 .42864 .27138 .43003 Metetra
.175 .605 0 r
.27138 .43003 .28544 .42864 .30619 .40899 .29231 .41106 Metetra
.051 .559 0 r
.29231 .41106 .30619 .40899 .32686 .39056 .31317 .39318 Metetra
0 .519 .045 r
.31317 .39318 .32686 .39056 .34746 .37361 .33396 .37666 Metetra
0 .484 .114 r
.33396 .37666 .34746 .37361 .368 .35836 .3547 .36172 Metetra
0 .456 .163 r
.3547 .36172 .368 .35836 .3885 .34497 .37542 .34854 Metetra
0 .436 .194 r
.37542 .34854 .3885 .34497 .409 .33356 .39613 .33725 Metetra
0 .423 .211 r
.39613 .33725 .409 .33356 .42954 .32422 .41688 .32793 Metetra
0 .419 .217 r
.41688 .32793 .42954 .32422 .45015 .31699 .43771 .32063 Metetra
0 .423 .211 r
.43771 .32063 .45015 .31699 .47089 .31189 .45865 .31535 Metetra
0 .436 .194 r
.45865 .31535 .47089 .31189 .49179 .30889 .47975 .31208 Metetra
0 .456 .163 r
.47975 .31208 .49179 .30889 .5129 .30792 .50106 .31074 Metetra
0 .484 .115 r
.50106 .31074 .5129 .30792 .53427 .30887 .52262 .31121 Metetra
0 .519 .045 r
.52262 .31121 .53427 .30887 .55594 .3116 .54448 .31334 Metetra
.051 .559 0 r
.54448 .31334 .55594 .3116 .57795 .3159 .56666 .31693 Metetra
.175 .605 0 r
.56666 .31693 .57795 .3159 .60034 .32153 .58921 .32171 Metetra
.33 .655 0 r
.58921 .32171 .60034 .32153 .62312 .32817 .61214 .32735 Metetra
.516 .707 0 r
.61214 .32735 .62312 .32817 .64632 .33544 .63547 .33347 Metetra
.728 .76 0 r
.63547 .33347 .64632 .33544 .66993 .34289 .6592 .3396 Metetra
.811 .663 0 r
.6592 .3396 .66993 .34289 .69394 .35 .68331 .34519 Metetra
.86 .521 0 r
.68331 .34519 .69394 .35 .71831 .35614 .70775 .34962 Metetra
.904 .378 0 r
.70775 .34962 .71831 .35614 .74298 .36062 .73246 .35217 Metetra
.939 .248 0 r
.73246 .35217 .74298 .36062 .76785 .36262 .75735 .35203 Metetra
.964 .151 0 r
.75735 .35203 .76785 .36262 .79281 .36127 .78229 .34831 Metetra
.972 .118 0 r
.09138 .5568 .10577 .56793 .12557 .55761 .11099 .54883 Metetra
.955 .185 0 r
.11099 .54883 .12557 .55761 .14587 .54388 .13115 .53724 Metetra
.927 .292 0 r
.13115 .53724 .14587 .54388 .1665 .52754 .15172 .52282 Metetra
.891 .422 0 r
.15172 .52282 .1665 .52754 .18735 .50932 .17256 .50632 Metetra
.848 .557 0 r
.17256 .50632 .18735 .50932 .20833 .4899 .19358 .48841 Metetra
.802 .687 0 r
.19358 .48841 .20833 .4899 .22936 .46988 .21469 .4697 Metetra
.706 .755 0 r
.21469 .4697 .22936 .46988 .25039 .44977 .23583 .45073 Metetra
.516 .707 0 r
.23583 .45073 .25039 .44977 .27138 .43003 .25696 .43197 Metetra
.352 .661 0 r
.25696 .43197 .27138 .43003 .29231 .41106 .27805 .4138 Metetra
.216 .619 0 r
.27805 .4138 .29231 .41106 .31317 .39318 .29909 .39658 Metetra
.107 .581 0 r
.29909 .39658 .31317 .39318 .33396 .37666 .32008 .38059 Metetra
.024 .549 0 r
.32008 .38059 .33396 .37666 .3547 .36172 .34103 .36604 Metetra
0 .522 .036 r
.34103 .36604 .3547 .36172 .37542 .34854 .36196 .35313 Metetra
0 .503 .077 r
.36196 .35313 .37542 .34854 .39613 .33725 .38289 .34199 Metetra
0 .492 .1 r
.38289 .34199 .39613 .33725 .41688 .32793 .40386 .3327 Metetra
0 .488 .107 r
.40386 .3327 .41688 .32793 .43771 .32063 .42491 .32532 Metetra
0 .492 .1 r
.42491 .32532 .43771 .32063 .45865 .31535 .44607 .31986 Metetra
0 .503 .077 r
.44607 .31986 .45865 .31535 .47975 .31208 .46739 .31628 Metetra
0 .522 .036 r
.46739 .31628 .47975 .31208 .50106 .31074 .48891 .31451 Metetra
.024 .548 0 r
.48891 .31451 .50106 .31074 .52262 .31121 .51068 .31443 Metetra
.107 .581 0 r
.51068 .31443 .52262 .31121 .54448 .31334 .53273 .31587 Metetra
.215 .619 0 r
.53273 .31587 .54448 .31334 .56666 .31693 .5551 .31862 Metetra
.352 .661 0 r
.5551 .31862 .56666 .31693 .58921 .32171 .57782 .32241 Metetra
.516 .707 0 r
.57782 .32241 .58921 .32171 .61214 .32735 .60091 .32689 Metetra
.706 .754 0 r
.60091 .32689 .61214 .32735 .63547 .33347 .62439 .33167 Metetra
.802 .688 0 r
.62439 .33167 .63547 .33347 .6592 .3396 .64824 .33626 Metetra
.848 .558 0 r
.64824 .33626 .6592 .3396 .68331 .34519 .67244 .3401 Metetra
.891 .422 0 r
.67244 .3401 .68331 .34519 .70775 .34962 .69695 .34255 Metetra
.927 .292 0 r
.69695 .34255 .70775 .34962 .73246 .35217 .7217 .34289 Metetra
.955 .185 0 r
.7217 .34289 .73246 .35217 .75735 .35203 .74659 .34029 Metetra
.972 .118 0 r
.74659 .34029 .75735 .35203 .78229 .34831 .77149 .33388 Metetra
.975 .104 0 r
.077 .54382 .09138 .5568 .11099 .54883 .09635 .53851 Metetra
.968 .135 0 r
.09635 .53851 .11099 .54883 .13115 .53724 .11632 .52934 Metetra
.948 .213 0 r
.11632 .52934 .13115 .53724 .15172 .52282 .13677 .51713 Metetra
.92 .321 0 r
.13677 .51713 .15172 .52282 .17256 .50632 .15755 .5026 Metetra
.884 .444 0 r
.15755 .5026 .17256 .50632 .19358 .48841 .17857 .48644 Metetra
.844 .569 0 r
.17857 .48644 .19358 .48841 .21469 .4697 .19972 .46927 Metetra
.802 .687 0 r
.19972 .46927 .21469 .4697 .23583 .45073 .22095 .45163 Metetra
.729 .76 0 r
.22095 .45163 .23583 .45073 .25696 .43197 .24219 .434 Metetra
.561 .719 0 r
.24219 .434 .25696 .43197 .27805 .4138 .26343 .41679 Metetra
.417 .68 0 r
.26343 .41679 .27805 .4138 .29909 .39658 .28465 .40036 Metetra
.299 .645 0 r
.28465 .40036 .29909 .39658 .32008 .38059 .30583 .38498 Metetra
.205 .616 0 r
.30583 .38498 .32008 .38059 .34103 .36604 .32698 .37091 Metetra
.136 .591 0 r
.32698 .37091 .34103 .36604 .36196 .35313 .34812 .35833 Metetra
.088 .574 0 r
.34812 .35833 .36196 .35313 .38289 .34199 .36928 .34738 Metetra
.06 .563 0 r
.36928 .34738 .38289 .34199 .40386 .3327 .39048 .33815 Metetra
.051 .559 0 r
.39048 .33815 .40386 .3327 .42491 .32532 .41175 .33069 Metetra
.06 .563 0 r
.41175 .33069 .42491 .32532 .44607 .31986 .43315 .32501 Metetra
.088 .574 0 r
.43315 .32501 .44607 .31986 .46739 .31628 .45469 .32108 Metetra
.136 .591 0 r
.45469 .32108 .46739 .31628 .48891 .31451 .47644 .31882 Metetra
.205 .615 0 r
.47644 .31882 .48891 .31451 .51068 .31443 .49842 .3181 Metetra
.298 .645 0 r
.49842 .3181 .51068 .31443 .53273 .31587 .52068 .31875 Metetra
.417 .68 0 r
.52068 .31875 .53273 .31587 .5551 .31862 .54325 .32054 Metetra
.56 .718 0 r
.54325 .32054 .5551 .31862 .57782 .32241 .56615 .32318 Metetra
.728 .76 0 r
.56615 .32318 .57782 .32241 .60091 .32689 .58941 .32633 Metetra
.802 .688 0 r
.58941 .32633 .60091 .32689 .62439 .33167 .61303 .32956 Metetra
.844 .57 0 r
.61303 .32956 .62439 .33167 .64824 .33626 .637 .33238 Metetra
.884 .444 0 r
.637 .33238 .64824 .33626 .67244 .3401 .6613 .33421 Metetra
.919 .321 0 r
.6613 .33421 .67244 .3401 .69695 .34255 .68588 .33441 Metetra
.948 .213 0 r
.68588 .33441 .69695 .34255 .7217 .34289 .71066 .33223 Metetra
.968 .135 0 r
.71066 .33223 .7217 .34289 .74659 .34029 .73554 .32686 Metetra
.975 .104 0 r
.73554 .32686 .74659 .34029 .77149 .33388 .76037 .31742 Metetra
.972 .117 0 r
.06275 .5284 .077 .54382 .09635 .53851 .08175 .52605 Metetra
.975 .106 0 r
.08175 .52605 .09635 .53851 .11632 .52934 .10146 .51962 Metetra
.965 .148 0 r
.10146 .51962 .11632 .52934 .13677 .51713 .12172 .50989 Metetra
.944 .227 0 r
.12172 .50989 .13677 .51713 .15755 .5026 .14239 .4976 Metetra
.917 .33 0 r
.14239 .4976 .15755 .5026 .17857 .48644 .16335 .48344 Metetra
.884 .444 0 r
.16335 .48344 .17857 .48644 .19972 .46927 .1845 .46803 Metetra
.849 .557 0 r
.1845 .46803 .19972 .46927 .22095 .45163 .20578 .45192 Metetra
.812 .662 0 r
.20578 .45192 .22095 .45163 .24219 .434 .22712 .43561 Metetra
.775 .755 0 r
.22712 .43561 .24219 .434 .26343 .41679 .24849 .41951 Metetra
.651 .741 0 r
.24849 .41951 .26343 .41679 .28465 .40036 .26986 .40399 Metetra
.528 .71 0 r
.26986 .40399 .28465 .40036 .30583 .38498 .29121 .38936 Metetra
.428 .683 0 r
.29121 .38936 .30583 .38498 .32698 .37091 .31257 .37585 Metetra
.352 .661 0 r
.31257 .37585 .32698 .37091 .34812 .35833 .33392 .36366 Metetra
.299 .645 0 r
.33392 .36366 .34812 .35833 .36928 .34738 .3553 .35294 Metetra
.267 .635 0 r
.3553 .35294 .36928 .34738 .39048 .33815 .37673 .34378 Metetra
.257 .632 0 r
.37673 .34378 .39048 .33815 .41175 .33069 .39824 .33624 Metetra
.267 .635 0 r
.39824 .33624 .41175 .33069 .43315 .32501 .41987 .33033 Metetra
.298 .645 0 r
.41987 .33033 .43315 .32501 .45469 .32108 .44165 .32601 Metetra
.352 .661 0 r
.44165 .32601 .45469 .32108 .47644 .31882 .46363 .32318 Metetra
.427 .683 0 r
.46363 .32318 .47644 .31882 .49842 .3181 .48584 .32173 Metetra
.527 .71 0 r
.48584 .32173 .49842 .3181 .52068 .31875 .50831 .32147 Metetra
.65 .741 0 r
.50831 .32147 .52068 .31875 .54325 .32054 .53109 .32215 Metetra
.775 .755 0 r
.53109 .32215 .54325 .32054 .56615 .32318 .55418 .32349 Metetra
.811 .663 0 r
.55418 .32349 .56615 .32318 .58941 .32633 .57761 .3251 Metetra
.848 .558 0 r
.57761 .3251 .58941 .32633 .61303 .32956 .60139 .32657 Metetra
.884 .445 0 r
.60139 .32657 .61303 .32956 .637 .33238 .62548 .32738 Metetra
.917 .331 0 r
.62548 .32738 .637 .33238 .6613 .33421 .64988 .32694 Metetra
.944 .228 0 r
.64988 .32694 .6613 .33421 .68588 .33441 .67451 .32459 Metetra
.964 .148 0 r
.67451 .32459 .68588 .33441 .71066 .33223 .69931 .31959 Metetra
.975 .107 0 r
.69931 .31959 .71066 .33223 .73554 .32686 .72416 .31112 Metetra
.972 .117 0 r
.72416 .31112 .73554 .32686 .76037 .31742 .74892 .2983 Metetra
.96 .166 0 r
.04873 .50989 .06275 .5284 .08175 .52605 .06729 .51082 Metetra
.974 .11 0 r
.06729 .51082 .08175 .52605 .10146 .51962 .08666 .50741 Metetra
.974 .109 0 r
.08666 .50741 .10146 .51962 .12172 .50989 .10666 .50045 Metetra
.963 .152 0 r
.10666 .50045 .12172 .50989 .14239 .4976 .12715 .49068 Metetra
.945 .227 0 r
.12715 .49068 .14239 .4976 .16335 .48344 .148 .47877 Metetra
.92 .32 0 r
.148 .47877 .16335 .48344 .1845 .46803 .16911 .46535 Metetra
.891 .421 0 r
.16911 .46535 .1845 .46803 .20578 .45192 .1904 .45099 Metetra
.86 .52 0 r
.1904 .45099 .20578 .45192 .22712 .43561 .21179 .43619 Metetra
.83 .613 0 r
.21179 .43619 .22712 .43561 .24849 .41951 .23326 .42137 Metetra
.8 .693 0 r
.23326 .42137 .24849 .41951 .26986 .40399 .25476 .40691 Metetra
.773 .761 0 r
.25476 .40691 .26986 .40399 .29121 .38936 .27628 .39313 Metetra
.684 .749 0 r
.27628 .39313 .29121 .38936 .31257 .37585 .29781 .38027 Metetra
.606 .73 0 r
.29781 .38027 .31257 .37585 .33392 .36366 .31937 .36854 Metetra
.55 .716 0 r
.31937 .36854 .33392 .36366 .3553 .35294 .34097 .3581 Metetra
.516 .707 0 r
.34097 .3581 .3553 .35294 .37673 .34378 .36263 .34904 Metetra
.505 .704 0 r
.36263 .34904 .37673 .34378 .39824 .33624 .38437 .34142 Metetra
.516 .707 0 r
.38437 .34142 .39824 .33624 .41987 .33033 .40624 .33524 Metetra
.549 .716 0 r
.40624 .33524 .41987 .33033 .44165 .32601 .42827 .33047 Metetra
.605 .73 0 r
.42827 .33047 .44165 .32601 .46363 .32318 .45048 .32701 Metetra
.683 .749 0 r
.45048 .32701 .46363 .32318 .48584 .32173 .47292 .32473 Metetra
.773 .761 0 r
.47292 .32473 .48584 .32173 .50831 .32147 .49562 .32343 Metetra
.8 .694 0 r
.49562 .32343 .50831 .32147 .53109 .32215 .51861 .32285 Metetra
.829 .613 0 r
.51861 .32285 .53109 .32215 .55418 .32349 .5419 .3227 Metetra
.86 .521 0 r
.5419 .3227 .55418 .32349 .57761 .3251 .56551 .32258 Metetra
.891 .422 0 r
.56551 .32258 .57761 .3251 .60139 .32657 .58944 .32206 Metetra
.919 .321 0 r
.58944 .32206 .60139 .32657 .62548 .32738 .61366 .3206 Metetra
.944 .228 0 r
.61366 .3206 .62548 .32738 .64988 .32694 .63814 .31761 Metetra
.963 .154 0 r
.63814 .31761 .64988 .32694 .67451 .32459 .66283 .31241 Metetra
.974 .11 0 r
.66283 .31241 .67451 .32459 .69931 .31959 .68763 .30427 Metetra
.974 .11 0 r
.68763 .30427 .69931 .31959 .72416 .31112 .71243 .29237 Metetra
.96 .166 0 r
.71243 .29237 .72416 .31112 .74892 .2983 .73709 .27585 Metetra
.937 .256 0 r
.03509 .4876 .04873 .50989 .06729 .51082 .05313 .49208 Metetra
.963 .154 0 r
.05313 .49208 .06729 .51082 .08666 .50741 .07206 .492 Metetra
.975 .107 0 r
.07206 .492 .08666 .50741 .10666 .50045 .09172 .48809 Metetra
.974 .109 0 r
.09172 .48809 .10666 .50045 .12715 .49068 .11195 .4811 Metetra
.965 .147 0 r
.11195 .4811 .12715 .49068 .148 .47877 .13262 .47171 Metetra
.949 .212 0 r
.13262 .47171 .148 .47877 .16911 .46535 .15363 .46053 Metetra
.928 .291 0 r
.15363 .46053 .16911 .46535 .1904 .45099 .17487 .44813 Metetra
.904 .377 0 r
.17487 .44813 .1904 .45099 .21179 .43619 .19628 .43503 Metetra
.879 .461 0 r
.19628 .43503 .21179 .43619 .23326 .42137 .21781 .42167 Metetra
.855 .539 0 r
.21781 .42167 .23326 .42137 .25476 .40691 .23941 .40842 Metetra
.832 .606 0 r
.23941 .40842 .25476 .40691 .27628 .39313 .26107 .39561 Metetra
.812 .662 0 r
.26107 .39561 .27628 .39313 .29781 .38027 .28277 .38351 Metetra
.795 .706 0 r
.28277 .38351 .29781 .38027 .31937 .36854 .30452 .37232 Metetra
.783 .737 0 r
.30452 .37232 .31937 .36854 .34097 .3581 .32632 .3622 Metetra
.775 .755 0 r
.32632 .3622 .34097 .3581 .36263 .34904 .3482 .35326 Metetra
.773 .761 0 r
.3482 .35326 .36263 .34904 .38437 .34142 .37018 .34555 Metetra
.775 .755 0 r
.37018 .34555 .38437 .34142 .40624 .33524 .39229 .33908 Metetra
.783 .737 0 r
.39229 .33908 .40624 .33524 .42827 .33047 .41456 .33381 Metetra
.795 .706 0 r
.41456 .33381 .42827 .33047 .45048 .32701 .43701 .32963 Metetra
.811 .663 0 r
.43701 .32963 .45048 .32701 .47292 .32473 .45969 .3264 Metetra
.831 .607 0 r
.45969 .3264 .47292 .32473 .49562 .32343 .48262 .32393 Metetra
.854 .54 0 r
.48262 .32393 .49562 .32343 .51861 .32285 .50582 .32193 Metetra
.879 .462 0 r
.50582 .32193 .51861 .32285 .5419 .3227 .52931 .3201 Metetra
.903 .378 0 r
.52931 .3201 .5419 .3227 .56551 .32258 .5531 .31803 Metetra
.927 .293 0 r
.5531 .31803 .56551 .32258 .58944 .32206 .57718 .31527 Metetra
.948 .213 0 r
.57718 .31527 .58944 .32206 .61366 .3206 .60152 .31127 Metetra
.964 .149 0 r
.60152 .31127 .61366 .3206 .63814 .31761 .62609 .30545 Metetra
.974 .11 0 r
.62609 .30545 .63814 .31761 .66283 .31241 .65081 .29711 Metetra
.974 .109 0 r
.65081 .29711 .66283 .31241 .68763 .30427 .67561 .28551 Metetra
.963 .155 0 r
.67561 .28551 .68763 .30427 .71243 .29237 .70034 .26986 Metetra
.937 .257 0 r
.70034 .26986 .71243 .29237 .73709 .27585 .72487 .24933 Metetra
.9 .391 0 r
.02201 .46079 .03509 .4876 .05313 .49208 .03941 .46909 Metetra
.939 .247 0 r
.03941 .46909 .05313 .49208 .07206 .492 .05781 .47259 Metetra
.963 .154 0 r
.05781 .47259 .07206 .492 .09172 .48809 .07703 .47202 Metetra
.974 .109 0 r
.07703 .47202 .09172 .48809 .11195 .4811 .09692 .46808 Metetra
.975 .105 0 r
.09692 .46808 .11195 .4811 .13262 .47171 .11734 .46145 Metetra
.968 .133 0 r
.11734 .46145 .13262 .47171 .15363 .46053 .13817 .45275 Metetra
.956 .184 0 r
.13817 .45275 .15363 .46053 .17487 .44813 .15931 .44254 Metetra
.939 .247 0 r
.15931 .44254 .17487 .44813 .19628 .43503 .18068 .43135 Metetra
.921 .315 0 r
.18068 .43135 .19628 .43503 .21781 .42167 .20222 .41962 Metetra
.902 .382 0 r
.20222 .41962 .21781 .42167 .23941 .40842 .22389 .40774 Metetra
.884 .444 0 r
.22389 .40774 .23941 .40842 .26107 .39561 .24565 .39604 Metetra
.868 .497 0 r
.24565 .39604 .26107 .39561 .28277 .38351 .2675 .38479 Metetra
.854 .539 0 r
.2675 .38479 .28277 .38351 .30452 .37232 .28941 .37422 Metetra
.844 .57 0 r
.28941 .37422 .30452 .37232 .32632 .3622 .31141 .36448 Metetra
.838 .588 0 r
.31141 .36448 .32632 .3622 .3482 .35326 .3335 .35568 Metetra
.836 .595 0 r
.3335 .35568 .3482 .35326 .37018 .34555 .35571 .34788 Metetra
.838 .589 0 r
.35571 .34788 .37018 .34555 .39229 .33908 .37805 .34108 Metetra
.844 .57 0 r
.37805 .34108 .39229 .33908 .41456 .33381 .40055 .33524 Metetra
.854 .54 0 r
.40055 .33524 .41456 .33381 .43701 .32963 .42325 .33025 Metetra
.868 .498 0 r
.42325 .33025 .43701 .32963 .45969 .3264 .44617 .32597 Metetra
.884 .445 0 r
.44617 .32597 .45969 .3264 .48262 .32393 .46932 .32217 Metetra
.902 .384 0 r
.46932 .32217 .48262 .32393 .50582 .32193 .49274 .31858 Metetra
.921 .317 0 r
.49274 .31858 .50582 .32193 .52931 .3201 .51643 .31486 Metetra
.939 .249 0 r
.51643 .31486 .52931 .3201 .5531 .31803 .54039 .31062 Metetra
.955 .186 0 r
.54039 .31062 .5531 .31803 .57718 .31527 .56462 .30537 Metetra
.968 .136 0 r
.56462 .30537 .57718 .31527 .60152 .31127 .58907 .29858 Metetra
.975 .107 0 r
.58907 .29858 .60152 .31127 .62609 .30545 .61371 .28963 Metetra
.974 .111 0 r
.61371 .28963 .62609 .30545 .65081 .29711 .63846 .27785 Metetra
.963 .156 0 r
.63846 .27785 .65081 .29711 .67561 .28551 .66323 .2625 Metetra
.939 .249 0 r
.66323 .2625 .67561 .28551 .70034 .26986 .68788 .24282 Metetra
.899 .392 0 r
.68788 .24282 .70034 .26986 .72487 .24933 .71226 .21799 Metetra
.846 .565 0 r
.00966 .4287 .02201 .46079 .03941 .46909 .02631 .44104 Metetra
.9 .39 0 r
.02631 .44104 .03941 .46909 .05781 .47259 .04408 .44836 Metetra
.937 .255 0 r
.04408 .44836 .05781 .47259 .07703 .47202 .06277 .45137 Metetra
.961 .164 0 r
.06277 .45137 .07703 .47202 .09692 .46808 .08223 .45074 Metetra
.973 .115 0 r
.08223 .45074 .09692 .46808 .11734 .46145 .10231 .44712 Metetra
.976 .102 0 r
.10231 .44712 .11734 .46145 .13817 .45275 .12289 .44114 Metetra
.972 .116 0 r
.12289 .44114 .13817 .45275 .15931 .44254 .14386 .43334 Metetra
.964 .149 0 r
.14386 .43334 .15931 .44254 .18068 .43135 .16512 .42426 Metetra
.953 .194 0 r
.16512 .42426 .18068 .43135 .20222 .41962 .18663 .41434 Metetra
.94 .243 0 r
.18663 .41434 .20222 .41962 .22389 .40774 .20831 .40399 Metetra
.928 .291 0 r
.20831 .40399 .22389 .40774 .24565 .39604 .23014 .39353 Metetra
.915 .335 0 r
.23014 .39353 .24565 .39604 .2675 .38479 .25208 .38324 Metetra
.905 .372 0 r
.25208 .38324 .2675 .38479 .28941 .37422 .27414 .37336 Metetra
.897 .399 0 r
.27414 .37336 .28941 .37422 .31141 .36448 .29631 .36405 Metetra
.892 .416 0 r
.29631 .36405 .31141 .36448 .3335 .35568 .3186 .35541 Metetra
.891 .422 0 r
.3186 .35541 .3335 .35568 .35571 .34788 .34101 .34751 Metetra
.892 .416 0 r
.34101 .34751 .35571 .34788 .37805 .34108 .36358 .34035 Metetra
.897 .4 0 r
.36358 .34035 .37805 .34108 .40055 .33524 .38631 .33388 Metetra
.905 .373 0 r
.38631 .33388 .40055 .33524 .42325 .33025 .40924 .32799 Metetra
.915 .337 0 r
.40924 .32799 .42325 .33025 .44617 .32597 .43239 .32252 Metetra
.927 .293 0 r
.43239 .32252 .44617 .32597 .46932 .32217 .45577 .31725 Metetra
.94 .245 0 r
.45577 .31725 .46932 .32217 .49274 .31858 .4794 .31188 Metetra
.953 .196 0 r
.4794 .31188 .49274 .31858 .51643 .31486 .50328 .30609 Metetra
.964 .152 0 r
.50328 .30609 .51643 .31486 .54039 .31062 .52741 .29944 Metetra
.972 .119 0 r
.52741 .29944 .54039 .31062 .56462 .30537 .55177 .29146 Metetra
.975 .105 0 r
.55177 .29146 .56462 .30537 .58907 .29858 .57633 .2816 Metetra
.972 .118 0 r
.57633 .2816 .58907 .29858 .61371 .28963 .60103 .26925 Metetra
.96 .167 0 r
.60103 .26925 .61371 .28963 .63846 .27785 .62579 .25375 Metetra
.937 .257 0 r
.62579 .25375 .63846 .27785 .66323 .2625 .6505 .23438 Metetra
.899 .392 0 r
.6505 .23438 .66323 .2625 .68788 .24282 .67504 .2104 Metetra
.845 .567 0 r
.67504 .2104 .68788 .24282 .71226 .21799 .69925 .18104 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.08206 .23755 m
.08679 .24211 L
s
[(-10)] .07261 .22845 1 .96289 Mshowa
.27211 .16314 m
.27652 .16799 L
s
[(-5)] .26329 .15343 .90843 1 Mshowa
.477 .08291 m
.48103 .08809 L
s
[(0)] .46894 .07256 .77832 1 Mshowa
.125 Mabswid
.11896 .22311 m
.12176 .22587 L
s
.1564 .20844 m
.15917 .21125 L
s
.1944 .19357 m
.19713 .19641 L
s
.23297 .17847 m
.23565 .18134 L
s
.31185 .14758 m
.31445 .15053 L
s
.35219 .13178 m
.35475 .13477 L
s
.39315 .11574 m
.39567 .11877 L
s
.43475 .09945 m
.43722 .10252 L
s
.51991 .06611 m
.52228 .06925 L
s
.5635 .04904 m
.56582 .05222 L
s
.60779 .03169 m
.61005 .03492 L
s
.6528 .01407 m
.655 .01734 L
s
.04569 .2518 m
.04856 .25449 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00d_ooool2o`0004cooooo003?ooooo`Go0000C?ooool00<gooooo0_l00004ooooo`;o0000
Boooool00<[ooooo0ol00006ooooo`03o`000?oooooo000004[ooooo0038ooooo`?o00002?ooool0
0ol0003oooooo`00001:ooooo`00aOooool3o`0000;ooooo00?o0000ooooooooool01_ooool01?l0
003oooooooooool00019ooooo`00`oooool2o`0000kooooo00Go0000ooooooooooooooooo`000018
ooooo`00`?ooool3o`00013ooooo00Go0000ooooooooooooooooo`000018ooooo`00__ooool2o`00
01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`15ooooo`00^oooool3o`000003
ooooool0003ooooo01;ooooo00Oo0000ooooooooooooooooo`000?oooooo000004Kooooo002Joooo
o`;o00007?ooool3o`0001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`14oooo
o`00VOooool01?l0003oooooooooool0000Iooooo`;o00007?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04?ooooo002Iooooo`04o`000?ooooooooooo`0001Kooooo0ol0000Noooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@oooool009Wooooo00Co0000oooooooo
oooo00005?ooool2o`0000;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04;ooooo002Iooooo`04o`000?ooooooooooo`00017ooooo0ol0000Soooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@Oooool009Wooooo00Co0000oooooooo
oooo00003oooool2o`0002Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11oooo
o`00V_ooool2o`0000gooooo0ol0000Xooooo`03o`000?oooooooooo00Gooooo0_l00012ooooo`00
Yoooool2o`000003ooooool0003ooooo02Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0oooooo`00Y?ooool3o`0002gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0;ooooo`?o0000<Oooool00:;ooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool01Ol0003ooooooooooooooooo0000033ooooo002Oooooo`?o0000<_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo1Ol00005ooooo`03o`000?oooooo
oooo02kooooo002Mooooo`?o0000=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0;_ooool009[ooooo0ol00003ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`Co0000<Oooool009Sooooo
0_l0000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0booooo`00UOooool3o`0003cooooo00?o0000ooooooooool02Oooool3o`0000Sooooo1Ol0
000`ooooo`00Toooool3o`0003kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0j
ooooo`00T?ooool3o`00047ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0ioooo
o`00S_ooool2o`0004Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0iooooo`00
Roooool3o`0004Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0hooooo`00ROoo
ool3o`0004Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0hooooo`00I_ooool3
o`0001gooooo0ol0001;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=oooool0
06Gooooo00Go0000ooooooooooooooooo`00000Iooooo`?o0000Coooool00ol0003oooooooooo`0>
ooooo`;o0000>?ooool005oooooo1Ol00005ooooo`03o`000?oooooooooo01Gooooo0_l0001Boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=_ooool006Wooooo00?o0000oooooooo
ool04_ooool4o`0005?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0eooooo`00
IOooool4o`0001?ooooo0_l0001Gooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
=?ooool006Gooooo00?o0000ooooooooool04Oooool3o`0005Wooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0dooooo`00IOooool5o`0000gooooo0_l0001Looooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0<oooool007Cooooo1?l0001Mooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0<_ooool007;ooooo0_l0001Qooooo`03o`000?oooooooooo01;o
oooo0_l0000dooooo`00Koooool3o`0006?ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0aooooo`00KOooool2o`0006Kooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0`ooooo`00J_ooool3o`000003ooooool0003ooooo06Gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0`ooooo`00J?ooool2o`0006_ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0_ooooo`00IOooool3o`0006gooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0^ooooo`00Hoooool2o`00073ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0^ooooo`00H?ooool3o`000003ooooool0003ooooo06oooooo00?o0000ooooooooool05ooo
ool2o`0002oooooo001Nooooo`;o0000M?ooool3o`0001Wooooo00?o0000ooooooooool0;Oooool0
05_ooooo0ol0001eooooo`04o`000?oHT@3o0000o`0001[ooooo00?o0000ooooooooool0;?ooool0
037ooooo0ol00004ooooo`;o00007oooool3o`0007Kooooo00?o0000omRA0?oHT@000_l0000Koooo
o`03o`000?oooooooooo02_ooooo000booooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00006oooool3o`0007Wooooo00Ko0000omRA0?oHT@3o0000omRA0?l0000Jooooo`03o`000?oo
oooooooo02_ooooo000Zooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0001Wooooo0_l0001kooooo`07o`000?oHT@3of940omRA0?l0003of940o`00000Kooooo`03
o`000?oooooooooo02[ooooo000booooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00005_ooool3o`0007cooooo00?o0000omRA0?oHT@000ooHT@02o`0001cooooo00?o0000oooooooo
ool0:Oooool003;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Cooooo`?o
000000?oooooo`000?ooool0N_ooool2o`0000Kof94000?o0000omRA0?l000006_ooool2o`0002_o
oooo000aooooo`;o00001?ooool01?l0003oooooooooool0000Aooooo`;o0000Ooooool00ol0003o
iV@0o`000006omRA0003o`000?oHT@3o000001cooooo00?o0000ooooooooool01_ooool2o`00023o
oooo000booooo`03o`000?oooooooooo00?ooooo0_l0000?ooooo`?o0000P?ooool01Ol0003oiV@0
onIT0?oVI03o000000Gof94000?o0000omRA0?l000007Oooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0001oooooo0017ooooo`;o0000P_ooool00ol0003oiV@0onIT0002onIT0003
o`000?oHT@3of94000?of9400_l000000ooVI03o0000ooooo`0Kooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00007oooool004Cooooo0ol00023ooooo`03o`000?oVI03oiV@000?o
iV@000?o0000omRA0?oHT@000ooHT@001?l0003oiV@0onIT0?l0000Mooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00007oooool004;ooooo0_l00024ooooo`;o00001ooVI0001?l0
003of940omRA0?oHT@02o`0000;oiV@000?o0000ooooooooool07?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0001oooooo000oooooo`?o0000QOooool00ol0003okd40o`000007
onIT0006o`000?oHT@3of940o`000?oVI03o00000ooVI0000ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00007oooool003gooooo0_l000000ooooooo0000
ooooo`24ooooo`05o`000?o_@@3okd40onm10?l000001_oVI0000ol0003of940o`000002onIT0005
o`000?oVI03oiV@0onIT0?l000007?ooool00ol0003oooooo`000004ooooo`;o00008?ooool003[o
oooo0ol00028ooooo`03o`000?o_@@3okd4000;okd4000?o0000onIT0?oVI0001?oVI002o`0000;o
iV@00_l00003onIT0003o`000?oooooooooo01gooooo00?o0000ooooooooool08oooool003Sooooo
0_l0002:ooooo`03o`000?o_@@3okd4000Cokd4000?o0000onIT0?oVI0000_oVI0000ol0003ol3l0
o`000002o`000003onIT0?l0003oiV@000;oiV@00_l0000Nooooo`03o`000?oooooooooo02?ooooo
000eooooo`?o0000R_ooool2o`0000Ookd4000?o0000onIT0?oVI0001?l000000oo`?`3o0000onIT
0002onIT0005o`000?oVI03o0000onm10?l000007oooool00ol0003oooooooooo`0Rooooo`00=?oo
ool2o`0008_ooooo00?o0000ooDZ0?l000001oo_@@04o`0000Col3l000?o0000onIT0?oVI0000_oV
I0001Ol0003okd40onm10?o_@@3o000001kooooo00?o0000ooooooooool08_ooool003Cooooo00?o
0000ooooool00000R?ooool2o`0000?omBX000?o0000onm10?o_@@000_o_@@04o`0000Ool3l000Ko
0000onIT0?oVI03o0000onm10?l00002onm10003o`000?oooooooooo01gooooo00?o0000oooooooo
ool08Oooool003Cooooo00Co0000oooooooooooo0000Q_ooool00ol0003omBX0ooDZ0003ooDZ0003
o`000?o_@@3o000000;o000000Cokd40o`000?of9`3o00001oo`?`000ol0003oiV@0o`000002onm1
0005o`000?o_@@3okd40onm10?l000007_ooool2o`0002;ooooo000cooooo`;o00000oooool00ol0
003oooooooooo`21ooooo`;o00001Ooe:P03o`0000;okd400_l00003ooHW0003o`000?o`?`3ol3l0
00Col3l00_l00004onm10004o`000?o_@@3okd40o`0001oooooo00?o0000ooooooooool08?ooool0
03?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1nooooo`;o000000?on1h0o`00
0?oe:P000_oe:P02o`0000;omBX000?o0000onm10?l000001Oof9`000ol0003ol3l0oo0o0003oo0o
0003o`000?of9`3o000000Gokd4000?o0000onm10?l000008?ooool00ol0003oooooooooo`0Ooooo
o`00<oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07_ooooo0_l00004ooPN00?o
00001?oe:P02o`0000OomRL000?o0000oo0o0?o`?`000_l00003ooHW0003o`000?o_@@3okd4000;o
kd4000Co0000onm10?l0003o00008?ooool00ol0003oooooooooo`0Nooooo`00<oooool2o`0000Ko
oooo00?o0000ooooooooool0N?ooool2o`0000?on1h00ol000000ooh7P3o0000ooDZ0002ooDZ00;o
000000?onA`0o`000?of9`001_of9`000ol0003ol3l0o`000005ooHW0003o`000?o_@@3okd4000?o
kd4000?o0000ooDZ0?l000008?ooool00ol0003oooooooooo`0Nooooo`00<oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo07Cooooo0ol000000ooi6P3o0000o`000002o`0000Con1h0
00Co0000ooDZ0?l0003o00001?oi70000ol0003omRL0ooHW0004ooHW00;o00001oof9`000ol0003o
kd40onm10002o`000004ooDZ0?l0003omBX0o`00023ooooo00?o0000ooooooooool07Oooool003?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1`ooooo`?o00000_oi6P04o`0000Ko
n1h00_l00007ooTL0004o`000?of9`3omRL0ooHW00;o000000?onA/0o`000?of9`001_of9`000ol0
003okd40o`000004ooDZ0003o`000?oe:P3o000001oooooo0_l0000Nooooo`00<oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo06cooooo0ol000000ooh7P3o0000o`000002o`0000Co
nAX000?o0000ooPN0?oh7P000ol000000ooi6`3o0000ooTL0006ooTL0004o`000?of9`3o0000o`00
00ConA/000?o0000ooHW0?of9`001?of9`02o`0000GomBX000?o0000ooDZ0?l000008?ooool00ol0
003oooooooooo`0Looooo`00<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06So
oooo0ol00003ooPN00?o00001_oi6P03o`0000GonA/000?o0000ooTL0?oi70001?oi7002o`0000Oo
nA/000Co0000ooHW0?of9`3omRL00_l000000ooi703o0000ooDZ0005ooDZ00?o00008?ooool00ol0
003oooooooooo`0Kooooo`00<_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Co
oooo0ol00002ooHV00Co00000ooh7P000ol0003onAX0ooTJ0003o`0000;omb8000?o0000ooTK0?oi
6`001?oi6`000ol0003onA`0ooTL0003o`0000;onA`000?o0000ooTK0?oi6`001?oi6`001?l0003o
mRL0o`000?l00004ooTL0003o`000?oe:P3omBX000;omBX01?l0000Qooooo`03o`000?oooooooooo
01[ooooo000booooo`;o00003Oooool2o`00063ooooo1?l00003ooHV00Co00000ooh7P05o`0000Ko
mb8000Co0000ooTK0?oi6`3onA/01Ol00006ooTL0004o`000?oi6`3onA/0ooTK00Co00001ooi7000
1?l0003omBX0o`000?l00003ooPM00;o00008?ooool00ol0003oooooooooo`0Jooooo`001oooool3
o`0000;ooooo0ol00003ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3
o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Eoooool6
o`0000Colc800ol00002ooHV00Go00001Ood;`001?l0003omb80ooLR0?og8P06o`0000ComRH000?o
0000ooTL0?oi70001?oi7004o`0000ConA`000?o0000ooTL0?oi70001?oi7002o`0000Gon1d000?o
0000ooPM0?l000008?ooool00ol0003oooooooooo`0Iooooo`002?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool01ol0003ooooooooo
oooooooo0000ooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Aooooo`Oo00000oo`?P000ol0
003olc80o`000007o`0000Col3l00_l00003oo@_00Go00001Oob=P000ol0003omRH0ooHV0003ooHV
0003o`000?oi703onA`000?o00000_of9`000ol0003onA`0ooTL0004ooTL0003o`000?oi703onA`0
00?o000000?onA/0o`000?oh7@001Ooh7@02o`00023ooooo0_l0000Jooooo`001Oooool5o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0C?ooool9o`0000?ol3h01_l00003on]A00co00001?o]B`001?l0003olSH0oo8f0?ob=P0;
o`0000KomRL000Co0000ooTL0?oi703onA`01Ol00005ooTK0003o`000?oh7@3on1d000Con1d00_l0
000Pooooo`03o`000?oooooooooo01Sooooo0005ooooo`04o`000?ooooooooooo`0000Cooooo0_l0
0004ooooo`;o00003?ooool01?l0003oooooooooooooool2o`0000Gooooo00?o0000ooooooooool0
0_ooool2o`0001?ooooo00?o0000ooooooooool0B?ooool6o`0000CokD/08_l00005on]B0003o`00
0?oa>P3olCX000?olCX000Co0000ooHW0?of9`3omRL01_l00004ooHU0003o`000?oi6`3onA/000Co
nA/000?o0000ooPM0?oh7@000ol000000ooi6P3o0000ooooo`0Pooooo`03o`000?oooooooooo01Oo
oooo0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`Co00001_ooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool0
00005Oooool00ol0003oooooooooo`14ooooo`Co00000ooZEP0=o`000004o`0@:_l0003o0000o`00
00;o00XT00Co0000o`0;9Ol02bGo00/U8?l00004oo4j0003o`000?of9@3omRD000ComRD000Co0000
ooTK0?oi6`3onA/01Ol00004ooTJ00;o00008?ooool00ol0003oooooooooo`0Gooooo`001oooool2
o`0000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`07o`000?ooooooooooooooool0003oooooo`000003oooo
o`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`10ooooo`?o000000?oiel0
o`000?l000003Ol00003o`0B;0;o00001Ol02R@4o`0000?o00LQ00?o0000o`0;9Ol02bD00_l02bD0
0ol0003o018/o`0B;002o`0B;004o`000?l07CCo01ddo`0M=0go000000?ojU@0o`000?oa>P001?oa
>P001?l0003omRD0ooHU0?of9@06o`0000Comb8000?o0000ooTJ0?oi6P000ooi6P02o`00023ooooo
00?o0000ooooooooool05_ooool000Sooooo00Co0000oooooooooooooooo0ol00003ooooo`?o0000
2?ooool5o`0000;ooooo0ol00003ooooo`?o00001?ooool2o`0001Kooooo00?o0000ooooooooool0
>_ooool=o`0000;o03I32?l000001?l04Rco0000o`000?l00002o`0;9@03o`000?l02RCo000000;o
00000_l01R000ol0003o00LQo`078@03o`078@03o`000?l02bGo00/U00co00000ol0;clCo`0000Co
lSH000?o0000ooLR0?og8P001?og8P001?l0003onAX0ooTJ0?oi6P04o`00023ooooo00?o0000oooo
ooooool05Oooool0037ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0eooooo`_o
000000Ko05m4o`000?l0D4ko051>o`000?l0=T<3o`000003o`0S>?l0003o000000?o01H_0ol00004
o`0;9@?o00001Ol01R001?l0003o00LQo`078Ol01b44o`0000?o00XT00?o0000o`0@:_l042X00_l0
42X00ol0003o01/co`0K<`06o`0000;o04Y=0ol000000ol0GdCo0000o`000007o`000003on]B0?l0
003olSH000ColSH000Co0000ooLR0?og8P3omb801_l00002ooPN00;o00008?ooool2o`0000Kooooo
0ol0000=ooooo`00<Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo037ooooo0ol0
00000ooTJP3o0000o`00000@o`000003o`0S>?l0003o01H_00;o01H_0_l00003o`0?:@04o`000?l0
2bGo0000o`0000?o00LQ00Co0000o`068?l01R3o00HP1Ol00002o`068003o`000?l02RCo00XT00?o
00XT00?o0000o`0@:_l042X00_l042X01Ol0003o01/co`0K<ol06c?o000000;o02dn1?l000000ol0
BTgo0000o`00000Do`0000?om2l000?o0000ooPN0?oh7P000ooh7P02o`00023ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000cooooo000`ooooo`;o00006_ooool00ol0
003oooooooooo`0^ooooo`_o00000_l0I3l2o`000003o`1FBol0003o000000?o00000_l0;Ch4o`00
0003o`0F;ol0003o00lY00Co00lY0_l00005o`078@Co00000_l01Ah00ol0003o00HPo`068003o`06
8004o`000?l02RCo00XTo`0:90co00000ol0;Ch00ol0003o04Q;o`000002o`0000;o05]70_l00000
0ol0Kc7o0000o`000006o`0000GokDX000?o0000oo@_0?od;`000ood;`001?l0003on1h0ooPN0?oh
7P04o`00023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`00<?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02[ooooo2ol000001?l0M2Wo0000o`1T?ol0
I3l4o`0000;o04=900Go0000o`0]?_l0;Cko02dno`000003o`0O=P?o00000ol03bT2o`0000;o00/U
00?o0000o`078Ol000000_l00002o`068003o`000?l01Ako00DN00;o00DN00Co0000o`068?l01R3o
00HP1Ol00002o`0;9@03o`000?l04Rco018/00;o018/00Co0000o`0M=?l07CCo01dd1_l00003o`18
B`;o000000?o05]7o`000?l000005ol00003ooHV00;o00007oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00[ooooo000`ooooo`03o`000?oooooooooo01_ooooo0_l0000Wooooo`Wo
000000GoC:D0o`000?l0Q@Wo0000o`1d:@0<o`000004o`0]?_l0003o01lfo`0O=P;o00000ol05Rl0
0ol0003o00lYo`000004o`0;9@;o00001_l01R000ol0003o00DNo`057P05o`0000?o00LQ00?o0000
o`0;9Ol02bD00_l02bD00ol0003o018/o`0B;002o`0B;005o`000?l07CCo01ddo`0M=?l000000ol0
;cl3o`000003o`18Bol0003o05Y800?o000000Co06`fo`000?l0003o080C2ol000000ooWH03o0000
oo0o0003oo0o0003o`000?of9P3omRH000;omRH000?o0000ooHV0?l000007oooool01?l0003ooooo
ooooooooool4o`0000gooooo000`ooooo`;o00007_ooool00ol0003oooooooooo`0Qooooo`?o0000
00?oi6X0o`000?l000001ol000000ol0Q@Wo0000o`000004o`000005o`1NAOl0003o055=o`1ACOl0
00000ol0?DL3o`000003o`0O=_l0003o01H_00Co01H_0ol00003o`0;9@04o`000?l02RCo00XTo`00
00Go00HP0ol00003o`068003o`000?l01b7o00LQ00?o00LQ00Go0000o`0;9Ol02bGo00/Uo`000004
o`0B;003o`000?l07CCo01dd00;o01dd00Ko0000o`0_?ol0;coo02loo`000?l0BTd3o`0000?o05Y8
0_l000001?l0K3Ko0000o`000?l0P1<7o`0000;ohGH01_l000000oo`?`3o0000ooHV0002ooHV00Co
00007oooool01?l0003oooooooooool0000@ooooo`00<?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01kooooo5?l00002o`1NA@04o`000?l0DDgo055=o`0000?o03e700Co0000o`0]
?_l0;Cko02dn0_l00003o`0F;`;o00000ol04R`00ol0003o00/Uo`000004o`0:9003o`000?l01R3o
000000;o000000?o00LQo`000?l01R001?l01R001?l0003o00LQo`078Ol01b4@o`0000Co02lo00Co
0000o`1:COl0BTgo04Y=0_l000000ol0FTSo0000o`1[=`0:o`000003olG20?l0003o000000;o0000
00CohGH0o`000?o[D03oje001Ol00002oo<a0003o`000?oc<@3o000001gooooo0_l00002ooooo`Go
00003?ooool0033ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Jooooo`?o0000
0_oUIP0>o`0000;o06`f00Co0000o`1NAOl0GTGo00000_l0DDd01Ol0003o03e7o`0mAol0?DOo0000
00?o02dn00Ko0000o`0S>?l08cSo0000o`0F;ol00005o`0B;0;o00001Ol02R@2o`0000Go00LQ00?o
0000o`068?l01R000_l01R04o`0000;o00/U00Go0000o`0?:Ol03bWo00lYo`000004o`0F;`04o`00
0?l08cSo02<ho`0S>0Ko00000ol0BTd00ol0003o05]7o`000002o`0000?o06/g0_l000000ol0OAWo
0000o`000005o`000003olG20?l0003o000000Go000000?oje00o`000?oc<@000ooc<@000ol0003o
lc40o`00000Nooooo`03o`000?oooooooooo013ooooo000`ooooo`;o00008Oooool00ol0003ooooo
ooooo`0Gooooo`Co000000?oiFH0o`000?l000006?l000000ol0?DOo0000o`0]?P02o`0]?P04o`00
0?l08cSo02<ho`0S>0;o00001Ol04R`00ol0003o010Zo`000003o`0:90;o000000?o00/Uo`000?l0
1b401?l01b400ol0003o00HPo`000002o`000003o`0:9?l0003o00/U00Co00/U00Go0000o`0?:Ol0
3bWo00lYo`000004o`0F;`05o`000?l08cSo02<ho`0S>?l000000ol0=T<6o`0000?o05]70ol00000
0ol0JcOo0000o`00000:o`000005omBK0?l0003o0000o`000?oVHP002_l0000Nooooo`03o`000?oo
oooooooo00oooooo0004ooooo`?o00000_ooool3o`0000?ooooo0ol00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00003ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Dooooo`;o00000ooWG`0?o`0000;o07DW00Co0000o`1W>ol0Ic_o00000ol0
FdL00ol0003o055=o`1AC@04o`000003o`0]?_l0003o02<h00;o02<h00Co0000o`0M=?l07CCo0000
0ol04R`01ol0003o010Zo`0@:_l042[o0000o`0:9?l000001?l02bD00ol0003o00LQo`078@02o`07
8@;o00001Ol02R@00ol0003o00/Uo`0;9@02o`0;9@03o`000?l03bWo00lY00;o00lY00?o0000o`0F
;ol05Rl00_l05Rl01Ol0003o02<ho`0S>?l08cSo000000?o03I300Co0000o`1@C_l0D4ko051>0ol0
00001?l0FdOo0000o`1/=_l0K3H3o`000004o`1l6ol0003o0000o`n@00Wo000000?oe9/0o`000?l0
00000_l000001ooVHP3o0000oo0n0?o`?P3o0000oo0n0?l000007_ooool00ol0003oooooooooo`0?
ooooo`001Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool01Oooool01ol0003ooooooooooooooooo0000ooooool000000oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Aooooo`;o00000_oWG`03o`000003omZ90?l0003o000000So00000_l0Q0/01?l0003o
07DWo`1e9ol00002o`1W>`05o`000?l0FdOo05]7o`1KAol000000_l0DDd00ol0003o0499o`12B@02
o`12B@05o`000?l08cSo02<ho`0S>?l000001?l07C@00ol0003o018/o`000005o`0@:P03o`000?l0
2bGo00/U00?o00/U00?o0000o`078Ol000000_l000000ol02bGo0000o`0:9004o`0:9004o`000?l0
2bGo00/Uo`0;9A7o00000ol0=T<01_l0003o051>o`1@C_l0D4ko0000o`1OA0?o00001?l0K3H2o`00
0004o`1l6ol0003o0000o`n@00?o000000?oV[X0o`000?l000001?l00002on9a00Ko000000?ol3h0
o`000?ooool07Oooool00ol0003oooooooooo`0>ooooo`000_ooool5o`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03_ooool;
o`000003ojno0?l0003o000000?o000000Go6i@0o`000?l0Q0_o08@;o`000002o`1e9`04o`000?l0
Ic_o06Lko`0000?o05]700Co0000o`1ACOl0DDgo00001?l0@TT01Ol0003o03I3o`000?l08cSo0000
00Go01dd0_l00005o`0@:P;o00001Ol02bD2o`0000Go00/U00?o0000o`0:9?l02R@00_l02R@4o`00
00;o018/00?o0000o`0F;ol05Rl00_l05Rl00ol0003o01lfo`0O=P02o`0O=P04o`000?l0;Cko02dn
o`0]?PKo00000ol0D4h00ol0003o05m4o`1OA002o`0000?o06`f00Go0000o`1m6Ol0003o0000o`f?
0002o`000003odBR0?l0003o000000;o000000?oV[X0o`000?l000001?l000001?oRL@3o0000one:
0?o]BP04o`0001gooooo0_l0000?ooooo`000_ooool01?l0003oooooooooool00004ooooo`;o0000
1?ooool2o`0000cooooo00Co0000oooooooooooooooo0_l00005ooooo`03o`000?oooooooooo00?o
oooo0_l0000Vooooo`03o`000?oooooooooo00[ooooo0ol00002onYE00;o00000_oNO`07o`0000;o
C:D000?o0000oa^D0?l000000_l0Q0/9o`000005o`1KAol0003o055=o`1ACOl000001?l0@TT01?l0
003o03I3o`0f@ol0=T<2o`0000?o01dd0_l00002o`0K<`05o`000?l042[o010Zo`0@:_l000000_l0
4R`01ol0003o00/Uo`0;9Ol02bGo0000o`0?:Ol000001_l02bD01_l0003o00XTo`000?l0003o010Z
o`0000Go018/00?o0000o`0F;ol05Rl00_l05Rl00ol0003o01lfo`0O=P02o`0O=P05o`000?l0;Cko
02dno`0]?_l000000ol0@dT3o`0000;o051>00Co0000o`1OA?l0GdCo05m40_l00002o`1/=P04o`00
0?l0OAWo07dIo`0000;o3Hl000?o0000odBR0?m4XP001Ol000000oo;]03o0000o`000004o`0000;o
kDX000?o0000one:0?l000007_ooool00ol0003oooooooooo`0=ooooo`000oooool00ol0003ooooo
o`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool4o`0000Kooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool01oooool4o`0000;ojUD000?o0000omio0?oNO`001_l000001?n7]@3o0000
odbU0?m<Y@07o`000005o`204ol0003o07<[o`1c:ol000000_l0Ic/6o`0000?o049900?o0000o`0f
@ol0=T<00_l0=T<01Ol0003o02loo`000?l07CCo000000Go01/c00?o0000o`0@:_l000001?l04R`0
0ol0003o00/Uo`000003o`0?:@03o`000?l02bGo00/U00?o00/U0_l00004o`0@:P03o`000?l04Rco
018/00?o018/00Go0000o`0F;ol05Roo01H_o`000004o`0O=P03o`000?l0;Cko02dn00;o02dn00Ko
0000o`13BOl0@dWo04=9o`000?l0ET/3o`0000?o05m400?o0000o`1_<Ol000000_l00003o`1m6@;o
000000?o3Hl0o`000?l000000_m4XP02o`000003ohbg0?l0003o000000;obk@01ol000000oo]BP3o
0000ooooo`0Mooooo`03o`000?oooooooooo00cooooo0004ooooo`;o00000_ooool01ol0003ooooo
oooooooooooo0000ooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo0_l00004one:00So000000?o
aL80o`000?n7]@001_l000000ol=S`3o0000o`204`02o`204`04o`000?l0Lb_o07<[o`0000;o06Lk
00Go0000o`1NAOl0GTGo05i5o`000002o`1FB`03o`000?l0@TWo000000Co03I300Go0000o`0_?ol0
;coo02loo`000006o`0K<`;o00001Ol04R`2o`0000Go00lY00?o0000o`0;9Ol000000_l000000ol0
4Rco0000o`0@:P04o`0@:P03o`000?l04Rco018/00;o018/00Go0000o`0F;ol05Roo01H_o`000004
o`0O=P03o`000?l0;Cko02dn00;o02dn00?o0000o`13BOl0@dT00_l0@dT01?l0003o05I;o`1FBol0
ET/2o`0000;o05m400Co0000o`1_<Ol0Kc7o06la0_l000000ol0OAWo0000o`n@0006o`000004ohBd
0?l0003o0000olRl00?o00000_oJR@03o`000004onYF0?l0003o0000o`0001gooooo00?o0000oooo
ooooool03?ooool000Gooooo00Co0000oooooooooooooooo0ol00003ooooo`?o00002?ooool5o`00
00;ooooo0ol00003ooooo`?o00001?ooool2o`0002[ooooo00?o0000ooooooooool00_ooool00ol0
003okDX0one:0002one:00;o000000?ohW40o`000?l000000ol00002olG200Go00000_lgWP000ol0
003o3Hl0o`000003o`204`04o`000?l0Lb_o07<[o`0000;o06Lk00Go0000o`1NAOl0GTGo05i5o`00
0004o`1FB`;o00000ol0=T<01ol0003o02loo`0_?ol0;coo0000o`0]?_l000000ol06c<2o`000003
o`0M=?l0003o018/00;o018/0_l000000ol05Roo0000o`0?:@04o`0?:@;o00001Ol04R`00ol0003o
010Zo`0@:P02o`0@:P04o`000?l04Rco018/o`0B;1Go00000ol0ET/00ol0003o06@oo`000002o`00
00?o06la00?o0000o`204ol000000_l00002o`n@00;o000000?o@J40o`000?l000000_n4]0000ol0
003ob;`0olRl0002o`0000CofXT00ol000000ooZEP3o0000ooooo`0Looooo`03o`000?oooooooooo
00_ooooo000^ooooo`03o`000?oooooooooo02[ooooo1_l000001?o]BP3o0000o`000?oRL@03o`00
00;oe9/01Ol00002ofZ^0006o`000?lgWP3o=ih0o`000?l=S`3o00000ol0P1<01?l0003o07<[o`1c
:ol00002o`1W>`05o`000?l0GTGo05i5o`1NAOl000001?l0ET/01_l0003o051>o`1@C_l0003o03I3
o`0000?o02lo00Oo0000o`0]?_l0;Cko02dno`000?l06c?o000000Co01dd00?o0000o`0B;?l00000
1?l05Rl00ol0003o00lYo`0?:@02o`000003o`0F;ol0003o018/00Co018/00Co0000o`0@:_l042[o
010Z1Ol00002o`0M=005o`000?l08cSo02<ho`0S>?l000001?l0;Ch00ol0003o03e7o`0mA`02o`0m
A`04o`000?l0DDgo055=o`1AC@?o00000_l0ET/01?l0003o06@oo`1T?ol0I3l2o`0000;o06la00?o
0000o`204ol0P1<00_l00003o`n@00;o000000Co@J40o`000?l0003oQ;@00ol000001oo8_03o0000
o`000?l0003ofXT0o`000?oWG`001?l0000Mooooo`03o`000?oooooooooo00[ooooo000^ooooo`03
o`000?oooooooooo02Wooooo0ol00003oo0n00co000000GoY[d0o`000?mZ[P3oJZh0o`000002ocNN
00oo000000?o05i5o`000?l0ET/00ol0ET/01?l0003o051>o`1@C_l0D4h2o`0000?o02lo00?o0000
o`0]?_l0;Ch00ol0;Ch00ol0003o01ddo`0M=003o`0M=0;o00001Ol05Rl00ol0003o00lYo`000004
o`0F;`03o`000?l04Rco018/00;o018/1?l00002o`0K<`03o`000?l07CCo01dd00?o01dd00Go0000
o`0S>?l08cSo02<ho`000004o`0]?P03o`000?l0?DOo03e700;o03e700Ko0000o`1ACOl0DDgo055=
o`000?l0GTD3o`0000?o06@o00?o0000o`1d:Ol000000_l00004o`204`;o000000?o3i00o`000?m4
XP000_l000001On1]03o0000o`000?l0003oa/4000?o000000Kof940o`000?l0003o0000onMO0?l0
0002onMO0003o`000?oooooooooo01[ooooo0_l0000;ooooo`00;_ooool00ol0003oooooooooo`0V
ooooo`?o00001?o`?P06o`0000;ofXT00_l000001?o</@3o0000o`000?nV_@09o`0000?o28d000Co
0000o`204ol0P1?o00000_l0MBL01?l0003o06`fo`1/=_l0K3H2o`0000?o05I;00Go0000o`1@C_l0
D4ko051>o`000002o`1:C@03o`000?l0;coo000000Go02dn0_l00004o`0M=003o`000?l08cSo0000
00Go01H_0_l00006o`0F;`06o`000?l04Rco018/o`000?l07CCo00001Ol06c<00ol0003o01ddo`0M
=002o`0M=003o`000?l08cSo02<h00;o02<h00?o0000o`0]?_l0;Ch00_l0;Ch00ol0003o03e7o`0m
A`02o`0mA`05o`000?l0DDgo055=o`1ACOl000000ol0GTD3o`000003o`1T?ol0003o07@Y00;o07@Y
0_l00002o`204`03o`000?lFTP3o000000;o00000_m4XP000ol0003oPK@0oh6d0002o`0000?oa/40
0_l00002omRA00Co000000?oiel0o`000?ooool06oooool00ol0003oooooooooo`09ooooo`00;_oo
ool00ol0003oooooooooo`0Tooooo`;o00000ooc<@02o`000006oo0n0?l0003o0000o`000?oVH@3o
00000ooJR@000ol0003oc;40olba0006o`0000;oFZT000Co0000obbJ0?l/VP3o00000ol8S@001?l0
003o080Co`204ol00002o`1e9`05o`000?l0K3Ko06`fo`1/=_l000000_l0I3l00ol0003o05I;o`00
0003o`1@CP03o`000?l0BTgo04Y=00;o04Y=00?o0000o`0]?_l0;Ch00ol0;Ch01?l0003o02loo`0_
?ol00002o`0M=005o`000?l08cSo02<ho`0S>?l000000ol05Rl00ol0003o01lfo`000006o`0F;`03
o`000?l04Rco000000?o01dd00?o0000o`0K<ol06c<00_l06c<00ol0003o01ddo`0M=002o`0M=003
o`000?l08cSo02<h00;o02<h00?o0000o`0]?_l0;Ch00_l0;Ch00ol0003o03e7o`0mA`02o`0mA`03
o`000?l0DDgo055=00;o055=00Co0000o`1NAOl0GTGo00000_l0K3H3o`0000;o07@Y00Ko0000o`25
2Ol0003o0000o`204ol00002oaJB0004o`000?m4XP3oA:80odBR00;o00000_n1]003o`000003olK1
0?l0003o000000;o000000?oiFH0o`000?oUIP000ol0000Looooo`03o`000?oooooooooo00Sooooo
000^ooooo`03o`000?oooooooooo02?ooooo00?o0000oo<a0?oc<@000ooc<@0@o`0000;oSkP000Co
0000oeZY0?mJZ@3o00000_l/VP001Ol0003o28d0o`R=0?l8S@3o000000;o080C00Co0000o`1e9ol0
MBOo00000ol0K3H00ol0003o06@oo`1T?`02o`1T?`?o000000?o051>o`000?l0BTd01?l0BTd2o`00
00?o02dn00Oo0000o`0_?ol0;coo02loo`000?l07CCo000000Go02<h00?o0000o`0F;ol000000ol0
7cH00ol0003o01H_o`0F;`03o`0F;`;o00001?l07C@00ol0003o01/co`0K<`02o`0K<`04o`000?l0
7CCo01ddo`0M=1Ko00000ol0GTD00ol0003o06`fo`1/=P02o`1/=P;o000000Co07@Yo`000?l0Q@Wo
08D90_l00003oaJB00?o000000?oA:80o`000?l000000_l00002olG200?o000000GoeYH0o`000?l0
003oiFH0o`000002onEV0003o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool002ko
oooo00?o0000ooooooooool08Oooool4o`000003oo<a0?l0003o000000;o00000_o[D002o`0000?o
hGH000Co0000omBL0?oDW03o00000_o6`@001?l0003oSkP0ohnh0?l00002oeZY0004o`000?l/VP3o
;9X0o`0000?o28d000Co0000o`204ol0P1?o00000_l0MBL01Ol0003o06`fo`1/=_l0K3Ko000000Co
06@o00Go0000o`1OA?l0GdCo05m4o`000005o`1:C@06o`000?l0B4_o04Q;o`000?l0;Cko00001Ol0
;cl00ol0003o02<ho`0S>004o`0S>0;o00001Ol07cH00ol0003o01H_o`000002o`000003o`0S>?l0
003o01dd00Co01dd00Co0000o`0K<ol06c?o01/c1?l00002o`0_?`03o`000?l0=T?o03I300;o03I3
00?o0000o`13BOl0@dT00_l0@dT00ol0003o055=o`1AC@02o`1AC@04o`000?l0FdOo05]7o`1KA`?o
00000_l0GTD01_l0003o06`fo`1/=_l0K3Ko0000o`1k7@?o00000ol0Q@T2o`000004oaJB0?l0003o
C:D0odbU00?o000000?oQ;@0o`000?l000001?o5`P02o`000003omJF0?l0003o000000;o000000?o
iFH0o`000?ooool06oooool00ol0003oooooooooo`07ooooo`00;Oooool2o`00023ooooo0ol00002
ooHV00Ko00000_o[D0001?l0003ohGH0on5f0?oQMP02o`0000;oe9`000Co0000olK10?o6`@3o0000
0_n?^00Co`000003o`1/=_l0003o06@o00?o06@o00?o0000o`1OA?l0Gd@00_l0Gd@2o`0000?o04Y=
00Co0000o`18Bol0B4_o04Q;0_l00005o`0_?`;o00001Ol08cP00ol0003o02dno`000005o`0O=P;o
00001Ol08cP00ol0003o01ddo`0M=002o`0M=006o`000?l06c?o0000o`000?l0;Cko00001Ol0;cl0
0ol0003o03I3o`0f@`02o`0f@`03o`000?l0@dWo04=900;o04=900?o0000o`1ACOl0DDd00_l0DDd0
1_l0003o05]7o`1KAol0FdOo0000o`1W>`?o00001?l0K3H01?l0003o07/Mo`1k7Ol0Nad2o`000003
o`252Ol0003o8YL000?o00001?m<Y@02o`000003ohBd0?l0003o000000;oaL8000?o0000omJH0?l0
00000ol000001?oTJP3o0000o`000?l0000Jooooo`?o00002?ooool002gooooo00?o0000omR@0?l0
00007Oooool3o`000003ooHV0?l0003o000000?o00001?o`?`04o`000003on5f0?l0003oe9`000;o
e9`02?l000001On4]03o0000oeBW0?mDY`3o000000?o;9X000Co0000o`f?0?l=S`3o00000ol0Q0/0
0ol0003o07/Mo`1k7@02o`0000?o06@o00?o0000o`1OA?l0Gd@00_l0Gd@01_l0003o05]7o`1KAol0
003o04Y=o`0000?o04Q;00Co0000o`1:COl0BTgo00000ol0;cl01?l0003o03I3o`0f@ol00003o`0S
>005o`000?l0;Cko02dno`0]?_l000000_l07cH2o`000003o`0]?_l0003o02<h00Co02<h00?o0000
o`0M=?l07C@00_l07C@2o`0000Co02dn00?o0000o`0_?ol0;cl00_l0;cl00ol0003o03I3o`0f@`02
o`0f@`03o`000?l0@dWo04=900;o04=900?o0000o`1ACOl0DDd00_l0DDd00ol0003o05]7o`1KA`02
o`1KA`04o`000?l0Ic_o06Lko`1W>`;o00000_l0K3H01_l0003o07/Mo`1k7Ol0Nago0000o`J<00?o
00000olRU`02o`0000;oC:D000?o0000ohbg0?l000001?l000001?o5`P3o0000omJH0?oFV003o`00
00?oi6X000?o0000ooooooooool05?ooool3o`0000;ooooo00?o0000ooooooooool01_ooool002go
oooo0_l000000ooHT03o0000ooooo`0Hooooo`?o00000_oh7@03o`000003ooHV0?l0003ol3l000Co
l3l000Co0000onMP0?oWH03oif002?l00002ok[20005o`000?n4]03oQ;@0ohBd0?l000000_mDY`00
1Ol0003o;9X0obbJ0?l/VP3o000000;o3Hl000Go0000o`242ol0Q0_o08@;o`000003o`1k7@05o`00
0?l0M2Wo0000o`1T?ol000001?l0Gd@00ol0003o05]7o`1KA`02o`1KA`05o`000?l0B4_o04Q;o`18
Bol000001?l0BTd00ol0003o02loo`000004o`0f@`03o`000?l08cSo000000Co02dn00?o0000o`0O
=_l000001?l0;Ch00ol0003o02<ho`0S>002o`0S>003o`000?l07CCo000000;o000000?o02loo`00
0?l0;Ch00ol0;Ch00ol0003o02loo`0_?`03o`0_?`05o`000?l0=T?o03I3o`0f@ol000001?l0@dT0
0ol0003o055=o`1AC@02o`1AC@03o`000?l0FdOo05]700;o05]700Ko0000o`1W>ol0Ic_o06Lko`00
0?l0MBL3o`0000Co07/M00Co0000o`J<0?l6S03o00000olRU`001_l0003oFZT0o`000?l0003oC:D0
o`0000;oS;L00_l000000oo6`@3o0000o`000004omJH00Co000000?oi6X0o`000?ooool04Oooool3
o`0000Gooooo00?o0000ooooooooool01_ooool002gooooo0_l00002omR@00;o00005?ooool3o`00
00;on1d00ol00002ooPM00?o00000oo`?`02o`0000;oif000_l00002omb500;o00000_o?Z@001?l0
003o^/80ok[20?l00003ohBd0004o`000?mDY`3oE:L0o`0000?o;9X000Co0000o`f?0?l=S`3o0000
0ol0Q0/01Ol0003o07/Mo`1k7Ol0Nago000000?o07@Y0_l00003o`1OA003o`000?l0FdOo05]700;o
05]700Go0000o`1JB?l0003o04Q;o`000006o`1:C@03o`000?l0=T?o03I300?o03I30_l00006o`0]
?P03o`000?l0;Cko02dn00?o02dn00?o0000o`0S>?l08cP00_l08cP2o`0000Go02lo00?o0000o`0]
?_l0;Ch00_l0;Ch00ol0003o02loo`0_?`02o`0_?`03o`000?l0=T?o03I300_o000000?o055=o`00
0?l0FdL00_l0FdL00ol0003o06Lko`1W>`02o`1W>`04o`000?l0MBOo07DWo`1e9`;o00000_l0Nad0
1?l0003o1X`0o`J<0?l6S002o`0000;o8YL000?o0000oeZY0?mJZ@000_l00004ohbg00;o000000Wo
a/40o`000?l0003o0000omJH0?l0003oi6`0o`000?oTK0000ol0000=ooooo`Co00002?ooool00ol0
003oooooooooo`06ooooo`000_ooool3o`0000;ooooo0ol00003ooooo`?o00001?ooool00ol0003o
ooooooooo`02ooooo`?o00000oooool3o`0000?ooooo0ol00005ooooo`;o00000_oHT0000ol0003o
iV<0o`000002o`0000cooooo1Ol00002ooTJ00?o00000ooh7@02o`0000?om2l000?o0000oo0o0?l0
00000ooWH0001Ol0003og8D0omb50?oLQ@3o000000?ocjT000Co0000ok[20?nj`P3o00000on4]000
1?l0003oE:L0oeBW0?l00003obbJ0004o`000?l=S`3o3Hl0o`0000?o08@;00Go0000o`1k7Ol0Nago
07/Mo`000003o`1d:@06o`000?l0Kc7o06lao`000?l0GdCo00001?l0FdL01Ol0003o05Y8o`1JB?l0
FTSo000000Ko04Y=0_l00004o`0f@`03o`000?l0@TWo000000Go02dn0_l00005o`0]?P03o`000?l0
8cSo000000;o000000?o03I3o`000?l0;cl01?l0;cl00ol0003o02dno`0]?P02o`0]?P04o`000?l0
;coo02loo`0_?`Co00000_l0D4h00ol0003o05I;o`1FB`02o`1FB`04o`000?l0GTGo05i5o`1NA@Go
000000?o05]7o`000?l0Ic/00_l0Ic/01_l0003o07DWo`1e9ol0MBOo0000o`242`?o00000ol6S000
1_l0003o=9d0o`000?l0003o8YL0o`0000?oFZT00_l00002ohbg0004o`000?o8_03o0000o`0000;o
eYH01?l00003onA/0003o`000?oooooooooo00Sooooo0ol0000=ooooo`03o`000?oooooooooo00Go
oooo0003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`05ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002omR@0004o`000?oVH`3o
iV<0onIS00co00000_oi7@000ol0003onAX0o`000002o`0000;onAX000Co0000ooPM0?l0003o0000
1Ood;`0Qo`000003o`242ol0003o07/M00;o07/M00Go0000o`1d:Ol0M2Wo07@Yo`000004o`1_<@;o
00000ol0FdL00ol0003o05Y8o`1JB002o`1JB003o`000?l0BTgo04Y=00?o04Y=00Co0000o`1@C_l0
D4ko00000_l0=T<01Ol0003o0499o`12BOl0@TWo000000?o02dn00Co0000o`0mAol0?DOo00001?l0
;Ch2o`0000Go03I300?o0000o`0_?ol0;cl00_l0;cl01?l0003o02dno`0]?_l0;Ch5o`0000;o04Y=
00?o0000o`1@C_l0D4h00_l0D4h00ol0003o05I;o`1FB`02o`1FB`05o`000?l0GTGo05i5o`1NAOl0
00000ol0Ic/6o`0000Co07DW00Co0000o`242ol0Q0_o08@;0_l00002o`J<0003o`000?ldW@3o=9d0
00;o00000omJZ@001_l0003oV[X0o`000?l0003oS;L0o`0000;ob;`000?o0000omJF0?oFUP000_oF
UP04o`000003onA/0?l0003ooooo00Gooooo0ol0000@ooooo`03o`000?oooooooooo00Gooooo0005
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000omR@0?oHT03o00000ooVH`001Ol0003okd40onm10?o_@@3o000000ComRT000Co0000ooTM0?oi
7@3onAd00ol00005ooTJ00?o00001?od;`02o`0000?okDX000Go0000onA[0?oTJ`3oi6/0o`000003
omV>0005o`000?o=[`3ocJl0olf_0?l000000ond`@001?l0003oQ;@0ohBd0?l00003oeZY0005o`00
0?lgWP3o=ih0ocNN0?l000000_lKU003o`000003o`1k7Ol0003o07@Y00;o07@Y00?o0000o`1_<Ol0
Kc400_l0Kc401_l0003o06`fo`1/=_l0003o05]7o`0000Co05Y800?o0000o`1KAol000000ol0BTd0
1ol0003o051>o`1@C_l0D4ko0000o`0f@ol000001Ol0@TT00ol0003o02dno`000004o`0mA`06o`00
0?l0;Cko02dno`000?l0@dWo00001_l0=T<01?l0003o02loo`0_?ol0;cl4o`0000;o04Q;00?o0000
o`1:COl0BTd00ol0BTd01Ol0003o051>o`1@C_l0D4ko000000Co05I;00?o0000o`1NAOl0GTD00_l0
GTD01Ol0003o06Lko`1W>ol0Ic_o000000?o07<[0ol00002o`1e9`06o`000?l0Q0_o08@;o`242ol0
003o6i@00_l000000ol6S03o0000ocBM0002ocBM00?o000000CoFZT0o`000?nJ^P3oV[X00_l00003
olRl00?o000000GoeYH0o`000?oTJP3o0000onAZ0003o`000003ooooool0003o000000;o00004ooo
ool00ol0003oooooooooo`05ooooo`0000Co0000oooooooooooo00001?ooool2o`0000Cooooo0_l0
000<ooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000
omR@0002omR@0005o`000?oVH`3oiV<0onIS0?l000000oo_@@000ol0003omRT0ooHY0002ooHY00?o
00000ooi7@000ol0003onAX0o`000002o`0000?omb800_l000000ood;`3o0000one:0003one:0005
o`000?oTJ`3oi6/0onA[0?l000000ooISP001Ol0003ocJl0olf_0?o=[`3o000000?o]<4000Co0000
ohBd0?n4]03o00000omJZ@001Ol0003o=ih0ocNN0?lgWP3o000000;o6i@000Co0000o`F<0?l5S03o
1H`00ol000000ol0M2Wo0000o`1_<@03o`1_<@03o`000?l0K3Ko06`f00;o06`f00?o0000o`1JB?l0
FTP00_l0FTP01ol0003o05]7o`1KAol0FdOo0000o`1:COl000001Ol0D4h00ol0003o0499o`12B@04
o`12B@;o00001Ol0?DL00ol0003o02dno`000003o`13B@03o`000?l0=T?o03I300?o03I300Ko0000
o`0_?ol0003o0000o`1:COl00005o`18B`03o`000?l0BTgo04Y=00;o04Y=00?o0000o`1@C_l0D4h0
0_l0D4h00ol0003o05I;o`1FB`02o`1FB`05o`000?l0GTGo05i5o`1NAOl000001?l0Ic/01_l0003o
07<[o`1c:ol0Lb_o0000o`204`?o00001?l0Q0/00ol0003o6i@0oa^D0002o`0000?o=9d000?o0000
off^0?m][P000ol00003oiZj00;o000000Cob;`0o`000?oHT@3of9400ol000001?oTJP3o0000onAZ
0?oTJP02o`0001Oooooo00?o0000ooooooooool01Oooool00004ooooool0003oooooo`0000Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`Co00001_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool2o`000003omR@0?l0003oiV<000;o
iV<000?o0000onm10?o_@@000_o_@@001_l0003omRT0o`000?l0003omRT0o`0000?onAd01?l00006
ooLR00Co00000_o]BP001Ol0003oi6/0onA[0?oTJ`3o000000?ofHh000Go0000olf_0?o=[`3ocJl0
o`000003okC10004o`000?n4]03oQ;@0o`0000?oFZT000Go0000ocNN0?lgWP3o=ih0o`000002oa^D
0003o`000?l5S03o1H`000;o1H`000?o0000o`252Ol0Q@T00_l00003o`1_<@03o`000?l0K3Ko06`f
00;o06`f00?o0000o`1[=ol000000ol0FTP00ol0003o05]7o`1KA`02o`1KA`03o`000?l0D4ko051>
00Co051>00?o0000o`12BOl0@TT00ol0@TT00ol0003o055=o`000005o`0mA`;o00001?l0@dT00ol0
003o03I3o`0f@`03o`0f@`;o00001?l0BTd00ol0003o04Q;o`18B`02o`18B`03o`000?l0BTgo04Y=
00;o04Y=00?o0000o`1@C_l0D4h00_l0D4h00ol0003o05I;o`1FB`02o`1FB`03o`000?l0GTGo05i5
00;o05i500Go0000o`1W>ol0Ic_o06Lko`000004o`1c:`04o`000?l0P1?o080Co`204`?o00000_l0
Q0/01?l0003o6i@0oa^D0?lKU002o`0000;o=9d000?o0000off^0?m][P000_m][P02o`000003oiZj
0?l0003obk@000?o00001?oHT@03o`0000;oi6X000?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`05ooooo`000_ooool2o`0000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`07o`000?oooooooooooooo
ool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oiV@0o`00
0?l00004onIS0003o`000?o_@@3okd4000?o00000_of:@05o`0000ConAX00_l000001?og8P3o0000
o`000?l00004oo8f00So000000?ofHh0o`000?o=[`000_o=[`001Ol0003o]<40okC10?nd`@3o0000
00;oQ;@000Go0000oeZY0?mJZ@3oFZT0o`000003ocNN0004o`000?lKU03o6i@0o`0000Co1H`000Wo
0000o`252Ol0Q@Wo08D9o`000?l0P1?o0000o`1_<Ol000001?l0K3H01ol0003o06/go`1[=ol0JcOo
0000o`1JB?l000001?l0FdL2o`0000Go051>00?o0000o`1FBol000000ol0@TT01Ol0003o055=o`1A
COl0DDgo000000?o03e700?o0000o`1ACOl000001Ol0@dT00ol0003o03I3o`0f@`02o`000003o`1@
C_l0003o04Y=00?o04Y=00?o0000o`18Bol0B4/00_l0B4/00ol0003o04Y=o`1:C@03o`1:C@03o`00
0?l0D4ko051>00co00001?l0Ic/01Ol0003o07<[o`1c:ol0Lb_o000000?o080C00?o0000o`f?0?l=
S`000ol00003oa^D0003o`000?m<Y@3o000000;o00001?m][P000ol0003o[[l0o`000002o`0000;o
bk@00_l00003omRA0003o`000?oUIP3o000000?o00005oooool00ol0003oooooooooo`05ooooo`00
0oooool01?l0003oooooooooooooool3o`0000?ooooo0ol00008ooooo`Go00000_ooool3o`0000?o
oooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000onIT0?oVI0001ol000000oo_@@3o
0000o`000002o`0000?onA/000?o0000ooTJ0?oi6P001?oi6P03o`0000ColSH00_l00003on]A0004
o`000?oRL@3ohW40on9a01?o000000Go=ih0o`000?lKU03o6i@0o`000004o`F<0005o`000?l0Q@Wo
08D9o`252Ol000000ol0P1<2o`0000?o06`f00?o0000o`1[=ol0JcL00ol0JcL00ol0003o05]7o`1K
A`02o`1KA`04o`000?l0GdCo05m4o`0000?o051>00Oo0000o`1FBol0ET_o05I;o`000?l0@TWo0000
00Co055=00Co0000o`0mAol0?DOo00000ol0DDd00ol0003o04=9o`13B@02o`13B@03o`000?l0=T?o
000000Co051>00?o0000o`1:COl0BTd00_l0BTd00ol0003o04Q;o`18B`02o`18B`03o`000?l0BTgo
04Y=00Go00000_l0Gd@00ol0003o06@oo`1T?`02o`1T?`04o`000?l0K3Ko06`fo`1/=PKo00001?l0
Lb/01Ol0003o080Co`204ol0P1?o000000Co3Hl00_l00002oa^D0004o`000?m<Y@3oC:D0odbU00;o
00000om][P001?l0003o[[l0ojjo0?l00004ol^d00?o000000Cof940o`000?oUIP3o00000_oUIP00
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo000[ooooo`;o00001?ooool00ol0
003oiV@0onIT0008o`0000;omRL000?o0000ooTK0?oi6`000ooi6`001?l0003onAX0ooTJ0?oi6P02
o`0000?ombD00_l000000oob=P3o0000on]A0003on]A0005o`000?oRL@3ohW40on9a0?l000000ooH
T@000ol0003ocJl0olf_0002olf_0004o`000?nj`P3o^/80o`0000CoSkL000?o0000ofZ^0?mZ[P00
1Ol00003o`F<0005o`000?l0Q@Wo08D9o`252Ol000001?l0P1<01Ol0003o07dIo`000?l0K3Ko0000
00Go06/g0_l00003o`1KA`03o`000?l0GdCo05m400;o05m400?o0000o`1@C_l000001Ol0ET/00ol0
003o055=o`1AC@03o`1AC@03o`000?l0?DOo000000Co055=00?o0000o`13BOl0@dT00_l0@dT2o`00
00Go051>00?o0000o`1:COl0BTd00_l0BTd00ol0003o04Q;o`18B`05o`0000;o05]700?o0000o`1O
A?l0Gd@00ol0Gd@00ol0003o06@oo`1T?`02o`1T?`05o`000?l0K3Ko06`fo`1/=_l000000ol0MBL6
o`0000?o080C00?o0000o`f?0?l=S`000_l=S`000ol0003o=ih0o`000002o`0000?oC:D000Ko0000
ohJe0?l0003o0000off^0?l00003ojjo00;o00000_o;]0000ol0003ofXT0omZ90003o`000005onEV
0?l0003oiFH0onEV0?l000005_ooool00ol0003oooooooooo`04ooooo`00;?ooool00ol0003ooooo
ooooo`03ooooo`Co00000oo`?`000ol0003omRL0ooHW0003ooHW0003o`000?oi6`3onA/000?onA/0
00?o0000ooTJ0?l000001_og9@04o`0000;oje4000Go0000on9a0?oRL@3ohW40o`000003omRA0003
o`000?o=[`3ocJl000;ocJl000Co0000ok[20?nj`P3o00001?n?]`001?l0003oJZh0ofZ^0?l00003
odbU0005o`000?ldW@3o0000o`F<0?l000000ol0Q@T00ol0003o080Co`204`02o`204`05o`000?l0
OAWo07dIo`1m6Ol000001Ol0JcL01_l0003o06`fo`1/=_l0003o05]7o`0000Ko05m400?o0000o`1F
Bol0ET/00ol0ET/2o`0000Ko055=00?o0000o`1ACOl0DDd00ol0DDd00ol0003o04=9o`13B@02o`00
0003o`1FBol0003o051>00Co051>00?o0000o`1:COl0BTd00_l0BTd3o`0000;o05Y800?o0000o`1K
Aol0FdL00ol0FdL00ol0003o05m4o`1OA002o`1OA003o`000?l0I3oo06@o00;o06@o00?o0000o`1/
=_l0K3H00_l0K3H01Ol0003o07DWo`1e9ol0MBOo000000?o080C0ol00002o`204`03o`000?l=S`3o
3Hl000;o3Hl000Co0000ocNN0?lgWP3o00001?m<Y@000ol0003oQ[D0ohJe0002o`0000?o[[l000Ko
0000olnY0?l0003o0000ol^d0?l00004omZ900Co000000?oiFH0o`000?ooool05?ooool00ol0003o
ooooooooo`04ooooo`00:oooool01?l0003oooooooooooooool4o`0000?oiV@000Go0000oo0o0?o`
?`3ol3l0o`000005ooHW0004o`000?oi6`3onA/0ooTK00Co00001?og9@02o`0000ColCX01?l00000
0ooRL@3o0000omRA0002omRA0003o`000?o=[`3ocJl000;ocJl000Co0000ok[20?nj`P3o00001?n?
]`001?l0003oJZh0ofZ^0?l00003odbU0004o`000?ldW@3o=9d0ocBM00?o000000?o08D9o`000?l0
P1<00ol0P1<00ol0003o07dIo`1m6@02o`1m6@;o00000ol0JcL00ol0003o06`fo`1/=P02o`1/=P03
o`000?l0GdCo05m400Co05m40_l00004o`1FB`04o`000?l0GTGo05i5o`0000Co055=0_l00006o`1A
C@;o00001?l0ET/00ol0003o051>o`1@CP03o`1@CPCo000000?o05]7o`000?l0FTP00ol0FTP00ol0
003o05]7o`1KA`02o`1KA`03o`000?l0GdCo05m400;o05m400?o0000o`1T?ol0I3l00_l0I3l00ol0
003o06`fo`1/=P02o`1/=P03o`000?l0MBOo07DW00;o07DW00Ko0000o`204ol0P1?o080Co`000?l8
S@03o`0000Co3Hl000Co0000ocNN0?lgWP3o=ih00ol00002odbU0004o`000?n6]@3oQ[D0ohJe00?o
000000Co[[l0o`000?o?Z@3ocjT00_l00004omZ90004o`000?oWG`3o0000onMO00?o00005?ooool0
0ol0003oooooooooo`04ooooo`00:oooool4o`0000Cooooo1Ol00003oo0o0004o`000?of9`3omRL0
ooHW00Go00001?oi6`02o`000003ooLU0?l0003olCX000ColCX000Co0000onYD0?oZE03ojU@02?l0
0002olf_0004o`000?nj`P3o^/80o`0000CoSkL000Co0000ofZ^0?mZ[P3o00000om<Y@001Ol0003o
=9d0ocBM0?ldW@3o000000?o8YL00_l00003o`204`03o`000?l0OAWo07dI00;o07dI00Ko0000o`1l
6ol0O1_o0000o`1[=ol00005o`1/=P03o`000?l0GdCo05m400?o05m400Co0000o`1T?ol0I3oo0000
0_l0ET/00ol0003o05i5o`1NA@02o`1NA@04o`000?l0DDgo055=o`0000;o05]700?o0000o`1ACOl0
DDd00_l0DDd2o`0000Go05I;00?o0000o`1@C_l0D4h00_l0D4h2o`0000Go05]700Go0000o`1JB?l0
FTSo05Y8o`000005o`1KA`03o`000?l0GdCo05m400;o05m400?o0000o`1T?ol0I3l00_l0I3l01Ol0
003o06`fo`1/=_l0K3Ko000000Co07DW00?o0000o`204ol0P1<00_l0P1<01?l0003o28d0o`R=0?l8
S@02o`0000;o3Hl000Go0000ocNN0?lgWP3o=ih0o`000002ofZ^00?o00000on6]@000ol0003oaL80
olG20003o`0000?ocjT00ol00002omZ90003o`000?oWG`3o000000;oiel000?o0000ooooooooool0
4_ooool00ol0003oooooooooo`04ooooo`00:oooool2o`0000Kooooo00Co0000onm10?o_@@3okd40
2?l00004ooTK0003o`000?oi6`3onA/000?onA/00ol00003oo4j00;o00000ooZE0000ol0003ohW40
on9a0002on9a0004o`000?oISP3ofHh0omV>00Oo00000_n?]`001?l0003oJZh0ofZ^0?l00003odbU
0005o`000?ldW@3o=9d0ocBM0?l000001?lRU`001Ol0003o5Y80o`000?l0P1?o000000Co07dI00?o
0000o`1l6ol0O1/00_l0O1/00ol0003o06`fo`1/=P03o`1/=P03o`000?l0Kc7o000000?o05m400Oo
0000o`1T?ol0I3oo06@oo`000?l0ET_o000000Go05i500?o0000o`1ACOl000001?l0FdL01_l0003o
055=o`1ACOl0003o05i5o`0000Go05I;00?o0000o`1@C_l000000_l000000ol0GdCo0000o`1KA`04
o`1KA`03o`000?l0FTSo05Y800;o05Y800?o0000o`1KAol0FdL00_l0FdL00ol0003o05m4o`1OA00;
o`000003o`1/=_l0003o07DW00;o07DW00?o0000o`204ol0P1<00_l0P1<01_l0003o28d0o`R=0?l8
S@3o0000obbJ00Co00000olgWP000ol0003oJZh0ofZ^0002ofZ^00;o00000_n6]@000ol0003oaL80
olG20002olG200;o000000CocjT0o`000?oNO`3ogWl00ol000000ooWG`3o0000onMO0002onMO0003
o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool002gooooo00?o0000ooooooooool0
1?ooool01Ol0003okd40onm10?o_@@3o000000ComRL000?o0000ooTK0?oi6`001?oi6`000ol0003o
nA/0o`000002o`0000?omRH000?o0000oo4j0?l000001?oZE0000ol0003ohW40on9a0002on9a0005
o`000?oISP3ofHh0omV>0?l000000oo?Z@001?l0003oa/40olK10?o6`@07o`000003odbU0?l0003o
=9d000;o=9d000?o0000ob:G0?lRU`000_lRU`001?l0003o5Y80oaJB0?lFTP02o`0000?o07dI00?o
0000o`1l6ol0O1/00ol0O1/2o`0000?o06`f00Oo0000o`1_<Ol0Kc7o06lao`000?l0GdCo000000Go
06@o00?o0000o`1NAOl0GTD01?l0GTD2o`0000Go05]700?o0000o`1ACOl000000ol0GTD00ol0003o
05I;o`1FB`02o`1FB`;o00001Ol0Gd@00ol0003o05]7o`1KA`02o`1KA`03o`000?l0FTSo05Y800;o
05Y800Co0000o`1KAol0FdOo05]71?l00002o`1_<@03o`000?l0M2Wo07@Y00;o07@Y00Co0000o`1k
7Ol0Nago07/M1Ol000000ol0MBOo0000o`204`02o`204`03o`000?l8S@3o28d000;o28d000Co0000
obbJ0?l/VP3o;9X00ol00002ocNN0006o`000?mZ[P3oJZh0ofZ^0?l0003oY[d00ol00004olG20003
o`000?oDV`3o000000;o00001?oNO`04o`000003onMO0?l0003ooooo01;ooooo00?o0000oooooooo
ool01?ooool002kooooo00?o0000ooooooooool01?ooool01Ol0003okd40onm10?o_@@3o000000Co
mRL000?o0000ooTK0?oi6`000ooi6`02o`0000KomRH01?l00002onYD0003o`000?oRL@3ohW4000;o
hW4000?o0000omV>0?oISP000_l00003olnY0005o`000?o6`@3oa/40olK10?l000001?nV_@000ol0
003oQ[D0ohJe0003o`000003ocBM0?l0003o8YL000?o8YL000?o0000oaJB0?lFTP000_lFTP001Ol0
003o3i00o`000?l0OAWo000000Go07`K00Ko0000o`1m6Ol0OAWo0000o`1/=_l00005o`1_<@03o`00
0?l0I3oo06@o00Co06@o00?o0000o`1NAOl0GTD00ol0GTD00ol0003o06Lko`000005o`1KA`;o0000
1Ol0GTD01_l0003o05I;o`1FBol0003o06@oo`0000Go05m400?o0000o`1KAol0FdL00ol0FdL00ol0
003o05Y8o`1JB005o`0000;o06`f00?o0000o`1_<Ol0Kc400_l0Kc400ol0003o07@Yo`1d:@02o`1d
:@05o`000?l0Nago07/Mo`1k7Ol000000ol0Q0/5o`000003o`204ol0003o28d000;o28d000Go0000
obbJ0?l/VP3o;9X0o`000002oeZY00?o00001?mZ[P001?l0003oY[d0ojJm0?l00005olG20004o`00
0?oDV`3oe9/0o`0000CogWl000?o0000onYF0?oZEP001?l0000Booooo`03o`000?oooooooooo00Co
oooo000_ooooo`03o`000?oooooooooo00?ooooo00?o0000onm10?o_@@000_o_@@000ol0003omRL0
ooHW0002ooHW0003o`000?oi6`3o000000;o00000_oi6`001?l0003omRH0ooHV0?of9P02o`0000Co
lCX01?l00002on9a0004o`000?oISP3ofHh0o`0000CocjT000Go0000olK10?o6`@3oa/40o`000004
ojJm0005o`000?n6]@3oQ[D0ohJe0?l000000_m][P02o`0000?o8YL000?o0000oaJB0?lFTP000_lF
TP001Ol0003o3i00o`n@0?l?T03o000000Go07`K00?o0000o`1m6Ol0OAT00_l0OAT00ol0003o06la
o`1_<@03o`1_<@;o00001Ol0I3l00ol0003o06`fo`000003o`1NA@05o`000?l0Ic_o06Lko`1W>ol0
00000ol0FdL00ol0003o06Lko`000005o`1NA@03o`000?l0ET_o000000?o06@o00?o0000o`1OA?l0
Gd@00_l0Gd@00ol0003o05]7o`1KA`02o`1KA`Co00000_l0JcL00ol0003o06`fo`1/=P02o`1/=P03
o`000?l0Kc7o06la00;o06la00?o0000o`1d:Ol0M2T00_l0M2T00ol0003o07/Mo`1k7@02o`1k7@05
o`000?l0Q0_o08@;o`242ol000000ol=S`03o`0000;o28d000?o0000obbJ0?l/VP000_l/VP000ol0
003oFZT0oeZY0002oeZY00;o00000_mZ[P001?l0003oY[d0ojJm0?nV_@03o`0000;oaL8000Co0000
omBK0?oDV`3oe9/01?l000001ooNO`3o0000onYF0?oZEP3o0000onYF0?l000004oooool00ol0003o
ooooooooo`03ooooo`00<?ooool2o`0000Cooooo00Go0000onm10?o_@@3okd40o`000003ooHW00?o
00001_oi6`000ol0003omRH0o`000004oo4j00;o00001?o[DP07o`0000;ocjT000Go0000olK10?o6
`@3oa/40o`000004ojJm0005o`000?n6]@3oQ[D0ohJe0?l000000om][P001Ol0003oFJT0o`000?lR
U`3o000000Co5Y8000?o0000o`n@0?l?T0000_l?T002o`0000?o07`K00?o0000o`1m6Ol0OAT00ol0
OAT00ol0003o06lao`1_<@02o`1_<@04o`000?l0M2Wo07@Yo`0000?o06@o00Oo0000o`1/=_l0K3Ko
06`fo`000?l0GTGo000000Co06Lk00Co0000o`1KAol0FdOo00000ol0Ic/00ol0003o05i5o`1NA@02
o`1NA@;o00001?l0I3l00ol0003o05m4o`1OA003o`1OA0Co000000?o06`fo`000?l0JcL01?l0JcL0
0ol0003o06`fo`1/=P02o`1/=P03o`000?l0Kc7o06la00;o06la00?o0000o`1d:Ol0M2T00_l0M2T0
1Ol0003o07/Mo`1k7Ol0Nago000000Co08@;00Ko0000o`f?0?l=S`3o3Hl0o`000?l/VP04o`0000?o
;9X000?o0000oeZY0?mJZ@000_mJZ@000ol0003oSkL0o`000002o`0000?oY[d000?o0000olba0?o<
/@000ol00003omBK0004o`000?oRL@3ohW40on9a00Ko000000?ojUH0o`000?ooool04Oooool00ol0
003oooooooooo`03ooooo`00<_ooool00ol0003oooooooooo`02ooooo`Oo00000ooi70000ol0003o
nA/0ooTK0003ooTK00Co00000_oa>P000ol0003oje80on]B0003on]B0005o`000?oTK03oi6`0onA/
0?l000000ooLQ@04o`000003olK10?l0003oY[d000?oY[d000Go0000ohJe0?n6]@3oQ[D0o`000003
off^0004o`000?mIZ@3oFJT0oeVY00;o00000olFTP000ol0003o3i00o`n@0002o`n@0006o`000?l<
S`3o38l0o`000?l0O1_o00001Ol0OAT00ol0003o080Co`000002o`1_<@03o`000?l0M2Wo07@Y00;o
07@Y00?o0000o`1T?ol000001Ol0K3H00ol0003o06Lko`1W>`03o`1W>`03o`000?l0FdOo000000Co
06Lk00Oo0000o`1NAOl0GTGo05i5o`000?l0K3Ko000000Go06@o00Co0000o`1OA?l0GdCo05m40_l0
0005o`1/=P03o`000?l0JcOo06/g00;o06/g00?o0000o`1/=_l0K3H00_l0K3H00ol0003o06lao`1_
<@02o`1_<@03o`000?l0M2Wo07@Y00;o07@Y00?o0000o`1k7Ol0Nad00_l0Nad01Ol0003o08@;o`24
2ol0Q0_o000000Co3Hl000Co0000obbJ0?l/VP3o;9X00ol00002obbJ0003o`000?mJZ@3oFZT000;o
FZT000Co0000ohng0?n?]`3oSkL00ol000000onV_@3o0000olba0003olba00?o000000?oe9/0o`00
0?oRL@000ooRL@000ol0003okDX0one:0004o`00017ooooo00?o0000ooooooooool00oooool003?o
oooo00Go0000ooooooooooooooooo`000004ooDZ0003o`000?oi703onA`000?onA`000?o0000ooTK
0?l000000_l00004ooLU00?o00001?o[DP001Ol0003oi6`0onA/0?oTK03o000000Cog8D000Co0000
omBL0?oDW03oe9`00ol00002ojJm0005o`000?n6]@3oQ[D0ohJe0?l000000om][P000ol0003oFJT0
oeVY0002oeVY0005o`000?m<Y@3o0000oaJB0?l000001?l?T0000ol0003o38l0o`b?0002o`b?0003
o`000?l0OAWo07dI00?o07dI00Ko0000o`204ol0P1?o0000o`1_<Ol00006o`1d:@03o`000?l0K3Ko
06`f00?o06`f0_l00006o`1W>`03o`000?l0Ic_o06Lk00?o06Lk00Co0000o`1NAOl0GTGo00000_l0
K3H00ol0003o06@oo`1T?`03o`1T?`06o`000?l0GdCo05m4o`000?l0Kc7o00001Ol0K3H00ol0003o
06/go`1[=`02o`1[=`03o`000?l0K3Ko06`f00;o06`f00?o0000o`1_<Ol0Kc400_l0Kc400ol0003o
07@Yo`1d:@02o`1d:@03o`000?l0Nago07/M00;o07/M00?o0000o`242ol0Q0/00_l0Q0/01Ol0003o
3Hl0o`f?0?l=S`3o000000?o;9X000?o0000oeBW0?mDY`000ol00004oeZY0005o`000?n?]`3oSkL0
ohng0?l000000_o6`@03o`0000?oc;4000?o0000omZ90?oJR@000ol00004on9a0006o`000?o]BP3o
kDX0o`000?o]BP3o00004Oooool00ol0003oooooooooo`03ooooo`00=?ooool01Ol0003ooooooooo
oooooooo000000ComBX000?o0000ooTL0?oi70000_oi7003o`0000CombD00_l00003oo8f00;o0000
00?oje80o`000?oTK0000_oTK0000ol0003og8D0omb50002omb50005o`000?oDW03oe9`0omBL0?l0
00000oo</@04o`000003ohJe0?l0003oKJh000;oKJh000?o0000oeVY0?mIZ@000_mIZ@001?l0003o
C:D0odbU0?m<Y@02o`0000?o3i0000?o0000o`b?0?l<S`000ol<S`02o`0000?o07dI00?o0000o`20
4ol0P1<00_l0P1<00ol0003o07@Yo`1d:@04o`1d:@;o00001?l0K3H01?l0003o07DWo`1e9ol00005
o`1W>`03o`000?l0Ic_o06Lk00Co06Lk0_l00004o`1/=P03o`000?l0I3oo06@o00;o06@o00?o0000
o`1OA?l000000ol0Kc400ol0003o06`fo`1/=P03o`1/=P03o`000?l0JcOo06/g00;o06/g00?o0000
o`1/=_l0K3H00_l0K3H00ol0003o06lao`1_<@0Ao`0000Co3Hl000Go0000obbJ0?l/VP3o;9X0o`00
0004oeBW00Go00001?n?]`000ol0003oa/40olK10002olK100;o00000_o</@000ol0003ofXT0omZ9
0002omZ900Go00000oo]BP000ol0003okDX0o`00000@ooooo`03o`000?oooooooooo00?ooooo000e
ooooo`;o00000_ooool00ol0003omBX0ooDZ0002ooDZ0004o`000?oi703o0000o`0000?onA/00_l0
00000oog9@3o0000oo8f0005oo8f00Co000000?oi6`0o`000?oLQ@000ooLQ@001Ol0003oe9`0omBL
0?oDW03o000000Coc;4000Co0000olG30?o5``3oaL<00ol000000om][P3o0000oeVY0003oeVY0003
o`000?m<Y@3oC:D000;oC:D000Go0000odBR0?l0003o3i00o`000005o`b?0006o`000?l?T03o3i00
o`000?l0OAWo00001Ol0P1<00ol0003o07@Yo`1d:@03o`1d:@04o`000?l0Nago07/Mo`0000;o06`f
00Go0000o`1e9ol0MBOo07DWo`000004o`1W>`03o`000?l0Lb_o000000Go06Lk00?o0000o`1/=_l0
K3H00ol0K3H00ol0003o06@oo`1T?`02o`1T?`;o00001?l0Kc400ol0003o06`fo`1/=P03o`1/=P04
o`000?l0JcOo06/go`1[=`Wo00000_l0P1<00ol0003o08D9o`252@02o`252@03o`000?l6S03o1X`0
00;o1X`000Co0000oa^D0?lKU03o6i@01_l00003obbJ0003o`000?mDY`3oE:L000;oE:L000Co0000
ohBd0?n4]03oQ;@01?l00002ohng0006o`000?o6`@3oa/40olK10?l0003oe9`00ol00004omZ90004
o`000?oVHP3oiV80onIR00Go000000?okDX0o`000?ooool03oooool00ol0003oooooooooo`03oooo
o`00=oooool00ol0003oooooooooo`06o`0000KonA/00ol00004oo8f00;o00000oo]BP04o`0000;o
g8D000Go0000omBL0?oDW03oe9`0o`000004olba0005o`000?o5``3oaL<0olG30?l000000on^_`02
o`0000?oFJT000?o0000odbU0?m<Y@000_m<Y@001Ol0003oA:80odBR0?m4XP3o000000Go38l000?o
0000o`n@0?l?T0000_l?T0000ol0003o080Co`204`03o`204`03o`000?l0Q@Wo000000?o07@Y00Oo
0000o`1k7Ol0Nago07/Mo`000?l0K3Ko000000Go07DW00Co0000o`1W>ol0Ic_o00000_l0Lb/00ol0
003o06Lko`1W>`02o`1W>`;o00001Ol0K3H00ol0003o06@oo`1T?`02o`000003o`1d:Ol0003o06la
00Co06la00?o0000o`1/=_l0K3H00_l0K3H01_l0003o06/go`000?l0003o07`Ko`0000Co07dI00?o
0000o`204ol0P1<00_l0P1<00ol0003o08D9o`252@02o`252@03o`000?l6S03o1X`000;o1X`000?o
0000oa^D0?lKU0000_lKU0001?l0003o=ih0ocNN0?lgWP03o`0000;o;9X000?o0000oeBW0?mDY`00
0_mDY`001Ol0003oQ;@0ohBd0?n4]03o000000;o^/800ol00004olK10004o`000?oDW03oe9`0omBL
00?o00000_oJR@001Ol0003oiV80onIR0?oVHP3o000000?ol3h00ol0000?ooooo`03o`000?oooooo
oooo00?ooooo000hooooo`04o`000?ooooooooooo`0000Con1d000Co0000ooTK0?oi6`3onA/00_l0
0003ooLR00;o000000?olSH0o`000?o]BP000oo]BP000ol0003oif00onMP0002onMP00Co000000?o
e9`0o`000?o</@000oo</@001Ol0003oaL<0olG30?o5``3o000000Co[[l000Go0000oiZj0?l0003o
FJT0o`000004odbU0003o`000?m4XP3oA:8000;oA:800_l00003o`b?0003o`000?l?T03o3i0000?o
3i0000?o0000o`204ol0P1<00_l0P1<01ol0003o08D9o`252Ol0Q@Wo0000o`1d:Ol000001Ol0Nad0
0ol0003o07DWo`1e9`04o`1e9`03o`000?l0Ic_o000000Co07<[00Co0000o`1W>ol0Ic_o00000_l0
MBL00ol0003o06`fo`1/=P03o`1/=P;o00001?l0M2T00ol0003o06lao`1_<@02o`1_<@03o`000?l0
K3Ko06`f00;o06`f0_l00004o`1l6`03o`000?l0OAWo07dI00;o07dI00?o0000o`204ol0P1<00_l0
P1<00ol0003o08D9o`252@02o`252@03o`000?l6S03o1X`000;o1X`000Go0000oa^D0?lKU03o6i@0
o`000004ocNN0003o`000?mJZ@3o000000;o00001?mDY`000ol0003oQ;@0ohBd0002ohBd0003o`00
0?nj`P3o^/8000;o^/800_l00002olK10005o`000?oDW03oe9`0omBL0?l000000_oQMP03o`0000Co
iV8000Co0000oo0n0?o`?P3ol3h00_l0000@ooooo`03o`000?oooooooooo00;ooooo000iooooo`04
o`000?ooooooooooo`0000Con1d000?o0000ooTK0?l000001_og8P03o`0000?okDX000?o0000onMP
0?oWH0000_oWH0000ol0003ohGH0on5f0002on5f00?o00000_o</@001Ol0003oaL<0olG30?o5``3o
000000Co[[l000Co0000oiZj0?nJ^P3oV[X00_l00004odbU0005o`000?m4XP3oA:80odBR0?l00000
0_m1X@000ol0003o38l0o`000005o`n@0003o`000?lFTP3o000000?o080C00?o0000o`252Ol0Q@T0
0_l0Q@T00ol0003o07/Mo`1k7@04o`1k7@03o`000?l0MBOo07DW00Co07DW0_l00005o`1c:`03o`00
0?l0Ic_o000000?o07DW00?o0000o`1/=_l0K3H00_l0K3H2o`0000Go07@Y00?o0000o`1_<Ol0Kc40
0_l0Kc400ol0003o06`fo`000002o`000003o`1m6Ol0003o07`K00?o07`K00?o0000o`1m6Ol0OAT0
0_l0OAT00ol0003o080Co`204`02o`204`03o`000?l0Q@Wo08D900;o08D900?o0000o`J<0?l6S000
0_l6S0000ol0003o6i@0oa^D0002oa^D0005o`000?lgWP3o=ih0ocNN0?l000001?mJZ@05o`0000Co
Q;@000?o0000ok[20?nj`P000_nj`P000ol0003ocjT0o`000002o`0000Coe9`000?o0000on5f0?oQ
MP000_oQMP04o`000007onIR0?l0003ol3h0oo0n0?l0003ol3h0o`00000?ooooo`03o`000?oooooo
oooo00;ooooo000jooooo`;o000000Coooooo`000?oh7@3on1d01?l00004ooLR00;o00000ood;`00
0ol0003okDX0o`000004onMP0003o`000?oQMP3ohGH000;ohGH000Co0000omZ:0?oJRP3ofXX01?l0
00000oo5``3o0000ojjo0003ojjo0003o`000?nJ^P3oV[X000;oV[X000Ko0000ohbg0?l0003o0000
odbU0?l00003odBR0003o`000?m1X@3o@J4000;o@J4000?o0000o`n@0?l?T0000ol?T0001ol0003o
5Y80oaJB0?lFTP3o0000o`204ol000001?l0Q@T2o`0000Go07/M00?o0000o`242ol000001?l0MBL0
0ol0003o080Co`000005o`1c:`;o00001Ol0MBL01_l0003o06`fo`1/=_l0003o07/Mo`0000Go07@Y
00?o0000o`1_<Ol0Kc400_l0Kc42o`0000Co07dI00?o0000o`1l6ol0O1/00ol0O1/01Ol0003o07dI
o`1m6Ol0OAWo000000Co080C00?o0000o`252Ol0Q@T00_l0Q@T00ol0003o1X`0o`J<0002o`J<0003
o`000?lKU03o6i@000;o6i@000?o0000ocNN0?lgWP000_lgWP001Ol0003oFZT0oeZY0?mJZ@3o0000
00?oQ;@00ol00002ohBd0003o`000?nj`P3o^/8000?o^/8000Co0000olnY0?o?Z@3ocjT00ol00002
omBL0005o`000?oQMP3ohGH0on5f0?l000000oo[D007o`0000oooooo00?o0000ooooooooool00_oo
ool003cooooo00Co0000ooooool0003o00001?oi6P02o`000003ooLR0?l0003om2l000Com2l01?l0
0002onMP0003o`000?oQMP3ohGH000;ohGH000?o0000omZ:0?oJRP000_oJRP001?l0003oe9/0omBK
0?oDV`02o`0000?o[[l000?o0000oiZj0?nJ^P000_nJ^P000ol0003oS;L0ohbg0002ohbg00;o0000
0om4XP000ol0003o@J40od6Q0002od6Q00;o00000ol?T0000ol0003o5Y80oaJB0003oaJB0003o`00
0?l0Q@Wo08D900;o08D900Co0000o`F<0?l5S03o00000ol0Nad01Ol0003o08@;o`242ol0Q0_o0000
00;o07DW00Go0000o`204ol0P1?o080Co`000003o`1c:`03o`000?l0P1?o000000Go07DW00?o0000
o`1/=_l000000ol0Nad00ol0003o07@Yo`1d:@03o`1d:@Co000000?o080Co`000?l0OAT01?l0OAT0
0ol0003o07`Ko`1l6`02o`1l6`03o`000?l0OAWo07dI00;o07dI00?o0000o`204ol0P1<00_l0P1<0
0ol0003o08D9o`252@02o`252@03o`000?l6S03o1X`000;o1X`000Go0000oa^D0?lKU03o6i@0o`00
0004ocNN0003o`000?mJZ@3oFZT000;oFZT000Ko0000ohBd0?n4]03oQ;@0o`000?nd`@04o`0000Co
^/8000Go0000olnY0?o?Z@3ocjT0o`000002omb500?o00001?oQMP000ol0003oje00on]@0002on]@
0004o`000?oc<@3olc40oo<a00;o00003_ooool00ol0003oooooooooo`02ooooo`00?Oooool00ol0
003oooooo`000005ooTJ00?o00000ood;`02o`0000Col3l00ol00003on5f0003o`000?oJRP3ofXX0
00;ofXX000?o0000omBK0?oDV`000_oDV`001Ol0003ocjT0o`000?n^_`3o000000CoV[X000?o0000
ohbg0?n<]`000on<]`001Ol0003oPk@0o`000?m4XP3o000000Co@J4000Ko0000odBR0?m4XP3o0000
o`n@0?l00005oaJB00;o00000ol0Q@T00ol0003o1H`0o`F<0002o`F<0003o`000?l0Nago000000Co
08@;00?o0000o`1e9ol000001?l0P1<01?l0003o07<[o`1c:ol00003o`204`03o`000?l0MBOo07DW
00;o07DW0_l00004o`1k7@03o`000?l0M2Wo07@Y00;o07@Y0_l00004o`204`03o`000?l0OAWo07dI
00?o07dI00?o0000o`1l6ol0O1/00_l0O1/00ol0003o07dIo`1m6@0Eo`000003oa^D0?l0003o=ih0
00;o=ih000?o0000oeZY0?mJZ@000_mJZ@000ol0003oQ;@0ohBd0002ohBd0004o`000?nd`@3o]<40
okC100?o00000_nj`P000ol0003ocjT0olnY0002olnY0003o`000?oLQ@3og8D000;og8D01Ol00005
on]@0004o`000?oc<@3olc40oo<a00;o00003Oooool00ol0003oooooooooo`02ooooo`00?_ooool0
1?l0003oooooo`000?oi6P03o`0000?on1h000?o0000oo@_0?l000001Oo`?`001ol0003oje40on]A
0?o[D@3o0000on5f0?l000001?oJRP000ol0003oe9/0omBK0002omBK0004o`000?o?Z@3ocjT0olnY
00;o00001?nJ^P000ol0003oS;L0ohbg0002ohbg0005o`000?n3]03oPk@0oh>d0?l000001?m1X@00
0ol0003oA:80odBR0002odBR0003o`000?lFTP3o5Y8000?o5Y8000Ko0000ob:G0?lRU`3o0000o`25
2Ol00006o`F<0003o`000?l0Q0_o08@;00Co08@;00?o0000o`204ol0P1<00ol0P1<00ol0003o07<[
o`000004o`204`07o`000?l0MBOo07DWo`1e9ol0003o08@;o`000005o`1k7@06o`000?l0M2Wo07@Y
o`000?l0Q@Wo00001Ol0P1<00ol0003o07dIo`1m6@02o`1m6@03o`000?l0O1_o07`K00;o07`K0ol0
0002o`n@0003o`000?lFTP3o5Y8000;o5Y8000?o0000ob:G0?lRU`000_lRU`000ol0003o=9d0ocBM
0002ocBM0004o`000?m<Y@3oC:D0odbU00Go000000?o=ih0o`000?mJZ@000_mJZ@000ol0003oQ;@0
ohBd0002ohBd0005o`000?nd`@3o]<40okC10?l000000_o=/004o`0000?ocjT000?o0000omb50?oL
Q@000_oLQ@001?l0003oif00onMP0?oWH005o`000003on]@0?l0003olc4000;olc4000?o0000oo<a
0?l000003?ooool00ol0003oooooooooo`02ooooo`00?oooool4o`0000Gon1h00ol00004oo0o0003
o`000?o[D@3oje4000;oje401?l00002omZ:0003o`000?oDV`3oe9/000;oe9/000Go0000olnY0?o?
Z@3ocjT0o`000002ol^d00;o000000?oV[X0o`000?n<]`000on<]`000ol0003oPk@0oh>d0002oh>d
0005o`000?m1X@3o@J40od6Q0?l000001Om4XP02o`0000?o5Y8000?o0000ob:G0?lRU`000_lRU`00
0ol0003o1H`0o`F<0005o`F<0003o`000?l0Q0_o08@;00?o08@;0_l00005o`204`;o00001Ol0P1<0
1?l0003o07DWo`1e9ol00003o`242`03o`000?l0Nago07/M00;o07/M00?o0000o`1d:Ol000000ol0
Q@T00ol0003o080Co`204`02o`204`03o`000?l0OAWo07dI00?o07dI1?l000000ol=S`3o0000o`n@
0003o`n@0003o`000?lFTP3o5Y8000;o5Y8000?o0000ob:G0?lRU`000_lRU`000ol0003o=9d0ocBM
0002ocBM0005o`000?m<Y@3oC:D0odbU0?l000000omZ[P05o`000003oeZY0?l0003oQ;@000?oQ;@0
00Go0000okC10?nd`@3o]<40o`000004olf`00Go00001OoLQ@001Ol0003oif00onMP0?oWH03o0000
00?ol3l02Ol0000;ooooo`03o`000?oooooooooo00;ooooo0011ooooo`03o`000?oooooo000000?o
n1h000Co0000ooHV0?of9P3omRH00_l000000oo`?`3o0000on]A0003on]A0003o`000?oVHP3oiV80
00;oiV800ol00003omBK0005o`000?o?Z@3ocjT0olnY0?l000001Oo;]002o`0000?oS;L000?o0000
oh>d0?n3]0000_n3]0001Ol0003oPK@0o`000?m1X@3o000000GoA:8000Ko0000odbU0?m<Y@3o0000
oaJB0?l00005ob:G0003o`000?l5S03o1H`000Co1H`000?o0000oa^D0?l000000ol0Q0/01?l0003o
3Hl0o`f?0?l00003o`204`03o`000?l8S@3o000000Ko080C0_l00004o`242`03o`000?l0Nago07/M
00;o07/M0_l00004o`252@03o`000?l0P1?o080C00;o080C00?o0000o`1m6Ol0OAT00_l0OAT2o`00
00Co3Hl000?o0000o`n@0?l?T0000_l?T0000ol0003o5Y80oaJB0002oaJB0003o`000?lRU`3o8YL0
00;o8YL000?o0000ocBM0?ldW@000_ldW@000ol0003oC:D0odbU0002odbU0005o`000?mZ[P3oJZh0
ofZ^0?l000000on?]`05o`000003ohBd0?l0003o]<4000;o]<4000?o0000olf`0?o=/0000_o=/000
1?l0003ofHh0omV>0?oISP04o`0000;og8D000?o0000onMP0?oWH0000_oWH0000ol0003ol3l0oo0o
0002oo0o0003o`000?of9P3omRH000;omRH00_l0000<ooooo`03o`000?oooooooooo007ooooo0012
ooooo`05o`000?oooooo0000ooPN0?l000001Oof9P03o`0000?oje4000?o0000onIR0?oVHP000ooV
HP001_l0003ohW40on9a0?l0003oe9/0o`0000?ocjT000?o0000ol^d0?o;]0000oo;]0001_l0003o
b;`0olRl0?l0003oS;L0o`0000CoPk@000Go0000oh6d0?n1]03oPK@0o`000005odBR0003o`000?m<
Y@3oC:D000;oC:D000?o0000ob:G0?lRU`000olRU`000ol0003o=9d0o`000004o`F<0004o`000?lK
U03o6i@0o`0000;o08@;00Go0000o`f?0?l=S`3o3Hl0o`000002o`204`05o`000?l8S@3o28d0o`R=
0?l000001Ol0P1<00ol0003o08@;o`242`03o`242`03o`000?l0Nago07/M00;o000000?o1X`0o`00
0?l0Q@T01?l0Q@T00ol0003o080Co`204`02o`204`Co000000?o3i00o`000?l=S`001?l=S`000ol0
003o3i00o`n@0002o`n@0003o`000?lFTP3o5Y8000;o5Y8000?o0000ob:G0?lRU`000_lRU`000ol0
003o=9d0ocBM0002ocBM0005o`000?m<Y@3oC:D0odbU0?l000001?mZ[P001Ol0003oSkL0ohng0?n?
]`3o000000?o^/801?l00002okC10003o`000?o=/03ocK0000;ocK0000Go0000omV>0?oISP3ofHh0
o`000002onA/00?o00001OoWH0000ol0003ol3l0oo0o0002oo0o0003o`000?of9P3omRH000;omRH0
0_l0000;ooooo`03o`000?oooooooooo007ooooo0013ooooo`04o`000?oooooo0000o`0000?omRH0
0_l00003oo<b0003o`000?o[D@3o000000GoiV8000Co0000on9a0?oRL@3ohW401?l000000oo?Z@3o
0000ol^d0004ol^d0003o`000?o8_03ob;`000;ob;`00_l00003oh>d0003o`000?n1]03oPK@000;o
PK@00_l00003odBR0003o`000?m<Y@3oC:D000?oC:D000?o0000ob:G0?lRU`000_lRU`001Ol0003o
=9d0ocBM0?ldW@3o000000;o1H`000Oo0000oa^D0?lKU03o6i@0o`000?l0Q0_o000000Co3Hl000?o
0000o`204ol000001?l8S@000ol0003o080Co`204`02o`204`;o00001_l0Q0/2o`0000Co1X`000?o
0000o`252Ol0Q@T00_l0Q@T01?l0003o080Co`204ol0P1<2o`0000Go3i0000?o0000o`f?0?l=S`00
0_l=S`000ol0003o3i00o`n@0002o`n@0003o`000?lFTP3o5Y8000;o5Y8000?o0000ob:G0?lRU`00
0_lRU`000ol0003o=9d0ocBM0002ocBM0003o`000?m<Y@3oC:D000;oC:D000Go0000ofZ^0?mZ[P3o
JZh0o`000004ohng0003o`000?nj`P3o^/8000;o^/8000?o0000olf`0?l000000_l00004olf`0003
o`000?oISP3ofHh000;ofHh000?o0000onA/0?oTK0000_oTK004o`000003onMP0?l0003ol3l000?o
l3l000Co0000ooHV0?of9P3omRH01?l0000:ooooo`03o`000?oooooooooo007ooooo0014ooooo`06
o`000?ooooooooooo`000?of9P3o00001Ooc<P03o`0000CoiV8000Go0000on9a0?oRL@3ohW40o`00
0004omeo00;o00001?o;]0000ol0003ob;`0olRl0002olRl0006o`000?o6`@3oa/40o`000?n3]03o
00001?n1]0001_l0003oPk@0oh>d0?l0003oA:80o`0000GoC:D000?o0000oeVY0?l000000olRU`00
1ol0003o=9d0ocBM0?ldW@3o0000o`F<0?l000001OlKU0000ol0003o3Hl0o`f?0004o`f?0003o`00
0?l8S@3o28d000Co28d000Co0000o`204ol0P1?o00000_l=S`000ol0003o08@;o`242`03o`242`03
o`000?l6S03o1X`000?o1X`000?o0000o`252Ol0Q@T00_l0Q@T01_l0003o080Co`000?l0003o5Y80
o`0000Go3i0000?o0000o`f?0?l=S`000_l=S`000ol0003o3i00o`n@0002o`n@0003o`000?lFTP3o
5Y8000;o5Y8000?o0000ob:G0?lRU`000_lRU`000ol0003o=9d0ocBM0002ocBM0003o`000?m<Y@3o
C:D000;oC:D000?o0000ofZ^0?mZ[P000_mZ[P001Ol0003oSkL0ohng0?n?]`3o000000Go^/8000Co
0000olf`0?o=/03ocK001Ol00005omV>0005o`000?oTK03oi6`0onA/0?l000000oo]BP0:o`0000;o
n1h00_l0000:ooooo`03o`000?oooooooooo007ooooo0015ooooo`;o000000?oooooo`000?l00000
0ooc<P02o`0000?ol3h00_l000000ooVHP3o0000on9a0002on9a0003o`000?oMO`3ogGl000;ogGl0
00?o0000omZ:0?oJRP000_l000000oo;]03o0000olRl0003olRl0003o`000?o6`@3oa/4000;oa/40
0_l00003oh6d0003o`000?n3]03oPk@000;oPk@000?o0000odbU0?m<Y@000om<Y@001ol0003oFJT0
oeVY0?mIZ@3o0000ob:G0?l000001OldW@000ol0003o6i@0oa^D0004oa^D0003o`000?l=S`3o3Hl0
00Co3Hl000?o0000o`R=0?l8S@001?l8S@000ol0003o080Co`000003o`f?0003o`000?l0Q0_o08@;
00;o08@;0_l00005o`J<0003o`000?l0Q@Wo08D900;o08D90_l00004oaJB0003o`000?l?T03o3i00
00?o3i0000?o0000o`f?0?l=S`000_l=S`000ol0003o3i00o`n@000Ko`0000CoSkL000?o0000ok[2
0?nj`P000_nj`P001Ol0003ocK00olf`0?o=/03o000000?of9401Ol000000ooISP3o0000onA/0003
onA/0003o`000?o]BP3okDX000;okDX000?o0000oo@_0?od;`000_od;`000ol0003on1h0ooPN0003
ooPN00;o00002Oooool00ol0003oooooooooo`01ooooo`00Aoooool01_l0003oooooooooool0003o
lc80o`0000Kol3h01?l000000ooRL@3o0000omeo0003omeo0003o`000?oJRP3ofXX000?ofXX00_l0
0003olRl0003o`000?o6`@3oa/4000;oa/4000Ko0000olG30?o5``3o0000oh6d0?l00005oh>d00;o
00000om<Y@000ol0003oFJT0oeVY0003oeVY0003o`000?ldW@3o=9d000?o=9d00_l00005oa^D0003
o`000?lgWP3o000000Co3Hl000?o0000obbJ0?l000001Ol8S@02o`0000Go3Hl000Co0000o`242ol0
Q0_o00000_lKU0000ol0003o1X`0o`J<0003o`J<00Co000000?o8YL0o`000?lFTP000olFTP000ol0
003o3i00o`n@0003o`n@0004o`000?l=S`3o3Hl0o`f?00Co00000_m4XP000ol0003oC:D0odbU0002
odbU0003o`000?mJZ@3oFZT000;oFZT000?o0000off^0?m][P000_m][P000ol0003oQ[D0ohJe0002
ohJe0004o`000?nV_@3oY[d0ojJm00Ko00001?nj`P000ol0003ocK00olf`0002olf`0005o`000?oH
T@3of940omRA0?l000000ooRL@07o`0000GokDX000?o0000oo@_0?od;`000_od;`001?l0003on1h0
ooPN0?oh7P04o`0000Sooooo00?o0000ooooooooool00Oooool004Sooooo00?o0000ooooooooool0
0_l00004oo0n00;o00000oo]B`03o`0000?ogGl000?o0000omZ:0?oJRP000ooJRP001_l0003of980
omRB0?l0003ob;`0o`0000Coa/4000?o0000olG30?o5``000_o5``000ol0003oPk@0oh>d0003oh>d
0006o`000?n<]`3oS;L0o`000?m<Y@3o00001_mIZ@000ol0003o=9d0ocBM0002ocBM0004o`000?m<
Y@3oC:D0o`0000?o6i@000Go0000ocNN0?lgWP3o=ih0o`000002o`f?0004o`000?l/VP3o;9X0o`00
00Co28d000?o0000obbJ0?l000001Ol=S`000ol0003o08@;o`000003oa^D0003o`000?l6S03o1X`0
00?o1X`000?o0000ob:G0?lRU`000_lRU`000ol0003o5Y80oaJB0003oaJB0003o`000?l?T03o3i00
00;o3i0000Ko0000o`f?0?l0003o0000od6Q0?l00004odBR0003o`000?m<Y@3oC:D000;oC:D000?o
0000oeZY0?mJZ@000omJZ@000ol0003oKJh0off^0002off^0005o`000?n6]@3oQ[D0ohJe0?l00000
1?nV_@001?l0003oa/40olK10?o6`@05o`000003ok[20?l0003ocK0000;ocK0000?o0000omRA0?oH
T@000_oHT@000ol0003ohW40on9a0002on9a0004o`000?o[DP3oje80on]B00Go000000?okDX0o`00
0?od;`000_od;`05o`0000;onAX00_l00008ooooo`03o`000?oooooooooo007ooooo0019ooooo`04
o`000?ooooooooooooooo`;o000000?ol3h0o`000?o]B`000oo]B`001ol0003ojUH0onYF0?oZEP3o
0000omeo0?l000001OoJRP000ol0003of980omRB0002omRB00;o00000oo6`@000ol0003oaL<0olG3
0003olG300;o00000on3]0000ol0003oS;L0ohbg0002ohbg0003o`000?mIZ@3oFJT000CoFJT000?o
0000off^0?l000000_ldW@000ol0003oC:D0odbU0002odbU0003o`000?lKU03o000000Co=ih000?o
0000o`f?0?l000001?l/VP001?l0003o28d0o`R=0?l00003obbJ0003o`000?l=S`3o3Hl000;o3Hl0
0_l00005oa^D0004o`000?l6S03o1X`0o`J<00;o00001OlRU`000ol0003o5Y80oaJB0002oaJB0004
o`000?l?T03o3i00o`n@00?o00001?m1X@000ol0003oA:80odBR0002odBR0003o`000?m<Y@3oC:D0
00;oC:D000?o0000oeZY0?mJZ@000_mJZ@000ol0003oKJh0off^0002off^0003o`000?n6]@3oQ[D0
00;oQ[D000?o0000ojJm0?nV_@000_nV_@001Ol0003oa/40olK10?o6`@3o000000?ocjT01_l00005
omRA0003o`000?oRL@3ohW4000;ohW4000Go0000on]B0?o[DP3oje80o`000003oo8f00Go00000_og
8P000ol0003onAX0ooTJ0003ooTJ00;o00002?ooool1o`00007ooooo0Oooool004[ooooo0_l00003
ooooo`;o00000oo]B`000ol0003ojUH0onYF0003onYF00;o00001?oJRP000ol0003of980omRB0002
omRB0006o`000?oFU`3oeYL0o`000?o6`@3o00001Oo5``001_l0003oa/40olK10?l0003oPk@0o`00
00GoS;L000?o0000oeVY0?mIZ@000omIZ@001_l0003oKJh0off^0?l0003o=9d0o`0000KoC:D000?o
0000ocNN0?lgWP001?lgWP000ol0003o;9X0obbJ0003obbJ0003o`000?l8S@3o000000Co;9X000Oo
0000o`f?0?l=S`3o3Hl0o`000?lgWP3o000000Go6i@000Co0000o`J<0?l6S03o00000_ldW@000ol0
003o8YL0ob:G0002ob:G0003o`000?lFTP3o5Y8000;o5Y801?l00002odBR0003o`000?m1X@3o@J40
00;o@J4000?o0000odBR0?m4XP000_m4XP000ol0003oC:D0odbU0002odbU0003o`000?mJZ@3oFZT0
00;oFZT000?o0000off^0?m][P000_m][P000ol0003oQ[D0ohJe0002ohJe0003o`000?nV_@3oY[d0
00;oY[d000?o0000olK10?o6`@000_o6`@001Ol0003ocjT0olnY0?o?Z@3o000000?ofHh01Ol00000
0ooHT@3o0000on9a0003on9a0003o`000?o[DP3oje8000;oje8000?o0000oo8f0?ob=P000_ob=P00
0ol0003omb80ooLR0003ooLR0004o`000?oi6P3onAX0ooTJ00Co00001oooool1o`00007ooooo0Ooo
ool004cooooo00?o0000ooooooooool00_ooool00ol0003okD/0o`000005onYF0003o`000?oWG`3o
iel000;o000000?ofXX0o`000?oHTP000ooHTP000ol0003oeYL0omJG0002omJG0003o`000?o5``3o
aL<000?oaL<000?o0000olK10?o6`@000_o6`@000ol0003oS;L0ohbg0003ohbg0003o`000?nJ^P3o
000000?oFJT000?o0000off^0?m][P000_m][P000ol0003oC:D0odbU0005odbU0003o`000?lgWP3o
=ih000?o=ih00_l00006obbJ0003o`000?l/VP3o;9X000?o;9X000Co0000o`f?0?l=S`3o00000olg
WP000ol0003o6i@0oa^D0002oa^D0003o`000?l6S03o000000?o=9d000?o0000ob:G0?lRU`000_lR
U`000ol0003o5Y80oaJB0002o`000003odbU0?l0003oA:8000CoA:8000?o0000od6Q0?m1X@000_m1
X@001Ol0003oA:80odBR0?m4XP3o000000CoC:D000?o0000oeZY0?mJZ@000omJZ@000ol0003oKJh0
off^0002off^0005o`000?n6]@3oQ[D0ohJe0?l000001?nV_@000ol0003oa/40olK10002olK10003
o`000?o?Z@3ocjT000;ocjT000Go0000omV>0?oISP3ofHh0o`000003on9a00Oo00001?o[DP000ol0
003olSH0oo8f0003oo8f0004o`000?og8P3omb80ooLR00Go00000_oh7@000ol0003on1d0o`000005
ooooo`;o00000_ooool004gooooo00?o0000ooooooooool00_ooool2o`0000CojUH000?o0000onMO
0?oWG`000ooWG`02o`0000?of98000?o0000omJG0?oFU`000ooFU`02o`0000?oaL<000?o0000olK1
0?o6`@000oo6`@000ol0003oS;L0ohbg0002ohbg0007o`000?nJ^P3oV[X0oiZj0?l0003oFJT0o`00
0005off^0003o`000?m<Y@3oC:D000CoC:D000?o0000ofZ^0?l000000olgWP001?l0003oFZT0oeZY
0?l00004obbJ00;o00001_l/VP02o`0000Co=ih000?o0000oa^D0?lKU0000_lKU002o`0000Go=9d0
00?o0000ob:G0?lRU`000_lRU`02o`0000?oC:D000?o0000odBR0?m4XP000om4XP000ol0003o@J40
od6Q0002od6Q0003o`000?m4XP3oA:8000;oA:8000?o0000odbU0?m<Y@000_m<Y@000ol0003oFZT0
oeZY000;o`000003ohJe0?l0003oY[d000?oY[d000Go0000olK10?o6`@3oa/40o`000004olnY0003
o`000?oISP3ofHh000;ofHh000?o0000on9a0?oRL@000_oRL@001?l0003ojU@0onYD0?oZE00?o`00
00;onA/000?o0000ooPM0?oh7@000ooh7@03o`0000?ooooo0ol00002ooooo`00C_ooool00ol0003o
ooooooooo`03ooooo`;o000000?ojUH0o`000?oWG`001?oWG`001_l0003oiFH0onEV0?l0003of980
o`0000GoeYL000Ko0000omFH0?oEV03o0000olG30?l00005olK10003o`000?o8_03o000000;oS;L0
00?o0000oiZj0?nJ^P000onJ^P000ol0003oKJh0off^0003off^0003o`000?n6]@3o000000CoC:D0
00Co0000ofZ^0?mZ[P3o00000_lgWP001Ol0003oFZT0oeZY0?mJZ@3o000000?o;9X000Co0000oeBW
0?mDY`3o00001?l/VP02o`0000Go=ih000?o0000oa^D0?lKU0000_l000000om<Y@3o0000ocBM0004
ocBM0004o`000?lRU`3o8YL0ob:G00;o00001Om<Y@000ol0003oA:80odBR0002odBR0003o`000?m1
X@3o@J4000;o@J4000?o0000odBR0?m4XP002_l00002oiZj0003o`000?n^_`3o[[l000;o[[l000Co
0000olG20?o5`P3oaL802_l000000oo6`@3o0000olnY0002olnY0003o`000?oISP3ofHh000?ofHh0
00?o0000on9a0?oRL@000_oRL@001Ol0003ojU@0onYD0?oZE03o000000ColCX000?o0000ooHU0?of
9@000oof9@000ol0003onA/0ooTK0003ooTK0003o`000?oh7@3on1d000Wo000000?oooooo`000?oo
ool00Oooool004oooooo0_l00005ooooo`03o`000?oWG`3oiel000?oiel000?o0000onEV0?oUIP00
0_oUIP000ol0003oeYL0omJG0003omJG0003o`000?oEV03oeIP000;oeIP000?o0000olK10?o6`@00
0oo6`@001_l0003ob;`0olRl0?l0003oS;L0o`0000GoV[X00_l00004off^0005o`000?n6]@3oQ[D0
ohJe0?l000000_m<Y@001ol0003oJZh0ofZ^0?mZ[P3o0000ocNN0?l000001?mJZ@001?l0003o;9X0
obbJ0?l00003oeBW0007o`000?l/VP3o;9X0obbJ0?l0003oFZT0o`000006ocNN00;o00001?m<Y@00
0ol0003o=9d0ocBM0002ocBM0006o`000?lRU`3o0000o`000?mJZ@3o00001Om<Y@000ol0003oA:80
odBR0003odBR0003o`000?m1X@3o@J4000Co00000_n4]0000ol0003oS;L0ohbg0002ohbg0003o`00
0?nJ^P3oV[X000?oV[X000Go0000ojjo0?n^_`3o[[l0o`000004olG20003o`000?o</@3oc;4000;o
c;4000Co0000omBL0?oDW03oe9`01Ol000000oo?Z@3o0000omV>0003omV>0003o`000?oRL@3ohW40
00;ohW4000?o0000onYD0?oZE0000_oZE0000ol0003olCX0oo4j0002oo4j0003o`000?of9@3omRD0
00?omRD000?o0000ooTK0?oi6`000_oi6`03o`0000;omBX01?l000001OoVI03o0000oooooooooooo
000000;ooooo001Aooooo`03o`000?oooooooooo00?ooooo00Go0000onMO0?oWG`3oiel0o`000004
onEV0003o`000?oTJ`3o000000?oeYL000?o0000omFH0?oEV0000_oEV0000ol0003oeYL0o`000003
olK10003o`000?o8_03ob;`000;ob;`000?o0000oiZj0?nJ^P000onJ^P001?l0003o[[l0ojjo0?l0
0003off^0007o`000?n6]@3oQ[D0ohJe0?l0003oC:D0o`000005ofZ^0003o`000?mJZ@3oFZT000Co
FZT00_l00004oeBW0004o`000?l/VP3o;9X0o`0000?oFZT000?o0000ocNN0?lgWP000olgWP000ol0
003oC:D0odbU0003odbU0003o`000?ldW@3o=9d000;o=9d00_l00004oeZY0003o`000?m<Y@3oC:D0
00;oC:D000?o0000odBR0?m4XP000_m4XP04o`0000;oPK@000?o0000ohBd0?n4]0000_n4]0000ol0
003oS;L0ohbg0002ohbg0003o`000?nJ^P3oV[X000;oV[X000?o0000ojjo0?n^_`000_n^_`000ol0
003oaL80olG20002olG20003o`000?o</@3oc;4000;oc;4000Go0000omBL0?oDW03oe9`0o`000003
omb500co00001?oZE0000ol0003olCX0oo4j0003oo4j0003o`000?of9@3omRD000;omRD000?o0000
ooTK0?l000000_l00002ooTL0003o`000?oe:P3o000000;okd4000?o0000onIT0?l000000oooool1
o`00007ooooo0Oooool005;ooooo00?o0000ooooooooool00oooool00ol0003oiel0o`000004onEV
0007o`000?oTJ`3oi6/0onA[0?l0003oeYL0o`000004omFH0007o`000?oFU`3oeYL0omJG0?l0003o
a/40o`000005olRl00;o00000onJ^P000ol0003o[[l0ojjo0002ojjo0003o`000?m][P3o000000Go
Q[D000?o0000ofZ^0?mZ[P001?mZ[P000ol0003oFZT0oeZY0004oeZY0003o`000?mDY`3oE:L000Co
E:L00_l00004oeZY0003o`000?lgWP3o=ih000;o=ih00_l00005odbU0003o`000?ldW@3o=9d000;o
000000?oKJh0o`000?mJZ@000omJZ@000ol0003oC:D0odbU0003odbU00Co000000?oQ;@0o`000?n1
]0000on1]0000ol0003oQ;@0ohBd0002ohBd0003o`000?n<]`3oS;L000;oS;L000?o0000oiZj0?nJ
^P000onJ^P001Ol0003o[[l0ojjo0?n^_`3o000000CoaL8000?o0000olba0?o</@000_o</@000ol0
003oe9`0omBL0002omBL0005o`000?oLQ@3og8D0omb50?l000001OoTK0001?l0003oje80on]B0?o[
DP0Bo`0000GonA`00ol000001?o_@@3o0000onIT0?l00005ooooo`7o00000Oooool005?ooooo00?o
0000ooooooooool00oooool2o`0000?oiFH000?o0000onA[0?oTJ`000_oTJ`03o`0000?oeIP000?o
0000omJG0?oFU`000ooFU`000ol0003ob;`0olRl0003olRl0006o`000?o;]03obk@0o`000?nJ^P3o
00001_n^_`000ol0003oQ[D0ohJe0003ohJe00;o00001OmZ[P000ol0003oSkL0o`000004oeZY00;o
00001_mDY`000ol0003oFZT0oeZY0004oeZY0004o`000?lgWP3o=ih0o`0000;oJZh000?o0000odbU
0?m<Y@000om<Y@02o`0000?oKJh000?o0000oeZY0?mJZ@000omJZ@001?l0003oC:D0odbU0?m<Y@02
o`0000CoQ;@000?o0000oh6d0?n1]0000on1]0000ol0003oQ;@0ohBd0002ohBd0003o`000?n<]`3o
S;L000;oS;L000?o0000oiZj0?nJ^P000_nJ^P001Ol0003o[[l0ojjo0?n^_`3o000000CoaL8000?o
0000olba0?o</@000_o</@000ol0003oe9`0omBL0002omBL0003o`000?oLQ@3og8D000;og8D000?o
0000onA/0?oTK0000ooTK0001Ol0003oje80on]B0?o[DP3o000000ColCX000?o0000ooHW0?of9`00
0oof9`000ol0003onA`0ooTL0003ooTL0003o`000?oi703o000000;o00000_of9`04o`000003oooo
ool0003ooooo00?ooooo0Ol00001ooooo`00E?ooool2o`0000Gooooo00?o0000onEV0?l000001?oT
J`001ol0003ohf`0on=/0?oSK03o0000omFH0?l000001OoFU`000ol0003of980o`000003olRl0003
o`000?o;]03obk@000;obk@000?o0000ojjo0?n^_`001?n^_`02o`0000CoQ[D000Co0000ojJm0?nV
_@3o00000omZ[P001Ol0003oSkL0ohng0?n?]`3o000000;oFZT000Co0000ohBd0?n4]03o00001?mD
Y`02o`0000KoFZT000?o0000ocNN0?l000000omZ[P000ol0003oC:D0odbU0002odbU00;o00001Om]
[P000ol0003oFZT0oeZY0002oeZY0006o`000?m<Y@3o0000o`000?n<]`3o00001On4]0000ol0003o
PK@0oh6d0002oh6d0003o`000?n4]03oQ;@000;oQ;@000?o0000ohbg0?n<]`000_n<]`000ol0003o
V[X0oiZj0002oiZj0003o`000?n^_`3o[[l000;o[[l000?o0000olG20?o5`P000_o5`P000ol0003o
c;40olba0002olba0003o`000?oDW03oe9`000;oe9`000?o0000omb50?oLQ@000_oLQ@000ol0003o
i6`0onA/0002onA/0003o`000?o[DP3oje8000;oje8000?o0000oo4j0?oa>P000_oa>P000ol0003o
mRL0ooHW0003ooHW0003o`000?oi703onA`000;onA`00_l00003ooHW00;o000000?ol3l0o`000?l0
00000oooool01Ol0003ooooooooooooooooo0000007ooooo001Fooooo`03o`000?oooooooooo00?o
oooo0_l00003onA[0003o`000?oSK03ohf`000?ohf`000?o0000omJG0?oFU`000ooFU`001ol0003o
f980omRB0?oHTP3o0000olRl0?l000001Oo;]0000ol0003o[[l0ojjo0003ojjo0004o`000?o5``3o
aL<0o`0000;oQ[D000?o0000ojJm0?nV_@000_nV_@000ol0003oJZh0o`000004ohng0003o`000?mJ
Z@3o000000CoQ;@000Co0000oeBW0?mDY`3o00000_n4]0000ol0003oFZT0oeZY0003oeZY00;o0000
1OmZ[P001_l0003oC:D0odbU0?l0003oQkD0o`0000GoKJh000?o0000oeZY0?mJZ@000_mJZ@02o`00
00CoS;L000?o0000ohBd0?n4]0000_n4]0000ol0003oPK@0oh6d0002oh6d0003o`000?n4]03oQ;@0
00;oQ;@000Co0000ohbg0?n<]`3oS;L06Ol000000ooDW03o0000omb50003omb50003o`000?oTK03o
i6`000;oi6`000?o0000on]B0?o[DP000_o[DP000ol0003olCX0oo4j0002oo4j0003o`000?of9`3o
mRL000?omRL000?o0000ooTL0?l000000_l00002ooTK0003o`000?of9`3o000000;ol3l00_l00004
ooooo`05o`000?ooooooooooooooool000000Oooool005Oooooo00?o0000ooooooooool01?ooool0
0ol0003oi6/0o`000005on=/0003o`000?oTJ`3o000000?oeYL000?o0000omRB0?oHTP000ooHTP00
0ol0003obk@0ol^d0003ol^d0003o`000?o?Z@3o000000?o[[l000Oo0000olG30?o5``3oaL<0o`00
0?n6]@3o000000KoY[d000?o0000ohng0?n?]`001?n?]`000ol0003oQ;@0ohBd0003ohBd0003o`00
0?mDY`3o000000CoQ;@000?o0000oeZY0?mJZ@000_l000000on?^03o0000ofZ^0004ofZ^0003o`00
0?m<Y@3o000000?oQkD000?o0000off^0?m][P000_m][P000ol0003oFZT0oeZY0002o`000003oi^j
0?l0003oS;L000?oS;L000?o0000ohBd0?n4]0000_n4]0000ol0003oPK@0oh6d0003oh6d0003o`00
0?n4]03oQ;@000Go00000_o8_0000ol0003obk@0ol^d0002ol^d0005o`000?o?Z@3ocjT0olnY0?l0
00001?oDV`000ol0003ofXX0omZ:0002omZ:0004o`000?oQMP3ohGH0on5f01go00001Ooi6`03o`00
0003oo0o0?l0003o000000Kooooo00Co0000oooooooooooo00000Oooool005Sooooo00?o0000oooo
ooooool01?ooool00ol0003ohf`0on=/0003on=/0007o`000?oTJ`3oi6/0onA[0?l0003oeYL0o`00
0005omRB0003o`000?oJRP3o000000?obk@000Oo0000olnY0?o?Z@3ocjT0o`000?n^_`3o000000Go
aL<000?o0000ojJm0?nV_@001?nV_@02o`0000GoSkL00_l00005ohBd00;o00001On4]0000ol0003o
FZT0o`000004ohnh0003o`000?mZ[P3oJZh000;oJZh00_l00004ohNe0003o`000?m][P3oKJh000?o
KJh00_l00003oi^j0003o`000?n<]`3oS;L000?oS;L000?o0000ohBd0?n4]0000_n4]0000ol0003o
PK@0oh6d0005o`0000;oa/4000?o0000olRl0?o8_0000_o8_0000ol0003obk@0ol^d0003ol^d0005
o`000?o?Z@3ocjT0olnY0?l000001?oDV`000ol0003ofXX0omZ:0002omZ:0003o`000?oQMP3ohGH0
00;ohGH000?o0000onMP0?oWH0000_oWH0000ol0003okD/0one;0002one;0003o`000?ob=P3olSH0
00;olSH000?o0000ooHV0?of9P000_of9P000ol0003onA`0ooTL0004ooTL0003o`000?oi6`3o0000
00;o00000_of9`03o`0000Sooooo00?o0000ooooool000000Oooool005Wooooo0_l00005ooooo`05
o`000?oSK03ohf`0on=/0?l000001?oTJ`02o`0000Gof98000Oo0000omZ:0?oJRP3ofXX0o`000?o;
]03o000000GocjT000?o0000olG30?o5``001?o5``000ol0003oY[d0ojJm0003ojJm0004o`000?o6
`@3oa/40o`0000?oSkL000Co0000ok[20?nj`P3o00000on4]0000ol0003o]<40o`000005ohBd00;o
00001On?^0001ol0003oJZh0ofZ^0?mZ[P3o0000ojJm0?l000001On7]@001?l0003oKJh0off^0?m]
[P02o`0000GoVkX000?o0000ohbg0?n<]`000_n<]`001?l0003oQ;@0ohBd0?n4]004o`0000;oaL80
00?o0000olK10?o6`@000oo6`@000ol0003ob;`0olRl0002olRl0003o`000?o;]03obk@000;obk@0
00Go0000olnY0?o?Z@3ocjT0o`000004omBK0003o`000?oJRP3ofXX000;ofXX000?o0000on5f0?oQ
MP000ooQMP000ol0003oif00onMP0002onMP0003o`000?o]B`3okD/000;okD/000?o0000oo8f0?ob
=P000_ob=P000ol0003omRH0ooHV0002ooHV0003o`000?oi703onA`000?onA`00_l00003ooHW00?o
00002_ooool00ol0003oooooo`000001ooooo`00Foooool00ol0003oooooooooo`03ooooo`03o`00
0?oSK03o000000Coi6/000Co0000onEV0?oUIP3o00000ooHTP000ol0003ofXX0omZ:0003omZ:0003
o`000?o?Z@3ocjT000?ocjT00_l00005olG30003o`000?o</@3o000000?oY[d000Go0000olK10?o6
`@3oa/40o`000002ohng0005o`000?nj`P3o^/80ok[20?l000000_n4]0001Ol0003o]<40okC10?nd
`@3o000000?oQ;@000?o0000ok[20?l000001On?^0001?l0003oJZh0ofZ^0?l00003ojJm0003o`00
0?n7]@3oQkD000;oQkD000Ko0000off^0?l0003o0000ojno0?l00005oi^j0003o`000?n<]`3oS;L0
00;oS;L000Ko0000ohBd0?l0003o0000olK10?l00005olG20003o`000?o6`@3oa/4000;oa/4000?o
0000olRl0?o8_0000_o8_0000ol0003obk@0ol^d0002ol^d0003o`000?o?Z@3ocjT000;ocjT000?o
0000omBK0?oDV`000_oDV`000ol0003ofXX0omZ:0002omZ:0003o`000?oQMP3ohGH000;ohGH000?o
0000onMP0?oWH0000_oWH0000ol0003okD/0one;0002one;0003o`000?ob=P3olSH000;olSH000?o
0000ooHV0?of9P000oof9P000ol0003onA`0o`000002o`0000;onA`000Go0000ooHW0?l0003okd40
o`00000<ooooo`7o00000Oooool1o`000000G?ooool00ol0003oooooooooo`03ooooo`;o00000ooT
J`000ol0003oiFH0onEV0002onEV0003o`000?oHTP3o000000GofXX00_l00004olnY0004o`000?oD
V`3oe9/0o`0000?oaL<000Oo0000olba0?o</@3oc;40o`000?nV_@3o000000Coa/4000?o0000ohng
0?l000001?nj`P000ol0003oQ;@0o`000004okC10004o`000?n4]03oQ;@0o`0000?o^/8000?o0000
ohnh0?n?^0000on?^002o`0000CoY[d000?o0000ohNe0?n7]@000_n7]@02o`0000Co[kl000?o0000
oi^j0?nK^P000_nK^P000ol0003oS;L0ohbg0002ohbg00;o00001?o6`@000ol0003oaL80olG20002
olG20003o`000?o6`@3oa/4000;oa/4000?o0000olRl0?o8_0000_o8_0000ol0003obk@0ol^d0003
ol^d0005o`000?o?Z@3ocjT0olnY0?l000001?oDV`000ol0003ofXX0omZ:0002omZ:0003o`000?oQ
MP3ohGH000;ohGH000?o0000onMP0?oWH0000_oWH0000ol0003okD/0one;0002one;0004o`000?ob
=P3olSH0oo8f00Wo00001Ooi7002o`000003onm10?l0003ooooo00gooooo0_l0000005gooooo00?o
0000ooooooooool01?ooool00ol0003oi6/0o`000005onEV00;o00001OoJRP001?l0003ogGl0omeo
0?l00002olnY0003o`000?oDV`3oe9/000;oe9/000?o0000olG30?l000001Oo</@000ol0003oa/40
olK10004olK10003o`000?nj`P3o^/8000Co^/8000?o0000okC10?nd`@000ond`@000ol0003oQ;@0
o`000004ok[20003o`000?n?^03oSkP000;oSkP00_l00005ojJm0003o`000?n7]@3oQkD000;o0000
00?oaL80o`000?n__`000on__`000ol0003oVkX0oi^j0003oi^j00Co000000?ob;`0o`000?o6`@00
0oo6`@000ol0003oaL80olG20003olG20003o`000?o6`@3oa/4000;oa/4000?o0000olRl0?o8_000
0_o8_0000ol0003obk@0ol^d000So`0000;omb8000?o0000ooTK0?oi6`001?oi6`000ol0003onA`0
o`000002o`000003ooDZ0?l0003o000000kooooo0ol0000005kooooo0_l00005ooooo`03o`000?oU
IP3oiFH000?oiFH000Co0000onMO0?oWG`3o00000ooJRP001ol0003ogGl0omeo0?oMO`3o0000olnY
0?l000001OoDV`02o`0000Goc;400_l00005olK100;o00001_nj`P000ol0003o]<40okC10004okC1
0003o`000?nj`P3o^/8000?o^/8000?o0000ohnh0?n?^0000_l000000oo6`@3o0000ojJm0005ojJm
00;o00000oo5`P000ol0003o[kl0ojno0003ojno0004o`000?nK^P3oVkX0oi^j00;o00001Oo8_000
0ol0003oa/40olK10002olK10003o`000?o5`P3oaL8000;oaL8000?o0000olK10?o6`@002_l00002
omZ:0003o`000?oNO`3ogWl000;ogWl000?o0000on9a0?oRL@000_oRL@000ol0003oiV80onIR0002
onIR0003o`000?o[D@3oje4000;oje4000?o0000oo0o0?o`?`000_o`?`000ol0003om2l0oo@_0002
oo@_0003o`000?og8P3omb8000?omb8000Co0000ooTK0?oi6`3onA/01?l00002ooDZ00;o00003?oo
ool4o`0000?ooooo001Pooooo`03o`000?oooooooooo00?ooooo00Go0000onEV0?oUIP3oiFH0o`00
0004onMO0003o`000?oJRP3o000000GogGl000?o0000omBK0?oDV`000ooDV`000ol0003ofXX0o`00
0004olba0004o`000?oDW03oe9`0o`0000?oa/4000Co0000olnY0?o?Z@3o00001?nj`P000ol0003o
cJl0o`000005okC10003o`000?nj`P3o^/8000Co^/800_l00004olK10003o`000?nV_@3oY[d000;o
Y[d00_l00005olG20003o`000?n__`3o[kl000;o[kl000Ko0000oi^j0?l0003o0000ol^d0?l00005
olRl0003o`000?o6`@3oa/4000;oa/4000?o0000olG20?o5`P000_o5`P03o`0000;oeYH000?o0000
omRA0?oHT@000_oHT@000ol0003ofXX0omZ:0003omZ:0003o`000?oNO`3ogWl000;ogWl000?o0000
on9a0?oRL@000_oRL@000ol0003oiV80onIR0002onIR0003o`000?o[D@3oje4000;oje4000?o0000
oo0o0?o`?`000_o`?`000ol0003om2l0oo@_0002oo@_0004o`000?og8P3omb80ooLR00Go00000ooh
7P000ol0003omBX0o`00000:ooooo`Co00001oooool0067ooooo00?o0000ooooooooool00oooool0
0ol0003oiFH0o`000005onMO00;o00001OoMO`000ol0003ohW40o`000003omBK0005o`000?oJRP3o
fXX0omZ:0?l000000_o</@000ol0003oe9`0omBL0002omBL0003o`000?o6`@3o000000CocjT000Co
0000ok[20?nj`P3o00000_o=[`000ol0003o]<40okC10002okC10003o`000?o=[`3o000000Go^/80
00?o0000olK10?o6`@000oo6`@001ol0003oY[d0ojJm0?nV_@3o0000olba0?l000001Oo5`P000ol0
003o[kl0ojno0002ojno00;o00001?o;]0000ol0003ob;`0olRl0002olRl0003o`000?o6`@3oa/40
00;oa/4000?o0000olG20?l000000_l000000ooFV03o0000omJF0003omJF0003o`000?oHT@3of940
00;of94000?o0000omZ:0?oJRP000_oJRP000ol0003ogWl0omio0002omio0003o`000?oRL@3ohW40
00;ohW4000?o0000onIR0?oVHP000_oVHP000ol0003oje40on]A0002on]A0003o`000?o`?`3ol3l0
00;ol3l000Co0000oo@_0?od;`3om2l01Ol00002ooTJ0003o`000?oh7P3on1h000?on1h00_l00007
ooooo`Co00002oooool006;ooooo00?o0000ooooooooool00oooool00ol0003oiel0onMO0003onMO
0004o`000?oZEP3ojUH0o`0000?ogGl000Oo0000on9a0?oRL@3ohW40o`000?oDV`3o000000CofXX0
00?o0000olba0?l000001_oDW0000ol0003ocjT0olnY0003olnY0003o`000?nj`P3o000000CocJl0
00Co0000okC10?nd`@3o00000_o=[`000ol0003o^/80ok[20002ok[200;o00001Oo6`@001?l0003o
Y[d0ojJm0?l00003olba0003o`000?o5`P3oaL8000;oaL8000?o0000ojno0?n__`000_l000000oo?
Z@3o0000ol^d0003ol^d0003o`000?o8_03ob;`000?ob;`000?o0000olK10?o6`@000ol00004omJH
0003o`000?oFUP3oeYH000;oeYH000?o0000omRA0?oHT@000_oHT@000ol0003ofXX0omZ:0002omZ:
0003o`000?oNO`3ogWl000;ogWl000?o0000on9a0?oRL@000_oRL@000ol0003oiV80onIR0002onIR
0003o`000?o[D@3oje4000;oje4000Co0000oo0o0?o`?`3ol3l01Ol00002ooPN0003o`000?oi6P3o
nAX000?onAX000?o0000ooPN0?l000000_l00006ooooo`?o00003oooool006?ooooo0_l00004oooo
o`05o`000?oWG`3oiel0onMO0?l000001?oZEP000ol0003ogGl0o`000005on9a0003o`000?oJRP3o
fXX000CofXX000?o0000omBL0?oDW0001?oDW002o`0000GocjT00_l00005olf_0003o`000?nd`@3o
000000CocJl000Co0000ok[20?nj`P3o00000_o?Z@000ol0003oa/40olK10003olK100;o00001?o<
/@000ol0003oaL80olG20003olG200;o00001?o?Z@000ol0003obk@0ol^d0002ol^d0004o`000?o8
_03ob;`0olRl00Co00000_oFUP000ol0003oeYP0omJH0003omJH0003o`000?oFUP3oeYH000;oeYH0
00Go0000omRA0?oHT@3of940o`000005omZ:0003o`000?oNO`3ogWl000;ogWl000?o0000on9a0?oR
L@003ol00002ooHV0003o`000?oh7P3on1h000?on1h000Co0000ooTJ0?oi6P3onAX00ol00005oooo
o`Co00004_ooool006Gooooo00?o0000ooooooooool00_ooool00ol0003oiel0o`000005onYF00;o
00001OoRL@02o`0000GofXX00_l00005omBL0004o`000?oLQ@3og8D0o`0000?ocjT000?o0000omV>
0?l000001Oo=[`02o`0000GocJl000?o0000ok[20?l000000oo?Z@000ol0003oa/40olK10002olK1
00;o00001Oo</@000ol0003oaL80olG20002olG200;o00001Oo?Z@000ol0003obk@0ol^d0002ol^d
0006o`000?o8_03o0000o`000?oHT@3o00001OoFUP000ol0003oeYP0omJH0002omJH0003o`000?oF
UP3oeYH000;oeYH000?o0000omRA0?oHT@000_oHT@000ol0003ofXX0omZ:000:o`0000;okD/000?o
0000oo0n0?o`?P000_o`?P000ol0003olc80oo<b0002oo<b0003o`000?of9P3omRH000?omRH000?o
0000ooPN0?oh7P000_oh7P04o`0000Cooooo1?l0000Fooooo`00I_ooool00ol0003oooooooooo`02
ooooo`03o`000?oZEP3ojUH000?ojUH000?o0000one;0?l000001?oRL@001?l0003oiV80onIR0?l0
0003omZ:0004o`000?oQMP3ohGH0o`0000?oe9`000Go0000omb50?oLQ@3og8D0o`000002olnY0005
o`000?oISP3ofHh0omV>0?l000000oo=[`000ol0003of940o`000005olf_00;o00001Oo?Z@001_l0
003oa/40olK10?l0003oe9`0o`0000Koc;401?l000000ooDV`3o0000olnY0004olnY0003o`000?o;
]03obk@000;obk@00_l00004omRA0003o`000?oFUP3oeYH000;oeYH000?o0000omJH0?oFV0000_oF
V0000ol0003oeYH0omJF0002omJF00So00000_oWG`000ol0003ojUH0onYF0002onYF0003o`000?o]
B`3okD/000?okD/000?o0000oo0n0?o`?P000_o`?P000ol0003olc80oo<b0002oo<b0003o`000?of
9P3omRH000;omRH000?o0000ooPN0?l000000_l00004ooooo`Co00006_ooool006Oooooo00?o0000
ooooooooool00_ooool01Ol0003ojUH0onYF0?oZEP3o000000?okD/000Co0000on9a0?oRL@3o0000
1?oVHP000ol0003ofXX0o`000004on5f0003o`000?oDW03o000000Cog8D000?o0000olnY0?l00000
1?oISP001?l0003ocJl0olf_0?l00003omRA0007o`000?o=[`3ocJl0olf_0?l0003ofHh0o`000005
olnY0003o`000?o6`@3o000000?oe9`000?o0000olba0?o</@000_o</@02o`0000Goe9/000?o0000
olnY0?o?Z@000oo?Z@04o`000003omZ90?l0003of94000?of94000?o0000omJF0?oFUP000_oFUP00
0ol0003oeYP0omJH0003omJH00Co000000?oi6X0o`000?oUIP000_oUIP000ol0003oiel0onMO0003
onMO0003o`000?oZEP3ojUH000;ojUH000?o0000one;0?o]B`000_o]B`000ol0003ol3h0oo0n0002
oo0n0004o`000?oc<P3olc80oo<b00So00000oooool4o`0001kooooo001Xooooo`;o00000oooool0
0ol0003ojUH0o`000004one;0003o`000?oRL@3o000000GoiV800_l00005on5f00;o00001_oLQ@00
0ol0003ofHh0omV>0003omV>0003o`000?o=[`3o000000Cof94000Co0000olf_0?o=[`3o00000ooI
SP000ol0003ocjT0olnY0002olnY00;o00001OoDW0001_l0003oc;40olba0?l0003ofXT0o`0000Go
e9/000?o0000olnY0?o?Z@000_o?Z@02o`0000GofXT000?o0000omRA0?oHT@000_oHT@000ol0003o
eYH0omJF0002omJF0003o`000?oFV03oeYP000?o00001OoTJP001Ol0003oiFH0onEV0?oUIP3o0000
00Goiel000?o0000onYF0?oZEP000_oZEP001Ol0003okD/0one;0?o]B`3o000000?ol3h01Ol00007
ooooo`Co00008_ooool006[ooooo00Go0000ooooooooooooooooo`000005one;00;o00001OoVHP00
0ol0003oje40o`000004on5f0003o`000?oWH03o000000Gog8D00_l00005omV>00;o00001OoHT@00
0ol0003ocJl0o`000004omV>0003o`000?o?Z@3ocjT000;o000000?og8D0o`000?oDW0001?oDW000
0ol0003oc;40o`000003omZ90003o`000?oDV`3oe9/000;oe9/000?o0000olnY0?o?Z@000_l00000
0ooNO`3o0000omZ90004omZ90003o`000?oHT@3of94000;of94000?o0000omJF0?oFUP001Ol00002
onA/0003o`000?oTJP3oi6X000?oi6X000?o0000onEV0?oUIP000_oUIP000ol0003oiel0onMO0002
onMO0004o`000?oZEP3ojUH0onYF00Wo00002?ooool4o`0002Kooooo001[ooooo`05o`000?oooooo
ooooooooool000000oo]B`001?l0003ol3h0oo0n0?l00003onIR0005o`000?o[D@3oje40on]A0?l0
00000_oQMP001Ol0003oif00onMP0?oWH03o000000?og8D000Co0000onA/0?oTK03o00000ooISP00
0ol0003ohW40o`000005omRA00;o00001OoISP000ol0003ocjT0o`000004omb50003o`000?oDW03o
e9`000;oe9`00_l00004omZ90003o`000?oDV`3oe9/000?oe9/00_l00004omio0003o`000?oJR@3o
fXT000;ofXT000?o0000omRA0?oHT@000_oHT@03o`0000;oi6X000?o0000onA/0?oTK0000ooTK000
0ol0003oi6X0onAZ0002onAZ0003o`000?oUIP3oiFH000;oiFH000Co0000onMO0?oWG`3oiel01Ol0
000>ooooo`?o0000:_ooool006cooooo00Oo0000ooooooooooooooooo`000?o]B`3o000000Col3h0
00?o0000onIR0?l000001?o[D@000ol0003ohGH0o`000005onMP0003o`000?oLQ@3o000000Coi6`0
00?o0000omV>0?l000000ooRL@001ol0003of940omRA0?oHT@3o0000on9a0?l000001OoISP02o`00
00Gog8D000?o0000omBL0?oDW0000_l000000ooQMP3o0000omZ90004omZ90004o`000?oDV`3oe9/0
omBK00;o00001OoNO`000ol0003ofXT0omZ90003omZ900Co000000?oiFH0o`000?oTJP000ooTJP00
0ol0003oi6`0onA/0002onA/0003o`000?oTJP3oi6X000?oi6X000?o0000onEV0?oUIP001Ol0000?
ooooo`Co0000;Oooool006gooooo0_l00002ooooo`03o`000?o`?P3ol3h000?ol3h00_l00005on]A
00;o00001_oWH002o`0000Goi6`00_l00005on9a0003o`000?oHT@3o000000?ohW4000Oo0000omV>
0?oISP3ofHh0o`000?oTJ`3o000000Gog8D000?o0000omBL0?l000001?oQMP000ol0003ofXT0omZ9
0002omZ90006o`000?oDV`3o0000o`000?oRL@3o00001OoNO`000ol0003ofXT0omZ90002omZ900;o
00001OoUIP000ol0003oi6X0onAZ0002onAZ0005o`000?oTK03oi6`0onA/0?l000000ooTJP05o`00
013ooooo1?l0000aooooo`00Koooool01?l0003oooooooooool00003oo0n0004o`000?oc<P3olc80
o`0000?oje4000Co0000oo0o0?o`?`3o00000ooWH002o`000003one:0?l0003oi6`000?oi6`000?o
0000on]B0?l000001OoRL@02o`0000GohW4000?o0000omV>0?l000000ooTJ`000ol0003og8D0omb5
0002omb500;o00001OoQMP000ol0003ofXT0omZ90002omZ900;o00001?oRL@000ol0003ogWl0omio
0003omio00Co000000?oiel0o`000?oUIP001?oUIP000ol0003oi6X0onAZ0002onAZ0003o`000?oT
K03oi6`000Go00004Oooool4o`0003Gooooo001`ooooo`06o`000?ooooooooooo`000?o`?P3o0000
1?oc<P000ol0003oje40o`000004oo0o0003o`000?oWH03o000000CokDX000Co0000onA/0?oTK03o
00000oo[DP001ol0003ohW40on9a0?oRL@3o0000onYD0?l000001OoRL@02o`0000Goi6/000Ko0000
omb50?oLQ@3o0000onMP0?l00005on5f0003o`000?oJR@3ofXT000;o000000?oiV40o`000?oRL@00
1?oRL@001?l0003ogWl0omio0?oNO`02o`0000Goiel000?o0000onEV0?oUIP000_oUIP000ol0003o
i6X0onAZ0002onAZ00?o00004_ooool4o`0003Wooooo001aooooo`04o`000?ooooooooooo`0000Go
lc800_l00005oo0o00;o00001Oo]BP000ol0003oi6`0o`000004on]B0004o`000?oRL@3ohW40o`00
00?ojU@000Oo0000on9a0?oRL@3ohW40o`000?o[D@3o000000Goi6/000?o0000omb50?l000000ooW
H0000ol0003ohGH0on5f0003on5f00;o00001?oVH@000ol0003ohW40on9a0002on9a0006o`000?oN
O`3o0000o`000?oZE@3o00001OoWG`000ol0003oiFH0onEV0003onEV00Co00004Oooool4o`0003go
oooo001booooo`?o00000ooc<P02o`0000;omRH000Oo0000oo0o0?o`?`3ol3l0o`000?od;`3o0000
00GokDX00_l00005on]B0003o`000?oRL@3o000000CojU@000Co0000on9a0?oRL@3o00000oo[D@00
0ol0003oi6/0onA[0002onA[00;o00001OoWH0001?l0003ohGH0on5f0?oQMP02o`0000GoiV4000?o
0000on9a0?oRL@000_oRL@02o`0000CojUD000?o0000onMO0?oWG`000_oWG`001?l0003oiFH0onEV
0?oUIP03o`00013ooooo1?l00011ooooo`00M?ooool2o`000003oo<b0?l0003omRH000ComRH000?o
0000oo0o0?l000000ood;`001ol0003okDX0one:0?o]BP3o0000oo8f0?l000001Oo[DP02o`0000Go
jU@000?o0000on9a0?l000001?o[D@000ol0003oi6/0onA[0002o`000003one:0?l0003oif0000Co
if0000Ko0000on5f0?l0003o0000on]@0?l00005onIQ0003o`000?oRL@3o000000;o000000?okDX0
o`000?oZE@001?oZE@001?l0003oiel0onMO0?oWG`04o`0000oooooo1?l00015ooooo`00MOooool2
o`0000KomRH00_l00005oo@_0003o`000?o]BP3o000000?olSH000Go0000on]B0?o[DP3oje80o`00
0002oo4j0003o`000?oZE03ojU@000;ojU@00_l00005on]A0003o`000?oTJ`3o000000CokDX000?o
0000onMP0?oWH0000_oWH002o`0000Coje0000?o0000onIQ0?oVH@000_oVH@02o`0000GokDX000?o
0000onYE0?oZE@000_oZE@001?l0003oiel0o`000?l0000@ooooo`?o0000BOooool007Kooooo0_l0
0003ooHV00;o000000?on1h0o`000?od;`001?od;`02o`0000GolSH000?o0000on]B0?l000001?oa
>P001_l0003ojU@0o`000?l0003olCX0o`0000Goje400_l00005one:0003o`000?oWH03oif0000;o
000000?ol3l0o`000?o[D0001?o[D0001_l0003oiV40o`000?l0003ol3h0o`0000GokDX000?o0000
onYE0?oZE@000_oZE@02o`0000kooooo1?l0001<ooooo`00Moooool2o`000003ooHV0?l0003on1h0
00?on1h000?o0000oo@_0?l000000_l000000oog8P3o0000oo8f0004oo8f00;o00001Ooa>P02o`00
00ColCX000Oo0000on]A0?o[D@3oje40o`000?ob=P3o000000GokDX000?o0000onMP0?l000001?o`
?`000ol0003oje00on]@0002on]@00;o00001?o`?P000ol0003okDX0one:0002one:0003o`000?oZ
E@3o000000;o00003?ooool4o`00053ooooo001hooooo`?o00001?oh7P02o`0000Gomb8000?o0000
oo8f0?l000000_l000000oog9@3o0000oo4j0002oo4j00;o000000?omRH0o`000?oa>P001?oa>P00
0ol0003oje40o`000003oo8f0003o`000?o]BP3okDX000;okDX00_l00005oo0o0003o`000?o[D03o
000000;o000000?olc40o`000?o`?P001?o`?P001?l0003okDX0one:0?o]BP02o`0000_ooooo1?l0
001Dooooo`00N_ooool2o`000003ooPN0?l0003o000000;onAX000?o0000ooLR0?og8P000_og8P02
o`0000GombD000?o0000oo4j0?l000001?of9P000ol0003olCX0oo4j0002oo4j00;o00001Oob=P00
1_l0003okDX0o`000?l0003om2l0o`0000Gol3l00_l00005oo<a0003o`000?o`?P3ol3h000;ol3h0
00Co0000one:0?l0003o00002Oooool4o`0005Sooooo001kooooo`?o00001?oi6P001?l0003omb80
o`000?l00002ooTK0003o`000?og9@3ombD000;ombD00_l00005ooHV0003o`000?oa>P3o000000;o
000000?ombD0o`000?ob=P001?ob=P02o`0000Com2l000Oo0000oo0o0?o`?`3ol3l0o`000?of9P3o
000000Golc4000Co0000oo0n0?o`?P3ol3h00ol00007ooooo`Co0000G?ooool007cooooo00?o0000
ooooool000000_oi6P04o`0000ConA/000Co0000ooLU0?l0003o00000_oi6`000ol0003omRH0ooHV
0002ooHV00;o00001Oog9@000ol0003olSH0o`000002o`000003ooLR0?l0003om2l000Com2l000?o
0000oo0o0?l000000oof9P000ol0003olc40oo<a0002oo<a00Co00001_ooool4o`00063ooooo001m
ooooo`Co00001?oh7@000ol0003onA/0ooTK0004o`0000ConA/000Co0000ooHV0?l0003o00000_oi
6`000ol0003ombD0ooLU0002ooLU00;o00001Oog8P001?l0003om2l0oo@_0?od;`03o`0000GomRH0
00Co0000oo<a0?l0003o00001_ooool4o`0006Cooooo001oooooo`03o`000?oooooo000000Ko0000
1?oi70000ol0003onA/0ooTK0004o`0000ConA/000Co0000ooLU0?l0003o00000_oi6P000ol0003o
mb80ooLR0002ooLR00Co00000_oh7@000ol0003omRH0ooHV0003ooHV00;o00001Oooool3o`0006So
oooo0020ooooo`04o`000?ooooooooooooooo`_o00001?oi6`000ol0003onA/0ooTK0004o`0000Co
nAX000Co0000ooLR0?l0003o00000_oi6P000ol0003on1d0ooPM0002ooPM0003o`000?of9P3o0000
00;o00000oooool4o`0006_ooooo0021ooooo`03o`000?oooooooooo00Kooooo1Ol00003ooTK00Co
00001?oi6`000ol0003onAX0ooTJ0003o`0000GonAX000?o0000ooPM0?oh7@000ol00002ooooo`Co
0000Koooool008;ooooo0_l00008ooooo`03o`000?oooooo000000ko00000ooi7@001?l0003onAX0
ooTJ0?oi6P04o`000003ooooool0003o000000;o0000Loooool008Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`09ooooo`co000000?oooooo`000?l000000_l0001gooooo`00QOoo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0001kooooo`00Q_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0001oooooo`00Qoooool2o`00
00?ooooo00?o0000ooooooooool02oooool3o`0008?ooooo0029ooooo`04o`000?ooooooooooo`00
00Wooooo1?l00026ooooo`00R_ooool00ol0003oooooo`000005ooooo`Co0000R_ooool008_ooooo
0_l000000ooooooo0000o`000002o`0008kooooo002<ooooo`;o0000T_ooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool003Kooooo0ol0001Hooooo`?o00005oooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo00Sooooo000gooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo000a
ooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000?ooooo1?l00000
0ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co00000oooool2o`0000;ooooo1_l00006
ooooo`Go00000_ooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l0
0002ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`Co000000?oooooo`000?l000000_l0
0002ooooo`Co00000oooool3o`0000;ooooo1Ol00003ooooo`;o000000Coooooo`000?oooooooooo
0_l00003ooooo`?o00002Oooool4o`000003ooooool0003o000000?o000000?oooooo`000?l00000
0_l00004ooooo`;o00000oooool4o`000005ooooool0003o0000o`000?ooool00_l000001?oooooo
0000o`000?l00003ooooo`?o00001Oooool00ol0003oooooooooo`06ooooo`00<?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo0000
00Cooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000_ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooool000000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00Kooooo000`oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;o
oooo0ol00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool5o`0000Oooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool00ol0003ooooooooo
o`03ooooo`?o00000oooool01_l0003oooooooooool0003oooooo`0000Gooooo1Ol00004ooooo`03
o`000?oooooooooo00Kooooo000`ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08
ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000oooool01_l0003oooooooooool0003oooooo`0000Gooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00004oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`00<?ooool01_l0003ooooo
oooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000oooool2o`00
00Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00002ooooo`;o00000oooool4
o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`Co00000oooool9
o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`?o00000oooool4
o`0000;ooooo0ol00004ooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?l0003ooooo
1?l00003ooooo`?o00002Oooool3o`0000;ooooo0ol00004ooooo`Co000000?oooooo`000?l00000
0_l00003ooooo`;o00000oooool4o`0000?ooooo0ol00003ooooo`?o00001Oooool00ol0003ooooo
ooooo`06ooooo`00<?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo000aooooo`?o0000
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0ol00009ooooo`Co0000
2Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool3o`0001Kooooo00?o0000ooooooooool0
0_ooool2o`0000gooooo00?o0000ooooooooool01_ooool2o`00013ooooo0ol0000:ooooo`03o`00
0?oooooooooo013ooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`08ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.169088, 0.0201575, \
0.0039083, 0.0039083}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.07261 .22845 -18 -8.83299 ]
[.07261 .22845 0 .16701 ]
[.26329 .15343 -11.4506 -9 ]
[.26329 .15343 .54943 0 ]
[.46894 .07256 -5.33495 -9 ]
[.46894 .07256 .66505 0 ]
[.76362 .09117 0 -6.16757 ]
[.76362 .09117 12 2.83243 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93772 .35778 0 -5.91556 ]
[.93772 .35778 6 3.08444 ]
[.02231 .27641 -24 -2.75186 ]
[.02231 .27641 0 6.24814 ]
[.015 .32223 -18 -2.79062 ]
[.015 .32223 0 6.20938 ]
[.00747 .36944 -24 -2.83067 ]
[.00747 .36944 0 6.16933 ]
[-0.00029 .41808 -18 -2.87207 ]
[-0.00029 .41808 0 6.12793 ]
[-0.0083 .46824 -24 -2.91489 ]
[-0.0083 .46824 0 6.08511 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.08206 .23755 m
.08679 .24211 L
s
[(-10)] .07261 .22845 1 .96289 Mshowa
.27211 .16314 m
.27652 .16799 L
s
[(-5)] .26329 .15343 .90843 1 Mshowa
.477 .08291 m
.48103 .08809 L
s
[(0)] .46894 .07256 .77832 1 Mshowa
.125 Mabswid
.11896 .22311 m
.12176 .22587 L
s
.1564 .20844 m
.15917 .21125 L
s
.1944 .19357 m
.19713 .19641 L
s
.23297 .17847 m
.23565 .18134 L
s
.31185 .14758 m
.31445 .15053 L
s
.35219 .13178 m
.35475 .13477 L
s
.39315 .11574 m
.39567 .11877 L
s
.43475 .09945 m
.43722 .10252 L
s
.51991 .06611 m
.52228 .06925 L
s
.5635 .04904 m
.56582 .05222 L
s
.60779 .03169 m
.61005 .03492 L
s
.6528 .01407 m
.655 .01734 L
s
.04569 .2518 m
.04856 .25449 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75132 .09573 m
.74517 .09801 L
s
[(-5)] .76362 .09117 -1 .37057 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9252 .36171 m
.91895 .36368 L
s
[(5)] .93772 .35778 -1 .31457 Mshowa
.125 Mabswid
.77092 .12571 m
.76722 .12706 L
s
.78997 .15485 m
.78627 .15618 L
s
.8085 .1832 m
.80479 .18451 L
s
.82653 .21078 m
.82281 .21206 L
s
.86116 .26374 m
.85742 .26499 L
s
.87779 .28919 m
.87406 .29043 L
s
.894 .31399 m
.89026 .3152 L
s
.9098 .33815 m
.90605 .33935 L
s
.73115 .06488 m
.72747 .06627 L
s
.71038 .03311 m
.70671 .03452 L
s
.689 .0004 m
.68533 .00183 L
s
.94023 .38469 m
.93647 .38586 L
s
.95488 .40711 m
.95111 .40826 L
s
.96918 .42898 m
.96541 .43011 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03454 .27166 m
.04066 .26928 L
s
[(0.15)] .02231 .27641 1 -0.38848 Mshowa
.02727 .31757 m
.0334 .31524 L
s
[(0.2)] .015 .32223 1 -0.37986 Mshowa
.01977 .36487 m
.02592 .36259 L
s
[(0.25)] .00747 .36944 1 -0.37096 Mshowa
.01205 .41362 m
.01821 .41139 L
s
[(0.3)] -0.00029 .41808 1 -0.36176 Mshowa
.00408 .46388 m
.01027 .4617 L
s
[(0.35)] -0.0083 .46824 1 -0.35225 Mshowa
.125 Mabswid
.0331 .28073 m
.03678 .27931 L
s
.03166 .28986 m
.03533 .28845 L
s
.0302 .29904 m
.03388 .29763 L
s
.02874 .30828 m
.03242 .30688 L
s
.02578 .32692 m
.02947 .32553 L
s
.02429 .33632 m
.02798 .33494 L
s
.0228 .34578 m
.02648 .3444 L
s
.02129 .3553 m
.02498 .35392 L
s
.01824 .3745 m
.02194 .37314 L
s
.01671 .38419 m
.0204 .38284 L
s
.01516 .39394 m
.01886 .39259 L
s
.01361 .40375 m
.01731 .40241 L
s
.01047 .42355 m
.01418 .42222 L
s
.00889 .43354 m
.01259 .43221 L
s
.0073 .44359 m
.011 .44227 L
s
.00569 .45371 m
.0094 .45239 L
s
.03597 .26263 m
.03964 .2612 L
s
.00246 .47412 m
.00617 .47282 L
s
.00082 .48443 m
.00454 .48313 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .475 .13 r
.39285 .65791 .40403 .63499 .41889 .69075 .40727 .72803 Metetra
.441 .687 0 r
.40727 .72803 .41889 .69075 .43524 .71488 .42364 .75886 Metetra
.77 .767 0 r
.42364 .75886 .43524 .71488 .45242 .71752 .4411 .76289 Metetra
.789 .722 0 r
.4411 .76289 .45242 .71752 .46988 .71375 .4589 .75898 Metetra
.791 .717 0 r
.4589 .75898 .46988 .71375 .48748 .70902 .47684 .75392 Metetra
.79 .718 0 r
.47684 .75392 .48748 .70902 .50519 .70418 .49491 .74877 Metetra
.79 .719 0 r
.49491 .74877 .50519 .70418 .52302 .6993 .51308 .74362 Metetra
.789 .72 0 r
.51308 .74362 .52302 .6993 .54097 .69438 .53138 .73847 Metetra
.789 .721 0 r
.53138 .73847 .54097 .69438 .55903 .68943 .5498 .73332 Metetra
.789 .722 0 r
.5498 .73332 .55903 .68943 .57722 .68444 .56834 .72817 Metetra
.789 .723 0 r
.56834 .72817 .57722 .68444 .59552 .67941 .587 .72299 Metetra
.788 .723 0 r
.587 .72299 .59552 .67941 .61394 .67434 .60579 .71783 Metetra
.788 .724 0 r
.60579 .71783 .61394 .67434 .63249 .66923 .6247 .71265 Metetra
.788 .724 0 r
.6247 .71265 .63249 .66923 .65116 .66409 .64374 .70747 Metetra
.788 .724 0 r
.64374 .70747 .65116 .66409 .66995 .6589 .66292 .70228 Metetra
.788 .724 0 r
.66292 .70228 .66995 .6589 .68888 .65368 .68222 .69709 Metetra
.788 .724 0 r
.68222 .69709 .68888 .65368 .70792 .64842 .70166 .69188 Metetra
.788 .724 0 r
.70166 .69188 .70792 .64842 .7271 .64312 .72124 .68667 Metetra
.788 .724 0 r
.72124 .68667 .7271 .64312 .7464 .63778 .74095 .68145 Metetra
.788 .723 0 r
.74095 .68145 .7464 .63778 .76584 .63239 .76081 .67622 Metetra
.788 .723 0 r
.76081 .67622 .76584 .63239 .78541 .62696 .7808 .67098 Metetra
.789 .722 0 r
.7808 .67098 .78541 .62696 .80511 .6215 .80094 .66573 Metetra
.789 .722 0 r
.80094 .66573 .80511 .6215 .82494 .61598 .82122 .66047 Metetra
.789 .721 0 r
.82122 .66047 .82494 .61598 .84492 .61043 .84165 .65521 Metetra
.79 .72 0 r
.84165 .65521 .84492 .61043 .86502 .60483 .86224 .64995 Metetra
.79 .719 0 r
.86224 .64995 .86502 .60483 .88527 .59919 .88297 .64467 Metetra
.791 .718 0 r
.88297 .64467 .88527 .59919 .90566 .59349 .90386 .63939 Metetra
.791 .718 0 r
.90386 .63939 .90566 .59349 .92616 .58753 .92487 .63383 Metetra
.785 .731 0 r
.92487 .63383 .92616 .58753 .94652 .57929 .9457 .62548 Metetra
.685 .749 0 r
.9457 .62548 .94652 .57929 .96547 .55926 .96477 .60243 Metetra
.225 .622 0 r
.96477 .60243 .96547 .55926 .98036 .50981 .97881 .54261 Metetra
.119 .585 0 r
.38224 .65949 .39285 .65791 .40727 .72803 .39638 .73417 Metetra
.822 .635 0 r
.39638 .73417 .40727 .72803 .42364 .75886 .41273 .76696 Metetra
.914 .341 0 r
.41273 .76696 .42364 .75886 .4411 .76289 .4303 .77126 Metetra
.933 .27 0 r
.4303 .77126 .4411 .76289 .4589 .75898 .44827 .76718 Metetra
.934 .266 0 r
.44827 .76718 .4589 .75898 .47684 .75392 .46638 .7619 Metetra
.933 .271 0 r
.46638 .7619 .47684 .75392 .49491 .74877 .4846 .75656 Metetra
.931 .277 0 r
.4846 .75656 .49491 .74877 .51308 .74362 .50295 .75123 Metetra
.93 .282 0 r
.50295 .75123 .51308 .74362 .53138 .73847 .52141 .74592 Metetra
.929 .286 0 r
.52141 .74592 .53138 .73847 .5498 .73332 .54 .74063 Metetra
.928 .289 0 r
.54 .74063 .5498 .73332 .56834 .72817 .5587 .73534 Metetra
.927 .292 0 r
.5587 .73534 .56834 .72817 .587 .72299 .57754 .73006 Metetra
.927 .295 0 r
.57754 .73006 .587 .72299 .60579 .71783 .5965 .72479 Metetra
.926 .297 0 r
.5965 .72479 .60579 .71783 .6247 .71265 .61559 .71954 Metetra
.926 .298 0 r
.61559 .71954 .6247 .71265 .64374 .70747 .63481 .71429 Metetra
.925 .299 0 r
.63481 .71429 .64374 .70747 .66292 .70228 .65416 .70905 Metetra
.925 .299 0 r
.65416 .70905 .66292 .70228 .68222 .69709 .67365 .70381 Metetra
.925 .299 0 r
.67365 .70381 .68222 .69709 .70166 .69188 .69328 .69858 Metetra
.926 .299 0 r
.69328 .69858 .70166 .69188 .72124 .68667 .71304 .69336 Metetra
.926 .298 0 r
.71304 .69336 .72124 .68667 .74095 .68145 .73295 .68814 Metetra
.926 .296 0 r
.73295 .68814 .74095 .68145 .76081 .67622 .753 .68293 Metetra
.927 .294 0 r
.753 .68293 .76081 .67622 .7808 .67098 .7732 .67773 Metetra
.928 .291 0 r
.7732 .67773 .7808 .67098 .80094 .66573 .79355 .67254 Metetra
.928 .288 0 r
.79355 .67254 .80094 .66573 .82122 .66047 .81404 .66735 Metetra
.929 .284 0 r
.81404 .66735 .82122 .66047 .84165 .65521 .83469 .66217 Metetra
.931 .28 0 r
.83469 .66217 .84165 .65521 .86224 .64995 .8555 .65701 Metetra
.932 .275 0 r
.8555 .65701 .86224 .64995 .88297 .64467 .87647 .65187 Metetra
.933 .269 0 r
.87647 .65187 .88297 .64467 .90386 .63939 .8976 .64673 Metetra
.935 .265 0 r
.8976 .64673 .90386 .63939 .92487 .63383 .91886 .64132 Metetra
.93 .283 0 r
.91886 .64132 .92487 .63383 .9457 .62548 .93994 .63299 Metetra
.891 .42 0 r
.93994 .63299 .9457 .62548 .96477 .60243 .95917 .60909 Metetra
.686 .75 0 r
.95917 .60909 .96477 .60243 .97881 .54261 .97311 .546 Metetra
.21 .617 0 r
.37181 .65244 .38224 .65949 .39638 .73417 .38577 .72774 Metetra
.859 .524 0 r
.38577 .72774 .39638 .73417 .41273 .76696 .40207 .76061 Metetra
.953 .194 0 r
.40207 .76061 .41273 .76696 .4303 .77126 .41971 .76481 Metetra
.972 .117 0 r
.41971 .76481 .4303 .77126 .44827 .76718 .43776 .76063 Metetra
.973 .115 0 r
.43776 .76063 .44827 .76718 .46638 .7619 .45596 .75527 Metetra
.971 .122 0 r
.45596 .75527 .46638 .7619 .4846 .75656 .47428 .74983 Metetra
.969 .13 0 r
.47428 .74983 .4846 .75656 .50295 .75123 .49272 .74442 Metetra
.968 .136 0 r
.49272 .74442 .50295 .75123 .52141 .74592 .51128 .73903 Metetra
.966 .142 0 r
.51128 .73903 .52141 .74592 .54 .74063 .52996 .73366 Metetra
.965 .146 0 r
.52996 .73366 .54 .74063 .5587 .73534 .54876 .7283 Metetra
.964 .151 0 r
.54876 .7283 .5587 .73534 .57754 .73006 .56769 .72294 Metetra
.963 .154 0 r
.56769 .72294 .57754 .73006 .5965 .72479 .58675 .7176 Metetra
.962 .156 0 r
.58675 .7176 .5965 .72479 .61559 .71954 .60594 .71228 Metetra
.962 .158 0 r
.60594 .71228 .61559 .71954 .63481 .71429 .62527 .70696 Metetra
.962 .16 0 r
.62527 .70696 .63481 .71429 .65416 .70905 .64472 .70165 Metetra
.962 .16 0 r
.64472 .70165 .65416 .70905 .67365 .70381 .66432 .69635 Metetra
.962 .16 0 r
.66432 .69635 .67365 .70381 .69328 .69858 .68405 .69106 Metetra
.962 .159 0 r
.68405 .69106 .69328 .69858 .71304 .69336 .70392 .68578 Metetra
.962 .158 0 r
.70392 .68578 .71304 .69336 .73295 .68814 .72394 .6805 Metetra
.963 .155 0 r
.72394 .6805 .73295 .68814 .753 .68293 .74411 .67524 Metetra
.963 .153 0 r
.74411 .67524 .753 .68293 .7732 .67773 .76442 .66998 Metetra
.964 .149 0 r
.76442 .66998 .7732 .67773 .79355 .67254 .78488 .66474 Metetra
.965 .145 0 r
.78488 .66474 .79355 .67254 .81404 .66735 .8055 .65951 Metetra
.967 .139 0 r
.8055 .65951 .81404 .66735 .83469 .66217 .82627 .65429 Metetra
.968 .134 0 r
.82627 .65429 .83469 .66217 .8555 .65701 .8472 .64908 Metetra
.97 .127 0 r
.8472 .64908 .8555 .65701 .87647 .65187 .8683 .6439 Metetra
.972 .119 0 r
.8683 .6439 .87647 .65187 .8976 .64673 .88956 .63872 Metetra
.973 .113 0 r
.88956 .63872 .8976 .64673 .91886 .64132 .91095 .63329 Metetra
.969 .13 0 r
.91095 .63329 .91886 .64132 .93994 .63299 .93217 .62493 Metetra
.93 .282 0 r
.93217 .62493 .93994 .63299 .95917 .60909 .95157 .60096 Metetra
.785 .73 0 r
.95157 .60096 .95917 .60909 .97311 .546 .96571 .53747 Metetra
.226 .622 0 r
.36133 .64362 .37181 .65244 .38577 .72774 .37511 .71881 Metetra
.864 .508 0 r
.37511 .71881 .38577 .72774 .40207 .76061 .39138 .75145 Metetra
.957 .177 0 r
.39138 .75145 .40207 .76061 .41971 .76481 .40906 .75551 Metetra
.977 .099 0 r
.40906 .75551 .41971 .76481 .43776 .76063 .42719 .75126 Metetra
.977 .098 0 r
.42719 .75126 .43776 .76063 .45596 .75527 .44547 .74584 Metetra
.975 .105 0 r
.44547 .74584 .45596 .75527 .47428 .74983 .46386 .74035 Metetra
.973 .113 0 r
.46386 .74035 .47428 .74983 .49272 .74442 .48238 .73488 Metetra
.972 .12 0 r
.48238 .73488 .49272 .74442 .51128 .73903 .50102 .72943 Metetra
.97 .125 0 r
.50102 .72943 .51128 .73903 .52996 .73366 .51978 .72399 Metetra
.969 .13 0 r
.51978 .72399 .52996 .73366 .54876 .7283 .53867 .71857 Metetra
.968 .135 0 r
.53867 .71857 .54876 .7283 .56769 .72294 .55769 .71314 Metetra
.967 .138 0 r
.55769 .71314 .56769 .72294 .58675 .7176 .57683 .70774 Metetra
.966 .141 0 r
.57683 .70774 .58675 .7176 .60594 .71228 .59611 .70235 Metetra
.966 .143 0 r
.59611 .70235 .60594 .71228 .62527 .70696 .61552 .69697 Metetra
.966 .144 0 r
.61552 .69697 .62527 .70696 .64472 .70165 .63507 .69159 Metetra
.965 .145 0 r
.63507 .69159 .64472 .70165 .66432 .69635 .65476 .68623 Metetra
.965 .144 0 r
.65476 .68623 .66432 .69635 .68405 .69106 .67458 .68086 Metetra
.966 .144 0 r
.67458 .68086 .68405 .69106 .70392 .68578 .69455 .67551 Metetra
.966 .142 0 r
.69455 .67551 .70392 .68578 .72394 .6805 .71466 .67016 Metetra
.967 .14 0 r
.71466 .67016 .72394 .6805 .74411 .67524 .73493 .66482 Metetra
.967 .137 0 r
.73493 .66482 .74411 .67524 .76442 .66998 .75534 .65949 Metetra
.968 .133 0 r
.75534 .65949 .76442 .66998 .78488 .66474 .7759 .65417 Metetra
.969 .129 0 r
.7759 .65417 .78488 .66474 .8055 .65951 .79662 .64886 Metetra
.971 .123 0 r
.79662 .64886 .8055 .65951 .82627 .65429 .81749 .64356 Metetra
.972 .117 0 r
.81749 .64356 .82627 .65429 .8472 .64908 .83853 .63828 Metetra
.974 .11 0 r
.83853 .63828 .8472 .64908 .8683 .6439 .85973 .63301 Metetra
.976 .102 0 r
.85973 .63301 .8683 .6439 .88956 .63872 .8811 .62775 Metetra
.977 .096 0 r
.8811 .62775 .88956 .63872 .91095 .63329 .90261 .62224 Metetra
.973 .113 0 r
.90261 .62224 .91095 .63329 .93217 .62493 .92394 .61384 Metetra
.935 .265 0 r
.92394 .61384 .93217 .62493 .95157 .60096 .94351 .58991 Metetra
.791 .717 0 r
.94351 .58991 .95157 .60096 .96571 .53747 .9579 .52652 Metetra
.229 .623 0 r
.35073 .63451 .36133 .64362 .37511 .71881 .36433 .70956 Metetra
.864 .51 0 r
.36433 .70956 .37511 .71881 .39138 .75145 .38056 .74195 Metetra
.956 .182 0 r
.38056 .74195 .39138 .75145 .40906 .75551 .39829 .74589 Metetra
.975 .106 0 r
.39829 .74589 .40906 .75551 .42719 .75126 .41649 .74157 Metetra
.975 .104 0 r
.41649 .74157 .42719 .75126 .44547 .74584 .43484 .73609 Metetra
.973 .112 0 r
.43484 .73609 .44547 .74584 .46386 .74035 .45332 .73054 Metetra
.972 .119 0 r
.45332 .73054 .46386 .74035 .48238 .73488 .47192 .72501 Metetra
.97 .126 0 r
.47192 .72501 .48238 .73488 .50102 .72943 .49064 .7195 Metetra
.969 .131 0 r
.49064 .7195 .50102 .72943 .51978 .72399 .50948 .71401 Metetra
.967 .136 0 r
.50948 .71401 .51978 .72399 .53867 .71857 .52845 .70852 Metetra
.966 .14 0 r
.52845 .70852 .53867 .71857 .55769 .71314 .54755 .70304 Metetra
.966 .144 0 r
.54755 .70304 .55769 .71314 .57683 .70774 .56679 .69757 Metetra
.965 .147 0 r
.56679 .69757 .57683 .70774 .59611 .70235 .58615 .69211 Metetra
.964 .148 0 r
.58615 .69211 .59611 .70235 .61552 .69697 .60565 .68666 Metetra
.964 .15 0 r
.60565 .68666 .61552 .69697 .63507 .69159 .62529 .68122 Metetra
.964 .15 0 r
.62529 .68122 .63507 .69159 .65476 .68623 .64506 .67577 Metetra
.964 .15 0 r
.64506 .67577 .65476 .68623 .67458 .68086 .66498 .67034 Metetra
.964 .149 0 r
.66498 .67034 .67458 .68086 .69455 .67551 .68505 .66491 Metetra
.965 .148 0 r
.68505 .66491 .69455 .67551 .71466 .67016 .70526 .65949 Metetra
.965 .146 0 r
.70526 .65949 .71466 .67016 .73493 .66482 .72561 .65407 Metetra
.966 .143 0 r
.72561 .65407 .73493 .66482 .75534 .65949 .74612 .64866 Metetra
.967 .139 0 r
.74612 .64866 .75534 .65949 .7759 .65417 .76679 .64327 Metetra
.968 .135 0 r
.76679 .64327 .7759 .65417 .79662 .64886 .78761 .63788 Metetra
.969 .129 0 r
.78761 .63788 .79662 .64886 .81749 .64356 .80859 .6325 Metetra
.971 .123 0 r
.80859 .6325 .81749 .64356 .83853 .63828 .82973 .62713 Metetra
.972 .116 0 r
.82973 .62713 .83853 .63828 .85973 .63301 .85103 .62177 Metetra
.974 .109 0 r
.85103 .62177 .85973 .63301 .8811 .62775 .87251 .61642 Metetra
.976 .102 0 r
.87251 .61642 .8811 .62775 .90261 .62224 .89412 .61082 Metetra
.972 .119 0 r
.89412 .61082 .90261 .62224 .92394 .61384 .91558 .60236 Metetra
.933 .269 0 r
.91558 .60236 .92394 .61384 .94351 .58991 .93531 .57848 Metetra
.791 .717 0 r
.93531 .57848 .94351 .58991 .9579 .52652 .94996 .51519 Metetra
.23 .624 0 r
.34 .62525 .35073 .63451 .36433 .70956 .35341 .70018 Metetra
.863 .513 0 r
.35341 .70018 .36433 .70956 .38056 .74195 .3696 .73238 Metetra
.954 .189 0 r
.3696 .73238 .38056 .74195 .39829 .74589 .38739 .73619 Metetra
.973 .114 0 r
.38739 .73619 .39829 .74589 .41649 .74157 .40566 .7318 Metetra
.973 .112 0 r
.40566 .7318 .41649 .74157 .43484 .73609 .42409 .72626 Metetra
.972 .119 0 r
.42409 .72626 .43484 .73609 .45332 .73054 .44264 .72066 Metetra
.97 .127 0 r
.44264 .72066 .45332 .73054 .47192 .72501 .46132 .71507 Metetra
.968 .133 0 r
.46132 .71507 .47192 .72501 .49064 .7195 .48012 .7095 Metetra
.967 .139 0 r
.48012 .7095 .49064 .7195 .50948 .71401 .49905 .70394 Metetra
.966 .143 0 r
.49905 .70394 .50948 .71401 .52845 .70852 .51811 .69839 Metetra
.965 .147 0 r
.51811 .69839 .52845 .70852 .54755 .70304 .53729 .69284 Metetra
.964 .151 0 r
.53729 .69284 .54755 .70304 .56679 .69757 .55661 .6873 Metetra
.963 .153 0 r
.55661 .6873 .56679 .69757 .58615 .69211 .57606 .68178 Metetra
.963 .155 0 r
.57606 .68178 .58615 .69211 .60565 .68666 .59565 .67626 Metetra
.962 .157 0 r
.59565 .67626 .60565 .68666 .62529 .68122 .61538 .67074 Metetra
.962 .157 0 r
.61538 .67074 .62529 .68122 .64506 .67577 .63525 .66523 Metetra
.962 .157 0 r
.63525 .66523 .64506 .67577 .66498 .67034 .65526 .65972 Metetra
.963 .156 0 r
.65526 .65972 .66498 .67034 .68505 .66491 .67542 .65422 Metetra
.963 .155 0 r
.67542 .65422 .68505 .66491 .70526 .65949 .69573 .64872 Metetra
.963 .153 0 r
.69573 .64872 .70526 .65949 .72561 .65407 .71618 .64322 Metetra
.964 .15 0 r
.71618 .64322 .72561 .65407 .74612 .64866 .73679 .63773 Metetra
.965 .146 0 r
.73679 .63773 .74612 .64866 .76679 .64327 .75755 .63225 Metetra
.966 .142 0 r
.75755 .63225 .76679 .64327 .78761 .63788 .77848 .62678 Metetra
.967 .137 0 r
.77848 .62678 .78761 .63788 .80859 .6325 .79956 .62132 Metetra
.969 .131 0 r
.79956 .62132 .80859 .6325 .82973 .62713 .82081 .61587 Metetra
.971 .124 0 r
.82081 .61587 .82973 .62713 .85103 .62177 .84222 .61043 Metetra
.972 .117 0 r
.84222 .61043 .85103 .62177 .87251 .61642 .8638 .60499 Metetra
.974 .11 0 r
.8638 .60499 .87251 .61642 .89412 .61082 .88553 .5993 Metetra
.97 .127 0 r
.88553 .5993 .89412 .61082 .91558 .60236 .90711 .59078 Metetra
.932 .275 0 r
.90711 .59078 .91558 .60236 .93531 .57848 .92701 .56691 Metetra
.79 .719 0 r
.92701 .56691 .93531 .57848 .94996 .51519 .9419 .50369 Metetra
.231 .624 0 r
.32914 .61585 .34 .62525 .35341 .70018 .34236 .6907 Metetra
.862 .516 0 r
.34236 .6907 .35341 .70018 .3696 .73238 .35851 .72273 Metetra
.953 .195 0 r
.35851 .72273 .3696 .73238 .38739 .73619 .37634 .72642 Metetra
.971 .121 0 r
.37634 .72642 .38739 .73619 .40566 .7318 .39469 .72196 Metetra
.972 .119 0 r
.39469 .72196 .40566 .7318 .42409 .72626 .4132 .71637 Metetra
.97 .126 0 r
.4132 .71637 .42409 .72626 .44264 .72066 .43183 .7107 Metetra
.968 .133 0 r
.43183 .7107 .44264 .72066 .46132 .71507 .45059 .70505 Metetra
.967 .14 0 r
.45059 .70505 .46132 .71507 .48012 .7095 .46948 .69942 Metetra
.965 .145 0 r
.46948 .69942 .48012 .7095 .49905 .70394 .48849 .69379 Metetra
.964 .15 0 r
.48849 .69379 .49905 .70394 .51811 .69839 .50763 .68818 Metetra
.963 .154 0 r
.50763 .68818 .51811 .69839 .53729 .69284 .5269 .68256 Metetra
.962 .157 0 r
.5269 .68256 .53729 .69284 .55661 .6873 .54631 .67696 Metetra
.962 .16 0 r
.54631 .67696 .55661 .6873 .57606 .68178 .56585 .67137 Metetra
.961 .161 0 r
.56585 .67137 .57606 .68178 .59565 .67626 .58553 .66578 Metetra
.961 .163 0 r
.58553 .66578 .59565 .67626 .61538 .67074 .60535 .66019 Metetra
.961 .163 0 r
.60535 .66019 .61538 .67074 .63525 .66523 .62531 .6546 Metetra
.961 .163 0 r
.62531 .6546 .63525 .66523 .65526 .65972 .64542 .64902 Metetra
.961 .162 0 r
.64542 .64902 .65526 .65972 .67542 .65422 .66567 .64344 Metetra
.961 .161 0 r
.66567 .64344 .67542 .65422 .69573 .64872 .68607 .63786 Metetra
.962 .159 0 r
.68607 .63786 .69573 .64872 .71618 .64322 .70663 .63229 Metetra
.963 .156 0 r
.70663 .63229 .71618 .64322 .73679 .63773 .72734 .62672 Metetra
.963 .152 0 r
.72734 .62672 .73679 .63773 .75755 .63225 .74821 .62115 Metetra
.965 .148 0 r
.74821 .62115 .75755 .63225 .77848 .62678 .76923 .6156 Metetra
.966 .143 0 r
.76923 .6156 .77848 .62678 .79956 .62132 .79042 .61005 Metetra
.967 .137 0 r
.79042 .61005 .79956 .62132 .82081 .61587 .81178 .60452 Metetra
.969 .131 0 r
.81178 .60452 .82081 .61587 .84222 .61043 .8333 .59899 Metetra
.971 .123 0 r
.8333 .59899 .84222 .61043 .8638 .60499 .85499 .59346 Metetra
.972 .117 0 r
.85499 .59346 .8638 .60499 .88553 .5993 .87683 .58769 Metetra
.968 .134 0 r
.87683 .58769 .88553 .5993 .90711 .59078 .89854 .5791 Metetra
.931 .28 0 r
.89854 .5791 .90711 .59078 .92701 .56691 .9186 .55523 Metetra
.79 .72 0 r
.9186 .55523 .92701 .56691 .9419 .50369 .93374 .49203 Metetra
.231 .624 0 r
.31815 .60631 .32914 .61585 .34236 .6907 .33118 .68112 Metetra
.861 .518 0 r
.33118 .68112 .34236 .6907 .35851 .72273 .34728 .713 Metetra
.951 .2 0 r
.34728 .713 .35851 .72273 .37634 .72642 .36516 .71659 Metetra
.97 .127 0 r
.36516 .71659 .37634 .72642 .39469 .72196 .38358 .71206 Metetra
.97 .125 0 r
.38358 .71206 .39469 .72196 .4132 .71637 .40217 .7064 Metetra
.968 .132 0 r
.40217 .7064 .4132 .71637 .43183 .7107 .42089 .70067 Metetra
.967 .139 0 r
.42089 .70067 .43183 .7107 .45059 .70505 .43973 .69496 Metetra
.965 .145 0 r
.43973 .69496 .45059 .70505 .46948 .69942 .45869 .68926 Metetra
.964 .151 0 r
.45869 .68926 .46948 .69942 .48849 .69379 .47779 .68357 Metetra
.963 .155 0 r
.47779 .68357 .48849 .69379 .50763 .68818 .49702 .67789 Metetra
.962 .159 0 r
.49702 .67789 .50763 .68818 .5269 .68256 .51637 .6722 Metetra
.961 .162 0 r
.51637 .6722 .5269 .68256 .54631 .67696 .53587 .66653 Metetra
.96 .165 0 r
.53587 .66653 .54631 .67696 .56585 .67137 .5555 .66087 Metetra
.96 .167 0 r
.5555 .66087 .56585 .67137 .58553 .66578 .57527 .65521 Metetra
.96 .168 0 r
.57527 .65521 .58553 .66578 .60535 .66019 .59518 .64955 Metetra
.96 .168 0 r
.59518 .64955 .60535 .66019 .62531 .6546 .61524 .64389 Metetra
.96 .168 0 r
.61524 .64389 .62531 .6546 .64542 .64902 .63544 .63823 Metetra
.96 .167 0 r
.63544 .63823 .64542 .64902 .66567 .64344 .6558 .63257 Metetra
.96 .166 0 r
.6558 .63257 .66567 .64344 .68607 .63786 .6763 .62692 Metetra
.961 .164 0 r
.6763 .62692 .68607 .63786 .70663 .63229 .69695 .62126 Metetra
.961 .161 0 r
.69695 .62126 .70663 .63229 .72734 .62672 .71776 .61561 Metetra
.962 .158 0 r
.71776 .61561 .72734 .62672 .74821 .62115 .73873 .60996 Metetra
.963 .154 0 r
.73873 .60996 .74821 .62115 .76923 .6156 .75987 .60431 Metetra
.964 .149 0 r
.75987 .60431 .76923 .6156 .79042 .61005 .78116 .59868 Metetra
.966 .143 0 r
.78116 .59868 .79042 .61005 .81178 .60452 .80262 .59306 Metetra
.967 .137 0 r
.80262 .59306 .81178 .60452 .8333 .59899 .82426 .58745 Metetra
.969 .129 0 r
.82426 .58745 .8333 .59899 .85499 .59346 .84606 .58183 Metetra
.971 .123 0 r
.84606 .58183 .85499 .59346 .87683 .58769 .86802 .57597 Metetra
.967 .14 0 r
.86802 .57597 .87683 .58769 .89854 .5791 .88985 .5673 Metetra
.929 .284 0 r
.88985 .5673 .89854 .5791 .9186 .55523 .91007 .54341 Metetra
.789 .721 0 r
.91007 .54341 .9186 .55523 .93374 .49203 .92546 .48021 Metetra
.232 .624 0 r
.30703 .59663 .31815 .60631 .33118 .68112 .31985 .67142 Metetra
.86 .52 0 r
.31985 .67142 .33118 .68112 .34728 .713 .33591 .70318 Metetra
.95 .205 0 r
.33591 .70318 .34728 .713 .36516 .71659 .35383 .70668 Metetra
.969 .132 0 r
.35383 .70668 .36516 .71659 .38358 .71206 .37233 .70208 Metetra
.969 .13 0 r
.37233 .70208 .38358 .71206 .40217 .7064 .391 .69636 Metetra
.967 .137 0 r
.391 .69636 .40217 .7064 .42089 .70067 .4098 .69056 Metetra
.966 .144 0 r
.4098 .69056 .42089 .70067 .43973 .69496 .42872 .68479 Metetra
.964 .15 0 r
.42872 .68479 .43973 .69496 .45869 .68926 .44777 .67902 Metetra
.963 .156 0 r
.44777 .67902 .45869 .68926 .47779 .68357 .46695 .67327 Metetra
.962 .16 0 r
.46695 .67327 .47779 .68357 .49702 .67789 .48626 .66752 Metetra
.961 .164 0 r
.48626 .66752 .49702 .67789 .51637 .6722 .50571 .66176 Metetra
.96 .167 0 r
.50571 .66176 .51637 .6722 .53587 .66653 .5253 .65602 Metetra
.959 .17 0 r
.5253 .65602 .53587 .66653 .5555 .66087 .54502 .65028 Metetra
.959 .171 0 r
.54502 .65028 .5555 .66087 .57527 .65521 .56488 .64455 Metetra
.958 .172 0 r
.56488 .64455 .57527 .65521 .59518 .64955 .58489 .63881 Metetra
.958 .173 0 r
.58489 .63881 .59518 .64955 .61524 .64389 .60504 .63308 Metetra
.958 .173 0 r
.60504 .63308 .61524 .64389 .63544 .63823 .62534 .62734 Metetra
.959 .172 0 r
.62534 .62734 .63544 .63823 .6558 .63257 .64579 .6216 Metetra
.959 .171 0 r
.64579 .6216 .6558 .63257 .6763 .62692 .66639 .61587 Metetra
.959 .169 0 r
.66639 .61587 .6763 .62692 .69695 .62126 .68715 .61013 Metetra
.96 .166 0 r
.68715 .61013 .69695 .62126 .71776 .61561 .70806 .6044 Metetra
.961 .163 0 r
.70806 .6044 .71776 .61561 .73873 .60996 .72914 .59866 Metetra
.962 .159 0 r
.72914 .59866 .73873 .60996 .75987 .60431 .75038 .59293 Metetra
.963 .154 0 r
.75038 .59293 .75987 .60431 .78116 .59868 .77178 .58721 Metetra
.965 .148 0 r
.77178 .58721 .78116 .59868 .80262 .59306 .79335 .5815 Metetra
.966 .142 0 r
.79335 .5815 .80262 .59306 .82426 .58745 .8151 .5758 Metetra
.968 .135 0 r
.8151 .5758 .82426 .58745 .84606 .58183 .83702 .5701 Metetra
.969 .129 0 r
.83702 .5701 .84606 .58183 .86802 .57597 .85909 .56414 Metetra
.965 .145 0 r
.85909 .56414 .86802 .57597 .88985 .5673 .88104 .5554 Metetra
.928 .288 0 r
.88104 .5554 .88985 .5673 .91007 .54341 .90143 .53147 Metetra
.789 .722 0 r
.90143 .53147 .91007 .54341 .92546 .48021 .91707 .46821 Metetra
.233 .624 0 r
.29577 .58681 .30703 .59663 .31985 .67142 .30838 .66162 Metetra
.86 .522 0 r
.30838 .66162 .31985 .67142 .33591 .70318 .32439 .69329 Metetra
.949 .208 0 r
.32439 .69329 .33591 .70318 .35383 .70668 .34236 .69669 Metetra
.967 .137 0 r
.34236 .69669 .35383 .70668 .37233 .70208 .36093 .69202 Metetra
.968 .135 0 r
.36093 .69202 .37233 .70208 .391 .69636 .37968 .68623 Metetra
.966 .142 0 r
.37968 .68623 .391 .69636 .4098 .69056 .39856 .68038 Metetra
.964 .149 0 r
.39856 .68038 .4098 .69056 .42872 .68479 .41757 .67453 Metetra
.963 .155 0 r
.41757 .67453 .42872 .68479 .44777 .67902 .43671 .6687 Metetra
.962 .16 0 r
.43671 .6687 .44777 .67902 .46695 .67327 .45597 .66287 Metetra
.961 .164 0 r
.45597 .66287 .46695 .67327 .48626 .66752 .47537 .65705 Metetra
.96 .168 0 r
.47537 .65705 .48626 .66752 .50571 .66176 .49491 .65123 Metetra
.959 .171 0 r
.49491 .65123 .50571 .66176 .5253 .65602 .51458 .64541 Metetra
.958 .173 0 r
.51458 .64541 .5253 .65602 .54502 .65028 .5344 .6396 Metetra
.958 .175 0 r
.5344 .6396 .54502 .65028 .56488 .64455 .55436 .63379 Metetra
.958 .176 0 r
.55436 .63379 .56488 .64455 .58489 .63881 .57446 .62798 Metetra
.957 .177 0 r
.57446 .62798 .58489 .63881 .60504 .63308 .59471 .62217 Metetra
.957 .177 0 r
.59471 .62217 .60504 .63308 .62534 .62734 .6151 .61635 Metetra
.958 .176 0 r
.6151 .61635 .62534 .62734 .64579 .6216 .63565 .61054 Metetra
.958 .175 0 r
.63565 .61054 .64579 .6216 .66639 .61587 .65636 .60472 Metetra
.958 .173 0 r
.65636 .60472 .66639 .61587 .68715 .61013 .67721 .5989 Metetra
.959 .17 0 r
.67721 .5989 .68715 .61013 .70806 .6044 .69823 .59308 Metetra
.96 .167 0 r
.69823 .59308 .70806 .6044 .72914 .59866 .71941 .58726 Metetra
.961 .163 0 r
.71941 .58726 .72914 .59866 .75038 .59293 .74076 .58145 Metetra
.962 .158 0 r
.74076 .58145 .75038 .59293 .77178 .58721 .76227 .57563 Metetra
.963 .152 0 r
.76227 .57563 .77178 .58721 .79335 .5815 .78396 .56983 Metetra
.965 .146 0 r
.78396 .56983 .79335 .5815 .8151 .5758 .80582 .56404 Metetra
.967 .139 0 r
.80582 .56404 .8151 .5758 .83702 .5701 .82785 .55825 Metetra
.968 .133 0 r
.82785 .55825 .83702 .5701 .85909 .56414 .85004 .5522 Metetra
.964 .149 0 r
.85004 .5522 .85909 .56414 .88104 .5554 .87212 .54338 Metetra
.928 .291 0 r
.87212 .54338 .88104 .5554 .90143 .53147 .89268 .51939 Metetra
.789 .722 0 r
.89268 .51939 .90143 .53147 .91707 .46821 .90856 .45605 Metetra
.233 .625 0 r
.28438 .57683 .29577 .58681 .30838 .66162 .29677 .6517 Metetra
.859 .523 0 r
.29677 .6517 .30838 .66162 .32439 .69329 .31272 .6833 Metetra
.949 .212 0 r
.31272 .6833 .32439 .69329 .34236 .69669 .33074 .68663 Metetra
.967 .14 0 r
.33074 .68663 .34236 .69669 .36093 .69202 .34939 .68189 Metetra
.967 .139 0 r
.34939 .68189 .36093 .69202 .37968 .68623 .36822 .67603 Metetra
.965 .145 0 r
.36822 .67603 .37968 .68623 .39856 .68038 .38718 .6701 Metetra
.964 .152 0 r
.38718 .6701 .39856 .68038 .41757 .67453 .40627 .66419 Metetra
.962 .158 0 r
.40627 .66419 .41757 .67453 .43671 .6687 .42549 .65829 Metetra
.961 .163 0 r
.42549 .65829 .43671 .6687 .45597 .66287 .44485 .65239 Metetra
.96 .167 0 r
.44485 .65239 .45597 .66287 .47537 .65705 .46434 .6465 Metetra
.959 .171 0 r
.46434 .6465 .47537 .65705 .49491 .65123 .48397 .6406 Metetra
.958 .174 0 r
.48397 .6406 .49491 .65123 .51458 .64541 .50373 .63471 Metetra
.957 .177 0 r
.50373 .63471 .51458 .64541 .5344 .6396 .52364 .62882 Metetra
.957 .178 0 r
.52364 .62882 .5344 .6396 .55436 .63379 .54369 .62294 Metetra
.957 .179 0 r
.54369 .62294 .55436 .63379 .57446 .62798 .56389 .61705 Metetra
.957 .18 0 r
.56389 .61705 .57446 .62798 .59471 .62217 .58423 .61115 Metetra
.957 .18 0 r
.58423 .61115 .59471 .62217 .6151 .61635 .60473 .60526 Metetra
.957 .179 0 r
.60473 .60526 .6151 .61635 .63565 .61054 .62538 .59936 Metetra
.957 .178 0 r
.62538 .59936 .63565 .61054 .65636 .60472 .64618 .59346 Metetra
.958 .176 0 r
.64618 .59346 .65636 .60472 .67721 .5989 .66715 .58756 Metetra
.958 .173 0 r
.66715 .58756 .67721 .5989 .69823 .59308 .68827 .58165 Metetra
.959 .17 0 r
.68827 .58165 .69823 .59308 .71941 .58726 .70956 .57575 Metetra
.96 .166 0 r
.70956 .57575 .71941 .58726 .74076 .58145 .73101 .56985 Metetra
.961 .161 0 r
.73101 .56985 .74076 .58145 .76227 .57563 .75264 .56395 Metetra
.963 .156 0 r
.75264 .56395 .76227 .57563 .78396 .56983 .77444 .55805 Metetra
.964 .15 0 r
.77444 .55805 .78396 .56983 .80582 .56404 .79641 .55217 Metetra
.966 .143 0 r
.79641 .55217 .80582 .56404 .82785 .55825 .81856 .54628 Metetra
.967 .137 0 r
.81856 .54628 .82785 .55825 .85004 .5522 .84087 .54014 Metetra
.963 .153 0 r
.84087 .54014 .85004 .5522 .87212 .54338 .86308 .53124 Metetra
.927 .294 0 r
.86308 .53124 .87212 .54338 .89268 .51939 .8838 .50717 Metetra
.788 .723 0 r
.8838 .50717 .89268 .51939 .90856 .45605 .89993 .4437 Metetra
.233 .625 0 r
.27284 .56671 .28438 .57683 .29677 .6517 .285 .64166 Metetra
.859 .525 0 r
.285 .64166 .29677 .6517 .31272 .6833 .30089 .67322 Metetra
.948 .214 0 r
.30089 .67322 .31272 .6833 .33074 .68663 .31896 .67648 Metetra
.966 .143 0 r
.31896 .67648 .33074 .68663 .34939 .68189 .33769 .67167 Metetra
.966 .142 0 r
.33769 .67167 .34939 .68189 .36822 .67603 .3566 .66574 Metetra
.965 .148 0 r
.3566 .66574 .36822 .67603 .38718 .6701 .37565 .65974 Metetra
.963 .155 0 r
.37565 .65974 .38718 .6701 .40627 .66419 .39483 .65376 Metetra
.961 .161 0 r
.39483 .65376 .40627 .66419 .42549 .65829 .41414 .64779 Metetra
.96 .166 0 r
.41414 .64779 .42549 .65829 .44485 .65239 .43358 .64182 Metetra
.959 .17 0 r
.43358 .64182 .44485 .65239 .46434 .6465 .45316 .63585 Metetra
.958 .174 0 r
.45316 .63585 .46434 .6465 .48397 .6406 .47287 .62987 Metetra
.957 .177 0 r
.47287 .62987 .48397 .6406 .50373 .63471 .49273 .62391 Metetra
.957 .179 0 r
.49273 .62391 .50373 .63471 .52364 .62882 .51273 .61794 Metetra
.956 .181 0 r
.51273 .61794 .52364 .62882 .54369 .62294 .53288 .61198 Metetra
.956 .182 0 r
.53288 .61198 .54369 .62294 .56389 .61705 .55317 .60601 Metetra
.956 .182 0 r
.55317 .60601 .56389 .61705 .58423 .61115 .57362 .60003 Metetra
.956 .182 0 r
.57362 .60003 .58423 .61115 .60473 .60526 .59421 .59406 Metetra
.956 .182 0 r
.59421 .59406 .60473 .60526 .62538 .59936 .61497 .58808 Metetra
.957 .18 0 r
.61497 .58808 .62538 .59936 .64618 .59346 .63587 .58209 Metetra
.957 .178 0 r
.63587 .58209 .64618 .59346 .66715 .58756 .65694 .57611 Metetra
.958 .176 0 r
.65694 .57611 .66715 .58756 .68827 .58165 .67817 .57012 Metetra
.958 .173 0 r
.67817 .57012 .68827 .58165 .70956 .57575 .69957 .56412 Metetra
.959 .169 0 r
.69957 .56412 .70956 .57575 .73101 .56985 .72114 .55813 Metetra
.961 .164 0 r
.72114 .55813 .73101 .56985 .75264 .56395 .74287 .55214 Metetra
.962 .159 0 r
.74287 .55214 .75264 .56395 .77444 .55805 .76478 .54615 Metetra
.963 .153 0 r
.76478 .54615 .77444 .55805 .79641 .55217 .78687 .54018 Metetra
.965 .146 0 r
.78687 .54018 .79641 .55217 .81856 .54628 .80914 .5342 Metetra
.967 .14 0 r
.80914 .5342 .81856 .54628 .84087 .54014 .83157 .52797 Metetra
.963 .156 0 r
.83157 .52797 .84087 .54014 .86308 .53124 .85391 .51897 Metetra
.926 .296 0 r
.85391 .51897 .86308 .53124 .8838 .50717 .8748 .4948 Metetra
.788 .723 0 r
.8748 .4948 .8838 .50717 .89993 .4437 .89118 .43118 Metetra
.234 .625 0 r
.26116 .55644 .27284 .56671 .285 .64166 .27309 .63149 Metetra
.859 .525 0 r
.27309 .63149 .285 .64166 .30089 .67322 .28892 .66305 Metetra
.947 .216 0 r
.28892 .66305 .30089 .67322 .31896 .67648 .30703 .66624 Metetra
.965 .146 0 r
.30703 .66624 .31896 .67648 .33769 .67167 .32583 .66136 Metetra
.966 .144 0 r
.32583 .66136 .33769 .67167 .3566 .66574 .34483 .65536 Metetra
.964 .151 0 r
.34483 .65536 .3566 .66574 .37565 .65974 .36397 .64929 Metetra
.962 .157 0 r
.36397 .64929 .37565 .65974 .39483 .65376 .38323 .64324 Metetra
.961 .163 0 r
.38323 .64324 .39483 .65376 .41414 .64779 .40262 .63719 Metetra
.96 .168 0 r
.40262 .63719 .41414 .64779 .43358 .64182 .42216 .63114 Metetra
.959 .172 0 r
.42216 .63114 .43358 .64182 .45316 .63585 .44182 .6251 Metetra
.958 .176 0 r
.44182 .6251 .45316 .63585 .47287 .62987 .46163 .61904 Metetra
.957 .179 0 r
.46163 .61904 .47287 .62987 .49273 .62391 .48158 .613 Metetra
.956 .181 0 r
.48158 .613 .49273 .62391 .51273 .61794 .50168 .60696 Metetra
.956 .183 0 r
.50168 .60696 .51273 .61794 .53288 .61198 .52192 .60091 Metetra
.956 .184 0 r
.52192 .60091 .53288 .61198 .55317 .60601 .54231 .59486 Metetra
.955 .184 0 r
.54231 .59486 .55317 .60601 .57362 .60003 .56286 .5888 Metetra
.956 .184 0 r
.56286 .5888 .57362 .60003 .59421 .59406 .58356 .58274 Metetra
.956 .184 0 r
.58356 .58274 .59421 .59406 .61497 .58808 .60441 .57668 Metetra
.956 .182 0 r
.60441 .57668 .61497 .58808 .63587 .58209 .62542 .57061 Metetra
.957 .18 0 r
.62542 .57061 .63587 .58209 .65694 .57611 .6466 .56454 Metetra
.957 .178 0 r
.6466 .56454 .65694 .57611 .67817 .57012 .66794 .55846 Metetra
.958 .175 0 r
.66794 .55846 .67817 .57012 .69957 .56412 .68944 .55238 Metetra
.959 .171 0 r
.68944 .55238 .69957 .56412 .72114 .55813 .71112 .5463 Metetra
.96 .166 0 r
.71112 .5463 .72114 .55813 .74287 .55214 .73297 .54022 Metetra
.961 .161 0 r
.73297 .54022 .74287 .55214 .76478 .54615 .755 .53414 Metetra
.963 .155 0 r
.755 .53414 .76478 .54615 .78687 .54018 .7772 .52807 Metetra
.965 .148 0 r
.7772 .52807 .78687 .54018 .80914 .5342 .79959 .52199 Metetra
.966 .142 0 r
.79959 .52199 .80914 .5342 .83157 .52797 .82214 .51566 Metetra
.962 .158 0 r
.82214 .51566 .83157 .52797 .85391 .51897 .84462 .50657 Metetra
.926 .298 0 r
.84462 .50657 .85391 .51897 .8748 .4948 .86567 .48229 Metetra
.788 .724 0 r
.86567 .48229 .8748 .4948 .89118 .43118 .8823 .41847 Metetra
.234 .625 0 r
.24933 .54602 .26116 .55644 .27309 .63149 .26102 .62121 Metetra
.859 .526 0 r
.26102 .62121 .27309 .63149 .28892 .66305 .27678 .65278 Metetra
.947 .217 0 r
.27678 .65278 .28892 .66305 .30703 .66624 .29494 .65592 Metetra
.965 .147 0 r
.29494 .65592 .30703 .66624 .32583 .66136 .31382 .65096 Metetra
.965 .145 0 r
.31382 .65096 .32583 .66136 .34483 .65536 .33291 .64489 Metetra
.964 .152 0 r
.33291 .64489 .34483 .65536 .36397 .64929 .35212 .63875 Metetra
.962 .159 0 r
.35212 .63875 .36397 .64929 .38323 .64324 .37147 .63262 Metetra
.961 .164 0 r
.37147 .63262 .38323 .64324 .40262 .63719 .39096 .62649 Metetra
.959 .169 0 r
.39096 .62649 .40262 .63719 .42216 .63114 .41058 .62037 Metetra
.958 .173 0 r
.41058 .62037 .42216 .63114 .44182 .6251 .43034 .61424 Metetra
.957 .177 0 r
.43034 .61424 .44182 .6251 .46163 .61904 .45024 .60811 Metetra
.957 .18 0 r
.45024 .60811 .46163 .61904 .48158 .613 .47028 .60199 Metetra
.956 .182 0 r
.47028 .60199 .48158 .613 .50168 .60696 .49048 .59586 Metetra
.956 .184 0 r
.49048 .59586 .50168 .60696 .52192 .60091 .51082 .58973 Metetra
.955 .185 0 r
.51082 .58973 .52192 .60091 .54231 .59486 .53131 .5836 Metetra
.955 .186 0 r
.53131 .5836 .54231 .59486 .56286 .5888 .55195 .57746 Metetra
.955 .186 0 r
.55195 .57746 .56286 .5888 .58356 .58274 .57275 .57131 Metetra
.955 .185 0 r
.57275 .57131 .58356 .58274 .60441 .57668 .59371 .56516 Metetra
.956 .184 0 r
.59371 .56516 .60441 .57668 .62542 .57061 .61483 .55901 Metetra
.956 .182 0 r
.61483 .55901 .62542 .57061 .6466 .56454 .63611 .55285 Metetra
.957 .179 0 r
.63611 .55285 .6466 .56454 .66794 .55846 .65756 .54668 Metetra
.958 .176 0 r
.65756 .54668 .66794 .55846 .68944 .55238 .67918 .54051 Metetra
.959 .172 0 r
.67918 .54051 .68944 .55238 .71112 .5463 .70097 .53434 Metetra
.96 .168 0 r
.70097 .53434 .71112 .5463 .73297 .54022 .72293 .52817 Metetra
.961 .162 0 r
.72293 .52817 .73297 .54022 .755 .53414 .74508 .52199 Metetra
.963 .156 0 r
.74508 .52199 .755 .53414 .7772 .52807 .7674 .51583 Metetra
.964 .149 0 r
.7674 .51583 .7772 .52807 .79959 .52199 .78991 .50966 Metetra
.966 .144 0 r
.78991 .50966 .79959 .52199 .82214 .51566 .81259 .50323 Metetra
.962 .159 0 r
.81259 .50323 .82214 .51566 .84462 .50657 .83519 .49404 Metetra
.925 .299 0 r
.83519 .49404 .84462 .50657 .86567 .48229 .85641 .46962 Metetra
.788 .724 0 r
.85641 .46962 .86567 .48229 .8823 .41847 .87329 .40558 Metetra
.234 .625 0 r
.23736 .53544 .24933 .54602 .26102 .62121 .24879 .61081 Metetra
.859 .526 0 r
.24879 .61081 .26102 .62121 .27678 .65278 .26448 .64242 Metetra
.947 .218 0 r
.26448 .64242 .27678 .65278 .29494 .65592 .28269 .6455 Metetra
.965 .148 0 r
.28269 .6455 .29494 .65592 .31382 .65096 .30165 .64048 Metetra
.965 .146 0 r
.30165 .64048 .31382 .65096 .33291 .64489 .32082 .63433 Metetra
.963 .153 0 r
.32082 .63433 .33291 .64489 .35212 .63875 .34012 .62811 Metetra
.962 .159 0 r
.34012 .62811 .35212 .63875 .37147 .63262 .35956 .6219 Metetra
.96 .165 0 r
.35956 .6219 .37147 .63262 .39096 .62649 .37913 .61569 Metetra
.959 .17 0 r
.37913 .61569 .39096 .62649 .41058 .62037 .39884 .60949 Metetra
.958 .174 0 r
.39884 .60949 .41058 .62037 .43034 .61424 .41869 .60328 Metetra
.957 .178 0 r
.41869 .60328 .43034 .61424 .45024 .60811 .43869 .59707 Metetra
.956 .181 0 r
.43869 .59707 .45024 .60811 .47028 .60199 .45883 .59086 Metetra
.956 .183 0 r
.45883 .59086 .47028 .60199 .49048 .59586 .47912 .58465 Metetra
.955 .185 0 r
.47912 .58465 .49048 .59586 .51082 .58973 .49956 .57844 Metetra
.955 .186 0 r
.49956 .57844 .51082 .58973 .53131 .5836 .52015 .57222 Metetra
.955 .186 0 r
.52015 .57222 .53131 .5836 .55195 .57746 .54089 .566 Metetra
.955 .186 0 r
.54089 .566 .55195 .57746 .57275 .57131 .5618 .55977 Metetra
.955 .186 0 r
.5618 .55977 .57275 .57131 .59371 .56516 .58286 .55353 Metetra
.955 .184 0 r
.58286 .55353 .59371 .56516 .61483 .55901 .60408 .54728 Metetra
.956 .182 0 r
.60408 .54728 .61483 .55901 .63611 .55285 .62548 .54103 Metetra
.957 .18 0 r
.62548 .54103 .63611 .55285 .65756 .54668 .64704 .53478 Metetra
.957 .177 0 r
.64704 .53478 .65756 .54668 .67918 .54051 .66877 .52852 Metetra
.958 .173 0 r
.66877 .52852 .67918 .54051 .70097 .53434 .69067 .52225 Metetra
.96 .168 0 r
.69067 .52225 .70097 .53434 .72293 .52817 .71275 .51599 Metetra
.961 .163 0 r
.71275 .51599 .72293 .52817 .74508 .52199 .73502 .50972 Metetra
.962 .157 0 r
.73502 .50972 .74508 .52199 .7674 .51583 .75746 .50346 Metetra
.964 .15 0 r
.75746 .50346 .7674 .51583 .78991 .50966 .78009 .4972 Metetra
.965 .145 0 r
.78009 .4972 .78991 .50966 .81259 .50323 .8029 .49067 Metetra
.962 .16 0 r
.8029 .49067 .81259 .50323 .83519 .49404 .82563 .48136 Metetra
.925 .299 0 r
.82563 .48136 .83519 .49404 .85641 .46962 .84703 .4568 Metetra
.788 .724 0 r
.84703 .4568 .85641 .46962 .87329 .40558 .86416 .3925 Metetra
.234 .625 0 r
.22523 .5247 .23736 .53544 .24879 .61081 .2364 .60027 Metetra
.858 .526 0 r
.2364 .60027 .24879 .61081 .26448 .64242 .25201 .63195 Metetra
.947 .218 0 r
.25201 .63195 .26448 .64242 .28269 .6455 .27027 .63499 Metetra
.965 .148 0 r
.27027 .63499 .28269 .6455 .30165 .64048 .28931 .62989 Metetra
.965 .146 0 r
.28931 .62989 .30165 .64048 .32082 .63433 .30856 .62367 Metetra
.963 .153 0 r
.30856 .62367 .32082 .63433 .34012 .62811 .32795 .61737 Metetra
.962 .159 0 r
.32795 .61737 .34012 .62811 .35956 .6219 .34748 .61107 Metetra
.96 .165 0 r
.34748 .61107 .35956 .6219 .37913 .61569 .36714 .60479 Metetra
.959 .17 0 r
.36714 .60479 .37913 .61569 .39884 .60949 .38694 .5985 Metetra
.958 .174 0 r
.38694 .5985 .39884 .60949 .41869 .60328 .40689 .59221 Metetra
.957 .178 0 r
.40689 .59221 .41869 .60328 .43869 .59707 .42698 .58592 Metetra
.956 .181 0 r
.42698 .58592 .43869 .59707 .45883 .59086 .44722 .57963 Metetra
.956 .183 0 r
.44722 .57963 .45883 .59086 .47912 .58465 .4676 .57333 Metetra
.955 .185 0 r
.4676 .57333 .47912 .58465 .49956 .57844 .48814 .56703 Metetra
.955 .186 0 r
.48814 .56703 .49956 .57844 .52015 .57222 .50883 .56073 Metetra
.955 .187 0 r
.50883 .56073 .52015 .57222 .54089 .566 .52968 .55442 Metetra
.955 .186 0 r
.52968 .55442 .54089 .566 .5618 .55977 .55069 .5481 Metetra
.955 .186 0 r
.55069 .5481 .5618 .55977 .58286 .55353 .57186 .54177 Metetra
.955 .184 0 r
.57186 .54177 .58286 .55353 .60408 .54728 .59319 .53544 Metetra
.956 .182 0 r
.59319 .53544 .60408 .54728 .62548 .54103 .61469 .5291 Metetra
.957 .18 0 r
.61469 .5291 .62548 .54103 .64704 .53478 .63636 .52275 Metetra
.957 .177 0 r
.63636 .52275 .64704 .53478 .66877 .52852 .65821 .51639 Metetra
.958 .173 0 r
.65821 .51639 .66877 .52852 .69067 .52225 .68023 .51004 Metetra
.959 .168 0 r
.68023 .51004 .69067 .52225 .71275 .51599 .70243 .50368 Metetra
.961 .163 0 r
.70243 .50368 .71275 .51599 .73502 .50972 .72481 .49731 Metetra
.962 .157 0 r
.72481 .49731 .73502 .50972 .75746 .50346 .74738 .49096 Metetra
.964 .15 0 r
.74738 .49096 .75746 .50346 .78009 .4972 .77014 .4846 Metetra
.965 .145 0 r
.77014 .4846 .78009 .4972 .8029 .49067 .79306 .47797 Metetra
.962 .16 0 r
.79306 .47797 .8029 .49067 .82563 .48136 .81594 .46856 Metetra
.925 .3 0 r
.81594 .46856 .82563 .48136 .84703 .4568 .8375 .44382 Metetra
.788 .724 0 r
.8375 .44382 .84703 .4568 .86416 .3925 .85489 .37922 Metetra
.234 .625 0 r
.21296 .5138 .22523 .5247 .2364 .60027 .22384 .58961 Metetra
.859 .526 0 r
.22384 .58961 .2364 .60027 .25201 .63195 .23938 .62138 Metetra
.947 .218 0 r
.23938 .62138 .25201 .63195 .27027 .63499 .25767 .62439 Metetra
.965 .147 0 r
.25767 .62439 .27027 .63499 .28931 .62989 .27679 .61921 Metetra
.965 .146 0 r
.27679 .61921 .28931 .62989 .30856 .62367 .29613 .61291 Metetra
.963 .152 0 r
.29613 .61291 .30856 .62367 .32795 .61737 .31561 .60652 Metetra
.962 .159 0 r
.31561 .60652 .32795 .61737 .34748 .61107 .33523 .60015 Metetra
.96 .165 0 r
.33523 .60015 .34748 .61107 .36714 .60479 .35498 .59378 Metetra
.959 .17 0 r
.35498 .59378 .36714 .60479 .38694 .5985 .37488 .58741 Metetra
.958 .174 0 r
.37488 .58741 .38694 .5985 .40689 .59221 .39492 .58104 Metetra
.957 .177 0 r
.39492 .58104 .40689 .59221 .42698 .58592 .4151 .57465 Metetra
.956 .181 0 r
.4151 .57465 .42698 .58592 .44722 .57963 .43544 .56828 Metetra
.956 .183 0 r
.43544 .56828 .44722 .57963 .4676 .57333 .45592 .5619 Metetra
.955 .184 0 r
.45592 .5619 .4676 .57333 .48814 .56703 .47656 .55551 Metetra
.955 .186 0 r
.47656 .55551 .48814 .56703 .50883 .56073 .49735 .54911 Metetra
.955 .186 0 r
.49735 .54911 .50883 .56073 .52968 .55442 .51831 .54271 Metetra
.955 .186 0 r
.51831 .54271 .52968 .55442 .55069 .5481 .53942 .5363 Metetra
.955 .185 0 r
.53942 .5363 .55069 .5481 .57186 .54177 .5607 .52989 Metetra
.956 .184 0 r
.5607 .52989 .57186 .54177 .59319 .53544 .58214 .52346 Metetra
.956 .182 0 r
.58214 .52346 .59319 .53544 .61469 .5291 .60375 .51703 Metetra
.957 .179 0 r
.60375 .51703 .61469 .5291 .63636 .52275 .62554 .51059 Metetra
.958 .176 0 r
.62554 .51059 .63636 .52275 .65821 .51639 .6475 .50414 Metetra
.958 .172 0 r
.6475 .50414 .65821 .51639 .68023 .51004 .66964 .49769 Metetra
.96 .168 0 r
.66964 .49769 .68023 .51004 .70243 .50368 .69195 .49123 Metetra
.961 .163 0 r
.69195 .49123 .70243 .50368 .72481 .49731 .71446 .48477 Metetra
.962 .157 0 r
.71446 .48477 .72481 .49731 .74738 .49096 .73715 .47832 Metetra
.964 .15 0 r
.73715 .47832 .74738 .49096 .77014 .4846 .76003 .47186 Metetra
.966 .144 0 r
.76003 .47186 .77014 .4846 .79306 .47797 .78309 .46514 Metetra
.962 .16 0 r
.78309 .46514 .79306 .47797 .81594 .46856 .8061 .4556 Metetra
.925 .299 0 r
.8061 .4556 .81594 .46856 .8375 .44382 .82784 .43068 Metetra
.788 .724 0 r
.82784 .43068 .8375 .44382 .85489 .37922 .84548 .36574 Metetra
.234 .625 0 r
.20052 .50274 .21296 .5138 .22384 .58961 .21112 .57882 Metetra
.859 .526 0 r
.21112 .57882 .22384 .58961 .23938 .62138 .22657 .6107 Metetra
.947 .217 0 r
.22657 .6107 .23938 .62138 .25767 .62439 .24491 .61368 Metetra
.965 .146 0 r
.24491 .61368 .25767 .62439 .27679 .61921 .26411 .60844 Metetra
.965 .144 0 r
.26411 .60844 .27679 .61921 .29613 .61291 .28354 .60204 Metetra
.964 .151 0 r
.28354 .60204 .29613 .61291 .31561 .60652 .3031 .59558 Metetra
.962 .158 0 r
.3031 .59558 .31561 .60652 .33523 .60015 .32281 .58911 Metetra
.961 .163 0 r
.32281 .58911 .33523 .60015 .35498 .59378 .34266 .58266 Metetra
.959 .168 0 r
.34266 .58266 .35498 .59378 .37488 .58741 .36265 .5762 Metetra
.958 .173 0 r
.36265 .5762 .37488 .58741 .39492 .58104 .38278 .56974 Metetra
.957 .176 0 r
.38278 .56974 .39492 .58104 .4151 .57465 .40306 .56327 Metetra
.957 .179 0 r
.40306 .56327 .4151 .57465 .43544 .56828 .42349 .55681 Metetra
.956 .182 0 r
.42349 .55681 .43544 .56828 .45592 .5619 .44408 .55034 Metetra
.956 .183 0 r
.44408 .55034 .45592 .5619 .47656 .55551 .46482 .54386 Metetra
.955 .184 0 r
.46482 .54386 .47656 .55551 .49735 .54911 .48571 .53738 Metetra
.955 .185 0 r
.48571 .53738 .49735 .54911 .51831 .54271 .50677 .53088 Metetra
.955 .185 0 r
.50677 .53088 .51831 .54271 .53942 .5363 .52799 .52438 Metetra
.956 .184 0 r
.52799 .52438 .53942 .5363 .5607 .52989 .54938 .51787 Metetra
.956 .183 0 r
.54938 .51787 .5607 .52989 .58214 .52346 .57093 .51136 Metetra
.956 .181 0 r
.57093 .51136 .58214 .52346 .60375 .51703 .59266 .50483 Metetra
.957 .178 0 r
.59266 .50483 .60375 .51703 .62554 .51059 .61456 .49829 Metetra
.958 .175 0 r
.61456 .49829 .62554 .51059 .6475 .50414 .63663 .49175 Metetra
.959 .171 0 r
.63663 .49175 .6475 .50414 .66964 .49769 .65889 .4852 Metetra
.96 .167 0 r
.65889 .4852 .66964 .49769 .69195 .49123 .68133 .47865 Metetra
.961 .162 0 r
.68133 .47865 .69195 .49123 .71446 .48477 .70396 .47209 Metetra
.963 .155 0 r
.70396 .47209 .71446 .48477 .73715 .47832 .72677 .46555 Metetra
.964 .149 0 r
.72677 .46555 .73715 .47832 .76003 .47186 .74978 .45898 Metetra
.966 .143 0 r
.74978 .45898 .76003 .47186 .78309 .46514 .77297 .45215 Metetra
.962 .159 0 r
.77297 .45215 .78309 .46514 .8061 .4556 .79612 .4425 Metetra
.926 .298 0 r
.79612 .4425 .8061 .4556 .82784 .43068 .81803 .41738 Metetra
.788 .724 0 r
.81803 .41738 .82784 .43068 .84548 .36574 .83594 .35206 Metetra
.234 .625 0 r
.18793 .49151 .20052 .50274 .21112 .57882 .19823 .56789 Metetra
.859 .525 0 r
.19823 .56789 .21112 .57882 .22657 .6107 .21358 .59991 Metetra
.948 .215 0 r
.21358 .59991 .22657 .6107 .24491 .61368 .23196 .60288 Metetra
.966 .144 0 r
.23196 .60288 .24491 .61368 .26411 .60844 .25124 .59756 Metetra
.966 .143 0 r
.25124 .59756 .26411 .60844 .28354 .60204 .27076 .59108 Metetra
.964 .149 0 r
.27076 .59108 .28354 .60204 .3031 .59558 .29042 .58452 Metetra
.963 .156 0 r
.29042 .58452 .3031 .59558 .32281 .58911 .31022 .57797 Metetra
.961 .162 0 r
.31022 .57797 .32281 .58911 .34266 .58266 .33016 .57143 Metetra
.96 .167 0 r
.33016 .57143 .34266 .58266 .36265 .5762 .35024 .56488 Metetra
.959 .171 0 r
.35024 .56488 .36265 .5762 .38278 .56974 .37047 .55833 Metetra
.958 .175 0 r
.37047 .55833 .38278 .56974 .40306 .56327 .39085 .55177 Metetra
.957 .178 0 r
.39085 .55177 .40306 .56327 .42349 .55681 .41138 .54522 Metetra
.957 .18 0 r
.41138 .54522 .42349 .55681 .44408 .55034 .43206 .53866 Metetra
.956 .182 0 r
.43206 .53866 .44408 .55034 .46482 .54386 .45291 .53209 Metetra
.956 .183 0 r
.45291 .53209 .46482 .54386 .48571 .53738 .47391 .52551 Metetra
.956 .183 0 r
.47391 .52551 .48571 .53738 .50677 .53088 .49507 .51893 Metetra
.956 .183 0 r
.49507 .51893 .50677 .53088 .52799 .52438 .5164 .51233 Metetra
.956 .182 0 r
.5164 .51233 .52799 .52438 .54938 .51787 .53789 .50573 Metetra
.956 .181 0 r
.53789 .50573 .54938 .51787 .57093 .51136 .55956 .49912 Metetra
.957 .179 0 r
.55956 .49912 .57093 .51136 .59266 .50483 .5814 .49249 Metetra
.957 .177 0 r
.5814 .49249 .59266 .50483 .61456 .49829 .60341 .48586 Metetra
.958 .173 0 r
.60341 .48586 .61456 .49829 .63663 .49175 .62561 .47922 Metetra
.959 .17 0 r
.62561 .47922 .63663 .49175 .65889 .4852 .64799 .47257 Metetra
.96 .165 0 r
.64799 .47257 .65889 .4852 .68133 .47865 .67055 .46592 Metetra
.962 .16 0 r
.67055 .46592 .68133 .47865 .70396 .47209 .6933 .45927 Metetra
.963 .154 0 r
.6933 .45927 .70396 .47209 .72677 .46555 .71624 .45262 Metetra
.965 .147 0 r
.71624 .45262 .72677 .46555 .74978 .45898 .73938 .44596 Metetra
.966 .141 0 r
.73938 .44596 .74978 .45898 .77297 .45215 .76271 .43903 Metetra
.962 .157 0 r
.76271 .43903 .77297 .45215 .79612 .4425 .786 .42924 Metetra
.926 .297 0 r
.786 .42924 .79612 .4425 .81803 .41738 .80808 .4039 Metetra
.788 .724 0 r
.80808 .4039 .81803 .41738 .83594 .35206 .82625 .33817 Metetra
.233 .625 0 r
.17517 .48011 .18793 .49151 .19823 .56789 .18516 .55682 Metetra
.859 .524 0 r
.18516 .55682 .19823 .56789 .21358 .59991 .20041 .58902 Metetra
.948 .213 0 r
.20041 .58902 .21358 .59991 .23196 .60288 .21883 .59198 Metetra
.966 .142 0 r
.21883 .59198 .23196 .60288 .25124 .59756 .23819 .58657 Metetra
.967 .14 0 r
.23819 .58657 .25124 .59756 .27076 .59108 .2578 .58001 Metetra
.965 .147 0 r
.2578 .58001 .27076 .59108 .29042 .58452 .27755 .57336 Metetra
.963 .153 0 r
.27755 .57336 .29042 .58452 .31022 .57797 .29744 .56672 Metetra
.962 .159 0 r
.29744 .56672 .31022 .57797 .33016 .57143 .31747 .56008 Metetra
.961 .164 0 r
.31747 .56008 .33016 .57143 .35024 .56488 .33765 .55345 Metetra
.959 .169 0 r
.33765 .55345 .35024 .56488 .37047 .55833 .35798 .54681 Metetra
.959 .172 0 r
.35798 .54681 .37047 .55833 .39085 .55177 .37846 .54015 Metetra
.958 .175 0 r
.37846 .54015 .39085 .55177 .41138 .54522 .39909 .53351 Metetra
.957 .178 0 r
.39909 .53351 .41138 .54522 .43206 .53866 .41988 .52685 Metetra
.957 .179 0 r
.41988 .52685 .43206 .53866 .45291 .53209 .44082 .52019 Metetra
.956 .18 0 r
.44082 .52019 .45291 .53209 .47391 .52551 .46193 .51352 Metetra
.956 .181 0 r
.46193 .51352 .47391 .52551 .49507 .51893 .4832 .50684 Metetra
.956 .181 0 r
.4832 .50684 .49507 .51893 .5164 .51233 .50464 .50015 Metetra
.957 .18 0 r
.50464 .50015 .5164 .51233 .53789 .50573 .52624 .49345 Metetra
.957 .179 0 r
.52624 .49345 .53789 .50573 .55956 .49912 .54802 .48674 Metetra
.957 .177 0 r
.54802 .48674 .55956 .49912 .5814 .49249 .56998 .48002 Metetra
.958 .174 0 r
.56998 .48002 .5814 .49249 .60341 .48586 .59211 .47329 Metetra
.959 .171 0 r
.59211 .47329 .60341 .48586 .62561 .47922 .61442 .46655 Metetra
.96 .167 0 r
.61442 .46655 .62561 .47922 .64799 .47257 .63692 .45981 Metetra
.961 .163 0 r
.63692 .45981 .64799 .47257 .67055 .46592 .65961 .45305 Metetra
.962 .157 0 r
.65961 .45305 .67055 .46592 .6933 .45927 .68248 .4463 Metetra
.964 .151 0 r
.68248 .4463 .6933 .45927 .71624 .45262 .70556 .43955 Metetra
.966 .144 0 r
.70556 .43955 .71624 .45262 .73938 .44596 .72883 .43278 Metetra
.967 .138 0 r
.72883 .43278 .73938 .44596 .76271 .43903 .75228 .42575 Metetra
.963 .154 0 r
.75228 .42575 .76271 .43903 .786 .42924 .77572 .41583 Metetra
.927 .295 0 r
.77572 .41583 .786 .42924 .80808 .4039 .79798 .39024 Metetra
.788 .723 0 r
.79798 .39024 .80808 .4039 .82625 .33817 .81642 .32407 Metetra
.233 .624 0 r
.16225 .46854 .17517 .48011 .18516 .55682 .17192 .54562 Metetra
.86 .523 0 r
.17192 .54562 .18516 .55682 .20041 .58902 .18705 .57802 Metetra
.949 .21 0 r
.18705 .57802 .20041 .58902 .21883 .59198 .20551 .58098 Metetra
.967 .138 0 r
.20551 .58098 .21883 .59198 .23819 .58657 .22496 .5755 Metetra
.967 .136 0 r
.22496 .5755 .23819 .58657 .2578 .58001 .24465 .56884 Metetra
.966 .143 0 r
.24465 .56884 .2578 .58001 .27755 .57336 .2645 .5621 Metetra
.964 .15 0 r
.2645 .5621 .27755 .57336 .29744 .56672 .28448 .55537 Metetra
.963 .156 0 r
.28448 .55537 .29744 .56672 .31747 .56008 .30461 .54864 Metetra
.961 .161 0 r
.30461 .54864 .31747 .56008 .33765 .55345 .32489 .54191 Metetra
.96 .165 0 r
.32489 .54191 .33765 .55345 .35798 .54681 .34531 .53518 Metetra
.959 .169 0 r
.34531 .53518 .35798 .54681 .37846 .54015 .36589 .52843 Metetra
.959 .172 0 r
.36589 .52843 .37846 .54015 .39909 .53351 .38662 .52169 Metetra
.958 .175 0 r
.38662 .52169 .39909 .53351 .41988 .52685 .40751 .51494 Metetra
.957 .176 0 r
.40751 .51494 .41988 .52685 .44082 .52019 .42856 .50818 Metetra
.957 .177 0 r
.42856 .50818 .44082 .52019 .46193 .51352 .44977 .50141 Metetra
.957 .178 0 r
.44977 .50141 .46193 .51352 .4832 .50684 .47115 .49463 Metetra
.957 .178 0 r
.47115 .49463 .4832 .50684 .50464 .50015 .4927 .48785 Metetra
.957 .177 0 r
.4927 .48785 .50464 .50015 .52624 .49345 .51442 .48105 Metetra
.958 .176 0 r
.51442 .48105 .52624 .49345 .54802 .48674 .53631 .47424 Metetra
.958 .174 0 r
.53631 .47424 .54802 .48674 .56998 .48002 .55838 .46742 Metetra
.959 .171 0 r
.55838 .46742 .56998 .48002 .59211 .47329 .58063 .46059 Metetra
.96 .168 0 r
.58063 .46059 .59211 .47329 .61442 .46655 .60307 .45375 Metetra
.961 .164 0 r
.60307 .45375 .61442 .46655 .63692 .45981 .62569 .4469 Metetra
.962 .159 0 r
.62569 .4469 .63692 .45981 .65961 .45305 .6485 .44005 Metetra
.963 .154 0 r
.6485 .44005 .65961 .45305 .68248 .4463 .67151 .4332 Metetra
.965 .148 0 r
.67151 .4332 .68248 .4463 .70556 .43955 .69471 .42635 Metetra
.966 .141 0 r
.69471 .42635 .70556 .43955 .72883 .43278 .71812 .41947 Metetra
.968 .135 0 r
.71812 .41947 .72883 .43278 .75228 .42575 .74171 .41233 Metetra
.964 .151 0 r
.74171 .41233 .75228 .42575 .77572 .41583 .76529 .40228 Metetra
.927 .292 0 r
.76529 .40228 .77572 .41583 .79798 .39024 .78773 .37642 Metetra
.789 .723 0 r
.78773 .37642 .79798 .39024 .81642 .32407 .80643 .30976 Metetra
.232 .624 0 r
.14917 .45679 .16225 .46854 .17192 .54562 .15849 .53427 Metetra
.86 .521 0 r
.15849 .53427 .17192 .54562 .18705 .57802 .1735 .5669 Metetra
.95 .206 0 r
.1735 .5669 .18705 .57802 .20551 .58098 .192 .56987 Metetra
.968 .134 0 r
.192 .56987 .20551 .58098 .22496 .5755 .21153 .56431 Metetra
.969 .132 0 r
.21153 .56431 .22496 .5755 .24465 .56884 .23132 .55756 Metetra
.967 .139 0 r
.23132 .55756 .24465 .56884 .2645 .5621 .25125 .55072 Metetra
.965 .146 0 r
.25125 .55072 .2645 .5621 .28448 .55537 .27133 .54389 Metetra
.964 .152 0 r
.27133 .54389 .28448 .55537 .30461 .54864 .29156 .53707 Metetra
.962 .157 0 r
.29156 .53707 .30461 .54864 .32489 .54191 .31193 .53024 Metetra
.961 .162 0 r
.31193 .53024 .32489 .54191 .34531 .53518 .33245 .52341 Metetra
.96 .165 0 r
.33245 .52341 .34531 .53518 .36589 .52843 .35313 .51656 Metetra
.959 .168 0 r
.35313 .51656 .36589 .52843 .38662 .52169 .37397 .50973 Metetra
.959 .171 0 r
.37397 .50973 .38662 .52169 .40751 .51494 .39496 .50288 Metetra
.958 .173 0 r
.39496 .50288 .40751 .51494 .42856 .50818 .41612 .49602 Metetra
.958 .174 0 r
.41612 .49602 .42856 .50818 .44977 .50141 .43744 .48916 Metetra
.958 .174 0 r
.43744 .48916 .44977 .50141 .47115 .49463 .45893 .48228 Metetra
.958 .174 0 r
.45893 .48228 .47115 .49463 .4927 .48785 .48059 .47539 Metetra
.958 .173 0 r
.48059 .47539 .4927 .48785 .51442 .48105 .50242 .4685 Metetra
.959 .172 0 r
.50242 .4685 .51442 .48105 .53631 .47424 .52443 .46159 Metetra
.959 .17 0 r
.52443 .46159 .53631 .47424 .55838 .46742 .54661 .45467 Metetra
.96 .167 0 r
.54661 .45467 .55838 .46742 .58063 .46059 .56899 .44773 Metetra
.961 .164 0 r
.56899 .44773 .58063 .46059 .60307 .45375 .59154 .44079 Metetra
.962 .16 0 r
.59154 .44079 .60307 .45375 .62569 .4469 .61429 .43384 Metetra
.963 .155 0 r
.61429 .43384 .62569 .4469 .6485 .44005 .63723 .42689 Metetra
.964 .15 0 r
.63723 .42689 .6485 .44005 .67151 .4332 .66036 .41994 Metetra
.966 .143 0 r
.66036 .41994 .67151 .4332 .69471 .42635 .6837 .41298 Metetra
.967 .136 0 r
.6837 .41298 .69471 .42635 .71812 .41947 .70724 .406 Metetra
.969 .131 0 r
.70724 .406 .71812 .41947 .74171 .41233 .73097 .39875 Metetra
.965 .147 0 r
.73097 .39875 .74171 .41233 .76529 .40228 .75469 .38855 Metetra
.928 .289 0 r
.75469 .38855 .76529 .40228 .78773 .37642 .77732 .36241 Metetra
.789 .722 0 r
.77732 .36241 .78773 .37642 .80643 .30976 .7963 .29521 Metetra
.232 .624 0 r
.13591 .44486 .14917 .45679 .15849 .53427 .14487 .52277 Metetra
.861 .519 0 r
.14487 .52277 .15849 .53427 .1735 .5669 .15976 .55567 Metetra
.951 .202 0 r
.15976 .55567 .1735 .5669 .192 .56987 .17829 .55865 Metetra
.969 .129 0 r
.17829 .55865 .192 .56987 .21153 .56431 .19791 .55301 Metetra
.97 .127 0 r
.19791 .55301 .21153 .56431 .23132 .55756 .21779 .54616 Metetra
.968 .134 0 r
.21779 .54616 .23132 .55756 .25125 .55072 .23782 .53923 Metetra
.966 .141 0 r
.23782 .53923 .25125 .55072 .27133 .54389 .25799 .5323 Metetra
.965 .147 0 r
.25799 .5323 .27133 .54389 .29156 .53707 .27831 .52538 Metetra
.963 .153 0 r
.27831 .52538 .29156 .53707 .31193 .53024 .29878 .51845 Metetra
.962 .157 0 r
.29878 .51845 .31193 .53024 .33245 .52341 .31941 .51152 Metetra
.961 .161 0 r
.31941 .51152 .33245 .52341 .35313 .51656 .34019 .50458 Metetra
.961 .164 0 r
.34019 .50458 .35313 .51656 .37397 .50973 .36113 .49764 Metetra
.96 .167 0 r
.36113 .49764 .37397 .50973 .39496 .50288 .38223 .49069 Metetra
.96 .168 0 r
.38223 .49069 .39496 .50288 .41612 .49602 .40349 .48373 Metetra
.959 .169 0 r
.40349 .48373 .41612 .49602 .43744 .48916 .42492 .47677 Metetra
.959 .17 0 r
.42492 .47677 .43744 .48916 .45893 .48228 .44652 .46979 Metetra
.959 .17 0 r
.44652 .46979 .45893 .48228 .48059 .47539 .46829 .4628 Metetra
.959 .169 0 r
.46829 .4628 .48059 .47539 .50242 .4685 .49024 .4558 Metetra
.96 .168 0 r
.49024 .4558 .50242 .4685 .52443 .46159 .51236 .44879 Metetra
.96 .166 0 r
.51236 .44879 .52443 .46159 .54661 .45467 .53467 .44177 Metetra
.961 .163 0 r
.53467 .44177 .54661 .45467 .56899 .44773 .55716 .43473 Metetra
.962 .16 0 r
.55716 .43473 .56899 .44773 .59154 .44079 .57984 .42769 Metetra
.963 .156 0 r
.57984 .42769 .59154 .44079 .61429 .43384 .60271 .42063 Metetra
.964 .151 0 r
.60271 .42063 .61429 .43384 .63723 .42689 .62578 .41358 Metetra
.965 .145 0 r
.62578 .41358 .63723 .42689 .66036 .41994 .64905 .40652 Metetra
.967 .139 0 r
.64905 .40652 .66036 .41994 .6837 .41298 .67252 .39945 Metetra
.969 .131 0 r
.67252 .39945 .6837 .41298 .70724 .406 .69619 .39237 Metetra
.97 .126 0 r
.69619 .39237 .70724 .406 .73097 .39875 .72006 .385 Metetra
.966 .142 0 r
.72006 .385 .73097 .39875 .75469 .38855 .74394 .37466 Metetra
.929 .286 0 r
.74394 .37466 .75469 .38855 .77732 .36241 .76675 .34821 Metetra
.789 .721 0 r
.76675 .34821 .77732 .36241 .7963 .29521 .78601 .28044 Metetra
.231 .624 0 r
.12248 .43274 .13591 .44486 .14487 .52277 .13107 .51112 Metetra
.862 .517 0 r
.13107 .51112 .14487 .52277 .15976 .55567 .14582 .54431 Metetra
.952 .197 0 r
.14582 .54431 .15976 .55567 .17829 .55865 .16438 .54733 Metetra
.971 .123 0 r
.16438 .54733 .17829 .55865 .19791 .55301 .18408 .54161 Metetra
.971 .121 0 r
.18408 .54161 .19791 .55301 .21779 .54616 .20405 .53466 Metetra
.969 .129 0 r
.20405 .53466 .21779 .54616 .23782 .53923 .22418 .52762 Metetra
.968 .136 0 r
.22418 .52762 .23782 .53923 .25799 .5323 .24445 .52059 Metetra
.966 .142 0 r
.24445 .52059 .25799 .5323 .27831 .52538 .26487 .51357 Metetra
.965 .147 0 r
.26487 .51357 .27831 .52538 .29878 .51845 .28544 .50654 Metetra
.964 .152 0 r
.28544 .50654 .29878 .51845 .31941 .51152 .30617 .49951 Metetra
.963 .156 0 r
.30617 .49951 .31941 .51152 .34019 .50458 .32705 .49246 Metetra
.962 .159 0 r
.32705 .49246 .34019 .50458 .36113 .49764 .34809 .48542 Metetra
.961 .162 0 r
.34809 .48542 .36113 .49764 .38223 .49069 .3693 .47837 Metetra
.961 .163 0 r
.3693 .47837 .38223 .49069 .40349 .48373 .39067 .47131 Metetra
.96 .165 0 r
.39067 .47131 .40349 .48373 .42492 .47677 .41221 .46424 Metetra
.96 .165 0 r
.41221 .46424 .42492 .47677 .44652 .46979 .43392 .45716 Metetra
.96 .165 0 r
.43392 .45716 .44652 .46979 .46829 .4628 .4558 .45007 Metetra
.961 .164 0 r
.4558 .45007 .46829 .4628 .49024 .4558 .47787 .44296 Metetra
.961 .163 0 r
.47787 .44296 .49024 .4558 .51236 .44879 .50011 .43585 Metetra
.961 .161 0 r
.50011 .43585 .51236 .44879 .53467 .44177 .52254 .42872 Metetra
.962 .158 0 r
.52254 .42872 .53467 .44177 .55716 .43473 .54516 .42158 Metetra
.963 .154 0 r
.54516 .42158 .55716 .43473 .57984 .42769 .56796 .41443 Metetra
.964 .15 0 r
.56796 .41443 .57984 .42769 .60271 .42063 .59096 .40728 Metetra
.965 .145 0 r
.59096 .40728 .60271 .42063 .62578 .41358 .61416 .40011 Metetra
.967 .14 0 r
.61416 .40011 .62578 .41358 .64905 .40652 .63756 .39294 Metetra
.968 .133 0 r
.63756 .39294 .64905 .40652 .67252 .39945 .66116 .38577 Metetra
.97 .126 0 r
.66116 .38577 .67252 .39945 .69619 .39237 .68498 .37858 Metetra
.972 .12 0 r
.68498 .37858 .69619 .39237 .72006 .385 .70899 .3711 Metetra
.968 .136 0 r
.70899 .3711 .72006 .385 .74394 .37466 .73301 .3606 Metetra
.93 .282 0 r
.73301 .3606 .74394 .37466 .76675 .34821 .75602 .33382 Metetra
.789 .72 0 r
.75602 .33382 .76675 .34821 .78601 .28044 .77556 .26544 Metetra
.23 .624 0 r
.10887 .42044 .12248 .43274 .13107 .51112 .11707 .49933 Metetra
.862 .514 0 r
.11707 .49933 .13107 .51112 .14582 .54431 .13167 .53285 Metetra
.954 .191 0 r
.13167 .53285 .14582 .54431 .16438 .54733 .15026 .5359 Metetra
.972 .117 0 r
.15026 .5359 .16438 .54733 .18408 .54161 .17005 .53009 Metetra
.973 .115 0 r
.17005 .53009 .18408 .54161 .20405 .53466 .19011 .52304 Metetra
.971 .122 0 r
.19011 .52304 .20405 .53466 .22418 .52762 .21034 .5159 Metetra
.969 .129 0 r
.21034 .5159 .22418 .52762 .24445 .52059 .2307 .50877 Metetra
.968 .136 0 r
.2307 .50877 .24445 .52059 .26487 .51357 .25122 .50164 Metetra
.966 .141 0 r
.25122 .50164 .26487 .51357 .28544 .50654 .2719 .4945 Metetra
.965 .146 0 r
.2719 .4945 .28544 .50654 .30617 .49951 .29272 .48737 Metetra
.964 .15 0 r
.29272 .48737 .30617 .49951 .32705 .49246 .31371 .48022 Metetra
.963 .153 0 r
.31371 .48022 .32705 .49246 .34809 .48542 .33486 .47307 Metetra
.963 .156 0 r
.33486 .47307 .34809 .48542 .3693 .47837 .35617 .46592 Metetra
.962 .158 0 r
.35617 .46592 .3693 .47837 .39067 .47131 .37765 .45875 Metetra
.962 .159 0 r
.37765 .45875 .39067 .47131 .41221 .46424 .3993 .45158 Metetra
.962 .159 0 r
.3993 .45158 .41221 .46424 .43392 .45716 .42113 .44439 Metetra
.962 .159 0 r
.42113 .44439 .43392 .45716 .4558 .45007 .44313 .43719 Metetra
.962 .158 0 r
.44313 .43719 .4558 .45007 .47787 .44296 .46531 .42998 Metetra
.962 .157 0 r
.46531 .42998 .47787 .44296 .50011 .43585 .48767 .42276 Metetra
.963 .155 0 r
.48767 .42276 .50011 .43585 .52254 .42872 .51022 .41553 Metetra
.964 .152 0 r
.51022 .41553 .52254 .42872 .54516 .42158 .53296 .40828 Metetra
.964 .149 0 r
.53296 .40828 .54516 .42158 .56796 .41443 .55589 .40103 Metetra
.966 .144 0 r
.55589 .40103 .56796 .41443 .59096 .40728 .57902 .39376 Metetra
.967 .139 0 r
.57902 .39376 .59096 .40728 .61416 .40011 .60235 .38649 Metetra
.968 .133 0 r
.60235 .38649 .61416 .40011 .63756 .39294 .62589 .37921 Metetra
.97 .127 0 r
.62589 .37921 .63756 .39294 .66116 .38577 .64963 .37193 Metetra
.972 .119 0 r
.64963 .37193 .66116 .38577 .68498 .37858 .67358 .36463 Metetra
.973 .113 0 r
.67358 .36463 .68498 .37858 .70899 .3711 .69774 .35704 Metetra
.969 .13 0 r
.69774 .35704 .70899 .3711 .73301 .3606 .72192 .34638 Metetra
.931 .277 0 r
.72192 .34638 .73301 .3606 .75602 .33382 .74511 .31924 Metetra
.79 .719 0 r
.74511 .31924 .75602 .33382 .77556 .26544 .76495 .2502 Metetra
.229 .623 0 r
.09508 .40793 .10887 .42044 .11707 .49933 .10287 .48737 Metetra
.863 .511 0 r
.10287 .48737 .11707 .49933 .13167 .53285 .11731 .52126 Metetra
.955 .185 0 r
.11731 .52126 .13167 .53285 .15026 .5359 .13593 .52436 Metetra
.974 .109 0 r
.13593 .52436 .15026 .5359 .17005 .53009 .1558 .51847 Metetra
.975 .107 0 r
.1558 .51847 .17005 .53009 .19011 .52304 .17596 .51131 Metetra
.973 .115 0 r
.17596 .51131 .19011 .52304 .21034 .5159 .19628 .50407 Metetra
.971 .122 0 r
.19628 .50407 .21034 .5159 .2307 .50877 .21675 .49683 Metetra
.969 .129 0 r
.21675 .49683 .2307 .50877 .25122 .50164 .23737 .48959 Metetra
.968 .134 0 r
.23737 .48959 .25122 .50164 .2719 .4945 .25814 .48235 Metetra
.967 .139 0 r
.25814 .48235 .2719 .4945 .29272 .48737 .27907 .47511 Metetra
.966 .143 0 r
.27907 .47511 .29272 .48737 .31371 .48022 .30017 .46785 Metetra
.965 .147 0 r
.30017 .46785 .31371 .48022 .33486 .47307 .32142 .46059 Metetra
.964 .149 0 r
.32142 .46059 .33486 .47307 .35617 .46592 .34284 .45333 Metetra
.964 .151 0 r
.34284 .45333 .35617 .46592 .37765 .45875 .36443 .44606 Metetra
.964 .152 0 r
.36443 .44606 .37765 .45875 .3993 .45158 .3862 .43878 Metetra
.963 .153 0 r
.3862 .43878 .3993 .45158 .42113 .44439 .40814 .43148 Metetra
.963 .153 0 r
.40814 .43148 .42113 .44439 .44313 .43719 .43026 .42418 Metetra
.964 .152 0 r
.43026 .42418 .44313 .43719 .46531 .42998 .45255 .41686 Metetra
.964 .15 0 r
.45255 .41686 .46531 .42998 .48767 .42276 .47504 .40953 Metetra
.965 .148 0 r
.47504 .40953 .48767 .42276 .51022 .41553 .49771 .40218 Metetra
.965 .145 0 r
.49771 .40218 .51022 .41553 .53296 .40828 .52058 .39483 Metetra
.966 .142 0 r
.52058 .39483 .53296 .40828 .55589 .40103 .54364 .38747 Metetra
.967 .137 0 r
.54364 .38747 .55589 .40103 .57902 .39376 .5669 .3801 Metetra
.969 .132 0 r
.5669 .3801 .57902 .39376 .60235 .38649 .59036 .37271 Metetra
.97 .126 0 r
.59036 .37271 .60235 .38649 .62589 .37921 .61403 .36532 Metetra
.972 .119 0 r
.61403 .36532 .62589 .37921 .64963 .37193 .63791 .35793 Metetra
.973 .112 0 r
.63791 .35793 .64963 .37193 .67358 .36463 .66201 .35052 Metetra
.975 .105 0 r
.66201 .35052 .67358 .36463 .69774 .35704 .68631 .34281 Metetra
.971 .122 0 r
.68631 .34281 .69774 .35704 .72192 .34638 .71064 .33198 Metetra
.933 .271 0 r
.71064 .33198 .72192 .34638 .74511 .31924 .73404 .30446 Metetra
.79 .718 0 r
.73404 .30446 .74511 .31924 .76495 .2502 .75417 .23472 Metetra
.228 .623 0 r
.08112 .39517 .09508 .40793 .10287 .48737 .08848 .47517 Metetra
.864 .509 0 r
.08848 .47517 .10287 .48737 .11731 .52126 .10274 .50945 Metetra
.957 .178 0 r
.10274 .50945 .11731 .52126 .13593 .52436 .12139 .51261 Metetra
.976 .101 0 r
.12139 .51261 .13593 .52436 .1558 .51847 .14134 .50665 Metetra
.976 .099 0 r
.14134 .50665 .1558 .51847 .17596 .51131 .1616 .49938 Metetra
.975 .107 0 r
.1616 .49938 .17596 .51131 .19628 .50407 .18202 .49202 Metetra
.973 .115 0 r
.18202 .49202 .19628 .50407 .21675 .49683 .20259 .48467 Metetra
.971 .121 0 r
.20259 .48467 .21675 .49683 .23737 .48959 .22331 .47732 Metetra
.97 .127 0 r
.22331 .47732 .23737 .48959 .25814 .48235 .24419 .46998 Metetra
.969 .132 0 r
.24419 .46998 .25814 .48235 .27907 .47511 .26522 .46262 Metetra
.967 .136 0 r
.26522 .46262 .27907 .47511 .30017 .46785 .28642 .45525 Metetra
.967 .14 0 r
.28642 .45525 .30017 .46785 .32142 .46059 .30778 .44789 Metetra
.966 .142 0 r
.30778 .44789 .32142 .46059 .34284 .45333 .32931 .44052 Metetra
.966 .144 0 r
.32931 .44052 .34284 .45333 .36443 .44606 .35102 .43314 Metetra
.965 .146 0 r
.35102 .43314 .36443 .44606 .3862 .43878 .37289 .42575 Metetra
.965 .146 0 r
.37289 .42575 .3862 .43878 .40814 .43148 .39495 .41834 Metetra
.965 .146 0 r
.39495 .41834 .40814 .43148 .43026 .42418 .41718 .41092 Metetra
.965 .145 0 r
.41718 .41092 .43026 .42418 .45255 .41686 .4396 .40349 Metetra
.966 .144 0 r
.4396 .40349 .45255 .41686 .47504 .40953 .46221 .39605 Metetra
.966 .141 0 r
.46221 .39605 .47504 .40953 .49771 .40218 .48501 .3886 Metetra
.967 .138 0 r
.48501 .3886 .49771 .40218 .52058 .39483 .508 .38114 Metetra
.968 .135 0 r
.508 .38114 .52058 .39483 .54364 .38747 .53119 .37366 Metetra
.969 .13 0 r
.53119 .37366 .54364 .38747 .5669 .3801 .55458 .36617 Metetra
.97 .125 0 r
.55458 .36617 .5669 .3801 .59036 .37271 .57818 .35868 Metetra
.972 .119 0 r
.57818 .35868 .59036 .37271 .61403 .36532 .60198 .35117 Metetra
.973 .112 0 r
.60198 .35117 .61403 .36532 .63791 .35793 .626 .34366 Metetra
.975 .104 0 r
.626 .34366 .63791 .35793 .66201 .35052 .65024 .33614 Metetra
.977 .098 0 r
.65024 .33614 .66201 .35052 .68631 .34281 .67469 .32831 Metetra
.973 .115 0 r
.67469 .32831 .68631 .34281 .71064 .33198 .69918 .31731 Metetra
.934 .266 0 r
.69918 .31731 .71064 .33198 .73404 .30446 .72278 .28938 Metetra
.791 .717 0 r
.72278 .28938 .73404 .30446 .75417 .23472 .74322 .2189 Metetra
.22 .62 0 r
.06708 .38143 .08112 .39517 .08848 .47517 .07404 .46167 Metetra
.863 .513 0 r
.07404 .46167 .08848 .47517 .10274 .50945 .08813 .49621 Metetra
.956 .181 0 r
.08813 .49621 .10274 .50945 .12139 .51261 .10679 .49942 Metetra
.976 .103 0 r
.10679 .49942 .12139 .51261 .14134 .50665 .12682 .49339 Metetra
.976 .101 0 r
.12682 .49339 .14134 .50665 .1616 .49938 .14717 .48603 Metetra
.974 .109 0 r
.14717 .48603 .1616 .49938 .18202 .49202 .16768 .47858 Metetra
.972 .116 0 r
.16768 .47858 .18202 .49202 .20259 .48467 .18834 .47113 Metetra
.971 .123 0 r
.18834 .47113 .20259 .48467 .22331 .47732 .20915 .46368 Metetra
.969 .129 0 r
.20915 .46368 .22331 .47732 .24419 .46998 .23012 .45623 Metetra
.968 .134 0 r
.23012 .45623 .24419 .46998 .26522 .46262 .25126 .44878 Metetra
.967 .138 0 r
.25126 .44878 .26522 .46262 .28642 .45525 .27255 .4413 Metetra
.966 .141 0 r
.27255 .4413 .28642 .45525 .30778 .44789 .29402 .43383 Metetra
.966 .144 0 r
.29402 .43383 .30778 .44789 .32931 .44052 .31565 .42635 Metetra
.965 .146 0 r
.31565 .42635 .32931 .44052 .35102 .43314 .33746 .41886 Metetra
.965 .147 0 r
.33746 .41886 .35102 .43314 .37289 .42575 .35944 .41135 Metetra
.965 .148 0 r
.35944 .41135 .37289 .42575 .39495 .41834 .3816 .40384 Metetra
.965 .148 0 r
.3816 .40384 .39495 .41834 .41718 .41092 .40395 .3963 Metetra
.965 .147 0 r
.40395 .3963 .41718 .41092 .4396 .40349 .42648 .38875 Metetra
.965 .145 0 r
.42648 .38875 .4396 .40349 .46221 .39605 .4492 .38119 Metetra
.966 .143 0 r
.4492 .38119 .46221 .39605 .48501 .3886 .47212 .37362 Metetra
.967 .14 0 r
.47212 .37362 .48501 .3886 .508 .38114 .49523 .36603 Metetra
.967 .136 0 r
.49523 .36603 .508 .38114 .53119 .37366 .51854 .35843 Metetra
.969 .132 0 r
.51854 .35843 .53119 .37366 .55458 .36617 .54205 .35081 Metetra
.97 .127 0 r
.54205 .35081 .55458 .36617 .57818 .35868 .56578 .34318 Metetra
.971 .121 0 r
.56578 .34318 .57818 .35868 .60198 .35117 .58971 .33554 Metetra
.973 .114 0 r
.58971 .33554 .60198 .35117 .626 .34366 .61387 .3279 Metetra
.975 .106 0 r
.61387 .3279 .626 .34366 .65024 .33614 .63824 .32023 Metetra
.977 .099 0 r
.63824 .32023 .65024 .33614 .67469 .32831 .66282 .31226 Metetra
.972 .117 0 r
.66282 .31226 .67469 .32831 .69918 .31731 .68746 .30105 Metetra
.933 .269 0 r
.68746 .30105 .69918 .31731 .72278 .28938 .71125 .27276 Metetra
.789 .722 0 r
.71125 .27276 .72278 .28938 .74322 .2189 .73202 .20175 Metetra
.17 .603 0 r
.05365 .36217 .06708 .38143 .07404 .46167 .06052 .44014 Metetra
.844 .572 0 r
.06052 .44014 .07404 .46167 .08813 .49621 .07455 .47375 Metetra
.937 .256 0 r
.07455 .47375 .08813 .49621 .10679 .49942 .0932 .4768 Metetra
.956 .181 0 r
.0932 .4768 .10679 .49942 .12682 .49339 .11324 .47076 Metetra
.957 .178 0 r
.11324 .47076 .12682 .49339 .14717 .48603 .13361 .46341 Metetra
.955 .185 0 r
.13361 .46341 .14717 .48603 .16768 .47858 .15415 .45594 Metetra
.954 .191 0 r
.15415 .45594 .16768 .47858 .18834 .47113 .17483 .44847 Metetra
.952 .197 0 r
.17483 .44847 .18834 .47113 .20915 .46368 .19568 .44098 Metetra
.951 .202 0 r
.19568 .44098 .20915 .46368 .23012 .45623 .21669 .43348 Metetra
.95 .206 0 r
.21669 .43348 .23012 .45623 .25126 .44878 .23786 .42596 Metetra
.949 .21 0 r
.23786 .42596 .25126 .44878 .27255 .4413 .2592 .41841 Metetra
.948 .213 0 r
.2592 .41841 .27255 .4413 .29402 .43383 .2807 .41086 Metetra
.948 .215 0 r
.2807 .41086 .29402 .43383 .31565 .42635 .30238 .40328 Metetra
.947 .217 0 r
.30238 .40328 .31565 .42635 .33746 .41886 .32424 .39568 Metetra
.947 .218 0 r
.32424 .39568 .33746 .41886 .35944 .41135 .34627 .38805 Metetra
.947 .218 0 r
.34627 .38805 .35944 .41135 .3816 .40384 .36848 .38041 Metetra
.947 .218 0 r
.36848 .38041 .3816 .40384 .40395 .3963 .39088 .37273 Metetra
.947 .217 0 r
.39088 .37273 .40395 .3963 .42648 .38875 .41347 .36503 Metetra
.947 .216 0 r
.41347 .36503 .42648 .38875 .4492 .38119 .43624 .35731 Metetra
.948 .214 0 r
.43624 .35731 .4492 .38119 .47212 .37362 .45921 .34956 Metetra
.949 .211 0 r
.45921 .34956 .47212 .37362 .49523 .36603 .48238 .34178 Metetra
.949 .208 0 r
.48238 .34178 .49523 .36603 .51854 .35843 .50575 .33397 Metetra
.95 .204 0 r
.50575 .33397 .51854 .35843 .54205 .35081 .52932 .32615 Metetra
.952 .2 0 r
.52932 .32615 .54205 .35081 .56578 .34318 .5531 .31829 Metetra
.953 .195 0 r
.5531 .31829 .56578 .34318 .58971 .33554 .5771 .31041 Metetra
.954 .189 0 r
.5771 .31041 .58971 .33554 .61387 .3279 .60131 .30252 Metetra
.956 .182 0 r
.60131 .30252 .61387 .3279 .63824 .32023 .62574 .29458 Metetra
.957 .177 0 r
.62574 .29458 .63824 .32023 .66282 .31226 .65038 .28633 Metetra
.953 .194 0 r
.65038 .28633 .66282 .31226 .68746 .30105 .67509 .27488 Metetra
.914 .341 0 r
.67509 .27488 .68746 .30105 .71125 .27276 .69903 .24671 Metetra
.77 .767 0 r
.69903 .24671 .71125 .27276 .73202 .20175 .72016 .17699 Metetra
0 .531 .017 r
.04285 .32471 .05365 .36217 .06052 .44014 .0508 .3918 Metetra
.71 .755 0 r
.0508 .3918 .06052 .44014 .07455 .47375 .06521 .42032 Metetra
.844 .572 0 r
.06521 .42032 .07455 .47375 .0932 .4768 .08379 .42227 Metetra
.863 .513 0 r
.08379 .42227 .0932 .4768 .11324 .47076 .10366 .41628 Metetra
.864 .509 0 r
.10366 .41628 .11324 .47076 .13361 .46341 .12384 .4091 Metetra
.863 .511 0 r
.12384 .4091 .13361 .46341 .15415 .45594 .14419 .40179 Metetra
.862 .514 0 r
.14419 .40179 .15415 .45594 .17483 .44847 .1647 .39442 Metetra
.862 .517 0 r
.1647 .39442 .17483 .44847 .19568 .44098 .18537 .38701 Metetra
.861 .519 0 r
.18537 .38701 .19568 .44098 .21669 .43348 .20621 .37954 Metetra
.86 .521 0 r
.20621 .37954 .21669 .43348 .23786 .42596 .22722 .37204 Metetra
.86 .522 0 r
.22722 .37204 .23786 .42596 .2592 .41841 .24839 .36447 Metetra
.859 .524 0 r
.24839 .36447 .2592 .41841 .2807 .41086 .26974 .35685 Metetra
.859 .525 0 r
.26974 .35685 .2807 .41086 .30238 .40328 .29126 .34919 Metetra
.859 .526 0 r
.29126 .34919 .30238 .40328 .32424 .39568 .31295 .34147 Metetra
.859 .526 0 r
.31295 .34147 .32424 .39568 .34627 .38805 .33483 .33369 Metetra
.859 .526 0 r
.33483 .33369 .34627 .38805 .36848 .38041 .35688 .32587 Metetra
.859 .526 0 r
.35688 .32587 .36848 .38041 .39088 .37273 .37912 .31798 Metetra
.859 .526 0 r
.37912 .31798 .39088 .37273 .41347 .36503 .40155 .31004 Metetra
.859 .525 0 r
.40155 .31004 .41347 .36503 .43624 .35731 .42416 .30205 Metetra
.859 .524 0 r
.42416 .30205 .43624 .35731 .45921 .34956 .44696 .29399 Metetra
.86 .523 0 r
.44696 .29399 .45921 .34956 .48238 .34178 .46996 .28588 Metetra
.86 .522 0 r
.46996 .28588 .48238 .34178 .50575 .33397 .49316 .27771 Metetra
.861 .52 0 r
.49316 .27771 .50575 .33397 .52932 .32615 .51655 .26947 Metetra
.861 .518 0 r
.51655 .26947 .52932 .32615 .5531 .31829 .54015 .26118 Metetra
.862 .516 0 r
.54015 .26118 .5531 .31829 .5771 .31041 .56395 .25283 Metetra
.863 .513 0 r
.56395 .25283 .5771 .31041 .60131 .30252 .58796 .24441 Metetra
.864 .51 0 r
.58796 .24441 .60131 .30252 .62574 .29458 .61218 .23592 Metetra
.864 .509 0 r
.61218 .23592 .62574 .29458 .65038 .28633 .6366 .2271 Metetra
.859 .524 0 r
.6366 .2271 .65038 .28633 .67509 .27488 .66112 .21545 Metetra
.822 .635 0 r
.66112 .21545 .67509 .27488 .69903 .24671 .68503 .18929 Metetra
.442 .687 0 r
.68503 .18929 .69903 .24671 .72016 .17699 .70666 .12717 Metetra
0 .349 .286 r
.03634 .26033 .04285 .32471 .0508 .3918 .04721 .30425 Metetra
0 .531 .017 r
.04721 .30425 .0508 .3918 .06521 .42032 .06271 .3216 Metetra
.17 .603 0 r
.06271 .3216 .06521 .42032 .08379 .42227 .08119 .32086 Metetra
.22 .62 0 r
.08119 .32086 .08379 .42227 .10366 .41628 .10063 .31469 Metetra
.227 .623 0 r
.10063 .31469 .10366 .41628 .12384 .4091 .12034 .30766 Metetra
.229 .623 0 r
.12034 .30766 .12384 .4091 .14419 .40179 .14022 .30047 Metetra
.23 .624 0 r
.14022 .30047 .14419 .40179 .1647 .39442 .16026 .29319 Metetra
.231 .624 0 r
.16026 .29319 .1647 .39442 .18537 .38701 .18046 .28582 Metetra
.232 .624 0 r
.18046 .28582 .18537 .38701 .20621 .37954 .20083 .27837 Metetra
.232 .624 0 r
.20083 .27837 .20621 .37954 .22722 .37204 .22137 .27083 Metetra
.233 .625 0 r
.22137 .27083 .22722 .37204 .24839 .36447 .24208 .2632 Metetra
.233 .625 0 r
.24208 .2632 .24839 .36447 .26974 .35685 .26296 .25549 Metetra
.234 .625 0 r
.26296 .25549 .26974 .35685 .29126 .34919 .284 .24768 Metetra
.234 .625 0 r
.284 .24768 .29126 .34919 .31295 .34147 .30522 .23979 Metetra
.234 .625 0 r
.30522 .23979 .31295 .34147 .33483 .33369 .32662 .23181 Metetra
.234 .625 0 r
.32662 .23181 .33483 .33369 .35688 .32587 .34819 .22374 Metetra
.234 .625 0 r
.34819 .22374 .35688 .32587 .37912 .31798 .36994 .21557 Metetra
.234 .625 0 r
.36994 .21557 .37912 .31798 .40155 .31004 .39187 .20732 Metetra
.234 .625 0 r
.39187 .20732 .40155 .31004 .42416 .30205 .41398 .19897 Metetra
.234 .625 0 r
.41398 .19897 .42416 .30205 .44696 .29399 .43627 .19052 Metetra
.233 .625 0 r
.43627 .19052 .44696 .29399 .46996 .28588 .45874 .18198 Metetra
.233 .624 0 r
.45874 .18198 .46996 .28588 .49316 .27771 .48141 .17335 Metetra
.232 .624 0 r
.48141 .17335 .49316 .27771 .51655 .26947 .50426 .16461 Metetra
.231 .624 0 r
.50426 .16461 .51655 .26947 .54015 .26118 .5273 .15578 Metetra
.231 .624 0 r
.5273 .15578 .54015 .26118 .56395 .25283 .55053 .14684 Metetra
.23 .623 0 r
.55053 .14684 .56395 .25283 .58796 .24441 .57395 .13779 Metetra
.229 .623 0 r
.57395 .13779 .58796 .24441 .61218 .23592 .59757 .12863 Metetra
.226 .622 0 r
.59757 .12863 .61218 .23592 .6366 .2271 .62137 .11918 Metetra
.21 .617 0 r
.62137 .11918 .6366 .2271 .66112 .21545 .6453 .10777 Metetra
.118 .585 0 r
.6453 .10777 .66112 .21545 .68503 .18929 .66891 .08652 Metetra
0 .475 .13 r
.66891 .08652 .68503 .18929 .70666 .12717 .69111 .04089 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.08206 .23755 m
.08679 .24211 L
s
[(-10)] .07261 .22845 1 .96289 Mshowa
.27211 .16314 m
.27652 .16799 L
s
[(-5)] .26329 .15343 .90843 1 Mshowa
.477 .08291 m
.48103 .08809 L
s
[(0)] .46894 .07256 .77832 1 Mshowa
.125 Mabswid
.11896 .22311 m
.12176 .22587 L
s
.1564 .20844 m
.15917 .21125 L
s
.1944 .19357 m
.19713 .19641 L
s
.23297 .17847 m
.23565 .18134 L
s
.31185 .14758 m
.31445 .15053 L
s
.35219 .13178 m
.35475 .13477 L
s
.39315 .11574 m
.39567 .11877 L
s
.43475 .09945 m
.43722 .10252 L
s
.51991 .06611 m
.52228 .06925 L
s
.5635 .04904 m
.56582 .05222 L
s
.60779 .03169 m
.61005 .03492 L
s
.6528 .01407 m
.655 .01734 L
s
.04569 .2518 m
.04856 .25449 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00c?ooool2o`0005;ooooo0039
ooooo`Go0000D_ooool00<Oooooo0_l00004ooooo`;o0000DOooool00<Cooooo0ol00006ooooo`03
o`000?oooooo0000053ooooo0032ooooo`?o00002?ooool00ol0003oooooo`00001@ooooo`00_ooo
ool3o`0000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0001?ooooo`00_Ooo
ool2o`0000kooooo00Go0000ooooooooooooooooo`00001>ooooo`00^_ooool3o`00013ooooo00Go
0000ooooooooooooooooo`00001>ooooo`00]oooool3o`0001?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1;ooooo`00]Oooool2o`000003ooooool0003o000001Cooooo00Co0000
oooooooooooooooo0_l0001<ooooo`00/_ooool3o`0001Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1:ooooo`00TOooool2o`0001gooooo0_l0000Looooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0BOooool0093ooooo00Co0000oooooooooooo00006Oooool3o`00
01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`18ooooo`00T?ooool01?l0003o
ooooooooool0000Gooooo`?o00007oooool2o`0000Kooooo00?o0000ooooooooool0B?ooool0093o
oooo00Co0000oooooooooooo00005?ooool3o`0000;ooooo00?o0000ooooooooool07Oooool2o`00
00Oooooo00?o0000ooooooooool0Aoooool0093ooooo00Co0000oooooooooooo00004_ooool2o`00
02Cooooo00Co0000o`1i8Ol0003o00001oooool00ol0003oooooooooo`16ooooo`00T?ooool01?l0
003oooooooooool0000?ooooo`?o00009_ooool01?l0003o07TQo`000?l00007ooooo`03o`000?oo
oooooooo04Kooooo002Aooooo`;o00003_ooool2o`0002Sooooo00?o0000o`1i8Ol0NB400_l00008
ooooo`03o`000?oooooooooo04Gooooo002Nooooo`Go0000:?ooool00ol0003o07TQo`1i8@02o`00
00Oooooo00?o0000ooooool00000A_ooool009cooooo0_l0000/ooooo`04o`000?l0NB7o07TQo`1i
8@;o00002Oooool00ol0003oooooooooo`14ooooo`00VOooool3o`0002kooooo00Oo0000o`1i8Ol0
NB7o07TQo`000?l0NB7o000000Wooooo00?o0000ooooooooool02oooool3o`0003Gooooo002Foooo
o`?o0000<?ooool00ol0003o07TQo`1i8@02o`1i8@03o`000?l0NB7o000000[ooooo00?o0000oooo
ooooool02Oooool01Ol0003ooooooooooooooooo000003Cooooo002Dooooo`?o0000<_ooool00ol0
003o07TQo`1i8@02o`1i8@03o`000?l0NB7o000000[ooooo00?o0000ooooooooool00oooool5o`00
00Gooooo00?o0000ooooooooool0<_ooool0097ooooo0ol00003ooooo`03o`000?oooooooooo02go
oooo0_l00005o`1i8@03o`000?l0NB7o000000_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0booooo`00Soooool2o`0003Gooooo00?o0000oajE0?l000001Ol0NB400ol0003o07TQ
o`00000<ooooo`03o`000?oooooooooo00Oooooo1?l0000eooooo`00S?ooool3o`0003Kooooo00Co
0000oajE0?lNU@3o00001_l0NB42o`0000cooooo0_l00008ooooo`03o`000?oooooooooo03Kooooo
002:ooooo`;o0000>?ooool01Ol0003o7YD0oajE0?lNU@3o000000Ko07TQ00?o0000o`1i8Ol00000
2_ooool00ol0003oooooo`000008ooooo`Go0000=?ooool008Oooooo0ol00002ooooo`03o`000?oo
oooooooo03Cooooo00?o0000oajE0?lNU@000olNU@000ol0003o07TQo`1i8@03o`1i8@03o`000?l0
NB7o000000gooooo00?o0000ooooooooool0?_ooool008Gooooo0_l0000jooooo`;o00001_lNU@00
0ol0003o07TQo`1i8@03o`1i8@03o`000?l0NB7o000000gooooo00?o0000ooooooooool0?_ooool0
08;ooooo0ol0000jooooo`;o000000?o=Id0o`000?lNU@001OlNU@000ol0003o07TQo`1i8@03o`1i
8@03o`000?l0NB7o000000kooooo00?o0000ooooooooool0?Oooool0083ooooo0_l0000kooooo`;o
00000oleW@000ol0003o7YD0oajE0004oajE0003o`000?l0NB7o07TQ00?o07TQ00?o0000o`1i8Ol0
00003_ooool00ol0003oooooooooo`0mooooo`00OOooool3o`000003ooooool0003ooooo03Sooooo
0_l00005ocFM0003o`000?lNU@3o7YD000Co7YD000?o0000o`1i8Ol0NB400ol0NB401?l0003o07TQ
o`1i8Ol0000>ooooo`03o`000?oooooooooo03cooooo001Jooooo`?o00007_ooool2o`0003cooooo
0_l000000oliW`3o0000ocFM0005ocFM0003o`000?lNU@3o7YD000?o7YD000?o0000o`1i8Ol0NB40
0ol0NB401?l0003o07TQo`1i8Ol0000?ooooo`03o`000?oooooooooo03_ooooo001Iooooo`05o`00
0?ooooooooooooooool000006_ooool3o`0003cooooo0_l00003ocVO0003o`000?leW@3o=Id000Co
=Id000?o0000oajE0?lNU@000olNU@000ol0003o07TQo`1i8@03o`1i8@04o`000?l0NB7o07TQo`00
00oooooo0_l0000looooo`00Doooool5o`0000Gooooo00?o0000ooooooooool05Oooool3o`0003co
oooo0ol00005ocVO0003o`000?leW@3o=Id000Co=Id000?o0000oajE0?lNU@001?lNU@000ol0003o
07TQo`1i8@02o`1i8@04o`000?l0NB7o07TQo`00013ooooo00?o0000ooooooooool0>_ooool005go
oooo00?o0000ooooooooool04oooool2o`000003ooooool0003ooooo03Wooooo0ol00002ocZO0003
o`000?liW`3o>Il000?o>Il000?o0000ocFM0?leW@001?leW@000ol0003o7YD0oajE0004oajE0003
o`000?l0NB7o07TQ00;o07TQ00Co0000o`1i8Ol0003o00004Oooool00ol0003oooooooooo`0ioooo
o`00FOooool4o`0001?ooooo0ol0000kooooo`?o00001OljW`000ol0003o>Il0ocVO0004ocVO0003
o`000?leW@3o=Id000?o=Id000?o0000oajE0?lNU@001?lNU@000ol0003o07TQo`1i8@02o`1i8@05
o`000?l0NB7o0000og6_0?l000004?ooool00ol0003oooooooooo`0iooooo`00FOooool00ol0003o
ooooooooo`0Booooo`;o0000??ooool2o`000003ocZO0?l0003o>Yl000Go>Yl000?o0000ocVO0?li
W`001?liW`000ol0003o=Id0ocFM0003ocFM0003o`000?lNU@3o7YD000Co7YD000?o0000o`1i8Ol0
NB400_l0NB401Ol0003o07TQo`000?ma[`3o0000017ooooo00?o0000ooooooooool0>?ooool005Wo
oooo1Ol0000=ooooo`?o0000??ooool2o`0000?o>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o
>Il0ocVO0004ocVO0003o`000?leW@3o=Id000?o=Id000?o0000oajE0?lNU@001?lNU@000ol0003o
07TQo`1i8@02o`1i8@;o00000_ma[`000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Oo
oooo001Yooooo`?o0000??ooool2o`0000Go>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o>Il0
ocVO0004ocVO0003o`000?leW@3o=Id000Co=Id000?o0000oajE0?lNU@000olNU@000ol0003o07TQ
o`1i8@02o`1i8@;o00000oma[`000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Oooooo
001Vooooo`?o00000oooool00ol0003oooooooooo`0fooooo`?o000000?o>il0o`000?ljW`001Olj
W`000ol0003o>Yl0ocZO0004ocZO0003o`000?liW`3o>Il000?o>Il000?o0000ocFM0?leW@001?le
W@000ol0003o7YD0oajE0003oajE0003o`000?l0NB7o07TQ00;o07TQ0_l00003og6_0003o`000?oo
oooooooo013ooooo00?o0000ooooooooool0=_ooool006Cooooo0_l0000looooo`?o00001?lkW`00
0ol0003o>Yl0ocZO0004ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocVO0?liW`000oliW`00
0ol0003o=Id0ocFM0004ocFM0003o`000?lNU@3o7YD000Co7YD000Co0000o`1i8Ol0NB7o07TQ0_l0
0003og6_0003o`000?oooooooooo013ooooo0_l0000gooooo`00HOooool3o`0003_ooooo0ol00000
0olkW`3o0000oc^O0004oc^O0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocZO0?ljW`001?ljW`00
0ol0003o>Il0ocVO0003ocVO0003o`000?leW@3o=Id000Co=Id000?o0000oajE0?lNU@001?lNU@00
1?l0003o07TQo`1i8Ol0NB42o`0000CoLJl000?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0eooooo`00Goooool3o`0003[ooooo0ol00004oc^O0003o`000?lkW`3o>il000Co>il000?o0000
ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?liW`3o>Il000Co>Il000?o0000
ocFM0?leW@000oleW@000ol0003o7YD0oajE0004oajE0004o`000?l0NB7o07TQo`1i8@;o00001?ma
[`000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Cooooo001Looooo`?o00000oooool0
0ol0003oooooooooo`0eooooo`;o000000?o>il0o`000?lkW`001?lkW`000ol0003o>il0oc^O0004
oc^O0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o>Il0ocVO0004
ocVO0003o`000?leW@3o=Id000?o=Id000?o0000oajE0?lNU@001?lNU@001_l0003o07TQo`1i8Ol0
003oLJl0o`0000CoLJl000?o0000ooooooooool04_ooool00ol0003oooooooooo`0cooooo`00F_oo
ool2o`0003cooooo0_l00003oc^O0003o`000?lkW`3o>il000Co>il000?o0000oc^O0?lkW`000olk
W`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocVO0?liW`001?li
W`000ol0003o=Id0ocFM0003ocFM0003o`000?lNU@3o7YD000Co7YD000Ko0000o`1i8Ol0NB7o0000
og6_0?l00005og6_0003o`000?oooooooooo017ooooo00?o0000ooooooooool0<oooool005Oooooo
0ol0000looooo`;o00001OlkW`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000?o>il0
00?o0000ocZO0?ljW`000oljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?liW`3o>Il000Co>Il0
00?o0000ocFM0?leW@001?leW@000ol0003o7YD0oajE0003oajE0006o`000?l0NB7o07TQo`000?ma
[`3o00001Oma[`000ol0003oooooooooo`0Booooo`03o`000?oooooooooo03;ooooo001Dooooo`?o
0000??ooool3o`000003oc^O0?l0003o>il000Co>il000?o0000oc^O0?lkW`001?lkW`000ol0003o
>il0oc^O0003oc^O0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o
>Il0ocVO0004ocVO0003o`000?leW@3o=Id000Co=Id000?o0000oajE0?lNU@000olNU@000ol0003o
07TQo`000002og6_0003o`000?ma[`3oLJl000?oLJl000?o0000ooooooooool04oooool00ol0003o
ooooooooo`0aooooo`00D_ooool2o`0000?ooooo00?o0000ooooooooool0=_ooool3o`0000Co>il0
00?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000?o>il0
00?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?liW`3o>Il000Co>Il0
00?o0000ocFM0?leW@001?leW@000ol0003o7YD0oajE0004oajE00;o00000_ma[`000ol0003oLJl0
og6_0003og6_00;o00005?ooool2o`0003;ooooo001?ooooo`?o0000>oooool3o`000003oc^O0?l0
003o>il000Co>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lk
W`3o>il000?o>il000?o0000ocZO0?ljW`001?ljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?li
W`3o>Il000?o>Il000?o0000ocFM0?leW@001?leW@000ol0003o7YD0oajE0004oajE00;o00000_ma
[`000ol0003oLJl0og6_0002og6_0003o`000?o5a03o000001Gooooo00?o0000ooooooooool0<?oo
ool004gooooo0_l0000kooooo`?o00001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o
>il000Co>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0004oc^O0003o`000?ljW`3o
>Yl000?o>Yl000?o0000ocZO0?ljW`001?ljW`000ol0003o>Il0ocVO0004ocVO0003o`000?leW@3o
=Id000?o=Id000?o0000oajE0?lNU@001?lNU@001Ol0003oLJl0og6_0?ma[`3o000000CoLJl000Co
0000olG40?o5a03o00005Oooool00ol0003oooooooooo`0_ooooo`00B_ooool3o`0003[ooooo0ol0
00000olkW`3o0000oc^O0004oc^O0003o`000?lkW`3o>il000Co>il000?o0000oc^O0?lkW`000olk
W`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000Co>il000?o0000ocZO0?ljW`000olj
W`000ol0003o>Yl0ocZO0004ocZO0003o`000?liW`3o>Il000Co>Il000?o0000ocFM0?leW@000ole
W@000ol0003o7YD0oajE0003oajE00;o00000oma[`000ol0003oLJl0og6_0002og6_0004o`000?o5
a03oaL@0o`0001Gooooo00?o0000ooooooooool0;oooool002;ooooo0ol00004ooooo`;o00007Ooo
ool2o`0000?ooooo00?o0000ooooooooool0=Oooool2o`0000Co>il000?o0000oc^O0?lkW`000olk
W`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`001?lk
W`000ol0003o>il0oc^O0003oc^O0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocZO0?ljW`001?lj
W`000ol0003o>Il0ocVO0004ocVO0003o`000?leW@3o=Id000?o=Id000?o0000oajE0?lNU@000_lN
U@000ol0003odZ80o`000003og6_0005o`000?ma[`3oLJl0og6_0?l000000oo5a0000ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02kooooo000Sooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00006Oooool3o`0003[ooooo0ol000000olkW`3o0000oc^O0003oc^O0003o`00
0?lkW`3o>il000Co>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000Co>il000?o0000oc^O0?lkW`000olkW`000ol0003o>Yl0ocZO0003ocZO0003o`00
0?ljW`3o>Yl000Co>Yl000?o0000ocVO0?liW`001?liW`000ol0003o=Id0ocFM0004ocFM0004o`00
0?lNU@3o7YD0o`0000?odZ8000Co0000og6_0?ma[`3o00000oma[`000ol0003oaL@0olG40002olG4
0003o`000?oooooooooo01Cooooo00?o0000ooooooooool0;Oooool001_ooooo1Ol00003ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005oooool2o`0003[ooooo0ol00004oc^O
0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O
0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O
0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>Il0ocVO0004ocVO
0003o`000?leW@3o=Id000Co=Id000?o0000oajE0?l000001?oBXP001?l0003oLJl0og6_0?l00003
og6_0003o`000?o5a03oaL@000;oaL@000?o0000ooooooooool05?ooool00ol0003oooooooooo`0]
ooooo`008oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Cooooo1?l0000i
ooooo`;o000000?o>il0o`000?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o
>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o
>il000Co>il000?o0000oc^O0?lkW`000olkW`000ol0003o>Yl0ocZO0004ocZO0003o`000?ljW`3o
>Yl000?o>Yl000?o0000ocVO0?liW`001?liW`000ol0003o=Id0ocFM0004ocFM00;o00001OoBXP00
1?l0003oLJl0og6_0?l00002og6_0003o`000?o5a03oaL@000;oaL@000?o0000olVh0?l000005_oo
ool00ol0003oooooooooo`0/ooooo`008oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0001;ooooo0_l0000kooooo`;o00000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lk
W`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lk
W`3o>il000?o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lj
W`3o>Yl000Co>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>Il0ocVO0004ocVO0003o`000?le
W@3o=Id000?o=Id00_l00006om:R0004o`000?ma[`3oLJl0o`0000;oLJl000?o0000olG40?o5a000
0_o5a0001?l0003obKP0olVh0?l0000Dooooo`03o`000?oooooo000002gooooo000Rooooo`;o0000
1?ooool01?l0003oooooooooool0000?ooooo`?o0000>oooool2o`0000Go>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000Co>il000?o0000oc^O0?lk
W`001?lkW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000ocVO0?li
W`001OliW`001ol0003o=Id0ocFM0?leW@3o0000om^60?l000001ooBXP001_l0003oLJl0og6_0?l0
003oLJl0o`0000CoaL@000Go0000olVh0?o9^03obKP0o`00000Eooooo`03o`000?oooooooooo00Ko
oooo0_l0000Sooooo`008oooool00ol0003oooooooooo`03ooooo`;o00003_ooool2o`0003_ooooo
0ol000000olkW`3o0000oc^O0004oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`00
0olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`00
1?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000Co>il000?o0000ocZO0?ljW`00
0oljW`000ol0003o>Yl0ocZO0004ocZO0003o`000?liW`3o>Il000Co>Il000Co0000ocFM0?l0003o
00000_oKQP000ol0003odZ80om:R0005om:R0003o`000?ma[`3oLJl000;o00001?o5a0000ol0003o
bKP0olVh0002olVh0003o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool0000Rooooo`00=_ooool4o`0003Wooooo0ol00004oc^O0003o`000?lkW`3o>il000?o
>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o
>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000Co
>il000?o0000oc^O0?lkW`000olkW`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000Co
>Yl000?o0000ocVO0?liW`001?liW`02o`0000GofhH000?o0000om:R0?oBXP001?oBXP000ol0003o
LJl0og6_0002o`0000CoaL@000?o0000olVh0?o9^0000_o9^002o`0001Kooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool0000Rooooo`00<oooool3o`0003[ooooo0ol000000olkW`3o
0000oc^O0004oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o
>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o
>il0oc^O0003oc^O0003o`000?lkW`3o>il000Co>il000?o0000oc^O0?lkW`000olkW`000ol0003o
>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000Co>Yl000?o0000ocVO0?liW`000_liW`03o`0000Ko
fhH000?o0000om:R0?oBXP001OoBXP001?l0003oLJl0o`000?l00004olG40007o`000?o9^03obKP0
olVh0?l0003ob[L0o`00000Fooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
8_ooool0037ooooo0_l0000kooooo`;o00001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lk
W`3o>il000?o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0002oc^O0003o`000?lk
W`3o>il000?o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lk
W`3o>il000Co>il000?o0000oc^O0?lkW`000olkW`000ol0003o>Yl0ocZO0004ocZO0003o`000?lj
W`3o>Yl000?o>Yl000?o0000ocVO0?l000000_l00002omf20003o`000?oKQP3ofhH000CofhH000?o
0000om:R0?oBXP001OoBXP000ol0003oLJl0o`000004olG40003o`000?o9^03obKP000;obKP000?o
0000olZg0?l000005oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002;ooooo
000^ooooo`?o0000>_ooool3o`000003oc^O0?l0003o>il000?o>il000?o0000oc^O0?lkW`001?lk
W`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lk
W`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olk
W`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000?o>il000?o0000ocZO0?ljW`001?lj
W`000ol0003o>Yl0ocZO0002ocZO00?o00001OoMPP000ol0003ofhH0om^60004om^60003o`000?oB
XP3odZ8000GodZ8000?o0000og6_0?l000001?o5a0000ol0003obKP0olVh0002olVh0004o`000?o:
]`3ob[L0o`0001Kooooo0_l00003ooooo`04o`000?ooooooooooo`0002;ooooo000/ooooo`;o0000
0_ooool00ol0003oooooooooo`0eooooo`?o00001?lkW`000ol0003o>il0oc^O0002oc^O0003o`00
0?lkW`3o>il000Co>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000;o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?ljW`3o>Yl000Co>Yl000?o0000ocZO0?l000000_l000000ooMPP3o0000omf20006omf20003o`00
0?oKQP3ofhH000CofhH000?o0000om:R0?oBXP001?oBXP000ol0003oLJl0o`000004olG40005o`00
0?o9^03obKP0olVh0?l000000oo:]`000ol0003oooooooooo`0Cooooo`03o`000?oooooo000000Co
oooo0_l0000Sooooo`00:Oooool3o`0003Wooooo0ol000000olkW`3o0000oc^O0004oc^O0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0004oc^O0003o`00
0?lkW`3o>il000Co>il000?o0000ocZO0?ljW`000_ljW`03o`0000CogH8000?o0000omf20?oMPP00
1OoMPP000ol0003ofhH0om^60004om^60003o`000?oBXP3odZ8000GodZ800_l00003olG40003o`00
0?o9^03obKP000;obKP000Co0000olZg0?o:]`3ob[L00_l0000Gooooo`03o`000?oooooooooo02Ko
oooo000Wooooo`;o0000>_ooool2o`0000Co>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0
oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0
oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0
oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`001?lkW`000ol0003o>il0
oc^O0004oc^O0003o`000?ljW`3o000000;o000000?og8<0o`000?oMPP001OoMPP000ol0003ogH80
omf20004omf20003o`000?oKQP3ofhH000CofhH000?o0000om:R0?oBXP000_oBXP05o`0000?oaL@0
00?o0000olVh0?o9^0000_o9^0001?l0003ob[L0olZg0?l00002olZg0003o`000?oooooooooo01Go
oooo00?o0000ooooooooool09Oooool002Cooooo0ol0000iooooo`?o000000?o>il0o`000?lkW`00
0olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`00
0olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`00
0olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`00
0olkW`000ol0003o>il0oc^O0005oc^O0003o`000?lkW`3o>il000;o>il00ol00004omb30003o`00
0?oMPP3ogH8000CogH8000?o0000omf20?oMPP001?oMPP000ol0003ofhH0om^60004om^60003o`00
0?oBXP3o000000;o00000ooBXP000ol0003oaL@0o`000002olG40005o`000?o9^03obKP0olVh0?l0
00000oo:]`001Ol0003ob[L0olZg0?o:]`3o000001Kooooo00?o0000ooooooooool09Oooool002?o
oooo0_l000000ooooooo0000ooooo`0eooooo`?o00001?lkW`000ol0003o>il0oc^O0002oc^O0003
o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003
o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003
o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0004oc^O0003
o`000?lkW`3o>il000Co>il000?o0000oc^O0?l000000_l000000ooLQ03o0000omb30005omb30003
o`000?oMPP3ogH8000?ogH8000?o0000omf20?oMPP001?oMPP000ol0003ofhH0om^60003om^600?o
00001OoBXP001?l0003ojEL0o`000?o5a002o`0000CobKP000Go0000olZg0?o:]`3ob[L0o`000003
olZg0003o`000?oooooooooo01Gooooo00?o0000ooooooooool09?ooool002?ooooo0ol0000doooo
o`?o000000?o>il0o`000?lkW`001?lkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il0
00Co>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il0
00?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il0
00?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il0
00?o>il00ol00004omb40003o`000?oLP`3og8<000Cog8<000?o0000omf20?oMPP000ooMPP000ol0
003ogH80omf20005omf20003o`000?oKQP3o000000;o00000_oKQP000ol0003odZ80om:R0002om:R
0004o`000?oYE`3ojEL0o`0000;oaL@000?o0000olVh0?o9^0000_o9^0001?l0003ob[L0olZg0?l0
0004olZg00;o00005oooool00ol0003oooooooooo`0Sooooo`008oooool01?l0003oooooooooool0
000aooooo`;o00001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o
0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o
0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o
0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000?o>il000?o
0000oc^O0?lkW`000ol000000ooLQ03o0000omb40005omb40003o`000?oLP`3og8<000?og8<000?o
0000omf20?oMPP001?oMPP000ol0003ogH80omf20003omf200?o00001OoKQP001Ol0003odZ80om:R
0?oBXP3o000000CojEL000?o0000olG40?l000000oo9^0001Ol0003ob[L0olZg0?o:]`3o000000?o
b[L000Co0000olZh0?o:^03o00005Oooool2o`0002Gooooo000Sooooo`05o`000?oooooooooooooo
ool00000;Oooool3o`000003oc^O0?l0003o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0
003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`000ol0
003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0
003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`001?lkW`000ol0
003o>il0oc^O0003oc^O00?o00001?oLQ0000ol0003og8@0omb40004omb40003o`000?oLP`3og8<0
00?og8<000?o0000omf20?oMPP001?oMPP000ol0003ogH80omf20003o`000003omf20?l0003ofhH0
00GofhH000Co0000om:R0?oBXP3o00001OoYE`02o`000005olVh0?l0003obKP0olVh0?l000000oo:
]`001Ol0003ob[L0olZg0?o:]`3o000000?ob[P000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Rooooo`008_ooool3o`0000?ooooo00?o0000ooooooooool09oooool3o`0000Co>il000?o
0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o
0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000Co>il000?o
0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o
0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il00_l0
0007omb40003o`000?oLQ03og8@000?og8@000?o0000omb30?oLP`001?oLP`000ol0003ogH80omf2
0003omf200?o00001?oMPP000ol0003ofhH0om^60005om^600;o00001ooYE`001_l0003obKP0olVh
0?l0003obKP0o`0000?ob[L000Go0000olZg0?o:]`3ob[L0o`000003olZh00;o00005_ooool00ol0
003oooooooooo`0Qooooo`002Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?o
oooo0ol00005ooooo`?o00001?ooool00ol0003oooooooooo`0Sooooo`?o000000?o>il0o`000?lk
W`001?lkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000Co>il000?o0000oc^O0?lk
W`000_lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lk
W`001?lkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?l0
00000_l000000ooLQ@3o0000omb40006omb40003o`000?oLQ03og8@000?og8@000?o0000omb30?oL
P`001?oLP`001?l0003ogH80omf20?oMPP04o`0000GogH8000?o0000om^60?oKQP001?oKQP02o`00
00SojEL000?o0000olVh0?o9^0000_l00003olZg0005o`000?o:]`3ob[L0olZg0?l000001?o:^000
0ol0003obKP0o`00000Eooooo`03o`000?oooooooooo027ooooo0008ooooo`04o`000?oooooooooo
o`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo0ol0
0005ooooo`03o`000?oooooooooo023ooooo0_l00004oc^O0003o`000?lkW`3o>il000?o>il000?o
0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000;o>il000?o
0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o
0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000?o>il000?o
0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O00?o00001?oLQ@000ol0003og8@0omb4
0005omb40003o`000?oLQ03og8@000?og8@000?o0000omb30?oLP`001?oLP`04o`0000?ogH8000?o
0000omf20?oMPP001?oMPP000ol0003ofhH0om^60003o`000003oo<a0?l0003ojEL000KojEL000?o
0000oni40?l000000_o9^0001Ol0003ob[L0olZg0?o:]`3o000000?ob[L000Go0000olZh0?o:^03o
b[P0o`000003olVh0003o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool000Sooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000001_ooool00ol0003oooooooooo`0Looooo`?o000000?o>il0o`000?lk
W`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lk
W`001?lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?l0
00000_l000000ooLQ@3o0000omb50005omb50003o`000?oLQ03og8@000Cog8@000?o0000omb40?oL
Q0001?oLQ0001?l0003og8<0omb30?oLP`04o`0000GogH8000?o0000omf20?oMPP001?oMPP03o`00
00Golc4000?o0000onUG0?oYE`000ooYE`001_l0003okT@0oni40?o^A03o0000olVh00;o00000_o:
]`001Ol0003ob[L0olZg0?o:]`3o000000?ob[P000Go0000olVh0?o9^03obKP0o`00000Fooooo`03
o`000?oooooooooo01oooooo0008ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000oooo
ooooool06Oooool2o`0000Co>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003oc^O
0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O
0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O
0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O
0003o`000?lkW`3o>il000;o>il00ol00004omb50003o`000?oLQ@3og8D000Cog8D000?o0000omb4
0?oLQ0001?oLQ0000ol0003og8@0omb40004omb400Co00000ooLP`000ol0003ogH80omf20003omf2
0003o`000?oMPP3ogH8000?ogH800_l00007oo<a0003o`000?oYE`3ojEL000;ojEL000?o0000oni4
0?o^A0000_o^A002o`0000;ob[L000?o0000olZg0?l000000oo:]`001Ol0003ob[P0olZh0?o:^03o
000000?obKP00_l0000Eooooo`03o`000?oooooooooo01oooooo0008ooooo`04o`000?oooooooooo
o`0000Wooooo00Co0000oooooooooooooooo1?l00005ooooo`Co00001oooool00ol0003ooooooooo
o`0Eooooo`?o000000?o>il0o`000?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lk
W`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lk
W`3o>il000;o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lk
W`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lk
W`3o>il000?o>il000?o0000oc^O0?l000000_l000000ooLQ@3o0000omb50005omb50003o`000?oL
Q@3og8D000?og8D000?o0000omb40?oLQ0001OoLQ0001?l0003og8@0omb40?oLQ003o`0000Kog8<0
00?o0000omf20?oMPP001?oMPP000ol0003ogH80o`000002o`000003oo@]0?l0003olc4000Oolc40
00Go0000onUG0?oYE`3ojEL0o`000005oni40003o`000?o:]`3ob[L000;o00000oo:]`001Ol0003o
b[P0olZh0?o:^03o000000?obKP000?o0000olVh0?l000005Oooool2o`00023ooooo0008ooooo`04
o`000?ooooooooooo`0000Sooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo00Co0000oooo
ool0003o00002?ooool00ol0003oooooooooo`0Aooooo`?o00001?lkW`000ol0003o>il0oc^O0002
oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003
oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003
oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003
oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`03o`0000Cog8D000?o0000
omb50?oLQ@001?oLQ@000ol0003og8D0omb50004omb50003o`000?oLQ03og8@000Cog8@01?l00002
omb40003o`000?oLP`3og8<000Cog8<000?o0000omf20?oMPP000ooMPP03o`0000Gom2d000?o0000
oo<a0?oc<@001Ooc<@001?l0003ojEL0onUG0?l00006oni40005o`000?o:]`3ob[L0olZg0?l00000
0oo:]`001Ol0003ob[P0olZh0?o:^03o000000?obKP000Co0000olVh0?o9^03o00005_ooool00ol0
003oooooooooo`0Mooooo`002Oooool2o`0000[ooooo00Co0000oooooooooooooooo1Ol00003oooo
o`Go00002Oooool00ol0003oooooooooo`0=ooooo`?o000000?o>Yl0o`000?lkW`001?lkW`000ol0
003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`000ol0
003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`000ol0
003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0
003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?l000000_l000000ooK
QP3o0000omb50005omb50003o`000?oLQ@3og8D000?og8D000?o0000omb50?oLQ@001?oLQ@000ol0
003og8@0omb40003omb400;o00001OoLQ0000ol0003og8<0omb30005omb30003o`000?oMPP3o0000
00;o000000?om2h0o`000?od;@001Ood;@000ol0003olc40oo<a0005oo<a0003o`000?oYE`3o0000
00KokT@000?o0000onm40?l000000_o:]`02o`0000;ob[L000Go0000olZh0?o:^03ob[P0o`000003
olVh0004o`000?o9^03obKP0o`0001Kooooo00?o0000ooooooooool07Oooool0027ooooo00Ko0000
oooooooooooo0000o`1IBOl00009ooooo`03o`000?oooooooooo00[ooooo0_l00004ocZO0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000;o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000;o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O00?o0000
1?oKQP000ol0003og8D0omb50004omb50003o`000?oLQ@3og8D000Cog8D000?o0000omb50?oLQ@00
0ooLQ@000ol0003og8@0omb40003o`000003omb40?l0003og8@000Gog8@000?o0000omb30?oLP`00
0_oLP`04o`0000Gom2h000?o0000oo@]0?od;@001?od;@000ol0003olc40oo<a0004oo<a00;o0000
1_o^A0001?l0003okd@0onm40?o_A002o`0000;ob[L000?o0000olZg0?l000000_o:^0001Ol0003o
bKP0olVh0?o9^03o000000?obKP00_l0000Fooooo`03o`000?oooooooooo01cooooo000Qooooo`;o
000000Coooooo`000?l0FDWo00002_ooool00ol0003oooooooooo`06ooooo`?o000000?o>Yl0o`00
0?ljW`000oljW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O
0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O
0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O
0?lkW`000olkW`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O
0?l000000_l000000ooKQP3o0000om^60005om^60003o`000?oLQ@3og8D000?og8D000?o0000omb5
0?oLQ@001?oLQ@000ol0003og8D0omb50003omb500?o00001?oLQ0000ol0003og8@0omb40004omb4
0003o`000?oLP`3o000000;o00000_od<0000ol0003om2h0oo@^0004oo@^0003o`000?od;@3om2d0
00Gom2d000Co0000oo<a0?oc<@3olc400_l000000ooh7@3o0000oni40004oni40003o`000?o_A03o
kd@000?okd@000?o0000olZg0?o:]`000_l00003olZh0005o`000?o9^03obKP0olVh0?l000000_o9
^0001?l0003obKP0olVh0?l0000Fooooo`03o`000?oooooooooo01_ooooo000Qooooo`05o`000?oo
ooooooooo`000?l0FDT00_l0000:ooooo`03o`000?oooooooooo00;ooooo0ol00004ocZO0003o`00
0?ljW`3o>Yl000;o>Yl000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003oc^O0003o`00
0?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0004oc^O0003o`00
0?lkW`3o>il000;o>il000?o0000oc^O0?lkW`001?lkW`001?l0003o>il0oc^O0?lkW`03o`0000Co
fhH000?o0000om^60?oKQP001?oKQP000ol0003og8D0omb50003omb50003o`000?oLQ@3og8D000Co
g8D000?o0000omb50?oLQ@000ol000000ooLQ@3o0000omb40005omb40003o`000?oLQ03og8@000;o
g8@00ol00006oo@`0003o`000?od;P3om2h000Com2h000?o0000oo@]0?od;@001?od;@001?l0003o
lc40o`000?l00004ooPM0005o`000?o^A03okT@0oni40?l000001_o_A0001Ol0003ob[L0olZg0?o:
]`3o000000?ob[P000Go0000olVh0?o9^03obKP0o`000002olVh0005o`000?o9^03obKP0olVh0?l0
00005Oooool00ol0003oooooooooo`0Kooooo`008Oooool01?l0003oooooooooooooool2o`000003
o`271?l0003ooooo00Wooooo1?l00002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?lj
W`000_ljW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000Co>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0003oc^O00Co000000?ofhH0o`000?oKQP001OoKQP000ol0003o
fhH0om^60003om^60003o`000?oLQ@3og8D000?og8D000?o0000omb50?oLQ@001?oLQ@03o`0000Co
g8D000?o0000omb40?oLQ0001?oLQ0000ol0003og8@0o`000002o`000003oo<a0?l0003om30000Ko
m30000?o0000oo@^0?od;P001?od;P000ol0003om2d0oo@]0003oo@]00?o00001ooh7@000ol0003o
kT@0o`000006onm40003o`000?o^A@3o000000;ob[L00_l00002olZh0005o`000?o9^03obKP0olVh
0?l000000_o9^0001Ol0003obKP0olVh0?o9^03o000001Kooooo00?o0000ooooooooool06_ooool0
027ooooo0_l00002ooooo`;o00000_l0Q`@00ol0003oooooooooo`04ooooo`?o000000?o>9h0o`00
0?ljW`000oljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000oc^O
0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O
0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O
0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O
0?lkW`000_lkW`02o`0000CofhH000?o0000om^60?oKQP001?oKQP000ol0003ofhH0om^60003om^6
0003o`000?oLQ@3og8D000Cog8D000?o0000omb50?oLQ@000ol000000ooLQ@3o0000omb50004omb5
0003o`000?oLQ03og8@000?og8@00ol00005oo<a0003o`000?od<03om30000Gom30000?o0000oo@^
0?od;P000ood;P000ol0003om2d0oo@]0003o`0000;onQT000?o0000ooPM0?oh7@001Ooh7@02o`00
00Kokd@000Co0000oni50?o^A@3okTD00_l000001?o:^03o0000olZh0?l00003olVh0004o`000?o9
^03obKP0o`0000CobKP00_l0000Dooooo`03o`000?oooooo000001_ooooo000>ooooo`;o00001?oo
ool01?l0003oooooooooooooool5o`0000Cooooo00Co0000oooooooooooooooo0_l00003o`2710Ko
00001?lhWP000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?lj
W`000oljW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0o`000002o`000003om^60?l0003ofhH000CofhH000?o0000om^60?oK
QP000ooKQP000ol0003ofhH0om^60003om^60003o`000?oLQ@3og8D000Cog8D00ol00004omb50003
o`000?oLQ@3og8D000Cog8D000?o0000omb40?l000000_l000000ooc<`3o0000oo<a0005oo<a0003
o`000?od<03om30000Gom30000?o0000oo@^0?od;P000ood;P03o`0000KonQT000?o0000ooPM0?oh
7@000_oh7@02o`000003ooTM0?l0003okd@000Cokd@000?o0000oni50?o^A@000oo^A@000ol0003o
b[P0olZh0002o`0000?obKP000Co0000olVh0?o9^03o00000oo9^0001?l0003obKT0olVi0?l0000E
ooooo`03o`000?oooooooooo01Wooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000oooool2o`0000?ooooo0_l00003o`271003o`000?l[VP3o:iX000;o:iX000?o
0000ocRN0?lhWP000_lhWP000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o
0000ocZO0?ljW`000oljW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000;o>il000?o
0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o
0000oc^O0?lkW`001?lkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o
0000oc^O0?lkW`000_lkW`03o`0000CofhH000?o0000om^60?oKQP000ooKQP000ol0003ofhH0om^6
0003om^60003o`000?oKQP3ofhH000CofhH000Co0000omb50?oLQ@3og8D00ol00006omb50003o`00
0?oLQ@3og8D000?og8D00ol00005oo<c0003o`000?oc<@3olc4000Colc4000?o0000oo@`0?od<000
1?od<0000ol0003om2h0oo@^0003o`000003ooTK0?l0003onQT000OonQT000Co0000ooPM0?l0003o
00001?oi7@001Ol0003okd@0onm40?o_A03o000000KokTD00_l00002olZh0005o`000?o9^03obKP0
olVh0?l000000_o9^0001Ol0003obKP0olVh0?o9^03o000000?obKT000?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Hooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000?o08L400?o0000ob^J0?l[VP000_l[
VP000ol0003o>9h0ocRN0002ocRN0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000_lj
W`000ol0003o>Yl0ocZO0003ocZO0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lkW`000_lk
W`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lk
W`000ol0003o>il0oc^O0004oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lkW`000olk
W`000ol0003o>il0o`000002o`000003om^60?l0003ofhH000GofhH000?o0000om^60?oKQP000_oK
QP000ol0003ofhH0om^60003om^60003o`000?oKQP3ofhH000CofhH01?l00002omb50003o`000?oL
Q@3og8D000Gog8D000?o0000omb50?l000000_l000000ooc=03o0000oo<c0005oo<c0003o`000?oc
<@3olc4000Colc4000?o0000oo@`0?od<0000ood<004o`0000GonA/000?o0000ooXI0?oj6@001?oj
6@03o`0000OonAd000?o0000onm40?l000001_o^A@000ol0003okTH0oni60002o`000005olVh0?l0
003obKP0olVh0?l000000_o9^0001Ol0003obKP0olVh0?o9^03o000000?obKT000?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Hooooo`003Oooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000?o08L400?o0000ob^J0?l[
VP000_l[VP000ol0003o>9h0ocRN0002ocRN0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?lj
W`000_ljW`000ol0003o>Yl0ocZO0003ocZO0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lk
W`000olkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lk
W`000_lkW`03o`0000CofhH000?o0000om^60?oKQP001?oKQP000ol0003ofhH0om^60002om^60003
o`000?oKQP3ofhH000CofhH000Co0000om^60?oKQP3ofhH00ol00005omb50003o`000?oLQ@3og8D0
00?og8D01?l00005oo<d0003o`000?oc<`3olc<000Colc<000?o0000oo<a0?oc<@000ooc<@000ol0
003om300oo@`0003o`0000;onAd000?o0000ooTK0?oi6`001Ooi6`000ol0003onQT0ooXI0003o`00
00;onQT000?o0000ooTM0?oi7@001Ooi7@02o`0000KokTD000?o0000oni60?o^AP000_o^AP001Ol0
003obKP0o`000?o9^03o000000;obKP000Go0000olVh0?o9^03obKP0o`000004olVi00;o00005Ooo
ool00ol0003oooooooooo`0Gooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000000oooool2o`0000?ooooo0_l00003o`271003o`000?l[VP3o:iX000;o:iX0
00?o0000ocRN0?lhWP000_lhWP000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl0
00?o0000ocZO0?ljW`000oljW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il0
00?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000?o>il0
00?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o000000;o0000
00?ofhH0o`000?oKQP001OoKQP000ol0003ofhH0om^60003om^60003o`000?oKQP3ofhH000?ofhH0
00?o0000om^60?oKQP000ooKQP04o`0000;ofhH000?o0000omb50?oLQ@001?oLQ@000ol0003og8D0
o`000002o`0000;olSD000?o0000oo<d0?oc=0001?oc=0000ol0003olc<0oo<c0004oo<c0003o`00
0?oc<@3olc4000?olc400ol00006ooTM0003o`000?oi6`3onA/000ConA/00ol00006ooXI0003o`00
0?oi7@3onAd000;onAd00_l000000ooh7`3o0000oni50004oni50003o`000?o^AP3okTH000?okTH0
00?o0000olVh0?o9^0000_l00002olVh0005o`000?o9^03obKP0olVh0?l000000oo9^@000ol0003o
bKT0o`00000Fooooo`03o`000?oooooooooo01Kooooo000=ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo0_l00003o`27
1003o`000?l[VP3o:iX000;o:iX000?o0000ocRN0?lhWP000_lhWP000ol0003o>Yl0ocZO0002ocZO
0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>il0oc^O0003oc^O
0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003oc^O
0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`001?l0003o>il0oc^O0?lkW`03
o`0000CofhH000?o0000om^60?oKQP001?oKQP000ol0003ofhH0om^60003om^60003o`000?oKQP3o
fhH000?ofhH000Co0000om^60?oKQP3ofhH00ol00005om^60003o`000?oLQ@3og8D000?og8D00ol0
0006oo8e0003o`000?oc=03olc@000Colc@000?o0000oo<c0?oc<`000ooc<`000ol0003olc40oo<a
0003o`0000;on1h000?o0000ooTM0?oi7@001Ooi7@000ol0003onA/0ooTK0003o`000003ooTJ0?l0
003onQT000OonQT000Co0000ooTM0?l0003o00001?oh7`001Ol0003okTD0oni50?o^A@3o000000Go
kTH000?o0000oni80?l000000_o9^0001?l0003obKP0olVh0?l00003olVh0005o`000?o9^@3obKT0
olVi0?l000000_o9^@000ol0003oooooooooo`0Booooo`;o00001oooool3o`0000kooooo000>oooo
o`;o00002Oooool3o`0000Cooooo0_l00004ooooo`05o`000?l0Q`Co08L4o`271?l000001?l[VP00
0ol0003o>9h0ocRN0002ocRN0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000_ljW`00
0ol0003o>Yl0ocZO0003ocZO0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`00
0ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000olkW`00
0ol0003o>il0oc^O0003oc^O00Co000000?ofhH0o`000?oKQP001OoKQP000ol0003ofhH0om^60003
om^60003o`000?oKQP3ofhH000?ofhH000?o0000om^60?oKQP000ooKQP04o`0000;ofhH000?o0000
om^60?oKQP001?oKQP000ol0003og8D0o`000002o`000003oo8f0?l0003olSD000KolSD000?o0000
oo<d0?oc=0001?oc=0000ol0003olc<0oo<c0003oo<c00?o00001_oh7P000ol0003onAd0ooTM0004
ooTM00?o00001Ooi6P000ol0003onQT0ooXI0004ooXI00?o00001ooh7`000ol0003okTD0o`000005
oni60004o`000?o^B03okTP0oni800;o000000CobKP0o`000?o9^03o00000_o9^0000ol0003obKT0
olVi0002olVi0003o`000?o9^@3obKT000;o00005Oooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000003Oooool0023ooooo00?o0000ooooooooool00oooool01Ol0003o08L4
o`271?l0Q`Co000000Co:iX000?o0000ocRN0?lhWP000_lhWP000ol0003o>Yl0ocZO0002ocZO0003
o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>il0oc^O0003oc^O0003
o`000?lkW`3o>il000;o>il000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003
o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lkW`02o`0000CofhH000?o0000om^60?oK
QP001?oKQP000ol0003ofhH0om^60003om^60003o`000?oKQP3ofhH000CofhH000?o0000om^60?oK
QP001?l00004om^60003o`000?oKQP3ofhH000?ofhH00ol00005oo8f0003o`000?ob=@3olSD000Go
lSD000?o0000oo<d0?oc=0000ooc=0000ol0003olc<0oo<c0003o`000003ooPP0?l0003on1h000Oo
n1h000?o0000ooTM0?oi7@000ol000000ooi703o0000ooTJ0006ooTJ0003o`000?oj6@3onQT000?o
00000ooi6P000ol0003on1l0ooPO0004ooPO00;o00001Oo^AP000ol0003okTP0oni80003oni80004
o`000?o9^03o0000o`0000?obKP000Go0000olVi0?o9^@3obKT0o`000003olVi0003o`000?o9^@3o
000001Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`007oooool00ol0
003oooooooooo`04ooooo`;o00000_l0Q`@00ol0003o:iX0ob^J0002ob^J0003o`000?lhWP3o>9h0
00;o>9h000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl0
00?o>Yl000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il0
00?o>il000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o0000
00;o000000?ofhH0o`000?oKQP001?oKQP000ol0003ofhH0om^60003om^60003o`000?oKQP3ofhH0
00?ofhH000?o0000om^60?oKQP001?oKQP03o`0000?ofhH000?o0000om^60?oKQP000ooKQP000ol0
003ofhH0o`000002o`000003oo8f0?l0003olSH000GolSH000?o0000oo8e0?ob=@001Oob=@000ol0
003olc@0oo<d0003oo<d00?o00001Ooh80000ol0003on1h0ooPN0004ooPN00Co00001Ooi70000ol0
003onAX0ooTJ0004ooTJ00?o00001ooi6P000ol0003on1l0ooPO0003o`0000;on24000Go0000oni6
0?o^AP3okTH0o`000006oni80004o`000?o9^03obKP0o`0000?obKP000Go0000olVi0?o9^@3obKT0
o`000002olVi0005o`000?o9^@3obKT0olVi0?l000005?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo000Oooooo`;o00001Oooool2o`0000;o08L400?o0000ob^J0?l[VP00
0_l[VP000ol0003o>9h0ocRN0002ocRN0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`00
0oljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`00
0_lkW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il000?o0000oc^O0?lkW`00
0_lkW`03o`0000CofhH000?o0000om^60?oKQP000ooKQP000ol0003ofhH0om^60003om^60003o`00
0?oKQP3ofhH000CofhH000Co0000om^60?oKQP3ofhH00ol00005om^60003o`000?oKQP3ofhH000;o
fhH00ol00005oo8f0003o`000?ob=P3olSH000ColSH000?o0000oo8e0?ob=@001?ob=@000ol0003o
lc@0oo<d0003o`000003ooPQ0?l0003on20000Kon20000?o0000ooPN0?oh7P000ol00002ooPN0003
o`000?oi703onA`000GonA`000?o0000ooTJ0?oi6P000ol00002ooTL0003o`000?oi6P3onAX000Co
nAX01?l00006ooPQ0003o`000?o^AP3o000000KokTP000Co0000one90?l0003obKP00_l00002olVh
0005o`000?o9^@3obKT0olVi0?l000000_o9^@001Ol0003obKT0olVi0?o9^@3o000001Gooooo00Co
0000oooooooooooooooo1?l0000>ooooo`007oooool00ol0003oooooooooo`04ooooo`;o00000_l0
Q`@00ol0003o:iX0ob^J0002ob^J0003o`000?lhWP3o>9h000;o>9h000?o0000ocZO0?ljW`000_lj
W`000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000oc^O0?lkW`000olk
W`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o>il000?o>il000?o0000oc^O0?lkW`000_lk
W`000ol0003o>il0o`000002o`000003om^60?l0003ofhH000GofhH000?o0000om^60?oKQP000_oK
QP000ol0003ofhH0om^60003om^60003o`000?oKQP3ofhH000CofhH01?l00002om^60003o`000?oK
QP3ofhH000?ofhH000?o0000om^60?oKQP000_l000000oob=`3o0000oo8f0005oo8f0003o`000?ob
=P3olSH000GolSH000?o0000oo8e0?ob=@000oob=@03o`0000Gon24000?o0000ooPP0?oh80001?oh
8003o`0000Kon1h000?o0000ooTL0?oi70001?oi7003o`0000KonA`000?o0000ooTJ0?oi6P000ol0
0002ooTL0003o`000?oh8@3on24000Gon2400_l00006oni80003o`000?o]B@3okDT000;o00000_o9
^002o`0000?obKT000Go0000olVi0?o9^@3obKT0o`000003olVi00;o00005Oooool01?l0003ooooo
ooooool0000Aooooo`007oooool2o`0000Gooooo0_l00002o`271003o`000?l[VP3o:iX000;o:iX0
00?o0000ocRN0?lhWP000_lhWP000ol0003o>Yl0ocZO0003ocZO0003o`000?ljW`3o>Yl000;o>Yl0
00?o0000ocZO0?ljW`000_ljW`000ol0003o>il0oc^O0003oc^O0003o`000?lkW`3o>il000;o>il0
00?o0000oc^O0?lkW`000olkW`001?l0003o>il0oc^O0?lkW`03o`0000CofhH000?o0000om^60?oK
QP001?oKQP000ol0003ofhH0om^60002om^60003o`000?oKQP3ofhH000CofhH000Co0000om^60?oK
QP3ofhH00ol00005om^60003o`000?oKQP3ofhH000CofhH00_l00004oo8g0003o`000?ob=P3olSH0
00ColSH000?o0000oo8f0?ob=P001?ob=P000ol0003olSD0oo8e0003o`000003ooLR0?l0003on240
00Kon24000?o0000ooPP0?oh80000ol00002ooPO0003o`000?oh7P3on1h000Gon1h000?o0000ooTL
0?oi70000ol00002ooPN0003o`000?oi703onA`000ConA`00ol00006ooTL0003o`000?oh8@3on240
00;on2400_l000000oog8P3o0000oni80004oni80003o`000?o]B@3okDT000;okDT000?o0000olVh
0?o9^0000_l00003olVi0004o`000?o9^@3obKT0o`0000?obKT000?o0000olVi0?l000004oooool3
o`0000;ooooo1Ol0000=ooooo`001_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00002
ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`;o00000_l0Q`@00ol0003o:iX0ob^J0002
ob^J0003o`000?lhWP3o>9h000?o>9h000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0002
ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000oc^O0?lkW`000olkW`000ol0003o>il0oc^O0002
oc^O0003o`000?lkW`3o>il000?o>il01?l000000ooLQ@3o0000om^60005om^60003o`000?oKQP3o
fhH000?ofhH000?o0000om^60?oKQP000_oKQP000ol0003ofhH0om^60004om^600Co00000_oKQP00
0ol0003ofhH0om^60004om^60003o`000?oKQP3ofhH000;ofhH00_l00005oo8g0003o`000?ob=P3o
lSH000GolSH000?o0000oo8f0?ob=P000oob=P03o`0000Gomb8000?o0000ooPQ0?oh8@001?oh8@03
o`0000Kon1l000?o0000ooPN0?oh7P001?oh7P03o`0000Kon1h000?o0000ooTL0?oi70000ol00000
0ooh7P3o0000ooTL0007ooTL0004o`000?oh8@3o0000o`0000Comb8000Go0000oni80?o^B03okTP0
o`000005one900;o00000_o9^0001Ol0003obKT0olVi0?o9^@3o000000;obKT000Go0000olVi0?o9
^@3obKT0o`000002olVi0003o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool000Go
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`;o00000_l0Q`@00ol0003o:iX0ob^J
0002ob^J0003o`000?lhWP3o>9h000?o>9h000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO
0002ocZO0003o`000?ljW`3o>Yl000?o>Yl000?o0000oc^O0?lkW`000_lkW`000ol0003o>il0oc^O
0002oc^O0003o`000?lkW`3o>il000;o>il00_l00004omb50003o`000?oKQP3ofhH000CofhH000?o
0000om^60?oKQP000ooKQP000ol0003ofhH0om^60003om^60004o`000?oKQP3ofhH0om^600?o0000
1OoKQP000ol0003ofhH0om^60004om^60003o`000?oKQP3o000000;o000000?olSL0o`000?ob=`00
1Oob=`000ol0003olSH0oo8f0004oo8f0003o`000?ob=P3olSH000?o000000?omb<0o`000?og8P00
1_og8P000ol0003on240ooPQ0003o`0000?on24000?o0000ooPO0?oh7`001?oh7`000ol0003on1h0
ooPN0003o`0000;on20000?o0000ooPN0?oh7P001?oh7P03o`0000Gon1h000?o0000ooTL0?oi7000
1?oi7003o`0000Oomb8000?o0000oni80?l000001Oo]B@000ol0003okDT0one90002o`000005olVi
0?l0003obKT0olVi0?l000000_o9^@001Ol0003obKT0olVi0?o9^@3o000000;obKT00_l0000Eoooo
o`03o`000?oooooooooo013ooooo0005ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooooooool2o`0000Kooooo0_l00003o`271003o`000?l[VP3o
:iX000;o:iX000?o0000ocRN0?lhWP000_lhWP000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o
>Yl000;o>Yl000?o0000ocZO0?ljW`000oljW`000ol0003o>il0oc^O0002oc^O0003o`000?lkW`3o
>il000;o>il000?o0000oc^O0?l000000_l000000ooLQ@3o0000omb50004omb50003o`000?oKQP3o
fhH000?ofhH000?o0000om^60?oKQP000ooKQP000ol0003ofhH0om^60003om^600Co00000_oKQP00
0ol0003ofhH0om^60004om^60003o`000?oKQP3ofhH000;ofhH00ol00005oo8g0003o`000?ob=`3o
lSL000ColSL000?o0000oo8f0?ob=P000oob=P03o`0000Gomb<000?o0000ooLR0?og8P001?og8P03
o`0000Oon24000Co0000ooPO0?oh7`3on1l01Ol00006ooPP0003o`000?oh7P3on1h000?o000000?o
n200o`000?oh7P001_oh7P000ol0003onA`0ooTL0003o`0000;on1h000?o0000ooLR0?og8P001Oog
8P02o`0000GokDT000?o0000one90?o]B@000_o]B@001Ol0003obKT0o`000?o9^@3o000000;obKT0
00Go0000olVi0?o9^@3obKT0o`000003olVi0003o`000?o9^@3o000001Cooooo00?o0000oooooooo
ool04?ooool000Gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000002?ooool01Ol0003o08L4o`271?l0Q`Co000000Co:iX000?o0000
ocRN0?lhWP000_lhWP000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000
ocZO0?ljW`000oljW`000ol0003o>il0oc^O0002oc^O0004o`000?lkW`3o>il0oc^O00?o00001?oL
Q@000ol0003og8D0omb50003omb50003o`000?oKQP3ofhH000?ofhH000?o0000om^60?oKQP001?oK
QP000ol0003ofhH0om^60003o`0000GofhH000?o0000om^60?oKQP001?oKQP000ol0003ofhH0o`00
0002o`000003oo8g0?l0003olSL000GolSL000?o0000oo8g0?ob=`001?ob=`000ol0003olSH0oo8f
0003o`000003ooLT0?l0003omb<000Komb<000?o0000ooLR0?og8P000ol00002ooLR0003o`000?oh
8@3on24000Con2401Ol00004ooPQ0003o`000?oh803on20000Con2000ol00005ooPP0003o`000?oh
7P3on1h000Con1h00ol00006ooPN0004o`000?og8P3omb80ooLR00?o000000?omb@0o`000?o]B@00
0oo]B@000ol0003okDT0one90003one90003o`000?o9^@3obKT000;o00000_o9^@001Ol0003obKT0
olVi0?o9^@3o000000;obKT000Go0000olVi0?o9^@3obKT0o`00000Dooooo`03o`000?oooooooooo
00oooooo0005ooooo`04o`000?ooooooooooo`0000Oooooo00Ko0000ooooooooooooooooo`000?oo
ool4o`0000Cooooo0_l00007ooooo`05o`000?l0Q`Co08L4o`271?l000001?l[VP000ol0003o>9h0
ocRN0002ocRN0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO0?ljW`000_ljW`000ol0003o>Yl0
ocZO0003ocZO0003o`000?lkW`3o>il000;o>il01?l000000ooLQ03o0000omb50005omb50003o`00
0?oLQ@3og8D000;og8D000?o0000om^60?oKQP000ooKQP000ol0003ofhH0om^60004om^600?o0000
0_oKQP000ol0003ofhH0om^60004om^60003o`000?oKQP3ofhH000;ofhH00ol00005oo8g0003o`00
0?ob=`3olSL000ColSL000?o0000oo8g0?ob=`000oob=`03o`0000Gomb@000?o0000ooLS0?og8`00
1?og8`03o`0000Komb8000?o0000ooPQ0?oh8@000ol00002ooLS0003o`000?oh8@3on24000Gon240
00?o0000ooPP0?oh80000ol000000oog8P3o0000ooPP0006ooPP0003o`000?oh7P3on1h000?o0000
00?on200o`000?oh7P001_oh7P001?l0003omb80o`000?l00005ooLT0005o`000?o]B@3okDT0one9
0?l000001?o]B@000ol0003okDX0o`000002olVi0004o`000?o9^@3obKT0o`0000?obKT000Co0000
olVi0?o9^@3o00000oo9^@000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo0005
ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oo
oooo00?o0000ooooooooool01_ooool01Ol0003o08L4o`271?l0Q`Co000000Co:iX000?o0000ocRN
0?lhWP000_lhWP000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO
0?ljW`000oljW`001?l0003o>il0oc^O0?lkW`02o`0000Cog8@000?o0000omb50?oLQ@001?oLQ@00
0ol0003og8D0omb50002omb50003o`000?oKQP3ofhH000CofhH000Co0000om^60?oKQP3ofhH00ol0
0004om^60003o`000?oKQP3ofhH000CofhH000?o0000om^60?l000000_l000000oob=`3o0000oo8g
0005oo8g0003o`000?ob=`3olSL000ColSL000?o0000oo8g0?ob=`000ol000000oog9@3o0000ooLT
0006ooLT0003o`000?og8`3omb<000?o00000_og8`000ol0003omb80ooLR0004ooLR00?o00001_og
8`000ol0003on240ooPQ0004ooPQ00?o00001Oog8P000ol0003on200ooPP0004ooPP00?o00001Ooh
80000ol0003on1h0ooPN0004ooPN00;o00002?og90000ol0003okDT0o`000004one90004o`000?o]
BP3okDX0one:00;o000000CobKT0o`000?o9^@3o00000_o9^@001Ol0003obKT0olVi0?o9^@3o0000
00?obKT00_l0000Cooooo`;o00004?ooool000Kooooo0_l00009ooooo`?o00000_ooool5o`0000?o
oooo00?o0000ooooooooool01_ooool01Ol0003o08L4o`271?l0Q`Co000000Co:iX000?o0000ocRN
0?lhWP000_lhWP000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl000?o0000ocZO
0?ljW`000oljW`04o`000003omb40?l0003og8@000Cog8@000?o0000omb50?oLQ@000ooLQ@000ol0
003og8D0omb50002omb50003o`000?oKQP3ofhH000CofhH01?l00002om^60003o`000?oKQP3ofhH0
00?ofhH000?o0000om^60?oKQP000_oKQP03o`0000GolSL000?o0000oo8g0?ob=`001?ob=`000ol0
003olSL0oo8g0003oo8g00?o00001Oog9@000ol0003omb@0ooLT0004ooLT00?o00001_og8`000ol0
003omb80ooLR0003o`0000;omb@000?o0000ooLS0?og8`001Oog8`000ol0003on240ooPQ0003o`00
0003ooLS0?l0003omb8000Komb8000?o0000ooPP0?oh80000ol00002ooLR0003o`000?oh803on200
00Con20000?o0000ooPN0?oh7P000ol00002ooPP0003o`000?og903omb@000Comb@00ol00004one9
0003o`000?o]BP3okDX000?okDX000Co0000olVi0?l0003o00000oo9^@001Ol0003obKT0olVi0?o9
^@3o000000;obKT000?o0000olVi0?l000005Oooool00ol0003oooooooooo`0=ooooo`007_ooool2
o`0000Oooooo00Go0000o`271?l0Q`Co08L4o`000004ob^J0003o`000?lhWP3o>9h000;o>9h000?o
0000ocZO0?ljW`000_ljW`000ol0003o>Yl0ocZO0002ocZO0003o`000?ljW`3o>Yl000;o>Yl00_l0
0004omb40003o`000?oLQ03og8@000?og8@000?o0000omb50?oLQ@000ooLQ@000ol0003og8D0omb5
0003omb50004o`000?oKQP3ofhH0om^600?o00001OoKQP000ol0003ofhH0om^60003om^60003o`00
0?oKQP3o000000;o000000?olSL0o`000?ob=`001Oob=`000ol0003olSL0oo8g0004oo8g0003o`00
0?ob=`3olSL000?o000000?ombD0o`000?og9@001_og9@000ol0003omb@0ooLT0003o`0000;omb@0
00?o0000ooLS0?og8`001?og8`03o`0000Komb@000?o0000ooLS0?og8`001?og8`03o`0000Gomb<0
00?o0000ooLR0?og8P001?og8P03o`0000Komb8000Co0000ooPP0?oh803on2001Ol00006ooPP0003
o`000?og903omb@000?o00000_og9@001Ol0003okDT0one90?o]B@3o000000KokDX000Co0000olVi
0?o9^@3o00000oo9^@001?l0003obKT0olVi0?l00003olVi0004o`000?o9^@3obKT0o`0001Gooooo
00?o0000ooooooooool03?ooool001kooooo00?o0000ooooooooool01_ooool2o`0000;o08L400?o
0000ob^J0?l[VP000_l[VP000ol0003o>9h0ocRN0002ocRN0003o`000?ljW`3o>Yl000;o>Yl000?o
0000ocZO0?ljW`000_ljW`000ol0003o>Yl0o`000002o`000003omb30?l0003og8@000Cog8@000?o
0000omb40?oLQ0000_oLQ0000ol0003og8D0omb50003omb50003o`000?oLQ@3og8D000?og8D01?l0
0002om^60003o`000?oKQP3ofhH000CofhH000?o0000om^60?oKQP001?l00005oo8g0003o`000?ob
=`3olSL000ColSL000?o0000oo8g0?ob=`000oob=`03o`0000GombD000?o0000ooLU0?og9@001?og
9@03o`0000Komb@000?o0000ooLS0?og8`000ol00002ooLU0003o`000?og903omb@000Gomb@000?o
0000ooLS0?og8`000ol000000oog903o0000ooLS0006ooLS0003o`000?og8P3omb8000?o00000_og
8`000ol0003omb80ooLR0004ooLR00Co00001?oh8@000ol0003on200ooPP0004ooPP00?o00001_og
9@000ol0003okDT0o`000006one:0004o`000?o]B`3o0000olVi00;o00000_o9^@001?l0003obKT0
olVi0?l00003olVi0004o`000?o9^@3obKT0o`0001Gooooo00?o0000ooooooooool03?ooool001go
oooo0_l00008ooooo`;o00000_l0Q`@00ol0003o:iX0ob^J0002ob^J0003o`000?lhWP3o>9h000;o
>9h000?o0000ocZO0?ljW`000_ljW`001?l0003o>Yl0ocZO0?ljW`03o`0000Cog8<000?o0000omb4
0?oLQ0000ooLQ0000ol0003og8@0omb40002omb40003o`000?oLQ@3og8D000Cog8D000?o0000omb5
0?oLQ@000ol00005om^60003o`000?oKQP3ofhH000?ofhH01?l00002oo8g0003o`000?ob=`3olSL0
00ColSL000?o0000oo8g0?ob=`001?ob=`000ol0003olSL0oo8g0003o`0000;ombD000?o0000ooLU
0?og9@001?og9@000ol0003ombD0ooLU0003o`0000?omb@000?o0000ooLT0?og90000oog9003o`00
00KombD000?o0000ooLT0?og90001?og9003o`0000Gomb@000?o0000ooLS0?og8`001?og8`03o`00
00Komb<000?o0000ooLR0?og8P000ol000000oog8`3o0000ooPQ0006ooPQ0003o`000?oh803on200
00?o000000?on240o`000?og9@001_og9@02o`0000KokDX000?o0000one;0?o]B`000_l00002olVi
00;o00000oo9^@001?l0003obKT0olVi0?l00003olVi00;o00005Oooool00ol0003oooooooooo`0;
ooooo`007Oooool00ol0003oooooooooo`08ooooo`;o000000?o08L4o`000?l[VP000ol[VP000ol0
003o>9h0ocRN0002ocRN0003o`000?ljW`3o>Yl000;o>Yl01?l000000ooLPP3o0000omb30004omb3
0003o`000?oLQ03og8@000?og8@000?o0000omb40?oLQ0000_oLQ0000ol0003og8D0omb50004omb5
00?o00000_oLQ@000ol0003ofhH0om^60004om^60003o`000?oKQP3o000000;o000000?olSL0o`00
0?ob=`001?ob=`000ol0003olSL0oo8g0004oo8g0003o`000?ob=`3olSL000?olSL00ol00006ooLU
0004o`000?og9@3ombD0ooLU00Go00001oog90000ol0003omb@0o`000002o`0000;ombD000?o0000
ooLU0?og9@001Oog9@000ol0003omb@0ooLT0003o`0000;omRH000?o0000ooLT0?og90001?og9000
0ol0003omb<0ooLS0003o`0000;ombD000?o0000ooLS0?og8`001?og8`03o`0000Gomb<000?o0000
ooPQ0?oh8@001?oh8@03o`0000Gon24000?o0000ooLU0?og9@000_og9@02o`000003ooHV0?l0003o
kDX000CokDX000?o0000one;0?o]B`000_o]B`000ol0003obKT0olVi0002o`0000?obKT000Co0000
olVi0?o9^@3o00000_o9^@001?l0003obKT0olVi0?l0000Eooooo`03o`000?oooooooooo00[ooooo
000Mooooo`03o`000?oooooooooo00Sooooo0_l000000ol0Q`Co0000ob^J0003ob^J0003o`000?lh
WP3o>9h000;o>9h000Co0000ocZO0?ljW`3o>Yl00_l00004omb20003o`000?oLP`3og8<000Cog8<0
00?o0000omb40?oLQ0000_oLQ0000ol0003og8@0omb40003omb40004o`000?oLQ@3og8D0omb500?o
00001?oLQ@000ol0003ofhH0om^60003om^600?o00001Oob=`000ol0003olSL0oo8g0003oo8g0003
o`000?ob=`3olSL000?olSL000?o0000oo8g0?ob=`000ol00003ooLU0003o`000?og9@3ombD000?o
mbD01?l00005ooLU0003o`000?og903omb@000Comb@00_l00006ooLU0003o`000?og9@3ombD000Co
mbD00ol00006ooHV0004o`000?og903omb@0ooLT00Go00001_og9@000ol0003omb<0ooLS0003o`00
0003ooLU0?l0003omb<000Komb<000?o0000ooPQ0?oh8@000ol000000oog8P3o0000ooPQ0006ooPQ
0004o`000?og9@3o0000o`0000ComRH000Go0000one:0?o]BP3okDX0o`000005one;00;o00000_o9
^@001Ol0003obKT0olVi0?o9^@3o000000;obKT000Co0000olVi0?o9^@3o00000_o9^@02o`0001?o
oooo0_l0000<ooooo`007Oooool2o`0000Wooooo00Co0000okG10?l0003o00001?l[VP000ol0003o
>9h0ocRN0002ocRN00Co000000?ogH80o`000?oLPP001?oLPP000ol0003og8<0omb30003omb30003
o`000?oLQ03og8@000;og8@000?o0000omb40?oLQ0000ooLQ004o`0000;og8D000?o0000omb50?oL
Q@000ooLQ@000ol0003ofhH0o`000002o`000003oo8f0?l0003olSL000GolSL000?o0000oo8g0?ob
=`000oob=`000ol0003olSL0oo8g0003oo8g00?o00001oog9@000ol0003ombD0o`000002o`0000;o
mbD000?o0000ooLU0?og9@001Oog9@000ol0003omb@0ooLT0003o`000003ooHV0?l0003ombD000Ko
mbD000?o0000ooLU0?og9@000ol00002ooHV0003o`000?of9P3omRH000ComRH01?l00004ooHV0003
o`000?og9@3ombD000CombD00ol00005ooLU0003o`000?og8`3omb<000Comb<00ol00005ooLR0003
o`000?oh8@3on24000Con2400_l00007ooHV0003o`000?o]BP3o000000GokD/000?o0000one<0?o]
C0000_l000001?o9^@3o0000olVi0?l00002olVi0005o`000?o9^@3obKT0olVi0?l000000_o9^@00
0ol0003obKT0o`00000Dooooo`03o`000?oooooooooo00Wooooo000:ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ne`@3o0000
o`0000Co:iX000?o0000ocRN0?lhWP000ol00004omf20003o`000?oLPP3og88000?og88000?o0000
omb30?oLP`000ooLP`000ol0003og8@0omb40003omb40003o`000?oLQ03og8@000?o00001OoLQ@00
0ol0003og8D0omb50002omb500?o00001Oob=P000ol0003olSL0oo8g0004oo8g0003o`000?ob=`3o
lSL000?olSL000?o0000oo8g0?l000000_l00003ooLU0003o`000?og9@3ombD000CombD00_l00006
ooLU0003o`000?og9@3ombD000CombD00ol00005ooHV0003o`000?og9@3ombD000CombD00ol00006
ooHV0003o`000?of9P3omRH000?o000000?omRL0o`000?of9P001_of9P000ol0003ombD0ooLU0003
o`000003ooHV0?l0003ombD000KombD000?o0000ooLS0?og8`000ol000000oog903o0000ooLR0006
ooLR0003o`000?oh8@3on24000?o00000_og8P000ol0003omRH0ooHV0004ooHV00;o00001Oo]B`00
0ol0003okD`0one<0002one<0005o`000?o9^@3o0000olVi0?l000000_o9^@001ol0003obKT0olVi
0?o9^@3o0000olVi0?l000000oo9^@000ol0003oooooooooo`0Booooo`03o`000?oooooooooo00So
oooo0009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00Sooooo00?o0000okG10?ne`@002?l00002omb30003o`000?oMPP3ogH80
00?ogH8000?o0000omb20?oLPP000_oLPP000ol0003og8<0omb30003omb30003o`000?oLQ03og8@0
00?og8@00ol00002omb40003o`000?oLQ@3og8D000Cog8D01?l000000oob=@3o0000oo8f0005oo8f
0003o`000?ob=`3olSL000ColSL000?o0000oo8g0?ob=`000oob=`02o`0000OombD000?o0000ooLU
0?og9@000ol000000oog9@3o0000ooLU0006ooLU0003o`000?og9@3ombD000?o00000_of9P000ol0
003omRH0ooHV0004ooHV0003o`000?og9@3ombD000?o00000_of9`000ol0003omRH0ooHV0004ooHV
00?o00001Oof9`000ol0003omRH0ooHV0004ooHV00?o00001Oof9P000ol0003ombD0ooLU0004ooLU
00?o00001Oog90000ol0003omb80ooLR0004ooLR00?o00001_og8P000ol0003omRH0ooHV0003o`00
00;omRL000Go0000one;0?o]B`3okD/0o`000005one<0003o`000?o9^@3obKT000;o00000_o9^@00
1?l0003obKT0olVi0?l00002olVi0005o`000?o9^@3obKT0olVi0?l000005?ooool00ol0003ooooo
ooooo`08ooooo`002Oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooooooo`;o
00002_ooool01?l0003o]L40okG10?l00004omRB0003o`000?oLP`3og8<000;og8<000?o0000omf2
0?oMPP000ooMPP000ol0003og880omb20002omb20003o`000?oLP`3og8<000?og8<000?o0000omb4
0?oLQ0001?l00004omb40003o`000?oLQ@3og8D000?og8D00_l00005oo8e0003o`000?ob=P3olSH0
00ColSH000?o0000oo8g0?ob=`000oob=`000ol0003olSL0oo8g0003o`0000;ombD000?o0000ooLU
0?og9@001?og9@03o`0000GombD000?o0000ooLU0?og9@001?og9@03o`0000KomRH000Co0000ooHV
0?of9P3omRH01Ol00006ooHW0003o`000?of9P3omRH000?o000000?omRP0o`000?of9`001_of9`00
0ol0003omRH0ooHV0003o`0000;omRL000?o0000ooHV0?of9P001?of9P000ol0003ombD0ooLU0003
o`0000;omRH000?o0000ooLT0?og90001?og90000ol0003omb80ooLR0003o`0000;omb@000?o0000
ooLR0?og8P001?og8P03o`0000KomRL000?o0000one;0?l000001Oo]C0000ol0003okD`0o`000002
olVi0004o`000?o9^@3obKT0o`0000;obKT000Co0000olVi0?o9^@3o00000oo9^@02o`0001Cooooo
00?o0000ooooooooool01oooool000Wooooo00Co0000oooooooooooo00002Oooool2o`0000Cooooo
00?o0000ooooooooool02Oooool01?l0003o]L40okG10?l00004omRB0003o`000?oLP`3og8<000;o
g8<000?o0000omf20?oMPP000ooMPP000ol0003og880omb20002omb20003o`000?oLP`3og8<000?o
g8<00ol00003omb40003o`000?oLQ03og8@000?og8@000?o0000omb50?l000000_l000000ooc=03o
0000oo8e0005oo8e0003o`000?ob=P3olSH000?olSH000Co0000oo8g0?ob=`3olSL01Ol00006ooLU
0003o`000?og9@3ombD000?o000000?ombD0o`000?og9@001_og9@000ol0003ombD0ooLU0003o`00
00;omRL000?o0000ooHV0?of9P001?of9P04o`0000ComRP000?o0000ooHW0?of9`001?of9`03o`00
00GomRP000?o0000ooHW0?of9`001?of9`03o`0000KomRL000Co0000ooHV0?of9P3omRH01Ol00006
ooHV0004o`000?og903omb@0ooLT00Go00001_og90000ol0003omb80ooLR0003o`000003ooLS0?l0
003omRL000KomRL00_l00005one<0004o`000?o]C03okD`0one<00;o000000?obKT0o`000?l00000
0oo9^@001?l0003obKT0olVi0?l00002olVi0003o`000?o9^@3o000001?ooooo0ol00008ooooo`00
2Oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooooooo`;o00002oooool00ol0
003o]L40o`000004omRB0003o`000?oLP`3og8<000?og8<000?o0000omf20?oMPP000_oMPP000ol0
003og880omb20003omb20003o`000?oLP`3o000000?o00001OoLQ0000ol0003og8@0omb40002omb4
00?o00001Ooc=0000ol0003olSD0oo8e0003oo8e0003o`000?ob=P3olSH000?olSH01?l00005ooLT
0003o`000?og9@3ombD000?ombD00ol00005ooLU0003o`000?og9@3ombD000CombD00ol00006ooHW
0003o`000?of9P3omRH000?o000000?omRP0o`000?of:0001_of:0000ol0003omRL0ooHW0003o`00
0003ooHY0?l0003omRP000KomRP000?o0000ooHW0?of9`000ol00002ooHX0003o`000?of9`3omRL0
00ComRL01?l00004ooHW0003o`000?of9P3omRH000ComRH01?l00004ooLU0003o`000?og903omb@0
00Comb@00ol00005ooLS0003o`000?of9`3omRL000;omRL00_l000000oof:03o0000one<0003one<
0003o`000?o]C03okD`000?okD`000Co0000olVi0?l0003o00000oo9^@000ol0003obKT0o`000003
olVi0004o`000?o9^@3obKT0o`0000oooooo0ol00002ooooo`03o`000?oooooooooo00Kooooo0009
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00[ooooo00Co0000okG10?ne`@3o00000ooHTP000ol0003og8<0omb30003omb30003
o`000?oMPP3ogH8000;ogH8000?o0000omb20?oLPP000ooLPP02o`0000Cog8<000?o0000omb40?oL
Q0000ooLQ004o`000003oo<c0?l0003olc@000Golc@000?o0000oo8e0?ob=@001?ob=@000ol0003o
lSH0o`000002o`0000;omb@000?o0000ooLT0?og90001Oog90000ol0003ombD0o`000002o`0000;o
mb@000?o0000ooLU0?og9@001?og9@000ol0003ombD0ooLU0003o`0000?omRL000?o0000ooHW0?of
9`000oof9`03o`0000GomRP000?o0000ooHX0?of:0001?of:003o`0000GomRT000?o0000ooHX0?of
:0001?of:003o`0000KomRP000?o0000ooHW0?of9`000ol000000oof:03o0000ooHW0006ooHW0003
o`000?of9P3omRH000?o000000?omRL0o`000?og9@001_og9@000ol0003omb@0ooLT0003o`000003
ooLT0?l0003omb<000Komb<000Co0000ooHW0?l0003o00001?of:0001?l0003okD`0one<0?l00005
one<00;o00000_o9^@001?l0003obKT0olVi0?l00002olVi0005o`000?o9^@3obKT0olVi0?l00000
0_o9^@000ol0003oooooooooo`0:ooooo`?o00001Oooool00ol0003oooooooooo`06ooooo`002_oo
ool2o`0000Wooooo0ol00004ooooo`03o`000?oooooooooo00[ooooo00Co0000okG10?ne`@3o0000
1?oHTP000ol0003og8<0omb30002omb30003o`000?oMPP3ogH8000?ogH8000?o0000omb20?l00000
0ol00005omb30003o`000?oLQ03og8@000;og8@00_l00005oo<c0003o`000?oc=03olc@000Colc@0
00?o0000oo8e0?ob=@000oob=@02o`0000Komb@000?o0000ooLT0?og90001?og9002o`0000Komb@0
00?o0000ooLU0?og9@000oog9@03o`0000OomRL000?o0000ooHW0?l000000_l00002ooHX0003o`00
0?of:03omRP000ComRP000?o0000ooHX0?of:0000ol00002ooHY0003o`000?of:@3omRT000ComRT0
00?o0000ooHX0?of:0000ol00002ooHY0003o`000?of:03omRP000ComRP00ol00005ooHX0003o`00
0?of9`3omRL000ComRL00ol00005ooHW0003o`000?og9@3ombD000CombD00ol00005ooLT0003o`00
0?og8`3omb<000Comb<00_l00006ooHX0003o`000?o]C03o000000GokD`000?o0000ona<0?o/C000
0_l000001?o9^@3o0000olVi0?l00002olVi0004o`000?o9^@3obKT0o`0000?obKT00_l00007oooo
o`Co00002?ooool00ol0003oooooooooo`06ooooo`007?ooool2o`0000_ooooo00Co0000okG10?ne
`@3o00001?oHTP000ol0003og8<0omb30002omb30003o`000?oMPP3ogH8000;ogH800ol00003omb2
0003o`000?oLP`3og8<000?og8<000?o0000omb40?l000000_l000000ooc<P3o0000oo<c0005oo<c
0003o`000?oc=03olc@000?olc@000?o0000oo8e0?ob=@000ol000000oog8`3o0000ooLT0006ooLT
0003o`000?og903omb@000?o000000?omb@0o`000?og90001_og90000ol0003ombD0o`000002o`00
00?omRH000?o0000ooHW0?of9`001?of9`02o`0000KomRP000?o0000ooHX0?of:0000oof:003o`00
00KomRT000Co0000ooHY0?of:@3omRT01Ol00006ooHY0003o`000?of:03omRP000?o000000?omRT0
o`000?of:0001_of:0000ol0003omRL0ooHW0003o`0000;omRP000?o0000ooHW0?of9`001?of9`00
0ol0003ombD0ooLU0003o`000003ooHV0?l0003omb@000Komb@000?o0000ooLS0?og8`000ol00000
0oog903o0000ooHX0005ooHX00;o00001Oo]C0000ol0003ok4`0ona<0002ona<0003o`000?o9^@3o
bKT000;o00000_o9^@001?l0003obKT0olVi0?l00002olVi0004o`000?o9^@3obKT0o`0000?ooooo
0ol0000<ooooo`03o`000?oooooooooo00Kooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
0000okG10?l000001?oHTP000ol0003og8<0omb30002omb30003o`000?oMPP3o000000;o000000?o
gH80o`000?oLPP000ooLPP000ol0003og8<0omb30002omb300?o00001Ooc<P000ol0003olc<0oo<c
0003oo<c0003o`000?oc=03olc@000?olc@00ol00005ooLS0003o`000?og903omb@000Comb@00ol0
0005ooLT0003o`000?og903omb@000Comb@00_l00007ooHV0003o`000?of9`3omRL000?o000000?o
mRP0o`000?of:0001_of:0000ol0003omRP0o`000002o`0000?omRT000?o0000ooHY0?of:@000oof
:@04o`0000ComBX000?o0000ooHY0?of:@001?of:@03o`0000GomRT000?o0000ooHX0?of:0001?of
:003o`0000KomRP000Co0000ooHW0?of9`3omRL01Ol00005ooHV0003o`000?og903omb@000;omb@0
1Ol00005ooLT0003o`000?of:03omRP000?o00000_of:0001Ol0003okD`0one<0?o]C03o000000Go
k4`00_l000000oo9^@3o0000o`000002olVi0004o`000?o9^@3obKT0o`0000;obKT000?o0000olVi
0?o9^@001?l0000@ooooo`03o`000?oooooooooo00Gooooo000Looooo`03o`000?oooooooooo00_o
oooo00?o0000okG10?l000001?oHTP001?l0003og8<0omb30?oLP`03o`0000CogH8000?o0000omb2
0?oLPP000ooLPP04o`000003oo@`0?l0003olc8000Golc8000?o0000oo<c0?oc<`001?oc<`000ol0
003olc@0o`000002o`0000;omb8000?o0000ooLS0?og8`001?og8`000ol0003omb@0ooLT0003o`00
00?omb<000?o0000ooLT0?og90000oog90000ol0003omb@0ooLT0003o`0000;omRH000?o0000ooHV
0?of9P001?of9P03o`0000GomRP000?o0000ooHX0?of:0001?of:002o`0000OomRT000?o0000ooHY
0?l000000_l000000ooe:`3o0000ooDZ0006ooDZ0003o`000?of:@3omRT000?o00000_oe:P000ol0
003omRT0ooHY0004ooHY0003o`000?of:03omRP000?o00000_of:@000ol0003omRP0ooHX0004ooHX
00Co00001?of:0000ol0003omRH0ooHV0003ooHV00Go00000oog9@000ol0003omb@0ooLT0004ooLT
00?o00001_of:0000ol0003okD`0o`000005ona<0003o`000?o/C03ok4`000?o000000GobKT0o`00
0?o9^@3obKT0o`000003olVi0006o`000?o9^@3obKT0o`000?o9^@3o00004Oooool00ol0003ooooo
ooooo`05ooooo`006oooool00ol0003oooooooooo`0=ooooo`;o00001?oHTP04o`000003omb30?l0
003ogH8000CogH8000?o0000omb20?oLPP000_oLPP02o`0000Gom30000?o0000oo<b0?oc<P001?oc
<P000ol0003olc<0oo<c0003oo<c00;o00001_og8P000ol0003omb<0ooLS0003ooLS00?o00001oog
8`001?l0003omb@0ooLT0?og9004o`0000KomRH000?o0000ooHV0?of9P000ol00002ooHX0003o`00
0?of:03omRP000ComRP000?o0000ooHX0?of:0000ol00002ooDZ0003o`000?of:@3omRT000ComRT0
0_l00005ooD[0003o`000?oe:P3omBX000ComBX00ol00006ooDZ0004o`000?of:@3omRT0ooHY00Go
00001_of:@000ol0003omRP0ooHX0003o`000003ooHY0?l0003omRP000KomRP000?o0000ooHV0?l0
00000_l000000oof9`3o0000ooLU0006ooLU0003o`000?og903omb@000?o000000?omb@0o`000?of
:0001_of:002o`0000Gok4`000?o0000ona<0?o/C0000_o/C0001?l0003obKT0o`000?l00002olVi
0007o`000?o9^@3obKT0olVi0?l0003obKT0o`000003olVi0003o`000?oooooooooo00kooooo00?o
0000ooooooooool01Oooool001_ooooo00?o0000ooooooooool03Oooool2o`0000;of9800ol00005
omb30003o`000?oMPP3ogH8000?ogH801?l000000ood;`3o0000oo@`0005oo@`0003o`000?oc<P3o
lc8000?olc8000?o0000oo<c0?oc<`000ol000000ooh8@3o0000ooLR0006ooLR0003o`000?og8`3o
000000;o00000oog8P000ol0003omb<0ooLS0004ooLS00Co00001?of9P000ol0003omRH0ooHV0003
ooHV00?o00001_of:0001?l0003omRP0ooHX0?of:005o`0000KomBX000?o0000ooHY0?of:@000ol0
00000ooe:`3o0000ooD[0005ooD[0003o`000?oe:P3omBX000?o00000_oe:`000ol0003omBX0ooDZ
0004ooDZ00Co00001?oe:`000ol0003omRT0ooHY0004ooHY00?o00001Oof:@000ol0003omRP0ooHX
0004ooHX00;o00001Oof9`000ol0003ombD0ooLU0004ooLU00?o00001Oog90000ol0003omRP0ooHX
0002ooHX00;o000000?omRP0o`000?o/C0000oo/C0000ol0003ok4`0ona<0003ona<0004o`000?o9
^@3o0000o`0000;obKT000Co0000olVi0?o9^@3o00000_o9^@001Ol0003obKT0olVi0?o9^@3o0000
013ooooo00?o0000ooooooooool01Oooool001_ooooo0_l0000>ooooo`04o`000?ne`@3o0000o`00
00;of98000?o0000omb30?oLP`000ooLP`000ol0003ogH80omf20002omf200;o00001Ood;`000ol0
003om300oo@`0003oo@`0003o`000?oc<P3olc8000?olc800ol00005ooPQ0003o`000?og8P3omb80
00Comb800_l00007ooLR0003o`000?og8`3omb<000?o000000?ombD0o`000?of9P001_of9P000ol0
003omRH0o`000002o`0000?omRP000?o0000ooHX0?of:0000oof:004o`0000ComBX000?o0000ooDZ
0?oe:P001?oe:P03o`0000GomB/000?o0000ooD[0?oe:`000ooe:`03o`0000KomB/000?o0000ooDZ
0?oe:P000ol000000ooe:`3o0000ooD[0006ooD[0003o`000?of:@3omRT000?o000000?omBX0o`00
0?of:@001_of:@000ol0003omRP0ooHX0003o`000003ooHX0?l0003omRL000GomRL000?o0000ooLU
0?og9@000ol00002ooHV0003o`000?og903omb@000Comb@000Co0000ooHX0?l0003o00001?of:000
1?l0003ok4`0ona<0?l00005ona<0005o`000?o/C03o0000olVi0?l000000_o9^@001?l0003obKT0
olVi0?l00002olVi0004o`000?o9^@3obKT0olVi00;o00003oooool00ol0003oooooooooo`05oooo
o`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol00005ooooo`03
o`000?oooooooooo00cooooo1?l00004omRB0003o`000?oLP`3og8<000;og8<000?o0000omf20?l0
00000_l000000ood;@3o0000oo@_0004oo@_0003o`000?od<03om30000Com30000?o0000oo<b0?l0
00000_l00002ooPO0003o`000?oh8@3on24000Con24000?o0000ooLR0?og8P000ol00002ooPQ0003
o`000?og8P3omb8000Comb800ol00005ooLU0003o`000?of9P3omRH000ComRH00_l00007ooHX0003
o`000?of:03o000000;o00000_oe:P000ol0003omBX0ooDZ0004ooDZ0003o`000?oe:P3omBX000?o
00000_oe:`000ol0003omB/0ooD[0004ooD[0003o`000?oe:`3o000000;o00000ooe;0000ol0003o
mB/0ooD[0003ooD[00?o00001Ooe:`000ol0003omB/0ooD[0004ooD[00?o00001Ooe:P000ol0003o
mRT0ooHY0004ooHY00?o00001Oof:0001?l0003omRL0ooHW0?of9`05o`0000KomRH000Co0000ooLT
0?og903omb@01?l00006ooHX0003o`000?o/C03o000000Gok4`000?o0000ona<0?o/C0000_l00000
0oo9^@3o0000o`000003olVi0004o`000?o9^@3obKT0o`0000;obKT000Co0000olVh0?o9^03o0000
3_ooool00ol0003oooooooooo`05ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`07o`00
0?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02Oooool3o`0000;ooooo0_l00004omRB0004o`000?oLP`3og8<0omb300?o00001Ood;@00
0ol0003om2l0oo@_0003oo@_0003o`000?od<03om30000?om3000_l00006ooPO0003o`000?oh8@3o
n24000?on2400ol00006ooPQ0003o`000?og8P3omb8000?o000000?omb@0o`000?og9@001_og9@00
0ol0003omRH0ooHV0003o`0000;omRL000?o0000ooHX0?of:0001?of:002o`0000KomBX000?o0000
ooDZ0?oe:P000ooe:P03o`0000KomB/000Co0000ooD[0?oe:`3omB/01?l00007ooD/0003o`000?oe
:`3o000000;o000000?omB`0o`000?oe:`001_oe:`000ol0003omB/0ooD[0003o`0000;omB/000?o
0000ooDZ0?oe:P001?oe:P000ol0003omRT0ooHY0003o`000003ooDZ0?l0003omRP000GomRP01?l0
0004ooHW0003o`000?of9P3omRH000ComRH01?l00004ooLT0003o`000?of:03omRP000?omRP00_l0
0005ona<0003o`000?o/C03ok4`000;ok4`000Co0000olVi0?o9^@3o00000oo9^@000ol0003obKT0
o`000003olVi0004o`000?o9^03obKP0o`0000kooooo00?o0000ooooooooool01Oooool00005oooo
ool0003oooooooooool000002oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooooooo
o`;o00002?ooool3o`0000Kooooo1?l000000ooHTP3o0000o`000002o`000003oo@^0?l0003om2d0
00Gom2d000?o0000oo@_0?od;`000ood;`000ol0003om300oo@`0003o`0000;on1d000?o0000ooPO
0?oh7`001?oh7`000ol0003on240o`000002o`0000?on20000?o0000ooPQ0?oh8@000ooh8@03o`00
00Gomb@000?o0000ooLU0?og9@001?og9@03o`0000KomRL000?o0000ooHX0?of:0000ol00002ooHY
0003o`000?oe:P3omBX000ComBX000?o0000ooDZ0?l000000_l00002ooD[0003o`000?oe:`3omB/0
00ComB/01?l00004ooD/0003o`000?oe;03omB`000ComB`00_l00005ooD/0003o`000?oe:`3omB/0
00ComB/00ol00006ooD[0004o`000?oe:P3omBX0ooDZ00Go00001Ooe:P000ol0003omRP0ooHX0003
o`000003ooHY0?l0003omRL000KomRL000?o0000ooHV0?of9P000ol000000oof9P3o0000ooLT0006
ooLT0003o`000?of:03o000000;o00000_of:0001Ol0003ok4`0ona<0?o/C03o000000Gok4`000Co
0000olVi0?o9^@3o00000_o9^@001?l0003obKT0olVi0?l00003olVi0003o`000?o9^03obKP000;o
00003_ooool00ol0003oooooooooo`04ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`;o
00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0ol00009ooooo`04
o`000?o_@@3okd40onm100;o00001Ood;P000ol0003om2d0oo@]0004oo@]0003o`000?od;`3om2l0
00;om2l00ol00006ooPM0003o`000?oh7`3on1l000?on1l00ol00006ooPP0003o`000?oh8@3o0000
00;o00000oog8`000ol0003omb@0ooLT0003ooLT0003o`000?og9@3ombD000?o00000_of9`000ol0
003omRL0ooHW0004ooHW00?o00001_of:@001?l0003omBX0ooDZ0?oe:P04o`0000KomB/000?o0000
ooD[0?oe:`000ol000000ooe;03o0000ooD/0006ooD/0003o`000?oe;03omB`000?o00000_oe;@00
0ol0003omB`0ooD/0003ooD/0003o`000?oe:`3omB/000?o00000_oe;0000ol0003omB/0ooD[0004
ooD[00Co00001?oe:`000ol0003omBX0ooDZ0003ooDZ00?o00001Oof:@000ol0003omRL0ooHW0004
ooHW00?o00001Oof9P000ol0003omb@0ooLT0004ooLT00;o00001_of:0000ol0003ok4`0o`000005
ona<0008o`000?o/C03o0000o`000?o9^@3o0000olVi0?l00002olVi0009o`000?o9^@3obKT0olVi
0?l0003obKP0o`000?o9^03o000000kooooo00?o0000ooooooooool01?ooool00005ooooool0003o
ooooooooool000002oooool00ol0003oooooo`000003o`0000Cooooo0_l00002ooooo`?o00003Ooo
ool01Ol0003okd40onm10?o_@@3o000000Kom2h000?o0000oo@]0?od;@000ood;@000ol0003om2l0
o`000002o`0000;onA/000?o0000ooPM0?oh7@001Ooh7@000ol0003on1l0o`000002o`0000?on1h0
00?o0000ooPP0?oh80000ooh8003o`0000Komb<000Co0000ooLT0?og903omb@01?l00006ooHW0003
o`000?of9`3omRL000?o00000_of:@000ol0003omRT0ooHY0004ooHY00Co00001?oe:`000ol0003o
mB/0ooD[0003ooD[00?o00001Ooe;0000ol0003omB`0ooD/0004ooD/00?o00001_oe;@001?l0003o
mB`0ooD/0?oe;004o`0000KomB`000?o0000ooD[0?oe:`000ol000000ooe;03o0000ooD[0006ooD[
0003o`000?oe:P3o000000;o00000_oe:P000ol0003omRT0ooHY0004ooHY0003o`000?of9`3omRL0
00?o00000_of:0000ol0003omRH0ooHV0004ooHV0003o`000?og903omb@000?o000000?ombD0o`00
0?of:0001Oof:002o`0000Gok4`000Go0000ona<0?o/C03ok4`0o`000002olVi00;o00000_o9^@00
1?l0003obKT0olVi0?l00002olVh0004o`000?o9^03obKP0o`0000gooooo00?o0000ooooooooool0
1?ooool00005ooooool0003oooooooooool000001oooool01ol0003ooooooooooooooooo0000oooo
ool000001oooool4o`00017ooooo00Go0000onm10?o_@@3okd40o`000005oo@^0003o`000?od;@3o
m2d000?om2d00_l00006ooTK0003o`000?oh7@3on1d000Con1d00_l00007ooPN0003o`000?oh803o
000000;o00000oog8P000ol0003omb<0ooLS0003ooLS00Co00001?of9P000ol0003omRL0ooHW0003
ooHW00?o00001_of:@000ol0003omRT0ooHY0003o`000003ooD[0?l0003omB/000KomB/000?o0000
ooD[0?l000000_l00003ooD/0003o`000?oe;03omB`000?omB`000?o0000ooD/0?oe;0000ol00002
oo@]0003o`000?oe;@3omBd000ComBd01?l00003oo@]0003o`000?oe;03omB`000ComB`00ol00005
ooD/0003o`000?oe:`3omB/000ComB/00_l00006ooDZ0004o`000?of:@3omRT0ooHY00Go00001_of
:0001?l0003omRH0ooHV0?of9P05o`0000GombD000?o0000ooHX0?of:0000ol00002ooHX0005o`00
0?o/C03ok4`0ona<0?l000001?o/C002o`0000;obKT000Co0000olVi0?o9^@3o00000_o9^@001?l0
003obKP0olVh0?l00002olVh0003o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool0
00;ooooo0_l00009ooooo`?o00000_ooool5o`0000?ooooo0_l0000Cooooo`03o`000?o_@@3okd40
00;okd4000?o0000oo@^0?od;P000ood;P000ol0003om2d0o`000002o`0000;onAT000?o0000ooTK
0?oi6`001?oi6`000ol0003on1d0ooPM0003o`0000;onAd000?o0000ooPN0?oh7P001?oh7P02o`00
00Oomb8000?o0000ooLS0?l000000_l00002ooLU0003o`000?of9P3omRH000ComRH000?o0000ooHW
0?l000000_l00003ooHX0003o`000?of:@3omRT000?omRT00ol00005ooD[0003o`000?oe:`3omB/0
00ComB/00_l00007ooD/0004o`000?oe;03omB`0ooD/00Co00001_od;@000ol0003omBd0ooD]0003
o`0000;om2d000?o0000oo@]0?od;@000ood;@000ol0003omB`0ooD/0003o`0000;om2d000?o0000
ooD/0?oe;0001?oe;0000ol0003omB/0ooD[0003o`000003ooD[0?l0003omBX000GomBX01?l00004
ooHY0003o`000?of:03omRP000ComRP01?l00003ooHV0003o`000?og9@3ombD000CombD00ol00006
ooHX0003o`000?o/C03o000000Cok4`000?o0000one<0?o]C0000ol000000oo9^@3o0000olVi0002
olVi0004o`000?o9^03obKP0o`0000;obKP00_l0000<ooooo`03o`000?oooooooooo00Cooooo000L
ooooo`03o`000?oooooooooo017ooooo00Go0000onm10?o_@@3okd40o`000005oo@^00?o00001Ooi
6@000ol0003onA/0ooTK0003ooTK00?o00001_oi7@000ol0003on1h0ooPN0003o`0000;on24000?o
0000ooLR0?og8P001?og8P02o`0000KombD000?o0000ooHV0?of9P000oof9P02o`0000OomRP000?o
0000ooHY0?l000000_l00003ooDZ0003o`000?oe:`3omB/000?omB/000?o0000ooD[0?oe:`000ol0
0002ooD/0003o`000?oe;03omB`000ComB`01?l00003oo@]0003o`000?od;@3om2d000Com2d00ol0
0006oo@]0004o`000?od;@3om2d0oo@]00Co00001_od;@001?l0003omB`0ooD/0?oe;005o`0000Go
mB/000?o0000ooDZ0?oe:P000ol000000ooe:`3o0000ooHY0006ooHY0003o`000?of:03omRP000?o
000000?omRP0o`000?of9P001Oof9P000ol0003ombD0ooLU0003o`000003ooLU0?l0003omRP000Ko
mRP00_l00004ona<0003o`000?o]C03okD`000;okD`000Co0000olVi0?l0003o00000oo9^@000ol0
003obKP0o`000002olVh0004o`000?o9^03obKP0o`0000_ooooo00?o0000ooooooooool01?ooool0
01gooooo00?o0000ooooooooool04Oooool5o`000004oo@^0?l0003o0000o`0000?onAX000?o0000
ooTI0?oi6@000ooi6@000ol0003onA/0o`000002o`0000?onA/000?o0000ooTM0?oi7@000ooi7@03
o`0000Kon24000?o0000ooLR0?og8P000ol00002ooLT0003o`000?og9@3ombD000CombD000?o0000
ooHV0?l000000_l00002ooHW0003o`000?of:03omRP000ComRP00_l00007ooDZ0004o`000?oe:`3o
mB/0ooD[00Co00001_oe;0000ol0003omB`0ooD/0003o`000003oo@]0?l0003om2d000Gom2d000?o
0000oo@]0?od;@000ol00002oo@^0003o`000?od;@3om2d000Com2d01?l00003oo@]0003o`000?od
;@3om2d000Com2d01?l00004ooD/0003o`000?oe:`3omB/000?omB/00ol00005ooD[0003o`000?of
:@3omRT000ComRT00ol00005ooHX0003o`000?of9P3omRH000?omRH00ol00005ooLU0003o`000?of
:03omRP000;omRP00_l000000oof:03o0000ona<0002ona<0003o`000?o]C03okD`000?okD`000Co
0000olVi0?o9^@3o00000oo9^@000ol0003obKP0o`000002olVh0004o`000?o9^03obKP0o`0000_o
oooo00?o0000ooooooooool01?ooool001kooooo00?o0000ooooooooool04Oooool00ol0003om2h0
oo@^0002o`0000OonAX000Co0000ooTI0?oi6@3onAT01?l00006ooTK0003o`000?oi7@3o000000;o
00000ooh7`000ol0003on240ooPQ0003ooPQ00?o00001_og90001?l0003ombD0ooLU0?og9@04o`00
00KomRL000?o0000ooHX0?of:0000ol00002ooHY0003o`000?oe:P3omBX000ComBX01?l00003ooD/
0003o`000?oe;03omB`000ComB`00ol00005oo@]0003o`000?od;@3om2d000?om2d00ol00006oo@^
0003o`000?od;@3om2d000?o000000?om2h0o`000?od;@001Ood;@000ol0003om2d0oo@]0003o`00
00;om2d000?o0000ooD/0?oe;0001?oe;0000ol0003omB/0o`000002o`0000;omB`000?o0000ooD[
0?oe:`001?oe:`000ol0003omRT0ooHY0003o`000003ooHY0?l0003omRP000GomRP000?o0000ooHV
0?of9P000ol00002ooHV0003o`000?og9@3ombD000CombD000Co0000ooHX0?l0003o00001?of:000
0ol0003ok4`0o`000005one<0005o`000?o]B`3o0000olVi0?l000000_o9^@001?l0003obKP0olVh
0?l00002olVh0003o`000?o9^03obKP000;o00002oooool00ol0003oooooooooo`03ooooo`007ooo
ool2o`0001;ooooo00Go0000oo@^0?od;P3om2h0o`000006ooTJ00Co00001?oi6@000ol0003onA/0
ooTK0003ooTK00?o00001_oh7`000ol0003on240o`000002o`0000?omb8000?o0000ooLT0?og9000
0oog9004o`0000ComRH000?o0000ooHW0?of9`000oof9`03o`0000KomRT000?o0000ooDZ0?oe:P00
0ol000000ooe:`3o0000ooD/0005ooD/0003o`000?oe;03omB`000?o00000_od;@000ol0003om2d0
oo@]0004oo@]0003o`000?od;@3o000000;o00000_od;P000ol0003om2h0oo@^0004oo@^00?o0000
1Ood;P000ol0003om2d0oo@]0003oo@]00?o00001_od;@001?l0003omB`0ooD/0?oe;004o`0000Ko
mB`000Co0000ooD[0?oe:`3omB/01Ol00005ooHY0004o`000?of:03omRP0ooHX00Go00001_of9P00
1?l0003ombD0ooLU0?og9@04o`0000KomRP00_l00005one<0003o`000?o]B`3okD/000;o000000Co
bKT0o`000?o9^@3o00000_o9^0001_l0003obKP0olVh0?l0003obKP0o`0000;ob[P000?o0000oooo
ooooool02?ooool00ol0003oooooooooo`03ooooo`008Oooool00ol0003oooooooooo`0@ooooo`Go
00000_oi6P03o`000003ooTI0?l0003onAT000KonAT000?o0000ooTK0?l000000_l00003ooTM0003
o`000?oh7`3on1l000?on1l00_l00007ooLR0003o`000?og903o000000;o00000_og9@000ol0003o
mRH0ooHV0004ooHV0003o`000?of9`3o000000;o00000oof:@000ol0003omRT0ooHY0003ooHY00?o
00001Ooe:`000ol0003omB`0ooD/0003ooD/00?o00001_od;@001?l0003om2d0oo@]0?od;@04o`00
00Kom2h000?o0000oo@^0?od;P000ol00002oo@^0003o`000?od;P3om2h000Com2h000?o0000oo@]
0?l000000_l00002oo@^0003o`000?od;@3om2d000Com2d01?l00003ooD]0003o`000?oe;03omB`0
00ComB`01?l00004ooD[0003o`000?of:@3omRT000?omRT01?l00004ooHX0003o`000?of9P3omRH0
00ComRH01?l00003ooLT0003o`000?of:03omRP000;omRP00_l000000oof:03o0000one<0003one<
0003o`000?o]B`3okD/000;okD/000?o0000olVi0?o9^@000_l00002olVh0003o`000?o9^03o0000
00;obKP000Co0000olZh0?o:^03o00002Oooool2o`0000Gooooo000Rooooo`03o`000?oooooooooo
017ooooo00?o0000oo@]0?l000000_l00005ooTI0003o`000?oi6@3onAT000ConAT00_l00007ooTM
0003o`000?oh7`3o000000;o00000_oh8@000ol0003omb80ooLR0004ooLR00;o00001_og9@000ol0
003omRH0ooHV0003ooHV00;o00001oof:@000ol0003omRT0o`000002o`0000?omB/000?o0000ooD[
0?oe:`000ooe:`000ol0003omB`0o`000002o`0000?om2d000?o0000oo@]0?od;@000ood;@04o`00
00Com2h000?o0000oo@^0?od;P000ood;P03o`0000Kom2h000Co0000oo@^0?od;P3om2h01?l00006
oo@^0003o`000?od;@3om2d000?o000000?om2d0o`000?oe;@001Ooe;@000ol0003omB`0ooD/0003
o`000003ooD/0?l0003omB/000KomB/000?o0000ooHY0?l000000_l00002ooHY0003o`000?of:03o
mRP000ComRP000?o0000ooHV0?of9P000ol000000oof9P3o0000ooLT0005ooLT0004o`000?of:03o
0000o`0000ComRP000Co0000one<0?o]C03o00001Oo]B`02o`0000;obKT000?o0000olVh0?l00000
0_o9^0001?l0003obKP0olVh0?l00002olZh00;o00002?ooool2o`0000Gooooo000Sooooo`03o`00
0?oooooooooo017ooooo00Go0000oo@]0?od;@3om2d0o`000005ooTI0003o`000?oi6@3onAT000?o
00000_oi6`000ol0003onAd0ooTM0004ooTM00;o00001_oh8@000ol0003omb80ooLR0003o`0000;o
mb@000?o0000ooLU0?og9@001?og9@000ol0003omRH0o`000002o`0000;omRP000?o0000ooHY0?of
:@001?of:@02o`0000OomB/000Co0000ooD[0?oe:`3omB/00ol00007oo@]0003o`000?od;@3o0000
00;o00000_od;P000ol0003om2h0oo@^0004oo@^0003o`000?od;P3o000000;o00000_od;P000ol0
003om2h0oo@^0004oo@^00Co00001?od;P000ol0003om2h0oo@^0003oo@^00?o00001Ood;@000ol0
003omBd0ooD]0003ooD]00?o00001Ooe;0000ol0003omB/0ooD[0004ooD[00;o00001_of:@001?l0
003omRP0ooHX0?of:005o`0000GomRH000Co0000ooLT0?og903omb@01?l00006ooHX0003o`000?o]
C03o000000GokD/000?o0000one;0?o]B`000ol000001Oo9^03o0000olVh0?o9^03o000000;obKP0
00?o0000olZh0?l000000_o:^0000ol0003oooooooooo`05ooooo`;o00001Oooool002Cooooo00?o
0000ooooooooool04Oooool5o`0000?onAT01?l00006ooTK0003o`000?oi7@3onAd000?o00000_oh
7`000ol0003on240ooPQ0003ooPQ00?o00001_og90001?l0003ombD0ooLU0?og9@04o`0000KomRP0
00?o0000ooHY0?of:@000ol00002ooDZ0003o`000?oe:`3omB/000ComB/01?l00003ooD/0003o`00
0?od;@3om2d000Com2d00_l00006oo@^0004o`000?od;P3om2h0oo@^00Co00001_od;P000ol0003o
m2h0oo@^0003o`000003oo@_0?l0003om2h000Kom2h000?o0000oo@^0?l000000_l00002oo@^0003
o`000?od;@3om2d000Com2d000?o0000ooD]0?l000000_l00002oo@]0003o`000?oe;03omB`000Co
mB`000?o0000ooD[0?oe:`000ol000000ooe:`3o0000ooHY0005ooHY00Co00000oof9`000ol0003o
mRH0ooHV0004ooHV00Co00001?og90000ol0003omRP0ooHX0003ooHX00;o00001Oo]B`000ol0003o
kD/0one;0002one;0004o`000?o9^03o0000o`0000;obKP000?o0000olVh0?l000000_o:^0000ol0
003ob[P0olZh0002o`0000Gooooo0ol00005ooooo`009Oooool2o`0001?ooooo00?o0000oo@_0?l0
00000ol00004ooTK0003o`000?oi6`3onA/000?onA/00ol00006ooPO0003o`000?oh8@3o000000;o
00000oog8P000ol0003omb@0ooLT0003ooLT00Co00001?of9`000ol0003omRP0ooHX0003ooHX00?o
00001_oe:P000ol0003omB/0ooD[0003o`0000;omB`000?o0000ooD/0?oe;0000ooe;0000ol0003o
m2d0oo@]0003o`0000;om2d000?o0000oo@^0?od;P000ood;P04o`0000Com2h000?o0000oo@^0?od
;P000ood;P03o`0000Gom2l000?o0000oo@^0?od;P001?od;P02o`0000Kom2h000Co0000oo@]0?od
;@3om2d01?l00006oo@]0004o`000?oe;03omB`0ooD/00Go00001Ooe:`000ol0003omRT0ooHY0003
o`000003ooHY0?l0003omRL000GomRL000?o0000ooHV0?of9P000ol000000oog9@3o0000ooLT0006
ooLT0003o`000?of:03o000000;o00000_of9`001Ol0003okD/0one;0?o]B`3o000000CokD/00_l0
0002olVh0003o`000?o9^03o000000;obKP000Co0000olZh0?o:^03o00000_o:^0000ol0003ob[L0
o`000004ooooo`?o00001Oooool002Oooooo00?o0000ooooooooool04Oooool01Ol0003om2l0oo@_
0?od;`3o000000GonA/000?o0000ooTK0?l000000_l00003ooTM0003o`000?oh7`3on1l000?on1l0
0ol00006ooLR0003o`000?og903o000000;o00000oog9@000ol0003omRL0ooHW0003ooHW0003o`00
0?of:03o000000;o00000oof:@000ol0003omBX0ooDZ0003ooDZ00?o00001_oe;0001?l0003omB`0
ooD/0?oe;004o`0000Kom2d000?o0000oo@^0?l000000_l00002oo@^0003o`000?od;P3om2h000Co
m2h000?o0000oo@^0?l000000_l00002oo@_0003o`000?od;`3om2l000Com2l000?o0000oo@^0?od
;P000ol000000ood;`3o0000oo@^0005oo@^00Co00000ood;P000ol0003om2d0oo@]0004oo@]00Co
00001?oe;0000ol0003omB/0ooD[0003ooD[00?o00001Oof:@000ol0003omRL0ooHW0003ooHW00?o
00001Oog9@000ol0003omb@0ooLT0004ooLT00;o00001_of9`000ol0003okD/0o`000004one;0003
o`000?o]BP3okDX000;o000000?obKP0o`000?l000000_o9^0001?l0003ob[P0olZh0?l00002olZh
0004o`000?o:]`3ob[L0o`0000?ooooo0ol00005ooooo`00:?ooool00ol0003oooooooooo`0Aoooo
o`Go00000ooi6`04o`0000KonAd000?o0000ooPO0?l000000_l00003ooPQ0003o`000?og8P3omb80
00?omb800_l00007ooLU0004o`000?of9`3omRL0ooHW00?o00001oof:@000ol0003omBX0o`000002
o`0000;omB/000?o0000ooD/0?oe;0001?oe;004o`0000?om2d000?o0000oo@]0?od;@001?od;@02
o`0000Kom2h000Co0000oo@^0?od;P3om2h01?l00006oo@_0004o`000?od;`3om2l0oo@_00Go0000
1Ood;`000ol0003om2h0oo@^0003o`0000;om2h000?o0000oo@^0?od;P000ood;P000ol0003om2d0
oo@]0003o`0000;om2d000?o0000ooD/0?oe;0001?oe;0000ol0003omB/0o`000002o`0000;omB/0
00?o0000ooHY0?of:@001?of:@000ol0003omRL0o`000002o`0000;omRL000?o0000ooLU0?og9@00
1?og9@000ol0003omb@0ooLT0003o`000003ooLS0?l0003omRL000GomRL00_l00004one;0003o`00
0?o]BP3okDX000;okDX000Co0000olVh0?l0003o00000_o9^0000ol0003ob[P0o`000002olZh0004
o`000?o:]`3ob[L0olZg00;o000000Koooooo`000?liW`3o0000ooooool00004ooooo`00:Oooool0
0ol0003oooooooooo`0Booooo`03o`000?od<03o000000?o00001?oh7@000ol0003onAd0ooTM0003
ooTM00;o00001ooh8@000ol0003omb80o`000002o`0000;omb@000?o0000ooLU0?og9@001?og9@04
o`0000?omRP000?o0000ooHY0?of:@001?of:@02o`0000KomB/000?o0000ooD/0?oe;0000ol00000
0ooe;03o0000oo@]0005oo@]0003o`000?od;@3om2d000?o00000_od;P000ol0003om2h0oo@^0003
oo@^00Co00001?od;`000ol0003om2l0oo@_0003oo@_00Co00001?od;`000ol0003om2l0oo@_0003
oo@_00?o00001_od;P001?l0003om2h0oo@^0?od;P04o`0000Kom2d000Co0000ooD/0?oe;03omB`0
1?l00006ooD[0004o`000?of:@3omRT0ooHY00Co00001_of9`001?l0003ombD0ooLU0?og9@05o`00
00Gomb<000?o0000ooHW0?of9`000ol000000oof9`3o0000one;0002one;0003o`000?o]BP3okDX0
00;okDX00_l00002olVh0003o`000?o9^03o000000;ob[P000Co0000olZh0?o:^03o00000oo:]`00
2?l0003ob[L0o`000?l0003o>Il0o`000?oooooo00001?ooool002[ooooo0_l0000Cooooo`05o`00
0?od<03om300oo@`0?l000001Ooh7@000ol0003onAd0o`000002o`0000;on1h000?o0000ooPQ0?oh
8@001?oh8@02o`0000Komb@000?o0000ooLU0?og9@000ol00002ooHV0003o`000?of:03omRP000?o
mRP000?o0000ooHY0?of:@000ol00002ooDZ0003o`000?oe:`3omB/000?omB/00ol00005ooD/0003
o`000?od;@3om2d000?om2d00ol00006oo@^0003o`000?od;P3o000000;o000000?om2l0o`000?od
;`001_od;`000ol0003om2l0o`000002o`0000;om2l000?o0000oo@_0?od;`001?od;`000ol0003o
m2l0o`000002o`0000;om2l000?o0000oo@^0?od;P001?od;P04o`0000?om2h000?o0000oo@]0?od
;@001?od;@04o`0000?omB`000?o0000ooD[0?oe:`001?oe:`04o`0000?omRT000?o0000ooHW0?of
9`001?of9`04o`0000?ombD000?o0000ooLS0?og8`001?og8`03o`0000GomRL000?o0000one;0?l0
00001?o]BP000ol0003okDT0one90002o`000003olVh0?l0003o000000;ob[P000Co0000olZh0?o:
^03o00000_o:]`000ol0003ob[L0olZg0002o`000004ocVO0?l0003oooooo`0000Cooooo000/oooo
o`03o`000?oooooooooo017ooooo1Ol00003ooPM00?o00001_oh7P000ol0003on240ooPQ0003o`00
00;omb8000?o0000ooLT0?og90000oog9003o`0000KomRH000Co0000ooHX0?of:03omRP01?l00006
ooDZ0003o`000?oe:`3o000000;o00000ooe;0000ol0003omB`0ooD/0003ooD/0003o`000?od;@3o
000000;o00000_od;P000ol0003om2h0oo@^0004oo@^00;o00001Ood;`000ol0003om2l0oo@_0004
oo@_00;o00001_od;`001?l0003om2l0oo@_0?od;`04o`0000Kom2l000?o0000oo@^0?od;P000ol0
00000ood;P3o0000oo@^0005oo@^0003o`000?od;@3om2d000?o000000?omBd0o`000?oe;0001Ooe
;0000ol0003omB/0ooD[0003o`000003ooDZ0?l0003omRT000GomRT000?o0000ooHW0?of9`000ol0
00000oof9`3o0000ooLU0005ooLU0003o`000?og8`3omb<000?o000000?omb<0o`000?of9`001Oof
9`02o`0000CokDX000?o0000one90?o]B@000_o]B@001?l0003obKP0o`000?l00002olZh0004o`00
0?o:^03ob[P0o`0000;ob[L000?o0000olZg0?o:]`001?l000000ooooooo0000ooooo`03ooooo`00
;Oooool00ol0003oooooooooo`0Aooooo`03o`000?oc<P3olc8000Co00000ooh7`000ol0003on1h0
ooPN0003ooPN00?o00001_og8P000ol0003omb@0o`000002o`0000?ombD000?o0000ooHV0?of9P00
0oof9P04o`0000ComRT000?o0000ooDZ0?oe:P000ooe:P02o`0000OomB`000Co0000ooD/0?oe;03o
mB`00ol00006oo@^0003o`000?od;P3om2h000?o00000_od;P000ol0003om2l0oo@_0003oo@_0003
o`000?od;`3om2l000?o00000_od;`000ol0003om2l0oo@_0003oo@_00Co00001?od;`000ol0003o
m2l0oo@_0003oo@_00?o00001Ood;P000ol0003om2h0oo@^0003oo@^00?o00001Ooe;@001?l0003o
mB`0ooD/0?oe;005o`0000GomBX000Co0000ooHY0?of:@3omRT01Ol00005ooHW0004o`000?og9@3o
mbD0ooLU00Go00001Oog8`000ol0003omRL0ooHW0003o`000003ooHV0?l0003okDX000;okDX000?o
0000one90?o]B@000oo]B@001_l0003obKP0olVh0?l0003ob[P0o`0000?ob[P000co0000olZg0?o:
]`3o0000olZg0?l0003ob;X0o`000?n__`3o0000ooooool00004ooooo`00;_ooool00ol0003ooooo
ooooo`0Aooooo`05o`000?oc<P3olc80oo<b0?l000001Ooh7`000ol0003on1h0o`000002o`0000?o
n20000?o0000ooLR0?og8P000oog8P03o`0000KombD000?o0000ooHV0?l000000_l00002ooHW0003
o`000?of:@3omRT000ComRT000?o0000ooDZ0?l000000_l00002ooD[0003o`000?oe;03omB`000Co
mB`01?l00003oo@]0003o`000?od;P3om2h000?om2h00ol00006oo@^0004o`000?od;`3om2l0oo@_
00Co00001_od;`000ol0003om2l0o`000002o`0000;om2l000?o0000oo@_0?od;`001?od;`000ol0
003om2l0o`000002o`0000;om2l000?o0000oo@^0?od;P001?od;P000ol0003om2h0o`000002o`00
00;om2d000?o0000ooD]0?oe;@000ooe;@04o`0000ComB/000?o0000ooDZ0?oe:P000ooe:P04o`00
00ComRP000?o0000ooHW0?of9`000oof9`04o`0000Comb@000?o0000ooLS0?og8`000oog8`03o`00
00GomRH000?o0000one:0?l000001Oo]B@001Ol0003okDP0o`000?l0003ob[P000;o00000_o:^000
3Ol0003ob[L0olZg0?o:]`3o0000olZg0?l0003ob;X0o`000?n__`3o0000ooooool000001?ooool0
02oooooo00?o0000ooooooooool04Oooool5o`0000?on1l01?l00006ooPP0003o`000?og8P3o0000
00;o00000oog8`000ol0003ombD0ooLU0003ooLU00;o00001_of9`001?l0003omRT0ooHY0?of:@04
o`0000KomB/000?o0000ooD/0?oe;0000ol00002ooD/0003o`000?od;@3om2d000?om2d000?o0000
oo@^0?l000000_l00003oo@^0003o`000?od;P3om2h000?om2h01?l00003oo@_0003o`000?od;`3o
m2l000Com2l00_l00006oo@_0004o`000?od;`3om2l0oo@_00Co00001_od;`001?l0003om2h0oo@^
0?od;P04o`0000Kom2d000?o0000ooD]0?l000000_l00002ooD/0003o`000?oe:`3omB/000ComB/0
00?o0000ooDZ0?l000000_l00002ooHY0003o`000?of:03omRP000ComRP000?o0000ooHW0?l00000
0_l00002ooHV0003o`000?og903omb@000Comb@000?o0000ooLS0?l000000_l00002ooLR0003o`00
0?of9P3omRH000?omRH00_l00005one90005o`000?o]B03okDP0one80?l000000_o:^0001?l0003o
b[P0olZh0?l00002olZg0005o`000?o:]`3ob[L0o`000?o8^P000_l00002ooooo`03o`000?oooooo
oooo00;ooooo000`ooooo`;o00004oooool00ol0003olc<0o`000003o`0000Con2400_l00003ooPP
00?o00001oog8`000ol0003ombD0o`000002o`0000;omRH000?o0000ooHW0?of9`000oof9`04o`00
00ComRT000?o0000ooD[0?oe:`000ooe:`03o`0000KomB`000Co0000oo@]0?od;@3om2d00ol00007
oo@^0003o`000?od;P3o000000;o00000_od;`000ol0003om2l0oo@_0003oo@_0003o`000?od;`3o
m2l000?o00000_od;`000ol0003om2l0oo@_0003oo@_00Co00001?od;`000ol0003om2l0oo@_0003
oo@_00Co00000ood;P000ol0003om2d0oo@]0004oo@]00;o00001_oe;0001?l0003omB/0ooD[0?oe
:`04o`0000KomRT000Co0000ooHX0?of:03omRP01?l00006ooHV0004o`000?og903omb@0ooLT00Co
00001_og8P000ol0003omRH0o`000002o`0000;ombD000Go0000one90?o]B@3okDT0o`000004one8
0004o`000?o:^03ob[P0o`0000;ob[P000Co0000olZg0?o:]`3o00000_o:]`001?l0003ob;X0o`00
0?l00003ooooo`03o`000?oooooooooo007ooooo000booooo`03o`000?oooooooooo017ooooo00Go
0000oo<c0?oc<`3olc<0o`000005ooPQ00Co00000ooh8@000ol0003omb<0ooLS0004ooLS00;o0000
1_of9P000ol0003omRL0o`000002o`0000?omRP000?o0000ooHY0?of:@000oof:@000ol0003omB/0
o`000002o`0000?omB/000?o0000ooD/0?oe;0000ooe;004o`0000?om2d000?o0000oo@^0?od;P00
1?od;P02o`0000Kom2l000Co0000oo@_0?od;`3om2l01?l00006oo@_0003o`000?od;`3o000000;o
00000_od;`000ol0003om2l0oo@_0004oo@_0003o`000?od;`3o000000;o00000_od;`000ol0003o
m2h0oo@^0003oo@^0003o`000?od;@3om2d000?o00000_od;@000ol0003omB`0ooD/0003ooD/00Co
00000ooe:`000ol0003omRT0ooHY0004ooHY00Co00000oof9`000ol0003omRH0ooHV0004ooHV00Co
00000oog8`000ol0003omb80ooLR0004ooLR00;o00001_og9@000ol0003okDT0o`000004one80008
o`000?o^A`3o0000o`000?o:^03o0000olZh0?l00002olZg0007o`000?o:]`3o0000olRj0?l0003o
[kl0o`000003ooooo`03o`000?oooooooooo007ooooo000cooooo`03o`000?oooooooooo017ooooo
1Ol000001?oh8@3o0000o`000?l00002ooLR0003o`000?oh8@3on24000?on24000?o0000ooLS0?og
8`000ol00002ooLT0003o`000?of9P3omRH000?omRH00ol00006ooHX0004o`000?of:@3omRT0ooHY
00?o00001ooe:`000ol0003omB`0o`000002o`0000;om2d000?o0000oo@]0?od;@000ood;@000ol0
003om2h0oo@^0003o`0000;om2h000?o0000oo@_0?od;`000ood;`04o`0000?om2l000?o0000oo@_
0?od;`001?od;`02o`0000Kom2l000Co0000oo@_0?od;`3om2l01?l00006oo@_0004o`000?od;P3o
m2h0oo@^00Co00001_od;@000ol0003omB`0o`000002o`0000;omB`000?o0000ooD[0?oe:`000ooe
:`000ol0003omRT0ooHY0003o`000003ooHY0?l0003omRL000GomRL000?o0000ooHV0?of9P000ol0
00000oog9@3o0000ooLS0005ooLS0003o`000?og8P3omb8000?o000000?on240o`000?og9@001Oog
9@02o`0000CokDP000Go0000oni70?o^A`3okTL0o`000002olZh00;o00000_o:]`001ol0003ob[L0
o`000?o8^P3o0000ojno0?l000000oooool00ol0003oooooooooo`01ooooo`00=?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oc=03olc@000;o00001_og8P001?l0003on240ooPQ0?oh8@04o`00
00Komb@000?o0000ooHV0?l000000_l00003ooHW0003o`000?of:03omRP000?omRP01?l00003ooDZ
0003o`000?oe:`3omB/000ComB/00_l00006oo@]0004o`000?od;@3om2d0oo@]00Co00001_od;P00
0ol0003om2l0o`000002o`0000;om2l000?o0000oo@_0?od;`000ood;`000ol0003om2l0oo@_0003
o`0000;om2l000?o0000oo@_0?od;`000ood;`04o`0000?om2l000?o0000oo@_0?od;`001?od;`04
o`0000?om2h000?o0000oo@]0?od;@001?od;@02o`0000KomB`000Co0000ooD[0?oe:`3omB/01?l0
0005ooHY0004o`000?of9`3omRL0ooHW00Go00001Oog9@001?l0003omb<0ooLS0?og8`05o`0000Go
n24000Co0000ooLU0?og9@3ombD00_l000000oog8`3o0000one80002one80003o`000?o^A`3okTL0
00;okTL00_l000001Oo:^03o0000o`000?o:]`3o000000;ob[L000Co0000olRj0?l0003o00001?oo
ool00ol0003oooooooooo`01ooooo`00=Oooool2o`0001;ooooo00Go0000oo<d0?oc=03olc@0o`00
0005ooLR00Co00001?og8P000ol0003omb@0ooLT0003ooLT00;o00001oof9`000ol0003omRP0o`00
0002o`0000;omRT000?o0000ooDZ0?oe:P000ooe:P000ol0003omB/0ooD[0003o`0000;omB`000?o
0000oo@]0?od;@000ood;@04o`0000Com2h000Co0000oo@^0?od;P3om2h01?l00006oo@_0004o`00
0?od;`3om2l0oo@_00Co00001_od;`000ol0003om2l0o`000002o`0000;om2l000?o0000oo@_0?od
;`000ood;`000ol0003om2l0oo@_0003o`0000;om2h000?o0000oo@^0?od;P000ood;P000ol0003o
m2d0oo@]0003o`000003ooD]0?l0003omB`000GomB`01?l00003ooDZ0003o`000?of:@3omRT000?o
mRT01?l00004ooHV0003o`000?og9@3ombD000?ombD01?l00003ooLR0003o`000?oh8@3on24000Co
n24000Co0000ooLU0?l0003o00001?og8`000ol0003okDP0o`000004oni70003o`000?o^AP3okTH0
00?o000000Kob[L0o`000?o:]`3ob[L0o`000?o8^P02o`0000Cooooo00?o0000ooooooooool00Ooo
ool003Oooooo00?o0000ooooooooool04?ooool5o`000004ooLR0?l0003o0000o`0000?omb<000?o
0000ooLR0?og8P000oog8P000ol0003omb@0o`000002o`0000;ombD000?o0000ooHW0?of9`001?of
9`02o`0000KomRT000Co0000ooDZ0?oe:P3omBX01?l00006ooD/0003o`000?od;@3o000000;o0000
0_od;@000ol0003om2h0oo@^0003oo@^00Co00001?od;P000ol0003om2l0oo@_0003oo@_00Co0000
0ood;`000ol0003om2l0oo@_0004oo@_00;o00001_od;`001?l0003om2l0oo@_0?od;`04o`0000Ko
m2h000Co0000oo@^0?od;P3om2h01?l00005ooD]0003o`000?oe;03omB`000?o000000?omB/0o`00
0?oe:P001Ooe:P000ol0003omRT0o`000002o`0000;omRP000?o0000ooHV0?of9P001?of9P000ol0
003ombD0o`000002o`000003ooLT0?l0003omb8000Gomb8000Co0000ooPQ0?oh8@3on2401?l00006
ooLS00;o00001?o^A`000ol0003okTH0oni60002oni60004o`000?o:]`3o0000o`0000;ob[L000Co
0000olRj0?l0003o00001?ooool00ol0003oooooooooo`01ooooo`00>?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?ob=@3o000000;o00001_og8`001?l0003omb80ooLR0?og8P04o`0000GombD0
00?o0000ooHW0?of9`000ol00002ooHW0003o`000?of:@3omRT000?omRT01?l00003ooD[0003o`00
0?oe;03omB`000ComB`00_l00006oo@]0003o`000?od;P3o000000;o00000_od;P000ol0003om2h0
oo@^0004oo@^0003o`000?od;`3o000000;o00000_od;`000ol0003om2l0oo@_0003oo@_0003o`00
0?od;`3om2l000?o000000?om2l0o`000?od;`001Ood;`04o`0000?om2l000?o0000oo@^0?od;P00
1?od;P04o`0000?om2d000?o0000ooD]0?oe;@000ooe;@03o`0000GomB/000Co0000ooDZ0?oe:P3o
mBX01?l00006ooHX0004o`000?of9P3omRH0ooHV00Co00001Oog90000ol0003omb80ooLR0003ooLR
00Co00000ooh7`000ol0003omb<0ooLS0002ooLS00;o000000?omb80o`000?o^A`000_o^A`000ol0
003okTH0oni60002oni600;o00000_o:]`001?l0003ob[L0o`000?o8^P02o`0000Gooooo00?o0000
ooooooooool00Oooool003Wooooo00?o0000ooooooooool04Oooool01Ol0003olSD0oo8e0?ob=@3o
000000Gomb<01?l00004ooLS0004o`000?og9@3ombD0ooLU00Co00001_of9`000ol0003omRT0o`00
0002o`0000;omRT000?o0000ooD[0?oe:`000ooe:`000ol0003omB`0ooD/0003o`0000;omB`000?o
0000oo@]0?od;@000ood;@02o`0000Kom2h000Co0000oo@^0?od;P3om2h01?l00006oo@_0004o`00
0?od;`3om2l0oo@_00Co00001Ood;`000ol0003om2l0oo@_0003o`0000;om2l000?o0000oo@_0?od
;`000ood;`000ol0003om2h0oo@^0003o`000003oo@^0?l0003om2d000Gom2d000?o0000ooD]0?l0
00000_l00002ooD/0003o`000?oe:`3omB/000?omB/01?l00003ooHY0003o`000?of:03omRP000Co
mRP01?l00003ooLU0003o`000?og903omb@000Comb@000?o0000ooLR0?l000000_l00002ooPQ0003
o`000?oh7`3on1l000?on1l000Co0000ooLS0?l0003o00001?og8P000ol0003okTL0o`000004oni6
0003o`000?o^A03okT@000;o000000Cob[L0o`000?l0003ob;X00_l00005ooooo`03o`000?oooooo
oooo007ooooo000jooooo`03o`000?oooooooooo017ooooo1Ol000001?og8`3o0000o`000?l00002
ooLT0003o`000?og8`3omb<000?omb<01?l00004ooHV0003o`000?of9`3omRL000?omRL00_l00006
ooHY0004o`000?oe:`3omB/0ooD[00Co00001_oe;0000ol0003om2d0o`000002o`0000;om2d000?o
0000oo@^0?od;P000ood;P04o`0000Com2h000?o0000oo@_0?od;`000ood;`04o`0000Com2l000Co
0000oo@_0?od;`3om2l01?l00006oo@_0004o`000?od;`3om2l0oo@_00Co00001Ood;P001?l0003o
m2d0oo@]0?od;@04o`0000KomB`000?o0000ooD[0?l000000_l00002ooDZ0003o`000?of:@3omRT0
00?omRT000?o0000ooHX0?of:0000ol000000oof9`3o0000ooLU0005ooLU0004o`000?og903omb@0
ooLT00Co00001_oh8@001?l0003on1l0ooPO0?oh7`03o`0000Komb800_l00004oni60003o`000?o^
A03okT@000;okT@000Go0000olZg0?l0003o0000olRj0002o`0000Kooooo0Ol00001ooooo`7ooooo
000kooooo`;o00004_ooool00ol0003olSH0oo8f0002o`0000Komb@000?o0000ooLS0?l000000_l0
0003ooLT0003o`000?of9P3omRH000?omRH000?o0000ooHW0?l000000_l00002ooHX0003o`000?of
:@3omRT000?omRT01?l00004ooD[00;o00000ooe;003o`0000Kom2d000?o0000oo@^0?l000000_l0
0002oo@^0003o`000?od;P3om2h000Com2h000?o0000oo@_0?l000000_l00002oo@_0003o`000?od
;`3om2l000?om2l01?l00003oo@_0003o`000?od;`3om2l000Com2l01?l00003oo@^0003o`000?od
;P3om2h000?om2h01?l00003ooD]0003o`000?oe;03omB`000ComB`00_l00006ooDZ0004o`000?of
:@3omRT0ooHY00Co00001Oof9`001?l0003ombD0ooLU0?og9@06o`0000?omb<000?o0000ooPQ0?oh
8@001?oh8@04o`0000?on1d000Co0000ooLR0?og8P3omb800_l000000ooh803o0000oni60002oni6
0003o`000?o^A03okT@000?okT@000Go0000olZg0?o:]`3o0000olRj0002o`0000Kooooo0Ol00001
ooooo`7ooooo000mooooo`03o`000?oooooooooo013ooooo00Go0000oo8f0?ob=P3olSH0o`000005
ooLT00?o00001_og90001?l0003omRH0ooHV0?of9P03o`0000KomRP000?o0000ooHY0?l000000_l0
0002ooDZ0003o`000?oe:`3omB/000ComB/01?l00003ooD/0003o`000?od;@3om2d000?om2d00_l0
0006oo@^0004o`000?od;P3om2h0oo@^00Co00001_od;`000ol0003om2l0o`000002o`0000;om2l0
00?o0000oo@_0?od;`000ood;`000ol0003om2l0oo@_0003o`000003oo@^0?l0003om2h000Gom2h0
00?o0000oo@^0?l000000_l00002oo@]0003o`000?oe;@3omBd000?omBd000?o0000ooD/0?oe;000
0ol000000ooe:`3o0000ooDZ0005ooDZ00Co00000oof:0000ol0003omRL0ooHW0003ooHW00Co0000
0oog90000ol0003omb<0ooLS0004ooLS0003o`000?oh8@3on24000?o000000?on1l0o`000?oh7@00
1Ooh7@000ol0003omb80o`000004ooPP0003o`000?o^AP3o000000GokT@000Go0000onm30?l0003o
0000olRj0002o`0000Oooooo0Ol00001ooooo`7ooooo000nooooo`03o`000?oooooooooo013ooooo
1Ol000001?og903o0000o`000?l00003ooLT0003o`000?og903omb@000?omb@01?l00003ooHV0003
o`000?of:03omRP000?omRP00_l00006ooDZ0003o`000?oe:`3omB/000?o00000_oe:`000ol0003o
mB`0ooD/0003ooD/0003o`000?od;@3o000000;o00000_od;@000ol0003om2h0oo@^0003oo@^00Co
00001?od;P000ol0003om2l0oo@_0003oo@_00;o00001_od;`001?l0003om2l0oo@_0?od;`04o`00
00Gom2h000Co0000oo@^0?od;P3om2h01?l00006oo@]0004o`000?oe;@3omBd0ooD]00Co00001Ooe
:`000ol0003omBX0ooDZ0003o`000003ooHY0?l0003omRP000GomRP000?o0000ooHW0?l000000_l0
0002ooHV0003o`000?og903omb@000?omb@000Co0000ooLS0?og8`3omb<01Ol00005ooPO0004o`00
0?oh7@3on1d0ooPM00Co00001Ooh8002o`0000GokT@000Ko0000onm30?o_@`3okd<0o`000?o8^P02
o`0000Oooooo0Ol00001ooooo`7ooooo000oooooo`03o`000?oooooooooo017ooooo00?o0000oo8g
0?l000000_l00006ooLT0003o`000?og903o000000;o00000_og90000ol0003omRH0ooHV0003ooHV
0003o`000?of:03o000000;o00000_of:0000ol0003omBX0ooDZ0003ooDZ00?o00001_oe:`001?l0
003omB`0ooD/0?oe;003o`0000Kom2d000?o0000oo@^0?l000000_l00002oo@^0003o`000?od;P3o
m2h000Com2h000?o0000oo@_0?l000000_l00002oo@^0003o`000?od;`3om2l000?om2l01?l00003
oo@^0003o`000?od;P3om2h000?om2h01?l00003oo@]0003o`000?od;@3om2d000Com2d01?l00004
ooD/0004o`000?oe:`3omB/0ooD[00Co00001Oof:@001?l0003omRP0ooHX0?of:004o`0000KomRH0
00Co0000ooLT0?og903omb@01Ol00003ooPQ0003o`000?oh7`3on1l000Con1l01?l00003ooTL0004
o`000?oh803on200ooPP00;o00000_oh7P001Ol0003okT@0oni40?o^A03o000000Cokd<01?l00007
ooooo`7o00000Oooool1ooooo`00@?ooool2o`0001;ooooo00Co0000oo8g0?ob=`3olSL00_l00003
ooLT00?o00001_og90001?l0003omRH0ooHV0?of9P04o`0000GomRP000?o0000ooDZ0?l000000_l0
0003ooDZ0003o`000?oe:`3omB/000?omB/01?l00003ooD/0003o`000?od;@3om2d000?om2d00_l0
0006oo@^0004o`000?od;P3om2h0oo@^00Co00001_od;P000ol0003om2l0o`000002o`0000;om2h0
00?o0000oo@^0?od;P000ood;P000ol0003om2h0o`000002o`0000;om2h000?o0000oo@]0?od;@00
0ood;@000ol0003om2d0oo@]0003o`000003ooD/0?l0003omB`000GomB`01?l00003ooDZ0003o`00
0?of:@3omRT000?omRT01?l00003ooHW0003o`000?of9P3omRH000ComRH01?l00003ooLS0003o`00
0?oh8@3on24000?on24000?o0000ooPO0?oh7`000ol000000ooh7@3o0000ooTL0005ooTL0003o`00
0?oh803o000000Gon1h000?o0000oni40?l000001?o_@`001_l0003okTP0oni80?l0003oooooo`00
00Kooooo0Ol00001ooooo`7ooooo0012ooooo`03o`000?oooooooooo013ooooo2?l00003ooLU0003
o`000?og903omb@000?omb@01?l00004ooHV0004o`000?of:03omRP0ooHX00?o00001ooe:P000ol0
003omB/0o`000002o`0000;omB/000?o0000ooD/0?oe;0000ooe;0000ol0003om2d0o`000002o`00
00;om2d000?o0000oo@^0?od;P000ood;P04o`0000Com2h000Co0000oo@^0?od;P3om2h01?l00006
oo@^0004o`000?od;P3om2h0oo@^00?o00001_od;P001?l0003om2d0oo@]0?od;@04o`0000GomB`0
00?o0000ooD/0?oe;0000ol000000ooe:`3o0000ooDZ0005ooDZ0003o`000?of:@3o000000;o0000
0_of:0000ol0003omRL0ooHW0003ooHW0003o`000?of9P3omRH000?o000000?omb@0o`000?og8`00
1Oog8`001?l0003on240ooPQ0?oh8@04o`0000Gon1d000Co0000ooTL0?oi703onA`01?l00006ooPN
00;o00001?o_@`001Ol0003okTP0oni80?o^B03o000000;ooooo00?o0000ooooooooool00oooool1
o`00007ooooo0Oooool004?ooooo00?o0000ooooooooool04Oooool01Ol0003olSL0oo8g0?ob=`3o
000000GombD000?o0000ooLT0?l000000_l00002ooLU0003o`000?of9P3omRH000?omRH01?l00003
ooHX0003o`000?oe:P3omBX000ComBX00_l00006ooD[0004o`000?oe;03omB`0ooD/00Co00001Ood
;@000ol0003om2h0o`000002o`0000;om2d000?o0000oo@^0?od;P000ood;P04o`0000?om2h000?o
0000oo@^0?od;P001?od;P04o`0000?om2h000?o0000oo@^0?od;P000ood;P04o`0000ComBd000Co
0000ooD/0?oe;03omB`01?l00005ooD[0004o`000?oe:P3omBX0ooDZ00Co00001_of:0001?l0003o
mRL0ooHW0?of9`04o`0000Gomb@000Co0000ooLS0?og8`3omb<01_l00004ooPO0004o`000?oh7@3o
n1d0ooPM00Go00000ooi6P000ol0003on1h0ooPN0002ooPN00;o000000?onA`0o`000?o_@`000_o_
@`001Ol0003okTP0oni80?o^B03o000000?ooooo00?o0000ooooooooool01?ooool1o`00007ooooo
0014ooooo`03o`000?oooooooooo017ooooo1Ol00003ooLU00?o00001_og9@000ol0003omRH0o`00
0002o`0000;omRL000?o0000ooHX0?of:0000oof:0000ol0003omBX0ooDZ0003o`0000;omBX000?o
0000ooD[0?oe:`000ooe:`04o`0000ComB`000Co0000oo@]0?od;@3om2d00ol00006oo@]0003o`00
0?od;P3o000000;o00000_od;@000ol0003om2h0oo@^0003oo@^0003o`000?od;P3om2h000?o0000
0_od;@000ol0003om2h0oo@^0003oo@^0003o`000?od;P3o000000;o00000_od;@000ol0003omBd0
ooD]0003ooD]00Co00000ooe:`000ol0003omB/0ooD[0003ooD[00Co00000oof:@000ol0003omRP0
ooHX0004ooHX00Co00000oog9@000ol0003omb@0ooLT0003ooLT00Co00000ooh8@000ol0003on1l0
ooPO0004ooPO00Co00000_oi6`000ol0003onAX0ooTJ0004ooTJ0004o`000?oh7P3o0000o`0000Co
nA`000?o0000onm30?l000000oo^B0000ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo0Ol00001ooooo`00AOooool2o`0001;ooooo00?o0000oo8g0?ob=`001?l00003ooLU0003o`00
0?og9@3ombD000?ombD00_l00006ooHW0004o`000?of:03omRP0ooHX00Co00001_oe:P000ol0003o
mB/0o`000002o`0000;omB/000?o0000ooD/0?oe;0000ooe;004o`0000?omBd000?o0000oo@]0?od
;@000ood;@02o`0000Kom2d000Co0000oo@^0?od;P3om2h01?l00006oo@]0004o`000?od;P3om2h0
oo@^00?o00001_od;@000ol0003omBd0o`000002o`0000;omB`000?o0000ooD[0?oe:`000ooe:`00
0ol0003omB/0o`000002o`0000;omRT000?o0000ooHY0?of:@000oof:@000ol0003omRP0ooHX0003
o`000003ooHV0?l0003ombD000GombD000?o0000ooLT0?l000000_l00002ooLS0003o`000?oh8@3o
n24000?on24000?o0000ooPO0?oh7`000ol000000ooh7@3o0000ooTK0004ooTK0004o`000?oi6P3o
nAX0ooTJ00Co00001_oi7002o`0000?okTP000?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`7o00000Oooool004Oooooo00?o0000ooooooooool04?ooool01Ol0003olSL0oo8g0?ob
=`3o000000GombD000?o0000ooLU0?l000000_l00002ooLU0003o`000?of9`3omRL000?omRL01?l0
0004ooHX00;o00000ooe:P03o`0000KomB/000?o0000ooD/0?l000000_l00002ooD/0003o`000?oe
;@3omBd000?omBd000?o0000oo@]0?l000000_l00002oo@]0003o`000?od;@3om2d000?om2d01?l0
0003oo@]0003o`000?od;@3om2d000Com2d01?l00003oo@]0004o`000?od;@3om2d0oo@]00Co0000
1_oe;0001?l0003omB/0ooD[0?oe:`03o`0000KomRT000Co0000ooHY0?of:@3omRT01?l00005ooHV
0004o`000?og9@3ombD0ooLU00Co00001_og8`001?l0003on240ooPQ0?oh8@04o`0000Gon1d000Co
0000ooTK0?oi6`3onA/01Ol00004ooXH0003o`000?oi703onA`000?o00000_oh8@000ol0003okTP0
o`000009ooooo`05o`000?ooooooooooooooool000000Oooool004Sooooo00?o0000ooooooooool0
4?ooool5o`0000?ombD01?l00005ooLU0003o`000?of9`3o000000;o00000oof9`000ol0003omRP0
ooHX0003ooHX00Co00000oof:@000ol0003omB/0ooD[0003ooD[00;o00001_oe;0001?l0003omBd0
ooD]0?oe;@04o`0000Gom2d000?o0000oo@]0?l000000_l00002oo@]0003o`000?od;@3om2d000?o
m2d000?o0000oo@]0?od;@000ol000000ooe;@3o0000oo@]0004oo@]00Co00000ooe;0000ol0003o
mB`0ooD/0004ooD/00Co00000ooe:P000ol0003omRT0ooHY0003ooHY00Co00000oof9`000ol0003o
mRH0ooHV0003ooHV00Co00000oog90000ol0003omb<0ooLS0004ooLS00Co00000_oh7`000ol0003o
n1d0ooPM0004ooPM00Co00000ooi6P000ol0003onQP0ooXH0003ooXH00?o00001Ooh8@02o`0000[o
oooo00Go0000ooooooooooooooooo`000001ooooo`00BOooool00ol0003oooooooooo`0Aooooo`03
o`000?ob=`3o000000?o00001?og9@001?l0003ombD0ooLU0?og9@04o`0000KomRL000?o0000ooHX
0?l000000_l00002ooHX0003o`000?of:@3omRT000?omRT000?o0000ooD[0?l000000_l00002ooD[
0003o`000?oe;03omB`000?omB`01?l00004ooD/0004o`000?od;@3om2d0oo@]00?o00001_od;@00
1?l0003om2d0oo@]0?od;@04o`0000GomBd000?o0000oo@]0?l000000_l00002ooD/0003o`000?oe
;03omB`000?omB`000?o0000ooD/0?oe;0000ol000000ooe:P3o0000ooDZ0005ooDZ0003o`000?of
:@3o000000;o000000?omRP0o`000?of9`001Oof9`000ol0003omRH0o`000002o`0000;ombD000?o
0000ooLT0?og90000oog90000ol0003omb<0ooLS0003o`000003ooPQ0?l0003on1l000Con1l000?o
0000ooPM0?oh7@000ol000000ooi703o0000ooTJ0005ooTJ0003o`000?oj603o000000;o000000?o
nA`0o`000?oh8@000ooh8@02o`0000gooooo00Co0000oooooooooooo00000Oooool004[ooooo00?o
0000ooooooooool04Oooool01?l0003olSL0oo8g0?l00005ooLU00Co00001?og9@000ol0003omRL0
ooHW0003ooHW00;o00001_of:0001?l0003omRT0ooHY0?of:@04o`0000GomB/000?o0000ooD/0?l0
00000_l00002ooD[0003o`000?oe;03omB`000?omB`01?l00003ooD/0003o`000?od;@3om2d000?o
m2d01?l00004ooD/0004o`000?oe;@3omBd0ooD]00?o00001_oe;0001?l0003omB`0ooD/0?oe;004
o`0000GomBX000Co0000ooDZ0?oe:P3omBX01?l00005ooHX0004o`000?of9`3omRL0ooHW00Co0000
1_og9@001?l0003omb@0ooLT0?og9004o`0000Gon24000Co0000ooPO0?oh7`3on1l01?l00005ooTL
0004o`000?oi6P3onAX0ooTJ00Co00001Ooi70001?l0003on240o`000?l0000@ooooo`03o`000?oo
oooo0000007ooooo001;ooooo`;o00004_ooool4o`000004ooLU0?l0003o0000o`0000?ombD000?o
0000ooLU0?og9@000oog9@000ol0003omRL0o`000002o`0000;omRH000?o0000ooHX0?of:0000oof
:004o`0000ComRT000Co0000ooD[0?oe:`3omB/01?l00005ooD[0003o`000?oe;03o000000;o0000
0_oe:`000ol0003omB`0ooD/0003ooD/0003o`000?od;@3o000000;o00000_oe;0000ol0003omB`0
ooD/0003ooD/00Co00000ooe;0000ol0003omB`0ooD/0003ooD/00Co00000ooe:`000ol0003omBX0
ooDZ0003ooDZ00Co00000oof:@000ol0003omRP0ooHX0003ooHX00Co00001?of9P001?l0003ombD0
ooLU0?og9@06o`0000;omb8000?o0000ooPQ0?oh8@001?oh8@04o`0000?on1d000?o0000ooTL0?oi
70000ooi7004o`0000Con1h000Co0000ooTL0?oi703onA`00ol0000Booooo`03o`000?oooooooooo
007o0000001=ooooo`03o`000?oooooooooo013ooooo00?o0000oo8g0?l000000_l00006ooLU0004
o`000?og9@3ombD0ooLU00Co00001Oof9P000ol0003omRP0o`000002o`0000;omRP000?o0000ooHY
0?of:@000oof:@04o`0000ComBX000Co0000ooD[0?oe:`3omB/00ol00006ooD[0004o`000?oe;03o
mB`0ooD/00Co00001Ooe;0000ol0003omB`0o`000002o`0000;omB/000?o0000ooD/0?oe;0000ooe
;0000ol0003omB`0o`000002o`0000;omB/000?o0000ooD[0?oe:`000ooe:`000ol0003omBX0o`00
0002o`0000;omRT000?o0000ooHY0?of:@000oof:@000ol0003omRP0o`000002o`0000;omRL000?o
0000ooHV0?of9P000oof9P04o`0000?omb<000?o0000ooLR0?og8P000oog8P000ol0003on240ooPQ
0003o`000003ooPO0?l0003on1d000Gon1d000?o0000ooTL0?l000000_l00002ooPP0004o`000?oh
7P3on1h0ooPN00Ko00005_ooool1o`00007ooooo0Ol0000004kooooo00?o0000ooooooooool04?oo
ool01?l0003olSL0oo8g0?ob=`02o`0000?ombD01Ol00004ooLU0004o`000?of9P3omRH0ooHV00Co
00001Oof:0000ol0003omRT0o`000002o`0000;omRT000?o0000ooDZ0?oe:P000ooe:P04o`0000?o
mBX000?o0000ooD[0?oe:`000ooe:`04o`0000ComB/000Co0000ooD/0?oe;03omB`00ol00006ooD[
0004o`000?oe;03omB`0ooD/00Co00001Ooe:`001?l0003omB/0ooD[0?oe:`04o`0000GomRT000Co
0000ooHY0?of:@3omRT01?l00005ooHW0003o`000?of9P3o000000;o00000_og90000ol0003omb<0
ooLS0003ooLS0004o`000?og8P3omb80ooLR00Co00001Ooh7`001?l0003on1d0ooPM0?oh7@04o`00
00Gon2001?l0000Mooooo`;o0000001?ooooo`03o`000?oooooooooo013ooooo2?l00003ooLU0003
o`000?og9@3ombD000?ombD01?l00004ooHV0004o`000?of:03omRP0ooHX00?o00001_of:@000ol0
003omBX0o`000002o`0000;omRT000?o0000ooDZ0?oe:P000ooe:P000ol0003omB/0o`000002o`00
00;omB/000?o0000ooD[0?oe:`000ooe:`04o`0000?omB/000?o0000ooD[0?oe:`000ooe:`04o`00
00ComB/000Co0000ooD[0?oe:`3omB/01Ol00004ooHY0004o`000?of:@3omRT0ooHY00Go00001?of
9`001?l0003omRL0ooHW0?of9`03o`0000Komb@000Co0000ooLS0?og8`3omb<01Ol00004ooPQ0004
o`000?oh7`3on1l0ooPO00Go00001?og8P000ol0003on200o`000002o`00023ooooo0ol00000053o
oooo0_l0000Booooo`05o`000?ob=`3olSL0oo8g0?l000001Oog9@000ol0003ombD0o`000002o`00
00;omb@000?o0000ooHV0?of9P000oof9P04o`0000?omRL000?o0000ooHY0?of:@000oof:@02o`00
00KomRT000Co0000ooDZ0?oe:P3omBX01?l00005ooD[0003o`000?oe:`3o000000;o000000?omBX0
o`000?oe:`001Ooe:`000ol0003omB/0o`000002o`000003ooDZ0?l0003omB/000GomB/01?l00002
ooHY0003o`000?of:@3omRT000ComRT01?l00002ooHW0003o`000?of9`3omRL000ComRL01?l00002
ooLU0003o`000?og903omb@000Comb@01?l00002ooLR0003o`000?oh8@3on24000Con2401?l00003
ooLS0004o`000?og8P3omb80ooLR00Co00007oooool4o`0000?ooooo001Booooo`03o`000?oooooo
oooo013ooooo1Ol00003ooLU00Co00001Oog90000ol0003omRH0o`000002o`0000;ombD000?o0000
ooHW0?of9`000oof9`000ol0003omRT0o`000002o`0000;omRP000?o0000ooHY0?of:@000oof:@04
o`0000ComRT000Co0000ooD[0?oe:`3omB/00ol00005ooDZ0004o`000?oe:`3omB/0ooD[00Co0000
1Ooe:P000ol0003omB/0ooD[0003o`000003ooHY0?l0003omRT000ComRT000?o0000ooHY0?of:@00
0ol000000oof:03o0000ooHW0004ooHW0003o`000?of9`3omRL000?o000000?ombD0o`000?og9@00
1?og9@000ol0003omb@0ooLT0003o`000003ooLS0?l0003omb8000Comb8000?o0000ooPQ0?oh8@00
0ol00002ooLU0004o`000?og8`3omb<0ooLS00Go00007oooool4o`0000Oooooo001Cooooo`03o`00
0?oooooooooo013ooooo00?o0000oo8g0?ob=`001?l00004ooLU0004o`000?og903omb@0ooLT00?o
00001_og9@001?l0003omRL0ooHW0?of9`04o`0000GomRP000?o0000ooHY0?l000000_l000000oof
:03o0000ooHY0005ooHY00Co00000_of:@000ol0003omBX0ooDZ0003ooDZ00Co00001?oe:P001?l0
003omBX0ooDZ0?oe:P04o`0000GomRT000Co0000ooHY0?of:@3omRT01?l00005ooHX0004o`000?of
9`3omRL0ooHW00Co00001Oog9@001?l0003ombD0ooLU0?og9@04o`0000Gomb<000Co0000ooLR0?og
8P3omb801?l00005ooLU00Co00008Oooool3o`0000_ooooo001Dooooo`03o`000?oooooooooo013o
oooo00Go0000oo8g0?ob=`3olSL0o`000005ooLU00Co00000oog90000ol0003ombD0ooLU0003ooLU
00Co00001?of9P001?l0003omRP0ooHX0?of:003o`0000GomRP000?o0000ooHY0?of:@000ol00000
0oof:03o0000ooHY0004ooHY0003o`000?oe:P3o000000;o00000_of:@000ol0003omBX0ooDZ0003
ooDZ00Co00000oof:@000ol0003omRT0ooHY0003ooHY00Co00000oof:0000ol0003omRP0ooHX0003
ooHX00Co00001?of9P001?l0003ombD0ooLU0?og9@05o`0000Comb<000Co0000ooLS0?og8`3omb<0
1Ol00004ooHV0003o`000?og9@3o000000;o00008Oooool4o`0000kooooo001Eooooo`03o`000?oo
oooooooo013ooooo1Ol000001?og9@3o0000o`000?l00002ooLT0003o`000?og903omb@000?omb@0
00?o0000ooLU0?l000000_l00002ooLU0003o`000?of9P3omRH000?omRH01?l00003ooHW0004o`00
0?of:03omRP0ooHX00Co00001Oof:0001?l0003omRT0ooHY0?of:@04o`0000GomRT000?o0000ooDZ
0?l000000_l00002ooHX0003o`000?of:@3omRT000?omRT000?o0000ooHY0?l000000_l00002ooHX
0003o`000?of:03omRP000?omRP000?o0000ooHX0?l000000_l00002ooHV0003o`000?of9P3omRH0
00?omRH01?l00002ooLT0003o`000?og8`3omb<000Comb<01?l00003ooHW0004o`000?of9P3omRH0
ooHV00Co00008?ooool4o`0001;ooooo001Fooooo`;o00004Oooool00ol0003olSH0oo8f0003o`00
00Gomb@000Co0000ooLT0?og903omb@01?l00005ooLU0003o`000?of9P3o000000;o000000?omRH0
o`000?of9`001?of9`04o`0000?omRL000?o0000ooHX0?of:0000oof:004o`0000ComRP000Co0000
ooHY0?of:@3omRT00ol00006ooHX0004o`000?of:@3omRT0ooHY00Co00001Oof:0001?l0003omRP0
ooHX0?of:003o`0000KomRH000?o0000ooHV0?l000000_l000000oog903o0000ooLT0004ooLT0003
o`000?og8`3omb<000?o00000_of9`001?l0003omRL0ooHW0?of9`05o`00023ooooo1?l0000Foooo
o`00F?ooool00ol0003oooooooooo`0?ooooo`03o`000?ob=P3olSH000;olSH000Co0000ooLT0?og
903omb@01Ol00004ooLS0004o`000?og9@3ombD0ooLU00Co00001?of9P000ol0003omRL0o`000002
o`0000;omRH000?o0000ooHW0?of9`000oof9`000ol0003omRP0o`000002o`0000;omRL000?o0000
ooHX0?of:0000oof:004o`0000?omRP000?o0000ooHX0?of:0000oof:004o`0000ComRL000Co0000
ooHX0?of:03omRP01Ol00003ooHV0004o`000?of9P3omRH0ooHV00Co00001Oog90001?l0003omb@0
ooLT0?og9004o`0000GomRL01?l0000Qooooo`Co00006_ooool005Wooooo00?o0000ooooooooool0
3oooool8o`0000?omb<000?o0000ooLS0?og8`000oog8`04o`0000Comb@000?o0000ooHV0?of9P00
0ol00006ooHV0004o`000?of9`3omRL0ooHW00Co00001Oof9`000ol0003omRP0o`000002o`0000;o
mRL000?o0000ooHX0?of:0000oof:0000ol0003omRP0o`000002o`0000;omRL000?o0000ooHW0?of
9`000oof9`04o`0000;omRH000?o0000ooHV0?of9P000oof9P04o`0000?omb@000?o0000ooLT0?og
90000oog9004o`0000ComRP000?o0000ooHW0?l000000_l0000Qooooo`Co00007_ooool005[ooooo
00?o0000ooooooooool04?ooool01Ol0003olSH0oo8f0?ob=P3o000000Gomb<000?o0000ooLS0?l0
00000_l00002ooLR0003o`000?og903omb@000?omb@00ol00003ooLT0003o`000?of9P3omRH000?o
mRH01?l00004ooHV0004o`000?of9`3omRL0ooHW00Co00001Oof9`001?l0003omRP0ooHX0?of:004
o`0000GomRL000?o0000ooHW0?l000000_l000000oof9@3o0000ooHV0004ooHV0003o`000?of9P3o
000000;o00000_og9@000ol0003omb@0ooLT0003ooLT0003o`000?og903o000000;o00000oof:000
1?l0003omRP0ooHX0?of:003o`00023ooooo1?l0000Rooooo`00Foooool2o`00017ooooo1Ol00003
ooLS00Co00001Oog8P000ol0003omb@0o`000002o`000003ooLS0?l0003omb@000Comb@000?o0000
ooHV0?l000000_l00002ooLU0003o`000?of9P3omRH000?omRH01?l00004ooHV0004o`000?of9`3o
mRL0ooHW00Go00001?of9P001?l0003omRL0ooHW0?of9`03o`0000GomRD000Co0000ooHV0?of9P3o
mRH01?l00005ooLU0004o`000?og903omb@0ooLT00?o00001_of:004o`00023ooooo0ol0000Voooo
o`00GOooool00ol0003oooooooooo`0?ooooo`03o`000?ob=@3olSD000Co00001?og8`001?l0003o
mb80ooLR0?og8P03o`0000Gomb<000Co0000ooLT0?og903omb@01?l00005ooLU0003o`000?of9P3o
000000;o00000_og9@000ol0003omRH0ooHV0003ooHV00Co00000_og9@000ol0003omRH0ooHV0004
ooHV00Co00000oog9@001?l0003omRD0ooHU0?of9@05o`0000Comb@000Co0000ooLU0?og9@3ombD0
1Ol00003ooHX0003o`000?of:03omRP000?o00008?ooool4o`0002Wooooo001Nooooo`03o`000?oo
oooooooo00oooooo00Go0000oo8e0?ob=@3olSD0o`000005ooLS00Co00000ooh8@000ol0003omb<0
ooLS0002ooLS00Co00001?og8`001?l0003ombD0ooLU0?og9@04o`0000GombD000?o0000ooHV0?l0
00000_l00002ooLT0003o`000?og9@3ombD000;ombD000?o0000ooHV0?of9P000ol000000oog903o
0000ooLU0004ooLU00Co00000oog90000ol0003omb@0ooLT0003ooLT00Co00000oof:0001?l0003o
mRP0ooHX0?of:004o`0001oooooo1?l0000]ooooo`00Goooool00ol0003oooooooooo`0?ooooo`Go
000000Comb<0o`000?l0003o00000_oh8@000ol0003on240ooPQ0003ooPQ0004o`000?og8`3o0000
o`0000;omb4000?o0000ooLS0?og8`000oog8`04o`0000Comb<000Co0000ooLU0?og9@3ombD00ol0
0006ooLT0003o`000?og9@3ombD000Co00001Oog90000ol0003ombD0o`000002o`0000;omb@000?o
0000ooLT0?og90000oog90000ol0003omb@0o`000002o`0000;omRP000Co0000ooHX0?of:03omRP0
1Ol0000Oooooo`Co0000<Oooool0063ooooo0_l0000Aooooo`03o`000?oc=03o000000;o00001Ooh
8@001?l0003on240ooPQ0?oh8@03o`0000Gomb4000?o0000ooLS0?l000000_l00002ooLR0003o`00
0?og8`3omb<000?omb<01?l00003ooLS0003o`000?og903omb@000?omb@00ol00004ooLS0004o`00
0?og903omb@0ooLT00Co00001Oog90001?l0003omb@0ooLT0?og9003o`0000GomRP01?l0000Poooo
o`Co0000=Oooool006;ooooo00?o0000ooooooooool03oooool5o`0000?on2401Ol00003ooPO0004
o`000?og8@3omb40ooLQ00Co00001Oog8P000ol0003omb<0o`000002o`0000;omb8000?o0000ooLS
0?og8`000oog8`000ol0003omb@0o`000002o`000003ooLR0?l0003omb<000Comb<01?l00004ooLS
0004o`000?og903omb@0ooLT00Go00000oof:0000ol0003omRP0o`000002o`00023ooooo1?l0000i
ooooo`00Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oc<`3olc<000Co00000ooh80000ol0
003on1l0ooPO0002ooPO00Co00001?oh80001?l0003omb80ooLR0?og8P04o`0000Gomb8000Co0000
ooLS0?og8`3omb<00ol00005ooLR0003o`000?og8`3o000000;o00000_og8P000ol0003omb<0ooLS
0003ooLS00Co00000oof9`001?l0003omRP0ooHX0?of:003o`0001oooooo1?l0000mooooo`00I?oo
ool00ol0003oooooooooo`0?ooooo`05o`000?oc<`3olc<0oo<c0?l000001Ooh80001?l0003on1l0
o`000?l00002ooPN0003o`000?oh803on20000?on2001?l00004ooPP0004o`000?og8P3omb80ooLR
00Go00000ooh8@001?l0003omb80ooLR0?og8P04o`0000Gomb8000?o0000ooLS0?l000000_l00002
ooHW0004o`000?of9`3omRL0ooHW00Go00007oooool3o`00047ooooo001Uooooo`03o`000?oooooo
oooo00oooooo1Ol00003ooPP00?o00001Ooh7P000ol0003on200o`000002o`0000;on1h000?o0000
ooPP0?oh80000ooh8004o`0000;on20000?o0000ooPQ0?oh8@000ooh8@04o`0000Con24000Co0000
ooLR0?og8P3omb800ol00005ooHW00Co00008?ooool4o`0004Cooooo001Vooooo`;o00004Oooool0
0ol0003olc40o`000003o`0000?on1h000Co0000ooPN0?oh7P3on1h01?l00005ooPN0003o`000?oh
803o000000;o000000?on1h0o`000?oh80001?oh80000ol0003on240o`000002o`0000;on1l000?o
0000ooPQ0?oh8@000ooh8@04o`0000?omRH000?o0000ooHW0?l000000_l0000Pooooo`Co0000B?oo
ool006Sooooo00?o0000ooooooooool03oooool5o`0000;on1h01Ol00004ooTL0004o`000?oh7P3o
n1h0ooPN00Co00001?oh7P001?l0003on200ooPP0?oh8004o`0000Gon1l000?o0000ooPQ0?l00000
0_l00002ooLU0004o`000?of9P3omRH0ooHV00?o00007oooool4o`0004cooooo001Yooooo`03o`00
0?oooooooooo00oooooo00?o0000oo@`0?od<0000ol00003ooTM0003o`000?oi703onA`000?onA`0
1?l00004ooTL0003o`000?oh7P3on1h000Go00001?oh7P001?l0003on1l0ooPO0?oh7`05o`0000;o
mbD01Ol0000Nooooo`Co0000D?ooool006[ooooo00?o0000ooooooooool03oooool01Ol0003om300
oo@`0?od<03o000000ConAd000?o0000ooTL0?l000000_l00002ooTJ0003o`000?oi703onA`000?o
nA`00ol00004ooTL0004o`000?oh7P3on1h0ooPN00Go00001?og9003o`0001oooooo1?l0001Doooo
o`00Joooool2o`00013ooooo1Ol00002ooTM00Co00001Ooi6P000ol0003onA`0o`000002o`000003
ooTJ0?l0003onA`000ConA`01?l00004ooLR0003o`000?og903o000000;o00007_ooool4o`0005So
oooo001]ooooo`03o`000?oooooooooo00oooooo00?o0000oo@^0?l000000_l00004ooTK0004o`00
0?oi6P3onAX0ooTJ00Co00001?oi6P000ol0003onA`0o`000002o`0000?on24000Co0000ooLR0?og
8P3omb800ol0000Nooooo`?o0000G?ooool006kooooo00?o0000ooooooooool03oooool4o`0000?o
nA/01Ol00004ooXI0003o`000?oi6P3onAX000Co00001Ooh8@04o`0001gooooo1?l0001Oooooo`00
Koooool00ol0003oooooooooo`0?ooooo`03o`000?od;@3o000000?o00000ooj6@000ol0003onQT0
ooXI0003ooXI00?o00001?oh7`000ol0003on240o`000002o`0001gooooo1?l0001Sooooo`00L?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?od;@3om2d0o`0000GonQT000?o0000ooXI0?l00000
0_l00002ooTM0004o`000?oh7`3on1l0ooPO00?o00007?ooool4o`0006Oooooo001aooooo`;o0000
3_ooool00ol0003oooooo`000003o`0000?onQT01Ol00002ooTM00Go00006oooool4o`0006_ooooo
001cooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo1Ol00003ooPM00Co0000
7?ooool4o`0006oooooo001dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Ooo
ool4o`0001cooooo1?l0001cooooo`00MOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo02;ooooo0ol0001gooooo`00M_ooool2o`0000Wooooo00?o0000ooooooooool07_ooool4o`00
07[ooooo001hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool4o`0007ko
oooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`0008;ooooo
001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`0008Kooooo001k
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`0008[ooooo001loooo
o`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000S_ooool007kooooo00Co0000oooooooo
oooo00002Oooool3o`0009;ooooo001oooooo`03o`000?oooooo000000Gooooo1?l0002Eooooo`00
P?ooool2o`000003ooooool0003o000000;o0000VOooool0087ooooo0_l0002Mooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00d_ooool3o`0004_ooooo003Cooooo`03o`000?oo
oooooooo04[ooooo001Qooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooo
oooo00;ooooo0ol00008ooooo`?o00000oooool3o`0000Cooooo0ol00002ooooo`?o000000?ooooo
o`000?l000000_ooool2o`0000Sooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_oo
ool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l00002ooooo`Go00000ooo
ool2o`0000Cooooo00?o0000ooooooooool0BOooool0067ooooo00?o0000ooooool000000_ooool0
1?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04
o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool0BOooool0067ooooo00?o0000ooooool000000oooool3
o`0000?ooooo00?o0000ooooool000000_ooool5o`0000Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`00
00;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooo`00001:ooooo`00H?ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool0
1ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000So
oooo0ol00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0_ooool01_l0003oooooooooool0003oooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000004[ooooo001Pooooo`05o`000?oooooo0000oooo
ool000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00002Oooool00ol0
003oooooooooo`02ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l00002oooo
o`Co00002_ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4
o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0
003o000004Wooooo001Pooooo`05o`000?oooooo0000ooooool000006_ooool01?l0003ooooooooo
ool0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo053ooooo001Pooooo`Ko00006?ooool5o`0001Cooooo00?o
0000ooooooooool02?ooool5o`0000Sooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo053ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.095562, 0.0487945, \
0.00365211, 0.00365211}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.07261 .22845 -18 -8.83299 ]
[.07261 .22845 0 .16701 ]
[.26329 .15343 -11.4506 -9 ]
[.26329 .15343 .54943 0 ]
[.46894 .07256 -5.33495 -9 ]
[.46894 .07256 .66505 0 ]
[.76362 .09117 0 -6.16757 ]
[.76362 .09117 12 2.83243 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93772 .35778 0 -5.91556 ]
[.93772 .35778 6 3.08444 ]
[.02412 .26509 -6 -2.7423 ]
[.02412 .26509 0 6.2577 ]
[.01324 .33326 -6 -2.79997 ]
[.01324 .33326 0 6.20003 ]
[.00187 .40451 -6 -2.86051 ]
[.00187 .40451 0 6.13949 ]
[-0.01002 .47907 -6 -2.92415 ]
[-0.01002 .47907 0 6.07585 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.08206 .23755 m
.08679 .24211 L
s
[(-10)] .07261 .22845 1 .96289 Mshowa
.27211 .16314 m
.27652 .16799 L
s
[(-5)] .26329 .15343 .90843 1 Mshowa
.477 .08291 m
.48103 .08809 L
s
[(0)] .46894 .07256 .77832 1 Mshowa
.125 Mabswid
.11896 .22311 m
.12176 .22587 L
s
.1564 .20844 m
.15917 .21125 L
s
.1944 .19357 m
.19713 .19641 L
s
.23297 .17847 m
.23565 .18134 L
s
.31185 .14758 m
.31445 .15053 L
s
.35219 .13178 m
.35475 .13477 L
s
.39315 .11574 m
.39567 .11877 L
s
.43475 .09945 m
.43722 .10252 L
s
.51991 .06611 m
.52228 .06925 L
s
.5635 .04904 m
.56582 .05222 L
s
.60779 .03169 m
.61005 .03492 L
s
.6528 .01407 m
.655 .01734 L
s
.04569 .2518 m
.04856 .25449 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75132 .09573 m
.74517 .09801 L
s
[(-5)] .76362 .09117 -1 .37057 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9252 .36171 m
.91895 .36368 L
s
[(5)] .93772 .35778 -1 .31457 Mshowa
.125 Mabswid
.77092 .12571 m
.76722 .12706 L
s
.78997 .15485 m
.78627 .15618 L
s
.8085 .1832 m
.80479 .18451 L
s
.82653 .21078 m
.82281 .21206 L
s
.86116 .26374 m
.85742 .26499 L
s
.87779 .28919 m
.87406 .29043 L
s
.894 .31399 m
.89026 .3152 L
s
.9098 .33815 m
.90605 .33935 L
s
.73115 .06488 m
.72747 .06627 L
s
.71038 .03311 m
.70671 .03452 L
s
.689 .0004 m
.68533 .00183 L
s
.94023 .38469 m
.93647 .38586 L
s
.95488 .40711 m
.95111 .40826 L
s
.96918 .42898 m
.96541 .43011 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26032 m
.04245 .25793 L
s
[(0)] .02412 .26509 1 -0.3906 Mshowa
.02552 .32862 m
.03165 .3263 L
s
[(1)] .01324 .33326 1 -0.37779 Mshowa
.0142 .40002 m
.02037 .39777 L
s
[(2)] .00187 .40451 1 -0.36433 Mshowa
.00236 .47473 m
.00855 .47256 L
s
[(3)] -0.01002 .47907 1 -0.35019 Mshowa
.125 Mabswid
.03421 .27374 m
.03788 .27232 L
s
.03207 .28728 m
.03574 .28586 L
s
.0299 .30094 m
.03358 .29953 L
s
.02772 .31472 m
.0314 .31332 L
s
.02329 .34265 m
.02698 .34126 L
s
.02105 .3568 m
.02474 .35542 L
s
.01879 .37108 m
.02248 .36971 L
s
.0165 .38548 m
.0202 .38413 L
s
.01188 .41469 m
.01558 .41335 L
s
.00953 .42949 m
.01324 .42816 L
s
.00716 .44443 m
.01087 .44311 L
s
.00477 .45951 m
.00848 .4582 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.846 .566 0 r
.38878 .76524 .39978 .75648 .41652 .7692 .40574 .77425 Metetra
.9 .391 0 r
.40574 .77425 .41652 .7692 .43365 .77743 .42307 .77894 Metetra
.937 .255 0 r
.42307 .77894 .43365 .77743 .4511 .78178 .4407 .77997 Metetra
.961 .164 0 r
.4407 .77997 .4511 .78178 .46881 .7829 .45855 .778 Metetra
.973 .115 0 r
.45855 .778 .46881 .7829 .48671 .78137 .47658 .77361 Metetra
.976 .102 0 r
.47658 .77361 .48671 .78137 .50478 .77773 .49475 .76738 Metetra
.973 .116 0 r
.49475 .76738 .50478 .77773 .52298 .77251 .51303 .75982 Metetra
.964 .149 0 r
.51303 .75982 .52298 .77251 .5413 .76615 .5314 .75139 Metetra
.953 .193 0 r
.5314 .75139 .5413 .76615 .55971 .75907 .54986 .74249 Metetra
.941 .242 0 r
.54986 .74249 .55971 .75907 .57822 .75162 .5684 .73347 Metetra
.928 .291 0 r
.5684 .73347 .57822 .75162 .59682 .74409 .58703 .72463 Metetra
.916 .334 0 r
.58703 .72463 .59682 .74409 .61553 .73675 .60575 .71623 Metetra
.906 .371 0 r
.60575 .71623 .61553 .73675 .63436 .72979 .62458 .70845 Metetra
.898 .398 0 r
.62458 .70845 .63436 .72979 .65331 .72336 .64354 .70145 Metetra
.893 .415 0 r
.64354 .70145 .65331 .72336 .6724 .71756 .66265 .69532 Metetra
.891 .42 0 r
.66265 .69532 .6724 .71756 .69165 .71245 .68191 .69011 Metetra
.893 .415 0 r
.68191 .69011 .69165 .71245 .71107 .70802 .70136 .68584 Metetra
.898 .398 0 r
.70136 .68584 .71107 .70802 .73066 .70424 .721 .68246 Metetra
.906 .371 0 r
.721 .68246 .73066 .70424 .75045 .70101 .74086 .67988 Metetra
.916 .334 0 r
.74086 .67988 .75045 .70101 .77043 .69818 .76092 .67795 Metetra
.928 .291 0 r
.76092 .67795 .77043 .69818 .79059 .69555 .7812 .67649 Metetra
.941 .242 0 r
.7812 .67649 .79059 .69555 .81092 .69287 .80169 .67524 Metetra
.953 .193 0 r
.80169 .67524 .81092 .69287 .83139 .68982 .82236 .6739 Metetra
.964 .149 0 r
.82236 .6739 .83139 .68982 .85196 .68603 .84319 .67211 Metetra
.973 .116 0 r
.84319 .67211 .85196 .68603 .87259 .68108 .86413 .66944 Metetra
.976 .102 0 r
.86413 .66944 .87259 .68108 .8932 .67446 .88511 .66539 Metetra
.973 .115 0 r
.88511 .66539 .8932 .67446 .9137 .66564 .90605 .65942 Metetra
.961 .164 0 r
.90605 .65942 .9137 .66564 .93398 .654 .92685 .65091 Metetra
.937 .255 0 r
.92685 .65091 .93398 .654 .95391 .63888 .94738 .63919 Metetra
.9 .391 0 r
.94738 .63919 .95391 .63888 .97333 .61961 .96748 .62355 Metetra
.846 .566 0 r
.96748 .62355 .97333 .61961 .99207 .59546 .98699 .60324 Metetra
.9 .391 0 r
.37773 .76946 .38878 .76524 .40574 .77425 .39491 .77494 Metetra
.939 .247 0 r
.39491 .77494 .40574 .77425 .42307 .77894 .41244 .77628 Metetra
.963 .153 0 r
.41244 .77628 .42307 .77894 .4407 .77997 .43023 .77418 Metetra
.974 .108 0 r
.43023 .77418 .4407 .77997 .45855 .778 .44822 .7693 Metetra
.975 .105 0 r
.44822 .7693 .45855 .778 .47658 .77361 .46637 .76225 Metetra
.968 .133 0 r
.46637 .76225 .47658 .77361 .49475 .76738 .48464 .7536 Metetra
.956 .183 0 r
.48464 .7536 .49475 .76738 .51303 .75982 .50299 .74387 Metetra
.94 .246 0 r
.50299 .74387 .51303 .75982 .5314 .75139 .52142 .73351 Metetra
.921 .314 0 r
.52142 .73351 .5314 .75139 .54986 .74249 .53992 .72292 Metetra
.902 .381 0 r
.53992 .72292 .54986 .74249 .5684 .73347 .55849 .71246 Metetra
.884 .443 0 r
.55849 .71246 .5684 .73347 .58703 .72463 .57713 .70241 Metetra
.868 .496 0 r
.57713 .70241 .58703 .72463 .60575 .71623 .59586 .69303 Metetra
.855 .538 0 r
.59586 .69303 .60575 .71623 .62458 .70845 .61469 .68449 Metetra
.845 .569 0 r
.61469 .68449 .62458 .70845 .64354 .70145 .63365 .67696 Metetra
.838 .587 0 r
.63365 .67696 .64354 .70145 .66265 .69532 .65275 .67051 Metetra
.836 .593 0 r
.65275 .67051 .66265 .69532 .68191 .69011 .67202 .66521 Metetra
.838 .587 0 r
.67202 .66521 .68191 .69011 .70136 .68584 .69148 .66107 Metetra
.845 .569 0 r
.69148 .66107 .70136 .68584 .721 .68246 .71115 .65803 Metetra
.855 .538 0 r
.71115 .65803 .721 .68246 .74086 .67988 .73105 .65603 Metetra
.868 .496 0 r
.73105 .65603 .74086 .67988 .76092 .67795 .75118 .65491 Metetra
.884 .443 0 r
.75118 .65491 .76092 .67795 .7812 .67649 .77155 .6545 Metetra
.902 .381 0 r
.77155 .6545 .7812 .67649 .80169 .67524 .79216 .65455 Metetra
.921 .314 0 r
.79216 .65455 .80169 .67524 .82236 .6739 .813 .65477 Metetra
.94 .246 0 r
.813 .65477 .82236 .6739 .84319 .67211 .83404 .6548 Metetra
.956 .183 0 r
.83404 .6548 .84319 .67211 .86413 .66944 .85524 .65421 Metetra
.968 .133 0 r
.85524 .65421 .86413 .66944 .88511 .66539 .87654 .65253 Metetra
.975 .105 0 r
.87654 .65253 .88511 .66539 .90605 .65942 .89787 .6492 Metetra
.974 .108 0 r
.89787 .6492 .90605 .65942 .92685 .65091 .91912 .64361 Metetra
.963 .153 0 r
.91912 .64361 .92685 .65091 .94738 .63919 .94019 .63507 Metetra
.939 .247 0 r
.94019 .63507 .94738 .63919 .96748 .62355 .96091 .62286 Metetra
.9 .391 0 r
.96091 .62286 .96748 .62355 .98699 .60324 .98112 .6062 Metetra
.937 .255 0 r
.36664 .76977 .37773 .76946 .39491 .77494 .38404 .77191 Metetra
.963 .153 0 r
.38404 .77191 .39491 .77494 .41244 .77628 .40175 .77011 Metetra
.975 .107 0 r
.40175 .77011 .41244 .77628 .43023 .77418 .4197 .76509 Metetra
.974 .108 0 r
.4197 .76509 .43023 .77418 .44822 .7693 .43784 .7575 Metetra
.965 .146 0 r
.43784 .7575 .44822 .7693 .46637 .76225 .4561 .74799 Metetra
.949 .211 0 r
.4561 .74799 .46637 .76225 .48464 .7536 .47446 .7371 Metetra
.928 .29 0 r
.47446 .7371 .48464 .7536 .50299 .74387 .49289 .72537 Metetra
.904 .376 0 r
.49289 .72537 .50299 .74387 .52142 .73351 .51138 .71324 Metetra
.879 .46 0 r
.51138 .71324 .52142 .73351 .53992 .72292 .52991 .70112 Metetra
.855 .538 0 r
.52991 .70112 .53992 .72292 .55849 .71246 .5485 .68933 Metetra
.832 .606 0 r
.5485 .68933 .55849 .71246 .57713 .70241 .56715 .67818 Metetra
.812 .662 0 r
.56715 .67818 .57713 .70241 .59586 .69303 .58588 .66789 Metetra
.795 .705 0 r
.58588 .66789 .59586 .69303 .61469 .68449 .60471 .65866 Metetra
.783 .736 0 r
.60471 .65866 .61469 .68449 .63365 .67696 .62366 .65063 Metetra
.776 .754 0 r
.62366 .65063 .63365 .67696 .65275 .67051 .64276 .64389 Metetra
.773 .76 0 r
.64276 .64389 .65275 .67051 .67202 .66521 .66202 .63849 Metetra
.776 .754 0 r
.66202 .63849 .67202 .66521 .69148 .66107 .68149 .63445 Metetra
.783 .736 0 r
.68149 .63445 .69148 .66107 .71115 .65803 .70117 .63171 Metetra
.795 .705 0 r
.70117 .63171 .71115 .65803 .73105 .65603 .72108 .63021 Metetra
.812 .662 0 r
.72108 .63021 .73105 .65603 .75118 .65491 .74126 .62981 Metetra
.832 .606 0 r
.74126 .62981 .75118 .65491 .77155 .6545 .7617 .63034 Metetra
.855 .538 0 r
.7617 .63034 .77155 .6545 .79216 .65455 .78241 .63155 Metetra
.879 .46 0 r
.78241 .63155 .79216 .65455 .813 .65477 .80338 .63317 Metetra
.904 .376 0 r
.80338 .63317 .813 .65477 .83404 .6548 .82459 .63484 Metetra
.928 .29 0 r
.82459 .63484 .83404 .6548 .85524 .65421 .846 .63616 Metetra
.949 .211 0 r
.846 .63616 .85524 .65421 .87654 .65253 .86758 .63663 Metetra
.965 .146 0 r
.86758 .63663 .87654 .65253 .89787 .6492 .88924 .63573 Metetra
.974 .108 0 r
.88924 .63573 .89787 .6492 .91912 .64361 .9109 .63282 Metetra
.975 .107 0 r
.9109 .63282 .91912 .64361 .94019 .63507 .93244 .62723 Metetra
.963 .153 0 r
.93244 .62723 .94019 .63507 .96091 .62286 .95372 .61822 Metetra
.937 .255 0 r
.95372 .61822 .96091 .62286 .98112 .6062 .97456 .60498 Metetra
.961 .164 0 r
.35552 .76677 .36664 .76977 .38404 .77191 .37312 .7658 Metetra
.974 .108 0 r
.37312 .7658 .38404 .77191 .40175 .77011 .39102 .76109 Metetra
.974 .108 0 r
.39102 .76109 .40175 .77011 .4197 .76509 .40913 .75336 Metetra
.964 .151 0 r
.40913 .75336 .4197 .76509 .43784 .7575 .42741 .74328 Metetra
.945 .226 0 r
.42741 .74328 .43784 .7575 .4561 .74799 .44578 .7315 Metetra
.92 .319 0 r
.44578 .7315 .4561 .74799 .47446 .7371 .46424 .71857 Metetra
.891 .42 0 r
.46424 .71857 .47446 .7371 .49289 .72537 .48274 .70502 Metetra
.861 .52 0 r
.48274 .70502 .49289 .72537 .51138 .71324 .50128 .69128 Metetra
.83 .612 0 r
.50128 .69128 .51138 .71324 .52991 .70112 .51985 .67775 Metetra
.8 .693 0 r
.51985 .67775 .52991 .70112 .5485 .68933 .53846 .66476 Metetra
.773 .76 0 r
.53846 .66476 .5485 .68933 .56715 .67818 .55713 .6526 Metetra
.685 .749 0 r
.55713 .6526 .56715 .67818 .58588 .66789 .57586 .64149 Metetra
.607 .73 0 r
.57586 .64149 .58588 .66789 .60471 .65866 .59468 .63163 Metetra
.551 .716 0 r
.59468 .63163 .60471 .65866 .62366 .65063 .61362 .62314 Metetra
.517 .707 0 r
.61362 .62314 .62366 .65063 .64276 .64389 .6327 .61612 Metetra
.506 .704 0 r
.6327 .61612 .64276 .64389 .66202 .63849 .65196 .61062 Metetra
.517 .707 0 r
.65196 .61062 .66202 .63849 .68149 .63445 .67141 .60665 Metetra
.551 .716 0 r
.67141 .60665 .68149 .63445 .70117 .63171 .69109 .60417 Metetra
.607 .73 0 r
.69109 .60417 .70117 .63171 .72108 .63021 .71102 .60311 Metetra
.685 .749 0 r
.71102 .60311 .72108 .63021 .74126 .62981 .73122 .60334 Metetra
.773 .76 0 r
.73122 .60334 .74126 .62981 .7617 .63034 .75171 .60469 Metetra
.8 .693 0 r
.75171 .60469 .7617 .63034 .78241 .63155 .77249 .60694 Metetra
.83 .612 0 r
.77249 .60694 .78241 .63155 .80338 .63317 .79356 .6098 Metetra
.861 .52 0 r
.79356 .6098 .80338 .63317 .82459 .63484 .81491 .61295 Metetra
.891 .42 0 r
.81491 .61295 .82459 .63484 .846 .63616 .83651 .61597 Metetra
.92 .319 0 r
.83651 .61597 .846 .63616 .86758 .63663 .85832 .61839 Metetra
.945 .226 0 r
.85832 .61839 .86758 .63663 .88924 .63573 .88027 .61969 Metetra
.964 .151 0 r
.88027 .61969 .88924 .63573 .9109 .63282 .90228 .61923 Metetra
.974 .108 0 r
.90228 .61923 .9109 .63282 .93244 .62723 .92423 .61634 Metetra
.974 .108 0 r
.92423 .61634 .93244 .62723 .95372 .61822 .94601 .61027 Metetra
.961 .164 0 r
.94601 .61027 .95372 .61822 .97456 .60498 .96743 .60021 Metetra
.973 .115 0 r
.34435 .76104 .35552 .76677 .37312 .7658 .36216 .7572 Metetra
.975 .105 0 r
.36216 .7572 .37312 .7658 .39102 .76109 .38024 .74981 Metetra
.965 .146 0 r
.38024 .74981 .39102 .76109 .40913 .75336 .39851 .7396 Metetra
.945 .226 0 r
.39851 .7396 .40913 .75336 .42741 .74328 .41692 .72725 Metetra
.917 .329 0 r
.41692 .72725 .42741 .74328 .44578 .7315 .43542 .71341 Metetra
.884 .443 0 r
.43542 .71341 .44578 .7315 .46424 .71857 .45396 .69862 Metetra
.849 .556 0 r
.45396 .69862 .46424 .71857 .48274 .70502 .47254 .68341 Metetra
.812 .662 0 r
.47254 .68341 .48274 .70502 .50128 .69128 .49113 .66822 Metetra
.776 .754 0 r
.49113 .66822 .50128 .69128 .51985 .67775 .50975 .65342 Metetra
.652 .741 0 r
.50975 .65342 .51985 .67775 .53846 .66476 .52838 .63935 Metetra
.528 .71 0 r
.52838 .63935 .53846 .66476 .55713 .6526 .54706 .62628 Metetra
.429 .683 0 r
.54706 .62628 .55713 .6526 .57586 .64149 .5658 .61443 Metetra
.353 .662 0 r
.5658 .61443 .57586 .64149 .59468 .63163 .58461 .60399 Metetra
.299 .646 0 r
.58461 .60399 .59468 .63163 .61362 .62314 .60354 .59509 Metetra
.268 .636 0 r
.60354 .59509 .61362 .62314 .6327 .61612 .62261 .58781 Metetra
.257 .632 0 r
.62261 .58781 .6327 .61612 .65196 .61062 .64185 .5822 Metetra
.268 .636 0 r
.64185 .5822 .65196 .61062 .67141 .60665 .66129 .57829 Metetra
.299 .646 0 r
.66129 .57829 .67141 .60665 .69109 .60417 .68096 .57602 Metetra
.353 .662 0 r
.68096 .57602 .69109 .60417 .71102 .60311 .7009 .57534 Metetra
.429 .683 0 r
.7009 .57534 .71102 .60311 .73122 .60334 .72111 .57611 Metetra
.528 .71 0 r
.72111 .57611 .73122 .60334 .75171 .60469 .74163 .57819 Metetra
.652 .741 0 r
.74163 .57819 .75171 .60469 .77249 .60694 .76246 .58134 Metetra
.776 .754 0 r
.76246 .58134 .77249 .60694 .79356 .6098 .78361 .5853 Metetra
.812 .662 0 r
.78361 .5853 .79356 .6098 .81491 .61295 .80508 .58975 Metetra
.849 .556 0 r
.80508 .58975 .81491 .61295 .83651 .61597 .82682 .59429 Metetra
.884 .443 0 r
.82682 .59429 .83651 .61597 .85832 .61839 .84883 .59846 Metetra
.917 .329 0 r
.84883 .59846 .85832 .61839 .88027 .61969 .87102 .60173 Metetra
.945 .226 0 r
.87102 .60173 .88027 .61969 .90228 .61923 .89333 .60348 Metetra
.965 .146 0 r
.89333 .60348 .90228 .61923 .92423 .61634 .91566 .60304 Metetra
.975 .105 0 r
.91566 .60304 .92423 .61634 .94601 .61027 .93787 .59966 Metetra
.973 .115 0 r
.93787 .59966 .94601 .61027 .96743 .60021 .9598 .5925 Metetra
.976 .102 0 r
.33314 .75312 .34435 .76104 .36216 .7572 .35115 .74666 Metetra
.968 .133 0 r
.35115 .74666 .36216 .7572 .38024 .74981 .36941 .73683 Metetra
.949 .211 0 r
.36941 .73683 .38024 .74981 .39851 .7396 .38784 .72437 Metetra
.92 .319 0 r
.38784 .72437 .39851 .7396 .41692 .72725 .40639 .70997 Metetra
.884 .443 0 r
.40639 .70997 .41692 .72725 .43542 .71341 .425 .69426 Metetra
.845 .569 0 r
.425 .69426 .43542 .71341 .45396 .69862 .44364 .67781 Metetra
.803 .687 0 r
.44364 .67781 .45396 .69862 .47254 .68341 .46229 .66112 Metetra
.73 .76 0 r
.46229 .66112 .47254 .68341 .49113 .66822 .48095 .64461 Metetra
.562 .719 0 r
.48095 .64461 .49113 .66822 .50975 .65342 .4996 .62868 Metetra
.418 .68 0 r
.4996 .62868 .50975 .65342 .52838 .63935 .51827 .61363 Metetra
.299 .646 0 r
.51827 .61363 .52838 .63935 .54706 .62628 .53696 .59975 Metetra
.206 .616 0 r
.53696 .59975 .54706 .62628 .5658 .61443 .55571 .58724 Metetra
.136 .592 0 r
.55571 .58724 .5658 .61443 .58461 .60399 .57452 .57628 Metetra
.088 .574 0 r
.57452 .57628 .58461 .60399 .60354 .59509 .59344 .56699 Metetra
.061 .563 0 r
.59344 .56699 .60354 .59509 .62261 .58781 .6125 .55947 Metetra
.051 .56 0 r
.6125 .55947 .62261 .58781 .64185 .5822 .63172 .55377 Metetra
.061 .563 0 r
.63172 .55377 .64185 .5822 .66129 .57829 .65115 .54989 Metetra
.088 .574 0 r
.65115 .54989 .66129 .57829 .68096 .57602 .67081 .5478 Metetra
.136 .592 0 r
.67081 .5478 .68096 .57602 .7009 .57534 .69074 .54743 Metetra
.206 .616 0 r
.69074 .54743 .7009 .57534 .72111 .57611 .71096 .54867 Metetra
.299 .646 0 r
.71096 .54867 .72111 .57611 .74163 .57819 .7315 .55137 Metetra
.418 .68 0 r
.7315 .55137 .74163 .57819 .76246 .58134 .75237 .55531 Metetra
.562 .719 0 r
.75237 .55531 .76246 .58134 .78361 .5853 .77358 .56023 Metetra
.73 .76 0 r
.77358 .56023 .78361 .5853 .80508 .58975 .79513 .56583 Metetra
.803 .687 0 r
.79513 .56583 .80508 .58975 .82682 .59429 .81701 .5717 Metetra
.845 .569 0 r
.81701 .5717 .82682 .59429 .84883 .59846 .83917 .57741 Metetra
.884 .443 0 r
.83917 .57741 .84883 .59846 .87102 .60173 .86157 .58244 Metetra
.92 .319 0 r
.86157 .58244 .87102 .60173 .89333 .60348 .88415 .58616 Metetra
.949 .211 0 r
.88415 .58616 .89333 .60348 .91566 .60304 .90679 .58792 Metetra
.968 .133 0 r
.90679 .58792 .91566 .60304 .93787 .59966 .92939 .58695 Metetra
.976 .102 0 r
.92939 .58695 .93787 .59966 .9598 .5925 .95177 .58242 Metetra
.973 .116 0 r
.32188 .74351 .33314 .75312 .35115 .74666 .34008 .73469 Metetra
.956 .183 0 r
.34008 .73469 .35115 .74666 .36941 .73683 .35852 .72266 Metetra
.928 .29 0 r
.35852 .72266 .36941 .73683 .38784 .72437 .37711 .70818 Metetra
.891 .42 0 r
.37711 .70818 .38784 .72437 .40639 .70997 .39579 .69194 Metetra
.849 .556 0 r
.39579 .69194 .40639 .70997 .425 .69426 .41452 .67457 Metetra
.803 .687 0 r
.41452 .67457 .425 .69426 .44364 .67781 .43326 .65663 Metetra
.708 .755 0 r
.43326 .65663 .44364 .67781 .46229 .66112 .45199 .63861 Metetra
.517 .707 0 r
.45199 .63861 .46229 .66112 .48095 .64461 .47071 .62095 Metetra
.353 .662 0 r
.47071 .62095 .48095 .64461 .4996 .62868 .48942 .604 Metetra
.216 .619 0 r
.48942 .604 .4996 .62868 .51827 .61363 .50812 .58809 Metetra
.108 .581 0 r
.50812 .58809 .51827 .61363 .53696 .59975 .52684 .57348 Metetra
.024 .549 0 r
.52684 .57348 .53696 .59975 .55571 .58724 .54559 .56038 Metetra
0 .523 .036 r
.54559 .56038 .55571 .58724 .57452 .57628 .56441 .54895 Metetra
0 .504 .076 r
.56441 .54895 .57452 .57628 .59344 .56699 .58333 .53932 Metetra
0 .492 .099 r
.58333 .53932 .59344 .56699 .6125 .55947 .60238 .53158 Metetra
0 .488 .107 r
.60238 .53158 .6125 .55947 .63172 .55377 .62159 .52577 Metetra
0 .492 .099 r
.62159 .52577 .63172 .55377 .65115 .54989 .641 .52191 Metetra
0 .504 .076 r
.641 .52191 .65115 .54989 .67081 .5478 .66066 .51996 Metetra
0 .523 .036 r
.66066 .51996 .67081 .5478 .69074 .54743 .68058 .51985 Metetra
.024 .549 0 r
.68058 .51985 .69074 .54743 .71096 .54867 .7008 .52149 Metetra
.108 .581 0 r
.7008 .52149 .71096 .54867 .7315 .55137 .72135 .52472 Metetra
.216 .619 0 r
.72135 .52472 .7315 .55137 .75237 .55531 .74225 .52934 Metetra
.353 .662 0 r
.74225 .52934 .75237 .55531 .77358 .56023 .76351 .53509 Metetra
.517 .707 0 r
.76351 .53509 .77358 .56023 .79513 .56583 .78513 .54168 Metetra
.708 .755 0 r
.78513 .54168 .79513 .56583 .81701 .5717 .8071 .54872 Metetra
.803 .687 0 r
.8071 .54872 .81701 .5717 .83917 .57741 .8294 .55578 Metetra
.849 .556 0 r
.8294 .55578 .83917 .57741 .86157 .58244 .85198 .56234 Metetra
.891 .42 0 r
.85198 .56234 .86157 .58244 .88415 .58616 .87478 .56781 Metetra
.928 .29 0 r
.87478 .56781 .88415 .58616 .90679 .58792 .8977 .57152 Metetra
.956 .183 0 r
.8977 .57152 .90679 .58792 .92939 .58695 .92063 .5727 Metetra
.973 .116 0 r
.92063 .5727 .92939 .58695 .95177 .58242 .94342 .57052 Metetra
.964 .149 0 r
.31054 .73267 .32188 .74351 .34008 .73469 .32893 .72174 Metetra
.94 .246 0 r
.32893 .72174 .34008 .73469 .35852 .72266 .34754 .70776 Metetra
.904 .376 0 r
.34754 .70776 .35852 .72266 .37711 .70818 .36629 .69149 Metetra
.861 .52 0 r
.36629 .69149 .37711 .70818 .39579 .69194 .38511 .67362 Metetra
.812 .662 0 r
.38511 .67362 .39579 .69194 .41452 .67457 .40396 .65478 Metetra
.73 .76 0 r
.40396 .65478 .41452 .67457 .43326 .65663 .42281 .63552 Metetra
.517 .707 0 r
.42281 .63552 .43326 .65663 .45199 .63861 .44163 .61634 Metetra
.331 .655 0 r
.44163 .61634 .45199 .63861 .47071 .62095 .46042 .59765 Metetra
.176 .606 0 r
.46042 .59765 .47071 .62095 .48942 .604 .47918 .57981 Metetra
.051 .56 0 r
.47918 .57981 .48942 .604 .50812 .58809 .49793 .56314 Metetra
0 .519 .044 r
.49793 .56314 .50812 .58809 .52684 .57348 .51668 .54788 Metetra
0 .484 .114 r
.51668 .54788 .52684 .57348 .54559 .56038 .53545 .53425 Metetra
0 .456 .163 r
.53545 .53425 .54559 .56038 .56441 .54895 .55428 .52241 Metetra
0 .436 .194 r
.55428 .52241 .56441 .54895 .58333 .53932 .5732 .51247 Metetra
0 .423 .211 r
.5732 .51247 .58333 .53932 .60238 .53158 .59225 .50452 Metetra
0 .419 .217 r
.59225 .50452 .60238 .53158 .62159 .52577 .61145 .49861 Metetra
0 .423 .211 r
.61145 .49861 .62159 .52577 .641 .52191 .63086 .49475 Metetra
0 .436 .194 r
.63086 .49475 .641 .52191 .66066 .51996 .6505 .49291 Metetra
0 .456 .163 r
.6505 .49291 .66066 .51996 .68058 .51985 .67042 .49302 Metetra
0 .484 .114 r
.67042 .49302 .68058 .51985 .7008 .52149 .69064 .49499 Metetra
0 .519 .044 r
.69064 .49499 .7008 .52149 .72135 .52472 .7112 .49866 Metetra
.051 .56 0 r
.7112 .49866 .72135 .52472 .74225 .52934 .73212 .50385 Metetra
.176 .606 0 r
.73212 .50385 .74225 .52934 .76351 .53509 .75342 .51031 Metetra
.331 .655 0 r
.75342 .51031 .76351 .53509 .78513 .54168 .7751 .51775 Metetra
.517 .707 0 r
.7751 .51775 .78513 .54168 .8071 .54872 .79715 .5258 Metetra
.73 .76 0 r
.79715 .5258 .8071 .54872 .8294 .55578 .81957 .53402 Metetra
.812 .662 0 r
.81957 .53402 .8294 .55578 .85198 .56234 .8423 .54192 Metetra
.861 .52 0 r
.8423 .54192 .85198 .56234 .87478 .56781 .86529 .5489 Metetra
.904 .376 0 r
.86529 .5489 .87478 .56781 .8977 .57152 .88845 .55431 Metetra
.94 .246 0 r
.88845 .55431 .8977 .57152 .92063 .5727 .91167 .55738 Metetra
.964 .149 0 r
.91167 .55738 .92063 .5727 .94342 .57052 .93481 .55727 Metetra
.953 .193 0 r
.29911 .721 .31054 .73267 .32893 .72174 .31769 .70822 Metetra
.921 .314 0 r
.31769 .70822 .32893 .72174 .34754 .70776 .33648 .69253 Metetra
.879 .46 0 r
.33648 .69253 .34754 .70776 .36629 .69149 .35538 .67469 Metetra
.83 .612 0 r
.35538 .67469 .36629 .69149 .38511 .67362 .37435 .65539 Metetra
.776 .754 0 r
.37435 .65539 .38511 .67362 .40396 .65478 .39332 .63527 Metetra
.562 .719 0 r
.39332 .63527 .40396 .65478 .42281 .63552 .41228 .61486 Metetra
.353 .662 0 r
.41228 .61486 .42281 .63552 .44163 .61634 .43119 .59466 Metetra
.176 .606 0 r
.43119 .59466 .44163 .61634 .46042 .59765 .45006 .57507 Metetra
.033 .552 0 r
.45006 .57507 .46042 .59765 .47918 .57981 .46889 .55646 Metetra
0 .504 .076 r
.46889 .55646 .47918 .57981 .49793 .56314 .48769 .53912 Metetra
0 .46 .156 r
.48769 .53912 .49793 .56314 .51668 .54788 .50647 .5233 Metetra
0 .423 .211 r
.50647 .5233 .51668 .54788 .53545 .53425 .52528 .50921 Metetra
0 .394 .247 r
.52528 .50921 .53545 .53425 .55428 .52241 .54413 .49699 Metetra
0 .372 .268 r
.54413 .49699 .55428 .52241 .5732 .51247 .56306 .48678 Metetra
0 .359 .279 r
.56306 .48678 .5732 .51247 .59225 .50452 .58211 .47864 Metetra
0 .355 .282 r
.58211 .47864 .59225 .50452 .61145 .49861 .60132 .47263 Metetra
0 .359 .279 r
.60132 .47263 .61145 .49861 .63086 .49475 .62072 .46876 Metetra
0 .372 .268 r
.62072 .46876 .63086 .49475 .6505 .49291 .64036 .46699 Metetra
0 .394 .247 r
.64036 .46699 .6505 .49291 .67042 .49302 .66028 .46727 Metetra
0 .423 .211 r
.66028 .46727 .67042 .49302 .69064 .49499 .6805 .46951 Metetra
0 .46 .156 r
.6805 .46951 .69064 .49499 .7112 .49866 .70107 .47355 Metetra
0 .504 .076 r
.70107 .47355 .7112 .49866 .73212 .50385 .72201 .47922 Metetra
.033 .552 0 r
.72201 .47922 .73212 .50385 .75342 .51031 .74333 .48627 Metetra
.176 .606 0 r
.74333 .48627 .75342 .51031 .7751 .51775 .76506 .49442 Metetra
.353 .662 0 r
.76506 .49442 .7751 .51775 .79715 .5258 .78719 .50332 Metetra
.562 .719 0 r
.78719 .50332 .79715 .5258 .81957 .53402 .80969 .51253 Metetra
.776 .754 0 r
.80969 .51253 .81957 .53402 .8423 .54192 .83255 .52157 Metetra
.83 .612 0 r
.83255 .52157 .8423 .54192 .86529 .5489 .8557 .52985 Metetra
.879 .46 0 r
.8557 .52985 .86529 .5489 .88845 .55431 .87907 .53672 Metetra
.921 .314 0 r
.87907 .53672 .88845 .55431 .91167 .55738 .90255 .54141 Metetra
.953 .193 0 r
.90255 .54141 .91167 .55738 .93481 .55727 .926 .5431 Metetra
.941 .242 0 r
.28757 .70886 .29911 .721 .31769 .70822 .30634 .69448 Metetra
.902 .381 0 r
.30634 .69448 .31769 .70822 .33648 .69253 .3253 .67731 Metetra
.855 .538 0 r
.3253 .67731 .33648 .69253 .35538 .67469 .34436 .65812 Metetra
.8 .693 0 r
.34436 .65812 .35538 .67469 .37435 .65539 .36347 .6376 Metetra
.652 .741 0 r
.36347 .6376 .37435 .65539 .39332 .63527 .38257 .61637 Metetra
.418 .68 0 r
.38257 .61637 .39332 .63527 .41228 .61486 .40164 .59498 Metetra
.216 .619 0 r
.40164 .59498 .41228 .61486 .43119 .59466 .42066 .57389 Metetra
.051 .56 0 r
.42066 .57389 .43119 .59466 .45006 .57507 .43961 .55354 Metetra
0 .504 .076 r
.43961 .55354 .45006 .57507 .46889 .55646 .45852 .53425 Metetra
0 .452 .169 r
.45852 .53425 .46889 .55646 .48769 .53912 .47738 .51633 Metetra
0 .407 .232 r
.47738 .51633 .48769 .53912 .50647 .5233 .49621 .50003 Metetra
0 .368 .272 r
.49621 .50003 .50647 .5233 .52528 .50921 .51506 .48553 Metetra
0 .337 .294 r
.51506 .48553 .52528 .50921 .54413 .49699 .53394 .47299 Metetra
0 .315 .305 r
.53394 .47299 .54413 .49699 .56306 .48678 .5529 .46253 Metetra
0 .292 .301 r
.5529 .46253 .56306 .48678 .58211 .47864 .57196 .45422 Metetra
0 .282 .296 r
.57196 .45422 .58211 .47864 .60132 .47263 .59118 .44811 Metetra
0 .292 .301 r
.59118 .44811 .60132 .47263 .62072 .46876 .61059 .44421 Metetra
0 .315 .305 r
.61059 .44421 .62072 .46876 .64036 .46699 .63023 .44249 Metetra
0 .337 .294 r
.63023 .44249 .64036 .46699 .66028 .46727 .65015 .4429 Metetra
0 .368 .272 r
.65015 .4429 .66028 .46727 .6805 .46951 .67038 .44535 Metetra
0 .407 .232 r
.67038 .44535 .6805 .46951 .70107 .47355 .69096 .44969 Metetra
0 .452 .169 r
.69096 .44969 .70107 .47355 .72201 .47922 .71191 .45574 Metetra
0 .504 .076 r
.71191 .45574 .72201 .47922 .74333 .48627 .73327 .46328 Metetra
.051 .56 0 r
.73327 .46328 .74333 .48627 .76506 .49442 .75504 .47202 Metetra
.216 .619 0 r
.75504 .47202 .76506 .49442 .78719 .50332 .77722 .48162 Metetra
.418 .68 0 r
.77722 .48162 .78719 .50332 .80969 .51253 .79981 .49166 Metetra
.652 .741 0 r
.79981 .49166 .80969 .51253 .83255 .52157 .82278 .50165 Metetra
.8 .693 0 r
.82278 .50165 .83255 .52157 .8557 .52985 .84607 .51102 Metetra
.855 .538 0 r
.84607 .51102 .8557 .52985 .87907 .53672 .86962 .51912 Metetra
.902 .381 0 r
.86962 .51912 .87907 .53672 .90255 .54141 .89331 .52518 Metetra
.941 .242 0 r
.89331 .52518 .90255 .54141 .926 .5431 .91703 .52839 Metetra
.928 .291 0 r
.27591 .69656 .28757 .70886 .30634 .69448 .29485 .68082 Metetra
.884 .443 0 r
.29485 .68082 .30634 .69448 .3253 .67731 .31398 .66241 Metetra
.832 .606 0 r
.31398 .66241 .3253 .67731 .34436 .65812 .3332 .64208 Metetra
.773 .76 0 r
.3332 .64208 .34436 .65812 .36347 .6376 .35246 .62053 Metetra
.528 .71 0 r
.35246 .62053 .36347 .6376 .38257 .61637 .3717 .59836 Metetra
.299 .646 0 r
.3717 .59836 .38257 .61637 .40164 .59498 .39089 .57613 Metetra
.108 .581 0 r
.39089 .57613 .40164 .59498 .42066 .57389 .41001 .55431 Metetra
0 .519 .044 r
.41001 .55431 .42066 .57389 .43961 .55354 .42906 .5333 Metetra
0 .46 .156 r
.42906 .5333 .43961 .55354 .45852 .53425 .44805 .51344 Metetra
0 .407 .232 r
.44805 .51344 .45852 .53425 .47738 .51633 .46698 .49503 Metetra
0 .359 .279 r
.46698 .49503 .47738 .51633 .49621 .50003 .48588 .4783 Metetra
0 .319 .303 r
.48588 .4783 .49621 .50003 .51506 .48553 .50478 .46346 Metetra
0 .262 .287 r
.50478 .46346 .51506 .48553 .53394 .47299 .5237 .45063 Metetra
0 .214 .264 r
.5237 .45063 .53394 .47299 .5529 .46253 .54269 .43995 Metetra
0 .187 .25 r
.54269 .43995 .5529 .46253 .57196 .45422 .56178 .43148 Metetra
0 .178 .245 r
.56178 .43148 .57196 .45422 .59118 .44811 .58102 .42528 Metetra
0 .187 .25 r
.58102 .42528 .59118 .44811 .61059 .44421 .60044 .42134 Metetra
0 .214 .264 r
.60044 .42134 .61059 .44421 .63023 .44249 .6201 .41965 Metetra
0 .262 .287 r
.6201 .41965 .63023 .44249 .65015 .4429 .64003 .42016 Metetra
0 .319 .303 r
.64003 .42016 .65015 .4429 .67038 .44535 .66027 .42276 Metetra
0 .359 .279 r
.66027 .42276 .67038 .44535 .69096 .44969 .68086 .42732 Metetra
0 .407 .232 r
.68086 .42732 .69096 .44969 .71191 .45574 .70184 .43368 Metetra
0 .46 .156 r
.70184 .43368 .71191 .45574 .73327 .46328 .72322 .44161 Metetra
0 .519 .044 r
.72322 .44161 .73327 .46328 .75504 .47202 .74503 .45082 Metetra
.108 .581 0 r
.74503 .45082 .75504 .47202 .77722 .48162 .76727 .46098 Metetra
.299 .646 0 r
.76727 .46098 .77722 .48162 .79981 .49166 .78993 .47169 Metetra
.528 .71 0 r
.78993 .47169 .79981 .49166 .82278 .50165 .81299 .48246 Metetra
.773 .76 0 r
.81299 .48246 .82278 .50165 .84607 .51102 .83641 .49271 Metetra
.832 .606 0 r
.83641 .49271 .84607 .51102 .86962 .51912 .86011 .50181 Metetra
.884 .443 0 r
.86011 .50181 .86962 .51912 .89331 .52518 .884 .50901 Metetra
.928 .291 0 r
.884 .50901 .89331 .52518 .91703 .52839 .90794 .51346 Metetra
.916 .334 0 r
.26409 .68434 .27591 .69656 .29485 .68082 .28321 .6675 Metetra
.868 .496 0 r
.28321 .6675 .29485 .68082 .31398 .66241 .30251 .64807 Metetra
.812 .662 0 r
.30251 .64807 .31398 .66241 .3332 .64208 .32189 .62681 Metetra
.685 .749 0 r
.32189 .62681 .3332 .64208 .35246 .62053 .34129 .60441 Metetra
.429 .683 0 r
.34129 .60441 .35246 .62053 .3717 .59836 .36067 .58148 Metetra
.206 .616 0 r
.36067 .58148 .3717 .59836 .39089 .57613 .37999 .55856 Metetra
.024 .549 0 r
.37999 .55856 .39089 .57613 .41001 .55431 .39923 .53612 Metetra
0 .484 .114 r
.39923 .53612 .41001 .55431 .42906 .5333 .41839 .51457 Metetra
0 .423 .211 r
.41839 .51457 .42906 .5333 .44805 .51344 .43747 .49423 Metetra
0 .368 .272 r
.43747 .49423 .44805 .51344 .46698 .49503 .45648 .47541 Metetra
0 .319 .303 r
.45648 .47541 .46698 .49503 .48588 .4783 .47546 .45833 Metetra
0 .242 .278 r
.47546 .45833 .48588 .4783 .50478 .46346 .49442 .44319 Metetra
0 .178 .245 r
.49442 .44319 .50478 .46346 .5237 .45063 .5134 .43012 Metetra
0 .138 .221 r
.5134 .43012 .5237 .45063 .54269 .43995 .53243 .41924 Metetra
0 .116 .206 r
.53243 .41924 .54269 .43995 .56178 .43148 .55156 .41063 Metetra
0 .109 .202 r
.55156 .41063 .56178 .43148 .58102 .42528 .57083 .40433 Metetra
0 .116 .206 r
.57083 .40433 .58102 .42528 .60044 .42134 .59028 .40035 Metetra
0 .138 .221 r
.59028 .40035 .60044 .42134 .6201 .41965 .60996 .39867 Metetra
0 .178 .245 r
.60996 .39867 .6201 .41965 .64003 .42016 .62991 .39922 Metetra
0 .242 .278 r
.62991 .39922 .64003 .42016 .66027 .42276 .65018 .40193 Metetra
0 .319 .303 r
.65018 .40193 .66027 .42276 .68086 .42732 .67079 .40667 Metetra
0 .368 .272 r
.67079 .40667 .68086 .42732 .70184 .43368 .69179 .41325 Metetra
0 .423 .211 r
.69179 .41325 .70184 .43368 .72322 .44161 .7132 .42147 Metetra
0 .484 .114 r
.7132 .42147 .72322 .44161 .74503 .45082 .73505 .43104 Metetra
.024 .549 0 r
.73505 .43104 .74503 .45082 .76727 .46098 .75734 .44164 Metetra
.206 .616 0 r
.75734 .44164 .76727 .46098 .78993 .47169 .78007 .45286 Metetra
.429 .683 0 r
.78007 .45286 .78993 .47169 .81299 .48246 .80322 .46423 Metetra
.685 .749 0 r
.80322 .46423 .81299 .48246 .83641 .49271 .82674 .47518 Metetra
.812 .662 0 r
.82674 .47518 .83641 .49271 .86011 .50181 .85057 .48506 Metetra
.868 .496 0 r
.85057 .48506 .86011 .50181 .884 .50901 .87462 .49314 Metetra
.916 .334 0 r
.87462 .49314 .884 .50901 .90794 .51346 .89877 .49858 Metetra
.906 .371 0 r
.25211 .6724 .26409 .68434 .28321 .6675 .27139 .65472 Metetra
.855 .538 0 r
.27139 .65472 .28321 .6675 .30251 .64807 .29085 .63449 Metetra
.795 .705 0 r
.29085 .63449 .30251 .64807 .32189 .62681 .31039 .6125 Metetra
.607 .73 0 r
.31039 .6125 .32189 .62681 .34129 .60441 .32994 .58943 Metetra
.353 .662 0 r
.32994 .58943 .34129 .60441 .36067 .58148 .34947 .56589 Metetra
.136 .592 0 r
.34947 .56589 .36067 .58148 .37999 .55856 .36892 .54243 Metetra
0 .523 .036 r
.36892 .54243 .37999 .55856 .39923 .53612 .38829 .5195 Metetra
0 .456 .163 r
.38829 .5195 .39923 .53612 .41839 .51457 .40756 .49751 Metetra
0 .394 .247 r
.40756 .49751 .41839 .51457 .43747 .49423 .42675 .4768 Metetra
0 .337 .294 r
.42675 .4768 .43747 .49423 .45648 .47541 .44586 .45764 Metetra
0 .262 .287 r
.44586 .45764 .45648 .47541 .47546 .45833 .46492 .44027 Metetra
0 .178 .245 r
.46492 .44027 .47546 .45833 .49442 .44319 .48396 .42487 Metetra
0 .123 .211 r
.48396 .42487 .49442 .44319 .5134 .43012 .503 .4116 Metetra
0 .089 .187 r
.503 .4116 .5134 .43012 .53243 .41924 .5221 .40055 Metetra
0 .071 .172 r
.5221 .40055 .53243 .41924 .55156 .41063 .54128 .39181 Metetra
0 .065 .167 r
.54128 .39181 .55156 .41063 .57083 .40433 .56059 .38542 Metetra
0 .071 .172 r
.56059 .38542 .57083 .40433 .59028 .40035 .58009 .38138 Metetra
0 .089 .187 r
.58009 .38138 .59028 .40035 .60996 .39867 .5998 .37968 Metetra
0 .123 .211 r
.5998 .37968 .60996 .39867 .62991 .39922 .61978 .38026 Metetra
0 .178 .245 r
.61978 .38026 .62991 .39922 .65018 .40193 .64008 .38304 Metetra
0 .262 .287 r
.64008 .38304 .65018 .40193 .67079 .40667 .66072 .38787 Metetra
0 .337 .294 r
.66072 .38787 .67079 .40667 .69179 .41325 .68175 .39461 Metetra
0 .394 .247 r
.68175 .39461 .69179 .41325 .7132 .42147 .7032 .40303 Metetra
0 .456 .163 r
.7032 .40303 .7132 .42147 .73505 .43104 .72509 .41286 Metetra
0 .523 .036 r
.72509 .41286 .73505 .43104 .75734 .44164 .74743 .42377 Metetra
.136 .592 0 r
.74743 .42377 .75734 .44164 .78007 .45286 .77022 .43536 Metetra
.353 .662 0 r
.77022 .43536 .78007 .45286 .80322 .46423 .79345 .44716 Metetra
.607 .73 0 r
.79345 .44716 .80322 .46423 .82674 .47518 .81706 .45862 Metetra
.795 .705 0 r
.81706 .45862 .82674 .47518 .85057 .48506 .84102 .46908 Metetra
.855 .538 0 r
.84102 .46908 .85057 .48506 .87462 .49314 .86521 .47781 Metetra
.906 .371 0 r
.86521 .47781 .87462 .49314 .89877 .49858 .88952 .48396 Metetra
.898 .398 0 r
.23994 .66091 .25211 .6724 .27139 .65472 .25938 .64262 Metetra
.845 .569 0 r
.25938 .64262 .27139 .65472 .29085 .63449 .27899 .62182 Metetra
.783 .736 0 r
.27899 .62182 .29085 .63449 .31039 .6125 .29869 .5993 Metetra
.551 .716 0 r
.29869 .5993 .31039 .6125 .32994 .58943 .31839 .57574 Metetra
.299 .646 0 r
.31839 .57574 .32994 .58943 .34947 .56589 .33806 .55176 Metetra
.088 .574 0 r
.33806 .55176 .34947 .56589 .36892 .54243 .35766 .52788 Metetra
0 .504 .076 r
.35766 .52788 .36892 .54243 .38829 .5195 .37716 .50459 Metetra
0 .436 .194 r
.37716 .50459 .38829 .5195 .40756 .49751 .39656 .48226 Metetra
0 .372 .268 r
.39656 .48226 .40756 .49751 .42675 .4768 .41586 .46125 Metetra
0 .315 .305 r
.41586 .46125 .42675 .4768 .44586 .45764 .43508 .44183 Metetra
0 .214 .264 r
.43508 .44183 .44586 .45764 .46492 .44027 .45424 .42423 Metetra
0 .138 .221 r
.45424 .42423 .46492 .44027 .48396 .42487 .47337 .40863 Metetra
0 .089 .187 r
.47337 .40863 .48396 .42487 .503 .4116 .4925 .39519 Metetra
0 .06 .162 r
.4925 .39519 .503 .4116 .5221 .40055 .51166 .384 Metetra
0 .045 .147 r
.51166 .384 .5221 .40055 .54128 .39181 .53091 .37514 Metetra
0 .04 .142 r
.53091 .37514 .54128 .39181 .56059 .38542 .55029 .36866 Metetra
0 .045 .147 r
.55029 .36866 .56059 .38542 .58009 .38138 .56983 .36456 Metetra
0 .06 .162 r
.56983 .36456 .58009 .38138 .5998 .37968 .5896 .36282 Metetra
0 .089 .187 r
.5896 .36282 .5998 .37968 .61978 .38026 .60963 .36339 Metetra
0 .138 .221 r
.60963 .36339 .61978 .38026 .64008 .38304 .62996 .36618 Metetra
0 .214 .264 r
.62996 .36618 .64008 .38304 .66072 .38787 .65064 .37107 Metetra
0 .315 .305 r
.65064 .37107 .66072 .38787 .68175 .39461 .67172 .37789 Metetra
0 .372 .268 r
.67172 .37789 .68175 .39461 .7032 .40303 .69321 .38642 Metetra
0 .436 .194 r
.69321 .38642 .7032 .40303 .72509 .41286 .71515 .3964 Metetra
0 .504 .076 r
.71515 .3964 .72509 .41286 .74743 .42377 .73754 .4075 Metetra
.088 .574 0 r
.73754 .4075 .74743 .42377 .77022 .43536 .76039 .41933 Metetra
.299 .646 0 r
.76039 .41933 .77022 .43536 .79345 .44716 .78369 .43141 Metetra
.551 .716 0 r
.78369 .43141 .79345 .44716 .81706 .45862 .80739 .44318 Metetra
.783 .736 0 r
.80739 .44318 .81706 .45862 .84102 .46908 .83145 .45401 Metetra
.845 .569 0 r
.83145 .45401 .84102 .46908 .86521 .47781 .85576 .46315 Metetra
.898 .398 0 r
.85576 .46315 .86521 .47781 .88952 .48396 .88022 .46977 Metetra
.893 .415 0 r
.22755 .64997 .23994 .66091 .25938 .64262 .24714 .63131 Metetra
.838 .587 0 r
.24714 .63131 .25938 .64262 .27899 .62182 .2669 .61016 Metetra
.776 .754 0 r
.2669 .61016 .27899 .62182 .29869 .5993 .28675 .58731 Metetra
.517 .707 0 r
.28675 .58731 .29869 .5993 .31839 .57574 .30661 .56344 Metetra
.268 .636 0 r
.30661 .56344 .31839 .57574 .33806 .55176 .32643 .53916 Metetra
.061 .563 0 r
.32643 .53916 .33806 .55176 .35766 .52788 .34617 .51501 Metetra
0 .492 .099 r
.34617 .51501 .35766 .52788 .37716 .50459 .36582 .49147 Metetra
0 .423 .211 r
.36582 .49147 .37716 .50459 .39656 .48226 .38535 .46891 Metetra
0 .359 .279 r
.38535 .46891 .39656 .48226 .41586 .46125 .40478 .44769 Metetra
0 .292 .301 r
.40478 .44769 .41586 .46125 .43508 .44183 .42412 .42808 Metetra
0 .187 .25 r
.42412 .42808 .43508 .44183 .45424 .42423 .4434 .4103 Metetra
0 .116 .206 r
.4434 .4103 .45424 .42423 .47337 .40863 .46263 .39455 Metetra
0 .071 .172 r
.46263 .39455 .47337 .40863 .4925 .39519 .48185 .38097 Metetra
0 .045 .147 r
.48185 .38097 .4925 .39519 .51166 .384 .50111 .36966 Metetra
0 .031 .132 r
.50111 .36966 .51166 .384 .53091 .37514 .52044 .3607 Metetra
0 .027 .127 r
.52044 .3607 .53091 .37514 .55029 .36866 .53989 .35412 Metetra
0 .031 .132 r
.53989 .35412 .55029 .36866 .56983 .36456 .55951 .34995 Metetra
0 .045 .147 r
.55951 .34995 .56983 .36456 .5896 .36282 .57933 .34816 Metetra
0 .071 .172 r
.57933 .34816 .5896 .36282 .60963 .36339 .59942 .34869 Metetra
0 .116 .206 r
.59942 .34869 .60963 .36339 .62996 .36618 .61981 .35146 Metetra
0 .187 .25 r
.61981 .35146 .62996 .36618 .65064 .37107 .64054 .35634 Metetra
0 .292 .301 r
.64054 .35634 .65064 .37107 .67172 .37789 .66167 .36317 Metetra
0 .359 .279 r
.66167 .36317 .67172 .37789 .69321 .38642 .68321 .37174 Metetra
0 .423 .211 r
.68321 .37174 .69321 .38642 .71515 .3964 .7052 .38177 Metetra
0 .492 .099 r
.7052 .38177 .71515 .3964 .73754 .4075 .72765 .39294 Metetra
.061 .563 0 r
.72765 .39294 .73754 .4075 .76039 .41933 .75057 .40486 Metetra
.268 .636 0 r
.75057 .40486 .76039 .41933 .78369 .43141 .77393 .41706 Metetra
.517 .707 0 r
.77393 .41706 .78369 .43141 .80739 .44318 .79772 .42898 Metetra
.776 .754 0 r
.79772 .42898 .80739 .44318 .83145 .45401 .82186 .43997 Metetra
.838 .587 0 r
.82186 .43997 .83145 .45401 .85576 .46315 .84629 .44929 Metetra
.893 .415 0 r
.84629 .44929 .85576 .46315 .88022 .46977 .87087 .45611 Metetra
.891 .42 0 r
.21495 .63963 .22755 .64997 .24714 .63131 .23466 .62084 Metetra
.836 .593 0 r
.23466 .62084 .24714 .63131 .2669 .61016 .25457 .59957 Metetra
.773 .76 0 r
.25457 .59957 .2669 .61016 .28675 .58731 .27457 .57658 Metetra
.506 .704 0 r
.27457 .57658 .28675 .58731 .30661 .56344 .29458 .55257 Metetra
.257 .632 0 r
.29458 .55257 .30661 .56344 .32643 .53916 .31455 .52815 Metetra
.051 .56 0 r
.31455 .52815 .32643 .53916 .34617 .51501 .33445 .50387 Metetra
0 .488 .107 r
.33445 .50387 .34617 .51501 .36582 .49147 .35424 .48019 Metetra
0 .419 .217 r
.35424 .48019 .36582 .49147 .38535 .46891 .37392 .45751 Metetra
0 .355 .282 r
.37392 .45751 .38535 .46891 .40478 .44769 .39349 .43616 Metetra
0 .282 .296 r
.39349 .43616 .40478 .44769 .42412 .42808 .41296 .41643 Metetra
0 .178 .245 r
.41296 .41643 .42412 .42808 .4434 .4103 .43236 .39854 Metetra
0 .109 .202 r
.43236 .39854 .4434 .4103 .46263 .39455 .45171 .38268 Metetra
0 .065 .167 r
.45171 .38268 .46263 .39455 .48185 .38097 .47105 .36899 Metetra
0 .04 .142 r
.47105 .36899 .48185 .38097 .50111 .36966 .49041 .35758 Metetra
0 .027 .127 r
.49041 .35758 .50111 .36966 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .027 .127 r
.52938 .34187 .53989 .35412 .55951 .34995 .54908 .33761 Metetra
0 .04 .142 r
.54908 .33761 .55951 .34995 .57933 .34816 .56898 .33574 Metetra
0 .065 .167 r
.56898 .33574 .57933 .34816 .59942 .34869 .58914 .3362 Metetra
0 .109 .202 r
.58914 .3362 .59942 .34869 .61981 .35146 .6096 .33891 Metetra
0 .178 .245 r
.6096 .33891 .61981 .35146 .64054 .35634 .6304 .34373 Metetra
0 .282 .296 r
.6304 .34373 .64054 .35634 .66167 .36317 .65158 .35051 Metetra
0 .355 .282 r
.65158 .35051 .66167 .36317 .68321 .37174 .67319 .35902 Metetra
0 .419 .217 r
.67319 .35902 .68321 .37174 .7052 .38177 .69524 .36901 Metetra
0 .488 .107 r
.69524 .36901 .7052 .38177 .72765 .39294 .71775 .38014 Metetra
.051 .56 0 r
.71775 .38014 .72765 .39294 .75057 .40486 .74074 .39202 Metetra
.257 .632 0 r
.74074 .39202 .75057 .40486 .77393 .41706 .76417 .40418 Metetra
.506 .704 0 r
.76417 .40418 .77393 .41706 .79772 .42898 .78803 .41606 Metetra
.773 .76 0 r
.78803 .41606 .79772 .42898 .82186 .43997 .81226 .42701 Metetra
.836 .593 0 r
.81226 .42701 .82186 .43997 .84629 .44929 .83678 .43628 Metetra
.891 .42 0 r
.83678 .43628 .84629 .44929 .87087 .45611 .86147 .44304 Metetra
.893 .415 0 r
.2021 .62989 .21495 .63963 .23466 .62084 .22194 .61124 Metetra
.838 .587 0 r
.22194 .61124 .23466 .62084 .25457 .59957 .24197 .59006 Metetra
.776 .754 0 r
.24197 .59006 .25457 .59957 .27457 .57658 .26211 .56713 Metetra
.517 .707 0 r
.26211 .56713 .27457 .57658 .29458 .55257 .28228 .54316 Metetra
.268 .636 0 r
.28228 .54316 .29458 .55257 .31455 .52815 .3024 .51876 Metetra
.061 .563 0 r
.3024 .51876 .31455 .52815 .33445 .50387 .32245 .49448 Metetra
0 .492 .099 r
.32245 .49448 .33445 .50387 .35424 .48019 .3424 .47078 Metetra
0 .423 .211 r
.3424 .47078 .35424 .48019 .37392 .45751 .36223 .44807 Metetra
0 .359 .279 r
.36223 .44807 .37392 .45751 .39349 .43616 .38195 .42668 Metetra
0 .292 .301 r
.38195 .42668 .39349 .43616 .41296 .41643 .40157 .40689 Metetra
0 .187 .25 r
.40157 .40689 .41296 .41643 .43236 .39854 .42111 .38895 Metetra
0 .116 .206 r
.42111 .38895 .43236 .39854 .45171 .38268 .44059 .37302 Metetra
0 .071 .172 r
.44059 .37302 .45171 .38268 .47105 .36899 .46005 .35926 Metetra
0 .045 .147 r
.46005 .35926 .47105 .36899 .49041 .35758 .47953 .34778 Metetra
0 .031 .132 r
.47953 .34778 .49041 .35758 .50984 .34853 .49907 .33865 Metetra
0 .027 .127 r
.49907 .33865 .50984 .34853 .52938 .34187 .51872 .3319 Metetra
0 .031 .132 r
.51872 .3319 .52938 .34187 .54908 .33761 .53852 .32756 Metetra
0 .045 .147 r
.53852 .32756 .54908 .33761 .56898 .33574 .55851 .3256 Metetra
0 .071 .172 r
.55851 .3256 .56898 .33574 .58914 .3362 .57876 .32596 Metetra
0 .116 .206 r
.57876 .32596 .58914 .3362 .6096 .33891 .5993 .32855 Metetra
0 .187 .25 r
.5993 .32855 .6096 .33891 .6304 .34373 .62018 .33326 Metetra
0 .292 .301 r
.62018 .33326 .6304 .34373 .65158 .35051 .64144 .33992 Metetra
0 .359 .279 r
.64144 .33992 .65158 .35051 .67319 .35902 .66312 .3483 Metetra
0 .423 .211 r
.66312 .3483 .67319 .35902 .69524 .36901 .68524 .35814 Metetra
0 .492 .099 r
.68524 .35814 .69524 .36901 .71775 .38014 .70783 .36911 Metetra
.061 .563 0 r
.70783 .36911 .71775 .38014 .74074 .39202 .73088 .38082 Metetra
.268 .636 0 r
.73088 .38082 .74074 .39202 .76417 .40418 .75439 .39278 Metetra
.517 .707 0 r
.75439 .39278 .76417 .40418 .78803 .41606 .77832 .40443 Metetra
.776 .754 0 r
.77832 .40443 .78803 .41606 .81226 .42701 .80263 .41513 Metetra
.838 .587 0 r
.80263 .41513 .81226 .42701 .83678 .43628 .82723 .42412 Metetra
.893 .415 0 r
.82723 .42412 .83678 .43628 .86147 .44304 .852 .43056 Metetra
.898 .398 0 r
.18901 .62072 .2021 .62989 .22194 .61124 .20894 .60244 Metetra
.845 .569 0 r
.20894 .60244 .22194 .61124 .24197 .59006 .2291 .58158 Metetra
.783 .736 0 r
.2291 .58158 .24197 .59006 .26211 .56713 .24937 .55892 Metetra
.551 .716 0 r
.24937 .55892 .26211 .56713 .28228 .54316 .26968 .53517 Metetra
.299 .646 0 r
.26968 .53517 .28228 .54316 .3024 .51876 .28996 .51095 Metetra
.088 .574 0 r
.28996 .51095 .3024 .51876 .32245 .49448 .31016 .48681 Metetra
0 .504 .076 r
.31016 .48681 .32245 .49448 .3424 .47078 .33027 .46321 Metetra
0 .436 .194 r
.33027 .46321 .3424 .47078 .36223 .44807 .35026 .44057 Metetra
0 .372 .268 r
.35026 .44057 .36223 .44807 .38195 .42668 .37014 .41923 Metetra
0 .315 .305 r
.37014 .41923 .38195 .42668 .40157 .40689 .38991 .39947 Metetra
0 .214 .264 r
.38991 .39947 .40157 .40689 .42111 .38895 .4096 .38152 Metetra
0 .138 .221 r
.4096 .38152 .42111 .38895 .44059 .37302 .42923 .36558 Metetra
0 .089 .187 r
.42923 .36558 .44059 .37302 .46005 .35926 .44884 .35178 Metetra
0 .06 .162 r
.44884 .35178 .46005 .35926 .47953 .34778 .46845 .34025 Metetra
0 .045 .147 r
.46845 .34025 .47953 .34778 .49907 .33865 .48812 .33105 Metetra
0 .04 .142 r
.48812 .33105 .49907 .33865 .51872 .3319 .50789 .32422 Metetra
0 .045 .147 r
.50789 .32422 .51872 .3319 .53852 .32756 .5278 .31978 Metetra
0 .06 .162 r
.5278 .31978 .53852 .32756 .55851 .3256 .54791 .3177 Metetra
0 .089 .187 r
.54791 .3177 .55851 .3256 .57876 .32596 .56826 .31793 Metetra
0 .138 .221 r
.56826 .31793 .57876 .32596 .5993 .32855 .5889 .32038 Metetra
0 .214 .264 r
.5889 .32038 .5993 .32855 .62018 .33326 .60987 .32492 Metetra
0 .315 .305 r
.60987 .32492 .62018 .33326 .64144 .33992 .63123 .33138 Metetra
0 .372 .268 r
.63123 .33138 .64144 .33992 .66312 .3483 .65299 .33954 Metetra
0 .436 .194 r
.65299 .33954 .66312 .3483 .68524 .35814 .67519 .34914 Metetra
0 .504 .076 r
.67519 .34914 .68524 .35814 .70783 .36911 .69785 .35983 Metetra
.088 .574 0 r
.69785 .35983 .70783 .36911 .73088 .38082 .72098 .37122 Metetra
.299 .646 0 r
.72098 .37122 .73088 .38082 .75439 .39278 .74457 .38282 Metetra
.551 .716 0 r
.74457 .38282 .75439 .39278 .77832 .40443 .76857 .39407 Metetra
.783 .736 0 r
.76857 .39407 .77832 .40443 .80263 .41513 .79295 .40431 Metetra
.845 .569 0 r
.79295 .40431 .80263 .41513 .82723 .42412 .81762 .41278 Metetra
.898 .398 0 r
.81762 .41278 .82723 .42412 .852 .43056 .84246 .41863 Metetra
.906 .371 0 r
.17568 .61201 .18901 .62072 .20894 .60244 .19568 .59436 Metetra
.855 .538 0 r
.19568 .59436 .20894 .60244 .2291 .58158 .21593 .57406 Metetra
.795 .705 0 r
.21593 .57406 .2291 .58158 .24937 .55892 .23632 .55188 Metetra
.607 .73 0 r
.23632 .55188 .24937 .55892 .26968 .53517 .25677 .52853 Metetra
.353 .662 0 r
.25677 .52853 .26968 .53517 .28996 .51095 .27719 .50465 Metetra
.136 .592 0 r
.27719 .50465 .28996 .51095 .31016 .48681 .29756 .48079 Metetra
0 .523 .036 r
.29756 .48079 .31016 .48681 .33027 .46321 .31783 .45742 Metetra
0 .456 .163 r
.31783 .45742 .33027 .46321 .35026 .44057 .33799 .43496 Metetra
0 .394 .247 r
.33799 .43496 .35026 .44057 .37014 .41923 .35803 .41375 Metetra
0 .337 .294 r
.35803 .41375 .37014 .41923 .38991 .39947 .37797 .39409 Metetra
0 .262 .287 r
.37797 .39409 .38991 .39947 .4096 .38152 .39782 .3762 Metetra
0 .178 .245 r
.39782 .3762 .4096 .38152 .42923 .36558 .41761 .36029 Metetra
0 .123 .211 r
.41761 .36029 .42923 .36558 .44884 .35178 .43737 .34649 Metetra
0 .089 .187 r
.43737 .34649 .44884 .35178 .46845 .34025 .45714 .33493 Metetra
0 .071 .172 r
.45714 .33493 .46845 .34025 .48812 .33105 .47695 .32567 Metetra
0 .065 .167 r
.47695 .32567 .48812 .33105 .50789 .32422 .49686 .31876 Metetra
0 .071 .172 r
.49686 .31876 .50789 .32422 .5278 .31978 .5169 .31421 Metetra
0 .089 .187 r
.5169 .31421 .5278 .31978 .54791 .3177 .53714 .312 Metetra
0 .123 .211 r
.53714 .312 .54791 .3177 .56826 .31793 .55761 .31207 Metetra
0 .178 .245 r
.55761 .31207 .56826 .31793 .5889 .32038 .57836 .31432 Metetra
0 .262 .287 r
.57836 .31432 .5889 .32038 .60987 .32492 .59944 .31864 Metetra
0 .337 .294 r
.59944 .31864 .60987 .32492 .63123 .33138 .6209 .32483 Metetra
0 .394 .247 r
.6209 .32483 .63123 .33138 .65299 .33954 .64276 .33269 Metetra
0 .456 .163 r
.64276 .33269 .65299 .33954 .67519 .34914 .66506 .34194 Metetra
0 .523 .036 r
.66506 .34194 .67519 .34914 .69785 .35983 .68781 .35223 Metetra
.136 .592 0 r
.68781 .35223 .69785 .35983 .72098 .37122 .71102 .36315 Metetra
.353 .662 0 r
.71102 .36315 .72098 .37122 .74457 .38282 .73468 .37423 Metetra
.607 .73 0 r
.73468 .37423 .74457 .38282 .76857 .39407 .75876 .38488 Metetra
.795 .705 0 r
.75876 .38488 .76857 .39407 .79295 .40431 .7832 .39444 Metetra
.855 .538 0 r
.7832 .39444 .79295 .40431 .81762 .41278 .80793 .40214 Metetra
.906 .371 0 r
.80793 .40214 .81762 .41278 .84246 .41863 .83282 .40714 Metetra
.916 .334 0 r
.1621 .60361 .17568 .61201 .19568 .59436 .18214 .58687 Metetra
.868 .496 0 r
.18214 .58687 .19568 .59436 .21593 .57406 .20247 .56736 Metetra
.812 .662 0 r
.20247 .56736 .21593 .57406 .23632 .55188 .22296 .54587 Metetra
.685 .749 0 r
.22296 .54587 .23632 .55188 .25677 .52853 .24353 .52312 Metetra
.429 .683 0 r
.24353 .52312 .25677 .52853 .27719 .50465 .2641 .49975 Metetra
.206 .616 0 r
.2641 .49975 .27719 .50465 .29756 .48079 .28462 .47632 Metetra
.024 .549 0 r
.28462 .47632 .29756 .48079 .31783 .45742 .30505 .4533 Metetra
0 .484 .114 r
.30505 .4533 .31783 .45742 .33799 .43496 .32538 .43113 Metetra
0 .423 .211 r
.32538 .43113 .33799 .43496 .35803 .41375 .3456 .41016 Metetra
0 .368 .272 r
.3456 .41016 .35803 .41375 .37797 .39409 .36572 .39067 Metetra
0 .319 .303 r
.36572 .39067 .37797 .39409 .39782 .3762 .38574 .37291 Metetra
0 .242 .278 r
.38574 .37291 .39782 .3762 .41761 .36029 .4057 .35707 Metetra
0 .178 .245 r
.4057 .35707 .41761 .36029 .43737 .34649 .42563 .34332 Metetra
0 .138 .221 r
.42563 .34332 .43737 .34649 .45714 .33493 .44556 .33175 Metetra
0 .116 .206 r
.44556 .33175 .45714 .33493 .47695 .32567 .46553 .32245 Metetra
0 .109 .202 r
.46553 .32245 .47695 .32567 .49686 .31876 .4856 .31546 Metetra
0 .116 .206 r
.4856 .31546 .49686 .31876 .5169 .31421 .50579 .31079 Metetra
0 .138 .221 r
.50579 .31079 .5169 .31421 .53714 .312 .52617 .30842 Metetra
0 .178 .245 r
.52617 .30842 .53714 .312 .55761 .31207 .54677 .30829 Metetra
0 .242 .278 r
.54677 .30829 .55761 .31207 .57836 .31432 .56766 .3103 Metetra
0 .319 .303 r
.56766 .3103 .57836 .31432 .59944 .31864 .58887 .31433 Metetra
0 .368 .272 r
.58887 .31433 .59944 .31864 .6209 .32483 .61044 .32018 Metetra
0 .423 .211 r
.61044 .32018 .6209 .32483 .64276 .33269 .63241 .32764 Metetra
0 .484 .114 r
.63241 .32764 .64276 .33269 .66506 .34194 .65481 .33643 Metetra
.024 .549 0 r
.65481 .33643 .66506 .34194 .68781 .35223 .67766 .34618 Metetra
.206 .616 0 r
.67766 .34618 .68781 .35223 .71102 .36315 .70096 .3565 Metetra
.429 .683 0 r
.70096 .3565 .71102 .36315 .73468 .37423 .7247 .36687 Metetra
.685 .749 0 r
.7247 .36687 .73468 .37423 .75876 .38488 .74885 .37672 Metetra
.812 .662 0 r
.74885 .37672 .75876 .38488 .7832 .39444 .77336 .38538 Metetra
.868 .496 0 r
.77336 .38538 .7832 .39444 .80793 .40214 .79814 .39207 Metetra
.916 .334 0 r
.79814 .39207 .80793 .40214 .83282 .40714 .82307 .39592 Metetra
.928 .291 0 r
.14828 .59532 .1621 .60361 .18214 .58687 .16834 .57975 Metetra
.884 .443 0 r
.16834 .57975 .18214 .58687 .20247 .56736 .18871 .56128 Metetra
.832 .606 0 r
.18871 .56128 .20247 .56736 .22296 .54587 .20929 .54071 Metetra
.773 .76 0 r
.20929 .54071 .22296 .54587 .24353 .52312 .22997 .51876 Metetra
.528 .71 0 r
.22997 .51876 .24353 .52312 .2641 .49975 .25067 .49608 Metetra
.299 .646 0 r
.25067 .49608 .2641 .49975 .28462 .47632 .27133 .47323 Metetra
.108 .581 0 r
.27133 .47323 .28462 .47632 .30505 .4533 .29193 .45072 Metetra
0 .519 .044 r
.29193 .45072 .30505 .4533 .32538 .43113 .31243 .42895 Metetra
0 .46 .156 r
.31243 .42895 .32538 .43113 .3456 .41016 .33283 .40831 Metetra
0 .407 .232 r
.33283 .40831 .3456 .41016 .36572 .39067 .35312 .38907 Metetra
0 .359 .279 r
.35312 .38907 .36572 .39067 .38574 .37291 .37333 .37151 Metetra
0 .319 .303 r
.37333 .37151 .38574 .37291 .4057 .35707 .39348 .35581 Metetra
0 .262 .287 r
.39348 .35581 .4057 .35707 .42563 .34332 .41359 .34212 Metetra
0 .214 .264 r
.41359 .34212 .42563 .34332 .44556 .33175 .4337 .33058 Metetra
0 .187 .25 r
.4337 .33058 .44556 .33175 .46553 .32245 .45384 .32125 Metetra
0 .178 .245 r
.45384 .32125 .46553 .32245 .4856 .31546 .47408 .31419 Metetra
0 .187 .25 r
.47408 .31419 .4856 .31546 .50579 .31079 .49443 .30939 Metetra
0 .214 .264 r
.49443 .30939 .50579 .31079 .52617 .30842 .51497 .30684 Metetra
0 .262 .287 r
.51497 .30684 .52617 .30842 .54677 .30829 .53573 .30647 Metetra
0 .319 .303 r
.53573 .30647 .54677 .30829 .56766 .3103 .55676 .30819 Metetra
0 .359 .279 r
.55676 .30819 .56766 .3103 .58887 .31433 .57811 .31186 Metetra
0 .407 .232 r
.57811 .31186 .58887 .31433 .61044 .32018 .59981 .31729 Metetra
0 .46 .156 r
.59981 .31729 .61044 .32018 .63241 .32764 .62191 .32425 Metetra
0 .519 .044 r
.62191 .32425 .63241 .32764 .65481 .33643 .64442 .33246 Metetra
.108 .581 0 r
.64442 .33246 .65481 .33643 .67766 .34618 .66738 .34154 Metetra
.299 .646 0 r
.66738 .34154 .67766 .34618 .70096 .3565 .69078 .35108 Metetra
.528 .71 0 r
.69078 .35108 .70096 .3565 .7247 .36687 .7146 .36057 Metetra
.773 .76 0 r
.7146 .36057 .7247 .36687 .74885 .37672 .73883 .36941 Metetra
.832 .606 0 r
.73883 .36941 .74885 .37672 .77336 .38538 .7634 .37693 Metetra
.884 .443 0 r
.7634 .37693 .77336 .38538 .79814 .39207 .78822 .38234 Metetra
.928 .291 0 r
.78822 .38234 .79814 .39207 .82307 .39592 .81318 .38477 Metetra
.941 .242 0 r
.13426 .58687 .14828 .59532 .16834 .57975 .15429 .57275 Metetra
.902 .381 0 r
.15429 .57275 .16834 .57975 .18871 .56128 .17468 .55558 Metetra
.855 .538 0 r
.17468 .55558 .18871 .56128 .20929 .54071 .19531 .53617 Metetra
.8 .693 0 r
.19531 .53617 .20929 .54071 .22997 .51876 .21607 .51523 Metetra
.652 .741 0 r
.21607 .51523 .22997 .51876 .25067 .49608 .23689 .49343 Metetra
.418 .68 0 r
.23689 .49343 .25067 .49608 .27133 .47323 .25769 .47133 Metetra
.216 .619 0 r
.25769 .47133 .27133 .47323 .29193 .45072 .27845 .44946 Metetra
.051 .56 0 r
.27845 .44946 .29193 .45072 .31243 .42895 .29912 .42823 Metetra
0 .504 .076 r
.29912 .42823 .31243 .42895 .33283 .40831 .31969 .40802 Metetra
0 .452 .169 r
.31969 .40802 .33283 .40831 .35312 .38907 .34018 .38913 Metetra
0 .407 .232 r
.34018 .38913 .35312 .38907 .37333 .37151 .36058 .37183 Metetra
0 .368 .272 r
.36058 .37183 .37333 .37151 .39348 .35581 .38092 .35632 Metetra
0 .337 .294 r
.38092 .35632 .39348 .35581 .41359 .34212 .40122 .34276 Metetra
0 .315 .305 r
.40122 .34276 .41359 .34212 .4337 .33058 .42152 .33127 Metetra
0 .292 .301 r
.42152 .33127 .4337 .33058 .45384 .32125 .44185 .32192 Metetra
0 .282 .296 r
.44185 .32192 .45384 .32125 .47408 .31419 .46227 .31478 Metetra
0 .292 .301 r
.46227 .31478 .47408 .31419 .49443 .30939 .48281 .30984 Metetra
0 .315 .305 r
.48281 .30984 .49443 .30939 .51497 .30684 .50352 .30708 Metetra
0 .337 .294 r
.50352 .30708 .51497 .30684 .53573 .30647 .52445 .30644 Metetra
0 .368 .272 r
.52445 .30644 .53573 .30647 .55676 .30819 .54564 .30781 Metetra
0 .407 .232 r
.54564 .30781 .55676 .30819 .57811 .31186 .56714 .31105 Metetra
0 .452 .169 r
.56714 .31105 .57811 .31186 .59981 .31729 .58899 .31597 Metetra
0 .504 .076 r
.58899 .31597 .59981 .31729 .62191 .32425 .61123 .32233 Metetra
.051 .56 0 r
.61123 .32233 .62191 .32425 .64442 .33246 .63387 .32982 Metetra
.216 .619 0 r
.63387 .32982 .64442 .33246 .66738 .34154 .65694 .33809 Metetra
.418 .68 0 r
.65694 .33809 .66738 .34154 .69078 .35108 .68044 .34668 Metetra
.652 .741 0 r
.68044 .34668 .69078 .35108 .7146 .36057 .70436 .35509 Metetra
.8 .693 0 r
.70436 .35509 .7146 .36057 .73883 .36941 .72866 .3627 Metetra
.855 .538 0 r
.72866 .3627 .73883 .36941 .7634 .37693 .75328 .36883 Metetra
.902 .381 0 r
.75328 .36883 .7634 .37693 .78822 .38234 .77814 .37268 Metetra
.941 .242 0 r
.77814 .37268 .78822 .38234 .81318 .38477 .8031 .37338 Metetra
.953 .193 0 r
.12007 .57793 .13426 .58687 .15429 .57275 .14001 .56556 Metetra
.921 .314 0 r
.14001 .56556 .15429 .57275 .17468 .55558 .16038 .54996 Metetra
.879 .46 0 r
.16038 .54996 .17468 .55558 .19531 .53617 .18103 .53194 Metetra
.83 .612 0 r
.18103 .53194 .19531 .53617 .21607 .51523 .20186 .51224 Metetra
.776 .754 0 r
.20186 .51224 .21607 .51523 .23689 .49343 .22277 .49152 Metetra
.562 .719 0 r
.22277 .49152 .23689 .49343 .25769 .47133 .2437 .47035 Metetra
.353 .662 0 r
.2437 .47035 .25769 .47133 .27845 .44946 .2646 .44927 Metetra
.176 .606 0 r
.2646 .44927 .27845 .44946 .29912 .42823 .28543 .42871 Metetra
.033 .552 0 r
.28543 .42871 .29912 .42823 .31969 .40802 .30619 .40905 Metetra
0 .504 .076 r
.30619 .40905 .31969 .40802 .34018 .38913 .32686 .39061 Metetra
0 .46 .156 r
.32686 .39061 .34018 .38913 .36058 .37183 .34746 .37366 Metetra
0 .423 .211 r
.34746 .37366 .36058 .37183 .38092 .35632 .36799 .3584 Metetra
0 .394 .247 r
.36799 .3584 .38092 .35632 .40122 .34276 .3885 .345 Metetra
0 .372 .268 r
.3885 .345 .40122 .34276 .42152 .33127 .409 .33359 Metetra
0 .359 .279 r
.409 .33359 .42152 .33127 .44185 .32192 .42954 .32425 Metetra
0 .355 .282 r
.42954 .32425 .44185 .32192 .46227 .31478 .45015 .31703 Metetra
0 .359 .279 r
.45015 .31703 .46227 .31478 .48281 .30984 .47089 .31193 Metetra
0 .372 .268 r
.47089 .31193 .48281 .30984 .50352 .30708 .49179 .30894 Metetra
0 .394 .247 r
.49179 .30894 .50352 .30708 .52445 .30644 .5129 .30797 Metetra
0 .423 .211 r
.5129 .30797 .52445 .30644 .54564 .30781 .53427 .30893 Metetra
0 .46 .156 r
.53427 .30893 .54564 .30781 .56714 .31105 .55594 .31167 Metetra
0 .504 .076 r
.55594 .31167 .56714 .31105 .58899 .31597 .57795 .31598 Metetra
.033 .552 0 r
.57795 .31598 .58899 .31597 .61123 .32233 .60034 .32161 Metetra
.176 .606 0 r
.60034 .32161 .61123 .32233 .63387 .32982 .62312 .32826 Metetra
.353 .662 0 r
.62312 .32826 .63387 .32982 .65694 .33809 .64632 .33554 Metetra
.562 .719 0 r
.64632 .33554 .65694 .33809 .68044 .34668 .66993 .34301 Metetra
.776 .754 0 r
.66993 .34301 .68044 .34668 .70436 .35509 .69394 .35013 Metetra
.83 .612 0 r
.69394 .35013 .70436 .35509 .72866 .3627 .71831 .35628 Metetra
.879 .46 0 r
.71831 .35628 .72866 .3627 .75328 .36883 .74298 .36075 Metetra
.921 .314 0 r
.74298 .36075 .75328 .36883 .77814 .37268 .76786 .36276 Metetra
.953 .193 0 r
.76786 .36276 .77814 .37268 .8031 .37338 .79282 .36141 Metetra
.964 .149 0 r
.10574 .56812 .12007 .57793 .14001 .56556 .12555 .55779 Metetra
.94 .246 0 r
.12555 .55779 .14001 .56556 .16038 .54996 .14585 .54404 Metetra
.904 .376 0 r
.14585 .54404 .16038 .54996 .18103 .53194 .16648 .52768 Metetra
.861 .52 0 r
.16648 .52768 .18103 .53194 .20186 .51224 .18734 .50945 Metetra
.812 .662 0 r
.18734 .50945 .20186 .51224 .22277 .49152 .20832 .49001 Metetra
.73 .76 0 r
.20832 .49001 .22277 .49152 .2437 .47035 .22935 .46997 Metetra
.517 .707 0 r
.22935 .46997 .2437 .47035 .2646 .44927 .25038 .44985 Metetra
.331 .655 0 r
.25038 .44985 .2646 .44927 .28543 .42871 .27137 .4301 Metetra
.176 .606 0 r
.27137 .4301 .28543 .42871 .30619 .40905 .2923 .41112 Metetra
.051 .56 0 r
.2923 .41112 .30619 .40905 .32686 .39061 .31316 .39323 Metetra
0 .519 .044 r
.31316 .39323 .32686 .39061 .34746 .37366 .33396 .37671 Metetra
0 .484 .114 r
.33396 .37671 .34746 .37366 .36799 .3584 .3547 .36177 Metetra
0 .456 .163 r
.3547 .36177 .36799 .3584 .3885 .345 .37541 .34859 Metetra
0 .436 .194 r
.37541 .34859 .3885 .345 .409 .33359 .39613 .33729 Metetra
0 .423 .211 r
.39613 .33729 .409 .33359 .42954 .32425 .41688 .32797 Metetra
0 .419 .217 r
.41688 .32797 .42954 .32425 .45015 .31703 .4377 .32067 Metetra
0 .423 .211 r
.4377 .32067 .45015 .31703 .47089 .31193 .45865 .31541 Metetra
0 .436 .194 r
.45865 .31541 .47089 .31193 .49179 .30894 .47975 .31214 Metetra
0 .456 .163 r
.47975 .31214 .49179 .30894 .5129 .30797 .50106 .3108 Metetra
0 .484 .114 r
.50106 .3108 .5129 .30797 .53427 .30893 .52262 .31128 Metetra
0 .519 .044 r
.52262 .31128 .53427 .30893 .55594 .31167 .54448 .31343 Metetra
.051 .56 0 r
.54448 .31343 .55594 .31167 .57795 .31598 .56666 .31702 Metetra
.176 .606 0 r
.56666 .31702 .57795 .31598 .60034 .32161 .58921 .32181 Metetra
.331 .655 0 r
.58921 .32181 .60034 .32161 .62312 .32826 .61215 .32746 Metetra
.517 .707 0 r
.61215 .32746 .62312 .32826 .64632 .33554 .63548 .33358 Metetra
.73 .76 0 r
.63548 .33358 .64632 .33554 .66993 .34301 .65921 .33972 Metetra
.812 .662 0 r
.65921 .33972 .66993 .34301 .69394 .35013 .68331 .34532 Metetra
.861 .52 0 r
.68331 .34532 .69394 .35013 .71831 .35628 .70776 .34976 Metetra
.904 .376 0 r
.70776 .34976 .71831 .35628 .74298 .36075 .73247 .35231 Metetra
.94 .246 0 r
.73247 .35231 .74298 .36075 .76786 .36276 .75736 .35217 Metetra
.964 .149 0 r
.75736 .35217 .76786 .36276 .79282 .36141 .7823 .34845 Metetra
.973 .116 0 r
.09135 .55697 .10574 .56812 .12555 .55779 .11097 .54899 Metetra
.956 .183 0 r
.11097 .54899 .12555 .55779 .14585 .54404 .13114 .53738 Metetra
.928 .29 0 r
.13114 .53738 .14585 .54404 .16648 .52768 .15171 .52294 Metetra
.891 .42 0 r
.15171 .52294 .16648 .52768 .18734 .50945 .17255 .50643 Metetra
.849 .556 0 r
.17255 .50643 .18734 .50945 .20832 .49001 .19357 .48851 Metetra
.803 .687 0 r
.19357 .48851 .20832 .49001 .22935 .46997 .21468 .46979 Metetra
.708 .755 0 r
.21468 .46979 .22935 .46997 .25038 .44985 .23582 .45081 Metetra
.517 .707 0 r
.23582 .45081 .25038 .44985 .27137 .4301 .25695 .43204 Metetra
.353 .662 0 r
.25695 .43204 .27137 .4301 .2923 .41112 .27805 .41387 Metetra
.216 .619 0 r
.27805 .41387 .2923 .41112 .31316 .39323 .29909 .39664 Metetra
.108 .581 0 r
.29909 .39664 .31316 .39323 .33396 .37671 .32008 .38064 Metetra
.024 .549 0 r
.32008 .38064 .33396 .37671 .3547 .36177 .34103 .3661 Metetra
0 .523 .036 r
.34103 .3661 .3547 .36177 .37541 .34859 .36196 .35319 Metetra
0 .504 .076 r
.36196 .35319 .37541 .34859 .39613 .33729 .38289 .34204 Metetra
0 .492 .099 r
.38289 .34204 .39613 .33729 .41688 .32797 .40386 .33276 Metetra
0 .488 .107 r
.40386 .33276 .41688 .32797 .4377 .32067 .42491 .32539 Metetra
0 .492 .099 r
.42491 .32539 .4377 .32067 .45865 .31541 .44607 .31993 Metetra
0 .504 .076 r
.44607 .31993 .45865 .31541 .47975 .31214 .46739 .31635 Metetra
0 .523 .036 r
.46739 .31635 .47975 .31214 .50106 .3108 .48891 .31459 Metetra
.024 .549 0 r
.48891 .31459 .50106 .3108 .52262 .31128 .51068 .31451 Metetra
.108 .581 0 r
.51068 .31451 .52262 .31128 .54448 .31343 .53273 .31597 Metetra
.216 .619 0 r
.53273 .31597 .54448 .31343 .56666 .31702 .5551 .31873 Metetra
.353 .662 0 r
.5551 .31873 .56666 .31702 .58921 .32181 .57782 .32252 Metetra
.517 .707 0 r
.57782 .32252 .58921 .32181 .61215 .32746 .60092 .32701 Metetra
.708 .755 0 r
.60092 .32701 .61215 .32746 .63548 .33358 .62439 .3318 Metetra
.803 .687 0 r
.62439 .3318 .63548 .33358 .65921 .33972 .64824 .33639 Metetra
.849 .556 0 r
.64824 .33639 .65921 .33972 .68331 .34532 .67244 .34024 Metetra
.891 .42 0 r
.67244 .34024 .68331 .34532 .70776 .34976 .69696 .34269 Metetra
.928 .29 0 r
.69696 .34269 .70776 .34976 .73247 .35231 .72171 .34303 Metetra
.956 .183 0 r
.72171 .34303 .73247 .35231 .75736 .35217 .7466 .34043 Metetra
.973 .116 0 r
.7466 .34043 .75736 .35217 .7823 .34845 .7715 .33402 Metetra
.976 .102 0 r
.07698 .54396 .09135 .55697 .11097 .54899 .09633 .53864 Metetra
.968 .133 0 r
.09633 .53864 .11097 .54899 .13114 .53738 .11631 .52947 Metetra
.949 .211 0 r
.11631 .52947 .13114 .53738 .15171 .52294 .13676 .51724 Metetra
.92 .319 0 r
.13676 .51724 .15171 .52294 .17255 .50643 .15754 .5027 Metetra
.884 .443 0 r
.15754 .5027 .17255 .50643 .19357 .48851 .17856 .48653 Metetra
.845 .569 0 r
.17856 .48653 .19357 .48851 .21468 .46979 .19971 .46935 Metetra
.803 .687 0 r
.19971 .46935 .21468 .46979 .23582 .45081 .22094 .4517 Metetra
.73 .76 0 r
.22094 .4517 .23582 .45081 .25695 .43204 .24219 .43407 Metetra
.562 .719 0 r
.24219 .43407 .25695 .43204 .27805 .41387 .26343 .41686 Metetra
.418 .68 0 r
.26343 .41686 .27805 .41387 .29909 .39664 .28464 .40042 Metetra
.299 .646 0 r
.28464 .40042 .29909 .39664 .32008 .38064 .30582 .38504 Metetra
.206 .616 0 r
.30582 .38504 .32008 .38064 .34103 .3661 .32698 .37097 Metetra
.136 .592 0 r
.32698 .37097 .34103 .3661 .36196 .35319 .34812 .35839 Metetra
.088 .574 0 r
.34812 .35839 .36196 .35319 .38289 .34204 .36928 .34744 Metetra
.061 .563 0 r
.36928 .34744 .38289 .34204 .40386 .33276 .39047 .33822 Metetra
.051 .56 0 r
.39047 .33822 .40386 .33276 .42491 .32539 .41175 .33076 Metetra
.061 .563 0 r
.41175 .33076 .42491 .32539 .44607 .31993 .43314 .32509 Metetra
.088 .574 0 r
.43314 .32509 .44607 .31993 .46739 .31635 .45469 .32117 Metetra
.136 .592 0 r
.45469 .32117 .46739 .31635 .48891 .31459 .47644 .31892 Metetra
.206 .616 0 r
.47644 .31892 .48891 .31459 .51068 .31451 .49842 .3182 Metetra
.299 .646 0 r
.49842 .3182 .51068 .31451 .53273 .31597 .52068 .31886 Metetra
.418 .68 0 r
.52068 .31886 .53273 .31597 .5551 .31873 .54325 .32066 Metetra
.562 .719 0 r
.54325 .32066 .5551 .31873 .57782 .32252 .56615 .32331 Metetra
.73 .76 0 r
.56615 .32331 .57782 .32252 .60092 .32701 .58941 .32646 Metetra
.803 .687 0 r
.58941 .32646 .60092 .32701 .62439 .3318 .61304 .3297 Metetra
.845 .569 0 r
.61304 .3297 .62439 .3318 .64824 .33639 .63701 .33252 Metetra
.884 .443 0 r
.63701 .33252 .64824 .33639 .67244 .34024 .66131 .33436 Metetra
.92 .319 0 r
.66131 .33436 .67244 .34024 .69696 .34269 .68589 .33456 Metetra
.949 .211 0 r
.68589 .33456 .69696 .34269 .72171 .34303 .71067 .33238 Metetra
.968 .133 0 r
.71067 .33238 .72171 .34303 .7466 .34043 .73555 .327 Metetra
.976 .102 0 r
.73555 .327 .7466 .34043 .7715 .33402 .76038 .31754 Metetra
.973 .115 0 r
.06273 .52851 .07698 .54396 .09633 .53864 .08173 .52616 Metetra
.975 .105 0 r
.08173 .52616 .09633 .53864 .11631 .52947 .10144 .51972 Metetra
.965 .146 0 r
.10144 .51972 .11631 .52947 .13676 .51724 .12171 .50998 Metetra
.945 .226 0 r
.12171 .50998 .13676 .51724 .15754 .5027 .14238 .49768 Metetra
.917 .329 0 r
.14238 .49768 .15754 .5027 .17856 .48653 .16334 .48352 Metetra
.884 .443 0 r
.16334 .48352 .17856 .48653 .19971 .46935 .1845 .4681 Metetra
.849 .556 0 r
.1845 .4681 .19971 .46935 .22094 .4517 .20577 .45199 Metetra
.812 .662 0 r
.20577 .45199 .22094 .4517 .24219 .43407 .22712 .43567 Metetra
.776 .754 0 r
.22712 .43567 .24219 .43407 .26343 .41686 .24848 .41958 Metetra
.652 .741 0 r
.24848 .41958 .26343 .41686 .28464 .40042 .26985 .40406 Metetra
.528 .71 0 r
.26985 .40406 .28464 .40042 .30582 .38504 .29121 .38942 Metetra
.429 .683 0 r
.29121 .38942 .30582 .38504 .32698 .37097 .31256 .37591 Metetra
.353 .662 0 r
.31256 .37591 .32698 .37097 .34812 .35839 .33392 .36373 Metetra
.299 .646 0 r
.33392 .36373 .34812 .35839 .36928 .34744 .35529 .35301 Metetra
.268 .636 0 r
.35529 .35301 .36928 .34744 .39047 .33822 .37672 .34386 Metetra
.257 .632 0 r
.37672 .34386 .39047 .33822 .41175 .33076 .39823 .33633 Metetra
.268 .636 0 r
.39823 .33633 .41175 .33076 .43314 .32509 .41986 .33043 Metetra
.299 .646 0 r
.41986 .33043 .43314 .32509 .45469 .32117 .44165 .32611 Metetra
.353 .662 0 r
.44165 .32611 .45469 .32117 .47644 .31892 .46362 .32329 Metetra
.429 .683 0 r
.46362 .32329 .47644 .31892 .49842 .3182 .48583 .32185 Metetra
.528 .71 0 r
.48583 .32185 .49842 .3182 .52068 .31886 .50831 .3216 Metetra
.652 .741 0 r
.50831 .3216 .52068 .31886 .54325 .32066 .53109 .32229 Metetra
.776 .754 0 r
.53109 .32229 .54325 .32066 .56615 .32331 .55418 .32363 Metetra
.812 .662 0 r
.55418 .32363 .56615 .32331 .58941 .32646 .57762 .32525 Metetra
.849 .556 0 r
.57762 .32525 .58941 .32646 .61304 .3297 .60139 .32673 Metetra
.884 .443 0 r
.60139 .32673 .61304 .3297 .63701 .33252 .62549 .32754 Metetra
.917 .329 0 r
.62549 .32754 .63701 .33252 .66131 .33436 .64988 .3271 Metetra
.945 .226 0 r
.64988 .3271 .66131 .33436 .68589 .33456 .67452 .32475 Metetra
.965 .146 0 r
.67452 .32475 .68589 .33456 .71067 .33238 .69932 .31974 Metetra
.975 .105 0 r
.69932 .31974 .71067 .33238 .73555 .327 .72417 .31125 Metetra
.973 .115 0 r
.72417 .31125 .73555 .327 .76038 .31754 .74893 .29842 Metetra
.961 .164 0 r
.04872 .50997 .06273 .52851 .08173 .52616 .06728 .51089 Metetra
.974 .108 0 r
.06728 .51089 .08173 .52616 .10144 .51972 .08665 .50748 Metetra
.974 .108 0 r
.08665 .50748 .10144 .51972 .12171 .50998 .10665 .50052 Metetra
.964 .151 0 r
.10665 .50052 .12171 .50998 .14238 .49768 .12714 .49074 Metetra
.945 .226 0 r
.12714 .49074 .14238 .49768 .16334 .48352 .14799 .47883 Metetra
.92 .319 0 r
.14799 .47883 .16334 .48352 .1845 .4681 .1691 .46541 Metetra
.891 .42 0 r
.1691 .46541 .1845 .4681 .20577 .45199 .19039 .45105 Metetra
.861 .52 0 r
.19039 .45105 .20577 .45199 .22712 .43567 .21179 .43624 Metetra
.83 .612 0 r
.21179 .43624 .22712 .43567 .24848 .41958 .23325 .42143 Metetra
.8 .693 0 r
.23325 .42143 .24848 .41958 .26985 .40406 .25475 .40697 Metetra
.773 .76 0 r
.25475 .40697 .26985 .40406 .29121 .38942 .27627 .39319 Metetra
.685 .749 0 r
.27627 .39319 .29121 .38942 .31256 .37591 .29781 .38034 Metetra
.607 .73 0 r
.29781 .38034 .31256 .37591 .33392 .36373 .31937 .36862 Metetra
.551 .716 0 r
.31937 .36862 .33392 .36373 .35529 .35301 .34096 .35819 Metetra
.517 .707 0 r
.34096 .35819 .35529 .35301 .37672 .34386 .36262 .34914 Metetra
.506 .704 0 r
.36262 .34914 .37672 .34386 .39823 .33633 .38437 .34152 Metetra
.517 .707 0 r
.38437 .34152 .39823 .33633 .41986 .33043 .40624 .33536 Metetra
.551 .716 0 r
.40624 .33536 .41986 .33043 .44165 .32611 .42826 .33059 Metetra
.607 .73 0 r
.42826 .33059 .44165 .32611 .46362 .32329 .45048 .32714 Metetra
.685 .749 0 r
.45048 .32714 .46362 .32329 .48583 .32185 .47292 .32487 Metetra
.773 .76 0 r
.47292 .32487 .48583 .32185 .50831 .3216 .49562 .32357 Metetra
.8 .693 0 r
.49562 .32357 .50831 .3216 .53109 .32229 .51861 .32301 Metetra
.83 .612 0 r
.51861 .32301 .53109 .32229 .55418 .32363 .5419 .32286 Metetra
.861 .52 0 r
.5419 .32286 .55418 .32363 .57762 .32525 .56551 .32275 Metetra
.891 .42 0 r
.56551 .32275 .57762 .32525 .60139 .32673 .58944 .32222 Metetra
.92 .319 0 r
.58944 .32222 .60139 .32673 .62549 .32754 .61366 .32076 Metetra
.945 .226 0 r
.61366 .32076 .62549 .32754 .64988 .3271 .63815 .31777 Metetra
.964 .151 0 r
.63815 .31777 .64988 .3271 .67452 .32475 .66284 .31257 Metetra
.974 .108 0 r
.66284 .31257 .67452 .32475 .69932 .31974 .68764 .30442 Metetra
.974 .108 0 r
.68764 .30442 .69932 .31974 .72417 .31125 .71244 .2925 Metetra
.961 .164 0 r
.71244 .2925 .72417 .31125 .74893 .29842 .7371 .27596 Metetra
.937 .255 0 r
.03509 .48764 .04872 .50997 .06728 .51089 .05312 .49212 Metetra
.963 .153 0 r
.05312 .49212 .06728 .51089 .08665 .50748 .07205 .49203 Metetra
.975 .107 0 r
.07205 .49203 .08665 .50748 .10665 .50052 .09171 .48813 Metetra
.974 .108 0 r
.09171 .48813 .10665 .50052 .12714 .49074 .11195 .48114 Metetra
.965 .146 0 r
.11195 .48114 .12714 .49074 .14799 .47883 .13262 .47175 Metetra
.949 .211 0 r
.13262 .47175 .14799 .47883 .1691 .46541 .15362 .46057 Metetra
.928 .29 0 r
.15362 .46057 .1691 .46541 .19039 .45105 .17487 .44818 Metetra
.904 .376 0 r
.17487 .44818 .19039 .45105 .21179 .43624 .19628 .43508 Metetra
.879 .46 0 r
.19628 .43508 .21179 .43624 .23325 .42143 .2178 .42172 Metetra
.855 .538 0 r
.2178 .42172 .23325 .42143 .25475 .40697 .2394 .40848 Metetra
.832 .606 0 r
.2394 .40848 .25475 .40697 .27627 .39319 .26106 .39568 Metetra
.812 .662 0 r
.26106 .39568 .27627 .39319 .29781 .38034 .28276 .38359 Metetra
.795 .705 0 r
.28276 .38359 .29781 .38034 .31937 .36862 .30451 .37241 Metetra
.783 .736 0 r
.30451 .37241 .31937 .36862 .34096 .35819 .32632 .3623 Metetra
.776 .754 0 r
.32632 .3623 .34096 .35819 .36262 .34914 .3482 .35337 Metetra
.773 .76 0 r
.3482 .35337 .36262 .34914 .38437 .34152 .37018 .34567 Metetra
.776 .754 0 r
.37018 .34567 .38437 .34152 .40624 .33536 .39229 .33921 Metetra
.783 .736 0 r
.39229 .33921 .40624 .33536 .42826 .33059 .41455 .33395 Metetra
.795 .705 0 r
.41455 .33395 .42826 .33059 .45048 .32714 .43701 .32978 Metetra
.812 .662 0 r
.43701 .32978 .45048 .32714 .47292 .32487 .45969 .32656 Metetra
.832 .606 0 r
.45969 .32656 .47292 .32487 .49562 .32357 .48262 .32409 Metetra
.855 .538 0 r
.48262 .32409 .49562 .32357 .51861 .32301 .50582 .32211 Metetra
.879 .46 0 r
.50582 .32211 .51861 .32301 .5419 .32286 .52931 .32028 Metetra
.904 .376 0 r
.52931 .32028 .5419 .32286 .56551 .32275 .5531 .31821 Metetra
.928 .29 0 r
.5531 .31821 .56551 .32275 .58944 .32222 .57718 .31545 Metetra
.949 .211 0 r
.57718 .31545 .58944 .32222 .61366 .32076 .60153 .31145 Metetra
.965 .146 0 r
.60153 .31145 .61366 .32076 .63815 .31777 .62609 .30562 Metetra
.974 .108 0 r
.62609 .30562 .63815 .31777 .66284 .31257 .65082 .29727 Metetra
.975 .107 0 r
.65082 .29727 .66284 .31257 .68764 .30442 .67561 .28566 Metetra
.963 .153 0 r
.67561 .28566 .68764 .30442 .71244 .2925 .70035 .26999 Metetra
.937 .255 0 r
.70035 .26999 .71244 .2925 .7371 .27596 .72488 .24944 Metetra
.9 .391 0 r
.02201 .46078 .03509 .48764 .05312 .49212 .03941 .46908 Metetra
.939 .247 0 r
.03941 .46908 .05312 .49212 .07205 .49203 .05781 .47259 Metetra
.963 .153 0 r
.05781 .47259 .07205 .49203 .09171 .48813 .07703 .47202 Metetra
.974 .108 0 r
.07703 .47202 .09171 .48813 .11195 .48114 .09692 .46809 Metetra
.975 .105 0 r
.09692 .46809 .11195 .48114 .13262 .47175 .11734 .46147 Metetra
.968 .133 0 r
.11734 .46147 .13262 .47175 .15362 .46057 .13817 .45277 Metetra
.956 .183 0 r
.13817 .45277 .15362 .46057 .17487 .44818 .15931 .44258 Metetra
.94 .246 0 r
.15931 .44258 .17487 .44818 .19628 .43508 .18068 .43139 Metetra
.921 .314 0 r
.18068 .43139 .19628 .43508 .2178 .42172 .20222 .41967 Metetra
.902 .381 0 r
.20222 .41967 .2178 .42172 .2394 .40848 .22389 .4078 Metetra
.884 .443 0 r
.22389 .4078 .2394 .40848 .26106 .39568 .24565 .39611 Metetra
.868 .496 0 r
.24565 .39611 .26106 .39568 .28276 .38359 .26749 .38487 Metetra
.855 .538 0 r
.26749 .38487 .28276 .38359 .30451 .37241 .28941 .37431 Metetra
.845 .569 0 r
.28941 .37431 .30451 .37241 .32632 .3623 .3114 .36458 Metetra
.838 .587 0 r
.3114 .36458 .32632 .3623 .3482 .35337 .3335 .3558 Metetra
.836 .593 0 r
.3335 .3558 .3482 .35337 .37018 .34567 .3557 .34801 Metetra
.838 .587 0 r
.3557 .34801 .37018 .34567 .39229 .33921 .37804 .34122 Metetra
.845 .569 0 r
.37804 .34122 .39229 .33921 .41455 .33395 .40055 .33539 Metetra
.855 .538 0 r
.40055 .33539 .41455 .33395 .43701 .32978 .42325 .33042 Metetra
.868 .496 0 r
.42325 .33042 .43701 .32978 .45969 .32656 .44616 .32614 Metetra
.884 .443 0 r
.44616 .32614 .45969 .32656 .48262 .32409 .46932 .32235 Metetra
.902 .381 0 r
.46932 .32235 .48262 .32409 .50582 .32211 .49274 .31877 Metetra
.921 .314 0 r
.49274 .31877 .50582 .32211 .52931 .32028 .51643 .31506 Metetra
.94 .246 0 r
.51643 .31506 .52931 .32028 .5531 .31821 .5404 .31082 Metetra
.956 .183 0 r
.5404 .31082 .5531 .31821 .57718 .31545 .56462 .30557 Metetra
.968 .133 0 r
.56462 .30557 .57718 .31545 .60153 .31145 .58908 .29877 Metetra
.975 .105 0 r
.58908 .29877 .60153 .31145 .62609 .30562 .61372 .28981 Metetra
.974 .108 0 r
.61372 .28981 .62609 .30562 .65082 .29727 .63847 .27802 Metetra
.963 .153 0 r
.63847 .27802 .65082 .29727 .67561 .28566 .66323 .26265 Metetra
.939 .247 0 r
.66323 .26265 .67561 .28566 .70035 .26999 .68788 .24294 Metetra
.9 .391 0 r
.68788 .24294 .70035 .26999 .72488 .24944 .71226 .21808 Metetra
.846 .566 0 r
.00967 .42863 .02201 .46078 .03941 .46908 .02632 .44098 Metetra
.9 .391 0 r
.02632 .44098 .03941 .46908 .05781 .47259 .04409 .44832 Metetra
.937 .255 0 r
.04409 .44832 .05781 .47259 .07703 .47202 .06278 .45134 Metetra
.961 .164 0 r
.06278 .45134 .07703 .47202 .09692 .46809 .08224 .45072 Metetra
.973 .115 0 r
.08224 .45072 .09692 .46809 .11734 .46147 .10232 .44711 Metetra
.976 .102 0 r
.10232 .44711 .11734 .46147 .13817 .45277 .12289 .44114 Metetra
.973 .116 0 r
.12289 .44114 .13817 .45277 .15931 .44258 .14385 .43336 Metetra
.964 .149 0 r
.14385 .43336 .15931 .44258 .18068 .43139 .16512 .42429 Metetra
.953 .193 0 r
.16512 .42429 .18068 .43139 .20222 .41967 .18662 .41438 Metetra
.941 .242 0 r
.18662 .41438 .20222 .41967 .22389 .4078 .2083 .40404 Metetra
.928 .291 0 r
.2083 .40404 .22389 .4078 .24565 .39611 .23013 .3936 Metetra
.916 .334 0 r
.23013 .3936 .24565 .39611 .26749 .38487 .25208 .38333 Metetra
.906 .371 0 r
.25208 .38333 .26749 .38487 .28941 .37431 .27414 .37346 Metetra
.898 .398 0 r
.27414 .37346 .28941 .37431 .3114 .36458 .2963 .36416 Metetra
.893 .415 0 r
.2963 .36416 .3114 .36458 .3335 .3558 .31859 .35554 Metetra
.891 .42 0 r
.31859 .35554 .3335 .3558 .3557 .34801 .341 .34766 Metetra
.893 .415 0 r
.341 .34766 .3557 .34801 .37804 .34122 .36357 .34051 Metetra
.898 .398 0 r
.36357 .34051 .37804 .34122 .40055 .33539 .3863 .33405 Metetra
.906 .371 0 r
.3863 .33405 .40055 .33539 .42325 .33042 .40923 .32818 Metetra
.916 .334 0 r
.40923 .32818 .42325 .33042 .44616 .32614 .43238 .32272 Metetra
.928 .291 0 r
.43238 .32272 .44616 .32614 .46932 .32235 .45576 .31745 Metetra
.941 .242 0 r
.45576 .31745 .46932 .32235 .49274 .31877 .47939 .3121 Metetra
.953 .193 0 r
.47939 .3121 .49274 .31877 .51643 .31506 .50328 .3063 Metetra
.964 .149 0 r
.50328 .3063 .51643 .31506 .5404 .31082 .52741 .29965 Metetra
.973 .116 0 r
.52741 .29965 .5404 .31082 .56462 .30557 .55178 .29167 Metetra
.976 .102 0 r
.55178 .29167 .56462 .30557 .58908 .29877 .57634 .2818 Metetra
.973 .115 0 r
.57634 .2818 .58908 .29877 .61372 .28981 .60103 .26944 Metetra
.961 .164 0 r
.60103 .26944 .61372 .28981 .63847 .27802 .62579 .25392 Metetra
.937 .255 0 r
.62579 .25392 .63847 .27802 .66323 .26265 .65051 .23453 Metetra
.9 .391 0 r
.65051 .23453 .66323 .26265 .68788 .24294 .67505 .21052 Metetra
.846 .566 0 r
.67505 .21052 .68788 .24294 .71226 .21808 .69925 .18112 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.08206 .23755 m
.08679 .24211 L
s
[(-10)] .07261 .22845 1 .96289 Mshowa
.27211 .16314 m
.27652 .16799 L
s
[(-5)] .26329 .15343 .90843 1 Mshowa
.477 .08291 m
.48103 .08809 L
s
[(0)] .46894 .07256 .77832 1 Mshowa
.125 Mabswid
.11896 .22311 m
.12176 .22587 L
s
.1564 .20844 m
.15917 .21125 L
s
.1944 .19357 m
.19713 .19641 L
s
.23297 .17847 m
.23565 .18134 L
s
.31185 .14758 m
.31445 .15053 L
s
.35219 .13178 m
.35475 .13477 L
s
.39315 .11574 m
.39567 .11877 L
s
.43475 .09945 m
.43722 .10252 L
s
.51991 .06611 m
.52228 .06925 L
s
.5635 .04904 m
.56582 .05222 L
s
.60779 .03169 m
.61005 .03492 L
s
.6528 .01407 m
.655 .01734 L
s
.04569 .2518 m
.04856 .25449 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oa_ooool2
o`0005Sooooo0033ooooo`?o000000?oooooo`000?ooool0Eoooool00<7ooooo0_l00004ooooo`;o
0000Eoooool00;kooooo0ol00006ooooo`03o`000?oooooo000005Kooooo002kooooo`?o00002Ooo
ool00ol0003oooooo`00001Fooooo`00^Oooool2o`0000;ooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool0001Eooooo`00]_ooool3o`0000kooooo00Go0000ooooooooooooooooo`00
001Dooooo`00]?ooool2o`00017ooooo00Go0000ooooooooooooooooo`00001Dooooo`00/Oooool3
o`0001?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Aooooo`00[oooool3o`00
01Gooooo00Co0000oooooooooooooooo0ol0001Booooo`00[?ooool3o`0001Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1@ooooo`00ZOooool3o`0001_ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1?ooooo`00R?ooool2o`0001gooooo0_l0000Oooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0C_ooool008Oooooo00Co0000oooooooooooo0000
6Oooool3o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1>ooooo`00Qooo
ool01?l0003oooooooooool0000Gooooo`;o000000?oooooo`000?ooool08Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04gooooo0027ooooo`04o`000?ooooooooooo`0001Cooooo
0ol0000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0C?ooool008Oooooo00Co
0000oooooooooooo00004_ooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1<ooooo`00Qoooool01?l0003oooooooooool0000?ooooo`?o0000:oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04_ooooo0028ooooo`;o00003_ooool2o`0002kooooo00?o
0000ooooooooool01_ooool2o`0004gooooo002Eooooo`?o000000?oooooo`000?ooool0;Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo04[ooooo002Booooo`?o0000<oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0ol0000kooooo`00T?ooool2o`0003Ko
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooooooo
ool00000>_ooool008gooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00oooool5o`0000Gooooo00?o0000ooooooooool0>?ooool008_ooooo0ol0000jooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0hooooo`00R?oo
ool3o`0000?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Sooooo1?l0000kooooo`00Q_ooool2o`00043ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo0023ooooo`?o0000@_ooool00ol0
003oooooooooo`0<ooooo`;o00002?ooool5o`0003[ooooo0020ooooo`?o0000AOooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooo000004Oooooo001nooooo`;o00000_ooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0A?ooool007_ooooo0ol0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@oooool007Wooooo0_l0001=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@oooool007Kooooo0ol0001?oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@_ooool007Cooooo0_l000000ooooooo
0000ooooo`1?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@Oooool0077ooooo
0ol0001Dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@Oooool004oooooo0ol0
000Looooo`?o0000F?ooool00ol0003oooooooooo`0@ooooo`;o0000@_ooool004kooooo00Go0000
ooooooooooooooooo`00000Iooooo`;o0000Foooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo03oooooo0018ooooo`Go00001Oooool00ol0003oooooooooo`0Dooooo`?o0000GOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo03oooooo001Booooo`03o`000?oooooooooo
01;ooooo0_l00003ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0nooooo`00C_ooool4o`0001;ooooo0ol0001Rooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0?Oooool004kooooo00?o0000ooooooooool04Oooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0mooooo`00C_ooool5o`0000cooooo0ol0
001Wooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0??ooool005gooooo0_l00002
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0k
ooooo`00F_ooool3o`0006cooooo00?o0000ooooooooool05Oooool2o`0003gooooo001Gooooo`?o
0000Koooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03[ooooo001Eooooo`;o0000
L_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Wooooo001Booooo`?o000000?o
ooooo`000?ooool0LOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Wooooo001@
ooooo`;o00001Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0>?ooool004gooooo0ol0001iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0>?ooool004_ooooo0_l0001looooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0=oooool004Sooooo0ol000000ooooooo0000ooooo`1kooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0=_ooool004Gooooo0ol00021ooooo`03o`000?oooooooooo01[ooooo0_l0
000hooooo`00@oooool2o`0008?ooooo0ol0000Mooooo`03o`000?oooooooooo03Gooooo0010oooo
o`?o0000Q?ooool01?l0003of900o`000?l0000Nooooo`03o`000?oooooooooo03Cooooo000noooo
o`;o000000?oooooo`000?ooool0Poooool00ol0003of900omR@0002o`0001kooooo00?o0000oooo
ooooool0=?ooool001Cooooo0ol00004ooooo`;o00007_ooool3o`0008Sooooo00Ko0000omR@0?oH
T03o0000omR@0?l0000Nooooo`03o`000?oooooooooo03?ooooo000Eooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00006oooool2o`0008[ooooo00Oo0000omR@0?oHT03of900o`00
0?oHT03o000001oooooo00?o0000ooooooooool0<_ooool000gooooo1Ol00003ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00006?ooool3o`0008_ooooo00?o0000omR@0?oHT000
0_oHT0001?l0003of900omR@0?l0000Nooooo`03o`000?oooooooooo03;ooooo000Eooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00005Oooool5o`0008_ooooo00?o0000omR@0?oH
T0001?oHT0000ol0003of900o`00000Nooooo`;o0000<oooool001Gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000Cooooo`;o0000Soooool2o`0000Kof90000?o0000omR@0?l0
00008?ooool00ol0003oooooooooo`0`ooooo`005?ooool2o`0000Cooooo00Co0000oooooooooooo
00004?ooool3o`00093ooooo00Co0000onIT0?oVI03o00001OoHT0001?l0003of900omR@0?l0000O
ooooo`03o`000?oooooooooo00Kooooo0_l0000Xooooo`005Oooool00ol0003oooooooooo`03oooo
o`;o00003oooool2o`0009;ooooo00Go0000onIT0?oVI03oiV@0o`000005omR@0004o`000?oHT03o
0000o`00023ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Wooooo`00:Ooo
ool3o`000003ooooool0003ooooo093ooooo00?o0000onIT0?oVI0000_oVI0000ol0003of900omR@
0003omR@00;o00000_oVI0000ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00009oooool002Oooooo0_l0002Eooooo`03o`000?oVI03oiV@000CoiV@000?o
0000omR@0?oHT0000_oHT0001Ol0003oiV@0onIT0?oVI03o0000023ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool0000Wooooo`009?ooool3o`0009Kooooo00?o0000onIT0?oVI000
1OoVI0001?l0003of900omR@0?oHT002o`0000?oiV@000?o0000ooooooooool07oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0002Oooooo000Rooooo`;o0000Uoooool2o`0000So
iV@000Ko0000omR@0?oHT03o0000onIT0?l00004onIT0003o`000?oooooooooo01kooooo0_l00003
ooooo`04o`000?ooooooooooo`0002Oooooo000Oooooo`Co0000Uoooool00ol0003okd40o`000009
onIT00;o00000_oVI0000ol0003oiV@0onIT0002onIT0003o`000?oooooooooo01gooooo00?o0000
ooooool000001?ooool2o`0002Sooooo000Looooo`?o00001?ooool00ol0003oooooooooo`2Coooo
o`05o`000?o_@@3okd40onm10?l000001ooVI002o`0000?oiV@000?o0000onIT0?oVI0000_oVI000
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02_ooooo000Jooooo`;o0000W?ooool00ol0
003okd40onm10002onm10003o`000?oVI03oiV@000CoiV@000?o0000oo0o0?l000000_oVI002o`00
00GoiV@000?o0000ooooooooool08?ooool00ol0003oooooooooo`0Zooooo`005oooool3o`0009go
oooo00?o0000onm10?o_@@001?o_@@000ol0003oiV@0onIT0002onIT0003o`000?o`?`3ol3l000?o
000000?oiV@0o`000?oVI0000ooVI002o`0002;ooooo00?o0000ooooooooool0:_ooool001Kooooo
0_l000000ooooooo0000ooooo`2Jooooo`;o00002?o_@@000ol0003oiV@0onIT0004o`000003oo0o
0?l0003oiV@000;oiV@000Ko0000onIT0?oVI03o0000onm10?l0000Sooooo`03o`000?oooooooooo
02Wooooo000Fooooo`?o0000V_ooool2o`000003ooHY0?l0003okd4000Ookd401?l00005oo0o0004
o`000?oVI03oiV@0onIT00;o00000oo_@@000ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
02Sooooo000Fooooo`04o`000?ooooooooooo`0009Sooooo00?o0000ooHY0?of:@000_of:@000ol0
003okd40onm10003onm100Co00002?o`?`000ol0003oiV@0onIT0002o`0000?okd4000?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Xooooo`003_ooool2o`0000Kooooo00Go0000oooooooo
ooooooooo`00002Eooooo`;o00001Oof:@000ol0003okd40onm10005o`000003ooHW0?l0003ol3l0
00Ool3l000Go0000onIT0?l0003okd40o`000004onm10003o`000?oooooooooo01oooooo0ol0000Y
ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0T?ooool2o`0000OomRT00ol00002onm10003o`000?of9`3omRL000;omRL000?o0000
oo0o0?o`?`001Oo`?`02o`0000?okd4000?o0000onm10?o_@@000_o_@@000ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo02Kooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo08cooooo0ol000000ooi7@3o0000ooHY0003ooHY00?o000000?omRT0
o`000?o_@@000_l00005ooHW0003o`000?o`?`3ol3l000?ol3l00_l000000oof9`3o0000onm10003
onm10005o`000?o_@@3okd40onm10?l000008oooool00ol0003oooooooooo`0Vooooo`003Oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ROoo
ool2o`0000GonAd000Co0000ooHY0?l0003o00001?of:@02o`0000SomRL000Go0000oo0o0?o`?`3o
l3l0o`000004ooHW0003o`000?o_@@3okd4000;okd4000?o0000onm10?o_@@000_l0000Sooooo`03
o`000?oooooooooo02Gooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`26ooooo`;o00001_oi7@03o`0000ComRT00_l000000ooi6`3o
0000ooHW0007ooHW0004o`000?o`?`3o0000o`0000GomRL000?o0000onm10?o_@@000_o_@@03o`00
0003ooHY0?l0003ooooo02;ooooo00?o0000ooooooooool09Oooool000gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08;ooooo0ol000000ooi
6P3o0000ooTM0002ooTM00?o00000_oi7@001Ol0003omRT0ooHY0?of:@3o000000ConA/000?o0000
ooHW0?of9`001Oof9`02o`0000SomRL000Co0000onm10?o_@@3okd400_l00003ooHY0003o`000?oo
oooooooo027ooooo00?o0000ooooooooool09?ooool000kooooo0_l00004ooooo`;o00002_ooool0
0ol0003oooooooooo`1oooooo`;o00001Ooi6P03o`0000GonAd000Co0000ooHY0?l0003o00001Ooi
6`000ol0003omRL0ooHW0003ooHW00;o000000?onA/0o`000?of9`001oof9`001?l0003okd40o`00
0?l00002ooHY0004o`000?of:@3omRT0o`0002Cooooo00?o0000ooooooooool08oooool001Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1looooo`;o00001?oi6P03o`000003ooTJ
0?l0003onAd000GonAd00_l00008ooTK0005o`000?of9`3omRL0ooHW0?l000001?oi6`000ol0003o
mRL0ooHW0005ooHW00;o00001?of:@001Ol0003omRT0ooHY0?of:@3o000002;ooooo0_l0000Uoooo
o`005?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07Sooooo0ol00002ooTM00Co
00001Ooi6P000ol0003onAd0ooTM0003o`0000;onAX000?o0000ooTK0?oi6`001Ooi6`001?l0003o
mRL0o`000?l00005ooTK0003o`000?of9`3omRL000?omRL00_l000000ooi6`3o0000ooHY0004ooHY
0004o`000?of:@3omRT0o`0002Cooooo00?o0000ooooooooool08_ooool001Cooooo0_l0000=oooo
o`03o`000?oooooooooo07?ooooo1?l00003ooTM00Co00001_oi6P04o`0000KonAX000?o0000ooTK
0?oi6`001?oi6`02o`0000SonA/000Go0000ooHW0?of9`3omRL0o`000004ooTK0003o`000?of:@3o
mRT000?omRT000Co0000ooHY0?l0003o00009?ooool00ol0003oooooooooo`0Qooooo`005?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo0ol00003ooHV00Co00001?oi7@00
0ol0003onAX0ooTJ0003o`0000?omb8000?o0000ooTJ0?oi6P001Ooi6P000ol0003onA/0ooTK0003
o`0000;onA/000?o0000ooTK0?oi6`001Ooi6`001?l0003omRL0o`000?l00006ooTK0004o`000?of
:@3omRT0ooHY00?o000000?onAd0o`000?ooool08oooool00ol0003oooooooooo`0Qooooo`005?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06[ooooo1?l00004ooHV00Co00001?oi
7@05o`0000Oomb8000?o0000ooTJ0?oi6P000_oi6P05o`0000KonA/000?o0000ooTK0?oi6`001?oi
6`02o`0000SonA/000Co0000ooHY0?l0003o00000_oi7@001?l0003onAd0ooTM0?l0000Tooooo`03
o`000?oooooooooo023ooooo000Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
Hoooool7o`0000?olc401?l000000oof9P3o0000o`000005o`0000Com2h000?o0000ooLR0?og8P00
1?og8P06o`0000CombD000?o0000ooTK0?oi6`001Ooi6`000ol0003onA/0ooTK0003o`000003ooTK
0?l0003onA/000OonA/00_l00005ooTM0004o`000?oi7@3onAd0o`0002Cooooo00?o0000oooooooo
ool07oooool001?ooooo0_l0000Booooo`;o0000Goooool9o`0000Colc401_l00005oo0n00;o0000
1Ood;P000ol0003omb80ooLR0003o`0000?olSH000?o0000ooLU0?og9@001Oog9@000ol0003onA/0
ooTK0002ooTK00Go00001Ooi6`000ol0003onA/0ooTK0002ooTK00?o000000?onAX0o`000?oi7@00
1Ooi7@000ol0003onAd0o`00000Sooooo`;o00008Oooool001?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`1Hooooo`Oo00000oo`?@07o`0000Goje0000?o0000oo0n0?o`?P000_o`
?P0<o`0000KolSH000?o0000ooLU0?og9@000_og9@07o`0000ComRH000?o0000ooTK0?oi6`001?oi
6`001?l0003onA/0o`000?l00005ooTJ0003o`000?oi7@3onAd000ConAd00ol0000Tooooo`03o`00
0?oooooooooo01kooooo000Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0E?oo
ool5o`0000;okDX01_l000000ooVH@3o0000o`00000>o`0000Goif0000?o0000one:0?o]BP000_o]
BP0=o`0000ColCT000?o0000ooHV0?of9P001Oof9P001?l0003onA/0ooTK0?oi6`05o`0000OonAX0
00Co0000ooTM0?oi7@3onAd00ol000000ooi6P3o0000ooooo`0Tooooo`03o`000?oooooooooo01go
oooo000Cooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0D?ooool:o`0000CohW40
8Ol000000ooTJ`3o0000on]A0004on]A0003o`000?oa>@3olCT000ColCT000?o0000ooHV0?of9P00
0_of9P06o`0000GombD000?o0000ooTJ0?oi6P001?oi6P001?l0003onAd0o`000?l00003ooTJ0003
o`000?oi6P3o000002Cooooo00?o0000ooooooooool07Oooool001?ooooo0_l0000Gooooo`03o`00
0?oooooooooo04_ooooo1?l00003onYE00_o00000ol04R`00ol0003o010Zo`0@:P03o`0000;o00XT
00Co0000o`0;9Ol02bGo00/U1_l00003o`0;9@03o`000?l04Rco018/00?o018/5_l00004oo4i0003
o`000?og9@3ombD000GombD000Co0000ooTJ0?oi6P3onAX01?l00006ooTJ0003o`000?oi6P3o0000
02Cooooo00?o0000ooooooooool07?ooool000[ooooo0ol00006ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0Aoooool3o`0000;oieh03_l00005o`0B;0?o00001Ol02R@4o`0000Co
00LQ00?o0000o`0;9Ol02bD00ol02bD00ol0003o018/o`0B;003o`0B;005o`000?l07CCo01ddo`0M
=?l000000_l0;cl;o`000003onYD0?l0003olCT000GolCT000?o0000ooLU0?og9@000_og9@06o`00
00Comb8000?o0000ooTJ0?oi6P001?oi6P02o`0002Gooooo00?o0000ooooooooool06oooool000_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo047o
oooo3_l00002o`0f@`Co000000?o02<ho`000?l000000_l000001?l04Rco0000o`000?l00003o`0;
9@03o`000?l02RCo000000;o00000_l01R000ol0003o00LQo`078@04o`078@04o`000?l02bGo00/U
o`0;9@go00001?l0;cl00ol0003o04Y=o`00000Bo`0000ColSH000?o0000ooLR0?og8P001?og8P00
0ol0003onAX0ooTJ0002ooTJ00Co00009?ooool00ol0003oooooooooo`0Kooooo`002oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>oooool5o`00
00;oiFD01Ol000001Ol0GdCo0000o`1@C_l0D4ko000000;o03I30ol00002o`0S>0;o00000ol05Rl3
o`0000Go00/U0_l00006o`068004o`000?l01b7o00LQo`078@Ko00000ol02R@00ol0003o010Zo`0@
:P02o`0@:P04o`000?l06c?o01/co`0K<`Go000000?o02loo`000?l0BTd00_l0BTd=o`000003on]A
0?l0003olSH000GolSH000Co0000ooLR0?og8P3omb801ol00002ooTM00;o00009?ooool2o`0001co
oooo000;ooooo`03o`000?oooooooooo00Cooooo0_l0000Looooo`03o`000?oooooooooo03Oooooo
0ol00002onAZ01?o000000?o02<ho`000?l000000ol05Rl2o`0000?o00lY00?o0000o`0;9Ol00000
0_l00002o`078@03o`000?l01R3o00HP00?o00HP1?l00004o`068003o`000?l02RCo00XT00?o00XT
00?o0000o`0@:_l042X00_l042X00ol0003o01/co`0K<`02o`0K<`03o`000?l0;Cko02dn00Go0000
00?o04Y=o`000?l0FdL02?l00002onA[00co00000ood;P000ol0003onAd0ooTM0004ooTM00;o0000
9Oooool00ol0003oooooooooo`04ooooo`?o00004_ooool000_ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03?ooooo4Ol00002o`1FB`Co00000ol0
;Ch4o`000003o`0F;ol0003o000000Go00lY0_l00006o`078@03o`000?l01R3o000000;o00000_l0
1Ah00ol0003o00HPo`068004o`068004o`000?l02RCo00XTo`0:90Oo00001Ol06c<01Ol0003o02dn
o`0]?_l0;Cko000000;o04Q;0ol00003o`1KA`[o000000?oi6/0o`000?o]BP000oo]BP000ol0003o
m2h0oo@^0004oo@^0003o`000?oi7@3onAd000ConAd00_l0000Tooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00000Aooooo`002_ooool2o`0000Kooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0_ooooo`?o00000_oTJ`02o`000003omJG0?l0003o000000Ko
000000Co06@oo`000?l0003o05I;0ol000000ol0@dWo0000o`0]?P02o`0]?P04o`000?l07cKo01lf
o`0O=P?o00001?l03bT2o`0000;o00/U00?o0000o`078Ol01b400ol01b42o`0000Ko00DN00Co0000
o`068?l01R3o00HP1_l00002o`0;9@04o`000?l04Rco018/o`0B;0[o000000?o02dno`000?l0B4/0
0ol0B4/2o`000003o`1KAol0003o06`f00ko000000?okDX0o`000?od;P001Ood;P000ol0003onAd0
ooTM0002ooTM00Co00009?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo
000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0[ooooo`Co00000_oTJ`0;o`0000;o06@o1?l00003o`13B@05o`000?l0;Cko02dno`0]?_l00000
0ol07cH01?l0003o01H_o`0F;ol05Rl2o`000003o`0?:Ol0003o00/U00Co00/U00?o0000o`078Ol0
00000_l00002o`068003o`000?l01Ako00DN00?o00DN1?l00003o`078@03o`000?l02bGo00/U00?o
00/U00Go0000o`0B;?l04Rco018/o`000005o`0M=003o`000?l0;coo02lo00?o00000ol0B4/00ol0
003o05Y8o`000002o`0000;o06`f2ol000000ooWH03o0000o`00000;o`0000;omRH000?o0000ooHV
0?l000009?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo000Aooooo`;o
00008Oooool00ol0003oooooooooo`0Xooooo`;o00001?oTJP0Ho`000003o`0]?_l0003o01lf00;o
01lf00?o0000o`0F;ol05Rl00ol05Rl2o`0000Ko00/U0_l00006o`068003o`000?l01Ako000000;o
000000?o00HPo`000?l01b401Ol01b400ol0003o00/Uo`0;9@03o`0;9@05o`000?l04Rco018/o`0B
;?l000001Ol07C@00ol0003o02loo`0_?`02o`0_?`;o00000_l0B4/01?l0003o05Y8o`1JB?l0FTP2
o`0000;o06`f3Ol000000ooWH03o0000oo0n0005oo0n0003o`000?of9P3omRH000;omRH000?o0000
ooHV0?l000008oooool01?l0003oooooooooooooool4o`0001;ooooo000Booooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool09Oooool2o`0000?oi6X04?l00002o`1NA@05o`000?l0DDgo
055=o`1ACOl000000ol0?DL4o`000003o`0O=_l0003o01H_00Co01H_00Co0000o`0B;?l04Rco0000
0ol02bD2o`0000;o00XT00?o0000o`068?l01R000ol01R02o`0000Go00HP00?o0000o`078Ol01b40
0ol01b401?l0003o00/Uo`0;9Ol02bD8o`0000Go01dd00Ko0000o`0_?ol0;coo02loo`000?l0BTd3
o`0000?o05Y800?o0000o`1[=ol000000_l000000ol0OAWo0000o`00000Jo`0002;ooooo0_l00002
ooooo`03o`000?oooooooooo01?ooooo000Aooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool08_ooool@o`000006o`1k7Ol0003o0000o`000?l0K3Ko00000_l0GTD00ol0003o055=o`1A
C@02o`0000?o03e700Co0000o`0]?_l0;Cko02dn0ol00003o`0F;`;o00001?l04R`00ol0003o00/U
o`000005o`0:9003o`000?l01R3o000000;o000000?o00LQo`000?l01R001Ol01R001?l0003o00LQ
o`078Ol01b45o`0000?o00lY00Co0000o`0F;ol05Roo01H_2Ol00002o`0_?`04o`000?l0BTgo04Y=
o`1:C@?o000000Co05Y8o`000?l0JcOo06/g0_l00002o`1m6@Ko000000?oaL80o`000?l000001Ol0
0005on]@0005o`000?oc<@3olc40oo<a0?l000000_oc<@000ol0003oooooooooo`0Nooooo`05o`00
0?ooooooooooo`000?ooool01Ol0000Aooooo`004Oooool2o`0002Cooooo0_l0000Oooooo`?o0000
0_oUI@0:o`000003o`J<0?l0003o000000;o00000ol0K3H01?l0003o05i5o`1NAOl00002o`1AC@03
o`000?l0?DOo03e700;o03e700Go0000o`0]?_l0;Cko02dno`000003o`0S>003o`000?l05Roo0000
00Ko018/0_l00006o`0:90;o00001Ol01b400ol0003o00HPo`068003o`0680Co00000_l02bD00ol0
003o00lYo`0?:@04o`0?:@05o`000?l05Roo01H_o`0F;ol000001Ol08cP00ol0003o03I3o`000002
o`0000?o04Y=00?o0000o`1KAol0FdL00ol00003o`1[=`;o00000_l0OAT7o`000003olG20?l0003o
000000Oo000000?oje00o`000?oc<@000_oc<@001?l0003olc40oo<a0?l0000Rooooo`03o`000?oo
oooooooo01Gooooo000Aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06Oooool4
o`0000;oiFD02ol000000ol6S03o0000o`00000>o`0000;o03e700Go0000o`0]?_l0;Cko02dno`00
0005o`0S>003o`000?l04Rco018/00Co018/00?o0000o`0@:_l000001?l02R@2o`000003o`0;9Ol0
003o00LQ00Go00LQ00?o0000o`068?l000000_l000000ol02RCo0000o`0;9@04o`0;9@03o`000?l0
3bWo00lY00?o00lY00?o0000o`0F;ol05Rl00_l05Rl00ol0003o02<ho`0S>003o`0S>004o`000?l0
=T?o03I3o`0f@`?o000000?o04Y=o`000?l0FdL00ol0FdL2o`000003o`1[=ol0003o07`K00?o0000
00?o3i00o`000?l000002ol00002onIQ00[o00008_ooool00ol0003oooooooooo`0Dooooo`004Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo0_l00004onMN00[o000000?o
=9d0o`000?l000000ol00003o`1e9`04o`000?l0J3_o06Pko`0000?o05]700Co0000o`1ACOl0DDgo
055=1?l000000ol0;Cko0000o`0S>004o`0S>003o`000?l07CCo000000?o018/0_l00003o`0@:P04
o`000?l02RCo0000o`0000Co00/U00?o0000o`078Ol01b400ol01b42o`0000Go00XT00?o0000o`0;
9Ol02bD00ol02bD00ol0003o00lYo`0?:@02o`0?:@03o`000?l05Roo01H_00?o01H_00?o0000o`0S
>?l08cP00_l08cP01Ol0003o03I3o`0f@ol0=T?o000000;o051>0ol00003o`1KA`03o`000?l0K3Ko
000000;o00000_l0O1/2o`0000;o3i002Ol000000ooDV`3o0000o`000002o`0000;oiV4000Co0000
oo0m0?o`?@3o00000_o`?@000ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?ooooo000A
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04oooool2o`0000?oieh02Ol00000
0om][P3o0000o`000004o`000003o`242ol0003o07DW00;o07DW00Co0000o`1X>ol0J3_o00000ol0
FdL01Ol0003o055=o`1ACOl0DDgo000000?o04=90_l00005o`0S>007o`000?l07CCo01ddo`0M=?l0
003o018/o`000005o`0@:P;o00001ol02bD00ol0003o00LQo`000002o`000003o`0;9Ol0003o00XT
00Go00XT00?o0000o`0;9Ol02bD00_l02bDAo`0000Co03I300?o0000o`1@C_l0D4h00_l0D4h3o`00
0004o`1KAol0003o06`fo`1/=P;o00000ol0O1/2o`0000;o3i002ol000000ooRL@3o0000o`000002
o`0000;ol3d000Co0000oo0m0?o`?@3o00008_ooool00ol0003oooooooooo`0Cooooo`004Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo013ooooo3?l00002ojno00Go00000_lKU000
0ol0003o08@;o`000003o`1e9`04o`000?l0J3_o06Pko`0000?o05]700Go0000o`1ACOl0DDgo055=
o`000003o`13B@04o`000?l0=T?o03I3o`0000?o02<h00?o0000o`0M=?l07C@00_l07C@2o`0000Go
010Z00?o0000o`0B;?l000001ol02bD2o`0000Go00/U00?o0000o`0:9?l02R@00ol02R@00ol0003o
00/Uo`000002o`000003o`0B;?l0003o01H_00?o01H_00?o0000o`0O=_l07cH00ol07cH01?l0003o
02dno`0]?_l0;Ch5o`000003o`0f@ol0003o051>00;o051>00?o0000o`1OA?l0Gd@00ol00003o`1/
=P;o000000?o07`Ko`000?l=S`001Ol000001?m<Y@3o0000o`000?nK^P05o`0000?ohW402?l0000R
ooooo`03o`000?oooooooooo01;ooooo000@ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool03Oooool2o`0000;ojUD00_l00002omin00;o00000_o?Z@000ol0003o[kl0o`000002o`00
00;oC:D000Ko0000oa^D0?lKU03o0000o`242ol00003o`1e9`04o`000?l0J3_o06Pko`0000?o05]7
00Go0000o`1ACOl0DDgo055=o`000003o`13B@03o`000?l0=T?o03I300;o03I300?o0000o`0S>?l0
00001?l07C@01?l0003o01/co`0K<ol00003o`0@:P05o`000?l04Rco018/o`0B;?l000001?l02bD2
o`000003o`0?:Ol0003o00/U00Go00/U00Co0000o`0:9?l02RCo00XT0ol00005o`0B;003o`000?l0
5Roo01H_00;o01H_00?o0000o`0O=_l07cH00ol07cH01Ol0003o02dno`0]?_l0;Cko000000?o04=9
1Ol000000ol0D4ko0000o`1OA003o`1OA0;o000000?o06`fo`000?l0OAT00ol00003o`f?00Co0000
00GoSKL0o`000?l0003o0000ol^d0006o`000005on9a0?l0003okDX0one:0?l000000_o]BP000ol0
003oooooooooo`0Nooooo`;o00005?ooool0013ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0:ooooo`;o00000_oZE@02o`0000?ogWh000Co0000olnY0?o?Z@3ocjT01Ol00002odbU
0003o`000?lKU03o6i@0013o000000?o055=o`000?l0@dT00_l0@dT00ol0003o03I3o`0f@`03o`0f
@`?o00000ol07C@00ol0003o01/co`0K<`02o`0K<`03o`000?l042[o000000Go018/00Co0000o`0;
9Ol0003o00001?l03bT00ol0003o00/Uo`0;9@03o`0;9@Co00000_l042X00ol0003o018/o`0B;003
o`0B;003o`000?l05Roo01H_00?o01H_00?o0000o`0O=_l07cH00ol07cH01Ol0003o02dno`0]?_l0
;Cko000000Co04=900?o0000o`1FBol0ET/00ol00003o`1OA003o`000?l0Kc7o000000;o00000_l0
OAT2o`0000Co3Hl00ol00002ohfg00;o00000_o;]002o`0000;ogWh01ol000000oo]BP3o0000oooo
o`0Pooooo`03o`000?oooooooooo017ooooo000@ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool01ooooolAo`000004ohNe0?l0003oC:D0odbU00Ko00000_l0PA<01Ol0003o07<[o`1c
:ol0Lb_o000000;o06Pk00?o0000o`1NAOl0GTD00_l0GTD3o`000003o`13BOl0003o03I300Co03I3
00Oo0000o`0_?ol0;coo02loo`000?l07CCo000000Go01/c0_l00006o`0B;0;o00001_l03bT01?l0
003o00/Uo`0;9Ol02bD2o`000003o`0B;?l0003o010Z00Co010Z00?o0000o`0B;?l04R`00ol04R`0
0ol0003o01H_o`0F;`02o`0F;`03o`000?l07cKo01lf00?o01lf00?o0000o`0]?_l0;Ch00_l0;Ch0
0ol0003o04=9o`13B@02o`13B@03o`000?l0ET_o05I;00;o05I;0ol000001?l0GdCo0000o`1_<Ol0
Kc42o`0000?o07dI0_l00002o`f?0003o`000?m1X@3o000000;o00000_n=]`02o`0000;obk@00ol0
0002omin0004o`000?oZE@3o0000onYE00?o00008Oooool00ol0003oooooooooo`0@ooooo`004?oo
ool2o`0002kooooo00?o0000ooooooooool01?ooool2o`0000?okDX000?o0000on9a0?oRL@000_oR
L@000ol0003oe9/0o`000002o`000004olG20?l0003o0000ohNe00Ko00000_l=S`001?l0003o084C
o`214ol00003o`1c:`04o`000?l0J3_o06Pko`0000Co05i500Co0000o`1FBol0ET_o05I;0_l00004
o`0f@`03o`000?l0;coo02lo00?o02lo00?o0000o`0K<ol06c<00ol06c<00ol0003o01ddo`000005
o`0B;003o`000?l05Roo000000Ko00lY00Co0000o`0;9Ol0003o00001?l04R`00ol0003o010Zo`0@
:P03o`0@:P03o`000?l04Rco018/00;o018/00Co0000o`0F;ol05Roo01H_3Ol00005o`13B@05o`00
0?l0ET_o05I;o`1FBol000000_l0I3l3o`0000?o06la0_l000000ol0OAWo0000o`n@0002o`000003
o`f?0?l0003o@J4000[o000000?ofXT0o`000?l000000_l000000ooZE@3o0000onYE0002onYE0003
o`000?oooooooooo01kooooo00?o0000ooooooooool04?ooool000Kooooo1Ol00005ooooo`03o`00
0?oooooooooo02kooooo00Co0000oooooooooooooooo0_l00003one:00;o00000ooRL@05o`0000;o
aL801_l00002ocNN0004o`000?l=S`3o3Hl0o`0000;o084C00Go0000o`1c:ol0Lb_o07<[o`000002
o`1X>`03o`000?l0GTGo05i500;o05i500?o0000o`1FBol0ET/00_l0ET/01_l0003o051>o`000?l0
003o03I3o`0000Go02lo00?o0000o`0]?_l000000ol06c<01Ol0003o01ddo`0M=?l07CCo000000?o
018/00Go0000o`0F;ol05Roo01H_o`000005o`0?:@;o00001_l04R`00ol0003o010Zo`0@:P03o`0@
:P04o`000?l04Rco018/o`0B;0Go00000_l08cP00ol0003o02dno`0]?P03o`0]?P04o`000?l0?DOo
03e7o`0mA`Go000000?o04=9o`000?l0ET/00ol0ET/00ol0003o06@oo`1T?`02o`1T?`;o000000?o
06lao`000?l0PA<00ol00002o`n@00;o00000om1X@000ol0003oQ;@0ohBd0002o`0000;ob;`00_l0
0003omZ900Ko000000?ojUD0o`000?ooool07oooool00ol0003oooooooooo`0?ooooo`001oooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo02oooooo1Ol00002one:0004o`000?oR
L@3ohW40on9a00_o000000?oJjh0o`000?l000000_lgWP001?l0003o3Hl0o`f?0?l00002o`214`05
o`000?l0Lb_o07<[o`1c:ol000000_l0J3/00ol0003o05i5o`1NA@02o`1NA@03o`000?l0ET_o05I;
00;o05I;00?o0000o`1@C_l0D4h00_l0D4h00ol0003o02loo`0_?`03o`0_?`07o`000?l0;Cko02dn
o`0]?_l0003o01/co`000005o`0M=003o`000?l04Rco000000Go01H_00?o0000o`0?:Ol03bT00_l0
00000ol05Roo0000o`0B;005o`0B;004o`000?l042[o010Zo`0@:PKo00000_l07C@00ol0003o02<h
o`0S>003o`0S>003o`000?l0;Cko02dn00?o02dn00Go0000o`0mAol0?DOo03e7o`000003o`1AC@Co
00000_l0ET/00ol0003o06@oo`1T?`02o`1T?`03o`000?l0M2Wo000000;o00000_l0PA<2o`0000?o
3i000_l00002od6Q00;o00000_n4]002o`0000;ob;`00ol00002omZ900;o00000_oWGP03o`00023o
oooo00?o0000ooooooooool03_ooool000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0]ooooo`?o00001?o`?@09o`0000?oc;4000Ko0000ojJm0?l0003o0000of^^0?l00003ocNN
013o00000_l0GTD00ol0003o05I;o`1FB`02o`1FB`03o`000?l0D4ko051>00;o051>00?o0000o`1:
COl000000ol0;cl00ol0003o02dno`0]?P03o`0]?P03o`000?l07CCo01dd00Co01dd0_l00006o`0F
;`03o`000?l03bWo000000Co01H_00?o0000o`0B;?l04R`00ol04R`4o`0000?o01/c00?o0000o`0M
=?l07C@00ol07C@00ol0003o02<ho`0S>002o`0S>003o`000?l0;Cko02dn00?o02dn00?o0000o`0m
Aol0?DL00_l0?DL00ol0003o055=o`1AC@02o`1AC@03o`000?l0GTGo000000;o00001Ol0I3l01?l0
003o07@Yo`1d:Ol00004o`214`;o000000?o3i00o`000?m4XP003?l000000ooHT@3o0000o`000003
o`0000?oieh000?o0000ooooooooool07Oooool2o`00013ooooo0009ooooo`03o`000?oooooooooo
00?ooooo0_l0000/ooooo`?o00001Oo`?@07o`000003omZ90?l0003o000000;oc;400_l000000onV
_@3o0000o`000008o`0000?o28d000Co0000o`214ol0PA?o00001?l0MBL00ol0003o06`fo`1/=P03
o`0000?o05I;00?o0000o`1@C_l0D4h00_l0D4h01ol0003o04Y=o`1:COl0BTgo0000o`0_?ol00000
1Ol0;Ch2o`0000Go01dd00?o0000o`0S>?l000001_l05Rl2o`0000Ko01H_00?o0000o`0B;?l04R`0
0_l000000ol07CCo0000o`0K<`05o`0K<`03o`000?l07CCo01dd00?o01dd00?o0000o`0S>?l08cP0
0_l08cP00ol0003o02dno`0]?P02o`0]?P03o`000?l0?DOo03e700;o03e700?o0000o`1ACOl0DDd0
0ol0DDd01?l0003o05i5o`1NAOl0GTD3o`0000;o06@o00Co0000o`1d:Ol0M2Wo07@Y0_l00002o`21
4`03o`000?lFTP3o000000;o00000om4XP02o`0000;oPK@00_l00002olK100;o00000ooHT@04o`00
00;oieh000?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`001_ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0:Oooool2o`0000?olc400ol000001Oo`
?@3o0000o`000?l0003oiV4000;o00000_oJR@001?l0003oc;40olba0?o</@06o`0000?oFZT000Co
0000obfK0?l]V`3o00000ol8S@001?l0003o084Co`214ol00004o`1e9`05o`000?l0K3Ko06`fo`1/
=_l000000_l0I3l00ol0003o05I;o`000004o`1@CP03o`000?l0BTgo04Y=00;o04Y=0_l00005o`0]
?P04o`000?l0;coo02loo`0000?o01dd00Go0000o`0S>?l08cSo02<ho`000003o`0F;`;o000000?o
01lfo`000?l05Rl01Ol05Rl00ol0003o018/o`000004o`0M=003o`000?l06c?o01/c00?o01/c00?o
0000o`0M=?l07C@00ol07C@00ol0003o02<ho`0S>002o`0S>003o`000?l0;Cko02dn00?o02dn00?o
0000o`0mAol0?DL00_l0?DL00ol0003o055=o`1AC@02o`1AC@05o`000?l0GTGo05i5o`1NAOl00000
0_l0K3H3o`0000?o07@Y00?o0000o`252Ol000000ol00002oaJB00;o00001?m4XP02o`0000;oPK@0
0_l00002olK100?o000000?of940o`000?oUI@001?l0000Qooooo`03o`000?oooooooooo00cooooo
0006ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Wooooo`;o0000
1_oc<@0Ao`0000;oSkP000Go0000oeZY0?mJZ@3oFZT0o`000002obfK0005o`000?l8S@3o28d0o`R=
0?l000000_l0PA<00ol0003o07DWo`1e9`02o`1e9`05o`000?l0K3Ko06`fo`1/=_l000001?l0I3l2
o`0000?o051>00?o0000o`1:COl0BTd00_l0BTd01?l0003o04Q;o`18Bol00003o`0]?P03o`000?l0
;coo02lo00;o02lo00?o0000o`0M=?l000001Ol08cP00ol0003o01H_o`000004o`0O=P03o`000?l0
5Roo01H_00?o01H_0_l00005o`0M=003o`000?l06c?o01/c00?o01/c00Co0000o`0M=?l07CCo01dd
4Ol000000ol0?DOo0000o`1AC@03o`1AC@03o`000?l0GTGo05i500;o05i500?o0000o`1/=_l0K3H0
0_l0K3H2o`0000;o07@Y00Co0000o`252Ol0Q@Wo08D90_l00003oaJB00;o00000_m4XP000ol0003o
Q;@0o`000002o`000004olG20?l0003o0000o`0000;oeYH01?l00003onEU0003o`000?oooooooooo
01kooooo00?o0000ooooooooool03?ooool000Oooooo0ol00005ooooo`03o`000?oooooooooo02Go
oooo0ol00004oo<a00Co00000oo[D0001Ol0003ohGD0on5e0?oQM@3o000000?oe9`000Co0000olK1
0?o6`@3o00000_n?^0001Ol0003oFZT0oeZY0?mJZ@3o000000;o;I/000Go0000o`R=0?l8S@3o28d0
o`000002o`214`03o`000?l0MBOo07DW00;o07DW00Go0000o`1/=_l0K3Ko06`fo`000005o`1T?`05
o`000?l0GdCo0000o`1@C_l000001?l0BTd00ol0003o04Q;o`18B`02o`18B`03o`000?l0;Cko0000
00Ko02lo00?o0000o`0S>?l08cP01?l08cP2o`0000Ko01lf00?o0000o`0F;ol05Rl00_l000000ol0
8cSo0000o`0M=005o`0M=003o`000?l06c?o01/c00;o01/c1?l00003o`0_?`03o`000?l0=T?o03I3
00;o03I300?o0000o`13BOl0@dT00_l0@dT01?l0003o055=o`1ACOl0DDd6o`000003o`1ACOl0003o
05i500;o05i500?o0000o`1/=_l0K3H00_l0K3H01_l0003o07/Mo`000?l0003o07@Yo`0000Co08D9
0_l000000olFTP3o0000odbU0002o`000004odBR0?l0003oQ;@0ohBd00;o00000_o5`P02o`0000Co
eYH00ol00002onEU0003o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool000kooooo
0_l0000Uooooo`;o00000oof9P06o`0000?oje000_l00002on5e00;o00000_oDW002o`0000;oa/40
00Co0000ohnh0?n?^03o00000omJZ@0=o`0000;o07DW00Go0000o`1/=_l0K3Ko06`fo`000005o`1T
?`04o`000?l0GdCo05m4o`1OA0;o00000ol0BTd00ol0003o04Q;o`18B`04o`18B`03o`000?l0;coo
02lo00Co02lo0_l00005o`0S>003o`000?l0;Cko000000Ko01lf00?o0000o`0F;ol000001?l08cP0
0ol0003o01ddo`0M=003o`0M=003o`000?l06c?o000000;o000000?o02dno`000?l0;cl01?l0;cl0
0ol0003o03I3o`0f@`03o`0f@`03o`000?l0@dWo04=900;o04=900?o0000o`1ACOl0DDd00_l0DDd0
1?l0003o05]7o`1KAol0FdL4o`0000;o05i500?o0000o`1/=_l0K3H00_l0K3H00ol0003o07/Mo`1k
7@02o`0000Co08D900?o0000ob:G0?l000000_l00002odbU00;o00001?n4]002o`0000;oaL800ol0
0002omJF00Ko00007_ooool3o`0000cooooo000>ooooo`?o00008oooool00ol0003omRH0ooHV0002
ooHV00;o000000?omRH0o`000?l000000_l00002on]@0005o`000?oQM@3ohGD0on5e0?l000000ooD
W0001?l0003oa/40olK10?o6`@09o`000003oeBW0?l0003o;I/000;o;I/000Go0000o`f?0?l=S`3o
3Hl0o`000002o`242`Co000000?o06`fo`000?l0I3l01?l0I3l00ol0003o05m4o`1OA002o`1OA005
o`000?l0FdOo0000o`1:COl000001_l0B4/2o`0000Go02lo00Co0000o`0f@ol0=T?o00000ol08cP0
1Ol0003o02dno`0]?_l0;Cko000000Go01lf0_l00006o`0S>003o`000?l07CCo01dd00;o01dd0_l0
0005o`0]?P03o`000?l0;coo02lo00?o02lo00?o0000o`0f@ol0=T<00_l0=T<00ol0003o04=9o`13
B@02o`13B@03o`000?l0DDgo055=00?o055=00Go0000o`1KAol0FdOo05]7o`000002o`1X>`?o0000
1?l0K3H00ol0003o07/Mo`1k7@02o`1k7@;o00000ol0Q@T00ol0003o8YL0ob:G0002o`0000?oC:D0
0_l00002ohBd0003o`000?o6`@3o000000?o000000?oeYL0o`000?l000000_l00003onAZ00;o0000
6_ooool3o`000003ooooool0003o000000cooooo000>ooooo`;o000000?of900o`000?ooool07ooo
ool3o`000005ooHV0?l0003o0000o`000?of9P000_l00004oo0n00oo000000?o^/80o`000?n4]000
0_n4]0001?l0003oE:L0oeBW0?l00003obfK0005o`000?l=S`3o3Hl0o`f?0?l000000ol0Q0/01?l0
003o07/Mo`1k7Ol0Nad2o`0000Co06@o00?o0000o`1OA?l0Gd@00_l0Gd@01?l0003o05]7o`1KAol0
FdL2o`0000Go04Q;00Co0000o`1:COl0BTgo00000ol0;cl00ol0003o03I3o`0f@`02o`0f@`03o`00
0?l08cSo000000Go02dn00?o0000o`0O=_l07cH00_l000000ol0;Cko0000o`0S>005o`0S>003o`00
0?l07CCo000000;o000000?o02loo`000?l0;Ch01?l0;Ch00ol0003o02loo`0_?`03o`0_?`03o`00
0?l0=T?o03I300?o03I300?o0000o`13BOl0@dT00_l0@dT00ol0003o055=o`1AC@02o`1AC@03o`00
0?l0FdOo05]700;o05]700?o0000o`1X>ol0J3/00_l0J3/3o`0000;o06`f00Ko0000o`1k7Ol0Nago
07/Mo`000?l6S002o`000003o`252Ol0003o8YL000?o8YL00_l000000om<Y@3o0000ohfg0004o`00
00?oa/400_l00003omJG00Co000000?oi6X0o`000?ooool05_ooool3o`0000Gooooo00?o0000oooo
ooooool02_ooool000kooooo0_l00002omR@0003o`000?oooooooooo01[ooooo0ol000000ooi7@3o
0000o`000002o`000003ooHV0?l0003o000000Gol3h000Go0000onMP0?oWH03oif00o`000003omb5
0003o`000?o?Z@3ocjT000;ocjT000Co0000ok[20?nj`P3o00000on4]0001?l0003oE:L0oeBW0?l0
0003obfK0005o`000?l=S`3o3Hl0o`f?0?l000000ol0Q0/00ol0003o07/Mo`1k7@02o`1k7@06o`00
0?l0M2Wo0000o`000?l0I3oo00001?l0Gd@00ol0003o05]7o`1KA`02o`1KA`03o`000?l0FTSo0000
00?o04Q;00?o0000o`1:COl0BTd00_l0BTd00ol0003o02loo`000006o`0f@`03o`000?l0;Cko02dn
00Co02dn00?o0000o`0O=_l000001?l0;Ch00ol0003o02<ho`0S>003o`0S>0;o00001Ol0;cl00ol0
003o02dno`0]?P03o`0]?P03o`000?l0;coo02lo00;o02lo00?o0000o`0f@ol0=T<00ol0=T<00ol0
003o04=9o`13B@02o`13B@03o`000?l0DDgo055=00?o055=00Go0000o`1KAol0FdOo05]7o`000004
o`1X>`03o`000?l0MBOo07DW00?o00001?l0Nad00ol0003o1X`0o`J<0002o`0000Co8YL000?o0000
oeZY0?l000000_l00003ohfg00;o00001?o6`@02o`0000;oeYL00_l000001?oTJ`3o0000o`000?l0
000Cooooo`?o00002?ooool00ol0003oooooooooo`0:ooooo`003_ooool3o`0000;of9000_l0000E
ooooo`Go000000ConAd0o`000?l0003o00000ooi7@03o`0000Col3h00_l00002onMP00;o00000ooL
Q@000ol0003ocjT0olnY0002olnY0004o`000?nj`P3o^/80o`0000?oQ;@000Co0000oeBW0?mDY`3o
00000ol]V`001Ol0003o3Hl0o`f?0?l=S`3o000000?o08@;00?o0000o`1k7Ol0Nad00_l0Nad00ol0
003o07@Yo`1d:@02o`1d:@;o00000ol0Gd@00ol0003o05]7o`1KA`02o`1KA`07o`000?l0FTSo05Y8
o`1JB?l0003o04Q;o`000006o`1:C@03o`000?l0=T?o03I300Co03I30_l00006o`0]?P;o00001_l0
;Ch00ol0003o02<ho`0S>002o`000003o`0f@ol0003o02lo00Co02lo00?o0000o`0]?_l0;Ch00ol0
;Ch00ol0003o02loo`0_?`03o`0_?`03o`000?l0=T?o03I300co000000?o055=o`000?l0FdL00ol0
FdL00ol0003o06Pko`1X>`02o`1X>`03o`000?l0MBOo07DW00;o07DW0ol00002o`1k7@04o`000?l6
S03o1X`0o`J<00;o00000olRU`000ol0003oFZT0oeZY0002o`0000CoSKL00_l00002olK10005o`00
0?oFUP3o0000o`000?oFU`000_l00003onA[0003o`000?oooooooooo00cooooo1?l0000;ooooo`03
o`000?oooooooooo00[ooooo000>ooooo`03o`000?oooooo000000;of90000?o0000onIT0?l00000
0_l0000=ooooo`Go00000ooi6P03o`0000ConAd00_l00003oo@^00;o000000?ol3h0o`000?oWH000
0_oWH0000ol0003og8D0omb50002omb50003o`000?o?Z@3ocjT000;ocjT000Co0000ok[20?nj`P3o
00000on4]0001?l0003oE:L0oeBW0?l00003obfK0005o`000?l=S`3o3Hl0o`f?0?l000000ol0Q0/0
0ol0003o07/Mo`1k7@02o`1k7@03o`000?l0M2Wo07@Y00;o07@Y00Ko0000o`1_<Ol0Kc7o0000o`1O
A?l00004o`1KA`03o`000?l0FTSo05Y800?o05Y800?o0000o`1:COl0BTd01?l0BTd2o`0000Go03I3
00Co0000o`13BOl0@dWo00001?l0;Ch00ol0003o03e7o`000006o`0]?P03o`000?l08cSo000000Co
03I300?o0000o`0_?ol0;cl00ol0;cl00ol0003o02dno`0]?P02o`0]?P04o`000?l0;coo02loo`0_
?`Go00000ol0D4h00ol0003o05I;o`1FB`02o`1FB`04o`000?l0GTGo05i5o`1NA@Oo00001?l0J3/0
0ol0003o07DWo`1e9`02o`1e9`03o`000?l0Q0_o08@;00?o00000ol6S0001_l0003o=9d0o`000?l0
003o8YL0o`0000CoFZT00_l00002ohfg0006o`000?o8_03o0000o`000?o6`@3o00000_oFUP03o`00
00?oi6/000?o0000ooooooooool02Oooool3o`00013ooooo00?o0000ooooooooool02Oooool000ko
oooo00?o0000ooooool000000ooHT0001?l0003oiV@0onIT0?oVI00=o`0000?onAd000?o0000ooTJ
0?l000000_l00003ooTJ0004o`000?oi7@3o0000o`0000Kom2h02?l00002omb50003o`000?o?Z@3o
cjT000;ocjT05Ol000000ol0Q0_o0000o`1k7@03o`1k7@03o`000?l0M2Wo07@Y00;o07@Y00?o0000
o`1_<Ol0Kc400_l0Kc42o`0000?o05]700?o0000o`1JB?l0FTP00ol0FTP2o`0000Go04Y=00Co0000
o`1@C_l0D4ko00000ol0=T<00ol0003o04=9o`13B@02o`13B@04o`000?l0;Cko02dno`0000?o03e7
00?o0000o`0]?_l0;Ch00ol0;Ch2o`0000Go03I300?o0000o`0_?ol0;cl00ol0;cl01?l0003o02dn
o`0]?_l0;Ch5o`0000;o04Y=00?o0000o`1@C_l0D4h00ol0D4h00ol0003o05I;o`1FB`03o`1FB`03
o`000?l0GTGo05i500;o05i500Co0000o`1X>ol0J3_o06Pk1?l00002o`1X>`03o`000?l0MBOo07DW
00;o07DW00?o0000o`242ol0Q0/00_l0Q0/2o`0000;o1X`000?o0000ocBM0?ldW@000_l00004oeZY
0006o`000?nK^P3o0000o`000?n=]`3o00000_o8_002o`0000CoeYH00ol00002onA[0003o`000?oo
oooooooo00Gooooo0ol0000Cooooo`03o`000?oooooooooo00Wooooo000>ooooo`04o`000?oooooo
ooooo`0000;of90000Go0000onIT0?oVI03oiV@0o`000004onm10003o`000?of:@3omRT000;omRT0
00?o0000ooTM0?oi7@000_oi7@03o`0000KonAX00ol00005oo@^00;o00000oo]BP000ol0003oi6/0
onA[0002onA[00Wo00001?ne`@001Ol0003oQ;@0ohBd0?n4]03o000000?oFZT000Co0000ocNN0?lg
WP3o00000olKU003o`0000;o07/M00?o0000o`1d:Ol0M2T00_l0M2T00ol0003o06lao`1_<@03o`1_
<@05o`000?l0K3Ko0000o`1KAol000001Ol0FTP01?l0003o05]7o`1KAol00003o`1:C@03o`000?l0
D4ko051>00;o051>00?o0000o`0f@ol000001Ol0@dT00ol0003o02dno`000004o`0mA`03o`000?l0
;Cko02dn00;o02dn00?o0000o`13BOl000001_l0=T<00ol0003o02loo`0_?`02o`0_?`Co00000_l0
B4/00ol0003o04Y=o`1:C@03o`1:C@03o`000?l0D4ko051>00?o051>00?o0000o`1FBol0ET/00_l0
ET/00ol0003o05i5o`1NA@03o`1NA@05o`000?l0J3_o06Pko`1X>ol000000_l0Lb/3o`0000Co07DW
00?o0000o`242ol0Q0/00_l0Q0/01_l0003o6i@0o`000?l0003o1X`0o`0000?o=9d00_l00003oeZY
0003o`000?nK^P3oVkX000;o00001?o8_002o`0000;oeYH000?o0000onAZ0?l000001?l00003oooo
o`?o00005_ooool00ol0003oooooooooo`09ooooo`003Oooool2o`0000;ooooo00Go0000omR@0?oH
T03of900o`000003onIT0003o`000?o_@@3okd4000;okd4000?o0000ooHY0?of:@000_of:@04o`00
00?onAd000?o0000ooTJ0?oi6P000ol00003ooLR00;o000000?om2h0o`000?l000001?o]BP000ol0
003oi6/0onA[0002onA[0003o`000?oISP3ofHh000;ofHh000Co0000olf_0?o=[`3o00001?ne`@00
1Ol0003oQ;@0ohBd0?n4]03o000000?oFZT000Co0000ocNN0?lgWP3o00001?lKU0000ol0003o1X`0
o`J<0003o`0000?o07@Y00?o0000o`1_<Ol0Kc400ol0Kc401Ol0003o06`fo`1/=_l0K3Ko000000Go
05Y800?o0000o`1KAol0FdL00_l0FdL00ol0003o04Y=o`000005o`1@CP;o00001ol0@dT00ol0003o
03e7o`0mA`04o`0mA`04o`000?l0;Cko02dno`0000?o04=900?o0000o`0f@ol0=T<00ol0=T<00ol0
003o02loo`000002o`000003o`1:COl0003o04Q;00Co04Q;00?o0000o`1:COl0BTd00_l0BTd00ol0
003o051>o`1@CP03o`1@CP03o`000?l0ET_o05I;00?o05I;00?o0000o`1NAOl0GTD00_l0GTD00ol0
003o06Pko`1X>`02o`1X>`03o`000?l0Lb_o07<[00;o07<[0ol00002o`1e9`03o`000?l0Q0_o08@;
00;o08@;00?o0000oa^D0?lKU0000_l00003ocBM0003o`000?m][P3o000000;o000000?oFZT0o`00
0?nK^P000_nK^P02o`0000;ob;`000?o0000omRA0?l000000ol000001?oTJP3o0000onAZ0?oTJP04
o`0001Wooooo00?o0000ooooooooool02Oooool000gooooo00?o0000ooooooooool00_ooool2o`00
0003omR@0?l0003oiV@000;oiV@000?o0000onm10?o_@@000oo_@@000ol0003omRT0ooHY0003o`00
00GonAd00ol00007ooLR00Go00000_o]BP000ol0003oi6/0onA[0002onA[0004o`000?oISP3ofHh0
omV>00;o00000_o=[`000ol0003o]L40okG10002okG10005o`000?n4]03oQ;@0ohBd0?l000000omJ
Z@001?l0003o=ih0ocNN0?l00004oa^D0005o`000?l6S03o1X`0o`J<0?l000000_l0Q@T00ol0003o
07@Yo`000005o`1_<@03o`000?l0K3Ko06`f00;o06`f0_l00003o`1JB003o`000?l0FdOo05]700Co
05]700?o0000o`1@C_l0D4h00ol0D4h00ol0003o05I;o`000006o`13B@;o00001_l0?DL00ol0003o
02dno`000004o`13B@03o`000?l0=T?o03I300?o03I30_l00005o`1:C@03o`000?l0B4_o04Q;00;o
04Q;00?o0000o`1:COl0BTd00ol0BTd00ol0003o051>o`1@CP02o`1@CP03o`000?l0ET_o05I;00?o
05I;00?o0000o`1NAOl0GTD00_l0GTD00ol0003o06Pko`1X>`02o`1X>`03o`000?l0Lb_o07<[00;o
07<[00?o0000o`214ol0PA<00ol00004o`242`03o`000?lKU03o6i@000;o6i@00_l00002ocBM0004
o`000?m][P3oKJh0off^00;o00000onK^P000ol0003obk@0o`000003o`0000?of9400ol00004onAZ
0003o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool000gooooo00?o0000oooooooo
ool00_ooool01?l0003oiV@0o`000?l00004onIT0003o`000?o_@@3okd4000;okd400ol00003ooHY
0003o`000?oi7@3o000000;o00000ooi6P02o`0000?omb800_l00005oo8f00Co00000_oTJ`001Ol0
003ofHh0omV>0?oISP3o000000?ocJl000?o0000okG10?ne`@000_ne`@001Ol0003oQ;@0ohBd0?n4
]03o000000?oFZT000Co0000ocNN0?lgWP3o00001?lKU0001Ol0003o1X`0o`J<0?l6S03o000000Co
08D90_l00004o`1_<@03o`000?l0K3Ko06`f00;o06`f00Ko0000o`1[=ol0JcOo0000o`1JB?l00006
o`1KA`;o00001?l0D4h01Ol0003o05I;o`1FBol0ET_o000000Co04=900Co0000o`1ACOl0DDgo0000
1Ol0?DL2o`0000Ko04=900?o0000o`0f@ol0=T<00_l000000ol0D4ko0000o`1:C@04o`1:C@03o`00
0?l0B4_o04Q;00?o04Q;00?o0000o`1:COl0BTd00_l0BTd00ol0003o051>o`1@CP03o`1@CP03o`00
0?l0ET_o05I;00;o05I;00?o0000o`1NAOl0GTD00ol0GTD00ol0003o06Pko`1X>`02o`1X>`03o`00
0?l0Lb_o07<[00;o07<[00?o0000o`214ol0PA<00_l0PA<3o`0000;o08@;00Ko0000oa^D0?lKU03o
6i@0o`000?m<Y@02o`000003ocBM0?l0003oKJh000?oKJh00_l00002oi^j0004o`000?o;]03obk@0
ol^d00;o00001?oHT@05o`000003onAZ0?l0003ooooo01Sooooo00?o0000ooooooooool02Oooool0
00gooooo00?o0000ooooooooool00oooool00ol0003oiV@0onIT0005o`000006onm10?l0003o0000
o`000?o_@@3o00000oof:@03o`0000SonAX000?o0000ooLR0?l000001_ob=P000ol0003oje40on]A
0002on]A00co00000_ne`@001Ol0003oQ;@0ohBd0?n4]03o000000?oFZT000Co0000ocNN0?lgWP3o
00001?lKU0001Ol0003o1X`0o`J<0?l6S03o000000Go08D900Ko0000o`214ol0003o0000o`1_<Ol0
0004o`1/=P03o`000?l0JcOo06/g00;o06/g00?o0000o`1KAol0FdL01?l0FdL01?l0003o05m4o`1O
A?l00002o`1@CP03o`000?l0ET_o05I;00?o05I;00Co0000o`13BOl0@dWo00000ol0DDd00ol0003o
03e7o`0mA`02o`0mA`03o`000?l0DDgo000000Ko04=900?o0000o`0f@ol000000ol0D4h00ol0003o
04Y=o`1:C@04o`1:C@03o`000?l0B4_o04Q;00;o04Q;00Co0000o`1:COl0BTgo04Y=5_l000000ol0
J3_o0000o`1c:`03o`1c:`03o`000?l0PA?o084C00;o084C00?o0000o`f?0?l=S`000ol00004oa^D
0003o`000?m<Y@3oC:D000;o00001?m][P001_l0003o[kl0o`000?l0003oVkX0o`0000Cobk@00_l0
0002omRA0003o`000?oUI@3o000000;oiFD00ol0000Hooooo`03o`000?oooooooooo00Wooooo000=
ooooo`;o00001?ooool01?l0003oiV@0onIT0?l00002oo0o00_o00000ooi6`000ol0003onAX0ooTJ
0005ooTJ00?o00001?ob=P02o`0000Coje4000Go0000on9a0?oRL@3ohW40o`000004omRA0004o`00
0?o=[`3ocJl0olf_00oo00000_lKU0001Ol0003o1X`0o`J<0?l6S03o000000Go08D900?o0000o`21
4ol0PA<00_l0PA<2o`0000?o06`f00?o0000o`1[=ol0JcL00ol0JcL00ol0003o05]7o`1KA`03o`1K
A`07o`000?l0GdCo05m4o`1OA?l0003o051>o`000006o`1FB`03o`000?l0@dWo000000Go055=00Co
0000o`0mAol0?DOo00000ol0DDd00ol0003o04=9o`13B@03o`13B@;o00001Ol0D4h00ol0003o04Y=
o`1:C@03o`1:C@03o`000?l0B4_o04Q;00;o04Q;1?l00002o`1KA`03o`000?l0GdCo05m400;o05m4
00?o0000o`1T?ol0I3l00ol0I3l00ol0003o06`fo`1/=P02o`1/=P04o`000?l0MBOo07DWo`1e9`Go
00000_l0Lb/00ol0003o084Co`214`02o`214`03o`000?l=S`3o3Hl000;o3Hl00_l00002oa^D0003
o`000?m<Y@3oC:D000;oC:D00_l00003off^0003o`000?n__`3o[kl000;o00001?o;]0002?l0003o
fXT0o`000?l0003of940o`000?oUI@3o00000ooUI@000ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Sooooo0004ooooo`?o00001Oooool2o`0000Kooooo00?o0000onIT0?l000000_l00002
oo0o0003o`000?of9`3omRL000ComRL000?o0000ooTK0?oi6`000ooi6`000ol0003onAX0ooTJ0002
ooTJ00;o00000oog9@02o`000003oo8f0?l0003oje4000?oje400_l00003on9a0003o`000?oHT@3o
f94000;of94000Go0000olf_0?o=[`3ocJl0o`000003ok[20003o`000?n?^03oSkP000;oSkP000Go
0000of^^0?m[[P3oJjh0o`000002odbU00Co000000?o1X`0o`000?l0Q@T01?l0Q@T00ol0003o084C
o`214`02o`214`06o`000?l0OAWo07dIo`000?l0K3Ko00001Ol0JcL00ol0003o06`fo`000003o`1K
A`03o`000?l0GdCo05m400?o05m400?o0000o`1FBol0ET/01Ol0ET/2o`0000Ko055=00?o0000o`0m
Aol000001?l0DDd00ol0003o04=9o`13B@02o`13B@03o`000?l0ET_o000000Go051>00?o0000o`1:
COl0BTd00ol0BTd00ol0003o04Q;o`000002o`000003o`1JB?l0003o05]700Co05]700?o0000o`1O
A?l0Gd@00_l0Gd@00ol0003o06@oo`1T?`03o`1T?`03o`000?l0K3Ko06`f00;o06`f00?o0000o`1e
9ol0MBL00_l0MBL00ol0003o084Co`214`03o`0000Co084C00?o0000o`f?0?l=S`000_l=S`001_l0
003o=ih0o`000?l0003o6i@0o`0000?oC:D000Ko0000ohNe0?l0003o0000off^0?l00004ojno00;o
00000oo;]0000ol0003ofXT0omZ90002o`000003onEU0?l0003oiFD000?oiFD000?o0000oooooooo
ool05_ooool00ol0003oooooooooo`08ooooo`000oooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool00oooool3o`000003onIT0?l0003ol3l000?ol3l000?o0000ooHW0?of
9`001?of9`000ol0003onA/0ooTK0003ooTK0004o`000?oi6P3o0000o`0000KombD01?l00002on]A
0003o`000?oRL@3ohW4000;ohW4000?o0000omRA0?oHT@000_oHT@001Ol0003ocJl0olf_0?o=[`3o
000000?o^/8000?o0000ohnh0?n?^0000_n?^0001Ol0003oJjh0of^^0?m[[P3o000000CoC:D000?o
0000ocBM0?ldW@000_l00004o`252@03o`000?l0PA?o084C00;o084C00?o0000o`1m6Ol0OAT00_l0
OAT00ol0003o06/go`1[=`03o`1[=`07o`000?l0K3Ko06`fo`1/=_l0003o05]7o`000006o`1OA003
o`000?l0ET_o05I;00Co05I;00?o0000o`1NAOl000001_l0DDd2o`0000Go055=00?o0000o`13BOl0
@dT00_l00002o`1FB`03o`000?l0D4ko051>00?o051>00?o0000o`1:COl0BTd00ol0BTd2o`0000Go
05Y800?o0000o`1KAol0FdL00_l0FdL00ol0003o05m4o`1OA002o`1OA003o`000?l0I3oo06@o00?o
06@o00?o0000o`1/=_l0K3H00_l0K3H00ol0003o07DWo`1e9`03o`1e9`03o`000?l0PA?o084C00;o
084C0_l00002o`214`03o`000?l=S`3o3Hl000?o3Hl000?o0000ocNN0?lgWP000_l00004odbU0003
o`000?n7]@3oQkD000;o00001?n__`000ol0003ocjT0o`000002o`000003ol^d0?l0003ofXT000;o
fXT01Ol000000ooUI@3o0000ooooo`0Gooooo`03o`000?oooooooooo00Sooooo0007ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000onIT0002onIT0003
o`000?o`?`3ol3l000;ol3l000?o0000ooHW0?of9`001?of9`001?l0003onA/0ooTK0?oi6`04o`00
00GombD00_l00004oo4i00Co00000_oRL@000ol0003of940omRA0002omRA0005o`000?o=[`3ocJl0
olf_0?l000000onj`P000ol0003oSkP0ohnh0002ohnh0005o`000?m[[P3oJjh0of^^0?l000001?m<
Y@001_l0003o=9d0ocBM0?ldW@3o0000ob:G00;o000000?o08D9o`000?l0PA<00ol0PA<00ol0003o
07dIo`1m6@03o`1m6@;o00000ol0JcL00ol0003o06`fo`1/=P03o`1/=P03o`000?l0GdCo05m400Co
05m400?o0000o`1T?ol000001?l0ET/01Ol0003o05i5o`1NAOl0GTGo000000Co055=00?o0000o`1K
Aol000001_l0DDd2o`0000Go05I;00?o0000o`1@C_l0D4h00ol0D4h00ol0003o04Y=o`000002o`00
0003o`1KAol0003o05Y800Co05Y800?o0000o`1KAol0FdL00ol0FdL00ol0003o05m4o`1OA002o`1O
A003o`000?l0I3oo06@o00?o06@o00?o0000o`1/=_l0K3H00_l0K3H00ol0003o07DWo`1e9`02o`1e
9`03o`000?l0PA?o084C00;o084C00?o0000o`R=0?l000000ol00004o`f?0003o`000?lgWP3o=ih0
00;o=ih00ol00002odbU0004o`000?n7]@3oQkD0ohNe00;o00000on__`001?l0003ocjT0olnY0?o?
Z@02o`0000?ofXT000Go0000onMN0?oWGP3o0000onMN0003o`0001Oooooo00?o0000ooooooooool0
2?ooool000Gooooo0_l00005ooooo`Co00001Oooool2o`0000;oiV@000?o0000oo0o0?o`?`000_o`
?`001?l0003omRL0ooHW0?of9`06o`0000ConA/00_l000000oog9@3o0000o`000005oo4i0003o`00
0?oZE03ojU@000;ojU@01?l00002omRA0005o`000?o=[`3ocJl0olf_0?l000000onj`P000ol0003o
SkP0ohnh0002ohnh0005o`000?m[[P3oJjh0of^^0?l000001?m<Y@001Ol0003o=9d0ocBM0?ldW@3o
000000Co8YL00_l00003o`214`03o`000?l0OAWo07dI00?o07dI00Ko0000o`1l6ol0O1_o0000o`1[
=ol00006o`1/=P03o`000?l0GdCo05m400?o05m400Go0000o`1T?ol0I3oo06@oo`000002o`1FB`03
o`000?l0GTGo05i500;o05i500?o0000o`1ACOl0DDd00_l00003o`1KA`03o`000?l0DDgo055=00;o
055=0_l00006o`1FB`03o`000?l0D4ko051>00;o051>0ol00004o`1KA`03o`000?l0FTSo05Y800Co
05Y800?o0000o`1KAol0FdL00_l0FdL00ol0003o05m4o`1OA002o`1OA003o`000?l0I3oo06@o00?o
06@o00?o0000o`1/=_l0K3H00_l0K3H00ol0003o07DWo`1e9`03o`1e9`05o`000?l0PA?o084Co`21
4ol000001?l8S@03o`0000;o3Hl000?o0000ocNN0?lgWP000_lgWP000ol0003oJjh0of^^0003o`00
00?oQkD000?o0000olG20?l000000_l000000on__`3o0000olnY0003olnY00?o000000CofXT0o`00
0?oWGP3o00000ooWGP000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo0007oooo
o`03o`000?oooooooooo00;ooooo0_l00007ooooo`03o`000?o_@@3o000000;o00000oo`?`05o`00
00ConA/000?o0000ooTK0?oi6`001?oi6`03o`0000ColCT00_l00004onYD0003o`000?oRL@3ohW40
00;ohW403?l00002ohnh0003o`000?m[[P3oJjh000;oJjh000Go0000odbU0?m<Y@3oC:D0o`000003
ocBM0003o`000?lRU`3o8YL000?o8YL000Go0000oaJB0?l0003o084Co`000005o`1m6@03o`000?l0
O1_o07`K00;o07`K00?o0000o`1/=_l0K3H01?l0K3H00ol0003o06lao`000003o`1OA003o`000?l0
I3oo06@o00;o06@o00?o0000o`1FBol000001Ol0GTD00ol0003o055=o`000005o`1KA`07o`000?l0
DDgo055=o`1ACOl0003o05i5o`000006o`1FB`03o`000?l0D4ko051>00;o000000?o05m4o`000?l0
FdL01Ol0FdL00ol0003o05Y8o`1JB003o`1JB003o`000?l0FdOo05]700;o05]700?o0000o`1OA?l0
Gd@00_l0Gd@00ol0003o06@oo`1T?`03o`1T?`03o`000?l0K3Ko06`f00;o06`f00?o0000o`1e9ol0
MBL00ol0MBL00ol0003o084Co`214`02o`214`05o`000?l8S@3o28d0o`R=0?l000000_l]V`04o`00
00Co=ih000?o0000of^^0?m[[P000_m[[P02o`0000;oQkD000Co0000olG20?o5`P3oaL800_l00004
olnY0003o`000?oNOP3ogWh000?o000000?oieh0o`000?oWGP000_oWGP000ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Sooooo0003ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`05ooooo`04o`000?o_@@3okd40onm100?o00000_of9`000ol0003onA/0ooTK
0005ooTK0004o`000?oi6`3onA/0ooTK00;o00000oof9P02o`000003oo4i0?l0003ojU@000?ojU@0
0_l00004on9a0005o`000?oISP3ofHh0omV>0?l000001?o?Z@001?l0003oa/40olK10?o6`@04o`00
00;oJjh000Go0000odbU0?m<Y@3oC:D0o`000003ocBM0003o`000?lRU`3o8YL000?o8YL000Go0000
oaJB0?lFTP3o5Y80o`000005o`1m6@03o`000?l0O1_o07`K00?o07`K00?o0000o`1/=_l0K3H00ol0
K3H01ol0003o06lao`1_<Ol0Kc7o0000o`1OA?l000001_l0I3l00ol0003o05i5o`1NA@05o`1NA@03
o`000?l0FdOo05]700Co05]700Co0000o`1ACOl0DDgo00000ol0GTD00ol0003o05I;o`1FB`04o`1F
B`;o00001?l0Gd@00ol0003o05]7o`1KA`03o`1KA`03o`000?l0FTSo05Y800?o05Y800Co0000o`1K
Aol0FdOo05]75_l000000ol0MBOo0000o`214`03o`214`03o`000?l8S@3o28d000;o28d000?o0000
obfK0?l]V`000_l]V`02o`0000?o=ih000?o0000of^^0?m[[P000_m[[P001_l0003oY[d0o`000?l0
003oQkD0o`0000CoaL800ol00002olnY0003o`000?oNOP3ogWh000;ogWh01Ol000000ooWGP3o0000
ooooo`0Dooooo`03o`000?oooooooooo00Sooooo0004ooooo`?o00002?ooool00ol0003ooooooooo
o`05ooooo`04o`000?o_@@3okd40o`0000GomRL000?o0000ooTK0?oi6`001Ooi6`000ol0003onA/0
o`000006ooHV00Co00000_oZE0000ol0003ohW40on9a0002on9a00;o00000ooISP000ol0003ocjT0
olnY0002olnY0003o`000?o6`@3oa/4000;oa/4000Co0000ojJm0?nV_@3oY[d01?l000000om<Y@3o
0000ocBM0003ocBM0003o`000?lRU`3o8YL000;o8YL000?o0000oaJB0?lFTP000_lFTP02o`0000?o
07dI00?o0000o`1l6ol0O1/00ol0O1/00ol0003o07dIo`000003o`1/=P03o`000?l0Kc7o06la00?o
06la00?o0000o`1T?ol0I3l01Ol0I3l00ol0003o05i5o`1NA@04o`1NA@;o00001ol0FdL2o`0000Co
05i500?o0000o`1FBol0ET/00ol0ET/2o`0000Go05m400?o0000o`1KAol0FdL00ol0FdL00ol0003o
05Y8o`1JB003o`1JB0Co00000_l0K3H00ol0003o06lao`1_<@02o`1_<@03o`000?l0M2Wo07@Y00?o
07@Y00?o0000o`1k7Ol0Nad00_l0Nad01?l0003o08@;o`242ol0Q0/4o`0000;o084C00?o0000o`R=
0?l8S@000_l8S@000ol0003o;I/0obfK0002obfK0006o`000?mJZ@3o0000o`000?lgWP3o00001Om[
[P000ol0003oY[d0ojJm0002o`0000CoaL8000?o0000omBK0?oDV`000ol00004omin0005o`000?oZ
E@3ojUD0o`000?oZE@000ol0000Dooooo`03o`000?oooooooooo00Sooooo000@ooooo`03o`000?oo
oooooooo00Cooooo00Go0000onm10?o_@@3okd40o`000005ooHW0003o`000?oi6`3onA/000ConA/0
0ol00004ooHV00;o00001?oa>@04o`0000;ohW4000?o0000omV>0?oISP000_oISP000ol0003ocjT0
olnY0002olnY0003o`000?o6`@3oa/4000;oa/4000?o0000ojJm0?nV_@000_nV_@001?l0003oQkD0
ohNe0?n7]@03o`0000;o=9d000?o0000ob:G0?lRU`000_lRU`000ol0003o5Y80oaJB0002oaJB0006
o`000?l?T03o3i00o`000?l0OAWo00001Ol0O1/01ol0003o07dIo`1m6Ol0OAWo0000o`1/=_l00000
1_l0Kc400ol0003o06@oo`1T?`04o`1T?`03o`000?l0K3Ko000000Co05i500Co0000o`1X>ol0J3_o
00001Ol0FdL2o`0000Ko05i500?o0000o`1FBol0ET/00_l000000ol0I3oo0000o`1OA005o`1OA003
o`000?l0FdOo05]700?o05]700?o0000o`1JB?l000000_l000000ol0JcOo0000o`1/=P04o`1/=P03
o`000?l0Kc7o06la00;o06la00?o0000o`1d:Ol0M2T00_l0M2T00ol0003o07/Mo`1k7@03o`1k7@03
o`000?l0Q0_o08@;00;o08@;00?o0000o`f?0?l000000ol00004o`R=0003o`000?l]V`3o;I/000;o
;I/000?o0000oeZY0?mJZ@000ol00004of^^0003o`000?nV_@3oY[d000;oY[d00_l00003olG20003
o`000?oDV`3oe9/000;oe9/00ol00002omin0003o`000?oZE@3o000000?ojUD000?o0000oooooooo
ool04oooool00ol0003oooooooooo`07ooooo`004Oooool2o`0000Gooooo00Go0000onm10?o_@@3o
kd40o`000005ooHW0003o`000?oi6`3onA/000?o00000ooi6`02o`000003ooHV0?l0003olCT000Co
lCT000?o0000on]A0?o[D@000_o[D@04o`0000;ofHh000?o0000olnY0?o?Z@000_o?Z@000ol0003o
a/40olK10002olK10003o`000?nV_@3oY[d000;oY[d000?o0000ohNe0?n7]@000_n7]@000ol0003o
KJh0off^0003o`0000?o8YL000?o0000oaJB0?lFTP000_lFTP000ol0003o3i00o`n@0002o`n@00;o
00001?l0O1/00ol0003o07dIo`1m6@03o`1m6@03o`000?l0Kc7o06la00Co06la00?o0000o`1d:Ol0
00001?l0I3l01Ol0003o06`fo`1/=_l0K3Ko000000;o05i500Go0000o`1X>ol0J3_o06Pko`000004
o`1KA`03o`000?l0J3_o000000Ko05i500?o0000o`1FBol000001?l0I3l00ol0003o05m4o`1OA003
o`1OA003o`000?l0FdOo05]700;o05]70ol00004o`1[=`03o`000?l0K3Ko06`f00?o06`f00?o0000
o`1_<Ol0Kc400_l0Kc400ol0003o07@Yo`1d:@03o`1d:@03o`000?l0Nago07/M00;o07/M00?o0000
o`242ol0Q0/00_l0Q0/00ol0003o3Hl0o`f?0002o`f?00Co000000?o28d0o`000?l]V`000ol]V`00
0ol0003oFZT0oeZY0002oeZY00?o00000_m[[P000ol0003oY[d0ojJm0002ojJm0006o`000?o</@3o
0000o`000?o5`P3o00001?oDV`000ol0003ohW40on9a0004o`000003onYE0?l0003ojUD000;ojUD0
00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`004oooool00ol0003ooooooooo
o`03ooooo`Go00000oof9`04o`0000OonA/00ol00004oo4i0003o`000?o[D@3oje4000?oje4000Co
0000onA[0?oTJ`3oi6/01?l00002olnY0003o`000?o6`@3oa/4000;oa/4000?o0000ojJm0?nV_@00
0_nV_@000ol0003oQkD0ohNe0002ohNe0005o`000?m][P3oKJh0off^0?l000000_mJZ@000ol0003o
8YL0o`000004oaJB0003o`000?l?T03o3i0000?o3i0000?o0000o`f?0?l000000ol0O1/00ol0003o
07dIo`1m6@03o`1m6@03o`000?l0Kc7o06la00?o06la00Go0000o`1d:Ol0M2Wo07@Yo`000002o`1T
?`03o`000?l0K3Ko06`f00;o06`f00?o0000o`1NAOl000001Ol0J3/01?l0003o05]7o`1KAol00003
o`1X>`03o`000?l0GTGo05i500?o05i50_l00005o`1T?`03o`000?l0GdCo05m400?o05m400?o0000
o`1KAol000000_l000000ol0K3Ko0000o`1[=`05o`1[=`03o`000?l0K3Ko06`f00;o06`f00?o0000
o`1_<Ol0Kc400ol0Kc400ol0003o07@Yo`1d:@02o`1d:@03o`000?l0Nago07/M00?o07/M00?o0000
o`242ol0Q0/00_l0Q0/01Ol0003o3Hl0o`f?0?l=S`3o000000?o;I/01Ol00002obfK0005o`000?mJ
Z@3oFZT0oeZY0?l000000_n?^004o`0000CoY[d000?o0000olba0?o</@000_l00005omBK0003o`00
0?oRL@3ohW4000;ohW401Ol000000ooZE@3o0000ooooo`0Cooooo`03o`000?oooooooooo00Oooooo
000Dooooo`03o`000?oooooooooo00;ooooo00Co0000ooHY0?of:@3omRT01?l00004ooTK0003o`00
0?oi6`3onA/000;onA/00_l00003ooLU00;o000000?olCT0o`000?o[D@001?o[D@000ol0003oi6/0
onA[0002onA[0004o`000?oLQ@3og8D0omb500Co00000_o6`@000ol0003oY[d0ojJm0002ojJm0003
o`000?n7]@3oQkD000;oQkD000Go0000off^0?m][P3oKJh0o`000004oeZY00;o00001?lFTP000ol0
003o3i00o`n@0002o`n@0007o`000?l=S`3o3Hl0o`f?0?l0003o07`Ko`000005o`1m6@03o`000?l0
PA?o000000?o06la00?o0000o`1d:Ol0M2T00_l0M2T00ol0003o06@oo`000006o`1/=P03o`000?l0
J3_o06Pk00Co06Pk00?o0000o`1KAol000001?l0J3/00ol0003o05i5o`1NA@02o`1NA@03o`000?l0
K3Ko000000Ko06@o00?o0000o`1OA?l0Gd@00_l0Gd@2o`0000Go06`f00?o0000o`1[=ol0JcL00ol0
JcL00ol0003o06`fo`1/=P03o`1/=P03o`000?l0Kc7o06la00;o06la00?o0000o`1d:Ol0M2T00_l0
M2T00ol0003o07/Mo`1k7@03o`1k7@03o`000?l0Q0_o08@;00;o08@;00?o0000o`f?0?l=S`000_l=
S`000ol0003o;I/0obfK0002obfK0003o`000?mDY`3oE:L000?o00001?mJZ@000ol0003oSkP0ohnh
0002ohnh00;o00000onV_@000ol0003oc;40olba0002olba00?o00000ooDV`000ol0003ohW40on9a
0002on9a0003o`000?o]BP3okDX000Co00004oooool00ol0003oooooooooo`07ooooo`005Oooool0
0ol0003oooooooooo`02ooooo`03o`000?of:@3omRT000;omRT000?o0000ooTK0?oi6`001?oi6`00
1?l0003onA/0o`000?l00006ooLU00?o00001?o[D@000ol0003oi6/0onA[0002onA[0003o`000?oL
Q@3og8D000;og8D000Co0000omBL0?oDW03oe9`01?l00002ojJm0003o`000?n7]@3oQkD000;oQkD0
00Go0000off^0?m][P3oKJh0o`000005oeZY0006o`000?m<Y@3o0000o`000?lFTP3o00001?l?T000
0ol0003o3Hl0o`f?0003o`f?0003o`000?l0OAWo07dI00?o07dI00Oo0000o`214ol0PA?o084Co`00
0?l0Kc7o000000Ko07@Y00?o0000o`1/=_l0K3H01Ol0K3H00ol0003o06Pko`1X>`05o`1X>`03o`00
0?l0J3_o06Pk00Co06Pk00Co0000o`1NAOl0GTGo00000ol0K3H00ol0003o06@oo`1T?`03o`1T?`03
o`000?l0GdCo05m400;o000000?o06lao`000?l0K3H01?l0K3H00ol0003o06/go`1[=`03o`1[=`03
o`000?l0K3Ko06`f00?o06`f00?o0000o`1_<Ol0Kc400_l0Kc400ol0003o07@Yo`1d:@03o`1d:@03
o`000?l0Nago07/M00;o07/M00?o0000o`242ol0Q0/00_l0Q0/00ol0003o3Hl0o`f?0002o`f?0003
o`000?l]V`3o;I/000?o;I/000?o0000oeBW0?mDY`000_mDY`02o`0000;oFZT000?o0000ohnh0?n?
^0000_n?^0000ol0003oa/40o`000002o`000003ojJm0?l0003oc;4000;oc;4000?o0000omZ90?oJ
R@001?l00005on9a0003o`000?o]BP3o000000;okDX000?o0000ooooooooool04Oooool00ol0003o
ooooooooo`07ooooo`005_ooool2o`0000?ooooo00?o0000ooHY0?of:@000_of:@000ol0003onA/0
ooTK0003ooTK00?o00001_og9@001?l0003olSH0oo8f0?ob=P02o`000003on]A0?l0003oi6/000?o
i6/000?o0000omb50?oLQ@000_oLQ@000ol0003oe9`0omBL0002omBL0004o`000?o</@3oc;40olba
00Co00000_n7]@001Ol0003oKJh0off^0?m][P3o000000GoFZT000?o0000odbU0?m<Y@000_m<Y@02
o`0000?o3i0000?o0000o`f?0?l=S`000ol=S`000ol0003o3i00o`000003o`1m6@03o`000?l0PA?o
084C00?o084C00?o0000o`1d:Ol0M2T01?l0M2T2o`0000Ko06`f00?o0000o`1e9ol000001Ol0J3/2
o`0000Ko06Pk00?o0000o`1NAOl000001?l0K3H00ol0003o06@oo`1T?`03o`1T?`03o`000?l0GdCo
000000Co06la00?o0000o`1/=_l0K3H00ol0K3H00ol0003o06/go`1[=`02o`1[=`03o`000?l0K3Ko
06`f00?o06`f00Co0000o`1_<Ol0Kc7o06la4Ol000000ol0Q0_o0000o`f?0003o`f?0003o`000?l]
V`3o;I/000;o;I/000?o0000oeBW0?mDY`000_mDY`001_l0003oQ;@0o`000?l0003oFZT0o`0000Co
SkP000Co0000olK10?o6`@3oa/400_l00004olba0003o`000?oJR@3ofXT000;ofXT01Ol000001OoR
L@3o0000one:0?o]BP3o000000;okDX000?o0000ooooooooool04?ooool00ol0003oooooooooo`07
ooooo`006?ooool01Ol0003ooooooooooooooooo000000ComRT000?o0000ooTK0?l000000_l00003
ooTJ0004o`000?og9@3ombD0ooLU00;o00001Oob=P04o`0000;oi6/000?o0000omb50?oLQ@000_oL
Q@000ol0003oe9`0omBL0002omBL0003o`000?o</@3oc;4000;oc;4000Co0000olG20?o5`P3oaL80
1?l000000om][P3o0000oeZY0004oeZY0003o`000?m<Y@3oC:D000;oC:D000Ko0000odBR0?m4XP3o
0000o`n@0?l00005o`f?0007o`000?l?T03o3i00o`n@0?l0003o07dIo`000006o`214`03o`000?l0
M2Wo07@Y00?o07@Y00Co0000o`1k7Ol0Nago00001?l0K3H01?l0003o07DWo`1e9ol00004o`1X>`04
o`000?l0Lb_o07<[o`0000Go06Pk0_l00006o`1/=P03o`000?l0I3oo06@o00;o06@o0_l00005o`1_
<@03o`000?l0K3Ko06`f00?o06`f00?o0000o`1[=ol0JcL00ol0JcL00ol0003o06`fo`1/=P06o`00
00;o084C00?o0000o`252Ol0Q@T00_l0Q@T00ol0003o1X`0o`J<0003o`J<0004o`000?lKU03o6i@0
oa^D00Co00000_l=S`000ol0003o;I/0obfK0003obfK0003o`000?mDY`3oE:L000;oE:L000?o0000
ohBd0?n4]0000_l00004ohnh0003o`000?o6`@3oa/4000?oa/400ol00002olba0003o`000?oJR@3o
fXT000;ofXT000Co0000onIQ0?oVH@3oiV401ol000000oo]BP3o0000ooooo`0@ooooo`03o`000?oo
oooooooo00Oooooo000Iooooo`04o`000?ooooooooooooooo`Oo00001_oi6P000ol0003ombD0o`00
0006oo8f0003o`000?o]BP3okDX000;okDX01?l00002omb50003o`000?oDW03oe9`000;oe9`000?o
0000olba0?o</@000_o</@000ol0003oaL80olG20002olG20004o`000?n__`3o[kl0ojno00;o0000
1?mJZ@000ol0003oC:D0odbU0002odbU0003o`000?m4XP3oA:8000;oA:8000?o0000o`f?0?l=S`00
0ol=S`000ol0003o3i00o`n@0003o`n@0003o`000?l0PA?o084C00Co084C00?o0000o`252Ol00000
0ol0M2T00ol0003o07/Mo`1k7@02o`1k7@04o`000?l0K3Ko06`fo`0000Co07DW00Co0000o`1X>ol0
J3_o00000ol0Lb/00ol0003o06Pko`1X>`02o`1X>`03o`000?l0MBOo000000Ko06`f00?o0000o`1T
?ol0I3l00_l000000ol0M2Wo0000o`1_<@05o`1_<@03o`000?l0K3Ko06`f00;o06`f00Co0000o`1[
=ol0JcOo06/g1Ol00003o`1m6@03o`000?l0PA?o084C00?o084C00?o0000o`252Ol0Q@T00_l0Q@T0
0ol0003o1X`0o`J<0003o`J<0005o`000?lKU03o6i@0oa^D0?l000000_lgWP03o`0000Go;I/000?o
0000oeBW0?mDY`000_mDY`000ol0003oQ;@0ohBd0002ohBd00?o00000_n?^0000ol0003oa/40olK1
0002olK10003o`000?oDW03oe9`000?o00001OoJR@000ol0003oiV40onIQ0002onIQ0004o`000?o`
?@3ol3d0oo0m00Co00004?ooool00ol0003oooooooooo`07ooooo`006_ooool01?l0003ooooooooo
ool00006ooTM0003o`000?oi6P3onAX000?onAX00ol00004oo8f00;o00001?o]BP000ol0003oif00
onMP0002onMP00Co00000_oDW0000ol0003oc;40olba0002olba0003o`000?o5`P3oaL8000;oaL80
00?o0000ojno0?n__`000_n__`001_l0003oVkX0o`000?l0003oFZT0o`0000CoC:D000?o0000odBR
0?m4XP000om4XP02o`0000?o3Hl000?o0000o`n@0?l?T0001?l?T0000ol0003o084Co`214`03o`21
4`07o`000?l0Q@Wo08D9o`252Ol0003o07@Yo`000005o`1k7@03o`000?l0K3Ko000000Go07DW00?o
0000o`1X>ol000001Ol0Lb/01?l0003o06Pko`1X>ol00003o`1e9`03o`000?l0K3Ko06`f00?o06`f
00?o0000o`1T?ol000001?l0M2T00ol0003o06lao`1_<@03o`1_<@03o`000?l0K3Ko06`f00;o06`f
1?l00002o`1l6`03o`000?l0OAWo07dI00?o07dI00?o0000o`214ol0PA<00ol0PA<00ol0003o08D9
o`252@02o`252@03o`000?l6S03o1X`000?o1X`000?o0000oa^D0?lKU0000_lKU0000ol0003o=ih0
ocNN0002ocNN00Co000000?o;I/0o`000?mDY`001?mDY`001Ol0003oQ;@0ohBd0?n4]03o000000;o
^/800ol00005olK10003o`000?oDW03oe9`000;oe9`00ol00002omZ90003o`000?oVH@3oiV4000?o
iV4000Co0000oo0m0?o`?@3o00000_o`?@000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Kooooo000Kooooo`;o000000?oooooo`000?oi7@001Ooi7@000ol0003onAX0o`000002o`0000?o
mb800_l000000oob=P3o0000one:0004one:0003o`000?oWH03oif0000;oif0000?o0000on5e0?oQ
M@000_oQM@03o`0000?oc;4000?o0000olG20?o5`P000_o5`P000ol0003o[kl0ojno0002ojno0003
o`000?nK^P3oVkX000;oVkX00_l00003odbU0003o`000?m4XP3oA:8000?oA:8000Ko0000od6Q0?m1
X@3o0000o`f?0?l00006o`n@0003o`000?lFTP3o000000?o084C00?o0000o`252Ol0Q@T00ol0Q@T0
0ol0003o07/Mo`1k7@05o`1k7@03o`000?l0MBOo07DW00Go07DW00?o0000o`1c:ol0Lb/01?l0Lb/0
0ol0003o06Pko`000004o`1e9`03o`000?l0K3Ko06`f00?o06`f0_l00005o`1d:@03o`000?l0Kc7o
06la00?o06la00?o0000o`1/=_l000000_l000000ol0OAWo0000o`1l6`04o`1l6`03o`000?l0OAWo
07dI00?o07dI00?o0000o`214ol0PA<00_l0PA<00ol0003o08D9o`252@02o`252@03o`000?l6S03o
1X`000?o1X`000?o0000oa^D0?lKU0000_lKU0000ol0003o=ih0ocNN0002ocNN0004o`000?mJZ@3o
FZT0oeZY00Go00000_mDY`000ol0003oQ;@0ohBd0002ohBd0003o`000?nj`P3o^/8000;o^/800ol0
0002olK10003o`000?oDW03oe9`000;oe9`000?o0000on5e0?oQM@000ol00006onIQ0004o`000?o`
?@3ol3d0o`0000;ol3d000?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`007Ooo
ool00ol0003oooooo`000005ooTM00?o00001_og8P03o`0000CokDX000?o0000onMP0?oWH0000_oW
H0000ol0003ohGD0on5e0003on5e0006o`000?oJR@3ofXT0o`000?o</@3o00001?o5`P000ol0003o
[kl0ojno0002ojno0003o`000?nK^P3oVkX000?oVkX000Go0000ohfg0?l0003oC:D0o`000005odBR
0003o`000?m1X@3o@J4000;o@J4000?o0000o`n@0?l?T0001?l?T0001ol0003o5Y80oaJB0?lFTP3o
0000o`214ol000001_l0Q@T00ol0003o07/Mo`1k7@04o`1k7@;o00001_l0MBL2o`0000Oo07<[00?o
0000o`1e9ol0MBL01?l0MBL01ol0003o06`fo`1/=_l0K3Ko0000o`1k7Ol000001_l0M2T00ol0003o
06lao`1_<@02o`1_<@;o00001Ol0OAT00ol0003o07`Ko`1l6`02o`1l6`03o`000?l0OAWo07dI00?o
07dI00?o0000o`214ol0PA<00ol0PA<00ol0003o08D9o`252@02o`252@03o`000?l6S03o1X`000?o
1X`000Go0000oa^D0?lKU03o6i@0o`000005ocNN0003o`000?mJZ@3oFZT000;oFZT000?o0000ohBd
0?n4]0000ol00004ohBd0003o`000?nj`P3o^/8000;o^/8000?o0000olnY0?o?Z@000ol00005omBL
0003o`000?oQM@3ohGD000;ohGD01Ol000000ooVH@3o0000oo0m0002oo0m0003o`000?o`?@3o0000
013ooooo00?o0000ooooooooool01_ooool001kooooo00Co0000ooooool0003onAd00ol00003ooTJ
0004o`000?og8P3omb80ooLR00;o00000ood;P02o`000003one:0?l0003oif0000?oif0000?o0000
on5e0?oQM@000ooQM@000ol0003ofXT0omZ90002omZ900?o00000_o5`P000ol0003o[kl0ojno0002
ojno0003o`000?nK^P3oVkX000?oVkX000Co0000ohfg0?n=]`3oSKL00_l00004odBR0003o`000?m1
X@3o@J4000?o@J4000?o0000o`n@0?l?T0000ol?T0000ol0003o5Y80oaJB0003oaJB0003o`000?l0
Q@Wo08D900Co08D900?o0000o`J<0?l000001?l0Nad01?l0003o08@;o`242ol00004o`1e9`04o`00
0?l0PA?o084Co`0000Go07<[0_l00006o`1e9`04o`000?l0K3Ko06`fo`0000?o07/M00?o0000o`1d
:Ol0M2T00ol0M2T00ol0003o06lao`1_<@02o`000003o`214ol0003o07dI00Co07dI00?o0000o`1l
6ol0O1/00ol0O1/00ol0003o07dIo`1m6@02o`1m6@03o`000?l0PA?o084C00?o084C00?o0000o`25
2Ol0Q@T00_l0Q@T00ol0003o1X`0o`J<0003o`J<0003o`000?lKU03o6i@000;o6i@000?o0000ocNN
0?lgWP000_lgWP000ol0003oFZT0oeZY0003oeZY0003o`000?n4]03oQ;@000;oQ;@00ol00002ohBd
0003o`000?nj`P3o^/8000;o^/8000?o0000olnY0?o?Z@000_o?Z@03o`0000?oe9`000Go0000on5e
0?oQM@3ohGD0o`000004on]@00Wo00003oooool00ol0003oooooooooo`06ooooo`007oooool00ol0
003oooooo`000007ooTJ0003o`000?og8P3o000000Kom2h01?l00002onMP0003o`000?oQM@3ohGD0
00?ohGD000?o0000omZ90?oJR@000_oJR@001?l0003oe9/0omBK0?oDV`03o`0000Co[kl000?o0000
oi^j0?nK^P000_nK^P000ol0003oSKL0ohfg0002ohfg0003o`000?n4]03o000000?oA:8000?o0000
od6Q0?m1X@000_m1X@000ol0003oA:80o`000003o`n@0003o`000?lFTP3o5Y8000Co5Y8000?o0000
o`252Ol0Q@T00ol0Q@T01Ol0003o1X`0o`J<0?l6S03o000000;o07/M00?o0000o`242ol0Q0/00_l0
Q0/01?l0003o07DWo`1e9ol00003o`214`03o`000?l0Lb_o07<[00;o07<[00Co0000o`214ol0PA?o
00001Ol0MBL00ol0003o06`fo`000004o`1k7@03o`000?l0M2Wo07@Y00?o07@Y00?o0000o`1_<Ol0
00001?l0PA<00ol0003o07dIo`1m6@02o`1m6@03o`000?l0O1_o07`K00?o07`K00?o0000o`1m6Ol0
OAT00ol0OAT00ol0003o084Co`214`02o`214`03o`000?l0Q@Wo08D900;o08D900?o0000o`J<0?l6
S0000ol6S0000ol0003o6i@0oa^D0002oa^D0003o`000?lgWP3o=ih000?o=ih000?o0000oeZY0?mJ
Z@000_mJZ@000ol0003oQ;@0ohBd0002ohBd0003o`000?ne`@3o]L4000?o00001?nj`P000ol0003o
cjT0olnY0002olnY0003o`000?oLQ@3og8D000Co00001?oQM@000ol0003oje00on]@0003on]@0007
o`000?oc<@3olc40oo<a0?l0003olc40o`00000?ooooo`03o`000?oooooooooo00Kooooo000Poooo
o`03o`000?oooooo000000KonAX00ol00004oo@^00;o00001?o`?P03o`0000CohGD000?o0000omZ9
0?oJR@000_oJR@000ol0003oe9/0omBK0003omBK0006o`000?o?Z@3o0000o`000?n__`3o00001?nK
^P000ol0003oSKL0ohfg0002ohfg0007o`000?n4]03oQ;@0ohBd0?l0003oA:80o`000004od6Q0007
o`000?m4XP3oA:80odBR0?l0003o3i00o`000006oaJB0003o`000?lRU`3o000000?o08D900?o0000
o`J<0?l6S0000_l6S0000ol0003o07/Mo`000005o`242`03o`000?l0MBOo000000Go084C00Co0000
o`1c:ol0Lb_o00000ol0PA<00ol0003o07DWo`1e9`03o`1e9`;o00001_l0Nad00ol0003o07@Yo`1d
:@02o`1d:@;o00001Ol0PA<00ol0003o07dIo`1m6@03o`1m6@03o`000?l0O1_o07`K00;o07`K00Co
0000o`1m6Ol0OAWo07dI6?l00005ocNN0003o`000?mJZ@3oFZT000?oFZT000Go0000ohBd0?n4]03o
Q;@0o`000005okG100?o00000_nj`P000ol0003ocjT0olnY0002olnY0003o`000?oLQ@3og8D000;o
g8D01Ol000000ooQM@3o0000on]@0004on]@0007o`000?oc<@3olc40oo<a0?l0003olc40o`00000>
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`?o00000_oi6P03o`0000?onAd00_l000000ood
;P3o0000oo0n0004oo0n0004o`000?o[D03oje00on]@00;o000000?ohGD0o`000?oJR@000ooJR@00
0ol0003oe9/0omBK0003omBK0003o`000?o?Z@3ocjT000;ocjT00_l00003oi^j0003o`000?n=]`3o
SKL000;oSKL000?o0000ohBd0?n4]0000on4]0000ol0003o@J40od6Q0002od6Q0003o`000?m4XP3o
A:8000?oA:8000?o0000oaJB0?lFTP001?lFTP001Ol0003o8YL0ob:G0?lRU`3o000000;o08D900?o
0000o`J<0?l6S0000ol6S0000ol0003o08@;o`242`05o`242`03o`000?l0PA?o084C00Co084C00?o
0000o`1c:ol000001Ol0PA<01ol0003o07DWo`1e9ol0MBOo0000o`242ol000001_l0Nad00ol0003o
07@Yo`1d:@02o`000003o`252Ol0003o084C00Co084C00?o0000o`1m6Ol0OAT00ol0OAT00ol0003o
07`Ko`1l6`02o`1l6`Co00000_l?T0000ol0003o5Y80oaJB0003oaJB0003o`000?lRU`3o8YL000;o
8YL000?o0000ocBM0?ldW@000oldW@001?l0003oC:D0odbU0?m<Y@05o`000003ocNN0?l0003oFZT0
00CoFZT000?o0000ohBd0?n4]0000_n4]0000ol0003o]L40okG10002okG10003o`000?o=[`3ocJl0
00?o00001?o?Z@000ol0003og8D0omb50003omb50004o`000?oWH03oif00onMP00Ko000000?oje00
o`000?oc<@000ooc<@02o`0000kooooo00?o0000ooooooooool01_ooool002?ooooo0ol00007ooTM
00?o00001?o`?P000ol0003oje00on]@0003on]@00Co00000_oJR@000ol0003oe9/0omBK0003omBK
0003o`000?o?Z@3ocjT000;ocjT000Ko0000ol^d0?o;]03o0000oi^j0?l00004ohfg0003o`000?n4
]03oQ;@000?oQ;@000?o0000oh6d0?l000000om1X@000ol0003oA:80odBR0003odBR00;o00001?lF
TP000ol0003o8YL0ob:G0002ob:G0003o`000?l0Q@Wo000000Ko1X`000?o0000o`242ol0Q0/01Ol0
Q0/00ol0003o084Co`214`05o`214`03o`000?l0PA?o084C00Co084C00Co0000o`1e9ol0MBOo0000
0ol0Q0/00ol0003o07/Mo`1k7@03o`1k7@03o`000?l0M2Wo000000Co08D900?o0000o`214ol0PA<0
0ol0PA<00ol0003o07dIo`1m6@02o`1m6@03o`000?l0O1_o000000;o000000?o3Hl0o`000?l?T000
1?l?T0000ol0003o5Y80oaJB0002oaJB0003o`000?lRU`3o8YL000?o8YL000?o0000ocBM0?ldW@00
0_ldW@000ol0003oC:D0odbU0002odbU0004o`000?m[[P3oJjh0of^^00Ko000000?oFZT0o`000?n4
]0000on4]0000ol0003o]L40okG10003okG10003o`000?o=[`3ocJl000;ocJl00ol00002olnY0003
o`000?oLQ@3og8D000?og8D000?o0000onMP0?oWH0000_oWH0001?l0003ol3h0oo0n0?o`?P09o`00
00kooooo00?o0000ooooooooool01Oooool002Cooooo00?o0000ooooool000001?oi7@02o`0000?o
mRH00_l000000oo`?P3o0000on]@0004on]@0003o`000?oVH@3oiV4000;oiV400ol00004omBK0003
o`000?o?Z@3ocjT000;ocjT000?o0000ol^d0?o;]0000_o;]002o`0000CoSKL000?o0000ohBd0?n4
]0000_n4]0001ol0003oPK@0oh6d0?n1]03o0000od6Q0?l000001Om4XP001?l0003oC:D0odbU0?l0
0003oaJB0003o`000?lRU`3o8YL000?o8YL000?o0000o`J<0?l6S0001?l6S0000ol0003o6i@0o`00
0005o`242`03o`000?l=S`3o000000Go084C0_l00006o`214`03o`000?l0MBOo000000Co08@;00?o
0000o`1k7Ol0Nad00ol0Nad2o`0000Go08D900?o0000o`214ol0PA<00ol0PA<00ol0003o07dIo`1m
6@02o`1m6@;o00001Ol=S`000ol0003o3i00o`n@0002o`n@0003o`000?lFTP3o5Y8000?o5Y8000?o
0000ob:G0?lRU`000_lRU`000ol0003o=9d0ocBM0003ocBM0003o`000?m<Y@3oC:D000;oC:D000?o
0000of^^0?m[[P000_m[[P001?l0003oSkP0ohnh0?n?^004o`0000;oQ;@000?o0000okG10?ne`@00
0one`@000ol0003ocJl0olf_0002olf_0003o`000?oISP3ofHh000?o00001OoLQ@000ol0003oif00
onMP0003onMP0003o`000?o`?P3ol3h000;ol3h000?o0000ooHV0?of9P000_of9P02o`0000kooooo
00?o0000ooooooooool01Oooool002Gooooo00Co0000ooooool0003onAd00_l00006ooHV00?o0000
1?o[D0000ol0003oiV40onIQ0002onIQ0004o`000?oRL@3ohW40on9a00;o000000?oe9/0o`000?o?
Z@000oo?Z@000ol0003obk@0ol^d0003ol^d0006o`000?o8_03o0000o`000?n=]`3o00001?n4]000
0ol0003oPK@0oh6d0003oh6d0003o`000?m4XP3oA:8000?oA:8000?o0000odbU0?m<Y@000_m<Y@00
0ol0003o5Y80o`000006ob:G0003o`000?l6S03o1X`000?o1X`000Co0000oa^D0?lKU03o00001?l0
Q0/01?l0003o3Hl0o`f?0?l00004o`214`04o`000?l8S@3o28d0o`0000Go084C0_l00006o`242`07
o`000?l0Nago07/Mo`1k7Ol0003o1X`0o`000006o`252@03o`000?l0PA?o084C00;o084C00?o0000
o`1m6Ol000000_l000000ol?T03o0000o`f?0004o`f?0003o`000?l?T03o3i0000;o3i0000?o0000
oaJB0?lFTP000olFTP000ol0003o8YL0ob:G0003ob:G0003o`000?ldW@3o=9d000;o=9d000?o0000
odbU0?m<Y@000_m<Y@000ol0003oJjh0of^^0003of^^0003o`000?n?^03oSkP000;oSkP000?o0000
ok[20?l000000ol00004okG10003o`000?o=[`3ocJl000?ocJl000?o0000omV>0?oISP000_oISP04
o`000003omb50?l0003oif0000Coif0000?o0000oo0n0?o`?P000oo`?P000ol0003omRH0ooHV0002
ooHV00;o00003Oooool00ol0003oooooooooo`05ooooo`009_ooool4o`0000KomRH000Co0000oo<a
0?oc<@3olc400_l000000oo[D03o0000onIQ0003onIQ0003o`000?oRL@3ohW4000?ohW400ol00003
olnY0003o`000?o;]03obk@000?obk@000?o0000olRl0?o8_0000_o8_002o`0000?oQ;@000?o0000
oh6d0?n1]0000on1]0000ol0003oQ;@0o`000003odBR0003o`000?m<Y@3oC:D000CoC:D000?o0000
ob:G0?lRU`001?lRU`000ol0003o=9d0o`000003o`J<0003o`000?lKU03o6i@000;o6i@000Co0000
o`242ol0Q0_o00001?l=S`001?l0003o084Co`214ol00003o`R=0003o`000?l0PA?o084C00;o084C
00?o0000o`f?0?l000001_l0Q0/01?l0003o07/Mo`1k7Ol00002o`J<0003o`000?l0Q@Wo08D900Co
08D900?o0000o`214ol0PA<00_l0PA<2o`0000Go3i0000?o0000o`f?0?l=S`000_l=S`000ol0003o
3i00o`n@0003o`n@0003o`000?lFTP3o5Y8000;o5Y8000?o0000ob:G0?lRU`000olRU`000ol0003o
=9d0ocBM0002ocBM0003o`000?m<Y@3oC:D000?oC:D000?o0000of^^0?m[[P000_m[[P000ol0003o
SkP0ohnh0002ohnh0003o`000?nj`P3o^/8000;o^/801?l00002okG10003o`000?o=[`3ocJl000;o
cJl000?o0000omV>0?oISP000_oISP001?l0003oi6/0onA[0?oTJ`06o`000003onMP0?l0003ol3h0
00Gol3h000?o0000ooHV0?of9P000_of9P02o`0000cooooo00?o0000ooooooooool01Oooool002So
oooo00?o0000ooooool000000oof9P02o`0000Golc400ol00003onIQ0003o`000?oRL@3ohW4000?o
hW4000Oo0000omin0?oNOP3ogWh0o`000?o?Z@3o000000Gobk@000?o0000olRl0?o8_0000_o8_000
1_l0003oa/40olK10?l0003oQ;@0o`0000GoPK@000Oo0000ohBd0?n4]03oQ;@0o`000?m4XP3o0000
00KoC:D00_l00005ob:G0007o`000?ldW@3o=9d0ocBM0?l0003o1X`0o`000005oa^D0003o`000?l0
Q0_o000000Go3Hl000?o0000o`214ol000001Ol8S@001?l0003o084Co`214ol00003o`f?0003o`00
0?l0Q0_o08@;00?o08@;00?o0000o`1k7Ol000001?l6S0000ol0003o08D9o`252@03o`252@03o`00
0?l0PA?o000000;o000000?o5Y80o`000?l?T0001?l?T0000ol0003o3Hl0o`f?0003o`f?0003o`00
0?l?T03o3i0000;o3i0000?o0000oaJB0?lFTP000olFTP000ol0003o8YL0ob:G0002ob:G0003o`00
0?ldW@3o=9d000?o=9d000?o0000odbU0?m<Y@000_m<Y@000ol0003oJjh0of^^0003of^^0003o`00
0?n?^03oSkP000;oSkP000Go0000ok[20?nj`P3o^/80o`000003olf_00Go00000_o=[`000ol0003o
fHh0omV>0003omV>0003o`000?oTJ`3oi6/000;oi6/000Co0000one:0?o]BP3okDX04?l0000;oooo
o`03o`000?oooooooooo00Gooooo000Yooooo`05o`000?oooooo0000ooHV0?l000001_oc<@001ol0
003ol3d0oo0m0?o`?@3o0000onIQ0?l000001OoRL@000ol0003ogWh0omin0003omin00;o00001?o;
]0000ol0003ob;`0olRl0002olRl0003o`000?o6`@3oa/4000;oa/4000?o0000oh6d0?n1]0000on1
]0000ol0003oQ;@0ohBd0003ohBd0003o`000?m<Y@3oC:D000CoC:D000Co0000oeZY0?mJZ@3o0000
0olRU`000ol0003o=9d0ocBM0003ocBM0003o`000?lKU03o6i@000Go6i@000?o0000o`f?0?l=S`00
1Ol=S`000ol0003o28d0o`R=0004o`R=0003o`000?l0PA?o000000Co3Hl000?o0000o`242ol0Q0/0
0ol0Q0/2o`0000Go1X`000?o0000o`252Ol0Q@T00ol0Q@T2o`0000Co5Y8000?o0000o`n@0?l?T000
1?l?T0000ol0003o3Hl0o`f?0002o`f?0003o`000?l?T03o3i0000;o3i0000Co0000oaJB0?lFTP3o
5Y804Ol000000om<Y@3o0000of^^0004of^^0003o`000?n?^03oSkP000;oSkP000?o0000ok[20?nj
`P000_nj`P000ol0003ocJl0olf_0002olf_0003o`000?oHT@3of94000Co00001OoISP000ol0003o
i6/0onA[0002onA[0003o`000?o]BP3okDX000;okDX000?o0000oo@^0?od;P001?od;P000ol0003o
nAd0ooTM0002ooTM00;o00002oooool00ol0003oooooooooo`05ooooo`00:_ooool01?l0003ooooo
o`000?l00004oo<a00;o00001Oo`?@02o`0000CohW4000?o0000omin0?oNOP000ooNOP000ol0003o
fXT0omZ90002o`000003ol^d0?l0003ob;`000?ob;`000?o0000olK10?o6`@000oo6`@02o`0000?o
PK@000?o0000ohBd0?n4]0001?n4]0000ol0003oC:D0odbU0003odbU0003o`000?mJZ@3oFZT000;o
FZT000?o0000ob:G0?l000001_ldW@000ol0003o6i@0oa^D0004oa^D00;o00001_l=S`02o`0000Oo
28d000?o0000o`f?0?l=S`001?l=S`001ol0003o08@;o`242ol0Q0_o0000oa^D0?l000001Ol6S000
1?l0003o08D9o`252Ol0Q@T2o`000003ob:G0?l0003o5Y8000Co5Y8000?o0000o`n@0?l?T0000ol?
T0000ol0003o3Hl0o`f?0002o`f?0004o`000?l?T03o3i00o`n@00Go00000_m<Y@000ol0003oFZT0
oeZY0003oeZY0003o`000?m][P3oKJh000;oKJh000Co0000ohNe0?n7]@3oQkD01_l000000om[[P3o
0000ohnh0003ohnh0003o`000?nj`P3o^/8000;o^/8000?o0000olf_0?o=[`000oo=[`000ol0003o
f940omRA0002omRA00Go000000?ofHh0o`000?oTJ`001?oTJ`000ol0003okDX0one:0002one:0003
o`000?od;P3om2h000Com2h000?o0000ooTM0?oi7@000_oi7@02o`0000[ooooo00?o0000oooooooo
ool01Oooool002_ooooo0_l000001Ooooooo0000o`000?oc<@3o000000Kol3d000?o0000one:0?o]
BP000_l000000ooRL@3o0000omin0004omin0003o`000?oJR@3ofXT000;ofXT00ol00003olRl0003
o`000?o6`@3oa/4000?oa/4000Ko0000olG20?o5`P3o0000oh6d0?l00006ohBd0003o`000?n=]`3o
000000?oC:D000?o0000oeZY0?mJZ@001?mJZ@000ol0003o=9d0ocBM0004ocBM0003o`000?m<Y@3o
000000Co6i@000Co0000ocNN0?lgWP3o00001?l=S`001?l0003o;I/0obfK0?l00005o`R=00;o0000
1_l=S`001?l0003o08@;o`242ol00002oa^D0003o`000?l6S03o1X`000Co1X`00ol00003ob:G0003
o`000?lFTP3o5Y8000?o5Y8000?o0000o`n@0?l?T0000ol?T0001?l0003o3Hl0o`f?0?l=S`05o`00
00;oA:8000?o0000odbU0?m<Y@000om<Y@000ol0003oFZT0oeZY0003oeZY0003o`000?m][P3oKJh0
00;oKJh000?o0000ohNe0?n7]@000_n7]@001?l0003oY[d0ojJm0?nV_@06o`000003ohnh0?l0003o
^/8000?o^/8000?o0000olf_0?o=[`000_o=[`000ol0003of940omRA0002omRA0003o`000?oRL@3o
hW4000;ohW401_l000000ooTJ`3o0000one:0004one:0003o`000?od;P3om2h000?om2h000Co0000
ooTM0?oi7@3onAd01?l00009ooooo`03o`000?oooooooooo00Gooooo000]ooooo`03o`000?oooooo
oooo00;o00001Oo`?@000ol0003okDX0one:0003one:00;o00001?oNOP000ol0003ofXT0omZ90002
omZ90007o`000?oHT@3of940omRA0?l0003ob;`0o`000005olK10003o`000?o5`P3oaL8000;oaL80
00?o0000ohBd0?n4]0001?n4]0001ol0003oSKL0ohfg0?n=]`3o0000odbU0?l000001_mJZ@02o`00
00Go=9d000Go0000odbU0?m<Y@3oC:D0o`000002oa^D0003o`000?lgWP3o=ih000;o=ih000Co0000
o`f?0?l=S`3o00000ol]V`000ol0003o28d0o`R=0002o`R=0003o`000?l]V`3o000000Ko3Hl000?o
0000o`242ol000001?lKU0000ol0003o1X`0o`J<0002o`J<00;o00001_lRU`000ol0003o5Y80oaJB
0002oaJB0003o`000?l?T03o3i0000?o3i001?l00002od6Q0003o`000?m4XP3oA:8000?oA:8000?o
0000odbU0?m<Y@000_m<Y@000ol0003oFZT0oeZY0003oeZY0003o`000?m][P3oKJh000;oKJh000?o
0000ohNe0?n7]@000on7]@000ol0003oY[d0ojJm0002ojJm0004o`000?o6`@3oa/40olK100Go0000
00?o^/80o`000?o=[`001?o=[`000ol0003of940omRA0002omRA0003o`000?oRL@3ohW4000?ohW40
00Co0000on]A0?o[D@3oje401_l000000oo]BP3o0000oo@^0002oo@^00Ko00000_oi6P02o`0000[o
oooo00?o0000ooooooooool01?ooool002kooooo00Go0000ooooooooooooooooo`000003oo0m0003
o`000?o]BP3okDX000?okDX000?o0000onYE0?oZE@000_l000000ooNOP3o0000omZ90003omZ90003
o`000?oHT@3of94000?of9400_l00004olK10003o`000?o5`P3oaL8000?oaL800_l00004ohBd0003
o`000?n=]`3oSKL000?oSKL000?o0000oeZY0?mJZ@001?mJZ@001?l0003oKJh0off^0?l00003ocBM
0003o`000?m<Y@3oC:D000;oC:D000?o0000oa^D0?l000001OlgWP000ol0003o3Hl0o`000005obfK
0004o`000?l8S@3o28d0o`0000?o;I/000?o0000o`f?0?l=S`000ol=S`02o`0000Go6i@000Oo0000
o`J<0?l6S03o1X`0o`000?ldW@3o000000Ko8YL000?o0000oaJB0?lFTP000olFTP000ol0003o3i00
o`000002o`000003odBR0?l0003o@J4000Co@J4000?o0000odBR0?m4XP000_m4XP000ol0003oC:D0
odbU0002odbU0003o`000?mJZ@3oFZT000?oFZT000?o0000off^0?m][P000_m][P000ol0003oQkD0
ohNe0003ohNe0003o`000?nV_@3oY[d000;oY[d000?o0000olK10?o6`@000_o6`@001?l0003ocjT0
olnY0?o?Z@06o`000003olf_0?l0003of94000Cof94000?o0000on9a0?oRL@000ooRL@000ol0003o
je40on]A0002on]A0004o`000?ob=P3olSH0oo8f00Go00000oog8P000ol0003onAX0ooTJ0003ooTJ
00;o00002Oooool00ol0003oooooooooo`04ooooo`00;oooool01ol0003ooooooooooooooooo0000
oo0m0?l000001Oo]BP000ol0003ojUD0onYE0002onYE00?o00000ooJR@000ol0003of940omRA0004
omRA0003o`000?oFUP3o000000?oa/4000?o0000olG20?o5`P000_o5`P001?l0003oa/40olK10?l0
0003ohBd0003o`000?n=]`3oSKL000?oSKL000?o0000oeZY0?mJZ@000omJZ@000ol0003oKJh0off^
0002off^0003o`000?ldW@3o000000KoC:D000?o0000ocNN0?lgWP001OlgWP000ol0003o;I/0obfK
0004obfK0003o`000?l8S@3o000000Co;I/000?o0000o`f?0?l=S`000_l=S`000ol0003o=ih0o`00
0005oa^D0004o`000?l6S03o1X`0o`0000?o=9d000?o0000ob:G0?lRU`000olRU`000ol0003o5Y80
oaJB0002oaJB00?o00001?m4XP000ol0003o@J40od6Q0003od6Q0003o`000?m4XP3oA:8000;oA:80
00?o0000odbU0?m<Y@000om<Y@000ol0003oFZT0oeZY0003oeZY0003o`000?m][P3oKJh000;oKJh0
00?o0000ohNe0?n7]@000on7]@000ol0003oY[d0ojJm0002ojJm0003o`000?o6`@3oa/4000;oa/40
00?o0000olnY0?o?Z@000_o?Z@001?l0003ofHh0omV>0?oISP06o`000003omRA0?l0003ohW4000Co
hW4000?o0000on]A0?o[D@000oo[D@000ol0003olSH0oo8f0002oo8f0003o`000?og8P3omb8000Co
mb8000?o0000ooTJ0?oi6P000ooi6P02o`0000Sooooo00?o0000ooooooooool01?ooool0033ooooo
0_l00002ooooo`;o00001?o]BP000ol0003ojUD0onYE0002onYE0007o`000?oWGP3oieh0onMN0?l0
003ofXT0o`000006omRA0007o`000?oFUP3oeYH0omJF0?l0003oa/40o`000004olG20003o`000?o6
`@3oa/4000;oa/4000?o0000ohBd0?l000001On=]`000ol0003oVkX0o`000003oeZY0003o`000?m]
[P3oKJh000CoKJh000?o0000odbU0?m<Y@001?m<Y@02o`0000Oo=ih000?o0000obfK0?l]V`001Ol]
V`000ol0003o;I/0obfK0003obfK0003o`000?l=S`3o3Hl000;o00000olgWP000ol0003o6i@0oa^D
0003oa^D00;o00001?ldW@000ol0003o8YL0ob:G0003ob:G0003o`000?lFTP3o5Y8000;o000000?o
C:D0o`000?m4XP001Om4XP000ol0003o@J40od6Q0002od6Q0003o`000?m4XP3oA:8000?oA:8000?o
0000odbU0?m<Y@000_m<Y@000ol0003oFZT0oeZY0003oeZY0003o`000?m][P3oKJh000;oKJh000?o
0000ohNe0?n7]@000on7]@000ol0003oY[d0ojJm0002ojJm0003o`000?o6`@3oa/4000;oa/4000?o
0000olnY0?o?Z@000oo?Z@000ol0003ofHh0omV>0002omV>0004o`000?oRL@3ohW40on9a00Ko0000
00?ohW40o`000?o[D@001?o[D@000ol0003olSH0oo8f0003oo8f0003o`000?og8P3omb8000?omb80
00?o0000ooTJ0?oi6P000ol000000ooi7@3o0000o`000007ooooo`03o`000?oooooooooo00Cooooo
000booooo`04o`000?ooooooooooooooo`;o000000?okDX0o`000?oZE@000ooZE@000ol0003oieh0
onMN0003onMN00;o00001OoHT@000ol0003oeYH0omJF0002omJF00;o00001?o5`P000ol0003oa/40
olK10004olK10003o`000?n=]`3oSKL000?oSKL000Oo0000oi^j0?nK^P3oVkX0o`000?mJZ@3o0000
00KoKJh00_l00005odbU0004o`000?m[[P3oJjh0o`0000Go=ih000?o0000oeZY0?l000001Ol]V`02
o`0000Ko;I/00_l00005ocNN0003o`000?lKU03o6i@000;o6i@00_l00005ocBM0003o`000?lRU`3o
8YL000Co8YL00_l00004odbU0003o`000?m4XP3oA:8000?oA:8000?o0000od6Q0?m1X@000om1X@00
0ol0003oA:80odBR0002odBR0003o`000?m<Y@3oC:D000;oC:D000?o0000oeZY0?mJZ@000omJZ@00
0ol0003oKJh0off^0002off^0003o`000?n7]@3oQkD000?oQkD000?o0000ojJm0?nV_@000_nV_@00
0ol0003oa/40olK10003olK10003o`000?o?Z@3ocjT000;ocjT000?o0000omV>0?oISP000ooISP00
0ol0003ohW40on9a0002on9a0004o`000?oZE03ojU@0onYD00Ko000000?oje40o`000?ob=P001?ob
=P001?l0003omb80ooLR0?og8P05o`0000ConAd01?l00005ooooo`03o`000?oooooooooo00Cooooo
000cooooo`03o`000?oooooooooo00;ooooo0_l00003onYE0003o`000?oWGP3oieh000?oieh000Co
0000onEU0?oUI@3o00000ooHT@000ol0003oeYH0omJF0002omJF0004o`000?oFU`3oeYL0o`0000?o
aL8000?o0000olK10?o6`@000oo6`@000ol0003ob;`0o`000003ohfg0003o`000?nK^P3oVkX000?o
VkX000?o0000off^0?m][P001?m][P001?l0003oQkD0ohNe0?l00003odbU0005o`000?m[[P3oJjh0
of^^0?l000001?lgWP001?l0003oFZT0oeZY0?l00004obfK0004o`000?mDY`3oE:L0o`0000Co;I/0
0_l00006ocNN0003o`000?lKU03o6i@000;o000000?oC:D0o`000?ldW@001OldW@000ol0003o8YL0
ob:G0002ob:G00;o00001Om<Y@000ol0003oA:80odBR0003odBR0003o`000?m1X@3o@J4000?o@J40
00?o0000odBR0?m4XP000_m4XP001?l0003oC:D0odbU0?m<Y@0Go`000003ojJm0?l0003oa/4000?o
a/4000?o0000olnY0?o?Z@000oo?Z@000ol0003ofHh0omV>0002omV>0003o`000?oRL@3ohW4000?o
hW4000?o0000onYD0?oZE0000_oZE0001?l0003olCT0oo4i0?oa>@0;o`0000?onAX000?o0000ooTM
0?oi7@000_oi7@03o`000003ooHY0?l0003o000000Go00001_ooool003Cooooo00?o0000oooooooo
ool00oooool00ol0003ojUD0o`000005onMN0003o`000?oUI@3oiFD000;oiFD000?o0000omRA0?l0
00001?oFUP000ol0003oeYL0omJG0002omJG0003o`000?o5`P3o000000Goa/4000Oo0000olRl0?o8
_03ob;`0o`000?n=]`3o000000KoVkX000?o0000off^0?m][P000om][P001Ol0003oQkD0ohNe0?n7
]@3o000000;oC:D000?o0000of^^0?m[[P000om[[P001?l0003o=ih0ocNN0?l00004oeZY0004o`00
0?l]V`3o;I/0o`0000?oE:L000Oo0000obfK0?l]V`3o;I/0o`000?mJZ@3o000000Oo=ih00_l00004
odbU0003o`000?ldW@3o=9d000?o=9d000?o0000ob:G0?lRU`000_l000000omJZ@3o0000odbU0004
odbU0003o`000?m4XP3oA:8000?oA:8000?o0000od6Q0?m1X@000om1X@001?l0003oA:80odBR0?m4
XP05o`0000;oSKL000?o0000oi^j0?nK^P000onK^P000ol0003o[kl0ojno0002ojno0003o`000?o5
`P3oaL8000?oaL8000Co0000olba0?o</@3oc;402ol000000oo?Z@3o0000omV>0004omV>0003o`00
0?oRL@3ohW4000;ohW4000?o0000onYD0?oZE0000ooZE0000ol0003olCT0oo4i0002oo4i0003o`00
0?og9@3ombD000CombD000?o0000ooTJ0?oi6P000ooi6P001?l0003onAd0o`000?l00003ooHY0004
o`000?o_@@3o0000onIT00;o000000?oooooo`000?ooool01Oooool003Gooooo0_l00004ooooo`;o
00001?oWGP000ol0003oiFD0onEU0004onEU00;o00000ooFUP000ol0003oeYL0omJG0004omJG0003
o`000?o6`@3oa/4000?oa/4000?o0000olRl0?o8_0000oo8_0000ol0003oVkX0oi^j0004oi^j0003
o`000?n__`3o000000?oKJh000?o0000ohNe0?n7]@000_n7]@000ol0003oC:D0o`000006of^^0003
o`000?lgWP3o000000GoFZT000?o0000obfK0?l000001?mDY`001?l0003o;I/0obfK0?l00003oeZY
0003o`000?lgWP3o=ih000Co=ih000?o0000odbU0?m<Y@000om<Y@000ol0003o=9d0ocBM0003ocBM
0003o`000?lRU`3o000000CoFZT000?o0000odbU0?m<Y@000om<Y@000ol0003oA:80odBR0003odBR
0003o`000?m1X@3o@J4000Ko00000_n4]0000ol0003oSKL0ohfg0003ohfg0003o`000?nK^P3oVkX0
00;oVkX000?o0000ojno0?n__`000on__`000ol0003oaL80olG20002olG20003o`000?o</@3oc;40
00;oc;4000?o0000omBL0?oDW0000ooDW0001?l0003og8D0omb50?oLQ@06o`000003omV>0?l0003o
hW4000CohW4000?o0000onYD0?oZE0000ooZE0000ol0003olCT0oo4i0002oo4i0003o`000?og9@3o
mbD000CombD000Co0000ooTJ0?oi6P3onAX01?l00003ooHY0004o`000?o_@@3o0000onIT00;o0000
0_ooool00ol0003oooooooooo`04ooooo`00=oooool00ol0003oooooooooo`03ooooo`;o000000?o
ieh0o`000?oUI@001OoUI@001_l0003oi6X0onAZ0?l0003oeYH0o`0000KoeYL000?o0000omJF0?l0
00000oo6`@000ol0003ob;`0olRl0004olRl0003o`000?nK^P3oVkX000?oVkX000Oo0000ojno0?n_
_`3o[kl0o`000?m][P3o000000KoQkD000?o0000of^^0?m[[P001Om[[P02o`0000KoFZT00_l00006
oeBW00;o00001?mJZ@000ol0003o=ih0ocNN0003ocNN00;o00001_m<Y@000ol0003o=9d0ocBM0002
ocBM00;o00001OmJZ@000ol0003oC:D0odbU0003odbU0003o`000?m4XP3oA:8000;oA:801?l00003
oh6d0003o`000?n4]03oQ;@000?oQ;@000?o0000ohfg0?n=]`000_n=]`000ol0003oVkX0oi^j0003
oi^j0003o`000?n__`3o[kl000;o[kl000?o0000olG20?o5`P000oo5`P000ol0003oc;40olba0002
olba0003o`000?oDW03oe9`000?oe9`000?o0000omb50?oLQ@000_oLQ@001?l0003oi6/0onA[0?oT
J`06o`000003on9a0?l0003ojU@000CojU@000?o0000oo4i0?oa>@000ooa>@001?l0003ombD0ooLU
0?og9@06o`0000ConA/000Co0000ooHY0?l0003okd401?l00004ooooo`03o`000?oooooooooo00?o
oooo000hooooo`03o`000?oooooooooo00Cooooo0_l00005onEU0003o`000?oTJP3oi6X000;oi6X0
0_l00005omJG0007o`000?oFUP3oeYH0omJF0?l0003oa/40o`000006olRl0003o`000?o;]03o0000
00?oVkX000?o0000ojno0?n__`000on__`000ol0003oQkD0ohNe0005ohNe0003o`000?m[[P3oJjh0
00CoJjh000?o0000ohnh0?l000001OmJZ@000ol0003oQ;@0o`000006oeBW0003o`000?mJZ@3oFZT0
00CoFZT000Go0000ocNN0?lgWP3o=ih0o`000002of^^0003o`000?m<Y@3oC:D000?oC:D000?o0000
ocBM0?ldW@000_l000000om][P3o0000oeZY0005oeZY0003o`000?m<Y@3oC:D000;oC:D000?o0000
odBR0?l000000_l000000on4]03o0000oh6d0004oh6d0003o`000?n4]03oQ;@000?oQ;@000?o0000
ohfg0?n=]`000on=]`000ol0003oVkX0oi^j0002oi^j0003o`000?n__`3o[kl000?o[kl000?o0000
olG20?o5`P000_o5`P000ol0003oc;40olba0002olba0003o`000?oDW03oe9`000?oe9`000?o0000
omb50?oLQ@000ooLQ@000ol0003oi6/0onA[0002onA[0004o`000?o[D@3oje40on]A017o00000ooi
6`000ol0003onA/0ooTK0004ooTK00;o000000?okd40o`000?oVI0000_l00005ooooo`03o`000?oo
oooooooo00?ooooo000iooooo`03o`000?oooooooooo00Gooooo00Go0000onEU0?oUI@3oiFD0o`00
0005onAZ0003o`000?oTJ`3o000000?oeYL000?o0000omJF0?oFUP000ooFUP02o`0000Gob;`000Oo
0000ol^d0?o;]03obk@0o`000?nK^P3o000000Ko[kl000?o0000ohNe0?n7]@001?n7]@000ol0003o
Y[d0o`000004of^^0005o`000?n?^03oSkP0ohnh0?l000000omJZ@001Ol0003oQ;@0ohBd0?n4]03o
000000CoE:L00_l00006oeZY0004o`000?lgWP3o=ih0o`0000?oJjh000?o0000odbU0?m<Y@000om<
Y@000ol0003o=9d0o`000004off^0003o`000?mJZ@3oFZT000?oFZT000?o0000odbU0?m<Y@000_m<
Y@02o`0000GoQ;@000?o0000oh6d0?n1]0000on1]0000ol0003oQ;@0ohBd0003ohBd0003o`000?n=
]`3oSKL000;oSKL000?o0000oi^j0?nK^P000_nK^P000ol0003o[kl0ojno0003ojno0003o`000?o5
`P3oaL8000;oaL8000?o0000olba0?o</@000oo</@000ol0003oe9`0omBL0003omBL0003o`000?oL
Q@3og8D000;og8D000?o0000onA[0?oTJ`000ooTJ`000ol0003oje40on]A0002on]A0003o`000?oa
>@3olCT000?olCT000?o0000ooHV0?of9P000oof9P000ol0003onA/0ooTK0004ooTK0003o`000?oi
6`3onA/000?o000000?omRL0o`000?l000000ol000000ooooooo0000ooooo`03ooooo`03o`000?oo
oooooooo00?ooooo000jooooo`;o00001_ooool00ol0003oiFD0o`000005onAZ0007o`000?oTJ`3o
i6/0onA[0?l0003oeYL0o`000005omJF0004o`000?oHT@3of940o`0000?ob;`000?o0000ol^d0?o;
]0000oo;]0000ol0003o[kl0ojno0004ojno0003o`000?o5`P3o000000CoQkD000Go0000ojJm0?nV
_@3oY[d0o`000002of^^0003o`000?n?^03oSkP000;oSkP000Co0000oeZY0?mJZ@3o00001?n4]000
1Ol0003oE:L0oeBW0?mDY`3o000000;oQ;@000?o0000oeZY0?mJZ@000omJZ@000ol0003o=ih0o`00
0005of^^0003o`000?m<Y@3oC:D000;oC:D00_l00005off^0003o`000?mJZ@3oFZT000?oFZT000?o
0000odbU0?l000000_l000000on=]`3o0000ohBd0004ohBd0003o`000?n1]03oPK@000?oPK@000?o
0000ohBd0?n4]0000on4]0000ol0003oSKL0ohfg0002ohfg0003o`000?nK^P3oVkX000?oVkX000?o
0000ojno0?n__`000_n__`000ol0003oaL80olG20003olG20003o`000?o</@3oc;4000;oc;4000?o
0000omBL0?oDW0000ooDW0000ol0003og8D0omb50002omb50003o`000?oTJ`3oi6/000?oi6/000?o
0000on]A0?o[D@000oo[D@000ol0003olCT0oo4i0003oo4i0003o`000?of9P3omRH000?omRH000?o
0000ooTK0?oi6`000ooi6`03o`0000;omRL00_l000001?o`?`3o0000onIT0?l00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool003cooooo00?o0000ooooooooool01?oo
ool00ol0003oi6X0onAZ0003onAZ0003o`000?oTJ`3oi6/000;oi6/00_l00005omJF0003o`000?oH
T@3of94000;of94000?o0000olRl0?l000001_o;]0000ol0003o[kl0ojno0003ojno0005o`000?o5
`P3oaL80olG20?l000000_n7]@000ol0003oY[d0ojJm0002ojJm0003o`000?m[[P3o000000GoSkP0
00?o0000oeZY0?l000001On4]0001?l0003oE:L0oeBW0?l00003ohBd0003o`000?mJZ@3oFZT000?o
FZT00_l00006of^^0003o`000?m<Y@3oC:D000;o000000?oQkD0o`000?m][P001Om][P000ol0003o
FZT0oeZY0002oeZY00;o00001On=]`000ol0003oQ;@0ohBd0002ohBd0003o`000?n1]03oPK@000?o
PK@000?o0000ohBd0?n4]0000on4]0001?l0003oSKL0ohfg0?n=]`0Lo`000003omBL0?l0003og8D0
00Cog8D000?o0000onA[0?oTJ`000_oTJ`000ol0003oje40on]A0003on]A0003o`000?oa>@3olCT0
00?olCT000?o0000ooHV0?of9P000oof9P000ol0003onA/0ooTK0003o`0000;onA/000?o0000ooHW
0?l000000_o`?`000ol0003oiV@0o`000004ooooo`05o`000?ooooooooooooooool000001Oooool0
03gooooo00?o0000ooooooooool01?ooool01Ol0003oi6X0onAZ0?oTJP3o000000Coi6/000Co0000
onAZ0?oTJP3o00000ooFUP000ol0003of940omRA0004omRA0003o`000?o;]03obk@000Cobk@000?o
0000olnY0?l000000on__`000ol0003oaL80olG20002olG20003o`000?n7]@3o000000KoY[d000?o
0000ohnh0?n?^0001On?^0000ol0003oQ;@0ohBd0005ohBd00;o00001On4]0001ol0003oFZT0oeZY
0?mJZ@3o0000ohnh0?l000001_m[[P000ol0003oC:D0o`000004ohNe0003o`000?m][P3oKJh000?o
KJh000?o0000oeZY0?mJZ@000_l000000onK^P3o0000ohfg0004ohfg0003o`000?n4]03oQ;@000?o
Q;@000?o0000oh6d0?n1]0000on1]0000ol0003oQ;@0ohBd0006o`0000;ob;`000?o0000ol^d0?o;
]0000_o;]0000ol0003ocjT0olnY0003olnY0003o`000?oDV`3oe9/000;oe9/000?o0000omZ90?oJ
R@000ooJR@001?l0003ohGD0on5e0?oQM@0;o`0000;oi6/000?o0000on]A0?o[D@000_o[D@001?l0
003olCT0oo4i0?oa>@0;o`0000GonA/00ol000001?o`?`3o0000onIT0?l00006ooooo`04o`000?oo
ooooooooo`0000Gooooo000nooooo`03o`000?oooooooooo00Cooooo00?o0000onAZ0?l000001?oT
J`000ol0003oi6X0onAZ0002onAZ0003o`000?oFUP3o000000Kof9400_l00005ol^d0007o`000?o?
Z@3ocjT0olnY0?l0003o[kl0o`000006olG20003o`000?nV_@3oY[d000GoY[d000?o0000ohnh0?n?
^0001On?^0000ol0003oQ;@0ohBd0005ohBd0003o`000?n4]03oQ;@000CoQ;@000Co0000oeZY0?mJ
Z@3o00000on?^0000ol0003oJjh0of^^0003of^^00;o00001On7]@000ol0003oKJh0off^0003off^
0003o`000?mJZ@3o000000CoVkX000?o0000ohfg0?n=]`000_n=]`000ol0003oQ;@0ohBd0003ohBd
0003o`000?n1]03oPK@000;oPK@01?l00003olK10003o`000?o8_03ob;`000?ob;`000?o0000ol^d
0?o;]0000_o;]0000ol0003ocjT0olnY0003olnY0003o`000?oDV`3oe9/000;oe9/000?o0000omZ9
0?oJR@000ooJR@000ol0003ohGD0on5e0002on5e0003o`000?oWH03oif0000;oif0000Co0000one:
0?o]BP3okDX02ol00003ooLU0003o`000?oi6`3onA/000?onA/000?o0000ooTK0?oi6`000_oi6`02
o`0000;omRL01?l00008ooooo`03o`000?oooooo000000Gooooo000oooooo`;o00001Oooool2o`00
00?oi6/000?o0000onAZ0?oTJP001?oTJP000ol0003of940omRA0004omRA0004o`000?oJR@3ofXT0
o`0000?obk@000?o0000olnY0?o?Z@000oo?Z@000ol0003oaL80olG20005olG20003o`000?nV_@3o
Y[d000CoY[d000?o0000olK10?l000001On?^0000ol0003o^/80o`000005ohBd00;o00001_n4]000
0ol0003oFZT0o`000004ohnh0003o`000?m[[P3oJjh000;oJjh000?o0000ojJm0?l000001_n7]@00
0ol0003oKJh0off^0002off^00;o00001OnK^P000ol0003oSKL0ohfg0003ohfg0003o`000?n4]03o
Q;@000;oQ;@000?o0000oh6d0?l000000_l000000oo5`P3o0000olK10004olK10003o`000?o8_03o
b;`000?ob;`000?o0000ol^d0?o;]0000_o;]0000ol0003ocjT0olnY0003olnY0003o`000?oDV`3o
e9/000;oe9/000?o0000omZ90?oJR@000ooJR@000ol0003ohGD0on5e0003on5e0003o`000?oWH03o
if0000;oif0000?o0000one:0?o]BP000_o]BP000ol0003olSH0oo8f0003oo8f0003o`000?og9@3o
mbD000CombD000?o0000ooTK0?oi6`000ooi6`001?l0003onA/0o`000?l00003ooHW0003o`000?o_
@@3o000000[ooooo00Co0000oooooooooooo00001?ooool0047ooooo00?o0000ooooooooool01?oo
ool00ol0003oi6/0o`000006onAZ00;o00001OoHT@000ol0003ofXT0omZ90002omZ90003o`000?o;
]03o000000KocjT000?o0000olG20?o5`P001?o5`P000ol0003oc;40o`000004ojJm0004o`000?o6
`@3oa/40o`0000CoSkP000Co0000ok[20?nj`P3o00001?n4]0001?l0003o]L40okG10?l00005ohBd
00;o00001_n?^0001?l0003oJjh0of^^0?l00003ojJm0003o`000?n7]@3oQkD000?oQkD000?o0000
off^0?m][P000_l000000on__`3o0000oi^j0004oi^j0003o`000?n=]`3oSKL000?oSKL000?o0000
ohBd0?n4]0000_n4]002o`0000GoaL8000?o0000olK10?o6`@000oo6`@000ol0003ob;`0olRl0002
olRl0003o`000?o;]03obk@000?obk@000?o0000olnY0?o?Z@000oo?Z@000ol0003oe9/0omBK0002
omBK0003o`000?oJR@3ofXT000?ofXT000?o0000on5e0?oQM@000_oQM@000ol0003oif00onMP0002
onMP0003o`000?o]BP3okDX000?okDX000?o0000oo8f0?ob=P000oob=P000ol0003ombD0ooLU0003
ooLU0004o`000?oi6`3onA/0ooTK00Co00000oof9`04o`0000cooooo00?o0000ooooool000001?oo
ool004;ooooo00?o0000ooooooooool01?ooool2o`0000Goi6X000Co0000onEU0?oUI@3o00000ooH
T@000ol0003ofXT0omZ90004omZ90003o`000?o?Z@3ocjT000CocjT000?o0000omBK0?l000001?o5
`P001Ol0003oc;40olba0?o</@3o000000;oY[d000?o0000olK10?o6`@000_o6`@001?l0003oSkP0
ohnh0?l00004ok[20004o`000?n4]03oQ;@0o`0000?o]L4000?o0000ohBd0?n4]0000_n4]0000ol0
003o^/80o`000006ohnh0003o`000?m[[P3o000000CoY[d000?o0000ohNe0?n7]@000on7]@000ol0
003oKJh0o`000004ojno0003o`000?nK^P3oVkX000?oVkX000?o0000ohfg0?n=]`000_n=]`000ol0
003oQ;@0o`000002o`000003olK10?l0003oaL8000CoaL8000?o0000olK10?o6`@000oo6`@000ol0
003ob;`0olRl0003olRl0003o`000?o;]03obk@000;obk@000?o0000olnY0?o?Z@000oo?Z@000ol0
003oe9/0omBK0002omBK0003o`000?oJR@3ofXT000?ofXT000?o0000on5e0?oQM@000_oQM@000ol0
003oif00onMP0003onMP0003o`000?o]BP3okDX000?okDX000?o0000oo8f0?ob=P000oob=P001?l0
003ombD0ooLU0?og9@05o`0000ConA/000Go0000ooHW0?l0003okd40o`00000?ooooo`;o00001?oo
ool004?ooooo00?o0000ooooooooool01Oooool01Ol0003oi6X0onAZ0?oTJP3o000000CoiFD000?o
0000omRA0?l000001_oJR@02o`0000GocjT000Go0000omBK0?oDV`3oe9/0o`000002olG20003o`00
0?o</@3oc;4000;oc;4000?o0000ojJm0?l000001Oo6`@000ol0003oSkP0o`000005ok[20003o`00
0?n4]03o000000Go]L4000Co0000ohBd0?n4]03o00000onj`P000ol0003oSkP0ohnh0003ohnh00;o
00001_nV_@000ol0003oQkD0ohNe0002ohNe00;o00001On__`000ol0003oVkX0oi^j0003oi^j0003
o`000?n=]`3oSKL000;oSKL00_l00005olK10003o`000?o5`P3oaL8000?oaL8000?o0000olK10?o6
`@000_o6`@000ol0003ob;`0olRl0003olRl0003o`000?o;]03obk@000;obk@000?o0000olnY0?o?
Z@000oo?Z@000ol0003oe9/0omBK0002omBK0003o`000?oJR@3ofXT000?ofXT000?o0000on5e0?oQ
M@000ooQM@000ol0003oif00onMP0002onMP0003o`000?o]BP3okDX000?okDX000Co0000oo8f0?ob
=P3olSH01_l00003ooTJ0003o`000?oi6`3onA/000?onA/01?l0000?ooooo`?o00001?ooool004Co
oooo00?o0000ooooooooool01Oooool00ol0003oi6X0o`000005onEU00?o00001OoJR@001?l0003o
gWh0omin0?l00003olnY0003o`000?oDV`3oe9/000;oe9/000?o0000olG20?l000001_o</@000ol0
003oa/40olK10005olK10003o`000?nj`P3o^/8000Go^/8000?o0000okG10?ne`@001?ne`@000ol0
003oQ;@0o`000004ok[20003o`000?n?^03oSkP000;oSkP000?o0000olK10?l000001_nV_@000ol0
003oQkD0ohNe0002o`000003olG20?l0003o[kl000Go[kl000?o0000oi^j0?nK^P000_nK^P000ol0
003oSKL0o`000002o`000003olRl0?l0003oa/4000Coa/4000?o0000olG20?o5`P000oo5`P000ol0
003oa/40olK10003olK10003o`000?o8_03ob;`000;ob;`000Co0000ol^d0?o;]03obk@09ol00003
ooLR0003o`000?oi6P3onAX000ConAX000?o0000ooTK0?l000000_l000000oof:@3o0000ooooo`0<
ooooo`Co00001oooool004Gooooo0_l00006ooooo`03o`000?oUI@3oiFD000?oiFD000Go0000onMN
0?oWGP3oieh0o`000003omZ90003o`000?oNOP3ogWh000;ogWh000?o0000olnY0?l000001_oDV`00
0ol0003oc;40olba0004olba00;o00001_o6`@02o`0000Ko^/800_l00007okG10003o`000?nj`P3o
^/8000Co^/8000Co0000ohnh0?n?^03o00000oo6`@000ol0003oY[d0ojJm0003ojJm0003o`000?n7
]@3o000000CoaL8000?o0000ojno0?n__`000on__`000ol0003oVkX0oi^j0002oi^j00;o00001Oo8
_0000ol0003oa/40olK10003olK10003o`000?o5`P3oaL8000;oaL8000Co0000olK10?o6`@3oa/40
2ol00002omZ90003o`000?oNOP3ogWh000?ogWh000?o0000on9a0?oRL@000_oRL@000ol0003oiV40
onIQ0003onIQ0003o`000?o[D03oje0000;oje0000?o0000oo0n0?o`?P000oo`?P000ol0003om2h0
oo@^0003oo@^0003o`000?og8P3omb8000Comb8000?o0000ooTJ0?oi6P000ooi6P02o`0000?omRT0
00?o0000ooooooooool02Oooool3o`0000_ooooo0017ooooo`03o`000?oooooooooo00Cooooo00Go
0000onEU0?oUI@3oiFD0o`000005onMN0003o`000?oJR@3o000000KogWh000?o0000omBK0?oDV`00
1?oDV`02o`0000Goc;4000Co0000omBL0?oDW03o00001?o6`@001?l0003ocjT0olnY0?l00004ok[2
0004o`000?o=[`3ocJl0o`0000Go]L400_l00006ok[20003o`000?n?^03o000000Coa/4000?o0000
ojJm0?nV_@000onV_@02o`0000GoaL8000?o0000ojno0?n__`000on__`000ol0003oVkX0o`000002
o`000003ol^d0?l0003ob;`000Cob;`000?o0000olK10?o6`@000oo6`@000ol0003oaL80olG20002
olG200Co00000_oFUP000ol0003of940omRA0003omRA0003o`000?oJR@3ofXT000?ofXT000?o0000
omin0?oNOP000ooNOP000ol0003ohW40on9a0002on9a0003o`000?oVH@3oiV4000?oiV4000?o0000
on]@0?o[D0000_o[D0000ol0003ol3h0oo0n0003oo0n0003o`000?od;P3om2h000?om2h000?o0000
ooLR0?og8P000oog8P000ol0003onAX0ooTJ0003o`0000;onAd000?o0000ooHY0?l000002?ooool4
o`0000kooooo0018ooooo`03o`000?oooooooooo00Cooooo00?o0000onEU0?l000001_oWGP02o`00
00KogWh00_l00005omBK0004o`000?oJR@3ofXT0o`0000?oc;4000?o0000omBL0?oDW0000_oDW000
1?l0003oa/40olK10?l00004olnY0004o`000?nj`P3o^/80o`0000?ocJl000?o0000okG10?ne`@00
0_ne`@001?l0003ocJl0olf_0?l00005ok[200;o00001_o6`@001ol0003oY[d0ojJm0?nV_@3o0000
olba0?l000001_o5`P000ol0003o[kl0ojno0002ojno00;o00001?o;]0000ol0003ob;`0olRl0004
olRl0003o`000?o6`@3oa/4000;oa/4000?o0000olG20?l000000_l000000ooFU`3o0000omJF0004
omJF0003o`000?oHT@3of94000?of94000?o0000omZ90?oJR@000_oJR@000ol0003ogWh0omin0003
omin0003o`000?oRL@3ohW4000;ohW4000?o0000onIQ0?oVH@000ooVH@000ol0003oje00on]@0003
on]@0003o`000?o`?P3ol3h000?ol3h000?o0000oo@^0?od;P000_od;P001?l0003omb80ooLR0?og
8P05o`0000GonAd00_l00005ooooo`Co00004_ooool004Wooooo00?o0000ooooooooool01?ooool0
0ol0003oieh0onMN0004onMN0003o`000?oZE@3o000000GogWh000Co0000on9a0?oRL@3o00000ooD
V`000ol0003ofXT0omZ90002omZ90003o`000?o</@3o000000Goe9`000?o0000olK10?l000001Oo?
Z@000ol0003o^/80o`000005olf_0004o`000?ne`@3o]L40o`0000?ocJl000?o0000ok[20?nj`P00
0_nj`P000ol0003ocjT0o`000006olK10004o`000?nV_@3oY[d0o`0000?oc;4000?o0000olG20?o5
`P000oo5`P000ol0003o[kl0ojno0002o`000003olnY0?l0003obk@000Cobk@000?o0000olRl0?o8
_0000oo8_0000ol0003oa/40olK10002olK100;o00001OoFU`000ol0003oeYH0omJF0002omJF0003
o`000?oHT@3of94000?of94000?o0000omZ90?oJR@000ooJR@000ol0003ogWh0omin0002omin0003
o`000?oRL@3ohW4000?ohW4000?o0000onIQ0?oVH@000_oVH@000ol0003oje00on]@0003on]@0004
o`000?o`?P3ol3h0oo0n00_o00001?oi6P000ol0003onAd0ooTM0003o`0000?ooooo1?l0000Foooo
o`00B_ooool2o`0000Cooooo00?o0000onMN0?oWGP000ooWGP001Ol0003ojUD0onYE0?oZE@3o0000
00?ogWh000?o0000on9a0?oRL@000_oRL@000ol0003oe9/0o`000006omZ90003o`000?oDW03oe9`0
00Goe9`000?o0000olnY0?o?Z@001Oo?Z@000ol0003ocJl0olf_0004olf_0003o`000?ne`@3o0000
00GocJl000Co0000ok[20?nj`P3o00000oo?Z@000ol0003oa/40olK10003olK10003o`000?nV_@3o
000000Coc;4000?o0000olG20?o5`P000oo5`P000ol0003o[kl0o`000003olnY0003o`000?o;]03o
bk@000?obk@000?o0000olRl0?o8_0000oo8_0000ol0003oa/40o`000002o`000003omJF0?l0003o
eYL000CoeYL000?o0000omJF0?oFUP000ooFUP000ol0003of940omRA0002omRA0003o`000?oJR@3o
fXT000?ofXT000?o0000omin0?oNOP000ooNOP000ol0003ohW40on9a0002on9a0004o`000?oVH@3o
iV40onIQ00_o00000oof9P000ol0003onAd0ooTM0002ooTM0003o`000?oi6P3onAX000ConAX00ol0
0002ooooo`Co00006_ooool004cooooo00?o0000ooooooooool00_ooool01Ol0003oieh0onMN0?oW
GP3o000000GojUD000?o0000omin0?l000001OoRL@02o`0000KofXT00_l00006omBL00;o00001_o?
Z@02o`0000KocJl00_l00006olf_0003o`000?nj`P3o000000CocjT000?o0000olK10?o6`@000oo6
`@02o`0000Koc;4000?o0000olG20?o5`P000_o5`P02o`0000GocjT000?o0000ol^d0?o;]0000_o;
]0000ol0003ob;`0olRl0003olRl00;o00001OoFUP000ol0003oeYL0omJG0003omJG0003o`000?oF
UP3oeYH000;oeYH000?o0000omRA0?oHT@000ooHT@000ol0003ofXT0omZ9000Ao`0000;ol3d000?o
0000oo<a0?oc<@000ooc<@000ol0003omRH0ooHV0004ooHV0003o`000?oi7@3onAd000;onAd000?o
0000ooTJ0?oi6P000ol00002ooooo`?o00007_ooool004gooooo00?o0000ooooooooool00_ooool0
0ol0003oieh0o`000006onYE00;o00001OoRL@000ol0003oiV40o`000005omZ90004o`000?oQM@3o
hGD0o`0000Coe9`000Co0000omb50?oLQ@3o00001?o?Z@001?l0003ofHh0omV>0?l00004olf_0003
o`000?oHT@3o000000OocJl000?o0000olnY0?o?Z@001?o?Z@001ol0003oa/40olK10?o6`@3o0000
omBL0?l000001_o</@000ol0003oaL80olG20002o`000003omBK0?l0003ocjT000CocjT000?o0000
ol^d0?o;]0000oo;]0000ol0003ob;`0o`000002o`000003omRA0?l0003oeYH000CoeYH000?o0000
omJG0?oFU`000ooFU`000ol0003oeYH0omJF0002omJF0004o`000?oHT@3of940omRA00Go00000ooW
GP000ol0003ojUD0onYE0002onYE0003o`000?o]BP3okDX000?okDX000?o0000oo0m0?o`?@000oo`
?@000ol0003olc40oo<a0003oo<a0003o`000?of9P3omRH000?omRH000Co0000ooTM0?oi7@3onAd0
1?l000000ooooooo0000o`000002o`00027ooooo001>ooooo`03o`000?oooooooooo00;ooooo0_l0
0005onYE0004o`000?o]BP3okDX0o`0000?ohW4000Go0000onIQ0?oVH@3oiV40o`000003omZ90003
o`000?oQM@3ohGD000;ohGD000Co0000omBL0?oDW03o00001?oLQ@001?l0003ocjT0olnY0?l00004
omV>0004o`000?o=[`3ocJl0o`0000?of94000?o0000olf_0?o=[`000oo=[`02o`0000KocjT000Co
0000olK10?o6`@3o00000ooDW0000ol0003oc;40olba0003olba0003o`000?o5`P3o000000?oe9/0
00?o0000olnY0?o?Z@000oo?Z@000ol0003obk@0ol^d0002ol^d00?o00001OoHT@000ol0003oeYH0
omJF0003omJF0003o`000?oFU`3oeYL000;oeYL000Co0000omJF0?oFUP3oeYH01Ol00002onEU0003
o`000?oWGP3oieh000Coieh000?o0000onYE0?oZE@000_oZE@000ol0003okDX0one:0003one:0003
o`000?o`?@3ol3d000?ol3d000?o0000oo<a0?oc<@000_oc<@001?l0003omRH0ooHV0?of9P06o`00
0003ooooool0003o000000;o00009Oooool004oooooo0_l00004ooooo`05o`000?oZE@3ojUD0onYE
0?l000001?o]BP000ol0003ohW40o`000005onIQ0003o`000?oJR@3o000000GohGD000?o0000omBL
0?l000001OoLQ@000ol0003ocjT0o`000005omV>0003o`000?o=[`3o000000Cof94000?o0000olf_
0?o=[`000_o=[`001?l0003ofHh0omV>0?l00005olnY0003o`000?o6`@3o000000Coe9`000?o0000
olba0?o</@000oo</@02o`0000Goe9/000?o0000olnY0?o?Z@000oo?Z@04o`000003omZ90?l0003o
f94000Gof94000?o0000omJF0?oFUP000ooFUP000ol0003oeYL0omJG0002omJG00Co00000_oTJP00
0ol0003oiFD0onEU0003onEU0003o`000?oWGP3oieh000?oieh000?o0000onYE0?oZE@000ooZE@00
0ol0003okDX0one:0002one:0003o`000?o`?@3ol3d000?ol3d000Co0000oo<a0?oc<@3olc401Ol0
0003ooooo`Co0000:Oooool0057ooooo00?o0000ooooooooool00_ooool00ol0003ojUD0o`000005
one:00;o00001_oVH@02o`0000KohGD00_l00006omb500;o00001ooISP000ol0003of940omRA0004
omRA0004o`000?o=[`3ocJl0o`0000?ofHh000?o0000olnY0?o?Z@000oo?Z@02o`0000Goe9`000Co
0000olba0?o</@3oc;400_l000000ooJR@3o0000omBK0004omBK0003o`000?o?Z@3ocjT000;ocjT0
0_l00005omZ90003o`000?oHT@3of94000?of94000?o0000omJF0?oFUP000ooFUP000ol0003oeYL0
o`000002o`000003onA[0?l0003oi6X000Coi6X000?o0000onEU0?oUI@000_oUI@000ol0003oieh0
onMN0003onMN0003o`000?oZE@3ojUD000?ojUD000?o0000one:0?o]BP000_o]BP001?l0003ol3d0
oo0m0?o`?@06o`0000Cooooo1?l0000]ooooo`00D_ooool00ol0003oooooooooo`02ooooo`03o`00
0?o]BP3okDX000?okDX000?o0000oo0m0?l000001OoVH@000ol0003oje00o`000005on5e0003o`00
0?oWH03o000000Gog8D000?o0000onA[0?l000001_oISP02o`0000Kof94000?o0000olf_0?l00000
1OoISP000ol0003ocjT0olnY0002o`000003omb50?l0003oe9`000Goe9`00ol00004omZ90003o`00
0?oDV`3oe9/000;oe9/000?o0000olnY0?o?Z@000_l000000ooNOP3o0000omZ90004omZ90003o`00
0?oHT@3of94000Cof94000?o0000omJF0?oFUP001?l00005onA[0003o`000?oTJP3oi6X000;oi6X0
00?o0000onEU0?oUI@000ooUI@000ol0003oieh0onMN0003onMN0003o`000?oZE@3ojUD000_o0000
1oooool3o`00037ooooo001Cooooo`03o`000?oooooooooo00;ooooo00Go0000one:0?o]BP3okDX0
o`000003oo0m0005o`000?oVH@3oiV40onIQ0?l000000oo[D0001Ol0003ohGD0on5e0?oQM@3o0000
00?oif0000Go0000omb50?oLQ@3og8D0o`000003onA[0003o`000?oISP3ofHh000;ofHh000Co0000
on9a0?oRL@3o00001OoHT@02o`0000KofHh000?o0000olnY0?l000001?oLQ@000ol0003oe9`0omBL
0002omBL00;o00001_oJR@000ol0003oe9/0omBK0003omBK00;o00001?oNOP000ol0003ofXT0omZ9
0003omZ90003o`000?oHT@3of94000;of9401?l00003onAZ0003o`000?oTJ`3oi6/000?oi6/000?o
0000onAZ0?oTJP000ooTJP000ol0003oiFD0onEU0002onEU0004o`000?oWGP3oieh0onMN00Go0000
3_ooool4o`0003Cooooo001Dooooo`;o00000oooool00ol0003okDX0o`000005oo0m0003o`000?oV
H@3o000000Goje0000?o0000on5e0?l000001OoWH0000ol0003og8D0o`000005onA[0004o`000?oI
SP3ofHh0o`0000?ohW4000?o0000omRA0?oHT@000_oHT@000ol0003ohW40o`000006omV>00;o0000
1OoLQ@001ol0003oe9`0omBL0?oDW03o0000on5e0?l000001_oJR@000ol0003oe9/0omBK0002omBK
00;o00001OoNOP000ol0003ofXT0omZ90003omZ90003o`000?oHT@3o000000;o000000?oiFD0o`00
0?oTJP001OoTJP000ol0003oi6/0onA[0002onA[0003o`000?oTJP3oi6X000?oi6X000Co0000onEU
0?oUI@3oiFD01Ol0000?ooooo`Co0000>?ooool005Kooooo00Go0000ooooooooooooooooo`000006
oo0m00;o00001_o[D002o`0000Koif000_l00006onA[0003o`000?oISP3o000000GohW4000Co0000
omRA0?oHT@3o00000ooRL@000ol0003ofHh0omV>0002omV>0003o`000?oTJ`3o000000Gog8D000Co
0000omBL0?oDW03o00000ooQM@000ol0003ofXT0omZ90004omZ900Co000000?ohW40o`000?oNOP00
1OoNOP000ol0003ofXT0omZ90002omZ900;o00001OoUI@000ol0003oi6X0onAZ0003onAZ0003o`00
0?oTJ`3oi6/000?oi6/000?o0000onAZ0?oTJP001_l0000@ooooo`Co0000??ooool005Oooooo00Co
0000oooooooooooo00001Oo`?@000ol0003olc40o`000005on]@0003o`000?o`?P3o000000Goif00
00?o0000one:0?l000001_oTJ`02o`0000KohW4000?o0000omRA0?l000001OoRL@001?l0003ofHh0
omV>0?l00003onA[0003o`000?oLQ@3og8D000?og8D00_l00004on5e0003o`000?oJR@3ofXT000?o
fXT00_l00005on9a0003o`000?oNOP3ogWh000?ogWh000?o0000omZ90?l000000_l000000ooWGP3o
0000onEU0004onEU0003o`000?oTJP3oi6X000?oi6X000?o0000onA[0?oTJ`000_oTJ`04o`0001;o
oooo1?l00010ooooo`00F?ooool01?l0003oooooooooool00003oo0m0005o`000?oc<@3olc40oo<a
0?l000000oo[D0001Ol0003ol3h0oo0n0?o`?P3o000000?oif0000Go0000one:0?o]BP3okDX0o`00
0004onA[0003o`000?o[D@3o000000KohW400_l00006on9a0003o`000?oISP3o000000Coi6/000?o
0000omb50?oLQ@000_oLQ@02o`0000KohGD000?o0000omZ90?oJR@000_l000000ooVH@3o0000on9a
0004on9a0003o`000?oNOP3ogWh000?ogWh00_l00005onMN0003o`000?oUI@3oiFD000?oiFD000?o
0000onAZ0?oTJP000ooTJP04o`0001?ooooo0ol00014ooooo`00FOooool2o`000004ooooool0003o
l3d0o`0000Golc4000?o0000on]@0?l000001Oo`?P000ol0003oif00o`000005one:0004o`000?oT
J`3oi6/0o`0000?oje4000Co0000on9a0?oRL@3ohW400_l000000ooZE03o0000on9a0005on9a00;o
00001OoTJ`000ol0003og8D0omb50002o`000003onMP0?l0003ohGD000GohGD000?o0000omZ90?l0
00001?oVH@000ol0003ohW40on9a0003on9a0003o`000?oNOP3ogWh000;o000000?ojUD0o`000?oW
GP001?oWGP000ol0003oiFD0onEU0003onEU0004o`000?oTJP3oi6X0onAZ00?o00004_ooool4o`00
04Oooooo001Kooooo`03o`000?oooooo000000Kolc400_l00006oo0n00;o00001_o]BP000ol0003o
i6/0o`000005on]A0003o`000?oRL@3o000000CojU@000Co0000on9a0?oRL@3ohW400_l000000oo[
D@3o0000onA[0005onA[00;o00001?oWH0000ol0003ohGD0on5e0003on5e00;o00001OoVH@000ol0
003ohW40on9a0003on9a0003o`000?oNOP3o000000CojUD000?o0000onMN0?oWGP000ooWGP000ol0
003oiFD0onEU0002onEU00Co00004Oooool4o`0004_ooooo001Looooo`03o`000?oooooo000000?o
lc400_l00002ooHV0004o`000?o`?P3ol3h0oo0n00;o000000?om2h0o`000?o]BP001Oo]BP02o`00
00Koje400_l00006onYD0003o`000?oRL@3o000000Coje4000?o0000onA[0?oTJ`000_oTJ`02o`00
00Koif0000?o0000on5e0?oQM@000_l000000oo[D03o0000onIQ0005onIQ0003o`000?oRL@3ohW40
00;ohW400_l00005onYE0003o`000?oWGP3oieh000?oieh000?o0000onEU0?l000000_l0000Aoooo
o`Co0000Coooool005gooooo00Go0000ooooool0003olc40o`000005ooHV0003o`000?o`?P3o0000
00Com2h000Co0000one:0?o]BP3okDX00_l000000oob=P3o0000on]A0004on]A0003o`000?oa>@3o
000000KojU@00_l00005on]A0003o`000?oTJ`3oi6/000;o000000?okDX0o`000?oWH0001OoWH000
0ol0003ohGD0o`000004on]@0003o`000?oVH@3oiV4000?oiV4000?o0000on9a0?l000000_l00000
0oo]BP3o0000onYE0005onYE0003o`000?oWGP3oieh000;oieh00_l0000@ooooo`Co0000Doooool0
05kooooo0ol00006ooHV00;o00001_od;P000ol0003okDX0o`000004oo8f0005o`000?o[D@3oje40
on]A0?l000000ooa>@000ol0003ojU@0onYD0002onYD0003o`000?oa>@3o000000Goje4000?o0000
onA[0?l000001?o]BP000ol0003oif00onMP0003onMP00;o00001_o[D0000ol0003oiV40onIQ0002
onIQ00;o00001Oo]BP000ol0003ojUD0onYE0003onYE0003o`000?oWGP3o000000;o00003oooool3
o`0005Oooooo001Pooooo`;o00000oof9P02o`000003ooTM0?l0003om2h000Gom2h00_l00006oo8f
0003o`000?o[D@3o000000GolCT000Co0000onYD0?oZE03o00000ooa>@000ol0003oje40on]A0002
on]A00;o00001_o]BP000ol0003oif00onMP0002o`000003oo0n0?l0003oje0000Goje0000?o0000
onIQ0?l000000_l000000oo`?@3o0000one:0005one:0003o`000?oZE@3ojUD000;ojUD00_l0000>
ooooo`Co0000F_ooool0067ooooo0_l000000oof9P3o0000ooTM0003ooTM0004o`000?od;P3om2h0
oo@^00;o00000_og8P000ol0003olSH0oo8f0003oo8f00;o00001_oa>@000ol0003ojU@0o`000004
oo4i0003o`000?o[D@3oje4000;o000000?olSH0o`000?o]BP001Oo]BP000ol0003oif00o`000004
oo0n0003o`000?o[D03oje0000?oje000_l00005oo0m0003o`000?o]BP3okDX000?okDX000?o0000
onYE0?l000000_l0000<ooooo`Co0000G_ooool006;ooooo0ol00005ooTM0003o`000?od;P3o0000
00Gomb8000?o0000oo8f0?l000000_l00002ooLU0003o`000?oa>@3olCT000?olCT00_l00005oo4i
0003o`000?o[D@3o000000ColSH000?o0000one:0?o]BP000oo]BP02o`0000Kol3h000?o0000on]@
0?o[D0000_l000000ooc<@3o0000oo0m0005oo0m0003o`000?o]BP3okDX000;okDX00_l0000;oooo
o`Co0000H_ooool006?ooooo0ol00003ooTM00Co00001Oog8P02o`0000KombD000?o0000oo4i0?l0
00000_l000000oof9P3o0000oo4i0004oo4i00;o00001_ob=P000ol0003okDX0o`000002o`000003
oo@^0?l0003ol3h000Gol3h000?o0000on]@0?l000001?oc<@000ol0003ol3d0oo0m0003oo0m0003
o`000?o]BP3o000000;o00002_ooool3o`0006Kooooo001Uooooo`Co00001?oi6P000ol0003omb80
o`000002o`000003ooTJ0?l0003ombD000GombD00_l00005ooHV0003o`000?oa>@3olCT000;o0000
00?ombD0o`000?ob=P001Oob=P02o`0000Gom2h000?o0000oo0n0?o`?P000oo`?P02o`0000Kolc40
00?o0000oo0m0?o`?@000_o`?@02o`0000Wooooo1?l0001Yooooo`00I_ooool2o`0000GonAX00_l0
0005ooTJ0004o`000?og9@3ombD0ooLU00;o000000?onA/0o`000?of9P001?of9P000ol0003olCT0
o`000004ooLU0004o`000?ob=P3olSH0oo8f00;o000000?omb80o`000?od;P001Ood;P000ol0003o
l3h0o`000002o`000003ooHV0?l0003olc4000Golc4000?o0000oo0m0?l000000_l00007ooooo`Co
0000KOooool006Oooooo0_l000001?oi6P3o0000o`000?l00002ooTM0003o`000?oi6P3onAX000?o
nAX000?o0000ooLU0?l000001?oi6`000ol0003omRH0ooHV0002ooHV00;o00001_og9@000ol0003o
lSH0o`000004ooLR0003o`000?od;P3om2h000?om2h00_l00005ooHV0003o`000?oc<@3olc4000?o
lc400_l00006ooooo`Co0000LOooool006Sooooo1?l00004ooTM0004o`000?oi6P3onAX0ooTJ00Co
00001Ooi6`001?l0003omRH0o`000?l00002ooTK0003o`000?og9@3ombD000?ombD00_l00006ooLR
0003o`000?od;P3o000000;o000000?onAd0o`000?of9P001Oof9P000ol0003olc40o`000002o`00
00Cooooo1?l0001eooooo`00JOooool2o`000003ooooool0003o000000Ko00001?oi6`001?l0003o
nA/0ooTK0?oi6`03o`0000GonA/000?o0000ooLU0?l000000_l00002ooTJ0003o`000?og8P3omb80
00?omb800_l00005ooTM0003o`000?of9P3omRH000?omRH00_l00004ooooo`?o0000NOooool006_o
oooo00Co0000oooooooooooooooo3Ol00003ooTK0004o`000?oi6`3onA/0ooTK00Co00001Ooi6P00
0ol0003omb80o`000002o`0000;onAX000?o0000ooTM0?oi7@000ooi7@000ol0003omRH0o`000002
o`0000;ooooo1?l0001looooo`00K?ooool00ol0003oooooooooo`07ooooo`Ko00000_oi6`05o`00
00ConA/000Co0000ooTJ0?oi6P3onAX01?l00005ooTJ0004o`000?oi7@3onAd0ooTM00?o000000?o
ooooo`000?l000000_l00020ooooo`00KOooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00So00000ooi6`05o`0000ConAd000Co0000ooTJ0?oi6P3onAX02Ol00024ooooo`00K_ooool2
o`0000Sooooo00?o0000ooooooooool01ooooolAo`000003ooooool0003o000000;o0000R?ooool0
073ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000S?ooool0077o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000Soooool007;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000Toooool007?ooooo0_l0
0003ooooo`03o`000?oooooooooo00[ooooo1?l0002Gooooo`00MOooool01?l0003oooooooooool0
0008ooooo`Co0000Voooool007Kooooo00?o0000ooooool000001Oooool3o`0009oooooo001goooo
o`;o000000?oooooo`000?l000000_l0002Rooooo`00N?ooool2o`000:Kooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo000Zooooo`?o0000R_ooool00ol0003oooooooooo`0[oooo
o`?o00005Oooool00ol0003oooooooooo`0Pooooo`00:oooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`00
9Oooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003ooooo`Co0000
00?oooooo`000?l000000ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko0000
1_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o0000
0_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`?o
00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`Co
00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`?o
000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_ooool:o`0000Gooooo00?o0000oooo
ooooool07_ooool002Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool002Cooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`0000Gooooo1Ol00008ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o00000oooool00ol0
003oooooo`000002ooooo`Go00000oooool01?l0003oooooooooooooool5o`0000;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00000_ooool3o`0000Gooooo00?o0000ooooooooool07_ooool002Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00005ooooo`06o`000?oo
ooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`0Nooooo`009?ooool01_l0003ooooo
oooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000oooool2o`00
00Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00002ooooo`;o00000oooool4
o`0000?ooooo0ol00009ooooo`05o`000?ooooooooooo`000?ooool00ol00004ooooo`Co00000_oo
ool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l0
0003ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00_ooool6o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o00000oooool4o`0000Cooooo00?o
0000ooooooooool07_ooool002Cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01oooooo000Uooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo0ol00009ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o0000
2_ooool4o`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0000^ooooo`03o`00
0?oooooooooo01Sooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000;ooooo`03o`00
0?oooooooooo023ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0426235, 0.0647328, \
0.00350953, 0.00350953}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(17.850000000000023`\ Second\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            
            RowBox[{\(ComponentNumber \[Rule] 6\), 
              ",", \(Energy \[Rule] 100.`\), 
              ",", \(Offset \[Rule] 433.53111692779225`\), ",", 
              RowBox[{"OpticalLengthFunction", "\[Rule]", 
                
                TagBox[\(CompiledFunction[
                    If[#1 == 0 && #2 == 0, 
                      433.5314775332529`, \(\(433.53151699531566`\)\(\
\[InvisibleSpace]\)\) - 
                        0.00015776161987073896`\ Cos[
                            ArcTan[#1, #2]]\ \@\(#1\^2 + #2\^2\) - 
                        5.137982563765716`*^-6\ Cos[
                            2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) - 
                        5.928953638377101`*^-9\ Cos[
                            3\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(3/2\) \
- 0.0013686342607552606`\ \((\(-1\) + 
                              0.010501112826625674`\ \((#1\^2 + #2\^2)\))\) - 
                        0.0027123089130212533`\ Cos[
                            ArcTan[#1, #2]]\ \((\(-0.14492144649171615`\)\ \@\
\(#1\^2 + #2\^2\) + 0.00114137734545548`\ \((#1\^2 + #2\^2)\)\^\(3/2\))\) - 
                        0.00005886223652483755`\ Cos[
                            2\ ArcTan[#1, #2]]\ \((\(-0.01575166923993851`\)\ \
\((#1\^2 + #2\^2)\) + 0.00011027337059752225`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                        0.0014444714498488065`\ \((1 - 
                              0.03150333847987702`\ \((#1\^2 + #2\^2)\) + 
                              0.00016541005589628337`\ \((#1\^2 + \
#2\^2)\)\^2)\) + 1.073048224120136`*^-6\ Cos[
                            3\ ArcTan[#1, #2]]\ \
\((\(-0.0015218364606073068`\)\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                              9.988110235318754`*^-6\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) - 
                        0.00010193989052402478`\ Cos[
                            ArcTan[#1, #2]]\ \((0.21738216973757424`\ \
\@\(#1\^2 + #2\^2\) - 0.00456550938182192`\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                              0.000019976220470637508`\ \((#1\^2 + #2\^2)\)\^\
\(5/2\))\) + 7.236660746412512`*^-7\ Cos[
                            4\ ArcTan[#1, #2]]\ \((\(-0.00013784171324690282`\
\)\ \((#1\^2 + #2\^2)\)\^2 + 
                              8.684948298126654`*^-7\ \((#1\^2 + #2\^2)\)\^3)\
\) + 4.167561030365284`*^-8\ Cos[
                            2\ ArcTan[#1, #2]]\ \((0.03150333847987702`\ \
\((#1\^2 + #2\^2)\) - 0.0005513668529876113`\ \((#1\^2 + #2\^2)\)\^2 + 
                              
                              2.1712370745316636`*^-6\ \((#1\^2 + \
#2\^2)\)\^3)\) - 0.000036375126324640896`\ \((\(-1\) + 
                              0.06300667695975404`\ \((#1\^2 + #2\^2)\) - 
                              0.0008270502794814169`\ \((#1\^2 + #2\^2)\)\^2 \
+ 2.8949827660422184`*^-6\ \((#1\^2 + #2\^2)\)\^3)\)], "-CompiledCode-"]\),
                  False,
                  Editable->False]}], ",", 
              RowBox[{"OpticalPathDifference", "\[Rule]", 
                
                TagBox[\(CompiledFunction[
                    If[#1 == 0 && #2 == 0, 
                      0.6778297993314419`, \(\(0.7520066149520297`\)\(\
\[InvisibleSpace]\)\) - 
                        0.2965443985284866`\ Cos[
                            ArcTan[#1, #2]]\ \@\(#1\^2 + #2\^2\) - 
                        0.009657861976129431`\ Cos[
                            2\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\) - 
                        0.000011144652862362098`\ Cos[
                            3\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(3/2\) \
+ 1.530715149960792`*^-7\ Cos[4\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^2 + 
                        3.80541700723118`*^-9\ Cos[
                            5\ ArcTan[#1, #2]]\ \((#1\^2 + #2\^2)\)\^\(5/2\) \
- 2.572620791065567`\ \((\(-1\) + 
                              0.010501112826625674`\ \((#1\^2 + #2\^2)\))\) - 
                        5.0983250261524935`\ Cos[
                            ArcTan[#1, #2]]\ \((\(-0.14492144649171615`\)\ \@\
\(#1\^2 + #2\^2\) + 0.00114137734545548`\ \((#1\^2 + #2\^2)\)\^\(3/2\))\) - 
                        0.11064331266539999`\ Cos[
                            2\ ArcTan[#1, #2]]\ \((\(-0.01575166923993851`\)\ \
\((#1\^2 + #2\^2)\) + 0.00011027337059752225`\ \((#1\^2 + #2\^2)\)\^2)\) - 
                        2.7151719044314295`\ \((1 - 
                              0.03150333847987702`\ \((#1\^2 + #2\^2)\) + 
                              0.00016541005589628337`\ \((#1\^2 + \
#2\^2)\)\^2)\) + 0.0020170058865407597`\ Cos[
                            3\ ArcTan[#1, #2]]\ \
\((\(-0.0015218364606073068`\)\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                              9.988110235318754`*^-6\ \((#1\^2 + \
#2\^2)\)\^\(5/2\))\) - 
                        0.19161633488260718`\ Cos[
                            ArcTan[#1, #2]]\ \((0.21738216973757424`\ \
\@\(#1\^2 + #2\^2\) - 0.00456550938182192`\ \((#1\^2 + #2\^2)\)\^\(3/2\) + 
                              0.000019976220470637508`\ \((#1\^2 + #2\^2)\)\^\
\(5/2\))\) + 0.0013602681159195333`\ Cos[
                            4\ ArcTan[#1, #2]]\ \((\(-0.00013784171324690282`\
\)\ \((#1\^2 + #2\^2)\)\^2 + 
                              8.684948298126654`*^-7\ \((#1\^2 + #2\^2)\)\^3)\
\) + 0.00007834130295733824`\ Cos[
                            2\ ArcTan[#1, #2]]\ \((0.03150333847987702`\ \
\((#1\^2 + #2\^2)\) - 0.0005513668529876113`\ \((#1\^2 + #2\^2)\)\^2 + 
                              2.1712370745316636`*^-6\ \((#1\^2 + \
#2\^2)\)\^3)\) - 0.0683742977452746`\ \((\(-1\) + 
                              0.06300667695975404`\ \((#1\^2 + #2\^2)\) - 
                              0.0008270502794814169`\ \((#1\^2 + #2\^2)\)\^2 \
+ 2.8949827660422184`*^-6\ \((#1\^2 + #2\^2)\)\^3)\)], "-CompiledCode-"]\),
                  False,
                  Editable->False]}], 
              ",", \(OpticalPathRange \[Rule] {433.53111692779225`, 
                  433.5327748863475`}\), ",", 
              RowBox[{"OutputGraphics", "\[Rule]", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"OpticalLengthFunction", "\[Rule]", 
                      RowBox[{"(", 
                        
                        TagBox[\(\[SkeletonIndicator]  
                            SurfaceGraphics  \[SkeletonIndicator]\),
                          False,
                          Editable->False], ")"}]}], ",", 
                    RowBox[{"WaveFrontIntensity", "\[Rule]", 
                      RowBox[{"(", 
                        
                        TagBox[\(\[SkeletonIndicator]  
                            SurfaceGraphics  \[SkeletonIndicator]\),
                          False,
                          Editable->False], ")"}]}], ",", 
                    RowBox[{"OpticalPathDifference", "\[Rule]", 
                      RowBox[{"(", 
                        
                        TagBox[\(\[SkeletonIndicator]  
                            SurfaceGraphics  \[SkeletonIndicator]\),
                          False,
                          Editable->False], ")"}]}]}], "}"}]}], 
              ",", \(RayBoundary \[Rule] {{\(-11.236724029327576`\), 
                    4.7870957420594165`}, {\(-8.011993408206337`\), 
                    8.011993408206337`}}\), 
              ",", \(RefractiveIndex \[Rule] 1.0002694514570802`\), 
              ",", \(ResidualFitError \[Rule] 0.00013655373963811581`\), 
              ",", \(Source \[Rule] 1\), ",", \(SpatialScale \[Rule] 1\), 
              ",", \(SurfaceNumber \[Rule] 1\), 
              ",", \(WaveFrontID \[Rule] 1\), ",", 
              RowBox[{"WaveFrontIntensity", "\[Rule]", 
                
                TagBox[\(InterpolatingFunction[{{\(-13.97786445040836`\), 
                        7.5282361631402015`}, {\(-10.75313382928712`\), 
                        10.753133829287117`}}, "<>"]\),
                  False,
                  Editable->False]}], ",", \(WaveLength \[Rule] 0.532`\), 
              ",", \(WaveTilt \[Rule] WaveTilt\)}], "}"}], "}"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[28]=",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindInterference[Join[wavefront1[[2]],wavefront2[[2]]]]//Timing\
\>", "Input",
  CellLabel->"In[29]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.62108 0.0751373 0.5 0.0600211 [
[.01998 -0.0125 -6 -9 ]
[.01998 -0.0125 6 0 ]
[.17026 -0.0125 -6 -9 ]
[.17026 -0.0125 6 0 ]
[.32053 -0.0125 -6 -9 ]
[.32053 -0.0125 6 0 ]
[.47081 -0.0125 -6 -9 ]
[.47081 -0.0125 6 0 ]
[.62108 -0.0125 -3 -9 ]
[.62108 -0.0125 3 0 ]
[.77135 -0.0125 -3 -9 ]
[.77135 -0.0125 3 0 ]
[.92163 -0.0125 -3 -9 ]
[.92163 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04984 -24 -4.5 ]
[-0.0125 .04984 0 4.5 ]
[-0.0125 .19989 -12 -4.5 ]
[-0.0125 .19989 0 4.5 ]
[-0.0125 .34995 -24 -4.5 ]
[-0.0125 .34995 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .65005 -18 -4.5 ]
[-0.0125 .65005 0 4.5 ]
[-0.0125 .80011 -6 -4.5 ]
[-0.0125 .80011 0 4.5 ]
[-0.0125 .95016 -18 -4.5 ]
[-0.0125 .95016 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -66 0 ]
[.5 1.0125 66 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01998 0 m
.01998 .00625 L
s
[(-8)] .01998 -0.0125 0 1 Mshowa
.17026 0 m
.17026 .00625 L
s
[(-6)] .17026 -0.0125 0 1 Mshowa
.32053 0 m
.32053 .00625 L
s
[(-4)] .32053 -0.0125 0 1 Mshowa
.47081 0 m
.47081 .00625 L
s
[(-2)] .47081 -0.0125 0 1 Mshowa
.62108 0 m
.62108 .00625 L
s
[(0)] .62108 -0.0125 0 1 Mshowa
.77135 0 m
.77135 .00625 L
s
[(2)] .77135 -0.0125 0 1 Mshowa
.92163 0 m
.92163 .00625 L
s
[(4)] .92163 -0.0125 0 1 Mshowa
.125 Mabswid
.05755 0 m
.05755 .00375 L
s
.09512 0 m
.09512 .00375 L
s
.13269 0 m
.13269 .00375 L
s
.20783 0 m
.20783 .00375 L
s
.24539 0 m
.24539 .00375 L
s
.28296 0 m
.28296 .00375 L
s
.3581 0 m
.3581 .00375 L
s
.39567 0 m
.39567 .00375 L
s
.43324 0 m
.43324 .00375 L
s
.50837 0 m
.50837 .00375 L
s
.54594 0 m
.54594 .00375 L
s
.58351 0 m
.58351 .00375 L
s
.65865 0 m
.65865 .00375 L
s
.69622 0 m
.69622 .00375 L
s
.73379 0 m
.73379 .00375 L
s
.80892 0 m
.80892 .00375 L
s
.84649 0 m
.84649 .00375 L
s
.88406 0 m
.88406 .00375 L
s
.9592 0 m
.9592 .00375 L
s
.99677 0 m
.99677 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04984 m
.00625 .04984 L
s
[(-7.5)] -0.0125 .04984 1 0 Mshowa
0 .19989 m
.00625 .19989 L
s
[(-5)] -0.0125 .19989 1 0 Mshowa
0 .34995 m
.00625 .34995 L
s
[(-2.5)] -0.0125 .34995 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .65005 m
.00625 .65005 L
s
[(2.5)] -0.0125 .65005 1 0 Mshowa
0 .80011 m
.00625 .80011 L
s
[(5)] -0.0125 .80011 1 0 Mshowa
0 .95016 m
.00625 .95016 L
s
[(7.5)] -0.0125 .95016 1 0 Mshowa
.125 Mabswid
0 .07985 m
.00375 .07985 L
s
0 .10986 m
.00375 .10986 L
s
0 .13987 m
.00375 .13987 L
s
0 .16988 m
.00375 .16988 L
s
0 .2299 m
.00375 .2299 L
s
0 .25992 m
.00375 .25992 L
s
0 .28993 m
.00375 .28993 L
s
0 .31994 m
.00375 .31994 L
s
0 .37996 m
.00375 .37996 L
s
0 .40997 m
.00375 .40997 L
s
0 .43998 m
.00375 .43998 L
s
0 .46999 m
.00375 .46999 L
s
0 .53001 m
.00375 .53001 L
s
0 .56002 m
.00375 .56002 L
s
0 .59003 m
.00375 .59003 L
s
0 .62004 m
.00375 .62004 L
s
0 .68006 m
.00375 .68006 L
s
0 .71007 m
.00375 .71007 L
s
0 .74008 m
.00375 .74008 L
s
0 .7701 m
.00375 .7701 L
s
0 .83012 m
.00375 .83012 L
s
0 .86013 m
.00375 .86013 L
s
0 .89014 m
.00375 .89014 L
s
0 .92015 m
.00375 .92015 L
s
0 .01983 m
.00375 .01983 L
s
0 .98017 m
.00375 .98017 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01998 .99375 m
.01998 1 L
s
.17026 .99375 m
.17026 1 L
s
.32053 .99375 m
.32053 1 L
s
.47081 .99375 m
.47081 1 L
s
.62108 .99375 m
.62108 1 L
s
.77135 .99375 m
.77135 1 L
s
.92163 .99375 m
.92163 1 L
s
.125 Mabswid
.05755 .99625 m
.05755 1 L
s
.09512 .99625 m
.09512 1 L
s
.13269 .99625 m
.13269 1 L
s
.20783 .99625 m
.20783 1 L
s
.24539 .99625 m
.24539 1 L
s
.28296 .99625 m
.28296 1 L
s
.3581 .99625 m
.3581 1 L
s
.39567 .99625 m
.39567 1 L
s
.43324 .99625 m
.43324 1 L
s
.50837 .99625 m
.50837 1 L
s
.54594 .99625 m
.54594 1 L
s
.58351 .99625 m
.58351 1 L
s
.65865 .99625 m
.65865 1 L
s
.69622 .99625 m
.69622 1 L
s
.73379 .99625 m
.73379 1 L
s
.80892 .99625 m
.80892 1 L
s
.84649 .99625 m
.84649 1 L
s
.88406 .99625 m
.88406 1 L
s
.9592 .99625 m
.9592 1 L
s
.99677 .99625 m
.99677 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .04984 m
1 .04984 L
s
.99375 .19989 m
1 .19989 L
s
.99375 .34995 m
1 .34995 L
s
.99375 .5 m
1 .5 L
s
.99375 .65005 m
1 .65005 L
s
.99375 .80011 m
1 .80011 L
s
.99375 .95016 m
1 .95016 L
s
.125 Mabswid
.99625 .07985 m
1 .07985 L
s
.99625 .10986 m
1 .10986 L
s
.99625 .13987 m
1 .13987 L
s
.99625 .16988 m
1 .16988 L
s
.99625 .2299 m
1 .2299 L
s
.99625 .25992 m
1 .25992 L
s
.99625 .28993 m
1 .28993 L
s
.99625 .31994 m
1 .31994 L
s
.99625 .37996 m
1 .37996 L
s
.99625 .40997 m
1 .40997 L
s
.99625 .43998 m
1 .43998 L
s
.99625 .46999 m
1 .46999 L
s
.99625 .53001 m
1 .53001 L
s
.99625 .56002 m
1 .56002 L
s
.99625 .59003 m
1 .59003 L
s
.99625 .62004 m
1 .62004 L
s
.99625 .68006 m
1 .68006 L
s
.99625 .71007 m
1 .71007 L
s
.99625 .74008 m
1 .74008 L
s
.99625 .7701 m
1 .7701 L
s
.99625 .83012 m
1 .83012 L
s
.99625 .86013 m
1 .86013 L
s
.99625 .89014 m
1 .89014 L
s
.99625 .92015 m
1 .92015 L
s
.99625 .01983 m
1 .01983 L
s
.99625 .98017 m
1 .98017 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
0 0 m
0 1 L
s
[(Interference Intensity)] .5 1.0125 0 -1 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00762700673C00554B003643001A32000B2500041C00021900031B00072100112B002137
00394400524D006043006E33007A2000840B098D001D95002F9B003DA00048A40050A600
56A80059A9005AA9005AA90058A80056A80054A70051A6004FA6004DA5004BA4004AA400
49A40048A40048A40049A4004AA4004BA5004DA5004FA60051A60053A70056A80057A800
59A9005AA9005BA9005BA9005BA90059A90057A80053A7004FA60049A40043A2003CA000
349D002B9A002297001893000E8F00048B0000870500830E007E18007A2000752800702F
006C3600673B006340005F44005B4800574A00534C00504E004B4D00454A003F47003A45
003743003342003140002F3F002E3F002D3E002D3E002E3E002F3F003140003342003744
003C46004249004A4C00504E00554B005A4800604300663D006D34007429007C1B00840B
068C001A94002E9B0040A1004FA60057A80057A8004DA500399F001D9500008803007725
00643F00504D002B3D00132C00072000021A00031B000A24
00673C00534C002F3F00152E00082200031B00021A00051E000D28001D3500384400544C
00643F00742900830E0F90002D9B0049A40061AB0074B00082B4008BB60090B80092B800
91B8008DB70089B60083B4007EB30078B10073B0006EAF006AAE0067AD0065AC0063AC00
63AB0063AC0064AC0066AC0069AD006CAE0070AF0074B00079B2007DB30082B40086B500
8AB6008EB70091B80092B80093B80092B80090B8008DB70088B60081B40079B2006FAF00
64AC0058A8004BA4003EA000309C00229700149100068C00008706008112007B1D007627
007030006A3700653E006043005B4700564B00524D004D4E00444A003D46003743003140
002D3E00293C00263A002439002237002137002036002036002036002137002238002539
00283B002C3D003140003844004048004B4D00524D00594900604300683B00702F007920
00830E088D002297003EA0005AA90073B00085B5008FB7008BB6007AB2005AA9002F9B00
018A00007627006043004349001D34000A2500031B00031A
00504E00293C00112B00061F00021A00031B00092300173000314000534C00663D007922
018A0029990053A70079B20099BA00B2C000C3C400C7BF00C7BD00C7BE00C6C100C4C400
BAC200AFBF00A5BD009ABA0091B80088B60081B4007BB20076B10073B00071AF0070AF00
71AF0073B00076B1007AB20080B30086B5008DB70094B9009CBB00A5BD00ADBF00B5C100
BDC300C4C400C6C100C7BF00C7BD00C8BD00C7BD00C7BF00C6C200C1C400B7C100ABBE00
9DBB008DB7007BB20069AD0056A80043A200309C001E95000C8F00008803008112007A1F
00732B006D3400663D006043005A4800554C004F4E00454A003C46003442002D3E00273B
002238001F35001B3300193100173000152F00142E00142D00142D00142D00142E00162F
001730001A32001D3400213700263A002D3E003643004249004F4E00574A005F44006939
00732B007E17018A0020960044A20069AD008EB700AFBF00C5C400C6C000C3C400A2BC00
71AF00379E0000880200703000564B002C3E00102A00051E
002338000D2700041D00031A00051E00102A00263A004E4E00643F007A200C8E0040A100
75B100A8BE00C8BC00CFA900D49C00D69600D79400D69700D49D00D1A600CDAF00C9B900
C5C300B7C100A7BD0099BA008DB70083B4007BB20075B10071AF006EAF006EAF006FAF00
72B00076B1007CB20083B4008CB70096B900A1BC00ADBF00BAC200C5C300C8BC00CBB400
CEAD00D0A600D3A000D49B00D69700D79400D79400D69500D59800D49D00D1A400CEAD00
CAB700C5C200B3C0009BBA0082B40068AD004FA600379E002096000B8E00008607007E18
007626006E3300673C005F4400584900524D00494C003D46003341002A3D002338001E35
00193100152F00122C00102A000E29000D27000C26000B25000B25000B25000B25000B25
000C26000D27000E2900102A00132D001730001C34002439002D3E003945004A4C00554B
005F44006B3700772500840B1692003FA1006EAF00A0BC00C7BF00D0A800D49B00D49C00
CEAC00BEC3007AB2002F9B00008014006340004048001831
000A2400041C00031B000923001931003945005B4700732B028A003FA1007FB300BCC300
CEAC00D79300DD8200DF7A00DF7A00DD7F00DA8900D69600D1A400CCB200C6C000B5C100
A0BC008DB7007DB3006FAF0063AC005AA90054A7004FA6004DA5004CA5004DA50050A600
55A7005CA90064AC006EAF007AB20087B50096B900A6BD00B7C100C6C200CAB800CEAD00
D2A300D59900D89000DB8700DD8100DF7C00DF7900E07900DF7B00DD8000DB8800D89200
D39E00CEAC00C9BA00BAC2009DBB007EB30061AB0044A200299900109000008705007E18
007528006C3500643F005C4700544C004B4D003D4600314000273B001F3600193200142E
00102A000D28000B2500092300082200072000061F00061F00051E00051E00051E00051E
00051E00051F00061F000720000822000A24000C26000F2900142D001A32002338002F3F
00404800524D005D45006A3800792200880325980057A80090B800C6C100D2A200D98D00
DC8500D98D00D0A800B2C00058A800078C00006E3200514D
00041C00051E000D28002439004F4E00683A0082112B9A0074B000C0C300D2A200DC8500
E27000E56500E66400E46B00DF7900DA8B00D39E00CDB000C5C200ABBE0090B80078B100
63AC0052A70044A200389E002F9B002899002497002197002196002297002598002A9A00
309C00399F0043A2004FA6005EAA006EAF0080B30093B800A8BE00BFC300C8BB00CEAE00
D3A000D79300DB8600DF7A00E27000E46800E66300E76100E66200E56600E36E00DF7900
DB8700D69700CFA900C8BB00B3C00090B8006EAF004DA5002E9B00129100008706007D1B
00732C00693900604300574A004F4E003F4700314000263A001D3400162F00112B000D27
000A2400082200062000051E00041D00041C00031B00031A00031A00021A00021A00021A
00021A00021A00031A00031A00031B00041C00041D00051F000721000A24000E2800132D
001B3300283B00394400504E005D46006B37007B1D078D00389F0075B100B7C100CFA900
DA8A00E07700E07600DA8B00CAB8007EB300239700007823
00072100142D003241005A480075281090005AA900ACBF00D1A500DF7B00E75F00EB5000
EC4F00E95700E56700DE7D00D69600CEAE00C5C400A1BC0080B30063AB004AA400359D00
2498001793000C8E00048B00008901008705008608008608008607008705008900048B00
0C8F001592002196002E9B003EA00050A60065AC007BB20094B900AFBF00C6C100CCB100
D2A000D88F00DE7F00E26F00E76100EA5600EC4D00ED4800EE4800ED4B00EB5300E75F00
E36E00DD8100D69500CFAB00C6C100A3BC007BB20056A800339D00149100008607007B1D
00702F00663D005C4700524D00444A00344200273A001D3400152E000F2A000B25000822
00061F00051D00041C00031B00021A00021900021900021900021900021900021900021A
00021A00021A00021900021900021900021900021900021900031A00031B00041D000620
000924000E2900162F002238003542004F4E005D45006E3300801419940055A8009ABA00
CBB300D98C00E36E00E66200E07800D2A200A3BC0040A100
001B33004249006440008113369E008CB700CCB200DD8200E95A00F03E00F23800EF4100
EA5500E36F00DA8B00CFA900C5C40099BA0071B00050A600339D001C9400098D00008705
008111007D1A00792100762600742900732B00732B00732B007529007626007921007C1B
00801400850A008A000E8F001E9600329C0048A30060AB007CB2009ABA00BAC200CAB700
D1A300D98F00DF7A00E56600EA5400EF4400F23700F42F00F52C00F42E00F23600EF4200
EA5300E46800DD8000D59A00CBB400B6C10089B6005EAA00379E00159200008608007920
006E3300624100584A004D4E003944002A3C001E3500152E000F29000A2400072100051E
00041C00031A00021900021900021900021A00031A00031B00031C00041C00041D00051D
00051E00051E00051E00051D00041D00041C00031B00031B00021A00021900021900021A
00031B00041D000721000C2600132D00203600344200504E00604300732B008803339D00
7AB200C6C100D79300E46A00E85D00E46900D88F00C5C400
00504E006C3600890051A600B5C100D59A00E36C00ED4A00F23800F23700ED4A00E56700
DB8800CFA900BFC3008CB70060AB003A9F001B9400028A00008211007A2000732B006D33
00693A00653E006241006043005F44005F44005F4400604300624100643F00673B006B37
007030007528007B1E0081120088030F90002498003DA0005AA90079B2009CBB00C2C400
CDB000D59900DD8100E46A00EA5300F04000F43000F72400F81E00F81E00F72500F33100
EF4300E95A00E17400D89000CEAC00BEC3008DB7005FAA00359D0010900000830D007626
006A38005E4500534D004148002E3F00203700162F000F29000A2400072000041D00031B
00021A00021900021900021A00031B00041C00051E00061F000721000923000A24000B25
000C26000C27000C27000C27000C26000B25000A2400082200072000051E00041D00031B
00021A00021900021A00031B00051F000A2400112B001F3500354200524D00653E007920
0F900052A600A4BD00D1A600DE7E00E56700E46900DB8800
00722D0E8F0063AC00C5C300DA8A00E66100ED4900EF4200EC4C00E66200DC8500CFAA00
B7C10080B40050A600279900068C00008112007725006E3300663D005F44005A4800554B
00514D004E4E004A4D00474B00464B00474B00494C004C4D00504E00524D00564B005A48
005F4400653E006B3700722D007920008210028B001A9400359D0055A70079B200A0BC00
C6C200CFA900D88F00E17500E85C00EE4400F43100F72200F91900FA1700F91C00F62700
F13A00EB5100E36D00DA8B00CFA900C0C3008CB7005BA900309C000A8E0000801400722D
00653E005949004C4D00354300253900193100102A000A2400072000041D00031B000219
00021900021A00031B00041D00061F000821000A24000D27000F2900122C00152E001830
001A32001B33001C34001C34001C33001B3300193100162F00132D00102A000D27000A24
00072000051E00031B00021A00021900031A00051D00092300112B002036003A4500574A
006B370082112A9A0079B200C6C200D59800DF7A00E17400
19940071AF00C7BD00DA8900E85D00EC4E00EB5200E56600DC8300D1A600BAC2007CB200
47A3001B9400008606007920006E33006440005B4800534C004A4D003F47003643003040
002B3D00283B00263A00253900253900263A00283B002B3D002F3F003542003C4600464B
00504E00554B005C47006340006B36007429007D19008704159200339D0057A8007EB300
AABE00C9BA00D39E00DD8200E56500ED4A00F33300F82100FB1500FC1000FB1300F81E00
F43000ED4800E56600DB8600D0A600C2C4008BB60058A8002A9A00038B00007C1B006E33
00604300544C004048002C3D001D3400122C000B2600072100041D00031A000219000219
00031A00041C00051E000822000B25000F2900132D001831001D3400233800283B002D3E
003241003643003844003A45003A45003944003643003241002D3E00283B002237001B33
00152E00102A000B2500072100041D00031A00021900021A00041D00092300132C002539
00444A005E45007429098D004CA5009BBB00CDB000D98E00
78B100C8BC00D98D00E46A00E95800E56600DD8200D1A400BFC30081B40046A300169200
00830E00742900673B005C4700524D004349003442002A3C002237001C3400183000152E
00132D00122C00112B00112B00112B00122C00142E00162F001A32001E35002338002A3D
003442003F48004E4E00564B005E4500673C00712F007B1D008606159200379E005FAA00
8BB600BCC200CEAD00D98F00E26F00EB5100F23600F82000FB1100FD0900FD0A00FB1400
F62600F04000E75E00DD8000D1A300C4C4008AB60054A700259800008802007921006A38
005C46004F4E00364300233800162F000E2800082200051E00031B00021900021900031A
00041D000620000A24000E2800132D001A32002237002A3D003342003D4600464B004F4E
00524D00554B00574A00584900594900594900584900564A00544C00514D004A4D004048
003542002A3C002036001730000F2900092400051F00031B00021900021A00051D000A25
001730002E3F00524D00683A00801427990073B000C2C400
C6C000D69700DE7C00E17400DE7F00D39F00C5C40085B50049A40017930000821100712E
00634000564B00474B00344200263A001C3400152E00102A000D27000B25000923000822
000721000721000720000721000721000822000923000B25000D27000F2A00132D001831
001F3600283B00334100424900514D005A4800643F006F31007B1E0087051A940040A100
6CAE009DBB00C8BD00D39E00DE7C00E85C00F03D00F72400FB1100FE0700FE0500FC0E00
F82000F13900E95900DE7D00D2A200C3C40087B5004FA6001F960000850800752700663D
00584A00454A002D3E001C3400112B000A2400061F00031B00021900021900031A00041D
000721000B2500102A001830002137002B3D00374400454A00504E00564B005C47006142
00653E00693A006C36006E33006F31007030006F31006E32006C3500693900653E006043
005B4800544C004B4D003A45002B3D001E3500132D000B2600061F00031B00021900031A
00061F000E28001E35003E47005C4700742A088D004EA500
D0A600D79300D79200D2A200C8BD0090B80050A6001A940000821000712E00614200534C
003D47002A3C001D3400142D000E28000A2400072100061F00041D00041C00031B00031B
00031B00031A00031A00031B00031B00031C00041C00051E00061F000821000A24000D27
00112B001830002036002B3D003A45004E4E005849006340006F31007C1C008900229700
4DA5007EB300B4C000CDAE00D98C00E46900EE4800F52B00FA1500FE0800FE0400FD0B00
F91C00F23600E95700DE7C00D2A200C0C30082B40049A40017930000820F00722D006241
00534C003B4600253A001730000D2700072100041C00021A00021900031A00041D000721
000B2600122C001A3200253A00334100434900514D00594900604300673C006D3300732B
007822007D1A00811300840D00860800870500870500870600850900830F007F16007B1E
007528006F3200673B005F4400564B004A4C00354200233800162F000C2600061F00031B
00021900031B00082200142D002B3D00514D00693A008210
CFAA00CDAE00C6C10099BA0061AB0025980000850A00722C00614200524D003945002539
001730000F29000A2400062000041D00031B00031A000219000219000219000219000219
00021900021900021900021900021900021900021900021A00031B00041C00051E000720
000923000D2800132D001B3300273B003743004B4D00584900643F00712E007F16098D00
319C0060AB0096B900C7BE00D49B00E07600EB5300F33300F91A00FD0900FF0300FD0900
F91900F33300EA5500DF7B00D2A300BEC3007DB30043A200119000007F16006E33005E45
004F4E003341001F3500122C000A2400051E00031B00021900021A00041C000620000B25
00122C001C3300283B003844004C4D00564B005F4400683A00702F007822008015008607
068C001391001F9600299900309C00369E00399F00399F00369E00319C002999001E9500
119000028A0000830D007B1D00722D00683B005D4600514D003B4500263A00162F000B25
00051E00021A00021900051E000D27001E35004148005F44
C0C3009BBA0068AD00339D00028B0000772500643F00534C00394500233800152E000C27
00072100051D00031B00021A00021900021900021A00031B00031B00041C00041D00041D
00041D00041D00041C00041C00031B00031A00021A00021900021900021900031A00031C
00051E000721000B2500112B001931002539003643004D4E005A4800673C00752800840C
17930045A3007AB200B6C100CFA900DC8400E75E00F13B00F81F00FD0B00FF0300FE0700
FA1600F43000EB5200DF7A00D2A300BBC20078B1003DA0000A8E00007C1C006A38005A48
00464B002B3D001932000E2800072100041C00021A00021900031B00061F000A2400112B
001B3300293C003B45004F4E005A4800643F006E33007823008112008A00149200289900
3B9F004DA5005DAA006BAE0077B10080B30085B50088B60087B50082B4007BB2006FAF00
61AB004FA6003B9F002598000E8F00008509007A1F006E3300614200544C003C46002439
00132D00092300041C00021900031B00082200162F003241
70AF0040A1000E8F00007D1A006A3800584A003F4700253900152E000C2600062000041C
00021A00021900021900031B00041C00051E000620000822000923000A24000B25000B25
000B25000A2400092300082200072100061F00051E00041C00031B00021A000219000219
00031A00041C000620000A2400102A00193100263A00384400504E005D46006B37007A1F
018A002C9A0060AB009CBB00CAB700D89100E46900EF4400F72500FC0E00FF0300FE0500
FB1300F42D00EB5000DF7900D1A300B8C10074B000379E00048B0000792200673C00564B
003E4700253900152E000B2500061F00031B00021900031A00041D000822000F29001931
00273B003A4500504E005B4700673C00722D007D1A0088041491002D9B0047A30061AB00
79B20090B800A4BD00B6C100C5C400C7BE00C9B900CAB600CAB600CAB700C9BA00C6C000
BFC300ADBF0098BA007FB30063AC0045A200259800068C00007F1600712E00624100534C
003743001F35000F2900062000031A00021A00061F00102A
1E960000840C00712F005E45004A4D002B3D001830000C2700062000031B000219000219
00031A00041D00061F000922000B26000F2900122B00142E001730001831001931001931
00183100173000152E00122C00102A000D27000A2400082100061F00041C00031B000219
00021900021A00041C00061F000A2400102A001A3200283B003E4700544C00624100712E
00811116920048A30082B400C4C400D39E00E17500EC4E00F52B00FB1200FE0500FE0400
FB1200F52B00EC4F00E07900D1A400B5C1006FAF00319C0000890100762700634000524D
003643001F3600112B00082200041D00021A00021900031B000620000C2600152F002338
003743004F4E005B4700683B00742A008013068C0023970041A10061AB0081B4009FBC00
BCC200C8BB00CEAD00D2A200D69700D88F00DA8900DC8400DD8200DD8200DC8400DA8900
D89000D59900D1A500CCB300C5C200A8BE0083B4005DAA00359E0010900000811200702F
005F44004E4E002D3E001730000A2400041C00021A00041D
00792100663D00544C003643001E35000F2900072100041C00021900021900031B00051E
000822000D2700122C001730001D3400233800293C002D3E003040003241003341003241
003040002D3E00293C002439001E3500193100142D000F29000B2500082200051E00041C
00031A00021900021A00031B00061F000A2400112B001C34002E3E00474B00594900683A
007921028A00319C006BAE00ACBF00CFAB00DD8100E95700F33200FA1600FE0600FE0400
FC1000F52900EC4D00E07800D1A500B1C0006AAD002B9A0000860600732B006043004F4E
003040001A32000E2800072000031B00021900031A00051D00092300112B001E35003040
004A4C00594900673C00742A0081110B8E002C9A0050A60075B1009ABA00BEC300CBB500
D2A300D79200DC8300E17500E46A00E76100E95900EA5400EB5100EB5000EB5000EA5300
E95800E76000E46A00E07700DB8600D59900CEAD00C5C40099BA006BAE003CA0000E8F00
007E18006C36005949003F47002036000E2800061F00031A
005D4500474B00283B00142E000A2400041D00021A00021900031B00061F000A2400102A
001830002137002B3D003543003F4800484C004F4E00524D00534C00544C00544C00534C
00514D004F4E00484B003F47003643002D3E002439001C3400152E000F29000A24000720
00041D00031A00021900021A00031C00061F000B2500142D00213700364300514D006043
00712E00830E1D950054A70096B900CAB700D98C00E76100F13A00F91B00FE0800FF0400
FC0F00F62800EC4C00E07800D1A500AEBF0065AC0026980000840C007030005D4600484C
002A3C00162F000B2500051E00031A00021900031B000620000D2700183000293C004048
00564B00643F00722D0080130C8E00309C0058A80082B400ACBF00C8BB00D1A500D89000
DF7C00E46A00E95A00EC4C00EF4100F23800F43100F52C00F62800F62600F62600F62700
F52A00F42F00F23600F03F00ED4C00E85C00E26F00DB8600D39F00C9BA00A2BC006AAD00
349D00038B0000782400643F004F4E002B3D00132D000821
003944001E35000E2900072000031B00021900031B00061F000B2500122C001C3400293C
00374400474B00524D005849005D4500624100653E00673B00693A00693A00683A00673C
00643F006142005D4600584A00524D004A4C003C46002F3F002439001A3200122C000C26
00072100041D00031A00021900021A00041C000721000D2800183100293C004349005849
006939007B1D0A8E0040A10080B400C5C200D69700E46B00EF4100F81F00FD0A00FF0400
FC0D00F62600ED4B00E07700D0A600ABBE0061AB00219600008211006D34005A48004148
00243900132D00092300041D00021900021A00041D00092300122B00203600364300504D
005F44006E32007E19078D002E9B005AA90087B500B6C100CCB300D59A00DD8100E46B00
EA5700EE4500F23600F52A00F82000FA1900FB1300FC0F00FC0C00FD0B00FD0A00FD0A00
FD0B00FC0D00FB1100FA1600F81E00F62900F23700ED4A00E76000DF7B00D59900C8BB00
98BA005BA90021970000820F006C3500574A003643001931
001830000B2500051E00031A00031A00051E000A2400112B001D34002D3E00404800514D
005A48006341006A38007030007528007921007C1C007E18007F17007E17007D1A007B1E
00782300742A006F31006939006340005C4700544C004A4D003945002A3D001E3500142D
000D2700082100041D00031A00021900031A00051D00092300112B001F3500344200514D
00624100742A0087052D9B006CAE00B4C100D2A200E17400ED4900F72400FD0C00FF0400
FD0C00F72400ED4900E07700D0A700A8BE005CAA001C9500007F15006A3700574A003B45
00203600102A00072100031B00021900031A00061F000C26001730002A3C00454A005949
00693900792100890027990055A70086B500B9C200CDAF00D79300E07800E75F00ED4900
F23600F62700F91B00FB1100FD0B00FE0600FF0300FF0200FF0100FF0000FF0000FF0000
FF0000FF0000FF0000FF0100FF0400FD0800FC1000F91C00F52B00F04000E95A00DF7C00
D3A000C4C40081B40040A100038B0000742A005D46004048
00092300041D00031A00041C000721000F29001B33002C3E00434900554B006043006A38
00732B007B1D00830F008802098D001191001893001B94001C95001A94001592000E8F00
058C00008705008111007B1E00742A006C3500643F005B4700524D004148002F3F002036
00152E000D2700072100041C00021A00021900031B00061F000C2600173000293C00454A
005B48006D340080131B940059A800A1BC00CEAD00DE7E00EB5000F52900FC0F00FE0400
FD0B00F72300ED4800E07700D0A800A5BD0058A800179300007D1A00683B00544C003542
001C33000D2800061F00031A00021900031C00082100102A001F3500364300524D006241
00732C00840D1A94004AA4007EB300B4C100CDAF00D89100E17300E95800F04000F52D00
F91D00FB1100FD0900FE0400FF0200FF0100FF0200FF0300FE0500FE0600FE0700FE0800
FE0800FE0600FE0500FF0300FF0100FF0000FF0100FF0400FD0A00FA1500F62700EF4200
E66200DB8700CDAF00A4BD0057A800149100007A1F006241
00041C00031B00051E000B2500152F00263A003D4700544C006142006E3300792100830D
078C001B94002E9B003EA0004BA40055A7005BA9005EAA005DAA0059A80051A60046A300
399F002A9A00199400088D00008509007C1B00732B006939005F4400554B00454A003140
00203600142E000C2600062000031B00021900021A00041C00082200112B001F36003844
00544C00663D007A200C8E0047A3008EB700CAB700DB8700E95800F42F00FB1200FE0500
FD0A00F72100EE4700E07600D0A800A2BC0054A700139100007B1E00653E00514D003040
001831000B2500051E00021A00021A00041D000A2400152E00273B004349005A48006B37
007C1B0A8E00399F006FAF00A8BE00CBB400D79300E17300EA5600F13C00F62700FA1700
FD0C00FE0500FF0200FF0200FE0500FD0900FC0E00FB1300FA1800F91C00F81F00F82000
F82100F81F00F91D00FA1900FB1300FC0E00FD0900FE0500FF0200FF0300FD0A00F91A00
F43100EC4E00E17200D49B00BAC2006AAD00229700007F16
00041D000721000F29001D34003341004F4E005E45006C35007A1F008704179300339D00
4DA50066AC007CB2008DB7009ABA00A3BD00A8BE00A9BE00A7BD00A0BC0095B90088B600
77B10064AC004EA500379E001F9600088D0000830E007822006D3400624100564B00464B
003040001E3500122C000A2400051E00031A00021900031B00061F000C26001831002D3E
004D4E00604300742A008901369E007DB300C6C000D89000E75F00F33400FB1400FE0500
FD0900F82000EE4600E07600CFA900A0BC0050A6000E8F00007922006340004F4E002B3D
00152F00092300041C00021900031A00061F000D27001B3200314000504E00624200742A
0086072598005BA90096B900C8BC00D59A00E07700E95700F13C00F72500FB1400FD0900
FF0300FF0200FE0500FD0B00FB1300F91C00F72500F42E00F23600F13C00EF4100EE4500
EE4600EE4600EF4300F03E00F23700F42F00F62600F91D00FB1300FD0B00FE0700FD0B00
FA1500F62600F04000E66200D79200C6C20077B1002C9A00
000A2400132D002439003F4700584A00673B0077250086071A94003FA10062AB0083B400
A0BC00BBC200C7BD00CBB400CEAD00CFA900D0A700D0A700CFAA00CDAF00CAB600C7BF00
BAC200A3BC0089B6006EAF0050A600339D00169200008704007B1D006F3100634100564B
004349002C3E001B33000F2900082200041C00021A00021900041C00092300122C002439
004048005A48006E3300830E2799006CAE00BCC300D59900E56700F13900FA1700FE0600
FD0900F81F00EE4500E07600CFAA009DBB004DA5000A8E00007725006142004A4C00273B
00132C00082200031B00021900031B00072100102A002137003D4600574A006939007C1B
0E8F0042A2007EB300BDC300D1A400DD8000E85D00F03F00F62600FB1400FD0800FF0300
FF0400FD0900FB1200F81D00F52A00F23700EF4400EB5000E85B00E66400E46B00E27000
E17300E17300E27100E36D00E56600E85D00EB5200EE4600F23800F62900F91C00FA1500
FB1300FA1600F72200F23700E76000D98E00C8BD0080B300
001730002B3D004B4D005E45007030008013109000399F0065AC0092B800B9C200C9B800
D0A700D59900D98C00DC8300DE7D00DF7A00E07900DF7A00DE7E00DC8400D98D00D59800
D1A400CCB300C5C300A8BE0087B50064AC0041A1001F9600008900007D1B006F31006142
00544C003E4700273A00162F000C2600061F00031B00021900031B000620000E28001C34
00354300544C00683B007D191993005CAA00ACBF00D2A100E36E00F03F00F91A00FE0700
FD0800F81E00EF4400E17500CFAA009ABA0049A400068C00007528005E4500444A002338
00102A00072000031A00021900041C00092300152E00293C00494C005E4500712E008509
26980061AB00A2BC00CCB300D98C00E56700EE4500F52A00FA1500FD0900FF0300FE0500
FD0C00FA1800F62600F23700EE4800E95800E46800E07700DC8300D98E00D69600D49C00
D2A000D2A200D2A100D39E00D59800D89000DC8500E07800E46800EA5700EE4500F23600
F62900F82000F91D00F72300F03E00E66200D98D00C8BB00
00314000514D00634000762700880228990057A80088B600BAC200CDB000D59900DB8600
E17500E56700E85C00EA5400EB5000EC4D00EC4D00EB5000EA5400E85B00E66400E27000
DE7E00D98E00D39F00CCB300C0C30099BA0071AF0049A400239700008A00007C1C006D34
005E4400504E00354300203600112B00092300041D00021900021A00051D000A2500162F
002C3E004F4E0062410078230C8F004EA5009DBB00CFA900E17500EF4400F81E00FD0800
FE0800F91C00EF4300E17500CFAB0098BA0045A300038B0000732B005C46004048002036
000E2800061F00021A00021900051E000C2600193200324100524D00653E007921098D00
40A10080B400C5C400D49C00E17500EB5000F43100F91900FD0A00FE0400FE0500FC0E00
F91B00F52D00F04000EA5500E46900DE7D00D98E00D39E00CEAB00CAB700C7BF00C2C400
B9C200B5C100B5C100B8C200C0C400C6C000CAB700CEAB00D49D00DA8B00E07800E66500
EB5100F03F00F43000F62700F33300ED4800E46800D89000
00544C00663C007A20088D003DA00071AF00A7BD00CAB700D59A00DE7E00E56800EA5600
EE4800F13C00F33300F52D00F52A00F52900F52A00F52C00F43100F23700F04000ED4B00
E95900E46900DF7C00D89100D0A700C7BF00A3BD0077B1004BA400219700008803007922
006939005A4800474B002C3D001931000D2700061F00031A00021900031B00082200122B
00243900444A005D4500732B008A0040A1008FB700CCB100DE7C00ED4900F82100FD0A00
FE0800F91B00EF4200E17500CEAB0095B90042A20000890000712E005A48003B45001D34
000C2700051E00021900031A00061F000E29001F36003C46005849006C350081121E9500
5CA900A1BC00CDB000DB8700E75E00F13B00F82000FC0E00FE0500FE0500FC0E00F91C00
F43000EE4600E75E00E17500D98C00D2A100CCB300C5C200B0C0009BBA008AB6007DB300
74B0006EAF006CAE006EAF0074B0007DB3008BB6009DBB00B4C100C7BE00CEAC00D59900
DC8300E36C00EA5600EF4200F03F00EE4500EA5500E27100
00693A007C1B10900047A30087B500C0C300D0A800DA8900E46C00EB5000F03E00F43000
F72500F91C00FA1600FB1200FC1000FC1000FB1100FB1300FA1700F91C00F72300F52D00
F13900ED4800E95A00E26F00DB8700D3A000C9BA00A6BD0076B10046A3001A940000840B
00742900643F00544C003A4500213700122C00082200041C00021900031A00061F000E28
001E35003A45005849006E33008509339D0081B400C9B900DC8300EC4F00F72400FD0B00
FE0700F91A00EF4100E17500CEAC0093B8003FA100008803006F31005849003743001A32
000B2500041D00021900031B00072100112B00253A00464B005E4500732B008802359D00
78B100C1C400D49C00E27100ED4A00F52A00FB1300FE0700FE0500FD0C00F91B00F43000
ED4800E66300DE7D00D69600CEAE00C6C200A8BE008BB70073B0005EAA004EA50041A100
379E00319C002E9B002F9B00329C00399F0043A20052A60065AC007DB3009ABA00BAC200
CAB600D39F00DB8600E36C00E85E00EA5600E95700E66400
007D191491004DA5008EB700C8BC00D49C00DE7D00E75F00EE4500F42E00F82000FA1700
FC1000FD0B00FE0600FE0400FE0400FE0400FE0400FE0500FE0700FD0A00FC0F00FA1600
F82000F52C00F13D00EB5000E56700DD8100D39D00C9BA00A2BC006EAF003CA0000F9000
007F16006E33005D46004B4D002C3E001831000C2600051E00021A00021900041D000B25
00183100324100544C00693900811327990074B000C6C000DA8A00EA5400F62700FD0C00
FE0700F91A00F04000E17400CEAD0091B8003CA000008606006D3300564B003341001830
000A2400041C00021900031B00092300152E002C3E00504E00643F007A200F90004CA500
94B900CBB500DB8800E85E00F23800F91C00FD0B00FE0500FD0900FA1700F52D00EE4700
E66300DD8000D49C00CAB600B6C10091B80071AF0055A7003DA0002A9A001B94000F9000
068C00008A00008802008803008901028B00098E00149200239700369E004DA50069AD00
8AB600B0C000CAB800D49D00DB8800E07700E46B00E46900
1391004CA5008EB700C8BC00D79400E17500E95900F04000F52B00F91A00FB1100FC0D00
FD0A00FD0800FE0600FE0500FE0500FE0500FF0400FF0300FF0200FF0300FE0500FD0800
FC0E00FA1800F72500F23600ED4B00E66400DD8100D39F00C7BE0097BA0060AB002C9A00
00890000782300663D00554B00394500203600102A00072100031B00021900031C000822
00142D002A3D004F4E00653E007C1B1C950068AD00C1C400D89000E95900F52B00FC0E00
FE0700FA1900F03F00E17400CEAD008EB700399F00008509006C3600544C00304000152F
00082200031B00021900041C000B2500193100344200554B006A3800801321970065AC00
B1C000D2A300E17500ED4B00F62900FB1100FE0600FE0700FB1200F62700EF4100E75F00
DE7F00D49D00C9B900ABBF0082B4005EAA0040A100269800119000008A0000840C007F16
007B1E007823007626007527007627007724007A20007D1900820F0088020F9000259800
40A10061AB0089B600B7C100CAB600D2A000D98D00DE7F00
47A30088B600C6C000D59A00E27200E95700EF4100F42F00F82100FA1500FB1300FB1300
FB1300FB1300FB1300FB1300FB1200FB1100FC0F00FD0C00FD0800FE0600FF0400FF0300
FE0500FD0A00FB1300F82000F33300ED4A00E56500DC8400D1A500C1C40086B5004DA500
199400008111006F31005D4600484C00293C00152E000A2400041C00021900031A000720
00102A00243900474B0060430078231291005CA900B5C100D69600E75E00F42E00FC0F00
FE0700FA1800F03F00E17400CEAE008CB700369E0000840C006A3800524D002C3E00132D
00072100031A00021900051E000D27001E35003C46005A48007030008705359D007DB300
C6C000D89100E66400F13B00F91D00FD0A00FE0500FC0D00F81F00F23900E95800DF7900
D59A00C9B900A8BE007BB20054A700329C00169200008900008112007A1F00742A006E32
006A3800673C00653E00643F00643F00653E00673C006A38006E3200742A007B1E00830F
058C001F960040A10068AD008FB800B9C200CBB400D39F00
7DB300BFC300D2A200DE7D00E95A00EE4700F23800F42D00F62600F82000F72200F62600
F62900F52A00F52B00F52A00F52900F62700F72300F81D00FA1700FB1100FD0B00FE0700
FE0400FE0400FD0800FB1100F81F00F33300EC4C00E46B00D98C00CDAF00ACBF006EAF00
359D00038B0000782300653E00534C003442001B33000D2700051E00021A00021A00051E
000D27001F35003E47005C4600742A088D0051A600AABE00D49C00E66300F33100FC1000
FE0700FA1700F03E00E17400CDAE008AB600339D0000820F00693A00514D00293C00122C
00072000031A00021A00061F000F2900223800454A005F44007627088D0049A40096B900
CDB000DD8000EB5300F52D00FB1300FE0600FE0800FA1600F42E00EC4D00E27000D79300
CBB400ACBF007BB20050A6002B9A000D8F0000840B007B1E00732C006B3700653E005F44
005B4700584A00554B00544C00544C00544C00564B005849005C4600614200673B006E32
007725008112058C0025980048A30070AF009ABA00C5C400
AEBF00CEAE00DA8B00E46B00EC4F00EF4400F03D00F13900F23800F23700F13C00EF4200
EE4700ED4900ED4A00ED4900EE4800EF4400F03E00F23600F42D00F72400F91A00FB1100
FD0A00FE0500FE0400FE0800FB1100F82100F23700EB5300E17400D59800C8BD0091B800
52A7001B9400008112006D34005A4800404800223800102A00072000031B00021900041D
000B25001A3200374300584900703000890046A3009FBC00D2A200E56800F33500FB1200
FE0700FA1600F03D00E17300CDAF0088B600309C0000811200673C004F4E00273A00102A
00061F00021A00031A00072000112B00283B004E4E00643F007B1D1893005EAA00AFBF00
D2A100E27000EF4400F72100FD0C00FE0600FC0E00F72200F03F00E66200DB8700CFAB00
B7C10082B40052A7002A9A00098D00008211007725006D3400653E005D4500574A00524D
004C4D00444A003F47003C46003A45003B45003D4700424900484C00504E00554B005C47
006340006D3500772400830D0D8F002F9B0057A80082B400
C8BB00D49B00DE7E00E56500EB5100EC4E00EC4E00EB5000EA5300EA5600E75E00E56500
E46A00E36D00E36D00E36C00E46A00E66400E85D00EA5400ED4800F13C00F42F00F72200
FA1700FC0D00FE0600FE0400FD0800FB1300F72500F03E00E85D00DD8100D0A800B4C100
71AF00339D00008900007528006142004E4E002B3D00152E00092300041C00021900031B
00092300162F00314000554B006C350086073DA00095B900D0A800E36D00F23800FB1300
FE0700FA1600F13C00E17300CDAF0086B5002E9B0000801400663D004D4E002439000F29
00051E00021900031B00082100142E002D3E00524D00693900811228990073B000C5C300
D79200E76100F23600FA1800FE0800FE0800FA1600F43000EB5200E07800D39E00C6C200
8FB7005BA9002E9B000A8E00008112007528006A3800614200584900514D00464B003B45
003241002C3E00283B00253A00243900243900253900283B002C3D003241003B4500474B
00524D005A4800643F006F31007B1E0087041C950044A200
CEAC00D89100DF7C00E46B00E75F00E66200E56800E36F00E17500DF7A00DC8300DA8B00
D89000D79200D79200D89000D98D00DB8600DE7E00E17300E56600E95800ED4800F23800
F62800F91A00FC0E00FE0700FE0500FD0A00FA1700F52C00ED4900E36C00D79300C9BB00
90B8004EA500139100007D1A00683A00544C003442001A32000B2600041D00021900031A
00072100132D002B3D00514D00693900830F349D008BB600CEAD00E27100F13B00FA1500
FE0700FA1500F13C00E17300CDB00084B5002B9A00007F1600643F00494C002237000D28
00051D00021900031B00092300173000334200574A006E33008607389E0087B500CAB600
DC8300EB5300F52B00FC1000FE0600FD0C00F82000F04000E56500D98D00CBB400A3BC00
6AAD00389E000F9000008210007528006939005E4400554B004A4D003B4600304000273B
002037001C3300193100162F00152F00152E00152F001730001932001D34002338002A3D
00354300444A00524D005D4600683B0074290081110E8F00
D1A400D89100DC8300DF7A00E17500DE7E00DB8700D89100D59900D3A000D0A800CDAF00
CBB300CBB500CBB500CCB200CDAE00D0A700D39E00D79300DC8500E17500E66300EB5100
F03D00F52B00F91A00FC0E00FE0600FE0600FC0D00F81E00F23700E95800DE7E00D0A800
AFBF0069AD0029990000840B006F31005A48003E47002036000E2800061F00021A00021A
00061F00102A00263A004E4E00663D007F152B9A0082B400CCB200E07600F03E00FA1700
FE0800FB1500F13B00E17300CDB00082B400299900007E1800634000464B002036000C27
00041D00021900041C000A24001A32003A45005B4800722C048B0049A4009CBB00CFA900
E17500EE4600F82100FD0B00FE0700FB1300F52D00EB5000E07900D2A200BEC30080B300
48A4001A9400008509007725006A38005E4500544C00454A00354200293C002036001931
00142E00112B000F29000D27000C26000C26000C26000D27000E2800102A00132D001831
001F3600293C003643004A4C00564A006241006F31007D1A
D1A500D59900D79200D89000D89100D49D00D0A800CCB300C8BB00C5C200BAC200AFBF00
A8BE00A6BD00A8BE00ADBF00B5C100C2C400C8BD00CCB100D2A300D79200DE7F00E46B00
EA5500F03F00F52A00FA1900FD0C00FE0600FE0700FB1300F62800EE4600E46B00D69500
C7BF0084B5003FA100058C00007627006143004A4C00273A00122B00072100031A000219
00051E000E2800213700474B006241007C1B23970079B200CAB700DF7A00EF4100FA1800
FE0800FB1400F13B00E17300CCB10081B400279900007D1A006241004349001E35000B25
00041C00021900041C000C26001E35004048005E4400772510900059A900B0C000D49D00
E46800F13A00FA1900FD0800FD0900F91B00F13A00E66100D98C00CBB5009CBB005FAA00
2B9A00018A00007B1E006C35005F4400544C00444A003241002539001B3300152E00102A
000C27000A24000822000721000720000620000620000720000721000923000A25000D27
00112B001730002036002D3E003E4700524D005E45006B36
CEAC00D0A700D0A600CFA900CDAF00C8BC00BEC300ABBE009BBA008EB70082B40078B100
72B00071AF0073B00079B20082B40090B800A1BC00B6C100C7BE00CEAE00D59A00DC8500
E36D00EA5500F03D00F62700FA1500FD0900FE0600FD0B00F91B00F23600E95900DC8300
CDAF009FBC0056A800169300007C1B00673C00524D002E3F00152F00092300031B000219
00041D000C26001E35004048005F440079211C950071AF00C8BB00DE7E00EF4400F91A00
FE0800FB1400F13A00E17300CCB1007FB300259800007C1C006043004048001C34000A25
00031C00021900051D000D2700213700474B006241007B1D1D95006AAE00C4C400D89000
E85C00F43000FB1200FE0700FC0E00F72500ED4800E17200D39E00C0C3007DB30042A100
11910000801300712F00634000564B00464B00324100233800193200122C000D27000A24
00072100061F00051E00041D00041C00041C00041C00041C00041C00051D00061F000720
000923000D2700122C001A3200263A003643004E4E005B47
C9B900C9B900C7BD00C5C400B7C1009EBB0088B60075B00066AC005AA9004FA60047A300
43A20042A20045A3004BA50055A70062AB0073B00089B600A2BC00C0C300CBB400D39E00
DB8600E36C00EB5100F23800F72100FC1000FE0700FE0700FB1200F62900ED4900E27200
D39E00BAC2006EAE0029990000830E006C3500574A003643001A32000A2500041C000219
00041C000A24001A32003B45005C4600772515920069AD00C7BF00DD8200EE4700F91B00
FD0800FB1300F13900E17200CCB1007DB300239700007B1E005F44003E47001A32000A24
00031B00021900051E000F29002539004E4E00663D0080152999007BB200C9BA00DC8400
EB5100F62700FC0E00FE0700FB1400F43000E95700DC8300CDB000A1BC0060AB00289900
00880400772500683B005A48004C4D00354200243900193100112B000C2600082200061F
00051D00041C00031B00031A00021A00021A00021A00021A00021A00031A00031B00041C
00051E000720000A24000E2900162F002137003241004A4C
BCC300B4C100A6BD0095B90084B5006BAE0056A80045A200379E002D9B002497001D9500
1A94001B94001E95002498002D9B003A9F004AA4005FAA0078B10096B900B8C200CAB600
D39D00DC8300E56600ED4A00F43000F91A00FD0B00FE0600FD0C00F81E00F13B00E66200
D98E00C8BC0085B5003CA00000890000722D005C47003E47001E35000D2700051D000219
00031B000923001730003643005A4800742A0E8F0061AB00C5C300DB8600ED4A00F91D00
FD0900FB1300F13900E17200CCB2007CB200219600007A20005E45003B46001931000923
00031B00021900061F00112B00293C00514D006A3900840C369E008BB600CDB000DF7900
EE4600F81F00FD0A00FD0900F91B00F13B00E56600D79400C7BF0085B50045A300119100
007F16006E32005F4400514D003A4500273B001A3200112B000B2600082100051E00041C
00031B00021A00021900021900021900021900021900021900021900021900021900021A
00031A00041C00051E000822000C2600132D001E35002F3F
9BBA008CB7007BB20068AD0055A8003EA0002B9A001C9500109000088D00008A00008803
008705008705008901038B000C8E001893002799003B9F0053A7006FAF0091B800B8C200
CBB400D59900DF7B00E85D00F03F00F62600FB1200FE0700FE0800FA1500F42E00EB5300
DE7F00CEAE009CBB004FA6000D8F0000782400614200474B002338000F2900061F00021A
00031A00082100152E00314000574A00712E098D005AA900BFC300DA8A00EC4D00F81E00
FD0900FB1200F23800E27200CCB2007AB2001F9600007922005D46003944001830000822
00031A00021A00062000122C002D3E00544C006D3400870442A2009ABA00D0A600E36F00
F03D00F91900FD0800FD0C00F72300EE4700E17400D1A300B2C0006BAE002E9B00008901
00772500663D00574A00444A002D3E001D3400132C000C2600082100051E00031C00031A
00021900021900021900021900021A00031A00031A00031A00031A00021A000219000219
00021900021A00031B00041D000720000B2500122C001D35
78B10066AC0052A7003EA0002C9A00189300078D0000870500830E007F15007D1A007B1E
007A1F007B1E007C1B007F1600830E008804098D001B9400329C004DA5006DAE0093B900
BFC300CEAD00D89000E27000EB5000F33300F91B00FD0B00FE0700FC0F00F72400EE4600
E27100D3A000B2C00062AB001B9400007D1A00653E004F4E00293C00122B00072000021A
00021A00072000132C002D3E00554B006F31038B0054A700B9C200D98D00EC4F00F82000
FD0900FB1200F23800E27200CCB30079B2001D9500007823005C4600374300162F000821
00031A00021A00072100142E00314000574A00702F048B004EA500AABE00D49D00E56500
F33500FB1400FE0800FC1000F52B00EA5300DD8200CCB10099BA0053A7001A9400008112
006F31005F4400504E00364300223800162F000D2800082200051E00031B00021A000219
00021900021A00031A00031B00041C00041C00041D00041D00041D00041C00031B00031A
00021A00021900021900031A00041C00061F000A2500122C
56A80042A1002D9B001A94000A8E00008607008015007A1F00762600732B00702F006F32
006E32006F3100712E00742A007823007D1A00830E018A001592002F9B004DA50072B000
9DBB00C6C000D2A300DC8300E76100EF4100F72500FB1100FE0700FD0A00F91B00F13A00
E66300D79300C5C30075B0002A9A00008210006A3800534C002E3F00142E00082100031A
00021A00061F00112B002A3C00534D006D350089014EA500B2C000D89000EB5200F82100
FD0A00FB1200F23800E27200CCB30078B1001C9400007724005B4700354200152F000721
00021A00031A00082100162F003542005A4800742A0C8F005BA900B8C200D79300E85C00
F42D00FC1000FE0800FA1500F33400E75F00D89000C7BF0082B4003EA000088D00007A20
00683B00584A004349002A3D001A3200102A00092400061F00041C00021A000219000219
00031A00031B00041C00051E00061F00062000072000072000072000062000051F00051D
00041C00031B00021A00021900021A00041C00061F000B25
369E002197000E8F00008803008111007A2000732A006E32006A3800673B00653E00643F
00634000643F00663C006939006D3300732C007921008014008901159200319C0054A700
7DB300ADBF00CBB500D79400E27200EB4F00F43000FA1800FD0900FE0800FB1500F43000
E95700DB8600CAB70087B500399F00008706006E3200574A00344200173000092300031B
00021900051E000F2900263A00504D006A3700870648A300ACBF00D79300EA5400F72200
FD0A00FB1100F23700E27200CBB30076B1001A9400007626005A4800334200142E000720
00021A00031A000822001831003944005C4600772515920066AC00C5C300DA8B00EA5300
F62700FC0D00FD0900F91B00F03D00E46B00D49D00B8C2006CAE002B9A0000860700732B
00614200514D00364300213700142E000C2600072000041C00031A00021900021900031A
00031C00051D00061F000721000923000A24000A25000B25000B25000A24000923000721
00061F00051D00031B00031A00021900021A00041C000620
199400058C0000840C007C1B007627006E3200683A006340005F44005D46005B48005948
005948005B48005D4600604300643F006939006F31007725007F150089001994003A9F00
61AB008FB800C4C400D1A500DD8200E75E00F13C00F82000FC0D00FE0700FC0F00F62700
EC4C00DF7A00CEAC0099BA0048A300048B0000732C005B47003A45001A32000A2400041C
00021900051D000E28002439004E4E00683A00850A42A200A7BD00D69600EA5600F72400
FD0A00FB1100F23700E27200CBB40075B10019930000762700594800324100132D000620
00021A00031B000923001A32003D47005F44007A201D950072B000C8BC00DD8200ED4B00
F72100FD0B00FD0B00F82100EE4700E07700CFA900A3BD0058A8001A9400008014006D35
005B4700474B002C3E001A32000F2900092300051E00031B00021900021900031A00041C
00051E000720000923000B25000D27000E2900102A00102A00102A000F29000E28000C26
000A2400072100051E00041C00031A00021900031A00041C
008A0000811100792100722D006B3700643F005E4500594900554B00534C00514D00504E
00504D00524D00544C00574A005B4700604300673C006E32007725008113048B00239700
48A30075B000A8BE00CBB500D89200E36D00ED4800F62900FB1200FE0800FD0C00F81F00
EF4200E26F00D2A200AABE0056A8000F9000007725005E44004048001E35000C2600041C
00021900041C000C27002137004A4D00673C00830E3DA000A2BC00D59900E95900F72500
FD0B00FB1100F23600E27200CBB40074B00017930000752800594900304000132C00061F
00021900031B000A24001C34004148006142007C1B2598007DB300CBB500DF7A00EF4400
F91C00FD0900FC0D00F62700EB5000DD8200CBB40090B80047A3000B8E00007A2000673C
00554B003C4600243900152E000C2600062000041C00021A00021900021A00031B00051E
000721000A24000D27000F2A00122C00152E00162F00173000173000162F00142E00122C
000F29000C2600092300061F00041C00031A00021A00031A
008014007724006F3100683B006142005A4800544C00504E004B4D00464A004249004148
00414800444A00494C004F4E00534C005949005F4400663C006F3100792100840C0F9000
329C005DAA008FB700C5C300D3A000DF7A00EA5500F33200FA1800FD0900FD0900F91900
F13900E56500D69800BAC20064AC00199400007B1E00624100464B002137000D2700041D
00021900041C000B25001F3500474B00653E008111399F009DBB00D49C00E85B00F62600
FD0B00FB1100F23600E27200CBB40073B00016920000742900584A002F3F00122C00061F
00021900031B000B25001E3500454A006440007F162D9B0087B500CDAE00E17300F03E00
FA1800FD0800FC1000F42D00E95900D98C00C7BE007EB300379E00008901007429006142
00504E003341001E3500112B00092300051E00031B00021900021900031B00051D000720
000A24000D2800112B00152E001931001C34001F35002036002036001F36001D34001932
00162F00112B000D2700092300062000041C00031A00021A
007724006E3200663D005E4500584A00514D00494C004048003A45003643003341003241
003341003643003A45004148004A4C00514D00584A005F4400683B00722D007D1B008901
1E960047A30078B100B0C000CEAD00DB8800E76100F13C00F81E00FD0C00FE0800FB1400
F33100E85C00D98E00C6C10072B000249700007E1800653E004D4E002439000F2900051E
00021900031B000A24001D34004349006340008014359D0098BA00D39E00E85D00F62700
FD0B00FC1100F23600E27200CBB40072B00015920000742A00574A002D3E00112B00051E
00021900041C000B2600203600494C00663D008111359D0091B800D0A800E36C00F23800
FA1500FD0800FB1400F33400E66200D69600BFC3006EAF0028990000840C006F31005C46
00484B002B3D001831000D2700072100041C00021A00021900031A00041C000620000923
000D2700122C001730001C3400213700253900283B002A3C002B3D00293C00273B002338
001E3500183100132D000E2800092300061F00041C00031A
006F3200663D005D4500564B00504E00444A003945003241002D3E002A3C00283B00273B
00283B002A3D002E3F003442003C4600474B00514D005949006142006B37007626008210
0E8F00349D0063AC009BBA00C9BA00D79400E36C00EE4600F62500FC0F00FE0800FC1100
F52B00EA5300DC8500C9B9007EB3002E9B0000811100683A00504E00283B00102A00061F
00021900031B000924001B33004048006242007E17319C0094B900D2A000E75E00F62800
FD0C00FC1000F23600E27100CBB50071AF0014910000732B00574A002C3E00102A00051E
00021900041C000C26002237004D4E00683B00840C3CA0009BBA00D2A200E56600F33300
FB1200FD0900FA1700F13A00E46A00D39F00AFBF005FAA001C9500007F16006B3700584A
003F4700243900142E000B2500061F00031B00021900021900031B00051E000822000C26
00112B001730001D35002439002A3C002F3F003341003643003743003543003341002E3F
00283B002137001A3200142D000E2800092300061F00041C
00673C005E4500564B004F4E004148003643002D3E00273B002338002036001F35001E35
001F36002137002539002A3C003140003B4500484B00534C005B4700653E007030007C1C
00890024970051A60087B500C4C400D39F00E07700EC4F00F52C00FB1300FE0800FC0E00
F72500ED4B00DE7D00CCB2008BB600379E0000850A006B3700534D002B3D00122B00061F
00021A00031B000923001932003D47006043007D1A2D9B0090B800D2A300E76000F62900
FD0C00FC1000F23500E27100CBB50070AF0013910000732C00564B002B3D00102A00051E
00021900041C000D27002439004F4E006A3900860843A200A3BD00D49C00E76100F42F00
FC1000FD0900F91B00F04000E27200D0A700A1BC0051A600119000007B1E00663D00544C
003743001F3600112B00092300041D00031A00021900031A00041D000720000A2500102A
00162F001D34002539002C3E003442003A45003F4700424900444A004349004048003A45
003342002B3D002338001B3300132D000D2700082200051E
00604300574A004F4E004048003442002B3D002439001F35001B33001932001831001831
001931001B33001E3500223800283C003140003D46004C4D00564B005F44006A38007626
00840C15920041A10075B100B2C000CFAA00DD8100E95800F33300FA1700FD0900FD0B00
F82000EE4500E17500CFAB0096B90041A100008704006E3300554B002E3F00132D000720
00021A00031A000822001831003B45005F44007C1C2A9A008CB700D1A400E66200F52A00
FD0C00FC1000F23500E27100CBB5006FAF0012910000722D00554B002A3D000F2900051D
00021900041D000E2800253A00514D006B360088034AA400ACBF00D69700E85B00F52B00
FC0E00FD0A00F81F00EE4600DF7900CDAF0094B90045A300078C0000772500624100504E
003040001B33000E2800072100041C00021900021900031B00051E000822000D2700132D
001B33002338002D3E003643003E4700464B004C4D004F4E00504E004F4E004E4E00484B
004048003743002D3E00233800193200112B000B25000720
00594800514D004249003542002A3D002238001C3400183100152F00142D00132D00132D
00142D00152F001831001C3400223700293C00344200424900514D005A4800653E00712E
007F16098D00329D0066AC00A2BC00CBB300DA8A00E76100F13A00F91C00FD0A00FD0A00
F91C00F03F00E36F00D1A400A0BC0049A400018A0000703000574A00314100152E000721
00031A00031A000821001730003944005E45007A1F27990089B600D0A600E66300F52B00
FC0C00FC1000F33500E27100CBB5006FAF0011900000722D00554B00293C000F2900051D
00021900041D000E2900273B00524D006D34008A0050A600B3C000D79200E95700F62700
FC0D00FD0B00F72200EC4C00DD8000CBB60088B6003B9F0000890100732B005F44004A4D
002B3D001730000C2600061F00031B00021900021A00041C000620000A2400102A001730
002036002A3D003542003F4800494C00504E00534C00554B00564B00554B00544C00514D
004D4E004349003744002C3D002036001730000F29000923
00544C00484B003844002C3D002338001C3300173000132D00112B00102A000F29000F29
00102A00112B00142D001730001C34002338002C3E003945004B4D00564B006142006D34
007A1F00890126980058A80093B800C8BB00D79300E46800F04000F82000FD0C00FD0900
FA1800F13A00E46800D39E00AABE0051A600078D0000722C00594900344200162F000821
00031A00021A00072100162F003743005D4600792024980086B500D0A800E66400F52C00
FC0D00FC1000F33500E27100CBB5006EAF0010900000712E00544C00293C000E2900041D
00021900051D000F2900293C00534C006E32048B0056A800BAC200D98E00EB5300F72400
FD0C00FC0D00F62600EB5100DB8600C8BC007DB300329C00008608007030005C4700444A
00263A00142E000A2400051E00031A00021900031A00041D000821000C2700132D001C33
00263A003140003D4700494C00514D00554B005849005A48005B47005B47005A4800574A
00534C004F4E00434900354300283B001C3400132D000C26
004F4E003D47002F3F002439001D3400173000132C00102A000E28000D27000C27000C27
000D27000E2900102B00142D001831001E3500273A00324100424900524D005D46006939
00762600850A1B94004CA50086B500C5C300D49B00E27000EE4600F72400FC0E00FD0800
FA1600F23500E66300D59900B3C00059A8000C8F00007429005B48003744001730000822
00031A00021A00072000152E003542005C4700782222970083B400CFA900E56600F52C00
FC0D00FC1000F33400E27100CBB6006EAE000F900000712E00544C00283B000E2800041D
00021900051E00102A002A3C00544C007030078D005BA900C0C300DA8A00EC4F00F72200
FD0B00FC0E00F62900EA5600D98C00C6C10074B00029990000830E006D34005949003E47
00233800122C00092300041D00021A00021900031B00051E000923000F2900162F002036
002B3D00384400464A00504E00554B005A48005D46005F44006043006043005F44005C46
00594900544C004E4E003F48003040002338001830000F29
00464B00354200283B001F3500183100132D000F29000D27000B26000B25000A24000A24
000B25000C26000E2800112B00152E001A32002238002D3E003C46004F4E00594800653E
00732C00811112910041A1007AB200BCC200D2A100E07600EC4C00F62800FC1000FD0800
FB1300F33100E75E00D79400BBC2005FAA00119100007626005C46003A45001931000923
00031B00021A00072000142E003342005B4700782420960081B400CFAA00E56700F52D00
FC0D00FC1000F33400E27100CAB6006DAE000F900000712F00544C00273B000E2800041D
00021900051E00102A002B3D00554B00712E0B8E005FAA00C5C400DB8700EC4C00F81F00
FD0A00FC0F00F52C00E85B00D89100C2C4006BAE00229700008014006A3800564B003A45
00203600102A00082200041C00021900021900031B00061F000A2400112B001932002439
003140003F47004E4E00544C005948005E4500614200634000653E00653E00643F006142
005D4500594900534C00494C00384400293C001C3400122C
003E47002F3F002338001B3200142E00102A000D27000B25000A24000923000923000923
000923000A24000C26000E2900122C001730001E3500283B00364300494C00564A006241
007030007E170B8E00389E0070AF00B2C000D0A700DF7C00EB5100F52C00FB1200FD0800
FB1200F42E00E95A00D89000C1C40065AC00169200007823005E45003C46001A32000923
00031B00021900062000132D003241005A480077251E95007FB300CEAC00E56800F42E00
FC0D00FC1000F33400E27100CAB6006DAE000E8F0000702F00534C00273B000E2800041C
00021900051E00112B002D3E00564B00722D0D8F0064AC00C6C100DC8400ED4900F81E00
FD0A00FC1000F42F00E75E00D69500BAC20064AC001C9500007E1800683A00544C003643
001D34000F2900072100031C00021900021A00041C000720000C2600132D001C3400283B
00364300454A00514D00584A005D4600614200653E00673B00693A00693900683B00653E
006242005D4600574A00504E004048002F3F00213700162F
003844002A3C001F3600173000122C000E28000B25000923000822000821000721000821
000822000923000A25000D2700102A00152E001B3300253900324100444A00544C006043
006D34007C1C048B00319C0068AD00A9BE00CEAC00DD8100EA5500F42F00FB1400FD0800
FC1000F52B00E95700D98C00C5C3006AAE001A9400007921005F44003E47001B33000A24
00031B00021900061F00132C0031400059480076261C95007DB300CEAD00E46800F42E00
FC0D00FC0F00F33400E27100CAB6006CAE000E8F0000703000534C00263A000D2800041C
00021900051E00112B002E3E00574A00732B10900067AD00C7BF00DD8100EE4700F91C00
FD0900FB1200F33100E66200D59900B4C1005EAA00179300007C1C00663D00524D003341
001B33000E2800062000031B00021900021A00041D000821000D2700152E001F36002C3E
003B45004B4D00544C005A4800604300653E00683A006B37006C35006C35006B36006939
00653E006043005B4800544C00484B00354300263A001931
00334200263A001C3300152E00102A000C26000A24000822000721000720000720000720
000721000822000923000B26000E2900132C001931002237002E3F003F4800524D005E45
006B370079200089002B9A0061AB00A2BC00CDB000DC8500E95900F33200FA1500FD0900
FC0F00F62900EA5400DA8900C6C0006EAF001D9500007A1F006043004048001C33000A24
00031B00021900061F00122C0030400059490076271B94007CB200CEAD00E46900F42E00
FC0D00FC0F00F33400E27100CAB6006CAE000D8F0000703000534C00263A000D2700041C
00021900051E00112B002E3F00584A00742A1291006AAD00C8BD00DE7F00EE4500F91B00
FD0900FB1300F33300E66500D49C00AFBF0059A900139100007A1F00653E00514D003040
001932000D2700061F00031B00021900031A00051D000822000E28001730002237002F3F
003F48004F4E00564A005D4600634000673B006B37006E33006F31007030006F32006C35
00683A006440005E4500574A004E4E003B45002A3C001C34
003040002338001A3200132D000E28000B2500092300072100072000061F00061F00061F
000620000721000922000A25000D2800112B001730002036002C3D003C4600504E005C47
0069390078230088042698005CA9009CBB00CBB400DB8800E85C00F33400FA1700FD0900
FC0E00F62700EB5200DB8700C7BE0072B0001F9600007B1D006142004148001C34000A24
00031B00021900061F00122C002F3F0058490075271A94007BB200CDAE00E46A00F42F00
FC0E00FC0F00F33400E27100CAB6006CAE000D8F0000703000534D00263A000D2700041C
00021900051F00122C002F3F0058490074291492006CAE00C8BB00DE7D00EF4300F91A00
FD0900FB1300F23500E56700D39F00AABE0055A80010900000792100634000504E002E3F
001831000C2600061F00031A00021900031A00051E000923000F29001831002439003241
00434900514D005849005F4400653E006A38006D3400703000722D00722D00712E006F32
006B3700663D00604300594900514D003F48002D3E001F35
002D3E00213700183100122C000D28000A2400082200072000061F00061F00061F00061F
00061F000720000822000A24000C2700102A00162F001E35002A3C003A45004F4E005B48
00683B00762600860723970058A80098BA00CAB600DA8B00E75E00F23600FA1800FD0900
FC0E00F62600EB5000DC8500C8BC0074B000219700007C1C006142004249001D34000A25
00031B00021900061F00122C002F3F0058490075281994007AB200CDAE00E46A00F42F00
FC0E00FC0F00F33400E27100CAB6006BAE000D8F0000703000524D00253A000D2700041C
00021900061F00122C0030400058490075291592006EAF00C9BA00DF7C00EF4200F91900
FD0900FB1400F23600E46900D2A000A7BD0052A7000E8F00007823006241004F4E002D3E
001730000B2600051E00031A00021900031A00051E00092300102A00193200263A003442
00464A00524D005A4800614300663C006B36006F3100722D00732B00742A00732B00702F
006D3400683B006241005B4700524D004349003040002137
002B3D001F3600173000112B000D27000A2400082200072000061F00051E00051E00051E
00061F000620000821000923000C2600102A00152F001D3400283C003844004E4E005A48
00673C00762700850820960055A80095B900CAB800D98C00E75F00F23700FA1800FD0900
FC0D00F62500EC4F00DC8400C8BB0076B100239700007C1B006241004349001D34000B25
00031B00021900061F00122B002E3F00584900752819930079B200CDAF00E46A00F42F00
FC0E00FC0F00F33400E27100CAB6006BAE000D8F0000703000524D00253A000D2700041C
00021900061F00122C0030400059490075281692006FAF00C9B900DF7B00EF4100FA1900
FD0900FB1500F23700E46A00D2A200A5BD0050A6000C8F00007724006241004E4E002C3D
001730000B2500051E00031A00021900031B00051E000A2400102A001A3200273A003643
00474B00534C005B4700624200673B006C3500702F00732B00752900752800742900722D
006E33006939006340005C4600544C00454A003241002238
002B3D001F3500162F00102A000C2700092400082100062000061F00051E00051E00051E
00061F000620000721000923000C26000F2A00152E001D3400283B003844004D4E005948
00673C0075280085091F960054A70093B900C9B800D98D00E76000F23700FA1900FD0900
FC0D00F72500EC4E00DC8300C8BB0077B100239700007C1B006241004349001E35000B25
00031B00021900051F00112B002E3F00584A00752819930079B200CDAF00E46A00F42F00
FC0E00FC0F00F33400E27100CAB6006BAE000D8F00006F3100524D00253A000D2700041C
00021900061F00122C00304000594900752816920070AF00C9B900DF7B00EF4100FA1900
FD0900FA1500F23800E46A00D2A200A4BD004FA6000B8E00007724006142004D4E002B3D
00162F000B2500051E00031A00021900031B00051E000A2400112B001B3200273B003743
00484C00544C005B4700624100683A006D3400712F00742A00752800762700752800722C
006F32006A3800643F005D4600544C00474B003342002338
002B3D001F3500162F00102A000C2700092400082100062000061F00051E00051E00051E
00061F000620000721000923000C26000F2A00152E001D3400283B003844004D4E005948
00673C0075280085091F960054A70093B900C9B800D98D00E76000F23700FA1900FD0900
FC0D00F72500EC4E00DC8300C8BB0077B100239700007C1B006241004349001E35000B25
00031B00021900051F00112B002E3F00584A00752819930079B200CDAF00E46A00F42F00
FC0E00FC0F00F33400E27100CAB6006BAE000D8F00006F3100524D00253A000D2700041C
00021900061F00122C00304000594900752816920070AF00C9B900DF7B00EF4100FA1900
FD0900FA1500F23800E46A00D2A200A4BD004FA6000B8E00007724006142004D4E002B3D
00162F000B2500051E00031A00021900031B00051E000A2400112B001B3200273B003743
00484C00544C005B4700624100683A006D3400712F00742A00752800762700752800722C
006F32006A3800643F005D4600544C00474B003342002338
002B3D001F3600173000112B000D27000A2400082200072000061F00051E00051E00051E
00061F000620000821000923000C2600102A00152F001D3400283C003844004E4E005A48
00673C00762700850820960055A80095B900CAB800D98C00E75F00F23700FA1800FD0900
FC0D00F62500EC4F00DC8400C8BB0076B100239700007C1B006241004349001D34000B25
00031B00021900061F00122B002E3F00584900752819930079B200CDAF00E46A00F42F00
FC0E00FC0F00F33400E27100CAB6006BAE000D8F0000703000524D00253A000D2700041C
00021900061F00122C0030400059490075281692006FAF00C9B900DF7B00EF4100FA1900
FD0900FB1500F23700E46A00D2A200A5BD0050A6000C8E00007724006241004E4E002C3D
001730000B2500051E00031A00021900031B00051E000A2400102A001A3200273A003643
00474B00534C005B4700624200673B006C3500702F00732B00752900752800742900722D
006E33006939006340005C4600544C00454A003241002238
002D3E00213700183100122C000D28000A2400082200072000061F00061F00061F00061F
00061F000720000822000A24000C2700102A00162F001E35002A3C003A45004F4E005B48
00683B00762600860723970058A80097BA00CAB600DA8B00E75E00F23600FA1800FD0900
FC0E00F62600EB5000DC8500C8BC0074B000219700007C1C006142004249001D34000A25
00031B00021900061F00122C002F3F0058490075281994007AB200CDAE00E46A00F42F00
FC0E00FC0F00F33400E27100CAB6006BAE000D8F0000703000524D00253A000D2700041C
00021900061F00122C0030400058490075291592006EAF00C9BA00DF7C00EF4200F91900
FD0900FB1400F23700E46900D2A000A7BD0052A7000E8F00007823006241004F4E002D3E
001730000B2600051E00031A00021900031A00051E00092300102A00193200263A003442
00464A00524D005A4800614300663C006B36006F3100722D00732B00742A00732B00702F
006D3400683B006241005B4700524D004349003040002137
003040002338001A3200132D000E28000B2500092300072100072000061F00061F00061F
000620000721000922000A25000D2800112B001730002036002C3D003C4600504E005C47
0069390078230088042698005CA9009CBB00CBB400DB8800E85C00F33400FA1700FD0900
FC0E00F62700EB5200DB8700C7BE0072B0001F9600007B1D006142004148001C34000A24
00031B00021900061F00122C002F3F0058490075271A94007BB200CDAE00E46A00F42F00
FC0E00FC0F00F33400E27100CAB6006BAE000D8F0000703000534D00263A000D2700041C
00021900051F00122C002F3F0058490074291492006CAE00C8BB00DE7D00EF4300F91A00
FD0900FB1300F23500E56700D39F00AABE0055A70010900000792100634000504E002E3F
001831000C2600061F00031A00021900031A00051E000923000F29001831002439003241
00434900514D005849005F4400653E006A38006D3400703000722D00722D00712E006F32
006B3700663D00604300594900514D003F48002D3E001F35
00334200263A001C3300152E00102A000C26000A24000822000721000720000720000720
000721000822000923000B26000E2900132C001931002237002E3F003F4800524D005E45
006B370079200089002B9A0061AB00A2BC00CDB000DC8500E95900F33200FA1500FD0900
FC0F00F62900EA5400DA8900C6C0006EAF001D9500007A1F006043004048001C33000A24
00031B00021900061F00122C0030400059490076271B94007CB200CEAD00E46900F42F00
FC0E00FC1000F33400E27100CAB6006CAE000D8F0000703000534C00263A000D2700041C
00021900051E00112B002E3F00584A00742A1291006AAD00C8BD00DE7F00EE4500F91B00
FD0900FB1300F33400E66500D49C00AEBF0059A900139100007A1F00653E00514D003040
001932000D2700061F00031B00021900031A00051D000822000E28001730002237002F3F
003F48004F4E00564A005D4600634000673B006B37006E33006F31007030006F32006C35
00683A006440005E4500574A004E4E003B45002A3C001C34
003844002A3C001F3600173000122C000E28000B25000923000822000821000721000821
000822000923000A25000D2700102A00152E001B3300253900324100444A00544C006043
006D34007C1C048B00319C0068AD00A9BE00CEAC00DD8100EA5500F42F00FB1400FD0800
FC1000F52B00E95700D98C00C5C3006AAE00199400007921005F44003E47001B33000A24
00031B00021900061F00132C0031400059480076261C95007DB300CEAD00E46900F42E00
FC0D00FC1000F33400E27100CAB6006CAE000E8F0000703000534C00263A000D2800041C
00021900051E00112B002E3E00574A00732B10900067AD00C7BF00DD8100EE4700F91C00
FD0A00FB1200F33100E66200D59900B4C1005EAA00179300007C1C00663D00524D003341
001B33000E2800062000031B00021900021A00041D000821000D2700152E001F36002C3E
003B45004B4D00544C005A4800604300653E00683A006B37006C35006C35006B36006939
00653E006043005B4800544C00484B00354300263A001931
003E47002F3F002338001B3200142E00102A000D27000B25000A24000923000923000923
000923000A24000C26000E2900122C001730001E3500283B00364300494C00564A006241
007030007E170B8E00389E0070AF00B1C000D0A700DF7C00EB5100F52C00FB1200FD0800
FB1200F42E00E85A00D89000C1C40065AC00169200007824005E45003C46001A32000923
00031B00021900062000132D003241005A480077251E95007FB300CEAC00E56800F42E00
FC0D00FC1000F33400E27100CAB6006CAE000E8F0000702F00534C00273B000E2800041C
00021900051E00112B002D3E00564B00722D0D8F0063AC00C6C100DC8400ED4900F81E00
FD0A00FC1000F42F00E75F00D69500BAC20064AC001C9500007E1800683A00544C003643
001D34000F2900072100031C00021900021A00041C000720000C2600132D001C3400283B
00364300454A00514D00584A005D4600614200653E00673B00693A00693900683B00653E
006242005D4600574A00504E004048002F3F00213700162F
00464B00354200283B001F3500183100132D000F29000D27000B26000B25000A24000A24
000B25000C26000E2800112B00152E001A32002237002D3E003C46004F4E00594800653E
00732C00811112910041A1007AB200BCC200D2A100E07600EC4C00F62800FC1000FD0800
FB1300F33100E75E00D79400BBC2005FAA00119100007626005C46003A45001931000923
00031B00021A00072000142E003342005B4700782420960081B400CFAB00E56700F42D00
FC0D00FC1000F33400E27100CAB6006DAE000F900000712F00544C00273B000E2800041D
00021900051E00102A002B3D00554B00712E0B8E005FAA00C5C400DB8700EC4C00F82000
FD0A00FC0F00F52C00E85B00D89100C2C4006BAE00229700008014006A3800564B003A45
00203600102A00082200041C00021900021900031B00061F000A2400112B001932002439
003140003F47004E4E00544C005948005E4500614200634000653E00653E00643F006142
005D4500594900534C00494C00384400293C001C3400122C
004F4E003D47002F3F002439001D3400173000132C00102A000E28000D27000C27000C27
000D27000E2900102B00142D001831001E3500273A00324100424900524D005D46006939
00762600850A1B94004CA50086B500C5C300D49B00E27000EE4600F72400FC0E00FD0800
FA1600F23500E66300D59900B3C00058A8000C8F00007429005B48003744001730000822
00031A00021A00072000152E003542005C4700782222970083B400CFA900E56600F52D00
FC0D00FC1000F33500E27100CAB6006DAE000F900000712E00544C00283B000E2800041D
00021900051E00102A002A3C00544C007030078D005BA900C0C300DA8A00EC4F00F72200
FD0B00FC0E00F52900EA5600D98C00C6C10074B00029990000830E006D34005949003E47
00233800122C00092300041D00021A00021900031B00051E000923000F2900162F002036
002B3D00384400464A00504E00554B005A48005D46005F44006043006043005F44005C46
00594900544C004E4E003F48003040002338001830000F29
00544C00484B003844002C3D002338001C3300173000132D00112B00102A000F29000F29
00102A00112B00142D001730001C34002338002C3E003945004B4D00564B006142006D34
007A1F00890126980058A80093B800C8BB00D79300E46900F04000F82000FD0C00FD0900
FA1800F13A00E46900D39E00AABE0051A600078D0000722C00594900344200162F000821
00031A00021A00072100162F003743005D4600792024980086B500D0A800E66500F52C00
FC0D00FC1000F33500E27100CBB5006EAF0010900000712E00544C00293C000E2900041D
00021900051D000F2900293C00534C006E32048B0056A800BAC200D98E00EB5300F72400
FD0C00FC0D00F62600EB5100DB8700C8BC007DB300319C00008608007030005C4700444A
00263A00142E000A2400051E00031A00021900031A00041D000821000C2700132D001C33
00263A003140003D4700494C00514D00554B005849005A48005B47005B47005A4800574A
00534C004F4E00434900354300283B001C3400132D000C26
00594800514D004249003542002A3D002238001C3400183100152F00142D00132D00132D
00142D00152F001831001C3400223700293C00344200424900514D005A4800653E00712E
007F16098D00329D0066AC00A1BC00CBB300DA8B00E76100F13A00F91C00FD0A00FD0A00
F91C00F03F00E36F00D1A400A0BC0049A400018A0000703000574A00314100152E000721
00031A00031A000821001730003844005E45007A1F27990089B600D0A600E66300F52B00
FC0D00FC1000F23500E27100CBB5006FAF0011900000722D00554B00293C000F2900051D
00021900041D000E2900273B00524D006D34008A0050A600B3C000D79200E95700F62700
FC0D00FD0B00F72200EC4C00DD8000CBB60088B6003B9F0000890100732B005F44004A4D
002B3D001730000C2600061F00031B00021900021A00041C000620000A2400102A001730
002036002A3D003542003F4800494C00504E00534C00554B00564B00554B00544C00514D
004D4E004349003744002C3D002036001730000F29000923
00604300574A004F4E004048003442002B3D002439001F35001B33001932001831001831
001931001B33001E3500223800283C003140003D46004C4D00564B005F44006A38007626
00840C15920041A10075B100B2C000CFAA00DD8100E95800F33300FA1700FD0900FD0C00
F82000EE4500E17600CFAB0096B90040A100008704006E3300554B002E3F00132D000720
00021A00031A000822001831003B45005F44007C1C2A9A008CB700D1A500E66200F52A00
FD0C00FC1000F23500E27100CBB5006FAF0012910000722D00554B002A3D000F2900051D
00021900041D000E2800253A00514D006B360088034AA400ACBF00D69700E85C00F52B00
FC0E00FD0A00F81F00EE4700DF7A00CDAF0093B90045A300078C0000772500624100504E
003040001B33000E2800072100041C00021900021900031B00051E000822000D2700132D
001B33002338002D3E003643003E4700464B004C4D004F4E00504E004F4E004E4E00484B
004048003743002D3E00233800193200112B000B25000720
00673C005E4500564B004F4E004148003543002D3E00273B002338002036001F35001E35
001F36002137002539002A3C003140003B4500484B00534C005B4700653E007030007C1C
00890024970051A60087B500C4C400D39F00E07700EC4F00F52C00FB1300FD0800FC0E00
F72500ED4C00DE7D00CCB2008AB600379E0000850A006B3700534D002B3D00122B00061F
00021A00031B000923001932003D47006043007D1A2D9B0090B800D2A300E76000F52900
FD0C00FC1000F23500E27200CBB50070AF0013910000732C00564B002B3D00102A00051E
00021900041C000D27002439004F4E006A3900860843A200A3BD00D49C00E76100F42F00
FC1000FD0900F91B00EF4100E17200D0A700A1BC0051A600109000007B1E00663D00544C
003743001F3600112B00092300041D00031A00021900031A00041D000720000A2500102A
00162F001D34002539002C3E003442003A45003F4700424900444A004349004048003A45
003342002B3D002338001B3300132D000D2700082200051E
006F3200663D005D4500564B00504E004449003945003241002D3E002A3C00283B00273B
00283B002A3D002E3F003442003C4600474B00514D005949006142006B37007626008210
0E8F00349D0063AC009ABA00C9BA00D79400E36C00EE4600F62500FC0F00FE0800FB1100
F52B00EA5300DC8500C9BA007EB3002E9B0000811100683A00504E00283B00102A00061F
00021900031B000924001B33004048006242007E17319C0094B900D2A100E75F00F62800
FD0C00FC1100F23600E27200CBB50071AF0014910000732B00564A002C3E00102A00051E
00021900041C000C26002237004D4E00683B00840C3CA0009BBA00D2A200E56600F33300
FB1200FD0900FA1700F13A00E46A00D39F00AFBF005FAA001C9400007F16006B3700584A
003F4700243900142E000B2500061F00031B00021900021900031B00051E000822000C26
00112B001730001D34002439002A3C002F3F003341003643003643003543003341002E3F
00283B002137001A3200142D000E2800092300061F00041C
007724006E3200663D005E4500584A00514D00494C004048003A45003643003341003241
003341003643003A45004148004A4C00514D00584A005F4400683B00722D007D1B008901
1E950047A30078B100B0C000CEAE00DB8800E76100F13C00F81F00FD0C00FD0800FB1500
F33100E85C00D98E00C6C20071B000249700007E1800653E004D4E002439000F2900051E
00021900031B000A24001D34004349006340008015359D0098BA00D39E00E85D00F62700
FD0B00FB1100F23600E27200CBB40072B00015920000742A00574A002D3E00112B00051E
00021900041C000B2600203600494C00663D008111359D0091B800D0A800E36D00F23800
FA1500FD0900FB1400F33400E66200D69600BFC3006DAE0028990000840C006F31005C46
00484B002B3D001831000D2700072100041C00021A00021900031A00041C000620000923
000D2700122C001730001C3400213700253900283B002A3C002B3D00293C00273B002338
001E3500183100132D000E2800092300061F00041C00031A
008014007724006F3100683B006142005A4800544C00504E004B4D00454A004249004148
00414800444A00494C004F4E00534C005949005F4400663C006F3100792100840C0F9000
329C005DAA008FB700C5C300D2A000DF7B00EA5500F33300FA1800FD0A00FD0900F91A00
F13900E56500D59800BAC20064AC00199400007B1E00624100464B002137000D2700041D
00021900041C000B25001F3500474B00653E008111399F009DBB00D49C00E85B00F62600
FD0B00FB1100F23600E27200CBB40073B00016920000742900584A002F3F00122C00061F
00021900031B000B25001E3500454A006440007F162D9B0087B500CDAE00E17300F03E00
FA1800FD0900FB1100F42E00E95900D98C00C7BE007EB300369E00008901007429006142
00504E003341001E3500112B00092300051E00031B00021900021900031B00051D000720
000A24000D2800112B00152E001931001C34001F35002036002036001F36001D34001932
00162F00112B000D2700092300062000041C00031A00021A
008A0000811100792100722D006B3700643F005E4500594900554B00534C00514D00504E
00504D00524D00544C00574A005B4700604300673C006E32007725008113048B00239700
48A30075B000A8BE00CBB500D79200E36D00ED4900F52900FB1200FE0800FD0C00F82000
EF4200E26F00D2A200AABE0056A8000F9000007725005E44004048001E35000C2600041C
00021900041C000C27002137004A4D00663C00830E3DA000A1BC00D59900E95900F72500
FD0B00FB1100F23700E27200CBB40074B00017930000752800594900304000132C00061F
00021900031B000A24001C34004148006142007C1B2598007DB300CBB500DF7B00EE4400
F91D00FD0900FC0E00F62700EB5000DD8200CBB40090B80046A3000B8E00007A2000673C
00554B003C4600243900152E000C2600062000041C00021A00021900021A00031B00051E
000721000A24000D27000F2A00122C00152E00162F00173000173000162F00142E00122C
000F29000C2600092300061F00041C00031A00021A00031A
199400058C0000840C007C1B007627006E3200683A006340005F44005D46005B48005948
005948005B48005D4600604300643F006939006F31007725007F150089001994003A9F00
61AB008FB800C3C400D1A500DD8200E75E00F13C00F82000FC0E00FE0700FC1000F62700
EC4C00DF7A00CEAC0099BA0048A300048B0000732C005B47003A45001A32000A2400041C
00021900051D000E28002439004E4E00683A00850A42A200A7BD00D69700E95700F72400
FD0B00FB1100F23700E27200CBB40075B10018930000762700594800324100132D000620
00021A00031B000923001A32003D46005F44007A201D950072B000C8BC00DC8200ED4C00
F72100FD0B00FD0B00F82100EE4700E07700CFA900A3BC0058A8001A9400008014006D35
005B4700474B002C3E001A32000F2900092300051E00031B00021900021900031A00041C
00051E000720000923000B25000D27000E2900102A00102A00102A000F29000E28000C26
000A2400072100051E00041C00031A00021900031A00041C
369E002196000E8F00008803008111007A2000732A006E32006A3800673B00653E00643F
00634000643F00663C006939006D3300732C007922008014008801159200319C0054A700
7DB300ADBF00CBB500D79500E27200EB5000F43100FA1800FD0A00FD0800FA1500F43000
E95700DB8600CAB80087B500399F00008706006E3200574A00344200173000092300031B
00021900051E000F2900263A00504D006A3700870648A300ACBF00D79400EA5400F72300
FD0A00FB1200F23700E27200CBB30076B1001A9400007626005A4800334100142E000720
00021A00031A000822001831003944005C4600772515920066AC00C5C400DA8B00EA5300
F62700FC0D00FD0900F91B00F03E00E46C00D49D00B8C2006CAE002B9A0000860700732B
00614200514D00364300213700142E000C2600072000041C00031A00021900021900031A
00031C00051D00061F000721000923000A24000A25000B25000B25000A24000923000721
00061F00051D00031B00031A00021900021A00041C000620
56A80042A1002D9B001A94000A8E00008607008015007A1F00762600732B00702F006F32
006E32006F3100712E00742A007823007D1A00830E018A001592002F9B004DA50072B000
9CBB00C6C000D2A300DC8300E66100EF4100F62500FB1100FE0700FD0B00F91C00F13A00
E66300D79300C5C30074B0002A9A00008210006A3800534C002E3F00142E00082100031A
00021900061F00112B002A3C00534D006D350089014DA500B2C000D89100EB5200F72100
FD0A00FB1200F23800E27200CCB30077B1001B9400007724005B4700354200152F000721
00021A00031A00082100162F003542005A4800742A0C8F005AA900B8C200D79400E85C00
F42D00FC1000FD0800FA1500F33400E76000D89000C7BF0081B4003EA000078D00007A20
00683B00584A004349002A3D001A3200102A00092300061F00041C00021A000219000219
00031A00031B00041C00051E00061F00062000072000072000072000062000051F00051D
00041C00031B00021A00021900021A00041C00061F000B25
78B10066AC0052A6003EA0002C9A00189300078D0000870500830E007F15007D1B007B1E
007A1F007B1E007C1B007F1600830E008804098D001B9400319C004DA5006DAE0093B900
BEC300CEAD00D89000E27000EB5000F33300F91B00FD0C00FE0700FC0F00F72400EE4600
E27100D2A000B2C00062AB001B9400007D1A00653E004F4E00293C00122B00072000021A
00021A00072000132C002D3E00554B006F31038B0054A700B9C200D98D00EB5000F82000
FD0A00FB1200F23800E17200CCB30079B2001D9500007823005C4600374300162F000821
00031A00021A00072100142E00314000574A00702F048B004EA500A9BE00D49D00E56500
F33500FB1400FE0800FC1000F52B00EA5400DC8300CCB20099BA0053A700199400008112
006F31005F4400504E00364300223800162F000D2800082200051E00031B00021A000219
00021900021A00031A00031B00041C00041C00041D00041D00041D00041C00031B00031A
00021A00021900021900031A00041C00061F000A2500122C
9BBA008CB7007BB20068AD0055A8003EA0002B9A001C9400109000088D00008A00008804
008706008705008901038B000C8E001893002799003A9F0052A7006FAF0091B800B8C100
CBB400D59900DF7B00E85D00F04000F62600FB1200FE0800FD0800FA1500F42F00EA5300
DE7F00CDAE009BBB004EA5000D8F0000782400614200474B002338000F2900061F00021A
00031A00082100152E00314000574A00712E088D005AA900BFC300DA8A00EC4D00F81E00
FD0900FB1300F23900E17200CCB2007AB2001F9600007922005D46003944001830000822
00031A00021A00062000122C002D3E00544C006D3400870442A2009ABA00D0A600E36F00
F03D00F91900FD0900FC0C00F72300EE4800E17400D1A300B2C0006BAE002E9B00008802
00772500663D00574A00444A002D3E001D3400132C000C2600082100051E00031C00031A
00021900021900021900021900021A00031A00031A00031A00031A00021A000219000219
00021900021A00031B00041D000720000B2500122C001D35
BCC300B4C000A6BD0095B90084B5006BAE0056A80045A200379E002D9B002497001D9500
1A94001A94001E95002497002D9B003A9F004AA4005FAA0078B10096B900B8C200CAB600
D39E00DC8300E56600ED4A00F43000F91A00FD0C00FE0600FD0C00F81E00F13B00E66200
D98E00C8BC0084B5003B9F0000890000722D005C47003E47001E35000D2700051D000219
00031B000923001730003643005A4800742A0E8F0061AB00C5C300DB8600ED4A00F91D00
FD0900FB1300F13900E17300CCB2007CB200219600007A20005E45003B46001931000923
00031B00021900061F00112B00293C00514D006A3900830D359E008AB600CDB000DF7900
EE4700F82000FD0B00FD0900F91B00F13C00E56600D79400C6C00085B50045A300119000
007F16006E32005F4400514D003A4500273B001A3200112B000B2600082100051E00041C
00031B00021A00021900021900021900021900021900021900021900021900021900021A
00031A00041C00051E000822000C2600132D001E35002F3F
C9B900C9B900C7BD00C5C400B7C1009EBB0087B50075B00065AC005AA9004FA60047A300
43A20042A20045A3004BA40054A70062AB0073B00088B600A2BC00C0C300CBB400D39E00
DB8600E36C00EB5200F23800F72200FB1100FE0700FE0800FB1300F62900ED4900E27200
D39E00BAC2006DAE0029990000830E006C3500574A003643001A32000A2500041C000219
00041C000A24001A32003B45005C4600762615920069AD00C7BF00DC8200EE4700F91C00
FD0900FB1400F13A00E17300CCB2007DB300239700007B1E005F44003E47001A32000A24
00031B00021900051E000F29002539004E4E00663D007F152999007AB200C8BB00DC8500
EB5100F62700FC0E00FE0800FB1400F43000E95700DC8400CDB000A1BC005FAA00289900
00870400772500683B005A48004C4D00354200243900193100112B000C2600082200061F
00051D00041C00031B00031A00021A00021A00021A00021A00021A00031A00031B00041C
00051E000720000A24000E2900162F002137003241004A4C
CEAC00D0A700D0A600CFAA00CDAF00C8BC00BEC300AABE009ABA008EB70081B40078B100
72B00071AF0073B00079B20082B4008FB800A1BC00B6C100C7BE00CEAE00D49B00DC8500
E36E00EA5500F03D00F62800FA1600FD0A00FE0600FD0C00F91C00F23600E95A00DC8300
CDAF009FBB0056A800169200007C1B00663C00524D002E3F00152F00092300031B000219
00041D000C26001E35004048005F440079211C940070AF00C8BB00DE7F00EE4500F91A00
FD0800FB1400F13A00E17300CCB1007FB300259800007C1C006043004048001C34000A25
00031C00021900051D000D2700213700474B006241007B1D1C95006AAD00C3C400D89100
E85C00F43000FB1300FE0700FC0E00F62500ED4900E17300D39F00C0C3007CB30041A100
11900000801400712F00634000564B00464B00324100233800193200122C000D27000A24
00072100061F00051E00041D00041C00041C00041C00041C00041C00051D00061F000720
000923000D2700122C001A3200253A003643004E4E005B47
D1A500D59900D79200D89000D89100D49D00D0A800CCB300C8BC00C5C200BAC200AFBF00
A8BE00A6BD00A8BE00ADBF00B5C100C2C400C8BD00CCB100D2A300D79200DD7F00E46B00
EA5500F03F00F52B00F91900FC0C00FE0600FE0800FB1300F62800EE4600E46B00D69500
C7BF0084B5003FA100058B00007627006043004A4C00273A00122B00072100031A000219
00051E000E2800213700474B006241007C1B23970079B200CAB700DF7A00EF4200FA1900
FD0800FB1500F13B00E17300CCB10080B400279800007D1B006241004349001E35000B25
00041C00021900041C000C26001E35004048005E4400772510900059A900B0C000D49D00
E46900F13B00F91900FD0900FD0A00F91C00F13A00E66200D98C00CBB5009CBB005FAA00
2B9A00018A00007B1E006C35005F4400544C00444A003241002539001B3300152E00102A
000C27000A24000822000721000720000620000620000720000721000923000A25000D27
00112B001730002036002D3E003E4700524D005E45006B36
D1A400D89100DC8300DF7A00E17500DE7E00DB8700D89100D59900D3A000D0A800CDAF00
CBB400CBB500CBB500CCB300CDAE00D0A800D39F00D79300DC8500E17500E66400EB5100
F03E00F52B00F91B00FC0E00FE0700FE0600FC0E00F81E00F23700E95800DE7F00D0A800
AFBF0068AD0029990000840B006F31005A48003E47002036000E2800061F00021A00021A
00061F00102A00263A004E4E00663D007F152B9A0082B400CCB200E07600F03F00FA1700
FE0800FA1500F13C00E17300CDB00082B400299900007E1900634000464B002036000C27
00041D00021900041C000A24001A32003A45005A4800722C048B0049A4009CBB00CFA900
E07600EE4600F72100FD0C00FE0700FB1300F52D00EB5100DF7900D2A200BEC3007FB300
48A4001A9400008509007725006A38005E4500534C00454A00354200293C002036001931
00142E00112B000F29000D27000C26000C26000C26000D27000E2800102A00132D001831
001F3600293C003643004A4C00564A006241006F31007D1A
CEAC00D89100DF7C00E46B00E75F00E66200E46800E36F00E17500DF7B00DC8300DA8B00
D89000D79200D79200D89000D98D00DB8700DE7E00E17300E56700E95800ED4900F23800
F62900F91A00FC0F00FE0700FE0500FD0A00FA1700F52C00ED4900E36C00D79300C8BB00
90B8004DA500139100007D1A00683A00544C003442001A32000B2600041D00021900031A
00072100132D002B3D00514D00693900830F339D008BB600CEAD00E27200F13B00FA1500
FE0800FA1600F13C00E17300CDB00084B5002B9A00007F1600643F00494C002237000D28
00051D00021900031B00092300173000334200564A006E33008607389E0087B500CAB600
DC8400EB5300F52B00FB1100FE0700FC0D00F82100F04000E56600D98E00CBB400A3BC00
6AAD00389E000F9000008210007528006939005E4500554B004A4D003B4500304000273B
002037001C3300193100162F00152F00152E00152F001730001932001D34002338002A3D
00354200444A00524D005D4600683B0074290081110E8F00
C8BB00D49B00DE7E00E56600EB5200EC4E00EC4E00EB5000EA5400E95700E75E00E56600
E46B00E36D00E36E00E36D00E46A00E66500E85D00EA5400ED4900F13D00F43000F72300
FA1700FC0D00FE0700FE0500FD0900FB1300F62500F03E00E85E00DD8200D0A800B4C000
71AF00339D00008900007528006142004E4E002B3D00152E00092300041C00021900031B
00092300162F00304000554B006C350086073CA00095B900D0A800E36D00F23800FB1400
FE0800FA1600F03D00E17400CDAF0086B5002E9B0000801400663D004C4D002439000F29
00051E00021900031B00082100142E002D3E00524D00693900811228990072B000C5C300
D79200E76100F23700FA1800FD0800FD0800FA1600F43000EB5200E07800D39F00C5C200
8FB7005AA9002E9B00098D00008112007528006A3800614200584900514D00464A003B45
003241002C3E00283B00253A00243900243900253900283B002C3D003241003B4500474B
00524D005A4800643F006F31007B1E0087041C950043A200
AEBF00CDAE00DA8C00E36C00EB4F00EF4400F03D00F13A00F23800F23700F13D00EF4300
EE4700ED4A00ED4A00ED4A00EE4800EF4400F03E00F23700F42E00F72400F91B00FB1200
FD0B00FE0600FE0500FD0800FB1100F82100F23700EA5300E17400D59800C8BD0091B800
52A7001A9400008113006D34005A4800404800223800102A00072000031B00021900041D
000B25001A3200374300584900703000890046A3009FBB00D2A200E46800F23500FB1200
FE0800FA1700F03E00E17400CDAF0088B600309C0000811200673C004F4E00273A00102A
00061F00021A00031A00072000112B00283B004E4E00643F007B1D1893005EAA00AEBF00
D2A100E27000EF4400F72200FC0D00FE0600FC0E00F72200F04000E66300DB8800CEAB00
B7C10081B40052A6002A9900098D00008211007725006D3400653E005D4500574A00524D
004C4D00444A003F47003C46003A45003B45003D4600414900484C00504E00554B005C47
006340006D3500772400830D0D8F002F9B0056A80082B400
7DB300BFC300D2A200DE7E00E85A00EE4700F23800F42E00F62600F82000F72200F62600
F62900F52B00F52B00F52B00F52A00F62700F72300F81E00FA1800FB1200FD0C00FE0700
FE0400FE0500FD0900FB1100F82000F33300EC4D00E46B00D98D00CDB000ACBF006EAF00
359D00038B0000782300653E00534C003442001B33000D2700051E00021A00021A00051E
000D27001F35003E47005C4600742A088D0051A600AABE00D49D00E66400F33200FB1100
FE0800FA1800F03E00E17400CDAE008AB600339D0000820F00693A00514D00293C00122C
00072000031A00021A00061F000F2900223800454A005F44007627088D0049A40096B900
CCB100DD8100EA5300F42E00FB1300FE0700FD0800FA1600F42E00EC4D00E27000D79300
CBB400ACBF007BB2004FA6002B9A000C8F0000840B007B1E00722C006B3700653E005F44
005B4700584A00554B00544C00544C00544C00564B005849005C4600614200673C006E32
007725008113058C0025980048A3006FAF009ABA00C5C400
47A30088B600C6C000D59A00E27200E95800EF4200F43000F72100FA1600FB1300FB1300
FB1400FB1400FB1300FB1300FB1300FB1200FC0F00FD0C00FD0900FE0600FE0400FF0400
FE0600FD0B00FB1300F82100F33300ED4A00E56600DC8500D1A600C1C40085B5004CA500
199300008111006F31005D4600484C00293C00152E000A2400041C00021900031A000720
00102A00243900474B0060430078231291005CA900B5C100D69700E75F00F42F00FC1000
FE0800FA1800F03F00E17400CDAE008CB700369E0000840C006A3800524D002C3E00132D
00072100031A00021900051E000D27001D35003C46005A48007030008705359D007DB300
C6C000D79200E66400F13C00F81D00FD0B00FE0600FC0D00F81F00F13900E95800DF7A00
D59A00C9B900A8BE007BB20053A700329C00169200008900008112007A2000742A006E32
006A3800673C00653E00643F00643F00653E00673C006A38006E3200742A007B1E00830F
058B001F960040A10068AD008FB700B9C200CBB400D3A000
1391004CA5008EB700C8BD00D79500E17500E95900EF4100F52C00F91A00FB1200FC0E00
FD0B00FD0900FE0700FE0600FE0600FE0500FE0400FF0300FF0300FF0300FE0500FD0900
FC0F00FA1800F72500F23600ED4B00E66500DD8100D3A000C7BF0097B90060AB002C9A00
00890000782300663D00554B00394500203600102A00072100031B00021900031C000822
00142D002A3D004F4E00653E007C1B1C950067AD00C1C400D89100E95A00F52B00FC0E00
FE0800F91900F04000E17400CEAD008EB700389E0000850A006C3600544C002F3F00152F
00082200031B00021900041C000B2500193100344200554B006A3800801321970064AC00
B1C000D1A300E07600EC4C00F52A00FB1200FE0700FE0700FB1300F62700EF4200E76000
DE7F00D39E00C9BA00ABBE0082B4005EAA003FA10026980011900000890000840C007F17
007B1E007823007626007528007627007725007A20007D1900820F0088020F9000249800
40A10061AB0089B600B6C100CAB600D2A100D98D00DE7F00
007D191491004CA5008DB700C8BD00D49C00DE7D00E76000EE4500F42E00F82000FA1700
FC1000FD0B00FE0700FE0500FE0500FE0500FE0500FE0600FE0700FD0B00FC1000FA1700
F82000F52D00F03D00EB5100E56800DD8200D39E00C9BB00A2BC006DAE003CA0000F9000
007F16006E33005D46004B4D002C3E001831000C2600051E00021A00021900041D000B25
00183100324100544C00693900801327990074B000C6C000DA8A00EA5400F62800FC0D00
FE0800F91A00EF4100E17500CEAD0090B8003B9F00008607006D3400564B003341001830
000A2400041C00021900031B00092300152E002C3E00504E00643F007A200F90004CA500
94B900CBB500DA8900E75E00F13900F91D00FD0B00FE0500FD0A00FA1800F52D00EE4700
E66400DD8100D49C00CAB600B6C10091B80070AF0055A7003DA0002A9A001B94000F9000
068C00008A00008802008803008901028A00098D00149200229700359D004DA50068AD00
8AB600B0C000CAB800D49D00DB8900E07700E46C00E46900
00683A007C1B10900047A30087B500C0C300D0A800DA8900E36C00EB5100F03E00F43000
F62500F91D00FA1600FB1200FB1100FB1100FB1200FB1400FA1700F91C00F72400F42D00
F13A00ED4900E85B00E27000DB8700D2A000C9BB00A6BD0075B10046A3001A940000840B
00742900643F00544C003A4500213700122B00082200041C00021900031A00061F000E28
001E35003A45005849006E33008509339D0081B400C9B900DC8300EC4F00F72500FD0B00
FE0800F91B00EF4200E17500CEAC0093B8003EA000008803006F31005849003743001A32
000B2500041D00021900031B00072100112B00253A00464B005E4500732B008802359D00
77B100C1C400D49C00E27200ED4B00F52B00FB1400FE0700FE0500FC0D00F91C00F43000
ED4900E66300DE7E00D69700CEAE00C5C200A8BE008BB60073B0005EAA004DA50041A100
379E00319C002E9B002E9B00329C00399F0043A20052A60065AC007DB3009ABA00B9C200
CAB700D3A000DB8600E36C00E75E00EA5600E95700E66400
00544C00663C007A20088D003DA00071AF00A7BD00CAB800D59A00DE7E00E56800E95700
ED4800F13D00F33300F42E00F52B00F52A00F52A00F52D00F33100F23800EF4100EC4C00
E95900E46A00DE7C00D89100D0A700C7BF00A3BC0076B1004AA400219600008803007922
006939005A4800474B002C3D001931000D2700061F00031A00021900031B00082200122B
00243900444A005D4600732C008A0040A1008EB700CCB100DE7D00ED4A00F72100FD0A00
FD0800F91C00EF4200E17500CEAC0095B90042A10000890000712E005A48003B45001D34
000C2700051E00021900031A00061F000E29001F36003C46005849006C350081121E9500
5BA900A0BC00CDB000DB8700E75F00F13C00F82100FC0E00FE0500FE0600FC0E00F91D00
F43000EE4700E75E00E07600D98C00D2A100CCB300C5C300AFBF009BBA008AB6007DB300
73B0006EAF006CAE006EAF0073B0007DB3008BB6009DBB00B4C000C7BE00CEAC00D59900
DC8400E36D00EA5600EF4200F03F00EE4500EA5600E27100
00314000514D00634000752700880227990056A80088B600BAC200CDB000D59900DB8600
E07600E56800E85C00EA5400EB5000EC4E00EC4E00EB5000EA5500E85C00E56500E27000
DE7E00D98E00D3A000CBB300BFC30098BA0070AF0049A400239700008A00007C1D006D34
005E4400504E00354300203600112B00092300041D00021900021A00051D000A2500162F
002C3E004F4E0062410078230C8E004DA5009DBB00CFAA00E07600EE4500F81E00FD0900
FD0900F81D00EF4300E17500CFAB0097BA0045A300028B0000732C005C46003F48002036
000E2800061F00021A00021900051E000C2600193200324100524D00653E007921098D00
40A10080B400C5C400D49D00E17500EB5000F33100F91A00FD0B00FE0500FE0600FC0E00
F91C00F42D00EF4100EA5500E46A00DE7D00D98F00D39E00CEAC00CAB700C6C000C1C400
B9C200B5C100B4C100B8C200C0C300C6C000CAB700CEAC00D49D00DA8C00E07800E56500
EB5200F03F00F43000F62800F33300ED4900E46800D89100
001730002B3D004B4D005E45007030008013109000399F0065AC0092B800B8C200C9B900
D0A800D59900D98C00DC8300DE7D00DF7A00DF7900DF7B00DE7E00DC8500D98D00D59800
D1A500CBB300C5C300A8BE0086B50064AC0041A1001F9600008900007C1B006F31006142
00544C003D4700273A00162F000C2600061F00031B00021900031B000620000E28001C34
00354300544C00683B007D191993005CA900ACBF00D2A200E36E00F03F00F91B00FE0800
FD0900F81E00EE4400E07600CFAA009ABA0049A400068C00007529005E4500444A002338
00102A00072000031A00021900041C00092300152E00293C00494C005E4500712E00850A
26980060AB00A1BC00CCB300D98D00E56700EE4600F52A00FA1600FD0900FE0400FE0600
FC0D00FA1800F62700F23700ED4800E95900E46900E07700DC8400D98E00D69700D49D00
D2A100D2A200D2A100D39E00D59800D89000DC8500E07800E46900E95700EE4500F23600
F52900F82000F81D00F72300F03E00E66200D98D00C8BB00
000A2400132D002439003F4700584A00673B0077250086081A94003FA10062AB0082B400
A0BC00BAC200C7BE00CBB400CEAE00CFA900D0A700D0A800CFAB00CDB000CAB700C6C000
B9C200A2BC0089B6006DAE0050A600339D00169200008704007B1D006F3100624100564B
004349002C3E001B33000F2900082200041C00021A00021900041C00092300122C002439
004048005A48006E3300830E2798006CAE00BCC200D59900E56700F13A00FA1800FE0700
FD0A00F81F00EE4500E07600CFAA009CBB004CA5000A8E00007725006143004A4C00273B
00132C00082200031B00021900031B00072100102A002137003C4600574A006939007C1B
0E8F0042A1007DB300BDC300D1A500DD8000E85E00F03F00F62600FB1400FD0900FF0400
FE0400FD0A00FB1300F81E00F52B00F23800EE4500EB5100E85B00E66400E46B00E27000
E17300E17400E27200E36D00E56600E85D00EB5300EE4600F23800F52A00F91D00FA1600
FB1300FA1700F72200F23700E76000D98E00C8BD007FB300
00041D000721000F29001D34003341004F4E005E45006C35007A1F008704179300329C00
4DA50065AC007BB2008DB7009ABA00A3BC00A8BE00A9BE00A6BD009FBC0095B90087B500
77B10063AC004EA500379E001F9600088D0000830E007822006D3400624100564B00464B
003040001E3500122C000A2400051E00031A00021900031B00061F000C26001831002D3E
004D4E00604300742A008802369E007CB300C6C000D89100E76000F33500FA1500FE0600
FD0A00F82100EE4700E07600CFA9009FBC0050A6000E8F00007922006340004F4E002B3D
00152E00092300041C00021900031A00061F000D27001A3200314000504E00624200742A
0086072598005AA90095B900C8BD00D59A00E07800E95800F13C00F62600FA1500FD0A00
FE0400FF0300FE0600FD0C00FB1300F91C00F62500F42E00F23600F03D00EF4200EE4500
EE4700EE4600EF4300F03F00F23800F43000F62700F81D00FB1400FD0C00FE0800FD0B00
FA1500F62700F04000E66200D79200C6C20077B1002C9A00
00041C00031B00051E000B2500152F00263A003D4700544C006142006E3300792100830D
078C001B94002E9B003EA0004BA40055A7005BA9005DAA005DAA0058A80051A60046A300
399F002A9A00199400078D00008509007C1B00732B006939005F4400554B00454A003140
00203600142E000C2600062000031B00021900021A00041C00082200112B001F36003844
00544C00663D007A200B8E0046A3008EB700CAB700DB8800E95800F42F00FB1200FE0500
FD0B00F72200EE4800E07700CFA900A2BC0054A700129100007B1E00653E00514D003040
001831000B2500051E00021A00021A00041D000A2400152E00273B004349005A48006B37
007C1B0A8E00399F006FAF00A8BE00CBB400D79400E17400EA5600F13D00F62800FA1800
FC0C00FE0600FF0300FF0300FE0500FD0900FC0E00FB1300FA1800F91C00F81F00F82100
F72100F82000F81D00F91900FB1400FC0F00FD0A00FE0500FF0300FE0400FD0B00F91B00
F33100EC4F00E17300D49B00BAC20069AD00229700007F16
00092300041D00031A00041C000721000F29001B33002C3E00424900554B006043006A38
00732B007B1D00820F008802088D001191001793001B94001C95001A94001592000E8F00
048B00008705008111007B1E00742A006C35006440005B4800514D004148002F3F002036
00152E000D2700072100041C00021A00021900031B00061F000C2600173000293C00454A
005B48006D340080131B940058A800A0BC00CEAD00DE7E00EB5100F52A00FC1000FE0500
FD0C00F72300ED4900E07700D0A800A5BD0058A800179300007D1A00683B00544C003542
001C33000D2800061F00031A00021900031C00082100102A001F3500364300524D006241
00732C00830D1A940049A4007DB300B4C000CDB000D89100E17400E95900EF4100F42D00
F81E00FB1200FD0A00FE0500FF0200FF0200FF0300FE0400FE0600FE0700FD0800FD0900
FD0800FE0700FE0600FF0300FF0100FF0000FF0100FE0500FD0B00FA1600F62800EF4300
E66300DB8800CDAF00A4BD0057A800139100007A1F006241
001830000B2500051E00031A00031A00051E000A2400112B001D34002D3E00404800514D
005A48006241006A38007030007528007921007C1C007E18007F17007E17007D1A007B1E
00782300742A006F32006939006340005C4700544C004A4D003945002A3D001E3500142D
000D2700082100041D00031A00021900031A00051D00092300112B001F3500344200514D
00624100742A0087052C9A006BAE00B3C000D2A300E17500ED4900F72500FC0D00FE0500
FC0D00F72500ED4A00E07700D0A700A8BE005CAA001C9400007F15006A3700574A003B45
00203600102A00072100031B00021900031A00061F000C26001730002A3C00454A005949
00693900792100890126980054A70086B500B8C200CDAF00D79300E07800E76000ED4A00
F23700F62800F91B00FB1200FD0C00FE0700FE0400FF0200FF0100FF0100FF0100FF0000
FF0000FF0000FF0100FF0200FE0500FD0900FB1100F91C00F52C00F04000E85B00DE7C00
D2A000C4C40080B40040A100038B0000742A005D46004048
003944001E35000E2900072000031B00021900031B00061F000B2500122C001C3400293C
00374400474B00524D005849005D4500624100653E00673B00683A00693A00683A00663C
00643F006142005D4600584A00524D004A4C003C46002F3F002439001A3200122C000C26
00072100041D00031A00021900021A00041C000721000D2800183100293C004349005849
006939007B1D0A8E003FA10080B300C5C300D59800E46B00EF4200F82000FD0B00FE0400
FC0E00F62700ED4B00E07800D0A700ABBE0060AB00209600008111006D34005A48004148
00243900132C00092300041D00021900021A00041D00092300122B00203600354300504D
005F44006E32007E19078D002E9B0059A90087B500B6C100CBB300D59A00DD8200E46B00
E95700EE4600F23700F52B00F72100F91A00FB1400FC1000FC0D00FD0B00FD0B00FD0B00
FD0C00FC0E00FB1200FA1700F81F00F52900F23800ED4A00E76100DF7B00D59900C8BB00
98BA005AA90021960000820F006C3500574A003543001931
005D4500474B00283B00142E000A2400041D00021A00021900031B00061F000A2400102A
001830002137002B3D003543003F4700484C004F4E00524D00534C00544C00544C00534C
00514D004F4E00474B003F47003643002D3E002439001C3400152E000F29000A24000720
00041D00031A00021900021A00031C00061F000B2500142D00213700364300514D006043
00712F00830F1C950054A70095B900CAB700D98D00E66200F13A00F91B00FD0900FE0400
FC0F00F62800EC4D00E07800D0A600AEBF0065AC0026980000840C007030005D4600484C
002A3C00162F000B2500051E00031A00021900031B000620000D2700183000283C004048
00564B00643F00722D0080130B8E00309C0058A80081B400ACBF00C8BC00D1A500D89000
DE7C00E46A00E85A00EC4D00EF4200F23900F33100F52C00F62900F62700F62600F62700
F52A00F42F00F23600F04000EC4C00E85C00E27000DB8600D3A000C8BB00A2BC0069AD00
339D00038B0000782400643F004F4E002B3D00132D000821
00792100663D00544C003643001D35000F2900072100041C00021900021900031B00051E
000822000D2700122C001730001D3400233800293C002D3E003040003241003341003241
003040002D3E00293C002439001E3500193100142D000F29000B2500082200051E00041C
00031A00021900021A00031B00061F000A2400112B001C34002E3E00474B00594900683A
007921028A00319C006AAE00ACBF00CFAB00DD8100E95800F33300FA1700FE0700FE0500
FB1100F52A00EC4E00E07900D1A500B1C0006AAD002B9A0000860700732C006043004F4E
002F3F001A32000E2800072000031B00021900031A00051D00092300112B001E35003040
00494C00594900663C00742A0081110B8E002C9A0050A60075B0009ABA00BEC300CBB500
D1A300D79300DC8300E07600E46B00E76100E95A00EA5500EB5100EB5000EB5100EA5400
E95900E76000E46A00E07700DB8700D59900CEAE00C4C40099BA006AAE003CA0000E8F00
007E18006C36005949003F47002036000E2800061F00031A
1E960000840C00712F005E45004A4D002B3D001830000C2700062000031B000219000219
00031A00041D00061F000922000B26000F2900122B00142E001730001831001931001931
00183100173000152E00122C00102A000D27000A2400082100061F00041C00031B000219
00021900021A00041C00061F000A2400102A001A3200283B003E4700534C00624100712E
00811115920047A30082B400C3C400D39E00E17600EC4E00F52C00FB1300FE0500FE0500
FB1200F52C00EB4F00DF7900D1A400B4C1006EAF00319C0000890100762700634000524D
003643001F3600112B00082200041D00021A00021900031B000620000C2600152F002338
003643004F4E005B4700683B00742A008014058C0022970041A10061AB0080B4009FBB00
BBC200C8BB00CEAE00D2A200D59800D88F00DA8900DC8500DC8300DC8300DC8500DA8900
D89000D59900D1A500CCB300C5C300A7BD0083B4005CAA00359D000F900000811200702F
005F44004E4E002D3E001730000A2400041C00021A00041D
71AF0040A1000E8F00007D1A006A3800584A003F4700253900152E000C2600062000041C
00021A00021900021900031B00041C00051E000620000822000923000A24000B25000B25
000B25000A2400092300082200072100061F00051E00041C00031B00021A000219000219
00031A00041C000620000A2400102A00193100263A00384400504E005D46006B37007A1F
018A002C9A0060AB009BBB00CAB800D89100E46A00EE4500F62500FC0F00FE0400FE0600
FB1400F42E00EB5100DF7900D1A400B7C10073B000369E00048B0000792200673C00564B
003E4700253900152E000B2500051F00031B00021900031A00041D000822000F29001931
00273B003A4500504E005B4700673C00722D007D1A0088041391002D9B0047A30060AB00
79B2008FB800A4BD00B5C100C4C400C7BE00C9B900CAB700CAB600CAB700C9BB00C6C000
BFC300ADBF0097BA007FB30063AB0044A200259800068C00007F1600712E00624100534C
003743001F35000F2900062000031A00021A00061F00102A
C0C3009BBB0069AD00339D00028B0000772500643F00534C00394500233800152E000C27
00072100051D00031B00021A00021900021900021A00031B00031B00041C00041D00041D
00041D00041D00041C00041C00031B00031A00021A00021900021900021900031A00031C
00051E000721000B2500112B001931002539003643004D4E005A4800673C00752800840C
17930045A3007AB200B6C100CFA900DC8400E75E00F13B00F81F00FD0C00FF0300FE0700
FA1600F43000EB5200DF7A00D2A300BBC20078B1003DA0000A8E00007C1C006A38005A48
00464B002B3D001932000E2800072100041C00021A00021900031B00061F000A2400112B
001B3300293C003B45004F4E005A4800643F006E33007823008112008A00149200289900
3B9F004DA5005DAA006BAE0077B1007FB30085B50088B60087B50082B4007AB2006FAF00
61AB004FA6003B9F002598000E8F00008509007A1F006E3300614200544C003C46002439
00132D00092300041C00021900031B00082200162F003241
CFA900CEAE00C6C0009ABA0061AB0025980000850A00722C00614200524D003945002539
001730000F29000A2400062000041D00031B00031A000219000219000219000219000219
00021900021900021900021900021900021900021900021A00031B00041C00051E000720
000923000D2800132D001B3300273B003743004B4D00584900643F00712E007F16098D00
319C0060AB0097B900C7BD00D59A00E07600EB5200F33200F91900FD0900FF0300FE0800
FA1800F33300EA5400DF7B00D2A200BEC3007DB30043A200119000007F16006E33005E45
004F4E003341001F3500122C000A2400051E00031B00021900021A00041C000620000B25
00122C001C3300283C003944004C4D00564A005F4400683A00702F007822008015008607
068C001391001F9600299900319C00369E00399F00399F00379E00319C002999001E9500
119000028A0000830D007B1D00722D00683B005D4600514D003B4500263A00162F000B25
00051E00031A00021900051E000D27001E35004148005F44
D1A500D79200D89100D2A100C8BC0091B80051A6001A940000821000712E00614200534C
003D47002A3C001D3400142D000E28000A2400072100061F00041D00041C00031B00031B
00031B00031A00031A00031B00031B00041C00041C00051E00061F000821000A24000D27
00112B001830002036002B3D003A45004E4E005849006340006F31007C1C008900239700
4DA5007EB300B5C100CEAD00DA8B00E56800EE4700F52A00FB1400FE0600FF0300FD0A00
F91B00F23500EA5600DF7B00D2A200C1C40083B40049A40018930000820F00722D006241
00534C003B4600263A001730000D2700072100041C00021A00021900031A00041D000721
000B2600122C001A3200263A00334100434900514D00594900604300673C006E3300732B
007922007D1A00811200840C00860800870500870400870600850900830E007F15007B1E
007528006F3200673B005F4400564B004A4C00354200233800162F000C2600061F00031B
00021900031B00082200142D002B3D00514D00693900820F
C7BE00D69600DF7A00E17200DE7D00D39E00C5C30086B5004AA40018930000821000722D
00634000564B00474B00344200263A001C3400152E00102A000D27000B25000923000822
000721000721000720000721000721000822000923000B25000D27000F2A00132D001831
001F3600283B00334200424900514D005A4800643F006F31007B1E0087041A940041A100
6DAE009EBB00C8BC00D49C00DF7B00E95A00F13C00F72200FC0F00FE0400FF0300FD0C00
F81E00F23800E95800DF7C00D2A100C5C40088B60050A6001F960000860800762700663D
00584A00454A002D3E001C3400112B000A2400061F00031B00021900021900031A00041D
000721000B2500102A001830002137002B3D00384400454A00504D00564A005C47006142
00653E006939006C36006E33006F31007030007030006E32006C3500693900653E006043
005B4700544C004B4D003B45002B3D001E3500132D000B2600062000031B00021900031A
00061F000E28001E35003E47005C46007429098D0050A600
7CB200C9B900DA8900E56500EA5400E66200DE7E00D2A100C3C40084B50049A400189300
00830D00752800683B005C4600524D00444A003542002A3C002238001C3400183100152E
00132D00122C00112B00112B00122B00132C00142E001730001A32001E35002439002B3D
003442004048004E4E00564B005E4500673B00712E007C1C008705179300399F0061AB00
8EB700BFC300CFAA00DA8B00E36C00EC4D00F33200F91C00FD0C00FE0400FE0500FC0F00
F72200F13B00E85B00DE7D00D2A100C5C3008DB70057A800279800008900007A20006B37
005C46004F4E00374300243900162F000E2800082200051E00031B00021900021900031A
00041D000620000A24000E2800142D001A32002238002B3D003442003D4700474B004F4E
00524D00554B00574A005949005A4800594800594900574A00544C00514D004B4D004048
003543002A3D002036001730000F2A000A2400061F00031B00021900021A00051E000B25
001730002E3F00524D00693A00811229990076B100C5C300
1D950077B100C9B800DD8200EA5400EE4500ED4900E85D00DE7C00D3A000C2C40083B400
4CA5001F9600008804007B1E006F3200643F005B4700544C004C4D004048003743003040
002C3D00283B00263A00253A00253A00263A00293C002C3D003040003643003D4700474B
00504E00564B005D4600643F006C35007528007F17008901189300389E005CA90085B500
B1C000CBB500D59800DF7B00E85D00EF4200F52A00FA1700FD0A00FE0600FD0900FB1400
F62700F04000E75E00DE7F00D2A100C6C20091B8005DAA002E9B00068C00007D19006F31
00614200544C004148002C3E001D3400132C000C2600072100041D00031A000219000219
00031A00041C00051F000822000B25000F2900132D001831001E3500233800293C002E3F
003341003643003945003B45003B45003A45003743003341002E3F00283B002238001C33
00152F00102A000B2500072100041D00031A00021900021A00041D00092300132D00253A
00454A005E440075270C8E0051A600A3BC00CFAB00DB8700
00732B1391006DAE00C8BC00DD8000EA5500F13B00F33400F03E00EA5600DF7B00D2A100
C4C4008AB60058A8002D9B000B8E0000830F007823006F3100673C006043005B4800564B
00524D004F4E004C4D00494C00484C00494C004B4D004E4E00504D00534C00574A005B47
00604300663D006C3500732B007B1D00830D078C001F96003CA0005DAA0082B400AABE00
C8BB00D2A100DB8600E46A00EB5000F23700F72300FB1300FD0A00FE0800FC0D00FA1900
F52C00EE4500E66200DD8100D2A100C6C00096B90063AC00369E000E8F0000811100742A
00663D005A48004E4E00374300263A00193100102A000A2500072000041D00031B000219
00021900021A00031B00041D00061F000822000A24000D2700102A00132C00152F001831
001A32001C33001D34001D34001D34001B3300193200173000132D00102A000D27000A24
00072100051E00031B00021A00021900031A00051D00092300122B002137003C4600584A
006C3500830D309C0083B400C9BA00D98E00E36F00E56800
00514D006D33058C005CA900C5C400D98D00E85C00F23800F72500F72300F23800E95700
DF7A00D39E00C7BE009ABA006BAE0043A200229700088D0000840C007C1C007528006F31
006B3700673C00643F00624100614200604300604300624200634000663D006939006D34
00722E007725007D1A00830D028A001592002C9A0047A30064AC0086B500ABBE00C7BD00
D0A600D98D00E17400E85A00EF4300F42E00F91D00FC1100FD0A00FD0A00FB1100F81E00
F33100ED4900E56500DC8300D2A200C7BF009BBA006AAE003EA000179300008508007823
006B36005F4400544C004349003040002137001730000F29000A2400072000041D00031B
00021A00021900021900021A00031B00041C00051E000620000821000923000A24000B25
000C26000D27000D27000D27000C26000B25000A2400082200072000051E00041D00031B
00021A00021900021A00031B00061F000A2400122C00203600374300544C00673C007C1C
1692005DAA00B3C000D59A00E26F00EA5600E95900DF7900
001D3400464B00663D00840B44A200A1BC00D2A200E36D00F04000F72200F91B00F62500
F13B00E95800E07700D59800CAB600AEBF0084B5005FAA0040A100279900129100028A00
00850A008014007C1B007920007724007626007627007626007724007920007C1C007F15
00830D008803098D001893002A9A003EA00056A80071AF008FB700AFBF00C7BD00CFA900
D79300DF7C00E56500EC4F00F13B00F52900F91C00FB1300FC1000FB1200F91A00F62800
F13B00EB5200E36C00DB8800D1A400C6C0009CBB006FAF0044A2001F9600008900007D1B
00702F00653E005A48004F4E003C46002C3D001F3600162F000F29000B2500072100051E
00041C00031A00021A00021900021900021A00031A00031B00031C00041C00041D00051E
00051E00051E00051E00051E00041D00041C00031B00031B00021A00021900021900021A
00031B00041D000721000C2600142E00213700364300524D006340007626048B0041A100
8EB700CCB300DD7F00EB5200EF4300EB5100DF7A00CAB600
00072100152E003643005D46007A1F20960075B000C7BD00DB8800E95700F23600F62600
F72400F42E00EF4100E85A00E07700D79300CEAD00C4C4009FBC007EB30062AB004BA400
389E002899001C95001291000C8E00078C00048B00048B00058C00088D000C8F00139100
1C9500279800339D0043A20055A70069AD0080B4009ABA00B5C100C8BC00CFAB00D59800
DC8400E27000E85D00ED4B00F13B00F42D00F72400F81E00F81D00F72100F52A00F23800
ED4A00E75F00E07700D89100CFAB00C5C40099BA006FAF0048A300249800058C00008014
007528006A38005F4400554B00494C003844002A3C001F3500162F00102A000C26000923
00062000051D00041C00031B00021A00021900021900021900021900021900021900021A
00021A00021A00021900021900021900021900021900021900031A00031B00051D000720
000A24000F2A00183100253900394400524D00614200722C0086082B9A0070AF00BEC300
D59900E46B00EE4800F13A00EA5300DC8500C5C30057A800
00041C00051E000F2900283B00534C006E3300890048A4009FBB00D0A700DF7900EA5400
F13A00F42D00F52C00F23500EE4700E85C00E17400DA8B00D2A200CAB600BFC300A3BC00
8BB60076B10065AC0057A8004CA50044A2003FA1003CA0003B9F003DA00040A10046A300
4EA50058A80064AC0072B00083B40096B900ABBE00C2C400CAB800CFA900D59900DA8900
E07800E56700E95700ED4900F13D00F33300F52D00F52A00F52B00F43100F13A00EE4800
E95900E36D00DC8300D59A00CCB100BFC30096B9006FAF004BA4002999000C8F0000840C
007921006F3200653E005B4700534C00464B003643002A3C00203600183100132C000E28
000B2500082200072000051E00041D00041C00031B00031B00031A00031A00021A00021A
00021A00021A00031A00031A00031B00041C00051D00061F000821000A25000F2900152E
001E35002C3D003F4800544C00614200712E00820F1D950058A800A0BC00CEAD00DD8100
E85A00EF4300EF4200E85B00D79400ABBE003EA000007F16
000B2500041C00031B000A24001C33004249006142007C1C1E95006BAE00BBC200D39F00
E07800E95800EF4100F23600F23600F03E00ED4B00E85C00E36F00DD8200D79400D1A500
CBB400C6C100B7C100A5BD0097BA008CB70083B4007EB3007AB2007AB2007BB2007FB300
85B5008DB70098BA00A4BD00B3C000C3C400C8BB00CDB000D1A400D69700DA8A00DF7C00
E36E00E76100EA5400ED4A00EF4100F13A00F23700F23700F13A00F04000ED4A00E95700
E56700DF7A00D98D00D2A200CAB700B8C10093B8006FAF004EA5002F9B00139100008704
007D1900742A006B3700624100594800524D00464A003844002D3E002439001C34001730
00122C000F29000C26000A2400092300072100072000061F00061F00051E00051E00051E
00051F00061F000620000721000923000B25000D2700112B00162F001E3500283B003643
004A4C00574A00643F00722D0082101693004AA40089B600C7BE00D79400E46B00EC4F00
EF4400EC4F00E27200D0A6008BB60024980000762600564B
00293C000F2900051D00031A00061F00122C002D3E00544C006D34008608339D0078B100
BFC300D2A200DD7F00E66500EB5300ED4900EE4700ED4B00EA5400E76000E36E00DE7C00
DA8A00D69800D1A300CDAE00CAB700C7BE00C5C400BDC300B8C100B5C100B4C100B5C100
B9C200BEC300C5C400C7BE00C9B800CCB100CFA900D3A000D69600DA8C00DD8100E07600
E36C00E66200E95A00EB5200EC4D00ED4900ED4800ED4A00EC4E00EA5500E75F00E46C00
DF7A00DA8A00D49C00CEAE00C6C000ACBF008BB6006BAE004DA500319C00179300018A00
00811200782300703000683B00604300594900524D00484C003C4600324100293C002338
001D3400193100152E00122C00102A000F29000D28000D27000C26000C26000C26000C27
000D28000F2900102A00132D00162F001B33002137002A3C00354300444A00534D005C46
00683B00742900820F13910041A10077B100B5C100D0A800DC8300E66300EB5000EB5100
E56800D89100C5C40063AC00078D00006C35004C4D001C33
00594900334100142D00062000021A00041C000B25001C34003D47005C4600732C008802
319C006CAE00A8BE00CAB700D49D00DB8800E07900E27000E36C00E36D00E27200E07900
DD8100DA8A00D79300D49C00D1A400CFAB00CCB100CAB600C9BA00C8BC00C7BE00C7BE00
C7BE00C8BC00C9BA00CAB700CCB200CEAD00D0A800D2A200D49B00D79400D98D00DB8600
DD7F00DF7900E17400E27000E36E00E36D00E36E00E27000E17500DF7C00DC8500D88F00
D49B00D0A800CAB600C5C400AABE008FB70074B00059A90040A100299900139100008900
008111007A2000722C006B3600643F005E4500584A00524D004B4D004148003844003140
002B3D00263A002237001E35001C33001A32001931001831001830001831001931001A32
001C34001F3600233800283C002F3F00394400444A00504D005849006142006B37007627
0082100C8F00329C005FAA0092B800C5C300D1A500DA8A00E07600E36F00E07800D79500
C8BD0080B3002C9A00007E1800604300374400132D00051E
007725005F44003F47001B3300092300031B00021A00061F00102B00263A004A4D006043
00742900870428990058A80088B600B3C000C9BA00CFA900D49C00D79400D88F00D98E00
D98F00D79200D69600D49B00D2A000D1A500CFAA00CDAE00CCB200CBB500CAB700C9B800
C9B900C9B800CAB700CAB600CBB300CCB100CEAD00CFAA00D1A600D2A100D49D00D59900
D69600D79200D89000D98E00D98E00D98E00D89000D79400D59800D39E00D1A600CDAE00
CAB800C5C200B5C1009FBC008AB60073B0005DAA0048A300339D002096000E8F00008802
008211007B1E007429006E3200683A006340005D4500584900544C00504E00494C004148
003B45003643003241002E3F002C3E002A3D00293C00293C002A3C002B3D002D3E003040
003442003A45004148004B4D00524D00574A005E4500663D006E3200782300820F098D00
2899004CA50076B100A2BC00C7BF00CFA900D59800D89000D79300D2A300C7BE008CB700
42A200008900006E3200534C00263A000D2700041C00031A
0C8E00007C1C00653E004D4E002439000E2800051D00021900031B00092300162F002E3F
00504E00614200732B00840C1893003EA00064AC0088B600A6BD00C0C300C8BC00CBB500
CDAF00CEAC00CEAB00CEAC00CEAD00CDAF00CCB200CBB400CAB600C9B900C9BA00C8BC00
C8BD00C8BD00C8BD00C8BC00C8BC00C9BA00C9B900CAB700CBB500CCB300CCB100CDAF00
CEAD00CEAC00CEAB00CFAB00CEAC00CEAD00CDB000CBB300CAB700C8BD00C5C300BBC200
ADBF009EBB008EB7007DB3006BAE0059A90048A300379E00269800169200078D00008705
008112007B1D00762600712F006C3600673C006241005E45005A4800574A00534C00514D
004E4E00494C00454A00434900414800404800404800414800424900454A00494C004F4E
00524D00554B005A48005F4400643F006B3700722C007A1F00830E078C002096003EA000
5FAA0083B400A6BD00C5C400CBB500CEAD00CEAD00CAB700BAC20088B6004DA5000F9000
007823005F44003E4700193200082200031A00031C000D27
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ImageSize->{440, 440},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006h0001^2000`400?l00000o`00003oooooooni
ooooo`00ooooooniooooo`009_ooool3o`0003[ooooo0ol0000looooo`?o0000>Oooool5o`0003Oo
oooo0_l0000jooooo`Go0000>_ooool3o`00023ooooo000Uooooo`05o`000?ooooooooooooooool0
0000>?ooool01Ol0003ooooooooooooooooo000003cooooo00?o0000ooooooooool0>Oooool01?l0
003oooooooooool0000fooooo`04o`000?ooooooooooo`0003[ooooo00Co0000oooooooooooo0000
>oooool00ol0003oooooooooo`0Oooooo`007oooool5o`000003ooooool0003ooooo00;ooooo00?o
0000ooooooooool0<?ooool5o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0<Ooo
ool5o`000003ooooool0003o000000?o0000<oooool5o`0000?ooooo00?o0000ooooooooool0=_oo
ool01?l0003oooooooooool0000kooooo`03o`000?oooooooooo03Sooooo1Ol0000Pooooo`009_oo
ool3o`0003Wooooo1?l0000jooooo`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0
=Oooool01?l0003oooooooooool0000looooo`03o`000?oooooooooo03Oooooo00Co0000oooooooo
oooo00008Oooool002Gooooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo
03cooooo00?o0000ooooool00000>_ooool01Ol0003ooooooooooooooooo000003Kooooo00Co0000
oooooooooooo0000>Oooool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooool00000
8Oooool002Gooooo00Go0000ooooooooooooooooo`00000iooooo`03o`000?oooooooooo03cooooo
0_l0000jooooo`05o`000?ooooooooooooooool00000=_ooool01?l0003oooooooooool0000ioooo
o`05o`000?ooooooooooooooool00000>_ooool2o`00027ooooo000Vooooo`?o0000>oooool2o`00
03gooooo00?o0000ooooooooool0>Oooool3o`0003Sooooo0_l0000kooooo`?o0000??ooool00ol0
003oooooooooo`0Oooooo`00ooooooniooooo`00ooooooniooooo`00ooooooniooooo`00ooooooni
ooooo`00ooooooniooooo`00ooooooniooooo`007Oooooooo`0009_o00000Oooool001gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0
0001ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool2o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool07Oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo0?ooooooUoooool1o`00007o
oooo000Mooooo`03o`000?oooooooooo0?ooooooUoooool1o`00007ooooo000Mooooo`03o`000?oo
oooooooo0?ooooooUoooool1o`00007ooooo000Mooooo`03o`000?oooooooooo0?ooooooUoooool1
o`00007ooooo000Mooooo`;o0000oooooonGooooo`;o00000Oooool001gooooo00?o0000oooooooo
ool01Oooool3o`1f9`?o06Ll0ol0ED/3o`0f@`?o01Xb0ol02bD3o`0470?o008I0ol00a/3o`078@?o
014[1?l08CL3o`0iA0?o059=0ol0H4<3o`1^<`?o07XP0ol0Q0/3o`V=00?o7ID00ol_V`03ocfP00?o
B:@01?m@YP03oeJX00?oFJT01_mJZ@03oeRX00?oEZP00omDY`03oe6V00?oCjH00om=Y@03od^T00Co
BZ@00om9Y006odRT00?oBJ@00om:Y003od^U00?oCJD00om?YP03oe6V00?oDjL01?mFZ003oeNX00?o
FJT00omJZ@09oe^Y00?oFJT00omGZ003oe>W00?oCjH00om9Y004od>R00?o?:000oldW@03ob^J00?o
8YL00olHT`03o`j?00?o18/00ol0Q`D3o`233P?o07hH0ol0NR04o`1e:0?o070_0ol0K3H3o`1W>`?o
06=00ol0Gd@3o`1KB0?o05M:0ol0Dd`3o`1@CP?o04]=1?l0ADX3o`0oA`?o03Y50ol0=d<3o`0c@P?o
03500ol0;cl3o`0^?`Ko02dn0ol0;Sh3o`0_?`Co03500ol0<d83o`0gA0?o03a60ol0@TT3o`1:C0?o
051>0ol0ED/3o`1JB0?o06130ol0ISd3o`1]=0Co07@Y0ol0O1/3o`242`?o1X`00olJU003objK00?o
@:400om?YP06oeNX00?oCJD00oliW`04oafE00?o08P30ol0MbD3o`1T?`?o051=0ol0:cd3o`0C;0?o
00LP0ol00QX3o`036`?o00XT1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo
0ol0MRL3o`1W?0?o05E;0ol0=T<3o`0J<P?o00/U0ol011`3o`026@?o00<K0ol01b43o`0A:`Co024g
0ol0>D@3o`1BC@?o06130ol0KS<3o`1j80?o08@;0ol9S@03oafE00?o;i/00olmX003odRT00CoD:H0
0omFZ003oeVY00KoFZT00omHZ003oeJX00?oE:L00omAYP03odnV00?oCJD00om;Y004odZT00?oBJ@0
1_m8Y003odVT00?oBZ@00om;Y@03odfU00?oCjH00omAYP03oe>W00CoEZP00omGZ003oeVY00?oFZT0
2OmKZ@03oeVY00?oEjP00omCY`03odnV00?oBJ@01?m3XP03ocbP00?o=9d00ol[VP03ob:G00?o69<0
0ol>S`03o`B;00?o08L50ol0P`h3o`1n60?o07XP1?l0MBP3o`1`;`?o06`f0ol0Ic/3o`1S@0?o05m4
0ol0FdP3o`1GBP?o05=<0ol0D4h3o`1;C@Co04E:0ol0?dL3o`0jA@?o03M30ol0<d83o`0a@0?o02lo
0ol0;Sl6o`0]?P?o02hn0ol0;cl4o`0a@0?o03=20ol0=d@3o`0lAP?o04990ol0BT`3o`1@CP?o05E;
0ol0FTP3o`1P@`?o06Hm0ol0KC@4o`1d:@?o07`K0ol0Q0/3o`J<00?o6Y@00ol^V`03od2Q00?oCjH0
1_mGZ003odfU00?o>Il01?lMU@03o`280`?o07LU0ol0I3l3o`1@C@?o02/m0ol04b`3o`0780?o008J
0ol00a/3o`0:90Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o07HW0ol0
Ic`3o`1EB`?o03I30ol06S83o`0;9@?o00@L0ol00QT3o`036`?o00LQ0ol04B/4o`0Q=`?o03U40ol0
DTd3o`1P@`?o06hc0ol0NR03o`242`?o2Hd00olMU@03obnK00?o?J000om8Y004oe2V00?oEZP00omI
Z@06oeZY00?oF:P00omFZ003oeBW00?oDJH00om?YP03odfU00?oBj@01?m:Y003odVT00KoB:@00om9
Y003odZT00?oBjD00om=Y@03odnV00?oDJH00omCY`04oeJX00?oEjP00omIZ@03oeZY00WoFjT00omI
Z@03oeNX00?oDjL00om?YP03odVT00Co@j800ollX003ocBM00?o:iX00olRU`03oaRC00?o3Xl00ol4
R`03o`271@?o08<>0ol0OQP3o`1j80Co07DX0ol0L2l3o`1/=P?o06Lk0ol0Hd03o`1OA0?o05]80ol0
EdX3o`1CC0?o051>0ol0Bdd4o`15BP?o03m70ol0>TD3o`0g@`?o03=20ol0<D03o`0_?`?o02ho1_l0
;Ch3o`0^?P?o02lo1?l0<D03o`0c@P?o03M40ol0?4H3o`12B@?o04Y<0ol0D4h3o`1EB`?o05Y80ol0
H4<3o`1V?@?o06dd1?l0M2T3o`1l6`?o08@;0ol6S003oaZD00?o;Y/00om0X@03odnV00KoEjP00om=
Y@03ocVO00Co7ID00ol0R0<3o`1g9@?o06@o0ol0D4d3o`0[?@?o01</0ol01b03o`026P?o00<K0ol0
2R@7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1W?0?o05=<0ol0;cl3
o`0E;P?o00PR0ol00a/3o`026P?o00DN0ol03BP3o`0M=@?o03Q41?l0E4`3o`1T?`?o07@Y0ol0P`h3
o`n@00?o;I/00om9Y003of6[00?oM;000on2]003oh^f00?oT;P01?nB^003oi6h00?oSKL00on9]P03
oh>d00?oO[<00omh/@03og>`00?oKZl00omZ[P03ofN]00?oIJ`01?mS[003of>[00?oHj`00omT[003
ofJ/00?oJJd00om/[P03og2_00?oM;000omi/P03ogfc00CoP[@00on6]@03ohZf00?oS[L00onA^003
oi:h00?oTkP00onB^003oi2h00?oSKL00on8]P03oh6d00CoNK800om_[`03ofB/00?oF:P00om;Y003
ocjP00?o<9`00olRU`03oaBA00?o1X`00ol0Q`H3o`214PCo07/M0ol0MRL3o`1`<0?o06Xg0ol0ICh3
o`1P@`?o05]70ol0ET/3o`1BC@?o04e>0ol0A4X4o`0mAP?o03M30ol0<D03o`0]?P?o02Tl0ol09SX3
o`0T>@?o028g0ol08CL9o`0P=PCo024g0ol08SP3o`0U>@?o02Pk0ol0;3d3o`0a@0?o03Q40ol0@4P3
o`1;C@?o059=0ol0FDT3o`1P@`Co06Pk0ol0L2l3o`1i80?o08<>0ol8S@03ob:G00?o?Z000omJZ@03
og>`00?oQKD00on?]`03oh^f00CoN[800omJZ@03obnK00?o0HX00ol0MRL3o`1P@`?o04=90ol07C@3
o`0:9@?o00<K0ol00aX7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1W
?0?o05=<0ol0;cl3o`0E;P?o00PR0ol00a/3o`026P?o00DN0ol03BP3o`0M=@?o03Q41?l0E4`3o`1T
?`?o07@Y0ol0P`h3o`n@00?o;I/00om9Y003of6[00?oM;000on2]003oh^f00?oT;P01?nB^003oi6h
00?oSKL00on9]P03oh>d00?oO[<00omh/@03og>`00?oKZl00omZ[P03ofN]00?oIJ`01?mS[003of>[
00?oHj`00omT[003ofJ/00?oJJd00om/[P03og2_00?oM;000omi/P03ogfc00CoP[@00on6]@03ohZf
00?oS[L00onA^003oi:h00?oTkP00onB^003oi2h00?oSKL00on8]P03oh6d00CoNK800om_[`03ofB/
00?oF:P00om;Y003ocjP00?o<9`00olRU`03oaBA00?o1X`00ol0Q`H3o`214PCo07/M0ol0MRL3o`1`
<0?o06Xg0ol0ICh3o`1P@`?o05]70ol0ET/3o`1BC@?o04e>0ol0A4X4o`0mAP?o03M30ol0<D03o`0]
?P?o02Tl0ol09SX3o`0T>@?o028g0ol08CL9o`0P=PCo024g0ol08SP3o`0U>@?o02Pk0ol0;3d3o`0a
@0?o03Q40ol0@4P3o`1;C@?o059=0ol0FDT3o`1P@`Co06Pk0ol0L2l3o`1i80?o08<>0ol8S@03ob:G
00?o?Z000omJZ@03og>`00?oQKD00on?]`03oh^f00CoN[800omJZ@03obnK00?o0HX00ol0MRL3o`1P
@`?o04=90ol07C@3o`0:9@?o00<K0ol00aX7ooooo`7o00000Oooool001gooooo00?o0000oooooooo
ool01Oooool3o`1W?0?o05=<0ol0;cl3o`0E;P?o00PR0ol00a/3o`026P?o00DN0ol03BP3o`0M=@?o
03Q41?l0E4`3o`1T?`?o07@Y0ol0P`h3o`n@00?o;I/00om9Y003of6[00?oM;000on2]003oh^f00?o
T;P01?nB^003oi6h00?oSKL00on9]P03oh>d00?oO[<00omh/@03og>`00?oKZl00omZ[P03ofN]00?o
IJ`01?mS[003of>[00?oHj`00omT[003ofJ/00?oJJd00om/[P03og2_00?oM;000omi/P03ogfc00Co
P[@00on6]@03ohZf00?oS[L00onA^003oi:h00?oTkP00onB^003oi2h00?oSKL00on8]P03oh6d00Co
NK800om_[`03ofB/00?oF:P00om;Y003ocjP00?o<9`00olRU`03oaBA00?o1X`00ol0Q`H3o`214PCo
07/M0ol0MRL3o`1`<0?o06Xg0ol0ICh3o`1P@`?o05]70ol0ET/3o`1BC@?o04e>0ol0A4X4o`0mAP?o
03M30ol0<D03o`0]?P?o02Tl0ol09SX3o`0T>@?o028g0ol08CL9o`0P=PCo024g0ol08SP3o`0U>@?o
02Pk0ol0;3d3o`0a@0?o03Q40ol0@4P3o`1;C@?o059=0ol0FDT3o`1P@`Co06Pk0ol0L2l3o`1i80?o
08<>0ol8S@03ob:G00?o?Z000omJZ@03og>`00?oQKD00on?]`03oh^f00CoN[800omJZ@03obnK00?o
0HX00ol0MRL3o`1P@`?o04=90ol07C@3o`0:9@?o00<K0ol00aX7ooooo`7o00000Oooool001gooooo
00?o0000ooooooooool01Oooool3o`1@CP?o02Tl0ol04B/3o`067`?o008J0ol00a/3o`098`?o01L`
0ol0<D03o`1CC0?o06Hm1?l0NB83o`6:00?o:IT00omCY`03ogVb00?oVKX00onb`003ol?400?oakl0
0oo7_@03olNn00?oa/401?o4a003ok[200?o[kl00onU_@03oiZj00?oTKP00on8]P03oh6d00?oNk80
0omf/@03og>`00?oLJl01?m`[`03og6_00?oLk000omf/@03ogZb00?oP;<00on6]@03ohfg00?oU;T0
0onL^`03ojFm00Co[Kl00one`@03okg300?oa<@00oo6`@03olNo00?oakd00oo8_@03olNm00?oakl0
0oo6`P03ol7400Co]l400on[_P03oifk00?oSKL00omk/P03ofV]00?oEZP00om3XP03oc2L00?o7YD0
0ol<S`03o`280`Co084B0ol0NQl3o`1c:`?o06dd0ol0ISd3o`1P@`?o05Y80ol0ED`3o`1?CP?o04E:
0ol0?4H4o`0d@P?o02dn0ol09c/3o`0R>0?o01le0ol06c<3o`0I<@?o01L`0ol05Bl3o`0D;P[o01@]
0ol052h3o`0F;`?o01L`0ol06S83o`0M=0?o024g0ol09SX3o`0]?P?o03I30ol0@TT3o`1?CPCo05M:
0ol0Gd@3o`1Y>@?o07<[0ol0OQL3o`6:00?o89H00om4XP03ofV]00?oS[L00on__`03olG400Coa/00
0oo3a003oj:l00?oLJl00olgWP03o`280P?o070`0ol0ET/3o`0/?P?o010Z0ol01Ah7ooooo`7o0000
0Oooool001gooooo00?o0000ooooooooool01Oooool3o`1@CP?o02Tl0ol04B/3o`067`?o008J0ol0
0a/3o`098`?o01L`0ol0<D03o`1CC0?o06Hm1?l0NB83o`6:00?o:IT00omCY`03ogVb00?oVKX00onb
`003ol?400?oakl00oo7_@03olNn00?oa/401?o4a003ok[200?o[kl00onU_@03oiZj00?oTKP00on8
]P03oh6d00?oNk800omf/@03og>`00?oLJl01?m`[`03og6_00?oLk000omf/@03ogZb00?oP;<00on6
]@03ohfg00?oU;T00onL^`03ojFm00Co[Kl00one`@03okg300?oa<@00oo6`@03olNo00?oakd00oo8
_@03olNm00?oakl00oo6`P03ol7400Co]l400on[_P03oifk00?oSKL00omk/P03ofV]00?oEZP00om3
XP03oc2L00?o7YD00ol<S`03o`280`Co084B0ol0NQl3o`1c:`?o06dd0ol0ISd3o`1P@`?o05Y80ol0
ED`3o`1?CP?o04E:0ol0?4H4o`0d@P?o02dn0ol09c/3o`0R>0?o01le0ol06c<3o`0I<@?o01L`0ol0
5Bl3o`0D;P[o01@]0ol052h3o`0F;`?o01L`0ol06S83o`0M=0?o024g0ol09SX3o`0]?P?o03I30ol0
@TT3o`1?CPCo05M:0ol0Gd@3o`1Y>@?o07<[0ol0OQL3o`6:00?o89H00om4XP03ofV]00?oS[L00on_
_`03olG400Coa/000oo3a003oj:l00?oLJl00olgWP03o`280P?o070`0ol0ET/3o`0/?P?o010Z0ol0
1Ah7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1@CP?o02Tl0ol04B/3
o`067`?o008J0ol00a/3o`098`?o01L`0ol0<D03o`1CC0?o06Hm1?l0NB83o`6:00?o:IT00omCY`03
ogVb00?oVKX00onb`003ol?400?oakl00oo7_@03olNn00?oa/401?o4a003ok[200?o[kl00onU_@03
oiZj00?oTKP00on8]P03oh6d00?oNk800omf/@03og>`00?oLJl01?m`[`03og6_00?oLk000omf/@03
ogZb00?oP;<00on6]@03ohfg00?oU;T00onL^`03ojFm00Co[Kl00one`@03okg300?oa<@00oo6`@03
olNo00?oakd00oo8_@03olNm00?oakl00oo6`P03ol7400Co]l400on[_P03oifk00?oSKL00omk/P03
ofV]00?oEZP00om3XP03oc2L00?o7YD00ol<S`03o`280`Co084B0ol0NQl3o`1c:`?o06dd0ol0ISd3
o`1P@`?o05Y80ol0ED`3o`1?CP?o04E:0ol0?4H4o`0d@P?o02dn0ol09c/3o`0R>0?o01le0ol06c<3
o`0I<@?o01L`0ol05Bl3o`0D;P[o01@]0ol052h3o`0F;`?o01L`0ol06S83o`0M=0?o024g0ol09SX3
o`0]?P?o03I30ol0@TT3o`1?CPCo05M:0ol0Gd@3o`1Y>@?o07<[0ol0OQL3o`6:00?o89H00om4XP03
ofV]00?oS[L00on__`03olG400Coa/000oo3a003oj:l00?oLJl00olgWP03o`280P?o070`0ol0ET/3
o`0/?P?o010Z0ol01Ah7ooooo`7o00000Oooool000Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`05ooooo`?o02<h0ol03BL3o`04
7@?o00<J0ol01Ah3o`0@:P?o02Hj0ol0CTh3o`1T?`?o07XP0ol<SP04od2Q00?oMK400onX_P03olRl
00?ocjT00ooDW003omJF00?oei@00ooFU`03omBM00?odJH00oo=[`04olVi00?oaL<00ong`@03ojNm
00?oVKX00on=]`03oh>d00?oNk800ome/@03og6_00KoKZl01?m_[`03og:`00?oM[400oml/P03oh>d
00?oS;L00onF^@03oj6l00?o[Kl00onj`P03olG300Cob;`00oo;]003olj]00?od:H00ooCX003omBK
00?oeYL01_oGU003omJE00?oeIP00ooDW@04om6T00?ocZd00oo:]`03olG200?o/l000onK^P03oh:d
00?oJ:d00om?YP03ocNN00?o89H00ol;SP04o`261`?o07hH0ol0MRH3o`1^<`?o06Ll0ol0Gd@3o`1H
B@?o059=0ol0BD`3o`0mAP?o03=11?l0:Sd3o`0S>0?o01he0ol06C43o`0E;`?o018/0ol042X3o`0>
:@?o00dW0ol032H@o`0;9@?o00`V0ol03BL3o`0>:@?o010Z0ol04bd3o`0G<0?o01`d0ol093T3o`0]
?PCo03U50ol0BT`3o`1EB`?o05m40ol0JcL3o`1g9@?o08@;0olFTP03ocnQ00?oKZl00onP_003olNo
00Cod:P00ooDV`03omBL00?ocZ`00onn``03ogZb00?o;i/00ol0P1@3o`1S@0?o04180ol06347oooo
o`7o00000Oooool000Sooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool01Oooool3o`0S>0?o00dW0ol011d3o`036P?o00DN0ol042X3o`0V
>P?o04i>0ol0I3l3o`1j80?o38h01?m0X@03ogFa00?oZ;h00oo8_003olnY00?oe9`00ooFUP03omND
00?oeYL00ooDW@03om6V00?ocJl01?o9^@03olG300?o]l400onW_@03oiVj00?oSKL00on3]003og^b
00?oMK400oma[`06ofj_00CoKjl00omb/003ogJa00?oO;800on3]003ohbg00?oU[T00onQ_003ojfo
00?o^/800oo5``04olRl00?obk@00oo>[@03om2V00?odj000ooDV`03omJG00Koei@00ooFU@03omFH
00?oe9d01?oAY003olj]00?ob[L00oo5`P03ok?000?oVkX00on2]003ofR]00?oCjH00olgWP03ob2F
00?o2hh01?l0QPL3o`1n60?o07HV0ol0KS<3o`1W?0?o05m40ol0F4T3o`1BC@?o04U<0ol0?DH3o`0c
@@Co02Xm0ol08cP3o`0N=@?o01Ta0ol05Bl3o`0B;0?o010Z0ol03RT3o`0=9`?o00`V4?l02bD3o`0<
9P?o00dW0ol03RT3o`0@:P?o01<]0ol05c03o`0L=0?o02@i0ol0;Ch4o`0iA@?o04Y<0ol0ED/3o`1O
A0?o06/g0ol0MbD3o`242`?o5Y800oloX@03ofj_00?oX;`00oo7_`04om2X00?oe9/00ooDW003olj/
00?o_/<00omj/P03obnK00?o080D0ol0Hd03o`10B0?o01Pa1oooool1o`00007ooooo0005o`0000Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo0ol08cP3o`0=9`?o00@M0ol00aX3o`057P?o010Z0ol09SX3o`1>CP?o06@o0ol0NR03o`b>00Co
@:400ome/@03ojRn00?ob;`00oo?Z@03omBL00?oeYH00ooGU003omJG00?oe9d00ooAYP03olf_00Co
bKT00oo5``03okO100?oYkd00onI^P03ohfg00?oPk@00omk/P03ogFa00?oLJl01_m^[`04ofn_00?o
L[000omf/@03ogbb00?oPk@00on<]`03oiJi00?oXK`00on]_`03ok[200?oaL<01?o8_003ol^d00?o
cZd00oo@YP03om>P00?oe9/00ooFU`06omND00?oeYD00ooEV003omBM00CodJ@00oo>[@03olZg00?o
aL800onc`003oi^j00?oP[@00omX[@03odnV00?o=ih00olPUP03o`^>00Co08H70ol0OQP3o`1f9P?o
06hc0ol0Ic`3o`1OA0?o05Q90ol0DTd3o`19C0?o03e60ol0<d44o`0Z?@?o02<h0ol07SD3o`0I<@?o
01D_0ol04R`3o`0@:P?o00hY0ol03BL3o`0<9Q3o00/U0ol032H3o`0=9`?o00hY0ol042X3o`0C;@?o
01L`0ol073@3o`0T>@?o02dn1?l0>DD3o`1:C0?o05E;0ol0Gd@3o`1[=`?o07LU0ol0Q0/3oaJB00?o
?j400om^[`03oj2l00?oakl01?o@Z003omBK00?oe9`00oo>[003okk300?oN[800ol_V`03o`2050?o
06=00ol0@4P3o`0H<@Oooooo0Ol00001ooooo`002Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo0ol00005ooooo`?o00XT0ol011`3o`036`?o00TS0ol06C43o`0iA@?o05]7
0ol0Lb/3o`::00?o?j400omo/`04okc300?ocZ`00ooGT`03omf200KoggX00ooMO`03omZ900?oeYH0
0ooAY003olbb00?oa/001?ne`@03oj2l00?oSKL00omm/`03ofn_00?oHj`00omJZ@03oeBW00?oCjH0
0om=Y@03odbU00?oCJD01?m@YP03oeFW00?oG:T00omT[003ofj_00?oN[800on7]@03oiJi00?oY[d0
0ong`@03olK200Cob[P00oo>[@03om:S00?oeIT00ooHT003om^700?ogH400ooOO003ommi00?oh7T0
0ooON`03omf000CofhP00ooHTP03om>N00?ocZ`00oo9^P03ok[200?oWK/00omn/`03of6[00?oA:80
0olYV@03oa2@00Co08L50ol0OQP3o`1e:0?o06`e0ol0I3l3o`1LA`?o05A<0ol0Bdd3o`0mAP?o0350
0ol09c/4o`0O=P?o01Tb0ol052h3o`0@:P?o00dX0ol02bD3o`098`?o00PR0ol01b06o`067a3o00DN
0ol01Al3o`067`?o00LP0ol02283o`0:90?o00`V0ol03bT3o`0D;@Co01Xb0ol08cP3o`0_?`?o0418
0ol0DTd3o`1MA@?o06Xh0ol0NB83o`280`?o9IP00omGZ003oi2h00Coa/400ooBXP03omV=00?og8D0
0ooIS@03om2X00?o//000omHZ003o`N<00?o06hb0ol0DDd5ooooo`?o00000Oooool000[ooooo00?o
0000ooooooooool01Oooool4o`0000Oooooo00?o0000ooooooooool01Oooool3o`0:90?o00@L0ol0
0a/3o`098`?o01Ta0ol0>DD3o`1KA`?o07<[0ol2RP03ocnQ00?oOk<01?nl``03olj/00?oei<00ooM
PP06ommj00?ogGl00ooJR@03omJF00?odJ@00oo</P03olK000Co]L400onP_003ohfg00?oOK<00om_
[`03of>/00?oFZT00omDY`03odnV00?oCJD00om<Y@03odfU00CoD:H00omEY`03oebY00?oI:`00om^
[`03ogZb00?oQkD00onF^@03ojJm00?o]l400oo6`P04olZh00?ocZd00ooBX`03omFI00?of9000ooK
Q`03omf100?ogg`00ooON@03on1i00?ogg/00ooMP004om^800?of9800ooCWP03olj/00?obKX00onj
`P03oifk00?oO[<00omQZ`03odBR00?o:IT00ol@T004o`271@?o07hH0ol0MBP3o`1/=@?o06@o0ol0
G4L3o`1DC0?o04]=0ol0?DH3o`0a@0?o02Lk1?l07cH3o`0I<P?o01@^0ol042X3o`0=:0?o00/U0ol0
2B<3o`088P?o00LP1_l01Ql@o`057P?o00DO0ol01Ql3o`0780?o00PR0ol02R@3o`0<9P?o00lY0ol0
52d4o`0J<P?o02<h0ol0;cl3o`10B0?o059=0ol0GDD3o`1Z>0?o07TR0ol0R0<3obFH00?oEjP00on@
^004olK100?odZ800ooIS@03omb500?ofHd00oo@Z003ok;000?oF:P00ol7S003o`1^<P?o055=1ooo
ool1o`00007ooooo0006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Gooooo0ol02R@3o`0470?o00<K0ol02B<3o`0I<@?o03U50ol0
FdL3o`1c:`?o0XX00oloX@03ognc00Co_<<00oo>[003omNC00?ogH801_oONP03omeo00?ofXT00ooF
UP03om6T00?oc;800oo6`004okG100?oX;`00on=]`03ogfc00?oKjl00omS[003oeZY00?oE:L00om?
YP03odfU00?oC:D00om=Y@04oe2V00?oEJL00omLZ@03ofB/00?oKZl00omj/P03ohNe00?oU[T00onV
_@03okO100?oa/801?o:^003olj]00?odZ<00ooEV@03omR@00?ofhL00ooMP@03omml00?oggT00ooP
N@03ommk00?ogH001?oKR003omRB00?odih00oo>[003olVj00?o^/800onM^`03ogjc00?oHJ/00om4
XP03obVI00?o49001?l0Q`D3o`1n60?o07DX0ol0K3D3o`1T?`?o05a70ol0E4`3o`1;C@?o03e60ol0
<D03o`0W>`Co01lf0ol06C83o`0D;P?o010Z0ol03BP3o`0;9@?o00TS0ol02283o`0780Ko00HO4?l0
1Ah3o`057`?o00HO0ol01b03o`088P?o00XT0ol032H3o`0?:@?o01@]1?l06S83o`0S>0?o02lo0ol0
@4P3o`1BC@?o05e50ol0JSP3o`1i8P?o08P30olUV003oeNX00?oT;P01?o6`@03om:R00?ofHd00ooL
Q@03omV=00?od:P00onb`003oeRX00?o1h`00ol0KS83o`1AC@Oooooo0Ol00001ooooo`001_ooool5
o`0000Oooooo1Ol00006ooooo`03o`000?oooooooooo00Gooooo0ol011`3o`057P?o00dX0ol093T3
o`1?CP?o06Pj0ol0PQ43ob^J00?oM;000oo0``03om:R00Cog8D00ooRL003onEU00?oiV@00ooTJ`03
ommi00?ofX/00ooCWP03olf`00?oaL800on[_P03oi2h00CoN;400omS[003oe:W00?oA:800olhWP03
obnK00?o:9T00olTU`03ob6G00?o8IH00olRU`03obFH00Co:YX00ol`W003ocVO00?o@j800om?YP03
oejZ00?oKZl00on0/`03oi>h00?oZ;h00ono``04olRk00?ocZh00ooCX003omNC00?ofhH00ooONP03
on9`00?oi6P00ooVH`03onMQ00?oiV800ooUIP04on=^00?oggT00ooKQ`03omJG00?ocjT00oo8^`03
ok?000?oT;P00om^[`03odfU00?o;Y/00olBT@04o`271P?o07dK0ol0Lb`3o`1Y>@?o06130ol0EdX3
o`1?CP?o03m70ol0<D03o`0V>P?o01dd1?l05Rl3o`0A:`?o00dW0ol02R@3o`088P?o00HP0ol01Ah3
o`047@?o00@L0ol00a/6o`036Q3o008J1_l00aX3o`036`?o00@L0ol011d3o`057`?o00LQ1?l02R@3
o`0>:0?o01<]0ol06c<3o`0X>`?o03U40ol0D4h3o`1MAP?o06/g0ol0Nad3o`N=00?o>9l01?me/@03
okO100?ocjT00ooJRP03on1g00?oh7H00ooJR`03olZh00?oO[<00olSU`03o`1h8`Oooooo0Ol00001
ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o00@L0ol01Ah3o`0=:0?o02@i0ol0Cdh3o`1X
>P?o088A0ol[VP03ogB`00?o`<<00ooBXP04omb500?ohW000ooUI@03onIT00?oi6/00ooON@03omZ;
00?odih00oo=/003olG200?oZkh00on@^004ogRa00?oHj`00omBY`03odBR00?o>9h00ol_V`03obRI
00?o99L00olQU`03ob6F00?o8YL00olUV004obZJ00?o<9`00oliW`03od>R00?oCjH00omNZP03ofj_
00?oP;<00onC^003ojRn00?o_l<01?o8^`03olj^00?odj000ooGT`03om^600?oggX00ooRL003onAX
00?oiV<00ooWH@03onIR00?oiFH01?oSKP03ommi00?ofhL00ooFU`03olnY00?ob;/00onc`003oi2h
00?oKZl00om=Y@03objK00?o4Y401?l0Q`H3o`1m6`?o07</0ol0JCT3o`1P@`?o05M:0ol0Cdh3o`0o
A`?o03500ol09SX3o`0M=0Co01H_0ol04B/3o`0=9`?o00XT0ol02283o`0680?o00DN0ol011d3o`04
70?o00<K1_l00aX@o`026PKo00<J0ol00a/3o`0470?o00@M0ol01Al3o`078@Co00XT0ol03RP3o`0C
;@?o01/c0ol0:3/3o`0iA0?o051>0ol0GDH3o`1[=`?o07/M0ol7S@03ocRO00CoMK400ong`@03olnY
00?ofXX00ooPM`03on1f00?ofX/00oo:^003ogjc00?o8iL00ol0N2<7ooooo`7o00000Oooool001go
oooo00?o0000ooooooooool01Oooool3o`0470?o00DN0ol03BP3o`0T>@?o04m>0ol0J3X3o`224@?o
:iX00omd/003ol3300?odZ801?oLQ@03on9`00?oiFD00ooVI003onA[00?oggT00ooJR`03om>N00?o
cK000oo5`P03oj^n00?oT;P01?mh/@03of>/00?oDZL00om4XP03ocRN00?o;i/00olXV@03obBG00?o
8IL00olQUP03ob:G00?o9IP01?lZVP03oc2L00?o>Il00om3XP03odnV00?oGZX00om^[`03oh2c00?o
TkP00onX_P03oko300Cob;/00oo>[P03om>P00?oei<00ooKQP03ommj00?ohW000ooTJ003onIS00?o
if400ooVHP03onEV00Cohfh00ooON@03om^700?oeYL00oo?Z@03olRk00?o/l000on@^003ofj_00?o
CJD00ol^V`03oa:A00Co08L60ol0OA/3o`1c;0?o06Ti0ol0H4<3o`1GBP?o04m>0ol0?dL3o`0a@0?o
02Hj0ol07C@4o`0F;`?o014[0ol03BL3o`0:90?o00PR0ol01R03o`057P?o00@M0ol011`3o`036`Ko
00<J4?l00QX6o`036P?o00<K0ol011`3o`047@?o00DO0ol01b44o`0:90?o00hX0ol04bd3o`0K<`?o
02Pk0ol0>D@3o`1@CP?o05e60ol0JcL3o`1k7@?o1hd00olhW`04ogFa00?o]l400oo?Z@03omZ:00?o
h7L00ooPMP03omZ;00?ob[P00omn/`03ob>G00?o07PS1oooool1o`00007ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo0ol01b43o`0D;@?o03910ol0FTP3o`1e:0?o49000omJZ@03ojbo00?odJD0
0ooON`03onMO00Coje000oo/C`03onUG00?oiFL00ooNO@03omJF00?ocZh00oo5a003oj6l00?oP;<0
0omSZ`03odZT00Co=Id00olTV003oaNC00?o38h00ol4R`03o`290@?o08L51_l0QPP3o`261`?o08L5
0ol0R@04o`B;00?o38l00olETP03ob6F00?o;Y/00olnX003oe2V00?oIJ`00omk/P03oiBi00?o[kl0
1?o6`@03olba00?odZ000ooHS`03omio00?ohVl00ooWH@03onYF00?ok4d00oo]B003oni800?okD/0
1?o[D`03onMO00?ohfh00ooMP@03omJE00?ocj/00oo6`@03oj>l00?oNk800omFZ003oc>M00?o5940
1?l0QPL3o`1k7@?o070_0ol0ISd3o`1LA`?o059=0ol0A4X3o`0d@P?o02Lj0ol07C@3o`0E;PCo00lZ
0ol02bD3o`088P?o00HO0ol01Ad3o`0470?o00<K0ol00QXCo`026@Wo008J4_l00QT3o`036PCo00<K
0ol011d3o`0680?o00TT0ol03RT3o`0F;`?o028h0ol0=D83o`1?CP?o05e50ol0KS<3o`2050Co6I@0
0omEZ003oiZj00?obk<00ooIS003on=^00?oiV800ooPN003om:R00?oXk`00om0X@07ooooo`7o0000
0Oooool001gooooo00?o0000ooooooooool01Oooool3o`078@?o01@]0ol0<T43o`1JB0?o07DX0ol@
T003oeZY00?o[;l00ooAY@03ommk00?oiel01?o[D003ona?00?ojEL00ooUI`03omim00?oeYH00oo>
[P03olG400?oXK`00on0/`03of>[00?oBZ@01?leW@03obBH00?o5i<00ol<SP03o`B;00?o08T10ol0
Q`D6o`2620?o08H70ol0Q`D3o`2900Co18/00ol<S`03oaFB00?o8IH00ol^V`03ocjP00?oD:H00omU
[003og^b00?oU;T00on__`04olK100?oc;400ooBX003omR?00?ogWl00ooRK`03onMQ00?ojUH00oo/
C@03one800?okTP00oo]B`04on]C00?oiel00ooSKP03omf100?oeYD00oo?Z`03olK100?oXk`00omk
/P03oeJX00?o<id00olDT@04o`261`?o07/M0ol0L2l3o`1V?@?o05a70ol0DTd3o`14BP?o03A20ol0
9cX3o`0M=0?o01D^1?l03bX3o`0;9@?o00PR0ol01Ql3o`057@?o00@L0ol00a/3o`026Q?o008I2Ol0
0QXBo`026@?o00<J1?l00a/3o`047@?o00HP0ol02B@3o`0>:@?o01H_0ol08SP3o`0e@P?o04m>0ol0
GDD3o`1^<`?o080D1?lIU003oeFX00?oV[X00oo;/`03omV<00?ohfh00ooVHP03on1h00?odZ800onS
_003od2Q00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o00LQ0ol052d3
o`0b@@?o05Y80ol0MBP3oa2@00?oFZT00on/_`03om6U00?ogg/00ooWG`04on]@00?ok4l00ooYE`03
onEW00?ogWd00ooFUP03olj^00?oaL@00onQ_003oh2c00?oHj/00om:Y004ocFM00?o99P00olGT`03
o`b>00?o18/00ol0R@43o`271@Ko08H80ol0QPL3o`271@?o08T01?l4R`03o`b?00?o5I800olQUP03
objK00?o?Z000om@YP03ofF/00?oNk800onD^@03ojno00Coa/400oo</@03om:P00?of8l00ooNO`03
on9_00?oif400ooZEP03ona=00?okDP00oo^B003one;00Coje<00ooWG`03on=^00?ogH400ooFU@03
oln[00?oa/400onS_003og^b00?oEZP00olcW@03oaBA00Co08H70ol0Nad3o`1`;`?o06Hm0ol0G4L3
o`1BC@?o04A:0ol0=483o`0W>P?o01dd0ol05Bh4o`0?:P?o00/U0ol02283o`067`?o00DM0ol011`3
o`036`?o008J4ol00QT9o`026Q;o008I0ol00aX4o`036`?o00@M0ol01R03o`0990?o00hY0ol05Rl3
o`0R>0?o03E20ol0Cdh3o`1MA@?o06hc0ol0P1@4oaVD00?oEJP00onJ^P03ol^c00?ofH`00ooSKP03
onIR00?oh7P00ooBXP03oj>l00?o@:401oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo
00Gooooo0ol01b43o`0D;@?o03910ol0FTP3o`1e:0?o49000omJZ@03ojbo00?odJD00ooON`03onMO
00Coje000oo/C`03onUG00?oiFL00ooNO@03omJF00?ocZh00oo5a003oj6l00?oP;<00omSZ`03odZT
00Co=Id00olTV003oaNC00?o38h00ol4R`03o`290@?o08L51_l0QPP3o`261`?o08L50ol0R@04o`B;
00?o38l00olETP03ob6F00?o;Y/00olnX003oe2V00?oIJ`00omk/P03oiBi00?o[kl01?o6`@03olba
00?odZ000ooHS`03omio00?ohVl00ooWH@03onYF00?ok4d00oo]B003oni800?okD/01?o[D`03onMO
00?ohfh00ooMP@03omJE00?ocj/00oo6`@03oj>l00?oNk800omFZ003oc>M00?o59401?l0QPL3o`1k
7@?o070_0ol0ISd3o`1LA`?o059=0ol0A4X3o`0d@P?o02Lj0ol07C@3o`0E;PCo00lZ0ol02bD3o`08
8P?o00HO0ol01Ad3o`0470?o00<K0ol00QXCo`026@Wo008J4_l00QT3o`036PCo00<K0ol011d3o`06
80?o00TT0ol03RT3o`0F;`?o028h0ol0=D83o`1?CP?o05e50ol0KS<3o`2050Co6I@00omEZ003oiZj
00?obk<00ooIS003on=^00?oiV800ooPN003om:R00?oXk`00om0X@07ooooo`7o00000Oooool001go
oooo00?o0000ooooooooool01Oooool3o`0K<`?o04990ol0I403o`214`?o=Yh00on<]`03olbb00?o
gH800ooYFP03oo0n00?olSP01?o_@@03onYE00?ohfl00ooJR`03olnY00?oaL@00onI^P03og6`00?o
D:H00olcW@03oabD00?o2Hd01?l0Q`D3o`214@?o07dJ0ol0NB43o`1f9P?o07@Y2Ol0Lb/3o`1e:@?o
07HV0ol0NB44o`1l6`?o080D0ol0Q@X3o`2:00?o3Xl00olNUP03oc:L00?oB:<00omPZ`03ogbb00?o
V[X01?nj`P03olZg00?odJ<00ooIS`03ommj00?oiFH00ooZE003onm400?olSL00ood;`03ooD/00?o
m2h01?ob=P03onm200?ojU<00ooTJ003omf000?oeIX00oo;]003okK100?oRKH00omNZP03ocNN00?o
5I801?l0QPP3o`1i80?o06hc0ol0HT43o`1HBP?o04e>0ol0>D@3o`0Z?0?o01he0ol05Bh3o`0?:@Co
00XT0ol01b43o`057P?o00@L0ol00aX9o`026@?o008J0ol00aX3o`036`?o00<L1?l011`3o`047@?o
00DM2Ol01Ah3o`057@?o00@M0ol011`6o`036`?o008J1ol00QT3o`026P?o00<K0ol011d3o`078@?o
00`V0ol04bd3o`0P=P?o03A20ol0D4h3o`1P@`Co07<[0ol0R0<3oc>M00?oN[800oo6`@03omNC00?o
i6X00ooXG@03onAY00?of8l00oo5a007ooooo`7o00000Oooool001gooooo00?o0000ooooooooool0
1Oooool3o`0K<`?o04990ol0I403o`214`?o=Yh00on<]`03olbb00?ogH800ooYFP03oo0n00?olSP0
1?o_@@03onYE00?ohfl00ooJR`03olnY00?oaL@00onI^P03og6`00?oD:H00olcW@03oabD00?o2Hd0
1?l0Q`D3o`214@?o07dJ0ol0NB43o`1f9P?o07@Y2Ol0Lb/3o`1e:@?o07HV0ol0NB44o`1l6`?o080D
0ol0Q@X3o`2:00?o3Xl00olNUP03oc:L00?oB:<00omPZ`03ogbb00?oV[X01?nj`P03olZg00?odJ<0
0ooIS`03ommj00?oiFH00ooZE003onm400?olSL00ood;`03ooD/00?om2h01?ob=P03onm200?ojU<0
0ooTJ003omf000?oeIX00oo;]003okK100?oRKH00omNZP03ocNN00?o5I801?l0QPP3o`1i80?o06hc
0ol0HT43o`1HBP?o04e>0ol0>D@3o`0Z?0?o01he0ol05Bh3o`0?:@Co00XT0ol01b43o`057P?o00@L
0ol00aX9o`026@?o008J0ol00aX3o`036`?o00<L1?l011`3o`047@?o00DM2Ol01Ah3o`057@?o00@M
0ol011`6o`036`?o008J1ol00QT3o`026P?o00<K0ol011d3o`078@?o00`V0ol04bd3o`0P=P?o03A2
0ol0D4h3o`1P@`Co07<[0ol0R0<3oc>M00?oN[800oo6`@03omNC00?oi6X00ooXG@03onAY00?of8l0
0oo5a007ooooo`7o00000Oooool001gooooo0_l00006ooooo`?o01/c0ol0@TT3o`1T@0?o084C0olf
WP03ohbg00?oc;800ooMPP03onUJ00?ol3h00oob>004onm100?ojUD00ooSK`03omZ;00?ocjT00oo5
a003oiVj00?oLK000om@YP03oc>M00?o79@00ol9S@04o`271@?o084A0ol0OAX3o`1i8@?o07HV0ol0
M2T9o`1c:`?o07DY0ol0MRH3o`1i8@Co07`K0ol0P1@3o`252P?o08X00ol>S`03oajF00?o<Y`00om8
X`03of2[00?oO;800onJ^P04ok[200?ob[L00ooAX`03omV?00?oggX00ooUIP03onYD00?okd@00oob
=`03oo@_00?omB`00ood;P04oo8f00?okd800ooZD`03onAX00?ogH000ooEVP03ol^d00?o]/400on9
]P03oejZ00?o=ih00olETP04o`2620?o07TP0ol0KS<3o`1R@@?o05Q:0ol0CDh3o`0iA0?o02Xl0ol0
7SD3o`0E;P?o00lY1?l02R@3o`078@?o00DN0ol011`3o`036PWo008I0ol00QX3o`036P?o00<K0ol0
0a`4o`0470?o00@M0ol01Ad9o`057P?o00DM0ol011d3o`0470Ko00<K0ol00QX7o`026@?o008J0ol0
0a/3o`047@?o00LQ0ol032H3o`0C;@?o020f0ol0=483o`1@CP?o06131?l0Lb/3o`280`?o<id00omj
/P03olK100?oei<00ooTJP03onQM00?oi6T00ooHS`03olG400Kooooo0_l00001ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`?o051>0ol0K3H3o`2900?oDJH00one`@03omFJ00?ohf`00oo]BP03
oo8h00?olSL00oo]BP04onEW00?ofhP00oo?Z@03oko300?oS;L00omPZ`03ocZO00?o6i@00ol2RP03
o`224@?o07XP0ol0Lb/4o`1]<`?o06Tj0ol0ICh3o`1R@@?o06132Ol0Gd@3o`1P@`?o06910ol0I3l3
o`1W>`Co06/g0ol0L303o`1e:0?o07/N0ol0PA83o`280`?o3i000olTV003ocfP00?oFZT00omi/P04
oibk00?o`/@00oo=/003omFI00?ogH400ooTJP03onYC00?ol4000ood<003ooLT00Kon1h01?og9@03
oo<a00?okd<00ooYFP03on5d00?of9000oo>[003okk300?oSKL00omOZP03ocFM00?o49001?l0P`d3
o`1f9P?o06Xh0ol0GTD3o`1CC@?o04580ol0;Sl3o`0P=`?o01H_0ol03bT3o`0:90Co00LP0ol011d3
o`036`?o008J1_l00QT3o`026P?o00<K0ol011`3o`057P?o00HO0ol01b44o`098`?o00XT0ol02bD3
o`0<9PWo00`W0ol032H3o`0;9@?o00XT0ol02283o`0780Co00DN0ol011d3o`036`?o008J0ol00QT3
o`026P?o00<K0ol01Al3o`0:90?o014[0ol07cD3o`0e@PCo059=0ol0ICh3o`1i80?o3i000omBYP03
ojBm00?odJH00ooNOP03onEW00?oi6T00ooKR007ooooo`7o00000Oooool001gooooo00?o0000oooo
ooooool01Oooool3o`1@CP?o06`f0ol0R@03oe6V00?o]L400ooEVP03on=/00?okDX00oob>003oo8g
00?okDX01?oUI`03om^800?ocjT00ono``03ohbg00?oH:/00oljW`03oa^D00?o0XX00ol0PQ43o`1j
80?o07<[1?l0KC<3o`1Y>P?o06Dn0ol0HT43o`1P@`Wo05m40ol0H4<3o`1R@@?o06@o0ol0Ic/4o`1[
=`?o070`0ol0MBP3o`1k7P?o084B0ol0R0<3o`n@00?o99P00olmX003oeZY00?oNK801?nL^`03ol;4
00?ocK000ooEV@03omf100?oi6X00ooZD`03oo1000?om3000oog9006ooPN00CombD00ooc<@03onm3
00?ojEX00ooQM003omR@00?ocZ`00onn``03ohfg00?oGjX00oleW@03oa2@00Co08<=0ol0MRH3o`1Z
>0?o05i50ol0Ddd3o`11B0?o02ho0ol083L3o`0F;`?o00lY0ol02R@4o`0780?o00@M0ol00a/3o`02
6PKo008I0ol00QX3o`036`?o00@L0ol01Ah3o`067`?o00LQ1?l02B<3o`0:90?o00/U0ol032H9o`0<
9`?o00`V0ol02bD3o`0:90?o00PR0ol01b04o`057P?o00@M0ol00a/3o`026P?o008I0ol00QX3o`03
6`?o00DO0ol02R@3o`0A:`?o01le0ol0=D84o`1BC@?o06Dn0ol0NB03o`n@00?oDZH00onT_@03om6V
00?ogWh00ooUI`03onAY00?ofhP01oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Go
oooo0ol0D4h3o`1/=P?o08T00omAYP03okG100?oeIX00ooSK003one:00?olSP00oob=`03one:00Co
iFL00ooKR003olnY00?o_l<00on<]`03of2[00?o>Yl00olKU003o`::00?o088A0ol0NR03o`1c:`Co
06dc0ol0JCX3o`1U?P?o06910ol0H4<9o`1OA0?o06130ol0HT43o`1T?`?o06Lk1?l0JcL3o`1`<0?o
07DX0ol0Nah3o`214P?o08P30ol?T003obBH00?o?J000omJZ@03ogVb00CoW;/00oo2a003olf`00?o
eIT00ooMP@03onAZ00?ojU<00oo`@003oo@`00?omb@01_oh7P04ooLU00?olc400oo_@`03onUJ00?o
hG@00ooHT003olj/00?o_/<00on=]`03oenZ00?o=Id00ol@T004o`233@?o07HV0ol0JSP3o`1NA@?o
05==0ol0@DP3o`0^?`?o020g0ol05Rl3o`0?:@?o00XT1?l01b03o`047@?o00<K0ol00QX6o`026@?o
008J0ol00a/3o`0470?o00DN0ol01Ql3o`078@Co00TS0ol02R@3o`0;9@?o00`V2Ol032L3o`0<9P?o
00/U0ol02R@3o`088P?o00LP1?l01Ah3o`047@?o00<K0ol00QX3o`026@?o008J0ol00a/3o`057`?o
00XT0ol04B/3o`0O=@?o03E21?l0DTd3o`1U?P?o07TP0ol?T003oe:V00?oY;d00ooAYP03omin00?o
iFL00ooTJ@03om^800Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o078]
0ol>S`03of>/00?oaL<00ooJRP03onIQ00?okDT00oo_@P03ona<00?oiV800ooLQ@04olnZ00?o]l40
0on0]003oe2V00?o9iT00ol6S003o`214P?o07LU0ol0KS<3o`1V?@?o05m40ol0FTP4o`1EB`?o055=
0ol0CTh3o`1:C@?o04M;0ol0AT/3o`17B`?o04U<0ol0C4d3o`1@CP?o059=0ol0ET/4o`1JB0?o05m4
0ol0ICh3o`1[=`?o078]0ol0NB03o`2240?o0X/00olJU003ocFM00?oEJL01?mi/P03oj2l00?oa/80
0oo?Z@03omR?00?ohGD00ooXG003oni400?om3400oog8P03ooTI00?onQL01?oi7003ooHW00?olCX0
0oo[D@03on=]00?ofX/00oo?Z@03ol3300?oS;L00omKZ@03oc2L00?o2Xh01?l0P1@3o`1b;@?o06Dn
0ol0FDT3o`1<C@?o03E30ol09CT3o`0I<@?o010Z0ol02R@3o`0780Co00@M0ol00a/6o`026@?o008J
0ol00a/3o`047@?o00HO0ol02243o`0:90?o00dW0ol03bT4o`0B;0?o01D^0ol06303o`0J<P?o01/c
1_l073@3o`0L<`?o01/c0ol06C43o`0F;`?o01<]1?l042X3o`0=9`?o00XT0ol01b03o`057P?o00<K
0ol00QX3o`026@?o00<J0ol01Ad3o`098`?o014[1?l083H3o`0jA@?o05M:0ol0JcL3o`224@?o:YX0
0omi/P03olK200?oeIP00ooONP03on5d00Oooooo0Ol00001ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`?o078]0ol>S`03of>/00?oaL<00ooJRP03onIQ00?okDT00oo_@P03ona<00?oiV800ooL
Q@04olnZ00?o]l400on0]003oe2V00?o9iT00ol6S003o`214P?o07LU0ol0KS<3o`1V?@?o05m40ol0
FTP4o`1EB`?o055=0ol0CTh3o`1:C@?o04M;0ol0AT/3o`17B`?o04U<0ol0C4d3o`1@CP?o059=0ol0
ET/4o`1JB0?o05m40ol0ICh3o`1[=`?o078]0ol0NB03o`2240?o0X/00olJU003ocFM00?oEJL01?mi
/P03oj2l00?oa/800oo?Z@03omR?00?ohGD00ooXG003oni400?om3400oog8P03ooTI00?onQL01?oi
7003ooHW00?olCX00oo[D@03on=]00?ofX/00oo?Z@03ol3300?oS;L00omKZ@03oc2L00?o2Xh01?l0
P1@3o`1b;@?o06Dn0ol0FDT3o`1<C@?o03E30ol09CT3o`0I<@?o010Z0ol02R@3o`0780Co00@M0ol0
0a/6o`026@?o008J0ol00a/3o`047@?o00HO0ol02243o`0:90?o00dW0ol03bT4o`0B;0?o01D^0ol0
6303o`0J<P?o01/c1_l073@3o`0L<`?o01/c0ol06C43o`0F;`?o01<]1?l042X3o`0=9`?o00XT0ol0
1b03o`057P?o00<K0ol00QX3o`026@?o00<J0ol01Ad3o`098`?o014[1?l083H3o`0jA@?o05M:0ol0
JcL3o`224@?o:YX00omi/P03olK200?oeIP00ooONP03on5d00Oooooo0Ol00001ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`?o078]0ol>S`03of>/00?oaL<00ooJRP03onIQ00?okDT00oo_@P03
ona<00?oiV800ooLQ@04olnZ00?o]l400on0]003oe2V00?o9iT00ol6S003o`214P?o07LU0ol0KS<3
o`1V?@?o05m40ol0FTP4o`1EB`?o055=0ol0CTh3o`1:C@?o04M;0ol0AT/3o`17B`?o04U<0ol0C4d3
o`1@CP?o059=0ol0ET/4o`1JB0?o05m40ol0ICh3o`1[=`?o078]0ol0NB03o`2240?o0X/00olJU003
ocFM00?oEJL01?mi/P03oj2l00?oa/800oo?Z@03omR?00?ohGD00ooXG003oni400?om3400oog8P03
ooTI00?onQL01?oi7003ooHW00?olCX00oo[D@03on=]00?ofX/00oo?Z@03ol3300?oS;L00omKZ@03
oc2L00?o2Xh01?l0P1@3o`1b;@?o06Dn0ol0FDT3o`1<C@?o03E30ol09CT3o`0I<@?o010Z0ol02R@3
o`0780Co00@M0ol00a/6o`026@?o008J0ol00a/3o`047@?o00HO0ol02243o`0:90?o00dW0ol03bT4
o`0B;0?o01D^0ol06303o`0J<P?o01/c1_l073@3o`0L<`?o01/c0ol06C43o`0F;`?o01<]1?l042X3
o`0=9`?o00XT0ol01b03o`057P?o00<K0ol00QX3o`026@?o00<J0ol01Ad3o`098`?o014[1?l083H3
o`0jA@?o05M:0ol0JcL3o`224@?o:YX00omi/P03olK200?oeIP00ooONP03on5d00Oooooo0Ol00001
ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o6I@00oma[`03olNm00?ofXT00ooXG@03ona>
00?oje800ooUIP03omb300?odJH00onj`P04ogbb00?oAj<00olKU003o`261P?o07TP0ol0KS<3o`1T
@0?o05]80ol0Dd`3o`1:C@?o03m70ol0=T<4o`0`@0?o02/m0ol0:3/3o`0V>PKo02Di0ol09SX3o`0X
>`?o02/m0ol0;cl3o`0e@P?o03a61?l0AT/3o`1@CP?o05E;0ol0G4L3o`1S@0?o06/f0ol0M2T3o`1m
6@?o08L40olETP03oc>M00CoEjP00omn/`03ojZn00?obKX00ooCWP03omf200?oiFD00oo]BP03oo<c
00?on2400ook5@03oo`@00Cona<00ooh7P03oo@`00?okDP00ooUIP03om^600?od:H00oo2a003oh^f
00?oF:P00olZVP03o`>;00Co07`K0ol0KS<3o`1P@`?o05A<0ol0@4P3o`0/?@?o01dd0ol04R`3o`0;
9P?o00LQ0ol011d4o`036PKo008I0ol00aX3o`0470?o00DN0ol02283o`0;9@?o00lY0ol04bd3o`0H
<@?o01dd1?l08cP3o`0X>`?o02dn0ol0<T43o`0f@`?o03Q41_l0>TD3o`0iA0?o03I30ol0<T43o`0]
?PCo02Pk0ol08SL3o`0K<`?o01D^0ol042X3o`0;9@?o00LQ0ol011d3o`036P?o008I0ol00QX3o`04
7@Co00TS0ol04b`3o`0U>@?o04A:0ol0GTD3o`1d:@?o2Hd00om<Y@03oi^k00?ocK000ooISP07oooo
o`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3oaVD00?oLJl00oo7_@03omZ900?o
j5d00oo/CP03on]B00?oiFH00ooLP`03om6V00?o^/801?ml/P03odNS00?o6i@00ol0QPH3o`1i80?o
06hc0ol0I403o`1KB0?o05=<0ol0BTd3o`0oA`?o03I31?l0<403o`0[?@?o02Pk0ol09SX6o`0U>@?o
02Hj0ol0:3/3o`0[?@?o02lo0ol0=D83o`0lAPCo04I;0ol0D4h3o`1EB`?o05a70ol0Hd03o`1[=P?o
07@Y0ol0OAT3o`2710?o5I800olcW@04oeNX00?oO[<00onZ_P03olVj00?odih00ooMPP03onEU00?o
kDX00ooc<`03ooPQ00?onaD00ool4004oo/C00?on1h00ood<003one800?oiFH00ooKQP03om2V00?o
`/@00on;]P03oeRX00?o:YX00ol3R`04o`1l6`?o06hc0ol0H4<3o`1DC0?o04180ol0;3d3o`0M=0?o
018/0ol02bH3o`078@?o00@M1?l00aX6o`026@?o00<J0ol011`3o`057P?o00PR0ol02bD3o`0?:@?o
01<]0ol06343o`0M=0Co02<h0ol0:3/3o`0]?P?o03910ol0=T<3o`0hA0Ko03Y50ol0>D@3o`0f@`?o
03910ol0;Ch4o`0X>`?o028g0ol06c<3o`0E;P?o010Z0ol02bD3o`078@?o00@M0ol00aX3o`026@?o
008J0ol011d4o`098`?o01</0ol09CT3o`14BP?o05i50ol0M2T3o`V=00?oC:D00onK^`03olf`00?o
fHh01oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0olIU003og6_00?oakd0
0ooJR@03onQM00?ok4h00oo[DP03onEV00?og8<00ooAYP03ok[200CoO;800om7X`03oa^D00?o08H6
0ol0NB03o`1^<`?o06A00ol0FdP3o`1CC0?o04Y=0ol0?dL3o`0f@`Co03100ol0:cd3o`0X>`?o02Hj
1_l09CT3o`0V>P?o02Pk0ol0:cd3o`0_?`?o03E20ol0?4H4o`16B`?o051>0ol0ED/3o`1LA`?o06=0
0ol0JcH3o`1d:@?o07dI0ol0Q`@3oaFB00?o<id01?mGZ003ogjc00?oZ[h00oo9^P03om>N00?ogH80
0ooUI@03one:00?olc<00ooh8@03oo/E00?oo1001?ok4`03ooPN00?om3000oo]B003onEV00?ofhH0
0oo@YP03ol;400?oRkH00omHZ003obZJ00?o0h/01?l0O1/3o`1^<`?o06130ol0E4`3o`10B0?o02`m
0ol07C@3o`0B;0?o00/V0ol01b43o`047@Co00<J1_l00QT3o`036P?o00@L0ol01Ah3o`088P?o00/U
0ol03bT3o`0C;@?o01Pa0ol07C@4o`0S>0?o02Pk0ol0;Ch3o`0b@@?o03I30ol0>4@6o`0jA@?o03U4
0ol0=T<3o`0b@@?o02dn1?l0:3/3o`0R=`?o01/c0ol05Bh3o`0@:P?o00/U0ol01b43o`047@?o00<J
0ol00QT3o`026P?o00@M1?l02B<3o`0C;0?o02Di0ol0A4X3o`1NA@?o07@Y0ol9S@03odbU00?oVk/0
0oo=/003omV>00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?oN;400oo8
_003omV=00?oi6X00ooYF003onEV00?ogH800ooAY003oko300?oPK@00om6X`04oaJB00?o08<>0ol0
M2T3o`1W>`?o05a70ol0DTd3o`13B@?o03A20ol0:S`3o`0R=`?o01`d0ol06304o`0E;P?o01<]0ol0
4R`9o`0A:`?o018/0ol052h3o`0F;`?o01Xb0ol07SD3o`0S>0Co02Xm0ol0=483o`0oB0?o04i>0ol0
ET/3o`1NA@?o06Ll0ol0LBl3o`1k7@?o08H60olETP04ocNN00?oGjX00on;]P03okc200?ocZd00ooI
S`03on9_00?oje400oob=P03ooPP00?ona400oom2@04ood:00?ona@00oof9P03oo1000?oieh00ooM
P003om6S00?oa<@00on:]P03oeBW00?o9IP00ol0R084o`1i8@?o06Xh0ol0G4H3o`1?CP?o03I30ol0
8cP3o`0F;`?o00hX0ol02283o`057P?o00<K1ol00QT3o`036P?o00@M0ol01R03o`0:90?o00hX0ol0
4bd3o`0J<P?o028g0ol0:Sd3o`0c@PCo03e60ol0AT/3o`1?CP?o059=0ol0ED/3o`1GBP?o05Q91_l0
FDT3o`1HB@?o05I:0ol0E4`4o`1AC@?o04Y=0ol0@4P3o`0e@P?o02Xl0ol083H3o`0G<0?o00lY0ol0
2B@3o`057`?o00<K0ol00QT4o`026P?o00DM0ol02RD3o`0G<0?o02ho0ol0DTd3o`1X>P?o080D0olW
V@03og>`00?o`/@01oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0omh/@03
olRl00?ofHd00ooTJP03onUH00?oiFH00ooMPP03om6T00?o_l<00on1]003odJS00Co5Y800ol0P`h3
o`1d:@?o06Lk0ol0G4L3o`1BC@?o04=90ol0=483o`0Z?0?o028g0ol073@3o`0H<0Co01D^0ol04bd3
o`0B;0Wo014[0ol04R`3o`0D;P?o01H_0ol06S83o`0N=@?o02<h1?l0:Sd3o`0d@P?o03m80ol0CTh3
o`1FB`?o05i50ol0Ic`3o`1a;`?o07/M0ol0QPH3oaFB00Co=ih00omOZP03oh^f00?o_<800oo>[@03
omV?00?ohVl00oo[D@03oo8f00?on2000ook4@03ood900Coo@X00ook5003ooHV00?ol4000ooWGP03
omf000?odJ<00oo4a003ohZf00?oE:L00olUV003o`280PCo07TQ0ol0JSP3o`1LAP?o04m>0ol0=T<3
o`0S>0?o01H_0ol03RP3o`088P?o00DN0ol00a/7o`026@?o00<J0ol011d3o`0680?o00XT0ol03RP3
o`0C;@?o01Xb0ol08SL3o`0Z?@?o03=21?l0?DH3o`16B`?o04m>0ol0DTd3o`1EB`?o05M:0ol0F4T6
o`1IB@?o05Q90ol0ETX3o`1DC0Co055=0ol0BTd3o`10B0?o03E20ol0:S`3o`0P=P?o01L`0ol03bT3
o`0990?o00DO0ol00a/3o`026@Co008J0ol01Ad3o`0:9@?o01L`0ol0;Sl3o`1BC@?o06Pj0ol0P1@3
obNI00?oLk000oo2a007ooooo`7o00000Oooool001gooooo0_l00006ooooo`?oN;400oo8_003omV=
00?oi6X00ooYF003onEV00?ogH800ooAY003oko300?oPK@00om6X`04oaJB00?o08<>0ol0M2T3o`1W
>`?o05a70ol0DTd3o`13B@?o03A20ol0:S`3o`0R=`?o01`d0ol06304o`0E;P?o01<]0ol04R`9o`0A
:`?o018/0ol052h3o`0F;`?o01Xb0ol07SD3o`0S>0Co02Xm0ol0=483o`0oB0?o04i>0ol0ET/3o`1N
A@?o06Ll0ol0LBl3o`1k7@?o08H60olETP04ocNN00?oGjX00on;]P03okc200?ocZd00ooIS`03on9_
00?oje400oob=P03ooPP00?ona400oom2@04ood:00?ona@00oof9P03oo1000?oieh00ooMP003om6S
00?oa<@00on:]P03oeBW00?o9IP00ol0R084o`1i8@?o06Xh0ol0G4H3o`1?CP?o03I30ol08cP3o`0F
;`?o00hX0ol02283o`057P?o00<K1ol00QT3o`036P?o00@M0ol01R03o`0:90?o00hX0ol04bd3o`0J
<P?o028g0ol0:Sd3o`0c@PCo03e60ol0AT/3o`1?CP?o059=0ol0ED/3o`1GBP?o05Q91_l0FDT3o`1H
B@?o05I:0ol0E4`4o`1AC@?o04Y=0ol0@4P3o`0e@P?o02Xl0ol083H3o`0G<0?o00lY0ol02B@3o`05
7`?o00<K0ol00QT4o`026P?o00DM0ol02RD3o`0G<0?o02ho0ol0DTd3o`1X>P?o080D0olWV@03og>`
00?o`/@01_ooool2o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0oo6`003omJG00?o
gW`00ooQM003omio00?odil00oo5a003ohFe00?oBJ@00olGT`03o`224@Co074^0ol0Hd03o`1FB`?o
04M;0ol0=483o`0V>P?o01`d0ol05Bh3o`0@:P?o00dW0ol02bD3o`098`Co00PR1_l01b43o`0780Ko
00LQ0ol02283o`098`?o00/U0ol03BL3o`0?:P?o01<]1?l06343o`0O=P?o02Pk0ol0<d43o`12B@?o
055=0ol0FTP3o`1T?`?o06la0ol0Nah3o`271@Co6Y@00om0X@03ofb^00?oWK/00oo8_@03om>N00?o
gW`00ooXG003oo0m00?omb@00ook4@03ooh700CooPD00ool3P03ooPP00?olCT00ooYF@03omim00?o
dZ800oo3a003ohNe00?oCjH00olOUP03o`2520Co07DW0ol0ISd3o`1HBP?o04E:0ol0;Ch3o`0L=0?o
014[0ol02R@3o`067`?o00<K1ol00QT3o`036P?o00@M0ol01b43o`0;9@?o010Z0ol06303o`0Q=`?o
02/m0ol0=d@3o`15BP?o051>1?l0ET/3o`1LA`?o06520ol0ICh3o`1Y>P?o06`f0ol0KS<3o`1_<@?o
070`0ol0Kc43o`1^<P?o06`e1?l0JCT3o`1U?P?o06130ol0FdP3o`1DC0?o04]=0ol0>TD3o`0[?@?o
01he0ol04bd3o`0;9P?o00HO1?l00a/3o`026@?o00<J0ol01Ql3o`0>:0?o01he0ol0?TL3o`1LA`?o
07@Z0ol8S@03odjU00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?oa/00
0ooFU`03omil00?ohG@00ooNO`03om>O00?oaL@00on5]@03odVT00?o5i<00ol0PQ44o`1a;P?o06=0
0ol0ET/3o`17B`?o03A20ol09SX3o`0L=0?o01D^0ol042X3o`0=9`?o00/U0ol02B<4o`088PKo00LQ
0ol01b06o`078@?o00PR0ol02B<3o`0;9@?o00dW0ol03bX3o`0C;@Co01Pa0ol07cH3o`0X>`?o03=1
0ol0@TT3o`1AC@?o05Y80ol0I3l3o`1_<@?o07/N0ol0Q`D4oaZD00?o@:400om/[P03oifk00?ob;d0
0ooCWP03omil00?oj5`00oo`?@03ooLT00?ona400oon1`04ooh500?oo0h00ooh8003oo4i00?ojET0
0ooNO@03om:R00?o`l@00on7]@03odnV00?o7iH00ol0Q@P4o`1e9`?o06Hm0ol0F4X3o`15BP?o02dn
0ol073@3o`0A:`?o00XT0ol01Ql3o`036`Oo008I0ol00aX3o`047@?o00LQ0ol02bD3o`0@:P?o01P`
0ol08CL3o`0[?@?o03M40ol0ADX3o`1@CPCo05I;0ol0G4L3o`1Q@P?o06Dn0ol0JCX3o`1/=P?o06hc
0ol0Kc43o`1`<0?o06la0ol0KS83o`1/=@Co06Ti0ol0ICh3o`1P@`?o05]80ol0E4`3o`1;C@?o03Y5
0ol0:cd3o`0N=@?o01<]0ol02bH3o`067`Co00<K0ol00QT3o`036P?o00HO0ol03RP3o`0N=@?o03i7
0ol0G4L3o`1d:P?o28d00om>Y@07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Ooo
ool3olK000?oeYL00ooNO003on5d00?ogWl00ooCW`03olG400?oQKD00om9Y003oaNC00?o088A1?l0
LBh3o`1S@0?o05I;0ol0Ad/3o`0d@P?o02Hj0ol073@3o`0E;P?o010Z0ol03BL3o`0;9@?o00TS1?l0
2286o`078@?o00LP1_l01b43o`088P?o00TS0ol02bD3o`0=9`?o00lZ0ol04bd4o`0H<@?o01lf0ol0
:3/3o`0c@@?o04990ol0DDd3o`1JB0?o06@o0ol0Kc43o`1k7P?o08L51?lJU003od2Q00?oK:h00onM
^`03olRm00?odih00ooNO003onQL00?ol3d00oog9003oo/A00?ooPL01?on1@03oo`>00?on2000ooa
>@03onUI00?ogWd00ooBXP03ol?400?oQkD00om?YP03oanF00?o08D81?l0MBL3o`1V?@?o05Q:0ol0
ADX3o`0]?P?o01`d0ol04B/3o`0:90?o00HO0ol00a/7o`026@?o00<J0ol011d3o`078@?o00/U0ol0
42X3o`0H<0?o024g0ol0:cd3o`0gA0?o04E:0ol0D4h4o`1FB`?o05a70ol0HD83o`1U?P?o06Tj0ol0
K3H3o`1^<`?o06la0ol0L303o`1_<@?o06hb0ol0K3D4o`1Y>@?o06Dn0ol0H4<3o`1KB0?o05A<0ol0
Bdd3o`0jA@?o02/m0ol07SD3o`0C;@?o00/V0ol01Ql4o`036`?o008I0ol00aX3o`067`?o00hX0ol0
7SD3o`0nA`?o05a70ol0M2X3o`R=00?oCZD01oooool1o`00007ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo0oo@YP03omNC00?oei800ooBXP03olRm00?oT;P00om@YP03oaZD00?o088@0ol0LBh3
o`1Q@PCo05=<0ol0?DL3o`0Z?0?o01dd0ol052d3o`0>:0?o00XT0ol01b43o`067`?o00@M0ol011`:
o`036`Ko00<J1_l00a/3o`0370?o00@L0ol01Ah3o`067`?o00PQ0ol02R@4o`0=9`?o014[0ol06303
o`0P=P?o02/m0ol0>TD3o`1>CP?o05Q90ol0Hd03o`1_<@?o07`L1?l0R@03ob:G00?oCJD00omn/`03
okC000?ocJh00ooIS003onAY00?okTP00ooe:`03ooXE00?ooPP01?on1003ood;00?onA`00oob=P03
onUG00?ogW`00ooBXP03ol3300?oP[@00om9Y003oaNC00?o088?1?l0LRd3o`1R@@?o05=<0ol0>dH3
o`0U>P?o01L`0ol03BL3o`078@?o00@L0ol00QX3o`026@Co00<J0ol011d3o`078@?o00/V0ol04R`3
o`0J<P?o02Dj0ol0<d43o`13B@?o055=0ol0FDT3o`1P@`Co06Ll0ol0KC<3o`1c:`?o07PR0ol0OAX3
o`214`?o08@=0ol0QPP6o`271@?o08L60ol0Q@T4o`233`?o07lF0ol0Nah3o`1e:0?o06lb0ol0Ic/3
o`1OA0?o05I;0ol0BT`3o`0e@P?o02<h0ol05Rl4o`0<9P?o00HO0ol00a/3o`026@?o00<K0ol02283
o`0D;@?o02/m0ol0DDd3o`1Y>P?o088@1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo
00Gooooo0oo@YP03omNC00?oei800ooBXP03olRm00?oT;P00om@YP03oaZD00?o088@0ol0LBh3o`1Q
@PCo05=<0ol0?DL3o`0Z?0?o01dd0ol052d3o`0>:0?o00XT0ol01b43o`067`?o00@M0ol011`:o`03
6`Ko00<J1_l00a/3o`0370?o00@L0ol01Ah3o`067`?o00PQ0ol02R@4o`0=9`?o014[0ol06303o`0P
=P?o02/m0ol0>TD3o`1>CP?o05Q90ol0Hd03o`1_<@?o07`L1?l0R@03ob:G00?oCJD00omn/`03okC0
00?ocJh00ooIS003onAY00?okTP00ooe:`03ooXE00?ooPP01?on1003ood;00?onA`00oob=P03onUG
00?ogW`00ooBXP03ol3300?oP[@00om9Y003oaNC00?o088?1?l0LRd3o`1R@@?o05=<0ol0>dH3o`0U
>P?o01L`0ol03BL3o`078@?o00@L0ol00QX3o`026@Co00<J0ol011d3o`078@?o00/V0ol04R`3o`0J
<P?o02Dj0ol0<d43o`13B@?o055=0ol0FDT3o`1P@`Co06Ll0ol0KC<3o`1c:`?o07PR0ol0OAX3o`21
4`?o08@=0ol0QPP6o`271@?o08L60ol0Q@T4o`233`?o07lF0ol0Nah3o`1e:0?o06lb0ol0Ic/3o`1O
A0?o05I;0ol0BT`3o`0e@P?o02<h0ol05Rl4o`0<9P?o00HO0ol00a/3o`026@?o00<K0ol02283o`0D
;@?o02/m0ol0DDd3o`1Y>P?o088@1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Go
oooo0oo@YP03omNC00?oei800ooBXP03olRm00?oT;P00om@YP03oaZD00?o088@0ol0LBh3o`1Q@PCo
05=<0ol0?DL3o`0Z?0?o01dd0ol052d3o`0>:0?o00XT0ol01b43o`067`?o00@M0ol011`:o`036`Ko
00<J1_l00a/3o`0370?o00@L0ol01Ah3o`067`?o00PQ0ol02R@4o`0=9`?o014[0ol06303o`0P=P?o
02/m0ol0>TD3o`1>CP?o05Q90ol0Hd03o`1_<@?o07`L1?l0R@03ob:G00?oCJD00omn/`03okC000?o
cJh00ooIS003onAY00?okTP00ooe:`03ooXE00?ooPP01?on1003ood;00?onA`00oob=P03onUG00?o
gW`00ooBXP03ol3300?oP[@00om9Y003oaNC00?o088?1?l0LRd3o`1R@@?o05=<0ol0>dH3o`0U>P?o
01L`0ol03BL3o`078@?o00@L0ol00QX3o`026@Co00<J0ol011d3o`078@?o00/V0ol04R`3o`0J<P?o
02Dj0ol0<d43o`13B@?o055=0ol0FDT3o`1P@`Co06Ll0ol0KC<3o`1c:`?o07PR0ol0OAX3o`214`?o
08@=0ol0QPP6o`271@?o08L60ol0Q@T4o`233`?o07lF0ol0Nah3o`1e:0?o06lb0ol0Ic/3o`1OA0?o
05I;0ol0BT`3o`0e@P?o02<h0ol05Rl4o`0<9P?o00HO0ol00a/3o`026@?o00<K0ol02283o`0D;@?o
02/m0ol0DDd3o`1Y>P?o088@1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo
0oo?ZP03olf^00?oa/400onI^P03of6[00?o9IP00ol0Q@X3o`1b;0?o06520ol0DTd3o`0iA@Co02Di
0ol05c03o`0?:@?o00XT0ol01R03o`047@?o00<K0ol00aXUo`026@?o008J0ol00a/3o`0470?o00DN
1?l01b03o`098`?o00dX0ol04bd3o`0K<`?o02Lk0ol0=d<3o`1;C@?o05Q90ol0I3l3o`1a;PCo07lF
0ol9S@03oc6L00?oH:/00onF^@03olNn00?oe9/00ooPMP03on]C00?olc<00ooi6P03ood900Coo`<0
0oom2@03ooTI00?olc<00ooZE@03ommk00?odZ<00onn``03ogfc00?o@j800olAT003o`1o5PCo06hc
0ol0GTD3o`1?CP?o03=10ol07cD3o`0B;0?o00XT0ol01Ah3o`036`?o008I0ol00QX4o`0470?o00HP
0ol02bD3o`0B;0?o01`c0ol0:3/3o`0hA0?o04a=0ol0ET/3o`1OA0?o06Pj0ol0L2l4o`1h8P?o080E
0ol0QPL3o`J<00?o4i400olOUP03obVI00?o<9`00olfWP06ocVO00?o=Yh01?laW003obVI00?o7YD0
0olAT003o`::00?o08<=0ol0Nad3o`1b;@?o06Pk0ol0GDH3o`1AC@?o03]51?l09SX3o`0F;`?o00/U
0ol01Ah3o`026P?o008I0ol01Ah3o`0=9`?o01he0ol0@DP3o`1OA0Oooooo0Ol00001ooooo`007Ooo
ool00ol0003oooooooooo`05ooooo`?ocjX00oo=[P03olK100?oVKX00omQZ`03obFH00?o08D:0ol0
LR`3o`1Q@P?o059=0ol0>DD4o`0U>@?o01L`0ol03bT3o`0:90?o00HP0ol011d3o`036`?o00<J9Ol0
0QT3o`026P?o00<K0ol011`3o`057PCo00LP0ol02B<3o`0=:0?o01<]0ol06c<3o`0W>`?o03M30ol0
Bdd3o`1HB@?o06@o0ol0LBh4o`1o5P?o2Hd00olaW003of2[00?oU[T00oo7_P03omBK00?oh7H00oo[
D`03oo<c00?onAX00oom2@04ool300?oo@T00ooi6@03oo<c00?ojUD00ooON`03om:S00?o_/<00omm
/`03od>R00?o4I000ol0OaH4o`1^<`?o05i50ol0Cdh3o`0c@@?o01le0ol04R`3o`0:90?o00DN0ol0
0a/3o`026@?o008J1?l011`3o`0680?o00/U0ol04R`3o`0L<`?o02Pk0ol0>4@3o`1<C@?o05I;0ol0
Gd@3o`1X>P?o070_1?l0N283o`205@?o08H70ol6S003oa>A00?o7iH00olYV@03oc2L00?o=Yh01_li
W`03ocJN00Co<I`00olYV@03oajE00?o4I000ol2RP03o`233@?o07/M0ol0LRd3o`1X>`?o05e60ol0
DDd3o`0kA@Co02Hj0ol05Rl3o`0;9@?o00DN0ol00QX3o`026@?o00DN0ol03BL3o`0N=@?o04580ol0
Gd@7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3olnZ00?ocJh00oo6`@03
oiVj00?oHJ/00olUV003o`252P?o078/0ol0HD83o`1BC@?o03U51?l09CT3o`0G<0?o00lY0ol02R@3
o`0680?o00@M0ol00a/3o`036RGo008I0ol00QX3o`036`?o00@L0ol01Ah4o`0780?o00TS0ol03BP3
o`0C;@?o01/c0ol09c/3o`0g@`?o04]=0ol0F4T3o`1T?`?o074^1?l0OaH3o`V=00?o<I`00omPZ`03
oiJi00?oakh00ooDV`03on1f00?oje<00ooc<`03ooTJ00?oo@T01?oo0`03ood900?onAT00ooc<`03
onYE00?ogg/00ooBX`03okk300?oOK<00om3XP03oa6@00?o07lF1?l0KS<3o`1NA@?o04m>0ol0<d43
o`0O=@?o018/0ol02R@3o`057P?o00<K0ol00QT3o`026PCo00@L0ol01R03o`0;9@?o018/0ol073<3
o`0X>`?o03Q40ol0C4d3o`1FB`?o05m40ol0J3X3o`1`;`Co07PR0ol0P1D3o`261`?o1X`00olCT@03
oanF00?o:IT00ol`W003ocJN00Ko>Il00olfWP04oc6L00?o:IT00olNU@03oa6@00?o0XX00ol0P`d3
o`1k7@?o078]0ol0J3/3o`1MAP?o055=0ol0>dD4o`0V>P?o01H_0ol02bD3o`057P?o008J0ol00QT3
o`057P?o00dW0ol07SD3o`11B0?o05m41oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo
00Gooooo0oo0``03oi^j00?oJ:d00olcW@03o`:;00?o07LU0ol0I3l3o`1CC0?o03U50ol08cP3o`0E
;PCo00`W0ol01b43o`057@?o00<K0ol00QX6o`026@?o008J1_l00a/3o`0470go00@M1_l011`3o`03
6`?o00<J0ol00QX9o`026@?o00<J1?l00a`3o`057P?o00LQ0ol02bD3o`0A:`?o01Ta0ol09CT3o`0f
@`?o04e>0ol0FTP3o`1W?0Co07DX0ol0Q0`3oaNC00?oAJ<00omj/P03okK100?ocjT00ooLQ003onMN
00?olC/00ooh7`03ood;00Coo`<00oon1`03ooXF00?om3000oo[DP03ommj00?odZ<00onk`P03ogRa
00?o?J000ol:SP03o`1l70Co06Xh0ol0FTP3o`16B`?o02/m0ol06C83o`0>:0?o00LQ0ol011`3o`02
6P?o008I0ol00a/4o`067`?o00XT0ol04B/3o`0K<`?o02Tl0ol0>dD3o`1?CP?o05Y80ol0I3l3o`1^
<`?o07PS0ol0PA84o`2:00?o59800olXV@03oc^O00?oCJD00omMZP03of^^00?oMk400on0/`03ohFe
00?oR;H00on7]@04oh:d00?oNk800om_[`03of6[00?oCjH00olkW`03obFH00?o3Xl00ol0Q@T3o`1j
7`?o06hc0ol0HD84o`1DC0?o03a60ol093T3o`0C;@?o00TS0ol011`3o`026@?o00<K0ol02283o`0F
;`?o03911oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0oo0``03oi^j00?o
J:d00olcW@03o`:;00?o07LU0ol0I3l3o`1CC0?o03U50ol08cP3o`0E;PCo00`W0ol01b43o`057@?o
00<K0ol00QX6o`026@?o008J1_l00a/3o`0470go00@M1_l011`3o`036`?o00<J0ol00QX9o`026@?o
00<J1?l00a`3o`057P?o00LQ0ol02bD3o`0A:`?o01Ta0ol09CT3o`0f@`?o04e>0ol0FTP3o`1W?0Co
07DX0ol0Q0`3oaNC00?oAJ<00omj/P03okK100?ocjT00ooLQ003onMN00?olC/00ooh7`03ood;00Co
o`<00oon1`03ooXF00?om3000oo[DP03ommj00?odZ<00onk`P03ogRa00?o?J000ol:SP03o`1l70Co
06Xh0ol0FTP3o`16B`?o02/m0ol06C83o`0>:0?o00LQ0ol011`3o`026P?o008I0ol00a/4o`067`?o
00XT0ol04B/3o`0K<`?o02Tl0ol0>dD3o`1?CP?o05Y80ol0I3l3o`1^<`?o07PS0ol0PA84o`2:00?o
59800olXV@03oc^O00?oCJD00omMZP03of^^00?oMk400on0/`03ohFe00?oR;H00on7]@04oh:d00?o
Nk800om_[`03of6[00?oCjH00olkW`03obFH00?o3Xl00ol0Q@T3o`1j7`?o06hc0ol0HD84o`1DC0?o
03a60ol093T3o`0C;@?o00TS0ol011`3o`026@?o00<K0ol02283o`0F;`?o03911oooool1o`00007o
oooo000Mooooo`;o00001_ooool3ol3300?oVkX00omX[@03oc>M00?o0X/00ol0MbD3o`1T?`?o05=<
0ol0>DD3o`0S>0?o01D^1?l032L3o`078@?o00DM0ol00a/3o`026PKo008I0ol00QX6o`036`?o00@L
3Ol011d6o`0470?o00<K0ol00aX3o`026PWo008I0ol00aX4o`0370?o00DN0ol01b43o`0;9@?o014[
0ol06C43o`0U>@?o03I30ol0CDh3o`1JB0?o06Ll1?l0MBP3o`2430?o5i<00om5X`03ogZb00?o]/40
0oo?Z@03omb400?oieh00ooa>`03ooPO00?oo@/01?oo0`03ooh700?onQH00ood<003on]B00?oggX0
0ooBX`03ok_200?oN;400olmX003o`Z>00?o07`L1?l0JSP3o`1JB0?o04I;0ol0:cd3o`0I<P?o00hX
0ol01b43o`0470?o008J0ol00QT3o`036`Co00HO0ol02R@3o`0A:`?o01/c0ol0:C`3o`0kA@?o04m>
0ol0FTP3o`1T?`?o06hc0ol0N2<3o`214PCo08X00olDTP03obRI00?o>il00om=Y@03oefZ00?oJjh0
0omg/@03oh2c00?oQKD00on8]P03ohNe00CoP[@00omk/P03ofn_00?oHJ/00om?YP03oc^O00?o9IP0
0ol>S`03o`252@?o07XO0ol0KS<3o`1Q@PCo05A<0ol0?4H3o`0T>@?o01<]0ol02B<3o`0470?o008I
0ol00a/3o`088P?o01H_0ol0<T46ooooo`;o00000Oooool001gooooo00?o0000ooooooooool01Ooo
ool3og2_00?o@:400ol>S`03o`1m6P?o06Xh0ol0F4X3o`0oA`?o02Di0ol05Bh3o`0<9P?o00HP1?l0
11`3o`026PKo008I0ol00a/3o`0470?o00DN0ol01R03o`088P?o00TS0ol02R@:o`0;9@?o00XT0ol0
2B<3o`088P?o00LQ0ol01Ql3o`057P?o00@L0ol00a/3o`026POo008I0ol00aX3o`0470?o00HP0ol0
2R@3o`0@:P?o01Ta0ol09SX3o`0hA0?o051>0ol0GDH4o`1[=`?o07XO0ol1RP03obbJ00?oH:/00onL
^`03olZg00?of9400ooTJ@03onm400?ombD00ool3P04ool300?ooPD00ook4`03oo@]00?oje000ooO
N@03om6S00?o^<400omd/003ocNN00?o18/00ol0NB84o`1W?0?o05I;0ol0?TL3o`0U>@?o01D^0ol0
2bD3o`067`?o00<K0ol00QT3o`036P?o00@M1?l02283o`0?:@?o01Ta0ol09c/3o`0jA@?o051>0ol0
FdL3o`1W?0?o078]0ol0OAX3o`2810?o59401?l]V`03odNS00?oHJ/00omi/P03oi2h00?oY;d00onf
`@03olG400?oakh00oo9^@06olZf00Cob[L00oo9^P03olK000?o_l<00on]_`03oiRj00?oOk<00omS
[003odFR00?o9IP00ol6S003o`1o5PCo074^0ol0HT43o`1CC0?o03M30ol07cD3o`0?:@?o00HP0ol0
0aX3o`026P?o00HO0ol042X7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3
og2_00?o@:400ol>S`03o`1m6P?o06Xh0ol0F4X3o`0oA`?o02Di0ol05Bh3o`0<9P?o00HP1?l011`3
o`026PKo008I0ol00a/3o`0470?o00DN0ol01R03o`088P?o00TS0ol02R@:o`0;9@?o00XT0ol02B<3
o`088P?o00LQ0ol01Ql3o`057P?o00@L0ol00a/3o`026POo008I0ol00aX3o`0470?o00HP0ol02R@3
o`0@:P?o01Ta0ol09SX3o`0hA0?o051>0ol0GDH4o`1[=`?o07XO0ol1RP03obbJ00?oH:/00onL^`03
olZg00?of9400ooTJ@03onm400?ombD00ool3P04ool300?ooPD00ook4`03oo@]00?oje000ooON@03
om6S00?o^<400omd/003ocNN00?o18/00ol0NB84o`1W?0?o05I;0ol0?TL3o`0U>@?o01D^0ol02bD3
o`067`?o00<K0ol00QT3o`036P?o00@M1?l02283o`0?:@?o01Ta0ol09c/3o`0jA@?o051>0ol0FdL3
o`1W?0?o078]0ol0OAX3o`2810?o59401?l]V`03odNS00?oHJ/00omi/P03oi2h00?oY;d00onf`@03
olG400?oakh00oo9^@06olZf00Cob[L00oo9^P03olK000?o_l<00on]_`03oiRj00?oOk<00omS[003
odFR00?o9IP00ol6S003o`1o5PCo074^0ol0HT43o`1CC0?o03M30ol07cD3o`0?:@?o00HP0ol00aX3
o`026P?o00HO0ol042X7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3og2_
00?o@:400ol>S`03o`1m6P?o06Xh0ol0F4X3o`0oA`?o02Di0ol05Bh3o`0<9P?o00HP1?l011`3o`02
6PKo008I0ol00a/3o`0470?o00DN0ol01R03o`088P?o00TS0ol02R@:o`0;9@?o00XT0ol02B<3o`08
8P?o00LQ0ol01Ql3o`057P?o00@L0ol00a/3o`026POo008I0ol00aX3o`0470?o00HP0ol02R@3o`0@
:P?o01Ta0ol09SX3o`0hA0?o051>0ol0GDH4o`1[=`?o07XO0ol1RP03obbJ00?oH:/00onL^`03olZg
00?of9400ooTJ@03onm400?ombD00ool3P04ool300?ooPD00ook4`03oo@]00?oje000ooON@03om6S
00?o^<400omd/003ocNN00?o18/00ol0NB84o`1W?0?o05I;0ol0?TL3o`0U>@?o01D^0ol02bD3o`06
7`?o00<K0ol00QT3o`036P?o00@M1?l02283o`0?:@?o01Ta0ol09c/3o`0jA@?o051>0ol0FdL3o`1W
?0?o078]0ol0OAX3o`2810?o59401?l]V`03odNS00?oHJ/00omi/P03oi2h00?oY;d00onf`@03olG4
00?oakh00oo9^@06olZf00Cob[L00oo9^P03olK000?o_l<00on]_`03oiRj00?oOk<00omS[003odFR
00?o9IP00ol6S003o`1o5PCo074^0ol0HT43o`1CC0?o03M30ol07cD3o`0?:@?o00HP0ol00aX3o`02
6P?o00HO0ol042X7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3oajF00?o
08@<0ol0LBl3o`1NA@?o04Y=0ol0:cd3o`0H<0?o00`W0ol01R03o`036`Oo008I0ol00aX3o`047@?o
00HO0ol02B83o`0;9P?o00lY0ol04R/3o`0D;P?o01L`0ol06347o`0I<@?o01Pa0ol05c03o`0E;P?o
018/0ol042X3o`0=9`?o00XT0ol02243o`067`?o00@L0ol00a/7o`026@?o008J0ol011`3o`067`?o
00XT0ol042X3o`0J<P?o02Pk0ol0?TL3o`1DC0Co06910ol0LBh3o`214@?o5Y800om8X`03oh:d00?o
a<@00ooCWP03on5e00?ok4h00ooe:`03oo/B00CooPD00oon1003oo/B00?omB/00oo/C`03on1i00?o
dJ@00one`@03ofn_00?o<I`00ol0R@43o`1f9`Co06=00ol0DTd3o`0f@`?o01lf0ol04B/3o`088P?o
00@M0ol00QX3o`026@?o00<K0ol01R04o`0<9P?o01D_0ol08cP3o`0g@`?o04m>0ol0FdL3o`1X>`?o
07@Z0ol0P1<3o`J<00?o8iL00om1X@04of6[00?oPK@00onO_003okc200?ob;/00oo>[@03om:R00?o
eYL00ooHS`03omZ900?og8@01ooMPP03omb400?ofXT00ooHT003omFI00?odJD00oo</`03olG200?o
Z;h00on3]003oefZ00?o=Ih01?l@T003o`214P?o070_0ol0Gd@3o`1>CP?o02dn0ol05c03o`0:90?o
00@L0ol00QX3o`047@Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o7YH0
0ol0Q0`3o`1a;`?o05i50ol0BTd3o`0[?@?o01P`0ol032L3o`0680?o00<K1ol00QT3o`036P?o00@M
0ol01Ql3o`098P?o00/V0ol03bT3o`0B:`?o01@^0ol05c03o`0H<@Oo01Ta0ol06343o`0G<0?o01D^
0ol04R`3o`0@:P?o00dW0ol02R@3o`088@?o00HO0ol011`3o`036`Oo008I0ol00QX3o`0470?o00HO
0ol02R@3o`0@:P?o01Xb0ol0:3/3o`0nA`?o05A<1?l0HT43o`1a;P?o084A0olFTP03odRS00?oP[@0
0oo4a003om>N00?ohGD00oo/CP03ooD[00?ona801?on1@03ooh400?ona800ooe:`03ona?00?oh7T0
0ooAY003okG100?oKjl00olaW003o`290@?o07HW1?l0Hd03o`1BC@?o03I30ol07cH3o`0A:`?o00PR
0ol011d3o`026P?o008I0ol00a/3o`0680Co00`V0ol05Bl3o`0S>0?o03M30ol0Cdh3o`1KA`?o06Pk
0ol0M2X3o`204`?o1X`00olSU`03od6Q00CoHJ/00on1]003oinl00?o_<800oo8^`03olj]00?odZ80
0ooFU`03omR?00?ofXT00ooLQ007omf200?og8@00ooJR@03omR@00?oeIT00ooAY@03olbc00?oaL80
0onX_P03oh>d00?oGJX00oleWP04oa2@00?o084B0ol0L2l3o`1OA0?o04i>0ol0;Ch3o`0G<0?o00XT
0ol011`3o`026P?o00@M1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0olN
UP03o`2430?o074_0ol0GTD3o`1:C@?o02/m0ol06303o`0<9`?o00HP0ol00a/7o`026@?o00<J0ol0
11d3o`067`?o00TR0ol02bH3o`0?:@?o018[0ol052h3o`0G<0?o01Pa1ol06C43o`0H<@?o01L`0ol0
5Bh3o`0B;0?o010Z0ol03BL3o`0:90?o00PQ0ol01Ql3o`0470?o00<K1ol00QT3o`026P?o00@L0ol0
1Ql3o`0:90?o010Z0ol06S83o`0X>`?o03i70ol0E4`4o`1R@@?o074^0ol0PA43oaJB00?oB:<00on2
]003olC400?odih00ooQM@03ona>00?omB/00ook4P04ooh500?ooP@00ook4P03ooD[00?ok4l00ooP
N@03om6T00?o]L400om_[`03oc6L00?o08T10ol0MRL4o`1S@0?o059=0ol0=T<3o`0O=P?o014[0ol0
2283o`047@?o008J0ol00QT3o`036`?o00HP1?l032H3o`0E;`?o02<h0ol0=d<3o`1?CP?o05]70ol0
J3/3o`1d:P?o080C0ol6S003ob>G00?o@J401?mQZ`03oh6d00?oWk`00onl`P03olRk00?ocZd00ooB
XP03omJG00?of8l00ooJR@03omb400OogH800ooLQ003omZ900?of9000ooEV@03om6U00?oc;<00oo5
`P03ojRn00?oPk@00omMZP03ocFN00Co49000ol0PA83o`1`;`?o05m40ol0CTh3o`0]?P?o01L`0ol0
2R@3o`0470?o008J0ol011d7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3
o`1i8@?o06Hm0ol0E4`3o`0f@`?o01he0ol03bT3o`078@?o00@L1_l00QT3o`036`Co00DN0ol02283
o`0=9`?o018/0ol05c03o`0M=0?o02<h0ol0:C`3o`0]?P?o03100ol0<T43o`0c@@Co03910ol0<403
o`0]?P?o02Tl0ol093T3o`0N=@?o01Ta0ol052d3o`0?:@?o00/U0ol02283o`057PCo00@L0ol00aX3
o`026@?o008J0ol00a/3o`067`?o00XT0ol04B/3o`0L=0?o02hn0ol0Ad/4o`1IB@?o06Pj0ol0NB43
o`::00?o<I`00om[[P03ojbo00?ocj/00ooMP@03onUG00?olc800ooj5P04ooh600?ooP@00ool4003
ooDY00?ok4d00ooPN003om6U00?o/L000omZ[@03ob^J00?o08H60ol0Lb/4o`1P@`?o04m>0ol0<403
o`0J<P?o00hX0ol01b03o`036`?o008I0ol00aX3o`057@?o00TS1?l04B/3o`0N=@?o03100ol0BT`3
o`1IB@?o06Ll0ol0M2X3o`214@?o2hh00ol/VP03oe2V00?oMK401?nJ^P03okk300?obkD00ooBX`03
omNB00?og8<00ooQM@03onAZ00?oif400ooYF@03onYD00?oje401oo[D003onYC00?ojEP00ooWH003
onAZ00?oh7L00ooKQP03omFI00?ocZd00oo5a003oiVj00CoJjh00ollX003o`j?00?o07hH0ol0K3H3
o`1IB@?o03m70ol083H3o`0>:0?o00HO0ol00aX7ooooo`7o00000Oooool001gooooo00?o0000oooo
ooooool01Oooool3o`1i8@?o06Hm0ol0E4`3o`0f@`?o01he0ol03bT3o`078@?o00@L1_l00QT3o`03
6`Co00DN0ol02283o`0=9`?o018/0ol05c03o`0M=0?o02<h0ol0:C`3o`0]?P?o03100ol0<T43o`0c
@@Co03910ol0<403o`0]?P?o02Tl0ol093T3o`0N=@?o01Ta0ol052d3o`0?:@?o00/U0ol02283o`05
7PCo00@L0ol00aX3o`026@?o008J0ol00a/3o`067`?o00XT0ol04B/3o`0L=0?o02hn0ol0Ad/4o`1I
B@?o06Pj0ol0NB43o`::00?o<I`00om[[P03ojbo00?ocj/00ooMP@03onUG00?olc800ooj5P04ooh6
00?ooP@00ool4003ooDY00?ok4d00ooPN003om6U00?o/L000omZ[@03ob^J00?o08H60ol0Lb/4o`1P
@`?o04m>0ol0<403o`0J<P?o00hX0ol01b03o`036`?o008I0ol00aX3o`057@?o00TS1?l04B/3o`0N
=@?o03100ol0BT`3o`1IB@?o06Ll0ol0M2X3o`214@?o2hh00ol/VP03oe2V00?oMK401?nJ^P03okk3
00?obkD00ooBX`03omNB00?og8<00ooQM@03onAZ00?oif400ooYF@03onYD00?oje401oo[D003onYC
00?ojEP00ooWH003onAZ00?oh7L00ooKQP03omFI00?ocZd00oo5a003oiVj00CoJjh00ollX003o`j?
00?o07hH0ol0K3H3o`1IB@?o03m70ol083H3o`0>:0?o00HO0ol00aX7ooooo`7o00000Oooool001go
oooo00?o0000ooooooooool01Oooool3o`1i8@?o06Hm0ol0E4`3o`0f@`?o01he0ol03bT3o`078@?o
00@L1_l00QT3o`036`Co00DN0ol02283o`0=9`?o018/0ol05c03o`0M=0?o02<h0ol0:C`3o`0]?P?o
03100ol0<T43o`0c@@Co03910ol0<403o`0]?P?o02Tl0ol093T3o`0N=@?o01Ta0ol052d3o`0?:@?o
00/U0ol02283o`057PCo00@L0ol00aX3o`026@?o008J0ol00a/3o`067`?o00XT0ol04B/3o`0L=0?o
02hn0ol0Ad/4o`1IB@?o06Pj0ol0NB43o`::00?o<I`00om[[P03ojbo00?ocj/00ooMP@03onUG00?o
lc800ooj5P04ooh600?ooP@00ool4003ooDY00?ok4d00ooPN003om6U00?o/L000omZ[@03ob^J00?o
08H60ol0Lb/4o`1P@`?o04m>0ol0<403o`0J<P?o00hX0ol01b03o`036`?o008I0ol00aX3o`057@?o
00TS1?l04B/3o`0N=@?o03100ol0BT`3o`1IB@?o06Ll0ol0M2X3o`214@?o2hh00ol/VP03oe2V00?o
MK401?nJ^P03okk300?obkD00ooBX`03omNB00?og8<00ooQM@03onAZ00?oif400ooYF@03onYD00?o
je401oo[D003onYC00?ojEP00ooWH003onAZ00?oh7L00ooKQP03omFI00?ocZd00oo5a003oiVj00Co
Jjh00ollX003o`j?00?o07hH0ol0K3H3o`1IB@?o03m70ol083H3o`0>:0?o00HO0ol00aX7ooooo`7o
00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1MA@?o04M;0ol0:3/3o`0D;P?o00XT
0ol011d3o`026P?o008I0ol00a/3o`067`?o00XT1?l042X3o`0H<0?o024g0ol0:cd3o`0e@`?o03m8
0ol0B4`3o`1?CP?o059=0ol0Dd`6o`1DC0Co05=<0ol0DDd3o`1?CP?o04Q;0ol0?dL3o`0f@`?o02dn
0ol093T3o`0L=0?o01D^0ol03bT3o`0:90Co00LP0ol011d3o`036P?o008I0ol00QX3o`0370?o00HO
0ol02bD3o`0D;@?o024g0ol0=T<4o`1AC@?o06130ol0LBh3o`233P?o7ID00omDY`03oiJi00?ob[L0
0ooIS003onMQ00?olCX00ooi6`04ooh800?oo`@00ool3`03ooHX00?ok4`00ooPN003om6U00?o[[l0
0omU[003obJH00?o08@<0ol0L304o`1MAP?o04Q<0ol0:S`3o`0F;`?o00/U0ol01Ah3o`036P?o008I
0ol00a/3o`0680?o00dW1?l06303o`0Y?0?o04180ol0ET/3o`1T?`?o078]0ol0P1<3o`b>00?o<9`0
0omHZ003oh:d00?o[;l01?o8^`03om6U00?of9000ooOO003onAZ00?ojEX00oo/C003onm100?olSP0
0ood<@03ooD/00?omRP01oof9P03ooHW00?omBX00ood;`03oo8f00?ol3l00oo]C003onQL00?ohVl0
0ooKQP03om>O00CobKX00onR_003ofZ]00?o=9d00ol3R`03o`1h90?o06@o0ol0Cdh3o`0[?@?o01<]
0ol02247ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1MA@?o04M;0ol0
:3/3o`0D;P?o00XT0ol011d3o`026P?o008I0ol00a/3o`067`?o00XT1?l042X3o`0H<0?o024g0ol0
:cd3o`0e@`?o03m80ol0B4`3o`1?CP?o059=0ol0Dd`6o`1DC0Co05=<0ol0DDd3o`1?CP?o04Q;0ol0
?dL3o`0f@`?o02dn0ol093T3o`0L=0?o01D^0ol03bT3o`0:90Co00LP0ol011d3o`036P?o008I0ol0
0QX3o`0370?o00HO0ol02bD3o`0D;@?o024g0ol0=T<4o`1AC@?o06130ol0LBh3o`233P?o7ID00omD
Y`03oiJi00?ob[L00ooIS003onMQ00?olCX00ooi6`04ooh800?oo`@00ool3`03ooHX00?ok4`00ooP
N003om6U00?o[[l00omU[003obJH00?o08@<0ol0L304o`1MAP?o04Q<0ol0:S`3o`0F;`?o00/U0ol0
1Ah3o`036P?o008I0ol00a/3o`0680?o00dW1?l06303o`0Y?0?o04180ol0ET/3o`1T?`?o078]0ol0
P1<3o`b>00?o<9`00omHZ003oh:d00?o[;l01?o8^`03om6U00?of9000ooOO003onAZ00?ojEX00oo/
C003onm100?olSP00ood<@03ooD/00?omRP01oof9P03ooHW00?omBX00ood;`03oo8f00?ol3l00oo]
C003onQL00?ohVl00ooKQP03om>O00CobKX00onR_003ofZ]00?o=9d00ol3R`03o`1h90?o06@o0ol0
Cdh3o`0[?@?o01<]0ol02247ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3
o`1MA@?o04M;0ol0:3/3o`0D;P?o00XT0ol011d3o`026P?o008I0ol00a/3o`067`?o00XT1?l042X3
o`0H<0?o024g0ol0:cd3o`0e@`?o03m80ol0B4`3o`1?CP?o059=0ol0Dd`6o`1DC0Co05=<0ol0DDd3
o`1?CP?o04Q;0ol0?dL3o`0f@`?o02dn0ol093T3o`0L=0?o01D^0ol03bT3o`0:90Co00LP0ol011d3
o`036P?o008I0ol00QX3o`0370?o00HO0ol02bD3o`0D;@?o024g0ol0=T<4o`1AC@?o06130ol0LBh3
o`233P?o7ID00omDY`03oiJi00?ob[L00ooIS003onMQ00?olCX00ooi6`04ooh800?oo`@00ool3`03
ooHX00?ok4`00ooPN003om6U00?o[[l00omU[003obJH00?o08@<0ol0L304o`1MAP?o04Q<0ol0:S`3
o`0F;`?o00/U0ol01Ah3o`036P?o008I0ol00a/3o`0680?o00dW1?l06303o`0Y?0?o04180ol0ET/3
o`1T?`?o078]0ol0P1<3o`b>00?o<9`00omHZ003oh:d00?o[;l01?o8^`03om6U00?of9000ooOO003
onAZ00?ojEX00oo/C003onm100?olSP00ood<@03ooD/00?omRP01oof9P03ooHW00?omBX00ood;`03
oo8f00?ol3l00oo]C003onQL00?ohVl00ooKQP03om>O00CobKX00onR_003ofZ]00?o=9d00ol3R`03
o`1h90?o06@o0ol0Cdh3o`0[?@?o01<]0ol02247ooooo`7o00000Oooool001gooooo0_l00006oooo
o`?o03U40ol07SD3o`0>:@?o00LP0ol00a/3o`026@?o00<K0ol01Ql3o`0;9@?o018/0ol073@4o`0Y
?0?o03M40ol0Ad/3o`1BC@?o05Q90ol0GDD3o`1R@@?o06Dn0ol0Ic/6o`1Y>P?o06Pj1?l0Ic`3o`1T
?`?o06520ol0GDH3o`1HBP?o059=0ol0BT`3o`0lAP?o02lo0ol093T3o`0J<P?o018/1?l032H3o`07
8@?o00@M0ol00aX3o`026@?o008J0ol011`3o`078@?o00dX0ol06343o`0Y?0Co04=90ol0F4T3o`1Y
>@?o07/M0ol:SP03od2Q00?oP;@00oo5`P03omJG00?oi6/00oo_@@03ooPO00Coo@X00ooo1003oo`=
00?omRH00oo]B`03on1g00?od:H00on[_P03of6[00?o8IH00ol0PQ43o`1]=0Co05Y80ol0@DP3o`0T
>@?o01<]0ol02B<3o`047@?o008I0ol00QX3o`047@?o00TS0ol04R/4o`0P=P?o03I30ol0D4d3o`1O
A0?o06hb0ol0OQT3o`N=00?o;Y/00omJZ@03ohNe00?o]/400oo</`04omFJ00?ogH400ooTJ`03onYG
00?okTD00oob=P03ooDZ00?on2000ooj6@03oo/C00?oo0l00ool3004ood;00Koo@X00oom2`03oo`=
00?ona400ooj5P03ooPN00?omRT00oob=`03one:00?oif001?oON`03omFI00?ob;/00onH^P03oe^Y
00?o8IL00ol0PPl3o`1/=@?o05M:0ol0=T<3o`0I<@Kooooo0_l00001ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`?o03U40ol07SD3o`0>:@?o00LP0ol00a/3o`026@?o00<K0ol01Ql3o`0;9@?o
018/0ol073@4o`0Y?0?o03M40ol0Ad/3o`1BC@?o05Q90ol0GDD3o`1R@@?o06Dn0ol0Ic/6o`1Y>P?o
06Pj1?l0Ic`3o`1T?`?o06520ol0GDH3o`1HBP?o059=0ol0BT`3o`0lAP?o02lo0ol093T3o`0J<P?o
018/1?l032H3o`078@?o00@M0ol00aX3o`026@?o008J0ol011`3o`078@?o00dX0ol06343o`0Y?0Co
04=90ol0F4T3o`1Y>@?o07/M0ol:SP03od2Q00?oP;@00oo5`P03omJG00?oi6/00oo_@@03ooPO00Co
o@X00ooo1003oo`=00?omRH00oo]B`03on1g00?od:H00on[_P03of6[00?o8IH00ol0PQ43o`1]=0Co
05Y80ol0@DP3o`0T>@?o01<]0ol02B<3o`047@?o008I0ol00QX3o`047@?o00TS0ol04R/4o`0P=P?o
03I30ol0D4d3o`1OA0?o06hb0ol0OQT3o`N=00?o;Y/00omJZ@03ohNe00?o]/400oo</`04omFJ00?o
gH400ooTJ`03onYG00?okTD00oob=P03ooDZ00?on2000ooj6@03oo/C00?oo0l00ool3004ood;00Ko
o@X00oom2`03oo`=00?ona400ooj5P03ooPN00?omRT00oob=`03one:00?oif001?oON`03omFI00?o
b;/00onH^P03oe^Y00?o8IL00ol0PPl3o`1/=@?o05M:0ol0=T<3o`0I<@Oooooo0Ol00001ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`?o03U40ol07SD3o`0>:@?o00LP0ol00a/3o`026@?o00<K
0ol01Ql3o`0;9@?o018/0ol073@4o`0Y?0?o03M40ol0Ad/3o`1BC@?o05Q90ol0GDD3o`1R@@?o06Dn
0ol0Ic/6o`1Y>P?o06Pj1?l0Ic`3o`1T?`?o06520ol0GDH3o`1HBP?o059=0ol0BT`3o`0lAP?o02lo
0ol093T3o`0J<P?o018/1?l032H3o`078@?o00@M0ol00aX3o`026@?o008J0ol011`3o`078@?o00dX
0ol06343o`0Y?0Co04=90ol0F4T3o`1Y>@?o07/M0ol:SP03od2Q00?oP;@00oo5`P03omJG00?oi6/0
0oo_@@03ooPO00Coo@X00ooo1003oo`=00?omRH00oo]B`03on1g00?od:H00on[_P03of6[00?o8IH0
0ol0PQ43o`1]=0Co05Y80ol0@DP3o`0T>@?o01<]0ol02B<3o`047@?o008I0ol00QX3o`047@?o00TS
0ol04R/4o`0P=P?o03I30ol0D4d3o`1OA0?o06hb0ol0OQT3o`N=00?o;Y/00omJZ@03ohNe00?o]/40
0oo</`04omFJ00?ogH400ooTJ`03onYG00?okTD00oob=P03ooDZ00?on2000ooj6@03oo/C00?oo0l0
0ool3004ood;00Koo@X00oom2`03oo`=00?ona400ooj5P03ooPN00?omRT00oob=`03one:00?oif00
1?oON`03omFI00?ob;/00onH^P03oe^Y00?o8IL00ol0PPl3o`1/=@?o05M:0ol0=T<3o`0I<@Oooooo
0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o03U40ol07SD3o`0>:@?o00LP0ol0
0a/3o`026@?o00<K0ol01Ql3o`0;9@?o018/0ol073@4o`0Y?0?o03M40ol0Ad/3o`1BC@?o05Q90ol0
GDD3o`1R@@?o06Dn0ol0Ic/6o`1Y>P?o06Pj1?l0Ic`3o`1T?`?o06520ol0GDH3o`1HBP?o059=0ol0
BT`3o`0lAP?o02lo0ol093T3o`0J<P?o018/1?l032H3o`078@?o00@M0ol00aX3o`026@?o008J0ol0
11`3o`078@?o00dX0ol06343o`0Y?0Co04=90ol0F4T3o`1Y>@?o07/M0ol:SP03od2Q00?oP;@00oo5
`P03omJG00?oi6/00oo_@@03ooPO00Coo@X00ooo1003oo`=00?omRH00oo]B`03on1g00?od:H00on[
_P03of6[00?o8IH00ol0PQ43o`1]=0Co05Y80ol0@DP3o`0T>@?o01<]0ol02B<3o`047@?o008I0ol0
0QX3o`047@?o00TS0ol04R/4o`0P=P?o03I30ol0D4d3o`1OA0?o06hb0ol0OQT3o`N=00?o;Y/00omJ
Z@03ohNe00?o]/400oo</`04omFJ00?ogH400ooTJ`03onYG00?okTD00oob=P03ooDZ00?on2000ooj
6@03oo/C00?oo0l00ool3004ood;00Koo@X00oom2`03oo`=00?ona400ooj5P03ooPN00?omRT00oob
=`03one:00?oif001?oON`03omFI00?ob;/00onH^P03oe^Y00?o8IL00ol0PPl3o`1/=@?o05M:0ol0
=T<3o`0I<@Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o01P`0ol02bD3
o`057PKo00<J0ol01Ah3o`0:90?o014[0ol07C@3o`0]?P?o04181?l0DDd3o`1JB0?o06=10ol0JSP3
o`1`<0?o07DX0ol0NB43o`1l70?o07hH0ol0OaL3o`1n5`?o07dJ1?l0Nah3o`1h8`?o07@Z0ol0Kc43
o`1Y>@?o06=00ol0G4L3o`1DC0?o04Y=0ol0>DD3o`0Z?@?o01he1?l052d3o`0=9`?o00PQ0ol011d3
o`036P?o008I0ol00aX3o`057@?o00TS0ol04B/3o`0O=@Co03A20ol0DDd3o`1R@@?o07@Z0ol0Q`D3
obfK00?oK:h00ond`@03om:R00?ohG@00oo]B@03ooLT00Coo@`00ooo1003ood<00?omb@00oo]B@03
on1g00?od:L00onX_P03oebZ00?o79D00ol0OaD3o`1Z=`Co05M:0ol0>dD3o`0P=P?o010Z0ol01b43
o`036`?o008I0ol00aX3o`067`?o00`V0ol05c04o`0Z?0?o04E:0ol0FDT3o`1Y>@?o07TQ0ol0R@03
obNI00?oEJL00on6]@03okW200?ocJl00ooGT`04on1h00?oiel00oo]B@03oo8f00?omRL00ooi6`03
oo/A00?oo@/00oon1P03ool300?oo`800ooo0@0Cool000?oo`400ooo1003ood800?oo1000ooi7003
ooD[00Col4000ooYFP03omml00?odj000oo4a003oh6d00?o@:400ol3R`03o`1d:P?o05e60ol0@4P7
ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`0H<0?o00/U0ol01Ah6o`03
6P?o00DN0ol02R@3o`0A:`?o01dd0ol0;Ch3o`10B0Co055=0ol0FTP3o`1S@@?o06Xh0ol0L303o`1e
:0?o07TQ0ol0O1`3o`1n60?o07lG0ol0OQL3o`1m6PCo07/N0ol0N2<3o`1d:P?o06la0ol0JCT3o`1S
@0?o05a70ol0E4`3o`1:C@?o03U50ol0:Sd3o`0N=@Co01@]0ol03BL3o`088@?o00@M0ol00aX3o`02
6@?o00<J0ol01Ad3o`098`?o014[0ol07cD4o`0d@P?o055=0ol0HT43o`1d:P?o08L50ol]V`03ofb^
00?o]<400ooBXP03on5d00?okDT00oog9004ood<00?oo`@00oom3003ooLT00?okDT00ooPM`03om2W
00?oZ;h00omLZP03oabE00?o07lE0ol0JSL4o`1GBP?o03]50ol083H3o`0@:P?o00LQ0ol00a/3o`02
6@?o00<J0ol01Ql3o`0<9P?o01L`1?l0:S`3o`15BP?o05U90ol0JCT3o`1i8@?o08T00olWV@03oeFW
00?oQ[D00oni`P03olf_00?oei<01?oPN003onMO00?okDT00oob=P03ooHW00?onA/00ook4@03ood;
00?ooPH00ooo0`03ool200?oo`404ooo0003ool100?oo`@00oom2003oo`@00?onA`00ooe:`04oo10
00?ojEX00ooOO003om>P00?oa<@00on1]003od2Q00?o0h/00ol0M2X3o`1MAP?o04181oooool1o`00
007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol06303o`0;9@?o00DN1_l00aX3o`057P?o
00XT0ol04B/3o`0M=0?o02dn0ol0@4P4o`1AC@?o05Y80ol0Hd43o`1Z>0?o070`0ol0MBP3o`1i8@?o
07`L0ol0OQP3o`1o5`?o07hG0ol0OAX4o`1k7P?o07PS0ol0M2X3o`1_<@?o06Ti0ol0Hd03o`1LA`?o
05A<0ol0BTd3o`0iA@?o02Xm0ol07SD4o`0D;@?o00dW0ol02243o`047@?o00<J0ol00QT3o`036P?o
00DM0ol02B<3o`0A:`?o01le1?l0=483o`1AC@?o06910ol0M2X3o`271@?o;I/00om/[P03okC100?o
dZ800ooQM003one900?omb@01?om3003ool400?oo@`00oog9003one900?oh7L00oo@Y`03ojRn00?o
G:X00olLU@03o`1o5@?o06Xg1?l0EdX3o`0kA@?o020f0ol042X3o`078@?o00<K0ol00QT3o`036P?o
00HO0ol032H3o`0G<0Co02Xl0ol0ADX3o`1IB@?o06Ti0ol0NB43o`2900?o9iT00omEY`03ohJe00?o
^L800oo=[`03omNC00Coh7P00ooWG`03one900?olSH00oof9`03ooTK00?ona400oom2`03ooh600?o
o`<00ooo0P03ool101?oo`000ooo0@03ool400?oo@P00ool4003ooTL00?omB/01?o`@003onUJ00?o
gg`00ooCX003olC400?oPK@00om0X@03o`>;00?o07@Z0ol0GDH3o`10B0Oooooo0Ol00001ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`?o00TS0ol011d3o`036P?o00@L0ol01b43o`0?:@?o01/c
0ol0;3h3o`13B@?o05E;0ol0H4<4o`1Z>0?o07<[0ol0Nad3o`233`?o08P20ol9S@03oa6A00?o69<0
0olKU003oabE00?o6Y@00olETP04o`j?00?o1H`00ol0Q`D3o`214@?o07/N0ol0M2X3o`1/=@?o06@o
0ol0FdL3o`1BC@?o04580ol0;cl4o`0P=P?o01D^0ol03BL3o`078@?o00@L0ol00QX3o`026@?o00<K
0ol01Ql3o`0<9P?o01L`1?l0:C`3o`15BP?o05]80ol0KC@3o`204`?o6i@00omIZ003oj6l00?ocZd0
0ooNOP03on]@00?omBT01?ol3`03ooh400?oo@/00oog8`03one800?oh7L00oo@Z003ojFm00?oF:P0
0olGT`03o`1m6P?o06Pk1?l0E4`3o`0e@P?o01`c0ol03BP3o`067`?o00<J0ol00QT3o`0370?o00PQ
0ol042X3o`0O=@Co03I30ol0DTd3o`1R@@?o07</0ol0Q0d3oaZD00?oBZ@00omn/`03okC100?ocJl0
0ooHT@03on5c00CojEP00oo`@003ooD]00?onAd00ook4@03ood900?ooP@00ooo0P03ool100?oo`80
0ooo0`03ooh500CooPH00oon1`06ooh800?ooPH00oon1@03ool300?oo`400ooo0003ool100?oo`@0
0oom2P04ooXE00?omRL00oo_@P03onIR00?ofhL00oo=[`03ojBm00?oEjP00olDT@03o`1j7`?o0691
1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol02B<3o`047@?o00<J0ol0
11`3o`078@?o00lY0ol06c<3o`0/?P?o04=90ol0ED/3o`1P@`Co06Xh0ol0Lb/3o`1k7@?o08<?0ol0
R083o`V=00?o4I400olHT`03oa^D00?o79D00olJU003oaFB00Co3Xl00ol5S003o`271@?o084A0ol0
Nah3o`1d:P?o06`e0ol0I3l3o`1KA`?o059=0ol0@DP3o`0_?`Co020f0ol05Bh3o`0=9`?o00LQ0ol0
11`3o`026P?o008I0ol00a/3o`067`?o00`V0ol05c04o`0Y?0?o04E:0ol0FdP3o`1]=0?o080C0olK
U003oeVX00?oXK`00oo>[@03omin00?oje000ooe:@04oo`?00?ooP@00oom2`03ooLS00?okDP00ooP
M`03om2X00?oYKd00omHZ003oaNC00?o07dJ0ol0J3/4o`1DC0?o03E20ol073<3o`0=:0?o00HO0ol0
0aX3o`026@?o00<L0ol02243o`0@:P?o01le1?l0=T<3o`1BC@?o06910ol0Lb`3o`243@?o6Y@00om:
Y003ogjc00?o]<400oo=[`03omRA00?ohG<01?oYF003oo1000?omBd00ooi7@03oo/A00?oo@T00oon
1003ool200?oo`400ooo0P03ool300?ooPD01?on1P03ooh700KooPP00oon1P03ooh500?oo`<00ooo
0@03ool000?oo`400ooo1003ood:00ConQD00oof9`03onm200?oiV800ooKQ`03olf_00?oY;d00omG
Z003oaBA00?o07XO0ol0HT47ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3
o`098`?o00@M0ol00aX3o`0470?o00LQ0ol03bT3o`0K<`?o02`n0ol0@dT3o`1EB`?o06131?l0JSP3
o`1c:`?o07/M0ol0P`l3o`280P?o2Hd00olAT@03oaRC00?o6i@00olLU@03oaZD00?o5I801?l>S`03
o`F<00?o08L50ol0PA43o`1k7P?o07@Z0ol0K3D3o`1T?`?o05]70ol0DTd3o`11B0?o02lo1?l083H3
o`0E;P?o00dW0ol01b43o`0470?o008J0ol00QT3o`036`?o00HO0ol032H3o`0G<0Co02Tl0ol0ADX3
o`1KB0?o06dd0ol0P1<3oa^D00?oFJP00onQ_003olj]00?ogWh00oo[D003ooDY00Coo0l00oon1003
ood;00?omb<00oo]B003on1g00?od:P00onU_@03oeRX00?o5i<00ol0OAX3o`1X>`Co05A<0ol0=D83
o`0L<`?o00dX0ol01Ql3o`036P?o008I0ol00a`3o`088@?o010Z0ol07cD4o`0f@`?o059=0ol0HT43
o`1c;0?o08@=0olJU003odZT00?oO[<00ond`@03olf_00?of9400ooQL`04onUH00?ol4000ooe;@03
ooTM00?ona400oom2@03ooh400?oo`800ooo0@03ool200?oo`<00oon1@04ooh600?ooPL01_on2003
ooh600?ooPD00ooo0`03ool100?oo`000ooo0@03ool400?oo@X01?oj5@03ooHW00?okd800ooVHP03
om^700?ocJl00onT_@03oeNX00?o59400ol0NQl3o`1R@@Oooooo0Ol00001ooooo`004oooool3o`00
00Oooooo00?o0000ooooooooool01Oooool3o`0470?o00<K0ol01Ah3o`0;9@?o01D_0ol09SX3o`0m
A`?o05A<0ol0HD83o`1^<`?o07TQ1?l0P`d3o`N<00?o6i@00ol^V`03ocjP00?oBj@00omEY`03oe^Y
00?oGZX00omMZP03oeVX00?oDJH01?m6X`03ocVO00?o:YX00olIU003o`R=00?o08D90ol0O1/3o`1c
:`?o06Ti0ol0Gd@3o`1EB`?o04E:1?l0<D03o`0P=P?o01@^0ol032H3o`0680?o00<K0ol00QT3o`02
6P?o00@L0ol02283o`0A:`Co01lf0ol0>4@3o`1DC0?o06Hm0ol0NR03o`b>00?oAj<00on>]`03olZg
00?ofhL00ooYF003oo@_00Cona800oon1@03ood:00?omb400oo^A`03on1f00?od:P00onR_003oeBW
00?o4i400ol0Nah3o`1U?PCo055=0ol0<403o`0H<@?o00/U0ol01Ah6o`026P?o00@M0ol02R@3o`0E
;P?o02Lk1?l0@dT3o`1JB0?o06/g0ol0O1/3o`Z>00?o>Il00om_[`03ojRn00?obk@00ooGT`03on5c
00?ojUH01?oa?003ooHW00?onQL00oom3003ooh500Koo`800oon1@03ood900?oo0h00ook4`03ooXH
00ConA`00ooh7`03ooPP00?on2400ooh7`03ooTM00?onQT00ook4`03oo`>00?oo@T00oon1@03ool2
00Coo`<00oom2P03ooTJ00?om3400oo/CP03on5b00?oe9/00onj`P03ofZ]00?o8YL00ol0OaH7oooo
o`7o00000Oooool001;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Gooooo0ol011`3o`036`?o00DN0ol02bD3o`0E;`?o02Hj0ol0?DL3o`1DC0?o06520ol0KS<3o`1i
8@Co08<=0ol7S003oa^D00?o;Y/00olnX003od^T00?oEJL00omKZ@03oejZ00?oGJX00omIZ003oe6V
00CoAZ<00oliW`03obZJ00?o6I@00ol8S@03o`252@?o07`K0ol0Lb/3o`1Y>@?o05m40ol0ED/3o`15
BPCo03500ol083H3o`0D;P?o00`V0ol01R03o`036`?o008I0ol00QX3o`0470?o00PR0ol04B/4o`0O
=P?o03Q40ol0E4`3o`1V?@?o07XP0ol<SP03odNS00?oS[L00oo:]`03om^700?ojEP00ood;`04oo/B
00?ooPD00oom2P03ooLQ00?okTL00ooPMP03om2X00?oX[`00omDY`03oa>A00?o07/N0ol0ICh4o`1A
C@?o03100ol06343o`0;9@?o00DN1_l00QX3o`047@?o00XT0ol05Bh3o`0W>`Co04=90ol0FTP3o`1[
=`?o07`K0ol:SP03ocVO00?oKjl00onX_P03ol^d00?oei<00ooQL`03onYF00ColC`00oof9`03ooXG
00?oo@`00oon1@06ool200?ooPD00oom2@03oo`>00?ona<00ooj6004ooTL00?on1l00ooh8003ooPQ
00?on1l00ooi7@03ooXI00?ona<00ool3P03ood900?ooPD00ooo0P04ool300?oo@X00ooi6P03oo@a
00?ok4h00ooQLP03omBK00?o^/800omZ[@03ob:G00?o07lF1oooool1o`00007ooooo000<ooooo`Go
00001Oooool00ol0003oooooooooo`04ooooo`?o00001Oooool3o`0470?o00<K0ol01Ah3o`0;9@?o
01D_0ol09SX3o`0mA`?o05A<0ol0HD83o`1^<`?o07TQ1?l0P`d3o`N<00?o6i@00ol^V`03ocjP00?o
Bj@00omEY`03oe^Y00?oGZX00omMZP03oeVX00?oDJH01?m6X`03ocVO00?o:YX00olIU003o`R=00?o
08D90ol0O1/3o`1c:`?o06Ti0ol0Gd@3o`1EB`?o04E:1?l0<D03o`0P=P?o01@^0ol032H3o`0680?o
00<K0ol00QT3o`026P?o00@L0ol02283o`0A:`Co01lf0ol0>4@3o`1DC0?o06Hm0ol0NR03o`b>00?o
Aj<00on>]`03olZg00?ofhL00ooYF003oo@_00Cona800oon1@03ood:00?omb400oo^A`03on1f00?o
d:P00onR_003oeBW00?o4i400ol0Nah3o`1U?PCo055=0ol0<403o`0H<@?o00/U0ol01Ah6o`026P?o
00@M0ol02R@3o`0E;P?o02Lk1?l0@dT3o`1JB0?o06/g0ol0O1/3o`Z>00?o>Il00om_[`03ojRn00?o
bk@00ooGT`03on5c00?ojUH01?oa?003ooHW00?onQL00oom3003ooh500Koo`800oon1@03ood900?o
o0h00ook4`03ooXH00ConA`00ooh7`03ooPP00?on2400ooh7`03ooTM00?onQT00ook4`03oo`>00?o
o@T00oon1@03ool200Coo`<00oom2P03ooTJ00?om3400oo/CP03on5b00?oe9/00onj`P03ofZ]00?o
8YL00ol0OaH5ooooo`?o00000Oooool001Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`?o00@M0ol01b43o`0?:@?o01dd0ol0<d43o`1?CP?o05i50ol0K3D3o`1j7`?o08L4
0olGT`04oc>M00?oCJD00omV[003ogbb00?oSKL00onJ^P03oj>m00?oZ;h00onY_P03ojNm00?oX;`0
0onE^@04ohRf00?oMk400omT[003odjU00?o=ih00olOUP03o`R=00?o08<>0ol0N283o`1]=0?o0691
0ol0ET/4o`16B`?o03100ol07SD3o`0B;0?o00XT0ol01Ah3o`036P?o008I0ol00a/3o`067`?o00`V
1?l06343o`0]?P?o04e>0ol0H4<3o`1d:P?o08T10olfWP03ogfc00?oa/000ooHT003onMO00?olc@0
1?ok5003ooh500?oo@T00ooh8003oni600?oh7H00oo?Z@03oj2l00?oD:H00ol>S`03o`1i8P?o06=0
1?l0Cdh3o`0[?@?o01D_0ol02B<3o`0470?o008I0ol00aX3o`067`?o00dW0ol06c83o`0a@0Co051>
0ol0HT83o`1d:P?o08H70olUV003oe^Y00?oU[T00oo8_003omFJ00?oh7L00ooYE`03oo4l00CombD0
0ook5003ood900?oo`<00ooo0P03ooh500?oo@/00ook4`03ooTL00?ombD00ood;P03oo8f00ColC`0
0oo_@@03oni500KokTH00oo_@`03oo0n00?olSL00ood;`03ooHV00?onAd00ook4`04ood;00?ooPL0
0oom2`03ooXE00?omRH00oo`@003onIR00?oei800oo6`P03ogNa00?o;9X01oooool1o`00007ooooo
000Booooo`Co00001oooool00ol0003oooooooooo`05ooooo`?o00@M0ol01b43o`0?:@?o01dd0ol0
<d43o`1?CP?o05i50ol0K3D3o`1j7`?o08L40olGT`04oc>M00?oCJD00omV[003ogbb00?oSKL00onJ
^P03oj>m00?oZ;h00onY_P03ojNm00?oX;`00onE^@04ohRf00?oMk400omT[003odjU00?o=ih00olO
UP03o`R=00?o08<>0ol0N283o`1]=0?o06910ol0ET/4o`16B`?o03100ol07SD3o`0B;0?o00XT0ol0
1Ah3o`036P?o008I0ol00a/3o`067`?o00`V1?l06343o`0]?P?o04e>0ol0H4<3o`1d:P?o08T10olf
WP03ogfc00?oa/000ooHT003onMO00?olc@01?ok5003ooh500?oo@T00ooh8003oni600?oh7H00oo?
Z@03oj2l00?oD:H00ol>S`03o`1i8P?o06=01?l0Cdh3o`0[?@?o01D_0ol02B<3o`0470?o008I0ol0
0aX3o`067`?o00dW0ol06c83o`0a@0Co051>0ol0HT83o`1d:P?o08H70olUV003oe^Y00?oU[T00oo8
_003omFJ00?oh7L00ooYE`03oo4l00CombD00ook5003ood900?oo`<00ooo0P03ooh500?oo@/00ook
4`03ooTL00?ombD00ood;P03oo8f00ColC`00oo_@@03oni500KokTH00oo_@`03oo0n00?olSL00ood
;`03ooHV00?onAd00ook4`04ood;00?ooPL00oom2`03ooXE00?omRH00oo`@003onIR00?oei800oo6
`P03ogNa00?o;9X01oooool1o`00007ooooo000Booooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01Oooool3o`047@?o00LQ0ol03bT3o`0M=0?o03=10ol0Cdh3o`1NA@?o06`e0ol0NQl3
o`2710?o5i<01?lcW@03odfU00?oIZ`00oml/P03ohfg00?oV[X00onS_@03ojRn00?oZKh00onW_@03
oj2l00?oUKT01?n8]P03ogNa00?oI:`00om>Y@03ocNN00?o7iH00ol8S@03o`233P?o07PR0ol0KC@3
o`1R@@?o05I;1?l0AT/3o`0`@0?o01he0ol04R`3o`0:90?o00DN0ol00aX3o`026@?o00<K0ol01Ql3
o`0<9PCo01Pa0ol0;Ch3o`1=CP?o06130ol0M2X3o`290@?o=Yh00omm/`03olK000?of9000ooWG`03
oo<d00Cona@00oon1@03ood900?on2000oo^AP03on1f00?ocjT00onP_003oe2V00?o3Xl00ol0NB83
o`1S@0Co04m>0ol0:cd3o`0E;`?o00TS0ol011`3o`026@?o00<J0ol01Ql3o`0=9`?o01/b0ol0<D04
o`1@CP?o06920ol0M2X3o`261`?o9IP00omKZ@03oiJi00?ob;`00ooEVP03on1g00?ojEL00ooa?004
ooLU00?ona@00oom2@03ool300?oo`800oon1@03ood;00?ona<00ooi7003ooLU00?om2h00oob=P04
oo4l00?okd400oo^A@06oni600?okd<00oo`?P03oo8g00?om2l00oof9P03ooTM00?ona<01?om2`03
ooh700?oo@/00ooj5@03ooHV00?ol4000ooVHP03omNB00?oa/800omg/@03obbJ00Oooooo0Ol00001
ooooo`004_ooool5o`0000Kooooo00?o0000ooooooooool01Oooool3o`0:90?o01<]0ol093T3o`0o
A`?o05Q:0ol0Ic/3o`1g9@?o08H70olJU003ocnQ00?oHZ/01?n3]003oj2l00?o^l800oo7_@03ol^d
00?ocZd00oo?Z@06om2W00?ocjX00oo=[`03olZf00Coakl00onj`P03oj>l00?oRKH00om^[`03oe2V
00?o<id00olFTP03o`2710?o07/M0ol0Kc43o`1S@@Co05I;0ol0@dT3o`0/?P?o01/c0ol03bT3o`08
8P?o00@L0ol00QX3o`026@?o00@L0ol02B<4o`0B;0?o02@i0ol0@4P3o`1JB0?o06hc0ol0P`h3obNI
00?oK:h00onl``03omFI00?oiFL00ooa>@04ooXG00?ooPH00oom2@03ooPO00?okTD00ooPMP03olnZ
00?oWK/00om=Y@03o`Z>00?o07LU0ol0HD84o`1:C0?o02Lk0ol04b`3o`088P?o00<K0ol00QT3o`03
6`?o00LQ0ol042X3o`0Q=`?o03e61?l0EdX3o`1Y>@?o07`K0ol>S`03od:R00?oO[<00onm``03om6T
00?ogH000ooXG@03oo0o00?omRH01?ok5003ood800?oo`<00ooo1003ood900?ona800ooh7@03ooDZ
00?olSL00oo_A003on]@00?oj5/01?oVI003onA[00?ohW001_oQL`03on9a00?ohfd00ooUIP03onQM
00?oje800oo^AP03oo8h00ComRT00ooi7003ooXE00?ona<00ooj5P03ooLR00?olSL00ooWH003omV>
00?ob;d00on0/`07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`0:90?o
01<]0ol093T3o`0oA`?o05Q:0ol0Ic/3o`1g9@?o08H70olJU003ocnQ00?oHZ/01?n3]003oj2l00?o
^l800oo7_@03ol^d00?ocZd00oo?Z@06om2W00?ocjX00oo=[`03olZf00Coakl00onj`P03oj>l00?o
RKH00om^[`03oe2V00?o<id00olFTP03o`2710?o07/M0ol0Kc43o`1S@@Co05I;0ol0@dT3o`0/?P?o
01/c0ol03bT3o`088P?o00@L0ol00QX3o`026@?o00@L0ol02B<4o`0B;0?o02@i0ol0@4P3o`1JB0?o
06hc0ol0P`h3obNI00?oK:h00onl``03omFI00?oiFL00ooa>@04ooXG00?ooPH00oom2@03ooPO00?o
kTD00ooPMP03olnZ00?oWK/00om=Y@03o`Z>00?o07LU0ol0HD84o`1:C0?o02Lk0ol04b`3o`088P?o
00<K0ol00QT3o`036`?o00LQ0ol042X3o`0Q=`?o03e61?l0EdX3o`1Y>@?o07`K0ol>S`03od:R00?o
O[<00onm``03om6T00?ogH000ooXG@03oo0o00?omRH01?ok5003ood800?oo`<00ooo1003ood900?o
na800ooh7@03ooDZ00?olSL00oo_A003on]@00?oj5/01?oVI003onA[00?ohW001_oQL`03on9a00?o
hfd00ooUIP03onQM00?oje800oo^AP03oo8h00ComRT00ooi7003ooXE00?ona<00ooj5P03ooLR00?o
lSL00ooWH003omV>00?ob;d00on0/`07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool0
1Oooool3o`0:90?o01<]0ol093T3o`0oA`?o05Q:0ol0Ic/3o`1g9@?o08H70olJU003ocnQ00?oHZ/0
1?n3]003oj2l00?o^l800oo7_@03ol^d00?ocZd00oo?Z@06om2W00?ocjX00oo=[`03olZf00Coakl0
0onj`P03oj>l00?oRKH00om^[`03oe2V00?o<id00olFTP03o`2710?o07/M0ol0Kc43o`1S@@Co05I;
0ol0@dT3o`0/?P?o01/c0ol03bT3o`088P?o00@L0ol00QX3o`026@?o00@L0ol02B<4o`0B;0?o02@i
0ol0@4P3o`1JB0?o06hc0ol0P`h3obNI00?oK:h00onl``03omFI00?oiFL00ooa>@04ooXG00?ooPH0
0oom2@03ooPO00?okTD00ooPMP03olnZ00?oWK/00om=Y@03o`Z>00?o07LU0ol0HD84o`1:C0?o02Lk
0ol04b`3o`088P?o00<K0ol00QT3o`036`?o00LQ0ol042X3o`0Q=`?o03e61?l0EdX3o`1Y>@?o07`K
0ol>S`03od:R00?oO[<00onm``03om6T00?ogH000ooXG@03oo0o00?omRH01?ok5003ood800?oo`<0
0ooo1003ood900?ona800ooh7@03ooDZ00?olSL00oo_A003on]@00?oj5/01?oVI003onA[00?ohW00
1_oQL`03on9a00?ohfd00ooUIP03onQM00?oje800oo^AP03oo8h00ComRT00ooi7003ooXE00?ona<0
0ooj5P03ooLR00?olSL00ooWH003omV>00?ob;d00on0/`07ooooo`7o00000Oooool001gooooo00?o
0000ooooooooool01Oooool3o`0G<0?o02/m0ol0Bdd3o`1NA@?o070`0ol0P1<3oa2@00?o>Il00omU
[003oi:h00?o^L801?o9^003om2W00?oeIT00ooIS003omb300?ogWd00ooONP03on1i00?oggX00ooN
OP03omb400?ofHd01?oEV003om6T00?oc;<00oo5``03ojRn00?oQkD00omT[003od6Q00?o7iH00ol0
R@03o`1m6`?o06la1?l0HD83o`1DC0?o03i70ol09cX3o`0F;`?o00`V0ol01Ql3o`036`?o008I0ol0
0a/3o`0680Co00hX0ol073@3o`0e@`?o05A<0ol0J3/3o`1m6@?o6I<00omLZP03ojbo00?odZ400ooS
KP03oo0o00ConAX00oon1`03ood800?on1h00oo_A003on5e00?ocjX00onJ^P03odVT00?o1X`00ol0
MBP3o`1NA@Co04A:0ol08cP3o`0@:P?o00LP0ol00aX3o`026@?o00@L0ol02B<3o`0E;P?o02Tl0ol0
BD`4o`1NA@?o074^0ol0Q@T3obJH00?oHJ/00onR_003olbc00?ofH`00ooUI`03oni500?omBX00ooj
5@04ood900?oo`<00oon1@03ood<00?onQP00oof9P03oo8g00?okTP00ooYF003onAX00?oh7L00ooL
P`04omV>00?oeYH00ooDW003om:P00?odZ800ooBX@03om>N00?oeIP00ooHT003omb500?oh7P00ooT
J004onYG00?okTD00oob=P03ooHY00?on2000ooi7@03ooLS00?ol3h00ooVHP03omV=00?ob;/01ooo
ool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol05c03o`0[?@?o04]=0ol0GTD3
o`1`<0?o080C0ol@T003ocVO00?oIJ`00onB^003okW200CobKP00oo@Y`03omFI00?ofH`00ooLP`03
omim00?oggX00ooPN@03ommj00?ogWh00ooLQ003omV=00CoeIP00ooAY003olbc00?oaL<00onX_P03
ohNe00?oI:`00om1X@03oanF00?o08T00ol0OA/3o`1_<@Co06520ol0E4`3o`0nA`?o02Lj0ol05Rl3
o`0<9P?o00HO0ol00a/3o`026@?o00<K0ol01R04o`0>:0?o01`d0ol0=D<3o`1DC0?o06Pk0ol0OAT3
oaVC00?oG:X00on/_`03om:Q00?ohfh00oo`?`04ooTJ00?ooPL00oom2003ooPN00?okd@00ooQM@03
olnZ00?oV[X00om9Y003o`J<00?o07DX0ol0GTD4o`14BP?o02<h0ol042X3o`0780?o00<J0ol00QT3
o`0470?o00TS0ol05Bh3o`0Y?0?o04U<1?l0GTD3o`1a;P?o08D90olVV003of6[00?oX[`00oo</`03
omV<00?oiFL00oo^A@03ooDZ00?onQD01?om2@03ool300?ooPD00oom3003ooXH00?omRH00oob=`03
oni800?ojEP00ooTJ003on1g00?og8<01?oISP03omJF00?oe9`00ooBX003om:R00?odZ400ooCWP03
omFH00?of9000ooLQ@03on1h00?oi6P01?oZE`03oni500?olSH00oof:@03ooPP00?onAd00oog8`03
oo0n00?oiV800ooIS@03olRk00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05oooo
o`?o01L`0ol0:cd3o`1;C@?o05i50ol0L303o`204`?o49000oliW`03ofF/00?oT[P00oni`P04olVh
00?od:L00ooEV@03omV<00?og8<00ooNO@03ommj00?oh7T00ooONP03omin00?og8@00ooIS@04omFH
00?odJ@00oo</`03olG300?oZ;h00on7]@03ofB/00?o@J400olOUP03o`2900?o07dK0ol0Kc44o`1Q
@P?o05A<0ol0?TL3o`0W>P?o01H_0ol032H3o`067`?o00<K0ol00QT3o`036`?o00HP1?l03RP3o`0L
=0?o03E30ol0E4`3o`1X>`?o07dI0olIT`03oebZ00?o[;l00ooBX@03on=^00?ol3l01?oi6P03ooh7
00?oo@P00ooh7P03onm400?ohGD00oo?ZP03oiZj00?oBJ@00ol6S003o`1e:0?o05i51?l0A4X3o`0S
>0?o010Z0ol01b03o`036P?o008I0ol011`3o`098`?o01D^0ol0:C`3o`19C0Co05i50ol0LBh3o`25
2@?o9YP00omQZ`03oj:l00?oc;<00ooIS003onEW00?okTD00ooe:P03ooXE00Coo@T00ooo0`03ooh5
00?oo@`00ooj6003ooHV00?olSL00oo^B003onUH00?oi6P00ooPM`03omb300CofHh00ooFUP03omBL
00?odZ000ooBXP03om:Q00?odih00ooEV003omR@00?og8D00ooPN003onAX00CojUL00oo^A@03oo8f
00?omRT00ooh8003ooTM00?omb<00oo`?P03onIR00?ofHd00oo8^`07ooooo`7o00000Oooool001go
oooo00?o0000ooooooooool01Oooool3o`0a@0?o055=0ol0Hd03o`1f9`?o08P20olXV@03oeNX00?o
R;H00onj`P03olf`00?oeIT01?oKQP03on5e00?oiFL00ooXG003onYD00?oje001_o/C@03on]@00?o
jU@00ooXF`03onIT00CohW000ooNOP03omV>00?odil00oo</`03ol3300?oVKX00oma[`03odVT00?o
8iL00ol0RP03o`1l70Co06dd0ol0GT@3o`1@CP?o03E30ol083H3o`0A:`?o00TS0ol011d3o`026@?o
008J0ol01Ad4o`0:9@?o01H_0ol0;3h3o`1?CP?o06910ol0N2<3o`b?00?oCZD00onM^`03olnY00?o
hGD00oo_A004ooPN00?oo@P00oon2003ooTL00?okd<00ooQM@03oln[00?oV;X00om5X`03o`>;00?o
07<[0ol0G4H4o`10B0?o020f0ol03RP3o`067`?o008J0ol00QT3o`057P?o00`V0ol06C83o`0b@@?o
059=1?l0ICh3o`1i8@?o2Hd00om0X@03oh2d00?oaL@00ooDW003on5e00?oje000ood<@03ooTI00?o
o@X01?on1003ooh500?oo0h00ooi6`03ooD]00?ol4000ooZE@03onAY00?ogWd00ooISP03om>N00?o
cZ/01?o:]`03olNo00?o`/@00oni`P06okG100?o^<800oo0a003olK000?ob[L00oo>Z`03omBM00Co
fX/00ooPN003onIU00?oje400oo`?`03oo@`00?omRL00ooc<`03one800?oi6P00ooHT007ooooo`7o
00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`0a@0?o055=0ol0Hd03o`1f9`?o08P2
0olXV@03oeNX00?oR;H00onj`P03olf`00?oeIT01?oKQP03on5e00?oiFL00ooXG003onYD00?oje00
1_o/C@03on]@00?ojU@00ooXF`03onIT00CohW000ooNOP03omV>00?odil00oo</`03ol3300?oVKX0
0oma[`03odVT00?o8iL00ol0RP03o`1l70Co06dd0ol0GT@3o`1@CP?o03E30ol083H3o`0A:`?o00TS
0ol011d3o`026@?o008J0ol01Ad4o`0:9@?o01H_0ol0;3h3o`1?CP?o06910ol0N2<3o`b?00?oCZD0
0onM^`03olnY00?ohGD00oo_A004ooPN00?oo@P00oon2003ooTL00?okd<00ooQM@03oln[00?oV;X0
0om5X`03o`>;00?o07<[0ol0G4H4o`10B0?o020f0ol03RP3o`067`?o008J0ol00QT3o`057P?o00`V
0ol06C83o`0b@@?o059=1?l0ICh3o`1i8@?o2Hd00om0X@03oh2d00?oaL@00ooDW003on5e00?oje00
0ood<@03ooTI00?oo@X01?on1003ooh500?oo0h00ooi6`03ooD]00?ol4000ooZE@03onAY00?ogWd0
0ooISP03om>N00?ocZ/01?o:]`03olNo00?o`/@00oni`P06okG100?o^<800oo0a003olK000?ob[L0
0oo>Z`03omBM00CofX/00ooPN003onIU00?oje400oo`?`03oo@`00?omRL00ooc<`03one800?oi6P0
0ooHT007ooooo`7o00000Oooool001gooooo0_l00006ooooo`?o03500ol0DDd3o`1S@0?o07HW0ol0
R083obRI00?oEjP00on8]P03ok[200?ocK000ooEV@04om^600?ohGD00ooUI`03onQL00?ojU@00oo[
D006ona=00?oje000ooZE003onQK00?oiV@01?oRL003omin00?ofHh00ooCW`03olbc00?o`<<00onI
^P03og6_00?oBJ@00olSU`03o`2:00?o07`L1?l0KC@3o`1NA0?o051>0ol0=D<3o`0P=P?o014[0ol0
2B<3o`047@?o008I0ol00QX3o`057@Co00XU0ol05Rl3o`0/?P?o04m>0ol0HT43o`1h8`?o38l00om>
Y@03oifk00?ocjT00ooQM@03onm400Con1h00oom2003ooh800?onA`00oo_@`03on5e00?ocj/00onH
^P03odFS00?o0h/00ol0Lb/3o`1LAPCo04180ol083H3o`0>:0?o00HO0ol00QX3o`026@?o00DN0ol0
32H3o`0I<P?o03910ol0DTd4o`1U?P?o07TQ0ol9S@03od2Q00?oP;@00oo5a003omBL00?ohGD00oo[
D003oo@a00?onAT00oom2P04ooh400?ooPD00ool3P03ooTK00?omBd00oo`@003onYE00?oi6T00ooN
O@03omV>00?odih00oo>Z`04olZg00?oakl00oo2a003okW200Ko]L400onh`P03ol3400?oa/000oo:
]`03olj[00?oe9d01?oJR`03on1h00?oiVD00oo[D@03oo0o00?om3000oof9`03oo<c00?okDP00ooT
J003omR@00Kooooo0_l00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o05A<0ol0IS`3
o`1j80?o28d00olmX003og6_00?oYkd00oo:]`03omFJ00?ogWh00ooUJ004onYF00?okTP00ooa?003
oo<c00?omBd00ooe:P03ooDY00?omBX00ooe;003oo@a00?olSL00oo`@004one;00?ojET00ooTJ@03
omml00?of9400oo@Y`03olNo00?oXkd00omg/@03od^T00?o8IL00ol0R0<4o`1i8P?o06Ti0ol0FTP3
o`17B`?o02`m0ol06C43o`0=9`?o00HO0ol00aX3o`026@?o00<K1?l02283o`0B:`?o02@i0ol0A4X3
o`1MA@?o07<[0ol0RP03od2Q00?oSkL00oo</@03omil00?okDT01?oh8@03ood:00?ooPP00ooi6`03
onm200?ohGD00oo>Z`03oiFi00?o@Z800ol0R@03o`1a;P?o05Y81?l0>dD3o`0M=0?o00`W0ol01Ah3
o`026@?o00<J0ol01Ql3o`0>:@?o01lf0ol0?4H3o`1HB@Co06`e0ol0PA83oajE00?oG:T00onQ_003
olf`00?ofhL00ooWGP03oo4k00?on2000ool3P07ooh500?oo0h00ooi7003oo@`00?okTH00ooWGP03
on5e00?ofH`00ooBX@03olbc00?oaL800on``004oi^j00?oR[H00omm/`03ogB`00?oKZl00om/[P03
ofj_00?oM;000omm/`03oh^f00?oWK/00ond`@04olNn00?ocZ`00ooEV@03omb300?ohf`00ooZEP03
onm200?ol3l00oo^A@03onYE00?ohW401oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo
00Gooooo0ol0E4`3o`1V?0?o07XP0ol8S@03ocfP00?oLJl00onW_@03olZg00?oeIX00ooNOP03onEX
00CojUH00oo^B003oo4l00?olc<00ooe;@03ooDZ00?omBT00ooe:P03ooD/00?om3400oob=`03oo10
00CokD/00ooYF@03onAY00?ogg`00ooHT@03om2W00?oakl00onS_@03ogNa00?oBj@00olQU`03o`28
0`Co07TR0ol0JCT3o`1JB0?o04M;0ol0;3d3o`0I<@?o00dW0ol01Ql3o`036P?o008I0ol00a/4o`08
8P?o018[0ol093T3o`14BP?o05e50ol0Lb/3o`2:00?o@:400on?]`03olba00?ogW`00oo]B@04ooPQ
00?oo@X00oon2003ooTK00?okd800ooQM@03olj[00?oUKT00om2XP03o`2900?o074^0ol0FTP4o`0k
A@?o01dd0ol032L3o`057P?o008I0ol00aX3o`067`?o00hY0ol07cH3o`0lAP?o05Q91?l0K3D3o`21
4P?o7YD00omLZ@03oj6l00?ocK000ooKQ`03onMN00?olC/00ooh8003oo`>00OooPD00ool3P03ooTL
00?om3000oo^AP03onMN00?ohGD00ooIS003om:Q00?oc;<00oo5`P03ok3000CoVkX00on:]P03ogfc
00?oM;000om^[`03ofb^00?oKZl00omd/003ogfc00?oRkH00onM^`03okC100Coakh00oo>[003omFI
00?og8<00ooSK003onYF00?okd800oo`?`03oni500?ojUD00ooRL@07ooooo`7o00000Oooool001go
oooo00?o0000ooooooooool01Oooool3o`1DC0?o06Hl0ol0NR03o`R=00?o?J000oma[`03ojNm00?o
b[L00ooEVP03omin00?oiFP01?oZEP03oni800?olC`00ooc<`03ooD]00?omBX00ooe:@03ooDZ00?o
mB`00ood<@03oo8g00?ol4001?o]B`03onUI00?oi6T00ooOO003omRA00?od:L00oo7_`03oj>m00?o
Mk400om;Y003ob6G00?o08P31?l0NB83o`1Y>@?o05Y80ol0Ad/3o`0/?@?o01Ta0ol03BL3o`067`?o
00<J0ol00QT3o`036`Co00PR0ol04R/3o`0T>@?o04A:0ol0GDD3o`1c:`?o08X00om0X@03ohng00?o
c;400ooNO003one900Con2400oom2P03ooh800?onA/00oo_@P03on5e00?ocZ/00onE^@03od:R00?o
08T00ol0LBh3o`1JB0Co03]50ol07C@3o`0<9`?o00DN0ol00QT3o`036P?o00HO0ol03RT3o`0O=P?o
03a60ol0F4T4o`1/=@?o084B0olNU@03oebY00?oXK`00oo=/003om^700?oieh00ooa>`03ooPP00?o
o0h01oon1@03oo`>00?onA`00ood<003oni600?oieh00ooQM@03omV<00?odZ400oo</`03olG200?o
/<001?nK^P03ohZf00?oOK<00omd/003ofj_00?oK:h00om^[`03ogB`00?oOK<00on;]P03oifk00?o
]<401?o7_P03olj/00?oeIT00ooLP`03on=/00?ojUH00oo_@P03oo0o00?okTD00ooZE@03on9a00Oo
oooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o06Tj0ol0O1/3oa2@00?oAj<0
0on7]@03ol3300?od:P00ooJR@03onA/00?oje000oo`?P04oo@`00?ombD00ooi7003ooXF00?ona80
1_ol4003oo/A00?ona<00ooj5`03ooTL00?omb<01?oe;@03oo4i00?okDP00ooYFP03on9_00?ofhL0
0ooCX003olVj00?oY[d00omf/@03odJS00?o6Y@01?l0Q0/3o`1d:@?o06@o0ol0E4`3o`0jA@?o024g
0ol04R`3o`088P?o00@L0ol00QT3o`036PCo00HO0ol03RP3o`0N=@?o03Y50ol0F4T3o`1^<`?o08D9
0olcW@03oh6d00?obKT00ooLP`03ona?00Comb@00oom2`03ooh700?onAX00oo_@@03on5e00?ocZ`0
0onC^003ocnQ00?o08P30ol0Kc43o`1HB@Co03M30ol06S83o`0;9@?o00@M0ol00QT3o`036`?o00LQ
0ol04B/3o`0U>P?o04I;0ol0GTD4o`1c:`?o08P20oleW@03ogRa00?o`L@00ooDW003on9a00?okDX0
0ooe:P03oo/C00?ooPL00oon1@04ood<00?onA/00ood<003one800?oiV<00ooNO@03omJF00?ocZh0
0oo6`P03ojRn00?oRkL00omc/004oejZ00?oCZD00om1X@03ocNN00?o<I`00ol^V`03obnK00?o<Y`0
0oliW`03od>R00?oDZH00omU[004ogfc00?oV[X00onj`P03olZf00?odil00ooKQP03on=/00?oj5h0
0ooZEP03onUG00?oiV@01oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0
JCX3o`1l6`?o49000om7X`03ohNe00?o`<<00oo@Z003omZ900?oi6`00oo[D003oo0n00Com3000oog
9@03ooTL00?onQH00ook4P06oo`@00?ona400ook4`03ooXG00?onA`00oog8`04ooD]00?olCT00oo]
B003onUJ00?ohVl00ooKQ`03om>P00?obKX00onV_@03ogJa00?oAZ<00olJU004o`242`?o07@Y0ol0
I3l3o`1DC0?o03Y50ol08CL3o`0B;0?o00PR0ol011`3o`026@?o00<J1?l01Ql3o`0>:0?o01he0ol0
>TD3o`1HB@?o06hc0ol0Q@T3oc>M00?oPK@00oo9^@03omb300?ok4l01?og9003ood;00?ooPL00ooi
6P03onm100?ohGD00oo>[003oi>h00?o?j400ol0R0<3o`1_<@?o05Q91?l0=d<3o`0J<P?o00/U0ol0
11d3o`026@?o00<K0ol01b43o`0A:`?o02Dj0ol0AT/3o`1NA@Co07<[0ol0R083ocFM00?oN;400oo1
a003omBL00?ohW400oo]BP03ooDZ00?ona<00oon1`03ooh500Coo@`00ooi6`03oo@`00?okDP00ooV
H`03omim00?oeYH00oo>[P03olK200?oZ;h00on;]`03og>`00CoGZX00om>Y@03od6Q00?o=ih00ola
W003objK00?o;i/00olbW003ocVO00?o@j800omBYP03ofF/00CoOK<00onJ^P03ok[200?ob[H00ooC
W`03om^600?ohf`00ooXGP03onYF00?ojEL00ooVI007ooooo`7o00000Oooool001gooooo00?o0000
ooooooooool01Oooool3o`1Y>P?o07`K0ol@T003odNS00?oQkD00oo0``03om2X00?ofXT00ooTK003
on]@00?ol3h01?od<003ooLU00?onA`00ooj5P03oo/B00Koo1000ook4@03oo/C00?onQL00ooi7003
ooLS00ComBd00ooa>@03one800?ojEX00ooRK`03om^700?odj000oo9^P03ojJm00?oM[400om6X`03
oaZD00Co08@;0ol0M2T3o`1T?`?o05A<0ol0>TD3o`0Q=`?o018/0ol02283o`0470?o008I0ol00aX4
o`067`?o00hX0ol07SD3o`0jA@?o05Q90ol0KS<3o`252@?o<id00on1]003olVi00?og8<00oo/C`04
ooLT00?oo@/00oon1`03ooTJ00?okd400ooQM@03olj/00?oTkP00oloX@03o`280`?o06la0ol0F4T4
o`0g@`?o01Xb0ol02bD3o`047@?o008I0ol00a/3o`078@?o014[0ol09CX3o`16B`?o05i51?l0Lb/3
o`280P?o=Id00omh/@03ol7400?oe9`00ooRL@03one:00?omBX00ook4`03ooh700?ooPD01?om3003
ooTK00?om3000oo]B003onIS00?ogWd00ooFUP03olj^00?oa/800onX_P03oh^g00?oLk001?mNZP03
odjU00?o@J400olgWP03oc6L00?o;Y/00ol_V`03oc:L00?o>Il00om3XP03oe:V00?oIJ`01?mm/`03
oiZj00?o^/800oo:]P03om>O00?ofhH00ooSK003onQN00?ojUH00ooYE`03onIT00Oooooo0Ol00001
ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o07dI0olDT@03odfU00?oS[L00oo8_003omBL
00?ogWd00ooWG`03oni500?om2h00ooh8004ooXG00?oo1000oom2`03ooh600cooP@00oon1@03ooh7
00?oo@X00ool3`04ooXF00?on2000ooe;003oo4m00?oje000ooUI`03omf100?odid00oo9^P03oj:l
00?oKZl00ollX004o`n@00?o07lF0ol0KS<3o`1MAP?o04]=0ol0;3h3o`0H<@?o00`V0ol01Ah3o`02
6P?o008I1?l011d3o`0;9@?o01Pa0ol0<T43o`1DC0?o06Ti0ol0PA<3obNI00?oM;000oo6`003omZ:
00?ojU@01?of9`03ood<00?ooPL00ooi6P03oo1000?ohG@00oo>[@03oi6h00?o?:000ol0QPH3o`1]
<`?o05I;1?l0<d43o`0H<0?o00XT0ol011`3o`026@?o00<K0ol02B<3o`0E;P?o02`n0ol0D4h3o`1T
?`Co07XP0ol?T003odbU00?oU;T00oo;]@03om^800?oj5h00oob>003ooTL00?oo@/00oon1@03ood9
00ConQL00ooe;@03oni700?oiV<00ooMP003omBL00?ob[H00onf`@03oi6h00?oLJl00omEY`03ocfP
00Co:YX00olKU003o`n@00?o1X`00ol0RP03o`280P?o08P30ol0R@43o`:;00?o2Hh00olDTP03ob>G
00Co=Yh00om=Y@03ofV]00?oR[H00on``003olZh00?oe9d00ooKR003on1g00?oi6/00ooTJ@07oooo
o`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1m6@?o59400om=Y@03ohjg00?o
b;`00ooDW003omim00?oiel00oo^A@03oo@^00?on2001?oj5`03oo`@00?oo@/00oon1P0<ooh400?o
oPD00oon1`03ood:00?oo0l01?oj5P03ooPP00?omB`00ooa?@03on]@00?oiFL00ooMP@03om>M00?o
bKX00onR_003ofj_00?o?:001?l?T003o`1o5P?o06hc0ol0GDH3o`1;C@?o02`n0ol06343o`0<9P?o
00DN0ol00QX3o`026@Co00@M0ol02bD3o`0H<@?o03910ol0E4`3o`1Y>@?o084C0olWV@03ogB`00?o
a/000ooJRP03onYD00ComRL00oom3003ooh700?onAX00oo`@003on5d00?ocZd00onA^003ocbP00?o
08H60ol0KC<3o`1FB`Co03=10ol06303o`0:90?o00@L0ol00QT3o`036`?o00TS0ol05Bh3o`0/?P?o
051>0ol0I3l4o`1j80?o3i000om<Y@03oiBi00?obkD00ooKR003onQN00?olSP00ooi7003ood;00?o
oPD00oom2@04ooXG00?omBd00oo^A`03onIS00?ogH000ooDW003olZf00?o]/400onA^003og6_00?o
EJL00olmX004obZJ00?o6i@00ol?T003o`J<00?o08X00ol0R083o`280`?o08T10ol2R`03o`V>00?o
59800olSU`04ocJN00?oCJD00omY[@03ohZf00?o/<000oo:^003omBM00?ofhP00ooPM`03onA[00?o
i6T01oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0OAT3oaBA00?oCJD0
0on>]`03olRl00?oe9`00ooNO@03onMO00?okTD00ood;P03ooPP00ConQL00ool4003ood;00?ooPH0
3?on1003ooh500?ooPL00oom2P03oo`?00ConQH00ooh8003ooD/00?olCd00oo[D003onEW00?ogH40
0ooCW@03olVj00?oX[`00om^[`03ocbP00Co3i000ol0OaH3o`1^<`?o05e60ol0Bdd3o`0/?P?o01Pa
0ol032H3o`057P?o008J0ol00QT4o`047@?o00/U0ol06343o`0b@@?o05A<0ol0JCT3o`214`?o9iT0
0omd/003olK000?ofXX00ooZE004ooHW00?oo@`00oon1`03ooTJ00?ol4000ooQM003olj]00?oTKP0
0ollX003o`261P?o06dc0ol0ET/4o`0c@@?o01P`0ol02R@3o`0470?o008I0ol00a/3o`098`?o01D^
0ol0;3h3o`1@CP?o06@o1?l0NR03o`n@00?oC:D00onD^@03ol^e00?ofhP00ooXGP03oo8h00?onA`0
0oom2`03ooh500?oo@T01?oj5`03ooD]00?okTL00ooVH`03omf000?oe9`00oo:]P03okK100?oTKP0
0oma[`03oeFW00?o?J001?lZVP03oa^D00?o3i000ol6S003o`2:00?o08P20ol0R0<3o`290@?o0X/0
0ol9SP03oaBB00?o8iL01?lfWP03odfU00?oJJd00on:]P03ok3000?ob[P00ooDW@03om^800?oh7L0
0ooTJ`03onAY00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o4i400om<
Y@03ohjg00?ob;`00ooGU003on5e00?ojET00oo`@003ooD[00?onAX00ook4@04oo`=00?oo@X00oom
2003ooh600WooPD00ooo1003ool300?oo`800ooo0`03ooh500Coo@P00ool3P03ooXH00?ombD00oob
=P03one;00?oiV@00ooMP@03om>O00?oakh00onG^P03of2[00Co;9X00ol0R@03o`1h8`?o06Hm0ol0
ED/3o`0iA@?o020f0ol042X3o`078@?o00<K0ol00QT4o`0370?o00PR0ol052d3o`0Z?@?o04m>0ol0
ICh3o`1l6`?o79D00omX[@03ol7400?of9000ooYF@04ooD[00?oo0h00oon1`03ooXI00?ol3l00ooQ
M003olj]00?oS[L00oliW`03o`252@?o06`f0ol0E4`4o`0`@0?o01D_0ol02283o`036`?o008I0ol0
11`3o`0;9@?o01Ta0ol0=483o`1EB`?o06Xh1?l0P1<3ob6G00?oIJ`00ona`003om:S00?ohGD00oo]
B`03ooHY00?ona400oon1P03ooh700?ona801?of9`03onm100?oiel00ooNO`03omBM00?obKT00on[
_`03oh:d00?oGZX00om0X@03obJH00?o4I001?l0RP03o`2430?o07lF0ol0Nah3o`1h8`?o07HV0ol0
MBL3o`1f9`?o07LT0ol0NR03o`1m6@?o088?1?l0R083o`n@00?o9IP00om0X@03of6[00?oRKH00ong
`@03olZf00?odZ000ooIS@03omio00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05
ooooo`?o4i400om<Y@03ohjg00?ob;`00ooGU003on5e00?ojET00oo`@003ooD[00?onAX00ook4@04
oo`=00?oo@X00oom2003ooh600WooPD00ooo1003ool300?oo`800ooo0`03ooh500Coo@P00ool3P03
ooXH00?ombD00oob=P03one;00?oiV@00ooMP@03om>O00?oakh00onG^P03of2[00Co;9X00ol0R@03
o`1h8`?o06Hm0ol0ED/3o`0iA@?o020f0ol042X3o`078@?o00<K0ol00QT4o`0370?o00PR0ol052d3
o`0Z?@?o04m>0ol0ICh3o`1l6`?o79D00omX[@03ol7400?of9000ooYF@04ooD[00?oo0h00oon1`03
ooXI00?ol3l00ooQM003olj]00?oS[L00oliW`03o`252@?o06`f0ol0E4`4o`0`@0?o01D_0ol02283
o`036`?o008I0ol011`3o`0;9@?o01Ta0ol0=483o`1EB`?o06Xh1?l0P1<3ob6G00?oIJ`00ona`003
om:S00?ohGD00oo]B`03ooHY00?ona400oon1P03ooh700?ona801?of9`03onm100?oiel00ooNO`03
omBM00?obKT00on[_`03oh:d00?oGZX00om0X@03obJH00?o4I001?l0RP03o`2430?o07lF0ol0Nah3
o`1h8`?o07HV0ol0MBL3o`1f9`?o07LT0ol0NR03o`1m6@?o088?1?l0R083o`n@00?o9IP00om0X@03
of6[00?oRKH00ong`@03olZf00?odZ000ooIS@03omio00Oooooo0Ol00001ooooo`007Oooool00ol0
003oooooooooo`05ooooo`?o4i400om<Y@03ohjg00?ob;`00ooGU003on5e00?ojET00oo`@003ooD[
00?onAX00ook4@04oo`=00?oo@X00oom2003ooh600WooPD00ooo1003ool300?oo`800ooo0`03ooh5
00Coo@P00ool3P03ooXH00?ombD00oob=P03one;00?oiV@00ooMP@03om>O00?oakh00onG^P03of2[
00Co;9X00ol0R@03o`1h8`?o06Hm0ol0ED/3o`0iA@?o020f0ol042X3o`078@?o00<K0ol00QT4o`03
70?o00PR0ol052d3o`0Z?@?o04m>0ol0ICh3o`1l6`?o79D00omX[@03ol7400?of9000ooYF@04ooD[
00?oo0h00oon1`03ooXI00?ol3l00ooQM003olj]00?oS[L00oliW`03o`252@?o06`f0ol0E4`4o`0`
@0?o01D_0ol02283o`036`?o008I0ol011`3o`0;9@?o01Ta0ol0=483o`1EB`?o06Xh1?l0P1<3ob6G
00?oIJ`00ona`003om:S00?ohGD00oo]B`03ooHY00?ona400oon1P03ooh700?ona801?of9`03onm1
00?oiel00ooNO`03omBM00?obKT00on[_`03oh:d00?oGZX00om0X@03obJH00?o4I001?l0RP03o`24
30?o07lF0ol0Nah3o`1h8`?o07HV0ol0MBL3o`1f9`?o07LT0ol0NR03o`1m6@?o088?1?l0R083o`n@
00?o9IP00om0X@03of6[00?oRKH00ong`@03olZf00?odZ000ooIS@03omio00Oooooo0Ol00001oooo
o`007Oooool2o`0000Kooooo0om7X`03ohRf00?oa/000ooEVP03on9b00?ojEL00oo_@@03oo@_00?o
n2400ooj5@0Coo/C00?ona800ook4@03oo`?00?oo@`00oom2003ooh600?oo`@01?oo0`03ooh500?o
o@X00ook4`03ooPP00?olc<00oo]BP03onEU00?og8@00ooAY@03ol7400?oQ[D01?m=Y@03oaVD00?o
084A0ol0Kc43o`1MAP?o04Q<0ol0:C`3o`0E;P?o00XT0ol011`3o`026@Co00<J0ol01b03o`0@:P?o
02@i0ol0Ad/3o`1P@`?o07PS0olBT@03oebY00?o]L400ooFUP03onMN00Com2h00ool3`03ooh700?o
nQP00oo`?`03on5d00?ocZh00on<]`03ocJN00?o08@<0ol0JSP3o`1BC@Co02`n0ol04bd3o`078@?o
00<J0ol00QT3o`057P?o00dW0ol07SD3o`0lAP?o05Y80ol0L304o`271@?o=Id00omm/`03olK000?o
f9400ooVI003oo4k00?onAd00oom2P03ooh500?oo0d00ooh7`04oo8i00?ojEP00ooON@03omFJ00?o
bKT00onX_P03og^b00?oE:L00olbW003oaJB00?o08T00ol0PA84o`1j7`?o07@Z0ol0KS83o`1Z>0?o
06Ll0ol0ICh6o`1T?`?o06Dn0ol0Ic`3o`1Z>0?o06hb1?l0M2X3o`1k7P?o08<?0ol5S003oanF00?o
@:400omX[@03ohnh00?o^L800oo;]003om>O00Kooooo0_l00001ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`?oAj<00on8]P03olK000?oeIX00ooRLP03onUG00?okd400ood;`03ooPQ00?onQD0
4ook4`03oo/B00?ona400ool3`03ood<00?oo@P00oon1P03ool400Coo`<00oon1@03ood:00?ona<0
0ooh8003oo<c00?okDX00ooUI@03omb400?odJD00oo1a003ohJe00CoCJD00olIU003o`214@?o06la
0ol0GDH3o`18C0?o02Tl0ol05Bh3o`0:90?o00@L0ol00QT4o`036P?o00LP0ol042X3o`0T>@?o04M;
0ol0H4<3o`1h8`?o4Y400omLZ@03okG100?oeYH00ooWGP04oo@^00?oo0l00oon1`03ooXH00?ol3l0
0ooQM003olj^00?oS;L00olfWP03o`2430?o06Xh0ol0DTd4o`0/?P?o01<]0ol01b43o`036P?o008I
0ol01Ah3o`0=9`?o01he0ol0?4H3o`1JB0?o070`1?l0Q`D3ocFM00?oOK<00oo6`003omRA00?oiV@0
0ooa>`03ooTM00?oo@X00oon1@03oo`=00?on1l01?ob>@03onUH00?oggT00ooEVP03olVi00?oZ;h0
0omk/P03oeBW00?o<Y`00olFTP03o`2900?o084B1?l0NQl3o`1d:P?o06hb0ol0JSP3o`1W?0?o06Dn
1_l0I3l3o`1U?P?o06Ll0ol0JSP3o`1^<PCo07@Z0ol0Nah3o`233`?o1H`00olOUP03od2Q00?oJ:d0
0on?^003okW200?obk@00ooCW`07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Ooo
ool3odNS00?oR;H00oo6`003omFJ00?ohW800ooYE`03onm100?om2l00ooh8@03ooXE01?ona<00ook
4P03oo/A00?oo0l00oom3003ood800?ooPH00ooo1004ool300?ooPD00oom2P03oo/C00?on2000ooc
<`03one:00?oiFD00ooLQ003om6U00?o`L@00on6]@04odfU00?o6I@00ol0PA43o`1_<@?o05e60ol0
B4`3o`0Y?0?o01D^0ol02R@3o`0470?o008I1?l00aX3o`0780?o010Z0ol093T3o`17B`?o06130ol0
N2<3oa:A00?oG:T00one`@03omJF00?oieh01?od;P03oo`?00?ooPL00ooj6003oo0o00?ohG@00oo>
[P03ohbg00?o=Yh00ol0Q0`3o`1Z>0?o059=1?l0;3h3o`0C;@?o00LQ0ol00aX3o`026@?o00DN0ol0
3BL3o`0N=@?o03a60ol0FTP3o`1`<0Co08L50oleW@03ogfc00?oa/000ooHT@03onIT00?olC/00ooi
7@03ood:00?ooPD00ool3@03ooPO00ColST00ooYF003ommi00?oeIX00oo9^@03ojRn00?oNk800omD
Y`03oc:L00?o5Y800ol0R@03o`214PCo07XO0ol0M2X3o`1^<P?o06Xh0ol0Ic`3o`1U?PKo06@o0ol0
ICh3o`1W?0?o06Xh0ol0KS84o`1d:P?o07/N0ol0P`l3o`F<00?o7iH00om0X@03ofR]00?oSkP00oni
`P03ol^d00?odil01oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0omm/`03
oko300?odZ800ooNO@03onUJ00?okTL00oob>003oo@]00?omRH00ooh8003ooLR00ComRH00oof:@03
ooDZ00?omB/00ooe:P03ooDY00?omRL00oog8`03ooPM00?onQL00ook4@03ood;00CooPL01_on1003
ood800?ona400ooh7`03oo<c00?ok4`00ooTJ`03omV<00?ocJl00on/_`04ofj_00?o=Id00ol3R`03
o`1h8`?o06Dn0ol0Dd`3o`0d@P?o01/c0ol03BL3o`057POo008J0ol01Ah3o`0=9`?o01le0ol0?TL3
o`1LAP?o07@Z0ol8S@03oe6V00?oZ[h00ooDW003onIS00Colc400ool4003ooh700?onQL00oo`?P03
on5d00?ocJh00on:]P03oc>M00?o088?0ol0JCX3o`1AC@Co02Tl0ol04R`3o`0780?o00<J0ol00QX3
o`067`?o00lY0ol08SP3o`15BP?o05m40ol0MRL4o`R=00?oBJ@00onF^@03olf`00?ogH000oo[D`03
ooD]00?ona<00oon1P03ooh800?onQH00ood;P04ona=00?ohW000ooGT`03ol^d00?o[;l00omk/P03
oe2V00?o:iX00ol=S`03o`242`?o07/N0ol0Lb`4o`1[=`?o06Dn0ol0Gd@3o`1KA`?o05Q:0ol0ED/9
o`1DC0?o05I;0ol0F4T3o`1LAPCo06520ol0Ic/3o`1^<P?o07LU0ol0PA83o`F<00?o9IP00om8X`03
og2_00?oV[X00oo5a007ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3ogfc
00?o_l<00ooBXP03omim00?ojEX00oo^A`03oo8h00?om2d00oof9P03ooPP00?omb801?of9P03ooHY
00?omBX00ooe:`03ooDZ00?omBT00oof9`03ooLS00?on1d00ooj5`03oo/A00?oo@/01?on1`06ooh4
00?oo@P00ook4@03ooPO00?olc<00oo/C003onA[00?ofH`00oo=[`03ojbo00CoKZl00oleW@03o`>;
00?o07PS0ol0ICh3o`1CC0?o03A20ol06c<3o`0=9`?o00DN1ol00QX3o`057P?o00dW0ol07cD3o`0n
A`?o05a60ol0M2X3o`R=00?oDJH00onZ_P03omBL00?oiV<01?oc<@03oo`@00?ooPL00ooj5`03oo0n
00?ohG@00oo=[P03ohZf00?o<id00ol0PPl3o`1Y>P?o055=1?l0:C`3o`0B;0?o00LP0ol00aX3o`02
6P?o00HO0ol03bT3o`0R>0?o04E:0ol0Gd@3o`1f9`Co28d00om9Y003oiJi00?ocK000ooMP003on]C
00?omBd00ook4`03ooh600?ooPP00ooj5P03oo@^00Cok4d00ooRL003omNC00?obk@00on/_`03og^b
00?oD:H00ol[VP03o`f?00?o08@;0ol0Nah3o`1c;0Co06/g0ol0ICh3o`1OA0?o05]70ol0F4X3o`1E
B`Wo05A<0ol0ET/3o`1HB@?o05a61?l0HD83o`1W>`?o06hb0ol0MbD3o`214P?o1H`00olUV003odRS
00?oL:l00onJ^P03olG400Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o
OK<00ono``03om:R00?ogWd00ooYFP03oni700?olSP00ood;@03ooHV00?on2000oog8P04ooHV00?o
mRT00ooe:P03ooD[00?omBX00ooe:@03ooHW00?omb<00ooh7@03ooXG00?ona400oom2`04ooh700Ko
oP@00oom2003oo/A00?on1l00ooc<`03ona<00?oi6/00ooIS003olf_00?o[;l01?m^[`03ocFM00?o
0h/00ol0N2<3o`1U?P?o05=<0ol0=483o`0K<`?o00dW0ol01Ah7o`026P?o00DN0ol03BL3o`0O=@?o
03i70ol0G4H3o`1d:P?o28d00omAYP03ojZn00?oe9`00ooVH`04oo<a00?oo1000oon1`03ooXG00?o
l3h00ooQM003olf^00?oR[H00olcW@03o`223`?o06Tj0ol0DDd4o`0Y?0?o018/0ol01b03o`036P?o
008J0ol01Ql3o`0?:@?o028h0ol0ADX3o`1OA0?o07HW1?l8S@03odVT00?oU[T00oo=/003omf000?o
je<00ooe;@03oo/C00?ooPH00oon2003ooXF00?om2h01?o/C@03on9`00?oei<00oo;]003ojbo00?o
Nk800om@YP03ob^J00?o3Hl00ol0Q0/3o`1k7P?o07</1?l0JcL3o`1U?P?o05m40ol0FdL3o`1HBP?o
05E;2Ol0E4`3o`1FB`?o05Q90ol0G4H4o`1Q@P?o06Lk0ol0KS83o`1g9@?o084B0ol5S003obFH00?o
B:<00om`[`03oiZj00?oaL@01oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo
0on^_`03olj^00?ofX/00ooTJ`03ona?00?okd@00oo`?@03oo4i00?olSP00oob=`03oo4l00Cokd80
0oo^A`03one900?okDX00oo]B@03oni800?okd@00oo`?P03oo8f00?om2d00oog9003ooTJ00Cona40
0oom2P03ooh500?ooP@00oon2003oo/A00?on2400oob=`03on]C00?ohG@00ooEV003olRm00CoTKP0
0omBY`03oa^D00?o084B0ol0KC@3o`1JB0?o04180ol08SP3o`0@:P?o00LP0ol00a/4o`026@?o00@M
0ol02bD3o`0J<P?o03M30ol0F4T3o`1`<0?o08T00om6X`03oinl00?odZ800ooUJ004oo<e00?ona80
0oon1`03ooXF00?ol3d00ooQL`03olf_00?oR;H00ol`W003o`214P?o06Ll0ol0Cdh4o`0W>P?o010Z
0ol01Ql3o`026P?o00<J0ol01b03o`0A:`?o02Pk0ol0CTh3o`1T?`?o07/M1?lHT`03oejZ00?o[kl0
0ooBX@03on9`00?okd@00oog8@03ood<00?ooPH00ool3P03ooLR00?ol3l01?oVHP03om^700?ocj/0
0ong`@03oh:d00?oDZL00olZVP03o`V=00?o088A0ol0MbD3o`1]=0?o06Dn1?l0GDD3o`1GBP?o059=
0ol0C4d3o`14BP?o03m70ol0?4H3o`0jA@?o03]50ol0?DL3o`12B@?o04Q<1?l0D4h3o`1EB`?o05a7
0ol0Hd03o`1]=@?o07LT0ol0P`d3o`f?00?o;i/00omGZ003oh:d00Oooooo0Ol00001ooooo`007Ooo
ool00ol0003oooooooooo`05ooooo`?o[[l00oo>[P03omZ;00?oi6/00oo/C`03onm400?ol3d00ooa
>@03oo8h00?olSL00ooa?004onm200?okTL00oo]B@03one:00?okDT00oo^B003onm400?ol3h00oob
=P03oo@]00?omb@00ooi6P04oo/A00?oo@X00oon1@03ooh400?ooPP00ook4@03ooPQ00?olSL00oo[
D`03on5d00?oeIP00oo8_@04oi6h00?oDZL00olKU003o`214P?o06dd0ol0FTP3o`10B0?o028h0ol0
42X3o`0780?o00<K1?l00QT3o`047@?o00/U0ol06S83o`0g@`?o05Q90ol0L303o`2900?oAZ<00onO
_003om:R00?oiFP01?oc=@03oo/B00?ooPL00ooj5P03oo0m00?ohG<00oo=[`03ohRf00?o<9`00ol0
PA83o`1W?0?o04m>1?l09cX3o`0@:P?o00HO0ol00QX3o`036P?o00LP0ol04B/3o`0X>`?o04i>0ol0
I3l3o`1k7@Co69<00omNZP03ojno00?odZ400ooRL003onm400?omb400oom3003ooh600?oo0h00oog
8P03oo0o00CoiV800ooKQ`03oln[00?o]l400on2]003oe:W00?o:YX00ol9S@03o`224@?o07LU0ol0
KC@3o`1U?PCo05e50ol0EdX3o`1BC@?o04a=0ol0A4X3o`0oA`?o03a60ol0>TD3o`0kA@?o03e70ol0
@TT3o`18C0Co051>0ol0ED/3o`1LA`?o06=00ol0KCD3o`1g90?o08<=0ol=S`03obnK00?oEjP00on2
]007ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3ojjo00?ocZh00ooJR`03
onA[00?ok4l00oo_A003oo0m00?olCT00oob>003oo8g00?olC`01?o_@P03oni700?okDT00oo]BP03
one900?okTP00oo_A003oo0n00?olSH00ood;@03ooLT00?onAX01?ok4@03ood:00?ooPD00oon1003
ooh800?ona400ooh8@03oo8g00?oje<00ooQM003omFH00?ob;d01?nA^003oe:W00?o6i@00ol0PA83
o`1]=0?o05Y80ol0@4P3o`0R>0?o010Z0ol01b03o`036`Co008I0ol011d3o`0;9@?o01Xb0ol0=d<3
o`1HB@?o070`0ol0R@03odJS00?oWk`00ooBXP03onEX00ColcD00ook4P03ooh700?onQH00oo`?@03
on5c00?ocJl00on8]P03oc2L00?o084B0ol0Ic`3o`1?CPCo02Lj0ol042X3o`067`?o008J0ol00aX3
o`0780?o014[0ol0:3/3o`1>CP?o06@o0ol0Nad4oaRC00?oGZX00on__`03om:Q00?ohW000oo_A003
ooLQ00?oo@`00oon1P03oo`>00?omb800oo`?`04onIR00?ofhL00oo?Z`03okO100?oP[@00omBY`03
obZJ00?o2Hd00ol0PQ43o`1g9@?o06dd0ol0ICh4o`1MA@?o05M:0ol0DTd3o`1<C@?o04A:0ol0?dL3
o`0lAP?o03Y50ol0>dD3o`0mA`?o04990ol0B4`4o`1@CP?o05E;0ol0G4L3o`1S@0?o06de0ol0Mb@3
o`233@?o3Hl00ol_V`03oeNX00?oP[@01oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo
00Gooooo0on^_`03olj^00?ofX/00ooTJ`03ona?00?okd@00oo`?@03oo4i00?olSP00oob=`03oo4l
00Cokd800oo^A`03one900?okDX00oo]B@03oni800?okd@00oo`?P03oo8f00?om2d00oog9003ooTJ
00Cona400oom2P03ooh500?ooP@00oon2003oo/A00?on2400oob=`03on]C00?ohG@00ooEV003olRm
00CoTKP00omBY`03oa^D00?o084B0ol0KC@3o`1JB0?o04180ol08SP3o`0@:P?o00LP0ol00a/4o`02
6@?o00@M0ol02bD3o`0J<P?o03M30ol0F4T3o`1`<0?o08T00om6X`03oinl00?odZ800ooUJ004oo<e
00?ona800oon1`03ooXF00?ol3d00ooQL`03olf_00?oR;H00ol`W003o`214P?o06Ll0ol0Cdh4o`0W
>P?o010Z0ol01Ql3o`026P?o00<J0ol01b03o`0A:`?o02Pk0ol0CTh3o`1T?`?o07/M1?lHT`03oejZ
00?o[kl00ooBX@03on9`00?okd@00oog8@03ood<00?ooPH00ool3P03ooLR00?ol3l01?oVHP03om^7
00?ocj/00ong`@03oh:d00?oDZL00olZVP03o`V=00?o088A0ol0MbD3o`1]=0?o06Dn1?l0GDD3o`1G
BP?o059=0ol0C4d3o`14BP?o03m70ol0?4H3o`0jA@?o03]50ol0?DL3o`12B@?o04Q<1?l0D4h3o`1E
B`?o05a70ol0Hd03o`1]=@?o07LT0ol0P`d3o`f?00?o;i/00omGZ003oh:d00Oooooo0Ol00001oooo
o`007Oooool00ol0003oooooooooo`05ooooo`?ob;/00ooDV`03omin00?oiFD00oo[D@06ona>00?o
je000ooZD`03onYF00?oieh01?oUI@03onAZ00Kohfd00ooSK003onAZ00?oiV@00ooXG@03onYD00?o
kDP00ooa?003oo@_00Comb800ooj5`03oo`=00?ooPH00oon1003ood800?ona<00oog9@03oo0n00?o
j5d00ooMP@03om2X00Co]<400oma[`03oc>M00?o08T00ol0MBP3o`1Q@P?o04i>0ol0:cd3o`0E;P?o
00TS0ol011`4o`026@?o00<K0ol02B<3o`0F;`?o03500ol0ED/3o`1/=@?o08H70olmX003oiFi00?o
d:P00ooSK@04oo8h00?ona<00oon1`03ooXF00?olC`00ooQL`03olf_00?oQ[D00ol^V`03o`2050?o
06Hm0ol0CDh4o`0T>@?o00lY0ol01Ah3o`026@?o00<K0ol02243o`0D;P?o02dn0ol0DTd3o`1Y>@?o
084B1?lXV@03og>`00?oaL<00ooGTP03onMQ00?olSH00ooj6006ooh800?onQH00ood<003on]B00Co
h7P00ooCWP03olK200?oSkL00omKZ@03objK00?o2Xh00ol0PA83o`1e:0?o06Xh0ol0HD83o`1HB@Co
055=0ol0AT/3o`0kA@?o03910ol0;3h3o`0X>`?o02Dj1_l093T3o`0U>@?o02Pk0ol0;3d4o`0b@@?o
03]50ol0Ad/3o`1BC@?o05Y80ol0I3l3o`1_<@?o07/N0ol0Q`@3oabE00?oA:801oooool1o`00007o
oooo000Mooooo`03o`000?oooooooooo00Gooooo0oo8^`03omBK00?ogWh00ooUI@03on]A00Kok4h0
0oo[D003onYC00?ojUH00ooWGP04onEU00?oi6X01_oSK@03on=/00?oi6X00ooVI003onQM00?ojU@0
0oo]B003oo4l00?om2l01?og8P03ooXG00?oo0d00oon1P03ooh400?oo@P00ook4`03ooLU00?ol3h0
0ooXG@03omf100?od:P01?nd`@03og6_00?o<id00ol0R@03o`1e:0?o06520ol0CTh3o`0[?@?o01D^
0ol02B<3o`0470Co008I0ol00a/3o`098`?o01H_0ol0<D03o`1EB`?o06`e0ol0QPL3ocfP00?oUKT0
0oo@Z003on=]00ColSP00ook4`03ooh700?onQH00ooa?003on5c00?ocJl00on6]@03objK00?o080D
0ol0ISd3o`1=CPCo02@i0ol03bT3o`057P?o008I0ol00a/3o`088@?o01@^0ol0;Ch3o`1BC@?o06Ti
0ol0PA84obRI00?oLk000oo5``03omNB00?oif400oob=P03ooXH00KooPP00ooj5P03oo@`00?oje80
1?oPN003om>N00?oa/800on?]`03oe^Y00?o;Y/00ol:SP03o`214P?o07DX0ol0JSP3o`1Q@P?o05Q9
1?l0DDd3o`16B`?o03]50ol0<T43o`0/?P?o02Pk0ol09CX6o`0T>@?o02Di0ol0:3/3o`0/?@Co0391
0ol0>dD3o`17B`?o059=0ol0FTP3o`1T?`?o06la0ol0Nah3o`2710?o79D00om4XP07ooooo`7o0000
0Oooool001gooooo0_l00006ooooo`?ob;/00ooDV`03omin00?oiFD00oo[D@06ona>00?oje000ooZ
D`03onYF00?oieh01?oUI@03onAZ00Kohfd00ooSK003onAZ00?oiV@00ooXG@03onYD00?okDP00ooa
?003oo@_00Comb800ooj5`03oo`=00?ooPH00oon1003ood800?ona<00oog9@03oo0n00?oj5d00ooM
P@03om2X00Co]<400oma[`03oc>M00?o08T00ol0MBP3o`1Q@P?o04i>0ol0:cd3o`0E;P?o00TS0ol0
11`4o`026@?o00<K0ol02B<3o`0F;`?o03500ol0ED/3o`1/=@?o08H70olmX003oiFi00?od:P00ooS
K@04oo8h00?ona<00oon1`03ooXF00?olC`00ooQL`03olf_00?oQ[D00ol^V`03o`2050?o06Hm0ol0
CDh4o`0T>@?o00lY0ol01Ah3o`026@?o00<K0ol02243o`0D;P?o02dn0ol0DTd3o`1Y>@?o084B1?lX
V@03og>`00?oaL<00ooGTP03onMQ00?olSH00ooj6006ooh800?onQH00ood<003on]B00Coh7P00ooC
WP03olK200?oSkL00omKZ@03objK00?o2Xh00ol0PA83o`1e:0?o06Xh0ol0HD83o`1HB@Co055=0ol0
AT/3o`0kA@?o03910ol0;3h3o`0X>`?o02Dj1_l093T3o`0U>@?o02Pk0ol0;3d4o`0b@@?o03]50ol0
Ad/3o`1BC@?o05Y80ol0I3l3o`1_<@?o07/N0ol0Q`@3oabE00?oA:801_ooool2o`00007ooooo000M
ooooo`03o`000?oooooooooo00Gooooo0oo>[003omRA00?ogg`00ooTJ`03onMO00?oiV800ooUJ003
on=_00?ohGD00ooONP03omb300CofX/00ooHT006omNB00?of9000ooIS@03om^600?ogWh00ooQL`03
onEV00?ojEP00oo]B004oo8h00?omRP00ooi6P03oo`>00?ooPL00oon1@03ood:00?onQL00ooe;003
one900?ohf`00ooGT`04olVk00?oT;P00om>Y@03oa>A00?o07dJ0ol0J3X3o`1DC0?o03A20ol06S83
o`0;9P?o00@M1?l00QT3o`036P?o00LQ0ol04bd3o`0[?@?o055=0ol0JCT3o`233`?o=9d00on;]P03
olj]00?ohW401?oa>`03ooXE00?ooPL00ooj5@03oo4l00?ohG<00oo=/003ohBe00?o:iX00ol0OaH3
o`1T?`?o04U<1?l08SL3o`0=:0?o00DM0ol00QT3o`036`?o00TS0ol05c03o`0c@P?o05M:0ol0KS<3
o`261`Co>9h00on7]@03olZf00?og8<00oo[D`03ooD[00?oo1000oon1P03ood<00?on2000oo`@003
onEU00CofHd00oo;]003oj>l00?oJZd00olhWP03o`n@00?o088@0ol0MBP3o`1Y>@?o05i40ol0ED/3
o`1:C@Co03]60ol0<403o`0W>`?o020g0ol073<3o`0I<@?o01H_0ol05Bl3o`0E;P?o01D_0ol05c03
o`0I<PCo01dd0ol08cP3o`0Z?@?o03E30ol0A4X3o`1BC@?o05e60ol0J3/3o`1d:@?o084A0ol>S`07
ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3olj/00?of9400ooOO003onA[
00?oiel00ooVHP03onEX00?ohfl00ooQM@03ommj00?og8<01?oJR`03omR@00Koei800ooHT003omV=
00?ofhH00ooNOP03on5c00?oiFH00ooYF003one800ColSP00oof:003ooTJ00?oo0h00oon1`03ooh5
00?oo@X00ooj5`03ooD/00?okDT00ooSK003omNC00CobK/00on@^003odjU00?o4i400ol0OAX3o`1X
>P?o05A<0ol0=483o`0J<P?o00/V0ol011d4o`026@?o00<J0ol01b43o`0C;@?o02/m0ol0DDd3o`1Y
>@?o08<?0oldW@03oh^f00?ocZd00ooRL@04oo4k00?onQD00oon1`03ooXE00?olC`00ooQL`03olf`
00?oQ;D00ol[VP03o`1o5P?o06@o0ol0BD`4o`0R=`?o00dX0ol01Ad3o`026@?o00<K0ol02B<3o`0G
<0?o03=20ol0EdX3o`1^<`?o08H71?lhWP03ohNe00?ob[H00ooLP`03on]C00?omB/00ool4003ooh6
00?oo@`00ooh8003oo1000?oiFD01?oIS@03ol^d00?oXk`00omZ[@03ocRN00?o3i000ol0PQ03o`1e
:0?o06Ti0ol0GT@3o`1EB`?o04Y=1?l0>dH3o`0`@0?o02Lk0ol083L3o`0L<`?o01Ta0ol05Rl3o`0E
;`?o01D^0ol05Bl3o`0G<0?o01Tb1?l07C@3o`0S>0?o02Xm0ol0=D<3o`14BP?o059=0ol0GDH3o`1X
>`?o07@Y0ol0PA43o`j?00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o
cZ`00ooHT@03omml00?oi6/00ooWG`03onIR00?oiFP00ooSK`03on5e00?oggX00ooLP`04omZ;00?o
f9001_oGTP03omR@00?ofHd00ooKQP03omin00?ohG<00ooUIP03onUH00?okDP01?ob>003ooHX00?o
nAX00ool3P03ooh700?ooPD00oom2P03ooXG00?omB`00oo]B@03on=/00?oei<01?o9^`03oi2h00?o
CZD00olCT@03o`1m6P?o06Pj0ol0E4`3o`0d@P?o01Xb0ol02bH3o`047@Co008I0ol00aX3o`078@?o
01<]0ol0:cd3o`1AC@?o06Ti0ol0P`l3ocBM00?oRkH00oo>[@03on9a00ColC/00ooj5@03ooh700?o
nQD00ooa?003on5c00?ocK000on4]@03ob^J00?o07lF0ol0I3l3o`19C0Co028g0ol03BP3o`057@?o
008I0ol00a/3o`098`?o01L`0ol0<d83o`1GBP?o06hc0ol0QPL4ocRN00?oQkD00oo:]P03omb300?o
je<00ooe:`03oo`@00?ooPH00oom3003ooPP00?ol4000ooUI@04omV=00?obk@00onS_003ofZ]00?o
>9h00ol?T003o`2240?o07DX0ol0JCT3o`1NA0?o05E;0ol0BTd4o`0kAP?o03100ol09c/3o`0P=`?o
01`c0ol06C43o`0F;`?o01D_0ol05Bh3o`0E;`?o01L`0ol06C84o`0M=0?o02<h0ol0:Sd3o`0e@`?o
04A:0ol0DTd3o`1MAP?o06Pk0ol0M2T3o`214@?o3Xl01oooool1o`00007ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo0ooAY003omRA00?og8<00ooONP03on5e00?ogWh00ooKQ`03omRA00?oeIT0
0ooCX003om2X00CocJl00oo;/`06ol^e00?oc;800oo=[P03om2W00?odih00ooGT`03omb500?ohGD0
0ooVH`04on]A00?ol3d00ooe:`03ooTJ00?oo0h01_on1P03oo`=00?on1h00oob=`03onUH00?ogWh0
1?o@Z003ojno00?oJJd00olYV@03o`242`?o06la0ol0FTP3o`0nA`?o020f0ol03RP3o`067`Oo008J
0ol01Ql3o`0@:P?o02Hj0ol0CTh3o`1V?@?o07lE0ol[VP03oh:d00?oc;800ooPMP04oo0n00?onQL0
0oon2003oo/E00?olC/00ooQL`03olf`00?oP[@00olYV@03o`1n60?o06=00ol0AT/4o`0P=P?o00`W
0ol011d3o`026@?o00@L0ol02R@3o`0J<P?o03Y50ol0FdP3o`1b;0?o18/01?m9Y003oibk00?ocjT0
0ooQM@03oni600?on2400oom2`03ooh700?ona<00ooe;@03on]@00?oh7T01?oBXP03okk300?oP;<0
0om8Y003oaZD00?o08D90ol0MbD3o`1Z>0?o05i50ol0E4`3o`15BP?o03E21?l0:C`3o`0P=P?o01Ta
0ol052h3o`0A:`?o00lY0ol03BL9o`0<9P?o00dW0ol03RP4o`0@:P?o01<]0ol06343o`0O=P?o02Tl
0ol0=T<3o`1:C0?o05I:0ol0HT43o`1_<@?o07dJ1oooool1o`00007ooooo000Mooooo`03o`000?oo
oooooooo00Gooooo0ooAY003omRA00?og8<00ooONP03on5e00?ogWh00ooKQ`03omRA00?oeIT00ooC
X003om2X00CocJl00oo;/`06ol^e00?oc;800oo=[P03om2W00?odih00ooGT`03omb500?ohGD00ooV
H`04on]A00?ol3d00ooe:`03ooTJ00?oo0h01_on1P03oo`=00?on1h00oob=`03onUH00?ogWh01?o@
Z003ojno00?oJJd00olYV@03o`242`?o06la0ol0FTP3o`0nA`?o020f0ol03RP3o`067`Oo008J0ol0
1Ql3o`0@:P?o02Hj0ol0CTh3o`1V?@?o07lE0ol[VP03oh:d00?oc;800ooPMP04oo0n00?onQL00oon
2003oo/E00?olC/00ooQL`03olf`00?oP[@00olYV@03o`1n60?o06=00ol0AT/4o`0P=P?o00`W0ol0
11d3o`026@?o00@L0ol02R@3o`0J<P?o03Y50ol0FdP3o`1b;0?o18/01?m9Y003oibk00?ocjT00ooQ
M@03oni600?on2400oom2`03ooh700?ona<00ooe;@03on]@00?oh7T01?oBXP03okk300?oP;<00om8
Y003oaZD00?o08D90ol0MbD3o`1Z>0?o05i50ol0E4`3o`15BP?o03E21?l0:C`3o`0P=P?o01Ta0ol0
52h3o`0A:`?o00lY0ol03BL9o`0<9P?o00dW0ol03RP4o`0@:P?o01<]0ol06343o`0O=P?o02Tl0ol0
=T<3o`1:C0?o05I:0ol0HT43o`1_<@?o07dJ1oooool1o`00007ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo0ooAY003omRA00?og8<00ooONP03on5e00?ogWh00ooKQ`03omRA00?oeIT00ooCX003
om2X00CocJl00oo;/`06ol^e00?oc;800oo=[P03om2W00?odih00ooGT`03omb500?ohGD00ooVH`04
on]A00?ol3d00ooe:`03ooTJ00?oo0h01_on1P03oo`=00?on1h00oob=`03onUH00?ogWh01?o@Z003
ojno00?oJJd00olYV@03o`242`?o06la0ol0FTP3o`0nA`?o020f0ol03RP3o`067`Oo008J0ol01Ql3
o`0@:P?o02Hj0ol0CTh3o`1V?@?o07lE0ol[VP03oh:d00?oc;800ooPMP04oo0n00?onQL00oon2003
oo/E00?olC/00ooQL`03olf`00?oP[@00olYV@03o`1n60?o06=00ol0AT/4o`0P=P?o00`W0ol011d3
o`026@?o00@L0ol02R@3o`0J<P?o03Y50ol0FdP3o`1b;0?o18/01?m9Y003oibk00?ocjT00ooQM@03
oni600?on2400oom2`03ooh700?ona<00ooe;@03on]@00?oh7T01?oBXP03okk300?oP;<00om8Y003
oaZD00?o08D90ol0MbD3o`1Z>0?o05i50ol0E4`3o`15BP?o03E21?l0:C`3o`0P=P?o01Ta0ol052h3
o`0A:`?o00lY0ol03BL9o`0<9P?o00dW0ol03RP4o`0@:P?o01<]0ol06343o`0O=P?o02Tl0ol0=T<3
o`1:C0?o05I:0ol0HT43o`1_<@?o07dJ1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo
00Gooooo0ooAY@03omFI00?oei800ooHT003omRA00?oe9d00oo@Z003olbc00?ob;/00oo5`P03ok[2
00Co[kl00onX_P03ojJm00?oZ;h00on]_`03okG100?o`/@00oo8_@03olba00?odZ<00ooGTP03omio
00Coi6/00ooZE@03oo0o00?omBX00ooj6@03ood<00?ooPH00oon1`03oo/C00?omRP00oo^AP03onA[
00CoeYD00oo7_`03ohBe00?o?j400ol5S003o`1f9`?o06530ol0BT`3o`0W>P?o018[0ol01b44o`03
6P?o008I0ol01Ah3o`0>:0?o024g0ol0Ad/3o`1R@@?o07`K0olSU`03ogVb00?ob[L00ooONP04onm1
00?onQP00oon2003oo/D00?olC/00ooQL`03olba00?oPK@00olWV@03o`1m6P?o06910ol0@dT4o`0N
=@?o00/U0ol011`3o`026@?o00@L0ol032H3o`0N=@?o04180ol0GT@3o`1g9@?o49001?mIZ@03ok30
00?oe9d00ooTJ003oo4j00?onQT00oom2003ood900?onA/00ooa>P03onIQ00?ofH`01?o;]@03oibk
00?oGjX00ol[VP03o`6:00?o07/N0ol0K3D3o`1OA0?o05A<0ol0A4X3o`0b@@?o02Di1?l06c<3o`0E
;P?o010Z0ol032L3o`0:90?o00PR0ol01b43o`0780Ko00HP0ol01b03o`078@Co00TS0ol02RD3o`0=
9`?o014[0ol05c03o`0P=P?o02dn0ol0?TL3o`1BC@?o05i50ol0JcH7ooooo`7o00000Oooool001go
oooo00?o0000ooooooooool01Oooool3om6U00?oeIT00ooGTP03omR@00?of9400ooDW@03om2X00?o
c;<00oo8^`03olG200?o^/801?n__`03ojRn00?oY[d00onX_P03ojfo00?o]L400oo2a003olRm00?o
c;400ooBX`03omNB00?ogWl01?oTJ`03onYE00?ol3l00ooe:P03ooXI00?oo@`00oon1P03ooh700?o
na<00oof:003oni600?oi6/01?oFU@03olNo00?oQ;D00oloX@03o`F<00?o07HW0ol0HD<3o`1:C0?o
02Lj0ol04R/3o`078@Co00<J0ol00QT3o`057P?o00hX0ol08CL3o`17B`?o06910ol0O1/3ob>G00?o
NK800oo:]`03ommj00Cokd400ooj6003ooh800?ona@00ooa>`03on5c00?oc;400on1]003obNI00?o
07dJ0ol0HT43o`13B@Co01he0ol02bD3o`0470?o008I0ol011`3o`0<9P?o01he0ol0@4P3o`1NA0?o
07LU0ol@T004oeVY00?o/<000ooDW@03onAX00?olCX00ooj6@03ood800?oo@T00ooi6`03oo4j00?o
iV400ooIS004ol^e00?oW;/00omOZP03ob^J00?o0HX00ol0Nah3o`1/=@?o05m40ol0E4`3o`14BP?o
03910ol09CT4o`0K<`?o01D^0ol042X3o`0<9`?o00XT0ol02283o`078@?o00LP1_l01R03o`0780?o
00LQ1?l02B<3o`0:9@?o00dW0ol04B/3o`0G<0?o020f0ol0;Ch3o`0nA`?o059=0ol0GTD3o`1[=POo
oooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?odJD00ooEV@03omNB00?of900
0ooHT@03omBM00?od:P00oo</`03olRk00?oaL800onj`P04ojno00?oZ;h00onV_@03ojRn00?o[Kl0
0one`@03ol;400?ob;d00oo</@03om:S00?oei800ooNO`04onA[00?ojUD00oo`?`03ooDZ00?onQT0
0oom3003ooh600?ooPL00ook4`03ooHX00?okTH00ooTJ`04omJE00?oakl00on4]@03ocnQ00?o1H`0
0ol0MRL3o`1Q@`?o04Y<0ol09cX3o`0B:`?o00LQ1?l00aX3o`026@?o00DN0ol03RP3o`0Q=`?o04M;
0ol0HT43o`1l6`?o8iL00omi/P03olZg00?oggX01?o_@@03ooXH00?ooPP00ook5003oo4k00?ohG<0
0oo</@03oh6d00?o9iT00ol0OAX3o`1R@@?o04=91?l07SD3o`0;9@?o00@L0ol00QT3o`0470?o00`V
0ol07SD3o`10B0?o05i40ol0MbD3oa2@00CoFJT00on``003omBM00?oi6P00ooa>P03ooXI00?oo@P0
0oom2@03ooTK00?olCX00ooVH@03omV<00CobkD00onL^`03oenZ00?o:iX00ol1RP03o`1k7P?o06`e
0ol0Gd@3o`1DC0?o04A:0ol0<T43o`0U>@Co01/c0ol05Bh3o`0@:P?o00`W0ol02R@3o`088P?o00LQ
0ol01b06o`0680?o00LP0ol01b44o`098`?o00XU0ol03BL3o`0A:`?o01L`0ol083H3o`0]?P?o03i7
0ol0DTd3o`1NA@?o06/f1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0oo>
[003om2W00?od:H00oo?Z@03olf_00?ob;`00onn``03oj^n00?oVkX00on>]`03oh:d00CoN;400omb
/003og6_00?oLk000omi/P03oh:d00?oT;P00onQ_003okK100?oakh00oo>[P03omFJ00Cog8D00ooS
K@03onYE00?ol3d00oof9`03ooXE00?oo@T00oon1P03ood;00?onA/00oob=P03onUI00Cog8<00oo=
[`03oinl00?oEZP00olFT`03o`1l6`?o06Ll0ol0DTd3o`0^?`?o01D_0ol02B<4o`036`?o008I0ol0
11d3o`0<9P?o01he0ol0@4P3o`1OA0?o07TQ0olLU@03og6_00?ob;/00ooNOP04onm400?onAX00oon
2003oo/D00?olCX00ooQL`03olba00?oOk<00olUV003o`1l70?o06130ol0@4P4o`0L=0?o00XU0ol0
0a`3o`026@?o00DM0ol03BL3o`0Q=`?o04M;0ol0HT43o`1k7@?o7ID01?mZ[P03olC400?of9000ooX
G003oo@`00?ona800oon1`03oo`>00?ombD00oo]B003on5b00?odih01?o0``03ogfc00?o@Z400olA
T@03o`204`?o074_0ol0Hd03o`1FB`?o04I;0ol0<T43o`0S>0?o01Tb1?l04R`3o`0=9`?o00XT0ol0
1b43o`067`?o00DN0ol011d?o`0470Co00DM0ol01Ql3o`0780?o00TS0ol03BL3o`0B;0?o01Xb0ol0
9SX3o`0f@`?o04i>0ol0FdL7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3
olj/00?od:L00oo@YP03olnY00?ocJl00oo8_003okk300?oZkh00onK^P03ohjg00?oP[@01?mh/@03
og:`00?oLJl00omc/003ogVb00?oP[@00on@^003oj6l00?o]/400oo7_P03olj^00?oeIX01?oLQ@03
on=]00?ojUD00oo`?@03ooHW00?onQD00oom2@03ooh600?oo@/00ooi6`03oo8f00?ojET01?oLP`03
olf_00?oWk`00omFZ003oaJC00?o07`K0ol0Ic`3o`1BC@?o02ho0ol05Bl3o`098`Co00<K0ol00QT3
o`047@?o00`V0ol07SD3o`10B0?o05m40ol0NB43oabE00?oLJl00oo8^`03omin00Cokd@00ooi6P03
ooh800?ona@00ooa>P03on5c00?oc;400omo/`03obFH00?o07`L0ol0H4<3o`10B0Co01`d0ol02RD3
o`0370?o008I0ol01Ad3o`0=9`?o024g0ol0Ad/3o`1R@@?o07/M0olMU@04ofZ^00?oa<@00ooHT003
onQL00?om3000ook4P03ooh700?oo0h00oog9@03one800?ohG800ooCWP04ol3300?oOK<00om2X@03
oa6A00?o080C0ol0LBl3o`1S@0?o05I;0ol0AT/3o`0b@@?o02<h0ol06C84o`0B;0?o00dW0ol02R@3
o`078@?o00HO0ol01Ah3o`047@oo00@L1?l01Ad3o`067`?o00LP0ol02B<3o`0=9`?o018/0ol06S83
o`0V>P?o03I30ol0CTh3o`1KA`Oooooo0Ol00001ooooo`007Oooool2o`0000Kooooo0oo>[003om2W
00?od:H00oo?Z@03olf_00?ob;`00onn``03oj^n00?oVkX00on>]`03oh:d00CoN;400omb/003og6_
00?oLk000omi/P03oh:d00?oT;P00onQ_003okK100?oakh00oo>[P03omFJ00Cog8D00ooSK@03onYE
00?ol3d00oof9`03ooXE00?oo@T00oon1P03ood;00?onA/00oob=P03onUI00Cog8<00oo=[`03oinl
00?oEZP00olFT`03o`1l6`?o06Ll0ol0DTd3o`0^?`?o01D_0ol02B<4o`036`?o008I0ol011d3o`0<
9P?o01he0ol0@4P3o`1OA0?o07TQ0olLU@03og6_00?ob;/00ooNOP04onm400?onAX00oon2003oo/D
00?olCX00ooQL`03olba00?oOk<00olUV003o`1l70?o06130ol0@4P4o`0L=0?o00XU0ol00a`3o`02
6@?o00DM0ol03BL3o`0Q=`?o04M;0ol0HT43o`1k7@?o7ID01?mZ[P03olC400?of9000ooXG003oo@`
00?ona800oon1`03oo`>00?ombD00oo]B003on5b00?odih01?o0``03ogfc00?o@Z400olAT@03o`20
4`?o074_0ol0Hd03o`1FB`?o04I;0ol0<T43o`0S>0?o01Tb1?l04R`3o`0=9`?o00XT0ol01b43o`06
7`?o00DN0ol011d?o`0470Co00DM0ol01Ql3o`0780?o00TS0ol03BL3o`0B;0?o01Xb0ol09SX3o`0f
@`?o04i>0ol0FdL6ooooo`;o00000Oooool001gooooo00?o0000ooooooooool01Oooool6olVi00?o
akd00oo5a003okO100?oW[/00on8]P03ogF`00?oIZ`00omJZ@03odnV00CoAj<00om3XP03od:R00?o
AJ<00om;Y@03oeFW00?oHZ/00omc/003ohVf00?oX[`00oo0``03ol^d00Codih00ooKQP03on=/00?o
je400oob>003ooLQ00?oo1001_on1`03oo/B00?omRT00oo]B@04on9b00?odih00onj`P03ofj^00?o
:IT00ol0P`h3o`1/=@?o05M:0ol0=T<3o`0J<P?o00XU1?l011`3o`026@?o00@L0ol02R@3o`0J<P?o
03]50ol0G4H3o`1g9@?o5I800omY[@03olNo00?ogH801?o^A`03ooTK00?oo@P00ook4`03oo4i00?o
hG800oo</@03ogfc00?o8iL00ol0Nah3o`1OA0?o03i71?l06S83o`0:90?o00<K0ol00QT3o`057P?o
00lY0ol09CT3o`1>CP?o06Hm0ol0P1D3obVI00CoNk800oo9^P03omb400?oje400oof9`03oo`>00?o
oPL00ook5003oo@`00?ojEL00ooLP`03olf`00CoXK`00omPZ`03obRI00?o08P40ol0MbD3o`1X>`?o
05Y80ol0C4d3o`0e@P?o02@i0ol06C43o`0A:`Co00`V0ol02283o`067`?o00DM0ol011`3o`036`?o
00<J3ol00QX4o`036P?o00<K0ol011`3o`057P?o00LP0ol02R@3o`0>:@?o01H_0ol08CL3o`0b@@?o
04Y<1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo1_o9^@03olNm00?oaL@0
0ong`@03oijk00?oR;H00ome/003ofJ/00?oFZT00om?YP04odNS00?o@j800om2XP03odFS00?oBjD0
0omEY`03of:[00?oLk000on9]P03oj:l00?o`<<00oo;]004om>N00?ofhH00ooSK003on]A00?olSP0
0oog8@03oo`@00KooPL00ook4P03ooHY00?okDT01?oRLP03om>N00?o^/800om^[P03obVI00?o08<>
0ol0K3D3o`1GBP?o03I30ol06S83o`0:9@Co00@L0ol00QT3o`0470?o00XT0ol06S83o`0kA@?o05a6
0ol0MbD3oaFB00?oJJd00oo7_`03omf200CokTL00ooi6`03ood800?ona<00ooa>@03on5b00?oc;40
0omm/`03ob>G00?o07/N0ol0Gd@3o`0nA`Co01Xb0ol02R@3o`036`?o008I0ol01Ah3o`0?:@?o02Di
0ol0CTh3o`1V?@?o080E0olYV@04og^b00?obKX00ooLQ003on]A00?omRL00ool3P03ooh700?ona@0
0ood<003onUG00?og8<00oo=/004oj6l00?oH:/00olXV@03o`2810?o07LU0ol0J3/3o`1JB0?o04a=
0ol0=D83o`0T>@?o01Ta0ol04B/4o`0<9P?o00PR0ol01Ql3o`057@?o00@L0ol00a/3o`036Poo008J
1?l00aX3o`036`?o00@L0ol01Ah3o`0780?o00XT0ol03RT3o`0F;`?o024g0ol0<T43o`1:C0Oooooo
0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`KobKT00oo7_@03olG400?o]l400onN
^`03ohRf00?oMK000omV[003oeZY00?oCjH01?m7X`03od>R00?o@Z800om5X`03od^U00?oEJL00omR
Z`03og>`00?oRKH00onR_003ol3300?obk@01?oCWP03om^600?ohf`00oo[D@03oo8h00?omb400ool
4006ooh700?ona800oof:@03one900CohW800ooCWP03ok[200?oKZh00olYV@03o`233P?o06`e0ol0
EdX3o`0f@`?o01Xb0ol02RD4o`0470?o008I0ol011`3o`0:90?o01Xb0ol0>dD3o`1LAP?o07LU0olE
TP03ofV]00?oakl00ooMPP04oni700?onA/00oom2003oo/C00?olCT00ooQLP03olba00?oOK<00olS
U`03o`1k7P?o05m40ol0?TL4o`0J<P?o00XT0ol00a/3o`026@?o00DN0ol03bT3o`0U>@?o04i>0ol0
ISd3o`205@?o:IT01?mk/P03olVj00?og8@00oo[D@03ooHW00?oo0h00oon1`03oo/D00?om3000ooY
E`03omb300?ocK001?nQ_003of2[00?o:9T00ol0R0@3o`1g9@?o06Pk0ol0FTP3o`1<C@?o03E20ol0
93T3o`0I<@?o014[1?l032H3o`088P?o00HO0ol01Ad3o`0470?o00<K0ol00aX?o`026PCo00<J0ol0
0a/3o`0470?o00DN0ol01b03o`0:90?o00hY0ol05Rl3o`0Q=`?o03910ol0BT`7ooooo`7o00000Ooo
ool001gooooo00?o0000ooooooooool01Oooool3okc300?o]<400onV_@03oiFi00?oQ;D00om[[P03
oeJX00?oAJ800olgWP03obfK00?o99L01?lMU@03oaZD00?o6i@00olNU@03obBH00?o;I/00oljW`03
odZT00?oGjX00omh/@03oiJi00?o^<801?o:]P03om>M00?og8<00ooUIP03one:00?om3000ooi6P03
ood;00?ooPH00oom3003ooPN00?olC/01?oVHP03omV>00?ob;`00on5]@03ocbP00?o08T00ol0LRd3
o`1LA`?o03i70ol07SD3o`0=9`Co00DM0ol00QT3o`036`?o00TS0ol05c03o`0f@`?o05Y80ol0M2X3
o`j?00?oHJ/00oo5``03om^600CokDX00ooi7@03ood900?ona<00ooa>@03on5b00?oc;800oml/P03
ob6F00?o07XP0ol0GTD3o`0kAPCo01Ta0ol02B<3o`036`?o008I0ol01Ql3o`0A:`?o02Tl0ol0DDd3
o`1Z>@?o08@<0olfWP04oh^f00?ocK000ooON@03oni600?on1l00oom2P03ood900?onA/00ooa>`03
onEV00?oei@00oo7_`04ohFe00?oAJ<00olAT@03o`1o5P?o06hb0ol0Gd@3o`1AC@?o03Y50ol09c/3
o`0J<P?o014[0ol02bH4o`088@?o00DN0ol011`3o`036`?o008J7?l00QT3o`026P?o00<J0ol011`3
o`057P?o00PR0ol032H3o`0C;@?o01he0ol0;cl7ooooo`7o00000Oooool001gooooo00?o0000oooo
ooooool01Oooool3okc300?o]<400onV_@03oiFi00?oQ;D00om[[P03oeJX00?oAJ800olgWP03obfK
00?o99L01?lMU@03oaZD00?o6i@00olNU@03obBH00?o;I/00oljW`03odZT00?oGjX00omh/@03oiJi
00?o^<801?o:]P03om>M00?og8<00ooUIP03one:00?om3000ooi6P03ood;00?ooPH00oom3003ooPN
00?olC/01?oVHP03omV>00?ob;`00on5]@03ocbP00?o08T00ol0LRd3o`1LA`?o03i70ol07SD3o`0=
9`Co00DM0ol00QT3o`036`?o00TS0ol05c03o`0f@`?o05Y80ol0M2X3o`j?00?oHJ/00oo5``03om^6
00CokDX00ooi7@03ood900?ona<00ooa>@03on5b00?oc;800oml/P03ob6F00?o07XP0ol0GTD3o`0k
APCo01Ta0ol02B<3o`036`?o008I0ol01Ql3o`0A:`?o02Tl0ol0DDd3o`1Z>@?o08@<0olfWP04oh^f
00?ocK000ooON@03oni600?on1l00oom2P03ood900?onA/00ooa>`03onEV00?oei@00oo7_`04ohFe
00?oAJ<00olAT@03o`1o5P?o06hb0ol0Gd@3o`1AC@?o03Y50ol09c/3o`0J<P?o014[0ol02bH4o`08
8@?o00DN0ol011`3o`036`?o008J7?l00QT3o`026P?o00<J0ol011`3o`057P?o00PR0ol032H3o`0C
;@?o01he0ol0;cl7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3okc300?o
]<400onV_@03oiFi00?oQ;D00om[[P03oeJX00?oAJ800olgWP03obfK00?o99L01?lMU@03oaZD00?o
6i@00olNU@03obBH00?o;I/00oljW`03odZT00?oGjX00omh/@03oiJi00?o^<801?o:]P03om>M00?o
g8<00ooUIP03one:00?om3000ooi6P03ood;00?ooPH00oom3003ooPN00?olC/01?oVHP03omV>00?o
b;`00on5]@03ocbP00?o08T00ol0LRd3o`1LA`?o03i70ol07SD3o`0=9`Co00DM0ol00QT3o`036`?o
00TS0ol05c03o`0f@`?o05Y80ol0M2X3o`j?00?oHJ/00oo5``03om^600CokDX00ooi7@03ood900?o
na<00ooa>@03on5b00?oc;800oml/P03ob6F00?o07XP0ol0GTD3o`0kAPCo01Ta0ol02B<3o`036`?o
008I0ol01Ql3o`0A:`?o02Tl0ol0DDd3o`1Z>@?o08@<0olfWP04oh^f00?ocK000ooON@03oni600?o
n1l00oom2P03ood900?onA/00ooa>`03onEV00?oei@00oo7_`04ohFe00?oAJ<00olAT@03o`1o5P?o
06hb0ol0Gd@3o`1AC@?o03Y50ol09c/3o`0J<P?o014[0ol02bH4o`088@?o00DN0ol011`3o`036`?o
008J7?l00QT3o`026P?o00<J0ol011`3o`057P?o00PR0ol032H3o`0C;@?o01he0ol0;cl7ooooo`7o
00000Oooool001gooooo00?o0000ooooooooool01Oooool3oi^j00?oS;L00omk/P03ofR]00?oEJP0
0olnX003ob^J00?o79D00ol@T003o`R=00?o08X01?l0R0<6o`271@?o08T10ol3R`03o`b>00?o69<0
0olWV@03oc^O00?oDjL00om_[`03oi6h00Co^<800oo;]003omFI00?ogg/00ooXG@03oo0o00?omRH0
0ook4P03ooh700?ooPP00ooj5@03oo@^00Coje<00ooNO`03olj^00?oW;/00om?YP03o`f?00?o07PT
0ol0HD83o`17B`?o02<h0ol03bT4o`067`?o008J0ol00aX3o`088@?o01D^0ol0<D03o`1GBP?o074^
0ol9S@03oeZY00?o_l<00ooJRP04ona=00?on1h00oom2@03oo/B00?olSP00ooRLP03olbb00?oN[80
0olOUP03o`1i8P?o05e60ol0>D@4o`0H<0?o00PR0ol00aX3o`026P?o00HP0ol04R`3o`0]?P?o05A<
0ol0KC@3o`2710?o@Z801?nJ^P03om2V00?ohfl00oo`?@03ooTI00?oo@P00oom3003ooLS00?okTL0
0ooQM003om6S00?o//001?m[[P03objK00?o08T10ol0MbD3o`1V?@?o05M:0ol0A4X3o`0]?P?o01dd
0ol04b`3o`0<9P?o00PQ1?l01Ah3o`0370?o00<J3?l00QT3o`026Pco00<J1?l00QX9o`026@?o008J
0ol00a/3o`047@?o00LP0ol02bD3o`0B;0?o01de1oooool1o`00007ooooo000Mooooo`03o`000?oo
oooooooo00Gooooo0onK^P03ohbg00?oNk800omX[@03oeFX00?o?Z000ol[VP03oabE00?o49000ol8
S@03o`2:00Co08P31_l0Q`D3o`290@?o0h/00ol<SP03oaRC00?o9iT00olkW`03oe>W00?oKjl00onA
^004okS200?obk@00ooEV@03ommk00?oj5d00oo`?`03ooHV00?ona800oon1`03ooh800?onQD00ood
;P04on]C00?ogWl00oo>[P03oibk00?oCjH00ol=S`03o`1h90?o06520ol0Ad/3o`0S>0?o00lY1?l0
1Ql3o`026P?o00<J0ol02243o`0E;P?o03500ol0EdX3o`1a;P?o2Hd00omJZ@03oko300?ofXX01?o/
C@03ooPN00?oo@T00ook4P03oo8h00?ohW800oo</P03ogZb00?o7iH00ol0NB83o`1MAP?o03U41?l0
6303o`088P?o00<J0ol00QX3o`0680?o018/0ol0;Ch3o`1DC0?o06dd0ol0Q`@3od:R00CoV[X00oo@
YP03on=_00?ol3d00ooi6@03ood800?oo@`00oog8`03oni700?ohG@00ooAX`03ok;000CoJjh00ol^
V`03o`290@?o07LU0ol0ISd3o`1GBP?o04A:0ol0;Ch3o`0M=0?o01</0ol032H3o`088@Co00DN0ol0
0a`3o`036Pco008I0ol00QX<o`036PCo008J2Ol00QT3o`026P?o00<K0ol011d3o`0780?o00/U0ol0
4R`3o`0M=@Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?oVkX00on<]`03
og^b00?oJ:d00omEZ003ocjP00?o:iX00olLU@03oa2@00?o28d00ol0RP04o`280`Ko08L50ol0R@43
o`>;00?o38h00olHT`03obNI00?o>il00omCY`03ofn_00?oTKP01?nh`P03ol^d00?oeIT00ooON`03
onQM00?ol3l00oof9P03oo/B00?ooPL00oon2003ooXE00?om2h01?o[D`03omio00?ocZh00onL^`03
odnV00?o3Hl00ol0N2@3o`1Q@P?o04M;0ol08cP3o`0?:@Co00HO0ol00QX3o`036P?o00PQ0ol05Bh3
o`0a@0?o05M:0ol0LBh3o`V=00?oFZT00ono``03omZ:00Cok4d00ooh7P03ood900?ona800oob>003
on9b00?oc;800omj/P03oanF00?o07TR0ol0GDH3o`0iA0Co01P`0ol02283o`036P?o008J0ol01R03
o`0B;0?o02dn0ol0E4`3o`1]=0?o08L40om2XP04oiZj00?od:H00ooSK`03oo0m00?onAT00oom2003
ood<00?omb<00oo^A`03on5d00?odJ<00onb`004of^^00?o;Y/00ol0R@43o`1g9@?o06Hm0ol0EdX3
o`14BP?o02dn0ol07C@3o`0C;0?o00`V0ol02244o`057P?o00<L0ol00aX<o`026@?o008J3?l00aX4
o`026PWo008I0ol00QX3o`036`?o00@M0ol01b03o`0;9@?o018/0ol07CD7ooooo`7o00000Oooool0
00Kooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo
00Gooooo0omh/@03ofJ/00?oDZL00olnX003obbJ00?o69<00ol7S@03o`271@?o08<>0ol0OaD3o`1m
6PCo07/N0ol0NQl3o`1k7P?o07`K0ol0OaH3o`233P?o08P40ol9S@03oa^D00?o<Y`00om=Y@03off^
00CoTkT00ono``03olj]00?of9000ooRL003on]@00?olc<00ooi6`03ood;00?ooPL00ool3`03ooLT
00CokTH00ooRL@03om>P00?o//000omRZ`03oa^D00?o07dJ0ol0ICh3o`1?CP?o02Tl0ol04R/4o`07
80Ko008J0ol01b03o`0C;0?o02dn0ol0ED/3o`1_<@?o0h/00omDY`03okW200?ofHd01?o/C`03ooPP
00?oo@T00ook4P03oo8h00?ohW800oo</`03ogVb00?o7ID00ol0N2<3o`1LAP?o03M31?l05Rl3o`08
8@?o00<J0ol00QX3o`078@?o01@^0ol0<D03o`1GBP?o070_0ol4R`03odjU00CoZ[h00ooDW@03onEU
00?olcD00ook5003ooh800?oo1000ooe:`03onYC00?ogH800oo</@03oiVj00CoDjL00olJU003o`21
4P?o06la0ol0Gd@3o`1@CP?o03I30ol08SP3o`0F;`?o00dX0ol02283o`057PCo00<K0ol00QX6o`02
6@?o008J0ol00aX3o`036`Ko00@L2Ol011d4o`0470?o00<K0ol00aX3o`026PKo008I0ol00aX3o`04
70?o00HO0ol02RD3o`0B;0Oooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`?oN;400omV[003
oe:W00?o?Z000ol/VP03oaRC00?o1hd00ol0Q`D3o`233P?o07lE0ol0OAX4o`1k7P?o07XO0ol0Nah3
o`1l6`?o07lF0ol0P`h3o`2810?o2Hd00olKU003oc:L00?oCJD00om][P04oi>i00?o_l<00oo>[@03
omR@00?ohW000oo[D003oo<c00?onA/00oom2`03ooh700?oo0l00oog9004oni600?ohW400ooCX003
ok;000?oHZ/00olKU003o`1m6P?o06Dn0ol0Cdh3o`0Y?0?o018[1?l01b06o`026P?o00LP0ol04b`3
o`0]?P?o05E;0ol0Kc43o`>;00?oE:L00oni`P03omV=00Cok4l00ooh8003ood900?ona800oob>003
on9b00?oc;<00omi/P03oafE00?o07PS0ol0G4H3o`0g@`Co01H_0ol02243o`036P?o008J0ol01b43
o`0D;P?o03500ol0EdX3o`1`;`?o18/00om>Y@04ojZn00?oe9d00ooUI@03oo<e00?ona@00oon2003
oo`@00?omB/00ooZD`03omf200?oc;400onI^P04oe>W00?o6Y@00ol0PA83o`1_<@?o05m40ol0D4h3
o`0f@`?o028h0ol05Rl3o`0=:0?o00PR0ol01Ah4o`036`?o008J1_l00QT3o`026P?o00<J0ol00a/6
o`0470Wo00@M1?l011`3o`036`?o00<J0ol00QX6o`026@?o00<J0ol011`3o`067`?o00XU0ol04R`7
ooooo`7o00000Oooool000Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool3ogRa00?oIZ`00omBY`03ocjP00?o;9X00olHT`03o`N=
00?o08L50ol0P`h3o`1o5@?o07dJ1?l0Nah3o`1j7`?o07/N0ol0O1/3o`1o5P?o08<>0ol0R0@3o`V=
00?o6i@00olbW003odfU00?oKJh01?nC^@03oko300?ocZd00ooHT003on9`00?oje000ooc<`03ooTK
00?oo@/00oon1`03oo`?00?omb@01?o^AP03on9a00?odj000onb`003of:[00?o6i@00ol0OAX3o`1U
?P?o04m>0ol0:C`3o`0B:`Co00LP1_l00QX3o`0780?o01</0ol0;Ch3o`1EB`?o06la0ol3R`03oeBW
00?o^L800ooIS@04ona?00?on2000oom2@03oo/B00?olSP00ooRLP03olbc00?oNK800olMU@03o`1h
8`?o05a60ol0=d<4o`0F;`?o00PQ0ol00aX3o`026P?o00LQ0ol052h3o`0a@0?o05M:0ol0L2l3o`B;
00?oCZD01?nZ_P03omBM00?oiFD00ooc=@03oo/D00?ooPP00ool4003ooD[00?ojU<00ooMPP03olba
00?oVKX01?mCY`03oaZD00?o084B0ol0Kc43o`1OA0?o051>0ol0=T<3o`0R>0?o01H_0ol03BP3o`08
8P?o00DN1?l00a/3o`026PKo008I0ol00QX3o`036P?o00<K1_l011`9o`047@Co00@L0ol00a/3o`03
6P?o008J1_l00QT3o`036P?o00@L0ol01Ql3o`0:9@?o018/1oooool1o`00007ooooo0009ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool3o`0000Gooooo0omFZ003od:Q00?o
;I/00olJU003o`Z>00?o08H70ol0P1D3o`1j7`?o07HV0ol0Lb/3o`1`;`Co06lb0ol0KS83o`1_<@?o
074^0ol0M2X3o`1h8`?o07dJ0ol0P`h3o`6:00?o5I800ol_V`03odfU00CoL[000onM^`03olK000?o
dZ<00ooLP`03onMQ00?okd400oog9@03oo/A00?ooPL00oom2P03ooTK00ColCX00ooVH`03omNC00?o
aL<00ome/003obZJ00?o088@0ol0JSP3o`1CC0?o02ho0ol052h4o`088@?o00<J0ol00QX3o`067`?o
014[0ol0:S`3o`1CC@?o06de0ol0R@43odjU00?o//000ooHT004on]B00?on2400oom2P03oo/B00?o
lSP00ooRLP03olbc00?oN;400olLU003o`1g90?o05]70ol0=D84o`0E;`?o00LQ0ol00QX3o`036P?o
00PQ0ol05Rl3o`0e@P?o05Y80ol0M2X3o`b?00?oFjT01?nh`P03omNC00?oj5`00ood;@03oo`@00?o
oPP00ooj5@03oo<d00?oiel00ooHT003olNo00?oP[@01?lnX003o`R=00?o07XP0ol0J3/3o`1HBP?o
04=90ol0:Sd3o`0J<P?o010Z0ol02B@3o`067`?o00@L1?l00QX6o`026@?o00<J0ol00a/3o`0470?o
00DN0ol01Ql3o`0680Wo00LP1?l01R03o`057`?o00DM0ol011`3o`036`?o008J0ol00QT3o`026P?o
00@L0ol01Ql3o`0;9@Gooooo0ol00001ooooo`001_ooool01Ol0003ooooooooooooooooo000000Oo
oooo1?l00007ooooo`03o`000?oooooooooo00Gooooo0omFZ003od:Q00?o;I/00olJU003o`Z>00?o
08H70ol0P1D3o`1j7`?o07HV0ol0Lb/3o`1`;`Co06lb0ol0KS83o`1_<@?o074^0ol0M2X3o`1h8`?o
07dJ0ol0P`h3o`6:00?o5I800ol_V`03odfU00CoL[000onM^`03olK000?odZ<00ooLP`03onMQ00?o
kd400oog9@03oo/A00?ooPL00oom2P03ooTK00ColCX00ooVH`03omNC00?oaL<00ome/003obZJ00?o
088@0ol0JSP3o`1CC0?o02ho0ol052h4o`088@?o00<J0ol00QX3o`067`?o014[0ol0:S`3o`1CC@?o
06de0ol0R@43odjU00?o//000ooHT004on]B00?on2400oom2P03oo/B00?olSP00ooRLP03olbc00?o
N;400olLU003o`1g90?o05]70ol0=D84o`0E;`?o00LQ0ol00QX3o`036P?o00PQ0ol05Rl3o`0e@P?o
05Y80ol0M2X3o`b?00?oFjT01?nh`P03omNC00?oj5`00ood;@03oo`@00?ooPP00ooj5@03oo<d00?o
iel00ooHT003olNo00?oP[@01?lnX003o`R=00?o07XP0ol0J3/3o`1HBP?o04=90ol0:Sd3o`0J<P?o
010Z0ol02B@3o`067`?o00@L1?l00QX6o`026@?o00<J0ol00a/3o`0470?o00DN0ol01Ql3o`0680Wo
00LP1?l01R03o`057`?o00DM0ol011`3o`036`?o008J0ol00QT3o`026P?o00@L0ol01Ql3o`0;9@Oo
oooo0Ol00001ooooo`001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`05ooooo`?oEZP00om2X@03obfK00?o6Y@00ol:SP03o`261`?o
080E0ol0NQl3o`1f9P?o07<[0ol0L2l4o`1_<P?o06hb0ol0Kc43o`1a;P?o07@Z0ol0N2<3o`1m6P?o
08<>0ol1RP03oaFB00?o;i/00om=Y@04og:`00?oWK/00oo6`003om:S00?og8<00ooWH@03onm100?o
mbD00ook4@03ooh700?oo@X00ooi6`04oo4j00?oiV<00ooGT`03olG300?oMK000olZVP03o`2240?o
06Xh0ol0Dd`3o`0^?`?o01@^1?l02243o`036P?o008J0ol01Ql3o`0A:`?o02Xl0ol0Ddd3o`1]=@?o
08T10om>Y@03ok;000?of9001?o[DP03ooPQ00?oo@X00ook4P03oo8h00?ohW800oo</`03ogRa00?o
79@00ol0Mb@3o`1KA`?o03E21?l05Bl3o`078@?o008J0ol00aX3o`088@?o01H_0ol0=D83o`1JB0?o
07@Z0ol<S`03oe^Y00Co^<800ooGT`03onQL00?om2d00ool4003ooh800?onQD00ooc=003onMO00?o
f9000oo7_`03oh:d00Co?Z000ol8S@03o`1j80?o06Pk0ol0F4X3o`13B@?o02Xm0ol06S83o`0@:P?o
00TT0ol01Ql3o`0470Co008J1_l00QT3o`036P?o00<K0ol011`3o`057P?o00HO0ol01R09o`0780Co
00HP0ol01Al3o`057@?o00@L0ol00a/3o`026P?o008I0ol00QX3o`0470?o00HO0ol02bD7ooooo`7o
00000Oooool000Oooooo0ol00008ooooo`Go00001_ooool00ol0003oooooooooo`05ooooo`?o=Yh0
0olQU`03o`j?00?o08P30ol0PA43o`1j80?o07<Z0ol0KS83o`1Z>0?o06Lk0ol0ICh4o`1T?`?o06=0
0ol0I3l3o`1V?0?o06Ti0ol0KC<3o`1c;0?o07TQ0ol0P1@3o`290@?o5I800olaW004oeBW00?oOK<0
0on]_`03ol^e00?oei@00ooRLP03on]?00?om3000ooj6003ood900?ooPP00ook5@04oo@`00?ojEL0
0ooKQP03olZg00?oQkD00oliW`03o`271P?o06hb0ol0EdX3o`0d@P?o01L`1?l02B<3o`036`?o008I
0ol01Ah3o`0?:@?o02Hj0ol0D4d3o`1Z=`?o08L60om8X`03ojbo00?oei<01?oZE003ooLR00?oo@X0
0ook4@03oo8g00?ohW800oo;/`03ogJa00?o6Y@00ol0MRH3o`1JB0?o03=21?l052h3o`0780?o008J
0ol00aX3o`088P?o01Pa0ol0>D@3o`1LAP?o07LU0olETP03ofJ/00CoaL<00ooJR`03onYC00?omRL0
0ool3@03ood900?onA/00oo`?@03onA[00?oe9d00onh`P03ofb^00Co:iX00ol0QPL3o`1c:`?o0652
0ol0DDd3o`0f@`?o024g0ol052h3o`0<9P?o00LP0ol011`3o`036POo008I0ol00aX3o`0370?o00DM
0ol01Ql3o`078@?o00TS0ol02R@3o`0:9@Ko00/U1?l02R@3o`098`?o00LQ0ol01Ql3o`057@?o00<K
0ol00aX3o`026@?o008J0ol011`3o`0680Oooooo0Ol00001ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`?o=Yh00olQU`03o`j?00?o08P30ol0PA43o`1j80?o07<Z0ol0KS83o`1Z>0?o06Lk0ol0
ICh4o`1T?`?o06=00ol0I3l3o`1V?0?o06Ti0ol0KC<3o`1c;0?o07TQ0ol0P1@3o`290@?o5I800ola
W004oeBW00?oOK<00on]_`03ol^e00?oei@00ooRLP03on]?00?om3000ooj6003ood900?ooPP00ook
5@04oo@`00?ojEL00ooKQP03olZg00?oQkD00oliW`03o`271P?o06hb0ol0EdX3o`0d@P?o01L`1?l0
2B<3o`036`?o008I0ol01Ah3o`0?:@?o02Hj0ol0D4d3o`1Z=`?o08L60om8X`03ojbo00?oei<01?oZ
E003ooLR00?oo@X00ook4@03oo8g00?ohW800oo;/`03ogJa00?o6Y@00ol0MRH3o`1JB0?o03=21?l0
52h3o`0780?o008J0ol00aX3o`088P?o01Pa0ol0>D@3o`1LAP?o07LU0olETP03ofJ/00CoaL<00ooJ
R`03onYC00?omRL00ool3@03ood900?onA/00oo`?@03onA[00?oe9d00onh`P03ofb^00Co:iX00ol0
QPL3o`1c:`?o06520ol0DDd3o`0f@`?o024g0ol052h3o`0<9P?o00LP0ol011`3o`036POo008I0ol0
0aX3o`0370?o00DM0ol01Ql3o`078@?o00TS0ol02R@3o`0:9@Ko00/U1?l02R@3o`098`?o00LQ0ol0
1Ql3o`057@?o00<K0ol00aX3o`026@?o008J0ol011`3o`0680Oooooo0Ol00001ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`?o=Yh00olQU`03o`j?00?o08P30ol0PA43o`1j80?o07<Z0ol0KS83
o`1Z>0?o06Lk0ol0ICh4o`1T?`?o06=00ol0I3l3o`1V?0?o06Ti0ol0KC<3o`1c;0?o07TQ0ol0P1@3
o`290@?o5I800olaW004oeBW00?oOK<00on]_`03ol^e00?oei@00ooRLP03on]?00?om3000ooj6003
ood900?ooPP00ook5@04oo@`00?ojEL00ooKQP03olZg00?oQkD00oliW`03o`271P?o06hb0ol0EdX3
o`0d@P?o01L`1?l02B<3o`036`?o008I0ol01Ah3o`0?:@?o02Hj0ol0D4d3o`1Z=`?o08L60om8X`03
ojbo00?oei<01?oZE003ooLR00?oo@X00ook4@03oo8g00?ohW800oo;/`03ogJa00?o6Y@00ol0MRH3
o`1JB0?o03=21?l052h3o`0780?o008J0ol00aX3o`088P?o01Pa0ol0>D@3o`1LAP?o07LU0olETP03
ofJ/00CoaL<00ooJR`03onYC00?omRL00ool3@03ood900?onA/00oo`?@03onA[00?oe9d00onh`P03
ofb^00Co:iX00ol0QPL3o`1c:`?o06520ol0DDd3o`0f@`?o024g0ol052h3o`0<9P?o00LP0ol011`3
o`036POo008I0ol00aX3o`0370?o00DM0ol01Ql3o`078@?o00TS0ol02R@3o`0:9@Ko00/U1?l02R@3
o`098`?o00LQ0ol01Ql3o`057@?o00<K0ol00aX3o`026@?o008J0ol011`3o`0680Oooooo0Ol00001
ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o6I@00ol5S003o`2430?o07`K0ol0MRL3o`1^
<P?o06Pj0ol0Hd03o`1OA0?o05e60ol0FdP7o`1IB0?o05]80ol0GDH3o`1P@`?o06@o0ol0JCT3o`1_
<@?o07LU0ol0OaD3o`2900?o6I@01?ljW`03of6[00?oSkP00oo4a003om6U00?ogH800ooWGP03oo4l
00?on2000ool3@03ooh700?oo0l01?of9`03ona<00?oggX00oo>[003oiVj00?oB:<00ol4R`03o`1c
;0?o05]70ol0>TD3o`0J<PCo00XT0ol011`3o`026@?o00DM0ol03RP3o`0T>@?o04i>0ol0J3X3o`25
2P?o@Z800onW_@03omJF00CojUH00oog9003ood:00?ona400oob=`03on9b00?obk@00ome/@03oaVC
00?o07HW0ol0FDP3o`0b@@Co01<]0ol01R03o`026P?o00<K0ol02B<3o`0J<P?o03e70ol0Gd@3o`1j
80?o7ID00omb/004olRl00?ogH800oo]B`03ooLQ00Koo@/00ooh8@03oni700?oh7L00oo?Z@03oj>m
00?oF:P01?lJU003o`2050?o06de0ol0FdL3o`17B`?o02`n0ol06S83o`0?:@?o00TS0ol01Ah3o`03
6`Oo008I0ol00aX3o`0470?o00DN0ol01b03o`098`?o00/U0ol03BL3o`0>:@Wo010Z1?l03bT3o`0>
:0?o00`V0ol02R@3o`078@?o00DN0ol011`3o`036P?o008I0ol00aX3o`0470Oooooo0Ol00001oooo
o`007Oooool00ol0003oooooooooo`05ooooo`?o6I@00ol5S003o`2430?o07`K0ol0MRL3o`1^<P?o
06Pj0ol0Hd03o`1OA0?o05e60ol0FdP7o`1IB0?o05]80ol0GDH3o`1P@`?o06@o0ol0JCT3o`1_<@?o
07LU0ol0OaD3o`2900?o6I@01?ljW`03of6[00?oSkP00oo4a003om6U00?ogH800ooWGP03oo4l00?o
n2000ool3@03ooh700?oo0l01?of9`03ona<00?oggX00oo>[003oiVj00?oB:<00ol4R`03o`1c;0?o
05]70ol0>TD3o`0J<PCo00XT0ol011`3o`026@?o00DM0ol03RP3o`0T>@?o04i>0ol0J3X3o`252P?o
@Z800onW_@03omJF00CojUH00oog9003ood:00?ona400oob=`03on9b00?obk@00ome/@03oaVC00?o
07HW0ol0FDP3o`0b@@Co01<]0ol01R03o`026P?o00<K0ol02B<3o`0J<P?o03e70ol0Gd@3o`1j80?o
7ID00omb/004olRl00?ogH800oo]B`03ooLQ00Koo@/00ooh8@03oni700?oh7L00oo?Z@03oj>m00?o
F:P01?lJU003o`2050?o06de0ol0FdL3o`17B`?o02`n0ol06S83o`0?:@?o00TS0ol01Ah3o`036`Oo
008I0ol00aX3o`0470?o00DN0ol01b03o`098`?o00/U0ol03BL3o`0>:@Wo010Z1?l03bT3o`0>:0?o
00`V0ol02R@3o`078@?o00DN0ol011`3o`036P?o008I0ol00aX3o`0470Oooooo0Ol00001ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`?o6I@00ol5S003o`2430?o07`K0ol0MRL3o`1^<P?o06Pj
0ol0Hd03o`1OA0?o05e60ol0FdP7o`1IB0?o05]80ol0GDH3o`1P@`?o06@o0ol0JCT3o`1_<@?o07LU
0ol0OaD3o`2900?o6I@01?ljW`03of6[00?oSkP00oo4a003om6U00?ogH800ooWGP03oo4l00?on200
0ool3@03ooh700?oo0l01?of9`03ona<00?oggX00oo>[003oiVj00?oB:<00ol4R`03o`1c;0?o05]7
0ol0>TD3o`0J<PCo00XT0ol011`3o`026@?o00DM0ol03RP3o`0T>@?o04i>0ol0J3X3o`252P?o@Z80
0onW_@03omJF00CojUH00oog9003ood:00?ona400oob=`03on9b00?obk@00ome/@03oaVC00?o07HW
0ol0FDP3o`0b@@Co01<]0ol01R03o`026P?o00<K0ol02B<3o`0J<P?o03e70ol0Gd@3o`1j80?o7ID0
0omb/004olRl00?ogH800oo]B`03ooLQ00Koo@/00ooh8@03oni700?oh7L00oo?Z@03oj>m00?oF:P0
1?lJU003o`2050?o06de0ol0FdL3o`17B`?o02`n0ol06S83o`0?:@?o00TS0ol01Ah3o`036`Oo008I
0ol00aX3o`0470?o00DN0ol01b03o`098`?o00/U0ol03BL3o`0>:@Wo010Z1?l03bT3o`0>:0?o00`V
0ol02R@3o`078@?o00DN0ol011`3o`036P?o008I0ol00aX3o`0470Oooooo0Ol00001ooooo`007Ooo
ool00ol0003oooooooooo`05ooooo`?o08X00ol0PA43o`1i8@?o078]0ol0JcL3o`1T?`?o05i50ol0
FDT3o`1EB`?o05=<0ol0DDd4o`1@CP?o051=0ol0DTd3o`1DC0?o05M:0ol0FdL3o`1P@`?o06Ll0ol0
KS83o`1g9@?o084C0ol4R`04ob>G00?oB:<00ome/003ojRn00?obkD00ooHTP03on=]00?okDP00oof
:@03oo/B00?ooPP00oom3004ooPO00?okd800ooRK`03om:R00?oZ[h00omFZ003o`n@00?o07LU0ol0
GT@3o`10B0?o01he1?l032H3o`0470?o008I0ol011`3o`0<9`?o024g0ol0BTd3o`1W?0?o08<>0olm
X003oj:l00?oeIT01?oYF@03ooLU00?oo@/00ook4@03oo8f00?ohW800oo;]003ogB`00?o5i<00ol0
MBP3o`1IB@?o03101?l04b`3o`067`?o008I0ol00a/3o`0:90?o01`d0ol0@DP3o`1Q@P?o07`K0olU
V003ogfc00CobkD00ooONP03onm400?onA`00oom2@03oo`=00?omRL00oo[D003omf200?obk@00on@
^003odNS00Co2hh00ol0NR03o`1W?0?o05E;0ol0?4H3o`0T>@?o01D^0ol032H3o`0680?o00@L0ol0
0QX3o`026@Co008J0ol00a/3o`057P?o00LQ0ol02R@3o`0=9`?o00lZ0ol04R`3o`0E;P?o01H_1_l0
5c04o`0F;`?o01@^0ol04R`3o`0?:@?o00`V0ol02B<3o`067`?o00@L0ol00aX3o`026P?o00<J1ooo
ool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0RP03o`214@?o07TQ0ol0LRd3
o`1[=`?o06@o0ol0GTD3o`1IB@?o05E;0ol0Dd`3o`1AC@Co051>0ol0D4d3o`1BC@?o05A<0ol0EdX3
o`1KA`?o06130ol0Ic`3o`1^<P?o07LU0ol0PA<3o`B;00Co8iL00om8X`03ogF`00?oZ;h00oo;]@03
omRB00?ohfd00oo]B003ooHY00?ona800oon2003ood<00Con1l00oo_@P03on9_00?odZ800onZ_P03
oeJX00?o3i000ol0MbD3o`1NA0?o04180ol07SD4o`0<9P?o00@L0ol00QT3o`0470?o00`W0ol08CL3
o`1:C@?o06Ll0ol0P`h3ocfP00?oX[`00ooEV@04onUI00?ombD00oom2`03oo/A00?olSH00ooRLP03
ol^d00?oM;000olGT`03o`1e:0?o05U90ol0<404o`0C;0?o00HO0ol00QT3o`036`?o00XT0ol073@3
o`11B0?o06520ol0O1/3obFH00?oOK<01?o;]@03ommj00?okd@00ooi7003ood900?oo0d00oof9`03
on]@00?ogH800oo;]003oi2h00?oAj<01?l;SP03o`1j80?o06Ll0ol0ED/3o`0lAP?o02@i0ol05Bh3
o`0<9P?o00HP0ol011`3o`026P?o008I1?l00QX3o`036`?o00DN0ol01b43o`0:90?o00dW0ol03bX3
o`0B;0?o01D^0ol05Rl6o`0G<0Co01H_0ol052h3o`0B;0?o00lY0ol032H3o`098`?o00HO0ol011`3
o`036P?o008J0ol00aX7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`2:
00?o084A0ol0NB43o`1b;@?o06/g0ol0I3l3o`1NA@?o05U90ol0ED/3o`1CC0?o055=1?l0D4h3o`1@
C@?o059=0ol0E4`3o`1GBP?o05]70ol0H4<3o`1W?0?o06hb0ol0MbD3o`214`?o18/01?lSU`03odRS
00?oMK000onX_P03ol^e00?of9800ooSK@03one800?omRT00ook4P03ooh800?oo@`01?oh7`03onm2
00?ohVl00ooBXP03ojZn00?oEZP00ol?T003o`1g9@?o05i40ol0@4P3o`0N=@Co00`V0ol011`3o`02
6@?o00@L0ol032L3o`0Q=`?o04Y=0ol0Ic`3o`233P?o?J000onR_003omFI00CojET00oog9@03ood;
00?ona400oob=P03on9b00?obk@00omd/003oaNC00?o07DX0ol0FDT3o`0`@0Co01</0ol01Ql3o`02
6@?o00<K0ol02R@3o`0L=0?o04580ol0HD83o`1l6`?o9IP00omm/`04ol^e00?oggX00oo_A003ooTL
00?oo@T00ool3@03ooHW00?oje000ooMPP03ol^d00?oT;P00om7X`04o`^>00?o07XP0ol0Ic`3o`1E
B`?o03a60ol093T3o`0E;P?o00`V0ol01R03o`0470?o008J0ol00QT4o`026P?o00<K0ol01Ah3o`07
8@?o00XT0ol03BL3o`0?:P?o018/0ol05Bh3o`0F;`Ko01L`1?l05Rl3o`0D;P?o018/0ol03bT3o`0<
9P?o00TS0ol01Ql3o`0470?o00<J0ol00QX3o`036POooooo0Ol00001ooooo`007Oooool2o`0000Ko
oooo0ol0P1@3o`1g90?o06la0ol0J3/3o`1Q@P?o05Y80ol0E4`3o`1@CP?o04]=0ol0ATX3o`12B@Oo
04580ol0A4X3o`19C0?o04m>0ol0Dd`3o`1IB@?o05m40ol0IS`3o`1_<@?o07TQ0ol0Q0`4o`n@00?o
<Y`00omMZP03ohng00?oaL<00ooCX003ommj00?ojUD00ooc<P03ooXH00Koo@T01?oi6@03oo4i00?o
iFD00ooFV003ok[200?oI:`00olIU003o`1k7P?o06910ol0AT/3o`0Q=`Co00dW0ol011d3o`026@?o
00@L0ol02bD3o`0O=@?o04M;0ol0ICh3o`214@?o>Il00onM^`03omBL00Coj5/00oof9P03ood;00?o
na400oob=P03on9b00?obk@00omc/003oaJB00?o07@Y0ol0F4X3o`0_?`Co018/0ol01Ql3o`026@?o
00<K0ol02bD3o`0N=@?o04E:0ol0I403o`1o5P?o;I/00on7]@04olf^00?ohG<00oo`?P03ooXH00?o
o@P00ool4003oo@]00?ojET00ooIS003olNn00?oO[<00olgWP04o`290@?o07@Y0ol0HD83o`1@CP?o
03=10ol07SD3o`0A:`?o00TS0ol01Ah3o`036`Ko008I1?l00a/3o`057@?o00LP0ol02R@3o`0=:0?o
014[0ol05Bh3o`0I<@?o01`d0ol07cD6o`0P=PCo01lf0ol07C@3o`0I<P?o01H_0ol04B/3o`0=9`?o
00TS0ol01R03o`0470?o00<J0ol00QX6ooooo`;o00000Oooool001gooooo00?o0000ooooooooool0
1Oooool3o`2050?o07LT0ol0Kc43o`1X>`?o06520ol0FTP3o`1DC0?o051>0ol0Bdd3o`16BP?o0499
1ol0@DP3o`14BP?o04U<0ol0Cdh3o`1CC0?o05U90ol0Gd@3o`1V?0?o06la0ol0NB43o`2430Co3i00
0olbW003oefZ00?oSkL00oo5``03om>P00?oggX00ooZE@03oo<b00?onQP01_om2@04ooTI00?olCT0
0ooUI@03omJH00?o^/800omT[003oaVD00?o07/N0ol0HT43o`16B`?o024g1?l03BL3o`047@?o008I
0ol011`3o`0;9@?o01le0ol0Ad/3o`1U?P?o084A0oliW`03oifk00?oe9`01?oXF`03ooHV00?oo@/0
0ook4@03oo8f00?ohW800oo;]003og>`00?o5Y800ol0M2T3o`1HBP?o02lo1?l04R`3o`067`?o008I
0ol00a/3o`0;9@?o01he0ol0ADX3o`1T@0?o07lF0ol]V`03ohNe00CocJh00ooQL`03oo0n00?onQP0
0oom2003oo`@00?om2d00ooYF@03omV<00?oakh00omn/`03ocNN00Co08T10ol0M2T3o`1Q@P?o051>
0ol0<d43o`0N=@?o014[0ol02B<3o`057P?o00<K1_l00QT4o`036`?o00DM0ol01b03o`0:90?o00dX
0ol04B/3o`0E;P?o01Ta0ol073@3o`0O=@Ko020f1?l07cH3o`0M=0?o01Tb0ol05Rl3o`0A:`?o00dW
0ol02B<3o`0680?o00@L0ol00aX3o`026POooooo0Ol00001ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`?o080D0ol0Mb@3o`1_<@?o06Pk0ol0HD83o`1JB0?o05A<0ol0D4h3o`1;C@?o04I:0ol0
@TT7o`11B0?o04A:0ol0BD`3o`1?CP?o05=<0ol0FDT3o`1OA0?o06Hl0ol0Kc43o`1i8@?o08@<1?l?
T003oc:L00?oGJX00on?]`03olG300?odj000ooONP03onYE00?olc800ooj6006ood900ConAT00ooa
>@03onEU00?oeYP00onj`P03ofB/00?o6I@00ol0Nah3o`1R@@?o04I;0ol08CL4o`0=9`?o00@M0ol0
0QT3o`0470?o00/U0ol07cD3o`17B`?o06Dn0ol0PA43ocVO00?oWK/00ooDW004onQK00?omRH00oom
2`03oo/A00?olSH00ooRLP03ol^d00?oLk000olFTP03o`1d:@?o05Q:0ol0;cl4o`0B;0?o00HO0ol0
0QT3o`036`?o00/U0ol07SD3o`15BP?o06A00ol0OaH3obfK00?oQkD01?o=[P03on5c00?ol3h00ooj
6003ood800?oo1000ood;@03onUI00?ofH`00oo7_P03ogjc00?o=ih01?l0R@43o`1d:@?o06520ol0
D4h3o`0c@@?o01he0ol04B/3o`098`?o00DN0ol00a/6o`026@Co00<K0ol01Ad3o`0780?o00XT0ol0
3BP3o`0A:`?o01D^0ol06C43o`0L=0?o01le1_l083H4o`0O=P?o01dd0ol06C83o`0F;`?o014[0ol0
3BL3o`098`?o00HP0ol011`3o`036P?o008J1oooool1o`00007ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo0ol0Mb@3o`1^<P?o06Hm0ol0GTD3o`1HBP?o055=0ol0BD`3o`10B0?o03Y50ol0=T<3
o`0c@@Co03910ol0<d43o`0f@`?o03Y50ol0@DP3o`1:C0?o055=0ol0F4X3o`1OA0?o06Pk0ol0LRd3
o`1m6`Co08T10olNUP03odNS00?oN;400on``003olj]00?ofhP00ooWH@03oo4l00?on1h00oom3003
ooh800Cona@00ooc<@03onQL00?ofHh00oo6`@03og:`00?o99L00ol0OQP3o`1U?P?o04e>0ol093T4
o`0?:@?o00DN0ol00QT3o`036`?o00XT0ol07C@3o`13B@?o06=00ol0P1@3ocFM00?oV;X00ooCWP04
onQM00?omRL00oom2`03oo`A00?olSH00ooRLP03ol^d00?oL[000olETP03o`1d:P?o05M:0ol0;Ch4
o`0A:`?o00DN0ol00QT3o`0470?o00/V0ol083H3o`19C0?o06Hm0ol0PA43ocFM00?oTKP01?o@Z003
on=/00?olSP00ooj5@03ood800?ona@00ooc=003onIR00?oeYH00ono``03ofj_00?o:9T01?l0Q0`3
o`1_<@?o05a60ol0B4/3o`0[?@?o01Pa0ol03BL3o`078@?o00@L0ol00QX3o`026@?o00<J1?l011`3
o`0680?o00TS0ol03BL3o`0B;0?o01L`0ol073@3o`0Q=`?o02Di0ol0:3/3o`0Z?0?o02/m1?l0:C`3
o`0W>`?o02<h0ol07SD3o`0H<@?o01<]0ol03RP3o`098`?o00HO0ol011`3o`036POooooo0Ol00001
ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o07LT0ol0KS83o`1V?@?o05i50ol0F4X3o`1A
C@?o04U<0ol0@4P3o`0jA@?o03I30ol0<d44o`0b@@?o03=10ol0=T<3o`0jA@?o04580ol0BT`3o`1A
C@?o05Q:0ol0Gd@3o`1X>`?o078]0ol0OA/4o`290@?o7YH00om7X`03ogRa00?o/<000oo>[@03om^8
00?oif400ooa?003ooPN00?oo@`00oon2004oo/D00?olc400ooXG003omV>00?oa/400omb/003obBG
00?o07hH0ol0ICh3o`1=CP?o02@i1?l03bT3o`057P?o008I0ol00a/3o`0:90?o01dd0ol0@dT3o`1S
@0?o080D0oleW@03oiRj00?odih01?oXG@03ooHW00?oo@/00ool4@03oo8f00?ohW800oo;]003og:`
00?o5I800ol0M2X3o`1GBP?o02dn1?l04B/3o`057P?o008I0ol011`3o`0;9P?o020f0ol0BD`3o`1V
?@?o084A0oleW@03oi6h00Cod:P00ooSK003oo8h00?onQD00oom2003oo/D00?olc@00ooVHP03omJF
00?o_l<00om^[`03obRI00Co08@<0ol0Kc43o`1LAP?o04Q;0ol0:cd3o`0H<@?o00dW0ol01b43o`04
70?o008J0ol00QT3o`036PCo00@L0ol01R03o`098`?o00dW0ol04R`3o`0G<0?o01`d0ol08CL3o`0U
>@?o02Pk0ol0:S`3o`0[?@Co02Tl0ol09c/3o`0S>0?o01he0ol06343o`0C;@?o00hX0ol02B<3o`06
7`?o00@L0ol00aX7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1g90?o
06hb0ol0ISd3o`1NA@?o05Q:0ol0DDd3o`19C0?o04180ol0>TD3o`0f@`?o03=11?l0<T43o`0c@@?o
03I30ol0>TD3o`11B0?o04Y<0ol0DDd3o`1HBP?o05m40ol0J3/3o`1b;@?o07dK1?l0R@43oajF00?o
Aj<00omh/@03ok3000?ocZd00ooKR003onMQ00?olC`00ooh7P03ood<00?ooPP01?ok5003oo<a00?o
j5`00ooISP03olK100?oL[000olTU`03o`1n60?o06Dn0ol0CDh3o`0T>@Co00lY0ol01Ah3o`026@?o
00<K0ol02R@3o`0M=0?o04=90ol0Hd03o`2050?o=Id00onH^P03om>N00Coj5d00oof9`03ood;00?o
o1400oob=P03on9b00?obk@00omb/003oaFB00?o07@Z0ol0EdX3o`0]?PCo014[0ol01Ah3o`026@?o
00@L0ol02bH3o`0P=P?o04U<0ol0ISd3o`214@?o=Id00onA^004om2X00?ohf`00oob>003ooXE00?o
o@P00ook5003oo<d00?oiV800ooFUP03oko300?oKZl00olXV@04o`2430?o06la0ol0G4H3o`18B`?o
02/m0ol06343o`0=9`?o00LQ0ol011`3o`026P?o008I0ol00aX4o`0470?o00HP0ol02B<3o`0=9`?o
018/0ol05c03o`0L=0?o024g0ol09CT3o`0X>`?o02Xl0ol0:cd4o`0Y?0?o02Lk0ol08cP3o`0N=@?o
01Pa0ol04bd3o`0>:0?o00TS0ol01Ql3o`0470?o00<J1oooool1o`00007ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo0ol0Mb@3o`1^<P?o06Hm0ol0GTD3o`1HBP?o055=0ol0BD`3o`10B0?o03Y5
0ol0=T<3o`0c@@Co03910ol0<d43o`0f@`?o03Y50ol0@DP3o`1:C0?o055=0ol0F4X3o`1OA0?o06Pk
0ol0LRd3o`1m6`Co08T10olNUP03odNS00?oN;400on``003olj]00?ofhP00ooWH@03oo4l00?on1h0
0oom3003ooh800Cona@00ooc<@03onQL00?ofHh00oo6`@03og:`00?o99L00ol0OQP3o`1U?P?o04e>
0ol093T4o`0?:@?o00DN0ol00QT3o`036`?o00XT0ol07C@3o`13B@?o06=00ol0P1@3ocFM00?oV;X0
0ooCWP04onQM00?omRL00oom2`03oo`A00?olSH00ooRLP03ol^d00?oL[000olETP03o`1d:P?o05M:
0ol0;Ch4o`0A:`?o00DN0ol00QT3o`0470?o00/V0ol083H3o`19C0?o06Hm0ol0PA43ocFM00?oTKP0
1?o@Z003on=/00?olSP00ooj5@03ood800?ona@00ooc=003onIR00?oeYH00ono``03ofj_00?o:9T0
1?l0Q0`3o`1_<@?o05a60ol0B4/3o`0[?@?o01Pa0ol03BL3o`078@?o00@L0ol00QX3o`026@?o00<J
1?l011`3o`0680?o00TS0ol03BL3o`0B;0?o01L`0ol073@3o`0Q=`?o02Di0ol0:3/3o`0Z?0?o02/m
1?l0:C`3o`0W>`?o02<h0ol07SD3o`0H<@?o01<]0ol03RP3o`098`?o00HO0ol011`3o`036POooooo
0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o06lb0ol0ISd3o`1MA@?o05I;0ol0
D4h3o`14BP?o03U50ol0<T43o`0]?P?o02Xl0ol0:3/4o`0W>`?o02Pk0ol0:Sd3o`0^?`?o03A20ol0
?4H3o`17B`?o055=0ol0FDT3o`1Q@P?o06/g0ol0MRH4o`2240?o3Xl00oldW@03of>/00?oVkX00oo9
^P03omND00?ohf`00oo^AP03ooHU00?oo0l00oon2004oo`A00?omB/00ooZD`03omb500?obKT00omn
/`03objK00?o084A0ol0J3X3o`1@CP?o02Pk1?l042X3o`067`?o008I0ol00a/3o`0990?o01/c0ol0
@4P3o`1R@P?o07hG0olaW003oiBi00?odZ001?oWGP03ooHX00?oo@`00ool4003oo8f00?ohW400oo;
]@03og6_00?o59400ol0Lb/3o`1GBP?o02`n1?l042X3o`057P?o008I0ol011`3o`0<9P?o028g0ol0
CDh3o`1X>`?o08@<0ollX003oi^j00CodZ800ooUIP03oo<c00?ona800oom2@03ooXG00?olCX00ooT
JP03om>O00?o[kl00omOZP03oabE00Co07lF0ol0JcL3o`1HBP?o03m70ol093T3o`0D;P?o00/U0ol0
1Ql3o`036`Ko008I0ol00a/4o`057P?o00PR0ol032H3o`0A:`?o01L`0ol07CD3o`0T>@?o02Xl0ol0
;cl3o`0c@@?o03I30ol0=d<4o`0e@`?o03=10ol0;Sl3o`0X>`?o024g0ol06S83o`0D;@?o00hX0ol0
2B<3o`067`?o00@L1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0Kc83
o`1V?@?o05e50ol0ET/3o`1@CP?o04A:0ol0>DD3o`0b@@?o02dn0ol0:S`3o`0X>`Co02Lk0ol0:3/3
o`0Z?@?o02ho0ol0=483o`0lAP?o04M;0ol0DDd3o`1IB@?o06520ol0JcL3o`1f9PCo088@0ol>S`03
ocBM00?oHj`00onK^P03olVj00?oei@00ooSK003oni600?omRD00ool3`03ooh800Coo1400ooe:`03
onYC00?og8D00oo9^@03ogjc00?o;Y/00ol0PA43o`1X>P?o051>0ol0:3/4o`0@:P?o00HO0ol00QT3
o`036`?o00TT0ol06c<3o`10B0?o06920ol0OQL3oc6L00?oU;T00ooBX004onMN00?omRP00oom3003
oo`@00?olSH00ooRL@03ol^e00?oLJl00olDT@03o`1c:`?o05M:0ol0;3h4o`0@:P?o00DN0ol00QT3
o`0470?o00`V0ol08SL3o`1=CP?o06Pk0ol0Q0`3ocbP00?oVkX01?oBXP03onEV00?olc<00ook4P03
ood900?onQL00ooa>P03onAZ00?odil00on__`03oenZ00?o79D01?l0OaH3o`1[=`?o05Q:0ol0?dL3
o`0T>@?o01@^0ol02bD3o`067`?o00<K1_l00QT3o`036`Co00DN0ol02283o`0<9P?o014[0ol05c03
o`0M=@?o02@i0ol0:S`3o`0_?`?o03=10ol0=T<3o`0g@`Co03E30ol0<d43o`0^?`?o02Pk0ol08CL3
o`0J<P?o01@]0ol03RP3o`098`?o00HO0ol011`7ooooo`7o00000Oooool001gooooo00?o0000oooo
ooooool01Oooool3o`1_<P?o06Hm0ol0GDD3o`1FB`?o051>0ol0A4X3o`0iA@?o03910ol0;Ch3o`0Z
?0?o02Pk1?l09c/3o`0X>`?o02Xm0ol0;Sl3o`0d@P?o03a60ol0Ad/3o`1AC@?o05U90ol0HD83o`1[
=`?o07HV1?l0PQ03o`j?00?o=9d00omS[003oi^j00?obKX00ooGU003on=/00?okTH00oof9@03oo`?
00?ooPP01?ol4@03ooD[00?ojU<00ooLQ@03olVi00?oO[<00ol^V`03o`214@?o06Pj0ol0D4h3o`0X
>`Co010Z0ol01Ql3o`026@?o00<K0ol02B@3o`0K<`?o04180ol0HT83o`1n5`?o<I`00onD^@03om:P
00Coieh00oof:003ood<00?oo1000oob=P03on9a00?obkD00oma[`03oaBA00?o07<[0ol0EdX3o`0/
?PCo010Z0ol01Ah3o`026@?o00@L0ol032H3o`0R=`?o04e>0ol0J3/3o`2430?o?:000onK^P04om:R
00?oiFH00ooc<`03oo/B00?oo@T00ooj5`03oo4j00?oi6X00ooCW`03ojno00?oGjX00olLU@04o`1o
5P?o06/g0ol0F4X3o`0oA`?o02@i0ol052h3o`0;9@?o00HO0ol00a/6o`026@?o00<K1?l01Ah3o`08
8P?o00`V0ol04B/3o`0G<0?o01de0ol093T3o`0Z?0?o02lo0ol0<d43o`0f@`?o03M31?l0=D<3o`0c
@@?o02ho0ol0:3/3o`0Q=`?o01Xb0ol052d3o`0>:0?o00TS0ol01Ql3o`0470Oooooo0Ol00001oooo
o`007Oooool00ol0003oooooooooo`05ooooo`?o06Ll0ol0GTD3o`1FB`?o04m>0ol0@DP3o`0f@`?o
02dn0ol09c/3o`0S>0?o020f0ol07cD4o`0N=@?o01lf0ol08CL3o`0U>@?o02Xl0ol0<D03o`0kA@?o
04Q;0ol0Dd`3o`1KA`?o06Dn0ol0L304o`1l70?o08T00olTU`03oe6V00?oQkD00oo4a003om>O00?o
h7L00oo/C`03ooD/00?ona<00oon2004oo`>00?ombD00oo]B`03omim00?oc;800on;]P03ocNN00?o
08D:0ol0JcL3o`1CC@?o02/m1?l04R/3o`067`?o008J0ol00a/3o`098`?o01Tb0ol0?DL3o`1P@`?o
07dJ0ol]V`03oi2h00?odZ<01?oWH003ooHY00?oo@`00ool4003oo8e00?ohW400oo;]@03og2_00?o
4i400ol0Lb`3o`1FB`?o02/m1?l042X3o`057P?o008I0ol011`3o`0=9`?o02@i0ol0Cdh3o`1Z>@?o
08H80om3XP03oj>m00Coe9`00ooWH@03oo@_00?oo1000oom2@03ooTK00?ol4000ooRLP03om2W00?o
XK`00omAYP03oa6@00Co07/N0ol0ISd3o`1DC0?o03M30ol07cH3o`0A:`?o00TS0ol011d3o`036P?o
008I0ol00aX3o`047@Co00LP0ol02RD3o`0@:P?o01H_0ol07C@3o`0U>@?o02`n0ol0=483o`0jA@?o
03m70ol0@TT3o`14BPCo04=90ol0@4P3o`0jA@?o03=20ol0:cd3o`0S>0?o01/c0ol04bd3o`0=9`?o
00PR0ol01Ah7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1W?0?o05i5
0ol0ET/3o`1?CP?o04580ol0=T<3o`0]?P?o02Lk0ol08cP3o`0P=P?o01le1?l07SD3o`0O=P?o024g
0ol09CT3o`0Z?0?o03500ol0>dD3o`18B`?o05=<0ol0FdL3o`1U?P?o070`1?l0O1`3o`2900?o99L0
0omAYP03ohNe00?oa<@00ooCW`03on1g00?ok4l00ooe;003oo/C00?ooPP01?ol3P03ooLU00?okD/0
0ooNO@03olbb00?oRkH00olgWP03o`252P?o06/g0ol0Ddd3o`0[?@Co018[0ol01Ql3o`026P?o00<K
0ol02B<3o`0I<P?o03e70ol0H4<3o`1m6P?o;I/00on@^003om:S00Coif000oof:@03ood<00?oo100
0oob=@03on9a00?obkD00om`[`03oa>A00?o07</0ol0ET/3o`0[?@Co010Z0ol01Ah3o`026@?o00@L
0ol03BL3o`0T>@?o04m>0ol0JST3o`2620?o@j800onS_@04omBL00?oif400ood;`03oo`@00?oo@T0
0ooi6`03oo1000?ohW800oo@Y`03oj6l00?oDJH00olAT004o`1k7P?o06Hm0ol0E4`3o`0g@`?o01lf
0ol04B/3o`098`?o00@M0ol00aX3o`026@?o00<J0ol011d4o`0780?o00XU0ol042X3o`0F;`?o01dd
0ol09CT3o`0/?P?o03A20ol0>TD3o`0oA`?o04990ol0A4X4o`13B@?o04180ol0>TD3o`0c@P?o02/m
0ol08cP3o`0K<`?o01<]0ol03BL3o`088P?o00DN1oooool1o`00007ooooo000Mooooo`;o00001_oo
ool3o`1W?0?o05i50ol0ET/3o`1?CP?o04580ol0=T<3o`0]?P?o02Lk0ol08cP3o`0P=P?o01le1?l0
7SD3o`0O=P?o024g0ol09CT3o`0Z?0?o03500ol0>dD3o`18B`?o05=<0ol0FdL3o`1U?P?o070`1?l0
O1`3o`2900?o99L00omAYP03ohNe00?oa<@00ooCW`03on1g00?ok4l00ooe;003oo/C00?ooPP01?ol
3P03ooLU00?okD/00ooNO@03olbb00?oRkH00olgWP03o`252P?o06/g0ol0Ddd3o`0[?@Co018[0ol0
1Ql3o`026P?o00<K0ol02B<3o`0I<P?o03e70ol0H4<3o`1m6P?o;I/00on@^003om:S00Coif000oof
:@03ood<00?oo1000oob=@03on9a00?obkD00om`[`03oa>A00?o07</0ol0ET/3o`0[?@Co010Z0ol0
1Ah3o`026@?o00@L0ol03BL3o`0T>@?o04m>0ol0JST3o`2620?o@j800onS_@04omBL00?oif400ood
;`03oo`@00?oo@T00ooi6`03oo1000?ohW800oo@Y`03oj6l00?oDJH00olAT004o`1k7P?o06Hm0ol0
E4`3o`0g@`?o01lf0ol04B/3o`098`?o00@M0ol00aX3o`026@?o00<J0ol011d4o`0780?o00XU0ol0
42X3o`0F;`?o01dd0ol09CT3o`0/?P?o03A20ol0>TD3o`0oA`?o04990ol0A4X4o`13B@?o04180ol0
>TD3o`0c@P?o02/m0ol08cP3o`0K<`?o01<]0ol03BL3o`088P?o00DN1_ooool2o`00007ooooo000M
ooooo`03o`000?oooooooooo00Gooooo0ol0H4<3o`1GBP?o04m>0ol0@4P3o`0d@P?o02/m0ol093T3
o`0O=@?o01/c0ol06C87o`0H<@?o01Ta0ol06c<3o`0N=@?o028h0ol0:3`3o`0a@0?o03e60ol0C4d3
o`1FB`?o05m40ol0JSP4o`1f9P?o08@<0olETP03od6Q00?oMK400onb`003olnZ00?ogH400ooYF003
oo<c00?onQL00oom2@04ood;00?on2000oo^A@03on5e00?ocj/00onF^@03od6Q00?o08L40ol0KS<3
o`1EB`?o02ho1?l04bd3o`0780?o008J0ol00aX3o`088P?o01Pa0ol0>dD3o`1OA0?o07`L0olZVP03
ohbg00?odJ@01?oVHP03ooDZ00?oo@`00ool4003oo8e00?ohW400oo;]@03ofn_00?o4Y400ol0LRd3
o`1EB`?o02Xm1?l03bT3o`057@?o008I0ol011d3o`0>:0?o02Dj0ol0DDd3o`1[=P?o08P30om:Y003
ojbo00CoeYL00ooXF`03ooD[00?oo0h00oom2P03ooPO00?okTH00ooON@03olf_00?oU;T00om5X`03
o`N<00Co07LU0ol0HT43o`1@CP?o03100ol06c<3o`0>:0?o00LQ0ol011`6o`026@?o00<K0ol01Ah4
o`088P?o00dW0ol04bd3o`0K<`?o02<h0ol0;Ch3o`0f@`?o03i70ol0AT/3o`1<C@?o04m>0ol0D4h4
o`1?CP?o04i>0ol0B4/3o`10B0?o03M30ol0;Ch3o`0S>0?o01Tb0ol04B/3o`0;9@?o00LP1oooool1
o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0H4<3o`1GBP?o04m>0ol0@4P3o`0d
@P?o02/m0ol093T3o`0O=@?o01/c0ol06C87o`0H<@?o01Ta0ol06c<3o`0N=@?o028h0ol0:3`3o`0a
@0?o03e60ol0C4d3o`1FB`?o05m40ol0JSP4o`1f9P?o08@<0olETP03od6Q00?oMK400onb`003olnZ
00?ogH400ooYF003oo<c00?onQL00oom2@04ood;00?on2000oo^A@03on5e00?ocj/00onF^@03od6Q
00?o08L40ol0KS<3o`1EB`?o02ho1?l04bd3o`0780?o008J0ol00aX3o`088P?o01Pa0ol0>dD3o`1O
A0?o07`L0olZVP03ohbg00?odJ@01?oVHP03ooDZ00?oo@`00ool4003oo8e00?ohW400oo;]@03ofn_
00?o4Y400ol0LRd3o`1EB`?o02Xm1?l03bT3o`057@?o008I0ol011d3o`0>:0?o02Dj0ol0DDd3o`1[
=P?o08P30om:Y003ojbo00CoeYL00ooXF`03ooD[00?oo0h00oom2P03ooPO00?okTH00ooON@03olf_
00?oU;T00om5X`03o`N<00Co07LU0ol0HT43o`1@CP?o03100ol06c<3o`0>:0?o00LQ0ol011`6o`02
6@?o00<K0ol01Ah4o`088P?o00dW0ol04bd3o`0K<`?o02<h0ol0;Ch3o`0f@`?o03i70ol0AT/3o`1<
C@?o04m>0ol0D4h4o`1?CP?o04i>0ol0B4/3o`10B0?o03M30ol0;Ch3o`0S>0?o01Tb0ol04B/3o`0;
9@?o00LP1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0H4<3o`1GBP?o
04m>0ol0@4P3o`0d@P?o02/m0ol093T3o`0O=@?o01/c0ol06C87o`0H<@?o01Ta0ol06c<3o`0N=@?o
028h0ol0:3`3o`0a@0?o03e60ol0C4d3o`1FB`?o05m40ol0JSP4o`1f9P?o08@<0olETP03od6Q00?o
MK400onb`003olnZ00?ogH400ooYF003oo<c00?onQL00oom2@04ood;00?on2000oo^A@03on5e00?o
cj/00onF^@03od6Q00?o08L40ol0KS<3o`1EB`?o02ho1?l04bd3o`0780?o008J0ol00aX3o`088P?o
01Pa0ol0>dD3o`1OA0?o07`L0olZVP03ohbg00?odJ@01?oVHP03ooDZ00?oo@`00ool4003oo8e00?o
hW400oo;]@03ofn_00?o4Y400ol0LRd3o`1EB`?o02Xm1?l03bT3o`057@?o008I0ol011d3o`0>:0?o
02Dj0ol0DDd3o`1[=P?o08P30om:Y003ojbo00CoeYL00ooXF`03ooD[00?oo0h00oom2P03ooPO00?o
kTH00ooON@03olf_00?oU;T00om5X`03o`N<00Co07LU0ol0HT43o`1@CP?o03100ol06c<3o`0>:0?o
00LQ0ol011`6o`026@?o00<K0ol01Ah4o`088P?o00dW0ol04bd3o`0K<`?o02<h0ol0;Ch3o`0f@`?o
03i70ol0AT/3o`1<C@?o04m>0ol0D4h4o`1?CP?o04i>0ol0B4/3o`10B0?o03M30ol0;Ch3o`0S>0?o
01Tb0ol04B/3o`0;9@?o00LP1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo
0ol0FDP3o`1AC@?o04990ol0=D83o`0Z?@?o028h0ol073@3o`0H<@?o01D_0ol052d7o`0C;@?o01@]
0ol05Bl3o`0H<@?o01`d0ol08SL3o`0Y?0?o03A20ol0@TT3o`1AC@?o05Y80ol0ICh4o`1a;P?o07lF
0ol9S@03oc:M00?oIZ`00onR_003ol^c00?ofXX00ooWH@03oo4j00?onA`01oom2P03ooTL00?ol3l0
0ooSK`03om6T00?oX;`00om9Y003o`6:00?o070`0ol0EdX3o`0a@@Co01D^0ol01b46o`036P?o00PQ
0ol05c03o`0iA0?o05i50ol0NQl3obNI00?oRKH00oo@YP04onIS00?omB/00ool3003oo`@00?olcD0
0ooRL@03ol^e00?oKjl00olAT003o`1b;@?o05E;0ol0:C`4o`0?:@?o00DM0ol00QT3o`047@?o00hY
0ol09c/3o`1BC@?o06dd0ol0RP03oe2V00?o/l001?oGTP03onUG00?omRL00ool3@03ood;00?omb80
0oo/C003omf000?obkH00on8]P03oc^O00?o08T11?l0Lb/3o`1OA0?o04Y=0ol0:cd3o`0G<0?o00`V
0ol01Ql3o`036`?o008I0ol00QX3o`0470?o00HP1?l02R@3o`0@:P?o01L`0ol083H3o`0Z?@?o03E2
0ol0?dP3o`19C0?o051>0ol0Dd`3o`1EB`?o05I;1?l0ED/3o`1DC0?o055=0ol0CDh3o`13B@?o03M4
0ol0;3d3o`0P=P?o01L`0ol03bT3o`098`Oooooo0Ol00001ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`?o05U80ol0DDd3o`12B@?o03E20ol0:Sd3o`0R>0?o01`d0ol06343o`0E;`?o01@]1ol0
4bd3o`0D;@?o01D_0ol06343o`0L=0?o028g0ol0:C`3o`0d@P?o04990ol0DDd3o`1JB0?o06Dn1?l0
LBh3o`1o5P?o2Hd00olbW@03ofJ/00?oX[`00oo;/`03omZ:00?oif400ooa>P03ooTL00Ooo@X00ooi
7003oo0o00?ohfl00ooAY003oj2l00?oBJ@00ol1RP03o`1`<0?o05M:0ol0<D44o`0E;P?o00LQ1_l0
0aX3o`088@?o01L`0ol0>D@3o`1NA@?o07XO0olWV@03ohVf00?od:H01?oVH`03ooD[00?oo0`00ool
4003oo<e00?ohW400oo;]@03ofn_00?o4I000ol0LRd3o`1EB`?o02Tl1?l03bT3o`057@?o008I0ol0
11d3o`0>:@?o02Lk0ol0DTd3o`1]=0?o08X00om@YP03ok?000Coei800ooYE`03ooHW00?oo0d00oom
2`03ooLR00?ok4`00ooMP003ol^f00?oR;H00olkW`03o`290@Co07<[0ol0Gd@3o`1:C@?o02/m0ol0
5c03o`0<9P?o00HO0ol00a/3o`026@?o008J0ol011`3o`0680Co00XT0ol042X3o`0G<0?o020f0ol0
:Sd3o`0e@P?o03m80ol0BD`3o`1@CP?o05=<0ol0ED/3o`1FB`Co05E;0ol0E4`3o`1AC@?o04e>0ol0
@dT3o`0gA0?o02`m0ol083H3o`0G<0?o00lY0ol02B<7ooooo`7o00000Oooool001gooooo00?o0000
ooooooooool01Oooool3o`1IB0?o055=0ol0@TT3o`0e@P?o02Xm0ol08SP3o`0L=0?o01Pa0ol05Bl3
o`0D;@Oo01<]0ol052d3o`0E;`?o01Pa0ol073@3o`0R=`?o02Tl0ol0=483o`12B@?o055=0ol0FTP3
o`1U?PCo074^0ol0OaH3o`V=00?o<Yd00omV[003oj:l00?obk<00ooJRP03onMQ00?olCX00ooi7007
ood:00?onA`00oo`?`03on=_00?odJ@00onP_003odVT00?o0HX00ol0L303o`1GBP?o03511?l05Bh3
o`078@Ko00<J0ol02243o`0G<0?o03U40ol0GTD3o`1j7`?o9iT00on9]P03om2V00CoiV<00ooe:`03
oo`<00?oo1000ooc=@03on9a00?obkD00om_[`03oa6@00?o078]0ol0ED/3o`0Y?0Co00lY0ol01Ad3
o`026@?o00@M0ol03RT3o`0W>`?o059=0ol0KC@3o`2:00?oD:H00onc`004omNB00?ojEL00oof9`03
oo`=00?oo@/00oog8P03ona<00?ogH000oo;]P03ohRf00?o>il00ol0R@44o`1c:`?o05m40ol0BTd3
o`0[?@?o01L`0ol032H3o`067`?o00<K0ol00QT3o`026P?o00@L0ol01R04o`0:90?o010Z0ol05c03
o`0P=P?o02Xm0ol0=D83o`0oB0?o04U<0ol0D4h3o`1CC0?o05E;0ol0ET/4o`1EB`?o05A<0ol0DDd3
o`1=CP?o04=90ol0=d@3o`0/?@?o020f0ol05c03o`0?:@?o00TS1oooool1o`00007ooooo000Moooo
o`03o`000?oooooooooo00Gooooo0ol0E4`3o`18B`?o03Q40ol0;3d3o`0S>0?o01`c0ol05c03o`0C
;@?o014[0ol042X7o`0?:@?o010Z0ol04B/3o`0D;@?o01L`0ol073@3o`0S>0?o02`n0ol0>DD3o`1;
C@?o05I;0ol0HD84o`1]=0?o07XO0ol0R@43obJH00?oF:P00onC^003olRk00?oei<00ooTJ003oo10
00?on2000oom3004ood900?onQP00ooa>P03onAX00?odih00onZ_P03oe6V00?o1hd00ol0LR`3o`1I
B@?o03A21?l05Rl3o`088@?o00<J0ol00QX3o`078@?o01H_0ol0=d<3o`1MAP?o07TP0olTV003ohJe
00?od:P01?oVI003ooD/00?oo0d00ool4003oo<e00?ohW400oo;]@03ofj_00?o49000ol0LBh3o`1D
C0?o02Tl1?l03RT3o`047@?o008I0ol01Ad3o`0?:@?o02Tl0ol0Dd`3o`1^<P?o18/00omFZ003ok[2
00CofHh00oo[D`03ooLT00?oo@`00ool3@03ooHV00?oje400ooKQP03olRl00?oOK<00olbW003o`26
20Co070`0ol0G4L3o`14BP?o02Hj0ol052h3o`0:90?o00DN0ol00aX3o`026@?o00<J0ol011d3o`08
8@Co00`W0ol04bd3o`0L<`?o02Hj0ol0<D03o`0mA`?o04U<0ol0DDd3o`1EB`?o05Q90ol0FTP7o`1K
A`?o05Y80ol0EdX3o`1CC0?o04m>0ol0@dT3o`0e@`?o02Pk0ol073@3o`0C;@?o00`V1oooool1o`00
007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0E4`3o`18B`?o03Q40ol0;3d3o`0S>0?o
01`c0ol05c03o`0C;@?o014[0ol042X7o`0?:@?o010Z0ol04B/3o`0D;@?o01L`0ol073@3o`0S>0?o
02`n0ol0>DD3o`1;C@?o05I;0ol0HD84o`1]=0?o07XO0ol0R@43obJH00?oF:P00onC^003olRk00?o
ei<00ooTJ003oo1000?on2000oom3004ood900?onQP00ooa>P03onAX00?odih00onZ_P03oe6V00?o
1hd00ol0LR`3o`1IB@?o03A21?l05Rl3o`088@?o00<J0ol00QX3o`078@?o01H_0ol0=d<3o`1MAP?o
07TP0olTV003ohJe00?od:P01?oVI003ooD/00?oo0d00ool4003oo<e00?ohW400oo;]@03ofj_00?o
49000ol0LBh3o`1DC0?o02Tl1?l03RT3o`047@?o008I0ol01Ad3o`0?:@?o02Tl0ol0Dd`3o`1^<P?o
18/00omFZ003ok[200CofHh00oo[D`03ooLT00?oo@`00ool3@03ooHV00?oje400ooKQP03olRl00?o
OK<00olbW003o`2620Co070`0ol0G4L3o`14BP?o02Hj0ol052h3o`0:90?o00DN0ol00aX3o`026@?o
00<J0ol011d3o`088@Co00`W0ol04bd3o`0L<`?o02Hj0ol0<D03o`0mA`?o04U<0ol0DDd3o`1EB`?o
05Q90ol0FTP7o`1KA`?o05Y80ol0EdX3o`1CC0?o04m>0ol0@dT3o`0e@`?o02Pk0ol073@3o`0C;@?o
00`V1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0E4`3o`18B`?o03Q4
0ol0;3d3o`0S>0?o01`c0ol05c03o`0C;@?o014[0ol042X7o`0?:@?o010Z0ol04B/3o`0D;@?o01L`
0ol073@3o`0S>0?o02`n0ol0>DD3o`1;C@?o05I;0ol0HD84o`1]=0?o07XO0ol0R@43obJH00?oF:P0
0onC^003olRk00?oei<00ooTJ003oo1000?on2000oom3004ood900?onQP00ooa>P03onAX00?odih0
0onZ_P03oe6V00?o1hd00ol0LR`3o`1IB@?o03A21?l05Rl3o`088@?o00<J0ol00QX3o`078@?o01H_
0ol0=d<3o`1MAP?o07TP0olTV003ohJe00?od:P01?oVI003ooD/00?oo0d00ool4003oo<e00?ohW40
0oo;]@03ofj_00?o49000ol0LBh3o`1DC0?o02Tl1?l03RT3o`047@?o008I0ol01Ad3o`0?:@?o02Tl
0ol0Dd`3o`1^<P?o18/00omFZ003ok[200CofHh00oo[D`03ooLT00?oo@`00ool3@03ooHV00?oje40
0ooKQP03olRl00?oOK<00olbW003o`2620Co070`0ol0G4L3o`14BP?o02Hj0ol052h3o`0:90?o00DN
0ol00aX3o`026@?o00<J0ol011d3o`088@Co00`W0ol04bd3o`0L<`?o02Hj0ol0<D03o`0mA`?o04U<
0ol0DDd3o`1EB`?o05Q90ol0FTP7o`1KA`?o05Y80ol0EdX3o`1CC0?o04m>0ol0@dT3o`0e@`?o02Pk
0ol073@3o`0C;@?o00`V1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0
Cdh3o`0mA`?o02lo0ol093T3o`0M=0?o01L`0ol04b`3o`0@:P?o00hX0ol03BL7o`0<9`?o00dW0ol0
3RT3o`0@:`?o01@]0ol06343o`0N=@?o02Lj0ol0<T43o`12B@?o059=0ol0GDH4o`1Y>@?o07HV0ol0
Q@X3oa^D00?oC:D00on6]@03olG300?oe9/00ooRL003oni600?omb@00ool3P04ood800?onQH00oob
=@03onIS00?oeIT00onc`003oeVX00?o38l00ol0M2T3o`1KB0?o03M41?l05c03o`088P?o00<J0ol0
0QX3o`0780?o01D^0ol0=D83o`1LA`?o07PR0olRU`03oh>d00?ocjT01?oUIP03ooD/00?oo0d00ool
4003oo<d00?ohW400oo;]P03ofj^00?o3i000ol0LBh3o`1DC0?o02Pk1?l03RP3o`047@?o008I0ol0
1Ah3o`0@:P?o02Xl0ol0E4`3o`1`<0?o1hd00omKZ@03ol3300CofXX00oo/C`03ooLR00?oo@/00ool
3P03ooHY00?ojUH00ooIS003olK100?oM;000olYV@03o`233PCo06dd0ol0FDT3o`0nA`?o02<h0ol0
4R`3o`098`?o00@M0ol00QX3o`026@?o00<K0ol01Ah3o`098`Co00lY0ol05Rl3o`0P=P?o02/m0ol0
>4@3o`16BP?o051>0ol0ED/3o`1JB0?o05e60ol0Gd@7o`1P@`?o05m40ol0G4H3o`1IB@?o05A<0ol0
CTh3o`0oB0?o03100ol08cP3o`0H<0?o00lY1oooool1o`00007ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo0ol0Cdh3o`0mA`?o02lo0ol093T3o`0M=0?o01L`0ol04b`3o`0@:P?o00hX0ol03BL7
o`0<9`?o00dW0ol03RT3o`0@:`?o01@]0ol06343o`0N=@?o02Lj0ol0<T43o`12B@?o059=0ol0GDH4
o`1Y>@?o07HV0ol0Q@X3oa^D00?oC:D00on6]@03olG300?oe9/00ooRL003oni600?omb@00ool3P04
ood800?onQH00oob=@03onIS00?oeIT00onc`003oeVX00?o38l00ol0M2T3o`1KB0?o03M41?l05c03
o`088P?o00<J0ol00QX3o`0780?o01D^0ol0=D83o`1LA`?o07PR0olRU`03oh>d00?ocjT01?oUIP03
ooD/00?oo0d00ool4003oo<d00?ohW400oo;]P03ofj^00?o3i000ol0LBh3o`1DC0?o02Pk1?l03RP3
o`047@?o008I0ol01Ah3o`0@:P?o02Xl0ol0E4`3o`1`<0?o1hd00omKZ@03ol3300CofXX00oo/C`03
ooLR00?oo@/00ool3P03ooHY00?ojUH00ooIS003olK100?oM;000olYV@03o`233PCo06dd0ol0FDT3
o`0nA`?o02<h0ol04R`3o`098`?o00@M0ol00QX3o`026@?o00<K0ol01Ah3o`098`Co00lY0ol05Rl3
o`0P=P?o02/m0ol0>4@3o`16BP?o051>0ol0ED/3o`1JB0?o05e60ol0Gd@7o`1P@`?o05m40ol0G4H3
o`1IB@?o05A<0ol0CTh3o`0oB0?o03100ol08cP3o`0H<0?o00lY1oooool1o`00007ooooo000Moooo
o`;o00001_ooool3o`1?CP?o03e70ol0;cl3o`0T>@?o01dd0ol05c03o`0C;0?o010Z0ol03RP3o`0=
9`Oo00`W0ol03BL3o`0>:@?o010[0ol052d3o`0H<@?o01he0ol09cX3o`0b@@?o04990ol0DTd3o`1M
APCo06Ti0ol0MRH3o`252P?o6i@00om<Y@03ohJe00?oaL<00ooDV`03on9`00?okTH00oog9003oo`>
00Coo@P00ooj5P03oo8e00?oiV<00ooEV@03ok?000?oFJP00ol<S`03o`1d:@?o05]80ol0=d@4o`0G
<0?o00PR0ol00aX3o`026P?o00LP0ol05Bh3o`0e@P?o05a70ol0N283ob:G00?oPk@00oo?Z@04onEV
00?omB`00ool3@03oo`@00?olc@00ooRL@03ol^f00?oKZh00ol?T003o`1a;P?o05A<0ol0:3/4o`0>
:0?o00@M0ol00QT3o`057P?o010Z0ol0:S`3o`1DC0?o070`0ol7S@03oe^Y00?o`<<01?oJRP03ona?
00?omb800oom2`03oo`>00?omRT00ooZEP03omV<00?oa/400omd/003obVI00?o08<>1?l0KC@3o`1I
B@?o03i70ol08cP3o`0B;0?o00TS0ol011d3o`026P?o008I0ol00a/3o`057P?o00TS1?l03bT3o`0F
;`?o020f0ol0:cd3o`0hA0?o04I:0ol0D4h3o`1EB`?o05Y80ol0GDH3o`1OA0Oo06130ol0Gd@3o`1L
AP?o05U90ol0E4`3o`1>CP?o03m80ol0<403o`0S>0?o01P`0ol03bT6ooooo`;o00000Oooool001go
oooo00?o0000ooooooooool01Oooool3o`16B`?o03E20ol0:3/3o`0O=@?o01Pa0ol04bd3o`0?:@?o
00dW0ol02bH3o`0;9@Oo00XT0ol02bD3o`0<9P?o00hX0ol04B/3o`0E;P?o01Xb0ol08SP3o`0]?P?o
03a60ol0Cdh3o`1IB0Co06Dn0ol0Lb`3o`214@?o4Y400om1X@03ogZb00?o_<800ooBX@03on1f00?o
k4`00oof:003oo`@00Coo@P00ook4`03oo<a00?oieh00ooGU003ok_200?oGjX00olAT@03o`1f9P?o
05a60ol0>TD4o`0I<@?o00TS0ol00a/3o`026P?o00LP0ol052h3o`0c@P?o05]70ol0N2@3ob2F00?o
PK@00oo?ZP04onEW00?omBd00ool3@03oo`@00?olc@00ooRL@03olZf00?oKJh00ol?T003o`1a;`?o
05A<0ol09c/4o`0>:0?o00@M0ol00QT3o`057P?o010Z0ol0:cd3o`1EB`?o074^0ol;SP03oenZ00?o
aL@01?oKQ`03ona<00?on1l00oom2P03oo`?00?omB`00ooXF`03omRA00?o`/@00om[[P03ob:G00?o
080D1?l0JSP3o`1FB`?o03Y50ol083H3o`0@:P?o00PR0ol011`6o`026@?o00<K0ol01Ql3o`0:90Co
014[0ol06C83o`0T>@?o03500ol0?dL3o`1>CP?o05A<0ol0FDP3o`1NA@?o06520ol0Hd07o`1U?P?o
06@o0ol0HD83o`1MA@?o05U90ol0Dd`3o`19C0?o03Q40ol0:C`3o`0L=0?o018/1oooool1o`00007o
oooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0AT/3o`0e@P?o02Pk0ol07cD3o`0H<@?o01<]
0ol03bT3o`0=9`?o00/V0ol02bD7o`0:90?o00/U0ol032H3o`0>:0?o014[0ol05Bh3o`0J<P?o028h
0ol0;Ch3o`0lAP?o04m>0ol0FDP4o`1U?P?o07</0ol0PA43oa:A00?o@J400omj/P03okc200?odZ40
0ooPMP03ona<00?omRP00ool4004ood800?ona<00ooc<@03onMN00?oei@00onk`P03oenZ00?o4I40
0ol0MRH3o`1LAP?o03Y51?l06C43o`098`?o00<K0ol00QX3o`0780?o01@^0ol0<d83o`1KA`?o07PT
0olPUP03oh6d00?ocjX01?oUI`03ooD]00?oo0d00ool4003oo<d00?ohW400oo:]P03off^00?o3i00
0ol0LBl3o`1DC0?o02Lk1?l03RP3o`047@?o008I0ol01Ah3o`0@:P?o02/m0ol0ED/3o`1a;P?o2hh0
0omOZP03olG400CofhL00oo/C003ooPO00?oo@X00ool3`03ooD/00?oj5/00ooHT@03ol;400?oJjh0
0olRU`03o`2050Co06Xh0ol0ET/3o`0jA@?o020f0ol042X3o`088P?o00@L1_l00QT3o`036`?o00HO
0ol02R@4o`0A:`?o01Tb0ol093T3o`0a@0?o03m70ol0CTh3o`1DC0?o05U80ol0GTD3o`1Q@P?o06=0
1ol0ICh3o`1T?`?o06520ol0GDD3o`1IB@?o05=<0ol0BD`3o`0hA0?o02Tl0ol073@3o`0B;0Oooooo
0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o04I;0ol0=D83o`0X>`?o01le0ol0
6343o`0C;@?o00lY0ol03BL3o`0;9P?o00/U1ol02R@3o`0;9@?o00`V0ol03RP3o`0A:`?o01D^0ol0
6S83o`0R>0?o02dn0ol0?4H3o`1?CP?o05U81?l0ICh3o`1c;0?o084A0olBT@03od6Q00?oN[800onl
`P03om:Q00?oh7H00oo/C003ooHX00?oo1001?om2003oo/C00?olc400ooWGP03omND00?o^l800omO
ZP03oa6A00?o07HV0ol0G4H3o`0jA@Co01Ta0ol02B<3o`036`?o008J0ol01b03o`0D;P?o03=20ol0
FdL3o`1h90?o89H00on1]003olnZ00CoiFL00ooe;@03oo`=00?oo1000ooc=003on9a00?ob[H00om]
[P03o`n@00?o074_0ol0E4`3o`0W>`Co00hX0ol011d3o`026@?o00DN0ol042X3o`0[?@?o05E;0ol0
LBh3o`^>00?oGjX00oo5a004om^700?ok4`00ooh7`03ood:00?oo0l00ooe;003onQK00?of9400oo2
a003of^^00?o8YL00ol0P1@4o`1Z>0?o05I;0ol0>TD3o`0P=P?o010Z0ol02283o`0470Ko008I0ol0
0a/3o`067`?o00XT1?l04B/3o`0I<P?o02@i0ol0<D03o`0oA`?o04i>0ol0E4`3o`1IB0?o05i50ol0
HD83o`1S@0Oo06Dn0ol0I3l3o`1Q@P?o05e50ol0FDT3o`1CC0?o04U<0ol0>4@3o`0Y?0?o01`d0ol0
4R`7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`0nA`?o02lo0ol08cP3
o`0K<P?o01@^0ol042X3o`0=9`?o00/U0ol02R@=o`098`?o00XT0ol032H3o`0>:@?o018/0ol05c03
o`0N=@?o02Pk0ol0=T<3o`19C0?o05I:1?l0HT43o`1`<0?o07hG0ol;SP03ocRN00?oL:l00onb`003
om2W00?ogg`00oo[D@03ooD/00?ona801?om2003oo/B00?om2h00ooYFP03omR@00?o`L@00omU[003
oaJB00?o07PS0ol0GTD3o`0lAPCo01Xb0ol02B<3o`036`?o008I0ol01R03o`0C;@?o03910ol0FTP3
o`1g9@?o7YD00omo/`03olj/00CoiFP00ood;P03oo`=00?oo1000ooc=003on9a00?ob[H00om][P03
o`j?00?o070_0ol0Dd`3o`0W>`Co00hX0ol011`3o`026@?o00DN0ol04B/3o`0]?P?o05I;0ol0LRd3
o`f?00?oI:`00oo6`@04omb400?okDT00ooh7P03ood:00?oo1000ood;`03onMN00?oeYD00onj`P03
ofB/00?o79D00ol0OQP4o`1X>P?o05A<0ol0=T<3o`0M=0?o00lY0ol01b43o`0370?o008I0ol00QX3
o`0470?o00LP0ol032H4o`0C;@?o01`d0ol0:3/3o`0f@`?o04E:0ol0DDd3o`1HBP?o05e60ol0HD83
o`1U?P?o06Lk0ol0JCX4o`1Y>@?o06Pk0ol0ICh3o`1R@P?o05e60ol0EdX3o`1@CP?o04180ol0;cl3
o`0Q=`?o01H_1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0?TL3o`0_
?`?o02<h0ol06c83o`0D;P?o010Z0ol03BL3o`0;9@?o00XT3Ol02B<3o`0:90?o00`V0ol03RT3o`0B
;0?o01L`0ol07SD3o`0X>`?o03I30ol0BD`3o`1FBPCo06910ol0L303o`1n5`?o2hh00olhWP03og2_
00?o//000oo@Y`03omml00?oje400ooe;003oo/B00Coo@P00ook4P03oo@^00?ojEX00ooHT003ol74
00?oIJ`00olFTP03o`1h8`?o05i50ol0?4H4o`0J<P?o00TS0ol00a/3o`026@?o00HP0ol04bd3o`0b
@@?o05Y80ol0MbD3oajE00?oOk<00oo>[004onEX00?om2h00ool3@03oo`@00?olc@00ooRL@03olZf
00?oKJh00ol>S`03o`1`;`?o05=<0ol09c/4o`0>:0?o00@L0ol00QT3o`057P?o014[0ol0;Ch3o`1F
B`?o078]0ol=S`03ofB/00?oa/401?oLQ003one900?on1h00oom2P03oo`@00?om2l00ooWGP03omJE
00?o^/800omT[003oabE00?o07hH1?l0J3X3o`1DC0?o03I30ol07C@3o`0?:@?o00LQ0ol00a`3o`02
6@?o008J0ol011`3o`0780?o00`V1?l04bd3o`0L=0?o02Pk0ol0=T<3o`15BP?o055=0ol0F4X3o`1M
AP?o06520ol0ICh3o`1W>`?o06Tj1?l0JCT3o`1X>`?o06Dn0ol0HT83o`1MAP?o05M:0ol0D4h3o`10
B0?o02lo0ol08CL3o`0F;`Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o
03i70ol0;cl3o`0S>0?o01/b0ol052h3o`0@:P?o00dW0ol02bD3o`0:90go00TS0ol02R@3o`0<9P?o
00hY0ol04R`3o`0G<0?o01he0ol0:3/3o`0f@`?o04U<0ol0ETX4o`1R@@?o070`0ol0OQL3o`^>00?o
>9h00om`[`03ok;000?od:L00ooOO003on]A00?omB`00ook4P04ood800?ona800ood;P03onUJ00?o
f9000oo1a003ofF/00?o5Y800ol0N2<3o`1NA@?o03a61?l06S83o`098`?o00<K0ol00QT3o`0680?o
01<]0ol0<T43o`1JB0?o07LU0olNU@03ognc00?ocZ`01?oUJ003oo@^00?oo0d00ool4003oo<d00?o
hW400oo:]P03off^00?o3Xl00ol0L2l3o`1CC0?o02Lk1?l03RP3o`0470?o008I0ol01Ah3o`0A:`?o
02dn0ol0ET/3o`1b;@?o3Hl00omT[003olK100Cog8@00oo]B@03ooPN00?oo@X00ool4003oo@_00?o
ieh00ooFU@03ok[200?oI:`00olLU@03o`1n60Co06Pj0ol0E4`3o`0f@`?o01dd0ol03bT3o`078@?o
00<L0ol00QT3o`026P?o00@L0ol01b03o`0<9PCo01<]0ol073@3o`0X>`?o03I30ol0ADX3o`1AC@?o
05Q:0ol0GDH3o`1Q@P?o06Dn0ol0Ic/3o`1Y>PCo06Ti0ol0J3/3o`1U?P?o06920ol0GDH3o`1GBP?o
051>0ol0@4P3o`0_?`?o024g0ol05Rl7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool0
1Oooool3o`0hA0?o02Xl0ol07cH3o`0G<0?o018/0ol03RP3o`0;9@?o00TS0ol02283o`088@?o00LQ
1?l02243o`088P?o00TS0ol02RD3o`0=9`?o010Z0ol05Bh3o`0K<`?o02Di0ol0<T43o`14BP?o05A<
1?l0H4<3o`1]=0?o07`L0ol4R`03oc6L00?oJ:d00onY_P03olj/00?ogH400ooZE@03oo@_00?ona@0
1?om2003oo`@00?omB/00ooYE`03omV<00?oaL<00omZ[P03oaZD00?o07TQ0ol0Gd@3o`0nA`Co01/c
0ol02R@3o`036`?o008I0ol01Ql3o`0C;0?o03500ol0FDP3o`1f9P?o79D00omm/`03olj]00Coi6P0
0ood;P03oo`=00?oo0l00ooc=003on9a00?ob[H00om/[P03o`j?00?o070`0ol0Dd`3o`0V>PCo00dX
0ol011`3o`026@?o00DN0ol04B/3o`0^?P?o05M:0ol0Lb/3oa2@00?oIjd00oo7_`04omf100?okTL0
0ooi7003ood900?ona800ooc<@03onIR00?oeIT00ond`@03oejZ00?o5i<00ol0O1`4o`1V?@?o059=
0ol0<d43o`0K<`?o00hX0ol01R03o`036`?o008I0ol00QX3o`047@?o00PQ0ol03BL4o`0E;P?o01lf
0ol0;3h3o`0kA@?o04]=0ol0E4`3o`1JB0?o06130ol0ICh3o`1X>P?o06/g1ol0K3D3o`1[=P?o06Ti
0ol0ICh3o`1P@`?o05]80ol0E4`3o`18B`?o03E30ol09SX3o`0I<@Oooooo0Ol00001ooooo`007Ooo
ool00ol0003oooooooooo`05ooooo`?o03Q40ol0:S`3o`0O=P?o01L`0ol04R`3o`0>:0?o00/U0ol0
2B<3o`088P?o00PQ0ol01b44o`088@?o00PR0ol02B<3o`0:9@?o00dW0ol042X3o`0E;P?o01/c0ol0
9CT3o`0b@@?o04A:0ol0E4`4o`1P@`?o06dd0ol0O1`3o`B;00?o<I`00omX[@03ojVn00?ocZ`00ooM
P@03onYE00?om2l00ook5004ood800?oo1000ooe:`03onUG00?ofH`00oo5``03ofZ^00?o6Y@00ol0
NB43o`1OA0?o03i71?l06c<3o`0:90?o00<K0ol00QT3o`067`?o01</0ol0<D03o`1IB0?o07HV0olL
U@03ogfc00?ocZd01?oTJ003oo@^00?oo0d00ool3`03oo<d00?ohW400oo:]P03ofb^00?o3Xl00ol0
L303o`1CC0?o02Hj1?l03BP3o`0470?o008I0ol01Ah3o`0A:`?o02hn0ol0EdX3o`1c:`?o49000omW
[@03olNo00CogH400oo^A`03ooTL00?oo@T00ook4P03oo<a00?oiV800ooEV@03okC100?oGZX00olG
T`03o`1l70Co06Hm0ol0DTd3o`0c@@?o01/c0ol03RP3o`0680?o00<K0ol00QT3o`026P?o00@M0ol0
2243o`0=9`Co01D^0ol07cH3o`0/?P?o03]50ol0Bdd3o`1DC0?o05Y80ol0H4<3o`1U?P?o06Pj0ol0
JcL7o`1/=@?o06/f0ol0JCT3o`1U?P?o06130ol0FdP3o`1DC0?o04Q;0ol0=D<3o`0V>P?o01Ta1ooo
ool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0>4@3o`0Z?0?o01lf0ol05c03
o`0B;0?o00hX0ol02bD3o`098`?o00PR0ol02243o`078@Co00PQ0ol02283o`098`?o00XU0ol03BL3
o`0@:P?o01D^0ol06c<3o`0U>@?o03910ol0A4X3o`1DC0Co06130ol0KC@3o`1l70?o18/00olaW003
ofR]00?oZKh00oo>[003omf100?ojUD00ood;`03oo/D00Coo@P00ool4003ooD[00?ojEL00ooIS003
olG300?oJZh00olJU003o`1i8@?o05m40ol0?TL4o`0K<`?o00XT0ol00a/3o`026@?o00HO0ol04b`3
o`0a@0?o05U80ol0MRH3oabE00?oOK<00oo>[@04onAX00?om2h00ool3@03oo`?00?olc@00ooRL@03
olZf00?oK:h00ol>S`03o`1`<0?o05=<0ol09SX4o`0=:0?o00@L0ol00QT3o`057P?o014[0ol0;Sh3
o`1GBP?o07<[0ol@T003ofN]00?oakl01?oMP@03oni700?onA`00oom2@03oo/B00?olc400ooVHP03
omFI00?o]<400omNZP03oaNC00?o07`L1?l0ISd3o`1BC@?o03=10ol06c<3o`0>:0?o00HP0ol00a/3
o`026@?o008J0ol011d3o`088@?o00dW1?l05Bh3o`0O=P?o02`n0ol0>dD3o`1;C@?o05A<0ol0FTP3
o`1P@`?o06Dn0ol0J3X3o`1[=`Oo06`e0ol0JcH3o`1Y>@?o06Dn0ol0H4<3o`1KB0?o05A<0ol0B4/3
o`0e@`?o02Hj0ol06C47ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`0c
@P?o02Hj0ol073<3o`0E;P?o010Z0ol032H3o`0:90?o00PR0ol01b4:o`0780?o00LQ0ol02283o`09
8`?o00/V0ol03RT3o`0C;0?o01Ta0ol08SL3o`0^?`?o03m80ol0DTd4o`1NA@?o06/g0ol0NB03o`29
00?o:iX00omQZ`03oj:l00?ocK000ooLQ@03onUI00?olc800ooj5@04ood900?oo0l00oof:@03onYD
00?ofXT00oo6`003ofj_00?o7ID00ol0NQl3o`1P@`?o04181?l073<3o`0:90?o00<K0ol00QT3o`06
7`?o018/0ol0<403o`1IB@?o07HW0olKU003ogbb00?ocZd01?oTJ@03oo@^00?oo0d00ool3`03oo<d
00?ohW400oo:]P03ofb^00?o3Hl00ol0L303o`1CC0?o02Hj1?l03BL3o`0470?o008I0ol01Ah3o`0A
:`?o02ho0ol0F4X3o`1d:P?o4Y400omZ[@03olRm00CogWl00oo^A@03ooTK00?oo@T00ook4`03oo<c
00?oiVD00ooDW003ojno00?oFJT00olCT@03o`1j7`Co06Dn0ol0DDd3o`0`@0?o01Tb0ol03BL3o`06
7`?o00<K0ol00QT3o`036P?o00DM0ol02283o`0>:0Co01L`0ol08SL3o`0_?`?o03m80ol0Cdh3o`1F
BP?o05e60ol0Hd03o`1W>`?o06/g0ol0KS<3o`1_<@Co070`0ol0Kc83o`1/=@?o06Pj0ol0I403o`1N
A@?o05M:0ol0CTh3o`0kA@?o02Xl0ol073@7ooooo`7o00000Oooool001gooooo00?o0000oooooooo
ool01Oooool3o`0c@P?o02Hj0ol073<3o`0E;P?o010Z0ol032H3o`0:90?o00PR0ol01b4:o`0780?o
00LQ0ol02283o`098`?o00/V0ol03RT3o`0C;0?o01Ta0ol08SL3o`0^?`?o03m80ol0DTd4o`1NA@?o
06/g0ol0NB03o`2900?o:iX00omQZ`03oj:l00?ocK000ooLQ@03onUI00?olc800ooj5@04ood900?o
o0l00oof:@03onYD00?ofXT00oo6`003ofj_00?o7ID00ol0NQl3o`1P@`?o04181?l073<3o`0:90?o
00<K0ol00QT3o`067`?o018/0ol0<403o`1IB@?o07HW0olKU003ogbb00?ocZd01?oTJ@03oo@^00?o
o0d00ool3`03oo<d00?ohW400oo:]P03ofb^00?o3Hl00ol0L303o`1CC0?o02Hj1?l03BL3o`0470?o
008I0ol01Ah3o`0A:`?o02ho0ol0F4X3o`1d:P?o4Y400omZ[@03olRm00CogWl00oo^A@03ooTK00?o
o@T00ook4`03oo<c00?oiVD00ooDW003ojno00?oFJT00olCT@03o`1j7`Co06Dn0ol0DDd3o`0`@0?o
01Tb0ol03BL3o`067`?o00<K0ol00QT3o`036P?o00DM0ol02283o`0>:0Co01L`0ol08SL3o`0_?`?o
03m80ol0Cdh3o`1FBP?o05e60ol0Hd03o`1W>`?o06/g0ol0KS<3o`1_<@Co070`0ol0Kc83o`1/=@?o
06Pj0ol0I403o`1NA@?o05M:0ol0CTh3o`0kA@?o02Xl0ol073@7ooooo`7o00000Oooool001gooooo
00?o0000ooooooooool01Oooool3o`0c@P?o02Hj0ol073<3o`0E;P?o010Z0ol032H3o`0:90?o00PR
0ol01b4:o`0780?o00LQ0ol02283o`098`?o00/V0ol03RT3o`0C;0?o01Ta0ol08SL3o`0^?`?o03m8
0ol0DTd4o`1NA@?o06/g0ol0NB03o`2900?o:iX00omQZ`03oj:l00?ocK000ooLQ@03onUI00?olc80
0ooj5@04ood900?oo0l00oof:@03onYD00?ofXT00oo6`003ofj_00?o7ID00ol0NQl3o`1P@`?o0418
1?l073<3o`0:90?o00<K0ol00QT3o`067`?o018/0ol0<403o`1IB@?o07HW0olKU003ogbb00?ocZd0
1?oTJ@03oo@^00?oo0d00ool3`03oo<d00?ohW400oo:]P03ofb^00?o3Hl00ol0L303o`1CC0?o02Hj
1?l03BL3o`0470?o008I0ol01Ah3o`0A:`?o02ho0ol0F4X3o`1d:P?o4Y400omZ[@03olRm00CogWl0
0oo^A@03ooTK00?oo@T00ook4`03oo<c00?oiVD00ooDW003ojno00?oFJT00olCT@03o`1j7`Co06Dn
0ol0DDd3o`0`@0?o01Tb0ol03BL3o`067`?o00<K0ol00QT3o`036P?o00DM0ol02283o`0>:0Co01L`
0ol08SL3o`0_?`?o03m80ol0Cdh3o`1FBP?o05e60ol0Hd03o`1W>`?o06/g0ol0KS<3o`1_<@Co070`
0ol0Kc83o`1/=@?o06Pj0ol0I403o`1NA@?o05M:0ol0CTh3o`0kA@?o02Xl0ol073@7ooooo`7o0000
0Oooool001gooooo0_l00006ooooo`?o03100ol08cP3o`0J<P?o01<]0ol03RP3o`0;9@?o00TS0ol0
1b43o`0780[o00HO0ol01R03o`078@?o00TR0ol02RD3o`0=:0?o014[0ol05c03o`0P=P?o02`m0ol0
?4H3o`1@CPCo05a70ol0JCT3o`1h8`?o08P40olVV003oebY00?oW;/00oo;]003om^800?oj5`00ooc
=003ooXG00Coo@T00ool3P03ooHW00?oje800ooKQ`03olNn00?oL[000olOUP03o`1k7@?o06520ol0
@DP4o`0L=0?o00XT0ol00a/3o`026@?o00HO0ol04R`3o`0_?`?o05Q90ol0MBL3oaZD00?oNk800oo=
[P04onAZ00?om2l00ool3P03oo`?00?olc@00ooRL@03olZf00?oK:h00ol=S`03o`1`<0?o05==0ol0
9SX4o`0=9`?o00@L0ol00QT3o`057`?o018/0ol0;cl3o`1HB@?o07@Y0olDTP03ofb^00?ob;/01?oN
O@03onm300?onAX00oom2@03oo/C00?olSD00ooUI`03om>O00?oZ[h00omEZ003oa2@00?o07TQ1?l0
Hd03o`1@CP?o02ho0ol06343o`0<9P?o00HO0ol00aX3o`026@?o00<J0ol01Ah3o`098`?o00lY1?l0
6343o`0T>@?o03910ol0@dT3o`1AC@?o05Q90ol0Gd@3o`1U?P?o06Xh0ol0KC@3o`1`<0Oo078]0ol0
LBh3o`1_<P?o06/g0ol0ISd3o`1P@`?o05U90ol0DDd3o`0oB0?o02dn0ol07cD6ooooo`;o00000Ooo
ool001gooooo00?o0000ooooooooool01Oooool3o`0`@0?o02<h0ol06S83o`0C;@?o00hX0ol02bD3
o`098`?o00LQ0ol01b0:o`067`?o00HP0ol01b43o`098P?o00XU0ol03BP3o`0A:`?o01L`0ol083H3
o`0/?@?o03a60ol0D4h4o`1LA`?o06Ti0ol0N2<3o`2810?o9YP00omLZ@03oibk00?obk@00ooKR003
onQL00?olc@00ooj5`04ood900?oo0h00oof9`03on]B00?ofhL00oo7_P03og:`00?o7iH00ol0Nad3
o`1Q@P?o04581?l073@3o`0:90?o00<K0ol00QT3o`067`?o018/0ol0;cl3o`1HB@?o07DW0olJU003
og^b00?ocJh01?oTJP03oo@_00?oo0h00ool3`03oo<d00?ohW400oo:]P03ofb^00?o3Hl00ol0L303
o`1CC@?o02Hj1?l03BL3o`0470?o008I0ol01Al3o`0B;0?o02lo0ol0F4T3o`1d:@?o59800om/[P03
olRk00CogWd00oo_@`03ooTJ00?oo@T00ook4`03oo8e00?oiFL00ooCW`03ojZn00?oEJP00ol@T003
o`1i8@Co06=00ol0D4h3o`0^?`?o01Pa0ol032H3o`067`?o00<J0ol00QT3o`036P?o00DN0ol02B<3
o`0?:@Co01Pa0ol093T3o`0b@@?o04=90ol0DDd3o`1HB@?o05m40ol0ICh3o`1Z>0?o06dd0ol0L307
o`1b;@?o074^0ol0Kc83o`1[=`?o06Hm0ol0H4<3o`1IB@?o055=0ol0?dP3o`0]?P?o01le1oooool1
o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0<403o`0S>0?o01Xb0ol04bd3o`0>
:0?o00/U0ol02B<3o`078@?o00LP2_l01Ql3o`0680?o00LQ0ol02B83o`0:9@?o00dX0ol04B/3o`0G
<0?o020f0ol0;3d3o`0lAP?o051>1?l0G4L3o`1Y>@?o07PS0ol0R0@3obJH00?oG:T00onL^`03ol^d
00?ofhP00ooXG003oo<d00?onQL01?om2@03oo`>00?omRL00oo[DP03om^700?oakh00omb/003oanF
00?o07/M0ol0HD83o`11B0Co01`d0ol02R@3o`036`?o008I0ol01Ql3o`0B;0?o02lo0ol0F4T3o`1e
9`?o6Y@00omk/P03olf^00Coi6X00ood;`03oo`>00?oo0l00ooc=003on9a00?ob[H00om/[P03o`f?
00?o070`0ol0Ddd3o`0V>PCo00dW0ol011`3o`026@?o00DO0ol04R`3o`0_?`?o05Q90ol0M2T3oaBB
00?oK:h00oo8^`04omim00?okd<00ooi6P03ood900?ona<00oob=@03onEW00?odil00onZ_P03oeFX
00?o49000ol0NB44o`1S@0?o051>0ol0;Sl3o`0H<@?o00`V0ol01Ql3o`036P?o008I0ol00aX3o`05
7P?o00TS0ol03bT4o`0H<@?o02@i0ol0<T43o`13B@?o055=0ol0F4T3o`1OA0?o06Dn0ol0JSP3o`1]
=0?o070`1ol0LRd3o`1a;P?o06lb0ol0JcL3o`1V?@?o06130ol0FDT3o`1AC@?o03m80ol0;Ch3o`0O
=@Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o02dn0ol08CL3o`0H<@?o
018/0ol03BP3o`0:90?o00PR0ol01b0@o`067`?o00LP0ol02283o`0:90?o00`W0ol042X3o`0F;`?o
01he0ol0:S`3o`0jA@?o04m>1?l0FdP3o`1X>`?o07HV0ol0QPL3ob>G00?oF:P00onH^P03olZf00?o
fX/00ooWGP03oo8f00?onQP01?om2@03oo`>00?omRH00oo[D003omb500?ob;`00omd/003ob6G00?o
07`L0ol0HD83o`12B@Co01dd0ol02RD3o`036`?o008I0ol01Ql3o`0B;0?o02lo0ol0F4T3o`1e:0?o
6I@00omj/P03olf^00Coi6X00ood;`03oo`>00?oo0l00ooc=003on9a00?ob[H00om[[P03o`f?00?o
070`0ol0DTd3o`0U>PCo00dW0ol011`3o`026@?o00HO0ol04R`3o`0`@0?o05Q90ol0MBT3oaFB00?o
KZl00oo9^P04omml00?okd800ooi6@03ood900?ona@00oob=P03onAY00?odZ000onW_@03oe:W00?o
3Xl00ol0N2<4o`1R@@?o04m>0ol0;Ch3o`0G<0?o00/V0ol01Ah3o`036P?o008I0ol00aX3o`057P?o
00TS0ol042X4o`0I<P?o02Hj0ol0=483o`16BP?o059=0ol0FTP3o`1Q@`?o06Hl0ol0JcH3o`1_<@?o
078]0ol0Lb/4o`1d:P?o07<[0ol0L2l3o`1]=0?o06Pk0ol0HT43o`1KA`?o059=0ol0@dT3o`0`@0?o
024g1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0;Ch3o`0Q=`?o01Pa
0ol04R`3o`0=:0?o00XT0ol02283o`07813o00HO0ol01b03o`088P?o00XT0ol032L3o`0@:P?o01H_
0ol07SD3o`0Z?0?o03Y50ol0Cdh4o`1KB0?o06Pk0ol0MRH3o`261`?o8iL00omHZ003oiRj00?ob[H0
0ooJR`03onMN00?olSH00ooj6004ood900?oo0h00oof9P03on]@00?og8D00oo8_003ogB`00?o8IL0
0ol0O1`3o`1Q@P?o04991?l07C@3o`0:9@?o00<K0ol00QT3o`067`?o018/0ol0;cl3o`1HB@?o07DX
0olIU003ogZb00?ocJh01?oTJP03oo@_00?oo0h00ool3`03oo<d00?ohW400oo:]P03of^^00?o3Hl0
0ol0L303o`1BC@?o02Dj1?l03BL3o`0470?o008I0ol01Ql3o`0B;0?o03100ol0F4T3o`1e:@?o5I80
0om^[`03olVj00Cogg`00oo_@P03ooTI00?oo@T00ook5003oo8f00?oi6T00ooBX003ojNm00?oDZL0
0ol>S`03o`1h8`Co06910ol0Cdh3o`0]?P?o01L`0ol02bH3o`057P?o00<J0ol00QT3o`036P?o00DN
0ol02B<3o`0@:PCo01Tb0ol09SX3o`0d@P?o04I:0ol0DTd3o`1JB0?o06530ol0IS`3o`1[=P?o06la
0ol0LRd3o`1c:`Co07@Z0ol0Lb/3o`1`;`?o06dd0ol0J3/3o`1R@@?o05]70ol0DTd3o`13B@?o0310
0ol08CL7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`0]?P?o024g0ol0
6343o`0B;0?o00dX0ol02R@3o`088P?o00LP4?l01Ql3o`0780?o00PR0ol02R@3o`0<9`?o010Z0ol0
5Rl3o`0N=@?o02Xl0ol0>TD3o`1?CPCo05]80ol0J3/3o`1f9P?o08H70olSU`03oeRX00?oV;X00oo:
]P03omZ;00?oieh00oob=P03ooXH00Coo@T00ool3P03ooHV00?oje000ooLQ@03olRl00?oM;000olQ
U`03o`1l70?o06520ol0@TT4o`0M=0?o00XU0ol00a/3o`026@?o00HO0ol04R`3o`0_?`?o05Q90ol0
MBP3oaVD00?oN[800oo=[P04onAZ00?om2l00ool3P03oo`?00?olc@00ooRL@03olZf00?oJjh00ol=
S`03o`1`<0?o059=0ol09CX4o`0=9`?o00@L0ol00QT3o`067`?o018/0ol0<403o`1HB@?o07DY0olE
TP03ofj_00?obKX01?oOO003onm200?onAT00oom2@03oo/D00?olSH00ooTJ@03om:P00?oYkd00omB
Y`03o`j?00?o07PS1?l0HT43o`1?CP?o02dn0ol05c03o`0;9P?o00DN0ol00aX3o`026@?o00<J0ol0
1Ah3o`098`?o010Z1?l06C83o`0V>P?o03A20ol0ATX3o`1BC@?o05Y80ol0HD<3o`1V?0?o06/f0ol0
Kc43o`1b;@?o07<[1?l0M2X3o`1c:`?o070_0ol0KC@3o`1X>`?o06910ol0FdL3o`1BC@?o04=90ol0
<403o`0Q=`Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o02/m0ol07cH3
o`0G<0?o014[0ol03BL3o`0:90?o00PR0ol01b03o`067`[o00DN0ol01Ql3o`0680?o00PQ0ol02B<3
o`0<9P?o010Z0ol05Bl3o`0M=0?o02Pl0ol0>4@3o`1>CPCo05Y80ol0Ic`3o`1f9`?o08D80olPUP03
oeFX00?oUKT00oo:^003omV<00?oiel00oob=`03ooXH00Coo@T00ool3@03ooHU00?ok4l00ooLQ003
olRk00?oM[400olSU`03o`1l6`?o06910ol0@dT4o`0M=0?o00/U0ol00a/3o`026@?o00HO0ol04R/3
o`0^?`?o05Q90ol0MBP3oaVC00?oNK800oo=[`04onAZ00?om2l00ool3P03oo`?00?olc@00ooRL@03
olZf00?oJjh00ol=S`03o`1`<0?o059=0ol09CX4o`0=9`?o00@L0ol00QT3o`067`?o018/0ol0<403
o`1IB@?o07DX0olFTP03ofn_00?obKT01?oON`03onm100?onQT00oom2@03oo/E00?olSL00ooTJP03
om:R00?oYKd00om@YP03o`b?00?o07LT1?l0HT43o`1>CP?o02`m0ol05c03o`0;9@?o00DN0ol00aX3
o`026@?o00<K0ol01Ah3o`0:90?o010Z1?l06S83o`0W>P?o03I30ol0Ad/3o`1CC0?o05]70ol0HT83
o`1W>`?o06`e0ol0L2l3o`1c:`?o07DY1?l0MBP3o`1d:@?o078]0ol0KS<3o`1Y>@?o06=00ol0G4H3
o`1DC0?o04E:0ol0<T43o`0R>0Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05oooo
o`?o02/m0ol07cH3o`0G<0?o014[0ol03BL3o`0:90?o00PR0ol01b03o`067`[o00DN0ol01Ql3o`06
80?o00PQ0ol02B<3o`0<9P?o010Z0ol05Bl3o`0M=0?o02Pl0ol0>4@3o`1>CPCo05Y80ol0Ic`3o`1f
9`?o08D80olPUP03oeFX00?oUKT00oo:^003omV<00?oiel00oob=`03ooXH00Coo@T00ool3@03ooHU
00?ok4l00ooLQ003olRk00?oM[400olSU`03o`1l6`?o06910ol0@dT4o`0M=0?o00/U0ol00a/3o`02
6@?o00HO0ol04R/3o`0^?`?o05Q90ol0MBP3oaVC00?oNK800oo=[`04onAZ00?om2l00ool3P03oo`?
00?olc@00ooRL@03olZf00?oJjh00ol=S`03o`1`<0?o059=0ol09CX4o`0=9`?o00@L0ol00QT3o`06
7`?o018/0ol0<403o`1IB@?o07DX0olFTP03ofn_00?obKT01?oON`03onm100?onQT00oom2@03oo/E
00?olSL00ooTJP03om:R00?oYKd00om@YP03o`b?00?o07LT1?l0HT43o`1>CP?o02`m0ol05c03o`0;
9@?o00DN0ol00aX3o`026@?o00<K0ol01Ah3o`0:90?o010Z1?l06S83o`0W>P?o03I30ol0Ad/3o`1C
C0?o05]70ol0HT83o`1W>`?o06`e0ol0L2l3o`1c:`?o07DY1?l0MBP3o`1d:@?o078]0ol0KS<3o`1Y
>@?o06=00ol0G4H3o`1DC0?o04E:0ol0<T43o`0R>0Oooooo0Ol00001ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`?o02/m0ol07cH3o`0G<0?o014[0ol03BL3o`0:90?o00PR0ol01b03o`067`[o
00DN0ol01Ql3o`0680?o00PQ0ol02B<3o`0<9P?o010Z0ol05Bl3o`0M=0?o02Pl0ol0>4@3o`1>CPCo
05Y80ol0Ic`3o`1f9`?o08D80olPUP03oeFX00?oUKT00oo:^003omV<00?oiel00oob=`03ooXH00Co
o@T00ool3@03ooHU00?ok4l00ooLQ003olRk00?oM[400olSU`03o`1l6`?o06910ol0@dT4o`0M=0?o
00/U0ol00a/3o`026@?o00HO0ol04R/3o`0^?`?o05Q90ol0MBP3oaVC00?oNK800oo=[`04onAZ00?o
m2l00ool3P03oo`?00?olc@00ooRL@03olZf00?oJjh00ol=S`03o`1`<0?o059=0ol09CX4o`0=9`?o
00@L0ol00QT3o`067`?o018/0ol0<403o`1IB@?o07DX0olFTP03ofn_00?obKT01?oON`03onm100?o
nQT00oom2@03oo/E00?olSL00ooTJP03om:R00?oYKd00om@YP03o`b?00?o07LT1?l0HT43o`1>CP?o
02`m0ol05c03o`0;9@?o00DN0ol00aX3o`026@?o00<K0ol01Ah3o`0:90?o010Z1?l06S83o`0W>P?o
03I30ol0Ad/3o`1CC0?o05]70ol0HT83o`1W>`?o06`e0ol0L2l3o`1c:`?o07DY1?l0MBP3o`1d:@?o
078]0ol0KS<3o`1Y>@?o06=00ol0G4H3o`1DC0?o04E:0ol0<T43o`0R>0Oooooo0Ol00001ooooo`00
5?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool3o`0[?@?o01le0ol05Rl3o`0@:P?o00`W
0ol02B@3o`088@?o00HP0ol01Ql:o`057P?o00HO0ol01R03o`078@?o00TS0ol032H3o`0?:P?o01D^
0ol07C@3o`0X>`?o03Q40ol0CDh4o`1IB0?o06Ll0ol0MBP3o`252@?o7iH00omDY`03oi>i00?obKP0
0ooIS@03onMP00?olSL00ooj6@04ood900?oo0d00oog9@03ona>00?og8<00oo8^`03ogNa00?o8iL0
0ol0O1/3o`1R@@?o04=91?l07SD3o`0;9@?o00<K0ol00QT3o`057`?o014[0ol0;Sl3o`1HBP?o07DX
0olIT`03ogVb00?ocJl01?oTJP03oo@_00?oo0h00ool3`03oo<d00?ohW400oo:]P03of^^00?o3Hl0
0ol0Kc43o`1BC@?o02Dj1?l03BL3o`0470?o008I0ol01Ql3o`0B;0?o03100ol0FDT3o`1e:0?o5Y80
0om`[`03olVi00Cogg/00oo_@@03ooXI00?oo@T00ooj5@03oo8h00?oi6X00ooBXP03ojBm00?oCjH0
0ol;SP03o`1g90Co06520ol0CDh3o`0[?@?o01H_0ol02bD3o`057P?o00<J0ol00QT3o`036`?o00DN
0ol02R@3o`0A:`Co01/b0ol09c/3o`0g@`?o04Q<0ol0E4`3o`1KA`?o06910ol0J3X3o`1]=0?o074_
0ol0M2X3o`1e:0Co07HW0ol0MBP3o`1b;0?o06lb0ol0JSP3o`1T?`?o05e60ol0E4`3o`17B`?o03=2
0ol08cP7ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`05ooooo`?o02/m0ol07cD3o`0F;`?o010Z0ol032L3o`0990?o00PQ0ol01R03o`067`[o00DN
0ol01Ql3o`0680?o00LQ0ol02B<3o`0<9P?o00lZ0ol05Bh3o`0M=0?o02Pk0ol0>4@3o`1=CPCo05U8
0ol0Ic`3o`1e:0?o08D90olOUP03oeBW00?oTkT00oo9^003omV=00?oif000oob=`03ooXI00Coo@T0
0ool3@03ooLU00?ok4h00ooLP`03olRk00?oMk400olSU`03o`1l6`?o06910ol0@dT4o`0N=@?o00/U
0ol00a/3o`026@?o00DO0ol04B/3o`0^?`?o05Q:0ol0MBP3oaVC00?oNK800oo=[`04onAZ00?om2l0
0ool3P03oo`?00?olc@00ooRL@03olZf00?oJjh00ol=S`03o`1_<@?o059=0ol09CX4o`0=9`?o00@L
0ol00QT3o`067`?o018/0ol0<403o`1IB@?o07DX0olFTP03og2_00?obKT01?oON`03onm100?onQT0
0oom2@03ooXE00?olSP00ooTJP03om:R00?oY;d00om?YP03o`^>00?o07LT1?l0HD83o`1=CP?o02/m
0ol05Rl3o`0;9@?o00DN0ol00aX3o`026@?o00<K0ol01Ah3o`0:90?o014[1?l06c83o`0W>`?o03M3
0ol0B4`3o`1DC0?o05]70ol0HT43o`1X>P?o06dd0ol0LBl3o`1d:P?o07DX1?l0MRL3o`1e:0?o078/
0ol0Kc83o`1Z>0?o06@o0ol0GDH3o`1DC0?o04M;0ol0<d83o`0S>0Oooooo0Ol00001ooooo`004ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Gooooo0ol0:cd3o`0O=@?o01H_
0ol042X3o`0<9`?o00TT0ol02243o`0680?o00HO2_l01Ah3o`067`?o00HP0ol01b43o`098`?o00`V
0ol03bX3o`0E;P?o01dd0ol0:3/3o`0hA0?o04e>1?l0FDP3o`1W?0?o07DX0ol0Q@T3oanF00?oE:L0
0onC^@03olVh00?ofHd00ooWH003oo8g00?onQT01?om2@03oo`=00?ombD00oo/CP03omb300?ob;/0
0omg/@03ob>G00?o07`K0ol0HT43o`13B@Co01he0ol02bD3o`036`?o008I0ol01Al3o`0A:`?o02ho
0ol0F4X3o`1e:0?o6I<00omi/P03olf_00Coi6X00ood;`03oo`>00?oo0l00ooc=003on9a00?ob[H0
0om[[P03o`f?00?o06la0ol0DTd3o`0U>PCo00dW0ol011`3o`026@?o00HO0ol04R`3o`0`@0?o05U9
0ol0MBP3oaJB00?oL:l00oo9^@04ommk00?okd400ooj6@03ood900?onQD00oob>003onAZ00?odZ80
0onT_@03odnV00?o2hh00ol0Mb@4o`1Q@P?o04e>0ol0:cd3o`0F;`?o00/U0ol01Ah3o`036P?o008I
0ol00a/3o`057P?o00XT0ol04B/4o`0K<P?o02Lk0ol0=d<3o`18C0?o05A<0ol0FdL3o`1R@@?o06Pj
0ol0KC@3o`1a;`?o07@Z0ol0MBP4o`1f9`?o07DX0ol0LR`3o`1_<P?o06Xh0ol0I3l3o`1MAP?o05A<
0ol0Ad/3o`0c@P?o02<h1oooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Kooooo
0ol00005ooooo`?o02/m0ol07cD3o`0F;`?o010Z0ol032L3o`0990?o00PQ0ol01R03o`067`[o00DN
0ol01Ql3o`0680?o00LQ0ol02B<3o`0<9P?o00lZ0ol05Bh3o`0M=0?o02Pk0ol0>4@3o`1=CPCo05U8
0ol0Ic`3o`1e:0?o08D90olOUP03oeBW00?oTkT00oo9^003omV=00?oif000oob=`03ooXI00Coo@T0
0ool3@03ooLU00?ok4h00ooLP`03olRk00?oMk400olSU`03o`1l6`?o06910ol0@dT4o`0N=@?o00/U
0ol00a/3o`026@?o00DO0ol04B/3o`0^?`?o05Q:0ol0MBP3oaVC00?oNK800oo=[`04onAZ00?om2l0
0ool3P03oo`?00?olc@00ooRL@03olZf00?oJjh00ol=S`03o`1_<@?o059=0ol09CX4o`0=9`?o00@L
0ol00QT3o`067`?o018/0ol0<403o`1IB@?o07DX0olFTP03og2_00?obKT01?oON`03onm100?onQT0
0oom2@03ooXE00?olSP00ooTJP03om:R00?oY;d00om?YP03o`^>00?o07LT1?l0HD83o`1=CP?o02/m
0ol05Rl3o`0;9@?o00DN0ol00aX3o`026@?o00<K0ol01Ah3o`0:90?o014[1?l06c83o`0W>`?o03M3
0ol0B4`3o`1DC0?o05]70ol0HT43o`1X>P?o06dd0ol0LBl3o`1d:P?o07DX1?l0MRL3o`1e:0?o078/
0ol0Kc83o`1Z>0?o06@o0ol0GDH3o`1DC0?o04M;0ol0<d83o`0S>0Gooooo0ol00001ooooo`004ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Gooooo0ol0:cd3o`0O=@?o01H_
0ol042X3o`0<9`?o00TT0ol02243o`0680?o00HO2_l01Ah3o`067`?o00HP0ol01b43o`098`?o00`V
0ol03bX3o`0E;P?o01dd0ol0:3/3o`0hA0?o04e>1?l0FDP3o`1W?0?o07DX0ol0Q@T3oanF00?oE:L0
0onC^@03olVh00?ofHd00ooWH003oo8g00?onQT01?om2@03oo`=00?ombD00oo/CP03omb300?ob;/0
0omg/@03ob>G00?o07`K0ol0HT43o`13B@Co01he0ol02bD3o`036`?o008I0ol01Al3o`0A:`?o02ho
0ol0F4X3o`1e:0?o6I<00omi/P03olf_00Coi6X00ood;`03oo`>00?oo0l00ooc=003on9a00?ob[H0
0om[[P03o`f?00?o06la0ol0DTd3o`0U>PCo00dW0ol011`3o`026@?o00HO0ol04R`3o`0`@0?o05U9
0ol0MBP3oaJB00?oL:l00oo9^@04ommk00?okd400ooj6@03ood900?onQD00oob>003onAZ00?odZ80
0onT_@03odnV00?o2hh00ol0Mb@4o`1Q@P?o04e>0ol0:cd3o`0F;`?o00/U0ol01Ah3o`036P?o008I
0ol00a/3o`057P?o00XT0ol04B/4o`0K<P?o02Lk0ol0=d<3o`18C0?o05A<0ol0FdL3o`1R@@?o06Pj
0ol0KC@3o`1a;`?o07@Z0ol0MBP4o`1f9`?o07DX0ol0LR`3o`1_<P?o06Xh0ol0I3l3o`1MAP?o05A<
0ol0Ad/3o`0c@P?o02<h1oooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooooooool01Oooool3o`0[?@?o01le0ol05Rl3o`0@:P?o00`W0ol02B@3o`088@?o00HP
0ol01Ql:o`057P?o00HO0ol01R03o`078@?o00TS0ol032H3o`0?:P?o01D^0ol07C@3o`0X>`?o03Q4
0ol0CDh4o`1IB0?o06Ll0ol0MBP3o`252@?o7iH00omDY`03oi>i00?obKP00ooIS@03onMP00?olSL0
0ooj6@04ood900?oo0d00oog9@03ona>00?og8<00oo8^`03ogNa00?o8iL00ol0O1/3o`1R@@?o04=9
1?l07SD3o`0;9@?o00<K0ol00QT3o`057`?o014[0ol0;Sl3o`1HBP?o07DX0olIT`03ogVb00?ocJl0
1?oTJP03oo@_00?oo0h00ool3`03oo<d00?ohW400oo:]P03of^^00?o3Hl00ol0Kc43o`1BC@?o02Dj
1?l03BL3o`0470?o008I0ol01Ql3o`0B;0?o03100ol0FDT3o`1e:0?o5Y800om`[`03olVi00Cogg/0
0oo_@@03ooXI00?oo@T00ooj5@03oo8h00?oi6X00ooBXP03ojBm00?oCjH00ol;SP03o`1g90Co0652
0ol0CDh3o`0[?@?o01H_0ol02bD3o`057P?o00<J0ol00QT3o`036`?o00DN0ol02R@3o`0A:`Co01/b
0ol09c/3o`0g@`?o04Q<0ol0E4`3o`1KA`?o06910ol0J3X3o`1]=0?o074_0ol0M2X3o`1e:0Co07HW
0ol0MBP3o`1b;0?o06lb0ol0JSP3o`1T?`?o05e60ol0E4`3o`17B`?o03=20ol08cP7ooooo`7o0000
0Oooool001Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo0ol0:cd3o`0O=@?o01H_0ol0
42X3o`0<9`?o00TT0ol02243o`0680?o00HO2_l01Ah3o`067`?o00HP0ol01b43o`098`?o00`V0ol0
3bX3o`0E;P?o01dd0ol0:3/3o`0hA0?o04e>1?l0FDP3o`1W?0?o07DX0ol0Q@T3oanF00?oE:L00onC
^@03olVh00?ofHd00ooWH003oo8g00?onQT01?om2@03oo`=00?ombD00oo/CP03omb300?ob;/00omg
/@03ob>G00?o07`K0ol0HT43o`13B@Co01he0ol02bD3o`036`?o008I0ol01Al3o`0A:`?o02ho0ol0
F4X3o`1e:0?o6I<00omi/P03olf_00Coi6X00ood;`03oo`>00?oo0l00ooc=003on9a00?ob[H00om[
[P03o`f?00?o06la0ol0DTd3o`0U>PCo00dW0ol011`3o`026@?o00HO0ol04R`3o`0`@0?o05U90ol0
MBP3oaJB00?oL:l00oo9^@04ommk00?okd400ooj6@03ood900?onQD00oob>003onAZ00?odZ800onT
_@03odnV00?o2hh00ol0Mb@4o`1Q@P?o04e>0ol0:cd3o`0F;`?o00/U0ol01Ah3o`036P?o008I0ol0
0a/3o`057P?o00XT0ol04B/4o`0K<P?o02Lk0ol0=d<3o`18C0?o05A<0ol0FdL3o`1R@@?o06Pj0ol0
KC@3o`1a;`?o07@Z0ol0MBP4o`1f9`?o07DX0ol0LR`3o`1_<P?o06Xh0ol0I3l3o`1MAP?o05A<0ol0
Ad/3o`0c@P?o02<h1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0:cd3
o`0O=P?o01L`0ol04B/3o`0=9`?o00XT0ol02283o`0780?o00HO2_l01Ah3o`067`?o00HP0ol02243
o`098`?o00`V0ol042X3o`0E;`?o01dd0ol0:3`3o`0hA0?o04i>1?l0FTP3o`1W?0?o07HW0ol0Q@P3
ob2F00?oEJP00onE^@03olZh00?ofH`00ooWG`03oo8g00?onQP01?om2@03oo`=00?omRD00oo/C`03
omb400?ob;/00omf/@03ob>G00?o07`K0ol0HT43o`13B@Co01dd0ol02bD3o`036`?o008I0ol01Ql3
o`0B:`?o02ho0ol0F4T3o`1e:0?o6I<00omi/P03olf_00Coi6X00ood;`03oo`>00?oo0l00ooc=003
on9a00?ob[H00om[[P03o`f?00?o070`0ol0DTd3o`0U>PCo00dW0ol011`3o`026@?o00HO0ol04R`3
o`0`@0?o05U90ol0MBP3oaJB00?oKjl00oo9^@04ommk00?okd400ooj6@03ood900?onaD00oob=`03
onAZ00?odZ800onU_@03oe2V00?o38h00ol0Mb@4o`1R@@?o04i>0ol0;3d3o`0G<0?o00/U0ol01Ah3
o`036P?o008I0ol00a/3o`057P?o00XT0ol042X4o`0J<P?o02Lj0ol0=T<3o`17B`?o05=<0ol0FdL3
o`1R@P?o06Lk0ol0K3D3o`1`;`?o07<[0ol0MBT4o`1e:0?o07@Y0ol0LRd3o`1^<`?o06Ti0ol0Hd03
o`1LAP?o05A<0ol0ADX3o`0b@@?o028h1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo
00Gooooo0ol0:cd3o`0O=P?o01L`0ol04B/3o`0=9`?o00XT0ol02283o`0780?o00HO2_l01Ah3o`06
7`?o00HP0ol02243o`098`?o00`V0ol042X3o`0E;`?o01dd0ol0:3`3o`0hA0?o04i>1?l0FTP3o`1W
?0?o07HW0ol0Q@P3ob2F00?oEJP00onE^@03olZh00?ofH`00ooWG`03oo8g00?onQP01?om2@03oo`=
00?omRD00oo/C`03omb400?ob;/00omf/@03ob>G00?o07`K0ol0HT43o`13B@Co01dd0ol02bD3o`03
6`?o008I0ol01Ql3o`0B:`?o02ho0ol0F4T3o`1e:0?o6I<00omi/P03olf_00Coi6X00ood;`03oo`>
00?oo0l00ooc=003on9a00?ob[H00om[[P03o`f?00?o070`0ol0DTd3o`0U>PCo00dW0ol011`3o`02
6@?o00HO0ol04R`3o`0`@0?o05U90ol0MBP3oaJB00?oKjl00oo9^@04ommk00?okd400ooj6@03ood9
00?onaD00oob=`03onAZ00?odZ800onU_@03oe2V00?o38h00ol0Mb@4o`1R@@?o04i>0ol0;3d3o`0G
<0?o00/U0ol01Ah3o`036P?o008I0ol00a/3o`057P?o00XT0ol042X4o`0J<P?o02Lj0ol0=T<3o`17
B`?o05=<0ol0FdL3o`1R@P?o06Lk0ol0K3D3o`1`;`?o07<[0ol0MBT4o`1e:0?o07@Y0ol0LRd3o`1^
<`?o06Ti0ol0Hd03o`1LAP?o05A<0ol0ADX3o`0b@@?o028h1oooool1o`00007ooooo000Mooooo`03
o`000?oooooooooo00Gooooo0ol0:cd3o`0O=P?o01L`0ol04B/3o`0=9`?o00XT0ol02283o`0780?o
00HO2_l01Ah3o`067`?o00HP0ol02243o`098`?o00`V0ol042X3o`0E;`?o01dd0ol0:3`3o`0hA0?o
04i>1?l0FTP3o`1W?0?o07HW0ol0Q@P3ob2F00?oEJP00onE^@03olZh00?ofH`00ooWG`03oo8g00?o
nQP01?om2@03oo`=00?omRD00oo/C`03omb400?ob;/00omf/@03ob>G00?o07`K0ol0HT43o`13B@Co
01dd0ol02bD3o`036`?o008I0ol01Ql3o`0B:`?o02ho0ol0F4T3o`1e:0?o6I<00omi/P03olf_00Co
i6X00ood;`03oo`>00?oo0l00ooc=003on9a00?ob[H00om[[P03o`f?00?o070`0ol0DTd3o`0U>PCo
00dW0ol011`3o`026@?o00HO0ol04R`3o`0`@0?o05U90ol0MBP3oaJB00?oKjl00oo9^@04ommk00?o
kd400ooj6@03ood900?onaD00oob=`03onAZ00?odZ800onU_@03oe2V00?o38h00ol0Mb@4o`1R@@?o
04i>0ol0;3d3o`0G<0?o00/U0ol01Ah3o`036P?o008I0ol00a/3o`057P?o00XT0ol042X4o`0J<P?o
02Lj0ol0=T<3o`17B`?o05=<0ol0FdL3o`1R@P?o06Lk0ol0K3D3o`1`;`?o07<[0ol0MBT4o`1e:0?o
07@Y0ol0LRd3o`1^<`?o06Ti0ol0Hd03o`1LAP?o05A<0ol0ADX3o`0b@@?o028h1oooool1o`00007o
oooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0;Ch3o`0Q=`?o01Pa0ol04R`3o`0=:0?o00XT
0ol02283o`07813o00HO0ol01b03o`088P?o00XT0ol032L3o`0@:P?o01H_0ol07SD3o`0Z?0?o03Y5
0ol0Cdh4o`1KB0?o06Pk0ol0MRH3o`261`?o8iL00omHZ003oiNj00?ob[H00ooJR`03onMN00?olSH0
0ooj6004ood900?oo0h00oof9P03on]@00?og8D00oo8_003ogB`00?o8IL00ol0O1`3o`1Q@P?o0499
1?l07C@3o`0:9@?o00<K0ol00QT3o`067`?o018/0ol0;cl3o`1HB@?o07DX0olIU003ogZb00?ocJh0
1?oTJP03oo@_00?oo0h00ool3`03oo<d00?ohW400oo:]P03of^^00?o3Hl00ol0L303o`1BC@?o02Dj
1?l03BL3o`0470?o008I0ol01Ql3o`0B;0?o03100ol0F4T3o`1e:@?o5I800om^[`03olVj00Cogg`0
0oo_@P03ooTI00?oo@T00ook5003oo8g00?oi6T00ooBX003ojNm00?oDZL00ol>S`03o`1h8`Co0691
0ol0Cdh3o`0]?P?o01L`0ol02bH3o`057P?o00<J0ol00QT3o`036P?o00DN0ol02B<3o`0@:PCo01Tb
0ol09SX3o`0d@P?o04I:0ol0DTd3o`1JB0?o06530ol0IS`3o`1[=P?o06la0ol0LRd3o`1c:`Co07@Z
0ol0Lb/3o`1`;`?o06dd0ol0J3/3o`1R@@?o05]70ol0DTd3o`13B@?o03100ol08CL7ooooo`7o0000
0Oooool001gooooo00?o0000ooooooooool01Oooool3o`0]?P?o024g0ol06343o`0B;0?o00dX0ol0
2R@3o`088P?o00LP4?l01Ql3o`0780?o00PR0ol02R@3o`0<9`?o010Z0ol05Rl3o`0N=@?o02Xl0ol0
>TD3o`1?CPCo05]80ol0J3/3o`1f9P?o08H70olSU`03oeRX00?oUkX00oo:]P03omZ;00?oieh00oob
=P03ooXH00Coo@T00ool3P03ooHV00?oje000ooLQ@03olRl00?oM;000olQU`03o`1l70?o06520ol0
@TT4o`0M=0?o00XU0ol00a/3o`026@?o00HO0ol04R`3o`0_?`?o05Q90ol0MBP3oaVD00?oN[800oo=
[P04onAZ00?om2l00ool3P03oo`?00?olc@00ooRL@03olZf00?oJjh00ol=S`03o`1`<0?o059=0ol0
9CX4o`0=9`?o00@L0ol00QT3o`067`?o018/0ol0<403o`1HB@?o07DY0olETP03ofj_00?obKX01?oO
O003onm200?onAT00oom2@03oo/D00?olSL00ooTJ@03om:P00?oYkd00omBY`03o`j?00?o07PS1?l0
HT43o`1?CP?o02dn0ol05c03o`0;9P?o00DN0ol00aX3o`026@?o00<J0ol01Ah3o`098`?o010Z1?l0
6C83o`0V>P?o03A20ol0ATX3o`1BC@?o05Y80ol0HD<3o`1V?0?o06/f0ol0Kc43o`1b;@?o07<[1?l0
M2X3o`1c:`?o070_0ol0KC@3o`1X>`?o06910ol0FdL3o`1BC@?o04=90ol0<403o`0Q=`Oooooo0Ol0
0001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o02dn0ol08CL3o`0H<@?o018/0ol03BP3
o`0:90?o00PR0ol01b0@o`067`?o00LP0ol02283o`0:90?o00`W0ol042X3o`0F;`?o01he0ol0:S`3
o`0jA@?o04m>1?l0FdP3o`1X>`?o07HV0ol0QPL3ob>G00?oF:P00onG^P03olZf00?ofX/00ooWGP03
oo8f00?onQP01?om2@03oo`>00?omRH00oo[D003omb500?ob;`00omd/003ob6G00?o07`L0ol0HD83
o`12B@Co01dd0ol02RD3o`036`?o008I0ol01Ql3o`0B;0?o02lo0ol0F4T3o`1e:0?o6I@00omj/P03
olf^00Coi6X00ood;`03oo`>00?oo0l00ooc=003on9a00?ob[H00om[[P03o`f?00?o070`0ol0DTd3
o`0U>PCo00dW0ol011`3o`026@?o00HO0ol04R`3o`0`@0?o05Q90ol0MBT3oaFB00?oKZl00oo9^P04
omml00?okd800ooi6@03ood900?ona@00oob=`03onAY00?odZ000onW_@03oe:W00?o3Xl00ol0N2<4
o`1R@@?o04m>0ol0;Ch3o`0G<0?o00/V0ol01Ah3o`036P?o008I0ol00aX3o`057P?o00TS0ol042X4
o`0I<P?o02Hj0ol0=483o`16BP?o059=0ol0FTP3o`1Q@`?o06Hl0ol0JcH3o`1_<@?o078]0ol0Lb/4
o`1d:P?o07<[0ol0L2l3o`1]=0?o06Pk0ol0HT43o`1KA`?o059=0ol0@dT3o`0`@0?o024g1oooool1
o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0<403o`0S>0?o01Xb0ol04bd3o`0>
:0?o00/U0ol02B<3o`078@?o00LP2_l01Ql3o`0680?o00LQ0ol02B83o`0:9@?o00dX0ol04B/3o`0G
<0?o020f0ol0;3d3o`0lAP?o051>1?l0G4L3o`1Y>@?o07PS0ol0R0@3obJH00?oG:T00onL^`03ol^d
00?ofhP00ooXG003oo<d00?onQL01?om2@03oo`>00?omRL00oo[DP03om^700?oakh00omb/003oanF
00?o07/M0ol0HD83o`11B0Co01`d0ol02R@3o`036`?o008I0ol01Ql3o`0B;0?o02lo0ol0F4T3o`1e
9`?o6Y@00omk/P03olf^00Coi6X00ood;`03oo`>00?oo0l00ooc=003on9a00?ob[H00om[[P03o`f?
00?o070`0ol0Ddd3o`0V>PCo00dW0ol011`3o`026@?o00DO0ol04R`3o`0_?`?o05Q90ol0M2T3oaBB
00?oK:h00oo8^`04omim00?okd<00ooi6P03ood900?ona<00oob=@03onEW00?odil00onZ_P03oeFW
00?o49000ol0NB44o`1S@0?o051>0ol0;Sl3o`0H<@?o00`V0ol01Ql3o`036P?o008I0ol00aX3o`05
7P?o00TS0ol03bT4o`0H<@?o02@i0ol0<T43o`13B@?o055=0ol0F4T3o`1OA0?o06Dn0ol0JSP3o`1]
=0?o070`1ol0LRd3o`1a;P?o06lb0ol0JcL3o`1V?@?o06130ol0FDT3o`1AC@?o03m80ol0;Ch3o`0O
=@Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o03100ol08cP3o`0J<P?o
01<]0ol03RP3o`0;9@?o00TS0ol01b43o`0780[o00HO0ol01R03o`078@?o00TR0ol02RD3o`0=:0?o
014[0ol05c03o`0P=P?o02`m0ol0?4H3o`1@CPCo05a70ol0JCT3o`1h8`?o08P40olVV003oebY00?o
W;/00oo;]003om^800?oj5`00ooc=003ooXG00Coo@T00ool3P03ooHW00?oje800ooKQ`03olNn00?o
L[000olOUP03o`1k7@?o06520ol0@DP4o`0L=0?o00XT0ol00a/3o`026@?o00HO0ol04R`3o`0_?`?o
05Q90ol0MBL3oaZD00?oNk800oo=[P04onAZ00?om2l00ool3P03oo`?00?olc@00ooRL@03olZf00?o
Jjh00ol=S`03o`1`<0?o05==0ol09SX4o`0=9`?o00@L0ol00QT3o`057`?o018/0ol0;cl3o`1HB@?o
07@Y0olDTP03ofb^00?ob;/01?oNO@03onm300?onAX00oom2@03oo/C00?olSD00ooUI`03om>O00?o
Z[h00omEY`03oa2@00?o07TQ1?l0Hd03o`1@CP?o02ho0ol06343o`0<9P?o00HO0ol00aX3o`026@?o
00<J0ol01Ah3o`098`?o00lY1?l06343o`0T>@?o03910ol0@dT3o`1AC@?o05Q90ol0Gd@3o`1U?P?o
06Xh0ol0KC@3o`1`<0Oo078]0ol0LBh3o`1_<P?o06/g0ol0ISd3o`1P@`?o05U90ol0DDd3o`0oB0?o
02dn0ol07cD7ooooo`7o00000Oooool001gooooo0_l00006ooooo`?o03100ol08cP3o`0J<P?o01<]
0ol03RP3o`0;9@?o00TS0ol01b43o`0780[o00HO0ol01R03o`078@?o00TR0ol02RD3o`0=:0?o014[
0ol05c03o`0P=P?o02`m0ol0?4H3o`1@CPCo05a70ol0JCT3o`1h8`?o08P40olVV003oebY00?oW;/0
0oo;]003om^800?oj5`00ooc=003ooXG00Coo@T00ool3P03ooHW00?oje800ooKQ`03olNn00?oL[00
0olOUP03o`1k7@?o06520ol0@DP4o`0L=0?o00XT0ol00a/3o`026@?o00HO0ol04R`3o`0_?`?o05Q9
0ol0MBL3oaZD00?oNk800oo=[P04onAZ00?om2l00ool3P03oo`?00?olc@00ooRL@03olZf00?oJjh0
0ol=S`03o`1`<0?o05==0ol09SX4o`0=9`?o00@L0ol00QT3o`057`?o018/0ol0;cl3o`1HB@?o07@Y
0olDTP03ofb^00?ob;/01?oNO@03onm300?onAX00oom2@03oo/C00?olSD00ooUI`03om>O00?oZ[h0
0omEY`03oa2@00?o07TQ1?l0Hd03o`1@CP?o02ho0ol06343o`0<9P?o00HO0ol00aX3o`026@?o00<J
0ol01Ah3o`098`?o00lY1?l06343o`0T>@?o03910ol0@dT3o`1AC@?o05Q90ol0Gd@3o`1U?P?o06Xh
0ol0KC@3o`1`<0Oo078]0ol0LBh3o`1_<P?o06/g0ol0ISd3o`1P@`?o05U90ol0DDd3o`0oB0?o02dn
0ol07cD6ooooo`;o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`0c@P?o02Hj0ol0
73<3o`0E;P?o010Z0ol032H3o`0:90?o00PR0ol01b4:o`0780?o00LQ0ol02283o`098`?o00/V0ol0
3RT3o`0C;0?o01Ta0ol08SL3o`0^?`?o03m80ol0DTd4o`1NA@?o06/g0ol0NB03o`2900?o:iX00omQ
Z`03oj:l00?ocK000ooLQ@03onUI00?olc800ooj5@04ood900?oo0l00oof:@03onYD00?ofXT00oo6
`003ofj_00?o7ID00ol0NQl3o`1P@`?o04181?l073<3o`0:90?o00<K0ol00QT3o`067`?o018/0ol0
<403o`1IB@?o07HW0olKU003ogbb00?ocZd01?oTJ@03oo@_00?oo0h00ool4003oo<d00?ohW400oo:
]P03ofb^00?o3Hl00ol0L303o`1CC0?o02Hj1?l03BL3o`0470?o008I0ol01Ah3o`0A:`?o02ho0ol0
F4X3o`1d:P?o4Y400omZ[@03olRm00CogWl00oo^A@03ooTK00?oo@T00ook4`03oo<d00?oiVD00ooD
W003ojjo00?oFJT00olCT@03o`1j7`Co06Dn0ol0DDd3o`0`@0?o01Tb0ol03BL3o`067`?o00<K0ol0
0QT3o`036P?o00DM0ol02283o`0>:0Co01L`0ol08SL3o`0_?`?o03m80ol0Cdh3o`1FBP?o05e60ol0
Hd03o`1W>`?o06/g0ol0KS<3o`1_<@Co070`0ol0Kc83o`1/=@?o06Pj0ol0I403o`1NA@?o05M:0ol0
CTh3o`0kA@?o02Xl0ol073@7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3
o`0c@P?o02Hj0ol073<3o`0E;P?o010Z0ol032H3o`0:90?o00PR0ol01b4:o`0780?o00LQ0ol02283
o`098`?o00/V0ol03RT3o`0C;0?o01Ta0ol08SL3o`0^?`?o03m80ol0DTd4o`1NA@?o06/g0ol0NB03
o`2900?o:iX00omQZ`03oj:l00?ocK000ooLQ@03onUI00?olc800ooj5@04ood900?oo0l00oof:@03
onYD00?ofXT00oo6`003ofj_00?o7ID00ol0NQl3o`1P@`?o04181?l073<3o`0:90?o00<K0ol00QT3
o`067`?o018/0ol0<403o`1IB@?o07HW0olKU003ogbb00?ocZd01?oTJ@03oo@_00?oo0h00ool4003
oo<d00?ohW400oo:]P03ofb^00?o3Hl00ol0L303o`1CC0?o02Hj1?l03BL3o`0470?o008I0ol01Ah3
o`0A:`?o02ho0ol0F4X3o`1d:P?o4Y400omZ[@03olRm00CogWl00oo^A@03ooTK00?oo@T00ook4`03
oo<d00?oiVD00ooDW003ojjo00?oFJT00olCT@03o`1j7`Co06Dn0ol0DDd3o`0`@0?o01Tb0ol03BL3
o`067`?o00<K0ol00QT3o`036P?o00DM0ol02283o`0>:0Co01L`0ol08SL3o`0_?`?o03m80ol0Cdh3
o`1FBP?o05e60ol0Hd03o`1W>`?o06/g0ol0KS<3o`1_<@Co070`0ol0Kc83o`1/=@?o06Pj0ol0I403
o`1NA@?o05M:0ol0CTh3o`0kA@?o02Xl0ol073@7ooooo`7o00000Oooool001gooooo00?o0000oooo
ooooool01Oooool3o`0c@P?o02Hj0ol073<3o`0E;P?o010Z0ol032H3o`0:90?o00PR0ol01b4:o`07
80?o00LQ0ol02283o`098`?o00/V0ol03RT3o`0C;0?o01Ta0ol08SL3o`0^?`?o03m80ol0DTd4o`1N
A@?o06/g0ol0NB03o`2900?o:iX00omQZ`03oj:l00?ocK000ooLQ@03onUI00?olc800ooj5@04ood9
00?oo0l00oof:@03onYD00?ofXT00oo6`003ofj_00?o7ID00ol0NQl3o`1P@`?o04181?l073<3o`0:
90?o00<K0ol00QT3o`067`?o018/0ol0<403o`1IB@?o07HW0olKU003ogbb00?ocZd01?oTJ@03oo@_
00?oo0h00ool4003oo<d00?ohW400oo:]P03ofb^00?o3Hl00ol0L303o`1CC0?o02Hj1?l03BL3o`04
70?o008I0ol01Ah3o`0A:`?o02ho0ol0F4X3o`1d:P?o4Y400omZ[@03olRm00CogWl00oo^A@03ooTK
00?oo@T00ook4`03oo<d00?oiVD00ooDW003ojjo00?oFJT00olCT@03o`1j7`Co06Dn0ol0DDd3o`0`
@0?o01Tb0ol03BL3o`067`?o00<K0ol00QT3o`036P?o00DM0ol02283o`0>:0Co01L`0ol08SL3o`0_
?`?o03m80ol0Cdh3o`1FBP?o05e60ol0Hd03o`1W>`?o06/g0ol0KS<3o`1_<@Co070`0ol0Kc83o`1/
=@?o06Pj0ol0I403o`1NA@?o05M:0ol0CTh3o`0kA@?o02Xl0ol073@7ooooo`7o00000Oooool001go
oooo00?o0000ooooooooool01Oooool3o`0hA0?o02Xl0ol07cH3o`0G<0?o018/0ol03RP3o`0;9@?o
00TS0ol02283o`088@?o00LQ1?l02243o`088P?o00TS0ol02RD3o`0=9`?o010Z0ol05Bh3o`0K<`?o
02Di0ol0<T43o`14BP?o05A<1?l0H4<3o`1]=0?o07`L0ol4R`03oc6L00?oJ:d00onY_P03olj/00?o
gH400ooZE@03oo@_00?ona@01?om2003oo`@00?omB/00ooYE`03omV<00?oaL<00omZ[P03oaVD00?o
07TQ0ol0Gd@3o`0nA`Co01/c0ol02R@3o`036`?o008I0ol01Ql3o`0C;0?o03500ol0FDP3o`1f9P?o
79D00omm/`03olj]00Coi6T00ood;P03oo`=00?oo1000ooc=003on9a00?ob[H00om/[P03o`j?00?o
070`0ol0Dd`3o`0V>PCo00dX0ol011`3o`026@?o00DN0ol04B/3o`0^?P?o05M:0ol0Lb/3oa2@00?o
Ijd00oo7_`04omf100?okTL00ooi7003ood:00?ona800ooc<@03onIR00?oeIT00ond`@03oejZ00?o
5i<00ol0O1`4o`1V?@?o059=0ol0<d43o`0K<`?o00hX0ol01R03o`036`?o008I0ol00QX3o`047@?o
00PQ0ol03BL4o`0E;P?o01lf0ol0;3h3o`0kA@?o04]=0ol0E4`3o`1JB0?o06130ol0ICh3o`1X>P?o
06/g1ol0K3D3o`1[=P?o06Ti0ol0ICh3o`1P@`?o05]80ol0E4`3o`18B`?o03E30ol09SX3o`0I<@Oo
oooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o03Q40ol0:S`3o`0O=P?o01L`
0ol04R`3o`0>:0?o00/U0ol02B<3o`088P?o00PQ0ol01b44o`088@?o00PR0ol02B<3o`0:9@?o00dW
0ol042X3o`0E;P?o01/c0ol09CT3o`0b@@?o04A:0ol0E4`4o`1P@`?o06dd0ol0O1`3o`B;00?o<I`0
0omX[@03ojVn00?ocZ`00ooMP@03onYE00?om2l00ook5004ood800?oo1000ooe:`03onUG00?ofH`0
0oo5``03ofZ^00?o6I@00ol0NB43o`1OA0?o03i71?l06c<3o`0:90?o00<K0ol00QT3o`067`?o01</
0ol0<D03o`1IB0?o07HV0olLU@03ogfc00?ocZd01?oTJ@03oo@^00?oo0d00ool4003oo<d00?ohW40
0oo:]P03ofb^00?o3Xl00ol0L303o`1CC0?o02Hj1?l03BP3o`0470?o008I0ol01Ah3o`0A:`?o02hn
0ol0EdX3o`1c:`?o49000omW[@03olNo00CogH400oo^A`03ooTL00?oo@X00ook4P03oo<a00?oiV80
0ooEV@03okC100?oGZX00olGT`03o`1l70Co06Hm0ol0DTd3o`0c@@?o01/c0ol03RP3o`0680?o00<K
0ol00QT3o`026P?o00@M0ol02243o`0=9`Co01D^0ol07cH3o`0/?P?o03]50ol0Bdd3o`1DC0?o05Y8
0ol0H4<3o`1U?P?o06Pj0ol0JcL7o`1/=@?o06/f0ol0JCT3o`1U?P?o06130ol0FdP3o`1DC0?o04Q;
0ol0=D<3o`0V>P?o01Ta1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0
>4@3o`0Z?0?o01lf0ol05c03o`0B;0?o00hX0ol02bD3o`098`?o00PR0ol02243o`078@Co00PQ0ol0
2283o`098`?o00XU0ol03BL3o`0@:P?o01D^0ol06c<3o`0U>@?o03910ol0A4X3o`1DC0Co06130ol0
KC@3o`1l70?o18/00olaW003ofR]00?oZKh00oo>[003omf100?ojUD00ood;`03oo/D00Coo@P00ool
4003ooD[00?ojEL00ooIS003olG300?oJZh00olIU003o`1i8@?o05m40ol0?TL4o`0K<`?o00XT0ol0
0a/3o`026@?o00HO0ol04b`3o`0a@0?o05U80ol0MRH3oabE00?oOK<00oo>[@04onAY00?om2h00ool
3@03oo`@00?olc@00ooRL@03olZf00?oK:h00ol>S`03o`1`<0?o05=<0ol09SX4o`0=:0?o00@L0ol0
0QT3o`057P?o014[0ol0;Sh3o`1GBP?o07<[0ol@T003ofN]00?oakl01?oMP@03oni700?onA`00oom
2P03oo/B00?olc400ooVHP03omFI00?o]<400omNZP03oaNC00?o07`L1?l0ISd3o`1BC@?o03=10ol0
6c<3o`0>:0?o00HP0ol00a/3o`026@?o008J0ol011d3o`088@?o00dW1?l05Bh3o`0O=P?o02`n0ol0
>dD3o`1;C@?o05A<0ol0FTP3o`1P@`?o06Dn0ol0J3X3o`1[=`Oo06`e0ol0JcH3o`1Y>@?o06Dn0ol0
H4<3o`1KB0?o05A<0ol0B4/3o`0e@`?o02Hj0ol06C47ooooo`7o00000Oooool001gooooo00?o0000
ooooooooool01Oooool3o`0nA`?o02lo0ol08cP3o`0K<P?o01@^0ol042X3o`0=9`?o00/U0ol02R@=
o`098`?o00XT0ol032H3o`0>:@?o018/0ol05c03o`0N=@?o02Pk0ol0=T<3o`19C0?o05I:1?l0HT43
o`1`<0?o07hG0ol;SP03ocRN00?oL:l00ona`003om2W00?ogg`00oo[D@03ooD/00?ona801?om2003
oo/B00?om2h00ooXFP03omR@00?o`L@00omU[003oaJB00?o07PT0ol0GTD3o`0lAPCo01Xb0ol02B<3
o`036`?o008I0ol01R03o`0C;@?o03910ol0FTP3o`1g9@?o7YD00omo/`03olj/00CoiFP00ood;P03
oo`=00?oo1000ooc=003on9a00?ob[H00om/[P03o`j?00?o070_0ol0Dd`3o`0W>`Co00hX0ol011`3
o`026@?o00DN0ol04B/3o`0]?P?o05I;0ol0LRd3o`f?00?oHj`00oo6`@04omb400?okDT00ooh7P03
ood:00?oo1000ood;`03onMO00?oeYD00onj`P03ofB/00?o79D00ol0OQP4o`1X>P?o05A<0ol0=T<3
o`0M=0?o00lY0ol01b43o`0370?o008I0ol00QX3o`0470?o00LP0ol032H4o`0C;@?o01`d0ol0:3/3
o`0f@`?o04E:0ol0DDd3o`1HBP?o05e60ol0HD83o`1U?P?o06Lk0ol0JCX4o`1Y>@?o06Pk0ol0ICh3
o`1R@P?o05e60ol0EdX3o`1@CP?o04180ol0;cl3o`0Q=`?o01H_1oooool1o`00007ooooo000Moooo
o`03o`000?oooooooooo00Gooooo0ol0?TL3o`0_?`?o02<h0ol06c83o`0D;P?o010Z0ol03BL3o`0;
9@?o00XT3Ol02B<3o`0:90?o00`V0ol03RT3o`0B;0?o01L`0ol07SD3o`0X>`?o03I30ol0BD`3o`1F
BPCo06910ol0L303o`1n5`?o2hh00olhWP03og2_00?o/L000oo@Y`03omml00?oje400ooe;003oo/B
00Coo@P00ook4P03oo@^00?oj5X00ooHT003ol7400?oIJ`00olFTP03o`1h90?o05i50ol0?4H4o`0J
<P?o00TS0ol00a/3o`026@?o00HP0ol04bd3o`0b@@?o05Y80ol0MbD3oajE00?oOk<00oo>[004onEX
00?om2h00ool3@03oo`@00?olc@00ooRL@03olZf00?oK:h00ol>S`03o`1`;`?o05=<0ol09c/4o`0>
:0?o00@L0ol00QT3o`057P?o014[0ol0;Ch3o`1FB`?o078]0ol=S`03of>/00?oa/401?oLQ003one9
00?on1h00oom2P03oo`@00?om2l00ooWG`03omJE00?o^/800omT[003oabE00?o07hH1?l0J3X3o`1D
C0?o03I30ol07C@3o`0?:@?o00LQ0ol00a`3o`026@?o008J0ol011`3o`0780?o00`V1?l04bd3o`0L
=0?o02Pk0ol0=T<3o`15BP?o055=0ol0F4X3o`1MAP?o06520ol0ICh3o`1W>`?o06Tj1?l0JCT3o`1X
>`?o06Dn0ol0HT83o`1MAP?o05M:0ol0D4h3o`10B0?o02lo0ol08CL3o`0F;`Oooooo0Ol00001oooo
o`007Oooool00ol0003oooooooooo`05ooooo`?o03i70ol0;cl3o`0S>0?o01/b0ol052h3o`0@:P?o
00dW0ol02bD3o`0:90go00TS0ol02R@3o`0<9P?o00hY0ol04R`3o`0G<0?o01he0ol0:3/3o`0f@`?o
04U<0ol0ETX4o`1R@@?o070`0ol0OQL3o`^>00?o>9h00om`[`03ok7000?od:L00ooOO003on]A00?o
mB`00ook4P04ood800?ona800ood;P03onQJ00?of9000oo1a003ofF/00?o5Y800ol0N2@3o`1NA@?o
03a61?l06S83o`098`?o00<K0ol00QT3o`0680?o01<]0ol0<T43o`1JB0?o07LU0olNU@03ognc00?o
cZ`01?oUJ003oo@^00?oo0d00ool4003oo<d00?ohW400oo:]P03ofb^00?o3Xl00ol0L2l3o`1CC0?o
02Lk1?l03RP3o`0470?o008I0ol01Ah3o`0A:`?o02dn0ol0ET/3o`1b;@?o3Hl00omS[003olK100Co
g8@00oo]B@03ooPN00?oo@X00ool4003oo@_00?oiel00ooFU@03ok[200?oI:`00olLU@03o`1n60Co
06Pj0ol0E4`3o`0f@`?o01dd0ol03bT3o`078@?o00<L0ol00QT3o`026P?o00@L0ol01b03o`0<9PCo
01<]0ol073@3o`0X>`?o03I30ol0ADX3o`1AC@?o05Q:0ol0GDH3o`1Q@P?o06Dn0ol0Ic/3o`1Y>PCo
06Ti0ol0J3/3o`1U?P?o06920ol0GDH3o`1GBP?o051>0ol0@4P3o`0_?`?o024g0ol05Rl7ooooo`7o
00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`16B`?o03E20ol0:3/3o`0O=@?o01Pa
0ol04bd3o`0?:@?o00dW0ol02bH3o`0;9@Oo00XT0ol02bD3o`0<9P?o00hX0ol04B/3o`0E;P?o01Xb
0ol08SL3o`0]?P?o03a60ol0Cdh3o`1IB0Co06Dn0ol0Lb`3o`214@?o4Y400om1X@03ogZb00?o_<80
0ooBX@03on1f00?ok4`00oof:003oo`@00Coo@P00ook4`03oo<a00?oieh00ooGU003ok_200?oGjX0
0olAT@03o`1f9P?o05a60ol0>TD4o`0I<@?o00TS0ol00a/3o`026P?o00LP0ol052h3o`0c@P?o05]7
0ol0N2@3ob2F00?oPK@00oo?Z`04onEW00?om2d00ool3@03oo`@00?olc@00ooRL@03olZf00?oKJh0
0ol?T003o`1a;`?o05A<0ol09c/4o`0>:0?o00@M0ol00QT3o`057P?o010Z0ol0:cd3o`1EB`?o074^
0ol;SP03oenZ00?oaL@01?oKQ`03ona<00?on2000oom2P03oo`?00?omB`00ooXF`03omRA00?o`/@0
0om[[P03ob:G00?o080D1?l0JSP3o`1FB`?o03Y50ol083H3o`0@:P?o00PR0ol011`6o`026@?o00<K
0ol01Ql3o`0:90Co014[0ol06C83o`0T>@?o03500ol0?dL3o`1>CP?o05A<0ol0FDP3o`1NA@?o0652
0ol0Hd07o`1U?P?o06@o0ol0HD83o`1MA@?o05U90ol0Dd`3o`19C0?o03Q40ol0:C`3o`0L=0?o018/
1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0AT/3o`0e@P?o02Pk0ol0
7cD3o`0H<@?o01<]0ol03bT3o`0=9`?o00/V0ol02bD7o`0:90?o00/U0ol032H3o`0>:0?o014[0ol0
5Bh3o`0J<P?o028g0ol0;Ch3o`0lAP?o04m>0ol0FDP4o`1U?P?o07</0ol0PA43oa:A00?o@J400omj
/P03okc200?odZ400ooPMP03ona<00?omRP00ool4004ood800?ona<00ooc<@03onMN00?oei@00onk
`P03oenZ00?o4I400ol0MRH3o`1LAP?o03Y51?l06C43o`098`?o00<K0ol00QX3o`0780?o01@^0ol0
<d83o`1KA`?o07PT0olPUP03oh6d00?ocj/01?oUI`03oo@]00?oo0d00ool4003oo<d00?ohW400oo:
]P03off^00?o3i000ol0LBl3o`1DC0?o02Lk1?l03RP3o`047@?o008I0ol01Ah3o`0@:P?o02/m0ol0
ED/3o`1a;P?o2hh00omOZP03olG400CofhL00oo/C003ooPP00?oo@X00ool3`03ooD/00?oj5/00ooH
T@03ol;400?oJjh00olRU`03o`2050Co06Xh0ol0ET/3o`0jA@?o020f0ol042X3o`088P?o00@L1_l0
0QT3o`036`?o00HO0ol02R@4o`0A:`?o01Tb0ol093T3o`0a@0?o03m70ol0CTh3o`1DC0?o05U80ol0
GTD3o`1Q@P?o06=01ol0ICh3o`1T?`?o06520ol0GDD3o`1IB@?o05=<0ol0BD`3o`0hA0?o02Tl0ol0
73@3o`0B;0Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o04I;0ol0=D83
o`0X>`?o01le0ol06343o`0C;@?o00lY0ol03BL3o`0;9P?o00/U1ol02R@3o`0;9@?o00`V0ol03RP3
o`0A:`?o01D^0ol06S83o`0R=`?o02dn0ol0?4H3o`1?CP?o05U81?l0ICh3o`1c;0?o084A0olBT@03
od6Q00?oN[800onl`P03om:Q00?oh7H00oo/C003ooHX00?oo1001?om2003oo/C00?olc400ooWGP03
omND00?o^l800omOZP03oa6A00?o07HV0ol0G4H3o`0jA@Co01Ta0ol02B<3o`036`?o008J0ol01b03
o`0D;P?o03=20ol0FdL3o`1h90?o89H00on1]003oln[00CoiFL00ood;@03oo`=00?oo1000ooc=003
on9a00?ob[H00om][P03o`n@00?o074_0ol0E4`3o`0W>`Co00hX0ol011d3o`026@?o00DN0ol042X3
o`0[?@?o05E;0ol0LBh3o`^>00?oGjX00oo5a004om^700?ok4`00ooh8003ood:00?oo0l00ooe;003
onQK00?of9400oo2a003of^^00?o8YL00ol0P1@4o`1Z>0?o05I;0ol0>TD3o`0P=P?o010Z0ol02283
o`0470Ko008I0ol00a/3o`067`?o00XT1?l04B/3o`0I<P?o02@i0ol0<D03o`0oA`?o04i>0ol0E4`3
o`1IB0?o05i50ol0HD83o`1S@0Oo06Dn0ol0I3l3o`1Q@P?o05e50ol0FDT3o`1CC0?o04U<0ol0>4@3
o`0Y?0?o01`d0ol04R`7ooooo`7o00000Oooool001gooooo0_l00006ooooo`?o04m>0ol0?DL3o`0_
?`?o02@i0ol07C@3o`0G<0?o01</0ol042X3o`0>:0?o00dW1ol032L3o`0=9`?o00hY0ol042/3o`0D
;@?o01Pa0ol07SD3o`0W>P?o03910ol0@TT3o`1BC@?o05e61?l0JCT3o`1f9P?o08D:0olKU003odbU
00?oQ[D00oo5``03omBK00?ohW000oo^AP03ooLT00?oo0h01?om2003ooXF00?olSD00ooVH`03omFI
00?o/l000omHZ003o`b?00?o07@Y0ol0FdP3o`0gA0Co01L`0ol02283o`036P?o008J0ol01b03o`0E
;P?o03E20ol0G4L3o`1h8P?o8YL00on3]003olnY00CoiFH00ooe;@03oo`=00?oo1000ooc=@03on9a
00?ob[H00om][P03o`n@00?o074^0ol0E4`3o`0X>`Co00hX0ol011d3o`026@?o00DN0ol042X3o`0Z
?0?o05A<0ol0L303o`N=00?oFjT00oo0``04omZ:00?ok4l00oog8P03ood;00?oo0h00ooe:@03onYF
00?ofH`00oo6`@03ogB`00?o:IT00ol0P`h4o`1]=0?o05U90ol0?TL3o`0S>0?o018/0ol02B<3o`04
7@?o008J0ol00QT3o`036`?o00DN0ol02B<4o`0?:@?o01H_0ol083H3o`0[?@?o03Q40ol0ATX3o`1@
CP?o05E;0ol0FTP3o`1MAP?o05m41ol0H4<3o`1OA0?o05a60ol0FDT3o`1DC0?o04i>0ol0?dP3o`0`
@0?o02<h0ol06303o`0?:@Kooooo0_l00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o
04m>0ol0?DL3o`0_?`?o02@i0ol07C@3o`0G<0?o01</0ol042X3o`0>:0?o00dW1ol032L3o`0=9`?o
00hY0ol042/3o`0D;@?o01Pa0ol07SD3o`0W>P?o03910ol0@TT3o`1BC@?o05e61?l0JCT3o`1f9P?o
08D:0olKU003odbU00?oQ[D00oo5``03omBK00?ohW000oo^AP03ooLT00?oo0h01?om2003ooXF00?o
lSD00ooVH`03omFI00?o/l000omHZ003o`b?00?o07@Y0ol0FdP3o`0gA0Co01L`0ol02283o`036P?o
008J0ol01b03o`0E;P?o03E20ol0G4L3o`1h8P?o8YL00on3]003olnY00CoiFH00ooe;@03oo`=00?o
o1000ooc=@03on9a00?ob[H00om][P03o`n@00?o074^0ol0E4`3o`0X>`Co00hX0ol011d3o`026@?o
00DN0ol042X3o`0Z?0?o05A<0ol0L303o`N=00?oFjT00oo0``04omZ:00?ok4l00oog8P03ood;00?o
o0h00ooe:@03onYF00?ofH`00oo6`@03ogB`00?o:IT00ol0P`h4o`1]=0?o05U90ol0?TL3o`0S>0?o
018/0ol02B<3o`047@?o008J0ol00QT3o`036`?o00DN0ol02B<4o`0?:@?o01H_0ol083H3o`0[?@?o
03Q40ol0ATX3o`1@CP?o05E;0ol0FTP3o`1MAP?o05m41ol0H4<3o`1OA0?o05a60ol0FDT3o`1DC0?o
04i>0ol0?dP3o`0`@0?o02<h0ol06303o`0?:@Oooooo0Ol00001ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`?o04m>0ol0?DL3o`0_?`?o02@i0ol07C@3o`0G<0?o01</0ol042X3o`0>:0?o00dW
1ol032L3o`0=9`?o00hY0ol042/3o`0D;@?o01Pa0ol07SD3o`0W>P?o03910ol0@TT3o`1BC@?o05e6
1?l0JCT3o`1f9P?o08D:0olKU003odbU00?oQ[D00oo5``03omBK00?ohW000oo^AP03ooLT00?oo0h0
1?om2003ooXF00?olSD00ooVH`03omFI00?o/l000omHZ003o`b?00?o07@Y0ol0FdP3o`0gA0Co01L`
0ol02283o`036P?o008J0ol01b03o`0E;P?o03E20ol0G4L3o`1h8P?o8YL00on3]003olnY00CoiFH0
0ooe;@03oo`=00?oo1000ooc=@03on9a00?ob[H00om][P03o`n@00?o074^0ol0E4`3o`0X>`Co00hX
0ol011d3o`026@?o00DN0ol042X3o`0Z?0?o05A<0ol0L303o`N=00?oFjT00oo0``04omZ:00?ok4l0
0oog8P03ood;00?oo0h00ooe:@03onYF00?ofH`00oo6`@03ogB`00?o:IT00ol0P`h4o`1]=0?o05U9
0ol0?TL3o`0S>0?o018/0ol02B<3o`047@?o008J0ol00QT3o`036`?o00DN0ol02B<4o`0?:@?o01H_
0ol083H3o`0[?@?o03Q40ol0ATX3o`1@CP?o05E;0ol0FTP3o`1MAP?o05m41ol0H4<3o`1OA0?o05a6
0ol0FDT3o`1DC0?o04i>0ol0?dP3o`0`@0?o02<h0ol06303o`0?:@Oooooo0Ol00001ooooo`007Ooo
ool00ol0003oooooooooo`05ooooo`?o05A<0ol0B4/3o`0hA0?o02`m0ol08cP3o`0L<`?o01L`0ol0
4bd3o`0A:`?o010Z1ol03bT3o`0@:P?o014[0ol052d3o`0G<0?o01`d0ol08cP3o`0/?P?o03U50ol0
Bdd3o`1FB`?o06521?l0KC@3o`1j7`?o08T10olVV003oeRX00?oTkP00oo8^`03omNC00?oi6T00oo`
@003ooPP00?oo@`01?om2@03ooXH00?olCX00ooTJ@03om>N00?oZ[h00omAYP03o`N=00?o078/0ol0
FDT3o`0d@PCo01H_0ol02243o`036P?o008J0ol01b43o`0F;`?o03M30ol0GDH3o`1i80?o99P00on6
]@03om2X00CoiVD00ooe;003oo`=00?oo1000ooc=@03on9a00?obkD00om^[`03oa2@00?o074^0ol0
E4`3o`0Y?0Co00hY0ol011d3o`026@?o00DM0ol03bT3o`0Y?0?o05=<0ol0KS83o`B;00?oEZP00onj
`P04omV>00?oje<00oog9003ood<00?oo0d00oof9P03on]A00?ofhL00oo8_003ogfc00?o<I`00ol0
QPP4o`1`<0?o05a70ol0A4X3o`0V>P?o01@^0ol02R@3o`057P?o00<J0ol00QT3o`036P?o00@M0ol0
2244o`0<9`?o01<]0ol073<3o`0V>P?o03500ol0?DL3o`19C0?o055=0ol0ED/3o`1HB@?o05Y81ol0
FdL3o`1JB0?o05M:0ol0Dd`3o`1?CP?o04=90ol0=D<3o`0X>`?o01`d0ol04bd3o`0<9POooooo0Ol0
0001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o05A<0ol0B4/3o`0hA0?o02`m0ol08cP3
o`0L<`?o01L`0ol04bd3o`0A:`?o010Z1ol03bT3o`0@:P?o014[0ol052d3o`0G<0?o01`d0ol08cP3
o`0/?P?o03U50ol0Bdd3o`1FB`?o06521?l0KC@3o`1j7`?o08T10olVV003oeRX00?oTkP00oo8^`03
omNC00?oi6T00oo`@003ooPP00?oo@`01?om2@03ooXH00?olCX00ooTJ@03om>N00?oZ[h00omAYP03
o`N=00?o078/0ol0FDT3o`0d@PCo01H_0ol02243o`036P?o008J0ol01b43o`0F;`?o03M30ol0GDH3
o`1i80?o99P00on6]@03om2X00CoiVD00ooe;003oo`=00?oo1000ooc=@03on9a00?obkD00om^[`03
oa2@00?o074^0ol0E4`3o`0Y?0Co00hY0ol011d3o`026@?o00DM0ol03bT3o`0Y?0?o05=<0ol0KS83
o`B;00?oEZP00onj`P04omV>00?oje<00oog9003ood<00?oo0d00oof9P03on]A00?ofhL00oo8_003
ogfc00?o<I`00ol0QPP4o`1`<0?o05a70ol0A4X3o`0V>P?o01@^0ol02R@3o`057P?o00<J0ol00QT3
o`036P?o00@M0ol02244o`0<9`?o01<]0ol073<3o`0V>P?o03500ol0?DL3o`19C0?o055=0ol0ED/3
o`1HB@?o05Y81ol0FdL3o`1JB0?o05M:0ol0Dd`3o`1?CP?o04=90ol0=D<3o`0X>`?o01`d0ol04bd3
o`0<9POooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o05A<0ol0B4/3o`0h
A0?o02`m0ol08cP3o`0L<`?o01L`0ol04bd3o`0A:`?o010Z1ol03bT3o`0@:P?o014[0ol052d3o`0G
<0?o01`d0ol08cP3o`0/?P?o03U50ol0Bdd3o`1FB`?o06521?l0KC@3o`1j7`?o08T10olVV003oeRX
00?oTkP00oo8^`03omNC00?oi6T00oo`@003ooPP00?oo@`01?om2@03ooXH00?olCX00ooTJ@03om>N
00?oZ[h00omAYP03o`N=00?o078/0ol0FDT3o`0d@PCo01H_0ol02243o`036P?o008J0ol01b43o`0F
;`?o03M30ol0GDH3o`1i80?o99P00on6]@03om2X00CoiVD00ooe;003oo`=00?oo1000ooc=@03on9a
00?obkD00om^[`03oa2@00?o074^0ol0E4`3o`0Y?0Co00hY0ol011d3o`026@?o00DM0ol03bT3o`0Y
?0?o05=<0ol0KS83o`B;00?oEZP00onj`P04omV>00?oje<00oog9003ood<00?oo0d00oof9P03on]A
00?ofhL00oo8_003ogfc00?o<I`00ol0QPP4o`1`<0?o05a70ol0A4X3o`0V>P?o01@^0ol02R@3o`05
7P?o00<J0ol00QT3o`036P?o00@M0ol02244o`0<9`?o01<]0ol073<3o`0V>P?o03500ol0?DL3o`19
C0?o055=0ol0ED/3o`1HB@?o05Y81ol0FdL3o`1JB0?o05M:0ol0Dd`3o`1?CP?o04=90ol0=D<3o`0X
>`?o01`d0ol04bd3o`0<9POooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o
05U80ol0DDd3o`12B@?o03E20ol0:Sd3o`0R>0?o01`d0ol06343o`0E;`?o01@]1ol04bd3o`0D;@?o
01D_0ol06343o`0L=0?o028g0ol0:C`3o`0d@P?o04990ol0DDd3o`1JB0?o06Dn1?l0LBh3o`1o5P?o
2Hd00olbW@03ofJ/00?oXK`00oo;/`03omZ;00?oif400ooa>P03ooTL00Ooo@X00ooi7003oo0o00?o
hfl00ooAY003oj2l00?oBJ@00ol1RP03o`1`<0?o05M:0ol0<D44o`0E;P?o00LQ1_l00aX3o`088@?o
01L`0ol0>4@3o`1NA@?o07XO0olWV@03ohVf00?od:H01?oVH`03ooD[00?oo0d00ool4003oo8e00?o
hW400oo;]@03ofn_00?o4I000ol0LRd3o`1EB`?o02Tl1?l03bT3o`057@?o008I0ol011d3o`0>:@?o
02Lk0ol0DTd3o`1]=0?o08X00om@YP03ok?000Coei800ooYE`03ooHW00?oo0d00oom2`03ooLR00?o
k4`00ooMP003ol^f00?oR;H00olkW`03o`290@Co07<[0ol0Gd@3o`1:C@?o02/m0ol05c03o`0<9P?o
00HO0ol00a/3o`026@?o008J0ol011`3o`0680Co00XT0ol042X3o`0G<0?o020f0ol0:Sd3o`0e@P?o
03m80ol0BD`3o`1@CP?o05=<0ol0ED/3o`1FB`Co05E;0ol0E4`3o`1AC@?o04e>0ol0@dT3o`0gA0?o
02`m0ol083H3o`0G<0?o00lY0ol02B<7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool0
1Oooool3o`1IB0?o055=0ol0@TT3o`0e@P?o02Xm0ol08SP3o`0L=0?o01Pa0ol05Bl3o`0D;@Oo01<]
0ol052d3o`0E;`?o01Pa0ol073@3o`0R=`?o02Tl0ol0=483o`12B@?o055=0ol0FTP3o`1U?PCo074^
0ol0OaH3o`V=00?o<Yd00omV[003oj6l00?obk<00ooJR`03onMQ00?olCX00ooi7007ood:00?onA`0
0oo`?`03on=_00?odJ@00onP_003odVT00?o0HX00ol0L303o`1GBP?o03511?l05Bh3o`078@Ko00<J
0ol02243o`0G<0?o03Q40ol0GTD3o`1j7`?o9iT00on9]P03om2V00CoiV<00ooe:`03oo`=00?oo100
0oob=@03on9a00?obkD00om_[`03oa6@00?o078]0ol0ED/3o`0Y?0Co00lY0ol01Ad3o`026@?o00@M
0ol03RT3o`0W>`?o059=0ol0KC@3o`2:00?oD:H00onc`004omNB00?ojEL00oof9`03oo`=00?oo@/0
0oog8P03ona<00?ogH000oo;]P03ohRf00?o>il00ol0R@44o`1c:`?o05m40ol0BTd3o`0[?@?o01L`
0ol032H3o`067`?o00<K0ol00QT3o`026P?o00@L0ol01R04o`0:90?o010Z0ol05c03o`0P=P?o02Xm
0ol0=D83o`0oB0?o04U<0ol0D4h3o`1CC0?o05E;0ol0ET/4o`1EB`?o05A<0ol0DDd3o`1=CP?o04=9
0ol0=d@3o`0/?@?o020f0ol05c03o`0?:@?o00TS1oooool1o`00007ooooo000Mooooo`03o`000?oo
oooooooo00Gooooo0ol0FDP3o`1AC@?o04990ol0=D83o`0Z?@?o028h0ol073@3o`0H<@?o01D_0ol0
52d7o`0C;@?o01@]0ol05Bl3o`0H<@?o01`d0ol08SL3o`0Y?0?o03A20ol0@TT3o`1AC@?o05Y80ol0
ICh4o`1a;P?o07lF0ol9S@03oc:M00?oIZ`00onQ_003ol^c00?ofX/00ooWH@03oo4j00?onA`01oom
2P03ooTL00?ol3l00ooSK`03om6T00?oX;`00om9Y003o`6:00?o070`0ol0EdX3o`0a@@Co01D^0ol0
1b46o`036P?o00PQ0ol05c03o`0hA0?o05i50ol0NQl3obNI00?oRKH00oo@YP04onIS00?omB/00ool
3@03oo`@00?olSD00ooRL@03ol^e00?oKjl00olAT003o`1b;@?o05E;0ol0:C`4o`0?:@?o00DM0ol0
0QT3o`047@?o00hY0ol09c/3o`1BC@?o06dd0ol0RP03oe2V00?o/l001?oGTP03onUG00?omRL00ool
3@03ood;00?omb800oo/C003omf000?obkH00on8]P03oc^O00?o08T11?l0Lb/3o`1OA0?o04Y=0ol0
:cd3o`0G<0?o00`V0ol01Ql3o`036`?o008I0ol00QX3o`0470?o00HP1?l02R@3o`0@:P?o01L`0ol0
83H3o`0Z?@?o03E20ol0?dP3o`19C0?o051>0ol0Dd`3o`1EB`?o05I;1?l0ED/3o`1DC0?o055=0ol0
CDh3o`13B@?o03M40ol0;3d3o`0P=P?o01L`0ol03bT3o`098`Oooooo0Ol00001ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`?o06130ol0EdX3o`1?CP?o04180ol0=483o`0[?@?o02@i0ol07cD3
o`0K<`?o01Tb1ol06343o`0I<@?o01/c0ol07SD3o`0R>0?o02Pl0ol0<D03o`0mAP?o04a=0ol0ET/3
o`1OA0?o06Xh1?l0MRH3o`2430?o5I800om1X@03ogFa00?o//000oo?ZP03omf100?ojEP00ooc<`03
ooXG00?oo@T01?om3003ooPP00?okTD00ooQMP03oln[00?oU[T00om0X@03o`2710?o06hc0ol0ED/3
o`0^?`Co01<]0ol01b03o`026P?o00<J0ol02283o`0H<@?o03]50ol0Gd@3o`1l70?o:YX00on<]`03
om6U00CoiV800ooe:P03ood<00?oo1000oob=@03on9a00?obkD00om_[`03oa:A00?o078]0ol0ED/3
o`0Z?@Co00lY0ol01Ad3o`026@?o00@M0ol03RP3o`0U>P?o055=0ol0JcH3o`280`?oBZ@00on/_`04
omJG00?oj5`00ooe:`03oo`>00?oo@X00ooh7`03oni700?oggX00oo=[`03oi>i00?oAJ<00ol7S004
o`1g9@?o06910ol0D4h3o`0`@0?o01/c0ol03RP3o`078@?o00@L1_l00QT3o`036`?o00DN1?l02283
o`0=9`?o01<]0ol06c<3o`0S>0?o02dn0ol0=T<3o`0nA`?o04I;0ol0C4d3o`1?CP?o051>1?l0Cdh3
o`1>CP?o04Q;0ol0@4P3o`0g@`?o02dn0ol08cP3o`0I<P?o014[0ol02bD3o`0780Oooooo0Ol00001
ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o06130ol0EdX3o`1?CP?o04180ol0=483o`0[
?@?o02@i0ol07cD3o`0K<`?o01Tb1ol06343o`0I<@?o01/c0ol07SD3o`0R>0?o02Pl0ol0<D03o`0m
AP?o04a=0ol0ET/3o`1OA0?o06Xh1?l0MRH3o`2430?o5I800om1X@03ogFa00?o//000oo?ZP03omf1
00?ojEP00ooc<`03ooXG00?oo@T01?om3003ooPP00?okTD00ooQMP03oln[00?oU[T00om0X@03o`27
10?o06hc0ol0ED/3o`0^?`Co01<]0ol01b03o`026P?o00<J0ol02283o`0H<@?o03]50ol0Gd@3o`1l
70?o:YX00on<]`03om6U00CoiV800ooe:P03ood<00?oo1000oob=@03on9a00?obkD00om_[`03oa:A
00?o078]0ol0ED/3o`0Z?@Co00lY0ol01Ad3o`026@?o00@M0ol03RP3o`0U>P?o055=0ol0JcH3o`28
0`?oBZ@00on/_`04omJG00?oj5`00ooe:`03oo`>00?oo@X00ooh7`03oni700?oggX00oo=[`03oi>i
00?oAJ<00ol7S004o`1g9@?o06910ol0D4h3o`0`@0?o01/c0ol03RP3o`078@?o00@L1_l00QT3o`03
6`?o00DN1?l02283o`0=9`?o01<]0ol06c<3o`0S>0?o02dn0ol0=T<3o`0nA`?o04I;0ol0C4d3o`1?
CP?o051>1?l0Cdh3o`1>CP?o04Q;0ol0@4P3o`0g@`?o02dn0ol08cP3o`0I<P?o014[0ol02bD3o`07
80Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o06130ol0EdX3o`1?CP?o
04180ol0=483o`0[?@?o02@i0ol07cD3o`0K<`?o01Tb1ol06343o`0I<@?o01/c0ol07SD3o`0R>0?o
02Pl0ol0<D03o`0mAP?o04a=0ol0ET/3o`1OA0?o06Xh1?l0MRH3o`2430?o5I800om1X@03ogFa00?o
//000oo?ZP03omf100?ojEP00ooc<`03ooXG00?oo@T01?om3003ooPP00?okTD00ooQMP03oln[00?o
U[T00om0X@03o`2710?o06hc0ol0ED/3o`0^?`Co01<]0ol01b03o`026P?o00<J0ol02283o`0H<@?o
03]50ol0Gd@3o`1l70?o:YX00on<]`03om6U00CoiV800ooe:P03ood<00?oo1000oob=@03on9a00?o
bkD00om_[`03oa:A00?o078]0ol0ED/3o`0Z?@Co00lY0ol01Ad3o`026@?o00@M0ol03RP3o`0U>P?o
055=0ol0JcH3o`280`?oBZ@00on/_`04omJG00?oj5`00ooe:`03oo`>00?oo@X00ooh7`03oni700?o
ggX00oo=[`03oi>i00?oAJ<00ol7S004o`1g9@?o06910ol0D4h3o`0`@0?o01/c0ol03RP3o`078@?o
00@L1_l00QT3o`036`?o00DN1?l02283o`0=9`?o01<]0ol06c<3o`0S>0?o02dn0ol0=T<3o`0nA`?o
04I;0ol0C4d3o`1?CP?o051>1?l0Cdh3o`1>CP?o04Q;0ol0@4P3o`0g@`?o02dn0ol08cP3o`0I<P?o
014[0ol02bD3o`0780Oooooo0Ol00001ooooo`007Oooool2o`0000Kooooo0ol0Ic`3o`1NA@?o05I;
0ol0Cdh3o`11B0?o03E30ol0;Ch3o`0W>`?o02<h0ol083H3o`0O=@Co01he0ol07cH3o`0Q=`?o02Di
0ol0:S`3o`0a@0?o03]50ol0B4/3o`1CC0?o05]70ol0ICh3o`1`<0Co07`L0ol0R@03obBG00?oDJH0
0on7]@03olC400?odil00ooPM`03ona?00?omB`00ook4`03ood800Coo0h00oog9@03one<00?ogWd0
0oo</P03ohZf00?o=ih00ol0Q@X3o`1[=`?o05==0ol0:cd4o`0B:`?o00HO0ol00QX3o`036`?o00TS
0ol06C83o`0mA`?o06130ol0OAX3obfK00?oT;P00ooBX`04onMP00?omBT00oom3003oo`@00?olSD0
0ooRLP03ol^e00?oL:l00olCT@03o`1c;0?o05I;0ol0:cd4o`0@:P?o00DN0ol00QT3o`0470?o00dW
0ol093T3o`1?CP?o06Xi0ol0QPP3od>R00?oXkd01?oDW003onMQ00?om2l00ool4003ood900?onA/0
0oo_@@03on5b00?od:L00onQ_003oe6V00?o49001?l0Nah3o`1V?@?o05A<0ol0=d<3o`0O=P?o014[
0ol02B<3o`047@?o00<J0ol00QT3o`036P?o00@M1?l01b03o`0:9@?o010Z0ol05Rl3o`0M=0?o02Di
0ol0;3h3o`0d@P?o03Y50ol0?dL3o`12B@?o04A:1?l0@dT3o`10B0?o03Y50ol0<d83o`0[?@?o02<h
0ol06c<3o`0C;@?o00dW0ol02283o`057PKooooo0_l00001ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`?o06Ll0ol0GTD3o`1FB`?o04m>0ol0@DP3o`0e@`?o02dn0ol09c/3o`0S>0?o020f0ol0
7cD4o`0N=@?o01lf0ol08CL3o`0U>@?o02Xl0ol0<D03o`0kA@?o04Q;0ol0Dd`3o`1KA`?o06Dn0ol0
L304o`1l70?o08T00olTU`03oe6V00?oQkD00oo4a003om>O00?oh7L00oo/C`03ooD/00?ona<00oom
2004oo`>00?ombD00oo]C003omim00?oc;800on:]P03ocNN00?o08D:0ol0JcL3o`1CC@?o02/m1?l0
4R/3o`067`?o008J0ol00a/3o`098`?o01Tb0ol0?DL3o`1P@`?o07dJ0ol]V`03oi2h00?odZ<01?oW
H003ooDY00?oo@`00ool4003oo8e00?ohW800oo;]@03og2_00?o4i400ol0Lb`3o`1FB`?o02/m1?l0
42X3o`057P?o008I0ol011`3o`0=9`?o02@i0ol0Cdh3o`1Z>@?o08H80om3XP03oj>m00Coe9`00ooW
H@03oo@_00?oo1000oom2@03ooTK00?okd400ooQLP03om2W00?oXK`00omAYP03oa2@00Co07/N0ol0
ISd3o`1DC0?o03M30ol07cH3o`0A:`?o00TS0ol011d3o`036P?o008I0ol00aX3o`047@Co00LP0ol0
2RD3o`0@:P?o01H_0ol07C@3o`0U>@?o02`n0ol0=483o`0jA@?o03m70ol0@TT3o`14BPCo04=90ol0
@4P3o`0jA@?o03=20ol0:cd3o`0S>0?o01/c0ol04bd3o`0=9`?o00PR0ol01Ah7ooooo`7o00000Ooo
ool001gooooo00?o0000ooooooooool01Oooool3o`1W?0?o05i50ol0ET/3o`1?CP?o04580ol0=D<3
o`0]?P?o02Lk0ol08cP3o`0P=P?o01le1?l07SD3o`0O=P?o024g0ol09CT3o`0Z?0?o03500ol0>dD3
o`18B`?o05=<0ol0FdL3o`1U?P?o070`1?l0O1`3o`2900?o99L00omAYP03ohNe00?oa<@00ooCW`03
on1g00?ok4l00ooe;003oo/C00?oo@P01?ol3P03ooLU00?okD`00ooNO@03olbb00?oR[H00olgWP03
o`252P?o06/g0ol0Ddd3o`0[?@Co018[0ol01Ql3o`026P?o00<K0ol02B<3o`0I<P?o03e70ol0H4<3
o`1m6P?o;I/00on@^003om:S00Coif000ooe:@03ood<00?oo1000oob=@03on9b00?obkD00om`[`03
oa>A00?o07</0ol0ET/3o`0[?@Co010Z0ol01Ah3o`026@?o00@L0ol03BL3o`0T>@?o04m>0ol0JST3
o`2620?o@j800onS_@04omBL00?oif400ood;`03oo`@00?oo@T00ooi6`03onm100?ohG800oo@Y`03
oj6l00?oDJH00ol@T004o`1k7P?o06Hm0ol0E4`3o`0g@`?o01lf0ol04B/3o`098`?o00@M0ol00aX3
o`026@?o00<J0ol011d4o`0780?o00XU0ol042X3o`0F;`?o01dd0ol09CT3o`0/?P?o03A20ol0>TD3
o`0oA`?o04990ol0A4X4o`13B@?o04180ol0>TD3o`0c@P?o02/m0ol08cP3o`0K<`?o01<]0ol03BL3
o`088P?o00DN1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0Kc83o`1V
?@?o05e50ol0ET/3o`1@CP?o04A90ol0>DD3o`0b@@?o02dn0ol0:S`3o`0X>`Co02Lk0ol0:3/3o`0Z
?@?o02ho0ol0=483o`0lAP?o04M;0ol0DDd3o`1IB@?o06520ol0JcL3o`1f9PCo088@0ol>S`03ocBM
00?oHj`00onJ^P03olVj00?oei@00ooSK003oni600?omRD00ool3`03ooh800Cona400ooe:`03onYC
00?og8D00oo9^P03ogjc00?o;Y/00ol0PA43o`1X>P?o051>0ol0:3/4o`0@:P?o00HO0ol00QT3o`03
6`?o00TT0ol06c<3o`10B0?o06920ol0OQL3oc6L00?oU;T00ooBX@04onMO00?omRP00oom3003oo`A
00?olSH00ooRLP03ol^e00?oLJl00olDT@03o`1c:`?o05I:0ol0;3h4o`0@:P?o00DN0ol00QT3o`04
70?o00`V0ol08SL3o`1=CP?o06Pk0ol0Q0`3ocbP00?oVkX01?oBXP03onEV00?olc<00ook4P03ood9
00?onQL00ooa>P03onAZ00?odil00on__`03oenZ00?o79@01?l0OaH3o`1[=`?o05Q:0ol0?dL3o`0T
>@?o01@^0ol02bD3o`067`?o00<K1_l00QT3o`036`Co00DN0ol02283o`0<9P?o014[0ol05c03o`0M
=0?o02@i0ol0:S`3o`0_?`?o03=11_l0=T<4o`0e@`?o03=10ol0;Sl3o`0X>`?o024g0ol06S83o`0D
;@?o00hX0ol02B<3o`067`?o00@L1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Go
oooo0ol0Kc83o`1V?@?o05e50ol0ET/3o`1@CP?o04A90ol0>DD3o`0b@@?o02dn0ol0:S`3o`0X>`Co
02Lk0ol0:3/3o`0Z?@?o02ho0ol0=483o`0lAP?o04M;0ol0DDd3o`1IB@?o06520ol0JcL3o`1f9PCo
088@0ol>S`03ocBM00?oHj`00onJ^P03olVj00?oei@00ooSK003oni600?omRD00ool3`03ooh800Co
na400ooe:`03onYC00?og8D00oo9^P03ogjc00?o;Y/00ol0PA43o`1X>P?o051>0ol0:3/4o`0@:P?o
00HO0ol00QT3o`036`?o00TT0ol06c<3o`10B0?o06920ol0OQL3oc6L00?oU;T00ooBX@04onMO00?o
mRP00oom3003oo`A00?olSH00ooRLP03ol^e00?oLJl00olDT@03o`1c:`?o05I:0ol0;3h4o`0@:P?o
00DN0ol00QT3o`0470?o00`V0ol08SL3o`1=CP?o06Pk0ol0Q0`3ocbP00?oVkX01?oBXP03onEV00?o
lc<00ook4P03ood900?onQL00ooa>P03onAZ00?odil00on__`03oenZ00?o79@01?l0OaH3o`1[=`?o
05Q:0ol0?dL3o`0T>@?o01@^0ol02bD3o`067`?o00<K1_l00QT3o`036`Co00DN0ol02283o`0<9P?o
014[0ol05c03o`0M=0?o02@i0ol0:S`3o`0_?`?o03=11_l0=T<4o`0e@`?o03=10ol0;Sl3o`0X>`?o
024g0ol06S83o`0D;@?o00hX0ol02B<3o`067`?o00@L1oooool1o`00007ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo0ol0Kc83o`1V?@?o05e50ol0ET/3o`1@CP?o04A90ol0>DD3o`0b@@?o02dn
0ol0:S`3o`0X>`Co02Lk0ol0:3/3o`0Z?@?o02ho0ol0=483o`0lAP?o04M;0ol0DDd3o`1IB@?o0652
0ol0JcL3o`1f9PCo088@0ol>S`03ocBM00?oHj`00onJ^P03olVj00?oei@00ooSK003oni600?omRD0
0ool3`03ooh800Cona400ooe:`03onYC00?og8D00oo9^P03ogjc00?o;Y/00ol0PA43o`1X>P?o051>
0ol0:3/4o`0@:P?o00HO0ol00QT3o`036`?o00TT0ol06c<3o`10B0?o06920ol0OQL3oc6L00?oU;T0
0ooBX@04onMO00?omRP00oom3003oo`A00?olSH00ooRLP03ol^e00?oLJl00olDT@03o`1c:`?o05I:
0ol0;3h4o`0@:P?o00DN0ol00QT3o`0470?o00`V0ol08SL3o`1=CP?o06Pk0ol0Q0`3ocbP00?oVkX0
1?oBXP03onEV00?olc<00ook4P03ood900?onQL00ooa>P03onAZ00?odil00on__`03oenZ00?o79@0
1?l0OaH3o`1[=`?o05Q:0ol0?dL3o`0T>@?o01@^0ol02bD3o`067`?o00<K1_l00QT3o`036`Co00DN
0ol02283o`0<9P?o014[0ol05c03o`0M=0?o02@i0ol0:S`3o`0_?`?o03=11_l0=T<4o`0e@`?o03=1
0ol0;Sl3o`0X>`?o024g0ol06S83o`0D;@?o00hX0ol02B<3o`067`?o00@L1oooool1o`00007ooooo
000Mooooo`03o`000?oooooooooo00Gooooo0ol0Kc83o`1V?@?o05e50ol0ET/3o`1@CP?o04A90ol0
>DD3o`0b@@?o02dn0ol0:S`3o`0X>`Co02Lk0ol0:3/3o`0Z?@?o02ho0ol0=483o`0lAP?o04M;0ol0
DDd3o`1IB@?o06520ol0JcL3o`1f9PCo088@0ol>S`03ocBM00?oHj`00onJ^P03olVj00?oei@00ooS
K003oni600?omRD00ool3`03ooh800Cona400ooe:`03onYC00?og8D00oo9^P03ogjc00?o;Y/00ol0
PA43o`1X>P?o051>0ol0:3/4o`0@:P?o00HO0ol00QT3o`036`?o00TT0ol06c<3o`10B0?o06920ol0
OQL3oc6L00?oU;T00ooBX@04onMO00?omRP00oom3003oo`A00?olSH00ooRLP03ol^e00?oLJl00olD
T@03o`1c:`?o05I:0ol0;3h4o`0@:P?o00DN0ol00QT3o`0470?o00`V0ol08SL3o`1=CP?o06Pk0ol0
Q0`3ocbP00?oVkX01?oBXP03onEV00?olc<00ook4P03ood900?onQL00ooa>P03onAZ00?odil00on_
_`03oenZ00?o79@01?l0OaH3o`1[=`?o05Q:0ol0?dL3o`0T>@?o01@^0ol02bD3o`067`?o00<K1_l0
0QT3o`036`Co00DN0ol02283o`0<9P?o014[0ol05c03o`0M=0?o02@i0ol0:S`3o`0_?`?o03=11_l0
=T<4o`0e@`?o03=10ol0;Sl3o`0X>`?o024g0ol06S83o`0D;@?o00hX0ol02B<3o`067`?o00@L1ooo
ool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0Mb@3o`1^<P?o06Hm0ol0GTD3
o`1HBP?o055=0ol0BD`3o`10B0?o03Y50ol0=T<3o`0c@@Co03910ol0<d43o`0f@`?o03Y50ol0@DP3
o`1:C0?o055=0ol0F4X3o`1OA0?o06Pk0ol0LRd3o`1m6`Co08T10olNU@03odNS00?oN;400on``003
olj^00?ofhP00ooWH@03oo4l00?on1l00oom3003ood800ConaD00ooc<@03onQL00?ofHh00oo6`P03
og6`00?o99L00ol0OQP3o`1U?P?o04e>0ol093T4o`0?:@?o00DN0ol00QT3o`036`?o00XT0ol07C@3
o`13B@?o06=00ol0P1D3ocFM00?oV;X00ooCWP04onQM00?omRL00oom2`03oo/A00?olSH00ooRLP03
ol^d00?oL[000olETP03o`1d:P?o05M:0ol0;Ch4o`0A:`?o00DN0ol00QT3o`0470?o00/V0ol083H3
o`19C0?o06Hm0ol0PA43ocFM00?oTKP01?o@Z003on=]00?olSP00ooj5@03ood900?ona@00ooc=003
onIR00?oeYH00ono``03off^00?o:9T01?l0Q0`3o`1_<@?o05a60ol0B4/3o`0[?@?o01Pa0ol03BL3
o`078@?o00@L0ol00QX3o`026@?o00<J1?l011`3o`0680?o00TS0ol03BL3o`0B;0?o01L`0ol073@3
o`0Q=`?o02Di0ol0:3/3o`0Z?0?o02/m1?l0:C`3o`0W>`?o02<h0ol07SD3o`0H<@?o01<]0ol03RP3
o`098`?o00HO0ol011`3o`036POooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05oooo
o`?o07LT0ol0KS83o`1V?@?o05i50ol0F4X3o`1AC@?o04U<0ol0@4P3o`0jA@?o03I30ol0<d44o`0b
@@?o03=10ol0=T<3o`0jA@?o04580ol0BT`3o`1AC@?o05Q:0ol0Gd@3o`1X>`?o078]0ol0OA/4o`29
0@?o7YD00om7X`03ogRa00?o/<000oo>[P03om^800?oif400ooa?003ooPO00?oo@`00oom2004oo/E
00?olc400ooXG003omV>00?oa/800oma/003obBG00?o07hH0ol0ICh3o`1=CP?o02@i1?l03bT3o`05
7P?o008I0ol00a/3o`0:90?o01dd0ol0@dT3o`1S@0?o080E0oleW@03oiRj00?odih01?oXG@03ooHW
00?oo@/00ook4@03oo8f00?ohW800oo;]003og:`00?o5I800ol0M2X3o`1GBP?o02dn1?l04B/3o`05
7P?o008I0ol011`3o`0;9P?o020f0ol0BD`3o`1V?@?o084A0oleW@03oi6h00Cod:P00ooSK@03oo8h
00?onQD00oom2@03oo/D00?olc@00ooVHP03omJF00?o_l<00om][P03obRI00Co08@<0ol0Kc43o`1L
AP?o04Q;0ol0:cd3o`0H<@?o00dW0ol01b43o`0470?o008J0ol00QT3o`036PCo00@L0ol01R03o`09
8`?o00dW0ol04R`3o`0G<0?o01`d0ol08CL3o`0U>@?o02Pk0ol0:S`3o`0[?@Co02Tl0ol09c/3o`0S
>0?o01he0ol06343o`0C;@?o00hX0ol02B<3o`067`?o00@L0ol00aX7ooooo`7o00000Oooool001go
oooo00?o0000ooooooooool01Oooool3o`1g90?o06hb0ol0ISd3o`1NA@?o05Q:0ol0DDd3o`19C0?o
04180ol0>TD3o`0f@`?o03=11?l0<T43o`0c@@?o03I30ol0>TD3o`11B0?o04Y<0ol0DDd3o`1HBP?o
05m40ol0J3/3o`1b;@?o07dK1?l0R@43oajE00?oAj<00omh/@03ok3000?ocZh00ooKR003onMQ00?o
lC`00ooh7`03ood<00?oo@P01?ok5@03oo<a00?oj5`00ooISP03olK200?oLK000olTU`03o`1n60?o
06Dn0ol0CDh3o`0T>@Co00lY0ol01Ah3o`026@?o00<K0ol02R@3o`0M=0?o04=90ol0Hd03o`205@?o
=Id00onH^P03om>N00Coj5d00oof9`03ood;00?ona400oob=P03on9b00?obk@00omb/003oaFB00?o
07@Z0ol0EdX3o`0]?PCo014[0ol01Ah3o`026@?o00@L0ol02bH3o`0P=P?o04U<0ol0ISd3o`214@?o
=Id00onA^004om2X00?ohfd00oob>003ooXE00?oo@T00ook5003oo<d00?oiV800ooFUP03oko300?o
KJh00olXV@04o`2430?o06la0ol0G4H3o`18B`?o02/m0ol06343o`0=9`?o00LQ0ol011`3o`026P?o
008I0ol00aX4o`0470?o00HP0ol02B<3o`0=9`?o018/0ol05c03o`0L=0?o024g0ol09CT3o`0X>`?o
02Xl0ol0:cd4o`0Y?0?o02Lk0ol08cP3o`0N=@?o01Pa0ol04bd3o`0>:0?o00TS0ol01Ql3o`0470?o
00<J1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0P1@3o`1g90?o06la
0ol0J3/3o`1Q@P?o05Y80ol0E4`3o`1@CP?o04]=0ol0ADX3o`12B@Oo04580ol0A4X3o`19C0?o04m>
0ol0Dd`3o`1IB@?o05m40ol0IS`3o`1_<@?o07TQ0ol0Q0`4o`n@00?o<Y`00omMZP03ohng00?oaL<0
0ooBX003ommk00?ojUD00ooc<`03ooXH00?oo@X00oom2@04ooTJ00?olCT00ooUI@03omFH00?o^/80
0omT[003oaVD00?o07/N0ol0HT43o`16B`?o024g1?l03BL3o`047@?o008I0ol011`3o`0;9@?o01le
0ol0Ad/3o`1U?P?o084A0oliW`03oifk00?oe9`01?oXF`03ooHV00?oo@/00ook4@03oo8f00?ohW80
0oo;]003og>`00?o5Y800ol0M2T3o`1HBP?o02lo1?l04R`3o`067`?o008I0ol00a/3o`0;9@?o01he
0ol0ADX3o`1T@0?o07lF0ol]V`03ohNe00CocJh00ooQL`03oo0n00?onQP00oom2@03oo/A00?om2h0
0ooYF@03omV<00?oakh00omn/`03ocJN00Co08T10ol0M2T3o`1Q@P?o051>0ol0<d43o`0N=@?o014[
0ol02B<3o`057P?o00<K1_l00QT4o`036`?o00DM0ol01b03o`0:90?o00dX0ol04B/3o`0E;P?o01Ta
0ol073@3o`0O=@Ko020f1?l07cH3o`0M=0?o01Tb0ol05Rl3o`0A:`?o00dW0ol02B<3o`0680?o00@L
0ol00aX3o`026POooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o080D0ol0
Mb@3o`1_<@?o06Pk0ol0HD83o`1JB0?o05A<0ol0D4h3o`1;C@?o04E:0ol0@TT7o`11B0?o04A:0ol0
BD`3o`1?CP?o05=<0ol0FDT3o`1OA0?o06Hl0ol0Kc43o`1i8@?o08@<1?l?T003oc:L00?oGJX00on?
]`03olG300?odZ000ooON`03onYE00?olc<00ooj6003ood:00?oo@T01?oi6P03oo4i00?oiFD00ooE
V003ok[200?oI:`00olIU003o`1k7P?o06910ol0AT/3o`0Q=`Co00dW0ol011d3o`026@?o00@L0ol0
2bD3o`0O=@?o04M;0ol0ICh3o`214@?o>Il00onM^`03omBL00Coj5/00oof9P03ood;00?ona400oob
=P03on9b00?obk@00omc/003oaJB00?o07@Y0ol0F4X3o`0_?`Co018/0ol01Ql3o`026@?o00<K0ol0
2bD3o`0N=@?o04E:0ol0I403o`1o5P?o;I/00on7]@04olf^00?ohG<00oo`?P03ooXH00?oo@T00ook
4@03oo@^00?ojET00ooIS003olNn00?oO[<00olfWP04o`290@?o07@Y0ol0HD83o`1@CP?o03=10ol0
7SD3o`0A:`?o00TS0ol01Ah3o`036`Ko008I1?l00a/3o`057@?o00LP0ol02R@3o`0=:0?o014[0ol0
5Bh3o`0I<@?o01`d0ol07cD6o`0P=PCo01lf0ol07C@3o`0I<P?o01H_0ol04B/3o`0=9`?o00TS0ol0
1R03o`0470?o00<J0ol00QX7ooooo`7o00000Oooool001gooooo0_l00006ooooo`?o080D0ol0Mb@3
o`1_<@?o06Pk0ol0HD83o`1JB0?o05A<0ol0D4h3o`1;C@?o04E:0ol0@TT7o`11B0?o04A:0ol0BD`3
o`1?CP?o05=<0ol0FDT3o`1OA0?o06Hl0ol0Kc43o`1i8@?o08@<1?l?T003oc:L00?oGJX00on?]`03
olG300?odZ000ooON`03onYE00?olc<00ooj6003ood:00?oo@T01?oi6P03oo4i00?oiFD00ooEV003
ok[200?oI:`00olIU003o`1k7P?o06910ol0AT/3o`0Q=`Co00dW0ol011d3o`026@?o00@L0ol02bD3
o`0O=@?o04M;0ol0ICh3o`214@?o>Il00onM^`03omBL00Coj5/00oof9P03ood;00?ona400oob=P03
on9b00?obk@00omc/003oaJB00?o07@Y0ol0F4X3o`0_?`Co018/0ol01Ql3o`026@?o00<K0ol02bD3
o`0N=@?o04E:0ol0I403o`1o5P?o;I/00on7]@04olf^00?ohG<00oo`?P03ooXH00?oo@T00ook4@03
oo@^00?ojET00ooIS003olNn00?oO[<00olfWP04o`290@?o07@Y0ol0HD83o`1@CP?o03=10ol07SD3
o`0A:`?o00TS0ol01Ah3o`036`Ko008I1?l00a/3o`057@?o00LP0ol02R@3o`0=:0?o014[0ol05Bh3
o`0I<@?o01`d0ol07cD6o`0P=PCo01lf0ol07C@3o`0I<P?o01H_0ol04B/3o`0=9`?o00TS0ol01R03
o`0470?o00<J0ol00QX6ooooo`;o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`2:
00?o084A0ol0NB43o`1b;@?o06/g0ol0I3l3o`1NA@?o05U90ol0ED/3o`1CC0?o055=1?l0D4h3o`1@
C@?o059=0ol0E4`3o`1GBP?o05]70ol0H4<3o`1W?0?o06hb0ol0MbD3o`214`?o18/01?lSU`03odRS
00?oMK000onX_P03ol^e00?oei800ooSK@03one900?omBT00ook4P03ooh800?oo@`01?oh8003onm2
00?ohVl00ooBXP03ojZn00?oEZP00ol?T003o`1g9@?o05i40ol0@4P3o`0N=@Co00`V0ol011`3o`02
6@?o00@L0ol032L3o`0Q=`?o04Y=0ol0IS`3o`233P?o?J000onQ_003omFI00CojET00oog9@03ood;
00?ona400oob=`03on9b00?obk@00omd/003oaNC00?o07DX0ol0FDT3o`0`@0Co01</0ol01Ql3o`02
6@?o00<K0ol02R@3o`0L=0?o04580ol0HD83o`1l6`?o9IP00omm/`04ol^e00?ogg/00oo^A003ooTM
00?oo@T00ool3P03ooHW00?oje000ooMPP03ol^d00?oT;P00om6X`04o`^>00?o07XP0ol0Ic`3o`1E
B`?o03a60ol093T3o`0E;P?o00`V0ol01R03o`0470?o008J0ol00QT4o`026P?o00<K0ol01Ah3o`07
8@?o00XT0ol03BL3o`0?:P?o018/0ol05Bh3o`0F;`Ko01L`1?l05Rl3o`0D;P?o018/0ol03bT3o`0<
9P?o00TS0ol01Ql3o`0470?o00<J0ol00QX3o`036POooooo0Ol00001ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`?o08X00ol0PA43o`1i8@?o078]0ol0JcL3o`1T?`?o05i50ol0FDT3o`1EB`?o
05=<0ol0DDd4o`1@CP?o051=0ol0DTd3o`1DC0?o05M:0ol0FdL3o`1P@`?o06Ll0ol0KS83o`1g9@?o
084C0ol4R`04ob>G00?oB:<00ome/003ojRn00?obkD00ooGTP03on=]00?okDT00ooe:@03oo/B00?o
oPP00oom3004ooPP00?okd800ooRK`03om:R00?oZ[h00omFZ003o`n@00?o07LU0ol0GT@3o`10B0?o
01he1?l032H3o`0470?o008I0ol011`3o`0<9`?o024g0ol0BTd3o`1V?0?o08<>0olmX003oj6l00?o
eIT01?oYF@03ooLU00?oo@/00ook4@03oo8g00?ohW800oo;]003ogB`00?o5i<00ol0MBP3o`1IB@?o
03101?l04b`3o`067`?o008I0ol00a/3o`0:90?o01`d0ol0@DP3o`1Q@P?o07`K0olUV003ogfc00Co
bkD00ooON`03oni400?onAd00oom2@03oo`>00?omRL00oo[D003omf200?obk@00on@^003odJS00Co
2hh00ol0NR03o`1W?0?o05E;0ol0?4H3o`0T>@?o01D^0ol032H3o`0680?o00@L0ol00QX3o`026@Co
008J0ol00a/3o`057P?o00LQ0ol02R@3o`0=9`?o00lZ0ol04R`3o`0E;P?o01H_1_l05c04o`0F;`?o
01@^0ol04R`3o`0?:@?o00`V0ol02B<3o`067`?o00@L0ol00aX3o`026P?o00<J1oooool1o`00007o
oooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0RP03o`214@?o07TQ0ol0LRd3o`1[=`?o06@o
0ol0GTD3o`1IB@?o05E;0ol0Dd`3o`1AC@Co051>0ol0D4d3o`1BC@?o05A<0ol0EdX3o`1KA`?o0613
0ol0Ic`3o`1^<P?o07LU0ol0PA<3o`B;00Co8iL00om8X`03ogF`00?oZ;h00oo;]@03omNB00?ohfd0
0oo]B@03ooDY00?ona800oon2003ood<00Con2000oo_@P03on9_00?odZ800onZ_P03oeJX00?o3i00
0ol0MbD3o`1NA0?o04180ol07SD4o`0<9P?o00@L0ol00QT3o`0470?o00`W0ol08CL3o`1:C@?o06Hl
0ol0P`h3ocfP00?oXK`00ooEV@04onUI00?ombD00oom2`03oo/A00?olSL00ooRLP03ol^d00?oM;00
0olGT`03o`1e:0?o05U90ol0<404o`0C;0?o00HO0ol00QT3o`036`?o00XT0ol073@3o`11B0?o0652
0ol0O1/3obFH00?oOK<01?o;]@03ommk00?okT@00ooi7@03ood900?oo0h00oof9`03on]@00?ogH80
0oo;]003oi2h00?oAZ<01?l;SP03o`1j80?o06Ll0ol0ED/3o`0lAP?o02@i0ol05Bh3o`0<9P?o00HP
0ol011`3o`026P?o008I1?l00QX3o`036`?o00DN0ol01b43o`0:90?o00dW0ol03bX3o`0B;0?o01D^
0ol05Rl6o`0G<0Co01H_0ol052h3o`0B;0?o00lY0ol032H3o`098`?o00HO0ol011`3o`036P?o008J
0ol00aX7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3oaVD00?o1H`00ol0
Q0`3o`1l6`?o07HW0ol0KS83o`1X>P?o06=00ol0Gd@3o`1MAP?o05]81ol0FDP3o`1KB0?o05e60ol0
H4<3o`1T?`?o06Ti0ol0Kc43o`1g9@?o07lE0ol0R@03oaVD00Co>Yl00omQZ`03ohnh00?o`l@00ooA
Y@03omf200?oieh00ooa?003ooPP00?oo0h00oon1`03oo`@00ComRL00oo/C003ommj00?ocZ`00onI
^P03odRS00?o18/00ol0Lb`3o`1KA`?o03Y50ol06S84o`0:90?o00@L0ol00QT3o`057@?o00hX0ol0
93T3o`1>CP?o06Pj0ol0Q@X3od:R00?oYkd00ooFU`04onUG00?omb@00oom2`03oo/A00?olSL00ooR
LP03ol^d00?oMK400olHT`03o`1f9`?o05U80ol0<T44o`0C;@?o00HP0ol00QX3o`036`?o00TS0ol0
6S83o`0mAP?o05m40ol0NR03oafE00?oL[001?o8_003omb200?okD`00oog8@06ood;00?on2400oo^
A`03on1g00?ocjT00onS_003oeRX00Co6Y@00ol0P1@3o`1]=@?o05]70ol0Ad/3o`0/?P?o01Xb0ol0
3bT3o`098`?o00DN0ol00a/7o`026@?o00<J0ol011`3o`057P?o00LP0ol02B<3o`0;9@?o00dW0ol0
3RT9o`0@:PCo00lY0ol03RP3o`0<9P?o00XT0ol01b43o`057P?o00@L0ol00aX3o`026@?o00<J0ol0
11`7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3oaVD00?o1H`00ol0Q0`3
o`1l6`?o07HW0ol0KS83o`1X>P?o06=00ol0Gd@3o`1MAP?o05]81ol0FDP3o`1KB0?o05e60ol0H4<3
o`1T?`?o06Ti0ol0Kc43o`1g9@?o07lE0ol0R@03oaVD00Co>Yl00omQZ`03ohnh00?o`l@00ooAY@03
omf200?oieh00ooa?003ooPP00?oo0h00oon1`03oo`@00ComRL00oo/C003ommj00?ocZ`00onI^P03
odRS00?o18/00ol0Lb`3o`1KA`?o03Y50ol06S84o`0:90?o00@L0ol00QT3o`057@?o00hX0ol093T3
o`1>CP?o06Pj0ol0Q@X3od:R00?oYkd00ooFU`04onUG00?omb@00oom2`03oo/A00?olSL00ooRLP03
ol^d00?oMK400olHT`03o`1f9`?o05U80ol0<T44o`0C;@?o00HP0ol00QX3o`036`?o00TS0ol06S83
o`0mAP?o05m40ol0NR03oafE00?oL[001?o8_003omb200?okD`00oog8@06ood;00?on2400oo^A`03
on1g00?ocjT00onS_003oeRX00Co6Y@00ol0P1@3o`1]=@?o05]70ol0Ad/3o`0/?P?o01Xb0ol03bT3
o`098`?o00DN0ol00a/7o`026@?o00<J0ol011`3o`057P?o00LP0ol02B<3o`0;9@?o00dW0ol03RT9
o`0@:PCo00lY0ol03RP3o`0<9P?o00XT0ol01b43o`057P?o00@L0ol00aX3o`026@?o00<J0ol011`7
ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3oaVD00?o1H`00ol0Q0`3o`1l
6`?o07HW0ol0KS83o`1X>P?o06=00ol0Gd@3o`1MAP?o05]81ol0FDP3o`1KB0?o05e60ol0H4<3o`1T
?`?o06Ti0ol0Kc43o`1g9@?o07lE0ol0R@03oaVD00Co>Yl00omQZ`03ohnh00?o`l@00ooAY@03omf2
00?oieh00ooa?003ooPP00?oo0h00oon1`03oo`@00ComRL00oo/C003ommj00?ocZ`00onI^P03odRS
00?o18/00ol0Lb`3o`1KA`?o03Y50ol06S84o`0:90?o00@L0ol00QT3o`057@?o00hX0ol093T3o`1>
CP?o06Pj0ol0Q@X3od:R00?oYkd00ooFU`04onUG00?omb@00oom2`03oo/A00?olSL00ooRLP03ol^d
00?oMK400olHT`03o`1f9`?o05U80ol0<T44o`0C;@?o00HP0ol00QX3o`036`?o00TS0ol06S83o`0m
AP?o05m40ol0NR03oafE00?oL[001?o8_003omb200?okD`00oog8@06ood;00?on2400oo^A`03on1g
00?ocjT00onS_003oeRX00Co6Y@00ol0P1@3o`1]=@?o05]70ol0Ad/3o`0/?P?o01Xb0ol03bT3o`09
8`?o00DN0ol00a/7o`026@?o00<J0ol011`3o`057P?o00LP0ol02B<3o`0;9@?o00dW0ol03RT9o`0@
:PCo00lY0ol03RP3o`0<9P?o00XT0ol01b43o`057P?o00@L0ol00aX3o`026@?o00<J0ol011`7oooo
o`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3ocJN00?o8IH00ol>S`03o`280`?o
084A0ol0NR03o`1c:P?o06hb0ol0JSP3o`1W>`?o06Dn1?l0I3l3o`1S@0?o06@o0ol0IS`3o`1Y>@?o
06dc0ol0Lb`3o`1i8P?o080D0ol0R043oaFB00?o<I`01?mDY`03ogfc00?o[Kl00oo;]@03omNE00?o
hW800oo[D003oo@a00?onQP00oom2P03ood800?onQD01?od<003onUG00?ofhH00oo:^003ohNe00?o
>Il00ol0Q`H3o`1^<P?o05M:0ol0=483o`0G<0Co00TS0ol00a/3o`026@?o00DN0ol03bT3o`0V>P?o
051=0ol0JSL3o`271P?oB:<00on/_`03omND00CojU@00oog8`03ood:00?ona800oob=`03on9b00?o
bk<00omf/@03oaZD00?o07HV0ol0FTP3o`0c@@Co01@^0ol01b03o`026P?o00<J0ol02283o`0H<@?o
03U40ol0G4H3o`1g9@?o5I800omV[004olG400?ofX/00ooZD`03ooHW00?oo0d00oom2@03ooTK00?o
l3h00ooTK003omBM00?o^<800om/[P04ob^J00?o08H70ol0Lb/3o`1Q@P?o055=0ol0=T<3o`0Q=`?o
01@^0ol032H3o`0780?o00@L0ol00aX7o`026@?o00<J0ol00a`3o`057@?o00HO0ol01b43o`098`?o
00XT0ol02RD6o`0;9@Co00XT0ol02B<3o`078@?o00HO0ol01Ad3o`036`?o00<J0ol00QT3o`026P?o
00@L0ol01R07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3ocJN00?o8IH0
0ol>S`03o`280`?o084A0ol0NR03o`1c:P?o06hb0ol0JSP3o`1W>`?o06Dn1?l0I3l3o`1S@0?o06@o
0ol0IS`3o`1Y>@?o06dc0ol0Lb`3o`1i8P?o080D0ol0R043oaFB00?o<I`01?mDY`03ogfc00?o[Kl0
0oo;]@03omNE00?ohW800oo[D003oo@a00?onQP00oom2P03ood800?onQD01?od<003onUG00?ofhH0
0oo:^003ohNe00?o>Il00ol0Q`H3o`1^<P?o05M:0ol0=483o`0G<0Co00TS0ol00a/3o`026@?o00DN
0ol03bT3o`0V>P?o051=0ol0JSL3o`271P?oB:<00on/_`03omND00CojU@00oog8`03ood:00?ona80
0oob=`03on9b00?obk<00omf/@03oaZD00?o07HV0ol0FTP3o`0c@@Co01@^0ol01b03o`026P?o00<J
0ol02283o`0H<@?o03U40ol0G4H3o`1g9@?o5I800omV[004olG400?ofX/00ooZD`03ooHW00?oo0d0
0oom2@03ooTK00?ol3h00ooTK003omBM00?o^<800om/[P04ob^J00?o08H70ol0Lb/3o`1Q@P?o055=
0ol0=T<3o`0Q=`?o01@^0ol032H3o`0780?o00@L0ol00aX7o`026@?o00<J0ol00a`3o`057@?o00HO
0ol01b43o`098`?o00XT0ol02RD6o`0;9@Co00XT0ol02B<3o`078@?o00HO0ol01Ad3o`036`?o00<J
0ol00QT3o`026P?o00@L0ol01R07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Ooo
ool3ocJN00?o8IH00ol>S`03o`280`?o084A0ol0NR03o`1c:P?o06hb0ol0JSP3o`1W>`?o06Dn1?l0
I3l3o`1S@0?o06@o0ol0IS`3o`1Y>@?o06dc0ol0Lb`3o`1i8P?o080D0ol0R043oaFB00?o<I`01?mD
Y`03ogfc00?o[Kl00oo;]@03omNE00?ohW800oo[D003oo@a00?onQP00oom2P03ood800?onQD01?od
<003onUG00?ofhH00oo:^003ohNe00?o>Il00ol0Q`H3o`1^<P?o05M:0ol0=483o`0G<0Co00TS0ol0
0a/3o`026@?o00DN0ol03bT3o`0V>P?o051=0ol0JSL3o`271P?oB:<00on/_`03omND00CojU@00oog
8`03ood:00?ona800oob=`03on9b00?obk<00omf/@03oaZD00?o07HV0ol0FTP3o`0c@@Co01@^0ol0
1b03o`026P?o00<J0ol02283o`0H<@?o03U40ol0G4H3o`1g9@?o5I800omV[004olG400?ofX/00ooZ
D`03ooHW00?oo0d00oom2@03ooTK00?ol3h00ooTK003omBM00?o^<800om/[P04ob^J00?o08H70ol0
Lb/3o`1Q@P?o055=0ol0=T<3o`0Q=`?o01@^0ol032H3o`0780?o00@L0ol00aX7o`026@?o00<J0ol0
0a`3o`057@?o00HO0ol01b43o`098`?o00XT0ol02RD6o`0;9@Co00XT0ol02B<3o`078@?o00HO0ol0
1Ad3o`036`?o00<J0ol00QT3o`026P?o00@L0ol01R07ooooo`7o00000Oooool000Kooooo1Ol00003
ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo00Gooooo0omFZ003
od:Q00?o;I/00olJU003o`Z>00?o08H70ol0P1D3o`1j7`?o07HV0ol0Lb/3o`1`;`Co06lb0ol0KS83
o`1_<@?o074^0ol0M2X3o`1h8`?o07dJ0ol0P`h3o`6:00?o5I800ol_V`03odfU00CoL[000onL^`03
olK000?odZ<00ooLP`03onIQ00?okd400oof9@03oo/A00?ooPL00oom2`03ooTL00ColCX00ooVH`03
omNC00?oaL<00omd/003obZJ00?o088@0ol0JSP3o`1CC0?o02ho0ol052h4o`088@?o00<J0ol00QT3
o`067`?o014[0ol0:S`3o`1CC@?o06de0ol0R@43odfU00?o//000ooHT@04on]B00?omb400oom2P03
oo/B00?olSP00ooRLP03olbc00?oMk400olKU003o`1g90?o05]70ol0=D84o`0E;`?o00LQ0ol00QX3
o`036P?o00PQ0ol05Rl3o`0e@P?o05Y80ol0M2X3o`b?00?oFZT01?nh`P03omND00?oj5`00ood;@03
oo`@00?oo@P00ooj5@03oo<d00?oif000ooHT003olNo00?oPK@01?lnX003o`N=00?o07XP0ol0J3/3
o`1HBP?o04=90ol0:Sd3o`0J<P?o010Z0ol02B<3o`067`?o00@L1?l00QX6o`026@?o00<J0ol00a/3
o`0470?o00DN0ol01Ql3o`0680Wo00LP1?l01R03o`057`?o00DM0ol011`3o`036`?o008J0ol00QT3
o`026P?o00@L0ol01Ql3o`0;9@Oooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`?oEZP00om2
X@03obfK00?o6Y@00ol:SP03o`261`?o080E0ol0NQl3o`1f9P?o07<[0ol0L2l4o`1_<P?o06hb0ol0
Kc43o`1a;P?o07@Z0ol0N2<3o`1m6P?o08<>0ol1RP03oaFB00?o;i/00om=Y@04og:`00?oW;/00oo6
`003om:S00?og8<00ooVH@03onm100?omRD00ook4@03ooh700?oo@/00ooi7004oo4j00?oiV<00ooG
T`03olG300?oM;000olZVP03o`2240?o06Xh0ol0Dd`3o`0^?`?o01@^1?l02243o`036P?o008I0ol0
1Ql3o`0A:`?o02Xl0ol0Ddd3o`1]=@?o08T10om=Y@03ok;000?of9401?o[DP03ooLQ00?oo@X00ook
4P03oo8h00?ohW800oo</`03ogNa00?o6i@00ol0Mb@3o`1KA`?o03E21?l05Bl3o`078@?o008J0ol0
0aX3o`088@?o01H_0ol0=D83o`1JB0?o07@Z0ol<S`03oeZY00Co^<800ooGU003onQL00?om2d00ool
4003ood800?onQD00ooc=003onMP00?of9000oo7_`03oh6d00Co?Z000ol7S@03o`1j80?o06Pk0ol0
F4X3o`13B@?o02Xm0ol06S83o`0@:P?o00TS0ol01Ql3o`0470Co008J1_l00QT3o`036P?o00<K0ol0
11`3o`057P?o00HO0ol01R09o`0780Co00HP0ol01Al3o`057@?o00@L0ol00a/3o`026P?o008I0ol0
0QX3o`0470?o00HO0ol02bD7ooooo`7o00000Oooool000Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`04ooooo`?o00001Oooool3oeJX00?o@Z400ol]V`03oaZD00?o2Xh00ol0QPL3
o`205@?o07XO0ol0MRH3o`1c:`?o070_1?l0Kc83o`1^<P?o06la0ol0LBh3o`1d:P?o07PS0ol0OAX3
o`233P?o0HX00olETP03obnK00?oCJD01?mb/003oibk00?oa/000ooBX`03omb300?oiV400oo_@@03
ooHU00?ona400oon1`03ood;00?onA`01?oa>P03onIS00?oei<00oo5``03ogB`00?o:YX00ol0PQ03
o`1Z>0?o05=<0ol0;Sl3o`0D;PCo00PQ0ol00aX3o`026@?o00HO0ol04B/3o`0Z?0?o05==0ol0KCD3
o`290@?oCJD00onb`003omRA00Coje800oog8@03ood:00?ona800oob>003on9b00?oc;<00omg/@03
oa^D00?o07LT0ol0FdL3o`0e@PCo01D_0ol01b43o`026P?o00<J0ol02243o`0F;`?o03E20ol0FTP3
o`1d:P?o38l00omJZ@04okS200?oei@00ooXG003oo@]00?oo1000oom2003ooXE00?olc@00ooWH003
omR@00?oakl00on1]004ocjP00?o1hd00ol0NR03o`1X>`?o05Q:0ol0@dT3o`0Z?@?o01Xb0ol042X3
o`098`?o00HO0ol011`4o`026PKo008I0ol00aX3o`036`?o00@L0ol01Ah3o`067`?o00HP2Ol01b04
o`0680?o00DO0ol01Ad3o`0470?o00<K0ol00QX3o`026@?o008J0ol011`3o`067`?o00/U1Oooool3
o`00007ooooo0009ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`?oN;400omV[003oe:V00?o?Z000ol/VP03oaRC00?o1hd00ol0Q`D3o`23
3P?o07lE0ol0OA/4o`1k7P?o07XO0ol0Nah3o`1l6`?o07lF0ol0P`h3o`2810?o2Hd00olKU003oc6L
00?oCJD00om][P04oi>i00?o_/<00oo>[@03omR@00?ohW000oo[D003oo<c00?onA/00oom3003ooh7
00?oo0l00oog9004oni600?ohW400ooBX003ok;000?oHZ/00olKU003o`1m6P?o06Dn0ol0Cdh3o`0Y
?0?o018[1?l01b06o`026P?o00LP0ol04b`3o`0]?P?o05E;0ol0Kc43o`>;00?oE:L00oni`P03omV=
00Coje000ooh8003ood:00?ona800oob>003on5b00?oc;<00omi/P03oafE00?o07PS0ol0G4H3o`0g
@`Co01H_0ol02243o`036P?o008J0ol01b43o`0D;P?o03500ol0EdX3o`1`;`?o18/00om>Y@04ojVn
00?oe9d00ooUI@03oo<e00?ona@00oon2003oo`@00?omB/00ooZE003omb300?oc;800onI^P04oe>W
00?o6I@00ol0PA83o`1_<@?o05m40ol0D4h3o`0f@`?o028h0ol05Rl3o`0=:0?o00PR0ol01Ah4o`03
6`?o008J1_l00QT3o`026P?o00<J0ol00a/6o`0470Wo00@M1?l011`3o`036`?o00<J0ol00QX6o`02
6@?o00<J0ol011`3o`067`?o00XU0ol04R`7ooooo`7o00000Oooool000Kooooo00Go0000oooooooo
ooooooooo`000007ooooo`Co00001oooool00ol0003oooooooooo`05ooooo`?oN;400omV[003oe:V
00?o?Z000ol/VP03oaRC00?o1hd00ol0Q`D3o`233P?o07lE0ol0OA/4o`1k7P?o07XO0ol0Nah3o`1l
6`?o07lF0ol0P`h3o`2810?o2Hd00olKU003oc6L00?oCJD00om][P04oi>i00?o_/<00oo>[@03omR@
00?ohW000oo[D003oo<c00?onA/00oom3003ooh700?oo0l00oog9004oni600?ohW400ooBX003ok;0
00?oHZ/00olKU003o`1m6P?o06Dn0ol0Cdh3o`0Y?0?o018[1?l01b06o`026P?o00LP0ol04b`3o`0]
?P?o05E;0ol0Kc43o`>;00?oE:L00oni`P03omV=00Coje000ooh8003ood:00?ona800oob>003on5b
00?oc;<00omi/P03oafE00?o07PS0ol0G4H3o`0g@`Co01H_0ol02243o`036P?o008J0ol01b43o`0D
;P?o03500ol0EdX3o`1`;`?o18/00om>Y@04ojVn00?oe9d00ooUI@03oo<e00?ona@00oon2003oo`@
00?omB/00ooZE003omb300?oc;800onI^P04oe>W00?o6I@00ol0PA83o`1_<@?o05m40ol0D4h3o`0f
@`?o028h0ol05Rl3o`0=:0?o00PR0ol01Ah4o`036`?o008J1_l00QT3o`026P?o00<J0ol00a/6o`04
70Wo00@M1?l011`3o`036`?o00<J0ol00QX6o`026@?o00<J0ol011`3o`067`?o00XU0ol04R`7oooo
o`7o00000Oooool000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01Oooool3ogRa00?oIZ`00omBYP03ocjP00?o;9X00olHT`03o`N=
00?o08L50ol0P`h3o`1o5@?o07dK1?l0Nah3o`1j7`?o07/N0ol0O1/3o`1o5P?o08<>0ol0R0@3o`V=
00?o6i@00olaW003odfU00?oKJh01?nC^@03okk300?ocZd00ooHT003on9`00?oje000ooc<`03ooTK
00?oo@`00oon1`03oo`?00?omb@01?o^AP03on9a00?odZ000onb`003of:[00?o6i@00ol0OAX3o`1U
?P?o04m>0ol0:C`3o`0B:`Co00LP1_l00QX3o`0780?o01</0ol0;Ch3o`1EB`?o06la0ol3R`03oeBW
00?o^L800ooIS@04on]@00?on2000oom2P03oo/B00?olSP00ooQLP03olbc00?oNK800olMU@03o`1h
8`?o05a60ol0=d<4o`0F;`?o00PQ0ol00aX3o`026P?o00LQ0ol052h3o`0a@0?o05M:0ol0L2l3o`B;
00?oCZD01?nY_P03omBM00?oiFD00ooc=@03oo/D00?ooPP00ool4003ooD[00?ojU@00ooLP`03olbb
00?oVKX01?mCY`03oaVD00?o084B0ol0Kc43o`1OA0?o051>0ol0=T<3o`0R>0?o01H_0ol03BP3o`08
8P?o00DN1?l00a/3o`026PKo008I0ol00QX3o`036P?o00<K1_l011`9o`047@Co00@L0ol00a/3o`03
6P?o008J1_l00QT3o`036P?o00@L0ol01Ql3o`0:9@?o018/1oooool1o`00007ooooo0007ooooo`?o
00002?ooool5o`0000Kooooo00?o0000ooooooooool01Oooool3oi^j00?oS;L00omk/P03ofR]00?o
EJP00olnX003ob^J00?o79@00ol@T003o`R=00?o08X01?l0R0@3o`271P?o08L50ol0R@43o`>;00?o
38h00olHT`03obNI00?o>Yl00omBY`03ofn_00?oTKP01?nh`@03ol^d00?oeIT00ooON`03onQM00?o
l4000oof9P03oo/B00?ooPP00oom2003ooXE00?om2l01?oZD`03omio00?ocJh00onK^`03odjU00?o
3Hl00ol0N2@3o`1Q@P?o04M;0ol08cP3o`0?:@Co00HO0ol00QX3o`036P?o00PQ0ol05Bh3o`0a@0?o
05M:0ol0LBh3o`R=00?oFZT00ono``03omZ:00Cok4d00ooh7P03ood900?ona<00oob>@03on5b00?o
c;800omj/P03oanF00?o07TR0ol0GDH3o`0iA0Co01P`0ol02283o`036P?o008J0ol01R03o`0B;0?o
02dn0ol0E4`3o`1]=0?o08L40om2XP04oiZj00?od:H00ooSK`03oo0m00?onAT00oom2@03oo`<00?o
mb<00oo^B003on5d00?odJ<00onb`004of^^00?o;Y/00ol0R083o`1g9@?o06Hm0ol0EdX3o`14BP?o
02dn0ol07C@3o`0C;0?o00`V0ol02244o`057P?o00<L0ol00aX<o`026@?o008J3?l00aX4o`026PWo
008I0ol00QX3o`036`?o00@M0ol01b03o`0;9@?o018/0ol07CD7ooooo`7o00000Oooool001gooooo
00?o0000ooooooooool01Oooool3oi^j00?oS;L00omk/P03ofR]00?oEJP00olnX003ob^J00?o79@0
0ol@T003o`R=00?o08X01?l0R0@3o`271P?o08L50ol0R@43o`>;00?o38h00olHT`03obNI00?o>Yl0
0omBY`03ofn_00?oTKP01?nh`@03ol^d00?oeIT00ooON`03onQM00?ol4000oof9P03oo/B00?ooPP0
0oom2003ooXE00?om2l01?oZD`03omio00?ocJh00onK^`03odjU00?o3Hl00ol0N2@3o`1Q@P?o04M;
0ol08cP3o`0?:@Co00HO0ol00QX3o`036P?o00PQ0ol05Bh3o`0a@0?o05M:0ol0LBh3o`R=00?oFZT0
0ono``03omZ:00Cok4d00ooh7P03ood900?ona<00oob>@03on5b00?oc;800omj/P03oanF00?o07TR
0ol0GDH3o`0iA0Co01P`0ol02283o`036P?o008J0ol01R03o`0B;0?o02dn0ol0E4`3o`1]=0?o08L4
0om2XP04oiZj00?od:H00ooSK`03oo0m00?onAT00oom2@03oo`<00?omb<00oo^B003on5d00?odJ<0
0onb`004of^^00?o;Y/00ol0R083o`1g9@?o06Hm0ol0EdX3o`14BP?o02dn0ol07C@3o`0C;0?o00`V
0ol02244o`057P?o00<L0ol00aX<o`026@?o008J3?l00aX4o`026PWo008I0ol00QX3o`036`?o00@M
0ol01b03o`0;9@?o018/0ol07CD7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Ooo
ool3oi^j00?oS;L00omk/P03ofR]00?oEJP00olnX003ob^J00?o79@00ol@T003o`R=00?o08X01?l0
R0@3o`271P?o08L50ol0R@43o`>;00?o38h00olHT`03obNI00?o>Yl00omBY`03ofn_00?oTKP01?nh
`@03ol^d00?oeIT00ooON`03onQM00?ol4000oof9P03oo/B00?ooPP00oom2003ooXE00?om2l01?oZ
D`03omio00?ocJh00onK^`03odjU00?o3Hl00ol0N2@3o`1Q@P?o04M;0ol08cP3o`0?:@Co00HO0ol0
0QX3o`036P?o00PQ0ol05Bh3o`0a@0?o05M:0ol0LBh3o`R=00?oFZT00ono``03omZ:00Cok4d00ooh
7P03ood900?ona<00oob>@03on5b00?oc;800omj/P03oanF00?o07TR0ol0GDH3o`0iA0Co01P`0ol0
2283o`036P?o008J0ol01R03o`0B;0?o02dn0ol0E4`3o`1]=0?o08L40om2XP04oiZj00?od:H00ooS
K`03oo0m00?onAT00oom2@03oo`<00?omb<00oo^B003on5d00?odJ<00onb`004of^^00?o;Y/00ol0
R083o`1g9@?o06Hm0ol0EdX3o`14BP?o02dn0ol07C@3o`0C;0?o00`V0ol02244o`057P?o00<L0ol0
0aX<o`026@?o008J3?l00aX4o`026PWo008I0ol00QX3o`036`?o00@M0ol01b03o`0;9@?o018/0ol0
7CD7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3okc300?o]<000onV_@03
oiFi00?oQ;D00om[[P03oeJX00?oAJ800olgWP03obfK00?o99L01?lMU@06oaZD00?o7YD00olTU`03
obfK00?o>Yl00om:Y003oenZ00?oN;400onF^@03okS200Cob[H00ooCWP03omb300?oiFH00oo]BP03
oo@`00?onAX00oom3003ooh600?oo@`00ooh7P03oo4k00CoiV800ooISP03olRl00?oQ;D00olkW`03
o`2900?o078]0ol0G4L3o`0nA`?o01he0ol03BL4o`057@?o008I0ol00a/3o`098`?o01L`0ol0=T<3
o`1JB0?o07@Z0ol>S`03of6[00?oaL<00ooKQP04one:00?onAd00oom2@03oo/C00?olCT00ooQL`03
olbb00?oO;800olQUP03o`1j80?o05i50ol0>dH4o`0I<@?o00TS0ol00a/3o`026@?o00HO0ol04B/3
o`0Y?0?o055=0ol0JST3o`233@?o=Ih01?n:]P03olf`00?oggT00oo^A`03ooPP00?oo@/00oom2@03
ooTK00?olC`00ooUIP03omND00?oa/001?n5]@03odFS00?o4I000ol0OaH3o`1^<P?o05m40ol0DDd3
o`0jA@?o02Lk0ol06S83o`0A:`?o00/V1?l02243o`057P?o00@L0ol00a/3o`026Qco008I0ol00QX3
o`036P?o00@L0ol01Ah3o`088P?o00`V0ol04bd3o`0N=@?o02lo1oooool1o`00007ooooo000Moooo
o`03o`000?oooooooooo00Gooooo0onl``03okC000?oY[d00onE^@03ohBe00?oJjh00omFZ003odFR
00?o=ih00ol]V`03obBG00Co7ID01_lJU003oajE00?o99L00ol]V`03ocZO00?oBZ@00omOZP03ogRa
00?oU[T00onh`P04olZf00?odih00ooLP`03onEV00?okDX00ood<003ooTJ00?oo@`00oon1P03ood<
00?on1h00ooa>`04onIR00?ofHh00oo8_003ohBe00?o>il00ol0R@03o`1b;@?o05a70ol0?TL3o`0N
=@?o00dW1?l01Ad3o`026@?o00<K0ol02B<3o`0G<0?o03I30ol0FTP3o`1d:P?o3Xl00omQZ`03olG3
00?ofhH01?o]BP03ooTM00?oo@T00ook4`03oo4i00?ohG<00oo</P03ogbb00?o8IH00ol0NR03o`1N
A@?o03]61?l06C43o`098`?o00<K0ol00QT3o`067`?o014[0ol0:C`3o`1AC@?o06Xi0ol0P`d3ocFN
00CoR[H00oo=/003ommi00?okTL00ooh8003ood;00?oo@T00ooi6`03oo4l00?oiFH00ooGU003olK0
00CoQKD00om5X`03oa6@00?o07lF0ol0KS83o`1OA0?o055=0ol0>TD3o`0W>`?o01Xb0ol04B/3o`0;
9PCo00PQ0ol01Ah3o`0470?o00<K0ol00QXLo`026@?o008J0ol00aX3o`0470?o00DN0ol02283o`0<
9P?o01<]0ol07SD3o`0_?`Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o
_<<00ond`003ojJm00?oUKT00on4]@03of^^00?oEZP00om5XP03ocNN00?o;I/00olTU`04oafE00Ko
6Y@00olNU@03obBG00?o;I/00oljW`03odZT00?oGjX00omh/@03oiJi00?o^<801?o:]P03om>N00?o
g8<00ooUIP03one:00?om3000ooi6P03ood<00?ooPH00oom3003ooPN00?olC/01?oVHP03omV>00?o
b;`00on4]@03oc^O00?o08T00ol0LRd3o`1LA`?o03i70ol07SD3o`0=9`Co00DM0ol00QT3o`036`?o
00TS0ol05c03o`0f@`?o05Y80ol0M2X3o`j?00?oHJ/00oo5``03om^600CokDX00ooi7@03ood900?o
na<00ooa>@03on5c00?oc;800oml/P03ob6F00?o07XP0ol0GTD3o`0kAPCo01Ta0ol02B<3o`036`?o
008I0ol01Ql3o`0A:`?o02Tl0ol0DDd3o`1Z>@?o08<=0oleWP04ohZf00?ocK000ooON@03oni700?o
n2000oom2`03ood900?onA/00ooa?003onEV00?oei@00oo6`004ohFe00?oAJ<00olAT003o`1o5P?o
06hb0ol0Gd@3o`1AC@?o03Y50ol09c/3o`0J<P?o014[0ol02bH4o`088@?o00DN0ol011`3o`036`?o
008J7?l00QT3o`026P?o00<J0ol011`3o`057P?o00PR0ol032H3o`0C;@?o01he0ol0;cl7ooooo`7o
00000Oooool001gooooo00?o0000ooooooooool01Oooool6olVi00?oakd00oo5a003okO100?oW[/0
0on7]@03ogF`00?oIJ`00omJZ@03odnV00CoAj<00om3XP03od:R00?oAJ<00om;Y003oeBW00?oHZ/0
0omc/003ohRf00?oX[`00oo0``03ol^d00Codih00ooKQP03on=/00?oje800oob>003ooLR00?ona40
0oon1`03ooh800?ona<00oof:@03one900CohW800ooCWP03ok[200?oKJh00olYV@03o`233P?o06`e
0ol0EdX3o`0f@`?o01Xb0ol02RD4o`0470?o008I0ol011`3o`0:90?o01Xb0ol0>dD3o`1LAP?o07HV
0olETP03ofV]00?oakl00ooLPP04oni700?onA`00oom2@03oo/D00?olCX00ooQL`03olbb00?oOK<0
0olSU`03o`1k7P?o05m40ol0?TL4o`0J<P?o00XT0ol00a/3o`026@?o00DN0ol03bT3o`0U>@?o04i>
0ol0ISd3o`1o5@?o:IT01?mj/P03olRk00?og8D00oo[D@03ooHW00?oo0h00oon2003oo/D00?om300
0ooYE`03omb400?ocK001?nQ_003oenZ00?o:9T00ol0Q`@3o`1g9@?o06Pk0ol0FTP3o`1<C@?o03E2
0ol093T3o`0I<@?o014[1?l032H3o`088P?o00HO0ol01Ad3o`0470?o00<K0ol00aX?o`026PCo00<J
0ol00a/3o`0470?o00DN0ol01b03o`0:90?o00hY0ol05Rl3o`0Q=`?o03910ol0BT`7ooooo`7o0000
0Oooool001gooooo00?o0000ooooooooool01Oooool6olVi00?oakd00oo5a003okO100?oW[/00on7
]@03ogF`00?oIJ`00omJZ@03odnV00CoAj<00om3XP03od:R00?oAJ<00om;Y003oeBW00?oHZ/00omc
/003ohRf00?oX[`00oo0``03ol^d00Codih00ooKQP03on=/00?oje800oob>003ooLR00?ona400oon
1`03ooh800?ona<00oof:@03one900CohW800ooCWP03ok[200?oKJh00olYV@03o`233P?o06`e0ol0
EdX3o`0f@`?o01Xb0ol02RD4o`0470?o008I0ol011`3o`0:90?o01Xb0ol0>dD3o`1LAP?o07HV0olE
TP03ofV]00?oakl00ooLPP04oni700?onA`00oom2@03oo/D00?olCX00ooQL`03olbb00?oOK<00olS
U`03o`1k7P?o05m40ol0?TL4o`0J<P?o00XT0ol00a/3o`026@?o00DN0ol03bT3o`0U>@?o04i>0ol0
ISd3o`1o5@?o:IT01?mj/P03olRk00?og8D00oo[D@03ooHW00?oo0h00oon2003oo/D00?om3000ooY
E`03omb400?ocK001?nQ_003oenZ00?o:9T00ol0Q`@3o`1g9@?o06Pk0ol0FTP3o`1<C@?o03E20ol0
93T3o`0I<@?o014[1?l032H3o`088P?o00HO0ol01Ad3o`0470?o00<K0ol00aX?o`026PCo00<J0ol0
0a/3o`0470?o00DN0ol01b03o`0:90?o00hY0ol05Rl3o`0Q=`?o03910ol0BT`7ooooo`7o00000Ooo
ool001gooooo00?o0000ooooooooool01Oooool6olVi00?oakd00oo5a003okO100?oW[/00on7]@03
ogF`00?oIJ`00omJZ@03odnV00CoAj<00om3XP03od:R00?oAJ<00om;Y003oeBW00?oHZ/00omc/003
ohRf00?oX[`00oo0``03ol^d00Codih00ooKQP03on=/00?oje800oob>003ooLR00?ona400oon1`03
ooh800?ona<00oof:@03one900CohW800ooCWP03ok[200?oKJh00olYV@03o`233P?o06`e0ol0EdX3
o`0f@`?o01Xb0ol02RD4o`0470?o008I0ol011`3o`0:90?o01Xb0ol0>dD3o`1LAP?o07HV0olETP03
ofV]00?oakl00ooLPP04oni700?onA`00oom2@03oo/D00?olCX00ooQL`03olbb00?oOK<00olSU`03
o`1k7P?o05m40ol0?TL4o`0J<P?o00XT0ol00a/3o`026@?o00DN0ol03bT3o`0U>@?o04i>0ol0ISd3
o`1o5@?o:IT01?mj/P03olRk00?og8D00oo[D@03ooHW00?oo0h00oon2003oo/D00?om3000ooYE`03
omb400?ocK001?nQ_003oenZ00?o:9T00ol0Q`@3o`1g9@?o06Pk0ol0FTP3o`1<C@?o03E20ol093T3
o`0I<@?o014[1?l032H3o`088P?o00HO0ol01Ad3o`0470?o00<K0ol00aX?o`026PCo00<J0ol00a/3
o`0470?o00DN0ol01b03o`0:90?o00hY0ol05Rl3o`0Q=`?o03910ol0BT`7ooooo`7o00000Oooool0
01gooooo0_l00006ooooo`?ocZ`00oo@Y`03om2V00?ocjX00oo=[`03olRl00?o_/<00onZ_P03oiZj
00?oS[L00on1]004ogRa00?oL[000oma[`03og>`00?oNK800on2]003ohnh00?oXK`00onf`@03olNn
00?ocZh00ooDV`04omb500?ohfh00ooZE@03oo0m00?omRP00ooj5P03ood:00?ooPH00oom3003ooTL
00?olSH00ooYFP04omb300?ocJl00onO^`03oeJX00?o5Y800ol0O1/3o`1V?0?o059=0ol0;Sl3o`0E
;`?o00TS1?l00a/3o`026@?o00@M0ol032H3o`0N=@?o04180ol0Gd@3o`1i8@?o79@00om`[`03olRk
00?ogWl01?o^A@03ooTJ00?oo@P00ook5003oo4j00?ohG<00oo</@03ognc00?o9IP00ol0O1`3o`1P
@`?o04181?l073@3o`0:9@?o00<L0ol00QT3o`057@?o00dW0ol08CL3o`17B`?o06910ol0Nad3oabE
00CoJZd00oo3a003omRA00?oj5`00ood<003oo/C00?ooPL00ool3P03ooHU00?okDT00ooQL`03om>O
00Co`<<00oml/`03od6Q00?o4I000ol0P1@3o`1a;`?o06=00ol0ET/3o`16B`?o03910ol08cP3o`0I
<PCo018/0ol03BL3o`0:90?o00LQ0ol01Ql3o`057P?o00@M3ol011`4o`057@?o00HO0ol01b03o`09
8`?o00dW0ol04R`3o`0J<P?o02Dj0ol0=T<3o`1>CP?o05]71_ooool2o`00007ooooo000Mooooo`03
o`000?oooooooooo00Gooooo0oo>[003om2W00?od:H00oo?ZP03olf_00?ob;`00onn``03ojZn00?o
V[X00on>]`03oh6d00CoN;400omb/003og6_00?oLk000omi/P03oh:d00?oSkP00onQ_003okK100?o
akh00oo>[P03omBK00Cog8D00ooSKP03onYE00?ol3d00oof:003ooXF00?oo@X00oon1P03ood<00?o
nA`00oob=P03onUJ00Cog8<00oo=[`03oink00?oEZP00olFTP03o`1l6`?o06Hl0ol0DTd3o`0^?`?o
01D_0ol02B<4o`036`?o008I0ol011d3o`0<9P?o01he0ol0@4P3o`1OA0?o07TQ0olLU003og2_00?o
b;/00ooNO`04oni500?onAX00oom2003oo/D00?olCX00ooQL`03olba00?oOk<00olUV003o`1l70?o
06130ol0@4P4o`0L=0?o00XU0ol00a`3o`026@?o00DM0ol03BL3o`0Q=`?o04M;0ol0HT43o`1k7@?o
79D01?mZ[@03ol?400?of9400ooXG003oo@`00?ona<00oon1`03oo`>00?omRD00oo]B@03on5c00?o
dil01?o0``03ogbc00?o@J400olAT003o`2050?o074_0ol0Hd03o`1FB`?o04I;0ol0<T43o`0S>0?o
01Tb1?l04R`3o`0=9`?o00XT0ol01b43o`067`?o00DN0ol011d?o`0470Co00DM0ol01Ql3o`0780?o
00TS0ol03BL3o`0B;0?o01Xb0ol09CX3o`0f@`?o04i>0ol0FdL7ooooo`7o00000Oooool001gooooo
00?o0000ooooooooool01Oooool3olj/00?od:L00oo@YP03olnZ00?ocJl00oo8_003okk300?oZ[h0
0onJ^P03ohjg00?oPK@01?mh/@03og:`00?oLJl00omc/003ogVb00?oP[@00on?^003oj6l00?o]/40
0oo7_P03olj^00?oe9/01?oLQ@03on=^00?ojUD00oo`?@03ooHX00?onQH00oom2P03ooh600?oo@`0
0ooi7003oo8f00?ojEX01?oLP`03olf_00?oWk/00omFZ003oaJB00?o07`K0ol0IS`3o`1BC@?o02ho
0ol05Bl3o`098`Co00<K0ol00QT3o`047@?o00`V0ol07SD3o`10B0?o05m40ol0NB43oabD00?oL:l0
0oo8^`03omio00CokTD00ooi6P03ood800?ona@00ooa>P03on5c00?oc;400omo/`03obFH00?o07`L
0ol0H4<3o`10B0Co01`d0ol02RD3o`0370?o008I0ol01Ad3o`0=9`?o024g0ol0Ad/3o`1R@@?o07/M
0olLU@04ofZ]00?o`l@00ooHT@03onQL00?om3000ook4`03ooh700?oo0h00oof9@03one900?ohG<0
0ooCW`04ol3300?oO;<00om1X@03oa6@00?o080D0ol0LBl3o`1S@0?o05I;0ol0AT/3o`0b@@?o02<h
0ol06C84o`0B;0?o00dW0ol02R@3o`078@?o00HO0ol01Ah3o`047@oo00@L1?l01Ad3o`067`?o00LP
0ol02B<3o`0=9`?o018/0ol06S83o`0U>P?o03I30ol0CTh3o`1KA`Oooooo0Ol00001ooooo`007Ooo
ool00ol0003oooooooooo`05ooooo`?odJD00ooEV@03omNB00?of9000ooHT@03omBM00?od:P00oo<
/`03olRl00?oaL800onj`P04ojno00?oZ;h00onV_@03ojRn00?o[Kl00one`@03ol;400?ob;d00oo<
/@03om:S00?oei800ooMO`04onA[00?ojUD00oo`?`03ooD[00?onAT00ool3003ooh600?ooPP00ook
4`03ooHX00?okTH00ooTJ`04omJE00?oakl00on4]@03ocnQ00?o1H/00ol0MRL3o`1P@`?o04Y<0ol0
9cX3o`0B:`?o00LQ1?l00aX3o`026@?o00DN0ol03RP3o`0Q=`?o04M;0ol0HT43o`1l6`?o8iL00omi
/P03olZg00?oggX01?o_@P03ooXI00?oo@P00ook5@03oo4k00?ohG<00oo</@03oh2d00?o9iP00ol0
OA/3o`1R@@?o04=91?l07SD3o`0;9@?o00@L0ol00QT3o`0470?o00`V0ol07SD3o`10B0?o05i40ol0
MbD3oa2@00CoFJT00on``003omBM00?oi6T00ooa>`03ooTI00?oo@T00oom2P03ooTL00?olCX00ooV
HP03omV<00CobkD00onL^`03oenZ00?o:iX00ol1RP03o`1k7P?o06`e0ol0Gd@3o`1DC0?o04A:0ol0
<T43o`0U>@Co01/c0ol05Bh3o`0@:P?o00`W0ol02R@3o`088P?o00LQ0ol01b06o`0680?o00LP0ol0
1b44o`098`?o00XU0ol03BL3o`0A:`?o01L`0ol083H3o`0]?P?o03i70ol0DTd3o`1NA@?o06/f1ooo
ool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ooAY@03omFI00?oei800ooHT003
omRA00?oe9d00oo@Z003olbc00?ob;`00oo5`P03ok[200Co[kl00onX_P03ojJm00?oZ;h00on]_`03
okG100?o`/@00oo8_@03olba00?odZ<00ooGTP03omeo00Coi6/00ooZE@03oo0o00?omB/00ooi6@03
oo`<00?ooPH00oon2003oo/C00?omRP00oo^AP03onA[00CoeYD00oo7_`03ohBe00?o?j400ol5R`03
o`1f9`?o06130ol0BT`3o`0W>P?o018[0ol01b44o`036P?o008I0ol01Ah3o`0>:0?o024g0ol0Ad/3
o`1R@@?o07`K0olSU`03ogVb00?ob[L00ooONP04onm200?onQT00oom2003oo/E00?olC/00ooQL`03
olba00?oP;@00olWV003o`1m6`?o06910ol0@dT4o`0N=@?o00/U0ol011`3o`026@?o00@L0ol032H3
o`0N=@?o04180ol0GT@3o`1g9@?o49001?mIZ@03ok3000?oe9d00ooTJ@03oo4k00?onAT00oom2@03
ood:00?onA`00ooa>P03onIR00?ofH`01?o;]@03oibk00?oGjX00ol[VP03o`6:00?o07/N0ol0K3D3
o`1OA0?o05A<0ol0A4X3o`0b@@?o02Di1?l06c<3o`0E;P?o010Z0ol032L3o`0:90?o00PR0ol01b43
o`0780Ko00HP0ol01b03o`078@Co00TS0ol02RD3o`0=9`?o014[0ol05c03o`0P=P?o02dn0ol0?TL3
o`1BC@?o05i50ol0JcH7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3om6U
00?oeIT00ooGTP03omR@00?of9400ooDW@03om2X00?oc;<00oo8_003olG200?o^/801?n__`03ojRn
00?oY[d00onX_P03ojfo00?o]L400oo2a003olRm00?oc;400ooBX`03omNB00?ogGl01?oTJ`03onYE
00?ol3l00ooe:`03ooTI00?oo0`00oon1P03ooh800?ona<00oof:003oni600?oi6/01?oFU@03olNo
00?oQ;D00oloX@03o`F;00?o07HW0ol0H4<3o`1:C0?o02Lj0ol04R/3o`078@Co00<J0ol00QT3o`05
7P?o00hX0ol08CL3o`17B`?o06910ol0O1/3ob>G00?oNK800oo:]`03ommj00Cokd800ooj6@03ood8
00?onaD00ooa>`03on5c00?oc;400on0]003obNH00?o07dK0ol0HT43o`13B@Co01he0ol02bD3o`04
70?o008I0ol011`3o`0<9P?o01he0ol0@4P3o`1NA0?o07LU0ol@T004oeVY00?o/<000ooDW@03onAY
00?olC/00ooi6@03ood900?oo@X00ooi7003oo4j00?oiV800ooIS004ol^e00?oW;/00omOZP03ob^J
00?o0HX00ol0Nah3o`1/=@?o05m40ol0E4`3o`14BP?o03910ol09CT4o`0K<`?o01D^0ol042X3o`0<
9`?o00XT0ol02283o`078@?o00LP1_l01R03o`0780?o00LQ1?l02B<3o`0:9@?o00dW0ol04B/3o`0G
<0?o020f0ol0;Ch3o`0nA`?o059=0ol0GTD3o`1[=POooooo0Ol00001ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`?odJ@00ooHT@03omb300?oggX00ooQM@03omin00?ofhL00ooHT@03omFI00?o
dj000oo@Z004olf_00?obk@01_o;]@03olbc00?ocJh00oo@Z003om>O00?oei<00ooLQ@03on5e00?o
iV@01?o[D@03oo0n00?omB/00ooi6`03oo`>00?ooPL00oon1P03oo`>00?on1h00oob=`03onUH00?o
gWl01?o@Z003ojno00?oJ:d00olYV@03o`242`?o06la0ol0FTP3o`0nA`?o020f0ol03RP3o`067`Oo
008J0ol01Ql3o`0@:P?o02Hj0ol0CTh3o`1V?@?o07lE0ol[VP03oh:d00?oc;800ooPMP04oo0o00?o
nQL00oon2003ooXE00?olC`00ooQL`03olf`00?oP[@00olYV@03o`1n6@?o06=00ol0AT/4o`0P=P?o
00`W0ol011d3o`026@?o00@L0ol02R@3o`0J<P?o03Y50ol0FTP3o`1b;0?o18/01?m9Y003oibk00?o
cjT00ooPMP03oni600?omb400oom3003ooh700?ona<00ooe;@03on]A00?oggT01?oBXP03okk300?o
Ok<00om8Y003oaZD00?o08D90ol0MbD3o`1Z>0?o05i50ol0Dd`3o`15BP?o03E21?l0:C`3o`0P=P?o
01Ta0ol052h3o`0A:`?o00lY0ol03BL9o`0<9P?o00dW0ol03RP4o`0@:P?o01<]0ol06343o`0O=P?o
02Tl0ol0=T<3o`1:C0?o05I:0ol0HT43o`1_<@?o07dJ1oooool1o`00007ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo0ooAY003omRA00?og8<00ooONP03on5e00?ogWh00ooKQ`03omRA00?oeIT0
0ooCX003om2X00CocJl00oo;]006ol^e00?oc;<00oo=[P03om2X00?odil00ooGT`03omb500?ohGD0
0ooVI004on]A00?ol3h00ooe:`03ooTK00?oo0h00oon1`03ooh600?oo0h00ooh7P03oo8g00?ojEP0
0ooNO`04om2X00?o[kl00omX[@03obVI00?o08@;0ol0Kc43o`1JB0?o03i70ol083H3o`0>:0?o00HO
1ol00QX3o`067`?o010Z0ol09SX3o`1>CP?o06Hm0ol0OaD3ob^J00?oP[@00oo</P03on1f00Col3l0
0ooj5`03ooh800?onQD00ooa?003on5c00?ocK000on2]003obVI00?o07hI0ol0Hd03o`16B`Co020f
0ol032L3o`047@?o008I0ol011`3o`0:90?o01Xb0ol0>TD3o`1JB0?o078/0ol4R`04odVT00?oW;/0
0oo?Z@03on1f00?okTH00oog8@03ood<00?ooPL00ook4`03ooD]00?oje400ooON@04om:R00?o_/<0
0omo/`03odRT00?o6Y@00ol0Q@T3o`1g9@?o06Xh0ol0GTD3o`1CC0?o04E:0ol0=D84o`0Y?0?o020f
0ol06C43o`0D;P?o014[0ol03bT3o`0=9`Wo00`V0ol03BL3o`0>:0Co010Z0ol04bd3o`0H<@?o01lf
0ol0:C`3o`0f@`?o04Y<0ol0ETX3o`1R@@?o06la0ol0OAX7ooooo`7o00000Oooool001gooooo00?o
0000ooooooooool01Oooool3om6T00?of9400ooLP`03ommj00?ohGD00ooNOP03om^700?of9400ooE
V@03om>P00?od:P01?o=[`03ol^d00KobkD00oo</`03olf^00?od:P00ooCW`03omNC00?og8D00ooQ
M@03onIT00Coje400oo`?P03ooD[00?onA/00ool3P03ooh700?ooPH00ool3P03ooPN00?olSL00ooY
F003omio00Cod:P00on__`03ofR]00?o:IT00ol0Q0/3o`1_<@?o05Y80ol0?TL3o`0P=P?o00hX0ol0
1Ql7o`026P?o00HO0ol042X3o`0V>P?o04i>0ol0ISd3o`1o5@?o:iX00on2]003olbb00?oh7H01?o`
?`03ooXG00?ooPP00ooj5@03oo4l00?ohG<00oo=/003oh:d00?o:IT00ol0OQT3o`1S@0?o04I;1?l0
83H3o`0<9`?o00@M0ol00QT3o`0470?o00XT0ol06S83o`0jA@?o05Y80ol0LR`3o`B;00CoBJ@00onL
^`03olnY00?oh7H00oo^AP03ooLQ00?oo@`00oon1`03oo/C00?omBd00oo[D@03ommi00CodZ800onn
``03ognc00?oB:@00olJU003o`252@?o07LU0ol0JSP3o`1NA@?o05=<0ol0ADX3o`0e@PCo02Tl0ol0
83H3o`0I<@?o01@^0ol04B/3o`0?:@?o00dW2Ol032H3o`0=9`?o00hX1?l042X3o`0C;@?o01Pa0ol0
7cH3o`0Y?0?o03I30ol0BT`3o`1FBP?o06910ol0Kc43o`1m6POooooo0Ol00001ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`?ocZ`00ooHT@03omml00?oi6/00ooWG`03onIR00?oi6P00ooSK`03
on5e00?ogg/00ooLP`04omZ;00?of9001_oGTP03omR@00?ofHd00ooKQ`03omin00?ohG<00ooUI`03
onUH00?okDT01?ob>003ooHY00?onAX00ool3`03ooh700?ooPD00oom2P03ooXG00?omB`00oo]B@03
on=/00?oei<01?o8^`03oi2h00?oCJD00olCT@03o`1m6P?o06Pj0ol0E4`3o`0d@P?o01Xb0ol02bH3
o`047@Co008I0ol00aX3o`078@?o01<]0ol0:cd3o`1AC@?o06Ti0ol0P`l3oc>M00?oRkH00oo>[@03
on9b00ColC/00ooj5@03ooh800?onQH00ooa?003on5c00?ocK000on4]@03ob^J00?o07lF0ol0I3l3
o`19C0Co028g0ol03BP3o`057@?o008I0ol00a/3o`098`?o01L`0ol0<d83o`1FBP?o06hc0ol0QPL4
ocRN00?oQkD00oo:]P03omb400?oje<00ooe:`03oo/A00?ooPL00ool3@03ooPQ00?ol4000ooUIP04
omV>00?obk@00onS_003ofZ]00?o>9h00ol?T003o`2240?o07DX0ol0JCT3o`1NA@?o05E;0ol0BTd4
o`0kA@?o03100ol09c/3o`0P=`?o01`c0ol06C43o`0F;`?o01D_0ol05Bh3o`0E;`?o01L`0ol06C84
o`0M=0?o02<h0ol0:Sd3o`0e@P?o04A:0ol0DTd3o`1MAP?o06Pk0ol0M2T3o`214@?o3Xl01oooool1
o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0oo>[003omRA00?ogg`00ooTJ`03onMO
00?oiV800ooTJ003on=_00?ohGD00ooON`03omb300CofX/00ooHT006omNB00?of9000ooIS@03om^7
00?ogWh00ooQL`03onEW00?ojEP00oo]B@04oo8h00?omRT00ooi6P03oo`?00?ooPL00oon1@03ood:
00?onQL00ooe;003one900?ohf`00ooGT`04olRk00?oT;P00om=Y@03oa>A00?o07dJ0ol0J3X3o`1D
C0?o03A20ol06S83o`0;9P?o00@M1?l00QT3o`036P?o00LQ0ol04bd3o`0[?@?o055=0ol0JCT3o`23
3`?o<id00on;]P03olj]00?ohW801?oa>`03ooXE00?ooPP00ooj5P03oo4l00?ohG<00oo=/003ohBe
00?o:iX00ol0OaH3o`1T?`?o04U<1?l08SL3o`0=:0?o00DM0ol00QT3o`036`?o00TS0ol05c03o`0c
@P?o05I:0ol0KS<3o`261`Co>9h00on7]@03olZf00?og8@00oo[D`03ooD[00?ona400oon1`03oo`=
00?on2400oo`@003onEV00CofHh00oo;]003oj>l00?oJZd00olhWP03o`n@00?o088@0ol0MBP3o`1Y
>@?o05i50ol0ED/3o`1:C@Co03]50ol0<403o`0W>`?o020g0ol073<3o`0I<@?o01H_0ol05Bl3o`0E
;P?o01D_0ol05c03o`0I<PCo01dd0ol08cP3o`0Z?@?o03E20ol0A4X3o`1BC@?o05e60ol0J3/3o`1d
:@?o084A0ol>S`07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3olj/00?o
f9400ooOO003onA[00?oiel00ooVHP03onAX00?ohfl00ooQM@03ommk00?og8<01?oJR`03omR@00Ko
ei800ooHT003omV=00?ofhL00ooNOP03on5c00?oiFL00ooYF003one900ColSP00oof:@03ooTJ00?o
o0l00oon1`03ooh500?oo@X00ooj5`03ooD/00?okDT00ooSK003omNC00Cob;/00on@^003odfU00?o
4i400ol0OAX3o`1X>P?o05A<0ol0=483o`0J<P?o00/V0ol011d4o`026@?o00<J0ol01b43o`0C;@?o
02/m0ol0DDd3o`1Y>@?o08<?0olcW@03oh^f00?ocZd00ooRLP04oo4k00?onQD00oon2003ooXF00?o
lC`00ooQL`03olf`00?oQ;D00ol[VP03o`1o5P?o06@o0ol0BD`4o`0R=`?o00dX0ol01Ad3o`026@?o
00<K0ol02B<3o`0G<0?o03=20ol0ETX3o`1^<`?o08H71?lhWP03ohNe00?ob[H00ooLQ003on]C00?o
mB/00ook4@03ooh700?oo0d00ooh8@03oo1000?oiFH01?oISP03ol^d00?oXk`00omZ[@03ocRN00?o
3i000ol0PQ03o`1e:0?o06Ti0ol0GTD3o`1EB`?o04Y=1?l0>dD3o`0`@0?o02Lk0ol083L3o`0L<`?o
01Ta0ol05Rl3o`0E;`?o01D^0ol05Bl3o`0G<0?o01Tb1?l07C@3o`0S>0?o02Xm0ol0=D83o`14BP?o
059=0ol0GDH3o`1X>`?o07@Y0ol0PA43o`j?00Oooooo0Ol00001ooooo`007Oooool2o`0000Kooooo
0oo8^`03omBK00?ogWh00ooUIP03on]B00Kok4h00oo[D003onYD00?ojEL00ooWGP04onEV00?oi6/0
0ooSK@03on=^00?ohfd00ooTJP03onIU00?oj5d00ooZE003one900?olCd00ood<004ooLS00?onQL0
0ool3@03ooh700?ooPD00oom2@03oo/C00?omRD00oo`?P03onQN00?ogH800oo@Z004okC000?oLJl0
0olcW@03o`2900?o07DX0ol0HD83o`1>CP?o02/m0ol05Bh3o`098`?o00@L1?l00QT3o`036`?o00TS
0ol05Rl3o`0`@0?o05E;0ol0K3D3o`261`?o?:000onE^@03om2X00?ohfd01?ob>003oo/D00?ooPP0
0ooj5P03oo0m00?ohG@00oo=[`03ohJe00?o;Y/00ol0P1@3o`1V?@?o04a=1?l093T3o`0?:@?o00DN
0ol00QT3o`036`?o00PQ0ol052h3o`0]?P?o059=0ol0JCT3o`214PCo:9T00omb/003olG300?oei80
0ooWH@03oo8g00?onQP01_om2003ooXF00?om3000oo[DP04on1h00?odil00oo5`P03ohng00?oFZT0
0ol^V`03o`V=00?o084B0ol0MBP3o`1Z>0?o06520ol0F4T4o`1AC@?o04I:0ol0>dD3o`0b@@?o02`n
0ol0:3/3o`0U>PKo02@i0ol09CT3o`0X>`?o02`m1?l0<T43o`0kA@?o04M;0ol0DTd3o`1JB0?o06@o
0ol0Kc43o`1k7P?o08L40olLU@03od>R00Kooooo0_l00001ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`?ob;/00ooDV`03omin00?oiFH00oo[DP06ona>00?oje000ooZE003onUG00?oieh01?oU
IP03onA[00?ohfd00ooSKP03on=]00?oi6X00ooVI@03onQM00?ojU@00oo]B@03oo4m00?om3001?og
8`03ooXG00?oo0d00oon1`03ooh500?oo@T00ook4`03ooHU00?ol3h00ooXGP03omf200?od:P01?nd
`003og6_00?o<id00ol0R@03o`1e:0?o06520ol0CTh3o`0[?@?o01D^0ol02B<3o`0470Co008I0ol0
0a/3o`098`?o01H_0ol0<403o`1EB`?o06`e0ol0QPL3ocbP00?oUKT00oo@Z003on=]00ColSP00ook
5003ooh800?onQH00oo`?@03on5d00?ocJl00on6]@03objK00?o080D0ol0ISd3o`1<C@Co02@i0ol0
3bT3o`057P?o008I0ol00a/3o`088@?o01@^0ol0;Ch3o`1BC@?o06Ti0ol0PA84obRI00?oL[000oo5
``03omNB00?oif400oob=`03ooXH00Koo@P00ooj5P03oo@`00?oje801?oPN003om>O00?oaL800on?
]`03oeZY00?o;Y/00ol9S@03o`214P?o07DX0ol0JSP3o`1Q@P?o05Q91?l0DDd3o`16BP?o03]50ol0
<T43o`0/?P?o02Pk0ol09CX6o`0T>@?o02Di0ol0:3/3o`0/?@Co03910ol0>dD3o`17B`?o059=0ol0
FTP3o`1T?`?o06la0ol0Nah3o`2710?o79D00om3XP07ooooo`7o00000Oooool001gooooo00?o0000
ooooooooool01Oooool3olRk00?oe9/00ooNOP03onEV00?oje801_o/CP03on]@00?ojU@00ooYE`03
onMN00CoiFH00ooTJ`03on=]00?ohfh00ooSK@03onAZ00?oiVD00ooXG@03onYD00?okDT00ooa?@03
oo@`00Comb<00ooj5`03oo`=00?ooPL00oon1@03ood900?ona<00oof9@03oo0n00?oj5h00ooMPP03
om2X00Co]<000oma[`03oc>M00?o08T00ol0MBP3o`1Q@P?o04i>0ol0:cd3o`0E;P?o00TS0ol011`4
o`026@?o00<K0ol02B<3o`0F;`?o03100ol0ED/3o`1/=@?o08H70ollX003oiFi00?od:P00ooSK@04
oo8h00?ona@00oon2003ooXF00?ol3d00ooQM003olf_00?oQ[D00ol^V`03o`2050?o06Hm0ol0C4d4
o`0T>@?o00lY0ol01Ah3o`026@?o00<K0ol02243o`0D;P?o02dn0ol0DTd3o`1Y>@?o084B1?lXV@03
og:`00?oaL<00ooGTP03onMQ00?olSL00ooj6006ood800?onQH00ood<003on]B00Coh7P00ooCW`03
olG200?oSkL00omJZ@03objK00?o2Hd00ol0PA83o`1e:0?o06Xh0ol0HD83o`1HB@Co055=0ol0ATX3
o`0kA@?o03910ol0;3h3o`0X>`?o02Dj1_l093T3o`0U>@?o02Pk0ol0;3d4o`0b@@?o03]50ol0Ad/3
o`1BC@?o05Y80ol0I3l3o`1_<@?o07/N0ol0Q`@3oabE00?o@j801oooool1o`00007ooooo000Moooo
o`03o`000?oooooooooo00Gooooo0oo8^`03omBK00?ogWh00ooUIP03on]B00Kok4h00oo[D003onYD
00?ojEL00ooWGP04onEV00?oi6/00ooSK@03on=^00?ohfd00ooTJP03onIU00?oj5d00ooZE003one9
00?olCd00ood<004ooLS00?onQL00ool3@03ooh700?ooPD00oom2@03oo/C00?omRD00oo`?P03onQN
00?ogH800oo@Z004okC000?oLJl00olcW@03o`2900?o07DX0ol0HD83o`1>CP?o02/m0ol05Bh3o`09
8`?o00@L1?l00QT3o`036`?o00TS0ol05Rl3o`0`@0?o05E;0ol0K3D3o`261`?o?:000onE^@03om2X
00?ohfd01?ob>003oo/D00?ooPP00ooj5P03oo0m00?ohG@00oo=[`03ohJe00?o;Y/00ol0P1@3o`1V
?@?o04a=1?l093T3o`0?:@?o00DN0ol00QT3o`036`?o00PQ0ol052h3o`0]?P?o059=0ol0JCT3o`21
4PCo:9T00omb/003olG300?oei800ooWH@03oo8g00?onQP01_om2003ooXF00?om3000oo[DP04on1h
00?odil00oo5`P03ohng00?oFZT00ol^V`03o`V=00?o084B0ol0MBP3o`1Z>0?o06520ol0F4T4o`1A
C@?o04I:0ol0>dD3o`0b@@?o02`n0ol0:3/3o`0U>PKo02@i0ol09CT3o`0X>`?o02`m1?l0<T43o`0k
A@?o04M;0ol0DTd3o`1JB0?o06@o0ol0Kc43o`1k7P?o08L40olLU@03od>R00Oooooo0Ol00001oooo
o`007Oooool00ol0003oooooooooo`05ooooo`?o[[l00oo=[P03omZ<00?ohf`00oo[C`03onm400?o
l3d00ooa>P03oo8h00?olSL00ooa?@04onm300?okTL02Oo]BP03oni800?okd@00oo`?P03oo8g00?o
m2h00oog9003ooTK00Cona800oom2`03ooh600?ooPD00oom2003oo/A00?on2400oob=`03onYC00?o
hG@00ooEV003olRm00CoTKP00omBY`03oaZD00?o084C0ol0KC@3o`1JB0?o04180ol08SP3o`0@:P?o
00LP0ol00a/4o`026@?o00@M0ol02bD3o`0J<P?o03M30ol0F4T3o`1`<0?o08T00om6X`03oink00?o
dZ800ooTJ004oo8e00?ona800oon2003ooXG00?ol3h00ooQM003olf_00?oR;H00ol`W003o`214P?o
06Ll0ol0Cdh4o`0W>P?o010Z0ol01Ql3o`026P?o00<J0ol01b03o`0A:`?o02Pk0ol0CTh3o`1T?`?o
07/M1?lHT`03oejZ00?o[[l00ooBX@03on9`00?okd@00oog8P03oo`=00?ooPH00ool3P03ooLR00?o
l4001?oVH`03om^800?ocZ/00ong`@03oh6d00?oDZH00olZV@03o`V=00?o088A0ol0MbD3o`1]=0?o
06Dn1?l0GDD3o`1GBP?o059=0ol0C4d3o`14BP?o03m70ol0?4H3o`0jA@?o03]50ol0?DH3o`11B@?o
04Q<1?l0D4h3o`1EB`?o05a70ol0Hd03o`1]=@?o07LT0ol0P`d3o`f?00?o;i/00omFZ003oh:d00Oo
oooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o[[l00oo=[P03omZ<00?ohf`0
0oo[C`03onm400?ol3d00ooa>P03oo8h00?olSL00ooa?@04onm300?okTL02Oo]BP03oni800?okd@0
0oo`?P03oo8g00?om2h00oog9003ooTK00Cona800oom2`03ooh600?ooPD00oom2003oo/A00?on240
0oob=`03onYC00?ohG@00ooEV003olRm00CoTKP00omBY`03oaZD00?o084C0ol0KC@3o`1JB0?o0418
0ol08SP3o`0@:P?o00LP0ol00a/4o`026@?o00@M0ol02bD3o`0J<P?o03M30ol0F4T3o`1`<0?o08T0
0om6X`03oink00?odZ800ooTJ004oo8e00?ona800oon2003ooXG00?ol3h00ooQM003olf_00?oR;H0
0ol`W003o`214P?o06Ll0ol0Cdh4o`0W>P?o010Z0ol01Ql3o`026P?o00<J0ol01b03o`0A:`?o02Pk
0ol0CTh3o`1T?`?o07/M1?lHT`03oejZ00?o[[l00ooBX@03on9`00?okd@00oog8P03oo`=00?ooPH0
0ool3P03ooLR00?ol4001?oVH`03om^800?ocZ/00ong`@03oh6d00?oDZH00olZV@03o`V=00?o088A
0ol0MbD3o`1]=0?o06Dn1?l0GDD3o`1GBP?o059=0ol0C4d3o`14BP?o03m70ol0?4H3o`0jA@?o03]5
0ol0?DH3o`11B@?o04Q<1?l0D4h3o`1EB`?o05a70ol0Hd03o`1]=@?o07LT0ol0P`d3o`f?00?o;i/0
0omFZ003oh:d00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o[[l00oo=
[P03omZ<00?ohf`00oo[C`03onm400?ol3d00ooa>P03oo8h00?olSL00ooa?@04onm300?okTL02Oo]
BP03oni800?okd@00oo`?P03oo8g00?om2h00oog9003ooTK00Cona800oom2`03ooh600?ooPD00oom
2003oo/A00?on2400oob=`03onYC00?ohG@00ooEV003olRm00CoTKP00omBY`03oaZD00?o084C0ol0
KC@3o`1JB0?o04180ol08SP3o`0@:P?o00LP0ol00a/4o`026@?o00@M0ol02bD3o`0J<P?o03M30ol0
F4T3o`1`<0?o08T00om6X`03oink00?odZ800ooTJ004oo8e00?ona800oon2003ooXG00?ol3h00ooQ
M003olf_00?oR;H00ol`W003o`214P?o06Ll0ol0Cdh4o`0W>P?o010Z0ol01Ql3o`026P?o00<J0ol0
1b03o`0A:`?o02Pk0ol0CTh3o`1T?`?o07/M1?lHT`03oejZ00?o[[l00ooBX@03on9`00?okd@00oog
8P03oo`=00?ooPH00ool3P03ooLR00?ol4001?oVH`03om^800?ocZ/00ong`@03oh6d00?oDZH00olZ
V@03o`V=00?o088A0ol0MbD3o`1]=0?o06Dn1?l0GDD3o`1GBP?o059=0ol0C4d3o`14BP?o03m70ol0
?4H3o`0jA@?o03]50ol0?DH3o`11B@?o04Q<1?l0D4h3o`1EB`?o05a70ol0Hd03o`1]=@?o07LT0ol0
P`d3o`f?00?o;i/00omFZ003oh:d00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05
ooooo`?oOK<00ono``03om:R00?ogWh00ooXFP03oni700?olSP00ood;P03ooHV00?on2000oog8P04
ooHV00?omRT02Ooe:`03ooDZ00?omRL00oog8`03ooPN00?onQP00ook4P03ood<00CooPL00oon1003
ooh500?oo@T00ook4@03ooPP00?olc<00oo/C@03onA[00?ofHd00oo=/003ojbo00CoKZl00oleW@03
o`>;00?o07PS0ol0ICh3o`1CC0?o03A20ol06c<3o`0=9`?o00DN1ol00QX3o`057P?o00dW0ol07cD3
o`0nA`?o05a60ol0M2X3o`R=00?oDJH00onZ_P03omBM00?oiV@01?oc<P03oo/A00?ooPP00ooj6003
oo0n00?ohG@00oo=[P03ohZf00?o<id00ol0PPl3o`1Y>P?o055=1?l0:C`3o`0B;0?o00LP0ol00aX3
o`026P?o00HO0ol03bT3o`0R>0?o04E:0ol0Gd@3o`1f9`Co28d00om9Y003oiJi00?oc;400ooMP@03
onYC00?om2h00ook4`03ooh700?oo@P00ooj5P03oo@^00Cok4d00ooRL003omNC00?obk@00on/_`03
og^b00?oCjH00ol[VP03o`b?00?o08@;0ol0Nah3o`1b;0Co06/g0ol0ICh3o`1OA0?o05]70ol0F4X3
o`1EB`Wo05A<0ol0ET/3o`1HB@?o05a61?l0HD83o`1W?0?o06hb0ol0MbD3o`214`?o1H`00olUV003
odRS00?oKjl00onJ^P03olG400Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05oooo
o`?oOK<00ono``03om:R00?ogWh00ooXFP03oni700?olSP00ood;P03ooHV00?on2000oog8P04ooHV
00?omRT02Ooe:`03ooDZ00?omRL00oog8`03ooPN00?onQP00ook4P03ood<00CooPL00oon1003ooh5
00?oo@T00ook4@03ooPP00?olc<00oo/C@03onA[00?ofHd00oo=/003ojbo00CoKZl00oleW@03o`>;
00?o07PS0ol0ICh3o`1CC0?o03A20ol06c<3o`0=9`?o00DN1ol00QX3o`057P?o00dW0ol07cD3o`0n
A`?o05a60ol0M2X3o`R=00?oDJH00onZ_P03omBM00?oiV@01?oc<P03oo/A00?ooPP00ooj6003oo0n
00?ohG@00oo=[P03ohZf00?o<id00ol0PPl3o`1Y>P?o055=1?l0:C`3o`0B;0?o00LP0ol00aX3o`02
6P?o00HO0ol03bT3o`0R>0?o04E:0ol0Gd@3o`1f9`Co28d00om9Y003oiJi00?oc;400ooMP@03onYC
00?om2h00ook4`03ooh700?oo@P00ooj5P03oo@^00Cok4d00ooRL003omNC00?obk@00on/_`03og^b
00?oCjH00ol[VP03o`b?00?o08@;0ol0Nah3o`1b;0Co06/g0ol0ICh3o`1OA0?o05]70ol0F4X3o`1E
B`Wo05A<0ol0ET/3o`1HB@?o05a61?l0HD83o`1W?0?o06hb0ol0MbD3o`214`?o1H`00olUV003odRS
00?oKjl00onJ^P03olG400Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o
OK<00ono``03om:R00?ogWh00ooXFP03oni700?olSP00ood;P03ooHV00?on2000oog8P04ooHV00?o
mRT02Ooe:`03ooDZ00?omRL00oog8`03ooPN00?onQP00ook4P03ood<00CooPL00oon1003ooh500?o
o@T00ook4@03ooPP00?olc<00oo/C@03onA[00?ofHd00oo=/003ojbo00CoKZl00oleW@03o`>;00?o
07PS0ol0ICh3o`1CC0?o03A20ol06c<3o`0=9`?o00DN1ol00QX3o`057P?o00dW0ol07cD3o`0nA`?o
05a60ol0M2X3o`R=00?oDJH00onZ_P03omBM00?oiV@01?oc<P03oo/A00?ooPP00ooj6003oo0n00?o
hG@00oo=[P03ohZf00?o<id00ol0PPl3o`1Y>P?o055=1?l0:C`3o`0B;0?o00LP0ol00aX3o`026P?o
00HO0ol03bT3o`0R>0?o04E:0ol0Gd@3o`1f9`Co28d00om9Y003oiJi00?oc;400ooMP@03onYC00?o
m2h00ook4`03ooh700?oo@P00ooj5P03oo@^00Cok4d00ooRL003omNC00?obk@00on/_`03og^b00?o
CjH00ol[VP03o`b?00?o08@;0ol0Nah3o`1b;0Co06/g0ol0ICh3o`1OA0?o05]70ol0F4X3o`1EB`Wo
05A<0ol0ET/3o`1HB@?o05a61?l0HD83o`1W?0?o06hb0ol0MbD3o`214`?o1H`00olUV003odRS00?o
Kjl00onJ^P03olG400Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?oAj<0
0on8]P03olK000?oeIX00ooRLP03onUH00?okd800ood<003ooLQ00?onQH01ook4`06oo/D00Wona<0
0ook4P03oo`?00?oo@`00oom2@03ooh600?ooP@01?oo1003ooh600?oo@/00ook4`03ooPQ00?olc<0
0oo]BP03onEV00?og8D00ooAYP03ol7400?oQKD01?m<Y@03oaVC00?o084A0ol0Kc43o`1MAP?o04Q<
0ol0:C`3o`0E;P?o00XT0ol011`3o`026@Co00<J0ol01b03o`0@:P?o02@i0ol0Ad/3o`1P@`?o07PS
0olBT@03oebY00?o]L400ooFU`03onMO00Com2l00ool4003ooh800?onQP00oo`?`03on5d00?ocJh0
0on<]`03ocJN00?o08@<0ol0JSP3o`1BC@Co02`n0ol04bd3o`078@?o00<J0ol00QT3o`057P?o00dW
0ol07CD3o`0lAP?o05Y80ol0L304o`271@?o=Id00omm/`03olK000?oei800ooVI003oo4l00?on1d0
0oom2`03ooh600?oo0d00ooh7`04oo4i00?ojEP00ooONP03omFJ00?obKT00onX_P03og^b00?oDjL0
0olbW003oaJB00?o08T00ol0PA84o`1j80?o07@Z0ol0KS83o`1Z>0?o06Ll0ol0ICh6o`1T?`?o06Dn
0ol0Ic`3o`1Z>0?o06hb1?l0M2X3o`1k7P?o08<?0ol5R`03oanF00?o@:400omX[@03ohng00?o^L80
0oo;]003om>P00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?oAj<00on8
]P03olK000?oeIX00ooRLP03onUH00?okd800ood<003ooLQ00?onQH01ook4`06oo/D00Wona<00ook
4P03oo`?00?oo@`00oom2@03ooh600?ooP@01?oo1003ooh600?oo@/00ook4`03ooPQ00?olc<00oo]
BP03onEV00?og8D00ooAYP03ol7400?oQKD01?m<Y@03oaVC00?o084A0ol0Kc43o`1MAP?o04Q<0ol0
:C`3o`0E;P?o00XT0ol011`3o`026@Co00<J0ol01b03o`0@:P?o02@i0ol0Ad/3o`1P@`?o07PS0olB
T@03oebY00?o]L400ooFU`03onMO00Com2l00ool4003ooh800?onQP00oo`?`03on5d00?ocJh00on<
]`03ocJN00?o08@<0ol0JSP3o`1BC@Co02`n0ol04bd3o`078@?o00<J0ol00QT3o`057P?o00dW0ol0
7CD3o`0lAP?o05Y80ol0L304o`271@?o=Id00omm/`03olK000?oei800ooVI003oo4l00?on1d00oom
2`03ooh600?oo0d00ooh7`04oo4i00?ojEP00ooONP03omFJ00?obKT00onX_P03og^b00?oDjL00olb
W003oaJB00?o08T00ol0PA84o`1j80?o07@Z0ol0KS83o`1Z>0?o06Ll0ol0ICh6o`1T?`?o06Dn0ol0
Ic`3o`1Z>0?o06hb1?l0M2X3o`1k7P?o08<?0ol5R`03oanF00?o@:400omX[@03ohng00?o^L800oo;
]003om>P00Oooooo0Ol00001ooooo`007Oooool2o`0000Kooooo0om7X`03ohRf00?oa/000ooEVP03
on9b00?ojEP00oo_@P03oo@`00?omb400ooj5P07oo/C00Kona@02Ook4`03oo/B00?oo0l00oom3003
ood900?ooPH00oon1004ool400?ooPH00oom2`03oo/C00?on2400ooc<`03one:00?oiFH00ooLQ@03
om6V00?o`L@00on5]@04odbU00?o6I<00ol0PA43o`1_<@?o05e60ol0B4`3o`0Y?0?o01D^0ol02R@3
o`0470?o008I1?l00aX3o`0780?o010Z0ol093T3o`17B`?o06130ol0N2<3oa:A00?oG:T00one`@03
omJG00?oiel01?od;`03oo`@00?ooPP00ooj6003oo0o00?ohG@00oo=[P03ohbg00?o=Yh00ol0Q0`3
o`1Z>0?o059=1?l0;3h3o`0C;@?o00LQ0ol00aX3o`026@?o00DN0ol03BL3o`0M=@?o03a60ol0FTP3
o`1`<0Co08L50oleW@03ogfc00?oa/000ooGTP03onIT00?olC`00ooh7@03ood;00?ooPH00ool3@03
ooPO00ColCT00ooYF003ommj00?oeIX00oo9^@03ojRn00?oNk800omCY`03oc:L00?o5Y800ol0R@03
o`214PCo07XP0ol0M2X3o`1^<P?o06Xh0ol0Ic`3o`1U?PKo06@o0ol0ICh3o`1W?0?o06Xh0ol0KS84
o`1d:P?o07/N0ol0P`l3o`F;00?o7iH00om0X@03ofR]00?oSkL00oni`P03ol^d00?odj001_ooool2
o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0olCT@03odbU00?oS[L00oo8_@03omNE
00?ohGD00ooYF@03onm100?omB`00ooi6P03oo/B00Coo0h00oom2`03ood900?ooPL01_on1P03ooh5
00?ooP@02Ooo0`03ooh500Coo@T00ool3`03ooXH00?ombD00oob=P03one;00?oiVD00ooMP@03om>P
00?oakl00onG^@03of2[00Co;9X00ol0R@03o`1h8`?o06Hm0ol0ED/3o`0iA@?o020f0ol042X3o`07
8@?o00<K0ol00QT4o`0370?o00PR0ol052d3o`0Z?@?o04m>0ol0ICh3o`1l6`?o79D00omW[@03ol74
00?of9400ooYFP04ooD[00?oo0h00oon2003ooTI00?ol4000ooQM003olj]00?oS[L00olhWP03o`25
2P?o06`f0ol0E4`4o`0_?`?o01D_0ol02283o`036`?o008I0ol011`3o`0;9@?o01Ta0ol0=483o`1E
B`?o06Xh1?l0P1<3ob6G00?oI:`00ona`003om6S00?oh7H00oo/C003ooDZ00?ona801_on1`03oo/C
00ComRL00oo_@P03onMP00?ogWl00ooCWP03olVj00?oZkh00on2]003oejZ00?o?j400olVV003oa6@
00Co08T00ol0Q0`3o`1o5`?o07/N0ol0N2<3o`1f9P?o07DX0ol0MRL3o`1g9@?o07XP0ol0OAT3o`22
3`Co08P20ol?T003obBH00?o@:400omQZ`03ohVf00?o]/400oo:]P03om:Q00?ofHd00ooNO`07oooo
o`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3oa>A00?oC:D00on>]`03olRm00?o
eiD00ooQM@03onUI00?okd400ooe;003ooTJ00?ona801?ol3P03ood;00?oo@T00oon1`06ooh600?o
oPD00oon1009ool300?ooPD01?om2@03oo`?00?onQP00oog9@03oo8f00?okD/00ooVI@03omf100?o
dj000oo7_`03oiNi00?oH:/01?l/VP03o`2900?o07PS0ol0ISd3o`1EB`?o03U50ol083H3o`0@:P?o
00LQ0ol00a/3o`026@Co00<L0ol02283o`0D;@?o02Xm0ol0Cdh3o`1U?P?o07`K0olLU@03ofN]00?o
`L@00ooHT@03onUJ00ComB/00ool3P03ooh800?onAT00oo`@003on5d00?ocZd00on>]`03ocRN00?o
08D:0ol0K3H3o`1DC0Co02lo0ol05Bl3o`088P?o00<K0ol00QT3o`0470?o00/U0ol06C43o`0d@P?o
05E;0ol0JSP4o`204`?o8IL00omT[003ok7000?odJ<00ooPMP03ona<00?omBX00ook4P06ooh700?o
na<01?of9`03onm200?oif000ooNO`03om>N00?obKX00on[_P03oh:d00?oGZX00oloX@03obJH00?o
4I001?l0R@03o`2430?o07lG0ol0Nah3o`1h8`?o07HV0ol0MBP3o`1f9`?o07LU0ol0NR03o`1m6@?o
088?1?l0R083o`n@00?o99P00om0X@03of6[00?oRKH00onf`@03olZf00?odZ400ooIS@03omio00Oo
oooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o4i400om<Y@03ohjg00?ob;d0
0ooGU@03on5e00?ojET00oo_@@03ooD/00?onAX00ook4P04oo`>00?oo@/00oom2@03ooh700KooPH0
0oon1@03ooh400Woo`<00oon1@04ood900?oo0l00ooj6003ooLU00?olSH00oo]B`03onIU00?ogH40
0ooCX003olNo00?oUkT00omPZ`04obbJ00?o08T00ol0N2<3o`1V?@?o05E;0ol0>DD3o`0P=P?o010Z
0ol01b43o`036`?o008I1?l00a`3o`088P?o01@]0ol0:Sd3o`1?CP?o06Dn0ol0O1/3oabE00?oIjd0
0oo1a003omRA00?ojEX01?oe:`03oo`>00?ooPP00ooi6@03oo1000?ohG@00oo>[@03ohjg00?o>9h0
0ol0Q@X3o`1/=P?o05A<1?l0;cl3o`0E;`?o00PR0ol00a/3o`026@?o00@L0ol02bD3o`0I<@?o03A2
0ol0ED/3o`1Z>0Co080C0olQU`03ofB/00?o/L000ooAX`03on1f00?ok4`00ooe:P03oo/B00KooPL0
0ook4`04ooHW00?okd800ooWH003omio00?odih00oo9^P03oj^n00?oP[@00omNZP03ocnQ00?o9YP0
0olAT004o`2900?o08@<0ol0OaL3o`1k7P?o07PS0ol0MRH3o`1e:0?o07HW0ol0MbD3o`1j80?o07dI
0ol0PPl4o`280P?o3i000olTV003od2Q00?oHJ/00on9]P03okK100?ob[H00ooBX@03omV=00?ogWl0
1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0OAT3oaBA00?oC:D00on=
]`03olRm00?oe9`00ooNO@03onMP00?okTD00ood;P03ooPP00ConQL00ool4003ood;00?ooPL03?on
1@03ooh600?ooPL00oom2`03oo`@00ConQL00ooh8003ooD]00?ol3d00oo[D@03onEX00?ogH800ooC
WP03olVk00?oX[`00om][P03ocbP00Co3i000ol0OaH3o`1^<`?o05e60ol0Bdd3o`0/?P?o01Pa0ol0
32H3o`057P?o008J0ol00QT4o`047@?o00/U0ol06343o`0b@@?o05A<0ol0JCT3o`204`?o9iT00omd
/003olK000?ofXX00ooZE004ooHX00?oo0d00oon2003ooTJ00?okd400ooQM@03olj]00?oT;P00olk
W`03o`261`?o06dd0ol0ET/4o`0c@@?o01P`0ol02R@3o`0470?o008I0ol00a/3o`098`?o01D^0ol0
;3h3o`1@CP?o06@o1?l0NR03o`n@00?oC:D00onD^@03ol^e00?ofXT00ooWGP03oo4i00?onAd00oom
2`03ooh500?oo@X01?oj6003ooD]00?okTL00ooVI003omf100?oe9`00oo:]P03okK100?oTKP00om`
[`03oeFW00?o?J001?lZVP03oa^D00?o3i000ol6S003o`2:00?o08P20ol0R0<3o`290@?o0XX00ol9
S@03oaBB00?o8YL01?leW@03odfU00?oJ:d00on:]P03ok3000?ob[P00ooDW@03om^900?oh7L00ooT
K003onAY00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o07dI0olDT@03
odbU00?oSKL00oo8_@03omBL00?ogWd00ooWH003oni500?om2h00ooh8004ooXG00?oo1000oom2`03
ooh700cooPD00oon1P03ooh700?oo@/00ool4004ooXG00?on2000ooe;@03oo0m00?oje400ooUJ003
omf200?odih00oo9^`03oj:l00?oKJh00ollX004o`n@00?o07lF0ol0KS<3o`1MAP?o04]=0ol0;3h3
o`0H<@?o00`V0ol01Ah3o`026P?o008I1?l011d3o`0;9@?o01Pa0ol0<T43o`1DC0?o06Ti0ol0P1<3
obNI00?oM;000oo6`003omZ:00?ojU@01?of:003oo`=00?ooPP00ooi6P03onm100?ohGD00oo>[@03
oi2h00?o>il00ol0QPL3o`1]=0?o05I;1?l0<d43o`0H<0?o00XT0ol011`3o`026@?o00<K0ol02B<3
o`0E;P?o02`n0ol0D4h3o`1T?`Co07XP0ol?T003odbU00?oU;T00oo;]@03omZ900?oieh00ooa>@03
ooTM00?oo@/00oon1@03ood:00ConQP00ooe;@03oni700?oiV@00ooMP@03omBL00?ob[H00onf`@03
oi6h00?oL:l00omEY`03ocfP00Co:YX00olKU003o`n@00?o1X`00ol0RP03o`280P?o08P30ol0R@43
o`::00?o2Hd00olDTP03ob:G00Co=Id00om=Y@03ofR]00?oR[H00on``003olZh00?oe9d00ooKR@03
on1g00?oi6`00ooTJ@07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1m
6@?o59400om<Y@03ohfg00?ob;d00ooDW003omim00?oif000oo^A@03oo@^00?on2001?oj5`03oo`@
00?oo@/00oon1`0<ooh500?ooPH00oon1`03ood;00?oo1001?oj5`03ooPP00?omBd00oo`?@03on]A
00?oiFP00ooMPP03om>N00?obK/00onR_003off^00?o?:001?l?T003o`1o5P?o06hc0ol0GDH3o`1;
C@?o02`n0ol06343o`0<9P?o00DN0ol00QX3o`026@Co00@M0ol02bD3o`0H<@?o03910ol0E4`3o`1Y
>@?o080C0olWV@03ogB`00?oa/000ooJRP03onYD00ComRP00ool3@03ooh800?onAX00oo_@@03on5e
00?ocZd00on@^003oc^O00?o08H70ol0KC@3o`1FB`Co03=10ol06303o`0:90?o00@L0ol00QT3o`03
6`?o00TS0ol05Bh3o`0/?P?o051>0ol0I3l4o`1j80?o3i000om<Y@03oiBi00?obkD00ooJR@03onMN
00?olCT00ooi7@03ood;00?ooPD00oom2P04ooXH00?omBd00oo^A`03onIT00?ogH400ooDW003olZf
00?o]/400onA^003og2_00?oEJL00olmX004obZJ00?o6i@00ol?T003o`J<00?o08X00ol0R083o`28
0`?o08T10ol2RP03o`V=00?o59800olRU`04ocFM00?oCJD00omX[@03ohZf00?o/<000oo:^003omBM
00?ofhT00ooPM`03onA/00?oi6T01oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Go
oooo0ol0J3X3o`1l6`?o49000om7X`03ohNe00?o`<<00oo@Z003omZ900?ohf`00oo[D@03oo0n00Co
m3000oof9@03ooTM00?onQH00ook4P06oo/A00?ona800ook5003ooXG00?onA`00oog9004oo@]00?o
lCX00oo]B@03onQK00?ohW000ooKQ`03om:P00?obK/00onV_@03ogFa00?oAZ<00olJU004o`242`?o
07@Y0ol0I3l3o`1DC0?o03Y50ol08CL3o`0B:`?o00PR0ol011`3o`026@?o00<J1?l01Ql3o`0>:0?o
01he0ol0>TD3o`1HB@?o06hc0ol0Q@T3oc>M00?oPK@00oo9^@03omb300?ok4l01?og9@03ood;00?o
oPP00ooi6`03onm200?ohGD00oo>[003oi>h00?o?Z000ol0R0<3o`1_<@?o05Q91?l0=d<3o`0J<P?o
00/U0ol011d3o`026@?o00<K0ol01b43o`0A:`?o02Dj0ol0AT/3o`1NA@Co07<[0ol0R083ocFM00?o
Mk400oo1a003omBL00?ohW800oo]B`03ooD[00?ona@00oon1`03ooh500Coo0d00ooi7003oo@`00?o
kDT00ooVH`03omin00?oeYL00oo>[P03olG200?oZ;h00on;]P03og>`00CoGZX00om=Y@03od6Q00?o
=ih00olaW006objK00?o<Y`00oliW`03od>R00?oDZH00omU[004ogfc00?oV[X00oni`P03olZg00?o
dj000ooKQP03on=/00?oieh00ooZEP03onUG00?oiV@01oooool1o`00007ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo0ol0J3X3o`1l6`?o49000om7X`03ohNe00?o`<<00oo@Z003omZ900?ohf`0
0oo[D@03oo0n00Com3000oof9@03ooTM00?onQH00ook4P06oo/A00?ona800ook5003ooXG00?onA`0
0oog9004oo@]00?olCX00oo]B@03onQK00?ohW000ooKQ`03om:P00?obK/00onV_@03ogFa00?oAZ<0
0olJU004o`242`?o07@Y0ol0I3l3o`1DC0?o03Y50ol08CL3o`0B:`?o00PR0ol011`3o`026@?o00<J
1?l01Ql3o`0>:0?o01he0ol0>TD3o`1HB@?o06hc0ol0Q@T3oc>M00?oPK@00oo9^@03omb300?ok4l0
1?og9@03ood;00?ooPP00ooi6`03onm200?ohGD00oo>[003oi>h00?o?Z000ol0R0<3o`1_<@?o05Q9
1?l0=d<3o`0J<P?o00/U0ol011d3o`026@?o00<K0ol01b43o`0A:`?o02Dj0ol0AT/3o`1NA@Co07<[
0ol0R083ocFM00?oMk400oo1a003omBL00?ohW800oo]B`03ooD[00?ona@00oon1`03ooh500Coo0d0
0ooi7003oo@`00?okDT00ooVH`03omin00?oeYL00oo>[P03olG200?oZ;h00on;]P03og>`00CoGZX0
0om=Y@03od6Q00?o=ih00olaW006objK00?o<Y`00oliW`03od>R00?oDZH00omU[004ogfc00?oV[X0
0oni`P03olZg00?odj000ooKQP03on=/00?oieh00ooZEP03onUG00?oiV@01oooool1o`00007ooooo
000Mooooo`03o`000?oooooooooo00Gooooo0ol0J3X3o`1l6`?o49000om7X`03ohNe00?o`<<00oo@
Z003omZ900?ohf`00oo[D@03oo0n00Com3000oof9@03ooTM00?onQH00ook4P06oo/A00?ona800ook
5003ooXG00?onA`00oog9004oo@]00?olCX00oo]B@03onQK00?ohW000ooKQ`03om:P00?obK/00onV
_@03ogFa00?oAZ<00olJU004o`242`?o07@Y0ol0I3l3o`1DC0?o03Y50ol08CL3o`0B:`?o00PR0ol0
11`3o`026@?o00<J1?l01Ql3o`0>:0?o01he0ol0>TD3o`1HB@?o06hc0ol0Q@T3oc>M00?oPK@00oo9
^@03omb300?ok4l01?og9@03ood;00?ooPP00ooi6`03onm200?ohGD00oo>[003oi>h00?o?Z000ol0
R0<3o`1_<@?o05Q91?l0=d<3o`0J<P?o00/U0ol011d3o`026@?o00<K0ol01b43o`0A:`?o02Dj0ol0
AT/3o`1NA@Co07<[0ol0R083ocFM00?oMk400oo1a003omBL00?ohW800oo]B`03ooD[00?ona@00oon
1`03ooh500Coo0d00ooi7003oo@`00?okDT00ooVH`03omin00?oeYL00oo>[P03olG200?oZ;h00on;
]P03og>`00CoGZX00om=Y@03od6Q00?o=ih00olaW006objK00?o<Y`00oliW`03od>R00?oDZH00omU
[004ogfc00?oV[X00oni`P03olZg00?odj000ooKQP03on=/00?oieh00ooZEP03onUG00?oiV@01ooo
ool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0E4`3o`1V?0?o07XP0ol8S@03
ocfP00?oLJl00onW_@03olZh00?oeIX00ooNOP03onEX00CojEL00oo]B003oo4m00?olc<00ood;P03
ooD[00KomBX00ooe;@03oo<a00?olSP00oo_@@04ona<00?ojET00ooTJP03omil00?of9400oo@Y`03
olNo00?oXk`00omf/@03odZT00?o8IH00ol0R0<4o`1i8P?o06Ti0ol0FTP3o`17B`?o02`m0ol06C43
o`0=9`?o00HO0ol00aX3o`026@?o00<K1?l02283o`0B:`?o02@i0ol0A4X3o`1MAP?o07</0ol0RP03
od2Q00?oS[L00oo</@03omim00?okDX01?og8@03ood:00?oo@P00ooi7003onm200?ohGD00oo>[003
oiFi00?o@Z400ol0R@03o`1a;P?o05Y81?l0>dD3o`0M=0?o00`W0ol01Ah3o`026@?o00<J0ol01Ql3
o`0>:@?o01lf0ol0?4H3o`1HB@Co06`e0ol0PA83oajE00?oFjT00onP_003olf`00?ofhL00ooWG`03
oo4l00?on2400ool3P03ooh500CooPH00ool3P03ooTM00?om3000oo^A`03onMN00?oh7H00ooIS003
om:Q00?oc;<00oo5``03ojno00CoVkX00on:]P03ogfc00?oLk000om^[`03ofb^00?oKZl00omc/003
ogfc00?oRkH00onM^`03okC000Coakh00oo>[003omFI00?og8@00ooSK@03onYF00?okd800oo`?`03
oni500?ojUH00ooRL@07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1D
C0?o06Hl0ol0NR03o`R=00?o?J000oma[`03ojNm00?ob[P00ooEVP03omin00?oiFP01?oYE`03one8
00?olCd00ooc<`03oo@^00?omB/01_oe:P03ooD]00?olc400oob>003onm100Cok4`00ooYF@03onAZ
00?ogW`00ooHT@03om2W00?oakl00onS_003ogJa00?oBZ@00olQUP03o`280`Co07TR0ol0JCT3o`1J
B0?o04M;0ol0;3d3o`0I<@?o00dW0ol01Ql3o`036P?o008I0ol00a/4o`088P?o018[0ol093T3o`14
BP?o05e60ol0Lb`3o`2:00?o@:400on>]`03olba00?ogWd00oo]BP04ooLQ00?oo@X00oom2003ooTL
00?okd800ooQM@03olj/00?oUKT00om2X@03o`2900?o074^0ol0FTP4o`0kA@?o01dd0ol032L3o`05
7P?o008I0ol00aX3o`067`?o00hY0ol07cH3o`0lAP?o05Q91?l0K3D3o`214P?o7YD00omKZ@03oj2l
00?ocK000ooKQ`03onMO00?olC`00ooh8@03oo`>00?ooPD01?on1P03oo`>00?onAd00ood<003oni7
00?oieh00ooPMP03omV<00?odZ400oo</`03olG300?o[kl01?nK^P03ohZf00?oOK<00omc/003ofj_
00?oK:h00om^[`03og>`00?oOK<00on;]P03oifk00?o]<001?o7_P03olj/00?oeIT00ooLQ003on=]
00?ojUH00oo_@P03oo0o00?okTD00ooZEP03on9a00Oooooo0Ol00001ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`?o05A<0ol0IS`3o`1j80?o28d00olmX003og6_00?oYkd00oo:^003omFJ00?o
gWh00ooUJ004onUG00?okDP00ooa?@03oo<c00?om2h00ooe:`06ooDZ00?omBd00ooc<@03oo8h00?o
kd401?o/C003onUI00?oi6X00ooNO003omRA00?od:L00oo7_`03oj>l00?oM[400om:Y003ob6F00?o
08P31?l0NB83o`1Y>@?o05Y80ol0Ad/3o`0/?@?o01Ta0ol03BL3o`067`?o00<J0ol00QT3o`036`Co
00PR0ol04R/3o`0T>@?o04A:0ol0GDH3o`1c;0?o08X00om0X@03ohjg00?oc;400ooNO@03one:00Co
mb400oom2P03ood800?onA`00oo_@P03on5e00?ocZ`00onE^@03od:Q00?o08T00ol0LBh3o`1JB0Co
03]50ol07C@3o`0<9`?o00DN0ol00QT3o`036P?o00HO0ol03RT3o`0O=P?o03a60ol0F4T4o`1/=@?o
084B0olNU@03oe^Y00?oX;`00oo=/003om^700?oiel00ooa?003ooPQ00?oo0h00oon1@04ooh600?o
o0h00ooi7@03oo@`00?okTL00ooWGP03on1f00?ofH`00ooBX@03olbc00?oaL<00on__`04oi^j00?o
R[H00omm/`03og>`00?oKZl00om/[P03ofj_00?oLk000omm/`03oh^f00?oWK/00ond`004olNn00?o
cZ`00ooEV@03omb400?ohfd00ooZEP03onm200?ol3l00oo^A@03onYF00?ohW401oooool1o`00007o
oooo000Mooooo`;o00001_ooool3o`0a@0?o055=0ol0Hd03o`1e9`?o08P20olWV@03oeJX00?oR;H0
0onj`P03olf`00?oeIT01?oKQP03on1f00?oiFP00ooXG003onYD00?oje001_o/CP03on]@00?ojUD0
0ooXG003onEU00CohW000ooNOP03omV>00?odj000oo;/`03oko300?oV;X00om`[`03odVT00?o8iL0
0ol0RP03o`1l7@Co06dd0ol0GT@3o`1@CP?o03E30ol083H3o`0A:`?o00TS0ol011d3o`026@?o008J
0ol01Ad4o`0:9@?o01H_0ol0;3h3o`1?CP?o06910ol0N2<3o`b>00?oCJD00onM^`03olnZ00?oh7H0
0oo^A@04ooPN00Koo@T00ooh7@03onm300?ohGD00oo?Z`03oiNj00?oAJ<00ol2R`03o`1c;0?o05a6
1?l0?dP3o`0P=P?o00hX0ol01Ql3o`026P?o008I0ol01Ah3o`0<9P?o01Tb0ol0<T43o`1BC@Co06Dn
0ol0NB43o`V=00?o@:400on0]003olG400?oe9d00ooQM@03on]@00?olc400ooi6P03ood;00CooPD0
0oon1P03oo`>00?onA`00ood;@03onm100?ojUD00ooTJP03omim00?ofHl00ooCWP03olj/00Cob[L0
0oo6`003ol7400?o^L800one`@03okC100?o^<800oo0``03olK000?ob[L00oo>[003omBM00CofX`0
0ooPN003onEU00?oje800oo`?`03oo@`00?omRP00ooc<`03one900?oi6P00ooHT@06ooooo`;o0000
0Oooool001gooooo00?o0000ooooooooool01Oooool3o`0a@0?o055=0ol0Hd03o`1e9`?o08P20olW
V@03oeJX00?oR;H00onj`P03olf`00?oeIT01?oKQP03on1f00?oiFP00ooXG003onYD00?oje001_o/
CP03on]@00?ojUD00ooXG003onEU00CohW000ooNOP03omV>00?odj000oo;/`03oko300?oV;X00om`
[`03odVT00?o8iL00ol0RP03o`1l7@Co06dd0ol0GT@3o`1@CP?o03E30ol083H3o`0A:`?o00TS0ol0
11d3o`026@?o008J0ol01Ad4o`0:9@?o01H_0ol0;3h3o`1?CP?o06910ol0N2<3o`b>00?oCJD00onM
^`03olnZ00?oh7H00oo^A@04ooPN00Koo@T00ooh7@03onm300?ohGD00oo?Z`03oiNj00?oAJ<00ol2
R`03o`1c;0?o05a61?l0?dP3o`0P=P?o00hX0ol01Ql3o`026P?o008I0ol01Ah3o`0<9P?o01Tb0ol0
<T43o`1BC@Co06Dn0ol0NB43o`V=00?o@:400on0]003olG400?oe9d00ooQM@03on]@00?olc400ooi
6P03ood;00CooPD00oon1P03oo`>00?onA`00ood;@03onm100?ojUD00ooTJP03omim00?ofHl00ooC
WP03olj/00Cob[L00oo6`003ol7400?o^L800one`@03okC100?o^<800oo0``03olK000?ob[L00oo>
[003omBM00CofX`00ooPN003onEU00?oje800oo`?`03oo@`00?omRP00ooc<`03one900?oi6P00ooH
T@07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`0a@0?o055=0ol0Hd03
o`1e9`?o08P20olWV@03oeJX00?oR;H00onj`P03olf`00?oeIT01?oKQP03on1f00?oiFP00ooXG003
onYD00?oje001_o/CP03on]@00?ojUD00ooXG003onEU00CohW000ooNOP03omV>00?odj000oo;/`03
oko300?oV;X00om`[`03odVT00?o8iL00ol0RP03o`1l7@Co06dd0ol0GT@3o`1@CP?o03E30ol083H3
o`0A:`?o00TS0ol011d3o`026@?o008J0ol01Ad4o`0:9@?o01H_0ol0;3h3o`1?CP?o06910ol0N2<3
o`b>00?oCJD00onM^`03olnZ00?oh7H00oo^A@04ooPN00Koo@T00ooh7@03onm300?ohGD00oo?Z`03
oiNj00?oAJ<00ol2R`03o`1c;0?o05a61?l0?dP3o`0P=P?o00hX0ol01Ql3o`026P?o008I0ol01Ah3
o`0<9P?o01Tb0ol0<T43o`1BC@Co06Dn0ol0NB43o`V=00?o@:400on0]003olG400?oe9d00ooQM@03
on]@00?olc400ooi6P03ood;00CooPD00oon1P03oo`>00?onA`00ood;@03onm100?ojUD00ooTJP03
omim00?ofHl00ooCWP03olj/00Cob[L00oo6`003ol7400?o^L800one`@03okC100?o^<800oo0``03
olK000?ob[L00oo>[003omBM00CofX`00ooPN003onEU00?oje800oo`?`03oo@`00?omRP00ooc<`03
one900?oi6P00ooHT@07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`0G
<0?o02/m0ol0Bdd3o`1NA@?o070`0ol0P1<3oa2@00?o>Il00omU[003oi:h00?o^<801?o9^@03om2X
00?oeIT00ooIS003omb300?ogWd00ooONP03ommi00?ogg/00ooNOP03omb500?ofHd01?oEV003om6U
00?obk<00oo5``03ojRn00?oQ[D00omT[003od6Q00?o7iH00ol0R@03o`1l6`?o06la1?l0HD83o`1D
C0?o03e70ol09cX3o`0F;`?o00`V0ol01Ql3o`036`?o008I0ol00a/3o`0680Co00hX0ol073@3o`0e
@`?o05A<0ol0J3/3o`1m6@?o6I<00omLZ@03ojbo00?odZ800ooSKP03oo0o00ConA/00oon2003ood9
00?on1h00oo^A003on1f00?ocjX00onJ^P03odVT00?o1X`00ol0MBT3o`1NA@Co04A:0ol08cP3o`0@
:P?o00LP0ol00aX3o`026@?o00@L0ol02B<3o`0E;P?o02Tl0ol0BD`4o`1NA@?o074^0ol0Q@X3obJH
00?oH:/00onQ_003olbc00?ofHd00ooUI`03oni600?omBX00ooj5P04ood900?ooP@00oon1P03oo`=
00?onQP00oof9`03oo8g00?okDP00ooYF@03onAY00?oh7L00ooLQ004omV>00?oeYL00ooDW@03om:Q
00?odZ800ooBX@03om>N00?oeIP00ooHT003omb500?oh7P00ooTJ@04onUG00?okTD00oob=P03ooDY
00?on2000ooh7@03ooLS00?ol3h00ooVHP03omV=00?ob;/01oooool1o`00007ooooo000Mooooo`03
o`000?oooooooooo00Gooooo0ol05c03o`0[?@?o04]=0ol0GTD3o`1`<0?o080C0ol@T003ocVO00?o
IJ`00onB^003okS200CobKT00oo@Z003omFI00?ofH`00ooLP`03omim00?oggX00ooON@03ommk00?o
gWh00ooLQ@03omV=00CoeIP00ooAY@03ol^c00?oaL<00onX_P03ohJe00?oI:`00om1X@03oanF00?o
08T00ol0O1/3o`1_<@Co06520ol0E4`3o`0mA`?o02Lj0ol05Rl3o`0<9P?o00HO0ol00a/3o`026@?o
00<K0ol01R04o`0>:0?o01`d0ol0=D<3o`1DC0?o06Pk0ol0OAT3oaVC00?oG:T00on/_`03om:R00?o
hfh00oo`?`04ooTK00?ooPP00oom2@03ooPN00?okT@00ooPMP03olnZ00?oV[X00om9Y003o`J<00?o
07DY0ol0GTD4o`14BP?o02<h0ol042X3o`0780?o00<J0ol00QT3o`0470?o00TS0ol05Bh3o`0Y?0?o
04U<1?l0GTD3o`1a;P?o08D:0olVV003of2[00?oXK`00oo</`03omV=00?oiFL00oo^AP03ooDZ00?o
nQH01?om2@03ooh400?ooPH00ool3@03ooXH00?omRL00oob=`03one800?ojET00ooTJ@03on1g00?o
g8@01?oISP03omJG00?oe9d00ooBX@03om:R00?odZ400ooCWP03omFH00?of9000ooLQ@03on1h00?o
i6T01?oYE`03oni500?olSH00ooe:@03ooPP00?on1d00oog8`03oo0n00?oiV800ooIS@03olRk00Oo
oooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o01L`0ol0:cd3o`1;C@?o05i5
0ol0L303o`204`?o49000oliW`03ofF/00?oT[P00onh`P04olVi00?od:P00ooEV@03omV<00?og8<0
0ooNO@03ommj00?oggT00ooON`03omin00?og8D00ooIS@04omFH00?odJD00oo;/`03olG300?oZ;h0
0on6]@03ofB/00?o@J400olOUP03o`2900?o07`K0ol0Kc44o`1Q@P?o05A<0ol0?DL3o`0W>P?o01H_
0ol032H3o`067`?o00<K0ol00QT3o`036`?o00HP1?l03RP3o`0L=0?o03E30ol0E4`3o`1X>`?o07dI
0olIT`03oebY00?o[;l00ooBXP03on=^00?ol3l01?oi6`03ooh800?oo@T00ooh7P03oni400?oh7H0
0oo?ZP03oiZj00?oBJ@00ol6S003o`1e:@?o05i51?l0A4X3o`0S>0?o010Z0ol01b03o`036P?o008I
0ol011`3o`098`?o01D^0ol0:C`3o`19C0Co05i50ol0LBh3o`252P?o9YP00omPZ`03oj6l00?oc;<0
0ooIS@03onEW00?okTH00ooe:P03ooXF00Coo@T00oon1003ooh600?oo0d00ooj6003ooHW00?olSL0
0oo]B003onUI00?oi6T00ooPM`03omb400CofHh00ooFU`03omBM00?odZ400ooBXP03om:Q00?odih0
0ooEV003omR@00?og8D00ooPN003onAY00CojEL00oo^A@03oo8f00?omBT00ooh8003ooPM00?omb<0
0oo`?P03onIR00?ofHd00oo8^`07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Ooo
ool3o`0:90?o01<]0ol093T3o`0oA`?o05Q:0ol0Ic/3o`1g9@?o08H80olJU003ocnQ00?oHZ/01?n2
]003oj2l00?o^/800oo7_P03ol^d00?ocZh00oo?Z@03om2W00?od:P00oo?Z`03olf`00?ob[L01?o6
`003okW200?oX[`00on9]P03off^00?oD:H00olcW@03oaJB00?o08L40ol0Nad3o`1_<@?o06911?l0
ET/3o`13B@?o02`n0ol06c<3o`0?:@?o00PR0ol011`3o`026P?o008I0ol011`3o`098`Co018/0ol0
93T3o`10B0?o05Y80ol0KS<3o`233P?o9iP00om/[P03okc200?oeIT00ooUI`03oo4j00ConQP00oon
1`03ood:00?on1l00oo^A@03on1f00?ocjX00onL^`03odbU00?o2Xh00ol0MbD3o`1Q@`Co04Y<0ol0
9c/3o`0C;0?o00PR0ol00a/3o`026@?o00<K0ol01b43o`0@:P?o024g0ol0?4H4o`1GBP?o06Ti0ol0
O1/3o`j?00?o@Z400omm/`03okg300?odJD00ooMP003onQN00?ol3l00oof9P04oo/D00?oo@T00ooo
1003ooh400?oo@X00ook4`03ooPN00?omB/00oob>003oni500?oje400ooXF`04onIT00?oi6/00ooR
L003on5c00?ohG@00ooRLP03on=]00?oiFH00ooXG@03on]C00?okTH00oob>004ooDZ00?onAd00ooj
5P03oo/C00?onQL00oog8P03oo8g00?oif000ooISP03olRm00?oOk<01oooool1o`00007ooooo000M
ooooo`03o`000?oooooooooo00Gooooo0ol02R@3o`0C;@?o02@i0ol0?dL3o`1HBP?o06Lk0ol0MbD3
o`2620?o6Y@00oloX@03of:[00CoP[@00onP_003ok[200?oakh00oo;]003olj^00?ocjT00oo@Y`03
om2X00?ocj/00oo=/003olZg00Coa/000oni`P03oj:l00?oRKH00om][P03oe2V00?o<id00olFTP03
o`2710?o07/M0ol0Kc43o`1R@@Co05I;0ol0@dT3o`0/?P?o01/c0ol03bT3o`088P?o00@L0ol00QX3
o`026@?o00@L0ol02B<4o`0B;0?o02@i0ol0@4P3o`1JB0?o06hc0ol0P`h3obNH00?oK:h00onl`P03
omFI00?oiFL00ooa>P04ooXH00?ooPL00oom2P03ooPO00?okTD00ooPMP03olnZ00?oW;/00om<Y@03
o`Z>00?o07LU0ol0HD<4o`1:C0?o02Lk0ol04b`3o`088P?o00<K0ol00QT3o`036`?o00LQ0ol042X3
o`0Q=`?o03a61?l0EdX3o`1Y>@?o07`K0ol>S`03od:Q00?oOK<00onm``03om6U00?ogH000ooXGP03
oo0o00?omRH01?ok5003ood900?oo`@00oon1003ood:00?ona<00ooh7P03ooD[00?olSP00oo^A@03
on]A00?oj5/01?oVI003onA[00?ohW000ooQL`03on5d00?ohW800ooSK@03onEV00?oj5d00oo[D`03
oni600?olSP01?oe:P03ooTM00?onQH00ook4`03ooXG00?omb800oob=`03onMP00?ofHh00oo8_@03
ognc00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o00XT0ol04bd3o`0T
>@?o03m70ol0F4X3o`1W>`?o07LU0ol0QPP3oaZD00?o?j400omRZ`04oh:d00?oX;`00onj`P03olNn
00?obk@00oo>[P03olnY00?od:L00oo@Z003oln[00?ocK000oo:]`04olK000?o^L800onR_003ohVf
00?oKJh00om@YP03oc>M00?o5Y800ol0Q`@3o`1k7@?o06la0ol0HT44o`1FB`?o04=90ol0;3h3o`0K
<`?o00lY0ol02283o`0470?o008J0ol00QT3o`0470?o00TS1?l04R`3o`0T>@?o04180ol0FTP3o`1^
<`?o08<>0olWV003ofb^00?o_<800ooEV@03onEW00?olCX01?oj6003ooh700?oo@X00ooh7`03oni5
00?oh7H00oo?ZP03oibk00?oC:D00ol:SP03o`1g9@?o06531?l0BT`3o`0W>`?o01</0ol02283o`03
6`?o008I0ol00a/3o`078@?o010Z0ol08CL3o`0lAPCo05M:0ol0JCT3o`1l6`?o3Xl00om2X@03ogfc
00?o_L<00ooAY@03omf000?oj5h00oo`?`03ooHV00Cona@00oom2@03ool400?ooP@00oom2P03oo/C
00?on1h00ooe:`03oo8h00?okTD00oo[D@03onQK00CoiV@00ooTJ`03on9`00?ohG<00ooQM003on9b
00?ohfd00ooUIP03onQM00?oje<00oo^AP03oo8h00ComBX00ooi7@03ooXF00?ona<00ooj5`03ooLR
00?olSL00ooWH003omV>00?ob;d00omo/`07ooooo`7o00000Oooool001?ooooo0ol00007ooooo`03
o`000?oooooooooo00Gooooo0ol011d3o`078@?o00lY0ol07C@3o`0c@@?o04m>0ol0GTD3o`1/=@?o
07XO0ol0Q`@3oaNC00Co<Y`00om=Y@03ofF/00?oNk800on=]`03oiZj00?oXk`00onX_P03ojVn00?o
Y[d00onO_003oiFi00CoQkD00omg/@03of>/00?oCZD00olgWP03oanF00?o28d00ol0P`h3o`1h8P?o
06dd0ol0HT43o`1FB`Co04I;0ol0<403o`0N=@?o018/0ol02R@3o`057P?o00<J0ol00QT3o`036`?o
00HO0ol032H4o`0H<@?o02dn0ol0CDh3o`1P@`?o07@Z0ol0R083ocJN00?oO;<00oo6`003omRA00?o
if000ooc=@04ooXE00?ooPH00oom2P03ooPQ00?okTL00ooPMP03olnY00?oWk`00om@YP03o`j?00?o
07TR0ol0Hd04o`1?CP?o02/m0ol05Bh3o`098`?o00@L0ol00QT3o`036P?o00HO0ol03BL3o`0J<P?o
03501?l0D4h3o`1R@P?o07@Z0ol0QPL3obFH00?oFZT00onE^@03olRm00?oeIX00ooPN003onUH00?o
lC`01?of9P03ooXE00?oo@X00oon1003ool300?ooPH00oom3003oo/C00?onA`00oof9@03oo@^00?o
lSH01?o`?@03onm200?okTD00oo^A`03oni600?okd<00oo`?`03oo8h00?om3000oof9`03ooPM00?o
na@01?om3003ooh800?oo@/00ooj5@03ooHW00?ol4000ooVHP03omNB00?oa/800omg/@03obbJ00Oo
oooo0Ol00001ooooo`004_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool01Oooool3o`047@?o00LQ0ol03bT3o`0M=0?o03=10ol0Cdh3o`1NA@?o06`e0ol0NQl3o`2710?o
5i<01?lbW003odfU00?oIJ`00omk/P03ohfg00?oV[X00onS_003ojRn00?oZKh00onV_@03oinl00?o
UKT01?n7]@03ogNa00?oHj`00om>Y@03ocNN00?o7iH00ol8S@03o`233P?o07PR0ol0KC@3o`1R@@?o
05I;1?l0AT/3o`0`@0?o01he0ol04R`3o`0:90?o00DN0ol00aX3o`026@?o00<K0ol01Ql3o`0<9PCo
01Pa0ol0;Ch3o`1=CP?o06130ol0M2X3o`280P?o=Yh00oml/`03olK000?of9400ooWH003oo<e00Co
nQD00oon1P03ood:00?on2400oo^A`03on1f00?ocjT00onO_003oe2V00?o3Xl00ol0NB83o`1S@0Co
04m>0ol0:cd3o`0E;P?o00TS0ol011`3o`026@?o00<J0ol01Ql3o`0=9`?o01Xb0ol0<D04o`1@CP?o
06920ol0M2X3o`261`?o9IP00omJZ@03oiFi00?ob;d00ooEVP03on1h00?ojEP00ooa?004ooHV00?o
nQD00oom2P03ooh400?oo`<00oon1P03ood<00?ona<00ooi7003ooHU00?om2h00oob=P04oo0m00?o
kd800oo^A@03oni700?okTH00oo_@`03oo0o00?olSP00ood<003ooHW00?on1d00ook5004ood<00?o
oPP00oom2`03ooXE00?omRL00oo`@003onIR00?oei800oo6`P03ogNa00?o;9X01oooool1o`00007o
oooo000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool3o`047@?o00LQ
0ol03bT3o`0M=0?o03=10ol0Cdh3o`1NA@?o06`e0ol0NQl3o`2710?o5i<01?lbW003odfU00?oIJ`0
0omk/P03ohfg00?oV[X00onS_003ojRn00?oZKh00onV_@03oinl00?oUKT01?n7]@03ogNa00?oHj`0
0om>Y@03ocNN00?o7iH00ol8S@03o`233P?o07PR0ol0KC@3o`1R@@?o05I;1?l0AT/3o`0`@0?o01he
0ol04R`3o`0:90?o00DN0ol00aX3o`026@?o00<K0ol01Ql3o`0<9PCo01Pa0ol0;Ch3o`1=CP?o0613
0ol0M2X3o`280P?o=Yh00oml/`03olK000?of9400ooWH003oo<e00ConQD00oon1P03ood:00?on240
0oo^A`03on1f00?ocjT00onO_003oe2V00?o3Xl00ol0NB83o`1S@0Co04m>0ol0:cd3o`0E;P?o00TS
0ol011`3o`026@?o00<J0ol01Ql3o`0=9`?o01Xb0ol0<D04o`1@CP?o06920ol0M2X3o`261`?o9IP0
0omJZ@03oiFi00?ob;d00ooEVP03on1h00?ojEP00ooa?004ooHV00?onQD00oom2P03ooh400?oo`<0
0oon1P03ood<00?ona<00ooi7003ooHU00?om2h00oob=P04oo0m00?okd800oo^A@03oni700?okTH0
0oo_@`03oo0o00?olSP00ood<003ooHW00?on1d00ook5004ood<00?ooPP00oom2`03ooXE00?omRL0
0oo`@003onIR00?oei800oo6`P03ogNa00?o;9X01oooool1o`00007ooooo000Fooooo`03o`000?oo
oooooooo00Cooooo0ol00005ooooo`?o00@L0ol00a/3o`057P?o00/U0ol05Bl3o`0V>P?o03e70ol0
E4`3o`1Q@P?o06hc0ol0NB44o`233@?o1h`00olKU003objK00?o?Z000om;Y003oeFW00?oFjT01_mM
ZP03oeRX00?oDJH01?m6X`03ocVO00?o:YX00olIU003o`N=00?o08D90ol0O1/3o`1c:`?o06Ti0ol0
Gd@3o`1EB`?o04E:1?l0<D03o`0P=P?o01@^0ol032H3o`0680?o00<K0ol00QT3o`026P?o00@L0ol0
2283o`0A:`Co01lf0ol0>4@3o`1DC0?o06Hm0ol0NR03o`^>00?oAZ<00on>]`03olZg00?ofhP00ooY
F003oo@_00Cona800oon1@03ood;00?omb800oo^B003on1g00?ocjT00onR_003oeBW00?o4Y400ol0
Nah3o`1U?PCo055=0ol0<403o`0H<@?o00/U0ol01Ah6o`026P?o00@M0ol02R@3o`0E;P?o02Lk1?l0
@dT3o`1JB0?o06/g0ol0O1/3o`Z>00?o>Il00om_[`03ojRn00?obk@00ooGU003on5d00?ojUH01?oa
?@03ooHX00?onQP00ool3003ooh600Koo`<00oon1@03ood900?oo0h00ook4`03ooXH00ConA`00ooh
7`03ooPQ00?omb400ooh8003ooPM00?onAT00ook5003oo`?00?oo@X00oon1@03ool300CooP@00oom
2`03ooTK00?olc400oo/C`03on5c00?oe9/00onj`P03ofV]00?o8YL00ol0OaH5ooooo`?o00000Ooo
ool001;ooooo1?l00007ooooo`03o`000?oooooooooo00Gooooo0ol011`3o`036`?o00DN0ol02bD3
o`0E;`?o02Hj0ol0?DL3o`1DC0?o06520ol0KS<3o`1i8@Co08<=0ol7S003oa^D00?o;Y/00olnX003
od^T00?oEJL00omKZ@06oefZ00?oF:P00omAYP04odJS00?o>Il00olZVP03oaVD00?o1hd00ol0Q@T3
o`1l6`?o07<[0ol0JCT3o`1OA0?o05E;0ol0ADX4o`0a@0?o020f0ol052h3o`0<9P?o00HP0ol00a/3
o`026@?o008J0ol011`3o`088P?o014[1?l07cH3o`0hA0?o05A<0ol0ISd3o`1j80?o2hh00om6X`03
ohjg00?ob[L00ooKR003onUH00?om2l01?ok4P03ooh500?oo@/00oog8P03oni800?oh7L00oo?Z@03
oj:l00?oE:L00olBT@03o`1k7P?o06Dn1?l0DDd3o`0`@0?o01Pa0ol02bD3o`057PKo008J0ol011d3
o`0:90?o01D^0ol09c/4o`13B@?o05Y80ol0JcL3o`1l6`?o2Xh00oliW`03ofn_00?oZ;h00oo;]003
omND00?ohG@00ooZEP04oo4m00?omRP00ooj6003oo`<00?ooPH01_oo0`03ooh500?oo@T00ool3P03
oo/C00?onQP01?oi7003ooPO00?on2400oog8@03ooPP00?on1d00ooi6@03oo/D00?oo0l00oom2P03
ooh500?oo`<01?on1003ood;00?onA/00ooc<@03ona?00?ohG<00ooDV`03ok[200?oJJd00olRU`03
o`1o5POooooo0Ol00001ooooo`004_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Gooooo0ol011`3o`036`?o00DN0ol02bD3o`0E;`?o02Hj0ol0?DL3o`1DC0?o06520ol0KS<3o`1i
8@Co08<=0ol7S003oa^D00?o;Y/00olnX003od^T00?oEJL00omKZ@06oefZ00?oF:P00omAYP04odJS
00?o>Il00olZVP03oaVD00?o1hd00ol0Q@T3o`1l6`?o07<[0ol0JCT3o`1OA0?o05E;0ol0ADX4o`0a
@0?o020f0ol052h3o`0<9P?o00HP0ol00a/3o`026@?o008J0ol011`3o`088P?o014[1?l07cH3o`0h
A0?o05A<0ol0ISd3o`1j80?o2hh00om6X`03ohjg00?ob[L00ooKR003onUH00?om2l01?ok4P03ooh5
00?oo@/00oog8P03oni800?oh7L00oo?Z@03oj:l00?oE:L00olBT@03o`1k7P?o06Dn1?l0DDd3o`0`
@0?o01Pa0ol02bD3o`057PKo008J0ol011d3o`0:90?o01D^0ol09c/4o`13B@?o05Y80ol0JcL3o`1l
6`?o2Xh00oliW`03ofn_00?oZ;h00oo;]003omND00?ohG@00ooZEP04oo4m00?omRP00ooj6003oo`<
00?ooPH01_oo0`03ooh500?oo@T00ool3P03oo/C00?onQP01?oi7003ooPO00?on2400oog8@03ooPP
00?on1d00ooi6@03oo/D00?oo0l00oom2P03ooh500?oo`<01?on1003ood;00?onA/00ooc<@03ona?
00?ohG<00ooDV`03ok[200?oJJd00olRU`03o`1o5POooooo0Ol00001ooooo`004_ooool5o`0000Ko
oooo00?o0000ooooooooool01Oooool3o`098`?o00@M0ol00aX3o`0470?o00LQ0ol03bT3o`0K<`?o
02`n0ol0@TT3o`1EB`?o06131?l0JSP3o`1c:`?o07/M0ol0PPl3o`280P?o28d00olAT@03oaNC00?o
6i@00olLU@03oaZD00?o5I801?l>S`03o`B;00?o08L50ol0PA43o`1k7P?o07@Z0ol0K3D3o`1T@0?o
05]80ol0DDd3o`11B0?o02lo1?l083H3o`0E;P?o00dW0ol01b43o`0470?o008J0ol00QT3o`036`?o
00HO0ol032H3o`0G<0Co02Tl0ol0ADX3o`1KB0?o06dd0ol0P1<3oa^D00?oF:P00onP_003olj]00?o
gWh00oo[D@03ooDZ00Coo1000oon1@03ood<00?omb<00oo]B@03on1g00?od:P00onU_@03oeRX00?o
5i<00ol0OAX3o`1X>`Co05A<0ol0=D83o`0L<`?o00dX0ol01Ql3o`036P?o008I0ol00a`3o`088@?o
010Z0ol07cD4o`0f@`?o059=0ol0HT43o`1c;0?o08<=0olJU003odVT00?oOK<00ond`003olf`00?o
f9400ooQM004onUI00?okd400ood;@03ooPN00?ona800oom2P03ooh500Koo`800ooo0`03ooh400?o
oPH01?on1`03ood800?oo@T00oom2003ooh700?ooPH00ooo0`03ool100?oo`000ooo0@03ooh500?o
o@/01?oj5P03ooHX00?okd<00ooVH`03om^800?ocJl00onT_@03oeNX00?o4i400ol0NQl3o`1R@@Oo
oooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o00TS0ol011d3o`036P?o00@L
0ol01b43o`0?:@?o01/c0ol0;3h3o`12B@?o05E;0ol0H4<4o`1Z>0?o07<[0ol0Nad3o`223`?o08P2
0ol8S@03oa6A00?o5i<00olKU003oabE00?o6Y@00olETP04o`j?00?o18/00ol0Q`D3o`214@?o07/N
0ol0M2X3o`1/=@?o06A00ol0FdP3o`1AC@?o04580ol0;cl4o`0P=P?o01D^0ol03BL3o`078@?o00@L
0ol00QX3o`026@?o00<K0ol01Ql3o`0<9P?o01L`1?l0:C`3o`15BP?o05]80ol0KC@3o`204`?o6i@0
0omHZ003oj2l00?ocZd00ooNOP03on]A00?omBX01?ol4003ooh500?oo@`00oog8`03one900?oh7L0
0oo@Z003ojFm00?oF:P00olGT`03o`1m6P?o06Pk1?l0E4`3o`0e@P?o01`c0ol03BP3o`067`?o00<J
0ol00QT3o`0370?o00PQ0ol042X3o`0O=@Co03I30ol0DTd3o`1R@@?o07</0ol0P`d3oaZD00?oBJ@0
0omm/`03okC000?ocK000ooHT@03on5d00CojET00oo_@@03oo@]00?on1h00ook4P03ood:00?ooPD0
1_oo0P03ool300?ooP@00oon1P04ooh700?oo@P00oom2@03ood800?ooPL00oon1P03ool300?oo`40
0ooo0003ool100?ooPD00oom2`04ooXF00?omRP00oo_@`03onIS00?ofhP00oo=[`03ojBm00?oEjP0
0olCT@03o`1j7`?o06911oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0
2B<3o`047@?o00<J0ol011`3o`078@?o00lY0ol06c<3o`0/?P?o04990ol0ED/3o`1P@`Co06Xh0ol0
Lb/3o`1k7@?o088?0ol0R083o`R=00?o4I400olGT`03oa^D00?o79D00olJU003oaFB00Co3Xl00ol4
R`03o`271@?o084A0ol0Nah3o`1d:P?o06`e0ol0I403o`1KB0?o055=0ol0@DP3o`0_?`Co020f0ol0
5Bh3o`0=9`?o00LQ0ol011`3o`026P?o008I0ol00a/3o`067`?o00`V0ol05c04o`0Y?0?o04E:0ol0
FdP3o`1]=0?o080C0olKU003oeRX00?oX;`00oo>[@03omin00?oje400ooe:P04oo`@00?ooPD00oom
3003ooLS00?okDT00ooPM`03om2X00?oYKd00omHZ003oaNC00?o07dJ0ol0J3/4o`1DC0?o03E20ol0
73<3o`0=:0?o00HO0ol00aX3o`026@?o00<L0ol02243o`0@:P?o01le1?l0=T<3o`1BC@?o06910ol0
Lb`3o`233@?o6Y@00om9Y003ogfc00?o]<000oo=/003omRA00?ohG@01?oYF@03onm100?om2d00ooh
7P03oo/B00?oo@X00oon1@06ool200?oo`<00oon1003ooh600CooPL00oom2003ood900?oo@P00oon
1`03ooh600?oo`<00ooo0@03ool000?oo`400oon1@03ood;00ConQH00oof:003onm300?oiV<00ooK
R003olf_00?oY;d00omGZ003oa>A00?o07XO0ol0HT47ooooo`7o00000Oooool001gooooo00?o0000
ooooooooool01Oooool3o`0H<0?o00/U0ol01Ah6o`036P?o00DN0ol02R@3o`0A:`?o01dd0ol0;Ch3
o`10B0Co055=0ol0FTP3o`1R@@?o06Xh0ol0L303o`1e:0?o07TQ0ol0O1`3o`1n60?o07lG0ol0OQL3
o`1m6PCo07/N0ol0N2<3o`1d:P?o06lb0ol0JCT3o`1S@0?o05a70ol0E4`3o`1:C@?o03U50ol0:Sd3
o`0N=@Co01@]0ol03BL3o`088@?o00@M0ol00aX3o`026@?o00<J0ol01Ad3o`098`?o014[0ol07cD4
o`0d@P?o055=0ol0HT43o`1d:P?o08L50ol/VP03of^^00?o/l000ooBX`03on5e00?okDT00oog9@04
oo`=00?ooPD00ool3@03ooLU00?okDX00ooPM`03om2W00?oZ;h00omLZP03oabD00?o07lE0ol0JSL4
o`1GBP?o03]50ol083H3o`0@:P?o00LQ0ol00a/3o`026@?o00<J0ol01Ql3o`0<9P?o01L`1?l0:S`3
o`15BP?o05U90ol0JCT3o`1i8@?o08T10olVV003oeBW00?oQ[D00onh`P03olf_00?oei<01?oPN003
onMP00?okDX00oob=`03ooHX00?onA/00ook4P03ood<00?ooPL00oon1003ool200[oo`402Ooo0003
ool100?oo`800oon1@03ood900?ona400ooi7003ooD/00Col4000ooXF`03omil00?odZ000oo4a003
oh2d00?o@:400ol3R`03o`1d:P?o05e60ol0@4P7ooooo`7o00000Oooool001gooooo00?o0000oooo
ooooool01Oooool3o`0H<0?o00/U0ol01Ah6o`036P?o00DN0ol02R@3o`0A:`?o01dd0ol0;Ch3o`10
B0Co055=0ol0FTP3o`1R@@?o06Xh0ol0L303o`1e:0?o07TQ0ol0O1`3o`1n60?o07lG0ol0OQL3o`1m
6PCo07/N0ol0N2<3o`1d:P?o06lb0ol0JCT3o`1S@0?o05a70ol0E4`3o`1:C@?o03U50ol0:Sd3o`0N
=@Co01@]0ol03BL3o`088@?o00@M0ol00aX3o`026@?o00<J0ol01Ad3o`098`?o014[0ol07cD4o`0d
@P?o055=0ol0HT43o`1d:P?o08L50ol/VP03of^^00?o/l000ooBX`03on5e00?okDT00oog9@04oo`=
00?ooPD00ool3@03ooLU00?okDX00ooPM`03om2W00?oZ;h00omLZP03oabD00?o07lE0ol0JSL4o`1G
BP?o03]50ol083H3o`0@:P?o00LQ0ol00a/3o`026@?o00<J0ol01Ql3o`0<9P?o01L`1?l0:S`3o`15
BP?o05U90ol0JCT3o`1i8@?o08T10olVV003oeBW00?oQ[D00onh`P03olf_00?oei<01?oPN003onMP
00?okDX00oob=`03ooHX00?onA/00ook4P03ood<00?ooPL00oon1003ool200[oo`402Ooo0003ool1
00?oo`800oon1@03ood900?ona400ooi7003ooD/00Col4000ooXF`03omil00?odZ000oo4a003oh2d
00?o@:400ol3R`03o`1d:P?o05e60ol0@4P7ooooo`7o00000Oooool001gooooo00?o0000oooooooo
ool01Oooool3o`0H<0?o00/U0ol01Ah6o`036P?o00DN0ol02R@3o`0A:`?o01dd0ol0;Ch3o`10B0Co
055=0ol0FTP3o`1R@@?o06Xh0ol0L303o`1e:0?o07TQ0ol0O1`3o`1n60?o07lG0ol0OQL3o`1m6PCo
07/N0ol0N2<3o`1d:P?o06lb0ol0JCT3o`1S@0?o05a70ol0E4`3o`1:C@?o03U50ol0:Sd3o`0N=@Co
01@]0ol03BL3o`088@?o00@M0ol00aX3o`026@?o00<J0ol01Ad3o`098`?o014[0ol07cD4o`0d@P?o
055=0ol0HT43o`1d:P?o08L50ol/VP03of^^00?o/l000ooBX`03on5e00?okDT00oog9@04oo`=00?o
oPD00ool3@03ooLU00?okDX00ooPM`03om2W00?oZ;h00omLZP03oabD00?o07lE0ol0JSL4o`1GBP?o
03]50ol083H3o`0@:P?o00LQ0ol00a/3o`026@?o00<J0ol01Ql3o`0<9P?o01L`1?l0:S`3o`15BP?o
05U90ol0JCT3o`1i8@?o08T10olVV003oeBW00?oQ[D00onh`P03olf_00?oei<01?oPN003onMP00?o
kDX00oob=`03ooHX00?onA/00ook4P03ood<00?ooPL00oon1003ool200[oo`402Ooo0003ool100?o
o`800oon1@03ood900?ona400ooi7003ooD/00Col4000ooXF`03omil00?odZ000oo4a003oh2d00?o
@:400ol3R`03o`1d:P?o05e60ol0@4P7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool0
1Oooool3o`0H<0?o00/U0ol01Ah6o`036P?o00DN0ol02R@3o`0A:`?o01dd0ol0;Ch3o`10B0Co055=
0ol0FTP3o`1R@@?o06Xh0ol0L303o`1e:0?o07TQ0ol0O1`3o`1n60?o07lG0ol0OQL3o`1m6PCo07/N
0ol0N2<3o`1d:P?o06lb0ol0JCT3o`1S@0?o05a70ol0E4`3o`1:C@?o03U50ol0:Sd3o`0N=@Co01@]
0ol03BL3o`088@?o00@M0ol00aX3o`026@?o00<J0ol01Ad3o`098`?o014[0ol07cD4o`0d@P?o055=
0ol0HT43o`1d:P?o08L50ol/VP03of^^00?o/l000ooBX`03on5e00?okDT00oog9@04oo`=00?ooPD0
0ool3@03ooLU00?okDX00ooPM`03om2W00?oZ;h00omLZP03oabD00?o07lE0ol0JSL4o`1GBP?o03]5
0ol083H3o`0@:P?o00LQ0ol00a/3o`026@?o00<J0ol01Ql3o`0<9P?o01L`1?l0:S`3o`15BP?o05U9
0ol0JCT3o`1i8@?o08T10olVV003oeBW00?oQ[D00onh`P03olf_00?oei<01?oPN003onMP00?okDX0
0oob=`03ooHX00?onA/00ook4P03ood<00?ooPL00oon1003ool200[oo`402Ooo0003ool100?oo`80
0oon1@03ood900?ona400ooi7003ooD/00Col4000ooXF`03omil00?odZ000oo4a003oh2d00?o@:40
0ol3R`03o`1d:P?o05e60ol0@4P7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Ooo
ool3o`0iA0?o01he0ol03RT3o`0780?o00<K0ol00QT3o`036`?o00HO0ol02bD3o`0B;0?o01`d1?l0
:C`3o`0gA0?o04M;0ol0DTd3o`1HB@?o05e50ol0HT43o`1U?P?o06Lk0ol0J3X3o`1Y>P?o06Pj1?l0
IS`3o`1T?`?o06520ol0GDH3o`1HBP?o059=0ol0BT`3o`0lAP?o02lo0ol093T3o`0J<P?o018/1?l0
32H3o`078@?o00@M0ol00aX3o`026@?o008J0ol011`3o`078@?o00dX0ol06343o`0Y?0Co04=90ol0
F4T3o`1Y>@?o07/M0ol:SP03ocnQ00?oP;<00oo5``03omFH00?oi6/00oo_@P03ooPP00Coo@/00oon
1003oo`>00?omRL00oo]B`03on1h00?od:L00on[_P03of2[00?o89H00ol0PA43o`1]=0Co05Y80ol0
@DP3o`0T>@?o01</0ol02B<3o`047@?o008I0ol00QX3o`047@?o00TS0ol04R/4o`0P=P?o03E30ol0
D4d3o`1OA0?o06hb0ol0OQT3o`N=00?o;Y/00omIZ@03ohNe00?o]/400oo;/`04omFJ00?ogH800ooT
J`03onUG00?okTH00oob=`03ooD[00?omb400ooi6P03oo/D00?oo1000ool3@0:ood;00?oo@`00ool
3P03oo/B00?onQL00ooh7`03ooDY00?olSP00oo]BP03onMQ00Cogg/00ooEV@03olRk00?oV;X00omJ
Z@03ob6F00?o088?0ol0K3D3o`1GBP?o03E30ol06C47ooooo`7o00000Oooool001gooooo00?o0000
ooooooooool01Oooool3o`0iA0?o01he0ol03RT3o`0780?o00<K0ol00QT3o`036`?o00HO0ol02bD3
o`0B;0?o01`d1?l0:C`3o`0gA0?o04M;0ol0DTd3o`1HB@?o05e50ol0HT43o`1U?P?o06Lk0ol0J3X3
o`1Y>P?o06Pj1?l0IS`3o`1T?`?o06520ol0GDH3o`1HBP?o059=0ol0BT`3o`0lAP?o02lo0ol093T3
o`0J<P?o018/1?l032H3o`078@?o00@M0ol00aX3o`026@?o008J0ol011`3o`078@?o00dX0ol06343
o`0Y?0Co04=90ol0F4T3o`1Y>@?o07/M0ol:SP03ocnQ00?oP;<00oo5``03omFH00?oi6/00oo_@P03
ooPP00Coo@/00oon1003oo`>00?omRL00oo]B`03on1h00?od:L00on[_P03of2[00?o89H00ol0PA43
o`1]=0Co05Y80ol0@DP3o`0T>@?o01</0ol02B<3o`047@?o008I0ol00QX3o`047@?o00TS0ol04R/4
o`0P=P?o03E30ol0D4d3o`1OA0?o06hb0ol0OQT3o`N=00?o;Y/00omIZ@03ohNe00?o]/400oo;/`04
omFJ00?ogH800ooTJ`03onUG00?okTH00oob=`03ooD[00?omb400ooi6P03oo/D00?oo1000ool3@0:
ood;00?oo@`00ool3P03oo/B00?onQL00ooh7`03ooDY00?olSP00oo]BP03onMQ00Cogg/00ooEV@03
olRk00?oV;X00omJZ@03ob6F00?o088?0ol0K3D3o`1GBP?o03E30ol06C47ooooo`7o00000Oooool0
01gooooo0_l00006ooooo`?o03U40ol07SD3o`0>:@?o00LP0ol00a/3o`026@?o00<K0ol01Ql3o`0;
9@?o018/0ol073@4o`0Y?0?o03M40ol0Ad/3o`1BC@?o05Q90ol0GDD3o`1R@@?o06Dn0ol0Ic/3o`1X
>P?o06Tj0ol0J3X4o`1V?0?o06@o0ol0HD83o`1MAP?o05Q:0ol0DTd3o`1:C0?o03a60ol0;cl3o`0T
>@?o01Xb0ol04R`4o`0<9P?o00LQ0ol011d3o`036P?o008I0ol00QX3o`0470?o00LQ0ol03BP3o`0H
<@?o02Tl1?l0@dT3o`1HB@?o06Ti0ol0Nad3o`Z>00?o?j400on0/`03olG300?oeIP00ooTJ`03onm2
00?on2001?om2`03ooh400?oo0h00oof9`03one;00?oh7P00oo@Y`03oj^n00?oH:/00olPUP03o`21
4@?o06dd1?l0FTP3o`11B0?o02@i0ol04b`3o`098`?o00@M0ol00QT3o`026P?o00@M0ol02B<3o`0B
:`Co020f0ol0=D<3o`1@C@?o05m40ol0KS83o`1n6@?o1hd00ol^V`03oeVY00?oQkD00onf`@03ol^c
00CoeIX00ooMPP03onA[00?ojEL00oo^AP03oo8g00?omB/00oog8@03ooTJ00?ona@00ool4003oo`=
00[oo@/00oom3003oo`>00?ona800ooj5`03ooPO00?omBT00oob>003one:00?oif401?oON`03omFI
00?ob;/00onH^P03oeZY00?o8IH00ol0PPl3o`1/=@?o05M:0ol0=D<3o`0I<@Kooooo0_l00001oooo
o`007Oooool00ol0003oooooooooo`05ooooo`?o05e50ol0Ad/3o`0X>`?o01@^0ol02R@3o`047@?o
008J0ol00QT3o`036`?o00HO0ol02R@4o`0@:P?o01P`0ol08CL3o`0[?@?o03E30ol0?dL3o`18C0?o
04m>0ol0DTd3o`1CC0Ko05A<1?l0Dd`3o`1AC@?o04m>0ol0Ad/3o`0oA`?o03I30ol0;Ch3o`0T>@?o
01`d0ol05Bh3o`0?:@?o00XT1?l01b03o`047@?o00<J0ol00QT3o`026P?o00<L0ol01Ql3o`0;9@?o
01@]0ol08CL3o`0f@`Co055=0ol0H4<3o`1a;`?o08<?0olLU@03oeBW00?oUKT00oo:]`03omV=00?o
iV800ooa>P03ooTK00Coo@T00oon1003oo`?00?omRP00oo/C@03on1h00?od:H00on^_`03ofF/00?o
9YP00ol0Q0`3o`1`<0Co05e60ol0B4`3o`0Z?0?o01H_0ol02bD3o`057P?o00<J0ol00QT3o`036`?o
00HP0ol03BL4o`0H<0?o02Pl0ol0@4P3o`1FB`?o06@o0ol0LRd3o`204`?o2hh00ol`W003oeRX00?o
PK@00on/_`04olRl00?odJD00ooHT003omil00?oi6X00ooXFP03ona=00?okd800oob>@03oo<a00?o
mB`00oof:@04ooHW00?omRH00oof9`03ooDZ00?om2l00oob=P03oo1000?ok4`00ooXG003on9`00?o
fhH00ooCX004olRk00?oX[`00omY[@03oc>M00?o0h/00ol0N2@3o`1T?`?o04m>0ol0:cd3o`0C;@?o
00PQ1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0GDD3o`17B`?o02Pk
0ol052h3o`0:90?o00@M0ol00QX3o`026@?o00<K0ol01Ql3o`0:90Co010Z0ol06303o`0Q=`?o02/m
0ol0=D<3o`0oA`?o04Q<0ol0Cdh3o`1BC@?o05=<1_l0E4`4o`1CC0?o055=0ol0Cdh3o`17B`?o03m7
0ol0=T<3o`0]?P?o02@i0ol073@3o`0E;P?o00lY0ol02R@4o`0780?o00@M0ol00aX3o`026@?o008J
0ol00a`3o`067`?o00/U0ol052d3o`0Q=`?o03I31?l0DDd3o`1P@`?o074_0ol0P`l3oabE00?oE:L0
0onE^@03olZg00?ofHd00ooVHP03oo4j00?onA/01?om2@03ooh400?oo0l00oof:003ona=00?oh7P0
0oo@YP03ojjo00?oIJ`00olVV003o`2430?o070`1?l0GDH3o`18C0?o02Xl0ol05Rl3o`0;9@?o00DN
0ol00aX3o`026@?o00<K0ol01R03o`0=9`Co01P`0ol0:3`3o`10B0?o05I;0ol0I3l3o`1b;@?o080C
0ol;SP03oc2L00?oF:P00on1]003ojbo00Cob;`00ooAY@03omR@00?ogW`00ooTJP03onQJ00?ok4d0
0oo_@P03oo8i00?olc400ooe;003ooHY00ComRL00oof9P03ooHW00?omBX00ood;`03oo8f00?ol400
0oo/C003onQL00?ohW000ooKQP03om>P00Cob;/00onR_003ofV]00?o<id00ol3R`03o`1h90?o06@o
0ol0Cdh3o`0[?@?o01<]0ol02247ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Ooo
ool3o`1MA@?o04M;0ol0:3/3o`0D;P?o00XT0ol011d3o`026P?o008I0ol00a/3o`067`?o00XT1?l0
42X3o`0H<0?o024g0ol0:cd3o`0e@`?o03m70ol0B4`3o`1?CP?o059=0ol0Dd`6o`1DC0Co05=<0ol0
DDd3o`1?CP?o04M;0ol0?dL3o`0f@`?o02dn0ol093T3o`0L=0?o01D^0ol03bT3o`0:90Co00LP0ol0
11d3o`036P?o008I0ol00QX3o`0370?o00HO0ol02bD3o`0D;@?o024g0ol0=T<4o`1AC@?o06130ol0
LBl3o`233`?o79D00omDY`03oiFi00?ob[L00ooIS@03onIR00?olCX00ooi6`04ood900?ooP@00ool
3`03ooHX00?ok4d00ooPN003om2V00?o[[l00omU[003obJH00?o08@<0ol0L304o`1MAP?o04Q<0ol0
:S`3o`0F;`?o00/U0ol01Ah3o`036P?o008I0ol00a/3o`0680?o00dW1?l06303o`0X?0?o04180ol0
ET/3o`1T?`?o078]0ol0P1<3o`^>00?o<9`00omHZ003oh6d00?o[;l01?o8_003om6U00?of9000ooN
O003onAZ00?oj5X00oo/C@03onm200?olST00ooc<@03ooD/00?omRT01?of9`03ooHV00?omRL00ooe
:P03oo@_00?olSH00oo`@003ona<00?oj5`00ooRL003om^600?odj001?o8^`03oj:l00?oJJd00olc
W@03o`>;00?o07PT0ol0I3l3o`1?CP?o02/m0ol04bd3o`088@Oooooo0Ol00001ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`?o07TQ0ol0ISd3o`1DC0?o03I30ol07CD3o`0?:@?o00LQ0ol011`6
o`026@?o00<K1?l01Ah3o`088P?o00dW0ol04R`3o`0G<0?o01dd0ol08cP3o`0Y?0?o02dn0ol0<403
o`0b@@?o03=11?l0<T43o`0`@0?o02dn0ol0:C`3o`0T>@?o01he0ol06C43o`0D;@?o00lY0ol02bD3
o`088P?o00DN1?l011`3o`036P?o008I0ol00QX3o`036`?o00HO0ol02R@3o`0A:`?o01`d0ol0;Sh3
o`17B`Co05U90ol0J3X3o`1i8@?o0XX00olaW003ofZ^00?o[;l00oo?Z`03omf100?ojEP00ooc<`03
ooXG00CooPL00oon1@03oo/A00?omBX00oo/CP03on1i00?odJD00ona`003ofZ]00?o:iX00ol0QPL3
o`1c;0Co06130ol0Cdh3o`0_?`?o01Xb0ol03RP3o`0780?o00<K0ol00QT3o`036P?o00DM0ol02B<4
o`0A:`?o01he0ol0<403o`19C0?o05U90ol0IS`3o`1d:P?o084A0ol;SP03obbJ00?oD:H00ome/004
oiZj00?o_/<00oo;]@03om6S00?oei<00ooLP`03on1f00?oi6/00ooWH@03onUJ00?ojUD00oo[D@04
on]@00?oje400ooZE003onUI00?oif000ooTJP03on1g00?ofhL00ooEV@03olj^00?oa<@00onI^P04
ofZ^00?o?:000ol>S`03o`1n60?o06`f0ol0FDT3o`0oA`?o020f0ol03RP3o`067`?o00<J1oooool1
o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0NB43o`1V?@?o05A<0ol0=T<3o`0M
=@?o00lY0ol01b43o`0470Ko008I0ol00a/4o`057P?o00PR0ol03BL3o`0B;0?o01L`0ol07C@3o`0S
>0?o02Tl0ol0;Ch3o`0`@0?o03910ol0<d44o`0b@@?o03100ol0;Ch3o`0Y?0?o02@i0ol07SD3o`0I
<@?o01@]0ol03bT3o`0;9@?o00PR0ol01Ah4o`0470?o00<J0ol00QT3o`026P?o00<K0ol01Ql3o`0:
90?o014[0ol073@3o`0^?P?o04M;1?l0FDT3o`1X>P?o07TQ0ol2RP03oc6L00?oJZh00on/_`03oln[
00?ogH400ooYF003oo<c00?onQL01?on1`03ooh500?ona400ooe:P03ona>00?oh7T00ooAY@03ok70
00?oJZd00ol[VP03o`261`?o07</1?l0H4<3o`1?CP?o02lo0ol06S83o`0>:0?o00LP0ol00a/3o`02
6@?o00<J0ol01Ad3o`098`Co014[0ol07SD3o`0`@0?o04U<0ol0FDT3o`1V?0?o07@Z0ol0PA43o`^>
00?o;9X00om@YP03ogF`00CoV[X00onn``03ol^e00?odJ<00ooGT`03omb300?oh7H00ooTJ`03onMQ
00?ojEX00ooZE@03on]A00Coje000oo[D@03onYD00?ojET00ooWH003onAZ00?oh7L00ooKQ`03omFI
00?ocZh00oo4a003oiVj00CoJZh00ollX003o`j?00?o07hH0ol0K3H3o`1IB@?o03m70ol083H3o`0>
:0?o00HO0ol00aX7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1i8@?o
06Hm0ol0E4`3o`0f@`?o01de0ol03bT3o`078@?o00@L1_l00QT3o`036`Co00DN0ol02283o`0=9`?o
018/0ol05c03o`0M=0?o02<h0ol0:C`3o`0]?P?o03100ol0<T43o`0c@@Co03910ol0<403o`0]?P?o
02Tl0ol093T3o`0N=@?o01Ta0ol052d3o`0?:@?o00/U0ol02283o`057PCo00@L0ol00aX3o`026@?o
008J0ol00a/3o`067`?o00XT0ol04B/3o`0L=0?o02hn0ol0Ad/4o`1IB@?o06Pj0ol0NB43o`::00?o
<I`00omZ[P03ojbo00?ocj/00ooMP@03onUH00?olc<00ooj5`04ooh700?ooPD00ook4@03ooDZ00?o
k4h00ooPN@03om6U00?o/L000omZ[@03ob^J00?o08H70ol0Lb`4o`1P@`?o04m>0ol0;cl3o`0J<P?o
00hX0ol01b03o`036`?o008I0ol00aX3o`057@?o00TS1?l04B/3o`0N=@?o03100ol0BD`3o`1IB@?o
06Hl0ol0M2X3o`214@?o2hh00ol/VP03oe2V00?oMK001?nJ^P03okk300?obkD00ooAX`03omNC00?o
g8<00ooPMP03onA[00?oif400ooYFP03onYE00?oje401?o[D003on]A00?ojU@00ooYF@03onMP00?o
i6X00ooPM`03om^700?oeIT00oo>[P03olC400?oVKX01?mZ[P03ocbP00?o3Xl00ol0OQP3o`1/=P?o
05U90ol0?dL3o`0P=P?o00hX0ol01Ql3o`036POooooo0Ol00001ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`?o7YH00ol0Q0`3o`1a;`?o05i50ol0BTd3o`0[?@?o01P`0ol032L3o`0680?o00<K
1ol00QT3o`036P?o00@M0ol01Ql3o`098P?o00/V0ol03bT3o`0B:`?o01@^0ol05c03o`0H<@Oo01Ta
0ol06343o`0G<0?o01D^0ol04R`3o`0@:P?o00dW0ol02R@3o`088@?o00HO0ol011`3o`036`Oo008I
0ol00QX3o`0470?o00HO0ol02R@3o`0@:P?o01Xb0ol0:3/3o`0nA`?o05=<1?l0HT43o`1a;P?o084A
0olETP03odNS00?oP[@00oo3a003om>N00?ohGH00oo/CP03ooD/00?ona<01oon1@03oo/B00?omB`0
0oo[C`03ommi00?odJ@00ond`@03ofj_00?o<I`00ol0R@43o`1f9`Co06=00ol0DTd3o`0f@`?o01lf
0ol04B/3o`088P?o00@M0ol00QX3o`026@?o00<K0ol01R04o`0<9P?o01D_0ol08cP3o`0f@`?o04m>
0ol0FdL3o`1X>`?o07@Z0ol0P1@3o`F<00?o8YL00om1X@04of6[00?oP;@00onO^`03ok_200?ob;/0
0oo>[P03om:R00?oeIP00ooHS`03omZ900?og8D01ooLP`03omb500?ofXT00ooHT003omFI00?odJD0
0oo</`03olG300?oYkd00on3]003oebZ00?o=Id01?l?T003o`214P?o070_0ol0Gd@3o`1>CP?o02dn
0ol05c03o`0:90?o00@L0ol00QX3o`047@Oooooo0Ol00001ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`?o7YH00ol0Q0`3o`1a;`?o05i50ol0BTd3o`0[?@?o01P`0ol032L3o`0680?o00<K1ol0
0QT3o`036P?o00@M0ol01Ql3o`098P?o00/V0ol03bT3o`0B:`?o01@^0ol05c03o`0H<@Oo01Ta0ol0
6343o`0G<0?o01D^0ol04R`3o`0@:P?o00dW0ol02R@3o`088@?o00HO0ol011`3o`036`Oo008I0ol0
0QX3o`0470?o00HO0ol02R@3o`0@:P?o01Xb0ol0:3/3o`0nA`?o05=<1?l0HT43o`1a;P?o084A0olE
TP03odNS00?oP[@00oo3a003om>N00?ohGH00oo/CP03ooD/00?ona<01oon1@03oo/B00?omB`00oo[
C`03ommi00?odJ@00ond`@03ofj_00?o<I`00ol0R@43o`1f9`Co06=00ol0DTd3o`0f@`?o01lf0ol0
4B/3o`088P?o00@M0ol00QX3o`026@?o00<K0ol01R04o`0<9P?o01D_0ol08cP3o`0f@`?o04m>0ol0
FdL3o`1X>`?o07@Z0ol0P1@3o`F<00?o8YL00om1X@04of6[00?oP;@00onO^`03ok_200?ob;/00oo>
[P03om:R00?oeIP00ooHS`03omZ900?og8D01ooLP`03omb500?ofXT00ooHT003omFI00?odJD00oo<
/`03olG300?oYkd00on3]003oebZ00?o=Id01?l?T003o`214P?o070_0ol0Gd@3o`1>CP?o02dn0ol0
5c03o`0:90?o00@L0ol00QX3o`047@Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05
ooooo`?o7YH00ol0Q0`3o`1a;`?o05i50ol0BTd3o`0[?@?o01P`0ol032L3o`0680?o00<K1ol00QT3
o`036P?o00@M0ol01Ql3o`098P?o00/V0ol03bT3o`0B:`?o01@^0ol05c03o`0H<@Oo01Ta0ol06343
o`0G<0?o01D^0ol04R`3o`0@:P?o00dW0ol02R@3o`088@?o00HO0ol011`3o`036`Oo008I0ol00QX3
o`0470?o00HO0ol02R@3o`0@:P?o01Xb0ol0:3/3o`0nA`?o05=<1?l0HT43o`1a;P?o084A0olETP03
odNS00?oP[@00oo3a003om>N00?ohGH00oo/CP03ooD/00?ona<01oon1@03oo/B00?omB`00oo[C`03
ommi00?odJ@00ond`@03ofj_00?o<I`00ol0R@43o`1f9`Co06=00ol0DTd3o`0f@`?o01lf0ol04B/3
o`088P?o00@M0ol00QX3o`026@?o00<K0ol01R04o`0<9P?o01D_0ol08cP3o`0f@`?o04m>0ol0FdL3
o`1X>`?o07@Z0ol0P1@3o`F<00?o8YL00om1X@04of6[00?oP;@00onO^`03ok_200?ob;/00oo>[P03
om:R00?oeIP00ooHS`03omZ900?og8D01ooLP`03omb500?ofXT00ooHT003omFI00?odJD00oo</`03
olG300?oYkd00on3]003oebZ00?o=Id01?l?T003o`214P?o070_0ol0Gd@3o`1>CP?o02dn0ol05c03
o`0:90?o00@L0ol00QX3o`047@Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05oooo
o`?oLJl00om0X@03o`j?00?o07dJ0ol0JSP3o`1HBP?o03m70ol09CT3o`0E;P?o00`V0ol01R04o`04
70?o008J1_l00QT3o`036`?o00@L0ol01Ah3o`0680?o00PR0ol02B<3o`0:90[o00/U0ol02R@3o`09
8`?o00PR0ol01b43o`067`?o00DN0ol011`3o`036`?o008J1ol00QT3o`036P?o00@L0ol01R03o`0:
90?o010Z0ol06C43o`0V>P?o03Q40ol0D4h3o`1MAPCo06/g0ol0NQl3o`6:00?o;9X00omPZ`03oi^k
00?ob[P00ooHT@03onAZ00?okTD00oof9@03oo`?00CooP@00oon1P03oo/D00?om2h00oo[D@03ommi
00?odJ@00ong`@03og>`00?o=Yh00ol4R`03o`1i8PCo06Ll0ol0ET/3o`0nA`?o02Di0ol05Bh3o`0;
9@?o00DO0ol00a/3o`026@?o00<J0ol011d4o`088P?o00lY0ol06C43o`0W>`?o03Y50ol0D4h3o`1K
A`?o06Ll0ol0LRd3o`1m6P?o08P40olCT@04obfK00?oAj<00omPZ`03ogVb00?oSkP00onT_@03okG1
00?oa<@00oo7_P03olVi00?ob[L00oo:]P04olZg00?obK/00oo6`003oko300?o[Kl00onG^P03ognc
00?oHj/00om4XP03obFH00?o1X`00ol0OaH4o`1a;P?o06910ol0Dd`3o`0g@`?o01le0ol03bT3o`06
80?o00<J0ol00QX3o`067`?o010Z1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Go
oooo0oma[`03od2Q00?o3Xl00ol0OAX3o`1Z>0?o05Q:0ol0?dL3o`0U>@?o01D^0ol032H3o`0680Co
00@L0ol00QX6o`026@?o00<K0ol011`3o`057P?o00HP0ol02283o`098`?o00XT2_l02bD3o`0:90?o
00TS0ol02283o`078@?o00HO0ol01Ah3o`0470?o00<K0ol00QX7o`026@?o00<J0ol011`3o`0680?o
00XT0ol042X3o`0I<@?o02Hj0ol0>4@3o`1@CP?o05e61?l0JcL3o`1j7`?o0HX00ol/VP03of2[00?o
Vk/00oo:^003omRA00?oi6X00oo^A@03ooHU00?oo0l01?on1003ooh600?ona@00ood;P03on]A00?o
ggT00ooAY003okO100?oLk000olfWP03o`B;00?o07TR1?l0Ic`3o`1FB`?o03i70ol09CT3o`0E;P?o
00/U0ol01Al3o`036`?o008I0ol00aX3o`047@Co00PR0ol03bT3o`0I<@?o02Lk0ol0>TD3o`1@CP?o
05]70ol0Ic`3o`1b;@?o07dJ0ol0R0@3oa>A00Co;I/00om7X`03of2[00?oNK800on?^003ojBm00?o
]L400oo4a003olNn00?obKT00oo:]`03olZf00Cob[L00oo9^`03olK000?o_l<00on]_`03oiNj00?o
Ok<00omSZ`03odBR00?o9IP00ol6S003o`1o5PCo074^0ol0HT43o`1CC0?o03M30ol07cD3o`0?:@?o
00HP0ol00aX3o`026P?o00HO0ol042X7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool0
1Oooool3og6_00?o@:400ol>S`03o`1m6P?o06Xh0ol0F4X3o`0oA`?o02Di0ol05Bh3o`0<9P?o00HP
1?l011`3o`026PKo008I0ol00a/3o`0470?o00DN0ol01R03o`088P?o00TS0ol02R@:o`0;9@?o00XT
0ol02B<3o`088P?o00LQ0ol01Ql3o`057P?o00@L0ol00a/3o`026POo008I0ol00aX3o`0470?o00HP
0ol02R@3o`0@:P?o01Ta0ol09SX3o`0hA0?o051>0ol0GDH4o`1[=`?o07XO0ol1RP03obbJ00?oH:/0
0onK^`03olZh00?of9400ooTJP03oni500?omRD00ool3`04ooh400?ooPH00ook5003oo@^00?oje40
0ooON@03om6T00?o]l400omc/003ocJN00?o18/00ol0NB84o`1W?0?o05I;0ol0?TL3o`0U>@?o01D^
0ol02bD3o`057`?o00<K0ol00QT3o`036P?o00@M1?l02283o`0?:@?o01Ta0ol09c/3o`0jA@?o051>
0ol0FdL3o`1W?0?o078]0ol0OAX3o`2810?o4i401?l]V`03odNS00?oH:/00omi/P03ohnh00?oY;d0
0one`@03olC400?oakh00oo9^@03olZg00?ob[H01?o:]`03olVk00?oa/000ono``03ojfo00?oUkX0
0omo/`03of>[00?oA:800olUV003o`J<00?o07lF1?l0LBh3o`1R@@?o05=<0ol0=d<3o`0O=@?o00lY
0ol01R03o`036P?o008J0ol01Ql3o`0@:POooooo0Ol00001ooooo`007Oooool2o`0000Kooooo0oo0
``03oi^k00?oJJd00olcW@03o`:;00?o07LU0ol0I3l3o`1CC0?o03U50ol08cP3o`0E;PCo00`W0ol0
1b43o`057@?o00<K0ol00QX6o`026@?o008J1_l00a/3o`0470go00@M1_l011`3o`036`?o00<J0ol0
0QX9o`026@?o00<J1?l00a`3o`057P?o00LQ0ol02bD3o`0A:`?o01Ta0ol09CT3o`0f@`?o04e>0ol0
FTP3o`1W?0Co07DX0ol0Q0`3oaNC00?oAJ<00omj/P03okK100?ocjT00ooLQ003onMN00?olC/00ooh
7`03ood<00Coo`<00oon1`03ooXF00?om3000oo[DP03ommj00?odZ<00onk`P03ogRa00?o?J000ol:
SP03o`1l70Co06Xh0ol0FTP3o`16B`?o02/m0ol06C83o`0>:0?o00LQ0ol011`3o`026P?o008I0ol0
0a/4o`067`?o00XT0ol04B/3o`0K<`?o02Tl0ol0>dD3o`1?CP?o05Y80ol0I3l3o`1^<`?o07PS0ol0
PA84o`2:00?o59800olXV@03oc^O00?oCJD00omMZP03of^^00?oMk400omo/`03ohFe00?oR;H00on7
]@04oh:d00?oN[800om_[`03of6[00?oCjH00olkW`03obFH00?o3Xl00ol0Q@T3o`1j7`?o06hc0ol0
HD84o`1DC0?o03a60ol093T3o`0C;@?o00TS0ol011`3o`026@?o00<K0ol02283o`0F;`?o03911_oo
ool2o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0oo0``03oi^k00?oJJd00olcW@03
o`:;00?o07LU0ol0I3l3o`1CC0?o03U50ol08cP3o`0E;PCo00`W0ol01b43o`057@?o00<K0ol00QX6
o`026@?o008J1_l00a/3o`0470go00@M1_l011`3o`036`?o00<J0ol00QX9o`026@?o00<J1?l00a`3
o`057P?o00LQ0ol02bD3o`0A:`?o01Ta0ol09CT3o`0f@`?o04e>0ol0FTP3o`1W?0Co07DX0ol0Q0`3
oaNC00?oAJ<00omj/P03okK100?ocjT00ooLQ003onMN00?olC/00ooh7`03ood<00Coo`<00oon1`03
ooXF00?om3000oo[DP03ommj00?odZ<00onk`P03ogRa00?o?J000ol:SP03o`1l70Co06Xh0ol0FTP3
o`16B`?o02/m0ol06C83o`0>:0?o00LQ0ol011`3o`026P?o008I0ol00a/4o`067`?o00XT0ol04B/3
o`0K<`?o02Tl0ol0>dD3o`1?CP?o05Y80ol0I3l3o`1^<`?o07PS0ol0PA84o`2:00?o59800olXV@03
oc^O00?oCJD00omMZP03of^^00?oMk400omo/`03ohFe00?oR;H00on7]@04oh:d00?oN[800om_[`03
of6[00?oCjH00olkW`03obFH00?o3Xl00ol0Q@T3o`1j7`?o06hc0ol0HD84o`1DC0?o03a60ol093T3
o`0C;@?o00TS0ol011`3o`026@?o00<K0ol02283o`0F;`?o03911oooool1o`00007ooooo000Moooo
o`03o`000?oooooooooo00Gooooo0oo0``03oi^k00?oJJd00olcW@03o`:;00?o07LU0ol0I3l3o`1C
C0?o03U50ol08cP3o`0E;PCo00`W0ol01b43o`057@?o00<K0ol00QX6o`026@?o008J1_l00a/3o`04
70go00@M1_l011`3o`036`?o00<J0ol00QX9o`026@?o00<J1?l00a`3o`057P?o00LQ0ol02bD3o`0A
:`?o01Ta0ol09CT3o`0f@`?o04e>0ol0FTP3o`1W?0Co07DX0ol0Q0`3oaNC00?oAJ<00omj/P03okK1
00?ocjT00ooLQ003onMN00?olC/00ooh7`03ood<00Coo`<00oon1`03ooXF00?om3000oo[DP03ommj
00?odZ<00onk`P03ogRa00?o?J000ol:SP03o`1l70Co06Xh0ol0FTP3o`16B`?o02/m0ol06C83o`0>
:0?o00LQ0ol011`3o`026P?o008I0ol00a/4o`067`?o00XT0ol04B/3o`0K<`?o02Tl0ol0>dD3o`1?
CP?o05Y80ol0I3l3o`1^<`?o07PS0ol0PA84o`2:00?o59800olXV@03oc^O00?oCJD00omMZP03of^^
00?oMk400omo/`03ohFe00?oR;H00on7]@04oh:d00?oN[800om_[`03of6[00?oCjH00olkW`03obFH
00?o3Xl00ol0Q@T3o`1j7`?o06hc0ol0HD84o`1DC0?o03a60ol093T3o`0C;@?o00TS0ol011`3o`02
6@?o00<K0ol02283o`0F;`?o03911oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Go
oooo0oo?Z@03olj^00?oa/000onJ^P03of6[00?o9IP00ol0Q@X3o`1b;0?o06520ol0DTd3o`0iA@Co
02Di0ol05c03o`0?:@?o00XT0ol01R03o`047@?o00<K0ol00aXUo`026@?o008J0ol00a/3o`0470?o
00DN1?l01b03o`098`?o00dX0ol04bd3o`0K<`?o02Lk0ol0=d<3o`1;C@?o05Q90ol0I3l3o`1a;PCo
07lF0ol9S@03oc6L00?oH:/00onG^@03olNm00?oeIX00ooPMP03on]B00?olc800ooi6@03ood900Co
o`<00oon2003ooXH00?olc<00ooZE003ommk00?odZ800onn``03ogfc00?o@j800olAT003o`1o5PCo
06hc0ol0GTD3o`1?CP?o03=10ol07cD3o`0B;0?o00XT0ol01Ah3o`036`?o008I0ol00QX4o`0470?o
00HP0ol02bD3o`0B;0?o01`c0ol0:3`3o`0iA0?o04a=0ol0ETX3o`1OA0?o06Pj0ol0L2l4o`1h8P?o
080E0ol0QPL3o`J<00?o4i400olOUP03obVI00?o<I`00olfWP06ocVO00?o=ih01?laW003obVI00?o
7YD00olAT003o`::00?o08<=0ol0Nad3o`1b;@?o06Pk0ol0GDH3o`1AC@?o03]51?l09SX3o`0F;`?o
00/U0ol01Ah3o`036P?o008I0ol01Ah3o`0=9`?o01he0ol0@DP3o`1OA0Oooooo0Ol00001ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`?ocjT00oo>[P03olK000?oV[X00omQZ`03obFH00?o08D:
0ol0LR`3o`1Q@P?o059=0ol0>DD4o`0U>@?o01L`0ol03bT3o`0:90?o00HP0ol011d3o`036`?o00<J
9Ol00QT3o`026P?o00<K0ol011`3o`057PCo00LP0ol02B<3o`0=:0?o01<]0ol06c<3o`0W>`?o03M3
0ol0Bdd3o`1HB@?o06@o0ol0LBh4o`1o5P?o2Hd00olaW003of2[00?oUkT00oo7_@03omFJ00?oh7H0
0oo[DP03oo<b00?onAT00oom2@04ool300?ooPP00ooj6003oo<c00?ojU@00ooON`03om:R00?o_/<0
0omm/`03od>R00?o4I000ol0OaH4o`1^<`?o05i50ol0Cdh3o`0c@@?o01le0ol04R`3o`0:90?o00DN
0ol00a/3o`026@?o008J1?l011`3o`0680?o00/U0ol04R`3o`0L<`?o02Pl0ol0>D@3o`1<C@?o05I:
0ol0Gd@3o`1X>P?o070_1?l0N283o`205@?o08H70ol6S003oa>A00?o7iH00olYV@03oc6L00?o=Yh0
1_liW`03ocNN00Co<I`00olYV@03oajE00?o4I000ol2RP03o`233@?o07/M0ol0LRd3o`1X>`?o05e6
0ol0DDd3o`0kA@Co02Hj0ol05Rl3o`0;9@?o00DN0ol00aX3o`026@?o00DN0ol03BL3o`0N=@?o0458
0ol0Gd@7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3olnY00?ocZh00oo6
`003oiZj00?oHJ/00olUV003o`252P?o078/0ol0HD83o`1BC@?o03U51?l09CT3o`0G<0?o00lY0ol0
2R@3o`0680?o00@M0ol00a/3o`036RGo008I0ol00QX3o`036`?o00@L0ol01Ah4o`0780?o00TS0ol0
3BP3o`0C;@?o01/c0ol09c/3o`0g@`?o04]=0ol0F4T3o`1T?`?o074^1?l0OaH3o`V=00?o<I`00omP
Z`03oiNi00?oakd00ooEVP03on1f00?oje800ooc<P03ooTI00?oo@T01?oo0`03ooh800?onQP00ooc
<`03onYD00?ogg/00ooBXP03okk300?oOK<00om3XP03oa6@00?o07lF1?l0KS<3o`1NA@?o04m>0ol0
<d43o`0O=@?o018/0ol02R@3o`057P?o00<K0ol00QT3o`026PCo00@L0ol01R03o`0;9@?o018/0ol0
73<3o`0X?0?o03U40ol0C4d3o`1FBP?o05m40ol0J3X3o`1`;`Co07PR0ol0P1D3o`261`?o1X`00olC
T@03oanF00?o:IT00olaW003ocJN00Ko>Il00olgWP04oc6L00?o:IT00olNU@03oa6@00?o0XX00ol0
P`d3o`1k7@?o078]0ol0J3/3o`1MAP?o055=0ol0>dD4o`0V>P?o01H_0ol02bD3o`057P?o00<J0ol0
0QT3o`057P?o00dW0ol07SD3o`11B0?o05m41oooool1o`00007ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo0ooAY@03omNB00?of9400ooBX@03olRl00?oTKP00omAYP03oaZD00?o088@0ol0LBh3
o`1Q@PCo05=<0ol0?DL3o`0Z?0?o01dd0ol052d3o`0>:0?o00XT0ol01b43o`067`?o00@M0ol011`:
o`036`Ko00<J1_l00a/6o`0470?o00DN0ol01Ql3o`088@?o00XT1?l03BL3o`0A:`?o01P`0ol083H3
o`0[?@?o03Y50ol0CTh3o`1HB@?o06=00ol0Kc43o`1l70Co08T00olSU`03odfU00?oO[<00one`@03
olj]00?ofX/00ooUJ003oni700?omBX00ook5003ooh600Coo`<00oom2P03ooTK00?olSD00ooZEP03
ommk00?odZ800oo1a003oh>d00?oBJ@00olHT`03o`223`Co078]0ol0HT43o`1CC0?o03]60ol09SX3
o`0G<0?o00dW0ol01b43o`0470?o008J0ol00QT4o`036P?o00@M0ol01b43o`0;9P?o018/0ol06S83
o`0V>P?o03=10ol0@dT3o`1AC@?o05U90ol0H4<4o`1W?0?o06hc0ol0Lb/3o`1i8P?o07dJ0ol0PA83
o`2430?o08H80ol0Q`D3o`2710?o08L60ol0Q@T4o`233P?o07lE0ol0Nah3o`1e:0?o06lb0ol0Ic/3
o`1OA0?o05I;0ol0BT`3o`0e@P?o02<h0ol05Rl4o`0<9P?o00HO0ol00a/3o`026@?o00<K0ol02283
o`0D;@?o02/m0ol0DDd3o`1Y>@?o088?1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo
00Gooooo0ooAY@03omNB00?of9400ooBX@03olRl00?oTKP00omAYP03oaZD00?o088@0ol0LBh3o`1Q
@PCo05=<0ol0?DL3o`0Z?0?o01dd0ol052d3o`0>:0?o00XT0ol01b43o`067`?o00@M0ol011`:o`03
6`Ko00<J1_l00a/6o`0470?o00DN0ol01Ql3o`088@?o00XT1?l03BL3o`0A:`?o01P`0ol083H3o`0[
?@?o03Y50ol0CTh3o`1HB@?o06=00ol0Kc43o`1l70Co08T00olSU`03odfU00?oO[<00one`@03olj]
00?ofX/00ooUJ003oni700?omBX00ook5003ooh600Coo`<00oom2P03ooTK00?olSD00ooZEP03ommk
00?odZ800oo1a003oh>d00?oBJ@00olHT`03o`223`Co078]0ol0HT43o`1CC0?o03]60ol09SX3o`0G
<0?o00dW0ol01b43o`0470?o008J0ol00QT4o`036P?o00@M0ol01b43o`0;9P?o018/0ol06S83o`0V
>P?o03=10ol0@dT3o`1AC@?o05U90ol0H4<4o`1W?0?o06hc0ol0Lb/3o`1i8P?o07dJ0ol0PA83o`24
30?o08H80ol0Q`D3o`2710?o08L60ol0Q@T4o`233P?o07lE0ol0Nah3o`1e:0?o06lb0ol0Ic/3o`1O
A0?o05I;0ol0BT`3o`0e@P?o02<h0ol05Rl4o`0<9P?o00HO0ol00a/3o`026@?o00<K0ol02283o`0D
;@?o02/m0ol0DDd3o`1Y>@?o088?1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Go
oooo0ooAY@03omNB00?of9400ooBX@03olRl00?oTKP00omAYP03oaZD00?o088@0ol0LBh3o`1Q@PCo
05=<0ol0?DL3o`0Z?0?o01dd0ol052d3o`0>:0?o00XT0ol01b43o`067`?o00@M0ol011`:o`036`Ko
00<J1_l00a/6o`0470?o00DN0ol01Ql3o`088@?o00XT1?l03BL3o`0A:`?o01P`0ol083H3o`0[?@?o
03Y50ol0CTh3o`1HB@?o06=00ol0Kc43o`1l70Co08T00olSU`03odfU00?oO[<00one`@03olj]00?o
fX/00ooUJ003oni700?omBX00ook5003ooh600Coo`<00oom2P03ooTK00?olSD00ooZEP03ommk00?o
dZ800oo1a003oh>d00?oBJ@00olHT`03o`223`Co078]0ol0HT43o`1CC0?o03]60ol09SX3o`0G<0?o
00dW0ol01b43o`0470?o008J0ol00QT4o`036P?o00@M0ol01b43o`0;9P?o018/0ol06S83o`0V>P?o
03=10ol0@dT3o`1AC@?o05U90ol0H4<4o`1W?0?o06hc0ol0Lb/3o`1i8P?o07dJ0ol0PA83o`2430?o
08H80ol0Q`D3o`2710?o08L60ol0Q@T4o`233P?o07lE0ol0Nah3o`1e:0?o06lb0ol0Ic/3o`1OA0?o
05I;0ol0BT`3o`0e@P?o02<h0ol05Rl4o`0<9P?o00HO0ol00a/3o`026@?o00<K0ol02283o`0D;@?o
02/m0ol0DDd3o`1Y>@?o088?1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo
0oo7_P03omJF00?oggX00ooQLP03omim00?odih00oo5``03ohJe00?oBZ@00olHT`03o`2240Co078]
0ol0Hd03o`1FB`?o04M;0ol0=483o`0V>P?o01`d0ol05Bh3o`0@:P?o00dW0ol02bD3o`098`Co00PR
1_l01b43o`0780Ko00LQ0ol02283o`098`?o00/U0ol03BL3o`0?:P?o01<]1?l06343o`0O=P?o02Pk
0ol0<d83o`12B@?o055=0ol0FTP3o`1T?`?o06la0ol0Nah3o`2710Co6Y@00om1X@03off^00?oW[/0
0oo8_003omBL00?ogg/00ooYFP03oo4l00?omb800ool3`03ooh400Coo`<00oom3003ooPN00?olSP0
0ooYF003omml00?odZ400oo5a003ohRf00?oD:H00olOUP03o`2620Co07HW0ol0ISd3o`1HBP?o04E:
0ol0;Ch3o`0L=0?o014[0ol02R@3o`067`?o00<K1ol00QT3o`036P?o00@M0ol01b43o`0;9@?o010Z
0ol06303o`0Q=`?o02/m0ol0>4@3o`15BP?o051=1?l0ETX3o`1LA`?o06520ol0ICh3o`1Y>@?o06`f
0ol0KS<3o`1_<@Ko070`0ol0KS83o`1/=@Co06Ti0ol0ICh3o`1P@`?o05]70ol0E4`3o`1;C@?o03]5
0ol0:cd3o`0N=@?o01<]0ol02bH3o`0680Co00<K0ol00QT3o`036P?o00HO0ol03RP3o`0N=@?o03i7
0ol0G4H3o`1d:@?o2Hd00om@YP07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Ooo
ool3olNn00?oeYH00ooONP03on5b00?ogWd00ooCWP03olG300?oQ[D00om:Y003oaRC00?o088@1?l0
LRd3o`1S@0?o05I;0ol0Ad/3o`0d@P?o02Hj0ol073@3o`0E;P?o010Z0ol03BL3o`0;9@?o00TS1?l0
2286o`078@?o00LP1_l01b43o`088P?o00TS0ol02bD3o`0=9`?o00lZ0ol04bd4o`0H<@?o01lf0ol0
:3/3o`0c@P?o04990ol0DDd3o`1JB0?o06@o0ol0Kc43o`1k7P?o08L41?lJU003od6Q00?oKJh00onN
^`03olRl00?oe9`00ooON`03onUJ00?olC`00oog8P03oo`?00?ooP@01?oo0`03ood<00?on1h00oob
>003onUH00?ogg`00ooBX@03olG400?oR;H00om@YP03oanF00?o08H81?l0MRL3o`1V?@?o05Q:0ol0
ADX3o`0]?P?o01`d0ol04B/3o`0:90?o00HO0ol00a/7o`026@?o00<J0ol011d3o`078@?o00/U0ol0
42X3o`0H<0?o024g0ol0:cd3o`0hA0?o04E:0ol0D4d4o`1FBP?o05a70ol0HD83o`1U?P?o06Ti0ol0
K3H3o`1^<`?o06la1_l0L303o`1^<P?o06`e1?l0JCT3o`1U?P?o06130ol0FdL3o`1DC0?o04]=0ol0
>dD3o`0[?@?o01he0ol04bd3o`0;9P?o00HP1?l00a/3o`026@?o00<J0ol01Ql3o`0>:0?o01he0ol0
?TL3o`1LAP?o07@Y0ol9S@03oe2V00Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05
ooooo`?oakh00ooFUP03ommj00?ohG800ooNO@03om>N00?oaL<00on6]@03odZT00?o69<00ol0PQ04
o`1b;@?o06=00ol0ET/3o`17B`?o03A20ol09SX3o`0L=0?o01D^0ol042X3o`0=9`?o00/U0ol02B<4
o`088PKo00LQ0ol01b06o`078@?o00PR0ol02B<3o`0;9@?o00dW0ol03bX3o`0C;@Co01Pa0ol07cH3
o`0X>`?o03=20ol0@TT3o`1AC@?o05Y80ol0I3l3o`1_<@?o07/N0ol0Q`@4oaZD00?o@J400om][P03
oijk00?ob;`00ooDW003ommk00?ojEX00ooa?003ooLR00?oo0l00oon1004ool300?oo@`00ooh7P03
oo8h00?ojEP00ooOO003om:Q00?oaL@00on8]P03oe2V00?o7iH00ol0QPP4o`1f9`?o06Hm0ol0F4X3
o`15BP?o02dn0ol073@3o`0A:`?o00XT0ol01Ql3o`036`Oo008I0ol00aX3o`047@?o00LQ0ol02bD3
o`0@:P?o01P`0ol08CL3o`0[?@?o03Q40ol0ADX3o`1@C@Co05I:0ol0G4L3o`1Q@P?o06Dn0ol0JCT3
o`1/=P?o06hc0ol0Kc46o`1`<0?o06hb0ol0K3D4o`1Y>@?o06Dn0ol0H4<3o`1KA`?o05A<0ol0Bdd3
o`0kA@?o02/m0ol07SD3o`0C;@?o00/V0ol01R04o`036`?o008I0ol00aX3o`067`?o00hX0ol07SD3
o`0nA`?o05a60ol0M2T3o`V=00?oD:H01oooool1o`00007ooooo000Mooooo`;o00001_ooool3ogbb
00?obKT00ooJR@03onEU00?ojU@00ooVHP03omin00?odZ400oo3a003ohBe00?oBJ@01?lHT`03o`23
3@?o07DX0ol0J3/3o`1LAP?o059=0ol0A4X3o`0e@P?o02Xl0ol08SP3o`0L=0?o01Pa1?l05Bh3o`0C
;@?o018/1_l04B/3o`0B:`?o01</0ol052h3o`0G<0?o01Xb0ol07SD3o`0T>@Co02/m0ol0=483o`10
B0?o04i>0ol0ET/3o`1NA@?o06Lk0ol0LBh3o`1l70?o08L50olGT`04ocVO00?oHJ/00on>]`03oko3
00?ocjX00ooJR`03on=/00?ok4d00ooc<P03ooTL00?oo@`00oon1004ooh500?oo0l00oog8P03oo4k
00?oj5/00ooNO@03om:Q00?oaL<00on=]`03oeNX00?o9iP00ol0R@04o`1j80?o06/g0ol0G4H3o`1?
CP?o03M30ol093T3o`0F;`?o00hX0ol02283o`057P?o00<K1ol00QT3o`036P?o00@M0ol01R03o`0:
90?o00hX0ol052d3o`0J<P?o028h0ol0:cd3o`0d@PCo03e70ol0Ad/3o`1?CP?o059=0ol0ED/3o`1G
BP?o05U90ol0FTP3o`1IB0?o05U90ol0EdX3o`1DC0Co055=0ol0Bdd3o`10B0?o03E30ol0:Sd3o`0P
=P?o01L`0ol03bX3o`0:90?o00HO0ol00a/3o`026@Co008J0ol01Ah3o`0;9@?o01L`0ol0;Sl3o`1B
C@?o06Tj0ol0PA83obVI00?oM[400oo5``06ooooo`;o00000Oooool001gooooo00?o0000oooooooo
ool01Oooool3ogbb00?obKT00ooJR@03onEU00?ojU@00ooVHP03omin00?odZ400oo3a003ohBe00?o
BJ@01?lHT`03o`233@?o07DX0ol0J3/3o`1LAP?o059=0ol0A4X3o`0e@P?o02Xl0ol08SP3o`0L=0?o
01Pa1?l05Bh3o`0C;@?o018/1_l04B/3o`0B:`?o01</0ol052h3o`0G<0?o01Xb0ol07SD3o`0T>@Co
02/m0ol0=483o`10B0?o04i>0ol0ET/3o`1NA@?o06Lk0ol0LBh3o`1l70?o08L50olGT`04ocVO00?o
HJ/00on>]`03oko300?ocjX00ooJR`03on=/00?ok4d00ooc<P03ooTL00?oo@`00oon1004ooh500?o
o0l00oog8P03oo4k00?oj5/00ooNO@03om:Q00?oaL<00on=]`03oeNX00?o9iP00ol0R@04o`1j80?o
06/g0ol0G4H3o`1?CP?o03M30ol093T3o`0F;`?o00hX0ol02283o`057P?o00<K1ol00QT3o`036P?o
00@M0ol01R03o`0:90?o00hX0ol052d3o`0J<P?o028h0ol0:cd3o`0d@PCo03e70ol0Ad/3o`1?CP?o
059=0ol0ED/3o`1GBP?o05U90ol0FTP3o`1IB0?o05U90ol0EdX3o`1DC0Co055=0ol0Bdd3o`10B0?o
03E30ol0:Sd3o`0P=P?o01L`0ol03bX3o`0:90?o00HO0ol00a/3o`026@Co008J0ol01Ah3o`0;9@?o
01L`0ol0;Sl3o`1BC@?o06Tj0ol0PA83obVI00?oM[400oo5``07ooooo`7o00000Oooool001gooooo
00?o0000ooooooooool01Oooool3ogbb00?obKT00ooJR@03onEU00?ojU@00ooVHP03omin00?odZ40
0oo3a003ohBe00?oBJ@01?lHT`03o`233@?o07DX0ol0J3/3o`1LAP?o059=0ol0A4X3o`0e@P?o02Xl
0ol08SP3o`0L=0?o01Pa1?l05Bh3o`0C;@?o018/1_l04B/3o`0B:`?o01</0ol052h3o`0G<0?o01Xb
0ol07SD3o`0T>@Co02/m0ol0=483o`10B0?o04i>0ol0ET/3o`1NA@?o06Lk0ol0LBh3o`1l70?o08L5
0olGT`04ocVO00?oHJ/00on>]`03oko300?ocjX00ooJR`03on=/00?ok4d00ooc<P03ooTL00?oo@`0
0oon1004ooh500?oo0l00oog8P03oo4k00?oj5/00ooNO@03om:Q00?oaL<00on=]`03oeNX00?o9iP0
0ol0R@04o`1j80?o06/g0ol0G4H3o`1?CP?o03M30ol093T3o`0F;`?o00hX0ol02283o`057P?o00<K
1ol00QT3o`036P?o00@M0ol01R03o`0:90?o00hX0ol052d3o`0J<P?o028h0ol0:cd3o`0d@PCo03e7
0ol0Ad/3o`1?CP?o059=0ol0ED/3o`1GBP?o05U90ol0FTP3o`1IB0?o05U90ol0EdX3o`1DC0Co055=
0ol0Bdd3o`10B0?o03E30ol0:Sd3o`0P=P?o01L`0ol03bX3o`0:90?o00HO0ol00a/3o`026@Co008J
0ol01Ah3o`0;9@?o01L`0ol0;Sl3o`1BC@?o06Tj0ol0PA83obVI00?oM[400oo5``07ooooo`7o0000
0Oooool001gooooo00?o0000ooooooooool01Oooool3oafE00?oMk400oo9^003omf200?ojU@00oo^
A@03one900?oj5d00ooNO003om>P00?o`/@01?n3]003odbU00?o7iH00ol0R0@3o`1k7P?o06lb0ol0
I3l3o`1KA`?o05A<0ol0C4d3o`10B0?o03M31?l0<403o`0/?@?o02Pk0ol09SX6o`0U>P?o02Hj0ol0
:C`3o`0/?@?o03100ol0=T<3o`0mA`Co04M;0ol0D4h3o`1FB`?o05e60ol0I3l3o`1/=@?o07DX0ol0
OaL3o`290@?o69<00olhWP04oebY00?oQKD00ona`003ol^e00?oeIP00ooON`03onQM00?okd800ooe
:P03ooXG00?oo@X00oon1P04ood900?ona@00oof9`03oo1000?oieh00ooNO`03om:Q00?oa/800onA
^003oefZ00?o;Y/00ol6S004o`1m6@?o06la0ol0HD83o`1DC0?o04580ol0;3h3o`0M=0?o01</0ol0
32H3o`078@?o00@M1?l00aX6o`026@?o00<J0ol011`3o`057`?o00PR0ol02bD3o`0?:@?o01<]0ol0
6343o`0N=@Co02<h0ol0:C`3o`0^?`?o03=10ol0=T<3o`0iA@Ko03]50ol0>TD3o`0g@`?o03=10ol0
;Sl4o`0X>`?o028h0ol073<3o`0E;`?o010Z0ol02bD3o`078@?o00@M0ol00aX3o`026@?o008J0ol0
11d4o`098`?o01<]0ol09CX3o`15BP?o05i40ol0MBL3o`b>00?oDJH00onS_003oln[00?ofhL01ooo
ool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0olMU@03ogNa00?obKP00ooMPP03
onYD00?okTD00oo]B@03onQM00?ogW`00ooCX003ol;400CoPk@00om<Y@03oanF00?o08P40ol0Nah3
o`1_<P?o06@o0ol0FdL3o`1DC0?o04a=0ol0@4P3o`0g@`Co03100ol0;3d3o`0X>`?o02Hj1_l09CX3
o`0V>P?o02Tl0ol0;3d3o`0`@0?o03I30ol0?DL4o`17B`?o051>0ol0ET/3o`1MAP?o06@o0ol0K3D3
o`1e:0?o07lG0ol0R@43oaRC00?o>9h01?mLZ@03ohFe00?o/L000oo;]@03omFH00?ogg/00ooXG@03
onm200?omBX00ooj5`03ood:00?ooPH01?om2@03oo/D00?omRL00oo`@003onMN00?ogWl00ooBX@03
olK200?oTKP00omMZP03objK00?o1X`01?l0OAT3o`1_<@?o06520ol0E4`3o`11B0?o02`n0ol07C@3
o`0C;0?o00`V0ol01b43o`047@Co00<J1_l00QT3o`036P?o00@L0ol01Al3o`088P?o00/U0ol03bT3
o`0C;@?o01Pa0ol07SD4o`0S>0?o02Tl0ol0;Sl3o`0c@@?o03I30ol0>DD6o`0kA@?o03Y50ol0=d<3
o`0c@@?o02ho1?l0:3/3o`0R>0?o01`c0ol05Bl3o`0@:P?o00/U0ol01b43o`047@?o00<J0ol00QT3
o`026P?o00@M1?l02B<3o`0C;@?o02Dj0ol0ADX3o`1NA0?o07DW0ol<SP03oe6V00?oXk`00oo?Z`03
om^700Oooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o7ID00omg/@03olVh
00?ogH800ooZE003oni500?okDT00ooXG@03omil00?odj000oo2a004oh>d00?oC:D00olOUP03o`28
10?o07/N0ol0Kc83o`1T?`?o05]70ol0E4`3o`1<C@?o04180ol0=d<4o`0`@0?o02`m0ol0:3/3o`0V
>PKo02Dj0ol09SX3o`0Y?0?o02`m0ol0<403o`0f@`?o03e71?l0Ad/3o`1@CP?o05I;0ol0GDH3o`1T
?`?o06`e0ol0MBP3o`1o5`?o08T10olHT`03ocRN00CoG:T00on5]@03ok7000?obkD00ooEV003ommk
00?oj5d00oo_@P03ooDZ00?onQL00oom2P03ooh600Coo@T00ook5003ooHW00?ol4000ooWGP03omio
00?odZ400oo6`P03oi6h00?oGJX00ol^V`03o`J<00Co07dI0ol0Kc43o`1Q@P?o05A<0ol0@DP3o`0/
?P?o01dd0ol04b`3o`0<9P?o00LQ0ol011d4o`036PKo008I0ol00aX3o`0470?o00DO0ol02283o`0;
9@?o00lY0ol04bd3o`0H<@?o01he1?l08cP3o`0Y?0?o02ho0ol0<d43o`0f@`?o03U51_l0>dD3o`0j
A@?o03M30ol0<d43o`0^?`Co02Pk0ol08SP3o`0L<`?o01D_0ol042X3o`0;9@?o00LQ0ol011d3o`03
6P?o008I0ol00QX3o`047@Co00TS0ol04bd3o`0U>P?o04E:0ol0GT@3o`1e9`?o38h00omAYP03oj>l
00?ocj/00ooKQ`07ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1c:`?o
4i400om][P03olRl00?ogH000ooZE@03oo4k00?olc@00oo`?P03onYF00?ogg/01?oBX@03olC400?o
R[H00omHZ003obfK00?o2hh00ol0P`l3o`1h8`?o06la0ol0Ic`3o`1P@`?o05]81?l0ET/3o`1BC@?o
04m>0ol0C4d3o`19C0?o04Q<0ol0BD`3o`1;C@?o04i>0ol0D4d3o`1CC0?o05M:1?l0FdL3o`1P@`?o
06Hm0ol0K3D3o`1c:`?o07/M0ol0P`d3o`N<00?o7iH00ollX003oefZ00CoP[@00onZ_P03olRk00?o
dZ400ooKQP03onAZ00?oje000oob=`03ooLS00?ona<00oom2P03ooh800Coo0d00ooj6@03ooD/00?o
kTD00ooVHP03omf100?odZ400oo6`003oiJi00?oHj`00olfWP03o`j?00Co084A0ol0M2X3o`1V?@?o
05Y80ol0CTh3o`0g@`?o02Hj0ol06C43o`0@:P?o00XU0ol01b04o`047@?o00<K1_l00QT3o`026P?o
00<K0ol011d3o`067`?o00PR0ol02R@3o`0=9`?o010Z1?l04b`3o`0E;`?o01Pa0ol06S83o`0L<`Wo
01dd0ol06c<3o`0I<P?o01L`0ol04bd4o`0@:P?o00dW0ol02R@3o`078@?o00DN0ol00a/3o`026P?o
008I0ol00aX3o`057@?o00TS0ol04R/4o`0Q=`?o03a60ol0F4X3o`1/=@?o08<=0ol`W003oh>d00?o
bKX00ooISP03on=_00?oiFP01oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo
0ol0Lb/3oa>A00?oKJh00oo8_003omf000?ojUD00ooa>`03oo<d00?ol3h00ooZEP03ommk00CodZ40
0oo4a003ohZf00?oF:P00ol]V`03o`^>00?o08<?0ol0N2<3o`1_<@?o06Ll0ol0H4<3o`1KB0Co05I;
0ol0DTd3o`1?CP?o04a=0ol0BD`3o`18C0?o04U<0ol0Bdd3o`1>CP?o051=0ol0Dd`3o`1GBPCo05]7
0ol0H4<3o`1V?@?o06`e0ol0Lb/3o`1k7@?o08<=0ol7S003oanF00?o?:000omMZP04oh:d00?oZ[h0
0oo8^`03om:Q00?ofhH00ooTJP03on]@00?olSL00oog8`03oo/C00?oo@X00oon2004oo`=00?onQT0
0ooe;003oni500?oiV800ooMP@03om:Q00?oa/000onF^@03of>/00?o=Yh00ol>S`04o`214@?o07@Z
0ol0ISd3o`1JB0?o04i>0ol0=d<3o`0V>P?o01Ta0ol042X3o`0:9@?o00LP1?l011d3o`036`Ko008I
0ol00QX3o`036`?o00@M0ol01Ql3o`088P?o00XT0ol03BL3o`0@:PCo01</0ol05Bl3o`0H<@?o01Xb
0ol073<9o`0M=0?o01/c0ol06C83o`0G<0?o01<]1?l042X3o`0=9`?o00XT0ol01b43o`057P?o00<K
0ol00QX3o`026@?o00<J0ol01Ad3o`098`?o018[1?l08CL3o`0lAP?o05Q:0ol0K3D3o`233@?o<9`0
0on3]003olVj00?ofHh00ooSK`03onEX00Oooooo0Ol00001ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`?o07<[0olCT@03off^00?ob;`00ooMP003onYE00?olC/00ooc=003oo0n00?ojUH00ooO
N`04om:Q00?oa<@00on:]P03oeRX00?o;I/00ol;SP03o`233`?o07PS0ol0Kc43o`1W?0?o06130ol0
FdP4o`1FB`?o059=0ol0Cdh3o`1<C@?o04U<0ol0B4`3o`19C0?o04]=0ol0CTh3o`1@C@?o05=<0ol0
EdX4o`1KA`?o06130ol0ISd3o`1/=@?o07<[0ol0Nad3o`233@?o1h`00olOUP03ocbP00?oGJX01?n2
]003ojZn00?ob;/00ooBX@03om^600?oi6X00oo[D003oo8g00?omb<00ook4`03ood:00?ooPP01?ol
3@03ooXI00?omB`00oo^A@03onIR00?ogH400ooBX@03olK000?oU[T00omS[003ocJN00?o3Xl01?l0
PA43o`1d:P?o06Hm0ol0FTP3o`1>CP?o03M30ol09SX3o`0I<@?o010Z0ol02RD3o`0780Co00@M0ol0
0a/6o`026@?o008J0ol00a/3o`047@?o00HO0ol02283o`0:90?o00dW0ol042X4o`0C;0?o01D_0ol0
6343o`0J<P?o01`c2Ol07C@3o`0K<`?o01Tb0ol05c03o`0C;@Co010Z0ol03BL3o`0:90?o00LQ0ol0
1Ah3o`036`?o008J0ol00QT3o`036P?o00DM0ol02B<3o`0B:`Co024g0ol0?4H3o`1HBP?o06`e0ol0
P`d3oc2L00?oPk@00oo9^P03omV>00?ohfl00ooUJ007ooooo`7o00000Oooool001gooooo00?o0000
ooooooooool01Oooool3o`1AC@?o06dc0ol5S003oebY00?oaL@00ooIS@03onQL00?olSP00oog9@03
ooLS00?olSP01?oYE`03ommj00?odih00oo7_P03oiZj00?oJjh00om3XP03ob:G00?o28d00ol0Q0`3
o`1l70?o07DX1?l0Kc43o`1[=`?o06Ll0ol0I3l3o`1R@@?o06521_l0H4<3o`1R@P?o06=00ol0ISd3
o`1Y>@Co06dd0ol0LRh3o`1g9@?o07dJ0ol0P`d3o`::00?o5I800ol/VP03odNS00?oI:`00on6]@04
oj^n00?oakd00oo@YP03omV=00?ohG@00ooXFP03onm300?om2h00ooi7@03oo`A00Koo@X01?ok4@03
ooPN00?olc400oo]B@03onEU00?og8<00ooBXP03olNo00?oVkX00omZ[P03ocjP00?o5i<01?l0Q@P3
o`1h8`?o06/f0ol0Gd@3o`1DC0?o04=90ol0<403o`0Q=`?o01L`0ol03bT3o`0:90Co00LP0ol011d3
o`036`?o008J1_l00QT3o`026P?o00<K0ol011`3o`057P?o00HP0ol02244o`098`?o00XT0ol02bD3
o`0<9PWo00dW0ol032H3o`0;9@?o00XT0ol02283o`0780Co00DN0ol011d3o`036`?o008J0ol00QT3
o`026P?o00<K0ol01Ql3o`0:90?o018/0ol083H3o`0g@`Co05A<0ol0Ic`3o`1l70?o5Y800omMZP03
ok?000?oeIX00ooRK`03onYF00?ojET00ooON@07ooooo`7o00000Oooool001gooooo00?o0000oooo
ooooool01Oooool3o`1AC@?o06dc0ol5S003oebY00?oaL@00ooIS@03onQL00?olSP00oog9@03ooLS
00?olSP01?oYE`03ommj00?odih00oo7_P03oiZj00?oJjh00om3XP03ob:G00?o28d00ol0Q0`3o`1l
70?o07DX1?l0Kc43o`1[=`?o06Ll0ol0I3l3o`1R@@?o06521_l0H4<3o`1R@P?o06=00ol0ISd3o`1Y
>@Co06dd0ol0LRh3o`1g9@?o07dJ0ol0P`d3o`::00?o5I800ol/VP03odNS00?oI:`00on6]@04oj^n
00?oakd00oo@YP03omV=00?ohG@00ooXFP03onm300?om2h00ooi7@03oo`A00Koo@X01?ok4@03ooPN
00?olc400oo]B@03onEU00?og8<00ooBXP03olNo00?oVkX00omZ[P03ocjP00?o5i<01?l0Q@P3o`1h
8`?o06/f0ol0Gd@3o`1DC0?o04=90ol0<403o`0Q=`?o01L`0ol03bT3o`0:90Co00LP0ol011d3o`03
6`?o008J1_l00QT3o`026P?o00<K0ol011`3o`057P?o00HP0ol02244o`098`?o00XT0ol02bD3o`0<
9PWo00dW0ol032H3o`0;9@?o00XT0ol02283o`0780Co00DN0ol011d3o`036`?o008J0ol00QT3o`02
6P?o00<K0ol01Ql3o`0:90?o018/0ol083H3o`0g@`Co05A<0ol0Ic`3o`1l70?o5Y800omMZP03ok?0
00?oeIX00ooRK`03onYF00?ojET00ooON@07ooooo`7o00000Oooool001gooooo00?o0000oooooooo
ool01Oooool3o`1AC@?o06dc0ol5S003oebY00?oaL@00ooIS@03onQL00?olSP00oog9@03ooLS00?o
lSP01?oYE`03ommj00?odih00oo7_P03oiZj00?oJjh00om3XP03ob:G00?o28d00ol0Q0`3o`1l70?o
07DX1?l0Kc43o`1[=`?o06Ll0ol0I3l3o`1R@@?o06521_l0H4<3o`1R@P?o06=00ol0ISd3o`1Y>@Co
06dd0ol0LRh3o`1g9@?o07dJ0ol0P`d3o`::00?o5I800ol/VP03odNS00?oI:`00on6]@04oj^n00?o
akd00oo@YP03omV=00?ohG@00ooXFP03onm300?om2h00ooi7@03oo`A00Koo@X01?ok4@03ooPN00?o
lc400oo]B@03onEU00?og8<00ooBXP03olNo00?oVkX00omZ[P03ocjP00?o5i<01?l0Q@P3o`1h8`?o
06/f0ol0Gd@3o`1DC0?o04=90ol0<403o`0Q=`?o01L`0ol03bT3o`0:90Co00LP0ol011d3o`036`?o
008J1_l00QT3o`026P?o00<K0ol011`3o`057P?o00HP0ol02244o`098`?o00XT0ol02bD3o`0<9PWo
00dW0ol032H3o`0;9@?o00XT0ol02283o`0780Co00DN0ol011d3o`036`?o008J0ol00QT3o`026P?o
00<K0ol01Ql3o`0:90?o018/0ol083H3o`0g@`Co05A<0ol0Ic`3o`1l70?o5Y800omMZP03ok?000?o
eIX00ooRK`03onYF00?ojET00ooON@07ooooo`7o00000Oooool001gooooo0_l00006ooooo`?o01dd
0ol0AT/3o`1V?@?o08@;0om4XP03oj6l00?odZ800ooSK@03oo1000?omb800ooi6`04ooHU00?olC/0
0ooYF003on1g00?oeIP00oo:]P03ojjo00?oQ;D00omOZP03od2Q00?o9iT00olBT@04o`::00?o08D:
0ol0P1@3o`1l6`?o07TP0ol0Mb@3o`1f9P?o07HW0ol0MRH3o`1g90?o07TP0ol0O1`4o`1o5@?o08<=
0ol0R0<3o`V=00?o69<00olZVP03ocjP00?oEZP00oma[`03ohng00?o[kl01?o7_@03olnY00?oei<0
0ooOO003onEU00?ok4l00ooa>`03ooDY00?onA`00ook4`03oo`@00?ona801?oi6P03ooHX00?olC/0
0oo[DP03on=/00?ofhP00ooAY003olK000?oW;/00om_[`03odBR00?o7iH01?l0R@03o`1m6`?o070_
0ol0ICh3o`1JB0?o04m>0ol0?4H3o`0/?@?o01lf0ol05Rl3o`0?:@Co00/U0ol01b43o`057P?o00@L
0ol00aX3o`026PKo008I0ol00QX3o`036P?o00<K0ol00a`4o`0470?o00@M3ol01Ah3o`047@?o00@L
1_l00a/3o`026POo008I0ol00QX3o`036`?o00@M0ol01b43o`0<9P?o01@^0ol08CL3o`0f@`?o059=
0ol0Hd04o`1f9P?o18/00om1X@03ohjg00?oc;<00ooMO`03on]B00?okd<00oo[D@03ommj00?ob[H0
1_ooool2o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol07C@3o`16B`?o06Hm0ol0
Q0/3odBR00?oXK`00ooBXP03on=]00?ol4000oog8P03ooTK00ComRD00ooa>`03onUH00?oh7L00ooE
V003olZf00?o[[l00on4]@03oenZ00?o@:400olWV@03oa:A00Co0XX00ol0Q@X3o`2050?o07`K0ol0
NB03o`1g90?o07HV0ol0MRL3o`1f9P?o07LT0ol0NB03o`1l70Co07lE0ol0P`d3o`280`?o2Hd00olH
T`03obZJ00?o?Z000omFZ003og6_00?oSkL00on__`04olNm00?ocjT00ooGT`03omml00?oiFD00oo/
C`03oo4k00?omBT00ooi7003oo/C00?oo1000ook4P04ooTJ00?omRP00ooa>`03on]B00?ohf`00ooK
R003om6T00?oa/000onL^`03ofn_00?oA:800olOUP04o`2900?o07dK0ol0L2l3o`1U?P?o05Y80ol0
Cdh3o`0lAP?o02`m0ol07cH3o`0F;`?o00lY1?l02bD3o`078@?o00DN0ol011`3o`036P?o008J1_l0
0QT3o`026P?o00<J0ol00a/3o`0370Co00@L0ol011d?o`057P?o00@M0ol011`6o`036`?o008J1ol0
0QT3o`026P?o00<K0ol011d3o`078@?o00`V0ol052h3o`0Q=`?o03I30ol0DTd3o`1S@0Co07HV0ol4
R`03od6Q00?oS[L00oo</`03omeo00?oje800oo_@`03on]A00?oggX00oo:]P07ooooo`7o00000Ooo
ool001gooooo00?o0000ooooooooool01Oooool3o`0M=0?o04I;0ol0ISd3o`242`?oA:800onQ_003
om:R00?ohfd00oo`@003ooLR00?onA/01?of9@03oo4k00?ojEP00ooPM`03omFH00?ob[H00on^_`03
ohBe00?oGjX00om0X@03obNI00?o4Y401?l2RP03o`252P?o080D0ol0O1/3o`1i80?o07LT0ol0MRH3
o`1f9`?o07HV0ol0Mb@3o`1i80?o07`L1?l0OaD3o`233@?o08P30ol9S@03oaRC00?o:YX00olnX003
oeJX00?oLJl00on?]`03ojno00Coakd00oo?Z@03omNC00?ogg`00ooUI@03ona?00?olC/00ooe:@03
ooTL00?ona<00ool4003oo/B00ConAX00oof:003oo4k00?oje800ooSK003om^800?odJ@00oo6`003
oibk00?oKjl00om4XP03oanF00Co08T00ol0OA/3o`1`;`?o06Dn0ol0FTP3o`1?CP?o03a60ol0;3d3
o`0O=P?o01H_0ol03bT4o`0;9@?o00LQ0ol01Ah3o`0470?o00<J0ol00QX6o`026@?o008J0ol00aX3
o`036`?o00<L1?l011`3o`047@oo00DN0ol011d3o`0470Ko00<K0ol00QX7o`026@?o008J0ol00a/3
o`047@?o00LQ0ol032H3o`0D;P?o024g0ol0=T<3o`1BC@?o06=01?l0MRH3o`B;00?o@J400on>]`03
olbc00?ogGl00oo[DP03onm300?oje400ooONP03olZf00Oooooo0Ol00001ooooo`007Oooool00ol0
003oooooooooo`05ooooo`?o01dd0ol0AT/3o`1V?@?o08@;0om4XP03oj6l00?odZ800ooSK@03oo10
00?omb800ooi6`04ooHU00?olC/00ooYF003on1g00?oeIP00oo:]P03ojjo00?oQ;D00omOZP03od2Q
00?o9iT00olBT@04o`::00?o08D:0ol0P1@3o`1l6`?o07TP0ol0Mb@3o`1f9P?o07HW0ol0MRH3o`1g
90?o07TP0ol0O1`4o`1o5@?o08<=0ol0R0<3o`V=00?o69<00olZVP03ocjP00?oEZP00oma[`03ohng
00?o[kl01?o7_@03olnY00?oei<00ooOO003onEU00?ok4l00ooa>`03ooDY00?onA`00ook4`03oo`@
00?ona801?oi6P03ooHX00?olC/00oo[DP03on=/00?ofhP00ooAY003olK000?oW;/00om_[`03odBR
00?o7iH01?l0R@03o`1m6`?o070_0ol0ICh3o`1JB0?o04m>0ol0?4H3o`0/?@?o01lf0ol05Rl3o`0?
:@Co00/U0ol01b43o`057P?o00@L0ol00aX3o`026PKo008I0ol00QX3o`036P?o00<K0ol00a`4o`04
70?o00@M3ol01Ah3o`047@?o00@L1_l00a/3o`026POo008I0ol00QX3o`036`?o00@M0ol01b43o`0<
9P?o01@^0ol08CL3o`0f@`?o059=0ol0Hd04o`1f9P?o18/00om1X@03ohjg00?oc;<00ooMO`03on]B
00?okd<00oo[D@03ommj00?ob[H01oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Go
oooo0ol01b43o`0E;P?o03I30ol0GDH3o`1j7`?o89H00ome/003olNm00?ofhP00ooYE`03oo8f00Co
mRH00oog9003oo@^00?okd400ooXFP03on1g00?oei<00oo>[@03olC400?oWk`00omn/`03of:[00Co
Bj@00olhWP03obRI00?o79D00olBT@03o`b>00?o1h`01_l4R`03o`F<00?o28d00ol<S`04oa>A00?o
79D00olWV003oc>M00?o@j800omEY`03ofV]00?oP;@00onJ^P03okG100?ob;`01?o?Z`03omFH00?o
g8@00ooRL003onQM00?okD/00ooa>`03oo@]00?omb@00ooh7P03ooPM00?omb401?oe:P03oo8h00?o
kDX00ooWG`03on1g00?of9400oo?Z`03olG400?oVKX00om_[`03odRS00?o99P01?l5S003o`2050?o
07DX0ol0JSP3o`1OA0?o05E;0ol0BD`3o`0hA0?o02Xl0ol07cD3o`0F;`Co010Z0ol032H3o`098`?o
00HP0ol01Ad3o`0470?o00<K0ol00QXCo`026@Wo008J4_l00QT3o`036PCo00<K0ol01Ad3o`0780?o
00XT0ol03bX3o`0H<@?o02Di0ol0>D@3o`1BC@?o06520ol0LR`3o`2620Co:iX00om`[`03okk300?o
eIT00ooTJ`03oni800?olCX00ooZD`03omb500?oaL<00omGZ007ooooo`7o00000Oooool001gooooo
00?o0000ooooooooool01Oooool3o`078@?o01D^0ol0=T<3o`1MAP?o07XO0olPUP03ogF`00?oakd0
0ooKR003onUG00?olSH01?of9P03ooLT00?om2h00oo_@@03onQJ00?oh7L00ooGT`03olj]00?oa<@0
0onO_003ogjc00?oHZ/01?m;Y003ocRN00?o:9T00olLU@03oa:A00?o38h00ol7S006o`B;00?o1H`0
0ol8S@03o`b?00Co4i400olLU@03obNH00?o<id00om3XP03oeFW00?oJJd00on0]003oiZj00?o]L40
0oo8_004oln[00?oeIP00ooLQ003on9`00?oj5d00oo]B`03oo4k00?om2d00oog9003ooPN00?on1d0
0oog8@04ooDZ00?olSP00oo]BP03onMO00?oh7L00ooHT@03oln[00?oaL@00onI^P03ofn_00?oB:<0
0olTV004o`F<00?o080D0ol0MBP3o`1Z>0?o05m40ol0ED/3o`19C0?o03Q40ol0:S`3o`0O=@?o01H_
1?l042X3o`0<9P?o00TS0ol01R03o`057@?o00@L0ol00a/3o`026Q?o008I2Ol00QXBo`026@?o00<J
1?l00a/3o`057@?o00LP0ol02R@3o`0?:P?o01Pa0ol09CT3o`0iA0?o059=0ol0HD83o`1b;0?o08H8
1?l[VP03og2_00?o_/<00ooEV@03onA[00?okTP00ooa>P03onYC00?og8D00oo5``03oeNX00Oooooo
0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o00LQ0ol05Bh3o`0f@`?o05e60ol0
NQl3ob2F00?oMK000oo7_@03om^800?ojEL00oob=P04ooHV00?omb@00ood;P03onm100?oj5X00ooP
M`03omNC00?ocZd00oo4a003oinl00?oO[<00omRZ`04od^T00?o>9h00olXV@03oabE00?o4Y400ol<
SP03o`N<00Ko18/00ol5S003o`R=00?o38l01?lCT@03oabE00?o9iP00olcW@03od>R00?oEJL00omY
[@03oh2d00?oV[X00one`@03olRl00Cocj/00ooEV003omb400?ohW000ooXG@03one;00?olC/00ood
;@03ooLT00?on1h00ooh7@03ooLQ00ComBX00oob>003one:00?oiel00ooPM`03omRA00?ocj/00oo5
a003oiVj00?oKjl00om8X`03obBH00Co1H`00ol0P1@3o`1e:0?o06Xh0ol0Gd@3o`1EB`?o04U<0ol0
>4@3o`0Z?0?o01le0ol05Rl4o`0@:P?o00`V0ol02B<3o`0680?o00DM0ol011`3o`036`?o008J4ol0
0QT9o`026Q;o008I0ol00aX4o`036`?o00DM0ol01b03o`0:90?o00lZ0ol06343o`0U>@?o03U40ol0
DTd3o`1Q@P?o078/0ol0QPP4ob^J00?oL:l00onn``03omFI00?oi6/00oo^B003oo4j00?ojU<00ooL
Q@03olG300?oEjP01oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol011`3
o`057P?o00lY0ol0:3/3o`1CC0?o06hc0ol0R@03odRT00?oWk/00oo@Y`03ommi00CojU@00ooa>P03
oo@]00?omB`00oob=@03oni700?oj5`00ooQM003omZ;00?odZ800oo:]P03oko300CoXk`00on;]P03
ogJa00?oIJ`00omGZ003odbU00?oA:800oloX@03ocbP00?o>il00olmX003od2Q00CoAZ<00om>Y@03
oeRX00?oI:`00omb/003oh>d00?oU[T00on[_P03ol;400?ob[P00oo?Z@04omFI00?ofXT00ooPN003
onEW00?ojEL00oo]B@03oo4m00?olc<00ooe;@03ooDZ00?omB/00ood<@04oo4j00?okTP00ooYF@03
on=]00?og8<00ooEVP03olba00?o_l<00onF^@03ofn_00?oBj@00olYV@04o`b?00?o08@<0ol0NB43
o`1_<P?o06Dn0ol0FdL3o`1CC0?o04I;0ol0=T<3o`0Z?0?o020f1?l06343o`0C;0?o00hX0ol02bD3
o`088P?o00LP0ol01Ah3o`047@?o00@L1_l00a/7o`036Pco008J1_l00aX3o`036`?o00@L0ol01Ad3
o`067`?o00PQ1?l02RD3o`0?:@?o01D^0ol07SD3o`0/?@?o03m80ol0E4`3o`1Q@P?o074^0ol0PPl3
oafE00?oF:P01?nP_003olj]00?ogH400ooXFP03onm300?okd800ooXF`03omND00?oZkh00olnX003
o`1o5POooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o00@L0ol01Ah3o`0?
:@?o02Pk0ol0Dd`3o`1^<`?o08T00om8Y003oink00?od:L00ooON@04onYD00?olCX00ood;@03ooD/
00?olSD00oo^A`03onQL00?ohG@00ooJR`03om:R00?ob[H00ono``04oj>l00?oRkH00omf/@03ofF/
00?oEjP00om<Y@03odBR00?o?j400ollX003oc^O00?o?J000om0X@04odJS00?oCZD00omHZ003ofB/
00?oL[000on3]003oiJi00?oZkh00oo2a003olZh00?ocjT01?oEV@03omZ900?oh7P00ooUI`03onUG
00?okDT00ooa?@03oo<c00?omBd00ooe:P03ooD[00?om3401?oa>P03oni800?ojET00ooSK@03omb3
00?oeIX00oo</@03oko300?oU[T00om_[`03od^T00?o:IT01?l<S`03o`2430?o07TQ0ol0Kc83o`1U
?P?o05]70ol0Dd`3o`16B`?o03I30ol0:S`3o`0P=PCo01Pa0ol04b`3o`0>:0?o00/U0ol02283o`07
80?o00DN0ol011d3o`0470Ko00<K1ol00aX<o`026PKo00<J0ol00a/3o`0470?o00DM0ol01Ql3o`08
8@Co00XU0ol03bT3o`0E;P?o01he0ol0;3d3o`0oB0?o05A<0ol0HD83o`1a;P?o088?0olMU@03oeRX
00CoX;`00oo>[@03omf100?oj5X00oo_@`03onm200?oj5/00ooGU003oj^n00?o?Z000ol0OaH7oooo
o`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`0470?o00DN0ol03bT3o`0X>`?o
05=<0ol0KS<3o`2900?oB:@00onO^`03om2W00?oggT01?oZE003oo4j00?om2d00ooe;003oo8e00?o
kTL00ooXG003on5d00?ofX/00ooBXP03olZf00?o_l<01?nS_003oh^f00?oM[400omU[003oeNX00?o
C:D00om4XP03ocnQ00?o?:000olkW`03ocfP00?o@:401?m6X`03odjU00?oF:P00omT[003og:`00?o
Pk@00onF^@03oj^n00?o`/@00oo:^003olnY00CoeIT00ooJR@03on1h00?oiFL00ooYE`03one900?o
lCd00ooc<`03ooD]00?omBX00ooe:`03oo@a00ColCX00oo^B003onUI00?ohfd00ooLP`03omFJ00?o
c;400ono``03oiJi00?oKjl00om;Y003obVI00Co38l00ol0Q0`3o`1i8@?o06lb0ol0ICh3o`1KA`?o
05=<0ol0AT/3o`0f@`?o02Xl0ol083H4o`0H<@?o01</0ol03RP3o`0;9@?o00PR0ol01b03o`057P?o
00@M0ol011`6o`036`Oo00<J3?l00QX6o`036P?o00<K0ol011`3o`057@?o00HO0ol02244o`0:9@?o
00lY0ol05Bh3o`0N=@?o02`m0ol0?dP3o`1DC0?o06520ol0LBh3o`223`?o7ID00omHZ004oj2l00?o
cZd00ooMP@03onQJ00?okd<00oo_@P03onQK00?oei@00on[_P03ocjP00?o07lF1oooool1o`00007o
oooo0008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3o`0000Oooooo
00?o0000ooooooooool01Oooool3o`0;9@?o00@L0ol00a/3o`0:90?o01`c0ol0@TT3o`1Q@P?o07`L
0olNU@03of^^00?o^l801?oCW`03on1h00?ojEP00oo_@@06oo8f00?ol3h00oo]B`03onQL00?ohfl0
0ooMPP03omND00CodJD00oo;]003olK100?o]l400onU_@03oiNj00?oS;L00on3]003ogjc00KoN[80
0omk/P04ognc00?oQKD00on=]`03oiRj00?oY;d00onc`003ol?400?ob;/00oo=/003om6T00?oeYL0
1?oJRP03omml00?ohfh00ooWH@03onYD00?okDX00oo_@@03oo4j00KolSL00ooa>P03oo1000CokDX0
0ooYE`03onEW00?oggX00ooIS@03om:R00?ob[L00onh`@03oi>h00?oKjl00om>Y@03obnK00Co4i40
0ol0Q`@3o`1m6@?o07@Z0ol0JcL3o`1R@@?o05U80ol0DTd3o`16BP?o03Q40ol0;Ch4o`0T>@?o01`d
0ol05c03o`0B;0?o00lY0ol032H3o`0:90?o00TS0ol01b43o`0780Ko00HO2_l01Ah3o`057`?o00HO
0ol01R03o`078@?o00TS0ol02bD3o`0=9`?o014[0ol05Rl4o`0N=@?o02Pk0ol0=T<3o`1:C0?o05M:
0ol0I3l3o`1b;@?o088@0olFT`03odZT00?oRKH00oo7_P04omND00?oi6/00oo/C`03onm400?ok4l0
0ooRLP03om2V00?oRkH00olTV003o`1f9P?o05I;1oooool1o`00007ooooo0008ooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo
0ol02bD3o`0470?o00<K0ol02R@3o`0L<`?o04990ol0HD83o`1l70?o7YD00om[[P03ok_200Codil0
0ooPN003onUH00?okd401_ob=P03oo0n00?okD/00ooXG003on=_00?ogH800ooGU004om6U00?obk@0
0oo6`@03okO100?oYKd00onG^P03ohbg00?oPk@00omn/`06ogZb00?oNk801?mo/`03ohFe00?oSKL0
0onH^P03ojBm00?o/l000oo3a003olRk00?ocK000ooAY003omJG00CofXX00ooOO003on=^00?oif40
0ooZE003one:00?okd400ooa>P06oo8g00?olCX00oo`@004one:00?ojEL00ooUI`03ommj00?ofHd0
0ooBXP03olZg00?o^<400onC^003ofn_00?oCZD00ol_V`04oa>A00?o08L40ol0OAT3o`1d:P?o06/g
0ol0HT43o`1IB0?o059=0ol0ATX3o`0hA0?o02dn1?l093T3o`0L=0?o01L`0ol04R`3o`0?:@?o00`V
0ol02R@3o`098`?o00LQ0ol01b06o`067`[o00DN0ol01Al3o`067`?o00HP0ol01b43o`098`?o00/U
0ol03BL3o`0A:`?o01H_1?l07SD3o`0X>`?o03I30ol0BT`3o`1GBP?o06@o0ol0LRd3o`2240?o5Y<0
0om:Y003ohVf00?oakh01?oGU003onA[00?ok4l00oo_A003ona?00?ohW800oo@YP03oh^f00?o99P0
0ol0MRH3o`1FB`Oooooo0Ol00001ooooo`002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Cooooo0ol00005ooooo`?o00/U0ol011`3o`036`?o00XT0ol073<3o`12B@?o06520ol0
O1`3oajE00?oJjh00onk`P04om>O00?oh7P00ooYF003onm100KolSH00oo`?P03one;00?oj5`00ooS
K`03omf200?oei@01?oAY@03ol^d00?oa/400ong`@03ojFm00?oUkX00on<]`03oh>d00?oO[<01_mj
/P03og^b00CoOk<00on5]@03ohfg00?oV;X00onT_@03ok?000?o`l@00oo8^`03olf`00?odJ@00ooF
U`04omZ:00?ogg`00ooSKP03onMQ00?ojU@00oo]BP03onm100?olCX01_ob=`03oo4j00?ol4001?o]
BP03onUG00?oiFL00ooONP03omV=00?odZ800oo:]`03okS100?oTkP00om_[`03odjU00?o;i/01?lC
T@03o`2710?o07dI0ol0M2X3o`1[=`?o06910ol0FDP3o`1BC@?o04I:0ol0>4@3o`0]?PCo02@i0ol0
73@3o`0G<0?o018/0ol03bT3o`0<9P?o00XT0ol02B<3o`078@?o00LP1_l01Ql:o`057P?o00DO0ol0
1Ql3o`0680?o00LQ0ol02B<3o`0;9@?o00dW0ol04B/3o`0F;`Co01he0ol0:3/3o`0f@`?o04Y<0ol0
EdX3o`1T?`?o078]0ol0PQ03oaJC00?oBZ@00on9]P03olNn00Coei@00ooTJ`03ona?00?okd@00oo/
C`03on9b00?od:H00on;]P03obBH00?o07HV0ol0ET/5ooooo`?o00000Oooool000Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo0ol0:C`3
o`0?:@?o00DM0ol00aX3o`067`?o018/0ol0;Ch3o`1DC0?o06dd0ol0QPP3oc>M00CoN;400ono``03
om:R00?ogGl00ooVI@03on]C00?okDT00oo^A`03one;00?ojU@00ooWH003on=^00CogW`00ooJRP03
omJH00?odJ<00oo=[P03olZg00?oakh00oo5a003okg300?o^<400one`@03okC100Co]L400oni`P03
okk300?oaL@00oo7_P03olVh00?oc;400oo?Z@03om>P00?oeYH00ooJS004omf100?oh7H00ooSK003
onIR00?ojEX00oo[DP03ona=00?okDT00oo]B003one:00?ok4h00ooZE@04onMO00?oi6`00ooONP03
omZ:00?oe9`00oo>[P03olK000?o[;l00on;]P03of^^00?oCJD00olaW004oaNC00?o0HX00ol0PA83
o`1h8`?o070`0ol0J3/3o`1P@`?o05U90ol0DTd3o`18C0?o03a61?l0<T43o`0Y?0?o02<h0ol07C@3
o`0I<@?o01D^0ol04R`3o`0@:P?o00lY0ol03BP3o`0=9`[o00`V0ol032L3o`0=:0?o00lY0ol042X3
o`0C;@?o01H_0ol06c<3o`0Q=`?o02Xl0ol0=D<4o`14BP?o05==0ol0G4H3o`1X>`?o07@Y0ol0PPl3
oa>A00?o@J400omg/@03okG100?od:P00ooLP`04onIS00?oje000oo[D@03onEX00?of9400oo5a003
of>/00?o1hd00ol0K3D3o`1<C@?o01`c1oooool1o`00007ooooo000:ooooo`03o`000?oooooooooo
00Gooooo1?l00007ooooo`03o`000?oooooooooo00Gooooo0ol0:C`3o`0?:@?o00DM0ol00aX3o`06
7`?o018/0ol0;Ch3o`1DC0?o06dd0ol0QPP3oc>M00CoN;400ono``03om:R00?ogGl00ooVI@03on]C
00?okDT00oo^A`03one;00?ojU@00ooWH003on=^00CogW`00ooJRP03omJH00?odJ<00oo=[P03olZg
00?oakh00oo5a003okg300?o^<400one`@03okC100Co]L400oni`P03okk300?oaL@00oo7_P03olVh
00?oc;400oo?Z@03om>P00?oeYH00ooJS004omf100?oh7H00ooSK003onIR00?ojEX00oo[DP03ona=
00?okDT00oo]B003one:00?ok4h00ooZE@04onMO00?oi6`00ooONP03omZ:00?oe9`00oo>[P03olK0
00?o[;l00on;]P03of^^00?oCJD00olaW004oaNC00?o0HX00ol0PA83o`1h8`?o070`0ol0J3/3o`1P
@`?o05U90ol0DTd3o`18C0?o03a61?l0<T43o`0Y?0?o02<h0ol07C@3o`0I<@?o01D^0ol04R`3o`0@
:P?o00lY0ol03BP3o`0=9`[o00`V0ol032L3o`0=:0?o00lY0ol042X3o`0C;@?o01H_0ol06c<3o`0Q
=`?o02Xl0ol0=D<4o`14BP?o05==0ol0G4H3o`1X>`?o07@Y0ol0PPl3oa>A00?o@J400omg/@03okG1
00?od:P00ooLP`04onIS00?oje000oo[D@03onEX00?of9400oo5a003of>/00?o1hd00ol0K3D3o`1<
C@?o01`c1oooool1o`00007ooooo0006ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo0ol0:C`3o`0?:@?o00DM0ol00aX3o`06
7`?o018/0ol0;Ch3o`1DC0?o06dd0ol0QPP3oc>M00CoN;400ono``03om:R00?ogGl00ooVI@03on]C
00?okDT00oo^A`03one;00?ojU@00ooWH003on=^00CogW`00ooJRP03omJH00?odJ<00oo=[P03olZg
00?oakh00oo5a003okg300?o^<400one`@03okC100Co]L400oni`P03okk300?oaL@00oo7_P03olVh
00?oc;400oo?Z@03om>P00?oeYH00ooJS004omf100?oh7H00ooSK003onIR00?ojEX00oo[DP03ona=
00?okDT00oo]B003one:00?ok4h00ooZE@04onMO00?oi6`00ooONP03omZ:00?oe9`00oo>[P03olK0
00?o[;l00on;]P03of^^00?oCJD00olaW004oaNC00?o0HX00ol0PA83o`1h8`?o070`0ol0J3/3o`1P
@`?o05U90ol0DTd3o`18C0?o03a61?l0<T43o`0Y?0?o02<h0ol07C@3o`0I<@?o01D^0ol04R`3o`0@
:P?o00lY0ol03BP3o`0=9`[o00`V0ol032L3o`0=:0?o00lY0ol042X3o`0C;@?o01H_0ol06c<3o`0Q
=`?o02Xl0ol0=D<4o`14BP?o05==0ol0G4H3o`1X>`?o07@Y0ol0PPl3oa>A00?o@J400omg/@03okG1
00?od:P00ooLP`04onIS00?oje000oo[D@03onEX00?of9400oo5a003of>/00?o1hd00ol0K3D3o`1<
C@?o01`c1oooool1o`00007ooooo0006ooooo`Go00001oooool5o`0000Kooooo00?o0000oooooooo
ool01Oooool3o`1IB@?o03=10ol052d3o`0680?o008J0ol011`3o`0;9@?o01`d0ol0?DL3o`1LAP?o
07</1?l0R083oc6L00?oK:h00onX_P03olZg00?oe9d00ooKR003on1i00?ohW000ooSK003on=]00?o
hW801?oPN@03omf100?ofXX00ooGT`03omBL00?odJ@00oo?Z`03olba00?ob[H00oo9^P03olRl00[o
akh00oo8_003olVj00?ob[L00oo</P03olj]00?od:P00ooBXP03omBK00?oei@01?oIS@03om^600?o
gGl00ooON@03on5d00?ohW000ooSKP03on=]00?ohfh00ooRL003on5e00?ogg`01?oLQ@03omR?00?o
e9/00oo@Z003olZf00?oaL@00onZ_P03ohng00?oM;000omIZ@03od2Q00?o:IT01?lCT@03o`2900?o
084A0ol0NR03o`1b;0?o06/f0ol0I3l3o`1NA@?o05Q:0ol0DTd3o`1;C@Co04580ol0>4@3o`0a@0?o
02/m0ol09SX3o`0R=`?o01he0ol073<3o`0J<P?o01Ta0ol06343o`0H<0Co01Pa0ol06C43o`0J<P?o
01`d0ol07cH3o`0S>0?o02Pl0ol0;cl3o`0iA0?o04A:0ol0D4d3o`1HB@Co06520ol0JcL3o`1f9`?o
088@0ol<S`03oc:L00?oGjX00onB^003olG300?odJD00ooJRP03on1f00Cohfl00ooPN003omNE00?o
b;d00on0/`03obbJ00?o07hH0ol0H4<3o`0gA0?o01<]0ol01Ah7ooooo`7o00000Oooool001gooooo
00?o0000ooooooooool01Oooool3o`1IB@?o03=10ol052d3o`0680?o008J0ol011`3o`0;9@?o01`d
0ol0?DL3o`1LAP?o07</1?l0R083oc6L00?oK:h00onX_P03olZg00?oe9d00ooKR003on1i00?ohW00
0ooSK003on=]00?ohW801?oPN@03omf100?ofXX00ooGT`03omBL00?odJ@00oo?Z`03olba00?ob[H0
0oo9^P03olRl00[oakh00oo8_003olVj00?ob[L00oo</P03olj]00?od:P00ooBXP03omBK00?oei@0
1?oIS@03om^600?ogGl00ooON@03on5d00?ohW000ooSKP03on=]00?ohfh00ooRL003on5e00?ogg`0
1?oLQ@03omR?00?oe9/00oo@Z003olZf00?oaL@00onZ_P03ohng00?oM;000omIZ@03od2Q00?o:IT0
1?lCT@03o`2900?o084A0ol0NR03o`1b;0?o06/f0ol0I3l3o`1NA@?o05Q:0ol0DTd3o`1;C@Co0458
0ol0>4@3o`0a@0?o02/m0ol09SX3o`0R=`?o01he0ol073<3o`0J<P?o01Ta0ol06343o`0H<0Co01Pa
0ol06C43o`0J<P?o01`d0ol07cH3o`0S>0?o02Pl0ol0;cl3o`0iA0?o04A:0ol0D4d3o`1HB@Co0652
0ol0JcL3o`1f9`?o088@0ol<S`03oc:L00?oGjX00onB^003olG300?odJD00ooJRP03on1f00Cohfl0
0ooPN003omNE00?ob;d00on0/`03obbJ00?o07hH0ol0H4<3o`0gA0?o01<]0ol01Ah7ooooo`7o0000
0Oooool001gooooo00?o0000ooooooooool01Oooool3o`1IB@?o03=10ol052d3o`0680?o008J0ol0
11`3o`0;9@?o01`d0ol0?DL3o`1LAP?o07</1?l0R083oc6L00?oK:h00onX_P03olZg00?oe9d00ooK
R003on1i00?ohW000ooSK003on=]00?ohW801?oPN@03omf100?ofXX00ooGT`03omBL00?odJ@00oo?
Z`03olba00?ob[H00oo9^P03olRl00[oakh00oo8_003olVj00?ob[L00oo</P03olj]00?od:P00ooB
XP03omBK00?oei@01?oIS@03om^600?ogGl00ooON@03on5d00?ohW000ooSKP03on=]00?ohfh00ooR
L003on5e00?ogg`01?oLQ@03omR?00?oe9/00oo@Z003olZf00?oaL@00onZ_P03ohng00?oM;000omI
Z@03od2Q00?o:IT01?lCT@03o`2900?o084A0ol0NR03o`1b;0?o06/f0ol0I3l3o`1NA@?o05Q:0ol0
DTd3o`1;C@Co04580ol0>4@3o`0a@0?o02/m0ol09SX3o`0R=`?o01he0ol073<3o`0J<P?o01Ta0ol0
6343o`0H<0Co01Pa0ol06C43o`0J<P?o01`d0ol07cH3o`0S>0?o02Pl0ol0;cl3o`0iA0?o04A:0ol0
D4d3o`1HB@Co06520ol0JcL3o`1f9`?o088@0ol<S`03oc:L00?oGjX00onB^003olG300?odJD00ooJ
RP03on1f00Cohfl00ooPN003omNE00?ob;d00on0/`03obbJ00?o07hH0ol0H4<3o`0gA0?o01<]0ol0
1Ah7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3o`1g9@?o05m40ol0?dL3
o`0K<`?o00TS0ol00a/3o`026P?o00HO0ol042/3o`0V>P?o04Y=1?l0H4<3o`1d:@?o08L40olXV@03
oeRX00?oR;H00onc`003olVj00?ocjT00ooDW003omND00?of8l01?oISP03omV?00?oei800ooFUP03
omBK00?odZ000ooAY@03olnZ00?ocJh00oo</P03ol^e00?ob[L01?o9^003olVi00?obKP00oo:]`03
olZf00?obk<00oo</@03olj]00?ocjX00ooAYP03om:Q00Coe9d00ooEV@03omJF00?oei800ooHT009
omV>00?of9000ooGU003omFH00?odih01?oAYP03olf^00?ob[P00oo5`P03okG100?oWk`00on:]P03
og>`00?oGJX00om8X`03oc>M00?o89H01?l>S`03o`280P?o088A0ol0Nah3o`1d:@?o06hb0ol0J3X3
o`1S@0?o05e50ol0F4T3o`1DC0Co051>0ol0BD`3o`11B0?o03]50ol0=T<3o`0b@@?o02ho0ol0;3h3
o`0Z?@Ko02Tl0ol0:S`4o`0[?@?o02dn0ol0<403o`0d@P?o03Y50ol0@DP3o`1;C@?o059=0ol0EdX3
o`1NA@?o06Hm0ol0KS84o`1h8`?o088?0ol9S@03obRI00?oC:D00omf/@03oj:l00?oakl00oo?Z@03
omFH00?of9000ooGT`04om:S00?oakh00on<]`03od:R00?o08T00ol0KS83o`1CC0?o02Hj0ol03BL3
o`0470?o00<J1oooool1o`00007ooooo000Mooooo`03o`000?oooooooooo00Gooooo0ol0MbD3o`1O
A0?o03m70ol06c<3o`098`?o00<K0ol00QX3o`067`?o010[0ol09SX3o`1:C@Co06130ol0M2T3o`27
10?o:9T00omHZ003ohRf00?o/l000oo9^P03olnY00?oe9`00ooGU003omR?00CofHh00ooIS`03omNB
00?oeYH00ooDV`03om:P00?odJD00oo?ZP03olf^00?oc;800oo;]@03olZg00CobKP00oo9^@03olVh
00?ob[L00oo:]P03ol^c00?oc;400oo>[@03olnZ00?odJH00ooBX@04omBM00?oeIT00ooFUP03omNB
00?of9002OoISP03omR@00?oei@00ooEV003om>N00CodJH00oo=[P03olZh00?oaL800one`@03oinl
00?oR[H00omc/003oefZ00?oB:<00olcW@03ob2F00Co3Xl00ol0R083o`224@?o07/N0ol0M2T3o`1^
<P?o06Pj0ol0Hd03o`1MA@?o05Q90ol0E4`4o`1@CP?o04U<0ol0@DP3o`0kA@?o03I30ol0<T43o`0^
?`?o02`n0ol0:Sd6o`0Y?0?o02Xl1?l0:cd3o`0]?P?o03100ol0=483o`0jA@?o04580ol0Bdd3o`1B
C@?o05M:0ol0GTD3o`1V?@?o06hb1?l0N2<3o`223`?o2Hd00olXV@03odbU00?oM[400onR_003olNo
00?ocjT00ooEV003omR@00?oei<01?oBX`03olNn00?oS;L00om2XP03o`2900?o06hb0ol0Dd`3o`0V
>P?o00dW0ol011`3o`036POooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`05ooooo`?o
07LU0ol0Gd@3o`0oA`?o01/c0ol02B<3o`036`?o008J0ol01Ql3o`0@:`?o02Hj0ol0BTd4o`1P@`?o
07@Y0ol0Q`@3obRI00?oF:P00on8]P03ok?000?obKX00oo?Z@03omBL00?oei@00ooHS`04omV>00?o
fHl00ooGTP03omJF00?oe9/00ooBX003om6U00?ocjX00oo=[P03olbb00?obkD00oo:]`04olVh00?o
bKT00oo9^003olZg00?ob[H00oo;/`03olba00?ocZd00oo?ZP03om6V00?odZ401?oDW@03omFI00?o
eYH00ooGTP03omR@00WofHh00ooHT003omND00?oeIP00ooCWP04om6V00?ocJh00oo:^003olG200?o
]L400onO_003ohZf00?oLk000omMZP03odRS00?o<id00olPUP04o`j?00?o08P20ol0PQ43o`1k7P?o
07@Y0ol0KS83o`1X>P?o06=00ol0GDD3o`1HB@?o05A<1?l0D4h3o`19C0?o04580ol0>dD3o`0f@`?o
03910ol0;Sl3o`0/?P?o02Xm1_l0:C`3o`0Z?0Co02/m0ol0;Ch3o`0`@0?o03A20ol0>TD3o`11B0?o
04]=0ol0DTd3o`1GBP?o05i50ol0ISd3o`1^<PCo07PS0ol0PPl3o`V=00?o:9T00om<Y@03ogJa00?o
X[`00oo7_`03olnY00?oeIP00ooHT003omNC00CodZ<00oo7_P03ohbg00?o@Z800ol0R@03o`1^<P?o
05=<0ol09SX3o`0=9`?o00@L0ol00aX7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool0
1Oooool3o`b>00?o07`L0ol0ICh3o`1=CP?o02@i0ol03RP3o`057@?o008I0ol00a/3o`098`?o01H_
1?l0;Sl3o`1@CP?o06520ol0Lb/3o`2430?o69<00olnX003ofB/00?oR;H00onV_@03ol3300?ob;`0
1?o;]@03olf_00?ocZ`00oo>Z`03olj/00?ocZd00oo=[`03olbb00?obk@00oo:]P03olVi00?obKX0
1?o8_009olRm00Kob;`00oo9^P03olVi00?ob[L00oo;]@03olbc00Coc;400oo=[`03olj]00?ocZ`0
0oo>Z`03oln[00?ocZ`00oo>[@03olf`00?obk<00oo:]`03olRm00CoaL<00onk`P03ojfo00?oW[/0
0on>]`03ogfc00?oJjh00omIZ@03odRS00?o=ih00olVV003oaJB00Co1hd00ol0Q`D3o`214P?o07/M
0ol0MRH3o`1a;`?o06`f0ol0Ic`3o`1R@@?o05i50ol0FTP4o`1GBP?o05=<0ol0DDd3o`1>CP?o04U<
0ol0ADX3o`13B@?o04581_l0@4P3o`11B0?o04991?l0ADX3o`19C0?o04m>0ol0DTd3o`1EB`?o05Y8
0ol0Gd@3o`1T?`?o06/g0ol0LR`3o`1j7`?o08<>1?l7S003ob2F00?o?Z000omOZP03oh>d00?oY[d0
0oo5a003ol^e00KocZd00oo:]`03ok[200CoR;H00om=Y@03o`n@00?o07PS0ol0Gd@3o`0nA`?o01Tb
0ol02283o`036P?o00<L0ol03BL7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Ooo
ool3o`b>00?o07`L0ol0ICh3o`1=CP?o02@i0ol03RP3o`057@?o008I0ol00a/3o`098`?o01H_1?l0
;Sl3o`1@CP?o06520ol0Lb/3o`2430?o69<00olnX003ofB/00?oR;H00onV_@03ol3300?ob;`01?o;
]@03olf_00?ocZ`00oo>Z`03olj/00?ocZd00oo=[`03olbb00?obk@00oo:]P03olVi00?obKX01?o8
_009olRm00Kob;`00oo9^P03olVi00?ob[L00oo;]@03olbc00Coc;400oo=[`03olj]00?ocZ`00oo>
Z`03oln[00?ocZ`00oo>[@03olf`00?obk<00oo:]`03olRm00CoaL<00onk`P03ojfo00?oW[/00on>
]`03ogfc00?oJjh00omIZ@03odRS00?o=ih00olVV003oaJB00Co1hd00ol0Q`D3o`214P?o07/M0ol0
MRH3o`1a;`?o06`f0ol0Ic`3o`1R@@?o05i50ol0FTP4o`1GBP?o05=<0ol0DDd3o`1>CP?o04U<0ol0
ADX3o`13B@?o04581_l0@4P3o`11B0?o04991?l0ADX3o`19C0?o04m>0ol0DTd3o`1EB`?o05Y80ol0
Gd@3o`1T?`?o06/g0ol0LR`3o`1j7`?o08<>1?l7S003ob2F00?o?Z000omOZP03oh>d00?oY[d00oo5
a003ol^e00KocZd00oo:]`03ok[200CoR;H00om=Y@03o`n@00?o07PS0ol0Gd@3o`0nA`?o01Tb0ol0
2283o`036P?o00<L0ol03BL7ooooo`7o00000Oooool001gooooo00?o0000ooooooooool01Oooool3
o`b>00?o07`L0ol0ICh3o`1=CP?o02@i0ol03RP3o`057@?o008I0ol00a/3o`098`?o01H_1?l0;Sl3
o`1@CP?o06520ol0Lb/3o`2430?o69<00olnX003ofB/00?oR;H00onV_@03ol3300?ob;`01?o;]@03
olf_00?ocZ`00oo>Z`03olj/00?ocZd00oo=[`03olbb00?obk@00oo:]P03olVi00?obKX01?o8_009
olRm00Kob;`00oo9^P03olVi00?ob[L00oo;]@03olbc00Coc;400oo=[`03olj]00?ocZ`00oo>Z`03
oln[00?ocZ`00oo>[@03olf`00?obk<00oo:]`03olRm00CoaL<00onk`P03ojfo00?oW[/00on>]`03
ogfc00?oJjh00omIZ@03odRS00?o=ih00olVV003oaJB00Co1hd00ol0Q`D3o`214P?o07/M0ol0MRH3
o`1a;`?o06`f0ol0Ic`3o`1R@@?o05i50ol0FTP4o`1GBP?o05=<0ol0DDd3o`1>CP?o04U<0ol0ADX3
o`13B@?o04581_l0@4P3o`11B0?o04991?l0ADX3o`19C0?o04m>0ol0DTd3o`1EB`?o05Y80ol0Gd@3
o`1T?`?o06/g0ol0LR`3o`1j7`?o08<>1?l7S003ob2F00?o?Z000omOZP03oh>d00?oY[d00oo5a003
ol^e00KocZd00oo:]`03ok[200CoR;H00om=Y@03o`n@00?o07PS0ol0Gd@3o`0nA`?o01Tb0ol02283
o`036P?o00<L0ol03BL7ooooo`7o00000Oooool001gooooo0_l0003ooooooiOooooo0_l00001oooo
o`007Oooool00ol0003oooooooooo`3ooooooiOooooo0Ol00001ooooo`007Oooool00ol0003ooooo
ooooo`3ooooooiOooooo0Ol00001ooooo`007Oooool00ol0003oooooooooo`3ooooooiOooooo0Ol0
0001ooooo`007Oooool00ol0003oooooooooo`3ooooooiOooooo0Ol00001ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo01gooooo0Ol00001ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`00007o
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`;o00000Oooool001goooooool0002Ko`00007ooooo003ooooookWooooo003ooooo
okWooooo003ooooookWooooo003ooooookWooooo003ooooookWooooo003oooooobOooooo0ol0002?
ooooo`00oooooolXooooo`03o`000?oooooooooo08kooooo002Xooooo`Go000000Goooooo`000?l0
003o0000ooooo`02o`0000;ooooo0_l00003ooooo`?o00000_ooool3o`0000?ooooo1Ol00002oooo
o`?o00000_ooool3o`0000Cooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo0ol00003
ooooo`?o00002?ooool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00000ooo
ool3o`0000;ooooo0ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003ooooo`;o00001?oo
ool00ol0003oooooooooo`2=ooooo`00Z_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000003Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo
0000ooooool00006ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`00
0004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0SOooool00:[ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
1Ol00002ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`03
o`000?oooooooooo00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5
o`0000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00002>ooooo`00Z_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00005ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooooooo
o`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool00000S_ooool00:[ooooo00Co0000oooooooooooooooo1?l00002ooooo`Co00000ooo
ool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool3o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`?o00000_ooool4o`0000?ooooo0ol00003ooooo`?o00002_oo
ool01?l0003oooooooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000?ooooo
1?l000001?oooooo0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o000008go
oooo002Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`2Dooooo`00Z?ooool5o`0000Sooooo00?o0000ooooooooool04Oooool2o`0002_ooooo1Ol0
0008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2Dooooo`00\
\>"],
  ImageRangeCache->{{{0, 439}, {439, 0}} -> {-9.2119, -8.92509, 0.0324808, \
0.040661}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(2.519999999999982`\ Second\), ",", 
        RowBox[{"{", 
          
          RowBox[{\(InterferenceFunction \[Rule] 
              "CompiledFunction[-intensity data-]"\), ",", 
            RowBox[{"OutputGraphics", "\[Rule]", 
              RowBox[{"InterferenceFunction", "\[Rule]", 
                RowBox[{"(", 
                  
                  TagBox[\(\[SkeletonIndicator]  
                      DensityGraphics  \[SkeletonIndicator]\),
                    False,
                    Editable->False], ")"}]}]}], 
            ",", \(ResidualFitError \[Rule] {0.00012449664901403496`, 
                0.00013655373963811581`}\), 
            ",", \(WaveLength \[Rule] 0.532`\), 
            ",", \(SpatialScale \[Rule] 1\), 
            ",", \(OpticalPathRange \[Rule] {404.6046095738237`, 
                433.5327748863475`}\), 
            ",", \(RayBoundary \[Rule] {{\(-8.009997405593364`\), 
                  4.7870957420594165`}, {\(-8.009997405593413`\), 
                  8.009997405593413`}}\)}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[29]=",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3", "Subsubsection",
  CellTags->{"AOG0.", "6.3.3", "AOG6.", "AOG6.3", "AOG6.3.3"}],

Cell["\<\
system = 
\t{
\t\tMove[GaussianBeam[1.5,.01,FullForm->True],-50],
\t\tPlanoConcaveLens[-30,20,2,\"L1\",CurvatureDirection->Back],
\t\tMove[PlanoConvexLens[160,30,6.5,\"L2\"],130],
\t\tMove[BeamSplitter[{70,30},50,10],175,-45],
\t\tMove[Mirror[50,10],250],
\t\tMove[Mirror[50,10],{175,50},90.01],
\t\tMove[BeamSplitter[{70,30},50,10,\"\"],175,-45,GraphicDesign->Off],
\t\tMove[Screen[50],{175,-50},90]
\t};\
\>", "Input",
  CellLabel->"In[30]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],

Cell[CellGroupData[{

Cell["AnalyzeSystem[system];", "Input",
  CellLabel->"In[31]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .56393 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0198594 1.01986 -0.205443 1.01986 [
[ 0 0 0 0 ]
[ 1 .56393 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .56393 L
0 .56393 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.11095 .42272 m
.22777 .3863 L
s
.10632 .41864 m
.22252 .38138 L
s
0 g
.23892 .38053 m
.23685 .3736 L
s
.23685 .3736 m
.25014 .36932 L
s
.23685 .3736 m
.23399 .36709 L
s
.24009 .38741 m
.23892 .38053 L
s
.23892 .38053 m
.25222 .37626 L
s
.23399 .36709 m
.24729 .3628 L
s
.23399 .36709 m
.23055 .36143 L
s
.24009 .38741 m
.25339 .38316 L
s
.23532 .38916 m .25358 .38955 L .24026 .3938 L .656 .751 .92 r
F
0 g
.23942 .39925 m
.24026 .3938 L
s
.24009 .38741 m
.24014 .38926 L
s
.25014 .36932 m
.25222 .37626 L
s
.24729 .3628 m
.25014 .36932 L
s
.25222 .37626 m
.25339 .38316 L
s
.24385 .35713 m
.24729 .3628 L
s
.22676 .35701 m .23457 .36191 L .2263 .36459 L .543 .322 .53 r
F
.22676 .35701 m .24007 .35269 L .23457 .36191 L F
0 g
.23589 .35971 m
.24385 .35713 L
s
.22676 .35701 m
.24007 .35269 L
s
.22285 .35412 m
.22676 .35701 L
s
.24007 .35269 m
.24385 .35713 L
s
.23762 .4034 m
.23942 .39925 L
s
.23942 .39925 m
.25276 .39501 L
s
.23532 .38916 m .2436 .38651 L .25358 .38955 L .656 .751 .92 r
F
0 g
.25276 .39501 m
.25358 .38955 L
s
.25339 .38316 m
.25358 .38955 L
s
.24026 .3938 m
.25358 .38955 L
s
.23036 .3845 m .2436 .38651 L .23532 .38916 L .656 .751 .92 r
F
0 g
.23532 .38916 m
.24026 .3938 L
s
.2263 .36459 m .23143 .37039 L .22585 .3722 L .543 .322 .53 r
F
.2263 .36459 m .23457 .36191 L .23143 .37039 L F
0 g
.2263 .36459 m
.22676 .35701 L
s
.22285 .35412 m
.23618 .34979 L
s
.22285 .35412 m
.21911 .35298 L
s
.23457 .36191 m
.24007 .35269 L
s
.23618 .34979 m
.24007 .35269 L
s
.23036 .3845 m .23595 .38271 L .2436 .38651 L .656 .751 .92 r
F
0 g
.2436 .38651 m
.25358 .38955 L
s
.23499 .40596 m
.23762 .4034 L
s
.23762 .4034 m
.25099 .39916 L
s
.25276 .39501 m
.25099 .39916 L
s
.22539 .37983 m .23595 .38271 L .23036 .3845 L .656 .751 .92 r
F
0 g
.23036 .3845 m
.23532 .38916 L
s
.039 .916 .04 r
.11153 .4159 m
.22824 .37828 L
s
.22585 .3722 m .23013 .3783 L .22539 .37983 L .543 .322 .53 r
F
.22585 .3722 m .23143 .37039 L .23013 .3783 L F
0 g
.22585 .3722 m
.2263 .36459 L
s
.039 .916 .04 r
.23024 .37763 m
.23346 .3766 L
s
0 g
.23143 .37039 m
.23457 .36191 L
s
.23245 .34863 m
.23618 .34979 L
s
.21911 .35298 m
.23245 .34863 L
s
.21911 .35298 m
.21577 .35365 L
s
.22539 .37983 m .23013 .3783 L .23595 .38271 L .656 .751 .92 r
F
.039 .916 .04 r
.10923 .41386 m
.22563 .37582 L
s
.11125 .4193 m
.228 .38228 L
s
0 g
.23595 .38271 m
.2436 .38651 L
s
.039 .916 .04 r
.23346 .3766 m
.56388 .26719 L
s
0 0 0 r
2 Mabswid
.23346 .3766 Mdot
.039 .916 .04 r
.5 Mabswid
.228 .38228 m
.23299 .3807 L
s
.22563 .37582 m
.2306 .3742 L
s
0 g
.25099 .39916 m
.24837 .40172 L
s
.23169 .40676 m
.23499 .40596 L
s
.23499 .40596 m
.24837 .40172 L
s
0 0 0 r
2 Mabswid
.23299 .3807 Mdot
.2306 .3742 Mdot
.22539 .37983 m .23053 .38569 L .22493 .38749 L .543 .322 .53 r
F
.039 .916 .04 r
.5 Mabswid
.10865 .42068 m
.22515 .38385 L
s
.22539 .37983 m .23013 .3783 L .23053 .38569 L .543 .322 .53 r
F
.039 .916 .04 r
.23052 .38543 m
.23299 .38466 L
s
.22039 .37513 m .23013 .3783 L .22539 .37983 L .656 .751 .92 r
F
.039 .916 .04 r
.10895 .41726 m
.22539 .37983 L
s
0 g
.22557 .37682 m
.22585 .3722 L
s
.039 .916 .04 r
.10691 .41182 m
.22301 .37335 L
s
0 0 0 r
2 Mabswid
.22539 .37983 Mdot
0 g
.5 Mabswid
.22914 .3493 m
.23245 .34863 L
s
.039 .916 .04 r
.23299 .38466 m
.56469 .31467 L
s
0 0 0 r
2 Mabswid
.23299 .38466 Mdot
.22039 .37513 m .22599 .37333 L .23013 .3783 L .656 .751 .92 r
F
0 0 0 r
.23013 .3783 Mdot
.039 .916 .04 r
.5 Mabswid
.22301 .37335 m
.22821 .37165 L
s
.22539 .37983 m
.23013 .3783 L
s
.10662 .41522 m
.22277 .37737 L
s
0 g
.23013 .3783 m
.23595 .38271 L
s
.23013 .3783 m
.23143 .37039 L
s
.21577 .35365 m
.21309 .35612 L
s
.22914 .3493 m
.21577 .35365 L
s
.039 .916 .04 r
.22515 .38385 m
.23013 .38226 L
s
0 0 0 r
2 Mabswid
.22515 .38385 Mdot
.039 .916 .04 r
.5 Mabswid
.22821 .37165 m
.53652 .23578 L
s
0 0 0 r
2 Mabswid
.22821 .37165 Mdot
.039 .916 .04 r
.5 Mabswid
.22277 .37737 m
.22774 .37575 L
s
0 0 0 r
2 Mabswid
.22277 .37737 Mdot
0 g
.5 Mabswid
.24837 .40172 m
.2451 .4025 L
s
.22794 .40571 m
.23169 .40676 L
s
.23169 .40676 m
.2451 .4025 L
s
0 0 0 r
2 Mabswid
.23013 .38226 Mdot
.22493 .38749 m .2328 .39251 L .22447 .39517 L .543 .322 .53 r
F
.22493 .38749 m .23053 .38569 L .2328 .39251 L F
0 g
.5 Mabswid
.22493 .38749 m
.22539 .37983 L
s
.23013 .3783 m
.23053 .38569 L
s
0 0 0 r
2 Mabswid
.22774 .37575 Mdot
.039 .916 .04 r
.5 Mabswid
.22252 .38138 m
.22773 .37971 L
s
0 0 0 r
2 Mabswid
.22252 .38138 Mdot
.21537 .37042 m .22599 .37333 L .22039 .37513 L .656 .751 .92 r
F
0 g
.5 Mabswid
.22039 .37513 m
.22539 .37983 L
s
.22648 .35176 m
.22914 .3493 L
s
.039 .916 .04 r
.22773 .37971 m
.53704 .28354 L
s
0 0 0 r
2 Mabswid
.22773 .37971 Mdot
0 g
.5 Mabswid
.21309 .35612 m
.22648 .35176 L
s
.21309 .35612 m
.21123 .36022 L
s
.21537 .37042 m .22369 .36773 L .22599 .37333 L .656 .751 .92 r
F
0 g
.22599 .37333 m
.23013 .3783 L
s
.2451 .4025 m
.24137 .40144 L
s
.22447 .39517 m .23745 .3986 L .22401 .40288 L .543 .322 .53 r
F
0 g
.22794 .40571 m
.24137 .40144 L
s
.22401 .40288 m
.22794 .40571 L
s
.22447 .39517 m .2328 .39251 L .23745 .3986 L .543 .322 .53 r
F
0 g
.22447 .39517 m
.22493 .38749 L
s
.22401 .40288 m
.22447 .39517 L
s
.23053 .38569 m
.2328 .39251 L
s
.21033 .36568 m .22369 .36773 L .21537 .37042 L .656 .751 .92 r
F
0 g
.21537 .37042 m
.22039 .37513 L
s
.2328 .39251 m
.23745 .3986 L
s
.21123 .36022 m
.22464 .35587 L
s
.22464 .35587 m
.22648 .35176 L
s
.22401 .40288 m
.23745 .3986 L
s
.22015 .39847 m
.22401 .40288 L
s
.23745 .3986 m
.24137 .40144 L
s
.21033 .36568 m .22377 .36133 L .22369 .36773 L .656 .751 .92 r
F
0 g
.22369 .36773 m
.22377 .36133 L
s
.21033 .36568 m
.21123 .36022 L
s
.22369 .36773 m
.22599 .37333 L
s
.21033 .36568 m
.21537 .37042 L
s
.70593 .29023 m
.69319 .30334 L
s
.72101 .27977 m
.70593 .29023 L
s
.21033 .36568 m
.22377 .36133 L
s
.21033 .36568 m
.21047 .37213 L
s
.69319 .30334 m
.68362 .31825 L
s
.22377 .36133 m
.22464 .35587 L
s
.21665 .39276 m
.22015 .39847 L
s
.22015 .39847 m
.23361 .39417 L
s
.23361 .39417 m
.23745 .3986 L
s
.21047 .37213 m
.22392 .36778 L
s
.21047 .37213 m
.21164 .37912 L
s
.21374 .38616 m
.21665 .39276 L
s
.21665 .39276 m
.23012 .38845 L
s
.68362 .31825 m
.67787 .334 L
s
.21164 .37912 m
.22509 .37478 L
s
.21164 .37912 m
.21374 .38616 L
s
.21374 .38616 m
.22721 .38183 L
s
.22377 .36133 m
.22392 .36778 L
s
.23361 .39417 m
.23012 .38845 L
s
.72551 .25771 m .73746 .27266 L .73854 .29155 L .975 .682 .399 r
F
0 g
.73746 .27266 m
.7542 .26937 L
s
.72101 .27977 m
.73215 .27495 L
s
.22509 .37478 m
.22392 .36778 L
s
.23012 .38845 m
.22721 .38183 L
s
.22721 .38183 m
.22509 .37478 L
s
.77013 .27015 m
.7542 .26937 L
s
.70531 .2885 m .69381 .27543 L .68099 .28862 L .554 .338 .542 r
F
0 g
.70452 .28851 m
.70593 .29023 L
s
.71548 .28145 m .69381 .27543 L .70531 .2885 L .554 .338 .542 r
F
.71548 .28145 m .70898 .2649 L .69381 .27543 L F
.69672 .29734 m .68099 .28862 L .67135 .3036 L F
0 g
.68966 .29908 m
.69319 .30334 L
s
.70531 .2885 m .68099 .28862 L .69672 .29734 L .554 .338 .542 r
F
0 g
.68099 .28862 m
.69381 .27543 L
s
.72655 .27666 m .73854 .29155 L .73964 .31061 L .975 .682 .399 r
F
.72551 .25771 m .73854 .29155 L .72655 .27666 L F
0 g
.73746 .27266 m
.73854 .29155 L
s
.72655 .27666 m .70898 .2649 L .71548 .28145 L .554 .338 .542 r
F
0 g
.72058 .27924 m
.72101 .27977 L
s
.72655 .27666 m .72551 .25771 L .70898 .2649 L .554 .338 .542 r
F
0 g
.69381 .27543 m
.70898 .2649 L
s
.68539 .32841 m .67633 .34955 L .66394 .33503 L .656 .751 .92 r
F
.68539 .32841 m .69768 .34302 L .67633 .34955 L F
0 g
.67633 .34955 m
.67915 .36388 L
s
.69027 .30739 m .67135 .3036 L .66553 .31942 L .554 .338 .542 r
F
0 g
.67908 .31283 m
.68362 .31825 L
s
.69672 .29734 m .67135 .3036 L .69027 .30739 L .554 .338 .542 r
F
0 g
.67135 .3036 m
.68099 .28862 L
s
.78418 .27499 m
.77013 .27015 L
s
.7378 .27445 m .72551 .25771 L .72655 .27666 L .554 .338 .542 r
F
.7378 .27445 m .74233 .25436 L .72551 .25771 L F
0 g
.70898 .2649 m
.72551 .25771 L
s
.70696 .32176 m .69768 .34302 L .68539 .32841 L .656 .751 .92 r
F
.70696 .32176 m .71915 .33645 L .69768 .34302 L F
0 g
.67633 .34955 m
.69768 .34302 L
s
.68641 .31798 m .66553 .31942 L .66394 .33503 L .554 .338 .542 r
F
0 g
.67295 .32819 m
.67567 .33141 L
s
.69027 .30739 m .66553 .31942 L .68641 .31798 L .554 .338 .542 r
F
0 g
.66553 .31942 m
.67135 .3036 L
s
.67915 .36388 m
.68619 .376 L
s
.7276 .29578 m .73964 .31061 L .74074 .32984 L .975 .682 .399 r
F
.72655 .27666 m .73964 .31061 L .7276 .29578 L F
0 g
.73854 .29155 m
.73964 .31061 L
s
.74848 .27499 m .74233 .25436 L .7378 .27445 L .554 .338 .542 r
F
.74848 .27499 m .75832 .2551 L .74233 .25436 L F
0 g
.72551 .25771 m
.74233 .25436 L
s
.75239 .26708 m
.7542 .26937 L
s
.71692 .30171 m .70531 .2885 L .69672 .29734 L .554 .338 .542 r
F
.72203 .29817 m .70531 .2885 L .71692 .30171 L F
.72203 .29817 m .71548 .28145 L .70531 .2885 L F
.71692 .30171 m .69672 .29734 L .7126 .30616 L F
.7126 .30616 m .69672 .29734 L .69027 .30739 L F
.7276 .29578 m .71548 .28145 L .72203 .29817 L F
.7276 .29578 m .72655 .27666 L .71548 .28145 L F
0 g
.79538 .28362 m
.78418 .27499 L
s
.70937 .31121 m .69027 .30739 L .68641 .31798 L .554 .338 .542 r
F
.7126 .30616 m .69027 .30739 L .70937 .31121 L F
.72866 .31506 m .71915 .33645 L .70696 .32176 L .656 .751 .92 r
F
.72866 .31506 m .74074 .32984 L .71915 .33645 L F
0 g
.69768 .34302 m
.71915 .33645 L
s
0 0 0 r
2 Mabswid
.70113 .29979 Mdot
.73325 .29469 m .72655 .27666 L .7276 .29578 L .554 .338 .542 r
F
.73325 .29469 m .7378 .27445 L .72655 .27666 L F
0 g
.5 Mabswid
.72551 .25771 m
.72655 .27666 L
s
.68641 .31798 m .66394 .33503 L .68539 .32841 L .554 .338 .542 r
F
.68539 .32841 m .66394 .33503 L .66674 .34939 L F
0 g
.67156 .34396 m
.67633 .34955 L
s
.66394 .33503 m
.66553 .31942 L
s
.70745 .31653 m .68641 .31798 L .68539 .32841 L .554 .338 .542 r
F
.70937 .31121 m .68641 .31798 L .70745 .31653 L F
0 g
.68619 .376 m
.69701 .38506 L
s
.75786 .27826 m .75832 .2551 L .74848 .27499 L .554 .338 .542 r
F
.75786 .27826 m .77242 .25991 L .75832 .2551 L F
0 g
.74233 .25436 m
.75832 .2551 L
s
.76723 .26645 m
.77013 .27015 L
s
.73859 .29498 m .7378 .27445 L .73325 .29469 L .554 .338 .542 r
F
.73859 .29498 m .74848 .27499 L .7378 .27445 L F
.7276 .29578 m .74074 .32984 L .72866 .31506 L .975 .682 .399 r
F
.72866 .31506 m .74074 .32984 L .74185 .34925 L F
0 g
.71915 .33645 m
.73504 .33159 L
s
.75048 .30833 m .74074 .32984 L .72866 .31506 L .656 .751 .92 r
F
0 g
.73964 .31061 m
.7397 .31166 L
s
.75048 .30833 m .76246 .3232 L .74074 .32984 L .656 .751 .92 r
F
.70745 .31653 m .68539 .32841 L .70696 .32176 L .554 .338 .542 r
F
.68539 .32841 m .66674 .34939 L .68731 .33798 L F
.70696 .32176 m .68539 .32841 L .68731 .33798 L F
0 g
.66394 .33503 m
.68539 .32841 L
s
.80293 .29548 m
.79538 .28362 L
s
0 0 0 r
2 Mabswid
.72738 .29171 Mdot
.72866 .31506 m .71692 .30171 L .7126 .30616 L .554 .338 .542 r
F
.72866 .31506 m .72203 .29817 L .71692 .30171 L F
.72866 .31506 m .7126 .30616 L .70937 .31121 L F
.72866 .31506 m .7276 .29578 L .72203 .29817 L F
.68731 .33798 m .66674 .34939 L .67377 .36152 L F
0 g
.5 Mabswid
.66394 .33503 m
.66674 .34939 L
s
.67512 .35917 m
.67915 .36388 L
s
.74328 .29664 m .74848 .27499 L .73859 .29498 L .554 .338 .542 r
F
.74328 .29664 m .75786 .27826 L .74848 .27499 L F
.72866 .31506 m .70937 .31121 L .70745 .31653 L F
.72866 .31506 m .73325 .29469 L .7276 .29578 L F
0 g
.72655 .27666 m
.7276 .29578 L
s
.72866 .31506 m .70745 .31653 L .70696 .32176 L .554 .338 .542 r
F
.72866 .31506 m .73859 .29498 L .73325 .29469 L F
.77243 .30156 m .76246 .3232 L .75048 .30833 L .656 .751 .92 r
F
.77243 .30156 m .7843 .31651 L .76246 .3232 L F
0 g
.74074 .32984 m
.76246 .3232 L
s
0 0 0 r
2 Mabswid
.70238 .32317 Mdot
.7653 .28405 m .77242 .25991 L .75786 .27826 L .554 .338 .542 r
F
.7653 .28405 m .78364 .26853 L .77242 .25991 L F
0 g
.5 Mabswid
.75832 .2551 m
.77242 .25991 L
s
.78093 .27082 m
.78418 .27499 L
s
.68731 .33798 m .67377 .36152 L .69205 .34604 L .554 .338 .542 r
F
.70795 .32654 m .68731 .33798 L .69205 .34604 L F
.70696 .32176 m .68731 .33798 L .70795 .32654 L F
0 g
.69701 .38506 m
.71092 .3904 L
s
.72866 .31506 m .70696 .32176 L .70795 .32654 L .554 .338 .542 r
F
0 g
.68539 .32841 m
.70696 .32176 L
s
.72866 .31506 m .74328 .29664 L .73859 .29498 L .554 .338 .542 r
F
.74698 .29956 m .75786 .27826 L .74328 .29664 L F
.74698 .29956 m .7653 .28405 L .75786 .27826 L F
.72972 .33452 m .74185 .34925 L .74298 .36882 L .975 .682 .399 r
F
.72866 .31506 m .74185 .34925 L .72972 .33452 L F
0 g
.74074 .32984 m
.74185 .34925 L
s
0 0 0 r
2 Mabswid
.7538 .28337 Mdot
.70795 .32654 m .69205 .34604 L .71035 .33056 L .554 .338 .542 r
F
.72866 .31506 m .70795 .32654 L .71035 .33056 L F
.72866 .31506 m .74698 .29956 L .74328 .29664 L F
.69205 .34604 m .67377 .36152 L .68461 .37058 L F
0 g
.5 Mabswid
.66674 .34939 m
.67377 .36152 L
s
.67377 .36152 m
.68619 .376 L
s
.79451 .29475 m .7843 .31651 L .77243 .30156 L .656 .751 .92 r
F
.79451 .29475 m .80627 .30979 L .7843 .31651 L F
0 g
.76246 .3232 m
.7843 .31651 L
s
.7843 .31651 m
.80627 .30979 L
s
.80293 .29548 m
.80627 .30979 L
s
.69205 .34604 m .68461 .37058 L .69932 .35203 L .554 .338 .542 r
F
.71035 .33056 m .69205 .34604 L .69932 .35203 L F
.71035 .33056 m .69932 .35203 L .71401 .33353 L F
.72866 .31506 m .71035 .33056 L .71401 .33353 L F
.72866 .31506 m .74943 .30355 L .74698 .29956 L F
.72866 .31506 m .75048 .30833 L .74943 .30355 L F
.72866 .31506 m .75003 .31359 L .75048 .30833 L F
.72866 .31506 m .74812 .31896 L .75003 .31359 L F
.72866 .31506 m .74488 .32406 L .74812 .31896 L F
.72866 .31506 m .74052 .32856 L .74488 .32406 L F
.72866 .31506 m .73535 .33213 L .74052 .32856 L F
.72866 .31506 m .72972 .33452 L .73535 .33213 L F
.72866 .31506 m .72404 .33559 L .72972 .33452 L F
.72866 .31506 m .71867 .33525 L .72404 .33559 L F
.72866 .31506 m .71401 .33353 L .71867 .33525 L F
0 0 0 r
2 Mabswid
.72866 .31506 Mdot
0 g
.5 Mabswid
.7276 .29578 m
.72866 .31506 L
s
.70696 .32176 m
.72866 .31506 L
s
.74943 .30355 m .7653 .28405 L .74698 .29956 L .554 .338 .542 r
F
.77028 .29199 m .78364 .26853 L .7653 .28405 L F
.74943 .30355 m .77028 .29199 L .7653 .28405 L F
0 g
.71092 .3904 m
.72699 .39161 L
s
.77028 .29199 m .79119 .2804 L .78364 .26853 L .554 .338 .542 r
F
0 g
.77242 .25991 m
.78364 .26853 L
s
.78364 .26853 m
.79538 .28362 L
s
.71401 .33353 m .70864 .35553 L .71867 .33525 L .554 .338 .542 r
F
.71401 .33353 m .69932 .35203 L .70864 .35553 L F
.75048 .30833 m .77028 .29199 L .74943 .30355 L F
0 0 0 r
2 Mabswid
.70342 .34688 Mdot
.69932 .35203 m .69856 .3759 L .70864 .35553 L .554 .338 .542 r
F
.69932 .35203 m .68461 .37058 L .69856 .3759 L F
0 g
.5 Mabswid
.67377 .36152 m
.68461 .37058 L
s
.68461 .37058 m
.69701 .38506 L
s
.80511 .32559 m
.80627 .30979 L
s
.71867 .33525 m .71938 .35626 L .72404 .33559 L .554 .338 .542 r
F
.71867 .33525 m .70864 .35553 L .71938 .35626 L F
.7308 .35416 m .74298 .36882 L .74411 .38857 L .975 .682 .399 r
F
.72972 .33452 m .74298 .36882 L .7308 .35416 L F
0 g
.74185 .34925 m
.74298 .36882 L
s
.75048 .30833 m .77243 .30156 L .77028 .29199 L .554 .338 .542 r
F
.75003 .31359 m .77243 .30156 L .75048 .30833 L F
0 g
.72866 .31506 m
.75048 .30833 L
s
.77243 .30156 m .79119 .2804 L .77028 .29199 L .554 .338 .542 r
F
0 0 0 r
2 Mabswid
.75512 .3069 Mdot
.72404 .33559 m .7308 .35416 L .72972 .33452 L .554 .338 .542 r
F
.72404 .33559 m .71938 .35626 L .7308 .35416 L F
.75003 .31359 m .77158 .3121 L .77243 .30156 L F
.74812 .31896 m .77158 .3121 L .75003 .31359 L F
0 g
.5 Mabswid
.56803 .27756 m
.56474 .26675 L
s
.56474 .26675 m
.57793 .2625 L
s
.56474 .26675 m
.56052 .2565 L
s
.72972 .33452 m .74211 .34936 L .73535 .33213 L .554 .338 .542 r
F
.72972 .33452 m .7308 .35416 L .74211 .34936 L F
0 g
.72866 .31506 m
.72972 .33452 L
s
.57017 .28822 m
.56803 .27756 L
s
.56803 .27756 m
.58123 .27333 L
s
.74488 .32406 m .76778 .32289 L .74812 .31896 L .554 .338 .542 r
F
.74812 .31896 m .76778 .32289 L .77158 .3121 L F
.70864 .35553 m .71469 .37707 L .71938 .35626 L F
.70864 .35553 m .69856 .3759 L .71469 .37707 L F
0 g
.69856 .3759 m
.71092 .3904 L
s
.68461 .37058 m
.69856 .3759 L
s
.039 .916 .04 r
.56388 .26719 m
.57737 .26285 L
s
.77243 .30156 m .79451 .29475 L .79119 .2804 L .554 .338 .542 r
F
0 g
.78364 .26853 m
.79119 .2804 L
s
.79119 .2804 m
.80293 .29548 L
s
.73535 .33213 m .75251 .34219 L .74052 .32856 L .554 .338 .542 r
F
.73535 .33213 m .74211 .34936 L .75251 .34219 L F
0 g
.56052 .2565 m
.57371 .25223 L
s
.56052 .2565 m
.55564 .24749 L
s
.74488 .32406 m .76127 .33316 L .76778 .32289 L .554 .338 .542 r
F
.74052 .32856 m .76127 .33316 L .74488 .32406 L F
.74052 .32856 m .75251 .34219 L .76127 .33316 L F
0 0 0 r
2 Mabswid
.72995 .33867 Mdot
0 g
.5 Mabswid
.79949 .34177 m
.80511 .32559 L
s
.57017 .28822 m
.58339 .28401 L
s
.77158 .3121 m .79451 .29475 L .77243 .30156 L .554 .338 .542 r
F
0 g
.75048 .30833 m
.77243 .30156 L
s
.57793 .2625 m
.58123 .27333 L
s
.57371 .25223 m
.57793 .2625 L
s
.58123 .27333 m
.58339 .28401 L
s
.55564 .24749 m
.56884 .2432 L
s
0 0 0 r
2 Mabswid
.57737 .26285 Mdot
0 g
.5 Mabswid
.56884 .2432 m
.57371 .25223 L
s
.7308 .35416 m .74411 .38857 L .73189 .37397 L .975 .682 .399 r
F
0 g
.74411 .38857 m
.76107 .38145 L
s
.72699 .39161 m
.74411 .38857 L
s
.74298 .36882 m
.74411 .38857 L
s
.71938 .35626 m .73189 .37397 L .7308 .35416 L .554 .338 .542 r
F
.71938 .35626 m .71469 .37707 L .73189 .37397 L F
0 g
.71469 .37707 m
.72699 .39161 L
s
.69856 .3759 m
.71469 .37707 L
s
.56239 .29109 m .58426 .29383 L .57102 .29803 L .656 .751 .92 r
F
0 g
.5705 .30634 m
.57102 .29803 L
s
.57017 .28822 m
.5705 .29211 L
s
.78979 .35718 m
.79949 .34177 L
s
.77158 .3121 m .7933 .3106 L .79451 .29475 L .554 .338 .542 r
F
0 g
.77243 .30156 m
.79451 .29475 L
s
.79119 .2804 m
.79451 .29475 L
s
.79451 .29475 m
.80627 .30979 L
s
.76778 .32289 m .7933 .3106 L .77158 .3121 L .554 .338 .542 r
F
0 g
.76107 .38145 m
.77667 .37073 L
s
.55042 .24031 m .56385 .24756 L .54862 .25251 L .543 .322 .53 r
F
.039 .916 .04 r
.2306 .3742 m
.54863 .25245 L
s
.55042 .24031 m .56365 .236 L .56385 .24756 L .543 .322 .53 r
F
0 g
.56365 .236 m
.56884 .2432 L
s
.55042 .24031 m
.56365 .236 L
s
.54521 .23546 m
.55042 .24031 L
s
.7308 .35416 m .74894 .36677 L .74211 .34936 L .554 .338 .542 r
F
.7308 .35416 m .73189 .37397 L .74894 .36677 L F
0 g
.72972 .33452 m
.7308 .35416 L
s
.73189 .37397 m
.74411 .38857 L
s
.7308 .35416 m
.73189 .37397 L
s
0 0 0 r
2 Mabswid
.75669 .33061 Mdot
.56239 .29109 m .57763 .28623 L .58426 .29383 L .656 .751 .92 r
F
0 g
.5 Mabswid
.58378 .30214 m
.58426 .29383 L
s
.58339 .28401 m
.58426 .29383 L
s
.039 .916 .04 r
.23299 .3807 m
.56243 .29113 L
s
0 g
.57102 .29803 m
.58426 .29383 L
s
.77667 .37073 m
.78979 .35718 L
s
.76778 .32289 m .78762 .32685 L .7933 .3106 L .554 .338 .542 r
F
0 g
.7933 .3106 m
.79451 .29475 L
s
.7933 .3106 m
.80511 .32559 L
s
.76127 .33316 m .78762 .32685 L .76778 .32289 L .554 .338 .542 r
F
0 g
.56866 .31257 m
.5705 .30634 L
s
.5705 .30634 m
.58378 .30214 L
s
.74211 .34936 m .76463 .35598 L .75251 .34219 L .554 .338 .542 r
F
.74211 .34936 m .74894 .36677 L .76463 .35598 L F
0 g
.74894 .36677 m
.76107 .38145 L
s
.55451 .28385 m .57763 .28623 L .56239 .29109 L .656 .751 .92 r
F
.039 .916 .04 r
.56243 .29113 m
.57767 .28628 L
s
0 g
.56239 .29109 m
.57102 .29803 L
s
.76127 .33316 m .77783 .34235 L .78762 .32685 L .554 .338 .542 r
F
0 g
.78762 .32685 m
.79949 .34177 L
s
.75251 .34219 m .77783 .34235 L .76127 .33316 L .554 .338 .542 r
F
.75251 .34219 m .76463 .35598 L .77783 .34235 L F
0 g
.77783 .34235 m
.78979 .35718 L
s
.76463 .35598 m
.77667 .37073 L
s
.71469 .37707 m
.73189 .37397 L
s
.55846 .23113 m
.56365 .236 L
s
0 0 0 r
2 Mabswid
.54863 .25245 Mdot
.54862 .25251 m .56405 .25919 L .54761 .26451 L .543 .322 .53 r
F
.54862 .25251 m .56385 .24756 L .56405 .25919 L F
0 g
.5 Mabswid
.54862 .25251 m
.55042 .24031 L
s
.039 .916 .04 r
.54863 .25245 m
.56385 .2475 L
s
0 g
.56365 .236 m
.56385 .24756 L
s
.58378 .30214 m
.58197 .30837 L
s
.54521 .23546 m
.55846 .23113 L
s
.54521 .23546 m
.54036 .23328 L
s
.78762 .32685 m
.7933 .3106 L
s
0 0 0 r
2 Mabswid
.57767 .28628 Mdot
.55451 .28385 m .57096 .27858 L .57763 .28623 L .656 .751 .92 r
F
0 g
.5 Mabswid
.57763 .28623 m
.58426 .29383 L
s
.5656 .3163 m
.56866 .31257 L
s
.56866 .31257 m
.58197 .30837 L
s
.54737 .27631 m .57096 .27858 L .55451 .28385 L .656 .751 .92 r
F
0 g
.55451 .28385 m
.56239 .29109 L
s
0 0 0 r
2 Mabswid
.56385 .2475 Mdot
0 g
.5 Mabswid
.73189 .37397 m
.74894 .36677 L
s
.55364 .22893 m
.55846 .23113 L
s
.54761 .26451 m .56425 .27089 L .54737 .27631 L .543 .322 .53 r
F
.54761 .26451 m .56405 .25919 L .56425 .27089 L F
0 g
.54761 .26451 m
.54862 .25251 L
s
.56385 .24756 m
.56405 .25919 L
s
.77783 .34235 m
.78762 .32685 L
s
.58197 .30837 m
.57895 .31209 L
s
.54036 .23328 m
.55364 .22893 L
s
.54036 .23328 m
.53619 .23395 L
s
.74894 .36677 m
.76463 .35598 L
s
.54737 .27631 m .56425 .27089 L .57096 .27858 L .656 .751 .92 r
F
0 g
.57096 .27858 m
.57763 .28623 L
s
.76463 .35598 m
.77783 .34235 L
s
.56152 .31724 m
.5656 .3163 L
s
.5656 .3163 m
.57895 .31209 L
s
.039 .916 .04 r
.56469 .31467 m
.57833 .31037 L
s
0 0 0 r
2 Mabswid
.56469 .31467 Mdot
.54737 .27631 m .56445 .28264 L .54792 .28793 L .543 .322 .53 r
F
.54737 .27631 m .56425 .27089 L .56445 .28264 L F
.54097 .26847 m .56425 .27089 L .54737 .27631 L .656 .751 .92 r
F
0 0 0 r
.54737 .27631 Mdot
.039 .916 .04 r
.5 Mabswid
.23013 .3783 m
.54737 .27631 L
s
0 g
.54751 .26915 m
.54761 .26451 L
s
.54952 .22958 m
.55364 .22893 L
s
.57895 .31209 m
.5749 .31302 L
s
0 0 0 r
2 Mabswid
.57833 .31037 Mdot
.67628 .20282 m .68143 .18536 L .69837 .19422 L .764 .495 .527 r
F
.66422 .19927 m .68143 .18536 L .67628 .20282 L F
.66422 .19927 m .66343 .18005 L .68143 .18536 L F
.67628 .20282 m .68143 .18536 L .69837 .19422 L F
.66422 .19927 m .68143 .18536 L .67628 .20282 L F
.66422 .19927 m .66343 .18005 L .68143 .18536 L F
0 g
.5 Mabswid
.68143 .18536 m
.6912 .16781 L
s
.68762 .20875 m .69837 .19422 L .71313 .20605 L .764 .495 .527 r
F
.67628 .20282 m .69837 .19422 L .68762 .20875 L F
.68762 .20875 m .69837 .19422 L .71313 .20605 L F
.67628 .20282 m .69837 .19422 L .68762 .20875 L F
0 g
.68143 .18536 m
.69837 .19422 L
s
.69837 .19422 m
.70826 .17673 L
s
.039 .916 .04 r
.53652 .23578 m
.55014 .23132 L
s
0 0 0 r
2 Mabswid
.53652 .23578 Mdot
0 g
.5 Mabswid
.53619 .23395 m
.53301 .23744 L
s
.54952 .22958 m
.53619 .23395 L
s
.54097 .26847 m .55749 .26314 L .56425 .27089 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.56425 .27089 Mdot
0 g
.5 Mabswid
.56425 .27089 m
.57096 .27858 L
s
.039 .916 .04 r
.54737 .27631 m
.56425 .27089 L
s
0 g
.56405 .25919 m
.56425 .27089 L
s
.65225 .19835 m .66343 .18005 L .66422 .19927 L .764 .495 .527 r
F
.65225 .19835 m .64555 .17864 L .66343 .18005 L F
.66343 .18005 m .67392 .18171 L .66422 .19927 L 0 0 .397 r
F
0 g
.67324 .18295 m
.68143 .18536 L
s
.66343 .18005 m .67308 .16244 L .67392 .18171 L 0 0 .397 r
F
.65225 .19835 m .66343 .18005 L .66422 .19927 L .764 .495 .527 r
F
.65225 .19835 m .64555 .17864 L .66343 .18005 L F
.66343 .18005 m .67392 .18171 L .66422 .19927 L 0 0 .397 r
F
.66343 .18005 m .67308 .16244 L .67392 .18171 L F
0 g
.66343 .18005 m
.67308 .16244 L
s
.6975 .21668 m .71313 .20605 L .72476 .22009 L .764 .495 .527 r
F
.68762 .20875 m .71313 .20605 L .6975 .21668 L F
.6975 .21668 m .71313 .20605 L .72476 .22009 L F
.68762 .20875 m .71313 .20605 L .6975 .21668 L F
0 g
.69837 .19422 m
.71313 .20605 L
s
.71313 .20605 m
.72314 .18863 L
s
.55668 .31531 m
.56152 .31724 L
s
.56152 .31724 m
.5749 .31302 L
s
.54792 .28793 m .56465 .29446 L .54926 .29936 L .543 .322 .53 r
F
.54792 .28793 m .56445 .28264 L .56465 .29446 L F
0 g
.54737 .27631 m
.54792 .28793 L
s
.56425 .27089 m
.56445 .28264 L
s
.53531 .26033 m .55749 .26314 L .54097 .26847 L .656 .751 .92 r
F
0 g
.54097 .26847 m
.54737 .27631 L
s
0 0 0 r
2 Mabswid
.55014 .23132 Mdot
0 g
.5 Mabswid
.54637 .23307 m
.54952 .22958 L
s
.64116 .20012 m .64555 .17864 L .65225 .19835 L .764 .495 .527 r
F
.64116 .20012 m .62895 .18125 L .64555 .17864 L F
.64116 .20012 m .64555 .17864 L .65225 .19835 L F
.64116 .20012 m .62895 .18125 L .64555 .17864 L F
0 g
.64555 .17864 m
.66343 .18005 L
s
.64555 .17864 m
.65509 .16099 L
s
.5749 .31302 m
.57009 .31107 L
s
.70526 .22609 m .72476 .22009 L .73245 .23541 L .764 .495 .527 r
F
.6975 .21668 m .72476 .22009 L .70526 .22609 L F
.70526 .22609 m .72476 .22009 L .73245 .23541 L F
.039 .916 .04 r
.70931 .22748 m
.7538 .28337 L
s
.70935 .22749 m
.7538 .28337 L
s
.6975 .21668 m .72476 .22009 L .70526 .22609 L .764 .495 .527 r
F
0 g
.71313 .20605 m
.72476 .22009 L
s
.72476 .22009 m
.73487 .20273 L
s
.53301 .23744 m
.54637 .23307 L
s
.53301 .23744 m
.53103 .24355 L
s
.53531 .26033 m .55069 .25534 L .55749 .26314 L .656 .751 .92 r
F
0 g
.55749 .26314 m
.56425 .27089 L
s
.54926 .29936 m .56486 .30635 L .55141 .31061 L .543 .322 .53 r
F
.54926 .29936 m .56465 .29446 L .56486 .30635 L F
.039 .916 .04 r
.23013 .38226 m
.54927 .29942 L
s
0 g
.54792 .28793 m
.54926 .29936 L
s
.54926 .29936 m
.55141 .31061 L
s
.56445 .28264 m
.56465 .29446 L
s
.039 .916 .04 r
.54927 .29942 m
.56466 .29453 L
s
0 0 0 r
2 Mabswid
.54927 .29942 Mdot
0 g
.5 Mabswid
.55141 .31061 m
.55668 .31531 L
s
.55668 .31531 m
.57009 .31107 L
s
.67108 .22044 m .67628 .20282 L .68762 .20875 L .764 .495 .527 r
F
.66502 .21866 m .67628 .20282 L .67108 .22044 L F
.66502 .21866 m .66422 .19927 L .67628 .20282 L F
.67108 .22044 m .67628 .20282 L .68762 .20875 L F
.66502 .21866 m .67628 .20282 L .67108 .22044 L F
.66502 .21866 m .66422 .19927 L .67628 .20282 L F
.67678 .22342 m .68762 .20875 L .6975 .21668 L F
.67108 .22044 m .68762 .20875 L .67678 .22342 L F
.67678 .22342 m .68762 .20875 L .6975 .21668 L F
.67108 .22044 m .68762 .20875 L .67678 .22342 L F
0 g
.54443 .23917 m
.54637 .23307 L
s
.53042 .25186 m .55069 .25534 L .53531 .26033 L .656 .751 .92 r
F
0 g
.53531 .26033 m
.54097 .26847 L
s
.039 .916 .04 r
.22774 .37575 m
.53528 .26028 L
s
0 0 0 r
2 Mabswid
.53528 .26028 Mdot
.63171 .2045 m .62895 .18125 L .64116 .20012 L .764 .495 .527 r
F
.63171 .2045 m .61475 .18773 L .62895 .18125 L F
.63171 .2045 m .62895 .18125 L .64116 .20012 L F
.63171 .2045 m .61475 .18773 L .62895 .18125 L F
0 g
.5 Mabswid
.62895 .18125 m
.64555 .17864 L
s
.62895 .18125 m
.6384 .16356 L
s
.66422 .19927 m .67477 .20117 L .66502 .21866 L 0 0 .397 r
F
.039 .916 .04 r
.6511 .23911 m
.70113 .29979 L
s
.65114 .23908 m
.70113 .29979 L
s
.66422 .19927 m .67392 .18171 L .67477 .20117 L 0 0 .397 r
F
.66422 .19927 m .67477 .20117 L .66502 .21866 L F
.66422 .19927 m .67392 .18171 L .67477 .20117 L F
.65901 .21821 m .66422 .19927 L .66502 .21866 L .764 .495 .527 r
F
.65901 .21821 m .65225 .19835 L .66422 .19927 L F
.65901 .21821 m .66422 .19927 L .66502 .21866 L F
.65901 .21821 m .65225 .19835 L .66422 .19927 L F
0 g
.66343 .18005 m
.66422 .19927 L
s
.67678 .22342 m .6975 .21668 L .68173 .22741 L .764 .495 .527 r
F
.67678 .22342 m .6975 .21668 L .68173 .22741 L F
.68173 .22741 m .6975 .21668 L .70526 .22609 L F
.039 .916 .04 r
.57737 .26285 m
.68864 .22702 L
s
.68173 .22741 m .6975 .21668 L .70526 .22609 L .764 .495 .527 r
F
.71037 .23635 m .73245 .23541 L .73568 .25102 L F
.70526 .22609 m .73245 .23541 L .71037 .23635 L F
.71037 .23635 m .73245 .23541 L .73568 .25102 L F
.70526 .22609 m .73245 .23541 L .71037 .23635 L F
0 g
.72476 .22009 m
.73245 .23541 L
s
.039 .916 .04 r
.66934 .21993 m
.72738 .29171 L
s
.66909 .21985 m
.72738 .29171 L
s
0 0 0 r
2 Mabswid
.70483 .22181 Mdot
.70483 .22184 Mdot
0 g
.5 Mabswid
.56486 .30635 m
.57009 .31107 L
s
.56465 .29446 m
.56486 .30635 L
s
0 0 0 r
2 Mabswid
.56466 .29453 Mdot
0 g
.5 Mabswid
.53103 .24355 m
.54443 .23917 L
s
.65346 .21912 m .65225 .19835 L .65901 .21821 L .764 .495 .527 r
F
.65346 .21912 m .64116 .20012 L .65225 .19835 L F
.65346 .21912 m .65225 .19835 L .65901 .21821 L F
.65346 .21912 m .64116 .20012 L .65225 .19835 L F
.039 .916 .04 r
.56385 .2475 m
.65304 .21847 L
s
.68562 .23214 m .70526 .22609 L .71037 .23635 L .764 .495 .527 r
F
.68173 .22741 m .70526 .22609 L .68562 .23214 L F
.68562 .23214 m .70526 .22609 L .71037 .23635 L F
.68173 .22741 m .70526 .22609 L .68562 .23214 L F
0 g
.6912 .16781 m
.70826 .17673 L
s
.67308 .16244 m
.6912 .16781 L
s
.70826 .17673 m
.72314 .18863 L
s
.54609 .30344 m
.55141 .31061 L
s
.55141 .31061 m
.56486 .30635 L
s
.53042 .25186 m .54384 .24749 L .55069 .25534 L .656 .751 .92 r
F
0 g
.54384 .24749 m
.55069 .25534 L
s
.53042 .25186 m
.53103 .24355 L
s
.039 .916 .04 r
.53528 .26028 m
.55065 .25529 L
s
0 g
.55069 .25534 m
.55749 .26314 L
s
.53042 .25186 m
.53531 .26033 L
s
0 0 0 r
2 Mabswid
.55065 .25529 Mdot
0 g
.5 Mabswid
.65509 .16099 m
.67308 .16244 L
s
.67308 .16244 m
.67392 .18171 L
s
.54384 .24749 m
.54443 .23917 L
s
.72314 .18863 m
.73487 .20273 L
s
.64873 .22133 m .64116 .20012 L .65346 .21912 L .764 .495 .527 r
F
.64873 .22133 m .63171 .2045 L .64116 .20012 L F
.64873 .22133 m .64116 .20012 L .65346 .21912 L F
.64873 .22133 m .63171 .2045 L .64116 .20012 L F
.62453 .21118 m .61475 .18773 L .63171 .2045 L F
.62453 .21118 m .60393 .19769 L .61475 .18773 L F
.62453 .21118 m .61475 .18773 L .63171 .2045 L F
.62453 .21118 m .60393 .19769 L .61475 .18773 L F
.039 .916 .04 r
.55014 .23132 m
.62025 .20838 L
s
0 g
.61475 .18773 m
.62895 .18125 L
s
.61475 .18773 m
.62413 .17004 L
s
.71037 .23635 m .73568 .25102 L .71248 .24678 L .764 .495 .527 r
F
.68816 .23729 m .71037 .23635 L .71248 .24678 L F
.68562 .23214 m .71037 .23635 L .68816 .23729 L F
.71037 .23635 m .73568 .25102 L .71248 .24678 L F
.68816 .23729 m .71037 .23635 L .71248 .24678 L F
.68562 .23214 m .71037 .23635 L .68816 .23729 L F
0 g
.53042 .25186 m
.54384 .24749 L
s
.53042 .25186 m
.53121 .26182 L
s
.039 .916 .04 r
.65978 .19408 m
.66484 .21436 L
s
0 0 0 r
2 Mabswid
.66484 .21436 Mdot
.039 .916 .04 r
.5 Mabswid
.65986 .19418 m
.66489 .21436 L
s
0 0 0 r
2 Mabswid
.66485 .21463 Mdot
0 g
.5 Mabswid
.55956 .29916 m
.56486 .30635 L
s
.71248 .24678 m .73568 .25102 L .73418 .26588 L .764 .495 .527 r
F
.71248 .24678 m .74594 .23378 L .73568 .25102 L .656 .751 .92 r
F
0 g
.73245 .23541 m
.73314 .23875 L
s
.71248 .24678 m .73568 .25102 L .73418 .26588 L .764 .495 .527 r
F
.71248 .24678 m .74594 .23378 L .73568 .25102 L .656 .751 .92 r
F
0 g
.54108 .2943 m
.54609 .30344 L
s
.54609 .30344 m
.55956 .29916 L
s
.66582 .23823 m .67108 .22044 L .67678 .22342 L .764 .495 .527 r
F
.66582 .23823 m .66502 .21866 L .67108 .22044 L F
.66582 .23823 m .67108 .22044 L .67678 .22342 L F
.66582 .23823 m .66502 .21866 L .67108 .22044 L F
.66582 .23823 m .67678 .22342 L .68173 .22741 L F
.66582 .23823 m .67678 .22342 L .68173 .22741 L F
0 g
.6384 .16356 m
.65509 .16099 L
s
.66582 .23823 m .65901 .21821 L .66502 .21866 L .764 .495 .527 r
F
.66502 .21866 m .67563 .2208 L .66582 .23823 L 0 0 .397 r
F
.039 .916 .04 r
.65211 .26262 m
.70238 .32317 L
s
.65204 .26274 m
.70238 .32317 L
s
.66502 .21866 m .67477 .20117 L .67563 .2208 L 0 0 .397 r
F
.66582 .23823 m .65901 .21821 L .66502 .21866 L .764 .495 .527 r
F
.66502 .21866 m .67563 .2208 L .66582 .23823 L 0 0 .397 r
F
.66502 .21866 m .67477 .20117 L .67563 .2208 L F
0 g
.66422 .19927 m
.66502 .21866 L
s
.039 .916 .04 r
.67508 .20821 m
.68936 .19962 L
s
.67509 .20846 m
.68937 .19986 L
s
.66582 .23823 m .68173 .22741 L .68562 .23214 L .764 .495 .527 r
F
.66582 .23823 m .68173 .22741 L .68562 .23214 L F
0 g
.73487 .20273 m
.74265 .21811 L
s
.66582 .23823 m .65346 .21912 L .65901 .21821 L .764 .495 .527 r
F
.66582 .23823 m .65346 .21912 L .65901 .21821 L F
.64516 .2247 m .63171 .2045 L .64873 .22133 L F
.64516 .2247 m .62453 .21118 L .63171 .2045 L F
.039 .916 .04 r
.63224 .21624 m
.6511 .23911 L
s
.63245 .21637 m
.65114 .23908 L
s
.64516 .2247 m .63171 .2045 L .64873 .22133 L .764 .495 .527 r
F
.64516 .2247 m .62453 .21118 L .63171 .2045 L F
0 g
.53121 .26182 m
.54466 .25746 L
s
.53121 .26182 m
.53336 .27272 L
s
.54384 .24749 m
.54466 .25746 L
s
.66582 .23823 m .68562 .23214 L .68816 .23729 L .764 .495 .527 r
F
.66582 .23823 m .68562 .23214 L .68816 .23729 L F
.68816 .23729 m .71248 .24678 L .68919 .24251 L F
.68816 .23729 m .71248 .24678 L .68919 .24251 L F
.71248 .24678 m .73418 .26588 L .71142 .25667 L F
.039 .916 .04 r
.71654 .25874 m
.75512 .3069 L
s
.71624 .25862 m
.75512 .3069 L
s
.68919 .24251 m .71248 .24678 L .71142 .25667 L .764 .495 .527 r
F
.039 .916 .04 r
.57767 .28628 m
.69786 .24803 L
s
.71248 .24678 m .72259 .22947 L .74594 .23378 L .656 .751 .92 r
F
.68919 .24251 m .72259 .22947 L .71248 .24678 L F
.71248 .24678 m .73418 .26588 L .71142 .25667 L .764 .495 .527 r
F
.68919 .24251 m .71248 .24678 L .71142 .25667 L F
.71248 .24678 m .72259 .22947 L .74594 .23378 L .656 .751 .92 r
F
0 g
.73568 .25102 m
.74594 .23378 L
s
.73465 .23169 m
.74265 .21811 L
s
.68919 .24251 m .72259 .22947 L .71248 .24678 L .656 .751 .92 r
F
0 g
.71248 .24678 m
.73568 .25102 L
s
.53673 .28381 m
.54108 .2943 L
s
.54108 .2943 m
.55455 .28999 L
s
.039 .916 .04 r
.53704 .28354 m
.55081 .27912 L
s
0 0 0 r
2 Mabswid
.53704 .28354 Mdot
0 g
.5 Mabswid
.55956 .29916 m
.55455 .28999 L
s
.66582 .23823 m .64873 .22133 L .65346 .21912 L .764 .495 .527 r
F
.66582 .23823 m .64873 .22133 L .65346 .21912 L F
0 0 0 r
2 Mabswid
.70607 .2456 Mdot
.70601 .24559 Mdot
.7057 .24553 Mdot
.66582 .23823 m .68816 .23729 L .68919 .24251 L .764 .495 .527 r
F
.66582 .23823 m .68816 .23729 L .68919 .24251 L F
0 g
.5 Mabswid
.53336 .27272 m
.54683 .26838 L
s
.53336 .27272 m
.53673 .28381 L
s
.53673 .28381 m
.55021 .27949 L
s
0 0 0 r
2 Mabswid
.62478 .20705 Mdot
.62459 .20696 Mdot
.62013 .21975 m .60393 .19769 L .62453 .21118 L .764 .495 .527 r
F
.62013 .21975 m .59724 .2105 L .60393 .19769 L F
.62013 .21975 m .60393 .19769 L .62453 .21118 L F
.62013 .21975 m .59724 .2105 L .60393 .19769 L F
0 g
.5 Mabswid
.60393 .19769 m
.61475 .18773 L
s
.60393 .19769 m
.61326 .18 L
s
.54683 .26838 m
.54466 .25746 L
s
.62413 .17004 m
.6384 .16356 L
s
.66582 .23823 m .64516 .2247 L .64873 .22133 L .764 .495 .527 r
F
.66582 .23823 m .64516 .2247 L .64873 .22133 L F
0 g
.67392 .18171 m
.67477 .20117 L
s
.68919 .24251 m .71142 .25667 L .68863 .24746 L .764 .495 .527 r
F
.66582 .23823 m .68919 .24251 L .68863 .24746 L F
.68919 .24251 m .69915 .22514 L .72259 .22947 L .656 .751 .92 r
F
.66582 .23823 m .69915 .22514 L .68919 .24251 L F
.68919 .24251 m .71142 .25667 L .68863 .24746 L .764 .495 .527 r
F
.66582 .23823 m .68919 .24251 L .68863 .24746 L F
.68919 .24251 m .69915 .22514 L .72259 .22947 L .656 .751 .92 r
F
.039 .916 .04 r
.70135 .22555 m
.70607 .2456 L
s
.70607 .2456 m
.73088 .231 L
s
.70129 .22554 m
.70601 .24559 L
s
.7057 .24553 m
.73054 .23094 L
s
.66582 .23823 m .69915 .22514 L .68919 .24251 L .656 .751 .92 r
F
0 g
.68919 .24251 m
.71248 .24678 L
s
.55455 .28999 m
.55021 .27949 L
s
.71142 .25667 m .73418 .26588 L .728 .27895 L .764 .495 .527 r
F
.71142 .25667 m .73418 .26588 L .728 .27895 L F
0 g
.73418 .26588 m
.73568 .25102 L
s
.73418 .26588 m
.74447 .24867 L
s
.74265 .21811 m
.74594 .23378 L
s
.64299 .229 m .62453 .21118 L .64516 .2247 L .764 .495 .527 r
F
.64299 .229 m .62013 .21975 L .62453 .21118 L F
.64299 .229 m .62453 .21118 L .64516 .2247 L F
.64299 .229 m .62013 .21975 L .62453 .21118 L F
0 0 0 r
2 Mabswid
.55081 .27912 Mdot
.71142 .25667 m .728 .27895 L .70724 .26536 L .764 .495 .527 r
F
.68863 .24746 m .71142 .25667 L .70724 .26536 L F
.71142 .25667 m .728 .27895 L .70724 .26536 L F
.68863 .24746 m .71142 .25667 L .70724 .26536 L F
0 g
.5 Mabswid
.55021 .27949 m
.54683 .26838 L
s
.66582 .23823 m .64299 .229 L .64516 .2247 L .764 .495 .527 r
F
.66582 .23823 m .64299 .229 L .64516 .2247 L F
.68863 .24746 m .70724 .26536 L .68652 .25178 L F
.66582 .23823 m .68863 .24746 L .68652 .25178 L F
.68863 .24746 m .70724 .26536 L .68652 .25178 L F
.66582 .23823 m .68863 .24746 L .68652 .25178 L F
.039 .916 .04 r
.66595 .23831 m
.72866 .31506 L
s
.66582 .23823 m .64237 .23394 L .64299 .229 L .764 .495 .527 r
F
.66582 .23823 m .64335 .23918 L .64237 .23394 L F
.66582 .23823 m .64588 .24437 L .64335 .23918 L F
.66582 .23823 m .64977 .24915 L .64588 .24437 L F
.039 .916 .04 r
.56425 .27089 m
.64605 .24459 L
s
.66582 .23823 m .65476 .25319 L .64977 .24915 L .764 .495 .527 r
F
.66582 .23823 m .66052 .2562 L .65476 .25319 L F
.66582 .23823 m .66664 .25798 L .66052 .2562 L F
.66582 .23823 m .67269 .25841 L .66664 .25798 L F
.66582 .23823 m .67827 .25746 L .67269 .25841 L F
.66582 .23823 m .68298 .2552 L .67827 .25746 L F
.039 .916 .04 r
.68063 .25633 m
.72866 .31506 L
s
.66582 .23823 m .68652 .25178 L .68298 .2552 L .764 .495 .527 r
F
.66582 .23823 m .67269 .25841 L .66664 .25798 L F
.66582 .23823 m .67827 .25746 L .67269 .25841 L F
.66582 .23823 m .68298 .2552 L .67827 .25746 L F
.66582 .23823 m .68652 .25178 L .68298 .2552 L F
.66582 .23823 m .67649 .24061 L .66664 .25798 L 0 0 .397 r
F
.039 .916 .04 r
.6529 .2868 m
.70342 .34688 L
s
.65294 .28669 m
.70342 .34688 L
s
.66582 .23823 m .67563 .2208 L .69915 .22514 L .656 .751 .92 r
F
.66582 .23823 m .67563 .2208 L .69915 .22514 L F
.66582 .23823 m .67563 .2208 L .67649 .24061 L 0 0 .397 r
F
0 g
.67647 .24018 m
.68919 .24251 L
s
.66582 .23823 m .64237 .23394 L .64299 .229 L .764 .495 .527 r
F
.64237 .23394 m .67563 .2208 L .66582 .23823 L .656 .751 .92 r
F
0 g
.66502 .21866 m
.66528 .22489 L
s
.66582 .23823 m .64335 .23918 L .64237 .23394 L .764 .495 .527 r
F
.66582 .23823 m .64588 .24437 L .64335 .23918 L F
.66582 .23823 m .64977 .24915 L .64588 .24437 L F
.66582 .23823 m .65476 .25319 L .64977 .24915 L F
.66582 .23823 m .66052 .2562 L .65476 .25319 L F
.66582 .23823 m .66664 .25798 L .66052 .2562 L F
.66582 .23823 m .67649 .24061 L .66664 .25798 L 0 0 .397 r
F
.66582 .23823 m .67563 .2208 L .67649 .24061 L F
.039 .916 .04 r
.67612 .2321 m
.69048 .22354 L
s
.64237 .23394 m .67563 .2208 L .66582 .23823 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.66582 .23823 Mdot
.66582 .23823 Mdot
.68936 .19962 Mdot
.68937 .19986 Mdot
.64237 .23394 m .62013 .21975 L .64299 .229 L .764 .495 .527 r
F
.64237 .23394 m .62013 .21975 L .64299 .229 L F
.68652 .25178 m .70021 .27223 L .68298 .2552 L F
.68652 .25178 m .70724 .26536 L .70021 .27223 L F
.68652 .25178 m .70021 .27223 L .68298 .2552 L F
.68652 .25178 m .70724 .26536 L .70021 .27223 L F
.039 .916 .04 r
.5 Mabswid
.57833 .31037 m
.69993 .27196 L
s
.61883 .22962 m .59724 .2105 L .62013 .21975 L .764 .495 .527 r
F
.64237 .23394 m .61883 .22962 L .62013 .21975 L F
.61883 .22962 m .59724 .2105 L .62013 .21975 L F
.64237 .23394 m .61883 .22962 L .62013 .21975 L F
0 g
.61326 .18 m
.62413 .17004 L
s
.70724 .26536 m .71751 .28934 L .70021 .27223 L .764 .495 .527 r
F
.039 .916 .04 r
.71111 .27439 m
.75669 .33061 L
s
.71113 .27444 m
.75669 .33061 L
s
.70724 .26536 m .728 .27895 L .71751 .28934 L .764 .495 .527 r
F
.70724 .26536 m .71751 .28934 L .70021 .27223 L F
.70724 .26536 m .728 .27895 L .71751 .28934 L F
0 g
.728 .27895 m
.73418 .26588 L
s
.61883 .22962 m .59521 .2253 L .59724 .2105 L .764 .495 .527 r
F
.61883 .22962 m .59521 .2253 L .59724 .2105 L F
0 g
.59724 .2105 m
.60393 .19769 L
s
.64335 .23918 m .61883 .22962 L .64237 .23394 L .764 .495 .527 r
F
.64237 .23394 m .65202 .21644 L .67563 .2208 L .656 .751 .92 r
F
.61883 .22962 m .65202 .21644 L .64237 .23394 L F
.64335 .23918 m .61883 .22962 L .64237 .23394 L .764 .495 .527 r
F
.64237 .23394 m .65202 .21644 L .67563 .2208 L .656 .751 .92 r
F
.039 .916 .04 r
.66082 .21806 m
.66587 .23815 L
s
.66074 .21805 m
.66582 .23823 L
s
.61883 .22962 m .65202 .21644 L .64237 .23394 L .656 .751 .92 r
F
0 g
.64237 .23394 m
.66582 .23823 L
s
.039 .916 .04 r
.62716 .23287 m
.65204 .26274 L
s
.62753 .23301 m
.65211 .26262 L
s
.55065 .25529 m
.62376 .23155 L
s
0 g
.74447 .24867 m
.74594 .23378 L
s
.72259 .22947 m
.74594 .23378 L
s
.68298 .2552 m .69079 .27681 L .67827 .25746 L .764 .495 .527 r
F
.68298 .2552 m .70021 .27223 L .69079 .27681 L F
.68298 .2552 m .69079 .27681 L .67827 .25746 L F
.68298 .2552 m .70021 .27223 L .69079 .27681 L F
0 g
.728 .27895 m
.73828 .26178 L
s
0 0 0 r
2 Mabswid
.70724 .26961 Mdot
.70725 .26965 Mdot
0 g
.5 Mabswid
.67477 .20117 m
.67563 .2208 L
s
.039 .916 .04 r
.65978 .19408 m
.6072 .12874 L
s
0 0 0 r
2 Mabswid
.65978 .19408 Mdot
.039 .916 .04 r
.5 Mabswid
.65986 .19418 m
.6073 .12879 L
s
0 0 0 r
2 Mabswid
.65986 .19418 Mdot
.64335 .23918 m .62075 .24014 L .61883 .22962 L .764 .495 .527 r
F
.64588 .24437 m .62075 .24014 L .64335 .23918 L F
.64335 .23918 m .62075 .24014 L .61883 .22962 L F
.64588 .24437 m .62075 .24014 L .64335 .23918 L F
0 0 0 r
.73088 .231 Mdot
.73054 .23094 Mdot
.62577 .23089 Mdot
.62547 .23084 Mdot
.67827 .25746 m .67961 .27876 L .67269 .25841 L .764 .495 .527 r
F
.039 .916 .04 r
.5 Mabswid
.67954 .27753 m
.72995 .33867 L
s
.67954 .27763 m
.72995 .33867 L
s
.67827 .25746 m .69079 .27681 L .67961 .27876 L .764 .495 .527 r
F
.67827 .25746 m .67961 .27876 L .67269 .25841 L F
.67827 .25746 m .69079 .27681 L .67961 .27876 L F
0 0 0 r
2 Mabswid
.62527 .2308 Mdot
.62075 .24014 m .59521 .2253 L .61883 .22962 L .764 .495 .527 r
F
.61883 .22962 m .62833 .21207 L .65202 .21644 L .656 .751 .92 r
F
.59521 .2253 m .62833 .21207 L .61883 .22962 L F
.62075 .24014 m .59521 .2253 L .61883 .22962 L .764 .495 .527 r
F
.61883 .22962 m .62833 .21207 L .65202 .21644 L .656 .751 .92 r
F
.59521 .2253 m .62833 .21207 L .61883 .22962 L F
0 g
.5 Mabswid
.61883 .22962 m
.64237 .23394 L
s
.69915 .22514 m
.72259 .22947 L
s
.64588 .24437 m .62577 .25056 L .62075 .24014 L .764 .495 .527 r
F
.64977 .24915 m .62577 .25056 L .64588 .24437 L F
.64588 .24437 m .62577 .25056 L .62075 .24014 L F
.64977 .24915 m .62577 .25056 L .64588 .24437 L F
.70021 .27223 m .70339 .29628 L .69079 .27681 L F
.70021 .27223 m .71751 .28934 L .70339 .29628 L F
.70021 .27223 m .70339 .29628 L .69079 .27681 L F
.70021 .27223 m .71751 .28934 L .70339 .29628 L F
0 g
.71751 .28934 m
.728 .27895 L
s
.67269 .25841 m .66746 .27792 L .66664 .25798 L .764 .495 .527 r
F
.039 .916 .04 r
.6705 .26658 m
.67896 .27684 L
s
.67048 .26665 m
.67901 .27699 L
s
.67269 .25841 m .67961 .27876 L .66746 .27792 L .764 .495 .527 r
F
.67269 .25841 m .66746 .27792 L .66664 .25798 L F
.67269 .25841 m .67961 .27876 L .66746 .27792 L F
.64977 .24915 m .63357 .26017 L .62577 .25056 L F
.65476 .25319 m .63357 .26017 L .64977 .24915 L F
.64977 .24915 m .63357 .26017 L .62577 .25056 L F
.65476 .25319 m .63357 .26017 L .64977 .24915 L F
.66664 .25798 m .65516 .27435 L .66052 .2562 L F
.039 .916 .04 r
.56466 .29453 m
.65795 .26491 L
s
.66664 .25798 m .66746 .27792 L .65516 .27435 L .764 .495 .527 r
F
.66664 .25798 m .67736 .26061 L .66746 .27792 L 0 0 .397 r
F
.66664 .25798 m .67649 .24061 L .67736 .26061 L F
.66664 .25798 m .65516 .27435 L .66052 .2562 L .764 .495 .527 r
F
.66664 .25798 m .66746 .27792 L .65516 .27435 L F
.66664 .25798 m .67736 .26061 L .66746 .27792 L 0 0 .397 r
F
.66664 .25798 m .67649 .24061 L .67736 .26061 L F
0 g
.66582 .23823 m
.66664 .25798 L
s
.65476 .25319 m .6436 .26829 L .63357 .26017 L .764 .495 .527 r
F
.66052 .2562 m .6436 .26829 L .65476 .25319 L F
.65476 .25319 m .6436 .26829 L .63357 .26017 L F
.66052 .2562 m .6436 .26829 L .65476 .25319 L F
.66052 .2562 m .65516 .27435 L .6436 .26829 L F
.66052 .2562 m .65516 .27435 L .6436 .26829 L F
0 g
.60657 .19283 m
.61326 .18 L
s
.039 .916 .04 r
.63604 .1436 m
.6847 .20466 L
s
.6847 .20466 m
.70135 .22555 L
s
0 0 0 r
2 Mabswid
.70135 .22555 Mdot
.039 .916 .04 r
.5 Mabswid
.63604 .1436 m
.68469 .20469 L
s
.68469 .20469 m
.70129 .22554 L
s
0 0 0 r
2 Mabswid
.70129 .22554 Mdot
.62075 .24014 m .59802 .2411 L .59521 .2253 L .764 .495 .527 r
F
.59521 .2253 m .60455 .20768 L .62833 .21207 L .656 .751 .92 r
F
.62075 .24014 m .59802 .2411 L .59521 .2253 L .764 .495 .527 r
F
.59521 .2253 m .60455 .20768 L .62833 .21207 L .656 .751 .92 r
F
0 g
.5 Mabswid
.59521 .2253 m
.61883 .22962 L
s
.039 .916 .04 r
.62002 .21053 m
.62547 .23084 L
s
.61981 .21049 m
.62527 .2308 L
s
0 g
.59521 .2253 m
.59724 .2105 L
s
.59521 .2253 m
.60455 .20768 L
s
.59724 .2105 m
.60657 .19283 L
s
.039 .916 .04 r
.62577 .23089 m
.65024 .21611 L
s
.62527 .2308 m
.64977 .21602 L
s
0 g
.67563 .2208 m
.69915 .22514 L
s
.88333 .1637 m .88888 .15967 L .89462 .17828 L .975 .667 .322 r
F
.87871 .15175 m .88888 .15967 L .88333 .1637 L F
.87871 .15175 m .882 .14186 L .88888 .15967 L F
0 g
.88888 .15967 m
.91668 .1507 L
s
.039 .916 .04 r
.67716 .256 m
.69161 .24749 L
s
0 0 0 r
2 Mabswid
.66681 .2621 Mdot
.039 .916 .04 r
.5 Mabswid
.66178 .24222 m
.66686 .26221 L
s
0 g
.74447 .24867 m
.73828 .26178 L
s
.039 .916 .04 r
.66171 .24229 m
.66682 .26237 L
s
0 0 0 r
2 Mabswid
.66682 .26237 Mdot
.039 .916 .04 r
.5 Mabswid
.67717 .25626 m
.69162 .24773 L
s
.88718 .1762 m .89462 .17828 L .89887 .1965 L .975 .667 .322 r
F
.88333 .1637 m .89462 .17828 L .88718 .1762 L F
0 g
.88888 .15967 m
.89462 .17828 L
s
.62577 .25056 m .59802 .2411 L .62075 .24014 L .764 .495 .527 r
F
.62577 .25056 m .59802 .2411 L .62075 .24014 L F
0 g
.71751 .28934 m
.72775 .27217 L
s
0 0 0 r
2 Mabswid
.69048 .22354 Mdot
.69048 .22354 Mdot
.69079 .27681 m .68659 .29926 L .67961 .27876 L .764 .495 .527 r
F
.69079 .27681 m .70339 .29628 L .68659 .29926 L F
.69079 .27681 m .68659 .29926 L .67961 .27876 L F
.69079 .27681 m .70339 .29628 L .68659 .29926 L F
0 g
.5 Mabswid
.70339 .29628 m
.71751 .28934 L
s
.87362 .14113 m .882 .14186 L .87871 .15175 L .975 .667 .322 r
F
.87362 .14113 m .87443 .12599 L .882 .14186 L F
0 g
.882 .14186 m
.88888 .15967 L
s
.882 .14186 m
.90981 .13282 L
s
.67563 .2208 m
.67649 .24061 L
s
.65202 .21644 m
.67563 .2208 L
s
.89002 .18843 m .89887 .1965 L .90133 .21317 L .975 .667 .322 r
F
.88718 .1762 m .89887 .1965 L .89002 .18843 L F
0 g
.89462 .17828 m
.89887 .1965 L
s
.89462 .17828 m
.92245 .16938 L
s
.62577 .25056 m .60552 .2568 L .59802 .2411 L .764 .495 .527 r
F
.63357 .26017 m .60552 .2568 L .62577 .25056 L F
.039 .916 .04 r
.55081 .27912 m
.61631 .2581 L
s
.63038 .25979 m
.65294 .28669 L
s
.63016 .25976 m
.6529 .2868 L
s
.62577 .25056 m .60552 .2568 L .59802 .2411 L .764 .495 .527 r
F
0 g
.59521 .2253 m
.59802 .2411 L
s
.63357 .26017 m .60552 .2568 L .62577 .25056 L .764 .495 .527 r
F
.67961 .27876 m .66828 .29804 L .66746 .27792 L F
.67961 .27876 m .68659 .29926 L .66828 .29804 L F
.67961 .27876 m .66828 .29804 L .66746 .27792 L F
.67961 .27876 m .68659 .29926 L .66828 .29804 L F
.039 .916 .04 r
.60798 .15302 m
.66082 .21806 L
s
0 0 0 r
2 Mabswid
.66082 .21806 Mdot
.039 .916 .04 r
.5 Mabswid
.60789 .15305 m
.66074 .21805 L
s
0 0 0 r
2 Mabswid
.66074 .21805 Mdot
.6263 .25492 Mdot
.62612 .25495 Mdot
0 g
.5 Mabswid
.59802 .2411 m
.60741 .22353 L
s
.60455 .20768 m
.60657 .19283 L
s
.62833 .21207 m
.65202 .21644 L
s
.91668 .1507 m
.92245 .16938 L
s
.90981 .13282 m
.91668 .1507 L
s
.63357 .26017 m .61722 .27129 L .60552 .2568 L .764 .495 .527 r
F
.6436 .26829 m .61722 .27129 L .63357 .26017 L F
.63357 .26017 m .61722 .27129 L .60552 .2568 L F
0 g
.59802 .2411 m
.60552 .2568 L
s
.6436 .26829 m .61722 .27129 L .63357 .26017 L .764 .495 .527 r
F
0 0 0 r
2 Mabswid
.65024 .21611 Mdot
.64977 .21602 Mdot
.66746 .27792 m .64975 .29268 L .65516 .27435 L .764 .495 .527 r
F
.66746 .27792 m .66828 .29804 L .64975 .29268 L F
.66746 .27792 m .67824 .2808 L .66828 .29804 L 0 0 .397 r
F
.66746 .27792 m .67736 .26061 L .67824 .2808 L F
.66746 .27792 m .64975 .29268 L .65516 .27435 L .764 .495 .527 r
F
.66746 .27792 m .66828 .29804 L .64975 .29268 L F
.66746 .27792 m .67824 .2808 L .66828 .29804 L 0 0 .397 r
F
.66746 .27792 m .67736 .26061 L .67824 .2808 L F
0 g
.5 Mabswid
.66664 .25798 m
.66746 .27792 L
s
.66746 .27792 m
.66828 .29804 L
s
.92245 .16938 m
.92675 .18766 L
s
.68659 .29926 m
.70339 .29628 L
s
.70339 .29628 m
.71356 .27911 L
s
.8684 .13254 m .87443 .12599 L .87362 .14113 L .975 .667 .322 r
F
.8684 .13254 m .86664 .11311 L .87443 .12599 L F
0 g
.87443 .12599 m
.882 .14186 L
s
.87443 .12599 m
.90228 .11687 L
s
.73828 .26178 m
.72775 .27217 L
s
.6436 .26829 m .63232 .28354 L .61722 .27129 L .764 .495 .527 r
F
.65516 .27435 m .63232 .28354 L .6436 .26829 L F
.6436 .26829 m .63232 .28354 L .61722 .27129 L F
.65516 .27435 m .63232 .28354 L .6436 .26829 L F
.65516 .27435 m .64975 .29268 L .63232 .28354 L F
.65516 .27435 m .64975 .29268 L .63232 .28354 L F
0 g
.90228 .11687 m
.90981 .13282 L
s
.89002 .18843 m .90133 .21317 L .89165 .19958 L .975 .667 .322 r
F
0 g
.89887 .1965 m
.92675 .18766 L
s
.89165 .19958 m .90133 .21317 L .90183 .22718 L .975 .667 .322 r
F
.89165 .19958 m .92931 .20435 L .90133 .21317 L .656 .751 .92 r
F
0 g
.89887 .1965 m
.89947 .20057 L
s
.60455 .20768 m
.62833 .21207 L
s
.039 .916 .04 r
.58012 .16236 m
.62002 .21053 L
s
0 0 0 r
2 Mabswid
.62002 .21053 Mdot
.039 .916 .04 r
.5 Mabswid
.57995 .16242 m
.61981 .21049 L
s
0 0 0 r
2 Mabswid
.61981 .21049 Mdot
0 g
.5 Mabswid
.60552 .2568 m
.61499 .2393 L
s
.60552 .2568 m
.61722 .27129 L
s
0 0 0 r
2 Mabswid
.69161 .24749 Mdot
.69162 .24773 Mdot
0 g
.5 Mabswid
.67649 .24061 m
.67736 .26061 L
s
.66828 .29804 m
.68659 .29926 L
s
.68659 .29926 m
.69667 .28207 L
s
.60455 .20768 m
.60741 .22353 L
s
.87769 .1678 m .88333 .1637 L .88718 .1762 L .975 .667 .322 r
F
.87537 .16178 m .88333 .1637 L .87769 .1678 L F
.87537 .16178 m .87871 .15175 L .88333 .1637 L F
.87964 .17409 m .88718 .1762 L .89002 .18843 L F
.87769 .1678 m .88718 .1762 L .87964 .17409 L F
.86664 .11311 m .89647 .12337 L .8684 .13254 L .543 .322 .53 r
F
.86664 .11311 m .89457 .10391 L .89647 .12337 L F
0 g
.89457 .10391 m
.90228 .11687 L
s
.86339 .12658 m .86664 .11311 L .8684 .13254 L .975 .667 .322 r
F
.86339 .12658 m .85914 .10409 L .86664 .11311 L F
0 g
.86664 .11311 m
.89457 .10391 L
s
.72775 .27217 m
.71356 .27911 L
s
.8728 .15645 m .87871 .15175 L .87537 .16178 L .975 .667 .322 r
F
.8728 .15645 m .87362 .14113 L .87871 .15175 L F
0 g
.61722 .27129 m
.6268 .25386 L
s
.61722 .27129 m
.63232 .28354 L
s
.64975 .29268 m
.66828 .29804 L
s
.66828 .29804 m
.67824 .2808 L
s
.88106 .18024 m .89002 .18843 L .89165 .19958 L .975 .667 .322 r
F
.87964 .17409 m .89002 .18843 L .88106 .18024 L F
.89165 .19958 m .91976 .19067 L .92931 .20435 L .656 .751 .92 r
F
0 g
.92931 .20435 m
.92993 .21838 L
s
.92675 .18766 m
.92931 .20435 L
s
.90133 .21317 m
.92931 .20435 L
s
.039 .916 .04 r
.66178 .24222 m
.60867 .17753 L
s
0 0 0 r
2 Mabswid
.66178 .24222 Mdot
.039 .916 .04 r
.5 Mabswid
.66171 .24229 m
.60858 .17764 L
s
0 0 0 r
2 Mabswid
.66171 .24229 Mdot
.89196 .20893 m .90183 .22718 L .90032 .23759 L .975 .667 .322 r
F
.89165 .19958 m .90183 .22718 L .89196 .20893 L F
0 g
.5 Mabswid
.90133 .21317 m
.90183 .22718 L
s
.90183 .22718 m
.92993 .21838 L
s
.63232 .28354 m
.64202 .26619 L
s
.63232 .28354 m
.64975 .29268 L
s
.64975 .29268 m
.65958 .27538 L
s
.87018 .15216 m .87362 .14113 L .8728 .15645 L .975 .667 .322 r
F
.87018 .15216 m .8684 .13254 L .87362 .14113 L F
.88106 .18024 m .89165 .19958 L .88187 .18585 L F
.88187 .18585 m .89165 .19958 L .89196 .20893 L F
.88187 .18585 m .91976 .19067 L .89165 .19958 L .656 .751 .92 r
F
0 g
.89165 .19958 m
.90133 .21317 L
s
.61499 .2393 m
.60741 .22353 L
s
.67736 .26061 m
.67824 .2808 L
s
.71356 .27911 m
.69667 .28207 L
s
.56367 .11649 m
.54994 .13051 L
s
.57976 .10512 m
.56367 .11649 L
s
.88718 .09482 m
.89457 .10391 L
s
.54994 .13051 m
.53946 .14628 L
s
.59716 .09714 m
.57976 .10512 L
s
.8684 .13254 m .89839 .14301 L .87018 .15216 L .543 .322 .53 r
F
.8684 .13254 m .89647 .12337 L .89839 .14301 L F
0 g
.89457 .10391 m
.89647 .12337 L
s
.86767 .14919 m .8684 .13254 L .87018 .15216 L .975 .667 .322 r
F
.86767 .14919 m .86339 .12658 L .8684 .13254 L F
0 g
.86664 .11311 m
.8684 .13254 L
s
.85894 .12365 m .85914 .10409 L .86339 .12658 L .975 .667 .322 r
F
.85894 .12365 m .85244 .09959 L .85914 .10409 L F
0 g
.85914 .10409 m
.86664 .11311 L
s
.85914 .10409 m
.88718 .09482 L
s
.92993 .21838 m
.92856 .22878 L
s
.53946 .14628 m
.53292 .16278 L
s
.89196 .20893 m .90032 .23759 L .89092 .21582 L .975 .667 .322 r
F
.88201 .19052 m .89196 .20893 L .89092 .21582 L F
.88187 .18585 m .89196 .20893 L .88201 .19052 L F
0 g
.6268 .25386 m
.61499 .2393 L
s
.67824 .2808 m
.69667 .28207 L
s
.61475 .09311 m
.59716 .09714 L
s
.59716 .09714 m
.59716 .09714 L
s
.59766 .11662 m
.59716 .09714 L
s
.88187 .18585 m .9101 .17683 L .91976 .19067 L .656 .751 .92 r
F
0 g
.91976 .19067 m
.92931 .20435 L
s
.89092 .21582 m .90032 .23759 L .89686 .24364 L .975 .667 .322 r
F
0 g
.90032 .23759 m
.92856 .22878 L
s
.90032 .23759 m
.90183 .22718 L
s
.87198 .17195 m .87769 .1678 L .87964 .17409 L .975 .667 .322 r
F
.87198 .17195 m .87537 .16178 L .87769 .1678 L F
.87198 .17195 m .87964 .17409 L .88106 .18024 L F
.87198 .17195 m .8728 .15645 L .87537 .16178 L F
.87198 .17195 m .88106 .18024 L .88187 .18585 L F
0 g
.64202 .26619 m
.6268 .25386 L
s
.86545 .14777 m .86339 .12658 L .86767 .14919 L .975 .667 .322 r
F
.86545 .14777 m .85894 .12365 L .86339 .12658 L F
.039 .916 .04 r
.68937 .19986 m
.86412 .14284 L
s
.68936 .19962 m
.86412 .14284 L
s
0 g
.53292 .16278 m
.53078 .17892 L
s
.65958 .27538 m
.67824 .2808 L
s
.87198 .17195 m .87018 .15216 L .8728 .15645 L .975 .667 .322 r
F
.87198 .17195 m .88187 .18585 L .88201 .19052 L F
.87198 .17195 m .9101 .17683 L .88187 .18585 L .656 .751 .92 r
F
0 g
.88187 .18585 m
.89165 .19958 L
s
.039 .916 .04 r
.73054 .23094 m
.87836 .18377 L
s
.73088 .231 m
.87836 .18377 L
s
0 g
.88061 .09024 m
.88718 .09482 L
s
.65958 .27538 m
.64202 .26619 L
s
.89092 .21582 m .89686 .24364 L .88858 .21978 L .975 .667 .322 r
F
.88147 .19394 m .89092 .21582 L .88858 .21978 L F
.88201 .19052 m .89092 .21582 L .88147 .19394 L F
0 g
.63136 .09331 m
.61475 .09311 L
s
.87198 .17195 m .86767 .14919 L .87018 .15216 L .975 .667 .322 r
F
.87018 .15216 m .90033 .16284 L .87198 .17195 L .543 .322 .53 r
F
.87018 .15216 m .89839 .14301 L .90033 .16284 L F
0 g
.8684 .13254 m
.87018 .15216 L
s
.89647 .12337 m
.89839 .14301 L
s
.87198 .17195 m .88201 .19052 L .88147 .19394 L .975 .667 .322 r
F
0 g
.92856 .22878 m
.92525 .23481 L
s
.85533 .124 m .85244 .09959 L .85894 .12365 L .975 .667 .322 r
F
.85533 .124 m .84699 .09998 L .85244 .09959 L F
0 g
.85244 .09959 m
.85914 .10409 L
s
.85244 .09959 m
.88061 .09024 L
s
.87198 .17195 m .86545 .14777 L .86767 .14919 L .975 .667 .322 r
F
0 g
.59766 .11662 m
.59817 .13629 L
s
.53078 .17892 m
.53323 .19364 L
s
.53078 .17892 m
.55328 .17137 L
s
.53078 .17892 m
.53078 .17892 L
s
.88147 .19394 m .88858 .21978 L .88028 .19588 L .975 .667 .322 r
F
.87198 .17195 m .88147 .19394 L .88028 .19588 L F
.86366 .14799 m .85894 .12365 L .86545 .14777 L F
.86366 .14799 m .85533 .124 L .85894 .12365 L F
.88858 .21978 m .89686 .24364 L .89166 .24486 L F
0 g
.89686 .24364 m
.92525 .23481 L
s
.89686 .24364 m
.90032 .23759 L
s
.87198 .17195 m .90033 .16284 L .9101 .17683 L .656 .751 .92 r
F
0 g
.9101 .17683 m
.91976 .19067 L
s
.88858 .21978 m .89166 .24486 L .88509 .2205 L .975 .667 .322 r
F
.88028 .19588 m .88858 .21978 L .88509 .2205 L F
0 g
.64589 .09777 m
.63136 .09331 L
s
.87198 .17195 m .86366 .14799 L .86545 .14777 L .975 .667 .322 r
F
.88028 .19588 m .88509 .2205 L .87852 .1962 L F
.87198 .17195 m .88028 .19588 L .87852 .1962 L F
0 g
.87531 .09058 m
.88061 .09024 L
s
.87198 .17195 m .86243 .14985 L .86366 .14799 L .975 .667 .322 r
F
.87198 .17195 m .86186 .15323 L .86243 .14985 L F
.87198 .17195 m .86197 .1579 L .86186 .15323 L F
.87198 .17195 m .86277 .16355 L .86197 .1579 L F
.87198 .17195 m .86421 .16978 L .86277 .16355 L F
.87198 .17195 m .86618 .17617 L .86421 .16978 L F
.87198 .17195 m .86854 .18227 L .86618 .17617 L F
.87198 .17195 m .87114 .18765 L .86854 .18227 L F
.87198 .17195 m .87379 .19194 L .87114 .18765 L F
.87198 .17195 m .87631 .19485 L .87379 .19194 L F
.87198 .17195 m .87852 .1962 L .87631 .19485 L F
.87198 .17195 m .90228 .18286 L .87379 .19194 L .543 .322 .53 r
F
.87198 .17195 m .90033 .16284 L .90228 .18286 L F
.86197 .1579 m .90033 .16284 L .87198 .17195 L .656 .751 .92 r
F
0 g
.87018 .15216 m
.87081 .15904 L
s
.039 .916 .04 r
.69048 .22354 m
.86373 .16769 L
s
0 g
.55328 .17137 m
.57591 .16378 L
s
.86243 .14985 m .85533 .124 L .86366 .14799 L .975 .667 .322 r
F
0 g
.53323 .19364 m
.54016 .20592 L
s
.87852 .1962 m .88067 .2179 L .87631 .19485 L .975 .667 .322 r
F
.87852 .1962 m .88509 .2205 L .88067 .2179 L F
.85284 .12764 m .84699 .09998 L .85533 .124 L F
.86243 .14985 m .85284 .12764 L .85533 .124 L F
0 g
.59817 .13629 m
.59869 .15614 L
s
.92525 .23481 m
.9202 .23599 L
s
0 0 0 r
2 Mabswid
.6072 .12874 Mdot
.6073 .12879 Mdot
.85284 .12764 m .8432 .10531 L .84699 .09998 L .975 .667 .322 r
F
0 g
.5 Mabswid
.84699 .09998 m
.87531 .09058 L
s
.84699 .09998 m
.85244 .09959 L
s
0 0 0 r
2 Mabswid
.86797 .16632 Mdot
.88509 .2205 m .88505 .24109 L .88067 .2179 L .975 .667 .322 r
F
.88509 .2205 m .89166 .24486 L .88505 .24109 L F
0 g
.5 Mabswid
.89166 .24486 m
.89686 .24364 L
s
.86186 .15323 m .85284 .12764 L .86243 .14985 L .975 .667 .322 r
F
0 g
.65732 .10626 m
.64589 .09777 L
s
.87631 .19485 m .87562 .21212 L .87379 .19194 L .975 .667 .322 r
F
.87631 .19485 m .88067 .2179 L .87562 .21212 L F
0 g
.57591 .16378 m
.59869 .15614 L
s
.86197 .1579 m .89045 .14868 L .90033 .16284 L .656 .751 .92 r
F
0 g
.90033 .16284 m
.9101 .17683 L
s
.89839 .14301 m
.90033 .16284 L
s
.89166 .24486 m
.9202 .23599 L
s
0 0 0 r
2 Mabswid
.57995 .16242 Mdot
.58012 .16236 Mdot
.86197 .1579 m .85165 .13435 L .86186 .15323 L .975 .667 .322 r
F
.86186 .15323 m .85165 .13435 L .85284 .12764 L F
.87379 .19194 m .90426 .20306 L .87562 .21212 L .543 .322 .53 r
F
.87379 .19194 m .90228 .18286 L .90426 .20306 L F
0 g
.5 Mabswid
.90033 .16284 m
.90228 .18286 L
s
.87379 .19194 m .87029 .20353 L .87114 .18765 L .975 .667 .322 r
F
.87379 .19194 m .87562 .21212 L .87029 .20353 L F
0 g
.87198 .17195 m
.87379 .19194 L
s
.85165 .13435 m .8432 .10531 L .85284 .12764 L .975 .667 .322 r
F
0 g
.54016 .20592 m
.55115 .21491 L
s
.86197 .1579 m .85185 .14369 L .85165 .13435 L .975 .667 .322 r
F
.86277 .16355 m .85185 .14369 L .86197 .1579 L F
.85185 .14369 m .89045 .14868 L .86197 .1579 L .656 .751 .92 r
F
0 g
.86197 .1579 m
.87198 .17195 L
s
.87167 .09587 m
.87531 .09058 L
s
.87114 .18765 m .86506 .19272 L .86854 .18227 L .975 .667 .322 r
F
.87114 .18765 m .87029 .20353 L .86506 .19272 L F
.88067 .2179 m .87747 .23249 L .87562 .21212 L F
.88067 .2179 m .88505 .24109 L .87747 .23249 L F
0 g
.88505 .24109 m
.89166 .24486 L
s
.59921 .17617 m
.59869 .15614 L
s
.59869 .15614 m
.6216 .14845 L
s
.86277 .16355 m .85344 .15503 L .85185 .14369 L .975 .667 .322 r
F
.039 .916 .04 r
.64977 .21602 m
.85276 .15014 L
s
.65024 .21611 m
.85276 .15014 L
s
.86421 .16978 m .85344 .15503 L .86277 .16355 L .975 .667 .322 r
F
.86854 .18227 m .86029 .18045 L .86618 .17617 L F
.86854 .18227 m .86506 .19272 L .86029 .18045 L F
.039 .916 .04 r
.69162 .24773 m
.8649 .19231 L
s
.69161 .24749 m
.8649 .1923 L
s
0 g
.66483 .11824 m
.65732 .10626 L
s
.86421 .16978 m .85632 .16758 L .85344 .15503 L .975 .667 .322 r
F
.86618 .17617 m .85632 .16758 L .86421 .16978 L F
.86618 .17617 m .86029 .18045 L .85632 .16758 L F
0 g
.9202 .23599 m
.91372 .23214 L
s
0 0 0 r
2 Mabswid
.60789 .15305 Mdot
.60798 .15302 Mdot
.85165 .13435 m .84136 .1153 L .8432 .10531 L .975 .667 .322 r
F
0 g
.5 Mabswid
.8432 .10531 m
.87167 .09587 L
s
.8432 .10531 m
.84699 .09998 L
s
0 0 0 r
2 Mabswid
.87015 .19063 Mdot
.85185 .14369 m .84136 .1153 L .85165 .13435 L .975 .667 .322 r
F
0 0 0 r
.85575 .14917 Mdot
.85185 .14369 m .88045 .13437 L .89045 .14868 L .656 .751 .92 r
F
0 g
.5 Mabswid
.89045 .14868 m
.90033 .16284 L
s
.6216 .14845 m
.64466 .14071 L
s
.87562 .21212 m .86944 .21961 L .87029 .20353 L .975 .667 .322 r
F
.87562 .21212 m .87747 .23249 L .86944 .21961 L F
.87562 .21212 m .90625 .22347 L .87747 .23249 L .543 .322 .53 r
F
0 g
.87747 .23249 m
.88505 .24109 L
s
.88505 .24109 m
.91372 .23214 L
s
.87562 .21212 m .90426 .20306 L .90625 .22347 L .543 .322 .53 r
F
0 g
.87379 .19194 m
.87562 .21212 L
s
.87562 .21212 m
.87747 .23249 L
s
.90228 .18286 m
.90426 .20306 L
s
.55115 .21491 m
.5655 .21994 L
s
.59921 .17617 m
.59973 .19641 L
s
.86996 .10585 m
.87167 .09587 L
s
.85185 .14369 m .84161 .12931 L .84136 .1153 L .975 .667 .322 r
F
0 g
.84136 .1153 m
.8432 .10531 L
s
.85344 .15503 m .84161 .12931 L .85185 .14369 L .975 .667 .322 r
F
.84161 .12931 m .88045 .13437 L .85185 .14369 L .656 .751 .92 r
F
0 g
.85185 .14369 m
.86197 .1579 L
s
0 0 0 r
2 Mabswid
.63604 .1436 Mdot
.63604 .1436 Mdot
0 g
.5 Mabswid
.66786 .13292 m
.66483 .11824 L
s
.87029 .20353 m .86153 .20333 L .86506 .19272 L .975 .667 .322 r
F
.87029 .20353 m .86944 .21961 L .86153 .20333 L F
0 g
.64466 .14071 m
.66786 .13292 L
s
.84136 .1153 m
.86996 .10585 L
s
.90625 .22347 m
.91372 .23214 L
s
.90426 .20306 m
.90625 .22347 L
s
0 0 0 r
2 Mabswid
.60867 .17753 Mdot
.85344 .15503 m .84399 .1464 L .84161 .12931 L .975 .667 .322 r
F
.85632 .16758 m .84399 .1464 L .85344 .15503 L F
0 0 0 r
.60858 .17764 Mdot
.86506 .19272 m .85431 .1848 L .86029 .18045 L .975 .667 .322 r
F
.86506 .19272 m .86153 .20333 L .85431 .1848 L F
0 g
.5 Mabswid
.5655 .21994 m
.58226 .22061 L
s
.86944 .21961 m
.87747 .23249 L
s
.87747 .23249 m
.90625 .22347 L
s
.85632 .16758 m .84832 .16535 L .84399 .1464 L .975 .667 .322 r
F
.86029 .18045 m .84832 .16535 L .85632 .16758 L F
.86029 .18045 m .85431 .1848 L .84832 .16535 L F
.84161 .12931 m .87034 .11988 L .88045 .13437 L .656 .751 .92 r
F
0 g
.87034 .11988 m
.88045 .13437 L
s
.84161 .12931 m
.85185 .14369 L
s
.84136 .1153 m
.84161 .12931 L
s
.88045 .13437 m
.89045 .14868 L
s
.66614 .14932 m
.66786 .13292 L
s
.66786 .13292 m
.66786 .13292 L
s
.60026 .21683 m
.59973 .19641 L
s
.86996 .10585 m
.87034 .11988 L
s
.84161 .12931 m
.87034 .11988 L
s
.84161 .12931 m
.84399 .1464 L
s
.58226 .22061 m
.60026 .21683 L
s
.8983 .21051 m
.90625 .22347 L
s
.86153 .20333 m
.86944 .21961 L
s
.86944 .21961 m
.8983 .21051 L
s
.65974 .16629 m
.66614 .14932 L
s
.84399 .1464 m
.87282 .137 L
s
.84399 .1464 m
.84832 .16535 L
s
.60026 .21683 m
.61824 .20883 L
s
.60026 .21683 m
.60026 .21683 L
s
.87034 .11988 m
.87282 .137 L
s
.85431 .1848 m
.86153 .20333 L
s
.86153 .20333 m
.89044 .19414 L
s
.64908 .18262 m
.65974 .16629 L
s
.8983 .21051 m
.89044 .19414 L
s
.84832 .16535 m
.87722 .156 L
s
.84832 .16535 m
.85431 .1848 L
s
.85431 .1848 m
.88324 .17552 L
s
.61824 .20883 m
.63491 .19715 L
s
.63491 .19715 m
.64908 .18262 L
s
.87722 .156 m
.87282 .137 L
s
.89044 .19414 m
.88324 .17552 L
s
.88324 .17552 m
.87722 .156 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[31]:=",
  ImageSize->{543.125, 306.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008O0001<R000`400?l00000o`00003ooooooooo
ooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo
003ooooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooo
oooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool0
0?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooo
oolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00
ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00oooooooooooo
ob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003o
oooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo
8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oo
oooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQ
ooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00oooo
ooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7o
oooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooo
oooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003oooooomWooooo1_l0
0011ooooo`00oooooooFooooo`Ko00000oooool00ol0003oooooooooo`0nooooo`00oooooom<oooo
o`ko0000NOooool6o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool0?Oooool00?oo
ooooAoooool5o`0000kooooo1?l0001booooo`Ko000000Coooooo`000?l0003o00001_ooool2o`00
03kooooo003ooooood?ooooo1?l0000Gooooo`?o0000K?ooool6o`000004ooooool0003o0000o`00
00;ooooo00Co0000oooooooooooooooo0ol00002ooooo`03o`000?oooooooooo03_ooooo003ooooo
od7ooooo0_l000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo06Oooooo1Ol000001?oo
oooo0000o`000?l00005ooooo`Co00001_ooool00ol0003oooooooooo`0jooooo`00oooooolnoooo
o`?o00000oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06Kooooo00?o0000ooVZ
D_oiZU800ol00006ooooo`?o00002_ooool00ol0003oooooooooo`0iooooo`00oooooollooooo`;o
00001_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06Cooooo1?l00003ooVZDP03
o`000?oooooooooo00?o000000?oooooo`000?ooool02_ooool2o`0003[ooooo003ooooooc[ooooo
0_l00008ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0H_ooool2o`0000OonJYB
0_l00003ooooo`;o00002?ooool3o`000003oh]BQol0003ooooo03Wooooo003oooooocWooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo067ooooo00?o
0000ooVZD_oiZU801ooiZU84o`000003ooooool0003ooooo00Cooooo0ol00004oh]BQ`;o0000>Ooo
ool00?oooooo=oooool2o`0000_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Q
ooooo`03o`000?oiZU;onJYB00GonJYB1?l00003ooooo`03o`000?oooooooooo00?o00001on;DXL2
o`0003Wooooo003oooooocKooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo063ooooo00?o0000ooVZD_oiZU800ooiZU82o`0000ConJYB00?o0000oooo
ooooool00ol0000:oh]BQ`03o`000?oooooo000003Sooooo003oooooocCooooo0_l0000>ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G_ooool01?l0003onJYBooVZD_oiZU83o`00
00OonJYB0ol0000<oh]BQ`04o`000?ooooooooooo`0003Oooooo003ooooooc?ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05kooooo1?l0000:ooVZ
DP03o`000?n;DXOo000000goRe:700?o0000ooooool00000=oooool00?oooooo<_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0GOooool00ol0003o
nJYBooVZDP0;ooVZDP03o`000?n;DXOo000000goRe:700Co0000ooooool0003o0000=_ooool00?oo
oooo<_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0G?ooool00ol0003onJYBooVZDP0;ooVZDP03o`000?n;DXOo000000goRe:70_l000000ooooooo
0000ooooo`0eooooo`00oooooolaooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1Looooo`03o`000?oiZU;onJYB00_onJYB0ol0000=oh]BQ`05o`00
0?ooooooooooooooool00000=Oooool00?oooooo<?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0G?ooool00ol0003onJYBooVZDP09ooVZDP?o0000
00?oYl3[o`000?n;DXL03?n;DXL01Ol0003ooooooooooooooooo000003Gooooo003ooooooboooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05gooooo
00?o0000ooVZD_oiZU801OoiZU83o`0000CoYl3[0_l0000<oh]BQ`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0<_ooool00?oooooo;_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0GOooool00ol0003onJYBooVZDP02ooVZDP?o00001onW
`>/00ol0003oYl3[o`00000;oh]BQ`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<_oo
ool00?oooooo;Oooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooooooo`;o00007ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oiZU;o000000;o00002_nW`>/01?l0003oYl3[ojO0
jol0000:oh]BQ`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<_ooool00?oooooo;?oo
ool00ol0003oooooooooo`0Fooooo`04o`000?ooooooooooooooo`;o00007oooool00ol0003ooooo
ooooo`1Looooo`;o00003_nW`>/00ol0003oYl3[o`00000:oh]BQ`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0<Oooool00?oooooo:oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00;ooooo00?o2NX:ooooooooool07Oooool00ol0003oooooooooo`1Looooo`03o`000?nW
`>_oYl3[00goYl3[00Co0000ojO0jonW`>_o00002On;DXL00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo037ooooo003oooooob_ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`03ooooo`03o`WZ2_oooooooooo01_ooooo0ol0001Mooooo`;o00003_nW`>/01Ol0003oYl3[ojO0
jonW`>_o000000SoRe:700?o0000ooooooooool00oooool2o`0003;ooooo003oooooob[ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`WZ2_oooooooooo01Oooooo0ol0
00000ooooooo0000ooooo`1Mooooo`03o`000?oiZU;o000000goYl3[00?o0000ojO0jonW`>/00_nW
`>/00ol0003oRe:7oh]BQ`06oh]BQ`03o`000?oooooo000000;o000000?oooooo`000?ooool0<Ooo
ool00?oooooo:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o2NX:
ooooooooool04oooool3o`0000Cooooo00?o0000ooooooooool0G?ooool00ol0003onJYBo`00000<
ojO0j`;o00001?nW`>/00ol0003oRe:7oh]BQ`06oh]BQ`;o00001Oooool00ol0003oooooooooo`0_
ooooo`00oooooolXooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol9
jP[oooooooooo`0?ooooo`?o00001oooool00ol0003oooooooooo`1Mooooo`03o`000?oiZU;o0000
00SoYl3[0ol000000onW`>_o0000ojO0j`04ojO0j`03o`000?n;DXOoRe:700GoRe:700?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0_ooooo`00oooooolXooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01_ooool00ol9jP[oooooooooo`0<ooooo`?o00002_ooool00ol0003o
ooooooooo`1Mooooo`03o`000?oiZU;o000000GoYl3[0ol00004ojO0j`03o`000?nW`>_oYl3[00Co
Yl3[00?o0000oh]BQon;DXL01?n;DXL00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02oo
oooo003oooooobOooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`WZ
2_oooooooooo00Oooooo1?l0000=ooooo`03o`000?oooooooooo05gooooo00Go0000ooVZD_oiZU;o
0000ojO0j`03o`0000SoYl3[00?o0000ojO0jonW`>/00onW`>/00ol0003oRe:7oh]BQ`04oh]BQ`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool00?oooooo9_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Sooooo00?o2NX:ooooooooool01?ooool4o`0000oooooo
00?o0000ooooooooool0GOooool00ol0003onJYBo`000002o`0000_oYl3[00?o0000ojO0jonW`>/0
1?nW`>/00ol0003oRe:7oh]BQ`03oh]BQ`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
;_ooool00?oooooo9Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Wooooo00Co
2NX:oooooooooooooooo0_l00002ooooo`03o`WZ2_oooooooooo00kooooo00?o0000ooooooooool0
GOooool2o`0000;onJYB00?o0000ojO0jonW`>/02OnW`>/00ol0003oYl3[ojO0j`04ojO0j`03o`00
0?n;DXOoRe:700?oRe:700?o0000ooooooooool01_ooool00ol0003oooooooooo`0]ooooo`00oooo
oolUooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool3o`0000Gooooo00?o
2NX:ooooooooool03Oooool00ol0003oooooooooo`1Mooooo`03o`000?oiZU;onJYB00;onJYB0ol0
0009ojO0j`03o`000?nW`>_oYl3[00CoYl3[00?o0000oh]BQon;DXL00_n;DXL00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02gooooo003oooooobCooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`08ooooo`;o000000?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`0<
ooooo`03o`000?oooooooooo05gooooo00Co0000ooVZD_oiZU;onJYB0_l9jPX2o`0000WoYl3[00?o
0000ojO0jonW`>/01OnW`>/01Ol0003oRe:7oh]BQon;DXOo000000Sooooo00?o0000ooooooooool0
;Oooool00?oooooo9?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo0ol0
0003ooooo`03o`WZ2_oooooooooo00Kooooo00?o2NX:ooooooooool02oooool00ol0003ooooooooo
o`1Jooooo`?o2NX:00?o0000ooVZD_oiZU801?oiZU800ol0003oYl3[ojO0j`07ojO0j`03o`000?nW
`>_oYl3[00GoYl3[00Go0000oh]BQon;DXOoRe:7o`000008ooooo`;o0000;_ooool00?oooooo8ooo
ool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooooooo`Co00001oooool00ol9jP[ooooo
ooooo`06ooooo`03o`WZ2_oooooooooo00Wooooo00?o0000ooooooooool0F?ooool6o`WZ2P03oooo
ool0003onJYB00ConJYB00?o0000ojO0jonW`>/01onW`>/00ol0003oYl3[ojO0j`06ojO0j`04o`00
0?n;DXOoRe:7o`0000Gooooo0ol000000ooooooo0000ooooo`0]ooooo`00oooooolSooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooool000001?l00009ooooo`03o`WZ2_oooooooooo00Kooooo
00?o2NX:ooooooooool02?ooool00ol0003oooooooooo`1Dooooo`Oo2NX:1?ooool00ol0003onJYB
ooVZDP04ooVZDP03o`000?nW`>_oYl3[00OoYl3[00?o0000ojO0jonW`>/01_nW`>/01Ol0003oRe:7
oh]BQol0003ooooo00?o00001?ooool00ol0003oooooooooo`0/ooooo`00oooooolSooooo`03o`00
0?oooooooooo01kooooo0ol00004ooooo`03o`WZ2_oooooooooo00Sooooo00?o2NX:ooooooooool0
1Oooool00ol9jP[oooooooooo`07ooooo`03o`000?oooooooooo05;ooooo0ol9jPX01?oooooo2NX:
o`WZ2_l9jPX7ooooo`03o`000?oiZU;onJYB00GonJYB00?o0000ojO0jonW`>/01?nW`>/3o`0000Wo
Yl3[00Co0000oh]BQol0003o00002?ooool00ol0003oooooooooo`0[ooooo`00oooooolRooooo`03
o`000?oooooooooo01cooooo0ol000000ooooooo0000ooooo`05ooooo`03o`WZ2_oooooooooo00Oo
oooo00?o2NX:ooooooooool01_ooool00ol9jP[oooooooooo`06ooooo`03o`000?oooooooooo04oo
oooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX:ooooo`03o`000?oiZU;onJYB00KonJYB00?o0000ojO0
jonW`>/00ol00002ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000oh]BQol000002Oooool00ol0
003oooooooooo`0[ooooo`00oooooolRooooo`03o`000?oooooooooo01Wooooo0ol00004ooooo`03
o`000?oooooooooo00Gooooo00?o2NX:ooooooooool01oooool00ol9jP[oooooooooo`06ooooo`03
o`WZ2_oooooo000000Oo0000COooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2Pgooooo00?o0000ooVZ
D_oiZU801_oiZU83o`0000GoYl3[00?o0000ojO0jonW`>/02?nW`>/2o`0000Wooooo00?o0000oooo
ooooool0:oooool00?oooooo8Oooool00ol0003oooooooooo`0Fooooo`Co00001oooool00ol0003o
ooooooooo`06ooooo`03o`WZ2_oooooooooo00Oooooo00?o2NX:ooooooooool00_ooool4o`000004
o`WZ2_ooooooooooo`0000;ooooo00?o0000ooooooooool01_l00014ooooo`?o2NX:00Coooooo`WZ
2_l9jP[o2NX:4Oooool00ol0003onJYBooVZDP02ooVZDP?o000000?onJYBo`000?nW`>/01_nW`>/0
0ol0003oYl3[ojO0j`08ojO0j`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool0
0?oooooo8Oooool00ol0003oooooooooo`0Cooooo`Go00002Oooool00ol0003oooooooooo`07oooo
o`03o`WZ2_oooooooooo00Oooooo00Co2NX:o`000?l0003o00001Oooool00ol9jP[o0000ooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ol0000nooooo`?o2NX:00Cooooo
o`WZ2_l9jP[o2NX:5?ooool00ol0003onJYBo`000002o`0000GonJYB00?o0000ojO0jonW`>/01?nW
`>/00ol0003oYl3[ojO0j`07ojO0j`03oh]BQol0003ooooo00Wooooo00?o0000ooooooooool0:_oo
ool00?oooooo8Oooool00ol0003oooooooooo`0@ooooo`?o00001Oooool00ol9jP[oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o2NX:ooooooooool01?ooool3o`000003ooooool9jP[o
oooo00Kooooo00Go2NX:ooooooooooooooooo`000005ooooo`;o00001Oooool3o`0003Oooooo1?l9
jPX01?oooooo2NX:o`WZ2_l9jPXGooooo`;o00002?oiZU82o`0000GoYl3[00?o0000ojO0jonW`>/0
1?nW`>/4oh]BQ`;o00002Oooool00ol0003oooooooooo`0Zooooo`00oooooolQooooo`03o`000?oo
oooooooo00gooooo0ol00009ooooo`03o`WZ2_oooooooooo00Gooooo00?o0000ooooooooool02?oo
ool01?l9jP[oooooooooooooool2o`0000?ooooo00?o0000o`WZ2_ooool01_ooool01Ol0003o2NX:
oooooooooooo000000Gooooo0_l00008ooooo`?o0000<Oooool3o`WZ2P;ooooo0ol9jPXJooooo`03
o`000?oiZU;onJYB00OonJYB0_l00006ojO0j`03o`000?nW`>_oYl3[00OoRe:700?o0000ojO0jol0
00002Oooool00ol0003oooooooooo`0Yooooo`00oooooolQooooo`03o`000?oooooooooo00[ooooo
0ol0000=ooooo`03o`WZ2_oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol9jP[ooooo
o`000005ooooo`03o`000?oooooo2NX:00Gooooo00Go0000oooooooooooo2NX:o`000005ooooo`03
o`000?l006Go000000Wooooo00Co0000ooooool0003o0000;?ooool3o`WZ2P;ooooo0ol9jPXMoooo
o`03o`000?oiZU;onJYB00WonJYB00?o0000ojO0jonW`>/00onW`>/00ol0003oRe:7oh]BQ`07oh]B
Q`04o`000?nW`>_oYl3[o`0000Oooooo0_l0000[ooooo`00oooooolPooooo`03o`000?oooooooooo
00Sooooo0ol0000Aooooo`03o`WZ2_oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol9
jP[o0000ooooo`03ooooo`05o`000?ooooooooooooooool9jPX01?ooool01Ol0003oooooooooool0
003o2NX:00Gooooo00?o0000o`00IOl000002?ooool00ol0003oooooooooo`02ooooo`;o00009ooo
ool3o`WZ2P;ooooo0ol9jPXPooooo`03o`WZ2_l0003onJYB00[onJYB00?o0000ojO0jon;DXL00_n;
DXL00ol0003oRe:7oh]BQ`07oh]BQ`04o`000?nW`>_oYl3[o`0000Cooooo0ol000000ooooooo0000
ooooo`0Zooooo`00oooooolPooooo`03o`000?oooooooooo00Gooooo0ol0000Dooooo`;o2NX:1?oo
ool00ol0003oooooooooo`09ooooo`;o000000Go2NX:ooooooooooooooooo`000005ooooo`04o`WZ
2_ooooooooooo`0000?ooooo00?o0000ooooool9jPX00oooool01Ol0003o001Uo`00IOl006Go0000
00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Qooooo`?o2NX:0_ooool3o`WZ
2R3ooooo0ol9jPX00ooooooo0000ooVZDP0:ooVZDP03o`000?n;DXOoRe:700?oRe:700?o0000oh]B
Qon;DXL01on;DXL00ol0003oYl3[ojO0j`04o`0000Cooooo00?o0000ooooooooool0:Oooool00?oo
oooo8?ooool00ol0003oooooooooo`02ooooo`?o00006?ooool2o`WZ2P?ooooo00?o0000oooooooo
ool02?ooool01Ol0003oooooo`000?oooooo2NX:00;ooooo00?o0000ooooooooool01?ooool00ol9
jP[o0000ooooo`02ooooo`05o`000?ooooooooooooooool9jPX00_ooool01Ol0003o001Uo`00IOl0
06Go000000Kooooo00?o0000ooooooooool01_ooool2o`0001kooooo0ol9jPX2ooooo`?o2NX:8?oo
ool3o`WZ2PCooooo00?o0000ooVZD_oiZU802OoiZU801?l0003oRe:7oh]BQon;DXL3o`0000WoRe:7
00Go0000ojO0jonW`>_oYl3[o`000007ooooo`03o`000?oooooooooo02Sooooo003oooooob3ooooo
00?o0000ooooool000000_l0000Looooo`05o`WZ2_ooooooooooooooool000001?ooool2o`0000?o
oooo00?o0000ooooool000000_ooool00ol9jP[oooooo`000007ooooo`05o`WZ2_l0003ooooooooo
ool000001?ooool00ol9jP[oooooo`000004o`00I@03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool2o`0001Sooooo1?l9jPX2ooooo`?o2NX:8?ooool3o`WZ2PSooooo00?o0000ooVZ
D_oiZU802?oiZU84o`0000;oRe:700?o0000oh]BQon;DXL01on;DXL00ol0003oYl3[ojO0j`02ojO0
j`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool00?oooooo8?ooool2o`00023o
oooo00Co2NX:oooooooooooo00001?ooool2o`0000;ooooo00Co0000oooooooooooo00000oooool0
0ol9jP[o0000ooooo`02ooooo`Go000000?o2NX:o`000?l000000_l00004ooooo`03o`WZ2_l0003o
001U00?o001U00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
000001Cooooo0ol9jPX3ooooo`?o2NX:8?ooool3o`WZ2P_ooooo00?o0000ooVZD_oiZU801_oiZU83
o`0000KoRe:700?o0000oh]BQon;DXL01_n;DXL00ol0003oYl3[ojO0j`02ojO0j`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0:?ooool00?oooooo8?ooool00ol0003oooooooooo`0Poooo
o`03o`WZ2_oooooo000000Gooooo00?o2NX:ooooool000000_ooool01?l0003oooooooooooooool2
o`000004o`WZ2_l0003o0000o`0000Ko`gj600Co2NX:o`000?o3OXKo`gj61Ol000000ol9jP[o001U
o`00I@02o`00I@03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooo
oooooooooooo0000013ooooo0ol9jPX3ooooo`?o2NX:8?ooool3o`WZ2Pkooooo00?o0000ooVZD_oi
ZU800ooiZU83o`0000;onJYB00?o0000oh]BQon;DXL01?n;DXL00ol0003oRe:7oh]BQ`06oh]BQ`03
o`000?nW`>_oYl3[00?oYl3[00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`00
oooooolPooooo`03o`000?oooooooooo023ooooo0_l9jPX00ol0003oooooooooo`04ooooo`06o`WZ
2_l0003oooooooooool0003ooooo0_l00003ol=nQP03o`WZ2_o3OXKo`gj600Ko`gj600?o0000o`WZ
2_o3OXH01Oo3OXH00ol0003o001Uo`WZ2P03o`00I@03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`;o00002oooool3o`WZ2P;ooooo1?l9jPXPoooo
o`?o2NX:4_ooool00ol0003onJYBo`000002o`0000KonJYB00?o0000oh]BQon;DXL00on;DXL00ol0
003oRe:7oh]BQ`06oh]BQ`03o`000?nW`>_oYl3[00CoYl3[00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Wooooo`00oooooolQooooo`03o`000?oooooooooo023ooooo00?o2NX:o`000?oo
ool01Oooool01_l0003o2NX:ooooool0003oooooo`0000Ko`gj600?o2NX:ol=nQ_o3OXH01Oo3OXH0
0ol0003o`gj6o`WZ2P05ol=nQP04o`000?l006Go001Uo`WZ2P;o001U1?l000000ooooooo0000oooo
o`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool3o`WZ2P;ooooo0ol9
jPXQooooo`?o2NX:5Oooool2o`0000WonJYB00?o0000oh]BQon;DXL01?n;DXL00ol0003oRe:7oh]B
Q`05oh]BQ`03o`000?nW`>_oYl3[00GoYl3[00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Wooooo`00oooooolQooooo`03o`000?oooooooooo027ooooo00?o0000o`WZ2_ooool01?ooool0
0ol0003oooooo`WZ2P02o`0000So`gj600?o2NX:ol=nQ_o3OXH00oo3OXH01?l0003o`gj6ol=nQ_l9
jPX5ol=nQP04o`000?l006Go001Uo`WZ2P;o001U00Co0000ol=nQ_o3OXKooooo0_l00009ooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0ol9jPX2ooooo`?o2NX:8?ooool4o`WZ
2QSooooo00?o0000ooVZD_oiZU802?oiZU800ol0003oRe:7oh]BQ`04oh]BQ`03o`000?n;DXOoRe:7
00GoRe:700?o0000ojO0jonW`>/01OnW`>/00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Kooooo003oooooob7ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`02ooooo`05
o`000?oooooo0000o`000?l9jPX02Oo3OXH00ol9jP[o`gj6ol=nQP02ol=nQP03o`000?o3OXKo`gj6
00;o`gj600?o2NX:ol=nQ_o3OXH00_o3OXH01ol0003o001Uo`00IOl006Go2NX:o`00IOl000001Oo3
OXH2o`0000Oooooo00?o0000ooooooooool01oooool4o`WZ2P;ooooo0ol9jPXPooooo`?o2NX:7Ooo
ool00ol0003onJYBooVZDP07ooVZDP03o`000?n;DXOoRe:700GoRe:700?o0000oh]BQon;DXL01?n;
DXL00ol0003oYl3[ojO0j`06ojO0j`04o`000?ooooooooooooooo`;o0000:?ooool00?oooooo8Ooo
ool00ol0003oooooooooo`0Rooooo`07o`000?l9jP[oooooooooool0003oooooo`000002ol=nQP03
o`WZ2_o3OXKo`gj600So`gj600Co2NX:ol=nQ_o3OXKo00001_o3OXH01Ol9jP[o`gj6ol=nQ_o3OXKo
000000Co001U00?o2NX:o`000?o3OXH01_o3OXH3o`0000?ooooo00?o0000ooooooooool01Oooool3
o`WZ2P03ooooool0003ooooo00?o2NX:8?ooool3o`WZ2R3ooooo00?o0000ooVZD_oiZU801?oiZU82
o`000003ooVZD_l0003oRe:700KoRe:700?o0000oh]BQon;DXL01?n;DXL00ol0003oYl3[ojO0j`07
ojO0j`?o000000?oooooo`000?ooool09oooool00?oooooo8_ooool00ol0003oooooooooo`0Qoooo
o`04o`000?oooooo2NX:ooooo`;o00001?o3OXH00ol9jP[o`gj6ol=nQP08ol=nQP03o`WZ2_l0003o
`gj600Oo`gj600Co2NX:ol=nQ_o3OXKo00001Ol006D00ol9jP[o`gj6ol=nQP08ol=nQP;o000000?o
ooooo`000?ooool00oooool3o`WZ2P?ooooo0ol9jPXPooooo`?o2NX:8Oooool2o`WZ2P03o`000?oi
ZU;onJYB00;onJYB00Ko2NX:ooVZD_l0003o0000ooVZD_l00007oh]BQ`03o`000?n;DXOoRe:700Co
Re:700?o0000ojO0jonW`>/01onW`>/01Ol0003ooooooooooooooooo000002Sooooo003oooooob;o
oooo00?o0000ooooooooool08Oooool01Ol0003oooooo`WZ2_l9jP[o000000Ko`gj600?o2NX:ol=n
Q_o3OXH01oo3OXH00ol0003o2NX:ol=nQP08ol=nQP?o00001Ol006D00ol0003o2NX:ol=nQP0:ol=n
QP;o000000Coooooo`WZ2_l9jP[o2NX:0oooool3o`WZ2P04o`000?ooooooooooo`0001cooooo0ol9
jPXPooooo`Co2NX:0_ooool00ol9jP[o0000ooVZDP07ooVZDP03o`000?n;DXOoRe:700CoRe:70ol0
0006oh]BQ`03o`000?nW`>_oYl3[00OoYl3[00Co0000oooooooooooo0000:?ooool00?oooooo8_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;o2NX:1oo3OXH00ol9jP[o`gj6ol=n
QP05ol=nQP04o`000?o3OXKo`gj6o`WZ2PSo`gj60ol00005o`00I@03o`000?o3OXKo2NX:00[o`gj6
0ol9jPX3ooooo`?o2NX:0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo
0ol9jPXPooooo`Co2NX:0_ooool3o`WZ2P03ooooool0003onJYB00OonJYB00Co0000oh]BQon;DXOo
Re:70ol00002oh]BQ`03o`000?n;DXOoRe:700CoRe:700?o0000ojO0jonW`>/02?nW`>/00ol0003o
ooooo`00000Xooooo`00oooooolSooooo`03o`000?oooooooooo023ooooo00Co0000ooooool0003o
00000_l9jPX7ol=nQP03o`WZ2_o3OXKo`gj600;o`gj60_l00003ol=nQP03o`WZ2_o3OXKo`gj600Ko
`gj600?o2NX:ol=nQ_l000001Ol006D00ol0003o`gj6o`WZ2P07ol=nQP?o2NX:0oo3OXH3o`WZ2PGo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`?o2NX:8?ooool3o`WZ2P?o
oooo0ol9jPX5ooooo`03o`000?oiZU;onJYB00GonJYB1?l00006oh]BQ`03o`000?n;DXOoRe:700?o
Re:700?o0000ojO0jonW`>/02?nW`>/01?l0003oooooooooool0000Wooooo`00oooooolSooooo`03
o`000?oooooooooo023ooooo00Go0000ooooool0003o0000ol=nQP02o`WZ2POo`gj600Co2NX:ol=n
Q_o3OXKo00001_o3OXH00ol9jP[o`gj6ol=nQP06ol=nQP03o`WZ2_l0003o001U00Co001U00Co0000
ol=nQ_o3OXKo2NX:0oo3OXH3o`WZ2P?o`gj60ol9jPX00oo3OXKo0000ooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03_ooool3o`WZ2R3ooooo0ol9jPX3ooooo`?o2NX:2?oo
ool00ol0003onJYBooVZDP03ooVZDP?o00002On;DXL00ol0003oRe:7oh]BQ`03oh]BQ`03o`000?nW
`>_oYl3[00WoYl3[00?o0000ooooool000009oooool00?oooooo9?ooool00ol0003oooooooooo`0O
ooooo`;o000000Go`gj6o`000?o3OXKo`gj6o`WZ2P07ol=nQP03o`WZ2_l0003o000000So`gj600?o
2NX:ol=nQ_o3OXH01Oo3OXH00ol9jP[o0000o`00I@04o`00I@08o`000?o3OXKo`gj6ol=nQ_l9jP[o
`gj6o`WZ2_o3OXH2o`0000?o2NX:1Oo3OXH00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02_ooool3o`WZ2R3ooooo0ol9jPX3ooooo`?o2NX:2oooool00ol0
003onJYBooVZDP03o`0000;onJYB00?o0000oh]BQon;DXL02?n;DXL00ol0003oRe:7oh]BQ`02oh]B
Q`03o`000?nW`>_oYl3[00WoYl3[00?o0000ooooool000009oooool00?oooooo9?ooool00ol0003o
ooooooooo`0Oooooo`?o00000oo3OXH2o`WZ2PKo`gj600?o0000o`WZ2_o3OXH02Oo3OXH00ol9jP[o
`gj6ol=nQP04ol=nQP03o`WZ2_l0003o001U00Co001U00Co0000ol=nQ_o3OXKo`gj60_l9jPX01?o3
OXKo2NX:o`WZ2_l9jPX9ol=nQP04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_oo
ool3o`WZ2Qoooooo1?l9jPX3ooooo`?o2NX:3oooool2o`0000KonJYB00?o0000oh]BQon;DXL01on;
DXL00ol0003oRe:7oh]BQ`02oh]BQ`03o`000?nW`>_oYl3[00[oYl3[0_l0000Wooooo`00oooooolT
ooooo`03o`000?oooooooooo01oooooo00?o0000ol=nQ_l000001?o3OXH2o`WZ2P?o`gj60_l00002
ol=nQP03o`WZ2_o3OXKo`gj600So`gj600?o2NX:ol=nQ_o3OXH01?o3OXH00ol0003o001Uo`00I@03
o`00I@03o`000?o3OXKo2NX:00Co2NX:3Oo3OXH00ol0003oooooo`00000:ooooo`03o`000?oooooo
oooo00;ooooo1?l9jPXOooooo`Co2NX:0_ooool4o`WZ2Q;ooooo00?o0000ooVZD_oiZU801OoiZU80
0ol0003oRe:7oh]BQ`07oh]BQ`03o`000?n;DXOoRe:700;oRe:700?o0000ojO0jonW`>/02_nW`>/2
o`0002Oooooo003oooooobGooooo0_l0000Nooooo`;o000000?o`gj6o`000?o3OXH01?o3OXH2o`WZ
2P03ol=nQ_l0003o`gj600;o00000_o3OXH00ol9jP[o`gj6ol=nQP08ol=nQP03o`WZ2_o3OXKo`gj6
00?o`gj600?o0000o`00IOl006D00ol006D01?l0003o2NX:o`WZ2_l9jPX2ol=nQP03o`WZ2_o3OXKo
`gj600co`gj600?o0000ooooooooool02?ooool00ol0003oooooo`000003o`WZ2R3ooooo1?l9jPX2
ooooo`?o2NX:5oooool00ol0003onJYBooVZDP04ooVZDP03o`000?n;DXOoRe:700SoRe:700Go0000
oh]BQon;DXOoRe:7o`000009ojO0j`?o000000?oooooo`000?ooool09_ooool00?oooooo9oooool0
0ol0003oooooooooo`0Kooooo`;o000000?o`gj6o`000?l000000_l00003ol=nQP;o000000Co2NX:
ol=nQ_l0003o00000oo3OXH00ol9jP[o`gj6ol=nQP07ol=nQP03o`WZ2_o3OXKo`gj600?o`gj600Co
0000o`00IOl006Go001U0ol9jPX6ol=nQP03o`WZ2_o3OXKo`gj600_o`gj600?o0000ooooooooool0
1oooool01?l0003o2NX:o`WZ2_l9jPXPooooo`?o2NX:0oooool3o`WZ2Q[ooooo00?o0000ooVZD_oi
ZU801?oiZU800ol0003oRe:7oh]BQ`08oh]BQ`05o`000?n;DXOoRe:7oh]BQol000001_nW`>/3o`00
00Cooooo00?o0000ooooooooool09Oooool00?oooooo:?ooool00ol0003oooooooooo`0Iooooo`05
o`000?o3OXKo0000ol=nQ_l000000onW`>/7o`0000Ko`gj600?o2NX:ol=nQ_o3OXH01oo3OXH00ol9
jP[o`gj6ol=nQP02ol=nQPCo2NX:0_l006D00ol0003o`gj6ol=nQP05ol=nQP03o`WZ2_o3OXKo`gj6
00_o`gj600?o0000ooooooooool01?ooool3o`WZ2P?ooooo00?o0000ooooooooool06_ooool3o`WZ
2P?ooooo0ol9jPXNooooo`03o`000?oiZU;onJYB00?onJYB00?o0000oh]BQon;DXL02?n;DXL2o`00
00?oRe:700?o0000ojO0jonW`>/00ol00007ooooo`03o`000?oooooooooo02Gooooo003oooooobWo
oooo00?o0000ooooooooool06?ooool00ol0003o`gj6o`000002o`0000;oYl3[0_l00003ojO0j`;o
000000?oYl3[o`000?l000001?l000000ol9jP[o`gj6ol=nQP08ol=nQP03o`WZ2_o3OXKo2NX:00;o
2NX:00?o0000o`00IOl006D00ol006D00ol0003o`gj6ol=nQP05ol=nQP03o`WZ2_o3OXKo`gj600_o
`gj600?o0000ooooooooool00ol9jPX00ooooooo0000ooooo`03ooooo`03o`000?oooooooooo01Ko
oooo1?l9jPX3ooooo`?o2NX:8_ooool00ol0003onJYBooVZDP02ooVZDP03o`000?n;DXOoRe:700Go
Re:70ol000000on;DXOo0000oh]BQ`02oh]BQ`?o00002_ooool00ol0003oooooooooo`0Uooooo`00
oooooolZooooo`03o`000?oooooooooo01Oooooo00Go0000ol=nQ_l0003o0000ojO0j`02o`0000Go
Yl3[0_l9jPX7ojO0j`03o`000?l9jP[o000000Co00000oo3OXH3o`WZ2P;o`gj60_l00005o`00I@03
o`000?o3OXKo`gj600Ko`gj600?o2NX:ol=nQ_o3OXH02_o3OXH3o`WZ2P?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`Co2NX:0oooool3o`WZ2RGooooo00?o0000ooVZD_oi
ZU800_oiZU800ol0003oRe:7oh]BQ`02oh]BQ`?o00001On;DXL01?l0003oRe:7oh]BQol0000<oooo
o`03o`000?oooooooooo02Gooooo003oooooob_ooooo0ol0000Eooooo`03o`WZ2_l0003o`gj600Co
00001onW`>/00ol9jP[oYl3[ojO0j`07ojO0j`03o`WZ2_nW`>_oYl3[00;oYl3[00?o0000o`WZ2_l9
jPX00_l000000oo3OXKo2NX:ol=nQP02o`0000Go001U00?o0000ol=nQ_o3OXH01oo3OXH00ol9jP[o
`gj6ol=nQP06ol=nQP?o2NX:0_o3OXH01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool03oooool4o`WZ2P?ooooo0ol9jPXYooooo`06o`000?oiZU;onJYBooVZD_l0003oRe:70ol0
0009oh]BQ`03o`000?n;DXOo000000cooooo00?o0000ooooooooool09Oooool00?oooooo;_ooool4
o`0000kooooo0ol9jPX01?oooooo0000o`000?l00002ojO0j`03o`000?nW`>_oYl3[00GoYl3[0_l9
jPX9ojO0j`04o`WZ2_nW`>_o2NX:o`WZ2P;o00000onW`>/5o`0000Go001U00?o0000ol=nQ_o3OXH0
1oo3OXH00ol9jP[o`gj6ol=nQP03ol=nQP?o2NX:1_o3OXH00ol0003oooooo`000008ooooo`03o`00
0?oooooooooo00_ooooo1?l9jPX3ooooo`?o2NX:;?ooool00ol0003onJYBooVZDP03o`0000goRe:7
0_l0000;ooooo`;o00009oooool00?oooooo<_ooool7o`0000?ooooo0ol9jPX5o`000003ol=nQ_l0
003oYl3[00;oYl3[00?o0000ojO0jonW`>/01OnW`>/2o`WZ2P[oYl3[0_l9jPX7ojO0j`;o00000_nW
`>/4o`000003o`00IOl0003o`gj600Wo`gj600?o2NX:ol=nQ_l9jPX00_l9jPX:ol=nQP03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool4o`WZ2P;ooooo1?l9jPX`ooooo`;o000000?o
nJYBo`000?n;DXL03On;DXL00ol0003oRe:7o`000007ooooo`?o000000?oooooo`000?ooool09_oo
ool00?oooooo>Oooool6o`0000Cooooo0_l00005ojO0j`03o`000?nW`>_oYl3[00GoYl3[00?o2NX:
ojO0jonW`>/01_nW`>/3o`WZ2PWoYl3[00?o2NX:ojO0jonW`>/01?nW`>/5o`0000Ko`gj60ol9jPX2
ol=nQP;o00002Oo3OXH00ol0003oooooooooo`06ooooo`;o00001_ooool4o`WZ2P?ooooo0ol9jPXd
ooooo`04o`000?oiZU;onJYBo`0000ooRe:70_l00004ooooo`?o00001?ooool00ol0003ooooooooo
o`0Uooooo`00oooooolfooooo`?o2NX:2_ooool2o`0000GoYl3[00?o0000ojO0jonW`>/01OnW`>/0
0ol9jP[oYl3[ojO0j`04ojO0j`;o2NX:0onW`>/00ol9jP[oYl3[ojO0j`06ojO0j`03o`WZ2_nW`>_o
Yl3[00GoYl3[00Co0000ojO0jonW`>_oYl3[1?l00002o`WZ2P?o`gj600Co2NX:ol=nQ_l0003o0000
2_o3OXH00ol0003oooooooooo`05ooooo`03o`000?oooooo000000;ooooo1?l9jPX3ooooo`?o2NX:
>?ooool01?l0003onJYBooVZD_l0000=oh]BQ`?o000000Coooooo`000?l0003o00001oooool00ol0
003oooooooooo`0Uooooo`00oooooolcooooo`?o2NX:3Oooool3o`0000CoYl3[00?o0000ojO0jonW
`>/01OnW`>/00ol9jP[oYl3[ojO0j`02ojO0j`?o2NX:1OnW`>/00ol9jP[oYl3[ojO0j`06ojO0j`03
o`WZ2_nW`>_oYl3[00CoYl3[00?o0000ojO0jonW`>/00onW`>/01?l9jP[o0000o`000?nW`>/6o`00
00_o`gj600?o0000ooooooooool01?ooool00ol0003oooooooooo`04o`WZ2P?ooooo0ol9jPXkoooo
o`04o`000?oiZU;onJYBo`0000[oRe:70ol000001?oooooo0000o`000?l0000:ooooo`03o`000?oo
oooooooo02Gooooo003ooooooc3ooooo0ol9jPX@ooooo`03o`000?o3OXKo`gj600Ko00001_nW`>/2
o`WZ2P;oYl3[0_l9jPX8ojO0j`03o`WZ2_nW`>_oYl3[00GoYl3[00?o2NX:ojO0jonW`>/00onW`>/0
0ol006Go0000ojO0j`02ojO0j`;o2NX:1onW`>/2o`000003ojO0jol0003o000000Go00001Oo3OXH0
0ol0003oooooooooo`03ooooo`Co2NX:0oooool3o`WZ2Soooooo00?o0000ooVZD_l000001on;DXL3
o`0000;onJYB0_l00002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool0
0?oooooo:Oooool4o`0000?o2NX:4oooool00ol0003o`gj6ol=nQP03ol=nQP03o`000?o3OXKo0000
00?o00001?nW`>/3o`WZ2P_oYl3[00?o2NX:ojO0jonW`>/01?nW`>/00ol9jP[oYl3[ojO0j`02ojO0
j`;o001U00Co0000ojO0jol9jP[o2NX:2_nW`>/00ol9jP[oYl3[ojO0j`06ojO0j`Ko00000_ooool4
o`WZ2P;ooooo00Co0000o`WZ2_l9jP[o2NX:@oooool2o`0000CoRe:70ol00005ooVZDP03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool3o`0002Oooooo003oooooobKooooo1Ol00002
o`WZ2P03ooooool0003o000001Cooooo00Go0000ol=nQ_o3OXKo`gj6o`000003ol=nQP03o`000?o3
OXKo`gj600Co00000_l9jPX=ojO0j`03o`WZ2_nW`>_oYl3[00?oYl3[00?o2NX:ojO0jonW`>/00_nW
`>/2o`00I@03o`000?l9jP[oYl3[00_oYl3[00?o2NX:ojO0jonW`>/02onW`>/01?l0003o2NX:o`WZ
2_l9jPX2o`000004ooooool9jP[o2NX:o`WZ2TKooooo0_l000001?n;DXOo0000o`000?l00008ooVZ
DP03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0ol00002ooooo`03o`000?oooooo
oooo02Gooooo003oooooobCooooo0ol000000ol9jP[o0000o`000004o`0000;ooooo00?o0000oooo
ooooool04Oooool01Ol0003o`gj6ol=nQ_o3OXKo000000?o`gj600?o0000ol=nQ_o3OXH00oo3OXH0
0ol9jP[o0000o`000006o`0000OoYl3[00?o2NX:ojO0jonW`>/00onW`>/01?l9jP[oYl3[ojO0jonW
`>/3o`00I@03o`000?nW`>_oYl3[00coYl3[00?o2NX:ojO0jonW`>/02OnW`>/2o`WZ2P;o00001?l9
jPX2o`000003ooooool0003ooooo04Gooooo0_l0000;ooVZDP03o`000?oooooooooo00;ooooo1Ol0
0004ooooo`03o`000?oooooooooo02Kooooo003oooooob?ooooo1Ol000000ooooooo0000o`000006
ooooo`03o`000?oooooooooo013ooooo00Co0000ol=nQ_o3OXKo00001?o3OXH00ol0003o`gj6ol=n
QP06ol=nQP03o`WZ2_o3OXKo`gj600?o`gj61_l00002ojO0j`03o`WZ2_nW`>_oYl3[00?oYl3[00?o
2NX:ojO0jol006D00ol006D00ol0003oYl3[ojO0j`0<ojO0j`03o`WZ2_nW`>_oYl3[00OoYl3[0_l9
jPX01?nW`>_o2NX:o`WZ2_l9jPX6ojO0j`;o0000A_ooool00ol0003onJYBooVZDP09ooVZDP03o`00
0?oooooooooo00Go00000_ooool00ol0003oooooo`000002o`0002Wooooo003oooooob;ooooo0ol0
0003ooooo`;o00001_ooool3o`00013ooooo00Go2NX:o`000?o3OXKo`gj6o`000005ol=nQP03o`00
0?o3OXKo`gj6017o`gj60ol000000ol9jP[o0000o`000002ojO0j`03o`WZ2_nW`>_o001U00?o001U
00?o0000ojO0jonW`>/03?nW`>/00ol9jP[oYl3[ojO0j`05ojO0j`Go2NX:2_nW`>/00ol0003ooooo
ooooo`15ooooo`03o`000?oiZU;onJYB00SonJYB1Ol00004ooooo`Co0000:oooool00?oooooo8?oo
ool00ol9jP[o0000ooooo`05ooooo`03o`000?oooooo000000;ooooo0ol00002oh]BQ`03o`000?oo
oooooooo00_ooooo0ol9jPX01?oooooo0000ol=nQ_l00006ol=nQP03o`000?o3OXKo`gj601Go`gj6
00?o2NX:ol=nQ_l000000ol00004o`00I@03o`000?nW`>_oYl3[00coYl3[00?o2NX:ojO0jonW`>/0
1?nW`>/3o`WZ2PcoYl3[0_l00018ooooo`03o`000?oiZU;onJYB00ConJYB1Ol00004ooooo`Co0000
;_ooool00?oooooo7Oooool3o`WZ2P03ooooool0003ooooo00?ooooo0ol00002ooooo`;o00001On;
DXL2o`0000Wooooo0ol9jPX4ooooo`03o`WZ2_l0003o000000Oo`gj600?o0000ol=nQ_o3OXH05Oo3
OXH00ol9jP[o`gj6ol=nQP02o`0000Co001U1Ol0000:ojO0j`04o`WZ2_nW`>_oYl3[ojO0j`?o2NX:
3_nW`>/00ol0003oooooo`000019ooooo`03o`000?oiZU;onJYB00?o00000ooiZU800ol0003ooooo
ooooo`04o`00037ooooo003ooooooa_ooooo0_l9jPX3ooooo`03o`000?oooooo000000?o00000_oo
ool01?l0003oooooooooool00006oh]BQ`03o`000?oooooo000000Gooooo0ol9jPX4ooooo`?o2NX:
00?oooooo`000?o3OXH01oo3OXH00ol0003o`gj6ol=nQP0Fol=nQP?o00001Ol006D00ol0003o`gj6
ol=nQP02ol=nQPGo00001_nW`>/4o`WZ2Q3oYl3[00?o0000ooooool00000B_ooool2o`0000GonJYB
1Ol0000dooooo`00oooooolIooooo`;o2NX:1Oooool2o`0000Kooooo00Co0000oooooooooooo0000
1_n;DXL4o`000004ooooool9jP[o2NX:o`WZ2P?ooooo1?l9jPX4ooooo`03o`000?o3OXKo`gj600Go
`gj600?o0000ol=nQ_l000005oo3OXH3o`0000Go001U00?o0000ol=nQ_o3OXH01oo3OXH3o`0000Ko
2NX:4?nW`>/00ol0003oooooo`00001=ooooo`;o000000?onJYBo`000?l000000_l0000gooooo`00
oooooolFooooo`?o2NX:1oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001_n;DXL00ol0003oooooo`WZ2P02o`WZ2P?ooooo0ol9jPX9ooooo`03o`000?o3OXKo`gj600Co
`gj600Co0000ol=nQ_o3OXKo00005_o3OXH00ol9jP[o`gj6o`000005o`00I@03o`000?o3OXKo`gj6
00Oo`gj60ol9jPX2ol=nQPCo00003onW`>/01?l0003oooooooooool0001?ooooo`;o0000>_ooool0
0?oooooo5?ooool2o`WZ2P[ooooo00?o0000ooooooooool00oooool2o`0000;ooooo00?o0000oh]B
Qon;DXL01?n;DXL3o`WZ2P;ooooo00Co0000o`WZ2_l9jP[o2NX:3?ooool00ol0003o`gj6ol=nQP03
ol=nQP03o`000?o3OXKo`gj600;o`gj600?o0000ol=nQ_o3OXH05?o3OXH00ol9jP[o0000o`00I@04
o`00I@03o`000?o3OXKo`gj600Co`gj60ol9jPX5ol=nQP?o000000?o`gj6o`000?l000000ol0000:
ojO0j`04o`000?ooooooooooo`0008_ooooo003ooooooa;ooooo0_l9jPX<ooooo`03o`000?oooooo
oooo00?o000000GoYl3[o`000?l0003oooooo`000003oh]BQ`?o2NX:00?oRe:7o`000?l9jPX00ol9
jPX@ooooo`05o`000?o3OXKo`gj6ol=nQ_l000001Oo3OXH00ol0003o`gj6ol=nQP0Dol=nQP03o`WZ
2_o3OXKo000000Co001U00?o0000ol=nQ_o3OXH00oo3OXH01?l9jP[o`gj6o`000?l0000>ol=nQPKo
00000onW`>/01Ol0003ooooooooooooooooo000008_ooooo003ooooooa3ooooo0_l9jPX>ooooo`?o
00001?nW`>/01?l0003oYl3[o`000?l00003o`WZ2P;oRe:70ol9jPX3ooooo`03o`000?oooooooooo
00kooooo00Go0000ol=nQ_o3OXKo`gj6o`000006ol=nQP03o`000?o3OXKo`gj601?o`gj600?o2NX:
ol=nQ_l000001Ol006D00ol0003o`gj6ol=nQP02o`WZ2QSo`gj60ol00004ooooo`03o`000?oooooo
oooo08Wooooo003oooooo`gooooo0ol9jPX@ooooo`03o`000?nW`>_oYl3[00CoYl3[00Co0000ojO0
jonW`>_o00000_n;DXL3o`WZ2P;oRe:700?o0000ooooooooool00ol0000?ooooo`04o`WZ2_l0003o
`gj6o`0000So`gj600?o0000ol=nQ_o3OXH04oo3OXH00ol9jP[o0000o`00I@04o`00I@03o`000?l9
jP[o2NX:01co`gj600Go0000ooooooooooooooooo`00002<ooooo`00ooooool;ooooo`;o2NX:4ooo
ool00ol0003oYl3[ojO0j`05ojO0j`03o`000?nW`>_o000000;o2NX:1On;DXL3o`0000;ooooo00?o
0000ooooooooool02_ooool3o`WZ2P04ooooool0003o`gj6o`0000So`gj60ol0000Col=nQP03o`WZ
2_l0003o001U00Co001U00?o0000ol=nQ_o3OXH07?o3OXH00ol0003oooooo`00000;o`0008?ooooo
003oooooo`Wooooo0_l9jPXEooooo`;o00001OnW`>/00ol9jP[o0000o`WZ2P02o`0000KoRe:700?o
0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`?o2NX:1Oooool00ol0003o`gj6ol=n
QP07ol=nQP;o000000?o`gj6o`000?o3OXH04Oo3OXH00ol9jP[o0000o`00I@03o`00I@03o`WZ2_l0
003o`gj601go`gj60_l000000on=EX[o0000oheFRP09oheFRP?o0000P?ooool00?oooooo1_ooool3
o`WZ2QOooooo00Co0000o`WZ2_l0003oYl3[0_l9jPX3o`0000?oYl3[00?o0000oh]BQon;DXL00on;
DXL00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol9jPX6ooooo`;o2NX:00?o
0000ol=nQ_o3OXH01oo3OXH01Ol0003o`gj6ol=nQ_o3OXKo0000017o`gj600?o2NX:o`000?l006D0
1?l006D00ol0003o`gj6ol=nQP0Lol=nQP04o`000?n=EX[o0000o`0000goSEJ:0ol0001mooooo`00
ooooool4ooooo`;o2NX:6?ooool2o`WZ2P03o`000?oooooo000000?o00000_nW`>/00ol0003oYl3[
ojO0j`02ojO0j`03o`000?n;DXOoRe:700;oRe:700?o0000ooooooooool01?ooool00ol0003ooooo
o`WZ2P02o`WZ2PKooooo0ol9jPX3ooooo`03o`000?o3OXKo`gj600Ko`gj600?o0000ol=nQ_o3OXH0
0_o3OXH2o`00013o`gj600?o0000o`00IOl006D00ol006D00ol0003o`gj6ol=nQP0Kol=nQP05o`00
0?l9jP[o0000oheFR_l000004?n=EXX2o`0007_ooooo003oooooo`;ooooo0_l9jPXHooooo`;o2NX:
00?oooooo`WZ2_l000000ol00004ojO0j`03o`000?nW`>_oYl3[00?oYl3[00Go0000oh]BQon;DXOo
Re:7o`000005ooooo`?o2NX:1Oooool4o`WZ2P?ooooo0ol9jPX00ooooooo0000ol=nQP05ol=nQP03
o`000?o3OXKo`gj600Go`gj600?o0000ol=nQ_o3OXH03?o3OXH2o`0000Go001U00?o0000ol=nQ_o3
OXH06oo3OXH01?l0003o2NX:o`000?l0000CoheFRP03o`000?oooooooooo07Sooooo003oooooo`;o
2NX:5oooool6o`WZ2P03ooooool0003ooooo00;ooooo00?o0000ojO0jonW`>/00_nW`>/00ol0003o
Yl3[ojO0j`03ojO0j`04o`000?n;DXOoRe:7o`0000;ooooo0ol9jPX3o`0000;ooooo0ol9jPX4oooo
o`?o2NX:1Oooool00ol0003o`gj6ol=nQP02ol=nQP03o`000?o3OXKo`gj600Oo`gj600?o0000ol=n
Q_o3OXH02oo3OXH2o`0000Go001U00?o0000ol=nQ_o3OXH06oo3OXH4o`0001CoSEJ:00?o0000oooo
ooooool0Moooool00?cooooo0ol9jPXFooooo`?o2NX:00?oooooo`WZ2_l9jPX01Oooool01Ol0003o
oooooooooooooooo000000?oYl3[00?o0000ojO0jonW`>/00onW`>/01?l0003oRe:7oh]BQol00002
o`WZ2P03o`000?oooooooooo00;ooooo0ol9jPX3ooooo`Co2NX:2?ooool00ol0003o`gj6ol=nQP02
ol=nQP03o`000?o3OXKo`gj600So`gj60_l0000<ol=nQP03o`000?l006Go001U00?o001U00?o0000
ol=nQ_o3OXH06oo3OXH3o`000003o`WZ2_n=EX[oSEJ:00coSEJ:00?o0000oheFR_n=EXX01?n=EXX0
0ol0003oooooooooo`1fooooo`00n_ooool2o`WZ2QOooooo0_l9jPX01?oooooo2NX:o`WZ2_l9jPX7
ooooo`05o`000?ooooooooooooooool000000_nW`>/2o`0000KoYl3[00Co0000oh]BQol0003o0000
0oooool3o`WZ2P03ooooool0003ooooo00?o2NX:3Oooool01?l0003o`gj6ol=nQ_l0000;ol=nQP04
o`000?o3OXKo0000o`0000[o`gj600?o0000o`00IOl006D00ol006D00ol0003o`gj6ol=nQP0Kol=n
QP;o00000_n=EXX00ol9jP[oSEJ:oheFRP0CoheFRP03o`000?oooooooooo07Gooooo003hooooo`;o
2NX:5_ooool6o`WZ2P[ooooo00Co0000oooooooooooooooo0ol000000onW`>_o0000ojO0j`06ojO0
j`?o00000ol9jPX3ooooo`?o2NX:4Oooool00ol0003o`gj6o`00000:ol=nQP03o`000?o3OXKo`gj6
00;o`gj60_l00008ol=nQP03o`000?l006Go001U00?o001U00?o0000ol=nQ_o3OXH03?o3OXH2o`00
00co`gj600?o0000oheFR_l000000_n=EXX00ol9jP[oSEJ:oheFRP0DoheFRP03o`000?oooooooooo
07Cooooo003eooooo`?o2NX:5_ooool2o`WZ2P03ooooool9jP[o2NX:00kooooo0ol000001Ooooooo
0000ojO0jonW`>_o000000OoYl3[0ol9jPX2ooooo`Co2NX:0_ooool00ol0003oooooooooo`0@oooo
o`;o00002_o3OXH00ol0003o`gj6ol=nQP04ol=nQP;o00001_o3OXH00ol0003o001Uo`00I@03o`00
I@03o`000?o3OXKo`gj600So`gj60_l9jPX2ol=nQP;o00002oo3OXH3o`0000CoSEJ:00?o2NX:oheF
R_n=EXX04on=EXX00ol0003oooooooooo`1dooooo`00loooool2o`WZ2QKooooo1_l9jPX@ooooo`03
o`000?oooooooooo00;ooooo00Co0000ojO0jonW`>_o00000onW`>/3o`WZ2P03oh]BQol0003o2NX:
00;o2NX:1?ooool3o`00017ooooo0ol9jPX00ol0003o`gj6ol=nQP06ol=nQP03o`000?o3OXKo`gj6
00Oo`gj60_l00004ol=nQP03o`000?l006Go001U00?o001U00?o0000ol=nQ_o3OXH05oo3OXH4o`00
00KoSEJ:00?o2NX:oheFR_n=EXX04on=EXX00ol0003oooooooooo`1cooooo`00lOooool2o`WZ2QGo
oooo1_l9jPXCooooo`03o`000?oooooo2NX:00;o2NX:00Coooooo`000?l0003o00000ol9jPX2oh]B
Q`?o2NX:00?oYl3[o`000?ooool01?l00002ooooo`03o`000?oooooooooo00cooooo0ol9jPX4oooo
o`03o`000?o3OXKo`gj600Go`gj600?o0000ol=nQ_o3OXH02Oo3OXH3o`000003ol=nQ_l0003o001U
00Co001U00?o0000ol=nQ_o3OXH05?o3OXH3o`000004ol=nQ_l0003o0000o`0000OoSEJ:00?o2NX:
oheFR_n=EXX04on=EXX00ol0003oooooooooo`1booooo`00koooool2o`WZ2QGooooo0_l9jPX00ooo
oooo2NX:o`WZ2P0Eooooo`03o`WZ2_l0003o2NX:00?ooooo0_l9jPX2o`0000;oRe:70ol9jPX2oh]B
Q`04o`000?nW`>_oYl3[o`0000Kooooo00?o0000ooooooooool02Oooool3o`WZ2PKooooo0_l9jPX0
0ol0003o`gj6ol=nQP03ol=nQP03o`000?o3OXKo`gj600[o`gj600?o0000ol=nQ_o3OXH00ol00004
o`00I@03o`000?o3OXKo`gj6017o`gj60ol00003ol=nQP04o`000?o3OXKo0000o`WZ2PSoSEJ:00?o
2NX:oheFR_n=EXX04_n=EXX2o`0007?ooooo003/ooooo`?o2NX:5?ooool6o`WZ2QCooooo0ol9jPX0
0ooooooo0000ooooo`03o`WZ2P;ooooo00Co0000o`WZ2_l9jP[o2NX:1On;DXL01Ol0003oYl3[ojO0
jonW`>_o000000Gooooo00?o0000ooooooooool01_ooool3o`WZ2PKooooo0ol9jPX3ooooo`03o`00
0?o3OXKo`gj600;o`gj600?o0000ol=nQ_o3OXH02Oo3OXH00ol0003o`gj6ol=nQP02ol=nQP03o`00
0?l006Go000000;o000000?o001Uo`000?o3OXH03oo3OXH3o`0000Go`gj600Go0000ol=nQ_l0003o
SEJ:o`WZ2P08oheFRP03o`WZ2_n=EX[oSEJ:01?oSEJ:00?o0000ooooooooool0LOooool00>[ooooo
0_l9jPXEooooo`;o2NX:00?oooooo`WZ2_l9jPX05?ooool3o`WZ2P?ooooo0_l9jPX01?l0003ooooo
ooooooooool2o`WZ2PCo00001On;DXL00ol0003oYl3[ojO0j`02ojO0j`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool3o`WZ2PGooooo1?l9jPX7ooooo`04o`000?o3OXKo`gj6o`00
00co`gj600?o0000ol=nQ_o3OXH00_o3OXH00ol0003o001Uo`00I@02o`00I@Oo00001_o3OXH5o`00
00;o`gj600?o0000ol=nQ_o3OXH00oo3OXH2o`0000?oSEJ:00?o2NX:oheFR_n=EXX01_n=EXX00ol9
jP[oSEJ:oheFRP0CoheFRP03o`000?oooooooooo073ooooo003Xooooo`;o2NX:5?ooool6o`WZ2Q?o
oooo0ol9jPX3ooooo`?o2NX:0_ooool7o`000003oh]BQol0003oRe:700GoRe:700?o0000ojO0jonW
`>/00onW`>/00ol0003oooooooooo`02ooooo`03o`000?oooooo2NX:00;o2NX:1Oooool3o`WZ2Pco
oooo00?o0000ol=nQ_l000002oo3OXH00ol0003o`gj6ol=nQP03ol=nQP03o`000?l006Go001U00?o
001U00?o0000ol=nQ_o3OXH00oo3OXH6o`0000Ko`gj600?o0000ol=nQ_o3OXH00oo3OXH3o`0000Co
SEJ:00?o2NX:oheFR_n=EXX01_n=EXX00ol9jP[o0000oheFRP0BoheFRP;o0000LOooool00>Gooooo
0ol9jPXCooooo`Ko2NX:4oooool3o`WZ2P?ooooo0ol9jPX4ooooo`03o`WZ2_l0003o000000Gooooo
00?o0000oh]BQol000001On;DXL00ol0003oYl3[ojO0j`04ojO0j`03o`000?oooooo000000?o2NX:
1Oooool3o`WZ2Q3ooooo0_l0000;ol=nQP03o`000?o3OXKo`gj600?o`gj600?o0000o`00IOl006D0
0_l006D00ol0003o`gj6ol=nQP08ol=nQP03o`000?o3OXKo`gj600Go`gj600?o0000ol=nQ_o3OXH0
0_o3OXH2o`000003oheFR_l0003oSEJ:00CoSEJ:00?o2NX:oheFR_n=EXX01On=EXX00ol0003o2NX:
oheFRP0BoheFRP?o0000L?ooool00>?ooooo0_l9jPXDooooo`;o2NX:00?oooooo`WZ2_l9jPX04ooo
ool3o`WZ2P?ooooo0ol9jPX4ooooo`?o2NX:00?oooooo`000?ooool01Oooool00ol0003oRe:7o`00
0005oh]BQ`03o`000?nW`>_oYl3[00GoYl3[0_l9jPX00ooooooo0000ooooo`02ooooo`?o2NX:5Ooo
ool2o`0000So`gj600?o0000ol=nQ_o3OXH01?o3OXH00ol0003o001Uo`00I@02o`00I@03o`000?o3
OXKo`gj600Oo`gj600?o0000ol=nQ_o3OXH01Oo3OXH00ol0003o`gj6ol=nQP03ol=nQP04o`000?l9
jP[oSEJ:o`0000KoSEJ:00?o2NX:oheFR_n=EXX06_n=EXX2o`00073ooooo003Qooooo`;o2NX:4ooo
ool6o`WZ2Q;ooooo0ol9jPX3ooooo`?o2NX:1?ooool3o`WZ2PGooooo00?o0000ooooooooool00ooo
ool00ol0003oRe:7o`000005oh]BQ`04o`000?nW`>_oYl3[ojO0j`?o2NX:0_l00002ooooo`04o`00
0?l9jP[o2NX:o`WZ2Q[ooooo0_l00006ol=nQP03o`000?o3OXKo`gj600Co`gj600Go0000o`00IOl0
06Go001Uo`00000:ol=nQP03o`000?o3OXKo`gj600Go`gj600?o0000ol=nQ_o3OXH00_o3OXH01_l0
003o2NX:oheFR_l9jP[oSEJ:o`0000KoSEJ:00?o2NX:oheFR_n=EXX06On=EXX00ol0003oooooo`00
001_ooooo`00goooool2o`WZ2Q?ooooo1Ol9jPXBooooo`?o2NX:0oooool3o`WZ2PCooooo0ol9jPX8
ooooo`03o`000?oooooooooo00?ooooo00Co0000oh]BQol0003o00001On;DXL00ol0003o2NX:o`WZ
2P05ojO0j`?o2NX:7Oooool2o`WZ2P;o00000oo3OXH00ol0003o`gj6ol=nQP06ol=nQP04o`000?l0
06Go001Uo`0000Wo`gj600?o0000ol=nQ_o3OXH01Oo3OXH01?l0003o`gj6ol=nQ_o3OXH2o`0000;o
SEJ:00Co2NX:oheFR_l9jP[o00001_n=EXX00ol9jP[oSEJ:oheFRP0IoheFRP04o`000?oooooooooo
o`0006kooooo003Looooo`?o2NX:4_ooool5o`WZ2Q;ooooo0ol9jPX2ooooo`Co2NX:0oooool4o`WZ
2Pcooooo00Co0000oooooooooooooooo0ol000000on;DXOo0000oh]BQ`04oh]BQ`03o`000?nW`>_o
Yl3[00;oYl3[0ol9jPX00onW`>_o0000o`00000Jooooo`?o2NX:1?ooool2o`000003ol=nQ_l0003o
`gj600Oo`gj600?o0000o`00IOl000002Oo3OXH00ol0003o`gj6ol=nQP06ol=nQP04o`000?o3OXKo
0000o`0000GoSEJ:00?o2NX:o`000?l9jPX01on=EXX00ol9jP[oSEJ:oheFRP0HoheFRP05o`000?oo
ooooooooooooool00000KOooool00=[ooooo0_l9jPXBooooo`Ko2NX:4Oooool3o`WZ2P;ooooo0ol9
jPX4ooooo`?o2NX:4?ooool01_l0003oooooo`000?l0003oooooo`0000?oRe:700Co0000oh]BQon;
DXOoRe:70_l000001?nW`>_o2NX:o`WZ2_l9jPX4ojO0j`;o00005oooool3o`WZ2PWooooo0ol00007
ol=nQP03o`000?l006Go000000Wo`gj600?o0000ol=nQ_o3OXH01Oo3OXH00ol0003o`gj6o`000008
oheFRP03o`WZ2_l0003oSEJ:00OoSEJ:00?o2NX:oheFR_n=EXX06?n=EXX01Ol0003ooooooooooooo
oooo000006cooooo003Hooooo`;o2NX:4_ooool5o`WZ2Q7ooooo0ol9jPX2ooooo`?o2NX:1?ooool3
o`WZ2QCooooo00Go0000ooooool9jP[o2NX:o`000004oh]BQ`04o`000?n;DXOo2NX:o`0000;o2NX:
1?nW`>/3o`000003ooooool0003ooooo01?ooooo0ol9jPX?ooooo`?o00001?o3OXH2o`0000Wo`gj6
00?o0000ol=nQ_o3OXH01_o3OXH2o`000003oheFR_l9jP[oSEJ:00OoSEJ:00?o2NX:oheFR_n=EXX0
1on=EXX00ol9jP[oSEJ:oheFRP0EoheFRP?o00001?ooool00ol0003oooooooooo`1Yooooo`00eOoo
ool3o`WZ2Q7ooooo1Ol9jPXAooooo`?o2NX:0_ooool3o`WZ2PCooooo0ol9jPXEooooo`;o2NX:00Ko
0000o`WZ2_ooooooooooo`000?n;DXL3o`WZ2P08o`000?l9jP[oRe:7oh]BQol0003oooooo`000?nW
`>/2o`0000Cooooo00?o0000ooooooooool03_ooool4o`WZ2QGooooo0ol000000oo3OXKo0000o`00
0009ol=nQP04o`000?o3OXKo`gj6ol=nQPGo00000on=EXX2o`WZ2POoSEJ:00?o0000o`WZ2_n=EXX0
2?n=EXX00ol9jP[oSEJ:oheFRP0@oheFRPCo00000_n=EXX00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo06Wooooo003Cooooo`;o2NX:4_ooool5o`WZ2Q3ooooo0ol9jPX2ooooo`?o2NX:1?oo
ool3o`WZ2QCooooo1?l9jPX3ooooo`03o`000?l9jP[o2NX:00;o00000_n;DXL3o`0000;oRe:700Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0;ooooo`?o2NX:6_ooool00ol9jP[ooooo
o`00000?o`000004o`WZ2_n=EX[o2NX:o`0000GoSEJ:00?o2NX:oheFR_n=EXX01On=EXX00ol0003o
2NX:oheFRP08oheFRP03o`WZ2_n=EX[oSEJ:00coSEJ:1?l00006oheFRP;o00000oooool00ol0003o
ooooooooo`1Yooooo`00dOooool2o`WZ2Q7ooooo1Ol9jPX@ooooo`?o2NX:0_ooool3o`WZ2P?ooooo
1?l9jPXDooooo`?o2NX:1?ooool4o`WZ2P03o`000?oooooo000000?o00000_n;DXL01?l0003oRe:7
oh]BQol00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool3o`WZ2Qgo
oooo00?o2NX:ooooooooool00oooool00ol0003oSEJ:oheFRP02oheFRP03o`WZ2_n=EX[oSEJ:00Go
SEJ:00?o2NX:o`000?l000001_n=EXX00ol9jP[oSEJ:oheFRP04oheFRP03o`000?n=EX[o2NX:00Wo
SEJ:00?o2NX:oheFR_n=EXX02?n=EXX3o`0000[oSEJ:00?o0000ojO0jol000000_ooool00ol0003o
ooooooooo`1Yooooo`00c_ooool3o`WZ2Q3ooooo1Ol9jPX@ooooo`?o2NX:0_ooool3o`WZ2P?ooooo
0ol9jPXDooooo`Co2NX:0oooool4o`WZ2PGooooo0_l00006oh]BQ`03o`000?n;DXOo000000;ooooo
00?o0000ooooooooool00_ooool3o`0000Oooooo0ol9jPXQooooo`05o`WZ2_ooooooooooooooool0
00001_n=EXX00ol9jP[oSEJ:oheFRP05oheFRP03o`WZ2_n=EX[oSEJ:00KoSEJ:00?o2NX:oheFR_n=
EXX00on=EXX01?l0003oSEJ:oheFR_l9jPX9oheFRP03o`WZ2_n=EX[oSEJ:00CoSEJ:0ol0000=oheF
RP06o`000?nW`>_oYl3[o`000?oooooo0000Joooool00<cooooo0_l9jPXAooooo`Go2NX:3oooool3
o`WZ2P;ooooo0ol9jPX3ooooo`?o2NX:4oooool4o`WZ2PCooooo0ol9jPX9ooooo`;o00001on;DXL2
o`0000;ooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooooooo00;ooooo0ol9jPXU
ooooo`03o`WZ2_oooooo000000OoSEJ:00?o2NX:oheFR_n=EXX01_n=EXX00ol9jP[oSEJ:oheFRP06
oheFRP03o`WZ2_n=EX[oSEJ:00;oSEJ:00Go0000oheFR_n=EX[oSEJ:o`WZ2P09oheFRP03o`WZ2_n=
EX[oSEJ:00?o00003on=EXX01Ol0003oYl3[ojO0jonW`>_o000000;ooooo00?o0000ooooooooool0
J?ooool00<[ooooo0_l9jPX@ooooo`Go2NX:3oooool3o`WZ2P03ooooool9jP[o2NX:00;o2NX:0ooo
ool3o`WZ2Q;ooooo1?l9jPX4ooooo`Co2NX:3Oooool2o`0000GoRe:70ol00002ooooo`;o00001?oo
ool00ol0003oooooooooo`03o`WZ2RWooooo00?o2NX:o`000?n=EXX01on=EXX00ol9jP[oSEJ:oheF
RP05oheFRP03o`WZ2_n=EX[oSEJ:00OoSEJ:00Go2NX:oheFR_n=EX[oSEJ:o`000004oheFRP03o`WZ
2_n=EX[oSEJ:00KoSEJ:00?o0000o`WZ2_l000004_n=EXX00ol0003oYl3[ojO0j`02ojO0j`03o`00
0?oooooo000006[ooooo0038ooooo`;o2NX:4?ooool4o`WZ2Poooooo0ol9jPX01?oooooo2NX:o`WZ
2_l9jPX3ooooo`Co2NX:4_ooool3o`WZ2PCooooo1?l9jPXAooooo`;o000000?oRe:7o`000?l00000
0_l00003ooooo`03o`000?oooooo000000?ooooo0_l00003o`WZ2Rcooooo00?o0000o`WZ2_n=EXX0
2?n=EXX00ol9jP[oSEJ:oheFRP05oheFRP03o`WZ2_n=EX[oSEJ:00KoSEJ:00Go2NX:oheFR_n=EX[o
SEJ:o`000005oheFRP03o`WZ2_n=EX[oSEJ:00;oSEJ:1Ol0000CoheFRP03o`000?nW`>_oYl3[00?o
Yl3[0_l0001Zooooo`00aOooool3o`WZ2Poooooo1Ol9jPX>ooooo`?o2NX:00Coooooo`WZ2_l9jP[o
2NX:0oooool3o`WZ2Q;ooooo1?l9jPX3ooooo`Co2NX:5_ooool2o`0000Sooooo00?o0000ooooool0
00000_l00002o`WZ2Roooooo00?o0000oheFR_l9jPX02On=EXX00ol9jP[oSEJ:oheFRP05oheFRP03
o`WZ2_n=EX[oSEJ:00KoSEJ:00Co2NX:oheFR_n=EX[o00001On=EXX00ol9jP[oSEJ:o`000002o`00
01SoSEJ:00?o0000ojO0jonW`>/00onW`>/2o`0006[ooooo0033ooooo`;o2NX:3oooool5o`WZ2Pko
oooo0ol9jPX01?oooooo2NX:o`WZ2_l9jPX3ooooo`?o2NX:4Oooool4o`WZ2P?ooooo1?l9jPXKoooo
o`03o`000?oooooooooo00Gooooo1?l000000ol9jP[o0000o`00000`ooooo`03o`000?n=EX[o2NX:
00[oSEJ:00?o2NX:oheFR_n=EXX01On=EXX00ol9jP[oSEJ:oheFRP06oheFRP03o`WZ2_n=EX[o0000
00CoSEJ:0_l000000ol9jP[oSEJ:oheFRP0IoheFRP03o`000?nW`>_oYl3[00?o000000?oooooo`00
0?ooool0JOooool00<7ooooo0_l9jPX?ooooo`Co2NX:3_ooool3o`WZ2P04ooooool9jP[o2NX:o`WZ
2P?ooooo0ol9jPXAooooo`?o2NX:0oooool4o`WZ2R3ooooo00?o0000ooooooooool01?l00002o`WZ
2P?o0000<Oooool01Ol0003oSEJ:oheFR_n=EX[o2NX:00[oSEJ:00?o2NX:oheFR_n=EXX01?n=EXX0
0ol9jP[oSEJ:oheFRP07oheFRP03o`WZ2_l0003o000000?o00000on=EXX00ol9jP[oSEJ:oheFRP0G
oheFRPCo00001?ooool00ol0003oooooooooo`1Xooooo`00__ooool3o`WZ2Pkooooo1Ol9jPX=oooo
o`?o2NX:00Coooooo`WZ2_l9jP[o2NX:0_ooool4o`WZ2Q3ooooo1?l9jPX2ooooo`Co2NX:9Oooool3
o`000003o`WZ2_l0003o000000;o0000=?ooool00ol0003oSEJ:oheFRP02oheFRP03o`WZ2_n=EX[o
SEJ:00OoSEJ:00?o2NX:oheFR_n=EXX01On=EXX00ol9jP[oSEJ:oheFRP05oheFRP;o000000?o2NX:
o`000?n=EXX01_n=EXX00ol9jP[oSEJ:oheFRP0FoheFRP04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0J?ooool00;cooooo0_l9jPX>ooooo`Go2NX:3Oooool3o`WZ2P04ooooool9jP[o
2NX:o`WZ2P;ooooo0ol9jPX@ooooo`Co2NX:0oooool3o`WZ2ROooooo1Ol9jPX2o`0003Oooooo00?o
0000oheFR_n=EXX00on=EXX00ol9jP[oSEJ:oheFRP07oheFRP03o`WZ2_n=EX[oSEJ:00GoSEJ:00?o
2NX:oheFR_n=EXX01?l00002oheFRP03o`000?n=EX[oSEJ:00OoSEJ:00?o2NX:oheFR_n=EXX05On=
EXX01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0J?ooool00;[ooooo0_l9
jPX>ooooo`Co2NX:3Oooool3o`WZ2P04ooooool9jP[o2NX:o`WZ2P;ooooo0ol9jPX@ooooo`?o2NX:
0oooool4o`WZ2RGooooo1Ol9jPXmooooo`03o`000?n=EX[oSEJ:00GoSEJ:00?o2NX:oheFR_n=EXX0
1on=EXX00ol9jP[oSEJ:oheFRP04oheFRP03o`000?l9jP[o000000KoSEJ:00?o0000oheFR_n=EXX0
2?n=EXX00ol9jP[oSEJ:oheFRP0CoheFRP03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
0000J_ooool00;Sooooo0_l9jPX=ooooo`Go2NX:2oooool8o`WZ2P;ooooo0ol9jPX?ooooo`Co2NX:
0_ooool4o`WZ2RCooooo1Ol9jPY2ooooo`03o`000?n=EX[oSEJ:00KoSEJ:00?o2NX:oheFR_n=EXX0
1on=EXX00ol9jP[oSEJ:oheFRP03o`0000;oSEJ:00?o2NX:oheFR_n=EXX01?n=EXX00ol0003oSEJ:
oheFRP08oheFRP03o`WZ2_n=EX[oSEJ:01?oSEJ:00?o0000ooooooooool01?ooool00ol0003ooooo
o`00001Zooooo`00]Oooool3o`WZ2Pgooooo1?l9jPX;ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:
0oooool3o`WZ2Pkooooo1?l9jPX2ooooo`Co2NX:8oooool5o`WZ2TOooooo00?o0000oheFR_n=EXX0
1on=EXX00ol9jP[oSEJ:oheFRP06oheFRP03o`000?l9jP[o000000GoSEJ:00?o2NX:oheFR_n=EXX0
1?n=EXX00ol0003oSEJ:oheFRP09oheFRP03o`WZ2_n=EX[oSEJ:01;oSEJ:00?o0000ooooooooool0
1Oooool2o`0006[ooooo002cooooo`;o2NX:3Oooool5o`WZ2P[ooooo0ol9jPX01?oooooo2NX:o`WZ
2_l9jPX2ooooo`Co2NX:3Oooool4o`WZ2P;ooooo1?l9jPXRooooo`Go2NX:C?ooool00ol0003oSEJ:
oheFRP07oheFRP03o`WZ2_n=EX[oSEJ:00?oSEJ:0ol000000on=EX[o0000oheFRP06oheFRP03o`WZ
2_n=EX[oSEJ:00?oSEJ:00?o0000oheFR_n=EXX02_n=EXX00ol9jP[oSEJ:oheFRP0@oheFRP03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0J?ooool00;7ooooo0_l9jPX<ooooo`Go2NX:2_oo
ool3o`WZ2P04ooooool9jP[o2NX:o`WZ2P;ooooo0ol9jPX>ooooo`?o2NX:0_ooool4o`WZ2R7ooooo
1Ol9jPYAooooo`03o`000?n=EX[oSEJ:00SoSEJ:00?o2NX:oheFR_l000000_l0000=oheFRP03o`WZ
2_n=EX[oSEJ:00?oSEJ:00?o0000oheFR_n=EXX02_n=EXX00ol9jP[oSEJ:oheFRP0?oheFRP03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0J?ooool00:kooooo0ol9jPX<ooooo`Co2NX:2_oo
ool3o`WZ2P04ooooool9jP[o2NX:o`WZ2P;ooooo0ol9jPX=ooooo`Co2NX:0_ooool3o`WZ2R7ooooo
1?l9jPYEooooo`03o`000?n=EX[oSEJ:00SoSEJ:0_l000000ol9jP[oSEJ:oheFRP0?oheFRP03o`WZ
2_n=EX[oSEJ:00;oSEJ:00?o0000oheFR_n=EXX02on=EXX00ol9jP[oSEJ:oheFRP0>oheFRP03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0JOooool00:cooooo0_l9jPX<ooooo`Go2NX:2Ooo
ool3o`WZ2P04ooooool9jP[o2NX:o`WZ2P;ooooo0ol9jPX<ooooo`Co2NX:0_ooool4o`WZ2Qoooooo
1Ol9jPYIooooo`03o`000?n=EX[oSEJ:00GoSEJ:0ol00003oheFRP03o`WZ2_n=EX[oSEJ:00ooSEJ:
00Go2NX:oheFR_n=EX[oSEJ:o`00000=oheFRP03o`000?l9jP[oSEJ:00goSEJ:00?o0000ooooool0
00001oooool00ol0003oooooooooo`1Yooooo`00Z_ooool2o`WZ2Pcooooo1?l9jPX9ooooo`?o2NX:
00Goooooo`WZ2_l9jP[o2NX:ooooo`04o`WZ2Pcooooo0ol9jPX2ooooo`Co2NX:7_ooool5o`WZ2Uko
oooo00?o0000oheFR_n=EXX00_n=EXX3o`0000OoSEJ:00?o2NX:oheFR_n=EXX03_n=EXX01Ol9jP[o
SEJ:oheFR_n=EX[o000000goSEJ:0_l0000>oheFRP04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0JOooool00:Sooooo0_l9jPX;ooooo`Co2NX:2Oooool7o`WZ2P04ooooool9jP[o2NX:
o`WZ2Pcooooo1?l9jPX00ooooooo2NX:o`WZ2P02o`WZ2Qgooooo1Ol9jPYSooooo`03o`000?n=EX[o
000000;o00002on=EXX00ol9jP[oSEJ:oheFRP0>oheFRP04o`WZ2_n=EX[oSEJ:o`0001coSEJ:00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06[ooooo002U
ooooo`?o2NX:2_ooool5o`WZ2PSooooo1_l9jPX2ooooo`?o2NX:2oooool4o`WZ2P03ooooool9jP[o
2NX:00;o2NX:7?ooool5o`WZ2VSooooo0_l0000>oheFRP03o`WZ2_n=EX[oSEJ:00ooSEJ:00?o2NX:
oheFR_l000006on=EXX00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000K?oo
ool00:?ooooo0_l9jPX;ooooo`Co2NX:2?ooool6o`WZ2P;ooooo0ol9jPX:ooooo`Co2NX:00?ooooo
o`WZ2_l9jPX00_l9jPXKooooo`Go2NX:KOooool00ol0003oSEJ:oheFRP0>oheFRP03o`WZ2_n=EX[o
SEJ:00ooSEJ:00?o2NX:o`000?l000006_n=EXX00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0006cooooo002Qooooo`;o2NX:2_ooool4o`WZ2PSooooo1_l9jPX00ooooooo2NX:o`WZ2P02
o`WZ2P[ooooo0ol9jPX00ooooooo2NX:o`WZ2P02o`WZ2Q[ooooo1Ol9jPYbooooo`03o`000?n=EX[o
SEJ:00ooSEJ:00?o2NX:oheFR_n=EXX03on=EXX00ol9jP[o0000oheFRP0HoheFRP03o`000?oooooo
oooo00Oooooo0_l0001]ooooo`00W_ooool3o`WZ2P[ooooo1?l9jPX7ooooo`Ko2NX:00Coooooo`WZ
2_l9jP[o2NX:2_ooool4o`WZ2P04ooooool9jP[o2NX:o`WZ2QWooooo1Ol9jPYhooooo`03o`000?n=
EX[oSEJ:00ooSEJ:00?o2NX:oheFR_n=EXX03_n=EXX00ol0003oSEJ:oheFRP0HoheFRP03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0Joooool009cooooo0_l9jPX:ooooo`Co2NX:1oooool6
o`WZ2P04ooooool9jP[o2NX:o`WZ2PWooooo1?l9jPX00ooooooo2NX:o`WZ2P02o`WZ2QSooooo1?l9
jPYmooooo`04o`000?n=EX[oSEJ:o`0000ooSEJ:00?o2NX:oheFR_n=EXX03On=EXX00ol0003oSEJ:
oheFRP0GoheFRP03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Joooool009[ooooo0_l9
jPX9ooooo`Co2NX:1oooool6o`WZ2P04ooooool9jP[o2NX:o`WZ2PWooooo0ol9jPX00ooooooo2NX:
o`WZ2P02o`WZ2QOooooo1Ol9jPZ1ooooo`03o`000?n=EX[oSEJ:017oSEJ:00?o2NX:o`000?n=EXX0
3On=EXX00ol0003oSEJ:oheFRP0EoheFRP;o00002_ooool00ol0003oooooooooo`1/ooooo`00V?oo
ool2o`WZ2PWooooo1?l9jPX6ooooo`Ko2NX:00Coooooo`WZ2_l9jP[o2NX:2?ooool8o`WZ2QKooooo
1Ol9jPZ7ooooo`03o`000?n=EX[oSEJ:013oSEJ:00?o0000o`WZ2_n=EXX03On=EXX00ol0003oSEJ:
oheFRP0DoheFRP04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0KOooool007_ooooo
1Ol0000Eooooo`?o2NX:2?ooool4o`WZ2PKooooo2_l9jPX7ooooo`So2NX:5Oooool5o`WZ2Xcooooo
00?o0000oheFR_n=EXX08?n=EXX00ol0003oSEJ:oheFRP0CoheFRP03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`00N?ooool4o`0000;ooooo1?l0
000Aooooo`;o2NX:2Oooool3o`WZ2PKooooo1Ol9jPX01?oooooo2NX:o`WZ2_l9jPX7ooooo`So2NX:
5?ooool5o`WZ2Y7ooooo00?o0000oheFR_n=EXX08?n=EXX00ol0003oSEJ:oheFRP0BoheFRP03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1^ooooo`00M_oo
ool8o`0000;ooooo0ol0000>ooooo`;o2NX:2?ooool4o`WZ2PGooooo1Ol9jPX01?oooooo2NX:o`WZ
2_l9jPX7ooooo`?o2NX:00Coooooo`WZ2_l9jP[o2NX:4oooool5o`WZ2YOooooo00?o0000oheFR_n=
EXX07on=EXX00ol0003oSEJ:oheFRP0AoheFRP03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1_ooooo`00M?ooool4o`000003ooooool0003o000000;ooooo
0ol00002oh]BQ`03o`000?oooooooooo00Wooooo0ol9jPX7ooooo`Co2NX:1Oooool5o`WZ2P04oooo
ool9jP[o2NX:o`WZ2PKooooo2?l9jPXAooooo`Go2NX:W?ooool00ol0003oSEJ:oheFRP0OoheFRP03
o`000?n=EX[oSEJ:013oSEJ:00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000
077ooooo001cooooo`;o00000_ooool3o`000003ooooool0003o000000CoRe:700?o0000ooooool0
00002?ooool2o`WZ2PSooooo0ol9jPX5ooooo`Wo2NX:1Oooool8o`WZ2Q7ooooo1?l9jPZRooooo`03
o`000?n=EX[oSEJ:01koSEJ:00?o0000oheFR_n=EXX03_n=EXX2o`0000_ooooo00?o0000ooooool0
0000L_ooool007?ooooo1?l00002ooooo`03o`000?oooooo000000CoRe:700?o0000ooooool00000
0_l00005ooooo`;o2NX:1oooool4o`WZ2PCooooo2?l9jPX6ooooo`Oo2NX:4?ooool5o`WZ2ZOooooo
00?o0000oheFR_n=EXX07On=EXX00ol0003oSEJ:oheFRP0=oheFRP03o`000?oooooo000000cooooo
00?o0000ooooooooool0LOooool007;ooooo0_l00005ooooo`03o`000?oooooo000000CoRe:70_l0
0002ooooo`04o`000?ooooooooooooooo`;o2NX:1oooool3o`WZ2PCooooo2?l9jPX5ooooo`Oo2NX:
3oooool5o`WZ2Zcooooo0_l0000NoheFRP03o`000?n=EX[oSEJ:00_oSEJ:0_l00003ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0L_ooool007;ooooo00?o0000ooooooooool00_oo
ool4o`0000CoRe:700?o0000ooooooooool00oooool3o`WZ2PKooooo1?l9jPX3ooooo`So2NX:1?oo
ool7o`WZ2Pkooooo1Ol9jPZbooooo`;o00007On=EXX00ol0003oSEJ:oheFRP0:oheFRP03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1cooooo`00L_ooool0
0ol0003oooooo`000002o`0000;oYl3[0_l00004oh]BQ`04o`000?ooooooooooooooo`;o2NX:0_l0
0004ooooo`Co2NX:0oooool8o`WZ2PCooooo1_l9jPX=ooooo`Go2NX:]oooool00ol0003oooooo`00
000LoheFRP03o`000?n=EX[oSEJ:00SoSEJ:0_l00008ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0M?ooool007;ooooo0_l00005ojO0j`;o00000on;DXL00ol0003oooooooooo`02
o`WZ2P04o`000?ooooooooooo`0000;ooooo0ol9jPX3ooooo`Oo2NX:1?ooool7o`WZ2P_ooooo1Ol9
jPZmooooo`03o`000?oooooo000001_oSEJ:00?o0000oheFR_n=EXX01on=EXX00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0MOooool007;ooooo00?o0000
ojO0jonW`>/00onW`>/3o`0000?oRe:70ol9jPX5ooooo`Co2NX:0_ooool7o`WZ2P?ooooo1ol9jPX:
ooooo`Go2NX:`oooool00ol0003oooooo`00000JoheFRP03o`000?n=EX[oSEJ:00GoSEJ:0_l0000<
ooooo`05o`000?ooooooooooooooool00000N?ooool007;ooooo0_l000001OnW`>_o0000o`000?l0
003oYl3[00;o000000?oRe:7o`WZ2_l9jPX00_l00004ooooo`?o2NX:00?o0000ooooool9jPX01_l9
jPX2ooooo`Oo2NX:2Oooool5o`WZ2/Wooooo0ol0000IoheFRP03o`000?n=EX[oSEJ:00?oSEJ:0_l0
00000ooooooo0000ooooo`0<ooooo`03o`000?oooooo000007Wooooo001booooo`Co00000onW`>/5
o`0000;ooooo00Ko0000o`WZ2_l9jP[o2NX:o`000?ooool7o`WZ2P;ooooo1_l9jPX9ooooo`Co2NX:
c_ooool00ol0003oooooo`000002o`0001OoSEJ:00?o0000oheFR_n=EXX01?l00003ooooo`03o`00
0?oooooooooo00[ooooo0_l0001jooooo`00L_ooool01Ol0003ooooooooooooooooo000000?oYl3[
1?l00004o`WZ2P03ooooool9jP[o2NX:00Go2NX:00?oooooo`WZ2_l9jPX01?l9jPX8ooooo`Go2NX:
doooool3o`000004ooooool0003o0000o`0001CoSEJ:0ol00003ooV^IP03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1jooooo`00L_ooool00ol0003ooooo
ooooo`02o`WZ2PGo00000ol9jPX00ooooooo2NX:o`WZ2P04o`WZ2P03ooooool9jP[o2NX:00Co2NX:
1oooool5o`WZ2]Wooooo00?o0000ooooool000000oooool2o`0000koSEJ:1Ol00005ooV^IP03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1kooooo`00L_oo
ool00ol0003o2NX:o`000006o`000003o`WZ2_l0003o000000Go2NX:00?oooooo`WZ2_l9jPX00ol9
jPX6ooooo`Go2NX:goooool3o`0000Cooooo3_l00004ooooo`03o`000?oi[VKonJiV00?onJiV00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`;o0000O_ooool006oooooo0ol9jPX2
o`0000Co2NX:1?l0000:o`WZ2P;ooooo00?o0000ooooool9jPX01?l9jP[Vooooo`;o00000oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooV^I_oi[VH00_oi[VH0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000P?ooool006cooooo0ol9jPX2
ooooo`05o`WZ2_l0003o2NX:o`WZ2_ooool00_l9jPX5o`0000Go2NX:00?o0000ooooooooool01Ol9
jP[/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oi[VKonJiV00;onJiV00?o0000ooooooooool01Oooool00ol0003oooooo`00
0021ooooo`00JOooool3o`WZ2P;ooooo1?l9jPX00ooooooo0000o`WZ2P03o`WZ2PCo00000_l9jPX3
o`0000Co2NX:1?ooool00ol0003oooooooooo`3[ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`05o`000?oi[VKonJiVooV^I_l000001ooo
ool2o`0008;ooooo001Vooooo`?o2NX:0_ooool4o`WZ2P05ooooool9jP[o2NX:o`WZ2_l000000_l9
jPX:o`0000;oYl3[0_l00003ooooo`?o0000k_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool01?l0003onJiVooV^I_l00005ooooo`;o0000
Q?ooool006?ooooo0ol9jPX2ooooo`Co2NX:00?oooooo`WZ2_l9jPX01Ol9jPX2o`0000;o2NX:00Co
ooooo`000?l0003oRe:71?l00004ojO0j`?o00000_ooool00ol0003oooooooooo`3]ooooo`;o0000
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooV^I_l00000
0_ooool3o`0008Kooooo001Pooooo`?o2NX:0_ooool4o`WZ2P03ooooool9jP[o2NX:00So2NX:00?o
0000ooooool9jPX00_l9jPX00ooooooo0000o`000003o`0000OoYl3[1?l0003aooooo`?o000000?o
ooooo`000?ooool01_ooool00ol0003oooooooooo`08ooooo`Co0000ROooool005gooooo0ol9jPX2
ooooo`Co2NX:00?oooooo`WZ2_l9jPX02Ol9jPX01?oooooo2NX:o`000?l9jPX2ooooo`?o000000Co
Re:7o`000?l0003ooooo0_l00006ojO0j`?o0000m?ooool3o`0000Oooooo00?o0000ooooooooool0
0oooool6o`0008_ooooo001Jooooo`?o2NX:0_ooool3o`WZ2P03ooooool9jP[o2NX:00[o2NX:00Co
ooooo`WZ2_l9jP[o2NX:0_ooool3o`0000;ooooo00?o0000oh]BQon;DXL00_l00002ooooo`03o`00
0?nW`>_oYl3[00?o00000_ooool00ol0003oooooooooo`3eooooo`go0000TOooool005Oooooo0ol9
jPX2ooooo`?o2NX:00?oooooo`WZ2_l9jPX02_l9jPX01?oooooo2NX:o`WZ2_l9jPX5ooooo`05o`00
0?ooooooooooooooool000000on;DXL2o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo0?oo
ooooU?ooool005Cooooo0ol9jPX2ooooo`?o2NX:00?oooooo`WZ2_l9jPX02_l9jPX01?oooooo2NX:
o`WZ2_l9jPX8ooooo`05o`000?ooooooooooooooool000000_n;DXL3o`0000?ooooo00?o0000oooo
ooooool00_ooool3o`000?ooooooU_ooool0057ooooo0ol9jPX2ooooo`?o2NX:00?oooooo`WZ2_l9
jPX02_l9jPX01?oooooo2NX:o`WZ2_l9jPX<ooooo`03o`000?oooooooooo00?o00000on;DXL01?l0
003oooooo`000?ooool4o`0000;ooooo00?o0000ooooooooool0oooooonDooooo`00C_ooool3o`WZ
2P;ooooo0ol9jPX00ooooooo2NX:o`WZ2P09o`WZ2P03ooooool9jP[o2NX:00;o2NX:4?ooool3o`00
00CoRe:71Ol00004ooooo`;o0000oooooonGooooo`00Boooool3o`WZ2P03ooooool9jP[o2NX:00;o
2NX:00?oooooo`WZ2_l9jPX02Ol9jPX01?oooooo2NX:o`WZ2_l9jPXEooooo`;o000000CoRe:7o`00
0?l0003o00000oooool2o`000003ooooool0003o000000;o0000oooooonHooooo`00B?ooool3o`WZ
2P03ooooool9jP[o2NX:00ko2NX:00Coooooo`WZ2_l9jP[o2NX:6Oooool2o`0000Kooooo1_l0003o
oooooiWooooo0015ooooo`?o2NX:00?oooooo`WZ2_l9jPX03_l9jPX01?oooooo2NX:o`WZ2_l9jPXM
ooooo`03o`000?oooooooooo00Oo0000oooooonLooooo`00@_ooool3o`WZ2P03ooooool9jP[o2NX:
00ko2NX:00Coooooo`WZ2_l9jP[o2NX:8Oooool6o`000?ooooooWoooool003oooooo0ol9jPX00ooo
oooo2NX:o`WZ2P0>o`WZ2P04ooooool9jP[o2NX:o`WZ2_oooooobOooool003cooooo0ol9jPX00ooo
oooo2NX:o`WZ2P0=o`WZ2P03ooooool9jP[o2NX:00;o2NX:ooooooo<ooooo`00>_ooool2o`WZ2P03
ooooool9jP[o2NX:00go2NX:00Coooooo`WZ2_l9jP[o2NX:ooooooo@ooooo`00>oooool>o`WZ2P04
ooooool9jP[o2NX:o`WZ2_oooooodoooool003[ooooo00?o2NX:ooooool9jPX02Ol9jPX01?oooooo
2NX:o`WZ2_l9jP[oooooomKooooo000kooooo`So2NX:00Coooooo`WZ2_l9jP[o2NX:oooooooIoooo
o`00>Oooool2o`WZ2P03ooooool9jP[o2NX:00;o2NX:00Coooooo`WZ2_l9jP[o2NX:oooooooLoooo
o`00>oooool2o`WZ2P04ooooool9jP[o2NX:o`WZ2_oooooogoooool003cooooo0_l9jP[oooooon;o
oooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooo
oooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Ooo
ool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooo
oooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQoooo
o`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00oooooooo
ooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo
003ooooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooo
oooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool0
0?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooo
oolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00
ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00oooooooooooo
ob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003o
oooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo
8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oo
oooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQ
ooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00oooo
ooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7o
oooo003ooooooooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooo
oooooooo8Oooool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Ooo
ool00?oooooooooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooo
oooooolQooooo`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00?oooooooooooolQoooo
o`00ooooooooooooob7ooooo003ooooooooooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 542.125}, {305.312, 0}} -> {0.0188125, 0.20144, \
0.00181111, 0.00181111}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["interference = FindInterference[system]", "Input",
  CellLabel->"In[32]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 7, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 1, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 7, SurfaceNumber -> 1, 
        WaveFrontID -> 1, Source -> 1}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.659957 0.0472564 0.5 0.0472465 [
[.18739 -0.0125 -9 -9 ]
[.18739 -0.0125 9 0 ]
[.42368 -0.0125 -6 -9 ]
[.42368 -0.0125 6 0 ]
[.65996 -0.0125 -3 -9 ]
[.65996 -0.0125 3 0 ]
[.89624 -0.0125 -3 -9 ]
[.89624 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02754 -18 -4.5 ]
[-0.0125 .02754 0 4.5 ]
[-0.0125 .26377 -12 -4.5 ]
[-0.0125 .26377 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .73623 -6 -4.5 ]
[-0.0125 .73623 0 4.5 ]
[-0.0125 .97246 -12 -4.5 ]
[-0.0125 .97246 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -111 0 ]
[.5 1.0125 111 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18739 0 m
.18739 .00625 L
s
[(-10)] .18739 -0.0125 0 1 Mshowa
.42368 0 m
.42368 .00625 L
s
[(-5)] .42368 -0.0125 0 1 Mshowa
.65996 0 m
.65996 .00625 L
s
[(0)] .65996 -0.0125 0 1 Mshowa
.89624 0 m
.89624 .00625 L
s
[(5)] .89624 -0.0125 0 1 Mshowa
.125 Mabswid
.23465 0 m
.23465 .00375 L
s
.28191 0 m
.28191 .00375 L
s
.32916 0 m
.32916 .00375 L
s
.37642 0 m
.37642 .00375 L
s
.47093 0 m
.47093 .00375 L
s
.51819 0 m
.51819 .00375 L
s
.56544 0 m
.56544 .00375 L
s
.6127 0 m
.6127 .00375 L
s
.70721 0 m
.70721 .00375 L
s
.75447 0 m
.75447 .00375 L
s
.80173 0 m
.80173 .00375 L
s
.84898 0 m
.84898 .00375 L
s
.14014 0 m
.14014 .00375 L
s
.09288 0 m
.09288 .00375 L
s
.04562 0 m
.04562 .00375 L
s
.9435 0 m
.9435 .00375 L
s
.99075 0 m
.99075 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02754 m
.00625 .02754 L
s
[(-10)] -0.0125 .02754 1 0 Mshowa
0 .26377 m
.00625 .26377 L
s
[(-5)] -0.0125 .26377 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .73623 m
.00625 .73623 L
s
[(5)] -0.0125 .73623 1 0 Mshowa
0 .97246 m
.00625 .97246 L
s
[(10)] -0.0125 .97246 1 0 Mshowa
.125 Mabswid
0 .07478 m
.00375 .07478 L
s
0 .12203 m
.00375 .12203 L
s
0 .16927 m
.00375 .16927 L
s
0 .21652 m
.00375 .21652 L
s
0 .31101 m
.00375 .31101 L
s
0 .35826 m
.00375 .35826 L
s
0 .40551 m
.00375 .40551 L
s
0 .45275 m
.00375 .45275 L
s
0 .54725 m
.00375 .54725 L
s
0 .59449 m
.00375 .59449 L
s
0 .64174 m
.00375 .64174 L
s
0 .68899 m
.00375 .68899 L
s
0 .78348 m
.00375 .78348 L
s
0 .83073 m
.00375 .83073 L
s
0 .87797 m
.00375 .87797 L
s
0 .92522 m
.00375 .92522 L
s
.25 Mabswid
0 0 m
0 1 L
s
.18739 .99375 m
.18739 1 L
s
.42368 .99375 m
.42368 1 L
s
.65996 .99375 m
.65996 1 L
s
.89624 .99375 m
.89624 1 L
s
.125 Mabswid
.23465 .99625 m
.23465 1 L
s
.28191 .99625 m
.28191 1 L
s
.32916 .99625 m
.32916 1 L
s
.37642 .99625 m
.37642 1 L
s
.47093 .99625 m
.47093 1 L
s
.51819 .99625 m
.51819 1 L
s
.56544 .99625 m
.56544 1 L
s
.6127 .99625 m
.6127 1 L
s
.70721 .99625 m
.70721 1 L
s
.75447 .99625 m
.75447 1 L
s
.80173 .99625 m
.80173 1 L
s
.84898 .99625 m
.84898 1 L
s
.14014 .99625 m
.14014 1 L
s
.09288 .99625 m
.09288 1 L
s
.04562 .99625 m
.04562 1 L
s
.9435 .99625 m
.9435 1 L
s
.99075 .99625 m
.99075 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02754 m
1 .02754 L
s
.99375 .26377 m
1 .26377 L
s
.99375 .5 m
1 .5 L
s
.99375 .73623 m
1 .73623 L
s
.99375 .97246 m
1 .97246 L
s
.125 Mabswid
.99625 .07478 m
1 .07478 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .16927 m
1 .16927 L
s
.99625 .21652 m
1 .21652 L
s
.99625 .31101 m
1 .31101 L
s
.99625 .35826 m
1 .35826 L
s
.99625 .40551 m
1 .40551 L
s
.99625 .45275 m
1 .45275 L
s
.99625 .54725 m
1 .54725 L
s
.99625 .59449 m
1 .59449 L
s
.99625 .64174 m
1 .64174 L
s
.99625 .68899 m
1 .68899 L
s
.99625 .78348 m
1 .78348 L
s
.99625 .83073 m
1 .83073 L
s
.99625 .87797 m
1 .87797 L
s
.99625 .92522 m
1 .92522 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
0 0 m
0 1 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 1.0125 0 -1 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.874 .477 0 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.892 .417 0 r
.01923 .6119 m
.02012 .61735 L
.02142 .62492 L
.0228 .6325 L
.02427 .64007 L
.02581 .64764 L
.0268 .65227 L
.02745 .65521 L
.02916 .66278 L
.03096 .67035 L
.03284 .67792 L
.03437 .68386 L
.0348 .68549 L
.03685 .69306 L
.03898 .70064 L
.0412 .70821 L
.04194 .71068 L
.0435 .71578 L
.04589 .72335 L
.04836 .73092 L
.04952 .73437 L
.05092 .73849 L
.05356 .74606 L
.05628 .75363 L
.05709 .75582 L
.05909 .76121 L
.06199 .76878 L
.06466 .77556 L
.06497 .77635 L
.06804 .78392 L
.07119 .79149 L
.07223 .79395 L
.07442 .79906 L
.07774 .80663 L
.0798 .81125 L
.08114 .8142 L
.08462 .82177 L
.08737 .82763 L
.08819 .82935 L
.09183 .83692 L
.09494 .84325 L
.09556 .84449 L
.09936 .85206 L
.10251 .85822 L
.10324 .85963 L
.1072 .8672 L
.11008 .87264 L
.11123 .87477 L
.11533 .88234 L
.11766 .8866 L
.11949 .88992 L
.12372 .89749 L
.12523 .90016 L
.12801 .90506 L
.13235 .91263 L
.1328 .9134 L
.13674 .9202 L
.14037 .9264 L
.14118 .92777 L
.14565 .93534 L
.14794 .9392 L
.15015 .94291 L
.15467 .95048 L
.15551 .9519 L
.15919 .95806 L
.16308 .96457 L
.16371 .96563 L
.16821 .9732 L
.17065 .97733 L
.17268 .98077 L
.01923 .98077 L
F
.01923 .3881 m
.02012 .38265 L
.02142 .37508 L
.0228 .3675 L
.02427 .35993 L
.02581 .35236 L
.0268 .34773 L
.02745 .34479 L
.02916 .33722 L
.03096 .32965 L
.03284 .32208 L
.03437 .31614 L
.0348 .31451 L
.03685 .30694 L
.03898 .29936 L
.0412 .29179 L
.04194 .28932 L
.0435 .28422 L
.04589 .27665 L
.04836 .26908 L
.04952 .26563 L
.05092 .26151 L
.05356 .25394 L
.05628 .24637 L
.05709 .24418 L
.05909 .23879 L
.06199 .23122 L
.06466 .22444 L
.06497 .22365 L
.06804 .21608 L
.07119 .20851 L
.07223 .20605 L
.07442 .20094 L
.07774 .19337 L
.0798 .18875 L
.08114 .1858 L
.08462 .17823 L
.08737 .17237 L
.08819 .17065 L
.09183 .16308 L
.09494 .15675 L
.09556 .15551 L
.09936 .14794 L
.10251 .14178 L
.10324 .14037 L
.1072 .1328 L
.11008 .12736 L
.11123 .12523 L
.11533 .11766 L
.11766 .1134 L
.11949 .11008 L
.12372 .10251 L
.12523 .09984 L
.12801 .09494 L
.13235 .08737 L
.1328 .0866 L
.13674 .0798 L
.14037 .0736 L
.14118 .07223 L
.14565 .06466 L
.14794 .0608 L
.15015 .05709 L
.15467 .04952 L
.15551 .0481 L
.15919 .04194 L
.16308 .03543 L
.16371 .03437 L
.16821 .0268 L
.17065 .02267 L
.17268 .01923 L
.01923 .01923 L
F
.91 .355 0 r
.01923 .33208 m
.0198 .32965 L
.02161 .32208 L
.0235 .31451 L
.02547 .30694 L
.0268 .302 L
.02753 .29936 L
.02966 .29179 L
.03187 .28422 L
.03416 .27665 L
.03437 .27597 L
.03654 .26908 L
.03899 .26151 L
.04152 .25394 L
.04194 .25269 L
.04413 .24637 L
.04682 .23879 L
.04952 .23143 L
.04959 .23122 L
.05244 .22365 L
.05537 .21608 L
.05709 .21173 L
.05837 .20851 L
.06145 .20094 L
.06461 .19337 L
.06466 .19326 L
.06785 .1858 L
.07115 .17823 L
.07223 .1758 L
.07453 .17065 L
.07799 .16308 L
.0798 .15916 L
.08151 .15551 L
.0851 .14794 L
.08737 .14321 L
.08875 .14037 L
.09247 .1328 L
.09494 .12783 L
.09625 .12523 L
.10008 .11766 L
.10251 .11291 L
.10397 .11008 L
.10791 .10251 L
.11008 .09836 L
.11189 .09494 L
.1159 .08737 L
.11766 .08409 L
.11995 .0798 L
.12402 .07223 L
.12523 .06999 L
.1281 .06466 L
.13219 .05709 L
.1328 .05596 L
.13627 .04952 L
.14032 .04194 L
.14037 .04186 L
.14434 .03437 L
.14794 .02751 L
.14831 .0268 L
.1522 .01923 L
.01923 .01923 L
F
.01923 .66792 m
.0198 .67035 L
.02161 .67792 L
.0235 .68549 L
.02547 .69306 L
.0268 .698 L
.02753 .70064 L
.02966 .70821 L
.03187 .71578 L
.03416 .72335 L
.03437 .72403 L
.03654 .73092 L
.03899 .73849 L
.04152 .74606 L
.04194 .74731 L
.04413 .75363 L
.04682 .76121 L
.04952 .76857 L
.04959 .76878 L
.05244 .77635 L
.05537 .78392 L
.05709 .78827 L
.05837 .79149 L
.06145 .79906 L
.06461 .80663 L
.06466 .80674 L
.06785 .8142 L
.07115 .82177 L
.07223 .8242 L
.07453 .82935 L
.07799 .83692 L
.0798 .84084 L
.08151 .84449 L
.0851 .85206 L
.08737 .85679 L
.08875 .85963 L
.09247 .8672 L
.09494 .87217 L
.09625 .87477 L
.10008 .88234 L
.10251 .88709 L
.10397 .88992 L
.10791 .89749 L
.11008 .90164 L
.11189 .90506 L
.1159 .91263 L
.11766 .91591 L
.11995 .9202 L
.12402 .92777 L
.12523 .93001 L
.1281 .93534 L
.13219 .94291 L
.1328 .94404 L
.13627 .95048 L
.14032 .95806 L
.14037 .95814 L
.14434 .96563 L
.14794 .97249 L
.14831 .9732 L
.1522 .98077 L
.01923 .98077 L
F
.928 .29 0 r
.01923 .28653 m
.01988 .28422 L
.02208 .27665 L
.02435 .26908 L
.02669 .26151 L
.0268 .26115 L
.02911 .25394 L
.0316 .24637 L
.03416 .23879 L
.03437 .23818 L
.0368 .23122 L
.03951 .22365 L
.04194 .21701 L
.04229 .21608 L
.04514 .20851 L
.04806 .20094 L
.04952 .19722 L
.05105 .19337 L
.0541 .1858 L
.05709 .17855 L
.05722 .17823 L
.0604 .17065 L
.06365 .16308 L
.06466 .16075 L
.06695 .15551 L
.07031 .14794 L
.07223 .14367 L
.07372 .14037 L
.07718 .1328 L
.0798 .12714 L
.08069 .12523 L
.08424 .11766 L
.08737 .11104 L
.08782 .11008 L
.09144 .10251 L
.09494 .09522 L
.09508 .09494 L
.09873 .08737 L
.1024 .0798 L
.10251 .07956 L
.10606 .07223 L
.1097 .06466 L
.11008 .06386 L
.11332 .05709 L
.11689 .04952 L
.11766 .04789 L
.12041 .04194 L
.12385 .03437 L
.12523 .03127 L
.12718 .0268 L
.13038 .01923 L
.01923 .01923 L
F
.01923 .71347 m
.01988 .71578 L
.02208 .72335 L
.02435 .73092 L
.02669 .73849 L
.0268 .73885 L
.02911 .74606 L
.0316 .75363 L
.03416 .76121 L
.03437 .76182 L
.0368 .76878 L
.03951 .77635 L
.04194 .78299 L
.04229 .78392 L
.04514 .79149 L
.04806 .79906 L
.04952 .80278 L
.05105 .80663 L
.0541 .8142 L
.05709 .82145 L
.05722 .82177 L
.0604 .82935 L
.06365 .83692 L
.06466 .83925 L
.06695 .84449 L
.07031 .85206 L
.07223 .85633 L
.07372 .85963 L
.07718 .8672 L
.0798 .87286 L
.08069 .87477 L
.08424 .88234 L
.08737 .88896 L
.08782 .88992 L
.09144 .89749 L
.09494 .90478 L
.09508 .90506 L
.09873 .91263 L
.1024 .9202 L
.10251 .92044 L
.10606 .92777 L
.1097 .93534 L
.11008 .93614 L
.11332 .94291 L
.11689 .95048 L
.11766 .95211 L
.12041 .95806 L
.12385 .96563 L
.12523 .96873 L
.12718 .9732 L
.13038 .98077 L
.01923 .98077 L
F
.946 .221 0 r
.01923 .24432 m
.02101 .23879 L
.0235 .23122 L
.02606 .22365 L
.0268 .22149 L
.02868 .21608 L
.03136 .20851 L
.03411 .20094 L
.03437 .20021 L
.03691 .19337 L
.03977 .1858 L
.04194 .18012 L
.04268 .17823 L
.04564 .17065 L
.04866 .16308 L
.04952 .16095 L
.05172 .15551 L
.05482 .14794 L
.05709 .14247 L
.05796 .14037 L
.06114 .1328 L
.06434 .12523 L
.06466 .12448 L
.06757 .11766 L
.07081 .11008 L
.07223 .10677 L
.07405 .10251 L
.0773 .09494 L
.0798 .0891 L
.08054 .08737 L
.08375 .0798 L
.08692 .07223 L
.08737 .07115 L
.09005 .06466 L
.0931 .05709 L
.09494 .0524 L
.09606 .04952 L
.0989 .04194 L
.10159 .03437 L
.10251 .03168 L
.1041 .0268 L
.10638 .01923 L
.01923 .01923 L
F
.01923 .75568 m
.02101 .76121 L
.0235 .76878 L
.02606 .77635 L
.0268 .77851 L
.02868 .78392 L
.03136 .79149 L
.03411 .79906 L
.03437 .79979 L
.03691 .80663 L
.03977 .8142 L
.04194 .81988 L
.04268 .82177 L
.04564 .82935 L
.04866 .83692 L
.04952 .83905 L
.05172 .84449 L
.05482 .85206 L
.05709 .85753 L
.05796 .85963 L
.06114 .8672 L
.06434 .87477 L
.06466 .87552 L
.06757 .88234 L
.07081 .88992 L
.07223 .89323 L
.07405 .89749 L
.0773 .90506 L
.0798 .9109 L
.08054 .91263 L
.08375 .9202 L
.08692 .92777 L
.08737 .92885 L
.09005 .93534 L
.0931 .94291 L
.09494 .9476 L
.09606 .95048 L
.0989 .95806 L
.10159 .96563 L
.10251 .96832 L
.1041 .9732 L
.10638 .98077 L
.01923 .98077 L
F
.964 .15 0 r
.01923 .20151 m
.01942 .20094 L
.02201 .19337 L
.02465 .1858 L
.0268 .17971 L
.02733 .17823 L
.03005 .17065 L
.0328 .16308 L
.03437 .15878 L
.03558 .15551 L
.03838 .14794 L
.0412 .14037 L
.04194 .13839 L
.04404 .1328 L
.04688 .12523 L
.04952 .1182 L
.04972 .11766 L
.05254 .11008 L
.05535 .10251 L
.05709 .09776 L
.05811 .09494 L
.06082 .08737 L
.06346 .0798 L
.06466 .0763 L
.06601 .07223 L
.06845 .06466 L
.07074 .05709 L
.07223 .05185 L
.07285 .04952 L
.07474 .04194 L
.07634 .03437 L
.07759 .0268 L
.07839 .01923 L
.01923 .01923 L
F
.01923 .79849 m
.01942 .79906 L
.02201 .80663 L
.02465 .8142 L
.0268 .82029 L
.02733 .82177 L
.03005 .82935 L
.0328 .83692 L
.03437 .84122 L
.03558 .84449 L
.03838 .85206 L
.0412 .85963 L
.04194 .86161 L
.04404 .8672 L
.04688 .87477 L
.04952 .8818 L
.04972 .88234 L
.05254 .88992 L
.05535 .89749 L
.05709 .90224 L
.05811 .90506 L
.06082 .91263 L
.06346 .9202 L
.06466 .9237 L
.06601 .92777 L
.06845 .93534 L
.07074 .94291 L
.07223 .94815 L
.07285 .95048 L
.07474 .95806 L
.07634 .96563 L
.07759 .9732 L
.07839 .98077 L
.01923 .98077 L
F
.982 .077 0 r
.01923 .15211 m
.02057 .14794 L
.023 .14037 L
.0254 .1328 L
.0268 .12836 L
.02778 .12523 L
.03012 .11766 L
.03239 .11008 L
.03437 .10328 L
.03459 .10251 L
.03669 .09494 L
.03867 .08737 L
.04048 .0798 L
.04194 .07304 L
.0421 .07223 L
.04348 .06466 L
.04454 .05709 L
.0452 .04952 L
.04533 .04194 L
.04475 .03437 L
.04314 .0268 L
.04194 .02408 L
.03995 .01923 L
.01923 .01923 L
F
.01923 .84789 m
.02057 .85206 L
.023 .85963 L
.0254 .8672 L
.0268 .87164 L
.02778 .87477 L
.03012 .88234 L
.03239 .88992 L
.03437 .89672 L
.03459 .89749 L
.03669 .90506 L
.03867 .91263 L
.04048 .9202 L
.04194 .92696 L
.0421 .92777 L
.04348 .93534 L
.04454 .94291 L
.0452 .95048 L
.04533 .95806 L
.04475 .96563 L
.04314 .9732 L
.04194 .97592 L
.03995 .98077 L
.01923 .98077 L
F
.856 .534 0 r
.19229 .98077 m
.18731 .9732 L
.1858 .9709 L
.18233 .96563 L
.17823 .95938 L
.17736 .95806 L
.1724 .95048 L
.17065 .9478 L
.16748 .94291 L
.16308 .93609 L
.1626 .93534 L
.15777 .92777 L
.15551 .9242 L
.15299 .9202 L
.14828 .91263 L
.14794 .91208 L
.14363 .90506 L
.14037 .89968 L
.13905 .89749 L
.13455 .88992 L
.1328 .88694 L
.13012 .88234 L
.12577 .87477 L
.12523 .87381 L
.12151 .8672 L
.11766 .86023 L
.11733 .85963 L
.11323 .85206 L
.11008 .84613 L
.10922 .84449 L
.1053 .83692 L
.10251 .83142 L
.10147 .82935 L
.09773 .82177 L
.09494 .81601 L
.09408 .8142 L
.09052 .80663 L
.08737 .79978 L
.08705 .79906 L
.08367 .79149 L
.08038 .78392 L
.0798 .78256 L
.07718 .77635 L
.07407 .76878 L
.07223 .76417 L
.07106 .76121 L
.06813 .75363 L
.0653 .74606 L
.06466 .74432 L
.06255 .73849 L
.0599 .73092 L
.05733 .72335 L
.05709 .72262 L
.05485 .71578 L
.05247 .70821 L
.05017 .70064 L
.04952 .69844 L
.04796 .69306 L
.04583 .68549 L
.0438 .67792 L
.04194 .67072 L
.04185 .67035 L
.03999 .66278 L
.03822 .65521 L
.03653 .64764 L
.03493 .64007 L
.03437 .63733 L
.03342 .6325 L
.03199 .62492 L
.03064 .61735 L
.02939 .60978 L
.02821 .60221 L
.02712 .59464 L
.0268 .59228 L
.02612 .58707 L
.0252 .5795 L
.02437 .57193 L
.02361 .56435 L
.02295 .55678 L
.02236 .54921 L
.02186 .54164 L
.02145 .53407 L
.02111 .5265 L
.02086 .51893 L
.0207 .51136 L
.02061 .50379 L
.02061 .49621 L
.0207 .48864 L
.02086 .48107 L
.02111 .4735 L
.02145 .46593 L
.02186 .45836 L
.02236 .45079 L
.02295 .44322 L
.02361 .43565 L
.02437 .42807 L
.0252 .4205 L
.02612 .41293 L
.0268 .40772 L
.02712 .40536 L
.02821 .39779 L
.02939 .39022 L
.03064 .38265 L
.03199 .37508 L
.03342 .3675 L
.03437 .36267 L
.03493 .35993 L
.03653 .35236 L
.03822 .34479 L
.03999 .33722 L
.04185 .32965 L
.04194 .32928 L
.0438 .32208 L
.04583 .31451 L
.04796 .30694 L
.04952 .30156 L
.05017 .29936 L
.05247 .29179 L
.05485 .28422 L
.05709 .27738 L
.05733 .27665 L
.0599 .26908 L
.06255 .26151 L
.06466 .25568 L
.0653 .25394 L
.06813 .24637 L
.07106 .23879 L
.07223 .23583 L
.07407 .23122 L
.07718 .22365 L
.0798 .21744 L
.08038 .21608 L
.08367 .20851 L
.08705 .20094 L
.08737 .20022 L
.09052 .19337 L
.09408 .1858 L
.09494 .18399 L
.09773 .17823 L
.10147 .17065 L
.10251 .16858 L
.1053 .16308 L
.10922 .15551 L
.11008 .15387 L
.11323 .14794 L
.11733 .14037 L
.11766 .13977 L
.12151 .1328 L
.12523 .12619 L
.12577 .12523 L
.13012 .11766 L
.1328 .11306 L
.13455 .11008 L
.13905 .10251 L
.14037 .10032 L
.14363 .09494 L
.14794 .08792 L
.14828 .08737 L
.15299 .0798 L
.15551 .0758 L
.15777 .07223 L
.1626 .06466 L
.16308 .06391 L
.16748 .05709 L
.17065 .0522 L
.1724 .04952 L
.17736 .04194 L
.17823 .04062 L
.18233 .03437 L
.1858 .0291 L
.18731 .0268 L
.19229 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.838 .588 0 r
.21134 .98077 m
.20851 .97684 L
.20589 .9732 L
.20094 .96631 L
.20045 .96563 L
.19505 .95806 L
.19337 .95569 L
.18969 .95048 L
.1858 .94493 L
.18439 .94291 L
.17914 .93534 L
.17823 .93401 L
.17397 .92777 L
.17065 .92287 L
.16886 .9202 L
.16384 .91263 L
.16308 .91148 L
.15889 .90506 L
.15551 .8998 L
.15404 .89749 L
.14927 .88992 L
.14794 .88779 L
.14459 .88234 L
.14037 .87539 L
.14 .87477 L
.1355 .8672 L
.1328 .86256 L
.1311 .85963 L
.1268 .85206 L
.12523 .84925 L
.1226 .84449 L
.11849 .83692 L
.11766 .83536 L
.11448 .82935 L
.11056 .82177 L
.11008 .82084 L
.10675 .8142 L
.10303 .80663 L
.10251 .80556 L
.09941 .79906 L
.09589 .79149 L
.09494 .78942 L
.09247 .78392 L
.08914 .77635 L
.08737 .77224 L
.08591 .76878 L
.08277 .76121 L
.0798 .7538 L
.07974 .75363 L
.07679 .74606 L
.07395 .73849 L
.07223 .7338 L
.07119 .73092 L
.06854 .72335 L
.06597 .71578 L
.06466 .71179 L
.0635 .70821 L
.06112 .70064 L
.05883 .69306 L
.05709 .68706 L
.05664 .68549 L
.05454 .67792 L
.05253 .67035 L
.05061 .66278 L
.04952 .65832 L
.04877 .65521 L
.04703 .64764 L
.04538 .64007 L
.04382 .6325 L
.04235 .62492 L
.04194 .62278 L
.04096 .61735 L
.03966 .60978 L
.03845 .60221 L
.03733 .59464 L
.0363 .58707 L
.03535 .5795 L
.03449 .57193 L
.03437 .57084 L
.03372 .56435 L
.03303 .55678 L
.03243 .54921 L
.03191 .54164 L
.03148 .53407 L
.03114 .5265 L
.03088 .51893 L
.03071 .51136 L
.03062 .50379 L
.03062 .49621 L
.03071 .48864 L
.03088 .48107 L
.03114 .4735 L
.03148 .46593 L
.03191 .45836 L
.03243 .45079 L
.03303 .44322 L
.03372 .43565 L
.03437 .42916 L
.03449 .42807 L
.03535 .4205 L
.0363 .41293 L
.03733 .40536 L
.03845 .39779 L
.03966 .39022 L
.04096 .38265 L
.04194 .37722 L
.04235 .37508 L
.04382 .3675 L
.04538 .35993 L
.04703 .35236 L
.04877 .34479 L
.04952 .34168 L
.05061 .33722 L
.05253 .32965 L
.05454 .32208 L
.05664 .31451 L
.05709 .31294 L
.05883 .30694 L
.06112 .29936 L
.0635 .29179 L
.06466 .28821 L
.06597 .28422 L
.06854 .27665 L
.07119 .26908 L
.07223 .2662 L
.07395 .26151 L
.07679 .25394 L
.07974 .24637 L
.0798 .2462 L
.08277 .23879 L
.08591 .23122 L
.08737 .22776 L
.08914 .22365 L
.09247 .21608 L
.09494 .21058 L
.09589 .20851 L
.09941 .20094 L
.10251 .19444 L
.10303 .19337 L
.10675 .1858 L
.11008 .17916 L
.11056 .17823 L
.11448 .17065 L
.11766 .16464 L
.11849 .16308 L
.1226 .15551 L
.12523 .15075 L
.1268 .14794 L
.1311 .14037 L
.1328 .13744 L
.1355 .1328 L
.14 .12523 L
.14037 .12461 L
.14459 .11766 L
.14794 .11221 L
.14927 .11008 L
.15404 .10251 L
.15551 .1002 L
.15889 .09494 L
.16308 .08852 L
.16384 .08737 L
.16886 .0798 L
.17065 .07713 L
.17397 .07223 L
.17823 .06599 L
.17914 .06466 L
.18439 .05709 L
.1858 .05507 L
.18969 .04952 L
.19337 .04431 L
.19505 .04194 L
.20045 .03437 L
.20094 .03369 L
.20589 .0268 L
.20851 .02316 L
.21134 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.82 .64 0 r
.23006 .98077 m
.22414 .9732 L
.22365 .97257 L
.21827 .96563 L
.21608 .96279 L
.21245 .95806 L
.20851 .95288 L
.20669 .95048 L
.20101 .94291 L
.20094 .94281 L
.19541 .93534 L
.19337 .93255 L
.1899 .92777 L
.1858 .92206 L
.18448 .9202 L
.17914 .91263 L
.17823 .91131 L
.17391 .90506 L
.17065 .90027 L
.16878 .89749 L
.16374 .88992 L
.16308 .88891 L
.15882 .88234 L
.15551 .87718 L
.15399 .87477 L
.14927 .8672 L
.14794 .86504 L
.14466 .85963 L
.14037 .85243 L
.14015 .85206 L
.13575 .84449 L
.1328 .83931 L
.13145 .83692 L
.12726 .82935 L
.12523 .82559 L
.12318 .82177 L
.11921 .8142 L
.11766 .8112 L
.11534 .80663 L
.11157 .79906 L
.11008 .79602 L
.10791 .79149 L
.10435 .78392 L
.10251 .77992 L
.1009 .77635 L
.09754 .76878 L
.09494 .76274 L
.09429 .76121 L
.09115 .75363 L
.0881 .74606 L
.08737 .74422 L
.08515 .73849 L
.0823 .73092 L
.0798 .72404 L
.07955 .72335 L
.0769 .71578 L
.07435 .70821 L
.07223 .7017 L
.07189 .70064 L
.06953 .69306 L
.06727 .68549 L
.0651 .67792 L
.06466 .67635 L
.06302 .67035 L
.06104 .66278 L
.05915 .65521 L
.05736 .64764 L
.05709 .64646 L
.05566 .64007 L
.05405 .6325 L
.05253 .62492 L
.0511 .61735 L
.04977 .60978 L
.04952 .6083 L
.04852 .60221 L
.04737 .59464 L
.0463 .58707 L
.04533 .5795 L
.04444 .57193 L
.04365 .56435 L
.04294 .55678 L
.04232 .54921 L
.04194 .54398 L
.04179 .54164 L
.04135 .53407 L
.041 .5265 L
.04073 .51893 L
.04056 .51136 L
.04047 .50379 L
.04047 .49621 L
.04056 .48864 L
.04073 .48107 L
.041 .4735 L
.04135 .46593 L
.04179 .45836 L
.04194 .45602 L
.04232 .45079 L
.04294 .44322 L
.04365 .43565 L
.04444 .42807 L
.04533 .4205 L
.0463 .41293 L
.04737 .40536 L
.04852 .39779 L
.04952 .3917 L
.04977 .39022 L
.0511 .38265 L
.05253 .37508 L
.05405 .3675 L
.05566 .35993 L
.05709 .35354 L
.05736 .35236 L
.05915 .34479 L
.06104 .33722 L
.06302 .32965 L
.06466 .32365 L
.0651 .32208 L
.06727 .31451 L
.06953 .30694 L
.07189 .29936 L
.07223 .2983 L
.07435 .29179 L
.0769 .28422 L
.07955 .27665 L
.0798 .27596 L
.0823 .26908 L
.08515 .26151 L
.08737 .25578 L
.0881 .25394 L
.09115 .24637 L
.09429 .23879 L
.09494 .23726 L
.09754 .23122 L
.1009 .22365 L
.10251 .22008 L
.10435 .21608 L
.10791 .20851 L
.11008 .20398 L
.11157 .20094 L
.11534 .19337 L
.11766 .1888 L
.11921 .1858 L
.12318 .17823 L
.12523 .17441 L
.12726 .17065 L
.13145 .16308 L
.1328 .16069 L
.13575 .15551 L
.14015 .14794 L
.14037 .14757 L
.14466 .14037 L
.14794 .13496 L
.14927 .1328 L
.15399 .12523 L
.15551 .12282 L
.15882 .11766 L
.16308 .11109 L
.16374 .11008 L
.16878 .10251 L
.17065 .09973 L
.17391 .09494 L
.17823 .08869 L
.17914 .08737 L
.18448 .0798 L
.1858 .07794 L
.1899 .07223 L
.19337 .06745 L
.19541 .06466 L
.20094 .05719 L
.20101 .05709 L
.20669 .04952 L
.20851 .04712 L
.21245 .04194 L
.21608 .03721 L
.21827 .03437 L
.22365 .02743 L
.22414 .0268 L
.23006 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.802 .688 0 r
.24862 .98077 m
.24637 .97811 L
.24223 .9732 L
.23879 .96908 L
.23592 .96563 L
.23122 .95993 L
.22969 .95806 L
.22365 .95063 L
.22354 .95048 L
.21748 .94291 L
.21608 .94114 L
.21153 .93534 L
.20851 .93146 L
.20567 .92777 L
.20094 .92154 L
.19993 .9202 L
.19429 .91263 L
.19337 .91137 L
.18877 .90506 L
.1858 .90092 L
.18336 .89749 L
.17823 .89015 L
.17806 .88992 L
.17289 .88234 L
.17065 .87903 L
.16782 .87477 L
.16308 .86752 L
.16288 .8672 L
.15805 .85963 L
.15551 .85558 L
.15334 .85206 L
.14874 .84449 L
.14794 .84315 L
.14426 .83692 L
.14037 .83018 L
.1399 .82935 L
.13564 .82177 L
.1328 .81659 L
.13151 .8142 L
.12748 .80663 L
.12523 .80229 L
.12357 .79906 L
.11977 .79149 L
.11766 .78718 L
.11608 .78392 L
.1125 .77635 L
.11008 .77111 L
.10903 .76878 L
.10566 .76121 L
.10251 .7539 L
.1024 .75363 L
.09925 .74606 L
.0962 .73849 L
.09494 .73528 L
.09326 .73092 L
.09042 .72335 L
.08768 .71578 L
.08737 .7149 L
.08505 .70821 L
.08251 .70064 L
.08008 .69306 L
.0798 .69218 L
.07774 .68549 L
.07551 .67792 L
.07337 .67035 L
.07223 .66617 L
.07133 .66278 L
.06938 .65521 L
.06754 .64764 L
.06579 .64007 L
.06466 .63496 L
.06413 .6325 L
.06257 .62492 L
.0611 .61735 L
.05973 .60978 L
.05845 .60221 L
.05726 .59464 L
.05709 .59349 L
.05617 .58707 L
.05516 .5795 L
.05425 .57193 L
.05343 .56435 L
.05271 .55678 L
.05207 .54921 L
.05153 .54164 L
.05108 .53407 L
.05071 .5265 L
.05044 .51893 L
.05026 .51136 L
.05017 .50379 L
.05017 .49621 L
.05026 .48864 L
.05044 .48107 L
.05071 .4735 L
.05108 .46593 L
.05153 .45836 L
.05207 .45079 L
.05271 .44322 L
.05343 .43565 L
.05425 .42807 L
.05516 .4205 L
.05617 .41293 L
.05709 .40651 L
.05726 .40536 L
.05845 .39779 L
.05973 .39022 L
.0611 .38265 L
.06257 .37508 L
.06413 .3675 L
.06466 .36504 L
.06579 .35993 L
.06754 .35236 L
.06938 .34479 L
.07133 .33722 L
.07223 .33383 L
.07337 .32965 L
.07551 .32208 L
.07774 .31451 L
.0798 .30782 L
.08008 .30694 L
.08251 .29936 L
.08505 .29179 L
.08737 .2851 L
.08768 .28422 L
.09042 .27665 L
.09326 .26908 L
.09494 .26472 L
.0962 .26151 L
.09925 .25394 L
.1024 .24637 L
.10251 .2461 L
.10566 .23879 L
.10903 .23122 L
.11008 .22889 L
.1125 .22365 L
.11608 .21608 L
.11766 .21282 L
.11977 .20851 L
.12357 .20094 L
.12523 .19771 L
.12748 .19337 L
.13151 .1858 L
.1328 .18341 L
.13564 .17823 L
.1399 .17065 L
.14037 .16982 L
.14426 .16308 L
.14794 .15685 L
.14874 .15551 L
.15334 .14794 L
.15551 .14442 L
.15805 .14037 L
.16288 .1328 L
.16308 .13248 L
.16782 .12523 L
.17065 .12097 L
.17289 .11766 L
.17806 .11008 L
.17823 .10985 L
.18336 .10251 L
.1858 .09908 L
.18877 .09494 L
.19337 .08863 L
.19429 .08737 L
.19993 .0798 L
.20094 .07846 L
.20567 .07223 L
.20851 .06854 L
.21153 .06466 L
.21608 .05886 L
.21748 .05709 L
.22354 .04952 L
.22365 .04937 L
.22969 .04194 L
.23122 .04007 L
.23592 .03437 L
.23879 .03092 L
.24223 .0268 L
.24637 .02189 L
.24862 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.784 .734 0 r
.26716 .98077 m
.26151 .97453 L
.26031 .9732 L
.25394 .96607 L
.25355 .96563 L
.24689 .95806 L
.24637 .95746 L
.24033 .95048 L
.23879 .94869 L
.2339 .94291 L
.23122 .93973 L
.22758 .93534 L
.22365 .93057 L
.22138 .92777 L
.21608 .92117 L
.21531 .9202 L
.20936 .91263 L
.20851 .91153 L
.20354 .90506 L
.20094 .90161 L
.19785 .89749 L
.19337 .89139 L
.19229 .88992 L
.18686 .88234 L
.1858 .88084 L
.18156 .87477 L
.17823 .86992 L
.17638 .8672 L
.17134 .85963 L
.17065 .85859 L
.16642 .85206 L
.16308 .84681 L
.16163 .84449 L
.15696 .83692 L
.15551 .83453 L
.15242 .82935 L
.14799 .82177 L
.14794 .82168 L
.1437 .8142 L
.14037 .8082 L
.13952 .80663 L
.13546 .79906 L
.1328 .79398 L
.13152 .79149 L
.12769 .78392 L
.12523 .77891 L
.12398 .77635 L
.12039 .76878 L
.11766 .76285 L
.11691 .76121 L
.11354 .75363 L
.11028 .74606 L
.11008 .74559 L
.10714 .73849 L
.1041 .73092 L
.10251 .72686 L
.10117 .72335 L
.09834 .71578 L
.09563 .70821 L
.09494 .70625 L
.09301 .70064 L
.09051 .69306 L
.0881 .68549 L
.08737 .68313 L
.0858 .67792 L
.0836 .67035 L
.0815 .66278 L
.0798 .65638 L
.0795 .65521 L
.0776 .64764 L
.0758 .64007 L
.07409 .6325 L
.07249 .62492 L
.07223 .62366 L
.07098 .61735 L
.06957 .60978 L
.06825 .60221 L
.06703 .59464 L
.06591 .58707 L
.06488 .5795 L
.06466 .57776 L
.06395 .57193 L
.06311 .56435 L
.06236 .55678 L
.06171 .54921 L
.06115 .54164 L
.06068 .53407 L
.06031 .5265 L
.06003 .51893 L
.05985 .51136 L
.05975 .50379 L
.05975 .49621 L
.05985 .48864 L
.06003 .48107 L
.06031 .4735 L
.06068 .46593 L
.06115 .45836 L
.06171 .45079 L
.06236 .44322 L
.06311 .43565 L
.06395 .42807 L
.06466 .42224 L
.06488 .4205 L
.06591 .41293 L
.06703 .40536 L
.06825 .39779 L
.06957 .39022 L
.07098 .38265 L
.07223 .37634 L
.07249 .37508 L
.07409 .3675 L
.0758 .35993 L
.0776 .35236 L
.0795 .34479 L
.0798 .34362 L
.0815 .33722 L
.0836 .32965 L
.0858 .32208 L
.08737 .31687 L
.0881 .31451 L
.09051 .30694 L
.09301 .29936 L
.09494 .29375 L
.09563 .29179 L
.09834 .28422 L
.10117 .27665 L
.10251 .27314 L
.1041 .26908 L
.10714 .26151 L
.11008 .25441 L
.11028 .25394 L
.11354 .24637 L
.11691 .23879 L
.11766 .23715 L
.12039 .23122 L
.12398 .22365 L
.12523 .22109 L
.12769 .21608 L
.13152 .20851 L
.1328 .20602 L
.13546 .20094 L
.13952 .19337 L
.14037 .1918 L
.1437 .1858 L
.14794 .17832 L
.14799 .17823 L
.15242 .17065 L
.15551 .16547 L
.15696 .16308 L
.16163 .15551 L
.16308 .15319 L
.16642 .14794 L
.17065 .14141 L
.17134 .14037 L
.17638 .1328 L
.17823 .13008 L
.18156 .12523 L
.1858 .11916 L
.18686 .11766 L
.19229 .11008 L
.19337 .10861 L
.19785 .10251 L
.20094 .09839 L
.20354 .09494 L
.20851 .08847 L
.20936 .08737 L
.21531 .0798 L
.21608 .07883 L
.22138 .07223 L
.22365 .06943 L
.22758 .06466 L
.23122 .06027 L
.2339 .05709 L
.23879 .05131 L
.24033 .04952 L
.24637 .04254 L
.24689 .04194 L
.25355 .03437 L
.25394 .03393 L
.26031 .0268 L
.26151 .02547 L
.26716 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.755 .766 0 r
.28583 .98077 m
.28422 .97913 L
.27848 .9732 L
.27665 .97129 L
.27126 .96563 L
.26908 .96332 L
.26415 .95806 L
.26151 .9552 L
.25718 .95048 L
.25394 .94691 L
.25035 .94291 L
.24637 .93843 L
.24365 .93534 L
.23879 .92974 L
.2371 .92777 L
.23122 .92084 L
.23069 .9202 L
.22442 .91263 L
.22365 .91169 L
.2183 .90506 L
.21608 .90227 L
.21232 .89749 L
.20851 .89256 L
.20649 .88992 L
.20094 .88253 L
.2008 .88234 L
.19525 .87477 L
.19337 .87216 L
.18984 .8672 L
.1858 .8614 L
.18458 .85963 L
.17945 .85206 L
.17823 .85023 L
.17445 .84449 L
.17065 .83859 L
.16959 .83692 L
.16487 .82935 L
.16308 .82643 L
.16027 .82177 L
.15581 .8142 L
.15551 .81369 L
.15148 .80663 L
.14794 .80029 L
.14727 .79906 L
.14318 .79149 L
.14037 .78613 L
.13922 .78392 L
.13539 .77635 L
.1328 .7711 L
.13167 .76878 L
.12807 .76121 L
.12523 .75503 L
.12459 .75363 L
.12123 .74606 L
.11798 .73849 L
.11766 .73772 L
.11485 .73092 L
.11183 .72335 L
.11008 .71886 L
.10891 .71578 L
.10611 .70821 L
.10342 .70064 L
.10251 .698 L
.10084 .69306 L
.09837 .68549 L
.096 .67792 L
.09494 .67444 L
.09373 .67035 L
.09157 .66278 L
.08952 .65521 L
.08756 .64764 L
.08737 .64687 L
.08571 .64007 L
.08396 .6325 L
.08231 .62492 L
.08076 .61735 L
.0798 .61238 L
.07931 .60978 L
.07796 .60221 L
.07671 .59464 L
.07556 .58707 L
.0745 .5795 L
.07354 .57193 L
.07268 .56435 L
.07223 .56001 L
.07191 .55678 L
.07125 .54921 L
.07067 .54164 L
.07019 .53407 L
.06981 .5265 L
.06953 .51893 L
.06934 .51136 L
.06924 .50379 L
.06924 .49621 L
.06934 .48864 L
.06953 .48107 L
.06981 .4735 L
.07019 .46593 L
.07067 .45836 L
.07125 .45079 L
.07191 .44322 L
.07223 .43999 L
.07268 .43565 L
.07354 .42807 L
.0745 .4205 L
.07556 .41293 L
.07671 .40536 L
.07796 .39779 L
.07931 .39022 L
.0798 .38762 L
.08076 .38265 L
.08231 .37508 L
.08396 .3675 L
.08571 .35993 L
.08737 .35313 L
.08756 .35236 L
.08952 .34479 L
.09157 .33722 L
.09373 .32965 L
.09494 .32556 L
.096 .32208 L
.09837 .31451 L
.10084 .30694 L
.10251 .302 L
.10342 .29936 L
.10611 .29179 L
.10891 .28422 L
.11008 .28114 L
.11183 .27665 L
.11485 .26908 L
.11766 .26228 L
.11798 .26151 L
.12123 .25394 L
.12459 .24637 L
.12523 .24497 L
.12807 .23879 L
.13167 .23122 L
.1328 .2289 L
.13539 .22365 L
.13922 .21608 L
.14037 .21387 L
.14318 .20851 L
.14727 .20094 L
.14794 .19971 L
.15148 .19337 L
.15551 .18631 L
.15581 .1858 L
.16027 .17823 L
.16308 .17357 L
.16487 .17065 L
.16959 .16308 L
.17065 .16141 L
.17445 .15551 L
.17823 .14977 L
.17945 .14794 L
.18458 .14037 L
.1858 .1386 L
.18984 .1328 L
.19337 .12784 L
.19525 .12523 L
.2008 .11766 L
.20094 .11747 L
.20649 .11008 L
.20851 .10744 L
.21232 .10251 L
.21608 .09773 L
.2183 .09494 L
.22365 .08831 L
.22442 .08737 L
.23069 .0798 L
.23122 .07916 L
.2371 .07223 L
.23879 .07026 L
.24365 .06466 L
.24637 .06157 L
.25035 .05709 L
.25394 .05309 L
.25718 .04952 L
.26151 .0448 L
.26415 .04194 L
.26908 .03668 L
.27126 .03437 L
.27665 .02871 L
.27848 .0268 L
.28422 .02087 L
.28583 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.679 .748 0 r
.30475 .98077 m
.29936 .9756 L
.29688 .9732 L
.29179 .96822 L
.28916 .96563 L
.28422 .9607 L
.28159 .95806 L
.27665 .95302 L
.27418 .95048 L
.26908 .94518 L
.26693 .94291 L
.26151 .93714 L
.25984 .93534 L
.25394 .9289 L
.25291 .92777 L
.24637 .92045 L
.24615 .9202 L
.23955 .91263 L
.23879 .91175 L
.23311 .90506 L
.23122 .9028 L
.22683 .89749 L
.22365 .89358 L
.22071 .88992 L
.21608 .88405 L
.21476 .88234 L
.20895 .87477 L
.20851 .87419 L
.2033 .8672 L
.20094 .86397 L
.19781 .85963 L
.19337 .85336 L
.19246 .85206 L
.18726 .84449 L
.1858 .84232 L
.1822 .83692 L
.17823 .8308 L
.17729 .82935 L
.17252 .82177 L
.17065 .81875 L
.16789 .8142 L
.16339 .80663 L
.16308 .8061 L
.15903 .79906 L
.15551 .79278 L
.1548 .79149 L
.15071 .78392 L
.14794 .77867 L
.14674 .77635 L
.1429 .76878 L
.14037 .76366 L
.13918 .76121 L
.13559 .75363 L
.1328 .74758 L
.13211 .74606 L
.12876 .73849 L
.12553 .73092 L
.12523 .73019 L
.12242 .72335 L
.11942 .71578 L
.11766 .71118 L
.11654 .70821 L
.11377 .70064 L
.11111 .69306 L
.11008 .69007 L
.10856 .68549 L
.10612 .67792 L
.10379 .67035 L
.10251 .66603 L
.10157 .66278 L
.09946 .65521 L
.09745 .64764 L
.09555 .64007 L
.09494 .63754 L
.09376 .6325 L
.09206 .62492 L
.09047 .61735 L
.08898 .60978 L
.0876 .60221 L
.08737 .60092 L
.08631 .59464 L
.08513 .58707 L
.08405 .5795 L
.08306 .57193 L
.08218 .56435 L
.08139 .55678 L
.08071 .54921 L
.08012 .54164 L
.0798 .53691 L
.07963 .53407 L
.07924 .5265 L
.07894 .51893 L
.07875 .51136 L
.07865 .50379 L
.07865 .49621 L
.07875 .48864 L
.07894 .48107 L
.07924 .4735 L
.07963 .46593 L
.0798 .46309 L
.08012 .45836 L
.08071 .45079 L
.08139 .44322 L
.08218 .43565 L
.08306 .42807 L
.08405 .4205 L
.08513 .41293 L
.08631 .40536 L
.08737 .39908 L
.0876 .39779 L
.08898 .39022 L
.09047 .38265 L
.09206 .37508 L
.09376 .3675 L
.09494 .36246 L
.09555 .35993 L
.09745 .35236 L
.09946 .34479 L
.10157 .33722 L
.10251 .33397 L
.10379 .32965 L
.10612 .32208 L
.10856 .31451 L
.11008 .30993 L
.11111 .30694 L
.11377 .29936 L
.11654 .29179 L
.11766 .28882 L
.11942 .28422 L
.12242 .27665 L
.12523 .26981 L
.12553 .26908 L
.12876 .26151 L
.13211 .25394 L
.1328 .25242 L
.13559 .24637 L
.13918 .23879 L
.14037 .23634 L
.1429 .23122 L
.14674 .22365 L
.14794 .22133 L
.15071 .21608 L
.1548 .20851 L
.15551 .20722 L
.15903 .20094 L
.16308 .1939 L
.16339 .19337 L
.16789 .1858 L
.17065 .18125 L
.17252 .17823 L
.17729 .17065 L
.17823 .1692 L
.1822 .16308 L
.1858 .15768 L
.18726 .15551 L
.19246 .14794 L
.19337 .14664 L
.19781 .14037 L
.20094 .13603 L
.2033 .1328 L
.20851 .12581 L
.20895 .12523 L
.21476 .11766 L
.21608 .11595 L
.22071 .11008 L
.22365 .10642 L
.22683 .10251 L
.23122 .0972 L
.23311 .09494 L
.23879 .08825 L
.23955 .08737 L
.24615 .0798 L
.24637 .07955 L
.25291 .07223 L
.25394 .0711 L
.25984 .06466 L
.26151 .06286 L
.26693 .05709 L
.26908 .05482 L
.27418 .04952 L
.27665 .04698 L
.28159 .04194 L
.28422 .0393 L
.28916 .03437 L
.29179 .03178 L
.29688 .0268 L
.29936 .0244 L
.30475 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.606 .73 0 r
.32407 .98077 m
.32208 .979 L
.31564 .9732 L
.31451 .97217 L
.30738 .96563 L
.30694 .96521 L
.29936 .9581 L
.29931 .95806 L
.29179 .95084 L
.29143 .95048 L
.28422 .9434 L
.28373 .94291 L
.27665 .93579 L
.27622 .93534 L
.26908 .92797 L
.26889 .92777 L
.26175 .9202 L
.26151 .91994 L
.2548 .91263 L
.25394 .91168 L
.24803 .90506 L
.24637 .90317 L
.24144 .89749 L
.23879 .89439 L
.23502 .88992 L
.23122 .88533 L
.22878 .88234 L
.22365 .87596 L
.22271 .87477 L
.21681 .8672 L
.21608 .86625 L
.21107 .85963 L
.20851 .85618 L
.2055 .85206 L
.20094 .8457 L
.20008 .84449 L
.19483 .83692 L
.19337 .83478 L
.18972 .82935 L
.1858 .82337 L
.18477 .82177 L
.17996 .8142 L
.17823 .81141 L
.1753 .80663 L
.17078 .79906 L
.17065 .79884 L
.1664 .79149 L
.16308 .78558 L
.16217 .78392 L
.15806 .77635 L
.15551 .77151 L
.15409 .76878 L
.15025 .76121 L
.14794 .75651 L
.14654 .75363 L
.14296 .74606 L
.14037 .7404 L
.13951 .73849 L
.13618 .73092 L
.13297 .72335 L
.1328 .72294 L
.12988 .71578 L
.12691 .70821 L
.12523 .70377 L
.12406 .70064 L
.12132 .69306 L
.11871 .68549 L
.11766 .68237 L
.1162 .67792 L
.11381 .67035 L
.11152 .66278 L
.11008 .6578 L
.10935 .65521 L
.10729 .64764 L
.10534 .64007 L
.10349 .6325 L
.10251 .62828 L
.10176 .62492 L
.10012 .61735 L
.0986 .60978 L
.09718 .60221 L
.09586 .59464 L
.09494 .589 L
.09464 .58707 L
.09353 .5795 L
.09252 .57193 L
.09162 .56435 L
.09081 .55678 L
.09011 .54921 L
.08951 .54164 L
.089 .53407 L
.0886 .5265 L
.0883 .51893 L
.0881 .51136 L
.088 .50379 L
.088 .49621 L
.0881 .48864 L
.0883 .48107 L
.0886 .4735 L
.089 .46593 L
.08951 .45836 L
.09011 .45079 L
.09081 .44322 L
.09162 .43565 L
.09252 .42807 L
.09353 .4205 L
.09464 .41293 L
.09494 .411 L
.09586 .40536 L
.09718 .39779 L
.0986 .39022 L
.10012 .38265 L
.10176 .37508 L
.10251 .37172 L
.10349 .3675 L
.10534 .35993 L
.10729 .35236 L
.10935 .34479 L
.11008 .3422 L
.11152 .33722 L
.11381 .32965 L
.1162 .32208 L
.11766 .31763 L
.11871 .31451 L
.12132 .30694 L
.12406 .29936 L
.12523 .29623 L
.12691 .29179 L
.12988 .28422 L
.1328 .27706 L
.13297 .27665 L
.13618 .26908 L
.13951 .26151 L
.14037 .2596 L
.14296 .25394 L
.14654 .24637 L
.14794 .24349 L
.15025 .23879 L
.15409 .23122 L
.15551 .22849 L
.15806 .22365 L
.16217 .21608 L
.16308 .21442 L
.1664 .20851 L
.17065 .20116 L
.17078 .20094 L
.1753 .19337 L
.17823 .18859 L
.17996 .1858 L
.18477 .17823 L
.1858 .17663 L
.18972 .17065 L
.19337 .16522 L
.19483 .16308 L
.20008 .15551 L
.20094 .1543 L
.2055 .14794 L
.20851 .14382 L
.21107 .14037 L
.21608 .13375 L
.21681 .1328 L
.22271 .12523 L
.22365 .12404 L
.22878 .11766 L
.23122 .11467 L
.23502 .11008 L
.23879 .10561 L
.24144 .10251 L
.24637 .09683 L
.24803 .09494 L
.25394 .08832 L
.2548 .08737 L
.26151 .08006 L
.26175 .0798 L
.26889 .07223 L
.26908 .07203 L
.27622 .06466 L
.27665 .06421 L
.28373 .05709 L
.28422 .0566 L
.29143 .04952 L
.29179 .04916 L
.29931 .04194 L
.29936 .0419 L
.30694 .03479 L
.30738 .03437 L
.31451 .02783 L
.31564 .0268 L
.32208 .021 L
.32407 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.535 .712 0 r
.34393 .98077 m
.33722 .97517 L
.33488 .9732 L
.32965 .96874 L
.32604 .96563 L
.32208 .96217 L
.31742 .95806 L
.31451 .95545 L
.30902 .95048 L
.30694 .94857 L
.30084 .94291 L
.29936 .94153 L
.29287 .93534 L
.29179 .9343 L
.28512 .92777 L
.28422 .92688 L
.27758 .9202 L
.27665 .91925 L
.27025 .91263 L
.26908 .9114 L
.26312 .90506 L
.26151 .90332 L
.25619 .89749 L
.25394 .89497 L
.24946 .88992 L
.24637 .88636 L
.24292 .88234 L
.23879 .87745 L
.23657 .87477 L
.23122 .86822 L
.2304 .8672 L
.22442 .85963 L
.22365 .85865 L
.21861 .85206 L
.21608 .8487 L
.21297 .84449 L
.20851 .83834 L
.2075 .83692 L
.20219 .82935 L
.20094 .82752 L
.19705 .82177 L
.19337 .81621 L
.19206 .8142 L
.18723 .80663 L
.1858 .80434 L
.18255 .79906 L
.17823 .79184 L
.17802 .79149 L
.17363 .78392 L
.17065 .77863 L
.16939 .77635 L
.16529 .76878 L
.16308 .7646 L
.16132 .76121 L
.15749 .75363 L
.15551 .74961 L
.1538 .74606 L
.15024 .73849 L
.14794 .73346 L
.1468 .73092 L
.1435 .72335 L
.14037 .71591 L
.14032 .71578 L
.13726 .70821 L
.13433 .70064 L
.1328 .69656 L
.13151 .69306 L
.12882 .68549 L
.12624 .67792 L
.12523 .67484 L
.12378 .67035 L
.12144 .66278 L
.11921 .65521 L
.11766 .64969 L
.11709 .64764 L
.11509 .64007 L
.11319 .6325 L
.11141 .62492 L
.11008 .61897 L
.10974 .61735 L
.10817 .60978 L
.10671 .60221 L
.10536 .59464 L
.10411 .58707 L
.10297 .5795 L
.10251 .57622 L
.10194 .57193 L
.10101 .56435 L
.10019 .55678 L
.09946 .54921 L
.09885 .54164 L
.09833 .53407 L
.09792 .5265 L
.09761 .51893 L
.09741 .51136 L
.09731 .50379 L
.09731 .49621 L
.09741 .48864 L
.09761 .48107 L
.09792 .4735 L
.09833 .46593 L
.09885 .45836 L
.09946 .45079 L
.10019 .44322 L
.10101 .43565 L
.10194 .42807 L
.10251 .42378 L
.10297 .4205 L
.10411 .41293 L
.10536 .40536 L
.10671 .39779 L
.10817 .39022 L
.10974 .38265 L
.11008 .38103 L
.11141 .37508 L
.11319 .3675 L
.11509 .35993 L
.11709 .35236 L
.11766 .35031 L
.11921 .34479 L
.12144 .33722 L
.12378 .32965 L
.12523 .32516 L
.12624 .32208 L
.12882 .31451 L
.13151 .30694 L
.1328 .30344 L
.13433 .29936 L
.13726 .29179 L
.14032 .28422 L
.14037 .28409 L
.1435 .27665 L
.1468 .26908 L
.14794 .26654 L
.15024 .26151 L
.1538 .25394 L
.15551 .25039 L
.15749 .24637 L
.16132 .23879 L
.16308 .2354 L
.16529 .23122 L
.16939 .22365 L
.17065 .22137 L
.17363 .21608 L
.17802 .20851 L
.17823 .20816 L
.18255 .20094 L
.1858 .19566 L
.18723 .19337 L
.19206 .1858 L
.19337 .18379 L
.19705 .17823 L
.20094 .17248 L
.20219 .17065 L
.2075 .16308 L
.20851 .16166 L
.21297 .15551 L
.21608 .1513 L
.21861 .14794 L
.22365 .14135 L
.22442 .14037 L
.2304 .1328 L
.23122 .13178 L
.23657 .12523 L
.23879 .12255 L
.24292 .11766 L
.24637 .11364 L
.24946 .11008 L
.25394 .10503 L
.25619 .10251 L
.26151 .09668 L
.26312 .09494 L
.26908 .0886 L
.27025 .08737 L
.27665 .08075 L
.27758 .0798 L
.28422 .07312 L
.28512 .07223 L
.29179 .0657 L
.29287 .06466 L
.29936 .05847 L
.30084 .05709 L
.30694 .05143 L
.30902 .04952 L
.31451 .04455 L
.31742 .04194 L
.32208 .03783 L
.32604 .03437 L
.32965 .03126 L
.33488 .0268 L
.33722 .02483 L
.34393 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.468 .694 0 r
.36452 .98077 m
.35993 .97723 L
.35478 .9732 L
.35236 .97129 L
.34529 .96563 L
.34479 .96523 L
.33722 .95902 L
.33606 .95806 L
.32965 .95267 L
.32708 .95048 L
.32208 .94616 L
.31837 .94291 L
.31451 .93949 L
.3099 .93534 L
.30694 .93264 L
.30168 .92777 L
.29936 .92559 L
.2937 .9202 L
.29179 .91835 L
.28596 .91263 L
.28422 .91089 L
.27845 .90506 L
.27665 .90321 L
.27116 .89749 L
.26908 .89528 L
.26409 .88992 L
.26151 .88709 L
.25724 .88234 L
.25394 .87862 L
.25059 .87477 L
.24637 .86984 L
.24414 .8672 L
.23879 .86075 L
.23789 .85963 L
.23182 .85206 L
.23122 .8513 L
.22595 .84449 L
.22365 .84146 L
.22026 .83692 L
.21608 .83121 L
.21474 .82935 L
.20939 .82177 L
.20851 .8205 L
.20422 .8142 L
.20094 .80928 L
.19921 .80663 L
.19436 .79906 L
.19337 .79748 L
.18967 .79149 L
.1858 .78505 L
.18513 .78392 L
.18074 .77635 L
.17823 .77189 L
.1765 .76878 L
.17241 .76121 L
.17065 .75788 L
.16846 .75363 L
.16464 .74606 L
.16308 .74288 L
.16097 .73849 L
.15743 .73092 L
.15551 .72669 L
.15403 .72335 L
.15075 .71578 L
.14794 .70903 L
.14761 .70821 L
.14459 .70064 L
.14169 .69306 L
.14037 .68949 L
.13892 .68549 L
.13627 .67792 L
.13375 .67035 L
.1328 .66741 L
.13134 .66278 L
.12905 .65521 L
.12687 .64764 L
.12523 .64161 L
.12482 .64007 L
.12287 .6325 L
.12104 .62492 L
.11932 .61735 L
.11772 .60978 L
.11766 .60948 L
.11622 .60221 L
.11484 .59464 L
.11356 .58707 L
.11239 .5795 L
.11133 .57193 L
.11038 .56435 L
.11008 .56185 L
.10953 .55678 L
.10879 .54921 L
.10816 .54164 L
.10763 .53407 L
.10721 .5265 L
.1069 .51893 L
.10669 .51136 L
.10658 .50379 L
.10658 .49621 L
.10669 .48864 L
.1069 .48107 L
.10721 .4735 L
.10763 .46593 L
.10816 .45836 L
.10879 .45079 L
.10953 .44322 L
.11008 .43815 L
.11038 .43565 L
.11133 .42807 L
.11239 .4205 L
.11356 .41293 L
.11484 .40536 L
.11622 .39779 L
.11766 .39052 L
.11772 .39022 L
.11932 .38265 L
.12104 .37508 L
.12287 .3675 L
.12482 .35993 L
.12523 .35839 L
.12687 .35236 L
.12905 .34479 L
.13134 .33722 L
.1328 .33259 L
.13375 .32965 L
.13627 .32208 L
.13892 .31451 L
.14037 .31051 L
.14169 .30694 L
.14459 .29936 L
.14761 .29179 L
.14794 .29097 L
.15075 .28422 L
.15403 .27665 L
.15551 .27331 L
.15743 .26908 L
.16097 .26151 L
.16308 .25712 L
.16464 .25394 L
.16846 .24637 L
.17065 .24212 L
.17241 .23879 L
.1765 .23122 L
.17823 .22811 L
.18074 .22365 L
.18513 .21608 L
.1858 .21495 L
.18967 .20851 L
.19337 .20252 L
.19436 .20094 L
.19921 .19337 L
.20094 .19072 L
.20422 .1858 L
.20851 .1795 L
.20939 .17823 L
.21474 .17065 L
.21608 .16879 L
.22026 .16308 L
.22365 .15854 L
.22595 .15551 L
.23122 .1487 L
.23182 .14794 L
.23789 .14037 L
.23879 .13925 L
.24414 .1328 L
.24637 .13016 L
.25059 .12523 L
.25394 .12138 L
.25724 .11766 L
.26151 .11291 L
.26409 .11008 L
.26908 .10472 L
.27116 .10251 L
.27665 .09679 L
.27845 .09494 L
.28422 .08911 L
.28596 .08737 L
.29179 .08165 L
.2937 .0798 L
.29936 .07441 L
.30168 .07223 L
.30694 .06736 L
.3099 .06466 L
.31451 .06051 L
.31837 .05709 L
.32208 .05384 L
.32708 .04952 L
.32965 .04733 L
.33606 .04194 L
.33722 .04098 L
.34479 .03477 L
.34529 .03437 L
.35236 .02871 L
.35478 .0268 L
.35993 .02277 L
.36452 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.403 .676 0 r
.38606 .98077 m
.38265 .97834 L
.37552 .9732 L
.37508 .97288 L
.3675 .96729 L
.36528 .96563 L
.35993 .96157 L
.35536 .95806 L
.35236 .95572 L
.34575 .95048 L
.34479 .94972 L
.33722 .94356 L
.33643 .94291 L
.32965 .93724 L
.32741 .93534 L
.32208 .93075 L
.31867 .92777 L
.31451 .92407 L
.31022 .9202 L
.30694 .9172 L
.30202 .91263 L
.29936 .91012 L
.29409 .90506 L
.29179 .90281 L
.28641 .89749 L
.28422 .89528 L
.27898 .88992 L
.27665 .88749 L
.27178 .88234 L
.26908 .87944 L
.26481 .87477 L
.26151 .8711 L
.25806 .8672 L
.25394 .86246 L
.25152 .85963 L
.24637 .85348 L
.24519 .85206 L
.23907 .84449 L
.23879 .84415 L
.23314 .83692 L
.23122 .83442 L
.22739 .82935 L
.22365 .82427 L
.22184 .82177 L
.21647 .8142 L
.21608 .81365 L
.21127 .80663 L
.20851 .80251 L
.20624 .79906 L
.20138 .79149 L
.20094 .79079 L
.19668 .78392 L
.19337 .77842 L
.19214 .77635 L
.18776 .76878 L
.1858 .76529 L
.18353 .76121 L
.17945 .75363 L
.17823 .7513 L
.17552 .74606 L
.17173 .73849 L
.17065 .73629 L
.16808 .73092 L
.16457 .72335 L
.16308 .72004 L
.1612 .71578 L
.15796 .70821 L
.15551 .70226 L
.15486 .70064 L
.15188 .69306 L
.14903 .68549 L
.14794 .6825 L
.14631 .67792 L
.14371 .67035 L
.14124 .66278 L
.14037 .66004 L
.13888 .65521 L
.13665 .64764 L
.13454 .64007 L
.1328 .63349 L
.13254 .6325 L
.13066 .62492 L
.1289 .61735 L
.12725 .60978 L
.12572 .60221 L
.12523 .59966 L
.1243 .59464 L
.12299 .58707 L
.12179 .5795 L
.1207 .57193 L
.11973 .56435 L
.11886 .55678 L
.1181 .54921 L
.11766 .54414 L
.11746 .54164 L
.11692 .53407 L
.11648 .5265 L
.11616 .51893 L
.11594 .51136 L
.11584 .50379 L
.11584 .49621 L
.11594 .48864 L
.11616 .48107 L
.11648 .4735 L
.11692 .46593 L
.11746 .45836 L
.11766 .45586 L
.1181 .45079 L
.11886 .44322 L
.11973 .43565 L
.1207 .42807 L
.12179 .4205 L
.12299 .41293 L
.1243 .40536 L
.12523 .40034 L
.12572 .39779 L
.12725 .39022 L
.1289 .38265 L
.13066 .37508 L
.13254 .3675 L
.1328 .36651 L
.13454 .35993 L
.13665 .35236 L
.13888 .34479 L
.14037 .33996 L
.14124 .33722 L
.14371 .32965 L
.14631 .32208 L
.14794 .3175 L
.14903 .31451 L
.15188 .30694 L
.15486 .29936 L
.15551 .29774 L
.15796 .29179 L
.1612 .28422 L
.16308 .27996 L
.16457 .27665 L
.16808 .26908 L
.17065 .26371 L
.17173 .26151 L
.17552 .25394 L
.17823 .2487 L
.17945 .24637 L
.18353 .23879 L
.1858 .23471 L
.18776 .23122 L
.19214 .22365 L
.19337 .22158 L
.19668 .21608 L
.20094 .20921 L
.20138 .20851 L
.20624 .20094 L
.20851 .19749 L
.21127 .19337 L
.21608 .18635 L
.21647 .1858 L
.22184 .17823 L
.22365 .17573 L
.22739 .17065 L
.23122 .16558 L
.23314 .16308 L
.23879 .15585 L
.23907 .15551 L
.24519 .14794 L
.24637 .14652 L
.25152 .14037 L
.25394 .13754 L
.25806 .1328 L
.26151 .1289 L
.26481 .12523 L
.26908 .12056 L
.27178 .11766 L
.27665 .11251 L
.27898 .11008 L
.28422 .10472 L
.28641 .10251 L
.29179 .09719 L
.29409 .09494 L
.29936 .08988 L
.30202 .08737 L
.30694 .0828 L
.31022 .0798 L
.31451 .07593 L
.31867 .07223 L
.32208 .06925 L
.32741 .06466 L
.32965 .06276 L
.33643 .05709 L
.33722 .05644 L
.34479 .05028 L
.34575 .04952 L
.35236 .04428 L
.35536 .04194 L
.35993 .03843 L
.36528 .03437 L
.3675 .03271 L
.37508 .02712 L
.37552 .0268 L
.38265 .02166 L
.38606 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.341 .658 0 r
.40884 .98077 m
.40536 .9785 L
.39779 .97349 L
.39735 .9732 L
.39022 .96836 L
.38625 .96563 L
.38265 .96311 L
.37553 .95806 L
.37508 .95773 L
.3675 .95221 L
.36517 .95048 L
.35993 .94655 L
.35518 .94291 L
.35236 .94073 L
.34553 .93534 L
.34479 .93475 L
.33722 .9286 L
.33621 .92777 L
.32965 .92228 L
.32721 .9202 L
.32208 .91576 L
.31852 .91263 L
.31451 .90904 L
.31013 .90506 L
.30694 .90211 L
.30202 .89749 L
.29936 .89495 L
.29418 .88992 L
.29179 .88755 L
.28661 .88234 L
.28422 .8799 L
.27929 .87477 L
.27665 .87198 L
.27221 .8672 L
.26908 .86377 L
.26537 .85963 L
.26151 .85524 L
.25875 .85206 L
.25394 .84638 L
.25236 .84449 L
.24637 .83715 L
.24618 .83692 L
.2402 .82935 L
.23879 .82753 L
.23442 .82177 L
.23122 .81747 L
.22883 .8142 L
.22365 .80694 L
.22344 .80663 L
.21822 .79906 L
.21608 .79588 L
.21318 .79149 L
.20851 .78422 L
.20832 .78392 L
.20362 .77635 L
.20094 .7719 L
.19909 .76878 L
.19472 .76121 L
.19337 .75881 L
.19051 .75363 L
.18645 .74606 L
.1858 .74482 L
.18254 .73849 L
.17878 .73092 L
.17823 .72979 L
.17516 .72335 L
.17169 .71578 L
.17065 .71347 L
.16835 .70821 L
.16515 .70064 L
.16308 .69556 L
.16209 .69306 L
.15916 .68549 L
.15636 .67792 L
.15551 .67555 L
.15369 .67035 L
.15115 .66278 L
.14873 .65521 L
.14794 .65264 L
.14644 .64764 L
.14427 .64007 L
.14222 .6325 L
.14037 .62523 L
.14029 .62492 L
.13848 .61735 L
.13679 .60978 L
.13522 .60221 L
.13376 .59464 L
.1328 .58927 L
.13242 .58707 L
.13119 .5795 L
.13008 .57193 L
.12908 .56435 L
.12819 .55678 L
.12741 .54921 L
.12675 .54164 L
.12619 .53407 L
.12575 .5265 L
.12542 .51893 L
.12523 .51275 L
.1252 .51136 L
.12509 .50379 L
.12509 .49621 L
.1252 .48864 L
.12523 .48725 L
.12542 .48107 L
.12575 .4735 L
.12619 .46593 L
.12675 .45836 L
.12741 .45079 L
.12819 .44322 L
.12908 .43565 L
.13008 .42807 L
.13119 .4205 L
.13242 .41293 L
.1328 .41073 L
.13376 .40536 L
.13522 .39779 L
.13679 .39022 L
.13848 .38265 L
.14029 .37508 L
.14037 .37477 L
.14222 .3675 L
.14427 .35993 L
.14644 .35236 L
.14794 .34736 L
.14873 .34479 L
.15115 .33722 L
.15369 .32965 L
.15551 .32445 L
.15636 .32208 L
.15916 .31451 L
.16209 .30694 L
.16308 .30444 L
.16515 .29936 L
.16835 .29179 L
.17065 .28653 L
.17169 .28422 L
.17516 .27665 L
.17823 .27021 L
.17878 .26908 L
.18254 .26151 L
.1858 .25518 L
.18645 .25394 L
.19051 .24637 L
.19337 .24119 L
.19472 .23879 L
.19909 .23122 L
.20094 .2281 L
.20362 .22365 L
.20832 .21608 L
.20851 .21578 L
.21318 .20851 L
.21608 .20412 L
.21822 .20094 L
.22344 .19337 L
.22365 .19306 L
.22883 .1858 L
.23122 .18253 L
.23442 .17823 L
.23879 .17247 L
.2402 .17065 L
.24618 .16308 L
.24637 .16285 L
.25236 .15551 L
.25394 .15362 L
.25875 .14794 L
.26151 .14476 L
.26537 .14037 L
.26908 .13623 L
.27221 .1328 L
.27665 .12802 L
.27929 .12523 L
.28422 .1201 L
.28661 .11766 L
.29179 .11245 L
.29418 .11008 L
.29936 .10505 L
.30202 .10251 L
.30694 .09789 L
.31013 .09494 L
.31451 .09096 L
.31852 .08737 L
.32208 .08424 L
.32721 .0798 L
.32965 .07772 L
.33621 .07223 L
.33722 .0714 L
.34479 .06525 L
.34553 .06466 L
.35236 .05927 L
.35518 .05709 L
.35993 .05345 L
.36517 .04952 L
.3675 .04779 L
.37508 .04227 L
.37553 .04194 L
.38265 .03689 L
.38625 .03437 L
.39022 .03164 L
.39735 .0268 L
.39779 .02651 L
.40536 .0215 L
.40884 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.282 .64 0 r
.43325 .98077 m
.42807 .9777 L
.42061 .9732 L
.4205 .97313 L
.41293 .96844 L
.40847 .96563 L
.40536 .96364 L
.39779 .95871 L
.39679 .95806 L
.39022 .95366 L
.38557 .95048 L
.38265 .94846 L
.37508 .94312 L
.37478 .94291 L
.3675 .93763 L
.36441 .93534 L
.35993 .93198 L
.35443 .92777 L
.35236 .92617 L
.34482 .9202 L
.34479 .92018 L
.33722 .914 L
.33557 .91263 L
.32965 .90763 L
.32665 .90506 L
.32208 .90106 L
.31806 .89749 L
.31451 .89427 L
.30978 .88992 L
.30694 .88725 L
.3018 .88234 L
.29936 .87998 L
.29409 .87477 L
.29179 .87246 L
.28666 .8672 L
.28422 .86466 L
.27948 .85963 L
.27665 .85656 L
.27256 .85206 L
.26908 .84815 L
.26587 .84449 L
.26151 .8394 L
.25942 .83692 L
.25394 .83027 L
.25318 .82935 L
.24717 .82177 L
.24637 .82075 L
.24136 .8142 L
.23879 .81078 L
.23575 .80663 L
.23122 .80033 L
.23033 .79906 L
.22511 .79149 L
.22365 .78933 L
.22007 .78392 L
.21608 .77774 L
.2152 .77635 L
.21051 .76878 L
.20851 .76546 L
.20599 .76121 L
.20164 .75363 L
.20094 .75239 L
.19745 .74606 L
.19341 .73849 L
.19337 .73841 L
.18953 .73092 L
.1858 .72335 L
.1858 .72334 L
.18222 .71578 L
.17879 .70821 L
.17823 .70694 L
.17549 .70064 L
.17234 .69306 L
.17065 .68887 L
.16933 .68549 L
.16645 .67792 L
.1637 .67035 L
.16308 .66859 L
.16109 .66278 L
.15861 .65521 L
.15625 .64764 L
.15551 .64517 L
.15402 .64007 L
.15192 .6325 L
.14994 .62492 L
.14809 .61735 L
.14794 .61674 L
.14635 .60978 L
.14474 .60221 L
.14324 .59464 L
.14186 .58707 L
.14061 .5795 L
.14037 .578 L
.13946 .57193 L
.13844 .56435 L
.13753 .55678 L
.13673 .54921 L
.13605 .54164 L
.13548 .53407 L
.13503 .5265 L
.13469 .51893 L
.13446 .51136 L
.13435 .50379 L
.13435 .49621 L
.13446 .48864 L
.13469 .48107 L
.13503 .4735 L
.13548 .46593 L
.13605 .45836 L
.13673 .45079 L
.13753 .44322 L
.13844 .43565 L
.13946 .42807 L
.14037 .422 L
.14061 .4205 L
.14186 .41293 L
.14324 .40536 L
.14474 .39779 L
.14635 .39022 L
.14794 .38326 L
.14809 .38265 L
.14994 .37508 L
.15192 .3675 L
.15402 .35993 L
.15551 .35483 L
.15625 .35236 L
.15861 .34479 L
.16109 .33722 L
.16308 .33141 L
.1637 .32965 L
.16645 .32208 L
.16933 .31451 L
.17065 .31113 L
.17234 .30694 L
.17549 .29936 L
.17823 .29306 L
.17879 .29179 L
.18222 .28422 L
.1858 .27666 L
.1858 .27665 L
.18953 .26908 L
.19337 .26159 L
.19341 .26151 L
.19745 .25394 L
.20094 .24761 L
.20164 .24637 L
.20599 .23879 L
.20851 .23454 L
.21051 .23122 L
.2152 .22365 L
.21608 .22226 L
.22007 .21608 L
.22365 .21067 L
.22511 .20851 L
.23033 .20094 L
.23122 .19967 L
.23575 .19337 L
.23879 .18922 L
.24136 .1858 L
.24637 .17925 L
.24717 .17823 L
.25318 .17065 L
.25394 .16973 L
.25942 .16308 L
.26151 .1606 L
.26587 .15551 L
.26908 .15185 L
.27256 .14794 L
.27665 .14344 L
.27948 .14037 L
.28422 .13534 L
.28666 .1328 L
.29179 .12754 L
.29409 .12523 L
.29936 .12002 L
.3018 .11766 L
.30694 .11275 L
.30978 .11008 L
.31451 .10573 L
.31806 .10251 L
.32208 .09894 L
.32665 .09494 L
.32965 .09237 L
.33557 .08737 L
.33722 .086 L
.34479 .07982 L
.34482 .0798 L
.35236 .07383 L
.35443 .07223 L
.35993 .06802 L
.36441 .06466 L
.3675 .06237 L
.37478 .05709 L
.37508 .05688 L
.38265 .05154 L
.38557 .04952 L
.39022 .04634 L
.39679 .04194 L
.39779 .04129 L
.40536 .03636 L
.40847 .03437 L
.41293 .03156 L
.4205 .02687 L
.42061 .0268 L
.42807 .0223 L
.43325 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.225 .622 0 r
.45985 .98077 m
.45836 .97998 L
.45079 .97593 L
.44578 .9732 L
.44322 .97178 L
.43565 .96752 L
.43233 .96563 L
.42807 .96315 L
.4205 .95866 L
.41949 .95806 L
.41293 .95405 L
.40722 .95048 L
.40536 .94931 L
.39779 .94443 L
.39549 .94291 L
.39022 .9394 L
.38425 .93534 L
.38265 .93423 L
.37508 .9289 L
.37349 .92777 L
.3675 .92341 L
.36318 .9202 L
.35993 .91775 L
.35328 .91263 L
.35236 .91191 L
.34479 .90588 L
.34378 .90506 L
.33722 .89965 L
.33464 .89749 L
.32965 .89321 L
.32587 .88992 L
.32208 .88656 L
.31742 .88234 L
.31451 .87966 L
.30929 .87477 L
.30694 .87252 L
.30146 .8672 L
.29936 .86512 L
.29392 .85963 L
.29179 .85744 L
.28666 .85206 L
.28422 .84946 L
.27966 .84449 L
.27665 .84115 L
.27291 .83692 L
.26908 .8325 L
.2664 .82935 L
.26151 .82347 L
.26012 .82177 L
.25407 .8142 L
.25394 .81404 L
.24823 .80663 L
.24637 .80415 L
.24261 .79906 L
.23879 .79377 L
.23718 .79149 L
.23195 .78392 L
.23122 .78285 L
.22691 .77635 L
.22365 .7713 L
.22205 .76878 L
.21738 .76121 L
.21608 .75906 L
.21287 .75363 L
.20854 .74606 L
.20851 .74601 L
.20437 .73849 L
.20094 .73202 L
.20037 .73092 L
.19652 .72335 L
.19337 .7169 L
.19283 .71578 L
.18929 .70821 L
.1859 .70064 L
.1858 .70041 L
.18265 .69306 L
.17955 .68549 L
.17823 .68215 L
.17659 .67792 L
.17376 .67035 L
.17108 .66278 L
.17065 .66155 L
.16853 .65521 L
.16611 .64764 L
.16382 .64007 L
.16308 .63755 L
.16166 .6325 L
.15962 .62492 L
.15772 .61735 L
.15594 .60978 L
.15551 .60788 L
.15428 .60221 L
.15275 .59464 L
.15134 .58707 L
.15004 .5795 L
.14887 .57193 L
.14794 .56527 L
.14782 .56435 L
.14689 .55678 L
.14607 .54921 L
.14537 .54164 L
.14479 .53407 L
.14433 .5265 L
.14398 .51893 L
.14375 .51136 L
.14363 .50379 L
.14363 .49621 L
.14375 .48864 L
.14398 .48107 L
.14433 .4735 L
.14479 .46593 L
.14537 .45836 L
.14607 .45079 L
.14689 .44322 L
.14782 .43565 L
.14794 .43473 L
.14887 .42807 L
.15004 .4205 L
.15134 .41293 L
.15275 .40536 L
.15428 .39779 L
.15551 .39212 L
.15594 .39022 L
.15772 .38265 L
.15962 .37508 L
.16166 .3675 L
.16308 .36245 L
.16382 .35993 L
.16611 .35236 L
.16853 .34479 L
.17065 .33845 L
.17108 .33722 L
.17376 .32965 L
.17659 .32208 L
.17823 .31785 L
.17955 .31451 L
.18265 .30694 L
.1858 .29959 L
.1859 .29936 L
.18929 .29179 L
.19283 .28422 L
.19337 .2831 L
.19652 .27665 L
.20037 .26908 L
.20094 .26798 L
.20437 .26151 L
.20851 .25399 L
.20854 .25394 L
.21287 .24637 L
.21608 .24094 L
.21738 .23879 L
.22205 .23122 L
.22365 .2287 L
.22691 .22365 L
.23122 .21715 L
.23195 .21608 L
.23718 .20851 L
.23879 .20623 L
.24261 .20094 L
.24637 .19585 L
.24823 .19337 L
.25394 .18596 L
.25407 .1858 L
.26012 .17823 L
.26151 .17653 L
.2664 .17065 L
.26908 .1675 L
.27291 .16308 L
.27665 .15885 L
.27966 .15551 L
.28422 .15054 L
.28666 .14794 L
.29179 .14256 L
.29392 .14037 L
.29936 .13488 L
.30146 .1328 L
.30694 .12748 L
.30929 .12523 L
.31451 .12034 L
.31742 .11766 L
.32208 .11344 L
.32587 .11008 L
.32965 .10679 L
.33464 .10251 L
.33722 .10035 L
.34378 .09494 L
.34479 .09412 L
.35236 .08809 L
.35328 .08737 L
.35993 .08225 L
.36318 .0798 L
.3675 .07659 L
.37349 .07223 L
.37508 .0711 L
.38265 .06577 L
.38425 .06466 L
.39022 .0606 L
.39549 .05709 L
.39779 .05557 L
.40536 .05069 L
.40722 .04952 L
.41293 .04595 L
.41949 .04194 L
.4205 .04134 L
.42807 .03685 L
.43233 .03437 L
.43565 .03248 L
.44322 .02822 L
.44578 .0268 L
.45079 .02407 L
.45836 .02002 L
.45985 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.172 .604 0 r
.48955 .98077 m
.48864 .98035 L
.48107 .97681 L
.47356 .9732 L
.4735 .97317 L
.46593 .96943 L
.45843 .96563 L
.45836 .96559 L
.45079 .96164 L
.4441 .95806 L
.44322 .95758 L
.43565 .95339 L
.43051 .95048 L
.42807 .94908 L
.4205 .94465 L
.41761 .94291 L
.41293 .94007 L
.40536 .93536 L
.40533 .93534 L
.39779 .9305 L
.39364 .92777 L
.39022 .92549 L
.38265 .92031 L
.38249 .9202 L
.37508 .91497 L
.37183 .91263 L
.3675 .90945 L
.36164 .90506 L
.35993 .90375 L
.35236 .89786 L
.35189 .89749 L
.34479 .89177 L
.34254 .88992 L
.33722 .88546 L
.33357 .88234 L
.32965 .87893 L
.32497 .87477 L
.32208 .87216 L
.3167 .8672 L
.31451 .86514 L
.30875 .85963 L
.30694 .85785 L
.30111 .85206 L
.29936 .85028 L
.29376 .84449 L
.29179 .84241 L
.28669 .83692 L
.28422 .8342 L
.27988 .82935 L
.27665 .82565 L
.27333 .82177 L
.26908 .81672 L
.26701 .8142 L
.26151 .80736 L
.26093 .80663 L
.25507 .79906 L
.25394 .79756 L
.24943 .79149 L
.24637 .78725 L
.244 .78392 L
.23879 .77638 L
.23877 .77635 L
.23374 .76878 L
.23122 .76488 L
.22889 .76121 L
.22423 .75363 L
.22365 .75267 L
.21975 .74606 L
.21608 .73963 L
.21545 .73849 L
.21131 .73092 L
.20851 .72562 L
.20734 .72335 L
.20353 .71578 L
.20094 .71044 L
.19988 .70821 L
.19638 .70064 L
.19337 .69383 L
.19304 .69306 L
.18984 .68549 L
.18679 .67792 L
.1858 .67537 L
.18389 .67035 L
.18113 .66278 L
.1785 .65521 L
.17823 .65439 L
.17601 .64764 L
.17366 .64007 L
.17144 .6325 L
.17065 .62969 L
.16936 .62492 L
.1674 .61735 L
.16557 .60978 L
.16387 .60221 L
.16308 .5985 L
.1623 .59464 L
.16085 .58707 L
.15952 .5795 L
.15832 .57193 L
.15724 .56435 L
.15628 .55678 L
.15551 .54985 L
.15545 .54921 L
.15473 .54164 L
.15413 .53407 L
.15366 .5265 L
.1533 .51893 L
.15306 .51136 L
.15294 .50379 L
.15294 .49621 L
.15306 .48864 L
.1533 .48107 L
.15366 .4735 L
.15413 .46593 L
.15473 .45836 L
.15545 .45079 L
.15551 .45015 L
.15628 .44322 L
.15724 .43565 L
.15832 .42807 L
.15952 .4205 L
.16085 .41293 L
.1623 .40536 L
.16308 .4015 L
.16387 .39779 L
.16557 .39022 L
.1674 .38265 L
.16936 .37508 L
.17065 .37031 L
.17144 .3675 L
.17366 .35993 L
.17601 .35236 L
.17823 .34561 L
.1785 .34479 L
.18113 .33722 L
.18389 .32965 L
.1858 .32463 L
.18679 .32208 L
.18984 .31451 L
.19304 .30694 L
.19337 .30617 L
.19638 .29936 L
.19988 .29179 L
.20094 .28956 L
.20353 .28422 L
.20734 .27665 L
.20851 .27438 L
.21131 .26908 L
.21545 .26151 L
.21608 .26037 L
.21975 .25394 L
.22365 .24733 L
.22423 .24637 L
.22889 .23879 L
.23122 .23512 L
.23374 .23122 L
.23877 .22365 L
.23879 .22362 L
.244 .21608 L
.24637 .21275 L
.24943 .20851 L
.25394 .20244 L
.25507 .20094 L
.26093 .19337 L
.26151 .19264 L
.26701 .1858 L
.26908 .18328 L
.27333 .17823 L
.27665 .17435 L
.27988 .17065 L
.28422 .1658 L
.28669 .16308 L
.29179 .15759 L
.29376 .15551 L
.29936 .14972 L
.30111 .14794 L
.30694 .14215 L
.30875 .14037 L
.31451 .13486 L
.3167 .1328 L
.32208 .12784 L
.32497 .12523 L
.32965 .12107 L
.33357 .11766 L
.33722 .11454 L
.34254 .11008 L
.34479 .10823 L
.35189 .10251 L
.35236 .10214 L
.35993 .09625 L
.36164 .09494 L
.3675 .09055 L
.37183 .08737 L
.37508 .08503 L
.38249 .0798 L
.38265 .07969 L
.39022 .07451 L
.39364 .07223 L
.39779 .0695 L
.40533 .06466 L
.40536 .06464 L
.41293 .05993 L
.41761 .05709 L
.4205 .05535 L
.42807 .05092 L
.43051 .04952 L
.43565 .04661 L
.44322 .04242 L
.4441 .04194 L
.45079 .03836 L
.45836 .03441 L
.45843 .03437 L
.46593 .03057 L
.4735 .02683 L
.47356 .0268 L
.48107 .02319 L
.48864 .01965 L
.48955 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.121 .586 0 r
.52389 .98077 m
.51893 .97882 L
.51136 .97577 L
.50515 .9732 L
.50379 .97263 L
.49621 .96939 L
.48864 .96606 L
.48767 .96563 L
.48107 .96263 L
.4735 .95909 L
.47133 .95806 L
.46593 .95544 L
.45836 .95167 L
.45601 .95048 L
.45079 .94779 L
.44322 .94378 L
.44161 .94291 L
.43565 .93965 L
.42807 .93537 L
.42802 .93534 L
.4205 .93096 L
.41517 .92777 L
.41293 .92641 L
.40536 .9217 L
.40299 .9202 L
.39779 .91684 L
.39143 .91263 L
.39022 .91181 L
.38265 .90661 L
.38043 .90506 L
.37508 .90124 L
.36995 .89749 L
.3675 .89567 L
.35994 .88992 L
.35993 .88991 L
.35236 .88395 L
.35037 .88234 L
.34479 .87776 L
.34122 .87477 L
.33722 .87135 L
.33246 .8672 L
.32965 .8647 L
.32406 .85963 L
.32208 .8578 L
.316 .85206 L
.31451 .85062 L
.30826 .84449 L
.30694 .84316 L
.30083 .83692 L
.29936 .83539 L
.29369 .82935 L
.29179 .82728 L
.28683 .82177 L
.28422 .81882 L
.28023 .8142 L
.27665 .80997 L
.27388 .80663 L
.26908 .8007 L
.26778 .79906 L
.2619 .79149 L
.26151 .79097 L
.25625 .78392 L
.25394 .78073 L
.25082 .77635 L
.24637 .76991 L
.2456 .76878 L
.24057 .76121 L
.23879 .75845 L
.23574 .75363 L
.23122 .74626 L
.23111 .74606 L
.22665 .73849 L
.22365 .73322 L
.22237 .73092 L
.21827 .72335 L
.21608 .71918 L
.21434 .71578 L
.21057 .70821 L
.20851 .70392 L
.20696 .70064 L
.20352 .69306 L
.20094 .68717 L
.20022 .68549 L
.19708 .67792 L
.19409 .67035 L
.19337 .66846 L
.19125 .66278 L
.18855 .65521 L
.18599 .64764 L
.1858 .64704 L
.18357 .64007 L
.18129 .6325 L
.17915 .62492 L
.17823 .62151 L
.17714 .61735 L
.17526 .60978 L
.17351 .60221 L
.1719 .59464 L
.17065 .58836 L
.17041 .58707 L
.16905 .5795 L
.16782 .57193 L
.16671 .56435 L
.16573 .55678 L
.16487 .54921 L
.16413 .54164 L
.16352 .53407 L
.16308 .52737 L
.16303 .5265 L
.16267 .51893 L
.16242 .51136 L
.1623 .50379 L
.1623 .49621 L
.16242 .48864 L
.16267 .48107 L
.16303 .4735 L
.16308 .47263 L
.16352 .46593 L
.16413 .45836 L
.16487 .45079 L
.16573 .44322 L
.16671 .43565 L
.16782 .42807 L
.16905 .4205 L
.17041 .41293 L
.17065 .41164 L
.1719 .40536 L
.17351 .39779 L
.17526 .39022 L
.17714 .38265 L
.17823 .37849 L
.17915 .37508 L
.18129 .3675 L
.18357 .35993 L
.1858 .35296 L
.18599 .35236 L
.18855 .34479 L
.19125 .33722 L
.19337 .33154 L
.19409 .32965 L
.19708 .32208 L
.20022 .31451 L
.20094 .31283 L
.20352 .30694 L
.20696 .29936 L
.20851 .29608 L
.21057 .29179 L
.21434 .28422 L
.21608 .28082 L
.21827 .27665 L
.22237 .26908 L
.22365 .26678 L
.22665 .26151 L
.23111 .25394 L
.23122 .25374 L
.23574 .24637 L
.23879 .24155 L
.24057 .23879 L
.2456 .23122 L
.24637 .23009 L
.25082 .22365 L
.25394 .21927 L
.25625 .21608 L
.26151 .20903 L
.2619 .20851 L
.26778 .20094 L
.26908 .1993 L
.27388 .19337 L
.27665 .19003 L
.28023 .1858 L
.28422 .18118 L
.28683 .17823 L
.29179 .17272 L
.29369 .17065 L
.29936 .16461 L
.30083 .16308 L
.30694 .15684 L
.30826 .15551 L
.31451 .14938 L
.316 .14794 L
.32208 .1422 L
.32406 .14037 L
.32965 .1353 L
.33246 .1328 L
.33722 .12865 L
.34122 .12523 L
.34479 .12224 L
.35037 .11766 L
.35236 .11605 L
.35993 .11009 L
.35994 .11008 L
.3675 .10433 L
.36995 .10251 L
.37508 .09876 L
.38043 .09494 L
.38265 .09339 L
.39022 .08819 L
.39143 .08737 L
.39779 .08316 L
.40299 .0798 L
.40536 .0783 L
.41293 .07359 L
.41517 .07223 L
.4205 .06904 L
.42802 .06466 L
.42807 .06463 L
.43565 .06035 L
.44161 .05709 L
.44322 .05622 L
.45079 .05221 L
.45601 .04952 L
.45836 .04833 L
.46593 .04456 L
.47133 .04194 L
.4735 .04091 L
.48107 .03737 L
.48767 .03437 L
.48864 .03394 L
.49621 .03061 L
.50379 .02737 L
.50515 .0268 L
.51136 .02423 L
.51893 .02118 L
.52389 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.073 .568 0 r
.566 .98077 m
.56435 .98026 L
.55678 .97785 L
.54921 .97536 L
.54282 .9732 L
.54164 .97279 L
.53407 .97014 L
.5265 .9674 L
.52174 .96563 L
.51893 .96457 L
.51136 .96164 L
.50379 .95861 L
.50244 .95806 L
.49621 .95547 L
.48864 .95223 L
.48466 .95048 L
.48107 .94888 L
.4735 .94541 L
.4682 .94291 L
.46593 .94182 L
.45836 .93811 L
.45287 .93534 L
.45079 .93427 L
.44322 .9303 L
.43853 .92777 L
.43565 .92619 L
.42807 .92193 L
.42507 .9202 L
.4205 .91753 L
.41293 .91297 L
.41238 .91263 L
.40536 .90825 L
.40039 .90506 L
.39779 .90336 L
.39022 .8983 L
.38902 .89749 L
.38265 .89306 L
.37823 .88992 L
.37508 .88762 L
.36797 .88234 L
.3675 .88199 L
.35993 .87615 L
.35819 .87477 L
.35236 .87009 L
.34885 .8672 L
.34479 .8638 L
.33993 .85963 L
.33722 .85726 L
.33139 .85206 L
.32965 .85047 L
.32322 .84449 L
.32208 .8434 L
.31539 .83692 L
.31451 .83604 L
.30788 .82935 L
.30694 .82837 L
.30068 .82177 L
.29936 .82036 L
.29377 .8142 L
.29179 .81198 L
.28713 .80663 L
.28422 .80322 L
.28075 .79906 L
.27665 .79403 L
.27463 .79149 L
.26908 .78436 L
.26874 .78392 L
.26309 .77635 L
.26151 .77417 L
.25766 .76878 L
.25394 .7634 L
.25244 .76121 L
.24743 .75363 L
.24637 .75198 L
.24263 .74606 L
.23879 .7398 L
.23801 .73849 L
.23359 .73092 L
.23122 .72674 L
.22934 .72335 L
.22528 .71578 L
.22365 .71265 L
.22139 .70821 L
.21767 .70064 L
.21608 .69731 L
.21411 .69306 L
.21071 .68549 L
.20851 .68038 L
.20748 .67792 L
.2044 .67035 L
.20147 .66278 L
.20094 .66137 L
.19869 .65521 L
.19605 .64764 L
.19357 .64007 L
.19337 .63944 L
.19122 .6325 L
.18902 .62492 L
.18695 .61735 L
.1858 .61289 L
.18502 .60978 L
.18323 .60221 L
.18157 .59464 L
.18004 .58707 L
.17864 .5795 L
.17823 .5771 L
.17737 .57193 L
.17624 .56435 L
.17523 .55678 L
.17435 .54921 L
.1736 .54164 L
.17297 .53407 L
.17247 .5265 L
.17209 .51893 L
.17184 .51136 L
.17172 .50379 L
.17172 .49621 L
.17184 .48864 L
.17209 .48107 L
.17247 .4735 L
.17297 .46593 L
.1736 .45836 L
.17435 .45079 L
.17523 .44322 L
.17624 .43565 L
.17737 .42807 L
.17823 .4229 L
.17864 .4205 L
.18004 .41293 L
.18157 .40536 L
.18323 .39779 L
.18502 .39022 L
.1858 .38711 L
.18695 .38265 L
.18902 .37508 L
.19122 .3675 L
.19337 .36056 L
.19357 .35993 L
.19605 .35236 L
.19869 .34479 L
.20094 .33863 L
.20147 .33722 L
.2044 .32965 L
.20748 .32208 L
.20851 .31962 L
.21071 .31451 L
.21411 .30694 L
.21608 .30269 L
.21767 .29936 L
.22139 .29179 L
.22365 .28735 L
.22528 .28422 L
.22934 .27665 L
.23122 .27326 L
.23359 .26908 L
.23801 .26151 L
.23879 .2602 L
.24263 .25394 L
.24637 .24802 L
.24743 .24637 L
.25244 .23879 L
.25394 .2366 L
.25766 .23122 L
.26151 .22583 L
.26309 .22365 L
.26874 .21608 L
.26908 .21564 L
.27463 .20851 L
.27665 .20597 L
.28075 .20094 L
.28422 .19678 L
.28713 .19337 L
.29179 .18802 L
.29377 .1858 L
.29936 .17964 L
.30068 .17823 L
.30694 .17163 L
.30788 .17065 L
.31451 .16396 L
.31539 .16308 L
.32208 .1566 L
.32322 .15551 L
.32965 .14953 L
.33139 .14794 L
.33722 .14274 L
.33993 .14037 L
.34479 .1362 L
.34885 .1328 L
.35236 .12991 L
.35819 .12523 L
.35993 .12385 L
.3675 .11801 L
.36797 .11766 L
.37508 .11238 L
.37823 .11008 L
.38265 .10694 L
.38902 .10251 L
.39022 .1017 L
.39779 .09664 L
.40039 .09494 L
.40536 .09175 L
.41238 .08737 L
.41293 .08703 L
.4205 .08247 L
.42507 .0798 L
.42807 .07807 L
.43565 .07381 L
.43853 .07223 L
.44322 .0697 L
.45079 .06573 L
.45287 .06466 L
.45836 .06189 L
.46593 .05818 L
.4682 .05709 L
.4735 .05459 L
.48107 .05112 L
.48466 .04952 L
.48864 .04777 L
.49621 .04453 L
.50244 .04194 L
.50379 .04139 L
.51136 .03836 L
.51893 .03543 L
.52174 .03437 L
.5265 .0326 L
.53407 .02986 L
.54164 .02721 L
.54282 .0268 L
.54921 .02464 L
.55678 .02215 L
.56435 .01974 L
.566 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.027 .55 0 r
.6241 .98077 m
.61735 .97927 L
.60978 .97754 L
.60221 .97574 L
.59464 .97388 L
.59194 .9732 L
.58707 .97194 L
.5795 .96994 L
.57193 .96785 L
.56435 .96568 L
.56417 .96563 L
.55678 .96343 L
.54921 .96109 L
.54164 .95865 L
.53983 .95806 L
.53407 .95612 L
.5265 .95349 L
.51893 .95076 L
.51817 .95048 L
.51136 .94793 L
.50379 .94498 L
.49863 .94291 L
.49621 .94193 L
.48864 .93875 L
.48107 .93546 L
.48081 .93534 L
.4735 .93204 L
.46593 .92849 L
.46443 .92777 L
.45836 .92481 L
.45079 .921 L
.44924 .9202 L
.44322 .91704 L
.43565 .91293 L
.4351 .91263 L
.42807 .90867 L
.42185 .90506 L
.4205 .90426 L
.41293 .89968 L
.4094 .89749 L
.40536 .89493 L
.39779 .89 L
.39766 .88992 L
.39022 .88489 L
.38655 .88234 L
.38265 .87958 L
.37602 .87477 L
.37508 .87408 L
.3675 .86836 L
.36601 .8672 L
.35993 .86241 L
.35649 .85963 L
.35236 .85624 L
.34741 .85206 L
.34479 .84981 L
.33874 .84449 L
.33722 .84312 L
.33046 .83692 L
.32965 .83616 L
.32254 .82935 L
.32208 .8289 L
.31495 .82177 L
.31451 .82132 L
.30769 .8142 L
.30694 .8134 L
.30073 .80663 L
.29936 .80511 L
.29405 .79906 L
.29179 .79643 L
.28765 .79149 L
.28422 .7873 L
.28151 .78392 L
.27665 .7777 L
.27562 .77635 L
.26996 .76878 L
.26908 .76757 L
.26454 .76121 L
.26151 .75684 L
.25933 .75363 L
.25434 .74606 L
.25394 .74543 L
.24956 .73849 L
.24637 .73326 L
.24497 .73092 L
.24058 .72335 L
.23879 .72018 L
.23637 .71578 L
.23235 .70821 L
.23122 .70602 L
.22851 .70064 L
.22483 .69306 L
.22365 .69055 L
.22133 .68549 L
.21799 .67792 L
.21608 .67342 L
.21481 .67035 L
.21179 .66278 L
.20893 .65521 L
.20851 .65406 L
.20622 .64764 L
.20366 .64007 L
.20124 .6325 L
.20094 .6315 L
.19898 .62492 L
.19685 .61735 L
.19487 .60978 L
.19337 .60368 L
.19302 .60221 L
.19132 .59464 L
.18975 .58707 L
.18831 .5795 L
.18701 .57193 L
.18584 .56435 L
.1858 .56404 L
.18481 .55678 L
.1839 .54921 L
.18313 .54164 L
.18248 .53407 L
.18197 .5265 L
.18158 .51893 L
.18133 .51136 L
.1812 .50379 L
.1812 .49621 L
.18133 .48864 L
.18158 .48107 L
.18197 .4735 L
.18248 .46593 L
.18313 .45836 L
.1839 .45079 L
.18481 .44322 L
.1858 .43596 L
.18584 .43565 L
.18701 .42807 L
.18831 .4205 L
.18975 .41293 L
.19132 .40536 L
.19302 .39779 L
.19337 .39632 L
.19487 .39022 L
.19685 .38265 L
.19898 .37508 L
.20094 .3685 L
.20124 .3675 L
.20366 .35993 L
.20622 .35236 L
.20851 .34594 L
.20893 .34479 L
.21179 .33722 L
.21481 .32965 L
.21608 .32658 L
.21799 .32208 L
.22133 .31451 L
.22365 .30945 L
.22483 .30694 L
.22851 .29936 L
.23122 .29398 L
.23235 .29179 L
.23637 .28422 L
.23879 .27982 L
.24058 .27665 L
.24497 .26908 L
.24637 .26674 L
.24956 .26151 L
.25394 .25457 L
.25434 .25394 L
.25933 .24637 L
.26151 .24316 L
.26454 .23879 L
.26908 .23243 L
.26996 .23122 L
.27562 .22365 L
.27665 .2223 L
.28151 .21608 L
.28422 .2127 L
.28765 .20851 L
.29179 .20357 L
.29405 .20094 L
.29936 .19489 L
.30073 .19337 L
.30694 .1866 L
.30769 .1858 L
.31451 .17868 L
.31495 .17823 L
.32208 .1711 L
.32254 .17065 L
.32965 .16384 L
.33046 .16308 L
.33722 .15688 L
.33874 .15551 L
.34479 .15019 L
.34741 .14794 L
.35236 .14376 L
.35649 .14037 L
.35993 .13759 L
.36601 .1328 L
.3675 .13164 L
.37508 .12592 L
.37602 .12523 L
.38265 .12042 L
.38655 .11766 L
.39022 .11511 L
.39766 .11008 L
.39779 .11 L
.40536 .10507 L
.4094 .10251 L
.41293 .10032 L
.4205 .09574 L
.42185 .09494 L
.42807 .09133 L
.4351 .08737 L
.43565 .08707 L
.44322 .08296 L
.44924 .0798 L
.45079 .079 L
.45836 .07519 L
.46443 .07223 L
.46593 .07151 L
.4735 .06796 L
.48081 .06466 L
.48107 .06454 L
.48864 .06125 L
.49621 .05807 L
.49863 .05709 L
.50379 .05502 L
.51136 .05207 L
.51817 .04952 L
.51893 .04924 L
.5265 .04651 L
.53407 .04388 L
.53983 .04194 L
.54164 .04135 L
.54921 .03891 L
.55678 .03657 L
.56417 .03437 L
.56435 .03432 L
.57193 .03215 L
.5795 .03006 L
.58707 .02806 L
.59194 .0268 L
.59464 .02612 L
.60221 .02426 L
.60978 .02246 L
.61735 .02073 L
.6241 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 .532 .015 r
.73171 .98077 m
.73092 .98067 L
.72335 .9797 L
.71578 .97876 L
.70821 .97782 L
.70064 .97687 L
.69306 .9759 L
.68549 .97492 L
.67792 .9739 L
.67283 .9732 L
.67035 .97285 L
.66278 .97175 L
.65521 .97061 L
.64764 .96941 L
.64007 .96816 L
.6325 .96684 L
.62583 .96563 L
.62492 .96546 L
.61735 .964 L
.60978 .96248 L
.60221 .96088 L
.59464 .9592 L
.58971 .95806 L
.58707 .95743 L
.5795 .95558 L
.57193 .95364 L
.56435 .95161 L
.56032 .95048 L
.55678 .94948 L
.54921 .94725 L
.54164 .94492 L
.53536 .94291 L
.53407 .94249 L
.5265 .93995 L
.51893 .9373 L
.51353 .93534 L
.51136 .93454 L
.50379 .93166 L
.49621 .92865 L
.49404 .92777 L
.48864 .92553 L
.48107 .92227 L
.4764 .9202 L
.4735 .91889 L
.46593 .91536 L
.46025 .91263 L
.45836 .9117 L
.45079 .90789 L
.44534 .90506 L
.44322 .90393 L
.43565 .89982 L
.43148 .89749 L
.42807 .89554 L
.4205 .8911 L
.41854 .88992 L
.41293 .88648 L
.40638 .88234 L
.40536 .88168 L
.39779 .8767 L
.39494 .87477 L
.39022 .87152 L
.38413 .8672 L
.38265 .86613 L
.37508 .86053 L
.37389 .85963 L
.3675 .8547 L
.36417 .85206 L
.35993 .84864 L
.35493 .84449 L
.35236 .84232 L
.34613 .83692 L
.34479 .83574 L
.33773 .82935 L
.33722 .82887 L
.32972 .82177 L
.32965 .82171 L
.32208 .81422 L
.32206 .8142 L
.31474 .80663 L
.31451 .80639 L
.30773 .79906 L
.30694 .79818 L
.30102 .79149 L
.29936 .78957 L
.2946 .78392 L
.29179 .78051 L
.28844 .77635 L
.28422 .77096 L
.28254 .76878 L
.27689 .76121 L
.27665 .76087 L
.27148 .75363 L
.26908 .75018 L
.26629 .74606 L
.26151 .73879 L
.26132 .73849 L
.25656 .73092 L
.25394 .7266 L
.25201 .72335 L
.24765 .71578 L
.24637 .71348 L
.24349 .70821 L
.23951 .70064 L
.23879 .69924 L
.23571 .69306 L
.23209 .68549 L
.23122 .68362 L
.22864 .67792 L
.22536 .67035 L
.22365 .66624 L
.22225 .66278 L
.2193 .65521 L
.2165 .64764 L
.21608 .64646 L
.21386 .64007 L
.21138 .6325 L
.20904 .62492 L
.20851 .62313 L
.20686 .61735 L
.20481 .60978 L
.20292 .60221 L
.20116 .59464 L
.20094 .59364 L
.19955 .58707 L
.19807 .5795 L
.19674 .57193 L
.19554 .56435 L
.19447 .55678 L
.19354 .54921 L
.19337 .54767 L
.19275 .54164 L
.19209 .53407 L
.19156 .5265 L
.19116 .51893 L
.1909 .51136 L
.19077 .50379 L
.19077 .49621 L
.1909 .48864 L
.19116 .48107 L
.19156 .4735 L
.19209 .46593 L
.19275 .45836 L
.19337 .45233 L
.19354 .45079 L
.19447 .44322 L
.19554 .43565 L
.19674 .42807 L
.19807 .4205 L
.19955 .41293 L
.20094 .40636 L
.20116 .40536 L
.20292 .39779 L
.20481 .39022 L
.20686 .38265 L
.20851 .37687 L
.20904 .37508 L
.21138 .3675 L
.21386 .35993 L
.21608 .35354 L
.2165 .35236 L
.2193 .34479 L
.22225 .33722 L
.22365 .33376 L
.22536 .32965 L
.22864 .32208 L
.23122 .31638 L
.23209 .31451 L
.23571 .30694 L
.23879 .30076 L
.23951 .29936 L
.24349 .29179 L
.24637 .28652 L
.24765 .28422 L
.25201 .27665 L
.25394 .2734 L
.25656 .26908 L
.26132 .26151 L
.26151 .26121 L
.26629 .25394 L
.26908 .24982 L
.27148 .24637 L
.27665 .23913 L
.27689 .23879 L
.28254 .23122 L
.28422 .22904 L
.28844 .22365 L
.29179 .21949 L
.2946 .21608 L
.29936 .21043 L
.30102 .20851 L
.30694 .20182 L
.30773 .20094 L
.31451 .19361 L
.31474 .19337 L
.32206 .1858 L
.32208 .18578 L
.32965 .17829 L
.32972 .17823 L
.33722 .17113 L
.33773 .17065 L
.34479 .16426 L
.34613 .16308 L
.35236 .15768 L
.35493 .15551 L
.35993 .15136 L
.36417 .14794 L
.3675 .1453 L
.37389 .14037 L
.37508 .13947 L
.38265 .13387 L
.38413 .1328 L
.39022 .12848 L
.39494 .12523 L
.39779 .1233 L
.40536 .11832 L
.40638 .11766 L
.41293 .11352 L
.41854 .11008 L
.4205 .1089 L
.42807 .10446 L
.43148 .10251 L
.43565 .10018 L
.44322 .09607 L
.44534 .09494 L
.45079 .09211 L
.45836 .0883 L
.46025 .08737 L
.46593 .08464 L
.4735 .08111 L
.4764 .0798 L
.48107 .07773 L
.48864 .07447 L
.49404 .07223 L
.49621 .07135 L
.50379 .06834 L
.51136 .06546 L
.51353 .06466 L
.51893 .0627 L
.5265 .06005 L
.53407 .05751 L
.53536 .05709 L
.54164 .05508 L
.54921 .05275 L
.55678 .05052 L
.56032 .04952 L
.56435 .04839 L
.57193 .04636 L
.5795 .04442 L
.58707 .04257 L
.58971 .04194 L
.59464 .0408 L
.60221 .03912 L
.60978 .03752 L
.61735 .036 L
.62492 .03454 L
.62583 .03437 L
.6325 .03316 L
.64007 .03184 L
.64764 .03059 L
.65521 .02939 L
.66278 .02825 L
.67035 .02715 L
.67283 .0268 L
.67792 .0261 L
.68549 .02508 L
.69306 .0241 L
.70064 .02313 L
.70821 .02218 L
.71578 .02124 L
.72335 .0203 L
.73092 .01933 L
.73171 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 .514 .054 r
.85368 .98077 m
.85206 .97983 L
.84449 .97618 L
.83692 .9734 L
.83628 .9732 L
.82935 .97124 L
.82177 .96952 L
.8142 .96814 L
.80663 .96701 L
.79906 .96608 L
.79484 .96563 L
.79149 .9653 L
.78392 .96463 L
.77635 .96404 L
.76878 .96353 L
.76121 .96305 L
.75363 .9626 L
.74606 .96217 L
.73849 .96174 L
.73092 .9613 L
.72335 .96084 L
.71578 .96036 L
.70821 .95985 L
.70064 .95929 L
.69306 .9587 L
.68557 .95806 L
.68549 .95805 L
.67792 .95735 L
.67035 .95659 L
.66278 .95577 L
.65521 .95488 L
.64764 .95392 L
.64007 .95289 L
.6325 .95178 L
.62492 .95059 L
.62426 .95048 L
.61735 .94932 L
.60978 .94797 L
.60221 .94653 L
.59464 .94499 L
.58707 .94337 L
.58504 .94291 L
.5795 .94164 L
.57193 .93982 L
.56435 .9379 L
.55678 .93588 L
.55485 .93534 L
.54921 .93374 L
.54164 .9315 L
.53407 .92915 L
.52981 .92777 L
.5265 .92668 L
.51893 .92409 L
.51136 .92138 L
.50816 .9202 L
.50379 .91855 L
.49621 .91558 L
.48898 .91263 L
.48864 .91249 L
.48107 .90926 L
.4735 .90589 L
.47168 .90506 L
.46593 .90238 L
.45836 .89871 L
.45589 .89749 L
.45079 .8949 L
.44322 .89092 L
.44135 .88992 L
.43565 .88678 L
.42807 .88247 L
.42785 .88234 L
.4205 .87799 L
.41526 .87477 L
.41293 .87332 L
.40536 .86846 L
.40345 .8672 L
.39779 .8634 L
.39234 .85963 L
.39022 .85813 L
.38265 .85265 L
.38186 .85206 L
.37508 .84693 L
.37193 .84449 L
.3675 .84097 L
.36252 .83692 L
.35993 .83476 L
.35358 .82935 L
.35236 .82828 L
.34508 .82177 L
.34479 .82151 L
.33722 .81444 L
.33697 .8142 L
.32965 .80704 L
.32924 .80663 L
.32208 .79929 L
.32186 .79906 L
.31481 .79149 L
.31451 .79116 L
.30807 .78392 L
.30694 .78262 L
.30162 .77635 L
.29936 .77362 L
.29545 .76878 L
.29179 .76412 L
.28955 .76121 L
.28422 .75407 L
.2839 .75363 L
.2785 .74606 L
.27665 .7434 L
.27333 .73849 L
.26908 .73201 L
.26838 .73092 L
.26365 .72335 L
.26151 .7198 L
.25914 .71578 L
.25482 .70821 L
.25394 .70662 L
.2507 .70064 L
.24677 .69306 L
.24637 .69227 L
.24302 .68549 L
.23946 .67792 L
.23879 .67647 L
.23607 .67035 L
.23286 .66278 L
.23122 .65878 L
.22981 .65521 L
.22693 .64764 L
.2242 .64007 L
.22365 .63848 L
.22164 .6325 L
.21923 .62492 L
.21698 .61735 L
.21608 .61418 L
.21488 .60978 L
.21292 .60221 L
.21112 .59464 L
.20946 .58707 L
.20851 .58243 L
.20794 .5795 L
.20656 .57193 L
.20533 .56435 L
.20424 .55678 L
.20328 .54921 L
.20246 .54164 L
.20178 .53407 L
.20124 .5265 L
.20094 .52123 L
.20083 .51893 L
.20056 .51136 L
.20043 .50379 L
.20043 .49621 L
.20056 .48864 L
.20083 .48107 L
.20094 .47877 L
.20124 .4735 L
.20178 .46593 L
.20246 .45836 L
.20328 .45079 L
.20424 .44322 L
.20533 .43565 L
.20656 .42807 L
.20794 .4205 L
.20851 .41757 L
.20946 .41293 L
.21112 .40536 L
.21292 .39779 L
.21488 .39022 L
.21608 .38582 L
.21698 .38265 L
.21923 .37508 L
.22164 .3675 L
.22365 .36152 L
.2242 .35993 L
.22693 .35236 L
.22981 .34479 L
.23122 .34122 L
.23286 .33722 L
.23607 .32965 L
.23879 .32353 L
.23946 .32208 L
.24302 .31451 L
.24637 .30773 L
.24677 .30694 L
.2507 .29936 L
.25394 .29338 L
.25482 .29179 L
.25914 .28422 L
.26151 .2802 L
.26365 .27665 L
.26838 .26908 L
.26908 .26799 L
.27333 .26151 L
.27665 .2566 L
.2785 .25394 L
.2839 .24637 L
.28422 .24593 L
.28955 .23879 L
.29179 .23588 L
.29545 .23122 L
.29936 .22638 L
.30162 .22365 L
.30694 .21738 L
.30807 .21608 L
.31451 .20884 L
.31481 .20851 L
.32186 .20094 L
.32208 .20071 L
.32924 .19337 L
.32965 .19296 L
.33697 .1858 L
.33722 .18556 L
.34479 .17849 L
.34508 .17823 L
.35236 .17172 L
.35358 .17065 L
.35993 .16524 L
.36252 .16308 L
.3675 .15903 L
.37193 .15551 L
.37508 .15307 L
.38186 .14794 L
.38265 .14735 L
.39022 .14187 L
.39234 .14037 L
.39779 .1366 L
.40345 .1328 L
.40536 .13154 L
.41293 .12668 L
.41526 .12523 L
.4205 .12201 L
.42785 .11766 L
.42807 .11753 L
.43565 .11322 L
.44135 .11008 L
.44322 .10908 L
.45079 .1051 L
.45589 .10251 L
.45836 .10129 L
.46593 .09762 L
.47168 .09494 L
.4735 .09411 L
.48107 .09074 L
.48864 .08751 L
.48898 .08737 L
.49621 .08442 L
.50379 .08145 L
.50816 .0798 L
.51136 .07862 L
.51893 .07591 L
.5265 .07332 L
.52981 .07223 L
.53407 .07085 L
.54164 .0685 L
.54921 .06626 L
.55485 .06466 L
.55678 .06412 L
.56435 .0621 L
.57193 .06018 L
.5795 .05836 L
.58504 .05709 L
.58707 .05663 L
.59464 .05501 L
.60221 .05347 L
.60978 .05203 L
.61735 .05068 L
.62426 .04952 L
.62492 .04941 L
.6325 .04822 L
.64007 .04711 L
.64764 .04608 L
.65521 .04512 L
.66278 .04423 L
.67035 .04341 L
.67792 .04265 L
.68549 .04195 L
.68557 .04194 L
.69306 .0413 L
.70064 .04071 L
.70821 .04015 L
.71578 .03964 L
.72335 .03916 L
.73092 .0387 L
.73849 .03826 L
.74606 .03783 L
.75363 .0374 L
.76121 .03695 L
.76878 .03647 L
.77635 .03596 L
.78392 .03537 L
.79149 .0347 L
.79484 .03437 L
.79906 .03392 L
.80663 .03299 L
.8142 .03186 L
.82177 .03048 L
.82935 .02876 L
.83628 .0268 L
.83692 .0266 L
.84449 .02382 L
.85206 .02017 L
.85368 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 .496 .091 r
.90776 .98077 m
.90506 .97342 L
.90495 .9732 L
.90025 .96563 L
.89749 .96246 L
.89246 .95806 L
.88992 .95627 L
.88234 .95215 L
.87831 .95048 L
.87477 .94925 L
.8672 .94716 L
.85963 .94564 L
.85206 .94454 L
.84449 .94376 L
.83692 .94323 L
.83029 .94291 L
.82935 .94288 L
.82177 .94268 L
.8142 .94258 L
.80663 .94257 L
.79906 .94261 L
.79149 .94269 L
.78392 .9428 L
.77676 .94291 L
.77635 .94292 L
.76878 .94304 L
.76121 .94314 L
.75363 .94322 L
.74606 .94328 L
.73849 .9433 L
.73092 .94327 L
.72335 .9432 L
.71578 .94308 L
.70861 .94291 L
.70821 .9429 L
.70064 .94266 L
.69306 .94236 L
.68549 .94198 L
.67792 .94154 L
.67035 .94102 L
.66278 .94042 L
.65521 .93975 L
.64764 .93899 L
.64007 .93814 L
.6325 .93721 L
.62492 .93619 L
.61913 .93534 L
.61735 .93507 L
.60978 .93386 L
.60221 .93255 L
.59464 .93115 L
.58707 .92964 L
.5795 .92802 L
.57836 .92777 L
.57193 .9263 L
.56435 .92447 L
.55678 .92253 L
.54921 .92048 L
.54823 .9202 L
.54164 .9183 L
.53407 .91601 L
.5265 .9136 L
.52357 .91263 L
.51893 .91106 L
.51136 .90839 L
.50379 .90559 L
.50239 .90506 L
.49621 .90265 L
.48864 .89957 L
.48369 .89749 L
.48107 .89636 L
.4735 .89299 L
.46687 .88992 L
.46593 .88947 L
.45836 .8858 L
.45153 .88234 L
.45079 .88196 L
.44322 .87796 L
.43742 .87477 L
.43565 .87378 L
.42807 .86942 L
.42433 .8672 L
.4205 .86488 L
.41293 .86014 L
.41213 .85963 L
.40536 .8552 L
.4007 .85206 L
.39779 .85005 L
.39022 .84468 L
.38996 .84449 L
.38265 .83907 L
.37982 .83692 L
.37508 .83322 L
.37023 .82935 L
.3675 .82711 L
.36115 .82177 L
.35993 .82073 L
.35252 .8142 L
.35236 .81406 L
.34479 .80708 L
.34432 .80663 L
.33722 .79976 L
.33651 .79906 L
.32965 .79209 L
.32907 .79149 L
.32208 .78403 L
.32198 .78392 L
.3152 .77635 L
.31451 .77555 L
.30874 .76878 L
.30694 .76661 L
.30256 .76121 L
.29936 .75715 L
.29665 .75363 L
.29179 .74713 L
.29101 .74606 L
.28562 .73849 L
.28422 .73647 L
.28047 .73092 L
.27665 .72507 L
.27555 .72335 L
.27086 .71578 L
.26908 .71282 L
.26638 .70821 L
.2621 .70064 L
.26151 .69955 L
.25803 .69306 L
.25415 .68549 L
.25394 .68507 L
.25046 .67792 L
.24696 .67035 L
.24637 .66904 L
.24363 .66278 L
.24048 .65521 L
.23879 .65097 L
.23751 .64764 L
.2347 .64007 L
.23205 .6325 L
.23122 .63003 L
.22957 .62492 L
.22724 .61735 L
.22508 .60978 L
.22365 .60448 L
.22306 .60221 L
.2212 .59464 L
.21949 .58707 L
.21793 .5795 L
.21651 .57193 L
.21608 .56944 L
.21524 .56435 L
.21412 .55678 L
.21314 .54921 L
.21229 .54164 L
.2116 .53407 L
.21104 .5265 L
.21062 .51893 L
.21034 .51136 L
.2102 .50379 L
.2102 .49621 L
.21034 .48864 L
.21062 .48107 L
.21104 .4735 L
.2116 .46593 L
.21229 .45836 L
.21314 .45079 L
.21412 .44322 L
.21524 .43565 L
.21608 .43056 L
.21651 .42807 L
.21793 .4205 L
.21949 .41293 L
.2212 .40536 L
.22306 .39779 L
.22365 .39552 L
.22508 .39022 L
.22724 .38265 L
.22957 .37508 L
.23122 .36997 L
.23205 .3675 L
.2347 .35993 L
.23751 .35236 L
.23879 .34903 L
.24048 .34479 L
.24363 .33722 L
.24637 .33096 L
.24696 .32965 L
.25046 .32208 L
.25394 .31493 L
.25415 .31451 L
.25803 .30694 L
.26151 .30045 L
.2621 .29936 L
.26638 .29179 L
.26908 .28718 L
.27086 .28422 L
.27555 .27665 L
.27665 .27493 L
.28047 .26908 L
.28422 .26353 L
.28562 .26151 L
.29101 .25394 L
.29179 .25287 L
.29665 .24637 L
.29936 .24285 L
.30256 .23879 L
.30694 .23339 L
.30874 .23122 L
.31451 .22445 L
.3152 .22365 L
.32198 .21608 L
.32208 .21597 L
.32907 .20851 L
.32965 .20791 L
.33651 .20094 L
.33722 .20024 L
.34432 .19337 L
.34479 .19292 L
.35236 .18594 L
.35252 .1858 L
.35993 .17927 L
.36115 .17823 L
.3675 .17289 L
.37023 .17065 L
.37508 .16678 L
.37982 .16308 L
.38265 .16093 L
.38996 .15551 L
.39022 .15532 L
.39779 .14995 L
.4007 .14794 L
.40536 .1448 L
.41213 .14037 L
.41293 .13986 L
.4205 .13512 L
.42433 .1328 L
.42807 .13058 L
.43565 .12622 L
.43742 .12523 L
.44322 .12204 L
.45079 .11804 L
.45153 .11766 L
.45836 .1142 L
.46593 .11053 L
.46687 .11008 L
.4735 .10701 L
.48107 .10364 L
.48369 .10251 L
.48864 .10043 L
.49621 .09735 L
.50239 .09494 L
.50379 .09441 L
.51136 .09161 L
.51893 .08894 L
.52357 .08737 L
.5265 .0864 L
.53407 .08399 L
.54164 .0817 L
.54823 .0798 L
.54921 .07952 L
.55678 .07747 L
.56435 .07553 L
.57193 .0737 L
.57836 .07223 L
.5795 .07198 L
.58707 .07036 L
.59464 .06885 L
.60221 .06745 L
.60978 .06614 L
.61735 .06493 L
.61913 .06466 L
.62492 .06381 L
.6325 .06279 L
.64007 .06186 L
.64764 .06101 L
.65521 .06025 L
.66278 .05958 L
.67035 .05898 L
.67792 .05846 L
.68549 .05802 L
.69306 .05764 L
.70064 .05734 L
.70821 .0571 L
.70861 .05709 L
.71578 .05692 L
.72335 .0568 L
.73092 .05673 L
.73849 .0567 L
.74606 .05672 L
.75363 .05678 L
.76121 .05686 L
.76878 .05696 L
.77635 .05708 L
.77676 .05709 L
.78392 .0572 L
.79149 .05731 L
.79906 .05739 L
.80663 .05743 L
.8142 .05742 L
.82177 .05732 L
.82935 .05712 L
.83029 .05709 L
.83692 .05677 L
.84449 .05624 L
.85206 .05546 L
.85963 .05436 L
.8672 .05284 L
.87477 .05075 L
.87831 .04952 L
.88234 .04785 L
.88992 .04373 L
.89246 .04194 L
.89749 .03754 L
.90025 .03437 L
.90495 .0268 L
.90506 .02658 L
.90776 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 .478 .125 r
.94203 .98077 m
.9428 .9732 L
.94291 .97101 L
.94298 .96563 L
.94291 .96368 L
.94244 .95806 L
.941 .95048 L
.93833 .94291 L
.93534 .93744 L
.93386 .93534 L
.92777 .92896 L
.92627 .92777 L
.9202 .92394 L
.91263 .92071 L
.91111 .9202 L
.90506 .91857 L
.89749 .9172 L
.88992 .91637 L
.88234 .91594 L
.87477 .91583 L
.8672 .91594 L
.85963 .91624 L
.85206 .91668 L
.84449 .91722 L
.83692 .91783 L
.82935 .9185 L
.82177 .9192 L
.8142 .91992 L
.81125 .9202 L
.80663 .92064 L
.79906 .92136 L
.79149 .92205 L
.78392 .92273 L
.77635 .92336 L
.76878 .92396 L
.76121 .92451 L
.75363 .92501 L
.74606 .92545 L
.73849 .92583 L
.73092 .92615 L
.72335 .92639 L
.71578 .92657 L
.70821 .92667 L
.70064 .92669 L
.69306 .92663 L
.68549 .92649 L
.67792 .92627 L
.67035 .92595 L
.66278 .92555 L
.65521 .92505 L
.64764 .92447 L
.64007 .92378 L
.6325 .923 L
.62492 .92212 L
.61735 .92114 L
.61078 .9202 L
.60978 .92005 L
.60221 .91886 L
.59464 .91756 L
.58707 .91615 L
.5795 .91463 L
.57193 .91299 L
.57032 .91263 L
.56435 .91124 L
.55678 .90937 L
.54921 .90738 L
.54164 .90526 L
.54094 .90506 L
.53407 .90302 L
.5265 .90065 L
.51893 .89814 L
.51701 .89749 L
.51136 .8955 L
.50379 .89272 L
.49651 .88992 L
.49621 .8898 L
.48864 .88673 L
.48107 .88351 L
.47841 .88234 L
.4735 .88014 L
.46593 .8766 L
.46214 .87477 L
.45836 .8729 L
.45079 .86903 L
.44732 .8672 L
.44322 .86499 L
.43565 .86076 L
.43368 .85963 L
.42807 .85634 L
.42104 .85206 L
.4205 .85172 L
.41293 .8469 L
.40926 .84449 L
.40536 .84186 L
.39823 .83692 L
.39779 .8366 L
.39022 .83111 L
.38786 .82935 L
.38265 .82536 L
.37809 .82177 L
.37508 .81935 L
.36885 .8142 L
.3675 .81306 L
.3601 .80663 L
.35993 .80648 L
.35236 .79959 L
.3518 .79906 L
.34479 .79235 L
.34391 .79149 L
.33722 .78475 L
.33641 .78392 L
.32965 .77676 L
.32927 .77635 L
.32246 .76878 L
.32208 .76834 L
.31597 .76121 L
.31451 .75944 L
.30979 .75363 L
.30694 .75002 L
.30388 .74606 L
.29936 .74002 L
.29825 .73849 L
.29287 .73092 L
.29179 .72935 L
.28775 .72335 L
.28422 .71793 L
.28286 .71578 L
.27819 .70821 L
.27665 .70562 L
.27375 .70064 L
.26952 .69306 L
.26908 .69225 L
.2655 .68549 L
.26168 .67792 L
.26151 .67758 L
.25804 .67035 L
.2546 .66278 L
.25394 .66127 L
.25134 .65521 L
.24826 .64764 L
.24637 .64274 L
.24536 .64007 L
.24263 .6325 L
.24007 .62492 L
.23879 .62098 L
.23767 .61735 L
.23543 .60978 L
.23335 .60221 L
.23143 .59464 L
.23122 .59377 L
.22967 .58707 L
.22806 .5795 L
.2266 .57193 L
.22529 .56435 L
.22413 .55678 L
.22365 .55333 L
.22312 .54921 L
.22226 .54164 L
.22153 .53407 L
.22096 .5265 L
.22053 .51893 L
.22024 .51136 L
.2201 .50379 L
.2201 .49621 L
.22024 .48864 L
.22053 .48107 L
.22096 .4735 L
.22153 .46593 L
.22226 .45836 L
.22312 .45079 L
.22365 .44667 L
.22413 .44322 L
.22529 .43565 L
.2266 .42807 L
.22806 .4205 L
.22967 .41293 L
.23122 .40623 L
.23143 .40536 L
.23335 .39779 L
.23543 .39022 L
.23767 .38265 L
.23879 .37902 L
.24007 .37508 L
.24263 .3675 L
.24536 .35993 L
.24637 .35726 L
.24826 .35236 L
.25134 .34479 L
.25394 .33873 L
.2546 .33722 L
.25804 .32965 L
.26151 .32242 L
.26168 .32208 L
.2655 .31451 L
.26908 .30775 L
.26952 .30694 L
.27375 .29936 L
.27665 .29438 L
.27819 .29179 L
.28286 .28422 L
.28422 .28207 L
.28775 .27665 L
.29179 .27065 L
.29287 .26908 L
.29825 .26151 L
.29936 .25998 L
.30388 .25394 L
.30694 .24998 L
.30979 .24637 L
.31451 .24056 L
.31597 .23879 L
.32208 .23166 L
.32246 .23122 L
.32927 .22365 L
.32965 .22324 L
.33641 .21608 L
.33722 .21525 L
.34391 .20851 L
.34479 .20765 L
.3518 .20094 L
.35236 .20041 L
.35993 .19352 L
.3601 .19337 L
.3675 .18694 L
.36885 .1858 L
.37508 .18065 L
.37809 .17823 L
.38265 .17464 L
.38786 .17065 L
.39022 .16889 L
.39779 .1634 L
.39823 .16308 L
.40536 .15814 L
.40926 .15551 L
.41293 .1531 L
.4205 .14828 L
.42104 .14794 L
.42807 .14366 L
.43368 .14037 L
.43565 .13924 L
.44322 .13501 L
.44732 .1328 L
.45079 .13097 L
.45836 .1271 L
.46214 .12523 L
.46593 .1234 L
.4735 .11986 L
.47841 .11766 L
.48107 .11649 L
.48864 .11327 L
.49621 .1102 L
.49651 .11008 L
.50379 .10728 L
.51136 .1045 L
.51701 .10251 L
.51893 .10186 L
.5265 .09935 L
.53407 .09698 L
.54094 .09494 L
.54164 .09474 L
.54921 .09262 L
.55678 .09063 L
.56435 .08876 L
.57032 .08737 L
.57193 .08701 L
.5795 .08537 L
.58707 .08385 L
.59464 .08244 L
.60221 .08114 L
.60978 .07995 L
.61078 .0798 L
.61735 .07886 L
.62492 .07788 L
.6325 .077 L
.64007 .07622 L
.64764 .07553 L
.65521 .07495 L
.66278 .07445 L
.67035 .07405 L
.67792 .07373 L
.68549 .07351 L
.69306 .07337 L
.70064 .07331 L
.70821 .07333 L
.71578 .07343 L
.72335 .07361 L
.73092 .07385 L
.73849 .07417 L
.74606 .07455 L
.75363 .07499 L
.76121 .07549 L
.76878 .07604 L
.77635 .07664 L
.78392 .07727 L
.79149 .07795 L
.79906 .07864 L
.80663 .07936 L
.81125 .0798 L
.8142 .08008 L
.82177 .0808 L
.82935 .0815 L
.83692 .08217 L
.84449 .08278 L
.85206 .08332 L
.85963 .08376 L
.8672 .08406 L
.87477 .08417 L
.88234 .08406 L
.88992 .08363 L
.89749 .0828 L
.90506 .08143 L
.91111 .0798 L
.91263 .07929 L
.9202 .07606 L
.92627 .07223 L
.92777 .07104 L
.93386 .06466 L
.93534 .06256 L
.93833 .05709 L
.941 .04952 L
.94244 .04194 L
.94291 .03632 L
.94298 .03437 L
.94291 .02899 L
.9428 .0268 L
.94203 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 .46 .156 r
.96774 .98077 m
.97002 .9732 L
.97199 .96563 L
.9732 .96032 L
.97364 .95806 L
.97493 .95048 L
.97581 .94291 L
.97622 .93534 L
.97607 .92777 L
.97523 .9202 L
.9735 .91263 L
.9732 .91163 L
.97052 .90506 L
.96563 .89759 L
.96554 .89749 L
.95806 .89082 L
.95664 .88992 L
.95048 .88688 L
.94291 .88453 L
.93534 .88322 L
.92777 .88263 L
.9202 .88258 L
.91263 .88291 L
.90506 .88355 L
.89749 .88441 L
.88992 .88545 L
.88234 .88662 L
.87477 .88789 L
.8672 .88922 L
.86335 .88992 L
.85963 .8906 L
.85206 .892 L
.84449 .89341 L
.83692 .89482 L
.82935 .89621 L
.82228 .89749 L
.82177 .89758 L
.8142 .89891 L
.80663 .9002 L
.79906 .90144 L
.79149 .90262 L
.78392 .90375 L
.77635 .90481 L
.77452 .90506 L
.76878 .90581 L
.76121 .90673 L
.75363 .90757 L
.74606 .90834 L
.73849 .90903 L
.73092 .90964 L
.72335 .91016 L
.71578 .91059 L
.70821 .91093 L
.70064 .91119 L
.69306 .91134 L
.68549 .91141 L
.67792 .91137 L
.67035 .91124 L
.66278 .91101 L
.65521 .91067 L
.64764 .91024 L
.64007 .9097 L
.6325 .90905 L
.62492 .90829 L
.61735 .90743 L
.60978 .90645 L
.60221 .90536 L
.60025 .90506 L
.59464 .90415 L
.58707 .90283 L
.5795 .90139 L
.57193 .89982 L
.56435 .89814 L
.56157 .89749 L
.55678 .89633 L
.54921 .89439 L
.54164 .89232 L
.53407 .89011 L
.53342 .88992 L
.5265 .88777 L
.51893 .88529 L
.51136 .88267 L
.51045 .88234 L
.50379 .8799 L
.49621 .87698 L
.49074 .87477 L
.48864 .87391 L
.48107 .87067 L
.4735 .86728 L
.47333 .8672 L
.46593 .86372 L
.45836 .85998 L
.45767 .85963 L
.45079 .85606 L
.44339 .85206 L
.44322 .85196 L
.43565 .84767 L
.43025 .84449 L
.42807 .84317 L
.4205 .83847 L
.41808 .83692 L
.41293 .83354 L
.40674 .82935 L
.40536 .82839 L
.39779 .823 L
.39611 .82177 L
.39022 .81736 L
.38613 .8142 L
.38265 .81145 L
.37673 .80663 L
.37508 .80525 L
.36785 .79906 L
.3675 .79876 L
.35993 .79195 L
.35944 .79149 L
.35236 .78479 L
.35147 .78392 L
.34479 .77726 L
.3439 .77635 L
.33722 .76932 L
.33671 .76878 L
.32987 .76121 L
.32965 .76095 L
.32336 .75363 L
.32208 .7521 L
.31716 .74606 L
.31451 .7427 L
.31126 .73849 L
.30694 .73271 L
.30563 .73092 L
.30027 .72335 L
.29936 .72203 L
.29517 .71578 L
.29179 .71056 L
.29031 .70821 L
.28569 .70064 L
.28422 .69816 L
.28129 .69306 L
.2771 .68549 L
.27665 .68465 L
.27313 .67792 L
.26936 .67035 L
.26908 .66976 L
.2658 .66278 L
.26242 .65521 L
.26151 .65309 L
.25923 .64764 L
.25622 .64007 L
.25394 .63398 L
.2534 .6325 L
.25075 .62492 L
.24827 .61735 L
.24637 .61116 L
.24596 .60978 L
.24381 .60221 L
.24183 .59464 L
.24001 .58707 L
.23879 .5816 L
.23835 .5795 L
.23684 .57193 L
.2355 .56435 L
.2343 .55678 L
.23326 .54921 L
.23236 .54164 L
.23162 .53407 L
.23122 .52926 L
.23103 .5265 L
.23058 .51893 L
.23029 .51136 L
.23014 .50379 L
.23014 .49621 L
.23029 .48864 L
.23058 .48107 L
.23103 .4735 L
.23122 .47074 L
.23162 .46593 L
.23236 .45836 L
.23326 .45079 L
.2343 .44322 L
.2355 .43565 L
.23684 .42807 L
.23835 .4205 L
.23879 .4184 L
.24001 .41293 L
.24183 .40536 L
.24381 .39779 L
.24596 .39022 L
.24637 .38884 L
.24827 .38265 L
.25075 .37508 L
.2534 .3675 L
.25394 .36602 L
.25622 .35993 L
.25923 .35236 L
.26151 .34691 L
.26242 .34479 L
.2658 .33722 L
.26908 .33024 L
.26936 .32965 L
.27313 .32208 L
.27665 .31535 L
.2771 .31451 L
.28129 .30694 L
.28422 .30184 L
.28569 .29936 L
.29031 .29179 L
.29179 .28944 L
.29517 .28422 L
.29936 .27797 L
.30027 .27665 L
.30563 .26908 L
.30694 .26729 L
.31126 .26151 L
.31451 .2573 L
.31716 .25394 L
.32208 .2479 L
.32336 .24637 L
.32965 .23905 L
.32987 .23879 L
.33671 .23122 L
.33722 .23068 L
.3439 .22365 L
.34479 .22274 L
.35147 .21608 L
.35236 .21521 L
.35944 .20851 L
.35993 .20805 L
.3675 .20124 L
.36785 .20094 L
.37508 .19475 L
.37673 .19337 L
.38265 .18855 L
.38613 .1858 L
.39022 .18264 L
.39611 .17823 L
.39779 .177 L
.40536 .17161 L
.40674 .17065 L
.41293 .16646 L
.41808 .16308 L
.4205 .16153 L
.42807 .15683 L
.43025 .15551 L
.43565 .15233 L
.44322 .14804 L
.44339 .14794 L
.45079 .14394 L
.45767 .14037 L
.45836 .14002 L
.46593 .13628 L
.47333 .1328 L
.4735 .13272 L
.48107 .12933 L
.48864 .12609 L
.49074 .12523 L
.49621 .12302 L
.50379 .1201 L
.51045 .11766 L
.51136 .11733 L
.51893 .11471 L
.5265 .11223 L
.53342 .11008 L
.53407 .10989 L
.54164 .10768 L
.54921 .10561 L
.55678 .10367 L
.56157 .10251 L
.56435 .10186 L
.57193 .10018 L
.5795 .09861 L
.58707 .09717 L
.59464 .09585 L
.60025 .09494 L
.60221 .09464 L
.60978 .09355 L
.61735 .09257 L
.62492 .09171 L
.6325 .09095 L
.64007 .0903 L
.64764 .08976 L
.65521 .08933 L
.66278 .08899 L
.67035 .08876 L
.67792 .08863 L
.68549 .08859 L
.69306 .08866 L
.70064 .08881 L
.70821 .08907 L
.71578 .08941 L
.72335 .08984 L
.73092 .09036 L
.73849 .09097 L
.74606 .09166 L
.75363 .09243 L
.76121 .09327 L
.76878 .09419 L
.77452 .09494 L
.77635 .09519 L
.78392 .09625 L
.79149 .09738 L
.79906 .09856 L
.80663 .0998 L
.8142 .10109 L
.82177 .10242 L
.82228 .10251 L
.82935 .10379 L
.83692 .10518 L
.84449 .10659 L
.85206 .108 L
.85963 .1094 L
.86335 .11008 L
.8672 .11078 L
.87477 .11211 L
.88234 .11338 L
.88992 .11455 L
.89749 .11559 L
.90506 .11645 L
.91263 .11709 L
.9202 .11742 L
.92777 .11737 L
.93534 .11678 L
.94291 .11547 L
.95048 .11312 L
.95664 .11008 L
.95806 .10918 L
.96554 .10251 L
.96563 .10241 L
.97052 .09494 L
.9732 .08837 L
.9735 .08737 L
.97523 .0798 L
.97607 .07223 L
.97622 .06466 L
.97581 .05709 L
.97493 .04952 L
.97364 .04194 L
.9732 .03968 L
.97199 .03437 L
.97002 .0268 L
.96774 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 .442 .185 r
.98077 .84349 m
.9732 .8421 L
.96563 .84172 L
.95806 .84206 L
.95048 .84292 L
.94291 .84417 L
.94118 .84449 L
.93534 .84571 L
.92777 .84748 L
.9202 .84941 L
.91263 .85147 L
.91049 .85206 L
.90506 .8536 L
.89749 .8558 L
.88992 .85802 L
.88446 .85963 L
.88234 .86026 L
.87477 .86249 L
.8672 .8647 L
.85963 .86689 L
.85853 .8672 L
.85206 .86903 L
.84449 .87113 L
.83692 .87317 L
.83082 .87477 L
.82935 .87515 L
.82177 .87707 L
.8142 .87891 L
.80663 .88067 L
.79914 .88234 L
.79906 .88236 L
.79149 .88396 L
.78392 .88548 L
.77635 .88692 L
.76878 .88826 L
.76121 .88951 L
.7586 .88992 L
.75363 .89066 L
.74606 .89172 L
.73849 .89269 L
.73092 .89355 L
.72335 .89432 L
.71578 .89498 L
.70821 .89554 L
.70064 .896 L
.69306 .89635 L
.68549 .8966 L
.67792 .89674 L
.67035 .89677 L
.66278 .8967 L
.65521 .89651 L
.64764 .89621 L
.64007 .8958 L
.6325 .89527 L
.62492 .89463 L
.61735 .89386 L
.60978 .89298 L
.60221 .89198 L
.59464 .89086 L
.58882 .88992 L
.58707 .88962 L
.5795 .88824 L
.57193 .88674 L
.56435 .88511 L
.55678 .88335 L
.55271 .88234 L
.54921 .88145 L
.54164 .87942 L
.53407 .87724 L
.5265 .87492 L
.52603 .87477 L
.51893 .87246 L
.51136 .86984 L
.50413 .8672 L
.50379 .86707 L
.49621 .86415 L
.48864 .86106 L
.48527 .85963 L
.48107 .8578 L
.4735 .85438 L
.46859 .85206 L
.46593 .85077 L
.45836 .84699 L
.45356 .84449 L
.45079 .84301 L
.44322 .83884 L
.43984 .83692 L
.43565 .83446 L
.42807 .82988 L
.42722 .82935 L
.4205 .82506 L
.41552 .82177 L
.41293 .82002 L
.40536 .81473 L
.40462 .8142 L
.39779 .80919 L
.39441 .80663 L
.39022 .80337 L
.38483 .79906 L
.38265 .79727 L
.3758 .79149 L
.37508 .79086 L
.3675 .78413 L
.36728 .78392 L
.35993 .77704 L
.35921 .77635 L
.35236 .76957 L
.35158 .76878 L
.34479 .76169 L
.34433 .76121 L
.33746 .75363 L
.33722 .75337 L
.33092 .74606 L
.32965 .74454 L
.32471 .73849 L
.32208 .73516 L
.31881 .73092 L
.31451 .72516 L
.31319 .72335 L
.30785 .71578 L
.30694 .71444 L
.30277 .70821 L
.29936 .70291 L
.29794 .70064 L
.29335 .69306 L
.29179 .6904 L
.289 .68549 L
.28487 .67792 L
.28422 .67671 L
.28095 .67035 L
.27724 .66278 L
.27665 .66153 L
.27374 .65521 L
.27043 .64764 L
.26908 .64442 L
.26731 .64007 L
.26438 .6325 L
.26164 .62492 L
.26151 .62455 L
.25907 .61735 L
.25668 .60978 L
.25446 .60221 L
.25394 .60032 L
.25242 .59464 L
.25054 .58707 L
.24882 .5795 L
.24726 .57193 L
.24637 .56715 L
.24587 .56435 L
.24464 .55678 L
.24356 .54921 L
.24264 .54164 L
.24187 .53407 L
.24126 .5265 L
.2408 .51893 L
.2405 .51136 L
.24034 .50379 L
.24034 .49621 L
.2405 .48864 L
.2408 .48107 L
.24126 .4735 L
.24187 .46593 L
.24264 .45836 L
.24356 .45079 L
.24464 .44322 L
.24587 .43565 L
.24637 .43285 L
.24726 .42807 L
.24882 .4205 L
.25054 .41293 L
.25242 .40536 L
.25394 .39968 L
.25446 .39779 L
.25668 .39022 L
.25907 .38265 L
.26151 .37545 L
.26164 .37508 L
.26438 .3675 L
.26731 .35993 L
.26908 .35558 L
.27043 .35236 L
.27374 .34479 L
.27665 .33847 L
.27724 .33722 L
.28095 .32965 L
.28422 .32329 L
.28487 .32208 L
.289 .31451 L
.29179 .3096 L
.29335 .30694 L
.29794 .29936 L
.29936 .29709 L
.30277 .29179 L
.30694 .28556 L
.30785 .28422 L
.31319 .27665 L
.31451 .27484 L
.31881 .26908 L
.32208 .26484 L
.32471 .26151 L
.32965 .25546 L
.33092 .25394 L
.33722 .24663 L
.33746 .24637 L
.34433 .23879 L
.34479 .23831 L
.35158 .23122 L
.35236 .23043 L
.35921 .22365 L
.35993 .22296 L
.36728 .21608 L
.3675 .21587 L
.37508 .20914 L
.3758 .20851 L
.38265 .20273 L
.38483 .20094 L
.39022 .19663 L
.39441 .19337 L
.39779 .19081 L
.40462 .1858 L
.40536 .18527 L
.41293 .17998 L
.41552 .17823 L
.4205 .17494 L
.42722 .17065 L
.42807 .17012 L
.43565 .16554 L
.43984 .16308 L
.44322 .16116 L
.45079 .15699 L
.45356 .15551 L
.45836 .15301 L
.46593 .14923 L
.46859 .14794 L
.4735 .14562 L
.48107 .1422 L
.48527 .14037 L
.48864 .13894 L
.49621 .13585 L
.50379 .13293 L
.50413 .1328 L
.51136 .13016 L
.51893 .12754 L
.52603 .12523 L
.5265 .12508 L
.53407 .12276 L
.54164 .12058 L
.54921 .11855 L
.55271 .11766 L
.55678 .11665 L
.56435 .11489 L
.57193 .11326 L
.5795 .11176 L
.58707 .11038 L
.58882 .11008 L
.59464 .10914 L
.60221 .10802 L
.60978 .10702 L
.61735 .10614 L
.62492 .10537 L
.6325 .10473 L
.64007 .1042 L
.64764 .10379 L
.65521 .10349 L
.66278 .1033 L
.67035 .10323 L
.67792 .10326 L
.68549 .1034 L
.69306 .10365 L
.70064 .104 L
.70821 .10446 L
.71578 .10502 L
.72335 .10568 L
.73092 .10645 L
.73849 .10731 L
.74606 .10828 L
.75363 .10934 L
.7586 .11008 L
.76121 .11049 L
.76878 .11174 L
.77635 .11308 L
.78392 .11452 L
.79149 .11604 L
.79906 .11764 L
.79914 .11766 L
.80663 .11933 L
.8142 .12109 L
.82177 .12293 L
.82935 .12485 L
.83082 .12523 L
.83692 .12683 L
.84449 .12887 L
.85206 .13097 L
.85853 .1328 L
.85963 .13311 L
.8672 .1353 L
.87477 .13751 L
.88234 .13974 L
.88446 .14037 L
.88992 .14198 L
.89749 .1442 L
.90506 .1464 L
.91049 .14794 L
.91263 .14853 L
.9202 .15059 L
.92777 .15252 L
.93534 .15429 L
.94118 .15551 L
.94291 .15583 L
.95048 .15708 L
.95806 .15794 L
.96563 .15828 L
.9732 .1579 L
.98077 .15651 L
F
0 .424 .21 r
.98077 .79503 m
.9732 .79748 L
.96872 .79906 L
.96563 .80022 L
.95806 .80317 L
.95048 .80627 L
.94962 .80663 L
.94291 .80947 L
.93534 .81274 L
.93197 .8142 L
.92777 .81604 L
.9202 .81934 L
.91461 .82177 L
.91263 .82263 L
.90506 .8259 L
.89749 .82912 L
.89694 .82935 L
.88992 .83228 L
.88234 .83539 L
.87855 .83692 L
.87477 .83842 L
.8672 .84137 L
.85963 .84425 L
.85898 .84449 L
.85206 .84703 L
.84449 .84972 L
.83769 .85206 L
.83692 .85232 L
.82935 .85482 L
.82177 .85722 L
.8142 .85952 L
.81382 .85963 L
.80663 .86171 L
.79906 .8638 L
.79149 .86579 L
.78583 .8672 L
.78392 .86767 L
.77635 .86943 L
.76878 .8711 L
.76121 .87265 L
.75363 .87409 L
.7498 .87477 L
.74606 .87541 L
.73849 .87663 L
.73092 .87774 L
.72335 .87873 L
.71578 .87961 L
.70821 .88037 L
.70064 .88102 L
.69306 .88156 L
.68549 .88198 L
.67792 .88228 L
.67677 .88234 L
.67035 .88246 L
.66278 .88253 L
.65521 .88248 L
.64902 .88234 L
.64764 .8823 L
.64007 .88201 L
.6325 .88159 L
.62492 .88105 L
.61735 .88039 L
.60978 .8796 L
.60221 .87868 L
.59464 .87763 L
.58707 .87645 L
.5795 .87514 L
.57751 .87477 L
.57193 .87369 L
.56435 .87211 L
.55678 .87039 L
.54921 .86852 L
.54417 .8672 L
.54164 .86651 L
.53407 .86436 L
.5265 .86205 L
.51904 .85963 L
.51893 .85959 L
.51136 .85697 L
.50379 .8542 L
.49825 .85206 L
.49621 .85125 L
.48864 .84814 L
.48107 .84485 L
.48026 .84449 L
.4735 .84138 L
.46593 .83772 L
.46431 .83692 L
.45836 .83388 L
.45079 .82983 L
.44991 .82935 L
.44322 .82557 L
.43677 .82177 L
.43565 .8211 L
.42807 .8164 L
.42466 .8142 L
.4205 .81146 L
.41344 .80663 L
.41293 .80628 L
.40536 .80083 L
.40298 .79906 L
.39779 .79511 L
.39319 .79149 L
.39022 .78909 L
.384 .78392 L
.38265 .78276 L
.37535 .77635 L
.37508 .7761 L
.3675 .76908 L
.36719 .76878 L
.35993 .76167 L
.35947 .76121 L
.35236 .75384 L
.35217 .75363 L
.34525 .74606 L
.34479 .74554 L
.33869 .73849 L
.33722 .73674 L
.33247 .73092 L
.32965 .72736 L
.32656 .72335 L
.32208 .71733 L
.32095 .71578 L
.31563 .70821 L
.31451 .70656 L
.31057 .70064 L
.30694 .69493 L
.30578 .69306 L
.30123 .68549 L
.29936 .68227 L
.29692 .67792 L
.29283 .67035 L
.29179 .66835 L
.28897 .66278 L
.28533 .65521 L
.28422 .65282 L
.28189 .64764 L
.27866 .64007 L
.27665 .63513 L
.27562 .6325 L
.27277 .62492 L
.27011 .61735 L
.26908 .61428 L
.26763 .60978 L
.26533 .60221 L
.26321 .59464 L
.26151 .58805 L
.26127 .58707 L
.25949 .5795 L
.25788 .57193 L
.25644 .56435 L
.25517 .55678 L
.25405 .54921 L
.25394 .54837 L
.2531 .54164 L
.25231 .53407 L
.25168 .5265 L
.2512 .51893 L
.25089 .51136 L
.25073 .50379 L
.25073 .49621 L
.25089 .48864 L
.2512 .48107 L
.25168 .4735 L
.25231 .46593 L
.2531 .45836 L
.25394 .45163 L
.25405 .45079 L
.25517 .44322 L
.25644 .43565 L
.25788 .42807 L
.25949 .4205 L
.26127 .41293 L
.26151 .41195 L
.26321 .40536 L
.26533 .39779 L
.26763 .39022 L
.26908 .38572 L
.27011 .38265 L
.27277 .37508 L
.27562 .3675 L
.27665 .36487 L
.27866 .35993 L
.28189 .35236 L
.28422 .34718 L
.28533 .34479 L
.28897 .33722 L
.29179 .33165 L
.29283 .32965 L
.29692 .32208 L
.29936 .31773 L
.30123 .31451 L
.30578 .30694 L
.30694 .30507 L
.31057 .29936 L
.31451 .29344 L
.31563 .29179 L
.32095 .28422 L
.32208 .28267 L
.32656 .27665 L
.32965 .27264 L
.33247 .26908 L
.33722 .26326 L
.33869 .26151 L
.34479 .25446 L
.34525 .25394 L
.35217 .24637 L
.35236 .24616 L
.35947 .23879 L
.35993 .23833 L
.36719 .23122 L
.3675 .23092 L
.37508 .2239 L
.37535 .22365 L
.38265 .21724 L
.384 .21608 L
.39022 .21091 L
.39319 .20851 L
.39779 .20489 L
.40298 .20094 L
.40536 .19917 L
.41293 .19372 L
.41344 .19337 L
.4205 .18854 L
.42466 .1858 L
.42807 .1836 L
.43565 .1789 L
.43677 .17823 L
.44322 .17443 L
.44991 .17065 L
.45079 .17017 L
.45836 .16612 L
.46431 .16308 L
.46593 .16228 L
.4735 .15862 L
.48026 .15551 L
.48107 .15515 L
.48864 .15186 L
.49621 .14875 L
.49825 .14794 L
.50379 .1458 L
.51136 .14303 L
.51893 .14041 L
.51904 .14037 L
.5265 .13795 L
.53407 .13564 L
.54164 .13349 L
.54417 .1328 L
.54921 .13148 L
.55678 .12961 L
.56435 .12789 L
.57193 .12631 L
.57751 .12523 L
.5795 .12486 L
.58707 .12355 L
.59464 .12237 L
.60221 .12132 L
.60978 .1204 L
.61735 .11961 L
.62492 .11895 L
.6325 .11841 L
.64007 .11799 L
.64764 .1177 L
.64902 .11766 L
.65521 .11752 L
.66278 .11747 L
.67035 .11754 L
.67677 .11766 L
.67792 .11772 L
.68549 .11802 L
.69306 .11844 L
.70064 .11898 L
.70821 .11963 L
.71578 .12039 L
.72335 .12127 L
.73092 .12226 L
.73849 .12337 L
.74606 .12459 L
.7498 .12523 L
.75363 .12591 L
.76121 .12735 L
.76878 .1289 L
.77635 .13057 L
.78392 .13233 L
.78583 .1328 L
.79149 .13421 L
.79906 .1362 L
.80663 .13829 L
.81382 .14037 L
.8142 .14048 L
.82177 .14278 L
.82935 .14518 L
.83692 .14768 L
.83769 .14794 L
.84449 .15028 L
.85206 .15297 L
.85898 .15551 L
.85963 .15575 L
.8672 .15863 L
.87477 .16158 L
.87855 .16308 L
.88234 .16461 L
.88992 .16772 L
.89694 .17065 L
.89749 .17088 L
.90506 .1741 L
.91263 .17737 L
.91461 .17823 L
.9202 .18066 L
.92777 .18396 L
.93197 .1858 L
.93534 .18726 L
.94291 .19053 L
.94962 .19337 L
.95048 .19373 L
.95806 .19683 L
.96563 .19978 L
.96872 .20094 L
.9732 .20252 L
.98077 .20497 L
F
0 .406 .233 r
.98077 .75241 m
.97889 .75363 L
.9732 .75732 L
.96721 .76121 L
.96563 .76224 L
.95806 .76713 L
.95548 .76878 L
.95048 .77197 L
.94354 .77635 L
.94291 .77674 L
.93534 .78143 L
.93126 .78392 L
.92777 .78603 L
.9202 .79052 L
.91854 .79149 L
.91263 .7949 L
.90524 .79906 L
.90506 .79916 L
.89749 .80331 L
.89124 .80663 L
.88992 .80733 L
.88234 .81122 L
.87637 .8142 L
.87477 .81499 L
.8672 .81862 L
.86042 .82177 L
.85963 .82213 L
.85206 .82551 L
.84449 .82876 L
.84309 .82935 L
.83692 .83188 L
.82935 .83487 L
.82396 .83692 L
.82177 .83773 L
.8142 .84046 L
.80663 .84306 L
.80231 .84449 L
.79906 .84553 L
.79149 .84788 L
.78392 .8501 L
.77682 .85206 L
.77635 .85219 L
.76878 .85415 L
.76121 .85599 L
.75363 .8577 L
.74606 .85928 L
.74431 .85963 L
.73849 .86074 L
.73092 .86208 L
.72335 .86328 L
.71578 .86437 L
.70821 .86533 L
.70064 .86616 L
.69306 .86687 L
.68891 .8672 L
.68549 .86745 L
.67792 .8679 L
.67035 .86823 L
.66278 .86843 L
.65521 .86851 L
.64764 .86845 L
.64007 .86827 L
.6325 .86796 L
.62492 .86751 L
.62061 .8672 L
.61735 .86693 L
.60978 .86622 L
.60221 .86538 L
.59464 .8644 L
.58707 .86328 L
.5795 .86202 L
.57193 .86062 L
.56697 .85963 L
.56435 .85908 L
.55678 .85739 L
.54921 .85555 L
.54164 .85356 L
.53628 .85206 L
.53407 .85142 L
.5265 .84912 L
.51893 .84665 L
.51266 .84449 L
.51136 .84402 L
.50379 .84123 L
.49621 .83825 L
.49295 .83692 L
.48864 .8351 L
.48107 .83177 L
.47582 .82935 L
.4735 .82824 L
.46593 .82452 L
.46059 .82177 L
.45836 .8206 L
.45079 .81646 L
.44682 .8142 L
.44322 .8121 L
.43565 .80751 L
.43424 .80663 L
.42807 .80268 L
.42265 .79906 L
.4205 .7976 L
.41293 .79224 L
.41189 .79149 L
.40536 .78661 L
.40187 .78392 L
.39779 .78068 L
.3925 .77635 L
.39022 .77443 L
.3837 .76878 L
.38265 .76784 L
.37543 .76121 L
.37508 .76088 L
.36762 .75363 L
.3675 .75352 L
.36026 .74606 L
.35993 .74572 L
.35329 .73849 L
.35236 .73745 L
.3467 .73092 L
.34479 .72865 L
.34046 .72335 L
.33722 .71925 L
.33454 .71578 L
.32965 .70918 L
.32894 .70821 L
.32363 .70064 L
.32208 .69834 L
.3186 .69306 L
.31451 .68658 L
.31384 .68549 L
.30933 .67792 L
.30694 .67372 L
.30507 .67035 L
.30104 .66278 L
.29936 .6595 L
.29724 .65521 L
.29366 .64764 L
.29179 .64351 L
.29029 .64007 L
.28713 .6325 L
.28422 .62507 L
.28417 .62492 L
.2814 .61735 L
.27883 .60978 L
.27665 .60287 L
.27645 .60221 L
.27425 .59464 L
.27223 .58707 L
.27039 .5795 L
.26908 .5736 L
.26873 .57193 L
.26723 .56435 L
.26591 .55678 L
.26476 .54921 L
.26377 .54164 L
.26296 .53407 L
.2623 .5265 L
.26181 .51893 L
.26151 .51212 L
.26149 .51136 L
.26132 .50379 L
.26132 .49621 L
.26149 .48864 L
.26151 .48788 L
.26181 .48107 L
.2623 .4735 L
.26296 .46593 L
.26377 .45836 L
.26476 .45079 L
.26591 .44322 L
.26723 .43565 L
.26873 .42807 L
.26908 .4264 L
.27039 .4205 L
.27223 .41293 L
.27425 .40536 L
.27645 .39779 L
.27665 .39713 L
.27883 .39022 L
.2814 .38265 L
.28417 .37508 L
.28422 .37493 L
.28713 .3675 L
.29029 .35993 L
.29179 .35649 L
.29366 .35236 L
.29724 .34479 L
.29936 .3405 L
.30104 .33722 L
.30507 .32965 L
.30694 .32628 L
.30933 .32208 L
.31384 .31451 L
.31451 .31342 L
.3186 .30694 L
.32208 .30166 L
.32363 .29936 L
.32894 .29179 L
.32965 .29082 L
.33454 .28422 L
.33722 .28075 L
.34046 .27665 L
.34479 .27135 L
.3467 .26908 L
.35236 .26255 L
.35329 .26151 L
.35993 .25428 L
.36026 .25394 L
.3675 .24648 L
.36762 .24637 L
.37508 .23912 L
.37543 .23879 L
.38265 .23216 L
.3837 .23122 L
.39022 .22557 L
.3925 .22365 L
.39779 .21932 L
.40187 .21608 L
.40536 .21339 L
.41189 .20851 L
.41293 .20776 L
.4205 .2024 L
.42265 .20094 L
.42807 .19732 L
.43424 .19337 L
.43565 .19249 L
.44322 .1879 L
.44682 .1858 L
.45079 .18354 L
.45836 .1794 L
.46059 .17823 L
.46593 .17548 L
.4735 .17176 L
.47582 .17065 L
.48107 .16823 L
.48864 .1649 L
.49295 .16308 L
.49621 .16175 L
.50379 .15877 L
.51136 .15598 L
.51266 .15551 L
.51893 .15335 L
.5265 .15088 L
.53407 .14858 L
.53628 .14794 L
.54164 .14644 L
.54921 .14445 L
.55678 .14261 L
.56435 .14092 L
.56697 .14037 L
.57193 .13938 L
.5795 .13798 L
.58707 .13672 L
.59464 .1356 L
.60221 .13462 L
.60978 .13378 L
.61735 .13307 L
.62061 .1328 L
.62492 .13249 L
.6325 .13204 L
.64007 .13173 L
.64764 .13155 L
.65521 .13149 L
.66278 .13157 L
.67035 .13177 L
.67792 .1321 L
.68549 .13255 L
.68891 .1328 L
.69306 .13313 L
.70064 .13384 L
.70821 .13467 L
.71578 .13563 L
.72335 .13672 L
.73092 .13792 L
.73849 .13926 L
.74431 .14037 L
.74606 .14072 L
.75363 .1423 L
.76121 .14401 L
.76878 .14585 L
.77635 .14781 L
.77682 .14794 L
.78392 .1499 L
.79149 .15212 L
.79906 .15447 L
.80231 .15551 L
.80663 .15694 L
.8142 .15954 L
.82177 .16227 L
.82396 .16308 L
.82935 .16513 L
.83692 .16812 L
.84309 .17065 L
.84449 .17124 L
.85206 .17449 L
.85963 .17787 L
.86042 .17823 L
.8672 .18138 L
.87477 .18501 L
.87637 .1858 L
.88234 .18878 L
.88992 .19267 L
.89124 .19337 L
.89749 .19669 L
.90506 .20084 L
.90524 .20094 L
.91263 .2051 L
.91854 .20851 L
.9202 .20948 L
.92777 .21397 L
.93126 .21608 L
.93534 .21857 L
.94291 .22326 L
.94354 .22365 L
.95048 .22803 L
.95548 .23122 L
.95806 .23287 L
.96563 .23776 L
.96721 .23879 L
.9732 .24268 L
.97889 .24637 L
.98077 .24759 L
F
0 .388 .253 r
.98077 .7101 m
.97491 .71578 L
.9732 .7174 L
.96683 .72335 L
.96563 .72446 L
.95845 .73092 L
.95806 .73127 L
.95048 .73784 L
.94972 .73849 L
.94291 .74418 L
.94062 .74606 L
.93534 .7503 L
.93109 .75363 L
.92777 .75619 L
.92109 .76121 L
.9202 .76186 L
.91263 .76733 L
.91057 .76878 L
.90506 .77259 L
.89947 .77635 L
.89749 .77765 L
.88992 .78252 L
.88769 .78392 L
.88234 .78721 L
.87514 .79149 L
.87477 .7917 L
.8672 .79602 L
.86167 .79906 L
.85963 .80016 L
.85206 .80413 L
.84711 .80663 L
.84449 .80793 L
.83692 .81156 L
.83119 .8142 L
.82935 .81504 L
.82177 .81835 L
.8142 .82151 L
.81354 .82177 L
.80663 .82451 L
.79906 .82736 L
.79353 .82935 L
.79149 .83006 L
.78392 .83261 L
.77635 .83502 L
.77001 .83692 L
.76878 .83728 L
.76121 .83939 L
.75363 .84137 L
.74606 .84321 L
.7404 .84449 L
.73849 .8449 L
.73092 .84646 L
.72335 .84788 L
.71578 .84916 L
.70821 .85031 L
.70064 .85132 L
.69432 .85206 L
.69306 .85219 L
.68549 .85293 L
.67792 .85354 L
.67035 .854 L
.66278 .85434 L
.65521 .85453 L
.64764 .85459 L
.64007 .85451 L
.6325 .8543 L
.62492 .85395 L
.61735 .85345 L
.60978 .85282 L
.60236 .85206 L
.60221 .85204 L
.59464 .85112 L
.58707 .85006 L
.5795 .84885 L
.57193 .84749 L
.56435 .84598 L
.55754 .84449 L
.55678 .84431 L
.54921 .84249 L
.54164 .84052 L
.53407 .83837 L
.52922 .83692 L
.5265 .83607 L
.51893 .83359 L
.51136 .83094 L
.50702 .82935 L
.50379 .82812 L
.49621 .82511 L
.48864 .82191 L
.48834 .82177 L
.48107 .81851 L
.4735 .81492 L
.47204 .8142 L
.46593 .81112 L
.45836 .8071 L
.45751 .80663 L
.45079 .80285 L
.44435 .79906 L
.44322 .79837 L
.43565 .79365 L
.43232 .79149 L
.42807 .78866 L
.42123 .78392 L
.4205 .7834 L
.41293 .77786 L
.41094 .77635 L
.40536 .77201 L
.40135 .76878 L
.39779 .76583 L
.39239 .76121 L
.39022 .7593 L
.38398 .75363 L
.38265 .75239 L
.37608 .74606 L
.37508 .74507 L
.36863 .73849 L
.3675 .7373 L
.36161 .73092 L
.35993 .72904 L
.35498 .72335 L
.35236 .72023 L
.34872 .71578 L
.34479 .7108 L
.3428 .70821 L
.33722 .70067 L
.3372 .70064 L
.3319 .69306 L
.32965 .68971 L
.3269 .68549 L
.32217 .67792 L
.32208 .67778 L
.3177 .67035 L
.31451 .66466 L
.31348 .66278 L
.30951 .65521 L
.30694 .65005 L
.30577 .64764 L
.30225 .64007 L
.29936 .63346 L
.29896 .6325 L
.29587 .62492 L
.293 .61735 L
.29179 .61401 L
.29032 .60978 L
.28784 .60221 L
.28556 .59464 L
.28422 .58989 L
.28346 .58707 L
.28155 .5795 L
.27982 .57193 L
.27828 .56435 L
.2769 .55678 L
.27665 .55527 L
.27571 .54921 L
.27469 .54164 L
.27384 .53407 L
.27316 .5265 L
.27266 .51893 L
.27232 .51136 L
.27215 .50379 L
.27215 .49621 L
.27232 .48864 L
.27266 .48107 L
.27316 .4735 L
.27384 .46593 L
.27469 .45836 L
.27571 .45079 L
.27665 .44473 L
.2769 .44322 L
.27828 .43565 L
.27982 .42807 L
.28155 .4205 L
.28346 .41293 L
.28422 .41011 L
.28556 .40536 L
.28784 .39779 L
.29032 .39022 L
.29179 .38599 L
.293 .38265 L
.29587 .37508 L
.29896 .3675 L
.29936 .36654 L
.30225 .35993 L
.30577 .35236 L
.30694 .34995 L
.30951 .34479 L
.31348 .33722 L
.31451 .33534 L
.3177 .32965 L
.32208 .32222 L
.32217 .32208 L
.3269 .31451 L
.32965 .31029 L
.3319 .30694 L
.3372 .29936 L
.33722 .29933 L
.3428 .29179 L
.34479 .2892 L
.34872 .28422 L
.35236 .27977 L
.35498 .27665 L
.35993 .27096 L
.36161 .26908 L
.3675 .2627 L
.36863 .26151 L
.37508 .25493 L
.37608 .25394 L
.38265 .24761 L
.38398 .24637 L
.39022 .2407 L
.39239 .23879 L
.39779 .23417 L
.40135 .23122 L
.40536 .22799 L
.41094 .22365 L
.41293 .22214 L
.4205 .2166 L
.42123 .21608 L
.42807 .21134 L
.43232 .20851 L
.43565 .20635 L
.44322 .20163 L
.44435 .20094 L
.45079 .19715 L
.45751 .19337 L
.45836 .1929 L
.46593 .18888 L
.47204 .1858 L
.4735 .18508 L
.48107 .18149 L
.48834 .17823 L
.48864 .17809 L
.49621 .17489 L
.50379 .17188 L
.50702 .17065 L
.51136 .16906 L
.51893 .16641 L
.5265 .16393 L
.52922 .16308 L
.53407 .16163 L
.54164 .15948 L
.54921 .15751 L
.55678 .15569 L
.55754 .15551 L
.56435 .15402 L
.57193 .15251 L
.5795 .15115 L
.58707 .14994 L
.59464 .14888 L
.60221 .14796 L
.60236 .14794 L
.60978 .14718 L
.61735 .14655 L
.62492 .14605 L
.6325 .1457 L
.64007 .14549 L
.64764 .14541 L
.65521 .14547 L
.66278 .14566 L
.67035 .146 L
.67792 .14646 L
.68549 .14707 L
.69306 .14781 L
.69432 .14794 L
.70064 .14868 L
.70821 .14969 L
.71578 .15084 L
.72335 .15212 L
.73092 .15354 L
.73849 .1551 L
.7404 .15551 L
.74606 .15679 L
.75363 .15863 L
.76121 .16061 L
.76878 .16272 L
.77001 .16308 L
.77635 .16498 L
.78392 .16739 L
.79149 .16994 L
.79353 .17065 L
.79906 .17264 L
.80663 .17549 L
.81354 .17823 L
.8142 .17849 L
.82177 .18165 L
.82935 .18496 L
.83119 .1858 L
.83692 .18844 L
.84449 .19207 L
.84711 .19337 L
.85206 .19587 L
.85963 .19984 L
.86167 .20094 L
.8672 .20398 L
.87477 .2083 L
.87514 .20851 L
.88234 .21279 L
.88769 .21608 L
.88992 .21748 L
.89749 .22235 L
.89947 .22365 L
.90506 .22741 L
.91057 .23122 L
.91263 .23267 L
.9202 .23814 L
.92109 .23879 L
.92777 .24381 L
.93109 .24637 L
.93534 .2497 L
.94062 .25394 L
.94291 .25582 L
.94972 .26151 L
.95048 .26216 L
.95806 .26873 L
.95845 .26908 L
.96563 .27554 L
.96683 .27665 L
.9732 .2826 L
.97491 .28422 L
.98077 .2899 L
F
0 .37 .27 r
.98077 .66408 m
.9763 .67035 L
.9732 .67455 L
.97065 .67792 L
.96563 .68434 L
.9647 .68549 L
.95844 .69306 L
.95806 .69352 L
.95186 .70064 L
.95048 .70217 L
.94494 .70821 L
.94291 .71036 L
.93766 .71578 L
.93534 .71811 L
.93 .72335 L
.92777 .72548 L
.92192 .73092 L
.9202 .73248 L
.91339 .73849 L
.91263 .73915 L
.90506 .7455 L
.90437 .74606 L
.89749 .75157 L
.89482 .75363 L
.88992 .75735 L
.88467 .76121 L
.88234 .76287 L
.87477 .76815 L
.87385 .76878 L
.8672 .77318 L
.86225 .77635 L
.85963 .77799 L
.85206 .78257 L
.84977 .78392 L
.84449 .78695 L
.83692 .79112 L
.83622 .79149 L
.82935 .79509 L
.82177 .79887 L
.82138 .79906 L
.8142 .80246 L
.80663 .80587 L
.80489 .80663 L
.79906 .80911 L
.79149 .81217 L
.78621 .8142 L
.78392 .81506 L
.77635 .81779 L
.76878 .82035 L
.76435 .82177 L
.76121 .82275 L
.75363 .825 L
.74606 .82708 L
.73849 .82902 L
.73714 .82935 L
.73092 .8308 L
.72335 .83243 L
.71578 .83391 L
.70821 .83524 L
.70064 .83643 L
.69723 .83692 L
.69306 .83747 L
.68549 .83836 L
.67792 .83911 L
.67035 .83972 L
.66278 .84018 L
.65521 .84049 L
.64764 .84066 L
.64007 .84069 L
.6325 .84057 L
.62492 .8403 L
.61735 .83989 L
.60978 .83932 L
.60221 .83861 L
.59464 .83775 L
.58834 .83692 L
.58707 .83673 L
.5795 .83557 L
.57193 .83424 L
.56435 .83276 L
.55678 .83111 L
.54939 .82935 L
.54921 .8293 L
.54164 .82733 L
.53407 .82518 L
.5265 .82286 L
.52313 .82177 L
.51893 .82036 L
.51136 .81768 L
.50379 .81482 L
.50223 .8142 L
.49621 .81176 L
.48864 .8085 L
.48452 .80663 L
.48107 .80503 L
.4735 .80135 L
.469 .79906 L
.46593 .79745 L
.45836 .79332 L
.45514 .79149 L
.45079 .78895 L
.44322 .78433 L
.44257 .78392 L
.43565 .77944 L
.43107 .77635 L
.42807 .77427 L
.4205 .76881 L
.42046 .76878 L
.41293 .76303 L
.41063 .76121 L
.40536 .75692 L
.40147 .75363 L
.39779 .75044 L
.39291 .74606 L
.39022 .74358 L
.38488 .73849 L
.38265 .73629 L
.37735 .73092 L
.37508 .72854 L
.37026 .72335 L
.3675 .72028 L
.36359 .71578 L
.35993 .71144 L
.35729 .70821 L
.35236 .70195 L
.35136 .70064 L
.34576 .69306 L
.34479 .69171 L
.34047 .68549 L
.33722 .6806 L
.33549 .67792 L
.33079 .67035 L
.32965 .66844 L
.32636 .66278 L
.32219 .65521 L
.32208 .65499 L
.31828 .64764 L
.3146 .64007 L
.31451 .63987 L
.31115 .6325 L
.30793 .62492 L
.30694 .62247 L
.30493 .61735 L
.30214 .60978 L
.29956 .60221 L
.29936 .60162 L
.29718 .59464 L
.29499 .58707 L
.29301 .5795 L
.29179 .57448 L
.29121 .57193 L
.2896 .56435 L
.28818 .55678 L
.28693 .54921 L
.28587 .54164 L
.28499 .53407 L
.28429 .5265 L
.28422 .52571 L
.28376 .51893 L
.28341 .51136 L
.28324 .50379 L
.28324 .49621 L
.28341 .48864 L
.28376 .48107 L
.28422 .47429 L
.28429 .4735 L
.28499 .46593 L
.28587 .45836 L
.28693 .45079 L
.28818 .44322 L
.2896 .43565 L
.29121 .42807 L
.29179 .42552 L
.29301 .4205 L
.29499 .41293 L
.29718 .40536 L
.29936 .39838 L
.29956 .39779 L
.30214 .39022 L
.30493 .38265 L
.30694 .37753 L
.30793 .37508 L
.31115 .3675 L
.31451 .36013 L
.3146 .35993 L
.31828 .35236 L
.32208 .34501 L
.32219 .34479 L
.32636 .33722 L
.32965 .33156 L
.33079 .32965 L
.33549 .32208 L
.33722 .3194 L
.34047 .31451 L
.34479 .30829 L
.34576 .30694 L
.35136 .29936 L
.35236 .29805 L
.35729 .29179 L
.35993 .28856 L
.36359 .28422 L
.3675 .27972 L
.37026 .27665 L
.37508 .27146 L
.37735 .26908 L
.38265 .26371 L
.38488 .26151 L
.39022 .25642 L
.39291 .25394 L
.39779 .24956 L
.40147 .24637 L
.40536 .24308 L
.41063 .23879 L
.41293 .23697 L
.42046 .23122 L
.4205 .23119 L
.42807 .22573 L
.43107 .22365 L
.43565 .22056 L
.44257 .21608 L
.44322 .21567 L
.45079 .21105 L
.45514 .20851 L
.45836 .20668 L
.46593 .20255 L
.469 .20094 L
.4735 .19865 L
.48107 .19497 L
.48452 .19337 L
.48864 .1915 L
.49621 .18824 L
.50223 .1858 L
.50379 .18518 L
.51136 .18232 L
.51893 .17964 L
.52313 .17823 L
.5265 .17714 L
.53407 .17482 L
.54164 .17267 L
.54921 .1707 L
.54939 .17065 L
.55678 .16889 L
.56435 .16724 L
.57193 .16576 L
.5795 .16443 L
.58707 .16327 L
.58834 .16308 L
.59464 .16225 L
.60221 .16139 L
.60978 .16068 L
.61735 .16011 L
.62492 .1597 L
.6325 .15943 L
.64007 .15931 L
.64764 .15934 L
.65521 .15951 L
.66278 .15982 L
.67035 .16028 L
.67792 .16089 L
.68549 .16164 L
.69306 .16253 L
.69723 .16308 L
.70064 .16357 L
.70821 .16476 L
.71578 .16609 L
.72335 .16757 L
.73092 .1692 L
.73714 .17065 L
.73849 .17098 L
.74606 .17292 L
.75363 .175 L
.76121 .17725 L
.76435 .17823 L
.76878 .17965 L
.77635 .18221 L
.78392 .18494 L
.78621 .1858 L
.79149 .18783 L
.79906 .19089 L
.80489 .19337 L
.80663 .19413 L
.8142 .19754 L
.82138 .20094 L
.82177 .20113 L
.82935 .20491 L
.83622 .20851 L
.83692 .20888 L
.84449 .21305 L
.84977 .21608 L
.85206 .21743 L
.85963 .22201 L
.86225 .22365 L
.8672 .22682 L
.87385 .23122 L
.87477 .23185 L
.88234 .23713 L
.88467 .23879 L
.88992 .24265 L
.89482 .24637 L
.89749 .24843 L
.90437 .25394 L
.90506 .2545 L
.91263 .26085 L
.91339 .26151 L
.9202 .26752 L
.92192 .26908 L
.92777 .27452 L
.93 .27665 L
.93534 .28189 L
.93766 .28422 L
.94291 .28964 L
.94494 .29179 L
.95048 .29783 L
.95186 .29936 L
.95806 .30648 L
.95844 .30694 L
.9647 .31451 L
.96563 .31566 L
.97065 .32208 L
.9732 .32545 L
.9763 .32965 L
.98077 .33592 L
F
0 .352 .284 r
.98077 .60657 m
.97941 .60978 L
.97604 .61735 L
.9732 .62335 L
.97242 .62492 L
.96855 .6325 L
.96563 .63791 L
.96442 .64007 L
.96002 .64764 L
.95806 .65088 L
.95535 .65521 L
.95048 .66264 L
.95039 .66278 L
.94513 .67035 L
.94291 .67342 L
.93956 .67792 L
.93534 .68339 L
.93367 .68549 L
.92777 .69267 L
.92743 .69306 L
.92084 .70064 L
.9202 .70135 L
.91385 .70821 L
.91263 .70949 L
.90646 .71578 L
.90506 .71717 L
.89862 .72335 L
.89749 .72441 L
.8903 .73092 L
.88992 .73126 L
.88234 .73774 L
.88144 .73849 L
.87477 .7439 L
.87201 .74606 L
.8672 .74973 L
.86191 .75363 L
.85963 .75527 L
.85206 .76054 L
.85107 .76121 L
.84449 .76554 L
.83937 .76878 L
.83692 .77029 L
.82935 .7748 L
.82665 .77635 L
.82177 .77908 L
.8142 .78314 L
.81269 .78392 L
.80663 .78698 L
.79906 .79062 L
.79719 .79149 L
.79149 .79406 L
.78392 .79731 L
.77964 .79906 L
.77635 .80037 L
.76878 .80324 L
.76121 .80594 L
.75917 .80663 L
.75363 .80846 L
.74606 .81081 L
.73849 .81298 L
.73397 .8142 L
.73092 .81499 L
.72335 .81684 L
.71578 .81852 L
.70821 .82005 L
.70064 .82141 L
.69847 .82177 L
.69306 .82262 L
.68549 .82367 L
.67792 .82457 L
.67035 .82531 L
.66278 .82589 L
.65521 .82633 L
.64764 .82661 L
.64007 .82673 L
.6325 .8267 L
.62492 .82652 L
.61735 .82618 L
.60978 .82569 L
.60221 .82504 L
.59464 .82423 L
.58707 .82326 L
.5795 .82212 L
.57736 .82177 L
.57193 .82083 L
.56435 .81936 L
.55678 .81773 L
.54921 .81593 L
.54259 .8142 L
.54164 .81395 L
.53407 .81179 L
.5265 .80945 L
.51893 .80692 L
.51811 .80663 L
.51136 .80419 L
.50379 .80127 L
.49837 .79906 L
.49621 .79815 L
.48864 .79481 L
.48155 .79149 L
.48107 .79126 L
.4735 .78748 L
.46677 .78392 L
.46593 .78346 L
.45836 .7792 L
.45354 .77635 L
.45079 .77468 L
.44322 .76988 L
.44153 .76878 L
.43565 .7648 L
.43054 .76121 L
.42807 .75942 L
.4205 .75371 L
.42041 .75363 L
.41293 .74766 L
.41101 .74606 L
.40536 .74123 L
.40227 .73849 L
.39779 .7344 L
.3941 .73092 L
.39022 .72713 L
.38646 .72335 L
.38265 .71938 L
.37929 .71578 L
.37508 .71109 L
.37256 .70821 L
.3675 .7022 L
.36623 .70064 L
.36027 .69306 L
.35993 .69262 L
.35467 .68549 L
.35236 .68224 L
.34939 .67792 L
.34479 .67093 L
.34442 .67035 L
.33975 .66278 L
.33722 .65847 L
.33536 .65521 L
.33124 .64764 L
.32965 .64457 L
.32738 .64007 L
.32377 .6325 L
.32208 .62877 L
.32039 .62492 L
.31725 .61735 L
.31451 .61025 L
.31433 .60978 L
.31163 .60221 L
.30915 .59464 L
.30694 .58729 L
.30687 .58707 L
.3048 .5795 L
.30292 .57193 L
.30125 .56435 L
.29976 .55678 L
.29936 .55458 L
.29847 .54921 L
.29736 .54164 L
.29645 .53407 L
.29572 .5265 L
.29517 .51893 L
.2948 .51136 L
.29462 .50379 L
.29462 .49621 L
.2948 .48864 L
.29517 .48107 L
.29572 .4735 L
.29645 .46593 L
.29736 .45836 L
.29847 .45079 L
.29936 .44542 L
.29976 .44322 L
.30125 .43565 L
.30292 .42807 L
.3048 .4205 L
.30687 .41293 L
.30694 .41271 L
.30915 .40536 L
.31163 .39779 L
.31433 .39022 L
.31451 .38975 L
.31725 .38265 L
.32039 .37508 L
.32208 .37123 L
.32377 .3675 L
.32738 .35993 L
.32965 .35543 L
.33124 .35236 L
.33536 .34479 L
.33722 .34153 L
.33975 .33722 L
.34442 .32965 L
.34479 .32907 L
.34939 .32208 L
.35236 .31776 L
.35467 .31451 L
.35993 .30738 L
.36027 .30694 L
.36623 .29936 L
.3675 .2978 L
.37256 .29179 L
.37508 .28891 L
.37929 .28422 L
.38265 .28062 L
.38646 .27665 L
.39022 .27287 L
.3941 .26908 L
.39779 .2656 L
.40227 .26151 L
.40536 .25877 L
.41101 .25394 L
.41293 .25234 L
.42041 .24637 L
.4205 .24629 L
.42807 .24058 L
.43054 .23879 L
.43565 .2352 L
.44153 .23122 L
.44322 .23012 L
.45079 .22532 L
.45354 .22365 L
.45836 .2208 L
.46593 .21654 L
.46677 .21608 L
.4735 .21252 L
.48107 .20874 L
.48155 .20851 L
.48864 .20519 L
.49621 .20185 L
.49837 .20094 L
.50379 .19873 L
.51136 .19581 L
.51811 .19337 L
.51893 .19308 L
.5265 .19055 L
.53407 .18821 L
.54164 .18605 L
.54259 .1858 L
.54921 .18407 L
.55678 .18227 L
.56435 .18064 L
.57193 .17917 L
.57736 .17823 L
.5795 .17788 L
.58707 .17674 L
.59464 .17577 L
.60221 .17496 L
.60978 .17431 L
.61735 .17382 L
.62492 .17348 L
.6325 .1733 L
.64007 .17327 L
.64764 .17339 L
.65521 .17367 L
.66278 .17411 L
.67035 .17469 L
.67792 .17543 L
.68549 .17633 L
.69306 .17738 L
.69847 .17823 L
.70064 .17859 L
.70821 .17995 L
.71578 .18148 L
.72335 .18316 L
.73092 .18501 L
.73397 .1858 L
.73849 .18702 L
.74606 .18919 L
.75363 .19154 L
.75917 .19337 L
.76121 .19406 L
.76878 .19676 L
.77635 .19963 L
.77964 .20094 L
.78392 .20269 L
.79149 .20594 L
.79719 .20851 L
.79906 .20938 L
.80663 .21302 L
.81269 .21608 L
.8142 .21686 L
.82177 .22092 L
.82665 .22365 L
.82935 .2252 L
.83692 .22971 L
.83937 .23122 L
.84449 .23446 L
.85107 .23879 L
.85206 .23946 L
.85963 .24473 L
.86191 .24637 L
.8672 .25027 L
.87201 .25394 L
.87477 .2561 L
.88144 .26151 L
.88234 .26226 L
.88992 .26874 L
.8903 .26908 L
.89749 .27559 L
.89862 .27665 L
.90506 .28283 L
.90646 .28422 L
.91263 .29051 L
.91385 .29179 L
.9202 .29865 L
.92084 .29936 L
.92743 .30694 L
.92777 .30733 L
.93367 .31451 L
.93534 .31661 L
.93956 .32208 L
.94291 .32658 L
.94513 .32965 L
.95039 .33722 L
.95048 .33736 L
.95535 .34479 L
.95806 .34912 L
.96002 .35236 L
.96442 .35993 L
.96563 .36209 L
.96855 .3675 L
.97242 .37508 L
.9732 .37665 L
.97604 .38265 L
.97941 .39022 L
.98077 .39343 L
F
0 .334 .296 r
.57193 .19281 m
.5795 .19153 L
.58707 .19043 L
.59464 .1895 L
.60221 .18874 L
.60978 .18814 L
.61735 .18772 L
.62492 .18745 L
.6325 .18735 L
.64007 .18741 L
.64764 .18764 L
.65521 .18803 L
.66278 .18858 L
.67035 .1893 L
.67792 .19018 L
.68549 .19122 L
.69306 .19243 L
.69829 .19337 L
.70064 .19381 L
.70821 .19536 L
.71578 .19708 L
.72335 .19898 L
.73054 .20094 L
.73092 .20105 L
.73849 .2033 L
.74606 .20573 L
.75363 .20835 L
.75407 .20851 L
.76121 .21116 L
.76878 .21417 L
.77334 .21608 L
.77635 .21738 L
.78392 .2208 L
.78991 .22365 L
.79149 .22443 L
.79906 .22828 L
.80457 .23122 L
.80663 .23236 L
.8142 .23668 L
.81775 .23879 L
.82177 .24125 L
.82935 .24609 L
.82976 .24637 L
.83692 .2512 L
.8408 .25394 L
.84449 .25661 L
.851 .26151 L
.85206 .26232 L
.85963 .26837 L
.86049 .26908 L
.8672 .27478 L
.86933 .27665 L
.87477 .28157 L
.87761 .28422 L
.88234 .28879 L
.88536 .29179 L
.88992 .29647 L
.89265 .29936 L
.89749 .30466 L
.8995 .30694 L
.90506 .31344 L
.90594 .31451 L
.91201 .32208 L
.91263 .32288 L
.91772 .32965 L
.9202 .33309 L
.92309 .33722 L
.92777 .34423 L
.92814 .34479 L
.93288 .35236 L
.93534 .35649 L
.93733 .35993 L
.94149 .3675 L
.94291 .3702 L
.94539 .37508 L
.94902 .38265 L
.95048 .38587 L
.95239 .39022 L
.95551 .39779 L
.95806 .40444 L
.95839 .40536 L
.96103 .41293 L
.96344 .4205 L
.96562 .42807 L
.96563 .42812 L
.96756 .43565 L
.96929 .44322 L
.97079 .45079 L
.97208 .45836 L
.97315 .46593 L
.9732 .46632 L
.974 .4735 L
.97464 .48107 L
.97506 .48864 L
.97528 .49621 L
.97528 .50379 L
.97506 .51136 L
.97464 .51893 L
.974 .5265 L
.9732 .53368 L
.97315 .53407 L
.97208 .54164 L
.97079 .54921 L
.96929 .55678 L
.96756 .56435 L
.96563 .57188 L
.96562 .57193 L
.96344 .5795 L
.96103 .58707 L
.95839 .59464 L
.95806 .59556 L
.95551 .60221 L
.95239 .60978 L
.95048 .61413 L
.94902 .61735 L
.94539 .62492 L
.94291 .6298 L
.94149 .6325 L
.93733 .64007 L
.93534 .64351 L
.93288 .64764 L
.92814 .65521 L
.92777 .65577 L
.92309 .66278 L
.9202 .66691 L
.91772 .67035 L
.91263 .67712 L
.91201 .67792 L
.90594 .68549 L
.90506 .68656 L
.8995 .69306 L
.89749 .69534 L
.89265 .70064 L
.88992 .70353 L
.88536 .70821 L
.88234 .71121 L
.87761 .71578 L
.87477 .71843 L
.86933 .72335 L
.8672 .72522 L
.86049 .73092 L
.85963 .73163 L
.85206 .73768 L
.851 .73849 L
.84449 .74339 L
.8408 .74606 L
.83692 .7488 L
.82976 .75363 L
.82935 .75391 L
.82177 .75875 L
.81775 .76121 L
.8142 .76332 L
.80663 .76764 L
.80457 .76878 L
.79906 .77172 L
.79149 .77557 L
.78991 .77635 L
.78392 .7792 L
.77635 .78262 L
.77334 .78392 L
.76878 .78583 L
.76121 .78884 L
.75407 .79149 L
.75363 .79165 L
.74606 .79427 L
.73849 .7967 L
.73092 .79895 L
.73054 .79906 L
.72335 .80102 L
.71578 .80292 L
.70821 .80464 L
.70064 .80619 L
.69829 .80663 L
.69306 .80757 L
.68549 .80878 L
.67792 .80982 L
.67035 .8107 L
.66278 .81142 L
.65521 .81197 L
.64764 .81236 L
.64007 .81259 L
.6325 .81265 L
.62492 .81255 L
.61735 .81228 L
.60978 .81186 L
.60221 .81126 L
.59464 .8105 L
.58707 .80957 L
.5795 .80847 L
.57193 .80719 L
.56888 .80663 L
.56435 .80574 L
.55678 .80412 L
.54921 .80231 L
.54164 .80032 L
.5372 .79906 L
.53407 .79814 L
.5265 .79576 L
.51893 .79319 L
.51423 .79149 L
.51136 .79041 L
.50379 .78742 L
.49621 .78422 L
.49553 .78392 L
.48864 .78079 L
.48107 .77713 L
.47951 .77635 L
.4735 .77323 L
.46593 .76907 L
.46541 .76878 L
.45836 .76465 L
.45277 .76121 L
.45079 .75995 L
.44322 .75495 L
.4413 .75363 L
.43565 .74964 L
.43079 .74606 L
.42807 .744 L
.42111 .73849 L
.4205 .73799 L
.41293 .73161 L
.41215 .73092 L
.40536 .7248 L
.40381 .72335 L
.39779 .71753 L
.39603 .71578 L
.39022 .70976 L
.38877 .70821 L
.38265 .70142 L
.38196 .70064 L
.37558 .69306 L
.37508 .69245 L
.36959 .68549 L
.3675 .68274 L
.36397 .67792 L
.35993 .67217 L
.3587 .67035 L
.35375 .66278 L
.35236 .66058 L
.3491 .65521 L
.34479 .64771 L
.34475 .64764 L
.34068 .64007 L
.33722 .63321 L
.33687 .6325 L
.33332 .62492 L
.33002 .61735 L
.32965 .61646 L
.32696 .60978 L
.32413 .60221 L
.32208 .5963 L
.32152 .59464 L
.31914 .58707 L
.31697 .5795 L
.31501 .57193 L
.31451 .56984 L
.31326 .56435 L
.31171 .55678 L
.31036 .54921 L
.30921 .54164 L
.30825 .53407 L
.30748 .5265 L
.30694 .5193 L
.30691 .51893 L
.30653 .51136 L
.30634 .50379 L
.30634 .49621 L
.30653 .48864 L
.30691 .48107 L
.30694 .4807 L
.30748 .4735 L
.30825 .46593 L
.30921 .45836 L
.31036 .45079 L
.31171 .44322 L
.31326 .43565 L
.31451 .43016 L
.31501 .42807 L
.31697 .4205 L
.31914 .41293 L
.32152 .40536 L
.32208 .4037 L
.32413 .39779 L
.32696 .39022 L
.32965 .38354 L
.33002 .38265 L
.33332 .37508 L
.33687 .3675 L
.33722 .36679 L
.34068 .35993 L
.34475 .35236 L
.34479 .35229 L
.3491 .34479 L
.35236 .33942 L
.35375 .33722 L
.3587 .32965 L
.35993 .32783 L
.36397 .32208 L
.3675 .31726 L
.36959 .31451 L
.37508 .30755 L
.37558 .30694 L
.38196 .29936 L
.38265 .29858 L
.38877 .29179 L
.39022 .29024 L
.39603 .28422 L
.39779 .28247 L
.40381 .27665 L
.40536 .2752 L
.41215 .26908 L
.41293 .26839 L
.4205 .26201 L
.42111 .26151 L
.42807 .256 L
.43079 .25394 L
.43565 .25036 L
.4413 .24637 L
.44322 .24505 L
.45079 .24005 L
.45277 .23879 L
.45836 .23535 L
.46541 .23122 L
.46593 .23093 L
.4735 .22677 L
.47951 .22365 L
.48107 .22287 L
.48864 .21921 L
.49553 .21608 L
.49621 .21578 L
.50379 .21258 L
.51136 .20959 L
.51423 .20851 L
.51893 .20681 L
.5265 .20424 L
.53407 .20186 L
.5372 .20094 L
.54164 .19968 L
.54921 .19769 L
.55678 .19588 L
.56435 .19426 L
.56888 .19337 L
F
0 .316 .305 r
.56435 .20816 m
.57193 .20672 L
.5795 .20546 L
.58707 .20439 L
.59464 .20349 L
.60221 .20278 L
.60978 .20224 L
.61735 .20187 L
.62492 .20168 L
.6325 .20166 L
.64007 .20182 L
.64764 .20215 L
.65521 .20265 L
.66278 .20332 L
.67035 .20417 L
.67792 .2052 L
.68549 .2064 L
.69306 .20778 L
.69674 .20851 L
.70064 .20934 L
.70821 .21108 L
.71578 .21301 L
.72335 .21512 L
.72656 .21608 L
.73092 .21743 L
.73849 .21994 L
.74606 .22265 L
.74873 .22365 L
.75363 .22556 L
.76121 .22869 L
.76698 .23122 L
.76878 .23204 L
.77635 .23561 L
.7827 .23879 L
.78392 .23943 L
.79149 .24348 L
.79661 .24637 L
.79906 .24779 L
.80663 .25237 L
.80912 .25394 L
.8142 .25724 L
.8205 .26151 L
.82177 .2624 L
.82935 .26788 L
.83095 .26908 L
.83692 .2737 L
.84059 .27665 L
.84449 .27988 L
.84953 .28422 L
.85206 .28647 L
.85785 .29179 L
.85963 .29348 L
.86562 .29936 L
.8672 .30097 L
.87289 .30694 L
.87477 .30899 L
.87969 .31451 L
.88234 .3176 L
.88606 .32208 L
.88992 .32691 L
.89204 .32965 L
.89749 .33701 L
.89764 .33722 L
.90289 .34479 L
.90506 .34807 L
.90781 .35236 L
.91241 .35993 L
.91263 .3603 L
.91671 .3675 L
.9202 .37406 L
.92072 .37508 L
.92445 .38265 L
.92777 .3899 L
.92791 .39022 L
.93111 .39779 L
.93405 .40536 L
.93534 .40889 L
.93675 .41293 L
.9392 .4205 L
.94142 .42807 L
.94291 .43369 L
.9434 .43565 L
.94516 .44322 L
.94668 .45079 L
.94799 .45836 L
.94907 .46593 L
.94994 .4735 L
.95048 .47966 L
.95058 .48107 L
.95102 .48864 L
.95123 .49621 L
.95123 .50379 L
.95102 .51136 L
.95058 .51893 L
.95048 .52034 L
.94994 .5265 L
.94907 .53407 L
.94799 .54164 L
.94668 .54921 L
.94516 .55678 L
.9434 .56435 L
.94291 .56631 L
.94142 .57193 L
.9392 .5795 L
.93675 .58707 L
.93534 .59111 L
.93405 .59464 L
.93111 .60221 L
.92791 .60978 L
.92777 .6101 L
.92445 .61735 L
.92072 .62492 L
.9202 .62594 L
.91671 .6325 L
.91263 .6397 L
.91241 .64007 L
.90781 .64764 L
.90506 .65193 L
.90289 .65521 L
.89764 .66278 L
.89749 .66299 L
.89204 .67035 L
.88992 .67309 L
.88606 .67792 L
.88234 .6824 L
.87969 .68549 L
.87477 .69101 L
.87289 .69306 L
.8672 .69903 L
.86562 .70064 L
.85963 .70652 L
.85785 .70821 L
.85206 .71353 L
.84953 .71578 L
.84449 .72012 L
.84059 .72335 L
.83692 .7263 L
.83095 .73092 L
.82935 .73212 L
.82177 .7376 L
.8205 .73849 L
.8142 .74276 L
.80912 .74606 L
.80663 .74763 L
.79906 .75221 L
.79661 .75363 L
.79149 .75652 L
.78392 .76057 L
.7827 .76121 L
.77635 .76439 L
.76878 .76796 L
.76698 .76878 L
.76121 .77131 L
.75363 .77444 L
.74873 .77635 L
.74606 .77735 L
.73849 .78006 L
.73092 .78257 L
.72656 .78392 L
.72335 .78488 L
.71578 .78699 L
.70821 .78892 L
.70064 .79066 L
.69674 .79149 L
.69306 .79222 L
.68549 .7936 L
.67792 .7948 L
.67035 .79583 L
.66278 .79668 L
.65521 .79735 L
.64764 .79785 L
.64007 .79818 L
.6325 .79834 L
.62492 .79832 L
.61735 .79813 L
.60978 .79776 L
.60221 .79722 L
.59464 .79651 L
.58707 .79561 L
.5795 .79454 L
.57193 .79328 L
.56435 .79184 L
.56264 .79149 L
.55678 .79021 L
.54921 .78839 L
.54164 .78638 L
.53407 .78416 L
.53327 .78392 L
.5265 .78174 L
.51893 .77912 L
.51156 .77635 L
.51136 .77627 L
.50379 .7732 L
.49621 .7699 L
.49375 .76878 L
.48864 .76636 L
.48107 .76257 L
.47846 .76121 L
.4735 .75852 L
.46593 .75419 L
.46499 .75363 L
.45836 .74958 L
.4529 .74606 L
.45079 .74466 L
.44322 .73942 L
.44193 .73849 L
.43565 .73383 L
.43189 .73092 L
.42807 .72787 L
.42265 .72335 L
.4205 .7215 L
.4141 .71578 L
.41293 .7147 L
.40615 .70821 L
.40536 .70742 L
.39876 .70064 L
.39779 .6996 L
.39186 .69306 L
.39022 .69119 L
.38541 .68549 L
.38265 .68208 L
.37938 .67792 L
.37508 .67219 L
.37374 .67035 L
.36846 .66278 L
.3675 .66136 L
.36351 .65521 L
.35993 .64939 L
.35889 .64764 L
.35457 .64007 L
.35236 .63597 L
.35055 .6325 L
.3468 .62492 L
.34479 .62063 L
.34331 .61735 L
.34009 .60978 L
.33722 .60251 L
.33711 .60221 L
.33437 .59464 L
.33186 .58707 L
.32965 .57972 L
.32959 .5795 L
.32753 .57193 L
.32569 .56435 L
.32407 .55678 L
.32265 .54921 L
.32208 .54577 L
.32145 .54164 L
.32045 .53407 L
.31965 .5265 L
.31905 .51893 L
.31865 .51136 L
.31845 .50379 L
.31845 .49621 L
.31865 .48864 L
.31905 .48107 L
.31965 .4735 L
.32045 .46593 L
.32145 .45836 L
.32208 .45423 L
.32265 .45079 L
.32407 .44322 L
.32569 .43565 L
.32753 .42807 L
.32959 .4205 L
.32965 .42028 L
.33186 .41293 L
.33437 .40536 L
.33711 .39779 L
.33722 .39749 L
.34009 .39022 L
.34331 .38265 L
.34479 .37937 L
.3468 .37508 L
.35055 .3675 L
.35236 .36403 L
.35457 .35993 L
.35889 .35236 L
.35993 .35061 L
.36351 .34479 L
.3675 .33864 L
.36846 .33722 L
.37374 .32965 L
.37508 .32781 L
.37938 .32208 L
.38265 .31792 L
.38541 .31451 L
.39022 .30881 L
.39186 .30694 L
.39779 .3004 L
.39876 .29936 L
.40536 .29258 L
.40615 .29179 L
.41293 .2853 L
.4141 .28422 L
.4205 .2785 L
.42265 .27665 L
.42807 .27213 L
.43189 .26908 L
.43565 .26617 L
.44193 .26151 L
.44322 .26058 L
.45079 .25534 L
.4529 .25394 L
.45836 .25042 L
.46499 .24637 L
.46593 .24581 L
.4735 .24148 L
.47846 .23879 L
.48107 .23743 L
.48864 .23364 L
.49375 .23122 L
.49621 .2301 L
.50379 .2268 L
.51136 .22373 L
.51156 .22365 L
.51893 .22088 L
.5265 .21826 L
.53327 .21608 L
.53407 .21584 L
.54164 .21362 L
.54921 .21161 L
.55678 .20979 L
.56264 .20851 L
F
0 .285 .298 r
.56435 .22242 m
.57193 .22098 L
.5795 .21973 L
.58707 .21868 L
.59464 .21782 L
.60221 .21715 L
.60978 .21666 L
.61735 .21636 L
.62492 .21624 L
.6325 .21631 L
.64007 .21656 L
.64764 .21699 L
.65521 .21761 L
.66278 .21841 L
.67035 .2194 L
.67792 .22058 L
.68549 .22194 L
.69306 .2235 L
.69376 .22365 L
.70064 .22525 L
.70821 .2272 L
.71578 .22936 L
.72183 .23122 L
.72335 .23172 L
.73092 .23429 L
.73849 .23707 L
.74289 .23879 L
.74606 .24009 L
.75363 .24333 L
.76027 .24637 L
.76121 .24681 L
.76878 .25054 L
.77526 .25394 L
.77635 .25453 L
.78392 .25878 L
.78851 .26151 L
.79149 .26333 L
.79906 .26817 L
.80042 .26908 L
.80663 .27334 L
.81125 .27665 L
.8142 .27884 L
.82116 .28422 L
.82177 .28471 L
.82935 .29098 L
.83029 .29179 L
.83692 .29768 L
.83875 .29936 L
.84449 .30485 L
.8466 .30694 L
.85206 .31254 L
.8539 .31451 L
.85963 .32084 L
.86071 .32208 L
.86707 .32965 L
.8672 .32981 L
.87301 .33722 L
.87477 .33957 L
.87856 .34479 L
.88234 .35028 L
.88374 .35236 L
.88857 .35993 L
.88992 .36214 L
.89307 .3675 L
.89726 .37508 L
.89749 .3755 L
.90115 .38265 L
.90475 .39022 L
.90506 .39089 L
.90808 .39779 L
.91113 .40536 L
.91263 .40933 L
.91392 .41293 L
.91646 .4205 L
.91875 .42807 L
.9202 .43332 L
.9208 .43565 L
.92261 .44322 L
.92419 .45079 L
.92553 .45836 L
.92665 .46593 L
.92754 .4735 L
.92777 .47576 L
.92821 .48107 L
.92865 .48864 L
.92887 .49621 L
.92887 .50379 L
.92865 .51136 L
.92821 .51893 L
.92777 .52424 L
.92754 .5265 L
.92665 .53407 L
.92553 .54164 L
.92419 .54921 L
.92261 .55678 L
.9208 .56435 L
.9202 .56668 L
.91875 .57193 L
.91646 .5795 L
.91392 .58707 L
.91263 .59067 L
.91113 .59464 L
.90808 .60221 L
.90506 .60911 L
.90475 .60978 L
.90115 .61735 L
.89749 .6245 L
.89726 .62492 L
.89307 .6325 L
.88992 .63786 L
.88857 .64007 L
.88374 .64764 L
.88234 .64972 L
.87856 .65521 L
.87477 .66043 L
.87301 .66278 L
.8672 .67019 L
.86707 .67035 L
.86071 .67792 L
.85963 .67916 L
.8539 .68549 L
.85206 .68746 L
.8466 .69306 L
.84449 .69515 L
.83875 .70064 L
.83692 .70232 L
.83029 .70821 L
.82935 .70902 L
.82177 .71529 L
.82116 .71578 L
.8142 .72116 L
.81125 .72335 L
.80663 .72666 L
.80042 .73092 L
.79906 .73183 L
.79149 .73667 L
.78851 .73849 L
.78392 .74122 L
.77635 .74547 L
.77526 .74606 L
.76878 .74946 L
.76121 .75319 L
.76027 .75363 L
.75363 .75667 L
.74606 .75991 L
.74289 .76121 L
.73849 .76293 L
.73092 .76571 L
.72335 .76828 L
.72183 .76878 L
.71578 .77064 L
.70821 .7728 L
.70064 .77475 L
.69376 .77635 L
.69306 .7765 L
.68549 .77806 L
.67792 .77942 L
.67035 .7806 L
.66278 .78159 L
.65521 .78239 L
.64764 .78301 L
.64007 .78344 L
.6325 .78369 L
.62492 .78376 L
.61735 .78364 L
.60978 .78334 L
.60221 .78285 L
.59464 .78218 L
.58707 .78132 L
.5795 .78027 L
.57193 .77902 L
.56435 .77758 L
.55856 .77635 L
.55678 .77594 L
.54921 .7741 L
.54164 .77206 L
.53407 .7698 L
.53087 .76878 L
.5265 .76732 L
.51893 .76462 L
.51136 .76169 L
.51017 .76121 L
.50379 .75852 L
.49621 .7551 L
.49313 .75363 L
.48864 .75142 L
.48107 .74747 L
.47849 .74606 L
.4735 .74324 L
.46593 .73871 L
.46558 .73849 L
.45836 .73386 L
.454 .73092 L
.45079 .72868 L
.4435 .72335 L
.44322 .72313 L
.43565 .7172 L
.4339 .71578 L
.42807 .71085 L
.42508 .70821 L
.4205 .70403 L
.41693 .70064 L
.41293 .6967 L
.40937 .69306 L
.40536 .68881 L
.40235 .68549 L
.39779 .68027 L
.39581 .67792 L
.39022 .67099 L
.38972 .67035 L
.38404 .66278 L
.38265 .66084 L
.37874 .65521 L
.37508 .64965 L
.3738 .64764 L
.36919 .64007 L
.3675 .63715 L
.3649 .6325 L
.36092 .62492 L
.35993 .62296 L
.35722 .61735 L
.35381 .60978 L
.35236 .60639 L
.35066 .60221 L
.34776 .59464 L
.34512 .58707 L
.34479 .58608 L
.34272 .5795 L
.34055 .57193 L
.33862 .56435 L
.33722 .55825 L
.33691 .55678 L
.33542 .54921 L
.33415 .54164 L
.3331 .53407 L
.33226 .5265 L
.33163 .51893 L
.33122 .51136 L
.33101 .50379 L
.33101 .49621 L
.33122 .48864 L
.33163 .48107 L
.33226 .4735 L
.3331 .46593 L
.33415 .45836 L
.33542 .45079 L
.33691 .44322 L
.33722 .44175 L
.33862 .43565 L
.34055 .42807 L
.34272 .4205 L
.34479 .41392 L
.34512 .41293 L
.34776 .40536 L
.35066 .39779 L
.35236 .39361 L
.35381 .39022 L
.35722 .38265 L
.35993 .37704 L
.36092 .37508 L
.3649 .3675 L
.3675 .36285 L
.36919 .35993 L
.3738 .35236 L
.37508 .35035 L
.37874 .34479 L
.38265 .33916 L
.38404 .33722 L
.38972 .32965 L
.39022 .32901 L
.39581 .32208 L
.39779 .31973 L
.40235 .31451 L
.40536 .31119 L
.40937 .30694 L
.41293 .3033 L
.41693 .29936 L
.4205 .29597 L
.42508 .29179 L
.42807 .28915 L
.4339 .28422 L
.43565 .2828 L
.44322 .27687 L
.4435 .27665 L
.45079 .27132 L
.454 .26908 L
.45836 .26614 L
.46558 .26151 L
.46593 .26129 L
.4735 .25676 L
.47849 .25394 L
.48107 .25253 L
.48864 .24858 L
.49313 .24637 L
.49621 .2449 L
.50379 .24148 L
.51017 .23879 L
.51136 .23831 L
.51893 .23538 L
.5265 .23268 L
.53087 .23122 L
.53407 .2302 L
.54164 .22794 L
.54921 .2259 L
.55678 .22406 L
.55856 .22365 L
F
0 .246 .28 r
.62492 .23122 m
.62574 .23122 L
.6325 .23137 L
.64007 .23172 L
.64764 .23226 L
.65521 .233 L
.66278 .23394 L
.67035 .23508 L
.67792 .23642 L
.68549 .23796 L
.68921 .23879 L
.69306 .23971 L
.70064 .24168 L
.70821 .24386 L
.71578 .24626 L
.7161 .24637 L
.72335 .24889 L
.73092 .25175 L
.73632 .25394 L
.73849 .25485 L
.74606 .25821 L
.75299 .26151 L
.75363 .26182 L
.76121 .26571 L
.76736 .26908 L
.76878 .26988 L
.77635 .27435 L
.78004 .27665 L
.78392 .27914 L
.79142 .28422 L
.79149 .28427 L
.79906 .28976 L
.80174 .29179 L
.80663 .29564 L
.81117 .29936 L
.8142 .30195 L
.81984 .30694 L
.82177 .30872 L
.82784 .31451 L
.82935 .316 L
.83525 .32208 L
.83692 .32387 L
.84212 .32965 L
.84449 .33239 L
.84851 .33722 L
.85206 .34167 L
.85445 .34479 L
.85963 .35187 L
.85998 .35236 L
.86512 .35993 L
.8672 .36317 L
.86989 .3675 L
.87433 .37508 L
.87477 .37587 L
.87843 .38265 L
.88222 .39022 L
.88234 .39047 L
.88572 .39779 L
.88892 .40536 L
.88992 .40785 L
.89185 .41293 L
.89451 .4205 L
.8969 .42807 L
.89749 .43006 L
.89904 .43565 L
.90093 .44322 L
.90257 .45079 L
.90397 .45836 L
.90506 .46539 L
.90513 .46593 L
.90606 .4735 L
.90675 .48107 L
.90721 .48864 L
.90744 .49621 L
.90744 .50379 L
.90721 .51136 L
.90675 .51893 L
.90606 .5265 L
.90513 .53407 L
.90506 .53461 L
.90397 .54164 L
.90257 .54921 L
.90093 .55678 L
.89904 .56435 L
.89749 .56994 L
.8969 .57193 L
.89451 .5795 L
.89185 .58707 L
.88992 .59215 L
.88892 .59464 L
.88572 .60221 L
.88234 .60953 L
.88222 .60978 L
.87843 .61735 L
.87477 .62413 L
.87433 .62492 L
.86989 .6325 L
.8672 .63683 L
.86512 .64007 L
.85998 .64764 L
.85963 .64813 L
.85445 .65521 L
.85206 .65833 L
.84851 .66278 L
.84449 .66761 L
.84212 .67035 L
.83692 .67613 L
.83525 .67792 L
.82935 .684 L
.82784 .68549 L
.82177 .69128 L
.81984 .69306 L
.8142 .69805 L
.81117 .70064 L
.80663 .70436 L
.80174 .70821 L
.79906 .71024 L
.79149 .71573 L
.79142 .71578 L
.78392 .72086 L
.78004 .72335 L
.77635 .72565 L
.76878 .73012 L
.76736 .73092 L
.76121 .73429 L
.75363 .73818 L
.75299 .73849 L
.74606 .74179 L
.73849 .74515 L
.73632 .74606 L
.73092 .74825 L
.72335 .75111 L
.7161 .75363 L
.71578 .75374 L
.70821 .75614 L
.70064 .75832 L
.69306 .76029 L
.68921 .76121 L
.68549 .76204 L
.67792 .76358 L
.67035 .76492 L
.66278 .76606 L
.65521 .767 L
.64764 .76774 L
.64007 .76828 L
.6325 .76863 L
.62574 .76878 L
.62492 .76878 L
.61985 .76878 L
.61735 .76874 L
.60978 .7685 L
.60221 .76807 L
.59464 .76743 L
.58707 .7666 L
.5795 .76557 L
.57193 .76433 L
.56435 .76288 L
.55678 .76123 L
.55669 .76121 L
.54921 .75936 L
.54164 .75726 L
.53407 .75494 L
.53009 .75363 L
.5265 .75239 L
.51893 .7496 L
.51136 .74656 L
.51017 .74606 L
.50379 .74327 L
.49621 .7397 L
.49377 .73849 L
.48864 .73586 L
.48107 .73171 L
.47968 .73092 L
.4735 .72726 L
.46727 .72335 L
.46593 .72248 L
.45836 .71734 L
.45616 .71578 L
.45079 .71183 L
.4461 .70821 L
.44322 .7059 L
.43692 .70064 L
.43565 .69953 L
.42849 .69306 L
.42807 .69267 L
.42072 .68549 L
.4205 .68527 L
.41354 .67792 L
.41293 .67725 L
.40688 .67035 L
.40536 .66854 L
.40071 .66278 L
.39779 .659 L
.39497 .65521 L
.39022 .64849 L
.38963 .64764 L
.38468 .64007 L
.38265 .63679 L
.38008 .6325 L
.37582 .62492 L
.37508 .62354 L
.37187 .61735 L
.36823 .60978 L
.3675 .6082 L
.36488 .60221 L
.3618 .59464 L
.35993 .58967 L
.359 .58707 L
.35645 .5795 L
.35416 .57193 L
.35236 .56532 L
.35211 .56435 L
.35031 .55678 L
.34874 .54921 L
.3474 .54164 L
.34629 .53407 L
.3454 .5265 L
.34479 .51964 L
.34474 .51893 L
.3443 .51136 L
.34408 .50379 L
.34408 .49621 L
.3443 .48864 L
.34474 .48107 L
.34479 .48036 L
.3454 .4735 L
.34629 .46593 L
.3474 .45836 L
.34874 .45079 L
.35031 .44322 L
.35211 .43565 L
.35236 .43468 L
.35416 .42807 L
.35645 .4205 L
.359 .41293 L
.35993 .41033 L
.3618 .40536 L
.36488 .39779 L
.3675 .3918 L
.36823 .39022 L
.37187 .38265 L
.37508 .37646 L
.37582 .37508 L
.38008 .3675 L
.38265 .36321 L
.38468 .35993 L
.38963 .35236 L
.39022 .35151 L
.39497 .34479 L
.39779 .341 L
.40071 .33722 L
.40536 .33146 L
.40688 .32965 L
.41293 .32275 L
.41354 .32208 L
.4205 .31473 L
.42072 .31451 L
.42807 .30733 L
.42849 .30694 L
.43565 .30047 L
.43692 .29936 L
.44322 .2941 L
.4461 .29179 L
.45079 .28817 L
.45616 .28422 L
.45836 .28266 L
.46593 .27752 L
.46727 .27665 L
.4735 .27274 L
.47968 .26908 L
.48107 .26829 L
.48864 .26414 L
.49377 .26151 L
.49621 .2603 L
.50379 .25673 L
.51017 .25394 L
.51136 .25344 L
.51893 .2504 L
.5265 .24761 L
.53009 .24637 L
.53407 .24506 L
.54164 .24274 L
.54921 .24064 L
.55669 .23879 L
.55678 .23877 L
.56435 .23712 L
.57193 .23567 L
.5795 .23443 L
.58707 .2334 L
.59464 .23257 L
.60221 .23193 L
.60978 .2315 L
.61735 .23126 L
.61985 .23122 L
F
0 .21 .262 r
.56435 .25235 m
.57193 .25089 L
.5795 .24965 L
.58707 .24863 L
.59464 .24782 L
.60221 .24723 L
.60978 .24685 L
.61735 .24667 L
.62492 .24671 L
.6325 .24695 L
.64007 .2474 L
.64764 .24806 L
.65521 .24894 L
.66278 .25002 L
.67035 .25133 L
.67792 .25285 L
.68278 .25394 L
.68549 .25459 L
.69306 .25656 L
.70064 .25876 L
.70821 .2612 L
.70912 .26151 L
.71578 .26388 L
.72335 .26682 L
.72877 .26908 L
.73092 .27002 L
.73849 .27349 L
.74491 .27665 L
.74606 .27724 L
.75363 .2813 L
.75876 .28422 L
.76121 .28567 L
.76878 .29037 L
.77096 .29179 L
.77635 .29543 L
.78187 .29936 L
.78392 .30088 L
.79149 .30674 L
.79173 .30694 L
.79906 .31306 L
.80072 .31451 L
.80663 .31987 L
.80896 .32208 L
.8142 .32724 L
.81654 .32965 L
.82177 .33525 L
.82354 .33722 L
.82935 .34399 L
.83001 .34479 L
.836 .35236 L
.83692 .35358 L
.84154 .35993 L
.84449 .36422 L
.84667 .3675 L
.85141 .37508 L
.85206 .37616 L
.85579 .38265 L
.85963 .38982 L
.85983 .39022 L
.86354 .39779 L
.86694 .40536 L
.8672 .40596 L
.87004 .41293 L
.87285 .4205 L
.87477 .42618 L
.87538 .42807 L
.87763 .43565 L
.87962 .44322 L
.88135 .45079 L
.88234 .45575 L
.88282 .45836 L
.88404 .46593 L
.88502 .4735 L
.88574 .48107 L
.88623 .48864 L
.88647 .49621 L
.88647 .50379 L
.88623 .51136 L
.88574 .51893 L
.88502 .5265 L
.88404 .53407 L
.88282 .54164 L
.88234 .54425 L
.88135 .54921 L
.87962 .55678 L
.87763 .56435 L
.87538 .57193 L
.87477 .57382 L
.87285 .5795 L
.87004 .58707 L
.8672 .59404 L
.86694 .59464 L
.86354 .60221 L
.85983 .60978 L
.85963 .61018 L
.85579 .61735 L
.85206 .62384 L
.85141 .62492 L
.84667 .6325 L
.84449 .63578 L
.84154 .64007 L
.83692 .64642 L
.836 .64764 L
.83001 .65521 L
.82935 .65601 L
.82354 .66278 L
.82177 .66475 L
.81654 .67035 L
.8142 .67276 L
.80896 .67792 L
.80663 .68013 L
.80072 .68549 L
.79906 .68694 L
.79173 .69306 L
.79149 .69326 L
.78392 .69912 L
.78187 .70064 L
.77635 .70457 L
.77096 .70821 L
.76878 .70963 L
.76121 .71433 L
.75876 .71578 L
.75363 .7187 L
.74606 .72276 L
.74491 .72335 L
.73849 .72651 L
.73092 .72998 L
.72877 .73092 L
.72335 .73318 L
.71578 .73612 L
.70912 .73849 L
.70821 .7388 L
.70064 .74124 L
.69306 .74344 L
.68549 .74541 L
.68278 .74606 L
.67792 .74715 L
.67035 .74867 L
.66278 .74998 L
.65521 .75106 L
.64764 .75194 L
.64007 .7526 L
.6325 .75305 L
.62492 .75329 L
.61735 .75333 L
.60978 .75315 L
.60221 .75277 L
.59464 .75218 L
.58707 .75137 L
.5795 .75035 L
.57193 .74911 L
.56435 .74765 L
.55722 .74606 L
.55678 .74596 L
.54921 .74404 L
.54164 .74189 L
.53407 .7395 L
.53111 .73849 L
.5265 .73685 L
.51893 .73394 L
.5117 .73092 L
.51136 .73077 L
.50379 .72732 L
.49621 .72357 L
.49579 .72335 L
.48864 .71951 L
.48216 .71578 L
.48107 .71513 L
.4735 .7104 L
.47018 .70821 L
.46593 .70529 L
.45948 .70064 L
.45836 .69979 L
.45079 .69385 L
.44982 .69306 L
.44322 .68744 L
.44103 .68549 L
.43565 .6805 L
.43298 .67792 L
.42807 .67297 L
.42558 .67035 L
.4205 .66477 L
.41876 .66278 L
.41293 .65579 L
.41247 .65521 L
.40664 .64764 L
.40536 .64589 L
.40126 .64007 L
.39779 .63486 L
.39628 .6325 L
.39167 .62492 L
.39022 .6224 L
.38742 .61735 L
.38351 .60978 L
.38265 .60803 L
.37991 .60221 L
.37663 .59464 L
.37508 .59082 L
.37363 .58707 L
.37091 .5795 L
.36847 .57193 L
.3675 .56868 L
.36629 .56435 L
.36437 .55678 L
.36271 .54921 L
.36128 .54164 L
.36011 .53407 L
.35993 .53284 L
.35917 .5265 L
.35847 .51893 L
.358 .51136 L
.35777 .50379 L
.35777 .49621 L
.358 .48864 L
.35847 .48107 L
.35917 .4735 L
.35993 .46716 L
.36011 .46593 L
.36128 .45836 L
.36271 .45079 L
.36437 .44322 L
.36629 .43565 L
.3675 .43132 L
.36847 .42807 L
.37091 .4205 L
.37363 .41293 L
.37508 .40918 L
.37663 .40536 L
.37991 .39779 L
.38265 .39197 L
.38351 .39022 L
.38742 .38265 L
.39022 .3776 L
.39167 .37508 L
.39628 .3675 L
.39779 .36514 L
.40126 .35993 L
.40536 .35411 L
.40664 .35236 L
.41247 .34479 L
.41293 .34421 L
.41876 .33722 L
.4205 .33523 L
.42558 .32965 L
.42807 .32703 L
.43298 .32208 L
.43565 .3195 L
.44103 .31451 L
.44322 .31256 L
.44982 .30694 L
.45079 .30615 L
.45836 .30021 L
.45948 .29936 L
.46593 .29471 L
.47018 .29179 L
.4735 .2896 L
.48107 .28487 L
.48216 .28422 L
.48864 .28049 L
.49579 .27665 L
.49621 .27643 L
.50379 .27268 L
.51136 .26923 L
.5117 .26908 L
.51893 .26606 L
.5265 .26315 L
.53111 .26151 L
.53407 .2605 L
.54164 .25811 L
.54921 .25596 L
.55678 .25404 L
.55722 .25394 L
F
0 .177 .244 r
.56435 .26826 m
.57193 .26677 L
.5795 .26552 L
.58707 .26451 L
.59464 .26372 L
.60221 .26316 L
.60978 .26283 L
.61735 .26272 L
.62492 .26284 L
.6325 .26318 L
.64007 .26375 L
.64764 .26454 L
.65521 .26556 L
.66278 .26681 L
.67035 .2683 L
.67391 .26908 L
.67792 .27002 L
.68549 .27199 L
.69306 .27421 L
.70054 .27665 L
.70064 .27669 L
.70821 .27942 L
.71578 .28244 L
.71995 .28422 L
.72335 .28574 L
.73092 .28934 L
.73574 .29179 L
.73849 .29325 L
.74606 .2975 L
.74921 .29936 L
.75363 .30209 L
.76101 .30694 L
.76121 .30707 L
.76878 .31245 L
.77152 .31451 L
.77635 .31827 L
.78099 .32208 L
.78392 .32458 L
.78959 .32965 L
.79149 .33142 L
.79743 .33722 L
.79906 .33888 L
.80462 .34479 L
.80663 .34703 L
.81123 .35236 L
.8142 .35599 L
.81731 .35993 L
.82177 .36592 L
.82291 .3675 L
.82806 .37508 L
.82935 .37706 L
.8328 .38265 L
.83692 .38978 L
.83716 .39022 L
.84115 .39779 L
.84449 .4047 L
.84479 .40536 L
.84811 .41293 L
.85111 .4205 L
.85206 .42308 L
.8538 .42807 L
.8562 .43565 L
.85832 .44322 L
.85963 .4485 L
.86015 .45079 L
.86172 .45836 L
.86301 .46593 L
.86404 .4735 L
.86481 .48107 L
.86533 .48864 L
.86558 .49621 L
.86558 .50379 L
.86533 .51136 L
.86481 .51893 L
.86404 .5265 L
.86301 .53407 L
.86172 .54164 L
.86015 .54921 L
.85963 .5515 L
.85832 .55678 L
.8562 .56435 L
.8538 .57193 L
.85206 .57692 L
.85111 .5795 L
.84811 .58707 L
.84479 .59464 L
.84449 .5953 L
.84115 .60221 L
.83716 .60978 L
.83692 .61022 L
.8328 .61735 L
.82935 .62294 L
.82806 .62492 L
.82291 .6325 L
.82177 .63408 L
.81731 .64007 L
.8142 .64401 L
.81123 .64764 L
.80663 .65297 L
.80462 .65521 L
.79906 .66112 L
.79743 .66278 L
.79149 .66858 L
.78959 .67035 L
.78392 .67542 L
.78099 .67792 L
.77635 .68173 L
.77152 .68549 L
.76878 .68755 L
.76121 .69293 L
.76101 .69306 L
.75363 .69791 L
.74921 .70064 L
.74606 .7025 L
.73849 .70675 L
.73574 .70821 L
.73092 .71066 L
.72335 .71426 L
.71995 .71578 L
.71578 .71756 L
.70821 .72058 L
.70064 .72331 L
.70054 .72335 L
.69306 .72579 L
.68549 .72801 L
.67792 .72998 L
.67391 .73092 L
.67035 .7317 L
.66278 .73319 L
.65521 .73444 L
.64764 .73546 L
.64007 .73625 L
.6325 .73682 L
.62492 .73716 L
.61735 .73728 L
.60978 .73717 L
.60221 .73684 L
.59464 .73628 L
.58707 .73549 L
.5795 .73448 L
.57193 .73323 L
.56435 .73174 L
.56063 .73092 L
.55678 .73001 L
.54921 .72803 L
.54164 .7258 L
.5342 .72335 L
.53407 .7233 L
.5265 .72054 L
.51893 .71748 L
.51498 .71578 L
.51136 .71414 L
.50379 .71048 L
.49938 .70821 L
.49621 .7065 L
.48864 .70218 L
.48609 .70064 L
.48107 .69748 L
.47446 .69306 L
.4735 .6924 L
.46593 .68688 L
.46412 .68549 L
.45836 .68089 L
.45482 .67792 L
.45079 .6744 L
.44638 .67035 L
.44322 .66732 L
.43869 .66278 L
.43565 .65959 L
.43164 .65521 L
.42807 .65111 L
.42517 .64764 L
.4205 .64174 L
.41923 .64007 L
.41376 .6325 L
.41293 .6313 L
.40872 .62492 L
.40536 .61949 L
.40409 .61735 L
.39985 .60978 L
.39779 .60587 L
.39595 .60221 L
.3924 .59464 L
.39022 .5896 L
.38917 .58707 L
.38625 .5795 L
.38363 .57193 L
.38265 .56885 L
.3813 .56435 L
.37924 .55678 L
.37745 .54921 L
.37594 .54164 L
.37508 .53666 L
.37468 .53407 L
.37368 .5265 L
.37293 .51893 L
.37243 .51136 L
.37218 .50379 L
.37218 .49621 L
.37243 .48864 L
.37293 .48107 L
.37368 .4735 L
.37468 .46593 L
.37508 .46334 L
.37594 .45836 L
.37745 .45079 L
.37924 .44322 L
.3813 .43565 L
.38265 .43115 L
.38363 .42807 L
.38625 .4205 L
.38917 .41293 L
.39022 .4104 L
.3924 .40536 L
.39595 .39779 L
.39779 .39413 L
.39985 .39022 L
.40409 .38265 L
.40536 .38051 L
.40872 .37508 L
.41293 .3687 L
.41376 .3675 L
.41923 .35993 L
.4205 .35826 L
.42517 .35236 L
.42807 .34889 L
.43164 .34479 L
.43565 .34041 L
.43869 .33722 L
.44322 .33268 L
.44638 .32965 L
.45079 .3256 L
.45482 .32208 L
.45836 .31911 L
.46412 .31451 L
.46593 .31312 L
.4735 .3076 L
.47446 .30694 L
.48107 .30252 L
.48609 .29936 L
.48864 .29782 L
.49621 .2935 L
.49938 .29179 L
.50379 .28952 L
.51136 .28586 L
.51498 .28422 L
.51893 .28252 L
.5265 .27946 L
.53407 .2767 L
.5342 .27665 L
.54164 .2742 L
.54921 .27197 L
.55678 .26999 L
.56063 .26908 L
F
0 .146 .226 r
.57193 .28348 m
.5795 .28221 L
.58707 .28119 L
.59464 .28042 L
.60221 .2799 L
.60978 .27962 L
.61735 .27958 L
.62492 .27979 L
.6325 .28024 L
.64007 .28093 L
.64764 .28187 L
.65521 .28306 L
.66142 .28422 L
.66278 .2845 L
.67035 .2862 L
.67792 .28816 L
.68549 .2904 L
.6898 .29179 L
.69306 .29291 L
.70064 .29571 L
.70821 .29882 L
.70947 .29936 L
.71578 .30224 L
.72335 .30598 L
.72517 .30694 L
.73092 .31008 L
.73842 .31451 L
.73849 .31455 L
.74606 .31942 L
.74993 .32208 L
.75363 .32473 L
.76012 .32965 L
.76121 .3305 L
.76878 .3368 L
.76925 .33722 L
.77635 .34369 L
.7775 .34479 L
.78392 .35124 L
.78499 .35236 L
.79149 .35956 L
.79182 .35993 L
.79805 .3675 L
.79906 .3688 L
.80376 .37508 L
.80663 .37916 L
.80898 .38265 L
.81375 .39022 L
.8142 .39097 L
.81811 .39779 L
.82177 .40477 L
.82207 .40536 L
.82566 .41293 L
.82891 .4205 L
.82935 .42159 L
.83182 .42807 L
.8344 .43565 L
.83667 .44322 L
.83692 .44409 L
.83864 .45079 L
.84032 .45836 L
.84171 .46593 L
.84281 .4735 L
.84364 .48107 L
.84418 .48864 L
.84446 .49621 L
.84446 .50379 L
.84418 .51136 L
.84364 .51893 L
.84281 .5265 L
.84171 .53407 L
.84032 .54164 L
.83864 .54921 L
.83692 .55591 L
.83667 .55678 L
.8344 .56435 L
.83182 .57193 L
.82935 .57841 L
.82891 .5795 L
.82566 .58707 L
.82207 .59464 L
.82177 .59523 L
.81811 .60221 L
.8142 .60903 L
.81375 .60978 L
.80898 .61735 L
.80663 .62084 L
.80376 .62492 L
.79906 .6312 L
.79805 .6325 L
.79182 .64007 L
.79149 .64044 L
.78499 .64764 L
.78392 .64876 L
.7775 .65521 L
.77635 .65631 L
.76925 .66278 L
.76878 .6632 L
.76121 .6695 L
.76012 .67035 L
.75363 .67527 L
.74993 .67792 L
.74606 .68058 L
.73849 .68545 L
.73842 .68549 L
.73092 .68992 L
.72517 .69306 L
.72335 .69402 L
.71578 .69776 L
.70947 .70064 L
.70821 .70118 L
.70064 .70429 L
.69306 .70709 L
.6898 .70821 L
.68549 .7096 L
.67792 .71184 L
.67035 .7138 L
.66278 .7155 L
.66142 .71578 L
.65521 .71694 L
.64764 .71813 L
.64007 .71907 L
.6325 .71976 L
.62492 .72021 L
.61735 .72042 L
.60978 .72038 L
.60221 .7201 L
.59464 .71958 L
.58707 .71881 L
.5795 .71779 L
.57193 .71652 L
.56807 .71578 L
.56435 .71499 L
.55678 .7132 L
.54921 .71114 L
.54164 .7088 L
.53985 .70821 L
.53407 .70617 L
.5265 .70325 L
.52034 .70064 L
.51893 .70001 L
.51136 .69644 L
.5048 .69306 L
.50379 .69252 L
.49621 .68824 L
.4917 .68549 L
.48864 .68356 L
.48107 .67845 L
.48032 .67792 L
.4735 .67288 L
.47027 .67035 L
.46593 .6668 L
.46127 .66278 L
.45836 .66015 L
.45315 .65521 L
.45079 .65286 L
.44578 .64764 L
.44322 .64483 L
.43907 .64007 L
.43565 .63592 L
.43294 .6325 L
.42807 .62596 L
.42734 .62492 L
.42222 .61735 L
.4205 .61466 L
.41754 .60978 L
.41327 .60221 L
.41293 .60158 L
.40938 .59464 L
.40586 .58707 L
.40536 .58592 L
.40269 .5795 L
.39984 .57193 L
.39779 .56585 L
.39731 .56435 L
.39509 .55678 L
.39316 .54921 L
.39153 .54164 L
.39022 .53437 L
.39017 .53407 L
.38909 .5265 L
.38829 .51893 L
.38775 .51136 L
.38748 .50379 L
.38748 .49621 L
.38775 .48864 L
.38829 .48107 L
.38909 .4735 L
.39017 .46593 L
.39022 .46563 L
.39153 .45836 L
.39316 .45079 L
.39509 .44322 L
.39731 .43565 L
.39779 .43415 L
.39984 .42807 L
.40269 .4205 L
.40536 .41408 L
.40586 .41293 L
.40938 .40536 L
.41293 .39842 L
.41327 .39779 L
.41754 .39022 L
.4205 .38534 L
.42222 .38265 L
.42734 .37508 L
.42807 .37404 L
.43294 .3675 L
.43565 .36408 L
.43907 .35993 L
.44322 .35517 L
.44578 .35236 L
.45079 .34714 L
.45315 .34479 L
.45836 .33985 L
.46127 .33722 L
.46593 .3332 L
.47027 .32965 L
.4735 .32712 L
.48032 .32208 L
.48107 .32155 L
.48864 .31644 L
.4917 .31451 L
.49621 .31176 L
.50379 .30748 L
.5048 .30694 L
.51136 .30356 L
.51893 .29999 L
.52034 .29936 L
.5265 .29675 L
.53407 .29383 L
.53985 .29179 L
.54164 .2912 L
.54921 .28886 L
.55678 .2868 L
.56435 .28501 L
.56807 .28422 L
F
0 .118 .208 r
.58707 .2989 m
.59464 .29814 L
.60221 .29765 L
.60978 .29743 L
.61735 .29747 L
.62492 .29778 L
.6325 .29835 L
.64007 .29919 L
.6414 .29936 L
.64764 .3003 L
.65521 .30169 L
.66278 .30336 L
.67035 .30532 L
.67589 .30694 L
.67792 .30757 L
.68549 .31013 L
.69306 .31301 L
.69669 .31451 L
.70064 .31623 L
.70821 .31979 L
.7127 .32208 L
.71578 .32373 L
.72335 .32806 L
.72595 .32965 L
.73092 .33282 L
.73734 .33722 L
.73849 .33805 L
.74606 .34379 L
.74732 .34479 L
.75363 .35009 L
.75619 .35236 L
.76121 .35704 L
.76414 .35993 L
.76878 .36474 L
.77132 .3675 L
.77635 .3733 L
.77781 .37508 L
.7837 .38265 L
.78392 .38294 L
.78905 .39022 L
.79149 .39394 L
.7939 .39779 L
.79829 .40536 L
.79906 .40677 L
.80225 .41293 L
.80582 .4205 L
.80663 .42235 L
.80901 .42807 L
.81183 .43565 L
.8142 .44287 L
.81431 .44322 L
.81645 .45079 L
.81828 .45836 L
.81978 .46593 L
.82098 .4735 L
.82177 .48007 L
.82187 .48107 L
.82246 .48864 L
.82276 .49621 L
.82276 .50379 L
.82246 .51136 L
.82187 .51893 L
.82177 .51993 L
.82098 .5265 L
.81978 .53407 L
.81828 .54164 L
.81645 .54921 L
.81431 .55678 L
.8142 .55713 L
.81183 .56435 L
.80901 .57193 L
.80663 .57765 L
.80582 .5795 L
.80225 .58707 L
.79906 .59323 L
.79829 .59464 L
.7939 .60221 L
.79149 .60606 L
.78905 .60978 L
.78392 .61706 L
.7837 .61735 L
.77781 .62492 L
.77635 .6267 L
.77132 .6325 L
.76878 .63526 L
.76414 .64007 L
.76121 .64296 L
.75619 .64764 L
.75363 .64991 L
.74732 .65521 L
.74606 .65621 L
.73849 .66195 L
.73734 .66278 L
.73092 .66718 L
.72595 .67035 L
.72335 .67194 L
.71578 .67627 L
.7127 .67792 L
.70821 .68021 L
.70064 .68377 L
.69669 .68549 L
.69306 .68699 L
.68549 .68987 L
.67792 .69243 L
.67589 .69306 L
.67035 .69468 L
.66278 .69664 L
.65521 .69831 L
.64764 .6997 L
.6414 .70064 L
.64007 .70081 L
.6325 .70165 L
.62492 .70222 L
.61735 .70253 L
.60978 .70257 L
.60221 .70235 L
.59464 .70186 L
.58707 .7011 L
.58336 .70064 L
.5795 .70007 L
.57193 .69876 L
.56435 .69717 L
.55678 .69529 L
.54921 .69312 L
.54904 .69306 L
.54164 .69063 L
.53407 .68783 L
.52837 .68549 L
.5265 .68469 L
.51893 .68119 L
.51248 .67792 L
.51136 .67732 L
.50379 .67305 L
.49934 .67035 L
.49621 .66835 L
.48864 .66319 L
.48808 .66278 L
.48107 .65751 L
.47821 .65521 L
.4735 .65125 L
.46944 .64764 L
.46593 .64435 L
.46159 .64007 L
.45836 .63671 L
.45451 .6325 L
.45079 .62818 L
.44811 .62492 L
.44322 .61859 L
.4423 .61735 L
.43704 .60978 L
.43565 .60765 L
.43226 .60221 L
.42807 .59489 L
.42794 .59464 L
.42404 .58707 L
.42053 .5795 L
.4205 .57943 L
.4174 .57193 L
.41463 .56435 L
.41293 .55921 L
.41219 .55678 L
.41008 .54921 L
.4083 .54164 L
.40682 .53407 L
.40564 .5265 L
.40536 .52442 L
.40477 .51893 L
.40418 .51136 L
.40389 .50379 L
.40389 .49621 L
.40418 .48864 L
.40477 .48107 L
.40536 .47558 L
.40564 .4735 L
.40682 .46593 L
.4083 .45836 L
.41008 .45079 L
.41219 .44322 L
.41293 .44079 L
.41463 .43565 L
.4174 .42807 L
.4205 .42057 L
.42053 .4205 L
.42404 .41293 L
.42794 .40536 L
.42807 .40511 L
.43226 .39779 L
.43565 .39235 L
.43704 .39022 L
.4423 .38265 L
.44322 .38141 L
.44811 .37508 L
.45079 .37182 L
.45451 .3675 L
.45836 .36329 L
.46159 .35993 L
.46593 .35565 L
.46944 .35236 L
.4735 .34875 L
.47821 .34479 L
.48107 .34249 L
.48808 .33722 L
.48864 .33681 L
.49621 .33165 L
.49934 .32965 L
.50379 .32695 L
.51136 .32268 L
.51248 .32208 L
.51893 .31881 L
.5265 .31531 L
.52837 .31451 L
.53407 .31217 L
.54164 .30937 L
.54904 .30694 L
.54921 .30688 L
.55678 .30471 L
.56435 .30283 L
.57193 .30124 L
.5795 .29993 L
.58336 .29936 L
F
0 .093 .19 r
.56435 .32207 m
.57193 .32039 L
.5795 .31902 L
.58707 .31796 L
.59464 .31721 L
.60221 .31675 L
.60978 .31658 L
.61735 .31671 L
.62492 .31714 L
.6325 .31786 L
.64007 .31888 L
.64764 .3202 L
.65521 .32184 L
.6562 .32208 L
.66278 .3238 L
.67035 .32608 L
.67792 .32871 L
.68041 .32965 L
.68549 .33169 L
.69306 .33506 L
.69752 .33722 L
.70064 .33882 L
.70821 .34301 L
.71119 .34479 L
.71578 .34767 L
.72269 .35236 L
.72335 .35284 L
.73092 .35856 L
.73262 .35993 L
.73849 .36493 L
.74134 .3675 L
.74606 .37202 L
.74909 .37508 L
.75363 .37996 L
.756 .38265 L
.76121 .38895 L
.7622 .39022 L
.76777 .39779 L
.76878 .39925 L
.77277 .40536 L
.77635 .41132 L
.77726 .41293 L
.78127 .4205 L
.78392 .42603 L
.78484 .42807 L
.78799 .43565 L
.79075 .44322 L
.79149 .44546 L
.79312 .45079 L
.79514 .45836 L
.7968 .46593 L
.79812 .4735 L
.79906 .48069 L
.7991 .48107 L
.79975 .48864 L
.80008 .49621 L
.80008 .50379 L
.79975 .51136 L
.7991 .51893 L
.79906 .51931 L
.79812 .5265 L
.7968 .53407 L
.79514 .54164 L
.79312 .54921 L
.79149 .55454 L
.79075 .55678 L
.78799 .56435 L
.78484 .57193 L
.78392 .57397 L
.78127 .5795 L
.77726 .58707 L
.77635 .58868 L
.77277 .59464 L
.76878 .60075 L
.76777 .60221 L
.7622 .60978 L
.76121 .61105 L
.756 .61735 L
.75363 .62004 L
.74909 .62492 L
.74606 .62798 L
.74134 .6325 L
.73849 .63507 L
.73262 .64007 L
.73092 .64144 L
.72335 .64716 L
.72269 .64764 L
.71578 .65233 L
.71119 .65521 L
.70821 .65699 L
.70064 .66118 L
.69752 .66278 L
.69306 .66494 L
.68549 .66831 L
.68041 .67035 L
.67792 .67129 L
.67035 .67392 L
.66278 .6762 L
.6562 .67792 L
.65521 .67816 L
.64764 .6798 L
.64007 .68112 L
.6325 .68214 L
.62492 .68286 L
.61735 .68329 L
.60978 .68342 L
.60221 .68325 L
.59464 .68279 L
.58707 .68204 L
.5795 .68098 L
.57193 .67961 L
.56435 .67793 L
.56431 .67792 L
.55678 .67593 L
.54921 .67359 L
.54164 .6709 L
.54021 .67035 L
.53407 .66785 L
.5265 .66441 L
.5232 .66278 L
.51893 .66055 L
.51136 .65626 L
.50963 .65521 L
.50379 .65148 L
.49822 .64764 L
.49621 .64618 L
.48864 .64028 L
.48838 .64007 L
.48107 .63373 L
.47974 .6325 L
.4735 .6264 L
.47208 .62492 L
.46593 .61816 L
.46524 .61735 L
.45911 .60978 L
.45836 .6088 L
.45361 .60221 L
.45079 .59799 L
.44866 .59464 L
.44423 .58707 L
.44322 .5852 L
.44028 .5795 L
.43676 .57193 L
.43565 .56933 L
.43365 .56435 L
.43093 .55678 L
.42859 .54921 L
.42807 .54739 L
.4266 .54164 L
.42496 .53407 L
.42367 .5265 L
.4227 .51893 L
.42205 .51136 L
.42173 .50379 L
.42173 .49621 L
.42205 .48864 L
.4227 .48107 L
.42367 .4735 L
.42496 .46593 L
.4266 .45836 L
.42807 .45261 L
.42859 .45079 L
.43093 .44322 L
.43365 .43565 L
.43565 .43067 L
.43676 .42807 L
.44028 .4205 L
.44322 .4148 L
.44423 .41293 L
.44866 .40536 L
.45079 .40201 L
.45361 .39779 L
.45836 .3912 L
.45911 .39022 L
.46524 .38265 L
.46593 .38184 L
.47208 .37508 L
.4735 .3736 L
.47974 .3675 L
.48107 .36627 L
.48838 .35993 L
.48864 .35972 L
.49621 .35382 L
.49822 .35236 L
.50379 .34852 L
.50963 .34479 L
.51136 .34374 L
.51893 .33945 L
.5232 .33722 L
.5265 .33559 L
.53407 .33215 L
.54021 .32965 L
.54164 .3291 L
.54921 .32641 L
.55678 .32407 L
.56431 .32208 L
F
0 .071 .172 r
.56435 .34327 m
.57193 .34145 L
.5795 .33999 L
.58707 .33888 L
.59464 .33811 L
.60221 .33768 L
.60978 .33758 L
.61735 .33782 L
.62492 .33839 L
.6325 .3393 L
.64007 .34055 L
.64764 .34216 L
.65521 .34412 L
.6575 .34479 L
.66278 .34647 L
.67035 .3492 L
.67792 .35235 L
.67796 .35236 L
.68549 .35594 L
.69295 .35993 L
.69306 .36 L
.70064 .36458 L
.70505 .3675 L
.70821 .36973 L
.71523 .37508 L
.71578 .37552 L
.72335 .38205 L
.724 .38265 L
.73092 .38944 L
.73167 .39022 L
.73842 .39779 L
.73849 .39788 L
.74439 .40536 L
.74606 .40766 L
.74968 .41293 L
.75363 .41926 L
.75436 .4205 L
.75849 .42807 L
.76121 .43363 L
.76212 .43565 L
.76527 .44322 L
.76798 .45079 L
.76878 .45326 L
.77027 .45836 L
.77215 .46593 L
.77364 .4735 L
.77475 .48107 L
.77548 .48864 L
.77585 .49621 L
.77585 .50379 L
.77548 .51136 L
.77475 .51893 L
.77364 .5265 L
.77215 .53407 L
.77027 .54164 L
.76878 .54674 L
.76798 .54921 L
.76527 .55678 L
.76212 .56435 L
.76121 .56637 L
.75849 .57193 L
.75436 .5795 L
.75363 .58074 L
.74968 .58707 L
.74606 .59234 L
.74439 .59464 L
.73849 .60212 L
.73842 .60221 L
.73167 .60978 L
.73092 .61056 L
.724 .61735 L
.72335 .61795 L
.71578 .62448 L
.71523 .62492 L
.70821 .63027 L
.70505 .6325 L
.70064 .63542 L
.69306 .64 L
.69295 .64007 L
.68549 .64406 L
.67796 .64764 L
.67792 .64765 L
.67035 .6508 L
.66278 .65353 L
.6575 .65521 L
.65521 .65588 L
.64764 .65784 L
.64007 .65945 L
.6325 .6607 L
.62492 .66161 L
.61735 .66218 L
.60978 .66242 L
.60221 .66232 L
.59464 .66189 L
.58707 .66112 L
.5795 .66001 L
.57193 .65855 L
.56435 .65673 L
.55896 .65521 L
.55678 .65454 L
.54921 .65196 L
.54164 .64896 L
.53859 .64764 L
.53407 .64554 L
.5265 .64165 L
.52367 .64007 L
.51893 .63725 L
.51166 .6325 L
.51136 .63229 L
.50379 .62671 L
.50154 .62492 L
.49621 .62042 L
.49284 .61735 L
.48864 .6133 L
.48524 .60978 L
.48107 .60518 L
.47854 .60221 L
.4735 .59582 L
.47263 .59464 L
.46739 .58707 L
.46593 .58479 L
.46275 .5795 L
.45866 .57193 L
.45836 .57132 L
.45508 .56435 L
.45196 .55678 L
.45079 .55363 L
.44928 .54921 L
.44702 .54164 L
.44516 .53407 L
.44369 .5265 L
.44322 .52366 L
.44259 .51893 L
.44186 .51136 L
.4415 .50379 L
.4415 .49621 L
.44186 .48864 L
.44259 .48107 L
.44322 .47634 L
.44369 .4735 L
.44516 .46593 L
.44702 .45836 L
.44928 .45079 L
.45079 .44637 L
.45196 .44322 L
.45508 .43565 L
.45836 .42868 L
.45866 .42807 L
.46275 .4205 L
.46593 .41521 L
.46739 .41293 L
.47263 .40536 L
.4735 .40418 L
.47854 .39779 L
.48107 .39482 L
.48524 .39022 L
.48864 .3867 L
.49284 .38265 L
.49621 .37958 L
.50154 .37508 L
.50379 .37329 L
.51136 .36771 L
.51166 .3675 L
.51893 .36275 L
.52367 .35993 L
.5265 .35835 L
.53407 .35446 L
.53859 .35236 L
.54164 .35104 L
.54921 .34804 L
.55678 .34546 L
.55896 .34479 L
F
0 .051 .154 r
.56435 .3674 m
.57193 .36535 L
.5795 .36373 L
.58707 .36252 L
.59464 .36172 L
.60221 .36131 L
.60978 .36129 L
.61735 .36167 L
.62492 .36244 L
.6325 .36361 L
.64007 .3652 L
.64764 .36721 L
.64863 .3675 L
.65521 .36966 L
.66278 .37259 L
.66838 .37508 L
.67035 .37602 L
.67792 .38 L
.68244 .38265 L
.68549 .38457 L
.69306 .38983 L
.69359 .39022 L
.70064 .39586 L
.70285 .39779 L
.70821 .40282 L
.71071 .40536 L
.71578 .41091 L
.71749 .41293 L
.72335 .4205 L
.72335 .4205 L
.72845 .42807 L
.73092 .43219 L
.73285 .43565 L
.73665 .44322 L
.73849 .44737 L
.73988 .45079 L
.74259 .45836 L
.74481 .46593 L
.74606 .47112 L
.74656 .4735 L
.74786 .48107 L
.74871 .48864 L
.74914 .49621 L
.74914 .50379 L
.74871 .51136 L
.74786 .51893 L
.74656 .5265 L
.74606 .52888 L
.74481 .53407 L
.74259 .54164 L
.73988 .54921 L
.73849 .55263 L
.73665 .55678 L
.73285 .56435 L
.73092 .56781 L
.72845 .57193 L
.72335 .5795 L
.72335 .5795 L
.71749 .58707 L
.71578 .58909 L
.71071 .59464 L
.70821 .59718 L
.70285 .60221 L
.70064 .60414 L
.69359 .60978 L
.69306 .61017 L
.68549 .61543 L
.68244 .61735 L
.67792 .62 L
.67035 .62398 L
.66838 .62492 L
.66278 .62741 L
.65521 .63034 L
.64863 .6325 L
.64764 .63279 L
.64007 .6348 L
.6325 .63639 L
.62492 .63756 L
.61735 .63833 L
.60978 .63871 L
.60221 .63869 L
.59464 .63828 L
.58707 .63748 L
.5795 .63627 L
.57193 .63465 L
.56435 .6326 L
.564 .6325 L
.55678 .6301 L
.54921 .62712 L
.54431 .62492 L
.54164 .62363 L
.53407 .61958 L
.53032 .61735 L
.5265 .61492 L
.51923 .60978 L
.51893 .60956 L
.51136 .60339 L
.51002 .60221 L
.50379 .59627 L
.5022 .59464 L
.49621 .58796 L
.49547 .58707 L
.48965 .5795 L
.48864 .57808 L
.48459 .57193 L
.48107 .56592 L
.48022 .56435 L
.47646 .55678 L
.4735 .54985 L
.47325 .54921 L
.47057 .54164 L
.46837 .53407 L
.46663 .5265 L
.46593 .5228 L
.46535 .51893 L
.46449 .51136 L
.46407 .50379 L
.46407 .49621 L
.46449 .48864 L
.46535 .48107 L
.46593 .4772 L
.46663 .4735 L
.46837 .46593 L
.47057 .45836 L
.47325 .45079 L
.4735 .45015 L
.47646 .44322 L
.48022 .43565 L
.48107 .43408 L
.48459 .42807 L
.48864 .42192 L
.48965 .4205 L
.49547 .41293 L
.49621 .41204 L
.5022 .40536 L
.50379 .40373 L
.51002 .39779 L
.51136 .39661 L
.51893 .39044 L
.51923 .39022 L
.5265 .38508 L
.53032 .38265 L
.53407 .38042 L
.54164 .37637 L
.54431 .37508 L
.54921 .37288 L
.55678 .3699 L
.564 .3675 L
F
0 .035 .136 r
.59464 .38977 m
.60221 .38937 L
.60978 .38947 L
.61735 .39006 L
.61886 .39022 L
.62492 .39115 L
.6325 .39276 L
.64007 .39491 L
.64764 .39764 L
.64801 .39779 L
.65521 .40099 L
.66278 .40502 L
.66337 .40536 L
.67035 .40983 L
.67462 .41293 L
.67792 .41555 L
.68355 .4205 L
.68549 .42238 L
.69087 .42807 L
.69306 .43064 L
.69697 .43565 L
.70064 .44094 L
.70207 .44322 L
.70633 .45079 L
.70821 .45464 L
.70984 .45836 L
.71268 .46593 L
.7149 .4735 L
.71578 .47714 L
.71653 .48107 L
.71761 .48864 L
.71815 .49621 L
.71815 .50379 L
.71761 .51136 L
.71653 .51893 L
.71578 .52286 L
.7149 .5265 L
.71268 .53407 L
.70984 .54164 L
.70821 .54536 L
.70633 .54921 L
.70207 .55678 L
.70064 .55906 L
.69697 .56435 L
.69306 .56936 L
.69087 .57193 L
.68549 .57762 L
.68355 .5795 L
.67792 .58445 L
.67462 .58707 L
.67035 .59017 L
.66337 .59464 L
.66278 .59498 L
.65521 .59901 L
.64801 .60221 L
.64764 .60236 L
.64007 .60509 L
.6325 .60724 L
.62492 .60885 L
.61886 .60978 L
.61735 .60994 L
.60978 .61053 L
.60221 .61063 L
.59464 .61023 L
.58959 .60978 L
.58707 .60934 L
.5795 .60793 L
.57193 .606 L
.56435 .60349 L
.56102 .60221 L
.55678 .60039 L
.54921 .59662 L
.54572 .59464 L
.54164 .59211 L
.53451 .58707 L
.53407 .58673 L
.5265 .58032 L
.52562 .5795 L
.51893 .5726 L
.51833 .57193 L
.51227 .56435 L
.51136 .5631 L
.50719 .55678 L
.50379 .55081 L
.50296 .54921 L
.49947 .54164 L
.49665 .53407 L
.49621 .53276 L
.49444 .5265 L
.49282 .51893 L
.49174 .51136 L
.49121 .50379 L
.49121 .49621 L
.49174 .48864 L
.49282 .48107 L
.49444 .4735 L
.49621 .46724 L
.49665 .46593 L
.49947 .45836 L
.50296 .45079 L
.50379 .44919 L
.50719 .44322 L
.51136 .4369 L
.51227 .43565 L
.51833 .42807 L
.51893 .4274 L
.52562 .4205 L
.5265 .41968 L
.53407 .41327 L
.53451 .41293 L
.54164 .40789 L
.54572 .40536 L
.54921 .40338 L
.55678 .39961 L
.56102 .39779 L
.56435 .39651 L
.57193 .394 L
.5795 .39207 L
.58707 .39066 L
.58959 .39022 L
F
0 .021 .118 r
.59464 .42728 m
.60221 .42684 L
.60978 .42716 L
.61651 .42807 L
.61735 .42823 L
.62492 .43009 L
.6325 .43282 L
.63849 .43565 L
.64007 .43651 L
.64764 .44135 L
.6501 .44322 L
.65521 .44765 L
.65831 .45079 L
.66278 .45605 L
.66448 .45836 L
.66919 .46593 L
.67035 .46813 L
.67274 .4735 L
.67528 .48107 L
.67692 .48864 L
.67773 .49621 L
.67773 .50379 L
.67692 .51136 L
.67528 .51893 L
.67274 .5265 L
.67035 .53187 L
.66919 .53407 L
.66448 .54164 L
.66278 .54395 L
.65831 .54921 L
.65521 .55235 L
.6501 .55678 L
.64764 .55865 L
.64007 .56349 L
.63849 .56435 L
.6325 .56718 L
.62492 .56991 L
.61735 .57177 L
.61651 .57193 L
.60978 .57284 L
.60221 .57316 L
.59464 .57272 L
.58807 .57193 L
.58707 .57153 L
.5795 .56953 L
.57193 .56666 L
.56714 .56435 L
.56435 .56279 L
.55678 .55773 L
.55557 .55678 L
.54921 .55112 L
.54738 .54921 L
.54164 .54223 L
.54123 .54164 L
.53653 .53407 L
.53407 .52908 L
.533 .5265 L
.53047 .51893 L
.52883 .51136 L
.52802 .50379 L
.52802 .49621 L
.52883 .48864 L
.53047 .48107 L
.533 .4735 L
.53407 .47092 L
.53653 .46593 L
.54123 .45836 L
.54164 .45777 L
.54738 .45079 L
.54921 .44888 L
.55557 .44322 L
.55678 .44227 L
.56435 .43721 L
.56714 .43565 L
.57193 .43334 L
.5795 .43047 L
.58707 .42847 L
.58807 .42807 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00A_ooool3o`0000Cooooo0_l0000hooooo`?o0000>Oooool2o`0003_ooooo0ol0000Moooo
o`00Aoooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003Kooooo00Go0000oooo
ooooooooooooo`00000gooooo`04o`000?ooooooooooo`0003Wooooo00Go0000oooooooooooooooo
o`00000Looooo`00?oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000`ooooo`Go00001Oooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0003go
oooo00?o0000ooooooooool06_ooool004Oooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000jooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo0000?Oooool00ol0
003oooooooooo`0Jooooo`00Aoooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
03Kooooo1?l0000hooooo`04o`000?ooooooooooo`0003Wooooo1?l0000Mooooo`00A_ooool2o`00
00Cooooo00Co0000oooooooooooo0000=_ooool00ol0003oooooooooo`0iooooo`04o`000?oooooo
ooooo`0003Wooooo00?o0000ooooooooool07_ooool004Oooooo00?o0000ooooooooool00oooool2
o`0003Oooooo1Ol0000hooooo`;o0000>_ooool5o`0001cooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Foooooooo00002Ol00002oooo
o`005_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool01?l0003oooooooooool00002ooooo`005_ooool00ol0003oooooooooo`3oooooo`Go
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo0?oooooo1Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool0ooooool5ooooo`7o00000Oooool1ooooo`002?ooool3
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo0?oooooo1Oooool1o`00007ooooo0Oooool0
00Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo1_ok4`0:ooHV00OolSP01oo]BP05onQJ00Koi6X01OoONP05om^800GoeYH01OoAX`04
olf`00Gob;/01Oo1a005ojfo00GoVkX01_n8]P05ogNa00KoIjd01omGZ006odRS00So>Il02?l/VP0;
oajF00ko4Y406_l6S00To`280a3o08<=2Ol0OQL6o`1j7`Co07DW1Oooool1o`00007ooooo0Oooool0
0003ooooool0003o000000?o00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Cooooo0ol00002ooooo`Oona<02Oof9P07oo8h00OokDX01OoXFP05onAZ00KoggX01?oKR005
omJF00GodJ<01?o=/005olRk00Go`L@01On]_`05oi^j00GoR;H01_mg/@06ofN]00KoEjP01_m8X`08
ocVO00So;9X02_lNUP0=oa:A01Ko1X`0:_l0R0<Bo`233@Wo07hG1ol0NQl3o`1e9`?ooooo0ol00002
ooooo`002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00_ooool7oo/C00WomRH01oob>006one:00Goj5X01_oTJP04ommj00GofhP01OoFUP05
om6S00GocK001?o8^`05ol7400Go[Kl01OnK^P05ohRf00GoMk401_mW[@06oeNX00KoB:<02?liW`08
obbJ00[o7YH02olBT@0Bo`J<02ko08P35Ol0P`d:o`1n5`Oo07XO0ol0MBL5ooooo`7o00000Oooool1
ooooo`002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00_ooool7oo/C00WomRH01_ob>006one:00Koj5X01OoTJP05ommj00GofhP01OoFUP04
om6S00GocK001Oo8^`04ol7400Go[Kl01OnK^P05ohRf00GoMk401_mW[@06oeNX00KoB:<01oliW`08
obbJ00So7YH02olBT@0Ao`J<02go08P36ol0P`d:o`1n5`Oo07XO0ol0MBL5ooooo`7o00000Oooool1
ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02
ooooo`Oona<02?of9P07oo8h00KokDX01OoXFP05onAZ00GoggX01OoKR005omJF00CodJ<01Oo=/004
olRk00Go`L@01On]_`05oi^j00GoR;H01Omg/@05ofN]00KoEjP01_m8X`07ocVO00So;9X02?lNUP09
oa:A013o1X`09_l0R0<Vo`233@_o07hG2?l0NQl2o`1e9`Gooooo0Ol00001ooooo`7ooooo0009oooo
o`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo1ook4`08ooHV
00OolSP01_o]BP05onQJ00Goi6X01?oONP06om^800CoeYH01?oAX`05olf`00Gob;/01?o1a005ojfo
00GoVkX01On8]P05ogNa00GoIjd01_mGZ006odRS00Ko>Il02?l/VP08oajF00[o4Y403?l6S00Ko`28
0cGo08<=3?l0OQL8o`1j7`;o07DW1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooooooo
ool00_ooool7oo/C00SomRH01_ob>006one:00Goj5X01OoTJP05ommj00CofhP01OoFUP05om6S00Co
cK001Oo8^`04ol7400Go[Kl01?nK^P05ohRf00GoMk401OmW[@06oeNX00KoB:<01_liW`06obbJ00So
7YH02_lBT@0;o`J<01Ko08P3??l0P`d?o`1n5`So07XO0_l0MBL5ooooo`7o00000Oooool1ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`Oona<02?of9P06oo8h00GokDX01_oXFP04onAZ00KoggX0
1?oKR004omJF00GodJ<01?o=/005olRk00Co`L@01On]_`04oi^j00GoR;H01Omg/@05ofN]00KoEjP0
1Om8X`06ocVO00Oo;9X02?lNUP09oa:A00[o1X`04Ol0R0=3o`233A3o07hG2?l0NQl2o`1e9`Gooooo
0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo1ook4`07ooHV00OolSP01Oo]
BP05onQJ00Goi6X01?oONP05om^800GoeYH01?oAX`04olf`00Gob;/01?o1a005ojfo00CoVkX01On8
]P05ogNa00GoIjd01OmGZ005odRS00Ko>Il01ol/VP07oajF00So4Y402ol6S00>o`280dKo08<=4_l0
OQL9o`1j7`;o07DW1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool7
oo/C00OomRH01_ob>006one:00Coj5X01_oTJP04ommj00CofhP01OoFUP04om6S00GocK001?o8^`04
ol7400Go[Kl01?nK^P05ohRf00GoMk401OmW[@05oeNX00GoB:<01_liW`07obbJ00Ko7YH02?lBT@0:
o`J<00go08P3A?l0P`dHo`1n5`Wo07XO0_l0MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02ooooo`Oona<01oof9P06oo8h00GokDX01OoXFP05onAZ00CoggX01OoKR004omJF
00CodJ<01Oo=/004olRk00Co`L@01On]_`04oi^j00GoR;H01?mg/@05ofN]00GoEjP01_m8X`06ocVO
00Ko;9X01_lNUP08oa:A00[o1X`02ol0R0<Fo`233D[o07hG2Ol0NQl2o`1e9`Gooooo0Ol00001oooo
o`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo1ook4`07ooHV00KolSP01Oo]BP05onQJ00Co
i6X01OoONP04om^800GoeYH01?oAX`04olf`00Cob;/01?o1a005ojfo00CoVkX01On8]P04ogNa00Go
Ijd01OmGZ005odRS00Ko>Il01_l/VP06oajF00So4Y402?l6S00;o`280a;o08<=DOl0OQL;o`1j7`03
o`1e9ooooooooooo00?ooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo
1ook4`06ooHV00KolSP01Oo]BP05onQJ00Goi6X01?oONP04om^800CoeYH01OoAX`04olf`00Cob;/0
1?o1a005ojfo00CoVkX01?n8]P05ogNa00GoIjd01OmGZ004odRS00Ko>Il01_l/VP06oajF00So4Y40
2?l6S00:o`280`go08<=F?l0OQL<o`1j7`03o`1e9ooooooooooo00?ooooo0Ol00001ooooo`7ooooo
000Fooooo`;o00000oooool7oo/C00KomRH01Oob>006one:00Coj5X01OoTJP05ommj00CofhP01?oF
UP04om6S00CocK001?o8^`04ol7400Go[Kl01?nK^P05ohRf00CoMk401OmW[@04oeNX00GoB:<01_li
W`05obbJ00Ko7YH02?lBT@08o`J<00So08P33Ol0P`eKo`1n5`go07XO00?o07DWooooooooool00_oo
ool2o`0000;ooooo000Fooooo`03o`000?oooooooooo00;ooooo1_ok4`07ooHV00GolSP01Oo]BP05
onQJ00Coi6X01OoONP04om^800CoeYH01?oAX`04olf`00Gob;/01?o1a004ojfo00CoVkX01?n8]P05
ogNa00CoIjd01OmGZ005odRS00Go>Il01Ol/VP06oajF00So4Y401_l6S00:o`280`_o08<=5_l0OQLM
o`1j7b_o07hG3_l0NQl00ol0MBOoooooooooo`03ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02ooooo`Kona<01_of9P06oo8h00GokDX01OoXFP04onAZ00CoggX01?oKR004omJF
00CodJ<01?o=/005olRk00Co`L@01?n]_`04oi^j00CoR;H01Omg/@04ofN]00GoEjP01Om8X`05ocVO
00Go;9X01_lNUP07oa:A00Ko1X`02Ol0R0<:o`233A7o07hG<_l0NQlMo`1n5a3o07XO00?o07DWoooo
ooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool6oo/C00Ko
mRH01Oob>005one:00Goj5X01?oTJP05ommj00CofhP01?oFUP04om6S00CocK001?o8^`04ol7400Co
[Kl01?nK^P04ohRf00GoMk401?mW[@04oeNX00GoB:<01OliW`06obbJ00Go7YH01olBT@06o`J<00So
08P32_l0P`d=o`1n5d?o07XO3ol0OQLCo`1j7`;o07DW1Oooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool00_ooool6oo/C00KomRH01Oob>005one:00Coj5X01OoTJP04ommj00CofhP0
1?oFUP04om6S00CocK001?o8^`04ol7400Co[Kl01?nK^P04ohRf00GoMk401?mW[@04oeNX00GoB:<0
1OliW`05obbJ00Ko7YH01_lBT@06o`J<00So08P32Ol0P`d<o`1n5fWo07XO0_l0MBL5ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`Kona<01Oof9P05oo8h00GokDX01OoX
FP04onAZ00CoggX01?oKR004omJF00CodJ<01?o=/004olRk00Co`L@01?n]_`04oi^j00CoR;H01?mg
/@05ofN]00CoEjP01?m8X`06ocVO00Co;9X01_lNUP06oa:A00Ko1X`02?l0R0<8o`233@_o07hG5?l0
NQlKo`1e9cko07XO0_l0MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02
ooooo`Kona<01Oof9P05oo8h00GokDX01OoXFP04onAZ00CoggX01?oKR004omJF00CodJ<01?o=/004
olRk00Co`L@00on]_`04oi^j00CoR;H01Omg/@04ofN]00CoEjP01?m8X`05ocVO00Go;9X01OlNUP06
oa:A00Ko1X`01ol0R0<9o`233@[o07hG3ol0NQl]o`1e9cCo07XO0_l0MBL5ooooo`7o00000Oooool1
ooooo`005_ooool00ol0003oooooooooo`02ooooo`Gona<01Oof9P06oo8h00CokDX01OoXFP04onAZ
00CoggX01?oKR004omJF00CodJ<01?o=/003olRk00Co`L@01?n]_`04oi^j00CoR;H01?mg/@04ofN]
00GoEjP01?m8X`05ocVO00Go;9X01?lNUP06oa:A00Ko1X`01_l0R0<8o`233@[o07hG3Ol0NQlio`1e
9bgo07XO0ol0MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`Go
na<01Oof9P06oo8h00CokDX01?oXFP04onAZ00CoggX01?oKR004omJF00CodJ<01?o=/004olRk00Co
`L@01?n]_`04oi^j00CoR;H01?mg/@04ofN]00CoEjP01?m8X`05ocVO00Co;9X01OlNUP06oa:A00Ko
1X`01_l0R0<7o`233@[o07hG2ol0NQm3o`1e9bOo07XO0ol0MBL5ooooo`7o00000Oooool1ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`Cona<01_of9P05oo8h00CokDX01OoXFP04onAZ00CoggX0
1?oKR004omJF00?odJ<01?o=/004olRk00Co`L@00on]_`04oi^j00CoR;H01?mg/@04ofN]00GoEjP0
1?m8X`04ocVO00Go;9X01OlNUP05oa:A00Go1X`01_l0R0<8o`233@So07hG2_l0NQlCo`1e9a_o074_
8?l0MBLOo`1j7`Go07DW1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_oo
ool4oo/C00KomRH01?ob>005one:00Goj5X01?oTJP04ommj00CofhP00ooFUP04om6S00?ocK001?o8
^`04ol7400Co[Kl01?nK^P04ohRf00CoMk401?mW[@04oeNX00CoB:<01?liW`05obbJ00Go7YH01OlB
T@05o`J<00Ko08P31ol0P`d8o`1n5`[o07XO3_l0MBL[o`1a;aco07DW6Ol0NQl6o`1e9`Gooooo0Ol0
0001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo1?ok4`05ooHV00GolSP01?o]BP04
onQJ00Goi6X00ooONP04om^800CoeYH01?oAX`04olf`00Cob;/00oo1a004ojfo00CoVkX00on8]P04
ogNa00CoIjd01?mGZ005odRS00Co>Il01?l/VP05oajF00Go4Y401_l6S005o`280`Oo08<=2?l0OQL8
o`1j7`go07DW=ol0LBlJo`1e9a7o07XO2Ol0MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02ooooo`Cona<01Oof9P05oo8h00CokDX01?oXFP04onAZ00CoggX01?oKR004omJF
00CodJ<00oo=/004olRk00?o`L@01?n]_`04oi^j00CoR;H01?mg/@04ofN]00CoEjP01?m8X`04ocVO
00Co;9X01OlNUP05oa:A00Go1X`01_l0R0<6o`233@Oo07hG2Ol0NQl:o`1e9d3o074_7_l0MBL5o`1j
7`go07DW1Oooool1o`00007ooooo0Oooool001Kooooo0_l00003ooooo`?ona<01Oof9P05oo8h00Co
kDX01OoXFP04onAZ00CoggX00ooKR004omJF00CodJ<00oo=/004olRk00Co`L@00on]_`04oi^j00Co
R;H00omg/@04ofN]00CoEjP01?m8X`05ocVO00Co;9X01?lNUP05oa:A00Go1X`01_l0R0<6o`233@Ko
07hG2?l0NQl:o`1e9a7o074_7ol0K3DHo`1a;bco07DW1?ooool2o`0000;ooooo000Fooooo`03o`00
0?oooooooooo00;ooooo0ook4`05ooHV00ColSP01Oo]BP05onQJ00Coi6X00ooONP03om^800CoeYH0
1?oAX`04olf`00Cob;/00oo1a003ojfo00CoVkX01?n8]P04ogNa00CoIjd01?mGZ004odRS00Co>Il0
1?l/VP04oajF00Go4Y401Ol6S005o`280`Ko08<=1ol0OQL7o`1j7`[o07DW3Ol0LBl/o`1/=AGo074_
:?l0MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;ona<01_of
9P04oo8h00CokDX01?oXFP04onAZ00CoggX01?oKR004omJF00?odJ<01?o=/003olRk00Co`L@01?n]
_`03oi^j00CoR;H01?mg/@03ofN]00CoEjP01?m8X`04ocVO00Go;9X01?lNUP04oa:A00Go1X`01Ol0
R0<6o`233@Ko07hG2?l0NQl8o`1e9`_o074_=ol0K3DDo`1a;bCo07DW1Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool2oo/C00KomRH01?ob>004one:00Coj5X01?oTJP04
ommj00CofhP01?oFUP03om6S00?ocK001?o8^`04ol7400?o[Kl00onK^P04ohRf00CoMk401?mW[@04
oeNX00?oB:<01?liW`05obbJ00Co7YH01?lBT@05o`J<00Go08P31_l0P`d6o`1n5`Oo07XO2?l0MBL:
o`1a;aGo06`e3ol0Ic/Jo`1/=ACo074_8?l0MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02ooooo`;ona<01Oof9P04oo8h00GokDX01?oXFP03onAZ00CoggX01?oKR003omJF
00CodJ<01?o=/003olRk00?o`L@01?n]_`04oi^j00?oR;H01?mg/@04ofN]00?oEjP01?m8X`04ocVO
00Co;9X01OlNUP04oa:A00Co1X`01_l0R0<4o`233@Ko07hG2?l0NQl6o`1e9`[o074_3ol0K3DSo`1W
>aCo06`e5?l0LBlLo`1e9`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;o
oooo0_ok4`04ooHV00GolSP01Oo]BP04onQJ00?oi6X00ooONP04om^800CoeYH01?oAX`03olf`00?o
b;/01?o1a004ojfo00?oVkX00on8]P04ogNa00CoIjd01?mGZ003odRS00Co>Il01?l/VP05oajF00Co
4Y401?l6S005o`280`Go08<=1_l0OQL7o`1j7`Oo07DW2Ol0LBl<o`1/=Bko06Lk4_l0K3DBo`1a;a[o
07DW1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool00ook4`3omRH0
ooHV0003ooHV00ColSP01?o]BP04onQJ00Coi6X01?oONP04om^800?oeYH01?oAX`03olf`00Cob;/0
0oo1a004ojfo00?oVkX01?n8]P03ogNa00CoIjd00omGZ004odRS00Co>Il01?l/VP04oajF00Go4Y40
1?l6S004o`280`Ko08<=1Ol0OQL7o`1j7`Ko07DW2?l0LBl;o`1/=COo06Lk4_l0K3DBo`1a;aKo07DW
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool00ook4`3omRH0ooHV
0003ooHV00ColSP01?o]BP04onQJ00Coi6X01?oONP04om^800?oeYH00ooAX`04olf`00?ob;/00oo1
a004ojfo00CoVkX00on8]P03ogNa00CoIjd01?mGZ004odRS00?o>Il01?l/VP04oajF00Go4Y401?l6
S004o`280`Ko08<=1Ol0OQL6o`1j7`Ko07DW2?l0LBl:o`1/=A7o06Lk5ol0Hd0Fo`1W>a3o06`e4ol0
LBlCo`1e9`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00?ona<0
ooHV0?of9P000_of9P05oo8h00CokDX01?oXFP03onAZ00CoggX00ooKR004omJF00CodJ<00oo=/003
olRk00Co`L@00on]_`03oi^j00CoR;H01?mg/@03ofN]00CoEjP00om8X`04ocVO00Co;9X01?lNUP04
oa:A00Go1X`01?l0R0<5o`233@Go07hG1_l0NQl6o`1e9`So074_2?l0K3D=o`1W>bOo06=04_l0Ic/@
o`1/=ACo074_3_l0MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02oooo
o`GomRH01Oob>004one:00Coj5X00ooTJP03ommj00CofhP01?oFUP03om6S00?ocK001?o8^`04ol74
00;o[Kl01?nK^P04ohRf00?oMk400omW[@04oeNX00CoB:<00oliW`04obbJ00Co7YH01?lBT@05o`J<
00Co08P31Ol0P`d5o`1n5`Go07XO1_l0MBL7o`1a;`Wo06`e3?l0Ic/_o`1S@13o06Lk3ol0K3DEo`1a
;`_o07DW1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool4ooHV00Go
lSP01?o]BP04onQJ00?oi6X01?oONP04om^800?oeYH00ooAX`04olf`00?ob;/00oo1a004ojfo00?o
VkX00on8]P04ogNa00CoIjd00omGZ003odRS00Co>Il01?l/VP04oajF00Co4Y401?l6S005o`280`Co
08<=1Ol0OQL5o`1j7`Ko07DW1_l0LBl8o`1/=@co06Lk>?l0Hd0>o`1W>a3o06`e7?l0LBl5ooooo`7o
00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`ComRH01?ob>004one:00Coj5X0
1?oTJP04ommj00?ofhP00ooFUP04om6S00CocK000_o8^`04ol7400?o[Kl00onK^P04ohRf00CoMk40
0omW[@03oeNX00CoB:<01?liW`03obbJ00Co7YH01?lBT@04o`J<00Co08P31Ol0P`d5o`1n5`Go07XO
1_l0MBL6o`1a;`So06`e2Ol0Ic/@o`1S@1_o05i54ol0Hd0?o`1W>`ko06`e6ol0LBl5ooooo`7o0000
0Oooool1ooooo`005_ooool2o`0000?ooooo1?of9P04oo8h00CokDX01?oXFP03onAZ00CoggX00ooK
R004omJF00?odJ<00oo=/004olRk00?o`L@00on]_`04oi^j00?oR;H00omg/@04ofN]00?oEjP01?m8
X`03ocVO00Co;9X01?lNUP04oa:A00Co1X`01?l0R0<5o`233@Co07hG1Ol0NQl5o`1e9`Ko074_2?l0
K3D8o`1W>`go06=0:Ol0GTD@o`1S@0ko06Lk3_l0K3DHo`1a;`Cooooo0_l00002ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`ComRH01?ob>004one:00Coj5X00ooTJP03ommj00CofhP01?oFUP02
om6S00CocK001?o8^`02ol7400Co[Kl00onK^P03ohRf00CoMk400omW[@03oeNX00CoB:<01?liW`03
obbJ00Co7YH01?lBT@04o`J<00Co08P31Ol0P`d4o`1n5`Go07XO1Ol0MBL6o`1a;`Oo06`e2?l0Ic/<
o`1S@33o05i53ol0Hd0=o`1W>`ko06`e5_l0LBl5ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02ooooo`?omRH01?ob>004one:00Coj5X00ooTJP04ommj00?ofhP01?oFUP03om6S
00?ocK000oo8^`04ol7400?o[Kl00onK^P04ohRf00?oMk400omW[@04oeNX00?oB:<01?liW`03obbJ
00Co7YH01?lBT@04o`J<00Co08P31?l0P`d5o`1n5`Co07XO1_l0MBL6o`1a;`Ko06`e2?l0Ic/:o`1S
@1?o05i53ol0FTPFo`1NA@ko06=03?l0Ic/@o`1/=A;o074_1Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool3ooHV00ColSP01?o]BP03onQJ00Coi6X01?oONP03om^800?o
eYH01?oAX`03olf`00?ob;/01?o1a002ojfo00CoVkX00on8]P03ogNa00CoIjd00omGZ003odRS00Co
>Il01?l/VP03oajF00Co4Y401?l6S004o`280`Co08<=1Ol0OQL4o`1j7`Go07DW1_l0LBl6o`1/=@So
06Lk2Ol0Hd0=o`1NAB3o05Y84Ol0GTD=o`1S@0co06Lk3_l0K3DBo`1a;`Gooooo0Ol00001ooooo`7o
oooo000Fooooo`03o`000?oooooooooo00;ooooo0_of9P04oo8h00CokDX01?oXFP04onAZ00?oggX0
0ooKR004omJF00?odJ<00oo=/003olRk00?o`L@01?n]_`03oi^j00?oR;H01?mg/@03ofN]00?oEjP0
1?m8X`03ocVO00?o;9X01?lNUP04oa:A00Co1X`00ol0R0<5o`233@Co07hG1Ol0NQl4o`1e9`Ko074_
1_l0K3D6o`1W>`[o06=02ol0GTD[o`1JB0ko05i53_l0Hd0<o`1W>`ko06`e3_l0LBl5ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;omRH01?ob>004one:00Coj5X01?oT
JP02ommj00CofhP01?oFUP02om6S00CocK000oo8^`03ol7400Co[Kl00_nK^P04ohRf00?oMk400omW
[@04oeNX00?oB:<00oliW`04obbJ00?o7YH01?lBT@04o`J<00?o08P31Ol0P`d4o`1n5`Go07XO1?l0
MBL6o`1a;`Ko06`e1_l0Ic/8o`1S@0_o05i5<Ol0FTP>o`1NA@_o06=03?l0Ic/?o`1/=@go074_1Ooo
ool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2ooHV00ColSP01?o]BP03
onQJ00?oi6X01?oONP03om^800?oeYH01?oAX`03olf`00?ob;/00oo1a003ojfo00CoVkX00on8]P03
ogNa00?oIjd00omGZ004odRS00?o>Il01?l/VP03oajF00Co4Y401?l6S003o`280`Co08<=1Ol0OQL4
o`1j7`Go07DW1Ol0LBl5o`1/=@Ko06Lk2?l0Hd0:o`1NAA7o05Y85Ol0ED/Do`1JB0co05i53?l0Hd0<
o`1W>`ko06`e2_l0LBl5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02oooo
o`;omRH01?ob>004one:00;oj5X01?oTJP04ommj00?ofhP00ooFUP04om6S00;ocK001?o8^`03ol74
00?o[Kl00onK^P03ohRf00CoMk400_mW[@04oeNX00CoB:<00_liW`04obbJ00Co7YH00olBT@04o`J<
00?o08P31?l0P`d5o`1n5`Co07XO1Ol0MBL5o`1a;`Go06`e1_l0Ic/8o`1S@0So05i53Ol0FTPRo`1E
Ba3o05Y83?l0GTD;o`1S@0_o06Lk4?l0K3D8o`1a;`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03
o`000?oooooooooo00;ooooo00?omRH0oo8h0?ob>0000_ob>004one:00?oj5X01?oTJP03ommj00?o
fhP01?oFUP03om6S00?ocK000oo8^`03ol7400?o[Kl00onK^P04ohRf00?oMk400omW[@03oeNX00?o
B:<01?liW`03obbJ00?o7YH01?lBT@04o`J<00?o08P31?l0P`d4o`1n5`Go07XO1?l0MBL5o`1a;`Ko
06`e1_l0Ic/6o`1S@0So05i52ol0FTP[o`1EBa3o05Y82_l0GTD<o`1S@0co06Lk4?l0K3D4o`1a;`Go
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00ComRH0oo8h0?ob>03o
lSP01?o]BP04onQJ00Coi6X00_oONP04om^800CoeYH00_oAX`04olf`00;ob;/01?o1a003ojfo00?o
VkX00on8]P03ogNa00CoIjd00_mGZ004odRS00?o>Il00ol/VP04oajF00Co4Y400ol6S003o`280`Co
08<=1?l0OQL5o`1j7`Co07DW1Ol0LBl5o`1/=@Ko06Lk1_l0Hd08o`1NA@[o05Y8<_l0ED/=o`1JB0_o
05i52_l0Hd0<o`1W>a7o06`e0ol0LBl5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooo
ooooo`02ooooo`ColSP01?o]BP03onQJ00Coi6X00ooONP03om^800?oeYH01?oAX`03olf`00?ob;/0
0oo1a003ojfo00?oVkX00on8]P03ogNa00?oIjd01?mGZ003odRS00?o>Il01?l/VP03oajF00?o4Y40
1?l6S004o`280`?o08<=1?l0OQL4o`1j7`Go07DW1Ol0LBl4o`1/=@Ko06Lk1_l0Hd08o`1NA@So05Y8
3ol0ED/Io`1@CQ;o05E;3?l0FTP:o`1NA@co06=02_l0Ic/Bo`1/=@Gooooo0Ol00001ooooo`7ooooo
000Fooooo`03o`000?oooooooooo00;ooooo1?ob>004one:00?oj5X00ooTJP04ommj00?ofhP00ooF
UP04om6S00;ocK001?o8^`02ol7400Co[Kl00_nK^P04ohRf00?oMk400omW[@03oeNX00?oB:<01?li
W`03obbJ00?o7YH01?lBT@03o`J<00Co08P30ol0P`d4o`1n5`Co07XO1Ol0MBL5o`1a;`Co06`e1_l0
Ic/6o`1S@0Oo05i52?l0FTP<o`1EBb?o051>3ol0ED/<o`1JB0[o05i52_l0Hd0;o`1W>a7o06`e1Ooo
ool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool4oo8h00?okDX00ooXFP04
onAZ00?oggX00ooKR004omJF00?odJ<00oo=/003olRk00?o`L@00on]_`03oi^j00?oR;H00omg/@03
ofN]00?oEjP00om8X`04ocVO00?o;9X00olNUP04oa:A00?o1X`00ol0R0<4o`233@Co07hG1?l0NQl4
o`1e9`Co074_1_l0K3D4o`1W>`Ko06=02?l0GTD8o`1JB0[o05E;;?l0D4h>o`1EB`[o05Y82_l0GTD:
o`1S@0co06Lk3_l0K3D5ooooo`7o00000Oooool1ooooo`005_ooool2o`0000?ooooo0oob>003one:
00Coj5X00ooTJP03ommj00CofhP00ooFUP03om6S00?ocK000oo8^`03ol7400?o[Kl00onK^P03ohRf
00?oMk400omW[@03oeNX00?oB:<00oliW`04obbJ00?o7YH00olBT@04o`J<00?o08P31?l0P`d4o`1n
5`Co07XO1?l0MBL4o`1a;`Go06`e1Ol0Ic/6o`1S@0Ko05i51ol0FTP:o`1EBcCo051>3?l0ED/:o`1J
B0[o05i52_l0Hd0<o`1W>`co06`e1?ooool2o`0000;ooooo000Fooooo`03o`000?oooooooooo00;o
oooo0oob>003one:00Coj5X00ooTJP03ommj00CofhP00ooFUP03om6S00?ocK000oo8^`03ol7400?o
[Kl00onK^P03ohRf00?oMk400omW[@03oeNX00?oB:<00oliW`03obbJ00?o7YH01?lBT@03o`J<00Co
08P30ol0P`d4o`1n5`Co07XO1?l0MBL4o`1a;`Co06`e1_l0Ic/6o`1S@0Ko05i51_l0FTP:o`1EB`go
051>6ol0B4`@o`1@CPco05E;2_l0FTP:o`1NA@[o06=03?l0Ic/:o`1/=@Gooooo0Ol00001ooooo`7o
oooo000Fooooo`03o`000?oooooooooo00;ooooo0_ob>004one:00?oj5X00ooTJP04ommj00?ofhP0
0ooFUP03om6S00?ocK000oo8^`03ol7400?o[Kl00onK^P03ohRf00?oMk400omW[@03oeNX00?oB:<0
0oliW`03obbJ00?o7YH01?lBT@03o`J<00Co08P30ol0P`d4o`1n5`Co07XO1?l0MBL4o`1a;`Co06`e
1Ol0Ic/5o`1S@0Ko05i51ol0FTP8o`1EB`go051>9Ol0B4`>o`1@CP[o05E;2_l0FTP:o`1NA@[o06=0
2ol0Ic/9o`1/=@Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_ob
>004one:00?oj5X00ooTJP04ommj00?ofhP00ooFUP03om6S00?ocK000oo8^`03ol7400?o[Kl00onK
^P03ohRf00?oMk400omW[@03oeNX00?oB:<00oliW`03obbJ00?o7YH00olBT@04o`J<00?o08P30ol0
P`d4o`1n5`Co07XO1?l0MBL4o`1a;`Co06`e1_l0Ic/4o`1S@0Ko05i51_l0FTP8o`1EB`co051>;?l0
B4`<o`1@CP[o05E;2_l0FTP:o`1NA@Wo06=02ol0Ic/8o`1/=@Gooooo0Ol00001ooooo`7ooooo000F
ooooo`03o`000?oooooooooo00;ooooo0_ob>003one:00?oj5X01?oTJP03ommj00?ofhP00ooFUP03
om6S00?ocK000oo8^`03ol7400?o[Kl00onK^P03ohRf00?oMk400omW[@03oeNX00?oB:<00oliW`03
obbJ00?o7YH00olBT@04o`J<00?o08P30ol0P`d4o`1n5`Co07XO1?l0MBL4o`1a;`Co06`e1Ol0Ic/5
o`1S@0Go05i51ol0FTP7o`1EB`[o051>5Ol0B4`7o`0nAaKo04Q<3?l0D4h:o`1EB`[o05Y82?l0GTD:
o`1S@0co06Lk1_l0K3D5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02oooo
o`;olSP00oo]BP03onQJ00Coi6X00ooONP03om^800?oeYH00ooAX`03olf`00?ob;/00oo1a003ojfo
00?oVkX00on8]P02ogNa00?oIjd00omGZ003odRS00?o>Il00ol/VP04oajF00?o4Y400ol6S004o`28
0`?o08<=0ol0OQL4o`1j7`Co07DW1?l0LBl4o`1/=@Co06Lk1_l0Hd06o`1NA@Ko05Y81_l0ED/:o`1@
CPgo04Q<6ol0?TL@o`18C0[o051>2_l0ED/:o`1JB0So05i52_l0Hd0<o`1W>`Co06`e1Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool01?ob>03okDX0one:0?o]BP04onQJ
00?oi6X00ooONP03om^800?oeYH00ooAX`03olf`00?ob;/00oo1a003ojfo00?oVkX00on8]P03ogNa
00;oIjd00omGZ003odRS00?o>Il00ol/VP04oajF00?o4Y400ol6S003o`280`Co08<=0ol0OQL4o`1j
7`Co07DW1?l0LBl4o`1/=@Co06Lk1Ol0Hd05o`1NA@Ko05Y81ol0ED/8o`1@CP_o04Q<9Ol0?TL>o`18
C0[o051>2_l0ED/8o`1JB0[o05i52Ol0Hd0=o`1W>`;o06`e1Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool01?ob>03okDX0one:0?o]BP04onQJ00?oi6X00ooONP03om^8
00?oeYH00ooAX`03olf`00?ob;/00oo1a003ojfo00?oVkX00_n8]P03ogNa00?oIjd00omGZ003odRS
00?o>Il00ol/VP03oajF00Co4Y400ol6S003o`280`Co08<=0ol0OQL3o`1j7`Co07DW1?l0LBl4o`1/
=@Co06Lk1_l0Hd04o`1NA@Ko05Y81_l0ED/8o`1@CP[o04Q<;?l0?TL<o`18C0[o051>2_l0ED/8o`1J
B0Wo05i52Ol0Hd0=o`1W>`03o`1/=Ooooooooooo00?ooooo0Ol00001ooooo`7ooooo000Fooooo`03
o`000?oooooooooo00;ooooo1?o]BP03onQJ00?oi6X00ooONP03om^800?oeYH00ooAX`03olf`00?o
b;/00oo1a003ojfo00?oVkX00on8]P02ogNa00?oIjd00omGZ003odRS00?o>Il00ol/VP03oajF00?o
4Y401?l6S003o`280`?o08<=1?l0OQL3o`1j7`Co07DW1?l0LBl4o`1/=@Co06Lk1Ol0Hd05o`1NA@Go
05Y81_l0ED/8o`1@CPWo04Q<<ol0?TL:o`18C0[o051>2Ol0ED/9o`1JB0So05i52_l0Hd0<o`1W>`Go
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo1?o]BP03onQJ00?oi6X0
0ooONP03om^800?oeYH00ooAX`03olf`00?ob;/00oo1a003ojfo00;oVkX01?n8]P02ogNa00?oIjd0
0omGZ003odRS00?o>Il00ol/VP03oajF00?o4Y400ol6S003o`280`Co08<=0ol0OQL4o`1j7`?o07DW
1?l0LBl4o`1/=@Co06Lk1?l0Hd06o`1NA@Co05Y81_l0ED/8o`1@CPSo04Q<3ol0?TLIo`0e@a3o03i7
2_l0B4`:o`1@CPSo05E;2Ol0FTP9o`1NA@Wo06=02ol0Ic/5ooooo`7o00000Oooool1ooooo`003_oo
ool3o`0000Gooooo00?o0000ooooooooool00_ooool3one:00?oj5X00ooTJP03ommj00CofhP00_oF
UP03om6S00?ocK000oo8^`03ol7400?o[Kl00onK^P03ohRf00;oMk400omW[@03oeNX00?oB:<00oli
W`03obbJ00?o7YH00olBT@03o`J<00?o08P31?l0P`d3o`1n5`Co07XO0ol0MBL4o`1a;`Co06`e1?l0
Ic/4o`1S@0Go05i51Ol0FTP6o`1EB`Oo051>2?l0B4`;o`0nAb?o03E33_l0?TL:o`18C0[o051>2?l0
ED/8o`1JB0So05i52_l0Hd0:o`1W>`Gooooo0Ol00001ooooo`7ooooo000=ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`02ooooo`?okDX00ooXFP03onAZ00?oggX01?oK
R002omJF00?odJ<00oo=/003olRk00?o`L@00on]_`03oi^j00;oR;H00omg/@03ofN]00?oEjP00om8
X`03ocVO00?o;9X00olNUP03oa:A00?o1X`00ol0R0<3o`233@Co07hG0ol0NQl4o`1e9`?o074_1?l0
K3D4o`1W>`Co06=01_l0GTD4o`1JB0Ko05E;1_l0D4h8o`18C0co03i7:?l0=D<<o`0nA`[o04Q<2_l0
D4h8o`1EB`So05Y82?l0GTD:o`1S@0So06Lk1Oooool1o`00007ooooo0Oooool000Oooooo1Ol00005
ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`;okDX01?oXFP03onAZ00?oggX00ooKR003
omJF00?odJ<00_o=/003olRk00?o`L@00on]_`03oi^j00?oR;H00_mg/@03ofN]00?oEjP00om8X`03
ocVO00?o;9X00olNUP03oa:A00?o1X`00ol0R0<3o`233@Co07hG0ol0NQl4o`1e9`?o074_1?l0K3D4
o`1W>`Co06=01Ol0GTD5o`1JB0Go05E;1ol0D4h7o`18C0[o03i7<?l0=D<;o`0nA`Wo04Q<2?l0D4h8
o`1EB`So05Y82Ol0GTD9o`1S@0So06Lk0oooool3o`0000;ooooo000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool2one:00Coj5X00_oTJP04ommj00?ofhP00ooFUP02om6S
00?ocK000oo8^`03ol7400?o[Kl00onK^P03ohRf00;oMk400omW[@03oeNX00?oB:<00oliW`03obbJ
00?o7YH00olBT@03o`J<00?o08P30ol0P`d3o`1n5`Co07XO0ol0MBL4o`1a;`?o06`e1?l0Ic/4o`1S
@0Go05i51Ol0FTP6o`1EB`Ko051>1_l0B4`:o`0nA`go03E35ol0;Ch@o`0e@`[o03i72_l0B4`8o`1@
CPSo05E;2?l0FTP8o`1NA@[o06=01_l0Ic/5ooooo`7o00000Oooool1ooooo`003Oooool4o`0000Go
oooo00?o0000ooooooooool00_ooool2one:00?oj5X00ooTJP03ommj00?ofhP00ooFUP03om6S00?o
cK000oo8^`02ol7400?o[Kl00onK^P03ohRf00;oMk400omW[@03oeNX00?oB:<00oliW`03obbJ00?o
7YH00olBT@03o`J<00?o08P30ol0P`d3o`1n5`Co07XO0ol0MBL4o`1a;`?o06`e1?l0Ic/4o`1S@0Go
05i51Ol0FTP5o`1EB`Ko051>1_l0B4`8o`0nA`go03E37ol0;Ch>o`0e@`[o03i72Ol0B4`8o`1@CPSo
05E;2?l0FTP8o`1NA@[o06=01Ol0Ic/5ooooo`7o00000Oooool1ooooo`003Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo0_o]BP03onQJ00?oi6X00ooONP03om^800?oeYH0
0ooAX`02olf`00Cob;/00_o1a003ojfo00?oVkX00on8]P02ogNa00?oIjd00omGZ003odRS00?o>Il0
0ol/VP02oajF00?o4Y401?l6S003o`280`?o08<=0ol0OQL3o`1j7`Co07DW0ol0LBl4o`1/=@Co06Lk
1?l0Hd04o`1NA@Go05Y81?l0ED/6o`1@CPKo04Q<2?l0?TL<o`0e@bKo02dn3?l0=D<:o`0nA`So04Q<
2?l0D4h8o`1EB`So05Y82?l0GTD:o`1S@0Co06Lk1Oooool1o`00007ooooo0Oooool000gooooo1Ol0
0004ooooo`03o`000?oooooooooo00;ooooo00CokDX0onQJ0?oXFP3oj5X00ooTJP03ommj00?ofhP0
0ooFUP03om6S00?ocK000oo8^`02ol7400?o[Kl00onK^P03ohRf00?oMk400_mW[@03oeNX00?oB:<0
0oliW`03obbJ00?o7YH00_lBT@03o`J<00Co08P30ol0P`d3o`1n5`?o07XO1?l0MBL3o`1a;`Co06`e
1?l0Ic/4o`1S@0Co05i51?l0FTP5o`1EB`Ko051>1_l0B4`7o`0nA`[o03E3;_l0;Ch:o`0e@`[o03i7
2?l0B4`8o`1@CPOo05E;2?l0FTP8o`1NA@[o06=00ol0Ic/5ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`04one:0?oXFP3oj5X0onQJ00?oi6X00ooONP03om^800?oeYH0
0ooAX`03olf`00?ob;/00_o1a003ojfo00?oVkX00on8]P02ogNa00?oIjd00omGZ003odRS00?o>Il0
0_l/VP03oajF00?o4Y400ol6S003o`280`?o08<=1?l0OQL3o`1j7`?o07DW1?l0LBl3o`1/=@Co06Lk
1?l0Hd04o`1NA@Go05Y81?l0ED/6o`1@CPKo04Q<1_l0?TL:o`0e@a7o02dn3Ol09CTDo`0]?P[o03E3
2_l0?TL8o`18C0Oo051>1ol0ED/8o`1JB0So05i52_l0Hd02o`1W>`Gooooo0Ol00001ooooo`7ooooo
000Fooooo`03o`000?oooooooooo00;ooooo00CokDX0onQJ0?oXFP3oj5X00ooTJP03ommj00?ofhP0
0ooFUP02om6S00?ocK000oo8^`03ol7400;o[Kl00onK^P03ohRf00?oMk400_mW[@03oeNX00?oB:<0
0oliW`03obbJ00;o7YH00olBT@03o`J<00?o08P30ol0P`d4o`1n5`?o07XO0ol0MBL4o`1a;`?o06`e
1?l0Ic/4o`1S@0Co05i51?l0FTP5o`1EB`Go051>1_l0B4`7o`0nA`Wo03E33Ol0;ChKo`0U>@ko02dn
2_l0=D<9o`0nA`So04Q<1ol0D4h7o`1EB`So05Y82?l0GTD:o`1S@003o`1W>ooooooooooo00?ooooo
0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo1?oXFP03onAZ00?oggX00_oK
R004omJF00;odJ<00oo=/003olRk00?o`L@00_n]_`03oi^j00?oR;H00omg/@02ofN]00?oEjP00om8
X`03ocVO00?o;9X00_lNUP03oa:A00?o1X`00ol0R0<3o`233@?o07hG1?l0NQl3o`1e9`?o074_1?l0
K3D4o`1W>`Co06=01?l0GTD4o`1JB0Co05E;1_l0D4h4o`18C0So03i72?l0=D<;o`0]?R?o02Di3?l0
;Ch:o`0e@`So03i72?l0B4`7o`1@CPOo05E;2?l0FTP8o`1NA@[o06=01Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool3onQJ00?oi6X00ooONP03om^800?oeYH00ooAX`02
olf`00?ob;/00oo1a003ojfo00;oVkX00on8]P03ogNa00?oIjd00_mGZ003odRS00?o>Il00ol/VP02
oajF00?o4Y400ol6S003o`280`?o08<=0ol0OQL4o`1j7`?o07DW0ol0LBl4o`1/=@?o06Lk1?l0Hd04
o`1NA@Co05Y81Ol0ED/5o`1@CPGo04Q<1ol0?TL7o`0e@`_o02dn:?l09CT<o`0]?P[o03E32?l0?TL7
o`18C0Oo051>1ol0ED/8o`1JB0So05i52Ol0Hd05ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02ooooo`?oj5X00ooTJP03ommj00?ofhP00ooFUP03om6S00;ocK000oo8^`03ol74
00?o[Kl00_nK^P03ohRf00?oMk400omW[@02oeNX00?oB:<00oliW`02obbJ00?o7YH00olBT@03o`J<
00?o08P30ol0P`d3o`1n5`?o07XO1?l0MBL3o`1a;`?o06`e1?l0Ic/4o`1S@0Co05i51?l0FTP4o`1E
B`Go051>1Ol0B4`6o`0nA`So03E32_l0;Ch^o`0U>@[o02dn2_l0=D<7o`0nA`Oo04Q<2?l0D4h6o`1E
B`So05Y82?l0GTD8o`1S@0Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;o
oooo0ooXFP03onAZ00?oggX00_oKR003omJF00?odJ<00oo=/003olRk00;o`L@00on]_`03oi^j00;o
R;H00omg/@03ofN]00;oEjP00om8X`03ocVO00?o;9X00_lNUP03oa:A00?o1X`00ol0R0<3o`233@?o
07hG0ol0NQl4o`1e9`?o074_0ol0K3D4o`1W>`Co06=00ol0GTD5o`1JB0Co05E;1Ol0D4h5o`18C0Ko
03i71ol0=D<9o`0]?Pko02Di4ol07SDBo`0U>@[o02dn2?l0=D<8o`0nA`Oo04Q<1ol0D4h7o`1EB`So
05Y82?l0GTD7o`1S@0Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo
0_oXFP04onAZ00;oggX00ooKR003omJF00?odJ<00oo=/002olRk00?o`L@00on]_`02oi^j00?oR;H0
0omg/@03ofN]00;oEjP00om8X`03ocVO00?o;9X00_lNUP03oa:A00?o1X`00ol0R0<3o`233@?o07hG
0ol0NQl3o`1e9`Co074_0ol0K3D3o`1W>`Co06=01?l0GTD4o`1JB0Co05E;1Ol0D4h5o`18C0Ko03i7
1_l0=D<8o`0]?Pgo02Di7Ol07SD>o`0U>@[o02dn2?l0=D<8o`0nA`Ko04Q<1ol0D4h7o`1EB`So05Y8
2?l0GTD6o`1S@0Gooooo0Ol00001ooooo`7ooooo000Fooooo`;o00000oooool2onQJ00?oi6X00ooO
NP03om^800?oeYH00_oAX`03olf`00?ob;/00oo1a002ojfo00?oVkX00on8]P02ogNa00?oIjd00omG
Z002odRS00?o>Il00ol/VP03oajF00;o4Y400ol6S003o`280`?o08<=0ol0OQL3o`1j7`?o07DW1?l0
LBl3o`1/=@?o06Lk1?l0Hd04o`1NA@Co05Y81?l0ED/5o`1@CPGo04Q<1Ol0?TL7o`0e@`So02dn2ol0
9CTTo`0N=@co02Di2Ol0;Ch8o`0e@`Oo03i71ol0B4`7o`1@CPOo05E;1ol0FTP9o`1NA@Go06=01?oo
ool2o`0000;ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_oXFP03onAZ00?oggX00ooKR003
omJF00;odJ<00oo=/003olRk00;o`L@00on]_`03oi^j00;oR;H00omg/@03ofN]00;oEjP00om8X`03
ocVO00?o;9X00olNUP02oa:A00?o1X`00ol0R0<3o`233@?o07hG0ol0NQl3o`1e9`?o074_1?l0K3D3
o`1W>`Co06=00ol0GTD4o`1JB0Go05E;1?l0D4h5o`18C0Ko03i71_l0=D<8o`0]?P[o02Di:?l07SD<
o`0U>@So02dn2?l0=D<8o`0nA`Ko04Q<1ol0D4h7o`1EB`Oo05Y82Ol0GTD4o`1S@0Gooooo0Ol00001
ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_oXFP02onAZ00?oggX00ooKR003omJF
00?odJ<00_o=/003olRk00?o`L@00on]_`02oi^j00?oR;H00_mg/@03ofN]00?oEjP00_m8X`03ocVO
00?o;9X00olNUP02oa:A00?o1X`00ol0R0<3o`233@?o07hG0ol0NQl3o`1e9`?o074_1?l0K3D3o`1W
>`Co06=00ol0GTD4o`1JB0Go05E;1?l0D4h5o`18C0Go03i71_l0=D<7o`0]?P[o02Di;Ol07SD;o`0U
>@Wo02dn1ol0=D<7o`0nA`Oo04Q<1ol0D4h7o`1EB`Oo05Y82?l0GTD4o`1S@0Gooooo0Ol00001oooo
o`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_oXFP02onAZ00?oggX00ooKR003omJF00?o
dJ<00_o=/003olRk00?o`L@00_n]_`03oi^j00?oR;H00_mg/@03ofN]00?oEjP00_m8X`03ocVO00?o
;9X00olNUP02oa:A00?o1X`00ol0R0<3o`233@?o07hG0ol0NQl3o`1e9`?o074_1?l0K3D3o`1W>`Co
06=00ol0GTD4o`1JB0Co05E;1Ol0D4h4o`18C0Ko03i71_l0=D<6o`0]?PSo02Di4Ol07SDAo`0G<13o
01he2_l09CT9o`0]?POo03E32?l0?TL6o`18C0Oo051>1ol0ED/7o`1JB0So05i50ol0Hd05ooooo`7o
00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04onQJ0?oTJP3oi6X0onAZ00?o
ggX00ooKR002omJF00?odJ<00oo=/003olRk00;o`L@00on]_`02oi^j00?oR;H00omg/@02ofN]00?o
EjP00om8X`02ocVO00?o;9X00olNUP03oa:A00;o1X`00ol0R0<3o`233@?o07hG0ol0NQl3o`1e9`?o
074_1?l0K3D3o`1W>`?o06=01?l0GTD4o`1JB0Co05E;1?l0D4h5o`18C0Go03i71_l0=D<6o`0]?PWo
02Di3?l07SDKo`0G<0ko01he2_l09CT8o`0]?POo03E31ol0?TL7o`18C0Ko051>1ol0ED/8o`1JB0So
05i50_l0Hd05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04onQJ
0?oTJP3oi6X0onAZ00?oggX00ooKR002omJF00?odJ<00oo=/002olRk00?o`L@00on]_`02oi^j00?o
R;H00omg/@02ofN]00?oEjP00om8X`02ocVO00?o;9X00olNUP02oa:A00?o1X`00ol0R0<3o`233@?o
07hG0ol0NQl3o`1e9`?o074_0ol0K3D4o`1W>`?o06=01?l0GTD4o`1JB0Co05E;1?l0D4h4o`18C0Ko
03i71Ol0=D<7o`0]?PSo02Di2_l07SDRo`0G<0co01he2_l09CT8o`0]?PKo03E31ol0?TL7o`18C0Ko
051>1ol0ED/7o`1JB0Wo05i500?o06=0ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool00_ooool00ooXFP3oi6X0onAZ0003ommj00?ofhP00ooFUP03om6S00;ocK00
0oo8^`03ol7400;o[Kl00onK^P02ohRf00?oMk400omW[@02oeNX00?oB:<00oliW`02obbJ00?o7YH0
0olBT@03o`J<00;o08P30ol0P`d3o`1n5`?o07XO0ol0MBL3o`1a;`?o06`e1?l0Ic/3o`1S@0Co05i5
0ol0FTP4o`1EB`Go051>1?l0B4`5o`0nA`Ko03E31_l0;Ch7o`0U>@_o01he9_l05c0<o`0N=@So02Di
2?l0;Ch7o`0e@`Oo03i71_l0B4`7o`1@CPOo05E;1ol0FTP8o`1NA@03o`1S@?oooooooooo00?ooooo
0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0ooTJP03ommj00?ofhP00ooF
UP02om6S00?ocK000oo8^`02ol7400?o[Kl00onK^P02ohRf00?oMk400omW[@02oeNX00?oB:<00oli
W`02obbJ00?o7YH00olBT@02o`J<00?o08P30ol0P`d3o`1n5`?o07XO0ol0MBL3o`1a;`?o06`e1?l0
Ic/3o`1S@0Co05i50ol0FTP4o`1EB`Co051>1Ol0B4`5o`0nA`Co03E31_l0;Ch8o`0U>@[o01he:_l0
5c0<o`0N=@So02Di2?l0;Ch6o`0e@`Oo03i71_l0B4`7o`1@CPOo05E;1ol0FTP8o`1NA@Gooooo0Ol0
0001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0ooTJP03ommj00?ofhP00_oFUP03
om6S00?ocK000_o8^`03ol7400?o[Kl00_nK^P03ohRf00;oMk400omW[@03oeNX00;oB:<00oliW`03
obbJ00;o7YH00olBT@03o`J<00;o08P30ol0P`d3o`1n5`?o07XO0ol0MBL3o`1a;`?o06`e1?l0Ic/3
o`1S@0Co05i50ol0FTP4o`1EB`Co051>1Ol0B4`4o`0nA`Go03E31_l0;Ch7o`0U>@[o01he4ol05c07
o`0B;1Co01L`2ol07SD8o`0U>@Oo02dn1ol0=D<7o`0nA`Ko04Q<1_l0D4h7o`1EB`Oo05Y82?l0GTD5
ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`?oi6X00ooONP02om^8
00?oeYH00ooAX`03olf`00;ob;/00oo1a003ojfo00;oVkX00on8]P02ogNa00?oIjd00omGZ002odRS
00?o>Il00ol/VP02oajF00?o4Y400ol6S002o`280`?o08<=0ol0OQL3o`1j7`?o07DW0ol0LBl3o`1/
=@Co06Lk0ol0Hd03o`1NA@Co05Y81?l0ED/4o`1@CPCo04Q<1Ol0?TL5o`0e@`Go02dn2?l09CT8o`0N
=@go01L`5Ol04R`@o`0G<0[o01he2?l09CT8o`0]?PKo03E31ol0?TL6o`18C0Ko051>1ol0ED/7o`1J
B0Oo05i51Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool3onAZ00;o
ggX00ooKR003omJF00?odJ<00_o=/003olRk00;o`L@00on]_`03oi^j00;oR;H00omg/@02ofN]00?o
EjP00om8X`02ocVO00?o;9X00olNUP02oa:A00?o1X`00ol0R0<2o`233@?o07hG0ol0NQl3o`1e9`?o
074_0ol0K3D4o`1W>`?o06=00ol0GTD4o`1JB0Co05E;1?l0D4h4o`18C0Go03i71Ol0=D<5o`0]?POo
02Di2?l07SD;o`0G<1go018/3_l05c09o`0N=@So02Di1ol0;Ch7o`0e@`Ko03i71_l0B4`7o`1@CPKo
05E;2?l0FTP6o`1NA@Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo
0_oTJP03ommj00?ofhP00ooFUP03om6S00;ocK000oo8^`02ol7400?o[Kl00onK^P02ohRf00?oMk40
0_mW[@03oeNX00?oB:<00_liW`03obbJ00?o7YH00_lBT@03o`J<00?o08P30_l0P`d3o`1n5`?o07XO
0ol0MBL3o`1a;`?o06`e1?l0Ic/3o`1S@0?o05i51?l0FTP4o`1EB`Co051>1?l0B4`4o`0nA`Go03E3
1Ol0;Ch7o`0U>@Oo01he3?l05c0Ro`0B;0co01L`2?l07SD8o`0U>@Oo02dn1ol0=D<6o`0nA`Ko04Q<
1ol0D4h6o`1EB`Oo05Y81_l0GTD5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`;oi6X00ooONP03om^800;oeYH00ooAX`03olf`00;ob;/00oo1a003ojfo00;oVkX00on8
]P02ogNa00?oIjd00_mGZ003odRS00?o>Il00_l/VP03oajF00;o4Y400ol6S003o`280`?o08<=0ol0
OQL2o`1j7`?o07DW0ol0LBl3o`1/=@Co06Lk0ol0Hd03o`1NA@Co05Y81?l0ED/3o`1@CPGo04Q<1?l0
?TL5o`0e@`Go02dn1ol09CT7o`0N=@_o01L`9_l04R`;o`0G<0Wo01he1ol09CT7o`0]?PKo03E31_l0
?TL7o`18C0Ko051>1ol0ED/6o`1JB0Ko05i51Oooool1o`00007ooooo0Oooool001Kooooo0_l00003
ooooo`;oi6X00ooONP03om^800;oeYH00ooAX`03olf`00;ob;/00oo1a003ojfo00;oVkX00on8]P02
ogNa00?oIjd00_mGZ003odRS00?o>Il00_l/VP03oajF00;o4Y400ol6S003o`280`?o08<=0ol0OQL2
o`1j7`?o07DW0ol0LBl3o`1/=@Co06Lk0ol0Hd03o`1NA@Co05Y80ol0ED/4o`1@CPCo04Q<1Ol0?TL5
o`0e@`Go02dn1Ol09CT8o`0N=@[o01L`:_l04R`:o`0G<0Wo01he1ol09CT7o`0]?PKo03E31_l0?TL7
o`18C0Ko051>1_l0ED/7o`1JB0Go05i51?ooool2o`0000;ooooo000Fooooo`03o`000?oooooooooo
00;ooooo0_oTJP03ommj00;ofhP00ooFUP03om6S00;ocK000oo8^`02ol7400?o[Kl00onK^P02ohRf
00?oMk400_mW[@03oeNX00;oB:<00oliW`03obbJ00;o7YH00olBT@02o`J<00?o08P30ol0P`d3o`1n
5`?o07XO0ol0MBL2o`1a;`Co06`e0ol0Ic/3o`1S@0?o05i51?l0FTP3o`1EB`Co051>1?l0B4`5o`0n
A`Co03E31_l0;Ch5o`0U>@So01he2Ol05c0^o`0B;0Wo01L`2?l07SD8o`0U>@Ko02dn1ol0=D<6o`0n
A`Ko04Q<1_l0D4h6o`1EB`So05Y81?l0GTD5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`;oi6X00_oONP03om^800?oeYH00ooAX`02olf`00?ob;/00_o1a003ojfo00?o
VkX00_n8]P03ogNa00;oIjd00omGZ002odRS00?o>Il00ol/VP02oajF00?o4Y400_l6S003o`280`?o
08<=0ol0OQL3o`1j7`?o07DW0_l0LBl4o`1/=@?o06Lk0ol0Hd03o`1NA@Co05Y80ol0ED/4o`1@CPCo
04Q<1Ol0?TL4o`0e@`Go02dn1_l09CT7o`0N=@So01L`3ol04R`Ao`0=9a7o018/2Ol05c08o`0N=@So
02Di1_l0;Ch7o`0e@`Ko03i71_l0B4`6o`1@CPKo05E;2?l0FTP3o`1NA@Gooooo0Ol00001ooooo`7o
oooo000Fooooo`03o`000?oooooooooo00;ooooo00Coi6X0ommj0?oONP3oggX00ooKR003omJF00;o
dJ<00oo=/002olRk00?o`L@00on]_`02oi^j00?oR;H00_mg/@03ofN]00;oEjP00om8X`02ocVO00?o
;9X00olNUP02oa:A00?o1X`00ol0R0<2o`233@?o07hG0ol0NQl3o`1e9`?o074_0ol0K3D3o`1W>`?o
06=00ol0GTD4o`1JB0?o05E;1?l0D4h4o`18C0Co03i71Ol0=D<5o`0]?PKo02Di1_l07SD9o`0G<0co
018/6Ol03BL>o`0B;0[o01L`1ol07SD7o`0U>@Oo02dn1_l0=D<6o`0nA`Ko04Q<1_l0D4h7o`1EB`Oo
05Y80ol0GTD5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04onAZ
0?oONP3oggX0ommj00?ofhP00ooFUP02om6S00?ocK000_o8^`03ol7400;o[Kl00onK^P03ohRf00;o
Mk400omW[@02oeNX00?oB:<00_liW`03obbJ00?o7YH00_lBT@03o`J<00?o08P30_l0P`d3o`1n5`?o
07XO0ol0MBL3o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i51?l0FTP3o`1EB`Co051>1?l0B4`4o`0nA`Go
03E31Ol0;Ch5o`0U>@Oo01he2?l05c0;o`0B;1go00dW3_l04R`9o`0G<0Oo01he1ol09CT7o`0]?PKo
03E31_l0?TL6o`18C0Ko051>1_l0ED/8o`1JB0;o05i51Oooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool00_ooool01?oTJP3oggX0ommj0?oONP02om^800?oeYH00ooAX`02olf`00?o
b;/00oo1a002ojfo00?oVkX00_n8]P03ogNa00;oIjd00omGZ002odRS00?o>Il00_l/VP03oajF00?o
4Y400_l6S003o`280`?o08<=0_l0OQL3o`1j7`?o07DW0ol0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@Co
05Y80ol0ED/4o`1@CPCo04Q<1?l0?TL5o`0e@`Go02dn1Ol09CT6o`0N=@So01L`2ol04R`Ro`0=9`co
018/2Ol05c07o`0N=@Oo02Di1_l0;Ch6o`0e@`Ko03i71_l0B4`6o`1@CPKo05E;2?l0FTP2o`1NA@Go
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00Coi6X0ommj0?oONP3o
ggX00_oKR003omJF00?odJ<00_o=/003olRk00?o`L@00_n]_`03oi^j00;oR;H00omg/@02ofN]00?o
EjP00_m8X`03ocVO00;o;9X00olNUP03oa:A00;o1X`00ol0R0<3o`233@;o07hG0ol0NQl3o`1e9`?o
074_0ol0K3D3o`1W>`?o06=00ol0GTD4o`1JB0?o05E;1?l0D4h4o`18C0Co03i71Ol0=D<4o`0]?PKo
02Di1_l07SD7o`0G<0_o018/9?l03BL<o`0B;0Wo01L`1ol07SD7o`0U>@Ko02dn1_l0=D<6o`0nA`Ko
04Q<1_l0D4h6o`1EB`So05Y800?o05i5ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool00_ooool00ooTJP3oggX0ommj0003om^800?oeYH00_oAX`03olf`00?ob;/0
0_o1a003ojfo00;oVkX00on8]P02ogNa00?oIjd00_mGZ003odRS00;o>Il00ol/VP02oajF00?o4Y40
0ol6S002o`280`?o08<=0ol0OQL3o`1j7`;o07DW0ol0LBl3o`1/=@?o06Lk0ol0Hd04o`1NA@?o05Y8
0ol0ED/4o`1@CPCo04Q<1?l0?TL4o`0e@`Go02dn1Ol09CT6o`0N=@So01L`2_l04R`Xo`0=9`_o018/
2?l05c07o`0N=@Oo02Di1_l0;Ch6o`0e@`Ko03i71_l0B4`6o`1@CPOo05E;1ol0FTP00ol0GTGooooo
ooooo`03ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`03onAZ0?oO
NP3oggX000?ofhP00ooFUP02om6S00?ocK000oo8^`02ol7400?o[Kl00_nK^P03ohRf00;oMk400omW
[@02oeNX00?oB:<00_liW`03obbJ00;o7YH00olBT@03o`J<00;o08P30ol0P`d3o`1n5`?o07XO0_l0
MBL3o`1a;`?o06`e0ol0Ic/3o`1S@0Co05i50ol0FTP3o`1EB`Co051>1?l0B4`4o`0nA`Co03E31Ol0
;Ch5o`0U>@Ko01he1ol05c09o`0B;2co00dW2_l04R`8o`0G<0Oo01he1ol09CT6o`0]?PKo03E31_l0
?TL6o`18C0Ko051>1_l0ED/7o`1JB003o`1NAOoooooooooo00?ooooo0Ol00001ooooo`7ooooo000F
ooooo`03o`000?oooooooooo00;ooooo0ooONP03om^800;oeYH00ooAX`03olf`00;ob;/00oo1a002
ojfo00?oVkX00_n8]P03ogNa00;oIjd00omGZ002odRS00?o>Il00_l/VP03oajF00?o4Y400_l6S003
o`280`;o08<=0ol0OQL3o`1j7`?o07DW0ol0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y81?l0ED/3
o`1@CPCo04Q<1?l0?TL4o`0e@`Go02dn1Ol09CT6o`0N=@Oo01L`2Ol04R`@o`0=9`go00PR4Ol03BL:
o`0B;0So01L`1ol07SD6o`0U>@Ko02dn1_l0=D<6o`0nA`Ko04Q<1_l0D4h6o`1EB`So05Y81Oooool1
o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool3ommj00?ofhP00_oFUP03om6S
00?ocK000_o8^`03ol7400;o[Kl00onK^P02ohRf00?oMk400_mW[@03oeNX00;oB:<00oliW`02obbJ
00?o7YH00olBT@02o`J<00?o08P30_l0P`d3o`1n5`?o07XO0ol0MBL3o`1a;`?o06`e0ol0Ic/3o`1S
@0?o05i50ol0FTP4o`1EB`?o051>1?l0B4`4o`0nA`Co03E31Ol0;Ch5o`0U>@Go01he1ol05c09o`0B
;0go00dW5Ol0228>o`0=9`[o018/2?l05c07o`0N=@Ko02Di1_l0;Ch6o`0e@`Ko03i71_l0B4`6o`1@
CPKo05E;1ol0FTP5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`?o
ggX00_oKR003omJF00?odJ<00_o=/003olRk00;o`L@00on]_`02oi^j00?oR;H00_mg/@03ofN]00;o
EjP00om8X`02ocVO00?o;9X00_lNUP03oa:A00?o1X`00_l0R0<3o`233@?o07hG0_l0NQl3o`1e9`?o
074_0ol0K3D3o`1W>`?o06=00ol0GTD3o`1JB0Co05E;0ol0D4h4o`18C0Co03i71?l0=D<5o`0]?PGo
02Di1Ol07SD7o`0G<0So018/3Ol03BLIo`088Pko00dW2Ol04R`7o`0G<0Oo01he1_l09CT6o`0]?PKo
03E31_l0?TL6o`18C0Ko051>1_l0ED/7o`1JB0Gooooo0Ol00001ooooo`7ooooo000Fooooo`;o0000
0oooool3ommj00;ofhP00ooFUP03om6S00;ocK000oo8^`02ol7400?o[Kl00_nK^P03ohRf00;oMk40
0omW[@02oeNX00?oB:<00_liW`03obbJ00;o7YH00olBT@03o`J<00;o08P30ol0P`d3o`1n5`;o07XO
0ol0MBL3o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i50ol0FTP4o`1EB`?o051>1?l0B4`4o`0nA`Co03E3
1Ol0;Ch5o`0U>@Go01he1ol05c08o`0B;0_o00dW7Ol0228=o`0=9`Wo018/1ol05c07o`0N=@Ko02Di
1_l0;Ch6o`0e@`Ko03i71Ol0B4`6o`1@CPOo05E;1_l0FTP4ooooo`;o00000_ooool001Kooooo00?o
0000ooooooooool00_ooool2ommj00?ofhP00ooFUP02om6S00?ocK000_o8^`03ol7400?o[Kl00_nK
^P02ohRf00?oMk400_mW[@03oeNX00;oB:<00oliW`02obbJ00?o7YH00olBT@02o`J<00?o08P30_l0
P`d3o`1n5`?o07XO0ol0MBL2o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i51?l0FTP3o`1EB`Co051>0ol0
B4`4o`0nA`Co03E31Ol0;Ch5o`0U>@Go01he1_l05c08o`0B;0co00dW8?l0228;o`0=9`Wo018/1ol0
5c07o`0N=@Ko02Di1_l0;Ch6o`0e@`Ko03i71_l0B4`6o`1@CPKo05E;1_l0FTP5ooooo`7o00000Ooo
ool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;oggX00ooKR003omJF00;odJ<00oo=/002
olRk00?o`L@00on]_`02oi^j00;oR;H00omg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00olNUP03
oa:A00;o1X`00ol0R0<2o`233@?o07hG0ol0NQl3o`1e9`;o074_0ol0K3D3o`1W>`?o06=00ol0GTD4
o`1JB0?o05E;1?l0D4h3o`18C0Co03i71?l0=D<5o`0]?PGo02Di1Ol07SD6o`0G<0So018/2_l03BLS
o`088P_o00dW2Ol04R`7o`0G<0Oo01he1_l09CT6o`0]?PKo03E31Ol0?TL6o`18C0Ko051>1ol0ED/5
o`1JB0Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_oONP03om^8
00?oeYH00_oAX`03olf`00;ob;/00oo1a002ojfo00?oVkX00_n8]P03ogNa00;oIjd00omGZ002odRS
00?o>Il00_l/VP03oajF00;o4Y400ol6S002o`280`?o08<=0ol0OQL2o`1j7`?o07DW0ol0LBl3o`1/
=@?o06Lk0ol0Hd03o`1NA@?o05Y80ol0ED/4o`1@CPCo04Q<0ol0?TL4o`0e@`Go02dn1Ol09CT5o`0N
=@Ko01L`1ol04R`;o`0=9bGo00PR2ol03BL8o`0B;0Oo01L`1ol07SD6o`0U>@Ko02dn1_l0=D<5o`0n
A`Ko04Q<1_l0D4h7o`1EB`Go05Y81Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooooooo
ool00_ooool2ommj00?ofhP00ooFUP02om6S00?ocK000_o8^`03ol7400;o[Kl00onK^P02ohRf00?o
Mk400_mW[@03oeNX00;oB:<00oliW`02obbJ00?o7YH00_lBT@03o`J<00;o08P30ol0P`d3o`1n5`;o
07XO0ol0MBL3o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i50ol0FTP3o`1EB`Co051>1?l0B4`3o`0nA`Co
03E31Ol0;Ch5o`0U>@Go01he1_l05c07o`0B;0[o00dW:?l0228:o`0=9`So018/1ol05c07o`0N=@Ko
02Di1_l0;Ch5o`0e@`Ko03i71_l0B4`6o`1@CPKo05E;1Ol0FTP5ooooo`7o00000Oooool1ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`;oggX00ooKR002omJF00?odJ<00_o=/003olRk00;o`L@0
0on]_`02oi^j00?oR;H00_mg/@03ofN]00;oEjP00om8X`02ocVO00?o;9X00_lNUP03oa:A00;o1X`0
0ol0R0<3o`233@;o07hG0ol0NQl3o`1e9`;o074_0ol0K3D3o`1W>`?o06=00ol0GTD4o`1JB0?o05E;
0ol0D4h4o`18C0Co03i71?l0=D<4o`0]?PGo02Di1Ol07SD6o`0G<0Oo018/2Ol03BLZo`088P_o00dW
1ol04R`7o`0G<0Oo01he1_l09CT6o`0]?PGo03E31_l0?TL6o`18C0Ko051>1_l0ED/5o`1JB0Gooooo
0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_oONP03om^800;oeYH00ooA
X`02olf`00?ob;/00_o1a003ojfo00;oVkX00on8]P02ogNa00?oIjd00_mGZ003odRS00;o>Il00ol/
VP02oajF00?o4Y400_l6S003o`280`?o08<=0_l0OQL3o`1j7`?o07DW0_l0LBl3o`1/=@?o06Lk0ol0
Hd03o`1NA@Co05Y80ol0ED/3o`1@CPCo04Q<1?l0?TL4o`0e@`Co02dn1Ol09CT5o`0N=@Ko01L`1ol0
4R`9o`0=9bco00PR2_l03BL7o`0B;0Oo01L`1ol07SD6o`0U>@Go02dn1_l0=D<6o`0nA`Go04Q<1_l0
D4h7o`1EB`Co05Y81Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2
ommj00;ofhP00ooFUP03om6S00;ocK000oo8^`02ol7400?o[Kl00_nK^P03ohRf00;oMk400_mW[@03
oeNX00;oB:<00oliW`02obbJ00?o7YH00_lBT@03o`J<00?o08P30_l0P`d3o`1n5`?o07XO0_l0MBL3
o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i50ol0FTP3o`1EB`Co051>0ol0B4`4o`0nA`Co03E31?l0;Ch5
o`0U>@Go01he1_l05c07o`0B;0So00dW4Ol0228;o`057Q;o00PR2_l03BL7o`0B;0Oo01L`1ol07SD6
o`0U>@Go02dn1_l0=D<6o`0nA`Ko04Q<1Ol0D4h7o`1EB`Co05Y81Oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_ooool2ommj00;ofhP00ooFUP03om6S00;ocK000oo8^`02ol74
00?o[Kl00_nK^P03ohRf00;oMk400_mW[@03oeNX00;oB:<00oliW`02obbJ00?o7YH00_lBT@03o`J<
00?o08P30_l0P`d3o`1n5`?o07XO0_l0MBL3o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i50ol0FTP3o`1E
B`Co051>0ol0B4`4o`0nA`Co03E31?l0;Ch5o`0U>@Go01he1_l05c07o`0B;0So00dW3ol0228Ao`05
7Poo00PR2_l03BL7o`0B;0Oo01L`1_l07SD6o`0U>@Ko02dn1_l0=D<5o`0nA`Ko04Q<1_l0D4h6o`1E
B`Co05Y81Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2ommj00;o
fhP00ooFUP02om6S00?ocK000_o8^`03ol7400;o[Kl00onK^P02ohRf00?oMk400_mW[@03oeNX00;o
B:<00oliW`02obbJ00?o7YH00_lBT@03o`J<00;o08P30ol0P`d2o`1n5`?o07XO0ol0MBL3o`1a;`;o
06`e0ol0Ic/3o`1S@0?o05i51?l0FTP3o`1EB`?o051>1?l0B4`3o`0nA`Co03E31Ol0;Ch4o`0U>@Go
01he1_l05c06o`0B;0Wo00dW3_l0228Do`057Poo00PR2Ol03BL7o`0B;0Oo01L`1_l07SD6o`0U>@Ko
02dn1_l0=D<5o`0nA`Ko04Q<1_l0D4h6o`1EB`Co05Y81Oooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool00_ooool2ommj00;ofhP00ooFUP02om6S00?ocK000_o8^`03ol7400;o[Kl0
0onK^P02ohRf00?oMk400_mW[@03oeNX00;oB:<00oliW`02obbJ00?o7YH00_lBT@03o`J<00;o08P3
0ol0P`d2o`1n5`?o07XO0ol0MBL3o`1a;`;o06`e0ol0Ic/3o`1S@0?o05i51?l0FTP3o`1EB`?o051>
1?l0B4`3o`0nA`Co03E31Ol0;Ch4o`0U>@Go01he1_l05c06o`0B;0So00dW3Ol0228Go`057Poo00PR
2Ol03BL7o`0B;0Oo01L`1_l07SD6o`0U>@Ko02dn1Ol0=D<6o`0nA`Go04Q<1_l0D4h7o`1EB`?o05Y8
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool01?oONP3ofhP0om^8
0?oKR003omJF00;odJ<00oo=/002olRk00?o`L@00_n]_`03oi^j00;oR;H00omg/@02ofN]00;oEjP0
0om8X`02ocVO00?o;9X00_lNUP03oa:A00;o1X`00ol0R0<3o`233@;o07hG0ol0NQl3o`1e9`;o074_
0ol0K3D3o`1W>`?o06=00ol0GTD3o`1JB0?o05E;1?l0D4h3o`18C0Co03i71?l0=D<4o`0]?PGo02Di
1?l07SD6o`0G<0Ko018/2?l03BL=o`088Q[o00DN3Ol02289o`0=9`Oo018/1ol05c06o`0N=@Ko02Di
1_l0;Ch5o`0e@`Ko03i71Ol0B4`6o`1@CPOo05E;0ol0FTP5ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`04ommj0?oKR03ofhP0om^800?oeYH00_oAX`03olf`00;ob;/0
0oo1a002ojfo00?oVkX00_n8]P03ogNa00;oIjd00_mGZ003odRS00;o>Il00ol/VP02oajF00?o4Y40
0_l6S003o`280`?o08<=0_l0OQL3o`1j7`?o07DW0_l0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y8
0ol0ED/4o`1@CP?o04Q<1?l0?TL4o`0e@`Co02dn1Ol09CT4o`0N=@Ko01L`1_l04R`8o`0=9`co00PR
7?l01Ah=o`088PWo00dW1ol04R`7o`0G<0Ko01he1Ol09CT6o`0]?PKo03E31Ol0?TL6o`18C0Ko051>
1_l0ED/3o`1JB0Gooooo0Ol00001ooooo`7ooooo000Fooooo`;o00000oooool01?oONP3ofhP0om^8
0?oKR002omJF00?odJ<00oo=/002olRk00?o`L@00_n]_`02oi^j00?oR;H00_mg/@03ofN]00;oEjP0
0om8X`02ocVO00?o;9X00_lNUP03oa:A00;o1X`00ol0R0<2o`233@?o07hG0ol0NQl2o`1e9`?o074_
0ol0K3D3o`1W>`?o06=00ol0GTD3o`1JB0?o05E;0ol0D4h4o`18C0Co03i70ol0=D<5o`0]?PCo02Di
1Ol07SD5o`0G<0Oo018/1ol03BL<o`088Qko00DN3?l02289o`0=9`Oo018/1ol05c06o`0N=@Go02Di
1_l0;Ch6o`0e@`Go03i71_l0B4`6o`1@CPKo05E;0ol0FTP4ooooo`;o00000_ooool001Kooooo00?o
0000ooooooooool00_ooool01?oONP3ofhP0om^80?oKR002omJF00?odJ<00oo=/002olRk00?o`L@0
0_n]_`02oi^j00?oR;H00_mg/@03ofN]00;oEjP00om8X`02ocVO00?o;9X00_lNUP03oa:A00;o1X`0
0ol0R0<2o`233@?o07hG0ol0NQl2o`1e9`?o074_0ol0K3D3o`1W>`?o06=00ol0GTD3o`1JB0?o05E;
0ol0D4h4o`18C0Co03i70ol0=D<5o`0]?PCo02Di1Ol07SD5o`0G<0Oo018/1ol03BL<o`088Qoo00DN
3?l02288o`0=9`So018/1_l05c06o`0N=@Ko02Di1_l0;Ch5o`0e@`Ko03i71Ol0B4`6o`1@CPKo05E;
0ol0FTP5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04ommj0?oK
R03ofhP0om^800;oeYH00ooAX`02olf`00?ob;/00_o1a003ojfo00;oVkX00on8]P02ogNa00?oIjd0
0_mGZ003odRS00;o>Il00_l/VP03oajF00;o4Y400ol6S002o`280`?o08<=0ol0OQL2o`1j7`?o07DW
0ol0LBl3o`1/=@;o06Lk0ol0Hd03o`1NA@Co05Y80ol0ED/3o`1@CPCo04Q<0ol0?TL4o`0e@`Co02dn
1Ol09CT4o`0N=@Ko01L`1_l04R`7o`0=9`_o00PR8Ol01Ah<o`088PSo00dW2?l04R`6o`0G<0Ko01he
1_l09CT6o`0]?PGo03E31_l0?TL5o`18C0Ko051>1_l0ED/3o`1JB0Gooooo0Ol00001ooooo`7ooooo
000Fooooo`03o`000?oooooooooo00;ooooo00CoggX0om^80?oKR03ofhP00_oFUP03om6S00;ocK00
0oo8^`02ol7400?o[Kl00_nK^P03ohRf00;oMk400omW[@02oeNX00?oB:<00_liW`02obbJ00?o7YH0
0_lBT@03o`J<00;o08P30ol0P`d3o`1n5`;o07XO0ol0MBL3o`1a;`?o06`e0_l0Ic/3o`1S@0?o05i5
1?l0FTP3o`1EB`?o051>1?l0B4`3o`0nA`Co03E31?l0;Ch5o`0U>@Co01he1_l05c06o`0B;0Oo00dW
2ol0228Ro`057P_o00PR2Ol03BL7o`0B;0Ko01L`1ol07SD5o`0U>@Ko02dn1Ol0=D<6o`0nA`Ko04Q<
1Ol0D4h7o`1EB`;o05Y81Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_oo
ool01?oONP3ofhP0om^80?oKR002omJF00?odJ<00_o=/003olRk00;o`L@00on]_`02oi^j00?oR;H0
0_mg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00olNUP02oa:A00?o1X`00_l0R0<3o`233@;o07hG
0ol0NQl3o`1e9`?o074_0_l0K3D3o`1W>`?o06=00ol0GTD3o`1JB0?o05E;1?l0D4h3o`18C0Co03i7
1?l0=D<4o`0]?PCo02Di1Ol07SD5o`0G<0Ko018/2?l03BL:o`088R?o00DN2ol02289o`0=9`Oo018/
1_l05c07o`0N=@Go02Di1_l0;Ch5o`0e@`Ko03i71_l0B4`5o`1@CPOo05E;0_l0FTP5ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04ommj0?oKR03ofhP0om^800;oeYH0
0ooAX`02olf`00?ob;/00_o1a003ojfo00;oVkX00on8]P02ogNa00;oIjd00omGZ002odRS00?o>Il0
0_l/VP03oajF00;o4Y400ol6S002o`280`?o08<=0_l0OQL3o`1j7`?o07DW0ol0LBl2o`1/=@?o06Lk
0ol0Hd03o`1NA@?o05Y80ol0ED/4o`1@CP?o04Q<1?l0?TL4o`0e@`Co02dn1?l09CT5o`0N=@Go01L`
1_l04R`8o`0=9`[o00PR9?l01Ah;o`088PSo00dW1ol04R`7o`0G<0Ko01he1_l09CT5o`0]?PKo03E3
1Ol0?TL6o`18C0Ko051>1_l0ED/2o`1JB0Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oo
oooooooo00;ooooo00CoggX0om^80?oKR03ofhP00_oFUP03om6S00;ocK000oo8^`02ol7400?o[Kl0
0_nK^P02ohRf00?oMk400_mW[@03oeNX00;oB:<00oliW`02obbJ00?o7YH00_lBT@03o`J<00;o08P3
0ol0P`d2o`1n5`?o07XO0ol0MBL2o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i50ol0FTP3o`1EB`Co051>
0ol0B4`4o`0nA`?o03E31?l0;Ch5o`0U>@Go01he1Ol05c06o`0B;0Oo00dW2_l0228Uo`057P_o00PR
2?l03BL7o`0B;0Oo01L`1_l07SD6o`0U>@Go02dn1_l0=D<5o`0nA`Ko04Q<1_l0D4h6o`1EB`;o05Y8
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool01?oONP3ofhP0om^8
0?oKR002omJF00?odJ<00_o=/003olRk00;o`L@00on]_`02oi^j00;oR;H00omg/@02ofN]00?oEjP0
0_m8X`03ocVO00;o;9X00olNUP02oa:A00?o1X`00_l0R0<3o`233@;o07hG0ol0NQl3o`1e9`;o074_
0ol0K3D3o`1W>`?o06=00ol0GTD3o`1JB0?o05E;1?l0D4h3o`18C0Co03i70ol0=D<4o`0]?PGo02Di
1Ol07SD5o`0G<0Ko018/1ol03BL:o`088RKo00DN2_l02289o`0=9`Oo018/1_l05c06o`0N=@Ko02Di
1Ol0;Ch6o`0e@`Go03i71_l0B4`6o`1@CPKo05E;0_l0FTP5ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`03ommj0?oKR03ofhP000?oeYH00ooAX`02olf`00?ob;/00_o1
a003ojfo00;oVkX00_n8]P03ogNa00;oIjd00omGZ002odRS00?o>Il00_l/VP03oajF00;o4Y400ol6
S002o`280`?o08<=0_l0OQL3o`1j7`?o07DW0_l0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y80ol0
ED/3o`1@CPCo04Q<0ol0?TL4o`0e@`Co02dn1Ol09CT4o`0N=@Ko01L`1Ol04R`8o`0=9`[o00PR9_l0
1Ah:o`088PWo00dW1ol04R`6o`0G<0Ko01he1_l09CT5o`0]?PKo03E31Ol0?TL6o`18C0Ko051>1_l0
ED/2o`1JB0Gooooo0Ol00001ooooo`7ooooo000?ooooo`;o00001Oooool00ol0003oooooooooo`02
ooooo`03ommj0?oKR03ofhP000?oeYH00ooAX`02olf`00?ob;/00_o1a003ojfo00;oVkX00_n8]P03
ogNa00;oIjd00omGZ002odRS00?o>Il00_l/VP03oajF00;o4Y400ol6S002o`280`?o08<=0_l0OQL3
o`1j7`?o07DW0_l0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y80ol0ED/3o`1@CPCo04Q<0ol0?TL4
o`0e@`Co02dn1Ol09CT4o`0N=@Ko01L`1Ol04R`8o`0=9`[o00PR9_l01Ah;o`088PSo00dW1ol04R`6
o`0G<0Ko01he1_l09CT5o`0]?PKo03E31Ol0?TL6o`18C0Ko051>1_l0ED/2o`1JB0Gooooo0Ol00001
ooooo`7ooooo000>ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool0
0ooONP3ofhP0om^80003omJF00?odJ<00_o=/003olRk00;o`L@00_n]_`03oi^j00;oR;H00omg/@02
ofN]00?oEjP00_m8X`03ocVO00;o;9X00_lNUP03oa:A00;o1X`00ol0R0<3o`233@;o07hG0ol0NQl2
o`1e9`?o074_0ol0K3D3o`1W>`?o06=00ol0GTD3o`1JB0?o05E;0ol0D4h4o`18C0?o03i71?l0=D<4
o`0]?PCo02Di1Ol07SD5o`0G<0Ko018/1ol03BL:o`088ROo00DN2ol02288o`0=9`Oo018/1_l05c06
o`0N=@Ko02Di1Ol0;Ch6o`0e@`Go03i71_l0B4`6o`1@CPKo05E;0_l0FTP5ooooo`7o00000Oooool1
ooooo`003_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00?oggX0
om^80?oKR0000ooFUP03om6S00;ocK000oo8^`02ol7400;o[Kl00onK^P02ohRf00?oMk400_mW[@03
oeNX00;oB:<00oliW`02obbJ00;o7YH00olBT@02o`J<00?o08P30ol0P`d2o`1n5`?o07XO0_l0MBL3
o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i50ol0FTP3o`1EB`?o051>1?l0B4`3o`0nA`Co03E31?l0;Ch4
o`0U>@Go01he1Ol05c06o`0B;0Oo00dW2_l0228Wo`057P_o00PR2?l03BL7o`0B;0Ko01L`1_l07SD6
o`0U>@Ko02dn1Ol0=D<6o`0nA`Go04Q<1_l0D4h6o`1EB`;o05Y81Oooool1o`00007ooooo0Oooool0
00kooooo00Co0000oooooooooooo00001?ooool3o`0000;ooooo00?oggX0om^80?oKR0000ooFUP03
om6S00;ocK000oo8^`02ol7400;o[Kl00onK^P02ohRf00?oMk400_mW[@03oeNX00;oB:<00_liW`03
obbJ00;o7YH00olBT@02o`J<00?o08P30ol0P`d2o`1n5`?o07XO0_l0MBL3o`1a;`?o06`e0ol0Ic/3
o`1S@0?o05i50ol0FTP3o`1EB`?o051>1?l0B4`3o`0nA`Co03E31?l0;Ch4o`0U>@Go01he1Ol05c06
o`0B;0Oo00dW2_l0228Wo`057P_o00PR2?l03BL7o`0B;0Ko01L`1_l07SD6o`0U>@Ko02dn1Ol0=D<6
o`0nA`Go04Q<1_l0D4h6o`1EB`;o05Y80oooool3o`0000;ooooo000>ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool00_ooool00ooONP3ofhP0om^80003omJF00?odJ<00_o=/003
olRk00;o`L@00_n]_`03oi^j00;oR;H00omg/@02ofN]00?oEjP00_m8X`02ocVO00?o;9X00_lNUP03
oa:A00;o1X`00ol0R0<3o`233@;o07hG0ol0NQl2o`1e9`?o074_0ol0K3D3o`1W>`?o06=00ol0GTD3
o`1JB0?o05E;0ol0D4h4o`18C0?o03i71?l0=D<4o`0]?PCo02Di1Ol07SD5o`0G<0Ko018/1ol03BL:
o`088ROo00DN2ol02288o`0=9`Oo018/1_l05c06o`0N=@Ko02Di1_l0;Ch5o`0e@`Ko03i71Ol0B4`6
o`1@CPKo05E;0_l0FTP5ooooo`7o00000Oooool1ooooo`003_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00;ooooo00?oggX0om^80?oKR0000ooFUP03om6S00;ocK000oo8^`02
ol7400;o[Kl00onK^P02ohRf00?oMk400_mW[@03oeNX00;oB:<00_liW`03obbJ00;o7YH00olBT@02
o`J<00?o08P30ol0P`d2o`1n5`?o07XO0_l0MBL3o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i50ol0FTP3
o`1EB`?o051>1?l0B4`3o`0nA`Co03E31?l0;Ch4o`0U>@Go01he1Ol05c06o`0B;0Oo00dW2_l0228W
o`057P_o00PR2?l03BL7o`0B;0Ko01L`1_l07SD6o`0U>@Ko02dn1Ol0=D<6o`0nA`Go04Q<1_l0D4h6
o`1EB`;o05Y81Oooool1o`00007ooooo0Oooool000oooooo0_l00005ooooo`03o`000?oooooooooo
00;ooooo00?oggX0om^80?oKR0000ooFUP03om6S00;ocK000oo8^`02ol7400;o[Kl00onK^P02ohRf
00?oMk400_mW[@03oeNX00;oB:<00oliW`02obbJ00;o7YH00olBT@02o`J<00?o08P30ol0P`d2o`1n
5`?o07XO0_l0MBL3o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i50ol0FTP3o`1EB`?o051>1?l0B4`3o`0n
A`Co03E31?l0;Ch4o`0U>@Go01he1Ol05c06o`0B;0Oo00dW2_l0228Wo`057P_o00PR2?l03BL7o`0B
;0Ko01L`1_l07SD6o`0U>@Ko02dn1Ol0=D<6o`0nA`Go04Q<1_l0D4h6o`1EB`;o05Y81Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool00ooONP3ofhP0om^80003omJF00?o
dJ<00_o=/003olRk00;o`L@00_n]_`03oi^j00;oR;H00omg/@02ofN]00?oEjP00_m8X`03ocVO00;o
;9X00_lNUP03oa:A00;o1X`00ol0R0<3o`233@;o07hG0ol0NQl2o`1e9`?o074_0ol0K3D3o`1W>`?o
06=00ol0GTD3o`1JB0?o05E;0ol0D4h4o`18C0?o03i71?l0=D<4o`0]?PCo02Di1Ol07SD5o`0G<0Ko
018/1ol03BL:o`088ROo00DN2ol02288o`0=9`Oo018/1_l05c06o`0N=@Ko02Di1Ol0;Ch6o`0e@`Go
03i71_l0B4`6o`1@CPKo05E;0_l0FTP5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooo
ooooo`02ooooo`03ommj0?oKR03ofhP000?oeYH00ooAX`02olf`00?ob;/00_o1a003ojfo00;oVkX0
0_n8]P03ogNa00;oIjd00omGZ002odRS00?o>Il00_l/VP03oajF00;o4Y400ol6S002o`280`?o08<=
0_l0OQL3o`1j7`?o07DW0_l0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y80ol0ED/3o`1@CPCo04Q<
0ol0?TL4o`0e@`Co02dn1Ol09CT4o`0N=@Ko01L`1Ol04R`8o`0=9`[o00PR9_l01Ah;o`088PSo00dW
1ol04R`6o`0G<0Ko01he1_l09CT5o`0]?PKo03E31Ol0?TL6o`18C0Ko051>1_l0ED/2o`1JB0Gooooo
0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00?oggX0om^80?oKR0000ooF
UP03om6S00;ocK000oo8^`02ol7400?o[Kl00_nK^P02ohRf00?oMk400_mW[@03oeNX00;oB:<00oli
W`02obbJ00?o7YH00_lBT@03o`J<00;o08P30ol0P`d2o`1n5`?o07XO0ol0MBL2o`1a;`?o06`e0ol0
Ic/3o`1S@0?o05i50ol0FTP3o`1EB`?o051>1?l0B4`3o`0nA`Co03E31?l0;Ch5o`0U>@Co01he1_l0
5c06o`0B;0Oo00dW2_l0228Vo`057P[o00PR2Ol03BL7o`0B;0Ko01L`1_l07SD6o`0U>@Go02dn1_l0
=D<5o`0nA`Ko04Q<1_l0D4h6o`1EB`;o05Y81Oooool1o`00007ooooo0Oooool001Kooooo00?o0000
ooooooooool00_ooool01?oONP3ofhP0om^80?oKR002omJF00?odJ<00_o=/003olRk00;o`L@00on]
_`02oi^j00;oR;H00omg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00olNUP02oa:A00?o1X`00_l0
R0<3o`233@;o07hG0ol0NQl3o`1e9`;o074_0ol0K3D3o`1W>`?o06=00ol0GTD3o`1JB0?o05E;1?l0
D4h3o`18C0Co03i70ol0=D<4o`0]?PGo02Di1Ol07SD5o`0G<0Ko018/1ol03BL:o`088RKo00DN2_l0
2289o`0=9`Oo018/1_l05c06o`0N=@Ko02Di1Ol0;Ch6o`0e@`Go03i71_l0B4`6o`1@CPKo05E;0_l0
FTP5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04ommj0?oKR03o
fhP0om^800;oeYH00ooAX`02olf`00?ob;/00_o1a003ojfo00;oVkX00_n8]P03ogNa00;oIjd00omG
Z002odRS00?o>Il00_l/VP03oajF00;o4Y400ol6S002o`280`?o08<=0_l0OQL3o`1j7`?o07DW0_l0
LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y80ol0ED/4o`1@CP?o04Q<1?l0?TL3o`0e@`Co02dn1Ol0
9CT5o`0N=@Go01L`1_l04R`7o`0=9`_o00PR9?l01Ah;o`088PSo00dW1ol04R`7o`0G<0Ko01he1_l0
9CT5o`0]?PKo03E31Ol0?TL6o`18C0Ko051>1_l0ED/2o`1JB0Gooooo0Ol00001ooooo`7ooooo000F
ooooo`03o`000?oooooooooo00;ooooo00CoggX0om^80?oKR03ofhP00_oFUP03om6S00;ocK000oo8
^`02ol7400?o[Kl00_nK^P03ohRf00;oMk400_mW[@03oeNX00;oB:<00oliW`02obbJ00?o7YH00_lB
T@03o`J<00;o08P30ol0P`d2o`1n5`?o07XO0ol0MBL3o`1a;`;o06`e0ol0Ic/3o`1S@0?o05i50ol0
FTP3o`1EB`Co051>0ol0B4`4o`0nA`Co03E31?l0;Ch4o`0U>@Go01he1Ol05c06o`0B;0So00dW2_l0
228So`057Pco00PR2?l03BL7o`0B;0Oo01L`1_l07SD6o`0U>@Go02dn1_l0=D<5o`0nA`Ko04Q<1_l0
D4h6o`1EB`;o05Y81Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool0
1?oONP3ofhP0om^80?oKR002omJF00?odJ<00_o=/003olRk00;o`L@00on]_`02oi^j00?oR;H00_mg
/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00olNUP02oa:A00?o1X`00_l0R0<3o`233@;o07hG0ol0
NQl3o`1e9`?o074_0_l0K3D3o`1W>`?o06=00ol0GTD3o`1JB0?o05E;1?l0D4h3o`18C0Co03i71?l0
=D<4o`0]?PCo02Di1Ol07SD5o`0G<0Ko018/2?l03BL:o`088R?o00DN2ol02289o`0=9`Oo018/1_l0
5c07o`0N=@Go02Di1_l0;Ch5o`0e@`Ko03i71_l0B4`5o`1@CPOo05E;0_l0FTP5ooooo`7o00000Ooo
ool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04ommj0?oKR03ofhP0om^800;oeYH00ooA
X`02olf`00?ob;/00_o1a003ojfo00;oVkX00on8]P02ogNa00?oIjd00_mGZ003odRS00;o>Il00_l/
VP03oajF00;o4Y400ol6S002o`280`?o08<=0ol0OQL2o`1j7`?o07DW0ol0LBl3o`1/=@;o06Lk0ol0
Hd03o`1NA@Co05Y80ol0ED/3o`1@CPCo04Q<0ol0?TL4o`0e@`Co02dn1Ol09CT4o`0N=@Ko01L`1_l0
4R`7o`0=9`_o00PR8_l01Ah;o`088PWo00dW1ol04R`6o`0G<0Oo01he1Ol09CT6o`0]?PGo03E31_l0
?TL6o`18C0Go051>1ol0ED/2o`1JB0Gooooo0Ol00001ooooo`7ooooo000Fooooo`;o00000oooool0
1?oONP3ofhP0om^80?oKR002omJF00?odJ<00_o=/003olRk00;o`L@00on]_`02oi^j00?oR;H00_mg
/@03ofN]00;oEjP00om8X`02ocVO00;o;9X00olNUP02oa:A00?o1X`00_l0R0<3o`233@?o07hG0_l0
NQl3o`1e9`?o074_0ol0K3D2o`1W>`?o06=00ol0GTD4o`1JB0?o05E;0ol0D4h4o`18C0?o03i71?l0
=D<4o`0]?PGo02Di1Ol07SD5o`0G<0Ko018/1ol03BL<o`088R3o00DN3?l02288o`0=9`So018/1_l0
5c06o`0N=@Ko02Di1_l0;Ch5o`0e@`Ko03i71Ol0B4`6o`1@CPKo05E;0ol0FTP4ooooo`;o00000_oo
ool001Kooooo00?o0000ooooooooool00_ooool01?oONP3ofhP0om^80?oKR002omJF00?odJ<00oo=
/002olRk00?o`L@00_n]_`02oi^j00?oR;H00_mg/@03ofN]00;oEjP00om8X`02ocVO00?o;9X00_lN
UP03oa:A00;o1X`00ol0R0<2o`233@?o07hG0ol0NQl2o`1e9`?o074_0ol0K3D3o`1W>`?o06=00ol0
GTD3o`1JB0?o05E;0ol0D4h4o`18C0Co03i70ol0=D<5o`0]?PCo02Di1Ol07SD5o`0G<0Oo018/1ol0
3BL<o`088Qko00DN3?l02289o`0=9`Oo018/1ol05c06o`0N=@Ko02Di1_l0;Ch5o`0e@`Ko03i71Ol0
B4`6o`1@CPKo05E;0ol0FTP5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02
ooooo`04ommj0?oKR03ofhP0om^800;oeYH00ooAX`03olf`00;ob;/00oo1a002ojfo00;oVkX00on8
]P02ogNa00?oIjd00_mGZ003odRS00;o>Il00ol/VP02oajF00?o4Y400_l6S003o`280`;o08<=0ol0
OQL3o`1j7`;o07DW0ol0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y80ol0ED/3o`1@CPCo04Q<1?l0
?TL3o`0e@`Go02dn1?l09CT5o`0N=@Ko01L`1_l04R`8o`0=9`co00PR7?l01Ah=o`088PWo00dW1ol0
4R`7o`0G<0Ko01he1Ol09CT6o`0]?PKo03E31Ol0?TL6o`18C0Ko051>1_l0ED/3o`1JB0Gooooo0Ol0
0001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00CoggX0om^80?oKR03ofhP00ooF
UP02om6S00?ocK000_o8^`03ol7400;o[Kl00onK^P02ohRf00?oMk400_mW[@02oeNX00?oB:<00_li
W`03obbJ00;o7YH00olBT@02o`J<00?o08P30ol0P`d2o`1n5`?o07XO0ol0MBL2o`1a;`?o06`e0ol0
Ic/3o`1S@0?o05i50ol0FTP3o`1EB`Co051>0ol0B4`4o`0nA`Co03E31?l0;Ch5o`0U>@Co01he1_l0
5c06o`0B;0So00dW3Ol0228Jo`057Pko00PR2?l03BL8o`0B;0Ko01L`1ol07SD5o`0U>@Ko02dn1_l0
=D<5o`0nA`Ko04Q<1_l0D4h6o`1EB`?o05Y81Oooool1o`00007ooooo0Oooool001Kooooo00?o0000
ooooooooool00_ooool01?oONP3ofhP0om^80?oKR003omJF00;odJ<00oo=/002olRk00?o`L@00_n]
_`03oi^j00;oR;H00omg/@02ofN]00;oEjP00om8X`02ocVO00?o;9X00_lNUP03oa:A00;o1X`00ol0
R0<3o`233@;o07hG0ol0NQl3o`1e9`;o074_0ol0K3D3o`1W>`?o06=00ol0GTD3o`1JB0?o05E;1?l0
D4h3o`18C0Co03i71?l0=D<4o`0]?PGo02Di1?l07SD6o`0G<0Ko018/2Ol03BL>o`088QKo00DN3_l0
228:o`0=9`Oo018/1ol05c06o`0N=@Ko02Di1_l0;Ch5o`0e@`Ko03i71Ol0B4`6o`1@CPOo05E;0ol0
FTP5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;oggX00_oKR003
omJF00;odJ<00oo=/002olRk00?o`L@00_n]_`03oi^j00;oR;H00omg/@02ofN]00?oEjP00_m8X`03
ocVO00;o;9X00olNUP02oa:A00?o1X`00_l0R0<3o`233@;o07hG0ol0NQl3o`1e9`?o074_0_l0K3D3
o`1W>`?o06=00ol0GTD4o`1JB0?o05E;0ol0D4h4o`18C0?o03i71?l0=D<5o`0]?PCo02Di1Ol07SD6
o`0G<0Ko018/2Ol03BL>o`088QCo00DN3ol0228:o`0=9`Oo018/1ol05c06o`0N=@Ko02Di1_l0;Ch5
o`0e@`Ko03i71Ol0B4`6o`1@CPOo05E;0ol0FTP5ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02ooooo`;oggX00_oKR003omJF00;odJ<00oo=/002olRk00?o`L@00_n]_`03oi^j
00;oR;H00omg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00olNUP02oa:A00?o1X`00_l0R0<3o`23
3@;o07hG0ol0NQl3o`1e9`?o074_0_l0K3D3o`1W>`?o06=00ol0GTD4o`1JB0?o05E;0ol0D4h4o`18
C0Co03i71?l0=D<4o`0]?PCo02Di1_l07SD5o`0G<0Oo018/2?l03BLAo`088Poo00DN4?l0228:o`0=
9`Oo018/1ol05c06o`0N=@Ko02Di1_l0;Ch6o`0e@`Go03i71_l0B4`6o`1@CPKo05E;1?l0FTP5oooo
o`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;oggX00_oKR003omJF00?o
dJ<00_o=/003olRk00;o`L@00on]_`02oi^j00?oR;H00_mg/@02ofN]00?oEjP00_m8X`03ocVO00;o
;9X00olNUP02oa:A00?o1X`00ol0R0<2o`233@?o07hG0ol0NQl2o`1e9`?o074_0ol0K3D3o`1W>`?o
06=00ol0GTD3o`1JB0?o05E;1?l0D4h3o`18C0Co03i71?l0=D<4o`0]?PGo02Di1Ol07SD6o`0G<0Oo
018/2?l03BLBo`088PWo00DN4ol0228:o`0=9`So018/1ol05c06o`0N=@Ko02Di1_l0;Ch6o`0e@`Go
03i71_l0B4`6o`1@CPKo05E;1?l0FTP5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooo
ooooo`02ooooo`;oggX00_oKR003omJF00?odJ<00_o=/003olRk00;o`L@00on]_`02oi^j00?oR;H0
0_mg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00olNUP02oa:A00?o1X`00ol0R0<2o`233@?o07hG
0ol0NQl2o`1e9`?o074_0ol0K3D3o`1W>`?o06=00ol0GTD3o`1JB0?o05E;1?l0D4h3o`18C0Co03i7
1?l0=D<4o`0]?PGo02Di1Ol07SD6o`0G<0So018/2?l03BL/o`088P_o00dW1ol04R`7o`0G<0Oo01he
1_l09CT5o`0]?PKo03E31_l0?TL5o`18C0Ko051>1ol0ED/4o`1JB0Gooooo0Ol00001ooooo`7ooooo
000Fooooo`03o`000?oooooooooo00;ooooo0_oONP03om^800;oeYH00ooAX`02olf`00?ob;/00_o1
a003ojfo00;oVkX00on8]P02ogNa00?oIjd00_mGZ003odRS00;o>Il00ol/VP02oajF00?o4Y400_l6
S003o`280`?o08<=0_l0OQL3o`1j7`?o07DW0_l0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@Co05Y80ol0
ED/3o`1@CPCo04Q<1?l0?TL4o`0e@`Co02dn1Ol09CT5o`0N=@Ko01L`1ol04R`9o`0=9b[o00PR2ol0
3BL8o`0B;0Oo01L`1_l07SD7o`0U>@Go02dn1_l0=D<6o`0nA`Go04Q<1_l0D4h7o`1EB`Co05Y81Ooo
ool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2ommj00?ofhP00_oFUP03
om6S00;ocK000oo8^`02ol7400?o[Kl00_nK^P03ohRf00;oMk400omW[@02oeNX00?oB:<00_liW`03
obbJ00;o7YH00olBT@02o`J<00?o08P30ol0P`d2o`1n5`?o07XO0ol0MBL2o`1a;`?o06`e0ol0Ic/3
o`1S@0?o05i51?l0FTP3o`1EB`?o051>1?l0B4`4o`0nA`Co03E31?l0;Ch5o`0U>@Ko01he1_l05c06
o`0B;0_o00dW9ol0228;o`0=9`So018/1ol05c07o`0N=@Ko02Di1_l0;Ch5o`0e@`Ko03i71_l0B4`6
o`1@CPKo05E;1Ol0FTP5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02oooo
o`;oggX00ooKR003omJF00;odJ<00oo=/002olRk00?o`L@00_n]_`03oi^j00;oR;H00omg/@02ofN]
00?oEjP00_m8X`03ocVO00;o;9X00olNUP02oa:A00?o1X`00_l0R0<3o`233@?o07hG0_l0NQl3o`1e
9`?o074_0ol0K3D3o`1W>`?o06=00ol0GTD3o`1JB0?o05E;1?l0D4h4o`18C0?o03i71?l0=D<5o`0]
?PGo02Di1Ol07SD6o`0G<0Oo018/2ol03BLUo`088Pco00dW2?l04R`7o`0G<0Oo01he1_l09CT6o`0]
?PGo03E31_l0?TL6o`18C0Ko051>1_l0ED/5o`1JB0Gooooo0Ol00001ooooo`7ooooo000Fooooo`03
o`000?oooooooooo00;ooooo0_oONP03om^800?oeYH00_oAX`03olf`00;ob;/00oo1a002ojfo00?o
VkX00_n8]P03ogNa00;oIjd00omGZ002odRS00?o>Il00_l/VP03oajF00;o4Y400ol6S002o`280`?o
08<=0ol0OQL2o`1j7`?o07DW0ol0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y80ol0ED/4o`1@CPCo
04Q<1?l0?TL4o`0e@`Co02dn1Ol09CT5o`0N=@Ko01L`2?l04R`<o`0=9b;o00PR2ol03BL9o`0B;0Oo
01L`1ol07SD6o`0U>@Ko02dn1_l0=D<5o`0nA`Ko04Q<1_l0D4h7o`1EB`Go05Y81Oooool1o`00007o
oooo0Oooool001Kooooo0_l00003ooooo`;oggX00ooKR003omJF00;odJ<00oo=/002olRk00?o`L@0
0on]_`02oi^j00;oR;H00omg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00olNUP03oa:A00;o1X`0
0ol0R0<2o`233@?o07hG0ol0NQl3o`1e9`;o074_0ol0K3D3o`1W>`?o06=00ol0GTD4o`1JB0?o05E;
1?l0D4h3o`18C0Co03i71?l0=D<5o`0]?PGo02Di1Ol07SD6o`0G<0So018/3?l03BLOo`088Pgo00dW
2?l04R`8o`0G<0Ko01he1ol09CT6o`0]?PKo03E31Ol0?TL6o`18C0Ko051>1ol0ED/5o`1JB0Cooooo
0_l00002ooooo`005_ooool00ol0003oooooooooo`02ooooo`;oggX00ooKR003omJF00;odJ<00oo=
/002olRk00?o`L@00on]_`02oi^j00;oR;H00omg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00olN
UP03oa:A00;o1X`00ol0R0<2o`233@?o07hG0ol0NQl3o`1e9`;o074_0ol0K3D3o`1W>`?o06=00ol0
GTD4o`1JB0?o05E;1?l0D4h3o`18C0Co03i71?l0=D<5o`0]?PGo02Di1_l07SD6o`0G<0So018/3Ol0
3BLKo`088Pko00dW2Ol04R`7o`0G<0Oo01he1_l09CT6o`0]?PKo03E31_l0?TL5o`18C0Ko051>1ol0
ED/6o`1JB0Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0ooONP02
om^800?oeYH00ooAX`02olf`00?ob;/00_o1a003ojfo00;oVkX00on8]P02ogNa00?oIjd00_mGZ003
odRS00;o>Il00ol/VP02oajF00?o4Y400ol6S002o`280`?o08<=0ol0OQL2o`1j7`?o07DW0ol0LBl3
o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y81?l0ED/3o`1@CPCo04Q<1?l0?TL4o`0e@`Go02dn1Ol09CT5
o`0N=@Oo01L`2?l04R`>o`0=9aOo00PR3ol03BL9o`0B;0Oo01L`2?l07SD6o`0U>@Ko02dn1_l0=D<6
o`0nA`Go04Q<1_l0D4h7o`1EB`Ko05Y81Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool3ommj00;ofhP00ooFUP03om6S00;ocK000oo8^`02ol7400?o[Kl00_nK^P03ohRf
00;oMk400omW[@02oeNX00?oB:<00_liW`03obbJ00;o7YH00olBT@03o`J<00;o08P30ol0P`d3o`1n
5`;o07XO0ol0MBL3o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i50ol0FTP4o`1EB`Co051>1?l0B4`4o`0n
A`Co03E31?l0;Ch6o`0U>@Go01he1ol05c09o`0B;0ko00dW4ol0228?o`0=9`[o018/2?l05c07o`0N
=@Ko02Di1_l0;Ch6o`0e@`Ko03i71_l0B4`6o`1@CPKo05E;1ol0FTP5ooooo`7o00000Oooool1oooo
o`005_ooool00ol0003oooooooooo`02ooooo`?oggX00ooKR002omJF00?odJ<00oo=/002olRk00?o
`L@00_n]_`03oi^j00;oR;H00omg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00olNUP03oa:A00;o
1X`00ol0R0<2o`233@?o07hG0ol0NQl3o`1e9`?o074_0ol0K3D3o`1W>`?o06=00ol0GTD3o`1JB0Co
05E;0ol0D4h4o`18C0Co03i71?l0=D<5o`0]?PGo02Di1_l07SD7o`0G<0Wo018/4Ol03BL;o`088Q;o
00dW2_l04R`8o`0G<0Oo01he1ol09CT6o`0]?PKo03E31_l0?TL6o`18C0Ko051>1_l0ED/7o`1JB0Go
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0ooONP03om^800;oeYH0
0ooAX`03olf`00;ob;/00oo1a002ojfo00?oVkX00_n8]P03ogNa00;oIjd00omGZ002odRS00?o>Il0
0_l/VP03oajF00?o4Y400_l6S003o`280`;o08<=0ol0OQL3o`1j7`?o07DW0ol0LBl3o`1/=@?o06Lk
0ol0Hd03o`1NA@?o05Y81?l0ED/3o`1@CPCo04Q<1?l0?TL4o`0e@`Ko02dn1?l09CT6o`0N=@So01L`
2_l04R`Zo`0=9`_o018/2?l05c07o`0N=@Oo02Di1_l0;Ch6o`0e@`Ko03i71_l0B4`6o`1@CPKo05E;
1ol0FTP00ol0GTGoooooooooo`03ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`03onAZ0?oONP3oggX000?ofhP00ooFUP02om6S00?ocK000oo8^`02ol7400?o[Kl00_nK
^P03ohRf00;oMk400omW[@02oeNX00?oB:<00_liW`03obbJ00;o7YH00olBT@03o`J<00;o08P30ol0
P`d3o`1n5`?o07XO0_l0MBL3o`1a;`?o06`e0ol0Ic/3o`1S@0Co05i50ol0FTP3o`1EB`Co051>1?l0
B4`4o`0nA`Co03E31Ol0;Ch5o`0U>@Ko01he2?l05c0:o`0B;2So00dW2ol04R`9o`0G<0Oo01he1ol0
9CT6o`0]?PKo03E31_l0?TL6o`18C0Ko051>1_l0ED/7o`1JB003o`1NAOoooooooooo00?ooooo0Ol0
0001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00?oi6X0ommj0?oONP000ooKR003
omJF00;odJ<00oo=/003olRk00;o`L@00on]_`02oi^j00?oR;H00_mg/@03ofN]00;oEjP00om8X`02
ocVO00?o;9X00_lNUP03oa:A00?o1X`00_l0R0<3o`233@?o07hG0ol0NQl2o`1e9`?o074_0ol0K3D3
o`1W>`Co06=00ol0GTD3o`1JB0Co05E;1?l0D4h4o`18C0Co03i71?l0=D<5o`0]?PGo02Di1_l07SD8
o`0G<0co018/8ol03BL<o`0B;0Wo01L`1ol07SD7o`0U>@Ko02dn1_l0=D<6o`0nA`Ko04Q<1_l0D4h6
o`1EB`So05Y800?o05i5ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool01?oTJP3oggX0ommj0?oONP02om^800?oeYH00ooAX`02olf`00?ob;/00oo1a002
ojfo00?oVkX00_n8]P03ogNa00;oIjd00omGZ002odRS00?o>Il00_l/VP03oajF00?o4Y400_l6S003
o`280`?o08<=0_l0OQL3o`1j7`?o07DW0ol0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@Co05Y80ol0ED/4
o`1@CPCo04Q<1?l0?TL5o`0e@`Go02dn1Ol09CT6o`0N=@So01L`2ol04R`Ro`0=9`co018/2Ol05c07
o`0N=@Oo02Di1_l0;Ch6o`0e@`Oo03i71_l0B4`6o`1@CPKo05E;1ol0FTP2o`1NA@Gooooo0Ol00001
ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00Coi6X0ommj0?oONP3oggX00_oKR003
omJF00?odJ<00_o=/003olRk00?o`L@00_n]_`03oi^j00;oR;H00omg/@02ofN]00?oEjP00_m8X`03
ocVO00;o;9X00olNUP03oa:A00;o1X`00ol0R0<3o`233@;o07hG0ol0NQl3o`1e9`?o074_0ol0K3D3
o`1W>`?o06=01?l0GTD3o`1JB0?o05E;1?l0D4h4o`18C0Co03i71_l0=D<4o`0]?PKo02Di1_l07SD9
o`0G<0co018/6ol03BL>o`0B;0[o01L`1ol07SD7o`0U>@Oo02dn1_l0=D<6o`0nA`Ko04Q<1_l0D4h6
o`1EB`So05Y80_l0GTD5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02oooo
o`04onAZ0?oONP3oggX0ommj00?ofhP00ooFUP02om6S00?ocK000_o8^`03ol7400?o[Kl00_nK^P03
ohRf00;oMk400omW[@02oeNX00?oB:<00_liW`03obbJ00?o7YH00_lBT@03o`J<00?o08P30_l0P`d3
o`1n5`?o07XO0ol0MBL3o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i51?l0FTP3o`1EB`Co051>1?l0B4`4
o`0nA`Go03E31Ol0;Ch6o`0U>@Ko01he2Ol05c0=o`0B;1So00dW3_l04R`:o`0G<0So01he1_l09CT7
o`0]?POo03E31_l0?TL6o`18C0Ko051>1_l0ED/8o`1JB0;o05i51Oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_ooool01?oTJP3oggX0ommj0?oONP03om^800?oeYH00_oAX`03
olf`00;ob;/00oo1a003ojfo00;oVkX00on8]P02ogNa00?oIjd00_mGZ003odRS00;o>Il00ol/VP03
oajF00;o4Y400ol6S003o`280`;o08<=0ol0OQL3o`1j7`?o07DW0ol0LBl3o`1/=@?o06Lk0ol0Hd03
o`1NA@Co05Y81?l0ED/4o`1@CPCo04Q<1?l0?TL4o`0e@`Ko02dn1_l09CT7o`0N=@Wo01L`3ol04R`?
o`0=9a;o018/2Ol05c08o`0N=@So02Di1_l0;Ch7o`0e@`Ko03i71_l0B4`6o`1@CPKo05E;2?l0FTP3
o`1NA@Gooooo0Ol00001ooooo`7ooooo000Fooooo`;o00000oooool2onAZ00?oggX00_oKR003omJF
00?odJ<00_o=/003olRk00;o`L@00on]_`03oi^j00;oR;H00omg/@02ofN]00?oEjP00_m8X`03ocVO
00?o;9X00_lNUP03oa:A00;o1X`00ol0R0<3o`233@?o07hG0ol0NQl3o`1e9`;o074_1?l0K3D3o`1W
>`?o06=00ol0GTD4o`1JB0?o05E;1?l0D4h4o`18C0Go03i71?l0=D<6o`0]?PGo02Di2?l07SD9o`0G
<2go018/2ol05c08o`0N=@Oo02Di1ol0;Ch6o`0e@`Ko03i71_l0B4`7o`1@CPKo05E;1ol0FTP4o`1N
A@Cooooo0_l00002ooooo`005_ooool00ol0003oooooooooo`02ooooo`;oi6X00ooONP02om^800?o
eYH00ooAX`02olf`00?ob;/00_o1a003ojfo00?oVkX00_n8]P03ogNa00;oIjd00omGZ002odRS00?o
>Il00ol/VP02oajF00?o4Y400ol6S002o`280`?o08<=0ol0OQL3o`1j7`?o07DW0_l0LBl4o`1/=@?o
06Lk0ol0Hd04o`1NA@?o05Y81?l0ED/3o`1@CPGo04Q<1Ol0?TL4o`0e@`Ko02dn1_l09CT8o`0N=@[o
01L`:?l04R`;o`0G<0Wo01he1ol09CT7o`0]?PKo03E31_l0?TL7o`18C0Ko051>1_l0ED/7o`1JB0Go
05i51Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2onAZ00?oggX0
0ooKR002omJF00?odJ<00oo=/002olRk00?o`L@00on]_`02oi^j00?oR;H00_mg/@03ofN]00;oEjP0
0om8X`03ocVO00;o;9X00olNUP02oa:A00?o1X`00ol0R0<3o`233@?o07hG0_l0NQl3o`1e9`?o074_
0ol0K3D4o`1W>`?o06=00ol0GTD4o`1JB0Co05E;0ol0D4h5o`18C0Co03i71Ol0=D<5o`0]?POo02Di
1ol07SD;o`0G<2Go018/3?l05c09o`0N=@Oo02Di1ol0;Ch6o`0e@`Oo03i71_l0B4`7o`1@CPKo05E;
1ol0FTP5o`1NA@Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_oT
JP03ommj00?ofhP00_oFUP03om6S00?ocK000_o8^`03ol7400?o[Kl00_nK^P03ohRf00;oMk400omW
[@02oeNX00?oB:<00oliW`02obbJ00?o7YH00olBT@02o`J<00?o08P30ol0P`d3o`1n5`?o07XO0_l0
MBL4o`1a;`;o06`e1?l0Ic/3o`1S@0?o05i51?l0FTP4o`1EB`Co051>1?l0B4`5o`0nA`Go03E31_l0
;Ch6o`0U>@So01he2ol05c0Qo`0B;0co01L`2Ol07SD8o`0U>@Oo02dn1ol0=D<6o`0nA`Ko04Q<1ol0
D4h6o`1EB`Oo05Y81_l0GTD5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02
ooooo`?oi6X00_oONP03om^800?oeYH00ooAX`02olf`00?ob;/00_o1a003ojfo00?oVkX00_n8]P03
ogNa00;oIjd00omGZ003odRS00;o>Il00ol/VP03oajF00;o4Y400ol6S003o`280`;o08<=0ol0OQL3
o`1j7`?o07DW0ol0LBl3o`1/=@Co06Lk0ol0Hd03o`1NA@Co05Y81?l0ED/4o`1@CPCo04Q<1Ol0?TL5
o`0e@`Go02dn1ol09CT8o`0N=@co01L`7?l04R`>o`0G<0Wo01he2?l09CT7o`0]?POo03E31ol0?TL6
o`18C0Ko051>1ol0ED/7o`1JB0Ko05i51Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool3onAZ00;oggX00ooKR003omJF00?odJ<00_o=/003olRk00;o`L@00on]_`03oi^j
00;oR;H00omg/@02ofN]00?oEjP00om8X`02ocVO00?o;9X00olNUP02oa:A00?o1X`00ol0R0<2o`23
3@Co07hG0_l0NQl4o`1e9`;o074_1?l0K3D3o`1W>`?o06=01?l0GTD4o`1JB0Co05E;1?l0D4h4o`18
C0Co03i71_l0=D<6o`0]?PKo02Di2_l07SD=o`0G<1?o018/4?l05c0:o`0N=@Wo02Di1ol0;Ch7o`0e
@`Oo03i71_l0B4`6o`1@CPOo05E;1ol0FTP7o`1NA@Gooooo0Ol00001ooooo`7ooooo000Fooooo`03
o`000?oooooooooo00;ooooo0ooTJP03ommj00?ofhP00_oFUP03om6S00?ocK000_o8^`03ol7400?o
[Kl00_nK^P03ohRf00;oMk400omW[@03oeNX00;oB:<00oliW`03obbJ00;o7YH00olBT@03o`J<00;o
08P30ol0P`d3o`1n5`?o07XO0ol0MBL3o`1a;`?o06`e1?l0Ic/3o`1S@0Co05i50ol0FTP4o`1EB`Co
051>1Ol0B4`4o`0nA`Go03E31_l0;Ch7o`0U>@[o01he5?l05c05o`0B;1Go01L`2_l07SD9o`0U>@Oo
02dn1ol0=D<7o`0nA`Ko04Q<1ol0D4h7o`1EB`Oo05Y81ol0GTD5ooooo`7o00000Oooool1ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`?oi6X00ooONP03om^800;oeYH00ooAX`03olf`00;ob;/0
0oo1a003ojfo00;oVkX00on8]P02ogNa00?oIjd00omGZ002odRS00?o>Il00ol/VP02oajF00?o4Y40
0ol6S002o`280`Co08<=0_l0OQL3o`1j7`?o07DW1?l0LBl2o`1/=@Co06Lk1?l0Hd03o`1NA@?o05Y8
1?l0ED/5o`1@CPGo04Q<1?l0?TL6o`0e@`Ko02dn2?l09CT:o`0N=BSo01L`3?l07SD8o`0U>@So02dn
1ol0=D<7o`0nA`Ko04Q<1ol0D4h7o`1EB`Oo05Y82?l0GTD5ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`03onQJ0?oTJP3oi6X000?oggX00ooKR003omJF00?odJ<00_o=
/003olRk00?o`L@00_n]_`03oi^j00;oR;H00omg/@03ofN]00;oEjP00om8X`03ocVO00;o;9X00olN
UP03oa:A00?o1X`00_l0R0<3o`233@?o07hG0ol0NQl3o`1e9`?o074_0ol0K3D4o`1W>`?o06=01?l0
GTD3o`1JB0Co05E;1Ol0D4h4o`18C0Go03i71_l0=D<6o`0]?POo02Di2ol07SDVo`0G<0co01he2?l0
9CT8o`0]?PSo03E31_l0?TL7o`18C0Ko051>1ol0ED/7o`1JB0Wo05i51Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool00ooXFP3oi6X0onAZ0003ommj00?ofhP00ooFUP03
om6S00;ocK000oo8^`03ol7400;o[Kl00onK^P02ohRf00?oMk400omW[@02oeNX00?oB:<00oliW`02
obbJ00?o7YH00olBT@03o`J<00?o08P30_l0P`d3o`1n5`?o07XO1?l0MBL2o`1a;`Co06`e0ol0Ic/3
o`1S@0Co05i51?l0FTP4o`1EB`Co051>1Ol0B4`5o`0nA`Ko03E31_l0;Ch9o`0U>@[o01he8Ol05c0<
o`0N=@[o02Di2?l0;Ch7o`0e@`Oo03i71ol0B4`6o`1@CPOo05E;1ol0FTP9o`1NA@03o`1S@?oooooo
oooo00?ooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00Coj5X0onAZ
0?oTJP3oi6X00ooONP03om^800;oeYH00ooAX`03olf`00?ob;/00_o1a003ojfo00;oVkX00on8]P03
ogNa00;oIjd00omGZ003odRS00;o>Il00ol/VP03oajF00?o4Y400_l6S003o`280`?o08<=0ol0OQL3
o`1j7`?o07DW0ol0LBl4o`1/=@?o06Lk0ol0Hd04o`1NA@Co05Y81?l0ED/4o`1@CPGo04Q<1Ol0?TL6
o`0e@`Ko02dn2Ol09CT=o`0N=A[o01L`3_l07SD:o`0U>@So02dn2?l0=D<6o`0nA`Oo04Q<1ol0D4h6
o`1EB`So05Y82?l0GTD2o`1S@0Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo
00;ooooo00Coj5X0onAZ0?oTJP3oi6X00ooONP03om^800;oeYH00ooAX`03olf`00?ob;/00_o1a003
ojfo00;oVkX00on8]P03ogNa00;oIjd00omGZ003odRS00;o>Il00ol/VP03oajF00?o4Y400ol6S002
o`280`?o08<=0ol0OQL4o`1j7`;o07DW1?l0LBl3o`1/=@?o06Lk1?l0Hd04o`1NA@Co05Y81?l0ED/4
o`1@CPGo04Q<1Ol0?TL6o`0e@`So02dn2?l09CTAo`0N=@oo01L`4?l07SD;o`0U>@Wo02dn1ol0=D<7
o`0nA`Oo04Q<1ol0D4h7o`1EB`Oo05Y82?l0GTD3o`1S@0Gooooo0Ol00001ooooo`7ooooo000Foooo
o`03o`000?oooooooooo00;ooooo0_oXFP02onAZ00?oggX00ooKR003omJF00?odJ<00_o=/003olRk
00?o`L@00on]_`02oi^j00?oR;H00_mg/@03ofN]00?oEjP00_m8X`03ocVO00?o;9X00olNUP02oa:A
00?o1X`00ol0R0<3o`233@?o07hG0ol0NQl3o`1e9`?o074_1?l0K3D3o`1W>`Co06=00ol0GTD4o`1J
B0Go05E;1?l0D4h5o`18C0Go03i71_l0=D<7o`0]?P[o02Di;Ol07SD;o`0U>@Wo02dn1ol0=D<7o`0n
A`Oo04Q<1ol0D4h7o`1EB`Oo05Y82?l0GTD4o`1S@0Gooooo0Ol00001ooooo`7ooooo000Fooooo`;o
00000oooool2onQJ00;oi6X00ooONP03om^800?oeYH00ooAX`02olf`00?ob;/00oo1a003ojfo00;o
VkX00on8]P02ogNa00?oIjd00omGZ002odRS00?o>Il00ol/VP03oajF00?o4Y400_l6S004o`280`;o
08<=1?l0OQL2o`1j7`Co07DW0ol0LBl3o`1/=@Co06Lk1?l0Hd03o`1NA@Co05Y81Ol0ED/4o`1@CPGo
04Q<1Ol0?TL8o`0e@`Oo02dn2ol09CTVo`0N=@co02Di2Ol0;Ch8o`0e@`Oo03i71ol0B4`7o`1@CPOo
05E;1ol0FTP9o`1NA@Co06=01?ooool2o`0000;ooooo000Fooooo`03o`000?oooooooooo00;ooooo
0_oXFP03onAZ00?oggX00ooKR003omJF00;odJ<00oo=/003olRk00?o`L@00_n]_`03oi^j00?oR;H0
0_mg/@03ofN]00?oEjP00_m8X`03ocVO00?o;9X00olNUP02oa:A00?o1X`00ol0R0<3o`233@?o07hG
0ol0NQl3o`1e9`Co074_0ol0K3D3o`1W>`Co06=01?l0GTD4o`1JB0Co05E;1Ol0D4h5o`18C0Go03i7
1ol0=D<8o`0]?P_o02Di8_l07SD>o`0U>@Wo02dn2?l0=D<7o`0nA`So04Q<1_l0D4h7o`1EB`So05Y8
2?l0GTD5o`1S@0Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_oX
FP03onAZ00?oggX00ooKR003omJF00;odJ<00oo=/003olRk00?o`L@00_n]_`03oi^j00?oR;H00_mg
/@03ofN]00?oEjP00_m8X`03ocVO00?o;9X00olNUP02oa:A00Co1X`00_l0R0<4o`233@;o07hG1?l0
NQl3o`1e9`?o074_1?l0K3D3o`1W>`Co06=00ol0GTD5o`1JB0Go05E;1?l0D4h6o`18C0Ko03i71_l0
=D<8o`0]?Pgo02Di6ol07SD>o`0U>@[o02dn2?l0=D<8o`0nA`Oo04Q<1ol0D4h7o`1EB`So05Y82?l0
GTD6o`1S@0Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0ooXFP03
onAZ00?oggX00_oKR003omJF00?odJ<00oo=/003olRk00;o`L@00on]_`03oi^j00;oR;H00omg/@03
ofN]00;oEjP00om8X`03ocVO00?o;9X00_lNUP03oa:A00?o1X`00ol0R0<3o`233@?o07hG0ol0NQl4
o`1e9`?o074_0ol0K3D4o`1W>`Co06=00ol0GTD5o`1JB0Co05E;1Ol0D4h5o`18C0Ko03i71ol0=D<9
o`0]?Poo02Di4_l07SDBo`0U>@[o02dn2?l0=D<8o`0nA`Oo04Q<1ol0D4h8o`1EB`Oo05Y82?l0GTD7
o`1S@0Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0ooXFP03onAZ
00?oggX00_oKR003omJF00?odJ<00oo=/003olRk00;o`L@00on]_`03oi^j00;oR;H00omg/@03ofN]
00?oEjP00_m8X`03ocVO00?o;9X00_lNUP04oa:A00;o1X`01?l0R0<2o`233@Co07hG0ol0NQl3o`1e
9`Co074_0ol0K3D3o`1W>`Co06=01?l0GTD4o`1JB0Ko05E;1?l0D4h6o`18C0Ko03i72?l0=D<:o`0]
?Rco02Di2_l0;Ch:o`0e@`So03i71ol0B4`7o`1@CPOo05E;2?l0FTP8o`1NA@So06=01Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool3onQJ00?oi6X00ooONP03om^800?o
eYH00ooAX`02olf`00?ob;/00oo1a003ojfo00;oVkX00on8]P03ogNa00?oIjd00_mGZ003odRS00?o
>Il00ol/VP02oajF00?o4Y400ol6S003o`280`?o08<=0ol0OQL4o`1j7`?o07DW0ol0LBl4o`1/=@?o
06Lk1?l0Hd04o`1NA@Co05Y81Ol0ED/5o`1@CPGo04Q<1ol0?TL7o`0e@`_o02dn:?l09CT<o`0]?P[o
03E32?l0?TL7o`18C0Oo051>2?l0ED/7o`1JB0So05i52Ol0Hd05ooooo`7o00000Oooool1ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`?oj5X00ooTJP03ommj00?ofhP00ooFUP03om6S00;ocK00
0oo8^`03ol7400?o[Kl00_nK^P03ohRf00?oMk400omW[@02oeNX00?oB:<00oliW`03obbJ00?o7YH0
0_lBT@04o`J<00;o08P31?l0P`d3o`1n5`?o07XO1?l0MBL3o`1a;`?o06`e1?l0Ic/4o`1S@0Co05i5
1?l0FTP6o`1EB`Co051>1_l0B4`8o`0nA`So03E32ol0;ChQo`0U>@co02dn2_l0=D<9o`0nA`Oo04Q<
2?l0D4h7o`1EB`So05Y82?l0GTD:o`1S@0Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oo
oooooooo00;ooooo00CokDX0onQJ0?oXFP3oj5X00ooTJP03ommj00?ofhP00ooFUP02om6S00?ocK00
0oo8^`03ol7400;o[Kl00onK^P03ohRf00?oMk400_mW[@03oeNX00?oB:<00oliW`03obbJ00;o7YH0
0olBT@03o`J<00?o08P30ol0P`d4o`1n5`?o07XO0ol0MBL4o`1a;`?o06`e1?l0Ic/4o`1S@0Co05i5
1?l0FTP5o`1EB`Go051>1_l0B4`7o`0nA`Wo03E33Ol0;ChJo`0U>@oo02dn2_l0=D<9o`0nA`Oo04Q<
2?l0D4h8o`1EB`Oo05Y82?l0GTD:o`1S@003o`1W>ooooooooooo00?ooooo0Ol00001ooooo`7ooooo
000Fooooo`03o`000?oooooooooo00;ooooo00CokDX0onQJ0?oXFP3oj5X00ooTJP03ommj00?ofhP0
0ooFUP02om6S00?ocK000oo8^`03ol7400;o[Kl00onK^P03ohRf00?oMk400_mW[@03oeNX00?oB:<0
0oliW`03obbJ00?o7YH00olBT@02o`J<00Co08P30ol0P`d3o`1n5`Co07XO0ol0MBL3o`1a;`Co06`e
1?l0Ic/4o`1S@0Co05i51?l0FTP6o`1EB`Go051>1ol0B4`6o`0nA`[o03E34Ol0;Ch;o`0U>ACo02dn
2_l0=D<:o`0nA`So04Q<2?l0D4h7o`1EB`So05Y82?l0GTD:o`1S@0;o06Lk1Oooool1o`00007ooooo
0Oooool000kooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo00CokDX0onQJ0?oXFP3oj5X0
0ooTJP03ommj00?ofhP00ooFUP03om6S00?ocK000oo8^`02ol7400?o[Kl00onK^P03ohRf00?oMk40
0_mW[@03oeNX00?oB:<00oliW`03obbJ00?o7YH00_lBT@03o`J<00Co08P30ol0P`d3o`1n5`?o07XO
1?l0MBL3o`1a;`Co06`e1?l0Ic/4o`1S@0Co05i51?l0FTP5o`1EB`Ko051>1_l0B4`7o`0nA`_o03E3
;?l0;Ch;o`0e@`[o03i72?l0B4`8o`1@CPSo05E;1ol0FTP8o`1NA@[o06=00ol0Ic/5ooooo`7o0000
0Oooool1ooooo`003Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
0_ooool01?o]BP3oj5X0onQJ0?oXFP03onAZ00?oggX00ooKR003omJF00?odJ<00oo=/003olRk00?o
`L@00_n]_`03oi^j00?oR;H00omg/@03ofN]00;oEjP00om8X`03ocVO00?o;9X00olNUP03oa:A00?o
1X`00ol0R0<3o`233@Co07hG0ol0NQl3o`1e9`Co074_1?l0K3D4o`1W>`Co06=01?l0GTD5o`1JB0Go
05E;1_l0D4h6o`18C0So03i72ol0=D<Uo`0]?Pco03E32_l0?TL9o`18C0So051>2?l0ED/8o`1JB0So
05i52_l0Hd04o`1W>`Gooooo0Ol00001ooooo`7ooooo000Aooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool2one:00?oj5X00ooTJP03ommj00?ofhP00ooFUP03om6S00?ocK00
0oo8^`02ol7400?o[Kl00onK^P03ohRf00;oMk400omW[@03oeNX00?oB:<00oliW`03obbJ00?o7YH0
0olBT@03o`J<00?o08P30ol0P`d3o`1n5`Co07XO0ol0MBL4o`1a;`?o06`e1?l0Ic/4o`1S@0Go05i5
1Ol0FTP5o`1EB`Ko051>1_l0B4`9o`0nA`co03E37ol0;Ch>o`0e@`[o03i72Ol0B4`8o`1@CPSo05E;
2?l0FTP8o`1NA@[o06=01Ol0Ic/5ooooo`7o00000Oooool1ooooo`004Oooool00ol0003ooooooooo
o`02ooooo`?o00000_ooool2one:00?oj5X00ooTJP03ommj00?ofhP00ooFUP03om6S00?ocK000oo8
^`02ol7400?o[Kl00onK^P03ohRf00?oMk400_mW[@03oeNX00?oB:<00oliW`03obbJ00?o7YH00olB
T@03o`J<00?o08P31?l0P`d3o`1n5`?o07XO1?l0MBL4o`1a;`Co06`e1?l0Ic/4o`1S@0Co05i51_l0
FTP4o`1EB`Oo051>1ol0B4`:o`0nA`go03E35Ol0;Ch@o`0e@`_o03i72Ol0B4`8o`1@CPSo05E;2?l0
FTP9o`1NA@Wo06=01ol0Ic/3ooooo`?o00000_ooool000gooooo1?l00005ooooo`03o`000?oooooo
oooo00;ooooo0_o]BP04onQJ00?oi6X00ooONP03om^800?oeYH00ooAX`02olf`00?ob;/00oo1a003
ojfo00?oVkX00on8]P02ogNa00?oIjd00omGZ003odRS00?o>Il00ol/VP03oajF00?o4Y400ol6S003
o`280`?o08<=1?l0OQL3o`1j7`Co07DW0ol0LBl4o`1/=@Co06Lk1?l0Hd05o`1NA@Go05Y81Ol0ED/7
o`1@CPOo04Q<2_l0?TL_o`0e@`co03i72Ol0B4`8o`1@CPSo05E;2?l0FTP9o`1NA@Wo06=02?l0Ic/5
ooooo`7o00000Oooool1ooooo`003Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo0_o]BP04onQJ00?oi6X00ooONP03om^800?oeYH00ooAX`03olf`00;ob;/00oo1a003ojfo
00?oVkX00on8]P02ogNa00CoIjd00_mGZ003odRS00?o>Il00ol/VP03oajF00Co4Y400_l6S004o`28
0`?o08<=0ol0OQL4o`1j7`Co07DW1?l0LBl4o`1/=@Co06Lk1?l0Hd04o`1NA@Ko05Y81_l0ED/6o`1@
CPSo04Q<2ol0?TLWo`0e@`co03i72_l0B4`:o`1@CPSo05E;2?l0FTP8o`1NA@[o06=02Ol0Ic/5oooo
o`7o00000Oooool1ooooo`003Oooool5o`0000Cooooo00?o0000ooooooooool00_ooool3one:00?o
j5X00ooTJP03ommj00CofhP00_oFUP03om6S00?ocK000oo8^`03ol7400?o[Kl00onK^P03ohRf00;o
Mk400omW[@03oeNX00?oB:<00oliW`03obbJ00?o7YH00olBT@03o`J<00?o08P31?l0P`d3o`1n5`Co
07XO0ol0MBL4o`1a;`Co06`e1?l0Ic/4o`1S@0Go05i51Ol0FTP6o`1EB`Oo051>2?l0B4`<o`0nAb;o
03E33_l0?TL:o`18C0[o051>2?l0ED/8o`1JB0So05i52_l0Hd0:o`1W>`Gooooo0Ol00001ooooo`7o
oooo000Fooooo`03o`000?oooooooooo00;ooooo0oo]BP03onQJ00?oi6X00ooONP04om^800;oeYH0
0ooAX`03olf`00?ob;/00oo1a003ojfo00?oVkX00on8]P03ogNa00;oIjd01?mGZ002odRS00Co>Il0
0_l/VP04oajF00;o4Y401?l6S003o`280`?o08<=1?l0OQL4o`1j7`Co07DW0ol0LBl4o`1/=@Go06Lk
1?l0Hd05o`1NA@Go05Y81_l0ED/8o`1@CPSo04Q<3ol0?TLGo`0e@a3o03i72_l0B4`:o`1@CPWo05E;
2Ol0FTP8o`1NA@[o06=02ol0Ic/5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`CokDX00ooXFP03onAZ00?oggX00ooKR003omJF00?odJ<00oo=/003olRk00?o`L@00on]
_`03oi^j00?oR;H00_mg/@03ofN]00?oEjP00om8X`03ocVO00?o;9X00olNUP03oa:A00Co1X`00ol0
R0<3o`233@Co07hG0ol0NQl4o`1e9`Co074_1?l0K3D4o`1W>`Go06=01Ol0GTD5o`1JB0Ko05E;2?l0
D4h9o`18C3;o03i72ol0B4`:o`1@CPWo05E;2Ol0FTP8o`1NA@[o06=03?l0Ic/5ooooo`7o00000Ooo
ool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`CokDX00ooXFP03onAZ00?oggX00ooKR003
omJF00?odJ<00oo=/003olRk00?o`L@00on]_`03oi^j00?oR;H00omg/@03ofN]00;oEjP01?m8X`02
ocVO00Co;9X00olNUP03oa:A00Co1X`00_l0R0<4o`233@Co07hG1?l0NQl3o`1e9`Co074_1Ol0K3D4
o`1W>`Co06=01_l0GTD6o`1JB0Ko05E;2?l0D4h:o`18C2[o03i73?l0B4`:o`1@CP[o05E;2?l0FTP:
o`1NA@Wo06=03Ol0Ic/00ol0K3Goooooooooo`03ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02ooooo`04oo8h0?o]BP3okDX0one:00Coj5X00ooTJP03ommj00?ofhP00ooFUP03
om6S00?ocK000oo8^`03ol7400?o[Kl00onK^P03ohRf00?oMk400_mW[@03oeNX00?oB:<00oliW`03
obbJ00Co7YH00olBT@03o`J<00?o08P31?l0P`d3o`1n5`Co07XO1?l0MBL4o`1a;`Co06`e1?l0Ic/5
o`1S@0Go05i51_l0FTP7o`1EB`So051>3?l0B4`To`0nA`ko04Q<2_l0D4h:o`1EB`So05Y82_l0GTD9
o`1S@0co06Lk0ol0K3D5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02oooo
o`04oo8h0?o]BP3okDX0one:00Coj5X00ooTJP03ommj00?ofhP00ooFUP03om6S00?ocK000oo8^`03
ol7400?o[Kl00onK^P03ohRf00?oMk400omW[@03oeNX00?oB:<00oliW`03obbJ00?o7YH01?lBT@03
o`J<00?o08P31?l0P`d4o`1n5`?o07XO1?l0MBL4o`1a;`Go06`e1?l0Ic/5o`1S@0Go05i51ol0FTP7
o`1EB`[o051>3Ol0B4`Io`0nAa3o04Q<2_l0D4h:o`1EB`[o05Y82?l0GTD:o`1S@0co06Lk1Ol0K3D5
ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;olSP00oo]BP03onQJ
00Coi6X00ooONP03om^800?oeYH00ooAX`03olf`00?ob;/00oo1a003ojfo00?oVkX00on8]P03ogNa
00?oIjd00omGZ003odRS00?o>Il00ol/VP03oajF00?o4Y401?l6S003o`280`?o08<=1?l0OQL4o`1j
7`Co07DW1?l0LBl4o`1/=@Go06Lk1Ol0Hd05o`1NA@Oo05Y81ol0ED/:o`1@CQKo04Q<1?l0?TLHo`18
C0co051>2_l0ED/:o`1JB0So05i52_l0Hd0<o`1W>`Ko06`e1Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool2oo8h00?okDX00ooXFP04onAZ00?oggX00ooKR003omJF00?o
dJ<00oo=/003olRk00?o`L@00on]_`03oi^j00?oR;H00omg/@03ofN]00?oEjP00om8X`03ocVO00?o
;9X01?lNUP03oa:A00?o1X`01?l0R0<4o`233@?o07hG1?l0NQl4o`1e9`Go074_1?l0K3D4o`1W>`Ko
06=01_l0GTD6o`1JB0So05E;2ol0D4h[o`18C0co051>2_l0ED/:o`1JB0[o05i52_l0Hd0;o`1W>`So
06`e1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2oo8h00CokDX0
0ooXFP03onAZ00CoggX00ooKR003omJF00?odJ<00oo=/003olRk00?o`L@00on]_`03oi^j00?oR;H0
0omg/@03ofN]00?oEjP00om8X`03ocVO00?o;9X00olNUP04oa:A00?o1X`01?l0R0<3o`233@Co07hG
1?l0NQl4o`1e9`Co074_1?l0K3D5o`1W>`Go06=01_l0GTD7o`1JB0Wo05E;3?l0D4hTo`18C0oo051>
2_l0ED/:o`1JB0[o05i52Ol0Hd0<o`1W>`Wo06`e1Oooool1o`00007ooooo0Oooool001Kooooo0_l0
0003ooooo`;olSP01?o]BP03onQJ00?oi6X01?oONP03om^800?oeYH00ooAX`03olf`00?ob;/00oo1
a003ojfo00?oVkX00on8]P03ogNa00?oIjd00omGZ004odRS00;o>Il01?l/VP03oajF00?o4Y401?l6
S004o`280`?o08<=1?l0OQL4o`1j7`Co07DW1Ol0LBl4o`1/=@Ko06Lk1Ol0Hd07o`1NA@Ko05Y82_l0
ED/=o`1@CQWo04Q<4?l0D4h<o`1EB`[o05Y82_l0GTD:o`1S@0co06Lk2ol0K3D4ooooo`;o00000_oo
ool001Kooooo00?o0000ooooooooool00_ooool3oo8h00?okDX01?oXFP03onAZ00?oggX01?oKR003
omJF00?odJ<00oo=/003olRk00?o`L@00on]_`03oi^j00?oR;H00omg/@03ofN]00?oEjP00om8X`03
ocVO00Co;9X00olNUP03oa:A00Co1X`00ol0R0<4o`233@Co07hG1?l0NQl4o`1e9`Co074_1Ol0K3D5
o`1W>`Ko06=01_l0GTD7o`1JB0[o05E;=?l0D4h<o`1EB`[o05Y82_l0GTD:o`1S@0co06Lk3?l0K3D5
ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`ColSP00oo]BP03onQJ
00Coi6X00ooONP03om^800CoeYH00ooAX`03olf`00?ob;/00oo1a003ojfo00?oVkX00on8]P03ogNa
00?oIjd00omGZ004odRS00?o>Il00ol/VP03oajF00Co4Y400ol6S004o`280`Co08<=1?l0OQL4o`1j
7`Co07DW1?l0LBl5o`1/=@Go06Lk1_l0Hd08o`1NA@So05Y82Ol0ED/[o`1@CPko05E;2_l0FTP:o`1N
A@[o06=03?l0Ic/?o`1/=@Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;o
oooo1?ob>003one:00Coj5X00ooTJP03ommj00CofhP00ooFUP03om6S00?ocK000oo8^`03ol7400?o
[Kl00onK^P03ohRf00?oMk400omW[@04oeNX00?oB:<00oliW`04obbJ00?o7YH00olBT@04o`J<00Co
08P30ol0P`d4o`1n5`Co07XO1Ol0MBL5o`1a;`Co06`e1_l0Ic/6o`1S@0So05i52?l0FTP;o`1EBb?o
051>3ol0ED/;o`1JB0[o05i52ol0Hd0;o`1W>a7o06`e1Oooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool00_ooool4oo8h00CokDX00ooXFP04onAZ00?oggX00ooKR003omJF00CodJ<0
0oo=/003olRk00?o`L@00on]_`03oi^j00?oR;H00omg/@03ofN]00CoEjP00om8X`03ocVO00Co;9X0
0olNUP03oa:A00Co1X`01?l0R0<4o`233@Co07hG1?l0NQl4o`1e9`Go074_1Ol0K3D6o`1W>`Ko06=0
2?l0GTD8o`1JB0oo05E;5ol0D4hBo`1EB`co05Y82_l0GTD<o`1S@0[o06Lk4_l0K3D00ol0LBoooooo
ooooo`03ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`ColSP01?o]
BP03onQJ00Coi6X00ooONP03om^800CoeYH00ooAX`03olf`00?ob;/00oo1a003ojfo00?oVkX01?n8
]P03ogNa00?oIjd00omGZ003odRS00Co>Il00ol/VP03oajF00Co4Y401?l6S003o`280`Co08<=1?l0
OQL5o`1j7`Co07DW1Ol0LBl6o`1/=@Ko06Lk1_l0Hd08o`1NA@[o05Y8<?l0ED/>o`1JB0[o05i52ol0
Hd0<o`1W>a7o06`e0ol0LBl5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02
ooooo`03ooHV0?ob>03olSP000;olSP01?o]BP03onQJ00Coi6X00ooONP03om^800CoeYH00ooAX`03
olf`00?ob;/00oo1a003ojfo00?oVkX01?n8]P03ogNa00?oIjd00omGZ003odRS00Co>Il00ol/VP03
oajF00Co4Y401?l6S004o`280`Co08<=1?l0OQL4o`1j7`Co07DW1_l0LBl5o`1/=@Ko06Lk1ol0Hd08
o`1NA@_o05Y8:Ol0ED/@o`1JB0[o05i53?l0Hd0<o`1W>a3o06`e1Ol0LBl5ooooo`7o00000Oooool1
ooooo`005_ooool00ol0003oooooooooo`02ooooo`03ooHV0?ob>03olSP000;olSP01?o]BP03onQJ
00Coi6X00ooONP03om^800CoeYH00ooAX`03olf`00?ob;/00oo1a003ojfo00CoVkX00on8]P03ogNa
00?oIjd00omGZ004odRS00?o>Il01?l/VP03oajF00Co4Y401?l6S003o`280`Co08<=1Ol0OQL4o`1j
7`Go07DW1Ol0LBl5o`1/=@Ko06Lk2?l0Hd08o`1NA@go05Y88Ol0ED/@o`1JB0co05i53?l0Hd0;o`1W
>`oo06`e2Ol0LBl5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;o
mRH01?ob>004one:00?oj5X00ooTJP04ommj00?ofhP00ooFUP04om6S00?ocK000oo8^`03ol7400?o
[Kl01?nK^P03ohRf00?oMk400omW[@03oeNX00CoB:<00oliW`04obbJ00?o7YH01?lBT@04o`J<00Co
08P31?l0P`d4o`1n5`Co07XO1_l0MBL4o`1a;`Ko06`e1_l0Ic/8o`1S@0[o05i54Ol0FTPCo`1EBaCo
05Y83?l0GTD<o`1S@0co06Lk3_l0K3D;o`1a;`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`00
0?oooooooooo00;ooooo0_of9P04oo8h00CokDX00ooXFP04onAZ00?oggX00ooKR004omJF00?odJ<0
0oo=/003olRk00?o`L@01?n]_`03oi^j00?oR;H01?mg/@03ofN]00?oEjP01?m8X`03ocVO00?o;9X0
1?lNUP04oa:A00Co1X`00ol0R0<5o`233@Co07hG1Ol0NQl4o`1e9`Ko074_1_l0K3D6o`1W>`So06=0
2ol0GTDao`1JB0ko05i52ol0Hd0<o`1W>`oo06`e3Ol0LBl5ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`;omRH01?ob>004one:00Coj5X01?oTJP03ommj00?ofhP01?oF
UP03om6S00?ocK000oo8^`03ol7400Co[Kl00onK^P03ohRf00CoMk400omW[@03oeNX00CoB:<00oli
W`03obbJ00Co7YH01?lBT@04o`J<00Co08P31?l0P`d4o`1n5`Go07XO1Ol0MBL6o`1a;`Ko06`e1_l0
Ic/:o`1S@0_o05i5:Ol0FTP>o`1NA@ko06=03?l0Ic/>o`1/=@oo074_1Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool3ooHV00ColSP00oo]BP04onQJ00Coi6X00ooONP03
om^800CoeYH00ooAX`03olf`00?ob;/01?o1a003ojfo00?oVkX01?n8]P03ogNa00?oIjd01?mGZ003
odRS00Co>Il00ol/VP04oajF00Co4Y401?l6S004o`280`Co08<=1Ol0OQL4o`1j7`Ko07DW1_l0LBl6
o`1/=@So06Lk2?l0Hd0=o`1NAAoo05Y84_l0GTD<o`1S@0go06Lk3_l0K3DBo`1a;`Gooooo0Ol00001
ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0oof9P04oo8h00CokDX01?oXFP03onAZ
00CoggX00ooKR004omJF00?odJ<00oo=/003olRk00Co`L@00on]_`03oi^j00CoR;H00omg/@03ofN]
00CoEjP00om8X`04ocVO00?o;9X01?lNUP04oa:A00Co1X`01?l0R0<4o`233@Go07hG1Ol0NQl5o`1e
9`Ko074_1ol0K3D8o`1W>`[o06=04ol0GTD=o`1JB1Ko05i53_l0Hd0<o`1W>a3o06`e4ol0LBl5oooo
o`7o00000Oooool1ooooo`005_ooool2o`0000?ooooo0oof9P04oo8h00CokDX01?oXFP04onAZ00?o
ggX00ooKR004omJF00?odJ<00oo=/004olRk00?o`L@00on]_`04oi^j00?oR;H00omg/@04ofN]00?o
EjP01?m8X`03ocVO00Co;9X01?lNUP04oa:A00Co1X`01?l0R0<5o`233@Co07hG1Ol0NQl5o`1e9`Ko
074_2?l0K3D8o`1W>`_o06=0;ol0GTD@o`1S@0co06Lk3_l0K3DGo`1a;`Cooooo0_l00002ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`ComRH01?ob>004one:00Coj5X00ooTJP04ommj00?ofhP0
1?oFUP03om6S00?ocK001?o8^`03ol7400?o[Kl01?nK^P03ohRf00?oMk401?mW[@03oeNX00CoB:<0
0oliW`04obbJ00Co7YH01?lBT@04o`J<00Co08P31Ol0P`d5o`1n5`Co07XO1_l0MBL6o`1a;`So06`e
2?l0Ic/=o`1S@2Oo05i54?l0Hd0>o`1W>`ko06`e6Ol0LBl5ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`ComRH01?ob>004one:00Coj5X00ooTJP04ommj00CofhP00ooF
UP03om6S00CocK000oo8^`03ol7400Co[Kl00onK^P03ohRf00CoMk401?mW[@03oeNX00?oB:<01?li
W`04obbJ00Co7YH01?lBT@04o`J<00Go08P31?l0P`d5o`1n5`Go07XO1_l0MBL6o`1a;`So06`e2_l0
Ic/?o`1S@1_o05i54ol0Hd0?o`1W>`ko06`e6ol0LBl5ooooo`7o00000Oooool1ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`ComRH01Oob>004one:00Coj5X00ooTJP04ommj00CofhP00ooFUP03
om6S00CocK000oo8^`03ol7400Co[Kl00onK^P03ohRf00CoMk401?mW[@03oeNX00?oB:<01?liW`04
obbJ00Co7YH01?lBT@04o`J<00Go08P31Ol0P`d4o`1n5`Ko07XO1_l0MBL6o`1a;`So06`e2ol0Ic/g
o`1S@0ko06Lk4?l0K3DMo`1a;`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo
00;ooooo1Oof9P04oo8h00CokDX01?oXFP03onAZ00CoggX01?oKR003omJF00CodJ<00oo=/003olRk
00Co`L@00on]_`03oi^j00CoR;H01?mg/@03ofN]00CoEjP00om8X`04ocVO00Co;9X01?lNUP04oa:A
00Go1X`01?l0R0<5o`233@Go07hG1_l0NQl6o`1e9`So074_2?l0K3D;o`1W>boo06=04?l0Ic/>o`1/
=AKo074_2ol0MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`03
oo/C0?of9P3omRH000;omRH01Oob>004one:00Coj5X00ooTJP04ommj00?ofhP01?oFUP04om6S00?o
cK000oo8^`04ol7400?o[Kl00onK^P04ohRf00CoMk400omW[@04oeNX00?oB:<01?liW`04obbJ00Co
7YH01?lBT@05o`J<00Go08P31?l0P`d6o`1n5`Ko07XO1_l0MBL8o`1a;`So06`e3Ol0Ic/Uo`1S@1;o
06Lk4?l0K3DDo`1a;`oo07DW1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool00ook4`3omRH0ooHV0002ooHV00GolSP01?o]BP04onQJ00?oi6X01?oONP04om^800?oeYH0
1?oAX`03olf`00Cob;/00oo1a004ojfo00?oVkX01?n8]P03ogNa00CoIjd00omGZ004odRS00Co>Il0
1?l/VP04oajF00Go4Y401?l6S004o`280`Ko08<=1Ol0OQL7o`1j7`Ko07DW2?l0LBl:o`1/=A7o06Lk
5Ol0Hd0Fo`1W>a3o06`e5?l0LBlCo`1e9`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oo
oooooooo00;ooooo00?ona<0ooHV0?of9P000oof9P04oo8h00CokDX01?oXFP04onAZ00CoggX01?oK
R003omJF00CodJ<00oo=/004olRk00?o`L@01?n]_`03oi^j00CoR;H00omg/@04ofN]00?oEjP01?m8
X`04ocVO00Co;9X01?lNUP05oa:A00Co1X`01Ol0R0<6o`233@Co07hG1ol0NQl7o`1e9`So074_2ol0
K3Deo`1W>a;o06`e4_l0LBlGo`1e9`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooo
oooo00;ooooo00?ona<0ooHV0?of9P000oof9P05oo8h00CokDX01?oXFP03onAZ00CoggX01?oKR003
omJF00CodJ<01?o=/003olRk00?o`L@01?n]_`04oi^j00?oR;H01?mg/@04ofN]00?oEjP01?m8X`04
ocVO00Co;9X01OlNUP04oa:A00Co1X`01_l0R0<4o`233@Ko07hG2?l0NQl6o`1e9`[o074_2ol0K3D]
o`1W>a;o06`e4ol0LBlJo`1e9`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo
00;ooooo0_ok4`05ooHV00ColSP01Oo]BP04onQJ00?oi6X01?oONP04om^800?oeYH01?oAX`04olf`
00?ob;/00oo1a004ojfo00CoVkX00on8]P04ogNa00CoIjd00omGZ004odRS00Co>Il01?l/VP05oajF
00Co4Y401Ol6S005o`280`Go08<=1_l0OQL8o`1j7`Ko07DW2_l0LBl?o`1/=B7o06Lk5?l0K3DDo`1a
;ago07DW1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2oo/C00Go
mRH01?ob>005one:00Coj5X00ooTJP04ommj00CofhP01?oFUP03om6S00CocK000oo8^`04ol7400Co
[Kl00onK^P04ohRf00CoMk400omW[@04oeNX00CoB:<01?liW`05obbJ00Co7YH01?lBT@06o`J<00Co
08P31_l0P`d6o`1n5`So07XO2?l0MBL9o`1a;aKo06`e3Ol0Ic/Jo`1/=ACo074_8Ol0MBL5ooooo`7o
00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;ona<01_of9P04oo8h00CokDX0
1?oXFP04onAZ00CoggX01?oKR004omJF00?odJ<01?o=/003olRk00Co`L@01?n]_`03oi^j00CoR;H0
1?mg/@03ofN]00CoEjP01?m8X`04ocVO00Go;9X01?lNUP05oa:A00Go1X`01Ol0R0<6o`233@Ko07hG
2?l0NQl8o`1e9`_o074_=Ol0K3DDo`1a;bGo07DW1Oooool1o`00007ooooo0Oooool001Kooooo0_l0
0003ooooo`?ona<01Oof9P04oo8h00GokDX01?oXFP04onAZ00CoggX00ooKR004omJF00CodJ<00oo=
/004olRk00Co`L@00on]_`04oi^j00CoR;H00omg/@04ofN]00CoEjP01?m8X`05ocVO00Co;9X01?lN
UP05oa:A00Go1X`01_l0R0<6o`233@Ko07hG2?l0NQl:o`1e9`go074_:ol0K3DDo`1a;bWo07DW1?oo
ool2o`0000;ooooo000Fooooo`03o`000?oooooooooo00;ooooo0ook4`05ooHV00GolSP01?o]BP05
onQJ00Coi6X01?oONP03om^800CoeYH01?oAX`03olf`00Cob;/01?o1a003ojfo00CoVkX01?n8]P03
ogNa00CoIjd01?mGZ004odRS00Go>Il01?l/VP05oajF00Co4Y401_l6S006o`280`Ko08<=1_l0OQL8
o`1j7`[o07DW4Ol0LBlMo`1/=ASo074_;Ol0MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02ooooo`?ona<01Oof9P05oo8h00CokDX01OoXFP04onAZ00CoggX00ooKR004omJF
00CodJ<01?o=/004olRk00?o`L@01?n]_`04oi^j00?oR;H01?mg/@04ofN]00CoEjP01Om8X`04ocVO
00Co;9X01OlNUP05oa:A00Ko1X`01Ol0R0<7o`233@Ko07hG2_l0NQl9o`1e9coo074_7_l0MBL7o`1j
7`co07DW1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool4oo/C00Go
mRH01Oob>004one:00Coj5X01OoTJP03ommj00CofhP01?oFUP04om6S00CocK001?o8^`03ol7400Co
[Kl01?nK^P03ohRf00CoMk401?mW[@04oeNX00GoB:<01?liW`05obbJ00Co7YH01_lBT@05o`J<00Go
08P32?l0P`d8o`1n5`So07XO3Ol0MBLeo`1a;a[o07DW4ol0NQl8o`1e9`Gooooo0Ol00001ooooo`7o
oooo000Fooooo`03o`000?oooooooooo00;ooooo1?ok4`05ooHV00GolSP01?o]BP05onQJ00Coi6X0
1?oONP04om^800CoeYH00ooAX`04olf`00Cob;/01?o1a003ojfo00CoVkX01?n8]P04ogNa00CoIjd0
1OmGZ004odRS00Co>Il01Ol/VP05oajF00Go4Y401Ol6S006o`280`So08<=2?l0OQL:o`1j7`go07DW
:ol0LBlLo`1e9aWo07XO1_l0MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`Cona<01_of9P05oo8h00CokDX01OoXFP04onAZ00CoggX01?oKR004omJF00?odJ<01?o=
/004olRk00Co`L@00on]_`04oi^j00CoR;H01?mg/@04ofN]00GoEjP01?m8X`05ocVO00Co;9X01OlN
UP05oa:A00Ko1X`01_l0R0<8o`233@So07hG2Ol0NQlDo`1e9aWo074_8?l0MBLQo`1j7`Co07DW1Ooo
ool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool4oo/C00KomRH01Oob>004
one:00Goj5X01?oTJP04ommj00CofhP01?oFUP04om6S00CocK000oo8^`04ol7400Co[Kl01?nK^P04
ohRf00CoMk401?mW[@05oeNX00CoB:<01OliW`05obbJ00Co7YH01_lBT@06o`J<00Ko08P32?l0P`d:
o`1n5`_o07XO@Ol0MBLWo`1j7`Co07DW1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool5oo/C00GomRH01_ob>004one:00Goj5X01?oTJP04ommj00CofhP01?oFUP04om6S
00CocK000oo8^`04ol7400Co[Kl01?nK^P04ohRf00CoMk401?mW[@05oeNX00GoB:<01?liW`05obbJ
00Go7YH01_lBT@06o`J<00Ko08P32?l0P`d:o`1n5`go07XO=ol0MBL^o`1j7`?o07DW1Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool5oo/C00KomRH01Oob>004one:00Go
j5X01?oTJP04ommj00CofhP01?oFUP04om6S00CocK001?o8^`04ol7400Co[Kl01?nK^P04ohRf00Co
Mk401OmW[@04oeNX00CoB:<01_liW`04obbJ00Ko7YH01_lBT@06o`J<00Ko08P32_l0P`d9o`1n5a3o
07XO:Ol0MBLfo`1j7`?o07DW1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool6oo/C00GomRH01Oob>005one:00Goj5X01?oTJP04ommj00CofhP01?oFUP04om6S00CocK00
1?o8^`04ol7400Co[Kl01?nK^P04ohRf00CoMk401OmW[@04oeNX00GoB:<01OliW`05obbJ00Ko7YH0
1_lBT@06o`J<00So08P32?l0P`d;o`1n5aCo07XO6Ol0MBLoo`1j7`;o07DW1Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool00_ooool6oo/C00GomRH01Oob>005one:00Goj5X01?oT
JP05ommj00CofhP01?oFUP04om6S00CocK001?o8^`04ol7400Co[Kl01?nK^P04ohRf00GoMk401?mW
[@04oeNX00GoB:<01OliW`06obbJ00Go7YH01olBT@06o`J<00So08P32?l0P`d=o`1n5fSo07XO0_l0
MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`Kona<01_of9P05
oo8h00GokDX01OoXFP04onAZ00GoggX01?oKR004omJF00CodJ<01?o=/004olRk00Co`L@01?n]_`04
oi^j00CoR;H01Omg/@04ofN]00GoEjP01?m8X`06ocVO00Go;9X01OlNUP07oa:A00Oo1X`02?l0R0<:
o`233@go07hG@Ol0NQlAo`1n5a;o07XO0_l0MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02ooooo`Kona<01_of9P05oo8h00GokDX01OoXFP04onAZ00GoggX01?oKR004omJF
00CodJ<01?o=/005olRk00Co`L@01?n]_`04oi^j00CoR;H01Omg/@04ofN]00GoEjP01Om8X`05ocVO
00Go;9X01_lNUP08oa:A00Ko1X`02?l0R0<;o`233A3o07hG<Ol0NQlOo`1n5`ko07XO0_l0MBL5oooo
o`7o00000Oooool1ooooo`005_ooool2o`0000?ooooo1_ok4`07ooHV00GolSP01Oo]BP05onQJ00Co
i6X01OoONP04om^800CoeYH01?oAX`04olf`00Gob;/01?o1a004ojfo00CoVkX01?n8]P05ogNa00Go
Ijd01?mGZ005odRS00Go>Il01_l/VP06oajF00Oo4Y401ol6S00:o`280`_o08<=5_l0OQLKo`1j7bco
07hG3_l0NQl00ol0MBOoooooooooo`02ooooo`;o00000_ooool001Kooooo00?o0000ooooooooool0
0_ooool6oo/C00OomRH01Oob>005one:00Goj5X01OoTJP04ommj00CofhP01?oFUP05om6S00CocK00
1?o8^`04ol7400Go[Kl01?nK^P04ohRf00GoMk401OmW[@05oeNX00CoB:<01_liW`06obbJ00Ko7YH0
2?lBT@08o`J<00So08P33Ol0P`eJo`1n5`go07XO00?o07DWooooooooool00oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool00_ooool7oo/C00KomRH01_ob>005one:00Goj5X01OoT
JP04ommj00CofhP01?oFUP05om6S00CocK001?o8^`05ol7400Co[Kl01?nK^P04ohRf00GoMk401OmW
[@05oeNX00GoB:<01_liW`06obbJ00Ko7YH02?lBT@08o`J<00Wo08P33_l0P`eGo`1n5`co07XO00?o
07DWooooooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool7
oo/C00KomRH01_ob>005one:00Goj5X01OoTJP04ommj00GofhP01?oFUP04om6S00GocK001?o8^`04
ol7400Go[Kl01?nK^P05ohRf00CoMk401OmW[@05oeNX00KoB:<01_liW`06obbJ00Ko7YH02?lBT@08
o`J<00_o08P34_l0P`e@o`1n5`_o07XO00?o07DWooooooooool00oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_ooool7oo/C00OomRH01_ob>005one:00Goj5X01OoTJP04ommj
00GofhP01?oFUP04om6S00GocK001?o8^`04ol7400Go[Kl01?nK^P05ohRf00GoMk401?mW[@06oeNX
00GoB:<01_liW`06obbJ00Oo7YH02?lBT@0:o`J<00_o08P35_l0P`e9o`1n5`[o07XO00?o07DWoooo
ooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool7oo/C00Oo
mRH01_ob>005one:00Goj5X01OoTJP04ommj00GofhP01OoFUP04om6S00CocK001Oo8^`04ol7400Go
[Kl01?nK^P05ohRf00GoMk401OmW[@05oeNX00GoB:<01_liW`07obbJ00Oo7YH02?lBT@0:o`J<00go
08P3A?l0P`dGo`1n5`Wo07XO0_l0MBL5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooo
ooooo`02ooooo`Oona<01oof9P07oo8h00GokDX01OoXFP05onAZ00CoggX01OoKR005omJF00CodJ<0
1?o=/005olRk00Co`L@01On]_`04oi^j00GoR;H01Omg/@05ofN]00GoEjP01_m8X`06ocVO00Ko;9X0
2?lNUP08oa:A00_o1X`03_l0R0=6o`233A7o07hG2Ol0NQl2o`1e9`Gooooo0Ol00001ooooo`7ooooo
000Fooooo`03o`000?oooooooooo00;ooooo1ook4`07ooHV00OolSP01Oo]BP05onQJ00Goi6X01OoO
NP04om^800GoeYH01OoAX`04olf`00Gob;/01?o1a005ojfo00CoVkX01On8]P05ogNa00GoIjd01_mG
Z006odRS00Ko>Il01_l/VP08oajF00[o4Y402Ol6S00Bo`280d;o08<=3ol0OQL9o`1j7`;o07DW1Ooo
ool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool7oo/C00SomRH01_ob>006
one:00Goj5X01OoTJP05ommj00CofhP01OoFUP05om6S00CocK001Oo8^`04ol7400Go[Kl01?nK^P06
ohRf00CoMk401_mW[@05oeNX00KoB:<01oliW`06obbJ00So7YH02_lBT@0;o`J<01Ko08P3??l0P`d>
o`1n5`So07XO0_l0MBL5ooooo`7o00000Oooool1ooooo`002?ooool3o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo00;ooooo1ook4`08ooHV00KolSP01_o]BP05onQJ00Goi6X01OoONP05om^8
00GoeYH01?oAX`05olf`00Cob;/01Oo1a005ojfo00GoVkX01On8]P05ogNa00GoIjd01_mGZ006odRS
00Oo>Il02?l/VP08oajF00Wo4Y403?l6S00Lo`280cCo08<=3?l0OQL8o`1j7`;o07DW1Oooool1o`00
007ooooo0Oooool000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00;ooooo1ook4`08ooHV00OolSP01_o]BP05onQJ00Goi6X01OoONP05om^8
00GoeYH01?oAX`05olf`00Cob;/01Oo1a005ojfo00GoVkX01On8]P05ogNa00GoIjd01_mGZ006odRS
00So>Il01ol/VP09oajF00Wo4Y404?l6S00Vo`280bGo08<=2ol0OQL8o`1j7`;o07DW1Oooool1o`00
007ooooo0Oooool000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00;ooooo1ook4`08ooHV00OolSP01_o]BP05onQJ00Koi6X01?oONP05om^8
00GoeYH01OoAX`05olf`00Cob;/01Oo1a005ojfo00GoVkX01On8]P05ogNa00KoIjd01_mGZ006odRS
00So>Il02?l/VP08oajF00_o4Y404?l6S00^o`280aWo08<=2ol0OQL7o`1j7`?o07DW1Oooool1o`00
007ooooo0Oooool000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004oooo
o`?o00000_ooool7oo/C00WomRH01oob>006one:00Goj5X01_oTJP04ommj00GofhP01OoFUP05om6S
00GocK001?o8^`05ol7400Go[Kl01OnK^P05ohRf00KoMk401_mW[@06oeNX00KoB:<02?liW`08obbJ
00[o7YH02olBT@0Bo`J<02ko08P35?l0P`d:o`1n5`Oo07XO0ol0MBL3ooooo`?o00000_ooool000Wo
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00;ooooo1ook4`09ooHV00OolSP01_o]BP05onQJ00Koi6X01OoONP05om^800GoeYH01OoAX`04olf`
00Gob;/01Oo1a005ojfo00GoVkX01_n8]P05ogNa00KoIjd01omGZ006odRS00So>Il02?l/VP09oajF
00ko4Y405_l6S00Zo`280a3o08<=2_l0OQL7o`1j7`?o07DW1Oooool1o`00007ooooo0Oooool000So
oooo0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool6oo/C
00[omRH01oob>007one:00Goj5X01_oTJP05ommj00GofhP01OoFUP05om6S00CocK001Oo8^`05ol74
00Go[Kl01_nK^P05ohRf00GoMk401_mW[@07oeNX00OoB:<02?liW`08obbJ00_o7YH03_lBT@0Jo`J<
02Co08P33ol0P`d9o`1n5`Oo07XO0ol0MBL5ooooo`7o00000Oooool1ooooo`002Oooool00ol0003o
ooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooo`Gooooo0Ol00001ooooo`7o
oooo000Fooooo`03o`000?oooooooooo0?oooooo1Oooool1o`00007ooooo0Oooool001Kooooo00?o
0000ooooooooool0ooooool5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0
0002ooooo`005_ooooooo`0000Wo00000_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool0037ooooo0ol0002:ooooo`03o`000?oooooooooo02_ooooo0ol0000Eooooo`03o`000?oo
oooooooo01Wooooo000booooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Sooooo000/ooooo`?o00000oooool3o`00
00Cooooo0_l00002ooooo`Go00000_ooool3o`0000?ooooo1?l000000ooooooo0000o`000003o`00
00Oooooo0ol00004ooooo`Co00000oooool2o`0000;ooooo1_l00006ooooo`Co00000_ooool5o`00
0003ooooool0003o000000?o000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool3o`00
00Cooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo0ol00003ooooo`?o00002Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooo
oooo00;ooooo0ol00002ooooo`Go00000_ooool3o`0000;ooooo0ol000001?oooooo0000o`000?oo
ool4o`0000?ooooo0_l00002ooooo`[o00001Oooool00ol0003oooooooooo`0Gooooo`00:oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooo000000cooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Gooooo`00:oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001_ooool3o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooooooo1Ol00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`06
o`000?ooooooooooo`000?oooooo00001Oooool5o`0000Sooooo00?o0000ooooooooool00_ooool0
1Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`03o`000?oooooo000000;ooooo1Ol0
0003ooooo`04o`000?ooooooooooooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00002ooooo`?o00001Ooo
ool00ol0003oooooooooo`0Gooooo`00:oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`00
0?ooooooooooooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
o`000003ooooo`04o`000?ooooooooooo`0000Gooooo00Ko0000oooooooooooo0000ooooool00008
ooooo`03o`000?oooooooooo01Oooooo000[ooooo`06o`000?ooooooooooooooool0003ooooo1?l0
0002ooooo`Co00000_ooool3o`0000Cooooo0ol00003ooooo`;o00001Oooool00ol0003ooooooooo
o`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co00000oooool3o`0000Wooooo
00Go0000oooooooooooo0000ooooo`03o`0000Cooooo1?l00002ooooo`Co00000_ooool3o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`0000?ooooo0ol00003ooooo`?o
00002Oooool00ol0003oooooooooo`02ooooo`Ko000000?oooooo`000?l000000oooool2o`000003
ooooool0003o000000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Co
00000oooool9o`0000?ooooo0ol00003ooooo`Co00001?ooool00ol0003oooooooooo`0Gooooo`00
:oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool0
02cooooo0ol00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool3o`00
00Wooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`Co00001?ooool00ol0
003oooooooooo`04ooooo`;o00001?ooool2o`0002kooooo00?o0000ooooooooool06?ooool3o`00
01Kooooo00?o0000ooooooooool00_ooool2o`0000_ooooo00?o0000ooooooooool06Oooool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-15.8087, -11.5733, 0.0806335, \
0.0806504}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],

Cell[BoxData[
    InterpretationBox[\("Surface Location : \
"\[InvisibleSpace]{ComponentNumber \[Rule] 7, SurfaceNumber \[Rule] 1, 
          WaveFrontID \[Rule] 2, Source \[Rule] 1}\),
      SequenceForm[ 
      "Surface Location : ", {ComponentNumber -> 7, SurfaceNumber -> 1, 
        WaveFrontID -> 2, Source -> 1}],
      Editable->False]], "Print",
  CellLabel->"From In[32]:=",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65794 0.0471168 0.5 0.0470872 [
[.18677 -0.0125 -9 -9 ]
[.18677 -0.0125 9 0 ]
[.42236 -0.0125 -6 -9 ]
[.42236 -0.0125 6 0 ]
[.65794 -0.0125 -3 -9 ]
[.65794 -0.0125 3 0 ]
[.89352 -0.0125 -3 -9 ]
[.89352 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02913 -18 -4.5 ]
[-0.0125 .02913 0 4.5 ]
[-0.0125 .26456 -12 -4.5 ]
[-0.0125 .26456 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .73544 -6 -4.5 ]
[-0.0125 .73544 0 4.5 ]
[-0.0125 .97087 -12 -4.5 ]
[-0.0125 .97087 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -111 0 ]
[.5 1.0125 111 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18677 0 m
.18677 .00625 L
s
[(-10)] .18677 -0.0125 0 1 Mshowa
.42236 0 m
.42236 .00625 L
s
[(-5)] .42236 -0.0125 0 1 Mshowa
.65794 0 m
.65794 .00625 L
s
[(0)] .65794 -0.0125 0 1 Mshowa
.89352 0 m
.89352 .00625 L
s
[(5)] .89352 -0.0125 0 1 Mshowa
.125 Mabswid
.23389 0 m
.23389 .00375 L
s
.28101 0 m
.28101 .00375 L
s
.32812 0 m
.32812 .00375 L
s
.37524 0 m
.37524 .00375 L
s
.46947 0 m
.46947 .00375 L
s
.51659 0 m
.51659 .00375 L
s
.56371 0 m
.56371 .00375 L
s
.61082 0 m
.61082 .00375 L
s
.70506 0 m
.70506 .00375 L
s
.75217 0 m
.75217 .00375 L
s
.79929 0 m
.79929 .00375 L
s
.84641 0 m
.84641 .00375 L
s
.13965 0 m
.13965 .00375 L
s
.09254 0 m
.09254 .00375 L
s
.04542 0 m
.04542 .00375 L
s
.94064 0 m
.94064 .00375 L
s
.98776 0 m
.98776 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02913 m
.00625 .02913 L
s
[(-10)] -0.0125 .02913 1 0 Mshowa
0 .26456 m
.00625 .26456 L
s
[(-5)] -0.0125 .26456 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .73544 m
.00625 .73544 L
s
[(5)] -0.0125 .73544 1 0 Mshowa
0 .97087 m
.00625 .97087 L
s
[(10)] -0.0125 .97087 1 0 Mshowa
.125 Mabswid
0 .07622 m
.00375 .07622 L
s
0 .1233 m
.00375 .1233 L
s
0 .17039 m
.00375 .17039 L
s
0 .21748 m
.00375 .21748 L
s
0 .31165 m
.00375 .31165 L
s
0 .35874 m
.00375 .35874 L
s
0 .40583 m
.00375 .40583 L
s
0 .45291 m
.00375 .45291 L
s
0 .54709 m
.00375 .54709 L
s
0 .59417 m
.00375 .59417 L
s
0 .64126 m
.00375 .64126 L
s
0 .68835 m
.00375 .68835 L
s
0 .78252 m
.00375 .78252 L
s
0 .82961 m
.00375 .82961 L
s
0 .8767 m
.00375 .8767 L
s
0 .92378 m
.00375 .92378 L
s
.25 Mabswid
0 0 m
0 1 L
s
.18677 .99375 m
.18677 1 L
s
.42236 .99375 m
.42236 1 L
s
.65794 .99375 m
.65794 1 L
s
.89352 .99375 m
.89352 1 L
s
.125 Mabswid
.23389 .99625 m
.23389 1 L
s
.28101 .99625 m
.28101 1 L
s
.32812 .99625 m
.32812 1 L
s
.37524 .99625 m
.37524 1 L
s
.46947 .99625 m
.46947 1 L
s
.51659 .99625 m
.51659 1 L
s
.56371 .99625 m
.56371 1 L
s
.61082 .99625 m
.61082 1 L
s
.70506 .99625 m
.70506 1 L
s
.75217 .99625 m
.75217 1 L
s
.79929 .99625 m
.79929 1 L
s
.84641 .99625 m
.84641 1 L
s
.13965 .99625 m
.13965 1 L
s
.09254 .99625 m
.09254 1 L
s
.04542 .99625 m
.04542 1 L
s
.94064 .99625 m
.94064 1 L
s
.98776 .99625 m
.98776 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02913 m
1 .02913 L
s
.99375 .26456 m
1 .26456 L
s
.99375 .5 m
1 .5 L
s
.99375 .73544 m
1 .73544 L
s
.99375 .97087 m
1 .97087 L
s
.125 Mabswid
.99625 .07622 m
1 .07622 L
s
.99625 .1233 m
1 .1233 L
s
.99625 .17039 m
1 .17039 L
s
.99625 .21748 m
1 .21748 L
s
.99625 .31165 m
1 .31165 L
s
.99625 .35874 m
1 .35874 L
s
.99625 .40583 m
1 .40583 L
s
.99625 .45291 m
1 .45291 L
s
.99625 .54709 m
1 .54709 L
s
.99625 .59417 m
1 .59417 L
s
.99625 .64126 m
1 .64126 L
s
.99625 .68835 m
1 .68835 L
s
.99625 .78252 m
1 .78252 L
s
.99625 .82961 m
1 .82961 L
s
.99625 .8767 m
1 .8767 L
s
.99625 .92378 m
1 .92378 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
0 0 m
0 1 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 1.0125 0 -1 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.802 .688 0 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.82 .64 0 r
.01923 .47803 m
.01946 .4735 L
.01994 .46593 L
.02054 .45836 L
.02126 .45079 L
.0221 .44322 L
.02306 .43565 L
.02414 .42807 L
.02535 .4205 L
.02668 .41293 L
.0268 .4123 L
.02814 .40536 L
.02973 .39779 L
.03144 .39022 L
.03328 .38265 L
.03437 .37838 L
.03525 .37508 L
.03735 .3675 L
.03959 .35993 L
.04194 .35243 L
.04197 .35236 L
.04448 .34479 L
.04713 .33722 L
.04952 .33074 L
.04993 .32965 L
.05287 .32208 L
.05596 .31451 L
.05709 .31184 L
.0592 .30694 L
.0626 .29936 L
.06466 .29495 L
.06616 .29179 L
.06988 .28422 L
.07223 .2796 L
.07376 .27665 L
.07782 .26908 L
.0798 .2655 L
.08206 .26151 L
.08647 .25394 L
.08737 .25243 L
.09108 .24637 L
.09494 .24024 L
.09588 .23879 L
.10088 .23122 L
.10251 .22881 L
.10608 .22365 L
.11008 .21804 L
.11151 .21608 L
.11716 .20851 L
.11766 .20786 L
.12305 .20094 L
.12523 .19822 L
.12919 .19337 L
.1328 .18906 L
.13559 .1858 L
.14037 .18034 L
.14226 .17823 L
.14794 .17202 L
.14922 .17065 L
.15551 .16409 L
.15649 .16308 L
.16308 .1565 L
.16409 .15551 L
.17065 .14924 L
.17204 .14794 L
.17823 .14228 L
.18036 .14037 L
.1858 .13562 L
.1891 .1328 L
.19337 .12923 L
.19827 .12523 L
.20094 .1231 L
.20793 .11766 L
.20851 .11721 L
.21608 .11157 L
.21812 .11008 L
.22365 .10615 L
.22891 .10251 L
.23122 .10094 L
.23879 .09595 L
.24036 .09494 L
.24637 .09116 L
.25257 .08737 L
.25394 .08656 L
.26151 .08214 L
.26567 .0798 L
.26908 .07791 L
.27665 .07386 L
.27979 .07223 L
.28422 .06998 L
.29179 .06626 L
.29517 .06466 L
.29936 .06271 L
.30694 .05932 L
.31211 .05709 L
.31451 .05608 L
.32208 .05299 L
.32965 .05005 L
.33107 .04952 L
.33722 .04726 L
.34479 .04461 L
.35236 .0421 L
.35283 .04194 L
.35993 .03972 L
.3675 .03749 L
.37508 .03538 L
.3789 .03437 L
.38265 .03342 L
.39022 .03158 L
.39779 .02987 L
.40536 .02828 L
.41293 .02683 L
.41307 .0268 L
.4205 .0255 L
.42807 .02429 L
.43565 .02321 L
.44322 .02225 L
.45079 .02141 L
.45836 .02069 L
.46593 .02009 L
.4735 .01961 L
.48107 .01926 L
.48158 .01923 L
.01923 .01923 L
F
.01923 .52197 m
.01946 .5265 L
.01994 .53407 L
.02054 .54164 L
.02126 .54921 L
.0221 .55678 L
.02306 .56435 L
.02414 .57193 L
.02535 .5795 L
.02668 .58707 L
.0268 .5877 L
.02814 .59464 L
.02973 .60221 L
.03144 .60978 L
.03328 .61735 L
.03437 .62162 L
.03525 .62492 L
.03735 .6325 L
.03959 .64007 L
.04194 .64757 L
.04197 .64764 L
.04448 .65521 L
.04713 .66278 L
.04952 .66926 L
.04993 .67035 L
.05287 .67792 L
.05596 .68549 L
.05709 .68816 L
.0592 .69306 L
.0626 .70064 L
.06466 .70505 L
.06616 .70821 L
.06988 .71578 L
.07223 .7204 L
.07376 .72335 L
.07782 .73092 L
.0798 .7345 L
.08206 .73849 L
.08647 .74606 L
.08737 .74757 L
.09108 .75363 L
.09494 .75976 L
.09588 .76121 L
.10088 .76878 L
.10251 .77119 L
.10608 .77635 L
.11008 .78196 L
.11151 .78392 L
.11716 .79149 L
.11766 .79214 L
.12305 .79906 L
.12523 .80178 L
.12919 .80663 L
.1328 .81094 L
.13559 .8142 L
.14037 .81966 L
.14226 .82177 L
.14794 .82798 L
.14922 .82935 L
.15551 .83591 L
.15649 .83692 L
.16308 .8435 L
.16409 .84449 L
.17065 .85076 L
.17204 .85206 L
.17823 .85772 L
.18036 .85963 L
.1858 .86438 L
.1891 .8672 L
.19337 .87077 L
.19827 .87477 L
.20094 .8769 L
.20793 .88234 L
.20851 .88279 L
.21608 .88843 L
.21812 .88992 L
.22365 .89385 L
.22891 .89749 L
.23122 .89906 L
.23879 .90405 L
.24036 .90506 L
.24637 .90884 L
.25257 .91263 L
.25394 .91344 L
.26151 .91786 L
.26567 .9202 L
.26908 .92209 L
.27665 .92614 L
.27979 .92777 L
.28422 .93002 L
.29179 .93374 L
.29517 .93534 L
.29936 .93729 L
.30694 .94068 L
.31211 .94291 L
.31451 .94392 L
.32208 .94701 L
.32965 .94995 L
.33107 .95048 L
.33722 .95274 L
.34479 .95539 L
.35236 .9579 L
.35283 .95806 L
.35993 .96028 L
.3675 .96251 L
.37508 .96462 L
.3789 .96563 L
.38265 .96658 L
.39022 .96842 L
.39779 .97013 L
.40536 .97172 L
.41293 .97317 L
.41307 .9732 L
.4205 .9745 L
.42807 .97571 L
.43565 .97679 L
.44322 .97775 L
.45079 .97859 L
.45836 .97931 L
.46593 .97991 L
.4735 .98039 L
.48107 .98074 L
.48158 .98077 L
.01923 .98077 L
F
.838 .588 0 r
.01923 .39943 m
.01958 .39779 L
.02125 .39022 L
.02305 .38265 L
.02498 .37508 L
.0268 .36836 L
.02704 .3675 L
.02923 .35993 L
.03155 .35236 L
.03401 .34479 L
.03437 .3437 L
.0366 .33722 L
.03933 .32965 L
.04194 .32276 L
.04221 .32208 L
.04523 .31451 L
.04839 .30694 L
.04952 .30433 L
.05171 .29936 L
.05518 .29179 L
.05709 .28777 L
.0588 .28422 L
.06259 .27665 L
.06466 .27265 L
.06655 .26908 L
.07067 .26151 L
.07223 .25872 L
.07497 .25394 L
.07944 .24637 L
.0798 .24578 L
.08411 .23879 L
.08737 .23368 L
.08897 .23122 L
.09402 .22365 L
.09494 .22231 L
.09929 .21608 L
.10251 .21158 L
.10476 .20851 L
.11008 .20143 L
.11047 .20094 L
.1164 .19337 L
.11766 .19181 L
.12258 .1858 L
.12523 .18265 L
.12902 .17823 L
.1328 .17392 L
.13573 .17065 L
.14037 .1656 L
.14273 .16308 L
.14794 .15764 L
.15003 .15551 L
.15551 .15003 L
.15765 .14794 L
.16308 .14274 L
.16562 .14037 L
.17065 .13575 L
.17395 .1328 L
.17823 .12905 L
.18269 .12523 L
.1858 .12262 L
.19186 .11766 L
.19337 .11645 L
.20094 .11052 L
.2015 .11008 L
.20851 .10482 L
.21167 .10251 L
.21608 .09935 L
.22241 .09494 L
.22365 .09409 L
.23122 .08904 L
.2338 .08737 L
.23879 .08419 L
.24592 .0798 L
.24637 .07953 L
.25394 .07506 L
.25889 .07223 L
.26151 .07077 L
.26908 .06665 L
.27285 .06466 L
.27665 .0627 L
.28422 .05892 L
.288 .05709 L
.29179 .05529 L
.29936 .05183 L
.30461 .04952 L
.30694 .04851 L
.31451 .04535 L
.32208 .04234 L
.32309 .04194 L
.32965 .03947 L
.33722 .03674 L
.34411 .03437 L
.34479 .03415 L
.35236 .03169 L
.35993 .02937 L
.3675 .02718 L
.36888 .0268 L
.37508 .02513 L
.38265 .0232 L
.39022 .0214 L
.39779 .01973 L
.40015 .01923 L
.01923 .01923 L
F
.01923 .60057 m
.01958 .60221 L
.02125 .60978 L
.02305 .61735 L
.02498 .62492 L
.0268 .63164 L
.02704 .6325 L
.02923 .64007 L
.03155 .64764 L
.03401 .65521 L
.03437 .6563 L
.0366 .66278 L
.03933 .67035 L
.04194 .67724 L
.04221 .67792 L
.04523 .68549 L
.04839 .69306 L
.04952 .69567 L
.05171 .70064 L
.05518 .70821 L
.05709 .71223 L
.0588 .71578 L
.06259 .72335 L
.06466 .72735 L
.06655 .73092 L
.07067 .73849 L
.07223 .74128 L
.07497 .74606 L
.07944 .75363 L
.0798 .75422 L
.08411 .76121 L
.08737 .76632 L
.08897 .76878 L
.09402 .77635 L
.09494 .77769 L
.09929 .78392 L
.10251 .78842 L
.10476 .79149 L
.11008 .79857 L
.11047 .79906 L
.1164 .80663 L
.11766 .80819 L
.12258 .8142 L
.12523 .81735 L
.12902 .82177 L
.1328 .82608 L
.13573 .82935 L
.14037 .8344 L
.14273 .83692 L
.14794 .84236 L
.15003 .84449 L
.15551 .84997 L
.15765 .85206 L
.16308 .85726 L
.16562 .85963 L
.17065 .86425 L
.17395 .8672 L
.17823 .87095 L
.18269 .87477 L
.1858 .87738 L
.19186 .88234 L
.19337 .88355 L
.20094 .88948 L
.2015 .88992 L
.20851 .89518 L
.21167 .89749 L
.21608 .90065 L
.22241 .90506 L
.22365 .90591 L
.23122 .91096 L
.2338 .91263 L
.23879 .91581 L
.24592 .9202 L
.24637 .92047 L
.25394 .92494 L
.25889 .92777 L
.26151 .92923 L
.26908 .93335 L
.27285 .93534 L
.27665 .9373 L
.28422 .94108 L
.288 .94291 L
.29179 .94471 L
.29936 .94817 L
.30461 .95048 L
.30694 .95149 L
.31451 .95465 L
.32208 .95766 L
.32309 .95806 L
.32965 .96053 L
.33722 .96326 L
.34411 .96563 L
.34479 .96585 L
.35236 .96831 L
.35993 .97063 L
.3675 .97282 L
.36888 .9732 L
.37508 .97487 L
.38265 .9768 L
.39022 .9786 L
.39779 .98027 L
.40015 .98077 L
.01923 .98077 L
F
.856 .534 0 r
.01923 .35753 m
.02079 .35236 L
.0232 .34479 L
.02573 .33722 L
.0268 .33413 L
.0284 .32965 L
.03121 .32208 L
.03415 .31451 L
.03437 .31396 L
.03724 .30694 L
.04048 .29936 L
.04194 .29604 L
.04386 .29179 L
.0474 .28422 L
.04952 .27984 L
.05109 .27665 L
.05494 .26908 L
.05709 .26499 L
.05896 .26151 L
.06314 .25394 L
.06466 .25126 L
.0675 .24637 L
.07203 .23879 L
.07223 .23847 L
.07675 .23122 L
.0798 .22648 L
.08166 .22365 L
.08676 .21608 L
.08737 .2152 L
.09207 .20851 L
.09494 .20454 L
.09759 .20094 L
.10251 .19444 L
.10334 .19337 L
.10931 .1858 L
.11008 .18484 L
.11553 .17823 L
.11766 .1757 L
.122 .17065 L
.12523 .16699 L
.12874 .16308 L
.1328 .15866 L
.13576 .15551 L
.14037 .1507 L
.14307 .14794 L
.14794 .14308 L
.15071 .14037 L
.15551 .13577 L
.15868 .1328 L
.16308 .12876 L
.16702 .12523 L
.17065 .12203 L
.17575 .11766 L
.17823 .11557 L
.1849 .11008 L
.1858 .10936 L
.19337 .10339 L
.19451 .10251 L
.20094 .09766 L
.20463 .09494 L
.20851 .09214 L
.21531 .08737 L
.21608 .08684 L
.22365 .08174 L
.22661 .0798 L
.23122 .07684 L
.23862 .07223 L
.23879 .07212 L
.24637 .06759 L
.25144 .06466 L
.25394 .06324 L
.26151 .05906 L
.2652 .05709 L
.26908 .05505 L
.27665 .05121 L
.28008 .04952 L
.28422 .04752 L
.29179 .04399 L
.29633 .04194 L
.29936 .04061 L
.30694 .03738 L
.3143 .03437 L
.31451 .03429 L
.32208 .03135 L
.32965 .02854 L
.33454 .0268 L
.33722 .02587 L
.34479 .02334 L
.35236 .02094 L
.35805 .01923 L
.01923 .01923 L
F
.01923 .64247 m
.02079 .64764 L
.0232 .65521 L
.02573 .66278 L
.0268 .66587 L
.0284 .67035 L
.03121 .67792 L
.03415 .68549 L
.03437 .68604 L
.03724 .69306 L
.04048 .70064 L
.04194 .70396 L
.04386 .70821 L
.0474 .71578 L
.04952 .72016 L
.05109 .72335 L
.05494 .73092 L
.05709 .73501 L
.05896 .73849 L
.06314 .74606 L
.06466 .74874 L
.0675 .75363 L
.07203 .76121 L
.07223 .76153 L
.07675 .76878 L
.0798 .77352 L
.08166 .77635 L
.08676 .78392 L
.08737 .7848 L
.09207 .79149 L
.09494 .79546 L
.09759 .79906 L
.10251 .80556 L
.10334 .80663 L
.10931 .8142 L
.11008 .81516 L
.11553 .82177 L
.11766 .8243 L
.122 .82935 L
.12523 .83301 L
.12874 .83692 L
.1328 .84134 L
.13576 .84449 L
.14037 .8493 L
.14307 .85206 L
.14794 .85692 L
.15071 .85963 L
.15551 .86423 L
.15868 .8672 L
.16308 .87124 L
.16702 .87477 L
.17065 .87797 L
.17575 .88234 L
.17823 .88443 L
.1849 .88992 L
.1858 .89064 L
.19337 .89661 L
.19451 .89749 L
.20094 .90234 L
.20463 .90506 L
.20851 .90786 L
.21531 .91263 L
.21608 .91316 L
.22365 .91826 L
.22661 .9202 L
.23122 .92316 L
.23862 .92777 L
.23879 .92788 L
.24637 .93241 L
.25144 .93534 L
.25394 .93676 L
.26151 .94094 L
.2652 .94291 L
.26908 .94495 L
.27665 .94879 L
.28008 .95048 L
.28422 .95248 L
.29179 .95601 L
.29633 .95806 L
.29936 .95939 L
.30694 .96262 L
.3143 .96563 L
.31451 .96571 L
.32208 .96865 L
.32965 .97146 L
.33454 .9732 L
.33722 .97413 L
.34479 .97666 L
.35236 .97906 L
.35805 .98077 L
.01923 .98077 L
F
.874 .477 0 r
.01923 .32355 m
.01978 .32208 L
.02265 .31451 L
.02567 .30694 L
.0268 .30417 L
.02882 .29936 L
.03212 .29179 L
.03437 .28681 L
.03557 .28422 L
.03917 .27665 L
.04194 .27101 L
.04292 .26908 L
.04682 .26151 L
.04952 .25647 L
.05089 .25394 L
.05513 .24637 L
.05709 .24297 L
.05954 .23879 L
.06412 .23122 L
.06466 .23035 L
.06888 .22365 L
.07223 .21851 L
.07384 .21608 L
.07898 .20851 L
.0798 .20734 L
.08433 .20094 L
.08737 .19676 L
.08989 .19337 L
.09494 .18673 L
.09567 .1858 L
.10167 .17823 L
.10251 .17719 L
.10791 .17065 L
.11008 .16809 L
.1144 .16308 L
.11766 .1594 L
.12116 .15551 L
.12523 .15109 L
.12819 .14794 L
.1328 .14314 L
.13551 .14037 L
.14037 .13552 L
.14315 .1328 L
.14794 .1282 L
.15111 .12523 L
.15551 .12118 L
.15943 .11766 L
.16308 .11444 L
.16813 .11008 L
.17065 .10795 L
.17725 .10251 L
.17823 .10172 L
.1858 .09573 L
.18681 .09494 L
.19337 .08996 L
.19686 .08737 L
.20094 .08441 L
.20745 .0798 L
.20851 .07906 L
.21608 .07392 L
.21864 .07223 L
.22365 .06898 L
.23051 .06466 L
.23122 .06422 L
.23879 .05964 L
.24315 .05709 L
.24637 .05524 L
.25394 .05101 L
.25668 .04952 L
.26151 .04694 L
.26908 .04304 L
.27126 .04194 L
.27665 .03929 L
.28422 .0357 L
.2871 .03437 L
.29179 .03226 L
.29936 .02896 L
.30452 .0268 L
.30694 .02581 L
.31451 .0228 L
.32208 .01993 L
.32397 .01923 L
.01923 .01923 L
F
.01923 .67645 m
.01978 .67792 L
.02265 .68549 L
.02567 .69306 L
.0268 .69583 L
.02882 .70064 L
.03212 .70821 L
.03437 .71319 L
.03557 .71578 L
.03917 .72335 L
.04194 .72899 L
.04292 .73092 L
.04682 .73849 L
.04952 .74353 L
.05089 .74606 L
.05513 .75363 L
.05709 .75703 L
.05954 .76121 L
.06412 .76878 L
.06466 .76965 L
.06888 .77635 L
.07223 .78149 L
.07384 .78392 L
.07898 .79149 L
.0798 .79266 L
.08433 .79906 L
.08737 .80324 L
.08989 .80663 L
.09494 .81327 L
.09567 .8142 L
.10167 .82177 L
.10251 .82281 L
.10791 .82935 L
.11008 .83191 L
.1144 .83692 L
.11766 .8406 L
.12116 .84449 L
.12523 .84891 L
.12819 .85206 L
.1328 .85686 L
.13551 .85963 L
.14037 .86448 L
.14315 .8672 L
.14794 .8718 L
.15111 .87477 L
.15551 .87882 L
.15943 .88234 L
.16308 .88556 L
.16813 .88992 L
.17065 .89205 L
.17725 .89749 L
.17823 .89828 L
.1858 .90427 L
.18681 .90506 L
.19337 .91004 L
.19686 .91263 L
.20094 .91559 L
.20745 .9202 L
.20851 .92094 L
.21608 .92608 L
.21864 .92777 L
.22365 .93102 L
.23051 .93534 L
.23122 .93578 L
.23879 .94036 L
.24315 .94291 L
.24637 .94476 L
.25394 .94899 L
.25668 .95048 L
.26151 .95306 L
.26908 .95696 L
.27126 .95806 L
.27665 .96071 L
.28422 .9643 L
.2871 .96563 L
.29179 .96774 L
.29936 .97104 L
.30452 .9732 L
.30694 .97419 L
.31451 .9772 L
.32208 .98007 L
.32397 .98077 L
.01923 .98077 L
F
.892 .417 0 r
.01923 .29318 m
.01983 .29179 L
.02319 .28422 L
.02669 .27665 L
.0268 .27641 L
.03034 .26908 L
.03414 .26151 L
.03437 .26106 L
.0381 .25394 L
.04194 .24686 L
.04222 .24637 L
.0465 .23879 L
.04952 .23363 L
.05095 .23122 L
.05557 .22365 L
.05709 .22123 L
.06037 .21608 L
.06466 .20956 L
.06536 .20851 L
.07054 .20094 L
.07223 .19853 L
.07592 .19337 L
.0798 .18807 L
.0815 .1858 L
.0873 .17823 L
.08737 .17813 L
.09332 .17065 L
.09494 .16866 L
.09958 .16308 L
.10251 .15963 L
.10608 .15551 L
.11008 .15098 L
.11283 .14794 L
.11766 .14271 L
.11986 .14037 L
.12523 .13479 L
.12718 .1328 L
.1328 .12718 L
.13479 .12523 L
.14037 .11988 L
.14273 .11766 L
.14794 .11286 L
.15102 .11008 L
.15551 .10611 L
.15967 .10251 L
.16308 .09962 L
.16873 .09494 L
.17065 .09338 L
.17821 .08737 L
.17823 .08736 L
.1858 .08157 L
.18817 .0798 L
.19337 .076 L
.19865 .07223 L
.20094 .07063 L
.20851 .06545 L
.2097 .06466 L
.21608 .06047 L
.2214 .05709 L
.22365 .05568 L
.23122 .05106 L
.23382 .04952 L
.23879 .04662 L
.24637 .04234 L
.24708 .04194 L
.25394 .03823 L
.26132 .03437 L
.26151 .03427 L
.26908 .03048 L
.27665 .02683 L
.27671 .0268 L
.28422 .02333 L
.29179 .01998 L
.29353 .01923 L
.01923 .01923 L
F
.01923 .70682 m
.01983 .70821 L
.02319 .71578 L
.02669 .72335 L
.0268 .72359 L
.03034 .73092 L
.03414 .73849 L
.03437 .73894 L
.0381 .74606 L
.04194 .75314 L
.04222 .75363 L
.0465 .76121 L
.04952 .76637 L
.05095 .76878 L
.05557 .77635 L
.05709 .77877 L
.06037 .78392 L
.06466 .79044 L
.06536 .79149 L
.07054 .79906 L
.07223 .80147 L
.07592 .80663 L
.0798 .81193 L
.0815 .8142 L
.0873 .82177 L
.08737 .82187 L
.09332 .82935 L
.09494 .83134 L
.09958 .83692 L
.10251 .84037 L
.10608 .84449 L
.11008 .84902 L
.11283 .85206 L
.11766 .85729 L
.11986 .85963 L
.12523 .86521 L
.12718 .8672 L
.1328 .87282 L
.13479 .87477 L
.14037 .88012 L
.14273 .88234 L
.14794 .88714 L
.15102 .88992 L
.15551 .89389 L
.15967 .89749 L
.16308 .90038 L
.16873 .90506 L
.17065 .90662 L
.17821 .91263 L
.17823 .91264 L
.1858 .91843 L
.18817 .9202 L
.19337 .924 L
.19865 .92777 L
.20094 .92937 L
.20851 .93455 L
.2097 .93534 L
.21608 .93953 L
.2214 .94291 L
.22365 .94432 L
.23122 .94894 L
.23382 .95048 L
.23879 .95338 L
.24637 .95766 L
.24708 .95806 L
.25394 .96177 L
.26132 .96563 L
.26151 .96573 L
.26908 .96952 L
.27665 .97317 L
.27671 .9732 L
.28422 .97667 L
.29179 .98002 L
.29353 .98077 L
.01923 .98077 L
F
.91 .355 0 r
.01923 .26453 m
.02072 .26151 L
.02457 .25394 L
.0268 .24968 L
.02857 .24637 L
.03273 .23879 L
.03437 .23587 L
.03704 .23122 L
.04153 .22365 L
.04194 .22296 L
.04618 .21608 L
.04952 .21082 L
.05101 .20851 L
.05602 .20094 L
.05709 .19936 L
.06122 .19337 L
.06466 .18851 L
.06661 .1858 L
.07221 .17823 L
.07223 .1782 L
.07802 .17065 L
.0798 .16838 L
.08404 .16308 L
.08737 .15902 L
.09029 .15551 L
.09494 .15006 L
.09679 .14794 L
.10251 .14149 L
.10353 .14037 L
.11008 .13328 L
.11054 .1328 L
.11766 .1254 L
.11782 .12523 L
.12523 .11783 L
.12541 .11766 L
.1328 .11056 L
.1333 .11008 L
.14037 .10356 L
.14153 .10251 L
.14794 .09683 L
.15011 .09494 L
.15551 .09034 L
.15908 .08737 L
.16308 .0841 L
.16846 .0798 L
.17065 .07808 L
.17823 .07229 L
.1783 .07223 L
.1858 .0667 L
.18863 .06466 L
.19337 .06131 L
.19951 .05709 L
.20094 .05612 L
.20851 .05112 L
.21099 .04952 L
.21608 .04629 L
.22316 .04194 L
.22365 .04165 L
.23122 .03717 L
.2361 .03437 L
.23879 .03286 L
.24637 .02871 L
.24994 .0268 L
.25394 .02471 L
.26151 .02087 L
.26484 .01923 L
.01923 .01923 L
F
.01923 .73547 m
.02072 .73849 L
.02457 .74606 L
.0268 .75032 L
.02857 .75363 L
.03273 .76121 L
.03437 .76413 L
.03704 .76878 L
.04153 .77635 L
.04194 .77704 L
.04618 .78392 L
.04952 .78918 L
.05101 .79149 L
.05602 .79906 L
.05709 .80064 L
.06122 .80663 L
.06466 .81149 L
.06661 .8142 L
.07221 .82177 L
.07223 .8218 L
.07802 .82935 L
.0798 .83162 L
.08404 .83692 L
.08737 .84098 L
.09029 .84449 L
.09494 .84994 L
.09679 .85206 L
.10251 .85851 L
.10353 .85963 L
.11008 .86672 L
.11054 .8672 L
.11766 .8746 L
.11782 .87477 L
.12523 .88217 L
.12541 .88234 L
.1328 .88944 L
.1333 .88992 L
.14037 .89644 L
.14153 .89749 L
.14794 .90317 L
.15011 .90506 L
.15551 .90966 L
.15908 .91263 L
.16308 .9159 L
.16846 .9202 L
.17065 .92192 L
.17823 .92771 L
.1783 .92777 L
.1858 .9333 L
.18863 .93534 L
.19337 .93869 L
.19951 .94291 L
.20094 .94388 L
.20851 .94888 L
.21099 .95048 L
.21608 .95371 L
.22316 .95806 L
.22365 .95835 L
.23122 .96283 L
.2361 .96563 L
.23879 .96714 L
.24637 .97129 L
.24994 .9732 L
.25394 .97529 L
.26151 .97913 L
.26484 .98077 L
.01923 .98077 L
F
.928 .29 0 r
.01923 .2364 m
.02211 .23122 L
.02645 .22365 L
.0268 .22305 L
.03095 .21608 L
.03437 .21051 L
.03562 .20851 L
.04047 .20094 L
.04194 .19868 L
.04549 .19337 L
.04952 .18748 L
.05069 .1858 L
.05609 .17823 L
.05709 .17685 L
.06168 .17065 L
.06466 .16673 L
.06748 .16308 L
.07223 .15707 L
.07349 .15551 L
.07972 .14794 L
.0798 .14784 L
.08618 .14037 L
.08737 .13901 L
.09289 .1328 L
.09494 .13054 L
.09986 .12523 L
.10251 .12242 L
.10709 .11766 L
.11008 .11461 L
.11461 .11008 L
.11766 .1071 L
.12243 .10251 L
.12523 .09988 L
.13057 .09494 L
.1328 .09293 L
.13906 .08737 L
.14037 .08623 L
.14791 .0798 L
.14794 .07977 L
.15551 .07355 L
.15716 .07223 L
.16308 .06755 L
.16683 .06466 L
.17065 .06176 L
.17697 .05709 L
.17823 .05618 L
.1858 .05079 L
.18763 .04952 L
.19337 .04559 L
.19885 .04194 L
.20094 .04058 L
.20851 .03574 L
.21071 .03437 L
.21608 .03108 L
.22328 .0268 L
.22365 .02658 L
.23122 .02225 L
.23666 .01923 L
.01923 .01923 L
F
.01923 .7636 m
.02211 .76878 L
.02645 .77635 L
.0268 .77695 L
.03095 .78392 L
.03437 .78949 L
.03562 .79149 L
.04047 .79906 L
.04194 .80132 L
.04549 .80663 L
.04952 .81252 L
.05069 .8142 L
.05609 .82177 L
.05709 .82315 L
.06168 .82935 L
.06466 .83327 L
.06748 .83692 L
.07223 .84293 L
.07349 .84449 L
.07972 .85206 L
.0798 .85216 L
.08618 .85963 L
.08737 .86099 L
.09289 .8672 L
.09494 .86946 L
.09986 .87477 L
.10251 .87758 L
.10709 .88234 L
.11008 .88539 L
.11461 .88992 L
.11766 .8929 L
.12243 .89749 L
.12523 .90012 L
.13057 .90506 L
.1328 .90707 L
.13906 .91263 L
.14037 .91377 L
.14791 .9202 L
.14794 .92023 L
.15551 .92645 L
.15716 .92777 L
.16308 .93245 L
.16683 .93534 L
.17065 .93824 L
.17697 .94291 L
.17823 .94382 L
.1858 .94921 L
.18763 .95048 L
.19337 .95441 L
.19885 .95806 L
.20094 .95942 L
.20851 .96426 L
.21071 .96563 L
.21608 .96892 L
.22328 .9732 L
.22365 .97342 L
.23122 .97775 L
.23666 .98077 L
.01923 .98077 L
F
.946 .221 0 r
.01923 .20761 m
.02335 .20094 L
.0268 .19552 L
.02819 .19337 L
.0332 .1858 L
.03437 .18407 L
.03839 .17823 L
.04194 .17319 L
.04377 .17065 L
.04933 .16308 L
.04952 .16284 L
.0551 .15551 L
.05709 .15296 L
.06107 .14794 L
.06466 .14352 L
.06726 .14037 L
.07223 .13448 L
.07367 .1328 L
.0798 .1258 L
.08031 .12523 L
.08721 .11766 L
.08737 .11748 L
.09436 .11008 L
.09494 .10948 L
.10178 .10251 L
.10251 .10178 L
.10949 .09494 L
.11008 .09437 L
.11751 .08737 L
.11766 .08723 L
.12523 .08035 L
.12585 .0798 L
.1328 .07372 L
.13454 .07223 L
.14037 .06732 L
.1436 .06466 L
.14794 .06115 L
.15307 .05709 L
.15551 .05518 L
.16297 .04952 L
.16308 .04943 L
.17065 .04387 L
.17334 .04194 L
.17823 .03851 L
.18424 .03437 L
.1858 .03332 L
.19337 .02832 L
.19572 .0268 L
.20094 .02349 L
.20784 .01923 L
.01923 .01923 L
F
.01923 .79239 m
.02335 .79906 L
.0268 .80448 L
.02819 .80663 L
.0332 .8142 L
.03437 .81593 L
.03839 .82177 L
.04194 .82681 L
.04377 .82935 L
.04933 .83692 L
.04952 .83716 L
.0551 .84449 L
.05709 .84704 L
.06107 .85206 L
.06466 .85648 L
.06726 .85963 L
.07223 .86552 L
.07367 .8672 L
.0798 .8742 L
.08031 .87477 L
.08721 .88234 L
.08737 .88252 L
.09436 .88992 L
.09494 .89052 L
.10178 .89749 L
.10251 .89822 L
.10949 .90506 L
.11008 .90563 L
.11751 .91263 L
.11766 .91277 L
.12523 .91965 L
.12585 .9202 L
.1328 .92628 L
.13454 .92777 L
.14037 .93268 L
.1436 .93534 L
.14794 .93885 L
.15307 .94291 L
.15551 .94482 L
.16297 .95048 L
.16308 .95057 L
.17065 .95613 L
.17334 .95806 L
.17823 .96149 L
.18424 .96563 L
.1858 .96668 L
.19337 .97168 L
.19572 .9732 L
.20094 .97651 L
.20784 .98077 L
.01923 .98077 L
F
.964 .15 0 r
.01923 .17646 m
.02319 .17065 L
.0268 .16549 L
.02851 .16308 L
.03402 .15551 L
.03437 .15503 L
.03972 .14794 L
.04194 .14505 L
.04561 .14037 L
.04952 .13549 L
.05171 .1328 L
.05709 .12634 L
.05803 .12523 L
.06457 .11766 L
.06466 .11755 L
.07134 .11008 L
.07223 .10911 L
.07836 .10251 L
.0798 .10099 L
.08563 .09494 L
.08737 .09317 L
.09318 .08737 L
.09494 .08564 L
.10101 .0798 L
.10251 .07838 L
.10915 .07223 L
.11008 .07138 L
.11761 .06466 L
.11766 .06462 L
.12523 .05809 L
.12642 .05709 L
.1328 .05179 L
.13559 .04952 L
.14037 .0457 L
.14517 .04194 L
.14794 .03982 L
.15518 .03437 L
.15551 .03413 L
.16308 .02863 L
.16566 .0268 L
.17065 .02332 L
.17666 .01923 L
.01923 .01923 L
F
.01923 .82354 m
.02319 .82935 L
.0268 .83451 L
.02851 .83692 L
.03402 .84449 L
.03437 .84497 L
.03972 .85206 L
.04194 .85495 L
.04561 .85963 L
.04952 .86451 L
.05171 .8672 L
.05709 .87366 L
.05803 .87477 L
.06457 .88234 L
.06466 .88245 L
.07134 .88992 L
.07223 .89089 L
.07836 .89749 L
.0798 .89901 L
.08563 .90506 L
.08737 .90683 L
.09318 .91263 L
.09494 .91436 L
.10101 .9202 L
.10251 .92162 L
.10915 .92777 L
.11008 .92862 L
.11761 .93534 L
.11766 .93538 L
.12523 .94191 L
.12642 .94291 L
.1328 .94821 L
.13559 .95048 L
.14037 .9543 L
.14517 .95806 L
.14794 .96018 L
.15518 .96563 L
.15551 .96587 L
.16308 .97137 L
.16566 .9732 L
.17065 .97668 L
.17666 .98077 L
.01923 .98077 L
F
.982 .077 0 r
.01923 .13875 m
.02375 .1328 L
.0268 .12889 L
.0297 .12523 L
.03437 .11944 L
.03584 .11766 L
.04194 .11036 L
.04218 .11008 L
.04874 .10251 L
.04952 .10164 L
.05553 .09494 L
.05709 .09324 L
.06256 .08737 L
.06466 .08516 L
.06983 .0798 L
.07223 .07736 L
.07737 .07223 L
.0798 .06985 L
.08518 .06466 L
.08737 .06259 L
.09329 .05709 L
.09494 .05558 L
.1017 .04952 L
.10251 .0488 L
.11008 .04225 L
.11045 .04194 L
.11766 .03593 L
.11955 .03437 L
.12523 .0298 L
.12903 .0268 L
.1328 .02387 L
.13892 .01923 L
.01923 .01923 L
F
.01923 .86125 m
.02375 .8672 L
.0268 .87111 L
.0297 .87477 L
.03437 .88056 L
.03584 .88234 L
.04194 .88964 L
.04218 .88992 L
.04874 .89749 L
.04952 .89836 L
.05553 .90506 L
.05709 .90676 L
.06256 .91263 L
.06466 .91484 L
.06983 .9202 L
.07223 .92264 L
.07737 .92777 L
.0798 .93015 L
.08518 .93534 L
.08737 .93741 L
.09329 .94291 L
.09494 .94442 L
.1017 .95048 L
.10251 .9512 L
.11008 .95775 L
.11045 .95806 L
.11766 .96407 L
.11955 .96563 L
.12523 .9702 L
.12903 .9732 L
.1328 .97613 L
.13892 .98077 L
.01923 .98077 L
F
.964 .15 0 r
.01923 .01936 m
.01936 .01923 L
.01923 .01923 L
F
.01923 .98064 m
.01936 .98077 L
.01923 .98077 L
F
.784 .734 0 r
.42807 .03403 m
.43565 .03293 L
.44322 .03195 L
.45079 .03109 L
.45836 .03036 L
.46593 .02975 L
.4735 .02926 L
.48107 .02889 L
.48864 .02865 L
.49621 .02853 L
.50379 .02853 L
.51136 .02865 L
.51893 .02889 L
.5265 .02926 L
.53407 .02975 L
.54164 .03036 L
.54921 .03109 L
.55678 .03194 L
.56435 .03293 L
.57193 .03403 L
.57411 .03437 L
.5795 .03526 L
.58707 .03662 L
.59464 .03811 L
.60221 .03973 L
.60978 .04147 L
.61174 .04194 L
.61735 .04335 L
.62492 .04536 L
.6325 .04751 L
.63915 .04952 L
.64007 .0498 L
.64764 .05222 L
.65521 .05479 L
.66164 .05709 L
.66278 .0575 L
.67035 .06036 L
.67792 .06337 L
.68105 .06466 L
.68549 .06653 L
.69306 .06985 L
.69828 .07223 L
.70064 .07333 L
.70821 .07697 L
.71386 .0798 L
.71578 .08078 L
.72335 .08477 L
.72813 .08737 L
.73092 .08893 L
.73849 .09327 L
.74132 .09494 L
.74606 .09781 L
.7536 .10251 L
.75363 .10254 L
.76121 .10747 L
.7651 .11008 L
.76878 .11261 L
.77591 .11766 L
.77635 .11797 L
.78392 .12356 L
.78611 .12523 L
.79149 .12939 L
.79577 .1328 L
.79906 .13547 L
.80493 .14037 L
.80663 .14182 L
.81365 .14794 L
.8142 .14843 L
.82177 .15535 L
.82195 .15551 L
.82935 .16257 L
.82987 .16308 L
.83692 .17013 L
.83743 .17065 L
.84449 .17803 L
.84467 .17823 L
.85159 .1858 L
.85206 .18633 L
.85821 .19337 L
.85963 .19503 L
.86456 .20094 L
.8672 .20418 L
.87065 .20851 L
.87477 .21383 L
.87648 .21608 L
.88208 .22365 L
.88234 .22402 L
.88745 .23122 L
.88992 .23481 L
.8926 .23879 L
.89749 .24629 L
.89753 .24637 L
.90227 .25394 L
.90506 .25855 L
.90681 .26151 L
.91116 .26908 L
.91263 .27172 L
.91532 .27665 L
.91931 .28422 L
.9202 .28596 L
.92312 .29179 L
.92677 .29936 L
.92777 .30151 L
.93025 .30694 L
.93357 .31451 L
.93534 .31869 L
.93674 .32208 L
.93975 .32965 L
.94261 .33722 L
.94291 .33804 L
.94533 .34479 L
.9479 .35236 L
.95032 .35993 L
.95048 .36045 L
.95261 .3675 L
.95476 .37508 L
.95678 .38265 L
.95806 .38774 L
.95866 .39022 L
.96041 .39779 L
.96202 .40536 L
.96351 .41293 L
.96487 .4205 L
.96563 .42504 L
.9661 .42807 L
.96721 .43565 L
.96819 .44322 L
.96905 .45079 L
.96978 .45836 L
.97039 .46593 L
.97088 .4735 L
.97125 .48107 L
.97149 .48864 L
.97161 .49621 L
.97161 .50379 L
.97149 .51136 L
.97125 .51893 L
.97088 .5265 L
.97039 .53407 L
.96978 .54164 L
.96905 .54921 L
.96819 .55678 L
.96721 .56435 L
.9661 .57193 L
.96563 .57496 L
.96487 .5795 L
.96351 .58707 L
.96202 .59464 L
.96041 .60221 L
.95866 .60978 L
.95806 .61226 L
.95678 .61735 L
.95476 .62492 L
.95261 .6325 L
.95048 .63955 L
.95032 .64007 L
.9479 .64764 L
.94533 .65521 L
.94291 .66196 L
.94261 .66278 L
.93975 .67035 L
.93674 .67792 L
.93534 .68131 L
.93357 .68549 L
.93025 .69306 L
.92777 .69849 L
.92677 .70064 L
.92312 .70821 L
.9202 .71404 L
.91931 .71578 L
.91532 .72335 L
.91263 .72828 L
.91116 .73092 L
.90681 .73849 L
.90506 .74145 L
.90227 .74606 L
.89753 .75363 L
.89749 .75371 L
.8926 .76121 L
.88992 .76519 L
.88745 .76878 L
.88234 .77598 L
.88208 .77635 L
.87648 .78392 L
.87477 .78617 L
.87065 .79149 L
.8672 .79582 L
.86456 .79906 L
.85963 .80497 L
.85821 .80663 L
.85206 .81367 L
.85159 .8142 L
.84467 .82177 L
.84449 .82197 L
.83743 .82935 L
.83692 .82987 L
.82987 .83692 L
.82935 .83743 L
.82195 .84449 L
.82177 .84465 L
.8142 .85157 L
.81365 .85206 L
.80663 .85818 L
.80493 .85963 L
.79906 .86453 L
.79577 .8672 L
.79149 .87061 L
.78611 .87477 L
.78392 .87644 L
.77635 .88203 L
.77591 .88234 L
.76878 .88739 L
.7651 .88992 L
.76121 .89253 L
.75363 .89746 L
.7536 .89749 L
.74606 .90219 L
.74132 .90506 L
.73849 .90673 L
.73092 .91107 L
.72813 .91263 L
.72335 .91523 L
.71578 .91922 L
.71386 .9202 L
.70821 .92303 L
.70064 .92667 L
.69828 .92777 L
.69306 .93015 L
.68549 .93347 L
.68105 .93534 L
.67792 .93663 L
.67035 .93964 L
.66278 .9425 L
.66164 .94291 L
.65521 .94521 L
.64764 .94778 L
.64007 .9502 L
.63915 .95048 L
.6325 .95249 L
.62492 .95464 L
.61735 .95665 L
.61174 .95806 L
.60978 .95853 L
.60221 .96027 L
.59464 .96189 L
.58707 .96338 L
.5795 .96474 L
.57411 .96563 L
.57193 .96597 L
.56435 .96707 L
.55678 .96806 L
.54921 .96891 L
.54164 .96964 L
.53407 .97025 L
.5265 .97074 L
.51893 .97111 L
.51136 .97135 L
.50379 .97147 L
.49621 .97147 L
.48864 .97135 L
.48107 .97111 L
.4735 .97074 L
.46593 .97025 L
.45836 .96964 L
.45079 .96891 L
.44322 .96805 L
.43565 .96707 L
.42807 .96597 L
.4259 .96563 L
.4205 .96474 L
.41293 .96338 L
.40536 .96189 L
.39779 .96027 L
.39022 .95853 L
.38827 .95806 L
.38265 .95665 L
.37508 .95464 L
.3675 .95249 L
.36085 .95048 L
.35993 .9502 L
.35236 .94778 L
.34479 .94521 L
.33836 .94291 L
.33722 .9425 L
.32965 .93964 L
.32208 .93663 L
.31895 .93534 L
.31451 .93347 L
.30694 .93015 L
.30172 .92777 L
.29936 .92667 L
.29179 .92303 L
.28614 .9202 L
.28422 .91922 L
.27665 .91523 L
.27187 .91263 L
.26908 .91107 L
.26151 .90673 L
.25868 .90506 L
.25394 .90219 L
.2464 .89749 L
.24637 .89746 L
.23879 .89253 L
.2349 .88992 L
.23122 .88739 L
.22409 .88234 L
.22365 .88203 L
.21608 .87644 L
.21389 .87477 L
.20851 .87061 L
.20423 .8672 L
.20094 .86453 L
.19506 .85963 L
.19337 .85819 L
.18635 .85206 L
.1858 .85157 L
.17823 .84465 L
.17805 .84449 L
.17065 .83743 L
.17013 .83692 L
.16308 .82988 L
.16256 .82935 L
.15551 .82197 L
.15533 .82177 L
.14841 .8142 L
.14794 .81367 L
.14179 .80663 L
.14037 .80497 L
.13544 .79906 L
.1328 .79582 L
.12935 .79149 L
.12523 .78617 L
.12352 .78392 L
.11792 .77635 L
.11766 .77598 L
.11255 .76878 L
.11008 .76519 L
.1074 .76121 L
.10251 .75371 L
.10247 .75363 L
.09773 .74606 L
.09494 .74145 L
.09319 .73849 L
.08884 .73092 L
.08737 .72828 L
.08468 .72335 L
.08069 .71578 L
.0798 .71404 L
.07688 .70821 L
.07323 .70064 L
.07223 .69849 L
.06975 .69306 L
.06643 .68549 L
.06466 .68131 L
.06326 .67792 L
.06025 .67035 L
.05739 .66278 L
.05709 .66196 L
.05468 .65521 L
.05211 .64764 L
.04968 .64007 L
.04952 .63955 L
.04739 .6325 L
.04524 .62492 L
.04322 .61735 L
.04194 .61226 L
.04134 .60978 L
.0396 .60221 L
.03798 .59464 L
.03649 .58707 L
.03513 .5795 L
.03437 .57495 L
.0339 .57193 L
.03279 .56435 L
.03181 .55678 L
.03095 .54921 L
.03022 .54164 L
.02961 .53407 L
.02912 .5265 L
.02875 .51893 L
.02851 .51136 L
.02839 .50379 L
.02839 .49621 L
.02851 .48864 L
.02875 .48107 L
.02912 .4735 L
.02961 .46593 L
.03022 .45836 L
.03095 .45079 L
.03181 .44322 L
.03279 .43565 L
.0339 .42807 L
.03437 .42505 L
.03513 .4205 L
.03649 .41293 L
.03798 .40536 L
.0396 .39779 L
.04134 .39022 L
.04194 .38774 L
.04322 .38265 L
.04524 .37508 L
.04739 .3675 L
.04952 .36045 L
.04968 .35993 L
.05211 .35236 L
.05468 .34479 L
.05709 .33804 L
.05739 .33722 L
.06025 .32965 L
.06326 .32208 L
.06466 .31869 L
.06643 .31451 L
.06975 .30694 L
.07223 .30151 L
.07323 .29936 L
.07688 .29179 L
.0798 .28596 L
.08069 .28422 L
.08468 .27665 L
.08737 .27172 L
.08884 .26908 L
.09319 .26151 L
.09494 .25855 L
.09773 .25394 L
.10247 .24637 L
.10251 .24629 L
.1074 .23879 L
.11008 .23481 L
.11255 .23122 L
.11766 .22402 L
.11792 .22365 L
.12352 .21608 L
.12523 .21383 L
.12935 .20851 L
.1328 .20418 L
.13544 .20094 L
.14037 .19503 L
.14179 .19337 L
.14794 .18633 L
.14841 .1858 L
.15533 .17823 L
.15551 .17803 L
.16256 .17065 L
.16308 .17012 L
.17013 .16308 L
.17065 .16257 L
.17805 .15551 L
.17823 .15535 L
.1858 .14843 L
.18635 .14794 L
.19337 .14181 L
.19506 .14037 L
.20094 .13547 L
.20423 .1328 L
.20851 .12939 L
.21389 .12523 L
.21608 .12356 L
.22365 .11797 L
.22409 .11766 L
.23122 .11261 L
.2349 .11008 L
.23879 .10747 L
.24637 .10254 L
.2464 .10251 L
.25394 .09781 L
.25868 .09494 L
.26151 .09327 L
.26908 .08893 L
.27187 .08737 L
.27665 .08477 L
.28422 .08078 L
.28614 .0798 L
.29179 .07697 L
.29936 .07333 L
.30172 .07223 L
.30694 .06985 L
.31451 .06653 L
.31895 .06466 L
.32208 .06337 L
.32965 .06036 L
.33722 .0575 L
.33836 .05709 L
.34479 .05479 L
.35236 .05222 L
.35993 .0498 L
.36085 .04952 L
.3675 .04751 L
.37508 .04536 L
.38265 .04335 L
.38827 .04194 L
.39022 .04147 L
.39779 .03973 L
.40536 .03811 L
.41293 .03662 L
.4205 .03526 L
.4259 .03437 L
F
.755 .766 0 r
.44322 .04141 m
.45079 .04054 L
.45836 .03979 L
.46593 .03917 L
.4735 .03867 L
.48107 .0383 L
.48864 .03805 L
.49621 .03793 L
.50379 .03793 L
.51136 .03805 L
.51893 .0383 L
.5265 .03867 L
.53407 .03917 L
.54164 .03979 L
.54921 .04054 L
.55678 .04141 L
.56092 .04194 L
.56435 .04241 L
.57193 .04354 L
.5795 .0448 L
.58707 .04619 L
.59464 .04771 L
.60221 .04936 L
.6029 .04952 L
.60978 .05114 L
.61735 .05306 L
.62492 .05512 L
.63173 .05709 L
.6325 .05731 L
.64007 .05965 L
.64764 .06213 L
.65493 .06466 L
.65521 .06476 L
.66278 .06753 L
.67035 .07046 L
.67475 .07223 L
.67792 .07354 L
.68549 .07678 L
.69225 .0798 L
.69306 .08018 L
.70064 .08374 L
.708 .08737 L
.70821 .08748 L
.71578 .09138 L
.72239 .09494 L
.72335 .09547 L
.73092 .09974 L
.73566 .10251 L
.73849 .10421 L
.74606 .10887 L
.74799 .11008 L
.75363 .11373 L
.75951 .11766 L
.76121 .11881 L
.76878 .12411 L
.77033 .12523 L
.77635 .12964 L
.78053 .1328 L
.78392 .13541 L
.79018 .14037 L
.79149 .14143 L
.79906 .14772 L
.79932 .14794 L
.80663 .15428 L
.80801 .15551 L
.8142 .16115 L
.81628 .16308 L
.82177 .16832 L
.82416 .17065 L
.82935 .17584 L
.83168 .17823 L
.83692 .18371 L
.83887 .1858 L
.84449 .19197 L
.84574 .19337 L
.85206 .20064 L
.85231 .20094 L
.8586 .20851 L
.85963 .20978 L
.86463 .21608 L
.8672 .21941 L
.87041 .22365 L
.87477 .2296 L
.87594 .23122 L
.88125 .23879 L
.88234 .2404 L
.88633 .24637 L
.88992 .25191 L
.8912 .25394 L
.89586 .26151 L
.89749 .26422 L
.90033 .26908 L
.90461 .27665 L
.90506 .27747 L
.9087 .28422 L
.91261 .29179 L
.91263 .29183 L
.91635 .29936 L
.91992 .30694 L
.9202 .30755 L
.92332 .31451 L
.92656 .32208 L
.92777 .325 L
.92964 .32965 L
.93257 .33722 L
.93534 .34477 L
.93535 .34479 L
.93798 .35236 L
.94046 .35993 L
.9428 .3675 L
.94291 .36788 L
.945 .37508 L
.94706 .38265 L
.94898 .39022 L
.95048 .39656 L
.95076 .39779 L
.95242 .40536 L
.95394 .41293 L
.95532 .4205 L
.95658 .42807 L
.95771 .43565 L
.95806 .43812 L
.95872 .44322 L
.95959 .45079 L
.96034 .45836 L
.96096 .46593 L
.96146 .4735 L
.96183 .48107 L
.96208 .48864 L
.96221 .49621 L
.96221 .50379 L
.96208 .51136 L
.96183 .51893 L
.96146 .5265 L
.96096 .53407 L
.96034 .54164 L
.95959 .54921 L
.95872 .55678 L
.95806 .56188 L
.95771 .56435 L
.95658 .57193 L
.95532 .5795 L
.95394 .58707 L
.95242 .59464 L
.95076 .60221 L
.95048 .60344 L
.94898 .60978 L
.94706 .61735 L
.945 .62492 L
.94291 .63212 L
.9428 .6325 L
.94046 .64007 L
.93798 .64764 L
.93535 .65521 L
.93534 .65523 L
.93257 .66278 L
.92964 .67035 L
.92777 .675 L
.92656 .67792 L
.92332 .68549 L
.9202 .69245 L
.91992 .69306 L
.91635 .70064 L
.91263 .70817 L
.91261 .70821 L
.9087 .71578 L
.90506 .72253 L
.90461 .72335 L
.90033 .73092 L
.89749 .73578 L
.89586 .73849 L
.8912 .74606 L
.88992 .74809 L
.88633 .75363 L
.88234 .7596 L
.88125 .76121 L
.87594 .76878 L
.87477 .7704 L
.87041 .77635 L
.8672 .78059 L
.86463 .78392 L
.85963 .79022 L
.8586 .79149 L
.85231 .79906 L
.85206 .79936 L
.84574 .80663 L
.84449 .80803 L
.83887 .8142 L
.83692 .81629 L
.83168 .82177 L
.82935 .82416 L
.82416 .82935 L
.82177 .83168 L
.81628 .83692 L
.8142 .83885 L
.80801 .84449 L
.80663 .84572 L
.79932 .85206 L
.79906 .85228 L
.79149 .85857 L
.79018 .85963 L
.78392 .86459 L
.78053 .8672 L
.77635 .87036 L
.77033 .87477 L
.76878 .87589 L
.76121 .88119 L
.75951 .88234 L
.75363 .88627 L
.74799 .88992 L
.74606 .89113 L
.73849 .89579 L
.73566 .89749 L
.73092 .90026 L
.72335 .90453 L
.72239 .90506 L
.71578 .90862 L
.70821 .91252 L
.708 .91263 L
.70064 .91626 L
.69306 .91982 L
.69225 .9202 L
.68549 .92322 L
.67792 .92646 L
.67475 .92777 L
.67035 .92954 L
.66278 .93247 L
.65521 .93524 L
.65493 .93534 L
.64764 .93787 L
.64007 .94035 L
.6325 .94269 L
.63173 .94291 L
.62492 .94488 L
.61735 .94694 L
.60978 .94886 L
.6029 .95048 L
.60221 .95064 L
.59464 .95229 L
.58707 .95381 L
.5795 .9552 L
.57193 .95646 L
.56435 .95759 L
.56092 .95806 L
.55678 .95859 L
.54921 .95946 L
.54164 .96021 L
.53407 .96083 L
.5265 .96133 L
.51893 .9617 L
.51136 .96195 L
.50379 .96207 L
.49621 .96207 L
.48864 .96195 L
.48107 .9617 L
.4735 .96133 L
.46593 .96083 L
.45836 .96021 L
.45079 .95946 L
.44322 .95859 L
.43908 .95806 L
.43565 .95758 L
.42807 .95646 L
.4205 .9552 L
.41293 .95381 L
.40536 .95229 L
.39779 .95064 L
.3971 .95048 L
.39022 .94886 L
.38265 .94694 L
.37508 .94488 L
.36827 .94291 L
.3675 .94268 L
.35993 .94035 L
.35236 .93787 L
.34507 .93534 L
.34479 .93524 L
.33722 .93247 L
.32965 .92954 L
.32525 .92777 L
.32208 .92646 L
.31451 .92322 L
.30776 .9202 L
.30694 .91982 L
.29936 .91626 L
.292 .91263 L
.29179 .91252 L
.28422 .90862 L
.27761 .90506 L
.27665 .90453 L
.26908 .90026 L
.26434 .89749 L
.26151 .89579 L
.25394 .89113 L
.25201 .88992 L
.24637 .88627 L
.24049 .88234 L
.23879 .88119 L
.23122 .87589 L
.22967 .87477 L
.22365 .87036 L
.21947 .8672 L
.21608 .86459 L
.20982 .85963 L
.20851 .85857 L
.20094 .85228 L
.20067 .85206 L
.19337 .84572 L
.19199 .84449 L
.1858 .83885 L
.18372 .83692 L
.17823 .83168 L
.17584 .82935 L
.17065 .82416 L
.16832 .82177 L
.16308 .81629 L
.16113 .8142 L
.15551 .80803 L
.15426 .80663 L
.14794 .79936 L
.14769 .79906 L
.14139 .79149 L
.14037 .79023 L
.13537 .78392 L
.1328 .78059 L
.12959 .77635 L
.12523 .7704 L
.12406 .76878 L
.11875 .76121 L
.11766 .7596 L
.11367 .75363 L
.11008 .74809 L
.1088 .74606 L
.10414 .73849 L
.10251 .73578 L
.09967 .73092 L
.09539 .72335 L
.09494 .72254 L
.0913 .71578 L
.08739 .70821 L
.08737 .70818 L
.08365 .70064 L
.08008 .69306 L
.0798 .69245 L
.07668 .68549 L
.07344 .67792 L
.07223 .675 L
.07036 .67035 L
.06743 .66278 L
.06466 .65523 L
.06465 .65521 L
.06202 .64764 L
.05954 .64007 L
.0572 .6325 L
.05709 .63212 L
.055 .62492 L
.05294 .61735 L
.05102 .60978 L
.04952 .60343 L
.04924 .60221 L
.04758 .59464 L
.04606 .58707 L
.04468 .5795 L
.04342 .57193 L
.04229 .56435 L
.04194 .56187 L
.04129 .55678 L
.04041 .54921 L
.03966 .54164 L
.03904 .53407 L
.03854 .5265 L
.03817 .51893 L
.03792 .51136 L
.0378 .50379 L
.0378 .49621 L
.03792 .48864 L
.03817 .48107 L
.03854 .4735 L
.03904 .46593 L
.03966 .45836 L
.04041 .45079 L
.04129 .44322 L
.04194 .43813 L
.04229 .43565 L
.04342 .42807 L
.04468 .4205 L
.04606 .41293 L
.04758 .40536 L
.04924 .39779 L
.04952 .39657 L
.05102 .39022 L
.05294 .38265 L
.055 .37508 L
.05709 .36788 L
.0572 .3675 L
.05954 .35993 L
.06202 .35236 L
.06465 .34479 L
.06466 .34477 L
.06743 .33722 L
.07036 .32965 L
.07223 .325 L
.07344 .32208 L
.07668 .31451 L
.0798 .30755 L
.08008 .30694 L
.08365 .29936 L
.08737 .29182 L
.08739 .29179 L
.0913 .28422 L
.09494 .27746 L
.09539 .27665 L
.09967 .26908 L
.10251 .26422 L
.10414 .26151 L
.1088 .25394 L
.11008 .25191 L
.11367 .24637 L
.11766 .2404 L
.11875 .23879 L
.12406 .23122 L
.12523 .2296 L
.12959 .22365 L
.1328 .21941 L
.13537 .21608 L
.14037 .20977 L
.14139 .20851 L
.14769 .20094 L
.14794 .20064 L
.15426 .19337 L
.15551 .19197 L
.16113 .1858 L
.16308 .18371 L
.16832 .17823 L
.17065 .17584 L
.17584 .17065 L
.17823 .16832 L
.18372 .16308 L
.1858 .16115 L
.19199 .15551 L
.19337 .15428 L
.20067 .14794 L
.20094 .14772 L
.20851 .14143 L
.20982 .14037 L
.21608 .13541 L
.21947 .1328 L
.22365 .12964 L
.22967 .12523 L
.23122 .12411 L
.23879 .11881 L
.24049 .11766 L
.24637 .11373 L
.25201 .11008 L
.25394 .10887 L
.26151 .10421 L
.26434 .10251 L
.26908 .09974 L
.27665 .09547 L
.27761 .09494 L
.28422 .09138 L
.29179 .08748 L
.292 .08737 L
.29936 .08374 L
.30694 .08018 L
.30776 .0798 L
.31451 .07678 L
.32208 .07354 L
.32525 .07223 L
.32965 .07046 L
.33722 .06753 L
.34479 .06476 L
.34507 .06466 L
.35236 .06213 L
.35993 .05965 L
.3675 .05732 L
.36827 .05709 L
.37508 .05512 L
.38265 .05306 L
.39022 .05114 L
.3971 .04952 L
.39779 .04936 L
.40536 .04771 L
.41293 .04619 L
.4205 .0448 L
.42807 .04354 L
.43565 .04242 L
.43908 .04194 L
F
.679 .748 0 r
.45836 .04904 m
.46593 .0484 L
.4735 .04789 L
.48107 .04751 L
.48864 .04726 L
.49621 .04713 L
.50379 .04713 L
.51136 .04726 L
.51893 .04751 L
.5265 .04789 L
.53407 .0484 L
.54164 .04904 L
.54654 .04952 L
.54921 .0498 L
.55678 .05069 L
.56435 .05172 L
.57193 .05287 L
.5795 .05415 L
.58707 .05557 L
.59449 .05709 L
.59464 .05712 L
.60221 .0588 L
.60978 .06063 L
.61735 .06259 L
.62481 .06466 L
.62492 .06469 L
.6325 .06694 L
.64007 .06932 L
.64764 .07186 L
.6487 .07223 L
.65521 .07455 L
.66278 .07739 L
.66891 .0798 L
.67035 .08038 L
.67792 .08353 L
.68549 .08685 L
.68665 .08737 L
.69306 .09033 L
.70064 .09399 L
.70256 .09494 L
.70821 .09782 L
.71578 .10183 L
.71704 .10251 L
.72335 .10602 L
.73037 .11008 L
.73092 .11041 L
.73849 .115 L
.74273 .11766 L
.74606 .11979 L
.75363 .1248 L
.75426 .12523 L
.76121 .13003 L
.76508 .1328 L
.76878 .13549 L
.77527 .14037 L
.77635 .1412 L
.78392 .14715 L
.78489 .14794 L
.79149 .15338 L
.79401 .15551 L
.79906 .15989 L
.80266 .16308 L
.80663 .16669 L
.81088 .17065 L
.8142 .17382 L
.81872 .17823 L
.82177 .18128 L
.82619 .1858 L
.82935 .18911 L
.83332 .19337 L
.83692 .19732 L
.84013 .20094 L
.84449 .20596 L
.84665 .20851 L
.85206 .21506 L
.85288 .21608 L
.85884 .22365 L
.85963 .22468 L
.86455 .23122 L
.8672 .23485 L
.87002 .23879 L
.87477 .24565 L
.87525 .24637 L
.88027 .25394 L
.88234 .25717 L
.88506 .26151 L
.88966 .26908 L
.88992 .26952 L
.89405 .27665 L
.89749 .28282 L
.89825 .28422 L
.90226 .29179 L
.90506 .29728 L
.9061 .29936 L
.90975 .30694 L
.91263 .31315 L
.91324 .31451 L
.91656 .32208 L
.91971 .32965 L
.9202 .33085 L
.92271 .33722 L
.92555 .34479 L
.92777 .35101 L
.92824 .35236 L
.93078 .35993 L
.93317 .3675 L
.93534 .37481 L
.93542 .37508 L
.93752 .38265 L
.93948 .39022 L
.94131 .39779 L
.94291 .40497 L
.943 .40536 L
.94455 .41293 L
.94597 .4205 L
.94725 .42807 L
.9484 .43565 L
.94943 .44322 L
.95032 .45079 L
.95048 .4523 L
.95108 .45836 L
.95172 .46593 L
.95223 .4735 L
.95261 .48107 L
.95286 .48864 L
.95299 .49621 L
.95299 .50379 L
.95286 .51136 L
.95261 .51893 L
.95223 .5265 L
.95172 .53407 L
.95108 .54164 L
.95048 .5477 L
.95032 .54921 L
.94943 .55678 L
.9484 .56435 L
.94725 .57193 L
.94597 .5795 L
.94455 .58707 L
.943 .59464 L
.94291 .59503 L
.94131 .60221 L
.93948 .60978 L
.93752 .61735 L
.93542 .62492 L
.93534 .62519 L
.93317 .6325 L
.93078 .64007 L
.92824 .64764 L
.92777 .64899 L
.92555 .65521 L
.92271 .66278 L
.9202 .66915 L
.91971 .67035 L
.91656 .67792 L
.91324 .68549 L
.91263 .68685 L
.90975 .69306 L
.9061 .70064 L
.90506 .70272 L
.90226 .70821 L
.89825 .71578 L
.89749 .71718 L
.89405 .72335 L
.88992 .73048 L
.88966 .73092 L
.88506 .73849 L
.88234 .74283 L
.88027 .74606 L
.87525 .75363 L
.87477 .75435 L
.87002 .76121 L
.8672 .76515 L
.86455 .76878 L
.85963 .77532 L
.85884 .77635 L
.85288 .78392 L
.85206 .78494 L
.84665 .79149 L
.84449 .79404 L
.84013 .79906 L
.83692 .80268 L
.83332 .80663 L
.82935 .81089 L
.82619 .8142 L
.82177 .81872 L
.81872 .82177 L
.8142 .82618 L
.81088 .82935 L
.80663 .83331 L
.80266 .83692 L
.79906 .84011 L
.79401 .84449 L
.79149 .84662 L
.78489 .85206 L
.78392 .85285 L
.77635 .8588 L
.77527 .85963 L
.76878 .86451 L
.76508 .8672 L
.76121 .86997 L
.75426 .87477 L
.75363 .8752 L
.74606 .88021 L
.74273 .88234 L
.73849 .885 L
.73092 .88959 L
.73037 .88992 L
.72335 .89398 L
.71704 .89749 L
.71578 .89817 L
.70821 .90218 L
.70256 .90506 L
.70064 .90601 L
.69306 .90967 L
.68665 .91263 L
.68549 .91315 L
.67792 .91647 L
.67035 .91962 L
.66891 .9202 L
.66278 .92261 L
.65521 .92545 L
.6487 .92777 L
.64764 .92814 L
.64007 .93068 L
.6325 .93306 L
.62492 .93531 L
.62481 .93534 L
.61735 .93741 L
.60978 .93937 L
.60221 .9412 L
.59464 .94288 L
.59449 .94291 L
.58707 .94443 L
.5795 .94585 L
.57193 .94713 L
.56435 .94828 L
.55678 .94931 L
.54921 .9502 L
.54654 .95048 L
.54164 .95096 L
.53407 .9516 L
.5265 .95211 L
.51893 .95249 L
.51136 .95274 L
.50379 .95287 L
.49621 .95287 L
.48864 .95274 L
.48107 .95249 L
.4735 .95211 L
.46593 .9516 L
.45836 .95096 L
.45346 .95048 L
.45079 .9502 L
.44322 .94931 L
.43565 .94828 L
.42807 .94713 L
.4205 .94585 L
.41293 .94443 L
.40551 .94291 L
.40536 .94288 L
.39779 .94119 L
.39022 .93937 L
.38265 .93741 L
.37519 .93534 L
.37508 .93531 L
.3675 .93306 L
.35993 .93067 L
.35236 .92814 L
.3513 .92777 L
.34479 .92545 L
.33722 .92261 L
.33109 .9202 L
.32965 .91962 L
.32208 .91647 L
.31451 .91315 L
.31335 .91263 L
.30694 .90967 L
.29936 .90601 L
.29744 .90506 L
.29179 .90218 L
.28422 .89817 L
.28296 .89749 L
.27665 .89398 L
.26963 .88992 L
.26908 .88959 L
.26151 .885 L
.25727 .88234 L
.25394 .88021 L
.24637 .8752 L
.24574 .87477 L
.23879 .86997 L
.23492 .8672 L
.23122 .86451 L
.22473 .85963 L
.22365 .85881 L
.21608 .85285 L
.2151 .85206 L
.20851 .84662 L
.20599 .84449 L
.20094 .84011 L
.19734 .83692 L
.19337 .83331 L
.18912 .82935 L
.1858 .82618 L
.18128 .82177 L
.17823 .81872 L
.17381 .8142 L
.17065 .8109 L
.16668 .80663 L
.16308 .80268 L
.15987 .79906 L
.15551 .79404 L
.15335 .79149 L
.14794 .78494 L
.14712 .78392 L
.14115 .77635 L
.14037 .77533 L
.13545 .76878 L
.1328 .76515 L
.12998 .76121 L
.12523 .75435 L
.12474 .75363 L
.11973 .74606 L
.11766 .74283 L
.11494 .73849 L
.11034 .73092 L
.11008 .73048 L
.10595 .72335 L
.10251 .71718 L
.10175 .71578 L
.09774 .70821 L
.09494 .70272 L
.0939 .70064 L
.09025 .69306 L
.08737 .68685 L
.08676 .68549 L
.08344 .67792 L
.08029 .67035 L
.0798 .66915 L
.07729 .66278 L
.07445 .65521 L
.07223 .64899 L
.07176 .64764 L
.06922 .64007 L
.06683 .6325 L
.06466 .62519 L
.06458 .62492 L
.06248 .61735 L
.06052 .60978 L
.05869 .60221 L
.05709 .59502 L
.057 .59464 L
.05545 .58707 L
.05403 .5795 L
.05275 .57193 L
.0516 .56435 L
.05057 .55678 L
.04968 .54921 L
.04952 .54769 L
.04892 .54164 L
.04828 .53407 L
.04777 .5265 L
.04739 .51893 L
.04714 .51136 L
.04701 .50379 L
.04701 .49621 L
.04714 .48864 L
.04739 .48107 L
.04777 .4735 L
.04828 .46593 L
.04892 .45836 L
.04952 .45231 L
.04968 .45079 L
.05057 .44322 L
.0516 .43565 L
.05275 .42807 L
.05403 .4205 L
.05545 .41293 L
.057 .40536 L
.05709 .40498 L
.05869 .39779 L
.06052 .39022 L
.06248 .38265 L
.06458 .37508 L
.06466 .37481 L
.06683 .3675 L
.06922 .35993 L
.07176 .35236 L
.07223 .35101 L
.07445 .34479 L
.07729 .33722 L
.0798 .33085 L
.08029 .32965 L
.08344 .32208 L
.08676 .31451 L
.08737 .31315 L
.09025 .30694 L
.0939 .29936 L
.09494 .29728 L
.09774 .29179 L
.10175 .28422 L
.10251 .28282 L
.10595 .27665 L
.11008 .26952 L
.11034 .26908 L
.11494 .26151 L
.11766 .25717 L
.11973 .25394 L
.12474 .24637 L
.12523 .24565 L
.12998 .23879 L
.1328 .23485 L
.13545 .23122 L
.14037 .22467 L
.14115 .22365 L
.14712 .21608 L
.14794 .21506 L
.15335 .20851 L
.15551 .20596 L
.15987 .20094 L
.16308 .19732 L
.16668 .19337 L
.17065 .1891 L
.17381 .1858 L
.17823 .18128 L
.18128 .17823 L
.1858 .17382 L
.18912 .17065 L
.19337 .16669 L
.19734 .16308 L
.20094 .15989 L
.20599 .15551 L
.20851 .15338 L
.2151 .14794 L
.21608 .14715 L
.22365 .14119 L
.22473 .14037 L
.23122 .13549 L
.23492 .1328 L
.23879 .13003 L
.24574 .12523 L
.24637 .1248 L
.25394 .11979 L
.25727 .11766 L
.26151 .115 L
.26908 .11041 L
.26963 .11008 L
.27665 .10602 L
.28296 .10251 L
.28422 .10183 L
.29179 .09782 L
.29744 .09494 L
.29936 .09399 L
.30694 .09033 L
.31335 .08737 L
.31451 .08685 L
.32208 .08353 L
.32965 .08038 L
.33109 .0798 L
.33722 .07739 L
.34479 .07455 L
.3513 .07223 L
.35236 .07186 L
.35993 .06933 L
.3675 .06694 L
.37508 .06469 L
.37519 .06466 L
.38265 .06259 L
.39022 .06063 L
.39779 .05881 L
.40536 .05712 L
.40551 .05709 L
.41293 .05557 L
.4205 .05415 L
.42807 .05287 L
.43565 .05172 L
.44322 .05069 L
.45079 .0498 L
.45346 .04952 L
F
.606 .73 0 r
.4735 .05696 m
.48107 .05657 L
.48864 .05631 L
.49621 .05619 L
.50379 .05619 L
.51136 .05631 L
.51893 .05657 L
.5265 .05696 L
.52855 .05709 L
.53407 .05748 L
.54164 .05813 L
.54921 .05891 L
.55678 .05982 L
.56435 .06086 L
.57193 .06204 L
.5795 .06335 L
.58638 .06466 L
.58707 .06479 L
.59464 .06638 L
.60221 .0681 L
.60978 .06996 L
.61735 .07197 L
.6183 .07223 L
.62492 .07412 L
.6325 .07641 L
.64007 .07885 L
.64288 .0798 L
.64764 .08145 L
.65521 .0842 L
.66278 .0871 L
.66346 .08737 L
.67035 .09017 L
.67792 .0934 L
.68142 .09494 L
.68549 .09679 L
.69306 .10036 L
.69745 .10251 L
.70064 .10411 L
.70821 .10804 L
.71202 .11008 L
.71578 .11215 L
.72335 .11646 L
.72538 .11766 L
.73092 .12097 L
.73776 .12523 L
.73849 .12569 L
.74606 .13062 L
.7493 .1328 L
.75363 .13578 L
.76011 .14037 L
.76121 .14117 L
.76878 .1468 L
.77027 .14794 L
.77635 .15269 L
.77986 .15551 L
.78392 .15885 L
.78893 .16308 L
.79149 .16529 L
.79754 .17065 L
.79906 .17204 L
.80571 .17823 L
.80663 .1791 L
.81349 .1858 L
.8142 .18651 L
.82091 .19337 L
.82177 .19428 L
.82798 .20094 L
.82935 .20245 L
.83473 .20851 L
.83692 .21104 L
.84118 .21608 L
.84449 .22011 L
.84734 .22365 L
.85206 .22968 L
.85324 .23122 L
.85888 .23879 L
.85963 .23983 L
.86427 .24637 L
.8672 .25062 L
.86943 .25394 L
.87437 .26151 L
.87477 .26215 L
.87909 .26908 L
.88234 .27451 L
.8836 .27665 L
.88791 .28422 L
.88992 .28785 L
.89203 .29179 L
.89597 .29936 L
.89749 .30239 L
.89972 .30694 L
.90329 .31451 L
.90506 .3184 L
.90669 .32208 L
.90992 .32965 L
.91263 .33631 L
.91299 .33722 L
.9159 .34479 L
.91865 .35236 L
.9202 .35683 L
.92124 .35993 L
.92369 .3675 L
.92599 .37508 L
.92777 .38133 L
.92814 .38265 L
.93014 .39022 L
.93201 .39779 L
.93373 .40536 L
.93531 .41293 L
.93534 .41307 L
.93676 .4205 L
.93807 .42807 L
.93925 .43565 L
.9403 .44322 L
.94121 .45079 L
.94199 .45836 L
.94264 .46593 L
.94291 .46971 L
.94315 .4735 L
.94354 .48107 L
.9438 .48864 L
.94393 .49621 L
.94393 .50379 L
.9438 .51136 L
.94354 .51893 L
.94315 .5265 L
.94291 .53029 L
.94264 .53407 L
.94199 .54164 L
.94121 .54921 L
.9403 .55678 L
.93925 .56435 L
.93807 .57193 L
.93676 .5795 L
.93534 .58693 L
.93531 .58707 L
.93373 .59464 L
.93201 .60221 L
.93014 .60978 L
.92814 .61735 L
.92777 .61867 L
.92599 .62492 L
.92369 .6325 L
.92124 .64007 L
.9202 .64317 L
.91865 .64764 L
.9159 .65521 L
.91299 .66278 L
.91263 .66369 L
.90992 .67035 L
.90669 .67792 L
.90506 .6816 L
.90329 .68549 L
.89972 .69306 L
.89749 .69761 L
.89597 .70064 L
.89203 .70821 L
.88992 .71215 L
.88791 .71578 L
.8836 .72335 L
.88234 .72549 L
.87909 .73092 L
.87477 .73785 L
.87437 .73849 L
.86943 .74606 L
.8672 .74938 L
.86427 .75363 L
.85963 .76017 L
.85888 .76121 L
.85324 .76878 L
.85206 .77032 L
.84734 .77635 L
.84449 .77989 L
.84118 .78392 L
.83692 .78896 L
.83473 .79149 L
.82935 .79755 L
.82798 .79906 L
.82177 .80572 L
.82091 .80663 L
.8142 .81349 L
.81349 .8142 L
.80663 .8209 L
.80571 .82177 L
.79906 .82796 L
.79754 .82935 L
.79149 .83471 L
.78893 .83692 L
.78392 .84115 L
.77986 .84449 L
.77635 .84731 L
.77027 .85206 L
.76878 .8532 L
.76121 .85883 L
.76011 .85963 L
.75363 .86422 L
.7493 .8672 L
.74606 .86938 L
.73849 .87431 L
.73776 .87477 L
.73092 .87903 L
.72538 .88234 L
.72335 .88354 L
.71578 .88785 L
.71202 .88992 L
.70821 .89196 L
.70064 .89589 L
.69745 .89749 L
.69306 .89964 L
.68549 .90321 L
.68142 .90506 L
.67792 .9066 L
.67035 .90983 L
.66346 .91263 L
.66278 .9129 L
.65521 .9158 L
.64764 .91855 L
.64288 .9202 L
.64007 .92115 L
.6325 .92359 L
.62492 .92588 L
.6183 .92777 L
.61735 .92803 L
.60978 .93004 L
.60221 .9319 L
.59464 .93362 L
.58707 .93521 L
.58638 .93534 L
.5795 .93665 L
.57193 .93796 L
.56435 .93914 L
.55678 .94018 L
.54921 .94109 L
.54164 .94187 L
.53407 .94252 L
.52855 .94291 L
.5265 .94304 L
.51893 .94343 L
.51136 .94369 L
.50379 .94381 L
.49621 .94381 L
.48864 .94369 L
.48107 .94343 L
.4735 .94304 L
.47145 .94291 L
.46593 .94252 L
.45836 .94187 L
.45079 .94109 L
.44322 .94018 L
.43565 .93914 L
.42807 .93796 L
.4205 .93665 L
.41362 .93534 L
.41293 .9352 L
.40536 .93362 L
.39779 .9319 L
.39022 .93004 L
.38265 .92803 L
.3817 .92777 L
.37508 .92588 L
.3675 .92359 L
.35993 .92115 L
.35712 .9202 L
.35236 .91855 L
.34479 .9158 L
.33722 .9129 L
.33654 .91263 L
.32965 .90983 L
.32208 .9066 L
.31858 .90506 L
.31451 .90321 L
.30694 .89964 L
.30255 .89749 L
.29936 .89589 L
.29179 .89196 L
.28799 .88992 L
.28422 .88785 L
.27665 .88354 L
.27462 .88234 L
.26908 .87903 L
.26224 .87477 L
.26151 .87431 L
.25394 .86938 L
.2507 .8672 L
.24637 .86422 L
.23989 .85963 L
.23879 .85883 L
.23122 .8532 L
.22973 .85206 L
.22365 .84731 L
.22014 .84449 L
.21608 .84115 L
.21107 .83692 L
.20851 .83471 L
.20246 .82935 L
.20094 .82796 L
.19429 .82177 L
.19337 .8209 L
.18651 .8142 L
.1858 .81349 L
.17909 .80663 L
.17823 .80572 L
.17202 .79906 L
.17065 .79755 L
.16527 .79149 L
.16308 .78896 L
.15882 .78392 L
.15551 .7799 L
.15266 .77635 L
.14794 .77032 L
.14676 .76878 L
.14112 .76121 L
.14037 .76017 L
.13573 .75363 L
.1328 .74938 L
.13057 .74606 L
.12563 .73849 L
.12523 .73786 L
.12091 .73092 L
.11766 .72549 L
.1164 .72335 L
.11208 .71578 L
.11008 .71215 L
.10797 .70821 L
.10403 .70064 L
.10251 .69761 L
.10028 .69306 L
.09671 .68549 L
.09494 .6816 L
.09331 .67792 L
.09008 .67035 L
.08737 .66369 L
.08701 .66278 L
.0841 .65521 L
.08135 .64764 L
.0798 .64316 L
.07876 .64007 L
.07631 .6325 L
.07401 .62492 L
.07223 .61867 L
.07186 .61735 L
.06986 .60978 L
.068 .60221 L
.06627 .59464 L
.06469 .58707 L
.06466 .58692 L
.06324 .5795 L
.06193 .57193 L
.06075 .56435 L
.05971 .55678 L
.05879 .54921 L
.05801 .54164 L
.05737 .53407 L
.05709 .53028 L
.05685 .5265 L
.05646 .51893 L
.0562 .51136 L
.05607 .50379 L
.05607 .49621 L
.0562 .48864 L
.05646 .48107 L
.05685 .4735 L
.05709 .46972 L
.05737 .46593 L
.05801 .45836 L
.05879 .45079 L
.05971 .44322 L
.06075 .43565 L
.06193 .42807 L
.06324 .4205 L
.06466 .41308 L
.06469 .41293 L
.06627 .40536 L
.068 .39779 L
.06986 .39022 L
.07186 .38265 L
.07223 .38133 L
.07401 .37508 L
.07631 .3675 L
.07876 .35993 L
.0798 .35684 L
.08135 .35236 L
.0841 .34479 L
.08701 .33722 L
.08737 .33631 L
.09008 .32965 L
.09331 .32208 L
.09494 .3184 L
.09671 .31451 L
.10028 .30694 L
.10251 .30239 L
.10403 .29936 L
.10797 .29179 L
.11008 .28785 L
.11208 .28422 L
.1164 .27665 L
.11766 .27451 L
.12091 .26908 L
.12523 .26214 L
.12563 .26151 L
.13057 .25394 L
.1328 .25062 L
.13573 .24637 L
.14037 .23983 L
.14112 .23879 L
.14676 .23122 L
.14794 .22968 L
.15266 .22365 L
.15551 .2201 L
.15882 .21608 L
.16308 .21104 L
.16527 .20851 L
.17065 .20245 L
.17202 .20094 L
.17823 .19428 L
.17909 .19337 L
.1858 .18651 L
.18651 .1858 L
.19337 .1791 L
.19429 .17823 L
.20094 .17204 L
.20246 .17065 L
.20851 .16529 L
.21107 .16308 L
.21608 .15885 L
.22014 .15551 L
.22365 .15269 L
.22973 .14794 L
.23122 .1468 L
.23879 .14117 L
.23989 .14037 L
.24637 .13578 L
.2507 .1328 L
.25394 .13062 L
.26151 .12569 L
.26224 .12523 L
.26908 .12097 L
.27462 .11766 L
.27665 .11646 L
.28422 .11215 L
.28799 .11008 L
.29179 .10804 L
.29936 .10411 L
.30255 .10251 L
.30694 .10036 L
.31451 .09679 L
.31858 .09494 L
.32208 .0934 L
.32965 .09017 L
.33654 .08737 L
.33722 .0871 L
.34479 .0842 L
.35236 .08145 L
.35712 .0798 L
.35993 .07885 L
.3675 .07641 L
.37508 .07412 L
.3817 .07223 L
.38265 .07197 L
.39022 .06996 L
.39779 .0681 L
.40536 .06638 L
.41293 .0648 L
.41362 .06466 L
.4205 .06335 L
.42807 .06204 L
.43565 .06086 L
.44322 .05982 L
.45079 .05891 L
.45836 .05813 L
.46593 .05748 L
.47145 .05709 L
F
.535 .712 0 r
.42807 .07108 m
.43565 .06988 L
.44322 .06881 L
.45079 .06789 L
.45836 .06709 L
.46593 .06643 L
.4735 .0659 L
.48107 .0655 L
.48864 .06524 L
.49621 .06511 L
.50379 .06511 L
.51136 .06524 L
.51893 .0655 L
.5265 .0659 L
.53407 .06643 L
.54164 .06709 L
.54921 .06788 L
.55678 .06881 L
.56435 .06988 L
.57193 .07108 L
.57847 .07223 L
.5795 .07242 L
.58707 .0739 L
.59464 .07551 L
.60221 .07727 L
.60978 .07918 L
.61214 .0798 L
.61735 .08123 L
.62492 .08342 L
.6325 .08577 L
.63741 .08737 L
.64007 .08827 L
.64764 .09092 L
.65521 .09373 L
.65834 .09494 L
.66278 .09671 L
.67035 .09985 L
.67649 .10251 L
.67792 .10315 L
.68549 .10664 L
.69264 .11008 L
.69306 .1103 L
.70064 .11414 L
.70726 .11766 L
.70821 .11817 L
.71578 .1224 L
.72066 .12523 L
.72335 .12683 L
.73092 .13146 L
.73304 .1328 L
.73849 .13631 L
.74456 .14037 L
.74606 .14139 L
.75363 .14671 L
.75535 .14794 L
.76121 .15226 L
.76547 .15551 L
.76878 .15808 L
.77502 .16308 L
.77635 .16417 L
.78392 .17054 L
.78405 .17065 L
.79149 .17722 L
.7926 .17823 L
.79906 .18422 L
.80072 .1858 L
.80663 .19156 L
.80844 .19337 L
.8142 .19927 L
.81579 .20094 L
.82177 .20738 L
.8228 .20851 L
.82935 .21593 L
.82948 .21608 L
.83586 .22365 L
.83692 .22494 L
.84195 .23122 L
.84449 .23448 L
.84777 .23879 L
.85206 .2446 L
.85334 .24637 L
.85865 .25394 L
.85963 .25537 L
.86374 .26151 L
.8672 .26687 L
.86859 .26908 L
.87323 .27665 L
.87477 .27924 L
.87766 .28422 L
.88189 .29179 L
.88234 .29262 L
.88593 .29936 L
.88978 .30694 L
.88992 .30722 L
.89344 .31451 L
.89692 .32208 L
.89749 .32334 L
.90023 .32965 L
.90338 .33722 L
.90506 .34144 L
.90635 .34479 L
.90917 .35236 L
.91182 .35993 L
.91263 .36232 L
.91432 .3675 L
.91667 .37508 L
.91887 .38265 L
.9202 .3875 L
.92092 .39022 L
.92282 .39779 L
.92458 .40536 L
.9262 .41293 L
.92768 .4205 L
.92777 .42098 L
.92902 .42807 L
.93022 .43565 L
.93129 .44322 L
.93222 .45079 L
.93302 .45836 L
.93368 .46593 L
.93421 .4735 L
.9346 .48107 L
.93487 .48864 L
.935 .49621 L
.935 .50379 L
.93487 .51136 L
.9346 .51893 L
.93421 .5265 L
.93368 .53407 L
.93302 .54164 L
.93222 .54921 L
.93129 .55678 L
.93022 .56435 L
.92902 .57193 L
.92777 .57902 L
.92768 .5795 L
.9262 .58707 L
.92458 .59464 L
.92282 .60221 L
.92092 .60978 L
.9202 .6125 L
.91887 .61735 L
.91667 .62492 L
.91432 .6325 L
.91263 .63768 L
.91182 .64007 L
.90917 .64764 L
.90635 .65521 L
.90506 .65856 L
.90338 .66278 L
.90023 .67035 L
.89749 .67666 L
.89692 .67792 L
.89344 .68549 L
.88992 .69278 L
.88978 .69306 L
.88593 .70064 L
.88234 .70738 L
.88189 .70821 L
.87766 .71578 L
.87477 .72076 L
.87323 .72335 L
.86859 .73092 L
.8672 .73313 L
.86374 .73849 L
.85963 .74463 L
.85865 .74606 L
.85334 .75363 L
.85206 .7554 L
.84777 .76121 L
.84449 .76552 L
.84195 .76878 L
.83692 .77506 L
.83586 .77635 L
.82948 .78392 L
.82935 .78407 L
.8228 .79149 L
.82177 .79262 L
.81579 .79906 L
.8142 .80073 L
.80844 .80663 L
.80663 .80844 L
.80072 .8142 L
.79906 .81578 L
.7926 .82177 L
.79149 .82278 L
.78405 .82935 L
.78392 .82946 L
.77635 .83583 L
.77502 .83692 L
.76878 .84192 L
.76547 .84449 L
.76121 .84774 L
.75535 .85206 L
.75363 .85329 L
.74606 .85861 L
.74456 .85963 L
.73849 .86369 L
.73304 .8672 L
.73092 .86854 L
.72335 .87317 L
.72066 .87477 L
.71578 .8776 L
.70821 .88183 L
.70726 .88234 L
.70064 .88586 L
.69306 .8897 L
.69264 .88992 L
.68549 .89336 L
.67792 .89685 L
.67649 .89749 L
.67035 .90015 L
.66278 .90329 L
.65834 .90506 L
.65521 .90627 L
.64764 .90908 L
.64007 .91173 L
.63741 .91263 L
.6325 .91423 L
.62492 .91658 L
.61735 .91877 L
.61214 .9202 L
.60978 .92082 L
.60221 .92273 L
.59464 .92449 L
.58707 .9261 L
.5795 .92758 L
.57847 .92777 L
.57193 .92892 L
.56435 .93012 L
.55678 .93119 L
.54921 .93212 L
.54164 .93291 L
.53407 .93357 L
.5265 .9341 L
.51893 .9345 L
.51136 .93476 L
.50379 .93489 L
.49621 .93489 L
.48864 .93476 L
.48107 .9345 L
.4735 .9341 L
.46593 .93357 L
.45836 .93291 L
.45079 .93211 L
.44322 .93119 L
.43565 .93012 L
.42807 .92892 L
.42154 .92777 L
.4205 .92758 L
.41293 .9261 L
.40536 .92448 L
.39779 .92273 L
.39022 .92082 L
.38786 .9202 L
.38265 .91877 L
.37508 .91658 L
.3675 .91423 L
.36259 .91263 L
.35993 .91173 L
.35236 .90908 L
.34479 .90627 L
.34166 .90506 L
.33722 .90329 L
.32965 .90015 L
.32351 .89749 L
.32208 .89685 L
.31451 .89336 L
.30736 .88992 L
.30694 .8897 L
.29936 .88586 L
.29274 .88234 L
.29179 .88183 L
.28422 .8776 L
.27934 .87477 L
.27665 .87317 L
.26908 .86854 L
.26696 .8672 L
.26151 .86369 L
.25544 .85963 L
.25394 .85861 L
.24637 .85329 L
.24465 .85206 L
.23879 .84774 L
.23453 .84449 L
.23122 .84192 L
.22498 .83692 L
.22365 .83583 L
.21608 .82946 L
.21595 .82935 L
.20851 .82278 L
.2074 .82177 L
.20094 .81578 L
.19928 .8142 L
.19337 .80844 L
.19156 .80663 L
.1858 .80073 L
.18421 .79906 L
.17823 .79262 L
.1772 .79149 L
.17065 .78407 L
.17052 .78392 L
.16414 .77635 L
.16308 .77506 L
.15805 .76878 L
.15551 .76552 L
.15223 .76121 L
.14794 .7554 L
.14666 .75363 L
.14135 .74606 L
.14037 .74464 L
.13626 .73849 L
.1328 .73313 L
.13141 .73092 L
.12677 .72335 L
.12523 .72076 L
.12233 .71578 L
.11811 .70821 L
.11766 .70738 L
.11407 .70064 L
.11022 .69306 L
.11008 .69278 L
.10656 .68549 L
.10308 .67792 L
.10251 .67666 L
.09977 .67035 L
.09662 .66278 L
.09494 .65855 L
.09365 .65521 L
.09083 .64764 L
.08818 .64007 L
.08737 .63768 L
.08568 .6325 L
.08333 .62492 L
.08113 .61735 L
.0798 .6125 L
.07908 .60978 L
.07718 .60221 L
.07542 .59464 L
.0738 .58707 L
.07232 .5795 L
.07223 .57902 L
.07098 .57193 L
.06978 .56435 L
.06871 .55678 L
.06778 .54921 L
.06698 .54164 L
.06632 .53407 L
.06579 .5265 L
.0654 .51893 L
.06513 .51136 L
.065 .50379 L
.065 .49621 L
.06513 .48864 L
.0654 .48107 L
.06579 .4735 L
.06632 .46593 L
.06698 .45836 L
.06778 .45079 L
.06871 .44322 L
.06978 .43565 L
.07098 .42807 L
.07223 .42098 L
.07232 .4205 L
.0738 .41293 L
.07542 .40536 L
.07718 .39779 L
.07908 .39022 L
.0798 .3875 L
.08113 .38265 L
.08333 .37508 L
.08568 .3675 L
.08737 .36232 L
.08818 .35993 L
.09083 .35236 L
.09365 .34479 L
.09494 .34145 L
.09662 .33722 L
.09977 .32965 L
.10251 .32334 L
.10308 .32208 L
.10656 .31451 L
.11008 .30722 L
.11022 .30694 L
.11407 .29936 L
.11766 .29262 L
.11811 .29179 L
.12233 .28422 L
.12523 .27924 L
.12677 .27665 L
.13141 .26908 L
.1328 .26687 L
.13626 .26151 L
.14037 .25536 L
.14135 .25394 L
.14666 .24637 L
.14794 .2446 L
.15223 .23879 L
.15551 .23448 L
.15805 .23122 L
.16308 .22494 L
.16414 .22365 L
.17052 .21608 L
.17065 .21593 L
.1772 .20851 L
.17823 .20738 L
.18421 .20094 L
.1858 .19927 L
.19156 .19337 L
.19337 .19156 L
.19928 .1858 L
.20094 .18422 L
.2074 .17823 L
.20851 .17722 L
.21595 .17065 L
.21608 .17054 L
.22365 .16417 L
.22498 .16308 L
.23122 .15808 L
.23453 .15551 L
.23879 .15226 L
.24465 .14794 L
.24637 .14671 L
.25394 .14139 L
.25544 .14037 L
.26151 .13631 L
.26696 .1328 L
.26908 .13146 L
.27665 .12683 L
.27934 .12523 L
.28422 .1224 L
.29179 .11817 L
.29274 .11766 L
.29936 .11414 L
.30694 .1103 L
.30736 .11008 L
.31451 .10664 L
.32208 .10315 L
.32351 .10251 L
.32965 .09985 L
.33722 .09671 L
.34166 .09494 L
.34479 .09373 L
.35236 .09092 L
.35993 .08827 L
.36259 .08737 L
.3675 .08577 L
.37508 .08342 L
.38265 .08123 L
.38786 .0798 L
.39022 .07918 L
.39779 .07727 L
.40536 .07552 L
.41293 .0739 L
.4205 .07242 L
.42154 .07223 L
F
.468 .694 0 r
.43565 .0788 m
.44322 .07771 L
.45079 .07676 L
.45836 .07595 L
.46593 .07527 L
.4735 .07473 L
.48107 .07433 L
.48864 .07406 L
.49621 .07393 L
.50379 .07393 L
.51136 .07406 L
.51893 .07433 L
.5265 .07473 L
.53407 .07527 L
.54164 .07595 L
.54921 .07676 L
.55678 .07771 L
.56435 .0788 L
.57061 .0798 L
.57193 .08002 L
.5795 .08139 L
.58707 .0829 L
.59464 .08455 L
.60221 .08635 L
.60625 .08737 L
.60978 .0883 L
.61735 .09039 L
.62492 .09264 L
.63221 .09494 L
.6325 .09504 L
.64007 .09759 L
.64764 .10031 L
.65348 .10251 L
.65521 .10319 L
.66278 .10623 L
.67035 .10945 L
.6718 .11008 L
.67792 .11284 L
.68549 .11641 L
.68805 .11766 L
.69306 .12016 L
.70064 .12411 L
.70272 .12523 L
.70821 .12825 L
.71578 .13259 L
.71613 .1328 L
.72335 .13714 L
.72851 .14037 L
.73092 .14191 L
.73849 .14691 L
.74002 .14794 L
.74606 .15214 L
.75076 .15551 L
.75363 .15762 L
.76085 .16308 L
.76121 .16336 L
.76878 .16937 L
.77035 .17065 L
.77635 .17567 L
.77932 .17823 L
.78392 .18227 L
.78781 .1858 L
.79149 .1892 L
.79587 .19337 L
.79906 .19648 L
.80352 .20094 L
.80663 .20412 L
.81081 .20851 L
.8142 .21217 L
.81774 .21608 L
.82177 .22066 L
.82435 .22365 L
.82935 .22962 L
.83066 .23122 L
.83667 .23879 L
.83692 .23911 L
.84242 .24637 L
.84449 .24918 L
.8479 .25394 L
.85206 .25992 L
.85314 .26151 L
.85814 .26908 L
.85963 .27141 L
.86291 .27665 L
.8672 .28377 L
.86747 .28422 L
.87181 .29179 L
.87477 .29716 L
.87596 .29936 L
.8799 .30694 L
.88234 .31181 L
.88366 .31451 L
.88723 .32208 L
.88992 .32803 L
.89063 .32965 L
.89384 .33722 L
.89689 .34479 L
.89749 .34632 L
.89977 .35236 L
.90249 .35993 L
.90505 .3675 L
.90506 .36753 L
.90745 .37508 L
.9097 .38265 L
.91179 .39022 L
.91263 .39339 L
.91374 .39779 L
.91554 .40536 L
.91719 .41293 L
.9187 .4205 L
.92007 .42807 L
.9202 .42882 L
.9213 .43565 L
.92239 .44322 L
.92334 .45079 L
.92415 .45836 L
.92483 .46593 L
.92537 .4735 L
.92577 .48107 L
.92604 .48864 L
.92618 .49621 L
.92618 .50379 L
.92604 .51136 L
.92577 .51893 L
.92537 .5265 L
.92483 .53407 L
.92415 .54164 L
.92334 .54921 L
.92239 .55678 L
.9213 .56435 L
.9202 .57118 L
.92007 .57193 L
.9187 .5795 L
.91719 .58707 L
.91554 .59464 L
.91374 .60221 L
.91263 .60661 L
.91179 .60978 L
.9097 .61735 L
.90745 .62492 L
.90506 .63247 L
.90505 .6325 L
.90249 .64007 L
.89977 .64764 L
.89749 .65368 L
.89689 .65521 L
.89384 .66278 L
.89063 .67035 L
.88992 .67197 L
.88723 .67792 L
.88366 .68549 L
.88234 .68819 L
.8799 .69306 L
.87596 .70064 L
.87477 .70284 L
.87181 .70821 L
.86747 .71578 L
.8672 .71623 L
.86291 .72335 L
.85963 .72859 L
.85814 .73092 L
.85314 .73849 L
.85206 .74008 L
.8479 .74606 L
.84449 .75082 L
.84242 .75363 L
.83692 .76089 L
.83667 .76121 L
.83066 .76878 L
.82935 .77038 L
.82435 .77635 L
.82177 .77934 L
.81774 .78392 L
.8142 .78783 L
.81081 .79149 L
.80663 .79588 L
.80352 .79906 L
.79906 .80352 L
.79587 .80663 L
.79149 .8108 L
.78781 .8142 L
.78392 .81773 L
.77932 .82177 L
.77635 .82433 L
.77035 .82935 L
.76878 .83063 L
.76121 .83664 L
.76085 .83692 L
.75363 .84238 L
.75076 .84449 L
.74606 .84786 L
.74002 .85206 L
.73849 .85309 L
.73092 .85809 L
.72851 .85963 L
.72335 .86286 L
.71613 .8672 L
.71578 .86741 L
.70821 .87175 L
.70272 .87477 L
.70064 .87589 L
.69306 .87984 L
.68805 .88234 L
.68549 .88359 L
.67792 .88716 L
.6718 .88992 L
.67035 .89055 L
.66278 .89377 L
.65521 .89681 L
.65348 .89749 L
.64764 .89969 L
.64007 .90241 L
.6325 .90496 L
.63221 .90506 L
.62492 .90736 L
.61735 .90961 L
.60978 .9117 L
.60625 .91263 L
.60221 .91365 L
.59464 .91545 L
.58707 .9171 L
.5795 .91861 L
.57193 .91998 L
.57061 .9202 L
.56435 .9212 L
.55678 .92229 L
.54921 .92324 L
.54164 .92405 L
.53407 .92473 L
.5265 .92527 L
.51893 .92567 L
.51136 .92594 L
.50379 .92607 L
.49621 .92607 L
.48864 .92594 L
.48107 .92567 L
.4735 .92527 L
.46593 .92473 L
.45836 .92405 L
.45079 .92324 L
.44322 .92229 L
.43565 .9212 L
.42939 .9202 L
.42807 .91998 L
.4205 .91861 L
.41293 .9171 L
.40536 .91545 L
.39779 .91365 L
.39375 .91263 L
.39022 .9117 L
.38265 .90961 L
.37508 .90736 L
.36779 .90506 L
.3675 .90496 L
.35993 .90241 L
.35236 .89969 L
.34652 .89749 L
.34479 .89681 L
.33722 .89377 L
.32965 .89055 L
.3282 .88992 L
.32208 .88716 L
.31451 .88359 L
.31195 .88234 L
.30694 .87984 L
.29936 .87589 L
.29728 .87477 L
.29179 .87175 L
.28422 .86741 L
.28387 .8672 L
.27665 .86286 L
.27149 .85963 L
.26908 .85809 L
.26151 .85309 L
.25998 .85206 L
.25394 .84786 L
.24924 .84449 L
.24637 .84238 L
.23915 .83692 L
.23879 .83664 L
.23122 .83063 L
.22965 .82935 L
.22365 .82433 L
.22068 .82177 L
.21608 .81773 L
.21219 .8142 L
.20851 .8108 L
.20413 .80663 L
.20094 .80352 L
.19647 .79906 L
.19337 .79588 L
.18919 .79149 L
.1858 .78783 L
.18226 .78392 L
.17823 .77934 L
.17565 .77635 L
.17065 .77038 L
.16934 .76878 L
.16333 .76121 L
.16308 .76089 L
.15758 .75363 L
.15551 .75082 L
.1521 .74606 L
.14794 .74008 L
.14686 .73849 L
.14186 .73092 L
.14037 .72859 L
.13709 .72335 L
.1328 .71623 L
.13253 .71578 L
.12819 .70821 L
.12523 .70284 L
.12404 .70064 L
.1201 .69306 L
.11766 .68819 L
.11634 .68549 L
.11277 .67792 L
.11008 .67197 L
.10937 .67035 L
.10616 .66278 L
.10311 .65521 L
.10251 .65368 L
.10023 .64764 L
.09751 .64007 L
.09495 .6325 L
.09494 .63247 L
.09255 .62492 L
.0903 .61735 L
.08821 .60978 L
.08737 .6066 L
.08626 .60221 L
.08446 .59464 L
.08281 .58707 L
.0813 .5795 L
.07993 .57193 L
.0798 .57117 L
.0787 .56435 L
.07761 .55678 L
.07666 .54921 L
.07585 .54164 L
.07517 .53407 L
.07463 .5265 L
.07423 .51893 L
.07396 .51136 L
.07383 .50379 L
.07383 .49621 L
.07396 .48864 L
.07423 .48107 L
.07463 .4735 L
.07517 .46593 L
.07585 .45836 L
.07666 .45079 L
.07761 .44322 L
.0787 .43565 L
.0798 .42883 L
.07993 .42807 L
.0813 .4205 L
.08281 .41293 L
.08446 .40536 L
.08626 .39779 L
.08737 .3934 L
.08821 .39022 L
.0903 .38265 L
.09255 .37508 L
.09494 .36753 L
.09495 .3675 L
.09751 .35993 L
.10023 .35236 L
.10251 .34632 L
.10311 .34479 L
.10616 .33722 L
.10937 .32965 L
.11008 .32803 L
.11277 .32208 L
.11634 .31451 L
.11766 .31181 L
.1201 .30694 L
.12404 .29936 L
.12523 .29716 L
.12819 .29179 L
.13253 .28422 L
.1328 .28377 L
.13709 .27665 L
.14037 .27141 L
.14186 .26908 L
.14686 .26151 L
.14794 .25992 L
.1521 .25394 L
.15551 .24918 L
.15758 .24637 L
.16308 .23911 L
.16333 .23879 L
.16934 .23122 L
.17065 .22962 L
.17565 .22365 L
.17823 .22066 L
.18226 .21608 L
.1858 .21217 L
.18919 .20851 L
.19337 .20412 L
.19647 .20094 L
.20094 .19648 L
.20413 .19337 L
.20851 .1892 L
.21219 .1858 L
.21608 .18227 L
.22068 .17823 L
.22365 .17567 L
.22965 .17065 L
.23122 .16937 L
.23879 .16336 L
.23915 .16308 L
.24637 .15762 L
.24924 .15551 L
.25394 .15214 L
.25998 .14794 L
.26151 .14691 L
.26908 .14191 L
.27149 .14037 L
.27665 .13714 L
.28387 .1328 L
.28422 .13259 L
.29179 .12825 L
.29728 .12523 L
.29936 .12411 L
.30694 .12016 L
.31195 .11766 L
.31451 .11641 L
.32208 .11284 L
.3282 .11008 L
.32965 .10945 L
.33722 .10623 L
.34479 .10319 L
.34652 .10251 L
.35236 .10031 L
.35993 .09759 L
.3675 .09504 L
.36779 .09494 L
.37508 .09264 L
.38265 .09039 L
.39022 .0883 L
.39375 .08737 L
.39779 .08635 L
.40536 .08455 L
.41293 .0829 L
.4205 .08139 L
.42807 .08002 L
.42939 .0798 L
F
.403 .676 0 r
.44322 .08652 m
.45079 .08555 L
.45836 .08473 L
.46593 .08404 L
.4735 .08348 L
.48107 .08307 L
.48864 .0828 L
.49621 .08266 L
.50379 .08266 L
.51136 .0828 L
.51893 .08307 L
.5265 .08348 L
.53407 .08404 L
.54164 .08473 L
.54921 .08555 L
.55678 .08652 L
.56265 .08737 L
.56435 .08763 L
.57193 .08889 L
.5795 .09029 L
.58707 .09183 L
.59464 .09352 L
.60057 .09494 L
.60221 .09535 L
.60978 .09734 L
.61735 .09948 L
.62492 .10178 L
.62724 .10251 L
.6325 .10424 L
.64007 .10685 L
.64764 .10963 L
.64883 .11008 L
.65521 .11258 L
.66278 .1157 L
.66732 .11766 L
.67035 .119 L
.67792 .12247 L
.68365 .12523 L
.68549 .12613 L
.69306 .12999 L
.69836 .1328 L
.70064 .13404 L
.70821 .13829 L
.71178 .14037 L
.71578 .14276 L
.72335 .14744 L
.72414 .14794 L
.73092 .15235 L
.73561 .15551 L
.73849 .1575 L
.74606 .1629 L
.74632 .16308 L
.75363 .16855 L
.75636 .17065 L
.76121 .17448 L
.7658 .17823 L
.76878 .18071 L
.77471 .1858 L
.77635 .18723 L
.78314 .19337 L
.78392 .19409 L
.79113 .20094 L
.79149 .20129 L
.79871 .20851 L
.79906 .20887 L
.80592 .21608 L
.80663 .21685 L
.81278 .22365 L
.8142 .22527 L
.81932 .23122 L
.82177 .23417 L
.82554 .23879 L
.82935 .24361 L
.83148 .24637 L
.83692 .25363 L
.83714 .25394 L
.84254 .26151 L
.84449 .26433 L
.84769 .26908 L
.85206 .27579 L
.85261 .27665 L
.8573 .28422 L
.85963 .28813 L
.86176 .29179 L
.86602 .29936 L
.8672 .30153 L
.87007 .30694 L
.87393 .31451 L
.87477 .31622 L
.87759 .32208 L
.88107 .32965 L
.88234 .33252 L
.88437 .33722 L
.88749 .34479 L
.88992 .35098 L
.89044 .35236 L
.89322 .35993 L
.89584 .3675 L
.89749 .37251 L
.8983 .37508 L
.9006 .38265 L
.90274 .39022 L
.90473 .39779 L
.90506 .39909 L
.90657 .40536 L
.90826 .41293 L
.9098 .4205 L
.9112 .42807 L
.91246 .43565 L
.91263 .43676 L
.91357 .44322 L
.91454 .45079 L
.91537 .45836 L
.91606 .46593 L
.91661 .4735 L
.91702 .48107 L
.9173 .48864 L
.91743 .49621 L
.91743 .50379 L
.9173 .51136 L
.91702 .51893 L
.91661 .5265 L
.91606 .53407 L
.91537 .54164 L
.91454 .54921 L
.91357 .55678 L
.91263 .56324 L
.91246 .56435 L
.9112 .57193 L
.9098 .5795 L
.90826 .58707 L
.90657 .59464 L
.90506 .60091 L
.90473 .60221 L
.90274 .60978 L
.9006 .61735 L
.8983 .62492 L
.89749 .62749 L
.89584 .6325 L
.89322 .64007 L
.89044 .64764 L
.88992 .64902 L
.88749 .65521 L
.88437 .66278 L
.88234 .66748 L
.88107 .67035 L
.87759 .67792 L
.87477 .68378 L
.87393 .68549 L
.87007 .69306 L
.8672 .69847 L
.86602 .70064 L
.86176 .70821 L
.85963 .71187 L
.8573 .71578 L
.85261 .72335 L
.85206 .72421 L
.84769 .73092 L
.84449 .73567 L
.84254 .73849 L
.83714 .74606 L
.83692 .74637 L
.83148 .75363 L
.82935 .75639 L
.82554 .76121 L
.82177 .76583 L
.81932 .76878 L
.8142 .77473 L
.81278 .77635 L
.80663 .78315 L
.80592 .78392 L
.79906 .79113 L
.79871 .79149 L
.79149 .79871 L
.79113 .79906 L
.78392 .80591 L
.78314 .80663 L
.77635 .81277 L
.77471 .8142 L
.76878 .81929 L
.7658 .82177 L
.76121 .82552 L
.75636 .82935 L
.75363 .83145 L
.74632 .83692 L
.74606 .8371 L
.73849 .8425 L
.73561 .84449 L
.73092 .84765 L
.72414 .85206 L
.72335 .85256 L
.71578 .85724 L
.71178 .85963 L
.70821 .86171 L
.70064 .86596 L
.69836 .8672 L
.69306 .87001 L
.68549 .87387 L
.68365 .87477 L
.67792 .87753 L
.67035 .881 L
.66732 .88234 L
.66278 .8843 L
.65521 .88742 L
.64883 .88992 L
.64764 .89037 L
.64007 .89315 L
.6325 .89576 L
.62724 .89749 L
.62492 .89822 L
.61735 .90052 L
.60978 .90266 L
.60221 .90465 L
.60057 .90506 L
.59464 .90648 L
.58707 .90817 L
.5795 .90971 L
.57193 .91111 L
.56435 .91237 L
.56265 .91263 L
.55678 .91348 L
.54921 .91445 L
.54164 .91527 L
.53407 .91596 L
.5265 .91652 L
.51893 .91693 L
.51136 .9172 L
.50379 .91734 L
.49621 .91734 L
.48864 .9172 L
.48107 .91693 L
.4735 .91652 L
.46593 .91596 L
.45836 .91527 L
.45079 .91445 L
.44322 .91348 L
.43735 .91263 L
.43565 .91237 L
.42807 .91111 L
.4205 .90971 L
.41293 .90817 L
.40536 .90648 L
.39943 .90506 L
.39779 .90465 L
.39022 .90266 L
.38265 .90052 L
.37508 .89822 L
.37276 .89749 L
.3675 .89576 L
.35993 .89315 L
.35236 .89037 L
.35117 .88992 L
.34479 .88742 L
.33722 .8843 L
.33268 .88234 L
.32965 .881 L
.32208 .87753 L
.31635 .87477 L
.31451 .87387 L
.30694 .87001 L
.30164 .8672 L
.29936 .86596 L
.29179 .86171 L
.28822 .85963 L
.28422 .85724 L
.27665 .85256 L
.27586 .85206 L
.26908 .84765 L
.26439 .84449 L
.26151 .8425 L
.25394 .8371 L
.25368 .83692 L
.24637 .83145 L
.24364 .82935 L
.23879 .82552 L
.2342 .82177 L
.23122 .81929 L
.22529 .8142 L
.22365 .81277 L
.21686 .80663 L
.21608 .80591 L
.20887 .79906 L
.20851 .79871 L
.20129 .79149 L
.20094 .79113 L
.19408 .78392 L
.19337 .78315 L
.18722 .77635 L
.1858 .77473 L
.18068 .76878 L
.17823 .76583 L
.17446 .76121 L
.17065 .7564 L
.16852 .75363 L
.16308 .74637 L
.16286 .74606 L
.15746 .73849 L
.15551 .73567 L
.15231 .73092 L
.14794 .72421 L
.14739 .72335 L
.1427 .71578 L
.14037 .71187 L
.13824 .70821 L
.13398 .70064 L
.1328 .69847 L
.12993 .69306 L
.12607 .68549 L
.12523 .68378 L
.12241 .67792 L
.11893 .67035 L
.11766 .66748 L
.11563 .66278 L
.11251 .65521 L
.11008 .64902 L
.10956 .64764 L
.10678 .64007 L
.10416 .6325 L
.10251 .62748 L
.1017 .62492 L
.0994 .61735 L
.09726 .60978 L
.09527 .60221 L
.09494 .60091 L
.09343 .59464 L
.09174 .58707 L
.0902 .5795 L
.0888 .57193 L
.08755 .56435 L
.08737 .56323 L
.08643 .55678 L
.08546 .54921 L
.08463 .54164 L
.08394 .53407 L
.08339 .5265 L
.08298 .51893 L
.0827 .51136 L
.08257 .50379 L
.08257 .49621 L
.0827 .48864 L
.08298 .48107 L
.08339 .4735 L
.08394 .46593 L
.08463 .45836 L
.08546 .45079 L
.08643 .44322 L
.08737 .43677 L
.08755 .43565 L
.0888 .42807 L
.0902 .4205 L
.09174 .41293 L
.09343 .40536 L
.09494 .39909 L
.09527 .39779 L
.09726 .39022 L
.0994 .38265 L
.1017 .37508 L
.10251 .37252 L
.10416 .3675 L
.10678 .35993 L
.10956 .35236 L
.11008 .35098 L
.11251 .34479 L
.11563 .33722 L
.11766 .33252 L
.11893 .32965 L
.12241 .32208 L
.12523 .31622 L
.12607 .31451 L
.12993 .30694 L
.1328 .30153 L
.13398 .29936 L
.13824 .29179 L
.14037 .28813 L
.1427 .28422 L
.14739 .27665 L
.14794 .27579 L
.15231 .26908 L
.15551 .26433 L
.15746 .26151 L
.16286 .25394 L
.16308 .25363 L
.16852 .24637 L
.17065 .2436 L
.17446 .23879 L
.17823 .23417 L
.18068 .23122 L
.1858 .22527 L
.18722 .22365 L
.19337 .21685 L
.19408 .21608 L
.20094 .20887 L
.20129 .20851 L
.20851 .20129 L
.20887 .20094 L
.21608 .19409 L
.21686 .19337 L
.22365 .18723 L
.22529 .1858 L
.23122 .18071 L
.2342 .17823 L
.23879 .17448 L
.24364 .17065 L
.24637 .16855 L
.25368 .16308 L
.25394 .1629 L
.26151 .1575 L
.26439 .15551 L
.26908 .15235 L
.27586 .14794 L
.27665 .14744 L
.28422 .14276 L
.28822 .14037 L
.29179 .13829 L
.29936 .13404 L
.30164 .1328 L
.30694 .12999 L
.31451 .12613 L
.31635 .12523 L
.32208 .12247 L
.32965 .119 L
.33268 .11766 L
.33722 .1157 L
.34479 .11258 L
.35117 .11008 L
.35236 .10963 L
.35993 .10685 L
.3675 .10424 L
.37276 .10251 L
.37508 .10178 L
.38265 .09948 L
.39022 .09734 L
.39779 .09535 L
.39943 .09494 L
.40536 .09352 L
.41293 .09183 L
.4205 .09029 L
.42807 .08889 L
.43565 .08763 L
.43735 .08737 L
F
.341 .658 0 r
.45079 .09429 m
.45836 .09344 L
.46593 .09273 L
.4735 .09217 L
.48107 .09175 L
.48864 .09147 L
.49621 .09133 L
.50379 .09133 L
.51136 .09147 L
.51893 .09175 L
.5265 .09217 L
.53407 .09273 L
.54164 .09344 L
.54921 .09429 L
.55436 .09494 L
.55678 .09528 L
.56435 .09641 L
.57193 .09769 L
.5795 .09912 L
.58707 .1007 L
.59464 .10242 L
.59502 .10251 L
.60221 .1043 L
.60978 .10634 L
.61735 .10853 L
.62243 .11008 L
.62492 .11088 L
.6325 .11339 L
.64007 .11607 L
.64434 .11766 L
.64764 .11892 L
.65521 .12194 L
.66278 .12513 L
.66299 .12523 L
.67035 .12851 L
.67792 .13208 L
.6794 .1328 L
.68549 .13584 L
.69306 .1398 L
.69413 .14037 L
.70064 .14396 L
.70755 .14794 L
.70821 .14833 L
.71578 .15292 L
.71989 .15551 L
.72335 .15775 L
.73092 .16281 L
.73132 .16308 L
.73849 .16812 L
.74198 .17065 L
.74606 .17369 L
.75197 .17823 L
.75363 .17954 L
.76121 .18568 L
.76135 .1858 L
.76878 .19212 L
.77019 .19337 L
.77635 .1989 L
.77855 .20094 L
.78392 .20603 L
.78647 .20851 L
.79149 .21353 L
.79398 .21608 L
.79906 .22144 L
.80111 .22365 L
.80663 .22979 L
.80789 .23122 L
.8142 .23863 L
.81434 .23879 L
.82049 .24637 L
.82177 .248 L
.82634 .25394 L
.82935 .25797 L
.83192 .26151 L
.83692 .26862 L
.83723 .26908 L
.8423 .27665 L
.84449 .28005 L
.84712 .28422 L
.85172 .29179 L
.85206 .29237 L
.8561 .29936 L
.85963 .30577 L
.86026 .30694 L
.86422 .31451 L
.8672 .32048 L
.86798 .32208 L
.87155 .32965 L
.87477 .33686 L
.87493 .33722 L
.87813 .34479 L
.88115 .35236 L
.88234 .35547 L
.884 .35993 L
.88668 .3675 L
.8892 .37508 L
.88992 .37733 L
.89155 .38265 L
.89374 .39022 L
.89578 .39779 L
.89749 .40465 L
.89766 .40536 L
.89938 .41293 L
.90096 .4205 L
.90239 .42807 L
.90367 .43565 L
.90481 .44322 L
.90506 .44502 L
.9058 .45079 L
.90665 .45836 L
.90735 .46593 L
.90791 .4735 L
.90834 .48107 L
.90862 .48864 L
.90876 .49621 L
.90876 .50379 L
.90862 .51136 L
.90834 .51893 L
.90791 .5265 L
.90735 .53407 L
.90665 .54164 L
.9058 .54921 L
.90506 .55498 L
.90481 .55678 L
.90367 .56435 L
.90239 .57193 L
.90096 .5795 L
.89938 .58707 L
.89766 .59464 L
.89749 .59535 L
.89578 .60221 L
.89374 .60978 L
.89155 .61735 L
.88992 .62267 L
.8892 .62492 L
.88668 .6325 L
.884 .64007 L
.88234 .64453 L
.88115 .64764 L
.87813 .65521 L
.87493 .66278 L
.87477 .66314 L
.87155 .67035 L
.86798 .67792 L
.8672 .67952 L
.86422 .68549 L
.86026 .69306 L
.85963 .69423 L
.8561 .70064 L
.85206 .70763 L
.85172 .70821 L
.84712 .71578 L
.84449 .71995 L
.8423 .72335 L
.83723 .73092 L
.83692 .73138 L
.83192 .73849 L
.82935 .74203 L
.82634 .74606 L
.82177 .752 L
.82049 .75363 L
.81434 .76121 L
.8142 .76137 L
.80789 .76878 L
.80663 .77021 L
.80111 .77635 L
.79906 .77856 L
.79398 .78392 L
.79149 .78647 L
.78647 .79149 L
.78392 .79397 L
.77855 .79906 L
.77635 .8011 L
.77019 .80663 L
.76878 .80788 L
.76135 .8142 L
.76121 .81432 L
.75363 .82046 L
.75197 .82177 L
.74606 .82631 L
.74198 .82935 L
.73849 .83188 L
.73132 .83692 L
.73092 .83719 L
.72335 .84225 L
.71989 .84449 L
.71578 .84708 L
.70821 .85167 L
.70755 .85206 L
.70064 .85604 L
.69413 .85963 L
.69306 .8602 L
.68549 .86416 L
.6794 .8672 L
.67792 .86792 L
.67035 .87149 L
.66299 .87477 L
.66278 .87487 L
.65521 .87806 L
.64764 .88108 L
.64434 .88234 L
.64007 .88393 L
.6325 .88661 L
.62492 .88912 L
.62243 .88992 L
.61735 .89147 L
.60978 .89366 L
.60221 .8957 L
.59502 .89749 L
.59464 .89758 L
.58707 .8993 L
.5795 .90088 L
.57193 .90231 L
.56435 .90359 L
.55678 .90472 L
.55436 .90506 L
.54921 .90571 L
.54164 .90656 L
.53407 .90727 L
.5265 .90783 L
.51893 .90825 L
.51136 .90853 L
.50379 .90867 L
.49621 .90867 L
.48864 .90853 L
.48107 .90825 L
.4735 .90783 L
.46593 .90727 L
.45836 .90656 L
.45079 .90571 L
.44565 .90506 L
.44322 .90472 L
.43565 .90359 L
.42807 .90231 L
.4205 .90088 L
.41293 .8993 L
.40536 .89758 L
.40498 .89749 L
.39779 .8957 L
.39022 .89366 L
.38265 .89147 L
.37757 .88992 L
.37508 .88912 L
.3675 .88661 L
.35993 .88393 L
.35566 .88234 L
.35236 .88108 L
.34479 .87806 L
.33722 .87487 L
.33701 .87477 L
.32965 .87149 L
.32208 .86792 L
.3206 .8672 L
.31451 .86416 L
.30694 .8602 L
.30587 .85963 L
.29936 .85604 L
.29245 .85206 L
.29179 .85167 L
.28422 .84708 L
.28011 .84449 L
.27665 .84225 L
.26908 .83719 L
.26868 .83692 L
.26151 .83188 L
.25802 .82935 L
.25394 .82631 L
.24803 .82177 L
.24637 .82046 L
.23879 .81432 L
.23865 .8142 L
.23122 .80788 L
.22981 .80663 L
.22365 .8011 L
.22145 .79906 L
.21608 .79397 L
.21353 .79149 L
.20851 .78647 L
.20602 .78392 L
.20094 .77856 L
.19889 .77635 L
.19337 .77021 L
.19211 .76878 L
.1858 .76137 L
.18566 .76121 L
.17951 .75363 L
.17823 .752 L
.17366 .74606 L
.17065 .74203 L
.16808 .73849 L
.16308 .73138 L
.16277 .73092 L
.1577 .72335 L
.15551 .71996 L
.15288 .71578 L
.14828 .70821 L
.14794 .70763 L
.1439 .70064 L
.14037 .69423 L
.13974 .69306 L
.13578 .68549 L
.1328 .67952 L
.13202 .67792 L
.12845 .67035 L
.12523 .66314 L
.12507 .66278 L
.12187 .65521 L
.11885 .64764 L
.11766 .64453 L
.116 .64007 L
.11332 .6325 L
.1108 .62492 L
.11008 .62267 L
.10845 .61735 L
.10626 .60978 L
.10422 .60221 L
.10251 .59535 L
.10234 .59464 L
.10062 .58707 L
.09904 .5795 L
.09761 .57193 L
.09633 .56435 L
.09519 .55678 L
.09494 .55498 L
.0942 .54921 L
.09335 .54164 L
.09265 .53407 L
.09209 .5265 L
.09166 .51893 L
.09138 .51136 L
.09124 .50379 L
.09124 .49621 L
.09138 .48864 L
.09166 .48107 L
.09209 .4735 L
.09265 .46593 L
.09335 .45836 L
.0942 .45079 L
.09494 .44502 L
.09519 .44322 L
.09633 .43565 L
.09761 .42807 L
.09904 .4205 L
.10062 .41293 L
.10234 .40536 L
.10251 .40465 L
.10422 .39779 L
.10626 .39022 L
.10845 .38265 L
.11008 .37733 L
.1108 .37508 L
.11332 .3675 L
.116 .35993 L
.11766 .35547 L
.11885 .35236 L
.12187 .34479 L
.12507 .33722 L
.12523 .33686 L
.12845 .32965 L
.13202 .32208 L
.1328 .32048 L
.13578 .31451 L
.13974 .30694 L
.14037 .30577 L
.1439 .29936 L
.14794 .29237 L
.14828 .29179 L
.15288 .28422 L
.15551 .28004 L
.1577 .27665 L
.16277 .26908 L
.16308 .26862 L
.16808 .26151 L
.17065 .25797 L
.17366 .25394 L
.17823 .248 L
.17951 .24637 L
.18566 .23879 L
.1858 .23863 L
.19211 .23122 L
.19337 .22979 L
.19889 .22365 L
.20094 .22144 L
.20602 .21608 L
.20851 .21353 L
.21353 .20851 L
.21608 .20603 L
.22145 .20094 L
.22365 .1989 L
.22981 .19337 L
.23122 .19212 L
.23865 .1858 L
.23879 .18568 L
.24637 .17954 L
.24803 .17823 L
.25394 .17369 L
.25802 .17065 L
.26151 .16812 L
.26868 .16308 L
.26908 .16281 L
.27665 .15775 L
.28011 .15551 L
.28422 .15292 L
.29179 .14833 L
.29245 .14794 L
.29936 .14396 L
.30587 .14037 L
.30694 .1398 L
.31451 .13584 L
.3206 .1328 L
.32208 .13208 L
.32965 .12851 L
.33701 .12523 L
.33722 .12513 L
.34479 .12194 L
.35236 .11892 L
.35566 .11766 L
.35993 .11607 L
.3675 .11339 L
.37508 .11088 L
.37757 .11008 L
.38265 .10853 L
.39022 .10634 L
.39779 .1043 L
.40498 .10251 L
.40536 .10242 L
.41293 .1007 L
.4205 .09912 L
.42807 .09769 L
.43565 .09641 L
.44322 .09528 L
.44565 .09494 L
F
.282 .64 0 r
.45836 .10211 m
.46593 .10139 L
.4735 .10081 L
.48107 .10038 L
.48864 .1001 L
.49621 .09995 L
.50379 .09995 L
.51136 .1001 L
.51893 .10038 L
.5265 .10081 L
.53407 .10139 L
.54164 .10211 L
.54536 .10251 L
.54921 .10297 L
.55678 .10399 L
.56435 .10515 L
.57193 .10645 L
.5795 .10791 L
.58707 .10953 L
.58954 .11008 L
.59464 .11129 L
.60221 .11321 L
.60978 .1153 L
.61735 .11754 L
.61774 .11766 L
.62492 .11994 L
.6325 .12252 L
.63998 .12523 L
.64007 .12526 L
.64764 .12818 L
.65521 .13127 L
.65878 .1328 L
.66278 .13455 L
.67035 .13802 L
.67525 .14037 L
.67792 .14168 L
.68549 .14554 L
.69001 .14794 L
.69306 .14961 L
.70064 .15389 L
.70341 .15551 L
.70821 .15839 L
.71572 .16308 L
.71578 .16312 L
.72335 .16809 L
.72711 .17065 L
.73092 .17331 L
.73772 .17823 L
.73849 .1788 L
.74606 .18456 L
.74764 .1858 L
.75363 .19061 L
.75696 .19337 L
.76121 .19697 L
.76574 .20094 L
.76878 .20367 L
.77402 .20851 L
.77635 .21071 L
.78186 .21608 L
.78392 .21814 L
.78929 .22365 L
.79149 .22597 L
.79634 .23122 L
.79906 .23425 L
.80304 .23879 L
.80663 .24302 L
.80941 .24637 L
.8142 .25233 L
.81547 .25394 L
.82123 .26151 L
.82177 .26224 L
.82672 .26908 L
.82935 .27284 L
.83195 .27665 L
.83692 .28422 L
.83692 .28422 L
.84165 .29179 L
.84449 .29651 L
.84616 .29936 L
.85044 .30694 L
.85206 .3099 L
.85451 .31451 L
.85837 .32208 L
.85963 .32463 L
.86204 .32965 L
.8655 .33722 L
.8672 .34108 L
.86879 .34479 L
.87189 .35236 L
.87477 .35985 L
.8748 .35993 L
.87755 .3675 L
.88013 .37508 L
.88234 .38203 L
.88253 .38265 L
.88478 .39022 L
.88686 .39779 L
.88878 .40536 L
.88992 .41014 L
.89055 .41293 L
.89216 .4205 L
.89362 .42807 L
.89493 .43565 L
.89609 .44322 L
.89711 .45079 L
.89749 .45395 L
.89797 .45836 L
.89869 .46593 L
.89927 .4735 L
.8997 .48107 L
.89999 .48864 L
.90013 .49621 L
.90013 .50379 L
.89999 .51136 L
.8997 .51893 L
.89927 .5265 L
.89869 .53407 L
.89797 .54164 L
.89749 .54605 L
.89711 .54921 L
.89609 .55678 L
.89493 .56435 L
.89362 .57193 L
.89216 .5795 L
.89055 .58707 L
.88992 .58986 L
.88878 .59464 L
.88686 .60221 L
.88478 .60978 L
.88253 .61735 L
.88234 .61797 L
.88013 .62492 L
.87755 .6325 L
.8748 .64007 L
.87477 .64015 L
.87189 .64764 L
.86879 .65521 L
.8672 .65892 L
.8655 .66278 L
.86204 .67035 L
.85963 .67537 L
.85837 .67792 L
.85451 .68549 L
.85206 .6901 L
.85044 .69306 L
.84616 .70064 L
.84449 .70349 L
.84165 .70821 L
.83692 .71578 L
.83692 .71578 L
.83195 .72335 L
.82935 .72716 L
.82672 .73092 L
.82177 .73776 L
.82123 .73849 L
.81547 .74606 L
.8142 .74767 L
.80941 .75363 L
.80663 .75698 L
.80304 .76121 L
.79906 .76575 L
.79634 .76878 L
.79149 .77403 L
.78929 .77635 L
.78392 .78186 L
.78186 .78392 L
.77635 .78929 L
.77402 .79149 L
.76878 .79633 L
.76574 .79906 L
.76121 .80303 L
.75696 .80663 L
.75363 .80939 L
.74764 .8142 L
.74606 .81544 L
.73849 .8212 L
.73772 .82177 L
.73092 .82669 L
.72711 .82935 L
.72335 .83191 L
.71578 .83688 L
.71572 .83692 L
.70821 .84161 L
.70341 .84449 L
.70064 .84611 L
.69306 .85039 L
.69001 .85206 L
.68549 .85446 L
.67792 .85832 L
.67525 .85963 L
.67035 .86198 L
.66278 .86545 L
.65878 .8672 L
.65521 .86873 L
.64764 .87182 L
.64007 .87474 L
.63998 .87477 L
.6325 .87748 L
.62492 .88006 L
.61774 .88234 L
.61735 .88246 L
.60978 .8847 L
.60221 .88679 L
.59464 .88871 L
.58954 .88992 L
.58707 .89047 L
.5795 .89209 L
.57193 .89355 L
.56435 .89485 L
.55678 .89601 L
.54921 .89703 L
.54536 .89749 L
.54164 .89789 L
.53407 .89861 L
.5265 .89919 L
.51893 .89962 L
.51136 .8999 L
.50379 .90005 L
.49621 .90005 L
.48864 .8999 L
.48107 .89962 L
.4735 .89919 L
.46593 .89861 L
.45836 .89789 L
.45464 .89749 L
.45079 .89703 L
.44322 .89601 L
.43565 .89485 L
.42807 .89355 L
.4205 .89209 L
.41293 .89047 L
.41046 .88992 L
.40536 .88871 L
.39779 .88679 L
.39022 .8847 L
.38265 .88246 L
.38226 .88234 L
.37508 .88006 L
.3675 .87748 L
.36002 .87477 L
.35993 .87474 L
.35236 .87182 L
.34479 .86873 L
.34122 .8672 L
.33722 .86545 L
.32965 .86198 L
.32475 .85963 L
.32208 .85832 L
.31451 .85446 L
.30999 .85206 L
.30694 .85039 L
.29936 .84611 L
.29659 .84449 L
.29179 .84161 L
.28428 .83692 L
.28422 .83688 L
.27665 .83191 L
.27289 .82935 L
.26908 .82669 L
.26228 .82177 L
.26151 .8212 L
.25394 .81544 L
.25236 .8142 L
.24637 .80939 L
.24304 .80663 L
.23879 .80303 L
.23426 .79906 L
.23122 .79633 L
.22598 .79149 L
.22365 .78929 L
.21814 .78392 L
.21608 .78186 L
.21071 .77635 L
.20851 .77403 L
.20366 .76878 L
.20094 .76575 L
.19696 .76121 L
.19337 .75698 L
.19059 .75363 L
.1858 .74767 L
.18453 .74606 L
.17877 .73849 L
.17823 .73776 L
.17328 .73092 L
.17065 .72716 L
.16805 .72335 L
.16308 .71578 L
.16308 .71578 L
.15835 .70821 L
.15551 .70349 L
.15384 .70064 L
.14956 .69306 L
.14794 .6901 L
.14549 .68549 L
.14163 .67792 L
.14037 .67537 L
.13796 .67035 L
.1345 .66278 L
.1328 .65892 L
.13121 .65521 L
.12812 .64764 L
.12523 .64015 L
.1252 .64007 L
.12245 .6325 L
.11988 .62492 L
.11766 .61796 L
.11747 .61735 L
.11522 .60978 L
.11314 .60221 L
.11122 .59464 L
.11008 .58986 L
.10945 .58707 L
.10784 .5795 L
.10638 .57193 L
.10507 .56435 L
.10391 .55678 L
.10289 .54921 L
.10251 .54605 L
.10203 .54164 L
.10131 .53407 L
.10073 .5265 L
.1003 .51893 L
.10002 .51136 L
.09987 .50379 L
.09987 .49621 L
.10002 .48864 L
.1003 .48107 L
.10073 .4735 L
.10131 .46593 L
.10203 .45836 L
.10251 .45395 L
.10289 .45079 L
.10391 .44322 L
.10507 .43565 L
.10638 .42807 L
.10784 .4205 L
.10945 .41293 L
.11008 .41014 L
.11122 .40536 L
.11314 .39779 L
.11522 .39022 L
.11747 .38265 L
.11766 .38204 L
.11988 .37508 L
.12245 .3675 L
.1252 .35993 L
.12523 .35985 L
.12812 .35236 L
.13121 .34479 L
.1328 .34108 L
.1345 .33722 L
.13796 .32965 L
.14037 .32463 L
.14163 .32208 L
.14549 .31451 L
.14794 .3099 L
.14956 .30694 L
.15384 .29936 L
.15551 .29651 L
.15835 .29179 L
.16308 .28422 L
.16308 .28422 L
.16805 .27665 L
.17065 .27284 L
.17328 .26908 L
.17823 .26224 L
.17877 .26151 L
.18453 .25394 L
.1858 .25233 L
.19059 .24637 L
.19337 .24302 L
.19696 .23879 L
.20094 .23425 L
.20366 .23122 L
.20851 .22597 L
.21071 .22365 L
.21608 .21814 L
.21814 .21608 L
.22365 .21071 L
.22598 .20851 L
.23122 .20367 L
.23426 .20094 L
.23879 .19697 L
.24304 .19337 L
.24637 .19061 L
.25236 .1858 L
.25394 .18456 L
.26151 .1788 L
.26228 .17823 L
.26908 .17331 L
.27289 .17065 L
.27665 .16809 L
.28422 .16312 L
.28428 .16308 L
.29179 .15839 L
.29659 .15551 L
.29936 .15389 L
.30694 .14961 L
.30999 .14794 L
.31451 .14554 L
.32208 .14168 L
.32475 .14037 L
.32965 .13802 L
.33722 .13455 L
.34122 .1328 L
.34479 .13127 L
.35236 .12818 L
.35993 .12526 L
.36002 .12523 L
.3675 .12252 L
.37508 .11994 L
.38226 .11766 L
.38265 .11754 L
.39022 .1153 L
.39779 .11321 L
.40536 .11129 L
.41046 .11008 L
.41293 .10953 L
.4205 .10791 L
.42807 .10645 L
.43565 .10515 L
.44322 .10399 L
.45079 .10297 L
.45464 .10251 L
F
.225 .622 0 r
.46593 .11001 m
.4735 .10942 L
.48107 .10898 L
.48864 .10869 L
.49621 .10854 L
.50379 .10854 L
.51136 .10869 L
.51893 .10898 L
.5265 .10942 L
.53407 .11001 L
.53491 .11008 L
.54164 .11075 L
.54921 .11163 L
.55678 .11267 L
.56435 .11385 L
.57193 .11519 L
.5795 .11668 L
.58405 .11766 L
.58707 .11833 L
.59464 .12014 L
.60221 .12211 L
.60978 .12424 L
.61311 .12523 L
.61735 .12653 L
.62492 .129 L
.6325 .13163 L
.63569 .1328 L
.64007 .13445 L
.64764 .13744 L
.65464 .14037 L
.65521 .14061 L
.66278 .14398 L
.67035 .14754 L
.67118 .14794 L
.67792 .1513 L
.68549 .15527 L
.68594 .15551 L
.69306 .15945 L
.69933 .16308 L
.70064 .16386 L
.70821 .16849 L
.71161 .17065 L
.71578 .17337 L
.72296 .17823 L
.72335 .1785 L
.73092 .18389 L
.73351 .1858 L
.73849 .18956 L
.74337 .19337 L
.74606 .19553 L
.75261 .20094 L
.75363 .2018 L
.76121 .20841 L
.76132 .20851 L
.76878 .21537 L
.76953 .21608 L
.77635 .22271 L
.77729 .22365 L
.78392 .23047 L
.78463 .23122 L
.79149 .23867 L
.7916 .23879 L
.79821 .24637 L
.79906 .24737 L
.80449 .25394 L
.80663 .25661 L
.81046 .26151 L
.8142 .26646 L
.81614 .26908 L
.82153 .27665 L
.82177 .277 L
.82667 .28422 L
.82935 .28833 L
.83155 .29179 L
.83619 .29936 L
.83692 .30059 L
.84059 .30694 L
.84449 .31397 L
.84478 .31451 L
.84875 .32208 L
.85206 .32872 L
.85251 .32965 L
.85607 .33722 L
.85944 .34479 L
.85963 .34523 L
.86262 .35236 L
.86561 .35993 L
.8672 .36415 L
.86843 .3675 L
.87107 .37508 L
.87353 .38265 L
.87477 .38667 L
.87583 .39022 L
.87796 .39779 L
.87993 .40536 L
.88174 .41293 L
.88234 .41564 L
.88339 .4205 L
.88488 .42807 L
.88622 .43565 L
.88741 .44322 L
.88844 .45079 L
.88933 .45836 L
.88992 .46427 L
.89006 .46593 L
.89065 .4735 L
.89109 .48107 L
.89138 .48864 L
.89153 .49621 L
.89153 .50379 L
.89138 .51136 L
.89109 .51893 L
.89065 .5265 L
.89006 .53407 L
.88992 .53573 L
.88933 .54164 L
.88844 .54921 L
.88741 .55678 L
.88622 .56435 L
.88488 .57193 L
.88339 .5795 L
.88234 .58436 L
.88174 .58707 L
.87993 .59464 L
.87796 .60221 L
.87583 .60978 L
.87477 .61333 L
.87353 .61735 L
.87107 .62492 L
.86843 .6325 L
.8672 .63585 L
.86561 .64007 L
.86262 .64764 L
.85963 .65477 L
.85944 .65521 L
.85607 .66278 L
.85251 .67035 L
.85206 .67128 L
.84875 .67792 L
.84478 .68549 L
.84449 .68603 L
.84059 .69306 L
.83692 .69941 L
.83619 .70064 L
.83155 .70821 L
.82935 .71167 L
.82667 .71578 L
.82177 .723 L
.82153 .72335 L
.81614 .73092 L
.8142 .73354 L
.81046 .73849 L
.80663 .74339 L
.80449 .74606 L
.79906 .75263 L
.79821 .75363 L
.7916 .76121 L
.79149 .76133 L
.78463 .76878 L
.78392 .76953 L
.77729 .77635 L
.77635 .77729 L
.76953 .78392 L
.76878 .78463 L
.76132 .79149 L
.76121 .79159 L
.75363 .7982 L
.75261 .79906 L
.74606 .80447 L
.74337 .80663 L
.73849 .81044 L
.73351 .8142 L
.73092 .81611 L
.72335 .8215 L
.72296 .82177 L
.71578 .82663 L
.71161 .82935 L
.70821 .83151 L
.70064 .83614 L
.69933 .83692 L
.69306 .84055 L
.68594 .84449 L
.68549 .84473 L
.67792 .8487 L
.67118 .85206 L
.67035 .85246 L
.66278 .85602 L
.65521 .85939 L
.65464 .85963 L
.64764 .86256 L
.64007 .86555 L
.63569 .8672 L
.6325 .86837 L
.62492 .871 L
.61735 .87347 L
.61311 .87477 L
.60978 .87576 L
.60221 .87789 L
.59464 .87986 L
.58707 .88167 L
.58405 .88234 L
.5795 .88332 L
.57193 .88481 L
.56435 .88615 L
.55678 .88733 L
.54921 .88837 L
.54164 .88925 L
.53491 .88992 L
.53407 .88999 L
.5265 .89058 L
.51893 .89102 L
.51136 .89131 L
.50379 .89146 L
.49621 .89146 L
.48864 .89131 L
.48107 .89102 L
.4735 .89058 L
.46593 .88999 L
.46509 .88992 L
.45836 .88925 L
.45079 .88837 L
.44322 .88733 L
.43565 .88615 L
.42807 .88481 L
.4205 .88332 L
.41595 .88234 L
.41293 .88167 L
.40536 .87986 L
.39779 .87789 L
.39022 .87576 L
.38689 .87477 L
.38265 .87347 L
.37508 .871 L
.3675 .86837 L
.36431 .8672 L
.35993 .86555 L
.35236 .86256 L
.34536 .85963 L
.34479 .85939 L
.33722 .85602 L
.32965 .85246 L
.32882 .85206 L
.32208 .8487 L
.31451 .84473 L
.31406 .84449 L
.30694 .84055 L
.30067 .83692 L
.29936 .83614 L
.29179 .83151 L
.28839 .82935 L
.28422 .82663 L
.27704 .82177 L
.27665 .8215 L
.26908 .81611 L
.26649 .8142 L
.26151 .81044 L
.25663 .80663 L
.25394 .80447 L
.24739 .79906 L
.24637 .7982 L
.23879 .79159 L
.23868 .79149 L
.23122 .78463 L
.23047 .78392 L
.22365 .77729 L
.22271 .77635 L
.21608 .76953 L
.21537 .76878 L
.20851 .76133 L
.2084 .76121 L
.20179 .75363 L
.20094 .75263 L
.19551 .74606 L
.19337 .74339 L
.18954 .73849 L
.1858 .73354 L
.18386 .73092 L
.17847 .72335 L
.17823 .723 L
.17333 .71578 L
.17065 .71167 L
.16845 .70821 L
.16381 .70064 L
.16308 .69941 L
.15941 .69306 L
.15551 .68603 L
.15522 .68549 L
.15125 .67792 L
.14794 .67128 L
.14749 .67035 L
.14393 .66278 L
.14056 .65521 L
.14037 .65477 L
.13738 .64764 L
.13439 .64007 L
.1328 .63585 L
.13157 .6325 L
.12894 .62492 L
.12647 .61735 L
.12523 .61333 L
.12417 .60978 L
.12204 .60221 L
.12007 .59464 L
.11826 .58707 L
.11766 .58436 L
.11661 .5795 L
.11512 .57193 L
.11378 .56435 L
.11259 .55678 L
.11156 .54921 L
.11067 .54164 L
.11008 .53573 L
.10994 .53407 L
.10935 .5265 L
.10891 .51893 L
.10862 .51136 L
.10847 .50379 L
.10847 .49621 L
.10862 .48864 L
.10891 .48107 L
.10935 .4735 L
.10994 .46593 L
.11008 .46427 L
.11067 .45836 L
.11156 .45079 L
.11259 .44322 L
.11378 .43565 L
.11512 .42807 L
.11661 .4205 L
.11766 .41564 L
.11826 .41293 L
.12007 .40536 L
.12204 .39779 L
.12417 .39022 L
.12523 .38667 L
.12647 .38265 L
.12894 .37508 L
.13157 .3675 L
.1328 .36415 L
.13439 .35993 L
.13738 .35236 L
.14037 .34523 L
.14056 .34479 L
.14393 .33722 L
.14749 .32965 L
.14794 .32872 L
.15125 .32208 L
.15522 .31451 L
.15551 .31397 L
.15941 .30694 L
.16308 .30059 L
.16381 .29936 L
.16845 .29179 L
.17065 .28833 L
.17333 .28422 L
.17823 .277 L
.17847 .27665 L
.18386 .26908 L
.1858 .26646 L
.18954 .26151 L
.19337 .25661 L
.19551 .25394 L
.20094 .24737 L
.20179 .24637 L
.2084 .23879 L
.20851 .23867 L
.21537 .23122 L
.21608 .23047 L
.22271 .22365 L
.22365 .22271 L
.23047 .21608 L
.23122 .21537 L
.23868 .20851 L
.23879 .20841 L
.24637 .2018 L
.24739 .20094 L
.25394 .19553 L
.25663 .19337 L
.26151 .18956 L
.26649 .1858 L
.26908 .18389 L
.27665 .1785 L
.27704 .17823 L
.28422 .17337 L
.28839 .17065 L
.29179 .16849 L
.29936 .16386 L
.30067 .16308 L
.30694 .15945 L
.31406 .15551 L
.31451 .15527 L
.32208 .1513 L
.32882 .14794 L
.32965 .14754 L
.33722 .14398 L
.34479 .14061 L
.34536 .14037 L
.35236 .13744 L
.35993 .13445 L
.36431 .1328 L
.3675 .13163 L
.37508 .129 L
.38265 .12653 L
.38689 .12523 L
.39022 .12424 L
.39779 .12211 L
.40536 .12014 L
.41293 .11833 L
.41595 .11766 L
.4205 .11668 L
.42807 .11519 L
.43565 .11385 L
.44322 .11267 L
.45079 .11163 L
.45836 .11075 L
.46509 .11008 L
F
.172 .604 0 r
.48107 .11757 m
.48864 .11727 L
.49621 .11712 L
.50379 .11712 L
.51136 .11727 L
.51893 .11757 L
.52068 .11766 L
.5265 .11802 L
.53407 .11862 L
.54164 .11937 L
.54921 .12028 L
.55678 .12134 L
.56435 .12255 L
.57193 .12392 L
.57846 .12523 L
.5795 .12545 L
.58707 .12713 L
.59464 .12898 L
.60221 .131 L
.6085 .1328 L
.60978 .13318 L
.61735 .13553 L
.62492 .13806 L
.63143 .14037 L
.6325 .14076 L
.64007 .14364 L
.64764 .14671 L
.65054 .14794 L
.65521 .14997 L
.66278 .15343 L
.66714 .15551 L
.67035 .15709 L
.67792 .16096 L
.68192 .16308 L
.68549 .16504 L
.69306 .16934 L
.69529 .17065 L
.70064 .17388 L
.70753 .17823 L
.70821 .17866 L
.71578 .1837 L
.71882 .1858 L
.72335 .189 L
.72931 .19337 L
.73092 .19458 L
.73849 .20045 L
.73911 .20094 L
.74606 .20663 L
.74828 .20851 L
.75363 .21315 L
.75691 .21608 L
.76121 .22003 L
.76504 .22365 L
.76878 .22729 L
.77272 .23122 L
.77635 .23496 L
.77998 .23879 L
.78392 .24308 L
.78686 .24637 L
.79149 .2517 L
.79338 .25394 L
.79906 .26087 L
.79957 .26151 L
.80545 .26908 L
.80663 .27065 L
.81103 .27665 L
.8142 .28113 L
.81633 .28422 L
.82137 .29179 L
.82177 .29242 L
.82615 .29936 L
.82935 .30464 L
.83069 .30694 L
.835 .31451 L
.83692 .318 L
.83909 .32208 L
.84296 .32965 L
.84449 .33276 L
.84662 .33722 L
.85008 .34479 L
.85206 .34934 L
.85334 .35236 L
.85641 .35993 L
.8593 .3675 L
.85963 .36841 L
.862 .37508 L
.86453 .38265 L
.86688 .39022 L
.8672 .3913 L
.86906 .39779 L
.87108 .40536 L
.87293 .41293 L
.87462 .4205 L
.87477 .42123 L
.87615 .42807 L
.87752 .43565 L
.87873 .44322 L
.87979 .45079 L
.8807 .45836 L
.88145 .46593 L
.88205 .4735 L
.88234 .47804 L
.8825 .48107 L
.8828 .48864 L
.88295 .49621 L
.88295 .50379 L
.8828 .51136 L
.8825 .51893 L
.88234 .52196 L
.88205 .5265 L
.88145 .53407 L
.8807 .54164 L
.87979 .54921 L
.87873 .55678 L
.87752 .56435 L
.87615 .57193 L
.87477 .57877 L
.87462 .5795 L
.87293 .58707 L
.87108 .59464 L
.86906 .60221 L
.8672 .6087 L
.86688 .60978 L
.86453 .61735 L
.862 .62492 L
.85963 .63159 L
.8593 .6325 L
.85641 .64007 L
.85334 .64764 L
.85206 .65066 L
.85008 .65521 L
.84662 .66278 L
.84449 .66724 L
.84296 .67035 L
.83909 .67792 L
.83692 .682 L
.835 .68549 L
.83069 .69306 L
.82935 .69536 L
.82615 .70064 L
.82177 .70758 L
.82137 .70821 L
.81633 .71578 L
.8142 .71887 L
.81103 .72335 L
.80663 .72935 L
.80545 .73092 L
.79957 .73849 L
.79906 .73913 L
.79338 .74606 L
.79149 .7483 L
.78686 .75363 L
.78392 .75692 L
.77998 .76121 L
.77635 .76504 L
.77272 .76878 L
.76878 .77271 L
.76504 .77635 L
.76121 .77997 L
.75691 .78392 L
.75363 .78685 L
.74828 .79149 L
.74606 .79337 L
.73911 .79906 L
.73849 .79955 L
.73092 .80542 L
.72931 .80663 L
.72335 .811 L
.71882 .8142 L
.71578 .8163 L
.70821 .82134 L
.70753 .82177 L
.70064 .82612 L
.69529 .82935 L
.69306 .83066 L
.68549 .83496 L
.68192 .83692 L
.67792 .83904 L
.67035 .84291 L
.66714 .84449 L
.66278 .84657 L
.65521 .85003 L
.65054 .85206 L
.64764 .85329 L
.64007 .85636 L
.6325 .85924 L
.63143 .85963 L
.62492 .86194 L
.61735 .86447 L
.60978 .86682 L
.6085 .8672 L
.60221 .869 L
.59464 .87102 L
.58707 .87287 L
.5795 .87455 L
.57846 .87477 L
.57193 .87608 L
.56435 .87745 L
.55678 .87866 L
.54921 .87972 L
.54164 .88063 L
.53407 .88138 L
.5265 .88198 L
.52068 .88234 L
.51893 .88243 L
.51136 .88273 L
.50379 .88288 L
.49621 .88288 L
.48864 .88273 L
.48107 .88243 L
.47932 .88234 L
.4735 .88198 L
.46593 .88138 L
.45836 .88063 L
.45079 .87972 L
.44322 .87866 L
.43565 .87745 L
.42807 .87608 L
.42154 .87477 L
.4205 .87455 L
.41293 .87287 L
.40536 .87102 L
.39779 .869 L
.3915 .8672 L
.39022 .86682 L
.38265 .86447 L
.37508 .86194 L
.36857 .85963 L
.3675 .85924 L
.35993 .85636 L
.35236 .85329 L
.34946 .85206 L
.34479 .85002 L
.33722 .84657 L
.33286 .84449 L
.32965 .84291 L
.32208 .83904 L
.31808 .83692 L
.31451 .83496 L
.30694 .83066 L
.30471 .82935 L
.29936 .82612 L
.29247 .82177 L
.29179 .82134 L
.28422 .8163 L
.28118 .8142 L
.27665 .811 L
.27069 .80663 L
.26908 .80542 L
.26151 .79955 L
.26089 .79906 L
.25394 .79337 L
.25172 .79149 L
.24637 .78685 L
.24309 .78392 L
.23879 .77997 L
.23496 .77635 L
.23122 .77271 L
.22728 .76878 L
.22365 .76504 L
.22002 .76121 L
.21608 .75692 L
.21314 .75363 L
.20851 .7483 L
.20662 .74606 L
.20094 .73913 L
.20043 .73849 L
.19455 .73092 L
.19337 .72935 L
.18897 .72335 L
.1858 .71887 L
.18367 .71578 L
.17863 .70821 L
.17823 .70758 L
.17385 .70064 L
.17065 .69536 L
.16931 .69306 L
.165 .68549 L
.16308 .682 L
.16091 .67792 L
.15704 .67035 L
.15551 .66724 L
.15338 .66278 L
.14992 .65521 L
.14794 .65066 L
.14666 .64764 L
.14359 .64007 L
.1407 .6325 L
.14037 .63158 L
.138 .62492 L
.13547 .61735 L
.13312 .60978 L
.1328 .6087 L
.13094 .60221 L
.12892 .59464 L
.12707 .58707 L
.12538 .5795 L
.12523 .57877 L
.12385 .57193 L
.12248 .56435 L
.12127 .55678 L
.12021 .54921 L
.1193 .54164 L
.11855 .53407 L
.11795 .5265 L
.11766 .52195 L
.1175 .51893 L
.1172 .51136 L
.11705 .50379 L
.11705 .49621 L
.1172 .48864 L
.1175 .48107 L
.11766 .47805 L
.11795 .4735 L
.11855 .46593 L
.1193 .45836 L
.12021 .45079 L
.12127 .44322 L
.12248 .43565 L
.12385 .42807 L
.12523 .42123 L
.12538 .4205 L
.12707 .41293 L
.12892 .40536 L
.13094 .39779 L
.1328 .3913 L
.13312 .39022 L
.13547 .38265 L
.138 .37508 L
.14037 .36842 L
.1407 .3675 L
.14359 .35993 L
.14666 .35236 L
.14794 .34934 L
.14992 .34479 L
.15338 .33722 L
.15551 .33276 L
.15704 .32965 L
.16091 .32208 L
.16308 .318 L
.165 .31451 L
.16931 .30694 L
.17065 .30464 L
.17385 .29936 L
.17823 .29242 L
.17863 .29179 L
.18367 .28422 L
.1858 .28113 L
.18897 .27665 L
.19337 .27065 L
.19455 .26908 L
.20043 .26151 L
.20094 .26087 L
.20662 .25394 L
.20851 .2517 L
.21314 .24637 L
.21608 .24308 L
.22002 .23879 L
.22365 .23496 L
.22728 .23122 L
.23122 .22729 L
.23496 .22365 L
.23879 .22003 L
.24309 .21608 L
.24637 .21315 L
.25172 .20851 L
.25394 .20663 L
.26089 .20094 L
.26151 .20045 L
.26908 .19458 L
.27069 .19337 L
.27665 .189 L
.28118 .1858 L
.28422 .1837 L
.29179 .17866 L
.29247 .17823 L
.29936 .17388 L
.30471 .17065 L
.30694 .16934 L
.31451 .16504 L
.31808 .16308 L
.32208 .16096 L
.32965 .15709 L
.33286 .15551 L
.33722 .15343 L
.34479 .14998 L
.34946 .14794 L
.35236 .14671 L
.35993 .14364 L
.3675 .14076 L
.36857 .14037 L
.37508 .13806 L
.38265 .13553 L
.39022 .13318 L
.3915 .1328 L
.39779 .131 L
.40536 .12898 L
.41293 .12713 L
.4205 .12545 L
.42154 .12523 L
.42807 .12392 L
.43565 .12255 L
.44322 .12134 L
.45079 .12028 L
.45836 .11937 L
.46593 .11862 L
.4735 .11802 L
.47932 .11766 L
F
.121 .586 0 r
.42807 .13265 m
.43565 .13125 L
.44322 .13001 L
.45079 .12892 L
.45836 .128 L
.46593 .12723 L
.4735 .12661 L
.48107 .12615 L
.48864 .12585 L
.49621 .12569 L
.50379 .12569 L
.51136 .12585 L
.51893 .12615 L
.5265 .12661 L
.53407 .12723 L
.54164 .128 L
.54921 .12892 L
.55678 .13001 L
.56435 .13125 L
.57193 .13265 L
.57268 .1328 L
.5795 .13421 L
.58707 .13594 L
.59464 .13784 L
.60221 .1399 L
.60384 .14037 L
.60978 .14214 L
.61735 .14455 L
.62492 .14714 L
.62717 .14794 L
.6325 .14991 L
.64007 .15287 L
.64644 .15551 L
.64764 .15602 L
.65521 .15937 L
.66278 .16293 L
.6631 .16308 L
.67035 .16669 L
.6779 .17065 L
.67792 .17067 L
.68549 .17487 L
.69125 .17823 L
.69306 .17931 L
.70064 .18399 L
.70345 .1858 L
.70821 .18893 L
.71469 .19337 L
.71578 .19413 L
.72335 .19961 L
.72512 .20094 L
.73092 .20539 L
.73484 .20851 L
.73849 .21149 L
.74394 .21608 L
.74606 .21792 L
.75249 .22365 L
.75363 .2247 L
.76054 .23122 L
.76121 .23187 L
.76813 .23879 L
.76878 .23946 L
.77531 .24637 L
.77635 .2475 L
.7821 .25394 L
.78392 .25604 L
.78853 .26151 L
.79149 .26514 L
.79463 .26908 L
.79906 .27485 L
.80041 .27665 L
.8059 .28422 L
.80663 .28527 L
.8111 .29179 L
.8142 .2965 L
.81604 .29936 L
.82072 .30694 L
.82177 .30869 L
.82516 .31451 L
.82935 .32203 L
.82937 .32208 L
.83335 .32965 L
.83692 .33681 L
.83712 .33722 L
.84067 .34479 L
.84402 .35236 L
.84449 .35345 L
.84718 .35993 L
.85014 .3675 L
.85206 .37269 L
.85291 .37508 L
.85551 .38265 L
.85792 .39022 L
.85963 .39596 L
.86015 .39779 L
.86222 .40536 L
.86412 .41293 L
.86585 .4205 L
.8672 .42702 L
.86741 .42807 L
.86881 .43565 L
.87006 .44322 L
.87114 .45079 L
.87207 .45836 L
.87284 .46593 L
.87345 .4735 L
.87391 .48107 L
.87422 .48864 L
.87437 .49621 L
.87437 .50379 L
.87422 .51136 L
.87391 .51893 L
.87345 .5265 L
.87284 .53407 L
.87207 .54164 L
.87114 .54921 L
.87006 .55678 L
.86881 .56435 L
.86741 .57193 L
.8672 .57298 L
.86585 .5795 L
.86412 .58707 L
.86222 .59464 L
.86015 .60221 L
.85963 .60404 L
.85792 .60978 L
.85551 .61735 L
.85291 .62492 L
.85206 .62731 L
.85014 .6325 L
.84718 .64007 L
.84449 .64655 L
.84402 .64764 L
.84067 .65521 L
.83712 .66278 L
.83692 .66319 L
.83335 .67035 L
.82937 .67792 L
.82935 .67797 L
.82516 .68549 L
.82177 .69131 L
.82072 .69306 L
.81604 .70064 L
.8142 .7035 L
.8111 .70821 L
.80663 .71473 L
.8059 .71578 L
.80041 .72335 L
.79906 .72515 L
.79463 .73092 L
.79149 .73486 L
.78853 .73849 L
.78392 .74396 L
.7821 .74606 L
.77635 .7525 L
.77531 .75363 L
.76878 .76054 L
.76813 .76121 L
.76121 .76813 L
.76054 .76878 L
.75363 .7753 L
.75249 .77635 L
.74606 .78208 L
.74394 .78392 L
.73849 .78851 L
.73484 .79149 L
.73092 .79461 L
.72512 .79906 L
.72335 .80039 L
.71578 .80587 L
.71469 .80663 L
.70821 .81107 L
.70345 .8142 L
.70064 .81601 L
.69306 .82069 L
.69125 .82177 L
.68549 .82513 L
.67792 .82933 L
.6779 .82935 L
.67035 .83331 L
.6631 .83692 L
.66278 .83707 L
.65521 .84063 L
.64764 .84398 L
.64644 .84449 L
.64007 .84713 L
.6325 .85009 L
.62717 .85206 L
.62492 .85286 L
.61735 .85545 L
.60978 .85786 L
.60384 .85963 L
.60221 .8601 L
.59464 .86216 L
.58707 .86406 L
.5795 .86579 L
.57268 .8672 L
.57193 .86735 L
.56435 .86875 L
.55678 .86999 L
.54921 .87108 L
.54164 .872 L
.53407 .87277 L
.5265 .87339 L
.51893 .87385 L
.51136 .87415 L
.50379 .87431 L
.49621 .87431 L
.48864 .87415 L
.48107 .87385 L
.4735 .87339 L
.46593 .87277 L
.45836 .872 L
.45079 .87108 L
.44322 .86999 L
.43565 .86875 L
.42807 .86735 L
.42732 .8672 L
.4205 .86579 L
.41293 .86406 L
.40536 .86216 L
.39779 .8601 L
.39616 .85963 L
.39022 .85786 L
.38265 .85545 L
.37508 .85286 L
.37284 .85206 L
.3675 .85009 L
.35993 .84713 L
.35356 .84449 L
.35236 .84398 L
.34479 .84063 L
.33722 .83707 L
.3369 .83692 L
.32965 .83331 L
.32211 .82935 L
.32208 .82933 L
.31451 .82513 L
.30875 .82177 L
.30694 .82069 L
.29936 .81601 L
.29655 .8142 L
.29179 .81107 L
.28531 .80663 L
.28422 .80587 L
.27665 .80039 L
.27488 .79906 L
.26908 .79461 L
.26516 .79149 L
.26151 .78851 L
.25606 .78392 L
.25394 .78208 L
.24751 .77635 L
.24637 .7753 L
.23946 .76878 L
.23879 .76813 L
.23187 .76121 L
.23122 .76054 L
.22469 .75363 L
.22365 .7525 L
.2179 .74606 L
.21608 .74396 L
.21147 .73849 L
.20851 .73486 L
.20537 .73092 L
.20094 .72515 L
.19959 .72335 L
.1941 .71578 L
.19337 .71473 L
.1889 .70821 L
.1858 .7035 L
.18396 .70064 L
.17928 .69306 L
.17823 .69131 L
.17484 .68549 L
.17065 .67797 L
.17063 .67792 L
.16665 .67035 L
.16308 .66319 L
.16288 .66278 L
.15933 .65521 L
.15598 .64764 L
.15551 .64655 L
.15282 .64007 L
.14986 .6325 L
.14794 .62731 L
.14709 .62492 L
.1445 .61735 L
.14208 .60978 L
.14037 .60404 L
.13985 .60221 L
.13778 .59464 L
.13588 .58707 L
.13416 .5795 L
.1328 .57298 L
.13259 .57193 L
.13119 .56435 L
.12995 .55678 L
.12886 .54921 L
.12793 .54164 L
.12716 .53407 L
.12655 .5265 L
.12609 .51893 L
.12578 .51136 L
.12563 .50379 L
.12563 .49621 L
.12578 .48864 L
.12609 .48107 L
.12655 .4735 L
.12716 .46593 L
.12793 .45836 L
.12886 .45079 L
.12995 .44322 L
.13119 .43565 L
.13259 .42807 L
.1328 .42702 L
.13416 .4205 L
.13588 .41293 L
.13778 .40536 L
.13985 .39779 L
.14037 .39596 L
.14208 .39022 L
.1445 .38265 L
.14709 .37508 L
.14794 .37269 L
.14986 .3675 L
.15282 .35993 L
.15551 .35345 L
.15598 .35236 L
.15933 .34479 L
.16288 .33722 L
.16308 .33681 L
.16665 .32965 L
.17063 .32208 L
.17065 .32203 L
.17484 .31451 L
.17823 .30869 L
.17928 .30694 L
.18396 .29936 L
.1858 .2965 L
.1889 .29179 L
.19337 .28527 L
.1941 .28422 L
.19959 .27665 L
.20094 .27485 L
.20537 .26908 L
.20851 .26514 L
.21147 .26151 L
.21608 .25604 L
.2179 .25394 L
.22365 .2475 L
.22469 .24637 L
.23122 .23946 L
.23187 .23879 L
.23879 .23187 L
.23946 .23122 L
.24637 .2247 L
.24751 .22365 L
.25394 .21792 L
.25606 .21608 L
.26151 .21149 L
.26516 .20851 L
.26908 .20539 L
.27488 .20094 L
.27665 .19961 L
.28422 .19413 L
.28531 .19337 L
.29179 .18893 L
.29655 .1858 L
.29936 .18399 L
.30694 .17931 L
.30875 .17823 L
.31451 .17487 L
.32208 .17067 L
.32211 .17065 L
.32965 .16669 L
.3369 .16308 L
.33722 .16293 L
.34479 .15937 L
.35236 .15602 L
.35356 .15551 L
.35993 .15287 L
.3675 .14991 L
.37284 .14794 L
.37508 .14714 L
.38265 .14455 L
.39022 .14214 L
.39616 .14037 L
.39779 .1399 L
.40536 .13784 L
.41293 .13594 L
.4205 .13421 L
.42732 .1328 L
F
.073 .568 0 r
.43565 .13997 m
.44322 .13869 L
.45079 .13758 L
.45836 .13664 L
.46593 .13585 L
.4735 .13522 L
.48107 .13475 L
.48864 .13443 L
.49621 .13428 L
.50379 .13428 L
.51136 .13443 L
.51893 .13475 L
.5265 .13522 L
.53407 .13585 L
.54164 .13664 L
.54921 .13758 L
.55678 .13869 L
.56435 .13997 L
.56658 .14037 L
.57193 .1414 L
.5795 .143 L
.58707 .14478 L
.59464 .14672 L
.59909 .14794 L
.60221 .14883 L
.60978 .15113 L
.61735 .1536 L
.62285 .15551 L
.62492 .15626 L
.6325 .15911 L
.64007 .16215 L
.6423 .16308 L
.64764 .16539 L
.65521 .16883 L
.65904 .17065 L
.66278 .17249 L
.67035 .17636 L
.67385 .17823 L
.67792 .18046 L
.68549 .18479 L
.68719 .1858 L
.69306 .18937 L
.69935 .19337 L
.70064 .19421 L
.70821 .19931 L
.71054 .20094 L
.71578 .2047 L
.7209 .20851 L
.72335 .21038 L
.73055 .21608 L
.73092 .21638 L
.73849 .22272 L
.73958 .22365 L
.74606 .22941 L
.74804 .23122 L
.75363 .23649 L
.75601 .23879 L
.76121 .24399 L
.76351 .24637 L
.76878 .25195 L
.7706 .25394 L
.77635 .26041 L
.7773 .26151 L
.78363 .26908 L
.78392 .26943 L
.78964 .27665 L
.79149 .27907 L
.79532 .28422 L
.79906 .28943 L
.80071 .29179 L
.80582 .29936 L
.80663 .30061 L
.81066 .30694 L
.8142 .31276 L
.81524 .31451 L
.81958 .32208 L
.82177 .32608 L
.82368 .32965 L
.82755 .33722 L
.82935 .34088 L
.83121 .34479 L
.83466 .35236 L
.83692 .35759 L
.8379 .35993 L
.84094 .3675 L
.84379 .37508 L
.84449 .37702 L
.84645 .38265 L
.84892 .39022 L
.85122 .39779 L
.85206 .40072 L
.85334 .40536 L
.85528 .41293 L
.85705 .4205 L
.85865 .42807 L
.85963 .43312 L
.86009 .43565 L
.86136 .44322 L
.86247 .45079 L
.86342 .45836 L
.86421 .46593 L
.86484 .4735 L
.86531 .48107 L
.86562 .48864 L
.86578 .49621 L
.86578 .50379 L
.86562 .51136 L
.86531 .51893 L
.86484 .5265 L
.86421 .53407 L
.86342 .54164 L
.86247 .54921 L
.86136 .55678 L
.86009 .56435 L
.85963 .56688 L
.85865 .57193 L
.85705 .5795 L
.85528 .58707 L
.85334 .59464 L
.85206 .59928 L
.85122 .60221 L
.84892 .60978 L
.84645 .61735 L
.84449 .62298 L
.84379 .62492 L
.84094 .6325 L
.8379 .64007 L
.83692 .64241 L
.83466 .64764 L
.83121 .65521 L
.82935 .65912 L
.82755 .66278 L
.82368 .67035 L
.82177 .67392 L
.81958 .67792 L
.81524 .68549 L
.8142 .68724 L
.81066 .69306 L
.80663 .69939 L
.80582 .70064 L
.80071 .70821 L
.79906 .71057 L
.79532 .71578 L
.79149 .72093 L
.78964 .72335 L
.78392 .73057 L
.78363 .73092 L
.7773 .73849 L
.77635 .73959 L
.7706 .74606 L
.76878 .74805 L
.76351 .75363 L
.76121 .75601 L
.75601 .76121 L
.75363 .76351 L
.74804 .76878 L
.74606 .77059 L
.73958 .77635 L
.73849 .77728 L
.73092 .78362 L
.73055 .78392 L
.72335 .78962 L
.7209 .79149 L
.71578 .7953 L
.71054 .79906 L
.70821 .80069 L
.70064 .80579 L
.69935 .80663 L
.69306 .81063 L
.68719 .8142 L
.68549 .81521 L
.67792 .81954 L
.67385 .82177 L
.67035 .82364 L
.66278 .82751 L
.65904 .82935 L
.65521 .83117 L
.64764 .83461 L
.6423 .83692 L
.64007 .83785 L
.6325 .84089 L
.62492 .84374 L
.62285 .84449 L
.61735 .8464 L
.60978 .84887 L
.60221 .85117 L
.59909 .85206 L
.59464 .85328 L
.58707 .85522 L
.5795 .857 L
.57193 .8586 L
.56658 .85963 L
.56435 .86003 L
.55678 .86131 L
.54921 .86242 L
.54164 .86336 L
.53407 .86415 L
.5265 .86478 L
.51893 .86525 L
.51136 .86557 L
.50379 .86572 L
.49621 .86572 L
.48864 .86557 L
.48107 .86525 L
.4735 .86478 L
.46593 .86415 L
.45836 .86336 L
.45079 .86242 L
.44322 .86131 L
.43565 .86003 L
.43342 .85963 L
.42807 .8586 L
.4205 .857 L
.41293 .85522 L
.40536 .85328 L
.40091 .85206 L
.39779 .85117 L
.39022 .84887 L
.38265 .8464 L
.37715 .84449 L
.37508 .84374 L
.3675 .84089 L
.35993 .83785 L
.3577 .83692 L
.35236 .83461 L
.34479 .83117 L
.34096 .82935 L
.33722 .82751 L
.32965 .82364 L
.32615 .82177 L
.32208 .81954 L
.31451 .81521 L
.31281 .8142 L
.30694 .81063 L
.30065 .80663 L
.29936 .80579 L
.29179 .80069 L
.28946 .79906 L
.28422 .7953 L
.2791 .79149 L
.27665 .78962 L
.26945 .78392 L
.26908 .78362 L
.26151 .77728 L
.26042 .77635 L
.25394 .77059 L
.25196 .76878 L
.24637 .76351 L
.24399 .76121 L
.23879 .75601 L
.23649 .75363 L
.23122 .74805 L
.2294 .74606 L
.22365 .73959 L
.2227 .73849 L
.21637 .73092 L
.21608 .73057 L
.21036 .72335 L
.20851 .72093 L
.20468 .71578 L
.20094 .71057 L
.19929 .70821 L
.19418 .70064 L
.19337 .69939 L
.18934 .69306 L
.1858 .68724 L
.18476 .68549 L
.18042 .67792 L
.17823 .67392 L
.17632 .67035 L
.17245 .66278 L
.17065 .65912 L
.16879 .65521 L
.16534 .64764 L
.16308 .64241 L
.1621 .64007 L
.15906 .6325 L
.15621 .62492 L
.15551 .62298 L
.15355 .61735 L
.15108 .60978 L
.14878 .60221 L
.14794 .59928 L
.14667 .59464 L
.14472 .58707 L
.14295 .5795 L
.14135 .57193 L
.14037 .56688 L
.13991 .56435 L
.13864 .55678 L
.13753 .54921 L
.13658 .54164 L
.13579 .53407 L
.13516 .5265 L
.13469 .51893 L
.13438 .51136 L
.13422 .50379 L
.13422 .49621 L
.13438 .48864 L
.13469 .48107 L
.13516 .4735 L
.13579 .46593 L
.13658 .45836 L
.13753 .45079 L
.13864 .44322 L
.13991 .43565 L
.14037 .43312 L
.14135 .42807 L
.14295 .4205 L
.14472 .41293 L
.14667 .40536 L
.14794 .40072 L
.14878 .39779 L
.15108 .39022 L
.15355 .38265 L
.15551 .37702 L
.15621 .37508 L
.15906 .3675 L
.1621 .35993 L
.16308 .35759 L
.16534 .35236 L
.16879 .34479 L
.17065 .34088 L
.17245 .33722 L
.17632 .32965 L
.17823 .32608 L
.18042 .32208 L
.18476 .31451 L
.1858 .31276 L
.18934 .30694 L
.19337 .30061 L
.19418 .29936 L
.19929 .29179 L
.20094 .28943 L
.20468 .28422 L
.20851 .27907 L
.21036 .27665 L
.21608 .26943 L
.21637 .26908 L
.2227 .26151 L
.22365 .26041 L
.2294 .25394 L
.23122 .25195 L
.23649 .24637 L
.23879 .24399 L
.24399 .23879 L
.24637 .23649 L
.25196 .23122 L
.25394 .22941 L
.26042 .22365 L
.26151 .22272 L
.26908 .21638 L
.26945 .21608 L
.27665 .21038 L
.2791 .20851 L
.28422 .2047 L
.28946 .20094 L
.29179 .19931 L
.29936 .19421 L
.30065 .19337 L
.30694 .18937 L
.31281 .1858 L
.31451 .18479 L
.32208 .18046 L
.32615 .17823 L
.32965 .17636 L
.33722 .17249 L
.34096 .17065 L
.34479 .16883 L
.35236 .16539 L
.3577 .16308 L
.35993 .16215 L
.3675 .15911 L
.37508 .15626 L
.37715 .15551 L
.38265 .1536 L
.39022 .15113 L
.39779 .14883 L
.40091 .14794 L
.40536 .14672 L
.41293 .14478 L
.4205 .143 L
.42807 .1414 L
.43342 .14037 L
F
.028 .55 0 r
.44322 .14741 m
.45079 .14628 L
.45836 .1453 L
.46593 .1445 L
.4735 .14385 L
.48107 .14337 L
.48864 .14305 L
.49621 .14289 L
.50379 .14289 L
.51136 .14305 L
.51893 .14337 L
.5265 .14385 L
.53407 .1445 L
.54164 .1453 L
.54921 .14628 L
.55678 .14741 L
.55998 .14794 L
.56435 .14872 L
.57193 .15019 L
.5795 .15183 L
.58707 .15365 L
.59418 .15551 L
.59464 .15564 L
.60221 .15781 L
.60978 .16016 L
.61735 .1627 L
.61844 .16308 L
.62492 .16543 L
.6325 .16836 L
.6381 .17065 L
.64007 .17149 L
.64764 .17482 L
.65492 .17823 L
.65521 .17836 L
.66278 .18213 L
.66975 .1858 L
.67035 .18612 L
.67792 .19035 L
.68307 .19337 L
.68549 .19483 L
.69306 .19956 L
.6952 .20094 L
.70064 .20456 L
.70633 .20851 L
.70821 .20985 L
.71578 .21543 L
.71663 .21608 L
.72335 .22133 L
.72621 .22365 L
.73092 .22757 L
.73516 .23122 L
.73849 .23417 L
.74354 .23879 L
.74606 .24116 L
.75142 .24637 L
.75363 .24858 L
.75884 .25394 L
.76121 .25645 L
.76583 .26151 L
.76878 .26483 L
.77244 .26908 L
.77635 .27377 L
.77868 .27665 L
.78392 .28334 L
.78459 .28422 L
.79017 .29179 L
.79149 .29364 L
.79546 .29936 L
.79906 .30476 L
.80047 .30694 L
.8052 .31451 L
.80663 .31688 L
.80968 .32208 L
.81391 .32965 L
.8142 .33019 L
.81791 .33722 L
.82167 .34479 L
.82177 .345 L
.82522 .35236 L
.82855 .35993 L
.82935 .3618 L
.83168 .3675 L
.83461 .37508 L
.83692 .38144 L
.83734 .38265 L
.83988 .39022 L
.84224 .39779 L
.84441 .40536 L
.84449 .40565 L
.8464 .41293 L
.84822 .4205 L
.84986 .42807 L
.85134 .43565 L
.85206 .43972 L
.85264 .44322 L
.85378 .45079 L
.85475 .45836 L
.85556 .46593 L
.8562 .4735 L
.85668 .48107 L
.85701 .48864 L
.85717 .49621 L
.85717 .50379 L
.85701 .51136 L
.85668 .51893 L
.8562 .5265 L
.85556 .53407 L
.85475 .54164 L
.85378 .54921 L
.85264 .55678 L
.85206 .56028 L
.85134 .56435 L
.84986 .57193 L
.84822 .5795 L
.8464 .58707 L
.84449 .59435 L
.84441 .59464 L
.84224 .60221 L
.83988 .60978 L
.83734 .61735 L
.83692 .61856 L
.83461 .62492 L
.83168 .6325 L
.82935 .6382 L
.82855 .64007 L
.82522 .64764 L
.82177 .655 L
.82167 .65521 L
.81791 .66278 L
.8142 .66981 L
.81391 .67035 L
.80968 .67792 L
.80663 .68312 L
.8052 .68549 L
.80047 .69306 L
.79906 .69524 L
.79546 .70064 L
.79149 .70636 L
.79017 .70821 L
.78459 .71578 L
.78392 .71666 L
.77868 .72335 L
.77635 .72623 L
.77244 .73092 L
.76878 .73517 L
.76583 .73849 L
.76121 .74355 L
.75884 .74606 L
.75363 .75142 L
.75142 .75363 L
.74606 .75884 L
.74354 .76121 L
.73849 .76583 L
.73516 .76878 L
.73092 .77243 L
.72621 .77635 L
.72335 .77867 L
.71663 .78392 L
.71578 .78457 L
.70821 .79015 L
.70633 .79149 L
.70064 .79544 L
.6952 .79906 L
.69306 .80044 L
.68549 .80517 L
.68307 .80663 L
.67792 .80965 L
.67035 .81388 L
.66975 .8142 L
.66278 .81787 L
.65521 .82164 L
.65492 .82177 L
.64764 .82518 L
.64007 .82851 L
.6381 .82935 L
.6325 .83164 L
.62492 .83457 L
.61844 .83692 L
.61735 .8373 L
.60978 .83984 L
.60221 .84219 L
.59464 .84436 L
.59418 .84449 L
.58707 .84635 L
.5795 .84817 L
.57193 .84981 L
.56435 .85128 L
.55998 .85206 L
.55678 .85259 L
.54921 .85372 L
.54164 .8547 L
.53407 .8555 L
.5265 .85615 L
.51893 .85663 L
.51136 .85695 L
.50379 .85711 L
.49621 .85711 L
.48864 .85695 L
.48107 .85663 L
.4735 .85615 L
.46593 .8555 L
.45836 .8547 L
.45079 .85372 L
.44322 .85259 L
.44002 .85206 L
.43565 .85128 L
.42807 .84981 L
.4205 .84817 L
.41293 .84635 L
.40582 .84449 L
.40536 .84436 L
.39779 .84219 L
.39022 .83984 L
.38265 .8373 L
.38156 .83692 L
.37508 .83457 L
.3675 .83164 L
.3619 .82935 L
.35993 .82851 L
.35236 .82518 L
.34508 .82177 L
.34479 .82164 L
.33722 .81787 L
.33025 .8142 L
.32965 .81388 L
.32208 .80965 L
.31693 .80663 L
.31451 .80517 L
.30694 .80044 L
.3048 .79906 L
.29936 .79544 L
.29367 .79149 L
.29179 .79015 L
.28422 .78457 L
.28337 .78392 L
.27665 .77867 L
.27379 .77635 L
.26908 .77243 L
.26484 .76878 L
.26151 .76583 L
.25646 .76121 L
.25394 .75884 L
.24858 .75363 L
.24637 .75142 L
.24116 .74606 L
.23879 .74355 L
.23417 .73849 L
.23122 .73517 L
.22756 .73092 L
.22365 .72623 L
.22132 .72335 L
.21608 .71666 L
.21541 .71578 L
.20983 .70821 L
.20851 .70636 L
.20454 .70064 L
.20094 .69524 L
.19953 .69306 L
.1948 .68549 L
.19337 .68312 L
.19032 .67792 L
.18609 .67035 L
.1858 .66981 L
.18209 .66278 L
.17833 .65521 L
.17823 .655 L
.17478 .64764 L
.17145 .64007 L
.17065 .6382 L
.16832 .6325 L
.16539 .62492 L
.16308 .61856 L
.16266 .61735 L
.16012 .60978 L
.15776 .60221 L
.15559 .59464 L
.15551 .59435 L
.1536 .58707 L
.15178 .5795 L
.15014 .57193 L
.14866 .56435 L
.14794 .56028 L
.14736 .55678 L
.14622 .54921 L
.14525 .54164 L
.14444 .53407 L
.1438 .5265 L
.14332 .51893 L
.14299 .51136 L
.14283 .50379 L
.14283 .49621 L
.14299 .48864 L
.14332 .48107 L
.1438 .4735 L
.14444 .46593 L
.14525 .45836 L
.14622 .45079 L
.14736 .44322 L
.14794 .43972 L
.14866 .43565 L
.15014 .42807 L
.15178 .4205 L
.1536 .41293 L
.15551 .40565 L
.15559 .40536 L
.15776 .39779 L
.16012 .39022 L
.16266 .38265 L
.16308 .38144 L
.16539 .37508 L
.16832 .3675 L
.17065 .3618 L
.17145 .35993 L
.17478 .35236 L
.17823 .345 L
.17833 .34479 L
.18209 .33722 L
.1858 .33019 L
.18609 .32965 L
.19032 .32208 L
.19337 .31688 L
.1948 .31451 L
.19953 .30694 L
.20094 .30476 L
.20454 .29936 L
.20851 .29364 L
.20983 .29179 L
.21541 .28422 L
.21608 .28334 L
.22132 .27665 L
.22365 .27377 L
.22756 .26908 L
.23122 .26483 L
.23417 .26151 L
.23879 .25645 L
.24116 .25394 L
.24637 .24858 L
.24858 .24637 L
.25394 .24116 L
.25646 .23879 L
.26151 .23417 L
.26484 .23122 L
.26908 .22757 L
.27379 .22365 L
.27665 .22133 L
.28337 .21608 L
.28422 .21543 L
.29179 .20985 L
.29367 .20851 L
.29936 .20456 L
.3048 .20094 L
.30694 .19956 L
.31451 .19483 L
.31693 .19337 L
.32208 .19035 L
.32965 .18612 L
.33025 .1858 L
.33722 .18213 L
.34479 .17836 L
.34508 .17823 L
.35236 .17482 L
.35993 .17149 L
.3619 .17065 L
.3675 .16836 L
.37508 .16543 L
.38156 .16308 L
.38265 .1627 L
.39022 .16016 L
.39779 .15781 L
.40536 .15564 L
.40582 .15551 L
.41293 .15365 L
.4205 .15183 L
.42807 .15019 L
.43565 .14872 L
.44002 .14794 L
F
0 .532 .015 r
.45079 .15501 m
.45836 .15401 L
.46593 .15319 L
.4735 .15252 L
.48107 .15203 L
.48864 .1517 L
.49621 .15154 L
.50379 .15154 L
.51136 .1517 L
.51893 .15203 L
.5265 .15252 L
.53407 .15319 L
.54164 .15401 L
.54921 .15501 L
.55263 .15551 L
.55678 .15617 L
.56435 .15751 L
.57193 .15902 L
.5795 .16071 L
.58707 .16257 L
.58903 .16308 L
.59464 .16462 L
.60221 .16685 L
.60978 .16926 L
.61389 .17065 L
.61735 .17187 L
.62492 .17468 L
.6325 .17769 L
.63379 .17823 L
.64007 .18091 L
.64764 .18434 L
.65071 .1858 L
.65521 .18799 L
.66278 .19188 L
.66557 .19337 L
.67035 .196 L
.67792 .20037 L
.67888 .20094 L
.68549 .20499 L
.69097 .20851 L
.69306 .20989 L
.70064 .21508 L
.70206 .21608 L
.70821 .22056 L
.7123 .22365 L
.71578 .22636 L
.7218 .23122 L
.72335 .23251 L
.73067 .23879 L
.73092 .23901 L
.73849 .24591 L
.73898 .24637 L
.74606 .25323 L
.74677 .25394 L
.75363 .26102 L
.75409 .26151 L
.761 .26908 L
.76121 .26932 L
.76751 .27665 L
.76878 .27818 L
.77365 .28422 L
.77635 .28768 L
.77946 .29179 L
.78392 .29791 L
.78495 .29936 L
.79013 .30694 L
.79149 .30899 L
.79503 .31451 L
.79906 .32107 L
.79966 .32208 L
.80403 .32965 L
.80663 .33437 L
.80815 .33722 L
.81204 .34479 L
.8142 .34922 L
.81569 .35236 L
.81913 .35993 L
.82177 .36612 L
.82235 .3675 L
.82536 .37508 L
.82817 .38265 L
.82935 .386 L
.83078 .39022 L
.8332 .39779 L
.83543 .40536 L
.83692 .4108 L
.83747 .41293 L
.83934 .4205 L
.84103 .42807 L
.84254 .43565 L
.84387 .44322 L
.84449 .44706 L
.84504 .45079 L
.84604 .45836 L
.84686 .46593 L
.84752 .4735 L
.84802 .48107 L
.84835 .48864 L
.84851 .49621 L
.84851 .50379 L
.84835 .51136 L
.84802 .51893 L
.84752 .5265 L
.84686 .53407 L
.84604 .54164 L
.84504 .54921 L
.84449 .55294 L
.84387 .55678 L
.84254 .56435 L
.84103 .57193 L
.83934 .5795 L
.83747 .58707 L
.83692 .5892 L
.83543 .59464 L
.8332 .60221 L
.83078 .60978 L
.82935 .614 L
.82817 .61735 L
.82536 .62492 L
.82235 .6325 L
.82177 .63388 L
.81913 .64007 L
.81569 .64764 L
.8142 .65078 L
.81204 .65521 L
.80815 .66278 L
.80663 .66563 L
.80403 .67035 L
.79966 .67792 L
.79906 .67893 L
.79503 .68549 L
.79149 .69101 L
.79013 .69306 L
.78495 .70064 L
.78392 .70209 L
.77946 .70821 L
.77635 .71232 L
.77365 .71578 L
.76878 .72182 L
.76751 .72335 L
.76121 .73068 L
.761 .73092 L
.75409 .73849 L
.75363 .73898 L
.74677 .74606 L
.74606 .74677 L
.73898 .75363 L
.73849 .75409 L
.73092 .76099 L
.73067 .76121 L
.72335 .76749 L
.7218 .76878 L
.71578 .77364 L
.7123 .77635 L
.70821 .77944 L
.70206 .78392 L
.70064 .78492 L
.69306 .79011 L
.69097 .79149 L
.68549 .79501 L
.67888 .79906 L
.67792 .79963 L
.67035 .804 L
.66557 .80663 L
.66278 .80812 L
.65521 .81201 L
.65071 .8142 L
.64764 .81566 L
.64007 .81909 L
.63379 .82177 L
.6325 .82231 L
.62492 .82532 L
.61735 .82813 L
.61389 .82935 L
.60978 .83074 L
.60221 .83315 L
.59464 .83538 L
.58903 .83692 L
.58707 .83743 L
.5795 .83929 L
.57193 .84098 L
.56435 .84249 L
.55678 .84383 L
.55263 .84449 L
.54921 .84499 L
.54164 .84599 L
.53407 .84681 L
.5265 .84748 L
.51893 .84797 L
.51136 .8483 L
.50379 .84846 L
.49621 .84846 L
.48864 .8483 L
.48107 .84797 L
.4735 .84748 L
.46593 .84681 L
.45836 .84599 L
.45079 .84499 L
.44737 .84449 L
.44322 .84383 L
.43565 .84249 L
.42807 .84098 L
.4205 .83929 L
.41293 .83743 L
.41097 .83692 L
.40536 .83538 L
.39779 .83315 L
.39022 .83074 L
.38611 .82935 L
.38265 .82813 L
.37508 .82532 L
.3675 .82231 L
.36621 .82177 L
.35993 .81909 L
.35236 .81566 L
.34929 .8142 L
.34479 .812 L
.33722 .80812 L
.33443 .80663 L
.32965 .804 L
.32208 .79963 L
.32112 .79906 L
.31451 .79501 L
.30903 .79149 L
.30694 .79011 L
.29936 .78492 L
.29794 .78392 L
.29179 .77944 L
.2877 .77635 L
.28422 .77364 L
.2782 .76878 L
.27665 .76749 L
.26933 .76121 L
.26908 .76099 L
.26151 .75409 L
.26102 .75363 L
.25394 .74677 L
.25323 .74606 L
.24637 .73898 L
.24591 .73849 L
.239 .73092 L
.23879 .73068 L
.23249 .72335 L
.23122 .72182 L
.22635 .71578 L
.22365 .71232 L
.22054 .70821 L
.21608 .70209 L
.21505 .70064 L
.20987 .69306 L
.20851 .69101 L
.20497 .68549 L
.20094 .67893 L
.20034 .67792 L
.19597 .67035 L
.19337 .66563 L
.19185 .66278 L
.18796 .65521 L
.1858 .65078 L
.18431 .64764 L
.18087 .64007 L
.17823 .63388 L
.17765 .6325 L
.17464 .62492 L
.17183 .61735 L
.17065 .614 L
.16922 .60978 L
.1668 .60221 L
.16457 .59464 L
.16308 .5892 L
.16253 .58707 L
.16066 .5795 L
.15897 .57193 L
.15746 .56435 L
.15613 .55678 L
.15551 .55294 L
.15496 .54921 L
.15396 .54164 L
.15314 .53407 L
.15248 .5265 L
.15198 .51893 L
.15165 .51136 L
.15149 .50379 L
.15149 .49621 L
.15165 .48864 L
.15198 .48107 L
.15248 .4735 L
.15314 .46593 L
.15396 .45836 L
.15496 .45079 L
.15551 .44706 L
.15613 .44322 L
.15746 .43565 L
.15897 .42807 L
.16066 .4205 L
.16253 .41293 L
.16308 .4108 L
.16457 .40536 L
.1668 .39779 L
.16922 .39022 L
.17065 .386 L
.17183 .38265 L
.17464 .37508 L
.17765 .3675 L
.17823 .36612 L
.18087 .35993 L
.18431 .35236 L
.1858 .34922 L
.18796 .34479 L
.19185 .33722 L
.19337 .33437 L
.19597 .32965 L
.20034 .32208 L
.20094 .32107 L
.20497 .31451 L
.20851 .30899 L
.20987 .30694 L
.21505 .29936 L
.21608 .29791 L
.22054 .29179 L
.22365 .28768 L
.22635 .28422 L
.23122 .27818 L
.23249 .27665 L
.23879 .26932 L
.239 .26908 L
.24591 .26151 L
.24637 .26102 L
.25323 .25394 L
.25394 .25323 L
.26102 .24637 L
.26151 .24591 L
.26908 .23901 L
.26933 .23879 L
.27665 .23251 L
.2782 .23122 L
.28422 .22636 L
.2877 .22365 L
.29179 .22056 L
.29794 .21608 L
.29936 .21508 L
.30694 .20989 L
.30903 .20851 L
.31451 .20499 L
.32112 .20094 L
.32208 .20037 L
.32965 .196 L
.33443 .19337 L
.33722 .19188 L
.34479 .188 L
.34929 .1858 L
.35236 .18434 L
.35993 .18091 L
.36621 .17823 L
.3675 .17769 L
.37508 .17468 L
.38265 .17187 L
.38611 .17065 L
.39022 .16926 L
.39779 .16685 L
.40536 .16462 L
.41097 .16308 L
.41293 .16257 L
.4205 .16071 L
.42807 .15902 L
.43565 .15751 L
.44322 .15617 L
.44737 .15551 L
F
0 .514 .054 r
.45836 .16278 m
.46593 .16193 L
.4735 .16125 L
.48107 .16074 L
.48864 .16041 L
.49621 .16024 L
.50379 .16024 L
.51136 .16041 L
.51893 .16074 L
.5265 .16125 L
.53407 .16193 L
.54164 .16278 L
.54405 .16308 L
.54921 .1638 L
.55678 .165 L
.56435 .16637 L
.57193 .16792 L
.5795 .16965 L
.58357 .17065 L
.58707 .17156 L
.59464 .17367 L
.60221 .17596 L
.60914 .17823 L
.60978 .17844 L
.61735 .18113 L
.62492 .18402 L
.62933 .1858 L
.6325 .18712 L
.64007 .19043 L
.64638 .19337 L
.64764 .19397 L
.65521 .19774 L
.66128 .20094 L
.66278 .20175 L
.67035 .20601 L
.67459 .20851 L
.67792 .21053 L
.68549 .21532 L
.68665 .21608 L
.69306 .2204 L
.69769 .22365 L
.70064 .22578 L
.70787 .23122 L
.70821 .23149 L
.71578 .23753 L
.71731 .23879 L
.72335 .24394 L
.7261 .24637 L
.73092 .25075 L
.73432 .25394 L
.73849 .25798 L
.74202 .26151 L
.74606 .26568 L
.74926 .26908 L
.75363 .27389 L
.75607 .27665 L
.76121 .28268 L
.76248 .28422 L
.76853 .29179 L
.76878 .29211 L
.77423 .29936 L
.77635 .30229 L
.77962 .30694 L
.78392 .31332 L
.7847 .31451 L
.78949 .32208 L
.79149 .32537 L
.79401 .32965 L
.79827 .33722 L
.79906 .33867 L
.80229 .34479 L
.80606 .35236 L
.80663 .35356 L
.8096 .35993 L
.81292 .3675 L
.8142 .37059 L
.81602 .37508 L
.81891 .38265 L
.82159 .39022 L
.82177 .39075 L
.82408 .39779 L
.82637 .40536 L
.82848 .41293 L
.82935 .41627 L
.83039 .4205 L
.83212 .42807 L
.83368 .43565 L
.83505 .44322 L
.83624 .45079 L
.83692 .45561 L
.83727 .45836 L
.83812 .46593 L
.83879 .4735 L
.8393 .48107 L
.83964 .48864 L
.83981 .49621 L
.83981 .50379 L
.83964 .51136 L
.8393 .51893 L
.83879 .5265 L
.83812 .53407 L
.83727 .54164 L
.83692 .54439 L
.83624 .54921 L
.83505 .55678 L
.83368 .56435 L
.83212 .57193 L
.83039 .5795 L
.82935 .58373 L
.82848 .58707 L
.82637 .59464 L
.82408 .60221 L
.82177 .60925 L
.82159 .60978 L
.81891 .61735 L
.81602 .62492 L
.8142 .62941 L
.81292 .6325 L
.8096 .64007 L
.80663 .64644 L
.80606 .64764 L
.80229 .65521 L
.79906 .66133 L
.79827 .66278 L
.79401 .67035 L
.79149 .67463 L
.78949 .67792 L
.7847 .68549 L
.78392 .68668 L
.77962 .69306 L
.77635 .69771 L
.77423 .70064 L
.76878 .70789 L
.76853 .70821 L
.76248 .71578 L
.76121 .71732 L
.75607 .72335 L
.75363 .72611 L
.74926 .73092 L
.74606 .73432 L
.74202 .73849 L
.73849 .74202 L
.73432 .74606 L
.73092 .74925 L
.7261 .75363 L
.72335 .75606 L
.71731 .76121 L
.71578 .76247 L
.70821 .76851 L
.70787 .76878 L
.70064 .77422 L
.69769 .77635 L
.69306 .7796 L
.68665 .78392 L
.68549 .78468 L
.67792 .78947 L
.67459 .79149 L
.67035 .79399 L
.66278 .79825 L
.66128 .79906 L
.65521 .80226 L
.64764 .80603 L
.64638 .80663 L
.64007 .80957 L
.6325 .81288 L
.62933 .8142 L
.62492 .81598 L
.61735 .81887 L
.60978 .82156 L
.60914 .82177 L
.60221 .82404 L
.59464 .82633 L
.58707 .82844 L
.58357 .82935 L
.5795 .83035 L
.57193 .83208 L
.56435 .83363 L
.55678 .835 L
.54921 .8362 L
.54405 .83692 L
.54164 .83722 L
.53407 .83807 L
.5265 .83875 L
.51893 .83926 L
.51136 .83959 L
.50379 .83976 L
.49621 .83976 L
.48864 .83959 L
.48107 .83926 L
.4735 .83875 L
.46593 .83807 L
.45836 .83722 L
.45595 .83692 L
.45079 .8362 L
.44322 .835 L
.43565 .83363 L
.42807 .83208 L
.4205 .83035 L
.41643 .82935 L
.41293 .82844 L
.40536 .82633 L
.39779 .82404 L
.39086 .82177 L
.39022 .82156 L
.38265 .81887 L
.37508 .81598 L
.37067 .8142 L
.3675 .81288 L
.35993 .80957 L
.35362 .80663 L
.35236 .80603 L
.34479 .80226 L
.33872 .79906 L
.33722 .79825 L
.32965 .79399 L
.32541 .79149 L
.32208 .78947 L
.31451 .78468 L
.31335 .78392 L
.30694 .7796 L
.30231 .77635 L
.29936 .77422 L
.29213 .76878 L
.29179 .76851 L
.28422 .76247 L
.28269 .76121 L
.27665 .75606 L
.2739 .75363 L
.26908 .74925 L
.26568 .74606 L
.26151 .74202 L
.25798 .73849 L
.25394 .73432 L
.25074 .73092 L
.24637 .72611 L
.24393 .72335 L
.23879 .71732 L
.23752 .71578 L
.23147 .70821 L
.23122 .70789 L
.22577 .70064 L
.22365 .69771 L
.22038 .69306 L
.21608 .68668 L
.2153 .68549 L
.21051 .67792 L
.20851 .67463 L
.20599 .67035 L
.20173 .66278 L
.20094 .66133 L
.19771 .65521 L
.19394 .64764 L
.19337 .64644 L
.1904 .64007 L
.18709 .6325 L
.1858 .62941 L
.18398 .62492 L
.18109 .61735 L
.17841 .60978 L
.17823 .60925 L
.17592 .60221 L
.17363 .59464 L
.17152 .58707 L
.17065 .58373 L
.16961 .5795 L
.16788 .57193 L
.16633 .56435 L
.16495 .55678 L
.16376 .54921 L
.16308 .54439 L
.16273 .54164 L
.16188 .53407 L
.16121 .5265 L
.1607 .51893 L
.16036 .51136 L
.16019 .50379 L
.16019 .49621 L
.16036 .48864 L
.1607 .48107 L
.16121 .4735 L
.16188 .46593 L
.16273 .45836 L
.16308 .45561 L
.16376 .45079 L
.16495 .44322 L
.16633 .43565 L
.16788 .42807 L
.16961 .4205 L
.17065 .41627 L
.17152 .41293 L
.17363 .40536 L
.17592 .39779 L
.17823 .39075 L
.17841 .39022 L
.18109 .38265 L
.18398 .37508 L
.1858 .37059 L
.18709 .3675 L
.1904 .35993 L
.19337 .35356 L
.19394 .35236 L
.19771 .34479 L
.20094 .33867 L
.20173 .33722 L
.20599 .32965 L
.20851 .32537 L
.21051 .32208 L
.2153 .31451 L
.21608 .31332 L
.22038 .30694 L
.22365 .30229 L
.22577 .29936 L
.23122 .29211 L
.23147 .29179 L
.23752 .28422 L
.23879 .28268 L
.24393 .27665 L
.24637 .27389 L
.25074 .26908 L
.25394 .26568 L
.25798 .26151 L
.26151 .25798 L
.26568 .25394 L
.26908 .25075 L
.2739 .24637 L
.27665 .24394 L
.28269 .23879 L
.28422 .23753 L
.29179 .23149 L
.29213 .23122 L
.29936 .22578 L
.30231 .22365 L
.30694 .2204 L
.31335 .21608 L
.31451 .21532 L
.32208 .21053 L
.32541 .20851 L
.32965 .20601 L
.33722 .20175 L
.33872 .20094 L
.34479 .19774 L
.35236 .19397 L
.35362 .19337 L
.35993 .19043 L
.3675 .18712 L
.37067 .1858 L
.37508 .18402 L
.38265 .18113 L
.39022 .17844 L
.39086 .17823 L
.39779 .17596 L
.40536 .17367 L
.41293 .17156 L
.41643 .17065 L
.4205 .16965 L
.42807 .16792 L
.43565 .16637 L
.44322 .165 L
.45079 .1638 L
.45595 .16308 L
F
0 .496 .091 r
.4735 .17005 m
.48107 .16952 L
.48864 .16918 L
.49621 .169 L
.50379 .169 L
.51136 .16918 L
.51893 .16952 L
.5265 .17004 L
.53324 .17065 L
.53407 .17074 L
.54164 .17161 L
.54921 .17266 L
.55678 .17389 L
.56435 .1753 L
.57193 .17689 L
.57767 .17823 L
.5795 .17867 L
.58707 .18064 L
.59464 .1828 L
.60221 .18516 L
.60415 .1858 L
.60978 .18772 L
.61735 .19049 L
.62468 .19337 L
.62492 .19347 L
.6325 .19666 L
.64007 .20008 L
.64188 .20094 L
.64764 .20374 L
.65521 .20763 L
.65685 .20851 L
.66278 .21178 L
.67017 .21608 L
.67035 .21619 L
.67792 .22087 L
.68221 .22365 L
.68549 .22585 L
.69306 .23112 L
.6932 .23122 L
.70064 .23672 L
.70332 .23879 L
.70821 .24267 L
.71269 .24637 L
.71578 .24898 L
.72141 .25394 L
.72335 .25569 L
.72955 .26151 L
.73092 .26284 L
.73716 .26908 L
.73849 .27045 L
.74431 .27665 L
.74606 .27858 L
.75102 .28422 L
.75363 .28729 L
.75734 .29179 L
.76121 .29666 L
.76329 .29936 L
.76878 .30677 L
.76889 .30694 L
.77417 .31451 L
.77635 .31776 L
.77915 .32208 L
.78383 .32965 L
.78392 .32979 L
.78824 .33722 L
.79149 .3431 L
.79239 .34479 L
.79629 .35236 L
.79906 .35806 L
.79995 .35993 L
.80337 .3675 L
.80657 .37508 L
.80663 .37524 L
.80954 .38265 L
.81231 .39022 L
.8142 .39575 L
.81487 .39779 L
.81723 .40536 L
.81939 .41293 L
.82136 .4205 L
.82177 .42218 L
.82314 .42807 L
.82474 .43565 L
.82615 .44322 L
.82738 .45079 L
.82843 .45836 L
.8293 .46593 L
.82935 .46637 L
.83 .4735 L
.83052 .48107 L
.83086 .48864 L
.83104 .49621 L
.83104 .50379 L
.83086 .51136 L
.83052 .51893 L
.83 .5265 L
.82935 .53363 L
.8293 .53407 L
.82843 .54164 L
.82738 .54921 L
.82615 .55678 L
.82474 .56435 L
.82314 .57193 L
.82177 .57782 L
.82136 .5795 L
.81939 .58707 L
.81723 .59464 L
.81487 .60221 L
.8142 .60425 L
.81231 .60978 L
.80954 .61735 L
.80663 .62476 L
.80657 .62492 L
.80337 .6325 L
.79995 .64007 L
.79906 .64194 L
.79629 .64764 L
.79239 .65521 L
.79149 .6569 L
.78824 .66278 L
.78392 .67021 L
.78383 .67035 L
.77915 .67792 L
.77635 .68224 L
.77417 .68549 L
.76889 .69306 L
.76878 .69323 L
.76329 .70064 L
.76121 .70334 L
.75734 .70821 L
.75363 .71271 L
.75102 .71578 L
.74606 .72142 L
.74431 .72335 L
.73849 .72955 L
.73716 .73092 L
.73092 .73716 L
.72955 .73849 L
.72335 .74431 L
.72141 .74606 L
.71578 .75102 L
.71269 .75363 L
.70821 .75733 L
.70332 .76121 L
.70064 .76328 L
.6932 .76878 L
.69306 .76888 L
.68549 .77415 L
.68221 .77635 L
.67792 .77913 L
.67035 .78381 L
.67017 .78392 L
.66278 .78822 L
.65685 .79149 L
.65521 .79237 L
.64764 .79626 L
.64188 .79906 L
.64007 .79992 L
.6325 .80334 L
.62492 .80653 L
.62468 .80663 L
.61735 .80951 L
.60978 .81228 L
.60415 .8142 L
.60221 .81484 L
.59464 .8172 L
.58707 .81936 L
.5795 .82133 L
.57767 .82177 L
.57193 .82311 L
.56435 .8247 L
.55678 .82611 L
.54921 .82734 L
.54164 .82839 L
.53407 .82926 L
.53324 .82935 L
.5265 .82996 L
.51893 .83048 L
.51136 .83082 L
.50379 .831 L
.49621 .831 L
.48864 .83082 L
.48107 .83048 L
.4735 .82995 L
.46676 .82935 L
.46593 .82926 L
.45836 .82839 L
.45079 .82734 L
.44322 .82611 L
.43565 .8247 L
.42807 .82311 L
.42233 .82177 L
.4205 .82133 L
.41293 .81936 L
.40536 .8172 L
.39779 .81484 L
.39585 .8142 L
.39022 .81228 L
.38265 .80951 L
.37532 .80663 L
.37508 .80653 L
.3675 .80334 L
.35993 .79992 L
.35812 .79906 L
.35236 .79626 L
.34479 .79237 L
.34315 .79149 L
.33722 .78822 L
.32983 .78392 L
.32965 .78381 L
.32208 .77913 L
.31779 .77635 L
.31451 .77415 L
.30694 .76888 L
.3068 .76878 L
.29936 .76327 L
.29668 .76121 L
.29179 .75733 L
.28731 .75363 L
.28422 .75102 L
.27859 .74606 L
.27665 .74431 L
.27045 .73849 L
.26908 .73716 L
.26284 .73092 L
.26151 .72955 L
.25569 .72335 L
.25394 .72142 L
.24898 .71578 L
.24637 .71271 L
.24266 .70821 L
.23879 .70334 L
.23671 .70064 L
.23122 .69323 L
.23111 .69306 L
.22583 .68549 L
.22365 .68224 L
.22085 .67792 L
.21617 .67035 L
.21608 .67021 L
.21176 .66278 L
.20851 .6569 L
.20761 .65521 L
.20371 .64764 L
.20094 .64194 L
.20005 .64007 L
.19663 .6325 L
.19343 .62492 L
.19337 .62476 L
.19046 .61735 L
.18769 .60978 L
.1858 .60425 L
.18513 .60221 L
.18277 .59464 L
.18061 .58707 L
.17864 .5795 L
.17823 .57782 L
.17686 .57193 L
.17526 .56435 L
.17385 .55678 L
.17262 .54921 L
.17157 .54164 L
.1707 .53407 L
.17065 .53363 L
.17 .5265 L
.16948 .51893 L
.16914 .51136 L
.16896 .50379 L
.16896 .49621 L
.16914 .48864 L
.16948 .48107 L
.17 .4735 L
.17065 .46637 L
.1707 .46593 L
.17157 .45836 L
.17262 .45079 L
.17385 .44322 L
.17526 .43565 L
.17686 .42807 L
.17823 .42218 L
.17864 .4205 L
.18061 .41293 L
.18277 .40536 L
.18513 .39779 L
.1858 .39575 L
.18769 .39022 L
.19046 .38265 L
.19337 .37524 L
.19343 .37508 L
.19663 .3675 L
.20005 .35993 L
.20094 .35806 L
.20371 .35236 L
.20761 .34479 L
.20851 .3431 L
.21176 .33722 L
.21608 .32979 L
.21617 .32965 L
.22085 .32208 L
.22365 .31776 L
.22583 .31451 L
.23111 .30694 L
.23122 .30677 L
.23671 .29936 L
.23879 .29666 L
.24266 .29179 L
.24637 .28729 L
.24898 .28422 L
.25394 .27858 L
.25569 .27665 L
.26151 .27045 L
.26284 .26908 L
.26908 .26284 L
.27045 .26151 L
.27665 .25569 L
.27859 .25394 L
.28422 .24898 L
.28731 .24637 L
.29179 .24267 L
.29668 .23879 L
.29936 .23673 L
.3068 .23122 L
.30694 .23112 L
.31451 .22585 L
.31779 .22365 L
.32208 .22087 L
.32965 .21619 L
.32983 .21608 L
.33722 .21178 L
.34315 .20851 L
.34479 .20763 L
.35236 .20374 L
.35812 .20094 L
.35993 .20008 L
.3675 .19666 L
.37508 .19347 L
.37532 .19337 L
.38265 .19049 L
.39022 .18772 L
.39585 .1858 L
.39779 .18516 L
.40536 .1828 L
.41293 .18064 L
.4205 .17867 L
.42233 .17823 L
.42807 .17689 L
.43565 .1753 L
.44322 .17389 L
.45079 .17266 L
.45836 .17161 L
.46593 .17074 L
.46676 .17065 L
F
0 .478 .125 r
.48864 .17803 m
.49621 .17785 L
.50379 .17785 L
.51136 .17803 L
.5164 .17823 L
.51893 .17839 L
.5265 .17892 L
.53407 .17964 L
.54164 .18053 L
.54921 .18161 L
.55678 .18288 L
.56435 .18432 L
.57119 .1858 L
.57193 .18596 L
.5795 .1878 L
.58707 .18982 L
.59464 .19205 L
.59883 .19337 L
.60221 .19448 L
.60978 .19712 L
.61735 .19997 L
.6198 .20094 L
.62492 .20304 L
.6325 .20634 L
.6372 .20851 L
.64007 .20988 L
.64764 .21366 L
.65225 .21608 L
.65521 .21769 L
.66278 .22199 L
.66559 .22365 L
.67035 .22656 L
.67762 .23122 L
.67792 .23142 L
.68549 .2366 L
.68858 .23879 L
.69306 .24209 L
.69864 .24637 L
.70064 .24794 L
.70795 .25394 L
.70821 .25416 L
.71578 .26077 L
.71659 .26151 L
.72335 .26782 L
.72465 .26908 L
.73092 .27535 L
.73218 .27665 L
.73849 .2834 L
.73923 .28422 L
.74585 .29179 L
.74606 .29204 L
.75207 .29936 L
.75363 .30134 L
.75792 .30694 L
.76121 .3114 L
.76342 .31451 L
.76859 .32208 L
.76878 .32236 L
.77346 .32965 L
.77635 .33437 L
.77803 .33722 L
.78233 .34479 L
.78392 .34771 L
.78637 .35236 L
.79015 .35993 L
.79149 .36275 L
.79368 .3675 L
.79699 .37508 L
.79906 .38013 L
.80006 .38265 L
.80291 .39022 L
.80555 .39779 L
.80663 .40107 L
.80798 .40536 L
.81021 .41293 L
.81224 .4205 L
.81407 .42807 L
.8142 .42866 L
.81571 .43565 L
.81716 .44322 L
.81842 .45079 L
.8195 .45836 L
.8204 .46593 L
.82111 .4735 L
.82165 .48107 L
.82177 .48292 L
.82201 .48864 L
.82218 .49621 L
.82218 .50379 L
.82201 .51136 L
.82177 .51708 L
.82165 .51893 L
.82111 .5265 L
.8204 .53407 L
.8195 .54164 L
.81842 .54921 L
.81716 .55678 L
.81571 .56435 L
.8142 .57134 L
.81407 .57193 L
.81224 .5795 L
.81021 .58707 L
.80798 .59464 L
.80663 .59893 L
.80555 .60221 L
.80291 .60978 L
.80006 .61735 L
.79906 .61987 L
.79699 .62492 L
.79368 .6325 L
.79149 .63725 L
.79015 .64007 L
.78637 .64764 L
.78392 .65229 L
.78233 .65521 L
.77803 .66278 L
.77635 .66563 L
.77346 .67035 L
.76878 .67764 L
.76859 .67792 L
.76342 .68549 L
.76121 .6886 L
.75792 .69306 L
.75363 .69866 L
.75207 .70064 L
.74606 .70796 L
.74585 .70821 L
.73923 .71578 L
.73849 .7166 L
.73218 .72335 L
.73092 .72465 L
.72465 .73092 L
.72335 .73218 L
.71659 .73849 L
.71578 .73923 L
.70821 .74584 L
.70795 .74606 L
.70064 .75206 L
.69864 .75363 L
.69306 .75791 L
.68858 .76121 L
.68549 .7634 L
.67792 .76858 L
.67762 .76878 L
.67035 .77344 L
.66559 .77635 L
.66278 .77801 L
.65521 .78231 L
.65225 .78392 L
.64764 .78634 L
.64007 .79012 L
.6372 .79149 L
.6325 .79366 L
.62492 .79696 L
.6198 .79906 L
.61735 .80003 L
.60978 .80288 L
.60221 .80552 L
.59883 .80663 L
.59464 .80795 L
.58707 .81018 L
.5795 .8122 L
.57193 .81404 L
.57119 .8142 L
.56435 .81568 L
.55678 .81712 L
.54921 .81839 L
.54164 .81947 L
.53407 .82036 L
.5265 .82108 L
.51893 .82161 L
.5164 .82177 L
.51136 .82197 L
.50379 .82215 L
.49621 .82215 L
.48864 .82197 L
.4836 .82177 L
.48107 .82161 L
.4735 .82108 L
.46593 .82036 L
.45836 .81947 L
.45079 .81839 L
.44322 .81712 L
.43565 .81567 L
.42881 .8142 L
.42807 .81404 L
.4205 .8122 L
.41293 .81018 L
.40536 .80795 L
.40117 .80663 L
.39779 .80552 L
.39022 .80288 L
.38265 .80003 L
.3802 .79906 L
.37508 .79696 L
.3675 .79366 L
.3628 .79149 L
.35993 .79012 L
.35236 .78634 L
.34775 .78392 L
.34479 .78231 L
.33722 .77801 L
.33441 .77635 L
.32965 .77344 L
.32238 .76878 L
.32208 .76857 L
.31451 .7634 L
.31142 .76121 L
.30694 .75791 L
.30136 .75363 L
.29936 .75206 L
.29205 .74606 L
.29179 .74584 L
.28422 .73923 L
.28341 .73849 L
.27665 .73218 L
.27535 .73092 L
.26908 .72465 L
.26782 .72335 L
.26151 .7166 L
.26077 .71578 L
.25415 .70821 L
.25394 .70796 L
.24793 .70064 L
.24637 .69866 L
.24208 .69306 L
.23879 .6886 L
.23658 .68549 L
.23141 .67792 L
.23122 .67764 L
.22654 .67035 L
.22365 .66563 L
.22197 .66278 L
.21767 .65521 L
.21608 .65229 L
.21363 .64764 L
.20985 .64007 L
.20851 .63725 L
.20632 .6325 L
.20301 .62492 L
.20094 .61987 L
.19994 .61735 L
.19709 .60978 L
.19445 .60221 L
.19337 .59893 L
.19202 .59464 L
.18979 .58707 L
.18776 .5795 L
.18593 .57193 L
.1858 .57134 L
.18429 .56435 L
.18284 .55678 L
.18158 .54921 L
.1805 .54164 L
.1796 .53407 L
.17889 .5265 L
.17835 .51893 L
.17823 .51707 L
.17799 .51136 L
.17782 .50379 L
.17782 .49621 L
.17799 .48864 L
.17823 .48293 L
.17835 .48107 L
.17889 .4735 L
.1796 .46593 L
.1805 .45836 L
.18158 .45079 L
.18284 .44322 L
.18429 .43565 L
.1858 .42866 L
.18593 .42807 L
.18776 .4205 L
.18979 .41293 L
.19202 .40536 L
.19337 .40107 L
.19445 .39779 L
.19709 .39022 L
.19994 .38265 L
.20094 .38013 L
.20301 .37508 L
.20632 .3675 L
.20851 .36275 L
.20985 .35993 L
.21363 .35236 L
.21608 .34771 L
.21767 .34479 L
.22197 .33722 L
.22365 .33437 L
.22654 .32965 L
.23122 .32236 L
.23141 .32208 L
.23658 .31451 L
.23879 .3114 L
.24208 .30694 L
.24637 .30134 L
.24793 .29936 L
.25394 .29204 L
.25415 .29179 L
.26077 .28422 L
.26151 .2834 L
.26782 .27665 L
.26908 .27535 L
.27535 .26908 L
.27665 .26782 L
.28341 .26151 L
.28422 .26077 L
.29179 .25416 L
.29205 .25394 L
.29936 .24794 L
.30136 .24637 L
.30694 .24209 L
.31142 .23879 L
.31451 .2366 L
.32208 .23143 L
.32238 .23122 L
.32965 .22656 L
.33441 .22365 L
.33722 .22199 L
.34479 .21769 L
.34775 .21608 L
.35236 .21366 L
.35993 .20988 L
.3628 .20851 L
.3675 .20634 L
.37508 .20304 L
.3802 .20094 L
.38265 .19997 L
.39022 .19712 L
.39779 .19448 L
.40117 .19337 L
.40536 .19205 L
.41293 .18982 L
.4205 .1878 L
.42807 .18596 L
.42881 .1858 L
.43565 .18433 L
.44322 .18288 L
.45079 .18161 L
.45836 .18053 L
.46593 .17964 L
.4735 .17892 L
.48107 .17839 L
.4836 .17823 L
F
0 .46 .156 r
.44322 .19197 m
.45079 .19067 L
.45836 .18956 L
.46593 .18863 L
.4735 .1879 L
.48107 .18735 L
.48864 .18698 L
.49621 .1868 L
.50379 .1868 L
.51136 .18698 L
.51893 .18735 L
.5265 .1879 L
.53407 .18863 L
.54164 .18956 L
.54921 .19067 L
.55678 .19197 L
.56392 .19337 L
.56435 .19346 L
.57193 .19515 L
.5795 .19703 L
.58707 .19912 L
.59312 .20094 L
.59464 .20142 L
.60221 .20392 L
.60978 .20665 L
.61463 .20851 L
.61735 .20959 L
.62492 .21277 L
.63227 .21608 L
.6325 .21618 L
.64007 .21984 L
.64744 .22365 L
.64764 .22376 L
.65521 .22794 L
.66083 .23122 L
.66278 .2324 L
.67035 .23716 L
.67285 .23879 L
.67792 .24222 L
.68378 .24637 L
.68549 .24762 L
.69306 .25336 L
.6938 .25394 L
.70064 .25948 L
.70305 .26151 L
.70821 .266 L
.71162 .26908 L
.71578 .27296 L
.7196 .27665 L
.72335 .2804 L
.72704 .28422 L
.73092 .28838 L
.73401 .29179 L
.73849 .29694 L
.74053 .29936 L
.74606 .30619 L
.74665 .30694 L
.7524 .31451 L
.75363 .3162 L
.75779 .32208 L
.76121 .32713 L
.76286 .32965 L
.76762 .33722 L
.76878 .33914 L
.77208 .34479 L
.77626 .35236 L
.77635 .35252 L
.78018 .35993 L
.78384 .3675 L
.78392 .36768 L
.78725 .37508 L
.79043 .38265 L
.79149 .3853 L
.79338 .39022 L
.7961 .39779 L
.79861 .40536 L
.79906 .40679 L
.80091 .41293 L
.803 .4205 L
.80488 .42807 L
.80657 .43565 L
.80663 .43593 L
.80807 .44322 L
.80937 .45079 L
.81048 .45836 L
.8114 .46593 L
.81213 .4735 L
.81269 .48107 L
.81305 .48864 L
.81324 .49621 L
.81324 .50379 L
.81305 .51136 L
.81269 .51893 L
.81213 .5265 L
.8114 .53407 L
.81048 .54164 L
.80937 .54921 L
.80807 .55678 L
.80663 .56407 L
.80657 .56435 L
.80488 .57193 L
.803 .5795 L
.80091 .58707 L
.79906 .59321 L
.79861 .59464 L
.7961 .60221 L
.79338 .60978 L
.79149 .6147 L
.79043 .61735 L
.78725 .62492 L
.78392 .63232 L
.78384 .6325 L
.78018 .64007 L
.77635 .64748 L
.77626 .64764 L
.77208 .65521 L
.76878 .66086 L
.76762 .66278 L
.76286 .67035 L
.76121 .67287 L
.75779 .67792 L
.75363 .6838 L
.7524 .68549 L
.74665 .69306 L
.74606 .69381 L
.74053 .70064 L
.73849 .70306 L
.73401 .70821 L
.73092 .71162 L
.72704 .71578 L
.72335 .7196 L
.7196 .72335 L
.71578 .72704 L
.71162 .73092 L
.70821 .734 L
.70305 .73849 L
.70064 .74052 L
.6938 .74606 L
.69306 .74664 L
.68549 .75238 L
.68378 .75363 L
.67792 .75778 L
.67285 .76121 L
.67035 .76284 L
.66278 .7676 L
.66083 .76878 L
.65521 .77206 L
.64764 .77624 L
.64744 .77635 L
.64007 .78016 L
.6325 .78382 L
.63227 .78392 L
.62492 .78723 L
.61735 .79041 L
.61463 .79149 L
.60978 .79335 L
.60221 .79608 L
.59464 .79858 L
.59312 .79906 L
.58707 .80088 L
.5795 .80297 L
.57193 .80485 L
.56435 .80654 L
.56392 .80663 L
.55678 .80803 L
.54921 .80933 L
.54164 .81044 L
.53407 .81137 L
.5265 .8121 L
.51893 .81265 L
.51136 .81302 L
.50379 .8132 L
.49621 .8132 L
.48864 .81302 L
.48107 .81265 L
.4735 .8121 L
.46593 .81137 L
.45836 .81044 L
.45079 .80933 L
.44322 .80803 L
.43608 .80663 L
.43565 .80654 L
.42807 .80485 L
.4205 .80297 L
.41293 .80088 L
.40688 .79906 L
.40536 .79858 L
.39779 .79608 L
.39022 .79335 L
.38537 .79149 L
.38265 .79041 L
.37508 .78723 L
.36773 .78392 L
.3675 .78382 L
.35993 .78016 L
.35256 .77635 L
.35236 .77624 L
.34479 .77206 L
.33917 .76878 L
.33722 .7676 L
.32965 .76284 L
.32715 .76121 L
.32208 .75778 L
.31622 .75363 L
.31451 .75238 L
.30694 .74664 L
.3062 .74606 L
.29936 .74052 L
.29695 .73849 L
.29179 .734 L
.28838 .73092 L
.28422 .72704 L
.2804 .72335 L
.27665 .7196 L
.27296 .71578 L
.26908 .71162 L
.26599 .70821 L
.26151 .70306 L
.25947 .70064 L
.25394 .69381 L
.25335 .69306 L
.2476 .68549 L
.24637 .6838 L
.24221 .67792 L
.23879 .67287 L
.23714 .67035 L
.23238 .66278 L
.23122 .66086 L
.22792 .65521 L
.22374 .64764 L
.22365 .64748 L
.21982 .64007 L
.21616 .6325 L
.21608 .63232 L
.21275 .62492 L
.20957 .61735 L
.20851 .6147 L
.20662 .60978 L
.2039 .60221 L
.20139 .59464 L
.20094 .59321 L
.19909 .58707 L
.197 .5795 L
.19512 .57193 L
.19343 .56435 L
.19337 .56407 L
.19194 .55678 L
.19063 .54921 L
.18952 .54164 L
.1886 .53407 L
.18787 .5265 L
.18731 .51893 L
.18695 .51136 L
.18676 .50379 L
.18676 .49621 L
.18695 .48864 L
.18731 .48107 L
.18787 .4735 L
.1886 .46593 L
.18952 .45836 L
.19063 .45079 L
.19194 .44322 L
.19337 .43593 L
.19343 .43565 L
.19512 .42807 L
.197 .4205 L
.19909 .41293 L
.20094 .40679 L
.20139 .40536 L
.2039 .39779 L
.20662 .39022 L
.20851 .3853 L
.20957 .38265 L
.21275 .37508 L
.21608 .36768 L
.21616 .3675 L
.21982 .35993 L
.22365 .35252 L
.22374 .35236 L
.22792 .34479 L
.23122 .33914 L
.23238 .33722 L
.23714 .32965 L
.23879 .32713 L
.24221 .32208 L
.24637 .3162 L
.2476 .31451 L
.25335 .30694 L
.25394 .30619 L
.25947 .29936 L
.26151 .29694 L
.26599 .29179 L
.26908 .28838 L
.27296 .28422 L
.27665 .2804 L
.2804 .27665 L
.28422 .27296 L
.28838 .26908 L
.29179 .266 L
.29695 .26151 L
.29936 .25948 L
.3062 .25394 L
.30694 .25336 L
.31451 .24762 L
.31622 .24637 L
.32208 .24222 L
.32715 .23879 L
.32965 .23716 L
.33722 .2324 L
.33917 .23122 L
.34479 .22794 L
.35236 .22376 L
.35256 .22365 L
.35993 .21984 L
.3675 .21618 L
.36773 .21608 L
.37508 .21277 L
.38265 .20959 L
.38537 .20851 L
.39022 .20665 L
.39779 .20392 L
.40536 .20142 L
.40688 .20094 L
.41293 .19912 L
.4205 .19703 L
.42807 .19515 L
.43565 .19346 L
.43608 .19337 L
F
0 .442 .185 r
.45079 .19984 m
.45836 .1987 L
.46593 .19775 L
.4735 .19699 L
.48107 .19642 L
.48864 .19604 L
.49621 .19586 L
.50379 .19586 L
.51136 .19604 L
.51893 .19642 L
.5265 .19699 L
.53407 .19775 L
.54164 .1987 L
.54921 .19984 L
.5555 .20094 L
.55678 .20118 L
.56435 .20272 L
.57193 .20446 L
.5795 .20641 L
.58689 .20851 L
.58707 .20856 L
.59464 .21093 L
.60221 .21352 L
.60911 .21608 L
.60978 .21634 L
.61735 .21939 L
.62492 .22268 L
.62707 .22365 L
.6325 .22621 L
.64007 .23001 L
.64238 .23122 L
.64764 .23407 L
.65521 .23842 L
.65584 .23879 L
.66278 .24306 L
.66788 .24637 L
.67035 .24802 L
.67792 .25331 L
.67879 .25394 L
.68549 .25895 L
.68877 .26151 L
.69306 .26497 L
.69796 .26908 L
.70064 .2714 L
.70647 .27665 L
.70821 .27827 L
.71437 .28422 L
.71578 .28563 L
.72173 .29179 L
.72335 .29353 L
.72861 .29936 L
.73092 .30203 L
.73504 .30694 L
.73849 .31121 L
.74106 .31451 L
.74606 .32119 L
.7467 .32208 L
.75199 .32965 L
.75363 .3321 L
.75695 .33722 L
.76121 .34413 L
.7616 .34479 L
.76594 .35236 L
.76878 .35758 L
.77001 .35993 L
.77381 .3675 L
.77635 .37289 L
.77735 .37508 L
.78063 .38265 L
.78368 .39022 L
.78392 .39083 L
.7865 .39779 L
.78909 .40536 L
.79146 .41293 L
.79149 .41303 L
.79362 .4205 L
.79557 .42807 L
.79731 .43565 L
.79885 .44322 L
.79906 .44435 L
.80019 .45079 L
.80133 .45836 L
.80228 .46593 L
.80304 .4735 L
.80361 .48107 L
.80398 .48864 L
.80417 .49621 L
.80417 .50379 L
.80398 .51136 L
.80361 .51893 L
.80304 .5265 L
.80228 .53407 L
.80133 .54164 L
.80019 .54921 L
.79906 .55565 L
.79885 .55678 L
.79731 .56435 L
.79557 .57193 L
.79362 .5795 L
.79149 .58697 L
.79146 .58707 L
.78909 .59464 L
.7865 .60221 L
.78392 .60917 L
.78368 .60978 L
.78063 .61735 L
.77735 .62492 L
.77635 .62711 L
.77381 .6325 L
.77001 .64007 L
.76878 .64242 L
.76594 .64764 L
.7616 .65521 L
.76121 .65587 L
.75695 .66278 L
.75363 .6679 L
.75199 .67035 L
.7467 .67792 L
.74606 .67881 L
.74106 .68549 L
.73849 .68879 L
.73504 .69306 L
.73092 .69797 L
.72861 .70064 L
.72335 .70647 L
.72173 .70821 L
.71578 .71437 L
.71437 .71578 L
.70821 .72173 L
.70647 .72335 L
.70064 .7286 L
.69796 .73092 L
.69306 .73503 L
.68877 .73849 L
.68549 .74105 L
.67879 .74606 L
.67792 .74669 L
.67035 .75198 L
.66788 .75363 L
.66278 .75694 L
.65584 .76121 L
.65521 .76158 L
.64764 .76593 L
.64238 .76878 L
.64007 .76999 L
.6325 .77379 L
.62707 .77635 L
.62492 .77732 L
.61735 .78061 L
.60978 .78366 L
.60911 .78392 L
.60221 .78648 L
.59464 .78907 L
.58707 .79144 L
.58689 .79149 L
.5795 .79359 L
.57193 .79554 L
.56435 .79728 L
.55678 .79882 L
.5555 .79906 L
.54921 .80016 L
.54164 .8013 L
.53407 .80225 L
.5265 .80301 L
.51893 .80358 L
.51136 .80396 L
.50379 .80414 L
.49621 .80414 L
.48864 .80396 L
.48107 .80358 L
.4735 .80301 L
.46593 .80225 L
.45836 .8013 L
.45079 .80016 L
.4445 .79906 L
.44322 .79882 L
.43565 .79728 L
.42807 .79554 L
.4205 .79359 L
.41311 .79149 L
.41293 .79144 L
.40536 .78907 L
.39779 .78648 L
.39089 .78392 L
.39022 .78366 L
.38265 .78061 L
.37508 .77732 L
.37293 .77635 L
.3675 .77379 L
.35993 .76999 L
.35762 .76878 L
.35236 .76593 L
.34479 .76158 L
.34416 .76121 L
.33722 .75694 L
.33212 .75363 L
.32965 .75198 L
.32208 .74669 L
.32121 .74606 L
.31451 .74105 L
.31123 .73849 L
.30694 .73503 L
.30204 .73092 L
.29936 .7286 L
.29353 .72335 L
.29179 .72173 L
.28563 .71578 L
.28422 .71437 L
.27827 .70821 L
.27665 .70647 L
.27139 .70064 L
.26908 .69797 L
.26496 .69306 L
.26151 .68878 L
.25894 .68549 L
.25394 .67881 L
.2533 .67792 L
.24801 .67035 L
.24637 .6679 L
.24305 .66278 L
.23879 .65587 L
.2384 .65521 L
.23406 .64764 L
.23122 .64242 L
.22999 .64007 L
.22619 .6325 L
.22365 .62711 L
.22266 .62492 L
.21937 .61735 L
.21632 .60978 L
.21608 .60917 L
.2135 .60221 L
.21091 .59464 L
.20854 .58707 L
.20851 .58697 L
.20638 .5795 L
.20443 .57193 L
.20269 .56435 L
.20115 .55678 L
.20094 .55564 L
.19981 .54921 L
.19867 .54164 L
.19772 .53407 L
.19696 .5265 L
.19639 .51893 L
.19602 .51136 L
.19583 .50379 L
.19583 .49621 L
.19602 .48864 L
.19639 .48107 L
.19696 .4735 L
.19772 .46593 L
.19867 .45836 L
.19981 .45079 L
.20094 .44436 L
.20115 .44322 L
.20269 .43565 L
.20443 .42807 L
.20638 .4205 L
.20851 .41303 L
.20854 .41293 L
.21091 .40536 L
.2135 .39779 L
.21608 .39083 L
.21632 .39022 L
.21937 .38265 L
.22266 .37508 L
.22365 .37289 L
.22619 .3675 L
.22999 .35993 L
.23122 .35758 L
.23406 .35236 L
.2384 .34479 L
.23879 .34413 L
.24305 .33722 L
.24637 .3321 L
.24801 .32965 L
.2533 .32208 L
.25394 .32119 L
.25894 .31451 L
.26151 .31122 L
.26496 .30694 L
.26908 .30203 L
.27139 .29936 L
.27665 .29353 L
.27827 .29179 L
.28422 .28563 L
.28563 .28422 L
.29179 .27827 L
.29353 .27665 L
.29936 .2714 L
.30204 .26908 L
.30694 .26497 L
.31123 .26151 L
.31451 .25895 L
.32121 .25394 L
.32208 .25331 L
.32965 .24802 L
.33212 .24637 L
.33722 .24306 L
.34416 .23879 L
.34479 .23842 L
.35236 .23407 L
.35762 .23122 L
.35993 .23001 L
.3675 .22621 L
.37293 .22365 L
.37508 .22268 L
.38265 .21939 L
.39022 .21634 L
.39089 .21608 L
.39779 .21352 L
.40536 .21093 L
.41293 .20856 L
.41311 .20851 L
.4205 .20641 L
.42807 .20446 L
.43565 .20272 L
.44322 .20118 L
.4445 .20094 L
F
0 .424 .21 r
.45836 .20798 m
.46593 .207 L
.4735 .20622 L
.48107 .20563 L
.48864 .20524 L
.49621 .20505 L
.50379 .20505 L
.51136 .20524 L
.51893 .20563 L
.5265 .20622 L
.53407 .207 L
.54164 .20798 L
.54523 .20851 L
.54921 .20916 L
.55678 .21054 L
.56435 .21213 L
.57193 .21393 L
.5795 .21594 L
.58 .21608 L
.58707 .21817 L
.59464 .22062 L
.60221 .2233 L
.60316 .22365 L
.60978 .22622 L
.61735 .22938 L
.62152 .23122 L
.62492 .23279 L
.6325 .23646 L
.63704 .23879 L
.64007 .2404 L
.64764 .24463 L
.65059 .24637 L
.65521 .24916 L
.66267 .25394 L
.66278 .25401 L
.67035 .25919 L
.67358 .26151 L
.67792 .26473 L
.68353 .26908 L
.68549 .27065 L
.69267 .27665 L
.69306 .27699 L
.70064 .28377 L
.70112 .28422 L
.70821 .29105 L
.70895 .29179 L
.71578 .29888 L
.71623 .29936 L
.72302 .30694 L
.72335 .30732 L
.72935 .31451 L
.73092 .31646 L
.73528 .32208 L
.73849 .32641 L
.74082 .32965 L
.746 .33722 L
.74606 .33731 L
.75085 .34479 L
.75363 .34938 L
.75538 .35236 L
.75961 .35993 L
.76121 .36293 L
.76356 .3675 L
.76723 .37508 L
.76878 .37843 L
.77064 .38265 L
.7738 .39022 L
.77635 .39679 L
.77672 .39779 L
.7794 .40536 L
.78185 .41293 L
.78392 .41992 L
.78408 .4205 L
.7861 .42807 L
.78789 .43565 L
.78948 .44322 L
.79087 .45079 L
.79149 .45461 L
.79205 .45836 L
.79303 .46593 L
.79381 .4735 L
.7944 .48107 L
.79479 .48864 L
.79498 .49621 L
.79498 .50379 L
.79479 .51136 L
.7944 .51893 L
.79381 .5265 L
.79303 .53407 L
.79205 .54164 L
.79149 .54539 L
.79087 .54921 L
.78948 .55678 L
.78789 .56435 L
.7861 .57193 L
.78408 .5795 L
.78392 .58008 L
.78185 .58707 L
.7794 .59464 L
.77672 .60221 L
.77635 .60321 L
.7738 .60978 L
.77064 .61735 L
.76878 .62157 L
.76723 .62492 L
.76356 .6325 L
.76121 .63707 L
.75961 .64007 L
.75538 .64764 L
.75363 .65062 L
.75085 .65521 L
.74606 .66269 L
.746 .66278 L
.74082 .67035 L
.73849 .67359 L
.73528 .67792 L
.73092 .68354 L
.72935 .68549 L
.72335 .69268 L
.72302 .69306 L
.71623 .70064 L
.71578 .70112 L
.70895 .70821 L
.70821 .70895 L
.70112 .71578 L
.70064 .71623 L
.69306 .72301 L
.69267 .72335 L
.68549 .72935 L
.68353 .73092 L
.67792 .73527 L
.67358 .73849 L
.67035 .74081 L
.66278 .74599 L
.66267 .74606 L
.65521 .75084 L
.65059 .75363 L
.64764 .75537 L
.64007 .7596 L
.63704 .76121 L
.6325 .76354 L
.62492 .76721 L
.62152 .76878 L
.61735 .77062 L
.60978 .77378 L
.60316 .77635 L
.60221 .7767 L
.59464 .77938 L
.58707 .78183 L
.58 .78392 L
.5795 .78406 L
.57193 .78607 L
.56435 .78787 L
.55678 .78946 L
.54921 .79084 L
.54523 .79149 L
.54164 .79202 L
.53407 .793 L
.5265 .79378 L
.51893 .79437 L
.51136 .79476 L
.50379 .79495 L
.49621 .79495 L
.48864 .79476 L
.48107 .79437 L
.4735 .79378 L
.46593 .793 L
.45836 .79202 L
.45477 .79149 L
.45079 .79084 L
.44322 .78946 L
.43565 .78787 L
.42807 .78607 L
.4205 .78406 L
.42 .78392 L
.41293 .78183 L
.40536 .77938 L
.39779 .7767 L
.39684 .77635 L
.39022 .77378 L
.38265 .77062 L
.37848 .76878 L
.37508 .76721 L
.3675 .76354 L
.36296 .76121 L
.35993 .7596 L
.35236 .75536 L
.34941 .75363 L
.34479 .75084 L
.33733 .74606 L
.33722 .74599 L
.32965 .74081 L
.32642 .73849 L
.32208 .73527 L
.31647 .73092 L
.31451 .72935 L
.30733 .72335 L
.30694 .72301 L
.29936 .71623 L
.29888 .71578 L
.29179 .70895 L
.29105 .70821 L
.28422 .70112 L
.28377 .70064 L
.27698 .69306 L
.27665 .69268 L
.27065 .68549 L
.26908 .68354 L
.26472 .67792 L
.26151 .67359 L
.25918 .67035 L
.254 .66278 L
.25394 .66269 L
.24915 .65521 L
.24637 .65062 L
.24462 .64764 L
.24039 .64007 L
.23879 .63707 L
.23644 .6325 L
.23277 .62492 L
.23122 .62157 L
.22936 .61735 L
.2262 .60978 L
.22365 .60321 L
.22328 .60221 L
.2206 .59464 L
.21815 .58707 L
.21608 .58008 L
.21592 .5795 L
.2139 .57193 L
.21211 .56435 L
.21052 .55678 L
.20913 .54921 L
.20851 .54539 L
.20795 .54164 L
.20697 .53407 L
.20619 .5265 L
.2056 .51893 L
.20522 .51136 L
.20502 .50379 L
.20502 .49621 L
.20522 .48864 L
.2056 .48107 L
.20619 .4735 L
.20697 .46593 L
.20795 .45836 L
.20851 .45461 L
.20913 .45079 L
.21052 .44322 L
.21211 .43565 L
.2139 .42807 L
.21592 .4205 L
.21608 .41992 L
.21815 .41293 L
.2206 .40536 L
.22328 .39779 L
.22365 .39679 L
.2262 .39022 L
.22936 .38265 L
.23122 .37843 L
.23277 .37508 L
.23644 .3675 L
.23879 .36293 L
.24039 .35993 L
.24462 .35236 L
.24637 .34938 L
.24915 .34479 L
.25394 .33731 L
.254 .33722 L
.25918 .32965 L
.26151 .32641 L
.26472 .32208 L
.26908 .31646 L
.27065 .31451 L
.27665 .30732 L
.27698 .30694 L
.28377 .29936 L
.28422 .29888 L
.29105 .29179 L
.29179 .29105 L
.29888 .28422 L
.29936 .28377 L
.30694 .27699 L
.30733 .27665 L
.31451 .27065 L
.31647 .26908 L
.32208 .26473 L
.32642 .26151 L
.32965 .25919 L
.33722 .25401 L
.33733 .25394 L
.34479 .24916 L
.34941 .24637 L
.35236 .24464 L
.35993 .2404 L
.36296 .23879 L
.3675 .23646 L
.37508 .23279 L
.37848 .23122 L
.38265 .22938 L
.39022 .22622 L
.39684 .22365 L
.39779 .2233 L
.40536 .22062 L
.41293 .21817 L
.42 .21608 L
.4205 .21594 L
.42807 .21393 L
.43565 .21213 L
.44322 .21054 L
.45079 .20916 L
.45477 .20851 L
F
0 .406 .233 r
.4735 .2156 m
.48107 .21499 L
.48864 .21459 L
.49621 .21439 L
.50379 .21439 L
.51136 .21459 L
.51893 .21499 L
.5265 .2156 L
.53132 .21608 L
.53407 .2164 L
.54164 .21742 L
.54921 .21864 L
.55678 .22007 L
.56435 .22171 L
.57193 .22357 L
.57224 .22365 L
.5795 .22565 L
.58707 .22796 L
.59464 .2305 L
.59667 .23122 L
.60221 .23328 L
.60978 .23631 L
.61557 .23879 L
.61735 .23959 L
.62492 .24314 L
.63136 .24637 L
.6325 .24696 L
.64007 .25107 L
.64504 .25394 L
.64764 .25548 L
.65521 .26022 L
.65718 .26151 L
.66278 .26529 L
.66811 .26908 L
.67035 .27073 L
.67792 .27655 L
.67804 .27665 L
.68549 .2828 L
.68715 .28422 L
.69306 .2895 L
.69554 .29179 L
.70064 .2967 L
.7033 .29936 L
.70821 .30446 L
.71051 .30694 L
.71578 .31285 L
.71721 .31451 L
.72335 .32195 L
.72345 .32208 L
.72928 .32965 L
.73092 .33188 L
.73472 .33722 L
.73849 .3428 L
.73979 .34479 L
.74453 .35236 L
.74606 .35493 L
.74894 .35993 L
.75306 .3675 L
.75363 .36861 L
.75688 .37508 L
.76043 .38265 L
.76121 .38439 L
.76371 .39022 L
.76674 .39779 L
.76878 .40328 L
.76952 .40536 L
.77206 .41293 L
.77437 .4205 L
.77635 .42768 L
.77645 .42807 L
.77831 .43565 L
.77996 .44322 L
.78139 .45079 L
.78261 .45836 L
.78362 .46593 L
.78392 .46848 L
.78443 .4735 L
.78503 .48107 L
.78543 .48864 L
.78563 .49621 L
.78563 .50379 L
.78543 .51136 L
.78503 .51893 L
.78443 .5265 L
.78392 .53152 L
.78362 .53407 L
.78261 .54164 L
.78139 .54921 L
.77996 .55678 L
.77831 .56435 L
.77645 .57193 L
.77635 .57232 L
.77437 .5795 L
.77206 .58707 L
.76952 .59464 L
.76878 .59672 L
.76674 .60221 L
.76371 .60978 L
.76121 .61561 L
.76043 .61735 L
.75688 .62492 L
.75363 .63139 L
.75306 .6325 L
.74894 .64007 L
.74606 .64507 L
.74453 .64764 L
.73979 .65521 L
.73849 .6572 L
.73472 .66278 L
.73092 .66812 L
.72928 .67035 L
.72345 .67792 L
.72335 .67805 L
.71721 .68549 L
.71578 .68715 L
.71051 .69306 L
.70821 .69554 L
.7033 .70064 L
.70064 .7033 L
.69554 .70821 L
.69306 .7105 L
.68715 .71578 L
.68549 .7172 L
.67804 .72335 L
.67792 .72345 L
.67035 .72927 L
.66811 .73092 L
.66278 .73471 L
.65718 .73849 L
.65521 .73978 L
.64764 .74452 L
.64504 .74606 L
.64007 .74893 L
.6325 .75304 L
.63136 .75363 L
.62492 .75686 L
.61735 .76041 L
.61557 .76121 L
.60978 .76369 L
.60221 .76672 L
.59667 .76878 L
.59464 .7695 L
.58707 .77204 L
.5795 .77435 L
.57224 .77635 L
.57193 .77643 L
.56435 .77829 L
.55678 .77993 L
.54921 .78136 L
.54164 .78258 L
.53407 .7836 L
.53132 .78392 L
.5265 .7844 L
.51893 .78501 L
.51136 .78541 L
.50379 .78561 L
.49621 .78561 L
.48864 .78541 L
.48107 .78501 L
.4735 .7844 L
.46868 .78392 L
.46593 .7836 L
.45836 .78258 L
.45079 .78136 L
.44322 .77993 L
.43565 .77829 L
.42807 .77643 L
.42776 .77635 L
.4205 .77435 L
.41293 .77204 L
.40536 .7695 L
.40333 .76878 L
.39779 .76672 L
.39022 .76369 L
.38443 .76121 L
.38265 .76041 L
.37508 .75686 L
.36864 .75363 L
.3675 .75304 L
.35993 .74893 L
.35496 .74606 L
.35236 .74452 L
.34479 .73978 L
.34282 .73849 L
.33722 .73471 L
.33189 .73092 L
.32965 .72927 L
.32208 .72345 L
.32196 .72335 L
.31451 .7172 L
.31285 .71578 L
.30694 .7105 L
.30446 .70821 L
.29936 .7033 L
.2967 .70064 L
.29179 .69554 L
.28949 .69306 L
.28422 .68715 L
.28279 .68549 L
.27665 .67805 L
.27655 .67792 L
.27072 .67035 L
.26908 .66812 L
.26528 .66278 L
.26151 .6572 L
.26021 .65521 L
.25547 .64764 L
.25394 .64507 L
.25106 .64007 L
.24694 .6325 L
.24637 .63139 L
.24312 .62492 L
.23957 .61735 L
.23879 .61561 L
.23629 .60978 L
.23326 .60221 L
.23122 .59672 L
.23048 .59464 L
.22794 .58707 L
.22563 .5795 L
.22365 .57232 L
.22355 .57193 L
.22169 .56435 L
.22004 .55678 L
.21861 .54921 L
.21739 .54164 L
.21638 .53407 L
.21608 .53151 L
.21557 .5265 L
.21497 .51893 L
.21457 .51136 L
.21437 .50379 L
.21437 .49621 L
.21457 .48864 L
.21497 .48107 L
.21557 .4735 L
.21608 .46849 L
.21638 .46593 L
.21739 .45836 L
.21861 .45079 L
.22004 .44322 L
.22169 .43565 L
.22355 .42807 L
.22365 .42768 L
.22563 .4205 L
.22794 .41293 L
.23048 .40536 L
.23122 .40328 L
.23326 .39779 L
.23629 .39022 L
.23879 .38439 L
.23957 .38265 L
.24312 .37508 L
.24637 .36861 L
.24694 .3675 L
.25106 .35993 L
.25394 .35493 L
.25547 .35236 L
.26021 .34479 L
.26151 .3428 L
.26528 .33722 L
.26908 .33188 L
.27072 .32965 L
.27655 .32208 L
.27665 .32195 L
.28279 .31451 L
.28422 .31285 L
.28949 .30694 L
.29179 .30446 L
.2967 .29936 L
.29936 .2967 L
.30446 .29179 L
.30694 .2895 L
.31285 .28422 L
.31451 .2828 L
.32196 .27665 L
.32208 .27655 L
.32965 .27073 L
.33189 .26908 L
.33722 .26529 L
.34282 .26151 L
.34479 .26022 L
.35236 .25548 L
.35496 .25394 L
.35993 .25107 L
.3675 .24696 L
.36864 .24637 L
.37508 .24314 L
.38265 .23959 L
.38443 .23879 L
.39022 .23631 L
.39779 .23328 L
.40333 .23122 L
.40536 .2305 L
.41293 .22796 L
.4205 .22565 L
.42776 .22365 L
.42807 .22357 L
.43565 .22171 L
.44322 .22007 L
.45079 .21864 L
.45836 .21742 L
.46593 .2164 L
.46868 .21608 L
F
0 .388 .253 r
.44322 .22978 m
.45079 .2283 L
.45836 .22704 L
.46593 .22599 L
.4735 .22515 L
.48107 .22453 L
.48864 .22411 L
.49621 .2239 L
.50379 .2239 L
.51136 .22411 L
.51893 .22453 L
.5265 .22515 L
.53407 .22599 L
.54164 .22704 L
.54921 .2283 L
.55678 .22978 L
.56326 .23122 L
.56435 .23148 L
.57193 .23341 L
.5795 .23557 L
.58707 .23797 L
.58952 .23879 L
.59464 .24061 L
.60221 .2435 L
.60913 .24637 L
.60978 .24665 L
.61735 .25006 L
.62492 .25376 L
.62527 .25394 L
.6325 .25775 L
.63915 .26151 L
.64007 .26205 L
.64764 .26667 L
.65138 .26908 L
.65521 .27164 L
.66234 .27665 L
.66278 .27697 L
.67035 .2827 L
.67228 .28422 L
.67792 .28885 L
.68136 .29179 L
.68549 .29547 L
.6897 .29936 L
.69306 .3026 L
.6974 .30694 L
.70064 .3103 L
.70453 .31451 L
.70821 .31864 L
.71115 .32208 L
.71578 .32772 L
.71731 .32965 L
.72304 .33722 L
.72335 .33765 L
.72837 .34479 L
.73092 .34861 L
.73334 .35236 L
.73796 .35993 L
.73849 .36084 L
.74226 .3675 L
.74606 .3747 L
.74625 .37508 L
.74995 .38265 L
.75337 .39022 L
.75363 .39083 L
.75652 .39779 L
.75941 .40536 L
.76121 .41044 L
.76205 .41293 L
.76444 .4205 L
.7666 .42807 L
.76853 .43565 L
.76878 .43667 L
.77024 .44322 L
.77172 .45079 L
.77298 .45836 L
.77403 .46593 L
.77487 .4735 L
.77549 .48107 L
.77591 .48864 L
.77611 .49621 L
.77611 .50379 L
.77591 .51136 L
.77549 .51893 L
.77487 .5265 L
.77403 .53407 L
.77298 .54164 L
.77172 .54921 L
.77024 .55678 L
.76878 .56333 L
.76853 .56435 L
.7666 .57193 L
.76444 .5795 L
.76205 .58707 L
.76121 .58956 L
.75941 .59464 L
.75652 .60221 L
.75363 .60917 L
.75337 .60978 L
.74995 .61735 L
.74625 .62492 L
.74606 .6253 L
.74226 .6325 L
.73849 .63916 L
.73796 .64007 L
.73334 .64764 L
.73092 .65139 L
.72837 .65521 L
.72335 .66235 L
.72304 .66278 L
.71731 .67035 L
.71578 .67228 L
.71115 .67792 L
.70821 .68136 L
.70453 .68549 L
.70064 .6897 L
.6974 .69306 L
.69306 .6974 L
.6897 .70064 L
.68549 .70453 L
.68136 .70821 L
.67792 .71115 L
.67228 .71578 L
.67035 .7173 L
.66278 .72303 L
.66234 .72335 L
.65521 .72836 L
.65138 .73092 L
.64764 .73333 L
.64007 .73795 L
.63915 .73849 L
.6325 .74225 L
.62527 .74606 L
.62492 .74624 L
.61735 .74994 L
.60978 .75335 L
.60913 .75363 L
.60221 .7565 L
.59464 .75939 L
.58952 .76121 L
.58707 .76203 L
.5795 .76443 L
.57193 .76659 L
.56435 .76852 L
.56326 .76878 L
.55678 .77022 L
.54921 .7717 L
.54164 .77296 L
.53407 .77401 L
.5265 .77485 L
.51893 .77547 L
.51136 .77589 L
.50379 .7761 L
.49621 .7761 L
.48864 .77589 L
.48107 .77547 L
.4735 .77485 L
.46593 .77401 L
.45836 .77296 L
.45079 .7717 L
.44322 .77022 L
.43674 .76878 L
.43565 .76852 L
.42807 .76659 L
.4205 .76443 L
.41293 .76203 L
.41048 .76121 L
.40536 .75939 L
.39779 .7565 L
.39087 .75363 L
.39022 .75335 L
.38265 .74994 L
.37508 .74624 L
.37473 .74606 L
.3675 .74225 L
.36085 .73849 L
.35993 .73795 L
.35236 .73333 L
.34862 .73092 L
.34479 .72836 L
.33766 .72335 L
.33722 .72303 L
.32965 .7173 L
.32772 .71578 L
.32208 .71115 L
.31864 .70821 L
.31451 .70453 L
.3103 .70064 L
.30694 .6974 L
.3026 .69306 L
.29936 .6897 L
.29547 .68549 L
.29179 .68136 L
.28885 .67792 L
.28422 .67228 L
.28269 .67035 L
.27696 .66278 L
.27665 .66235 L
.27163 .65521 L
.26908 .65139 L
.26666 .64764 L
.26204 .64007 L
.26151 .63916 L
.25774 .6325 L
.25394 .6253 L
.25375 .62492 L
.25005 .61735 L
.24663 .60978 L
.24637 .60917 L
.24348 .60221 L
.24059 .59464 L
.23879 .58956 L
.23795 .58707 L
.23556 .5795 L
.2334 .57193 L
.23147 .56435 L
.23122 .56333 L
.22976 .55678 L
.22828 .54921 L
.22702 .54164 L
.22597 .53407 L
.22513 .5265 L
.22451 .51893 L
.22409 .51136 L
.22389 .50379 L
.22389 .49621 L
.22409 .48864 L
.22451 .48107 L
.22513 .4735 L
.22597 .46593 L
.22702 .45836 L
.22828 .45079 L
.22976 .44322 L
.23122 .43667 L
.23147 .43565 L
.2334 .42807 L
.23556 .4205 L
.23795 .41293 L
.23879 .41044 L
.24059 .40536 L
.24348 .39779 L
.24637 .39083 L
.24663 .39022 L
.25005 .38265 L
.25375 .37508 L
.25394 .3747 L
.25774 .3675 L
.26151 .36084 L
.26204 .35993 L
.26666 .35236 L
.26908 .34861 L
.27163 .34479 L
.27665 .33765 L
.27696 .33722 L
.28269 .32965 L
.28422 .32772 L
.28885 .32208 L
.29179 .31864 L
.29547 .31451 L
.29936 .3103 L
.3026 .30694 L
.30694 .3026 L
.3103 .29936 L
.31451 .29547 L
.31864 .29179 L
.32208 .28885 L
.32772 .28422 L
.32965 .2827 L
.33722 .27697 L
.33766 .27665 L
.34479 .27164 L
.34862 .26908 L
.35236 .26667 L
.35993 .26205 L
.36085 .26151 L
.3675 .25775 L
.37473 .25394 L
.37508 .25376 L
.38265 .25006 L
.39022 .24665 L
.39087 .24637 L
.39779 .2435 L
.40536 .24061 L
.41048 .23879 L
.41293 .23797 L
.4205 .23557 L
.42807 .23341 L
.43565 .23148 L
.43674 .23122 L
F
0 .37 .27 r
.45079 .23818 m
.45836 .23687 L
.46593 .23578 L
.4735 .23492 L
.48107 .23427 L
.48864 .23384 L
.49621 .23362 L
.50379 .23362 L
.51136 .23384 L
.51893 .23427 L
.5265 .23491 L
.53407 .23578 L
.54164 .23687 L
.54921 .23818 L
.55239 .23879 L
.55678 .23972 L
.56435 .24149 L
.57193 .24349 L
.5795 .24573 L
.58149 .24637 L
.58707 .24823 L
.59464 .25097 L
.60209 .25394 L
.60221 .25399 L
.60978 .25727 L
.61735 .26084 L
.61871 .26151 L
.62492 .26471 L
.6325 .26888 L
.63284 .26908 L
.64007 .27339 L
.6452 .27665 L
.64764 .27825 L
.65521 .28348 L
.65623 .28422 L
.66278 .28912 L
.66619 .29179 L
.67035 .29518 L
.67526 .29936 L
.67792 .30172 L
.68356 .30694 L
.68549 .30879 L
.69121 .31451 L
.69306 .31643 L
.69828 .32208 L
.70064 .32474 L
.70482 .32965 L
.70821 .3338 L
.71089 .33722 L
.71578 .34376 L
.71652 .34479 L
.72176 .35236 L
.72335 .35478 L
.72662 .35993 L
.73092 .36715 L
.73113 .3675 L
.73531 .37508 L
.73849 .38127 L
.73917 .38265 L
.74274 .39022 L
.74603 .39779 L
.74606 .39787 L
.74904 .40536 L
.75179 .41293 L
.75363 .41846 L
.75428 .4205 L
.75653 .42807 L
.75853 .43565 L
.7603 .44322 L
.76121 .44754 L
.76184 .45079 L
.76315 .45836 L
.76423 .46593 L
.7651 .4735 L
.76575 .48107 L
.76618 .48864 L
.7664 .49621 L
.7664 .50379 L
.76618 .51136 L
.76575 .51893 L
.7651 .5265 L
.76423 .53407 L
.76315 .54164 L
.76184 .54921 L
.76121 .55246 L
.7603 .55678 L
.75853 .56435 L
.75653 .57193 L
.75428 .5795 L
.75363 .58154 L
.75179 .58707 L
.74904 .59464 L
.74606 .60213 L
.74603 .60221 L
.74274 .60978 L
.73917 .61735 L
.73849 .61873 L
.73531 .62492 L
.73113 .6325 L
.73092 .63285 L
.72662 .64007 L
.72335 .64522 L
.72176 .64764 L
.71652 .65521 L
.71578 .65624 L
.71089 .66278 L
.70821 .6662 L
.70482 .67035 L
.70064 .67526 L
.69828 .67792 L
.69306 .68357 L
.69121 .68549 L
.68549 .69121 L
.68356 .69306 L
.67792 .69828 L
.67526 .70064 L
.67035 .70482 L
.66619 .70821 L
.66278 .71088 L
.65623 .71578 L
.65521 .71652 L
.64764 .72175 L
.6452 .72335 L
.64007 .72661 L
.63284 .73092 L
.6325 .73112 L
.62492 .73529 L
.61871 .73849 L
.61735 .73916 L
.60978 .74273 L
.60221 .74601 L
.60209 .74606 L
.59464 .74903 L
.58707 .75177 L
.58149 .75363 L
.5795 .75427 L
.57193 .75651 L
.56435 .75851 L
.55678 .76028 L
.55239 .76121 L
.54921 .76182 L
.54164 .76313 L
.53407 .76422 L
.5265 .76509 L
.51893 .76573 L
.51136 .76616 L
.50379 .76638 L
.49621 .76638 L
.48864 .76616 L
.48107 .76573 L
.4735 .76508 L
.46593 .76422 L
.45836 .76313 L
.45079 .76182 L
.44761 .76121 L
.44322 .76028 L
.43565 .75851 L
.42807 .75651 L
.4205 .75427 L
.41851 .75363 L
.41293 .75177 L
.40536 .74903 L
.39791 .74606 L
.39779 .74601 L
.39022 .74273 L
.38265 .73916 L
.38129 .73849 L
.37508 .73529 L
.3675 .73112 L
.36717 .73092 L
.35993 .72661 L
.3548 .72335 L
.35236 .72175 L
.34479 .71652 L
.34377 .71578 L
.33722 .71088 L
.33381 .70821 L
.32965 .70482 L
.32474 .70064 L
.32208 .69828 L
.31644 .69306 L
.31451 .69121 L
.30879 .68549 L
.30694 .68357 L
.30172 .67792 L
.29936 .67526 L
.29518 .67035 L
.29179 .6662 L
.28911 .66278 L
.28422 .65624 L
.28348 .65521 L
.27824 .64764 L
.27665 .64522 L
.27338 .64007 L
.26908 .63285 L
.26887 .6325 L
.26469 .62492 L
.26151 .61873 L
.26083 .61735 L
.25726 .60978 L
.25397 .60221 L
.25394 .60212 L
.25096 .59464 L
.24821 .58707 L
.24637 .58154 L
.24572 .5795 L
.24347 .57193 L
.24147 .56435 L
.2397 .55678 L
.23879 .55246 L
.23816 .54921 L
.23685 .54164 L
.23577 .53407 L
.2349 .5265 L
.23425 .51893 L
.23382 .51136 L
.2336 .50379 L
.2336 .49621 L
.23382 .48864 L
.23425 .48107 L
.2349 .4735 L
.23577 .46593 L
.23685 .45836 L
.23816 .45079 L
.23879 .44754 L
.2397 .44322 L
.24147 .43565 L
.24347 .42807 L
.24572 .4205 L
.24637 .41846 L
.24821 .41293 L
.25096 .40536 L
.25394 .39788 L
.25397 .39779 L
.25726 .39022 L
.26083 .38265 L
.26151 .38127 L
.26469 .37508 L
.26887 .3675 L
.26908 .36715 L
.27338 .35993 L
.27665 .35478 L
.27824 .35236 L
.28348 .34479 L
.28422 .34376 L
.28911 .33722 L
.29179 .3338 L
.29518 .32965 L
.29936 .32474 L
.30172 .32208 L
.30694 .31643 L
.30879 .31451 L
.31451 .30879 L
.31644 .30694 L
.32208 .30172 L
.32474 .29936 L
.32965 .29518 L
.33381 .29179 L
.33722 .28912 L
.34377 .28422 L
.34479 .28348 L
.35236 .27825 L
.3548 .27665 L
.35993 .27339 L
.36717 .26908 L
.3675 .26888 L
.37508 .26471 L
.38129 .26151 L
.38265 .26084 L
.39022 .25727 L
.39779 .25399 L
.39791 .25394 L
.40536 .25097 L
.41293 .24823 L
.41851 .24637 L
.4205 .24573 L
.42807 .24349 L
.43565 .24149 L
.44322 .23972 L
.44761 .23879 L
F
0 .352 .284 r
.46593 .24581 m
.4735 .24491 L
.48107 .24424 L
.48864 .24379 L
.49621 .24356 L
.50379 .24356 L
.51136 .24379 L
.51893 .24424 L
.5265 .24491 L
.53407 .24581 L
.538 .24637 L
.54164 .24694 L
.54921 .2483 L
.55678 .2499 L
.56435 .25174 L
.57193 .25383 L
.57229 .25394 L
.5795 .25617 L
.58707 .25877 L
.5943 .26151 L
.59464 .26164 L
.60221 .26479 L
.60978 .26823 L
.61157 .26908 L
.61735 .27197 L
.62492 .27603 L
.62604 .27665 L
.6325 .28042 L
.6386 .28422 L
.64007 .28517 L
.64764 .2903 L
.64973 .29179 L
.65521 .29584 L
.65974 .29936 L
.66278 .30183 L
.66881 .30694 L
.67035 .30829 L
.6771 .31451 L
.67792 .3153 L
.6847 .32208 L
.68549 .3229 L
.69171 .32965 L
.69306 .33119 L
.69818 .33722 L
.70064 .34026 L
.70416 .34479 L
.70821 .35026 L
.7097 .35236 L
.71484 .35993 L
.71578 .36139 L
.71959 .3675 L
.72335 .37395 L
.72398 .37508 L
.72804 .38265 L
.73092 .38841 L
.73178 .39022 L
.73522 .39779 L
.73837 .40536 L
.73849 .40567 L
.74124 .41293 L
.74384 .4205 L
.74606 .42767 L
.74618 .42807 L
.74827 .43565 L
.75011 .44322 L
.75171 .45079 L
.75307 .45836 L
.75363 .4619 L
.7542 .46593 L
.7551 .4735 L
.75578 .48107 L
.75623 .48864 L
.75645 .49621 L
.75645 .50379 L
.75623 .51136 L
.75578 .51893 L
.7551 .5265 L
.7542 .53407 L
.75363 .5381 L
.75307 .54164 L
.75171 .54921 L
.75011 .55678 L
.74827 .56435 L
.74618 .57193 L
.74606 .57233 L
.74384 .5795 L
.74124 .58707 L
.73849 .59433 L
.73837 .59464 L
.73522 .60221 L
.73178 .60978 L
.73092 .61159 L
.72804 .61735 L
.72398 .62492 L
.72335 .62605 L
.71959 .6325 L
.71578 .63861 L
.71484 .64007 L
.7097 .64764 L
.70821 .64974 L
.70416 .65521 L
.70064 .65974 L
.69818 .66278 L
.69306 .66881 L
.69171 .67035 L
.68549 .6771 L
.6847 .67792 L
.67792 .6847 L
.6771 .68549 L
.67035 .69171 L
.66881 .69306 L
.66278 .69817 L
.65974 .70064 L
.65521 .70416 L
.64973 .70821 L
.64764 .7097 L
.64007 .71483 L
.6386 .71578 L
.6325 .71958 L
.62604 .72335 L
.62492 .72397 L
.61735 .72803 L
.61157 .73092 L
.60978 .73177 L
.60221 .73521 L
.59464 .73836 L
.5943 .73849 L
.58707 .74123 L
.5795 .74383 L
.57229 .74606 L
.57193 .74617 L
.56435 .74826 L
.55678 .7501 L
.54921 .7517 L
.54164 .75306 L
.538 .75363 L
.53407 .75419 L
.5265 .75509 L
.51893 .75576 L
.51136 .75621 L
.50379 .75644 L
.49621 .75644 L
.48864 .75621 L
.48107 .75576 L
.4735 .75509 L
.46593 .75419 L
.462 .75363 L
.45836 .75306 L
.45079 .7517 L
.44322 .7501 L
.43565 .74826 L
.42807 .74617 L
.42771 .74606 L
.4205 .74383 L
.41293 .74123 L
.4057 .73849 L
.40536 .73836 L
.39779 .73521 L
.39022 .73177 L
.38844 .73092 L
.38265 .72803 L
.37508 .72397 L
.37396 .72335 L
.3675 .71958 L
.3614 .71578 L
.35993 .71483 L
.35236 .7097 L
.35027 .70821 L
.34479 .70416 L
.34026 .70064 L
.33722 .69817 L
.33119 .69306 L
.32965 .69171 L
.3229 .68549 L
.32208 .6847 L
.3153 .67792 L
.31451 .6771 L
.30829 .67035 L
.30694 .66881 L
.30182 .66278 L
.29936 .65974 L
.29584 .65521 L
.29179 .64974 L
.2903 .64764 L
.28516 .64007 L
.28422 .63861 L
.28041 .6325 L
.27665 .62605 L
.27602 .62492 L
.27196 .61735 L
.26908 .61158 L
.26822 .60978 L
.26478 .60221 L
.26163 .59464 L
.26151 .59433 L
.25876 .58707 L
.25616 .5795 L
.25394 .57233 L
.25382 .57193 L
.25173 .56435 L
.24989 .55678 L
.24829 .54921 L
.24693 .54164 L
.24637 .53809 L
.2458 .53407 L
.2449 .5265 L
.24422 .51893 L
.24377 .51136 L
.24355 .50379 L
.24355 .49621 L
.24377 .48864 L
.24422 .48107 L
.2449 .4735 L
.2458 .46593 L
.24637 .46191 L
.24693 .45836 L
.24829 .45079 L
.24989 .44322 L
.25173 .43565 L
.25382 .42807 L
.25394 .42767 L
.25616 .4205 L
.25876 .41293 L
.26151 .40567 L
.26163 .40536 L
.26478 .39779 L
.26822 .39022 L
.26908 .38842 L
.27196 .38265 L
.27602 .37508 L
.27665 .37395 L
.28041 .3675 L
.28422 .36139 L
.28516 .35993 L
.2903 .35236 L
.29179 .35026 L
.29584 .34479 L
.29936 .34026 L
.30182 .33722 L
.30694 .33119 L
.30829 .32965 L
.31451 .3229 L
.3153 .32208 L
.32208 .3153 L
.3229 .31451 L
.32965 .30829 L
.33119 .30694 L
.33722 .30183 L
.34026 .29936 L
.34479 .29584 L
.35027 .29179 L
.35236 .2903 L
.35993 .28517 L
.3614 .28422 L
.3675 .28042 L
.37396 .27665 L
.37508 .27603 L
.38265 .27197 L
.38844 .26908 L
.39022 .26823 L
.39779 .26479 L
.40536 .26164 L
.4057 .26151 L
.41293 .25877 L
.4205 .25617 L
.42771 .25394 L
.42807 .25383 L
.43565 .25174 L
.44322 .2499 L
.45079 .2483 L
.45836 .24694 L
.462 .24637 L
F
0 .334 .296 r
.49621 .25377 m
.50379 .25377 L
.50978 .25394 L
.51136 .254 L
.51893 .25447 L
.5265 .25517 L
.53407 .25611 L
.54164 .25729 L
.54921 .25871 L
.55678 .26038 L
.56135 .26151 L
.56435 .2623 L
.57193 .26448 L
.5795 .26693 L
.58554 .26908 L
.58707 .26965 L
.59464 .27266 L
.60221 .27596 L
.60371 .27665 L
.60978 .27957 L
.61735 .28351 L
.61866 .28422 L
.62492 .28779 L
.63149 .29179 L
.6325 .29243 L
.64007 .29746 L
.64278 .29936 L
.64764 .30291 L
.65286 .30694 L
.65521 .30882 L
.66196 .31451 L
.66278 .31522 L
.67025 .32208 L
.67035 .32218 L
.67782 .32965 L
.67792 .32975 L
.68478 .33722 L
.68549 .33803 L
.69118 .34479 L
.69306 .34714 L
.69709 .35236 L
.70064 .35722 L
.70254 .35993 L
.70757 .3675 L
.70821 .3685 L
.71222 .37508 L
.71578 .38133 L
.7165 .38265 L
.72044 .39022 L
.72335 .39627 L
.72405 .39779 L
.72735 .40536 L
.73036 .41293 L
.73092 .41444 L
.73308 .4205 L
.73553 .42807 L
.73771 .43565 L
.73849 .43861 L
.73963 .44322 L
.7413 .45079 L
.74272 .45836 L
.7439 .46593 L
.74484 .4735 L
.74554 .48107 L
.74601 .48864 L
.74606 .48994 L
.74624 .49621 L
.74624 .50379 L
.74606 .51006 L
.74601 .51136 L
.74554 .51893 L
.74484 .5265 L
.7439 .53407 L
.74272 .54164 L
.7413 .54921 L
.73963 .55678 L
.73849 .56139 L
.73771 .56435 L
.73553 .57193 L
.73308 .5795 L
.73092 .58556 L
.73036 .58707 L
.72735 .59464 L
.72405 .60221 L
.72335 .60373 L
.72044 .60978 L
.7165 .61735 L
.71578 .61867 L
.71222 .62492 L
.70821 .6315 L
.70757 .6325 L
.70254 .64007 L
.70064 .64278 L
.69709 .64764 L
.69306 .65286 L
.69118 .65521 L
.68549 .66197 L
.68478 .66278 L
.67792 .67025 L
.67782 .67035 L
.67035 .67782 L
.67025 .67792 L
.66278 .68478 L
.66196 .68549 L
.65521 .69118 L
.65286 .69306 L
.64764 .69709 L
.64278 .70064 L
.64007 .70254 L
.6325 .70757 L
.63149 .70821 L
.62492 .71221 L
.61866 .71578 L
.61735 .71649 L
.60978 .72043 L
.60371 .72335 L
.60221 .72404 L
.59464 .72734 L
.58707 .73035 L
.58554 .73092 L
.5795 .73307 L
.57193 .73552 L
.56435 .7377 L
.56135 .73849 L
.55678 .73962 L
.54921 .74129 L
.54164 .74271 L
.53407 .74389 L
.5265 .74483 L
.51893 .74553 L
.51136 .746 L
.50978 .74606 L
.50379 .74623 L
.49621 .74623 L
.49022 .74606 L
.48864 .746 L
.48107 .74553 L
.4735 .74483 L
.46593 .74389 L
.45836 .74271 L
.45079 .74129 L
.44322 .73962 L
.43865 .73849 L
.43565 .7377 L
.42807 .73552 L
.4205 .73307 L
.41446 .73092 L
.41293 .73035 L
.40536 .72734 L
.39779 .72404 L
.39629 .72335 L
.39022 .72043 L
.38265 .71649 L
.38134 .71578 L
.37508 .71221 L
.36851 .70821 L
.3675 .70757 L
.35993 .70254 L
.35722 .70064 L
.35236 .69709 L
.34714 .69306 L
.34479 .69118 L
.33804 .68549 L
.33722 .68478 L
.32975 .67792 L
.32965 .67782 L
.32218 .67035 L
.32208 .67025 L
.31522 .66278 L
.31451 .66197 L
.30882 .65521 L
.30694 .65286 L
.30291 .64764 L
.29936 .64278 L
.29746 .64007 L
.29243 .6325 L
.29179 .6315 L
.28778 .62492 L
.28422 .61867 L
.2835 .61735 L
.27956 .60978 L
.27665 .60373 L
.27595 .60221 L
.27265 .59464 L
.26964 .58707 L
.26908 .58556 L
.26692 .5795 L
.26447 .57193 L
.26229 .56435 L
.26151 .56139 L
.26037 .55678 L
.2587 .54921 L
.25728 .54164 L
.2561 .53407 L
.25516 .5265 L
.25446 .51893 L
.25399 .51136 L
.25394 .51005 L
.25376 .50379 L
.25376 .49621 L
.25394 .48995 L
.25399 .48864 L
.25446 .48107 L
.25516 .4735 L
.2561 .46593 L
.25728 .45836 L
.2587 .45079 L
.26037 .44322 L
.26151 .43861 L
.26229 .43565 L
.26447 .42807 L
.26692 .4205 L
.26908 .41444 L
.26964 .41293 L
.27265 .40536 L
.27595 .39779 L
.27665 .39627 L
.27956 .39022 L
.2835 .38265 L
.28422 .38133 L
.28778 .37508 L
.29179 .3685 L
.29243 .3675 L
.29746 .35993 L
.29936 .35722 L
.30291 .35236 L
.30694 .34714 L
.30882 .34479 L
.31451 .33803 L
.31522 .33722 L
.32208 .32975 L
.32218 .32965 L
.32965 .32218 L
.32975 .32208 L
.33722 .31522 L
.33804 .31451 L
.34479 .30882 L
.34714 .30694 L
.35236 .30291 L
.35722 .29936 L
.35993 .29746 L
.3675 .29243 L
.36851 .29179 L
.37508 .28779 L
.38134 .28422 L
.38265 .28351 L
.39022 .27957 L
.39629 .27665 L
.39779 .27596 L
.40536 .27266 L
.41293 .26965 L
.41446 .26908 L
.4205 .26693 L
.42807 .26448 L
.43565 .2623 L
.43865 .26151 L
.44322 .26038 L
.45079 .25871 L
.45836 .25729 L
.46593 .25611 L
.4735 .25517 L
.48107 .25447 L
.48864 .254 L
.49022 .25394 L
F
0 .316 .305 r
.45836 .26796 m
.46593 .26673 L
.4735 .26575 L
.48107 .26501 L
.48864 .26453 L
.49621 .26428 L
.50379 .26428 L
.51136 .26453 L
.51893 .26501 L
.5265 .26575 L
.53407 .26673 L
.54164 .26796 L
.54747 .26908 L
.54921 .26945 L
.55678 .27119 L
.56435 .27321 L
.57193 .27549 L
.57544 .27665 L
.5795 .27806 L
.58707 .28092 L
.59464 .28409 L
.59495 .28422 L
.60221 .28757 L
.60978 .29138 L
.61057 .29179 L
.61735 .29554 L
.62378 .29936 L
.62492 .30008 L
.6325 .30501 L
.63528 .30694 L
.64007 .31038 L
.64549 .31451 L
.64764 .31621 L
.65466 .32208 L
.65521 .32256 L
.66278 .32948 L
.66296 .32965 L
.67035 .33704 L
.67052 .33722 L
.67744 .34479 L
.67792 .34534 L
.68379 .35236 L
.68549 .35451 L
.68962 .35993 L
.69306 .36471 L
.69499 .3675 L
.69993 .37508 L
.70064 .37622 L
.70446 .38265 L
.70821 .38942 L
.70863 .39022 L
.71244 .39779 L
.71578 .40504 L
.71592 .40536 L
.71908 .41293 L
.72195 .4205 L
.72335 .42453 L
.72451 .42807 L
.7268 .43565 L
.72881 .44322 L
.73056 .45079 L
.73092 .45249 L
.73205 .45836 L
.73328 .46593 L
.73426 .4735 L
.735 .48107 L
.73548 .48864 L
.73573 .49621 L
.73573 .50379 L
.73548 .51136 L
.735 .51893 L
.73426 .5265 L
.73328 .53407 L
.73205 .54164 L
.73092 .54751 L
.73056 .54921 L
.72881 .55678 L
.7268 .56435 L
.72451 .57193 L
.72335 .57547 L
.72195 .5795 L
.71908 .58707 L
.71592 .59464 L
.71578 .59496 L
.71244 .60221 L
.70863 .60978 L
.70821 .61058 L
.70446 .61735 L
.70064 .62378 L
.69993 .62492 L
.69499 .6325 L
.69306 .63529 L
.68962 .64007 L
.68549 .64549 L
.68379 .64764 L
.67792 .65466 L
.67744 .65521 L
.67052 .66278 L
.67035 .66296 L
.66296 .67035 L
.66278 .67052 L
.65521 .67744 L
.65466 .67792 L
.64764 .68379 L
.64549 .68549 L
.64007 .68962 L
.63528 .69306 L
.6325 .69499 L
.62492 .69992 L
.62378 .70064 L
.61735 .70446 L
.61057 .70821 L
.60978 .70862 L
.60221 .71243 L
.59495 .71578 L
.59464 .71591 L
.58707 .71908 L
.5795 .72194 L
.57544 .72335 L
.57193 .72451 L
.56435 .72679 L
.55678 .72881 L
.54921 .73055 L
.54747 .73092 L
.54164 .73204 L
.53407 .73327 L
.5265 .73425 L
.51893 .73499 L
.51136 .73547 L
.50379 .73572 L
.49621 .73572 L
.48864 .73547 L
.48107 .73499 L
.4735 .73425 L
.46593 .73327 L
.45836 .73204 L
.45253 .73092 L
.45079 .73055 L
.44322 .72881 L
.43565 .72679 L
.42807 .72451 L
.42456 .72335 L
.4205 .72194 L
.41293 .71908 L
.40536 .71591 L
.40505 .71578 L
.39779 .71243 L
.39022 .70862 L
.38943 .70821 L
.38265 .70446 L
.37622 .70064 L
.37508 .69992 L
.3675 .69499 L
.36472 .69306 L
.35993 .68962 L
.35451 .68549 L
.35236 .68379 L
.34534 .67792 L
.34479 .67744 L
.33722 .67052 L
.33704 .67035 L
.32965 .66296 L
.32948 .66278 L
.32256 .65521 L
.32208 .65466 L
.31621 .64764 L
.31451 .64549 L
.31038 .64007 L
.30694 .63529 L
.30501 .6325 L
.30007 .62492 L
.29936 .62378 L
.29554 .61735 L
.29179 .61058 L
.29137 .60978 L
.28756 .60221 L
.28422 .59496 L
.28408 .59464 L
.28092 .58707 L
.27806 .5795 L
.27665 .57546 L
.27549 .57193 L
.2732 .56435 L
.27119 .55678 L
.26944 .54921 L
.26908 .54751 L
.26795 .54164 L
.26672 .53407 L
.26574 .5265 L
.265 .51893 L
.26452 .51136 L
.26427 .50379 L
.26427 .49621 L
.26452 .48864 L
.265 .48107 L
.26574 .4735 L
.26672 .46593 L
.26795 .45836 L
.26908 .45249 L
.26944 .45079 L
.27119 .44322 L
.2732 .43565 L
.27549 .42807 L
.27665 .42454 L
.27806 .4205 L
.28092 .41293 L
.28408 .40536 L
.28422 .40504 L
.28756 .39779 L
.29137 .39022 L
.29179 .38942 L
.29554 .38265 L
.29936 .37622 L
.30007 .37508 L
.30501 .3675 L
.30694 .36471 L
.31038 .35993 L
.31451 .35451 L
.31621 .35236 L
.32208 .34534 L
.32256 .34479 L
.32948 .33722 L
.32965 .33704 L
.33704 .32965 L
.33722 .32948 L
.34479 .32256 L
.34534 .32208 L
.35236 .31621 L
.35451 .31451 L
.35993 .31038 L
.36472 .30694 L
.3675 .30501 L
.37508 .30008 L
.37622 .29936 L
.38265 .29554 L
.38943 .29179 L
.39022 .29138 L
.39779 .28757 L
.40505 .28422 L
.40536 .28409 L
.41293 .28092 L
.4205 .27806 L
.42456 .27665 L
.42807 .27549 L
.43565 .27321 L
.44322 .27119 L
.45079 .26945 L
.45253 .26908 L
F
0 .285 .298 r
.48107 .27591 m
.48864 .2754 L
.49621 .27514 L
.50379 .27514 L
.51136 .2754 L
.51893 .27591 L
.52628 .27665 L
.5265 .27668 L
.53407 .27771 L
.54164 .279 L
.54921 .28056 L
.55678 .2824 L
.56336 .28422 L
.56435 .28452 L
.57193 .28693 L
.5795 .28963 L
.58499 .29179 L
.58707 .29265 L
.59464 .296 L
.60158 .29936 L
.60221 .29968 L
.60978 .30373 L
.61532 .30694 L
.61735 .30816 L
.62492 .31301 L
.62714 .31451 L
.6325 .31829 L
.63754 .32208 L
.64007 .32406 L
.64681 .32965 L
.64764 .33037 L
.65516 .33722 L
.65521 .33726 L
.66274 .34479 L
.66278 .34484 L
.66964 .35236 L
.67035 .35319 L
.67594 .35993 L
.67792 .36246 L
.68171 .3675 L
.68549 .37285 L
.687 .37508 L
.69184 .38265 L
.69306 .38467 L
.69627 .39022 L
.70032 .39779 L
.70064 .39841 L
.70401 .40536 L
.70735 .41293 L
.70821 .41499 L
.71037 .4205 L
.71308 .42807 L
.71549 .43565 L
.71578 .43662 L
.71761 .44322 L
.71944 .45079 L
.72101 .45836 L
.7223 .46593 L
.72333 .4735 L
.72335 .47367 L
.7241 .48107 L
.72461 .48864 L
.72486 .49621 L
.72486 .50379 L
.72461 .51136 L
.7241 .51893 L
.72335 .52633 L
.72333 .5265 L
.7223 .53407 L
.72101 .54164 L
.71944 .54921 L
.71761 .55678 L
.71578 .56338 L
.71549 .56435 L
.71308 .57193 L
.71037 .5795 L
.70821 .58501 L
.70735 .58707 L
.70401 .59464 L
.70064 .60159 L
.70032 .60221 L
.69627 .60978 L
.69306 .61533 L
.69184 .61735 L
.687 .62492 L
.68549 .62715 L
.68171 .6325 L
.67792 .63754 L
.67594 .64007 L
.67035 .64681 L
.66964 .64764 L
.66278 .65516 L
.66274 .65521 L
.65521 .66274 L
.65516 .66278 L
.64764 .66963 L
.64681 .67035 L
.64007 .67594 L
.63754 .67792 L
.6325 .68171 L
.62714 .68549 L
.62492 .68699 L
.61735 .69184 L
.61532 .69306 L
.60978 .69627 L
.60221 .70032 L
.60158 .70064 L
.59464 .704 L
.58707 .70735 L
.58499 .70821 L
.5795 .71037 L
.57193 .71307 L
.56435 .71548 L
.56336 .71578 L
.55678 .7176 L
.54921 .71944 L
.54164 .721 L
.53407 .72229 L
.5265 .72332 L
.52628 .72335 L
.51893 .72409 L
.51136 .7246 L
.50379 .72486 L
.49621 .72486 L
.48864 .7246 L
.48107 .72409 L
.47372 .72335 L
.4735 .72332 L
.46593 .72229 L
.45836 .721 L
.45079 .71944 L
.44322 .7176 L
.43664 .71578 L
.43565 .71548 L
.42807 .71307 L
.4205 .71037 L
.41501 .70821 L
.41293 .70735 L
.40536 .704 L
.39842 .70064 L
.39779 .70032 L
.39022 .69627 L
.38468 .69306 L
.38265 .69184 L
.37508 .68699 L
.37286 .68549 L
.3675 .68171 L
.36246 .67792 L
.35993 .67594 L
.35319 .67035 L
.35236 .66963 L
.34484 .66278 L
.34479 .66274 L
.33726 .65521 L
.33722 .65516 L
.33036 .64764 L
.32965 .64681 L
.32406 .64007 L
.32208 .63754 L
.31829 .6325 L
.31451 .62715 L
.313 .62492 L
.30816 .61735 L
.30694 .61533 L
.30373 .60978 L
.29968 .60221 L
.29936 .60159 L
.29599 .59464 L
.29265 .58707 L
.29179 .585 L
.28963 .5795 L
.28692 .57193 L
.28451 .56435 L
.28422 .56338 L
.28239 .55678 L
.28056 .54921 L
.27899 .54164 L
.2777 .53407 L
.27667 .5265 L
.27665 .52633 L
.2759 .51893 L
.27539 .51136 L
.27514 .50379 L
.27514 .49621 L
.27539 .48864 L
.2759 .48107 L
.27665 .47367 L
.27667 .4735 L
.2777 .46593 L
.27899 .45836 L
.28056 .45079 L
.28239 .44322 L
.28422 .43662 L
.28451 .43565 L
.28692 .42807 L
.28963 .4205 L
.29179 .415 L
.29265 .41293 L
.29599 .40536 L
.29936 .39841 L
.29968 .39779 L
.30373 .39022 L
.30694 .38467 L
.30816 .38265 L
.313 .37508 L
.31451 .37285 L
.31829 .3675 L
.32208 .36246 L
.32406 .35993 L
.32965 .35319 L
.33036 .35236 L
.33722 .34484 L
.33726 .34479 L
.34479 .33726 L
.34484 .33722 L
.35236 .33037 L
.35319 .32965 L
.35993 .32406 L
.36246 .32208 L
.3675 .31829 L
.37286 .31451 L
.37508 .31301 L
.38265 .30816 L
.38468 .30694 L
.39022 .30373 L
.39779 .29968 L
.39842 .29936 L
.40536 .296 L
.41293 .29265 L
.41501 .29179 L
.4205 .28963 L
.42807 .28693 L
.43565 .28452 L
.43664 .28422 L
.44322 .2824 L
.45079 .28056 L
.45836 .279 L
.46593 .27771 L
.4735 .27668 L
.47372 .27665 L
F
0 .246 .28 r
.45836 .29048 m
.46593 .28912 L
.4735 .28803 L
.48107 .28722 L
.48864 .28668 L
.49621 .28641 L
.50379 .28641 L
.51136 .28668 L
.51893 .28722 L
.5265 .28803 L
.53407 .28912 L
.54164 .29048 L
.54778 .29179 L
.54921 .29213 L
.55678 .29407 L
.56435 .29631 L
.57193 .29886 L
.57333 .29936 L
.5795 .30173 L
.58707 .30493 L
.59142 .30694 L
.59464 .30849 L
.60221 .31243 L
.60594 .31451 L
.60978 .31675 L
.61735 .32151 L
.61821 .32208 L
.62492 .32672 L
.62889 .32965 L
.6325 .33244 L
.63832 .33722 L
.64007 .33872 L
.64677 .34479 L
.64764 .34562 L
.65438 .35236 L
.65521 .35323 L
.66128 .35993 L
.66278 .36167 L
.66756 .3675 L
.67035 .37111 L
.67328 .37508 L
.67792 .38178 L
.67849 .38265 L
.68325 .39022 L
.68549 .39405 L
.68758 .39779 L
.69151 .40536 L
.69306 .40857 L
.69507 .41293 L
.69828 .4205 L
.70064 .42666 L
.70115 .42807 L
.7037 .43565 L
.70594 .44322 L
.70788 .45079 L
.70821 .4522 L
.70952 .45836 L
.71089 .46593 L
.71197 .4735 L
.71278 .48107 L
.71332 .48864 L
.71359 .49621 L
.71359 .50379 L
.71332 .51136 L
.71278 .51893 L
.71197 .5265 L
.71089 .53407 L
.70952 .54164 L
.70821 .5478 L
.70788 .54921 L
.70594 .55678 L
.7037 .56435 L
.70115 .57193 L
.70064 .57334 L
.69828 .5795 L
.69507 .58707 L
.69306 .59143 L
.69151 .59464 L
.68758 .60221 L
.68549 .60595 L
.68325 .60978 L
.67849 .61735 L
.67792 .61822 L
.67328 .62492 L
.67035 .62889 L
.66756 .6325 L
.66278 .63833 L
.66128 .64007 L
.65521 .64677 L
.65438 .64764 L
.64764 .65438 L
.64677 .65521 L
.64007 .66128 L
.63832 .66278 L
.6325 .66756 L
.62889 .67035 L
.62492 .67328 L
.61821 .67792 L
.61735 .67849 L
.60978 .68325 L
.60594 .68549 L
.60221 .68757 L
.59464 .69151 L
.59142 .69306 L
.58707 .69507 L
.5795 .69827 L
.57333 .70064 L
.57193 .70114 L
.56435 .70369 L
.55678 .70593 L
.54921 .70787 L
.54778 .70821 L
.54164 .70952 L
.53407 .71088 L
.5265 .71197 L
.51893 .71278 L
.51136 .71332 L
.50379 .71359 L
.49621 .71359 L
.48864 .71332 L
.48107 .71278 L
.4735 .71197 L
.46593 .71088 L
.45836 .70952 L
.45222 .70821 L
.45079 .70787 L
.44322 .70593 L
.43565 .70369 L
.42807 .70114 L
.42667 .70064 L
.4205 .69827 L
.41293 .69507 L
.40858 .69306 L
.40536 .69151 L
.39779 .68757 L
.39406 .68549 L
.39022 .68325 L
.38265 .67849 L
.38179 .67792 L
.37508 .67328 L
.37111 .67035 L
.3675 .66756 L
.36168 .66278 L
.35993 .66128 L
.35323 .65521 L
.35236 .65438 L
.34562 .64764 L
.34479 .64677 L
.33872 .64007 L
.33722 .63833 L
.33244 .6325 L
.32965 .62889 L
.32672 .62492 L
.32208 .61822 L
.32151 .61735 L
.31675 .60978 L
.31451 .60595 L
.31242 .60221 L
.30849 .59464 L
.30694 .59143 L
.30493 .58707 L
.30172 .5795 L
.29936 .57334 L
.29885 .57193 L
.2963 .56435 L
.29406 .55678 L
.29212 .54921 L
.29179 .5478 L
.29048 .54164 L
.28911 .53407 L
.28803 .5265 L
.28722 .51893 L
.28668 .51136 L
.28641 .50379 L
.28641 .49621 L
.28668 .48864 L
.28722 .48107 L
.28803 .4735 L
.28911 .46593 L
.29048 .45836 L
.29179 .4522 L
.29212 .45079 L
.29406 .44322 L
.2963 .43565 L
.29885 .42807 L
.29936 .42666 L
.30172 .4205 L
.30493 .41293 L
.30694 .40857 L
.30849 .40536 L
.31242 .39779 L
.31451 .39405 L
.31675 .39022 L
.32151 .38265 L
.32208 .38178 L
.32672 .37508 L
.32965 .37111 L
.33244 .3675 L
.33722 .36167 L
.33872 .35993 L
.34479 .35323 L
.34562 .35236 L
.35236 .34562 L
.35323 .34479 L
.35993 .33872 L
.36168 .33722 L
.3675 .33244 L
.37111 .32965 L
.37508 .32672 L
.38179 .32208 L
.38265 .32151 L
.39022 .31675 L
.39406 .31451 L
.39779 .31243 L
.40536 .30849 L
.40858 .30694 L
.41293 .30493 L
.4205 .30173 L
.42667 .29936 L
.42807 .29886 L
.43565 .29631 L
.44322 .29407 L
.45079 .29213 L
.45222 .29179 L
F
0 .21 .262 r
.48107 .29903 m
.48864 .29846 L
.49621 .29817 L
.50379 .29817 L
.51136 .29846 L
.51893 .29903 L
.52233 .29936 L
.5265 .29988 L
.53407 .30103 L
.54164 .30248 L
.54921 .30423 L
.55678 .30629 L
.55895 .30694 L
.56435 .30867 L
.57193 .31139 L
.5795 .31445 L
.57962 .31451 L
.58707 .31788 L
.59464 .3217 L
.59535 .32208 L
.60221 .32593 L
.60829 .32965 L
.60978 .3306 L
.61735 .33576 L
.61937 .33722 L
.62492 .34144 L
.62906 .34479 L
.6325 .34771 L
.63766 .35236 L
.64007 .35464 L
.64536 .35993 L
.64764 .36234 L
.65229 .3675 L
.65521 .37094 L
.65856 .37508 L
.66278 .38063 L
.66424 .38265 L
.6694 .39022 L
.67035 .3917 L
.67407 .39779 L
.67792 .40465 L
.6783 .40536 L
.68212 .41293 L
.68549 .42037 L
.68555 .4205 L
.68861 .42807 L
.69133 .43565 L
.69306 .44105 L
.69371 .44322 L
.69577 .45079 L
.69752 .45836 L
.69897 .46593 L
.70012 .4735 L
.70064 .47764 L
.70098 .48107 L
.70155 .48864 L
.70183 .49621 L
.70183 .50379 L
.70155 .51136 L
.70098 .51893 L
.70064 .52236 L
.70012 .5265 L
.69897 .53407 L
.69752 .54164 L
.69577 .54921 L
.69371 .55678 L
.69306 .55895 L
.69133 .56435 L
.68861 .57193 L
.68555 .5795 L
.68549 .57963 L
.68212 .58707 L
.6783 .59464 L
.67792 .59535 L
.67407 .60221 L
.67035 .6083 L
.6694 .60978 L
.66424 .61735 L
.66278 .61937 L
.65856 .62492 L
.65521 .62906 L
.65229 .6325 L
.64764 .63766 L
.64536 .64007 L
.64007 .64536 L
.63766 .64764 L
.6325 .65229 L
.62906 .65521 L
.62492 .65856 L
.61937 .66278 L
.61735 .66424 L
.60978 .6694 L
.60829 .67035 L
.60221 .67407 L
.59535 .67792 L
.59464 .6783 L
.58707 .68212 L
.57962 .68549 L
.5795 .68555 L
.57193 .68861 L
.56435 .69133 L
.55895 .69306 L
.55678 .69371 L
.54921 .69577 L
.54164 .69752 L
.53407 .69897 L
.5265 .70012 L
.52233 .70064 L
.51893 .70097 L
.51136 .70154 L
.50379 .70183 L
.49621 .70183 L
.48864 .70154 L
.48107 .70097 L
.47767 .70064 L
.4735 .70012 L
.46593 .69897 L
.45836 .69752 L
.45079 .69577 L
.44322 .69371 L
.44105 .69306 L
.43565 .69133 L
.42807 .68861 L
.4205 .68555 L
.42038 .68549 L
.41293 .68212 L
.40536 .6783 L
.40465 .67792 L
.39779 .67407 L
.39171 .67035 L
.39022 .6694 L
.38265 .66424 L
.38063 .66278 L
.37508 .65856 L
.37094 .65521 L
.3675 .65229 L
.36234 .64764 L
.35993 .64536 L
.35464 .64007 L
.35236 .63766 L
.34771 .6325 L
.34479 .62906 L
.34144 .62492 L
.33722 .61937 L
.33576 .61735 L
.3306 .60978 L
.32965 .6083 L
.32593 .60221 L
.32208 .59535 L
.3217 .59464 L
.31788 .58707 L
.31451 .57963 L
.31445 .5795 L
.31139 .57193 L
.30867 .56435 L
.30694 .55895 L
.30629 .55678 L
.30423 .54921 L
.30248 .54164 L
.30103 .53407 L
.29988 .5265 L
.29936 .52236 L
.29902 .51893 L
.29845 .51136 L
.29817 .50379 L
.29817 .49621 L
.29845 .48864 L
.29902 .48107 L
.29936 .47764 L
.29988 .4735 L
.30103 .46593 L
.30248 .45836 L
.30423 .45079 L
.30629 .44322 L
.30694 .44105 L
.30867 .43565 L
.31139 .42807 L
.31445 .4205 L
.31451 .42037 L
.31788 .41293 L
.3217 .40536 L
.32208 .40465 L
.32593 .39779 L
.32965 .3917 L
.3306 .39022 L
.33576 .38265 L
.33722 .38063 L
.34144 .37508 L
.34479 .37094 L
.34771 .3675 L
.35236 .36234 L
.35464 .35993 L
.35993 .35464 L
.36234 .35236 L
.3675 .34771 L
.37094 .34479 L
.37508 .34144 L
.38063 .33722 L
.38265 .33576 L
.39022 .3306 L
.39171 .32965 L
.39779 .32593 L
.40465 .32208 L
.40536 .3217 L
.41293 .31788 L
.42038 .31451 L
.4205 .31445 L
.42807 .31139 L
.43565 .30867 L
.44105 .30694 L
.44322 .30629 L
.45079 .30423 L
.45836 .30248 L
.46593 .30103 L
.4735 .29988 L
.47767 .29936 L
F
0 .177 .244 r
.46593 .31356 m
.4735 .31233 L
.48107 .31142 L
.48864 .31081 L
.49621 .31051 L
.50379 .31051 L
.51136 .31081 L
.51893 .31142 L
.5265 .31233 L
.53407 .31356 L
.53891 .31451 L
.54164 .3151 L
.54921 .31697 L
.55678 .31918 L
.56435 .32174 L
.5653 .32208 L
.57193 .32465 L
.5795 .32795 L
.58307 .32965 L
.58707 .33166 L
.59464 .3358 L
.59707 .33722 L
.60221 .3404 L
.60876 .34479 L
.60978 .34551 L
.61735 .35118 L
.61884 .35236 L
.62492 .35748 L
.62767 .35993 L
.6325 .36449 L
.63551 .3675 L
.64007 .37233 L
.64252 .37508 L
.64764 .38116 L
.64882 .38265 L
.65449 .39022 L
.65521 .39124 L
.6596 .39779 L
.66278 .40293 L
.6642 .40536 L
.66834 .41293 L
.67035 .41693 L
.67205 .4205 L
.67535 .42807 L
.67792 .4347 L
.67827 .43565 L
.68082 .44322 L
.68303 .45079 L
.6849 .45836 L
.68549 .46108 L
.68644 .46593 L
.68767 .4735 L
.68858 .48107 L
.68919 .48864 L
.68949 .49621 L
.68949 .50379 L
.68919 .51136 L
.68858 .51893 L
.68767 .5265 L
.68644 .53407 L
.68549 .53892 L
.6849 .54164 L
.68303 .54921 L
.68082 .55678 L
.67827 .56435 L
.67792 .5653 L
.67535 .57193 L
.67205 .5795 L
.67035 .58307 L
.66834 .58707 L
.6642 .59464 L
.66278 .59707 L
.6596 .60221 L
.65521 .60876 L
.65449 .60978 L
.64882 .61735 L
.64764 .61884 L
.64252 .62492 L
.64007 .62767 L
.63551 .6325 L
.6325 .63551 L
.62767 .64007 L
.62492 .64252 L
.61884 .64764 L
.61735 .64882 L
.60978 .65449 L
.60876 .65521 L
.60221 .6596 L
.59707 .66278 L
.59464 .6642 L
.58707 .66834 L
.58307 .67035 L
.5795 .67205 L
.57193 .67535 L
.5653 .67792 L
.56435 .67826 L
.55678 .68082 L
.54921 .68303 L
.54164 .6849 L
.53891 .68549 L
.53407 .68644 L
.5265 .68767 L
.51893 .68858 L
.51136 .68919 L
.50379 .68949 L
.49621 .68949 L
.48864 .68919 L
.48107 .68858 L
.4735 .68767 L
.46593 .68644 L
.46109 .68549 L
.45836 .6849 L
.45079 .68303 L
.44322 .68082 L
.43565 .67826 L
.4347 .67792 L
.42807 .67535 L
.4205 .67205 L
.41693 .67035 L
.41293 .66834 L
.40536 .6642 L
.40293 .66278 L
.39779 .6596 L
.39124 .65521 L
.39022 .65449 L
.38265 .64882 L
.38116 .64764 L
.37508 .64252 L
.37233 .64007 L
.3675 .63551 L
.36449 .6325 L
.35993 .62767 L
.35748 .62492 L
.35236 .61884 L
.35118 .61735 L
.34551 .60978 L
.34479 .60876 L
.3404 .60221 L
.33722 .59707 L
.3358 .59464 L
.33166 .58707 L
.32965 .58307 L
.32795 .5795 L
.32465 .57193 L
.32208 .5653 L
.32173 .56435 L
.31918 .55678 L
.31697 .54921 L
.3151 .54164 L
.31451 .53891 L
.31356 .53407 L
.31233 .5265 L
.31142 .51893 L
.31081 .51136 L
.31051 .50379 L
.31051 .49621 L
.31081 .48864 L
.31142 .48107 L
.31233 .4735 L
.31356 .46593 L
.31451 .46109 L
.3151 .45836 L
.31697 .45079 L
.31918 .44322 L
.32173 .43565 L
.32208 .4347 L
.32465 .42807 L
.32795 .4205 L
.32965 .41693 L
.33166 .41293 L
.3358 .40536 L
.33722 .40293 L
.3404 .39779 L
.34479 .39124 L
.34551 .39022 L
.35118 .38265 L
.35236 .38116 L
.35748 .37508 L
.35993 .37233 L
.36449 .3675 L
.3675 .36449 L
.37233 .35993 L
.37508 .35748 L
.38116 .35236 L
.38265 .35118 L
.39022 .34551 L
.39124 .34479 L
.39779 .3404 L
.40293 .33722 L
.40536 .3358 L
.41293 .33166 L
.41693 .32965 L
.4205 .32795 L
.42807 .32465 L
.4347 .32208 L
.43565 .32174 L
.44322 .31918 L
.45079 .31697 L
.45836 .3151 L
.46109 .31451 L
F
0 .146 .226 r
.45836 .3285 m
.46593 .32684 L
.4735 .32552 L
.48107 .32454 L
.48864 .32388 L
.49621 .32356 L
.50379 .32356 L
.51136 .32388 L
.51893 .32454 L
.5265 .32552 L
.53407 .32684 L
.54164 .3285 L
.54612 .32965 L
.54921 .33052 L
.55678 .3329 L
.56435 .33567 L
.56818 .33722 L
.57193 .33884 L
.5795 .34244 L
.584 .34479 L
.58707 .34649 L
.59464 .35104 L
.59669 .35236 L
.60221 .35613 L
.60736 .35993 L
.60978 .36182 L
.61657 .3675 L
.61735 .36819 L
.62465 .37508 L
.62492 .37535 L
.63181 .38265 L
.6325 .38343 L
.63818 .39022 L
.64007 .39264 L
.64387 .39779 L
.64764 .40331 L
.64896 .40536 L
.65351 .41293 L
.65521 .416 L
.65756 .4205 L
.66116 .42807 L
.66278 .43182 L
.66433 .43565 L
.6671 .44322 L
.66948 .45079 L
.67035 .45388 L
.6715 .45836 L
.67316 .46593 L
.67448 .4735 L
.67546 .48107 L
.67612 .48864 L
.67644 .49621 L
.67644 .50379 L
.67612 .51136 L
.67546 .51893 L
.67448 .5265 L
.67316 .53407 L
.6715 .54164 L
.67035 .54612 L
.66948 .54921 L
.6671 .55678 L
.66433 .56435 L
.66278 .56818 L
.66116 .57193 L
.65756 .5795 L
.65521 .584 L
.65351 .58707 L
.64896 .59464 L
.64764 .59669 L
.64387 .60221 L
.64007 .60736 L
.63818 .60978 L
.6325 .61657 L
.63181 .61735 L
.62492 .62465 L
.62465 .62492 L
.61735 .63181 L
.61657 .6325 L
.60978 .63818 L
.60736 .64007 L
.60221 .64387 L
.59669 .64764 L
.59464 .64896 L
.58707 .65351 L
.584 .65521 L
.5795 .65756 L
.57193 .66116 L
.56818 .66278 L
.56435 .66433 L
.55678 .6671 L
.54921 .66948 L
.54612 .67035 L
.54164 .6715 L
.53407 .67316 L
.5265 .67448 L
.51893 .67546 L
.51136 .67612 L
.50379 .67644 L
.49621 .67644 L
.48864 .67612 L
.48107 .67546 L
.4735 .67448 L
.46593 .67316 L
.45836 .6715 L
.45388 .67035 L
.45079 .66948 L
.44322 .6671 L
.43565 .66433 L
.43182 .66278 L
.42807 .66116 L
.4205 .65756 L
.416 .65521 L
.41293 .65351 L
.40536 .64896 L
.40331 .64764 L
.39779 .64387 L
.39264 .64007 L
.39022 .63818 L
.38343 .6325 L
.38265 .63181 L
.37535 .62492 L
.37508 .62465 L
.36819 .61735 L
.3675 .61657 L
.36182 .60978 L
.35993 .60736 L
.35613 .60221 L
.35236 .59668 L
.35104 .59464 L
.34649 .58707 L
.34479 .584 L
.34244 .5795 L
.33884 .57193 L
.33722 .56818 L
.33567 .56435 L
.3329 .55678 L
.33052 .54921 L
.32965 .54612 L
.3285 .54164 L
.32684 .53407 L
.32552 .5265 L
.32454 .51893 L
.32388 .51136 L
.32356 .50379 L
.32356 .49621 L
.32388 .48864 L
.32454 .48107 L
.32552 .4735 L
.32684 .46593 L
.3285 .45836 L
.32965 .45388 L
.33052 .45079 L
.3329 .44322 L
.33567 .43565 L
.33722 .43182 L
.33884 .42807 L
.34244 .4205 L
.34479 .416 L
.34649 .41293 L
.35104 .40536 L
.35236 .40332 L
.35613 .39779 L
.35993 .39264 L
.36182 .39022 L
.3675 .38343 L
.36819 .38265 L
.37508 .37535 L
.37535 .37508 L
.38265 .36819 L
.38343 .3675 L
.39022 .36182 L
.39264 .35993 L
.39779 .35613 L
.40331 .35236 L
.40536 .35104 L
.41293 .34649 L
.416 .34479 L
.4205 .34244 L
.42807 .33884 L
.43182 .33722 L
.43565 .33567 L
.44322 .3329 L
.45079 .33052 L
.45388 .32965 L
F
0 .118 .208 r
.45836 .34287 m
.46593 .34106 L
.4735 .33962 L
.48107 .33855 L
.48864 .33784 L
.49621 .33749 L
.50379 .33749 L
.51136 .33784 L
.51893 .33855 L
.5265 .33962 L
.53407 .34106 L
.54164 .34287 L
.54831 .34479 L
.54921 .34508 L
.55678 .34769 L
.56435 .35073 L
.56802 .35236 L
.57193 .35423 L
.5795 .35822 L
.58249 .35993 L
.58707 .36274 L
.59417 .3675 L
.59464 .36784 L
.60221 .37361 L
.604 .37508 L
.60978 .38012 L
.61247 .38265 L
.61735 .38753 L
.61988 .39022 L
.62492 .396 L
.62639 .39779 L
.63216 .40536 L
.6325 .40583 L
.63726 .41293 L
.64007 .41752 L
.64178 .4205 L
.64577 .42807 L
.64764 .43199 L
.64927 .43565 L
.65231 .44322 L
.65492 .45079 L
.65521 .4517 L
.65713 .45836 L
.65894 .46593 L
.66038 .4735 L
.66145 .48107 L
.66215 .48864 L
.66251 .49621 L
.66251 .50379 L
.66215 .51136 L
.66145 .51893 L
.66038 .5265 L
.65894 .53407 L
.65713 .54164 L
.65521 .5483 L
.65492 .54921 L
.65231 .55678 L
.64927 .56435 L
.64764 .56801 L
.64577 .57193 L
.64178 .5795 L
.64007 .58248 L
.63726 .58707 L
.6325 .59417 L
.63216 .59464 L
.62639 .60221 L
.62492 .604 L
.61988 .60978 L
.61735 .61247 L
.61247 .61735 L
.60978 .61988 L
.604 .62492 L
.60221 .62639 L
.59464 .63216 L
.59417 .6325 L
.58707 .63726 L
.58249 .64007 L
.5795 .64178 L
.57193 .64577 L
.56802 .64764 L
.56435 .64927 L
.55678 .65231 L
.54921 .65492 L
.54831 .65521 L
.54164 .65713 L
.53407 .65894 L
.5265 .66038 L
.51893 .66145 L
.51136 .66216 L
.50379 .66251 L
.49621 .66251 L
.48864 .66216 L
.48107 .66145 L
.4735 .66038 L
.46593 .65894 L
.45836 .65713 L
.45169 .65521 L
.45079 .65492 L
.44322 .65231 L
.43565 .64927 L
.43198 .64764 L
.42807 .64577 L
.4205 .64178 L
.41751 .64007 L
.41293 .63726 L
.40583 .6325 L
.40536 .63216 L
.39779 .62639 L
.396 .62492 L
.39022 .61988 L
.38753 .61735 L
.38265 .61247 L
.38013 .60978 L
.37508 .604 L
.37361 .60221 L
.36784 .59464 L
.3675 .59416 L
.36274 .58707 L
.35993 .58248 L
.35822 .5795 L
.35423 .57193 L
.35236 .56801 L
.35073 .56435 L
.34769 .55678 L
.34508 .54921 L
.34479 .5483 L
.34287 .54164 L
.34106 .53407 L
.33962 .5265 L
.33856 .51893 L
.33785 .51136 L
.33749 .50379 L
.33749 .49621 L
.33785 .48864 L
.33856 .48107 L
.33962 .4735 L
.34106 .46593 L
.34287 .45836 L
.34479 .4517 L
.34508 .45079 L
.34769 .44322 L
.35073 .43565 L
.35236 .43199 L
.35423 .42807 L
.35822 .4205 L
.35993 .41752 L
.36274 .41293 L
.3675 .40584 L
.36784 .40536 L
.37361 .39779 L
.37508 .396 L
.38013 .39022 L
.38265 .38753 L
.38753 .38265 L
.39022 .38012 L
.396 .37508 L
.39779 .37361 L
.40536 .36784 L
.40583 .3675 L
.41293 .36274 L
.41751 .35993 L
.4205 .35822 L
.42807 .35423 L
.43198 .35236 L
.43565 .35073 L
.44322 .34769 L
.45079 .34508 L
.45169 .34479 L
F
0 .093 .19 r
.45836 .35852 m
.46593 .35651 L
.4735 .35492 L
.48107 .35374 L
.48864 .35296 L
.49621 .35257 L
.50379 .35257 L
.51136 .35296 L
.51893 .35374 L
.5265 .35492 L
.53407 .35651 L
.54164 .35852 L
.54618 .35993 L
.54921 .36097 L
.55678 .36389 L
.56435 .3673 L
.56477 .3675 L
.57193 .37125 L
.57838 .37508 L
.5795 .37578 L
.58707 .38097 L
.58932 .38265 L
.59464 .38689 L
.59848 .39022 L
.60221 .39369 L
.60631 .39779 L
.60978 .40152 L
.61311 .40536 L
.61735 .41068 L
.61903 .41293 L
.62422 .4205 L
.62492 .42162 L
.62875 .42807 L
.6325 .43523 L
.63269 .43565 L
.63611 .44322 L
.63902 .45079 L
.64007 .45383 L
.64148 .45836 L
.64349 .46593 L
.64508 .4735 L
.64626 .48107 L
.64704 .48864 L
.64743 .49621 L
.64743 .50379 L
.64704 .51136 L
.64626 .51893 L
.64508 .5265 L
.64349 .53407 L
.64148 .54164 L
.64007 .54617 L
.63902 .54921 L
.63611 .55678 L
.63269 .56435 L
.6325 .56477 L
.62875 .57193 L
.62492 .57838 L
.62422 .5795 L
.61903 .58707 L
.61735 .58932 L
.61311 .59464 L
.60978 .59848 L
.60631 .60221 L
.60221 .60631 L
.59848 .60978 L
.59464 .61311 L
.58932 .61735 L
.58707 .61903 L
.5795 .62422 L
.57838 .62492 L
.57193 .62875 L
.56477 .6325 L
.56435 .6327 L
.55678 .63611 L
.54921 .63903 L
.54618 .64007 L
.54164 .64148 L
.53407 .64349 L
.5265 .64508 L
.51893 .64626 L
.51136 .64704 L
.50379 .64743 L
.49621 .64743 L
.48864 .64704 L
.48107 .64626 L
.4735 .64508 L
.46593 .64349 L
.45836 .64148 L
.45382 .64007 L
.45079 .63903 L
.44322 .63611 L
.43565 .6327 L
.43523 .6325 L
.42807 .62875 L
.42162 .62492 L
.4205 .62422 L
.41293 .61903 L
.41068 .61735 L
.40536 .61311 L
.40152 .60978 L
.39779 .60631 L
.39369 .60221 L
.39022 .59848 L
.38689 .59464 L
.38265 .58932 L
.38097 .58707 L
.37578 .5795 L
.37508 .57838 L
.37125 .57193 L
.3675 .56476 L
.36731 .56435 L
.36389 .55678 L
.36098 .54921 L
.35993 .54617 L
.35852 .54164 L
.35651 .53407 L
.35492 .5265 L
.35374 .51893 L
.35296 .51136 L
.35257 .50379 L
.35257 .49621 L
.35296 .48864 L
.35374 .48107 L
.35492 .4735 L
.35651 .46593 L
.35852 .45836 L
.35993 .45383 L
.36098 .45079 L
.36389 .44322 L
.36731 .43565 L
.3675 .43524 L
.37125 .42807 L
.37508 .42162 L
.37578 .4205 L
.38097 .41293 L
.38265 .41068 L
.38689 .40536 L
.39022 .40152 L
.39369 .39779 L
.39779 .39369 L
.40152 .39022 L
.40536 .38689 L
.41068 .38265 L
.41293 .38097 L
.4205 .37578 L
.42162 .37508 L
.42807 .37125 L
.43523 .3675 L
.43565 .3673 L
.44322 .36389 L
.45079 .36097 L
.45382 .35993 L
F
0 .071 .172 r
.46593 .37365 m
.4735 .37184 L
.48107 .37051 L
.48864 .36963 L
.49621 .36919 L
.50379 .36919 L
.51136 .36963 L
.51893 .37051 L
.5265 .37184 L
.53407 .37365 L
.539 .37508 L
.54164 .37594 L
.54921 .37874 L
.55678 .3821 L
.55791 .38265 L
.56435 .38605 L
.57123 .39022 L
.57193 .39067 L
.5795 .39605 L
.58172 .39779 L
.58707 .4023 L
.59038 .40536 L
.59464 .40962 L
.5977 .41293 L
.60221 .41828 L
.60395 .4205 L
.60932 .42807 L
.60978 .42877 L
.61395 .43565 L
.61735 .44209 L
.6179 .44322 L
.62126 .45079 L
.62406 .45836 L
.62492 .46101 L
.62635 .46593 L
.62815 .4735 L
.62949 .48107 L
.63037 .48864 L
.63081 .49621 L
.63081 .50379 L
.63037 .51136 L
.62949 .51893 L
.62815 .5265 L
.62635 .53407 L
.62492 .53899 L
.62406 .54164 L
.62126 .54921 L
.6179 .55678 L
.61735 .55791 L
.61395 .56435 L
.60978 .57123 L
.60932 .57193 L
.60395 .5795 L
.60221 .58172 L
.5977 .58707 L
.59464 .59038 L
.59038 .59464 L
.58707 .5977 L
.58172 .60221 L
.5795 .60395 L
.57193 .60933 L
.57123 .60978 L
.56435 .61395 L
.55791 .61735 L
.55678 .6179 L
.54921 .62126 L
.54164 .62406 L
.539 .62492 L
.53407 .62635 L
.5265 .62816 L
.51893 .62949 L
.51136 .63037 L
.50379 .63081 L
.49621 .63081 L
.48864 .63037 L
.48107 .62949 L
.4735 .62816 L
.46593 .62635 L
.461 .62492 L
.45836 .62406 L
.45079 .62126 L
.44322 .6179 L
.44209 .61735 L
.43565 .61395 L
.42877 .60978 L
.42807 .60933 L
.4205 .60395 L
.41828 .60221 L
.41293 .5977 L
.40962 .59464 L
.40536 .59038 L
.4023 .58707 L
.39779 .58172 L
.39605 .5795 L
.39068 .57193 L
.39022 .57123 L
.38605 .56435 L
.38265 .55791 L
.3821 .55678 L
.37874 .54921 L
.37594 .54164 L
.37508 .53899 L
.37365 .53407 L
.37185 .5265 L
.37051 .51893 L
.36963 .51136 L
.36919 .50379 L
.36919 .49621 L
.36963 .48864 L
.37051 .48107 L
.37185 .4735 L
.37365 .46593 L
.37508 .46101 L
.37594 .45836 L
.37874 .45079 L
.3821 .44322 L
.38265 .44209 L
.38605 .43565 L
.39022 .42877 L
.39068 .42807 L
.39605 .4205 L
.39779 .41828 L
.4023 .41293 L
.40536 .40962 L
.40962 .40536 L
.41293 .4023 L
.41828 .39779 L
.4205 .39605 L
.42807 .39067 L
.42877 .39022 L
.43565 .38605 L
.44209 .38265 L
.44322 .3821 L
.45079 .37874 L
.45836 .37594 L
.461 .37508 L
F
0 .051 .154 r
.48107 .38959 m
.48864 .38856 L
.49621 .38805 L
.50379 .38805 L
.51136 .38856 L
.51893 .38959 L
.52238 .39022 L
.5265 .39116 L
.53407 .39329 L
.54164 .39601 L
.54585 .39779 L
.54921 .39937 L
.55678 .40344 L
.55993 .40536 L
.56435 .40831 L
.57048 .41293 L
.57193 .41413 L
.57892 .4205 L
.5795 .42108 L
.58587 .42807 L
.58707 .42952 L
.59168 .43565 L
.59464 .44007 L
.59656 .44322 L
.60063 .45079 L
.60221 .45416 L
.60399 .45836 L
.60671 .46593 L
.60884 .4735 L
.60978 .47764 L
.6104 .48107 L
.61144 .48864 L
.61195 .49621 L
.61195 .50379 L
.61144 .51136 L
.6104 .51893 L
.60978 .52236 L
.60884 .5265 L
.60671 .53407 L
.60399 .54164 L
.60221 .54584 L
.60063 .54921 L
.59656 .55678 L
.59464 .55993 L
.59168 .56435 L
.58707 .57048 L
.58587 .57193 L
.5795 .57892 L
.57892 .5795 L
.57193 .58587 L
.57048 .58707 L
.56435 .59169 L
.55993 .59464 L
.55678 .59656 L
.54921 .60063 L
.54585 .60221 L
.54164 .60399 L
.53407 .60671 L
.5265 .60884 L
.52238 .60978 L
.51893 .61041 L
.51136 .61144 L
.50379 .61195 L
.49621 .61195 L
.48864 .61144 L
.48107 .61041 L
.47762 .60978 L
.4735 .60884 L
.46593 .60671 L
.45836 .60399 L
.45415 .60221 L
.45079 .60063 L
.44322 .59656 L
.44007 .59464 L
.43565 .59169 L
.42952 .58707 L
.42807 .58587 L
.42108 .5795 L
.4205 .57892 L
.41413 .57193 L
.41293 .57048 L
.40832 .56435 L
.40536 .55993 L
.40344 .55678 L
.39937 .54921 L
.39779 .54584 L
.39601 .54164 L
.39329 .53407 L
.39116 .5265 L
.39022 .52236 L
.3896 .51893 L
.38856 .51136 L
.38805 .50379 L
.38805 .49621 L
.38856 .48864 L
.3896 .48107 L
.39022 .47764 L
.39116 .4735 L
.39329 .46593 L
.39601 .45836 L
.39779 .45416 L
.39937 .45079 L
.40344 .44322 L
.40536 .44007 L
.40832 .43565 L
.41293 .42952 L
.41413 .42807 L
.4205 .42108 L
.42108 .4205 L
.42807 .41413 L
.42952 .41293 L
.43565 .40831 L
.44007 .40536 L
.44322 .40344 L
.45079 .39937 L
.45415 .39779 L
.45836 .39601 L
.46593 .39329 L
.4735 .39116 L
.47762 .39022 L
F
0 .035 .136 r
.48107 .4125 m
.48864 .41119 L
.49621 .41055 L
.50379 .41055 L
.51136 .41119 L
.51893 .4125 L
.52092 .41293 L
.5265 .41448 L
.53407 .41721 L
.54118 .4205 L
.54164 .42075 L
.54921 .42521 L
.55331 .42807 L
.55678 .43078 L
.56224 .43565 L
.56435 .43776 L
.56922 .44322 L
.57193 .44669 L
.57479 .45079 L
.57925 .45836 L
.5795 .45883 L
.58279 .46593 L
.58551 .4735 L
.58707 .47909 L
.5875 .48107 L
.5888 .48864 L
.58945 .49621 L
.58945 .50379 L
.5888 .51136 L
.5875 .51893 L
.58707 .52091 L
.58551 .5265 L
.58279 .53407 L
.5795 .54117 L
.57925 .54164 L
.57479 .54921 L
.57193 .55331 L
.56922 .55678 L
.56435 .56224 L
.56224 .56435 L
.55678 .56922 L
.55331 .57193 L
.54921 .57479 L
.54164 .57925 L
.54118 .5795 L
.53407 .58279 L
.5265 .58552 L
.52092 .58707 L
.51893 .5875 L
.51136 .58881 L
.50379 .58945 L
.49621 .58945 L
.48864 .58881 L
.48107 .5875 L
.47908 .58707 L
.4735 .58552 L
.46593 .58279 L
.45882 .5795 L
.45836 .57925 L
.45079 .57479 L
.44669 .57193 L
.44322 .56922 L
.43776 .56435 L
.43565 .56224 L
.43078 .55678 L
.42807 .55331 L
.42521 .54921 L
.42075 .54164 L
.4205 .54117 L
.41721 .53407 L
.41449 .5265 L
.41293 .5209 L
.4125 .51893 L
.4112 .51136 L
.41055 .50379 L
.41055 .49621 L
.4112 .48864 L
.4125 .48107 L
.41293 .4791 L
.41449 .4735 L
.41721 .46593 L
.4205 .45883 L
.42075 .45836 L
.42521 .45079 L
.42807 .44669 L
.43078 .44322 L
.43565 .43776 L
.43776 .43565 L
.44322 .43078 L
.44669 .42807 L
.45079 .42521 L
.45836 .42075 L
.45882 .4205 L
.46593 .41721 L
.4735 .41448 L
.47908 .41293 L
F
0 .021 .118 r
.48864 .44171 m
.49621 .44074 L
.50379 .44074 L
.51136 .44171 L
.51768 .44322 L
.51893 .44371 L
.5265 .44685 L
.53325 .45079 L
.53407 .45136 L
.54164 .45766 L
.54234 .45836 L
.54864 .46593 L
.54921 .46676 L
.55315 .4735 L
.55628 .48107 L
.55678 .48232 L
.55829 .48864 L
.55926 .49621 L
.55926 .50379 L
.55829 .51136 L
.55678 .51768 L
.55628 .51893 L
.55315 .5265 L
.54921 .53324 L
.54864 .53407 L
.54234 .54164 L
.54164 .54234 L
.53407 .54864 L
.53325 .54921 L
.5265 .55315 L
.51893 .55629 L
.51768 .55678 L
.51136 .55829 L
.50379 .55926 L
.49621 .55926 L
.48864 .55829 L
.48232 .55678 L
.48107 .55629 L
.4735 .55315 L
.46675 .54921 L
.46593 .54864 L
.45836 .54233 L
.45767 .54164 L
.45136 .53407 L
.45079 .53324 L
.44685 .5265 L
.44372 .51893 L
.44322 .51768 L
.44171 .51136 L
.44074 .50379 L
.44074 .49621 L
.44171 .48864 L
.44322 .48232 L
.44372 .48107 L
.44685 .4735 L
.45079 .46676 L
.45136 .46593 L
.45767 .45836 L
.45836 .45767 L
.46593 .45136 L
.46675 .45079 L
.4735 .44685 L
.48107 .44371 L
.48232 .44322 L
F
.82 .64 0 r
.98077 .478 m
.98054 .4735 L
.98006 .46593 L
.97946 .45836 L
.97874 .45079 L
.9779 .44322 L
.97694 .43565 L
.97586 .42807 L
.97465 .4205 L
.97332 .41293 L
.9732 .41229 L
.97186 .40536 L
.97028 .39779 L
.96856 .39022 L
.96672 .38265 L
.96563 .37838 L
.96475 .37508 L
.96265 .3675 L
.96041 .35993 L
.95806 .35243 L
.95803 .35236 L
.95552 .34479 L
.95287 .33722 L
.95048 .33074 L
.95007 .32965 L
.94713 .32208 L
.94404 .31451 L
.94291 .31184 L
.9408 .30694 L
.9374 .29936 L
.93534 .29495 L
.93384 .29179 L
.93012 .28422 L
.92777 .2796 L
.92624 .27665 L
.92218 .26908 L
.9202 .2655 L
.91794 .26151 L
.91353 .25394 L
.91263 .25244 L
.90892 .24637 L
.90506 .24024 L
.90412 .23879 L
.89912 .23122 L
.89749 .22881 L
.89392 .22365 L
.88992 .21804 L
.88849 .21608 L
.88284 .20851 L
.88234 .20786 L
.87695 .20094 L
.87477 .19822 L
.87081 .19337 L
.8672 .18906 L
.86441 .1858 L
.85963 .18034 L
.85774 .17823 L
.85206 .17202 L
.85078 .17065 L
.84449 .16409 L
.84351 .16308 L
.83692 .1565 L
.83591 .15551 L
.82935 .14924 L
.82796 .14794 L
.82177 .14228 L
.81963 .14037 L
.8142 .13562 L
.8109 .1328 L
.80663 .12923 L
.80173 .12523 L
.79906 .1231 L
.79207 .11766 L
.79149 .11721 L
.78392 .11157 L
.78188 .11008 L
.77635 .10615 L
.77109 .10251 L
.76878 .10094 L
.76121 .09595 L
.75964 .09494 L
.75363 .09116 L
.74743 .08737 L
.74606 .08656 L
.73849 .08214 L
.73434 .0798 L
.73092 .07791 L
.72335 .07386 L
.72021 .07223 L
.71578 .06998 L
.70821 .06626 L
.70483 .06466 L
.70064 .06271 L
.69306 .05932 L
.68789 .05709 L
.68549 .05608 L
.67792 .05299 L
.67035 .05005 L
.66893 .04952 L
.66278 .04726 L
.65521 .0446 L
.64764 .04209 L
.64717 .04194 L
.64007 .03972 L
.6325 .03749 L
.62492 .03538 L
.6211 .03437 L
.61735 .03341 L
.60978 .03158 L
.60221 .02987 L
.59464 .02828 L
.58707 .02683 L
.58693 .0268 L
.5795 .0255 L
.57193 .02429 L
.56435 .02321 L
.55678 .02225 L
.54921 .02141 L
.54164 .02069 L
.53407 .02009 L
.5265 .01961 L
.51893 .01926 L
.51843 .01923 L
.98077 .01923 L
F
.98077 .522 m
.98054 .5265 L
.98006 .53407 L
.97946 .54164 L
.97874 .54921 L
.9779 .55678 L
.97694 .56435 L
.97586 .57193 L
.97465 .5795 L
.97332 .58707 L
.9732 .58771 L
.97186 .59464 L
.97028 .60221 L
.96856 .60978 L
.96672 .61735 L
.96563 .62162 L
.96475 .62492 L
.96265 .6325 L
.96041 .64007 L
.95806 .64757 L
.95803 .64764 L
.95552 .65521 L
.95287 .66278 L
.95048 .66926 L
.95007 .67035 L
.94713 .67792 L
.94404 .68549 L
.94291 .68816 L
.9408 .69306 L
.9374 .70064 L
.93534 .70505 L
.93384 .70821 L
.93012 .71578 L
.92777 .7204 L
.92624 .72335 L
.92218 .73092 L
.9202 .7345 L
.91794 .73849 L
.91353 .74606 L
.91263 .74756 L
.90892 .75363 L
.90506 .75976 L
.90412 .76121 L
.89912 .76878 L
.89749 .77119 L
.89392 .77635 L
.88992 .78196 L
.88849 .78392 L
.88284 .79149 L
.88234 .79214 L
.87695 .79906 L
.87477 .80178 L
.87081 .80663 L
.8672 .81094 L
.86441 .8142 L
.85963 .81966 L
.85774 .82177 L
.85206 .82798 L
.85078 .82935 L
.84449 .83591 L
.84351 .83692 L
.83692 .8435 L
.83591 .84449 L
.82935 .85076 L
.82796 .85206 L
.82177 .85772 L
.81963 .85963 L
.8142 .86438 L
.8109 .8672 L
.80663 .87077 L
.80173 .87477 L
.79906 .8769 L
.79207 .88234 L
.79149 .88279 L
.78392 .88843 L
.78188 .88992 L
.77635 .89385 L
.77109 .89749 L
.76878 .89906 L
.76121 .90405 L
.75964 .90506 L
.75363 .90884 L
.74743 .91263 L
.74606 .91344 L
.73849 .91786 L
.73434 .9202 L
.73092 .92209 L
.72335 .92614 L
.72021 .92777 L
.71578 .93002 L
.70821 .93374 L
.70483 .93534 L
.70064 .93729 L
.69306 .94068 L
.68789 .94291 L
.68549 .94392 L
.67792 .94701 L
.67035 .94995 L
.66893 .95048 L
.66278 .95274 L
.65521 .9554 L
.64764 .95791 L
.64717 .95806 L
.64007 .96028 L
.6325 .96251 L
.62492 .96462 L
.6211 .96563 L
.61735 .96659 L
.60978 .96842 L
.60221 .97013 L
.59464 .97172 L
.58707 .97317 L
.58693 .9732 L
.5795 .9745 L
.57193 .97571 L
.56435 .97679 L
.55678 .97775 L
.54921 .97859 L
.54164 .97931 L
.53407 .97991 L
.5265 .98039 L
.51893 .98074 L
.51843 .98077 L
.98077 .98077 L
F
.838 .588 0 r
.98077 .39942 m
.98042 .39779 L
.97875 .39022 L
.97695 .38265 L
.97502 .37508 L
.9732 .36836 L
.97296 .3675 L
.97077 .35993 L
.96845 .35236 L
.96599 .34479 L
.96563 .3437 L
.9634 .33722 L
.96067 .32965 L
.95806 .32276 L
.95779 .32208 L
.95477 .31451 L
.95161 .30694 L
.95048 .30433 L
.94829 .29936 L
.94482 .29179 L
.94291 .28777 L
.9412 .28422 L
.93741 .27665 L
.93534 .27266 L
.93345 .26908 L
.92933 .26151 L
.92777 .25872 L
.92503 .25394 L
.92055 .24637 L
.9202 .24578 L
.91589 .23879 L
.91263 .23368 L
.91103 .23122 L
.90598 .22365 L
.90506 .22231 L
.90071 .21608 L
.89749 .21158 L
.89524 .20851 L
.88992 .20144 L
.88953 .20094 L
.8836 .19337 L
.88234 .19181 L
.87742 .1858 L
.87477 .18265 L
.87098 .17823 L
.8672 .17393 L
.86427 .17065 L
.85963 .1656 L
.85727 .16308 L
.85206 .15764 L
.84997 .15551 L
.84449 .15003 L
.84235 .14794 L
.83692 .14274 L
.83438 .14037 L
.82935 .13575 L
.82605 .1328 L
.82177 .12905 L
.81731 .12523 L
.8142 .12262 L
.80814 .11766 L
.80663 .11645 L
.79906 .11052 L
.7985 .11008 L
.79149 .10482 L
.78833 .10251 L
.78392 .09935 L
.77759 .09494 L
.77635 .09409 L
.76878 .08904 L
.7662 .08737 L
.76121 .08419 L
.75408 .0798 L
.75363 .07953 L
.74606 .07506 L
.74111 .07223 L
.73849 .07077 L
.73092 .06665 L
.72715 .06466 L
.72335 .0627 L
.71578 .05891 L
.712 .05709 L
.70821 .05529 L
.70064 .05183 L
.69539 .04952 L
.69306 .04851 L
.68549 .04535 L
.67792 .04234 L
.67691 .04194 L
.67035 .03946 L
.66278 .03674 L
.65589 .03437 L
.65521 .03414 L
.64764 .03169 L
.64007 .02937 L
.6325 .02718 L
.63113 .0268 L
.62492 .02513 L
.61735 .0232 L
.60978 .0214 L
.60221 .01973 L
.59985 .01923 L
.98077 .01923 L
F
.98077 .60058 m
.98042 .60221 L
.97875 .60978 L
.97695 .61735 L
.97502 .62492 L
.9732 .63164 L
.97296 .6325 L
.97077 .64007 L
.96845 .64764 L
.96599 .65521 L
.96563 .6563 L
.9634 .66278 L
.96067 .67035 L
.95806 .67724 L
.95779 .67792 L
.95477 .68549 L
.95161 .69306 L
.95048 .69567 L
.94829 .70064 L
.94482 .70821 L
.94291 .71223 L
.9412 .71578 L
.93741 .72335 L
.93534 .72734 L
.93345 .73092 L
.92933 .73849 L
.92777 .74128 L
.92503 .74606 L
.92055 .75363 L
.9202 .75422 L
.91589 .76121 L
.91263 .76632 L
.91103 .76878 L
.90598 .77635 L
.90506 .77769 L
.90071 .78392 L
.89749 .78842 L
.89524 .79149 L
.88992 .79856 L
.88953 .79906 L
.8836 .80663 L
.88234 .80819 L
.87742 .8142 L
.87477 .81735 L
.87098 .82177 L
.8672 .82607 L
.86427 .82935 L
.85963 .8344 L
.85727 .83692 L
.85206 .84236 L
.84997 .84449 L
.84449 .84997 L
.84235 .85206 L
.83692 .85726 L
.83438 .85963 L
.82935 .86425 L
.82605 .8672 L
.82177 .87095 L
.81731 .87477 L
.8142 .87738 L
.80814 .88234 L
.80663 .88355 L
.79906 .88948 L
.7985 .88992 L
.79149 .89518 L
.78833 .89749 L
.78392 .90065 L
.77759 .90506 L
.77635 .90591 L
.76878 .91096 L
.7662 .91263 L
.76121 .91581 L
.75408 .9202 L
.75363 .92047 L
.74606 .92494 L
.74111 .92777 L
.73849 .92923 L
.73092 .93335 L
.72715 .93534 L
.72335 .9373 L
.71578 .94109 L
.712 .94291 L
.70821 .94471 L
.70064 .94817 L
.69539 .95048 L
.69306 .95149 L
.68549 .95465 L
.67792 .95766 L
.67691 .95806 L
.67035 .96054 L
.66278 .96326 L
.65589 .96563 L
.65521 .96586 L
.64764 .96831 L
.64007 .97063 L
.6325 .97282 L
.63113 .9732 L
.62492 .97487 L
.61735 .9768 L
.60978 .9786 L
.60221 .98027 L
.59985 .98077 L
.98077 .98077 L
F
.856 .534 0 r
.98077 .35753 m
.97921 .35236 L
.9768 .34479 L
.97427 .33722 L
.9732 .33413 L
.9716 .32965 L
.96879 .32208 L
.96585 .31451 L
.96563 .31396 L
.96276 .30694 L
.95952 .29936 L
.95806 .29604 L
.95614 .29179 L
.9526 .28422 L
.95048 .27984 L
.94891 .27665 L
.94506 .26908 L
.94291 .265 L
.94104 .26151 L
.93686 .25394 L
.93534 .25126 L
.9325 .24637 L
.92797 .23879 L
.92777 .23847 L
.92325 .23122 L
.9202 .22648 L
.91834 .22365 L
.91324 .21608 L
.91263 .2152 L
.90793 .20851 L
.90506 .20454 L
.90241 .20094 L
.89749 .19444 L
.89666 .19337 L
.89069 .1858 L
.88992 .18484 L
.88447 .17823 L
.88234 .1757 L
.878 .17065 L
.87477 .16699 L
.87126 .16308 L
.8672 .15867 L
.86424 .15551 L
.85963 .1507 L
.85692 .14794 L
.85206 .14308 L
.84929 .14037 L
.84449 .13577 L
.84132 .1328 L
.83692 .12876 L
.83298 .12523 L
.82935 .12203 L
.82425 .11766 L
.82177 .11557 L
.8151 .11008 L
.8142 .10936 L
.80663 .10339 L
.80549 .10251 L
.79906 .09766 L
.79537 .09494 L
.79149 .09214 L
.78469 .08737 L
.78392 .08684 L
.77635 .08174 L
.77339 .0798 L
.76878 .07684 L
.76138 .07223 L
.76121 .07212 L
.75363 .06759 L
.74856 .06466 L
.74606 .06324 L
.73849 .05906 L
.7348 .05709 L
.73092 .05505 L
.72335 .05121 L
.71992 .04952 L
.71578 .04752 L
.70821 .04399 L
.70367 .04194 L
.70064 .04061 L
.69306 .03738 L
.68571 .03437 L
.68549 .03429 L
.67792 .03134 L
.67035 .02854 L
.66546 .0268 L
.66278 .02587 L
.65521 .02334 L
.64764 .02094 L
.64196 .01923 L
.98077 .01923 L
F
.98077 .64247 m
.97921 .64764 L
.9768 .65521 L
.97427 .66278 L
.9732 .66587 L
.9716 .67035 L
.96879 .67792 L
.96585 .68549 L
.96563 .68604 L
.96276 .69306 L
.95952 .70064 L
.95806 .70396 L
.95614 .70821 L
.9526 .71578 L
.95048 .72016 L
.94891 .72335 L
.94506 .73092 L
.94291 .735 L
.94104 .73849 L
.93686 .74606 L
.93534 .74874 L
.9325 .75363 L
.92797 .76121 L
.92777 .76153 L
.92325 .76878 L
.9202 .77352 L
.91834 .77635 L
.91324 .78392 L
.91263 .7848 L
.90793 .79149 L
.90506 .79546 L
.90241 .79906 L
.89749 .80556 L
.89666 .80663 L
.89069 .8142 L
.88992 .81516 L
.88447 .82177 L
.88234 .8243 L
.878 .82935 L
.87477 .83301 L
.87126 .83692 L
.8672 .84133 L
.86424 .84449 L
.85963 .8493 L
.85692 .85206 L
.85206 .85692 L
.84929 .85963 L
.84449 .86423 L
.84132 .8672 L
.83692 .87124 L
.83298 .87477 L
.82935 .87797 L
.82425 .88234 L
.82177 .88443 L
.8151 .88992 L
.8142 .89064 L
.80663 .89661 L
.80549 .89749 L
.79906 .90234 L
.79537 .90506 L
.79149 .90786 L
.78469 .91263 L
.78392 .91316 L
.77635 .91826 L
.77339 .9202 L
.76878 .92316 L
.76138 .92777 L
.76121 .92788 L
.75363 .93241 L
.74856 .93534 L
.74606 .93676 L
.73849 .94094 L
.7348 .94291 L
.73092 .94495 L
.72335 .94879 L
.71992 .95048 L
.71578 .95248 L
.70821 .95601 L
.70367 .95806 L
.70064 .95939 L
.69306 .96262 L
.68571 .96563 L
.68549 .96571 L
.67792 .96866 L
.67035 .97146 L
.66546 .9732 L
.66278 .97413 L
.65521 .97666 L
.64764 .97906 L
.64196 .98077 L
.98077 .98077 L
F
.874 .477 0 r
.98077 .32355 m
.98023 .32208 L
.97735 .31451 L
.97433 .30694 L
.9732 .30417 L
.97118 .29936 L
.96788 .29179 L
.96563 .28681 L
.96443 .28422 L
.96083 .27665 L
.95806 .27101 L
.95708 .26908 L
.95318 .26151 L
.95048 .25647 L
.94911 .25394 L
.94487 .24637 L
.94291 .24297 L
.94046 .23879 L
.93588 .23122 L
.93534 .23036 L
.93111 .22365 L
.92777 .21851 L
.92616 .21608 L
.92101 .20851 L
.9202 .20734 L
.91567 .20094 L
.91263 .19677 L
.91011 .19337 L
.90506 .18673 L
.90433 .1858 L
.89833 .17823 L
.89749 .17719 L
.89209 .17065 L
.88992 .16809 L
.88559 .16308 L
.88234 .1594 L
.87884 .15551 L
.87477 .15109 L
.87181 .14794 L
.8672 .14314 L
.86449 .14037 L
.85963 .13552 L
.85685 .1328 L
.85206 .1282 L
.84889 .12523 L
.84449 .12118 L
.84057 .11766 L
.83692 .11444 L
.83187 .11008 L
.82935 .10796 L
.82275 .10251 L
.82177 .10172 L
.8142 .09573 L
.81319 .09494 L
.80663 .08996 L
.80314 .08737 L
.79906 .08441 L
.79255 .0798 L
.79149 .07906 L
.78392 .07392 L
.78136 .07223 L
.77635 .06898 L
.76949 .06466 L
.76878 .06422 L
.76121 .05964 L
.75685 .05709 L
.75363 .05524 L
.74606 .05101 L
.74332 .04952 L
.73849 .04694 L
.73092 .04304 L
.72874 .04194 L
.72335 .03929 L
.71578 .0357 L
.7129 .03437 L
.70821 .03226 L
.70064 .02896 L
.69549 .0268 L
.69306 .02581 L
.68549 .0228 L
.67792 .01993 L
.67604 .01923 L
.98077 .01923 L
F
.98077 .67645 m
.98023 .67792 L
.97735 .68549 L
.97433 .69306 L
.9732 .69583 L
.97118 .70064 L
.96788 .70821 L
.96563 .71319 L
.96443 .71578 L
.96083 .72335 L
.95806 .72899 L
.95708 .73092 L
.95318 .73849 L
.95048 .74353 L
.94911 .74606 L
.94487 .75363 L
.94291 .75703 L
.94046 .76121 L
.93588 .76878 L
.93534 .76964 L
.93111 .77635 L
.92777 .78149 L
.92616 .78392 L
.92101 .79149 L
.9202 .79266 L
.91567 .79906 L
.91263 .80323 L
.91011 .80663 L
.90506 .81327 L
.90433 .8142 L
.89833 .82177 L
.89749 .82281 L
.89209 .82935 L
.88992 .83191 L
.88559 .83692 L
.88234 .8406 L
.87884 .84449 L
.87477 .84891 L
.87181 .85206 L
.8672 .85686 L
.86449 .85963 L
.85963 .86448 L
.85685 .8672 L
.85206 .8718 L
.84889 .87477 L
.84449 .87882 L
.84057 .88234 L
.83692 .88556 L
.83187 .88992 L
.82935 .89204 L
.82275 .89749 L
.82177 .89828 L
.8142 .90427 L
.81319 .90506 L
.80663 .91004 L
.80314 .91263 L
.79906 .91559 L
.79255 .9202 L
.79149 .92094 L
.78392 .92608 L
.78136 .92777 L
.77635 .93102 L
.76949 .93534 L
.76878 .93578 L
.76121 .94036 L
.75685 .94291 L
.75363 .94476 L
.74606 .94899 L
.74332 .95048 L
.73849 .95306 L
.73092 .95696 L
.72874 .95806 L
.72335 .96071 L
.71578 .9643 L
.7129 .96563 L
.70821 .96774 L
.70064 .97104 L
.69549 .9732 L
.69306 .97419 L
.68549 .9772 L
.67792 .98007 L
.67604 .98077 L
.98077 .98077 L
F
.892 .417 0 r
.98077 .29318 m
.98017 .29179 L
.97681 .28422 L
.97331 .27665 L
.9732 .27641 L
.96966 .26908 L
.96586 .26151 L
.96563 .26106 L
.9619 .25394 L
.95806 .24686 L
.95778 .24637 L
.9535 .23879 L
.95048 .23363 L
.94905 .23122 L
.94443 .22365 L
.94291 .22124 L
.93962 .21608 L
.93534 .20956 L
.93464 .20851 L
.92946 .20094 L
.92777 .19853 L
.92408 .19337 L
.9202 .18808 L
.9185 .1858 L
.9127 .17823 L
.91263 .17814 L
.90668 .17065 L
.90506 .16867 L
.90042 .16308 L
.89749 .15963 L
.89392 .15551 L
.88992 .15099 L
.88716 .14794 L
.88234 .14272 L
.88014 .14037 L
.87477 .13479 L
.87282 .1328 L
.8672 .12718 L
.86521 .12523 L
.85963 .11988 L
.85727 .11766 L
.85206 .11286 L
.84898 .11008 L
.84449 .10611 L
.84033 .10251 L
.83692 .09962 L
.83127 .09494 L
.82935 .09338 L
.82179 .08737 L
.82177 .08736 L
.8142 .08157 L
.81183 .0798 L
.80663 .076 L
.80135 .07223 L
.79906 .07063 L
.79149 .06545 L
.7903 .06466 L
.78392 .06047 L
.7786 .05709 L
.77635 .05568 L
.76878 .05106 L
.76618 .04952 L
.76121 .04662 L
.75363 .04234 L
.75292 .04194 L
.74606 .03823 L
.73869 .03437 L
.73849 .03427 L
.73092 .03048 L
.72335 .02683 L
.72329 .0268 L
.71578 .02333 L
.70821 .01998 L
.70648 .01923 L
.98077 .01923 L
F
.98077 .70682 m
.98017 .70821 L
.97681 .71578 L
.97331 .72335 L
.9732 .72359 L
.96966 .73092 L
.96586 .73849 L
.96563 .73894 L
.9619 .74606 L
.95806 .75314 L
.95778 .75363 L
.9535 .76121 L
.95048 .76637 L
.94905 .76878 L
.94443 .77635 L
.94291 .77876 L
.93962 .78392 L
.93534 .79044 L
.93464 .79149 L
.92946 .79906 L
.92777 .80147 L
.92408 .80663 L
.9202 .81192 L
.9185 .8142 L
.9127 .82177 L
.91263 .82186 L
.90668 .82935 L
.90506 .83133 L
.90042 .83692 L
.89749 .84037 L
.89392 .84449 L
.88992 .84901 L
.88716 .85206 L
.88234 .85728 L
.88014 .85963 L
.87477 .86521 L
.87282 .8672 L
.8672 .87282 L
.86521 .87477 L
.85963 .88012 L
.85727 .88234 L
.85206 .88714 L
.84898 .88992 L
.84449 .89389 L
.84033 .89749 L
.83692 .90038 L
.83127 .90506 L
.82935 .90662 L
.82179 .91263 L
.82177 .91264 L
.8142 .91843 L
.81183 .9202 L
.80663 .924 L
.80135 .92777 L
.79906 .92937 L
.79149 .93455 L
.7903 .93534 L
.78392 .93953 L
.7786 .94291 L
.77635 .94432 L
.76878 .94894 L
.76618 .95048 L
.76121 .95338 L
.75363 .95766 L
.75292 .95806 L
.74606 .96177 L
.73869 .96563 L
.73849 .96573 L
.73092 .96952 L
.72335 .97317 L
.72329 .9732 L
.71578 .97667 L
.70821 .98002 L
.70648 .98077 L
.98077 .98077 L
F
.91 .355 0 r
.98077 .26453 m
.97928 .26151 L
.97543 .25394 L
.9732 .24968 L
.97143 .24637 L
.96727 .23879 L
.96563 .23587 L
.96296 .23122 L
.95847 .22365 L
.95806 .22296 L
.95382 .21608 L
.95048 .21082 L
.94899 .20851 L
.94398 .20094 L
.94291 .19937 L
.93878 .19337 L
.93534 .18851 L
.93338 .1858 L
.92779 .17823 L
.92777 .1782 L
.92198 .17065 L
.9202 .16839 L
.91596 .16308 L
.91263 .15902 L
.9097 .15551 L
.90506 .15007 L
.90321 .14794 L
.89749 .1415 L
.89647 .14037 L
.88992 .13328 L
.88946 .1328 L
.88234 .1254 L
.88217 .12523 L
.87477 .11783 L
.87459 .11766 L
.8672 .11056 L
.8667 .11008 L
.85963 .10356 L
.85847 .10251 L
.85206 .09683 L
.84989 .09494 L
.84449 .09034 L
.84092 .08737 L
.83692 .0841 L
.83153 .0798 L
.82935 .07808 L
.82177 .07229 L
.8217 .07223 L
.8142 .0667 L
.81137 .06466 L
.80663 .06131 L
.80049 .05709 L
.79906 .05612 L
.79149 .05112 L
.78901 .04952 L
.78392 .04629 L
.77684 .04194 L
.77635 .04164 L
.76878 .03717 L
.7639 .03437 L
.76121 .03286 L
.75363 .02871 L
.75006 .0268 L
.74606 .02471 L
.73849 .02087 L
.73517 .01923 L
.98077 .01923 L
F
.98077 .73547 m
.97928 .73849 L
.97543 .74606 L
.9732 .75032 L
.97143 .75363 L
.96727 .76121 L
.96563 .76413 L
.96296 .76878 L
.95847 .77635 L
.95806 .77704 L
.95382 .78392 L
.95048 .78918 L
.94899 .79149 L
.94398 .79906 L
.94291 .80063 L
.93878 .80663 L
.93534 .81149 L
.93338 .8142 L
.92779 .82177 L
.92777 .8218 L
.92198 .82935 L
.9202 .83161 L
.91596 .83692 L
.91263 .84098 L
.9097 .84449 L
.90506 .84993 L
.90321 .85206 L
.89749 .8585 L
.89647 .85963 L
.88992 .86672 L
.88946 .8672 L
.88234 .8746 L
.88217 .87477 L
.87477 .88217 L
.87459 .88234 L
.8672 .88944 L
.8667 .88992 L
.85963 .89644 L
.85847 .89749 L
.85206 .90317 L
.84989 .90506 L
.84449 .90966 L
.84092 .91263 L
.83692 .9159 L
.83153 .9202 L
.82935 .92192 L
.82177 .92771 L
.8217 .92777 L
.8142 .9333 L
.81137 .93534 L
.80663 .93869 L
.80049 .94291 L
.79906 .94388 L
.79149 .94888 L
.78901 .95048 L
.78392 .95371 L
.77684 .95806 L
.77635 .95836 L
.76878 .96283 L
.7639 .96563 L
.76121 .96714 L
.75363 .97129 L
.75006 .9732 L
.74606 .97529 L
.73849 .97913 L
.73517 .98077 L
.98077 .98077 L
F
.928 .29 0 r
.98077 .2364 m
.97789 .23122 L
.97355 .22365 L
.9732 .22305 L
.96905 .21608 L
.96563 .21051 L
.96438 .20851 L
.95953 .20094 L
.95806 .19868 L
.95451 .19337 L
.95048 .18749 L
.94931 .1858 L
.94391 .17823 L
.94291 .17685 L
.93832 .17065 L
.93534 .16673 L
.93252 .16308 L
.92777 .15708 L
.92651 .15551 L
.92028 .14794 L
.9202 .14785 L
.91381 .14037 L
.91263 .13901 L
.9071 .1328 L
.90506 .13055 L
.90014 .12523 L
.89749 .12242 L
.8929 .11766 L
.88992 .11461 L
.88538 .11008 L
.88234 .10711 L
.87756 .10251 L
.87477 .09988 L
.86942 .09494 L
.8672 .09293 L
.86094 .08737 L
.85963 .08623 L
.85209 .0798 L
.85206 .07978 L
.84449 .07355 L
.84284 .07223 L
.83692 .06755 L
.83317 .06466 L
.82935 .06176 L
.82302 .05709 L
.82177 .05618 L
.8142 .05079 L
.81237 .04952 L
.80663 .04559 L
.80115 .04194 L
.79906 .04058 L
.79149 .03574 L
.78929 .03437 L
.78392 .03108 L
.77672 .0268 L
.77635 .02658 L
.76878 .02225 L
.76334 .01923 L
.98077 .01923 L
F
.98077 .7636 m
.97789 .76878 L
.97355 .77635 L
.9732 .77695 L
.96905 .78392 L
.96563 .78949 L
.96438 .79149 L
.95953 .79906 L
.95806 .80132 L
.95451 .80663 L
.95048 .81251 L
.94931 .8142 L
.94391 .82177 L
.94291 .82315 L
.93832 .82935 L
.93534 .83327 L
.93252 .83692 L
.92777 .84292 L
.92651 .84449 L
.92028 .85206 L
.9202 .85215 L
.91381 .85963 L
.91263 .86099 L
.9071 .8672 L
.90506 .86945 L
.90014 .87477 L
.89749 .87758 L
.8929 .88234 L
.88992 .88539 L
.88538 .88992 L
.88234 .89289 L
.87756 .89749 L
.87477 .90012 L
.86942 .90506 L
.8672 .90707 L
.86094 .91263 L
.85963 .91377 L
.85209 .9202 L
.85206 .92022 L
.84449 .92645 L
.84284 .92777 L
.83692 .93245 L
.83317 .93534 L
.82935 .93824 L
.82302 .94291 L
.82177 .94382 L
.8142 .94921 L
.81237 .95048 L
.80663 .95441 L
.80115 .95806 L
.79906 .95942 L
.79149 .96426 L
.78929 .96563 L
.78392 .96892 L
.77672 .9732 L
.77635 .97342 L
.76878 .97775 L
.76334 .98077 L
.98077 .98077 L
F
.946 .221 0 r
.98077 .20761 m
.97664 .20094 L
.9732 .19552 L
.9718 .19337 L
.96679 .1858 L
.96563 .18407 L
.9616 .17823 L
.95806 .1732 L
.95623 .17065 L
.95066 .16308 L
.95048 .16285 L
.9449 .15551 L
.94291 .15297 L
.93892 .14794 L
.93534 .14352 L
.93274 .14037 L
.92777 .13448 L
.92633 .1328 L
.9202 .12581 L
.91968 .12523 L
.91279 .11766 L
.91263 .11748 L
.90564 .11008 L
.90506 .10948 L
.89822 .10251 L
.89749 .10178 L
.89051 .09494 L
.88992 .09437 L
.88249 .08737 L
.88234 .08724 L
.87477 .08036 L
.87415 .0798 L
.8672 .07372 L
.86546 .07223 L
.85963 .06732 L
.8564 .06466 L
.85206 .06115 L
.84693 .05709 L
.84449 .05518 L
.83703 .04952 L
.83692 .04943 L
.82935 .04387 L
.82666 .04194 L
.82177 .03851 L
.81576 .03437 L
.8142 .03332 L
.80663 .02832 L
.80428 .0268 L
.79906 .02349 L
.79216 .01923 L
.98077 .01923 L
F
.98077 .79239 m
.97664 .79906 L
.9732 .80448 L
.9718 .80663 L
.96679 .8142 L
.96563 .81593 L
.9616 .82177 L
.95806 .8268 L
.95623 .82935 L
.95066 .83692 L
.95048 .83715 L
.9449 .84449 L
.94291 .84703 L
.93892 .85206 L
.93534 .85648 L
.93274 .85963 L
.92777 .86552 L
.92633 .8672 L
.9202 .87419 L
.91968 .87477 L
.91279 .88234 L
.91263 .88252 L
.90564 .88992 L
.90506 .89052 L
.89822 .89749 L
.89749 .89822 L
.89051 .90506 L
.88992 .90563 L
.88249 .91263 L
.88234 .91276 L
.87477 .91964 L
.87415 .9202 L
.8672 .92628 L
.86546 .92777 L
.85963 .93268 L
.8564 .93534 L
.85206 .93885 L
.84693 .94291 L
.84449 .94482 L
.83703 .95048 L
.83692 .95057 L
.82935 .95613 L
.82666 .95806 L
.82177 .96149 L
.81576 .96563 L
.8142 .96668 L
.80663 .97168 L
.80428 .9732 L
.79906 .97651 L
.79216 .98077 L
.98077 .98077 L
F
.964 .15 0 r
.98077 .17647 m
.97681 .17065 L
.9732 .1655 L
.97148 .16308 L
.96598 .15551 L
.96563 .15504 L
.96028 .14794 L
.95806 .14506 L
.95438 .14037 L
.95048 .1355 L
.94828 .1328 L
.94291 .12634 L
.94197 .12523 L
.93543 .11766 L
.93534 .11756 L
.92866 .11008 L
.92777 .10911 L
.92164 .10251 L
.9202 .10099 L
.91436 .09494 L
.91263 .09318 L
.90682 .08737 L
.90506 .08564 L
.89898 .0798 L
.89749 .07838 L
.89085 .07223 L
.88992 .07138 L
.88239 .06466 L
.88234 .06462 L
.87477 .05809 L
.87358 .05709 L
.8672 .05179 L
.8644 .04952 L
.85963 .0457 L
.85483 .04194 L
.85206 .03982 L
.84482 .03437 L
.84449 .03413 L
.83692 .02863 L
.83434 .0268 L
.82935 .02332 L
.82334 .01923 L
.98077 .01923 L
F
.98077 .82353 m
.97681 .82935 L
.9732 .8345 L
.97148 .83692 L
.96598 .84449 L
.96563 .84496 L
.96028 .85206 L
.95806 .85494 L
.95438 .85963 L
.95048 .8645 L
.94828 .8672 L
.94291 .87366 L
.94197 .87477 L
.93543 .88234 L
.93534 .88244 L
.92866 .88992 L
.92777 .89089 L
.92164 .89749 L
.9202 .89901 L
.91436 .90506 L
.91263 .90682 L
.90682 .91263 L
.90506 .91436 L
.89898 .9202 L
.89749 .92162 L
.89085 .92777 L
.88992 .92862 L
.88239 .93534 L
.88234 .93538 L
.87477 .94191 L
.87358 .94291 L
.8672 .94821 L
.8644 .95048 L
.85963 .9543 L
.85483 .95806 L
.85206 .96018 L
.84482 .96563 L
.84449 .96587 L
.83692 .97137 L
.83434 .9732 L
.82935 .97668 L
.82334 .98077 L
.98077 .98077 L
F
.982 .077 0 r
.98077 .13876 m
.97624 .1328 L
.9732 .1289 L
.97029 .12523 L
.96563 .11945 L
.96416 .11766 L
.95806 .11037 L
.95781 .11008 L
.95125 .10251 L
.95048 .10165 L
.94446 .09494 L
.94291 .09325 L
.93743 .08737 L
.93534 .08517 L
.93016 .0798 L
.92777 .07737 L
.92262 .07223 L
.9202 .06985 L
.91481 .06466 L
.91263 .0626 L
.9067 .05709 L
.90506 .05558 L
.89829 .04952 L
.89749 .04881 L
.88992 .04226 L
.88955 .04194 L
.88234 .03593 L
.88045 .03437 L
.87477 .02981 L
.87097 .0268 L
.8672 .02387 L
.86108 .01923 L
.98077 .01923 L
F
.98077 .86124 m
.97624 .8672 L
.9732 .8711 L
.97029 .87477 L
.96563 .88055 L
.96416 .88234 L
.95806 .88963 L
.95781 .88992 L
.95125 .89749 L
.95048 .89835 L
.94446 .90506 L
.94291 .90675 L
.93743 .91263 L
.93534 .91483 L
.93016 .9202 L
.92777 .92263 L
.92262 .92777 L
.9202 .93015 L
.91481 .93534 L
.91263 .9374 L
.9067 .94291 L
.90506 .94442 L
.89829 .95048 L
.89749 .95119 L
.88992 .95774 L
.88955 .95806 L
.88234 .96407 L
.88045 .96563 L
.87477 .97019 L
.87097 .9732 L
.8672 .97613 L
.86108 .98077 L
.98077 .98077 L
F
.964 .15 0 r
.98077 .01935 m
.98065 .01923 L
.98077 .01923 L
F
.98077 .98065 m
.98065 .98077 L
.98077 .98077 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00AOooool3o`0000Cooooo0_l0000hooooo`?o0000>Oooool2o`0003_ooooo0ol0000Noooo
o`00A_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003Kooooo00Go0000oooo
ooooooooooooo`00000gooooo`04o`000?ooooooooooo`0003Wooooo00Go0000oooooooooooooooo
o`00000Mooooo`00?_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000`ooooo`Go00001Oooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0003go
oooo00?o0000ooooooooool06oooool004Kooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000jooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo0000?Oooool00ol0
003oooooooooo`0Kooooo`00A_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
03Kooooo1?l0000hooooo`04o`000?ooooooooooo`0003Wooooo1?l0000Nooooo`00AOooool2o`00
00Cooooo00Co0000oooooooooooo0000=_ooool00ol0003oooooooooo`0iooooo`04o`000?oooooo
ooooo`0003Wooooo00?o0000ooooooooool07oooool004Kooooo00?o0000ooooooooool00oooool2
o`0003Oooooo1Ol0000hooooo`;o0000>_ooool5o`0001gooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Foooooooo00002Ol00002oooo
o`005_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool01?l0003oooooooooool00002ooooo`005_ooool00ol0003oooooooooo`3oooooo`Go
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo0?oooooo1Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool0ooooool5ooooo`7o00000Oooool1ooooo`002?ooool3
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo0?oooooo1Oooool1o`00007ooooo0Oooool0
00Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo7ook4`0:ooHV00SolSP02?o]BP06onQJ00Soi6X02?oONP08om^800[oeYH04?oAX`0L
olf`013odJ<02_oFUP08om^800SoggX02?oTJP06onQJ00SokDX02?ob>00:ooHV01kona<01Oooool1
o`00007ooooo0Oooool00003ooooool0003o000000?o00000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Cooooo0ol00002oooooakona<02_of9P08oo8h00OokDX01ooXFP07
onAZ00SoggX02?oKR008omJF00codJ<0;?o=/00<om6S00SoeYH02?oKR008ommj00Ooi6X01ooXFP07
one:00SolSP02_of9P0Moo/C00?ooooo0ol00002ooooo`002Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oooolMoo/C00WomRH02?ob>007
one:00Koj5X02?oTJP06ommj00SofhP02?oFUP0<om6S01;ocK004Oo8^`0Aolf`00codJ<02?oFUP08
om^800KoggX02?oTJP06onQJ00OokDX02?ob>009ooHV01cona<01Oooool1o`00007ooooo0Oooool0
00Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo7?ok4`09ooHV00SolSP01oo]BP06onQJ00Ooi6X01ooONP07om^800SoeYH02_oAX`0<
olf`02Cob;/03?o=/00:om6S00SoeYH01ooKR007ommj00Ooi6X01_oXFP07one:00SolSP02Oof9P0K
oo/C00Gooooo0Ol00001ooooo`7ooooo0008ooooo`;o00001?ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00;ooooo6_ok4`09ooHV00SolSP01_o]BP08onQJ00Koi6X01_oONP08
om^800KoeYH02_oAX`0:olf`033ob;/02_o=/00:om6S00KoeYH02?oKR006ommj00Koi6X02?oXFP06
one:00SolSP02Oof9P0Ioo/C00Gooooo0Ol00001ooooo`7ooooo0009ooooo`03o`000?oooooooooo
00?ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo6Ook4`09ooHV00SolSP01_o]BP07onQJ
00Koi6X01ooONP06om^800OoeYH02?oAX`0:olf`00kob;/07?o1a00>olRk00[ocK002?oAX`07omJF
00OofhP01_oONP06onAZ00Ooj5X01_o]BP08oo8h00WomRH06?ok4`05ooooo`7o00000Oooool1oooo
o`005_ooool00ol0003oooooooooo`02oooooaSona<02Oof9P07oo8h00OokDX01_oXFP06onAZ00Ko
ggX01_oKR008omJF00KodJ<02_o=/00<olRk02So`L@03?o8^`0:olf`00KodJ<02?oFUP06om^800Ko
ggX01_oTJP06onQJ00OokDX01oob>009ooHV01Oona<01Oooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool00_oooolGoo/C00WomRH01oob>007one:00Koj5X01_oTJP06ommj00KofhP0
1ooFUP06om6S00SocK002_o8^`0@ol7401Go[Kl03oo1a00:olRk00SocK001_oAX`07omJF00KofhP0
1_oONP06onAZ00Ooj5X01_o]BP07oo8h00WomRH05_ok4`05ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02oooooaGona<02Oof9P07oo8h00OokDX01_oXFP05onAZ00KoggX01_oK
R006omJF00SodJ<01_o=/00:olRk00co`L@09?n]_`0<ol7400[ob;/01_o=/008om6S00KoeYH01_oK
R006ommj00Goi6X01_oXFP07one:00OolSP02Oof9P0Doo/C00Gooooo0Ol00001ooooo`7ooooo000F
ooooo`03o`000?oooooooooo00;ooooo5?ok4`0:ooHV00KolSP01oo]BP06onQJ00Goi6X01_oONP06
om^800KoeYH01_oAX`07olf`00Sob;/02_o1a00`ojfo00[o`L@02?o8^`07olf`00KodJ<01_oFUP06
om^800KoggX01OoTJP06onQJ00OokDX01oob>008ooHV01Cona<01Oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_oooolCoo/C00WomRH01oob>006one:00Koj5X01_oTJP05ommj
00GofhP01_oFUP06om6S00SocK001_o8^`0:ol7400co[Kl08?nK^P0<ojfo00[o`L@01_o8^`08olf`
00KodJ<01_oFUP05om^800GoggX01_oTJP06onQJ00KokDX01oob>009ooHV01;ona<01Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_oooolBoo/C00WomRH01oob>006one:00Ko
j5X01OoTJP06ommj00GofhP01_oFUP06om6S00KocK001oo8^`08ol7400[o[Kl0;?nK^P0:ojfo00So
`L@01oo8^`06olf`00KodJ<01_oFUP05om^800KoggX01OoTJP06onQJ00KokDX01oob>008ooHV01;o
na<01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_oooolAoo/C00WomRH0
1_ob>007one:00Goj5X01OoTJP06ommj00KofhP01?oFUP06om6S00KocK002?o8^`06ol7400[o[Kl0
3_nK^P0HohRf00koVkX02_n]_`06ol7400Sob;/01_o=/006om6S00CoeYH01_oKR006ommj00Goi6X0
1OoXFP06one:00OolSP02Oof9P0@oo/C00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oo
oooooooo00;ooooo4?ok4`09ooHV00OolSP01_o]BP05onQJ00Goi6X01_oONP05om^800GoeYH01_oA
X`06olf`00Kob;/01oo1a008ojfo00[oVkX0:?n8]P0:oi^j00So[Kl01oo1a007olRk00GocK001_oA
X`05omJF00GofhP01_oONP05onAZ00Koj5X01Oo]BP07oo8h00SomRH04?ok4`05ooooo`7o00000Ooo
ool1ooooo`005_ooool2o`0000?ooooo3ook4`08ooHV00OolSP01_o]BP05onQJ00Koi6X01OoONP05
om^800GoeYH01OoAX`06olf`00Kob;/01_o1a008ojfo00[oVkX04?n8]P0AogNa00ooR;H02_nK^P08
ojfo00Ko`L@01_o8^`06olf`00GodJ<01OoFUP05om^800GoggX01_oTJP05onQJ00KokDX01oob>008
ooHV00kona<01?ooool2o`0000;ooooo000Fooooo`03o`000?oooooooooo00;ooooo3_ok4`08ooHV
00OolSP01_o]BP05onQJ00Koi6X01OoONP05om^800GoeYH01OoAX`05olf`00Kob;/01_o1a007ojfo
00WoVkX02_n8]P0TogNa00[oR;H02OnK^P07ojfo00Ko`L@01_o8^`05olf`00GodJ<01OoFUP05om^8
00GoggX01_oTJP05onQJ00KokDX01_ob>008ooHV00kona<01Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool=oo/C00SomRH01oob>005one:00Koj5X01OoTJP05ommj00Go
fhP01OoFUP04om6S00KocK001_o8^`06ol7400Ko[Kl02?nK^P0:ohRf01CoMk401OmW[@0CogNa00[o
R;H02?nK^P06ojfo00Ko`L@01_o8^`06olf`00CodJ<01OoFUP05om^800GoggX01OoTJP06onQJ00Go
kDX01oob>008ooHV00cona<01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool<oo/C00SomRH01oob>005one:00Koj5X01OoTJP05ommj00GofhP01OoFUP04om6S00KocK00
1Oo8^`06ol7400Ko[Kl01onK^P08ohRf00_oMk408?mW[@0;ogNa00WoR;H01_nK^P06ojfo00Ko`L@0
1Oo8^`06olf`00CodJ<01OoFUP05om^800GoggX01OoTJP05onQJ00KokDX01_ob>008ooHV00cona<0
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool;oo/C00SomRH01oob
>005one:00Goj5X01OoTJP05ommj00GofhP01?oFUP06om6S00CocK001_o8^`04ol7400Ko[Kl02?nK
^P08ohRf00SoMk40;?mW[@08ogNa00SoR;H02?nK^P06ojfo00Co`L@01_o8^`04olf`00KodJ<01?oF
UP05om^800GoggX01?oTJP06onQJ00GokDX01oob>008ooHV00[ona<01Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool:oo/C00SomRH01oob>005one:00Koj5X01?oTJP05
ommj00GofhP01?oFUP05om6S00GocK001Oo8^`05ol7400Ko[Kl01_nK^P07ohRf00SoMk403_mW[@0H
oeNX00koIjd02?mg/@07ohRf00KoVkX01_n]_`05ol7400Gob;/01Oo=/004om6S00GoeYH01OoKR005
ommj00Coi6X01_oXFP05one:00KolSP02?of9P0:oo/C00Gooooo0Ol00001ooooo`7ooooo000Foooo
o`03o`000?oooooooooo00;ooooo2Ook4`08ooHV00KolSP01_o]BP05onQJ00Goi6X01?oONP05om^8
00GoeYH01?oAX`05olf`00Gob;/01Oo1a005ojfo00KoVkX01_n8]P08ogNa00[oIjd0:?mGZ00:ofN]
00SoMk401_n8]P06oi^j00Go[Kl01Oo1a005olRk00GocK001?oAX`05omJF00GofhP01?oONP05onAZ
00Goj5X01_o]BP06oo8h00SomRH02?ok4`05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`Sona<02?of9P06oo8h00KokDX01_oXFP04onAZ00CoggX01OoKR005omJF00Co
dJ<01Oo=/005olRk00Go`L@01On]_`05oi^j00KoR;H01omg/@09ofN]00koEjP05Om8X`0=oeNX00Wo
Ijd01omg/@06ohRf00GoVkX01On]_`05ol7400Gob;/01Oo=/004om6S00GoeYH01?oKR005ommj00Go
i6X01OoXFP05one:00KolSP02?of9P08oo/C00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`00
0?oooooooooo00;ooooo2?ok4`07ooHV00OolSP01Oo]BP05onQJ00Goi6X01?oONP04om^800GoeYH0
1OoAX`04olf`00Cob;/01_o1a004ojfo00KoVkX01_n8]P06ogNa00SoIjd02_mGZ00TodRS00[oEjP0
2?mW[@06ogNa00KoR;H01_nK^P04ojfo00Ko`L@01?o8^`04olf`00GodJ<01OoFUP04om^800CoggX0
1OoTJP05onQJ00GokDX01oob>007ooHV00Oona<01Oooool1o`00007ooooo0Oooool001Kooooo00?o
0000ooooooooool00_ooool7oo/C00OomRH01oob>005one:00Goj5X01OoTJP04ommj00CofhP01OoF
UP05om6S00CocK001?o8^`05ol7400Go[Kl01OnK^P06ohRf00KoMk401_mW[@0:oeNX00koB:<04Oli
W`0=odRS00[oEjP01_mW[@06ogNa00KoR;H01OnK^P05ojfo00Go`L@01?o8^`05olf`00CodJ<01?oF
UP05om^800CoggX01OoTJP05onQJ00GokDX01_ob>008ooHV00Kona<01Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool6oo/C00SomRH01_ob>005one:00Goj5X01?oTJP05
ommj00CofhP01?oFUP05om6S00CocK001Oo8^`04ol7400Co[Kl01_nK^P04ohRf00KoMk402?mW[@06
oeNX00coB:<08?liW`0<odRS00KoEjP02?mW[@06ogNa00CoR;H01_nK^P04ojfo00Co`L@01Oo8^`04
olf`00GodJ<01?oFUP04om^800CoggX01OoTJP05onQJ00GokDX01_ob>007ooHV00Kona<01Oooool1
o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool6oo/C00OomRH01_ob>005one:
00Goj5X01OoTJP04ommj00CofhP01?oFUP05om6S00CocK001?o8^`05ol7400Co[Kl01OnK^P05ohRf
00KoMk401_mW[@07oeNX00WoB:<0:oliW`08odRS00OoEjP01_mW[@06ogNa00GoR;H01OnK^P04ojfo
00Go`L@01?o8^`04olf`00CodJ<01OoFUP04om^800CoggX01OoTJP05onQJ00GokDX01_ob>007ooHV
00Gona<01Oooool1o`00007ooooo0Oooool001Kooooo0_l00003ooooo`Cona<02?of9P06oo8h00Go
kDX01OoXFP04onAZ00GoggX01?oKR004omJF00CodJ<01?o=/004olRk00Go`L@01On]_`04oi^j00Co
R;H01_mg/@06ofN]00KoEjP02?m8X`0<ocVO01co;9X03?liW`08odRS00KoEjP01_mW[@06ogNa00Co
R;H01?nK^P05ojfo00Go`L@01?o8^`04olf`00CodJ<01?oFUP04om^800CoggX01OoTJP05onQJ00Go
kDX01_ob>007ooHV00Cona<01?ooool2o`0000;ooooo000Fooooo`03o`000?oooooooooo00;ooooo
1?ok4`08ooHV00GolSP01Oo]BP05onQJ00Goi6X01?oONP04om^800CoeYH01?oAX`04olf`00Cob;/0
1Oo1a004ojfo00GoVkX01?n8]P05ogNa00KoIjd01_mGZ007odRS00Wo>Il0:?l/VP09ocVO00OoB:<0
1_mGZ006ofN]00GoMk401?n8]P05oi^j00Co[Kl01Oo1a004olRk00CocK001?oAX`04omJF00CofhP0
1?oONP05onAZ00Goj5X01Oo]BP06oo8h00OomRH00ook4`05ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`?ona<01oof9P06oo8h00GokDX01OoXFP04onAZ00CoggX01OoK
R004omJF00CodJ<01?o=/004olRk00Co`L@01?n]_`04oi^j00GoR;H01Omg/@06ofN]00CoEjP02?m8
X`08ocVO00co;9X06?lNUP0<obbJ00So>Il02?m8X`04oeNX00KoIjd01Omg/@05ohRf00CoVkX01?n]
_`04ol7400Cob;/01?o=/004om6S00CoeYH01?oKR004ommj00Goi6X01OoXFP04one:00KolSP02?of
9P02oo/C00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_ok4`08
ooHV00KolSP01?o]BP05onQJ00Goi6X01?oONP04om^800CoeYH01?oAX`04olf`00Cob;/01?o1a004
ojfo00CoVkX01On8]P05ogNa00CoIjd01_mGZ006odRS00Oo>Il02_l/VP0ToajF00[o;9X01oliW`06
odRS00KoEjP01OmW[@04ogNa00GoR;H01?nK^P04ojfo00Co`L@01?o8^`04olf`00CodJ<01?oFUP04
om^800CoggX01OoTJP04onQJ00GokDX01_ob>008ooHV0003oo/C0?oooooooooo00?ooooo0Ol00001
ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00?ona<0ooHV0?of9P001Oof9P06oo8h
00GokDX01OoXFP04onAZ00CoggX01?oKR004omJF00CodJ<01?o=/004olRk00Co`L@01?n]_`05oi^j
00CoR;H01?mg/@04ofN]00KoEjP01_m8X`06ocVO00So;9X03_lNUP0Eoa:A00go7YH02?l/VP06ocVO
00KoB:<01_mGZ004ofN]00CoMk401?n8]P05oi^j00Co[Kl01?o1a004olRk00?ocK001?oAX`04omJF
00CofhP01?oONP05onAZ00Goj5X01?o]BP06oo8h00SomRH01Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool8ooHV00KolSP01?o]BP06onQJ00Coi6X01?oONP04om^800Co
eYH01?oAX`04olf`00?ob;/01?o1a004ojfo00CoVkX01On8]P04ogNa00CoIjd01_mGZ005odRS00Ko
>Il01ol/VP0;oajF023o4Y402olNUP07obbJ00Ko>Il01_m8X`05oeNX00CoIjd01Omg/@04ohRf00Co
VkX01?n]_`04ol7400Cob;/00oo=/004om6S00CoeYH01?oKR004ommj00Goi6X01?oXFP05one:00Ko
lSP01oof9P05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`OomRH0
1Oob>006one:00Coj5X01?oTJP04ommj00CofhP01?oFUP04om6S00CocK001?o8^`03ol7400Co[Kl0
1?nK^P04ohRf00CoMk401_mW[@04oeNX00KoB:<01?liW`08obbJ00So7YH04?lBT@0=o`N<00oo4Y40
2?lNUP08obbJ00Co>Il01_m8X`04oeNX00KoIjd01?mg/@04ohRf00CoVkX01?n]_`03ol7400Cob;/0
1?o=/003om6S00CoeYH01?oKR004ommj00Coi6X01OoXFP05one:00KolSP01_of9P05ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`KomRH01_ob>005one:00Goj5X01?oT
JP04ommj00CofhP01?oFUP04om6S00?ocK001?o8^`03ol7400Co[Kl01?nK^P04ohRf00CoMk401OmW
[@05oeNX00CoB:<01_liW`06obbJ00So7YH02_lBT@0No`N<00_o4Y401olNUP06obbJ00Ko>Il01?m8
X`05oeNX00CoIjd01Omg/@04ohRf00CoVkX00on]_`04ol7400Cob;/01?o=/003om6S00CoeYH01?oK
R004ommj00Coi6X01OoXFP05one:00GolSP01_of9P05ooooo`7o00000Oooool1ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`GomRH01_ob>005one:00Coj5X01?oTJP04ommj00CofhP01?oFUP04
om6S00CocK000oo8^`04ol7400Co[Kl01?nK^P04ohRf00CoMk401?mW[@04oeNX00GoB:<01OliW`06
obbJ00Ko7YH02_lBT@0Xo`N<00[o4Y401_lNUP06obbJ00Go>Il01Om8X`04oeNX00CoIjd01?mg/@04
ohRf00CoVkX01?n]_`04ol7400?ob;/01?o=/003om6S00CoeYH01?oKR004ommj00Coi6X01OoXFP05
one:00KolSP01?of9P05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02oooo
o`ComRH01_ob>006one:00Coj5X01?oTJP04ommj00CofhP01?oFUP03om6S00CocK000oo8^`04ol74
00Co[Kl01?nK^P04ohRf00CoMk401?mW[@04oeNX00GoB:<01OliW`05obbJ00Ko7YH02?lBT@0;o`N<
01[o08P32ol7S008oa:A00Ko7YH01Ol/VP05ocVO00GoB:<01?mGZ004ofN]00CoMk401?n8]P04oi^j
00Co[Kl00oo1a004olRk00CocK000ooAX`04omJF00CofhP01?oONP04onAZ00Goj5X01?o]BP06oo8h
00ComRH01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool4ooHV00Ko
lSP01?o]BP05onQJ00Coi6X01?oONP03om^800CoeYH01?oAX`03olf`00Cob;/01?o1a003ojfo00Co
VkX01?n8]P04ogNa00CoIjd01?mGZ005odRS00Co>Il01_l/VP06oajF00Ko4Y402_l7S00To`280`[o
1h`01_lBT@06oajF00Ko;9X01?liW`05odRS00CoEjP01?mW[@04ogNa00CoR;H00onK^P04ojfo00Co
`L@01?o8^`03olf`00?odJ<01?oFUP04om^800CoggX01?oTJP04onQJ00GokDX01Oob>004ooHV00Go
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo1?of9P05oo8h00GokDX0
1?oXFP04onAZ00CoggX01?oKR004omJF00?odJ<00oo=/004olRk00Co`L@01?n]_`03oi^j00CoR;H0
1?mg/@04ofN]00CoEjP01?m8X`05ocVO00Go;9X01OlNUP06oa:A00So1h`03?l0R0<Fo`233@co08P3
2?l7S006oa:A00Go7YH01Ol/VP05ocVO00CoB:<01?mGZ004ofN]00CoMk401?n8]P03oi^j00Co[Kl0
1?o1a003olRk00CocK000ooAX`04omJF00CofhP01?oONP04onAZ00Coj5X01Oo]BP05oo8h00?omRH0
1Oooool1o`00007ooooo0Oooool001Kooooo0_l00003ooooo`;omRH01_ob>005one:00Coj5X01?oT
JP04ommj00CofhP00ooFUP04om6S00?ocK001?o8^`04ol7400?o[Kl01?nK^P03ohRf00CoMk401?mW
[@04oeNX00CoB:<01?liW`06obbJ00Co7YH01_lBT@08o`N<00So08P39?l0P`d8o`280`So1h`01_lB
T@04oajF00Ko;9X01?liW`04odRS00CoEjP01?mW[@04ogNa00?oR;H01?nK^P03ojfo00Co`L@01?o8
^`03olf`00?odJ<01?oFUP04om^800CoggX01?oTJP04onQJ00CokDX01_ob>002ooHV00Cooooo0_l0
0002ooooo`005_ooool00ol0003oooooooooo`02ooooo`;omRH01_ob>004one:00Coj5X01?oTJP04
ommj00CofhP01?oFUP04om6S00;ocK001?o8^`04ol7400?o[Kl01?nK^P03ohRf00CoMk401?mW[@04
oeNX00CoB:<01?liW`05obbJ00Go7YH01OlBT@07o`N<00So08P33Ol0P`d@o`1n5`ko08<=1ol0R0<7
o`N<00Go4Y401OlNUP05obbJ00Co>Il01?m8X`04oeNX00CoIjd01?mg/@03ohRf00CoVkX00on]_`04
ol7400?ob;/01?o=/003om6S00CoeYH00ooKR004ommj00Coi6X01OoXFP04one:00KolSP000?omRH0
ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool00oof
9P3olSP0oo8h0003oo8h00GokDX01OoXFP04onAZ00?oggX01?oKR003omJF00CodJ<01?o=/003olRk
00?o`L@01?n]_`03oi^j00CoR;H01?mg/@03ofN]00CoEjP01?m8X`04ocVO00Go;9X01?lNUP06oa:A
00Ko1h`01_l0R0<:o`233B3o07hG2_l0P`d6o`280`Ko1h`01_lBT@04oajF00Go;9X01?liW`04odRS
00CoEjP00omW[@04ogNa00CoR;H00onK^P03ojfo00Co`L@00oo8^`03olf`00CodJ<01?oFUP04om^8
00?oggX01?oTJP05onQJ00CokDX01_ob>005ooooo`7o00000Oooool1ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`KolSP01?o]BP05onQJ00Coi6X00ooONP04om^800CoeYH01?oAX`03olf`00?o
b;/01?o1a003ojfo00?oVkX01?n8]P04ogNa00?oIjd01?mGZ004odRS00Co>Il01?l/VP05oajF00Go
4Y401Ol7S007o`280`So08<=4_l0OQL5o`1j7a7o07hG2?l0P`d7o`280`Go1h`01OlBT@05oajF00Co
;9X01?liW`04odRS00CoEjP00omW[@04ogNa00?oR;H01?nK^P03ojfo00Co`L@00oo8^`03olf`00Co
dJ<00ooFUP04om^800CoggX01?oTJP04onQJ00GokDX01Oob>005ooooo`7o00000Oooool1ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`GolSP01Oo]BP04onQJ00Coi6X01?oONP03om^800CoeYH0
0ooAX`04olf`00?ob;/00oo1a004ojfo00?oVkX01?n8]P03ogNa00CoIjd00omGZ004odRS00Co>Il0
1?l/VP04oajF00Ko4Y401?l7S006o`280`So08<=2_l0OQLLo`1j7`[o07hG2?l0P`d6o`280`Co1h`0
1_lBT@04oajF00Co;9X01?liW`04odRS00?oEjP01?mW[@03ogNa00CoR;H00onK^P03ojfo00Co`L@0
0oo8^`03olf`00CodJ<01?oFUP03om^800?oggX01?oTJP04onQJ00KokDX01?ob>005ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`ColSP01_o]BP04onQJ00Coi6X00ooO
NP03om^800CoeYH01?oAX`03olf`00?ob;/01?o1a003ojfo00?oVkX01?n8]P03ogNa00CoIjd00omG
Z004odRS00Co>Il01?l/VP04oajF00Go4Y401Ol7S006o`280`Ko08<=2Ol0OQLTo`1j7`Wo07hG1ol0
P`d5o`280`Go1h`01OlBT@04oajF00Co;9X01?liW`04odRS00?oEjP01?mW[@03ogNa00?oR;H01?nK
^P03ojfo00Co`L@00oo8^`03olf`00CodJ<00ooFUP04om^800?oggX01?oTJP04onQJ00GokDX01?ob
>005ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`ColSP01?o]BP04
onQJ00Coi6X01?oONP04om^800?oeYH00ooAX`04olf`00?ob;/00oo1a004ojfo00?oVkX00on8]P04
ogNa00?oIjd01?mGZ004odRS00?o>Il01?l/VP04oajF00Go4Y401?l7S006o`280`Ko08<=2?l0OQL<
o`1j7aGo07DW2ol0NQl8o`1n5`Ko08<=1_l0R0<4o`N<00Go4Y401?lNUP04obbJ00?o>Il01?m8X`04
oeNX00?oIjd00omg/@04ohRf00?oVkX00on]_`04ol7400?ob;/00oo=/004om6S00?oeYH00ooKR004
ommj00Coi6X01?oXFP04one:00ColSP01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool4oo8h00CokDX01?oXFP04onAZ00CoggX00ooKR003omJF00CodJ<01?o=/002olRk
00Co`L@00on]_`03oi^j00CoR;H00omg/@03ofN]00CoEjP01?m8X`03ocVO00Co;9X01?lNUP05oa:A
00Co1h`01Ol0R0<6o`233@Oo07hG2Ol0NQlPo`1e9`[o07XO1_l0OQL6o`233@Go08P31Ol7S004oa:A
00Co7YH01?l/VP03ocVO00CoB:<00omGZ004ofN]00?oMk401?n8]P03oi^j00?o[Kl00oo1a004olRk
00?ocK000ooAX`04omJF00?ofhP01?oONP04onAZ00Coj5X01?o]BP03oo8h00Gooooo0Ol00001oooo
o`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_ob>005one:00Coj5X01?oTJP03ommj00Co
fhP01?oFUP03om6S00?ocK000oo8^`04ol7400?o[Kl00onK^P03ohRf00CoMk400omW[@03oeNX00Co
B:<00oliW`04obbJ00Co7YH01?lBT@04o`N<00Ko08P31?l0P`d8o`1n5`Ko07XO3_l0MBLAo`1a;`go
07DW1_l0NQl8o`1n5`Co08<=1_l0R0<4o`N<00Co4Y401?lNUP04obbJ00?o>Il00om8X`04oeNX00?o
Ijd00omg/@04ohRf00?oVkX00on]_`04ol7400;ob;/01?o=/003om6S00?oeYH01?oKR004ommj00Co
i6X01?oXFP04one:00;olSP01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool2oo8h00CokDX01?oXFP04onAZ00CoggX01?oKR003omJF00?odJ<01?o=/002olRk00Co`L@0
1?n]_`02oi^j00CoR;H00omg/@03ofN]00CoEjP00om8X`03ocVO00Co;9X01?lNUP04oa:A00Co1h`0
1Ol0R0<5o`233@Ko07hG1ol0NQl:o`1e9aco074_2_l0MBL7o`1j7`Ko07hG1Ol0P`d5o`280`Co1h`0
1?lBT@04oajF00?o;9X01?liW`03odRS00CoEjP00omW[@03ogNa00?oR;H01?nK^P03ojfo00?o`L@0
0oo8^`04olf`00?odJ<00ooFUP04om^800?oggX01?oTJP04onQJ00GokDX000?olSP0ooooooooool0
0oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool00oob>03okDX0one:
0003one:00Coj5X01?oTJP03ommj00?ofhP01?oFUP03om6S00?ocK001?o8^`03ol7400?o[Kl00onK
^P03ohRf00CoMk400omW[@03oeNX00?oB:<01?liW`04obbJ00Co7YH00olBT@05o`N<00Co08P31?l0
P`d6o`1n5`Ko07XO2?l0MBLXo`1a;`So07DW1_l0NQl6o`1n5`Co08<=1?l0R0<5o`N<00?o4Y401?lN
UP04obbJ00Co>Il00_m8X`04oeNX00?oIjd00omg/@04ohRf00;oVkX01?n]_`03ol7400?ob;/01?o=
/002om6S00CoeYH01?oKR003ommj00?oi6X01?oXFP06one:00Gooooo0Ol00001ooooo`7ooooo000F
ooooo`03o`000?oooooooooo00;ooooo1_o]BP04onQJ00Coi6X00_oONP04om^800CoeYH00_oAX`04
olf`00?ob;/00oo1a004ojfo00;oVkX01?n8]P03ogNa00?oIjd01?mGZ002odRS00Co>Il01?l/VP04
oajF00?o4Y401?l7S005o`280`Co08<=1_l0OQL5o`1j7`So07DW2ol0LBlFo`1/=@_o074_2?l0MBL6
o`1j7`Go07hG1?l0P`d5o`280`Co1h`01?lBT@03oajF00Co;9X00oliW`03odRS00CoEjP00omW[@03
ogNa00?oR;H00onK^P04ojfo00?o`L@00oo8^`03olf`00?odJ<01?oFUP03om^800CoggX00ooTJP04
onQJ00GokDX01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool4one:
00Coj5X01?oTJP04ommj00?ofhP00ooFUP04om6S00?ocK000oo8^`03ol7400?o[Kl00onK^P03ohRf
00?oMk401?mW[@03oeNX00?oB:<01?liW`03obbJ00?o7YH01?lBT@04o`N<00Co08P31?l0P`d6o`1n
5`Ko07XO1_l0MBL8o`1a;bCo06`e2?l0LBl6o`1e9`Ko07XO1_l0OQL4o`233@Co08P31?l7S004oa:A
00Co7YH00_l/VP04ocVO00CoB:<00_mGZ004ofN]00?oMk400on8]P03oi^j00?o[Kl00oo1a003olRk
00CocK000ooAX`03omJF00?ofhP01?oONP04onAZ00Coj5X00oo]BP05ooooo`7o00000Oooool1oooo
o`005_ooool2o`0000?ooooo0oo]BP04onQJ00Coi6X01?oONP03om^800?oeYH01?oAX`03olf`00?o
b;/00oo1a003ojfo00?oVkX00on8]P03ogNa00?oIjd01?mGZ003odRS00?o>Il01?l/VP03oajF00Co
4Y401?l7S004o`280`Co08<=1Ol0OQL5o`1j7`Ko07DW1ol0LBl=o`1/=A;o06Lk3Ol0K3D6o`1a;`Ko
07DW1_l0NQl4o`1n5`Go08<=1?l0R0<4o`N<00?o4Y401?lNUP03obbJ00Co>Il00om8X`03oeNX00?o
Ijd00omg/@04ohRf00;oVkX01?n]_`03ol7400?ob;/00oo=/003om6S00?oeYH01?oKR003ommj00Co
i6X01?oXFP03one:00Cooooo0_l00002ooooo`005_ooool00ol0003oooooooooo`02ooooo`?okDX0
1?oXFP04onAZ00?oggX01?oKR003omJF00?odJ<00oo=/003olRk00?o`L@01?n]_`02oi^j00CoR;H0
0_mg/@04ofN]00?oEjP00om8X`04ocVO00;o;9X01?lNUP04oa:A00Co1h`01?l0R0<4o`233@Co07hG
1?l0NQl6o`1e9`So074_2_l0K3DLo`1W>`[o06`e2?l0LBl6o`1e9`Co07XO1?l0OQL4o`233@Co08P3
1?l7S004oa:A00Co7YH00_l/VP04ocVO00?oB:<00omGZ004ofN]00;oMk401?n8]P02oi^j00Co[Kl0
0oo1a003olRk00?ocK000ooAX`03omJF00CofhP00ooONP04onAZ00Coj5X00_o]BP05ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;okDX01?oXFP04onAZ00?oggX01?oK
R003omJF00?odJ<00oo=/003olRk00?o`L@00on]_`03oi^j00?oR;H00omg/@04ofN]00?oEjP00om8
X`03ocVO00?o;9X01?lNUP03oa:A00Co1h`01?l0R0<4o`233@Co07hG1Ol0NQl5o`1e9`Ko074_2?l0
K3DXo`1W>`So06`e1_l0LBl4o`1e9`Ko07XO1?l0OQL4o`233@Co08P30ol7S004oa:A00?o7YH01?l/
VP03ocVO00?oB:<00omGZ003ofN]00?oMk400on8]P03oi^j00?o[Kl00oo1a003olRk00?ocK000ooA
X`04omJF00?ofhP00ooONP04onAZ00Coj5X00_o]BP05ooooo`7o00000Oooool1ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`;okDX01?oXFP04onAZ00?oggX00ooKR004omJF00?odJ<00oo=/003
olRk00?o`L@00on]_`03oi^j00?oR;H00omg/@03ofN]00?oEjP00om8X`03ocVO00?o;9X01?lNUP04
oa:A00;o1h`01?l0R0<4o`233@Co07hG1_l0NQl4o`1e9`Ko074_2?l0K3D:o`1W>aSo06=02_l0Ic/8
o`1/=@Ko074_1?l0MBL6o`1j7`Co07hG1?l0P`d4o`280`;o1h`01?lBT@04oajF00?o;9X00oliW`03
odRS00?oEjP00omW[@03ogNa00?oR;H00onK^P03ojfo00?o`L@00oo8^`03olf`00?odJ<01?oFUP03
om^800?oggX01?oTJP04onQJ0003one:0?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Foooo
o`03o`000?oooooooooo00;ooooo00?okDX0onQJ0?oXFP000_oXFP04onAZ00?oggX01?oKR003omJF
00?odJ<00oo=/003olRk00?o`L@00on]_`03oi^j00?oR;H00omg/@03ofN]00?oEjP00om8X`03ocVO
00?o;9X00olNUP04oa:A00?o1h`01?l0R0<4o`233@Co07hG1?l0NQl5o`1e9`Ko074_1_l0K3D9o`1W
>b7o06=02_l0Ic/6o`1/=@Ko074_1?l0MBL4o`1j7`Go07hG0ol0P`d4o`280`Co1h`00olBT@03oajF
00Co;9X00oliW`03odRS00?oEjP00omW[@03ogNa00?oR;H00onK^P03ojfo00?o`L@00oo8^`03olf`
00?odJ<00ooFUP03om^800CoggX00ooTJP04onQJ0003one:0?oooooooooo00?ooooo0Ol00001oooo
o`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00?okDX0onQJ0?oXFP000_oXFP03onAZ00Co
ggX00ooKR003omJF00CodJ<00_o=/004olRk00;o`L@00on]_`03oi^j00?oR;H00omg/@03ofN]00?o
EjP00om8X`03ocVO00?o;9X01?lNUP03oa:A00?o1h`01?l0R0<4o`233@Co07hG1?l0NQl4o`1e9`Ko
074_1_l0K3D8o`1W>`co06=04Ol0GTD;o`1S@0So06Lk1_l0K3D6o`1a;`Co07DW1?l0NQl4o`1n5`Co
08<=1?l0R0<3o`N<00?o4Y401?lNUP03obbJ00?o>Il00om8X`03oeNX00?oIjd00omg/@03ohRf00?o
VkX00on]_`03ol7400?ob;/00oo=/003om6S00?oeYH00ooKR004ommj00?oi6X01?oXFP05ooooo`7o
00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`Coj5X01?oTJP03ommj00?ofhP0
0ooFUP04om6S00?ocK000oo8^`02ol7400?o[Kl00onK^P03ohRf00?oMk400omW[@03oeNX00?oB:<0
0oliW`03obbJ00?o7YH01?lBT@03o`N<00Co08P30ol0P`d4o`1n5`Co07XO1Ol0MBL5o`1a;`Go06`e
1ol0Ic/:o`1S@1co05i52_l0Hd06o`1W>`Ko06`e1Ol0LBl5o`1e9`Co07XO1?l0OQL3o`233@?o08P3
1?l7S003oa:A00?o7YH00ol/VP04ocVO00;oB:<01?mGZ002ofN]00?oMk400on8]P03oi^j00?o[Kl0
0oo1a003olRk00?ocK000ooAX`03omJF00?ofhP01?oONP03onAZ00Coj5X01Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool00_ooool4onQJ00?oi6X01?oONP03om^800?oeYH00ooA
X`03olf`00?ob;/00oo1a003ojfo00?oVkX00on8]P03ogNa00;oIjd01?mGZ002odRS00Co>Il00_l/
VP04oajF00?o4Y400ol7S004o`280`?o08<=0ol0OQL4o`1j7`Ko07DW1?l0LBl6o`1/=@Ko06Lk2?l0
Hd0To`1NA@So06=01_l0Ic/6o`1/=@Co074_1_l0MBL4o`1j7`?o07hG0ol0P`d4o`280`Co1h`00_lB
T@04oajF00;o;9X01?liW`02odRS00CoEjP00_mW[@03ogNa00?oR;H00onK^P03ojfo00?o`L@00oo8
^`03olf`00?odJ<00ooFUP03om^800CoggX00ooTJP03onQJ00Gooooo0Ol00001ooooo`7ooooo000F
ooooo`03o`000?oooooooooo00;ooooo0ooXFP03onAZ00CoggX00ooKR003omJF00?odJ<00oo=/003
olRk00?o`L@00on]_`03oi^j00?oR;H00omg/@02ofN]00?oEjP00om8X`03ocVO00?o;9X00olNUP04
oa:A00?o1h`00ol0R0<4o`233@?o07hG1?l0NQl5o`1e9`Co074_1Ol0K3D6o`1W>`Oo06=03?l0GTDE
o`1JB0_o05i51_l0Hd06o`1W>`Ko06`e1?l0LBl4o`1e9`Co07XO1?l0OQL3o`233@Co08P30ol7S003
oa:A00?o7YH00ol/VP03ocVO00?oB:<00omGZ003ofN]00?oMk400on8]P02oi^j00?o[Kl00oo1a003
olRk00?ocK000ooAX`03omJF00?ofhP01?oONP04onAZ00;oj5X01Oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_ooool2onQJ00Coi6X01?oONP03om^800?oeYH00ooAX`03olf`
00?ob;/00oo1a003ojfo00;oVkX00on8]P03ogNa00?oIjd00omGZ003odRS00?o>Il00ol/VP03oajF
00?o4Y400ol7S004o`280`;o08<=1?l0OQL4o`1j7`Co07DW1?l0LBl6o`1/=@Co06Lk2?l0Hd08o`1N
AB3o05Y82?l0GTD8o`1S@0Co06Lk1_l0K3D4o`1a;`Co07DW1?l0NQl4o`1n5`;o08<=1?l0R0<4o`N<
00;o4Y401?lNUP02obbJ00?o>Il00om8X`03oeNX00?oIjd00omg/@03ohRf00;oVkX00on]_`03ol74
00?ob;/00oo=/003om6S00?oeYH00ooKR004ommj00?oi6X00_oXFP05ooooo`7o00000Oooool1oooo
o`003_ooool3o`0000Gooooo00?o0000ooooooooool00_ooool2onQJ00?oi6X01?oONP03om^800?o
eYH00ooAX`03olf`00?ob;/00oo1a003ojfo00;oVkX00on8]P03ogNa00?oIjd00omGZ003odRS00?o
>Il00ol/VP03oajF00?o4Y400ol7S003o`280`?o08<=1?l0OQL4o`1j7`Co07DW1?l0LBl5o`1/=@Co
06Lk1_l0Hd08o`1NAA3o05Y82Ol0ED/?o`1JB0So05i51_l0Hd04o`1W>`Go06`e1?l0LBl4o`1e9`Co
07XO0ol0OQL4o`233@?o08P30ol7S003oa:A00?o7YH00ol/VP03ocVO00?oB:<00omGZ002ofN]00?o
Mk400on8]P03oi^j00?o[Kl00_o1a003olRk00?ocK000ooAX`03omJF00CofhP00ooONP03onAZ00;o
j5X01Oooool1o`00007ooooo0Oooool000gooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00;ooooo0_oXFP03onAZ00?oggX01?oKR003omJF00?odJ<00oo=/003olRk00;o
`L@00on]_`03oi^j00?oR;H00omg/@02ofN]00?oEjP00om8X`03ocVO00?o;9X00olNUP03oa:A00?o
1h`00ol0R0<3o`233@Co07hG1?l0NQl4o`1e9`Co074_1?l0K3D4o`1W>`Ko06=02?l0GTD:o`1JB1So
05E;2_l0FTP8o`1NA@Ko06=01?l0Ic/4o`1/=@Co074_1?l0MBL4o`1j7`Co07hG0ol0P`d3o`280`?o
1h`00olBT@03oajF00?o;9X00oliW`03odRS00?oEjP00_mW[@03ogNa00?oR;H00onK^P03ojfo00;o
`L@00oo8^`03olf`00?odJ<00ooFUP04om^800?oggX00ooTJP000ooXFP3oooooooooo`03ooooo`7o
00000Oooool1ooooo`001oooool5o`0000Gooooo00?o0000ooooooooool00_ooool3o`0000;ooooo
00Coj5X0onAZ0?oTJP3oi6X01?oONP03om^800?oeYH00ooAX`03olf`00?ob;/00oo1a002ojfo00?o
VkX00on8]P03ogNa00;oIjd00omGZ003odRS00?o>Il00ol/VP03oajF00?o4Y400ol7S003o`280`?o
08<=1?l0OQL3o`1j7`Co07DW1?l0LBl4o`1/=@Go06Lk1Ol0Hd06o`1NA@Wo05Y88Ol0ED/:o`1JB0Ko
05i51?l0Hd06o`1W>`Co06`e1?l0LBl3o`1e9`Co07XO0ol0OQL3o`233@Co08P30ol7S003oa:A00?o
7YH00ol/VP02ocVO00?oB:<00omGZ003ofN]00?oMk400_n8]P03oi^j00?o[Kl00oo1a002olRk00Co
cK000_oAX`04omJF00?ofhP00ooONP04onAZ00?ooooo0ol00002ooooo`004Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo1?oTJP04ommj00;ofhP01?oFUP02om6S00CocK00
0_o8^`03ol7400?o[Kl00onK^P03ohRf00;oMk400omW[@03oeNX00?oB:<00_liW`03obbJ00?o7YH0
0olBT@03o`N<00Co08P30_l0P`d4o`1n5`Co07XO0ol0MBL3o`1a;`Co06`e1_l0Ic/4o`1S@0Ko05i5
2?l0FTP>o`1EB`go051>3Ol0ED/8o`1JB0Ko05i51?l0Hd06o`1W>`Co06`e1?l0LBl2o`1e9`Co07XO
1?l0OQL2o`233@Co08P30ol7S003oa:A00?o7YH00ol/VP02ocVO00?oB:<00omGZ003ofN]00?oMk40
0_n8]P03oi^j00?o[Kl00oo1a002olRk00?ocK000ooAX`03omJF00CofhP00ooONP03onAZ00Gooooo
0Ol00001ooooo`7ooooo000=ooooo`Co00001Oooool00ol0003oooooooooo`02ooooo`?oi6X01?oO
NP03om^800?oeYH00ooAX`03olf`00?ob;/00_o1a003ojfo00?oVkX00on8]P02ogNa00?oIjd00omG
Z003odRS00;o>Il00ol/VP03oajF00?o4Y400ol7S003o`280`?o08<=1?l0OQL3o`1j7`Co07DW0ol0
LBl4o`1/=@Go06Lk1Ol0Hd05o`1NA@Oo05Y82Ol0ED/Lo`1@CPSo05E;2?l0FTP5o`1NA@Go06=01?l0
Ic/4o`1/=@Co074_1?l0MBL3o`1j7`?o07hG0ol0P`d4o`280`;o1h`01?lBT@02oajF00?o;9X00oli
W`03odRS00;oEjP00omW[@03ogNa00?oR;H00_nK^P03ojfo00?o`L@00oo8^`02olf`00CodJ<00_oF
UP04om^800?oggX00ooTJP05ooooo`7o00000Oooool1ooooo`003Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo0ooTJP03ommj00CofhP00_oFUP04om6S00;ocK000oo8^`03
ol7400?o[Kl00onK^P02ohRf00?oMk400omW[@02oeNX00?oB:<00oliW`03obbJ00?o7YH00olBT@02
o`N<00Co08P30_l0P`d4o`1n5`?o07XO0ol0MBL4o`1a;`Co06`e1?l0Ic/6o`1S@0Co05i51_l0FTP8
o`1EBbCo051>2?l0ED/6o`1JB0Co05i51_l0Hd04o`1W>`Co06`e1?l0LBl3o`1e9`?o07XO1?l0OQL2
o`233@Co08P30_l7S004oa:A00;o7YH00ol/VP03ocVO00?oB:<00_mGZ003ofN]00?oMk400on8]P02
oi^j00?o[Kl00oo1a003olRk00;ocK000ooAX`03omJF00CofhP00ooONP02onAZ00Gooooo0Ol00001
ooooo`7ooooo000=ooooo`Go00001?ooool00ol0003oooooooooo`02ooooo`;oi6X01?oONP03om^8
00?oeYH00ooAX`03olf`00;ob;/00oo1a003ojfo00?oVkX00_n8]P03ogNa00?oIjd00_mGZ003odRS
00?o>Il00ol/VP03oajF00;o4Y400ol7S003o`280`?o08<=1?l0OQL3o`1j7`?o07DW1?l0LBl4o`1/
=@Co06Lk1?l0Hd05o`1NA@Ko05Y82?l0ED/<o`1@CQ7o04Q<2ol0D4h8o`1EB`Ko05Y81?l0GTD5o`1S
@0Co06Lk1?l0K3D3o`1a;`Co07DW0ol0NQl3o`1n5`?o08<=0ol0R0<3o`N<00?o4Y400olNUP02obbJ
00?o>Il00om8X`03oeNX00;oIjd00omg/@03ohRf00;oVkX00on]_`03ol7400?ob;/00oo=/002om6S
00CoeYH00ooKR003ommj00;oi6X01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooooooo
ool00_ooool2onAZ00CoggX00_oKR004omJF00;odJ<01?o=/002olRk00?o`L@00on]_`02oi^j00?o
R;H00omg/@02ofN]00?oEjP00om8X`03ocVO00;o;9X00olNUP03oa:A00?o1h`00ol0R0<3o`233@?o
07hG0ol0NQl3o`1e9`Co074_1?l0K3D4o`1W>`Co06=01?l0GTD6o`1JB0So05E;2?l0D4hLo`18C0So
051>2?l0ED/6o`1JB0Co05i51?l0Hd04o`1W>`Co06`e1?l0LBl3o`1e9`?o07XO0ol0OQL3o`233@?o
08P30ol7S003oa:A00?o7YH00_l/VP03ocVO00?oB:<00omGZ002ofN]00?oMk400on8]P02oi^j00?o
[Kl00oo1a003olRk00;ocK000ooAX`03omJF00?ofhP01?oONP000ooTJP3oooooooooo`03ooooo`7o
00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`03onAZ0?oONP3oggX000;oggX0
0ooKR003omJF00?odJ<00oo=/002olRk00?o`L@00on]_`02oi^j00?oR;H00omg/@02ofN]00?oEjP0
0om8X`03ocVO00;o;9X00olNUP03oa:A00?o1h`00ol0R0<3o`233@?o07hG0ol0NQl3o`1e9`Co074_
0ol0K3D4o`1W>`Go06=01?l0GTD5o`1JB0Ko05E;2?l0D4hTo`18C0So051>1_l0ED/4o`1JB0Go05i5
1?l0Hd04o`1W>`Co06`e0ol0LBl4o`1e9`?o07XO0ol0OQL3o`233@?o08P30ol7S002oa:A00?o7YH0
0ol/VP03ocVO00;oB:<00omGZ003ofN]00;oMk400on8]P03oi^j00;o[Kl00oo1a003olRk00;ocK00
1?oAX`02omJF00CofhP00ooONP000ooTJP3oooooooooo`03ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`04onAZ0?oONP3oggX0ommj00CofhP00_oFUP04om6S00;ocK00
0oo8^`03ol7400;o[Kl00onK^P03ohRf00;oMk400omW[@03oeNX00;oB:<00oliW`03obbJ00?o7YH0
0_lBT@03o`N<00?o08P30ol0P`d3o`1n5`?o07XO0ol0MBL4o`1a;`Co06`e1?l0Ic/4o`1S@0Co05i5
1?l0FTP6o`1EB`So051>3?l0B4`Ao`0nA`_o04Q<2?l0D4h6o`1EB`Co05Y81?l0GTD4o`1S@0Co06Lk
1?l0K3D4o`1a;`?o07DW0ol0NQl3o`1n5`?o08<=0ol0R0<3o`N<00;o4Y400olNUP03obbJ00?o>Il0
0_m8X`03oeNX00?oIjd00_mg/@03ohRf00;oVkX00on]_`03ol7400?ob;/00_o=/003om6S00?oeYH0
0ooKR004ommj00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00Co
i6X0ommj0?oONP3oggX00ooKR003omJF00?odJ<00oo=/002olRk00?o`L@00on]_`02oi^j00?oR;H0
0omg/@02ofN]00?oEjP00om8X`02ocVO00?o;9X00olNUP02oa:A00?o1h`00ol0R0<3o`233@?o07hG
0ol0NQl3o`1e9`Co074_0ol0K3D4o`1W>`Co06=01?l0GTD5o`1JB0Go05E;1ol0D4h9o`18C1co03i7
2?l0B4`8o`1@CPCo05E;1_l0FTP4o`1NA@Co06=00ol0Ic/4o`1/=@?o074_0ol0MBL4o`1j7`;o07hG
1?l0P`d2o`280`?o1h`00olBT@02oajF00?o;9X00oliW`02odRS00?oEjP00omW[@02ogNa00?oR;H0
0_nK^P03ojfo00?o`L@00oo8^`03olf`00;odJ<01?oFUP02om^800CoggX01Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool00_ooool4ommj00;ofhP01?oFUP02om6S00CocK000_o8
^`03ol7400?o[Kl00_nK^P03ohRf00?oMk400_mW[@03oeNX00;oB:<00oliW`03obbJ00;o7YH00olB
T@03o`N<00?o08P30ol0P`d2o`1n5`Co07XO0ol0MBL3o`1a;`Co06`e0ol0Ic/4o`1S@0Co05i51Ol0
FTP4o`1EB`Ko051>2_l0B4`Po`0nA`[o04Q<1_l0D4h4o`1EB`Ko05Y81?l0GTD3o`1S@0?o06Lk1?l0
K3D4o`1a;`;o07DW1?l0NQl2o`1n5`Co08<=0_l0R0<3o`N<00?o4Y400_lNUP03obbJ00?o>Il00_m8
X`03oeNX00?oIjd00_mg/@03ohRf00;oVkX00on]_`03ol7400?ob;/00_o=/003om6S00?oeYH00ooK
R003ommj00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0ooONP03
om^800?oeYH00ooAX`03olf`00;ob;/00oo1a003ojfo00;oVkX00on8]P03ogNa00;oIjd00omGZ002
odRS00?o>Il00ol/VP02oajF00?o4Y400ol7S003o`280`;o08<=0ol0OQL3o`1j7`Co07DW0ol0LBl3
o`1/=@Co06Lk1?l0Hd04o`1NA@Co05Y81Ol0ED/5o`1@CPSo04Q<3?l0?TLAo`0e@`_o03i72?l0B4`4
o`1@CPKo05E;1?l0FTP4o`1NA@Co06=00ol0Ic/4o`1/=@?o074_0ol0MBL3o`1j7`?o07hG0ol0P`d3
o`280`;o1h`00olBT@03oajF00;o;9X00oliW`03odRS00;oEjP00omW[@02ogNa00?oR;H00onK^P02
ojfo00?o`L@00oo8^`02olf`00?odJ<00ooFUP03om^800?oggX01Oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_ooool3ommj00?ofhP00ooFUP03om6S00;ocK000oo8^`03ol74
00;o[Kl00onK^P03ohRf00;oMk400omW[@03oeNX00;oB:<00oliW`02obbJ00?o7YH00olBT@02o`N<
00?o08P30ol0P`d3o`1n5`?o07XO0ol0MBL3o`1a;`Co06`e0ol0Ic/3o`1S@0Co05i51?l0FTP6o`1E
B`Co051>2?l0B4`:o`0nAaSo03E32_l0?TL8o`18C0Co051>1_l0ED/4o`1JB0Co05i50ol0Hd03o`1W
>`Co06`e0ol0LBl3o`1e9`?o07XO0ol0OQL3o`233@?o08P30_l7S003oa:A00?o7YH00_l/VP03ocVO
00?oB:<00_mGZ003ofN]00;oMk400on8]P02oi^j00?o[Kl00oo1a002olRk00?ocK000ooAX`03omJF
00?ofhP00_oONP05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;o
ggX00ooKR003omJF00?odJ<00oo=/002olRk00?o`L@00on]_`02oi^j00?oR;H00_mg/@03ofN]00?o
EjP00_m8X`03ocVO00;o;9X00olNUP03oa:A00;o1h`00ol0R0<3o`233@?o07hG0ol0NQl3o`1e9`?o
074_0ol0K3D4o`1W>`?o06=01?l0GTD4o`1JB0Go05E;1Ol0D4h7o`18C0So03i78?l0=D<8o`0nA`Ko
04Q<1_l0D4h4o`1EB`Co05Y81?l0GTD4o`1S@0?o06Lk1?l0K3D3o`1a;`?o07DW0_l0NQl4o`1n5`;o
08<=0ol0R0<3o`N<00;o4Y400olNUP02obbJ00?o>Il00om8X`02oeNX00?oIjd00_mg/@03ohRf00;o
VkX00on]_`03ol7400;ob;/00oo=/003om6S00?oeYH00ooKR002ommj00Gooooo0Ol00001ooooo`7o
oooo000Fooooo`;o00000oooool2ommj00?ofhP00ooFUP03om6S00?ocK000_o8^`03ol7400?o[Kl0
0_nK^P03ohRf00;oMk400omW[@02oeNX00?oB:<00oliW`02obbJ00?o7YH00_lBT@03o`N<00?o08P3
0ol0P`d3o`1n5`;o07XO0ol0MBL3o`1a;`Co06`e0ol0Ic/3o`1S@0Co05i51?l0FTP4o`1EB`Ko051>
1_l0B4`6o`0nAa3o03E32Ol0;Ch?o`0e@`Ko03i71_l0B4`6o`1@CPCo05E;1?l0FTP4o`1NA@?o06=0
0ol0Ic/4o`1/=@?o074_0ol0MBL2o`1j7`Co07hG0_l0P`d3o`280`?o1h`00_lBT@03oajF00;o;9X0
0oliW`03odRS00;oEjP00omW[@02ogNa00?oR;H00_nK^P03ojfo00?o`L@00_o8^`03olf`00?odJ<0
0ooFUP03om^80003ommj0?oooooooooo00;ooooo0_l00002ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`04ommj0?oKR03ofhP0om^800?oeYH00ooAX`03olf`00;ob;/00oo1a003ojfo00;oVkX0
0on8]P02ogNa00?oIjd00omGZ002odRS00?o>Il00_l/VP03oajF00;o4Y400ol7S003o`280`?o08<=
0_l0OQL3o`1j7`?o07DW0ol0LBl4o`1/=@?o06Lk0ol0Hd04o`1NA@Co05Y81?l0ED/5o`1@CPKo04Q<
1_l0?TL:o`0e@aSo02dn2_l0=D<6o`0nA`Ko04Q<1?l0D4h4o`1EB`Co05Y81?l0GTD4o`1S@0?o06Lk
0ol0K3D3o`1a;`?o07DW0ol0NQl3o`1n5`?o08<=0_l0R0<3o`N<00;o4Y400olNUP03obbJ00;o>Il0
0om8X`02oeNX00?oIjd00_mg/@03ohRf00?oVkX00_n]_`03ol7400?ob;/00_o=/003om6S00?oeYH0
0ooKR0000ooONP3oooooooooo`03ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`04ommj0?oKR03ofhP0om^800?oeYH00ooAX`02olf`00?ob;/00oo1a002ojfo00?oVkX0
0on8]P02ogNa00?oIjd00omGZ002odRS00;o>Il00ol/VP03oajF00;o4Y400ol7S003o`280`;o08<=
0ol0OQL3o`1j7`?o07DW0ol0LBl3o`1/=@?o06Lk1?l0Hd03o`1NA@Co05Y81?l0ED/4o`1@CPKo04Q<
1_l0?TL:o`0e@aco02dn2_l0=D<6o`0nA`Ko04Q<1?l0D4h4o`1EB`Co05Y81?l0GTD3o`1S@0?o06Lk
0ol0K3D3o`1a;`?o07DW0ol0NQl3o`1n5`?o08<=0_l0R0<3o`N<00;o4Y400olNUP03obbJ00;o>Il0
0om8X`02oeNX00?oIjd00_mg/@03ohRf00;oVkX00on]_`03ol7400;ob;/00oo=/003om6S00?oeYH0
0ooKR005ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04ommj0?oK
R03ofhP0om^800;oeYH00ooAX`03olf`00?ob;/00_o1a003ojfo00;oVkX00on8]P02ogNa00?oIjd0
0omGZ002odRS00?o>Il00_l/VP03oajF00;o4Y400ol7S003o`280`;o08<=0ol0OQL3o`1j7`?o07DW
0ol0LBl3o`1/=@?o06Lk1?l0Hd03o`1NA@Co05Y81?l0ED/4o`1@CPKo04Q<1Ol0?TL8o`0e@bCo02dn
2?l0=D<5o`0nA`Go04Q<1Ol0D4h4o`1EB`?o05Y81?l0GTD3o`1S@0Co06Lk0ol0K3D3o`1a;`;o07DW
0ol0NQl3o`1n5`?o08<=0_l0R0<3o`N<00?o4Y400_lNUP03obbJ00;o>Il00om8X`02oeNX00?oIjd0
0_mg/@03ohRf00;oVkX00on]_`03ol7400;ob;/00oo=/003om6S00?oeYH00ooKR005ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`CofhP00_oFUP03om6S00?ocK000_o8
^`03ol7400?o[Kl00_nK^P03ohRf00;oMk400omW[@02oeNX00?oB:<00oliW`02obbJ00;o7YH00olB
T@03o`N<00;o08P30ol0P`d3o`1n5`?o07XO0_l0MBL3o`1a;`?o06`e1?l0Ic/3o`1S@0?o05i51?l0
FTP4o`1EB`Co051>1_l0B4`4o`0nA`So03E33?l0;ChAo`0U>@_o02dn2?l0=D<4o`0nA`Ko04Q<1?l0
D4h4o`1EB`Co05Y80ol0GTD3o`1S@0Co06Lk0ol0K3D3o`1a;`;o07DW0ol0NQl3o`1n5`?o08<=0_l0
R0<3o`N<00?o4Y400_lNUP03obbJ00;o>Il00om8X`02oeNX00?oIjd00_mg/@03ohRf00;oVkX00on]
_`02ol7400?ob;/00oo=/002om6S00?oeYH00ooKR005ooooo`7o00000Oooool1ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`?ofhP00ooFUP02om6S00?ocK000oo8^`02ol7400?o[Kl00onK^P02
ohRf00?oMk400_mW[@03oeNX00;oB:<00oliW`02obbJ00?o7YH00_lBT@03o`N<00;o08P30ol0P`d3
o`1n5`?o07XO0_l0MBL3o`1a;`?o06`e1?l0Ic/3o`1S@0?o05i51?l0FTP4o`1EB`Co051>1Ol0B4`5
o`0nA`Oo03E32Ol0;ChIo`0U>@[o02dn1_l0=D<6o`0nA`Go04Q<1?l0D4h4o`1EB`?o05Y81?l0GTD3
o`1S@0?o06Lk0ol0K3D3o`1a;`?o07DW0_l0NQl3o`1n5`?o08<=0_l0R0<3o`N<00?o4Y400_lNUP03
obbJ00;o>Il00om8X`02oeNX00?oIjd00_mg/@03ohRf00;oVkX00on]_`02ol7400?ob;/00oo=/002
om6S00CoeYH00_oKR005ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02oooo
o`;ofhP01?oFUP02om6S00?ocK000oo8^`02ol7400?o[Kl00onK^P02ohRf00;oMk400omW[@03oeNX
00;oB:<00_liW`03obbJ00?o7YH00_lBT@03o`N<00;o08P30ol0P`d3o`1n5`;o07XO0ol0MBL3o`1a
;`?o06`e0ol0Ic/3o`1S@0Co05i50ol0FTP4o`1EB`Co051>1?l0B4`6o`0nA`Ko03E32?l0;ChPo`0U
>@So02dn1_l0=D<6o`0nA`Co04Q<1?l0D4h4o`1EB`Co05Y80ol0GTD3o`1S@0?o06Lk0ol0K3D3o`1a
;`?o07DW0_l0NQl3o`1n5`?o08<=0_l0R0<3o`N<00?o4Y400_lNUP03obbJ00;o>Il00om8X`02oeNX
00;oIjd00omg/@02ohRf00?oVkX00on]_`02ol7400?ob;/00_o=/003om6S00?oeYH00_oKR005oooo
o`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;ofhP00ooFUP03om6S00;o
cK000oo8^`03ol7400;o[Kl00onK^P02ohRf00?oMk400_mW[@03oeNX00;oB:<00oliW`02obbJ00?o
7YH00_lBT@03o`N<00;o08P30ol0P`d3o`1n5`;o07XO0ol0MBL3o`1a;`?o06`e0ol0Ic/3o`1S@0Co
05i50ol0FTP4o`1EB`Co051>1?l0B4`5o`0nA`Ko03E32?l0;Ch>o`0U>@Wo01he3Ol09CT8o`0]?PKo
03E31?l0?TL5o`18C0Co051>1?l0ED/3o`1JB0?o05i51?l0Hd02o`1W>`?o06`e0ol0LBl3o`1e9`?o
07XO0_l0OQL3o`233@;o08P30ol7S003oa:A00;o7YH00ol/VP02ocVO00?oB:<00_mGZ002ofN]00?o
Mk400on8]P02oi^j00?o[Kl00_o1a003olRk00;ocK000ooAX`03omJF00;ofhP01Oooool1o`00007o
oooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2om^800?oeYH00ooAX`02olf`00?ob;/0
0oo1a002ojfo00;oVkX00on8]P03ogNa00;oIjd00_mGZ003odRS00?o>Il00_l/VP02oajF00?o4Y40
0ol7S002o`280`?o08<=0_l0OQL3o`1j7`?o07DW0ol0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y8
1?l0ED/4o`1@CPCo04Q<1Ol0?TL5o`0e@`So02dn2_l09CTEo`0N=@Wo02Di2?l0;Ch5o`0e@`Go03i7
1?l0B4`4o`1@CPCo05E;0ol0FTP3o`1NA@Co06=00_l0Ic/3o`1/=@?o074_0ol0MBL3o`1j7`;o07hG
0ol0P`d2o`280`?o1h`00olBT@02oajF00;o;9X00oliW`02odRS00?oEjP00_mW[@03ogNa00;oR;H0
0onK^P02ojfo00?o`L@00_o8^`03olf`00?odJ<00ooFUP000ooKR03oooooooooo`03ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04om^80?oFUP3oeYH0omJF00?odJ<0
0oo=/002olRk00?o`L@00_n]_`03oi^j00;oR;H00omg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X0
0olNUP02oa:A00?o1h`00_l0R0<3o`233@;o07hG0ol0NQl3o`1e9`?o074_0ol0K3D3o`1W>`?o06=0
0ol0GTD3o`1JB0Co05E;1?l0D4h4o`18C0Go03i71Ol0=D<7o`0]?PSo02Di7?l07SD8o`0U>@Oo02dn
1Ol0=D<5o`0nA`Co04Q<1?l0D4h3o`1EB`?o05Y81?l0GTD3o`1S@0?o06Lk0ol0K3D2o`1a;`?o07DW
0ol0NQl2o`1n5`?o08<=0ol0R0<2o`N<00?o4Y400_lNUP03obbJ00;o>Il00_m8X`03oeNX00;oIjd0
0omg/@02ohRf00?oVkX00_n]_`03ol7400;ob;/00oo=/003om6S00?oeYH000?ofhP0ooooooooool0
0oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool01?oKR03oeYH0omJF
0?oFUP03om6S00?ocK000_o8^`03ol7400;o[Kl00onK^P02ohRf00?oMk400_mW[@03oeNX00;oB:<0
0_liW`03obbJ00?o7YH00_lBT@02o`N<00?o08P30ol0P`d2o`1n5`?o07XO0ol0MBL2o`1a;`?o06`e
0ol0Ic/3o`1S@0Co05i50ol0FTP3o`1EB`Co051>1?l0B4`4o`0nA`Ko03E31_l0;Ch8o`0U>B3o01he
2?l09CT6o`0]?PKo03E31?l0?TL4o`18C0Co051>0ol0ED/3o`1JB0Co05i50ol0Hd03o`1W>`?o06`e
0_l0LBl3o`1e9`?o07XO0_l0OQL3o`233@;o08P30ol7S002oa:A00?o7YH00_l/VP03ocVO00;oB:<0
0omGZ002ofN]00;oMk400on8]P02oi^j00?o[Kl00oo1a002olRk00?ocK000ooAX`02omJF0003om^8
0?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00Co
fhP0omJF0?oFUP3oeYH00_oAX`03olf`00?ob;/00_o1a003ojfo00;oVkX00on8]P02ogNa00?oIjd0
0_mGZ002odRS00?o>Il00_l/VP03oajF00;o4Y400ol7S002o`280`?o08<=0_l0OQL3o`1j7`?o07DW
0ol0LBl2o`1/=@?o06Lk0ol0Hd04o`1NA@?o05Y80ol0ED/4o`1@CPCo04Q<1?l0?TL5o`0e@`Ko02dn
2?l09CT>o`0N=@Wo01L`3Ol07SD8o`0U>@Go02dn1Ol0=D<5o`0nA`Co04Q<0ol0D4h3o`1EB`Co05Y8
0ol0GTD3o`1S@0?o06Lk0ol0K3D2o`1a;`?o07DW0ol0NQl2o`1n5`?o08<=0_l0R0<3o`N<00;o4Y40
0olNUP02obbJ00?o>Il00_m8X`03oeNX00;oIjd00_mg/@03ohRf00?oVkX00_n]_`03ol7400;ob;/0
0oo=/003om6S00;oeYH000?ofhP0ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo0_l0
0003ooooo`04om^80?oFUP3oeYH0omJF00;odJ<00oo=/003olRk00;o`L@00_n]_`03oi^j00?oR;H0
0_mg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00olNUP02oa:A00?o1h`00_l0R0<3o`233@;o07hG
0ol0NQl3o`1e9`;o074_0ol0K3D3o`1W>`?o06=00ol0GTD4o`1JB0?o05E;0ol0D4h4o`18C0Co03i7
1_l0=D<4o`0]?PSo02Di2_l07SDEo`0G<0Wo01he2?l09CT4o`0]?PKo03E31?l0?TL4o`18C0?o051>
0ol0ED/4o`1JB0?o05i50ol0Hd03o`1W>`?o06`e0_l0LBl3o`1e9`?o07XO0_l0OQL3o`233@;o08P3
0ol7S002oa:A00?o7YH00_l/VP03ocVO00;oB:<00_mGZ003ofN]00;oMk400on8]P02oi^j00?o[Kl0
0_o1a003olRk00;ocK000ooAX`03omJF00Cooooo0_l00002ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`?oeYH00ooAX`02olf`00?ob;/00oo1a002ojfo00?oVkX00_n8]P02ogNa00?oIjd00_mG
Z003odRS00;o>Il00_l/VP03oajF00;o4Y400ol7S002o`280`?o08<=0_l0OQL3o`1j7`?o07DW0_l0
LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y81?l0ED/3o`1@CPCo04Q<1?l0?TL5o`0e@`Go02dn1ol0
9CT9o`0N=AWo01L`2_l07SD6o`0U>@Ko02dn1?l0=D<4o`0nA`Co04Q<1?l0D4h3o`1EB`?o05Y80ol0
GTD3o`1S@0?o06Lk0ol0K3D2o`1a;`?o07DW0ol0NQl2o`1n5`?o08<=0_l0R0<3o`N<00;o4Y400olN
UP02obbJ00?o>Il00_m8X`02oeNX00?oIjd00_mg/@03ohRf00;oVkX00on]_`02ol7400?ob;/00_o=
/003om6S00?oeYH01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool3
omJF00?odJ<00_o=/003olRk00?o`L@00_n]_`02oi^j00?oR;H00_mg/@03ofN]00;oEjP00_m8X`03
ocVO00;o;9X00olNUP02oa:A00?o1h`00_l0R0<3o`233@;o07hG0ol0NQl3o`1e9`;o074_0ol0K3D3
o`1W>`?o06=00ol0GTD3o`1JB0?o05E;1?l0D4h4o`18C0Co03i71?l0=D<5o`0]?PKo02Di2?l07SDP
o`0G<0So01he1_l09CT5o`0]?PGo03E31?l0?TL3o`18C0Co051>0ol0ED/3o`1JB0?o05i50ol0Hd03
o`1W>`?o06`e0_l0LBl3o`1e9`?o07XO0_l0OQL3o`233@;o08P30ol7S002oa:A00;o7YH00ol/VP02
ocVO00?oB:<00_mGZ002ofN]00?oMk400_n8]P03oi^j00;o[Kl00oo1a002olRk00?ocK000ooAX`02
omJF00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_oFUP03om6S
00?ocK000_o8^`03ol7400;o[Kl00onK^P02ohRf00?oMk400_mW[@02oeNX00?oB:<00_liW`03obbJ
00;o7YH00olBT@02o`N<00;o08P30ol0P`d3o`1n5`;o07XO0ol0MBL2o`1a;`?o06`e0ol0Ic/3o`1S
@0?o05i50ol0FTP3o`1EB`Co051>1?l0B4`4o`0nA`Co03E31Ol0;Ch6o`0U>@Oo01he9?l05c07o`0N
=@Ko02Di1Ol0;Ch4o`0e@`Co03i70ol0B4`4o`1@CP?o05E;0ol0FTP3o`1NA@?o06=00ol0Ic/3o`1/
=@;o074_0ol0MBL3o`1j7`;o07hG0ol0P`d2o`280`?o1h`00_lBT@02oajF00?o;9X00_liW`03odRS
00;oEjP00_mW[@03ogNa00;oR;H00onK^P02ojfo00?o`L@00_o8^`03olf`00?odJ<00_oFUP05oooo
o`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;oeYH00ooAX`03olf`00;o
b;/00oo1a002ojfo00?oVkX00_n8]P03ogNa00;oIjd00_mGZ003odRS00;o>Il00ol/VP02oajF00?o
4Y400_l7S002o`280`?o08<=0ol0OQL2o`1j7`?o07DW0_l0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@?o
05Y80ol0ED/4o`1@CP?o04Q<1?l0?TL4o`0e@`Go02dn1_l09CT6o`0N=@co01L`4Ol04R`;o`0G<0Ko
01he1_l09CT5o`0]?PCo03E31?l0?TL3o`18C0Co051>0ol0ED/3o`1JB0?o05i50ol0Hd03o`1W>`?o
06`e0_l0LBl3o`1e9`?o07XO0_l0OQL3o`233@;o08P30_l7S003oa:A00;o7YH00ol/VP02ocVO00;o
B:<00omGZ002ofN]00?oMk400_n8]P02oi^j00?o[Kl00_o1a003olRk00?ocK000_oAX`02omJF00Go
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_oFUP03om6S00;ocK00
0oo8^`02ol7400?o[Kl00_nK^P03ohRf00;oMk400_mW[@03oeNX00;oB:<00oliW`02obbJ00;o7YH0
0olBT@02o`N<00?o08P30_l0P`d3o`1n5`;o07XO0ol0MBL2o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i5
0ol0FTP3o`1EB`Co051>0ol0B4`4o`0nA`Co03E31Ol0;Ch5o`0U>@Oo01he2Ol05c0Ho`0B;0Wo01L`
1_l07SD6o`0U>@Co02dn1?l0=D<4o`0nA`Co04Q<0ol0D4h3o`1EB`?o05Y80ol0GTD3o`1S@0?o06Lk
0ol0K3D2o`1a;`?o07DW0ol0NQl2o`1n5`?o08<=0_l0R0<2o`N<00?o4Y400_lNUP03obbJ00;o>Il0
0_m8X`03oeNX00;oIjd00omg/@02ohRf00;oVkX00on]_`02ol7400?ob;/00oo=/002om6S00;oeYH0
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2omJF00;odJ<00oo=
/003olRk00;o`L@00on]_`02oi^j00?oR;H00_mg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00_lN
UP03oa:A00;o1h`00ol0R0<2o`233@?o07hG0_l0NQl3o`1e9`;o074_0ol0K3D3o`1W>`?o06=00ol0
GTD3o`1JB0?o05E;0ol0D4h4o`18C0Co03i71?l0=D<4o`0]?PKo02Di1_l07SD8o`0G<1co018/2?l0
5c06o`0N=@Ko02Di1?l0;Ch4o`0e@`Co03i71?l0B4`3o`1@CP?o05E;0ol0FTP3o`1NA@?o06=00ol0
Ic/3o`1/=@;o074_0ol0MBL2o`1j7`?o07hG0_l0P`d3o`280`;o1h`00olBT@02oajF00;o;9X00oli
W`02odRS00;oEjP00omW[@02ogNa00?oR;H00_nK^P02ojfo00?o`L@00_o8^`03olf`00?odJ<000?o
eYH0ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool0
1?oFUP3odJ<0om6S0?oAX`03olf`00;ob;/00oo1a002ojfo00?oVkX00_n8]P02ogNa00?oIjd00_mG
Z003odRS00;o>Il00_l/VP03oajF00;o4Y400_l7S003o`280`;o08<=0ol0OQL2o`1j7`?o07DW0ol0
LBl2o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y80ol0ED/3o`1@CPCo04Q<0ol0?TL5o`0e@`Co02dn1Ol0
9CT6o`0N=@So01L`8?l04R`8o`0G<0Ko01he1Ol09CT4o`0]?PCo03E31?l0?TL3o`18C0?o051>0ol0
ED/3o`1JB0?o05i50ol0Hd03o`1W>`?o06`e0_l0LBl3o`1e9`;o07XO0ol0OQL2o`233@?o08P30_l7
S003oa:A00;o7YH00_l/VP03ocVO00;oB:<00_mGZ003ofN]00;oMk400on8]P02oi^j00;o[Kl00oo1
a002olRk00?ocK000ooAX`000ooFUP3oooooooooo`03ooooo`7o00000Oooool1ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`04omJF0?oAX`3odJ<0om6S00?ocK000_o8^`03ol7400;o[Kl00_nK
^P03ohRf00;oMk400omW[@02oeNX00;oB:<00oliW`02obbJ00?o7YH00_lBT@02o`N<00?o08P30_l0
P`d3o`1n5`;o07XO0ol0MBL3o`1a;`;o06`e0ol0Ic/3o`1S@0?o05i50ol0FTP3o`1EB`?o051>0ol0
B4`4o`0nA`Co03E31?l0;Ch5o`0U>@Ko01he1ol05c0To`0B;0Oo01L`1_l07SD5o`0U>@Co02dn1?l0
=D<4o`0nA`?o04Q<0ol0D4h3o`1EB`?o05Y80ol0GTD3o`1S@0?o06Lk0_l0K3D3o`1a;`?o07DW0_l0
NQl3o`1n5`;o08<=0_l0R0<3o`N<00;o4Y400olNUP02obbJ00;o>Il00om8X`02oeNX00;oIjd00omg
/@02ohRf00;oVkX00on]_`02ol7400?ob;/00oo=/002om6S0003omJF0?oooooooooo00?ooooo0Ol0
0001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00CoeYH0om6S0?oAX`3odJ<00_o=
/003olRk00;o`L@00on]_`02oi^j00?oR;H00_mg/@02ofN]00?oEjP00_m8X`02ocVO00?o;9X00_lN
UP02oa:A00?o1h`00_l0R0<3o`233@;o07hG0ol0NQl2o`1e9`?o074_0_l0K3D3o`1W>`?o06=00ol0
GTD3o`1JB0?o05E;0ol0D4h3o`18C0Co03i71?l0=D<4o`0]?PGo02Di1_l07SD7o`0G<0_o018/4Ol0
3BL:o`0B;0Oo01L`1Ol07SD5o`0U>@Co02dn1?l0=D<4o`0nA`?o04Q<0ol0D4h3o`1EB`?o05Y80ol0
GTD3o`1S@0?o06Lk0_l0K3D3o`1a;`?o07DW0_l0NQl3o`1n5`;o08<=0_l0R0<3o`N<00;o4Y400olN
UP02obbJ00;o>Il00om8X`02oeNX00;oIjd00omg/@02ohRf00;oVkX00on]_`02ol7400?ob;/00oo=
/002om6S0003omJF0?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooo
oooo00;ooooo00CoeYH0om6S0?oAX`3odJ<00_o=/003olRk00;o`L@00on]_`02oi^j00;oR;H00omg
/@02ofN]00?oEjP00_m8X`02ocVO00?o;9X00_lNUP02oa:A00?o1h`00_l0R0<3o`233@;o07hG0ol0
NQl2o`1e9`?o074_0_l0K3D3o`1W>`?o06=00ol0GTD3o`1JB0?o05E;0ol0D4h3o`18C0Co03i71?l0
=D<4o`0]?PGo02Di1Ol07SD7o`0G<0[o018/5Ol03BL9o`0B;0Oo01L`1Ol07SD5o`0U>@Co02dn1?l0
=D<4o`0nA`?o04Q<0ol0D4h3o`1EB`?o05Y80ol0GTD3o`1S@0?o06Lk0_l0K3D3o`1a;`;o07DW0ol0
NQl2o`1n5`?o08<=0_l0R0<2o`N<00?o4Y400_lNUP02obbJ00?o>Il00_m8X`02oeNX00?oIjd00_mg
/@03ohRf00;oVkX00_n]_`03ol7400;ob;/00oo=/003om6S00Gooooo0Ol00001ooooo`7ooooo000F
ooooo`03o`000?oooooooooo00;ooooo0ooAX`03olf`00;ob;/00oo1a002ojfo00?oVkX00_n8]P02
ogNa00?oIjd00_mGZ002odRS00?o>Il00_l/VP02oajF00?o4Y400_l7S003o`280`;o08<=0_l0OQL3
o`1j7`;o07DW0ol0LBl3o`1/=@;o06Lk0ol0Hd03o`1NA@?o05Y80ol0ED/3o`1@CP?o04Q<1?l0?TL4
o`0e@`Co02dn1?l09CT6o`0N=@Ko01L`2_l04R`Ho`0=9`[o018/1_l05c05o`0N=@Co02Di1?l0;Ch4
o`0e@`Co03i70ol0B4`3o`1@CP?o05E;0ol0FTP3o`1NA@?o06=00ol0Ic/2o`1/=@?o074_0_l0MBL3
o`1j7`;o07hG0ol0P`d2o`280`;o1h`00olBT@02oajF00;o;9X00oliW`02odRS00;oEjP00omW[@02
ogNa00?oR;H00_nK^P02ojfo00?o`L@00_o8^`03olf`00?odJ<01Oooool1o`00007ooooo0Oooool0
01Kooooo0_l00003ooooo`?odJ<00oo=/002olRk00?o`L@00_n]_`03oi^j00;oR;H00_mg/@03ofN]
00;oEjP00_m8X`03ocVO00;o;9X00_lNUP03oa:A00;o1h`00ol0R0<2o`233@;o07hG0ol0NQl2o`1e
9`?o074_0ol0K3D2o`1W>`?o06=00ol0GTD3o`1JB0?o05E;0ol0D4h3o`18C0Co03i71?l0=D<4o`0]
?PCo02Di1Ol07SD6o`0G<0Wo018/7?l03BL9o`0B;0Ko01L`1Ol07SD4o`0U>@Co02dn1?l0=D<4o`0n
A`?o04Q<0ol0D4h3o`1EB`?o05Y80ol0GTD3o`1S@0;o06Lk0ol0K3D2o`1a;`?o07DW0_l0NQl3o`1n
5`;o08<=0ol0R0<2o`N<00;o4Y400olNUP02obbJ00;o>Il00om8X`02oeNX00;oIjd00omg/@02ohRf
00;oVkX00on]_`02ol7400?ob;/00_o=/003om6S00Cooooo0_l00002ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`?odJ<00_o=/003olRk00;o`L@00on]_`02oi^j00?oR;H00_mg/@02ofN]00?o
EjP00_m8X`02ocVO00?o;9X00_lNUP02oa:A00?o1h`00_l0R0<2o`233@?o07hG0_l0NQl3o`1e9`;o
074_0ol0K3D3o`1W>`;o06=00ol0GTD3o`1JB0?o05E;0ol0D4h3o`18C0Co03i70ol0=D<4o`0]?PGo
02Di1Ol07SD6o`0G<0So018/8?l03BL8o`0B;0Go01L`1_l07SD4o`0U>@Co02dn0ol0=D<4o`0nA`?o
04Q<0ol0D4h3o`1EB`?o05Y80ol0GTD3o`1S@0;o06Lk0ol0K3D2o`1a;`?o07DW0_l0NQl3o`1n5`;o
08<=0ol0R0<2o`N<00;o4Y400olNUP02obbJ00;o>Il00om8X`02oeNX00;oIjd00omg/@02ohRf00;o
VkX00on]_`02ol7400?ob;/00_o=/003om6S00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`00
0?oooooooooo00;ooooo0ooAX`02olf`00?ob;/00_o1a003ojfo00;oVkX00on8]P02ogNa00;oIjd0
0_mGZ003odRS00;o>Il00ol/VP02oajF00;o4Y400ol7S002o`280`;o08<=0ol0OQL2o`1j7`?o07DW
0_l0LBl3o`1/=@;o06Lk0ol0Hd03o`1NA@?o05Y80ol0ED/3o`1@CP?o04Q<1?l0?TL3o`0e@`Co02dn
1Ol09CT5o`0N=@Go01L`1ol04R`To`0=9`Oo018/1Ol05c06o`0N=@Co02Di1?l0;Ch3o`0e@`Co03i7
0ol0B4`3o`1@CP?o05E;0ol0FTP3o`1NA@;o06=00ol0Ic/3o`1/=@;o074_0ol0MBL2o`1j7`;o07hG
0ol0P`d2o`280`;o1h`00olBT@02oajF00;o;9X00oliW`02odRS00;oEjP00omW[@02ogNa00;oR;H0
0onK^P02ojfo00?o`L@00_o8^`03olf`00;odJ<01Oooool1o`00007ooooo0Oooool001Kooooo00?o
0000ooooooooool00_ooool2om6S00?ocK000_o8^`03ol7400;o[Kl00onK^P02ohRf00;oMk400omW
[@02oeNX00;oB:<00oliW`02obbJ00;o7YH00olBT@02o`N<00;o08P30ol0P`d2o`1n5`?o07XO0_l0
MBL3o`1a;`;o06`e0ol0Ic/3o`1S@0;o05i50ol0FTP3o`1EB`?o051>0ol0B4`4o`0nA`?o03E31?l0
;Ch5o`0U>@Co01he1_l05c07o`0B;0go00dW3Ol0228<o`0=9`Ko018/1_l05c05o`0N=@Co02Di1?l0
;Ch3o`0e@`Co03i70ol0B4`3o`1@CP?o05E;0ol0FTP3o`1NA@;o06=00ol0Ic/3o`1/=@;o074_0ol0
MBL2o`1j7`;o07hG0ol0P`d2o`280`;o1h`00olBT@02oajF00;o;9X00oliW`02odRS00;oEjP00omW
[@02ogNa00;oR;H00onK^P02ojfo00?o`L@00_o8^`03olf`00;odJ<01Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool2om6S00?ocK000_o8^`03ol7400;o[Kl00onK^P02
ohRf00;oMk400omW[@02oeNX00;oB:<00oliW`02obbJ00;o7YH00olBT@02o`N<00;o08P30ol0P`d2
o`1n5`?o07XO0_l0MBL3o`1a;`;o06`e0ol0Ic/3o`1S@0;o05i50ol0FTP3o`1EB`?o051>0ol0B4`4
o`0nA`?o03E31?l0;Ch4o`0U>@Go01he1_l05c06o`0B;0[o00dW5?l0228:o`0=9`Ko018/1_l05c05
o`0N=@Co02Di1?l0;Ch3o`0e@`Co03i70ol0B4`3o`1@CP?o05E;0ol0FTP2o`1NA@?o06=00ol0Ic/2
o`1/=@?o074_0_l0MBL3o`1j7`;o07hG0_l0P`d3o`280`;o1h`00_lBT@03oajF00;o;9X00_liW`02
odRS00?oEjP00_mW[@02ogNa00?oR;H00_nK^P03ojfo00;o`L@00oo8^`02olf`00;odJ<01Oooool1
o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2om6S00?ocK000_o8^`03ol74
00;o[Kl00_nK^P03ohRf00;oMk400_mW[@03oeNX00;oB:<00_liW`03obbJ00;o7YH00_lBT@03o`N<
00;o08P30_l0P`d3o`1n5`;o07XO0ol0MBL2o`1a;`?o06`e0_l0Ic/3o`1S@0?o05i50_l0FTP3o`1E
B`?o051>1?l0B4`3o`0nA`?o03E31?l0;Ch4o`0U>@Go01he1Ol05c07o`0B;0Wo00dW6?l02289o`0=
9`Ko018/1Ol05c05o`0N=@Co02Di1?l0;Ch3o`0e@`Co03i70ol0B4`3o`1@CP?o05E;0ol0FTP2o`1N
A@?o06=00ol0Ic/2o`1/=@?o074_0_l0MBL3o`1j7`;o07hG0_l0P`d3o`280`;o1h`00_lBT@03oajF
00;o;9X00_liW`02odRS00?oEjP00_mW[@02ogNa00?oR;H00_nK^P03ojfo00;o`L@00oo8^`02olf`
00;odJ<01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2om6S00;o
cK000oo8^`03ol7400;o[Kl00_nK^P03ohRf00;oMk400_mW[@03oeNX00;oB:<00_liW`03obbJ00;o
7YH00_lBT@03o`N<00;o08P30_l0P`d3o`1n5`;o07XO0ol0MBL2o`1a;`?o06`e0_l0Ic/3o`1S@0?o
05i50_l0FTP3o`1EB`?o051>1?l0B4`3o`0nA`?o03E31?l0;Ch4o`0U>@Go01he1Ol05c06o`0B;0Wo
00dW6ol02288o`0=9`Ko018/1Ol05c05o`0N=@Co02Di1?l0;Ch3o`0e@`?o03i70ol0B4`3o`1@CP?o
05E;0ol0FTP3o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0ol0MBL2o`1j7`;o07hG0ol0P`d2o`280`;o
1h`00olBT@02oajF00;o;9X00oliW`02odRS00;oEjP00_mW[@03ogNa00;oR;H00onK^P02ojfo00;o
`L@00oo8^`02olf`00;odJ<01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool2om6S00;ocK000oo8^`02ol7400?o[Kl00_nK^P02ohRf00?oMk400_mW[@02oeNX00?oB:<0
0_liW`02obbJ00;o7YH00olBT@02o`N<00;o08P30ol0P`d2o`1n5`?o07XO0_l0MBL2o`1a;`?o06`e
0ol0Ic/2o`1S@0?o05i50ol0FTP3o`1EB`?o051>0ol0B4`3o`0nA`Co03E30ol0;Ch4o`0U>@Go01he
1Ol05c06o`0B;0Wo00dW7?l02288o`0=9`Ko018/1Ol05c05o`0N=@Co02Di1?l0;Ch3o`0e@`?o03i7
0ol0B4`3o`1@CP?o05E;0ol0FTP3o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0ol0MBL2o`1j7`;o07hG
0ol0P`d2o`280`;o1h`00olBT@02oajF00;o;9X00oliW`02odRS00;oEjP00_mW[@03ogNa00;oR;H0
0onK^P02ojfo00;o`L@00oo8^`02olf`00;odJ<01Oooool1o`00007ooooo0Oooool001Kooooo00?o
0000ooooooooool00_ooool2om6S00;ocK000oo8^`02ol7400?o[Kl00_nK^P02ohRf00?oMk400_mW
[@02oeNX00?oB:<00_liW`02obbJ00;o7YH00olBT@02o`N<00;o08P30ol0P`d2o`1n5`?o07XO0_l0
MBL2o`1a;`?o06`e0ol0Ic/2o`1S@0?o05i50ol0FTP3o`1EB`?o051>0ol0B4`3o`0nA`Co03E30ol0
;Ch4o`0U>@Go01he1Ol05c06o`0B;0Oo00dW8?l02288o`0=9`Go018/1Ol05c05o`0N=@Co02Di0ol0
;Ch4o`0e@`?o03i70ol0B4`3o`1@CP?o05E;0ol0FTP2o`1NA@?o06=00ol0Ic/2o`1/=@?o074_0_l0
MBL2o`1j7`?o07hG0_l0P`d2o`280`?o1h`00_lBT@02oajF00?o;9X00_liW`02odRS00?oEjP00_mW
[@02ogNa00;oR;H00onK^P02ojfo00?o`L@00_o8^`03olf`0003om6S0?oooooooooo00?ooooo0Ol0
0001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00CodJ<0olf`0?o=/03ocK000_o8
^`03ol7400;o[Kl00onK^P02ohRf00;oMk400omW[@02oeNX00;oB:<00oliW`02obbJ00;o7YH00_lB
T@03o`N<00;o08P30_l0P`d3o`1n5`;o07XO0ol0MBL2o`1a;`?o06`e0_l0Ic/3o`1S@0;o05i50ol0
FTP3o`1EB`?o051>0ol0B4`3o`0nA`Co03E30ol0;Ch4o`0U>@Go01he1Ol05c06o`0B;0Oo00dW8Ol0
2288o`0=9`Go018/1Ol05c05o`0N=@Co02Di0ol0;Ch4o`0e@`?o03i70ol0B4`3o`1@CP?o05E;0ol0
FTP2o`1NA@?o06=00ol0Ic/2o`1/=@?o074_0_l0MBL2o`1j7`?o07hG0_l0P`d2o`280`?o1h`00_lB
T@02oajF00?o;9X00_liW`02odRS00?oEjP00_mW[@02ogNa00;oR;H00onK^P02ojfo00?o`L@00_o8
^`03olf`0003om6S0?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooo
oooo00;ooooo00CodJ<0olf`0?o=/03ocK000_o8^`03ol7400;o[Kl00onK^P02ohRf00;oMk400omW
[@02oeNX00;oB:<00oliW`02obbJ00;o7YH00_lBT@03o`N<00;o08P30_l0P`d3o`1n5`;o07XO0ol0
MBL2o`1a;`?o06`e0_l0Ic/3o`1S@0;o05i50ol0FTP3o`1EB`?o051>0ol0B4`3o`0nA`Co03E30ol0
;Ch4o`0U>@Go01he1Ol05c05o`0B;0Oo00dW4?l02285o`057Poo00PR1ol03BL5o`0B;0Go01L`1Ol0
7SD3o`0U>@Co02dn0ol0=D<4o`0nA`?o04Q<0ol0D4h2o`1EB`?o05Y80ol0GTD3o`1S@0;o06Lk0ol0
K3D2o`1a;`;o07DW0ol0NQl2o`1n5`?o08<=0_l0R0<2o`N<00;o4Y400olNUP02obbJ00;o>Il00om8
X`02oeNX00;oIjd00_mg/@03ohRf00;oVkX00on]_`02ol7400;ob;/00oo=/0000ooAX`3ooooooooo
o`03ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04om6S0?o=/03o
cK00olf`00;ob;/00oo1a002ojfo00;oVkX00on8]P02ogNa00;oIjd00omGZ002odRS00;o>Il00_l/
VP03oajF00;o4Y400_l7S003o`280`;o08<=0_l0OQL3o`1j7`;o07DW0ol0LBl2o`1/=@?o06Lk0_l0
Hd03o`1NA@?o05Y80ol0ED/2o`1@CPCo04Q<0ol0?TL3o`0e@`Co02dn1?l09CT4o`0N=@Go01L`1Ol0
4R`7o`0=9`go00PR3Ol01Ah;o`088POo00dW1_l04R`4o`0G<0Go01he0ol09CT4o`0]?P?o03E31?l0
?TL3o`18C0?o051>0_l0ED/3o`1JB0?o05i50ol0Hd02o`1W>`?o06`e0_l0LBl2o`1e9`?o07XO0_l0
OQL3o`233@;o08P30_l7S002oa:A00?o7YH00_l/VP02ocVO00?oB:<00_mGZ002ofN]00;oMk400on8
]P02oi^j00?o[Kl00_o1a002olRk00?ocK0000?odJ<0ooooooooool00oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool01?oAX`3ocK00olf`0?o=/002olRk00?o`L@00_n]
_`02oi^j00?oR;H00_mg/@02ofN]00?oEjP00_m8X`02ocVO00;o;9X00olNUP02oa:A00;o1h`00ol0
R0<2o`233@;o07hG0ol0NQl2o`1e9`?o074_0_l0K3D3o`1W>`;o06=00ol0GTD3o`1JB0?o05E;0_l0
D4h4o`18C0?o03i70ol0=D<4o`0]?PCo02Di1?l07SD5o`0G<0Go018/1ol03BL;o`088Q3o00DN2ol0
2287o`0=9`Go018/1Ol05c04o`0N=@Co02Di1?l0;Ch3o`0e@`?o03i70ol0B4`3o`1@CP?o05E;0ol0
FTP2o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0ol0MBL2o`1j7`;o07hG0ol0P`d2o`280`;o1h`00olB
T@02oajF00;o;9X00oliW`02odRS00;oEjP00_mW[@03ogNa00;oR;H00_nK^P03ojfo00;o`L@00oo8
^`02olf`0003om6S0?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Fooooo`;o00000oooool0
0ooAX`3ocK00olf`0003olRk00;o`L@00on]_`02oi^j00;oR;H00omg/@02ofN]00;oEjP00om8X`02
ocVO00;o;9X00_lNUP03oa:A00;o1h`00_l0R0<3o`233@;o07hG0_l0NQl3o`1e9`;o074_0ol0K3D2
o`1W>`?o06=00ol0GTD2o`1JB0?o05E;0ol0D4h3o`18C0?o03i71?l0=D<3o`0]?PCo02Di1?l07SD5
o`0G<0Go018/1ol03BL;o`088Q?o00DN2Ol02287o`0=9`Go018/1Ol05c04o`0N=@Co02Di1?l0;Ch3
o`0e@`?o03i70ol0B4`3o`1@CP?o05E;0ol0FTP2o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0ol0MBL2
o`1j7`;o07hG0ol0P`d2o`280`;o1h`00olBT@02oajF00;o;9X00oliW`02odRS00;oEjP00_mW[@03
ogNa00;oR;H00_nK^P03ojfo00;o`L@00oo8^`02olf`0003om6S0?oooooooooo00;ooooo0_l00002
ooooo`005_ooool00ol0003oooooooooo`02ooooo`03om6S0?o=/03ocK0000?ob;/00_o1a003ojfo
00;oVkX00_n8]P03ogNa00;oIjd00_mGZ003odRS00;o>Il00_l/VP02oajF00?o4Y400_l7S002o`28
0`?o08<=0_l0OQL2o`1j7`?o07DW0_l0LBl3o`1/=@;o06Lk0ol0Hd03o`1NA@;o05Y80ol0ED/3o`1@
CP?o04Q<0ol0?TL4o`0e@`?o02dn1?l09CT4o`0N=@Go01L`1Ol04R`7o`0=9`[o00PR5Ol01Ah9o`08
8POo00dW1Ol04R`5o`0G<0Co01he1?l09CT3o`0]?P?o03E31?l0?TL3o`18C0;o051>0ol0ED/3o`1J
B0?o05i50_l0Hd03o`1W>`;o06`e0ol0LBl2o`1e9`;o07XO0ol0OQL2o`233@;o08P30ol7S002oa:A
00;o7YH00_l/VP03ocVO00;oB:<00_mGZ003ofN]00;oMk400_n8]P03oi^j00;o[Kl00_o1a003olRk
00;ocK0000?odJ<0ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooooooo
ool00_ooool00ooAX`3ocK00olf`0003olRk00;o`L@00on]_`02oi^j00;oR;H00omg/@02ofN]00;o
EjP00_m8X`03ocVO00;o;9X00_lNUP02oa:A00?o1h`00_l0R0<2o`233@?o07hG0_l0NQl2o`1e9`?o
074_0_l0K3D3o`1W>`?o06=00_l0GTD3o`1JB0?o05E;0ol0D4h3o`18C0?o03i70ol0=D<4o`0]?P?o
02Di1?l07SD5o`0G<0Go018/1ol03BL9o`088QOo00DN2Ol02287o`0=9`Go018/1Ol05c04o`0N=@Co
02Di0ol0;Ch3o`0e@`Co03i70ol0B4`2o`1@CP?o05E;0ol0FTP3o`1NA@;o06=00ol0Ic/2o`1/=@?o
074_0_l0MBL2o`1j7`?o07hG0_l0P`d2o`280`?o1h`00_lBT@02oajF00;o;9X00oliW`02odRS00;o
EjP00omW[@02ogNa00;oR;H00onK^P02ojfo00;o`L@00oo8^`02olf`0003om6S0?oooooooooo00?o
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00?odJ<0olf`0?o=/000
0oo8^`02ol7400?o[Kl00_nK^P02ohRf00?oMk400_mW[@02oeNX00;oB:<00oliW`02obbJ00;o7YH0
0_lBT@03o`N<00;o08P30_l0P`d3o`1n5`;o07XO0_l0MBL3o`1a;`;o06`e0ol0Ic/3o`1S@0;o05i5
0ol0FTP3o`1EB`?o051>0ol0B4`3o`0nA`?o03E31?l0;Ch3o`0U>@Co01he1Ol05c05o`0B;0Oo00dW
2Ol0228Ho`057PWo00PR1ol03BL5o`0B;0Co01L`1?l07SD4o`0U>@Co02dn0ol0=D<3o`0nA`?o04Q<
0ol0D4h3o`1EB`;o05Y80ol0GTD2o`1S@0?o06Lk0_l0K3D3o`1a;`;o07DW0ol0NQl2o`1n5`;o08<=
0ol0R0<2o`N<00;o4Y400_lNUP03obbJ00;o>Il00_m8X`02oeNX00?oIjd00_mg/@02ohRf00?oVkX0
0_n]_`03ol7400;ob;/00oo=/005ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`03om6S0?o=/03ocK0000?ob;/00_o1a002ojfo00?oVkX00_n8]P02ogNa00?oIjd00_mG
Z002odRS00;o>Il00ol/VP02oajF00;o4Y400ol7S002o`280`;o08<=0_l0OQL3o`1j7`;o07DW0ol0
LBl2o`1/=@?o06Lk0_l0Hd03o`1NA@?o05Y80_l0ED/3o`1@CP?o04Q<0ol0?TL4o`0e@`?o02dn1?l0
9CT4o`0N=@Co01L`1_l04R`6o`0=9`Wo00PR6_l01Ah8o`088POo00dW1Ol04R`4o`0G<0Co01he1?l0
9CT4o`0]?P?o03E30ol0?TL3o`18C0?o051>0ol0ED/2o`1JB0?o05i50_l0Hd03o`1W>`;o06`e0ol0
LBl2o`1e9`?o07XO0_l0OQL2o`233@?o08P30_l7S002oa:A00;o7YH00ol/VP02ocVO00;oB:<00_mG
Z003ofN]00;oMk400_n8]P03oi^j00;o[Kl00oo1a002olRk00?ocK001Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool00ooAX`3ocK00olf`0003olRk00;o`L@00_n]_`03
oi^j00;oR;H00_mg/@03ofN]00;oEjP00_m8X`02ocVO00?o;9X00_lNUP02oa:A00?o1h`00_l0R0<2
o`233@;o07hG0ol0NQl2o`1e9`?o074_0_l0K3D3o`1W>`;o06=00ol0GTD3o`1JB0;o05E;0ol0D4h3
o`18C0?o03i71?l0=D<3o`0]?PCo02Di1?l07SD4o`0G<0Ko018/1_l03BL9o`088Q_o00DN2?l02286
o`0=9`Go018/1Ol05c04o`0N=@?o02Di1?l0;Ch3o`0e@`?o03i70ol0B4`3o`1@CP?o05E;0ol0FTP2
o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0_l0MBL3o`1j7`;o07hG0_l0P`d3o`280`;o1h`00_lBT@03
oajF00;o;9X00_liW`02odRS00?oEjP00_mW[@02ogNa00?oR;H00_nK^P02ojfo00?o`L@00_o8^`03
olf`00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0oo=/002olRk
00?o`L@00_n]_`03oi^j00;oR;H00_mg/@03ofN]00;oEjP00_m8X`02ocVO00?o;9X00_lNUP02oa:A
00;o1h`00ol0R0<2o`233@;o07hG0ol0NQl2o`1e9`;o074_0ol0K3D2o`1W>`?o06=00ol0GTD2o`1J
B0?o05E;0ol0D4h3o`18C0?o03i70ol0=D<4o`0]?P?o02Di1Ol07SD4o`0G<0Go018/1_l03BL9o`08
8Qco00DN2?l02286o`0=9`Go018/1Ol05c04o`0N=@?o02Di1?l0;Ch3o`0e@`?o03i70ol0B4`3o`1@
CP?o05E;0ol0FTP2o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0_l0MBL3o`1j7`;o07hG0_l0P`d3o`28
0`;o1h`00_lBT@03oajF00;o;9X00_liW`02odRS00?oEjP00_mW[@02ogNa00?oR;H00_nK^P02ojfo
00?o`L@00_o8^`03olf`00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;o
oooo0oo=/002olRk00?o`L@00_n]_`03oi^j00;oR;H00_mg/@03ofN]00;oEjP00_m8X`02ocVO00?o
;9X00_lNUP02oa:A00;o1h`00ol0R0<2o`233@;o07hG0ol0NQl2o`1e9`;o074_0ol0K3D2o`1W>`?o
06=00ol0GTD2o`1JB0?o05E;0ol0D4h3o`18C0?o03i70ol0=D<4o`0]?P?o02Di1Ol07SD4o`0G<0Go
018/1_l03BL9o`088Qco00DN2?l02287o`0=9`Go018/1?l05c04o`0N=@Co02Di0ol0;Ch3o`0e@`?o
03i70ol0B4`3o`1@CP?o05E;0ol0FTP2o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0ol0MBL2o`1j7`;o
07hG0ol0P`d2o`280`;o1h`00_lBT@03oajF00;o;9X00_liW`02odRS00?oEjP00_mW[@02ogNa00?o
R;H00_nK^P02ojfo00?o`L@00_o8^`03olf`00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`00
0?oooooooooo00;ooooo0oo=/002olRk00?o`L@00_n]_`03oi^j00;oR;H00_mg/@02ofN]00?oEjP0
0_m8X`02ocVO00;o;9X00olNUP02oa:A00;o1h`00ol0R0<2o`233@;o07hG0ol0NQl2o`1e9`;o074_
0ol0K3D2o`1W>`?o06=00_l0GTD3o`1JB0?o05E;0ol0D4h3o`18C0?o03i70ol0=D<4o`0]?P?o02Di
1?l07SD5o`0G<0Go018/1_l03BL8o`088Qgo00DN2Ol02286o`0=9`Go018/1?l05c04o`0N=@Co02Di
0ol0;Ch3o`0e@`?o03i70ol0B4`3o`1@CP?o05E;0ol0FTP2o`1NA@?o06=00_l0Ic/3o`1/=@;o074_
0ol0MBL2o`1j7`;o07hG0ol0P`d2o`280`;o1h`00_lBT@03oajF00;o;9X00_liW`02odRS00?oEjP0
0_mW[@02ogNa00?oR;H00_nK^P02ojfo00?o`L@00_o8^`03olf`00Gooooo0Ol00001ooooo`7ooooo
000?ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`?ocK000_o8^`03ol7400;o[Kl00onK
^P02ohRf00;oMk400_mW[@03oeNX00;oB:<00_liW`02obbJ00?o7YH00_lBT@02o`N<00?o08P30_l0
P`d2o`1n5`?o07XO0_l0MBL2o`1a;`?o06`e0_l0Ic/3o`1S@0;o05i50ol0FTP3o`1EB`?o051>0ol0
B4`3o`0nA`?o03E31?l0;Ch3o`0U>@Co01he1Ol05c05o`0B;0Ko00dW2?l0228No`057PSo00PR1_l0
3BL5o`0B;0Co01L`1?l07SD4o`0U>@?o02dn0ol0=D<4o`0nA`?o04Q<0_l0D4h3o`1EB`?o05Y80_l0
GTD3o`1S@0;o06Lk0ol0K3D2o`1a;`?o07DW0_l0NQl2o`1n5`?o08<=0_l0R0<2o`N<00?o4Y400_lN
UP02obbJ00;o>Il00om8X`02oeNX00;oIjd00_mg/@03ohRf00;oVkX00_n]_`03ol7400;ob;/00oo=
/005ooooo`7o00000Oooool1ooooo`003_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00;ooooo0oo=/002olRk00?o`L@00_n]_`02oi^j00?oR;H00_mg/@02ofN]00?oEjP00_m8
X`02ocVO00;o;9X00olNUP02oa:A00;o1h`00_l0R0<3o`233@;o07hG0_l0NQl3o`1e9`;o074_0ol0
K3D2o`1W>`?o06=00_l0GTD3o`1JB0?o05E;0ol0D4h3o`18C0?o03i70ol0=D<3o`0]?PCo02Di1?l0
7SD4o`0G<0Go018/1_l03BL8o`088Qoo00DN2?l02286o`0=9`Go018/1?l05c04o`0N=@Co02Di0ol0
;Ch3o`0e@`Co03i70ol0B4`2o`1@CP?o05E;0ol0FTP2o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0ol0
MBL2o`1j7`;o07hG0ol0P`d2o`280`;o1h`00olBT@02oajF00;o;9X00_liW`03odRS00;oEjP00_mW
[@02ogNa00?oR;H00_nK^P02ojfo00?o`L@00_o8^`03olf`00Gooooo0Ol00001ooooo`7ooooo000>
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool3olf`00;ob;/00oo1
a002ojfo00;oVkX00on8]P02ogNa00;oIjd00omGZ002odRS00;o>Il00_l/VP03oajF00;o4Y400_l7
S002o`280`?o08<=0_l0OQL2o`1j7`?o07DW0_l0LBl3o`1/=@;o06Lk0ol0Hd02o`1NA@?o05Y80ol0
ED/3o`1@CP?o04Q<0ol0?TL3o`0e@`?o02dn1?l09CT4o`0N=@Co01L`1Ol04R`6o`0=9`So00PR7ol0
1Ah8o`088PKo00dW1Ol04R`4o`0G<0Co01he1?l09CT3o`0]?PCo03E30ol0?TL3o`18C0;o051>0ol0
ED/3o`1JB0;o05i50ol0Hd03o`1W>`;o06`e0_l0LBl3o`1e9`;o07XO0_l0OQL3o`233@;o08P30_l7
S003oa:A00;o7YH00_l/VP02ocVO00?oB:<00_mGZ002ofN]00;oMk400on8]P02oi^j00;o[Kl00oo1
a002olRk00?ocK001Oooool1o`00007ooooo0Oooool000kooooo00Co0000oooooooooooo00001?oo
ool3o`0000;ooooo0oo=/002olRk00?o`L@00_n]_`02oi^j00?oR;H00_mg/@02ofN]00?oEjP00_m8
X`02ocVO00;o;9X00olNUP02oa:A00;o1h`00_l0R0<3o`233@;o07hG0_l0NQl3o`1e9`;o074_0ol0
K3D2o`1W>`?o06=00_l0GTD3o`1JB0?o05E;0ol0D4h3o`18C0?o03i70ol0=D<3o`0]?PCo02Di1?l0
7SD4o`0G<0Go018/1_l03BL8o`088Qoo00DN2?l02286o`0=9`Go018/1?l05c04o`0N=@Co02Di0ol0
;Ch4o`0e@`?o03i70ol0B4`2o`1@CP?o05E;0ol0FTP2o`1NA@?o06=00ol0Ic/2o`1/=@;o074_0ol0
MBL2o`1j7`;o07hG0ol0P`d2o`280`;o1h`00olBT@02oajF00;o;9X00_liW`03odRS00;oEjP00_mW
[@02ogNa00?oR;H00_nK^P02ojfo00?o`L@00_o8^`03olf`00?ooooo0ol00002ooooo`003_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo0oo=/002olRk00?o`L@00_n]
_`02oi^j00?oR;H00_mg/@02ofN]00?oEjP00_m8X`02ocVO00;o;9X00olNUP02oa:A00;o1h`00_l0
R0<3o`233@;o07hG0_l0NQl3o`1e9`;o074_0ol0K3D2o`1W>`?o06=00_l0GTD3o`1JB0?o05E;0ol0
D4h3o`18C0?o03i70ol0=D<3o`0]?PCo02Di1?l07SD4o`0G<0Go018/1_l03BL8o`088Qoo00DN2?l0
2286o`0=9`Go018/1?l05c04o`0N=@Co02Di0ol0;Ch4o`0e@`?o03i70ol0B4`2o`1@CP?o05E;0ol0
FTP2o`1NA@?o06=00ol0Ic/2o`1/=@;o074_0ol0MBL2o`1j7`;o07hG0ol0P`d2o`280`;o1h`00olB
T@02oajF00;o;9X00_liW`03odRS00;oEjP00_mW[@02ogNa00?oR;H00_nK^P02ojfo00?o`L@00_o8
^`03olf`00Gooooo0Ol00001ooooo`7ooooo000>ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00_ooool3olf`00;ob;/00oo1a002ojfo00;oVkX00on8]P02ogNa00;oIjd00omG
Z002odRS00;o>Il00_l/VP03oajF00;o4Y400_l7S002o`280`?o08<=0_l0OQL2o`1j7`?o07DW0_l0
LBl3o`1/=@;o06Lk0ol0Hd02o`1NA@?o05Y80ol0ED/3o`1@CP?o04Q<0ol0?TL3o`0e@`?o02dn1?l0
9CT4o`0N=@Co01L`1Ol04R`6o`0=9`So00PR7ol01Ah8o`088PKo00dW1Ol04R`4o`0G<0Co01he1?l0
9CT3o`0]?PCo03E30ol0?TL3o`18C0;o051>0ol0ED/3o`1JB0;o05i50ol0Hd03o`1W>`;o06`e0_l0
LBl3o`1e9`;o07XO0_l0OQL3o`233@;o08P30_l7S003oa:A00;o7YH00_l/VP02ocVO00?oB:<00_mG
Z002ofN]00;oMk400on8]P02oi^j00;o[Kl00oo1a002olRk00?ocK001Oooool1o`00007ooooo0Ooo
ool000oooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0oo=/002olRk00?o`L@00_n]_`02
oi^j00?oR;H00_mg/@02ofN]00?oEjP00_m8X`02ocVO00;o;9X00olNUP02oa:A00;o1h`00_l0R0<3
o`233@;o07hG0_l0NQl3o`1e9`;o074_0ol0K3D2o`1W>`?o06=00_l0GTD3o`1JB0?o05E;0ol0D4h3
o`18C0?o03i70ol0=D<3o`0]?PCo02Di1?l07SD4o`0G<0Go018/1_l03BL8o`088Qoo00DN2?l02286
o`0=9`Go018/1?l05c04o`0N=@Co02Di0ol0;Ch4o`0e@`?o03i70ol0B4`2o`1@CP?o05E;0ol0FTP2
o`1NA@?o06=00ol0Ic/2o`1/=@;o074_0ol0MBL2o`1j7`;o07hG0ol0P`d2o`280`;o1h`00olBT@02
oajF00;o;9X00_liW`03odRS00;oEjP00_mW[@02ogNa00?oR;H00_nK^P02ojfo00?o`L@00_o8^`03
olf`00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0oo=/002olRk
00?o`L@00_n]_`02oi^j00?oR;H00_mg/@02ofN]00?oEjP00_m8X`02ocVO00;o;9X00olNUP02oa:A
00;o1h`00_l0R0<3o`233@;o07hG0_l0NQl3o`1e9`;o074_0ol0K3D2o`1W>`?o06=00_l0GTD3o`1J
B0?o05E;0ol0D4h3o`18C0?o03i70ol0=D<3o`0]?PCo02Di1?l07SD4o`0G<0Go018/1_l03BL8o`08
8Qoo00DN2?l02286o`0=9`Go018/1?l05c04o`0N=@Co02Di0ol0;Ch3o`0e@`Co03i70ol0B4`2o`1@
CP?o05E;0ol0FTP2o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0ol0MBL2o`1j7`;o07hG0ol0P`d2o`28
0`;o1h`00olBT@02oajF00;o;9X00_liW`03odRS00;oEjP00_mW[@02ogNa00?oR;H00_nK^P02ojfo
00?o`L@00_o8^`03olf`00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;o
oooo0oo=/002olRk00?o`L@00_n]_`03oi^j00;oR;H00_mg/@02ofN]00?oEjP00_m8X`02ocVO00;o
;9X00olNUP02oa:A00;o1h`00ol0R0<2o`233@;o07hG0ol0NQl2o`1e9`;o074_0ol0K3D2o`1W>`?o
06=00_l0GTD3o`1JB0?o05E;0ol0D4h3o`18C0?o03i70ol0=D<4o`0]?P?o02Di1?l07SD5o`0G<0Go
018/1_l03BL8o`088Qko00DN2?l02286o`0=9`Go018/1?l05c04o`0N=@Co02Di0ol0;Ch3o`0e@`Co
03i70ol0B4`2o`1@CP?o05E;0ol0FTP2o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0ol0MBL2o`1j7`;o
07hG0ol0P`d2o`280`;o1h`00olBT@02oajF00;o;9X00_liW`03odRS00;oEjP00_mW[@02ogNa00?o
R;H00_nK^P02ojfo00?o`L@00_o8^`03olf`00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`00
0?oooooooooo00;ooooo0oo=/002olRk00?o`L@00_n]_`03oi^j00;oR;H00_mg/@02ofN]00?oEjP0
0_m8X`02ocVO00;o;9X00olNUP02oa:A00;o1h`00ol0R0<2o`233@;o07hG0ol0NQl2o`1e9`;o074_
0ol0K3D2o`1W>`?o06=00_l0GTD3o`1JB0?o05E;0ol0D4h3o`18C0?o03i70ol0=D<4o`0]?P?o02Di
1?l07SD5o`0G<0Go018/1_l03BL8o`088Qgo00DN2?l02287o`0=9`Go018/1?l05c04o`0N=@Co02Di
0ol0;Ch3o`0e@`?o03i70ol0B4`3o`1@CP?o05E;0ol0FTP2o`1NA@?o06=00_l0Ic/3o`1/=@;o074_
0ol0MBL2o`1j7`;o07hG0ol0P`d2o`280`;o1h`00_lBT@03oajF00;o;9X00_liW`02odRS00?oEjP0
0_mW[@02ogNa00?oR;H00_nK^P02ojfo00?o`L@00_o8^`03olf`00Gooooo0Ol00001ooooo`7ooooo
000Fooooo`03o`000?oooooooooo00;ooooo0oo=/002olRk00?o`L@00_n]_`03oi^j00;oR;H00_mg
/@03ofN]00;oEjP00_m8X`02ocVO00?o;9X00_lNUP02oa:A00;o1h`00ol0R0<2o`233@;o07hG0ol0
NQl2o`1e9`;o074_0ol0K3D2o`1W>`?o06=00ol0GTD2o`1JB0?o05E;0ol0D4h3o`18C0?o03i70ol0
=D<4o`0]?P?o02Di1Ol07SD4o`0G<0Go018/1_l03BL9o`088Qco00DN2?l02286o`0=9`Ko018/1?l0
5c04o`0N=@Co02Di0ol0;Ch3o`0e@`?o03i70ol0B4`3o`1@CP?o05E;0ol0FTP2o`1NA@?o06=00_l0
Ic/3o`1/=@;o074_0ol0MBL2o`1j7`;o07hG0ol0P`d2o`280`;o1h`00_lBT@03oajF00;o;9X00_li
W`02odRS00?oEjP00_mW[@02ogNa00?oR;H00_nK^P02ojfo00?o`L@00_o8^`03olf`00Gooooo0Ol0
0001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0oo=/002olRk00?o`L@00_n]_`03
oi^j00;oR;H00_mg/@03ofN]00;oEjP00_m8X`02ocVO00?o;9X00_lNUP02oa:A00;o1h`00ol0R0<2
o`233@;o07hG0ol0NQl2o`1e9`;o074_0ol0K3D2o`1W>`?o06=00ol0GTD2o`1JB0?o05E;0ol0D4h3
o`18C0?o03i70ol0=D<4o`0]?P?o02Di1Ol07SD4o`0G<0Go018/1_l03BL9o`088Qco00DN2?l02286
o`0=9`Go018/1Ol05c04o`0N=@?o02Di1?l0;Ch3o`0e@`?o03i70ol0B4`3o`1@CP?o05E;0ol0FTP2
o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0_l0MBL3o`1j7`;o07hG0_l0P`d3o`280`;o1h`00_lBT@03
oajF00;o;9X00_liW`02odRS00?oEjP00_mW[@02ogNa00?oR;H00_nK^P02ojfo00?o`L@00_o8^`03
olf`00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00?odJ<0olf`
0?o=/0000oo8^`02ol7400;o[Kl00onK^P02ohRf00;oMk400omW[@02oeNX00;oB:<00_liW`03obbJ
00;o7YH00_lBT@03o`N<00;o08P30_l0P`d2o`1n5`?o07XO0_l0MBL3o`1a;`;o06`e0ol0Ic/2o`1S
@0?o05i50ol0FTP2o`1EB`?o051>0ol0B4`3o`0nA`Co03E30ol0;Ch4o`0U>@Co01he1?l05c06o`0B
;0Ko00dW2Ol0228Jo`057PWo00PR1_l03BL5o`0B;0Go01L`1?l07SD3o`0U>@Co02dn0ol0=D<3o`0n
A`?o04Q<0ol0D4h3o`1EB`?o05Y80_l0GTD3o`1S@0;o06Lk0ol0K3D2o`1a;`;o07DW0ol0NQl2o`1n
5`;o08<=0ol0R0<2o`N<00;o4Y400olNUP02obbJ00;o>Il00_m8X`03oeNX00;oIjd00_mg/@03ohRf
00;oVkX00_n]_`03ol7400;ob;/00oo=/005ooooo`7o00000Oooool1ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`03om6S0?o=/03ocK0000?ob;/00_o1a002ojfo00?oVkX00_n8]P02ogNa00?o
Ijd00_mGZ002odRS00;o>Il00ol/VP02oajF00;o4Y400ol7S002o`280`;o08<=0_l0OQL3o`1j7`;o
07DW0ol0LBl2o`1/=@?o06Lk0_l0Hd03o`1NA@?o05Y80_l0ED/3o`1@CP?o04Q<0ol0?TL4o`0e@`?o
02dn1?l09CT4o`0N=@Go01L`1Ol04R`6o`0=9`Wo00PR6Ol01Ah9o`088POo00dW1Ol04R`4o`0G<0Co
01he1?l09CT4o`0]?P?o03E30ol0?TL3o`18C0?o051>0ol0ED/2o`1JB0?o05i50_l0Hd03o`1W>`;o
06`e0ol0LBl2o`1e9`?o07XO0_l0OQL2o`233@?o08P30_l7S002oa:A00;o7YH00ol/VP02ocVO00;o
B:<00_mGZ003ofN]00;oMk400_n8]P03oi^j00;o[Kl00oo1a002olRk00?ocK001Oooool1o`00007o
oooo0Oooool001Kooooo00?o0000ooooooooool00_ooool00ooAX`3ocK00olf`0003olRk00;o`L@0
0on]_`02oi^j00;oR;H00omg/@02ofN]00;oEjP00_m8X`03ocVO00;o;9X00_lNUP02oa:A00?o1h`0
0_l0R0<2o`233@?o07hG0_l0NQl2o`1e9`?o074_0_l0K3D3o`1W>`?o06=00_l0GTD3o`1JB0?o05E;
0ol0D4h3o`18C0?o03i70ol0=D<4o`0]?P?o02Di1?l07SD5o`0G<0Go018/1ol03BL9o`088QSo00DN
2Ol02287o`0=9`Co018/1Ol05c04o`0N=@Co02Di0ol0;Ch4o`0e@`?o03i70ol0B4`3o`1@CP?o05E;
0_l0FTP3o`1NA@;o06=00ol0Ic/2o`1/=@?o074_0_l0MBL3o`1j7`;o07hG0_l0P`d3o`280`;o1h`0
0_lBT@02oajF00?o;9X00_liW`02odRS00;oEjP00omW[@02ogNa00;oR;H00onK^P02ojfo00?o`L@0
0_o8^`03olf`00Gooooo0Ol00001ooooo`7ooooo000Fooooo`;o00000oooool00ooAX`3ocK00olf`
0003olRk00;o`L@00on]_`02oi^j00;oR;H00omg/@02ofN]00;oEjP00_m8X`03ocVO00;o;9X00_lN
UP02oa:A00?o1h`00_l0R0<2o`233@?o07hG0_l0NQl2o`1e9`?o074_0_l0K3D3o`1W>`?o06=00_l0
GTD3o`1JB0?o05E;0ol0D4h3o`18C0?o03i70ol0=D<4o`0]?P?o02Di1Ol07SD4o`0G<0Ko018/1_l0
3BL;o`088QGo00DN2Ol02287o`0=9`Go018/1Ol05c04o`0N=@Co02Di0ol0;Ch3o`0e@`Co03i70ol0
B4`2o`1@CP?o05E;0ol0FTP3o`1NA@;o06=00ol0Ic/2o`1/=@?o074_0_l0MBL2o`1j7`?o07hG0_l0
P`d2o`280`?o1h`00_lBT@02oajF00;o;9X00oliW`02odRS00;oEjP00omW[@02ogNa00;oR;H00onK
^P02ojfo00;o`L@00oo8^`02olf`0003om6S0?oooooooooo00;ooooo0_l00002ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`03om6S0?o=/03ocK0000?ob;/00_o1a003ojfo00;oVkX00_n8]P03
ogNa00;oIjd00_mGZ003odRS00;o>Il00_l/VP02oajF00?o4Y400_l7S002o`280`?o08<=0_l0OQL2
o`1j7`?o07DW0_l0LBl3o`1/=@;o06Lk0ol0Hd03o`1NA@;o05Y80ol0ED/3o`1@CP?o04Q<0ol0?TL4
o`0e@`?o02dn1?l09CT4o`0N=@Go01L`1Ol04R`7o`0=9`_o00PR4ol01Ah:o`088PKo00dW1_l04R`4
o`0G<0Go01he0ol09CT4o`0]?P?o03E31?l0?TL3o`18C0;o051>0ol0ED/3o`1JB0?o05i50_l0Hd03
o`1W>`;o06`e0ol0LBl2o`1e9`;o07XO0ol0OQL2o`233@;o08P30ol7S002oa:A00;o7YH00_l/VP03
ocVO00;oB:<00_mGZ003ofN]00;oMk400_n8]P03oi^j00;o[Kl00_o1a003olRk00;ocK0000?odJ<0
ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool00ooA
X`3ocK00olf`0003olRk00;o`L@00on]_`02oi^j00;oR;H00omg/@02ofN]00;oEjP00om8X`02ocVO
00;o;9X00_lNUP03oa:A00;o1h`00_l0R0<3o`233@;o07hG0_l0NQl3o`1e9`;o074_0ol0K3D2o`1W
>`?o06=00ol0GTD2o`1JB0?o05E;0ol0D4h3o`18C0?o03i71?l0=D<3o`0]?PCo02Di1?l07SD5o`0G
<0Go018/2?l03BL<o`088Poo00DN2ol02287o`0=9`Go018/1Ol05c04o`0N=@Co02Di1?l0;Ch3o`0e
@`?o03i70ol0B4`3o`1@CP?o05E;0ol0FTP2o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0ol0MBL2o`1j
7`;o07hG0ol0P`d2o`280`;o1h`00olBT@02oajF00;o;9X00oliW`02odRS00;oEjP00_mW[@03ogNa
00;oR;H00_nK^P03ojfo00;o`L@00oo8^`02olf`0003om6S0?oooooooooo00?ooooo0Ol00001oooo
o`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00CodJ<0olf`0?o=/03ocK000_o8^`03ol74
00;o[Kl00_nK^P03ohRf00;oMk400_mW[@03oeNX00;oB:<00_liW`02obbJ00?o7YH00_lBT@02o`N<
00?o08P30_l0P`d2o`1n5`?o07XO0_l0MBL3o`1a;`;o06`e0ol0Ic/2o`1S@0?o05i50ol0FTP3o`1E
B`;o051>1?l0B4`3o`0nA`?o03E31?l0;Ch4o`0U>@Co01he1Ol05c05o`0B;0Oo00dW3_l0228;o`05
7Pco00PR2?l03BL5o`0B;0Go01L`1?l07SD4o`0U>@Co02dn0ol0=D<3o`0nA`?o04Q<0ol0D4h3o`1E
B`?o05Y80_l0GTD3o`1S@0;o06Lk0ol0K3D2o`1a;`?o07DW0_l0NQl2o`1n5`?o08<=0_l0R0<2o`N<
00?o4Y400_lNUP02obbJ00?o>Il00_m8X`02oeNX00;oIjd00omg/@02ohRf00;oVkX00on]_`02ol74
00?ob;/00_o=/0000ooAX`3oooooooooo`03ooooo`7o00000Oooool1ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`04om6S0?o=/03ocK00olf`00;ob;/00oo1a002ojfo00;oVkX00on8]P02ogNa
00;oIjd00omGZ002odRS00;o>Il00_l/VP03oajF00;o4Y400_l7S003o`280`;o08<=0_l0OQL3o`1j
7`;o07DW0ol0LBl2o`1/=@?o06Lk0_l0Hd03o`1NA@?o05Y80ol0ED/2o`1@CPCo04Q<0ol0?TL3o`0e
@`Co02dn1?l09CT4o`0N=@Go01L`1_l04R`8o`0=9a3o00PR0ol01Ah?o`088PSo00dW1Ol04R`5o`0G
<0Go01he0ol09CT4o`0]?P?o03E31?l0?TL3o`18C0?o051>0_l0ED/3o`1JB0?o05i50ol0Hd02o`1W
>`?o06`e0_l0LBl2o`1e9`?o07XO0_l0OQL3o`233@;o08P30_l7S002oa:A00?o7YH00_l/VP02ocVO
00?oB:<00_mGZ002ofN]00;oMk400on8]P02oi^j00?o[Kl00_o1a002olRk00?ocK0000?odJ<0oooo
ooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool01?oAX`3o
cK00olf`0?o=/002olRk00?o`L@00_n]_`03oi^j00;oR;H00_mg/@03ofN]00;oEjP00_m8X`03ocVO
00;o;9X00_lNUP02oa:A00?o1h`00_l0R0<2o`233@?o07hG0_l0NQl3o`1e9`;o074_0ol0K3D2o`1W
>`?o06=00_l0GTD3o`1JB0?o05E;0ol0D4h3o`18C0?o03i71?l0=D<3o`0]?PCo02Di1Ol07SD5o`0G
<0Ko018/1ol03BLQo`088PSo00dW1_l04R`5o`0G<0Go01he0ol09CT4o`0]?P?o03E31?l0?TL3o`18
C0?o051>0_l0ED/3o`1JB0?o05i50ol0Hd02o`1W>`?o06`e0_l0LBl2o`1e9`?o07XO0_l0OQL3o`23
3@;o08P30_l7S002oa:A00?o7YH00_l/VP02ocVO00?oB:<00_mGZ002ofN]00;oMk400on8]P02oi^j
00?o[Kl00_o1a002olRk00?ocK0000?odJ<0ooooooooool00oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool01?oAX`3ocK00olf`0?o=/002olRk00?o`L@00_n]_`03oi^j
00;oR;H00_mg/@03ofN]00;oEjP00_m8X`03ocVO00;o;9X00_lNUP02oa:A00?o1h`00_l0R0<2o`23
3@?o07hG0_l0NQl3o`1e9`;o074_0ol0K3D2o`1W>`?o06=00_l0GTD3o`1JB0?o05E;0ol0D4h3o`18
C0?o03i71?l0=D<4o`0]?PCo02Di1?l07SD5o`0G<0Oo018/2?l03BLNo`088PSo00dW1_l04R`5o`0G
<0Go01he1?l09CT3o`0]?PCo03E30ol0?TL3o`18C0?o051>0ol0ED/3o`1JB0;o05i50ol0Hd03o`1W
>`;o06`e0ol0LBl2o`1e9`;o07XO0ol0OQL2o`233@;o08P30ol7S002oa:A00;o7YH00ol/VP02ocVO
00;oB:<00omGZ002ofN]00;oMk400_n8]P03oi^j00;o[Kl00oo1a002olRk00?ocK0000?odJ<0oooo
ooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2om6S00;o
cK000oo8^`02ol7400?o[Kl00_nK^P02ohRf00?oMk400_mW[@02oeNX00?oB:<00_liW`02obbJ00;o
7YH00olBT@02o`N<00;o08P30ol0P`d2o`1n5`?o07XO0_l0MBL2o`1a;`?o06`e0ol0Ic/2o`1S@0?o
05i50ol0FTP3o`1EB`?o051>0ol0B4`3o`0nA`Co03E30ol0;Ch4o`0U>@Go01he1Ol05c06o`0B;0Wo
00dW7?l02288o`0=9`Oo018/1Ol05c04o`0N=@Co02Di1?l0;Ch4o`0e@`?o03i70ol0B4`3o`1@CP?o
05E;0ol0FTP2o`1NA@?o06=00ol0Ic/2o`1/=@?o074_0_l0MBL2o`1j7`?o07hG0_l0P`d2o`280`?o
1h`00_lBT@02oajF00?o;9X00_liW`02odRS00?oEjP00_mW[@02ogNa00;oR;H00onK^P02ojfo00?o
`L@00_o8^`03olf`0003om6S0?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Fooooo`03o`00
0?oooooooooo00;ooooo0_oAX`02olf`00?ob;/00_o1a003ojfo00;oVkX00_n8]P03ogNa00;oIjd0
0_mGZ003odRS00;o>Il00_l/VP02oajF00?o4Y400_l7S002o`280`?o08<=0_l0OQL3o`1j7`;o07DW
0_l0LBl3o`1/=@?o06Lk0_l0Hd03o`1NA@?o05Y80ol0ED/3o`1@CP?o04Q<0ol0?TL4o`0e@`?o02dn
1?l09CT5o`0N=@Go01L`1ol04R`9o`0=9a[o00PR2Ol03BL6o`0B;0Go01L`1Ol07SD4o`0U>@Co02dn
0ol0=D<3o`0nA`?o04Q<0ol0D4h3o`1EB`?o05Y80ol0GTD3o`1S@0;o06Lk0ol0K3D2o`1a;`?o07DW
0_l0NQl2o`1n5`?o08<=0_l0R0<2o`N<00?o4Y400_lNUP02obbJ00?o>Il00_m8X`02oeNX00;oIjd0
0omg/@02ohRf00?oVkX00_n]_`02ol7400?ob;/00_o=/002om6S00Gooooo0Ol00001ooooo`7ooooo
000Fooooo`03o`000?oooooooooo00;ooooo0_oAX`03olf`00;ob;/00oo1a002ojfo00;oVkX00on8
]P02ogNa00;oIjd00omGZ002odRS00;o>Il00ol/VP02oajF00;o4Y400ol7S002o`280`;o08<=0ol0
OQL2o`1j7`?o07DW0_l0LBl3o`1/=@;o06Lk0ol0Hd03o`1NA@;o05Y80ol0ED/3o`1@CPCo04Q<0ol0
?TL3o`0e@`Co02dn1?l09CT5o`0N=@Go01L`1ol04R`:o`0=9aOo00PR2Ol03BL7o`0B;0Go01L`1Ol0
7SD4o`0U>@Co02dn0ol0=D<3o`0nA`?o04Q<0ol0D4h3o`1EB`?o05Y80ol0GTD3o`1S@0;o06Lk0ol0
K3D2o`1a;`?o07DW0_l0NQl2o`1n5`?o08<=0_l0R0<2o`N<00?o4Y400_lNUP02obbJ00?o>Il00_m8
X`02oeNX00;oIjd00omg/@02ohRf00?oVkX00_n]_`02ol7400?ob;/00_o=/002om6S00Gooooo0Ol0
0001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_oAX`03olf`00;ob;/00oo1a002
ojfo00;oVkX00on8]P02ogNa00;oIjd00omGZ002odRS00;o>Il00ol/VP02oajF00;o4Y400ol7S002
o`280`;o08<=0ol0OQL2o`1j7`?o07DW0_l0LBl3o`1/=@;o06Lk0ol0Hd03o`1NA@?o05Y80_l0ED/4
o`1@CP?o04Q<0ol0?TL4o`0e@`Co02dn1?l09CT4o`0N=@Ko01L`1ol04R`;o`0=9a?o00PR2_l03BL6
o`0B;0Ko01L`1Ol07SD4o`0U>@Co02dn0ol0=D<4o`0nA`?o04Q<0ol0D4h3o`1EB`?o05Y80_l0GTD3
o`1S@0?o06Lk0_l0K3D3o`1a;`;o07DW0ol0NQl2o`1n5`;o08<=0ol0R0<2o`N<00;o4Y400olNUP02
obbJ00;o>Il00_m8X`03oeNX00;oIjd00_mg/@03ohRf00;oVkX00on]_`02ol7400?ob;/00_o=/002
om6S00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_oAX`03olf`
00;ob;/00oo1a002ojfo00?oVkX00_n8]P02ogNa00?oIjd00_mGZ002odRS00?o>Il00_l/VP02oajF
00?o4Y400_l7S002o`280`?o08<=0_l0OQL3o`1j7`;o07DW0ol0LBl2o`1/=@?o06Lk0ol0Hd02o`1N
A@?o05Y80ol0ED/3o`1@CP?o04Q<1?l0?TL3o`0e@`Co02dn1Ol09CT4o`0N=@Ko01L`1ol04R`=o`0=
9`co00PR3Ol03BL7o`0B;0Ko01L`1?l07SD4o`0U>@Co02dn1?l0=D<4o`0nA`;o04Q<1?l0D4h2o`1E
B`Co05Y80_l0GTD3o`1S@0?o06Lk0_l0K3D3o`1a;`;o07DW0ol0NQl2o`1n5`;o08<=0ol0R0<2o`N<
00;o4Y400olNUP02obbJ00;o>Il00_m8X`03oeNX00;oIjd00_mg/@03ohRf00;oVkX00on]_`02ol74
00?ob;/00_o=/002om6S00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;o
oooo0_oAX`03olf`00;ob;/00oo1a002ojfo00?oVkX00_n8]P02ogNa00?oIjd00_mGZ002odRS00?o
>Il00_l/VP02oajF00?o4Y400_l7S002o`280`?o08<=0_l0OQL3o`1j7`;o07DW0ol0LBl2o`1/=@?o
06Lk0ol0Hd02o`1NA@?o05Y80ol0ED/3o`1@CPCo04Q<0ol0?TL3o`0e@`Co02dn1Ol09CT5o`0N=@Ko
01L`2?l04R`Ro`0=9`So018/1Ol05c06o`0N=@Co02Di1?l0;Ch3o`0e@`Co03i70ol0B4`3o`1@CP?o
05E;0ol0FTP3o`1NA@;o06=00ol0Ic/3o`1/=@;o074_0ol0MBL2o`1j7`;o07hG0ol0P`d2o`280`;o
1h`00olBT@02oajF00;o;9X00oliW`02odRS00;oEjP00omW[@02ogNa00;oR;H00onK^P02ojfo00?o
`L@00_o8^`03olf`00;odJ<01Oooool1o`00007ooooo0Oooool001Kooooo0_l00003ooooo`?odJ<0
0_o=/003olRk00;o`L@00on]_`02oi^j00?oR;H00_mg/@02ofN]00?oEjP00_m8X`02ocVO00?o;9X0
0_lNUP02oa:A00?o1h`00_l0R0<2o`233@?o07hG0_l0NQl3o`1e9`;o074_0ol0K3D3o`1W>`;o06=0
0ol0GTD3o`1JB0?o05E;0ol0D4h3o`18C0Co03i70ol0=D<4o`0]?PGo02Di1Ol07SD6o`0G<0So018/
8?l03BL8o`0B;0Ko01L`1Ol07SD5o`0U>@Co02dn0ol0=D<3o`0nA`Co04Q<0ol0D4h3o`1EB`?o05Y8
0ol0GTD2o`1S@0?o06Lk0ol0K3D2o`1a;`;o07DW0ol0NQl2o`1n5`?o08<=0_l0R0<2o`N<00?o4Y40
0_lNUP02obbJ00?o>Il00_m8X`02oeNX00?oIjd00_mg/@02ohRf00?oVkX00_n]_`03ol7400;ob;/0
0oo=/002om6S00Cooooo0_l00002ooooo`005_ooool00ol0003oooooooooo`02ooooo`?odJ<00_o=
/003olRk00;o`L@00on]_`02oi^j00?oR;H00_mg/@02ofN]00?oEjP00_m8X`02ocVO00?o;9X00_lN
UP02oa:A00?o1h`00_l0R0<2o`233@?o07hG0_l0NQl3o`1e9`;o074_0ol0K3D3o`1W>`;o06=00ol0
GTD3o`1JB0?o05E;0ol0D4h3o`18C0Co03i71?l0=D<4o`0]?PCo02Di1_l07SD6o`0G<0[o018/6_l0
3BL:o`0B;0Ko01L`1Ol07SD4o`0U>@Co02dn1?l0=D<4o`0nA`?o04Q<0ol0D4h3o`1EB`?o05Y80ol0
GTD3o`1S@0;o06Lk0ol0K3D2o`1a;`?o07DW0_l0NQl3o`1n5`;o08<=0ol0R0<2o`N<00;o4Y400olN
UP02obbJ00;o>Il00om8X`02oeNX00;oIjd00omg/@02ohRf00;oVkX00on]_`02ol7400?ob;/00_o=
/003om6S00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0ooAX`03
olf`00;ob;/00oo1a002ojfo00?oVkX00_n8]P02ogNa00?oIjd00_mGZ002odRS00?o>Il00_l/VP02
oajF00?o4Y400_l7S003o`280`;o08<=0_l0OQL3o`1j7`;o07DW0ol0LBl3o`1/=@;o06Lk0ol0Hd03
o`1NA@?o05Y80ol0ED/3o`1@CP?o04Q<1?l0?TL4o`0e@`Co02dn1?l09CT6o`0N=@Ko01L`2_l04R`H
o`0=9`[o018/1_l05c06o`0N=@Co02Di1?l0;Ch4o`0e@`Co03i70ol0B4`3o`1@CP?o05E;0ol0FTP3
o`1NA@?o06=00_l0Ic/3o`1/=@;o074_0ol0MBL2o`1j7`?o07hG0_l0P`d3o`280`;o1h`00_lBT@03
oajF00;o;9X00_liW`03odRS00;oEjP00_mW[@03ogNa00;oR;H00_nK^P03ojfo00;o`L@00oo8^`02
olf`00?odJ<01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool3om6S
00?ocK000_o8^`03ol7400;o[Kl00onK^P02ohRf00;oMk400omW[@02oeNX00;oB:<00oliW`02obbJ
00;o7YH00olBT@02o`N<00?o08P30_l0P`d2o`1n5`?o07XO0_l0MBL3o`1a;`?o06`e0_l0Ic/3o`1S
@0?o05i50ol0FTP3o`1EB`?o051>1?l0B4`4o`0nA`?o03E31Ol0;Ch4o`0U>@Ko01he1ol05c0;o`0B
;1?o00dW2_l04R`7o`0G<0Go01he1Ol09CT4o`0]?PCo03E31?l0?TL3o`18C0?o051>0ol0ED/3o`1J
B0?o05i50ol0Hd03o`1W>`;o06`e0ol0LBl2o`1e9`?o07XO0_l0OQL3o`233@;o08P30_l7S003oa:A
00;o7YH00_l/VP03ocVO00;oB:<00_mGZ003ofN]00;oMk400on8]P02oi^j00;o[Kl00oo1a002olRk
00?ocK000ooAX`05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04
omJF0?oAX`3odJ<0om6S00;ocK000oo8^`02ol7400?o[Kl00_nK^P03ohRf00;oMk400_mW[@03oeNX
00;oB:<00_liW`03obbJ00;o7YH00_lBT@03o`N<00;o08P30ol0P`d2o`1n5`?o07XO0_l0MBL3o`1a
;`;o06`e0ol0Ic/3o`1S@0?o05i50ol0FTP3o`1EB`?o051>0ol0B4`4o`0nA`Co03E31?l0;Ch5o`0U
>@Ko01he1ol05c0<o`0B;0oo00dW2ol04R`7o`0G<0Ko01he1?l09CT5o`0]?P?o03E31?l0?TL4o`18
C0?o051>0ol0ED/3o`1JB0?o05i50ol0Hd03o`1W>`;o06`e0ol0LBl2o`1e9`?o07XO0_l0OQL3o`23
3@;o08P30_l7S003oa:A00;o7YH00_l/VP03ocVO00;oB:<00_mGZ003ofN]00;oMk400on8]P02oi^j
00;o[Kl00oo1a002olRk00?ocK000ooAX`05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`04omJF0?oAX`3odJ<0om6S00;ocK000oo8^`02ol7400?o[Kl00_nK^P03ohRf
00;oMk400_mW[@03oeNX00;oB:<00_liW`03obbJ00;o7YH00_lBT@03o`N<00;o08P30ol0P`d2o`1n
5`?o07XO0_l0MBL3o`1a;`?o06`e0_l0Ic/3o`1S@0?o05i50ol0FTP3o`1EB`Co051>0ol0B4`3o`0n
A`Go03E31?l0;Ch5o`0U>@Ko01he2?l05c0Ro`0B;0So01L`1_l07SD5o`0U>@Co02dn1?l0=D<4o`0n
A`?o04Q<0ol0D4h3o`1EB`?o05Y80ol0GTD3o`1S@0?o06Lk0_l0K3D3o`1a;`?o07DW0_l0NQl3o`1n
5`;o08<=0_l0R0<3o`N<00;o4Y400olNUP02obbJ00;o>Il00om8X`02oeNX00;oIjd00omg/@02ohRf
00;oVkX00on]_`02ol7400?ob;/00oo=/002om6S0003omJF0?oooooooooo00?ooooo0Ol00001oooo
o`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00CoeYH0om6S0?oAX`3odJ<00oo=/002olRk
00?o`L@00_n]_`03oi^j00;oR;H00_mg/@03ofN]00;oEjP00om8X`02ocVO00;o;9X00olNUP02oa:A
00;o1h`00ol0R0<2o`233@?o07hG0_l0NQl3o`1e9`?o074_0_l0K3D3o`1W>`?o06=00ol0GTD3o`1J
B0?o05E;0ol0D4h4o`18C0?o03i71Ol0=D<4o`0]?PGo02Di1_l07SD8o`0G<23o018/2?l05c06o`0N
=@Go02Di1Ol0;Ch4o`0e@`?o03i70ol0B4`4o`1@CP?o05E;0ol0FTP3o`1NA@?o06=00_l0Ic/3o`1/
=@?o074_0_l0MBL3o`1j7`?o07hG0_l0P`d2o`280`?o1h`00_lBT@03oajF00;o;9X00_liW`03odRS
00;oEjP00_mW[@03ogNa00;oR;H00_nK^P03ojfo00;o`L@00oo8^`03olf`00;odJ<000?oeYH0oooo
ooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool01?oFUP3o
dJ<0om6S0?oAX`03olf`00;ob;/00oo1a002ojfo00?oVkX00_n8]P02ogNa00?oIjd00_mGZ003odRS
00;o>Il00_l/VP03oajF00;o4Y400_l7S003o`280`;o08<=0ol0OQL2o`1j7`?o07DW0ol0LBl2o`1/
=@?o06Lk0ol0Hd03o`1NA@?o05Y81?l0ED/3o`1@CP?o04Q<1?l0?TL4o`0e@`Go02dn1Ol09CT7o`0N
=@Wo01L`6_l04R`9o`0G<0Ko01he1_l09CT4o`0]?PCo03E31?l0?TL4o`18C0?o051>0ol0ED/3o`1J
B0?o05i50ol0Hd03o`1W>`?o06`e0_l0LBl3o`1e9`;o07XO0ol0OQL2o`233@?o08P30_l7S003oa:A
00;o7YH00_l/VP03ocVO00;oB:<00_mGZ003ofN]00;oMk400on8]P02oi^j00;o[Kl00oo1a002olRk
00?ocK000ooAX`000ooFUP3oooooooooo`03ooooo`7o00000Oooool1ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`;oeYH00ooAX`02olf`00?ob;/00_o1a003ojfo00;oVkX00on8]P02ogNa00;o
Ijd00omGZ002odRS00?o>Il00_l/VP02oajF00?o4Y400_l7S003o`280`;o08<=0ol0OQL2o`1j7`?o
07DW0_l0LBl3o`1/=@?o06Lk0ol0Hd03o`1NA@?o05Y80ol0ED/4o`1@CP?o04Q<1?l0?TL4o`0e@`Go
02dn1Ol09CT7o`0N=@[o01L`5ol04R`9o`0G<0Oo01he1Ol09CT5o`0]?PCo03E31?l0?TL4o`18C0;o
051>1?l0ED/3o`1JB0?o05i50ol0Hd03o`1W>`;o06`e0ol0LBl3o`1e9`;o07XO0ol0OQL2o`233@?o
08P30_l7S002oa:A00?o7YH00_l/VP03ocVO00;oB:<00_mGZ003ofN]00;oMk400on8]P02oi^j00;o
[Kl00oo1a002olRk00?ocK000ooAX`000ooFUP3oooooooooo`03ooooo`7o00000Oooool1ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`;oeYH00ooAX`02olf`00?ob;/00_o1a003ojfo00;oVkX0
0on8]P02ogNa00;oIjd00omGZ002odRS00?o>Il00_l/VP02oajF00?o4Y400_l7S003o`280`;o08<=
0ol0OQL2o`1j7`?o07DW0_l0LBl4o`1/=@;o06Lk0ol0Hd03o`1NA@?o05Y80ol0ED/4o`1@CPCo04Q<
1?l0?TL4o`0e@`Go02dn1_l09CT7o`0N=@co01L`3ol04R`;o`0G<0Oo01he1_l09CT5o`0]?PCo03E3
1?l0?TL3o`18C0Co051>0ol0ED/3o`1JB0?o05i50ol0Hd03o`1W>`?o06`e0_l0LBl3o`1e9`?o07XO
0_l0OQL3o`233@;o08P30_l7S003oa:A00;o7YH00ol/VP02ocVO00;oB:<00omGZ002ofN]00?oMk40
0_n8]P02oi^j00?o[Kl00_o1a003olRk00?ocK000_oAX`02omJF00Gooooo0Ol00001ooooo`7ooooo
000Fooooo`03o`000?oooooooooo00;ooooo0_oFUP03om6S00?ocK000_o8^`03ol7400;o[Kl00onK
^P02ohRf00?oMk400_mW[@02oeNX00?oB:<00_liW`03obbJ00;o7YH00olBT@02o`N<00;o08P30ol0
P`d3o`1n5`;o07XO0ol0MBL2o`1a;`?o06`e0ol0Ic/3o`1S@0?o05i50ol0FTP3o`1EB`Co051>1?l0
B4`4o`0nA`Co03E31Ol0;Ch6o`0U>@So01he8ol05c07o`0N=@Ko02Di1Ol0;Ch4o`0e@`Co03i71?l0
B4`4o`1@CP?o05E;0ol0FTP3o`1NA@?o06=00_l0Ic/4o`1/=@;o074_0ol0MBL3o`1j7`;o07hG0_l0
P`d3o`280`;o1h`00olBT@02oajF00?o;9X00_liW`02odRS00?oEjP00_mW[@03ogNa00;oR;H00_nK
^P03ojfo00;o`L@00oo8^`03olf`00;odJ<00_oFUP05ooooo`7o00000Oooool1ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`;oeYH00ooAX`03olf`00;ob;/00oo1a002ojfo00?oVkX00_n8]P03
ogNa00;oIjd00_mGZ003odRS00;o>Il00ol/VP02oajF00?o4Y400_l7S002o`280`?o08<=0ol0OQL2
o`1j7`?o07DW0ol0LBl2o`1/=@?o06Lk0ol0Hd04o`1NA@;o05Y81?l0ED/4o`1@CPCo04Q<1?l0?TL4
o`0e@`Ko02dn1_l09CT8o`0N=Ako01L`2?l07SD6o`0U>@Ko02dn1?l0=D<4o`0nA`Co04Q<1?l0D4h3
o`1EB`?o05Y80ol0GTD3o`1S@0?o06Lk0ol0K3D2o`1a;`?o07DW0ol0NQl2o`1n5`?o08<=0_l0R0<3
o`N<00;o4Y400_lNUP03obbJ00;o>Il00om8X`02oeNX00;oIjd00omg/@02ohRf00?oVkX00_n]_`03
ol7400;ob;/00oo=/003om6S00;oeYH01Oooool1o`00007ooooo0Oooool001Kooooo0_l00003oooo
o`?oeYH00ooAX`02olf`00?ob;/00oo1a002ojfo00?oVkX00_n8]P02ogNa00?oIjd00_mGZ003odRS
00;o>Il00_l/VP03oajF00;o4Y400ol7S002o`280`?o08<=0_l0OQL3o`1j7`?o07DW0_l0LBl3o`1/
=@?o06Lk0ol0Hd03o`1NA@?o05Y81?l0ED/3o`1@CPCo04Q<1?l0?TL5o`0e@`Go02dn1ol09CT9o`0N
=AWo01L`2_l07SD6o`0U>@Ko02dn1?l0=D<4o`0nA`Co04Q<1?l0D4h4o`1EB`;o05Y81?l0GTD3o`1S
@0?o06Lk0_l0K3D3o`1a;`?o07DW0_l0NQl3o`1n5`?o08<=0_l0R0<2o`N<00?o4Y400_lNUP03obbJ
00;o>Il00om8X`02oeNX00;oIjd00omg/@02ohRf00?oVkX00_n]_`03ol7400;ob;/00oo=/003om6S
00;oeYH01?ooool2o`0000;ooooo000Fooooo`03o`000?oooooooooo00;ooooo0ooFUP03om6S00;o
cK000oo8^`03ol7400;o[Kl00onK^P02ohRf00;oMk400omW[@02oeNX00?oB:<00_liW`03obbJ00;o
7YH00_lBT@03o`N<00?o08P30_l0P`d2o`1n5`?o07XO0ol0MBL3o`1a;`?o06`e0_l0Ic/4o`1S@0?o
05i50ol0FTP4o`1EB`?o051>1?l0B4`5o`0nA`Co03E31_l0;Ch8o`0U>@[o01he4ol05c09o`0N=@So
02Di1Ol0;Ch5o`0e@`Go03i71?l0B4`3o`1@CP?o05E;1?l0FTP3o`1NA@?o06=00ol0Ic/3o`1/=@;o
074_0ol0MBL3o`1j7`;o07hG0ol0P`d2o`280`?o1h`00_lBT@03oajF00;o;9X00oliW`02odRS00;o
EjP00omW[@02ogNa00?oR;H00_nK^P03ojfo00;o`L@00oo8^`02olf`00?odJ<00ooFUP05ooooo`7o
00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04om^80?oFUP3oeYH0omJF00;o
dJ<00oo=/003olRk00;o`L@00on]_`02oi^j00?oR;H00_mg/@03ofN]00;oEjP00_m8X`03ocVO00;o
;9X00olNUP02oa:A00?o1h`00_l0R0<3o`233@;o07hG0ol0NQl3o`1e9`?o074_0_l0K3D3o`1W>`?o
06=01?l0GTD3o`1JB0?o05E;1?l0D4h4o`18C0Co03i71Ol0=D<6o`0]?PSo02Di3ol07SD7o`0G<0ko
01he2?l09CT6o`0]?PCo03E31Ol0?TL4o`18C0?o051>1?l0ED/4o`1JB0;o05i51?l0Hd02o`1W>`Co
06`e0_l0LBl3o`1e9`?o07XO0_l0OQL2o`233@?o08P30ol7S002oa:A00;o7YH00ol/VP03ocVO00;o
B:<00_mGZ003ofN]00;oMk400on8]P02oi^j00?o[Kl00_o1a003olRk00;ocK000ooAX`03omJF00Go
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00CofhP0omJF0?oFUP3o
eYH00_oAX`03olf`00?ob;/00_o1a003ojfo00;oVkX00on8]P02ogNa00?oIjd00_mGZ002odRS00?o
>Il00_l/VP03oajF00;o4Y400ol7S002o`280`?o08<=0ol0OQL2o`1j7`?o07DW0ol0LBl3o`1/=@?o
06Lk0ol0Hd03o`1NA@Co05Y80ol0ED/4o`1@CPCo04Q<1Ol0?TL5o`0e@`Oo02dn2?l09CTNo`0N=@So
02Di1ol0;Ch5o`0e@`Go03i71?l0B4`4o`1@CP?o05E;0ol0FTP4o`1NA@?o06=00ol0Ic/3o`1/=@;o
074_0ol0MBL3o`1j7`;o07hG0ol0P`d2o`280`?o1h`00_lBT@03oajF00;o;9X00oliW`02odRS00?o
EjP00_mW[@02ogNa00?oR;H00_nK^P03ojfo00?o`L@00_o8^`03olf`00?odJ<00_oFUP000ooKR03o
ooooooooo`03ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`04om^8
0?oFUP3oeYH0omJF00?odJ<00oo=/002olRk00?o`L@00_n]_`03oi^j00;oR;H00omg/@02ofN]00?o
EjP00_m8X`03ocVO00;o;9X00olNUP02oa:A00?o1h`00_l0R0<3o`233@;o07hG0ol0NQl3o`1e9`?o
074_0ol0K3D3o`1W>`?o06=00ol0GTD3o`1JB0Co05E;1?l0D4h4o`18C0Go03i71Ol0=D<7o`0]?PWo
02Di6_l07SD9o`0U>@Oo02dn1Ol0=D<5o`0nA`Co04Q<1?l0D4h3o`1EB`Co05Y80ol0GTD3o`1S@0Co
06Lk0_l0K3D3o`1a;`?o07DW0_l0NQl3o`1n5`?o08<=0_l0R0<3o`N<00;o4Y400olNUP02obbJ00?o
>Il00_m8X`03oeNX00;oIjd00_mg/@03ohRf00;oVkX00on]_`03ol7400;ob;/00oo=/003om6S00;o
eYH000?ofhP0ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool01?oKR03oeYH0omJF0?oFUP03om6S00?ocK000_o8^`03ol7400;o[Kl00onK^P02ohRf00?o
Mk400_mW[@03oeNX00;oB:<00oliW`02obbJ00?o7YH00_lBT@03o`N<00?o08P30_l0P`d3o`1n5`?o
07XO0_l0MBL3o`1a;`?o06`e0ol0Ic/3o`1S@0Co05i50ol0FTP4o`1EB`Co051>1Ol0B4`4o`0nA`Ko
03E32?l0;Ch:o`0U>A?o01he2Ol09CT8o`0]?PKo03E31?l0?TL5o`18C0Co051>1?l0ED/3o`1JB0?o
05i51?l0Hd02o`1W>`?o06`e0ol0LBl3o`1e9`?o07XO0_l0OQL3o`233@;o08P30ol7S003oa:A00;o
7YH00_l/VP03ocVO00;oB:<00omGZ002ofN]00?oMk400_n8]P03oi^j00;o[Kl00oo1a002olRk00?o
cK000ooAX`03omJF0003om^80?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Fooooo`03o`00
0?oooooooooo00;ooooo0_oKR003omJF00?odJ<00_o=/003olRk00?o`L@00_n]_`03oi^j00;oR;H0
0omg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00olNUP02oa:A00?o1h`00_l0R0<3o`233@?o07hG
0_l0NQl3o`1e9`?o074_0ol0K3D3o`1W>`?o06=01?l0GTD3o`1JB0Co05E;1?l0D4h4o`18C0Go03i7
1_l0=D<8o`0]?Poo02Di1ol07SD>o`0U>@So02dn1_l0=D<4o`0nA`Go04Q<1?l0D4h4o`1EB`?o05Y8
1?l0GTD3o`1S@0?o06Lk0ol0K3D3o`1a;`;o07DW1?l0NQl2o`1n5`;o08<=0ol0R0<3o`N<00;o4Y40
0olNUP02obbJ00?o>Il00_m8X`03oeNX00;oIjd00omg/@02ohRf00?oVkX00_n]_`03ol7400;ob;/0
0oo=/003om6S00?oeYH000?ofhP0ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o
0000ooooooooool00_ooool2om^800?oeYH00ooAX`02olf`00?ob;/00oo1a002ojfo00?oVkX00_n8
]P03ogNa00;oIjd00omGZ002odRS00?o>Il00_l/VP03oajF00;o4Y400ol7S002o`280`?o08<=0ol0
OQL3o`1j7`?o07DW0_l0LBl4o`1/=@?o06Lk0ol0Hd04o`1NA@?o05Y81?l0ED/4o`1@CPGo04Q<1_l0
?TL6o`0e@`So02dn7_l09CT8o`0]?PKo03E31_l0?TL5o`18C0Co051>1?l0ED/3o`1JB0Co05i50ol0
Hd03o`1W>`?o06`e0ol0LBl3o`1e9`;o07XO0ol0OQL3o`233@;o08P30ol7S003oa:A00;o7YH00ol/
VP02ocVO00?oB:<00_mGZ002ofN]00?oMk400_n8]P03oi^j00?o[Kl00_o1a003olRk00;ocK000ooA
X`03omJF00;ofhP01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool3
om^800?oeYH00_oAX`03olf`00?ob;/00_o1a003ojfo00?oVkX00_n8]P03ogNa00;oIjd00omGZ002
odRS00?o>Il00_l/VP03oajF00;o4Y400ol7S002o`280`?o08<=0ol0OQL3o`1j7`;o07DW0ol0LBl3
o`1/=@Co06Lk0ol0Hd03o`1NA@Co05Y81?l0ED/4o`1@CPGo04Q<1Ol0?TL7o`0e@`Wo02dn6Ol09CT:
o`0]?PKo03E31_l0?TL5o`18C0Co051>1?l0ED/3o`1JB0Co05i51?l0Hd02o`1W>`Co06`e0_l0LBl4
o`1e9`;o07XO0ol0OQL3o`233@;o08P30ol7S003oa:A00;o7YH00_l/VP03ocVO00?oB:<00_mGZ002
ofN]00?oMk400_n8]P03oi^j00;o[Kl00oo1a003olRk00;ocK000ooAX`03omJF00;ofhP01Oooool1
o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool3om^800?oeYH00_oAX`03olf`
00?ob;/00_o1a003ojfo00?oVkX00_n8]P03ogNa00;oIjd00omGZ002odRS00?o>Il00_l/VP03oajF
00;o4Y400ol7S003o`280`;o08<=0ol0OQL3o`1j7`?o07DW0ol0LBl3o`1/=@?o06Lk1?l0Hd04o`1N
A@?o05Y81?l0ED/5o`1@CPGo04Q<1Ol0?TL8o`0e@`co02dn3ol09CT;o`0]?PSo03E31Ol0?TL5o`18
C0Go051>1?l0ED/3o`1JB0Co05i50ol0Hd04o`1W>`?o06`e0ol0LBl2o`1e9`?o07XO0ol0OQL3o`23
3@;o08P30ol7S003oa:A00;o7YH00ol/VP02ocVO00?oB:<00_mGZ003ofN]00;oMk400on8]P02oi^j
00?o[Kl00_o1a003olRk00?ocK000_oAX`03omJF00?ofhP01Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool01?oONP3ofhP0om^80?oKR002omJF00?odJ<00oo=/003olRk
00;o`L@00on]_`02oi^j00?oR;H00_mg/@03ofN]00?oEjP00_m8X`03ocVO00;o;9X00olNUP02oa:A
00?o1h`00ol0R0<2o`233@?o07hG0ol0NQl3o`1e9`?o074_0ol0K3D3o`1W>`Co06=00ol0GTD4o`1J
B0Co05E;1?l0D4h6o`18C0Ko03i71ol0=D<To`0]?PSo03E31_l0?TL4o`18C0Go051>1?l0ED/3o`1J
B0Co05i51?l0Hd03o`1W>`?o06`e0ol0LBl3o`1e9`?o07XO0ol0OQL2o`233@?o08P30ol7S002oa:A
00?o7YH00ol/VP02ocVO00;oB:<00omGZ003ofN]00;oMk400_n8]P03oi^j00?o[Kl00_o1a003olRk
00?ocK000_oAX`03omJF00?ofhP01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooooooo
ool00_ooool01?oONP3ofhP0om^80?oKR002omJF00?odJ<00oo=/003olRk00;o`L@00on]_`02oi^j
00?oR;H00omg/@02ofN]00?oEjP00_m8X`03ocVO00;o;9X00olNUP03oa:A00;o1h`00ol0R0<3o`23
3@;o07hG1?l0NQl2o`1e9`Co074_0ol0K3D3o`1W>`Co06=01?l0GTD4o`1JB0Co05E;1?l0D4h6o`18
C0Ko03i72_l0=D<Jo`0]?P[o03E31_l0?TL6o`18C0Co051>1?l0ED/4o`1JB0Co05i51?l0Hd03o`1W
>`?o06`e0ol0LBl3o`1e9`?o07XO0ol0OQL3o`233@;o08P30ol7S002oa:A00?o7YH00ol/VP02ocVO
00?oB:<00_mGZ003ofN]00;oMk400on8]P02oi^j00?o[Kl00oo1a002olRk00?ocK000ooAX`03omJF
00?ofhP01Oooool1o`00007ooooo0Oooool001Kooooo0_l00003ooooo`04ommj0?oKR03ofhP0om^8
00?oeYH00ooAX`03olf`00;ob;/00oo1a003ojfo00;oVkX00on8]P02ogNa00?oIjd00omGZ002odRS
00?o>Il00_l/VP03oajF00;o4Y400ol7S003o`280`?o08<=0_l0OQL3o`1j7`?o07DW0ol0LBl4o`1/
=@?o06Lk0ol0Hd04o`1NA@Co05Y81?l0ED/5o`1@CPKo04Q<1ol0?TL:o`0e@aOo02dn2Ol0=D<7o`0n
A`Ko04Q<1?l0D4h4o`1EB`Co05Y81?l0GTD4o`1S@0Co06Lk0_l0K3D4o`1a;`;o07DW1?l0NQl2o`1n
5`?o08<=0ol0R0<2o`N<00?o4Y400olNUP02obbJ00?o>Il00om8X`02oeNX00;oIjd00omg/@03ohRf
00;oVkX00on]_`03ol7400;ob;/00oo=/003om6S00?oeYH00ooKR004ooooo`;o00000_ooool001Ko
oooo00?o0000ooooooooool00_ooool01?oONP3ofhP0om^80?oKR003omJF00?odJ<00oo=/002olRk
00?o`L@00on]_`02oi^j00?oR;H00_mg/@03ofN]00?oEjP00_m8X`03ocVO00?o;9X00_lNUP03oa:A
00?o1h`00_l0R0<3o`233@?o07hG0ol0NQl3o`1e9`?o074_0ol0K3D4o`1W>`Co06=01?l0GTD4o`1J
B0Co05E;1_l0D4h6o`18C0So03i73_l0=D<7o`0]?Pgo03E32?l0?TL6o`18C0Ko051>1?l0ED/4o`1J
B0Co05i51?l0Hd03o`1W>`Co06`e0ol0LBl3o`1e9`;o07XO1?l0OQL2o`233@?o08P30ol7S002oa:A
00?o7YH00_l/VP03ocVO00?oB:<00_mGZ003ofN]00;oMk400on8]P02oi^j00?o[Kl00oo1a002olRk
00?ocK000ooAX`03omJF00?ofhP000?oggX0ooooooooool00oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool2ommj00?ofhP00ooFUP03om6S00?ocK000_o8^`03ol7400?o
[Kl00_nK^P03ohRf00;oMk400omW[@03oeNX00;oB:<00oliW`02obbJ00?o7YH00olBT@02o`N<00?o
08P30ol0P`d3o`1n5`?o07XO0ol0MBL3o`1a;`?o06`e1?l0Ic/3o`1S@0Co05i51?l0FTP5o`1EB`Go
051>1ol0B4`8o`0nAb3o03E32?l0?TL6o`18C0Ko051>1?l0ED/4o`1JB0Co05i51?l0Hd04o`1W>`?o
06`e0ol0LBl3o`1e9`?o07XO0ol0OQL3o`233@;o08P30ol7S003oa:A00;o7YH00ol/VP03ocVO00;o
B:<00omGZ003ofN]00;oMk400on8]P02oi^j00?o[Kl00oo1a002olRk00?ocK000ooAX`03omJF00?o
fhP000?oggX0ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool2ommj00?ofhP00ooFUP03om6S00?ocK000_o8^`03ol7400?o[Kl00_nK^P03ohRf00?oMk40
0_mW[@03oeNX00?oB:<00_liW`03obbJ00?o7YH00_lBT@03o`N<00?o08P30_l0P`d4o`1n5`;o07XO
1?l0MBL3o`1a;`?o06`e1?l0Ic/4o`1S@0Co05i51?l0FTP6o`1EB`Co051>2?l0B4`:o`0nAaOo03E3
2Ol0?TL8o`18C0Co051>1_l0ED/4o`1JB0Co05i51?l0Hd03o`1W>`Co06`e0ol0LBl3o`1e9`?o07XO
0ol0OQL3o`233@?o08P30_l7S003oa:A00?o7YH00_l/VP03ocVO00?oB:<00_mGZ003ofN]00;oMk40
0on8]P02oi^j00?o[Kl00oo1a002olRk00?ocK000ooAX`03omJF00?ofhP00_oONP05ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`?oggX00ooKR003omJF00?odJ<00oo=
/002olRk00?o`L@00on]_`02oi^j00?oR;H00omg/@02ofN]00?oEjP00_m8X`03ocVO00?o;9X00_lN
UP03oa:A00?o1h`00ol0R0<2o`233@?o07hG0ol0NQl4o`1e9`?o074_0ol0K3D4o`1W>`Co06=01?l0
GTD4o`1JB0Go05E;1_l0D4h7o`18C0go03i73ol0=D<<o`0nA`Oo04Q<1Ol0D4h6o`1EB`Co05Y81?l0
GTD4o`1S@0Co06Lk0ol0K3D3o`1a;`Co07DW0_l0NQl4o`1n5`;o08<=0ol0R0<3o`N<00;o4Y401?lN
UP02obbJ00;o>Il00om8X`03oeNX00;oIjd00omg/@03ohRf00;oVkX00on]_`03ol7400;ob;/00oo=
/003om6S00?oeYH00ooKR002ommj00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooo
oooo00;ooooo0ooONP03om^800?oeYH00ooAX`03olf`00;ob;/00oo1a003ojfo00?oVkX00_n8]P03
ogNa00?oIjd00_mGZ003odRS00?o>Il00_l/VP03oajF00?o4Y400_l7S003o`280`?o08<=0ol0OQL3
o`1j7`Co07DW0ol0LBl3o`1/=@Co06Lk1?l0Hd04o`1NA@Ko05Y81?l0ED/6o`1@CP[o04Q<7_l0?TL:
o`18C0Ko051>1?l0ED/6o`1JB0Co05i51?l0Hd03o`1W>`Co06`e0ol0LBl3o`1e9`Co07XO0_l0OQL4
o`233@;o08P30ol7S003oa:A00;o7YH00ol/VP03ocVO00;oB:<00omGZ003ofN]00;oMk400on8]P02
oi^j00?o[Kl00oo1a003olRk00;ocK000ooAX`03omJF00?ofhP00ooONP05ooooo`7o00000Oooool1
ooooo`005_ooool00ol0003oooooooooo`02ooooo`04onAZ0?oONP3oggX0ommj00?ofhP00ooFUP03
om6S00?ocK000_o8^`03ol7400?o[Kl00_nK^P03ohRf00?oMk400_mW[@03oeNX00?oB:<00_liW`03
obbJ00?o7YH00_lBT@03o`N<00?o08P30ol0P`d3o`1n5`?o07XO0ol0MBL4o`1a;`?o06`e1?l0Ic/4
o`1S@0Co05i51Ol0FTP6o`1EB`Ko051>2_l0B4`Jo`0nA`Wo04Q<2?l0D4h4o`1EB`Ko05Y81?l0GTD4
o`1S@0Co06Lk0ol0K3D3o`1a;`Co07DW0ol0NQl3o`1n5`?o08<=0ol0R0<2o`N<00?o4Y400olNUP02
obbJ00Co>Il00_m8X`02oeNX00CoIjd00_mg/@02ohRf00?oVkX00on]_`03ol7400?ob;/00_o=/003
om6S00?oeYH00ooKR003ommj00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo
00;ooooo00Coi6X0ommj0?oONP3oggX00ooKR003omJF00?odJ<00oo=/002olRk00?o`L@00on]_`02
oi^j00?oR;H00omg/@02ofN]00?oEjP00om8X`03ocVO00?o;9X00_lNUP03oa:A00?o1h`00ol0R0<3
o`233@?o07hG0ol0NQl4o`1e9`?o074_0ol0K3D4o`1W>`Go06=01Ol0GTD4o`1JB0Ko05E;2?l0D4h<
o`18C0oo03i72ol0B4`8o`1@CPKo05E;1?l0FTP5o`1NA@Co06=01?l0Ic/4o`1/=@?o074_1?l0MBL3
o`1j7`?o07hG0ol0P`d3o`280`?o1h`00_lBT@03oajF00?o;9X00oliW`02odRS00?oEjP00omW[@02
ogNa00?oR;H00_nK^P03ojfo00?o`L@00oo8^`02olf`00?odJ<00ooFUP03om^800CoggX01Oooool1
o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool00ooTJP3oggX0ommj0002ommj
00?ofhP00ooFUP03om6S00?ocK000_o8^`03ol7400?o[Kl00_nK^P03ohRf00?oMk400_mW[@03oeNX
00?oB:<00oliW`02obbJ00?o7YH00olBT@03o`N<00?o08P30ol0P`d3o`1n5`?o07XO0ol0MBL4o`1a
;`?o06`e1?l0Ic/5o`1S@0Co05i51Ol0FTP7o`1EB`So051>8_l0B4`8o`1@CPOo05E;1?l0FTP6o`1N
A@Co06=01?l0Ic/3o`1/=@?o074_1?l0MBL3o`1j7`?o07hG0ol0P`d3o`280`?o1h`00olBT@02oajF
00Co;9X00_liW`03odRS00?oEjP00_mW[@03ogNa00?oR;H00_nK^P03ojfo00?o`L@00_o8^`03olf`
00?odJ<00ooFUP03om^800CoggX01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooooooo
ool00_ooool00ooTJP3oggX0ommj0002ommj00?ofhP00ooFUP03om6S00?ocK000oo8^`02ol7400?o
[Kl00onK^P02ohRf00?oMk400omW[@02oeNX00?oB:<00oliW`03obbJ00?o7YH00_lBT@04o`N<00;o
08P31?l0P`d3o`1n5`?o07XO1?l0MBL3o`1a;`Co06`e1?l0Ic/5o`1S@0Co05i51_l0FTP8o`1EB`So
051>6_l0B4`8o`1@CPSo05E;1_l0FTP4o`1NA@Go06=01?l0Ic/4o`1/=@?o074_1?l0MBL3o`1j7`?o
07hG0ol0P`d3o`280`?o1h`00olBT@03oajF00;o;9X00oliW`03odRS00?oEjP00_mW[@03ogNa00?o
R;H00_nK^P03ojfo00?o`L@00oo8^`02olf`00?odJ<00ooFUP03om^800CoggX000?oi6X0oooooooo
ool00oooool1o`00007ooooo0Oooool000kooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo
0_oTJP04ommj00?ofhP00ooFUP03om6S00?ocK000_o8^`03ol7400?o[Kl00onK^P02ohRf00?oMk40
0omW[@02oeNX00?oB:<00oliW`03obbJ00?o7YH00_lBT@03o`N<00?o08P30ol0P`d4o`1n5`?o07XO
0ol0MBL4o`1a;`Co06`e1?l0Ic/4o`1S@0Ko05i51Ol0FTP8o`1EB`go051>3ol0B4`<o`1@CPSo05E;
1_l0FTP4o`1NA@Go06=01?l0Ic/4o`1/=@?o074_1?l0MBL4o`1j7`;o07hG1?l0P`d2o`280`Co1h`0
0_lBT@03oajF00?o;9X00oliW`03odRS00;oEjP00omW[@03ogNa00;oR;H00onK^P03ojfo00;o`L@0
1?o8^`02olf`00?odJ<00ooFUP03om^800CoggX000?oi6X0ooooooooool00oooool1o`00007ooooo
0Oooool000gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo
0_oTJP04ommj00?ofhP00ooFUP03om6S00?ocK000oo8^`03ol7400;o[Kl00onK^P03ohRf00;oMk40
0omW[@03oeNX00?oB:<00oliW`02obbJ00?o7YH00olBT@03o`N<00?o08P31?l0P`d3o`1n5`?o07XO
1?l0MBL4o`1a;`Co06`e1?l0Ic/5o`1S@0Go05i51_l0FTP8o`1EBb;o051>2?l0ED/6o`1JB0Go05i5
1Ol0Hd04o`1W>`Co06`e1?l0LBl4o`1e9`?o07XO0ol0OQL3o`233@Co08P30_l7S004oa:A00;o7YH0
0ol/VP03ocVO00?oB:<00_mGZ003ofN]00?oMk400on8]P02oi^j00?o[Kl00oo1a003olRk00;ocK00
0ooAX`03omJF00CofhP00ooONP02onAZ00Gooooo0Ol00001ooooo`7ooooo000Aooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool3onAZ00CoggX00ooKR003omJF00?odJ<00oo=
/003olRk00;o`L@00on]_`03oi^j00?oR;H00_mg/@03ofN]00?oEjP00om8X`02ocVO00?o;9X00olN
UP03oa:A00?o1h`00ol0R0<3o`233@Co07hG0ol0NQl4o`1e9`?o074_1?l0K3D5o`1W>`Go06=01Ol0
GTD7o`1JB0[o05E;6_l0D4h9o`1EB`So05Y81Ol0GTD5o`1S@0Co06Lk1?l0K3D4o`1a;`Co07DW1?l0
NQl2o`1n5`Co08<=0ol0R0<3o`N<00?o4Y400olNUP02obbJ00Co>Il00_m8X`03oeNX00?oIjd00_mg
/@03ohRf00?oVkX00_n]_`04ol7400;ob;/00oo=/003om6S00?oeYH00ooKR004ommj00;oi6X01Ooo
ool1o`00007ooooo0Oooool0017ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo0ooTJP04
ommj00?ofhP00ooFUP03om6S00?ocK000oo8^`03ol7400?o[Kl00_nK^P03ohRf00?oMk400_mW[@04
oeNX00;oB:<00oliW`03obbJ00?o7YH00olBT@03o`N<00?o08P31?l0P`d3o`1n5`?o07XO1?l0MBL4
o`1a;`Co06`e1_l0Ic/4o`1S@0Ko05i52?l0FTP>o`1EB`_o051>3Ol0ED/8o`1JB0Ko05i51?l0Hd06
o`1W>`Co06`e1?l0LBl3o`1e9`Co07XO0ol0OQL3o`233@Co08P30ol7S003oa:A00?o7YH00ol/VP02
ocVO00?oB:<00omGZ003ofN]00?oMk400_n8]P03oi^j00?o[Kl00oo1a002olRk00?ocK000ooAX`03
omJF00CofhP00ooONP03onAZ00?ooooo0ol00002ooooo`003Oooool4o`0000Gooooo00?o0000oooo
ooooool00_ooool01?oXFP3oi6X0onAZ0?oTJP04ommj00?ofhP00ooFUP03om6S00?ocK000oo8^`03
ol7400;o[Kl00onK^P03ohRf00?oMk400_mW[@03oeNX00?oB:<00oliW`03obbJ00?o7YH00olBT@03
o`N<00?o08P30ol0P`d4o`1n5`?o07XO1?l0MBL4o`1a;`Co06`e1Ol0Ic/5o`1S@0Oo05i52?l0FTPQ
o`1EB`Wo05Y81ol0GTD4o`1S@0Ko06Lk1?l0K3D4o`1a;`Co07DW0ol0NQl3o`1n5`Co08<=0ol0R0<3
o`N<00?o4Y400olNUP03obbJ00?o>Il00_m8X`04oeNX00;oIjd00omg/@03ohRf00;oVkX01?n]_`02
ol7400?ob;/00oo=/003om6S00?oeYH01?oKR003ommj00?oi6X01Oooool1o`00007ooooo0Oooool0
00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onQJ0?oTJP3oi6X0
onAZ00CoggX00ooKR003omJF00?odJ<00oo=/003olRk00?o`L@00on]_`03oi^j00;oR;H00omg/@03
ofN]00?oEjP00om8X`03ocVO00?o;9X00olNUP03oa:A00?o1h`00ol0R0<4o`233@?o07hG1?l0NQl4
o`1e9`Co074_1Ol0K3D4o`1W>`Ko06=02?l0GTD:o`1JB1Oo05E;2Ol0FTP8o`1NA@Ko06=01?l0Ic/5
o`1/=@Co074_1?l0MBL4o`1j7`?o07hG1?l0P`d3o`280`?o1h`00olBT@03oajF00?o;9X00oliW`03
odRS00?oEjP00_mW[@03ogNa00?oR;H00onK^P03ojfo00;o`L@00oo8^`03olf`00?odJ<00ooFUP04
om^800?oggX00ooTJP000ooXFP3oooooooooo`03ooooo`7o00000Oooool1ooooo`003Oooool5o`00
00Cooooo00?o0000ooooooooool00_ooool2onQJ00?oi6X01?oONP03om^800?oeYH00ooAX`03olf`
00?ob;/00oo1a003ojfo00;oVkX00on8]P03ogNa00?oIjd00omGZ003odRS00?o>Il00ol/VP03oajF
00?o4Y400ol7S003o`280`?o08<=1?l0OQL4o`1j7`Co07DW1?l0LBl5o`1/=@Go06Lk1_l0Hd08o`1N
AA3o05Y81ol0ED/@o`1JB0Oo05i51_l0Hd05o`1W>`Go06`e1Ol0LBl3o`1e9`Co07XO0ol0OQL4o`23
3@?o08P30ol7S004oa:A00;o7YH01?l/VP02ocVO00?oB:<00omGZ003ofN]00?oMk400_n8]P04oi^j
00;o[Kl00oo1a003olRk00?ocK000ooAX`03omJF00?ofhP01?oONP03onAZ0003onQJ0?oooooooooo
00?ooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0_oXFP04onAZ00?o
ggX00ooKR003omJF00?odJ<00oo=/003olRk00?o`L@00on]_`03oi^j00?oR;H00omg/@03ofN]00;o
EjP01?m8X`02ocVO00Co;9X00_lNUP04oa:A00?o1h`00ol0R0<4o`233@Co07hG1?l0NQl4o`1e9`Co
074_1_l0K3D4o`1W>`So06=02?l0GTDNo`1JB0So05i52?l0Hd04o`1W>`Ko06`e1?l0LBl4o`1e9`Co
07XO1?l0OQL3o`233@Co08P30ol7S003oa:A00?o7YH00ol/VP03ocVO00?oB:<00omGZ003ofN]00?o
Mk400on8]P02oi^j00?o[Kl00oo1a003olRk00?ocK000ooAX`03omJF00?ofhP01?oONP03onAZ00;o
j5X01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool3onQJ00?oi6X0
1?oONP03om^800?oeYH00ooAX`03olf`00?ob;/00oo1a003ojfo00?oVkX00on8]P03ogNa00;oIjd0
0omGZ003odRS00?o>Il00ol/VP03oajF00Co4Y400ol7S003o`280`Co08<=0ol0OQL4o`1j7`Go07DW
1?l0LBl5o`1/=@Ko06Lk1ol0Hd0<o`1NAAGo05Y82ol0GTD6o`1S@0Ko06Lk1_l0K3D4o`1a;`Co07DW
1?l0NQl4o`1n5`Co08<=0ol0R0<3o`N<00Co4Y400_lNUP04obbJ00;o>Il01?m8X`02oeNX00CoIjd0
0_mg/@03ohRf00?oVkX00on]_`03ol7400?ob;/00oo=/003om6S00?oeYH00ooKR003ommj00Coi6X0
0_oXFP05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`?oj5X01?oT
JP03ommj00?ofhP00ooFUP04om6S00?ocK000oo8^`02ol7400Co[Kl00_nK^P04ohRf00;oMk400omW
[@03oeNX00?oB:<00oliW`04obbJ00;o7YH01?lBT@04o`N<00?o08P30ol0P`d4o`1n5`Co07XO1Ol0
MBL5o`1a;`Ko06`e1_l0Ic/8o`1S@2;o05i52?l0Hd06o`1W>`Ko06`e1Ol0LBl5o`1e9`Co07XO1?l0
OQL3o`233@?o08P31?l7S003oa:A00?o7YH00ol/VP04ocVO00;oB:<01?mGZ002ofN]00?oMk400on8
]P03oi^j00?o[Kl00oo1a003olRk00?ocK000ooAX`03omJF00?ofhP01?oONP03onAZ00?oj5X01Ooo
ool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool4onQJ00Coi6X00ooONP03
om^800?oeYH01?oAX`03olf`00?ob;/00_o1a003ojfo00?oVkX00on8]P03ogNa00?oIjd00omGZ003
odRS00?o>Il00ol/VP03oajF00Co4Y400ol7S004o`280`?o08<=1?l0OQL4o`1j7`Go07DW1Ol0LBl5
o`1/=@Oo06Lk2_l0Hd0Lo`1NA@[o06=01_l0Ic/6o`1/=@Go074_1Ol0MBL4o`1j7`Co07hG1?l0P`d2
o`280`Co1h`01?lBT@02oajF00Co;9X00oliW`03odRS00?oEjP00omW[@02ogNa00CoR;H00_nK^P04
ojfo00;o`L@01?o8^`02olf`00CodJ<00ooFUP03om^800CoggX00ooTJP03onQJ00Gooooo0Ol00001
ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo1?oXFP04onAZ00?oggX01?oKR003omJF
00?odJ<00oo=/003olRk00?o`L@00on]_`03oi^j00?oR;H00omg/@03ofN]00?oEjP00om8X`03ocVO
00Co;9X00_lNUP04oa:A00Co1h`01?l0R0<3o`233@Go07hG1?l0NQl4o`1e9`Ko074_1_l0K3D8o`1W
>`co06=03ol0GTD;o`1S@0So06Lk1_l0K3D6o`1a;`Co07DW1?l0NQl5o`1n5`?o08<=1?l0R0<4o`N<
00?o4Y400olNUP04obbJ00?o>Il00om8X`03oeNX00?oIjd00omg/@03ohRf00?oVkX00on]_`03ol74
00?ob;/00oo=/003om6S00?oeYH00ooKR004ommj00?oi6X01?oXFP05ooooo`7o00000Oooool1oooo
o`005_ooool00ol0003oooooooooo`02ooooo`03one:0?oXFP3oj5X000;oj5X01?oTJP03ommj00Co
fhP00ooFUP03om6S00?ocK000oo8^`03ol7400?o[Kl00onK^P03ohRf00?oMk400omW[@03oeNX00?o
B:<00oliW`03obbJ00?o7YH01?lBT@03o`N<00Co08P31?l0P`d4o`1n5`Co07XO1Ol0MBL6o`1a;`Ko
06`e2Ol0Ic/Qo`1S@0[o06Lk1_l0K3D6o`1a;`Co07DW1?l0NQl5o`1n5`?o08<=1?l0R0<4o`N<00Co
4Y400_lNUP04obbJ00?o>Il00om8X`03oeNX00?oIjd00omg/@03ohRf00?oVkX00on]_`03ol7400?o
b;/00oo=/003om6S00CoeYH00ooKR003ommj00Coi6X01?oXFP05ooooo`7o00000Oooool1ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`03one:0?oXFP3oj5X000;oj5X01?oTJP03ommj00CofhP0
0ooFUP03om6S00CocK000_o8^`04ol7400;o[Kl01?nK^P02ohRf00CoMk400omW[@03oeNX00?oB:<0
0oliW`04obbJ00?o7YH00olBT@04o`N<00Co08P31?l0P`d4o`1n5`Ko07XO1?l0MBL6o`1a;`So06`e
2_l0Ic/Go`1S@0Wo06Lk2?l0K3D6o`1a;`Co07DW1_l0NQl4o`1n5`Co08<=1?l0R0<3o`N<00Co4Y40
0olNUP04obbJ00?o>Il00om8X`03oeNX00?oIjd00omg/@03ohRf00?oVkX00on]_`03ol7400?ob;/0
0oo=/003om6S00CoeYH00ooKR003ommj00Coi6X01?oXFP000oo]BP3oooooooooo`03ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`;okDX01?oXFP04onAZ00?oggX01?oK
R003omJF00?odJ<00oo=/003olRk00?o`L@00on]_`03oi^j00?oR;H00omg/@04ofN]00?oEjP00om8
X`03ocVO00?o;9X01?lNUP03oa:A00Co1h`01?l0R0<4o`233@Co07hG1Ol0NQl5o`1e9`Oo074_2?l0
K3DWo`1W>`So06`e1_l0LBl4o`1e9`Ko07XO1?l0OQL4o`233@Co08P31?l7S003oa:A00?o7YH01?l/
VP03ocVO00?oB:<01?mGZ002ofN]00CoMk400_n8]P04oi^j00;o[Kl01?o1a002olRk00CocK000ooA
X`03omJF00CofhP00ooONP04onAZ00Coj5X000?okDX0ooooooooool00oooool1o`00007ooooo0Ooo
ool001Kooooo0_l00003ooooo`;okDX01?oXFP04onAZ00CoggX00ooKR003omJF00CodJ<00oo=/003
olRk00?o`L@00on]_`03oi^j00?oR;H01?mg/@02ofN]00CoEjP00om8X`03ocVO00Co;9X01?lNUP03
oa:A00Co1h`01?l0R0<5o`233@Co07hG1?l0NQl6o`1e9`So074_2_l0K3DJo`1W>`[o06`e2?l0LBl6
o`1e9`Co07XO1?l0OQL5o`233@Co08P31?l7S003oa:A00Co7YH00ol/VP04ocVO00?oB:<00omGZ003
ofN]00?oMk401?n8]P02oi^j00Co[Kl00oo1a003olRk00?ocK000ooAX`03omJF00CofhP00ooONP04
onAZ00Coj5X00_o]BP04ooooo`;o00000_ooool001Kooooo00?o0000ooooooooool00_ooool3one:
00Coj5X01?oTJP04ommj00?ofhP00ooFUP04om6S00?ocK000oo8^`03ol7400?o[Kl00onK^P03ohRf
00?oMk400omW[@04oeNX00?oB:<00oliW`04obbJ00?o7YH01?lBT@04o`N<00Co08P31?l0P`d5o`1n
5`Go07XO1_l0MBL8o`1a;`co06`e4_l0Ic/=o`1/=@Ko074_1_l0MBL6o`1j7`Co07hG1_l0P`d4o`28
0`?o1h`00olBT@04oajF00Co;9X00oliW`03odRS00CoEjP00_mW[@04ogNa00?oR;H00onK^P03ojfo
00?o`L@00oo8^`03olf`00CodJ<00ooFUP03om^800CoggX01?oTJP04onQJ00;okDX01Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool4one:00Coj5X01?oTJP04ommj00Co
fhP00_oFUP04om6S00?ocK000oo8^`04ol7400;o[Kl01?nK^P02ohRf00CoMk400omW[@03oeNX00Co
B:<00oliW`03obbJ00Co7YH01?lBT@04o`N<00Co08P31?l0P`d6o`1n5`Ko07XO1_l0MBL8o`1a;b;o
06`e2?l0LBl6o`1e9`Ko07XO1_l0OQL4o`233@Co08P31?l7S004oa:A00Co7YH00ol/VP03ocVO00Co
B:<00omGZ003ofN]00CoMk400_n8]P04oi^j00?o[Kl00oo1a003olRk00?ocK001?oAX`03omJF00?o
fhP01?oONP04onAZ00Coj5X00oo]BP05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooo
ooooo`02ooooo`GokDX01?oXFP04onAZ00?oggX01?oKR003omJF00?odJ<00oo=/004olRk00?o`L@0
0on]_`03oi^j00?oR;H01?mg/@03ofN]00?oEjP00om8X`04ocVO00Co;9X01?lNUP03oa:A00Go1h`0
1?l0R0<4o`233@Ko07hG1_l0NQl8o`1e9`[o074_5_l0K3D:o`1a;`So07DW1_l0NQl6o`1n5`Co08<=
1?l0R0<5o`N<00?o4Y401?lNUP04obbJ00?o>Il00om8X`04oeNX00?oIjd00omg/@03ohRf00?oVkX0
1?n]_`03ol7400?ob;/00oo=/003om6S00CoeYH00ooKR004ommj00?oi6X01?oXFP05one:00Gooooo
0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo00?olSP0one:0?o]BP000oo]
BP04onQJ00Coi6X00ooONP03om^800CoeYH01?oAX`02olf`00Cob;/00oo1a003ojfo00CoVkX00_n8
]P04ogNa00?oIjd00omGZ004odRS00Co>Il01?l/VP03oajF00?o4Y401_l7S004o`280`Co08<=1_l0
OQL6o`1j7`So07DW9_l0LBl8o`1e9`Ko07XO1_l0OQL4o`233@Go08P31Ol7S003oa:A00Co7YH00ol/
VP04ocVO00CoB:<00omGZ003ofN]00CoMk400_n8]P04oi^j00?o[Kl00oo1a004olRk00?ocK000ooA
X`04omJF00?ofhP00ooONP04onAZ00Coj5X01Oo]BP05ooooo`7o00000Oooool1ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`03oo8h0?o]BP3okDX000?okDX01?oXFP04onAZ00?oggX01?oKR004
omJF00?odJ<00oo=/003olRk00Co`L@00on]_`03oi^j00?oR;H01?mg/@03ofN]00?oEjP01?m8X`03
ocVO00Co;9X01?lNUP04oa:A00Co1h`01_l0R0<4o`233@Ko07hG2?l0NQl:o`1e9a[o074_2_l0MBL8
o`1j7`Ko07hG1?l0P`d6o`280`Co1h`01?lBT@04oajF00?o;9X01?liW`03odRS00CoEjP00omW[@03
ogNa00?oR;H01?nK^P03ojfo00?o`L@00oo8^`04olf`00?odJ<00ooFUP04om^800?oggX01?oTJP04
onQJ00GokDX000?olSP0ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool2oo8h00GokDX01?oXFP04onAZ00?oggX01?oKR004omJF00?odJ<00oo=/004olRk
00?o`L@00on]_`04oi^j00;oR;H01?mg/@04ofN]00;oEjP01?m8X`04ocVO00Co;9X01?lNUP04oa:A
00Co1h`01_l0R0<4o`233@So07hG1_l0NQl>o`1e9`oo074_3Ol0MBL6o`1j7`So07hG1?l0P`d6o`28
0`Co1h`01?lBT@04oajF00Co;9X01?liW`04odRS00;oEjP01?mW[@04ogNa00?oR;H00onK^P03ojfo
00?o`L@01?o8^`03olf`00?odJ<01?oFUP04om^800?oggX01?oTJP04onQJ00GokDX000?olSP0oooo
ooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool3oo8h00Co
kDX01?oXFP04onAZ00CoggX01?oKR003omJF00?odJ<01?o=/003olRk00?o`L@01?n]_`03oi^j00?o
R;H01?mg/@03ofN]00CoEjP01?m8X`03ocVO00Co;9X01?lNUP05oa:A00Co1h`01_l0R0<6o`233@Ko
07hG2_l0NQlNo`1e9`[o07XO1_l0OQL6o`233@Ko08P31?l7S005oa:A00Co7YH01?l/VP03ocVO00Co
B:<00omGZ004ofN]00?oMk401?n8]P03oi^j00?o[Kl00oo1a004olRk00?ocK000ooAX`04omJF00?o
fhP01?oONP04onAZ00Coj5X01?o]BP03oo8h00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`00
0?oooooooooo00;ooooo1?ob>004one:00Coj5X01?oTJP04ommj00CofhP01?oFUP02om6S00CocK00
1?o8^`02ol7400Co[Kl01?nK^P02ohRf00CoMk401?mW[@04oeNX00?oB:<00oliW`04obbJ00Co7YH0
1_lBT@04o`N<00Ko08P31_l0P`d8o`1n5`co07XO4ol0MBL;o`1j7`So07hG1_l0P`d6o`280`Co1h`0
1_lBT@04oajF00Co;9X00oliW`04odRS00?oEjP01?mW[@04ogNa00;oR;H01?nK^P04ojfo00?o`L@0
0oo8^`04olf`00?odJ<00ooFUP04om^800CoggX01?oTJP04onQJ00CokDX00oob>005ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`ColSP01Oo]BP04onQJ00Coi6X01?oO
NP03om^800CoeYH00ooAX`04olf`00?ob;/00oo1a004ojfo00?oVkX01?n8]P03ogNa00CoIjd00omG
Z004odRS00Co>Il01?l/VP04oajF00Ko4Y401?l7S006o`280`Ko08<=2_l0OQLRo`1j7`[o07hG1_l0
P`d6o`280`Co1h`01_lBT@04oajF00Co;9X01?liW`04odRS00?oEjP01?mW[@03ogNa00?oR;H01?nK
^P03ojfo00Co`L@00oo8^`03olf`00CodJ<00ooFUP04om^800?oggX01?oTJP04onQJ00GokDX01?ob
>005ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`GolSP01Oo]BP04
onQJ00Coi6X01?oONP04om^800?oeYH00ooAX`04olf`00Cob;/00_o1a004ojfo00CoVkX00on8]P03
ogNa00CoIjd01?mGZ004odRS00Co>Il01?l/VP04oajF00Ko4Y401?l7S006o`280`So08<=2_l0OQLJ
o`1j7`[o07hG2?l0P`d6o`280`Co1h`01_lBT@04oajF00Co;9X01?liW`04odRS00CoEjP01?mW[@03
ogNa00?oR;H01?nK^P04ojfo00?o`L@00oo8^`04olf`00?odJ<00ooFUP04om^800CoggX01?oTJP04
onQJ00GokDX01?ob>005ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02oooo
o`GolSP01Oo]BP05onQJ00Coi6X00ooONP04om^800?oeYH01?oAX`04olf`00?ob;/00oo1a004ojfo
00?oVkX01?n8]P04ogNa00?oIjd01?mGZ004odRS00Co>Il01Ol/VP04oajF00Ko4Y401?l7S008o`28
0`So08<=4_l0OQL3o`1j7a7o07hG2?l0P`d8o`280`Co1h`01_lBT@04oajF00Go;9X01?liW`04odRS
00CoEjP00omW[@04ogNa00?oR;H01?nK^P03ojfo00Co`L@00oo8^`03olf`00CodJ<00ooFUP04om^8
00CoggX01?oTJP04onQJ00GokDX01Oob>005ooooo`7o00000Oooool1ooooo`005_ooool2o`0000?o
oooo00?omRH0oo8h0?ob>0000oob>006one:00Coj5X01?oTJP04ommj00?ofhP00ooFUP04om6S00Co
cK001?o8^`02ol7400Co[Kl01?nK^P04ohRf00?oMk400omW[@04oeNX00CoB:<01?liW`06obbJ00Co
7YH01_lBT@06o`N<00Ko08P32_l0P`dNo`1n5`[o08<=1_l0R0<6o`N<00Ko4Y401?lNUP06obbJ00Co
>Il01?m8X`04oeNX00?oIjd01?mg/@03ohRf00CoVkX01?n]_`03ol7400?ob;/01?o=/004om6S00?o
eYH00ooKR004ommj00Coi6X01OoXFP05one:00GolSP01?ooool2o`0000;ooooo000Fooooo`03o`00
0?oooooooooo00;ooooo00?omRH0oo8h0?ob>0001?ob>005one:00Coj5X01?oTJP04ommj00CofhP0
0ooFUP04om6S00?ocK001?o8^`04ol7400?o[Kl01?nK^P03ohRf00CoMk401?mW[@04oeNX00CoB:<0
1?liW`06obbJ00Co7YH01_lBT@06o`N<00So08P33_l0P`d?o`1n5`go08<=2?l0R0<6o`N<00Ko4Y40
1?lNUP06obbJ00Co>Il01?m8X`04oeNX00CoIjd01?mg/@03ohRf00CoVkX00on]_`04ol7400?ob;/0
1?o=/003om6S00CoeYH00ooKR004ommj00Coi6X01OoXFP04one:00KolSP000?omRH0ooooooooool0
0oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2ooHV00KolSP01Oo]
BP04onQJ00Coi6X01?oONP04om^800?oeYH01?oAX`04olf`00Cob;/00oo1a003ojfo00CoVkX01?n8
]P04ogNa00CoIjd01?mGZ004odRS00Co>Il01_l/VP04oajF00Ko4Y402?l7S008o`280b;o08<=2?l0
R0<8o`N<00Ko4Y401?lNUP06obbJ00Co>Il01?m8X`04oeNX00CoIjd01?mg/@04ohRf00CoVkX00on]
_`04ol7400?ob;/01?o=/004om6S00?oeYH01?oKR004ommj00Coi6X01?oXFP05one:00KolSP000?o
mRH0ooooooooool00oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool3
ooHV00KolSP01?o]BP05onQJ00Coi6X01?oONP03om^800CoeYH01?oAX`03olf`00Cob;/01?o1a003
ojfo00CoVkX01?n8]P04ogNa00CoIjd01?mGZ005odRS00Co>Il01_l/VP04oajF00Ko4Y402?l7S00>
o`280a?o08<=3Ol0R0<8o`N<00Ko4Y401?lNUP06obbJ00Co>Il01Om8X`04oeNX00CoIjd01?mg/@04
ohRf00?oVkX01?n]_`04ol7400?ob;/01?o=/003om6S00CoeYH01?oKR004ommj00Coi6X01?oXFP05
one:00GolSP00oof9P05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02oooo
o`ComRH01_ob>004one:00Goj5X01?oTJP04ommj00?ofhP01?oFUP04om6S00CocK001?o8^`03ol74
00?o[Kl01?nK^P04ohRf00CoMk401?mW[@04oeNX00KoB:<01?liW`06obbJ00Ko7YH01_lBT@0:o`N<
02;o08P32_l7S006oa:A00Ko7YH01_l/VP04ocVO00KoB:<01?mGZ004ofN]00CoMk401?n8]P04oi^j
00?o[Kl00oo1a004olRk00CocK001?oAX`04omJF00?ofhP01?oONP04onAZ00Goj5X01?o]BP06oo8h
00?omRH01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool4ooHV00Ko
lSP01Oo]BP04onQJ00Coi6X01?oONP04om^800CoeYH01?oAX`04olf`00?ob;/01?o1a004ojfo00Co
VkX01?n8]P04ogNa00CoIjd01?mGZ005odRS00Go>Il01_l/VP06oajF00So4Y402_l7S00Jo`280`[o
1h`02?lBT@06oajF00Ko;9X01OliW`05odRS00CoEjP01?mW[@04ogNa00CoR;H01?nK^P04ojfo00?o
`L@01?o8^`04olf`00?odJ<01?oFUP04om^800CoggX01?oTJP05onQJ00CokDX01_ob>004ooHV00Go
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo1_of9P05oo8h00GokDX0
1?oXFP04onAZ00CoggX01?oKR004omJF00CodJ<01?o=/004olRk00Co`L@01?n]_`04oi^j00CoR;H0
1?mg/@04ofN]00CoEjP01?m8X`06ocVO00Ko;9X01_lNUP0:oa:A02Ko1h`02_lBT@06oajF00Ko;9X0
1_liW`04odRS00CoEjP01?mW[@05ogNa00CoR;H01?nK^P03ojfo00Co`L@01?o8^`04olf`00CodJ<0
1?oFUP04om^800CoggX01?oTJP04onQJ00GokDX01Oob>005ooHV00Gooooo0Ol00001ooooo`7ooooo
000Fooooo`03o`000?oooooooooo00;ooooo1_of9P05oo8h00KokDX01?oXFP04onAZ00CoggX01?oK
R004omJF00CodJ<01?o=/004olRk00?o`L@01?n]_`04oi^j00CoR;H01?mg/@06ofN]00CoEjP01_m8
X`04ocVO00Ko;9X02?lNUP0:oa:A01ko1h`02_lBT@08oajF00Ko;9X01?liW`06odRS00CoEjP01OmW
[@05ogNa00CoR;H01?nK^P03ojfo00Co`L@01?o8^`04olf`00?odJ<01?oFUP04om^800CoggX01?oT
JP05onQJ00GokDX01Oob>006ooHV00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooo
oooo00;ooooo1oof9P05oo8h00KokDX01?oXFP04onAZ00CoggX01?oKR004omJF00CodJ<01?o=/004
olRk00Co`L@01?n]_`04oi^j00CoR;H01?mg/@06ofN]00CoEjP01_m8X`04ocVO00So;9X02?lNUP0@
oa:A00_o1h`03olBT@08oajF00So;9X01?liW`06odRS00GoEjP01OmW[@04ogNa00CoR;H01?nK^P04
ojfo00Co`L@01?o8^`04olf`00CodJ<01?oFUP04om^800CoggX01?oTJP04onQJ00KokDX01Oob>006
ooHV00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo1oof9P06oo8h
00GokDX01OoXFP04onAZ00CoggX01?oKR004omJF00CodJ<01?o=/004olRk00Co`L@01?n]_`05oi^j
00CoR;H01?mg/@04ofN]00KoEjP01_m8X`06ocVO00Ko;9X03?lNUP0Noa:A00co7YH01_l/VP06ocVO
00KoB:<01_mGZ004ofN]00CoMk401?n8]P05oi^j00Co[Kl01?o1a004olRk00?ocK001?oAX`04omJF
00CofhP01?oONP05onAZ00Coj5X01Oo]BP06oo8h00OomRH01Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool2oo/C00KomRH01_ob>006one:00Coj5X01?oTJP04ommj00Co
fhP01?oFUP04om6S00CocK001?o8^`04ol7400Co[Kl01OnK^P05ohRf00CoMk401?mW[@06oeNX00Ko
B:<01_liW`08obbJ00ko7YH04olBT@0=oajF00So;9X01_liW`06odRS00KoEjP01?mW[@04ogNa00Go
R;H01OnK^P04ojfo00Co`L@01?o8^`04olf`00CodJ<01?oFUP04om^800CoggX01?oTJP04onQJ00Ko
kDX01_ob>007ooHV00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo
0_ok4`07ooHV00KolSP01Oo]BP05onQJ00Coi6X01?oONP05om^800CoeYH01?oAX`04olf`00Cob;/0
1?o1a004ojfo00CoVkX01On8]P05ogNa00CoIjd01_mGZ006odRS00So>Il02_l/VP0RoajF00[o;9X0
2?liW`06odRS00KoEjP01?mW[@05ogNa00GoR;H01?nK^P04ojfo00Co`L@01?o8^`04olf`00CodJ<0
1?oFUP04om^800CoggX01OoTJP04onQJ00GokDX01_ob>008ooHV0003oo/C0?oooooooooo00?ooooo
0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0ook4`07ooHV00KolSP01_o]
BP04onQJ00Coi6X01?oONP05om^800CoeYH01?oAX`04olf`00Gob;/01?o1a004ojfo00CoVkX01?n8
]P06ogNa00KoIjd01?mGZ008odRS00So>Il03?l/VP0GoajF00_o;9X02?liW`08odRS00CoEjP01_mW
[@06ogNa00CoR;H01?nK^P04ojfo00Go`L@01?o8^`04olf`00CodJ<01?oFUP05om^800CoggX01?oT
JP05onQJ00GokDX01_ob>007ooHV00;ona<01Oooool1o`00007ooooo0Oooool001Kooooo0_l00003
ooooo`?ona<02?of9P06oo8h00GokDX01OoXFP04onAZ00GoggX01?oKR004omJF00CodJ<01?o=/004
olRk00Go`L@01On]_`04oi^j00CoR;H01_mg/@06ofN]00KoEjP01_m8X`0:ocVO02Ko;9X02_liW`06
odRS00KoEjP01_mW[@06ogNa00CoR;H01?nK^P05ojfo00Go`L@01?o8^`04olf`00CodJ<01?oFUP04
om^800CoggX01OoTJP05onQJ00GokDX01_ob>007ooHV00?ona<01?ooool2o`0000;ooooo000Foooo
o`03o`000?oooooooooo00;ooooo1?ok4`08ooHV00KolSP01Oo]BP05onQJ00Coi6X01OoONP04om^8
00GoeYH01?oAX`04olf`00Cob;/01?o1a005ojfo00GoVkX01?n8]P06ogNa00KoIjd01_mGZ008odRS
00co>Il06_l/VP0<ocVO00SoB:<01_mGZ006ofN]00KoMk401?n8]P05oi^j00Go[Kl01?o1a004olRk
00CocK001?oAX`05omJF00CofhP01OoONP04onAZ00Goj5X01Oo]BP06oo8h00SomRH00ook4`05oooo
o`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`Gona<02?of9P06oo8h00Go
kDX01OoXFP04onAZ00GoggX01?oKR004omJF00GodJ<01?o=/005olRk00Co`L@01?n]_`06oi^j00Co
R;H01_mg/@06ofN]00SoEjP02?m8X`0ZocVO00SoB:<02?mGZ006ofN]00KoMk401?n8]P06oi^j00Co
[Kl01?o1a005olRk00CocK001?oAX`05omJF00CofhP01?oONP05onAZ00Goj5X01Oo]BP06oo8h00Oo
mRH01Ook4`05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`Kona<0
2?of9P06oo8h00GokDX01OoXFP04onAZ00GoggX01OoKR004omJF00CodJ<01?o=/005olRk00Go`L@0
1?n]_`06oi^j00CoR;H01_mg/@08ofN]00KoEjP03?m8X`0NocVO00coB:<01_mGZ008ofN]00KoMk40
1?n8]P06oi^j00Co[Kl01Oo1a005olRk00CocK001?oAX`04omJF00GofhP01OoONP04onAZ00Goj5X0
1Oo]BP06oo8h00SomRH01Ook4`05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`Oona<01oof9P07oo8h00GokDX01OoXFP05onAZ00CoggX01?oKR005omJF00GodJ<01?o=
/004olRk00Ko`L@01?n]_`06oi^j00KoR;H01_mg/@06ofN]00[oEjP03_m8X`0?ocVO00goB:<02_mG
Z006ofN]00KoMk401_n8]P06oi^j00Co[Kl01_o1a004olRk00CocK001OoAX`04omJF00GofhP01?oO
NP05onAZ00Goj5X01Oo]BP06oo8h00SomRH01_ok4`05ooooo`7o00000Oooool1ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`Sona<02?of9P06oo8h00GokDX01OoXFP05onAZ00GoggX01?oKR004
omJF00GodJ<01Oo=/004olRk00Ko`L@01?n]_`06oi^j00KoR;H01_mg/@08ofN]00[oEjP08_m8X`0:
oeNX00SoIjd01_mg/@06ohRf00KoVkX01On]_`05ol7400Cob;/01Oo=/005om6S00CoeYH01?oKR005
ommj00Goi6X01OoXFP05one:00KolSP02?of9P07oo/C00Gooooo0Ol00001ooooo`7ooooo000Foooo
o`03o`000?oooooooooo00;ooooo2?ok4`08ooHV00KolSP01_o]BP05onQJ00Goi6X01?oONP05om^8
00GoeYH01?oAX`05olf`00Gob;/01Oo1a005ojfo00KoVkX01_n8]P06ogNa00[oIjd03_mGZ00CodRS
00goEjP02_mW[@06ogNa00KoR;H01_nK^P05ojfo00Go`L@01Oo8^`05olf`00CodJ<01OoFUP04om^8
00GoggX01OoTJP05onQJ00GokDX01_ob>008ooHV00Sona<01Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool:oo/C00SomRH01_ob>006one:00Coj5X01_oTJP04ommj00Co
fhP01_oFUP04om6S00CocK001_o8^`04ol7400Ko[Kl01_nK^P06ohRf00SoMk402_mW[@0VoeNX00[o
Ijd02?mg/@06ohRf00KoVkX01_n]_`04ol7400Kob;/01?o=/004om6S00KoeYH01?oKR005ommj00Go
i6X01OoXFP05one:00KolSP02?of9P09oo/C00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`00
0?oooooooooo00;ooooo2_ok4`08ooHV00OolSP01Oo]BP05onQJ00Goi6X01OoONP05om^800CoeYH0
1_oAX`04olf`00Kob;/01?o1a006ojfo00KoVkX02?n8]P08ogNa00koIjd05omGZ00=ofN]00SoMk40
2?n8]P06oi^j00Ko[Kl01?o1a006olRk00CocK001OoAX`05omJF00GofhP01OoONP04onAZ00Koj5X0
1Oo]BP06oo8h00SomRH02_ok4`05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`cona<02?of9P06oo8h00KokDX01?oXFP06onAZ00CoggX01_oKR004omJF00KodJ<01?o=
/006olRk00Co`L@01_n]_`08oi^j00SoR;H02?mg/@0ZofN]00SoMk402?n8]P08oi^j00Ko[Kl01?o1
a006olRk00GocK001OoAX`04omJF00KofhP01?oONP06onAZ00Coj5X01_o]BP06oo8h00SomRH02ook
4`05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`cona<02?of9P07
oo8h00GokDX01_oXFP05onAZ00GoggX01OoKR005omJF00GodJ<01Oo=/006olRk00Ko`L@01_n]_`06
oi^j00SoR;H03?mg/@0NofN]00coMk402?n8]P06oi^j00Ko[Kl01_o1a006olRk00GocK001OoAX`05
omJF00GofhP01OoONP05onAZ00Goj5X01_o]BP06oo8h00SomRH03?ok4`05ooooo`7o00000Oooool1
ooooo`005_ooool00ol0003oooooooooo`02ooooo`kona<02?of9P06oo8h00KokDX01_oXFP04onAZ
00KoggX01?oKR006omJF00CodJ<01_o=/006olRk00Ko`L@01_n]_`08oi^j00[oR;H05?mg/@03ofN]
01?oMk402_n8]P08oi^j00Ko[Kl01_o1a006olRk00KocK001?oAX`06omJF00CofhP01_oONP05onAZ
00Goj5X01_o]BP06oo8h00SomRH03Ook4`05ooooo`7o00000Oooool1ooooo`005_ooool2o`0000?o
oooo3_ok4`08ooHV00OolSP01_o]BP05onQJ00Koi6X01OoONP05om^800GoeYH01OoAX`06olf`00Ko
b;/01_o1a006ojfo00[oVkX02_n8]P0RogNa00[oR;H02_nK^P06ojfo00Ko`L@01_o8^`06olf`00Go
dJ<01OoFUP05om^800GoggX01_oTJP05onQJ00KokDX01_ob>008ooHV00kona<01?ooool2o`0000;o
oooo000Fooooo`03o`000?oooooooooo00;ooooo4?ok4`08ooHV00KolSP01_o]BP06onQJ00Goi6X0
1OoONP06om^800CoeYH01_oAX`06olf`00Kob;/01_o1a008ojfo00[oVkX04?n8]P0?ogNa00ooR;H0
2_nK^P08ojfo00Ko`L@01_o8^`06olf`00KodJ<01?oFUP06om^800GoggX01OoTJP06onQJ00KokDX0
1_ob>008ooHV00oona<01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_oo
ool@oo/C00WomRH01_ob>007one:00Goj5X01OoTJP06ommj00KofhP01?oFUP06om6S00KocK001_o8
^`08ol7400So[Kl02_nK^P0VohRf00[oVkX02?n]_`08ol7400Kob;/01_o=/006om6S00CoeYH01_oK
R006ommj00Goi6X01OoXFP06one:00OolSP02?of9P0@oo/C00Gooooo0Ol00001ooooo`7ooooo000F
ooooo`03o`000?oooooooooo00;ooooo4_ok4`08ooHV00KolSP01oo]BP05onQJ00Koi6X01_oONP05
om^800GoeYH01_oAX`06olf`00Sob;/01_o1a00:ojfo00koVkX05on8]P0=oi^j00[o[Kl01_o1a008
olRk00KocK001_oAX`05omJF00GofhP01_oONP06onAZ00Goj5X01oo]BP06oo8h00SomRH04Ook4`05
ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02oooooa;ona<02Oof9P07oo8h
00KokDX01_oXFP06onAZ00GoggX01OoKR006omJF00KodJ<01_o=/008olRk00So`L@02_n]_`0Zoi^j
00[o[Kl02?o1a008olRk00KocK001_oAX`06omJF00GofhP01OoONP06onAZ00Koj5X01_o]BP07oo8h
00SomRH04_ok4`05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02oooooaCo
na<02?of9P08oo8h00KokDX01_oXFP05onAZ00GoggX01_oKR006omJF00KodJ<02?o=/006olRk00[o
`L@03?n]_`0Noi^j00co[Kl02_o1a006olRk00SocK001_oAX`06omJF00KofhP01OoONP05onAZ00Ko
j5X01oo]BP07oo8h00SomRH04ook4`05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooo
ooooo`02oooooaCona<02Oof9P07oo8h00OokDX01_oXFP05onAZ00KoggX01_oKR006omJF00SodJ<0
1_o=/008olRk00[o`L@0;_n]_`0:ol7400Sob;/01_o=/008om6S00KoeYH01_oKR006ommj00Goi6X0
1_oXFP07one:00OolSP02?of9P0Doo/C00Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oo
oooooooo00;ooooo5_ok4`08ooHV00SolSP01_o]BP06onQJ00Koi6X01_oONP06om^800KoeYH02?oA
X`06olf`00[ob;/03?o1a00Rojfo00co`L@02_o8^`06olf`00SodJ<01_oFUP06om^800KoggX01_oT
JP06onQJ00KokDX02?ob>008ooHV01Gona<01Oooool1o`00007ooooo0Oooool001Kooooo00?o0000
ooooooooool00_oooolGoo/C00WomRH01oob>007one:00Koj5X01_oTJP06ommj00KofhP02?oFUP06
om6S00SocK002_o8^`0@ol7401?o[Kl03oo1a00:olRk00SocK001_oAX`08omJF00KofhP01_oONP06
onAZ00Koj5X01oo]BP07oo8h00WomRH05_ok4`05ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02oooooaSona<02Oof9P07oo8h00SokDX01_oXFP06onAZ00KoggX01_oKR008omJF
00KodJ<02_o=/00<olRk02Ko`L@03?o8^`0:olf`00KodJ<02?oFUP06om^800KoggX01_oTJP07onQJ
00OokDX01oob>009ooHV01Oona<01Oooool1o`00007ooooo0Oooool000Sooooo0ol00004ooooo`;o
00001Oooool00ol0003oooooooooo`02oooooaWona<02Oof9P08oo8h00KokDX02?oXFP06onAZ00Ko
ggX01_oKR008omJF00SodJ<02_o=/00>olRk01[o`L@03_o8^`0:olf`00SodJ<02?oFUP06om^800Ko
ggX01_oTJP08onQJ00KokDX02?ob>009ooHV01Sona<01Oooool1o`00007ooooo0Oooool000Wooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;o
oooo6_ok4`0:ooHV00SolSP01_o]BP07onQJ00Ooi6X01_oONP08om^800KoeYH02_oAX`0:olf`02ko
b;/02_o=/00:om6S00KoeYH02?oKR006ommj00Ooi6X01ooXFP06one:00SolSP02_of9P0Ioo/C00Go
oooo0Ol00001ooooo`7ooooo0009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`02oooooacona<02Oof9P08oo8h00OokDX01_oXFP08onAZ00Ko
ggX02?oKR008omJF00[odJ<03?o=/00RolRk00cocK002_oAX`08omJF00SofhP01_oONP08onAZ00Ko
j5X01oo]BP08oo8h00WomRH06ook4`05ooooo`7o00000Oooool1ooooo`002Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo0ol00002oooooagona<02Oof9P08oo8h00So
kDX01_oXFP08onAZ00KoggX02?oKR008omJF00codJ<04_o=/00?olRk017ocK003?oAX`08omJF00So
fhP01_oONP08onAZ00Koj5X02?o]BP08oo8h00WomRH07?ok4`03ooooo`?o00000_ooool000Wooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;o
oooo7_ok4`0:ooHV00SolSP02?o]BP06onQJ00Soi6X02?oONP08om^800SoeYH03?oAX`0Zolf`00co
dJ<02?oFUP08om^800SoggX02?oTJP06onQJ00SokDX02?ob>00:ooHV01gona<01Oooool1o`00007o
oooo0Oooool000Sooooo0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool00_oooolPoo/C00[omRH02?ob>007one:00Ooj5X02?oTJP08ommj00SofhP02_oFUP0@om6S01[o
cK004?oAX`0:omJF00SofhP02?oONP08onAZ00Ooj5X01oo]BP08oo8h00[omRH07ook4`05ooooo`7o
00000Oooool1ooooo`002Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003ooooo
ooooo`3oooooo`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo0?oooooo1Ooo
ool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0ooooool5ooooo`7o00000Oooool1
ooooo`005_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool01?l0003oooooooooool00002ooooo`005_ooooooo`0000Wo00000_ooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0037ooooo0ol0002:ooooo`03o`000?oooooo
oooo02_ooooo0ol0000Eooooo`03o`000?oooooooooo01Wooooo000booooo`03o`000?oooooooooo
08Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01Sooooo000/ooooo`?o00000oooool3o`0000Cooooo0_l00002ooooo`Go00000_ooool3o`0000?o
oooo1?l000000ooooooo0000o`000003o`0000Oooooo0ol00004ooooo`Co00000oooool2o`0000;o
oooo1_l00006ooooo`Co00000_ooool5o`000003ooooool0003o000000?o000000?oooooo`000?l0
00000ol00002ooooo`?o00000_ooool3o`0000Cooooo0ol00002ooooo`?o000000Coooooo`000?l0
003ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
00?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Go00000_ooool3o`00
00;ooooo0ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00002ooooo`[o00001Oooool0
0ol0003oooooooooo`0Gooooo`00:oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001_ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`00:ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`03o`00
0?oooooooooo00;ooooo1Ol00002ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool5o`00
00Sooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003
ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`04o`000?ooooooooooooooo`Go00000_oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001Oooool01?l0
003oooooooooool00002ooooo`?o00001Oooool00ol0003oooooooooo`0Gooooo`00:oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02?ooool3o`0000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo0000
00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`07o`000?oooooo0000
ooooool0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Gooooo
00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo01Oooooo000[ooooo`06
o`000?ooooooooooooooool0003ooooo1?l00002ooooo`Co00000_ooool3o`0000Cooooo0ol00003
ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l0
0003ooooo`Co00000oooool3o`0000Wooooo00Go0000oooooooooooo0000ooooo`03o`0000Cooooo
1?l00002ooooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o0000
0_ooool4o`0000?ooooo0ol00003ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`Ko0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00002ooooo`Co00000oooool9o`0000?ooooo0ol00003ooooo`Co0000
1?ooool00ol0003oooooooooo`0Gooooo`00:oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool06?ooool002cooooo0ol00009ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03Oooool3o`0000Wooooo1?l00009ooooo`03o`000?oooooooooo00;o
oooo0_l0000:ooooo`Co00001?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool2o`0002ko
oooo00?o0000ooooooooool06?ooool3o`0001Kooooo00?o0000ooooooooool00_ooool2o`0000_o
oooo00?o0000ooooooooool06Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-15.8127, -11.6125, 0.0808724, \
0.0809232}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.659916 0.0472626 0.5 0.0472465 [
[.18729 -0.0125 -9 -9 ]
[.18729 -0.0125 9 0 ]
[.4236 -0.0125 -6 -9 ]
[.4236 -0.0125 6 0 ]
[.65992 -0.0125 -3 -9 ]
[.65992 -0.0125 3 0 ]
[.89623 -0.0125 -3 -9 ]
[.89623 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02754 -18 -4.5 ]
[-0.0125 .02754 0 4.5 ]
[-0.0125 .26377 -12 -4.5 ]
[-0.0125 .26377 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .73623 -6 -4.5 ]
[-0.0125 .73623 0 4.5 ]
[-0.0125 .97246 -12 -4.5 ]
[-0.0125 .97246 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -66 0 ]
[.5 1.0125 66 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18729 0 m
.18729 .00625 L
s
[(-10)] .18729 -0.0125 0 1 Mshowa
.4236 0 m
.4236 .00625 L
s
[(-5)] .4236 -0.0125 0 1 Mshowa
.65992 0 m
.65992 .00625 L
s
[(0)] .65992 -0.0125 0 1 Mshowa
.89623 0 m
.89623 .00625 L
s
[(5)] .89623 -0.0125 0 1 Mshowa
.125 Mabswid
.23455 0 m
.23455 .00375 L
s
.28182 0 m
.28182 .00375 L
s
.32908 0 m
.32908 .00375 L
s
.37634 0 m
.37634 .00375 L
s
.47087 0 m
.47087 .00375 L
s
.51813 0 m
.51813 .00375 L
s
.56539 0 m
.56539 .00375 L
s
.61265 0 m
.61265 .00375 L
s
.70718 0 m
.70718 .00375 L
s
.75444 0 m
.75444 .00375 L
s
.8017 0 m
.8017 .00375 L
s
.84897 0 m
.84897 .00375 L
s
.14003 0 m
.14003 .00375 L
s
.09276 0 m
.09276 .00375 L
s
.0455 0 m
.0455 .00375 L
s
.94349 0 m
.94349 .00375 L
s
.99075 0 m
.99075 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02754 m
.00625 .02754 L
s
[(-10)] -0.0125 .02754 1 0 Mshowa
0 .26377 m
.00625 .26377 L
s
[(-5)] -0.0125 .26377 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .73623 m
.00625 .73623 L
s
[(5)] -0.0125 .73623 1 0 Mshowa
0 .97246 m
.00625 .97246 L
s
[(10)] -0.0125 .97246 1 0 Mshowa
.125 Mabswid
0 .07478 m
.00375 .07478 L
s
0 .12203 m
.00375 .12203 L
s
0 .16927 m
.00375 .16927 L
s
0 .21652 m
.00375 .21652 L
s
0 .31101 m
.00375 .31101 L
s
0 .35826 m
.00375 .35826 L
s
0 .40551 m
.00375 .40551 L
s
0 .45275 m
.00375 .45275 L
s
0 .54725 m
.00375 .54725 L
s
0 .59449 m
.00375 .59449 L
s
0 .64174 m
.00375 .64174 L
s
0 .68899 m
.00375 .68899 L
s
0 .78348 m
.00375 .78348 L
s
0 .83073 m
.00375 .83073 L
s
0 .87797 m
.00375 .87797 L
s
0 .92522 m
.00375 .92522 L
s
.25 Mabswid
0 0 m
0 1 L
s
.18729 .99375 m
.18729 1 L
s
.4236 .99375 m
.4236 1 L
s
.65992 .99375 m
.65992 1 L
s
.89623 .99375 m
.89623 1 L
s
.125 Mabswid
.23455 .99625 m
.23455 1 L
s
.28182 .99625 m
.28182 1 L
s
.32908 .99625 m
.32908 1 L
s
.37634 .99625 m
.37634 1 L
s
.47087 .99625 m
.47087 1 L
s
.51813 .99625 m
.51813 1 L
s
.56539 .99625 m
.56539 1 L
s
.61265 .99625 m
.61265 1 L
s
.70718 .99625 m
.70718 1 L
s
.75444 .99625 m
.75444 1 L
s
.8017 .99625 m
.8017 1 L
s
.84897 .99625 m
.84897 1 L
s
.14003 .99625 m
.14003 1 L
s
.09276 .99625 m
.09276 1 L
s
.0455 .99625 m
.0455 1 L
s
.94349 .99625 m
.94349 1 L
s
.99075 .99625 m
.99075 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02754 m
1 .02754 L
s
.99375 .26377 m
1 .26377 L
s
.99375 .5 m
1 .5 L
s
.99375 .73623 m
1 .73623 L
s
.99375 .97246 m
1 .97246 L
s
.125 Mabswid
.99625 .07478 m
1 .07478 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .16927 m
1 .16927 L
s
.99625 .21652 m
1 .21652 L
s
.99625 .31101 m
1 .31101 L
s
.99625 .35826 m
1 .35826 L
s
.99625 .40551 m
1 .40551 L
s
.99625 .45275 m
1 .45275 L
s
.99625 .54725 m
1 .54725 L
s
.99625 .59449 m
1 .59449 L
s
.99625 .64174 m
1 .64174 L
s
.99625 .68899 m
1 .68899 L
s
.99625 .78348 m
1 .78348 L
s
.99625 .83073 m
1 .83073 L
s
.99625 .87797 m
1 .87797 L
s
.99625 .92522 m
1 .92522 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
0 0 m
0 1 L
s
[(Interference Intensity)] .5 1.0125 0 -1 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00031B00041C00041C00031B00031A00021900021900031A00041C00051E00061F00061F
00051E00031C00021A00021900031A00041D00062000082200092300082100051F00031B
00021900021A00041C000720000A24000D27000C2600092300061F00031B00021900031B
00061F000B2500102A00122C000F29000A2400051E00021A00021900051D000A2400112B
00162F00162F00102A00092300041C00021900031B000721000E2900162F001A3200162F
000F2900072100031B00021900041D000A2400132C001932001A3200142D000B2500051E
00021900031A000620000D2700152E00183100152F000E2800072100031B00021900041C
000822000E2800132D00132D000F2900092300041D00021900021A00051E000923000D27
000F29000D2700092300051E00031A00021900031B00061F000822000A24000A24000822
00051E00031B00021900021A00041C00051E00072000072100061F00051D00031B000219
00021900031A00041C00041D00051E00041D00041C00031A
00041C00041C00041C00031B00031A00021900021900031A00041D00061F000620000620
00051E00041C00021A00021900031A00041D000721000923000A2400092300061F00041C
00021900021A00041D000821000C26000F29000E28000B2500062000031B00021900031B
000720000D2700132C00152E00122C000B2600061F00031A00021A00051E000B2500142D
001A32001A3200132D000A2500041D00021900031B00082200112B001A32001F35001B33
00112B00082200031B00021900051D000C2600162F001E35001F35001730000D2700051E
00021900031A000720000F29001831001D3400193200112B00082200031B00021900041C
00092300102A00162F00173000122B000A2400051D00021900021A00051E000A24000F29
00112B000F29000A2500061F00031A00021900031B00061F000924000C26000C26000923
00061F00031B00021900021A00041C00061F00082100082200072000051E00031B000219
00021900031A00041C00051E00051E00051E00041C00031B
00041C00041D00041D00031C00031A00021900021900031B00041D00061F000721000721
00061F00041C00031A00021900031A00051E000821000A25000B25000A2400072000041C
00021900021A00041D000822000D2800112B00102A000C2600072000031B00021900031B
000821000E2900152F00183100142E000D2700061F00031A00021A00051E000D27001730
001E35001E3500162F000C2600051D00021900031B00092300132D001F35002439001F36
00142D00092300031B00021900051E000D27001932002338002439001B33000F2900061F
00021A00031A00082100112B001C34002237001E3500132D00092300041C00021900041C
000A2400132C001A32001B3300142E000C2600051E00021A00021A00061F000B2500112B
00142E00122C000C2600062000031B00021900031B000620000B25000D28000D27000A24
00062000031B00021900021A00041C00062000082200092300082100051E00031B000219
00021900031A00041D00051E00061F00051E00041D00031B
00041C00051D00041D00041C00031A00021900021900031B00051D000720000822000821
00062000041D00031A00021900031B00051E000922000C26000D27000B2500072100041C
00021900021A00051D000923000F2900132D00122C000D2800082100031B00021900031C
00082200102A001931001C33001730000F2900072000031A00021A00061F000E28001A32
002338002338001932000D2700051E00021900031B000A2400162F002439002A3C002439
001730000A2400031C00021900051E000F29001D3400293C002A3C001F3600112B000620
00021A00031B00082200132D00203600273B00233800162F000A2500041C00021900041D
000B2500152E001E35001F35001830000D2800061F00021A00031A00061F000C2700142D
00173000142E000D2800072000031B00021900031B000721000C26000F29000F29000B26
00072000041C00021900021A00041D000720000923000A2400082200061F00041C00021A
00021900031B00041D00061F00062000061F00041D00031B
00041D00051E00051D00041C00031A00021900021900031B00051E000721000923000822
00072000041D00031A00021900031B00061F000923000D27000E28000C2600082200041D
00021900021A00051E000A2400112B00152F00152E000F2900082200041C00021900041C
00092300122C001C33001F36001A3200102A00072100031A00021A00061F00102A001D34
00283B00273B001C34000F2900051F00021900031C000A2500183100283B00304000293C
001A32000B2500041C00021900061F00102A002137002F3F00304000243900132D000721
00021A00031B00092300152F002439002C3E00273B001932000C2600041C00021900041D
000C26001830002237002338001B33000F2900062000021A00031A000620000D2800162F
001A32001730000F2900082100031B00021900031C000721000D2700112B00112B000D27
00082100041C00021900021A00041D000721000A24000B2500092300062000041C00021A
00021900031B00051D00061F00072000061F00051D00031B
00041D00051E00051E00041C00031B00021900021900031B00051E000821000923000923
00072100051D00031A00021900031B00061F000A24000E28000F29000D2700082200041D
00021900021A00051E000B2500122C00183000173000102A00092300041C00021900041C
000A2400142E001F35002338001D3400122C00082200031A00021A00062000112B002037
002C3E002C3E00203600102A00061F00021900041C000B26001B33002D3E003643002E3F
001D34000C2600041C00021900061F00122B00243900344200364300283B00152E000821
00021A00031B00092300173000293C003241002C3E001C34000D2700041D00021900051D
000D27001A3200263A00273B001E3500112B00072000021A00031A000620000F29001831
001D3400193200112B00082200031B00021900041C000822000E2800122C00122C000E28
00082200041C00021900021A00051D000822000B25000C26000A2400072100041C00021A
00021900031B00051D00062000072100072000051E00031C
00051D00051E00051E00041D00031B00021900021900031B00061F000822000A24000A24
00082100051D00031A00021900031B000620000B25000F2900112B000E2800092300051D
00021A00021A00051F000C2600142E001A3200193100122C00092400041C00021900041C
000A2400162F00223800273B00213700142D00082200031B00021A00072000132C002439
00324100314100233800122C00062000021900041C000C26001E35003241003C46003442
002036000D2800041C00021900062000132D00283B003A45003C46002D3E001730000822
00031A00031B000A24001A32002D3E003844003241002036000E2800051D00021900051D
000E28001C34002A3C002C3D00213700122C00072100031A00031A00072000102A001A32
002036001C3400132C00092300041C00021900041C000822000F2900142E00142E000F29
00092300041D00021900021A00051D000822000C26000D27000B2500072100041D00021A
00021900031B00051E00072000082100072100051E00041C
00051E00061F00051E00041D00031B00021900021900041C00061F000923000B25000A25
00082200051E00031A00021900031B000720000C2600112B00122C000F29000A2400051E
00021A00021A00061F000D2700162F001D34001B3300142D000A2400041C00021900041C
000B2500183100263A002B3D00243900152F00092300031B00021A00072100142E00283B
00374300374300273B00132D00072000021900041C000D27002037003744004349003A45
002338000E2900041D00021900072000152E002C3E004148004349003241001A32000923
00031A00031B000B25001C33003141003E47003743002338000F2900051E00021900051E
000F29001F36002E3F00304000253900142E00082200031A00031A00072100112B001D34
002338001F3600142E000A2400041C00021900041C00092300102A00162F00162F00112B
000A2400041D00021900021A00051E000923000D27000E28000C2600082200041D00021A
00021900031B00051E00072100082200072100061F00041C
00051E00061F00061F00041D00031B00021900021A00041C000620000923000B26000B25
00082200051E00031A00021900031B000721000D2700122C00142D00102A000A2400051E
00021A00031A00061F000E28001831001F36001E3500152E000B2500041D00021900041D
000C26001A3200293C002F3F00273B00173000092400031B00021A00082100162F002B3D
003C46003C46002B3D00152E00072000021900041C000E28002338003D4600494C003F48
00263A000F2A00041D00021900072000162F00304000474B004A4C003743001C33000924
00031A00031B000B25001E3500364300444A003D4600263A00112B00051E00021900051E
000F2A00213700324100354200283B00162F00082200031A00031A00072100122C001F35
00263A00223800162F000B2500041C00021900041C00092300112B00173000183100122C
000A2500051E00021A00021A00051E000923000D28000F29000D2700092300051E00031A
00021900031B00051E00082100092300082200061F00041C
00051E00061F00061F00051D00031B00021900021A00041C000720000A24000C26000C26
00092300051E00031A00021900031B000721000D2800132D00152E00122B000B2500051E
00021A00031A000620000F29001A32002237002036001730000B2600041D00021900041D
000D27001C33002C3E003341002A3D001931000A2400031B00021A000822001730002F3F
004249004249002E3F00173000072100021900041C000F2900263A004249004F4E00454A
00293C00112B00041D000219000721001830003442004D4E004F4E003C46001E35000A24
00031A00031B000C26002036003B45004A4C004249002A3C00122C00051E00021900051E
00102A002439003643003A45002C3E00183100092300031A00031A00082100132D002137
00293C002539001831000B2600041D00021900041C00092400122C001932001A3200142D
000B2500051E00021A00021A00051E000A24000E2900102A000E2800092300051E00031A
00021900031B00051E00082200092300082200062000041C
00061F00062000061F00051D00031B00021900021A00041C000721000B25000D27000D27
00092300061F00031A00021900041C000821000E2800152E00173000132C000C2600051E
00021A00031A00072000102A001C33002439002338001831000C2600041D00021900041D
000D28001E35003040003844002E3F001B33000B2500031B00021A000822001931003341
00474B00474B00324100183100082100021900041D00102A00293C00484C00524D004B4D
002D3E00122C00051D00021900072100193200384400514D00524D004148002137000B25
00031A00031B000C27002338004048004F4E00484C002D3E00132D00061F00021900051E
00112B00273A003B45003F47003040001A32000A2400031B00031A00082200142E002439
002D3E00283B001A32000C2700041D00021900041C000A2400132D001B33001C3300152F
000C2600051E00021A00021A00051E000A24000F2900112B000F29000A2400051E00031A
00021900031B00061F000822000A2400092300072000041D
00061F00072000062000051E00031B00021900021A00041C000721000B25000E28000D28
000A2400061F00031B00021900041C000822000F2900162F00183100142E000C2600061F
00021A00031A00072000112B001E3500273B00263A001A32000D2700051D00021900041D
000E28002037003442003C46003241001D34000B2500031B00021A000923001B33003743
004E4E004E4E003743001A3200082200021900041D00112B002C3E004E4E00554B00504E
00314000132D00051E000219000822001B33003D4600544C00564B00474B002338000B26
00031A00031B000D2700253900454A00524D004E4E00314100152E00061F00021900051E
00122C00293C00404800444A003442001C34000A2400031B00031A00082200152E00263A
003040002C3D001C34000D2700051D00021900041C000A2400142E001D34001E35001730
000D2700061F00021A00021A00051E000B2500102A00122C00102A000A2500061F00031A
00021900031B00061F000923000A2400092300072000041D
00061F00072100072000051E00031B00021900021A00041D000821000C26000F29000E28
000A2500061F00031B00021900041C00082200102A001830001A3200152F000D2700061F
00021A00031A00072100122C002036002A3D00293C001C34000E2800051D00021900051D
000F29002338003844004148003643001F36000C2600031B00021A000923001D34003B46
00514D00514D003B45001C3300082200021900041D00122C00304000514D00584900534C
00354200142E00051E000219000822001D3400424900574A005949004D4E00263A000C26
00031A00031B000E2800283B004A4D00554B00514D00364300162F00061F00021900051E
00132D002C3E00454A004A4C003944001E35000B2500031B00031A00082200162F00293C
003442002F3F001F35000E2800051E00021900041C000B2500152F001F36002036001931
000E2800061F00021A00021A00051E000B2500112B00132D00112B000B2500061F00031A
00021900031B00061F000923000B25000A2400072100051D
00062000072100072000051E00031B00021900021A00041D000822000D2700102A000F29
000B2500062000031B00021900041C00092300112B001931001C33001730000E2800061F
00021A00031A00082100132D002238002D3E002C3D001E35000E2900051E00021900051E
00102A00253A003D4600464B003A45002137000C2700031B00031A000A24001F36004048
00544C00544C003F48001E3500092300021900041D00132D00344200544C005C4700564B
00394400162F00051E000219000822001F3600474B005A48005C4700504E00293C000D27
00031B00031B000E28002A3D004F4E00584900544C003A4500183100062000021900061F
00142E002F3F004A4C004F4E003D47002137000C2600031B00031A000922001830002C3D
003844003341002137000F2900051E00021900041C000B25001730002137002338001B32
000F2900062000031A00021A00051E000B2600122C00152E00122C000C2600061F00031B
00021900031B00061F000923000B25000A2500082100051E
00072000082100072100051E00031B00021900021A00041D000822000D2700102A00102A
000C2600062000031B00021900041C00092300122C001B33001E35001831000E29000620
00021A00031A00082200142E002539003140002F3F002036000F2900051E00021900051E
00112B00283B004249004C4D003E47002338000D2700031B00031A000A2400213700454A
00564A00564A00444A00203600092300021900051D00142E00384400574A005F44005949
003D4600173000051E000219000923002137004D4E005D46005F4400534C002C3E000E28
00031B00031B000F29002D3E00524D005B4700574A003E47001A3200072000021900061F
00152F003341004F4E00524D004249002338000C2700031B00031A000923001931002E3F
003C4600374300243900102A00051E00021900041C000B26001831002338002539001C34
00102A00072000031A00021A00061F000C2600132C00162F00132D000D2700062000031B
00021900031B000620000A24000C26000B2500082200051E
00072000082200072100051F00031B00021900021A00051D000923000E2800112B00112B
000C2600072000031B00021900041C000A2400132D001D34002036001A32000F29000620
00021A00031A00082200152F00273B00344200324100223800102A00051E00021900051E
00122C002B3D00474B00504E00434900263A000E2800031C00031A000B25002338004B4D
00594800594900494C002237000A2400021900051E00152F003C46005A48006241005C47
00414900183100061F00021900092300243900504E00604300634100564B002F3F000E29
00031B00031B00102A00314000544C005E44005A48004349001C3300072100021900061F
00162F00364300514D00554C00484B00263A000D2800031B00031A000923001A32003241
004048003B4500263A00112B00061F00021900041C000C2600193100253A00283B001F35
00112B00072100031A00021A00061F000C2700142D00173000142E000D2800072000031B
00021900031B000620000A24000C27000C2600082200051E
00072100082200082100061F00031B00021900021A00051D000923000F2900122C00122C
000D2700072000031B00021900041D000A2400142E001E35002237001B3300102A000720
00021A00031A000923001730002A3C00384400364300243900112B00051E00021900051E
00132D002E3F004C4D00524D00484B00283B000E2900031C00031A000B2600263A004F4E
005C46005C46004E4E002439000A2400021900051E001730004048005D4600663D005F44
00464B001A3200061F000219000A2400263A00534C00643F00663D005949003241000F29
00031B00031B00112B00344200574A006241005D4600484C001D3500072100021900061F
001830003A4500544C00574A004D4E00293C000E2800031C00031A000923001C33003542
00454A00404800293C00132C00061F00021900041C000C26001A3200283B002A3D002137
00122C00072100031A00021A00061F000D2700152E00193100162F000E2900072100031B
00021900031B000720000B25000D27000C2600092300051E
00072100092300082200061F00031C00021900021A00051E000A2400102A00132D00132C
000D2800072100031B00021900041D000B2500162F002037002439001D3400112B000720
00021A00031A000923001831002D3E003C4600394500273B00122C00051F00021900051F
00142E00314000504E00554B004D4E002B3D000F2900041C00031A000C2600293C00524D
006043005F4400514D00263A000A2500021900051E00183100454A006043006939006241
004B4D001B3300061F000219000A2400293C00554B00673B006A39005B4700364300102A
00031B00031C00122B003744005A4800653E006043004E4E001F36000822000219000620
001931003E4700574A005A4800504D002C3D000F2900041C00031A000A24001D34003844
004A4C00444A002C3E00142E00062000021900041C000D27001C33002A3D002D3E002338
00142D00082200031A00021A00061F000D2700162F001A32001730000F2900082100031B
00021900031B000720000B25000E28000D2700092300061F
00082200092300082200061F00041C00021900021A00051E000A2400102A00152E00142D
000E2800072100031B00021900041D000B2500173000233800263A001F3600122C000721
00021A00031B000923001932003040004048003D4700293C00132C00061F00021900061F
00152F00354200524D00584A00504E002D3E00102A00041C00031A000D27002B3D00544C
00634000624100534C00283B000B2500021900051E001A32004A4C006340006D3400653E
004F4E001D3400061F000219000B25002B3D005849006B37006D34005E44003A4500112B
00031B00041C00132C003B46005D4600683A00643F00514D002137000822000219000620
001A32004249005949005D4600534C002F3F00102A00041C00031A000A24001F35003C46
004F4E00494C00304000152F00072000021900041C000D27001D34002D3E00304000263A
00152E00082200031A00021A00061F000E28001730001C3300193100102A00082200031B
00021900031B000720000B26000E28000D28000A2400061F
00082200092300092300062000041C00021900031A00051E000B2500112B00162F00152E
000F2900082100031B00021900041D000C2600183100253900293C00213700132C000721
00021A00031B000A24001B3300334200454A004249002C3D00142D00061F00021900061F
00173000384400554B005A4800524D00304000112B00041C00031A000D28002E3F00574A
00663D00663D00564B002B3D000B2500021900061F001B33004F4E00673C00702F00683A
00514D001E3500061F000219000B25002E3F005B47006E3200712F006142003D4700122B
00031B00041C00142D003F48006043006C3600673C00534C002439000822000219000720
001C3300464B005C4700604300564B00324100112B00041C00031A000A24002036004048
00514D004E4E00334100173000072000021900041C000D28001F3500304000344200283B
00162F00092300031B00021A00061F000E28001831001D34001A3200112B00092200031C
00021900031B000721000C26000F29000E28000A2500061F
000822000A2400092300062000041C00021900031A00051E000B2500122C00173000162F
000F2A00082200031B00021900051D000C27001A3200273B002B3D00233800142D000821
00021A00031B000A24001D3400374300494C00464B002F3F00152E00061F00021900061F
001831003C4600574A005D4600554B00334100112B00041C00031A000E28003241005A48
00693900693A005849002D3E000C2600021900061F001D3400514D006A38007429006C36
00544C002036000620000219000C26003241005E4500722D00742900643F00414800122C
00031B00041C00152E00444A006340006F31006A3800554B00263A000923000219000720
001D34004B4D005F4400634000584900364300122C00041C00031A000B2500223800444A
00534C00514D00374300183100072100021900041D000E28002036003241003743002B3D
00183100092300031B00021A00061F000F29001932001F36001C3300122C00092300041C
00021900031B000721000C2600102A000F29000B25000620
000923000A2400092300072000041C00021900031A00061F000C2600132D001831001730
00102A00082200031B00021900051D000D27001B3300293C002E3F00253900152E000822
00031A00031B000B25001E35003A45004E4E004B4D00314100162F00061F000219000620
001932004048005A4800604300574A00364300122C00041C00031B000F29003542005D46
006D34006C35005B48003040000C2600021900061F001F3600544C006D33007823006F31
00564B002237000620000219000D2700354200614200762700782200673B00454A00132D
00031B00041C00162F00484C00663D00732B006E3300584900283B000923000219000721
001F36004F4E00624100663D005B4700394500132D00041C00031A000B2500243900484B
00564B00534C003B45001A3200082100021900041D000E29002238003543003B45002E3F
001932000A2400031B00021A000620000F29001B33002137001D3500132D00092400041C
00021900031B000721000D2700102A00102A000B26000720
000923000B25000A2400072000041C00021900031A00061F000C2600142E001A32001831
00112B00092200031B00021900051E000E28001D34002C3E00314000273B00162F000822
00031A00031B000B26002036003E4700504D004F4E003442001730000620000219000720
001B3300454A005D46006340005A4800394500132D00041C00031B00102A003944005F44
00702F006F31005D46003241000C2700021900062000213700564A00712E007C1C00722C
005849002338000720000219000D2700394400643F007A20007C1B006B3700494C00142E
00031B00041C001730004D4E00693900772500712E005A48002A3D000A24000219000721
00213700514D00653E006939005E45003D4600142D00041D00031A000B2600263A004C4D
00584900564B003F47001C3300082200021900041D000F29002439003944003E47003140
001B33000A2500031B00021A00062000102A001C33002338001F3600152E000A2400041C
00021900031B000721000D2700112B00102A000C26000721
000A24000B25000A2400072100041C00021900031A00061F000D2700152F001B33001A32
00122C00092300031B00021900051E000E28001E35002F3F00344200293C001730000822
00031A00031B000C2600223800424900534C00514D003744001830000620000219000720
001D3400494C005F4400663D005C46003C4600142D00041C00031B00112B003D46006241
00742A00732C006043003542000D27000219000720002338005949007528008014007627
005A4800253900072000021A000E28003D4600673B007E19008014006E33004E4E00152E
00031B00041C00183100504E006C35007A1F007429005D46002D3E000A24000219000721
00233800534C00683B006D3500604300414800152E00041D00031A000C2600283B004F4E
005B48005849004349001D3400082200021900041D000F2A00253A003C46004249003442
001D34000B2500031B00021A00062000102A001D3400253900213700162F000B2500041C
00021900031B000821000E2800122C00112B000D27000721
000A24000C26000A2500072100041C00021900031A00061F000D2800162F001C34001B33
00132C00092300031C00021900051E000F29002036003141003743002B3D001831000923
00031A00031B000C2700243900464B00554B00534C003A45001931000620000219000721
001E35004E4E00624100693A005F4400404800142E00041C00031B00122C00414800653D
007724007626006241003744000D2700021900072000263A005C4700782200840C007921
005D4600273A00072000021A000F29004148006A3700811100840C00712F00504E00162F
00031B00041D001A3200524D007030007E17007823006043002F3F000A24000219000821
00243900554B006B3700703000634000454A00162F00041D00031A000C26002A3C00514D
005D46005B4800474B001F3600092300021900041D00102A00273B003F4800464B003744
001F35000C2600031B00021900062000112B001F3500273A002338001730000B2500041D
00021900031B000822000E2800132C00122C000D28000821
000A25000C26000B2500072100041C00021900031A000620000E28001830001E35001C34
00132D00092400041C00021900051E00102A002237003442003A45002E3F001931000923
00031A00031B000D2700263A004B4D00574A00554B003E47001A32000720000219000821
00203600504D00653E006C3600614200434900152E00041C00031B00132C00454A00693A
007B1E007A2000653E003A45000D2800021900072100283B005F44007C1B008803007D1B
005F4400283B00072000021A00102A00454A006E3300860800880300742A00524D001730
00031B00041D001B3300554B00732B008210007B1D006241003241000B25000219000822
00263A00584A006E3300732B00663D00494C00173000041D00031A000D27002C3D00534C
006043005D46004C4D00213700092300021900041D00112B00293C004349004B4D003B45
002037000C2700031C00021900072000122B00203600293C002539001831000C2600041D
00021900031B000822000F2900132D00132D000E28000822
000B25000D27000B2500082100041C00021900031A000720000F29001931001F36001E35
00142E000A2400041C00021900051F00102A002439003744003D47003040001A32000923
00031A00031B000E2800283C004F4E005A4800574A004148001B33000720000219000822
00223800534C00683A006F3200644000474B00162F00041C00031B00142D004A4C006C36
007F17007D1A00673B003D46000E28000219000821002B3D006142008014068C00008014
006142002A3C00072100021A00102B004A4C00712E008A00068C0000772500544C001730
00031B00041D001D3400574A007725008607007F1600653E003442000B25000219000822
00293C005A4800712E007625006939004E4E00193100051D00031A000D27002E3F00564B
006241006043004F4E002338000A2400021A00041D00112B002B3D00474B004F4E003F47
002238000D2700041C00021900072000122C002137002B3D00273B001A32000C2700051D
00021900031B000822000F2900142E00142D000F29000822
000B25000D27000C2600082200041D00021900031A000720000F29001A32002137001F36
00152E000A2400041C00021900061F00112B00263A003A45004148003341001B33000A24
00031A00031B000E28002B3D00514D005C4700594800444A001C34000720000219000822
00243900554B006B3700722D00663D004A4C00173000041C00031B00152E004E4E006F31
00820F008013006A38004048000E28000219000822002E3F00643F00840C10900000840D
006440002C3D00072100021A00112B004E4E0074290A8E00109000007A1F00554B001831
00031B00051D001F35005948007A1F018A0000830E00673B003743000B26000219000923
002B3D005D46007429007A20006C3600504E001A3200051D00031A000E2800304000584A
00653E00624100514D002539000A2400021A00041D00122C002D3E004A4D00514D004249
002439000E2800041C00021900072000132C002338002D3E00293C001B33000D2700051D
00021900031B00082200102A00152E00152E000F2A000923
000C26000E28000C2600082200041D00021900031A00072100102A001B33002338002137
00162F000A2500041C00021900061F00122C00283B003E4700444A003543001C34000A24
00031A00031C000F29002D3E00534C005E45005C4700484B001D34000721000219000922
00263A00574A006E3300752800693A004E4E00173000041C00031B00162F00514D00722D
00860700840C006C35004249000E2900021900082200314000673B0088031B9400008705
00663D002D3E00072100021A00122C00514D0078231592001A9400007D1900574A001931
00031B00051E002137005C47007E190A8E00008607006A38003A45000C26000219000923
002D3E005F44007724007D19006F3200524D001B3300051E00031A000E28003341005A48
00673B00653E00534C00273B000A2500021A00041D00122C002F3F004E4E00534D00464B
00273A000E2900041C00021900072000132D002439002F3F002C3D001D34000E2800051E
00021900031B00082200102A00162F00162F00102A000923
000C26000E28000D2700082200041D00021900031A00072100102B001C34002439002238
001730000B2500041C00021900061F00132C002A3C00414800484B003844001E35000A24
00031A00041C00102A00304000554B006142005E45004B4D001E35000721000219000923
00283B005A4800712E007823006B37004F4E00183100041C00031C00183000534C007527
018A00008704006F3100454A000F29000219000923003442006A37058C00269800028A00
00683A002F3F00072100021A00142D00534C007B1D209600269800008013005949001A32
00031B00051E002238005E44008111159200018A00006D35003C46000C26000219000923
003040006142007B1E00811300722D00544C001C3400051E00031A000F29003543005C47
006A3800673B00554B00293C000B2500021A00041D00132D00314100504E00554C004A4D
00293C000F2900041C00021900072100142D00263A003241002E3F001E35000E2900051E
00021900031B00092300112B00173000173000112B000924
000D27000F29000D2700092300041D00021900031B00072100112B001E3500263A002439
001831000B2500041C00021900061F00142D002C3E00444A004C4D003B45001F36000A24
00031A00041C00102A00324100574A006340006043004F4E002036000721000219000923
002B3D005C4700742A007B1E006E3300514D00193100041C00041C00193100554B007922
0A8E00038B0000712E00484B000F29000219000923003744006D330F9000329C000B8E00
006A3800314000072100031A00152E00554B007F162C9A00329C0000840C005B47001B33
00031B00051E00253900614200850A1F9600098D00006F31003F47000C27000219000A24
00324100643F007E1800840B00742900564B001D3500051E00031A000F29003844005E45
006D34006A3800584A002B3D000B2600021A00041D00132D00344200524D00564A004E4E
002B3D00102A00041C00021900072100152E00283B003442003040002036000F2900051E
00021900031B00092300112B00183100183100122C000A24
000D27000F29000D2800092300041D00021900031B00082100122C001F3600283B00253A
001931000B2600041C00021900062000142E002E3F00484C004F4E003E47002036000B25
00031A00041C00112B00354200594900653D00624100504E002137000721000219000A24
002D3E005E45007725007E1800703000524D001A3200041C00041C001A3200574A007C1C
1391000C8E0000742A004B4D000F29000219000A24003B4500712F1A94003FA100139100
006C3500324100072100031A00162F00584A00830E399F003EA000008706005D46001B33
00031B00051E00273A0064400088022B9A0012910000722D004249000D27000219000A24
00354200663C00811200870400772400584A001F3500051E00031A00102A003B45006043
006F31006D34005A48002E3E000C2600021A00051D00142E00364300534C00584900504E
002D3E00112B00041D00021900072100152F00293C00364300334100223700102A00051E
00021900031B00092300122C00193100193100122C000A24
000D2800102A000E2800092300041D00021900031B00082200132C002137002A3C00273B
001A32000C2600041C00021900072000152F003040004C4D00504D004048002137000B25
00031A00041C00122C003844005B4700683B00643F00524D002237000721000219000A24
003040006142007A1F00811100732C00544C001A3200041C00041C001C34005A48007F15
1E9500149200007626004D4E000F2A000219000A24003F4700742A2598004CA5001D9500
006F3200344200072100031A001730005A4800860647A3004BA400008A00005E45001C34
00031B00061F00293C00663D068C00379E001C950000742900454A000D27000219000A25
00384400693900840B038B00007A1F00594800203600051E00031A00102A003D47006241
00722D006F31005C47003040000C2700021A00051D00152E00384400554B005A4800524D
00304000112B00041D00021900072100162F002B3D00394400354300233800112B00061F
00021900031B00092300122C001A32001A3200132D000B25
000E2800102A000E2900092300041D00021900031B00082200132D002238002C3D00293C
001B33000C2600041C00021900072000162F003341004F4E00524D004349002338000B25
00031A00041C00132C003B45005D45006A3800673C00534C002338000821000219000B25
003241006340007D1900840B00752800554B001B3300041C00041C001E35005C4600830E
2899001E9500007922004F4E00102A000219000B25004249007725319C005AA900269800
00712F00354300072100031A001931005C46018A0055A70059A800088D00006043001D34
00031B00061F002B3D0069390F900043A20026980000772500474B000D27000219000B25
003B45006C360088030B8E00007D1A005B4700213700051E00031A00112B00404800653E
00752800722D005E45003241000D2700021A00051D00152F003B4500574A005C4600544C
00324100122C00041D000219000721001730002D3E003C4600384400253A00112B00061F
00021900031B00092300132D001B33001B3300142E000B25
000E2900112B000F29000A2400051D00021900031B00082200142E002439002E3E002A3D
001C33000C2700041C00021900072000173000354200504D00544C00464B002439000B26
00031A00041C00142D003E47005F44006D3500693A00554B002439000821000219000B25
00354300653D00801300870400772400574A001B3300041C00041D001F36005E44008607
349D00279900007B1D00504E00102A000219000B2600474B007A1F3EA00069AD00309C00
00732C00374300072100031A001A32005F440A8E0064AC0067AD000F9000006242001E35
00031B00061F002E3F006C3619940051A600309C00007921004A4C000D28000219000B26
003E47006E33038B00149200008014005D4600223800051E00031A00112B00434900673C
007724007529006043003442000D2700021A00051D00162F003D46005949005E4400564B
00354200132D00051D000219000721001730002E3F003E47003A4500273B00122C00061F
00021900031B00092300132D001C33001C3400152E000C26
000F2900112B000F2A000A2400051D00021900031B00092300152E002539003040002C3E
001D34000D2700041C00021900072100183100384400524D00554B00494C00253A000C26
00031A00041C00142E004148006142006F31006B3700564B00253A000821000219000C26
00384400683B00830D028A00007A20005849001C3400041C00041D002137006142008A00
3FA100319C00007D1900514D00102A000219000C26004B4D007D194BA40078B1003A9F00
00752800384400072100031B001C3300614213910073B00075B100179300006340001E35
00031B000620003040006E322397005EAA003B9F00007C1C004D4E000E28000219000C26
00414800712F0C8E001D950000830E005F4400243900051F00031A00122C00464B006939
007A1F007724006241003743000E2800021A00051E001730003F48005A4800604300574A
00374400142D00051D000219000821001831003040004148003D4600293C00132D000620
00021900031B000A2400142D001D34001D3400162F000C26
000F2A00122C00102A000A2400051D00021900031B00092300162F00273A003241002E3F
001E35000D2700041C000219000721001932003A4500544C00574A004C4D00263A000C26
00031A00041D00152F00444A00643F00712E006D3400584A00263A000822000219000C26
003B45006A38008606098D00007C1B005A48001D3400041C00041D002338006340088D00
4BA4003B9F0000801500524D00102A000219000D27004F4E00811358A80087B50044A200
00772500394500072100031B001D3400643F1D950083B40084B4001F960000653E001F35
00031B00072000334100712E2E9B006CAE0046A300007E18004F4E000E28000219000C27
00444A00732B14920027980000850800614200253900061F00031A00132C00494C006B36
007D1A007A2000643F003945000E2800021A00051E001830004249005C46006241005949
003A4500152E00051E000219000821001931003241004349004048002B3D00142D000620
00021900031B000A2400142E001E35001E35001730000D27
00102A00132C00102A000A2500051E00021900031B00092300162F00283B003442003040
001F36000E2800041C000219000821001A32003D4600554B005949004F4E00283B000C26
00031A00041D00162F00474B00663D00742A006F3100594900273B000822000219000D27
003E47006D34008900119000007F17005B47001D3400041C00051D00253900663D119000
58A80046A30000821000534C00102A000219000D2800514D00840C66AC0097BA004FA600
007922003B4500072100031B001F3600663D28990093B90093B80027990000663D001F36
00031B00072000364300742A399F007BB20051A60000801300504E000E28000219000D27
00474B0076271D9500309C0000880200634100263A00061F00031A00132D004D4E006D33
007F15007C1B00663D003C46000F2900031A00051E00183100444A005E4500643F005B47
003C4600152F00051E00021900082200193200344200464B004349002C3E00152E000720
00021900031B000A2400152E001F35002036001830000D27
00102A00132D00112B000B2500051E00021900031B000923001730002A3C003643003141
002036000E2800041C000219000822001B33003F4700574A005A4800504E00293C000C27
00031A00041D001730004B4D00683B00762600712E005B4800283B000822000219000D28
004148006F31078C00199300008112005C46001E3500041C00051E00273A00683A1A9400
65AC0050A60000840B00544C00102B000219000E2800534D00870575B000A7BE0059A900
007A1E003C4600072100031B00213700693A329D00A4BD00A2BC002F9B0000683B002036
00031B00072100394400762644A20089B6005CAA0000830F00514D000E29000219000D28
004B4D0078222698003A9F00038B0000643F00273B00061F00031A00142E004F4E007030
008210007F1600683B003E47000F2900031A00051E00193100474B00604300663D005D46
003F4700162F00051E000219000822001A3200354300494C00454A002E3F00152F000720
00021900031B000A2400162F002036002137001831000D28
00112B00142D00112B000B2500051E00021900031B000A24001831002B3D003844003342
002137000E2800041D000219000822001C34004249005849005C4700514D002A3D000D27
00031A00041D001831004E4E006A3800782200732B005C4700293C000822000219000E28
00444A00722D0E8F0021960000830D005D45001E3500041C00051E00293C006A38239700
72B0005BA90000860700554B00112B000219000F2900544C028A0084B400B8C10064AC00
007C1B003D4700072100031B002238006B363EA000B6C100B2C000379E00006939002037
00031B000721003B4600792150A60099BA0068AD0000850A00524D000F29000219000E28
004E4E007B1E2F9B0045A2000A8E0000663D00293C00061F00031B00152E00504E00722D
00850A008111006A3800404800102A00031A00051E001A32004A4C00614200683A005E45
00424900173000051E000219000822001B33003744004C4D00484C00304000162F000721
00021900031B000A2400162F002137002237001932000E28
00112B00142E00122C000B2500051E00021900031B000A24001931002D3E003A45003542
002238000E2900041D000219000822001D3400444A005A48005D4500524D002C3D000D27
00031A00051D00193100504E006C36007B1E007528005D46002A3D000822000219000E29
00484B00742A169200299900008509005F44001F3500041C00051E002B3D006D342D9B00
7FB30066AC0000880200564B00112B00021900102A00564A098D0093B800C5C2006FAF00
007E18003E4700072100031B002439006E3349A400C5C300C2C40040A100006A38002137
00031B000821003E47007C1C5CAA00A8BE0074B00000870500534C000F29000219000E29
00504E007D19399F004FA60010900000683B002A3C00061F00031B00162F00524D00742A
00870400840C006C3600434900102A00031A00051E001A32004C4D006340006A38006043
00444A00183100051E000219000822001B33003944004E4E004B4D003241001730000721
00021A00031B000A24001730002237002338001A32000E29
00122C00152E00122C000B2600051E00021900031B000A24001A32002E3F003C46003743
002338000F2900041D000219000822001E3500474B005B47005F4400544C002D3E000D27
00031A00051D001A3200514D006E33007D1A007724005F44002B3D000822000219000F29
004B4D0076261D9500319C00008704006043001F3600041C00051E002D3E006F31369E00
8CB70071AF00028A0000574A00112B00021900102A005849119100A2BC00C9B9007AB200
008014003F4800072100031C00263A00702F55A700C9B900C8BD0048A300006C36002137
00031B000822004249007E1769AD00B8C1007FB30000890000544C000F29000219000F29
00514D00801442A20059A900179300006939002B3D00061F00031B00162F00534C007626
008A00008607006E3300454A00102A00031A00051E001B33004F4E00643E006C36006241
00474B00193100051F000219000822001C34003B45004F4E004E4E003442001831000821
00021A00031B000A25001730002338002439001B33000F29
00122C00162F00132C000C2600051E00021900031B000A25001A32003040003E47003944
002439000F2900041D000219000923001F36004A4C005D4600604300554B002E3F000D27
00031A00051E001B3300524D007030007F16007921006043002C3E00082200021900102A
004E4E007922259800399F0000890000614200203600041C00061F002F3F00712E40A100
9ABA007CB200078C0000584A00112B00021900112B005A481A9400B2C000CDAF0084B500
00811100404800072100041C00283B00732C61AB00CDAF00CBB40050A600006D34002237
00031B00082200454A00811275B100C5C3008BB700048B0000554B000F2900021900102A
00534C00820F4CA50064AC001E9500006B37002C3E00061F00031B00173000544C007823
068C00008901006F3100484B00112B00031A00051E001C3300504E00663D006E33006340
004A4C001A3200061F000219000822001D34003C4600514D004F4E003643001931000822
00021A00031B000B2500183000243900253A001C34000F2A
00132D00162F00132D000C2600051E00021900031B000B25001B33003141004048003A45
002539000F2A00041D000219000923002037004C4D005E4500624100564B002F3F000D28
00031A00051E001C3400544C00722D008111007B1E006142002D3E00082200021900102A
00504E007B1E2D9B0041A100058C0000624100203600041C00061F00314100742A4AA400
A8BE0087B5000B8E0000584900112B00021900122C005C46229700C2C400D1A6008FB700
00830E00414900072100041C002A3D0075286DAE00D1A500CFAB0058A800006E32002238
00031B00092300484B00840C82B400C9BA0097BA00098D0000564B000F2900021900102A
00544C00850A56A8006FAF00249800006C35002D3E00061F00031B00183000564B007A1F
0C8F00038B0000712E004A4C00112B00031A00051E001D3400514D00683B006F3100653E
004C4D001B3200061F000219000822001D34003E4700524D00504D003844001A32000822
00021A00031B000B2500183100253900263A001D3400102A
00132D00173000142D000C2600051E00021900031B000B25001C34003341004249003C46
00263A00102A00041D000219000923002137004F4E00604300634000574A003040000E28
00031A00051E001D3400554B00742A00830D007D1A006241002E3F00082200021900112B
00514D007D19359D004AA400098D0000634000203600041C00061F00344200762654A700
B6C10092B80010900000594900112B00021900132D005E452B9A00C7BD00D49C009ABA00
00840B00424900072100041C002C3E0077247AB200D59A00D2A20060AB00006F31002238
00031B000923004B4D0086078FB700CCB100A3BC000D8F0000564A000F2900021900112B
00564B00870460AB0079B2002B9A00006E33002E3F00061F00031B00183100574A007C1B
129100088D0000732B004C4D00122C00031A00051E001D3500524D00693900712E00663C
004E4E001B3300061F000219000822001E3500404800534C00514D003A45001B33000822
00021A00031B000B2500193100253A00283B001E3500102A
00142D00173000142E000C2700051E00021900031B000B25001D3400344200444A003E47
00273B00102A00041D00021900092300233800504E00614200653E005849003140000E28
00031A00051E001E3500564A007627008509007E17006340002F3F00082200021A00122B
00524D007F153DA00052A6000E8F0000643F00213700031C0006200036430078225FAA00
C3C4009CBB00149200005A4800112B00021900142D006043339D00CBB400D79200A4BD00
00860800434900072000041C002E3F007A2086B500D88F00D5990068AD0000702F002338
00031B000923004E4E0089019CBB00D0A800AFBF0012910000574A000F2900021900112B
00574A008A006AAE0084B500329C00006F31002F3F00061F00031B001932005849007E18
1893000E8F00007529004E4E00122C00031A00051E001E3500534C006B3700732C00683B
00504E001C3400061F000219000922001F3500424900544C00534D003C46001B33000822
00021A00031B000B2500193100263A00293C001F3500112B
00142E00183100152E000D2700051E00021900031C000B26001E3500364300454A003F48
00283B00102A00041D00021A000A2400243900514D00624100663D005949003241000E28
00031A00051E001F3600584A00772400870400801400643F00304000082200021A00122C
00544C00821145A3005AA90013910000653E00213700031C000620003844007A1F69AD00
C7BE00A7BD00199300005A4800112B00021900152E0062413CA000CFAB00DB8800AFBF00
00870400444A00072000041D003040007C1B93B800DC8400D88F0070AF0000712E002338
00031B000A2400504E048B00A8BE00D39F00BAC200179300005849000F2A00021900122C
005949058C0074B0008FB700389F0000702F00304000061F00031B001A32005A48008014
1E9500139100007626004F4E00122C00031A00051F001F3500544C006C35007429006939
00514D001D3400061F000219000923001F3600434900554B00544C003D47001C34000923
00021A00031B000B25001A3200273B002A3C00203600112B
00152E00183100152E000D2700051E00021900031C000C26001E3500374400474B004148
00293C00112B00041D00021A000A2400253900524D00643F00673C005A48003342000E28
00021A00051E00203600594900792100890000821000653D00314000082200021A00132D
00554B00840C4DA50062AB0017930000663D00213700031B000720003A45007D1B73B000
CAB600B1C0001D9500005B4700112B00021900152F00634045A200D2A200DE7E00B9C200
00880100454A00072000041D003241007E179FBB00DF7900DB860078B10000722C002338
00031A000A2400514D0A8E00B5C100D69600C5C4001B940000594900102A00021900132C
005A480B8E007EB30099BA003FA10000722D00314000062000031B001B33005B48008210
24980019930000782300504E00132D00031A00061F00203600554B006D33007627006B37
00524D001E3500061F00021900092300203600454A00564B00554B003F48001D34000923
00021A00031B000B25001A3200283B002B3D00203700122C
00152E00193100152F000D2700051E00021900041C000C26001F3600394400494C004349
002A3C00112B00041D00021A000A2400263A00534C00653E00683A005B47003442000E28
00021A00061F002137005A48007B1E038B0000830D00663C00314000082200021A00132D
00564A00860855A7006AAD001C950000673C00223700031B000720003D46007F177DB300
CDAF00BCC200219600005C4700112B00021900162F00653E4DA500D59900E17400C2C400
008A0000454A00072000041D003442008013ABBE00E36E00DE7D007FB30000732B002338
00031A000B2500524D0F9000C2C400D98D00C7BE0020960000594800102A00021900132D
005B4710900088B600A3BD0045A30000732B00324100062000031B001B33005C4700840C
2A9A001E950000792100514D00132D00031A00061F00203600564B006F31007724006C35
00534D001E3500062000021900092300203700474B00574A00564B004148001E35000923
00021A00031B000B26001B3300293C002C3D00213700122C
00162F00193200162F000D2700051F00021900041C000C26002036003A45004B4D00444A
002A3D00112B00041D00021A000A2400263A00544C00663D006A39005C47003543000E29
00021A00061F002237005B47007C1B078D0000850A00673B00324100082200021A00142E
00584A0087045DAA0072B00020960000673B00223700031B000721003F4700801387B500
D0A700C5C400259800005C4600112B00021900173000673C56A800D89000E46A00C6C000
038B0000464B00072000051D00364300830FB7C100E66400E1740086B500007429002439
00031A000B2500544C159200C7BF00DC8400CAB800249700005A4800102A00021900142D
005C4615920091B800ADBF004BA50000742900334100062000031B001C34005D46008509
2F9B00239700007B1E00524D00132D00031A00061F00213700574A007030007922006D33
00534C001F3600062000021900092300213700484C00584A00574A004349001F35000923
00021A00031B000B26001B33002A3C002D3E00223800132C
00162F001A3200162F000D2800051F00021900041C000C27002137003B46004D4E00464A
002B3D00112B00041D00021A000A2400273B00554C00673B006B37005D46003643000E29
00021A00061F002338005C46007E180B8E0000860700683A00334100082200021A00152E
00594900890064AC0079B20024980000683A00223800031B00072100414800820F91B800
D2A000C7BF00299900005D4600112B00021900183100683A5EAA00DB8700E76000C8BB00
068C0000474B00072000051D00384400850AC3C400E95900E46B008DB700007528002439
00031A000B2500554B1B9400C9B900DF7B00CCB200289900005B4800102A00021900142E
005E451B94009BBA00B7C10051A60000752800334200062000031B001D34005E45008705
359D00289900007C1C00534D00142D00031A00061F00223700574A00712E007A1F006F32
00544C002036000620000219000923002237004A4C00594900574A00444A001F36000923
00021A00031B000C26001B33002B3D002E3F00233800132D
00162F001A32001730000E2800061F00021900041C000D27002137003D46004E4E00474B
002C3E00122B00041D00021A000B2500283B00554B00683A006C36005E45003744000F29
00021A00061F002439005D45007F150F900000870400693900334100082200021A00152F
005A48038B006BAE0080B40028990000693900223800031B00082100434900840B9ABA00
D59900C9BA002D9B00005D4600112B000219001931006A3866AC00DE7E00E95700CAB700
088D0000474B00072000051E003A45008606C7BF00EC4F00E6620094B900007627002439
00031A000C2600564B209600CCB200E17300CEAC002C9A00005B4700102A00021900152E
005F44209600A4BD00C0C30057A80000762600344200062000031B001D34005F44008802
3A9F002D9B00007D1A00534C00142E00031A00061F00223800584900722C007B1D007030
00554B002037000720000219000923002238004B4D00594800584900464B002036000A24
00021A00031B000C26001C33002B3D002F3F00233800132D
001730001B33001730000E2800061F00021900041C000D27002237003E47004F4E00484C
002D3E00122C00041D00021A000B2500293C00564B006939006D35005E45003844000F29
00021A00061F002439005E44008113139100008901006A3800344200082200021A00162F
005B47078D0072B00087B5002C9A00006A3900223800031B00082200454A008608A3BC00
D79200CBB500309C00005E4500112B000219001A32006B366EAF00E07600EC4E00CCB200
0B8E0000484B00062000051E003C46008802C9B900EE4500E95A009ABA00007626002439
00031A000C2600574A259800CEAC00E46B00D0A700309C00005C4700102A00021900152F
006043249800ACBF00C5C2005DAA0000772400354200062000031B001E35006043018A00
40A100319C00007E1700544C00142E00031A00061F00233800594900742A007D1B00712E
00564B002137000720000219000923002338004C4D005A4800594900474B002137000A24
00021A00031B000C26001C34002C3E002F3F00243900142D
001730001B33001730000E2800061F00021900041C000D27002238003F4700504E004A4C
002D3E00122C00041D00021A000B25002A3C00574A006A38006E33005F44003944000F29
00021A00061F00253A005F44008210179300018A00006B3700344200082200021A00162F
005C470B8E0079B2008EB7002F9C00006A3800233800031B00082200474B008704ABBF00
D98C00CDB000339D00005E4500112B000219001A32006D3576B100E36E00EE4600CEAD00
0D8F0000484C00062000051E003E47018A00CCB300F13B00EB5200A0BC00007724002439
00031A000C260058492A9A00D1A600E66300D2A200339D00005C4600102A00021900162F
006142299900B5C100C7BD0062AB0000782300364300062000031B001F35006142048B00
44A200369E00007F1500554C00152E00031A00061F002338005A48007529007E1800722D
00574A002237000720000219000923002338004E4E005B47005A4800494C002137000A24
00021A00031B000C26001D34002D3E00304000253900142E
001730001C33001830000E2800061F00021900041C000D2700233800404800504E004B4D
002E3F00122C00041D00021A000B25002B3D00584A006B37006E32006043003A45000F29
00021A00061F00263A00604300830E1A9400038B00006B3600354200082200021A001730
005D460F90007FB30094B900339D00006B3700233800031B00082200494C008901B4C000
DC8600CEAC00379E00005E4500112B000219001B33006E337DB300E56600F03E00CFA900
0F900000484C00062000051E004048058B00CEAD00F33200ED4B00A5BD00007823002439
00031A000D270059492F9B00D3A000E85B00D49D00379E00005D4600102A00021900162F
0062412E9B00BDC300C9B90067AD0000792100364300062000031B001F36006241078C00
49A4003A9F0000801300554B00152E00031A00061F002439005A48007627007F1600732B
00574A002238000720000219000923002338004E4E005C47005B48004A4C002237000A24
00031A00031B000C26001D34002D3E00314000253A00142E
001830001C34001831000E2800061F00021900041C000D2800233800414800514D004C4D
002F3F00122C00041D00021A000B25002B3D005849006C36006F31006043003A45000F29
00021A00062000273A00614200840B1D9500068C00006C3500354300082200031A001730
005E4512910085B50099BA00369E00006B3600233800031B000822004A4D028A00BBC200
DD8000D0A800399F00005F4400112B000219001C33006F3184B500E75F00F23600D1A500
11900000494C00062000051E004148088D00D0A800F52A00EF4400AABE00007822002539
00031A000D27005A48349D00D59A00EA5400D598003A9F00005D4600102A000219001730
006340329C00C4C400CBB5006BAE00007A2000374300062000031B0020360063410A8E00
4DA5003EA00000811100564B00152E00031A00061F002439005B4700762600801400742A
005849002338000720000219000923002439004F4E005C46005B47004B4D002238000A24
00031A00031B000C26001D34002E3F00324100263A00152E
001831001C34001831000E2800061F00021900041C000D2800243900424900514D004D4E
002F3F00122C00041D00021A000B26002C3E005949006D35007030006142003B45000F29
00021A00062000273B006241008509209600088D00006D3500364300082200031A001830
005E441592008AB6009FBB00399F00006C3600233800031B000822004C4D058B00C2C400
DF7A00D1A4003CA000005F4400112B000219001C340070308AB600E95800F42F00D2A200
13910000494C00062000051E0043490B8E00D2A300F72200F03E00AFBF00007921002539
00031A000D27005B48389E00D69500EC4E00D794003CA000005D4500102A000219001730
00643F359E00C6C100CCB10070AF00007A1F00374400062000031B0020360063400C8F00
51A60041A10000820F00564B00152F00031A00061F002539005C47007724008113007429
005849002338000720000219000923002439004F4E005D46005C47004C4D002338000A24
00031A00031B000C26001D35002F3F00324100263A00152E
001831001D34001831000E2900061F00021900041C000E2800243900434900524D004E4E
00304000132C00041D00021A000B26002D3E005948006D3400712F006142003B46000F29
00021A00062000283B0062410086072397000A8E00006D3400364300082200031A001831
005F441893008FB700A3BD003B9F00006C3500233800031B000923004D4E078D00C5C200
E17500D2A0003EA000005F4400112B000219001D3400712E90B800EB5200F62900D39E00
14920000494C00062000051F00444A0E8F00D39E00F91B00F23800B3C000007921002539
00031A000D28005B473CA000D89000EE4800D890003FA100005E4500102A000219001830
00643F399F00C7BE00CEAD0073B000007B1D00384400062000031C00213700643F0F9000
55A70044A20000830E00574A00152F00031A00061F00253A005C46007823008111007528
00594900243900072100021900092400253900504E005D45005C46004D4E002338000A25
00031A00031B000C26001E35002F3F00334100273B00152E
001931001D34001931000E2900061F00021900041C000E2800253900444A00524D004E4E
00304000132C00041D00021A000C26002D3E005A48006E3300712E006241003C46000F29
00021A00062000283B0063400087052598000C8E00006E3300364300082200031A001931
0060431A940094B900A8BE003EA000006C3500233800031B000923004E4E0A8E00C7BF00
E27100D49D0041A100005F4400102B000219001D3500722D95B900EC4C00F72300D49B00
169200004A4C00062000061F00454A119000D59A00FB1400F33200B7C100007A20002539
00031A000E28005C463FA100D98C00EF4200D98C0041A100005E4500102A000219001831
00653E3CA000C8BB00CFAA0077B100007C1C00384400062000031C00213700643F119000
58A80047A30000840C00574A00162F00031A00061F00263A005D46007922008210007627
005948002439000721000219000A2400253900504E005E45005D46004E4E002439000B25
00031A00031B000C26001E3500304000344200273B00152F
001931001D34001931000F2900061F00021900041C000E2800253900444A00524D004F4E
00304000132D00041D00021A000C26002E3E005A48006E3200722D006241003C46000F29
00021A00062000293C0063400087042799000D8F00006E3300374300082200031A001931
0060431D950097BA00ABBF0040A100006D3400233800031B000923004F4E0C8E00C8BC00
E36D00D59A0042A20000604300102B000219001E3500732C99BA00EE4700F81E00D59900
179300004A4C00062000061F00464B139100D69700FC0F00F42E00BBC200007A1F002539
00031A000E28005D4642A200DB8800F03E00DA890043A200005E4500102A000219001831
00663D3FA100C9B800D0A7007AB200007C1B00384400062000031C00213700653E139100
5BA9004AA40000840B00574A00162F00031A00061F00263A005D4600792100830E007626
005A48002439000721000219000A2400253A00504D005E45005D46004F4E002439000B25
00031A00031B000C26001E3500304000344200283B00162F
001931001D34001931000F2900061F00021900041C000E2800253A00454A00534D004F4E
00314000132D00041D00021A000C26002E3F005B48006F3200722D006341003D46000F29
00021A00072000293C00643F0088022999000F9000006E3200374300082200031A001931
0061421F96009BBA00AFBF0042A100006D3400233800031B000923004F4E0D8F00C9BA00
E46A00D5980044A20000604300102B000219001E3500732B9DBB00EF4300F91A00D69600
189300004A4D00061F00061F00474B159200D79400FD0A00F52A00BDC300007A1F002539
00031A000E28005D4645A200DC8500F13A00DB870045A300005F4400102A000219001931
00663D41A100CAB600D1A5007CB300007C1B00394400062000041C00223700653E149200
5EAA004CA50000850A00584A00162F00031A00061F00263A005D45007A2000830D007725
005A48002539000721000219000A2400253A00514D005E44005D45004F4E002439000B25
00031A00031B000C27001E3500304000344200283B00162F
001931001E35001931000F2900061F00021900041C000E2800263A00454A00534C004F4E
00314000132D00041D00021A000C26002E3F005B47006F3100722C006340003D46000F29
00021A000720002A3C00643F0089012A9A00109000006F3200374400082200031A001932
0061422096009DBB00B1C00043A200006D3400233800031B00092300504E0F9000C9B800
E56700D6960045A30000604300102B000219001F3500742AA0BC00F04000FA1600D79500
199300004A4D00061F00061F00484B179300D89100FE0600F62700C0C300007B1E002539
00031A000E28005D4547A300DC8300F23600DC850046A300005F4400102A000219001931
00663C43A200CBB400D1A3007EB300007D1A00394400062000041C00223700663D169200
60AB004EA50000850900584A00162F00031A00062000263A005E45007A1F00840C007724
005A48002539000721000219000A2400263A00514D005F44005E45004F4E002439000B25
00031A00031B000C27001E3500314000354200283B00162F
001931001E35001931000F2900061F00021900041C000E2800263A00464A00534C004F4E
00314000132D00041D00021A000C26002E3F005B47006F3100732C006340003D46000F2A
00021A000720002A3C00643E0089012B9A00109000006F3200374400082200031A001932
0061422197009FBC00B3C00044A200006E3300243900031B00092300504E109000CAB700
E56500D7950046A30000604300102B000219001F3500742AA2BC00F03D00FB1400D79300
1A9400004B4D00061F00061F00484C189300D88F00FF0300F72400C2C400007B1E002539
00031A000E28005E4548A400DD8100F33400DC830048A300005F4400102A000219001931
00673C44A200CCB300D2A20080B400007D1A00394500062000041C00223800663D179300
61AB004FA60000850800584900162F00031A00062000273A005E45007A1F00840C007724
005B48002539000721000219000A2400263A00514D005F44005E45004F4E002539000B25
00031A00031B000C27001F3500314000354200283B00162F
001932001E35001932000F2900061F00021900041C000E2800263A00464B00534C004F4E
00314100132D00041D00021A000C26002F3F005B4700703000732B006340003D47000F2A
00021A000720002A3C00653E0089002C9A00119100006F3100374400082200031A001932
006142229700A1BC00B5C10045A300006E3300243900031B00092300504E119000CAB600
E66300D7940047A30000604300112B000219001F35007429A3BD00F13C00FB1200D79200
1A9400004B4D00061F00061F00484C199300D98E00FF0100F72200C3C400007B1E00253A
00031A000E28005E4549A400DD7F00F33200DD820048A400005F4400102A000219001931
00673C45A300CCB200D2A00081B400007D1900394500062000041C00223800663D179300
62AB0050A60000860800584900162F00031A00062000273A005E45007A1F00840B007823
005B47002539000721000219000A2400263A00514D005F44005E45004F4E002539000B25
00031A00031B000C27001F3500314000354200293C00162F
001932001E35001932000F2900061F00021900041C000E2800263A00464B00534C004F4E
00314100132D00041D00021A000C26002F3F005B4700703000732B006340003D47000F2A
00021A000720002A3C00653E0089002D9B00119100006F3100384400082200031A001A32
006242229700A1BC00B5C10046A300006E3300243900031B00092300504E119100CBB500
E66200D7930048A30000604300112B000219001F36007429A4BD00F13B00FC1000D89100
1B9400004B4D00061F00061F00494C199400D98D00FF0000F72100C4C400007B1D00253A
00031A000E28005E454AA400DE7F00F43100DD810049A400005F4400102A000219001931
00673C46A300CCB100D3A00082B400007D1900394500062000041C00223800663D189300
63AB0051A60000860700584900162F00031A00062000273A005E45007B1E00840B007823
005B47002539000721000219000A2400263A00514D005F44005E45004F4E002539000B25
00031A00031B000C27001F3500314000354200293C00162F
001932001E35001932000F2900061F00021900041C000E2800263A00464B00534C004F4E
00324100132D00041D00021A000C26002F3F005B4700703000732B006340003D47000F2A
00021A000720002A3C00653E0089002D9B00129100006F3100384400082200031A001A32
006242229700A1BC00B6C10046A300006E3300243900031B00092300504E119100CBB500
E66200D7930048A30000604300112B000219001F35007429A4BD00F13A00FC1000D89100
1B9400004B4D00061F00061F00494C199400D98D00FF0000F72100C4C400007B1D00253A
00031A000E28005E454AA400DE7E00F43100DD810049A400005F4400102A000219001931
00673C46A300CCB100D3A00082B400007D19003A4500062000041C00223800663D189300
63AB0051A60000860700584900162F00031A00062000273A005E45007B1E00840B007823
005B4700253A000721000219000A2400263A00514D005F44005E45004F4E002539000B25
00031A00031B000C27001F3500314000354300293C00162F
001932001E35001932000F2900061F00021900041C000E2800263A00464B00534C004F4E
00314100132D00041D00021A000C26002F3F005B4700703000732B006340003D47000F2A
00021A000720002A3C00653E0089002C9A00119100006F3100384400082200031A001932
006142229700A1BC00B5C10046A300006E3300243900031B00092300504E119000CAB600
E66300D7930048A30000604300112B000219001F35007429A3BD00F13B00FB1100D89100
1B9400004B4D00062000061F00484C199300D98E00FF0000F72200C4C400007B1D00253A
00031A000E28005E4549A400DE7F00F33100DD810049A400005F4400102A000219001931
00673C45A300CCB100D3A00082B400007D19003A4500062000041C00223800663D179300
63AB0050A60000860800584900162F00031A00062000273A005E45007A1E00840B007823
005B47002539000721000219000A2400263A00514D005F44005E45004F4E002539000B25
00031A00031B000C27001F3500314000354200293C00162F
001932001E35001932000F2900061F00021900041C000E2800263A00464A00534C004F4E
00314100132D00041D00021A000C26002E3F005B47006F3100732B006340003D47000F2A
00021A000720002A3C00653E0089002C9A00119000006F3100384400082200031A001932
006142219700A0BC00B4C10045A300006E3300243900031B00092300504E109000CAB700
E66400D7940048A30000604300112B000219001F3500742AA2BC00F03D00FB1200D79200
1B9400004B4D00062000061F00484B189300D88F00FF0200F72300C3C400007B1D00253A
00031A000E28005E4548A400DD8000F33300DD820048A400005F4400102A000219001931
00673C45A200CCB200D2A10081B400007D1900394500062000041C00223800663D179300
62AB0050A60000860800584900162F00031A00062000273A005E45007A1F00840B007824
005B48002539000721000219000A2400263A00514D005F44005E45004F4E002539000B25
00031A00031B000C27001F3500314000354200283C00162F
001931001E35001931000F2900061F00021900041C000E2800263A00454A00534C004F4E
00314000132D00041D00021A000C26002E3F005B47006F3100732C006340003D47000F2A
00021A00072000293C00643F0089012B9A00109000006F3200384400082200031A001931
0061422096009EBB00B2C00044A200006E3300243900031B000923004F4E0F9000CAB800
E56600D6950047A30000604300112B000219001E3500742AA0BC00F03F00FB1400D79300
1A9400004B4D00062000061F00474B179300D89100FE0500F72500C2C400007B1D00253A
00031A000E28005D4547A300DD8200F23500DC830048A300005F4400102A000219001931
00663C43A200CBB400D2A20080B300007D1A00394500062000041C00223700663D169200
60AB004FA50000850800584900162F00031A00062000263A005E45007A1F00840C007724
005A48002539000721000219000A2400263A00514D005F44005E45004F4E002439000B25
00031A00031B000C27001F3500314000354200283B00162F
001931001D35001931000F2900061F00021900041C000E2800253A00454A00534C004F4E
00314000132D00041D00021A000C26002E3F005B47006F3100722C006340003D46000F2A
00021A00072000293C00643F0088022A9A000F9000006F3200374400082200031A001931
0061421F96009CBB00B0C00043A200006E3300243900031B000923004F4E0D8F00C9BA00
E46800D6960046A30000604300112B000219001E3500732B9DBB00EF4200FA1700D79400
1A9400004B4D00062000061F00464B159200D79300FD0800F62800C0C300007B1E00253A
00031A000E28005D4645A200DC8500F23800DC850047A300005F4400102A000219001831
00663D41A100CBB500D1A4007EB300007D1A00394500062000041C00223700653E159200
5FAA004DA50000850900584A00162F00031A00061F00263A005D45007A2000830D007725
005A48002539000721000219000A2400263A00514D005F44005E45004F4E002439000B25
00031A00031B000C27001E3500304000354200283B00162F
001931001D34001931000F2900061F00021900041C000E2800253A00444A00524D004F4E
00314000132D00041D00021A000C26002E3E005A48006F3200722D006241003D46000F2A
00021A00062000293C0064400088032899000E8F00006E3200374400082200031A001931
0060431D950099BA00ADBF0042A200006D3400243900031B000923004F4E0C8E00C8BC00
E46B00D5980045A20000604300112B000219001E3500722C99BA00EE4600F91B00D69600
199300004B4D00062000061F00464A139100D69600FC0D00F52B00BEC300007B1E00253A
00031A000E28005C4642A200DB8800F13C00DB870045A300005F4400102A000219001831
00653D3FA100CAB700D0A6007CB200007D1B00394400062000031C00213700653E139100
5CAA004BA40000850A00574A00162F00031A00061F00263A005D4600792100830E007725
005A48002439000721000219000A2400253A00514D005E45005D45004F4E002439000B25
00031A00031B000C27001E3500304000344200283B00162F
001931001D34001931000F2900061F00021900041C000E2800253900444A00524D004F4E
00304000132D00041D00021A000C26002D3E005A48006E3300712E006241003C46000F2A
00021A00062000283B0063400087052698000D8F00006E3300374300082200031A001831
0060431B940095B900AABE0040A100006D3400243900031B000923004E4E098D00C7BF00
E26F00D49B0043A20000604300112B000219001D3400722D94B900ED4B00F82000D59900
189300004B4D00062000051E00444A109000D59A00FB1200F42F00BBC200007A1E00263A
00031A000D28005C473FA100DA8B00F04000DA8A0044A200005F4400102A000219001831
00653E3CA000C9BA00CFA90079B200007C1B00394400062000031C00213700653E119100
5AA90049A40000840B00574A00162F00031A00061F00263A005D4600792100820F007626
005A48002439000721000219000A2400253A00504E005E45005D46004E4E002439000A25
00031A00031B000C27001E3500304000344200273B00152F
001831001D34001931000E2900061F00021900041C000E2800243900434900524D004E4E
00304000132C00041D00021A000B26002D3E005A48006E3300712E006241003C46000F29
00021A00062000283B0062410086072497000B8E00006E3300374300082200031A001831
005F4418930091B800A6BD003EA000006D3400243900031B000822004D4E078C00C6C200
E17300D39E0042A10000604300112B000219001C3400712F8FB800EB5000F62500D49B00
179300004B4D00062000051E0043490E8F00D39E00FA1800F33400B8C200007A1F00263A
00031A000D27005B473CA000D88F00EE4500D98D0042A100005E4500102A000219001830
00643F399F00C8BD00CEAC0076B100007C1C00384400062000031B00213700643F0F9000
57A80046A30000830D00574A00162F00031A00061F00253A005C46007822008210007527
005949002439000721000219000A2400253900504E005E45005D46004E4E002338000A25
00031A00031B000C26001E35002F3F00334200273B00152E
001831001D34001831000E2900061F00021900041C000D2800243900424900514D004D4E
00304000132C00041D00021A000B26002C3E005949006D3400702F006142003B46000F29
00021A00062000273B006241008508219700098D00006D3400374300082200021A001830
005E451592008CB700A2BC003CA000006C3500243900031B000822004B4D048B00C3C400
E07800D2A10040A10000604300112B000219001C330070308AB600EA5600F52B00D39E00
169200004B4D00062000051E0042490B8E00D2A200F81F00F13900B4C100007A2000263A
00031A000D27005A48389E00D79400ED4B00D891003FA100005E4500102A000219001730
006440369E00C6C000CDAF0073B000007B1D00384400062000031B0020360063400D8F00
53A70043A20000830E00564A00152F00031A00061F002539005C47007824008112007528
00594900233800072000021900092400253900504E005D46005C46004D4E002338000A24
00031A00031B000C26001E35002F3F00334100273A00152E
001831001C34001831000E2800061F00021900041C000D2800243900424900514D004C4D
002F3F00122C00041D00021A000B25002B3D005949006C35007030006142003B45000F29
00021A00062000273A00614200840B1F9600078D00006D3400364300082200021A001730
005E4512910087B5009DBB00399F00006C3500243900031B000822004A4C018A00BDC300
DE7D00D1A4003DA00000604300112B000219001B33006F3284B500E85D00F33200D2A100
149200004B4D00072000051E004048078D00D0A700F62600F03F00B0C00000792000263A
00031A000D27005A48349D00D59900EB5100D695003DA000005E4500102A000219001730
006340329C00C5C300CCB3006FAF00007A1E00384400062000031B0020360063400B8E00
4FA60040A10000821000564B00152F00031A00061F002539005B47007725008014007429
005849002338000720000219000924002439004F4E005D46005B47004C4D002238000A24
00031A00031B000C26001D35002F3F00324100263A00152E
001830001C33001830000E2800061F00021900041C000D2700233800414800504D004B4D
002F3F00122C00041D00021A000B25002B3D00584A006B36006F31006043003A45000F29
00021A00061F00263A00604300830D1C9400058C00006C3500364300082200021A001730
005D460F900081B40097BA00369E00006C3600243900031B00082200484B008901B5C100
DC8300D0A8003B9F00005F4400112B000219001A32006E337DB300E66400F13900D1A500
139100004B4D00072000051E003F47048B00CEAD00F42F00EE4600ABBF0000792100263A
00031A000C270059492F9B00D39E00E95800D599003A9F00005E4500102A00021900162F
0062412E9B00BFC300CAB7006AAE00007A2000374400062000031B001F36006241088D00
4BA4003CA00000811200554B00152E00031A00061F002439005B47007626007F1500732B
00584A002238000720000219000923002439004F4E005C47005B47004A4D002237000A24
00021A00031B000C26001D34002E3F00314100263A00142E
001730001C33001730000E2800061F00021900041C000D2700233800404800504E004A4D
002E3F00122C00041D00021A000B25002A3C00574A006B37006E32006043003A45000F29
00021A00061F002539005F4400820F189300038B00006C3600354300082200021A00162F
005C470B8E007BB20092B800339D00006B3600243900031B00082100464B008704ADBF00
DA8900CEAD00389E00005F4400112B000219001A32006C3576B100E46B00EF4100CFA900
119000004A4D00072000051E003D46008A00CCB200F23800EC4D00A6BD0000782200263A
00031A000C2600584A2A9A00D1A400E75F00D39E00379E00005D4600102A00021900162F
0061422A9A00B8C100C8BB0066AC0000792100374300062000031B001F35006142058C00
47A300389E0000801400554B00152E00031A00061F002439005A48007528007E1700722C
00574A002237000720000219000923002338004E4E005B47005A4800494C002137000A24
00021A00031B000C26001D34002D3E00314000253900142E
001730001B33001730000E2800061F00021900041C000D27002238003E47004F4E00494C
002D3E00122C00041D00021A000B2500293C00564A006A38006D34005F44003944000F29
00021A00061F002439005F44008112159200008A00006B3700354200082200021A00162F
005B47088D0075B0008BB600309C00006B3700243900031B00082100444A008608A5BD00
D88F00CCB100359D00005F4400112B000219001931006B376EAF00E17300ED4900CEAD00
0F9000004A4C00072000051E003B46008803CAB800EF4100EA5500A1BC0000782300253A
00031A000C2600574A259800CFAA00E56700D2A300349D00005D4600102A00021900152E
006043259800B0C000C7BF0061AB0000782300364300062000031B001E35006043028A00
42A200349D00007F1600544C00152E00031A00061F002338005948007429007D1900712E
00564B002137000720000219000923002338004D4E005B4800594800484B002137000A24
00021A00031B000C26001D34002D3E00304000243900142D
001730001B33001730000E2800061F00021900041C000D27002137003D47004F4E00484B
002D3E00122C00041D00021A000A2500283B00564B00693A006C35005E45003844000F29
00021A00061F002338005E45008015119100008802006A3800354200082200021A00152E
005A48048B006EAF0085B5002C9A00006A3800233800031B00072100424900840B9CBB00
D69600CAB600329C00005E4400112B00021900183100693967AD00DF7C00EB5200CCB200
0D8F00004A4C00072000051D003945008607C7BE00ED4B00E85C009BBA0000772400253A
00031A000B2500564B209600CDB000E36F00D0A800309C00005C4600102A00021900152E
005F44209600A7BD00C5C4005BA90000772400354300062000031B001D34005F44008901
3DA0002F9B00007E1800544C00142E00031A00061F00223800594900732B007C1C00702F
00554B002137000720000219000923002338004C4D005A4800594900464B002036000A24
00021A00031B000C26001C34002C3E002F3F00243900132D
00162F001A3200162F000D2800061F00021900041C000C27002137003C46004D4E00464B
002C3D00122B00041D00021A000A2400273B00554B00683B006B36005D45003744000F29
00031A00061F002338005D46007E170D8F0000870500693900344200082200021A00142E
00594900890067AD007DB30028990000693900233800031B00072100404800820F92B800
D49D00C8BB002E9B00005E4500122B00021900173000683B5EAA00DC8500E85B00CAB700
0A8E0000494C00072000041D00374400840BC4C400EA5500E5650095B90000772500253A
00031A000B2500544C1B9400CAB700E07700CEAE002C9A00005C4700102A00021900142E
005E451B94009EBB00BCC20056A80000762600354200062000031B001D34005E45008704
389E002A9A00007D1A00534C00142E00031A00061F00223700584900722D007B1E006F31
00554B002036000620000219000923002238004B4D00594900584A00454A001F36000923
00021A00031B000C26001C33002B3D002E3F00233800132D
00162F001A3200162F000D2800051F00021900041C000C26002036003B45004C4D00454A
002B3D00112B00041D00021A000A2400273A00544C00673C006A38005D46003643000F29
00031A00061F002237005B47007D1A098D0000860800683A00334200082200021A00142D
00574A0088035FAA0076B10024980000693A00233800031C000720003E4700801389B600
D1A400C6C0002A9A00005E4500122B00021900162F00663C56A800D98D00E66400C8BB00
088D0000494C00072100041D00354300820FB9C200E75F00E36E008EB70000762700253A
00031B000B2500534C159200C7BE00DD8000CBB400289900005B4700102A00021900142D
005C4616930095B900B2C00050A60000752800344200062000031B001C34005D45008607
329C00259800007B1D00524D00142D00031A00061F00213700574A00712F007920006E33
00544C001F3600062000021900092300223700494C00584900574A004349001F35000923
00021A00031B000C26001B33002B3D002D3E00223800132C
00152F00193200162F000D2700051F00021900041C000C26001F36003945004A4C004449
002A3D00112B00041D00021A000A2400263A00534C00653E006939005C47003643000F29
00031A00051F002137005A48007B1D058C0000840B00683B00334100082200021A00132D
00564B00860858A8006FAF0020960000683B00233800041C000720003C46007E177FB300
CEAB00C3C400269800005D4600122C00021900162F00653E4EA500D69600E36E00C6C100
058C0000484C00072100041D003342008014ADBF00E46A00E0770087B500007528002539
00031B000A2400524D0F9000C5C400DA8900C9B900249800005B4800102A00021900132D
005B471191008CB700A9BE004AA40000742A00334100062000031B001B33005C4600840B
2C9A00209600007A1F00514D00132D00031A00061F00213700564B007030007823006D34
00534C001F3500062000021900092300213700484B00574A00564B004149001E35000923
00021A00031B000C26001B33002A3C002C3E00213700122C
00152E00193100152F000D2700051E00021900031C000C26001F3500384400484C004249
00293C00112B00041D00021A000A2400253900524D00643F00683B005B47003542000E29
00031A00051E002036005949007A20018A0000830E00673C00324100082200021A00132C
00554B00840C50A60067AD001C940000673B00233800041C000620003945007C1B75B100
CCB300B9C200229700005D4600122C00021900152E00634045A300D39F00E07800C2C400
028B0000484B00072100041C003140007E18A1BC00E17500DD800080B300007429002539
00031B000A2400514D0A8E00B9C200D79200C7BF00209600005A4800102A00021900122C
005A480C8E0082B4009FBB0043A20000732B00324100062000031B001B33005B4700820F
2798001B940000792200514D00132D00031A00061F00203600554B006E32007725006B36
00524D001E3500061F00021900092300203700464B00564A00554B004048001D34000923
00021A00031B000B26001B3300293C002B3D00213700122C
00152E00183100152E000D2700051E00021900031C000B26001E3500374300464B004048
00293C00112B00041D00021900092400243900514D00634000673C005A48003442000E28
00031A00051E001F3500584A00782300880200811100663D00314000082200021900122C
00544C00821048A3005FAA0017930000663C00223800041C000620003744007A1F6BAE00
C9BA00AFBF001E9500005C4600122C00021900142D0061423CA000CFA900DD8200B8C200
00890000474B00072100041C002F3F007C1C94B900DD8000DA890078B10000732B002539
00031B000924004F4E048B00ACBF00D49B00C2C4001B940000594900102A00021900122C
005849078C0078B10094B9003DA00000722D00314000062000031B001A32005A48008112
21960016920000772500504E00132C00031A00061F001F3600544C006D34007528006A38
00514D001D3400061F00021900092300203600454A00554B00544C003E47001C34000923
00021A00031B000B26001A3200283B002A3D00203600112B
00142E00183000142E000C2700051E00021900031B000B25001D3400354200444A003F47
00283B00102A00041D00021900092300233800504E00624100653E005949003341000E28
00031A00051E001E3500574A00762600860700801500643F00314000082200021900112B
00524D00801440A10057A80012910000653D00223800041C00061F00354200782361AB00
C6C200A4BD001A9400005B4700122C00021900132D005F44349D00CCB200D98C00AEBF00
00880300464B00072100041C002D3E007A2088B600DA8B00D7920070AF0000722C002439
00031B000923004D4E0089019FBB00D1A400B7C10017930000594900102A00021900112B
00574A018A006EAF008AB600369E0000702F00304000062000031B001932005949007F16
1B9400119000007527004F4E00122C00031A00051F001F3500534C006B3600732A00693A
00504E001C3400061F000219000923001F3600434900544C00534C003C46001B33000822
00021A00031B000B25001A3200273B00293C001F3600112B
00142D00173000142D000C2700051E00021900031B000B25001C34003442004349003D46
00273A00102A00041D000219000923002237004F4E00604300643F00584A003141000E28
00031A00051E001D3400554B00742900840B007E1800634000304000082200021900112B
00514D007E19389E004EA5000E8F0000643F00223700041C00061F00334100762657A800
BCC2009ABA00159200005B4700122C00021900122C005E452B9A00C9BB00D69600A3BD00
00870600464A00072100041C002B3D0077247BB200D69600D49C0068AD0000712E002439
00031B000923004A4D00860692B800CEAD00ABBE0012910000584A00102A00021900112B
00564B00880364AC007FB300309C00006F31002F3F00062000031B00183100574A007D1A
1592000B8E0000742A004D4E00122C00031A00051E001E3500524D006A3800722D00673C
004F4E001B3300061F000219000923001F3500414800534C00524D003A45001B33000822
00021A00031B000B2500193200263A00283B001E3500102A
00132D00173000142D000C2600051E00021900031B000B25001C33003241004148003B46
00263A00102A00041D000219000923002137004D4E005F4400634100574A003040000E28
00031A00051E001C3300544C00722C00820F007C1B006241002F3F00082200021900102A
00504E007B1D309C0046A300098D0000634000213700041C00061F00314000742A4CA500
AEBF008FB700119000005A4800122C00021900112B005C47239700C5C300D3A00099BA00
00850900454A00082100041C00293C0075286FAF00D2A000D1A50060AB00007030002439
00031B00082200474B00840C85B500CAB6009FBC000D8F0000574A00102A00021900102A
00544C0085085AA90074B000299900006D33002E3F00061F00031B00183000564B007B1D
0F9000068C0000722D004B4D00112B00031A00051E001D3400514D00693A00703000663D
004D4E001B3300061F000219000922001E3500404800524D00514D003844001A32000822
00021A00031B000B2500193100253A00273B001D3400102A
00132C00162F00132D000C2600051E00021900031B000A25001B33003040003F47003A45
002539000F2A00041D000219000923002036004A4D005D4500614200564B002F3F000E28
00031A00051E001B3300534D00702F008014007A1F006142002E3F000822000219000F2A
004E4E0079212899003EA000048B0000624100213700041C00051E002E3F00712E42A200
A0BC0084B5000C8E0000594800122C00021900112B005A481A9400B7C100CFAA008EB700
00840C00444A00082100031B00273B00722C63AC00CFAB00CDAE0058A800006F31002338
00031B00082200444A00811179B200C7BF0094B900088D0000564B00102A000219000F2A
00534C00830E50A6006AAD00229700006C35002D3E00061F00031B00173000554B007921
098D00008A0000702F00494C00112B00031A00051E001C3400504E00673C006E3200643F
004A4D001A3200061F000219000822001D34003E4700514D00504E003743001931000821
00021A00031C000B2500183100243900263A001C34000F2A
00122C00152F00132C000C2600051E00021900031B000A24001A32002F3F003D46003844
002439000F2900041D000219000822001F3500484B005C4700604300544C002E3F000D28
00031A00051D001A3200514D006F32007E18007822006043002D3E000822000219000F29
004B4D007725209600369E0000890000614200213700041C00051E002C3E006F31399F00
93B80079B200078D0000594900122C00021900102A005849129100A7BD00CBB40083B400
00821000434900082100031B00253A00703057A800CBB500CAB70050A600006E33002338
00031B000822004148007F166CAE00BFC30088B600038B0000554B000F2A000219000F29
00514D00811346A3005FAA001B9400006A37002C3E00061F00031B00162F00544C007725
038B00008704006F3200464B00112B00031A00051E001C33004F4E00653D006D34006241
00484B00193100051E000219000822001D34003C4600504E004F4E003542001831000721
00021900031C000B25001830002338002539001B33000F29
00122C00152E00122C000B2600051E00021900031B000A24001932002D3E003B45003643
002338000F2900041D000219000822001E3500454A005A48005E4500534C002D3E000D27
00031A00051D00193100504E006D35007C1C007725005E44002C3E000822000219000E28
00474B0074291893002D9B0000870500604300203600041C00051E002A3D006D342F9B00
85B5006EAF00028B0000584A00122C000219000F2900564B0A8E0098BA00C7BD0078B100
00801300424900082100031B002339006E334BA400C7BF00C6C00047A300006C35002338
00031B000721003E47007C1C60AB00AFBF007CB20000890000544C000F29000219000E28
00504E007E173DA00054A700159200006939002B3D00061F00031B00162F00524D007528
008802008509006D3500444A00102A00031A00051E001B33004E4E00643F006B37006142
00454A00183100051E000219000822001C34003A45004F4E004C4D003341001730000721
00021900031C000B25001730002238002439001B32000E29
00112B00142E00122C000B2500051E00021900031B000A24001831002C3D003944003442
002237000E2900041D000219000822001C34004349005949005D4600524D002B3D000D27
00031A00041D001831004E4E006B37007920007529005D46002B3D000822000219000E28
00444A00722D119000259800008509005F4400203600041C00051E00283B006A38259800
78B10063AB0000890100574A00122B000219000E2800544C028B0088B600C1C4006DAE00
007F1700414800082200031B002237006B3740A100BDC300BCC2003FA100006B37002238
00031B000721003B4500792054A700A0BC0070AF0000870500534C000F29000219000E28
004E4E007C1C339D004AA4000E8F0000673B002A3C00061F00031A00152E00514D00732B
00860700830F006B3700424900102A00031A00051E001A32004B4D006241006939005F44
00424900173000051E000219000822001B33003944004D4E00494C00314000162F000721
00021900031C000A25001730002137002238001A32000E28
00112B00142D00112B000B2500051E00021900031B000924001830002A3D003743003241
002137000E2800041D000219000822001B3300404800574A005B4700514D002A3D000D27
00031A00041D001730004B4D00683A00772400732C005C47002A3C000822000219000D27
004148007030098D001D950000830E005E45001F3600041C00051D00263A00683A1C9500
6AAE0058A80000860600564B00112B000219000E2800524D00870479B200B0C00062AB00
007D1A003F4800082200031B00203600693A359D00ABBE00ACBF00369E00006A38002237
00031B00072000384400772548A30090B80064AC0000840A00524D000F29000219000D27
004B4D0079212A990040A100078D0000663D00283C00061F00031A00142E004F4E00712F
00830D008014006939003F47000F2900031A00051E001A3200494C00614300673C005D45
00404800162F00051E000219000822001B33003743004B4D00464B002F3F00152F000720
00021900031C000A2400162F002037002137001931000D28
00102A00132D00112B000B2500051E00021900031B00092300173000293C003542003140
002036000E2800041D000219000821001A32003D4700564B00594800504E00293C000C27
00031A00041D00162F00484B00663C00752800702F005A4800293C000822000219000D27
003E47006D34028A00159200008013005C46001F3500041C00041D00243900663D139100
5DAA004DA50000840B00554B00112B000219000D2700504E00840B6BAE00A0BC0057A800
007B1E003E4700082200031B001E3500663D2A9A009ABA009CBB002E9B0000683A002137
00031B00072000354300742A3CA00081B40058A80000820F00514D000F29000219000D27
00484B007725209600359E00018A0000643F00273B00061F00031A00142D004E4E006F32
008112007E1900673C003D46000F2900031A00051E00193100464B005F4400653E005C47
003D4600162F00051E000219000822001A3200354200484B00444A002D3E00152E000720
00021900031C000A2400162F001F36002036001830000D27
00102A00122C00102A000A2400051E00021900031B00092300162F00273B003341002F3F
001F35000D2800041C000219000721001932003B4500544C00584A004E4E00283B000C26
00031A00041D00152F00454A00643F00732C006E3200594900283B000822000219000C26
003B45006B370087040D8F00007E18005B47001E3500041C00041D0022380063400B8E00
51A60042A20000821000544C00112B000219000C26004E4E0081125DAA0090B8004CA500
007921003D4600082200031B001D3400643F1F960089B6008DB70026980000673C002037
00031B00062000334100712E319C0073B0004DA50000801400504E000E29000219000C26
00454A00742A1893002C9A0000870500624100263A00061F00031A00132D004B4D006C35
007E18007B1D00653E003A45000E2800021A00051E00183100444A005D46006340005A48
003A4500152E00051E00021900082200193200334200454A004148002B3D00142D000620
00021900031C000A2400152E001E35001F36001730000D27
000F2900122C00102A000A2400051D00021900031B00092300152E00263A003140002D3E
001E35000D2700041C00021900072100183100384400534C00564B004B4D00263A000C26
00031A00041C00142E00424900624100702F006C3500574A00273A000822000219000C26
00384400683A00840B068C00007C1C005A48001E3500041C00041D002137006142028B00
45A200389E0000801500534C00112B000219000C26004A4C007E184FA60080B30042A200
007725003B4600082200031A001B3300614216920079B2007EB3001E950000653E002036
00031B00061F003040006F3227980065AC0042A100007D19004F4E000E28000219000C26
00414900722D0F900022970000840B00604300253900061F00031A00122C00484B006A38
007C1D007822006340003844000E2800021A00051E001730004148005B47006142005849
00384400142D00051D000219000822001931003241004249003E4700293C00132D00061F
00021900031C000A2400152E001D35001E3500162F000C26
000F2900112B000F29000A2400051D00021900031B00082200142E002439002F3F002B3D
001D34000D2700041C00021900072000183000364300514D00554B00484C002539000C26
00031A00041C00142D003E47006043006E33006A3800564B00263A000822000219000B25
00354300663D008111008900007921005849001D3400041C00041C001F35005F44008705
399F002E9B00007D1900524D00112B000219000B2500464B007B1E42A20071AF00379E00
007528003A4500082200031A001A32005F440C8F006AAD006FAF00169200006340001F36
00031B00061F002D3E006C351C950057A800379E00007B1D004D4E000E28000219000B26
003E47006F31078C00199300008211005E4500233800061F00031A00122C00454A00683A
007921007627006142003543000D2800021A00051E001730003F47005A48005F4400564B
00354300132D00041D000219000821001831003040004048003C4600273B00122C00061F
00021900031C000A2400142E001C34001D3400152E000C26
000E2800112B000F29000A2400051D00021900031B00082200142D002338002D3E002A3C
001C33000C2700041C000219000720001730003442004F4E00534C00454A002439000B26
00031A00041C00132C003B46005E45006B3600683B00544C002439000822000219000B25
00334100643F007E1700860700772500574A001C3400041C00041C001D34005C4600840C
2D9B00249700007B1E00514D00112B000219000A25004249007724359D0062AB002D9B00
00732B00384400082200031A001831005C46038B005BA90061AB000E8F00006241001E35
00031B00061F002B3D0069391391004AA4002C9A00007822004A4C000E28000219000B25
003B46006C35008900109000007F17005C4600223800051E00031A00112B00424900663D
00762600732B005F44003341000D2700021A00051E00162F003C46005849005D4500544C
00334100122C00041D000219000821001730002E3F003D4600394400263A00112B00061F
00021900031C000A2400132D001B33001C3300142E000B25
000E2800102A000E2800092300041D00021900031B00082200132D002137002B3D00283B
001B33000C2600041C00021900072000162F003140004D4E00514D004249002238000B25
00031A00041C00122C003944005C4700693900663D00534C002338000822000219000A24
003040006142007B1D00830E00742900554B001B3300041C00041C001C33005A48008013
2297001A9400007822004F4E00102A000219000A24003E4700742929990054A700239700
00712F00364300082200031A001730005A480087044DA50053A700068C00006043001E35
00031B00051E00293C00673C098D003DA00022970000762600474B000D28000219000A25
003844006A38008607078D00007C1C005B4800213700051E00031A00112B003F4700643F
00742A00712F005D46003140000C2700021A00051D00152F003A4500564B005B4700534C
00304000112B00041D000219000821001730002C3E003A4500364300243900112B00061F
00021900031C00092300132D001A32001A3200132D000B25
000D27000F2A000E2800092300041D00021900031B00082100122C00203600293C00263A
001A32000C2600041C00021900062000152E002F3F004A4C00504E003F48002137000B25
00031A00041C00112B003643005A4800673C00644000514D002238000821000219000A24
002D3E005F4400782200801400722D00544C001B3300041C00041C001A3200584A007D1A
189300119100007626004E4E00102A000219000923003B4500712E1E950046A3001A9400
006F3200354200082200031A00162F00584A00840C3FA10045A300008900005E45001D34
00031B00051E00273A00643F018A00319C0018930000732B00444A000D27000219000A24
00364300673B00830E008900007921005949001F3600051E00031A00102A003C46006142
00712F006E33005B48002E3F000C2600021A00051D00152E00384400554B00594800514D
002E3F00112B00041D00021900072100162F002B3D00384400344200223800102A00051E
00021900031C00092300122C00193200193200132C000A24
000D27000F29000D2800092300041D00021900031B00072100112B001E3500273B002539
001931000B2600041C00021900062000142D002D3E00464B004E4E003C46002036000B25
00031A00041C00102A00334100584A00643F00614200504E002137000821000219000923
002B3D005D46007528007D1A006F3100524D001A3200041C00041C00193100554B007A20
0E8F00088D0000732A004B4D00102A000219000923003743006E33139100399F00119000
006C3500334100082100021A00142E00554B008014329C00399F00008607005D46001C34
00031B00051E0025390062420086072598000F900000712E004249000D27000219000A24
00334100653E007F1500860800762600574A001E3500051E00031A000F2A003A45005F44
006E32006B36005849002C3E000B2600021A00051D00142E00354300534C00574A004F4E
002C3D00102A00041C00021900072100152F00293C003543003140002036000F2900051E
00021900031C00092300122C00193100183100122C000A24
000C27000E29000D2700092200041D00021900031A00072100112B001D3400253A002338
001830000B2500041C00021900061F00132D002B3D004349004A4C003A45001F35000A25
00031A00041C00102A00304000564B006241005F44004E4E002036000721000219000923
00293C005A4800722C007A20006D3400514D00193200041C00031B00173000534C007626
058C00008A0000712E00484C00102A000219000922003442006B37098D002C9A00088D00
006A3800314100082100021A00132D00534C007D1B2598002C9A0000830E005B47001B33
00031B00051E002338005F4400830F1A9400058C00006E32003F47000C27000219000923
003040006241007C1C00820F00732B00554B001D3400051E00031A000F29003743005D46
006C3600693A00564A002A3C000B2500021A00051D00142D00334100514D00564B004C4D
00293C000F2900041C00021900072100152E00273B003341002F3F001F35000E2900051E
00021900031C00092300112B00183000173000112B000924
000C26000E28000C2700082200041D00021900031A00072100102A001C33002439002137
001730000B2500041C00021900061F00122C00293C003F4700464B003743001D34000A24
00031A00031B000F29002E3F00544C005F44005D46004A4D001E35000721000219000822
00263A00584A006F31007626006A38004F4E00193100041C00031B00162F00514D00732B
008803008607006E3200464A000F2900021900082200314000683A008900209600008900
00683B00304000082100021A00122C00514D0079211A9400219600008015005949001A32
00031B00051D002137005D46007F160F9000008802006C36003C46000C26000219000923
002E3F006043007921007F1600703000534C001C3300051E00031A000E29003442005B47
00693900663D00544C00283B000A2500021A00051D00132D003140004F4E00544C00484B
00273B000E2800041C00021900072100142E00263A003140002C3E001D34000E2800051E
00021900031C00092300112B00173000162F00102A000923
000B26000D28000C2600082200041D00021900031A000720000F2A001B32002237002036
00162F000A2500041C00021900061F00112B00273A003C46004249003442001C34000A24
00031A00031B000E29002C3D00524D005D46005B4800474B001D34000721000219000822
00243900564B006C3500732B00683B004D4E00183000041C00031B00152E004F4E007030
00840B00830F006C36004349000F29000219000822002E3F00653E008508159200008608
00663D002E3F00072100021A00112B004F4E0076270F9000169200007C1B00574A001932
00031B00051D001F36005A48007B1D058C0000850A006939003944000C26000219000923
002C3D005E45007627007C1D006D3400514D001A3200051D00031A000E28003241005949
00663D00634000524D00253A000A2400021A00051D00122C002F3F004D4E00524D00444A
002539000E2800041C00021A00072100142D002439002E3F002A3D001C33000D2700051D
00021900031C00092300102A00162F00152F00102A000923
000B25000D27000C2600082200041D00021900031A000720000F29001932002036001E35
00152E000A2400041C00021900051F00112B002539003944003F47003241001B33000A24
00031A00031B000E2800293C00504E005B47005949004349001C34000721000219000822
00223800534C00693900702F00653E00494C00173000041C00031B00142D004B4D006D34
008013007F16006939004048000E29000219000721002B3D0062410082110B8E0000820F
006340002C3E00072100021A00102A004B4D00722C058B000B8E0000792100554B001831
00031B00041D001D3400584A00782300880300811200663C003643000B25000219000822
002A3C005B4700722C007823006A38004F4E00193100051D00031A000E2800304000574A
00643F00614200504E002338000A2400021900041D00122C002D3E00494C00504E004048
002338000D2700041C00021A00072100132D002338002C3E00283B001A32000C2700041D
00021900031C00082200102A00152E00142E000F29000822
000B25000C27000B2500082100041C00021900031A000620000E28001831001F35001D34
00142D000A2400041C00021900051E00102A002338003643003C46002F3F001A32000923
00031A00031B000D2700273B004D4E00584900564A004048001B33000720000219000721
00203700514D00663C006D3400634000464B00162F00041C00031B00132C00464B006A38
007D1A007C1D00673C003D46000E2800021900072100283B005F44007E18018A00007F16
006142002A3D00072100021A00102A00464B006F31008704018A0000762600534C001830
00031B00041D001C3300554B00752900840C007D1900643F003442000B25000219000822
00273B005949006F3100752800673B004B4D00183000041D00031A000D27002D3E00554B
006142005E45004E4E00213700092300021900041D00112B002B3D00454A004D4E003C46
002137000C2600031B00021A00072000122C002137002A3C00263A001931000C2600041D
00021900031C000822000F2900142E00132D000E28000822
000A24000C26000B2500072100041C00021900031A000620000E28001730001D34001C33
00132D00092300041C00021900051E000F29002137003341003844002D3E001931000923
00031A00031B000D2700253900484C00564B00544C003D46001A32000720000219000721
001F35004F4E006440006A3800604300424900152F00041C00031B00122C00424900673C
00792100782300643F003A45000E2800021A00072000263A005D46007A20008608007B1D
005E4400283B00072100021A000F29004249006C3600830D00860700732C00514D001730
00031B00041D001A3200534C00712E008014007A20006142003140000A25000219000822
00253A00574A006C3500712E00653E00474B00173000041D00031A000D27002B3D00534C
005E44005C4700494C001F3600092300021900041D00112B00293C00424900494C003944
001F35000C2600031B00021A00072000122C00203600283B002439001730000B2500041D
00021900031C000822000F2900132D00132C000D28000821
000A24000B26000A2400072100041C00021900031A00061F000D2700162F001C33001A32
00122C00092300031C00021900051E000F29001F36003040003543002A3D001730000923
00031A00031B000C2600233800444A00544C00524D003945001931000720000219000720
001D34004B4D00614200673B005E45003F4700142E00041C00031B00112B003E47006440
007527007529006142003744000D2800021A000620002439005A48007626008210007823
005C4600273A000721000219000E28003E4700683A007F15008210007030004F4E00162F
00031B00041C00193100514D006E33007C1B007626005E44002E3F000A24000219000821
00243900544C006939006E3200624100434900152F00041D00031A000C2700293C00514D
005C4700594900444A001E3500082200021900041D00102A00273B003E4700444A003543
001D34000B2500031B00021A00072000112B001E3500263A00223700162F000A2500041C
00021900031C000822000E2800122C00122C000D27000721
000923000B25000A2400072000041C00021900031A00061F000C2700152E001A32001931
00112B00092300031B00021900051E000E28001D35002D3E00324100283B00162F000822
00031A00031B000B2600213700404800524D00504E003643001830000620000219000720
001B3300464B005E4500643F005B47003C4600142D00041C00031B00102A003A45006142
00722D00712E005F44003442000D2700021A00062000223700574A00732C007E18007429
005A48002539000720000219000D27003A4500653E007B1D007E17006C35004C4D00152E
00031B00041C001830004F4E006B3700792200732C005C47002C3D000A24000219000721
00223700524D00663D006B37005F44003F4700142E00041D00031A000C2600273B004F4E
00594800574A004048001C3300082200021900041D00102A00253A003B45004048003241
001B33000A2400031B00021A00072000112B001D3400243900203600152E000A2400041C
00021900031C000822000E2800122B00112B000C26000721
000923000A25000A2400072000041C00021900031A00061F000C2600142D001931001830
00112B00082200031B00021900051E000D27001C33002B3D002F3F00263A00152F000822
00031A00031B000B25001F36003C46004F4E004D4E00334100162F000620000219000620
001A32004249005B4700614200594900384400132D00041C00031A000F29003643005E45
006E32006E33005C46003241000C2700021A00061F001F3600554B006F31007A1F00712E
00574A002338000720000219000D27003643006241007824007A1F00693900484C00142D
00031B00041C00162F004A4D00673B007528006F3100594900293C000923000219000721
00203600504E00634000683B005C46003B4500132D00041C00031A000B2600253A004B4D
00574A00544C003C46001A3200072100021900041D000F29002439003844003D46002F3F
001A32000A2400031B00021A00072000102A001C33002237001E3500142D00092300041C
00021900031C000821000D2700112B00102A000C26000720
000923000A2400092300072000041C00021900031A00051E000B2600132C00183000162F
00102A00082200031B00021900051D000D27001A3200283B002D3E00243900142E000822
00031A00031B000A25001D34003844004C4D00484C00304000152F00061F00021900061F
001831003E47005949005F4400564B00354300122C00041C00031A000E28003341005B47
006B37006B37005A48002F3F000C2600021A00061F001E3500524D006C36007626006D33
00554B002137000720000219000C26003341005F4400742A00762600663D00444A00132D
00031B00041C00152E00464B00643F00712E006C3600574A00273B000923000219000720
001E35004E4E00604300653E00594800374300122C00041C00031A000B2500243900474B
00554B00524D00384400193100072100021900041D000F29002237003542003944002C3D
00183100092300031B00021A00062000102A001A32002036001C3400122C00092300041C
00021900031C000721000D2700102A000F29000B25000620
000822000A2400092300062000041C00021900031A00051E000B2500122C00162F00152F
000F2900082200031B00021900041D000C2600193100263A002A3C00223700132D000821
00031A00031B000A24001C3300354200474B00444A002D3E00142E00061F00021900061F
001730003A4500564B005C4700544C00324100112B00041C00031A000D28002F3F005849
00683B00673B00574A002D3E000C2600021A00051F001C3300504E00683A00722C006A38
00534C002036000620000219000B26003040005C4600703000732C00634000404800122C
00031B00041C00142E004149006142006E3300683A00544C002539000923000219000720
001D3400494C005E4500624100574A00334200112B00041C00031A000B25002237004249
00524D004F4E00344200173000072000021900041D000E2800203600324100354300293C
00162F00092300031B00021A000620000F29001932001E35001B3300112B00082200031B
00021900031C000721000C27000F29000E29000A2500061F
00082200092300082200061F00041C00021900021A00051E000A2400112B00152E00142E
000E2900082100031B00021900041D000B2600183000243900273B00203600122C000721
00021A00031B000A24001A32003241004249004048002B3D00132D00061F00021900061F
00162F00364300534C00594900514D002F3F00102B00041C00031A000D27002C3E00554B
00643F00643F00554B002A3C000B2500021A00051E001A32004C4D00653E006F3200673C
00504D001E3500061F000219000B25002D3E005948006C35006F31006043003C4600112B
00031B00041C00132D003D47005E45006A3800653E00524D002238000822000219000720
001B3300454A005B47005F4400544C00304000102A00041C00031A000A25002036003F47
00504E004C4D00314000152F00062000021900041D000E28001F35002F3F00324100263A
00152E00082200031A00021A000620000E29001831001D3400193100102A00082200031B
00021900031C000721000C26000F29000E28000A2400061F
00082100092300082200061F00041C00021900021A00051E000A2400102A00142E00132D
000E2800072100031B00021900041D000B2500162F002137002539001E3500112B000721
00021A00031A000923001931002E3F003E47003C4600283B00122C00061F00021900061F
00142E00334100514D00564A004F4E002C3E00102A00041C00031A000C26002A3C00534C
00614200614200524D00283B000B2500021A00051E00193100474B006242006B3700643F
004E4E001C3400061F000219000A25002A3C00574A006939006B36005D4600384400102A
00031B00041C00122C003A45005B4700673C006241004F4E002036000822000219000620
001A32004048005849005C4700514D002D3E000F2900041C00031A000A24001F35003B45
004D4E00464B002D3E00142E00061F00021900041D000D28001D34002C3E002F3F002439
00142D00082200031A00021A00061F000E28001730001B33001830000F2900082100031B
00021900031C000721000B26000E28000D2700092400061F
00072100082200082200061F00031C00021900021A00051E000923000F2900132D00122C
000D2700072100031B00021900041D000A2500152E001F36002338001C3400112B000720
00021A00031A000923001730002B3D003A4500384400263A00112B00051E00021900051E
00132D002F3F004E4E00544C004B4D002A3C000F2900041C00031A000C2600273B00504E
005E45005E4500504E00253A000A2400021A00051E001730004249005E4500673B006043
00494C001B3300061F000219000A2400273B00544C00653D00683B005A48003442000F2A
00031B00031C00112B003643005949006340005F44004B4D001E35000721000219000620
001931003C4600554B005949004F4E002A3C000E2800031B00031A000A24001D34003744
00484B004249002A3D00132C00061F00021900041D000D27001C3300293C002C3D002137
00122C00072100031A00021A00061F000D2800162F001A3200162F000E2900072100031B
00021900031B000720000B25000D28000C2700092300051E
00072100082200082100061F00031B00021900021A00051D000923000E2900122C00112B
000C2700072000031B00021900041C000A2400142D001E35002137001B3300102A000720
00021A00031A00082200162F00293C00364300344200233800112B00051E00021900051E
00122C002C3E00494C00514D00464A00273B000E2800031C00031A000B25002439004D4E
005B47005B47004C4D002338000A2400021A00051E00162F003E47005B4700643F005D45
00444A00193200061F00021900092400253900514D00624100643F00574A003140000F29
00031B00031B00102A00334100564B006043005C4700454A001C3400072100021900061F
00173000394400534C00564B004A4C00273A000D2800031B00031A000A24001C33003442
004349003D4600273B00122B00051F00021900041D000C27001A3200273B00293C001F36
00112B00072000031A00021A00061F000D2700152E00183100152E000E2800072000031B
00021900031B000720000B25000D27000C2600092200051E
00072000082200072100051E00031B00021900021A00041D000922000E2800112B00102A
000C2600072000031B00021900041C000A2400132C001C33001F35001931000F29000620
00021A00031A00082200152E00263A00324100304000213700102A00051E00021900051E
00112B00293C00444A004F4E004148002539000E2800031B00031A000A2500223800484B
00584900584900474B00213700092300021900051D00152E003A45005849006142005A48
003F4800183000051E000219000923002238004F4E005F4400614200544C002D3E000E28
00031B00031B00102A002F3F00534C005D46005949004048001A3200072000021900061F
00162F00354200504E00534C00444A002439000C2700031B00031A000923001A32003140
003E4700394400243900102A00051E00021900041D000C2600193100253900263A001D34
00102A00072000031A00021A00061F000C2700142D00173000142D000D2700062000031B
00021900031B000620000A24000C26000B2500082200051E
00062000072100072100051E00031B00021900021A00041D000822000D2700102A000F2A
000B2600062000031B00021900041C00092300122C001A32001D34001830000E2800061F
00021A00031A00082100132D002439002F3F002D3E001F36000F2900051E00021900051E
00102A00273A003F4800494C003C46002238000D2700031B00031A000A24002036004349
00554B00554B004249001F3500092300021900051D00132D00364300554B005D4500574A
003B4500162F00051E000219000923002036004A4D005C47005E4500524D002A3D000D27
00031B00031B000F29002C3E00514D005A4800564B003C4600193100062000021900061F
00152F003241004D4E00504D003F48002137000C2600031B00031A000923001931002E3F
003A45003442002237000F2900051E00021900041D000C26001831002238002439001B33
000F2900062000021A00021A00061F000C2600132C00152F00122C000C2600061F00031A
00021900031B000620000A24000C26000B2500082200051D
00062000072100072000051E00031B00021900021A00041D000822000C26000F29000F29
000B2500061F00031B00021900041C00092300112B001831001B3300162F000D2800061F
00021A00031A00072100122C002137002C3D002A3D001D34000E2800051E00021900051D
000F2A002439003B4500444A003844002036000C2600031B00031A000A24001E35003E47
00524D00524D003D47001D3400092300021900041D00122C00324100534D005A4800544C
00374300152E00051E000219000822001E3500454A005949005A48004F4E00273B000C27
00031A00031B000E28002A3C004E4E00574A00534C00374400173000061F00021900061F
00142E002F3F00484C004D4E003B45001F35000B2500031B00031A000923001830002B3D
003643003140001F36000E2800051D00021900041C000B25001730002036002137001932
000E2800061F00021A00021A00061F000C2600122C00142E00112B000B2500061F00031A
00021900031B00061F000923000B25000A2400072100051D
00061F00072000062000051E00031B00021900021A00041C000721000C26000E28000E28
000A2400061F00031B00021900041C00082200102A00173000193200152E000D2700061F
00021A00031A00072100112B001F3600293C00273B001B33000D2800051D00021900051D
000F29002237003643003F47003442001E35000C2600031B00021A000923001C34003945
00504E004F4E003944001B3300082200021900041D00112B002E3F00504E00574A00514D
00334100142D00051E000219000822001C3400404800564B00574A004A4C002439000C26
00031A00031B000E2800273B00484C00544C00504E00334100152F00061F00021900061F
00132D002C3D00434900474B003643001D34000A2400031B00031A00082200162F00283B
003241002D3E001D34000D2700041D00021900041C000B2500152F001E35001F36001730
000D2700061F00021A00021A00061F000B2500112B00132D00102A000B2500051F00031A
00021900031B00061F000923000A25000A2400072100041D
00061F00072000062000051E00031B00021900021A00041C000721000B25000D28000D27
000A2400061F00031B00021900041C000822000F2900152F00183000132D000C2600051F
00021A00031A00072000102A001D3400263A002439001932000D2700041D00021900041D
000E28001F36003241003A45003040001C33000B2500031B00021A000923001A32003542
004B4D004B4D00344200193100082200021900041D00102A002B3D004C4D00544C004E4E
002F3F00122C00051D000219000821001B33003B4600534D00544C00444A002237000B25
00031A00031B000D2700243900434900514D004B4D002F3F00142D00061F00021900051E
00122C00293C003E47004249003241001A32000A2400031A00031A00082200152F00263A
002F3F002A3C001B33000C2700041D00021900041C000A2500142E001C34001D3400162F
000C2600051E00021A00031A00051E000B2500102A00122C000F29000A2400051E00031A
00021900031B00061F000923000A2400092300072000041D
00051F00062000061F00051D00031B00021900021A00041C000720000A24000D27000C27
00092300051F00031A00021900031C000721000E2800142D00162F00122C000B2500051E
00021A00031A000620000F29001B33002338002237001830000C2600041D00021900041D
000D27001D34002F3F003643002C3E001A32000A2400031B00021A000822001831003140
00454A00454A00304000173000072100021900041D000F2A00283B00464A00514D00484C
002B3D00112B00051D00021900072100193100374300504E00514D003E47001F36000A24
00031A00031B000C27002238003E47004E4E00454A002B3D00122C00051E00021900051E
00112B00263A003945003C46002E3E00183100092300031A00031A00082200142E002338
002B3D00263A001931000B2600041C00021900041C000A2400132D001B32001B3300142E
000B2600051E00021A00031A00051E000A24000F2900112B000E2800092300051E00031A
00021900031B00061F00082200092300092200062000041C
00051E00061F00061F00051D00031B00021900021900041C000620000A24000C26000C26
00092300051E00031A00021900031B000721000D2700132C00142E00112B000B2500051E
00021A00031A000620000E28001931002037001F3600162F000B2500041D00021900041D
000C26001B33002B3D00314000293C001831000A2400031B00021A000822001730002D3E
003F48003F47002D3E00162F00072100021900041C000E29002539004048004D4E004249
00283B00102A00041D000219000721001730003341004B4D004E4E003944001D34000A24
00031A00031B000C2600203600394500474B003F4800283B00112B00051E00021900051E
00102A002439003542003844002A3C00162F00082200031A00031A00082200132D002137
00283B002338001730000B2500041C00021900041C000A2400122C00193100193100132C
000B2500051D00021900031A00051E000A24000E2800102A000D2700092300051D00031A
00021900031B00051F00082200092300082200061F00041C
00051E00061F00061F00041D00031B00021900021900041C00061F000923000B25000B25
00082200051E00031A00021900031B000720000C2600112B00132D00102A000A2400051E
00021A00031A00061F000D28001730001E35001D3400142E000A2500041C00021900041C
000C2600193100273B002D3E00263A00162F00092300031B00021A00082100152E002A3C
003A4500394500293C00142E00072000021900041C000E28002238003B4500474B003C46
002439000F2900041D00021900072000162F002F3F00444A00474B003442001A32000923
00031A00031B000B25001D35003442004148003A4500243900102A00051D00021900051E
00102A00213700304000334100263A00142E00082200031A00031A00072100122C001E35
00253900203600152E000A2400041C00021900041C00092300112B00173000173000112B
000A2400041D00021900031A00051E000923000D28000F29000C2700082200041D00021A
00021900031B00051E00072100082200082100061F00041C
00051E00051F00051E00041D00031B00021900021900031C00061F000922000A25000A24
00082200051E00031A00021900031B000620000B2600102A00122B000F2900092300051D
00021A00021A00061F000C2700152F001B33001A3200132D000A2400041C00021900041C
000B2500173000243900293C00223800142E00092300031B00021A00072100142D00263A
00344200344200253A00122C00062000021900041C000D27001F36003543004048003743
002137000E2800041C00021900072000142E002B3D003E47004048002F3F001831000822
00021A00031B000B25001B33003040003B45003442002137000E2800041D00021900051E
000F29001E35002C3E002E3F00233800132C00072100031A00031A00072100112B001C34
002237001D3500132D00092300041C00021900041C00092300102A00152F00152E00102A
00092300041D00021900031A00051E000923000C27000E28000B2600082100041D00021A
00021900031B00051E00072100082200072100051E00041C
00051D00051E00051E00041D00031B00021900021900031B00051F000822000A24000924
00072100051D00031A00021900031B00061F000B25000F2900102A000E2800092300041D
00021A00021A00051E000C2600132D00193100183100112B00092300041C00021900041C
000A2400152E00213700253A001F3600132C00082200031A00021A00072000122C002338
002F3F002F3F00223700112B00061F00021900041C000C26001D34003040003945003140
001E35000D2700041C00021900062000132C00273A003844003945002A3D00162F000822
00021A00031B000A24001931002B3D003542002F3F001D35000D2700041D00021900051E
000E28001C3300283B00293C001F3600112B00072000021A00031A00072000102A001A32
001E35001B3300112B00082200031B00021900041C000822000F2900132D00132D000E29
00082200041C00021900031A00051E000822000C26000C27000A2500072100041C00021A
00021900031B00051E00072000072100072000051E00031C
00041D00051E00051E00041C00031B00021900021900031B00051E000721000923000923
00072000041D00031A00021900031B00061F000A24000D28000F29000C2700082200041D
00021900021A00051E000B2500122C00162F00162F00102A00082200041C00021900041C
00092300132D001D34002137001C3300112B00072100031A00021A00062000102B001F36
002A3C002A3C001E35000F2900061F00021900041C000B25001A32002B3D003341002C3D
001B33000B2600041C00021900061F00112B00233800324100334100253A00142D000721
00021A00031B00092300173000273B002F3F002A3C001A32000C2600041C00021900051D
000D27001932002439002539001C33000F2900061F00021A00031A000720000E29001730
001B33001831000F2A00082100031B00021900041C000822000E2800122C00112B000D27
00082100041C00021900031A00051D000822000B25000B26000A2400072000041C00021A
00021900031B00051D00062000072100062000051E00031B
00041D00051D00051D00041C00031A00021900021900031B00051E000720000822000822
00062000041D00031A00021900031B00051E000923000C26000D28000B2600082100041C
00021900021A00051E000A2400102A00142E00132D000E2800082200031C00021900041C
00092300112B001A32001D35001931000F2900072000031A00021A00061F000F29001C33
00253A002539001B33000E2800051E00021900031C000A2400173000263A002D3E00263A
001830000A2500031C00021900061F00102A001F36002C3D002D3E00213700112B000720
00021A00031B00092300152E002338002A3C002539001730000B2500041C00021900041D
000C26001730002036002137001931000E2800061F00021A00031A000620000D2800152E
00183100152E000E2800072100031B00021900041C000721000D2700102A00102A000C26
00072100041C00021900031A00041D000721000A24000A2500092300061F00041C00021A
00021900031B00041D00061F00062000061F00051D00031B
00041C00041D00041D00041C00031A00021900021900031B00041D000620000821000721
00061F00041C00031A00021900031A00051E000822000B25000C26000A2400072100041C
00021900021A00051D000923000E2800122C00112B000D2700072100031B00021900031B
000822000F2A001730001A3200162F000E2800062000031A00021A00061F000E28001831
002137002036001730000C2700051E00021900031B00092300152E00213700273B002237
00152E00092300031B00021900051E000E28001B3300263A00273B001D34000F2A00061F
00021A00031B00082200132C001E3500243900203600142E000A2400041C00021900041D
000B2500142E001C34001D3400162F000C2600051E00021A00031A00061F000C2600132C
00162F00132C000C2700062000031B00021900041C000721000B26000E29000E28000B25
00062000031B00021900021A00041D00072000092300092400082200061F00031B000219
00021900031B00041D00061F00061F00051F00041D00031B
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00A_ooool3o`0000Cooooo0_l0000hooooo`?o0000>Oooool2o`0003_ooooo0ol0000Moooo
o`00Aoooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003Kooooo00Go0000oooo
ooooooooooooo`00000gooooo`04o`000?ooooooooooo`0003Wooooo00Go0000oooooooooooooooo
o`00000Looooo`00?oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000`ooooo`Go00001Oooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0003go
oooo00?o0000ooooooooool06_ooool004Oooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000jooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo0000?Oooool00ol0
003oooooooooo`0Jooooo`00Aoooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
03Kooooo1?l0000hooooo`04o`000?ooooooooooo`0003Wooooo1?l0000Mooooo`00A_ooool2o`00
00Cooooo00Co0000oooooooooooo0000=_ooool00ol0003oooooooooo`0iooooo`04o`000?oooooo
ooooo`0003Wooooo00?o0000ooooooooool07_ooool004Oooooo00?o0000ooooooooool00oooool2
o`0003Oooooo1Ol0000hooooo`;o0000>_ooool5o`0001cooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Foooooooo00002Ol00002oooo
o`005_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool01?l0003oooooooooool00002ooooo`005_ooool00ol0003oooooooooo`3oooooo`Go
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo0?oooooo1Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool0ooooool5ooooo`7o00000Oooool1ooooo`002?ooool3
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo0?oooooo1Oooool1o`00007ooooo0Oooool0
00Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo0P000a/40004708000<K0P000aX400026@8000<J0P0011`200057P@000HO0P001Ah2
00037080008J0P000QT200036P8000@M0P001R0200088P8000TS00<000PQ00057`001Al00P000a/2
00026@80008J0P0011`20007808000XT0P003BL2000<9P8000TS0P001Ql200036`80008I0P000a/2
00067`8000/U0P0042X2000B;08000lY0P002R@200057P80008J0P000QT200057@8000XT0P004B/4
000F;`80010Z0P002B<200047080008I0P000a/200078@8000hY0P005Rl2000J<P8001H_0P003bT2
00078@8000<K0P000QT00`0011d000XT000:9002000C;08001Tb0P006S82000D;@8000/U0P001Ah2
00026@8000<J0P001R02000=9`8001D^0P006342000E;`8000hX0P001b4200036`80008I0P0011`2
00088P8000hX10004bd2000?:@8000TS0P0011d200026@80008J0P001Ah200098`8000dW0P003bT2
000=9`8000TS0P001Ah200036P80008I0P000a/200067`8000PR0`002R@200088P8000DN0P000a/2
00026@80008J0P0011`200057P8000LP0P001b4200067`8000DM0P000a/400026@8000<J0P0011`2
00047@8000DN0P0011d20004708000<J1Oooool1o`00007ooooo0Oooool00003ooooool0003o0000
00?o00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo0ol00002
ooooo`8000<K100011`200036`8000<J10000QT200036P8000@L0P001Ah400067`8000DN0P000a`2
00026P80008I0P000aX200047@8000HP0P00228200098`0300088@001Al000DO008000<K0P000QT2
00026P8000@L0P001b02000:908000dW0P0032H200098`8000HO0P000a/200026@8000<K0P001Ql2
000;9@80010Z0P004R`2000?:@8000XT0P001Ah200026P80008I0P001Ad2000:9080014[10005Rl2
000@:P8000TS0P0011`200026@8000<K0P001b42000>:@8001H_0P006S82000F;`8000lY0P001b42
00036`80008I00<000@M000:90002R@00P004b`2000I<P8001Xb0P0052d2000;9@8000DN0P000QT2
00036P8000HP0P003BL2000E;P8001Pa0P005Bl2000>:08000LQ0P000a/200026@8000@L0P002282
000>:0@001<]0P003bT200098`8000@M0P000QT200026P8000DN0P002B<2000=9`8000lY0P003BL2
00098`8000DN0P000aX200026@8000<K0P001Ql200088P<000XT0P00228200057P8000<K0P000QT2
00026P8000@L0P001Ah20007808000LQ0P001Ql200057@8000<K10000QT200036P8000@L0P0011d2
00057P8000@M0P0011`200036P?ooooo0ol00002ooooo`002Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool60004708000<K0P000aX4
00026@8000<J0P0011d200067`@000HP0P001Ah200047080008J0P000QT200036P8000@M0P001b42
00098`8000XT00<000TS00067`001Ql00P0011`200026@80008J0P0011d200088@8000`V0P003bT2
000>:08000/U0P001R0200036`80008I0P000a/20007808000dW0P004b`2000E;P80018/0P002bH2
00067`8000<J0P000QX200057P8000/U0P0052d4000J<P8001<]0P002RD200047@80008I0P000a/2
00088P80014[0P006S82000O=@8001/c0P004B/200088P8000<K0P000QT00`001Ad000`V000<9P02
000F;`8001he0P007cD2000G<08000dW0P001Ah200026@8000<J0P001b02000?:@8001Pa0P007C@2
000I<P80014[0P00228200036`80008I0P0011`200098`80010Z0P005Rl2000G<080018[0P002R@2
00057@80008I0P000QX200057P8000XT0P003bT2000A:`8000lY0P002RD200067`8000<J0P000QT2
00036`8000HO0P002B@3000<9P8000TS0P001Ql200036`80008I0P000QX20004708000HO0P002242
00088P8000LP0P001Ah200036`@0008I0P000aX2000470H000DN0P0011`200036`Gooooo0Ol00001
ooooo`7ooooo0009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02ooooo`H000@L0P000a/200036P@0008I0P000aX200047@8000HO10001R02
00057P8000@L0P000QX200026@8000<J0P0011d200078@8000TS0P002R@00`002B<000HO00067`02
00047080008I0P000QX200047@8000PQ0P0032H2000?:@8000hX0P002bD20006808000<K0P000QT2
00036`8000LP0P003BL2000C;08001D^0P004R`2000;9P8000HO0P000aX200026P8000DN0P002bD2
000D;@@001Xb0P004bd2000:9@8000@M0P000QT200036`8000PR0P004B/2000J<P8001le0P006c<2
000A:`8000PR0P000a/200026@0300057@0032H000`V008001H_0P007SD2000O=@8001L`0P003BL2
00057P80008I0P000aX20007808000lY0P006342000M=08001Tb0P004B/200088P8000<K0P000QT2
0004708000TS0P0042X2000F;`8001L`0P004R/2000:908000DM0P000QT200026P8000DN0P002R@2
000?:@80014[0P003bT2000:9@8000HO0P000aX200026@8000<K0P001Ql2000990<000`V0P002B<2
00067`8000<K0P000QT200026P8000@L0P001Ql200088@8000PR0P001b0200057P8000<K10000QT2
00036P8000@L1P001Ah20004708000<K1Oooool1o`00007ooooo0Oooool000Sooooo0_l00004oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool2000470@000@M0P000a`2
00036P@0008I0P000a/200047@8000HO10001b4200067`8000@L0P000aX200026@8000<J0P001Ah2
00088@8000XU0P002bD00`002R@000LP0007800200047080008I0P000QX200047@8000PR0P003BP2
000A:`80010Z0P0032H20007808000<K0P000QT200036`8000PQ0P003RT2000E;`8001Pa0P0052h2
000=9`8000HO0P000aX200026P8000DN0P003BL2000G<0@001he0P005Rl2000<9P8000DM0P000QT2
00036`8000TS0P004bd2000O=@8002@i0P007cH2000D;@8000TS0P000a/200026@0300057P003BL0
00dW008001Tb0P008cP2000T>@8001/c0P003bT200067`80008J0P000aX200088@80014[0P0073@2
000R=`8001he0P004bd200098`8000@L0P000QT20004708000XT0P004b`2000J<P8001/c0P0052h2
000<9P8000DN10000QX200067`8000/U0P004B/2000D;P80018/0P0032H20006808000<K0P000QT2
00036`8000HP0P002bD2000=:003000=9`002R@000XT008000HP0P000a/200026@80008J0P0011`2
0006808000PR0P002B<200088@8000DN0P000a/400026@8000<J0P0011d200057P8000HO0P001Ah2
00047@8000<K1Oooool1o`00007ooooo0Oooool000Wooooo00?o0000ooooooooool00oooool2o`00
00Gooooo00?o0000ooooooooool00_ooool2000470@000@M0P000a`200036P@0008I0P000a/20004
7@8000HO10001b4200067`8000@L0P000aX200026@8000<J0P001Ah200088@8000XU0P002bD00`00
2R@000LP0007800200047080008I0P000QX200047@8000PR0P003BP2000A:`80010Z0P0032H20007
808000<K0P000QT200036`8000PQ0P003RT2000E;`8001Pa0P0052h2000=9`8000HO0P000aX20002
6P8000DN0P003BL2000G<0@001he0P005Rl2000<9P8000DM0P000QT200036`8000TS0P004bd2000O
=@8002@i0P007cH2000D;@8000TS0P000a/200026@0300057P003BL000dW008001Tb0P008cP2000T
>@8001/c0P003bT200067`80008J0P000aX200088@80014[0P0073@2000R=`8001he0P004bd20009
8`8000@L0P000QT20004708000XT0P004b`2000J<P8001/c0P0052h2000<9P8000DN10000QX20006
7`8000/U0P004B/2000D;P80018/0P0032H20006808000<K0P000QT200036`8000HP0P002bD2000=
:003000=9`002R@000XT008000HP0P000a/200026@80008J0P0011`20006808000PR0P002B<20008
8@8000DN0P000a/400026@8000<J0P0011d200057P8000HO0P001Ah200047@8000<K1Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool20004708000DM0P0011d200047080
00<J10000QT200036`8000DM0P001b0200088P8000PQ0P001R0200047@8000<J0P000QT200036`80
00DN0P002B82000<9P8000dW00<000/U00078@001b400P0011`200026@80008J0P001Ad200098`80
00lY0P004bd2000B;08000dX0P00224200036`80008I0P000a`200088P80010Z0P006C42000L<`80
01L`0P003bT20007808000<J0P000QX200067`8000hX0P006S84000S>08001Tb0P003BL200057P80
008I0P000a/2000:908001H_0P0093T2000Z?08002@i0P005c02000:908000<L0P000QT00`001Ah0
00lY000?:@02000M=08002Tl0P00:S`2000O=P80014[0P001R0200026P8000<K0P002282000C;@80
020f0P009c/2000S>08001H_0P002RD200047080008I0P0011d2000;9@8001D^0P007SD2000O=@80
01P`0P003BP200067`80008J0P000aX200067`8000`W0P0052d2000G<08001@^0P003BP200078080
00<K0P000QT200036`8000LQ0P0032H3000?:@8000/V0P001b0200047080008I0P000QX200047@80
00LP0P002B<2000:908000PR0P001Ql200047080008J0P000QT200036`8000@M0P001Ql200068080
00HO0P0011d200036`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo
0P0011`200057@8000@M0P0011`200036P@0008I0P000a/200057@8000LP0P00228200088@8000HP
0P0011d200036P80008I0P000a/200057P8000TR0P0032H2000=9`03000;9@001b4000LQ008000@L
0P000QT200026P8000DM0P002B<2000?:@8001<]0P004R`2000=:08000PQ0P000a/200026@8000<L
0P002282000@:P8001Ta0P0073<2000G<08000lY0P001b0200036P80008J0P001Ql2000>:08001Xb
10008cP2000I<P8000dW0P001Ah200026@8000<K0P002R@2000F;`8002@i0P00:S`2000T>@8001L`
0P002R@200037080008I00<000DN000?:@003bT00P007C@2000Y?08002Xl0P007cH2000A:`8000HP
0P000QX200036`8000PR0P004bd2000P=P8002Lk0P008cP2000F;`8000XU0P0011`200026@8000@M
0P002bD2000E;P8001he0P007cD2000H<08000dX0P001Ql200026P8000<J0P001Ql2000<9`8001@]
0P005c02000D;P8000dX0P001b0200036`80008I0P000a/200078@8000`V0`003bT2000;9P8000LP
0P0011`200026@80008J0P0011d20007808000TS0P002R@200088P8000HO0P0011`200026P80008I
0P000a/200047@8000HO0P001R0200067`8000@M0P000a/5ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`8000@M0P001Ah200057@8000@L0P000aX400026@8000<K0P00
1Ah200078@8000TS0P0022820007808000@M0P000aX200026@8000<K0P001Ql200098`8000dW0P00
3RP00`0032H000PR00088P0200047@80008I0P000QX200057P8000XT0P004B/2000E;`8001D^0P00
3bT200088P8000@L0P000QT20004708000TS0P004R`2000L<`8001lf0P006S82000@:P8000LQ0P00
0aX200026P8000HO0P0042X2000M=08002Pk0P009c/2000L=08000lY0P001Al200026@8000<L0P00
2RD2000H<@8002Pk0P00<402000Y?08001Xb0P002bD200047080008I00<000HO000@:P0042X00P00
8CL2000_?`8003100P0093T2000C;@8000LQ0P000QX200036`8000TS0P005Bl2000T>@8002`n0P00
9c/2000I<P8000`V0P0011`200026@8000@M0P0032H2000H<080028g0P008cP2000K<`8000lY0P00
1R0200026P8000<J0P001R02000=:08001H_0P006S82000G<08000lY0P00224200036`80008I0P00
0a`200078@8000dW0`004B/2000=9`8000PQ0P0011`200026@80008J0P0011d200078@8000XT0P00
2bD200098`8000HP0P0011`200026P80008I0P000a/200057@8000HO0P001b0200067`8000DM0P00
0a/5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000@M0P001Ah2
00057@8000@L0P000aX400026@8000<K0P001Ah200078@8000TS0P0022820007808000@M0P000aX2
00026@8000<K0P001Ql200098`8000dW0P003RP00`0032H000PR00088P0200047@80008I0P000QX2
00057P8000XT0P004B/2000E;`8001D^0P003bT200088P8000@L0P000QT20004708000TS0P004R`2
000L<`8001lf0P006S82000@:P8000LQ0P000aX200026P8000HO0P0042X2000M=08002Pk0P009c/2
000L=08000lY0P001Al200026@8000<L0P002RD2000H<@8002Pk0P00<402000Y?08001Xb0P002bD2
00047080008I00<000HO000@:P0042X00P008CL2000_?`8003100P0093T2000C;@8000LQ0P000QX2
00036`8000TS0P005Bl2000T>@8002`n0P009c/2000I<P8000`V0P0011`200026@8000@M0P0032H2
000H<080028g0P008cP2000K<`8000lY0P001R0200026P8000<J0P001R02000=:08001H_0P006S82
000G<08000lY0P00224200036`80008I0P000a`200078@8000dW0`004B/2000=9`8000PQ0P0011`2
00026@80008J0P0011d200078@8000XT0P002bD200098`8000HP0P0011`200026P80008I0P000a/2
00057@8000HO0P001b0200067`8000DM0P000a/5ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02ooooo`8000@M10001Ah20004708000<K10000QT200036`8000DN0P0022440009
8`8000LQ0P001Ad200036P80008I0P000a/200067`8000XT0P003RP2000?:@03000=9`00228000PR
008000@M0P000QT200026P8000DN0P002bD2000B;08001P`0P005c02000@:P8000TS0P0011`20002
6@8000@L0P002R@2000D;P8001le0P008cP2000M=080018/0P00228200036P80008J0P001R02000A
:`80020g1000;3h2000P=P80010Z0P001Ql200026@8000@L0P002bH2000K<`8002dn0P00=T<2000^
?`8001dd0P0032H200047080008I00<000HO000B:`004R/00P0093T2000d@P8003I30P00:3/2000E
;P8000PQ0P000QX200036`8000TS0P005c02000Y?08003910P00;3h2000L=08000dW0P0011d20002
6@8000DM0P003BL2000J<P8002Hj0P009c/2000N=@80014[0P001b0200026P8000<J0P001R02000?
:@8001Pa0P007C@2000I<P80014[0P00228200036`80008I0P0011`200088P8000hX0`004R`2000>
:08000PR0P0011`200026@80008J0P001Ad200088P8000/U0P0032H2000:908000LQ0P0011`20002
6P80008I0P000a/200057@8000HP0P001b420007808000DN0P000a`5ooooo`7o00000Oooool1oooo
o`005_ooool00ol0003oooooooooo`02ooooo`8000@M10001Ah20004708000<K10000QT200036`80
00DN0P00224400098`8000LQ0P001Ad200036P80008I0P000a/200067`8000XT0P003RP2000?:@03
000=9`00228000PR008000@M0P000QT200026P8000DN0P002bD2000B;08001P`0P005c02000@:P80
00TS0P0011`200026@8000@L0P002R@2000D;P8001le0P008cP2000M=080018/0P00228200036P80
008J0P001R02000A:`80020g1000;3h2000P=P80010Z0P001Ql200026@8000@L0P002bH2000K<`80
02dn0P00=T<2000^?`8001dd0P0032H200047080008I00<000HO000B:`004R/00P0093T2000d@P80
03I30P00:3/2000E;P8000PQ0P000QX200036`8000TS0P005c02000Y?08003910P00;3h2000L=080
00dW0P0011d200026@8000DM0P003BL2000J<P8002Hj0P009c/2000N=@80014[0P001b0200026P80
00<J0P001R02000?:@8001Pa0P007C@2000I<P80014[0P00228200036`80008I0P0011`200088P80
00hX0`004R`2000>:08000PR0P0011`200026@80008J0P001Ad200088P8000/U0P0032H2000:9080
00LQ0P0011`200026P80008I0P000a/200057@8000HP0P001b420007808000DN0P000a`5ooooo`7o
00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000DM10001Ah200047@8000<K
10000QT200036`8000HO0P002284000:908000PQ0P001Ad200036P80008I0P000a/20006808000/U
0P003bT2000A:`03000>:0002B<000TS008000DM10000QX200057`8000`V0P0052h2000J<P8001Ta
0P004R`20009908000@L0P000QT20004708000XT0P005Rl2000R>08002Lk0P008CL2000D;@8000PR
0P000a/200026P8000LP0P004b`2000T>@8003910P00<D42000S>080018/0P001R0200026@8000@L
0P0032H2000N=@8003910P00?4H2000d@P80020f0P003BP200047080008I00<000HP000C;@004bd0
0P00:3/2000jA@8003a60P00;Ch2000G<08000PR0P000aX200036`8000XT0P006S82000]?P8003Q4
0P00<T42000P=P8000hX0P001Ad200026@8000DM0P003RP2000L=08002Xl0P00;3d2000Q=`80018/
0P001b4400036P8000LP0P0042X2000J<P80020f0P0073@2000C;08000TS0P0011`200026@8000@L
0P002282000?:@<001@^0P003bT200098`8000@M0P000QT200026P8000DM0P002282000<9P8000dW
0P002bD200078@8000@M0P000QX200026@8000<K0P001Ah20007808000PQ0P001b4200057P8000@L
1Oooool1o`00007ooooo0Oooool001Kooooo0_l00003ooooo`8000DM10001Ah200047@8000<K1000
0QT200036`8000HO0P002284000:908000PQ0P001Ad200036P80008I0P000a/20006808000/U0P00
3bT2000A:`03000>:0002B<000TS008000DM10000QX200057`8000`V0P0052h2000J<P8001Ta0P00
4R`20009908000@L0P000QT20004708000XT0P005Rl2000R>08002Lk0P008CL2000D;@8000PR0P00
0a/200026P8000LP0P004b`2000T>@8003910P00<D42000S>080018/0P001R0200026@8000@L0P00
32H2000N=@8003910P00?4H2000d@P80020f0P003BP200047080008I00<000HP000C;@004bd00P00
:3/2000jA@8003a60P00;Ch2000G<08000PR0P000aX200036`8000XT0P006S82000]?P8003Q40P00
<T42000P=P8000hX0P001Ad200026@8000DM0P003RP2000L=08002Xl0P00;3d2000Q=`80018/0P00
1b4400036P8000LP0P0042X2000J<P80020f0P0073@2000C;08000TS0P0011`200026@8000@L0P00
2282000?:@<001@^0P003bT200098`8000@M0P000QT200026P8000DM0P002282000<9P8000dW0P00
2bD200078@8000@M0P000QX200026@8000<K0P001Ah20007808000PQ0P001b4200057P8000@L1?oo
ool2o`0000;ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P001Ah200067`8000DN0P0011d2
00036`@0008I0P0011`200067`8000TS0P002bD2000:9@8000PR0P001Ah200036P80008I0P000a/2
0007808000`V0P004B/2000B;003000?:@002R@000XT008000DN10000QX200067`8000dW0P005Rl2
000M=08001/c0P0052d2000:908000@L0P000QT20004708000/U0P006342000V>P8002/m0P0093T2
000E;`8000TS0P000a/200026P8000LQ0P0052h2000X>`@003M30P009c/2000C;@8000LP0P000QT2
0004708000dW0P0083L2000gA08004=90P00>TD2000S>08000hY0P0011d200026@03000780005Bh0
01D^008002`n0P00@DP20013B@8003910P006S8200098`8000<J0P000a/2000;9@8001`c0P00<D42
000nA`8003M30P008cP2000?:@8000DN0P000QT200057P8000lY0P007cH2000^?`8003100P009CT2
000D;P8000PR10000aX200078@80014[0P007C@2000S>08001lf0P0052h2000:908000@L0P000QT2
0004708000TS0P0042X3000F;`80014[0P002R@200047@80008I0P000QX200057P8000TS0P003BL2
000>:08000`V0P00228200047@80008J0P000QT200036`8000DN0P001b4200088P8000LQ0P001Ql2
000470Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P001Ah20006
7`8000DN0P0011d200036`@0008I0P0011`200067`8000TS0P002bD2000:9@8000PR0P001Ah20003
6P80008I0P000a/20007808000`V0P004B/2000B;003000?:@002R@000XT008000DN10000QX20006
7`8000dW0P005Rl2000M=08001/c0P0052d2000:908000@L0P000QT20004708000/U0P006342000V
>P8002/m0P0093T2000E;`8000TS0P000a/200026P8000LQ0P0052h2000X>`@003M30P009c/2000C
;@8000LP0P000QT20004708000dW0P0083L2000gA08004=90P00>TD2000S>08000hY0P0011d20002
6@03000780005Bh001D^008002`n0P00@DP20013B@8003910P006S8200098`8000<J0P000a/2000;
9@8001`c0P00<D42000nA`8003M30P008cP2000?:@8000DN0P000QT200057P8000lY0P007cH2000^
?`8003100P009CT2000D;P8000PR10000aX200078@80014[0P007C@2000S>08001lf0P0052h2000:
908000@L0P000QT20004708000TS0P0042X3000F;`80014[0P002R@200047@80008I0P000QX20005
7P8000TS0P003BL2000>:08000`V0P00228200047@80008J0P000QT200036`8000DN0P001b420008
8P8000LQ0P001Ql2000470Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;o
oooo0P001Ah400067`8000@M0P000a/200026@80008J0P0011`20006808000TS0P002bH2000;9@80
00PR0P001Ah200036P80008I0P000a/200078@8000dW0P004R`2000D;@03000@:P002R@000XT0080
00DN0P000QX200036P8000HO0P003RP2000H<@8001lf0P007SD2000E;P8000/U0P0011d200026@80
00@M0P0032H2000J<P8002Tl0P00;cl2000W>`8001L`0P002B@200036`80008J0P002242000F;`80
02/m1000?4H2000[?@8001D^0P001b0200026@8000@L0P003RP2000S>08003e60P00BD`2000oB080
02Hj0P003bX200047@80008I00<000LP000F;`005Rl00P00<4020017B`8004Y<0P00=d<2000L<`80
00TT0P000aX200036`8000/U0P007SD2000f@`8004A:0P00?DH2000V>P80014[0P001Ah200026@80
00DN0P003bX2000Q=`8003910P00=D82000X>`8001H_0P00228400036P8000LQ0P004R`2000O=@80
02Hj0P008SP2000F;`8000/U0P0011`200026@8000@L0P002B<2000A:`8001L`00<001Pa000B;000
4R`00P002RD200057P@0008J0P001Ah200098`8000dX0P003bT2000=9`8000TS0P001Ah200036P80
008I0P000a/200057P8000PQ0P002B<200088P8000HO0P0011`5ooooo`7o00000Oooool1ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`8000DN10001Ql200047@8000<K0P000QT200026P8000@L
0P001R0200098`8000/V0P002bD200088P8000DN0P000aX200026@8000<K0P001b42000=9`80018/
0P0052d00`0042X000XT000:900200057P80008J0P000aX200067`8000hX0P006342000O=P8001he
0P005Bh2000;9@8000@M0P000QT200047@8000`V0P006S82000Y?08002lo0P009c/2000G<08000TT
0P000a/200026P8000PQ0P005Rl2000[?@@003a60P00:cd2000E;P8000LP0P000QT20004708000hX
0P008cP2000mAP8004U<0P00?dP2000V>P8000lZ0P0011d200026@03000780005Rl001H_00800310
0P00Ad/2001:C08003M30P0073<20009908000<J0P000a/2000;9@8001he0P00=T<20014BP8003e6
0P009SX2000A:`8000DN0P000QT200057P8000lZ0P008CL2000b@@8003E20P00:3/2000F;`8000PR
10000aX200078@80018/0P007cD2000V>P80028h0P005Rl2000;9@8000@L0P000QT20004708000TS
0P004B/2000G<003000H<@004R`0018/008000XU0P001Ah400026P8000DN0P002B<2000=:08000lY
0P003BL200098`8000DN0P000aX200026@8000<K0P001Ah200088@8000TS0P00228200067`8000@L
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool200057P@000HO0P00
1Ad200036`80008I0P000QX20004708000LP0P002R@4000<9P8000TS0P001Ah200036P80008I0P00
0a/200078@8000dX0P004bd2000E;P03000B:`002bD000/U008000DN0P000QX200036P8000HP0P00
3bT2000J<P80028g0P0083H2000G<08000/V0P0011d200026@8000@M0P003BL2000L<`8002`n0P00
<d42000Z?@8001Ta0P002R@200036`80008J0P002282000G<08002lo1000@TT2000^?`8001L`0P00
1b4200026@8000@L0P003bT2000V>P8004990P00Cdh20015BP8002Tl0P004B/200047@80008I00<0
00LQ000H<00063000P00=482001=CP8004m>0P00?4H2000N=@8000XT0P000aX200036`8000`V0P00
83H2000kA@8004Y<0P00@TT2000Z?080018/0P001Ah200026@8000DN0P0042X2000T>@8003I30P00
>TD2000/?P8001Pa0P002B<400036P8000PQ0P004bd2000Q=`8002Tl0P009CT2000H<@8000/V0P00
11d200026@8000@L0P002B@2000B;08001Tb00<001Xb000D;@0052d00P002bD200057P@0008J0P00
1Ah2000:908000hY0P0042X2000>:08000TS0P001Ah200036P80008I0P000a/200057P8000PR0P00
2B<200088P8000HP0P0011`5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02
ooooo`8000DN10001Ql200057@8000<K0P000QT200026P8000@L0P001b02000:90@000`V0P002B<2
00057P8000<J0P000QT200036`8000LQ0P003BP2000C;@8001D^00<0018[000;9@002bD00P001Ah2
00026P8000<J0P001R02000?:@8001Xb0P008SL2000P=P8001L`0P002bH200047@80008I0P0011d2
000=9`8001`c0P00;3h2000c@@8002Xm0P006C42000:908000<K0P000QX200088P8001L`0P00;cl4
0012B@8002ho0P005c0200078@80008I0P0011`2000?:@8002Hj0P00@TT2001?CP8004E:0P00:C`2
000A:`8000@M0P000QT00`001b4001P`000H<002000d@P8004e>0P00Cdh2000lAP8001he0P002R@2
00036P8000<K0P0032H2000P=P8003]50P00BT`20012B@8002Xl0P004R`200057P80008I0P001Ah2
000@:P8002@i0P00=T<2000jA@8002`n0P00634200098`@000<J0P002242000C;@80024g0P00:C`2
000U>@8001Pa0P002bH200047@80008I0P0011`200099080018/0P006C800`006S8001@]000D;@02
000;9@8000DN10000QX200057P8000XT0P003RT2000@:P8000hX0P002B<200057P8000<J0P000QT2
00036`8000DN0P00228200098`8000PR0P001R02000470Gooooo0Ol00001ooooo`7ooooo000Foooo
o`03o`000?oooooooooo00;ooooo0P001Ql20006808000HO0P001Ad200036`80008I0P000QX20004
708000LQ0P002bD4000=9`8000TS0P001Ql200036P80008I0P0011`200088@8000hX0P005Bh2000G
<003000C;00032H000`V008000DN0P000QX200036P8000LP0P0042X2000L<`8002@i0P008cP2000H
<@8000`V0P0011d200026@8000@M0P003BP2000N=@8003100P00>4@2000^?`8001/c0P002bD20003
6`80008J0P002282000I<@8003=11000Ad/2000b@@8001Pa0P00224200026@8000@M0P0042X2000Y
?08004Q<0P00DTd2001;C@8002dn0P004R`200057@80008I00<000LQ000I<P006C800P00>4@2001A
C@80059=0P00@DP2000Q=`8000/U0P000aX200036`8000`W0P008cP20010B08004m>0P00B4`2000]
?P8001<]0P001Ql200026@8000DN0P004B/2000W>P8003]50P00?dL2000`@08001Xb0P002R@20003
6`8000<J0P002282000D;P8002@i0P00;Ch2000X>`8001Xb0P0032L200047@80008I0P0011`2000:
908001<]0P006c<00`0073<001D_000E;`02000<9P8000DN10000QX200057P8000XT0P003bT2000A
:`8000lY0P002R@200057P8000<J0P000QT200036`8000HO0P002282000:908000TS0P001b020004
7@Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P001Ql200068080
00HO0P001Ad200036`80008I0P000QX20004708000LQ0P002bD4000=9`8000TS0P001Ql200036P80
008I0P0011`200088@8000hX0P005Bh2000G<003000C;00032H000`V008000DN0P000QX200036P80
00LP0P0042X2000L<`8002@i0P008cP2000H<@8000`V0P0011d200026@8000@M0P003BP2000N=@80
03100P00>4@2000^?`8001/c0P002bD200036`80008J0P002282000I<@8003=11000Ad/2000b@@80
01Pa0P00224200026@8000@M0P0042X2000Y?08004Q<0P00DTd2001;C@8002dn0P004R`200057@80
008I00<000LQ000I<P006C800P00>4@2001AC@80059=0P00@DP2000Q=`8000/U0P000aX200036`80
00`W0P008cP20010B08004m>0P00B4`2000]?P8001<]0P001Ql200026@8000DN0P004B/2000W>P80
03]50P00?dL2000`@08001Xb0P002R@200036`8000<J0P002282000D;P8002@i0P00;Ch2000X>`80
01Xb0P0032L200047@80008I0P0011`2000:908001<]0P006c<00`0073<001D_000E;`02000<9P80
00DN10000QX200057P8000XT0P003bT2000A:`8000lY0P002R@200057P8000<J0P000QT200036`80
00HO0P002282000:908000TS0P001b0200047@Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`00
0?oooooooooo00;ooooo0P001Ql20007808000HP0P001Ah200036`80008I0P000QX20004708000LQ
0P002bD2000>:08000dX0P002R@200067`8000<K0P000QT20004708000PR0P003bT2000F;`8001Pa
00<001@^000<9P0032H00P001Ql200026P8000<J0P001b02000A:`8001he0P009c/2000V>P8001Xb
0P003BL200057@80008I0P0011d2000>:080020g0P00=482000lAP8003910P007C@2000;9@8000<K
0P000QX200098`8001/c0P00=d<4001>CP8003M30P006S8200088P80008I0P0011d2000A:`8002`n
0P00CTh2001EB`80051>0P00<D02000C;@8000DN0P000QT00`00228001/c000K<`02000mAP8005A<
0P00ET/20017B`8002<h0P002bH200036P8000<K0P003BL2000U>@8004E:0P00DTd2001>CP800351
0P005Bh200067`80008I0P001Ah2000B;08002Tl0P00@4P20014BP8003A20P0073@2000:908000<K
0P000aX200088P8001D^0P009SX2000`@08002`m0P0073@2000=9`8000DM0P000QT20004708000XT
0P0052h2000M=003000N=@005c0001L`008000dW0P001Ql400026P8000DN0P002bD2000@:P80018/
0P0042X2000:9@8000HO0P000aX200026@8000<K0P001Ql200098`8000XT0P002B<20007808000@M
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool200067`8000LP0P00
1R0200057P8000<K0P000QT200026P8000@L0P001b42000;9@8000hX0P003BP2000:908000HO0P00
0a/200026@8000@L0P002282000?:@8001H_0P0063400`0052h000`V000<9P0200067`80008J0P00
0aX200078080014[0P007SD2000W>`8002Hj0P006S82000=9`8000DM0P000QT200047@8000hX0P00
83L2000d@P8003a60P00<T42000M=08000/U0P000a/200026P8000TS0P006c<2000g@`@004i>0P00
=d<2000J<P8000PR0P000QT200047@80014[0P00;3h2001>CP8005E;0P00D4h2000a@08001<]0P00
1Ah200026@0300088P006c<001/c008003e60P00E4`2001FB`8004M;0P008cP2000;9P8000<J0P00
0a/2000=9`8002Di0P00ADX2001BC@8004i>0P00<D42000E;P8000HO0P000QT200057P80018/0P00
:C`20010B08004A:0P00=482000L=08000XT0P000a/200036P8000PR0P005Bh2000V>P8003100P00
;3d2000L=08000dW0P001Ad200026@8000@L0P002R@2000D;P8001dd00<001he000G<0005c000P00
3BL200067`@0008J0P001Ah2000;9@80010Z0P004R`2000@:P8000XU0P001Ql200036P80008I0P00
0a/200067`8000TS0P002R@200098`8000LP0P0011d5ooooo`7o00000Oooool1ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`8000HO0P001b420007808000DN0P000a/200026@80008J0P0011d2
00088@8000`V0P003bT2000>:08000XU0P001Ql200036`80008I0P0011`200088P80010Z0P006302
000J<P03000E;`003BL000dW008000HO0P000QX200036P8000LQ0P004R`2000P=P8002Xm0P00:C`2
000L=08000hX0P001Ad200026@8000DM0P003bT2000S>08003Q40P00@DP2000f@`8001lf0P0032H2
00036`80008J0P002B<2000M=08003]61000DDd2000kA@8001`c0P00228200026@8000@M0P004R`2
000`@080055=0P00F4T2001CC08003E20P0052h200057P80008I00<000PR000M=0007C@00P00@TT2
001GBP8005U90P00CDh2000V>P8000`V0P000aX200036`8000hX0P00:3/2001:C@8005E;0P00DDd2
000f@`8001H_0P001Ql200026@8000DN0P004bd2000/?P8004E:0P00BT`2000iA08001he0P002bD2
00036`8000<J0P002282000F;`8002Tl0P00=482000_?`8001le0P003RP200057P80008I0P0011`2
000;9@8001D_0P007cH00`0083H001Ta000I<@02000>:08000HO10000QX200057P8000/U0P004B/2
000C;@80014[0P002bD200067`8000<J0P000QT200036`8000HO0P002B<2000;9@8000XT0P001b42
00057@Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P001Ql20007
8@8000LP0P001Ah200036`80008I0P000QX200047@8000PQ0P0032H2000?:@8000hX0P002RD20006
7`8000<K0P000QT20004708000PR0P0042X2000H<08001Xb00<001D_000=9`003BL00P001Ql20002
6P8000<J0P001b42000B;080020f0P00:Sd2000Y?08001`d0P003RP200057@80008I0P001Ad2000?
:@8002<h0P00>4@20011B08003I30P007cH2000<9P8000<K0P000QX200098`8001dd0P00>dH4001A
C@8003]50P0073<200088P80008I0P0011d2000B;08003100P00DDd2001HB@8005=<0P00=D82000D
;P8000DN0P000QT00`00228001dd000M=0020012B@8005M:0P00FDT2001=CP8002Hj0P0032H20003
6P8000<K0P003RP2000X>`8004Y=0P00ED/2001AC@8003I30P005Rl200067`80008I0P001Ah2000C
;@8002`n0P00ADX2001:C08003U40P007SD2000;9@8000<K0P000aX200088P8001H_0P00:C`2000d
@P8002lo0P007cD2000>:08000DN0P000QT20004708000/U0P005Bl2000O=P03000P=P006C4001Ta
008000hX0P001Ql400026P8000DN0P002bD2000A:`8001<]0P004B/2000;9@8000HO0P000aX20002
6@8000<K0P001Ql200098`8000/U0P002R@200078@8000DM1Oooool1o`00007ooooo0Oooool001Ko
oooo0_l00003ooooo`8000HP0P001b420007808000DN0P000a/200026@80008J0P0011d200088P80
00dW0P0042X2000?:@8000/U0P001R0200036`80008I0P0011`200098`80014[0P006C42000L<`03
000G<0003RP000hX008000HO0P000QX200036P8000PQ0P004bd2000R>08002dn0P00;3d2000N=@80
00hY0P001Ah200026@8000DN0P0042X2000U>P8003e60P00AT/2000jA@80024g0P0032L200036`80
00<J0P002R@2000O=P8004181000E4`2000oB08001he0P002B<200026@8000@M0P004bd2000d@P80
05A<0P00G4L2001FB`8003U40P005Rl200057P80008I00<000PR000O=P007cH00P00Ad/2001JB080
05a70P00D4h2000Y?08000dW10000a/2000>:08002Xm0P00Cdh2001HB@8005A<0P00>TD2000H<@80
00HP0P000QT200067`8001@^0P00;cl2001:C08004m>0P00?DL2000Q=`8000`V0P000a/200036P80
00TR0P006302000/?@8003Q40P00<d42000Q=`8000lY0P001Ah200026@8000@L0P002bD2000G<080
024g00<002<h000K<P006c800P003bT20006808000<J0P000QX200057P8000/V0P004R`2000E;P80
018/0P0032H200067`8000<K0P000QT200036`8000HO0P002B<2000;9@8000XU0P00224200057PCo
oooo0_l00002ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000HP0P001b420007808000DN
0P000a/200026@80008J0P0011d200088P8000dW0P0042X2000?:@8000/U0P001R0200036`80008I
0P0011`200098`80014[0P006C42000L<`03000G<0003RP000hX008000HO0P000QX200036P8000PQ
0P004bd2000R>08002dn0P00;3d2000N=@8000hY0P001Ah200026@8000DN0P0042X2000U>P8003e6
0P00AT/2000jA@80024g0P0032L200036`8000<J0P002R@2000O=P8004181000E4`2000oB08001he
0P002B<200026@8000@M0P004bd2000d@P8005A<0P00G4L2001FB`8003U40P005Rl200057P80008I
00<000PR000O=P007cH00P00Ad/2001JB08005a70P00D4h2000Y?08000dW10000a/2000>:08002Xm
0P00Cdh2001HB@8005A<0P00>TD2000H<@8000HP0P000QT200067`8001@^0P00;cl2001:C08004m>
0P00?DL2000Q=`8000`V0P000a/200036P8000TR0P006302000/?@8003Q40P00<d42000Q=`8000lY
0P001Ah200026@8000@L0P002bD2000G<080024g00<002<h000K<P006c800P003bT20006808000<J
0P000QX200057P8000/V0P004R`2000E;P80018/0P0032H200067`8000<K0P000QT200036`8000HO
0P002B<2000;9@8000XU0P00224200057PGooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oo
oooooooo00;ooooo0P001b0200088@8000LQ0P001Ah200036`80008I0P000QX200047@8000PR0P00
3BL4000@:P8000`V0P001R0200036`80008I0P0011`200098`80018/0P006c<2000N=@03000H<@00
3RT000hY008000HP0P000QX200036P8000PR0P0052h2000U>@8003500P00;cl2000P=P8000lY0P00
1Ah200026@8000DN0P004B/2000X>`8004990P00C4d2000nA`8002<h0P003BL200036`8000<J0P00
2R@2000Q=`8004E:1000ETX20014BP80020f0P002B<200026@8000DM0P0052h2000hA08005M:0P00
Gd@2001IB@8003e60P005c0200057P80008I00<000TS000Q=`008CL00P00CDh2001MAP8005m40P00
Dd`2000/?P8000hX10000a/2000?:@8002dn0P00DTd2001KA`8005M:0P00?TL2000J<P8000LP0P00
0QT200067`8001D_0P00<d42001?CP80059=0P00@TT2000S>08000`W0P000a/200036P8000TS0P00
6C42000^?`8003a60P00=d<2000T>@80010Z0P001Ah200026@8000@L0P002bH2000H<@8002<h00<0
02Di000L=00073@00P0042X20007808000<J0P000QX200067`8000`V0P004b`2000F;`8001<]0P00
3BL20006808000<K0P000QT200036`8000HP0P002R@2000<9P8000/U0P00228200057PGooooo0Ol0
0001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P001b0200088@8000LQ0P001Ah2
00036`80008I0P000QX200047@8000PR0P003BL4000@:P8000`V0P001R0200036`80008I0P0011`2
00098`80018/0P006c<2000N=@03000H<@003RT000hY008000HP0P000QX200036P8000PR0P0052h2
000U>@8003500P00;cl2000P=P8000lY0P001Ah200026@8000DN0P004B/2000X>`8004990P00C4d2
000nA`8002<h0P003BL200036`8000<J0P002R@2000Q=`8004E:1000ETX20014BP80020f0P002B<2
00026@8000DM0P0052h2000hA08005M:0P00Gd@2001IB@8003e60P005c0200057P80008I00<000TS
000Q=`008CL00P00CDh2001MAP8005m40P00Dd`2000/?P8000hX10000a/2000?:@8002dn0P00DTd2
001KA`8005M:0P00?TL2000J<P8000LP0P000QT200067`8001D_0P00<d42001?CP80059=0P00@TT2
000S>08000`W0P000a/200036P8000TS0P006C42000^?`8003a60P00=d<2000T>@80010Z0P001Ah2
00026@8000@L0P002bH2000H<@8002<h00<002Di000L=00073@00P0042X20007808000<J0P000QX2
00067`8000`V0P004b`2000F;`8001<]0P003BL20006808000<K0P000QT200036`8000HP0P002R@2
000<9P8000/U0P00228200057PGooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo
00;ooooo0P001b0200088P8000LQ0P001Al200036`80008I0P000QX200057@8000TS0P003RP4000A
:`8000`V0P001b0200036`80008I0P0011`2000:908001<]0P007C@2000P=P03000J<P003bT000lY
008000HP0P000QX200036P8000PR0P005Bl2000W>`8003A20P00<T42000R>080010Z0P001Ah20002
6@8000DN0P004R`2000[?@8004M;0P00D4h20013B@8002Hj0P003RP20003708000<J0P002bD2000S
>08004]=0P00FDP2001IB@8004U<0P008SL2000:9080008I0P001Ah2000E;`8003a60P00FTP2001R
@@8005a70P00@DT2000H<@8000HO0P000QT00`002B<002@i000T>@02001@CP8006130P00Hd42001F
B`8002lo0P003RT400036`80010Z0P00<D02001DC08005i40P00FTP20013B@8001`c0P001b420002
6@8000HO0P005Rl2000f@`80055=0P00ED`20018B`8002Hj0P003BP200036`8000<J0P002B<2000J
<P8003910P00@4P2000kA@8002Hj0P004B/200067`80008I0P0011`2000<9P8001Ta0P009CX00`00
:3/001le000O=@02000A:`8000LQ0P000aX200026P8000HO0P0032L2000D;@8001L`0P0052h2000=
:08000LP0P000a/200026@8000<K0P001R02000:908000`W0P0032H200088P8000DN1Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool200078@8000PR0P00224200067`80
00<K0P000QT200026P8000DM0P002B<2000?:@@0018/0P003BL20007808000<K0P000QT200047@80
00XT0P0052h2000N=@80028g00<001/c000@:P0042X00P001b0200026P8000<J0P002B<2000G<080
02Xl0P00>4@2000f@`8002@i0P004B/200057P80008I0P001Ah2000C;@8002ho0P00C4d2001BC@80
04Q;0P00:3/2000>:@8000<L0P000aX2000;9P8002Hj0P00Cdh4001LAP8004i>0P0093T2000:9080
008I0P001Ah2000G<08004180P00GDH2001V?@8005m40P00AT/2000J<P8000HO0P000QT00`002R@0
02Hj000V>P02001CC08006@o0P00ISd2001IB@8003910P003bT400036`80014[0P00=482001GBP80
06910P00GDH20018C08001de0P001b4200026@8000HO0P006302000jA@8005A<0P00EdX2001=CP80
02Tl0P003RP20003708000<J0P002B<2000L<`8003E20P00ADX20010B08002Tl0P004b`200067`80
008I0P0011`2000<9P8001Xb0P00:3/00`00:Sd0024g000Q=`02000B;08000LQ0P000aX200026P80
00HO0P003BL2000E;P8001Ta0P005Rl2000>:@8000LQ0P000a/200026@8000<K0P001b02000;9@80
00dW0P0032H200098`8000DN1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool200078@8000PR0P00224200067`8000<K0P000QT200026P8000DM0P002B<2000?:@@0018/
0P003BL20007808000<K0P000QT200047@8000XT0P0052h2000N=@80028g00<001/c000@:P0042X0
0P001b0200026P8000<J0P002B<2000G<08002Xl0P00>4@2000f@`8002@i0P004B/200057P80008I
0P001Ah2000C;@8002ho0P00C4d2001BC@8004Q;0P00:3/2000>:@8000<L0P000aX2000;9P8002Hj
0P00Cdh4001LAP8004i>0P0093T2000:9080008I0P001Ah2000G<08004180P00GDH2001V?@8005m4
0P00AT/2000J<P8000HO0P000QT00`002R@002Hj000V>P02001CC08006@o0P00ISd2001IB@800391
0P003bT400036`80014[0P00=482001GBP8006910P00GDH20018C08001de0P001b4200026@8000HO
0P006302000jA@8005A<0P00EdX2001=CP8002Tl0P003RP20003708000<J0P002B<2000L<`8003E2
0P00ADX20010B08002Tl0P004b`200067`80008I0P0011`2000<9P8001Xb0P00:3/00`00:Sd0024g
000Q=`02000B;08000LQ0P000aX200026P8000HO0P003BL2000E;P8001Ta0P005Rl2000>:@8000LQ
0P000a/200026@8000<K0P001b02000;9@8000dW0P0032H200098`8000DN1Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool00_ooool200078@8000TS0P00228200067`8000<L0P00
0QT200026P8000DN0P002R@2000@:P8001<]0P004b`2000=:08000LQ0P000a/200026@8000@M0P00
2bD2000F;`80020g0P0093T00`007C@0014[000A:`0200078080008J0P000aX200098`8001Pa0P00
;Ch2000lAP8003U50P009c/2000B;08000DO0P000QT200057`8001@^0P00<D02001@CP8005E;0P00
CDh2000[?@8000lY0P0011`200036P8000`V0P00:C`2001BC@8006130P00Gd@2001AC@8002Hj0P00
2RD200026@8000DN0P0063420015BP8006130P00JCT2001R@@8004]=0P006c<200067`80008I00<0
00XT000Y?000:C`00P00ED/2001W>`8006Xi0P00FdL2000f@`80010Z0P000a/200037080018[0P00
=d@2001JB08006Dn0P00H4<2001>CP8001lf0P00228200026@8000HP0P006C42000nA`8005M:0P00
FTP2001@C@8002`m0P003bT20004708000<J0P002R@2000M=08003Q40P00BT`20014BP8002`n0P00
52h200068080008I0P0011`2000=9`8001`c0P00:Sd00`00;Ch002<h000S>002000D;@8000PR0P00
0aX200026P8000HO0P003BL2000F;`8001Xb0P005c02000?:@8000PQ0P000a/200026@8000<K0P00
1b02000;9@8000hX0P003BL200098`8000HO1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000
ooooooooool00_ooool200078@8000TS0P00228200067`8000<L0P000QT200026P8000DN0P002R@2
000@:P8001<]0P004b`2000=:08000LQ0P000a/200026@8000@M0P002bD2000F;`80020g0P0093T0
0`007C@0014[000A:`0200078080008J0P000aX200098`8001Pa0P00;Ch2000lAP8003U50P009c/2
000B;08000DO0P000QT200057`8001@^0P00<D02001@CP8005E;0P00CDh2000[?@8000lY0P0011`2
00036P8000`V0P00:C`2001BC@8006130P00Gd@2001AC@8002Hj0P002RD200026@8000DN0P006342
0015BP8006130P00JCT2001R@@8004]=0P006c<200067`80008I00<000XT000Y?000:C`00P00ED/2
001W>`8006Xi0P00FdL2000f@`80010Z0P000a/200037080018[0P00=d@2001JB08006Dn0P00H4<2
001>CP8001lf0P00228200026@8000HP0P006C42000nA`8005M:0P00FTP2001@C@8002`m0P003bT2
0004708000<J0P002R@2000M=08003Q40P00BT`20014BP8002`n0P0052h200068080008I0P0011`2
000=9`8001`c0P00:Sd00`00;Ch002<h000S>002000D;@8000PR0P000aX200026P8000HO0P003BL2
000F;`8001Xb0P005c02000?:@8000PQ0P000a/200026@8000<K0P001b02000;9@8000hX0P003BL2
00098`8000HO1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool20008
8P8000TS0P00228200067`8000@L0P000QT200026P8000DN0P002R@2000@:P8001D^0P0052d2000>
:08000LQ0P000a/200026@8000@M0P002bD2000G<08002<h0P009SX00`007cH0018/000B;0020007
8@80008J0P000a/200098`8001Tb0P00<4020010B08003e70P00:C`2000C;08000HO0P000QT20006
7`8001D_0P00=D82001BC@8005Q:0P00D4h2000]?P80010Z0P0011`200036P8000dW0P00:cd2001D
C08006=00P00HT42001CC08002Pk0P002bD200026@8000DN0P006S82001:C08006=00P00KC@2001U
?P8004m>0P007C@200067`80008I00<000/U000[?@00:cd00P00F4T2001[=`8006dd0P00GT@2000j
A@80014[0P000a/20004708001</0P00>dH2001MAP8006Pj0P00I3l2001AC@80024g0P0022820002
6@8000HP0P006S820012B@8005U90P00GDH2001CC08002lo0P0042X20004708000<J0P002R@2000O
=@8003a60P00Cdh20019C08003100P005Bl200078080008I0P0011`2000=9`8001dd0P00;Ch00`00
<40002Hj000V>P02000E;P8000PR0P000aX200026P8000HO0P003RP2000G<08001`c0P006C42000@
:P8000PR0P000a/200026@8000<K0P001b02000;9P8000hX0P003BP2000:908000HO1Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool200088P8000TS0P00228200067`80
00@L0P000QT200026P8000DN0P002R@2000@:P8001D^0P0052d2000>:08000LQ0P000a/200026@80
00@M0P002bD2000G<08002<h0P009SX00`007cH0018/000B;00200078@80008J0P000a/200098`80
01Tb0P00<4020010B08003e70P00:C`2000C;08000HO0P000QT200067`8001D_0P00=D82001BC@80
05Q:0P00D4h2000]?P80010Z0P0011`200036P8000dW0P00:cd2001DC08006=00P00HT42001CC080
02Pk0P002bD200026@8000DN0P006S82001:C08006=00P00KC@2001U?P8004m>0P007C@200067`80
008I00<000/U000[?@00:cd00P00F4T2001[=`8006dd0P00GT@2000jA@80014[0P000a/200047080
01</0P00>dH2001MAP8006Pj0P00I3l2001AC@80024g0P00228200026@8000HP0P006S820012B@80
05U90P00GDH2001CC08002lo0P0042X20004708000<J0P002R@2000O=@8003a60P00Cdh20019C080
03100P005Bl200078080008I0P0011`2000=9`8001dd0P00;Ch00`00<40002Hj000V>P02000E;P80
00PR0P000aX200026P8000HO0P003RP2000G<08001`c0P006C42000@:P8000PR0P000a/200026@80
00<K0P001b02000;9P8000hX0P003BP2000:908000HO1Oooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool00_ooool200088P@000TS0P001R0200047080008I0P000aX200057P8000/U
0P004B/2000F;`8001D^0P003bT200088@8000<K0P000QT200047@8000`V0P006342000U>@8002Tl
00<0024g000C;0004b`00P001b4200026P8000<K0P002R@2000K<`8003=20P00ADX20012B@8002`m
0P0052d200067`80008I0P001Ql2000G<08003Q40P00ED/2001JB080059=0P00<402000A:`8000@L
0P000aX2000=:08002ho0P00EdX4001V?@8005I;0P00:cd2000;9@80008I0P001Ql2000K<`8004m>
0P00Ic`2001`;`8006Pj0P00DDd2000N=@8000HO0P000QT00`002bD002ho000^?`02001KA`8006hb
0P00LBl2001Q@P8003e70P004R/200036`8000@L0P0052d2000oB08006130P00K3H2001W?08005=<
0P0093T200088P80008I0P001b02000L<`8004I;0P00G4L2001P@`8005I;0P00<T42000A:`8000@L
0P000aX2000:9080020f0P00@4P2001AC@8004i>0P00<d42000G<08000LP0P000QT20004708000dX
0P007cD2000`@003000d@P00:3/002Pk008001H_0P002B<200036`80008J0P001Ql2000>:08001Pa
0P007C@2000J<P80014[0P002B8200037080008I0P000a/200078@8000`V0P003bT2000>:08000XU
0P001Ql5ooooo`7o00000Oooool1ooooo`005_ooool2o`0000?ooooo0P00228400098`8000HP0P00
11`200026@8000<J0P001Ah2000;9@80014[0P005Rl2000E;P8000lY0P00224200036`80008I0P00
11d2000<9P8001Pa0P009CT2000Y?003000Q=`004b`001</008000LQ0P000QX200036`8000XT0P00
6c<2000c@P8004E:0P00@TT2000/?@8001@]0P001Ql200026@8000HO0P005c02000hA08005E;0P00
FTP2001BC@8003100P004B/20004708000<J0P003BP2000^?`8005M:1000ISd2001FB`8002/m0P00
2bD200026@8000HO0P006c<2001?CP8006Ll0P00L2l2001X>P80055=0P007SD200067`80008I00<0
00/U000^?`00;Sl00P00FdL2001^<P80074_0P00HD82000mA`80018[0P000a/20004708001@]0P00
?dP2001P@`8006`f0P00Ic`2001CC08002@i0P00228200026@8000LP0P0073<20016B`8005a70P00
H4<2001FB`8003910P004B/20004708000<J0P002R@2000P=P8004180P00DDd2001>CP8003=10P00
5c0200078080008I0P0011`2000=:08001le0P00<4000`00=48002Pk000X>`02000F;`8000TS0P00
0a/200026P8000HO0P003RP2000H<@8001dd0P006S82000A:`8000TR0P000a`200026@8000<K0P00
1b42000<9P8000lY0P003RP2000:9@8000HO1?ooool2o`0000;ooooo000Fooooo`03o`000?oooooo
oooo00;ooooo0P002282000:908000TS0P001R0200047080008I0P000aX200057P8000/U0P004R`2
000G<08001H_0P003bX200088P8000<K0P000QT200057@8000`W0P006S82000W>`8002/m00<002<h
000D;@0052d00P00224200026P8000<K0P002R@2000M=08003M30P00BD`20016B`8002lo0P005Bh2
00067`80008I0P001Ql2000H<@8003a60P00EdX2001MAP8005E;0P00<d42000A:`8000@L0P000aX2
000>:08003910P00FTP2001Y>@8006Tj0P00F4T2000]?P8000`V0P000QT200067`8001dd0P00DDd2
001Z>08007@Y0P00K3H2001DC080020f0P001R0200026@03000<9P00<T400391008005i50P00LRd2
001d:@8006@o0P00@DP2000B;08000<K0P0011`2000E;P8004A:0P00Hd02001_<@8006Xh0P00ED/2
000V>P8000TS0P000QT20007808001dd0P00Bdd2001OA08006=00P00F4T2000f@`80018/0P0011`2
00036P8000/U0P008SP20014BP8005=<0P00DDd2000g@`8001Pa0P001b4200026@8000@M0P003RP2
000P=P80039100<003M3000[?@00:cd00P00634200098`8000<K0P000QX200067`8000lY0P006C82
000O=P8001`c0P004R`200098`8000@L0P000QT200036`8000LQ0P0032H2000@:P8000lY0P002bD2
000680Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P002282000:
908000TS0P001R0200047080008I0P000aX200057P8000/U0P004R`2000G<08001H_0P003bX20008
8P8000<K0P000QT200057@8000`W0P006S82000W>`8002/m00<002<h000D;@0052d00P0022420002
6P8000<K0P002R@2000M=08003M30P00BD`20016B`8002lo0P005Bh200067`80008I0P001Ql2000H
<@8003a60P00EdX2001MAP8005E;0P00<d42000A:`8000@L0P000aX2000>:08003910P00FTP2001Y
>@8006Tj0P00F4T2000]?P8000`V0P000QT200067`8001dd0P00DDd2001Z>08007@Y0P00K3H2001D
C080020f0P001R0200026@03000<9P00<T400391008005i50P00LRd2001d:@8006@o0P00@DP2000B
;08000<K0P0011`2000E;P8004A:0P00Hd02001_<@8006Xh0P00ED/2000V>P8000TS0P000QT20007
808001dd0P00Bdd2001OA08006=00P00F4T2000f@`80018/0P0011`200036P8000/U0P008SP20014
BP8005=<0P00DDd2000g@`8001Pa0P001b4200026@8000@M0P003RP2000P=P80039100<003M3000[
?@00:cd00P00634200098`8000<K0P000QX200067`8000lY0P006C82000O=P8001`c0P004R`20009
8`8000@L0P000QT200036`8000LQ0P0032H2000@:P8000lY0P002bD2000680Gooooo0Ol00001oooo
o`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P002B<2000:908000TS0P001b0200047080
008I0P000aX200067`8000`V0P004bd2000H<@8001L`0P0042X200088P8000<K0P000QT200057@80
00dW0P006c<2000Y?08002ho00<002Di000E;P005Bh00P00228200036P8000<K0P002bD2000N=@80
03Y50P00CTh2001;C@8003510P005Rl200067`80008I0P001R02000I<P8004180P00FTP2001P@`80
05M:0P00=T<2000B;08000@L0P000a/2000?:@8003E20P00GDH2001]=08006`e0P00FdP2000`@080
00`V0P000QT200067`8001lf0P00E4`2001]<`8007PS0P00Kc42001FB`80028g0P001R0200026@03
000=9`00=D8003E2008006520P00MRL2001h8P8006Lk0P00ADX2000C;@8000<K0P0011`2000F;`80
04Q<0P00ISd2001c:`8006hc0P00F4T2000X>`8000TS0P000QT200078@8001lf0P00Cdh2001R@@80
06Hm0P00FdL2000iA@8001<]0P0011`200036P8000/U0P0093T20018B`8005I;0P00Dd`2000kA@80
01Xb0P00224200026@8000@M0P003RT2000R>08003E300<003]5000^?`00;Sl00P006C82000:9080
00<K0P000QX20006808000lY0P006c<2000Q=`8001de0P004bd20009908000@L0P000QT200036`80
00LQ0P003BL4000@:P8000/V0P001b05ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooo
ooooo`02ooooo`8000TS0P002R@200098`8000LP0P0011`200026@8000<J0P001Ql2000<9P8001<]
0P006342000G<080010Z0P00228200036`80008I0P001Ad2000=9`8001/c0P00:C`2000^?`03000U
>@005Bh001D^008000PR0P000aX200036`8000/U0P007SD2000jA@8004i>0P00Bdd2000a@@8001H_
0P001Ql200026@8000HP0P006C820010B08005Y80P00H4<2001GBP8003I30P004R`20004708000<K
0P003bT2000e@P8005e60P00KC@2001/=@8005]80P00<402000<9P80008I0P001Ql2000O=P8005A<
0P00KC<2001h8`8006la0P00ET/2000R=`8000HP0P000QT00`003BL003E2000e@P02001Q@P8007HW
0P00N282001W>`8004E:0P004bd200036`8000@L0P005Rl20018C08006Hm0P00Lb/2001^<`8005Q9
0P00:3/200098`80008I0P001b42000O=P8004m>0P00HT42001V?@8005]70P00>DD2000C;@8000@L
0P000aX2000;9@8002@i0P00B4/2001FB`8005=<0P00>dD2000J<P8000PQ0P000QT200047@8000hY
0P008SP2000e@`03000kA@00;Sl002ho008001Tb0P002R@200036`80008J0P001R02000?:@8001/c
0P008CL2000M=@8001<]0P002B@200047080008I0P000a/200078@8000dW100042X2000;9P8000LP
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool200098`8000/U0P00
2R@20007808000@L0P000QT200036P8000HO0P0032H2000D;P8001Xb0P006342000A:`8000TR0P00
0a/200026@8000DN0P003RP2000M=08002`n0P00<D000`009c/001H_000F;`0200088P8000<J0P00
0a/2000;9P80020f0P00?TL2001@C@8004m>0P00=482000G<08000HP0P000QT20007808001/c0P00
ADX2001MAP8006=00P00FTP2000iA@8001<]0P0011`200036`80010Z0P00>D@2001OA080070_0P00
Kc42001MAP8003910P0032L200026@8000HP0P008CL2001FBP80074^0P00O1`2001b;08005Q90P00
8cP200078080008I00<000dW000iA000>D@00P00I3l2001j808007`K0P00JcL20019C08001@^0P00
0a/20004708001L`0P00CDh2001Y>@8007LU0P00LBh2001JB08002Xm0P002R@200026@8000LQ0P00
8CL2001AC@8006Dn0P00JCT2001NA@8003e60P0052d200047@8000<J0P002bH2000V>P8004a=0P00
F4T2001FB`8003m70P0073<200088P80008I0P0011d2000?:@8002@i0P00>D@00`00?TL00350000a
@002000K<`8000XU0P000a/200026P8000HP0P0042X2000L<`8002<h0P007cH2000E;P8000XT0P00
11`200026@8000<K0P001b42000=9`80014[0P0042X2000<9P8000LQ1Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool200098`8000/U0P002R@20007808000@L0P000QT2
00036P8000HO0P0032H2000D;P8001Xb0P006342000A:`8000TR0P000a/200026@8000DN0P003RP2
000M=08002`n0P00<D000`009c/001H_000F;`0200088P8000<J0P000a/2000;9P80020f0P00?TL2
001@C@8004m>0P00=482000G<08000HP0P000QT20007808001/c0P00ADX2001MAP8006=00P00FTP2
000iA@8001<]0P0011`200036`80010Z0P00>D@2001OA080070_0P00Kc42001MAP8003910P0032L2
00026@8000HP0P008CL2001FBP80074^0P00O1`2001b;08005Q90P008cP200078080008I00<000dW
000iA000>D@00P00I3l2001j808007`K0P00JcL20019C08001@^0P000a/20004708001L`0P00CDh2
001Y>@8007LU0P00LBh2001JB08002Xm0P002R@200026@8000LQ0P008CL2001AC@8006Dn0P00JCT2
001NA@8003e60P0052d200047@8000<J0P002bH2000V>P8004a=0P00F4T2001FB`8003m70P0073<2
00088P80008I0P0011d2000?:@8002@i0P00>D@00`00?TL00350000a@002000K<`8000XU0P000a/2
00026P8000HP0P0042X2000L<`8002<h0P007cH2000E;P8000XT0P0011`200026@8000<K0P001b42
000=9`80014[0P0042X2000<9P8000LQ1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool2000:908000/U0P002R@200078@8000@L0P000QT200036P8000HO0P003BL2000E
;`8001/c0P006S82000B;08000TS0P000a/200026@8000DN0P003RP2000N=@8002lo0P00=4800`00
:C`001L`000G<00200088P8000<J0P000a/2000<9P80028h0P00@TT2001CC080055=0P00=d@2000H
<08000HP0P000QT20007808001dd0P00BD`2001OA08006Hm0P00G4H2000lAP8001@]0P0011`20003
6`80014[0P00?DH2001R@@8007@Z0P00Lb`2001P@`8003E20P003BL200026@8000LP0P008cP2001I
B@8007DX0P00P1@2001f9`8005Y80P009CT200078080008J00<000hX000mAP00?DH00P00Ic/2001n
6@80080D0P00KS<2001>CP8001D^0P000a/20004708001Pa0P00D4h2001/=@8007XO0P00M2T2001M
AP8002dn0P002R@200026@8000LQ0P008cP2001CC08006Pk0P00KCD2001P@`8004580P005Bh20004
7@8000<J0P0032H2000X>`8004m>0P00FdP2001HB@8004=90P007C@200088P80008I0P0011d2000?
:P8002Dj0P00?4H00`00@TT003A2000d@P02000M=08000/U0P000a/200026P8000HP0P0042X2000M
=08002Di0P008CL2000F;`8000/U0P0011`200026@8000<K0P002242000>:080018/0P004B/2000=
9`8000LQ1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000:9080
00/U0P002R@200078@8000@L0P000QT200036P8000HO0P003BL2000E;`8001/c0P006S82000B;080
00TS0P000a/200026@8000DN0P003RP2000N=@8002lo0P00=4800`00:C`001L`000G<00200088P80
00<J0P000a/2000<9P80028h0P00@TT2001CC080055=0P00=d@2000H<08000HP0P000QT200078080
01dd0P00BD`2001OA08006Hm0P00G4H2000lAP8001@]0P0011`200036`80014[0P00?DH2001R@@80
07@Z0P00Lb`2001P@`8003E20P003BL200026@8000LP0P008cP2001IB@8007DX0P00P1@2001f9`80
05Y80P009CT200078080008J00<000hX000mAP00?DH00P00Ic/2001n6@80080D0P00KS<2001>CP80
01D^0P000a/20004708001Pa0P00D4h2001/=@8007XO0P00M2T2001MAP8002dn0P002R@200026@80
00LQ0P008cP2001CC08006Pk0P00KCD2001P@`8004580P005Bh200047@8000<J0P0032H2000X>`80
04m>0P00FdP2001HB@8004=90P007C@200088P80008I0P0011d2000?:P8002Dj0P00?4H00`00@TT0
03A2000d@P02000M=08000/U0P000a/200026P8000HP0P0042X2000M=08002Di0P008CL2000F;`80
00/U0P0011`200026@8000<K0P002242000>:080018/0P004B/2000=9`8000LQ1Oooool1o`00007o
oooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000:908000`V0P002RD200078@8000@L
0P000QT200036P8000HO0P003BP2000F;`8001`d0P006c<2000C;08000TS0P000a`200026@8000DN
0P003bT2000P=P8003510P00=d<00`00:cd001Pa000H<@0200098`8000<J0P000a/2000<9`8002@i
0P00AT/2001EB`8005=<0P00>TD2000I<@8000HP0P000QT200078@8001he0P00CTh2001R@@8006Tj
0P00Gd@20010B08001@^0P0011`200036`80018/0P00@DP2001U?@8007LT0P00MRH2001R@@8003M4
0P003BL200026@8000LP0P009SX2001LA`8007PR0P00Q0`2001i8@8005e60P009cX200078080008J
00<000lY0011B000@DP00P00JSL200214@8008@<0P00LBl2001@CP8001H_0P000a/200047@8001Xb
0P00DTd2001`<08007hG0P00N2<2001P@`8002lo0P002R@200026@8000PQ0P0093T2001EB`8006/g
0P00L302001S@08004E:0P005Rl200047@8000<J0P0032H2000Z?080055=0P00GDH2001KB08004M;
0P007cH200098`80008I0P0011d2000@:P8002Lk0P00?dP00`00AT/003M4000gA002000O=@8000`V
0P000a/200026@8000HP0P004B/2000O=@8002Lj0P008cP2000G<08000/U0P0011d200026@8000<K
0P002282000>:08001</0P004R`2000=:08000PQ1Oooool1o`00007ooooo0Oooool001Kooooo00?o
0000ooooooooool00_ooool2000:908000`V0P002RD200078@8000@L0P000QT200036P8000HO0P00
3BP2000F;`8001`d0P006c<2000C;08000TS0P000a`200026@8000DN0P003bT2000P=P8003510P00
=d<00`00:cd001Pa000H<@0200098`8000<J0P000a/2000<9`8002@i0P00AT/2001EB`8005=<0P00
>TD2000I<@8000HP0P000QT200078@8001he0P00CTh2001R@@8006Tj0P00Gd@20010B08001@^0P00
11`200036`80018/0P00@DP2001U?@8007LT0P00MRH2001R@@8003M40P003BL200026@8000LP0P00
9SX2001LA`8007PR0P00Q0`2001i8@8005e60P009cX200078080008J00<000lY0011B000@DP00P00
JSL200214@8008@<0P00LBl2001@CP8001H_0P000a/200047@8001Xb0P00DTd2001`<08007hG0P00
N2<2001P@`8002lo0P002R@200026@8000PQ0P0093T2001EB`8006/g0P00L302001S@08004E:0P00
5Rl200047@8000<J0P0032H2000Z?080055=0P00GDH2001KB08004M;0P007cH200098`80008I0P00
11d2000@:P8002Lk0P00?dP00`00AT/003M4000gA002000O=@8000`V0P000a/200026@8000HP0P00
4B/2000O=@8002Lj0P008cP2000G<08000/U0P0011d200026@8000<K0P002282000>:08001</0P00
4R`2000=:08000PQ1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2
000:9@8000`V0P002bD200078@8000@L0P000QT200036P8000HP0P003RP2000H<08001he0P0073@2
000C;@8000TT0P0011`200026@8000DN0P0042X2000R=`8003A20P00>TD00`00;Sl001Ta000I<@02
00098`8000<J0P000a/2000=9`8002Hj0P00Bdd2001GBP8005E;0P00?TL2000J<P8000LP0P000QT2
00088@80020f0P00D4d2001U?P8006`f0P00HD820013B@8001D^0P0011`200036`8001</0P00ADX2
001Y>P8007/N0P00NR02001U?P8003Y50P003BP200026@8000LQ0P00:3/2001OA08007`K0P00R0<2
001m6`8005m40P00:3/200078080008J00<0010Z0015BP00ADX00P00KS<20026208008P30P00M2X2
001BC@8001L`0P000a/200047@8001/c0P00ED/2001c:`80088@0P00Nad2001R@@8003910P002bD2
00026@8000PR0P009SX2001HBP8006hc0P00Lb/2001V?@8004U<0P005c0200047@8000<J0P003BL2
000/?@8005=<0P00H4<2001MAP8004a=0P008CL200098`80008I0P0011d2000A:`8002Tl0P00@dT0
0`00Bdd003]5000kA@02000P=`8000`W0P000a`200026@8000LP0P004R/2000P=P8002Tl0P009CT2
000H<@8000`V0P0011d200026@8000<K0P002282000?:@@001<]0P003RP200088PGooooo0Ol00001
ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P002RD2000<9P8000/U0P001b420004
7080008I0P000aX20006808000hX0P006302000N=@8001`d0P004bd20009908000@L0P000QT20005
7P80010Z0P008SL2000d@P8003Y500<002ho000I<@006C400P002B<200036P8000<K0P003BL2000V
>P8004]=0P00EdX2001EB`8003i70P006S8200078080008I0P002242000P=P80051=0P00ICh2001/
=P8006520P00@dT2000E;P8000@L0P000a/2000C;08004E:0P00JCX2001k7P8007XP0P00ICh2000j
A@8000dX0P000QT200078@8002Pk0P00Gd@2001l6`8008P30P00OA/2001OA08002Pk0P001b020002
6P03000@:P00ADX004E:008006hc0P00QPP200280`8007@Z0P00DTd2000G<08000<K0P0011d2000K
<`8005E;0P00Lb/20022408007/M0P00HT42000b@@8000/U0P000QT200088P8002Hj0P00F4X2001^
<`8007<[0P00ISd20019C08001L`0P0011d200036P8000dW0P00;3d2001CC08006130P00GDH2001<
C@80024g0P002B<200026@8000@M0P004B/2000Y?08004=900<004]=000kA@00>dD00P0083L2000<
9`8000<L0P000QT200078080018[0P0083H2000Y?08002Di0P006342000<9P8000@M0P000QT20003
6`8000PR0P003bT4000C;@8000hX0P002285ooooo`7o00000Oooool1ooooo`005_ooool2o`0000?o
oooo0P002bD2000=9`8000/U0P00224200047080008I0P000aX20007808000lY0P006C42000O=P80
01he0P0052h2000:908000@L0P000QT200057`80010Z0P0093T2000gA08003e700<00310000J<P00
6S800P002B<200036P8000<K0P003RP2000X?08004m>0P00FTP2001GBP8004580P006c<200078080
008I0P002282000R>08005=<0P00J3X2001_<P8006A00P00Ad/2000F;`8000@L0P000a/2000D;@80
04Y<0P00K3H2001o5`8007dJ0P00Ic/2000mAP8000hX0P000QT200088@8002/m0P00HD8200205080
1X`00P00P1@2001Q@P8002Xl0P001b4200026P03000@:`00BT`004Y<0080074^0P00RP0200J<0080
07LU0P00E4`2000G<08000<K0P0011d2000M=08005M:0P00MbD200261`8007lF0P00ICh2000d@P80
00/U0P000QT200088P8002Tl0P00FTP2001a;P8007HU0P00JCT2001>CP8001Ta0P001Ad200036P80
00dW0P00;Sl2001FB`8006910P00H4<2001?CP8002<h0P002R@200026P8000@M0P004B/2000[?@80
04M;00<004m>000oA`00?dL00P008SP2000=9`8000@L0P000QT200078080018/0P008CL2000[?@80
02Lk0P006S82000<9`8000DM0P000QT200036`8000PR0P003bT2000D;P8001@]0P003bT200088PCo
oooo0_l00002ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000/U0P003BL2000;9@8000PQ
0P0011`200026@8000<J0P001b02000?:@8001Ta0P007cH2000N=@8001@^0P002R@200047080008I
0P001Al2000@:P8002@i0P00=d@2000mA`03000`@0006S8001Xb008000TS0P000aX200036`8000hX
0P00:3`2001?CP8005Y80P00EdX20011B08001/c0P001b0200026@8000PR0P008SP2001CC08006Pj
0P00Kc82001T@08004M;0P005Rl20004708000<K0P0052d2001:C08006`f0P00OaL2001m6P8006Lk
0P00?DH2000>:080008I0P002242000[?@8006520P00P1@200J<0080080D0P00HD82000Z?08000LQ
0P000QX00`0042/004Y<001:C002001a;P8008X00P06S002001g9@8005A<0P005c0200036`8000@M
0P007C@2001GBP8007LU0P00QPL2001o5P8006Dn0P00=482000;9@80008I0P002282000Y?08005Y8
0P00LBh2001f9@8006Ti0P00CTh2000I<@8000DM0P000aX2000=9`8002ho0P00ET/2001R@@800613
0P00Cdh2000S>08000XT0P000QX200047@80014[0P00:cd20017B`03001?CP00?dL003m70080028h
0P003BL200047080008I0P001b02000B;080024g0P00:cd2000W>`8001Xb0P0032L200057@80008I
0P000a/200088P8000lY0P0052h2000D;@8000lY0P002285ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`8000/U0P003BL2000<9P8000PR0P0011d200026@8000<J0P00
1b02000?:@8001Xb0P008CL2000O=P8001D^0P002R@200047080008I0P001Ql2000A:`8002Hj0P00
>TD20011B003000c@@006c<001/c008000XT0P000aX200036`8000hX0P00:cd2001AC@8005a70P00
FDP20014BP8001`d0P001b0200026@8000PR0P0093T2001EB`8006/g0P00LRd2001V?@8004Y<0P00
5c020004708000<K0P005Bh2001>CP8006la0P00PPl200204`8006Xh0P00@4P2000>:080008I0P00
2282000^?`8006@o0P00Q0`2012@008008@=0P00I402000/?@8000LQ0P000QX00`004B/004i>001>
CP02001d:@802Xh00P0@T002001j7`8005E;0P00634200036`8000DM0P007cD2001IB08007XO0P01
RP0200233P8006Lk0P00=d<2000;9P80008I0P002B<2000[?@8005e60P00M2T2001j808006`f0P00
D4h2000J<P8000DM0P000aX2000>:08003100P00F4X2001U?P8006910P00DDd2000U>@8000XT0P00
0QX200047@80018/0P00;Ch2001:C@03001AC@00@TT00499008002@i0P003RP200047080008I0P00
1b02000C;08002<h0P00;Ch2000Y?08001/c0P003BL200057@80008I0P000a/200088P80010Z1000
5Bh2000?:P8000TS1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2
000;9@8000dW0P0032H200088P8000@M0P000QT200036P8000LP0P003bT2000J<P80024g0P007cH2
000E;P8000XT0P0011`200026@8000HO0P004B/2000V>P8003Y50P00@DP00`00<d4001/c000K<`02
000:908000<J0P000a/2000>:08002/m0P00DDd2001LA`8005U80P00A4X2000L=08000LP0P000QT2
00088P8002@i0P00ED/2001[=`80078]0P00ISd2001:C08001L`0P0011`200036`8001D^0P00CTh2
001_<@80088?0P00P1<2001Z>08004180P003RP200026@8000PR0P00;Sl2001T?`8008@<0P0@T002
00243@8006A00P00;3d200078@80008J00<0014[001>CP00CTh00P00M2T200Z>008049000P00NQl2
001EB`8001Pa0P000a/200057@8001le0P00FDP2001j7`800HX00P00P`h2001W>`8003M30P002bH2
00026@8000TS0P00:cd2001MAP8007@Y0P00NR02001/=P80051>0P006S8200057@8000<J0P003RP2
000`@08005Q:0P00ICh2001R@@80055=0P009CT2000:9080008J0P0011d2000B;08002dn0P00BTd0
0`00DDd004990012B@02000T>@8000hX0P0011`200026@8000LP0P004b`2000S>08002dn0P00:C`2
000K<`8000dW0P001Ad200026@8000<K0P002282000@:P@001D^0P003bX200098`Gooooo0Ol00001
ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P0032H2000>:08000`V0P0022820004
7@80008I0P000aX200078@80010Z0P006c<2000S>080024g0P005Rl2000:9@8000@L0P000QT20006
7`80018/0P00:3/2000nA`8004A:00<003E3000L=00073@00P002R@200036P8000<L0P003bT2000]
?P8005=<0P00GTD2001LA`8004Q;0P007C@200078@80008I0P002B82000V>P8005M:0P00KS<2001e
:08006Tj0P00CTh2000G<08000@L0P000a/2000F;`80055=0P00LRd200261`8008@<0P00K3D20012
B@8000hY0P000QT200088P8003500P00Ic/200280`806i@00P00Q`D2001V?@8002dn0P001b420002
6P03000B;000DDd0055=008007PS0P0ETP0201ZD008007dI0P00EdX2000I<@8000<K0P001Ah2000Q
=`8005a70P00OQT200Z>008008H70P00JSP2000jA@8000`V0P000QT200098`8002dn0P00Gd@2001g
908007dI0P00Kc82001BC@8001/c0P001Ah200036P8000hX0P00<d42001JB08006Lk0P00ICh2001C
C08002Lk0P002RD200026P8000@M0P004R`2000_?`8004i>00<005==0016B`00AT/00P009cX2000>
:@8000@L0P000QT20007808001<]0P0093T2000_?`8002`m0P007C@2000>:08000DN0P000QT20003
6`8000PR0P0042X4000F;`80010Z0P002B<5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`8000`V0P003RP2000<9P8000PR0P0011d200026@8000<J0P001b42000@:P80
01/c0P008cP2000Q=`8001H_0P002RD200047080008I0P001Ql2000B;08002Pk0P00?TL20014BP03
000e@`0073@001`d008000XT0P000aX20003708000lY0P00;Ch2001CC08005i50P00G4L20018B`80
01dd0P001b4200026@8000TR0P009SX2001GBP8006hc0P00MBP2001Y>P8004i>0P005c0200047080
00<K0P005Rl2001AC@80078]0P00QPL20024308006`e0P00@TT2000>:@80008I0P002282000a@080
06Lk0P00R0<201^D008008L50P00ISd2000]?P8000LQ0P000QX00`004R`0055=001AC@02001h8`80
5I800P0JU002001m6@8005M:0P006C4200036`8000DN0P008CL2001LA`8007hI0P0:SP0200261`80
06Xh0P00>TD2000<9P80008I0P002B<2000]?P8005m40P00Mb@2001m6@8006lb0P00DTd2000K<`80
00DN0P000aX2000>:08003=10P00FTP2001W>`8006Dn0P00Dd`2000W>`8000XU0P000QX200047@80
018/0P00;cl2001>CP03001CC@00AT/004I;008002Lj0P003RT200047080008I0P001b02000C;@80
02@i0P00;cl2000/?@8001dd0P003RP200057P80008I0P000a/200088P80010Z10005Rl2000@:P80
00TS1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000<9P8000hX
0P003BL200088P8000@M0P000QT200036P8000LQ0P0042/2000L=08002@i0P008SP2000G<08000/U
0P0011`200026@8000HO0P004b`2000Z?08004580P00B4/00`00>4@001he000N=@02000:908000<J
0P0011`2000@:P8003100P00ED/2001Q@P8005i50P00Bdd2000N=@8000LQ0P000QT200098`8002Pk
0P00FTP2001a;P8007PS0P00JcL2001?CP8001Pa0P0011`20003708001P`0P00Dd`2001e9`800HX0
0P00Q`@2001_<@8004E:0P003bT200026@8000TS0P00=482001Z=`801H`00P0VV00200::008006Pj
0P00;cl200078@80008J00<001@]001CC000Dd`00P00Nad2022F00809YP00P00P1<2001IB@8001Xb
0P000a/200057P80028h0P00GT@200214@805I800P01RP02001]=@8003a60P0032H200026@8000TS
0P00<402001Q@P8007/N0P00PA<2001b;@8005A<0P0073@200057P8000<J0P003bT2000e@`8005a7
0P00JSP2001W>`8005E;0P00:C`2000;9@80008J0P0011d2000C;@8003510P00D4h00`00ED`004Y=
001:C@02000Y?08000lY0P0011`200026@8000LQ0P0052d2000V>P8003910P00;Sl2000N=@8000hY
0P001Ah200026@8000<K0P002B<2000A:`@001L`0P004B/2000990Gooooo0Ol00001ooooo`7ooooo
000Fooooo`03o`000?oooooooooo00;ooooo0P0032H2000>:08000dW0P00228200047@80008I0P00
0aX200078@80010[0P0073@2000T>@80028h0P005c02000;9@8000@L0P000QT200067`8001</0P00
:S`20011B08004Q;00<003Q4000N=@007SD00P002R@200036P8000@L0P0042X2000`@08005E;0P00
HD82001NA@8004]=0P007SD200078@80008I0P002B<2000X>`8005Y80P00LBh2001h8`8006/g0P00
Cdh2000H<@8000@L0P000a`2000H<08005=<0P00MBL2006:008008L40P00Kc420015BP8000lY0P00
0QT200098`8003A20P00JSL200F<00809YP00P02RP02001X>P8002lo0P001b4200026P03000D;@00
Dd`005=<008007/M0P0PUP0202JH0080080C0P00FDT2000J<P8000<K0P001Ah2000R>08005i40P00
PA4201FB00800HX00P00KCD2000lAP8000`V0P000QT200098`8003100P00HD82001k7P80084C0P00
LRd2001DC08001`d0P001Ah200036P8000lY0P00=D<2001LA`8006Xh0P00Ic/2001EB`8002Tl0P00
2bD200026P8000@M0P004bd2000a@@80051>00<005E<001:C@00BTd00P00:C`2000?:@8000@L0P00
0QT200078@8001@]0P009SX2000b@@8002ho0P007SD2000>:@8000DN0P000QT200036`8000TS0P00
4B/4000G<080014[0P002B@5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02
ooooo`8000dW0P003bT2000=9`8000TS0P0011d200026@8000<K0P001b42000A:`8001he0P009SX2
000T>@8001Pa0P002bD200047080008I0P001Ql2000D;@8002`n0P00A4X2001<C@03000kA@007cH0
01lf008000XT0P000aX200047080010Z0P00<T42001GBP8006=00P00H4<2001?CP80020f0P001b42
00026@8000TS0P00:cd2001LA`8007@Z0P00Nah2001^<`80055=0P006C440004708001Ta0P00ED/2
001i8P802Xh00P03R`02001a;P8004Q;0P003bT200026@8000TS0P00=d@2001]<`803i000P0bW002
00^>008006Xh0P00<D0200078@8000<J00<001D^001EB`00ED/00P00OaH202bJ0080<Y`00P00Q0`2
001KA`8001/c0P000a/200057P8002Di0P00HD8200252P807iH00P09S@02001_<@8003m70P0032L2
00026@8000XT0P00<T42001T?`8007hH0P00Q0/2001d:@8005I;0P007CD200057P8000<J0P003bT2
000hA08005i50P00KC@2001Z>08005Q:0P00:cd2000;9P80008J0P0011d2000C;@8003A20P00DTd0
0`00ETX004i>001>CP02000[?@80010Z0P0011`200026@8000LQ0P005Bh2000X>`8003A20P00<402
000P=P8000lY0P001Ah200026@8000<K0P002B<2000A:`@001Pa0P004R`2000:90Gooooo0Ol00001
ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P003BL2000?:@8000dW0P002B<20004
7@80008I0P000a/200078@80014[0P007SD2000V>P8002@i0P006342000;9@8000@L0P000QT20006
7`8001@]0P00;3h20014BP8004a=00<003]5000O=P007cH00P002R@200036P8000@L0P0042X2000b
@@8005M:0P00Hd02001P@`8004m>0P0083H200078@80008I0P002B<2000[?@8005a70P00M2X2001k
7P8006hc0P00DDd2000I<@@000@L0P006C42001EB`8007TR0P0:SP0200>;0080074^0P00B4/2000?
:@80008I0P002B<2000gA08006dc0P0?T00203:L00802hh00P00JSP2000a@08000LQ0P000aX00`00
5Bh005E;001EB`02001o5P80;9X00P0bW0020024308005]70P006c<200036`8000DN0P009CT2001Q
@P8008D:0P0OUP0200V=008006la0P00?dL2000<9`80008I0P002R@2000b@@8006@o0P00OQP20024
2`8007@Y0P00ET/2000M=@8000DN0P000aX2000?:@8003Q40P00GTD2001]=08006Xh0P00F4X2000[
?@8000/V0P000QX200047@8001<]0P00=482001BC@03001FBP00CTh004i>008002/m0P0042X20004
7080008I0P001b42000E;P8002Pk0P00=482000`@080020f0P003bT200057P80008I0P000a/20009
8`80014[10006342000B;08000XT1Oooool1o`00007ooooo0Oooool000kooooo0ol00005ooooo`03
o`000?oooooooooo00;ooooo0P003BL2000?:@8000dX0P002B<200047@80008I0P000a/200088@80
018/0P007cH2000X>`8002Dj0P006C42000;9P8000@L0P000QT20006808001@^0P00;Sl20018C080
04m>00<003i7000P=P0083H00P002bD200036P8000@L0P004B/2000e@P8005U90P00ICd2001R@@80
051>0P008CL200078@80008I0P002R@2000]?P8005i50P00MbD2001n6080070`0P00DTd2000J<P@0
00@L0P006S82001GBP8007`L0P0CT@0200b>008007@Z0P00Bdd2000?:@80008I0P002R@2000kA@80
074_0P0JU00203nQ00804i400P00K3D2000b@@8000LQ0P000aX00`005Rl005Q:001HBP0200233P80
>Il00P0nX00200271P8005e60P006c<200036`8000DN0P009cX2001T@08008P20P0[VP0201:A0080
078]0P00@TT2000=9`80008I0P002R@2000e@P8006Hl0P00PA820027108007LT0P00F4X2000O=@80
00DN0P000aX2000@:P8003]50P00H4<2001_<@8006dd0P00FTP2000^?P8000`V0P000QX200057@80
01@^0P00=T<2001CC003001HB@00D4h0051>008002dn0P004B/200047@80008I0P001b42000E;`80
02Tl0P00=T<2000c@@80028g0P0042X200057P80008I0P000a/200098`80018/10006C42000B;080
00XT1Oooool1o`00007ooooo0Oooool000gooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00;ooooo0P003BL2000?:@8000dX0P002B<200047@80008I0P000a/200088@80
018/0P007cH2000X>`8002Dj0P006C42000;9P8000@L0P000QT20006808001@^0P00;Sl20018C080
04m>00<003i7000P=P0083H00P002bD200036P8000@L0P004B/2000e@P8005U90P00ICd2001R@@80
051>0P008CL200078@80008I0P002R@2000]?P8005i50P00MbD2001n6080070`0P00DTd2000J<P@0
00@L0P006S82001GBP8007`L0P0CT@0200b>008007@Z0P00Bdd2000?:@80008I0P002R@2000kA@80
074_0P0JU00203nQ00804i400P00K3D2000b@@8000LQ0P000aX00`005Rl005Q:001HBP0200233P80
>Il00P0nX00200271P8005e60P006c<200036`8000DN0P009cX2001T@08008P20P0[VP0201:A0080
078]0P00@TT2000=9`80008I0P002R@2000e@P8006Hl0P00PA820027108007LT0P00F4X2000O=@80
00DN0P000aX2000@:P8003]50P00H4<2001_<@8006dd0P00FTP2000^?P8000`V0P000QX200057@80
01@^0P00=T<2001CC003001HB@00D4h0051>008002dn0P004B/200047@80008I0P001b42000E;`80
02Tl0P00=T<2000c@@80028g0P0042X200057P80008I0P000a/200098`80018/10006C42000B;080
00XT1Oooool1o`00007ooooo0Oooool000Oooooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo
0ol00002ooooo`8000dX0P0042X2000>:08000TS0P0011d200026@8000<K0P002282000C;080024g
0P00:S`2000W>`8001Xb0P0032H200047080008I0P001b02000E;`8003100P00C4d2001@C@030010
B0008CL0024g008000/U0P000aX200047080018/0P00>4@2001KA`8006Pk0P00I3l2001BC@80028g
0P001b4200026@8000XT0P00<402001Q@P8007XO0P00PA42001c;08005A<0P006S840004708001`d
0P00FTP2001o5@807YD00P0DTP02001f9P8004e>0P003bX200026@8000XT0P00?dL2001d:P809IP0
0P1<Y@0201fE008006lb0P00=48200078@8000<J00<001L`001JB000FTP00P00QPH204NS0080Bj@0
0P00RP02001NA@8001`d0P000a/200067`8002Tl0P00ISd200J<0080=ih00P0LU@02001d:@8004E:
0P003BL200026@8000XU0P00>4@2001Y>@8008@;0P03R`02001j7`8005U80P0083H200057P8000<J
0P0042X2000mA`8006910P00LRd2001_<@8005a70P00<402000<9`80008J0P001Ad2000E;P8003Q4
0P00ED/00`00FTP0059=001BC@02000`@080014[0P0011d200026@8000LQ0P005Rl2000[?@8003U4
0P00=D<2000S>080014[0P001Ql200026@8000<K0P002B<2000B;0@001Xb0P004bd2000;9@?ooooo
0ol00002ooooo`004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0P00
3BP2000@:P8000hX0P002B<200047@80008I0P000a/200088P8001</0P008CL2000Z?08002Lk0P00
6S82000<9P8000@L0P000QT20007808001D_0P00<402001<C@80051=00<00418000Q=`008CL00P00
2bD200036P8000@L0P004R`2000hA08005]70P00J3/2001T?`80059=0P008SL200078@80008I0P00
2R@2000`@08006520P00NQl200214@8007</0P00E4`2000J<P@000@L0P0073@2001JB08007lE0P0N
U@0201BB008007HV0P00CDh2000?:P80008I0P002R@2000oA`8007@Z0P0UV00204bU00807ID00P00
Kc82000d@P8000LQ0P000aX00`005c0005Y8001JB00200261P80Aj<00P1;Y002002:008005i50P00
73@200036`8000HO0P00:C`2001V?@801X`00P0gWP0201bE008007@Y0P00ADX2000=9`80008I0P00
2RD2000hA08006Ti0P00Q0/200>;008007XO0P00FDP2000P=P8000DN0P000aX2000@:P8003e70P00
HT42001b;@8006la0P00G4L2000`@08000`W0P000QX200057@8001D^0P00>4@2001EB`03001JB000
DTd0059=008003100P004B/200047@80008I0P001b42000F;`8002/m0P00>D@2000e@`8002<h0P00
4B/200067`80008I0P000a/200098`80018/10006S82000C;@8000/U1Oooool1o`00007ooooo0Ooo
ool000gooooo1?l00005ooooo`03o`000?oooooooooo00;ooooo0P003RP2000@:P8000hY0P002B<2
00047@80008I0P000a/200088P8001<]0P008SP2000/?@8002Tl0P006c<2000<9P8000@L0P000QT2
0007808001H_0P00<d42001?CP80059=00<004=9000S>0008cP00P002bD200036P8000@L0P004b`2
000kA@8005e50P00JSP2001W?08005=<0P008cP200088@80008I0P002bD2000b@@8006=00P00OAT2
00242`8007DX0P00ED/2000K<`@000@L0P007SD2001LAP8008<>0P0XV@0201jE008007TR0P00Cdh2
000@:P80008I0P002bD20012B@8007LU0P0aW00205ZY00809YP00P00LBl2000e@`8000LQ0P000aX0
0`006C4005a6001LAP02006:0080EJL00P1IZ00200R=008006130P007C@200036`8000HO0P00:cd2
001Y>@803i000P13XP0202JH008007LU0P00Ad/2000=9`80008I0P002bD2000kA@8006`f0P00R0<2
00^>008007dJ0P00FdL2000Q=`8000DN0P000aX2000A:`8004180P00ICh2001e:080078]0P00GTD2
000b@@8000dW0P000QX200057@8001D_0P00>dD2001GBP03001LAP00E4`005A<008003910P004R`2
00047@80008I0P001b42000G<08002dn0P00?4H2000hA08002Dj0P004B/200067`80008I0P000a/2
00098`8001<]10006c<2000D;P8000/U1Oooool1o`00007ooooo0Oooool000gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`8000hX0P0042X2000>:@8000TS0P0011d20002
6@8000<K0P002282000C;@80028h0P00;3d2000Y?08001/c0P0032H200047080008I0P001b02000F
;`8003=10P00Cdh2001BC@030013B@008cP002<h008000/U0P000aX20004708001</0P00>dD2001M
A@8006Xh0P00Ic`2001CC08002<h0P00224200026@8000/U0P00<T42001S@08007dI0P00Q0/2001e
:08005E;0P006c<40004708001he0P00G4H200233P80:9T00P0NU@02001i8P8004m>0P0042X20002
6@8000/U0P00@TT2001g9@80<I`00P1JZ@0202JH0080074_0P00=D<200078@8000<J00<001Ta001L
AP00G4H00P01RP0205FW0080FJP00P08S@02001P@`8001dd0P000a/200067`8002/m0P00JCT200n@
0080@j800P0VV002001g9@8004M;0P003BL200026@8000/U0P00>dD2001/=P8008P30P0;SP02001m
6P8005]70P008CL200057P8000<J0P004B/20010B08006Dn0P00MBP2001b;@8005i50P00<T42000=
9`80008J0P001Ad2000E;`8003]50P00EdX00`00G4H005A<001DC002000b@@80018/0P0011d20002
6@8000LQ0P005c02000]?P8003a60P00>4@2000U>P80014[0P001Ql200026@8000<K0P002B<2000C
;@@001/c0P0052h2000;9@Gooooo0Ol00001ooooo`7ooooo000=ooooo`Go00001?ooool00ol0003o
ooooooooo`02ooooo`8000hY0P004B/2000?:@8000XT0P001Ad200026@8000<K0P002282000D;P80
02@i0P00;Sh2000Z?@8001`c0P0032L200047080008I0P001b02000G<08003E20P00D4d2001DC003
0016B`0093T002@i008000/V0P000aX20004708001@]0P00?TL2001OA08006de0P00JCX2001EB`80
02@i0P00224200026@8000/U0P00=D<2001U?@80080C0P00Q`@2001g908005M:0P006c<200047080
00@M0P007cH2001NA08008H70P0dW@0202NI008007/M0P00D4h2000@:P80008I0P002bH20017B`80
07XO0P0nX00206V]0080<9`00P00Lb`2000g@`8000LQ0P000aX00`006S8005m4001OA00200Z>0080
I:`00P1W[@0200n@008006920P007SD200036`8000HO0P00;Sl2001/=P806I@00P1AYP02032L0080
07TQ0P00BT`2000=:080008I0P002bH2000nA`8006hc0P03R`0201BB0080080D0P00GDH2000R>080
00DN0P000aX2000A:`8004=90P00Ic`2001g908007DY0P00H4<2000d@P8000dW0P000QX200057@80
01H_0P00?DH2001IB@03001NA000ET/005I;008003E20P004bd200057@80008I0P001b42000G<080
02ho0P00?TL2000jA@8002Lk0P004R`200067`80008I0P000a/200098`8001<]0P0073<2000L=080
01D^0P0032H5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000hY
0P004B/2000?:@8000XT0P001Ad200026@8000<K0P002282000D;P8002@i0P00;Sh2000Z?@8001`c
0P0032L200047080008I0P001b02000G<08003E20P00D4d2001DC0030016B`0093T002@i008000/V
0P000aX20004708001@]0P00?TL2001OA08006de0P00JCX2001EB`8002@i0P00224200026@8000/U
0P00=D<2001U?@80080C0P00Q`@2001g908005M:0P006c<20004708000@M0P007cH2001NA08008H7
0P0dW@0202NI008007/M0P00D4h2000@:P80008I0P002bH20017B`8007XO0P0nX00206V]0080<9`0
0P00Lb`2000g@`8000LQ0P000aX00`006S8005m4001OA00200Z>0080I:`00P1W[@0200n@00800692
0P007SD200036`8000HO0P00;Sl2001/=P806I@00P1AYP02032L008007TQ0P00BT`2000=:080008I
0P002bH2000nA`8006hc0P03R`0201BB0080080D0P00GDH2000R>08000DN0P000aX2000A:`8004=9
0P00Ic`2001g908007DY0P00H4<2000d@P8000dW0P000QX200057@8001H_0P00?DH2001IB@03001N
A000ET/005I;008003E20P004bd200057@80008I0P001b42000G<08002ho0P00?TL2000jA@8002Lk
0P004R`200067`80008I0P000a/200098`8001<]0P0073<2000L=08001D^0P0032H5ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000lY0P004B/2000?:P8000XT0P00
1Ad200026@8000<K0P002B<2000E;P8002Di0P00<402000/?P8001dd0P003BL200047080008I0P00
1b42000H<@8003Q40P00DTd2001EB`030019C0009CX002Dj008000`V0P000aX20004708001@^0P00
@DP2001Q@P8006la0P00JcL2001FB`8002Dj0P00224200026@8000`V0P00>4@2001X>`8008<=0P02
RP02001j808005Q90P0073@20004708000@M0P008CL2001Q@P8008X00P0oX@02036L008007dI0P00
DDd2000@:P80008I0P0032H2001;C@8007dI0P1;Y00207Ra0080>Yl00P00MBP2000hA08000LQ0P00
0a/00`0073<00652001Q@P0201>A0080Lk000P1e/@0201NC008006=00P007SD200036`8000HP0P00
<402001^<P808iL00P1NZP0203^O008007`L0P00CDh2000>:080008I0P0032H20011B080074_0P0<
SP0201fE008008<>0P00Gd@2000T>@8000DO0P000aX2000B;08004I;0P00JCT2001j7`8007LT0P00
HT42000g@`8000hX0P000QX200057P8001L`0P00?dP2001JB003001P@`00EdX005M:008003M40P00
52d200057@80008I0P002242000H<@8003100P00@DP2000mAP8002Tl0P004bd200068080008I0P00
0a/2000:908001@]10007C@2000F;`8000`V1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000
ooooooooool00_ooool2000?:@80014[0P003bX2000:908000DM0P000QT200036`8000TS0P005Bh2
000U>@8003100P00;3h2000M=08000dW0P0011`200026@8000LQ0P006342000hA080059=0P00ED/0
0`00BD`002Dj000U>P02000<9P8000<J0P0011`2000D;P8004580P00HD82001_<@8006/g0P00ET/2
000U>P8000PQ0P000QT2000<9P8003Q40P00J3/200233@800XX00P00NR02001HB@8001`d0P0011`2
00047@80024g0P00HD82002:0080?j400P0aW002001m6@80055=0P0042X200026@8000`V0P00Bdd2
001m6@80Bj@00P1h/@0203ZO008007DX0P00>4@200078@8000<K00<001`c001Q@P00HD800P0CT@02
07>`0080MK400P0GT`02001S@08001he0P000a/20006808003100P00KS8202>G0080GZX00P0kW`02
001l708004e>0P003RP200026@8000`V0P00@DP2001a;`8038h00P0MU@0200233P8005m40P0093T2
00057`8000<J0P004R`20016B`8006Ti0P00NQl2001g908006910P00=d<2000>:080008J0P001Ah2
000G<08003m80P00FTP00`00H4<005M:001GBP02000gA08001@]0P001Ad200026@8000PQ0P006342
000`@08004580P00?DH2000Y?08001<]0P001R0200026@8000<K0P002R@2000D;@@001dd0P005Rl2
000<9PGooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P003bX2000B
;080010Z0P002R@200057@80008I0P000a/200098`8001H_0P009cX2000b@@8002ho0P007SD2000=
9`8000@L0P000QT200078@8001Tb0P00>TD2001DC08005M:00<004a=000V>P009SX00P0032H20003
6P8000@M0P005Bl20014BP8006@o0P00LBh2001]=08005Q:0P009SX200088P80008I0P0032H2000k
A@8006Xh0P00QPH200V=008007`K0P00FTP2000M=08000@L0P0011d2000S>08006=00P08S@0204^T
0080>il00P00P1D2001BC@80010Z0P000QT2000=9`8004m>0P00PA<205RX0080QkD00P14XP02001g
9@8003U50P001b4200036`03000M=000I3l006@o00807ID00P23]00208Bd00807iH00P00ICh2000O
=@8000<K0P001b02000c@@80074^0P0^V`0206b^0080AZ<00P00OQP2001?CP8000hX0P000QT2000<
9`8004A:0P00Lb/201BB00809iP00P00Q@P2001Q@P8002Di0P001Ql200036P8001</0P00BD`2001[
=P8007dJ0P00NR02001T?`8003U50P003RP200026P8000DN0P0063020012B@8005a600<00691001I
B@00FDT00P00>TD2000E;P8000DN0P000QT200088@8001Ta0P00<T420013B@8004180P00:cd2000D
;@8000HP0P000QT200036`8000XT0P0052h4000N=@8001L`0P003BL5ooooo`7o00000Oooool1oooo
o`005_ooool00ol0003oooooooooo`02ooooo`8000lZ0P004R`2000@:P8000XT0P001Ad200026@80
00<K0P002B<2000F;`8002Lj0P00<T42000^?`8001he0P003BL200047080008I0P001b42000I<P80
03Y50P00E4`2001GBP03001<C@009SX002Hj008000`V0P000aX200047@8001D_0P00A4X2001T?`80
074^0P00KC@2001HBP8002Hj0P00228200026@8000`V0P00>dD2001Z>08008H60P09S@02001l6`80
05Y80P007C@20004708000@M0P008cP2001S@08028d00P1;Y00203^O0080080E0P00DTd2000@:P80
008I0P003BL2001?CP80084C0P1HZ00208Ne0080A:800P00MbD2000iA@8000LQ0P000a/00`007C@0
06@o001T?`0201fE0080Pk@00P24]00201nF008006Dn0P007cD200036`8000LP0P00<d42001a;P80
;Y/00P1/[P0204JS008007hH0P00Cdh2000>:080008I0P0032L20014BP8007<[0P0DTP0202NH0080
08D80P00HD82000U>@8000HO0P000aX2000C;08004U<0P00JcH2001m6P8007XP0P00I3l2000iA@80
00hX0P000QX200057P8001P`0P00@TT2001LAP03001R@@00FDT005U9008003Y50P005Bh200057P80
008I0P002242000I<@8003910P00@dT20010B08002/m0P0052d200068080008I0P000a/2000:9080
01@^10007SD2000G<08000dW1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool2000@:P8001</0P0042X2000:9@8000DN0P000QT200036`8000TS0P005Rl2000X>`8003A2
0P00<402000O=P8000hX0P0011`200026@8000PQ0P006S82000mAP8005E;0P00FDT00`00Cdh002Pk
000X>`02000<9P8000<J0P0011d2000F;`8004M;0P00ISd2001d:P8006la0P00FDT2000W>`8000PR
0P000QT2000=9`8003i70P00KC@2002900804I000P00OaL2001KA`8001dd0P0011`200057@8002Di
0P00ISd2016@0080F:P00P16X`020022408005=<0P0042X200026@8000dX0P00DDd200243080IZ`0
0P2G^P0204nV008007TR0P00>dD200078@8000<K00<001lf001V?@00ISd00P0XV@0209>i0080TkP0
0P0WV@02001V?@8001lf0P000a/20007808003I30P00M2X203VO0080Nk800P1AYP0200204`80051>
0P003RP200026@8000dW0P00Ad/2001f9`807ID00P0`W00200280P8006=10P009SX200067`8000<J
0P004bd2001=CP8006dc0P00OaD2001l6`8006Hm0P00?4H2000?:@8000<J0P001Ah2000H<@8004A:
0P00GTD00`00I3l005]7001KA`02000lAP8001D_0P001Ah200026@8000PR0P006C82000d@P8004I;
0P00@dT2000/?P8001D^0P001b0200026@8000<K0P002R@2000E;P8001le0P0083H2000H<08000dW
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000@:P8001</0P00
42X2000:9@8000DN0P000QT200036`8000TS0P005Rl2000X>`8003A20P00<402000O=P8000hX0P00
11`200026@8000PQ0P006S82000mAP8005E;0P00FDT00`00Cdh002Pk000X>`02000<9P8000<J0P00
11d2000F;`8004M;0P00ISd2001d:P8006la0P00FDT2000W>`8000PR0P000QT2000=9`8003i70P00
KC@2002900804I000P00OaL2001KA`8001dd0P0011`200057@8002Di0P00ISd2016@0080F:P00P16
X`020022408005=<0P0042X200026@8000dX0P00DDd200243080IZ`00P2G^P0204nV008007TR0P00
>dD200078@8000<K00<001lf001V?@00ISd00P0XV@0209>i0080TkP00P0WV@02001V?@8001lf0P00
0a/20007808003I30P00M2X203VO0080Nk800P1AYP0200204`80051>0P003RP200026@8000dW0P00
Ad/2001f9`807ID00P0`W00200280P8006=10P009SX200067`8000<J0P004bd2001=CP8006dc0P00
OaD2001l6`8006Hm0P00?4H2000?:@8000<J0P001Ah2000H<@8004A:0P00GTD00`00I3l005]7001K
A`02000lAP8001D_0P001Ah200026@8000PR0P006C82000d@P8004I;0P00@dT2000/?P8001D^0P00
1b0200026@8000<K0P002R@2000E;P8001le0P0083H2000H<08000dW1Oooool1o`00007ooooo0Ooo
ool001Kooooo0_l00003ooooo`80010Z0P004bd2000A:`8000/U0P001Ah200026@8000<K0P002B<2
000G<08002Xl0P00=T<2000a@@80020f0P003RP200047080008I0P002282000K<`8003m70P00EdX2
001JB003001@CP00:C`002Tl008000`W0P000aX200047@8001L`0P00Bdd2001X>`8007HV0P00LBh2
001KB08002Pk0P00228200026@8000dX0P00@DP2001_<@801h`00P0IT`0200214P8005a60P007SD2
0004708000DN0P009cX2001X>P806Y@00P1U[002052V008008@;0P00E4`2000@:`80008I0P003RP2
001CC@8008L50P1e/0020:Nn0080FJT00P00NQh2000lAP8000LQ0P000a/00`008CL006Tj001Y>P02
03:M0080Y;d00P2R_00202nK008006Pk0P0083H200036`8000LQ0P00>D@2001f9P80A:800P29]P02
05bZ008008<?0P00DDd2000>:@80008I0P003BP2001;C@8007PR0P0VV00203ZO00800h/00P00I3l2
000W>`8000HO0P000aX2000D;P8004m>0P00L3020022408007lF0P00J3/2000nA`8000lY0P000aX2
00057P8001Ta0P00Ad/2001P@`03001V?@00GDH005e6008003m70P005Rl200057P80008I0P002282
000J<P8003E30P00BD`20015BP8002ho0P005Bl200078080008I0P000a/2000:908001H_0P0083H2
000Q=`8001Pa0P003BP4ooooo`;o00000_ooool001Kooooo00?o0000ooooooooool00_ooool2000@
:P8001<]0P004B/2000;9@8000DN0P000QT200036`8000TS0P005c02000Z?08003I30P00<D42000P
=P8000hX0P0011`200026@8000PR0P006c<2000oA`8005M:0P00FTP00`00D4h002Tl000Y?002000<
9`8000<J0P0011d2000G<08004]=0P00J3/2001f9P80074^0P00FdP2000X>`8000PR0P000QT2000=
:08004580P00Kc4200N<00806I<00P00PA82001LAP8001he0P0011`200057P8002Lj0P00J3X201ZD
0080IJ`00P1@YP0200242`8005A<0P0042/200026@8000hX0P00Ddd200271@80MK000P2W_P0205VY
008007XN0P00?4H200078@8000<K00<0024g001Y>P00JCX00P0bW@020:Bm0080X[`00P0_V`02001X
>`80020f0P000a/200078@8003U40P00MRH204BR0080RKH00P1LZP0200233`80055=0P003RT20002
6@8000dX0P00Bdd2001h8P809YP00P0jW`0200>;008006@o0P009c/200067`8000<J0P0052h2001?
CP80070`0P00PQ02001o5P8006Pk0P00?TL2000?:@8000<J0P001Ah2000I<@8004M;0P00H4<00`00
ISd005e6001MAP02000oA`8001H_0P001Ah200026@8000PR0P006S82000e@`8004U<0P00ADX2000^
?`8001D_0P001b0200026@8000<K0P002R@2000F;`80020f0P008CL2000H<@8000dX1Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000A:`8001@]0P004B/2000;9@80
00DN0P000QT200036`8000XT0P006342000[?@8003Q40P00<d82000Q=`8000hX0P0011d200026@80
00PR0P0073@20012B@8005Q90P00G4L00`00DDd002Xm000Z?@02000=9`8000<J0P0011d2000H<@80
04i>0P00JSP2001h8P8007<[0P00G4L2000Y?08000PR0P000QT2000>:08004A:0P00LRd200j?0080
8IH00P00P`d2001MA@8001he0P0011`200057P8002Tl0P00JSP202>G0080L[000P1KZ@0200261`80
05E;0P004B/200026@8000lY0P00E4`200::0080Q;@00P2h`@0206B/008007`K0P00?DL200078@80
00<K00<0028h001[=P00JcH00P0nX0020;K10080//000P0gWP02001Y>@80020g0P000a/200078@80
03]60P00NB42052V0080VKX00P1X[@0200252P80059=0P003bT200026@8000hX0P00CTh2001k7P80
;i/00P15XP0200Z>008006Hm0P00:C`200067`8000<K0P005Bh2001@CP80078]0P00Q@X200214@80
06Xh0P00@4P2000@:P8000<J0P001Ah2000J<P8004Y<0P00HD800`00J3X005i5001NA@020012B@80
01L`0P001Ah200026@8000PR0P006c<2000gA08004a=0P00B4`2000`@08001H_0P001b4200026@80
00<K0P002R@2000F;`80024g0P008SL2000I<P8000hX1Oooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool00_ooool2000A:`8001@]0P004B/2000;9@8000DN0P000QT200036`8000XT
0P006342000[?@8003Q40P00<d82000Q=`8000hX0P0011d200026@8000PR0P0073@20012B@8005Q9
0P00G4L00`00DDd002Xm000Z?@02000=9`8000<J0P0011d2000H<@8004i>0P00JSP2001h8P8007<[
0P00G4L2000Y?08000PR0P000QT2000>:08004A:0P00LRd200j?00808IH00P00P`d2001MA@8001he
0P0011`200057P8002Tl0P00JSP202>G0080L[000P1KZ@0200261`8005E;0P004B/200026@8000lY
0P00E4`200::0080Q;@00P2h`@0206B/008007`K0P00?DL200078@8000<K00<0028h001[=P00JcH0
0P0nX0020;K10080//000P0gWP02001Y>@80020g0P000a/200078@8003]60P00NB42052V0080VKX0
0P1X[@0200252P80059=0P003bT200026@8000hX0P00CTh2001k7P80;i/00P15XP0200Z>008006Hm
0P00:C`200067`8000<K0P005Bh2001@CP80078]0P00Q@X200214@8006Xh0P00@4P2000@:P8000<J
0P001Ah2000J<P8004Y<0P00HD800`00J3X005i5001NA@020012B@8001L`0P001Ah200026@8000PR
0P006c<2000gA08004a=0P00B4`2000`@08001H_0P001b4200026@8000<K0P002R@2000F;`80024g
0P008SL2000I<P8000hX1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_oo
ool2000A:`8001@^0P004R`2000;9@8000DN0P000QT200036`8000XT0P006C42000]?P8003Y50P00
=D82000R>08000hY0P0011d200026@8000PR0P007C@20014BP8005Y80P00GDD00`00DTd002`m000/
?@02000=9`8000<J0P001Ad2000I<@80051>0P00K3H2001k7P8007DX0P00GDH2000Z?@8000PR0P00
0QT2000>:@8004Q;0P00M2X201JB0080:IT00P00Q@T2001OA08001le0P0011`200057P8002/m0P00
KC@202fK0080Ok<00P1V[00200280P8005I;0P004B/200026@80010Z0P00ETX200V=0080TkP00P35
`P0206n_008007hH0P00?TL200078@8000<K00<002@i001^<`00KS<00P19Y0020<G30080`/@00P10
X@02001Z>080024g0P000a/200088@8003i70P00O1`205bZ0080Z;h00P1d/00200271@8005=<0P00
3bT200026@8000hY0P00D4h2001m6@80>Il00P1?YP02012@008006Pk0P00:S`200067`8000<K0P00
5Rl2001BC@8007@Z0P00Q`@20024308006`f0P00@dT2000@:P8000<J0P001Ah2000J<P8004a=0P00
Hd000`00JSP00613001P@`020014BP8001Pa0P001Ah200026@8000PR0P006c<2000iA08004i>0P00
Bdd2000b@@8001L`0P001b4200026P8000<K0P002R@2000G<080028g0P008cP2000J<P8000hY1Ooo
ool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000A:`8001@^0P004R`2
000;9@8000DN0P000QT200036`8000XT0P006C42000]?P8003Y50P00=D82000R>08000hY0P0011d2
00026@8000PR0P007C@20014BP8005Y80P00GDD00`00DTd002`m000/?@02000=9`8000<J0P001Ad2
000I<@80051>0P00K3H2001k7P8007DX0P00GDH2000Z?@8000PR0P000QT2000>:@8004Q;0P00M2X2
01JB0080:IT00P00Q@T2001OA08001le0P0011`200057P8002/m0P00KC@202fK0080Ok<00P1V[002
00280P8005I;0P004B/200026@80010Z0P00ETX200V=0080TkP00P35`P0206n_008007hH0P00?TL2
00078@8000<K00<002@i001^<`00KS<00P19Y0020<G30080`/@00P10X@02001Z>080024g0P000a/2
00088@8003i70P00O1`205bZ0080Z;h00P1d/00200271@8005=<0P003bT200026@8000hY0P00D4h2
001m6@80>Il00P1?YP02012@008006Pk0P00:S`200067`8000<K0P005Rl2001BC@8007@Z0P00Q`@2
0024308006`f0P00@dT2000@:P8000<J0P001Ah2000J<P8004a=0P00Hd000`00JSP00613001P@`02
0014BP8001Pa0P001Ah200026@8000PR0P006c<2000iA08004i>0P00Bdd2000b@@8001L`0P001b42
00026P8000<K0P002R@2000G<080028g0P008cP2000J<P8000hY1Oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_ooool2000B;08001D^0P004R`2000;9P8000DN0P000QT20003
6`8000XT0P006S82000^?`8003a60P00=d<2000S>08000lY0P0011d200026@8000PR0P007SD20017
B`8005]70P00Gd@00`00E4`002dn000]?P02000=9`8000<J0P001Ad2000J<P80055=0P00KS<2001m
6P8007LT0P00Gd@2000[?@8000PR0P000QT2000?:@8004]=0P00MRH201fE0080<I`00P00Q`@2001P
@`8001lf0P0011`200057P8002dn0P00Kc4203JN0080S;L00P1a[`0200::008005M:0P004B/20002
6@80010Z0P00F4T2016A0080X[`00P39^@0207Zb0080080D0P00?dP200078@8000<L00<002Hj001`
;`00L2l00P1EY`020<Vi0080b;d00P18X`02001/=P80024g0P000a/200088P8004990P00OQL206V]
0080^<400P1o/`020029008005A<0P003bT200026@8000lY0P00DDd200205080@Z800P1IZ@0201NC
008006Ti0P00:cd200067`8000<K0P005Rl2001CC08007HV0P00RP0200261`8006hc0P00ADX2000@
:P8000<J0P001Ah2000K<`8004m>0P00I3h00`00K3H00691001R@@020017B`8001Ta0P001Al20002
6@8000PR0P0073@2000kA@8004m>0P00CTh2000d@P8001Pa0P00224200026P8000<K0P002RD2000G
<08002<h0P0093T2000K<`8000lY1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooooooo
ool00_ooool2000B;08001D^0P004R`2000;9P8000DN0P000QT200036`8000XT0P006S82000^?`80
03a60P00=d<2000S>08000lY0P0011d200026@8000PR0P007SD20017B`8005]70P00Gd@00`00E4`0
02dn000]?P02000=9`8000<J0P001Ad2000J<P80055=0P00KS<2001m6P8007LT0P00Gd@2000[?@80
00PR0P000QT2000?:@8004]=0P00MRH201fE0080<I`00P00Q`@2001P@`8001lf0P0011`200057P80
02dn0P00Kc4203JN0080S;L00P1a[`0200::008005M:0P004B/200026@80010Z0P00F4T2016A0080
X[`00P39^@0207Zb0080080D0P00?dP200078@8000<L00<002Hj001`;`00L2l00P1EY`020<Vi0080
b;d00P18X`02001/=P80024g0P000a/200088P8004990P00OQL206V]0080^<400P1o/`0200290080
05A<0P003bT200026@8000lY0P00DDd200205080@Z800P1IZ@0201NC008006Ti0P00:cd200067`80
00<K0P005Rl2001CC08007HV0P00RP0200261`8006hc0P00ADX2000@:P8000<J0P001Ah2000K<`80
04m>0P00I3h00`00K3H00691001R@@020017B`8001Ta0P001Al200026@8000PR0P0073@2000kA@80
04m>0P00CTh2000d@P8001Pa0P00224200026P8000<K0P002RD2000G<08002<h0P0093T2000K<`80
00lY1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000B;08001H_
0P004b`2000<9P8000DN0P000QT200036`8000XU0P006S82000`@08003i70P00>D@2000T>@8000lY
0P0011d200026@8000TS0P007cH2001:C08005e60P00H4<00`00ED/002ho000^?`02000=9`8000<J
0P001Ah2000K<`80059=0P00L302001o5P8007TQ0P00H4<2000/?P8000PR0P000QT2000@:P8004i>
0P00NB8202FH0080>Il00P00R@02001Q@P80020f0P0011`200067`8002lo0P00LBh2042Q0080V[X0
0P1l/P0200N<008005Q:0P004B/200026@80014[0P00FTP201ZD0080//000P3=[`0208Be0080084A
0P00@4P200078@8000@L00<002Pk001c;000Lb`00P1QZ`020<f_0080bk@00P1@YP02001]=080028g
0P000a/200088P8004E:0P00PA8207Fa0080aL<00P2;]`0200B;008005E;0P003bT200026@80010Z
0P00Dd`200223`80C:D00P1T[00201jE008006/g0P00;3h200067`8000<K0P005c02001DC08007PS
0P06S00200290@8006la0P00B4/2000A:`8000<J0P001Ah2000L<`80051>0P00ISd00`00KS<006=0
001S@002001:C08001Xb0P001Ql200026@8000PR0P007C@2000lAP80055=0P00Cdh2000f@`8001Ta
0P00228200026P8000<K0P002bD2000H<08002@i0P009CX2000L=08000lZ1Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool00_ooool2000B;08001H_0P004b`2000<9P8000DN0P00
0QT200036`8000XU0P006S82000`@08003i70P00>D@2000T>@8000lY0P0011d200026@8000TS0P00
7cH2001:C08005e60P00H4<00`00ED/002ho000^?`02000=9`8000<J0P001Ah2000K<`80059=0P00
L302001o5P8007TQ0P00H4<2000/?P8000PR0P000QT2000@:P8004i>0P00NB8202FH0080>Il00P00
R@02001Q@P80020f0P0011`200067`8002lo0P00LBh2042Q0080V[X00P1l/P0200N<008005Q:0P00
4B/200026@80014[0P00FTP201ZD0080//000P3=[`0208Be0080084A0P00@4P200078@8000@L00<0
02Pk001c;000Lb`00P1QZ`020<f_0080bk@00P1@YP02001]=080028g0P000a/200088P8004E:0P00
PA8207Fa0080aL<00P2;]`0200B;008005E;0P003bT200026@80010Z0P00Dd`200223`80C:D00P1T
[00201jE008006/g0P00;3h200067`8000<K0P005c02001DC08007PS0P06S00200290@8006la0P00
B4/2000A:`8000<J0P001Ah2000L<`80051>0P00ISd00`00KS<006=0001S@002001:C08001Xb0P00
1Ql200026@8000PR0P007C@2000lAP80055=0P00Cdh2000f@`8001Ta0P00228200026P8000<K0P00
2bD2000H<08002@i0P009CX2000L=08000lZ1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000
ooooooooool00_ooool2000C;@8001H_0P004bd2000<9P8000DN0P000QT200036`8000/U0P006c<2
000a@@8004180P00>TD2000U>@8000lZ0P0011d200026@8000TS0P0083L2001<C@8005i50P00HT40
0`00ET/002lo000_?`02000=:08000<J0P001Ah2000L=08005A<0P00LRd200214@8007/N0P00HD82
000]?P8000PR0P000QT2000@:P80051>0P00Nah202fK0080@J400P05S002001R@@80020f0P0011`2
00067`8003510P00M2X204ZT0080Z;h00P27]@0200^>008005Q90P004B/200026@80018/0P00G4H2
02:G0080`/@00P3AYP0208ng008008<>0P00@DT200078@8000@L00<002Xm001e:000MBP00P1][P02
0=6U0080cj/00P1HZ002001^<P80028h0P000a/200098`8004Q;0P00Q0`208:d0080bKX00P2G^P02
00V=008005I;0P003bT200026@80010Z0P00E4`200252P80EZP00P1_[`0202BH008006`e0P00;Ch2
00067`8000<K0P006302001FB`8007XO0P0<S`0200>;0080074^0P00BT`2000A:`8000<J0P001Ah2
000M=080055=0P00J3/00`00Kc4006Dn001U?P02001<C@8001/b0P001Ql200026@8000PR0P007C@2
000nA`80059=0P00D4d2000hA08001Xb0P00228200026P8000<K0P002bD2000H<@8002Di0P009SX2
000M=080010Z1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000C
;@8001H_0P004bd2000<9P8000DN0P000QT200036`8000/U0P006c<2000a@@8004180P00>TD2000U
>@8000lZ0P0011d200026@8000TS0P0083L2001<C@8005i50P00HT400`00ET/002lo000_?`02000=
:08000<J0P001Ah2000L=08005A<0P00LRd200214@8007/N0P00HD82000]?P8000PR0P000QT2000@
:P80051>0P00Nah202fK0080@J400P05S002001R@@80020f0P0011`200067`8003510P00M2X204ZT
0080Z;h00P27]@0200^>008005Q90P004B/200026@80018/0P00G4H202:G0080`/@00P3AYP0208ng
008008<>0P00@DT200078@8000@L00<002Xm001e:000MBP00P1][P020=6U0080cj/00P1HZ002001^
<P80028h0P000a/200098`8004Q;0P00Q0`208:d0080bKX00P2G^P0200V=008005I;0P003bT20002
6@80010Z0P00E4`200252P80EZP00P1_[`0202BH008006`e0P00;Ch200067`8000<K0P006302001F
B`8007XO0P0<S`0200>;0080074^0P00BT`2000A:`8000<J0P001Ah2000M=080055=0P00J3/00`00
Kc4006Dn001U?P02001<C@8001/b0P001Ql200026@8000PR0P007C@2000nA`80059=0P00D4d2000h
A08001Xb0P00228200026P8000<K0P002bD2000H<@8002Di0P009SX2000M=080010Z1Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000C;@8001L`0P0052d2000<9P80
00DN0P000QT200036`8000/U0P0073@2000c@@8004990P00?4H2000V>P80010Z0P0011d200026@80
00TS0P008CL2001?CP8006130P00Hd000`00EdX00310000`@002000>:08000<J0P001Ah2000M=080
05E;0P00M2X200233@8007dJ0P00HT42000^?`8000PR0P000QT2000A:`80055=0P00OAT203FM0080
BZ@00P09S@02001S@080020f0P0011`200067`8003A20P00MRH205BW0080]/400P2B^002012@0080
05U90P004B/200026@8001<]0P00GTD202^J0080akd00P3DW00209Zj008008@;0P00@TT200078@80
00@L00<002`n001g9000Mb@00P1j/P020=FJ0080dZ800P1PZ`02001_<@80028h0P000a/200098`80
04]=0P00QPL208ng0080c;400P2S_00200f?008005I:0P003bT200026@80014[0P00ET/200271080
H:/00P1i/P0202^J008006hc0P00;Sl200067`8000<K0P006342001GBP8007`K0P0BT@0200R=0080
07<[0P00C4d2000B;08000<J0P001Ah2000M=@80059=0P00JCT00`00LBh006Hl001V?002001>CP80
01/c0P001Ql200026@8000PR0P007SD20010B08005=<0P00DDd2000jA@8001/c0P00228200026P80
00<K0P002bD2000I<@8002Dj0P00:3/2000N=@80010Z1Oooool1o`00007ooooo0Oooool001Kooooo
0_l00003ooooo`8001<]0P005c02000D;@8000`V0P001Ah200026@8000<K0P002bD2000L=08003=1
0P00@TT2000lAP8002Hj0P0042X200047@80008I0P002B<2000Q=`8004m>0P00H4<2001S@003001G
BP00<4000310008000hX0P000aX200057P8001dd0P00ED/2001d:P8008<=0P00OAX2001R@@8002ho
0P00228200026@80014[0P00DDd2001m6@80=Id00P1:Y00200V=008006=00P0083H20004708000HO
0P00=482001f9P80E:L00P2f`@0209:h008049000P00FDT2000A:`80008I0P004bd2001NA@80:iX0
0P37_@020=BL0080V[X00P00Q0/20012B@8000LQ0P0011`00`00;3h007LT001g900207Zb0080eIX0
0P3BXP02062[008006la0P008SP200036`8000TS0P00Bdd200261`80SkL00P3</@020:>l00803Hl0
0P00ETX2000?:@80008I0P004B/2001FB`8008L40P1PZ`0207Vb0080:iX00P00KS<2000^?`8000HO
0P000a/2000H<@8005M:0P00O1/201:A008028d00P00Lb/2001<C@80018/0P000aX200057P8001de
0P00DTd2001Y>@03001a;P00IS`006Hl008004i>0P006c<200067`80008I0P002282000N=@800418
0P00Dd`2001AC@8003Y50P006c<200088P80008J0P000a/2000;9@8001Ta0P009CX2000X>`8001he
0P0042X4ooooo`;o00000_ooool001Kooooo00?o0000ooooooooool00_ooool2000D;@8001L`0P00
52h2000<9`8000DN0P000QT200036`8000/U0P007C@2000d@P8004A:0P00?TL2000W>`80010Z0P00
11d200026@8000TS0P008cP2001@CP8006520P00ICh00`00F4T00350000a@002000>:08000<J0P00
1Ah2000N=@8005I:0P00MRL200252@8007hG0P00Hd02000_?`8000PR0P000QX2000B:`80059=0P00
OaD203fP0080DZH00P0>S`02001T?`80024g0P000a`20006808003I30P00N28205nZ0080`l@00P2L
^`0201BB008005Y80P004B/200026@8001@]0P00H4<203>M0080bk@00P3GTP020:Bm008008H80P00
@dT20007808000@L00<002ho001j8000NR000P26]@020=R?0080eIT00P1X[@02001`;`8002<h0P00
0a/200098`8004i>0P00R@4209bk0080d:P00P2__`0201:A008005M:0P003bT200026@80014[0P00
EdX2002:0080JZh00P24]@0203:L008006la0P00;cl200067`8000<K0P006C82001HB@8007hH0P0H
T`0200j?008007DY0P00CTh2000B;08000<J0P001Ah2000N=@8005=<0P00JcL00`00Lb`006Pk001X
>`02001@CP8001`d0P001Ql200026@8000TR0P007cD20012B@8005A<0P00Ddd2000lAP8001/c0P00
228200026P8000<K0P002bD2000I<@8002Hj0P00:C`2000O=@80014[1Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool2000D;@8001L`0P0052h2000<9`8000DN0P000QT2
00036`8000/U0P007C@2000d@P8004A:0P00?TL2000W>`80010Z0P0011d200026@8000TS0P008cP2
001@CP8006520P00ICh00`00F4T00350000a@002000>:08000<J0P001Ah2000N=@8005I:0P00MRL2
00252@8007hG0P00Hd02000_?`8000PR0P000QX2000B:`80059=0P00OaD203fP0080DZH00P0>S`02
001T?`80024g0P000a`20006808003I30P00N28205nZ0080`l@00P2L^`0201BB008005Y80P004B/2
00026@8001@]0P00H4<203>M0080bk@00P3GTP020:Bm008008H80P00@dT20007808000@L00<002ho
001j8000NR000P26]@020=R?0080eIT00P1X[@02001`;`8002<h0P000a/200098`8004i>0P00R@42
09bk0080d:P00P2__`0201:A008005M:0P003bT200026@80014[0P00EdX2002:0080JZh00P24]@02
03:L008006la0P00;cl200067`8000<K0P006C82001HB@8007hH0P0HT`0200j?008007DY0P00CTh2
000B;08000<J0P001Ah2000N=@8005=<0P00JcL00`00Lb`006Pk001X>`02001@CP8001`d0P001Ql2
00026@8000TR0P007cD20012B@8005A<0P00Ddd2000lAP8001/c0P00228200026P8000<K0P002bD2
000I<@8002Hj0P00:C`2000O=@80014[1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool2000D;P8001Pa0P005Bh2000=9`8000DN0P000QT20003708000/V0P007SD2000f
@`8004E:0P00?dP2000X>`80010Z0P0011d200026P8000XT0P0093T2001AC@8006910P00ISd00`00
FDT00391000b@@02000>:08000<J0P001Ah2000O=P8005Q:0P00Mb@200271080080D0P00I3l2000`
@08000PR0P000QX2000B;08005A<0P00PQ4204FS0080FZT00P0CT@02001U?P80024g0P000a`20006
808003Q40P00NQl206V]0080akh00P2W_@0201VC008005Y80P004B/200026@8001D^0P00HT4203bP
0080cj/00P3KR0020:no008008L40P00A4X20007808000@M00<00310001l6`00O1/00P2C^0020=b4
0080f8l00P1`[`02001a;P8002<h0P000a/2000:9080051>0P04R`020:Rn0080dil00P2j`P0201NC
008005Q90P003bX200026@80018/0P00FDT200F<0080M;000P2?]`0203RO0080070_0P00<4020006
7`8000<K0P006S82001JB080080D0P0NU@0201>A008007HV0P00Cdh2000B;08000<J0P001Al2000O
=@8005A<0P00K3D00`00M2T006Ti001Y>@02001AC@8001dd0P001Ql200026@8000TS0P007cH20013
B@8005E;0P00E4`2000mA`8001`d0P002B<200026P8000<K0P002bD2000J<P8002Lk0P00:S`2000P
=P80014[1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000D;P80
01Pa0P005Bh2000=9`8000DN0P000QT20003708000/V0P007SD2000f@`8004E:0P00?dP2000X>`80
010Z0P0011d200026P8000XT0P0093T2001AC@8006910P00ISd00`00FDT00391000b@@02000>:080
00<J0P001Ah2000O=P8005Q:0P00Mb@200271080080D0P00I3l2000`@08000PR0P000QX2000B;080
05A<0P00PQ4204FS0080FZT00P0CT@02001U?P80024g0P000a`20006808003Q40P00NQl206V]0080
akh00P2W_@0201VC008005Y80P004B/200026@8001D^0P00HT4203bP0080cj/00P3KR0020:no0080
08L40P00A4X20007808000@M00<00310001l6`00O1/00P2C^0020=b40080f8l00P1`[`02001a;P80
02<h0P000a/2000:9080051>0P04R`020:Rn0080dil00P2j`P0201NC008005Q90P003bX200026@80
018/0P00FDT200F<0080M;000P2?]`0203RO0080070_0P00<40200067`8000<K0P006S82001JB080
080D0P0NU@0201>A008007HV0P00Cdh2000B;08000<J0P001Al2000O=@8005A<0P00K3D00`00M2T0
06Ti001Y>@02001AC@8001dd0P001Ql200026@8000TS0P007cH20013B@8005E;0P00E4`2000mA`80
01`d0P002B<200026P8000<K0P002bD2000J<P8002Lk0P00:S`2000P=P80014[1Oooool1o`00007o
oooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000E;P8001Pa0P005Bh2000=9`8000DN
0P000QT20003708000`V0P007SD2000gA08004M;0P00@DP2000Y?080014[0P0011d200026P8000XT
0P009CT2001BC@8006@o0P00Ic`00`00FTP003=2000c@P02000>:080008J0P001Ah2000P=P8005U9
0P00NB4200290080088@0P00ICd2000a@08000PR0P000QX2000C;@8005E;0P00Q0`204fU0080HZ/0
0P0GT`02001V?@80024g0P000a/20007808003Y50P00OA/207>`0080b[H00P2a`00201fE008005]7
0P004B/200026@8001D_0P00Hd0204FR0080dZ800P3NOP020;W2008008P10P00ADX20007808000@M
00<00391001n5`00OQL00P2O^`020=mi0080fhH00P1h/@02001b;08002<h0P000aX2000:9080055=
0P0:SP020;G10080eYH00P35a00201^D008005U90P0042X200026@8001</0P00FTP200^>0080O[<0
0P2I^P0203nQ0080078]0P00<D020006808000<K0P006c<2001KB080088@0P0TV00201VC008007PS
0P00D4h2000C;@8000<J0P001Ql2000P=P8005E;0P00KC<00`00MRL006/g001[=`02001BC@8001he
0P001Ql200026@8000TS0P0083H20015BP8005I;0P00ED/2000oB08001dd0P002B<200026P8000<K
0P002bD2000J<P8002Pk0P00:cd2000P=`80018/1Oooool1o`00007ooooo0Oooool001Kooooo00?o
0000ooooooooool00_ooool2000E;P8001Ta0P005Bl2000=9`8000DN0P000QT20004708000`V0P00
7cH2000iA08004U<0P00@dT2000Z?080014[0P0011d200026P8000XT0P009SX2001CC08006Dn0P00
J3X00`00FdL003A2000d@P02000>:080008J0P001Ql2000Q=`8005Y80P00Nah200>;008008<=0P00
IS`2000a@08000PR0P000QX2000C;@8005I:0P00QPP205FW0080JZd00P0LU@02001W?080028g0P00
0a/20007808003e60P00OaL207fc0080cJl00P2l`P02026F008005a70P004B/200026@8001H_0P00
ICh204fU0080eIT00P3QM0020<;4008008X00P00ADX20007808000@M00<003A200204`00P1<00P2[
_P020>=^0080gWd00P1o/`02001c:`8002<h0P000aX2000;9@80059=0P0?T0020<;40080fHd00P37
_P02022F008005U80P0042X200026@8001<]0P00FdL2012@0080R;H00P2S_@0204FS008007<[0P00
<T420006808000<K0P006c<2001LA`8008@<0P0ZVP0201jE008007TQ0P00DDd2000C;@8000<J0P00
1Ql2000P=P8005I;0P00Kc400`00Mb@006`e001/=@02001CC@8001he0P001R0200026@8000TS0P00
83L20017B`8005M:0P00ET/20011B08001he0P002B<200026P8000<K0P002bH2000K<`8002Tl0P00
;3d2000Q=`80018/1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2
000E;P8001Ta0P005Bl2000=9`8000DN0P000QT20004708000`V0P007cH2000iA08004U<0P00@dT2
000Z?080014[0P0011d200026P8000XT0P009SX2001CC08006Dn0P00J3X00`00FdL003A2000d@P02
000>:080008J0P001Ql2000Q=`8005Y80P00Nah200>;008008<=0P00IS`2000a@08000PR0P000QX2
000C;@8005I:0P00QPP205FW0080JZd00P0LU@02001W?080028g0P000a/20007808003e60P00OaL2
07fc0080cJl00P2l`P02026F008005a70P004B/200026@8001H_0P00ICh204fU0080eIT00P3QM002
0<;4008008X00P00ADX20007808000@M00<003A200204`00P1<00P2[_P020>=^0080gWd00P1o/`02
001c:`8002<h0P000aX2000;9@80059=0P0?T0020<;40080fHd00P37_P02022F008005U80P0042X2
00026@8001<]0P00FdL2012@0080R;H00P2S_@0204FS008007<[0P00<T420006808000<K0P006c<2
001LA`8008@<0P0ZVP0201jE008007TQ0P00DDd2000C;@8000<J0P001Ql2000P=P8005I;0P00Kc40
0`00Mb@006`e001/=@02001CC@8001he0P001R0200026@8000TS0P0083L20017B`8005M:0P00ET/2
0011B08001he0P002B<200026P8000<K0P002bH2000K<`8002Tl0P00;3d2000Q=`80018/1Oooool1
o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000F;`8001Tb0P005Rl2000=
9`8000DO0P000QT20004708000`V0P0083H2000jA@8004]=0P00A4X2000Z?@80014[0P0011d20002
6P8000XT0P009SX2001DC08006Hm0P00JST00`00G4L003E3000e@`02000>:@80008J0P001Ql2000R
=`8005]70P00O1/200N=008008D:0P00Ic/2000b@@8000PR0P000QX2000D;P8005Q:0P00Q`@205fZ
0080L[000P0PUP02001W>`80028g0P000a/200078@8003m70P00P1<208Ne0080d:L00P35a00202FH
008005a60P004B/200026@8001L`0P00Ic`205JX0080f9000P3TJP020<K000800h/00P00AT/20007
808000DM00<003I300233`00P`l00P2g`@020>IT0080hG@00P26]@02001d:@8002@i0P000aX2000;
9@8005A<0P0ETP020<No0080g8@00P3:^00202BG008005Y80P0042X200026@8001@]0P00G4H201FB
0080TKP00P2]_`0204^U008007@Y0P00<d420006808000<K0P0073@2001MAP8008D90P0_V`0202>G
008007/N0P00DTd2000C;@8000<J0P001Ql2000Q=`8005M:0P00L3000`00NB8006dc001]<`02001C
C08001lf0P001R0200026@8000TS0P008CL20018C08005Q:0P00EdX20013B@8001le0P002B<20002
6P8000<K0P002bH2000K<`8002Xl0P00;Ch2000R>08001</1Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool2000F;`8001Tb0P005Rl2000=9`8000DO0P000QT200047080
00`V0P0083H2000jA@8004]=0P00A4X2000Z?@80014[0P0011d200026P8000XT0P009SX2001DC080
06Hm0P00JST00`00G4L003E3000e@`02000>:@80008J0P001Ql2000R=`8005]70P00O1/200N=0080
08D:0P00Ic/2000b@@8000PR0P000QX2000D;P8005Q:0P00Q`@205fZ0080L[000P0PUP02001W>`80
028g0P000a/200078@8003m70P00P1<208Ne0080d:L00P35a00202FH008005a60P004B/200026@80
01L`0P00Ic`205JX0080f9000P3TJP020<K000800h/00P00AT/20007808000DM00<003I300233`00
P`l00P2g`@020>IT0080hG@00P26]@02001d:@8002@i0P000aX2000;9@8005A<0P0ETP020<No0080
g8@00P3:^00202BG008005Y80P0042X200026@8001@]0P00G4H201FB0080TKP00P2]_`0204^U0080
07@Y0P00<d420006808000<K0P0073@2001MAP8008D90P0_V`0202>G008007/N0P00DTd2000C;@80
00<J0P001Ql2000Q=`8005M:0P00L3000`00NB8006dc001]<`02001CC08001lf0P001R0200026@80
00TS0P008CL20018C08005Q:0P00EdX20013B@8001le0P002B<200026P8000<K0P002bH2000K<`80
02Xl0P00;Ch2000R>08001</1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool2000F;`8001Xb0P005Rl2000=:08000DO0P000QT20004708000`W0P008CL2000kAP8004e>
0P00ATX2000[?@80014[0P0011d200026P8000XT0P009c/2001EC08006Lk0P00JcL00`00GDH003I3
000f@`02000>:@80008J0P001Ql2000S>08005a60P00OQP200^>008008H70P00J3X2000c@@8000PR
0P000QX2000E;P8005U90P00R@0206B/0080NK800P0TV002001X>P80028h0P000a/200078@800458
0P00PPl2096h0080dZ000P37_`0202VI008005e60P004B/200026@8001Pa0P00J3X205jZ0080fhL0
0P3WH0020<Rk00801X`00P00Ad/20007808000DM00<003Q400252P00Q@X00P33a0020>UI0080i6/0
0P2=]`02001e:08002@i0P000aX2000;9@8005E;0P0KU0020<Vi0080gg/00P3</P0202RI008005]8
0P0042X200026@8001@^0P00GTD201^D0080VkX00P2g`@02056V008007DX0P00<d820006808000<K
0P007C@2001NA@8008L50P0eW@0202RI008007`L0P00Ddd2000D;@8000<J0P001Ql2000R=`8005M:
0P00LBh00`00NQl006lb001_<P02001DC080020f0P001R0200026@8000TS0P008SL2001:C08005U9
0P00EdX20014BP8001lf0P002B<200026P8000<K0P0032H2000K<`8002/m0P00;Sl2000S>08001<]
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000F;`8001Xb0P00
5Rl2000=:08000DO0P000QT20004708000`W0P008CL2000kAP8004e>0P00ATX2000[?@80014[0P00
11d200026P8000XT0P009c/2001EC08006Lk0P00JcL00`00GDH003I3000f@`02000>:@80008J0P00
1Ql2000S>08005a60P00OQP200^>008008H70P00J3X2000c@@8000PR0P000QX2000E;P8005U90P00
R@0206B/0080NK800P0TV002001X>P80028h0P000a/200078@8004580P00PPl2096h0080dZ000P37
_`0202VI008005e60P004B/200026@8001Pa0P00J3X205jZ0080fhL00P3WH0020<Rk00801X`00P00
Ad/20007808000DM00<003Q400252P00Q@X00P33a0020>UI0080i6/00P2=]`02001e:08002@i0P00
0aX2000;9@8005E;0P0KU0020<Vi0080gg/00P3</P0202RI008005]80P0042X200026@8001@^0P00
GTD201^D0080VkX00P2g`@02056V008007DX0P00<d820006808000<K0P007C@2001NA@8008L50P0e
W@0202RI008007`L0P00Ddd2000D;@8000<J0P001Ql2000R=`8005M:0P00LBh00`00NQl006lb001_
<P02001DC080020f0P001R0200026@8000TS0P008SL2001:C08005U90P00EdX20014BP8001lf0P00
2B<200026P8000<K0P0032H2000K<`8002/m0P00;Sl2000S>08001<]1Oooool1o`00007ooooo0Ooo
ool001Kooooo0_l00003ooooo`8001H_0P006S82000G<08000hX0P001Ql200026@8000@L0P003BL2
000Q=`8003e60P00CTh20017B`8002`n0P004R/200047@80008J0P002bD2000X>`8005E;0P00J3X2
001/=P03001NA@00=d@003M4008000lY0P000QX200067`8002@i0P00GDD2001o5@803i000P00Q`@2
001Y>@8003=10P00228200026P8001D_0P00FTP200>;0080Jjh00P20]00202RI008006Ti0P008SP2
00036`8000PQ0P00@dT200242`80V[X00P3EV@020<Vj0080;I/00P00GDH2000A:`80008I0P006C42
001Z>080IZ`00P3NOP020>UG0080b[L00P08S@020017B`8000LP0P001Ah00`00>TD008H600261P02
0<No0080k4l00P3VHP0209Bi008007HW0P0093T200036P8000`V0P00ET/2022F0080c;800P3QL`02
0<j/0080;9X00P00FdL2000@:P80008I0P005Bh2001OA08089H00P2T_@020<330080EjP00P00MRH2
000d@P8000HP0P000a/2000M=08005m40P00R08203ZO0080;I/00P00OAX2001CC08001@^0P000aX2
00067`80028h0P00F4T2001b;003001k7@00L300070`008005E;0P0083L200078080008I0P002B<2
000R>08004]=0P00FDP2001HB@8004I;0P0083H2000:9080008J0P000a/2000<9P8001`c0P00:cd2
000_?`8002<h0P004bd4ooooo`;o00000_ooool001Kooooo00?o0000ooooooooool00_ooool2000F
;`8001Xb0P005c02000>:08000HO0P000QT20004708000dW0P008CL2000mAP8004i>0P00Ad/2000/
?P80018[0P0011d200026P8000/U0P00:3/2001EB`8006Pj0P00K3H00`00GTD003M4000gA002000?
:@80008J0P001Ql2000T>@8005e50P00OaD200n@008008L40P00JCT2000c@@8000PR0P000QX2000E
;`8005Y80P03R`0206^^0080P;@00P0XV@02001Y>@80028h0P000a/200088@8004=90P00Q0/209Zj
0080eIT00P39^P0202fK008005e60P004B/200026@8001Ta0P00JSP206J/0080gWh00P3YE`020<Zg
008028d00P00Ad/20007808000DN00<003Y500261P00QPH00P37_`020>a?0080iV800P2D^@02001f
9`8002@i0P000aX2000<9P8005I;0P0PUP020<bb0080hG<00P3>[00202bJ008005]70P0042X20002
6@8001D^0P00Gd@2022F0080Y;d00P30``0205NX008007HV0P00=4820006808000<K0P007C@2001O
A08008P20P0jW`0202fK008007dJ0P00Dd`2000D;P8000<J0P001Ql2000R>08005Q90P00LR`00`00
Nad0070`001`<002001EB`80020g0P001b0200026@8000TS0P008SP2001;C@8005U80P00F4T20016
B`80020f0P002R@200026P8000<K0P0032H2000L<`8002/m0P00;cl2000S>08001<]1Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000G<08001/c0P005c02000>:080
00HO0P000QT20004708000dW0P008SL2000nA`8004m>0P00B4`2000]?P80018/0P0011d200026P80
00/U0P00:C`2001FB`8006Ti0P00KCD00`00GTD003Q4000hA002000?:@80008J0P001Ql2000T>@80
05i40P00PA<201>A008008T10P00JSP2000d@P8000PR0P000QX2000F;`8005]70P07S@0207:`0080
QkD00P0/VP02001Z>@80028h0P000a/200088P8004E:0P00QPP20:>l0080ei800P3;]@02032L0080
05i50P004B/200026@8001Xb0P00JcH206j_0080h7H00P3/CP020<bb00802hh00P00B4/200068080
00DN00<003a600280P00R0800P39^@020>i50080jEX00P2J^P02001f9P8002@i0P000aX2000<9P80
05M:0P0UV0020<j/0080i6/00P3@Y`02032L008005a70P0042X200026@8001D_0P00H4<202BH0080
[;l00P35`P0205fZ008007LT0P00=D820006808000<K0P007SD2001P@`800HX00P10X@02036L0080
07hG0P00E4`2000D;P8000<J0P001Ql2000S>08005U90P00M2X00`00OA/0074^001a;P02001FB`80
024g0P001b0200026@8000TS0P008cP2001<C@8005Y80P00FDT20017B`80024g0P002R@200026P80
00<K0P0032H2000L=08002`n0P00;cl2000T>@8001@]1Oooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool00_ooool2000G<08001/c0P005c02000>:08000HO0P000QT20004708000dW
0P008SL2000nA`8004m>0P00B4`2000]?P80018/0P0011d200026P8000/U0P00:C`2001FB`8006Ti
0P00KCD00`00GTD003Q4000hA002000?:@80008J0P001Ql2000T>@8005i40P00PA<201>A008008T1
0P00JSP2000d@P8000PR0P000QX2000F;`8005]70P07S@0207:`0080QkD00P0/VP02001Z>@80028h
0P000a/200088P8004E:0P00QPP20:>l0080ei800P3;]@02032L008005i50P004B/200026@8001Xb
0P00JcH206j_0080h7H00P3/CP020<bb00802hh00P00B4/20006808000DN00<003a600280P00R080
0P39^@020>i50080jEX00P2J^P02001f9P8002@i0P000aX2000<9P8005M:0P0UV0020<j/0080i6/0
0P3@Y`02032L008005a70P0042X200026@8001D_0P00H4<202BH0080[;l00P35`P0205fZ008007LT
0P00=D820006808000<K0P007SD2001P@`800HX00P10X@02036L008007hG0P00E4`2000D;P8000<J
0P001Ql2000S>08005U90P00M2X00`00OA/0074^001a;P02001FB`80024g0P001b0200026@8000TS
0P008cP2001<C@8005Y80P00FDT20017B`80024g0P002R@200026P8000<K0P0032H2000L=08002`n
0P00;cl2000T>@8001@]1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_oo
ool2000G<08001/c0P005c02000>:08000HO0P000QT20004708000dW0P008SP2000oA`80051>0P00
BT`2000]?P80018/0P0011d200026P8000/U0P00:S`2001GBP8006Xh0P00KS<00`00Gd@003U4000i
A002000?:@80008J0P001Ql2000U>P8005m40P00PQ0201NC00800HX00P00JcL2000d@P8000PR0P00
0QX2000F;`8005a70P0;SP0207Vb0080S[L00P0_W002001Z>08002<h0P000a/200088P8004M;0P00
Q`@20:^o0080fH`00P3=/00203>M008005i50P004B/200026@8001Xb0P00KCD207Ja0080hfh00P3^
AP020<j]00803Hl00P00B4`20006808000DN00<003i7006:0001RP000P3</`020?4k0080je800P2P
_002001g908002@i0P000aX2000<9P8005Q90P0ZVP020=6V0080iV<00P3BXP0203>M008005a60P00
42X200026@8001H_0P00HD8202VI0080]L400P37_@0206:[008007PS0P00=T<20006808000<K0P00
7cD2001Q@P8018/00P14XP0203JN008007lE0P00ED`2000E;P8000<J0P001Ql2000S>08005Y80P00
MBT00`00OQP0078]001b;@02001GBP80028g0P001b0200026@8000TS0P008cP2001>CP8005]70P00
FTP20019C080024g0P002R@200026P8000<K0P0032H2000M=08002dn0P00<402000U>@8001@^1Ooo
ool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000G<08001/c0P005c02
000>:08000HO0P000QT20004708000dW0P008SP2000oA`80051>0P00BT`2000]?P80018/0P0011d2
00026P8000/U0P00:S`2001GBP8006Xh0P00KS<00`00Gd@003U4000iA002000?:@80008J0P001Ql2
000U>P8005m40P00PQ0201NC00800HX00P00JcL2000d@P8000PR0P000QX2000F;`8005a70P0;SP02
07Vb0080S[L00P0_W002001Z>08002<h0P000a/200088P8004M;0P00Q`@20:^o0080fH`00P3=/002
03>M008005i50P004B/200026@8001Xb0P00KCD207Ja0080hfh00P3^AP020<j]00803Hl00P00B4`2
0006808000DN00<003i7006:0001RP000P3</`020?4k0080je800P2P_002001g908002@i0P000aX2
000<9P8005Q90P0ZVP020=6V0080iV<00P3BXP0203>M008005a60P0042X200026@8001H_0P00HD82
02VI0080]L400P37_@0206:[008007PS0P00=T<20006808000<K0P007cD2001Q@P8018/00P14XP02
03JN008007lE0P00ED`2000E;P8000<J0P001Ql2000S>08005Y80P00MBT00`00OQP0078]001b;@02
001GBP80028g0P001b0200026@8000TS0P008cP2001>CP8005]70P00FTP20019C080024g0P002R@2
00026P8000<K0P0032H2000M=08002dn0P00<402000U>@8001@^1Oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_ooool2000G<08001`c0P006302000>:08000HO0P000QT20004
708000dW0P008cP20010B080051>0P00Bdd2000^?`80018/0P0011d200026P8000/U0P00:cd2001H
BP8006/g0P00KS800`00H4<003Y5000jA@02000?:@80008J0P001Ql2000V>P8006130P00P`h201ZD
00800h/00P00JcH2000e@P8000PR0P000QX2000G<08005e60P0?T00207nc0080U;T00P0cW@02001[
=`8002<h0P000a/200088P8004U<0P00R@420;C00080g8H00P3>[00203NN008005i50P004B/20002
6@8001/c0P00KS<207fc0080iFH00P3`?P020<nY00803i000P00B4`20006808000DN00<0041800F;
0005R`000P3>[@020?<b0080kD/00P2U_@02001h8`8002@i0P000aX2000=9`8005U90P0_V`020=>P
0080j5/00P3DW@0203NN008005e60P0042X200026@8001H_0P00HT4202jK0080_L<00P39^@0206N]
008007TQ0P00=T<20006808000<K0P007cH2001R@@801h`00P19Y00203ZO0080080C0P00ED/2000E
;P8000<J0P001Ql2000T>@8005Y80P00MRL00`00OaH007<[001c:`02001GBP80028h0P001b020002
6@8000TS0P008cP2001>CP8005a70P00FdP2001:C080028g0P002R@200036P8000<K0P0032H2000M
=08002dn0P00<D02000U>P8001@^1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooooooo
ool00_ooool2000G<08001`c0P006302000>:08000HO0P000QT20004708000dW0P008cP20010B080
051>0P00Bdd2000^?`80018/0P0011d200026P8000/U0P00:cd2001HBP8006/g0P00KS800`00H4<0
03Y5000jA@02000?:@80008J0P001Ql2000V>P8006130P00P`h201ZD00800h/00P00JcH2000e@P80
00PR0P000QX2000G<08005e60P0?T00207nc0080U;T00P0cW@02001[=`8002<h0P000a/200088P80
04U<0P00R@420;C00080g8H00P3>[00203NN008005i50P004B/200026@8001/c0P00KS<207fc0080
iFH00P3`?P020<nY00803i000P00B4`20006808000DN00<0041800F;0005R`000P3>[@020?<b0080
kD/00P2U_@02001h8`8002@i0P000aX2000=9`8005U90P0_V`020=>P0080j5/00P3DW@0203NN0080
05e60P0042X200026@8001H_0P00HT4202jK0080_L<00P39^@0206N]008007TQ0P00=T<200068080
00<K0P007cH2001R@@801h`00P19Y00203ZO0080080C0P00ED/2000E;P8000<J0P001Ql2000T>@80
05Y80P00MRL00`00OaH007<[001c:`02001GBP80028h0P001b0200026@8000TS0P008cP2001>CP80
05a70P00FdP2001:C080028g0P002R@200036P8000<K0P0032H2000M=08002dn0P00<D02000U>P80
01@^1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000H<08001`d
0P006342000>:08000HO0P000QT20004708000dX0P008cP20011B080055=0P00C4d2000_?`80018/
0P0011d200026P8000/U0P00:cd2001HB@8006`f0P00Kc400`00H4<003Y5000jA@02000?:@80008J
0P001R02000W>P8006520P00Q0/201fE00801X`00P00K3D2000e@`8000PR0P000aX2000G<08005i5
0P0BT@0208Fe0080VKX00P0fWP02001[=P8002<h0P000a/200088P8004Y=0P02RP020;_20080gH00
0P3@Z00203VO008005m40P004B/200026@8001`c0P00Kc4208Be0080iel00P3b=P020=6U00804I00
0P00BD`20006808000DN00<0045800R=0008S@000P3@Z0020?DZ0080kd@00P2Z_P02001h8P8002Di
0P000aX2000=9`8005Y80P0dW@020=FJ0080jU@00P3EV00203ZO008005e60P0042X200026@8001L`
0P00Hd0203:L0080a<@00P3;]@0206^^008007XP0P00=d<20006808000<K0P0083H2001S@@802Xh0
0P1=Y@0203jP0080084A0P00ET/2000E;P8000<J0P001Ql2000T>@8005]70P00MRH00`00P1@007@Z
001d:P02001HB@8002<h0P001b0200026@8000TS0P0093T2001?CP8005a60P00FdL2001;C@80028h
0P002R@200036P8000<K0P0032H2000M=08002ho0P00<T42000V>P8001D^1Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool00_ooool2000H<08001`d0P006342000>:08000HO0P00
0QT20004708000dX0P008cP20011B080055=0P00C4d2000_?`80018/0P0011d200026P8000/U0P00
:cd2001HB@8006`f0P00Kc400`00H4<003Y5000jA@02000?:@80008J0P001R02000W>P8006520P00
Q0/201fE00801X`00P00K3D2000e@`8000PR0P000aX2000G<08005i50P0BT@0208Fe0080VKX00P0f
WP02001[=P8002<h0P000a/200088P8004Y=0P02RP020;_20080gH000P3@Z00203VO008005m40P00
4B/200026@8001`c0P00Kc4208Be0080iel00P3b=P020=6U00804I000P00BD`20006808000DN00<0
045800R=0008S@000P3@Z0020?DZ0080kd@00P2Z_P02001h8P8002Di0P000aX2000=9`8005Y80P0d
W@020=FJ0080jU@00P3EV00203ZO008005e60P0042X200026@8001L`0P00Hd0203:L0080a<@00P3;
]@0206^^008007XP0P00=d<20006808000<K0P0083H2001S@@802Xh00P1=Y@0203jP0080084A0P00
ET/2000E;P8000<J0P001Ql2000T>@8005]70P00MRH00`00P1@007@Z001d:P02001HB@8002<h0P00
1b0200026@8000TS0P0093T2001?CP8005a60P00FdL2001;C@80028h0P002R@200036P8000<K0P00
32H2000M=08002ho0P00<T42000V>P8001D^1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000
ooooooooool00_ooool2000H<@8001`d0P006342000>:08000HO0P000QT20004708000dX0P0093T2
0012B@80055=0P00CDh2000_?`80018/0P0011d200026P8000/V0P00;3h2001IB@8006de0P00L300
0`00HD8003]5000kA@02000?:@80008J0P001R02000W>`8006910P00Q@T2022F008028d00P00KCD2
000f@`8000PR0P000aX2000H<08005i40P0ETP0208Zf0080Wk/00P0iW`02001/=P8002<h0P000a/2
00088P8004a=0P05R`020<;40080ggX00P3AY00203bP008005m40P004B/200026@8001`d0P00L302
08Zf0080jEP00P3d;`020=:R00804i400P00BD`20006808000DN00<004=900^>000;SP000P3BX`02
0?LR0080l3h00P2__`02001i8@8002Di0P000aX2000=9`8005]80P0hWP020=JE0080k4h00P3GU002
03bP008005e50P0042X200026@8001L`0P00I3l203FN0080a/400P3</@02072_008007XO0P00=d@2
0006808000<K0P0083H2001S@08038l00P1AYP02046Q0080088?0P00ET/2000E;`8000<J0P001Ql2
000U>@8005a70P00Mb@00`00PA<007@Y001d:@02001HB@8002<h0P001b0200026@8000TS0P0093T2
001?CP8005e60P00G4L2001<C@8002<h0P002R@200036P8000<K0P0032H2000M=@8002lo0P00<T42
000V>P8001D^1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000H
<@8001`d0P006342000>:08000HO0P000QT20004708000dX0P0093T20012B@80055=0P00CDh2000_
?`80018/0P0011d200026P8000/V0P00;3h2001IB@8006de0P00L3000`00HD8003]5000kA@02000?
:@80008J0P001R02000W>`8006910P00Q@T2022F008028d00P00KCD2000f@`8000PR0P000aX2000H
<08005i40P0ETP0208Zf0080Wk/00P0iW`02001/=P8002<h0P000a/200088P8004a=0P05R`020<;4
0080ggX00P3AY00203bP008005m40P004B/200026@8001`d0P00L30208Zf0080jEP00P3d;`020=:R
00804i400P00BD`20006808000DN00<004=900^>000;SP000P3BX`020?LR0080l3h00P2__`02001i
8@8002Di0P000aX2000=9`8005]80P0hWP020=JE0080k4h00P3GU00203bP008005e50P0042X20002
6@8001L`0P00I3l203FN0080a/400P3</@02072_008007XO0P00=d@20006808000<K0P0083H2001S
@08038l00P1AYP02046Q0080088?0P00ET/2000E;`8000<J0P001Ql2000U>@8005a70P00Mb@00`00
PA<007@Y001d:@02001HB@8002<h0P001b0200026@8000TS0P0093T2001?CP8005e60P00G4L2001<
C@8002<h0P002R@200036P8000<K0P0032H2000M=@8002lo0P00<T42000V>P8001D^1Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000H<@8001dd0P006342000>:@80
00HO0P000QT20004708000hX0P0093T20013B@80059=0P00CTh2000`@08001</0P0011d200026P80
00/V0P00;Ch2001IB08006dd0P00LBl00`00HD8003]6000kAP02000?:@80008J0P001R02000X>`80
06910P00QPL202>G00802Xh00P00KC@2000f@`8000PR0P000aX2000H<@8005m40P0HT`0208ng0080
Xkd00P0kW`02001/=@8002<h0P000a/200098`8004e>0P07S@020<G20080hGD00P3BX00203jP0080
05m40P004B/200026@8001dd0P00LBh2092h0080je800P3f:@020=>N008059800P00BD`200068080
00DO00<004A:00j?000>S`000P3CWP020?TK0080lSP00P2c`002001i8@8002Di0P000aX2000=:080
05]70P0lX0020=R@0080kTP00P3HT00203nQ008005i50P0042X200026@8001P`0P00I3l203VO0080
akh00P3>[@0207>`008007/M0P00>4@20006808000<L0P008CL2001T?`803i000P1EY`0204BR0080
08<>0P00EdX2000E;`8000<J0P001Ql2000U>P8005a60P00N2<00`00PA4007DX001e:002001IB@80
02@i0P001b4200026@8000TT0P009CT2001@CP8005e50P00G4H2001=CP8002<h0P002RD200036P80
00<K0P0032H2000N=@8002lo0P00<d42000W>`8001D^1Oooool1o`00007ooooo0Oooool001Kooooo
0_l00003ooooo`8001Pa0P007C@2000H<@8000hY0P001Ql200026@8000@L0P003RP2000T>@8004=9
0P00DTd2001>CP8003100P004b`200047@80008J0P002bH2000]?P8005U80P00KC@2001a;`03001Q
@P00>dH003]6008000lY0P000QX20006808002Pk0P00HT4200261`808iL00P0:SP02001]=08003I3
0P00228200036P8001Pa0P00Gd@201RC0080SkL00P2S_@0203^O008006`e0P008cP200036`8000TS
0P00CDh200N=0080aL800P3QM@020=:P0080?Z000P00Gd@2000A:`80008I0P007C@2001a;P80T;P0
0P3[DP020?HY0080dih00P0DTP020019C08000HP0P001Al00`00A4X03Xl000j?00020=>N0080nA/0
0P3b>0020;?0008007TQ0P009CT200036P8000dX0P00FdL203bP0080f9000P3^B0020=R@0080?j40
0P00GTD2000@:P80008I0P006302001T?`80>Il00P37_P020<j]0080Lk000P00Nad2000hA08000HP
0P000a`2000Q=`8006@o0P0?T00205FW0080A:800P00P`h2001GBP8001D_0P000aX200067`8002Dj
0P00G4H2001h8`0300214@00MBP007DX008005U90P0093T200078@80008I0P002B@2000U>@80051>
0P00GDD2001LAP8004e>0P008cP2000:9@8000<J0P000a/2000<9P8001he0P00;cl2000c@@8002Lk
0P005Bh4ooooo`;o00000_ooool001Kooooo00?o0000ooooooooool00_ooool2000I<@8001dd0P00
6C42000>:@8000HO0P000QT20004708000hX0P009CT20014BP80059=0P00CTh2000`@08001</0P00
11d200026P8000`V0P00;Ch2001JB08006hc0P00LBh00`00HT4003a6000lAP02000?:@80008J0P00
1R02000X>`8006=00P00Q`D202FH008038h00P00KS<2000f@`8000PR0P000aX2000I<@8006130P0J
U00209Bi0080Z;h00P0nX002001/=@8002<h0P000a/200098`8004i>0P0:SP020<No0080hW400P3D
W@02046Q008005m40P0042/200026@8001de0P00LRd209Fi0080k4`00P3g8`020=BK00805Y800P00
BT`20006808000HO00<004E:016@000AT0000P3EVP020?/D0080lc800P2g`@02001j808002Di0P00
0aX2000>:08005a60P0oX@020=V<0080kd800P3IS002046Q008005i50P0042X200026@8001Pa0P00
ICh203bP0080b;/00P3?ZP0207Na008007`L0P00>4@20006808000<L0P008CL2001T?`804I000P1H
Z00204NS008008@<0P00EdX2000F;`8000<J0P001Ql2000V>P8005e60P00NB800`00PQ0007HW001f
9`02001IB08002@i0P001b4200026@8000XT0P009CT2001@CP8005i50P00GDH2001>CP8002@i0P00
2bD200036P8000<K0P0032H2000N=@8003100P00=482000W>`8001D_1Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool2000I<@8001dd0P006C42000>:@8000HO0P000QT2
0004708000hX0P009CT20014BP80059=0P00CTh2000`@08001</0P0011d200026P8000`V0P00;Ch2
001JB08006hc0P00LBh00`00HT4003a6000lAP02000?:@80008J0P001R02000X>`8006=00P00Q`D2
02FH008038h00P00KS<2000f@`8000PR0P000aX2000I<@8006130P0JU00209Bi0080Z;h00P0nX002
001/=@8002<h0P000a/200098`8004i>0P0:SP020<No0080hW400P3DW@02046Q008005m40P0042/2
00026@8001de0P00LRd209Fi0080k4`00P3g8`020=BK00805Y800P00BT`20006808000HO00<004E:
016@000AT0000P3EVP020?/D0080lc800P2g`@02001j808002Di0P000aX2000>:08005a60P0oX@02
0=V<0080kd800P3IS002046Q008005i50P0042X200026@8001Pa0P00ICh203bP0080b;/00P3?ZP02
07Na008007`L0P00>4@20006808000<L0P008CL2001T?`804I000P1HZ00204NS008008@<0P00EdX2
000F;`8000<J0P001Ql2000V>P8005e60P00NB800`00PQ0007HW001f9`02001IB08002@i0P001b42
00026@8000XT0P009CT2001@CP8005i50P00GDH2001>CP8002@i0P002bD200036P8000<K0P0032H2
000N=@8003100P00=482000W>`8001D_1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool2000I<@8001dd0P006C42000?:@8000HO0P000QT20004708000hX0P009CT20014
BP80059=0P00Cdh2000`@08001<]0P0011d200026P8000`V0P00;Sh2001JB08006hb0P00LRd00`00
HT4003a6000lAP02000?:@80008J0P001R02000Y?08006=00P00Q`@202NI00803Hl00P00KS<2000g
@`8000PR0P000aX2000I<@8006130P0MU@0209Nj0080Zkl00P10X@02001]=08002<h0P000a/20009
8`8004m>0P0<SP020<Rl0080hfd00P3EVP0204:R008006130P0042/200026@8001he0P00Lb`209Vj
0080kTL00P3h7P020=FI00805i<00P00BT`20006808000HO00<004I;01>A000CT@000P3FU`020?`?
0080m2h00P2k`P02001j7`8002Di0P000aX2000>:08005e60P12XP020=^80080l3h00P3JR@0204>R
008005i50P0042X200026@8001Pa0P00ISd203nQ0080bKP00P3@Y`0207Zb008007`K0P00>4@20006
808000<L0P008CL2001U?P804i400P1KZ@0204ZT008008@;0P00EdX2000F;`8000<J0P001Ql2000V
>P8005e60P00NB400`00P`h007HV001f9P02001JB08002@i0P001b4200026@8000XT0P009CX2001@
C@8005i50P00GDH2001?CP8002@i0P002bD200036P8000<K0P0032H2000N=@8003100P00=482000X
>`8001H_1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000I<@80
01dd0P006C42000?:@8000HO0P000QT20004708000hX0P009CT20014BP80059=0P00Cdh2000`@080
01<]0P0011d200026P8000`V0P00;Sh2001JB08006hb0P00LRd00`00HT4003a6000lAP02000?:@80
008J0P001R02000Y?08006=00P00Q`@202NI00803Hl00P00KS<2000g@`8000PR0P000aX2000I<@80
06130P0MU@0209Nj0080Zkl00P10X@02001]=08002<h0P000a/200098`8004m>0P0<SP020<Rl0080
hfd00P3EVP0204:R008006130P0042/200026@8001he0P00Lb`209Vj0080kTL00P3h7P020=FI0080
5i<00P00BT`20006808000HO00<004I;01>A000CT@000P3FU`020?`?0080m2h00P2k`P02001j7`80
02Di0P000aX2000>:08005e60P12XP020=^80080l3h00P3JR@0204>R008005i50P0042X200026@80
01Pa0P00ISd203nQ0080bKP00P3@Y`0207Zb008007`K0P00>4@20006808000<L0P008CL2001U?P80
4i400P1KZ@0204ZT008008@;0P00EdX2000F;`8000<J0P001Ql2000V>P8005e60P00NB400`00P`h0
07HV001f9P02001JB08002@i0P001b4200026@8000XT0P009CX2001@C@8005i50P00GDH2001?CP80
02@i0P002bD200036P8000<K0P0032H2000N=@8003100P00=482000X>`8001H_1Oooool1o`00007o
oooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000I<@8001dd0P006C42000?:@8000HO
0P000QT20004708000hX0P009CX20015BP8005==0P00Cdh2000a@08001<]0P0011d200026P8000`V
0P00;Sl2001KB08006lb0P00LRd00`00Hd4003e6000mAP02000?:@80008J0P001b02000Y?08006@o
0P00R08202VI00803i000P00KS82000g@`8000PR0P000aX2000I<@8006520P0OUP0209^j0080[kl0
0P12X@02001]=08002<h0P000a/200098`8004m>0P0=S`020<Vj0080i6X00P3EV00204BR00800613
0P0042/200026@8001he0P00Lb/209fk0080kd<00P3i6P020=JF008069<00P00BTd400067`030017
B`0ETP005I800080ei@00P3m2P020?DZ0080_L<00P00NQl2000U>@8000<J0P003RP2001MAP80AJ80
0P3LQ@020?4j0080fhL00P15X`02001OA080010Z0P000QT2000I<@8006Hm0P11X@020<Zf0080dJD0
0P1l/`02001l6`8003U40P001R0200047080028g0P00ICh201BB0080GZX00P1<Y@0200252P8005Q:
0P005Rl200036P8000HO0P009SX2001MA@8007XP00<008<=001g9@00MbD00P00FTP2000U>@8000LQ
0P000QT2000:908002Dj0P00DDd2001NA08005e50P00Cdh2000T>@8000/U0P000aX200036`8000`W
0P007SD2000`@08003A20P00:3/2000F;`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oo
oooooooo00;ooooo0P006C42000M=08001Ta0P003bT200067`80008I0P0011`2000>:08002Dj0P00
ADX2001CC@8004m>0P00<D02000C;@8000@M0P000QX2000<9P8002ho0P00FdP2001_<P80078]00<0
06=1000mAP00?DH00P003bT200026P8000LP0P00:C`2001T?`8008P20P0YV@0200n@008006hb0P00
=d<200088P8000<J0P006C42001Q@P807iH00P2K^P020:no0080@Z400P00KC@2000S>08000<K0P00
2B<2001?CP803Hl00P39^P020>AZ0080eIP00P14XP02001P@`80010[0P000QT2000N=@8007<[0P2M
^`020>m30080nAX00P3FUP0201RC008004Y=10001Ql00`00Ad/05I8001FB00020=ND0080o@X00P3e
:P020;g3008007XO0P009CT200036P8000hX0P00GDH204FR0080g8D00P3a>P020=^70080AJ<00P00
Gd@2000@:P80008I0P006C42001V?@80@J400P3:]P020=6U0080O;<00P00O1/2000iA08000HP0P00
11`2000R=`8006Dn0P0DTP0205jZ0080C:D00P00Q@X2001HBP8001H_0P000aX200067`8002Hj0P00
GDD2001j800300233@00MbD007LU008005Y80P009CT200078@80008I0P002R@2000U>P80055=0P00
GT@2001MA@8004m>0P0093T2000;9@8000<J0P000a/2000<9`8001he0P00<402000d@P8002Pk0P00
5Rl5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`8001Ta0P007SD2
000I<@8000lY0P001Ql200026@8000@L0P003RP2000V>P8004E:0P00Dd`2001?CP8003500P004bd2
00047@80008J0P0032H2000^?`8005]70P00Kc42001b;003001S@000?DH003e6008000lY0P000QX2
0007808002Xl0P00I3l200290@80:YX00P0@T002001_<P8003M40P00228200036P8001Tb0P00HD82
022F0080WK/00P2a`00204>R008006dd0P008cP200036`8000TS0P00D4h200n@0080bKP00P3UI`02
0=JF0080AJ<00P00H4<2000@:`80008I0P007cD2001d:P80X;`00P3`@0020?XF0080eiD00P0IT`02
001:C@@000HO00<004Q;01NC000GT`000P3HT@020?h60080mRL00P30``02001k7P8002Di0P000aX2
000>:08005e50P17X`020=b30080lSH00P3LQ@0204JS008005m40P0042X200026@8001Ta0P00IS`2
04>R0080bk@00P3AX`0207jc008007dJ0P00>D@20006808000@L0P008SL2001V?@805Y800P1PZ`02
04jU008008D90P00F4X2000F;`8000<J0P001R02000V>P8005i50P00NQl00`00Q0`007LT001g9002
001JB08002Di0P001b4200026@8000XT0P009SX2001AC@8005m40P00GTD2001?CP8002@i0P002bD2
00036P8000<K0P0032L2000N=@8003500P00=D82000X>`8001H_1Oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_ooool2000I<@8001he0P006C42000?:@8000HO0P000QT20004
708000hX0P009SX20015BP8005=<0P00Cdh2000a@08001<]0P0011d200026P8000`V0P00;Sl2001K
A`8006la0P00LR`00`00Hd0003e6000mAP02000?:@80008J0P001b02000Z?08006@o0P00R@4202ZJ
008049000P00Kc82000gA08000PR0P000aX2000I<P8006520P0PUP0209fk0080/L000P13XP02001]
=08002<h0P000a/200098`80051>0P0?T0020<Vh0080iFL00P3FUP0204FS008006130P0042/20002
6@8001le0P00M2X20:2l0080l4000P3j5P020=NE00806I<00P00BTd400067`030018B`0GT`005i<0
0080f9400P3n1P020?HW0080`<<00P00Nah2000U>@8000<J0P003RP2001MA@80Aj<00P3LP`020?8f
0080g8D00P16X`02001OA080010Z0P000QT2000I<@8006Hl0P13XP020<^d0080dJ<00P1n/`02001m
6P8003U40P001R0200047080028g0P00ISd201JB0080H:/00P1>Y@0200252@8005Q:0P005Rl20003
6P8000HP0P009SX2001NA@8007XO00<008@<001g9000Mb@00P00FTP2000U>@8000LQ0P000QT2000:
908002Hj0P00DDd2001OA08005i50P00Cdh2000T>@8000/U0P000aX200036`8000`W0P007SD2000a
@08003E20P00:3/2000F;`Gooooo0Ol00001ooooo`7ooooo000?ooooo`;o00001Oooool00ol0003o
ooooooooo`02ooooo`8001Ta0P007SD2000I<@8000lY0P001Ql200026@8000@L0P003RP2000V>P80
04I:0P00Dd`2001?CP8003500P004bd200047@80008J0P0032H2000^?`8005]70P00Kc42001c;003
001S@000?DH003e6008000lZ0P000QX20007808002Xl0P00I3h200290@80:iX00P0@T002001_<P80
03M40P00228200036P8001Tb0P00HD82026G0080Wk`00P2c`00204BR008006hc0P0093T200036`80
00TS0P00D4h2012@0080b[L00P3UI@020=NE0080AZ<00P00H4<2000@:`80008I0P007cD2001d:P80
X[`00P3`?@020?/D0080ei<00P0JU002001;C@@000HO00<004Q<01RC000HT`000P3HS`020?l30080
mb@00P32a002001k7P8002Di0P000aX2000>:08005i50P18Y0020=f10080lc@00P3LP`0204RS0080
05m40P0042X200026@8001Ta0P00Ic`204BR0080c;<00P3BXP02082d008007dJ0P00>DD200068080
00@L0P008SP2001V?@805i<00P1QZ`0204nV008008D80P00F4T2000F;`8000<J0P001R02000W>P80
05i50P00NQl00`00Q0`007LT001g9002001KB08002Di0P001b4200026@8000XT0P009SX2001AC@80
05m40P00GTD2001?CP8002Di0P002bD200036P8000<K0P0032L2000O=@8003500P00=D82000X>`80
01H_1Oooool1o`00007ooooo0Oooool000kooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`02ooooo`8001Ta0P007SD2000I<@8000lY0P001Ql200026@8000@L0P003RP2000V>P80
04I:0P00Dd`2001?CP8003500P004bd200047@80008J0P0032H2000^?`8005]70P00Kc42001c;003
001S@000?DH003e6008000lZ0P000QX20007808002Xl0P00I3h200290@80:iX00P0@T002001_<P80
03M40P00228200036P8001Tb0P00HD82026G0080Wk`00P2c`00204BR008006hc0P0093T200036`80
00TS0P00D4h2012@0080b[L00P3UI@020=NE0080AZ<00P00H4<2000@:`80008I0P007cD2001d:P80
X[`00P3`?@020?/D0080ei<00P0JU002001;C@@000HO00<004Q<01RC000HT`000P3HS`020?l30080
mb@00P32a002001k7P8002Di0P000aX2000>:08005i50P18Y0020=f10080lc@00P3LP`0204RS0080
05m40P0042X200026@8001Ta0P00Ic`204BR0080c;<00P3BXP02082d008007dJ0P00>DD200068080
00@L0P008SP2001V?@805i<00P1QZ`0204nV008008D80P00F4T2000F;`8000<J0P001R02000W>P80
05i50P00NQl00`00Q0`007LT001g9002001KB08002Di0P001b4200026@8000XT0P009SX2001AC@80
05m40P00GTD2001?CP8002Di0P002bD200036P8000<K0P0032L2000O=@8003500P00=D82000X>`80
01H_1Oooool1o`00007ooooo0Oooool000kooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`02ooooo`8001Tb0P007SD2000I<P8000lY0P001Ql200026@8000@L0P003RP2000V>P80
04I;0P00Dd`2001?CP8003510P004bd200047@80008J0P0032H2000_?`8005]70P00L302001c:`03
001S@000?DL003e7008000lZ0P000QX20007808002Xl0P00ICh200290080;9X00P0AT@02001_<@80
03M40P00228200036P8001Tb0P00HD8202:G0080XK`00P2e`@0204FS008006hc0P0093T200036`80
00TS0P00D4h2016@0080b[H00P3VH`020=ND0080Aj<00P00H4<2000A:`80008I0P007cD2001d:@80
Xkd00P3a?0020?/B0080ei800P0JU002001;C@@000HO00<004Q<01VC000IT`000P3ISP020?l10080
mb800P33a002001k7P8002Dj0P000aX2000>:08005i50P19Y0020=eo0080lc800P3MPP0204RT0080
05m40P0042X200026@8001Ta0P00Ic`204FS0080c;800P3BX002086d008007dI0P00>DD200068080
00@L0P008SP2001V?@805i<00P1RZ`02052V008008H80P00F4T2000F;`8000<J0P001R02000W>P80
05i50P00NQl00`00Q0/007PS001h8`02001KA`8002Di0P001b4200026@8000XT0P009SX2001AC@80
05m40P00GTD2001?CP8002Di0P002bD200036P8000<K0P0032L2000O=@8003500P00=D82000Y?080
01H_1Oooool1o`00007ooooo0Oooool000kooooo00Co0000oooooooooooo00001?ooool3o`0000;o
oooo0P006C82000N=@8001Tb0P003bT200067`80008I0P0011`2000>:08002Hj0P00AT/2001CC080
04m>0P00<D42000C;@8000@M0P000QX2000<9P8002lo0P00FdL2001`<08007<[00<006=0000mA`00
?DL00P003bX200026P8000LP0P00:S`2001U?P8008T00P0/VP02016A008006la0P00=d@200088P80
00<J0P006C82001Q@P808YL00P2Q_0020;G10080AJ<00P00KS<2000T>@8000<K0P002B<2001@CP80
4I000P3:]P020>IS0080ei@00P17X`02001P@`80014[0P000QT2000O=@8007@Y0P2S_@020?4l0080
na800P3GTP0201ZD008004]=10001Ql00`00B4`06I<001VC00020=V>0080o`400P3g8P020<?40080
07/N0P009CX200036P8000hX0P00GTD204VT0080gGl00P3c<P020=f20080B:@00P00Gd@2000@:P80
008I0P006C42001W?080AJ<00P3</P020=:P0080PK@00P00OAT2000iA@8000HP0P0011`2000R>080
06Hm0P0GT`0206:[0080D:H00P00QPP2001HB@8001H_0P000aX20006808002Lj0P00GTD2001j7`03
00242`00N2<007PS008005]70P009CT200078@80008I0P002R@2000V>P80055=0P00Gd@2001NA@80
04m>0P009CT2000;9@8000<J0P000a/2000<9`8001le0P00<D02000e@P8002Tl0P005Rl3ooooo`?o
00000_ooool000kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`80
01Tb0P007SD2000I<P8000lY0P001Ql200026@8000@L0P003RP2000V>P8004I;0P00Dd`2001?CP80
03510P004bd200047@80008J0P0032H2000_?`8005]70P00L302001c:`03001S@000?DL003e70080
00lZ0P000QX20007808002Xl0P00ICh200290080;I/00P0AT@02001_<@8003Q40P00228200036P80
01Xb0P00HT8202:G0080XK`00P2e`@0204JS008006hc0P0093T200036`8000TS0P00D4h2016A0080
bkD00P3VHP020=NC0080B:<00P00H4<2000A:`80008I0P007cH2001d:@80Y;d00P3a>`020?`@0080
f9400P0KU002001;C@@000HO00<004U<01VD000IU0000P3IS@020?l00080mb400P34a002001k7@80
02Dj0P000aX2000>:08005i50P1:Y0020=io0080m3400P3MP@0204VT008005m40P0042X200026@80
01Ta0P00Ic`204JS0080c;400P3CX00208:d008007dI0P00>DD20006808000@L0P008SP2001V?@80
69<00P1SZ`02056V008008H70P00F4T2000F;`8000<J0P001R02000W>P8005i50P00Nah00`00Q0/0
07PS001h8`02001KA`8002Di0P001b4200026@8000XT0P009SX2001AC@8005m40P00GTD2001?CP80
02Di0P002bD200036P8000<K0P0032L2000O=@8003500P00=D82000Y?08001H_1Oooool1o`00007o
oooo0Oooool000kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`80
01Tb0P007SD2000I<P8000lY0P001Ql200026@8000@L0P003RP2000V>P8004I;0P00Dd`2001?CP80
03510P004bd200047@80008J0P0032H2000_?`8005]70P00L302001c:`03001S@000?DL003e70080
00lZ0P000QX20007808002Xl0P00ICh200290080;I/00P0AT@02001_<@8003Q40P00228200036P80
01Xb0P00HT8202:G0080XK`00P2e`@0204JS008006hc0P0093T200036`8000TS0P00D4h2016A0080
bkD00P3VHP020=NC0080B:<00P00H4<2000A:`80008I0P007cH2001d:@80Y;d00P3a>`020?`@0080
f9400P0KU002001;C@@000HO00<004U<01VD000IU0000P3IS@020?l00080mb400P34a002001k7@80
02Dj0P000aX2000>:08005i50P1:Y0020=io0080m3400P3MP@0204VT008005m40P0042X200026@80
01Ta0P00Ic`204JS0080c;400P3CX00208:d008007dI0P00>DD20006808000@L0P008SP2001V?@80
69<00P1SZ`02056V008008H70P00F4T2000F;`8000<J0P001R02000W>P8005i50P00Nah00`00Q0/0
07PS001h8`02001KA`8002Di0P001b4200026@8000XT0P009SX2001AC@8005m40P00GTD2001?CP80
02Di0P002bD200036P8000<K0P0032L2000O=@8003500P00=D82000Y?08001H_1Oooool1o`00007o
oooo0Oooool000oooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0P006C82000N=@8001Tb
0P003bT200067`80008I0P0011`2000>:08002Hj0P00AT/2001CC08004m>0P00<T42000C;@8000@M
0P000QX2000<9P8002lo0P00FdL2001`<08007<[00<006=0000mA`00?DL00P003bX200026P8000LP
0P00:S`2001U?P8008T00P0]V`0201:A008006la0P00>4@200088P8000<J0P006S82001R@P808YL0
0P2Q_0020;K10080AZ<00P00KS<2000T>@8000<K0P002B<2001@CP804I400P3;]@020>IR0080ei<0
0P18X`02001P@`80014[0P000QT2000O=@8007@Y0P2T_@020?4j0080o1000P3HT@0201^D008004]=
10001Ql00`00BD`06I@001VD00020=V=0080o`000P3g8@020<C4008007/M0P009CX200036P8000hX
0P00GTD204ZT0080gWh00P3d<@020=f10080BJ@00P00Gd@2000@:P80008I0P006C42001W?080AZ<0
0P3</@020=>P0080P[@00P00OAT2000jA@8000HP0P0011`2000R>08006Hm0P0HT`0206>[0080DJH0
0P00QPL2001HB@8001H_0P000aX20006808002Lj0P00GTD2001k7P0300242`00N2<007PS008005]7
0P009CX200078@80008I0P002R@2000V>P80055=0P00Gd@2001NA@8004m>0P009CT2000;9@8000<J
0P000a/2000<9`8001le0P00<D02000e@`8002Tl0P005Rl5ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`8001Tb0P007SD2000I<P8000lY0P001Ql200026@8000@L0P00
3RP2000V>P8004I;0P00Dd`2001?CP8003910P004bd200047@80008J0P0032H2000_?`8005]70P00
L302001c:`03001S@000?DL003e7008000lZ0P000QX20007808002Xl0P00ICh200290080;I/00P0B
T@02001_<@8003Q40P00228200036P8001Xb0P00HT8202:G0080XK`00P2f`@0204JS008006hc0P00
93T200036`8000TS0P00D4h2016A0080bkD00P3VHP020=NC0080B:<00P00H4<2000A:`80008I0P00
7cD2001d:@80Y;d00P3a>P020?`@0080f9400P0KU002001;C@@000HO00<004U<01VD000IU0000P3I
S@020?l00080mb400P34a002001k7@8002Dj0P000aX2000>:08005i50P1:Y0020=in0080m3400P3M
P@0204VT008005m40P0042X200026@8001Ta0P00Ic`204JS0080c;400P3CX00208:d008007dI0P00
>TD20006808000@L0P008SP2001V?@8069<00P1SZ`02056V008008H70P00F4T2000F;`8000<J0P00
1R02000W>P8005i50P00Nah00`00Q0/007PS001h8`02001KA`8002Dj0P001b4200026@8000XT0P00
9SX2001AC@8005m40P00GTD2001?CP8002Di0P002bD200036P8000<K0P0032L2000O=@8003500P00
=D<2000Y?08001H_1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2
000I<P8001he0P006C82000?:@8000HO0P000QT20004708000hX0P009SX20016B`8005=<0P00Cdh2
000a@@8001<]0P0011d200026P8000`V0P00;cl2001KA`80070`0P00Lb/00`00Hd0003e7000mA`02
000?:P80008J0P001b02000Z?08006Dn0P00R@0202bJ00804I400P00Kc42000hA08000PR0P000aX2
000I<P8006520P0RU`020:6l0080]L400P16X`02001^<`8002@i0P000a/200098`80051>0P0AT002
0<Zf0080iV<00P3GT`0204RS008006130P004B/200026@8001le0P00M2T20:>m0080lC/00P3k4@02
0=RA00806i@00P00Bdd20006808000HO00<004Q<01VC000IT`000P3ISP020?l00080mb800P34a002
001k7@8002Dj0P000aX2000>:08005i50P19Y0020=io0080lc400P3MP@0204VT008005m40P0042X2
00026@8001Ta0P00Ic`204FS0080c;400P3CX00208:d008007dI0P00>TD20006808000@L0P008SP2
001V?@805i<00P1SZ`02052V008008H80P00F4T2000F;`8000<J0P001R02000W>P8005i50P00NQh0
0`00Q0/007PS001h8`02001KA`8002Di0P001b4200026@8000XT0P009SX2001AC@8005m40P00GTD2
001?CP8002Di0P002bD200036P8000<K0P0032L2000O=@8003500P00=D82000Y?08001H_1Oooool1
o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000I<P8001he0P006C82000?
:@8000HO0P000QT20004708000hX0P009SX20016B`8005=<0P00Cdh2000a@@8001<]0P0011d20002
6P8000`V0P00;cl2001KA`80070`0P00Lb/00`00Hd0003e7000mA`02000?:P80008J0P001b02000Z
?08006Dn0P00R@0202bJ00804I400P00Kc42000hA08000PR0P000aX2000I<P8006520P0RU`020:6l
0080]L400P16X`02001^<`8002@i0P000a/200098`80051>0P0AT0020<Zf0080iV<00P3GT`0204RS
008006130P004B/200026@8001le0P00M2T20:>m0080lC/00P3k4@020=RA00806i@00P00Bdd20006
808000HO00<004Q<01VC000IT`000P3ISP020?l00080mb800P34a002001k7@8002Dj0P000aX2000>
:08005i50P19Y0020=io0080lc400P3MP@0204VT008005m40P0042X200026@8001Ta0P00Ic`204FS
0080c;400P3CX00208:d008007dI0P00>TD20006808000@L0P008SP2001V?@805i<00P1SZ`02052V
008008H80P00F4T2000F;`8000<J0P001R02000W>P8005i50P00NQh00`00Q0/007PS001h8`02001K
A`8002Di0P001b4200026@8000XT0P009SX2001AC@8005m40P00GTD2001?CP8002Di0P002bD20003
6P8000<K0P0032L2000O=@8003500P00=D82000Y?08001H_1Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool2000I<P8001he0P006C82000?:@8000HO0P000QT200047080
00hX0P009SX20016BP8005=<0P00Cdh2000a@@8001<]0P0011d200026P8000`V0P00;Sl2001KA`80
06la0P00Lb/00`00Hd0003e7000mA`02000?:P80008J0P001b02000Z?08006Dn0P00R@0202bJ0080
4I000P00Kc42000hA08000PR0P000aX2000I<P8006520P0QU`020:2l0080]<400P15X`02001^<`80
02@i0P000a/200098`80051>0P0@T0020<Zg0080iV@00P3GU00204RS008006130P004B/200026@80
01le0P00M2X20::l0080l3d00P3k4P020=NB00806i@00P00Bdd20006808000HO00<004Q;01RC000H
T`000P3HS`020?l20080mb<00P33a002001k7@8002Dj0P000aX2000>:08005i50P18Y0020=f00080
lc<00P3MPP0204RT008005m40P0042X200026@8001Ta0P00Ic`204FR0080c;800P3BX@02086d0080
07dI0P00>DD20006808000@L0P008SP2001V?@805i<00P1RZ`02052V008008H80P00F4T2000F;`80
00<J0P001R02000W>P8005i50P00NQl00`00Q0/007PT001h9002001KB08002Di0P001b4200026@80
00XT0P009SX2001AC@8005m40P00GTD2001?CP8002Di0P002bD200036P8000<K0P0032L2000O=@80
03500P00=D82000X?08001H_1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool2000I<P8001he0P006C82000?:@8000HO0P000QT20004708000hX0P009SX20016BP8005=<
0P00Cdh2000a@@8001<]0P0011d200026P8000`V0P00;Sl2001KA`8006la0P00Lb/00`00Hd0003e7
000mA`02000?:P80008J0P001b02000Z?08006Dn0P00R@0202bJ00804I000P00Kc42000hA08000PR
0P000aX2000I<P8006520P0QU`020:2l0080]<400P15X`02001^<`8002@i0P000a/200098`80051>
0P0@T0020<Zg0080iV@00P3GU00204RS008006130P004B/200026@8001le0P00M2X20::l0080l3d0
0P3k4P020=NB00806i@00P00Bdd20006808000HO00<004Q;01RC000HT`000P3HS`020?l20080mb<0
0P33a002001k7@8002Dj0P000aX2000>:08005i50P18Y0020=f00080lc<00P3MPP0204RT008005m4
0P0042X200026@8001Ta0P00Ic`204FR0080c;800P3BX@02086d008007dI0P00>DD20006808000@L
0P008SP2001V?@805i<00P1RZ`02052V008008H80P00F4T2000F;`8000<J0P001R02000W>P8005i5
0P00NQl00`00Q0/007PT001h9002001KB08002Di0P001b4200026@8000XT0P009SX2001AC@8005m4
0P00GTD2001?CP8002Di0P002bD200036P8000<K0P0032L2000O=@8003500P00=D82000X?08001H_
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000I<@8001he0P00
6C42000?:@8000HO0P000QT20004708000hX0P009SX20015BP8005=<0P00Cdh2000a@08001<]0P00
11d200026P8000`V0P00;Sl2001KA`8006la0P00Lb`00`00Hd0003e7000mA`02000?:P80008J0P00
1b02000Y?08006@o0P00R@4202^J008049000P00Kc82000hA08000PR0P000aX2000I<@8006520P0P
UP0209jk0080//000P14XP02001^<`8002@i0P000a/200098`8004m>0P0?T0020<Zh0080iFH00P3F
U@0204NS008006130P004B/200026@8001he0P00M2X20:2l0080l3l00P3k50020=NC00806Y@00P00
Bdd20006808000HO00<004M;01NC000GT`000P3HT@020?h50080mbD00P32a002001k7@8002Dj0P00
0aX2000>:08005e50P17X`020=f20080lSD00P3LP`0204RS008005m40P0042X200026@8001Ta0P00
IS`204>R0080bk@00P3BXP02082c008007dJ0P00>DD20006808000@L0P008SL2001V?@805Y800P1P
Z`0204nU008008D80P00F4T2000F;`8000<J0P001R02000V>P8005i50P00NQl00`00Q0`007LT001g
9002001JB08002Di0P001b4200026@8000XT0P009SX2001AC@8005m40P00GTD2001?CP8002@i0P00
2bD200036P8000<K0P0032L2000O=@8003500P00=D82000X>`8001H_1Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool2000I<@8001he0P006C42000?:@8000HO0P000QT2
0004708000hX0P009SX20015BP8005=<0P00Cdh2000a@08001<]0P0011d200026P8000`V0P00;Sl2
001KA`8006la0P00Lb`00`00Hd0003e7000mA`02000?:P80008J0P001b02000Y?08006@o0P00R@42
02^J008049000P00Kc82000hA08000PR0P000aX2000I<@8006520P0PUP0209jk0080//000P14XP02
001^<`8002@i0P000a/200098`8004m>0P0?T0020<Zh0080iFH00P3FU@0204NS008006130P004B/2
00026@8001he0P00M2X20:2l0080l3l00P3k50020=NC00806Y@00P00Bdd20006808000HO00<004M;
01NC000GT`000P3HT@020?h50080mbD00P32a002001k7@8002Dj0P000aX2000>:08005e50P17X`02
0=f20080lSD00P3LP`0204RS008005m40P0042X200026@8001Ta0P00IS`204>R0080bk@00P3BXP02
082c008007dJ0P00>DD20006808000@L0P008SL2001V?@805Y800P1PZ`0204nU008008D80P00F4T2
000F;`8000<J0P001R02000V>P8005i50P00NQl00`00Q0`007LT001g9002001JB08002Di0P001b42
00026@8000XT0P009SX2001AC@8005m40P00GTD2001?CP8002@i0P002bD200036P8000<K0P0032L2
000O=@8003500P00=D82000X>`8001H_1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool2000I<@8001de0P006C42000?:@8000HO0P000QT20004708000hX0P009CX20015
BP8005=<0P00Cdh2000a@08001<]0P0011d200026P8000`V0P00;Sl2001KA`8006la0P00LR`00`00
Hd0003e6000mAP02000?:P80008J0P001b02000Y?08006@o0P00R08202ZJ00803i000P00Kc82000g
A08000PR0P000aX2000I<@8006520P0OUP0209bk0080/<000P13XP02001^<`8002@i0P000a/20009
8`8004m>0P0=S`020<Vj0080i6P00P3FUP0204JS008006130P004B/200026@8001he0P00Lb/209fk
0080kd800P3j5`020=ND00806Y@00P00Bdd20006808000HO00<004I;01FB000ETP000P3GT`020?d8
0080mRP00P30``02001k7P8002Dj0P000aX2000>:08005e60P15XP020=b50080lSP00P3LQ@0204NS
008005m40P0042X200026@8001Pa0P00ISd2046Q0080bkD00P3AY00207jc008007dJ0P00>DD20006
808000@L0P008SL2001U?P805I800P1OZP0204fU008008D90P00F4X2000F;`8000<J0P001Ql2000V
>P8005e50P00NR000`00P`d007LU001g9@02001JB08002Di0P001b4200026@8000XT0P009SX2001A
C@8005m40P00GTD2001?CP8002@i0P002bD200036P8000<K0P0032L2000N=@8003100P00=D82000X
>`8001H_1Oooool1o`00007ooooo0Oooool001Kooooo0_l00003ooooo`8001Ta0P007CD2000I<@80
00lY0P001Ql200026@8000@L0P003RP2000U>P8004E:0P00Dd`2001?CP8003500P004bd200047@80
008J0P0032H2000^?`8005]70P00Kc42001b;003001S@000?DH003e6008000lZ0P000QX200078080
02Tl0P00I3l200280P80:YX00P0?T002001_<P8003M40P00228200036P8001Ta0P00HD8201nF0080
W;/00P2``00204>R008006hc0P0093T200036`8000TS0P00Cdh200f?0080bKX00P3TJ0020=JF0080
AZ<00P00H4<2000A:`80008I0P007SD2001c:`80WK/00P3_@P020?XG0080ei@00P0JU002001;C@80
00HP0P001Ql00`00AT/05I8001FB00020=NC0080o@P00P3f:0020<33008007/N0P009CX200036P80
00hX0P00GDH204FR0080g8D00P3b>0020=b50080Aj<00P00Gd@2000@:P80008I0P006342001V?@80
@J400P3;]@020=6T0080O[<00P00OAX2000iA@8000HP0P0011`2000R=`8006Dn0P0ETP0205nZ0080
CJD00P00Q@T2001HBP8001H_0P000aX200067`8002Hj0P00GDD2001j800300233@00MbD007LU0080
05Y80P009CT200078@80008I0P002R@2000V>P80055=0P00Gd@2001NA@8004m>0P0093T2000;9@80
00<J0P000a/2000<9`8001he0P00<402000e@P8002Pk0P005Rl4ooooo`;o00000_ooool001Kooooo
00?o0000ooooooooool00_ooool2000I<@8001dd0P006C42000?:@8000HO0P000QT20004708000hX
0P009CX20014BP80059=0P00Cdh2000a@08001<]0P0011d200026P8000`V0P00;Sh2001JB08006lb
0P00LRd00`00HT4003e6000mAP02000?:P80008J0P001R02000Y?08006A00P00R0<202RI00803Xl0
0P00KS82000gA08000PR0P000aX2000I<@8006130P0MU@0209Vj0080[Kl00P12XP02001]=08002@i
0P000a/200098`8004m>0P0<SP020<Rl0080i6/00P3EV00204FR008006130P004B/200026@8001he
0P00LR`209Vj0080kTH00P3i6`020=JF00806I<00P00Bdd20006808000HO00<004I:01>A000CT@00
0P3FUP020?`=0080mB/00P2n``02001k7P8002Dj0P000aX2000>:08005a60P12XP020=^80080lC`0
0P3KQ`0204FS008005m40P0042X200026@8001Pa0P00ICd203nQ0080b[L00P3@YP0207bb008007dK
0P00>D@20006808000<L0P008CL2001U?P804i400P1LZP0204^T008008D:0P00EdX2000F;`8000<J
0P001Ql2000V>P8005e60P00NB400`00P`h007LU001g9@02001JB08002@i0P001b4200026@8000XT
0P009CX2001AC@8005i50P00GDD2001?CP8002@i0P002bD200036P8000<K0P0032L2000N=@800310
0P00=482000X>`8001H_1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_oo
ool2000I<@8001dd0P006C42000?:@8000HO0P000QT20004708000hX0P009CX20014BP80059=0P00
Cdh2000a@08001<]0P0011d200026P8000`V0P00;Sh2001JB08006lb0P00LRd00`00HT4003e6000m
AP02000?:P80008J0P001R02000Y?08006A00P00R0<202RI00803Xl00P00KS82000gA08000PR0P00
0aX2000I<@8006130P0MU@0209Vj0080[Kl00P12XP02001]=08002@i0P000a/200098`8004m>0P0<
SP020<Rl0080i6/00P3EV00204FR008006130P004B/200026@8001he0P00LR`209Vj0080kTH00P3i
6`020=JF00806I<00P00Bdd20006808000HO00<004I:01>A000CT@000P3FUP020?`=0080mB/00P2n
``02001k7P8002Dj0P000aX2000>:08005a60P12XP020=^80080lC`00P3KQ`0204FS008005m40P00
42X200026@8001Pa0P00ICd203nQ0080b[L00P3@YP0207bb008007dK0P00>D@20006808000<L0P00
8CL2001U?P804i400P1LZP0204^T008008D:0P00EdX2000F;`8000<J0P001Ql2000V>P8005e60P00
NB400`00P`h007LU001g9@02001JB08002@i0P001b4200026@8000XT0P009CX2001AC@8005i50P00
GDD2001?CP8002@i0P002bD200036P8000<K0P0032L2000N=@8003100P00=482000X>`8001H_1Ooo
ool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000I<@8001dd0P006C42
000?:@8000HO0P000QT20004708000hX0P009CT20014BP80059=0P00Cdh2000`@08001<]0P0011d2
00026P8000`V0P00;Ch2001JB08006hc0P00LBh00`00HT4003a6000lAP02000?:P80008J0P001R02
000X>`8006=00P00Q`D202JH00803Hl00P00KS<2000g@`8000PR0P000aX2000H<@8006130P0KU002
09Fi0080Z[h00P10X@02001]=08002@i0P000a/200098`8004i>0P09S@020<No0080hVl00P3DV`02
04>R008006130P004B/200026@8001dd0P00LRd209Bi0080kD/00P3h80020=FI008069<00P00Bdd2
0006808000DN00<004A:012@000@T0000P3EVP020?/B0080m2l00P2k`P02001j7P8002Hj0P000aX2
000=:08005a70P0oX@020=Z;0080l4000P3JRP0204BR008005m40P0042X200026@8001Pa0P00ICh2
03bP0080bKX00P3?Z@0207Vb008007`K0P00>D@20006808000<L0P008CL2001U?P804I400P1JZ@02
04VT008008@;0P00EdX2000F;`8000<J0P001Ql2000V>P8005e60P00NB400`00PPl007HV001f9P02
001JB08002@i0P001b4200026@8000XT0P009CX2001@CP8005i50P00GDH2001>CP8002@i0P002RD2
00036P8000<K0P0032L2000N=@8003100P00=482000W>`8001D_1Oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_ooool2000I<@8001dd0P006C42000?:@8000HO0P000QT20004
708000hX0P009CT20014BP80059=0P00Cdh2000`@08001<]0P0011d200026P8000`V0P00;Ch2001J
B08006hc0P00LBh00`00HT4003a6000lAP02000?:P80008J0P001R02000X>`8006=00P00Q`D202JH
00803Hl00P00KS<2000g@`8000PR0P000aX2000H<@8006130P0KU00209Fi0080Z[h00P10X@02001]
=08002@i0P000a/200098`8004i>0P09S@020<No0080hVl00P3DV`0204>R008006130P004B/20002
6@8001dd0P00LRd209Bi0080kD/00P3h80020=FI008069<00P00Bdd20006808000DN00<004A:012@
000@T0000P3EVP020?/B0080m2l00P2k`P02001j7P8002Hj0P000aX2000=:08005a70P0oX@020=Z;
0080l4000P3JRP0204BR008005m40P0042X200026@8001Pa0P00ICh203bP0080bKX00P3?Z@0207Vb
008007`K0P00>D@20006808000<L0P008CL2001U?P804I400P1JZ@0204VT008008@;0P00EdX2000F
;`8000<J0P001Ql2000V>P8005e60P00NB400`00PPl007HV001f9P02001JB08002@i0P001b420002
6@8000XT0P009CX2001@CP8005i50P00GDH2001>CP8002@i0P002RD200036P8000<K0P0032L2000N
=@8003100P00=482000W>`8001D_1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooooooo
ool00_ooool2000H<@8001dd0P006C42000>:@8000HO0P000QT20004708000hX0P0093T20013B@80
059=0P00CTh2000`@08001</0P0011d200026P8000/V0P00;Ch2001JB08006hc0P00LBh00`00HT40
03a6000lAP02000?:@80008J0P001R02000X>`8006910P00QPL202BG00802hh00P00KS<2000g@`80
00PR0P000aX2000H<@8005m40P0HT`02096h0080Y[d00P0nX002001]=08002@i0P000a/200088P80
04e>0P07S0020<K20080hG<00P3CWP0204:Q008006130P004B/200026@8001`d0P00LBl208nh0080
je000P3f9@020=BK00805i<00P00Bdd20006808000DN00<004=900j?000>S`000P3CWP020?XH0080
lc@00P2h`P02001j7`8002Hj0P000aX2000=9`8005]70P0lX0020=R?0080kTD00P3IS@0204:Q0080
05i50P0042X200026@8001P`0P00I3l203VO0080b;d00P3>[00207Ja008007`L0P00>4@200068080
00<K0P008CL2001T?`803i000P1GZ00204JS008008<=0P00EdX2000F;`8000<J0P001Ql2000U>P80
05a60P00N2800`00PQ0007DW001e9`02001IB@8002@i0P001b4200026@8000XT0P009CT2001@CP80
05i50P00GDH2001>CP8002<h0P002RD200036P8000<K0P0032H2000N=@8002lo0P00<d82000W>`80
01D^1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000H<@8001dd
0P006C42000>:@8000HO0P000QT20004708000hX0P0093T20013B@80059=0P00CTh2000`@08001</
0P0011d200026P8000/V0P00;Ch2001JB08006hc0P00LBh00`00HT4003a6000lAP02000?:@80008J
0P001R02000X>`8006910P00QPL202BG00802hh00P00KS<2000g@`8000PR0P000aX2000H<@8005m4
0P0HT`02096h0080Y[d00P0nX002001]=08002@i0P000a/200088P8004e>0P07S0020<K20080hG<0
0P3CWP0204:Q008006130P004B/200026@8001`d0P00LBl208nh0080je000P3f9@020=BK00805i<0
0P00Bdd20006808000DN00<004=900j?000>S`000P3CWP020?XH0080lc@00P2h`P02001j7`8002Hj
0P000aX2000=9`8005]70P0lX0020=R?0080kTD00P3IS@0204:Q008005i50P0042X200026@8001P`
0P00I3l203VO0080b;d00P3>[00207Ja008007`L0P00>4@20006808000<K0P008CL2001T?`803i00
0P1GZ00204JS008008<=0P00EdX2000F;`8000<J0P001Ql2000U>P8005a60P00N2800`00PQ0007DW
001e9`02001IB@8002@i0P001b4200026@8000XT0P009CT2001@CP8005i50P00GDH2001>CP8002<h
0P002RD200036P8000<K0P0032H2000N=@8002lo0P00<d82000W>`8001D^1Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool00_ooool2000H<@8001dd0P006342000>:@8000HO0P00
0QT20004708000dX0P0093T20012B@80055=0P00CDh2000`@08001</0P0011d200026P8000/V0P00
;3h2001IB@8006dd0P00L2l00`00HD8003]6000kAP02000?:@80008J0P001R02000W>`8006910P00
Q@P2026G00802Hd00P00KC@2000g@`8000PR0P000QX2000H<08005i50P0ETP0208bg0080X[`00P0l
X002001/=@8002@i0P000a/200088P8004]=0P04R`020<?40080h7P00P3BX@02042Q008006130P00
4B/200026@8001`c0P00L30208Zf0080jUH00P3e:`020=>N00805Y800P00Bdd20006808000DN00<0
049900^>000;SP000P3BXP020?PO0080lCT00P2d`@02001j808002Hj0P000aX2000=9`8005Y80P0h
WP020=ND0080kD/00P3HT@0203nQ008005i50P0042X200026@8001L`0P00I40203JN0080a/000P3=
[`0207>`008007/M0P00>4@20006808000<K0P0083H2001S@0803Hl00P1CY`0204>R008008<>0P00
ETX2000E;`8000<J0P001Ql2000U>@8005a70P00N2@00`00PA8007DX001e:002001IB@8002<h0P00
1b0200026@8000TT0P009CT2001@CP8005e60P00G4H2001=CP8002<h0P002R@200036P8000<K0P00
32H2000N=@8002lo0P00<d42000W>P8001D^1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000
ooooooooool00_ooool2000H<@8001dd0P006342000>:@8000HO0P000QT20004708000dX0P0093T2
0012B@80055=0P00CDh2000`@08001</0P0011d200026P8000/V0P00;3h2001IB@8006dd0P00L2l0
0`00HD8003]6000kAP02000?:@80008J0P001R02000W>`8006910P00Q@P2026G00802Hd00P00KC@2
000g@`8000PR0P000QX2000H<08005i50P0ETP0208bg0080X[`00P0lX002001/=@8002@i0P000a/2
00088P8004]=0P04R`020<?40080h7P00P3BX@02042Q008006130P004B/200026@8001`c0P00L302
08Zf0080jUH00P3e:`020=>N00805Y800P00Bdd20006808000DN00<0049900^>000;SP000P3BXP02
0?PO0080lCT00P2d`@02001j808002Hj0P000aX2000=9`8005Y80P0hWP020=ND0080kD/00P3HT@02
03nQ008005i50P0042X200026@8001L`0P00I40203JN0080a/000P3=[`0207>`008007/M0P00>4@2
0006808000<K0P0083H2001S@0803Hl00P1CY`0204>R008008<>0P00ETX2000E;`8000<J0P001Ql2
000U>@8005a70P00N2@00`00PA8007DX001e:002001IB@8002<h0P001b0200026@8000TT0P009CT2
001@CP8005e60P00G4H2001=CP8002<h0P002R@200036P8000<K0P0032H2000N=@8002lo0P00<d42
000W>P8001D^1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000H
<@8001`d0P006342000>:08000HO0P000QT20004708000dX0P0093T20012B@80055=0P00C4d2000_
?`80018/0P0011d200026P8000/U0P00:cd2001IB@8006`e0P00L3000`00HD8003]5000kA@02000?
:@80008J0P001R02000W>P8006520P00Q0/201nF00801hd00P00KC@2000f@`8000PR0P000QX2000G
<08005i50P0BT@0208Ne0080WK/00P0iW`02001/=@8002@i0P000a/200088P8004Y<0P01RP020;g3
0080gWd00P3AY00203fP008006130P004B/200026@8001/c0P00Kc8208Be0080j5d00P3c<P020=:Q
008059800P00Bdd20007808000DN00<0041800N=0007S@000P3@Y`020?HV0080l3l00P2``002001i
808002Hj0P000aX2000=9`8005Y80P0dW@020=FI0080je400P3FU@0203fP008005i50P0042X20002
6@8001L`0P00Hd0203:L0080aL<00P3</`0206n_008007XN0P00>4@20006808000<K0P0083H2001S
@0802hh00P1?YP02042Q0080088@0P00ET/2000E;`8000<J0P001Ql2000U>@8005]70P00MbD00`00
P1@007@Y001d:@02001HB@8002<h0P001b0200026@8000TT0P0093T2001?CP8005e60P00FdL2001<
C@80028h0P002R@200036P8000<K0P0032H2000M=@8002lo0P00<T42000V>P8001D^1Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000H<@8001`d0P006342000>:080
00HO0P000QT20004708000dX0P0093T20012B@80055=0P00C4d2000_?`80018/0P0011d200026P80
00/U0P00:cd2001IB@8006`e0P00L3000`00HD8003]5000kA@02000?:@80008J0P001R02000W>P80
06520P00Q0/201nF00801hd00P00KC@2000f@`8000PR0P000QX2000G<08005i50P0BT@0208Ne0080
WK/00P0iW`02001/=@8002@i0P000a/200088P8004Y<0P01RP020;g30080gWd00P3AY00203fP0080
06130P004B/200026@8001/c0P00Kc8208Be0080j5d00P3c<P020=:Q008059800P00Bdd200078080
00DN00<0041800N=0007S@000P3@Y`020?HV0080l3l00P2``002001i808002Hj0P000aX2000=9`80
05Y80P0dW@020=FI0080je400P3FU@0203fP008005i50P0042X200026@8001L`0P00Hd0203:L0080
aL<00P3</`0206n_008007XN0P00>4@20006808000<K0P0083H2001S@0802hh00P1?YP02042Q0080
088@0P00ET/2000E;`8000<J0P001Ql2000U>@8005]70P00MbD00`00P1@007@Y001d:@02001HB@80
02<h0P001b0200026@8000TT0P0093T2001?CP8005e60P00FdL2001<C@80028h0P002R@200036P80
00<K0P0032H2000M=@8002lo0P00<T42000V>P8001D^1Oooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool00_ooool2000H<08001`c0P006302000>:08000HO0P000QT20004708000dW
0P008cP20011B080051=0P00Bdd2000_?`80018/0P0011d200026P8000/U0P00:cd2001HBP8006/f
0P00Kc400`00H4<003Y5000jA@02000?:@80008J0P001Ql2000V>P8006130P00P`d201bD00801H`0
0P00K3D2000f@`8000PR0P000QX2000G<08005e60P0?T002086d0080UkX00P0fWP02001/=P8002@i
0P000a/200088P8004Q;0P00R@420;G10080g8<00P3@Z00203^O008005m40P004B/200026@8001Xb
0P00KS<207fc0080iV@00P3a>@020=6U00804i400P00Bdd20007808000DN00<003m700B;0004R`00
0P3>[@020?@_0080kTH00P2[_`02001i8@8002Hj0P000aX2000<9`8005U90P0_V`020=>N0080jEP0
0P3EV@0203ZO008005i50P0042X200026@8001H_0P00HT4202jK0080_l<00P3:]`0206Z^008007XP
0P00=d@20006808000<K0P007cH2001R@@8028d00P1;Y00203bP0080084B0P00ED/2000E;P8000<J
0P001Ql2000T>@8005]70P00MRH00`00OaD007<[001c:`02001HBP80028h0P001b0200026@8000TS
0P0093T2001?CP8005a70P00FdL2001:C@80028g0P002R@200026P8000<K0P0032H2000M=08002ho
0P00<D42000V>P8001@^1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_oo
ool2000H<08001`c0P006302000>:08000HO0P000QT20004708000dW0P008cP20011B080051=0P00
Bdd2000_?`80018/0P0011d200026P8000/U0P00:cd2001HBP8006/f0P00Kc400`00H4<003Y5000j
A@02000?:@80008J0P001Ql2000V>P8006130P00P`d201bD00801H`00P00K3D2000f@`8000PR0P00
0QX2000G<08005e60P0?T002086d0080UkX00P0fWP02001/=P8002@i0P000a/200088P8004Q;0P00
R@420;G10080g8<00P3@Z00203^O008005m40P004B/200026@8001Xb0P00KS<207fc0080iV@00P3a
>@020=6U00804i400P00Bdd20007808000DN00<003m700B;0004R`000P3>[@020?@_0080kTH00P2[
_`02001i8@8002Hj0P000aX2000<9`8005U90P0_V`020=>N0080jEP00P3EV@0203ZO008005i50P00
42X200026@8001H_0P00HT4202jK0080_l<00P3:]`0206Z^008007XP0P00=d@20006808000<K0P00
7cH2001R@@8028d00P1;Y00203bP0080084B0P00ED/2000E;P8000<J0P001Ql2000T>@8005]70P00
MRH00`00OaD007<[001c:`02001HBP80028h0P001b0200026@8000TS0P0093T2001?CP8005a70P00
FdL2001:C@80028g0P002R@200026P8000<K0P0032H2000M=08002ho0P00<D42000V>P8001@^1Ooo
ool1o`00007ooooo0Oooool001Kooooo0_l00003ooooo`8001L`0P0073<2000G<08000hX0P001Ql2
00026@8000@L0P003BL2000S>08004180P00D4h2001:C@8002ho0P004R`200047@80008J0P002bD2
000Z?08005M:0P00JcL2001^<P03001P@`00>TD003Y5008000lY0P000QX200067`8002Di0P00Gd@2
00223`8069<00P03R`02001/=P8003E30P00228200026P8001H_0P00G4L200^>0080Nk800P2B^002
03>M008006/f0P0093T200036`8000PQ0P00AT/200271080[Kl00P3JR@020<j]0080>9h00P00Gd@2
000A:`80008I0P006S82001/=@80M[400P3TJ`020>m10080cjT00P0AT002001:C@8000LP0P001Ah0
0`00?DH008X0002:00020<bb0080lSP00P3/C@020:Jm008007PR0P009SX200036P8000`V0P00F4X2
02ZJ0080dJ@00P3WG`020=>N0080=ih00P00GDH2000@:P80008I0P005Rl2001Q@P80:YX00P2h`@02
0<Rk0080IZ`00P00NB42000g@`8000HP0P000a/2000O=@8006520P05S00204NS0080>9h00P00P1@2
001EB`8001D^0P000aX200067`8002@i0P00FTP2001e:003001n5`00LR`0078/008005M:0P008SL2
00078080008I0P002B<2000S>08004i>0P00FdL2001JB08004U<0P008CL2000:9080008J0P000a/2
000<9P8001dd0P00;Ch2000a@08002Di0P0052h4ooooo`;o00000_ooool001Kooooo00?o0000oooo
ooooool00_ooool2000G<08001`c0P005c02000>:08000HO0P000QT20004708000dW0P008cP20010
B080051>0P00BTd2000^?`80018/0P0011d200026P8000/U0P00:S`2001GBP8006/g0P00KS800`00
H4<003Y5000jA@02000?:@80008J0P001Ql2000U>@8005m40P00PPl201RC00800h/00P00K3H2000e
@`8000PR0P000QX2000F;`8005a70P0;SP0207^b0080T[P00P0cW@02001[=P8002@i0P000a/20008
8@8004I;0P00Q`@20:fo0080fXT00P3>[@0203RN008005m40P004B/200026@8001Xb0P00K3D207Ja
0080i6/00P3_@@020<nY00804I000P00BTd20007808000DN00<003e6002:0000RP000P3</P020?8h
0080k4d00P2V_@02001h8P8002Hj0P000aX2000<9P8005Q:0P0ZVP020=6T0080iel00P3CWP0203NN
008005e60P0042X200026@8001H_0P00HD8202ZJ0080^<400P38^`0206J/008007TQ0P00=d<20006
808000<K0P007cD2001Q@P801H`00P17X`0203RN0080080D0P00ED/2000E;P8000<J0P001Ql2000T
>@8005Y80P00MBP00`00OQL0078/001b;002001GBP80028g0P001b0200026@8000TS0P008cP2001>
CP8005]70P00FTP20019C080024g0P002R@200026P8000<K0P0032H2000M=08002dn0P00<D02000U
>@8001@^1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000G<080
01/c0P005c02000>:08000HO0P000QT20004708000dW0P008SP2000nA`8004m>0P00BD`2000]?P80
018/0P0011d200026P8000/U0P00:C`2001FBP8006Xh0P00KC@00`00Gd@003U4000iA002000?:@80
008J0P001Ql2000T>@8005m40P00PA8201FB008008X00P00JcL2000e@P8000PR0P000QX2000F;`80
05]70P08S@0207F`0080RkH00P0`W002001[=`8002@i0P000a/200088@8004A:0P00QPP20:Fm0080
f8l00P3</@0203FM008005m40P004B/200026@8001Ta0P00JcL206j_0080hG<00P3]B@020<j]0080
3i000P00BT`20007808000DN00<003]600280`00R0<00P3:^0020>m10080jUD00P2Q_002001h8`80
02Dj0P000aX2000<9P8005M:0P0UV0020<nZ0080iFL00P3BX`0203BM008005e60P0042X200026@80
01D^0P00H4<202FH0080/<000P37_`02066[008007PS0P00=T<20006808000<K0P007SD2001P@`80
0XX00P12XP0203BM008007lF0P00E4`2000E;P8000<J0P001Ql2000S>08005U80P00M2T00`00OAT0
074^001a;P02001FB`80024g0P001b0200026@8000TS0P008cP2001=CP8005]80P00FDP20018B`80
024g0P002R@200026P8000<K0P0032H2000M=08002dn0P00<402000T>@8001@]1Oooool1o`00007o
oooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000G<08001/c0P005c02000>:08000HO
0P000QT20004708000dW0P008SP2000nA`8004m>0P00BD`2000]?P80018/0P0011d200026P8000/U
0P00:C`2001FBP8006Xh0P00KC@00`00Gd@003U4000iA002000?:@80008J0P001Ql2000T>@8005m4
0P00PA8201FB008008X00P00JcL2000e@P8000PR0P000QX2000F;`8005]70P08S@0207F`0080RkH0
0P0`W002001[=`8002@i0P000a/200088@8004A:0P00QPP20:Fm0080f8l00P3</@0203FM008005m4
0P004B/200026@8001Ta0P00JcL206j_0080hG<00P3]B@020<j]00803i000P00BT`20007808000DN
00<003]600280`00R0<00P3:^0020>m10080jUD00P2Q_002001h8`8002Dj0P000aX2000<9P8005M:
0P0UV0020<nZ0080iFL00P3BX`0203BM008005e60P0042X200026@8001D^0P00H4<202FH0080/<00
0P37_`02066[008007PS0P00=T<20006808000<K0P007SD2001P@`800XX00P12XP0203BM008007lF
0P00E4`2000E;P8000<J0P001Ql2000S>08005U80P00M2T00`00OAT0074^001a;P02001FB`80024g
0P001b0200026@8000TS0P008cP2001=CP8005]80P00FDP20018B`80024g0P002R@200026P8000<K
0P0032H2000M=08002dn0P00<402000T>@8001@]1Oooool1o`00007ooooo0Oooool001Kooooo00?o
0000ooooooooool00_ooool2000G<08001/c0P005c02000>:08000HO0P000QT20004708000dW0P00
8CL2000mA`8004m>0P00B4/2000]?P80018/0P0011d200026P8000XU0P00:3/2001FB`8006Tj0P00
K3D00`00GTD003Q4000hA002000?:@80008J0P001Ql2000S>08005i50P00P1D2016A008008P20P00
JSP2000e@P8000PR0P000QX2000E;P8005Y80P04R`0206j_0080QKD00P0/VP02001Z>08002<h0P00
0a/200078@8004990P00Q0/209bk0080eYH00P3:]P0203:L008005i40P004B/200026@8001Pa0P00
JCT206N]0080gg`00P3[DP020<bb00803Hl00P00BT`20007808000DM00<003U500261`00QPL00P37
_P020>e;0080j5`00P2K^P02001g908002Dj0P000aX2000;9@8005I;0P0PUP020<f`0080hfl00P3@
Z002032L008005a60P0042X200026@8001D^0P00Gd@2022F0080Ykd00P35a00205^Y008007LT0P00
=D<20006808000<K0P007C@2001OA08008T10P0mX00202nK008007hH0P00E4`2000D;P8000<J0P00
1Ql2000R>08005U90P00Lb/00`00O1`0070_001`;`02001EB`80024g0P001b0200026@8000TS0P00
8cP2001<C@8005Y80P00FDT20016B`80020f0P002R@200026P8000<K0P0032H2000L=08002`n0P00
;cl2000T>@8001<]1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2
000G<08001/c0P005c02000>:08000HO0P000QT20004708000dW0P008CL2000mA`8004m>0P00B4/2
000]?P80018/0P0011d200026P8000XU0P00:3/2001FB`8006Tj0P00K3D00`00GTD003Q4000hA002
000?:@80008J0P001Ql2000S>08005i50P00P1D2016A008008P20P00JSP2000e@P8000PR0P000QX2
000E;P8005Y80P04R`0206j_0080QKD00P0/VP02001Z>08002<h0P000a/200078@8004990P00Q0/2
09bk0080eYH00P3:]P0203:L008005i40P004B/200026@8001Pa0P00JCT206N]0080gg`00P3[DP02
0<bb00803Hl00P00BT`20007808000DM00<003U500261`00QPL00P37_P020>e;0080j5`00P2K^P02
001g908002Dj0P000aX2000;9@8005I;0P0PUP020<f`0080hfl00P3@Z002032L008005a60P0042X2
00026@8001D^0P00Gd@2022F0080Ykd00P35a00205^Y008007LT0P00=D<20006808000<K0P007C@2
001OA08008T10P0mX00202nK008007hH0P00E4`2000D;P8000<J0P001Ql2000R>08005U90P00Lb/0
0`00O1`0070_001`;`02001EB`80024g0P001b0200026@8000TS0P008cP2001<C@8005Y80P00FDT2
0016B`80020f0P002R@200026P8000<K0P0032H2000L=08002`n0P00;cl2000T>@8001<]1Oooool1
o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000F;`8001Xb0P005Rl2000=
:08000HO0P000QT20004708000`W0P008CL2000lAP8004e>0P00AT/2000/?@80018[0P0011d20002
6P8000XT0P009c/2001EB`8006Pk0P00JcH00`00GDD003M4000gA002000?:@8000<J0P001Ql2000S
>08005e60P00OQL200f?008008L50P00JCT2000d@P8000PR0P000QX2000D;P8005U90P00R@0206N]
0080OK<00P0XV@02001Y>@8002<h0P000a/200078@8004180P00PPl209:h0080e9d00P38^`0202jK
008005i50P004R/200026@8001L`0P00J3/205jZ0080g8D00P3XF`020<Zg00802Xh00P00BD`20007
808000@M00<003M400242`00Q0/00P34a0020>YE0080iFD00P2E^@02001g9@8002Dj0P000aX2000;
9@8005A<0P0KU0020<Zg0080h7L00P3>[P0202bJ008005a70P0042X200026@8001@^0P00GTD201^D
0080W[/00P2l`P0205JX008007HV0P00=D820006808000<K0P007C@2001NA@8008L40P0hWP0202ZJ
008007dJ0P00Dd`2000D;P8000<J0P001Ql2000R=`8005Q90P00LRd00`00Nah006la001_<@02001E
B`80020f0P001R0200026@8000TS0P008SP2001;C@8005U90P00F4X20015BP8001lf0P002B<20002
6P8000<K0P0032H2000L<`8002/m0P00;Sl2000S>08001<]1Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool2000F;`8001Xb0P005Rl2000=:08000DO0P000QT200047080
00`V0P0083H2000kA@8004a=0P00ADX2000[?@80014[0P0011d200026P8000XT0P009cX2001DC080
06Ll0P00JSP00`00GDH003I3000f@`02000?:@8000<J0P001Ql2000R=`8005]70P00OAX200V=0080
08H80P00J3X2000c@P8000PR0P000QX2000D;@8005M:0P00R0<205nZ0080M[400P0TV002001Y>P80
02<h0P000a`20007808003i70P00P1<208Vf0080dJ@00P36`00202ZJ008005i50P004R/200026@80
01H_0P00IS`205JX0080fHd00P3VI0020<Rk008028d00P00BD`200078@8000@M00<003E300223`00
PPl00P2i`P020>MO0080hfh00P2>]`02001f9`8002Dj0P000a/2000;9@8005=<0P0ETP020<Nn0080
gH000P3;]00202RI008005]70P0042X200026@8001@]0P00G4H201JC0080UKT00P2b`002052V0080
07DX0P00=4820006808000<K0P0073@2001MA@8008H70P0bW00202FH008007/M0P00DTd2000D;@80
00<J0P001Ql2000Q=`8005M:0P00LBl00`00NB0006hc001^<`02001DC08001lf0P001R0200026@80
00TS0P008SL20019C08005Q90P00EdX20013B@8001le0P002B<200026P8000<K0P0032H2000K<`80
02/m0P00;Ch2000R>08001</1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool2000F;`8001Xb0P005Rl2000=:08000DO0P000QT20004708000`V0P0083H2000kA@8004a=
0P00ADX2000[?@80014[0P0011d200026P8000XT0P009cX2001DC08006Ll0P00JSP00`00GDH003I3
000f@`02000?:@8000<J0P001Ql2000R=`8005]70P00OAX200V=008008H80P00J3X2000c@P8000PR
0P000QX2000D;@8005M:0P00R0<205nZ0080M[400P0TV002001Y>P8002<h0P000a`20007808003i7
0P00P1<208Vf0080dJ@00P36`00202ZJ008005i50P004R/200026@8001H_0P00IS`205JX0080fHd0
0P3VI0020<Rk008028d00P00BD`200078@8000@M00<003E300223`00PPl00P2i`P020>MO0080hfh0
0P2>]`02001f9`8002Dj0P000a/2000;9@8005=<0P0ETP020<Nn0080gH000P3;]00202RI008005]7
0P0042X200026@8001@]0P00G4H201JC0080UKT00P2b`002052V008007DX0P00=4820006808000<K
0P0073@2001MA@8008H70P0bW00202FH008007/M0P00DTd2000D;@8000<J0P001Ql2000Q=`8005M:
0P00LBl00`00NB0006hc001^<`02001DC08001lf0P001R0200026@8000TS0P008SL20019C08005Q9
0P00EdX20013B@8001le0P002B<200026P8000<K0P0032H2000K<`8002/m0P00;Ch2000R>08001</
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000E;`8001Tb0P00
5Rl2000=9`8000DO0P000QT20004708000`V0P007cH2000iA@8004Y<0P00A4T2000Z?@80014[0P00
11d200026P8000XT0P009SX2001CC08006Dn0P00JCT00`00G4L003I3000f@`02000?:@8000<J0P00
1Al2000Q=`8005Y80P00Nad200F<008008@;0P00J3/2000c@@8000PR0P000QX2000C;@8005I;0P00
QPP205RX0080Kjl00P0PUP02001X>`8002<h0P0011`20007808003a60P00OQL207nc0080cZ/00P33
a00202JH008005e60P004R`200026@8001H_0P00ICh204jU0080eYH00P3SKP020<K100801H`00P00
B4`200078@8000@M00<003=200205000P1@00P2]_`020>AZ0080h7L00P27]@02001e:08002Di0P00
0a/2000:9080059=0P0?T0020<G40080fXT00P39^@0202BH008005]80P0042X200026@8001<]0P00
FdL2016A0080S;L00P2Y_P0204ZT008007@Z0P00<d420006808000<K0P006c<2001LAP8008@;0P0/
VP02022F008007XO0P00DDd2000C;@8000<J0P001Ql2000Q=`8005I;0P00L3000`00N2<006dd001]
=002001CC08001le0P001R0200026@8000TS0P008CL20018B`8005M:0P00ET/20011B@8001he0P00
2B<200026P8000<K0P0032H2000K<`8002Xl0P00;3h2000Q=`80018/1Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool2000E;`8001Tb0P005Rl2000=9`8000DO0P000QT2
0004708000`V0P007cH2000iA@8004Y<0P00A4T2000Z?@80014[0P0011d200026P8000XT0P009SX2
001CC08006Dn0P00JCT00`00G4L003I3000f@`02000?:@8000<J0P001Al2000Q=`8005Y80P00Nad2
00F<008008@;0P00J3/2000c@@8000PR0P000QX2000C;@8005I;0P00QPP205RX0080Kjl00P0PUP02
001X>`8002<h0P0011`20007808003a60P00OQL207nc0080cZ/00P33a00202JH008005e60P004R`2
00026@8001H_0P00ICh204jU0080eYH00P3SKP020<K100801H`00P00B4`200078@8000@M00<003=2
00205000P1@00P2]_`020>AZ0080h7L00P27]@02001e:08002Di0P000a/2000:9080059=0P0?T002
0<G40080fXT00P39^@0202BH008005]80P0042X200026@8001<]0P00FdL2016A0080S;L00P2Y_P02
04ZT008007@Z0P00<d420006808000<K0P006c<2001LAP8008@;0P0/VP02022F008007XO0P00DDd2
000C;@8000<J0P001Ql2000Q=`8005I;0P00L3000`00N2<006dd001]=002001CC08001le0P001R02
00026@8000TS0P008CL20018B`8005M:0P00ET/20011B@8001he0P002B<200026P8000<K0P0032H2
000K<`8002Xl0P00;3h2000Q=`80018/1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool2000E;P8001Ta0P005Bl2000=9`8000DN0P000QT20003708000`V0P007cD2000h
A08004Q<0P00@TT2000Y?080014[0P0011d200026P8000XT0P009CT2001BC@8006@o0P00J3/00`00
FdL003E2000e@P02000>:@8000<J0P001Ah2000P=P8005U90P00NR02006:008008<>0P00Ic`2000b
@@8000PR0P000QX2000C;08005E;0P00Q0`2052V0080Ijd00P0LU002001W>`8002<h0P0011`20006
808003U50P00O1/207Fa0080c;<00P2i`P0202:G008005e60P004R`200026@8001D^0P00Hd0204FS
0080dil00P3PN0020<;400800X/00P00B4/200078@8000@L00<00350001n6000OQP00P2Q_0020>5e
0080gH000P20/`02001d:@8002Di0P000a/2000:9080055=0P0:SP020;W20080ei800P37_`02022F
008005Y80P0042X200026@80018/0P00FTP200b>0080P[@00P2O^`0204>R008007<[0P00<T420006
808000<K0P006c<2001KA`80088?0P0WV00201^D008007TR0P00DDd2000C;@8000<J0P001Ql2000P
=P8005E;0P00KS800`00MbD006/f001[=P02001BC@8001he0P001Ql200026@8000TS0P0083L20016
B`8005I:0P00ED/20010B08001dd0P002B<200026P8000<K0P002bH2000K<`8002Tl0P00:cd2000Q
=`80018/1Oooool1o`00007ooooo0Oooool001Kooooo0_l00003ooooo`8001D^0P006C42000E;`80
00dW0P001Ah200026@8000<L0P0032H2000O=@8003Q40P00B4`20012B@8002Tl0P004B/200047@80
008J0P002R@2000U>@80059=0P00I3l2001X>`03001KA`00=D8003E2008000hY0P000aX200057P80
020f0P00FDT2001j80800HX00P00P`h2001W?08003910P00228200026P8001</0P00ED/200243080
D:H00P1W[@0201bD008006Lk0P008cP20004708000HP0P00>DD2001l6`80MK400P3</`020;W20080
8YL00P00GDH2000B;080008I0P005Bh2001S@080AJ<00P3CW`020>1h0080`/@00P02R`020018B`80
00LQ0P0011`00`00<D0007hH001n60020:6l0080hGD00P3MP002082c008007@Y0P009CT200036`80
00XT0P00DDd200Z>0080^L800P3GTP020<No008089H00P00FTP2000@:P80008I0P004R`2001JB080
38h00P22]00209nk0080@j800P00Lb/2000b@@8000HP0P000a/2000K<`8005]70P00PPl202NH0080
6i@00P00NB82001AC@8001<]0P000aX200067`80020f0P00ED/2001^<P03001g9@00JcH006/f0080
059=0P007SD200067`80008I0P002B<2000P=`8004I;0P00ETX2001EB`8004180P007C@200098`80
008J0P000a/2000;9P8001/c0P00:C`2000[?@80024g0P004R`4ooooo`;o00000_ooool001Kooooo
00?o0000ooooooooool00_ooool2000E;P8001Pa0P005Bh2000=9`8000DN0P000QT20003708000/V
0P007SD2000g@`8004I;0P00@4P2000Y?080014[0P0011d200026@8000TT0P0093T2001AC@8006=0
0P00Ic`00`00FTP003A2000d@P02000>:08000<J0P001Ah2000O=@8005Q:0P00N2<200280P80084A
0P00ISd2000a@08000PR0P000QT2000B;08005A<0P00PQ0204RS0080GjX00P0GT`02001V?080028h
0P0011`20006808003M40P00NQl206^^0080bKX00P2__`0201jE008005a60P004R`200026@8001@]
0P00HD8203bP0080cjT00P3MPP020;S2008008T00P00Ad/200078@8000@L00<002lo001l7000O1`0
0P2D^@020=f00080fXT00P1h/@02001c:`8002Di0P000a/20009908004m>0P04R`020:bo0080e9/0
0P32a00201^D008005U90P0042X200026@80018/0P00F4T200N<0080N;400P2D^@0203fP0080078]
0P00<D020006808000<K0P006S82001JB080084B0P0QUP0201JB008007LU0P00D4h2000C;08000<J
0P001Ql2000O=P8005A<0P00KC@00`00MBP006Xh001Z>002001AC@8001dd0P001Ql200026@8000TS
0P0083H20015BP8005E;0P00E4`2000nA`8001`d0P002B<200026P8000<K0P002bH2000J<P8002Pk
0P00:Sd2000P=P80014[1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_oo
ool2000E;P8001Pa0P005Bh2000=9`8000DN0P000QT20003708000/V0P007SD2000g@`8004I;0P00
@4P2000Y?080014[0P0011d200026@8000TT0P0093T2001AC@8006=00P00Ic`00`00FTP003A2000d
@P02000>:08000<J0P001Ah2000O=@8005Q:0P00N2<200280P80084A0P00ISd2000a@08000PR0P00
0QT2000B;08005A<0P00PQ0204RS0080GjX00P0GT`02001V?080028h0P0011`20006808003M40P00
NQl206^^0080bKX00P2__`0201jE008005a60P004R`200026@8001@]0P00HD8203bP0080cjT00P3M
PP020;S2008008T00P00Ad/200078@8000@L00<002lo001l7000O1`00P2D^@020=f00080fXT00P1h
/@02001c:`8002Di0P000a/20009908004m>0P04R`020:bo0080e9/00P32a00201^D008005U90P00
42X200026@80018/0P00F4T200N<0080N;400P2D^@0203fP0080078]0P00<D020006808000<K0P00
6S82001JB080084B0P0QUP0201JB008007LU0P00D4h2000C;08000<J0P001Ql2000O=P8005A<0P00
KC@00`00MBP006Xh001Z>002001AC@8001dd0P001Ql200026@8000TS0P0083H20015BP8005E;0P00
E4`2000nA`8001`d0P002B<200026P8000<K0P002bH2000J<P8002Pk0P00:Sd2000P=P80014[1Ooo
ool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000D;P8001P`0P0052h2
000<9`8000DN0P000QT200036`8000/U0P007C@2000e@P8004A:0P00?dL2000X>`80010Z0P0011d2
00026@8000TS0P008cP2001@CP8006910P00ICh00`00FDT003=1000c@@02000>:08000<J0P001Ah2
000N=@8005M:0P00MRH200261`80080E0P00I3l2000a@08000PR0P000QT2000A:`80059=0P00P1@2
042Q0080EjP00P0BT@02001U?@80028h0P0011`200067`8003E20P00N2<2066[0080a/800P2T_@02
01ZD008005]70P004R`200026@8001<]0P00Gd@203BM0080c;800P3IS0020:jo008008P30P00AT/2
00078@8000@L00<002dn001j8000NR000P28]P020=Z;0080ei800P1`[`02001b;08002@i0P000a/2
00098`8004e>0P00R@4209nk0080dJ@00P2g`@0201NC008005U90P0042X200026@80014[0P00EdX2
006:0080KZl00P2:]P0203JN0080070_0P00<4020006808000<K0P006C82001IB@8007lF0P0KU002
016@008007DW0P00Cdh2000B;08000<J0P001Al2000O=@8005=<0P00JcH00`00LbX006Tj001Y>P02
001@CP8001`d0P001Ql200026@8000TS0P007cH20013B@8005A<0P00Dd`2000lAP8001/c0P002282
00026P8000<K0P002bD2000J<P8002Lk0P00:C`2000O=P80014[1Oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_ooool2000D;P8001P`0P0052h2000<9`8000DN0P000QT20003
6`8000/U0P007C@2000e@P8004A:0P00?dL2000X>`80010Z0P0011d200026@8000TS0P008cP2001@
CP8006910P00ICh00`00FDT003=1000c@@02000>:08000<J0P001Ah2000N=@8005M:0P00MRH20026
1`80080E0P00I3l2000a@08000PR0P000QT2000A:`80059=0P00P1@2042Q0080EjP00P0BT@02001U
?@80028h0P0011`200067`8003E20P00N2<2066[0080a/800P2T_@0201ZD008005]70P004R`20002
6@8001<]0P00Gd@203BM0080c;800P3IS0020:jo008008P30P00AT/200078@8000@L00<002dn001j
8000NR000P28]P020=Z;0080ei800P1`[`02001b;08002@i0P000a/200098`8004e>0P00R@4209nk
0080dJ@00P2g`@0201NC008005U90P0042X200026@80014[0P00EdX2006:0080KZl00P2:]P0203JN
0080070_0P00<4020006808000<K0P006C82001IB@8007lF0P0KU002016@008007DW0P00Cdh2000B
;08000<J0P001Al2000O=@8005=<0P00JcH00`00LbX006Tj001Y>P02001@CP8001`d0P001Ql20002
6@8000TS0P007cH20013B@8005A<0P00Dd`2000lAP8001/c0P00228200026P8000<K0P002bD2000J
<P8002Lk0P00:C`2000O=P80014[1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooooooo
ool00_ooool2000D;@8001L`0P0052d2000<9`8000DN0P000QT200036`8000/U0P0073@2000d@P80
04=90P00?DH2000W>P80010Z0P0011d200026@8000TS0P008SL2001?CP8006130P00I3l00`00F4X0
0351000a@@02000>:08000<J0P001Ah2000M=08005E;0P00M2T200242`8007hH0P00Hd02000`@080
00PR0P000QT2000A:`80055=0P00OQT203RN0080CZD00P0>S`02001T?`80028g0P0011`200067`80
03=10P00MRH205NX0080_<800P2J^P0201FB008005]70P004R`200026@80018/0P00GTD202^J0080
bK/00P3FUP020:>m008008L60P00ATX200078@8000@L00<002/m001g9000Mb@00P1k/P020=JF0080
e9`00P1X[@02001a;P8002@i0P000a/200098`8004Y=0P00QPH209:h0080cZd00P2[_P0201:A0080
05Q:0P0042X200026@80014[0P00ET/200280`80I:`00P1o/`02032L008006la0P00;cl200068080
00<K0P006342001GBP8007dJ0P0ETP0200^>008007@Z0P00CDh2000B;08000<J0P001Ah2000N=@80
059=0P00JSP00`00LRd006Ll001W?002001?CP8001/c0P001Ql200026@8000TS0P007cD20011B080
05=<0P00DTd2000jA@8001/c0P00228200026P8000<K0P002bD2000I<P8002Hj0P00:3/2000N=@80
010Z1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000D;@8001L`
0P0052d2000<9`8000DN0P000QT200036`8000/U0P0073@2000d@P8004=90P00?DH2000W>P80010Z
0P0011d200026@8000TS0P008SL2001?CP8006130P00I3l00`00F4X00351000a@@02000>:08000<J
0P001Ah2000M=08005E;0P00M2T200242`8007hH0P00Hd02000`@08000PR0P000QT2000A:`80055=
0P00OQT203RN0080CZD00P0>S`02001T?`80028g0P0011`200067`8003=10P00MRH205NX0080_<80
0P2J^P0201FB008005]70P004R`200026@80018/0P00GTD202^J0080bK/00P3FUP020:>m008008L6
0P00ATX200078@8000@L00<002/m001g9000Mb@00P1k/P020=JF0080e9`00P1X[@02001a;P8002@i
0P000a/200098`8004Y=0P00QPH209:h0080cZd00P2[_P0201:A008005Q:0P0042X200026@80014[
0P00ET/200280`80I:`00P1o/`02032L008006la0P00;cl20006808000<K0P006342001GBP8007dJ
0P0ETP0200^>008007@Z0P00CDh2000B;08000<J0P001Ah2000N=@80059=0P00JSP00`00LRd006Ll
001W?002001?CP8001/c0P001Ql200026@8000TS0P007cD20011B08005=<0P00DTd2000jA@8001/c
0P00228200026P8000<K0P002bD2000I<P8002Hj0P00:3/2000N=@80010Z1Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool00_ooool2000C;@8001L`0P0052d2000<9P8000DN0P00
0QT200036`8000/U0P0073<2000b@@8004580P00>dH2000V>P80010Z0P0011d200026@8000TS0P00
8CL2001=CP8005m40P00Hd400`00EdX00310000`@002000>:08000<J0P001Ah2000L<`8005A<0P00
LR`200223`8007`K0P00HT42000_?`8000PR0P000QT2000@:P80051>0P00Nad2032L0080AZ<00P09
S@02001S@080024g0P0011`200067`8003500P00M2X204bU0080[[l00P2?]`02016@008005Y80P00
4R`200026@80014[0P00G4L202>G0080aL<00P3CX00209Vj008008D90P00ADX200088@8000@L00<0
02Tl001e:000MBP00P1_[`020=:P0080dJD00P1PZ`02001`<08002@i0P000a/200088P8004M;0P00
Q0`208Fe0080b[H00P2O_00200f?008005M:0P0042X200026@80010Z0P00E4`200252080FZT00P1d
/00202VI008006dc0P00;Sl200067`8000<K0P006302001FB`8007/M0P0?T00200J<0080078]0P00
Bdd2000A:`8000<J0P001Ah2000M=080055=0P00JCX00`00L30006Hm001V?@02001=CP8001/c0P00
1Ql200026@8000TR0P007SD20010B080059=0P00DDd2000hA08001Xb0P00228200026P8000<K0P00
2bD2000I<@8002Dj0P009c/2000M=080010Z1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000
ooooooooool00_ooool2000C;@8001L`0P0052d2000<9P8000DN0P000QT200036`8000/U0P0073<2
000b@@8004580P00>dH2000V>P80010Z0P0011d200026@8000TS0P008CL2001=CP8005m40P00Hd40
0`00EdX00310000`@002000>:08000<J0P001Ah2000L<`8005A<0P00LR`200223`8007`K0P00HT42
000_?`8000PR0P000QT2000@:P80051>0P00Nad2032L0080AZ<00P09S@02001S@080024g0P0011`2
00067`8003500P00M2X204bU0080[[l00P2?]`02016@008005Y80P004R`200026@80014[0P00G4L2
02>G0080aL<00P3CX00209Vj008008D90P00ADX200088@8000@L00<002Tl001e:000MBP00P1_[`02
0=:P0080dJD00P1PZ`02001`<08002@i0P000a/200088P8004M;0P00Q0`208Fe0080b[H00P2O_002
00f?008005M:0P0042X200026@80010Z0P00E4`200252080FZT00P1d/00202VI008006dc0P00;Sl2
00067`8000<K0P006302001FB`8007/M0P0?T00200J<0080078]0P00Bdd2000A:`8000<J0P001Ah2
000M=080055=0P00JCX00`00L30006Hm001V?@02001=CP8001/c0P001Ql200026@8000TR0P007SD2
0010B080059=0P00DDd2000hA08001Xb0P00228200026P8000<K0P002bD2000I<@8002Dj0P009c/2
000M=080010Z1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000C
;08001H_0P004bd2000<9P8000DN0P000QT200036`8000XU0P006c<2000`@08003m70P00>TD2000U
>@8000lZ0P0011d200026@8000TS0P0083H2001:C@8005e50P00HD800`00ET/002lo000_?`02000>
:08000<J0P001Ah2000K<`8005==0P00L2l20020508007XO0P00HD82000^?`8000PR0P000QT2000?
:P8004i>0P00NB4202RI0080?Z000P04R`02001R@@80024g0P0011`200057P8002ho0P00LBh204:R
0080X;`00P24]@0200b>008005U80P004R`200026@80014[0P00FTP201ZD0080]l400P3?ZP0208jg
008008@<0P00A4X200088@8000<K00<002Lk001b;000LR`00P1S[0020<n[0080cJh00P1HZ002001_
<@8002<h0P000a/200088P8004A:0P00PA4207Vb0080akl00P2D^@0200R=008005I;0P0042X20002
6@8000lZ0P00Dd`200233P80D:H00P1Z[@0202:G008006`e0P00;Ch200067`8000<K0P005c02001E
B`8007TQ0P09S@02002:0080070_0P00BD`2000A:`8000<J0P001Ah2000L=080051>0P00Ic`00`00
KS8006@o001T?`02001:C@8001Xb0P001Ql200026@8000PR0P007C@2000nA`80055=0P00D4h2000g
@`8001Ta0P00224200026P8000<L0P002bD2000H<@8002@i0P009SX2000L=08000lZ1Oooool1o`00
007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000C;08001H_0P004bd2000<9P80
00DN0P000QT200036`8000XU0P006c<2000`@08003m70P00>TD2000U>@8000lZ0P0011d200026@80
00TS0P0083H2001:C@8005e50P00HD800`00ET/002lo000_?`02000>:08000<J0P001Ah2000K<`80
05==0P00L2l20020508007XO0P00HD82000^?`8000PR0P000QT2000?:P8004i>0P00NB4202RI0080
?Z000P04R`02001R@@80024g0P0011`200057P8002ho0P00LBh204:R0080X;`00P24]@0200b>0080
05U80P004R`200026@80014[0P00FTP201ZD0080]l400P3?ZP0208jg008008@<0P00A4X200088@80
00<K00<002Lk001b;000LR`00P1S[0020<n[0080cJh00P1HZ002001_<@8002<h0P000a/200088P80
04A:0P00PA4207Vb0080akl00P2D^@0200R=008005I;0P0042X200026@8000lZ0P00Dd`200233P80
D:H00P1Z[@0202:G008006`e0P00;Ch200067`8000<K0P005c02001EB`8007TQ0P09S@02002:0080
070_0P00BD`2000A:`8000<J0P001Ah2000L=080051>0P00Ic`00`00KS8006@o001T?`02001:C@80
01Xb0P001Ql200026@8000PR0P007C@2000nA`80055=0P00D4h2000g@`8001Ta0P00224200026P80
00<L0P002bD2000H<@8002@i0P009SX2000L=08000lZ1Oooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool00_ooool2000B;08001D_0P004b`2000<9P8000DN0P000QT200036`8000XT
0P006S82000_?`8003e60P00>4@2000T>@8000lY0P0011d200026@8000PR0P007cD20018B`8005a7
0P00H4<00`00E4`002ho000^?`02000=:08000<J0P001Ad2000J<P80055=0P00Kc82001n608007PR
0P00H4<2000]?P8000PR0P000QT2000?:@8004]=0P00MbD2022F0080=Yh00P00R@02001Q@P80024g
0P0011`200057P8002`n0P00Kc4203VO0080TkP00P1i/P0200N=008005U90P004R`200026@80010Z
0P00F4T201:A0080Ykd00P3;]00208>d0080088@0P00@dT200088@8000<K00<002Dj001`<000L300
0P1GZ0020<^e0080b[L00P1@YP02001^<`8002<h0P000a/200088P8004580P00OaH206b^0080_l<0
0P28]P0200>;008005E;0P003bX200026@8000lY0P00DDd200214`80AZ<00P1OZP0201^D008006Xg
0P00;3h200067`8000<K0P005Rl2001DC08007LU0P03R`020027108006lb0P00AT/2000A:`8000<J
0P001Ah2000L<`8004m>0P00ICd00`00KC@00691001R@@020018B`8001Ta0P001Ah200026@8000PR
0P007C@2000lAP80051>0P00Cdh2000e@P8001Pa0P001b4200026@8000<L0P002bD2000H<08002<h
0P009CT2000K<`8000lY1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_oo
ool2000B;08001D_0P004b`2000<9P8000DN0P000QT200036`8000XT0P006S82000_?`8003e60P00
>4@2000T>@8000lY0P0011d200026@8000PR0P007cD20018B`8005a70P00H4<00`00E4`002ho000^
?`02000=:08000<J0P001Ad2000J<P80055=0P00Kc82001n608007PR0P00H4<2000]?P8000PR0P00
0QT2000?:@8004]=0P00MbD2022F0080=Yh00P00R@02001Q@P80024g0P0011`200057P8002`n0P00
Kc4203VO0080TkP00P1i/P0200N=008005U90P004R`200026@80010Z0P00F4T201:A0080Ykd00P3;
]00208>d0080088@0P00@dT200088@8000<K00<002Dj001`<000L3000P1GZ0020<^e0080b[L00P1@
YP02001^<`8002<h0P000a/200088P8004580P00OaH206b^0080_l<00P28]P0200>;008005E;0P00
3bX200026@8000lY0P00DDd200214`80AZ<00P1OZP0201^D008006Xg0P00;3h200067`8000<K0P00
5Rl2001DC08007LU0P03R`020027108006lb0P00AT/2000A:`8000<J0P001Ah2000L<`8004m>0P00
ICd00`00KC@00691001R@@020018B`8001Ta0P001Ah200026@8000PR0P007C@2000lAP80051>0P00
Cdh2000e@P8001Pa0P001b4200026@8000<L0P002bD2000H<08002<h0P009CT2000K<`8000lY1Ooo
ool1o`00007ooooo0Oooool001Kooooo0_l00003ooooo`80018/0P005Bh2000B;08000/V0P001Ah2
00026@8000<K0P002R@2000I<P8002dn0P00>dD2000f@`8002<h0P003bT200047@80008I0P002282
000N=@8004E:0P00FTP2001NA@03001CC000;Ch002dn008000dW0P000aX200057@8001Ta0P00D4h2
001]=@8007`L0P00MbD2001NA08002`n0P00228200026@8000hX0P00Ad/2001d:@8069<00P0]V`02
00271@8006130P0083H20004708000DN0P00:Sd2001]=080;i/00P25]@0206j_00800X/00P00F4X2
000B;080008I0P003bT2001FB`802Xh00P2H^P020<Nm0080N;400P00P1<20012B@8000PQ0P000a/0
0`008cT006hc001^<`0204^T0080akl00P36`00204NS008006`e0P008cP200036`8000LQ0P00?TL2
001l7080H:/00P2__`0207bb008008T00P00E4`2000?:@80008I0P003RP2001@CP8007hG0P0mX002
05BW00805I800P00JCT2000[?@8000HO0P000a/2000F;`80059=0P00MBP200280P8008D90P00KCD2
0014BP80010Z0P000aX200057P8001/c0P00CTh2001T?`03001[=`00HD800652008004E:0P006342
00057P80008I0P002282000L=08003Y50P00Cdh2001<C@8003=10P005c0200078@80008I0P000a`2
000;9@8001L`0P008SP2000T>@8001/b0P003RT4ooooo`;o00000_ooool001Kooooo00?o0000oooo
ooooool00_ooool2000B;08001D^0P004R`2000;9P8000DN0P000QT200036`8000XT0P006C82000]
?P8003]50P00=T<2000S>08000lY0P0011d200026@8000PR0P007SD20015BP8005Y80P00GTD00`00
Dd`002dn000]?P02000=9`8000<J0P001Ad2000I<@80051>0P00KCD2001l708007LU0P00GT@2000/
?P8000PR0P000QT2000>:08004M;0P00M2T201RC0080;I/00P00Q`D2001P@`80020f0P0011`20005
7P8002Xm0P00KC@202nK0080QKD00P1^[`0200:;008005Q:0P004R`200026@8000lY0P00ET/200Z>
0080V;X00P37_@0207Ra0080080C0P00@TT200088@8000<K00<002<i001^<`00KS<00P1;Y0020<No
0080a/000P17X`02001/=@8002<h0P000a/200078@8003i70P00O1`2062[0080[kl00P1l/P020029
008005A<0P003bT200026@8000hX0P00D4h2001n5`80?J000P1DY`0201FB008006Ti0P00:cd20006
7`8000<K0P005Rl2001BC@8007DX0P00R08200252@8006de0P00A4X2000@:P8000<J0P001Ah2000K
<`8004i>0P00I3l00`00JcL00652001Q@P020015BP8001Pa0P001Ah200026@8000PR0P0073@2000j
A@8004m>0P00C4d2000c@@8001L`0P001b4200026@8000<L0P002bD2000G<080028h0P0093T2000K
<P8000hY1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000A:`80
01@^0P004R`2000;9@8000DN0P000QT200036`8000XT0P006342000/?@8003U40P00=482000R=`80
00hY0P0011d200026@8000PR0P0073@20013B@8005U90P00GDH00`00DTd002/m000[?@02000=9`80
00<J0P0011d2000H<@8004i>0P00JcL2001i808007DY0P00GDH2000[?@8000PR0P000QT2000>:080
04A:0P00LRd2016@00809IP00P00Q@T2001OA080020f0P0011`200057P8002Pk0P00JSP202FH0080
N;400P1SZ`0200290@8005M:0P004R/200026@8000hX0P00E4`200:;0080R;H00P31a00206f^0080
07lG0P00@DP200088P8000<K00<0028g001[=`00JcL00P10X@020;g30080_<800P0oX@02001[=`80
028h0P000a/200078@8003]50P00NB0205BW0080X;`00P1`[`0200271@8005=<0P003bT200026@80
00hX0P00CTh2001l7080<id00P1:Y00200j?008006Lk0P00:S`200067`8000<J0P005Bh2001AC@80
07<[0P00QPL200233`8006/g0P00@TT2000@:P8000<J0P001Ah2000J<P8004]=0P00HT400`00JCT0
05m4001OA0020012B@8001L`0P001Ah200026@8000PR0P006c<2000iA08004e>0P00BD`2000a@080
01H_0P001b4200026@8000<L0P002RD2000G<080024g0P008SP2000J<P8000hX1Oooool1o`00007o
oooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000A:`8001@^0P004R`2000;9@8000DN
0P000QT200036`8000XT0P006342000/?@8003U40P00=482000R=`8000hY0P0011d200026@8000PR
0P0073@20013B@8005U90P00GDH00`00DTd002/m000[?@02000=9`8000<J0P0011d2000H<@8004i>
0P00JcL2001i808007DY0P00GDH2000[?@8000PR0P000QT2000>:08004A:0P00LRd2016@00809IP0
0P00Q@T2001OA080020f0P0011`200057P8002Pk0P00JSP202FH0080N;400P1SZ`0200290@8005M:
0P004R/200026@8000hX0P00E4`200:;0080R;H00P31a00206f^008007lG0P00@DP200088P8000<K
00<0028g001[=`00JcL00P10X@020;g30080_<800P0oX@02001[=`80028h0P000a/200078@8003]5
0P00NB0205BW0080X;`00P1`[`0200271@8005=<0P003bT200026@8000hX0P00CTh2001l7080<id0
0P1:Y00200j?008006Lk0P00:S`200067`8000<J0P005Bh2001AC@8007<[0P00QPL200233`8006/g
0P00@TT2000@:P8000<J0P001Ah2000J<P8004]=0P00HT400`00JCT005m4001OA0020012B@8001L`
0P001Ah200026@8000PR0P006c<2000iA08004e>0P00BD`2000a@08001H_0P001b4200026@8000<L
0P002RD2000G<080024g0P008SP2000J<P8000hX1Oooool1o`00007ooooo0Oooool001Kooooo00?o
0000ooooooooool00_ooool2000A:`8001@]0P004B/2000;9@8000DN0P000QT200036`8000TT0P00
6302000Z?@8003M30P00<T42000Q=`8000hX0P0011d200026@8000PR0P006c<20010B08005M:0P00
FdL00`00DDd002Xm000Z?@02000=9`8000<J0P0011d2000G<08004]=0P00J3X2001g908007</0P00
G4L2000Z?08000PR0P000QT2000=9`8004580P00L30200V=00807ID00P00P`h2001NA@8001lf0P00
11`200057@8002Hj0P00J3X201bE0080JZh00P1HZ00200261P8005I;0P004B/200026@8000hX0P00
DTd200271080NK800P2``00206:[008007dJ0P00?dP200088P8000<K00<0020f001Y>P00JCX00P0e
W@020:^n0080[;l00P0fWP02001Z>080028g0P000a/20007808003Q40P00MbD204RS0080T;P00P1T
[00200242P80059=0P003bT200026@8000dW0P00Bdd2001i8@80:YT00P10X@0200N=008006Hm0P00
:3`200067`8000<J0P0052h2001?CP80074_0P00P`d20020508006Ti0P00?dL2000?:@8000<J0P00
1Ah2000J<P8004U<0P00HD<00`00Ic`005e5001MA@020010B08001H_0P001Ah200026@8000PR0P00
6c<2000g@`8004]=0P00AT/2000_?`8001D_0P001b0200026@8000<L0P002R@2000F;`80020g0P00
8CL2000I<@8000dX1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2
000A:`8001@]0P004B/2000;9@8000DN0P000QT200036`8000TT0P006302000Z?@8003M30P00<T42
000Q=`8000hX0P0011d200026@8000PR0P006c<20010B08005M:0P00FdL00`00DDd002Xm000Z?@02
000=9`8000<J0P0011d2000G<08004]=0P00J3X2001g908007</0P00G4L2000Z?08000PR0P000QT2
000=9`8004580P00L30200V=00807ID00P00P`h2001NA@8001lf0P0011`200057@8002Hj0P00J3X2
01bE0080JZh00P1HZ00200261P8005I;0P004B/200026@8000hX0P00DTd200271080NK800P2``002
06:[008007dJ0P00?dP200088P8000<K00<0020f001Y>P00JCX00P0eW@020:^n0080[;l00P0fWP02
001Z>080028g0P000a/20007808003Q40P00MbD204RS0080T;P00P1T[00200242P80059=0P003bT2
00026@8000dW0P00Bdd2001i8@80:YT00P10X@0200N=008006Hm0P00:3`200067`8000<J0P0052h2
001?CP80074_0P00P`d20020508006Ti0P00?dL2000?:@8000<J0P001Ah2000J<P8004U<0P00HD<0
0`00Ic`005e5001MA@020010B08001H_0P001Ah200026@8000PR0P006c<2000g@`8004]=0P00AT/2
000_?`8001D_0P001b0200026@8000<L0P002R@2000F;`80020g0P008CL2000I<@8000dX1Oooool1
o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000@:P8001<]0P004B/2000;
9@8000DN0P000QT200036`8000TS0P005c02000Y?08003E20P00<D02000P=P8000hX0P0011d20002
6@8000PQ0P006S82000mA`8005I;0P00FDP00`00D4h002Tl000Y?002000<9`8000<J0P0011d2000F
;`8004Q;0P00IS`2001e:080070_0P00FTP2000Y?08000PR0P000QT2000=9`8003i70P00KC@200::
00805I800P00P1<2001LAP8001le0P0011`200047@8002@i0P00ISd201>A0080GJX00P1=Y@020024
2`8005E;0P004B/200026@8000dW0P00D4h200242`80Jjh00P2P_00205NX008007/N0P00?TL20008
8P8000<K00<001he001V?@00ISd00P0ZVP0209Zj0080W;/00P0^V`02001X>P80024g0P000a/20007
808003E30P00M2X203bP0080PK@00P1HZ00200223`80055=0P003bT200026@8000dW0P00B4/2001g
9@8089H00P0eWP02006:008006@o0P009c/200067`8000<J0P0052d2001>CP8006lb0P00PA82001n
6@8006Ll0P00?DH2000?:@8000<J0P001Ah2000I<@8004I;0P00Gd@00`00ICh005a7001LA`02000m
AP8001H_0P001Ah200026@8000PR0P006S82000e@P8004Q;0P00A4X2000]?P8001D^0P001b020002
6@8000<L0P002R@2000F;`8001lf0P0083H2000H<08000dW1Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool2000@:P8001<]0P004B/2000;9@8000DN0P000QT200036`80
00TS0P005c02000Y?08003E20P00<D02000P=P8000hX0P0011d200026@8000PQ0P006S82000mA`80
05I;0P00FDP00`00D4h002Tl000Y?002000<9`8000<J0P0011d2000F;`8004Q;0P00IS`2001e:080
070_0P00FTP2000Y?08000PR0P000QT2000=9`8003i70P00KC@200::00805I800P00P1<2001LAP80
01le0P0011`200047@8002@i0P00ISd201>A0080GJX00P1=Y@0200242`8005E;0P004B/200026@80
00dW0P00D4h200242`80Jjh00P2P_00205NX008007/N0P00?TL200088P8000<K00<001he001V?@00
ISd00P0ZVP0209Zj0080W;/00P0^V`02001X>P80024g0P000a/20007808003E30P00M2X203bP0080
PK@00P1HZ00200223`80055=0P003bT200026@8000dW0P00B4/2001g9@8089H00P0eWP02006:0080
06@o0P009c/200067`8000<J0P0052d2001>CP8006lb0P00PA82001n6@8006Ll0P00?DH2000?:@80
00<J0P001Ah2000I<@8004I;0P00Gd@00`00ICh005a7001LA`02000mAP8001H_0P001Ah200026@80
00PR0P006S82000e@P8004Q;0P00A4X2000]?P8001D^0P001b0200026@8000<L0P002R@2000F;`80
01lf0P0083H2000H<08000dW1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool2000@:P80018/0P0042X2000:908000DN0P000QT200036`8000TS0P005Rl2000W>`8003=1
0P00;cl2000O=@8000dX0P0011`200026@8000LQ0P006C82000kA@8005A<0P00F4X00`00CTh002Pk
000X>`02000<9P8000<J0P0011d2000E;`8004E:0P00I3l2001c;08006hb0P00FDT2000X>`8000PR
0P000QT2000<9P8003]50P00JcL2002710803Hl00P00OQP2001KA`8001he0P0011`200047@80028h
0P00Hd0200^>0080DJH00P12XP020022408005A<0P004B/200026@8000`V0P00CTh200214P80GJX0
0P2@^00204bU008007TQ0P00?DH200088P8000<K00<001dd001T?`00I3l00P0OUP0208Vf0080SKL0
0P0VV002001W?080020g0P000a/20006808003=10P00LBh2036L0080Lk000P1=Y@0200205080051>
0P003RT200026@8000`V0P00ADX2001d:P8069<00P0/VP0200271@8006910P009SX200067`8000<J
0P004bd2001;C@8006`e0P00OQP2001k7@8006Dn0P00>TD2000>:080008J0P001Ah2000H<@8004A:
0P00GDH00`00Hd0005Y8001JB002000jA@8001D^0P001Ah200026@8000PR0P006C82000c@P8004E:
0P00@DP2000[?@8001@]0P001R0200026@8000<L0P002R@2000E;P8001he0P007cH2000G<08000dW
1Oooool1o`00007ooooo0Oooool000kooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo0P00
42X2000B;080010Z0P002R@200057P80008I0P000a/200098`8001H_0P009c/2000c@@8002lo0P00
7cD2000=:08000@L0P000QT200078@8001Tb0P00>dD2001DC08005Q:00<004i>000X>`00:3/00P00
32H200036P8000@M0P005Bl20015BP8006@o0P00Lb`2001^<P8005U90P00:3/200088P80008I0P00
32H2000kA@8006/g0P00Q`@200f?008007hH0P00FdL2000N=@8000@L0P0011d2000R>08006=00P0;
SP02056V0080@Z800P00PQ02001DC080014[0P000QT2000<9P8004i>0P00PA8205fZ0080T;P00P1<
Y@02001i8@8003e60P00228200036`03000M=000I3l006@o00807iH00P29]P0208fg00809YP00P00
Ic`2000P=`8000<K0P001R02000c@@80074^0P0aW00207>`0080CJD00P00P1@2001@CP8000hY0P00
0QT2000<9P8004E:0P00M2X201RC0080;9X00P00Q`D2001R@@8002Hj0P001Ql200036P8001<]0P00
Bdd2001/=@8007hH0P00Nad2001U?P8003Y50P003RP200026P8000DN0P0063420014BP8005e600<0
06=0001JB000FTP00P00>TD2000E;P8000DN0P000QT200088P8001Tb0P00<d820015BP8004580P00
:cd2000D;@8000HP0P000QT20003708000XT0P005Bh2000N=@8001lf0P005c02000=9`Gooooo0Ol0
0001ooooo`7ooooo000=ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`02ooooo`8000lY0P004R`2000@:P8000XT0P001Ad200026@8000<K0P002B<2000E;P8002Hj0P00
<D02000]?P8001he0P003BL200047080008I0P001b42000H<@8003Q40P00Dd`2001FB`03001;C@00
9SX002Hj008000`V0P000aX20004708001@^0P00@TT2001R@@80070_0P00K3D2001GBP8002Lj0P00
228200026@8000`V0P00>4@2001X>P8008@;0P06S002001l708005Y80P007SD20004708000@M0P00
8CL2001Q@P800X/00P15XP0203RN0080080E0P00Dd`2000A:`80008I0P0032H2001:C08007hH0P1?
YP02082c0080@Z800P00MbD2000kAP8000PR0P000aX00`006c<00652001Q@P0201JB0080NK800P1n
/`0201jE008006Dn0P0083H200036`8000HO0P00<402001_<P809iP00P1U[00204:Q008007dI0P00
Cdh2000>:080008I0P0032H20011B@80078]0P0?T00202:G008008@;0P00H4<2000U>@8000HO0P00
0aX2000B;08004Q;0P00JSP2001l7@8007PR0P00Hd02000hA08000hX0P000QX200057P8001L`0P00
@DP2001KA`03001Q@P00F4T005Q9008003Q40P0052d200057@80008I0P002282000I<@8003910P00
@TT2000nA`8002Tl0P004bd200067`80008I0P000a`2000:908001D^0P007CD2000N=@8001H_0P00
32H5ooooo`7o00000Oooool1ooooo`004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo0P003bT2000B;080010Z0P002R@200057@80008I0P000a/200098`8001D^0P009SX2
000a@08002dn0P007SD2000=9`8000@L0P000QT200078@8001Pa0P00>4@2001CC08005I;00<004]=
000V>P009SX00P0032H200036P8000@L0P0052h20012B@8006910P00L2l2001/=@8005M:0P009cX2
00088P80008I0P0032H2000hA08006Pj0P00Q0/200J<008007`L0P00FTP2000N=@8000@L0P0011d2
000Q=`8006520P02R`0204FR0080>9h00P00P1D2001CC080014[0P000QT2000<9P8004Y<0P00OQP2
04nV0080P;<00P12XP02001g9@8003]60P00228200036P03000K<`00HD80065200805Y800P1i/P02
07jc00807YD00P00ICh2000P=P8000<K0P001Ql2000`@08006lb0P0WV00206F/0080@Z400P00OAT2
001?CP8000hX0P000QT2000<9P8004590P00LRd200n@00808YL00P00Q0/2001P@`8002Di0P001Ql2
00036P80018/0P00B4/2001Z>08007`M0P00N282001S@08003Q40P003RP200026P8000DN0P005c02
0011B08005]700<00652001HB@00F4T00P00>4@2000D;@8000DM0P000QT200088P8001Ta0P00<T42
0012B@8003i70P00:C`2000C;@8000HO0P000QT20003708000XT0P005Bh2000M=@8001he0P005Rl2
000<9PGooooo0Ol00001ooooo`7ooooo000Aooooo`03o`000?oooooooooo00;ooooo0ol00002oooo
o`8000lY0P004B/2000?:@8000XT0P001Ad200026@8000<K0P002282000D;P8002@i0P00;cl2000[
?@8001dd0P003BL200047080008I0P001b02000H<08003I30P00DDd2001EB`030018C0009CT002Di
008000`V0P000aX20004708001@]0P00?TL2001P@`8006hc0P00JSP2001FB`8002Hj0P0022820002
6@8000/U0P00=D<2001V?@80084A0P00R@02001i8@8005Q90P007C@40004708001le0P00Gd@20027
1@80>Il00P0^V`02001m6@80059=0P004B/200026@8000/U0P00AT/2001k7P80@Z800P1a[`0203NN
008007DX0P00>TD200088P8000<J00<001Xb001OA000Gd@00P0<S`0206Z]0080Kjl00P0FTP02001S
@08001lf0P000a/200067`8002dn0P00K3D201bE0080EjP00P0gWP02001k7@8004e>0P003RP20002
6@8000/V0P00?TL2001_<@801h`00P0IT`0200224@8005i50P008cP200067`8000<J0P004R`20015
BP8006Pj0P00NB42001f9`8006520P00=D<2000=:080008J0P001Ah2000G<08003m70P00FTP00`00
Gd@005I;001FB`02000e@`8001<]0P0011d200026@8000PQ0P006342000`@08004180P00?4H2000W
>`80018/0P001Ql200026@8000<L0P002R@2000D;P8001`d0P007C@2000E;P8000`V0oooool3o`00
00;ooooo000=ooooo`Co00001Oooool00ol0003oooooooooo`02ooooo`8000lY0P004B/2000?:@80
00XT0P001Ad200026@8000<K0P002282000D;P8002@i0P00;cl2000[?@8001dd0P003BL200047080
008I0P001b02000H<08003I30P00DDd2001EB`030018C0009CT002Di008000`V0P000aX200047080
01@]0P00?TL2001P@`8006hc0P00JSP2001FB`8002Hj0P00228200026@8000/U0P00=D<2001V?@80
084A0P00R@02001i8@8005Q90P007C@40004708001le0P00Gd@200271@80>Il00P0^V`02001m6@80
059=0P004B/200026@8000/U0P00AT/2001k7P80@Z800P1a[`0203NN008007DX0P00>TD200088P80
00<J00<001Xb001OA000Gd@00P0<S`0206Z]0080Kjl00P0FTP02001S@08001lf0P000a/200067`80
02dn0P00K3D201bE0080EjP00P0gWP02001k7@8004e>0P003RP200026@8000/V0P00?TL2001_<@80
1h`00P0IT`0200224@8005i50P008cP200067`8000<J0P004R`20015BP8006Pj0P00NB42001f9`80
06520P00=D<2000=:080008J0P001Ah2000G<08003m70P00FTP00`00Gd@005I;001FB`02000e@`80
01<]0P0011d200026@8000PQ0P006342000`@08004180P00?4H2000W>`80018/0P001Ql200026@80
00<L0P002R@2000D;P8001`d0P007C@2000E;P8000`V1Oooool1o`00007ooooo0Oooool000gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`8000hX0P004B/2000?:@8000XT
0P001Ad200026@8000<K0P002282000D;@8002<h0P00;Ch2000Z?08001`c0P0032L200047080008I
0P001b02000G<08003A20P00Cdh2001CC0030015BP0093T002@i008000/V0P000aX20004708001</
0P00>dH2001NA@8006/f0P00J3/2001DC08002@i0P00228200026@8000/U0P00<d42001T?`8007hG
0P00QPL2001g9@8005M:0P0073@40004708001dd0P00G4H200243080;I/00P0TU`02001k7P80055=
0P004B/200026@8000XU0P00@TT2001g9080=Id00P1RZ`0202fK008007<[0P00>4@200088P8000<J
00<001Pa001LAP00G4H00P03R`0205^Y0080HJ/00P0>S`02001R@@8001he0P000a/200067`8002/m
0P00JCT201>A0080BZ@00P0/VP02001h8P8004Y<0P003RP200026@8000/U0P00>dH2001/=@8008T0
0P0@T002001o5`8005a60P008SP200057P8000<J0P004B/20012B@8006Hm0P00MRH2001c:`8005m4
0P00<d42000=9`80008J0P001Ah2000F;`8003a60P00F4T00`00GDD005A<001DC002000c@@80018/
0P0011d200026@8000PQ0P005c02000^?`8003e60P00>D@2000V>P80014[0P001Ql200026@8000<L
0P002R@2000C;@8001/c0P0073<2000D;P8000/U1Oooool1o`00007ooooo0Oooool000gooooo1Ol0
0004ooooo`03o`000?oooooooooo00;ooooo0P003RP2000A:`8000lY0P002R@200057@80008I0P00
0a/200088P8001@]0P008cP2000]?P8002Xl0P0073<2000<9`8000@L0P000QT20007808001L`0P00
=482001?CP8005=<00<004E:000T>@0093T00P002bH200036P8000@L0P004b`2000kAP8005i50P00
JcH2001X>`8005A<0P0093T200088P80008I0P002bD2000c@@8006@o0P00OQL200261`8007LU0P00
EdX2000L=0@000@L0P007C@2001LAP8008@<0P0]V`0202BG008007/N0P00DDd2000A:`80008I0P00
2RD20012B@8007LT0P0eW@0206:[0080;I/00P00Lb/2000hA08000PR0P000aX00`00634005a6001L
AP0200>;0080FjT00P1QZ`0200j?008006910P007SD200036`8000HO0P00:cd2001Y>@804i400P1:
Y00202bJ008007PR0P00BT`2000>:080008I0P002bD2000kAP8006`e0P00R@02012@008007lG0P00
G4H2000R>08000DN0P000aX2000A:`8004990P00ISd2001f9P8007<[0P00Gd@2000c@@8000dW0P00
0QX200057P8001H_0P00?4H2001HB@03001MA@00E4`005A<008003=10P004R`200047@80008I0P00
2242000G<08002ho0P00?DH2000iA08002Hj0P004B/200067`80008I0P000a`2000:908001<]0P00
6c<2000L<`8001@^0P002bD5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02
ooooo`8000hX0P0042X2000>:08000TS0P0011d200026@8000<K0P002282000C;@80024g0P00:cd2
000X>`8001/c0P0032H200047080008I0P001b02000F;`8003500P00CDh2001AC@030012B@008SP0
028h008000/U0P000aX200047080018/0P00>D@2001LA`8006Ti0P00ISd2001CC08002<h0P002282
00026@8000XT0P00<402001Q@P8007/M0P00P`h2001d:@8005E;0P006c<40004708001`c0P00FTP2
00204`808YL00P0JU002001h8P8004m>0P0042X200026@8000XT0P00?TL2001d:@80:IT00P1DY`02
02>G0080074_0P00=T<200088P8000<J00<001L`001JB000FTP00P00Q`@204fU0080DjL00P06S002
001P@`8001he0P000a/200057P8002Tl0P00Ic`200V=0080?J000P0RU`02001f9P8004M;0P003BP2
00026@8000XU0P00>4@2001Z>08008H70P07S@02001l708005]80P008CL200057P8000<J0P004B/2
000oA`8006@o0P00M2X2001a;`8005e60P00<D02000<9`80008J0P001Ad2000E;`8003Y50P00ET/0
0`00FdL005=<001CC002000`@080014[0P0011d200026@8000PQ0P005c02000/?P8003Y50P00=T<2
000T>@80014[0P001Ql200026@8000<L0P002B<2000C;@@001Xb0P004bd2000;9@Gooooo0Ol00001
ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P003RP2000@:P8000hX0P002B<20004
7@80008I0P000a/200088P8001<]0P008CL2000[?@8002Pk0P006c<2000<9P8000@L0P000QT20007
808001H_0P00<D02001=CP80055=00<00499000R>0008SP00P002bD200036P8000@L0P004R`2000i
A08005a70P00JCT2001V?@8005=<0P008cP200088P80008I0P002R@2000`@08006520P00Nad20023
3P8007@Y0P00ED/2000K<`@000@L0P0073<2001JB080080C0P0RU`0201ZD008007PR0P00Cdh2000@
:P80008I0P002R@2000nA`8007@Y0P0YV@0205BW00808iL00P00LBl2000f@`8000PR0P000aX00`00
5c0005Y8001JB00200271080CJD00P1CY`0200J<008006130P007SD200036`8000DN0P00:C`2001W
?0802Hd00P0mX00202:G008007HV0P00Ad/2000=:080008I0P002RD2000hA08006Xh0P00QPL200N=
008007`L0P00FdP2000Q=`8000DN0P000aX2000A:`8003m70P00I3l2001d:P80074_0P00GDH2000a
@08000`W0P000QX200057@8001D_0P00>TD2001FB`03001KA`00Dd`005=<008003100P004B/20004
7@80008I0P002242000G<08002`n0P00>TD2000f@`8002@i0P004B/200067`80008I0P000a`20009
8`8001<]10006S82000C;@8000/U1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooooooo
ool00_ooool2000=9`8000lZ0P003RP200098`8000@M0P000QT200036`8000PQ0P004R`2000P=P80
02Tl0P009SX2000J<P8000`V0P0011`200026@8000HP0P005Bh2000_?`8004Y<0P00D4h00`00?dP0
024g000Q=`02000;9@8000<J0P0011`2000A:`8003I30P00FTP2001W?08006A00P00DDd2000R>080
00PQ0P000QT2000:908002dn0P00Gd@2001h8P80080D0P00LRd2001DC08001/c100011`2000J<P80
05Q:0P00OAX201RC00804I400P00MRH2001>CP80010Z0P000QT200098`8003]50P00LBh201jE0080
AZ<00P0JU002001_<P8003E20P00228200036P03000F;`00F4X005Q:008008@<0P0oX@0204FS0080
08T00P00GTD2000M=08000<K0P001Ah2000W>P8006@o0P01RP02036L008069<00P00Lb/20014BP80
00dW0P000QT2000:908003I30P00Ic/200233P8008T00P00NB42001IB@8001lf0P001Ah200036P80
010Z0P00?4H2001Q@P80074_0P00KS<2001KB08002ho0P0032H200026P8000DM0P005Bh2000hA080
05E;00<005U8001AC@00DDd00P00;Sl2000A:`8000@M0P000QT200078@8001H_0P00:cd2000hA080
03A20P008SP2000@:P8000DN0P000QT20003708000TS0P004R`4000I<P8001</0P002R@5ooooo`7o
00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000dW0P003bX2000>:08000TS
0P0011d200026@8000<K0P002242000B;080020f0P00:C`2000V>P8001Xb0P0032H200047080008I
0P001R02000E;P8002lo0P00BT`2001@CP03000oB0008CL0024g008000/U0P000aX200047080014[
0P00=T<2001JB08006Ll0P00I402001AC@80028h0P00224200026@8000XT0P00;Ch2001OA08007PR
0P00P1@2001b;@8005A<0P006c<40004708001Xb0P00F4X2001m6P8069<00P0AT@02001f9P8004i>
0P0042X200026@8000TS0P00>dD2001a;P807YD00P16X`0201ZD008006lb0P00=D8200088P8000<J
00<001H_001HBP00F4X00P00Q0`203nQ0080AJ<00P00R@02001NA@8001dd0P000a/200057P8002Lj
0P00I3l2006:0080<I`00P0HT`02001c:`8004A:0P003BL200026@8000XT0P00=T<2001W>`8008<>
0P00R@02001i8@8005U90P007cH200057P8000<J0P0042X2000lAP8006520P00LBl2001^<`8005]8
0P00;Sl2000<9P80008J0P001Ad2000E;P8003Q40P00ED/00`00FDP0055=001AC@02000^?`80014[
0P0011d200026@8000LQ0P005Rl2000[?@8003Q40P00=482000R>080010Z0P001Ah200026@8000<L
0P002B<2000B;0@001Tb0P004b`2000:90Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oo
oooooooo00;ooooo0P003BL2000?:@8000dX0P002B<200047@80008I0P000a/200078@80014[0P00
7SD2000W>`8002Di0P006C42000;9P8000@L0P000QT20006808001@]0P00;Ch20016B`8004i>00<0
03a6000P=P0083H00P002bD200036P8000@L0P0042X2000c@@8005Q:0P00I3l2001Q@P80051>0P00
8CL200088@80008I0P002B<2000[?@8005e60P00MBP2001m6P8006la0P00DTd2000J<P@000@L0P00
6C42001EB`8007XP0P0>S`0200R=008007<Z0P00Bdd2000@:P80008I0P002B<2000g@`8006hc0P0C
T@0203VO00804I000P00K3D2000c@@8000PQ0P000QX00`0052h005E;001EB`0200205080<Y`00P0i
W`0200261`8005e60P0073@200036`8000DN0P009CT2001R@P8008H70P0UV00200n@0080074^0P00
@TT2000=9`80008I0P002R@2000c@@8006Dn0P00OaD20026208007HV0P00EdX2000N=@8000DN0P00
0aX2000?:P8003Y50P00Gd@2001^<P8006/f0P00F4T2000/?P8000/V0P000QX200057@8001@^0P00
=D<2001CC003001GBP00Cdh004m>008002`m0P0042X200047080008I0P001b42000E;`8002Tl0P00
=D<2000a@080020f0P003bT200057P80008I0P000a`200098`80018/0P006C42000H<@80018/0P00
2R@5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000dW0P003bT2
000=:08000TS0P0011d200026@8000<K0P001b42000A:`8001he0P009c/2000U>@8001Ta0P002bH2
00047080008I0P001R02000D;@8002dn0P00AT/2001>CP03000lAP0083H0020f008000/U0P000aX2
00047080010Z0P00<d42001HBP8006@o0P00HD82001@CP80024g0P00224200026@8000TS0P00:cd2
001MAP8007DX0P00OAX2001_<@80059=0P006S840004708001Ta0P00ED/2001j80803Xl00P08S@02
001c:P8004]=0P0042X200026@8000TS0P00=d<2001^<`804i400P0iW`02016@008006`e0P00<d42
00088@80008J00<001@^001EB`00ED/00P00P1@203:L0080>Il00P00QPL2001MAP8001`d0P000a/2
00057P8002Di0P00HT8200261`809IP00P0?T002001a;P8004990P003BL200026@8000XT0P00<d42
001U?P8007lE0P00QPP2001f9P8005M:0P007SD200057P8000<J0P003bX2000jA@8005m40P00KS82
001[=P8005Q90P00;3h2000;9P80008J0P001Ad2000D;P8003E30P00Dd`00`00EdX004m>001?CP02
000/?@80010Z0P0011`200026@8000LQ0P005Bl2000Y?08003E30P00<D02000P=P8000lY0P001Ah2
00026@8000<L0P002B<2000B;08001Ta0P006342000B;08000XT1Oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_ooool2000<9`8000hY0P003BL200098P8000@M0P000QT20003
6P8000LQ0P004B/2000M=08002Dj0P008cP2000H<08000/U0P0011`200026@8000HO0P004bd2000[
?@8004=90P00BT`00`00>TD001le000O=@02000:9@8000<J0P0011`2000@:P8003100P00ET/2001R
@@8005m40P00CTh2000P=P8000LQ0P000QT200098`8002Tl0P00FTP2001b;08007XP0P00KC@2001A
C@8001Tb0P0011`200036`8001L`0P00Dd`2001f9P801H`00P00RP02001a;P8004Q<0P0042X20002
6@8000TR0P00=482001[=`802Hd00P0/VP0200R=008006Xh0P00<D4200088@80008J00<001<]001C
C000Dd`00P00OA/202FH0080;9X00P00P`h2001KA`8001/c0P000a/200057P8002<h0P00Gd@20023
3`806Y@00P05S002001^<P8003m70P0032L200026@8000TS0P00<402001R@@8007`L0P00PPl2001c
:`8005E;0P007C@200057P8000<J0P003bT2000g@`8005e60P00K3H2001Y>P8005I:0P00:S`2000;
9@80008J0P001Ad2000D;@8003=10P00DDd00`00ET/004a=001<C@02000Y?08000lY0P0011`20002
6@8000LQ0P005Bh2000W>`8003=10P00;cl2000O=@8000hY0P001Ah200026@8000<L0P002B<2000A
:`8001P`0P005c02000A:`8000TT1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooooooo
ool00_ooool2000<9`8000hY0P003BL200098P8000@M0P000QT200036P8000LQ0P004B/2000M=080
02Dj0P008cP2000H<08000/U0P0011`200026@8000HO0P004bd2000[?@8004=90P00BT`00`00>TD0
01le000O=@02000:9@8000<J0P0011`2000@:P8003100P00ET/2001R@@8005m40P00CTh2000P=P80
00LQ0P000QT200098`8002Tl0P00FTP2001b;08007XP0P00KC@2001AC@8001Tb0P0011`200036`80
01L`0P00Dd`2001f9P801H`00P00RP02001a;P8004Q<0P0042X200026@8000TR0P00=482001[=`80
2Hd00P0/VP0200R=008006Xh0P00<D4200088@80008J00<001<]001CC000Dd`00P00OA/202FH0080
;9X00P00P`h2001KA`8001/c0P000a/200057P8002<h0P00Gd@200233`806Y@00P05S002001^<P80
03m70P0032L200026@8000TS0P00<402001R@@8007`L0P00PPl2001c:`8005E;0P007C@200057P80
00<J0P003bT2000g@`8005e60P00K3H2001Y>P8005I:0P00:S`2000;9@80008J0P001Ad2000D;@80
03=10P00DDd00`00ET/004a=001<C@02000Y?08000lY0P0011`200026@8000LQ0P005Bh2000W>`80
03=10P00;cl2000O=@8000hY0P001Ah200026@8000<L0P002B<2000A:`8001P`0P005c02000A:`80
00TT1Oooool1o`00007ooooo0Oooool001Kooooo0_l00003ooooo`8000`V0P003RP2000<9`8000PR
0P0011d200026@8000<J0P001b42000@:P8001`c0P0093T2000Q=`8001L`0P002bD200047080008I
0P001Ql2000B;08002Tl0P00?dL20016B`03000g@`007C@001dd008000XT0P000aX200036`8000lY
0P00;Sl2001DC08005m40P00GDH2001:C@8001he0P001b4200026@8000PR0P009SX2001HBP8006la
0P00MRH2001Z>08004m>0P006C420004708000<K0P005Rl2001AC@8007<[0P00R0<200261`8006hb
0P00ATX2000?:@80008I0P002282000a@08006Pj0P00R@02022F008008T00P00J3/2000`@08000PQ
0P000QX00`004R`0055=001AC@02001i8@806Y@00P0QUP0200205@8005U90P006S8200036`8000DM
0P008CL2001MAP8007lF0P0?T00200280P8006`f0P00?4H2000<9P80008I0P002B<2000^?`800613
0P00NB42001o5P80070`0P00Dd`2000L<`8000DN0P000aX2000>:@8003A20P00FdL2001Y>@8006Hm
0P00E4`2000X>`8000XU0P000QX200057@8001<]0P00<D02001?CP03001DC000B4/004Q;008002Lk
0P003RP200047080008I0P001b42000D;P8002Hj0P00<D02000/?P8001dd0P003RP200057P80008I
0P000a`200098`80014[0P005c02000F;`80010Z0P002B<4ooooo`;o00000_ooool001Kooooo00?o
0000ooooooooool00_ooool2000<9P8000hX0P0032L200088P8000@M0P000QT200036P8000LQ0P00
42X2000L<`8002@i0P008CL2000G<08000/U0P0011`200026@8000HO0P004R`2000Y?08003m70P00
AT/00`00=d<001dd000M=002000:908000<J0P000a/2000?:@8002ho0P00E4`2001OA08005e60P00
BTd2000N=@8000LQ0P000QT200088P8002Hj0P00F4X2001_<@8007HV0P00JSP2001?CP8001Ta0P00
11`200036`8001H_0P00DDd2001c:`8008P30P00QPL2001^<P8004I:0P003bT200026@8000PR0P00
<D02001X>P8008T00P0PUP020029008006Pk0P00<40200088@80008J00<0018/001AC@00DDd00P00
NB4201ZD00808IH00P00P1D2001IB@8001Xb0P000a/200057@80024g0P00GDH2001o5P803i000P00
R082001/=P8003a60P0032H200026@8000TS0P00;Sl2001P@`8007TQ0P00OaH2001`<08005=<0P00
73<200057P8000<J0P003RT2000d@P8005]70P00JCT2001V?@8005A<0P00:3/2000:9@80008J0P00
1Ad2000C;@8003500P00Cdh00`00E4`004Q;0018B`02000W>`8000hX0P0011`200026@8000LQ0P00
52h2000V>P8003500P00;3h2000M=08000hX0P001Ah200026@8000<L0P002B<2000A:`8001L`0P00
5Rl2000@:P8000TS1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2
000;9P8000dX0P0032H200088P8000@M0P000QT200036P8000LP0P003bX2000K<P80028g0P0083H2
000F;`8000XU0P0011`200026@8000HO0P004B/2000W>P8003a60P00@TT00`00=48001`d000L=002
000:908000<J0P000a/2000>:@8002`m0P00DTd2001MAP8005]80P00Ad/2000M=08000LQ0P000QT2
00088P8002@i0P00ET/2001/=@8007<[0P00J3/2001=CP8001P`0P0011`200036`8001D^0P00Cdh2
001`<08008@;0P00P`l2001/=P8004=90P003bT200026@8000PR0P00;Sl2001U?P8008D80P0ETP02
0026208006Hm0P00;Sl200078@80008J00<0014[001?CP00Cdh00P00MRL200n@00805Y800P00O1/2
001GBP8001Tb0P000a/200057@8001lf0P00FTP2001k7@801H`00P00Q@X2001Y>@8003U40P0032H2
00026@8000TS0P00;3d2001NA@8007HW0P00O1d2001]=080055=0P006S8200057@8000<J0P003RP2
000b@@8005U90P00ISd2001S@080059=0P009CX2000:9080008J0P001Ad2000B;08002lo0P00CDh0
0`00DTd004A:0014BP02000U>@8000hX0P0011`200026P8000LQ0P0052d2000T>@8002ho0P00:Sd2
000L<`8000dW0P001Ad200026@8000<L0P002B<2000@:P8001H_0P005Bl2000@:P8000TS1Oooool1
o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000;9P8000dX0P0032H20008
8P8000@M0P000QT200036P8000LP0P003bX2000K<P80028g0P0083H2000F;`8000XU0P0011`20002
6@8000HO0P004B/2000W>P8003a60P00@TT00`00=48001`d000L=002000:908000<J0P000a/2000>
:@8002`m0P00DTd2001MAP8005]80P00Ad/2000M=08000LQ0P000QT200088P8002@i0P00ET/2001/
=@8007<[0P00J3/2001=CP8001P`0P0011`200036`8001D^0P00Cdh2001`<08008@;0P00P`l2001/
=P8004=90P003bT200026@8000PR0P00;Sl2001U?P8008D80P0ETP020026208006Hm0P00;Sl20007
8@80008J00<0014[001?CP00Cdh00P00MRL200n@00805Y800P00O1/2001GBP8001Tb0P000a/20005
7@8001lf0P00FTP2001k7@801H`00P00Q@X2001Y>@8003U40P0032H200026@8000TS0P00;3d2001N
A@8007HW0P00O1d2001]=080055=0P006S8200057@8000<J0P003RP2000b@@8005U90P00ISd2001S
@080059=0P009CX2000:9080008J0P001Ad2000B;08002lo0P00CDh00`00DTd004A:0014BP02000U
>@8000hX0P0011`200026P8000LQ0P0052d2000T>@8002ho0P00:Sd2000L<`8000dW0P001Ad20002
6@8000<L0P002B<2000@:P8001H_0P005Bl2000@:P8000TS1Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool2000;9@8000dW0P0032H200088P8000@M0P000QT200036P80
00LP0P003bT2000I<P80020f0P007SD2000E;P8000XT0P0011`200026@8000DO0P004B/2000U>@80
03U40P00?dL00`00<T4001/c000K<`02000:908000<J0P000a/2000>:08002Tl0P00D4h2001KA`80
05U90P00@dT2000L=08000LQ0P000QT200088P80028h0P00Dd`2001Y>@80070_0P00ICh20019C080
01L`0P0011`200036`8001@]0P00Bdd2001]=080080C0P00OaH2001Y>@8004180P003RT200026@80
00LQ0P00:cd2001R@@80088A0P0;SP0200223`8006=00P00;3h200078@80008J00<0010Z001;C@00
Bdd00P00LR`200F;00802hh00P00NB42001EB`8001Pa0P000a/200047@8001dd0P00F4X2001h8`80
08P30P00PA82001V?08003I30P002bD200026@8000PR0P00:S`2001KA`80078/0P00N2<2001Z>080
04m>0P006C4200057@8000<J0P003RP2000`@08005M:0P00I3l2001Q@P80051>0P008cP2000:9080
008I0P0011d2000B;08002dn0P00BD`00`00D4h004180010B002000S>08000dW0P0011`200026P80
00LQ0P004bd2000S>08002`n0P00:3/2000J<P8000`W0P0011d200026@8000<L0P002282000@:P80
01D^0P0052h2000?:@8000PR1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool0
0_ooool2000;9@8000dW0P0032H200088P8000@M0P000QT200036P8000LP0P003bT2000I<P80020f
0P007SD2000E;P8000XT0P0011`200026@8000DO0P004B/2000U>@8003U40P00?dL00`00<T4001/c
000K<`02000:908000<J0P000a/2000>:08002Tl0P00D4h2001KA`8005U90P00@dT2000L=08000LQ
0P000QT200088P80028h0P00Dd`2001Y>@80070_0P00ICh20019C08001L`0P0011`200036`8001@]
0P00Bdd2001]=080080C0P00OaH2001Y>@8004180P003RT200026@8000LQ0P00:cd2001R@@80088A
0P0;SP0200223`8006=00P00;3h200078@80008J00<0010Z001;C@00Bdd00P00LR`200F;00802hh0
0P00NB42001EB`8001Pa0P000a/200047@8001dd0P00F4X2001h8`8008P30P00PA82001V?08003I3
0P002bD200026@8000PR0P00:S`2001KA`80078/0P00N2<2001Z>08004m>0P006C4200057@8000<J
0P003RP2000`@08005M:0P00I3l2001Q@P80051>0P008cP2000:9080008I0P0011d2000B;08002dn
0P00BD`00`00D4h004180010B002000S>08000dW0P0011`200026P8000LQ0P004bd2000S>08002`n
0P00:3/2000J<P8000`W0P0011d200026@8000<L0P002282000@:P8001D^0P0052h2000?:@8000PR
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000;9@8000`W0P00
2bD200088@8000@L0P000QT200036P8000HP0P003RP2000H<@8001le0P007C@2000D;@8000XT0P00
11`200026@8000DN0P0042X2000S>08003I30P00?4H00`00;cl001Xb000J<P0200098`8000<J0P00
0a/2000=9`8002Lk0P00CDh2001HB@8005I:0P00@4P2000K<`8000LP0P000QT200078@80020g0P00
DDd2001V?08006dd0P00Hd020016B`8001H_0P0011`200036`8001</0P00AT/2001Z>08007dJ0P00
O1d2001W?08003e60P003RP200026@8000LQ0P00:3/2001OA08007hH0P01RP02001o5P8006520P00
:Sd200078@80008J00<0010Z0016B`00AT/00P00Kc42002710800HX00P00MRH2001CC08001P`0P00
0a/200047@8001`c0P00ED/2001e:@8008@<0P00OAT2001T?`8003A20P002bD200026@8000PR0P00
9c/2001IB@8006la0P00MBP2001W>`8004]=0P00630200047@8000<J0P003BL2000]?P8005E;0P00
HD82001NA@8004i>0P008CL200098`80008I0P0011d2000A:`8002/m0P00ADX00`00CDh003a6000l
AP02000Q=`8000`V0P000a/200026P8000LP0P004R`2000Q=`8002Xl0P009SX2000I<@8000`V0P00
11d200026@8000<L0P002282000?:@8001@^0P004bd2000>:08000PR1Oooool1o`00007ooooo0Ooo
ool001Kooooo00?o0000ooooooooool00_ooool2000;9@8000`W0P002bD200088@8000@L0P000QT2
00036P8000HP0P003RP2000H<@8001le0P007C@2000D;@8000XT0P0011`200026@8000DN0P0042X2
000S>08003I30P00?4H00`00;cl001Xb000J<P0200098`8000<J0P000a/2000=9`8002Lk0P00CDh2
001HB@8005I:0P00@4P2000K<`8000LP0P000QT200078@80020g0P00DDd2001V?08006dd0P00Hd02
0016B`8001H_0P0011`200036`8001</0P00AT/2001Z>08007dJ0P00O1d2001W?08003e60P003RP2
00026@8000LQ0P00:3/2001OA08007hH0P01RP02001o5P8006520P00:Sd200078@80008J00<0010Z
0016B`00AT/00P00Kc42002710800HX00P00MRH2001CC08001P`0P000a/200047@8001`c0P00ED/2
001e:@8008@<0P00OAT2001T?`8003A20P002bD200026@8000PR0P009c/2001IB@8006la0P00MBP2
001W>`8004]=0P00630200047@8000<J0P003BL2000]?P8005E;0P00HD82001NA@8004i>0P008CL2
00098`80008I0P0011d2000A:`8002/m0P00ADX00`00CDh003a6000lAP02000Q=`8000`V0P000a/2
00026P8000LP0P004R`2000Q=`8002Xl0P009SX2000I<@8000`V0P0011d200026@8000<L0P002282
000?:@8001@^0P004bd2000>:08000PR1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool2000:908000`V0P002bD200078@8000@L0P000QT200036P8000HP0P003RP2000G
<08001dd0P0073<2000C;@8000TS0P0011`200026@8000DN0P003bT2000Q=`8003=10P00>4@00`00
;Ch001Ta000I<@0200098`8000<J0P000a/2000=9`8002Di0P00B4`2001FB`8005A<0P00?DH2000J
<P8000LP0P000QT200078@8001le0P00Cdh2001T@08006Xh0P00H4<20012B@8001D_0P0011`20003
6`80018/0P00@TT2001W?08007TQ0P00N2<2001T?`8003Y50P003RP200026P8000LP0P009SX2001M
AP8007XP0P00QPP2001k7@8005i40P00:3/200078@80008J00<000lY0012B@00@TT00P00K3H20023
3@8008H70P00Lb`2001AC@8001L`0P000a/200047@8001Xb0P00Dd`2001a;P80080D0P00NR02001Q
@P8003500P002RD200026@8000PR0P009CX2001GBP8006`e0P00LBh2001U?P8004M;0P005c020004
7@8000<J0P003BL2000[?@8005=<0P00GT@2001LA`8004U<0P007cH200098`80008I0P0011d2000A
:`8002Tl0P00@TT00`00BD`003U4000iA002000O=@8000`V0P000a/200026P8000LP0P004R`2000P
=P8002Pk0P0093T2000G<08000/U0P0011d200026@8000<L0P002282000?:@8001<]0P004b`2000=
:08000PQ1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000:9080
00`V0P002bD200078@8000@L0P000QT200036P8000HP0P003RP2000G<08001dd0P0073<2000C;@80
00TS0P0011`200026@8000DN0P003bT2000Q=`8003=10P00>4@00`00;Ch001Ta000I<@0200098`80
00<J0P000a/2000=9`8002Di0P00B4`2001FB`8005A<0P00?DH2000J<P8000LP0P000QT200078@80
01le0P00Cdh2001T@08006Xh0P00H4<20012B@8001D_0P0011`200036`80018/0P00@TT2001W?080
07TQ0P00N2<2001T?`8003Y50P003RP200026P8000LP0P009SX2001MAP8007XP0P00QPP2001k7@80
05i40P00:3/200078@80008J00<000lY0012B@00@TT00P00K3H200233@8008H70P00Lb`2001AC@80
01L`0P000a/200047@8001Xb0P00Dd`2001a;P80080D0P00NR02001Q@P8003500P002RD200026@80
00PR0P009CX2001GBP8006`e0P00LBh2001U?P8004M;0P005c0200047@8000<J0P003BL2000[?@80
05=<0P00GT@2001LA`8004U<0P007cH200098`80008I0P0011d2000A:`8002Tl0P00@TT00`00BD`0
03U4000iA002000O=@8000`V0P000a/200026P8000LP0P004R`2000P=P8002Pk0P0093T2000G<080
00/U0P0011d200026@8000<L0P002282000?:@8001<]0P004b`2000=:08000PQ1Oooool1o`00007o
oooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2000:908000/V0P002R@200078@8000@L
0P000QT200036P8000HO0P003BL2000F;`8001`c0P006S82000B;08000TS0P000a`200026@8000DN
0P003bT2000O=P8003100P00=D<00`00:Sd001L`000G<00200098`8000<J0P000a/2000<9P8002<h
0P00A4X2001DC080059=0P00>DD2000I<@8000LP0P000QT20007808001dd0P00Bdd2001Q@P8006Lk
0P00GTD2000oA`8001@^0P0011`200036`80014[0P00?TL2001T@08007DW0P00MBT2001Q@P8003M4
0P003BP200026P8000HP0P0093T2001JB08007HV0P00PQ02001h8`8005a60P009cX200078@80008I
00<000hX000nA`00?TL00P00J3X2001o5@80088@0P00L302001?CP8001H_0P000a/20004708001Ta
0P00DDd2001^<`8007`K0P00MRH2001NA08002ho0P002R@200026@8000PQ0P0093T2001DC08006Ti
0P00KS82001R@@8004=90P005Bl200047@8000<J0P0032L2000Y?080055=0P00G4L2001IB@8004A:
0P007SD200088P80008I0P0011d2000@:P8002Lk0P00?TL00`00A4X003E3000e@`02000M=08000/U
0P000a/200026P8000LP0P004B/2000N=@8002Hj0P008SL2000F;`8000XU0P0011`200026@8000<L
0P002282000>:0@0018/0P003BL200078@Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oo
oooooooo00;ooooo0P002R@2000;9P8000XT0P001b4200047080008I0P000aX200067`8000dW0P00
5Rl2000L<`8001Xb0P004R`200098`8000<L0P000QT200057P8000lY0P007cH2000`@08003E300<0
02Xm000G<0005c000P002B<200036P8000<K0P0032H2000S>08004A:0P00E4`2001BC@8003U50P00
6C4200078080008I0P001b02000M=08004]=0P00HD82001W>`8005i50P00?dL2000D;P8000@L0P00
0a/2000A:`8003i70P00I402001e9`8007DY0P00HD82000gA08000dX0P000QX20006808002@i0P00
FTP2001f9P80088@0P00N2<2001LAP8002Lj0P001b4200026@03000>:000?TL003i7008006Pj0P00
OaD200224080070`0P00Cdh2000F;`8000<K0P0011`2000I<@80055=0P00KS<2001l6`8007HV0P00
GT@2000^?`8000XT0P000QT200088@8002@i0P00E4`2001Y>@8006hb0P00HT420013B@8001D_0P00
11d200036P8000`W0P00:C`2001AC@8005a70P00FDT20014BP8001he0P00228200026@8000@M0P00
42X2000W>`8003i700<004A:000e@`00=D<00P007C@2000;9@8000<K0P000QX200078080014[0P00
7SD2000V>P80028g0P005Rl2000:9@8000@L0P000QT20003708000PR0P003RP4000B;08000dW0P00
1b45ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000TS0P002bD2
000:908000LP0P0011`200026@8000<J0P001Ql2000<9`8001D^0P006S82000I<@80014[0P002B<2
00036`80008I0P001Ah2000>:08001de0P00;Ch2000b@@03000X>`005Rl001H_008000PR0P000aX2
00036`8000/V0P008CL20010B080059=0P00D4h2000f@`8001P`0P001R0200026@8000LP0P006c<2
0016B`8005i50P00I3l2001KA`8003a60P0052d20004708000<K0P0042X2000jA@8006520P00LRd2
001a;P8005m40P00=482000=9`80008J0P001R02000R=`8005M:0P00Lb`2001n608007@Y0P00FTP2
000U>@8000LP0P000QT00`003BL003Y5000jA@02001U?P8007/M0P00OQL2001/=@8004a=0P005Bh2
00036`8000@L0P006302001?CP8006/g0P00NB82001c;08005a70P00;3d2000:9080008I0P001b42
000R=`80059=0P00ISd2001[=`8005m40P00?dL2000D;P8000@M0P000aX2000<9P8002Lk0P00Cdh2
001IB08005M:0P00@4P2000L<`8000PR0P000QT200047@80010Z0P009CX2000kA@030010B000<T40
0391008001/c0P002R@200036`80008J0P001b02000A:`8001dd0P0093T2000P=P8001D^0P002R@2
00047080008I0P000a`200088P8000hX0P004R/2000A:`8000`V0P001b45ooooo`7o00000Oooool1
ooooo`005_ooool2o`0000?ooooo0P002B<2000;9@8000XT0P001b0200047080008I0P000aX20006
7`8000`W0P005Bh2000J<P8001Ta0P004B/200098`8000<K0P000QT200057P8000hX0P007CD2000]
?P80039100<002Pk000F;`005Rl00P00228200036P8000<K0P002bH2000Q=`8004180P00DTd2001@
CP8003I30P00630200068080008I0P001b02000K<`8004I;0P00GTD2001T?`8005]70P00?4H2000D
;@8000@L0P000a/2000@:P8003Y50P00HD82001b;@80074^0P00Gd@2000d@P8000dW0P000QX20006
8080028g0P00EdX2001c;08007hH0P00M2T2001JB08002Di0P001b0200026@03000=9`00>TD003Y5
008006Dn0P00Nad2001n5`8006`e0P00C4d2000E;P8000<K0P0011`2000H<08004m>0P00JcL2001i
8P8007</0P00G4L2000/?@8000XT0P000QT200078@80028g0P00DTd2001V?@8006/g0P00Gd@2000o
A`8001@^0P0011d200036P8000`V0P009c/2001?CP8005U80P00EdX20010B08001`c0P0022820002
6@8000@M0P0042X2000U>P8003]500<00418000b@@00<T400P006c<2000:908000<K0P000QX20007
8080014[0P007C@2000T>@80020f0P005Bh2000:908000@L0P000QT20003708000PR0P003RP2000B
:`80014[0P0032H200078@Cooooo0_l00002ooooo`005_ooool00ol0003oooooooooo`02ooooo`80
00TS0P002RD2000:908000LP0P0011`200026@8000<J0P001Ql2000<9P8001@]0P006C42000H<080
014[0P00228200036`80008I0P001Ah2000=9`8001`c0P00:cd2000_?`03000V>P005Bl001D_0080
00PR0P000aX200036`8000/U0P007cH2000lAP8004m>0P00CDh2000c@@8001H_0P001R0200026@80
00HP0P006S820012B@8005]70P00HD82001IB@8003Q40P004bd20004708000<J0P003bT2000f@`80
05i50P00KS82001^<`8005a60P00<T42000<9`80008J0P001Ql2000O=P8005E;0P00Kc42001j7`80
074^0P00EdX2000S>08000LP0P000QT00`003BL003I3000f@`02001R@@8007PT0P00NQl2001Y>@80
04Q<0P0052d200036`8000@L0P005Rl2001:C@8006Lk0P00MBP2001_<@8005U90P00:C`200098`80
008I0P001b42000P=P80051>0P00Hd02001X>`8005a60P00>dD2000C;@8000@L0P000aX2000;9P80
02Dj0P00Bdd2001GBP8005A<0P00?4H2000J<P8000LQ0P000QT200047@8000lY0P0093T2000hA003
000mAP00;cl002lo008001Xb0P002R@200036`80008J0P001b02000@:P8001`c0P008SL2000N=@80
01@]0P002B<200047080008I0P000a`200088@8000dW0P004B/2000@:P8000`V0P001b05ooooo`7o
00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000TS0P002RD2000:908000LP
0P0011`200026@8000<J0P001Ql2000<9P8001@]0P006C42000H<080014[0P00228200036`80008I
0P001Ah2000=9`8001`c0P00:cd2000_?`03000V>P005Bl001D_008000PR0P000aX200036`8000/U
0P007cH2000lAP8004m>0P00CDh2000c@@8001H_0P001R0200026@8000HP0P006S820012B@8005]7
0P00HD82001IB@8003Q40P004bd20004708000<J0P003bT2000f@`8005i50P00KS82001^<`8005a6
0P00<T42000<9`80008J0P001Ql2000O=P8005E;0P00Kc42001j7`80074^0P00EdX2000S>08000LP
0P000QT00`003BL003I3000f@`02001R@@8007PT0P00NQl2001Y>@8004Q<0P0052d200036`8000@L
0P005Rl2001:C@8006Lk0P00MBP2001_<@8005U90P00:C`200098`80008I0P001b42000P=P80051>
0P00Hd02001X>`8005a60P00>dD2000C;@8000@L0P000aX2000;9P8002Dj0P00Bdd2001GBP8005A<
0P00?4H2000J<P8000LQ0P000QT200047@8000lY0P0093T2000hA003000mAP00;cl002lo008001Xb
0P002R@200036`80008J0P001b02000@:P8001`c0P008SL2000N=@8001@]0P002B<200047080008I
0P000a`200088@8000dW0P004B/2000@:P8000`V0P001b05ooooo`7o00000Oooool1ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`8000TS0P002R@200098`8000LP0P0011`200026@8000<J0P00
1Ah2000;9P8001</0P006302000F;`80010Z0P00228200036`80008I0P001Ad2000=9`8001Xb0P00
:3/2000]?P03000T>@0052h001@^008000PR0P000aX200036`8000XU0P007C@2000hA08004a=0P00
B4`2000`@08001D_0P001Ql200026@8000HO0P006342000nA`8005U90P00Gd@2001FB`8003E30P00
4R`20004708000<J0P003RP2000c@@8005]71000JcL2001JB08002lo0P0032H200026P8000HO0P00
7SD2001BC@8006`f0P00MRH2001]<`8005E;0P008CL200078080008I00<000`V000c@@00<d400P00
Gd@2001d:P8007HV0P00ISd20014BP8001<]0P000a/20004708001D^0P00AT/2001T?`80074^0P00
K3H2001GBP8002Lk0P002B<200026@8000LP0P007SD2001>CP8006130P00ICh2001IB08003M30P00
4R`20004708000<J0P002bD2000T>@8004M;0P00ED/2001BC@8003Q40P006C4200078@80008I0P00
11d2000?:@80028g0P00=D800`00>D@002`m000/?@02000H<@8000TS0P000a/200026P8000HP0P00
42X2000J<P80020f0P0073@2000B;08000TS0P0011`200026@8000<L0P001b42000=9`80010Z0P00
3bT2000;9@8000HP1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2
00098`8000XT0P002B<20007808000@L0P000QT200036P8000DN0P002bH2000C;08001P`0P005Rl2
000@:P8000PR0P000a/200026@8000DM0P003BL2000J<P8002Pk0P00;Ch00`0093T001@^000D;P02
00088P8000<J0P000a/2000:9@8001dd0P00>4@2001<C@8004Q<0P00<402000E;`8000HO0P000QT2
00067`8001Pa0P00?TL2001IB@8005m40P00ET/2000e@`80018/0P0011`200036P8000hX0P00<d42
001KA`@006/g0P00FTP2000_?`8000`V0P000QX200067`8001he0P00DTd2001/=P8007HV0P00KC<2
001EB`80024g0P001b0200026@03000<9P00<d4003=1008005m40P00M2X2001f9P8006Hm0P00A4X2
000C;@8000<K0P0011`2000E;P8004I;0P00I3l2001a;P8006`f0P00EdX2000W>`8000TS0P000QT2
0007808001he0P00CTh2001P@`8006Dn0P00FDP2000g@`80018/0P0011`200036P8000/U0P0093T2
0017B`8005E;0P00DTd2000hA08001Ta0P001b4200026@8000@M0P003bT2000R=`8003E200<003U4
000/?@00;3d00P00634200098`8000<K0P000QX200068080010Z0P006S82000P=P8001`d0P004R`2
00098`8000@L0P000QT20003708000LQ0P003BL2000@:P8000lY0P002bD2000680Gooooo0Ol00001
ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P002282000:908000TS0P001R020004
7080008I0P000aX200057P8000/U0P004R`2000F;`8001D_0P003bT200088P8000<K0P000QT20004
7@8000`V0P006C42000V>P8002Xl00<0028g000C;@004bd00P00224200036P8000<K0P002R@2000L
<`8003E20P00Ad/20014BP8002dn0P0052h200067`80008I0P001Ql2000G<08003Y50P00ET/2001L
A`8005A<0P00<T42000A:`8000@L0P000aX2000=:08002lo0P00F4T2001X>`8006Lk0P00EdX2000]
?P8000`V0P000QX200057`8001`c0P00D4h2001X>P80078/0P00JSP2001CC080020f0P001R020002
6@03000;9P00<4000310008005a60P00L302001c;08006=00P00@4P2000B;08000<K0P0011`2000D
;P8004590P00HD82001^<`8006Pj0P00E4`2000U>@8000TS0P000QT20007808001dd0P00BD`2001N
A@8006910P00EdX2000c@P80014[0P0011`200036P8000/U0P008SL20012B@80059=0P00Cdh2000d
@P8001L`0P001b0200026@8000@M0P003RP2000P=P80039100<003E3000Y?000:C`00P005Rl20009
8`8000<K0P000QX20006808000lY0P006C82000N=@8001/c0P004B/200088P8000<K0P000QT20003
708000LQ0P0032L2000?:@8000hY0P002RD200067`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03
o`000?oooooooooo00;ooooo0P002282000:908000TS0P001R0200047080008I0P000aX200057P80
00/U0P004R`2000F;`8001D_0P003bT200088P8000<K0P000QT200047@8000`V0P006C42000V>P80
02Xl00<0028g000C;@004bd00P00224200036P8000<K0P002R@2000L<`8003E20P00Ad/20014BP80
02dn0P0052h200067`80008I0P001Ql2000G<08003Y50P00ET/2001LA`8005A<0P00<T42000A:`80
00@L0P000aX2000=:08002lo0P00F4T2001X>`8006Lk0P00EdX2000]?P8000`V0P000QX200057`80
01`c0P00D4h2001X>P80078/0P00JSP2001CC080020f0P001R0200026@03000;9P00<40003100080
05a60P00L302001c;08006=00P00@4P2000B;08000<K0P0011`2000D;P8004590P00HD82001^<`80
06Pj0P00E4`2000U>@8000TS0P000QT20007808001dd0P00BD`2001NA@8006910P00EdX2000c@P80
014[0P0011`200036P8000/U0P008SL20012B@80059=0P00Cdh2000d@P8001L`0P001b0200026@80
00@M0P003RP2000P=P80039100<003E3000Y?000:C`00P005Rl200098`8000<K0P000QX200068080
00lY0P006C82000N=@8001/c0P004B/200088P8000<K0P000QT20003708000LQ0P0032L2000?:@80
00hY0P002RD200067`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo
0P00228200098`8000PR0P001Ql200047080008I0P000QX200057P8000XT0P004B/2000E;P8001@^
0P003RT200088@8000<K0P000QT200047@8000/V0P006302000T>@8002Lk00<0020f000B;0004R`0
0P001b4200026P8000<K0P002R@2000J<P8003910P00@TT20010B08002/m0P004bd200067`80008I
0P001Ql2000F;`8003I30P00Dd`2001IB@80055=0P00;cl2000@:`8000@L0P000aX2000=9`8002`n
0P00ED/4001T?`8005E;0P00:S`2000;9@80008J0P001Ah2000J<P8004a=0P00ICh2001_<P8006Ll
0P00D4d2000N=@8000HO0P000QT00`002bD002dn000]?P02001IB08006`e0P00Kc42001P@`8003a6
0P004B/200036`8000@L0P004bd2000mA`8005i50P00JSP2001U?P80059=0P008SP200088P80008I
0P001b02000K<`8004E:0P00FdL2001OA08005A<0P00<402000@:P8000@L0P000aX2000:9@80020f
0P00?dL2001@CP8004a=0P00<D02000E;`8000HP0P000QT200047@8000hX0P007cD2000_?`03000b
@@009SX002Hj008001D^0P00228200036P80008J0P001R02000>:@8001Pa0P007C@2000I<@80010Z
0P00228200036`80008I0P000a`200078@8000`V0P003bT2000>:08000XT0P001Ql5ooooo`7o0000
0Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000PQ0P002B<200088P8000HO0P00
11`200026@80008J0P001Ah2000:9080010Z0P0052h2000C;@8000hX0P001b4200036`80008I0P00
11d2000;9@8001H_0P008CL2000U>@03000N=@004B/0014[008000LQ0P000QX200036P8000TS0P00
6C42000^?`8003i70P00?4H2000X>`80018/0P001Ql200026@8000HO0P0052h2000c@@80055=0P00
ETX2001?CP8002`n0P0042X20004708000<J0P0032H2000Z?08005=<1000HD82001BC@8002Pk0P00
2bD200026P8000DN0P006C420017B`8006920P00JcL2001T?`8004i>0P0073@200067`80008I00<0
00XU000Z?000:S`00P00EdX2001Y>@8006/f0P00GDH2000hA080010Z0P000a/200047080018/0P00
>TD2001KA`8006Ll0P00HT42001?CP80020f0P00228200026@8000HP0P006S820010B08005Q90P00
G4L2001AC@8002dn0P003bT20004708000<J0P002R@2000O=@8003]50P00CDh20016B`8002dn0P00
52h200067`80008I0P0011d2000=:08001dd0P00;3h00`00;cl002@i000T>@02000D;@8000PR0P00
0aX200026P8000HO0P003RP2000G<08001/c0P006302000?:@8000PQ0P000a/200026@8000<L0P00
1b42000;9P8000hX0P003BL20009908000HO1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000
ooooooooool00_ooool200088@8000TS0P00228200067`8000@L0P000QT200026P8000DN0P002R@2
000@:P8001@^0P004bd2000>:08000LQ0P000a/200026@8000@M0P002bD2000F;`80024g0P009CT0
0`007SD0014[000A:`0200078@80008J0P000aX200098`8001Ta0P00;Sl2000nA`8003a60P00:3/2
000B;08000HO0P000QT200067`8001@^0P00<d42001AC@8005I:0P00Cdh2000/?P80010Z0P0011`2
00036P8000`V0P00:S`2001CC0@006520P00DTd2000X>`8000/U0P000QX200057P8001Ta0P00Ad/2
001R@P8006/g0P00I3l2001>CP8001`d0P001Ql200026@03000:9@00:S`002Xl008005M:0P00JCT2
001[=P8005e60P00>4@2000@:P8000<K0P0011`2000B;08003Y50P00FdL2001W?08006910P00Cdh2
000P=P8000PR0P000QT20006808001Xb0P00@4P2001HB@8005a70P00DDd2000]?P8000lY0P0011`2
00036P8000XT0P007cD2000kA@8004e>0P00AT/2000]?P8001@^0P001Ql200026@8000@M0P003BP2
000M=08002`n00<002lo000T>@0093T00P0052d200088P8000<J0P000QX200067`8000hX0P005c02
000K<`8001P`0P003bT200088@8000<K0P000QT20003708000LQ0P002bH2000>:08000dW0P002B@2
00067`Gooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P001b440008
8P8000HO0P000a`200026@80008J0P001Ah200098`8000lY0P004bd2000B;08000dW0P001b420003
6`80008I0P0011d2000:9@8001D^0P007cH2000S>003000L=0004B/0014[008000LP0P000QX20003
6P8000TS0P005c02000[?@8003Y50P00>4@2000V>P80014[0P001Ah200026@8000DN0P004bd2000_
?`8004i>0P00E4`2001;C@8002Xl0P003bT20004708000<J0P0032H2000W>`80051>1000GTD2001@
CP8002Dj0P002R@200026P8000DN0P005c020012B@8005i50P00Ic/2001P@`8004U<0P006c<20006
7`80008I00<000XT000W>`009c/00P00E4`2001U?@8006Pk0P00FTP2000d@P8000lZ0P000a/20003
7080014[0P00=T<2001IB@8006=00P00Gd@2001;C@8001he0P001b4200026@8000HP0P006C42000l
AP8005E;0P00FDT2001?CP8002Xl0P003RP200036`8000<J0P002R@2000M=08003M40P00B4/20012
B@8002Xm0P004b`200067`80008I0P0011d2000=9`8001`c0P00:C`00`00;3d0024g000Q=`02000B
;08000LQ0P000aX200026P8000HO0P003BP2000F;`8001Xb0P005Rl2000>:@8000LQ0P000a/20002
6@8000<K0P001b02000;9@8000dX0P0032L200098`8000DN1Oooool1o`00007ooooo0Oooool001Ko
oooo00?o0000ooooooooool00_ooool200078@@000PR0P001Ql200037080008I0P000QX200057P80
00TS0P003bT2000C;@80018/0P003BL200078@8000<K0P000QT200047@8000XU0P005Bh2000O=P80
02<h00<001`d000A:`004B/00P001b0200026P8000<J0P002B<2000G<08002/m0P00>TD2000hA080
02Hj0P004B/200057P80008I0P001Ah2000C;@8002lo0P00CTh2001DC08004]=0P00:S`2000?:@80
00@L0P000aX2000<9P8002Lk0P00D4h4001NA@80051>0P009CX2000:9080008J0P001Ah2000G<080
04990P00GTD2001W>`8006130P00BD`2000K<`8000HO0P000QT00`002R@002Lk000W>`02001DC080
06Dm0P00J3/2001JB08003A20P003bX200036`8000<L0P004B/2000f@`8005U90P00Hd02001OA080
04]=0P007SD200078@80008I0P001R02000I<@8003a60P00ED/2001IB@8004m>0P00:S`2000>:080
00<K0P000aX2000:908001dd0P00=d@20018B`8004990P00:Sd2000C;08000HO0P000QT200047@80
00dW0P0073<2000Y?003000/?@008CL0024g0080018/0P001b4200036P80008J0P001Ql2000=:080
01H_0P006S82000F;`8000hY0P001b4200036`80008I0P000a/20007808000/U0P003BP2000<9`80
00TS0P001Ah5ooooo`7o00000Oooool1ooooo`005_ooool2o`0000?ooooo0P001b4200088P8000PQ
0P001Ql200036`80008I0P000QX200057@8000TS0P003RT2000B;080014[0P0032L20007808000<K
0P000QT20004708000XT0P0052d2000N=@80024g00<001/c000@:P0042X00P001b0200026P8000<J
0P002282000F;`8002Tl0P00=T<2000d@P8002<h0P004B/200057P80008I0P001Ah2000B;08002`n
0P00BD`2001AC@8004I:0P009c/2000>:08000<L0P000aX2000;9@8002@i0P00CDh4001KA`8004a=
0P008cP2000:9080008J0P001Ah2000F;`8003i70P00FdL2001T?`8005e50P00A4X2000I<P8000HO
0P000QT00`002B@002Di000U>@02001AC@8006910P00I3l2001GBP8003500P003bT400036`80010Z
0P00<d42001FB`8006130P00G4L20015BP8001`d0P001b4200026@8000HO0P005c02000iA08005=<
0P00ET/2001:C08002Lj0P003BP200036`8000<J0P002R@2000L<`8003A20P00@dT2000mAP8002Lk
0P004R/200057`80008I0P0011d2000<9`8001Xb0P009c/00`00:C`001lf000O=P02000A:`8000LP
0P000aX200026P8000HO0P003BL2000E;P8001Pa0P005Bh2000>:08000LP0P000a/200026@8000<K
0P001b02000;9@8000dW0P0032H200098P8000DN1?ooool2o`0000;ooooo000Fooooo`03o`000?oo
oooooooo00;ooooo0P001b4200088P8000PQ0P001Ql200036`80008I0P000QX200057@8000TS0P00
3RT2000B;080014[0P0032L20007808000<K0P000QT20004708000XT0P0052d2000N=@80024g00<0
01/c000@:P0042X00P001b0200026P8000<J0P002282000F;`8002Tl0P00=T<2000d@P8002<h0P00
4B/200057P80008I0P001Ah2000B;08002`n0P00BD`2001AC@8004I:0P009c/2000>:08000<L0P00
0aX2000;9@8002@i0P00CDh4001KA`8004a=0P008cP2000:9080008J0P001Ah2000F;`8003i70P00
FdL2001T?`8005e50P00A4X2000I<P8000HO0P000QT00`002B@002Di000U>@02001AC@8006910P00
I3l2001GBP8003500P003bT400036`80010Z0P00<d42001FB`8006130P00G4L20015BP8001`d0P00
1b4200026@8000HO0P005c02000iA08005=<0P00ET/2001:C08002Lj0P003BP200036`8000<J0P00
2R@2000L<`8003A20P00@dT2000mAP8002Lk0P004R/200057`80008I0P0011d2000<9`8001Xb0P00
9c/00`00:C`001lf000O=P02000A:`8000LP0P000aX200026P8000HO0P003BL2000E;P8001Pa0P00
5Bh2000>:08000LP0P000a/200026@8000<K0P001b02000;9@8000dW0P0032H200098P8000DN1Ooo
ool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool20007808000PR0P001b42
00057P8000<K0P000QT200026P8000@M0P002B82000>:080014[0P0042X2000<9P8000LP0P000a/2
00026@8000@L0P002R@2000C;08001`c0P007cD00`006C4000lY000?:@0200068080008J0P000aX2
00088P8001D^0P009SX2000b@@8003100P008CL2000@:P8000DN0P000QT200057P80014[0P00:C`2
0014BP8004m>0P00@DP2000U>@8000hX0P000a/200036P8000XU0P008SP20018B`@005Q90P00Ad/2
000Q=`8000TS0P000QT200057@8001D^0P00>TD2001HB@8006520P00FTP2000oB08001P`0P001Ah2
00026@0300098`008SP0028h008004m>0P00Gd@2001Q@P8005A<0P00;Ch2000>:0@000<K0P0042X2
000_?`8005=<0P00GDH2001IB@8004180P006S8200078080008I0P001Ql2000F;`8003E20P00D4h2
001CC08004A:0P0093T2000<9`8000<K0P000aX200098`8001Xb0P00<D02000nA`8003U40P0093T2
000@:P8000DN0P000QT200047@8000`V0P006C42000U>@03000V>P007C@001dd0080010Z0P001b02
00036P80008J0P001Ql2000<9`8001@]0P005c02000D;@8000dW0P001R0200036`80008I0P000a/2
0006808000XT0P0032H2000;9@8000PR0P001Ah5ooooo`7o00000Oooool1ooooo`005_ooool00ol0
003oooooooooo`02ooooo`8000LP0P00228200078@8000DN0P000a/200026@80008J0P0011d20009
8P8000hX0P004B/2000@:P8000`V0P001b0200036`80008I0P0011`2000:908001</0P0073<2000O
=@03000I<@003bT000lY008000HP0P000QX200036P8000PR0P005Bh2000V>P8003910P00<402000Q
=`80010Z0P001Ah200026@8000DN0P004B/2000Y?08004A:0P00Cdh20011B08002Di0P003RP20003
6`8000<J0P002RD2000R>08004Q;1000F4T20017B`80024g0P002B<200026@8000DM0P005Bh2000j
A@8005Q90P00HD82001JB08003m80P00630200057P80008I00<000TS000R>0008SP00P00Cdh2001O
A08006520P00E4`2000]?P8000hX10000a/2000@:P8002lo0P00Dd`2001MAP8005U90P00@4P2000J
<P8000LP0P000QT200067`8001H_0P00=D82001@CP8005=<0P00A4X2000T>@8000`W0P000a/20003
6P8000TS0P006S82000a@08003i70P00>D@2000T>@80010Z0P001Ah200026@8000@M0P0032H2000I
<@8002Di00<002Hj000M=0007C@00P0042X20007808000<J0P000QX200067`8000`W0P0052d2000G
<08001@]0P003BL20006808000<K0P000QT200036`8000HP0P002R@2000<9P8000/U0P0022820005
7PGooooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P001R0400078@80
00DN0P000a/200026@80008J0P0011d200088P8000dW0P0042X2000?:P8000/V0P001R0200036`80
008I0P0011`200098`80018/0P006S82000M=003000H<0003RP000hX008000HO0P000QX200036P80
00PQ0P004bd2000T>@8002lo0P00;Ch2000O=P8000lY0P001Ah200026@8000DN0P0042X2000W>P80
03m80P00BD`2000lAP80028h0P003BL200036`8000<J0P002R@2000P=P8004=91000ED/20012B@80
01le0P002B<200026@8000DM0P004bd2000f@`8005E;0P00GDD2001GBP8003]50P005Rl200057P80
008I00<000TS000P=P0083H00P00BTd2001LA`8005i50P00DTd2000Z?@8000dW10000a/2000?:@80
02`n0P00DDd2001JB08005I;0P00?4H2000I<@8000HP0P000QT200067`8001D_0P00<T42001=CP80
051=0P00?dP2000Q=`8000`V0P000a/200036P8000TS0P006C42000^?`8003Y50P00=482000R=`80
00lY0P001Ah200026@8000@M0P0032H2000H<@80028h00<002@i000K<`006c<00P003bT2000680@0
008J0P001Ql2000<9P8001</0P005Bl2000B;08000`V0P001Ql200036P80008I0P000a/200068080
00XT0P0032H2000;9@8000PR0P001Ad5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooo
ooooo`02ooooo`8000HP10001b4200057P8000<K0P000QT200026P8000@M0P002282000=9`80010Z
0P003bX2000;9P8000HP0P000a/200026@8000@L0P002B<2000B;08001Xb0P007C@00`00630000hX
000>:00200067`80008J0P000aX200088@8001<]0P0093T2000_?`8002dn0P007cH2000?:@8000DN
0P000QT200057P80010Z0P009cX2000oB08004U<0P00?4H2000R>08000dW0P000a/200036P8000XT
0P0083H20013B@@005E;0P00@TT2000O=@8000TS0P000QT200057@8001<]0P00=T<2001EB`8005e5
0P00EdX2000kA@8001H_0P001Ah200026@0300098`0083H0020f008004Y=0P00G4L2001NA@80059=
0P00:Sd2000=9`@000<K0P003bT2000/?P80055=0P00FTP2001FB`8003a60P006C4200068080008I
0P001Ql2000E;`8003910P00CDh2001@C@8003m80P008CL2000<9P8000<K0P000aX200098`8001Ta
0P00;Sl2000jA@8003A20P008SL2000?:@8000DN0P000QT200047@8000`V0P006342000R>003000T
>@006c<001/c008000lY0P001R0400026P8000HO0P0032H2000C;08001D_0P004R`2000<9P8000HO
0P000aX200026@8000<K0P001R02000:908000`V0P002bD200088P8000DM1Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool00_ooool20006808000LQ0P001b0200057P8000<K0P00
0QT200026P8000@M0P002282000<9P@000lY0P002bD200067`8000<K0P000QT20004708000TS0P00
4B/2000H<@8001/c00<001H_000=:0003BP00P001Ql200026P8000<J0P001b42000B;080024g0P00
;3d2000Z?@8001dd0P003RP200057P80008I0P001Ad2000?:P8002@i0P00>dD20014BP8003Q40P00
83H2000<9P8000<K0P000aX2000:908001he0P00?TL4001BC@8003e70P007C@200098`80008I0P00
11d2000B;08003910P00Ddd2001JB08005A<0P00=d<2000E;P8000DN0P000QT00`00228001he000N
=@020015BP8005U90P00FTP2001?CP8002Lk0P0032L200036P8000<K0P003RP2000Z?08004i>0P00
EdX2001CC08003M40P005c0200067`80008I0P001Ql2000D;P8002lo0P00B4`2001=CP8003]50P00
7cD2000;9@8000<K0P000aX200098`8001P`0P00:cd2000f@`8003500P007cH2000>:08000DM0P00
0QT20004708000/U0P005c02000P=P03000Q=`006C8001Tb008000hX0P001Ql400026P8000HO0P00
32H2000B;08001@^0P004B/2000;9@8000HO0P000aX200026@8000<K0P001Ql200098`8000/U0P00
2R@200078@8000DM1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2
0006808000LQ0P001b0200057P8000<K0P000QT200026P8000@M0P002282000<9P@000lY0P002bD2
00067`8000<K0P000QT20004708000TS0P004B/2000H<@8001/c00<001H_000=:0003BP00P001Ql2
00026P8000<J0P001b42000B;080024g0P00;3d2000Z?@8001dd0P003RP200057P80008I0P001Ad2
000?:P8002@i0P00>dD20014BP8003Q40P0083H2000<9P8000<K0P000aX2000:908001he0P00?TL4
001BC@8003e70P007C@200098`80008I0P0011d2000B;08003910P00Ddd2001JB08005A<0P00=d<2
000E;P8000DN0P000QT00`00228001he000N=@020015BP8005U90P00FTP2001?CP8002Lk0P0032L2
00036P8000<K0P003RP2000Z?08004i>0P00EdX2001CC08003M40P005c0200067`80008I0P001Ql2
000D;P8002lo0P00B4`2001=CP8003]50P007cD2000;9@8000<K0P000aX200098`8001P`0P00:cd2
000f@`8003500P007cH2000>:08000DM0P000QT20004708000/U0P005c02000P=P03000Q=`006C80
01Tb008000hX0P001Ql400026P8000HO0P0032H2000B;08001@^0P004B/2000;9@8000HO0P000aX2
00026@8000<K0P001Ql200098`8000/U0P002R@200078@8000DM1Oooool1o`00007ooooo0Oooool0
01Kooooo00?o0000ooooooooool00_ooool200067`8000LP0P001R0200057P8000<K0P000QT20002
6P8000@L0P001b42000<9P@000hX0P002R@200067`8000<K0P000QT20004708000PR0P0042X2000G
<08001Tb00<001D^000=9`003BL00P001Ql200026P8000<J0P001b42000A:`8001lf0P00:C`2000W
>`8001/c0P003BP200057@80008I0P001Ad2000?:@80028g0P00=T<2000oA`8003A20P007SD2000<
9P8000<K0P000QX200098`8001`d0P00>DD2001@CP8004m>0P00>D@2000K<`8000PR0P000QT20004
7@80014[0P00;Sl2001@CP8005M:0P00DDd2000c@@8001@]0P001Ah200026@0300088P0073@001`d
008004180P00ET/2001GBP8004Y<0P0093T2000<9P8000<J0P000a/2000>:08002Lk0P00B4`2001D
C080051>0P00<d42000E;`8000HO0P000QT200067`8001<]0P00;3d20013B@8004M;0P00=T<2000M
=08000XT0P000a/200036P8000PR0P005Rl2000X>`8003910P00;Ch2000M=08000dW0P0011d20002
6@8000@L0P002bD2000E;`8001he00<001lf000G<0005c000P003BL200067`@0008J0P001Ql2000;
9@80014[0P004bd2000@:P8000/U0P001Al200036P80008I0P000a/200067`8000TS0P002RD2000:
908000LQ0P0011d5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`80
00HO0P001b020006808000DN0P000a/200026@80008J0P0011`200078@8000`V10003RP2000:9080
00HO0P000a/200026@8000@L0P002282000@:P8001L`0P006C800`005Bh000dW000=9`0200067`80
008J0P000aX200078@80014[0P007cH2000Y?08002Lk0P006c<2000=:08000DM0P000QT200057@80
00lY0P008SL2000f@`8003m70P00=482000N=@8000`V0P000a/200026P8000TS0P0073@2000iA@80
051>0P00Cdh2000iA08001/c0P00228200026@8000@M0P004B/2000^?`80051>0P00EdX2001AC@80
03=10P0052d200057P80008I00<000PR000L=00073@00P00@4P2001FB`8005M:0P00BT`2000T>@80
00`V0P000aX200036`8000hX0P009c/20018C08005A<0P00D4h2000c@@8001D_0P001Ql200026@80
00HO0P004bd2000/?@8004=90P00Ad/2000f@`8001dd0P002R@200036`8000<J0P002282000F;`80
02Pk0P00<T42000]?P8001dd0P003BL200047@80008I0P0011`2000;9@8001D_0P007SD00`007cH0
01L`000G<002000=9`8000HO10000QX200067`8000/U0P004B/2000C;@80010Z0P002bD200057`80
00<J0P000QT200036`8000HO0P002B<2000:9@8000XT0P001b4200047@Gooooo0Ol00001ooooo`7o
oooo000Fooooo`03o`000?oooooooooo00;ooooo0P001Ql20007808000HP0P001Ah200036`80008I
0P000QX20004708000LQ0P002bD2000=:08000dW0P002R@200067`8000<K0P000QT20004708000PR
0P003bT2000E;`8001P`00<001<]000<9P0032H00P001Al200026P8000<J0P001b02000@:P8001dd
0P009SX2000T>@8001Tb0P003BL200047@80008I0P0011d2000>:08001lf0P00<T42000jA@800310
0P0073<2000;9@8000<K0P000QX200098`8001Xb0P00=D84001;C@8003A20P006C4200088P80008I
0P0011d2000@:P8002/m0P00C4d2001DC08004i>0P00;cl2000B;08000DM0P000QT00`00224001/c
000K<`02000kAP8005==0P00E4`20014BP80028g0P002bD200036P8000<K0P003BL2000T>@8004=9
0P00DDd2001;C@8002lo0P0052d200067`80008I0P001Ah2000B;08002Tl0P00?TL20012B@800391
0P006S82000:90@000<J0P002282000E;`8002Hj0P00;cl2000Z?08001/c0P0032L200047@80008I
0P0011`2000:9@8001@^0P0073@00`007C@001H_000F;`02000<9P8000DN0P000QX200036P8000DN
0P002bD2000@:P80018/0P003bT2000:908000DN0P000aX200026@8000<K0P001Ql200098`8000XT
0P002B<20007808000@M1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_oo
ool200067`8000LP0P001R0200057P8000<K0P000QT200026P8000@L0P001b42000;9@8000dX0P00
3BL2000:908000HO0P000a/200026@8000@L0P002282000?:@8001D_0P0063000`004bd000`V000<
9P0200057`80008J0P000aX200078080010Z0P007C@2000V>P8002@i0P006C82000=9`8000@M0P00
0QT200047@8000hX0P007cH2000b@@8003Y50P00<402000L<`8000/U0P000a/200026P8000TS0P00
6S82000e@P@004]=0P00=482000I<@8000PR0P000QT200047@80010Z0P00:cd2001<C@8005A<0P00
CTh2000_?`80018/0P001Ad200026@0300088@006c<001/c008003]60P00Ddd2001DC08004A:0P00
8SL2000;9@8000<J0P000a/2000=9`8002@i0P00@dT2001AC@8004]=0P00;cl2000D;@8000HO0P00
0QT200057P80018/0P00:C`2000nA`8004990P00<T42000J<P8000XT10000aX200088P8001D_0P00
9SX2000_?`8002Xl0P006c<2000<9`8000@M0P000QT20004708000XU0P0052h2000L=003000M=000
5Rl001H_008000`V0P001Ah200026P8000<J0P001Ah2000;9@80010Z0P004R`2000?:@8000XT0P00
1Ah200036P80008I0P000a/200067`8000TS0P002R@200098`8000LP0P0011d5ooooo`7o00000Ooo
ool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000DO0P001R0200067`8000DM0P000a/2
00026@80008J0P0011`20007808000XT0P003BL2000<9`8000TS0P001Al200036P80008I0P000a`2
00078@8000hX0P0052d2000F;`03000B;0002bD000/U008000DN0P000QX200036P8000HP0P003bT2
000K<`8002<h0P008SL2000H<08000`V0P0011d200026@8000@M0P003BL2000M=08002lo0P00=T<2
000/?P8001Xb0P002R@200036`80008J0P002282000H<@8003501000ADX2000`@08001L`0P001b42
00026@8000@M0P003bX2000X>`8004I:0P00DDd20018C08002/m0P004B/200057@80008I00<000LQ
000I<@006C400P00=d<2001@CP80055=0P00?TL2000O=P8000XT0P000aX200036`8000`W0P008SP2
000nA`8004i>0P00ADX2000[?@80018/0P001Ah200026@8000DN0P004B/2000V>P8003U50P00?4H2
000^?P8001Pa0P002B<400036P8000PR0P0052h2000S>08002/m0P009SX2000I<@8000/V0P0011`2
00026@8000@L0P002R@2000C;@8001/b00<001/c000D;P0052h00P002bH200057P80008J0P000aX2
00057P8000XT0P003bT2000A:`8000hX0P002B<200057P8000<J0P000QT200036`8000HO0P002282
00098`8000TR0P001R02000470Gooooo0Ol00001ooooo`7ooooo000Fooooo`;o00000oooool20005
7`8000HP0P001Ql200057@8000<K0P000QT200026P8000@L0P001b02000:908000dW0P0032L20009
8`8000DO0P000aX200026@8000<L0P001b42000>:08001@]0P005Rl00`004R`000/U000;9@020005
7P80008J0P000aX20006808000lY0P006c<2000S>080028g0P006302000<9P8000@M0P000QT20004
7@8000dW0P007C@2000_?`8003I30P00;3h2000J<P8000XT0P000a/200026P8000PR0P006342000a
@0@004E:0P00<402000G<08000LQ0P000QT200047@8000lZ0P00:3/20016BP80055=0P00B4`2000[
?@80014[0P001Ad200026@0300078@006C4001Ta008003M30P00D4h2001AC@8003i70P007cH2000:
908000<J0P000a/2000<9`80028h0P00?TL2001>CP8004E:0P00:cd2000B;08000DN0P000QT20005
7P80014[0P009SX2000iA@8003a60P00;Sh2000H<@8000TS10000aX200088P8001@^0P008cP2000[
?@8002Hj0P006C42000;9P8000@L0P000QT20004708000XT0P004bd2000K<P03000K<`0052h001@^
008000/V0P001Ah200026P8000<J0P001Ah2000:908000lY0P004B/2000>:08000TS0P001Ah20003
6P80008I0P000a/200067`8000PR0P002B<200098P8000HP0P0011`4ooooo`;o00000_ooool001Ko
oooo00?o0000ooooooooool00_ooool200057P@000HO0P001Ad200036`@0008I0P0011`200068080
00XT100032H200098`8000DN0P000aX200026@8000<K0P001b42000=9`8001</0P0052h00`004B/0
00/U000;9@0200057P80008J0P000aX20006808000hX0P006C42000P=`8001lf0P005Rl2000;9@80
00@M0P000QT200047@8000`V0P006c<2000[?@8003500P00:C`2000H<@8000XT0P000a/200026P80
00PR0P005c02000]?P8003m80P00?dL2000]?P8001H_0P001b4200026@8000@L0P003RT2000U>@80
04180P00CDh20012B@8002Pk0P0042X200047@80008I00<000LQ000G<0005c000P00<d42001;C@80
04i>0P00>D@2000M=08000XT0P000aX200036`8000`V0P0083H2000iA@8004M;0P00?dP2000X>`80
014[0P001Ah200026@8000DN0P0042X2000T>@8003E20P00>4@2000Z?08001H_0P00228400036P80
00PR0P004bd2000Q=`8002Pk0P008cP2000G<08000/U0P0011`200026@8000@L0P002R@2000B;0<0
01Ta0P004b`2000;9@8000DM0P000QT200036P8000DN0P002R@2000>:080010Z0P003BL200098`80
00DM0P000aX200026@8000<K0P001Al200088P8000TS0P00228200067`8000@L1Oooool1o`00007o
oooo0Oooool001Kooooo00?o0000ooooooooool00_ooool200057P@000HO0P001Ad200036`@0008I
0P0011`20006808000XT100032H200098`8000DN0P000aX200026@8000<K0P001b42000=9`8001</
0P0052h00`004B/000/U000;9@0200057P80008J0P000aX20006808000hX0P006C42000P=`8001lf
0P005Rl2000;9@8000@M0P000QT200047@8000`V0P006c<2000[?@8003500P00:C`2000H<@8000XT
0P000a/200026P8000PR0P005c02000]?P8003m80P00?dL2000]?P8001H_0P001b4200026@8000@L
0P003RT2000U>@8004180P00CDh20012B@8002Pk0P0042X200047@80008I00<000LQ000G<0005c00
0P00<d42001;C@8004i>0P00>D@2000M=08000XT0P000aX200036`8000`V0P0083H2000iA@8004M;
0P00?dP2000X>`80014[0P001Ah200026@8000DN0P0042X2000T>@8003E20P00>4@2000Z?08001H_
0P00228400036P8000PR0P004bd2000Q=`8002Pk0P008cP2000G<08000/U0P0011`200026@8000@L
0P002R@2000B;0<001Ta0P004b`2000;9@8000DM0P000QT200036P8000DN0P002R@2000>:080010Z
0P003BL200098`8000DM0P000aX200026@8000<K0P001Al200088P8000TS0P00228200067`8000@L
1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool200057P@000HO0P00
11d200036`@0008I0P0011`200067`8000TS10002bD200088P8000DN0P000aX200026@8000<K0P00
1b02000<9P80014[0P004bd00`0042X000XT000:900200057P80008J0P000aX200067`8000dX0P00
5c02000N=@8001dd0P0052h2000:9@8000@L0P000QT20004708000`V0P006C42000W>`8002dn0P00
9SX2000F;`8000TS0P000a/200026P8000PQ0P005Bh2000Z?08003Y50P00>DD2000Y?08001@^0P00
1b0200026@8000@L0P003RP2000R>08003]50P00Ad/2000lAP8002@i0P003bT200047@80008I00<0
00LP000F;`005Rl00P00;cl20014BP8004M;0P00=482000J<P8000TS0P000aX200036`8000/U0P00
7CD2000d@P8004580P00>TD2000T>@80010Z0P001Ad200026@8000DN0P0042X2000Q=`8003100P00
<d42000V>P8001@^0P00228400036P8000LQ0P004R`2000N=@8002Di0P0083H2000E;P8000XT0P00
11`200026@8000@L0P002B<2000A:`<001L`0P004B/2000:908000@M0P000QT200036P8000DN0P00
2B<2000=:08000lY0P0032L200088P8000@M0P000QX200026@8000<K0P001Ah200078@8000PR0P00
224200067`8000@L1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool00_ooool2
00057P@000HO0P0011d200036`@0008I0P0011`200067`8000TS10002bD200088P8000DN0P000aX2
00026@8000<K0P001b02000<9P80014[0P004bd00`0042X000XT000:900200057P80008J0P000aX2
00067`8000dX0P005c02000N=@8001dd0P0052h2000:9@8000@L0P000QT20004708000`V0P006C42
000W>`8002dn0P009SX2000F;`8000TS0P000a/200026P8000PQ0P005Bh2000Z?08003Y50P00>DD2
000Y?08001@^0P001b0200026@8000@L0P003RP2000R>08003]50P00Ad/2000lAP8002@i0P003bT2
00047@80008I00<000LP000F;`005Rl00P00;cl20014BP8004M;0P00=482000J<P8000TS0P000aX2
00036`8000/U0P007CD2000d@P8004580P00>TD2000T>@80010Z0P001Ad200026@8000DN0P0042X2
000Q=`8003100P00<d42000V>P8001@^0P00228400036P8000LQ0P004R`2000N=@8002Di0P0083H2
000E;P8000XT0P0011`200026@8000@L0P002B<2000A:`<001L`0P004B/2000:908000@M0P000QT2
00036P8000DN0P002B<2000=:08000lY0P0032L200088P8000@M0P000QX200026@8000<K0P001Ah2
00078@8000PR0P00224200067`8000@L1Oooool1o`00007ooooo0Oooool001Kooooo00?o0000oooo
ooooool00_ooool200057P8000DO0P001Ah200047@8000<K10000QT20003708000HO0P002B82000:
9@8000XT0P00228200057P8000<J0P000QT200036`8000HP0P002bH2000@:P80018[00<000lY0009
8`002B<00P001Ad400026P8000HO0P0032L2000E;`8001/c0P006S82000C;@8000XT0P0011`20002
6@8000@L0P002bD2000G<08002@i0P00:C`2000R>08001@^0P002B<200036`80008J0P001b42000D
;@8002Hj1000=482000U>P80018/0P001R0200026@8000@L0P003BL2000O=P8003E30P00@4P2000g
@`80024g0P003RP200047080008I00<000LP000D;P0052h00P00:cd2000nA`8004180P00;cl2000H
<@8000PR0P000QX200036`8000/U0P006c<2000`@08003]50P00=482000Q=`8000hX0P0011d20002
6@8000DN0P003bT2000N=@8002`n0P00;Sl2000S>08001</0P001b4400036P8000LQ0P004B/2000L
=080028g0P007CD2000C;@8000TS0P0011`200026@8000@L0P002B<2000@:P8001D_00<001D^000@
:P0042X00P002B<200047@80008I0P000aX200057P8000TS0P0032L2000>:08000/V0P0022420004
7@80008J0P000QT200036`8000DN0P001b4200088P8000LQ0P001Ah2000470Gooooo0Ol00001oooo
o`7ooooo000Fooooo`03o`000?oooooooooo00;ooooo0P001Ah200057`8000DN0P0011d200036`@0
008I0P000a`200067`8000TR0P002RD2000:908000PR0P001Ah200036P80008I0P000a/200068080
00/V0P0042X2000B:`03000?:@002B<000TS008000DM10000QX200067`8000`W0P005Bl2000K<`80
01Xb0P004bd2000:908000@L0P000QT20004708000/U0P005c02000T>@8002Tl0P008SP2000D;P80
00TS0P000a/200026P8000LQ0P0052d2000V>P@003A20P009CX2000B;08000HP0P000QT200047080
00dW0P007cH2000e@`8004180P00=d<2000Q=`8000hX0P0011`200026@030007800052h001@^0080
02/m0P00?TL20010B08002lo0P00634200088P80008J0P000a/2000;9@8001/c0P00<402000kA@80
03A20P008CL2000>:08000@M0P000QT200057P8000lY0P007SD2000/?P8002ho0P008cP2000C;080
00LQ10000aX200078@80014[0P0073@2000R=`8001de0P004bd200098`8000@L0P000QT200047080
00TS0P0042X2000E;`03000E;P0042X0010Z008000TS0P0011d200026@8000<J0P001Ah200098`80
00`W0P003RP2000;9P8000PQ0P0011d200026P80008I0P000a/200057P8000LQ0P00228200078@80
00DN0P0011`5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`02ooooo`8000DM
10001Ah200047@8000<K10000QT200036`8000DO0P002282000:908000TT0P001b4200057@8000<J
0P000QT200036`8000HO0P002bD2000?:@80010Z00<000hX00098`002B<00P0011d400026P8000DN
0P0032H2000C;@8001Ta0P006342000A:`8000TS0P0011`200026@8000@L0P002R@2000E;P80024g
0P009CX2000O=P8001</0P00228200036P80008J0P001b02000B;08002<h1000;cl2000R=`80014[
0P001Ql200026@8000@L0P0032H2000M=08003100P00>DD2000a@08001he0P003BL200047080008I
00<000HP000C;0004b`00P009cX2000hA08003U50P00:Sd2000F;`8000PR0P000QX200036`8000XT
0P006C42000[?@8003E20P00;cl2000M=@8000dW0P0011d200026@8000DN0P003RP2000L<`8002Pk
0P00:C`2000O=P80014[0P001b0200026P8000<J0P001b02000@:P8001Xb0P007SD2000K<`80014[
0P00228200036`80008I0P0011`200088P8000lY0`004bd2000>:@8000PR0P0011`200026@8000<J
0P001Ah200088P8000`V0P0032L2000:9@8000LQ0P0011`200026P80008I0P000a/200057P8000LP
0P001b420007808000DN0P000a`5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`8000DM10001Ah200047@8000<K10000QT200036`8000DO0P002282000:908000TT0P00
1b4200057@8000<J0P000QT200036`8000HO0P002bD2000?:@80010Z00<000hX00098`002B<00P00
11d400026P8000DN0P0032H2000C;@8001Ta0P006342000A:`8000TS0P0011`200026@8000@L0P00
2R@2000E;P80024g0P009CX2000O=P8001</0P00228200036P80008J0P001b02000B;08002<h1000
;cl2000R=`80014[0P001Ql200026@8000@L0P0032H2000M=08003100P00>DD2000a@08001he0P00
3BL200047080008I00<000HP000C;0004b`00P009cX2000hA08003U50P00:Sd2000F;`8000PR0P00
0QX200036`8000XT0P006C42000[?@8003E20P00;cl2000M=@8000dW0P0011d200026@8000DN0P00
3RP2000L<`8002Pk0P00:C`2000O=P80014[0P001b0200026P8000<J0P001b02000@:P8001Xb0P00
7SD2000K<`80014[0P00228200036`80008I0P0011`200088P8000lY0`004bd2000>:@8000PR0P00
11`200026@8000<J0P001Ah200088P8000`V0P0032L2000:9@8000LQ0P0011`200026P80008I0P00
0a/200057P8000LP0P001b420007808000DN0P000a`5ooooo`7o00000Oooool1ooooo`002?ooool3
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0P0011d400057P8000@L0P000a/4
00026@8000<K0P001Ah200078@@000TS0P001b0200047@8000<J0P000QT200036`8000HO0P002R@2
000=:08000lY00<000`W00088P0022800P0011d200026@80008J0P001Ah2000;9@80018/10005Rl2
000@:P8000PR0P0011`200026@8000@L0P002B<2000C;@8001dd0P008CL2000L<`80014[0P001b42
00036P80008J0P001R02000@:`8001lf1000:S`2000N=@8000lY0P001Ql200026@8000@L0P002bD2
000J<P8002/m0P00<d42000/?@8001/c0P002bH200047080008I00<000HO000A:`004B/00P008cP2
000b@@8003=10P009CX2000D;@8000LQ0P000QX200036`8000TS0P005c02000W>`8002lo0P00:S`2
000J<P8000`V0P0011`200026@8000DM0P003BL2000I<P8002@i0P009CT2000L<`8000lY0P001Ql2
00026P8000<J0P001b02000>:@8001L`0P006c<2000H<@8000lZ0P00224200036`80008I0P0011`2
00088P8000hX0P004R`00`004B/000dW000=9`0200088@8000@L0P000QT200036P8000DM0P002282
000;9@8000/V0P002R@20007808000@L0P000QX200026@8000<K0P001Ad20006808000LQ0P001R02
00057P8000<K1Oooool1o`00007ooooo0Oooool000Wooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo0P0011d400057P8000@L0P000a/4
00026@8000<K0P001Ah200078@@000TS0P001b0200047@8000<J0P000QT200036`8000HO0P002R@2
000=:08000lY00<000`W00088P0022800P0011d200026@80008J0P001Ah2000;9@80018/10005Rl2
000@:P8000PR0P0011`200026@8000@L0P002B<2000C;@8001dd0P008CL2000L<`80014[0P001b42
00036P80008J0P001R02000@:`8001lf1000:S`2000N=@8000lY0P001Ql200026@8000@L0P002bD2
000J<P8002/m0P00<d42000/?@8001/c0P002bH200047080008I00<000HO000A:`004B/00P008cP2
000b@@8003=10P009CX2000D;@8000LQ0P000QX200036`8000TS0P005c02000W>`8002lo0P00:S`2
000J<P8000`V0P0011`200026@8000DM0P003BL2000I<P8002@i0P009CT2000L<`8000lY0P001Ql2
00026P8000<J0P001b02000>:@8001L`0P006c<2000H<@8000lZ0P00224200036`80008I0P0011`2
00088P8000hX0P004R`00`004B/000dW000=9`0200088@8000@L0P000QT200036P8000DM0P002282
000;9@8000/V0P002R@20007808000@L0P000QX200026@8000<K0P001Ad20006808000LQ0P001R02
00057P8000<K1Oooool1o`00007ooooo0Oooool000Wooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo0P0011d400057@8000@L0P000aX4
00026@8000<K0P001Ah2000780@000PR0P001R0200047@8000<J0P000QT200036`8000DN0P002B<2
000<9P8000dX00<000/V00088@0022400P0011`200026@80008J0P001Ah2000:9080010Z0P0052h2
000C;@8000hX0P00228200037080008I0P0011`200098`80014[0P006S82000M=@8001Ta0P003bT2
0007808000<J0P000QX200067`8000lY0P0073<2000U>P8002Di0P006c<2000>:08000DN0P000QT2
0003708000XT0P005c02000V>P8002dn0P009SX2000H<08000XU0P000a`200026@0300067`0042X0
010Z008001lf0P00;3d2000]?P80024g0P004B/200078080008J0P000a/200098`8001D^0P008cP2
000Z?08002Di0P005c02000;9@8000@L0P000QT200047@8000`V0P005c02000P=P80024g0P006C42
000>:08000HO0P000QX200036P8000HP0P003BP2000E;P8001Pa0P005Bh2000>:08000LQ0P000a/2
00026@8000@L0P001b42000=9`<0010Z0P0032H200078@8000@L0P000QT200036P8000@M0P001b42
000:908000XU0P002B<200067`8000@L0P000QX200026@8000<K0P0011d200067`8000HP0P001Ql2
00057@8000<K1Oooool1o`00007ooooo0Oooool000Wooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00004ooooo`?o00000_ooool200047@@000DM0P0011`200036P@0008I0P000a/2
00057P8000LP100022820006808000@M0P000aX200026@8000<K0P001Ah200098`8000`V0P003BP0
0`002bH000PQ00088@0200047080008I0P000QX200057P8000XT0P0042X2000D;P8001<]0P003RP2
00088P8000<L0P000QT20004708000TS0P004B/2000J<P8001de0P006C42000?:@8000LP0P000aX2
00026P8000HO0P003bT2000L<`8002Dj0P009CT2000K<`8000hX0P001Ah200026@8000<L0P002R@2
000G<08002Hj0P00;Ch2000V>P8001P`0P002RD200037080008I00<000HO000@:P0042X00P007cH2
000/?@8002dn0P008CL2000A:`8000LP0P000QX200036`8000TS0P005Bh2000S>08002Xl0P009CT2
000G<08000/U0P0011`200026@8000@M0P0032H2000G<080020f0P008CL2000I<@8000hX0P001Ql2
00026P8000<J0P001R02000=:08001D^0P006342000E;P8000hX0P001b4200036`80008I0P0011`2
00078@8000dW0`0042X2000<9P8000LQ0P0011`200026@8000<J0P0011d200078@8000XT0P002RD2
00098`8000HO0P0011`200026P80008I0P000a/200047@8000HO0P001R0200067`8000DM0P000a/3
ooooo`?o00000_ooool000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00;ooooo0P0011`400047@8000@L0P000aX400026@8000<K0P0011d2
0006808000PQ0P001b4200067`8000@L0P000aX200026@8000<J0P001Ah200088P8000/U0P0032H0
0`002R@000LQ00078@0200047080008I0P000QX200057@8000TS0P003RP2000B;080014[0P003BL2
00078@8000<K0P000QT200036`8000PR0P003bX2000G<08001Xb0P005Rl2000>:08000HP0P000aX2
00026P8000HO0P003RP2000H<@80024g0P0083H2000G<08000`W0P001Ah200026@8000<K0P002B<2
000E;P80024g0P009c/2000R=`8001D^0P002B<200036`80008I00<000DN000>:0003RP00P006c<2
000V>P8002Lk0P007C@2000?:P8000HO0P000QX200036`8000PR0P004b`2000N=@8002@i0P0083H2
000D;P8000XT0P0011`200026@8000@M0P002bD2000D;P8001`d0P007C@2000F;`8000`V0P001Ah2
00026P8000<J0P001Ql2000<9P8001</0P005Rl2000C;08000`W0P001R0200036`80008I0P0011`2
00078@8000/V0P003RT00`003RP000/U000;9@020006808000<K0P000QT200026P8000@M0P001b02
00098`8000TT0P00228200067`8000<K10000QT200036`8000@M10001Ql200057`8000@M0P000a/5
ooooo`7o00000Oooool1ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02ooooo`8000@L100011d20004708000<J10000QT200036`8000@M0P001R02
00088@8000LQ0P001Ql20004708000<J0P000QT200036P8000DN0P002282000;9@8000`V00<000XT
00078@001b400P0011`200026@80008J0P001Ad200098`8000hX0P004R`2000A:`8000dW0P001b42
00036`80008I0P000a/200088P8000lZ0P005c02000J<P8001H_0P003RP20006808000<J0P000QX2
00067`8000hX0P006342000Q=`80020f0P005c02000<9`8000DN0P000QT200036`8000TS0P005Bh2
000Q=`8002Lk0P008SL2000E;P8000TS0P000a/200026@0300057P003RP000hX008001/c0P009SX2
000W>`8001dd0P003bX200067`80008J0P000a/200088P8001</0P007SD2000T>@80020f0P0052h2
000:908000@L0P000QT200047@8000/U0P0052h2000L=08001dd0P005Rl2000<9P8000DN0P000QX2
00036P8000HO0P0032H2000C;08001H_0P004b`2000<9`8000HP0P000a/200026@8000@L0P001b42
000;9P8000hY00<000hX000;9@002bD00P001R0200036`80008I0P000QX200047@8000LP0P002B<2
0009908000PR0P001Ql200036`@0008I0P000a/200047@@000HO0P001Al200047@8000<K1Oooool1
o`00007ooooo0Oooool000Wooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000oooo
ooooool0ooooool5ooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`3oooooo`Go
oooo0Ol00001ooooo`7ooooo000Fooooo`03o`000?oooooooooo0?oooooo1Oooool1o`00007ooooo
0Oooool001Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00Co0000oooooooooooo00000_ooool001Koooooool00009o`0000;ooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003Fooooo`?o0000Aoooool00=Oooooo00?o
0000ooooooooool0A_ooool005Sooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_oo
ool2o`0000?ooooo0ol00002ooooo`?o00000oooool5o`0000;ooooo0ol00002ooooo`?o00001?oo
ool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`0000?ooooo0ol00008ooooo`Go0000
00Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003ooooo`?o00000_ooool3o`000003
ooooool0003o000000Co00000_ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04Go
oooo001Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01_l0003o
ooooooooool0003oooooo`0000Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00Co
0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`15ooooo`00F_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooooooool5o`0000;ooooo00?o0000ooooooooool00_ooool5
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`Go00002Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;o
oooo00Co0000oooooooooooo00000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000004Kooooo001Jooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000_ooool2o`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000016ooooo`00
F_ooool01?l0003oooooooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool2o`000003
ooooool0003o000000;ooooo1?l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000;o
oooo0ol00002ooooo`Co00000oooool3o`0000?ooooo0ol0000:ooooo`04o`000?oooooooooooooo
o`Co00000_ooool4o`0000?ooooo0ol00002ooooo`Co00000oooool4o`000004ooooool0003o0000
o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l00000AOooool005[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04cooooo001Hooooo`Go
00002?ooool00ol0003oooooooooo`0Aooooo`;o0000:oooool5o`0000Sooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04cooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-15.8058, -11.5733, 0.0806229, \
0.0806504}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(InterferenceFunction \[Rule] 
          "CompiledFunction[-intensity data-]"\), ",", 
        RowBox[{"OutputGraphics", "\[Rule]", 
          RowBox[{"InterferenceFunction", "\[Rule]", 
            RowBox[{"(", 
              
              TagBox[\(\[SkeletonIndicator]  
                  DensityGraphics  \[SkeletonIndicator]\),
                False,
                Editable->False], ")"}]}]}], 
        ",", \(ResidualFitError \[Rule] {0.0006820034649892955`, 
            0.0009625815916313148`}\), ",", \(WaveLength \[Rule] 0.532`\), 
        ",", \(SpatialScale \[Rule] 1\), 
        ",", \(OpticalPathRange \[Rule] {385.8896230092469`, 
            448.66153806252265`}\), 
        ",", \(RayBoundary \[Rule] {{\(-13.55586140068667`\), 
              6.78874943307785`}, {\(-10.175771877221775`\), 
              10.175771877221775`}}\)}], "}"}]], "Output",
  CellLabel->"Out[32]=",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot3D[Evaluate[(InterferenceFunction/.interference)][x,y],{x,-13.5,6.7},{y,-\
10.,10.},PlotPoints->100,Mesh->False];\
\>", "Input",
  CellLabel->"In[33]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12983 .20593 -17.9863 -9 ]
[.12983 .20593 .01371 0 ]
[.28339 .14552 -11.3716 -9 ]
[.28339 .14552 .62843 0 ]
[.44647 .08139 -5.37614 -9 ]
[.44647 .08139 .62386 0 ]
[.62 .01319 -5.0665 -9 ]
[.62 .01319 .9335 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 18 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 12 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 6 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01114 .34643 -18 -2.81114 ]
[.01114 .34643 0 6.18886 ]
[-0.00254 .43216 -18 -2.88408 ]
[-0.00254 .43216 0 6.11592 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.1391 .21522 m
.14374 .21986 L
s
[(-10)] .12983 .20593 .99848 1 Mshowa
.29214 .1553 m
.29652 .16018 L
s
[(-5)] .28339 .14552 .89526 1 Mshowa
.45462 .09167 m
.45869 .09682 L
s
[(0)] .44647 .08139 .79205 1 Mshowa
.62744 .024 m
.63116 .0294 L
s
[(5)] .62 .01319 .68883 1 Mshowa
.125 Mabswid
.16899 .20352 m
.17175 .20633 L
s
.19924 .19167 m
.20196 .19452 L
s
.22984 .17969 m
.23253 .18256 L
s
.2608 .16757 m
.26346 .17047 L
s
.32385 .14288 m
.32644 .14584 L
s
.35595 .13031 m
.35851 .1333 L
s
.38844 .11759 m
.39096 .12061 L
s
.42133 .10471 m
.42381 .10776 L
s
.48833 .07847 m
.49073 .08159 L
s
.52245 .06511 m
.52482 .06826 L
s
.55701 .05158 m
.55933 .05476 L
s
.592 .03788 m
.59428 .04109 L
s
.10955 .22679 m
.11236 .22955 L
s
.08035 .23823 m
.08318 .24096 L
s
.05147 .24953 m
.05434 .25223 L
s
.66334 .00995 m
.66552 .01322 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-10)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-5)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(5)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(10)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02342 .34182 m
.02957 .33951 L
s
[(0.2)] .01114 .34643 1 -0.3753 Mshowa
.00981 .42773 m
.01598 .42551 L
s
[(0.4)] -0.00254 .43216 1 -0.35909 Mshowa
.125 Mabswid
.03317 .28031 m
.03684 .27889 L
s
.02996 .30055 m
.03364 .29914 L
s
.02672 .32105 m
.0304 .31965 L
s
.02009 .36287 m
.02378 .3615 L
s
.01671 .3842 m
.0204 .38284 L
s
.01328 .40582 m
.01698 .40447 L
s
.00629 .44994 m
.01 .44862 L
s
.00272 .47246 m
.00644 .47115 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.626 .761 .943 r
.40191 .60447 .40501 .60694 .41017 .60578 .40708 .60333 Mtetra
.735 .782 .891 r
.40708 .60333 .41017 .60578 .41539 .60323 .41231 .60063 Mtetra
.766 .775 .86 r
.41231 .60063 .41539 .60323 .42063 .59996 .41757 .59716 Mtetra
.723 .759 .881 r
.41757 .59716 .42063 .59996 .42586 .59749 .42281 .5946 Mtetra
.559 .709 .941 r
.42281 .5946 .42586 .59749 .43104 .59696 .42799 .59422 Mtetra
.239 .571 .94 r
.42799 .59422 .43104 .59696 .43619 .59815 .43313 .59574 Mtetra
.152 .547 .926 r
.43313 .59574 .43619 .59815 .44135 .59947 .43829 .59738 Mtetra
.516 .759 .984 r
.43829 .59738 .44135 .59947 .44658 .59898 .44352 .59699 Mtetra
.773 .82 .89 r
.44352 .59699 .44658 .59898 .45187 .59581 .44883 .5936 Mtetra
.829 .8 .824 r
.44883 .5936 .45187 .59581 .4572 .59096 .45418 .58835 Mtetra
.799 .78 .835 r
.45418 .58835 .4572 .59096 .46253 .5868 .45952 .5839 Mtetra
.639 .737 .919 r
.45952 .5839 .46253 .5868 .4678 .58549 .4648 .58263 Mtetra
.087 .469 .89 r
.4648 .58263 .4678 .58549 .47304 .58741 .47003 .58497 Mtetra
0 .159 .623 r
.47003 .58497 .47304 .58741 .47828 .59068 .47527 .5888 Mtetra
0 .471 .85 r
.47527 .5888 .47828 .59068 .48357 .59223 .48056 .5907 Mtetra
.72 .86 .948 r
.48056 .5907 .48357 .59223 .48891 .58984 .48592 .5882 Mtetra
.869 .83 .806 r
.48592 .5882 .48891 .58984 .4943 .58388 .49132 .58172 Mtetra
.867 .799 .781 r
.49132 .58172 .4943 .58388 .49969 .57729 .49673 .57455 Mtetra
.775 .776 .854 r
.49673 .57455 .49969 .57729 .50506 .57375 .50211 .57078 Mtetra
.239 .551 .931 r
.50211 .57078 .50506 .57375 .51041 .57519 .50746 .57256 Mtetra
.616 .1 0 r
.50746 .57256 .51041 .57519 .51577 .58023 .51282 .57836 Mtetra
.663 .124 0 r
.51282 .57836 .51577 .58023 .52116 .58487 .51821 .58372 Mtetra
.229 .698 .943 r
.51821 .58372 .52116 .58487 .52658 .58496 .52364 .58401 Mtetra
.884 .882 .826 r
.52364 .58401 .52658 .58496 .53201 .57915 .52908 .57773 Mtetra
.915 .82 .737 r
.52908 .57773 .53201 .57915 .53742 .57014 .5345 .56786 Mtetra
.875 .797 .769 r
.5345 .56786 .53742 .57014 .54282 .56302 .53992 .56009 Mtetra
.615 .732 .929 r
.53992 .56009 .54282 .56302 .54827 .56198 .54537 .55908 Mtetra
.583 .081 0 r
.54537 .55908 .54827 .56198 .55378 .56734 .55088 .56521 Mtetra
.827 .355 0 r
.55088 .56521 .55378 .56734 .55934 .57509 .55646 .57404 Mtetra
.668 .116 0 r
.55646 .57404 .55934 .57509 .56491 .57922 .56204 .57886 Mtetra
.769 .96 .931 r
.56204 .57886 .56491 .57922 .5704 .57576 .56755 .57522 Mtetra
.945 .853 .719 r
.56755 .57522 .5704 .57576 .5758 .56573 .57295 .56424 Mtetra
.931 .809 .702 r
.57295 .56424 .5758 .56573 .58117 .55474 .57832 .55216 Mtetra
.841 .795 .807 r
.57832 .55216 .58117 .55474 .58662 .54927 .58377 .54621 Mtetra
0 .324 .801 r
.58377 .54621 .58662 .54927 .59224 .55242 .5894 .54985 Mtetra
.844 .389 0 r
.5894 .54985 .59224 .55242 .59802 .56166 .59521 .5603 Mtetra
.852 .394 .074 r
.59521 .5603 .59802 .56166 .60383 .57016 .60104 .56999 Mtetra
.288 0 0 r
.60104 .56999 .60383 .57016 .60949 .57118 .60673 .57138 Mtetra
.948 .919 .749 r
.60673 .57138 .60949 .57118 .61493 .56278 .61217 .56226 Mtetra
.962 .827 .663 r
.61217 .56226 .61493 .56278 .62021 .54936 .61743 .5475 Mtetra
.926 .806 .708 r
.61743 .5475 .62021 .54936 .62555 .53883 .62276 .5359 Mtetra
.657 .751 .92 r
.62276 .5359 .62555 .53883 .63116 .5373 .62838 .5343 Mtetra
.731 .254 0 r
.62838 .5343 .63116 .5373 .63709 .54508 .63434 .54309 Mtetra
.884 .452 .101 r
.63434 .54309 .63709 .54508 .64319 .55632 .64048 .55581 Mtetra
.789 .293 .01 r
.64048 .55581 .64319 .55632 .64915 .56257 .64649 .56303 Mtetra
.743 .992 .863 r
.64649 .56303 .64915 .56257 .65476 .55845 .65211 .55872 Mtetra
.978 .863 .656 r
.65211 .55872 .65476 .55845 .66002 .54552 .65734 .54456 Mtetra
.962 .816 .651 r
.65734 .54456 .66002 .54552 .66519 .53129 .66248 .52886 Mtetra
.885 .809 .77 r
.66248 .52886 .66519 .53129 .67064 .52406 .66791 .52091 Mtetra
0 .322 .803 r
.66791 .52091 .67064 .52406 .67657 .52754 .67386 .52486 Mtetra
.849 .404 0 r
.67386 .52486 .67657 .52754 .68287 .53842 .68023 .53712 Mtetra
.863 .413 .079 r
.68023 .53712 .68287 .53842 .68919 .54846 .68662 .54856 Mtetra
.384 0 0 r
.68662 .54856 .68919 .54846 .69512 .54979 .69258 .55036 Mtetra
.963 .932 .708 r
.69258 .55036 .69512 .54979 .70052 .54037 .69796 .54015 Mtetra
.98 .837 .629 r
.69796 .54015 .70052 .54037 .7056 .52539 .70298 .52368 Mtetra
.947 .817 .684 r
.70298 .52368 .7056 .52539 .71082 .51362 .70815 .51068 Mtetra
.701 .77 .905 r
.70815 .51068 .71082 .51362 .71657 .51148 .7139 .50834 Mtetra
.623 .151 0 r
.7139 .50834 .71657 .51148 .7229 .51898 .72029 .51677 Mtetra
.847 .396 0 r
.72029 .51677 .7229 .51898 .72949 .52985 .72697 .52909 Mtetra
.734 .207 0 r
.72697 .52909 .72949 .52985 .73581 .53559 .73335 .5358 Mtetra
.765 .995 .867 r
.73335 .5358 .73581 .53559 .74151 .5312 .73906 .53126 Mtetra
.982 .875 .65 r
.73906 .53126 .74151 .5312 .74667 .51857 .74417 .51746 Mtetra
.969 .83 .65 r
.74417 .51746 .74667 .51857 .75174 .50501 .74917 .50251 Mtetra
.885 .821 .779 r
.74917 .50251 .75174 .50501 .75725 .49808 .75463 .49484 Mtetra
.143 .467 .891 r
.75463 .49484 .75725 .49808 .76343 .5007 .76084 .49779 Mtetra
.704 .233 0 r
.76084 .49779 .76343 .5007 .77009 .50948 .76759 .5077 Mtetra
.744 .241 0 r
.76759 .5077 .77009 .50948 .77672 .51708 .77431 .51646 Mtetra
.068 .618 .831 r
.77431 .51646 .77672 .51708 .78281 .51714 .78044 .5169 Mtetra
.952 .932 .74 r
.78044 .5169 .78281 .51714 .78823 .50858 .78584 .50769 Mtetra
.974 .854 .66 r
.78584 .50769 .78823 .50858 .79333 .49612 .79086 .49401 Mtetra
.932 .834 .725 r
.79086 .49401 .79333 .49612 .79866 .48672 .79612 .48363 Mtetra
.675 .759 .914 r
.79612 .48363 .79866 .48672 .80461 .48492 .80207 .48165 Mtetra
0 .18 .7 r
.80207 .48165 .80461 .48492 .81118 .49004 .8087 .48743 Mtetra
.576 .085 0 r
.8087 .48743 .81118 .49004 .81794 .49691 .81555 .49532 Mtetra
0 .323 .729 r
.81555 .49532 .81794 .49691 .82435 .49947 .82203 .49852 Mtetra
.828 .954 .898 r
.82203 .49852 .82435 .49947 .83013 .49488 .82782 .49377 Mtetra
.958 .885 .718 r
.82782 .49377 .83013 .49488 .83545 .48524 .83307 .48328 Mtetra
.94 .848 .724 r
.83307 .48328 .83545 .48524 .84076 .47581 .83831 .47291 Mtetra
.816 .812 .847 r
.83831 .47291 .84076 .47581 .84655 .47131 .84406 .46794 Mtetra
.339 .578 .93 r
.84406 .46794 .84655 .47131 .85293 .47283 .85048 .46971 Mtetra
0 .238 .743 r
.85048 .46971 .85293 .47283 .85966 .47746 .85728 .47505 Mtetra
0 .369 .818 r
.85728 .47505 .85966 .47746 .86625 .48046 .86395 .4787 Mtetra
.623 .855 .987 r
.86395 .4787 .86625 .48046 .87236 .47856 .87009 .47692 Mtetra
.903 .899 .813 r
.87009 .47692 .87236 .47856 .87799 .47199 .87568 .46988 Mtetra
.921 .861 .764 r
.87568 .46988 .87799 .47199 .88346 .46408 .88109 .46125 Mtetra
.847 .826 .828 r
.88109 .46125 .88346 .46408 .8892 .45871 .88679 .45536 Mtetra
.607 .722 .926 r
.88679 .45536 .8892 .45871 .89544 .45769 .89303 .45433 Mtetra
.251 .525 .914 r
.89303 .45433 .89544 .45769 .90205 .45983 .8997 .45688 Mtetra
.186 .514 .915 r
.8997 .45688 .90205 .45983 .90869 .46197 .90641 .45952 Mtetra
.522 .753 .98 r
.90641 .45952 .90869 .46197 .91503 .46127 .91278 .45904 Mtetra
.807 .869 .894 r
.91278 .45904 .91503 .46127 .92096 .4571 .91871 .45466 Mtetra
.872 .859 .825 r
.91871 .45466 .92096 .4571 .92668 .45116 .92439 .44825 Mtetra
.833 .826 .842 r
.92439 .44825 .92668 .45116 .93252 .44615 .93018 .44281 Mtetra
.698 .763 .902 r
.93018 .44281 .93252 .44615 .93869 .44382 .93635 .44036 Mtetra
.499 .663 .935 r
.93635 .44036 .93869 .44382 .9452 .44395 .94289 .44068 Mtetra
.416 .631 .943 r
.94289 .44068 .9452 .44395 .9518 .4447 .94954 .44174 Mtetra
.547 .725 .957 r
.94954 .44174 .9518 .4447 .95825 .44404 .95602 .44127 Mtetra
.725 .814 .92 r
.95602 .44127 .95825 .44404 .96442 .4412 .9622 .43834 Mtetra
.799 .829 .875 r
.9622 .43834 .96442 .4412 .97041 .43702 .96817 .43389 Mtetra
.625 .76 .943 r
.39881 .602 .40191 .60447 .40708 .60333 .40398 .60085 Mtetra
.742 .782 .886 r
.40398 .60085 .40708 .60333 .41231 .60063 .40922 .59801 Mtetra
.773 .775 .854 r
.40922 .59801 .41231 .60063 .41757 .59716 .4145 .59434 Mtetra
.727 .759 .878 r
.4145 .59434 .41757 .59716 .42281 .5946 .41974 .59171 Mtetra
.542 .703 .944 r
.41974 .59171 .42281 .5946 .42799 .59422 .42492 .59147 Mtetra
.165 .528 .921 r
.42492 .59147 .42799 .59422 .43313 .59574 .43006 .59332 Mtetra
.073 .497 .897 r
.43006 .59332 .43313 .59574 .43829 .59738 .43522 .59527 Mtetra
.503 .753 .985 r
.43522 .59527 .43829 .59738 .44352 .59699 .44045 .59496 Mtetra
.782 .818 .882 r
.44045 .59496 .44352 .59699 .44883 .5936 .44578 .59136 Mtetra
.836 .797 .814 r
.44578 .59136 .44883 .5936 .45418 .58835 .45115 .58573 Mtetra
.807 .779 .827 r
.45115 .58573 .45418 .58835 .45952 .5839 .4565 .58099 Mtetra
.635 .735 .92 r
.4565 .58099 .45952 .5839 .4648 .58263 .46179 .57977 Mtetra
0 .405 .85 r
.46179 .57977 .4648 .58263 .47003 .58497 .46702 .58251 Mtetra
.469 0 0 r
.46702 .58251 .47003 .58497 .47527 .5888 .47225 .58689 Mtetra
0 .405 .8 r
.47225 .58689 .47527 .5888 .48056 .5907 .47753 .58913 Mtetra
.728 .858 .943 r
.47753 .58913 .48056 .5907 .48592 .5882 .4829 .58653 Mtetra
.876 .825 .793 r
.4829 .58653 .48592 .5882 .49132 .58172 .48833 .57954 Mtetra
.874 .795 .769 r
.48833 .57954 .49132 .58172 .49673 .57455 .49375 .57179 Mtetra
.782 .776 .848 r
.49375 .57179 .49673 .57455 .50211 .57078 .49914 .5678 Mtetra
.171 .511 .914 r
.49914 .5678 .50211 .57078 .50746 .57256 .5045 .56991 Mtetra
.691 .184 0 r
.5045 .56991 .50746 .57256 .51282 .57836 .50985 .57646 Mtetra
.72 .197 0 r
.50985 .57646 .51282 .57836 .51821 .58372 .51525 .58253 Mtetra
.185 .668 .929 r
.51525 .58253 .51821 .58372 .52364 .58401 .52068 .58302 Mtetra
.892 .873 .812 r
.52068 .58302 .52364 .58401 .52908 .57773 .52614 .57627 Mtetra
.92 .812 .724 r
.52614 .57627 .52908 .57773 .5345 .56786 .53157 .56556 Mtetra
.882 .793 .757 r
.53157 .56556 .5345 .56786 .53992 .56009 .537 .55715 Mtetra
.612 .731 .93 r
.537 .55715 .53992 .56009 .54537 .55908 .54246 .55617 Mtetra
.662 .165 0 r
.54246 .55617 .54537 .55908 .55088 .56521 .54798 .56306 Mtetra
.855 .4 .04 r
.54798 .56306 .55088 .56521 .55646 .57404 .55357 .57294 Mtetra
.715 .181 0 r
.55357 .57294 .55646 .57404 .56204 .57886 .55916 .57844 Mtetra
.784 .956 .925 r
.55916 .57844 .56204 .57886 .56755 .57522 .56467 .57463 Mtetra
.948 .842 .705 r
.56467 .57463 .56755 .57522 .57295 .56424 .57009 .56272 Mtetra
.934 .801 .689 r
.57009 .56272 .57295 .56424 .57832 .55216 .57546 .54956 Mtetra
.85 .794 .796 r
.57546 .54956 .57832 .55216 .58377 .54621 .58091 .54314 Mtetra
0 .253 .746 r
.58091 .54314 .58377 .54621 .5894 .54985 .58656 .54725 Mtetra
.87 .43 .047 r
.58656 .54725 .5894 .54985 .59521 .5603 .59238 .5589 Mtetra
.871 .429 .116 r
.59238 .5589 .59521 .5603 .60104 .56999 .59825 .56976 Mtetra
.346 0 0 r
.59825 .56976 .60104 .56999 .60673 .57138 .60395 .57151 Mtetra
.954 .905 .735 r
.60395 .57151 .60673 .57138 .61217 .56226 .60939 .56168 Mtetra
.963 .817 .65 r
.60939 .56168 .61217 .56226 .61743 .5475 .61464 .5456 Mtetra
.93 .799 .694 r
.61464 .5456 .61743 .5475 .62276 .5359 .61996 .53296 Mtetra
.662 .753 .918 r
.61996 .53296 .62276 .5359 .62838 .5343 .62558 .53129 Mtetra
.78 .314 0 r
.62558 .53129 .62838 .5343 .63434 .54309 .63157 .54106 Mtetra
.899 .481 .14 r
.63157 .54106 .63434 .54309 .64048 .55581 .63776 .55522 Mtetra
.815 .336 .051 r
.63776 .55522 .64048 .55581 .64649 .56303 .64381 .56342 Mtetra
.767 .995 .868 r
.64381 .56342 .64649 .56303 .65211 .55872 .64944 .55893 Mtetra
.979 .85 .644 r
.64944 .55893 .65211 .55872 .65734 .54456 .65465 .54356 Mtetra
.964 .806 .638 r
.65465 .54356 .65734 .54456 .66248 .52886 .65975 .52642 Mtetra
.893 .806 .755 r
.65975 .52642 .66248 .52886 .66791 .52091 .66516 .51774 Mtetra
0 .262 .759 r
.66516 .51774 .66791 .52091 .67386 .52486 .67114 .52214 Mtetra
.872 .441 .037 r
.67114 .52214 .67386 .52486 .68023 .53712 .67757 .53576 Mtetra
.88 .445 .115 r
.67757 .53576 .68023 .53712 .68662 .54856 .68402 .54857 Mtetra
.441 0 0 r
.68402 .54857 .68662 .54856 .69258 .55036 .69002 .55085 Mtetra
.969 .918 .696 r
.69002 .55085 .69258 .55036 .69796 .54015 .69538 .53989 Mtetra
.981 .825 .616 r
.69538 .53989 .69796 .54015 .70298 .52368 .70035 .52195 Mtetra
.951 .81 .668 r
.70035 .52195 .70298 .52368 .70815 .51068 .70548 .50773 Mtetra
.713 .774 .9 r
.70548 .50773 .70815 .51068 .7139 .50834 .71122 .50517 Mtetra
.683 .215 0 r
.71122 .50517 .7139 .50834 .72029 .51677 .71767 .51452 Mtetra
.869 .431 .037 r
.71767 .51452 .72029 .51677 .72697 .52909 .72442 .52824 Mtetra
.77 .26 0 r
.72442 .52824 .72697 .52909 .73335 .5358 .73088 .53593 Mtetra
.782 .995 .87 r
.73088 .53593 .73335 .5358 .73906 .53126 .7366 .53126 Mtetra
.984 .862 .636 r
.7366 .53126 .73906 .53126 .74417 .51746 .74165 .51634 Mtetra
.972 .821 .635 r
.74165 .51634 .74417 .51746 .74917 .50251 .74658 .5 Mtetra
.896 .818 .763 r
.74658 .5 .74917 .50251 .75463 .49484 .75201 .49158 Mtetra
.096 .435 .875 r
.75201 .49158 .75463 .49484 .76084 .49779 .75825 .49484 Mtetra
.75 .288 0 r
.75825 .49484 .76084 .49779 .76759 .5077 .76508 .50586 Mtetra
.781 .294 0 r
.76508 .50586 .76759 .5077 .77431 .51646 .77188 .51575 Mtetra
.002 .563 .805 r
.77188 .51575 .77431 .51646 .78044 .5169 .77806 .51659 Mtetra
.958 .92 .727 r
.77806 .51659 .78044 .5169 .78584 .50769 .78343 .50678 Mtetra
.977 .844 .643 r
.78343 .50678 .78584 .50769 .79086 .49401 .78838 .49191 Mtetra
.94 .828 .707 r
.78838 .49191 .79086 .49401 .79612 .48363 .79358 .48054 Mtetra
.687 .764 .91 r
.79358 .48054 .79612 .48363 .80207 .48165 .79952 .47835 Mtetra
0 .115 .645 r
.79952 .47835 .80207 .48165 .8087 .48743 .8062 .48477 Mtetra
.637 .153 0 r
.8062 .48477 .8087 .48743 .81555 .49532 .81315 .49365 Mtetra
0 .241 .666 r
.81315 .49365 .81555 .49532 .82203 .49852 .81969 .49751 Mtetra
.835 .949 .893 r
.81969 .49751 .82203 .49852 .82782 .49377 .82548 .49262 Mtetra
.963 .875 .701 r
.82548 .49262 .82782 .49377 .83307 .48328 .83068 .48132 Mtetra
.948 .842 .706 r
.83068 .48132 .83307 .48328 .83831 .47291 .83586 .47002 Mtetra
.831 .815 .835 r
.83586 .47002 .83831 .47291 .84406 .46794 .84157 .46457 Mtetra
.312 .562 .926 r
.84157 .46457 .84406 .46794 .85048 .46971 .84802 .46655 Mtetra
0 .17 .69 r
.84802 .46655 .85048 .46971 .85728 .47505 .8549 .47259 Mtetra
0 .297 .768 r
.8549 .47259 .85728 .47505 .86395 .4787 .86164 .47688 Mtetra
.61 .845 .988 r
.86164 .47688 .86395 .4787 .87009 .47692 .8678 .47524 Mtetra
.911 .894 .8 r
.8678 .47524 .87009 .47692 .87568 .46988 .87336 .46777 Mtetra
.93 .857 .747 r
.87336 .46777 .87568 .46988 .88109 .46125 .87871 .45842 Mtetra
.86 .828 .814 r
.87871 .45842 .88109 .46125 .88679 .45536 .88437 .45202 Mtetra
.61 .723 .926 r
.88437 .45202 .88679 .45536 .89303 .45433 .89062 .45094 Mtetra
.205 .493 .902 r
.89062 .45094 .89303 .45433 .8997 .45688 .89734 .45388 Mtetra
.124 .469 .893 r
.89734 .45388 .8997 .45688 .90641 .45952 .90411 .45701 Mtetra
.499 .738 .98 r
.90411 .45701 .90641 .45952 .91278 .45904 .91053 .45677 Mtetra
.814 .868 .887 r
.91053 .45677 .91278 .45904 .91871 .45466 .91644 .45221 Mtetra
.883 .858 .811 r
.91644 .45221 .91871 .45466 .92439 .44825 .92208 .44534 Mtetra
.846 .829 .83 r
.92208 .44534 .92439 .44825 .93018 .44281 .92784 .43948 Mtetra
.705 .766 .9 r
.92784 .43948 .93018 .44281 .93635 .44036 .934 .43688 Mtetra
.483 .654 .935 r
.934 .43688 .93635 .44036 .94289 .44068 .94057 .43737 Mtetra
.385 .611 .939 r
.94057 .43737 .94289 .44068 .94954 .44174 .94727 .43874 Mtetra
.53 .715 .957 r
.94727 .43874 .94954 .44174 .95602 .44127 .95379 .43846 Mtetra
.729 .814 .918 r
.95379 .43846 .95602 .44127 .9622 .43834 .95996 .43547 Mtetra
.809 .831 .867 r
.95996 .43547 .9622 .43834 .96817 .43389 .96592 .43075 Mtetra
.625 .759 .943 r
.39569 .59949 .39881 .602 .40398 .60085 .40087 .59835 Mtetra
.748 .781 .88 r
.40087 .59835 .40398 .60085 .40922 .59801 .40612 .59536 Mtetra
.779 .774 .848 r
.40612 .59536 .40922 .59801 .4145 .59434 .41141 .59151 Mtetra
.73 .759 .876 r
.41141 .59151 .4145 .59434 .41974 .59171 .41667 .5888 Mtetra
.525 .696 .947 r
.41667 .5888 .41974 .59171 .42492 .59147 .42185 .5887 Mtetra
.091 .481 .896 r
.42185 .5887 .42492 .59147 .43006 .59332 .42698 .59086 Mtetra
0 .447 .864 r
.42698 .59086 .43006 .59332 .43522 .59527 .43214 .59312 Mtetra
.493 .746 .984 r
.43214 .59312 .43522 .59527 .44045 .59496 .43737 .59289 Mtetra
.789 .815 .873 r
.43737 .59289 .44045 .59496 .44578 .59136 .44271 .58908 Mtetra
.843 .794 .804 r
.44271 .58908 .44578 .59136 .45115 .58573 .4481 .58308 Mtetra
.813 .778 .82 r
.4481 .58308 .45115 .58573 .4565 .58099 .45347 .57807 Mtetra
.631 .734 .922 r
.45347 .57807 .4565 .58099 .46179 .57977 .45876 .57689 Mtetra
0 .338 .803 r
.45876 .57689 .46179 .57977 .46702 .58251 .46399 .58002 Mtetra
.551 .02 0 r
.46399 .58002 .46702 .58251 .47225 .58689 .46921 .58493 Mtetra
0 .344 .753 r
.46921 .58493 .47225 .58689 .47753 .58913 .4745 .5875 Mtetra
.735 .854 .936 r
.4745 .5875 .47753 .58913 .4829 .58653 .47988 .58479 Mtetra
.881 .818 .782 r
.47988 .58479 .4829 .58653 .48833 .57954 .48532 .57731 Mtetra
.879 .791 .759 r
.48532 .57731 .48833 .57954 .49375 .57179 .49077 .56902 Mtetra
.789 .776 .841 r
.49077 .56902 .49375 .57179 .49914 .5678 .49617 .56481 Mtetra
.103 .469 .892 r
.49617 .56481 .49914 .5678 .5045 .56991 .50152 .56724 Mtetra
.744 .249 0 r
.50152 .56724 .5045 .56991 .50985 .57646 .50687 .5745 Mtetra
.761 .253 0 r
.50687 .5745 .50985 .57646 .51525 .58253 .51227 .58126 Mtetra
.152 .641 .919 r
.51227 .58126 .51525 .58253 .52068 .58302 .51771 .58194 Mtetra
.896 .863 .799 r
.51771 .58194 .52068 .58302 .52614 .57627 .52318 .57474 Mtetra
.922 .804 .712 r
.52318 .57474 .52614 .57627 .53157 .56556 .52863 .56322 Mtetra
.887 .789 .746 r
.52863 .56322 .53157 .56556 .537 .55715 .53408 .55419 Mtetra
.609 .73 .931 r
.53408 .55419 .537 .55715 .54246 .55617 .53954 .55324 Mtetra
.721 .232 0 r
.53954 .55324 .54246 .55617 .54798 .56306 .54506 .56086 Mtetra
.874 .434 .084 r
.54506 .56086 .54798 .56306 .55357 .57294 .55066 .57175 Mtetra
.75 .23 0 r
.55066 .57175 .55357 .57294 .55916 .57844 .55626 .57791 Mtetra
.798 .948 .92 r
.55626 .57791 .55916 .57844 .56467 .57463 .56179 .57394 Mtetra
.949 .831 .693 r
.56179 .57394 .56467 .57463 .57009 .56272 .56721 .56113 Mtetra
.937 .794 .678 r
.56721 .56113 .57009 .56272 .57546 .54956 .57258 .54694 Mtetra
.857 .791 .786 r
.57258 .54694 .57546 .54956 .58091 .54314 .57804 .54005 Mtetra
0 .184 .688 r
.57804 .54005 .58091 .54314 .58656 .54725 .5837 .54462 Mtetra
.888 .461 .09 r
.5837 .54462 .58656 .54725 .59238 .5589 .58954 .55741 Mtetra
.885 .456 .147 r
.58954 .55741 .59238 .5589 .59825 .56976 .59543 .56941 Mtetra
.389 0 0 r
.59543 .56941 .59825 .56976 .60395 .57151 .60115 .57152 Mtetra
.956 .89 .723 r
.60115 .57152 .60395 .57151 .60939 .56168 .60659 .561 Mtetra
.963 .807 .64 r
.60659 .561 .60939 .56168 .61464 .5456 .61184 .54366 Mtetra
.934 .793 .681 r
.61184 .54366 .61464 .5456 .61996 .53296 .61715 .53001 Mtetra
.667 .754 .916 r
.61715 .53001 .61996 .53296 .62558 .53129 .62277 .52826 Mtetra
.815 .359 0 r
.62277 .52826 .62558 .53129 .63157 .54106 .62879 .53898 Mtetra
.91 .503 .169 r
.62879 .53898 .63157 .54106 .63776 .55522 .63503 .55453 Mtetra
.836 .369 .08 r
.63503 .55453 .63776 .55522 .64381 .56342 .64111 .56367 Mtetra
.793 .994 .875 r
.64111 .56367 .64381 .56342 .64944 .55893 .64675 .55902 Mtetra
.979 .837 .634 r
.64675 .55902 .64944 .55893 .65465 .54356 .65194 .54247 Mtetra
.964 .798 .627 r
.65194 .54247 .65465 .54356 .65975 .52642 .65701 .52395 Mtetra
.9 .802 .742 r
.65701 .52395 .65975 .52642 .66516 .51774 .66241 .51457 Mtetra
0 .206 .713 r
.66241 .51457 .66516 .51774 .67114 .52214 .66841 .51939 Mtetra
.889 .468 .076 r
.66841 .51939 .67114 .52214 .67757 .53576 .67489 .53431 Mtetra
.893 .469 .142 r
.67489 .53431 .67757 .53576 .68402 .54857 .6814 .54845 Mtetra
.485 0 0 r
.6814 .54845 .68402 .54857 .69002 .55085 .68744 .5512 Mtetra
.973 .904 .687 r
.68744 .5512 .69002 .55085 .69538 .53989 .69278 .53953 Mtetra
.98 .815 .606 r
.69278 .53953 .69538 .53989 .70035 .52195 .69771 .52017 Mtetra
.954 .802 .655 r
.69771 .52017 .70035 .52195 .70548 .50773 .70279 .50477 Mtetra
.724 .777 .894 r
.70279 .50477 .70548 .50773 .71122 .50517 .70853 .50199 Mtetra
.728 .266 0 r
.70853 .50199 .71122 .50517 .71767 .51452 .71503 .51219 Mtetra
.884 .458 .071 r
.71503 .51219 .71767 .51452 .72442 .52824 .72186 .52727 Mtetra
.797 .302 0 r
.72186 .52727 .72442 .52824 .73088 .53593 .72838 .53592 Mtetra
.801 .992 .877 r
.72838 .53592 .73088 .53593 .7366 .53126 .73411 .53115 Mtetra
.985 .85 .626 r
.73411 .53115 .7366 .53126 .74165 .51634 .73912 .51514 Mtetra
.973 .812 .622 r
.73912 .51514 .74165 .51634 .74658 .5 .74399 .49748 Mtetra
.905 .815 .748 r
.74399 .49748 .74658 .5 .75201 .49158 .74938 .48832 Mtetra
.053 .407 .859 r
.74938 .48832 .75201 .49158 .75825 .49484 .75564 .49184 Mtetra
.783 .33 0 r
.75564 .49184 .75825 .49484 .76508 .50586 .76255 .50391 Mtetra
.808 .335 0 r
.76255 .50391 .76508 .50586 .77188 .51575 .76944 .51492 Mtetra
0 .513 .787 r
.76944 .51492 .77188 .51575 .77806 .51659 .77565 .51617 Mtetra
.962 .908 .716 r
.77565 .51617 .77806 .51659 .78343 .50678 .781 .50579 Mtetra
.978 .834 .63 r
.781 .50579 .78343 .50678 .78838 .49191 .78588 .48979 Mtetra
.946 .822 .691 r
.78588 .48979 .78838 .49191 .79358 .48054 .79102 .47744 Mtetra
.7 .769 .905 r
.79102 .47744 .79358 .48054 .79952 .47835 .79696 .47503 Mtetra
0 .059 .595 r
.79696 .47503 .79952 .47835 .8062 .48477 .80369 .48204 Mtetra
.683 .206 0 r
.80369 .48204 .8062 .48477 .81315 .49365 .81072 .49187 Mtetra
0 .169 .612 r
.81072 .49187 .81315 .49365 .81969 .49751 .81734 .49638 Mtetra
.84 .941 .89 r
.81734 .49638 .81969 .49751 .82548 .49262 .82313 .49139 Mtetra
.966 .865 .687 r
.82313 .49139 .82548 .49262 .83068 .48132 .82828 .47933 Mtetra
.953 .835 .69 r
.82828 .47933 .83068 .48132 .83586 .47002 .83339 .46712 Mtetra
.845 .817 .822 r
.83339 .46712 .83586 .47002 .84157 .46457 .83907 .46118 Mtetra
.289 .549 .922 r
.83907 .46118 .84157 .46457 .84802 .46655 .84554 .46335 Mtetra
0 .11 .64 r
.84554 .46335 .84802 .46655 .8549 .47259 .85249 .47003 Mtetra
0 .231 .719 r
.85249 .47003 .8549 .47259 .86164 .47688 .8593 .47496 Mtetra
.597 .832 .989 r
.8593 .47496 .86164 .47688 .8678 .47524 .8655 .47349 Mtetra
.917 .887 .788 r
.8655 .47349 .8678 .47524 .87336 .46777 .87103 .46561 Mtetra
.937 .851 .732 r
.87103 .46561 .87336 .46777 .87871 .45842 .87633 .45559 Mtetra
.872 .828 .801 r
.87633 .45559 .87871 .45842 .88437 .45202 .88194 .44867 Mtetra
.614 .726 .925 r
.88194 .44867 .88437 .45202 .89062 .45094 .88819 .44753 Mtetra
.161 .464 .888 r
.88819 .44753 .89062 .45094 .89734 .45388 .89496 .45082 Mtetra
.067 .425 .869 r
.89496 .45082 .89734 .45388 .90411 .45701 .9018 .45443 Mtetra
.476 .72 .977 r
.9018 .45443 .90411 .45701 .91053 .45677 .90825 .45443 Mtetra
.819 .865 .881 r
.90825 .45443 .91053 .45677 .91644 .45221 .91416 .44971 Mtetra
.892 .855 .799 r
.91416 .44971 .91644 .45221 .92208 .44534 .91976 .44241 Mtetra
.857 .829 .819 r
.91976 .44241 .92208 .44534 .92784 .43948 .92548 .43613 Mtetra
.713 .769 .897 r
.92548 .43613 .92784 .43948 .934 .43688 .93164 .43338 Mtetra
.469 .646 .935 r
.93164 .43338 .934 .43688 .94057 .43737 .93824 .43403 Mtetra
.355 .592 .935 r
.93824 .43403 .94057 .43737 .94727 .43874 .94499 .43569 Mtetra
.514 .703 .956 r
.94499 .43569 .94727 .43874 .95379 .43846 .95154 .4356 Mtetra
.731 .812 .915 r
.95154 .4356 .95379 .43846 .95996 .43547 .95772 .43256 Mtetra
.817 .831 .86 r
.95772 .43256 .95996 .43547 .96592 .43075 .96365 .4276 Mtetra
.625 .758 .942 r
.39256 .59697 .39569 .59949 .40087 .59835 .39775 .59583 Mtetra
.754 .781 .875 r
.39775 .59583 .40087 .59835 .40612 .59536 .40302 .5927 Mtetra
.785 .773 .843 r
.40302 .5927 .40612 .59536 .41141 .59151 .40832 .58866 Mtetra
.733 .759 .874 r
.40832 .58866 .41141 .59151 .41667 .5888 .41358 .58588 Mtetra
.507 .689 .95 r
.41358 .58588 .41667 .5888 .42185 .5887 .41877 .58593 Mtetra
.015 .432 .865 r
.41877 .58593 .42185 .5887 .42698 .59086 .42389 .58839 Mtetra
0 .394 .826 r
.42389 .58839 .42698 .59086 .43214 .59312 .42904 .59093 Mtetra
.482 .74 .984 r
.42904 .59093 .43214 .59312 .43737 .59289 .43428 .59078 Mtetra
.796 .813 .866 r
.43428 .59078 .43737 .59289 .44271 .58908 .43964 .58677 Mtetra
.848 .791 .795 r
.43964 .58677 .44271 .58908 .4481 .58308 .44505 .58041 Mtetra
.819 .777 .813 r
.44505 .58041 .4481 .58308 .45347 .57807 .45043 .57513 Mtetra
.627 .733 .923 r
.45043 .57513 .45347 .57807 .45876 .57689 .45573 .574 Mtetra
0 .271 .749 r
.45573 .574 .45876 .57689 .46399 .58002 .46095 .57751 Mtetra
.618 .092 0 r
.46095 .57751 .46399 .58002 .46921 .58493 .46616 .58293 Mtetra
0 .282 .7 r
.46616 .58293 .46921 .58493 .4745 .5875 .47145 .58582 Mtetra
.741 .851 .931 r
.47145 .58582 .4745 .5875 .47988 .58479 .47684 .58301 Mtetra
.886 .813 .771 r
.47684 .58301 .47988 .58479 .48532 .57731 .48231 .57506 Mtetra
.884 .787 .749 r
.48231 .57506 .48532 .57731 .49077 .56902 .48777 .56623 Mtetra
.795 .776 .836 r
.48777 .56623 .49077 .56902 .49617 .56481 .49318 .56181 Mtetra
.034 .424 .866 r
.49318 .56181 .49617 .56481 .50152 .56724 .49854 .56454 Mtetra
.785 .301 0 r
.49854 .56454 .50152 .56724 .50687 .5745 .50388 .57251 Mtetra
.793 .3 0 r
.50388 .57251 .50687 .5745 .51227 .58126 .50928 .57993 Mtetra
.113 .612 .904 r
.50928 .57993 .51227 .58126 .51771 .58194 .51473 .5808 Mtetra
.901 .855 .788 r
.51473 .5808 .51771 .58194 .52318 .57474 .52021 .57316 Mtetra
.925 .798 .702 r
.52021 .57316 .52318 .57474 .52863 .56322 .52568 .56085 Mtetra
.892 .785 .736 r
.52568 .56085 .52863 .56322 .53408 .55419 .53114 .55122 Mtetra
.607 .729 .931 r
.53114 .55122 .53408 .55419 .53954 .55324 .53661 .55029 Mtetra
.765 .286 0 r
.53661 .55029 .53954 .55324 .54506 .56086 .54214 .55862 Mtetra
.889 .461 .121 r
.54214 .55862 .54506 .56086 .55066 .57175 .54773 .57051 Mtetra
.778 .273 0 r
.54773 .57051 .55066 .57175 .55626 .57791 .55334 .57731 Mtetra
.809 .942 .914 r
.55334 .57731 .55626 .57791 .56179 .57394 .55888 .57317 Mtetra
.95 .822 .682 r
.55888 .57317 .56179 .57394 .56721 .56113 .56431 .55949 Mtetra
.938 .788 .668 r
.56431 .55949 .56721 .56113 .57258 .54694 .5697 .5443 Mtetra
.864 .789 .776 r
.5697 .5443 .57258 .54694 .57804 .54005 .57516 .53696 Mtetra
0 .118 .629 r
.57516 .53696 .57804 .54005 .5837 .54462 .58083 .54197 Mtetra
.901 .485 .126 r
.58083 .54197 .5837 .54462 .58954 .55741 .58669 .55588 Mtetra
.896 .478 .174 r
.58669 .55588 .58954 .55741 .59543 .56941 .5926 .56898 Mtetra
.434 0 0 r
.5926 .56898 .59543 .56941 .60115 .57152 .59834 .57144 Mtetra
.958 .878 .712 r
.59834 .57144 .60115 .57152 .60659 .561 .60378 .56026 Mtetra
.963 .799 .631 r
.60378 .56026 .60659 .561 .61184 .54366 .60902 .54167 Mtetra
.936 .788 .671 r
.60902 .54167 .61184 .54366 .61715 .53001 .61432 .52704 Mtetra
.671 .755 .913 r
.61432 .52704 .61715 .53001 .62277 .52826 .61995 .52521 Mtetra
.841 .396 0 r
.61995 .52521 .62277 .52826 .62879 .53898 .626 .53685 Mtetra
.918 .521 .194 r
.626 .53685 .62879 .53898 .63503 .55453 .63227 .55377 Mtetra
.852 .398 .107 r
.63227 .55377 .63503 .55453 .64111 .56367 .63839 .56382 Mtetra
.81 .991 .876 r
.63839 .56382 .64111 .56367 .64675 .55902 .64404 .55901 Mtetra
.978 .827 .625 r
.64404 .55901 .64675 .55902 .65194 .54247 .64921 .54133 Mtetra
.965 .791 .617 r
.64921 .54133 .65194 .54247 .65701 .52395 .65425 .52146 Mtetra
.906 .798 .73 r
.65425 .52146 .65701 .52395 .66241 .51457 .65964 .51139 Mtetra
0 .152 .667 r
.65964 .51139 .66241 .51457 .66841 .51939 .66566 .51662 Mtetra
.901 .49 .109 r
.66566 .51662 .66841 .51939 .67489 .53431 .67219 .5328 Mtetra
.903 .49 .166 r
.67219 .5328 .67489 .53431 .6814 .54845 .67877 .54824 Mtetra
.53 0 0 r
.67877 .54824 .6814 .54845 .68744 .5512 .68484 .55146 Mtetra
.975 .892 .678 r
.68484 .55146 .68744 .5512 .69278 .53953 .69017 .53909 Mtetra
.98 .806 .597 r
.69017 .53909 .69278 .53953 .69771 .52017 .69505 .51835 Mtetra
.956 .796 .643 r
.69505 .51835 .69771 .52017 .70279 .50477 .70009 .50179 Mtetra
.735 .78 .888 r
.70009 .50179 .70279 .50477 .70853 .50199 .70583 .4988 Mtetra
.764 .307 0 r
.70583 .4988 .70853 .50199 .71503 .51219 .71237 .50981 Mtetra
.897 .48 .101 r
.71237 .50981 .71503 .51219 .72186 .52727 .71928 .52622 Mtetra
.819 .337 0 r
.71928 .52622 .72186 .52727 .72838 .53592 .72586 .53582 Mtetra
.812 .989 .879 r
.72586 .53582 .72838 .53592 .73411 .53115 .73161 .53096 Mtetra
.985 .84 .617 r
.73161 .53096 .73411 .53115 .73912 .51514 .73658 .51391 Mtetra
.974 .804 .611 r
.73658 .51391 .73912 .51514 .74399 .49748 .74138 .49495 Mtetra
.913 .812 .734 r
.74138 .49495 .74399 .49748 .74938 .48832 .74674 .48505 Mtetra
.014 .38 .843 r
.74674 .48505 .74938 .48832 .75564 .49184 .75302 .48881 Mtetra
.81 .365 0 r
.75302 .48881 .75564 .49184 .76255 .50391 .76 .50189 Mtetra
.83 .369 0 r
.76 .50189 .76255 .50391 .76944 .51492 .76697 .51399 Mtetra
0 .455 .755 r
.76697 .51399 .76944 .51492 .77565 .51617 .77323 .51566 Mtetra
.965 .898 .707 r
.77323 .51566 .77565 .51617 .781 .50579 .77856 .50476 Mtetra
.98 .825 .619 r
.77856 .50476 .781 .50579 .78588 .48979 .78338 .48765 Mtetra
.951 .817 .676 r
.78338 .48765 .78588 .48979 .79102 .47744 .78846 .47434 Mtetra
.714 .774 .9 r
.78846 .47434 .79102 .47744 .79696 .47503 .79438 .47169 Mtetra
0 .009 .548 r
.79438 .47169 .79696 .47503 .80369 .48204 .80117 .47925 Mtetra
.721 .252 0 r
.80117 .47925 .80369 .48204 .81072 .49187 .80828 .49001 Mtetra
.438 0 0 r
.80828 .49001 .81072 .49187 .81734 .49638 .81496 .49518 Mtetra
.843 .936 .887 r
.81496 .49518 .81734 .49638 .82313 .49139 .82076 .49011 Mtetra
.969 .857 .675 r
.82076 .49011 .82313 .49139 .82828 .47933 .82587 .47733 Mtetra
.958 .83 .675 r
.82587 .47733 .82828 .47933 .83339 .46712 .83091 .46422 Mtetra
.857 .818 .81 r
.83091 .46422 .83339 .46712 .83907 .46118 .83656 .45779 Mtetra
.269 .537 .918 r
.83656 .45779 .83907 .46118 .84554 .46335 .84305 .4601 Mtetra
0 .056 .592 r
.84305 .4601 .84554 .46335 .85249 .47003 .85007 .46741 Mtetra
0 .168 .668 r
.85007 .46741 .85249 .47003 .8593 .47496 .85695 .47297 Mtetra
.58 .82 .99 r
.85695 .47297 .8593 .47496 .8655 .47349 .86318 .47169 Mtetra
.922 .882 .778 r
.86318 .47169 .8655 .47349 .87103 .46561 .86869 .46344 Mtetra
.943 .846 .718 r
.86869 .46344 .87103 .46561 .87633 .45559 .87393 .45276 Mtetra
.883 .828 .789 r
.87393 .45276 .87633 .45559 .88194 .44867 .87951 .44531 Mtetra
.62 .729 .924 r
.87951 .44531 .88194 .44867 .88819 .44753 .88576 .44408 Mtetra
.12 .435 .874 r
.88576 .44408 .88819 .44753 .89496 .45082 .89257 .44771 Mtetra
.01 .381 .844 r
.89257 .44771 .89496 .45082 .9018 .45443 .89947 .4518 Mtetra
.45 .703 .975 r
.89947 .4518 .9018 .45443 .90825 .45443 .90596 .45205 Mtetra
.823 .863 .876 r
.90596 .45205 .90825 .45443 .91416 .44971 .91187 .4472 Mtetra
.899 .853 .788 r
.91187 .4472 .91416 .44971 .91976 .44241 .91744 .43948 Mtetra
.867 .83 .809 r
.91744 .43948 .91976 .44241 .92548 .43613 .92312 .43278 Mtetra
.721 .773 .894 r
.92312 .43278 .92548 .43613 .93164 .43338 .92927 .42987 Mtetra
.455 .638 .935 r
.92927 .42987 .93164 .43338 .93824 .43403 .93589 .43065 Mtetra
.325 .572 .929 r
.93589 .43065 .93824 .43403 .94499 .43569 .94269 .4326 Mtetra
.496 .692 .955 r
.94269 .4326 .94499 .43569 .95154 .4356 .94928 .43271 Mtetra
.733 .811 .913 r
.94928 .43271 .95154 .4356 .95772 .43256 .95547 .42963 Mtetra
.825 .832 .853 r
.95547 .42963 .95772 .43256 .96365 .4276 .96138 .42443 Mtetra
.625 .758 .942 r
.38942 .59443 .39256 .59697 .39775 .59583 .39461 .59328 Mtetra
.759 .78 .871 r
.39461 .59328 .39775 .59583 .40302 .5927 .39989 .59002 Mtetra
.79 .773 .838 r
.39989 .59002 .40302 .5927 .40832 .58866 .40521 .5858 Mtetra
.736 .759 .872 r
.40521 .5858 .40832 .58866 .41358 .58588 .41049 .58295 Mtetra
.488 .681 .952 r
.41049 .58295 .41358 .58588 .41877 .58593 .41567 .58314 Mtetra
0 .379 .828 r
.41567 .58314 .41877 .58593 .42389 .58839 .42079 .5859 Mtetra
0 .34 .784 r
.42079 .5859 .42389 .58839 .42904 .59093 .42593 .58872 Mtetra
.471 .734 .984 r
.42593 .58872 .42904 .59093 .43428 .59078 .43118 .58865 Mtetra
.802 .811 .859 r
.43118 .58865 .43428 .59078 .43964 .58677 .43655 .58443 Mtetra
.853 .788 .787 r
.43655 .58443 .43964 .58677 .44505 .58041 .44198 .57772 Mtetra
.824 .776 .807 r
.44198 .57772 .44505 .58041 .45043 .57513 .44738 .57218 Mtetra
.623 .731 .924 r
.44738 .57218 .45043 .57513 .45573 .574 .45268 .5711 Mtetra
0 .203 .691 r
.45268 .5711 .45573 .574 .46095 .57751 .4579 .57498 Mtetra
.673 .154 0 r
.4579 .57498 .46095 .57751 .46616 .58293 .4631 .5809 Mtetra
0 .221 .647 r
.4631 .5809 .46616 .58293 .47145 .58582 .46839 .5841 Mtetra
.747 .849 .926 r
.46839 .5841 .47145 .58582 .47684 .58301 .47379 .5812 Mtetra
.89 .808 .762 r
.47379 .5812 .47684 .58301 .48231 .57506 .47928 .57278 Mtetra
.888 .784 .741 r
.47928 .57278 .48231 .57506 .48777 .56623 .48476 .56342 Mtetra
.8 .776 .83 r
.48476 .56342 .48777 .56623 .49318 .56181 .49018 .55879 Mtetra
0 .377 .835 r
.49018 .55879 .49318 .56181 .49854 .56454 .49554 .56183 Mtetra
.815 .344 0 r
.49554 .56183 .49854 .56454 .50388 .57251 .50088 .57048 Mtetra
.819 .338 0 r
.50088 .57048 .50388 .57251 .50928 .57993 .50627 .57856 Mtetra
.072 .581 .886 r
.50627 .57856 .50928 .57993 .51473 .5808 .51173 .57962 Mtetra
.905 .848 .777 r
.51173 .57962 .51473 .5808 .52021 .57316 .51723 .57154 Mtetra
.927 .793 .693 r
.51723 .57154 .52021 .57316 .52568 .56085 .52272 .55846 Mtetra
.896 .782 .727 r
.52272 .55846 .52568 .56085 .53114 .55122 .52819 .54824 Mtetra
.604 .727 .932 r
.52819 .54824 .53114 .55122 .53661 .55029 .53366 .54734 Mtetra
.799 .33 0 r
.53366 .54734 .53661 .55029 .54214 .55862 .5392 .55636 Mtetra
.9 .483 .152 r
.5392 .55636 .54214 .55862 .54773 .57051 .5448 .56922 Mtetra
.802 .31 0 r
.5448 .56922 .54773 .57051 .55334 .57731 .55041 .57665 Mtetra
.818 .937 .907 r
.55041 .57665 .55334 .57731 .55888 .57317 .55597 .57236 Mtetra
.951 .814 .673 r
.55597 .57236 .55888 .57317 .56431 .55949 .56141 .55781 Mtetra
.94 .783 .659 r
.56141 .55781 .56431 .55949 .5697 .5443 .5668 .54163 Mtetra
.869 .787 .767 r
.5668 .54163 .5697 .5443 .57516 .53696 .57227 .53385 Mtetra
0 .056 .569 r
.57227 .53385 .57516 .53696 .58083 .54197 .57795 .5393 Mtetra
.911 .505 .156 r
.57795 .5393 .58083 .54197 .58669 .55588 .58382 .55431 Mtetra
.904 .496 .197 r
.58382 .55431 .58669 .55588 .5926 .56898 .58975 .56849 Mtetra
.477 0 0 r
.58975 .56849 .5926 .56898 .59834 .57144 .5955 .57129 Mtetra
.96 .868 .702 r
.5955 .57129 .59834 .57144 .60378 .56026 .60095 .55945 Mtetra
.963 .792 .623 r
.60095 .55945 .60378 .56026 .60902 .54167 .60619 .53965 Mtetra
.938 .783 .662 r
.60619 .53965 .60902 .54167 .61432 .52704 .61149 .52405 Mtetra
.676 .756 .911 r
.61149 .52405 .61432 .52704 .61995 .52521 .61712 .52215 Mtetra
.861 .426 .008 r
.61712 .52215 .61995 .52521 .626 .53685 .6232 .5347 Mtetra
.924 .535 .215 r
.6232 .5347 .626 .53685 .63227 .55377 .6295 .55295 Mtetra
.865 .421 .131 r
.6295 .55295 .63227 .55377 .63839 .56382 .63565 .56391 Mtetra
.824 .988 .874 r
.63565 .56391 .63839 .56382 .64404 .55901 .64131 .55894 Mtetra
.978 .819 .617 r
.64131 .55894 .64404 .55901 .64921 .54133 .64647 .54013 Mtetra
.965 .785 .609 r
.64647 .54013 .64921 .54133 .65425 .52146 .65149 .51894 Mtetra
.911 .795 .719 r
.65149 .51894 .65425 .52146 .65964 .51139 .65687 .50819 Mtetra
0 .101 .621 r
.65687 .50819 .65964 .51139 .66566 .51662 .66291 .51383 Mtetra
.911 .509 .136 r
.66291 .51383 .66566 .51662 .67219 .5328 .66949 .53124 Mtetra
.911 .506 .187 r
.66949 .53124 .67219 .5328 .67877 .54824 .67612 .54796 Mtetra
.571 0 0 r
.67612 .54796 .67877 .54824 .68484 .55146 .68222 .55164 Mtetra
.977 .881 .669 r
.68222 .55164 .68484 .55146 .69017 .53909 .68754 .53859 Mtetra
.979 .799 .59 r
.68754 .53859 .69017 .53909 .69505 .51835 .69238 .5165 Mtetra
.958 .791 .633 r
.69238 .5165 .69505 .51835 .70009 .50179 .69738 .4988 Mtetra
.746 .782 .882 r
.69738 .4988 .70009 .50179 .70583 .4988 .70312 .49558 Mtetra
.792 .342 0 r
.70312 .49558 .70583 .4988 .71237 .50981 .70971 .5074 Mtetra
.906 .499 .126 r
.70971 .5074 .71237 .50981 .71928 .52622 .71669 .52511 Mtetra
.837 .368 .025 r
.71669 .52511 .71928 .52622 .72586 .53582 .72333 .53564 Mtetra
.819 .986 .881 r
.72333 .53564 .72586 .53582 .73161 .53096 .72908 .53071 Mtetra
.985 .832 .608 r
.72908 .53071 .73161 .53096 .73658 .51391 .73401 .51264 Mtetra
.975 .798 .601 r
.73401 .51264 .73658 .51391 .74138 .49495 .73876 .4924 Mtetra
.919 .808 .721 r
.73876 .4924 .74138 .49495 .74674 .48505 .74409 .48177 Mtetra
0 .354 .827 r
.74409 .48177 .74674 .48505 .75302 .48881 .75039 .48575 Mtetra
.831 .394 0 r
.75039 .48575 .75302 .48881 .76 .50189 .75743 .49982 Mtetra
.848 .398 0 r
.75743 .49982 .76 .50189 .76697 .51399 .76448 .51299 Mtetra
0 .394 .716 r
.76448 .51299 .76697 .51399 .77323 .51566 .77079 .51509 Mtetra
.968 .89 .698 r
.77079 .51509 .77323 .51566 .77856 .50476 .7761 .50369 Mtetra
.981 .818 .609 r
.7761 .50369 .77856 .50476 .78338 .48765 .78086 .4855 Mtetra
.954 .812 .663 r
.78086 .4855 .78338 .48765 .78846 .47434 .78589 .47124 Mtetra
.727 .779 .893 r
.78589 .47124 .78846 .47434 .79438 .47169 .7918 .46832 Mtetra
0 0 .504 r
.7918 .46832 .79438 .47169 .80117 .47925 .79863 .47641 Mtetra
.752 .29 0 r
.79863 .47641 .80117 .47925 .80828 .49001 .80582 .48809 Mtetra
.498 0 0 r
.80582 .48809 .80828 .49001 .81496 .49518 .81256 .49391 Mtetra
.845 .931 .885 r
.81256 .49391 .81496 .49518 .82076 .49011 .81838 .4888 Mtetra
.971 .851 .664 r
.81838 .4888 .82076 .49011 .82587 .47733 .82344 .47531 Mtetra
.961 .824 .662 r
.82344 .47531 .82587 .47733 .83091 .46422 .82842 .46133 Mtetra
.868 .819 .798 r
.82842 .46133 .83091 .46422 .83656 .45779 .83404 .45439 Mtetra
.252 .527 .915 r
.83404 .45439 .83656 .45779 .84305 .4601 .84055 .45682 Mtetra
0 .007 .546 r
.84055 .45682 .84305 .4601 .85007 .46741 .84763 .46474 Mtetra
0 .108 .617 r
.84763 .46474 .85007 .46741 .85695 .47297 .85458 .47093 Mtetra
.56 .807 .991 r
.85458 .47093 .85695 .47297 .86318 .47169 .86084 .46985 Mtetra
.926 .878 .769 r
.86084 .46985 .86318 .47169 .86869 .46344 .86634 .46126 Mtetra
.948 .842 .705 r
.86634 .46126 .86869 .46344 .87393 .45276 .87153 .44992 Mtetra
.892 .828 .776 r
.87153 .44992 .87393 .45276 .87951 .44531 .87706 .44195 Mtetra
.627 .732 .923 r
.87706 .44195 .87951 .44531 .88576 .44408 .88331 .44062 Mtetra
.082 .408 .86 r
.88331 .44062 .88576 .44408 .89257 .44771 .89016 .44456 Mtetra
0 .338 .816 r
.89016 .44456 .89257 .44771 .89947 .4518 .89713 .44911 Mtetra
.421 .684 .972 r
.89713 .44911 .89947 .4518 .90596 .45205 .90366 .44963 Mtetra
.827 .861 .872 r
.90366 .44963 .90596 .45205 .91187 .4472 .90957 .44466 Mtetra
.906 .851 .778 r
.90957 .44466 .91187 .4472 .91744 .43948 .9151 .43654 Mtetra
.876 .831 .799 r
.9151 .43654 .91744 .43948 .92312 .43278 .92075 .42943 Mtetra
.73 .777 .89 r
.92075 .42943 .92312 .43278 .92927 .42987 .92689 .42634 Mtetra
.443 .631 .934 r
.92689 .42634 .92927 .42987 .93589 .43065 .93354 .42725 Mtetra
.295 .552 .923 r
.93354 .42725 .93589 .43065 .94269 .4326 .94038 .42948 Mtetra
.477 .68 .955 r
.94038 .42948 .94269 .4326 .94928 .43271 .94701 .42979 Mtetra
.734 .81 .911 r
.94701 .42979 .94928 .43271 .95547 .42963 .9532 .42667 Mtetra
.832 .833 .847 r
.9532 .42667 .95547 .42963 .96138 .42443 .9591 .42126 Mtetra
.624 .759 .943 r
.38627 .5919 .38942 .59443 .39461 .59328 .39147 .59075 Mtetra
.765 .782 .867 r
.39147 .59075 .39461 .59328 .39989 .59002 .39676 .58734 Mtetra
.795 .773 .833 r
.39676 .58734 .39989 .59002 .40521 .5858 .4021 .58293 Mtetra
.738 .76 .87 r
.4021 .58293 .40521 .5858 .41049 .58295 .40738 .58002 Mtetra
.467 .672 .953 r
.40738 .58002 .41049 .58295 .41567 .58314 .41256 .58035 Mtetra
0 .32 .783 r
.41256 .58035 .41567 .58314 .42079 .5859 .41768 .58343 Mtetra
0 .278 .73 r
.41768 .58343 .42079 .5859 .42593 .58872 .42281 .58654 Mtetra
.454 .73 .986 r
.42281 .58654 .42593 .58872 .43118 .58865 .42806 .58655 Mtetra
.809 .813 .854 r
.42806 .58655 .43118 .58865 .43655 .58443 .43345 .58212 Mtetra
.859 .788 .78 r
.43345 .58212 .43655 .58443 .44198 .57772 .4389 .57504 Mtetra
.83 .776 .801 r
.4389 .57504 .44198 .57772 .44738 .57218 .44432 .56923 Mtetra
.619 .73 .926 r
.44432 .56923 .44738 .57218 .45268 .5711 .44962 .56819 Mtetra
0 .133 .626 r
.44962 .56819 .45268 .5711 .4579 .57498 .45483 .57246 Mtetra
.722 .213 0 r
.45483 .57246 .4579 .57498 .4631 .5809 .46003 .57891 Mtetra
.407 0 0 r
.46003 .57891 .4631 .5809 .46839 .5841 .46531 .58245 Mtetra
.753 .854 .925 r
.46531 .58245 .46839 .5841 .47379 .5812 .47073 .57944 Mtetra
.896 .807 .753 r
.47073 .57944 .47379 .5812 .47928 .57278 .47624 .57052 Mtetra
.893 .783 .732 r
.47624 .57052 .47928 .57278 .48476 .56342 .48174 .56061 Mtetra
.806 .776 .825 r
.48174 .56061 .48476 .56342 .49018 .55879 .48718 .55577 Mtetra
0 .325 .797 r
.48718 .55577 .49018 .55879 .49554 .56183 .49253 .55913 Mtetra
.841 .382 0 r
.49253 .55913 .49554 .56183 .50088 .57048 .49787 .5685 Mtetra
.841 .375 .029 r
.49787 .5685 .50088 .57048 .50627 .57856 .50325 .57727 Mtetra
0 .532 .842 r
.50325 .57727 .50627 .57856 .51173 .57962 .50872 .57852 Mtetra
.912 .848 .768 r
.50872 .57852 .51173 .57962 .51723 .57154 .51423 .56999 Mtetra
.931 .791 .684 r
.51423 .56999 .51723 .57154 .52272 .55846 .51974 .55608 Mtetra
.901 .781 .719 r
.51974 .55608 .52272 .55846 .52819 .54824 .52523 .54525 Mtetra
.6 .726 .933 r
.52523 .54525 .52819 .54824 .53366 .54734 .53071 .54438 Mtetra
.828 .369 0 r
.53071 .54438 .53366 .54734 .5392 .55636 .53624 .55414 Mtetra
.909 .502 .184 r
.53624 .55414 .5392 .55636 .5448 .56922 .54184 .56803 Mtetra
.824 .347 .041 r
.54184 .56803 .5448 .56922 .55041 .57665 .54747 .57612 Mtetra
.825 .945 .902 r
.54747 .57612 .55041 .57665 .55597 .57236 .55303 .57165 Mtetra
.955 .812 .663 r
.55303 .57165 .55597 .57236 .56141 .55781 .55849 .55619 Mtetra
.943 .78 .65 r
.55849 .55619 .56141 .55781 .5668 .54163 .56389 .53897 Mtetra
.875 .786 .759 r
.56389 .53897 .5668 .54163 .57227 .53385 .56937 .53073 Mtetra
0 0 .506 r
.56937 .53073 .57227 .53385 .57795 .5393 .57505 .53666 Mtetra
.919 .523 .185 r
.57505 .53666 .57795 .5393 .58382 .55431 .58094 .55283 Mtetra
.911 .513 .224 r
.58094 .55283 .58382 .55431 .58975 .56849 .58689 .56815 Mtetra
.54 0 0 r
.58689 .56815 .58975 .56849 .5955 .57129 .59266 .5713 Mtetra
.965 .866 .69 r
.59266 .5713 .5955 .57129 .60095 .55945 .59812 .55875 Mtetra
.966 .789 .614 r
.59812 .55875 .60095 .55945 .60619 .53965 .60335 .53766 Mtetra
.942 .78 .653 r
.60335 .53766 .60619 .53965 .61149 .52405 .60864 .52106 Mtetra
.679 .757 .91 r
.60864 .52106 .61149 .52405 .61712 .52215 .61428 .5191 Mtetra
.878 .452 .048 r
.61428 .5191 .61712 .52215 .6232 .5347 .62038 .5326 Mtetra
.929 .549 .238 r
.62038 .5326 .6232 .5347 .6295 .55295 .62673 .55227 Mtetra
.876 .445 .166 r
.62673 .55227 .6295 .55295 .63565 .56391 .63291 .56417 Mtetra
.825 .993 .861 r
.63291 .56417 .63565 .56391 .64131 .55894 .63858 .55902 Mtetra
.98 .815 .607 r
.63858 .55902 .64131 .55894 .64647 .54013 .64372 .53902 Mtetra
.967 .781 .6 r
.64372 .53902 .64647 .54013 .65149 .51894 .64871 .51643 Mtetra
.916 .793 .709 r
.64871 .51643 .65149 .51894 .65687 .50819 .65408 .50498 Mtetra
0 .047 .57 r
.65408 .50498 .65687 .50819 .66291 .51383 .66014 .51105 Mtetra
.919 .525 .163 r
.66014 .51105 .66291 .51383 .66949 .53124 .66677 .52978 Mtetra
.917 .522 .212 r
.66677 .52978 .66949 .53124 .67612 .54796 .67346 .54785 Mtetra
.625 .063 0 r
.67346 .54785 .67612 .54796 .68222 .55164 .67959 .552 Mtetra
.981 .879 .656 r
.67959 .552 .68222 .55164 .68754 .53859 .6849 .53823 Mtetra
.981 .795 .58 r
.6849 .53823 .68754 .53859 .69238 .5165 .6897 .51471 Mtetra
.961 .787 .623 r
.6897 .51471 .69238 .5165 .69738 .4988 .69467 .49582 Mtetra
.756 .785 .876 r
.69467 .49582 .69738 .4988 .70312 .49558 .7004 .49236 Mtetra
.817 .374 0 r
.7004 .49236 .70312 .49558 .70971 .5074 .70703 .50503 Mtetra
.915 .515 .153 r
.70703 .50503 .70971 .5074 .71669 .52511 .71409 .52412 Mtetra
.855 .399 .069 r
.71409 .52412 .71669 .52511 .72333 .53564 .72079 .53562 Mtetra
.814 .992 .871 r
.72079 .53562 .72333 .53564 .72908 .53071 .72655 .53061 Mtetra
.988 .828 .597 r
.72655 .53061 .72908 .53071 .73401 .51264 .73144 .51146 Mtetra
.977 .794 .591 r
.73144 .51146 .73401 .51264 .73876 .4924 .73613 .48987 Mtetra
.926 .806 .708 r
.73613 .48987 .73876 .4924 .74409 .48177 .74142 .47848 Mtetra
0 .327 .809 r
.74142 .47848 .74409 .48177 .75039 .48575 .74775 .4827 Mtetra
.85 .42 0 r
.74775 .4827 .75039 .48575 .75743 .49982 .75486 .4978 Mtetra
.866 .426 .033 r
.75486 .4978 .75743 .49982 .76448 .51299 .762 .51211 Mtetra
.291 0 0 r
.762 .51211 .76448 .51299 .77079 .51509 .76834 .51467 Mtetra
.972 .89 .686 r
.76834 .51467 .77079 .51509 .7761 .50369 .77363 .50273 Mtetra
.983 .815 .597 r
.77363 .50273 .7761 .50369 .78086 .4855 .77834 .48341 Mtetra
.959 .809 .65 r
.77834 .48341 .78086 .4855 .78589 .47124 .7833 .46815 Mtetra
.741 .784 .887 r
.7833 .46815 .78589 .47124 .7918 .46832 .7892 .46495 Mtetra
0 0 .459 r
.7892 .46495 .7918 .46832 .79863 .47641 .79608 .47358 Mtetra
.782 .328 0 r
.79608 .47358 .79863 .47641 .80582 .48809 .80335 .48622 Mtetra
.571 .039 0 r
.80335 .48622 .80582 .48809 .81256 .49391 .81017 .49274 Mtetra
.846 .939 .885 r
.81017 .49274 .81256 .49391 .81838 .4888 .816 .48759 Mtetra
.975 .848 .652 r
.816 .48759 .81838 .4888 .82344 .47531 .82101 .47336 Mtetra
.966 .822 .649 r
.82101 .47336 .82344 .47531 .82842 .46133 .82593 .45845 Mtetra
.879 .82 .785 r
.82593 .45845 .82842 .46133 .83404 .45439 .83151 .45097 Mtetra
.236 .516 .911 r
.83151 .45097 .83404 .45439 .84055 .45682 .83804 .45353 Mtetra
0 0 .497 r
.83804 .45353 .84055 .45682 .84763 .46474 .84518 .46208 Mtetra
0 .042 .554 r
.84518 .46208 .84763 .46474 .85458 .47093 .85221 .46893 Mtetra
.528 .798 .995 r
.85221 .46893 .85458 .47093 .86084 .46985 .85851 .46808 Mtetra
.932 .879 .76 r
.85851 .46808 .86084 .46985 .86634 .46126 .86398 .45914 Mtetra
.954 .841 .692 r
.86398 .45914 .86634 .46126 .87153 .44992 .86912 .44712 Mtetra
.902 .829 .764 r
.86912 .44712 .87153 .44992 .87706 .44195 .87461 .43859 Mtetra
.635 .737 .922 r
.87461 .43859 .87706 .44195 .88331 .44062 .88085 .43713 Mtetra
.041 .378 .843 r
.88085 .43713 .88331 .44062 .89016 .44456 .88775 .4414 Mtetra
0 .29 .783 r
.88775 .4414 .89016 .44456 .89713 .44911 .89477 .44644 Mtetra
.382 .665 .97 r
.89477 .44644 .89713 .44911 .90366 .44963 .90135 .44725 Mtetra
.831 .865 .87 r
.90135 .44725 .90366 .44963 .90957 .44466 .90726 .44217 Mtetra
.914 .852 .768 r
.90726 .44217 .90957 .44466 .9151 .43654 .91276 .43363 Mtetra
.886 .833 .788 r
.91276 .43363 .9151 .43654 .92075 .42943 .91837 .42608 Mtetra
.739 .781 .886 r
.91837 .42608 .92075 .42943 .92689 .42634 .9245 .42279 Mtetra
.431 .624 .934 r
.9245 .42279 .92689 .42634 .93354 .42725 .93117 .42382 Mtetra
.261 .531 .916 r
.93117 .42382 .93354 .42725 .94038 .42948 .93806 .42635 Mtetra
.454 .668 .955 r
.93806 .42635 .94038 .42948 .94701 .42979 .94472 .42688 Mtetra
.735 .812 .912 r
.94472 .42688 .94701 .42979 .9532 .42667 .95093 .42374 Mtetra
.84 .836 .842 r
.95093 .42374 .9532 .42667 .9591 .42126 .95681 .41809 Mtetra
.624 .759 .943 r
.3831 .58936 .38627 .5919 .39147 .59075 .38831 .58821 Mtetra
.77 .782 .863 r
.38831 .58821 .39147 .59075 .39676 .58734 .39362 .58465 Mtetra
.8 .773 .828 r
.39362 .58465 .39676 .58734 .4021 .58293 .39897 .58005 Mtetra
.741 .76 .868 r
.39897 .58005 .4021 .58293 .40738 .58002 .40426 .57707 Mtetra
.444 .663 .954 r
.40426 .57707 .40738 .58002 .41256 .58035 .40944 .57755 Mtetra
0 .259 .732 r
.40944 .57755 .41256 .58035 .41768 .58343 .41455 .58094 Mtetra
0 .217 .675 r
.41455 .58094 .41768 .58343 .42281 .58654 .41968 .58436 Mtetra
.439 .724 .986 r
.41968 .58436 .42281 .58654 .42806 .58655 .42493 .58444 Mtetra
.815 .812 .848 r
.42493 .58444 .42806 .58655 .43345 .58212 .43033 .57981 Mtetra
.864 .787 .773 r
.43033 .57981 .43345 .58212 .4389 .57504 .43581 .57235 Mtetra
.835 .775 .795 r
.43581 .57235 .4389 .57504 .44432 .56923 .44124 .56626 Mtetra
.614 .729 .927 r
.44124 .56626 .44432 .56923 .44962 .56819 .44655 .56527 Mtetra
0 .064 .558 r
.44655 .56527 .44962 .56819 .45483 .57246 .45176 .56994 Mtetra
.761 .262 0 r
.45176 .56994 .45483 .57246 .46003 .57891 .45694 .57693 Mtetra
.472 0 0 r
.45694 .57693 .46003 .57891 .46531 .58245 .46222 .58079 Mtetra
.759 .855 .922 r
.46222 .58079 .46531 .58245 .47073 .57944 .46765 .57768 Mtetra
.9 .804 .745 r
.46765 .57768 .47073 .57944 .47624 .57052 .47318 .56827 Mtetra
.897 .78 .725 r
.47318 .56827 .47624 .57052 .48174 .56061 .47871 .5578 Mtetra
.812 .776 .82 r
.47871 .5578 .48174 .56061 .48718 .55577 .48416 .55273 Mtetra
0 .27 .754 r
.48416 .55273 .48718 .55577 .49253 .55913 .48951 .55642 Mtetra
.861 .414 .035 r
.48951 .55642 .49253 .55913 .49787 .5685 .49484 .56653 Mtetra
.858 .404 .069 r
.49484 .56653 .49787 .5685 .50325 .57727 .50022 .57599 Mtetra
0 .49 .807 r
.50022 .57599 .50325 .57727 .50872 .57852 .50569 .57744 Mtetra
.916 .845 .758 r
.50569 .57744 .50872 .57852 .51423 .56999 .51122 .56844 Mtetra
.933 .787 .676 r
.51122 .56844 .51423 .56999 .51974 .55608 .51676 .5537 Mtetra
.905 .778 .711 r
.51676 .5537 .51974 .55608 .52523 .54525 .52226 .54224 Mtetra
.596 .725 .934 r
.52226 .54224 .52523 .54525 .53071 .54438 .52775 .54141 Mtetra
.851 .403 0 r
.52775 .54141 .53071 .54438 .53624 .55414 .53328 .55192 Mtetra
.916 .519 .21 r
.53328 .55192 .53624 .55414 .54184 .56803 .53888 .56686 Mtetra
.84 .376 .077 r
.53888 .56686 .54184 .56803 .54747 .57612 .54451 .57562 Mtetra
.833 .945 .895 r
.54451 .57562 .54747 .57612 .55303 .57165 .55009 .57096 Mtetra
.956 .807 .655 r
.55009 .57096 .55303 .57165 .55849 .55619 .55556 .55457 Mtetra
.945 .776 .643 r
.55556 .55457 .55849 .55619 .56389 .53897 .56097 .53629 Mtetra
.88 .785 .751 r
.56097 .53629 .56389 .53897 .56937 .53073 .56646 .5276 Mtetra
.555 .066 0 r
.56646 .5276 .56937 .53073 .57505 .53666 .57215 .53401 Mtetra
.925 .537 .209 r
.57215 .53401 .57505 .53666 .58094 .55283 .57805 .55137 Mtetra
.916 .527 .244 r
.57805 .55137 .58094 .55283 .58689 .56815 .58401 .56785 Mtetra
.581 .006 0 r
.58401 .56785 .58689 .56815 .59266 .5713 .5898 .57134 Mtetra
.967 .859 .68 r
.5898 .57134 .59266 .5713 .59812 .55875 .59526 .55807 Mtetra
.966 .784 .606 r
.59526 .55807 .59812 .55875 .60335 .53766 .60049 .53567 Mtetra
.944 .776 .644 r
.60049 .53567 .60335 .53766 .60864 .52106 .60578 .51805 Mtetra
.682 .758 .909 r
.60578 .51805 .60864 .52106 .61428 .5191 .61143 .51604 Mtetra
.892 .475 .083 r
.61143 .51604 .61428 .5191 .62038 .5326 .61755 .53053 Mtetra
.934 .56 .255 r
.61755 .53053 .62038 .5326 .62673 .55227 .62393 .55163 Mtetra
.885 .463 .19 r
.62393 .55163 .62673 .55227 .63291 .56417 .63015 .56448 Mtetra
.834 .993 .854 r
.63015 .56448 .63291 .56417 .63858 .55902 .63582 .55913 Mtetra
.981 .81 .599 r
.63582 .55913 .63858 .55902 .64372 .53902 .64095 .53792 Mtetra
.968 .777 .593 r
.64095 .53792 .64372 .53902 .64871 .51643 .64593 .51391 Mtetra
.921 .79 .699 r
.64593 .51391 .64871 .51643 .65408 .50498 .65129 .50176 Mtetra
0 0 .519 r
.65129 .50176 .65408 .50498 .66014 .51105 .65736 .50829 Mtetra
.926 .539 .185 r
.65736 .50829 .66014 .51105 .66677 .52978 .66404 .52834 Mtetra
.923 .535 .23 r
.66404 .52834 .66677 .52978 .67346 .54785 .67078 .54778 Mtetra
.661 .111 0 r
.67078 .54778 .67346 .54785 .67959 .552 .67694 .55241 Mtetra
.983 .872 .646 r
.67694 .55241 .67959 .552 .6849 .53823 .68224 .53789 Mtetra
.981 .79 .573 r
.68224 .53789 .6849 .53823 .6897 .51471 .687 .51291 Mtetra
.962 .783 .614 r
.687 .51291 .6897 .51471 .69467 .49582 .69194 .49281 Mtetra
.765 .786 .87 r
.69194 .49281 .69467 .49582 .7004 .49236 .69767 .48914 Mtetra
.837 .401 0 r
.69767 .48914 .7004 .49236 .70703 .50503 .70435 .50267 Mtetra
.922 .529 .175 r
.70435 .50267 .70703 .50503 .71409 .52412 .71147 .52314 Mtetra
.868 .423 .099 r
.71147 .52314 .71409 .52412 .72079 .53562 .71823 .53564 Mtetra
.817 .993 .867 r
.71823 .53564 .72079 .53562 .72655 .53061 .72401 .53055 Mtetra
.988 .822 .588 r
.72401 .53055 .72655 .53061 .73144 .51146 .72886 .5103 Mtetra
.978 .79 .582 r
.72886 .5103 .73144 .51146 .73613 .48987 .73349 .48735 Mtetra
.931 .803 .697 r
.73349 .48735 .73613 .48987 .74142 .47848 .73875 .47517 Mtetra
0 .3 .79 r
.73875 .47517 .74142 .47848 .74775 .4827 .7451 .47963 Mtetra
.866 .443 .008 r
.7451 .47963 .74775 .4827 .75486 .4978 .75228 .49579 Mtetra
.879 .449 .063 r
.75228 .49579 .75486 .4978 .762 .51211 .75949 .51125 Mtetra
.367 0 0 r
.75949 .51125 .762 .51211 .76834 .51467 .76589 .51427 Mtetra
.975 .885 .676 r
.76589 .51427 .76834 .51467 .77363 .50273 .77116 .5018 Mtetra
.984 .81 .587 r
.77116 .5018 .77363 .50273 .77834 .48341 .7758 .48133 Mtetra
.963 .805 .639 r
.7758 .48133 .77834 .48341 .7833 .46815 .78071 .46505 Mtetra
.755 .788 .88 r
.78071 .46505 .7833 .46815 .7892 .46495 .7866 .46156 Mtetra
.574 .119 0 r
.7866 .46156 .7892 .46495 .79608 .47358 .79353 .47074 Mtetra
.806 .359 0 r
.79353 .47074 .79608 .47358 .80335 .48622 .80088 .48435 Mtetra
.623 .099 0 r
.80088 .48435 .80335 .48622 .81017 .49274 .80776 .49158 Mtetra
.846 .94 .884 r
.80776 .49158 .81017 .49274 .816 .48759 .8136 .4864 Mtetra
.978 .844 .641 r
.8136 .4864 .816 .48759 .82101 .47336 .81857 .47144 Mtetra
.969 .817 .637 r
.81857 .47144 .82101 .47336 .82593 .45845 .82343 .45559 Mtetra
.89 .82 .773 r
.82343 .45559 .82593 .45845 .83151 .45097 .82897 .44755 Mtetra
.221 .507 .908 r
.82897 .44755 .83151 .45097 .83804 .45353 .83552 .45022 Mtetra
0 0 .452 r
.83552 .45022 .83804 .45353 .84518 .46208 .84272 .45939 Mtetra
0 0 .498 r
.84272 .45939 .84518 .46208 .85221 .46893 .84983 .46692 Mtetra
.497 .784 .996 r
.84983 .46692 .85221 .46893 .85851 .46808 .85616 .46632 Mtetra
.937 .877 .751 r
.85616 .46632 .85851 .46808 .86398 .45914 .86162 .45703 Mtetra
.959 .838 .68 r
.86162 .45703 .86398 .45914 .86912 .44712 .8667 .44433 Mtetra
.911 .828 .751 r
.8667 .44433 .86912 .44712 .87461 .43859 .87214 .43523 Mtetra
.644 .741 .92 r
.87214 .43523 .87461 .43859 .88085 .43713 .87839 .43363 Mtetra
.002 .35 .826 r
.87839 .43363 .88085 .43713 .88775 .4414 .88532 .43822 Mtetra
0 .243 .748 r
.88532 .43822 .88775 .4414 .89477 .44644 .89241 .44375 Mtetra
.344 .642 .964 r
.89241 .44375 .89477 .44644 .90135 .44725 .89903 .44487 Mtetra
.834 .866 .868 r
.89903 .44487 .90135 .44725 .90726 .44217 .90495 .43969 Mtetra
.92 .852 .758 r
.90495 .43969 .90726 .44217 .91276 .43363 .91042 .43073 Mtetra
.895 .833 .778 r
.91042 .43073 .91276 .43363 .91837 .42608 .91599 .42273 Mtetra
.749 .785 .882 r
.91599 .42273 .91837 .42608 .9245 .42279 .9221 .41923 Mtetra
.419 .618 .933 r
.9221 .41923 .9245 .42279 .93117 .42382 .9288 .42038 Mtetra
.228 .508 .907 r
.9288 .42038 .93117 .42382 .93806 .42635 .93573 .4232 Mtetra
.43 .654 .953 r
.93573 .4232 .93806 .42635 .94472 .42688 .94243 .42395 Mtetra
.735 .812 .912 r
.94243 .42395 .94472 .42688 .95093 .42374 .94865 .42081 Mtetra
.847 .837 .836 r
.94865 .42081 .95093 .42374 .95681 .41809 .95452 .41493 Mtetra
.624 .759 .943 r
.37993 .58682 .3831 .58936 .38831 .58821 .38514 .58566 Mtetra
.776 .782 .858 r
.38514 .58566 .38831 .58821 .39362 .58465 .39046 .58195 Mtetra
.805 .773 .823 r
.39046 .58195 .39362 .58465 .39897 .58005 .39583 .57716 Mtetra
.744 .761 .866 r
.39583 .57716 .39897 .58005 .40426 .57707 .40113 .57411 Mtetra
.42 .652 .955 r
.40113 .57411 .40426 .57707 .40944 .57755 .40631 .57474 Mtetra
0 .197 .677 r
.40631 .57474 .40944 .57755 .41455 .58094 .41141 .57846 Mtetra
0 .157 .617 r
.41141 .57846 .41455 .58094 .41968 .58436 .41653 .58218 Mtetra
.423 .718 .986 r
.41653 .58218 .41968 .58436 .42493 .58444 .42179 .58234 Mtetra
.821 .812 .842 r
.42179 .58234 .42493 .58444 .43033 .57981 .42721 .57749 Mtetra
.869 .785 .766 r
.42721 .57749 .43033 .57981 .43581 .57235 .43271 .56965 Mtetra
.839 .774 .79 r
.43271 .56965 .43581 .57235 .44124 .56626 .43816 .56329 Mtetra
.609 .727 .929 r
.43816 .56329 .44124 .56626 .44655 .56527 .44347 .56234 Mtetra
.51 .001 0 r
.44347 .56234 .44655 .56527 .45176 .56994 .44867 .56742 Mtetra
.792 .304 0 r
.44867 .56742 .45176 .56994 .45694 .57693 .45384 .57494 Mtetra
.53 0 0 r
.45384 .57494 .45694 .57693 .46222 .58079 .45912 .57915 Mtetra
.765 .856 .918 r
.45912 .57915 .46222 .58079 .46765 .57768 .46456 .57592 Mtetra
.904 .802 .737 r
.46456 .57592 .46765 .57768 .47318 .56827 .47011 .56601 Mtetra
.9 .778 .717 r
.47011 .56601 .47318 .56827 .47871 .5578 .47567 .55497 Mtetra
.817 .776 .815 r
.47567 .55497 .47871 .5578 .48416 .55273 .48113 .54969 Mtetra
0 .213 .706 r
.48113 .54969 .48416 .55273 .48951 .55642 .48648 .55371 Mtetra
.877 .44 .075 r
.48648 .55371 .48951 .55642 .49484 .56653 .4918 .56456 Mtetra
.872 .429 .104 r
.4918 .56456 .49484 .56653 .50022 .57599 .49717 .57473 Mtetra
0 .446 .769 r
.49717 .57473 .50022 .57599 .50569 .57744 .50264 .57637 Mtetra
.92 .841 .749 r
.50264 .57637 .50569 .57744 .51122 .56844 .5082 .56689 Mtetra
.935 .783 .668 r
.5082 .56689 .51122 .56844 .51676 .5537 .51376 .55131 Mtetra
.908 .776 .703 r
.51376 .55131 .51676 .5537 .52226 .54224 .51928 .53923 Mtetra
.592 .723 .935 r
.51928 .53923 .52226 .54224 .52775 .54141 .52477 .53844 Mtetra
.869 .431 .038 r
.52477 .53844 .52775 .54141 .53328 .55192 .5303 .54972 Mtetra
.921 .533 .231 r
.5303 .54972 .53328 .55192 .53888 .56686 .5359 .56571 Mtetra
.854 .401 .109 r
.5359 .56571 .53888 .56686 .54451 .57562 .54153 .57514 Mtetra
.842 .944 .888 r
.54153 .57514 .54451 .57562 .55009 .57096 .54712 .57028 Mtetra
.957 .802 .647 r
.54712 .57028 .55009 .57096 .55556 .55457 .55261 .55294 Mtetra
.946 .773 .635 r
.55261 .55294 .55556 .55457 .56097 .53629 .55804 .5336 Mtetra
.885 .783 .743 r
.55804 .5336 .56097 .53629 .56646 .5276 .56354 .52446 Mtetra
.611 .121 0 r
.56354 .52446 .56646 .5276 .57215 .53401 .56924 .53137 Mtetra
.93 .55 .23 r
.56924 .53137 .57215 .53401 .57805 .55137 .57515 .54994 Mtetra
.921 .539 .262 r
.57515 .54994 .57805 .55137 .58401 .56785 .58112 .56758 Mtetra
.616 .051 0 r
.58112 .56758 .58401 .56785 .5898 .57134 .58692 .57141 Mtetra
.969 .853 .671 r
.58692 .57141 .5898 .57134 .59526 .55807 .59239 .55738 Mtetra
.967 .78 .6 r
.59239 .55738 .59526 .55807 .60049 .53567 .59763 .53366 Mtetra
.945 .773 .637 r
.59763 .53366 .60049 .53567 .60578 .51805 .60292 .51502 Mtetra
.684 .758 .908 r
.60292 .51502 .60578 .51805 .61143 .51604 .60857 .51297 Mtetra
.903 .494 .113 r
.60857 .51297 .61143 .51604 .61755 .53053 .61471 .52847 Mtetra
.937 .569 .271 r
.61471 .52847 .61755 .53053 .62393 .55163 .62113 .55103 Mtetra
.892 .479 .21 r
.62113 .55103 .62393 .55163 .63015 .56448 .62737 .56483 Mtetra
.844 .993 .847 r
.62737 .56483 .63015 .56448 .63582 .55913 .63306 .55927 Mtetra
.981 .804 .592 r
.63306 .55927 .63582 .55913 .64095 .53792 .63818 .53681 Mtetra
.968 .773 .586 r
.63818 .53681 .64095 .53792 .64593 .51391 .64313 .51137 Mtetra
.924 .787 .691 r
.64313 .51137 .64593 .51391 .65129 .50176 .64848 .49853 Mtetra
0 0 .467 r
.64848 .49853 .65129 .50176 .65736 .50829 .65458 .50552 Mtetra
.931 .551 .205 r
.65458 .50552 .65736 .50829 .66404 .52834 .6613 .52693 Mtetra
.927 .546 .247 r
.6613 .52693 .66404 .52834 .67078 .54778 .6681 .54775 Mtetra
.691 .153 0 r
.6681 .54775 .67078 .54778 .67694 .55241 .67429 .55285 Mtetra
.985 .866 .637 r
.67429 .55285 .67694 .55241 .68224 .53789 .67958 .53756 Mtetra
.982 .786 .566 r
.67958 .53756 .68224 .53789 .687 .51291 .6843 .51111 Mtetra
.964 .779 .606 r
.6843 .51111 .687 .51291 .69194 .49281 .6892 .4898 Mtetra
.774 .788 .864 r
.6892 .4898 .69194 .49281 .69767 .48914 .69493 .4859 Mtetra
.854 .425 0 r
.69493 .4859 .69767 .48914 .70435 .50267 .70165 .50031 Mtetra
.927 .541 .194 r
.70165 .50031 .70435 .50267 .71147 .52314 .70885 .5222 Mtetra
.879 .444 .125 r
.70885 .5222 .71147 .52314 .71823 .53564 .71567 .5357 Mtetra
.82 .994 .863 r
.71567 .5357 .71823 .53564 .72401 .53055 .72146 .53051 Mtetra
.989 .817 .58 r
.72146 .53051 .72401 .53055 .72886 .5103 .72627 .50916 Mtetra
.979 .785 .574 r
.72627 .50916 .72886 .5103 .73349 .48735 .73084 .48483 Mtetra
.936 .8 .686 r
.73084 .48483 .73349 .48735 .73875 .47517 .73607 .47186 Mtetra
0 .272 .77 r
.73607 .47186 .73875 .47517 .7451 .47963 .74244 .47656 Mtetra
.879 .462 .037 r
.74244 .47656 .7451 .47963 .75228 .49579 .74969 .49377 Mtetra
.89 .468 .089 r
.74969 .49377 .75228 .49579 .75949 .51125 .75698 .5104 Mtetra
.436 0 0 r
.75698 .5104 .75949 .51125 .76589 .51427 .76342 .51389 Mtetra
.978 .88 .667 r
.76342 .51389 .76589 .51427 .77116 .5018 .76868 .50089 Mtetra
.985 .805 .579 r
.76868 .50089 .77116 .5018 .7758 .48133 .77326 .47926 Mtetra
.965 .8 .628 r
.77326 .47926 .7758 .48133 .78071 .46505 .77811 .46195 Mtetra
.768 .791 .872 r
.77811 .46195 .78071 .46505 .7866 .46156 .78398 .45816 Mtetra
.61 .155 0 r
.78398 .45816 .7866 .46156 .79353 .47074 .79096 .46788 Mtetra
.826 .386 0 r
.79096 .46788 .79353 .47074 .80088 .48435 .79839 .48247 Mtetra
.668 .152 0 r
.79839 .48247 .80088 .48435 .80776 .49158 .80534 .49043 Mtetra
.847 .941 .884 r
.80534 .49043 .80776 .49158 .8136 .4864 .8112 .48523 Mtetra
.98 .839 .631 r
.8112 .48523 .8136 .4864 .81857 .47144 .81613 .46953 Mtetra
.972 .813 .626 r
.81613 .46953 .81857 .47144 .82343 .45559 .82092 .45274 Mtetra
.899 .819 .761 r
.82092 .45274 .82343 .45559 .82897 .44755 .82642 .44412 Mtetra
.207 .499 .904 r
.82642 .44412 .82897 .44755 .83552 .45022 .83298 .44688 Mtetra
.58 .128 0 r
.83298 .44688 .83552 .45022 .84272 .45939 .84025 .45669 Mtetra
.553 .068 0 r
.84025 .45669 .84272 .45939 .84983 .46692 .84743 .46491 Mtetra
.462 .766 .996 r
.84743 .46491 .84983 .46692 .85616 .46632 .8538 .46457 Mtetra
.941 .876 .744 r
.8538 .46457 .85616 .46632 .86162 .45703 .85924 .45494 Mtetra
.963 .834 .669 r
.85924 .45494 .86162 .45703 .8667 .44433 .86428 .44156 Mtetra
.919 .827 .739 r
.86428 .44156 .8667 .44433 .87214 .43523 .86967 .43186 Mtetra
.653 .746 .918 r
.86967 .43186 .87214 .43523 .87839 .43363 .87591 .43011 Mtetra
0 .322 .808 r
.87591 .43011 .87839 .43363 .88532 .43822 .88289 .43501 Mtetra
0 .196 .712 r
.88289 .43501 .88532 .43822 .89241 .44375 .89004 .44104 Mtetra
.303 .616 .957 r
.89004 .44104 .89241 .44375 .89903 .44487 .89671 .44248 Mtetra
.837 .866 .865 r
.89671 .44248 .89903 .44487 .90495 .43969 .90263 .43721 Mtetra
.926 .85 .748 r
.90263 .43721 .90495 .43969 .91042 .43073 .90806 .42784 Mtetra
.903 .833 .767 r
.90806 .42784 .91042 .43073 .91599 .42273 .91359 .41938 Mtetra
.759 .788 .877 r
.91359 .41938 .91599 .42273 .9221 .41923 .91969 .41566 Mtetra
.409 .611 .932 r
.91969 .41566 .9221 .41923 .9288 .42038 .92641 .41691 Mtetra
.194 .485 .898 r
.92641 .41691 .9288 .42038 .93573 .4232 .93339 .42002 Mtetra
.406 .64 .951 r
.93339 .42002 .93573 .4232 .94243 .42395 .94013 .42102 Mtetra
.734 .812 .912 r
.94013 .42102 .94243 .42395 .94865 .42081 .94637 .41787 Mtetra
.853 .838 .83 r
.94637 .41787 .94865 .42081 .95452 .41493 .95222 .41177 Mtetra
.624 .761 .944 r
.37674 .58429 .37993 .58682 .38514 .58566 .38195 .58312 Mtetra
.781 .783 .854 r
.38195 .58312 .38514 .58566 .39046 .58195 .38729 .57925 Mtetra
.81 .773 .819 r
.38729 .57925 .39046 .58195 .39583 .57716 .39268 .57427 Mtetra
.747 .761 .864 r
.39268 .57427 .39583 .57716 .40113 .57411 .39799 .57114 Mtetra
.394 .64 .954 r
.39799 .57114 .40113 .57411 .40631 .57474 .40317 .57193 Mtetra
0 .133 .616 r
.40317 .57193 .40631 .57474 .41141 .57846 .40826 .57598 Mtetra
.44 0 0 r
.40826 .57598 .41141 .57846 .41653 .58218 .41337 .58002 Mtetra
.403 .711 .986 r
.41337 .58002 .41653 .58218 .42179 .58234 .41863 .58026 Mtetra
.827 .813 .836 r
.41863 .58026 .42179 .58234 .42721 .57749 .42407 .57519 Mtetra
.873 .784 .759 r
.42407 .57519 .42721 .57749 .43271 .56965 .42959 .56695 Mtetra
.844 .774 .784 r
.42959 .56695 .43271 .56965 .43816 .56329 .43506 .5603 Mtetra
.604 .726 .93 r
.43506 .5603 .43816 .56329 .44347 .56234 .44038 .55941 Mtetra
.574 .063 0 r
.44038 .55941 .44347 .56234 .44867 .56742 .44557 .5649 Mtetra
.818 .342 0 r
.44557 .5649 .44867 .56742 .45384 .57494 .45073 .573 Mtetra
.588 .034 0 r
.45073 .573 .45384 .57494 .45912 .57915 .456 .57755 Mtetra
.771 .861 .916 r
.456 .57755 .45912 .57915 .46456 .57592 .46145 .57421 Mtetra
.908 .8 .729 r
.46145 .57421 .46456 .57592 .47011 .56601 .46703 .56377 Mtetra
.904 .776 .71 r
.46703 .56377 .47011 .56601 .47567 .55497 .47261 .55214 Mtetra
.822 .776 .81 r
.47261 .55214 .47567 .55497 .48113 .54969 .47809 .54663 Mtetra
0 .154 .653 r
.47809 .54663 .48113 .54969 .48648 .55371 .48344 .55101 Mtetra
.89 .464 .111 r
.48344 .55101 .48648 .55371 .4918 .56456 .48874 .56263 Mtetra
.883 .452 .139 r
.48874 .56263 .4918 .56456 .49717 .57473 .4941 .57354 Mtetra
0 .391 .713 r
.4941 .57354 .49717 .57473 .50264 .57637 .49959 .57538 Mtetra
.925 .839 .741 r
.49959 .57538 .50264 .57637 .5082 .56689 .50516 .56539 Mtetra
.938 .781 .661 r
.50516 .56539 .5082 .56689 .51376 .55131 .51074 .54894 Mtetra
.912 .774 .696 r
.51074 .54894 .51376 .55131 .51928 .53923 .51628 .5362 Mtetra
.586 .721 .936 r
.51628 .5362 .51928 .53923 .52477 .53844 .52179 .53547 Mtetra
.884 .455 .076 r
.52179 .53547 .52477 .53844 .5303 .54972 .52731 .54755 Mtetra
.926 .545 .252 r
.52731 .54755 .5303 .54972 .5359 .56571 .53291 .56465 Mtetra
.865 .423 .143 r
.53291 .56465 .5359 .56571 .54153 .57514 .53854 .57476 Mtetra
.85 .949 .881 r
.53854 .57476 .54153 .57514 .54712 .57028 .54415 .56969 Mtetra
.96 .799 .639 r
.54415 .56969 .54712 .57028 .55261 .55294 .54965 .55135 Mtetra
.948 .77 .628 r
.54965 .55135 .55261 .55294 .55804 .5336 .5551 .53091 Mtetra
.889 .782 .736 r
.5551 .53091 .55804 .5336 .56354 .52446 .56061 .5213 Mtetra
.661 .174 0 r
.56061 .5213 .56354 .52446 .56924 .53137 .56631 .52876 Mtetra
.935 .561 .25 r
.56631 .52876 .56924 .53137 .57515 .54994 .57223 .54859 Mtetra
.924 .549 .279 r
.57223 .54859 .57515 .54994 .58112 .56758 .57822 .56744 Mtetra
.651 .099 0 r
.57822 .56744 .58112 .56758 .58692 .57141 .58403 .5716 Mtetra
.973 .85 .66 r
.58403 .5716 .58692 .57141 .59239 .55738 .58951 .55678 Mtetra
.968 .777 .593 r
.58951 .55678 .59239 .55738 .59763 .53366 .59475 .53167 Mtetra
.947 .77 .63 r
.59475 .53167 .59763 .53366 .60292 .51502 .60004 .51198 Mtetra
.685 .758 .907 r
.60004 .51198 .60292 .51502 .60857 .51297 .6057 .50991 Mtetra
.912 .511 .141 r
.6057 .50991 .60857 .51297 .61471 .52847 .61186 .52647 Mtetra
.94 .578 .286 r
.61186 .52647 .61471 .52847 .62113 .55103 .61831 .55055 Mtetra
.897 .494 .233 r
.61831 .55055 .62113 .55103 .62737 .56483 .62458 .56534 Mtetra
.848 .995 .832 r
.62458 .56534 .62737 .56483 .63306 .55927 .63028 .55953 Mtetra
.982 .8 .584 r
.63028 .55953 .63306 .55927 .63818 .53681 .63539 .53576 Mtetra
.969 .77 .579 r
.63539 .53576 .63818 .53681 .64313 .51137 .64032 .50883 Mtetra
.928 .784 .682 r
.64032 .50883 .64313 .51137 .64848 .49853 .64566 .49528 Mtetra
.582 .104 0 r
.64566 .49528 .64848 .49853 .65458 .50552 .65178 .50278 Mtetra
.936 .561 .224 r
.65178 .50278 .65458 .50552 .6613 .52693 .65855 .52561 Mtetra
.93 .555 .263 r
.65855 .52561 .6613 .52693 .6681 .54775 .6654 .54787 Mtetra
.719 .196 0 r
.6654 .54787 .6681 .54775 .67429 .55285 .67162 .55344 Mtetra
.987 .862 .626 r
.67162 .55344 .67429 .55285 .67958 .53756 .6769 .53733 Mtetra
.982 .782 .558 r
.6769 .53733 .67958 .53756 .6843 .51111 .68158 .50934 Mtetra
.965 .776 .598 r
.68158 .50934 .6843 .51111 .6892 .4898 .68645 .48677 Mtetra
.781 .789 .859 r
.68645 .48677 .6892 .4898 .69493 .4859 .69218 .48266 Mtetra
.87 .447 .017 r
.69218 .48266 .69493 .4859 .70165 .50031 .69894 .498 Mtetra
.932 .552 .212 r
.69894 .498 .70165 .50031 .70885 .5222 .70621 .52136 Mtetra
.888 .463 .153 r
.70621 .52136 .70885 .5222 .71567 .5357 .71309 .5359 Mtetra
.816 .997 .852 r
.71309 .5359 .71567 .5357 .72146 .53051 .7189 .53061 Mtetra
.99 .813 .571 r
.7189 .53061 .72146 .53051 .72627 .50916 .72367 .50808 Mtetra
.98 .782 .565 r
.72367 .50808 .72627 .50916 .73084 .48483 .72818 .48231 Mtetra
.94 .798 .675 r
.72818 .48231 .73084 .48483 .73607 .47186 .73338 .46854 Mtetra
0 .242 .747 r
.73338 .46854 .73607 .47186 .74244 .47656 .73977 .47349 Mtetra
.89 .48 .063 r
.73977 .47349 .74244 .47656 .74969 .49377 .74709 .49181 Mtetra
.9 .486 .116 r
.74709 .49181 .74969 .49377 .75698 .5104 .75446 .50965 Mtetra
.509 0 0 r
.75446 .50965 .75698 .5104 .76342 .51389 .76094 .51364 Mtetra
.981 .878 .656 r
.76094 .51364 .76342 .51389 .76868 .50089 .76618 .50008 Mtetra
.987 .801 .569 r
.76618 .50008 .76868 .50089 .77326 .47926 .7707 .47724 Mtetra
.968 .797 .617 r
.7707 .47724 .77326 .47926 .77811 .46195 .7755 .45885 Mtetra
.78 .795 .865 r
.7755 .45885 .77811 .46195 .78398 .45816 .78136 .45474 Mtetra
.644 .19 0 r
.78136 .45474 .78398 .45816 .79096 .46788 .78838 .46503 Mtetra
.844 .411 0 r
.78838 .46503 .79096 .46788 .79839 .48247 .79589 .48064 Mtetra
.711 .203 0 r
.79589 .48064 .79839 .48247 .80534 .49043 .80291 .48936 Mtetra
.846 .947 .884 r
.80291 .48936 .80534 .49043 .8112 .48523 .80879 .48415 Mtetra
.983 .837 .621 r
.80879 .48415 .8112 .48523 .81613 .46953 .81367 .46769 Mtetra
.975 .81 .614 r
.81367 .46769 .81613 .46953 .82092 .45274 .8184 .4499 Mtetra
.907 .819 .748 r
.8184 .4499 .82092 .45274 .82642 .44412 .82386 .44068 Mtetra
.193 .49 .901 r
.82386 .44068 .82642 .44412 .83298 .44688 .83044 .44354 Mtetra
.619 .166 0 r
.83044 .44354 .83298 .44688 .84025 .45669 .83778 .454 Mtetra
.604 .121 0 r
.83778 .454 .84025 .45669 .84743 .46491 .84503 .46294 Mtetra
.417 .747 .994 r
.84503 .46294 .84743 .46491 .8538 .46457 .85144 .46288 Mtetra
.946 .876 .736 r
.85144 .46288 .8538 .46457 .85924 .45494 .85686 .45291 Mtetra
.967 .832 .657 r
.85686 .45291 .85924 .45494 .86428 .44156 .86185 .43881 Mtetra
.927 .827 .727 r
.86185 .43881 .86428 .44156 .86967 .43186 .86719 .42849 Mtetra
.664 .751 .915 r
.86719 .42849 .86967 .43186 .87591 .43011 .87342 .42658 Mtetra
0 .293 .789 r
.87342 .42658 .87591 .43011 .88289 .43501 .88044 .43179 Mtetra
0 .148 .673 r
.88044 .43179 .88289 .43501 .89004 .44104 .88765 .43835 Mtetra
.253 .587 .947 r
.88765 .43835 .89004 .44104 .89671 .44248 .89437 .44012 Mtetra
.84 .869 .864 r
.89437 .44012 .89671 .44248 .90263 .43721 .9003 .43478 Mtetra
.932 .851 .739 r
.9003 .43478 .90263 .43721 .90806 .42784 .9057 .42497 Mtetra
.911 .834 .757 r
.9057 .42497 .90806 .42784 .91359 .41938 .91119 .41603 Mtetra
.769 .792 .872 r
.91119 .41603 .91359 .41938 .91969 .41566 .91727 .41207 Mtetra
.398 .605 .932 r
.91727 .41207 .91969 .41566 .92641 .41691 .92401 .41342 Mtetra
.158 .461 .887 r
.92401 .41342 .92641 .41691 .93339 .42002 .93104 .41684 Mtetra
.377 .623 .949 r
.93104 .41684 .93339 .42002 .94013 .42102 .93783 .41809 Mtetra
.734 .813 .914 r
.93783 .41809 .94013 .42102 .94637 .41787 .94407 .41494 Mtetra
.86 .841 .825 r
.94407 .41494 .94637 .41787 .95222 .41177 .94991 .40862 Mtetra
.623 .762 .945 r
.37353 .58175 .37674 .58429 .38195 .58312 .37876 .58058 Mtetra
.787 .784 .85 r
.37876 .58058 .38195 .58312 .38729 .57925 .38411 .57656 Mtetra
.815 .773 .814 r
.38411 .57656 .38729 .57925 .39268 .57427 .38951 .57136 Mtetra
.75 .762 .862 r
.38951 .57136 .39268 .57427 .39799 .57114 .39484 .56816 Mtetra
.365 .626 .953 r
.39484 .56816 .39799 .57114 .40317 .57193 .40002 .56911 Mtetra
0 .069 .551 r
.40002 .56911 .40317 .57193 .40826 .57598 .40509 .57351 Mtetra
.504 0 0 r
.40509 .57351 .40826 .57598 .41337 .58002 .4102 .57788 Mtetra
.382 .704 .985 r
.4102 .57788 .41337 .58002 .41863 .58026 .41546 .57821 Mtetra
.834 .813 .831 r
.41546 .57821 .41863 .58026 .42407 .57519 .42091 .5729 Mtetra
.878 .783 .753 r
.42091 .5729 .42407 .57519 .42959 .56695 .42646 .56425 Mtetra
.849 .774 .778 r
.42646 .56425 .42959 .56695 .43506 .5603 .43195 .5573 Mtetra
.599 .724 .932 r
.43195 .5573 .43506 .5603 .44038 .55941 .43728 .55646 Mtetra
.63 .122 0 r
.43728 .55646 .44038 .55941 .44557 .5649 .44245 .5624 Mtetra
.84 .375 .003 r
.44245 .5624 .44557 .5649 .45073 .573 .4476 .57108 Mtetra
.637 .09 0 r
.4476 .57108 .45073 .573 .456 .57755 .45287 .576 Mtetra
.777 .864 .913 r
.45287 .576 .456 .57755 .46145 .57421 .45833 .57254 Mtetra
.912 .798 .721 r
.45833 .57254 .46145 .57421 .46703 .56377 .46394 .56154 Mtetra
.907 .774 .703 r
.46394 .56154 .46703 .56377 .47261 .55214 .46955 .5493 Mtetra
.827 .776 .805 r
.46955 .5493 .47261 .55214 .47809 .54663 .47503 .54356 Mtetra
0 .093 .596 r
.47503 .54356 .47809 .54663 .48344 .55101 .48038 .54831 Mtetra
.9 .484 .143 r
.48038 .54831 .48344 .55101 .48874 .56263 .48567 .56074 Mtetra
.892 .471 .168 r
.48567 .56074 .48874 .56263 .4941 .57354 .49102 .57241 Mtetra
.251 0 0 r
.49102 .57241 .4941 .57354 .49959 .57538 .49651 .57445 Mtetra
.93 .837 .732 r
.49651 .57445 .49959 .57538 .50516 .56539 .50211 .56394 Mtetra
.94 .778 .653 r
.50211 .56394 .50516 .56539 .51074 .54894 .50772 .54656 Mtetra
.915 .772 .689 r
.50772 .54656 .51074 .54894 .51628 .5362 .51328 .53316 Mtetra
.579 .719 .938 r
.51328 .53316 .51628 .5362 .52179 .53547 .51879 .53249 Mtetra
.896 .477 .11 r
.51879 .53249 .52179 .53547 .52731 .54755 .52431 .54542 Mtetra
.929 .556 .271 r
.52431 .54542 .52731 .54755 .53291 .56465 .5299 .56367 Mtetra
.874 .443 .171 r
.5299 .56367 .53291 .56465 .53854 .57476 .53554 .57449 Mtetra
.859 .952 .872 r
.53554 .57449 .53854 .57476 .54415 .56969 .54116 .56918 Mtetra
.961 .796 .631 r
.54116 .56918 .54415 .56969 .54965 .55135 .54668 .54979 Mtetra
.949 .767 .622 r
.54668 .54979 .54965 .55135 .5551 .53091 .55214 .52821 Mtetra
.893 .78 .729 r
.55214 .52821 .5551 .53091 .56061 .5213 .55766 .51814 Mtetra
.705 .223 0 r
.55766 .51814 .56061 .5213 .56631 .52876 .56337 .52617 Mtetra
.938 .571 .267 r
.56337 .52617 .56631 .52876 .57223 .54859 .5693 .54731 Mtetra
.927 .558 .295 r
.5693 .54731 .57223 .54859 .57822 .56744 .5753 .56742 Mtetra
.678 .139 0 r
.5753 .56742 .57822 .56744 .58403 .5716 .58112 .57191 Mtetra
.975 .846 .651 r
.58112 .57191 .58403 .5716 .58951 .55678 .58662 .55625 Mtetra
.969 .774 .586 r
.58662 .55625 .58951 .55678 .59475 .53167 .59185 .52969 Mtetra
.949 .767 .623 r
.59185 .52969 .59475 .53167 .60004 .51198 .59715 .50892 Mtetra
.684 .757 .907 r
.59715 .50892 .60004 .51198 .6057 .50991 .60282 .50685 Mtetra
.92 .526 .166 r
.60282 .50685 .6057 .50991 .61186 .52647 .609 .52453 Mtetra
.942 .585 .299 r
.609 .52453 .61186 .52647 .61831 .55055 .61548 .55019 Mtetra
.902 .506 .251 r
.61548 .55019 .61831 .55055 .62458 .56534 .62178 .56598 Mtetra
.855 .996 .818 r
.62178 .56598 .62458 .56534 .63028 .55953 .62749 .55989 Mtetra
.983 .797 .576 r
.62749 .55989 .63028 .55953 .63539 .53576 .63258 .53475 Mtetra
.97 .767 .573 r
.63258 .53475 .63539 .53576 .64032 .50883 .6375 .50628 Mtetra
.931 .782 .674 r
.6375 .50628 .64032 .50883 .64566 .49528 .64283 .49202 Mtetra
.629 .153 0 r
.64283 .49202 .64566 .49528 .65178 .50278 .64897 .50007 Mtetra
.94 .571 .24 r
.64897 .50007 .65178 .50278 .65855 .52561 .65579 .52438 Mtetra
.933 .564 .278 r
.65579 .52438 .65855 .52561 .6654 .54787 .66269 .54812 Mtetra
.741 .231 0 r
.66269 .54812 .6654 .54787 .67162 .55344 .66894 .55417 Mtetra
.989 .858 .615 r
.66894 .55417 .67162 .55344 .6769 .53733 .67421 .53719 Mtetra
.983 .779 .552 r
.67421 .53719 .6769 .53733 .68158 .50934 .67885 .50759 Mtetra
.967 .773 .59 r
.67885 .50759 .68158 .50934 .68645 .48677 .68368 .48373 Mtetra
.788 .79 .854 r
.68368 .48373 .68645 .48677 .69218 .48266 .68942 .47942 Mtetra
.882 .467 .047 r
.68942 .47942 .69218 .48266 .69894 .498 .69623 .49574 Mtetra
.936 .562 .228 r
.69623 .49574 .69894 .498 .70621 .52136 .70357 .52062 Mtetra
.896 .479 .177 r
.70357 .52062 .70621 .52136 .71309 .5359 .71051 .53623 Mtetra
.814 .999 .841 r
.71051 .53623 .71309 .5359 .7189 .53061 .71632 .53081 Mtetra
.991 .809 .563 r
.71632 .53081 .7189 .53061 .72367 .50808 .72106 .50706 Mtetra
.981 .778 .558 r
.72106 .50706 .72367 .50808 .72818 .48231 .72551 .47981 Mtetra
.944 .795 .665 r
.72551 .47981 .72818 .48231 .73338 .46854 .73068 .4652 Mtetra
0 .211 .722 r
.73068 .4652 .73338 .46854 .73977 .47349 .73709 .47042 Mtetra
.9 .496 .088 r
.73709 .47042 .73977 .47349 .74709 .49181 .74448 .48989 Mtetra
.908 .501 .14 r
.74448 .48989 .74709 .49181 .75446 .50965 .75194 .50899 Mtetra
.57 0 0 r
.75194 .50899 .75446 .50965 .76094 .51364 .75846 .51349 Mtetra
.983 .876 .646 r
.75846 .51349 .76094 .51364 .76618 .50008 .76369 .49935 Mtetra
.988 .797 .56 r
.76369 .49935 .76618 .50008 .7707 .47724 .76814 .47525 Mtetra
.971 .794 .607 r
.76814 .47525 .7707 .47724 .7755 .45885 .77288 .45575 Mtetra
.792 .798 .857 r
.77288 .45575 .7755 .45885 .78136 .45474 .77872 .45132 Mtetra
.675 .222 0 r
.77872 .45132 .78136 .45474 .78838 .46503 .78579 .46219 Mtetra
.859 .432 0 r
.78579 .46219 .78838 .46503 .79589 .48064 .79339 .47885 Mtetra
.747 .248 0 r
.79339 .47885 .79589 .48064 .80291 .48936 .80048 .48837 Mtetra
.845 .952 .885 r
.80048 .48837 .80291 .48936 .80879 .48415 .80637 .48314 Mtetra
.985 .833 .611 r
.80637 .48314 .80879 .48415 .81367 .46769 .81121 .46589 Mtetra
.978 .806 .604 r
.81121 .46589 .81367 .46769 .8184 .4499 .81587 .44708 Mtetra
.915 .818 .736 r
.81587 .44708 .8184 .4499 .82386 .44068 .82129 .43723 Mtetra
.18 .482 .897 r
.82129 .43723 .82386 .44068 .83044 .44354 .82789 .44018 Mtetra
.653 .202 0 r
.82789 .44018 .83044 .44354 .83778 .454 .83529 .45131 Mtetra
.648 .168 0 r
.83529 .45131 .83778 .454 .84503 .46294 .84262 .461 Mtetra
.367 .723 .988 r
.84262 .461 .84503 .46294 .85144 .46288 .84907 .46124 Mtetra
.95 .876 .728 r
.84907 .46124 .85144 .46288 .85686 .45291 .85448 .45092 Mtetra
.971 .829 .646 r
.85448 .45092 .85686 .45291 .86185 .43881 .85941 .43609 Mtetra
.934 .825 .715 r
.85941 .43609 .86185 .43881 .86719 .42849 .8647 .42512 Mtetra
.675 .756 .912 r
.8647 .42512 .86719 .42849 .87342 .42658 .87092 .42302 Mtetra
0 .263 .769 r
.87092 .42302 .87342 .42658 .88044 .43179 .87798 .42855 Mtetra
0 .1 .632 r
.87798 .42855 .88044 .43179 .88765 .43835 .88526 .43565 Mtetra
.2 .554 .933 r
.88526 .43565 .88765 .43835 .89437 .44012 .89203 .43778 Mtetra
.843 .872 .863 r
.89203 .43778 .89437 .44012 .9003 .43478 .89796 .43237 Mtetra
.938 .85 .729 r
.89796 .43237 .9003 .43478 .9057 .42497 .90334 .42213 Mtetra
.919 .834 .746 r
.90334 .42213 .9057 .42497 .91119 .41603 .90878 .41269 Mtetra
.779 .796 .867 r
.90878 .41269 .91119 .41603 .91727 .41207 .91484 .40847 Mtetra
.387 .599 .931 r
.91484 .40847 .91727 .41207 .92401 .41342 .92161 .40992 Mtetra
.12 .435 .874 r
.92161 .40992 .92401 .41342 .93104 .41684 .92868 .41366 Mtetra
.346 .606 .945 r
.92868 .41366 .93104 .41684 .93783 .41809 .93551 .41517 Mtetra
.733 .814 .915 r
.93551 .41517 .93783 .41809 .94407 .41494 .94177 .41203 Mtetra
.866 .843 .82 r
.94177 .41203 .94407 .41494 .94991 .40862 .94759 .40547 Mtetra
.623 .762 .946 r
.37032 .57923 .37353 .58175 .37876 .58058 .37555 .57805 Mtetra
.792 .785 .846 r
.37555 .57805 .37876 .58058 .38411 .57656 .38092 .57386 Mtetra
.819 .773 .809 r
.38092 .57386 .38411 .57656 .38951 .57136 .38634 .56845 Mtetra
.752 .762 .86 r
.38634 .56845 .38951 .57136 .39484 .56816 .39168 .56517 Mtetra
.334 .61 .95 r
.39168 .56517 .39484 .56816 .40002 .56911 .39685 .56629 Mtetra
.513 0 0 r
.39685 .56629 .40002 .56911 .40509 .57351 .40191 .57105 Mtetra
.562 .025 0 r
.40191 .57105 .40509 .57351 .4102 .57788 .40701 .57575 Mtetra
.36 .695 .983 r
.40701 .57575 .4102 .57788 .41546 .57821 .41227 .57618 Mtetra
.839 .813 .825 r
.41227 .57618 .41546 .57821 .42091 .5729 .41775 .57062 Mtetra
.882 .782 .746 r
.41775 .57062 .42091 .5729 .42646 .56425 .42332 .56155 Mtetra
.853 .773 .773 r
.42332 .56155 .42646 .56425 .43195 .5573 .42883 .55429 Mtetra
.593 .722 .934 r
.42883 .55429 .43195 .5573 .43728 .55646 .43416 .55351 Mtetra
.679 .176 0 r
.43416 .55351 .43728 .55646 .44245 .5624 .43933 .5599 Mtetra
.857 .404 .045 r
.43933 .5599 .44245 .5624 .4476 .57108 .44446 .56919 Mtetra
.678 .139 0 r
.44446 .56919 .4476 .57108 .45287 .576 .44972 .57448 Mtetra
.784 .867 .91 r
.44972 .57448 .45287 .576 .45833 .57254 .4552 .57089 Mtetra
.915 .796 .714 r
.4552 .57089 .45833 .57254 .46394 .56154 .46083 .55932 Mtetra
.91 .772 .696 r
.46083 .55932 .46394 .56154 .46955 .5493 .46647 .54646 Mtetra
.831 .776 .799 r
.46647 .54646 .46955 .5493 .47503 .54356 .47197 .54048 Mtetra
0 .033 .535 r
.47197 .54048 .47503 .54356 .48038 .54831 .47731 .54562 Mtetra
.909 .502 .171 r
.47731 .54562 .48038 .54831 .48567 .56074 .48259 .55888 Mtetra
.9 .488 .194 r
.48259 .55888 .48567 .56074 .49102 .57241 .48793 .57134 Mtetra
.309 0 0 r
.48793 .57134 .49102 .57241 .49651 .57445 .49342 .57358 Mtetra
.934 .834 .723 r
.49342 .57358 .49651 .57445 .50211 .56394 .49904 .56251 Mtetra
.942 .776 .647 r
.49904 .56251 .50211 .56394 .50772 .54656 .50468 .54419 Mtetra
.917 .769 .682 r
.50468 .54419 .50772 .54656 .51328 .53316 .51026 .5301 Mtetra
.571 .715 .94 r
.51026 .5301 .51328 .53316 .51879 .53249 .51578 .52952 Mtetra
.906 .496 .14 r
.51578 .52952 .51879 .53249 .52431 .54542 .52129 .54332 Mtetra
.932 .565 .287 r
.52129 .54332 .52431 .54542 .5299 .56367 .52687 .56275 Mtetra
.881 .46 .196 r
.52687 .56275 .5299 .56367 .53554 .57449 .53252 .57429 Mtetra
.868 .953 .863 r
.53252 .57429 .53554 .57449 .54116 .56918 .53815 .56872 Mtetra
.963 .792 .624 r
.53815 .56872 .54116 .56918 .54668 .54979 .5437 .54824 Mtetra
.951 .764 .616 r
.5437 .54824 .54668 .54979 .55214 .52821 .54918 .52549 Mtetra
.897 .778 .723 r
.54918 .52549 .55214 .52821 .55766 .51814 .55471 .51496 Mtetra
.744 .269 0 r
.55471 .51496 .55766 .51814 .56337 .52617 .56042 .5236 Mtetra
.941 .579 .283 r
.56042 .5236 .56337 .52617 .5693 .54731 .56635 .54611 Mtetra
.929 .566 .308 r
.56635 .54611 .5693 .54731 .5753 .56742 .57236 .5675 Mtetra
.7 .173 0 r
.57236 .5675 .5753 .56742 .58112 .57191 .5782 .57232 Mtetra
.977 .841 .641 r
.5782 .57232 .58112 .57191 .58662 .55625 .58371 .55576 Mtetra
.969 .77 .58 r
.58371 .55576 .58662 .55625 .59185 .52969 .58895 .5277 Mtetra
.95 .765 .617 r
.58895 .5277 .59185 .52969 .59715 .50892 .59424 .50584 Mtetra
.682 .756 .907 r
.59424 .50584 .59715 .50892 .60282 .50685 .59993 .50379 Mtetra
.927 .54 .188 r
.59993 .50379 .60282 .50685 .609 .52453 .60613 .52264 Mtetra
.944 .592 .311 r
.60613 .52264 .609 .52453 .61548 .55019 .61264 .54992 Mtetra
.906 .517 .268 r
.61264 .54992 .61548 .55019 .62178 .56598 .61896 .56674 Mtetra
.864 .996 .805 r
.61896 .56674 .62178 .56598 .62749 .55989 .62468 .56034 Mtetra
.983 .792 .569 r
.62468 .56034 .62749 .55989 .63258 .53475 .62977 .53376 Mtetra
.971 .763 .567 r
.62977 .53376 .63258 .53475 .6375 .50628 .63466 .50372 Mtetra
.933 .779 .667 r
.63466 .50372 .6375 .50628 .64283 .49202 .63999 .48874 Mtetra
.673 .199 0 r
.63999 .48874 .64283 .49202 .64897 .50007 .64615 .49738 Mtetra
.943 .579 .255 r
.64615 .49738 .64897 .50007 .65579 .52438 .65302 .52323 Mtetra
.936 .572 .29 r
.65302 .52323 .65579 .52438 .66269 .54812 .65998 .54849 Mtetra
.759 .261 .036 r
.65998 .54849 .66269 .54812 .66894 .55417 .66626 .55501 Mtetra
.991 .853 .606 r
.66626 .55501 .66894 .55417 .67421 .53719 .67151 .53711 Mtetra
.983 .775 .546 r
.67151 .53711 .67421 .53719 .67885 .50759 .67611 .50585 Mtetra
.968 .769 .584 r
.67611 .50585 .67885 .50759 .68368 .48373 .68091 .48068 Mtetra
.795 .791 .849 r
.68091 .48068 .68368 .48373 .68942 .47942 .68665 .47618 Mtetra
.893 .484 .073 r
.68665 .47618 .68942 .47942 .69623 .49574 .6935 .49351 Mtetra
.94 .57 .243 r
.6935 .49351 .69623 .49574 .70357 .52062 .70092 .51996 Mtetra
.902 .493 .197 r
.70092 .51996 .70357 .52062 .71051 .53623 .70792 .53666 Mtetra
.814 1 .83 r
.70792 .53666 .71051 .53623 .71632 .53081 .71374 .5311 Mtetra
.992 .805 .555 r
.71374 .5311 .71632 .53081 .72106 .50706 .71844 .50609 Mtetra
.981 .774 .551 r
.71844 .50609 .72106 .50706 .72551 .47981 .72283 .4773 Mtetra
.947 .792 .655 r
.72283 .4773 .72551 .47981 .73068 .4652 .72796 .46185 Mtetra
0 .178 .695 r
.72796 .46185 .73068 .4652 .73709 .47042 .7344 .46736 Mtetra
.908 .51 .11 r
.7344 .46736 .73709 .47042 .74448 .48989 .74186 .48802 Mtetra
.915 .514 .16 r
.74186 .48802 .74448 .48989 .75194 .50899 .7494 .50841 Mtetra
.619 .052 0 r
.7494 .50841 .75194 .50899 .75846 .51349 .75597 .51342 Mtetra
.986 .872 .636 r
.75597 .51342 .75846 .51349 .76369 .49935 .76118 .49867 Mtetra
.988 .793 .552 r
.76118 .49867 .76369 .49935 .76814 .47525 .76557 .47328 Mtetra
.973 .79 .597 r
.76557 .47328 .76814 .47525 .77288 .45575 .77024 .45264 Mtetra
.804 .8 .848 r
.77024 .45264 .77288 .45575 .77872 .45132 .77608 .44788 Mtetra
.703 .252 0 r
.77608 .44788 .77872 .45132 .78579 .46219 .78319 .45935 Mtetra
.872 .452 .022 r
.78319 .45935 .78579 .46219 .79339 .47885 .79088 .47709 Mtetra
.776 .287 0 r
.79088 .47709 .79339 .47885 .80048 .48837 .79804 .48743 Mtetra
.844 .956 .885 r
.79804 .48743 .80048 .48837 .80637 .48314 .80395 .4822 Mtetra
.987 .83 .602 r
.80395 .4822 .80637 .48314 .81121 .46589 .80875 .46414 Mtetra
.98 .803 .593 r
.80875 .46414 .81121 .46589 .81587 .44708 .81334 .44427 Mtetra
.923 .817 .724 r
.81334 .44427 .81587 .44708 .82129 .43723 .81872 .43377 Mtetra
.168 .474 .894 r
.81872 .43377 .82129 .43723 .82789 .44018 .82533 .43681 Mtetra
.684 .235 0 r
.82533 .43681 .82789 .44018 .83529 .45131 .83279 .44862 Mtetra
.686 .21 0 r
.83279 .44862 .83529 .45131 .84262 .461 .8402 .45909 Mtetra
.313 .695 .979 r
.8402 .45909 .84262 .461 .84907 .46124 .84669 .45964 Mtetra
.954 .875 .72 r
.84669 .45964 .84907 .46124 .85448 .45092 .85209 .44898 Mtetra
.974 .826 .636 r
.85209 .44898 .85448 .45092 .85941 .43609 .85696 .43338 Mtetra
.94 .824 .702 r
.85696 .43338 .85941 .43609 .8647 .42512 .86221 .42176 Mtetra
.686 .761 .908 r
.86221 .42176 .8647 .42512 .87092 .42302 .86842 .41946 Mtetra
0 .234 .748 r
.86842 .41946 .87092 .42302 .87798 .42855 .87552 .42531 Mtetra
0 .054 .59 r
.87552 .42531 .87798 .42855 .88526 .43565 .88286 .43296 Mtetra
.145 .517 .915 r
.88286 .43296 .88526 .43565 .89203 .43778 .88968 .43547 Mtetra
.845 .874 .862 r
.88968 .43547 .89203 .43778 .89796 .43237 .89562 .42999 Mtetra
.943 .849 .72 r
.89562 .42999 .89796 .43237 .90334 .42213 .90096 .4193 Mtetra
.926 .834 .735 r
.90096 .4193 .90334 .42213 .90878 .41269 .90637 .40934 Mtetra
.79 .8 .86 r
.90637 .40934 .90878 .41269 .91484 .40847 .91241 .40486 Mtetra
.377 .593 .93 r
.91241 .40486 .91484 .40847 .92161 .40992 .91919 .4064 Mtetra
.082 .408 .86 r
.91919 .4064 .92161 .40992 .92868 .41366 .92631 .41046 Mtetra
.314 .586 .94 r
.92631 .41046 .92868 .41366 .93551 .41517 .93319 .41224 Mtetra
.731 .815 .916 r
.93319 .41224 .93551 .41517 .94177 .41203 .93946 .40913 Mtetra
.872 .844 .814 r
.93946 .40913 .94177 .41203 .94759 .40547 .94527 .40234 Mtetra
.623 .763 .946 r
.36709 .5767 .37032 .57923 .37555 .57805 .37232 .57552 Mtetra
.797 .785 .842 r
.37232 .57552 .37555 .57805 .38092 .57386 .37771 .57115 Mtetra
.824 .773 .805 r
.37771 .57115 .38092 .57386 .38634 .56845 .38315 .56553 Mtetra
.755 .762 .858 r
.38315 .56553 .38634 .56845 .39168 .56517 .3885 .56217 Mtetra
.301 .592 .946 r
.3885 .56217 .39168 .56517 .39685 .56629 .39367 .56347 Mtetra
.572 .052 0 r
.39367 .56347 .39685 .56629 .40191 .57105 .39872 .56859 Mtetra
.614 .079 0 r
.39872 .56859 .40191 .57105 .40701 .57575 .40381 .57364 Mtetra
.336 .686 .98 r
.40381 .57364 .40701 .57575 .41227 .57618 .40907 .57416 Mtetra
.845 .813 .819 r
.40907 .57416 .41227 .57618 .41775 .57062 .41457 .56836 Mtetra
.886 .78 .739 r
.41457 .56836 .41775 .57062 .42332 .56155 .42017 .55885 Mtetra
.857 .772 .767 r
.42017 .55885 .42332 .56155 .42883 .55429 .4257 .55127 Mtetra
.587 .72 .935 r
.4257 .55127 .42883 .55429 .43416 .55351 .43104 .55055 Mtetra
.721 .224 0 r
.43104 .55055 .43416 .55351 .43933 .5599 .43619 .55741 Mtetra
.872 .429 .082 r
.43619 .55741 .43933 .5599 .44446 .56919 .4413 .56732 Mtetra
.714 .185 0 r
.4413 .56732 .44446 .56919 .44972 .57448 .44655 .573 Mtetra
.79 .869 .907 r
.44655 .573 .44972 .57448 .4552 .57089 .45205 .56927 Mtetra
.919 .794 .707 r
.45205 .56927 .4552 .57089 .46083 .55932 .45771 .55712 Mtetra
.913 .77 .69 r
.45771 .55712 .46083 .55932 .46647 .54646 .46338 .5436 Mtetra
.835 .775 .795 r
.46338 .5436 .46647 .54646 .47197 .54048 .4689 .53739 Mtetra
.527 .026 0 r
.4689 .53739 .47197 .54048 .47731 .54562 .47423 .54293 Mtetra
.916 .517 .197 r
.47423 .54293 .47731 .54562 .48259 .55888 .47949 .55706 Mtetra
.906 .503 .217 r
.47949 .55706 .48259 .55888 .48793 .57134 .48482 .57032 Mtetra
.363 0 0 r
.48482 .57032 .48793 .57134 .49342 .57358 .49031 .57276 Mtetra
.937 .832 .715 r
.49031 .57276 .49342 .57358 .49904 .56251 .49596 .56111 Mtetra
.944 .773 .64 r
.49596 .56111 .49904 .56251 .50468 .54419 .50163 .54182 Mtetra
.92 .767 .676 r
.50163 .54182 .50468 .54419 .51026 .5301 .50724 .52703 Mtetra
.561 .711 .942 r
.50724 .52703 .51026 .5301 .51578 .52952 .51276 .52654 Mtetra
.914 .513 .167 r
.51276 .52654 .51578 .52952 .52129 .54332 .51826 .54125 Mtetra
.935 .573 .302 r
.51826 .54125 .52129 .54332 .52687 .56275 .52383 .5619 Mtetra
.887 .474 .217 r
.52383 .5619 .52687 .56275 .53252 .57429 .52948 .57418 Mtetra
.877 .954 .853 r
.52948 .57418 .53252 .57429 .53815 .56872 .53512 .56832 Mtetra
.964 .788 .617 r
.53512 .56832 .53815 .56872 .5437 .54824 .5407 .54672 Mtetra
.952 .762 .61 r
.5407 .54672 .5437 .54824 .54918 .52549 .5462 .52276 Mtetra
.9 .777 .717 r
.5462 .52276 .54918 .52549 .55471 .51496 .55174 .51178 Mtetra
.778 .31 0 r
.55174 .51178 .55471 .51496 .56042 .5236 .55746 .52105 Mtetra
.943 .587 .297 r
.55746 .52105 .56042 .5236 .56635 .54611 .56339 .54498 Mtetra
.931 .573 .32 r
.56339 .54498 .56635 .54611 .57236 .5675 .56941 .56769 Mtetra
.718 .202 0 r
.56941 .56769 .57236 .5675 .5782 .57232 .57527 .57282 Mtetra
.979 .836 .632 r
.57527 .57282 .5782 .57232 .58371 .55576 .58078 .55532 Mtetra
.97 .767 .575 r
.58078 .55532 .58371 .55576 .58895 .5277 .58603 .52571 Mtetra
.951 .762 .611 r
.58603 .52571 .58895 .5277 .59424 .50584 .59133 .50274 Mtetra
.679 .755 .908 r
.59133 .50274 .59424 .50584 .59993 .50379 .59702 .50074 Mtetra
.932 .552 .209 r
.59702 .50074 .59993 .50379 .60613 .52264 .60325 .52082 Mtetra
.945 .598 .322 r
.60325 .52082 .60613 .52264 .61264 .54992 .60978 .54977 Mtetra
.909 .526 .282 r
.60978 .54977 .61264 .54992 .61896 .56674 .61613 .56762 Mtetra
.873 .994 .79 r
.61613 .56762 .61896 .56674 .62468 .56034 .62186 .56088 Mtetra
.984 .789 .563 r
.62186 .56088 .62468 .56034 .62977 .53376 .62694 .53281 Mtetra
.971 .76 .562 r
.62694 .53281 .62977 .53376 .63466 .50372 .63181 .50114 Mtetra
.935 .777 .66 r
.63181 .50114 .63466 .50372 .63999 .48874 .63714 .48545 Mtetra
.712 .242 0 r
.63714 .48545 .63999 .48874 .64615 .49738 .64333 .49472 Mtetra
.946 .586 .269 r
.64333 .49472 .64615 .49738 .65302 .52323 .65024 .52217 Mtetra
.938 .578 .302 r
.65024 .52217 .65302 .52323 .65998 .54849 .65725 .54898 Mtetra
.774 .286 .069 r
.65725 .54898 .65998 .54849 .66626 .55501 .66355 .55596 Mtetra
.992 .848 .596 r
.66355 .55596 .66626 .55501 .67151 .53711 .6688 .5371 Mtetra
.983 .772 .54 r
.6688 .5371 .67151 .53711 .67611 .50585 .67336 .50412 Mtetra
.968 .766 .577 r
.67336 .50412 .67611 .50585 .68091 .48068 .67813 .4776 Mtetra
.8 .791 .844 r
.67813 .4776 .68091 .48068 .68665 .47618 .68387 .47293 Mtetra
.903 .5 .098 r
.68387 .47293 .68665 .47618 .6935 .49351 .69077 .49132 Mtetra
.943 .578 .256 r
.69077 .49132 .6935 .49351 .70092 .51996 .69826 .5194 Mtetra
.908 .506 .215 r
.69826 .5194 .70092 .51996 .70792 .53666 .70532 .53722 Mtetra
.815 1 .817 r
.70532 .53722 .70792 .53666 .71374 .5311 .71115 .53148 Mtetra
.992 .801 .548 r
.71115 .53148 .71374 .5311 .71844 .50609 .7158 .50515 Mtetra
.982 .771 .545 r
.7158 .50515 .71844 .50609 .72283 .4773 .72014 .4748 Mtetra
.95 .789 .646 r
.72014 .4748 .72283 .4773 .72796 .46185 .72524 .45849 Mtetra
0 .143 .666 r
.72524 .45849 .72796 .46185 .7344 .46736 .73169 .46431 Mtetra
.915 .522 .13 r
.73169 .46431 .7344 .46736 .74186 .48802 .73923 .4862 Mtetra
.921 .526 .179 r
.73923 .4862 .74186 .48802 .7494 .50841 .74686 .50791 Mtetra
.66 .105 0 r
.74686 .50791 .7494 .50841 .75597 .51342 .75347 .51345 Mtetra
.988 .869 .627 r
.75347 .51345 .75597 .51342 .76118 .49867 .75866 .49807 Mtetra
.989 .79 .545 r
.75866 .49807 .76118 .49867 .76557 .47328 .76299 .47135 Mtetra
.974 .786 .588 r
.76299 .47135 .76557 .47328 .77024 .45264 .7676 .44953 Mtetra
.814 .802 .84 r
.7676 .44953 .77024 .45264 .77608 .44788 .77342 .44443 Mtetra
.728 .28 0 r
.77342 .44443 .77608 .44788 .78319 .45935 .78059 .45652 Mtetra
.883 .469 .047 r
.78059 .45652 .78319 .45935 .79088 .47709 .78836 .47538 Mtetra
.8 .321 0 r
.78836 .47538 .79088 .47709 .79804 .48743 .79559 .48656 Mtetra
.843 .961 .884 r
.79559 .48656 .79804 .48743 .80395 .4822 .80152 .48132 Mtetra
.988 .826 .592 r
.80152 .48132 .80395 .4822 .80875 .46414 .80627 .46243 Mtetra
.981 .799 .584 r
.80627 .46243 .80875 .46414 .81334 .44427 .81079 .44148 Mtetra
.929 .815 .712 r
.81079 .44148 .81334 .44427 .81872 .43377 .81613 .4303 Mtetra
.155 .466 .89 r
.81613 .4303 .81872 .43377 .82533 .43681 .82275 .43343 Mtetra
.711 .265 0 r
.82275 .43343 .82533 .43681 .83279 .44862 .83029 .44594 Mtetra
.719 .248 0 r
.83029 .44594 .83279 .44862 .8402 .45909 .83777 .4572 Mtetra
.252 .66 .964 r
.83777 .4572 .8402 .45909 .84669 .45964 .84431 .45809 Mtetra
.958 .875 .712 r
.84431 .45809 .84669 .45964 .85209 .44898 .84969 .44707 Mtetra
.977 .823 .625 r
.84969 .44707 .85209 .44898 .85696 .43338 .85451 .4307 Mtetra
.946 .822 .691 r
.85451 .4307 .85696 .43338 .86221 .42176 .8597 .41838 Mtetra
.698 .766 .904 r
.8597 .41838 .86221 .42176 .86842 .41946 .8659 .41587 Mtetra
0 .205 .726 r
.8659 .41587 .86842 .41946 .87552 .42531 .87304 .42205 Mtetra
0 .01 .549 r
.87304 .42205 .87552 .42531 .88286 .43296 .88045 .43027 Mtetra
.086 .477 .893 r
.88045 .43027 .88286 .43296 .88968 .43547 .88733 .43317 Mtetra
.848 .876 .861 r
.88733 .43317 .88968 .43547 .89562 .42999 .89328 .42763 Mtetra
.948 .848 .711 r
.89328 .42763 .89562 .42999 .90096 .4193 .89858 .41649 Mtetra
.932 .833 .724 r
.89858 .41649 .90096 .4193 .90637 .40934 .90394 .406 Mtetra
.8 .803 .854 r
.90394 .406 .90637 .40934 .91241 .40486 .90996 .40123 Mtetra
.368 .588 .929 r
.90996 .40123 .91241 .40486 .91919 .4064 .91676 .40286 Mtetra
.044 .38 .844 r
.91676 .40286 .91919 .4064 .92631 .41046 .92393 .40725 Mtetra
.279 .564 .933 r
.92393 .40725 .92631 .41046 .93319 .41224 .93085 .40932 Mtetra
.729 .815 .918 r
.93085 .40932 .93319 .41224 .93946 .40913 .93715 .40624 Mtetra
.878 .846 .808 r
.93715 .40624 .93946 .40913 .94527 .40234 .94294 .39921 Mtetra
.623 .764 .947 r
.36385 .57418 .36709 .5767 .37232 .57552 .36909 .57299 Mtetra
.802 .785 .837 r
.36909 .57299 .37232 .57552 .37771 .57115 .37449 .56845 Mtetra
.828 .773 .8 r
.37449 .56845 .37771 .57115 .38315 .56553 .37995 .5626 Mtetra
.758 .763 .856 r
.37995 .5626 .38315 .56553 .3885 .56217 .38531 .55916 Mtetra
.264 .573 .939 r
.38531 .55916 .3885 .56217 .39367 .56347 .39048 .56063 Mtetra
.625 .108 0 r
.39048 .56063 .39367 .56347 .39872 .56859 .39552 .56614 Mtetra
.659 .13 0 r
.39552 .56614 .39872 .56859 .40381 .57364 .40059 .57155 Mtetra
.312 .675 .976 r
.40059 .57155 .40381 .57364 .40907 .57416 .40586 .57216 Mtetra
.85 .813 .813 r
.40586 .57216 .40907 .57416 .41457 .56836 .41137 .5661 Mtetra
.889 .779 .733 r
.41137 .5661 .41457 .56836 .42017 .55885 .41701 .55615 Mtetra
.861 .771 .761 r
.41701 .55615 .42017 .55885 .4257 .55127 .42256 .54824 Mtetra
.58 .717 .937 r
.42256 .54824 .4257 .55127 .43104 .55055 .4279 .54759 Mtetra
.757 .268 0 r
.4279 .54759 .43104 .55055 .43619 .55741 .43303 .55493 Mtetra
.883 .45 .115 r
.43303 .55493 .43619 .55741 .4413 .56732 .43813 .56548 Mtetra
.744 .225 0 r
.43813 .56548 .4413 .56732 .44655 .573 .44337 .57156 Mtetra
.797 .872 .903 r
.44337 .57156 .44655 .573 .45205 .56927 .44888 .56769 Mtetra
.922 .792 .7 r
.44888 .56769 .45205 .56927 .45771 .55712 .45458 .55492 Mtetra
.916 .768 .684 r
.45458 .55492 .45771 .55712 .46338 .5436 .46028 .54074 Mtetra
.839 .775 .79 r
.46028 .54074 .46338 .5436 .4689 .53739 .46581 .53429 Mtetra
.584 .083 0 r
.46581 .53429 .4689 .53739 .47423 .54293 .47114 .54025 Mtetra
.921 .53 .219 r
.47114 .54025 .47423 .54293 .47949 .55706 .47638 .55527 Mtetra
.911 .516 .238 r
.47638 .55527 .47949 .55706 .48482 .57032 .48169 .56936 Mtetra
.411 0 0 r
.48169 .56936 .48482 .57032 .49031 .57276 .48719 .57199 Mtetra
.94 .828 .706 r
.48719 .57199 .49031 .57276 .49596 .56111 .49286 .55974 Mtetra
.945 .77 .634 r
.49286 .55974 .49596 .56111 .50163 .54182 .49857 .53944 Mtetra
.922 .765 .67 r
.49857 .53944 .50163 .54182 .50724 .52703 .5042 .52395 Mtetra
.55 .707 .944 r
.5042 .52395 .50724 .52703 .51276 .52654 .50973 .52357 Mtetra
.921 .527 .192 r
.50973 .52357 .51276 .52654 .51826 .54125 .51522 .53923 Mtetra
.937 .581 .315 r
.51522 .53923 .51826 .54125 .52383 .5619 .52078 .56113 Mtetra
.892 .487 .237 r
.52078 .56113 .52383 .5619 .52948 .57418 .52642 .57415 Mtetra
.886 .954 .843 r
.52642 .57415 .52948 .57418 .53512 .56832 .53208 .56798 Mtetra
.965 .785 .611 r
.53208 .56798 .53512 .56832 .5407 .54672 .53768 .5452 Mtetra
.953 .759 .605 r
.53768 .5452 .5407 .54672 .5462 .52276 .54321 .52001 Mtetra
.902 .775 .711 r
.54321 .52001 .5462 .52276 .55174 .51178 .54876 .50858 Mtetra
.807 .347 0 r
.54876 .50858 .55174 .51178 .55746 .52105 .55449 .51854 Mtetra
.945 .594 .309 r
.55449 .51854 .55746 .52105 .56339 .54498 .56042 .54393 Mtetra
.933 .58 .331 r
.56042 .54393 .56339 .54498 .56941 .56769 .56645 .56799 Mtetra
.733 .226 .02 r
.56645 .56799 .56941 .56769 .57527 .57282 .57231 .57341 Mtetra
.98 .831 .624 r
.57231 .57341 .57527 .57282 .58078 .55532 .57784 .55492 Mtetra
.97 .764 .57 r
.57784 .55492 .58078 .55532 .58603 .52571 .5831 .52372 Mtetra
.952 .759 .605 r
.5831 .52372 .58603 .52571 .59133 .50274 .58841 .49962 Mtetra
.674 .753 .91 r
.58841 .49962 .59133 .50274 .59702 .50074 .59411 .4977 Mtetra
.936 .562 .227 r
.59411 .4977 .59702 .50074 .60325 .52082 .60035 .51905 Mtetra
.946 .603 .332 r
.60035 .51905 .60325 .52082 .60978 .54977 .60691 .54974 Mtetra
.912 .534 .295 r
.60691 .54974 .60978 .54977 .61613 .56762 .61329 .56863 Mtetra
.883 .992 .775 r
.61329 .56863 .61613 .56762 .62186 .56088 .61903 .5615 Mtetra
.984 .785 .557 r
.61903 .5615 .62186 .56088 .62694 .53281 .62409 .53187 Mtetra
.971 .758 .557 r
.62409 .53187 .62694 .53281 .63181 .50114 .62896 .49855 Mtetra
.937 .774 .654 r
.62896 .49855 .63181 .50114 .63714 .48545 .63428 .48215 Mtetra
.747 .283 0 r
.63428 .48215 .63714 .48545 .64333 .49472 .64049 .49209 Mtetra
.948 .593 .281 r
.64049 .49209 .64333 .49472 .65024 .52217 .64745 .52119 Mtetra
.939 .584 .312 r
.64745 .52119 .65024 .52217 .65725 .54898 .6545 .5496 Mtetra
.785 .308 .096 r
.6545 .5496 .65725 .54898 .66355 .55596 .66084 .55703 Mtetra
.993 .843 .587 r
.66084 .55703 .66355 .55596 .6688 .5371 .66607 .53715 Mtetra
.983 .768 .535 r
.66607 .53715 .6688 .5371 .67336 .50412 .6706 .5024 Mtetra
.969 .763 .571 r
.6706 .5024 .67336 .50412 .67813 .4776 .67533 .47451 Mtetra
.804 .791 .84 r
.67533 .47451 .67813 .4776 .68387 .47293 .68108 .46968 Mtetra
.911 .514 .121 r
.68108 .46968 .68387 .47293 .69077 .49132 .68803 .48918 Mtetra
.945 .585 .268 r
.68803 .48918 .69077 .49132 .69826 .5194 .69559 .51893 Mtetra
.912 .516 .231 r
.69559 .51893 .69826 .5194 .70532 .53722 .7027 .53788 Mtetra
.817 1 .804 r
.7027 .53788 .70532 .53722 .71115 .53148 .70855 .53196 Mtetra
.992 .797 .541 r
.70855 .53196 .71115 .53148 .7158 .50515 .71316 .50426 Mtetra
.982 .768 .539 r
.71316 .50426 .7158 .50515 .72014 .4748 .71744 .47229 Mtetra
.953 .786 .638 r
.71744 .47229 .72014 .4748 .72524 .45849 .72251 .45511 Mtetra
0 .107 .634 r
.72251 .45511 .72524 .45849 .73169 .46431 .72898 .46126 Mtetra
.921 .534 .148 r
.72898 .46126 .73169 .46431 .73923 .4862 .73659 .48442 Mtetra
.925 .537 .195 r
.73659 .48442 .73923 .4862 .74686 .50791 .7443 .5075 Mtetra
.694 .151 0 r
.7443 .5075 .74686 .50791 .75347 .51345 .75097 .51357 Mtetra
.99 .865 .617 r
.75097 .51357 .75347 .51345 .75866 .49807 .75613 .49753 Mtetra
.989 .786 .538 r
.75613 .49753 .75866 .49807 .76299 .47135 .7604 .46943 Mtetra
.976 .783 .58 r
.7604 .46943 .76299 .47135 .7676 .44953 .76495 .44642 Mtetra
.824 .803 .832 r
.76495 .44642 .7676 .44953 .77342 .44443 .77076 .44097 Mtetra
.751 .306 0 r
.77076 .44097 .77342 .44443 .78059 .45652 .77797 .4537 Mtetra
.893 .484 .07 r
.77797 .4537 .78059 .45652 .78836 .47538 .78583 .47371 Mtetra
.821 .35 0 r
.78583 .47371 .78836 .47538 .79559 .48656 .79314 .48575 Mtetra
.841 .965 .884 r
.79314 .48575 .79559 .48656 .80152 .48132 .79908 .4805 Mtetra
.99 .823 .584 r
.79908 .4805 .80152 .48132 .80627 .46243 .80379 .46076 Mtetra
.983 .795 .575 r
.80379 .46076 .80627 .46243 .81079 .44148 .80824 .43869 Mtetra
.935 .813 .7 r
.80824 .43869 .81079 .44148 .81613 .4303 .81353 .42682 Mtetra
.143 .458 .886 r
.81353 .42682 .81613 .4303 .82275 .43343 .82017 .43003 Mtetra
.736 .293 0 r
.82017 .43003 .82275 .43343 .83029 .44594 .82777 .44326 Mtetra
.748 .283 0 r
.82777 .44326 .83029 .44594 .83777 .4572 .83534 .45535 Mtetra
.187 .621 .944 r
.83534 .45535 .83777 .4572 .84431 .45809 .84192 .45658 Mtetra
.961 .874 .704 r
.84192 .45658 .84431 .45809 .84969 .44707 .84729 .4452 Mtetra
.979 .82 .615 r
.84729 .4452 .84969 .44707 .85451 .4307 .85205 .42804 Mtetra
.951 .82 .679 r
.85205 .42804 .85451 .4307 .8597 .41838 .85719 .41501 Mtetra
.71 .771 .9 r
.85719 .41501 .8597 .41838 .8659 .41587 .86337 .41227 Mtetra
0 .176 .703 r
.86337 .41227 .8659 .41587 .87304 .42205 .87055 .41877 Mtetra
0 0 .507 r
.87055 .41877 .87304 .42205 .88045 .43027 .87803 .42759 Mtetra
.024 .434 .867 r
.87803 .42759 .88045 .43027 .88733 .43317 .88496 .43089 Mtetra
.849 .878 .861 r
.88496 .43089 .88733 .43317 .89328 .42763 .89092 .4253 Mtetra
.952 .847 .702 r
.89092 .4253 .89328 .42763 .89858 .41649 .89619 .4137 Mtetra
.938 .832 .713 r
.89619 .4137 .89858 .41649 .90394 .406 .90151 .40266 Mtetra
.811 .807 .847 r
.90151 .40266 .90394 .406 .90996 .40123 .9075 .39759 Mtetra
.358 .582 .928 r
.9075 .39759 .90996 .40123 .91676 .40286 .91432 .3993 Mtetra
.005 .351 .827 r
.91432 .3993 .91676 .40286 .92393 .40725 .92154 .40402 Mtetra
.242 .54 .925 r
.92154 .40402 .92393 .40725 .93085 .40932 .92851 .4064 Mtetra
.726 .815 .92 r
.92851 .4064 .93085 .40932 .93715 .40624 .93482 .40336 Mtetra
.884 .847 .802 r
.93482 .40336 .93715 .40624 .94294 .39921 .9406 .39609 Mtetra
.623 .765 .948 r
.36059 .57166 .36385 .57418 .36909 .57299 .36584 .57046 Mtetra
.807 .786 .833 r
.36584 .57046 .36909 .57299 .37449 .56845 .37126 .56574 Mtetra
.832 .772 .795 r
.37126 .56574 .37449 .56845 .37995 .5626 .37674 .55966 Mtetra
.761 .763 .854 r
.37674 .55966 .37995 .5626 .38531 .55916 .38211 .55614 Mtetra
.225 .551 .931 r
.38211 .55614 .38531 .55916 .39048 .56063 .38728 .5578 Mtetra
.671 .159 0 r
.38728 .5578 .39048 .56063 .39552 .56614 .3923 .56369 Mtetra
.698 .176 0 r
.3923 .56369 .39552 .56614 .40059 .57155 .39736 .56947 Mtetra
.286 .663 .971 r
.39736 .56947 .40059 .57155 .40586 .57216 .40263 .57018 Mtetra
.855 .813 .807 r
.40263 .57018 .40586 .57216 .41137 .5661 .40816 .56385 Mtetra
.893 .777 .727 r
.40816 .56385 .41137 .5661 .41701 .55615 .41383 .55344 Mtetra
.865 .77 .756 r
.41383 .55344 .41701 .55615 .42256 .54824 .41941 .5452 Mtetra
.572 .715 .939 r
.41941 .5452 .42256 .54824 .4279 .54759 .42475 .54462 Mtetra
.787 .307 0 r
.42475 .54462 .4279 .54759 .43303 .55493 .42987 .55245 Mtetra
.893 .469 .144 r
.42987 .55245 .43303 .55493 .43813 .56548 .43494 .56367 Mtetra
.769 .26 0 r
.43494 .56367 .43813 .56548 .44337 .57156 .44018 .57015 Mtetra
.804 .874 .898 r
.44018 .57015 .44337 .57156 .44888 .56769 .4457 .56612 Mtetra
.924 .789 .693 r
.4457 .56612 .44888 .56769 .45458 .55492 .45143 .55272 Mtetra
.918 .766 .678 r
.45143 .55272 .45458 .55492 .46028 .54074 .45716 .53787 Mtetra
.843 .774 .785 r
.45716 .53787 .46028 .54074 .46581 .53429 .46271 .53118 Mtetra
.636 .136 0 r
.46271 .53118 .46581 .53429 .47114 .54025 .46803 .53758 Mtetra
.926 .542 .239 r
.46803 .53758 .47114 .54025 .47638 .55527 .47325 .55352 Mtetra
.915 .527 .256 r
.47325 .55352 .47638 .55527 .48169 .56936 .47854 .56845 Mtetra
.453 0 0 r
.47854 .56845 .48169 .56936 .48719 .57199 .48405 .57127 Mtetra
.943 .825 .698 r
.48405 .57127 .48719 .57199 .49286 .55974 .48975 .55838 Mtetra
.946 .767 .629 r
.48975 .55838 .49286 .55974 .49857 .53944 .49549 .53706 Mtetra
.924 .763 .664 r
.49549 .53706 .49857 .53944 .5042 .52395 .50115 .52085 Mtetra
.536 .701 .946 r
.50115 .52085 .5042 .52395 .50973 .52357 .50668 .52059 Mtetra
.927 .54 .213 r
.50668 .52059 .50973 .52357 .51522 .53923 .51216 .53724 Mtetra
.938 .587 .326 r
.51216 .53724 .51522 .53923 .52078 .56113 .51771 .56043 Mtetra
.896 .498 .253 r
.51771 .56043 .52078 .56113 .52642 .57415 .52335 .5742 Mtetra
.896 .953 .832 r
.52335 .5742 .52642 .57415 .53208 .56798 .52903 .56769 Mtetra
.965 .782 .605 r
.52903 .56769 .53208 .56798 .53768 .5452 .53465 .54369 Mtetra
.953 .757 .6 r
.53465 .54369 .53768 .5452 .54321 .52001 .5402 .51724 Mtetra
.905 .773 .705 r
.5402 .51724 .54321 .52001 .54876 .50858 .54577 .50537 Mtetra
.832 .38 0 r
.54577 .50537 .54876 .50858 .55449 .51854 .5515 .51605 Mtetra
.947 .6 .321 r
.5515 .51605 .55449 .51854 .56042 .54393 .55744 .54296 Mtetra
.934 .585 .34 r
.55744 .54296 .56042 .54393 .56645 .56799 .56347 .56838 Mtetra
.744 .246 .047 r
.56347 .56838 .56645 .56799 .57231 .57341 .56934 .57408 Mtetra
.981 .826 .616 r
.56934 .57408 .57231 .57341 .57784 .55492 .57488 .55455 Mtetra
.97 .761 .565 r
.57488 .55455 .57784 .55492 .5831 .52372 .58016 .52171 Mtetra
.953 .757 .6 r
.58016 .52171 .5831 .52372 .58841 .49962 .58547 .49648 Mtetra
.666 .75 .913 r
.58547 .49648 .58841 .49962 .59411 .4977 .59118 .49466 Mtetra
.94 .572 .244 r
.59118 .49466 .59411 .4977 .60035 .51905 .59744 .51735 Mtetra
.947 .608 .34 r
.59744 .51735 .60035 .51905 .60691 .54974 .60403 .54981 Mtetra
.914 .542 .306 r
.60403 .54981 .60691 .54974 .61329 .56863 .61043 .56975 Mtetra
.894 .989 .761 r
.61043 .56975 .61329 .56863 .61903 .5615 .61617 .56219 Mtetra
.984 .781 .552 r
.61617 .56219 .61903 .5615 .62409 .53187 .62123 .53094 Mtetra
.971 .755 .553 r
.62123 .53094 .62409 .53187 .62896 .49855 .62608 .49592 Mtetra
.939 .772 .648 r
.62608 .49592 .62896 .49855 .63428 .48215 .63141 .47883 Mtetra
.778 .32 0 r
.63141 .47883 .63428 .48215 .64049 .49209 .63764 .48949 Mtetra
.95 .599 .292 r
.63764 .48949 .64049 .49209 .64745 .52119 .64464 .5203 Mtetra
.941 .59 .321 r
.64464 .5203 .64745 .52119 .6545 .5496 .65175 .55034 Mtetra
.795 .326 .12 r
.65175 .55034 .6545 .5496 .66084 .55703 .65811 .5582 Mtetra
.994 .837 .579 r
.65811 .5582 .66084 .55703 .66607 .53715 .66333 .53724 Mtetra
.983 .765 .53 r
.66333 .53724 .66607 .53715 .6706 .5024 .66782 .50066 Mtetra
.97 .76 .566 r
.66782 .50066 .6706 .5024 .67533 .47451 .67252 .47139 Mtetra
.808 .791 .837 r
.67252 .47139 .67533 .47451 .68108 .46968 .67828 .46643 Mtetra
.918 .527 .142 r
.67828 .46643 .68108 .46968 .68803 .48918 .68527 .48709 Mtetra
.947 .591 .279 r
.68527 .48709 .68803 .48918 .69559 .51893 .6929 .51856 Mtetra
.916 .526 .245 r
.6929 .51856 .69559 .51893 .7027 .53788 .70008 .53866 Mtetra
.821 .999 .791 r
.70008 .53866 .7027 .53788 .70855 .53196 .70593 .53251 Mtetra
.992 .793 .535 r
.70593 .53251 .70855 .53196 .71316 .50426 .7105 .50339 Mtetra
.982 .765 .533 r
.7105 .50339 .71316 .50426 .71744 .47229 .71472 .46977 Mtetra
.955 .783 .63 r
.71472 .46977 .71744 .47229 .72251 .45511 .71976 .45172 Mtetra
0 .069 .599 r
.71976 .45172 .72251 .45511 .72898 .46126 .72627 .45823 Mtetra
.927 .544 .165 r
.72627 .45823 .72898 .46126 .73659 .48442 .73395 .48269 Mtetra
.929 .546 .21 r
.73395 .48269 .73659 .48442 .7443 .5075 .74174 .50717 Mtetra
.722 .191 0 r
.74174 .50717 .7443 .5075 .75097 .51357 .74845 .51377 Mtetra
.991 .861 .608 r
.74845 .51377 .75097 .51357 .75613 .49753 .7536 .49704 Mtetra
.99 .782 .531 r
.7536 .49704 .75613 .49753 .7604 .46943 .7578 .46753 Mtetra
.977 .78 .572 r
.7578 .46753 .7604 .46943 .76495 .44642 .76229 .44329 Mtetra
.833 .804 .823 r
.76229 .44329 .76495 .44642 .77076 .44097 .76808 .4375 Mtetra
.771 .33 0 r
.76808 .4375 .77076 .44097 .77797 .4537 .77534 .45088 Mtetra
.901 .498 .09 r
.77534 .45088 .77797 .4537 .78583 .47371 .78329 .47207 Mtetra
.837 .376 0 r
.78329 .47207 .78583 .47371 .79314 .48575 .79067 .485 Mtetra
.84 .968 .883 r
.79067 .485 .79314 .48575 .79908 .4805 .79663 .47974 Mtetra
.991 .819 .576 r
.79663 .47974 .79908 .4805 .80379 .46076 .80129 .45912 Mtetra
.984 .792 .566 r
.80129 .45912 .80379 .46076 .80824 .43869 .80568 .43591 Mtetra
.94 .811 .689 r
.80568 .43591 .80824 .43869 .81353 .42682 .81093 .42333 Mtetra
.131 .45 .883 r
.81093 .42333 .81353 .42682 .82017 .43003 .81758 .42662 Mtetra
.758 .318 0 r
.81758 .42662 .82017 .43003 .82777 .44326 .82524 .44059 Mtetra
.772 .313 0 r
.82524 .44059 .82777 .44326 .83534 .45535 .83289 .45351 Mtetra
.119 .576 .919 r
.83289 .45351 .83534 .45535 .84192 .45658 .83952 .4551 Mtetra
.964 .872 .697 r
.83952 .4551 .84192 .45658 .84729 .4452 .84487 .44337 Mtetra
.981 .817 .606 r
.84487 .44337 .84729 .4452 .85205 .42804 .84958 .4254 Mtetra
.955 .817 .668 r
.84958 .4254 .85205 .42804 .85719 .41501 .85466 .41163 Mtetra
.722 .776 .895 r
.85466 .41163 .85719 .41501 .86337 .41227 .86083 .40866 Mtetra
0 .148 .68 r
.86083 .40866 .86337 .41227 .87055 .41877 .86805 .41548 Mtetra
0 0 .467 r
.86805 .41548 .87055 .41877 .87803 .42759 .8756 .4249 Mtetra
0 .388 .837 r
.8756 .4249 .87803 .42759 .88496 .43089 .88259 .42863 Mtetra
.851 .88 .86 r
.88259 .42863 .88496 .43089 .89092 .4253 .88856 .423 Mtetra
.956 .846 .693 r
.88856 .423 .89092 .4253 .89619 .4137 .8938 .41093 Mtetra
.944 .83 .702 r
.8938 .41093 .89619 .4137 .90151 .40266 .89906 .39932 Mtetra
.821 .81 .84 r
.89906 .39932 .90151 .40266 .9075 .39759 .90504 .39393 Mtetra
.35 .577 .927 r
.90504 .39393 .9075 .39759 .91432 .3993 .91187 .39572 Mtetra
0 .322 .809 r
.91187 .39572 .91432 .3993 .92154 .40402 .91914 .40079 Mtetra
.203 .515 .914 r
.91914 .40079 .92154 .40402 .92851 .4064 .92616 .40348 Mtetra
.723 .815 .922 r
.92616 .40348 .92851 .4064 .93482 .40336 .93249 .40049 Mtetra
.889 .848 .797 r
.93249 .40049 .93482 .40336 .9406 .39609 .93825 .39297 Mtetra
.622 .766 .948 r
.35732 .56914 .36059 .57166 .36584 .57046 .36258 .56794 Mtetra
.812 .786 .828 r
.36258 .56794 .36584 .57046 .37126 .56574 .36802 .56303 Mtetra
.836 .772 .79 r
.36802 .56303 .37126 .56574 .37674 .55966 .37352 .55671 Mtetra
.764 .763 .852 r
.37352 .55671 .37674 .55966 .38211 .55614 .3789 .5531 Mtetra
.183 .526 .921 r
.3789 .5531 .38211 .55614 .38728 .5578 .38406 .55495 Mtetra
.711 .205 0 r
.38406 .55495 .38728 .5578 .3923 .56369 .38907 .56125 Mtetra
.731 .217 0 r
.38907 .56125 .3923 .56369 .39736 .56947 .39411 .5674 Mtetra
.259 .65 .965 r
.39411 .5674 .39736 .56947 .40263 .57018 .39939 .56821 Mtetra
.86 .812 .801 r
.39939 .56821 .40263 .57018 .40816 .56385 .40494 .56161 Mtetra
.896 .776 .721 r
.40494 .56161 .40816 .56385 .41383 .55344 .41064 .55072 Mtetra
.868 .769 .751 r
.41064 .55072 .41383 .55344 .41941 .5452 .41624 .54215 Mtetra
.564 .712 .94 r
.41624 .54215 .41941 .5452 .42475 .54462 .42159 .54164 Mtetra
.813 .341 0 r
.42159 .54164 .42475 .54462 .42987 .55245 .42669 .54998 Mtetra
.901 .486 .17 r
.42669 .54998 .42987 .55245 .43494 .56367 .43174 .56188 Mtetra
.79 .292 0 r
.43174 .56188 .43494 .56367 .44018 .57015 .43697 .56876 Mtetra
.811 .875 .894 r
.43697 .56876 .44018 .57015 .4457 .56612 .4425 .56458 Mtetra
.926 .787 .687 r
.4425 .56458 .4457 .56612 .45143 .55272 .44827 .55053 Mtetra
.92 .764 .672 r
.44827 .55053 .45143 .55272 .45716 .53787 .45404 .53498 Mtetra
.847 .774 .78 r
.45404 .53498 .45716 .53787 .46271 .53118 .4596 .52806 Mtetra
.681 .186 0 r
.4596 .52806 .46271 .53118 .46803 .53758 .46492 .53491 Mtetra
.93 .553 .257 r
.46492 .53491 .46803 .53758 .47325 .55352 .47011 .5518 Mtetra
.918 .537 .272 r
.47011 .5518 .47325 .55352 .47854 .56845 .47538 .56759 Mtetra
.49 0 0 r
.47538 .56759 .47854 .56845 .48405 .57127 .4809 .57059 Mtetra
.946 .822 .69 r
.4809 .57059 .48405 .57127 .48975 .55838 .48662 .55705 Mtetra
.947 .765 .623 r
.48662 .55705 .48975 .55838 .49549 .53706 .49241 .53466 Mtetra
.926 .761 .658 r
.49241 .53466 .49549 .53706 .50115 .52085 .49809 .51773 Mtetra
.519 .693 .948 r
.49809 .51773 .50115 .52085 .50668 .52059 .50362 .51762 Mtetra
.931 .552 .233 r
.50362 .51762 .50668 .52059 .51216 .53724 .50909 .53529 Mtetra
.94 .593 .337 r
.50909 .53529 .51216 .53724 .51771 .56043 .51462 .5598 Mtetra
.9 .508 .268 r
.51462 .5598 .51771 .56043 .52335 .5742 .52026 .57432 Mtetra
.905 .95 .82 r
.52026 .57432 .52335 .5742 .52903 .56769 .52595 .56744 Mtetra
.966 .778 .599 r
.52595 .56744 .52903 .56769 .53465 .54369 .53161 .54218 Mtetra
.954 .754 .595 r
.53161 .54218 .53465 .54369 .5402 .51724 .53719 .51445 Mtetra
.907 .771 .7 r
.53719 .51445 .5402 .51724 .54577 .50537 .54277 .50215 Mtetra
.852 .41 0 r
.54277 .50215 .54577 .50537 .5515 .51605 .5485 .51359 Mtetra
.948 .605 .331 r
.5485 .51359 .5515 .51605 .55744 .54296 .55444 .54206 Mtetra
.935 .591 .349 r
.55444 .54206 .55744 .54296 .56347 .56838 .56047 .56888 Mtetra
.754 .264 .069 r
.56047 .56888 .56347 .56838 .56934 .57408 .56636 .57484 Mtetra
.982 .821 .608 r
.56636 .57484 .56934 .57408 .57488 .55455 .57191 .55421 Mtetra
.97 .758 .561 r
.57191 .55421 .57488 .55455 .58016 .52171 .5772 .51968 Mtetra
.954 .754 .595 r
.5772 .51968 .58016 .52171 .58547 .49648 .58252 .49331 Mtetra
.656 .746 .916 r
.58252 .49331 .58547 .49648 .59118 .49466 .58825 .49164 Mtetra
.943 .58 .26 r
.58825 .49164 .59118 .49466 .59744 .51735 .59452 .5157 Mtetra
.948 .612 .348 r
.59452 .5157 .59744 .51735 .60403 .54981 .60113 .54998 Mtetra
.916 .548 .316 r
.60113 .54998 .60403 .54981 .61043 .56975 .60755 .57098 Mtetra
.905 .984 .746 r
.60755 .57098 .61043 .56975 .61617 .56219 .61331 .56294 Mtetra
.984 .777 .547 r
.61331 .56294 .61617 .56219 .62123 .53094 .61836 .53002 Mtetra
.971 .752 .548 r
.61836 .53002 .62123 .53094 .62608 .49592 .6232 .49327 Mtetra
.94 .77 .642 r
.6232 .49327 .62608 .49592 .63141 .47883 .62853 .4755 Mtetra
.805 .354 0 r
.62853 .4755 .63141 .47883 .63764 .48949 .63478 .48692 Mtetra
.951 .604 .302 r
.63478 .48692 .63764 .48949 .64464 .5203 .64183 .51949 Mtetra
.942 .595 .329 r
.64183 .51949 .64464 .5203 .65175 .55034 .64898 .55119 Mtetra
.803 .342 .14 r
.64898 .55119 .65175 .55034 .65811 .5582 .65537 .55947 Mtetra
.994 .832 .571 r
.65537 .55947 .65811 .5582 .66333 .53724 .66057 .53737 Mtetra
.983 .762 .526 r
.66057 .53737 .66333 .53724 .66782 .50066 .66503 .49892 Mtetra
.97 .758 .561 r
.66503 .49892 .66782 .50066 .67252 .47139 .66971 .46825 Mtetra
.81 .79 .834 r
.66971 .46825 .67252 .47139 .67828 .46643 .67546 .46319 Mtetra
.924 .538 .161 r
.67546 .46319 .67828 .46643 .68527 .48709 .68251 .48505 Mtetra
.949 .596 .288 r
.68251 .48505 .68527 .48709 .6929 .51856 .69021 .51828 Mtetra
.919 .534 .258 r
.69021 .51828 .6929 .51856 .70008 .53866 .69744 .53953 Mtetra
.828 .998 .779 r
.69744 .53953 .70008 .53866 .70593 .53251 .7033 .53313 Mtetra
.992 .789 .529 r
.7033 .53313 .70593 .53251 .7105 .50339 .70783 .50254 Mtetra
.982 .762 .528 r
.70783 .50254 .7105 .50339 .71472 .46977 .71199 .46724 Mtetra
.957 .78 .623 r
.71199 .46724 .71472 .46977 .71976 .45172 .71701 .44831 Mtetra
0 .03 .563 r
.71701 .44831 .71976 .45172 .72627 .45823 .72354 .4552 Mtetra
.931 .553 .18 r
.72354 .4552 .72627 .45823 .73395 .48269 .73129 .481 Mtetra
.933 .554 .223 r
.73129 .481 .73395 .48269 .74174 .50717 .73917 .5069 Mtetra
.745 .225 0 r
.73917 .5069 .74174 .50717 .74845 .51377 .74592 .51404 Mtetra
.992 .857 .6 r
.74592 .51404 .74845 .51377 .7536 .49704 .75105 .4966 Mtetra
.99 .779 .525 r
.75105 .4966 .7536 .49704 .7578 .46753 .75518 .46564 Mtetra
.978 .776 .565 r
.75518 .46564 .7578 .46753 .76229 .44329 .75961 .44016 Mtetra
.842 .805 .815 r
.75961 .44016 .76229 .44329 .76808 .4375 .7654 .43402 Mtetra
.789 .353 0 r
.7654 .43402 .76808 .4375 .77534 .45088 .77271 .44808 Mtetra
.908 .51 .109 r
.77271 .44808 .77534 .45088 .78329 .47207 .78074 .47046 Mtetra
.852 .399 .011 r
.78074 .47046 .78329 .47207 .79067 .485 .7882 .4843 Mtetra
.838 .972 .883 r
.7882 .4843 .79067 .485 .79663 .47974 .79417 .47902 Mtetra
.992 .816 .568 r
.79417 .47902 .79663 .47974 .80129 .45912 .79879 .45751 Mtetra
.985 .788 .558 r
.79879 .45751 .80129 .45912 .80568 .43591 .8031 .43313 Mtetra
.945 .808 .678 r
.8031 .43313 .80568 .43591 .81093 .42333 .80831 .41983 Mtetra
.119 .442 .879 r
.80831 .41983 .81093 .42333 .81758 .42662 .81497 .42321 Mtetra
.777 .341 0 r
.81497 .42321 .81758 .42662 .82524 .44059 .82271 .43792 Mtetra
.793 .34 0 r
.82271 .43792 .82524 .44059 .83289 .45351 .83044 .4517 Mtetra
.048 .528 .888 r
.83044 .4517 .83289 .45351 .83952 .4551 .83711 .45366 Mtetra
.967 .871 .69 r
.83711 .45366 .83952 .4551 .84487 .44337 .84245 .44157 Mtetra
.983 .814 .597 r
.84245 .44157 .84487 .44337 .84958 .4254 .8471 .42277 Mtetra
.959 .814 .657 r
.8471 .42277 .84958 .4254 .85466 .41163 .85213 .40825 Mtetra
.735 .78 .89 r
.85213 .40825 .85466 .41163 .86083 .40866 .85829 .40503 Mtetra
0 .12 .657 r
.85829 .40503 .86083 .40866 .86805 .41548 .86555 .41218 Mtetra
0 0 .428 r
.86555 .41218 .86805 .41548 .8756 .4249 .87316 .42221 Mtetra
0 .339 .804 r
.87316 .42221 .8756 .4249 .88259 .42863 .88021 .42638 Mtetra
.852 .882 .86 r
.88021 .42638 .88259 .42863 .88856 .423 .88619 .42071 Mtetra
.96 .844 .684 r
.88619 .42071 .88856 .423 .8938 .41093 .8914 .40817 Mtetra
.949 .829 .692 r
.8914 .40817 .8938 .41093 .89906 .39932 .89661 .39599 Mtetra
.831 .812 .832 r
.89661 .39599 .89906 .39932 .90504 .39393 .90256 .39027 Mtetra
.342 .572 .925 r
.90256 .39027 .90504 .39393 .91187 .39572 .90942 .39212 Mtetra
0 .292 .789 r
.90942 .39212 .91187 .39572 .91914 .40079 .91673 .39754 Mtetra
.163 .488 .902 r
.91673 .39754 .91914 .40079 .92616 .40348 .9238 .40056 Mtetra
.72 .814 .924 r
.9238 .40056 .92616 .40348 .93249 .40049 .93015 .39762 Mtetra
.894 .848 .791 r
.93015 .39762 .93249 .40049 .93825 .39297 .9359 .38987 Mtetra
.622 .766 .949 r
.35404 .56662 .35732 .56914 .36258 .56794 .3593 .56541 Mtetra
.816 .785 .824 r
.3593 .56541 .36258 .56794 .36802 .56303 .36476 .56031 Mtetra
.84 .771 .786 r
.36476 .56031 .36802 .56303 .37352 .55671 .37029 .55375 Mtetra
.767 .764 .85 r
.37029 .55375 .37352 .55671 .3789 .5531 .37568 .55006 Mtetra
.139 .5 .908 r
.37568 .55006 .3789 .5531 .38406 .55495 .38084 .5521 Mtetra
.745 .246 0 r
.38084 .5521 .38406 .55495 .38907 .56125 .38582 .55881 Mtetra
.759 .254 0 r
.38582 .55881 .38907 .56125 .39411 .5674 .39085 .56535 Mtetra
.232 .636 .958 r
.39085 .56535 .39411 .5674 .39939 .56821 .39613 .56625 Mtetra
.865 .811 .795 r
.39613 .56625 .39939 .56821 .40494 .56161 .40171 .55937 Mtetra
.899 .774 .715 r
.40171 .55937 .40494 .56161 .41064 .55072 .40744 .548 Mtetra
.872 .768 .745 r
.40744 .548 .41064 .55072 .41624 .54215 .41307 .53909 Mtetra
.556 .709 .942 r
.41307 .53909 .41624 .54215 .42159 .54164 .41841 .53865 Mtetra
.834 .372 0 r
.41841 .53865 .42159 .54164 .42669 .54998 .4235 .54752 Mtetra
.907 .501 .193 r
.4235 .54752 .42669 .54998 .43174 .56188 .42852 .5601 Mtetra
.808 .32 0 r
.42852 .5601 .43174 .56188 .43697 .56876 .43374 .5674 Mtetra
.817 .876 .888 r
.43374 .5674 .43697 .56876 .4425 .56458 .43929 .56305 Mtetra
.928 .784 .68 r
.43929 .56305 .4425 .56458 .44827 .55053 .44509 .54834 Mtetra
.922 .762 .666 r
.44509 .54834 .44827 .55053 .45404 .53498 .4509 .53208 Mtetra
.85 .773 .776 r
.4509 .53208 .45404 .53498 .4596 .52806 .45648 .52493 Mtetra
.721 .231 0 r
.45648 .52493 .4596 .52806 .46492 .53491 .46179 .53226 Mtetra
.933 .562 .273 r
.46179 .53226 .46492 .53491 .47011 .5518 .46695 .55011 Mtetra
.921 .546 .286 r
.46695 .55011 .47011 .5518 .47538 .56759 .47221 .56677 Mtetra
.521 0 0 r
.47221 .56677 .47538 .56759 .4809 .57059 .47772 .56995 Mtetra
.948 .818 .683 r
.47772 .56995 .4809 .57059 .48662 .55705 .48348 .55572 Mtetra
.948 .762 .618 r
.48348 .55572 .48662 .55705 .49241 .53466 .4893 .53225 Mtetra
.927 .759 .653 r
.4893 .53225 .49241 .53466 .49809 .51773 .49502 .51459 Mtetra
.499 .685 .95 r
.49502 .51459 .49809 .51773 .50362 .51762 .50056 .51465 Mtetra
.935 .562 .251 r
.50056 .51465 .50362 .51762 .50909 .53529 .50601 .53337 Mtetra
.941 .598 .346 r
.50601 .53337 .50909 .53529 .51462 .5598 .51152 .55922 Mtetra
.903 .517 .281 r
.51152 .55922 .51462 .5598 .52026 .57432 .51715 .5745 Mtetra
.914 .946 .808 r
.51715 .5745 .52026 .57432 .52595 .56744 .52286 .56722 Mtetra
.966 .775 .594 r
.52286 .56722 .52595 .56744 .53161 .54218 .52855 .54066 Mtetra
.954 .752 .591 r
.52855 .54066 .53161 .54218 .53719 .51445 .53416 .51163 Mtetra
.909 .77 .696 r
.53416 .51163 .53719 .51445 .54277 .50215 .53976 .49892 Mtetra
.87 .436 .03 r
.53976 .49892 .54277 .50215 .5485 .51359 .54549 .51116 Mtetra
.949 .61 .34 r
.54549 .51116 .5485 .51359 .55444 .54206 .55142 .54123 Mtetra
.936 .595 .357 r
.55142 .54123 .55444 .54206 .56047 .56888 .55745 .56946 Mtetra
.761 .278 .088 r
.55745 .56946 .56047 .56888 .56636 .57484 .56335 .57565 Mtetra
.982 .816 .601 r
.56335 .57565 .56636 .57484 .57191 .55421 .56892 .55388 Mtetra
.97 .755 .557 r
.56892 .55388 .57191 .55421 .5772 .51968 .57422 .51763 Mtetra
.954 .752 .591 r
.57422 .51763 .5772 .51968 .58252 .49331 .57956 .49011 Mtetra
.643 .741 .92 r
.57956 .49011 .58252 .49331 .58825 .49164 .5853 .48862 Mtetra
.946 .588 .273 r
.5853 .48862 .58825 .49164 .59452 .5157 .59159 .51412 Mtetra
.949 .616 .355 r
.59159 .51412 .59452 .5157 .60113 .54998 .59822 .55026 Mtetra
.918 .554 .324 r
.59822 .55026 .60113 .54998 .60755 .57098 .60466 .5723 Mtetra
.917 .979 .732 r
.60466 .5723 .60755 .57098 .61331 .56294 .61042 .56374 Mtetra
.983 .773 .542 r
.61042 .56374 .61331 .56294 .61836 .53002 .61547 .52908 Mtetra
.971 .749 .545 r
.61547 .52908 .61836 .53002 .6232 .49327 .6203 .49059 Mtetra
.941 .767 .637 r
.6203 .49059 .6232 .49327 .62853 .4755 .62563 .47216 Mtetra
.828 .385 0 r
.62563 .47216 .62853 .4755 .63478 .48692 .63191 .48438 Mtetra
.953 .609 .311 r
.63191 .48438 .63478 .48692 .64183 .51949 .639 .51877 Mtetra
.943 .599 .337 r
.639 .51877 .64183 .51949 .64898 .55119 .6462 .55215 Mtetra
.809 .355 .156 r
.6462 .55215 .64898 .55119 .65537 .55947 .65261 .56081 Mtetra
.995 .826 .564 r
.65261 .56081 .65537 .55947 .66057 .53737 .6578 .53752 Mtetra
.983 .759 .522 r
.6578 .53752 .66057 .53737 .66503 .49892 .66222 .49715 Mtetra
.97 .755 .556 r
.66222 .49715 .66503 .49892 .66971 .46825 .66687 .46508 Mtetra
.812 .79 .832 r
.66687 .46508 .66971 .46825 .67546 .46319 .67264 .45994 Mtetra
.93 .549 .178 r
.67264 .45994 .67546 .46319 .68251 .48505 .67973 .48305 Mtetra
.95 .601 .297 r
.67973 .48305 .68251 .48505 .69021 .51828 .68751 .51807 Mtetra
.922 .542 .269 r
.68751 .51807 .69021 .51828 .69744 .53953 .6948 .54049 Mtetra
.837 .997 .767 r
.6948 .54049 .69744 .53953 .7033 .53313 .70066 .53381 Mtetra
.992 .785 .524 r
.70066 .53381 .7033 .53313 .70783 .50254 .70514 .5017 Mtetra
.982 .759 .523 r
.70514 .5017 .70783 .50254 .71199 .46724 .70925 .46468 Mtetra
.958 .777 .616 r
.70925 .46468 .71199 .46724 .71701 .44831 .71424 .44488 Mtetra
0 0 .524 r
.71424 .44488 .71701 .44831 .72354 .4552 .7208 .45218 Mtetra
.935 .561 .194 r
.7208 .45218 .72354 .4552 .73129 .481 .72862 .47936 Mtetra
.936 .562 .235 r
.72862 .47936 .73129 .481 .73917 .5069 .73659 .50671 Mtetra
.765 .254 0 r
.73659 .50671 .73917 .5069 .74592 .51404 .74338 .51437 Mtetra
.993 .853 .592 r
.74338 .51437 .74592 .51404 .75105 .4966 .74849 .49619 Mtetra
.99 .775 .52 r
.74849 .49619 .75105 .4966 .75518 .46564 .75256 .46375 Mtetra
.978 .773 .558 r
.75256 .46375 .75518 .46564 .75961 .44016 .75693 .43701 Mtetra
.85 .805 .807 r
.75693 .43701 .75961 .44016 .7654 .43402 .7627 .43054 Mtetra
.806 .373 0 r
.7627 .43054 .7654 .43402 .77271 .44808 .77006 .44528 Mtetra
.914 .52 .125 r
.77006 .44528 .77271 .44808 .78074 .47046 .77818 .46889 Mtetra
.864 .418 .037 r
.77818 .46889 .78074 .47046 .7882 .4843 .78571 .48364 Mtetra
.837 .974 .882 r
.78571 .48364 .7882 .4843 .79417 .47902 .7917 .47835 Mtetra
.992 .812 .561 r
.7917 .47835 .79417 .47902 .79879 .45751 .79628 .45592 Mtetra
.986 .785 .551 r
.79628 .45592 .79879 .45751 .8031 .43313 .80052 .43036 Mtetra
.949 .806 .668 r
.80052 .43036 .8031 .43313 .80831 .41983 .80568 .41632 Mtetra
.107 .434 .875 r
.80568 .41632 .80831 .41983 .81497 .42321 .81236 .41978 Mtetra
.794 .362 0 r
.81236 .41978 .81497 .42321 .82271 .43792 .82016 .43525 Mtetra
.811 .364 0 r
.82016 .43525 .82271 .43792 .83044 .4517 .82797 .44991 Mtetra
0 .476 .852 r
.82797 .44991 .83044 .4517 .83711 .45366 .8347 .45225 Mtetra
.969 .869 .683 r
.8347 .45225 .83711 .45366 .84245 .44157 .84002 .43979 Mtetra
.984 .81 .588 r
.84002 .43979 .84245 .44157 .8471 .42277 .84461 .42015 Mtetra
.963 .812 .646 r
.84461 .42015 .8471 .42277 .85213 .40825 .84959 .40487 Mtetra
.747 .785 .884 r
.84959 .40487 .85213 .40825 .85829 .40503 .85573 .40139 Mtetra
0 .093 .634 r
.85573 .40139 .85829 .40503 .86555 .41218 .86303 .40886 Mtetra
.597 .145 0 r
.86303 .40886 .86555 .41218 .87316 .42221 .87072 .41951 Mtetra
0 .291 .768 r
.87072 .41951 .87316 .42221 .88021 .42638 .87782 .42414 Mtetra
.853 .883 .86 r
.87782 .42414 .88021 .42638 .88619 .42071 .88381 .41843 Mtetra
.963 .842 .675 r
.88381 .41843 .88619 .42071 .8914 .40817 .88898 .40542 Mtetra
.953 .827 .682 r
.88898 .40542 .8914 .40817 .89661 .39599 .89415 .39265 Mtetra
.841 .814 .824 r
.89415 .39265 .89661 .39599 .90256 .39027 .90008 .38659 Mtetra
.334 .568 .924 r
.90008 .38659 .90256 .39027 .90942 .39212 .90695 .38851 Mtetra
0 .263 .769 r
.90695 .38851 .90942 .39212 .91673 .39754 .91431 .39428 Mtetra
.122 .459 .888 r
.91431 .39428 .91673 .39754 .9238 .40056 .92143 .39763 Mtetra
.715 .813 .926 r
.92143 .39763 .9238 .40056 .93015 .39762 .9278 .39475 Mtetra
.899 .849 .785 r
.9278 .39475 .93015 .39762 .9359 .38987 .93354 .38676 Mtetra
.622 .767 .949 r
.35074 .56409 .35404 .56662 .3593 .56541 .35601 .56288 Mtetra
.821 .785 .819 r
.35601 .56288 .3593 .56541 .36476 .56031 .36149 .55759 Mtetra
.844 .771 .781 r
.36149 .55759 .36476 .56031 .37029 .55375 .36704 .55078 Mtetra
.769 .764 .848 r
.36704 .55078 .37029 .55375 .37568 .55006 .37245 .54701 Mtetra
.091 .47 .891 r
.37245 .54701 .37568 .55006 .38084 .5521 .3776 .54925 Mtetra
.774 .283 0 r
.3776 .54925 .38084 .5521 .38582 .55881 .38256 .55637 Mtetra
.784 .288 0 r
.38256 .55637 .38582 .55881 .39085 .56535 .38757 .5633 Mtetra
.204 .621 .95 r
.38757 .5633 .39085 .56535 .39613 .56625 .39285 .5643 Mtetra
.869 .81 .789 r
.39285 .5643 .39613 .56625 .40171 .55937 .39846 .55714 Mtetra
.901 .772 .709 r
.39846 .55714 .40171 .55937 .40744 .548 .40422 .54527 Mtetra
.875 .767 .74 r
.40422 .54527 .40744 .548 .41307 .53909 .40988 .53601 Mtetra
.546 .705 .944 r
.40988 .53601 .41307 .53909 .41841 .53865 .41523 .53566 Mtetra
.851 .398 .01 r
.41523 .53566 .41841 .53865 .4235 .54752 .42029 .54507 Mtetra
.912 .514 .214 r
.42029 .54507 .4235 .54752 .42852 .5601 .42528 .55835 Mtetra
.823 .344 .02 r
.42528 .55835 .42852 .5601 .43374 .5674 .43049 .56607 Mtetra
.824 .877 .883 r
.43049 .56607 .43374 .5674 .43929 .56305 .43606 .56153 Mtetra
.93 .782 .674 r
.43606 .56153 .43929 .56305 .44509 .54834 .44191 .54614 Mtetra
.923 .76 .661 r
.44191 .54614 .44509 .54834 .4509 .53208 .44775 .52917 Mtetra
.853 .772 .772 r
.44775 .52917 .4509 .53208 .45648 .52493 .45335 .52179 Mtetra
.755 .272 0 r
.45335 .52179 .45648 .52493 .46179 .53226 .45864 .52961 Mtetra
.935 .57 .288 r
.45864 .52961 .46179 .53226 .46695 .55011 .46378 .54845 Mtetra
.923 .554 .299 r
.46378 .54845 .46695 .55011 .47221 .56677 .46901 .566 Mtetra
.549 0 0 r
.46901 .566 .47221 .56677 .47772 .56995 .47453 .56934 Mtetra
.95 .814 .675 r
.47453 .56934 .47772 .56995 .48348 .55572 .48032 .55441 Mtetra
.949 .76 .614 r
.48032 .55441 .48348 .55572 .4893 .53225 .48619 .52983 Mtetra
.928 .757 .649 r
.48619 .52983 .4893 .53225 .49502 .51459 .49193 .51144 Mtetra
.476 .674 .951 r
.49193 .51144 .49502 .51459 .50056 .51465 .49748 .51169 Mtetra
.938 .571 .267 r
.49748 .51169 .50056 .51465 .50601 .53337 .50291 .53149 Mtetra
.942 .603 .355 r
.50291 .53149 .50601 .53337 .51152 .55922 .50839 .55872 Mtetra
.905 .525 .293 r
.50839 .55872 .51152 .55922 .51715 .5745 .51402 .57474 Mtetra
.922 .942 .796 r
.51402 .57474 .51715 .5745 .52286 .56722 .51976 .56703 Mtetra
.966 .771 .589 r
.51976 .56703 .52286 .56722 .52855 .54066 .52548 .53913 Mtetra
.955 .749 .587 r
.52548 .53913 .52855 .54066 .53416 .51163 .53112 .50879 Mtetra
.91 .768 .691 r
.53112 .50879 .53416 .51163 .53976 .49892 .53674 .49568 Mtetra
.884 .46 .066 r
.53674 .49568 .53976 .49892 .54549 .51116 .54247 .50876 Mtetra
.95 .614 .349 r
.54247 .50876 .54549 .51116 .55142 .54123 .54839 .54048 Mtetra
.937 .599 .364 r
.54839 .54048 .55142 .54123 .55745 .56946 .55442 .57014 Mtetra
.767 .289 .105 r
.55442 .57014 .55745 .56946 .56335 .57565 .56033 .57653 Mtetra
.983 .811 .594 r
.56033 .57653 .56335 .57565 .56892 .55388 .56592 .55356 Mtetra
.97 .753 .553 r
.56592 .55356 .56892 .55388 .57422 .51763 .57124 .51555 Mtetra
.955 .75 .587 r
.57124 .51555 .57422 .51763 .57956 .49011 .57659 .48689 Mtetra
.626 .734 .925 r
.57659 .48689 .57956 .49011 .5853 .48862 .58234 .48561 Mtetra
.948 .594 .286 r
.58234 .48561 .5853 .48862 .59159 .51412 .58864 .51261 Mtetra
.95 .619 .362 r
.58864 .51261 .59159 .51412 .59822 .55026 .59529 .55064 Mtetra
.919 .559 .332 r
.59529 .55064 .59822 .55026 .60466 .5723 .60175 .57373 Mtetra
.928 .972 .718 r
.60175 .57373 .60466 .5723 .61042 .56374 .60752 .56459 Mtetra
.983 .77 .538 r
.60752 .56459 .61042 .56374 .61547 .52908 .61257 .52814 Mtetra
.971 .747 .541 r
.61257 .52814 .61547 .52908 .6203 .49059 .61739 .48787 Mtetra
.942 .765 .633 r
.61739 .48787 .6203 .49059 .62563 .47216 .62273 .4688 Mtetra
.848 .413 0 r
.62273 .4688 .62563 .47216 .63191 .48438 .62903 .48189 Mtetra
.954 .614 .32 r
.62903 .48189 .63191 .48438 .639 .51877 .63616 .51814 Mtetra
.944 .603 .343 r
.63616 .51814 .639 .51877 .6462 .55215 .6434 .55322 Mtetra
.814 .366 .172 r
.6434 .55322 .6462 .55215 .65261 .56081 .64983 .56224 Mtetra
.995 .821 .557 r
.64983 .56224 .65261 .56081 .6578 .53752 .65501 .53771 Mtetra
.983 .756 .518 r
.65501 .53771 .6578 .53752 .66222 .49715 .6594 .49536 Mtetra
.97 .752 .552 r
.6594 .49536 .66222 .49715 .66687 .46508 .66403 .46189 Mtetra
.812 .789 .83 r
.66403 .46189 .66687 .46508 .67264 .45994 .66981 .4567 Mtetra
.934 .558 .194 r
.66981 .4567 .67264 .45994 .67973 .48305 .67695 .4811 Mtetra
.952 .605 .305 r
.67695 .4811 .67973 .48305 .68751 .51807 .68479 .51797 Mtetra
.924 .548 .279 r
.68479 .51797 .68751 .51807 .6948 .54049 .69213 .54155 Mtetra
.846 .995 .754 r
.69213 .54155 .6948 .54049 .70066 .53381 .69801 .53455 Mtetra
.992 .781 .519 r
.69801 .53455 .70066 .53381 .70514 .5017 .70245 .50087 Mtetra
.982 .756 .519 r
.70245 .50087 .70514 .5017 .70925 .46468 .7065 .46211 Mtetra
.959 .774 .61 r
.7065 .46211 .70925 .46468 .71424 .44488 .71146 .44144 Mtetra
0 0 .485 r
.71146 .44144 .71424 .44488 .7208 .45218 .71805 .44918 Mtetra
.939 .568 .207 r
.71805 .44918 .7208 .45218 .72862 .47936 .72595 .47777 Mtetra
.939 .568 .245 r
.72595 .47777 .72862 .47936 .73659 .50671 .73399 .50659 Mtetra
.781 .28 0 r
.73399 .50659 .73659 .50671 .74338 .51437 .74083 .51478 Mtetra
.994 .848 .584 r
.74083 .51478 .74338 .51437 .74849 .49619 .74592 .49582 Mtetra
.99 .772 .515 r
.74592 .49582 .74849 .49619 .75256 .46375 .74992 .46187 Mtetra
.979 .77 .552 r
.74992 .46187 .75256 .46375 .75693 .43701 .75423 .43384 Mtetra
.857 .805 .799 r
.75423 .43384 .75693 .43701 .7627 .43054 .76 .42704 Mtetra
.821 .392 0 r
.76 .42704 .7627 .43054 .77006 .44528 .76741 .4425 Mtetra
.919 .53 .141 r
.76741 .4425 .77006 .44528 .77818 .46889 .77561 .46735 Mtetra
.874 .436 .06 r
.77561 .46735 .77818 .46889 .78571 .48364 .78322 .48304 Mtetra
.835 .977 .88 r
.78322 .48304 .78571 .48364 .7917 .47835 .78923 .47772 Mtetra
.993 .808 .554 r
.78923 .47772 .7917 .47835 .79628 .45592 .79375 .45435 Mtetra
.986 .781 .544 r
.79375 .45435 .79628 .45592 .80052 .43036 .79793 .42759 Mtetra
.952 .803 .658 r
.79793 .42759 .80052 .43036 .80568 .41632 .80304 .4128 Mtetra
.095 .426 .87 r
.80304 .4128 .80568 .41632 .81236 .41978 .80974 .41634 Mtetra
.809 .381 0 r
.80974 .41634 .81236 .41978 .82016 .43525 .81761 .43258 Mtetra
.827 .386 0 r
.81761 .43258 .82016 .43525 .82797 .44991 .8255 .44813 Mtetra
0 .421 .811 r
.8255 .44813 .82797 .44991 .8347 .45225 .83227 .45086 Mtetra
.971 .867 .676 r
.83227 .45086 .8347 .45225 .84002 .43979 .83758 .43803 Mtetra
.986 .807 .58 r
.83758 .43803 .84002 .43979 .84461 .42015 .84212 .41755 Mtetra
.966 .809 .636 r
.84212 .41755 .84461 .42015 .84959 .40487 .84703 .40148 Mtetra
.758 .789 .878 r
.84703 .40148 .84959 .40487 .85573 .40139 .85316 .39773 Mtetra
0 .066 .61 r
.85316 .39773 .85573 .40139 .86303 .40886 .8605 .40553 Mtetra
.628 .177 0 r
.8605 .40553 .86303 .40886 .87072 .41951 .86826 .41681 Mtetra
0 .241 .728 r
.86826 .41681 .87072 .41951 .87782 .42414 .87541 .42191 Mtetra
.854 .885 .86 r
.87541 .42191 .87782 .42414 .88381 .41843 .88143 .41618 Mtetra
.966 .84 .667 r
.88143 .41618 .88381 .41843 .88898 .40542 .88656 .40269 Mtetra
.957 .825 .672 r
.88656 .40269 .88898 .40542 .89415 .39265 .89168 .38931 Mtetra
.85 .816 .815 r
.89168 .38931 .89415 .39265 .90008 .38659 .89758 .3829 Mtetra
.327 .564 .923 r
.89758 .3829 .90008 .38659 .90695 .38851 .90447 .38488 Mtetra
0 .233 .747 r
.90447 .38488 .90695 .38851 .91431 .39428 .91188 .391 Mtetra
.079 .429 .872 r
.91188 .391 .91431 .39428 .92143 .39763 .91905 .39469 Mtetra
.711 .813 .928 r
.91905 .39469 .92143 .39763 .9278 .39475 .92545 .39188 Mtetra
.903 .849 .78 r
.92545 .39188 .9278 .39475 .93354 .38676 .93117 .38366 Mtetra
.622 .768 .95 r
.34743 .56157 .35074 .56409 .35601 .56288 .35271 .56035 Mtetra
.825 .785 .815 r
.35271 .56035 .35601 .56288 .36149 .55759 .35821 .55487 Mtetra
.847 .77 .776 r
.35821 .55487 .36149 .55759 .36704 .55078 .36378 .54781 Mtetra
.772 .764 .846 r
.36378 .54781 .36704 .55078 .37245 .54701 .3692 .54394 Mtetra
.041 .438 .872 r
.3692 .54394 .37245 .54701 .3776 .54925 .37434 .54639 Mtetra
.799 .317 0 r
.37434 .54639 .3776 .54925 .38256 .55637 .37929 .55394 Mtetra
.804 .318 0 r
.37929 .55394 .38256 .55637 .38757 .5633 .38428 .56127 Mtetra
.174 .605 .94 r
.38428 .56127 .38757 .5633 .39285 .5643 .38956 .56237 Mtetra
.873 .809 .783 r
.38956 .56237 .39285 .5643 .39846 .55714 .39519 .5549 Mtetra
.904 .77 .704 r
.39519 .5549 .39846 .55714 .40422 .54527 .40099 .54253 Mtetra
.878 .766 .735 r
.40099 .54253 .40422 .54527 .40988 .53601 .40668 .53292 Mtetra
.535 .701 .946 r
.40668 .53292 .40988 .53601 .41523 .53566 .41203 .53266 Mtetra
.866 .422 .045 r
.41203 .53266 .41523 .53566 .42029 .54507 .41707 .54262 Mtetra
.917 .525 .233 r
.41707 .54262 .42029 .54507 .42528 .55835 .42204 .55663 Mtetra
.836 .367 .051 r
.42204 .55663 .42528 .55835 .43049 .56607 .42723 .56476 Mtetra
.831 .877 .877 r
.42723 .56476 .43049 .56607 .43606 .56153 .43282 .56004 Mtetra
.932 .779 .669 r
.43282 .56004 .43606 .56153 .44191 .54614 .4387 .54394 Mtetra
.925 .758 .656 r
.4387 .54394 .44191 .54614 .44775 .52917 .44459 .52624 Mtetra
.856 .771 .768 r
.44459 .52624 .44775 .52917 .45335 .52179 .45021 .51864 Mtetra
.785 .309 0 r
.45021 .51864 .45335 .52179 .45864 .52961 .45549 .52697 Mtetra
.937 .578 .301 r
.45549 .52697 .45864 .52961 .46378 .54845 .46059 .54682 Mtetra
.925 .561 .311 r
.46059 .54682 .46378 .54845 .46901 .566 .4658 .56528 Mtetra
.572 0 0 r
.4658 .56528 .46901 .566 .47453 .56934 .47132 .56878 Mtetra
.951 .811 .668 r
.47132 .56878 .47453 .56934 .48032 .55441 .47715 .5531 Mtetra
.949 .757 .609 r
.47715 .5531 .48032 .55441 .48619 .52983 .48306 .5274 Mtetra
.93 .755 .644 r
.48306 .5274 .48619 .52983 .49193 .51144 .48884 .50827 Mtetra
.448 .661 .952 r
.48884 .50827 .49193 .51144 .49748 .51169 .49438 .50873 Mtetra
.941 .579 .282 r
.49438 .50873 .49748 .51169 .50291 .53149 .4998 .52965 Mtetra
.943 .607 .363 r
.4998 .52965 .50291 .53149 .50839 .55872 .50526 .55828 Mtetra
.908 .532 .303 r
.50526 .55828 .50839 .55872 .51402 .57474 .51088 .57506 Mtetra
.93 .937 .783 r
.51088 .57506 .51402 .57474 .51976 .56703 .51663 .56688 Mtetra
.967 .768 .585 r
.51663 .56688 .51976 .56703 .52548 .53913 .52239 .5376 Mtetra
.955 .747 .583 r
.52239 .5376 .52548 .53913 .53112 .50879 .52807 .50592 Mtetra
.912 .766 .687 r
.52807 .50592 .53112 .50879 .53674 .49568 .5337 .49244 Mtetra
.896 .48 .098 r
.5337 .49244 .53674 .49568 .54247 .50876 .53943 .5064 Mtetra
.95 .618 .356 r
.53943 .5064 .54247 .50876 .54839 .54048 .54534 .53981 Mtetra
.938 .603 .37 r
.54534 .53981 .54839 .54048 .55442 .57014 .55137 .57091 Mtetra
.771 .299 .119 r
.55137 .57091 .55442 .57014 .56033 .57653 .55728 .57748 Mtetra
.983 .807 .588 r
.55728 .57748 .56033 .57653 .56592 .55356 .5629 .55326 Mtetra
.97 .75 .55 r
.5629 .55326 .56592 .55356 .57124 .51555 .56824 .51344 Mtetra
.955 .747 .583 r
.56824 .51344 .57124 .51555 .57659 .48689 .57361 .48364 Mtetra
.605 .725 .93 r
.57361 .48364 .57659 .48689 .58234 .48561 .57937 .48262 Mtetra
.95 .6 .297 r
.57937 .48262 .58234 .48561 .58864 .51261 .58568 .51117 Mtetra
.95 .622 .368 r
.58568 .51117 .58864 .51261 .59529 .55064 .59234 .55113 Mtetra
.92 .564 .34 r
.59234 .55113 .59529 .55064 .60175 .57373 .59882 .57526 Mtetra
.939 .965 .704 r
.59882 .57526 .60175 .57373 .60752 .56459 .6046 .56549 Mtetra
.983 .767 .534 r
.6046 .56549 .60752 .56459 .61257 .52814 .60965 .52718 Mtetra
.971 .745 .538 r
.60965 .52718 .61257 .52814 .61739 .48787 .61447 .48512 Mtetra
.943 .763 .629 r
.61447 .48512 .61739 .48787 .62273 .4688 .61981 .46543 Mtetra
.866 .438 .012 r
.61981 .46543 .62273 .4688 .62903 .48189 .62613 .47943 Mtetra
.955 .618 .328 r
.62613 .47943 .62903 .48189 .63616 .51814 .63331 .5176 Mtetra
.945 .606 .349 r
.63331 .5176 .63616 .51814 .6434 .55322 .64059 .55441 Mtetra
.818 .375 .185 r
.64059 .55441 .6434 .55322 .64983 .56224 .64704 .56376 Mtetra
.995 .816 .551 r
.64704 .56376 .64983 .56224 .65501 .53771 .65221 .53792 Mtetra
.982 .753 .515 r
.65221 .53792 .65501 .53771 .6594 .49536 .65657 .49355 Mtetra
.971 .75 .548 r
.65657 .49355 .6594 .49536 .66403 .46189 .66118 .45866 Mtetra
.812 .788 .83 r
.66118 .45866 .66403 .46189 .66981 .4567 .66696 .45346 Mtetra
.938 .567 .209 r
.66696 .45346 .66981 .4567 .67695 .4811 .67415 .47921 Mtetra
.953 .609 .312 r
.67415 .47921 .67695 .4811 .68479 .51797 .68207 .51795 Mtetra
.926 .554 .288 r
.68207 .51795 .68479 .51797 .69213 .54155 .68946 .54271 Mtetra
.856 .992 .74 r
.68946 .54271 .69213 .54155 .69801 .53455 .69534 .53535 Mtetra
.992 .778 .514 r
.69534 .53535 .69801 .53455 .70245 .50087 .69973 .50005 Mtetra
.982 .753 .515 r
.69973 .50005 .70245 .50087 .7065 .46211 .70373 .45951 Mtetra
.96 .772 .604 r
.70373 .45951 .7065 .46211 .71146 .44144 .70867 .43798 Mtetra
.551 .088 0 r
.70867 .43798 .71146 .44144 .71805 .44918 .71529 .44619 Mtetra
.942 .575 .218 r
.71529 .44619 .71805 .44918 .72595 .47777 .72326 .47624 Mtetra
.941 .574 .255 r
.72326 .47624 .72595 .47777 .73399 .50659 .73139 .50655 Mtetra
.795 .303 .019 r
.73139 .50655 .73399 .50659 .74083 .51478 .73827 .51526 Mtetra
.995 .844 .576 r
.73827 .51526 .74083 .51478 .74592 .49582 .74333 .49549 Mtetra
.99 .769 .51 r
.74333 .49549 .74592 .49582 .74992 .46187 .74727 .45999 Mtetra
.979 .767 .546 r
.74727 .45999 .74992 .46187 .75423 .43384 .75153 .43066 Mtetra
.863 .805 .792 r
.75153 .43066 .75423 .43384 .76 .42704 .75728 .42353 Mtetra
.834 .409 0 r
.75728 .42353 .76 .42704 .76741 .4425 .76474 .43972 Mtetra
.924 .539 .155 r
.76474 .43972 .76741 .4425 .77561 .46735 .77303 .46585 Mtetra
.883 .452 .082 r
.77303 .46585 .77561 .46735 .78322 .48304 .78072 .48249 Mtetra
.834 .98 .878 r
.78072 .48249 .78322 .48304 .78923 .47772 .78674 .47714 Mtetra
.993 .805 .547 r
.78674 .47714 .78923 .47772 .79375 .45435 .79122 .45281 Mtetra
.987 .778 .537 r
.79122 .45281 .79375 .45435 .79793 .42759 .79532 .42481 Mtetra
.956 .8 .649 r
.79532 .42481 .79793 .42759 .80304 .4128 .80039 .40927 Mtetra
.082 .418 .866 r
.80039 .40927 .80304 .4128 .80974 .41634 .8071 .4129 Mtetra
.823 .399 0 r
.8071 .4129 .80974 .41634 .81761 .43258 .81504 .42992 Mtetra
.841 .406 0 r
.81504 .42992 .81761 .43258 .8255 .44813 .82301 .44638 Mtetra
0 .364 .767 r
.82301 .44638 .8255 .44813 .83227 .45086 .82983 .44951 Mtetra
.974 .865 .669 r
.82983 .44951 .83227 .45086 .83758 .43803 .83514 .43631 Mtetra
.987 .804 .572 r
.83514 .43631 .83758 .43803 .84212 .41755 .83961 .41495 Mtetra
.969 .806 .626 r
.83961 .41495 .84212 .41755 .84703 .40148 .84447 .39809 Mtetra
.77 .792 .871 r
.84447 .39809 .84703 .40148 .85316 .39773 .85058 .39406 Mtetra
0 .041 .587 r
.85058 .39406 .85316 .39773 .8605 .40553 .85796 .40219 Mtetra
.657 .207 0 r
.85796 .40219 .8605 .40553 .86826 .41681 .86579 .41411 Mtetra
0 .191 .687 r
.86579 .41411 .86826 .41681 .87541 .42191 .873 .41969 Mtetra
.854 .886 .86 r
.873 .41969 .87541 .42191 .88143 .41618 .87903 .41394 Mtetra
.969 .838 .659 r
.87903 .41394 .88143 .41618 .88656 .40269 .88414 .39996 Mtetra
.961 .823 .662 r
.88414 .39996 .88656 .40269 .89168 .38931 .88921 .38597 Mtetra
.859 .818 .807 r
.88921 .38597 .89168 .38931 .89758 .3829 .89508 .37919 Mtetra
.32 .56 .922 r
.89508 .37919 .89758 .3829 .90447 .38488 .90198 .38123 Mtetra
0 .203 .725 r
.90198 .38123 .90447 .38488 .91188 .391 .90944 .38771 Mtetra
.035 .397 .853 r
.90944 .38771 .91188 .391 .91905 .39469 .91666 .39176 Mtetra
.705 .811 .931 r
.91666 .39176 .91905 .39469 .92545 .39188 .92308 .38902 Mtetra
.908 .849 .774 r
.92308 .38902 .92545 .39188 .93117 .38366 .92879 .38056 Mtetra
.623 .768 .95 r
.34411 .55905 .34743 .56157 .35271 .56035 .34939 .55782 Mtetra
.829 .784 .81 r
.34939 .55782 .35271 .56035 .35821 .55487 .35491 .55213 Mtetra
.851 .769 .772 r
.35491 .55213 .35821 .55487 .36378 .54781 .36051 .54482 Mtetra
.775 .764 .843 r
.36051 .54482 .36378 .54781 .3692 .54394 .36595 .54086 Mtetra
0 .403 .85 r
.36595 .54086 .3692 .54394 .37434 .54639 .37108 .54352 Mtetra
.819 .346 0 r
.37108 .54352 .37434 .54639 .37929 .55394 .376 .5515 Mtetra
.822 .344 0 r
.376 .5515 .37929 .55394 .38428 .56127 .38098 .55923 Mtetra
.147 .589 .93 r
.38098 .55923 .38428 .56127 .38956 .56237 .38626 .56043 Mtetra
.877 .807 .777 r
.38626 .56043 .38956 .56237 .39519 .5549 .39191 .55266 Mtetra
.906 .768 .699 r
.39191 .55266 .39519 .5549 .40099 .54253 .39775 .53978 Mtetra
.88 .765 .731 r
.39775 .53978 .40099 .54253 .40668 .53292 .40346 .52982 Mtetra
.524 .696 .948 r
.40346 .52982 .40668 .53292 .41203 .53266 .40882 .52965 Mtetra
.878 .443 .077 r
.40882 .52965 .41203 .53266 .41707 .54262 .41384 .54017 Mtetra
.921 .535 .25 r
.41384 .54017 .41707 .54262 .42204 .55663 .41877 .55491 Mtetra
.847 .386 .076 r
.41877 .55491 .42204 .55663 .42723 .56476 .42396 .56346 Mtetra
.838 .876 .871 r
.42396 .56346 .42723 .56476 .43282 .56004 .42956 .55854 Mtetra
.933 .776 .663 r
.42956 .55854 .43282 .56004 .4387 .54394 .43549 .54173 Mtetra
.926 .756 .652 r
.43549 .54173 .4387 .54394 .44459 .52624 .44141 .5233 Mtetra
.858 .771 .764 r
.44141 .5233 .44459 .52624 .45021 .51864 .44705 .51547 Mtetra
.81 .342 0 r
.44705 .51547 .45021 .51864 .45549 .52697 .45231 .52433 Mtetra
.939 .584 .313 r
.45231 .52433 .45549 .52697 .46059 .54682 .45739 .54522 Mtetra
.927 .567 .321 r
.45739 .54522 .46059 .54682 .4658 .56528 .46257 .56457 Mtetra
.59 .016 0 r
.46257 .56457 .4658 .56528 .47132 .56878 .4681 .56821 Mtetra
.952 .806 .662 r
.4681 .56821 .47132 .56878 .47715 .5531 .47396 .55178 Mtetra
.95 .755 .605 r
.47396 .55178 .47715 .5531 .48306 .5274 .47992 .52493 Mtetra
.931 .753 .64 r
.47992 .52493 .48306 .5274 .48884 .50827 .48573 .50508 Mtetra
.416 .645 .952 r
.48573 .50508 .48884 .50827 .49438 .50873 .49128 .50577 Mtetra
.943 .586 .295 r
.49128 .50577 .49438 .50873 .4998 .52965 .49667 .52784 Mtetra
.943 .611 .369 r
.49667 .52784 .4998 .52965 .50526 .55828 .5021 .55788 Mtetra
.91 .538 .312 r
.5021 .55788 .50526 .55828 .51088 .57506 .50771 .5754 Mtetra
.937 .93 .771 r
.50771 .5754 .51088 .57506 .51663 .56688 .51349 .56672 Mtetra
.966 .765 .581 r
.51349 .56672 .51663 .56688 .52239 .5376 .51929 .53603 Mtetra
.955 .745 .58 r
.51929 .53603 .52239 .5376 .52807 .50592 .525 .50302 Mtetra
.913 .765 .684 r
.525 .50302 .52807 .50592 .5337 .49244 .53066 .48918 Mtetra
.906 .499 .127 r
.53066 .48918 .5337 .49244 .53943 .5064 .53638 .50406 Mtetra
.951 .622 .363 r
.53638 .50406 .53943 .5064 .54534 .53981 .54228 .53919 Mtetra
.939 .606 .376 r
.54228 .53919 .54534 .53981 .55137 .57091 .5483 .57174 Mtetra
.774 .305 .128 r
.5483 .57174 .55137 .57091 .55728 .57748 .55422 .57845 Mtetra
.983 .801 .583 r
.55422 .57845 .55728 .57748 .5629 .55326 .55986 .55293 Mtetra
.97 .747 .547 r
.55986 .55293 .5629 .55326 .56824 .51344 .56523 .51128 Mtetra
.955 .745 .58 r
.56523 .51128 .56824 .51344 .57361 .48364 .57062 .48037 Mtetra
.579 .714 .935 r
.57062 .48037 .57361 .48364 .57937 .48262 .57639 .47964 Mtetra
.951 .606 .308 r
.57639 .47964 .57937 .48262 .58568 .51117 .58271 .50978 Mtetra
.951 .625 .373 r
.58271 .50978 .58568 .51117 .59234 .55113 .58938 .55169 Mtetra
.921 .568 .345 r
.58938 .55169 .59234 .55113 .59882 .57526 .59587 .57683 Mtetra
.95 .956 .692 r
.59587 .57683 .59882 .57526 .6046 .56549 .60166 .56639 Mtetra
.982 .763 .531 r
.60166 .56639 .6046 .56549 .60965 .52718 .60671 .52618 Mtetra
.971 .742 .535 r
.60671 .52618 .60965 .52718 .61447 .48512 .61153 .48231 Mtetra
.944 .761 .625 r
.61153 .48231 .61447 .48512 .61981 .46543 .61688 .46204 Mtetra
.88 .46 .045 r
.61688 .46204 .61981 .46543 .62613 .47943 .62323 .47701 Mtetra
.956 .621 .334 r
.62323 .47701 .62613 .47943 .63331 .5176 .63044 .51713 Mtetra
.946 .609 .355 r
.63044 .51713 .63331 .5176 .64059 .55441 .63777 .55566 Mtetra
.822 .382 .194 r
.63777 .55566 .64059 .55441 .64704 .56376 .64423 .56531 Mtetra
.995 .811 .546 r
.64423 .56531 .64704 .56376 .65221 .53792 .64939 .5381 Mtetra
.982 .75 .512 r
.64939 .5381 .65221 .53792 .65657 .49355 .65372 .49169 Mtetra
.97 .748 .545 r
.65372 .49169 .65657 .49355 .66118 .45866 .65831 .4554 Mtetra
.811 .787 .83 r
.65831 .4554 .66118 .45866 .66696 .45346 .66411 .45022 Mtetra
.941 .574 .222 r
.66411 .45022 .66696 .45346 .67415 .47921 .67135 .47736 Mtetra
.954 .613 .319 r
.67135 .47736 .67415 .47921 .68207 .51795 .67933 .518 Mtetra
.928 .56 .295 r
.67933 .518 .68207 .51795 .68946 .54271 .68677 .54392 Mtetra
.871 .99 .731 r
.68677 .54392 .68946 .54271 .69534 .53535 .69265 .53616 Mtetra
.991 .774 .51 r
.69265 .53616 .69534 .53535 .69973 .50005 .697 .4992 Mtetra
.982 .75 .512 r
.697 .4992 .69973 .50005 .70373 .45951 .70095 .45688 Mtetra
.961 .769 .599 r
.70095 .45688 .70373 .45951 .70867 .43798 .70587 .4345 Mtetra
.59 .126 0 r
.70587 .4345 .70867 .43798 .71529 .44619 .71252 .44321 Mtetra
.944 .581 .229 r
.71252 .44321 .71529 .44619 .72326 .47624 .72057 .47473 Mtetra
.943 .58 .264 r
.72057 .47473 .72326 .47624 .73139 .50655 .72877 .50655 Mtetra
.806 .321 .039 r
.72877 .50655 .73139 .50655 .73827 .51526 .73569 .51576 Mtetra
.996 .839 .57 r
.73569 .51576 .73827 .51526 .74333 .49549 .74073 .49516 Mtetra
.99 .766 .506 r
.74073 .49516 .74333 .49549 .74727 .45999 .74461 .45808 Mtetra
.98 .764 .541 r
.74461 .45808 .74727 .45999 .75153 .43066 .74881 .42746 Mtetra
.868 .804 .785 r
.74881 .42746 .75153 .43066 .75728 .42353 .75455 .42001 Mtetra
.846 .425 0 r
.75455 .42001 .75728 .42353 .76474 .43972 .76206 .43695 Mtetra
.928 .547 .167 r
.76206 .43695 .76474 .43972 .77303 .46585 .77044 .46437 Mtetra
.89 .465 .099 r
.77044 .46437 .77303 .46585 .78072 .48249 .7782 .48195 Mtetra
.835 .98 .877 r
.7782 .48195 .78072 .48249 .78674 .47714 .78424 .47657 Mtetra
.993 .801 .542 r
.78424 .47657 .78674 .47714 .79122 .45281 .78867 .45127 Mtetra
.987 .775 .531 r
.78867 .45127 .79122 .45281 .79532 .42481 .7927 .42203 Mtetra
.958 .797 .64 r
.7927 .42203 .79532 .42481 .80039 .40927 .79774 .40572 Mtetra
.069 .409 .861 r
.79774 .40572 .80039 .40927 .8071 .4129 .80446 .40944 Mtetra
.835 .414 0 r
.80446 .40944 .8071 .4129 .81504 .42992 .81246 .42725 Mtetra
.853 .423 0 r
.81246 .42725 .81504 .42992 .82301 .44638 .82052 .44463 Mtetra
0 .31 .723 r
.82052 .44463 .82301 .44638 .82983 .44951 .82739 .44816 Mtetra
.975 .863 .663 r
.82739 .44816 .82983 .44951 .83514 .43631 .83268 .43459 Mtetra
.988 .8 .565 r
.83268 .43459 .83514 .43631 .83961 .41495 .8371 .41235 Mtetra
.971 .803 .617 r
.8371 .41235 .83961 .41495 .84447 .39809 .8419 .39469 Mtetra
.781 .796 .865 r
.8419 .39469 .84447 .39809 .85058 .39406 .84799 .39037 Mtetra
0 .016 .564 r
.84799 .39037 .85058 .39406 .85796 .40219 .85541 .39883 Mtetra
.682 .234 0 r
.85541 .39883 .85796 .40219 .86579 .41411 .8633 .4114 Mtetra
0 .144 .647 r
.8633 .4114 .86579 .41411 .873 .41969 .87058 .41746 Mtetra
.854 .886 .861 r
.87058 .41746 .873 .41969 .87903 .41394 .87662 .4117 Mtetra
.971 .835 .652 r
.87662 .4117 .87903 .41394 .88414 .39996 .8817 .39724 Mtetra
.964 .82 .653 r
.8817 .39724 .88414 .39996 .88921 .38597 .88672 .38263 Mtetra
.868 .819 .798 r
.88672 .38263 .88921 .38597 .89508 .37919 .89256 .37548 Mtetra
.314 .556 .922 r
.89256 .37548 .89508 .37919 .90198 .38123 .89948 .37756 Mtetra
0 .174 .703 r
.89948 .37756 .90198 .38123 .90944 .38771 .90699 .38439 Mtetra
0 .365 .834 r
.90699 .38439 .90944 .38771 .91666 .39176 .91426 .3888 Mtetra
.699 .809 .933 r
.91426 .3888 .91666 .39176 .92308 .38902 .9207 .38615 Mtetra
.911 .849 .769 r
.9207 .38615 .92308 .38902 .92879 .38056 .9264 .37745 Mtetra
.623 .769 .95 r
.34077 .55651 .34411 .55905 .34939 .55782 .34606 .55528 Mtetra
.833 .784 .806 r
.34606 .55528 .34939 .55782 .35491 .55213 .35161 .54939 Mtetra
.854 .769 .767 r
.35161 .54939 .35491 .55213 .36051 .54482 .35723 .54182 Mtetra
.777 .764 .841 r
.35723 .54182 .36051 .54482 .36595 .54086 .36268 .53777 Mtetra
0 .367 .824 r
.36268 .53777 .36595 .54086 .37108 .54352 .3678 .54064 Mtetra
.836 .372 0 r
.3678 .54064 .37108 .54352 .376 .5515 .3727 .54906 Mtetra
.836 .367 .011 r
.3727 .54906 .376 .5515 .38098 .55923 .37766 .5572 Mtetra
.12 .573 .919 r
.37766 .5572 .38098 .55923 .38626 .56043 .38294 .55849 Mtetra
.88 .805 .771 r
.38294 .55849 .38626 .56043 .39191 .55266 .38862 .55042 Mtetra
.908 .767 .694 r
.38862 .55042 .39191 .55266 .39775 .53978 .3945 .53702 Mtetra
.883 .764 .726 r
.3945 .53702 .39775 .53978 .40346 .52982 .40024 .5267 Mtetra
.512 .691 .949 r
.40024 .5267 .40346 .52982 .40882 .52965 .4056 .52663 Mtetra
.889 .461 .105 r
.4056 .52663 .40882 .52965 .41384 .54017 .41059 .53773 Mtetra
.924 .544 .265 r
.41059 .53773 .41384 .54017 .41877 .55491 .41549 .5532 Mtetra
.856 .403 .1 r
.41549 .5532 .41877 .55491 .42396 .56346 .42066 .56217 Mtetra
.844 .875 .864 r
.42066 .56217 .42396 .56346 .42956 .55854 .42629 .55704 Mtetra
.934 .774 .658 r
.42629 .55704 .42956 .55854 .43549 .54173 .43226 .53951 Mtetra
.927 .754 .647 r
.43226 .53951 .43549 .54173 .44141 .5233 .43823 .52033 Mtetra
.861 .77 .76 r
.43823 .52033 .44141 .5233 .44705 .51547 .44388 .5123 Mtetra
.831 .372 0 r
.44388 .5123 .44705 .51547 .45231 .52433 .44913 .5217 Mtetra
.941 .59 .324 r
.44913 .5217 .45231 .52433 .45739 .54522 .45417 .54363 Mtetra
.929 .573 .33 r
.45417 .54363 .45739 .54522 .46257 .56457 .45932 .56389 Mtetra
.606 .036 0 r
.45932 .56389 .46257 .56457 .4681 .56821 .46485 .56767 Mtetra
.953 .802 .655 r
.46485 .56767 .4681 .56821 .47396 .55178 .47075 .55045 Mtetra
.95 .752 .601 r
.47075 .55045 .47396 .55178 .47992 .52493 .47677 .52244 Mtetra
.932 .751 .636 r
.47677 .52244 .47992 .52493 .48573 .50508 .48261 .50187 Mtetra
.378 .626 .95 r
.48261 .50187 .48573 .50508 .49128 .50577 .48816 .50281 Mtetra
.945 .592 .306 r
.48816 .50281 .49128 .50577 .49667 .52784 .49353 .52606 Mtetra
.944 .615 .376 r
.49353 .52606 .49667 .52784 .5021 .55788 .49893 .55753 Mtetra
.911 .544 .32 r
.49893 .55753 .5021 .55788 .50771 .5754 .50453 .57578 Mtetra
.943 .923 .759 r
.50453 .57578 .50771 .5754 .51349 .56672 .51033 .56657 Mtetra
.966 .762 .577 r
.51033 .56657 .51349 .56672 .51929 .53603 .51617 .53443 Mtetra
.955 .743 .576 r
.51617 .53443 .51929 .53603 .525 .50302 .52193 .50008 Mtetra
.914 .763 .681 r
.52193 .50008 .525 .50302 .53066 .48918 .5276 .48591 Mtetra
.915 .515 .153 r
.5276 .48591 .53066 .48918 .53638 .50406 .53332 .50176 Mtetra
.952 .625 .37 r
.53332 .50176 .53638 .50406 .54228 .53919 .5392 .53863 Mtetra
.939 .609 .381 r
.5392 .53863 .54228 .53919 .5483 .57174 .54521 .57263 Mtetra
.776 .31 .136 r
.54521 .57263 .5483 .57174 .55422 .57845 .55114 .57945 Mtetra
.982 .796 .577 r
.55114 .57945 .55422 .57845 .55986 .55293 .5568 .55258 Mtetra
.969 .745 .544 r
.5568 .55258 .55986 .55293 .56523 .51128 .5622 .50908 Mtetra
.955 .743 .577 r
.5622 .50908 .56523 .51128 .57062 .48037 .56761 .47706 Mtetra
.547 .7 .94 r
.56761 .47706 .57062 .48037 .57639 .47964 .57339 .47668 Mtetra
.953 .611 .317 r
.57339 .47668 .57639 .47964 .58271 .50978 .57972 .50844 Mtetra
.951 .628 .378 r
.57972 .50844 .58271 .50978 .58938 .55169 .5864 .55233 Mtetra
.922 .572 .351 r
.5864 .55233 .58938 .55169 .59587 .57683 .59291 .57847 Mtetra
.959 .947 .68 r
.59291 .57847 .59587 .57683 .60166 .56639 .59871 .56729 Mtetra
.982 .76 .528 r
.59871 .56729 .60166 .56639 .60671 .52618 .60376 .52515 Mtetra
.971 .74 .532 r
.60376 .52515 .60671 .52618 .61153 .48231 .60859 .47947 Mtetra
.944 .759 .622 r
.60859 .47947 .61153 .48231 .61688 .46204 .61394 .45865 Mtetra
.893 .48 .075 r
.61394 .45865 .61688 .46204 .62323 .47701 .62031 .47462 Mtetra
.956 .624 .341 r
.62031 .47462 .62323 .47701 .63044 .51713 .62756 .51674 Mtetra
.946 .612 .359 r
.62756 .51674 .63044 .51713 .63777 .55566 .63492 .557 Mtetra
.824 .388 .202 r
.63492 .557 .63777 .55566 .64423 .56531 .6414 .56691 Mtetra
.995 .805 .541 r
.6414 .56691 .64423 .56531 .64939 .5381 .64655 .53828 Mtetra
.981 .748 .509 r
.64655 .53828 .64939 .5381 .65372 .49169 .65085 .48979 Mtetra
.97 .745 .542 r
.65085 .48979 .65372 .49169 .65831 .4554 .65543 .45211 Mtetra
.808 .785 .831 r
.65543 .45211 .65831 .4554 .66411 .45022 .66124 .44699 Mtetra
.944 .581 .235 r
.66124 .44699 .66411 .45022 .67135 .47736 .66853 .47556 Mtetra
.955 .616 .325 r
.66853 .47556 .67135 .47736 .67933 .518 .67657 .51812 Mtetra
.929 .564 .302 r
.67657 .51812 .67933 .518 .68677 .54392 .68406 .54519 Mtetra
.884 .986 .72 r
.68406 .54519 .68677 .54392 .69265 .53616 .68994 .53699 Mtetra
.991 .771 .507 r
.68994 .53699 .69265 .53616 .697 .4992 .69426 .49833 Mtetra
.982 .748 .509 r
.69426 .49833 .697 .4992 .70095 .45688 .69816 .45422 Mtetra
.962 .767 .594 r
.69816 .45422 .70095 .45688 .70587 .4345 .70306 .43101 Mtetra
.626 .163 0 r
.70306 .43101 .70587 .4345 .71252 .44321 .70974 .44024 Mtetra
.946 .587 .239 r
.70974 .44024 .71252 .44321 .72057 .47473 .71786 .47327 Mtetra
.945 .584 .271 r
.71786 .47327 .72057 .47473 .72877 .50655 .72614 .5066 Mtetra
.816 .338 .059 r
.72614 .5066 .72877 .50655 .73569 .51576 .7331 .5163 Mtetra
.996 .834 .563 r
.7331 .5163 .73569 .51576 .74073 .49516 .73812 .49484 Mtetra
.989 .763 .502 r
.73812 .49484 .74073 .49516 .74461 .45808 .74193 .45617 Mtetra
.98 .761 .536 r
.74193 .45617 .74461 .45808 .74881 .42746 .74608 .42424 Mtetra
.873 .804 .778 r
.74608 .42424 .74881 .42746 .75455 .42001 .75182 .41648 Mtetra
.857 .44 0 r
.75182 .41648 .75455 .42001 .76206 .43695 .75938 .43419 Mtetra
.931 .554 .179 r
.75938 .43419 .76206 .43695 .77044 .46437 .76784 .46291 Mtetra
.896 .477 .116 r
.76784 .46291 .77044 .46437 .7782 .48195 .77567 .48144 Mtetra
.835 .982 .875 r
.77567 .48144 .7782 .48195 .78424 .47657 .78172 .47601 Mtetra
.993 .798 .536 r
.78172 .47601 .78424 .47657 .78867 .45127 .78611 .44972 Mtetra
.987 .772 .526 r
.78611 .44972 .78867 .45127 .7927 .42203 .79008 .41923 Mtetra
.961 .794 .632 r
.79008 .41923 .7927 .42203 .79774 .40572 .79507 .40216 Mtetra
.056 .4 .856 r
.79507 .40216 .79774 .40572 .80446 .40944 .8018 .40597 Mtetra
.846 .429 0 r
.8018 .40597 .80446 .40944 .81246 .42725 .80987 .42457 Mtetra
.863 .438 .002 r
.80987 .42457 .81246 .42725 .82052 .44463 .81801 .44288 Mtetra
0 .256 .678 r
.81801 .44288 .82052 .44463 .82739 .44816 .82493 .44682 Mtetra
.977 .86 .657 r
.82493 .44682 .82739 .44816 .83268 .43459 .8302 .43287 Mtetra
.988 .797 .558 r
.8302 .43287 .83268 .43459 .8371 .41235 .83457 .40976 Mtetra
.973 .8 .609 r
.83457 .40976 .8371 .41235 .8419 .39469 .83932 .39128 Mtetra
.792 .798 .858 r
.83932 .39128 .8419 .39469 .84799 .39037 .8454 .38667 Mtetra
0 0 .542 r
.8454 .38667 .84799 .39037 .85541 .39883 .85284 .39546 Mtetra
.704 .259 0 r
.85284 .39546 .85541 .39883 .8633 .4114 .86081 .40867 Mtetra
0 .098 .606 r
.86081 .40867 .8633 .4114 .87058 .41746 .86815 .41523 Mtetra
.854 .887 .861 r
.86815 .41523 .87058 .41746 .87662 .4117 .87421 .40946 Mtetra
.973 .833 .645 r
.87421 .40946 .87662 .4117 .8817 .39724 .87925 .39452 Mtetra
.967 .818 .644 r
.87925 .39452 .8817 .39724 .88672 .38263 .88422 .37928 Mtetra
.876 .82 .79 r
.88422 .37928 .88672 .38263 .89256 .37548 .89004 .37175 Mtetra
.309 .553 .921 r
.89004 .37175 .89256 .37548 .89948 .37756 .89697 .37388 Mtetra
0 .146 .68 r
.89697 .37388 .89948 .37756 .90699 .38439 .90453 .38106 Mtetra
0 .332 .813 r
.90453 .38106 .90699 .38439 .91426 .3888 .91185 .38584 Mtetra
.693 .807 .936 r
.91185 .38584 .91426 .3888 .9207 .38615 .91832 .38328 Mtetra
.915 .849 .763 r
.91832 .38328 .9207 .38615 .9264 .37745 .924 .37434 Mtetra
.623 .769 .95 r
.33742 .55398 .34077 .55651 .34606 .55528 .34272 .55273 Mtetra
.836 .783 .801 r
.34272 .55273 .34606 .55528 .35161 .54939 .34829 .54663 Mtetra
.857 .768 .763 r
.34829 .54663 .35161 .54939 .35723 .54182 .35394 .53881 Mtetra
.78 .764 .839 r
.35394 .53881 .35723 .54182 .36268 .53777 .35939 .53468 Mtetra
0 .328 .795 r
.35939 .53468 .36268 .53777 .3678 .54064 .36451 .53776 Mtetra
.851 .395 .021 r
.36451 .53776 .3678 .54064 .3727 .54906 .36939 .54662 Mtetra
.849 .388 .041 r
.36939 .54662 .3727 .54906 .37766 .5572 .37432 .55517 Mtetra
.091 .555 .907 r
.37432 .55517 .37766 .5572 .38294 .55849 .37961 .55656 Mtetra
.884 .803 .765 r
.37961 .55656 .38294 .55849 .38862 .55042 .38532 .54817 Mtetra
.909 .765 .689 r
.38532 .54817 .38862 .55042 .3945 .53702 .39124 .53425 Mtetra
.885 .762 .722 r
.39124 .53425 .3945 .53702 .40024 .5267 .397 .52357 Mtetra
.498 .685 .951 r
.397 .52357 .40024 .5267 .4056 .52663 .40236 .52361 Mtetra
.897 .478 .131 r
.40236 .52361 .4056 .52663 .41059 .53773 .40733 .53529 Mtetra
.926 .552 .278 r
.40733 .53529 .41059 .53773 .41549 .5532 .4122 .5515 Mtetra
.864 .418 .122 r
.4122 .5515 .41549 .5532 .42066 .56217 .41735 .5609 Mtetra
.85 .874 .858 r
.41735 .5609 .42066 .56217 .42629 .55704 .423 .55554 Mtetra
.936 .771 .653 r
.423 .55554 .42629 .55704 .43226 .53951 .42901 .53727 Mtetra
.928 .752 .643 r
.42901 .53727 .43226 .53951 .43823 .52033 .43503 .51735 Mtetra
.863 .769 .757 r
.43503 .51735 .43823 .52033 .44388 .5123 .4407 .50912 Mtetra
.849 .398 0 r
.4407 .50912 .44388 .5123 .44913 .5217 .44593 .51908 Mtetra
.942 .595 .333 r
.44593 .51908 .44913 .5217 .45417 .54363 .45093 .54208 Mtetra
.93 .578 .339 r
.45093 .54208 .45417 .54363 .45932 .56389 .45606 .56325 Mtetra
.619 .054 0 r
.45606 .56325 .45932 .56389 .46485 .56767 .46159 .56714 Mtetra
.954 .799 .649 r
.46159 .56714 .46485 .56767 .47075 .55045 .46753 .54911 Mtetra
.95 .75 .597 r
.46753 .54911 .47075 .55045 .47677 .52244 .4736 .51993 Mtetra
.932 .749 .632 r
.4736 .51993 .47677 .52244 .48261 .50187 .47948 .49864 Mtetra
.335 .602 .946 r
.47948 .49864 .48261 .50187 .48816 .50281 .48503 .49987 Mtetra
.946 .598 .317 r
.48503 .49987 .48816 .50281 .49353 .52606 .49037 .52432 Mtetra
.944 .618 .382 r
.49037 .52432 .49353 .52606 .49893 .55753 .49574 .55723 Mtetra
.913 .549 .327 r
.49574 .55723 .49893 .55753 .50453 .57578 .50133 .5762 Mtetra
.949 .916 .747 r
.50133 .5762 .50453 .57578 .51033 .56657 .50715 .56642 Mtetra
.966 .759 .573 r
.50715 .56642 .51033 .56657 .51617 .53443 .51304 .53281 Mtetra
.955 .741 .573 r
.51304 .53281 .51617 .53443 .52193 .50008 .51884 .49711 Mtetra
.914 .762 .678 r
.51884 .49711 .52193 .50008 .5276 .48591 .52453 .48264 Mtetra
.922 .529 .177 r
.52453 .48264 .5276 .48591 .53332 .50176 .53024 .49949 Mtetra
.952 .628 .375 r
.53024 .49949 .53332 .50176 .5392 .53863 .5361 .53814 Mtetra
.94 .612 .385 r
.5361 .53814 .5392 .53863 .54521 .57263 .5421 .57359 Mtetra
.777 .313 .143 r
.5421 .57359 .54521 .57263 .55114 .57945 .54804 .58049 Mtetra
.982 .792 .572 r
.54804 .58049 .55114 .57945 .5568 .55258 .55373 .55221 Mtetra
.969 .743 .541 r
.55373 .55221 .5568 .55258 .5622 .50908 .55916 .50683 Mtetra
.955 .742 .574 r
.55916 .50683 .5622 .50908 .56761 .47706 .56459 .47373 Mtetra
.507 .682 .945 r
.56459 .47373 .56761 .47706 .57339 .47668 .57039 .47373 Mtetra
.954 .615 .326 r
.57039 .47373 .57339 .47668 .57972 .50844 .57672 .50718 Mtetra
.951 .63 .382 r
.57672 .50718 .57972 .50844 .5864 .55233 .58341 .55306 Mtetra
.923 .575 .356 r
.58341 .55306 .5864 .55233 .59291 .57847 .58992 .58018 Mtetra
.967 .937 .667 r
.58992 .58018 .59291 .57847 .59871 .56729 .59573 .56822 Mtetra
.981 .757 .525 r
.59573 .56822 .59871 .56729 .60376 .52515 .60079 .52407 Mtetra
.97 .738 .53 r
.60079 .52407 .60376 .52515 .60859 .47947 .60562 .47658 Mtetra
.945 .758 .619 r
.60562 .47658 .60859 .47947 .61394 .45865 .61099 .45524 Mtetra
.903 .498 .103 r
.61099 .45524 .61394 .45865 .62031 .47462 .61739 .47227 Mtetra
.957 .627 .347 r
.61739 .47227 .62031 .47462 .62756 .51674 .62467 .51642 Mtetra
.947 .615 .364 r
.62467 .51642 .62756 .51674 .63492 .557 .63206 .55843 Mtetra
.826 .393 .21 r
.63206 .55843 .63492 .557 .6414 .56691 .63856 .56855 Mtetra
.994 .801 .536 r
.63856 .56855 .6414 .56691 .64655 .53828 .64369 .53846 Mtetra
.981 .745 .507 r
.64369 .53846 .64655 .53828 .65085 .48979 .64797 .48786 Mtetra
.97 .743 .539 r
.64797 .48786 .65085 .48979 .65543 .45211 .65254 .44878 Mtetra
.805 .784 .834 r
.65254 .44878 .65543 .45211 .66124 .44699 .65837 .44377 Mtetra
.947 .587 .246 r
.65837 .44377 .66124 .44699 .66853 .47556 .6657 .4738 Mtetra
.955 .619 .33 r
.6657 .4738 .66853 .47556 .67657 .51812 .67381 .51831 Mtetra
.931 .569 .308 r
.67381 .51831 .67657 .51812 .68406 .54519 .68134 .54653 Mtetra
.897 .982 .708 r
.68134 .54653 .68406 .54519 .68994 .53699 .68722 .53785 Mtetra
.991 .768 .503 r
.68722 .53785 .68994 .53699 .69426 .49833 .6915 .49745 Mtetra
.981 .746 .506 r
.6915 .49745 .69426 .49833 .69816 .45422 .69536 .45152 Mtetra
.963 .765 .589 r
.69536 .45152 .69816 .45422 .70306 .43101 .70024 .4275 Mtetra
.661 .199 0 r
.70024 .4275 .70306 .43101 .70974 .44024 .70694 .43728 Mtetra
.948 .592 .248 r
.70694 .43728 .70974 .44024 .71786 .47327 .71514 .47185 Mtetra
.946 .589 .278 r
.71514 .47185 .71786 .47327 .72614 .5066 .7235 .5067 Mtetra
.824 .353 .077 r
.7235 .5067 .72614 .5066 .7331 .5163 .7305 .51689 Mtetra
.997 .83 .557 r
.7305 .51689 .7331 .5163 .73812 .49484 .73549 .49453 Mtetra
.989 .76 .498 r
.73549 .49453 .73812 .49484 .74193 .45617 .73924 .45424 Mtetra
.98 .759 .532 r
.73924 .45424 .74193 .45617 .74608 .42424 .74334 .421 Mtetra
.878 .803 .772 r
.74334 .421 .74608 .42424 .75182 .41648 .74907 .41295 Mtetra
.866 .454 .004 r
.74907 .41295 .75182 .41648 .75938 .43419 .75668 .43144 Mtetra
.935 .56 .189 r
.75668 .43144 .75938 .43419 .76784 .46291 .76523 .46148 Mtetra
.902 .488 .131 r
.76523 .46148 .76784 .46291 .77567 .48144 .77313 .48097 Mtetra
.836 .983 .873 r
.77313 .48097 .77567 .48144 .78172 .47601 .7792 .47548 Mtetra
.994 .794 .531 r
.7792 .47548 .78172 .47601 .78611 .44972 .78354 .44819 Mtetra
.987 .769 .521 r
.78354 .44819 .78611 .44972 .79008 .41923 .78744 .41643 Mtetra
.963 .792 .624 r
.78744 .41643 .79008 .41923 .79507 .40216 .79239 .39858 Mtetra
.043 .39 .85 r
.79239 .39858 .79507 .40216 .8018 .40597 .79914 .40249 Mtetra
.855 .442 0 r
.79914 .40249 .8018 .40597 .80987 .42457 .80727 .42191 Mtetra
.872 .452 .022 r
.80727 .42191 .80987 .42457 .81801 .44288 .81549 .44115 Mtetra
0 .203 .631 r
.81549 .44115 .81801 .44288 .82493 .44682 .82246 .44551 Mtetra
.979 .858 .651 r
.82246 .44551 .82493 .44682 .8302 .43287 .82772 .43117 Mtetra
.989 .794 .552 r
.82772 .43117 .8302 .43287 .83457 .40976 .83203 .40716 Mtetra
.975 .797 .6 r
.83203 .40716 .83457 .40976 .83932 .39128 .83672 .38786 Mtetra
.802 .801 .85 r
.83672 .38786 .83932 .39128 .8454 .38667 .84279 .38296 Mtetra
0 0 .52 r
.84279 .38296 .8454 .38667 .85284 .39546 .85027 .39207 Mtetra
.724 .282 0 r
.85027 .39207 .85284 .39546 .86081 .40867 .85831 .40594 Mtetra
0 .054 .565 r
.85831 .40594 .86081 .40867 .86815 .41523 .86571 .413 Mtetra
.854 .888 .862 r
.86571 .413 .86815 .41523 .87421 .40946 .87178 .40723 Mtetra
.975 .831 .638 r
.87178 .40723 .87421 .40946 .87925 .39452 .87679 .3918 Mtetra
.969 .815 .635 r
.87679 .3918 .87925 .39452 .88422 .37928 .88172 .37593 Mtetra
.883 .82 .781 r
.88172 .37593 .88422 .37928 .89004 .37175 .8875 .36801 Mtetra
.304 .55 .92 r
.8875 .36801 .89004 .37175 .89697 .37388 .89444 .37017 Mtetra
0 .118 .657 r
.89444 .37017 .89697 .37388 .90453 .38106 .90205 .37772 Mtetra
0 .299 .79 r
.90205 .37772 .90453 .38106 .91185 .38584 .90943 .38286 Mtetra
.686 .805 .938 r
.90943 .38286 .91185 .38584 .91832 .38328 .91592 .3804 Mtetra
.919 .849 .758 r
.91592 .3804 .91832 .38328 .924 .37434 .9216 .37124 Mtetra
.623 .769 .95 r
.33406 .55143 .33742 .55398 .34272 .55273 .33936 .55017 Mtetra
.84 .782 .797 r
.33936 .55017 .34272 .55273 .34829 .54663 .34495 .54387 Mtetra
.86 .767 .759 r
.34495 .54387 .34829 .54663 .35394 .53881 .35063 .53578 Mtetra
.782 .764 .837 r
.35063 .53578 .35394 .53881 .35939 .53468 .3561 .53157 Mtetra
0 .288 .763 r
.3561 .53157 .35939 .53468 .36451 .53776 .36121 .53486 Mtetra
.863 .415 .051 r
.36121 .53486 .36451 .53776 .36939 .54662 .36606 .54417 Mtetra
.86 .407 .067 r
.36606 .54417 .36939 .54662 .37432 .55517 .37097 .55314 Mtetra
.065 .538 .896 r
.37097 .55314 .37432 .55517 .37961 .55656 .37626 .55462 Mtetra
.886 .801 .76 r
.37626 .55462 .37961 .55656 .38532 .54817 .38199 .54591 Mtetra
.911 .763 .684 r
.38199 .54591 .38532 .54817 .39124 .53425 .38796 .53147 Mtetra
.887 .761 .717 r
.38796 .53147 .39124 .53425 .397 .52357 .39375 .52043 Mtetra
.483 .679 .952 r
.39375 .52043 .397 .52357 .40236 .52361 .39911 .52058 Mtetra
.904 .492 .154 r
.39911 .52058 .40236 .52361 .40733 .53529 .40405 .53285 Mtetra
.929 .56 .29 r
.40405 .53285 .40733 .53529 .4122 .5515 .40889 .54981 Mtetra
.87 .432 .14 r
.40889 .54981 .4122 .5515 .41735 .5609 .41402 .55963 Mtetra
.856 .872 .85 r
.41402 .55963 .41735 .5609 .423 .55554 .41969 .55404 Mtetra
.936 .769 .649 r
.41969 .55404 .423 .55554 .42901 .53727 .42576 .53502 Mtetra
.929 .75 .639 r
.42576 .53502 .42901 .53727 .43503 .51735 .43182 .51436 Mtetra
.865 .768 .754 r
.43182 .51436 .43503 .51735 .4407 .50912 .43751 .50593 Mtetra
.864 .422 .029 r
.43751 .50593 .4407 .50912 .44593 .51908 .44272 .51646 Mtetra
.943 .6 .342 r
.44272 .51646 .44593 .51908 .45093 .54208 .44768 .54053 Mtetra
.931 .583 .346 r
.44768 .54053 .45093 .54208 .45606 .56325 .45277 .56262 Mtetra
.629 .066 0 r
.45277 .56262 .45606 .56325 .46159 .56714 .45831 .56661 Mtetra
.955 .795 .644 r
.45831 .56661 .46159 .56714 .46753 .54911 .46429 .54775 Mtetra
.95 .748 .594 r
.46429 .54775 .46753 .54911 .4736 .51993 .47042 .51739 Mtetra
.933 .748 .629 r
.47042 .51739 .4736 .51993 .47948 .49864 .47634 .4954 Mtetra
.284 .574 .938 r
.47634 .4954 .47948 .49864 .48503 .49987 .48189 .49692 Mtetra
.947 .603 .327 r
.48189 .49692 .48503 .49987 .49037 .52432 .4872 .5226 Mtetra
.945 .621 .387 r
.4872 .5226 .49037 .52432 .49574 .55723 .49253 .55696 Mtetra
.914 .553 .334 r
.49253 .55696 .49574 .55723 .50133 .5762 .4981 .57663 Mtetra
.954 .907 .736 r
.4981 .57663 .50133 .5762 .50715 .56642 .50395 .56625 Mtetra
.966 .756 .57 r
.50395 .56625 .50715 .56642 .51304 .53281 .50989 .53115 Mtetra
.955 .739 .571 r
.50989 .53115 .51304 .53281 .51884 .49711 .51574 .49411 Mtetra
.915 .761 .676 r
.51574 .49411 .51884 .49711 .52453 .48264 .52145 .47936 Mtetra
.928 .541 .198 r
.52145 .47936 .52453 .48264 .53024 .49949 .52715 .49724 Mtetra
.952 .631 .381 r
.52715 .49724 .53024 .49949 .5361 .53814 .53299 .5377 Mtetra
.94 .615 .389 r
.53299 .5377 .5361 .53814 .5421 .57359 .53897 .57459 Mtetra
.777 .314 .145 r
.53897 .57459 .5421 .57359 .54804 .58049 .54492 .58153 Mtetra
.982 .787 .568 r
.54492 .58153 .54804 .58049 .55373 .55221 .55063 .5518 Mtetra
.969 .74 .539 r
.55063 .5518 .55373 .55221 .55916 .50683 .5561 .50454 Mtetra
.955 .74 .572 r
.5561 .50454 .55916 .50683 .56459 .47373 .56156 .47036 Mtetra
.458 .658 .947 r
.56156 .47036 .56459 .47373 .57039 .47373 .56737 .4708 Mtetra
.955 .619 .334 r
.56737 .4708 .57039 .47373 .57672 .50718 .57371 .50596 Mtetra
.952 .632 .386 r
.57371 .50596 .57672 .50718 .58341 .55306 .5804 .55385 Mtetra
.924 .578 .36 r
.5804 .55385 .58341 .55306 .58992 .58018 .58691 .58192 Mtetra
.974 .926 .657 r
.58691 .58192 .58992 .58018 .59573 .56822 .59273 .56912 Mtetra
.981 .754 .522 r
.59273 .56912 .59573 .56822 .60079 .52407 .5978 .52294 Mtetra
.97 .736 .528 r
.5978 .52294 .60079 .52407 .60562 .47658 .60265 .47364 Mtetra
.945 .756 .616 r
.60265 .47364 .60562 .47658 .61099 .45524 .60803 .45182 Mtetra
.912 .514 .128 r
.60803 .45182 .61099 .45524 .61739 .47227 .61445 .46996 Mtetra
.958 .63 .352 r
.61445 .46996 .61739 .47227 .62467 .51642 .62176 .51617 Mtetra
.948 .617 .368 r
.62176 .51617 .62467 .51642 .63206 .55843 .62918 .5599 Mtetra
.828 .397 .214 r
.62918 .5599 .63206 .55843 .63856 .56855 .63569 .57021 Mtetra
.994 .796 .532 r
.63569 .57021 .63856 .56855 .64369 .53846 .64082 .53859 Mtetra
.981 .743 .504 r
.64082 .53859 .64369 .53846 .64797 .48786 .64508 .48586 Mtetra
.97 .741 .536 r
.64508 .48586 .64797 .48786 .65254 .44878 .64963 .44543 Mtetra
.8 .782 .837 r
.64963 .44543 .65254 .44878 .65837 .44377 .65548 .44055 Mtetra
.949 .593 .256 r
.65548 .44055 .65837 .44377 .6657 .4738 .66286 .47209 Mtetra
.956 .622 .335 r
.66286 .47209 .6657 .4738 .67381 .51831 .67102 .51856 Mtetra
.932 .573 .313 r
.67102 .51856 .67381 .51831 .68134 .54653 .6786 .5479 Mtetra
.912 .977 .699 r
.6786 .5479 .68134 .54653 .68722 .53785 .68448 .5387 Mtetra
.99 .764 .5 r
.68448 .5387 .68722 .53785 .6915 .49745 .68872 .49653 Mtetra
.981 .743 .503 r
.68872 .49653 .6915 .49745 .69536 .45152 .69253 .44879 Mtetra
.963 .762 .585 r
.69253 .44879 .69536 .45152 .70024 .4275 .69741 .42397 Mtetra
.692 .233 0 r
.69741 .42397 .70024 .4275 .70694 .43728 .70414 .43434 Mtetra
.95 .596 .256 r
.70414 .43434 .70694 .43728 .71514 .47185 .7124 .47045 Mtetra
.947 .593 .285 r
.7124 .47045 .71514 .47185 .7235 .5067 .72084 .50684 Mtetra
.832 .365 .09 r
.72084 .50684 .7235 .5067 .7305 .51689 .72787 .51748 Mtetra
.997 .825 .552 r
.72787 .51748 .7305 .51689 .73549 .49453 .73284 .4942 Mtetra
.989 .757 .495 r
.73284 .4942 .73549 .49453 .73924 .45424 .73654 .45227 Mtetra
.98 .756 .528 r
.73654 .45227 .73924 .45424 .74334 .421 .74058 .41774 Mtetra
.882 .802 .766 r
.74058 .41774 .74334 .421 .74907 .41295 .74631 .4094 Mtetra
.875 .466 .022 r
.74631 .4094 .74907 .41295 .75668 .43144 .75397 .4287 Mtetra
.937 .566 .199 r
.75397 .4287 .75668 .43144 .76523 .46148 .7626 .46005 Mtetra
.907 .497 .143 r
.7626 .46005 .76523 .46148 .77313 .48097 .77057 .4805 Mtetra
.838 .983 .871 r
.77057 .4805 .77313 .48097 .7792 .47548 .77665 .47495 Mtetra
.994 .791 .526 r
.77665 .47495 .7792 .47548 .78354 .44819 .78095 .44664 Mtetra
.987 .766 .516 r
.78095 .44664 .78354 .44819 .78744 .41643 .78479 .4136 Mtetra
.964 .789 .616 r
.78479 .4136 .78744 .41643 .79239 .39858 .7897 .39499 Mtetra
.028 .38 .844 r
.7897 .39499 .79239 .39858 .79914 .40249 .79646 .399 Mtetra
.864 .454 0 r
.79646 .399 .79914 .40249 .80727 .42191 .80466 .41923 Mtetra
.88 .464 .039 r
.80466 .41923 .80727 .42191 .81549 .44115 .81296 .43941 Mtetra
0 .155 .588 r
.81296 .43941 .81549 .44115 .82246 .44551 .81997 .44418 Mtetra
.98 .855 .646 r
.81997 .44418 .82246 .44551 .82772 .43117 .82523 .42946 Mtetra
.989 .791 .546 r
.82523 .42946 .82772 .43117 .83203 .40716 .82948 .40456 Mtetra
.976 .794 .593 r
.82948 .40456 .83203 .40716 .83672 .38786 .83412 .38443 Mtetra
.812 .803 .843 r
.83412 .38443 .83672 .38786 .84279 .38296 .84017 .37923 Mtetra
0 0 .498 r
.84017 .37923 .84279 .38296 .85027 .39207 .84769 .38867 Mtetra
.742 .303 0 r
.84769 .38867 .85027 .39207 .85831 .40594 .85579 .4032 Mtetra
0 .014 .526 r
.85579 .4032 .85831 .40594 .86571 .413 .86325 .41076 Mtetra
.853 .888 .862 r
.86325 .41076 .86571 .413 .87178 .40723 .86934 .405 Mtetra
.976 .828 .631 r
.86934 .405 .87178 .40723 .87679 .3918 .87433 .38908 Mtetra
.971 .812 .627 r
.87433 .38908 .87679 .3918 .88172 .37593 .8792 .37257 Mtetra
.89 .82 .772 r
.8792 .37257 .88172 .37593 .8875 .36801 .88496 .36425 Mtetra
.3 .548 .919 r
.88496 .36425 .8875 .36801 .89444 .37017 .89191 .36645 Mtetra
0 .091 .634 r
.89191 .36645 .89444 .37017 .90205 .37772 .89957 .37435 Mtetra
0 .266 .766 r
.89957 .37435 .90205 .37772 .90943 .38286 .907 .37987 Mtetra
.679 .802 .941 r
.907 .37987 .90943 .38286 .91592 .3804 .91352 .37751 Mtetra
.922 .848 .753 r
.91352 .37751 .91592 .3804 .9216 .37124 .91918 .36812 Mtetra
.624 .769 .95 r
.33068 .54887 .33406 .55143 .33936 .55017 .33599 .54761 Mtetra
.843 .782 .792 r
.33599 .54761 .33936 .55017 .34495 .54387 .34161 .5411 Mtetra
.862 .766 .755 r
.34161 .5411 .34495 .54387 .35063 .53578 .34731 .53275 Mtetra
.785 .764 .835 r
.34731 .53275 .35063 .53578 .3561 .53157 .35279 .52844 Mtetra
0 .247 .729 r
.35279 .52844 .3561 .53157 .36121 .53486 .35789 .53196 Mtetra
.874 .433 .078 r
.35789 .53196 .36121 .53486 .36606 .54417 .36272 .54172 Mtetra
.869 .424 .091 r
.36272 .54172 .36606 .54417 .37097 .55314 .36761 .55109 Mtetra
.041 .522 .885 r
.36761 .55109 .37097 .55314 .37626 .55462 .37289 .55267 Mtetra
.889 .799 .754 r
.37289 .55267 .37626 .55462 .38199 .54591 .37866 .54364 Mtetra
.912 .761 .68 r
.37866 .54364 .38199 .54591 .38796 .53147 .38467 .52866 Mtetra
.889 .76 .713 r
.38467 .52866 .38796 .53147 .39375 .52043 .39049 .51728 Mtetra
.467 .672 .953 r
.39049 .51728 .39375 .52043 .39911 .52058 .39585 .51754 Mtetra
.91 .505 .174 r
.39585 .51754 .39911 .52058 .40405 .53285 .40076 .5304 Mtetra
.931 .566 .301 r
.40076 .5304 .40405 .53285 .40889 .54981 .40556 .54811 Mtetra
.876 .444 .156 r
.40556 .54811 .40889 .54981 .41402 .55963 .41068 .55834 Mtetra
.862 .869 .843 r
.41068 .55834 .41402 .55963 .41969 .55404 .41637 .55251 Mtetra
.937 .766 .644 r
.41637 .55251 .41969 .55404 .42576 .53502 .42248 .53274 Mtetra
.93 .749 .636 r
.42248 .53274 .42576 .53502 .43182 .51436 .4286 .51134 Mtetra
.866 .767 .751 r
.4286 .51134 .43182 .51436 .43751 .50593 .43431 .50272 Mtetra
.877 .442 .06 r
.43431 .50272 .43751 .50593 .44272 .51646 .4395 .51385 Mtetra
.944 .605 .35 r
.4395 .51385 .44272 .51646 .44768 .54053 .44441 .53899 Mtetra
.932 .587 .353 r
.44441 .53899 .44768 .54053 .45277 .56262 .44947 .56198 Mtetra
.636 .075 0 r
.44947 .56198 .45277 .56262 .45831 .56661 .45502 .56606 Mtetra
.955 .791 .639 r
.45502 .56606 .45831 .56661 .46429 .54775 .46104 .54636 Mtetra
.95 .746 .591 r
.46104 .54636 .46429 .54775 .47042 .51739 .46723 .51481 Mtetra
.933 .746 .626 r
.46723 .51481 .47042 .51739 .47634 .4954 .47318 .49213 Mtetra
.226 .54 .926 r
.47318 .49213 .47634 .4954 .48189 .49692 .47874 .49398 Mtetra
.948 .608 .336 r
.47874 .49398 .48189 .49692 .4872 .5226 .48401 .52089 Mtetra
.945 .624 .391 r
.48401 .52089 .4872 .5226 .49253 .55696 .4893 .55671 Mtetra
.916 .557 .339 r
.4893 .55671 .49253 .55696 .4981 .57663 .49486 .57706 Mtetra
.957 .898 .725 r
.49486 .57706 .4981 .57663 .50395 .56625 .50074 .56605 Mtetra
.965 .753 .567 r
.50074 .56605 .50395 .56625 .50989 .53115 .50673 .52943 Mtetra
.955 .737 .568 r
.50673 .52943 .50989 .53115 .51574 .49411 .51263 .49106 Mtetra
.915 .76 .674 r
.51263 .49106 .51574 .49411 .52145 .47936 .51836 .47607 Mtetra
.932 .553 .217 r
.51836 .47607 .52145 .47936 .52715 .49724 .52405 .49502 Mtetra
.953 .633 .385 r
.52405 .49502 .52715 .49724 .53299 .5377 .52986 .53729 Mtetra
.941 .617 .393 r
.52986 .53729 .53299 .5377 .53897 .57459 .53582 .57561 Mtetra
.776 .313 .145 r
.53582 .57561 .53897 .57459 .54492 .58153 .54178 .58254 Mtetra
.981 .783 .564 r
.54178 .58254 .54492 .58153 .55063 .5518 .54753 .55134 Mtetra
.968 .738 .537 r
.54753 .55134 .55063 .5518 .5561 .50454 .55303 .50218 Mtetra
.955 .738 .569 r
.55303 .50218 .5561 .50454 .56156 .47036 .55852 .46697 Mtetra
.399 .627 .946 r
.55852 .46697 .56156 .47036 .56737 .4708 .56434 .46787 Mtetra
.956 .623 .341 r
.56434 .46787 .56737 .4708 .57371 .50596 .57068 .50478 Mtetra
.952 .634 .39 r
.57068 .50478 .57371 .50596 .5804 .55385 .57736 .55468 Mtetra
.925 .581 .363 r
.57736 .55468 .5804 .55385 .58691 .58192 .58389 .58367 Mtetra
.979 .915 .647 r
.58389 .58367 .58691 .58192 .59273 .56912 .58972 .56997 Mtetra
.98 .751 .52 r
.58972 .56997 .59273 .56912 .5978 .52294 .5948 .52174 Mtetra
.97 .734 .526 r
.5948 .52174 .5978 .52294 .60265 .47364 .59966 .47065 Mtetra
.945 .754 .614 r
.59966 .47065 .60265 .47364 .60803 .45182 .60506 .44839 Mtetra
.92 .528 .151 r
.60506 .44839 .60803 .45182 .61445 .46996 .61149 .46767 Mtetra
.958 .632 .357 r
.61149 .46767 .61445 .46996 .62176 .51617 .61883 .51596 Mtetra
.948 .62 .371 r
.61883 .51596 .62176 .51617 .62918 .5599 .62628 .56141 Mtetra
.829 .399 .217 r
.62628 .56141 .62918 .5599 .63569 .57021 .63281 .57185 Mtetra
.993 .791 .528 r
.63281 .57185 .63569 .57021 .64082 .53859 .63792 .53866 Mtetra
.98 .741 .502 r
.63792 .53866 .64082 .53859 .64508 .48586 .64217 .4838 Mtetra
.97 .739 .534 r
.64217 .4838 .64508 .48586 .64963 .44543 .64672 .44203 Mtetra
.793 .78 .841 r
.64672 .44203 .64963 .44543 .65548 .44055 .65258 .43733 Mtetra
.951 .598 .266 r
.65258 .43733 .65548 .44055 .66286 .47209 .66 .47041 Mtetra
.957 .624 .34 r
.66 .47041 .66286 .47209 .67102 .51856 .66823 .51884 Mtetra
.934 .576 .318 r
.66823 .51884 .67102 .51856 .6786 .5479 .67584 .54928 Mtetra
.926 .97 .691 r
.67584 .54928 .6786 .5479 .68448 .5387 .68172 .53952 Mtetra
.989 .761 .498 r
.68172 .53952 .68448 .5387 .68872 .49653 .68592 .49555 Mtetra
.981 .741 .501 r
.68592 .49555 .68872 .49653 .69253 .44879 .6897 .446 Mtetra
.963 .76 .581 r
.6897 .446 .69253 .44879 .69741 .42397 .69456 .42042 Mtetra
.721 .266 0 r
.69456 .42042 .69741 .42397 .70414 .43434 .70133 .4314 Mtetra
.952 .6 .263 r
.70133 .4314 .70414 .43434 .7124 .47045 .70966 .46908 Mtetra
.949 .596 .29 r
.70966 .46908 .7124 .47045 .72084 .50684 .71817 .50699 Mtetra
.838 .376 .101 r
.71817 .50699 .72084 .50684 .72787 .51748 .72523 .51807 Mtetra
.997 .82 .547 r
.72523 .51807 .72787 .51748 .73284 .4942 .73018 .49384 Mtetra
.988 .755 .492 r
.73018 .49384 .73284 .4942 .73654 .45227 .73381 .45027 Mtetra
.98 .754 .524 r
.73381 .45027 .73654 .45227 .74058 .41774 .73781 .41444 Mtetra
.885 .801 .761 r
.73781 .41444 .74058 .41774 .74631 .4094 .74354 .40585 Mtetra
.883 .477 .039 r
.74354 .40585 .74631 .4094 .75397 .4287 .75125 .42595 Mtetra
.94 .572 .208 r
.75125 .42595 .75397 .4287 .7626 .46005 .75997 .45863 Mtetra
.911 .506 .154 r
.75997 .45863 .7626 .46005 .77057 .4805 .768 .48003 Mtetra
.842 .983 .868 r
.768 .48003 .77057 .4805 .77665 .47495 .7741 .4744 Mtetra
.993 .788 .522 r
.7741 .4744 .77665 .47495 .78095 .44664 .77835 .44506 Mtetra
.987 .763 .512 r
.77835 .44506 .78095 .44664 .78479 .4136 .78212 .41076 Mtetra
.966 .786 .61 r
.78212 .41076 .78479 .4136 .7897 .39499 .78699 .39139 Mtetra
.014 .37 .838 r
.78699 .39139 .7897 .39499 .79646 .399 .79377 .39551 Mtetra
.871 .465 .013 r
.79377 .39551 .79646 .399 .80466 .41923 .80204 .41654 Mtetra
.886 .475 .054 r
.80204 .41654 .80466 .41923 .81296 .43941 .81042 .43766 Mtetra
.438 0 0 r
.81042 .43766 .81296 .43941 .81997 .44418 .81747 .44284 Mtetra
.981 .852 .641 r
.81747 .44284 .81997 .44418 .82523 .42946 .82272 .42774 Mtetra
.989 .788 .541 r
.82272 .42774 .82523 .42946 .82948 .40456 .82692 .40194 Mtetra
.977 .791 .586 r
.82692 .40194 .82948 .40456 .83412 .38443 .83151 .38099 Mtetra
.821 .805 .836 r
.83151 .38099 .83412 .38443 .84017 .37923 .83754 .37549 Mtetra
0 0 .477 r
.83754 .37549 .84017 .37923 .84769 .38867 .84509 .38524 Mtetra
.758 .322 0 r
.84509 .38524 .84769 .38867 .85579 .4032 .85326 .40043 Mtetra
0 0 .49 r
.85326 .40043 .85579 .4032 .86325 .41076 .86078 .4085 Mtetra
.852 .887 .863 r
.86078 .4085 .86325 .41076 .86934 .405 .86689 .40274 Mtetra
.978 .825 .625 r
.86689 .40274 .86934 .405 .87433 .38908 .87185 .38634 Mtetra
.973 .81 .619 r
.87185 .38634 .87433 .38908 .8792 .37257 .87668 .3692 Mtetra
.897 .82 .763 r
.87668 .3692 .8792 .37257 .88496 .36425 .8824 .36049 Mtetra
.296 .546 .919 r
.8824 .36049 .88496 .36425 .89191 .36645 .88937 .36271 Mtetra
0 .066 .612 r
.88937 .36271 .89191 .36645 .89957 .37435 .89707 .37097 Mtetra
0 .233 .742 r
.89707 .37097 .89957 .37435 .907 .37987 .90455 .37686 Mtetra
.671 .798 .943 r
.90455 .37686 .907 .37987 .91352 .37751 .9111 .3746 Mtetra
.924 .847 .748 r
.9111 .3746 .91352 .37751 .91918 .36812 .91675 .36499 Mtetra
.624 .77 .95 r
.32729 .54631 .33068 .54887 .33599 .54761 .33261 .54503 Mtetra
.846 .781 .788 r
.33261 .54503 .33599 .54761 .34161 .5411 .33825 .53831 Mtetra
.865 .765 .751 r
.33825 .53831 .34161 .5411 .34731 .53275 .34398 .5297 Mtetra
.787 .764 .833 r
.34398 .5297 .34731 .53275 .35279 .52844 .34947 .52531 Mtetra
0 .205 .692 r
.34947 .52531 .35279 .52844 .35789 .53196 .35456 .52905 Mtetra
.883 .45 .103 r
.35456 .52905 .35789 .53196 .36272 .54172 .35936 .53926 Mtetra
.877 .438 .113 r
.35936 .53926 .36272 .54172 .36761 .55109 .36423 .54905 Mtetra
.016 .505 .872 r
.36423 .54905 .36761 .55109 .37289 .55267 .36951 .55071 Mtetra
.892 .797 .749 r
.36951 .55071 .37289 .55267 .37866 .54364 .37531 .54135 Mtetra
.914 .759 .676 r
.37531 .54135 .37866 .54364 .38467 .52866 .38136 .52585 Mtetra
.891 .759 .71 r
.38136 .52585 .38467 .52866 .39049 .51728 .38722 .51411 Mtetra
.449 .664 .954 r
.38722 .51411 .39049 .51728 .39585 .51754 .39258 .5145 Mtetra
.915 .516 .193 r
.39258 .5145 .39585 .51754 .40076 .5304 .39746 .52796 Mtetra
.932 .572 .311 r
.39746 .52796 .40076 .5304 .40556 .54811 .40222 .54642 Mtetra
.881 .455 .172 r
.40222 .54642 .40556 .54811 .41068 .55834 .40732 .55705 Mtetra
.867 .867 .836 r
.40732 .55705 .41068 .55834 .41637 .55251 .41303 .55097 Mtetra
.938 .764 .64 r
.41303 .55097 .41637 .55251 .42248 .53274 .4192 .53044 Mtetra
.931 .747 .632 r
.4192 .53044 .42248 .53274 .4286 .51134 .42536 .5083 Mtetra
.868 .767 .748 r
.42536 .5083 .4286 .51134 .43431 .50272 .43109 .49951 Mtetra
.887 .461 .089 r
.43109 .49951 .43431 .50272 .4395 .51385 .43626 .51123 Mtetra
.945 .608 .357 r
.43626 .51123 .4395 .51385 .44441 .53899 .44113 .53747 Mtetra
.933 .591 .359 r
.44113 .53747 .44441 .53899 .44947 .56198 .44615 .56136 Mtetra
.642 .084 0 r
.44615 .56136 .44947 .56198 .45502 .56606 .4517 .5655 Mtetra
.956 .787 .634 r
.4517 .5655 .45502 .56606 .46104 .54636 .45778 .54494 Mtetra
.951 .744 .588 r
.45778 .54494 .46104 .54636 .46723 .51481 .46402 .5122 Mtetra
.934 .744 .623 r
.46402 .5122 .46723 .51481 .47318 .49213 .47001 .48884 Mtetra
.16 .5 .908 r
.47001 .48884 .47318 .49213 .47874 .49398 .47557 .49104 Mtetra
.949 .612 .344 r
.47557 .49104 .47874 .49398 .48401 .52089 .48081 .51922 Mtetra
.946 .626 .396 r
.48081 .51922 .48401 .52089 .4893 .55671 .48605 .55649 Mtetra
.917 .561 .344 r
.48605 .55649 .4893 .55671 .49486 .57706 .4916 .5775 Mtetra
.961 .89 .714 r
.4916 .5775 .49486 .57706 .50074 .56605 .4975 .56582 Mtetra
.965 .751 .564 r
.4975 .56582 .50074 .56605 .50673 .52943 .50355 .52767 Mtetra
.955 .735 .566 r
.50355 .52767 .50673 .52943 .51263 .49106 .5095 .48798 Mtetra
.916 .759 .672 r
.5095 .48798 .51263 .49106 .51836 .47607 .51525 .47278 Mtetra
.936 .562 .234 r
.51525 .47278 .51836 .47607 .52405 .49502 .52093 .49282 Mtetra
.953 .636 .39 r
.52093 .49282 .52405 .49502 .52986 .53729 .52671 .53693 Mtetra
.941 .619 .396 r
.52671 .53693 .52986 .53729 .53582 .57561 .53265 .57666 Mtetra
.774 .311 .145 r
.53265 .57666 .53582 .57561 .54178 .58254 .53862 .58355 Mtetra
.98 .779 .56 r
.53862 .58355 .54178 .58254 .54753 .55134 .5444 .55083 Mtetra
.968 .736 .535 r
.5444 .55083 .54753 .55134 .55303 .50218 .54994 .49977 Mtetra
.955 .736 .567 r
.54994 .49977 .55303 .50218 .55852 .46697 .55547 .46356 Mtetra
.326 .588 .939 r
.55547 .46356 .55852 .46697 .56434 .46787 .5613 .46497 Mtetra
.956 .626 .348 r
.5613 .46497 .56434 .46787 .57068 .50478 .56763 .50365 Mtetra
.952 .636 .393 r
.56763 .50365 .57068 .50478 .57736 .55468 .57431 .55557 Mtetra
.926 .583 .366 r
.57431 .55557 .57736 .55468 .58389 .58367 .58084 .58544 Mtetra
.984 .904 .637 r
.58084 .58544 .58389 .58367 .58972 .56997 .58668 .5708 Mtetra
.979 .748 .518 r
.58668 .5708 .58972 .56997 .5948 .52174 .59178 .52048 Mtetra
.969 .732 .524 r
.59178 .52048 .5948 .52174 .59966 .47065 .59666 .46761 Mtetra
.945 .753 .612 r
.59666 .46761 .59966 .47065 .60506 .44839 .60208 .44495 Mtetra
.926 .54 .172 r
.60208 .44495 .60506 .44839 .61149 .46767 .60853 .46542 Mtetra
.958 .635 .361 r
.60853 .46542 .61149 .46767 .61883 .51596 .61589 .51581 Mtetra
.949 .622 .374 r
.61589 .51581 .61883 .51596 .62628 .56141 .62337 .56297 Mtetra
.829 .4 .22 r
.62337 .56297 .62628 .56141 .63281 .57185 .6299 .57349 Mtetra
.992 .786 .525 r
.6299 .57349 .63281 .57185 .63792 .53866 .63501 .53869 Mtetra
.979 .739 .501 r
.63501 .53869 .63792 .53866 .64217 .4838 .63924 .48168 Mtetra
.97 .738 .531 r
.63924 .48168 .64217 .4838 .64672 .44203 .64379 .43861 Mtetra
.785 .778 .846 r
.64379 .43861 .64672 .44203 .65258 .43733 .64967 .43413 Mtetra
.953 .603 .275 r
.64967 .43413 .65258 .43733 .66 .47041 .65714 .46876 Mtetra
.957 .627 .344 r
.65714 .46876 .66 .47041 .66823 .51884 .66541 .51917 Mtetra
.935 .579 .322 r
.66541 .51917 .66823 .51884 .67584 .54928 .67307 .55069 Mtetra
.938 .963 .681 r
.67307 .55069 .67584 .54928 .68172 .53952 .67894 .54034 Mtetra
.989 .758 .495 r
.67894 .54034 .68172 .53952 .68592 .49555 .68311 .49453 Mtetra
.98 .739 .498 r
.68311 .49453 .68592 .49555 .6897 .446 .68685 .44317 Mtetra
.964 .758 .578 r
.68685 .44317 .6897 .446 .69456 .42042 .69171 .41685 Mtetra
.747 .295 0 r
.69171 .41685 .69456 .42042 .70133 .4314 .69851 .42848 Mtetra
.953 .604 .27 r
.69851 .42848 .70133 .4314 .70966 .46908 .7069 .46774 Mtetra
.95 .6 .295 r
.7069 .46774 .70966 .46908 .71817 .50699 .71548 .50717 Mtetra
.843 .386 .112 r
.71548 .50717 .71817 .50699 .72523 .51807 .72258 .51866 Mtetra
.997 .816 .542 r
.72258 .51866 .72523 .51807 .73018 .49384 .7275 .49346 Mtetra
.988 .752 .489 r
.7275 .49346 .73018 .49384 .73381 .45027 .73108 .44824 Mtetra
.98 .751 .52 r
.73108 .44824 .73381 .45027 .73781 .41444 .73503 .41112 Mtetra
.888 .8 .756 r
.73503 .41112 .73781 .41444 .74354 .40585 .74076 .40228 Mtetra
.89 .488 .055 r
.74076 .40228 .74354 .40585 .75125 .42595 .74852 .42321 Mtetra
.942 .576 .216 r
.74852 .42321 .75125 .42595 .75997 .45863 .75731 .45723 Mtetra
.915 .514 .165 r
.75731 .45723 .75997 .45863 .768 .48003 .76541 .47957 Mtetra
.845 .983 .865 r
.76541 .47957 .768 .48003 .7741 .4744 .77152 .47385 Mtetra
.993 .785 .518 r
.77152 .47385 .7741 .4744 .77835 .44506 .77574 .44347 Mtetra
.987 .761 .508 r
.77574 .44347 .77835 .44506 .78212 .41076 .77945 .4079 Mtetra
.967 .784 .603 r
.77945 .4079 .78212 .41076 .78699 .39139 .78428 .38777 Mtetra
0 .359 .831 r
.78428 .38777 .78699 .39139 .79377 .39551 .79107 .392 Mtetra
.878 .475 .028 r
.79107 .392 .79377 .39551 .80204 .41654 .7994 .41385 Mtetra
.892 .485 .068 r
.7994 .41385 .80204 .41654 .81042 .43766 .80786 .4359 Mtetra
.48 0 0 r
.80786 .4359 .81042 .43766 .81747 .44284 .81496 .4415 Mtetra
.982 .85 .636 r
.81496 .4415 .81747 .44284 .82272 .42774 .8202 .42601 Mtetra
.99 .785 .535 r
.8202 .42601 .82272 .42774 .82692 .40194 .82435 .39931 Mtetra
.978 .788 .579 r
.82435 .39931 .82692 .40194 .83151 .38099 .82888 .37753 Mtetra
.829 .806 .829 r
.82888 .37753 .83151 .38099 .83754 .37549 .8349 .37173 Mtetra
0 0 .457 r
.8349 .37173 .83754 .37549 .84509 .38524 .84249 .38181 Mtetra
.773 .339 0 r
.84249 .38181 .84509 .38524 .85326 .40043 .85072 .39765 Mtetra
.544 .06 0 r
.85072 .39765 .85326 .40043 .86078 .4085 .8583 .40623 Mtetra
.852 .887 .864 r
.8583 .40623 .86078 .4085 .86689 .40274 .86443 .40048 Mtetra
.979 .823 .619 r
.86443 .40048 .86689 .40274 .87185 .38634 .86935 .3836 Mtetra
.975 .807 .612 r
.86935 .3836 .87185 .38634 .87668 .3692 .87414 .36583 Mtetra
.903 .82 .755 r
.87414 .36583 .87668 .3692 .8824 .36049 .87984 .35671 Mtetra
.293 .544 .918 r
.87984 .35671 .8824 .36049 .88937 .36271 .88681 .35895 Mtetra
0 .041 .59 r
.88681 .35895 .88937 .36271 .89707 .37097 .89456 .36756 Mtetra
0 .201 .717 r
.89456 .36756 .89707 .37097 .90455 .37686 .90209 .37383 Mtetra
.663 .795 .945 r
.90209 .37383 .90455 .37686 .9111 .3746 .90867 .37169 Mtetra
.927 .846 .744 r
.90867 .37169 .9111 .3746 .91675 .36499 .91431 .36185 Mtetra
.625 .77 .949 r
.32389 .54373 .32729 .54631 .33261 .54503 .32921 .54244 Mtetra
.849 .78 .784 r
.32921 .54244 .33261 .54503 .33825 .53831 .33487 .53551 Mtetra
.867 .764 .747 r
.33487 .53551 .33825 .53831 .34398 .5297 .34063 .52664 Mtetra
.789 .764 .831 r
.34063 .52664 .34398 .5297 .34947 .52531 .34614 .52217 Mtetra
0 .164 .654 r
.34614 .52217 .34947 .52531 .35456 .52905 .35122 .52613 Mtetra
.89 .464 .125 r
.35122 .52613 .35456 .52905 .35936 .53926 .35599 .53679 Mtetra
.883 .452 .133 r
.35599 .53679 .35936 .53926 .36423 .54905 .36083 .54699 Mtetra
0 .489 .861 r
.36083 .54699 .36423 .54905 .36951 .55071 .36612 .54873 Mtetra
.894 .795 .744 r
.36612 .54873 .36951 .55071 .37531 .54135 .37195 .53904 Mtetra
.915 .758 .672 r
.37195 .53904 .37531 .54135 .38136 .52585 .37804 .52301 Mtetra
.892 .757 .706 r
.37804 .52301 .38136 .52585 .38722 .51411 .38394 .51093 Mtetra
.43 .655 .954 r
.38394 .51093 .38722 .51411 .39258 .5145 .38929 .51145 Mtetra
.92 .526 .21 r
.38929 .51145 .39258 .5145 .39746 .52796 .39414 .52551 Mtetra
.934 .577 .32 r
.39414 .52551 .39746 .52796 .40222 .54642 .39886 .54472 Mtetra
.886 .464 .185 r
.39886 .54472 .40222 .54642 .40732 .55705 .40395 .55575 Mtetra
.872 .864 .828 r
.40395 .55575 .40732 .55705 .41303 .55097 .40968 .54942 Mtetra
.938 .761 .636 r
.40968 .54942 .41303 .55097 .4192 .53044 .4159 .52812 Mtetra
.931 .745 .629 r
.4159 .52812 .4192 .53044 .42536 .5083 .42211 .50524 Mtetra
.869 .766 .746 r
.42211 .50524 .42536 .5083 .43109 .49951 .42786 .49629 Mtetra
.896 .477 .114 r
.42786 .49629 .43109 .49951 .43626 .51123 .43301 .50862 Mtetra
.945 .612 .364 r
.43301 .50862 .43626 .51123 .44113 .53747 .43783 .53595 Mtetra
.934 .595 .364 r
.43783 .53595 .44113 .53747 .44615 .56136 .44282 .56074 Mtetra
.646 .089 0 r
.44282 .56074 .44615 .56136 .4517 .5655 .44837 .56493 Mtetra
.956 .783 .629 r
.44837 .56493 .4517 .5655 .45778 .54494 .45449 .54349 Mtetra
.951 .742 .585 r
.45449 .54349 .45778 .54494 .46402 .5122 .4608 .50956 Mtetra
.934 .743 .62 r
.4608 .50956 .46402 .5122 .47001 .48884 .46684 .48554 Mtetra
.087 .454 .884 r
.46684 .48554 .47001 .48884 .47557 .49104 .47239 .4881 Mtetra
.95 .616 .351 r
.47239 .4881 .47557 .49104 .48081 .51922 .47759 .51756 Mtetra
.946 .628 .399 r
.47759 .51756 .48081 .51922 .48605 .55649 .48279 .55628 Mtetra
.918 .564 .348 r
.48279 .55628 .48605 .55649 .4916 .5775 .48832 .57793 Mtetra
.963 .881 .703 r
.48832 .57793 .4916 .5775 .4975 .56582 .49425 .56556 Mtetra
.965 .748 .561 r
.49425 .56556 .4975 .56582 .50355 .52767 .50036 .52586 Mtetra
.955 .734 .564 r
.50036 .52586 .50355 .52767 .5095 .48798 .50636 .48487 Mtetra
.916 .758 .67 r
.50636 .48487 .5095 .48798 .51525 .47278 .51214 .46948 Mtetra
.94 .571 .25 r
.51214 .46948 .51525 .47278 .52093 .49282 .5178 .49065 Mtetra
.953 .638 .394 r
.5178 .49065 .52093 .49282 .52671 .53693 .52355 .5366 Mtetra
.942 .621 .399 r
.52355 .5366 .52671 .53693 .53265 .57666 .52946 .57774 Mtetra
.771 .306 .141 r
.52946 .57774 .53265 .57666 .53862 .58355 .53544 .58454 Mtetra
.98 .775 .557 r
.53544 .58454 .53862 .58355 .5444 .55083 .54125 .55026 Mtetra
.967 .734 .533 r
.54125 .55026 .5444 .55083 .54994 .49977 .54685 .4973 Mtetra
.955 .735 .565 r
.54685 .4973 .54994 .49977 .55547 .46356 .5524 .46011 Mtetra
.241 .538 .923 r
.5524 .46011 .55547 .46356 .5613 .46497 .55824 .46207 Mtetra
.957 .629 .354 r
.55824 .46207 .5613 .46497 .56763 .50365 .56457 .50257 Mtetra
.953 .638 .396 r
.56457 .50257 .56763 .50365 .57431 .55557 .57124 .5565 Mtetra
.927 .586 .369 r
.57124 .5565 .57431 .55557 .58084 .58544 .57777 .58721 Mtetra
.987 .893 .628 r
.57777 .58721 .58084 .58544 .58668 .5708 .58363 .57158 Mtetra
.979 .746 .516 r
.58363 .57158 .58668 .5708 .59178 .52048 .58874 .51916 Mtetra
.969 .731 .522 r
.58874 .51916 .59178 .52048 .59666 .46761 .59364 .46452 Mtetra
.945 .752 .611 r
.59364 .46452 .59666 .46761 .60208 .44495 .59908 .4415 Mtetra
.931 .551 .19 r
.59908 .4415 .60208 .44495 .60853 .46542 .60555 .4632 Mtetra
.959 .637 .365 r
.60555 .4632 .60853 .46542 .61589 .51581 .61294 .5157 Mtetra
.949 .624 .377 r
.61294 .5157 .61589 .51581 .62337 .56297 .62043 .56455 Mtetra
.829 .4 .22 r
.62043 .56455 .62337 .56297 .6299 .57349 .62697 .57512 Mtetra
.992 .782 .522 r
.62697 .57512 .6299 .57349 .63501 .53869 .63207 .53867 Mtetra
.979 .737 .499 r
.63207 .53867 .63501 .53869 .63924 .48168 .6363 .4795 Mtetra
.97 .736 .529 r
.6363 .4795 .63924 .48168 .64379 .43861 .64085 .43515 Mtetra
.776 .775 .852 r
.64085 .43515 .64379 .43861 .64967 .43413 .64675 .43092 Mtetra
.954 .607 .283 r
.64675 .43092 .64967 .43413 .65714 .46876 .65426 .46715 Mtetra
.958 .629 .347 r
.65426 .46715 .65714 .46876 .66541 .51917 .66258 .51954 Mtetra
.936 .582 .325 r
.66258 .51954 .66541 .51917 .67307 .55069 .67027 .55211 Mtetra
.949 .955 .672 r
.67027 .55211 .67307 .55069 .67894 .54034 .67615 .54112 Mtetra
.988 .756 .493 r
.67615 .54112 .67894 .54034 .68311 .49453 .68028 .49346 Mtetra
.98 .737 .496 r
.68028 .49346 .68311 .49453 .68685 .44317 .68399 .4403 Mtetra
.964 .757 .575 r
.68399 .4403 .68685 .44317 .69171 .41685 .68884 .41327 Mtetra
.77 .323 0 r
.68884 .41327 .69171 .41685 .69851 .42848 .69567 .42556 Mtetra
.954 .607 .276 r
.69567 .42556 .69851 .42848 .7069 .46774 .70413 .46642 Mtetra
.951 .603 .3 r
.70413 .46642 .7069 .46774 .71548 .50717 .71277 .50736 Mtetra
.848 .394 .12 r
.71277 .50736 .71548 .50717 .72258 .51866 .7199 .51925 Mtetra
.996 .811 .538 r
.7199 .51925 .72258 .51866 .7275 .49346 .7248 .49305 Mtetra
.988 .75 .487 r
.7248 .49305 .7275 .49346 .73108 .44824 .72833 .44617 Mtetra
.98 .749 .517 r
.72833 .44617 .73108 .44824 .73503 .41112 .73224 .40778 Mtetra
.891 .799 .752 r
.73224 .40778 .73503 .41112 .74076 .40228 .73797 .39871 Mtetra
.896 .497 .07 r
.73797 .39871 .74076 .40228 .74852 .42321 .74578 .42048 Mtetra
.944 .581 .223 r
.74578 .42048 .74852 .42321 .75731 .45723 .75465 .45582 Mtetra
.918 .521 .174 r
.75465 .45582 .75731 .45723 .76541 .47957 .76281 .47911 Mtetra
.849 .983 .863 r
.76281 .47911 .76541 .47957 .77152 .47385 .76893 .47328 Mtetra
.993 .781 .514 r
.76893 .47328 .77152 .47385 .77574 .44347 .77311 .44185 Mtetra
.987 .758 .504 r
.77311 .44185 .77574 .44347 .77945 .4079 .77676 .40501 Mtetra
.968 .781 .597 r
.77676 .40501 .77945 .4079 .78428 .38777 .78156 .38413 Mtetra
0 .347 .824 r
.78156 .38413 .78428 .38777 .79107 .392 .78837 .38848 Mtetra
.884 .484 .041 r
.78837 .38848 .79107 .392 .7994 .41385 .79675 .41114 Mtetra
.898 .494 .081 r
.79675 .41114 .7994 .41385 .80786 .4359 .80529 .43414 Mtetra
.516 0 0 r
.80529 .43414 .80786 .4359 .81496 .4415 .81244 .44014 Mtetra
.983 .847 .631 r
.81244 .44014 .81496 .4415 .8202 .42601 .81766 .42426 Mtetra
.99 .782 .531 r
.81766 .42426 .8202 .42601 .82435 .39931 .82176 .39667 Mtetra
.979 .785 .573 r
.82176 .39667 .82435 .39931 .82888 .37753 .82624 .37406 Mtetra
.837 .807 .822 r
.82624 .37406 .82888 .37753 .8349 .37173 .83225 .36796 Mtetra
0 0 .438 r
.83225 .36796 .8349 .37173 .84249 .38181 .83987 .37836 Mtetra
.786 .355 0 r
.83987 .37836 .84249 .38181 .85072 .39765 .84817 .39485 Mtetra
.575 .092 0 r
.84817 .39485 .85072 .39765 .8583 .40623 .85581 .40395 Mtetra
.851 .887 .864 r
.85581 .40395 .8583 .40623 .86443 .40048 .86195 .39821 Mtetra
.98 .82 .613 r
.86195 .39821 .86443 .40048 .86935 .3836 .86685 .38085 Mtetra
.976 .804 .605 r
.86685 .38085 .86935 .3836 .87414 .36583 .87159 .36244 Mtetra
.909 .819 .747 r
.87159 .36244 .87414 .36583 .87984 .35671 .87726 .35291 Mtetra
.29 .542 .918 r
.87726 .35291 .87984 .35671 .88681 .35895 .88425 .35518 Mtetra
0 .017 .568 r
.88425 .35518 .88681 .35895 .89456 .36756 .89204 .36414 Mtetra
0 .17 .692 r
.89204 .36414 .89456 .36756 .90209 .37383 .89963 .37078 Mtetra
.654 .791 .948 r
.89963 .37078 .90209 .37383 .90867 .37169 .90623 .36875 Mtetra
.929 .845 .739 r
.90623 .36875 .90867 .37169 .91431 .36185 .91186 .3587 Mtetra
.626 .769 .949 r
.32047 .54114 .32389 .54373 .32921 .54244 .3258 .53983 Mtetra
.851 .778 .78 r
.3258 .53983 .32921 .54244 .33487 .53551 .33149 .53269 Mtetra
.869 .763 .743 r
.33149 .53269 .33487 .53551 .34063 .52664 .33727 .52356 Mtetra
.791 .764 .829 r
.33727 .52356 .34063 .52664 .34614 .52217 .3428 .51901 Mtetra
0 .123 .615 r
.3428 .51901 .34614 .52217 .35122 .52613 .34787 .52319 Mtetra
.897 .477 .145 r
.34787 .52319 .35122 .52613 .35599 .53679 .35261 .5343 Mtetra
.889 .464 .149 r
.35261 .5343 .35599 .53679 .36083 .54699 .35742 .5449 Mtetra
0 .475 .851 r
.35742 .5449 .36083 .54699 .36612 .54873 .36271 .54673 Mtetra
.895 .792 .739 r
.36271 .54673 .36612 .54873 .37195 .53904 .36857 .53671 Mtetra
.916 .756 .668 r
.36857 .53671 .37195 .53904 .37804 .52301 .37471 .52016 Mtetra
.894 .756 .702 r
.37471 .52016 .37804 .52301 .38394 .51093 .38064 .50774 Mtetra
.41 .646 .954 r
.38064 .50774 .38394 .51093 .38929 .51145 .386 .50838 Mtetra
.923 .535 .226 r
.386 .50838 .38929 .51145 .39414 .52551 .39081 .52304 Mtetra
.935 .582 .328 r
.39081 .52304 .39414 .52551 .39886 .54472 .39548 .54299 Mtetra
.89 .473 .196 r
.39548 .54299 .39886 .54472 .40395 .55575 .40055 .55442 Mtetra
.876 .859 .821 r
.40055 .55442 .40395 .55575 .40968 .54942 .40631 .54782 Mtetra
.938 .759 .633 r
.40631 .54782 .40968 .54942 .4159 .52812 .41259 .52575 Mtetra
.932 .744 .626 r
.41259 .52575 .4159 .52812 .42211 .50524 .41885 .50215 Mtetra
.87 .765 .744 r
.41885 .50215 .42211 .50524 .42786 .49629 .42462 .49306 Mtetra
.904 .492 .137 r
.42462 .49306 .42786 .49629 .43301 .50862 .42975 .506 Mtetra
.946 .615 .37 r
.42975 .506 .43301 .50862 .43783 .53595 .43451 .53441 Mtetra
.935 .598 .369 r
.43451 .53441 .43783 .53595 .44282 .56074 .43946 .56008 Mtetra
.646 .088 0 r
.43946 .56008 .44282 .56074 .44837 .56493 .44502 .5643 Mtetra
.955 .779 .625 r
.44502 .5643 .44837 .56493 .45449 .54349 .45119 .54198 Mtetra
.95 .74 .583 r
.45119 .54198 .45449 .54349 .4608 .50956 .45757 .50687 Mtetra
.935 .741 .617 r
.45757 .50687 .4608 .50956 .46684 .48554 .46365 .48222 Mtetra
.008 .4 .852 r
.46365 .48222 .46684 .48554 .47239 .4881 .46919 .48516 Mtetra
.951 .619 .358 r
.46919 .48516 .47239 .4881 .47759 .51756 .47435 .51589 Mtetra
.946 .63 .403 r
.47435 .51589 .47759 .51756 .48279 .55628 .4795 .55605 Mtetra
.92 .568 .351 r
.4795 .55605 .48279 .55628 .48832 .57793 .48502 .5783 Mtetra
.965 .871 .694 r
.48502 .5783 .48832 .57793 .49425 .56556 .49098 .56522 Mtetra
.964 .746 .559 r
.49098 .56522 .49425 .56556 .50036 .52586 .49716 .52398 Mtetra
.955 .732 .562 r
.49716 .52398 .50036 .52586 .50636 .48487 .50321 .48171 Mtetra
.916 .757 .669 r
.50321 .48171 .50636 .48487 .51214 .46948 .50901 .46618 Mtetra
.943 .579 .264 r
.50901 .46618 .51214 .46948 .5178 .49065 .51465 .48849 Mtetra
.954 .64 .397 r
.51465 .48849 .5178 .49065 .52355 .5366 .52036 .53627 Mtetra
.942 .623 .401 r
.52036 .53627 .52355 .5366 .52946 .57774 .52625 .57876 Mtetra
.767 .299 .132 r
.52625 .57876 .52946 .57774 .53544 .58454 .53223 .58544 Mtetra
.978 .77 .554 r
.53223 .58544 .53544 .58454 .54125 .55026 .53809 .5496 Mtetra
.967 .732 .532 r
.53809 .5496 .54125 .55026 .54685 .4973 .54373 .49476 Mtetra
.955 .734 .564 r
.54373 .49476 .54685 .4973 .5524 .46011 .54932 .45664 Mtetra
.142 .476 .896 r
.54932 .45664 .5524 .46011 .55824 .46207 .55518 .45919 Mtetra
.957 .632 .359 r
.55518 .45919 .55824 .46207 .56457 .50257 .56149 .50149 Mtetra
.953 .639 .398 r
.56149 .50149 .56457 .50257 .57124 .5565 .56815 .55741 Mtetra
.928 .588 .371 r
.56815 .55741 .57124 .5565 .57777 .58721 .57468 .58892 Mtetra
.989 .882 .621 r
.57468 .58892 .57777 .58721 .58363 .57158 .58055 .57226 Mtetra
.978 .743 .515 r
.58055 .57226 .58363 .57158 .58874 .51916 .58569 .51773 Mtetra
.969 .729 .521 r
.58569 .51773 .58874 .51916 .59364 .46452 .59061 .46137 Mtetra
.945 .751 .609 r
.59061 .46137 .59364 .46452 .59908 .4415 .59607 .43805 Mtetra
.936 .561 .207 r
.59607 .43805 .59908 .4415 .60555 .4632 .60256 .46099 Mtetra
.959 .639 .369 r
.60256 .46099 .60555 .4632 .61294 .5157 .60996 .5156 Mtetra
.95 .626 .379 r
.60996 .5156 .61294 .5157 .62043 .56455 .61747 .5661 Mtetra
.829 .399 .217 r
.61747 .5661 .62043 .56455 .62697 .57512 .62402 .57666 Mtetra
.991 .777 .519 r
.62402 .57666 .62697 .57512 .63207 .53867 .62912 .53853 Mtetra
.978 .734 .498 r
.62912 .53853 .63207 .53867 .6363 .4795 .63334 .47724 Mtetra
.969 .734 .528 r
.63334 .47724 .6363 .4795 .64085 .43515 .63789 .43165 Mtetra
.764 .772 .859 r
.63789 .43165 .64085 .43515 .64675 .43092 .64382 .42773 Mtetra
.955 .611 .29 r
.64382 .42773 .64675 .43092 .65426 .46715 .65136 .46555 Mtetra
.958 .631 .35 r
.65136 .46555 .65426 .46715 .66258 .51954 .65973 .51989 Mtetra
.937 .585 .328 r
.65973 .51989 .66258 .51954 .67027 .55211 .66745 .55347 Mtetra
.959 .945 .665 r
.66745 .55347 .67027 .55211 .67615 .54112 .67332 .5418 Mtetra
.988 .753 .492 r
.67332 .5418 .67615 .54112 .68028 .49346 .67743 .4923 Mtetra
.979 .735 .495 r
.67743 .4923 .68028 .49346 .68399 .4403 .68111 .43738 Mtetra
.964 .755 .572 r
.68111 .43738 .68399 .4403 .68884 .41327 .68596 .40967 Mtetra
.791 .349 0 r
.68596 .40967 .68884 .41327 .69567 .42556 .69283 .42265 Mtetra
.956 .611 .282 r
.69283 .42265 .69567 .42556 .70413 .46642 .70135 .4651 Mtetra
.952 .606 .304 r
.70135 .4651 .70413 .46642 .71277 .50736 .71005 .50752 Mtetra
.852 .401 .125 r
.71005 .50752 .71277 .50736 .7199 .51925 .7172 .51977 Mtetra
.996 .807 .534 r
.7172 .51977 .7199 .51925 .7248 .49305 .72208 .49256 Mtetra
.987 .747 .485 r
.72208 .49256 .7248 .49305 .72833 .44617 .72556 .44404 Mtetra
.98 .747 .514 r
.72556 .44404 .72833 .44617 .73224 .40778 .72944 .4044 Mtetra
.893 .798 .748 r
.72944 .4044 .73224 .40778 .73797 .39871 .73516 .39512 Mtetra
.901 .506 .084 r
.73516 .39512 .73797 .39871 .74578 .42048 .74302 .41773 Mtetra
.946 .585 .229 r
.74302 .41773 .74578 .42048 .75465 .45582 .75197 .45439 Mtetra
.921 .527 .181 r
.75197 .45439 .75465 .45582 .76281 .47911 .76019 .47859 Mtetra
.855 .98 .86 r
.76019 .47859 .76281 .47911 .76893 .47328 .76632 .47265 Mtetra
.993 .778 .511 r
.76632 .47265 .76893 .47328 .77311 .44185 .77046 .44018 Mtetra
.987 .756 .501 r
.77046 .44018 .77311 .44185 .77676 .40501 .77405 .40209 Mtetra
.969 .779 .592 r
.77405 .40209 .77676 .40501 .78156 .38413 .77882 .38048 Mtetra
0 .335 .816 r
.77882 .38048 .78156 .38413 .78837 .38848 .78565 .38495 Mtetra
.89 .492 .054 r
.78565 .38495 .78837 .38848 .79675 .41114 .79409 .40842 Mtetra
.902 .502 .092 r
.79409 .40842 .79675 .41114 .80529 .43414 .8027 .43233 Mtetra
.544 .003 0 r
.8027 .43233 .80529 .43414 .81244 .44014 .80989 .43873 Mtetra
.983 .843 .627 r
.80989 .43873 .81244 .44014 .81766 .42426 .81511 .42247 Mtetra
.99 .779 .527 r
.81511 .42247 .81766 .42426 .82176 .39667 .81916 .39399 Mtetra
.98 .782 .567 r
.81916 .39399 .82176 .39667 .82624 .37406 .8236 .37057 Mtetra
.844 .808 .815 r
.8236 .37057 .82624 .37406 .83225 .36796 .82958 .36418 Mtetra
0 0 .419 r
.82958 .36418 .83225 .36796 .83987 .37836 .83724 .37488 Mtetra
.797 .369 0 r
.83724 .37488 .83987 .37836 .84817 .39485 .8456 .39202 Mtetra
.601 .121 0 r
.8456 .39202 .84817 .39485 .85581 .40395 .8533 .40162 Mtetra
.849 .885 .865 r
.8533 .40162 .85581 .40395 .86195 .39821 .85946 .3959 Mtetra
.98 .818 .608 r
.85946 .3959 .86195 .39821 .86685 .38085 .86434 .37807 Mtetra
.978 .801 .598 r
.86434 .37807 .86685 .38085 .87159 .36244 .86903 .35903 Mtetra
.914 .818 .739 r
.86903 .35903 .87159 .36244 .87726 .35291 .87468 .34911 Mtetra
.288 .541 .917 r
.87468 .34911 .87726 .35291 .88425 .35518 .88167 .35138 Mtetra
0 0 .547 r
.88167 .35138 .88425 .35518 .89204 .36414 .88951 .36068 Mtetra
0 .14 .668 r
.88951 .36068 .89204 .36414 .89963 .37078 .89714 .3677 Mtetra
.645 .786 .949 r
.89714 .3677 .89963 .37078 .90623 .36875 .90377 .36579 Mtetra
.931 .844 .735 r
.90377 .36579 .90623 .36875 .91186 .3587 .9094 .35553 Mtetra
.627 .769 .948 r
.31704 .53853 .32047 .54114 .3258 .53983 .32238 .53721 Mtetra
.854 .777 .776 r
.32238 .53721 .3258 .53983 .33149 .53269 .32809 .52986 Mtetra
.871 .762 .739 r
.32809 .52986 .33149 .53269 .33727 .52356 .3339 .52048 Mtetra
.793 .764 .827 r
.3339 .52048 .33727 .52356 .3428 .51901 .33944 .51584 Mtetra
0 .083 .576 r
.33944 .51584 .3428 .51901 .34787 .52319 .3445 .52025 Mtetra
.902 .488 .163 r
.3445 .52025 .34787 .52319 .35261 .5343 .34921 .5318 Mtetra
.894 .474 .165 r
.34921 .5318 .35261 .5343 .35742 .5449 .354 .54281 Mtetra
0 .46 .841 r
.354 .54281 .35742 .5449 .36271 .54673 .35929 .54471 Mtetra
.897 .79 .734 r
.35929 .54471 .36271 .54673 .36857 .53671 .36518 .53436 Mtetra
.917 .754 .665 r
.36518 .53436 .36857 .53671 .37471 .52016 .37137 .51728 Mtetra
.895 .755 .699 r
.37137 .51728 .37471 .52016 .38064 .50774 .37733 .50453 Mtetra
.388 .635 .953 r
.37733 .50453 .38064 .50774 .386 .50838 .38268 .50531 Mtetra
.927 .544 .239 r
.38268 .50531 .386 .50838 .39081 .52304 .38746 .52057 Mtetra
.936 .587 .335 r
.38746 .52057 .39081 .52304 .39548 .54299 .3921 .54125 Mtetra
.893 .481 .207 r
.3921 .54125 .39548 .54299 .40055 .55442 .39715 .55306 Mtetra
.88 .855 .814 r
.39715 .55306 .40055 .55442 .40631 .54782 .40293 .54619 Mtetra
.939 .756 .629 r
.40293 .54619 .40631 .54782 .41259 .52575 .40926 .52336 Mtetra
.932 .742 .623 r
.40926 .52336 .41259 .52575 .41885 .50215 .41558 .49905 Mtetra
.871 .764 .742 r
.41558 .49905 .41885 .50215 .42462 .49306 .42137 .48981 Mtetra
.91 .504 .158 r
.42137 .48981 .42462 .49306 .42975 .506 .42647 .50338 Mtetra
.946 .618 .375 r
.42647 .50338 .42975 .506 .43451 .53441 .43118 .53287 Mtetra
.936 .601 .373 r
.43118 .53287 .43451 .53441 .43946 .56008 .43609 .5594 Mtetra
.646 .088 0 r
.43609 .5594 .43946 .56008 .44502 .5643 .44166 .56363 Mtetra
.955 .776 .621 r
.44166 .56363 .44502 .5643 .45119 .54198 .44788 .54042 Mtetra
.95 .738 .581 r
.44788 .54042 .45119 .54198 .45757 .50687 .45432 .50415 Mtetra
.935 .74 .615 r
.45432 .50415 .45757 .50687 .46365 .48222 .46044 .47888 Mtetra
0 .341 .812 r
.46044 .47888 .46365 .48222 .46919 .48516 .46599 .48223 Mtetra
.951 .622 .364 r
.46599 .48223 .46919 .48516 .47435 .51589 .4711 .51424 Mtetra
.947 .632 .406 r
.4711 .51424 .47435 .51589 .4795 .55605 .4762 .55581 Mtetra
.921 .57 .354 r
.4762 .55581 .4795 .55605 .48502 .5783 .4817 .57865 Mtetra
.966 .862 .685 r
.4817 .57865 .48502 .5783 .49098 .56522 .4877 .56483 Mtetra
.964 .743 .557 r
.4877 .56483 .49098 .56522 .49716 .52398 .49393 .52204 Mtetra
.954 .73 .56 r
.49393 .52204 .49716 .52398 .50321 .48171 .50005 .47852 Mtetra
.916 .756 .668 r
.50005 .47852 .50321 .48171 .50901 .46618 .50587 .46287 Mtetra
.945 .586 .277 r
.50587 .46287 .50901 .46618 .51465 .48849 .51149 .48634 Mtetra
.954 .641 .401 r
.51149 .48634 .51465 .48849 .52036 .53627 .51716 .53595 Mtetra
.943 .625 .404 r
.51716 .53595 .52036 .53627 .52625 .57876 .52302 .57978 Mtetra
.762 .29 .124 r
.52302 .57978 .52625 .57876 .53223 .58544 .52901 .5863 Mtetra
.978 .767 .551 r
.52901 .5863 .53223 .58544 .53809 .5496 .53491 .54886 Mtetra
.966 .731 .53 r
.53491 .54886 .53809 .5496 .54373 .49476 .54061 .49216 Mtetra
.955 .732 .562 r
.54061 .49216 .54373 .49476 .54932 .45664 .54624 .45315 Mtetra
.03 .402 .855 r
.54624 .45315 .54932 .45664 .55518 .45919 .5521 .45632 Mtetra
.958 .634 .364 r
.5521 .45632 .55518 .45919 .56149 .50149 .5584 .50045 Mtetra
.953 .641 .401 r
.5584 .50045 .56149 .50149 .56815 .55741 .56504 .55833 Mtetra
.929 .59 .372 r
.56504 .55833 .56815 .55741 .57468 .58892 .57156 .5906 Mtetra
.991 .871 .614 r
.57156 .5906 .57468 .58892 .58055 .57226 .57745 .57287 Mtetra
.977 .741 .513 r
.57745 .57287 .58055 .57226 .58569 .51773 .58261 .51622 Mtetra
.968 .728 .52 r
.58261 .51622 .58569 .51773 .59061 .46137 .58757 .45817 Mtetra
.945 .75 .608 r
.58757 .45817 .59061 .46137 .59607 .43805 .59305 .43459 Mtetra
.939 .569 .222 r
.59305 .43459 .59607 .43805 .60256 .46099 .59956 .45881 Mtetra
.959 .64 .372 r
.59956 .45881 .60256 .46099 .60996 .5156 .60697 .51553 Mtetra
.95 .627 .381 r
.60697 .51553 .60996 .5156 .61747 .5661 .61449 .56764 Mtetra
.827 .397 .215 r
.61449 .56764 .61747 .5661 .62402 .57666 .62105 .57816 Mtetra
.99 .773 .517 r
.62105 .57816 .62402 .57666 .62912 .53853 .62614 .53832 Mtetra
.978 .733 .496 r
.62614 .53832 .62912 .53853 .63334 .47724 .63036 .47491 Mtetra
.969 .733 .526 r
.63036 .47491 .63334 .47724 .63789 .43165 .63493 .42813 Mtetra
.75 .768 .867 r
.63493 .42813 .63789 .43165 .64382 .42773 .64088 .42453 Mtetra
.956 .614 .296 r
.64088 .42453 .64382 .42773 .65136 .46555 .64846 .46397 Mtetra
.959 .633 .353 r
.64846 .46397 .65136 .46555 .65973 .51989 .65687 .52025 Mtetra
.938 .588 .331 r
.65687 .52025 .65973 .51989 .66745 .55347 .66461 .55481 Mtetra
.967 .936 .657 r
.66461 .55481 .66745 .55347 .67332 .5418 .67048 .54244 Mtetra
.987 .75 .49 r
.67048 .54244 .67332 .5418 .67743 .4923 .67456 .49107 Mtetra
.979 .734 .493 r
.67456 .49107 .67743 .4923 .68111 .43738 .67822 .4344 Mtetra
.964 .753 .57 r
.67822 .4344 .68111 .43738 .68596 .40967 .68307 .40605 Mtetra
.81 .372 0 r
.68307 .40605 .68596 .40967 .69283 .42265 .68997 .41974 Mtetra
.957 .613 .287 r
.68997 .41974 .69283 .42265 .70135 .4651 .69855 .46378 Mtetra
.953 .608 .307 r
.69855 .46378 .70135 .4651 .71005 .50752 .70731 .50767 Mtetra
.855 .407 .13 r
.70731 .50767 .71005 .50752 .7172 .51977 .71449 .52026 Mtetra
.996 .802 .531 r
.71449 .52026 .7172 .51977 .72208 .49256 .71934 .49203 Mtetra
.987 .745 .483 r
.71934 .49203 .72208 .49256 .72556 .44404 .72278 .44185 Mtetra
.98 .745 .512 r
.72278 .44185 .72556 .44404 .72944 .4044 .72662 .40099 Mtetra
.894 .797 .745 r
.72662 .40099 .72944 .4044 .73516 .39512 .73235 .39153 Mtetra
.906 .514 .096 r
.73235 .39153 .73516 .39512 .74302 .41773 .74026 .41498 Mtetra
.947 .588 .235 r
.74026 .41498 .74302 .41773 .75197 .45439 .74927 .45295 Mtetra
.923 .532 .189 r
.74927 .45295 .75197 .45439 .76019 .47859 .75755 .47806 Mtetra
.86 .978 .857 r
.75755 .47806 .76019 .47859 .76632 .47265 .7637 .47198 Mtetra
.992 .775 .508 r
.7637 .47198 .76632 .47265 .77046 .44018 .76779 .43848 Mtetra
.986 .753 .498 r
.76779 .43848 .77046 .44018 .77405 .40209 .77134 .39914 Mtetra
.97 .776 .587 r
.77134 .39914 .77405 .40209 .77882 .38048 .77608 .37681 Mtetra
0 .322 .807 r
.77608 .37681 .77882 .38048 .78565 .38495 .78292 .38141 Mtetra
.895 .5 .065 r
.78292 .38141 .78565 .38495 .79409 .40842 .79142 .40568 Mtetra
.906 .509 .102 r
.79142 .40568 .79409 .40842 .8027 .43233 .8001 .43051 Mtetra
.572 .035 0 r
.8001 .43051 .8027 .43233 .80989 .43873 .80733 .4373 Mtetra
.983 .84 .622 r
.80733 .4373 .80989 .43873 .81511 .42247 .81254 .42065 Mtetra
.99 .777 .523 r
.81254 .42065 .81511 .42247 .81916 .39399 .81655 .39129 Mtetra
.98 .78 .561 r
.81655 .39129 .81916 .39399 .8236 .37057 .82094 .36707 Mtetra
.851 .808 .808 r
.82094 .36707 .8236 .37057 .82958 .36418 .82691 .36038 Mtetra
.584 .145 0 r
.82691 .36038 .82958 .36418 .83724 .37488 .8346 .37139 Mtetra
.807 .383 0 r
.8346 .37139 .83724 .37488 .8456 .39202 .84302 .38917 Mtetra
.626 .148 0 r
.84302 .38917 .8456 .39202 .8533 .40162 .85077 .39927 Mtetra
.848 .884 .865 r
.85077 .39927 .8533 .40162 .85946 .3959 .85695 .39357 Mtetra
.981 .815 .603 r
.85695 .39357 .85946 .3959 .86434 .37807 .86181 .37527 Mtetra
.979 .799 .592 r
.86181 .37527 .86434 .37807 .86903 .35903 .86646 .35561 Mtetra
.918 .817 .731 r
.86646 .35561 .86903 .35903 .87468 .34911 .87208 .34529 Mtetra
.286 .54 .917 r
.87208 .34529 .87468 .34911 .88167 .35138 .87909 .34757 Mtetra
0 0 .527 r
.87909 .34757 .88167 .35138 .88951 .36068 .88697 .35721 Mtetra
0 .111 .644 r
.88697 .35721 .88951 .36068 .89714 .3677 .89465 .3646 Mtetra
.636 .782 .951 r
.89465 .3646 .89714 .3677 .90377 .36579 .9013 .36281 Mtetra
.933 .843 .731 r
.9013 .36281 .90377 .36579 .9094 .35553 .90693 .35234 Mtetra
.628 .769 .948 r
.31359 .53591 .31704 .53853 .32238 .53721 .31894 .53457 Mtetra
.856 .776 .772 r
.31894 .53457 .32238 .53721 .32809 .52986 .32467 .52701 Mtetra
.873 .761 .736 r
.32467 .52701 .32809 .52986 .3339 .52048 .33052 .51738 Mtetra
.795 .764 .825 r
.33052 .51738 .3339 .52048 .33944 .51584 .33608 .51266 Mtetra
0 .044 .536 r
.33608 .51266 .33944 .51584 .3445 .52025 .34112 .51729 Mtetra
.907 .498 .179 r
.34112 .51729 .3445 .52025 .34921 .5318 .3458 .52929 Mtetra
.899 .484 .18 r
.3458 .52929 .34921 .5318 .354 .54281 .35056 .54069 Mtetra
0 .446 .83 r
.35056 .54069 .354 .54281 .35929 .54471 .35585 .54266 Mtetra
.899 .788 .73 r
.35585 .54266 .35929 .54471 .36518 .53436 .36178 .53198 Mtetra
.918 .752 .662 r
.36178 .53198 .36518 .53436 .37137 .51728 .36802 .51439 Mtetra
.896 .754 .696 r
.36802 .51439 .37137 .51728 .37733 .50453 .37401 .5013 Mtetra
.365 .623 .952 r
.37401 .5013 .37733 .50453 .38268 .50531 .37936 .50222 Mtetra
.929 .551 .252 r
.37936 .50222 .38268 .50531 .38746 .52057 .3841 .51809 Mtetra
.937 .591 .342 r
.3841 .51809 .38746 .52057 .3921 .54125 .38869 .5395 Mtetra
.897 .488 .216 r
.38869 .5395 .3921 .54125 .39715 .55306 .39372 .55169 Mtetra
.884 .852 .806 r
.39372 .55169 .39715 .55306 .40293 .54619 .39953 .54454 Mtetra
.939 .754 .626 r
.39953 .54454 .40293 .54619 .40926 .52336 .40592 .52094 Mtetra
.932 .741 .621 r
.40592 .52094 .40926 .52336 .41558 .49905 .4123 .49592 Mtetra
.872 .764 .74 r
.4123 .49592 .41558 .49905 .42137 .48981 .4181 .48656 Mtetra
.916 .516 .177 r
.4181 .48656 .42137 .48981 .42647 .50338 .42317 .50076 Mtetra
.947 .621 .38 r
.42317 .50076 .42647 .50338 .43118 .53287 .42783 .53132 Mtetra
.937 .604 .377 r
.42783 .53132 .43118 .53287 .43609 .5594 .4327 .55871 Mtetra
.644 .086 0 r
.4327 .55871 .43609 .5594 .44166 .56363 .43827 .56294 Mtetra
.955 .773 .617 r
.43827 .56294 .44166 .56363 .44788 .54042 .44455 .53883 Mtetra
.95 .736 .579 r
.44455 .53883 .44788 .54042 .45432 .50415 .45106 .50139 Mtetra
.935 .739 .613 r
.45106 .50139 .45432 .50415 .46044 .47888 .45723 .47552 Mtetra
0 .276 .763 r
.45723 .47552 .46044 .47888 .46599 .48223 .46277 .47929 Mtetra
.952 .625 .37 r
.46277 .47929 .46599 .48223 .4711 .51424 .46783 .51259 Mtetra
.947 .634 .409 r
.46783 .51259 .4711 .51424 .4762 .55581 .47288 .55558 Mtetra
.922 .573 .357 r
.47288 .55558 .4762 .55581 .4817 .57865 .47836 .57898 Mtetra
.967 .854 .677 r
.47836 .57898 .4817 .57865 .4877 .56483 .48439 .56439 Mtetra
.963 .741 .555 r
.48439 .56439 .4877 .56483 .49393 .52204 .4907 .52005 Mtetra
.954 .729 .559 r
.4907 .52005 .49393 .52204 .50005 .47852 .49687 .47529 Mtetra
.916 .755 .668 r
.49687 .47529 .50005 .47852 .50587 .46287 .50271 .45955 Mtetra
.947 .592 .288 r
.50271 .45955 .50587 .46287 .51149 .48634 .50832 .4842 Mtetra
.954 .643 .404 r
.50832 .4842 .51149 .48634 .51716 .53595 .51394 .53565 Mtetra
.943 .627 .406 r
.51394 .53565 .51716 .53595 .52302 .57978 .51977 .58079 Mtetra
.755 .28 .114 r
.51977 .58079 .52302 .57978 .52901 .5863 .52576 .58711 Mtetra
.977 .763 .549 r
.52576 .58711 .52901 .5863 .53491 .54886 .53171 .54806 Mtetra
.966 .729 .529 r
.53171 .54806 .53491 .54886 .54061 .49216 .53747 .4895 Mtetra
.955 .731 .56 r
.53747 .4895 .54061 .49216 .54624 .45315 .54313 .44964 Mtetra
0 .317 .799 r
.54313 .44964 .54624 .45315 .5521 .45632 .549 .45346 Mtetra
.958 .637 .368 r
.549 .45346 .5521 .45632 .5584 .50045 .55529 .49942 Mtetra
.954 .642 .403 r
.55529 .49942 .5584 .50045 .56504 .55833 .56191 .55926 Mtetra
.929 .591 .374 r
.56191 .55926 .56504 .55833 .57156 .5906 .56843 .59226 Mtetra
.991 .861 .607 r
.56843 .59226 .57156 .5906 .57745 .57287 .57433 .57342 Mtetra
.976 .739 .512 r
.57433 .57342 .57745 .57287 .58261 .51622 .57953 .51465 Mtetra
.968 .726 .518 r
.57953 .51465 .58261 .51622 .58757 .45817 .58451 .45493 Mtetra
.945 .749 .607 r
.58451 .45493 .58757 .45817 .59305 .43459 .59002 .43112 Mtetra
.943 .577 .236 r
.59002 .43112 .59305 .43459 .59956 .45881 .59654 .45664 Mtetra
.96 .642 .375 r
.59654 .45664 .59956 .45881 .60697 .51553 .60396 .51548 Mtetra
.951 .629 .383 r
.60396 .51548 .60697 .51553 .61449 .56764 .61149 .56918 Mtetra
.826 .393 .212 r
.61149 .56918 .61449 .56764 .62105 .57816 .61805 .57961 Mtetra
.989 .77 .515 r
.61805 .57961 .62105 .57816 .62614 .53832 .62315 .53805 Mtetra
.977 .731 .495 r
.62315 .53805 .62614 .53832 .63036 .47491 .62737 .47251 Mtetra
.969 .732 .524 r
.62737 .47251 .63036 .47491 .63493 .42813 .63195 .42457 Mtetra
.734 .763 .876 r
.63195 .42457 .63493 .42813 .64088 .42453 .63792 .42134 Mtetra
.957 .618 .303 r
.63792 .42134 .64088 .42453 .64846 .46397 .64553 .46241 Mtetra
.959 .634 .356 r
.64553 .46241 .64846 .46397 .65687 .52025 .65398 .52062 Mtetra
.939 .59 .333 r
.65398 .52062 .65687 .52025 .66461 .55481 .66175 .55613 Mtetra
.974 .926 .648 r
.66175 .55613 .66461 .55481 .67048 .54244 .66762 .54302 Mtetra
.986 .748 .488 r
.66762 .54302 .67048 .54244 .67456 .49107 .67168 .48978 Mtetra
.979 .732 .492 r
.67168 .48978 .67456 .49107 .67822 .4344 .67531 .43138 Mtetra
.964 .752 .567 r
.67531 .43138 .67822 .4344 .68307 .40605 .68016 .40242 Mtetra
.826 .393 0 r
.68016 .40242 .68307 .40605 .68997 .41974 .6871 .41683 Mtetra
.957 .616 .292 r
.6871 .41683 .68997 .41974 .69855 .46378 .69573 .46246 Mtetra
.953 .61 .311 r
.69573 .46246 .69855 .46378 .70731 .50767 .70455 .50781 Mtetra
.858 .413 .135 r
.70455 .50781 .70731 .50767 .71449 .52026 .71175 .52072 Mtetra
.995 .798 .527 r
.71175 .52072 .71449 .52026 .71934 .49203 .71658 .49144 Mtetra
.986 .743 .481 r
.71658 .49144 .71934 .49203 .72278 .44185 .71998 .43963 Mtetra
.979 .743 .509 r
.71998 .43963 .72278 .44185 .72662 .40099 .72379 .39756 Mtetra
.896 .796 .742 r
.72379 .39756 .72662 .40099 .73235 .39153 .72953 .38793 Mtetra
.911 .522 .108 r
.72953 .38793 .73235 .39153 .74026 .41498 .73748 .41223 Mtetra
.948 .592 .241 r
.73748 .41223 .74026 .41498 .74927 .45295 .74656 .45151 Mtetra
.926 .538 .195 r
.74656 .45151 .74927 .45295 .75755 .47806 .7549 .4775 Mtetra
.866 .976 .853 r
.7549 .4775 .75755 .47806 .7637 .47198 .76105 .47129 Mtetra
.992 .773 .505 r
.76105 .47129 .7637 .47198 .76779 .43848 .76511 .43673 Mtetra
.986 .751 .495 r
.76511 .43673 .76779 .43848 .77134 .39914 .7686 .39616 Mtetra
.971 .774 .582 r
.7686 .39616 .77134 .39914 .77608 .37681 .77332 .37312 Mtetra
0 .309 .798 r
.77332 .37312 .77608 .37681 .78292 .38141 .78017 .37785 Mtetra
.899 .507 .076 r
.78017 .37785 .78292 .38141 .79142 .40568 .78874 .40292 Mtetra
.91 .516 .112 r
.78874 .40292 .79142 .40568 .8001 .43051 .79748 .42866 Mtetra
.597 .064 0 r
.79748 .42866 .8001 .43051 .80733 .4373 .80476 .43585 Mtetra
.984 .838 .618 r
.80476 .43585 .80733 .4373 .81254 .42065 .80996 .41881 Mtetra
.99 .774 .519 r
.80996 .41881 .81254 .42065 .81655 .39129 .81392 .38857 Mtetra
.981 .777 .556 r
.81392 .38857 .81655 .39129 .82094 .36707 .81827 .36355 Mtetra
.857 .809 .801 r
.81827 .36355 .82094 .36707 .82691 .36038 .82423 .35657 Mtetra
.6 .161 0 r
.82423 .35657 .82691 .36038 .8346 .37139 .83195 .36789 Mtetra
.817 .395 0 r
.83195 .36789 .8346 .37139 .84302 .38917 .84043 .3863 Mtetra
.648 .173 0 r
.84043 .3863 .84302 .38917 .85077 .39927 .84823 .3969 Mtetra
.847 .884 .866 r
.84823 .3969 .85077 .39927 .85695 .39357 .85443 .39121 Mtetra
.982 .813 .599 r
.85443 .39121 .85695 .39357 .86181 .37527 .85927 .37246 Mtetra
.98 .796 .586 r
.85927 .37246 .86181 .37527 .86646 .35561 .86388 .35218 Mtetra
.923 .816 .723 r
.86388 .35218 .86646 .35561 .87208 .34529 .86947 .34145 Mtetra
.285 .539 .917 r
.86947 .34145 .87208 .34529 .87909 .34757 .87649 .34375 Mtetra
0 0 .508 r
.87649 .34375 .87909 .34757 .88697 .35721 .88441 .35371 Mtetra
0 .084 .62 r
.88441 .35371 .88697 .35721 .89465 .3646 .89214 .36147 Mtetra
.626 .777 .953 r
.89214 .36147 .89465 .3646 .9013 .36281 .89882 .3598 Mtetra
.935 .841 .727 r
.89882 .3598 .9013 .36281 .90693 .35234 .90445 .34914 Mtetra
.629 .769 .947 r
.31013 .53326 .31359 .53591 .31894 .53457 .31549 .53191 Mtetra
.858 .775 .768 r
.31549 .53191 .31894 .53457 .32467 .52701 .32125 .52415 Mtetra
.874 .76 .733 r
.32125 .52415 .32467 .52701 .33052 .51738 .32713 .51426 Mtetra
.796 .764 .824 r
.32713 .51426 .33052 .51738 .33608 .51266 .33269 .50947 Mtetra
.502 0 0 r
.33269 .50947 .33608 .51266 .34112 .51729 .33772 .51432 Mtetra
.911 .508 .194 r
.33772 .51432 .34112 .51729 .3458 .52929 .34237 .52675 Mtetra
.903 .493 .192 r
.34237 .52675 .3458 .52929 .35056 .54069 .34711 .53854 Mtetra
0 .435 .823 r
.34711 .53854 .35056 .54069 .35585 .54266 .3524 .54058 Mtetra
.9 .785 .725 r
.3524 .54058 .35585 .54266 .36178 .53198 .35836 .52958 Mtetra
.918 .751 .658 r
.35836 .52958 .36178 .53198 .36802 .51439 .36465 .51147 Mtetra
.897 .753 .693 r
.36465 .51147 .36802 .51439 .37401 .5013 .37067 .49807 Mtetra
.34 .611 .949 r
.37067 .49807 .37401 .5013 .37936 .50222 .37602 .49913 Mtetra
.931 .557 .263 r
.37602 .49913 .37936 .50222 .3841 .51809 .38073 .51559 Mtetra
.938 .594 .348 r
.38073 .51559 .3841 .51809 .38869 .5395 .38527 .53772 Mtetra
.9 .495 .224 r
.38527 .53772 .38869 .5395 .39372 .55169 .39028 .55026 Mtetra
.887 .847 .799 r
.39028 .55026 .39372 .55169 .39953 .54454 .39612 .54283 Mtetra
.939 .752 .623 r
.39612 .54283 .39953 .54454 .40592 .52094 .40257 .51848 Mtetra
.933 .739 .618 r
.40257 .51848 .40592 .52094 .4123 .49592 .409 .49277 Mtetra
.873 .763 .738 r
.409 .49277 .4123 .49592 .4181 .48656 .41482 .4833 Mtetra
.92 .526 .194 r
.41482 .4833 .4181 .48656 .42317 .50076 .41987 .49812 Mtetra
.947 .623 .384 r
.41987 .49812 .42317 .50076 .42783 .53132 .42447 .52975 Mtetra
.937 .607 .381 r
.42447 .52975 .42783 .53132 .4327 .55871 .4293 .55796 Mtetra
.639 .078 0 r
.4293 .55796 .4327 .55871 .43827 .56294 .43487 .56217 Mtetra
.955 .769 .613 r
.43487 .56217 .43827 .56294 .44455 .53883 .44121 .53716 Mtetra
.95 .734 .577 r
.44121 .53716 .44455 .53883 .45106 .50139 .44779 .49858 Mtetra
.935 .738 .611 r
.44779 .49858 .45106 .50139 .45723 .47552 .454 .47214 Mtetra
0 .209 .707 r
.454 .47214 .45723 .47552 .46277 .47929 .45953 .47635 Mtetra
.952 .628 .375 r
.45953 .47635 .46277 .47929 .46783 .51259 .46455 .51092 Mtetra
.947 .636 .411 r
.46455 .51092 .46783 .51259 .47288 .55558 .46954 .55529 Mtetra
.923 .576 .359 r
.46954 .55529 .47288 .55558 .47836 .57898 .475 .57921 Mtetra
.967 .845 .669 r
.475 .57921 .47836 .57898 .48439 .56439 .48107 .56385 Mtetra
.962 .739 .553 r
.48107 .56385 .48439 .56439 .4907 .52005 .48745 .51798 Mtetra
.954 .728 .557 r
.48745 .51798 .4907 .52005 .49687 .47529 .49369 .47202 Mtetra
.915 .755 .667 r
.49369 .47202 .49687 .47529 .50271 .45955 .49955 .45623 Mtetra
.948 .598 .298 r
.49955 .45623 .50271 .45955 .50832 .4842 .50513 .48206 Mtetra
.954 .644 .406 r
.50513 .48206 .50832 .4842 .51394 .53565 .5107 .53531 Mtetra
.944 .628 .407 r
.5107 .53531 .51394 .53565 .51977 .58079 .51649 .58172 Mtetra
.747 .265 .096 r
.51649 .58172 .51977 .58079 .52576 .58711 .5225 .5878 Mtetra
.976 .759 .547 r
.5225 .5878 .52576 .58711 .53171 .54806 .52849 .54714 Mtetra
.965 .727 .528 r
.52849 .54714 .53171 .54806 .53747 .4895 .53431 .48678 Mtetra
.955 .73 .559 r
.53431 .48678 .53747 .4895 .54313 .44964 .54002 .4461 Mtetra
0 .225 .729 r
.54002 .4461 .54313 .44964 .549 .45346 .5459 .4506 Mtetra
.958 .639 .373 r
.5459 .4506 .549 .45346 .55529 .49942 .55216 .49839 Mtetra
.954 .643 .405 r
.55216 .49839 .55529 .49942 .56191 .55926 .55876 .56014 Mtetra
.93 .593 .375 r
.55876 .56014 .56191 .55926 .56843 .59226 .56527 .5938 Mtetra
.991 .851 .601 r
.56527 .5938 .56843 .59226 .57433 .57342 .57119 .57383 Mtetra
.976 .736 .511 r
.57119 .57383 .57433 .57342 .57953 .51465 .57642 .51296 Mtetra
.967 .725 .517 r
.57642 .51296 .57953 .51465 .58451 .45493 .58144 .45164 Mtetra
.945 .748 .607 r
.58144 .45164 .58451 .45493 .59002 .43112 .58698 .42765 Mtetra
.945 .584 .248 r
.58698 .42765 .59002 .43112 .59654 .45664 .59351 .45448 Mtetra
.96 .644 .378 r
.59351 .45448 .59654 .45664 .60396 .51548 .60093 .51539 Mtetra
.951 .63 .385 r
.60093 .51539 .60396 .51548 .61149 .56918 .60846 .57065 Mtetra
.824 .389 .205 r
.60846 .57065 .61149 .56918 .61805 .57961 .61503 .58094 Mtetra
.988 .766 .513 r
.61503 .58094 .61805 .57961 .62315 .53805 .62013 .53764 Mtetra
.977 .729 .494 r
.62013 .53764 .62315 .53805 .62737 .47251 .62436 .47003 Mtetra
.969 .73 .523 r
.62436 .47003 .62737 .47251 .63195 .42457 .62896 .42098 Mtetra
.714 .756 .886 r
.62896 .42098 .63195 .42457 .63792 .42134 .63496 .41815 Mtetra
.958 .62 .308 r
.63496 .41815 .63792 .42134 .64553 .46241 .6426 .46084 Mtetra
.959 .636 .359 r
.6426 .46084 .64553 .46241 .65398 .52062 .65108 .52094 Mtetra
.94 .592 .334 r
.65108 .52094 .65398 .52062 .66175 .55613 .65887 .55735 Mtetra
.98 .915 .642 r
.65887 .55735 .66175 .55613 .66762 .54302 .66473 .54348 Mtetra
.986 .745 .487 r
.66473 .54348 .66762 .54302 .67168 .48978 .66877 .48838 Mtetra
.978 .73 .49 r
.66877 .48838 .67168 .48978 .67531 .43138 .67239 .4283 Mtetra
.964 .75 .566 r
.67239 .4283 .67531 .43138 .68016 .40242 .67725 .39877 Mtetra
.84 .412 0 r
.67725 .39877 .68016 .40242 .6871 .41683 .68422 .41393 Mtetra
.958 .619 .296 r
.68422 .41393 .6871 .41683 .69573 .46246 .6929 .46112 Mtetra
.954 .613 .313 r
.6929 .46112 .69573 .46246 .70455 .50781 .70177 .50789 Mtetra
.861 .417 .136 r
.70177 .50789 .70455 .50781 .71175 .52072 .70899 .52108 Mtetra
.995 .794 .525 r
.70899 .52108 .71175 .52072 .71658 .49144 .7138 .49075 Mtetra
.986 .741 .479 r
.7138 .49075 .71658 .49144 .71998 .43963 .71716 .43733 Mtetra
.979 .742 .507 r
.71716 .43733 .71998 .43963 .72379 .39756 .72095 .39409 Mtetra
.897 .795 .739 r
.72095 .39409 .72379 .39756 .72953 .38793 .72669 .38431 Mtetra
.915 .529 .119 r
.72669 .38431 .72953 .38793 .73748 .41223 .73469 .40946 Mtetra
.95 .595 .246 r
.73469 .40946 .73748 .41223 .74656 .45151 .74383 .45002 Mtetra
.928 .542 .2 r
.74383 .45002 .74656 .45151 .7549 .4775 .75222 .47687 Mtetra
.873 .972 .85 r
.75222 .47687 .7549 .4775 .76105 .47129 .75839 .47051 Mtetra
.991 .77 .503 r
.75839 .47051 .76105 .47129 .76511 .43673 .76242 .43492 Mtetra
.986 .749 .493 r
.76242 .43492 .76511 .43673 .7686 .39616 .76586 .39314 Mtetra
.971 .772 .578 r
.76586 .39314 .7686 .39616 .77332 .37312 .77055 .36942 Mtetra
0 .295 .789 r
.77055 .36942 .77332 .37312 .78017 .37785 .77742 .37429 Mtetra
.903 .513 .086 r
.77742 .37429 .78017 .37785 .78874 .40292 .78604 .40014 Mtetra
.913 .522 .12 r
.78604 .40014 .78874 .40292 .79748 .42866 .79484 .42677 Mtetra
.616 .087 0 r
.79484 .42677 .79748 .42866 .80476 .43585 .80216 .43433 Mtetra
.984 .834 .615 r
.80216 .43433 .80476 .43585 .80996 .41881 .80736 .4169 Mtetra
.989 .771 .516 r
.80736 .4169 .80996 .41881 .81392 .38857 .81128 .38581 Mtetra
.981 .775 .552 r
.81128 .38581 .81392 .38857 .81827 .36355 .81558 .36001 Mtetra
.863 .809 .795 r
.81558 .36001 .81827 .36355 .82423 .35657 .82154 .35274 Mtetra
.614 .176 0 r
.82154 .35274 .82423 .35657 .83195 .36789 .82928 .36436 Mtetra
.825 .405 0 r
.82928 .36436 .83195 .36789 .84043 .3863 .83782 .38338 Mtetra
.667 .195 0 r
.83782 .38338 .84043 .3863 .84823 .3969 .84568 .39447 Mtetra
.845 .881 .866 r
.84568 .39447 .84823 .3969 .85443 .39121 .8519 .38881 Mtetra
.982 .81 .595 r
.8519 .38881 .85443 .39121 .85927 .37246 .85671 .3696 Mtetra
.98 .794 .581 r
.85671 .3696 .85927 .37246 .86388 .35218 .86129 .34872 Mtetra
.926 .815 .716 r
.86129 .34872 .86388 .35218 .86947 .34145 .86686 .3376 Mtetra
.284 .539 .917 r
.86686 .3376 .86947 .34145 .87649 .34375 .87388 .3399 Mtetra
0 0 .49 r
.87388 .3399 .87649 .34375 .88441 .35371 .88184 .35019 Mtetra
0 .058 .597 r
.88184 .35019 .88441 .35371 .89214 .36147 .88962 .35831 Mtetra
.616 .771 .954 r
.88962 .35831 .89214 .36147 .89882 .3598 .89633 .35676 Mtetra
.937 .84 .723 r
.89633 .35676 .89882 .3598 .90445 .34914 .90195 .3459 Mtetra
.63 .768 .946 r
.30666 .53059 .31013 .53326 .31549 .53191 .31203 .52922 Mtetra
.86 .774 .765 r
.31203 .52922 .31549 .53191 .32125 .52415 .31781 .52126 Mtetra
.876 .759 .73 r
.31781 .52126 .32125 .52415 .32713 .51426 .32372 .51113 Mtetra
.798 .764 .822 r
.32372 .51113 .32713 .51426 .33269 .50947 .3293 .50627 Mtetra
.538 .027 0 r
.3293 .50627 .33269 .50947 .33772 .51432 .33432 .51134 Mtetra
.914 .516 .207 r
.33432 .51134 .33772 .51432 .34237 .52675 .33893 .52419 Mtetra
.906 .5 .204 r
.33893 .52419 .34237 .52675 .34711 .53854 .34364 .53636 Mtetra
0 .425 .817 r
.34364 .53636 .34711 .53854 .3524 .54058 .34893 .53847 Mtetra
.901 .783 .721 r
.34893 .53847 .3524 .54058 .35836 .52958 .35493 .52713 Mtetra
.919 .749 .656 r
.35493 .52713 .35836 .52958 .36465 .51147 .36127 .50853 Mtetra
.898 .752 .69 r
.36127 .50853 .36465 .51147 .37067 .49807 .36733 .49482 Mtetra
.314 .597 .946 r
.36733 .49482 .37067 .49807 .37602 .49913 .37267 .49602 Mtetra
.933 .563 .274 r
.37267 .49602 .37602 .49913 .38073 .51559 .37734 .51306 Mtetra
.939 .598 .353 r
.37734 .51306 .38073 .51559 .38527 .53772 .38184 .53589 Mtetra
.902 .501 .231 r
.38184 .53589 .38527 .53772 .39028 .55026 .38683 .54878 Mtetra
.889 .842 .792 r
.38683 .54878 .39028 .55026 .39612 .54283 .39269 .54106 Mtetra
.939 .75 .62 r
.39269 .54106 .39612 .54283 .40257 .51848 .3992 .51598 Mtetra
.933 .738 .616 r
.3992 .51598 .40257 .51848 .409 .49277 .40569 .4896 Mtetra
.873 .762 .737 r
.40569 .4896 .409 .49277 .41482 .4833 .41153 .48003 Mtetra
.924 .535 .21 r
.41153 .48003 .41482 .4833 .41987 .49812 .41654 .49547 Mtetra
.947 .626 .388 r
.41654 .49547 .41987 .49812 .42447 .52975 .42109 .52814 Mtetra
.938 .609 .384 r
.42109 .52814 .42447 .52975 .4293 .55796 .42587 .55715 Mtetra
.631 .068 0 r
.42587 .55715 .4293 .55796 .43487 .56217 .43145 .56133 Mtetra
.954 .766 .61 r
.43145 .56133 .43487 .56217 .44121 .53716 .43785 .53543 Mtetra
.95 .733 .575 r
.43785 .53543 .44121 .53716 .44779 .49858 .44451 .49573 Mtetra
.936 .737 .609 r
.44451 .49573 .44779 .49858 .454 .47214 .45076 .46875 Mtetra
0 .14 .646 r
.45076 .46875 .454 .47214 .45953 .47635 .45629 .4734 Mtetra
.952 .63 .379 r
.45629 .4734 .45953 .47635 .46455 .51092 .46125 .50923 Mtetra
.948 .637 .413 r
.46125 .50923 .46455 .51092 .46954 .55529 .46618 .55495 Mtetra
.924 .578 .36 r
.46618 .55495 .46954 .55529 .475 .57921 .47162 .57936 Mtetra
.967 .837 .662 r
.47162 .57936 .475 .57921 .48107 .56385 .47773 .56321 Mtetra
.962 .737 .552 r
.47773 .56321 .48107 .56385 .48745 .51798 .48418 .51583 Mtetra
.954 .726 .556 r
.48418 .51583 .48745 .51798 .49369 .47202 .49049 .46872 Mtetra
.915 .754 .667 r
.49049 .46872 .49369 .47202 .49955 .45623 .49637 .4529 Mtetra
.95 .602 .308 r
.49637 .4529 .49955 .45623 .50513 .48206 .50192 .47992 Mtetra
.954 .646 .409 r
.50192 .47992 .50513 .48206 .5107 .53531 .50744 .53493 Mtetra
.945 .63 .409 r
.50744 .53493 .5107 .53531 .51649 .58172 .5132 .58257 Mtetra
.737 .247 .075 r
.5132 .58257 .51649 .58172 .5225 .5878 .51921 .58838 Mtetra
.975 .756 .545 r
.51921 .58838 .5225 .5878 .52849 .54714 .52526 .54611 Mtetra
.965 .726 .527 r
.52526 .54611 .52849 .54714 .53431 .48678 .53114 .48398 Mtetra
.954 .729 .558 r
.53114 .48398 .53431 .48678 .54002 .4461 .5369 .44254 Mtetra
0 .131 .648 r
.5369 .44254 .54002 .4461 .5459 .4506 .54278 .44774 Mtetra
.959 .64 .376 r
.54278 .44774 .5459 .4506 .55216 .49839 .54902 .49733 Mtetra
.954 .645 .406 r
.54902 .49733 .55216 .49839 .55876 .56014 .55559 .56095 Mtetra
.931 .595 .375 r
.55559 .56095 .55876 .56014 .56527 .5938 .56208 .59524 Mtetra
.991 .841 .596 r
.56208 .59524 .56527 .5938 .57119 .57383 .56802 .57411 Mtetra
.975 .734 .51 r
.56802 .57411 .57119 .57383 .57642 .51296 .5733 .51117 Mtetra
.967 .724 .516 r
.5733 .51117 .57642 .51296 .58144 .45164 .57836 .44829 Mtetra
.944 .747 .606 r
.57836 .44829 .58144 .45164 .58698 .42765 .58392 .42416 Mtetra
.948 .59 .259 r
.58392 .42416 .58698 .42765 .59351 .45448 .59046 .45232 Mtetra
.96 .645 .38 r
.59046 .45232 .59351 .45448 .60093 .51539 .59789 .51528 Mtetra
.952 .632 .386 r
.59789 .51528 .60093 .51539 .60846 .57065 .60541 .57202 Mtetra
.822 .383 .196 r
.60541 .57202 .60846 .57065 .61503 .58094 .61198 .58214 Mtetra
.987 .762 .512 r
.61198 .58214 .61503 .58094 .62013 .53764 .6171 .5371 Mtetra
.976 .728 .493 r
.6171 .5371 .62013 .53764 .62436 .47003 .62134 .46747 Mtetra
.968 .729 .522 r
.62134 .46747 .62436 .47003 .62896 .42098 .62595 .41737 Mtetra
.691 .749 .896 r
.62595 .41737 .62896 .42098 .63496 .41815 .63198 .41495 Mtetra
.959 .623 .313 r
.63198 .41495 .63496 .41815 .6426 .46084 .63965 .45926 Mtetra
.96 .637 .361 r
.63965 .45926 .6426 .46084 .65108 .52094 .64815 .52121 Mtetra
.941 .594 .335 r
.64815 .52121 .65108 .52094 .65887 .55735 .65596 .55848 Mtetra
.984 .904 .636 r
.65596 .55848 .65887 .55735 .66473 .54348 .66182 .54382 Mtetra
.985 .743 .486 r
.66182 .54382 .66473 .54348 .66877 .48838 .66584 .48688 Mtetra
.978 .729 .489 r
.66584 .48688 .66877 .48838 .67239 .4283 .66946 .42517 Mtetra
.964 .749 .564 r
.66946 .42517 .67239 .4283 .67725 .39877 .67432 .3951 Mtetra
.853 .43 0 r
.67432 .3951 .67725 .39877 .68422 .41393 .68132 .41101 Mtetra
.959 .621 .3 r
.68132 .41101 .68422 .41393 .6929 .46112 .69005 .45975 Mtetra
.955 .615 .316 r
.69005 .45975 .6929 .46112 .70177 .50789 .69896 .5079 Mtetra
.863 .42 .136 r
.69896 .5079 .70177 .50789 .70899 .52108 .7062 .52134 Mtetra
.994 .79 .523 r
.7062 .52134 .70899 .52108 .7138 .49075 .711 .48997 Mtetra
.985 .739 .478 r
.711 .48997 .7138 .49075 .71716 .43733 .71432 .43496 Mtetra
.979 .74 .505 r
.71432 .43496 .71716 .43733 .72095 .39409 .71809 .39059 Mtetra
.898 .794 .737 r
.71809 .39059 .72095 .39409 .72669 .38431 .72384 .38069 Mtetra
.918 .535 .129 r
.72384 .38069 .72669 .38431 .73469 .40946 .73188 .40667 Mtetra
.951 .598 .25 r
.73188 .40667 .73469 .40946 .74383 .45002 .74109 .44848 Mtetra
.93 .546 .204 r
.74109 .44848 .74383 .45002 .75222 .47687 .74953 .47617 Mtetra
.879 .967 .846 r
.74953 .47617 .75222 .47687 .75839 .47051 .7557 .46965 Mtetra
.991 .767 .501 r
.7557 .46965 .75839 .47051 .76242 .43492 .7597 .43304 Mtetra
.986 .747 .491 r
.7597 .43304 .76242 .43492 .76586 .39314 .7631 .39008 Mtetra
.972 .77 .574 r
.7631 .39008 .76586 .39314 .77055 .36942 .76777 .36569 Mtetra
0 .281 .779 r
.76777 .36569 .77055 .36942 .77742 .37429 .77466 .3707 Mtetra
.907 .519 .095 r
.77466 .3707 .77742 .37429 .78604 .40014 .78332 .39733 Mtetra
.916 .527 .127 r
.78332 .39733 .78604 .40014 .79484 .42677 .79219 .42482 Mtetra
.632 .109 0 r
.79219 .42482 .79484 .42677 .80216 .43433 .79955 .43275 Mtetra
.984 .831 .612 r
.79955 .43275 .80216 .43433 .80736 .4169 .80474 .41494 Mtetra
.989 .769 .513 r
.80474 .41494 .80736 .4169 .81128 .38581 .80863 .38301 Mtetra
.981 .772 .548 r
.80863 .38301 .81128 .38581 .81558 .36001 .81289 .35644 Mtetra
.868 .809 .789 r
.81289 .35644 .81558 .36001 .82154 .35274 .81883 .3489 Mtetra
.628 .19 0 r
.81883 .3489 .82154 .35274 .82928 .36436 .82661 .36081 Mtetra
.832 .415 0 r
.82661 .36081 .82928 .36436 .83782 .38338 .8352 .38044 Mtetra
.683 .214 0 r
.8352 .38044 .83782 .38338 .84568 .39447 .84311 .392 Mtetra
.843 .879 .867 r
.84311 .392 .84568 .39447 .8519 .38881 .84935 .38636 Mtetra
.982 .807 .591 r
.84935 .38636 .8519 .38881 .85671 .3696 .85414 .36672 Mtetra
.981 .791 .576 r
.85414 .36672 .85671 .3696 .86129 .34872 .85868 .34524 Mtetra
.93 .814 .709 r
.85868 .34524 .86129 .34872 .86686 .3376 .86423 .33374 Mtetra
.283 .538 .917 r
.86423 .33374 .86686 .3376 .87388 .3399 .87126 .33604 Mtetra
0 0 .472 r
.87126 .33604 .87388 .3399 .88184 .35019 .87926 .34664 Mtetra
0 .034 .576 r
.87926 .34664 .88184 .35019 .88962 .35831 .88709 .35511 Mtetra
.607 .765 .956 r
.88709 .35511 .88962 .35831 .89633 .35676 .89382 .35369 Mtetra
.938 .838 .719 r
.89382 .35369 .89633 .35676 .90195 .3459 .89944 .34264 Mtetra
.631 .768 .945 r
.30318 .5279 .30666 .53059 .31203 .52922 .30855 .52651 Mtetra
.862 .772 .761 r
.30855 .52651 .31203 .52922 .31781 .52126 .31436 .51835 Mtetra
.877 .758 .727 r
.31436 .51835 .31781 .52126 .32372 .51113 .3203 .50798 Mtetra
.799 .764 .82 r
.3203 .50798 .32372 .51113 .3293 .50627 .32589 .50306 Mtetra
.571 .059 0 r
.32589 .50306 .3293 .50627 .33432 .51134 .3309 .50834 Mtetra
.917 .523 .219 r
.3309 .50834 .33432 .51134 .33893 .52419 .33548 .52161 Mtetra
.909 .507 .214 r
.33548 .52161 .33893 .52419 .34364 .53636 .34016 .53415 Mtetra
0 .416 .811 r
.34016 .53415 .34364 .53636 .34893 .53847 .34545 .53631 Mtetra
.902 .78 .717 r
.34545 .53631 .34893 .53847 .35493 .52713 .35149 .52465 Mtetra
.919 .747 .653 r
.35149 .52465 .35493 .52713 .36127 .50853 .35787 .50556 Mtetra
.899 .751 .688 r
.35787 .50556 .36127 .50853 .36733 .49482 .36397 .49155 Mtetra
.286 .582 .942 r
.36397 .49155 .36733 .49482 .37267 .49602 .36931 .49291 Mtetra
.935 .569 .283 r
.36931 .49291 .37267 .49602 .37734 .51306 .37394 .51052 Mtetra
.94 .601 .358 r
.37394 .51052 .37734 .51306 .38184 .53589 .37839 .53403 Mtetra
.905 .506 .237 r
.37839 .53403 .38184 .53589 .38683 .54878 .38336 .54725 Mtetra
.891 .837 .785 r
.38336 .54725 .38683 .54878 .39269 .54106 .38925 .53924 Mtetra
.939 .748 .618 r
.38925 .53924 .39269 .54106 .3992 .51598 .39582 .51343 Mtetra
.933 .736 .614 r
.39582 .51343 .3992 .51598 .40569 .4896 .40237 .4864 Mtetra
.874 .762 .736 r
.40237 .4864 .40569 .4896 .41153 .48003 .40823 .47674 Mtetra
.928 .543 .224 r
.40823 .47674 .41153 .48003 .41654 .49547 .41321 .49281 Mtetra
.948 .628 .392 r
.41321 .49281 .41654 .49547 .42109 .52814 .4177 .52649 Mtetra
.939 .611 .386 r
.4177 .52649 .42109 .52814 .42587 .55715 .42243 .55628 Mtetra
.622 .056 0 r
.42243 .55628 .42587 .55715 .43145 .56133 .42802 .56041 Mtetra
.953 .763 .607 r
.42802 .56041 .43145 .56133 .43785 .53543 .43448 .53362 Mtetra
.949 .731 .573 r
.43448 .53362 .43785 .53543 .44451 .49573 .44121 .49284 Mtetra
.936 .736 .608 r
.44121 .49284 .44451 .49573 .45076 .46875 .44751 .46534 Mtetra
0 .073 .582 r
.44751 .46534 .45076 .46875 .45629 .4734 .45303 .47044 Mtetra
.953 .632 .383 r
.45303 .47044 .45629 .4734 .46125 .50923 .45793 .50752 Mtetra
.948 .639 .415 r
.45793 .50752 .46125 .50923 .46618 .55495 .4628 .55455 Mtetra
.925 .58 .361 r
.4628 .55455 .46618 .55495 .47162 .57936 .46822 .57942 Mtetra
.966 .829 .656 r
.46822 .57942 .47162 .57936 .47773 .56321 .47437 .56248 Mtetra
.961 .735 .55 r
.47437 .56248 .47773 .56321 .48418 .51583 .4809 .51361 Mtetra
.954 .725 .555 r
.4809 .51361 .48418 .51583 .49049 .46872 .48727 .46539 Mtetra
.915 .754 .668 r
.48727 .46539 .49049 .46872 .49637 .4529 .49318 .44957 Mtetra
.951 .607 .316 r
.49318 .44957 .49637 .4529 .50192 .47992 .4987 .47777 Mtetra
.955 .647 .411 r
.4987 .47777 .50192 .47992 .50744 .53493 .50416 .53452 Mtetra
.945 .631 .41 r
.50416 .53452 .50744 .53493 .5132 .58257 .50988 .58333 Mtetra
.725 .226 .05 r
.50988 .58333 .5132 .58257 .51921 .58838 .5159 .58884 Mtetra
.974 .753 .543 r
.5159 .58884 .51921 .58838 .52526 .54611 .52201 .54498 Mtetra
.964 .724 .526 r
.52201 .54498 .52526 .54611 .53114 .48398 .52796 .48111 Mtetra
.954 .728 .557 r
.52796 .48111 .53114 .48398 .5369 .44254 .53376 .43896 Mtetra
0 .039 .561 r
.53376 .43896 .5369 .44254 .54278 .44774 .53964 .44488 Mtetra
.959 .642 .38 r
.53964 .44488 .54278 .44774 .54902 .49733 .54586 .49626 Mtetra
.955 .646 .408 r
.54586 .49626 .54902 .49733 .55559 .56095 .55239 .5617 Mtetra
.932 .596 .375 r
.55239 .5617 .55559 .56095 .56208 .59524 .55888 .59656 Mtetra
.99 .832 .591 r
.55888 .59656 .56208 .59524 .56802 .57411 .56484 .57426 Mtetra
.974 .732 .509 r
.56484 .57426 .56802 .57411 .5733 .51117 .57016 .50927 Mtetra
.967 .722 .515 r
.57016 .50927 .5733 .51117 .57836 .44829 .57527 .4449 Mtetra
.944 .747 .606 r
.57527 .4449 .57836 .44829 .58392 .42416 .58086 .42068 Mtetra
.95 .595 .269 r
.58086 .42068 .58392 .42416 .59046 .45232 .5874 .45015 Mtetra
.961 .646 .382 r
.5874 .45015 .59046 .45232 .59789 .51528 .59482 .51512 Mtetra
.952 .633 .387 r
.59482 .51512 .59789 .51528 .60541 .57202 .60234 .5733 Mtetra
.819 .376 .185 r
.60234 .5733 .60541 .57202 .61198 .58214 .60891 .58321 Mtetra
.986 .759 .51 r
.60891 .58321 .61198 .58214 .6171 .5371 .61404 .53644 Mtetra
.976 .726 .493 r
.61404 .53644 .6171 .5371 .62134 .46747 .6183 .46483 Mtetra
.968 .728 .521 r
.6183 .46483 .62134 .46747 .62595 .41737 .62294 .41372 Mtetra
.664 .739 .906 r
.62294 .41372 .62595 .41737 .63198 .41495 .62899 .41176 Mtetra
.96 .626 .318 r
.62899 .41176 .63198 .41495 .63965 .45926 .63668 .45765 Mtetra
.96 .639 .362 r
.63668 .45765 .63965 .45926 .64815 .52121 .64521 .52141 Mtetra
.942 .596 .336 r
.64521 .52141 .64815 .52121 .65596 .55848 .65303 .55949 Mtetra
.987 .893 .63 r
.65303 .55949 .65596 .55848 .66182 .54382 .65888 .54404 Mtetra
.984 .741 .485 r
.65888 .54404 .66182 .54382 .66584 .48688 .6629 .48528 Mtetra
.977 .727 .488 r
.6629 .48528 .66584 .48688 .66946 .42517 .66651 .42198 Mtetra
.964 .748 .562 r
.66651 .42198 .66946 .42517 .67432 .3951 .67139 .39142 Mtetra
.864 .445 0 r
.67139 .39142 .67432 .3951 .68132 .41101 .67841 .40808 Mtetra
.96 .623 .304 r
.67841 .40808 .68132 .41101 .69005 .45975 .68719 .45835 Mtetra
.956 .616 .318 r
.68719 .45835 .69005 .45975 .69896 .5079 .69614 .50783 Mtetra
.865 .423 .135 r
.69614 .50783 .69896 .5079 .7062 .52134 .7034 .5215 Mtetra
.993 .786 .521 r
.7034 .5215 .7062 .52134 .711 .48997 .70818 .48909 Mtetra
.984 .737 .477 r
.70818 .48909 .711 .48997 .71432 .43496 .71147 .43253 Mtetra
.979 .738 .503 r
.71147 .43253 .71432 .43496 .71809 .39059 .71522 .38706 Mtetra
.899 .793 .736 r
.71522 .38706 .71809 .39059 .72384 .38069 .72099 .37705 Mtetra
.922 .54 .138 r
.72099 .37705 .72384 .38069 .73188 .40667 .72906 .40387 Mtetra
.952 .6 .254 r
.72906 .40387 .73188 .40667 .74109 .44848 .73833 .4469 Mtetra
.931 .55 .208 r
.73833 .4469 .74109 .44848 .74953 .47617 .74681 .4754 Mtetra
.885 .962 .842 r
.74681 .4754 .74953 .47617 .7557 .46965 .75299 .4687 Mtetra
.99 .764 .499 r
.75299 .4687 .7557 .46965 .7597 .43304 .75696 .4311 Mtetra
.985 .745 .489 r
.75696 .4311 .7597 .43304 .7631 .39008 .76033 .38698 Mtetra
.972 .768 .57 r
.76033 .38698 .7631 .39008 .76777 .36569 .76497 .36195 Mtetra
0 .267 .769 r
.76497 .36195 .76777 .36569 .77466 .3707 .77188 .36711 Mtetra
.91 .524 .103 r
.77188 .36711 .77466 .3707 .78332 .39733 .78059 .39448 Mtetra
.919 .532 .134 r
.78059 .39448 .78332 .39733 .79219 .42482 .78952 .42282 Mtetra
.647 .128 0 r
.78952 .42282 .79219 .42482 .79955 .43275 .79692 .4311 Mtetra
.984 .827 .609 r
.79692 .4311 .79955 .43275 .80474 .41494 .8021 .41292 Mtetra
.989 .767 .51 r
.8021 .41292 .80474 .41494 .80863 .38301 .80595 .38017 Mtetra
.982 .77 .544 r
.80595 .38017 .80863 .38301 .81289 .35644 .81018 .35286 Mtetra
.873 .808 .783 r
.81018 .35286 .81289 .35644 .81883 .3489 .81611 .34505 Mtetra
.64 .202 0 r
.81611 .34505 .81883 .3489 .82661 .36081 .82392 .35723 Mtetra
.838 .424 0 r
.82392 .35723 .82661 .36081 .8352 .38044 .83257 .37745 Mtetra
.698 .232 0 r
.83257 .37745 .8352 .38044 .84311 .392 .84052 .38949 Mtetra
.842 .876 .867 r
.84052 .38949 .84311 .392 .84935 .38636 .84678 .38386 Mtetra
.983 .805 .587 r
.84678 .38386 .84935 .38636 .85414 .36672 .85156 .36379 Mtetra
.981 .789 .571 r
.85156 .36379 .85414 .36672 .85868 .34524 .85607 .34174 Mtetra
.933 .812 .703 r
.85607 .34174 .85868 .34524 .86423 .33374 .86159 .32986 Mtetra
.282 .538 .917 r
.86159 .32986 .86423 .33374 .87126 .33604 .86863 .33216 Mtetra
0 0 .456 r
.86863 .33216 .87126 .33604 .87926 .34664 .87667 .34306 Mtetra
0 .011 .555 r
.87667 .34306 .87926 .34664 .88709 .35511 .88454 .35188 Mtetra
.597 .76 .956 r
.88454 .35188 .88709 .35511 .89382 .35369 .8913 .35058 Mtetra
.939 .837 .716 r
.8913 .35058 .89382 .35369 .89944 .34264 .89691 .33934 Mtetra
.633 .767 .944 r
.29968 .52518 .30318 .5279 .30855 .52651 .30506 .52378 Mtetra
.863 .771 .758 r
.30506 .52378 .30855 .52651 .31436 .51835 .3109 .51542 Mtetra
.878 .757 .724 r
.3109 .51542 .31436 .51835 .3203 .50798 .31686 .50482 Mtetra
.8 .763 .819 r
.31686 .50482 .3203 .50798 .32589 .50306 .32247 .49983 Mtetra
.6 .089 0 r
.32247 .49983 .32589 .50306 .3309 .50834 .32746 .50532 Mtetra
.92 .53 .229 r
.32746 .50532 .3309 .50834 .33548 .52161 .33201 .51899 Mtetra
.912 .514 .223 r
.33201 .51899 .33548 .52161 .34016 .53415 .33667 .53189 Mtetra
0 .408 .807 r
.33667 .53189 .34016 .53415 .34545 .53631 .34196 .5341 Mtetra
.903 .778 .713 r
.34196 .5341 .34545 .53631 .35149 .52465 .34803 .52214 Mtetra
.919 .746 .65 r
.34803 .52214 .35149 .52465 .35787 .50556 .35447 .50257 Mtetra
.9 .75 .685 r
.35447 .50257 .35787 .50556 .36397 .49155 .36059 .48827 Mtetra
.258 .566 .937 r
.36059 .48827 .36397 .49155 .36931 .49291 .36593 .48977 Mtetra
.936 .573 .291 r
.36593 .48977 .36931 .49291 .37394 .51052 .37052 .50794 Mtetra
.94 .604 .362 r
.37052 .50794 .37394 .51052 .37839 .53403 .37492 .53212 Mtetra
.907 .511 .242 r
.37492 .53212 .37839 .53403 .38336 .54725 .37988 .54566 Mtetra
.893 .832 .779 r
.37988 .54566 .38336 .54725 .38925 .53924 .38579 .53736 Mtetra
.939 .746 .616 r
.38579 .53736 .38925 .53924 .39582 .51343 .39243 .51084 Mtetra
.933 .735 .612 r
.39243 .51084 .39582 .51343 .40237 .4864 .39903 .48318 Mtetra
.874 .761 .735 r
.39903 .48318 .40237 .4864 .40823 .47674 .40491 .47345 Mtetra
.93 .55 .236 r
.40491 .47345 .40823 .47674 .41321 .49281 .40986 .49012 Mtetra
.948 .63 .395 r
.40986 .49012 .41321 .49281 .4177 .52649 .41429 .52479 Mtetra
.94 .613 .389 r
.41429 .52479 .4177 .52649 .42243 .55628 .41898 .55533 Mtetra
.609 .04 0 r
.41898 .55533 .42243 .55628 .42802 .56041 .42457 .5594 Mtetra
.953 .76 .605 r
.42457 .5594 .42802 .56041 .43448 .53362 .43109 .53174 Mtetra
.949 .73 .572 r
.43109 .53174 .43448 .53362 .44121 .49284 .4379 .4899 Mtetra
.936 .735 .606 r
.4379 .4899 .44121 .49284 .44751 .46534 .44425 .46192 Mtetra
0 .008 .517 r
.44425 .46192 .44751 .46534 .45303 .47044 .44975 .46748 Mtetra
.953 .634 .387 r
.44975 .46748 .45303 .47044 .45793 .50752 .4546 .50577 Mtetra
.949 .64 .417 r
.4546 .50577 .45793 .50752 .4628 .55455 .45941 .55406 Mtetra
.926 .582 .362 r
.45941 .55406 .4628 .55455 .46822 .57942 .46481 .57937 Mtetra
.965 .821 .65 r
.46481 .57937 .46822 .57942 .47437 .56248 .471 .56162 Mtetra
.961 .733 .549 r
.471 .56162 .47437 .56248 .4809 .51361 .47761 .5113 Mtetra
.953 .724 .554 r
.47761 .5113 .4809 .51361 .48727 .46539 .48405 .46202 Mtetra
.914 .753 .668 r
.48405 .46202 .48727 .46539 .49318 .44957 .48998 .44623 Mtetra
.952 .611 .323 r
.48998 .44623 .49318 .44957 .4987 .47777 .49547 .47559 Mtetra
.955 .648 .413 r
.49547 .47559 .4987 .47777 .50416 .53452 .50087 .53403 Mtetra
.946 .633 .411 r
.50087 .53403 .50416 .53452 .50988 .58333 .50654 .58397 Mtetra
.709 .2 .018 r
.50654 .58397 .50988 .58333 .5159 .58884 .51258 .58915 Mtetra
.972 .75 .542 r
.51258 .58915 .5159 .58884 .52201 .54498 .51874 .54371 Mtetra
.964 .723 .525 r
.51874 .54371 .52201 .54498 .52796 .48111 .52476 .47818 Mtetra
.954 .727 .556 r
.52476 .47818 .52796 .48111 .53376 .43896 .53061 .43537 Mtetra
0 0 .475 r
.53061 .43537 .53376 .43896 .53964 .44488 .5365 .44201 Mtetra
.959 .644 .383 r
.5365 .44201 .53964 .44488 .54586 .49626 .54268 .49515 Mtetra
.955 .647 .409 r
.54268 .49515 .54586 .49626 .55239 .5617 .54917 .56234 Mtetra
.933 .598 .375 r
.54917 .56234 .55239 .5617 .55888 .59656 .55565 .59772 Mtetra
.989 .823 .587 r
.55565 .59772 .55888 .59656 .56484 .57426 .56163 .57425 Mtetra
.973 .73 .508 r
.56163 .57425 .56484 .57426 .57016 .50927 .567 .50727 Mtetra
.966 .721 .515 r
.567 .50727 .57016 .50927 .57527 .4449 .57216 .44146 Mtetra
.944 .746 .606 r
.57216 .44146 .57527 .4449 .58086 .42068 .57778 .41718 Mtetra
.951 .6 .278 r
.57778 .41718 .58086 .42068 .5874 .45015 .58433 .44797 Mtetra
.961 .647 .384 r
.58433 .44797 .5874 .45015 .59482 .51512 .59173 .5149 Mtetra
.953 .634 .388 r
.59173 .5149 .59482 .51512 .60234 .5733 .59925 .57445 Mtetra
.816 .368 .172 r
.59925 .57445 .60234 .5733 .60891 .58321 .60582 .58412 Mtetra
.984 .755 .51 r
.60582 .58412 .60891 .58321 .61404 .53644 .61096 .53564 Mtetra
.975 .725 .492 r
.61096 .53564 .61404 .53644 .6183 .46483 .61525 .4621 Mtetra
.968 .727 .52 r
.61525 .4621 .6183 .46483 .62294 .41372 .61991 .41005 Mtetra
.633 .727 .916 r
.61991 .41005 .62294 .41372 .62899 .41176 .62598 .40855 Mtetra
.96 .628 .322 r
.62598 .40855 .62899 .41176 .63668 .45765 .63369 .45601 Mtetra
.961 .64 .364 r
.63369 .45601 .63668 .45765 .64521 .52141 .64224 .52153 Mtetra
.943 .598 .336 r
.64224 .52153 .64521 .52141 .65303 .55949 .65007 .56037 Mtetra
.989 .882 .624 r
.65007 .56037 .65303 .55949 .65888 .54404 .65592 .5441 Mtetra
.983 .738 .485 r
.65592 .5441 .65888 .54404 .6629 .48528 .65993 .48357 Mtetra
.977 .726 .487 r
.65993 .48357 .6629 .48528 .66651 .42198 .66354 .41874 Mtetra
.964 .747 .561 r
.66354 .41874 .66651 .42198 .67139 .39142 .66844 .38773 Mtetra
.873 .459 .021 r
.66844 .38773 .67139 .39142 .67841 .40808 .67549 .40514 Mtetra
.96 .625 .307 r
.67549 .40514 .67841 .40808 .68719 .45835 .68431 .45689 Mtetra
.956 .618 .319 r
.68431 .45689 .68719 .45835 .69614 .50783 .69329 .50766 Mtetra
.867 .425 .132 r
.69329 .50766 .69614 .50783 .7034 .5215 .70056 .52153 Mtetra
.992 .782 .519 r
.70056 .52153 .7034 .5215 .70818 .48909 .70533 .48808 Mtetra
.984 .736 .476 r
.70533 .48808 .70818 .48909 .71147 .43253 .7086 .43002 Mtetra
.978 .737 .502 r
.7086 .43002 .71147 .43253 .71522 .38706 .71234 .3835 Mtetra
.899 .793 .734 r
.71234 .3835 .71522 .38706 .72099 .37705 .71812 .3734 Mtetra
.924 .546 .146 r
.71812 .3734 .72099 .37705 .72906 .40387 .72623 .40103 Mtetra
.953 .602 .257 r
.72623 .40103 .72906 .40387 .73833 .4469 .73555 .44525 Mtetra
.933 .553 .211 r
.73555 .44525 .73833 .4469 .74681 .4754 .74407 .47453 Mtetra
.89 .956 .838 r
.74407 .47453 .74681 .4754 .75299 .4687 .75026 .46765 Mtetra
.99 .762 .497 r
.75026 .46765 .75299 .4687 .75696 .4311 .75421 .42906 Mtetra
.985 .743 .487 r
.75421 .42906 .75696 .4311 .76033 .38698 .75754 .38383 Mtetra
.972 .766 .567 r
.75754 .38383 .76033 .38698 .76497 .36195 .76217 .35819 Mtetra
0 .253 .759 r
.76217 .35819 .76497 .36195 .77188 .36711 .76909 .36349 Mtetra
.913 .529 .11 r
.76909 .36349 .77188 .36711 .78059 .39448 .77785 .3916 Mtetra
.921 .536 .14 r
.77785 .3916 .78059 .39448 .78952 .42282 .78684 .42075 Mtetra
.659 .144 0 r
.78684 .42075 .78952 .42282 .79692 .4311 .79426 .42937 Mtetra
.984 .824 .606 r
.79426 .42937 .79692 .4311 .8021 .41292 .79944 .41082 Mtetra
.988 .764 .508 r
.79944 .41082 .8021 .41292 .80595 .38017 .80327 .37727 Mtetra
.982 .768 .54 r
.80327 .37727 .80595 .38017 .81018 .35286 .80746 .34925 Mtetra
.877 .808 .777 r
.80746 .34925 .81018 .35286 .81611 .34505 .81339 .34118 Mtetra
.652 .214 0 r
.81339 .34118 .81611 .34505 .82392 .35723 .82122 .35364 Mtetra
.844 .432 0 r
.82122 .35364 .82392 .35723 .83257 .37745 .82992 .37442 Mtetra
.71 .248 0 r
.82992 .37442 .83257 .37745 .84052 .38949 .83792 .38691 Mtetra
.84 .873 .867 r
.83792 .38691 .84052 .38949 .84678 .38386 .84419 .3813 Mtetra
.983 .802 .584 r
.84419 .3813 .84678 .38386 .85156 .36379 .84896 .36082 Mtetra
.982 .787 .567 r
.84896 .36082 .85156 .36379 .85607 .34174 .85344 .33821 Mtetra
.936 .811 .697 r
.85344 .33821 .85607 .34174 .86159 .32986 .85894 .32596 Mtetra
.282 .538 .917 r
.85894 .32596 .86159 .32986 .86863 .33216 .86599 .32826 Mtetra
0 0 .441 r
.86599 .32826 .86863 .33216 .87667 .34306 .87406 .33945 Mtetra
0 0 .535 r
.87406 .33945 .87667 .34306 .88454 .35188 .88197 .34861 Mtetra
.587 .753 .957 r
.88197 .34861 .88454 .35188 .8913 .35058 .88876 .34742 Mtetra
.94 .835 .713 r
.88876 .34742 .8913 .35058 .89691 .33934 .89438 .33601 Mtetra
.634 .766 .942 r
.29617 .52243 .29968 .52518 .30506 .52378 .30156 .52101 Mtetra
.865 .769 .755 r
.30156 .52101 .30506 .52378 .3109 .51542 .30742 .51247 Mtetra
.88 .756 .721 r
.30742 .51247 .3109 .51542 .31686 .50482 .31342 .50165 Mtetra
.802 .763 .818 r
.31342 .50165 .31686 .50482 .32247 .49983 .31904 .49659 Mtetra
.627 .117 0 r
.31904 .49659 .32247 .49983 .32746 .50532 .32402 .50228 Mtetra
.922 .536 .239 r
.32402 .50228 .32746 .50532 .33201 .51899 .32853 .51635 Mtetra
.914 .52 .231 r
.32853 .51635 .33201 .51899 .33667 .53189 .33316 .52959 Mtetra
0 .402 .805 r
.33316 .52959 .33667 .53189 .34196 .5341 .33846 .53185 Mtetra
.903 .775 .71 r
.33846 .53185 .34196 .5341 .34803 .52214 .34456 .51958 Mtetra
.92 .744 .648 r
.34456 .51958 .34803 .52214 .35447 .50257 .35105 .49955 Mtetra
.901 .749 .683 r
.35105 .49955 .35447 .50257 .36059 .48827 .35721 .48498 Mtetra
.229 .549 .93 r
.35721 .48498 .36059 .48827 .36593 .48977 .36255 .48663 Mtetra
.938 .578 .299 r
.36255 .48663 .36593 .48977 .37052 .50794 .36709 .50534 Mtetra
.941 .606 .366 r
.36709 .50534 .37052 .50794 .37492 .53212 .37144 .53015 Mtetra
.909 .515 .246 r
.37144 .53015 .37492 .53212 .37988 .54566 .37638 .54399 Mtetra
.895 .827 .773 r
.37638 .54399 .37988 .54566 .38579 .53736 .38232 .53541 Mtetra
.938 .744 .614 r
.38232 .53541 .38579 .53736 .39243 .51084 .38902 .5082 Mtetra
.933 .734 .61 r
.38902 .5082 .39243 .51084 .39903 .48318 .39569 .47993 Mtetra
.874 .761 .734 r
.39569 .47993 .39903 .48318 .40491 .47345 .40158 .47014 Mtetra
.933 .557 .247 r
.40158 .47014 .40491 .47345 .40986 .49012 .4065 .48741 Mtetra
.948 .631 .398 r
.4065 .48741 .40986 .49012 .41429 .52479 .41086 .52305 Mtetra
.94 .615 .391 r
.41086 .52305 .41429 .52479 .41898 .55533 .4155 .5543 Mtetra
.594 .021 0 r
.4155 .5543 .41898 .55533 .42457 .5594 .42111 .55829 Mtetra
.952 .757 .602 r
.42111 .55829 .42457 .5594 .43109 .53174 .42769 .52977 Mtetra
.949 .728 .571 r
.42769 .52977 .43109 .53174 .4379 .4899 .43458 .48692 Mtetra
.936 .734 .605 r
.43458 .48692 .4379 .4899 .44425 .46192 .44097 .45848 Mtetra
.545 .051 0 r
.44097 .45848 .44425 .46192 .44975 .46748 .44647 .4645 Mtetra
.953 .636 .39 r
.44647 .4645 .44975 .46748 .4546 .50577 .45126 .50397 Mtetra
.949 .641 .419 r
.45126 .50397 .4546 .50577 .45941 .55406 .456 .55349 Mtetra
.928 .584 .362 r
.456 .55349 .45941 .55406 .46481 .57937 .46137 .57919 Mtetra
.964 .814 .645 r
.46137 .57919 .46481 .57937 .471 .56162 .46761 .56065 Mtetra
.96 .731 .548 r
.46761 .56065 .471 .56162 .47761 .5113 .4743 .50892 Mtetra
.953 .723 .553 r
.4743 .50892 .47761 .5113 .48405 .46202 .48081 .45862 Mtetra
.914 .753 .669 r
.48081 .45862 .48405 .46202 .48998 .44623 .48676 .44288 Mtetra
.953 .614 .33 r
.48676 .44288 .48998 .44623 .49547 .47559 .49221 .47339 Mtetra
.955 .649 .414 r
.49221 .47339 .49547 .47559 .50087 .53403 .49756 .53347 Mtetra
.946 .634 .411 r
.49756 .53347 .50087 .53403 .50654 .58397 .50319 .58447 Mtetra
.69 .168 0 r
.50319 .58447 .50654 .58397 .51258 .58915 .50923 .58932 Mtetra
.971 .747 .541 r
.50923 .58932 .51258 .58915 .51874 .54371 .51546 .54233 Mtetra
.963 .722 .524 r
.51546 .54233 .51874 .54371 .52476 .47818 .52155 .47518 Mtetra
.954 .726 .555 r
.52155 .47518 .52476 .47818 .53061 .43537 .52745 .43176 Mtetra
.6 .121 0 r
.52745 .43176 .53061 .43537 .5365 .44201 .53334 .43914 Mtetra
.959 .645 .385 r
.53334 .43914 .5365 .44201 .54268 .49515 .53948 .49398 Mtetra
.955 .648 .41 r
.53948 .49398 .54268 .49515 .54917 .56234 .54594 .56287 Mtetra
.935 .599 .375 r
.54594 .56287 .54917 .56234 .55565 .59772 .55239 .59872 Mtetra
.987 .815 .584 r
.55239 .59872 .55565 .59772 .56163 .57425 .5584 .57408 Mtetra
.973 .729 .508 r
.5584 .57408 .56163 .57425 .567 .50727 .56383 .50516 Mtetra
.966 .72 .514 r
.56383 .50516 .567 .50727 .57216 .44146 .56904 .43798 Mtetra
.943 .746 .606 r
.56904 .43798 .57216 .44146 .57778 .41718 .57469 .41368 Mtetra
.953 .604 .286 r
.57469 .41368 .57778 .41718 .58433 .44797 .58124 .44576 Mtetra
.961 .649 .386 r
.58124 .44576 .58433 .44797 .59173 .5149 .58862 .5146 Mtetra
.953 .636 .388 r
.58862 .5146 .59173 .5149 .59925 .57445 .59612 .57546 Mtetra
.812 .358 .156 r
.59612 .57546 .59925 .57445 .60582 .58412 .6027 .58485 Mtetra
.983 .752 .509 r
.6027 .58485 .60582 .58412 .61096 .53564 .60786 .53469 Mtetra
.974 .723 .492 r
.60786 .53469 .61096 .53564 .61525 .4621 .61218 .4593 Mtetra
.968 .726 .519 r
.61218 .4593 .61525 .4621 .61991 .41005 .61687 .40636 Mtetra
.597 .712 .925 r
.61687 .40636 .61991 .41005 .62598 .40855 .62297 .40534 Mtetra
.961 .63 .325 r
.62297 .40534 .62598 .40855 .63369 .45601 .63069 .45433 Mtetra
.961 .641 .365 r
.63069 .45433 .63369 .45601 .64224 .52153 .63925 .52154 Mtetra
.944 .6 .336 r
.63925 .52154 .64224 .52153 .65007 .56037 .64708 .5611 Mtetra
.99 .872 .619 r
.64708 .5611 .65007 .56037 .65592 .5441 .65294 .54401 Mtetra
.983 .736 .484 r
.65294 .54401 .65592 .5441 .65993 .48357 .65695 .48175 Mtetra
.977 .725 .487 r
.65695 .48175 .65993 .48357 .66354 .41874 .66056 .41545 Mtetra
.964 .746 .56 r
.66056 .41545 .66354 .41874 .66844 .38773 .66548 .38402 Mtetra
.882 .471 .039 r
.66548 .38402 .66844 .38773 .67549 .40514 .67256 .40218 Mtetra
.961 .626 .31 r
.67256 .40218 .67549 .40514 .68431 .45689 .6814 .45537 Mtetra
.957 .62 .321 r
.6814 .45537 .68431 .45689 .69329 .50766 .69042 .50738 Mtetra
.868 .426 .129 r
.69042 .50738 .69329 .50766 .70056 .52153 .69771 .52142 Mtetra
.991 .778 .518 r
.69771 .52142 .70056 .52153 .70533 .48808 .70247 .48696 Mtetra
.983 .734 .475 r
.70247 .48696 .70533 .48808 .7086 .43002 .70572 .42743 Mtetra
.978 .736 .501 r
.70572 .42743 .7086 .43002 .71234 .3835 .70945 .37991 Mtetra
.899 .792 .733 r
.70945 .37991 .71234 .3835 .71812 .3734 .71523 .36973 Mtetra
.927 .55 .154 r
.71523 .36973 .71812 .3734 .72623 .40103 .72338 .39816 Mtetra
.953 .605 .26 r
.72338 .39816 .72623 .40103 .73555 .44525 .73275 .44354 Mtetra
.934 .556 .214 r
.73275 .44354 .73555 .44525 .74407 .47453 .74131 .47355 Mtetra
.895 .949 .833 r
.74131 .47355 .74407 .47453 .75026 .46765 .7475 .46649 Mtetra
.989 .759 .496 r
.7475 .46649 .75026 .46765 .75421 .42906 .75143 .42695 Mtetra
.985 .742 .485 r
.75143 .42695 .75421 .42906 .75754 .38383 .75473 .38064 Mtetra
.972 .764 .564 r
.75473 .38064 .75754 .38383 .76217 .35819 .75935 .35442 Mtetra
0 .238 .748 r
.75935 .35442 .76217 .35819 .76909 .36349 .76629 .35986 Mtetra
.915 .533 .117 r
.76629 .35986 .76909 .36349 .77785 .3916 .77509 .38868 Mtetra
.923 .54 .145 r
.77509 .38868 .77785 .3916 .78684 .42075 .78413 .41862 Mtetra
.669 .159 0 r
.78413 .41862 .78684 .42075 .79426 .42937 .79159 .42755 Mtetra
.983 .821 .603 r
.79159 .42755 .79426 .42937 .79944 .41082 .79677 .40865 Mtetra
.988 .762 .506 r
.79677 .40865 .79944 .41082 .80327 .37727 .80056 .37433 Mtetra
.982 .766 .537 r
.80056 .37433 .80327 .37727 .80746 .34925 .80473 .34561 Mtetra
.881 .807 .772 r
.80473 .34561 .80746 .34925 .81339 .34118 .81065 .33729 Mtetra
.663 .225 0 r
.81065 .33729 .81339 .34118 .82122 .35364 .8185 .35002 Mtetra
.849 .439 0 r
.8185 .35002 .82122 .35364 .82992 .37442 .82725 .37135 Mtetra
.721 .262 0 r
.82725 .37135 .82992 .37442 .83792 .38691 .8353 .38427 Mtetra
.838 .87 .867 r
.8353 .38427 .83792 .38691 .84419 .3813 .84159 .37868 Mtetra
.983 .8 .581 r
.84159 .37868 .84419 .3813 .84896 .36082 .84634 .3578 Mtetra
.982 .784 .564 r
.84634 .3578 .84896 .36082 .85344 .33821 .85079 .33466 Mtetra
.938 .809 .691 r
.85079 .33466 .85344 .33821 .85894 .32596 .85628 .32205 Mtetra
.282 .538 .917 r
.85628 .32205 .85894 .32596 .86599 .32826 .86334 .32434 Mtetra
0 0 .426 r
.86334 .32434 .86599 .32826 .87406 .33945 .87144 .33581 Mtetra
0 0 .517 r
.87144 .33581 .87406 .33945 .88197 .34861 .87939 .34529 Mtetra
.578 .747 .957 r
.87939 .34529 .88197 .34861 .88876 .34742 .88621 .34422 Mtetra
.941 .833 .71 r
.88621 .34422 .88876 .34742 .89438 .33601 .89182 .33265 Mtetra
.635 .765 .941 r
.29264 .51965 .29617 .52243 .30156 .52101 .29804 .51822 Mtetra
.866 .768 .752 r
.29804 .51822 .30156 .52101 .30742 .51247 .30393 .50949 Mtetra
.881 .755 .719 r
.30393 .50949 .30742 .51247 .31342 .50165 .30996 .49846 Mtetra
.803 .763 .816 r
.30996 .49846 .31342 .50165 .31904 .49659 .3156 .49334 Mtetra
.65 .142 0 r
.3156 .49334 .31904 .49659 .32402 .50228 .32056 .49923 Mtetra
.924 .541 .248 r
.32056 .49923 .32402 .50228 .32853 .51635 .32504 .51367 Mtetra
.916 .525 .238 r
.32504 .51367 .32853 .51635 .33316 .52959 .32964 .52724 Mtetra
0 .396 .802 r
.32964 .52724 .33316 .52959 .33846 .53185 .33494 .52955 Mtetra
.904 .773 .706 r
.33494 .52955 .33846 .53185 .34456 .51958 .34108 .51698 Mtetra
.92 .743 .646 r
.34108 .51698 .34456 .51958 .35105 .49955 .34761 .49651 Mtetra
.901 .748 .681 r
.34761 .49651 .35105 .49955 .35721 .48498 .35381 .48168 Mtetra
.199 .532 .923 r
.35381 .48168 .35721 .48498 .36255 .48663 .35914 .48347 Mtetra
.939 .581 .306 r
.35914 .48347 .36255 .48663 .36709 .50534 .36365 .50271 Mtetra
.942 .608 .37 r
.36365 .50271 .36709 .50534 .37144 .53015 .36795 .52814 Mtetra
.911 .519 .25 r
.36795 .52814 .37144 .53015 .37638 .54399 .37286 .54226 Mtetra
.896 .822 .767 r
.37286 .54226 .37638 .54399 .38232 .53541 .37884 .5334 Mtetra
.938 .742 .612 r
.37884 .5334 .38232 .53541 .38902 .5082 .3856 .50551 Mtetra
.933 .733 .609 r
.3856 .50551 .38902 .5082 .39569 .47993 .39233 .47667 Mtetra
.874 .76 .733 r
.39233 .47667 .39569 .47993 .40158 .47014 .39824 .46682 Mtetra
.935 .563 .257 r
.39824 .46682 .40158 .47014 .4065 .48741 .40312 .48468 Mtetra
.949 .633 .401 r
.40312 .48468 .4065 .48741 .41086 .52305 .40742 .52125 Mtetra
.941 .617 .393 r
.40742 .52125 .41086 .52305 .4155 .5543 .41202 .55319 Mtetra
.577 .001 0 r
.41202 .55319 .4155 .5543 .42111 .55829 .41763 .55709 Mtetra
.952 .754 .6 r
.41763 .55709 .42111 .55829 .42769 .52977 .42427 .52774 Mtetra
.948 .727 .569 r
.42427 .52774 .42769 .52977 .43458 .48692 .43124 .4839 Mtetra
.936 .733 .604 r
.43124 .4839 .43458 .48692 .44097 .45848 .43768 .45502 Mtetra
.599 .106 0 r
.43768 .45502 .44097 .45848 .44647 .4645 .44316 .4615 Mtetra
.953 .638 .393 r
.44316 .4615 .44647 .4645 .45126 .50397 .44789 .50213 Mtetra
.949 .643 .42 r
.44789 .50213 .45126 .50397 .456 .55349 .45257 .55283 Mtetra
.929 .586 .362 r
.45257 .55283 .456 .55349 .46137 .57919 .45792 .5789 Mtetra
.963 .808 .64 r
.45792 .5789 .46137 .57919 .46761 .56065 .4642 .55957 Mtetra
.959 .73 .547 r
.4642 .55957 .46761 .56065 .4743 .50892 .47098 .50647 Mtetra
.953 .722 .552 r
.47098 .50647 .4743 .50892 .48081 .45862 .47756 .45519 Mtetra
.913 .753 .669 r
.47756 .45519 .48081 .45862 .48676 .44288 .48353 .43952 Mtetra
.954 .617 .336 r
.48353 .43952 .48676 .44288 .49221 .47339 .48895 .47116 Mtetra
.955 .651 .416 r
.48895 .47116 .49221 .47339 .49756 .53347 .49422 .53283 Mtetra
.947 .635 .412 r
.49422 .53283 .49756 .53347 .50319 .58447 .49981 .58486 Mtetra
.666 .132 0 r
.49981 .58486 .50319 .58447 .50923 .58932 .50586 .58934 Mtetra
.97 .744 .539 r
.50586 .58934 .50923 .58932 .51546 .54233 .51215 .54083 Mtetra
.963 .721 .523 r
.51215 .54083 .51546 .54233 .52155 .47518 .51833 .47213 Mtetra
.954 .725 .555 r
.51833 .47213 .52155 .47518 .52745 .43176 .52428 .42813 Mtetra
.663 .186 0 r
.52428 .42813 .52745 .43176 .53334 .43914 .53017 .43625 Mtetra
.96 .647 .388 r
.53017 .43625 .53334 .43914 .53948 .49398 .53627 .49277 Mtetra
.956 .649 .411 r
.53627 .49277 .53948 .49398 .54594 .56287 .54267 .56329 Mtetra
.936 .601 .374 r
.54267 .56329 .54594 .56287 .55239 .59872 .54911 .59958 Mtetra
.986 .808 .58 r
.54911 .59958 .55239 .59872 .5584 .57408 .55515 .57377 Mtetra
.972 .727 .507 r
.55515 .57377 .5584 .57408 .56383 .50516 .56064 .50295 Mtetra
.966 .719 .513 r
.56064 .50295 .56383 .50516 .56904 .43798 .56591 .43446 Mtetra
.943 .745 .606 r
.56591 .43446 .56904 .43798 .57469 .41368 .57158 .41017 Mtetra
.954 .608 .293 r
.57158 .41017 .57469 .41368 .58124 .44576 .57813 .44353 Mtetra
.961 .65 .387 r
.57813 .44353 .58124 .44576 .58862 .5146 .5855 .51422 Mtetra
.954 .637 .389 r
.5855 .51422 .58862 .5146 .59612 .57546 .59298 .57634 Mtetra
.807 .346 .139 r
.59298 .57634 .59612 .57546 .6027 .58485 .59955 .58543 Mtetra
.982 .749 .508 r
.59955 .58543 .6027 .58485 .60786 .53469 .60473 .53361 Mtetra
.974 .722 .491 r
.60473 .53361 .60786 .53469 .61218 .4593 .60909 .45642 Mtetra
.967 .725 .518 r
.60909 .45642 .61218 .4593 .61687 .40636 .61382 .40265 Mtetra
.555 .694 .932 r
.61382 .40265 .61687 .40636 .62297 .40534 .61994 .40212 Mtetra
.961 .632 .329 r
.61994 .40212 .62297 .40534 .63069 .45433 .62767 .45261 Mtetra
.961 .642 .366 r
.62767 .45261 .63069 .45433 .63925 .52154 .63623 .52146 Mtetra
.945 .601 .336 r
.63623 .52146 .63925 .52154 .64708 .5611 .64407 .56169 Mtetra
.99 .863 .615 r
.64407 .56169 .64708 .5611 .65294 .54401 .64993 .54378 Mtetra
.982 .735 .483 r
.64993 .54378 .65294 .54401 .65695 .48175 .65394 .47982 Mtetra
.976 .724 .486 r
.65394 .47982 .65695 .48175 .66056 .41545 .65757 .41211 Mtetra
.964 .745 .559 r
.65757 .41211 .66056 .41545 .66548 .38402 .6625 .3803 Mtetra
.889 .483 .056 r
.6625 .3803 .66548 .38402 .67256 .40218 .66961 .3992 Mtetra
.961 .628 .312 r
.66961 .3992 .67256 .40218 .6814 .45537 .67849 .4538 Mtetra
.957 .621 .322 r
.67849 .4538 .6814 .45537 .69042 .50738 .68753 .507 Mtetra
.869 .427 .125 r
.68753 .507 .69042 .50738 .69771 .52142 .69483 .52119 Mtetra
.99 .775 .516 r
.69483 .52119 .69771 .52142 .70247 .48696 .69958 .48572 Mtetra
.983 .732 .475 r
.69958 .48572 .70247 .48696 .70572 .42743 .70281 .42477 Mtetra
.978 .734 .499 r
.70281 .42477 .70572 .42743 .70945 .37991 .70654 .37629 Mtetra
.899 .791 .732 r
.70654 .37629 .70945 .37991 .71523 .36973 .71234 .36606 Mtetra
.929 .555 .161 r
.71234 .36606 .71523 .36973 .72338 .39816 .72052 .39527 Mtetra
.954 .607 .263 r
.72052 .39527 .72338 .39816 .73275 .44354 .72993 .44176 Mtetra
.935 .559 .216 r
.72993 .44176 .73275 .44354 .74131 .47355 .73852 .47248 Mtetra
.9 .942 .828 r
.73852 .47248 .74131 .47355 .7475 .46649 .74473 .46524 Mtetra
.989 .757 .495 r
.74473 .46524 .7475 .46649 .75143 .42695 .74864 .42476 Mtetra
.984 .74 .484 r
.74864 .42476 .75143 .42695 .75473 .38064 .75192 .3774 Mtetra
.973 .763 .561 r
.75192 .3774 .75473 .38064 .75935 .35442 .75653 .35062 Mtetra
0 .224 .737 r
.75653 .35062 .75935 .35442 .76629 .35986 .76348 .35621 Mtetra
.918 .537 .123 r
.76348 .35621 .76629 .35986 .77509 .38868 .77232 .38572 Mtetra
.925 .544 .15 r
.77232 .38572 .77509 .38868 .78413 .41862 .78141 .41642 Mtetra
.679 .172 0 r
.78141 .41642 .78413 .41862 .79159 .42755 .7889 .42566 Mtetra
.983 .817 .601 r
.7889 .42566 .79159 .42755 .79677 .40865 .79407 .40641 Mtetra
.988 .76 .504 r
.79407 .40641 .79677 .40865 .80056 .37433 .79784 .37134 Mtetra
.982 .764 .534 r
.79784 .37134 .80056 .37433 .80473 .34561 .80199 .34195 Mtetra
.885 .807 .767 r
.80199 .34195 .80473 .34561 .81065 .33729 .8079 .33339 Mtetra
.672 .236 0 r
.8079 .33339 .81065 .33729 .8185 .35002 .81578 .34637 Mtetra
.854 .446 0 r
.81578 .34637 .8185 .35002 .82725 .37135 .82457 .36824 Mtetra
.732 .275 0 r
.82457 .36824 .82725 .37135 .8353 .38427 .83266 .38158 Mtetra
.836 .867 .867 r
.83266 .38158 .8353 .38427 .84159 .37868 .83897 .37601 Mtetra
.983 .798 .579 r
.83897 .37601 .84159 .37868 .84634 .3578 .84371 .35474 Mtetra
.982 .782 .56 r
.84371 .35474 .84634 .3578 .85079 .33466 .84814 .33107 Mtetra
.94 .808 .686 r
.84814 .33107 .85079 .33466 .85628 .32205 .85361 .31812 Mtetra
.283 .538 .917 r
.85361 .31812 .85628 .32205 .86334 .32434 .86067 .3204 Mtetra
0 0 .413 r
.86067 .3204 .86334 .32434 .87144 .33581 .86881 .33214 Mtetra
0 0 .5 r
.86881 .33214 .87144 .33581 .87939 .34529 .8768 .34194 Mtetra
.568 .741 .958 r
.8768 .34194 .87939 .34529 .88621 .34422 .88364 .34098 Mtetra
.941 .831 .707 r
.88364 .34098 .88621 .34422 .89182 .33265 .88926 .32925 Mtetra
.637 .764 .94 r
.2891 .51685 .29264 .51965 .29804 .51822 .29451 .51539 Mtetra
.867 .767 .75 r
.29451 .51539 .29804 .51822 .30393 .50949 .30043 .50649 Mtetra
.881 .754 .717 r
.30043 .50649 .30393 .50949 .30996 .49846 .30649 .49525 Mtetra
.804 .763 .815 r
.30649 .49525 .30996 .49846 .3156 .49334 .31214 .49008 Mtetra
.671 .165 0 r
.31214 .49008 .3156 .49334 .32056 .49923 .31708 .49615 Mtetra
.926 .546 .255 r
.31708 .49615 .32056 .49923 .32504 .51367 .32153 .51096 Mtetra
.918 .529 .245 r
.32153 .51096 .32504 .51367 .32964 .52724 .3261 .52485 Mtetra
0 .392 .801 r
.3261 .52485 .32964 .52724 .33494 .52955 .3314 .5272 Mtetra
.904 .771 .703 r
.3314 .5272 .33494 .52955 .34108 .51698 .33758 .51433 Mtetra
.92 .742 .644 r
.33758 .51433 .34108 .51698 .34761 .49651 .34417 .49344 Mtetra
.902 .747 .679 r
.34417 .49344 .34761 .49651 .35381 .48168 .3504 .47836 Mtetra
.168 .514 .915 r
.3504 .47836 .35381 .48168 .35914 .48347 .35573 .48029 Mtetra
.94 .585 .312 r
.35573 .48029 .35914 .48347 .36365 .50271 .3602 .50004 Mtetra
.942 .611 .373 r
.3602 .50004 .36365 .50271 .36795 .52814 .36445 .52606 Mtetra
.912 .523 .253 r
.36445 .52606 .36795 .52814 .37286 .54226 .36934 .54046 Mtetra
.897 .817 .761 r
.36934 .54046 .37286 .54226 .37884 .5334 .37534 .53131 Mtetra
.938 .74 .61 r
.37534 .53131 .37884 .5334 .3856 .50551 .38217 .50278 Mtetra
.933 .732 .607 r
.38217 .50278 .3856 .50551 .39233 .47667 .38895 .47338 Mtetra
.874 .76 .733 r
.38895 .47338 .39233 .47667 .39824 .46682 .39489 .46349 Mtetra
.937 .568 .266 r
.39489 .46349 .39824 .46682 .40312 .48468 .39973 .48192 Mtetra
.949 .635 .403 r
.39973 .48192 .40312 .48468 .40742 .52125 .40396 .51938 Mtetra
.942 .619 .394 r
.40396 .51938 .40742 .52125 .41202 .55319 .40851 .55197 Mtetra
.556 0 0 r
.40851 .55197 .41202 .55319 .41763 .55709 .41413 .55579 Mtetra
.951 .751 .598 r
.41413 .55579 .41763 .55709 .42427 .52774 .42084 .52562 Mtetra
.948 .726 .568 r
.42084 .52562 .42427 .52774 .43124 .4839 .42789 .48083 Mtetra
.936 .732 .603 r
.42789 .48083 .43124 .4839 .43768 .45502 .43438 .45156 Mtetra
.646 .154 0 r
.43438 .45156 .43768 .45502 .44316 .4615 .43985 .45849 Mtetra
.954 .639 .396 r
.43985 .45849 .44316 .4615 .44789 .50213 .44452 .50024 Mtetra
.95 .644 .421 r
.44452 .50024 .44789 .50213 .45257 .55283 .44912 .55207 Mtetra
.93 .587 .362 r
.44912 .55207 .45257 .55283 .45792 .5789 .45445 .57847 Mtetra
.962 .801 .636 r
.45445 .57847 .45792 .5789 .4642 .55957 .46078 .55836 Mtetra
.959 .728 .546 r
.46078 .55836 .4642 .55957 .47098 .50647 .46764 .50393 Mtetra
.953 .721 .551 r
.46764 .50393 .47098 .50647 .47756 .45519 .4743 .45173 Mtetra
.912 .753 .67 r
.4743 .45173 .47756 .45519 .48353 .43952 .48029 .43615 Mtetra
.954 .62 .341 r
.48029 .43615 .48353 .43952 .48895 .47116 .48567 .46889 Mtetra
.955 .652 .417 r
.48567 .46889 .48895 .47116 .49422 .53283 .49087 .5321 Mtetra
.948 .636 .412 r
.49087 .5321 .49422 .53283 .49981 .58486 .49641 .58509 Mtetra
.636 .088 0 r
.49641 .58509 .49981 .58486 .50586 .58934 .50248 .5892 Mtetra
.969 .742 .539 r
.50248 .5892 .50586 .58934 .51215 .54083 .50883 .53921 Mtetra
.963 .72 .523 r
.50883 .53921 .51215 .54083 .51833 .47213 .51509 .46902 Mtetra
.954 .725 .554 r
.51509 .46902 .51833 .47213 .52428 .42813 .52109 .42449 Mtetra
.713 .241 0 r
.52109 .42449 .52428 .42813 .53017 .43625 .52698 .43334 Mtetra
.96 .648 .39 r
.52698 .43334 .53017 .43625 .53627 .49277 .53304 .49148 Mtetra
.956 .65 .411 r
.53304 .49148 .53627 .49277 .54267 .56329 .53939 .56357 Mtetra
.937 .602 .373 r
.53939 .56357 .54267 .56329 .54911 .59958 .54581 .60025 Mtetra
.984 .801 .577 r
.54581 .60025 .54911 .59958 .55515 .57377 .55188 .57328 Mtetra
.971 .725 .507 r
.55188 .57328 .55515 .57377 .56064 .50295 .55743 .50064 Mtetra
.965 .718 .513 r
.55743 .50064 .56064 .50295 .56591 .43446 .56276 .43091 Mtetra
.943 .745 .607 r
.56276 .43091 .56591 .43446 .57158 .41017 .56847 .40665 Mtetra
.955 .612 .299 r
.56847 .40665 .57158 .41017 .57813 .44353 .57501 .44126 Mtetra
.962 .651 .389 r
.57501 .44126 .57813 .44353 .5855 .51422 .58235 .51373 Mtetra
.955 .638 .389 r
.58235 .51373 .5855 .51422 .59298 .57634 .58981 .57704 Mtetra
.801 .333 .118 r
.58981 .57704 .59298 .57634 .59955 .58543 .59638 .58582 Mtetra
.981 .746 .507 r
.59638 .58582 .59955 .58543 .60473 .53361 .60159 .53238 Mtetra
.973 .721 .491 r
.60159 .53238 .60473 .53361 .60909 .45642 .60599 .45347 Mtetra
.967 .724 .518 r
.60599 .45347 .60909 .45642 .61382 .40265 .61076 .39891 Mtetra
.509 .673 .938 r
.61076 .39891 .61382 .40265 .61994 .40212 .61689 .39888 Mtetra
.962 .633 .332 r
.61689 .39888 .61994 .40212 .62767 .45261 .62464 .45082 Mtetra
.962 .643 .367 r
.62464 .45082 .62767 .45261 .63623 .52146 .6332 .52124 Mtetra
.946 .603 .336 r
.6332 .52124 .63623 .52146 .64407 .56169 .64104 .5621 Mtetra
.99 .853 .61 r
.64104 .5621 .64407 .56169 .64993 .54378 .6469 .54337 Mtetra
.981 .733 .483 r
.6469 .54337 .64993 .54378 .65394 .47982 .65092 .47779 Mtetra
.976 .723 .485 r
.65092 .47779 .65394 .47982 .65757 .41211 .65456 .40872 Mtetra
.964 .744 .558 r
.65456 .40872 .65757 .41211 .6625 .3803 .65952 .37656 Mtetra
.895 .492 .072 r
.65952 .37656 .6625 .3803 .66961 .3992 .66665 .39619 Mtetra
.962 .629 .315 r
.66665 .39619 .66961 .3992 .67849 .4538 .67555 .45214 Mtetra
.958 .623 .323 r
.67555 .45214 .67849 .4538 .68753 .507 .68461 .50649 Mtetra
.87 .428 .119 r
.68461 .50649 .68753 .507 .69483 .52119 .69192 .5208 Mtetra
.989 .771 .515 r
.69192 .5208 .69483 .52119 .69958 .48572 .69666 .48436 Mtetra
.982 .731 .474 r
.69666 .48436 .69958 .48572 .70281 .42477 .69989 .42203 Mtetra
.978 .733 .498 r
.69989 .42203 .70281 .42477 .70654 .37629 .70362 .37263 Mtetra
.899 .791 .732 r
.70362 .37263 .70654 .37629 .71234 .36606 .70943 .36236 Mtetra
.931 .558 .168 r
.70943 .36236 .71234 .36606 .72052 .39527 .71765 .39233 Mtetra
.955 .608 .266 r
.71765 .39233 .72052 .39527 .72993 .44176 .72709 .43989 Mtetra
.936 .562 .218 r
.72709 .43989 .72993 .44176 .73852 .47248 .73572 .47129 Mtetra
.903 .935 .823 r
.73572 .47129 .73852 .47248 .74473 .46524 .74193 .46386 Mtetra
.988 .755 .494 r
.74193 .46386 .74473 .46524 .74864 .42476 .74582 .42247 Mtetra
.984 .739 .483 r
.74582 .42247 .74864 .42476 .75192 .3774 .74908 .37412 Mtetra
.973 .761 .558 r
.74908 .37412 .75192 .3774 .75653 .35062 .75369 .3468 Mtetra
0 .21 .726 r
.75369 .3468 .75653 .35062 .76348 .35621 .76065 .35254 Mtetra
.92 .541 .129 r
.76065 .35254 .76348 .35621 .77232 .38572 .76953 .38271 Mtetra
.926 .547 .154 r
.76953 .38271 .77232 .38572 .78141 .41642 .77866 .41414 Mtetra
.686 .183 0 r
.77866 .41414 .78141 .41642 .7889 .42566 .78618 .42368 Mtetra
.982 .814 .599 r
.78618 .42368 .7889 .42566 .79407 .40641 .79136 .40408 Mtetra
.987 .758 .502 r
.79136 .40408 .79407 .40641 .79784 .37134 .79511 .36829 Mtetra
.982 .762 .531 r
.79511 .36829 .79784 .37134 .80199 .34195 .79923 .33826 Mtetra
.888 .806 .762 r
.79923 .33826 .80199 .34195 .8079 .33339 .80514 .32948 Mtetra
.681 .245 0 r
.80514 .32948 .8079 .33339 .81578 .34637 .81304 .3427 Mtetra
.858 .452 0 r
.81304 .3427 .81578 .34637 .82457 .36824 .82187 .36507 Mtetra
.74 .287 0 r
.82187 .36507 .82457 .36824 .83266 .38158 .83 .37882 Mtetra
.834 .864 .867 r
.83 .37882 .83266 .38158 .83897 .37601 .83633 .37326 Mtetra
.982 .795 .576 r
.83633 .37326 .83897 .37601 .84371 .35474 .84106 .35163 Mtetra
.982 .78 .557 r
.84106 .35163 .84371 .35474 .84814 .33107 .84547 .32746 Mtetra
.942 .806 .681 r
.84547 .32746 .84814 .33107 .85361 .31812 .85092 .31417 Mtetra
.283 .538 .917 r
.85092 .31417 .85361 .31812 .86067 .3204 .858 .31645 Mtetra
0 0 .4 r
.858 .31645 .86067 .3204 .86881 .33214 .86616 .32845 Mtetra
0 0 .484 r
.86616 .32845 .86881 .33214 .8768 .34194 .87419 .33854 Mtetra
.559 .735 .958 r
.87419 .33854 .8768 .34194 .88364 .34098 .88106 .33769 Mtetra
.942 .83 .705 r
.88106 .33769 .88364 .34098 .88926 .32925 .88668 .32581 Mtetra
.638 .763 .938 r
.28556 .514 .2891 .51685 .29451 .51539 .29097 .51253 Mtetra
.868 .765 .747 r
.29097 .51253 .29451 .51539 .30043 .50649 .29691 .50346 Mtetra
.882 .753 .714 r
.29691 .50346 .30043 .50649 .30649 .49525 .303 .49203 Mtetra
.805 .763 .814 r
.303 .49203 .30649 .49525 .31214 .49008 .30867 .4868 Mtetra
.69 .186 0 r
.30867 .4868 .31214 .49008 .31708 .49615 .3136 .49306 Mtetra
.927 .55 .262 r
.3136 .49306 .31708 .49615 .32153 .51096 .31802 .50821 Mtetra
.92 .534 .25 r
.31802 .50821 .32153 .51096 .3261 .52485 .32256 .52239 Mtetra
0 .39 .803 r
.32256 .52239 .3261 .52485 .3314 .5272 .32786 .52478 Mtetra
.904 .768 .701 r
.32786 .52478 .3314 .5272 .33758 .51433 .33407 .51164 Mtetra
.92 .74 .642 r
.33407 .51164 .33758 .51433 .34417 .49344 .34071 .49034 Mtetra
.902 .746 .678 r
.34071 .49034 .34417 .49344 .3504 .47836 .34698 .47502 Mtetra
.138 .495 .906 r
.34698 .47502 .3504 .47836 .35573 .48029 .3523 .47709 Mtetra
.941 .588 .317 r
.3523 .47709 .35573 .48029 .3602 .50004 .35673 .49733 Mtetra
.943 .613 .375 r
.35673 .49733 .3602 .50004 .36445 .52606 .36093 .5239 Mtetra
.914 .526 .255 r
.36093 .5239 .36445 .52606 .36934 .54046 .3658 .53855 Mtetra
.897 .812 .756 r
.3658 .53855 .36934 .54046 .37534 .53131 .37183 .52914 Mtetra
.937 .739 .608 r
.37183 .52914 .37534 .53131 .38217 .50278 .37873 .49999 Mtetra
.933 .731 .606 r
.37873 .49999 .38217 .50278 .38895 .47338 .38557 .47008 Mtetra
.874 .76 .733 r
.38557 .47008 .38895 .47338 .39489 .46349 .39152 .46015 Mtetra
.938 .572 .274 r
.39152 .46015 .39489 .46349 .39973 .48192 .39633 .47912 Mtetra
.949 .636 .405 r
.39633 .47912 .39973 .48192 .40396 .51938 .4005 .51743 Mtetra
.942 .62 .395 r
.4005 .51743 .40396 .51938 .40851 .55197 .405 .55063 Mtetra
.529 0 0 r
.405 .55063 .40851 .55197 .41413 .55579 .41062 .55434 Mtetra
.95 .748 .597 r
.41062 .55434 .41413 .55579 .42084 .52562 .4174 .52339 Mtetra
.948 .725 .567 r
.4174 .52339 .42084 .52562 .42789 .48083 .42453 .47772 Mtetra
.936 .731 .602 r
.42453 .47772 .42789 .48083 .43438 .45156 .43107 .44808 Mtetra
.685 .197 0 r
.43107 .44808 .43438 .45156 .43985 .45849 .43652 .45545 Mtetra
.954 .64 .398 r
.43652 .45545 .43985 .45849 .44452 .50024 .44113 .49826 Mtetra
.95 .645 .422 r
.44113 .49826 .44452 .50024 .44912 .55207 .44566 .55116 Mtetra
.931 .589 .361 r
.44566 .55116 .44912 .55207 .45445 .57847 .45097 .57785 Mtetra
.96 .794 .632 r
.45097 .57785 .45445 .57847 .46078 .55836 .45734 .55699 Mtetra
.958 .726 .546 r
.45734 .55699 .46078 .55836 .46764 .50393 .46429 .50131 Mtetra
.952 .72 .55 r
.46429 .50131 .46764 .50393 .4743 .45173 .47102 .44825 Mtetra
.912 .753 .671 r
.47102 .44825 .4743 .45173 .48029 .43615 .47703 .43277 Mtetra
.955 .623 .346 r
.47703 .43277 .48029 .43615 .48567 .46889 .48237 .46657 Mtetra
.956 .652 .418 r
.48237 .46657 .48567 .46889 .49087 .5321 .48751 .53122 Mtetra
.948 .638 .412 r
.48751 .53122 .49087 .5321 .49641 .58509 .49299 .58511 Mtetra
.596 .031 0 r
.49299 .58511 .49641 .58509 .50248 .5892 .49907 .58883 Mtetra
.968 .739 .538 r
.49907 .58883 .50248 .5892 .50883 .53921 .5055 .53743 Mtetra
.962 .718 .522 r
.5055 .53743 .50883 .53921 .51509 .46902 .51184 .46584 Mtetra
.953 .724 .553 r
.51184 .46584 .51509 .46902 .52109 .42449 .51789 .42084 Mtetra
.753 .287 0 r
.51789 .42084 .52109 .42449 .52698 .43334 .52378 .43041 Mtetra
.96 .649 .392 r
.52378 .43041 .52698 .43334 .53304 .49148 .52979 .49009 Mtetra
.956 .651 .412 r
.52979 .49009 .53304 .49148 .53939 .56357 .53609 .56365 Mtetra
.938 .603 .371 r
.53609 .56365 .53939 .56357 .54581 .60025 .54249 .60066 Mtetra
.982 .794 .575 r
.54249 .60066 .54581 .60025 .55188 .57328 .54859 .57257 Mtetra
.97 .724 .506 r
.54859 .57257 .55188 .57328 .55743 .50064 .55421 .4982 Mtetra
.965 .717 .512 r
.55421 .4982 .55743 .50064 .56276 .43091 .5596 .42732 Mtetra
.942 .745 .607 r
.5596 .42732 .56276 .43091 .56847 .40665 .56534 .40312 Mtetra
.956 .615 .305 r
.56534 .40312 .56847 .40665 .57501 .44126 .57187 .43893 Mtetra
.962 .651 .39 r
.57187 .43893 .57501 .44126 .58235 .51373 .57918 .51309 Mtetra
.955 .639 .389 r
.57918 .51309 .58235 .51373 .58981 .57704 .58661 .57751 Mtetra
.794 .316 .089 r
.58661 .57751 .58981 .57704 .59638 .58582 .59319 .58595 Mtetra
.98 .743 .507 r
.59319 .58595 .59638 .58582 .60159 .53238 .59843 .53097 Mtetra
.973 .719 .491 r
.59843 .53097 .60159 .53238 .60599 .45347 .60287 .45043 Mtetra
.967 .724 .517 r
.60287 .45043 .60599 .45347 .61076 .39891 .60768 .39516 Mtetra
.457 .647 .94 r
.60768 .39516 .61076 .39891 .61689 .39888 .61384 .39562 Mtetra
.962 .635 .334 r
.61384 .39562 .61689 .39888 .62464 .45082 .62158 .44895 Mtetra
.962 .644 .368 r
.62158 .44895 .62464 .45082 .6332 .52124 .63014 .52085 Mtetra
.947 .604 .334 r
.63014 .52085 .6332 .52124 .64104 .5621 .63797 .56227 Mtetra
.988 .843 .607 r
.63797 .56227 .64104 .5621 .6469 .54337 .64384 .54275 Mtetra
.98 .731 .483 r
.64384 .54275 .6469 .54337 .65092 .47779 .64787 .47561 Mtetra
.975 .722 .485 r
.64787 .47561 .65092 .47779 .65456 .40872 .65154 .40527 Mtetra
.964 .743 .557 r
.65154 .40527 .65456 .40872 .65952 .37656 .65652 .37281 Mtetra
.901 .501 .085 r
.65652 .37281 .65952 .37656 .66665 .39619 .66367 .39315 Mtetra
.962 .631 .317 r
.66367 .39315 .66665 .39619 .67555 .45214 .67259 .45038 Mtetra
.958 .624 .323 r
.67259 .45038 .67555 .45214 .68461 .50649 .68167 .5058 Mtetra
.87 .427 .111 r
.68167 .5058 .68461 .50649 .69192 .5208 .68898 .5202 Mtetra
.988 .768 .515 r
.68898 .5202 .69192 .5208 .69666 .48436 .69373 .48282 Mtetra
.982 .729 .474 r
.69373 .48282 .69666 .48436 .69989 .42203 .69695 .4192 Mtetra
.977 .732 .497 r
.69695 .4192 .69989 .42203 .70362 .37263 .70068 .36895 Mtetra
.899 .79 .731 r
.70068 .36895 .70362 .37263 .70943 .36236 .70652 .35866 Mtetra
.933 .562 .173 r
.70652 .35866 .70943 .36236 .71765 .39233 .71475 .38935 Mtetra
.956 .61 .268 r
.71475 .38935 .71765 .39233 .72709 .43989 .72423 .43791 Mtetra
.937 .564 .218 r
.72423 .43791 .72709 .43989 .73572 .47129 .73288 .46994 Mtetra
.906 .925 .818 r
.73288 .46994 .73572 .47129 .74193 .46386 .7391 .46232 Mtetra
.987 .753 .493 r
.7391 .46232 .74193 .46386 .74582 .42247 .74299 .42008 Mtetra
.983 .737 .482 r
.74299 .42008 .74582 .42247 .74908 .37412 .74623 .37078 Mtetra
.973 .76 .556 r
.74623 .37078 .74908 .37412 .75369 .3468 .75083 .34297 Mtetra
0 .196 .716 r
.75083 .34297 .75369 .3468 .76065 .35254 .75782 .34885 Mtetra
.922 .544 .134 r
.75782 .34885 .76065 .35254 .76953 .38271 .76673 .37965 Mtetra
.927 .55 .157 r
.76673 .37965 .76953 .38271 .77866 .41414 .7759 .41176 Mtetra
.69 .192 0 r
.7759 .41176 .77866 .41414 .78618 .42368 .78344 .42156 Mtetra
.981 .811 .598 r
.78344 .42156 .78618 .42368 .79136 .40408 .78862 .40165 Mtetra
.987 .756 .501 r
.78862 .40165 .79136 .40408 .79511 .36829 .79236 .36518 Mtetra
.982 .76 .529 r
.79236 .36518 .79511 .36829 .79923 .33826 .79646 .33455 Mtetra
.891 .805 .758 r
.79646 .33455 .79923 .33826 .80514 .32948 .80237 .32555 Mtetra
.689 .254 0 r
.80237 .32555 .80514 .32948 .81304 .3427 .81029 .339 Mtetra
.862 .457 0 r
.81029 .339 .81304 .3427 .82187 .36507 .81915 .36185 Mtetra
.747 .296 0 r
.81915 .36185 .82187 .36507 .83 .37882 .82732 .37597 Mtetra
.832 .859 .866 r
.82732 .37597 .83 .37882 .83633 .37326 .83367 .37043 Mtetra
.982 .793 .574 r
.83367 .37043 .83633 .37326 .84106 .35163 .8384 .34845 Mtetra
.982 .778 .554 r
.8384 .34845 .84106 .35163 .84547 .32746 .84278 .32381 Mtetra
.944 .805 .676 r
.84278 .32381 .84547 .32746 .85092 .31417 .84823 .31021 Mtetra
.284 .539 .917 r
.84823 .31021 .85092 .31417 .858 .31645 .85531 .31248 Mtetra
.593 .162 0 r
.85531 .31248 .858 .31645 .86616 .32845 .8635 .32471 Mtetra
0 0 .47 r
.8635 .32471 .86616 .32845 .87419 .33854 .87157 .33509 Mtetra
.551 .728 .957 r
.87157 .33509 .87419 .33854 .88106 .33769 .87846 .33435 Mtetra
.942 .827 .703 r
.87846 .33435 .88106 .33769 .88668 .32581 .88408 .32232 Mtetra
.639 .762 .937 r
.28199 .51113 .28556 .514 .29097 .51253 .28741 .50963 Mtetra
.869 .764 .745 r
.28741 .50963 .29097 .51253 .29691 .50346 .29338 .50041 Mtetra
.883 .752 .713 r
.29338 .50041 .29691 .50346 .303 .49203 .2995 .48879 Mtetra
.806 .762 .813 r
.2995 .48879 .303 .49203 .30867 .4868 .30518 .48351 Mtetra
.706 .205 0 r
.30518 .48351 .30867 .4868 .3136 .49306 .3101 .48994 Mtetra
.929 .554 .269 r
.3101 .48994 .3136 .49306 .31802 .50821 .31448 .50542 Mtetra
.921 .538 .255 r
.31448 .50542 .31802 .50821 .32256 .52239 .319 .51988 Mtetra
0 .388 .804 r
.319 .51988 .32256 .52239 .32786 .52478 .3243 .5223 Mtetra
.905 .766 .698 r
.3243 .5223 .32786 .52478 .33407 .51164 .33055 .50889 Mtetra
.92 .739 .641 r
.33055 .50889 .33407 .51164 .34071 .49034 .33724 .48721 Mtetra
.903 .745 .676 r
.33724 .48721 .34071 .49034 .34698 .47502 .34354 .47168 Mtetra
.108 .477 .896 r
.34354 .47168 .34698 .47502 .3523 .47709 .34886 .47388 Mtetra
.941 .591 .322 r
.34886 .47388 .3523 .47709 .35673 .49733 .35324 .49458 Mtetra
.943 .614 .378 r
.35324 .49458 .35673 .49733 .36093 .5239 .35739 .52168 Mtetra
.916 .529 .257 r
.35739 .52168 .36093 .5239 .3658 .53855 .36225 .53655 Mtetra
.897 .807 .751 r
.36225 .53655 .3658 .53855 .37183 .52914 .36831 .52688 Mtetra
.937 .737 .607 r
.36831 .52688 .37183 .52914 .37873 .49999 .37527 .49715 Mtetra
.933 .73 .605 r
.37527 .49715 .37873 .49999 .38557 .47008 .38217 .46674 Mtetra
.874 .759 .732 r
.38217 .46674 .38557 .47008 .39152 .46015 .38814 .45679 Mtetra
.939 .576 .282 r
.38814 .45679 .39152 .46015 .39633 .47912 .39291 .47628 Mtetra
.949 .637 .407 r
.39291 .47628 .39633 .47912 .4005 .51743 .39701 .5154 Mtetra
.943 .622 .396 r
.39701 .5154 .4005 .51743 .405 .55063 .40146 .54918 Mtetra
.5 0 0 r
.40146 .54918 .405 .55063 .41062 .55434 .4071 .55278 Mtetra
.949 .746 .595 r
.4071 .55278 .41062 .55434 .4174 .52339 .41394 .52108 Mtetra
.947 .724 .567 r
.41394 .52108 .4174 .52339 .42453 .47772 .42116 .47457 Mtetra
.936 .731 .601 r
.42116 .47457 .42453 .47772 .43107 .44808 .42774 .44458 Mtetra
.718 .234 0 r
.42774 .44458 .43107 .44808 .43652 .45545 .43318 .45238 Mtetra
.954 .642 .401 r
.43318 .45238 .43652 .45545 .44113 .49826 .43772 .49621 Mtetra
.95 .646 .423 r
.43772 .49621 .44113 .49826 .44566 .55116 .44218 .55011 Mtetra
.933 .591 .36 r
.44218 .55011 .44566 .55116 .45097 .57785 .44747 .57707 Mtetra
.959 .789 .629 r
.44747 .57707 .45097 .57785 .45734 .55699 .45389 .55549 Mtetra
.957 .725 .545 r
.45389 .55549 .45734 .55699 .46429 .50131 .46093 .4986 Mtetra
.952 .719 .55 r
.46093 .4986 .46429 .50131 .47102 .44825 .46774 .44474 Mtetra
.911 .753 .672 r
.46774 .44474 .47102 .44825 .47703 .43277 .47377 .42937 Mtetra
.955 .625 .351 r
.47377 .42937 .47703 .43277 .48237 .46657 .47906 .46419 Mtetra
.956 .653 .419 r
.47906 .46419 .48237 .46657 .48751 .53122 .48412 .53022 Mtetra
.949 .639 .412 r
.48412 .53022 .48751 .53122 .49299 .58511 .48956 .58495 Mtetra
.548 0 0 r
.48956 .58495 .49299 .58511 .49907 .58883 .49565 .58829 Mtetra
.967 .737 .537 r
.49565 .58829 .49907 .58883 .5055 .53743 .50215 .53552 Mtetra
.962 .717 .522 r
.50215 .53552 .5055 .53743 .51184 .46584 .50858 .46261 Mtetra
.953 .724 .553 r
.50858 .46261 .51184 .46584 .51789 .42084 .51468 .41718 Mtetra
.785 .326 0 r
.51468 .41718 .51789 .42084 .52378 .43041 .52056 .42745 Mtetra
.96 .65 .393 r
.52056 .42745 .52378 .43041 .52979 .49009 .52653 .4886 Mtetra
.957 .652 .412 r
.52653 .4886 .52979 .49009 .53609 .56365 .53277 .56355 Mtetra
.939 .605 .37 r
.53277 .56355 .53609 .56365 .54249 .60066 .53915 .60087 Mtetra
.98 .788 .573 r
.53915 .60087 .54249 .60066 .54859 .57257 .54528 .57169 Mtetra
.97 .722 .506 r
.54528 .57169 .54859 .57257 .55421 .4982 .55097 .49566 Mtetra
.965 .717 .512 r
.55097 .49566 .55421 .4982 .5596 .42732 .55643 .4237 Mtetra
.942 .745 .608 r
.55643 .4237 .5596 .42732 .56534 .40312 .5622 .39958 Mtetra
.957 .617 .31 r
.5622 .39958 .56534 .40312 .57187 .43893 .56872 .43654 Mtetra
.962 .652 .391 r
.56872 .43654 .57187 .43893 .57918 .51309 .57599 .51232 Mtetra
.956 .64 .388 r
.57599 .51232 .57918 .51309 .58661 .57751 .58339 .57778 Mtetra
.785 .298 .06 r
.58339 .57778 .58661 .57751 .59319 .58595 .58997 .58587 Mtetra
.979 .741 .507 r
.58997 .58587 .59319 .58595 .59843 .53097 .59524 .5294 Mtetra
.972 .718 .49 r
.59524 .5294 .59843 .53097 .60287 .45043 .59974 .44732 Mtetra
.967 .723 .517 r
.59974 .44732 .60287 .45043 .60768 .39516 .60459 .39139 Mtetra
.4 .618 .939 r
.60459 .39139 .60768 .39516 .61384 .39562 .61077 .39234 Mtetra
.963 .636 .337 r
.61077 .39234 .61384 .39562 .62158 .44895 .61851 .447 Mtetra
.962 .645 .369 r
.61851 .447 .62158 .44895 .63014 .52085 .62705 .5203 Mtetra
.948 .605 .333 r
.62705 .5203 .63014 .52085 .63797 .56227 .63488 .56224 Mtetra
.987 .834 .604 r
.63488 .56224 .63797 .56227 .64384 .54275 .64075 .54195 Mtetra
.98 .729 .483 r
.64075 .54195 .64384 .54275 .64787 .47561 .64481 .47331 Mtetra
.975 .721 .485 r
.64481 .47331 .64787 .47561 .65154 .40527 .64851 .40179 Mtetra
.963 .743 .556 r
.64851 .40179 .65154 .40527 .65652 .37281 .65351 .36905 Mtetra
.905 .509 .098 r
.65351 .36905 .65652 .37281 .66367 .39315 .66068 .39006 Mtetra
.962 .632 .318 r
.66068 .39006 .66367 .39315 .67259 .45038 .66961 .44852 Mtetra
.959 .625 .324 r
.66961 .44852 .67259 .45038 .68167 .5058 .6787 .50495 Mtetra
.87 .427 .103 r
.6787 .50495 .68167 .5058 .68898 .5202 .68602 .51943 Mtetra
.987 .765 .514 r
.68602 .51943 .68898 .5202 .69373 .48282 .69077 .48114 Mtetra
.981 .728 .473 r
.69077 .48114 .69373 .48282 .69695 .4192 .694 .4163 Mtetra
.977 .731 .496 r
.694 .4163 .69695 .4192 .70068 .36895 .69774 .36524 Mtetra
.899 .79 .731 r
.69774 .36524 .70068 .36895 .70652 .35866 .70359 .35493 Mtetra
.935 .565 .179 r
.70359 .35493 .70652 .35866 .71475 .38935 .71185 .38631 Mtetra
.956 .611 .27 r
.71185 .38631 .71475 .38935 .72423 .43791 .72135 .43584 Mtetra
.938 .566 .219 r
.72135 .43584 .72423 .43791 .73288 .46994 .73003 .46846 Mtetra
.909 .916 .812 r
.73003 .46846 .73288 .46994 .7391 .46232 .73625 .46064 Mtetra
.987 .751 .493 r
.73625 .46064 .7391 .46232 .74299 .42008 .74013 .41759 Mtetra
.983 .736 .481 r
.74013 .41759 .74299 .42008 .74623 .37078 .74337 .3674 Mtetra
.973 .759 .554 r
.74337 .3674 .74623 .37078 .75083 .34297 .74797 .33912 Mtetra
0 .183 .705 r
.74797 .33912 .75083 .34297 .75782 .34885 .75497 .34514 Mtetra
.923 .547 .138 r
.75497 .34514 .75782 .34885 .76673 .37965 .76391 .37653 Mtetra
.929 .553 .16 r
.76391 .37653 .76673 .37965 .7759 .41176 .77311 .40929 Mtetra
.694 .2 0 r
.77311 .40929 .7759 .41176 .78344 .42156 .78068 .41935 Mtetra
.981 .807 .596 r
.78068 .41935 .78344 .42156 .78862 .40165 .78587 .39912 Mtetra
.987 .754 .5 r
.78587 .39912 .78862 .40165 .79236 .36518 .78959 .36201 Mtetra
.981 .759 .527 r
.78959 .36201 .79236 .36518 .79646 .33455 .79368 .3308 Mtetra
.893 .805 .754 r
.79368 .3308 .79646 .33455 .80237 .32555 .79958 .3216 Mtetra
.697 .262 0 r
.79958 .3216 .80237 .32555 .81029 .339 .80752 .33527 Mtetra
.865 .462 0 r
.80752 .33527 .81029 .339 .81915 .36185 .81642 .35857 Mtetra
.753 .305 0 r
.81642 .35857 .81915 .36185 .82732 .37597 .82462 .37306 Mtetra
.83 .855 .865 r
.82462 .37306 .82732 .37597 .83367 .37043 .83099 .36753 Mtetra
.982 .791 .572 r
.83099 .36753 .83367 .37043 .8384 .34845 .83572 .34522 Mtetra
.982 .776 .552 r
.83572 .34522 .8384 .34845 .84278 .32381 .84009 .32013 Mtetra
.945 .803 .672 r
.84009 .32013 .84278 .32381 .84823 .31021 .84552 .30623 Mtetra
.284 .539 .917 r
.84552 .30623 .84823 .31021 .85531 .31248 .85261 .30849 Mtetra
.602 .172 0 r
.85261 .30849 .85531 .31248 .8635 .32471 .86083 .32095 Mtetra
0 0 .457 r
.86083 .32095 .8635 .32471 .87157 .33509 .86893 .33159 Mtetra
.543 .722 .956 r
.86893 .33159 .87157 .33509 .87846 .33435 .87584 .33095 Mtetra
.942 .826 .7 r
.87584 .33095 .87846 .33435 .88408 .32232 .88147 .31879 Mtetra
.641 .761 .935 r
.27842 .50822 .28199 .51113 .28741 .50963 .28384 .5067 Mtetra
.869 .763 .742 r
.28384 .5067 .28741 .50963 .29338 .50041 .28984 .49733 Mtetra
.884 .751 .711 r
.28984 .49733 .29338 .50041 .2995 .48879 .29599 .48553 Mtetra
.806 .762 .812 r
.29599 .48553 .2995 .48879 .30518 .48351 .30168 .48021 Mtetra
.72 .222 0 r
.30168 .48021 .30518 .48351 .3101 .48994 .30659 .4868 Mtetra
.93 .557 .274 r
.30659 .4868 .3101 .48994 .31448 .50542 .31094 .50259 Mtetra
.923 .541 .259 r
.31094 .50259 .31448 .50542 .319 .51988 .31543 .51732 Mtetra
0 .387 .806 r
.31543 .51732 .319 .51988 .3243 .5223 .32073 .51976 Mtetra
.905 .764 .696 r
.32073 .51976 .3243 .5223 .33055 .50889 .32701 .5061 Mtetra
.92 .738 .639 r
.32701 .5061 .33055 .50889 .33724 .48721 .33376 .48406 Mtetra
.903 .744 .675 r
.33376 .48406 .33724 .48721 .34354 .47168 .34009 .46832 Mtetra
.079 .458 .885 r
.34009 .46832 .34354 .47168 .34886 .47388 .3454 .47065 Mtetra
.942 .593 .327 r
.3454 .47065 .34886 .47388 .35324 .49458 .34975 .49178 Mtetra
.944 .616 .38 r
.34975 .49178 .35324 .49458 .35739 .52168 .35385 .51938 Mtetra
.917 .532 .259 r
.35385 .51938 .35739 .52168 .36225 .53655 .35868 .53447 Mtetra
.897 .803 .747 r
.35868 .53447 .36225 .53655 .36831 .52688 .36478 .52455 Mtetra
.937 .736 .606 r
.36478 .52455 .36831 .52688 .37527 .49715 .3718 .49426 Mtetra
.933 .729 .604 r
.3718 .49426 .37527 .49715 .38217 .46674 .37876 .4634 Mtetra
.874 .759 .732 r
.37876 .4634 .38217 .46674 .38814 .45679 .38474 .45342 Mtetra
.941 .58 .288 r
.38474 .45342 .38814 .45679 .39291 .47628 .38948 .47341 Mtetra
.95 .638 .409 r
.38948 .47341 .39291 .47628 .39701 .5154 .39352 .51329 Mtetra
.944 .623 .397 r
.39352 .51329 .39701 .5154 .40146 .54918 .39792 .5476 Mtetra
.469 0 0 r
.39792 .5476 .40146 .54918 .4071 .55278 .40356 .5511 Mtetra
.948 .744 .594 r
.40356 .5511 .4071 .55278 .41394 .52108 .41047 .51869 Mtetra
.947 .723 .566 r
.41047 .51869 .41394 .52108 .42116 .47457 .41777 .47138 Mtetra
.936 .73 .6 r
.41777 .47138 .42116 .47457 .42774 .44458 .4244 .44108 Mtetra
.746 .266 0 r
.4244 .44108 .42774 .44458 .43318 .45238 .42983 .44929 Mtetra
.954 .643 .403 r
.42983 .44929 .43318 .45238 .43772 .49621 .4343 .49409 Mtetra
.951 .647 .424 r
.4343 .49409 .43772 .49621 .44218 .55011 .43869 .54894 Mtetra
.934 .592 .359 r
.43869 .54894 .44218 .55011 .44747 .57707 .44395 .57614 Mtetra
.957 .784 .626 r
.44395 .57614 .44747 .57707 .45389 .55549 .45042 .55385 Mtetra
.957 .724 .544 r
.45042 .55385 .45389 .55549 .46093 .4986 .45755 .49583 Mtetra
.952 .719 .549 r
.45755 .49583 .46093 .4986 .46774 .44474 .46443 .44121 Mtetra
.91 .753 .674 r
.46443 .44121 .46774 .44474 .47377 .42937 .47049 .42596 Mtetra
.955 .627 .354 r
.47049 .42596 .47377 .42937 .47906 .46419 .47574 .46175 Mtetra
.956 .654 .42 r
.47574 .46175 .47906 .46419 .48412 .53022 .48072 .52909 Mtetra
.95 .64 .412 r
.48072 .52909 .48412 .53022 .48956 .58495 .4861 .58461 Mtetra
.488 0 0 r
.4861 .58461 .48956 .58495 .49565 .58829 .4922 .58756 Mtetra
.966 .735 .537 r
.4922 .58756 .49565 .58829 .50215 .53552 .49878 .5335 Mtetra
.961 .716 .522 r
.49878 .5335 .50215 .53552 .50858 .46261 .5053 .45934 Mtetra
.953 .723 .552 r
.5053 .45934 .50858 .46261 .51468 .41718 .51146 .41351 Mtetra
.81 .358 0 r
.51146 .41351 .51468 .41718 .52056 .42745 .51733 .42445 Mtetra
.96 .651 .395 r
.51733 .42445 .52056 .42745 .52653 .4886 .52324 .48701 Mtetra
.957 .653 .413 r
.52324 .48701 .52653 .4886 .53277 .56355 .52942 .56328 Mtetra
.94 .606 .368 r
.52942 .56328 .53277 .56355 .53915 .60087 .53578 .60086 Mtetra
.978 .782 .571 r
.53578 .60086 .53915 .60087 .54528 .57169 .54195 .57063 Mtetra
.969 .721 .506 r
.54195 .57063 .54528 .57169 .55097 .49566 .54771 .49303 Mtetra
.964 .716 .512 r
.54771 .49303 .55097 .49566 .55643 .4237 .55324 .42006 Mtetra
.942 .745 .609 r
.55324 .42006 .55643 .4237 .5622 .39958 .55904 .39603 Mtetra
.957 .62 .314 r
.55904 .39603 .5622 .39958 .56872 .43654 .56555 .4341 Mtetra
.962 .653 .391 r
.56555 .4341 .56872 .43654 .57599 .51232 .57278 .5114 Mtetra
.956 .641 .388 r
.57278 .5114 .57599 .51232 .58339 .57778 .58015 .57783 Mtetra
.774 .277 .027 r
.58015 .57783 .58339 .57778 .58997 .58587 .58673 .58558 Mtetra
.978 .739 .507 r
.58673 .58558 .58997 .58587 .59524 .5294 .59204 .52768 Mtetra
.972 .717 .49 r
.59204 .52768 .59524 .5294 .59974 .44732 .59659 .44415 Mtetra
.966 .722 .516 r
.59659 .44415 .59974 .44732 .60459 .39139 .60149 .38761 Mtetra
.339 .585 .934 r
.60149 .38761 .60459 .39139 .61077 .39234 .60769 .38903 Mtetra
.963 .637 .339 r
.60769 .38903 .61077 .39234 .61851 .447 .61542 .44495 Mtetra
.963 .646 .369 r
.61542 .44495 .61851 .447 .62705 .5203 .62395 .51959 Mtetra
.948 .607 .332 r
.62395 .51959 .62705 .5203 .63488 .56224 .63176 .56201 Mtetra
.986 .827 .601 r
.63176 .56201 .63488 .56224 .64075 .54195 .63764 .54096 Mtetra
.979 .728 .483 r
.63764 .54096 .64075 .54195 .64481 .47331 .64173 .47091 Mtetra
.975 .72 .484 r
.64173 .47091 .64481 .47331 .64851 .40179 .64546 .39826 Mtetra
.963 .742 .556 r
.64546 .39826 .64851 .40179 .65351 .36905 .65049 .36527 Mtetra
.909 .516 .109 r
.65049 .36527 .65351 .36905 .66068 .39006 .65768 .38694 Mtetra
.963 .633 .32 r
.65768 .38694 .66068 .39006 .66961 .44852 .66662 .44656 Mtetra
.959 .626 .324 r
.66662 .44656 .66961 .44852 .6787 .50495 .67571 .50394 Mtetra
.87 .426 .095 r
.67571 .50394 .6787 .50495 .68602 .51943 .68303 .51849 Mtetra
.986 .762 .514 r
.68303 .51849 .68602 .51943 .69077 .48114 .68778 .47933 Mtetra
.981 .727 .473 r
.68778 .47933 .69077 .48114 .694 .4163 .69102 .41332 Mtetra
.977 .73 .496 r
.69102 .41332 .694 .4163 .69774 .36524 .69478 .36151 Mtetra
.898 .789 .731 r
.69478 .36151 .69774 .36524 .70359 .35493 .70065 .35119 Mtetra
.936 .568 .183 r
.70065 .35119 .70359 .35493 .71185 .38631 .70892 .38323 Mtetra
.957 .613 .271 r
.70892 .38323 .71185 .38631 .72135 .43584 .71845 .43366 Mtetra
.939 .568 .219 r
.71845 .43366 .72135 .43584 .73003 .46846 .72714 .46684 Mtetra
.91 .908 .807 r
.72714 .46684 .73003 .46846 .73625 .46064 .73338 .45884 Mtetra
.986 .749 .492 r
.73338 .45884 .73625 .46064 .74013 .41759 .73726 .415 Mtetra
.983 .735 .48 r
.73726 .415 .74013 .41759 .74337 .3674 .74049 .36397 Mtetra
.973 .757 .553 r
.74049 .36397 .74337 .3674 .74797 .33912 .74509 .33525 Mtetra
0 .17 .695 r
.74509 .33525 .74797 .33912 .75497 .34514 .75211 .3414 Mtetra
.925 .55 .142 r
.75211 .3414 .75497 .34514 .76391 .37653 .76107 .37336 Mtetra
.93 .555 .163 r
.76107 .37336 .76391 .37653 .77311 .40929 .7703 .40673 Mtetra
.698 .206 0 r
.7703 .40673 .77311 .40929 .78068 .41935 .7779 .41703 Mtetra
.98 .804 .595 r
.7779 .41703 .78068 .41935 .78587 .39912 .78309 .3965 Mtetra
.986 .753 .499 r
.78309 .3965 .78587 .39912 .78959 .36201 .7868 .35878 Mtetra
.981 .757 .525 r
.7868 .35878 .78959 .36201 .79368 .3308 .79088 .32703 Mtetra
.895 .804 .751 r
.79088 .32703 .79368 .3308 .79958 .3216 .79679 .31764 Mtetra
.704 .269 0 r
.79679 .31764 .79958 .3216 .80752 .33527 .80474 .33152 Mtetra
.868 .466 .004 r
.80474 .33152 .80752 .33527 .81642 .35857 .81368 .35524 Mtetra
.759 .313 0 r
.81368 .35524 .81642 .35857 .82462 .37306 .82191 .37007 Mtetra
.828 .851 .864 r
.82191 .37007 .82462 .37306 .83099 .36753 .8283 .36455 Mtetra
.981 .789 .571 r
.8283 .36455 .83099 .36753 .83572 .34522 .83302 .34193 Mtetra
.982 .775 .549 r
.83302 .34193 .83572 .34522 .84009 .32013 .83738 .31641 Mtetra
.947 .802 .668 r
.83738 .31641 .84009 .32013 .84552 .30623 .8428 .30224 Mtetra
.285 .539 .917 r
.8428 .30224 .84552 .30623 .85261 .30849 .8499 .30448 Mtetra
.611 .18 0 r
.8499 .30448 .85261 .30849 .86083 .32095 .85814 .31715 Mtetra
0 0 .445 r
.85814 .31715 .86083 .32095 .86893 .33159 .86627 .32805 Mtetra
.535 .716 .956 r
.86627 .32805 .86893 .33159 .87584 .33095 .87321 .3275 Mtetra
.942 .824 .699 r
.87321 .3275 .87584 .33095 .88147 .31879 .87884 .31521 Mtetra
.642 .759 .933 r
.27483 .50527 .27842 .50822 .28384 .5067 .28026 .50373 Mtetra
.87 .761 .74 r
.28026 .50373 .28384 .5067 .28984 .49733 .28629 .49422 Mtetra
.884 .75 .709 r
.28629 .49422 .28984 .49733 .29599 .48553 .29247 .48226 Mtetra
.807 .762 .811 r
.29247 .48226 .29599 .48553 .30168 .48021 .29817 .4769 Mtetra
.733 .237 0 r
.29817 .4769 .30168 .48021 .30659 .4868 .30306 .48364 Mtetra
.931 .56 .279 r
.30306 .48364 .30659 .4868 .31094 .50259 .30738 .49971 Mtetra
.924 .544 .263 r
.30738 .49971 .31094 .50259 .31543 .51732 .31184 .51468 Mtetra
0 .388 .81 r
.31184 .51468 .31543 .51732 .32073 .51976 .31715 .51715 Mtetra
.904 .762 .693 r
.31715 .51715 .32073 .51976 .32701 .5061 .32347 .50325 Mtetra
.92 .737 .638 r
.32347 .50325 .32701 .5061 .33376 .48406 .33026 .48088 Mtetra
.903 .744 .673 r
.33026 .48088 .33376 .48406 .34009 .46832 .33663 .46494 Mtetra
.051 .44 .874 r
.33663 .46494 .34009 .46832 .3454 .47065 .34193 .4674 Mtetra
.942 .596 .33 r
.34193 .4674 .3454 .47065 .34975 .49178 .34624 .48893 Mtetra
.944 .618 .382 r
.34624 .48893 .34975 .49178 .35385 .51938 .35029 .51699 Mtetra
.919 .534 .259 r
.35029 .51699 .35385 .51938 .35868 .53447 .3551 .53228 Mtetra
.897 .798 .742 r
.3551 .53228 .35868 .53447 .36478 .52455 .36123 .52212 Mtetra
.936 .734 .604 r
.36123 .52212 .36478 .52455 .3718 .49426 .36831 .49131 Mtetra
.933 .728 .603 r
.36831 .49131 .3718 .49426 .37876 .4634 .37534 .46002 Mtetra
.874 .759 .732 r
.37534 .46002 .37876 .4634 .38474 .45342 .38133 .45004 Mtetra
.941 .583 .294 r
.38133 .45004 .38474 .45342 .38948 .47341 .38603 .47049 Mtetra
.95 .639 .41 r
.38603 .47049 .38948 .47341 .39352 .51329 .39001 .51108 Mtetra
.945 .625 .397 r
.39001 .51108 .39352 .51329 .39792 .5476 .39436 .54588 Mtetra
.428 0 0 r
.39436 .54588 .39792 .5476 .40356 .5511 .40002 .54926 Mtetra
.947 .742 .592 r
.40002 .54926 .40356 .5511 .41047 .51869 .40699 .51619 Mtetra
.947 .721 .565 r
.40699 .51619 .41047 .51869 .41777 .47138 .41437 .46814 Mtetra
.936 .729 .599 r
.41437 .46814 .41777 .47138 .4244 .44108 .42105 .43756 Mtetra
.768 .294 0 r
.42105 .43756 .4244 .44108 .42983 .44929 .42646 .44617 Mtetra
.954 .644 .404 r
.42646 .44617 .42983 .44929 .4343 .49409 .43086 .49186 Mtetra
.951 .648 .424 r
.43086 .49186 .4343 .49409 .43869 .54894 .43518 .54758 Mtetra
.935 .593 .357 r
.43518 .54758 .43869 .54894 .44395 .57614 .44042 .575 Mtetra
.955 .778 .623 r
.44042 .575 .44395 .57614 .45042 .55385 .44693 .55204 Mtetra
.956 .722 .544 r
.44693 .55204 .45042 .55385 .45755 .49583 .45416 .49297 Mtetra
.952 .718 .549 r
.45416 .49297 .45755 .49583 .46443 .44121 .46112 .43766 Mtetra
.91 .753 .675 r
.46112 .43766 .46443 .44121 .47049 .42596 .46719 .42254 Mtetra
.956 .629 .358 r
.46719 .42254 .47049 .42596 .47574 .46175 .4724 .45923 Mtetra
.957 .655 .421 r
.4724 .45923 .47574 .46175 .48072 .52909 .4773 .52778 Mtetra
.951 .641 .412 r
.4773 .52778 .48072 .52909 .4861 .58461 .48263 .58401 Mtetra
.406 0 0 r
.48263 .58401 .4861 .58461 .4922 .58756 .48874 .58658 Mtetra
.965 .732 .536 r
.48874 .58658 .4922 .58756 .49878 .5335 .4954 .53131 Mtetra
.961 .716 .521 r
.4954 .53131 .49878 .5335 .5053 .45934 .50201 .456 Mtetra
.953 .723 .552 r
.50201 .456 .5053 .45934 .51146 .41351 .50822 .40983 Mtetra
.83 .384 0 r
.50822 .40983 .51146 .41351 .51733 .42445 .51409 .42141 Mtetra
.961 .652 .396 r
.51409 .42141 .51733 .42445 .52324 .48701 .51994 .48528 Mtetra
.958 .654 .413 r
.51994 .48528 .52324 .48701 .52942 .56328 .52606 .56275 Mtetra
.942 .607 .365 r
.52606 .56275 .52942 .56328 .53578 .60086 .53239 .60055 Mtetra
.976 .776 .57 r
.53239 .60055 .53578 .60086 .54195 .57063 .5386 .56933 Mtetra
.968 .72 .506 r
.5386 .56933 .54195 .57063 .54771 .49303 .54444 .49027 Mtetra
.964 .715 .511 r
.54444 .49027 .54771 .49303 .55324 .42006 .55005 .41639 Mtetra
.941 .745 .609 r
.55005 .41639 .55324 .42006 .55904 .39603 .55588 .39246 Mtetra
.958 .622 .318 r
.55588 .39246 .55904 .39603 .56555 .4341 .56236 .43157 Mtetra
.963 .654 .392 r
.56236 .43157 .56555 .4341 .57278 .5114 .56955 .51028 Mtetra
.957 .642 .388 r
.56955 .51028 .57278 .5114 .58015 .57783 .57688 .5776 Mtetra
.76 .251 0 r
.57688 .5776 .58015 .57783 .58673 .58558 .58346 .585 Mtetra
.977 .736 .507 r
.58346 .585 .58673 .58558 .59204 .52768 .58882 .52577 Mtetra
.971 .716 .49 r
.58882 .52577 .59204 .52768 .59659 .44415 .59343 .4409 Mtetra
.966 .722 .516 r
.59343 .4409 .59659 .44415 .60149 .38761 .59838 .38381 Mtetra
.276 .548 .924 r
.59838 .38381 .60149 .38761 .60769 .38903 .60459 .38569 Mtetra
.963 .638 .341 r
.60459 .38569 .60769 .38903 .61542 .44495 .61231 .44279 Mtetra
.963 .647 .369 r
.61231 .44279 .61542 .44495 .62395 .51959 .62081 .51864 Mtetra
.949 .608 .33 r
.62081 .51864 .62395 .51959 .63176 .56201 .62862 .5615 Mtetra
.984 .818 .599 r
.62862 .5615 .63176 .56201 .63764 .54096 .63451 .53973 Mtetra
.978 .726 .483 r
.63451 .53973 .63764 .54096 .64173 .47091 .63862 .46836 Mtetra
.974 .719 .484 r
.63862 .46836 .64173 .47091 .64546 .39826 .6424 .39469 Mtetra
.963 .742 .555 r
.6424 .39469 .64546 .39826 .65049 .36527 .64746 .36148 Mtetra
.913 .522 .118 r
.64746 .36148 .65049 .36527 .65768 .38694 .65466 .38377 Mtetra
.963 .634 .321 r
.65466 .38377 .65768 .38694 .66662 .44656 .6636 .44446 Mtetra
.96 .627 .324 r
.6636 .44446 .66662 .44656 .67571 .50394 .67269 .50271 Mtetra
.869 .424 .082 r
.67269 .50271 .67571 .50394 .68303 .51849 .68001 .5173 Mtetra
.985 .759 .514 r
.68001 .5173 .68303 .51849 .68778 .47933 .68478 .47733 Mtetra
.98 .725 .473 r
.68478 .47733 .68778 .47933 .69102 .41332 .68803 .41024 Mtetra
.976 .729 .495 r
.68803 .41024 .69102 .41332 .69478 .36151 .69181 .35774 Mtetra
.898 .789 .732 r
.69181 .35774 .69478 .36151 .70065 .35119 .69769 .34743 Mtetra
.937 .57 .188 r
.69769 .34743 .70065 .35119 .70892 .38323 .70599 .38008 Mtetra
.957 .614 .272 r
.70599 .38008 .70892 .38323 .71845 .43366 .71553 .43135 Mtetra
.939 .57 .219 r
.71553 .43135 .71845 .43366 .72714 .46684 .72424 .46503 Mtetra
.911 .897 .802 r
.72424 .46503 .72714 .46684 .73338 .45884 .73048 .45685 Mtetra
.985 .747 .492 r
.73048 .45685 .73338 .45884 .73726 .415 .73436 .41228 Mtetra
.982 .733 .48 r
.73436 .41228 .73726 .415 .74049 .36397 .7376 .36048 Mtetra
.973 .756 .551 r
.7376 .36048 .74049 .36397 .74509 .33525 .74221 .33136 Mtetra
0 .158 .685 r
.74221 .33136 .74509 .33525 .75211 .3414 .74923 .33764 Mtetra
.926 .552 .146 r
.74923 .33764 .75211 .3414 .76107 .37336 .75822 .37012 Mtetra
.931 .557 .165 r
.75822 .37012 .76107 .37336 .7703 .40673 .76748 .40405 Mtetra
.698 .21 0 r
.76748 .40405 .7703 .40673 .7779 .41703 .77509 .41456 Mtetra
.979 .801 .594 r
.77509 .41456 .7779 .41703 .78309 .3965 .78029 .39376 Mtetra
.986 .751 .498 r
.78029 .39376 .78309 .3965 .7868 .35878 .784 .35547 Mtetra
.981 .756 .524 r
.784 .35547 .7868 .35878 .79088 .32703 .78807 .32323 Mtetra
.897 .803 .747 r
.78807 .32323 .79088 .32703 .79679 .31764 .79398 .31366 Mtetra
.709 .276 0 r
.79398 .31366 .79679 .31764 .80474 .33152 .80195 .32773 Mtetra
.87 .47 .009 r
.80195 .32773 .80474 .33152 .81368 .35524 .81091 .35185 Mtetra
.763 .32 0 r
.81091 .35185 .81368 .35524 .82191 .37007 .81917 .36698 Mtetra
.826 .846 .863 r
.81917 .36698 .82191 .37007 .8283 .36455 .82558 .36148 Mtetra
.981 .786 .57 r
.82558 .36148 .8283 .36455 .83302 .34193 .8303 .33856 Mtetra
.982 .773 .548 r
.8303 .33856 .83302 .34193 .83738 .31641 .83465 .31266 Mtetra
.948 .8 .664 r
.83465 .31266 .83738 .31641 .8428 .30224 .84008 .29822 Mtetra
.286 .54 .917 r
.84008 .29822 .8428 .30224 .8499 .30448 .84718 .30045 Mtetra
.619 .188 0 r
.84718 .30045 .8499 .30448 .85814 .31715 .85544 .31332 Mtetra
0 0 .435 r
.85544 .31332 .85814 .31715 .86627 .32805 .8636 .32444 Mtetra
.528 .71 .954 r
.8636 .32444 .86627 .32805 .87321 .3275 .87056 .32398 Mtetra
.942 .822 .697 r
.87056 .32398 .87321 .3275 .87884 .31521 .8762 .31157 Mtetra
.643 .757 .932 r
.27123 .50227 .27483 .50527 .28026 .50373 .27667 .50072 Mtetra
.87 .76 .738 r
.27667 .50072 .28026 .50373 .28629 .49422 .28272 .49108 Mtetra
.884 .749 .708 r
.28272 .49108 .28629 .49422 .29247 .48226 .28893 .47897 Mtetra
.807 .762 .81 r
.28893 .47897 .29247 .48226 .29817 .4769 .29465 .47357 Mtetra
.743 .25 0 r
.29465 .47357 .29817 .4769 .30306 .48364 .29952 .48045 Mtetra
.932 .563 .283 r
.29952 .48045 .30306 .48364 .30738 .49971 .30381 .49678 Mtetra
.925 .547 .266 r
.30381 .49678 .30738 .49971 .31184 .51468 .30825 .51198 Mtetra
0 .389 .814 r
.30825 .51198 .31184 .51468 .31715 .51715 .31355 .51446 Mtetra
.904 .76 .691 r
.31355 .51446 .31715 .51715 .32347 .50325 .31991 .50035 Mtetra
.92 .736 .636 r
.31991 .50035 .32347 .50325 .33026 .48088 .32675 .47766 Mtetra
.904 .743 .672 r
.32675 .47766 .33026 .48088 .33663 .46494 .33315 .46156 Mtetra
.025 .422 .863 r
.33315 .46156 .33663 .46494 .34193 .4674 .33845 .46412 Mtetra
.943 .597 .334 r
.33845 .46412 .34193 .4674 .34624 .48893 .34272 .48603 Mtetra
.945 .619 .383 r
.34272 .48603 .34624 .48893 .35029 .51699 .34672 .51451 Mtetra
.92 .537 .259 r
.34672 .51451 .35029 .51699 .3551 .53228 .35152 .52997 Mtetra
.896 .793 .738 r
.35152 .52997 .3551 .53228 .36123 .52212 .35767 .51959 Mtetra
.936 .732 .603 r
.35767 .51959 .36123 .52212 .36831 .49131 .36482 .4883 Mtetra
.933 .727 .602 r
.36482 .4883 .36831 .49131 .37534 .46002 .3719 .45663 Mtetra
.874 .759 .732 r
.3719 .45663 .37534 .46002 .38133 .45004 .37791 .44664 Mtetra
.942 .586 .299 r
.37791 .44664 .38133 .45004 .38603 .47049 .38258 .46752 Mtetra
.95 .64 .411 r
.38258 .46752 .38603 .47049 .39001 .51108 .38648 .50875 Mtetra
.945 .626 .398 r
.38648 .50875 .39001 .51108 .39436 .54588 .39079 .544 Mtetra
.386 0 0 r
.39079 .544 .39436 .54588 .40002 .54926 .39645 .54728 Mtetra
.946 .739 .591 r
.39645 .54728 .40002 .54926 .40699 .51619 .40349 .51359 Mtetra
.946 .72 .565 r
.40349 .51359 .40699 .51619 .41437 .46814 .41096 .46487 Mtetra
.936 .729 .599 r
.41096 .46487 .41437 .46814 .42105 .43756 .41768 .43403 Mtetra
.787 .317 0 r
.41768 .43403 .42105 .43756 .42646 .44617 .42308 .44301 Mtetra
.954 .645 .406 r
.42308 .44301 .42646 .44617 .43086 .49186 .42742 .48952 Mtetra
.952 .649 .424 r
.42742 .48952 .43086 .49186 .43518 .54758 .43166 .54605 Mtetra
.937 .595 .355 r
.43166 .54605 .43518 .54758 .44042 .575 .43687 .57364 Mtetra
.953 .773 .621 r
.43687 .57364 .44042 .575 .44693 .55204 .44344 .55006 Mtetra
.955 .721 .543 r
.44344 .55006 .44693 .55204 .45416 .49297 .45076 .49002 Mtetra
.951 .717 .548 r
.45076 .49002 .45416 .49297 .46112 .43766 .4578 .43409 Mtetra
.909 .753 .676 r
.4578 .43409 .46112 .43766 .46719 .42254 .46388 .4191 Mtetra
.956 .63 .361 r
.46388 .4191 .46719 .42254 .4724 .45923 .46904 .45663 Mtetra
.957 .656 .421 r
.46904 .45663 .4724 .45923 .4773 .52778 .47387 .52629 Mtetra
.951 .642 .411 r
.47387 .52629 .4773 .52778 .48263 .58401 .47914 .58316 Mtetra
.31 0 0 r
.47914 .58316 .48263 .58401 .48874 .58658 .48527 .58537 Mtetra
.964 .73 .536 r
.48527 .58537 .48874 .58658 .4954 .53131 .492 .52898 Mtetra
.96 .715 .521 r
.492 .52898 .4954 .53131 .50201 .456 .49871 .45261 Mtetra
.953 .722 .552 r
.49871 .45261 .50201 .456 .50822 .40983 .50497 .40614 Mtetra
.845 .406 0 r
.50497 .40614 .50822 .40983 .51409 .42141 .51083 .41833 Mtetra
.961 .653 .397 r
.51083 .41833 .51409 .42141 .51994 .48528 .51663 .4834 Mtetra
.958 .654 .413 r
.51663 .4834 .51994 .48528 .52606 .56275 .52267 .56197 Mtetra
.943 .608 .363 r
.52267 .56197 .52606 .56275 .53239 .60055 .52898 .59996 Mtetra
.974 .771 .569 r
.52898 .59996 .53239 .60055 .5386 .56933 .53524 .56781 Mtetra
.968 .718 .506 r
.53524 .56781 .5386 .56933 .54444 .49027 .54116 .48741 Mtetra
.964 .715 .511 r
.54116 .48741 .54444 .49027 .55005 .41639 .54684 .41269 Mtetra
.941 .745 .61 r
.54684 .41269 .55005 .41639 .55588 .39246 .5527 .38888 Mtetra
.958 .624 .322 r
.5527 .38888 .55588 .39246 .56236 .43157 .55916 .42895 Mtetra
.963 .655 .392 r
.55916 .42895 .56236 .43157 .56955 .51028 .5663 .50896 Mtetra
.958 .643 .387 r
.5663 .50896 .56955 .51028 .57688 .5776 .57359 .57708 Mtetra
.743 .222 0 r
.57359 .57708 .57688 .5776 .58346 .585 .58017 .58414 Mtetra
.975 .734 .507 r
.58017 .58414 .58346 .585 .58882 .52577 .58557 .52368 Mtetra
.971 .715 .49 r
.58557 .52368 .58882 .52577 .59343 .4409 .59025 .43758 Mtetra
.966 .721 .516 r
.59025 .43758 .59343 .4409 .59838 .38381 .59525 .38 Mtetra
.212 .51 .91 r
.59525 .38 .59838 .38381 .60459 .38569 .60148 .38231 Mtetra
.963 .639 .342 r
.60148 .38231 .60459 .38569 .61231 .44279 .60918 .4405 Mtetra
.964 .648 .369 r
.60918 .4405 .61231 .44279 .62081 .51864 .61766 .51748 Mtetra
.95 .609 .328 r
.61766 .51748 .62081 .51864 .62862 .5615 .62545 .56071 Mtetra
.981 .81 .598 r
.62545 .56071 .62862 .5615 .63451 .53973 .63135 .53826 Mtetra
.977 .725 .483 r
.63135 .53826 .63451 .53973 .63862 .46836 .6355 .46568 Mtetra
.974 .718 .484 r
.6355 .46568 .63862 .46836 .6424 .39469 .63932 .39107 Mtetra
.963 .741 .555 r
.63932 .39107 .6424 .39469 .64746 .36148 .64441 .35768 Mtetra
.916 .527 .127 r
.64441 .35768 .64746 .36148 .65466 .38377 .65162 .38054 Mtetra
.963 .635 .322 r
.65162 .38054 .65466 .38377 .6636 .44446 .66056 .44223 Mtetra
.96 .628 .324 r
.66056 .44223 .6636 .44446 .67269 .50271 .66965 .50126 Mtetra
.867 .421 .07 r
.66965 .50126 .67269 .50271 .68001 .5173 .67697 .51588 Mtetra
.984 .756 .514 r
.67697 .51588 .68001 .5173 .68478 .47733 .68175 .47515 Mtetra
.98 .724 .473 r
.68175 .47515 .68478 .47733 .68803 .41024 .68502 .40707 Mtetra
.976 .728 .495 r
.68502 .40707 .68803 .41024 .69181 .35774 .68882 .35395 Mtetra
.897 .788 .732 r
.68882 .35395 .69181 .35774 .69769 .34743 .69472 .34365 Mtetra
.939 .573 .191 r
.69472 .34365 .69769 .34743 .70599 .38008 .70303 .37687 Mtetra
.957 .615 .273 r
.70303 .37687 .70599 .38008 .71553 .43135 .71258 .4289 Mtetra
.94 .571 .218 r
.71258 .4289 .71553 .43135 .72424 .46503 .7213 .46305 Mtetra
.91 .887 .797 r
.7213 .46305 .72424 .46503 .73048 .45685 .72756 .45469 Mtetra
.984 .745 .492 r
.72756 .45469 .73048 .45685 .73436 .41228 .73144 .40945 Mtetra
.982 .732 .479 r
.73144 .40945 .73436 .41228 .7376 .36048 .73469 .35693 Mtetra
.973 .755 .55 r
.73469 .35693 .7376 .36048 .74221 .33136 .73931 .32745 Mtetra
0 .147 .676 r
.73931 .32745 .74221 .33136 .74923 .33764 .74634 .33385 Mtetra
.927 .554 .149 r
.74634 .33385 .74923 .33764 .75822 .37012 .75535 .36681 Mtetra
.931 .559 .166 r
.75535 .36681 .75822 .37012 .76748 .40405 .76463 .40125 Mtetra
.698 .214 0 r
.76463 .40125 .76748 .40405 .77509 .41456 .77226 .41196 Mtetra
.978 .798 .593 r
.77226 .41196 .77509 .41456 .78029 .39376 .77747 .3909 Mtetra
.985 .749 .497 r
.77747 .3909 .78029 .39376 .784 .35547 .78118 .35209 Mtetra
.981 .754 .522 r
.78118 .35209 .784 .35547 .78807 .32323 .78525 .31939 Mtetra
.899 .802 .744 r
.78525 .31939 .78807 .32323 .79398 .31366 .79116 .30967 Mtetra
.715 .282 0 r
.79116 .30967 .79398 .31366 .80195 .32773 .79915 .32391 Mtetra
.872 .473 .013 r
.79915 .32391 .80195 .32773 .81091 .35185 .80813 .34838 Mtetra
.766 .325 0 r
.80813 .34838 .81091 .35185 .81917 .36698 .81642 .3638 Mtetra
.824 .841 .862 r
.81642 .3638 .81917 .36698 .82558 .36148 .82284 .35831 Mtetra
.98 .784 .568 r
.82284 .35831 .82558 .36148 .8303 .33856 .82757 .33513 Mtetra
.981 .771 .546 r
.82757 .33513 .8303 .33856 .83465 .31266 .83191 .30887 Mtetra
.948 .799 .661 r
.83191 .30887 .83465 .31266 .84008 .29822 .83733 .29419 Mtetra
.287 .54 .917 r
.83733 .29419 .84008 .29822 .84718 .30045 .84445 .2964 Mtetra
.626 .195 0 r
.84445 .2964 .84718 .30045 .85544 .31332 .85273 .30945 Mtetra
0 0 .426 r
.85273 .30945 .85544 .31332 .8636 .32444 .86091 .32078 Mtetra
.522 .704 .953 r
.86091 .32078 .8636 .32444 .87056 .32398 .86789 .3204 Mtetra
.942 .82 .695 r
.86789 .3204 .87056 .32398 .8762 .31157 .87354 .30789 Mtetra
.644 .756 .93 r
.26762 .49924 .27123 .50227 .27667 .50072 .27307 .49767 Mtetra
.871 .759 .737 r
.27307 .49767 .27667 .50072 .28272 .49108 .27914 .48791 Mtetra
.885 .748 .706 r
.27914 .48791 .28272 .49108 .28893 .47897 .28538 .47566 Mtetra
.808 .762 .81 r
.28538 .47566 .28893 .47897 .29465 .47357 .29111 .47023 Mtetra
.753 .261 0 r
.29111 .47023 .29465 .47357 .29952 .48045 .29597 .47724 Mtetra
.933 .565 .286 r
.29597 .47724 .29952 .48045 .30381 .49678 .30023 .49381 Mtetra
.926 .549 .268 r
.30023 .49381 .30381 .49678 .30825 .51198 .30464 .5092 Mtetra
0 .391 .819 r
.30464 .5092 .30825 .51198 .31355 .51446 .30995 .5117 Mtetra
.904 .758 .689 r
.30995 .5117 .31355 .51446 .31991 .50035 .31634 .49739 Mtetra
.92 .735 .635 r
.31634 .49739 .31991 .50035 .32675 .47766 .32323 .47442 Mtetra
.904 .742 .671 r
.32323 .47442 .32675 .47766 .33315 .46156 .32966 .45816 Mtetra
.001 .406 .853 r
.32966 .45816 .33315 .46156 .33845 .46412 .33496 .46083 Mtetra
.943 .599 .337 r
.33496 .46083 .33845 .46412 .34272 .48603 .33918 .48307 Mtetra
.945 .62 .384 r
.33918 .48307 .34272 .48603 .34672 .51451 .34314 .51193 Mtetra
.921 .538 .259 r
.34314 .51193 .34672 .51451 .35152 .52997 .34792 .52755 Mtetra
.896 .789 .735 r
.34792 .52755 .35152 .52997 .35767 .51959 .3541 .51697 Mtetra
.935 .731 .603 r
.3541 .51697 .35767 .51959 .36482 .4883 .36131 .48524 Mtetra
.932 .726 .601 r
.36131 .48524 .36482 .4883 .3719 .45663 .36845 .45322 Mtetra
.874 .759 .732 r
.36845 .45322 .3719 .45663 .37791 .44664 .37448 .44322 Mtetra
.943 .588 .303 r
.37448 .44322 .37791 .44664 .38258 .46752 .37911 .46449 Mtetra
.951 .641 .412 r
.37911 .46449 .38258 .46752 .38648 .50875 .38295 .50632 Mtetra
.946 .627 .398 r
.38295 .50632 .38648 .50875 .39079 .544 .38721 .54197 Mtetra
0 .225 .623 r
.38721 .54197 .39079 .544 .39645 .54728 .39288 .54514 Mtetra
.945 .737 .591 r
.39288 .54514 .39645 .54728 .40349 .51359 .39999 .51089 Mtetra
.946 .72 .564 r
.39999 .51089 .40349 .51359 .41096 .46487 .40753 .46155 Mtetra
.935 .728 .598 r
.40753 .46155 .41096 .46487 .41768 .43403 .4143 .43049 Mtetra
.802 .337 0 r
.4143 .43049 .41768 .43403 .42308 .44301 .41968 .43981 Mtetra
.955 .646 .407 r
.41968 .43981 .42308 .44301 .42742 .48952 .42395 .48708 Mtetra
.952 .65 .424 r
.42395 .48708 .42742 .48952 .43166 .54605 .42813 .54433 Mtetra
.938 .596 .353 r
.42813 .54433 .43166 .54605 .43687 .57364 .43331 .57208 Mtetra
.952 .769 .619 r
.43331 .57208 .43687 .57364 .44344 .55006 .43993 .54792 Mtetra
.955 .72 .543 r
.43993 .54792 .44344 .55006 .45076 .49002 .44734 .487 Mtetra
.951 .717 .548 r
.44734 .487 .45076 .49002 .4578 .43409 .45446 .4305 Mtetra
.908 .753 .677 r
.45446 .4305 .4578 .43409 .46388 .4191 .46056 .41563 Mtetra
.956 .632 .363 r
.46056 .41563 .46388 .4191 .46904 .45663 .46568 .45394 Mtetra
.957 .656 .422 r
.46568 .45394 .46904 .45663 .47387 .52629 .47042 .52461 Mtetra
.952 .643 .411 r
.47042 .52461 .47387 .52629 .47914 .58316 .47563 .58206 Mtetra
0 .389 .684 r
.47563 .58206 .47914 .58316 .48527 .58537 .48177 .58393 Mtetra
.963 .728 .536 r
.48177 .58393 .48527 .58537 .492 .52898 .48859 .5265 Mtetra
.96 .714 .521 r
.48859 .5265 .492 .52898 .49871 .45261 .49539 .44918 Mtetra
.953 .722 .552 r
.49539 .44918 .49871 .45261 .50497 .40614 .50171 .40244 Mtetra
.858 .424 0 r
.50171 .40244 .50497 .40614 .51083 .41833 .50756 .41519 Mtetra
.961 .653 .398 r
.50756 .41519 .51083 .41833 .51663 .4834 .51329 .48136 Mtetra
.959 .655 .412 r
.51329 .48136 .51663 .4834 .52267 .56197 .51927 .56094 Mtetra
.945 .61 .36 r
.51927 .56094 .52267 .56197 .52898 .59996 .52555 .59909 Mtetra
.972 .766 .569 r
.52555 .59909 .52898 .59996 .53524 .56781 .53185 .56607 Mtetra
.967 .717 .506 r
.53185 .56607 .53524 .56781 .54116 .48741 .53785 .48444 Mtetra
.963 .714 .511 r
.53785 .48444 .54116 .48741 .54684 .41269 .54361 .40897 Mtetra
.941 .745 .611 r
.54361 .40897 .54684 .41269 .5527 .38888 .54951 .38528 Mtetra
.959 .625 .325 r
.54951 .38528 .5527 .38888 .55916 .42895 .55595 .42624 Mtetra
.963 .655 .393 r
.55595 .42624 .55916 .42895 .5663 .50896 .56303 .50743 Mtetra
.959 .644 .386 r
.56303 .50743 .5663 .50896 .57359 .57708 .57027 .57627 Mtetra
.721 .188 0 r
.57027 .57627 .57359 .57708 .58017 .58414 .57685 .58302 Mtetra
.974 .732 .507 r
.57685 .58302 .58017 .58414 .58557 .52368 .58231 .52141 Mtetra
.97 .715 .49 r
.58231 .52141 .58557 .52368 .59025 .43758 .58706 .43419 Mtetra
.966 .721 .515 r
.58706 .43419 .59025 .43758 .59525 .38 .59211 .37618 Mtetra
.149 .47 .893 r
.59211 .37618 .59525 .38 .60148 .38231 .59836 .37889 Mtetra
.964 .64 .344 r
.59836 .37889 .60148 .38231 .60918 .4405 .60604 .43809 Mtetra
.964 .648 .369 r
.60604 .43809 .60918 .4405 .61766 .51748 .61447 .51608 Mtetra
.951 .61 .325 r
.61447 .51608 .61766 .51748 .62545 .56071 .62225 .55964 Mtetra
.979 .803 .596 r
.62225 .55964 .62545 .56071 .63135 .53826 .62817 .53657 Mtetra
.977 .723 .483 r
.62817 .53657 .63135 .53826 .6355 .46568 .63236 .46287 Mtetra
.974 .717 .484 r
.63236 .46287 .6355 .46568 .63932 .39107 .63623 .38741 Mtetra
.963 .741 .554 r
.63623 .38741 .63932 .39107 .64441 .35768 .64135 .35386 Mtetra
.919 .532 .134 r
.64135 .35386 .64441 .35768 .65162 .38054 .64857 .37725 Mtetra
.964 .636 .323 r
.64857 .37725 .65162 .38054 .66056 .44223 .6575 .43984 Mtetra
.961 .629 .323 r
.6575 .43984 .66056 .44223 .66965 .50126 .66657 .49959 Mtetra
.865 .418 .056 r
.66657 .49959 .66965 .50126 .67697 .51588 .6739 .51424 Mtetra
.982 .753 .514 r
.6739 .51424 .67697 .51588 .68175 .47515 .67869 .47281 Mtetra
.979 .723 .473 r
.67869 .47281 .68175 .47515 .68502 .40707 .682 .40382 Mtetra
.976 .728 .494 r
.682 .40382 .68502 .40707 .68882 .35395 .68582 .35014 Mtetra
.897 .788 .732 r
.68582 .35014 .68882 .35395 .69472 .34365 .69174 .33985 Mtetra
.939 .575 .194 r
.69174 .33985 .69472 .34365 .70303 .37687 .70006 .37359 Mtetra
.958 .616 .274 r
.70006 .37359 .70303 .37687 .71258 .4289 .70961 .42632 Mtetra
.94 .572 .217 r
.70961 .42632 .71258 .4289 .7213 .46305 .71834 .46087 Mtetra
.91 .878 .792 r
.71834 .46087 .7213 .46305 .72756 .45469 .72461 .45235 Mtetra
.984 .743 .492 r
.72461 .45235 .72756 .45469 .73144 .40945 .72851 .4065 Mtetra
.981 .731 .479 r
.72851 .4065 .73144 .40945 .73469 .35693 .73176 .35334 Mtetra
.972 .754 .549 r
.73176 .35334 .73469 .35693 .73931 .32745 .73639 .32352 Mtetra
0 .136 .667 r
.73639 .32352 .73931 .32745 .74634 .33385 .74344 .33004 Mtetra
.928 .556 .152 r
.74344 .33004 .74634 .33385 .75535 .36681 .75246 .36343 Mtetra
.932 .56 .168 r
.75246 .36343 .75535 .36681 .76463 .40125 .76176 .39834 Mtetra
.696 .216 0 r
.76176 .39834 .76463 .40125 .77226 .41196 .76941 .40922 Mtetra
.977 .795 .593 r
.76941 .40922 .77226 .41196 .77747 .3909 .77462 .38793 Mtetra
.984 .748 .497 r
.77462 .38793 .77747 .3909 .78118 .35209 .77834 .34864 Mtetra
.981 .753 .521 r
.77834 .34864 .78118 .35209 .78525 .31939 .78242 .31553 Mtetra
.9 .802 .742 r
.78242 .31553 .78525 .31939 .79116 .30967 .78833 .30566 Mtetra
.719 .287 0 r
.78833 .30566 .79116 .30967 .79915 .32391 .79633 .32006 Mtetra
.874 .476 .017 r
.79633 .32006 .79915 .32391 .80813 .34838 .80533 .34486 Mtetra
.769 .33 0 r
.80533 .34486 .80813 .34838 .81642 .3638 .81364 .36053 Mtetra
.821 .837 .86 r
.81364 .36053 .81642 .3638 .82284 .35831 .82008 .35504 Mtetra
.98 .782 .568 r
.82008 .35504 .82284 .35831 .82757 .33513 .82481 .33162 Mtetra
.981 .77 .545 r
.82481 .33162 .82757 .33513 .83191 .30887 .82916 .30503 Mtetra
.949 .798 .659 r
.82916 .30503 .83191 .30887 .83733 .29419 .83458 .29013 Mtetra
.288 .541 .917 r
.83458 .29013 .83733 .29419 .84445 .2964 .8417 .29234 Mtetra
.631 .201 0 r
.8417 .29234 .84445 .2964 .85273 .30945 .85 .30554 Mtetra
0 0 .418 r
.85 .30554 .85273 .30945 .86091 .32078 .8582 .31707 Mtetra
.517 .698 .952 r
.8582 .31707 .86091 .32078 .86789 .3204 .8652 .31675 Mtetra
.941 .818 .694 r
.8652 .31675 .86789 .3204 .87354 .30789 .87086 .30414 Mtetra
.645 .754 .928 r
.26399 .49616 .26762 .49924 .27307 .49767 .26945 .49458 Mtetra
.871 .758 .735 r
.26945 .49458 .27307 .49767 .27914 .48791 .27555 .48471 Mtetra
.885 .748 .705 r
.27555 .48471 .27914 .48791 .28538 .47566 .28181 .47234 Mtetra
.808 .761 .809 r
.28181 .47234 .28538 .47566 .29111 .47023 .28755 .46688 Mtetra
.76 .271 0 r
.28755 .46688 .29111 .47023 .29597 .47724 .29241 .474 Mtetra
.933 .567 .289 r
.29241 .474 .29597 .47724 .30023 .49381 .29664 .49077 Mtetra
.927 .551 .27 r
.29664 .49077 .30023 .49381 .30464 .5092 .30102 .50634 Mtetra
0 .394 .824 r
.30102 .50634 .30464 .5092 .30995 .5117 .30633 .50885 Mtetra
.903 .755 .688 r
.30633 .50885 .30995 .5117 .31634 .49739 .31276 .49436 Mtetra
.92 .734 .635 r
.31276 .49436 .31634 .49739 .32323 .47442 .31969 .47115 Mtetra
.904 .742 .67 r
.31969 .47115 .32323 .47442 .32966 .45816 .32615 .45475 Mtetra
0 .391 .843 r
.32615 .45475 .32966 .45816 .33496 .46083 .33145 .45751 Mtetra
.944 .601 .339 r
.33145 .45751 .33496 .46083 .33918 .48307 .33564 .48006 Mtetra
.946 .621 .385 r
.33564 .48006 .33918 .48307 .34314 .51193 .33955 .50925 Mtetra
.922 .54 .258 r
.33955 .50925 .34314 .51193 .34792 .52755 .34431 .52501 Mtetra
.895 .784 .732 r
.34431 .52501 .34792 .52755 .3541 .51697 .35052 .51424 Mtetra
.935 .73 .602 r
.35052 .51424 .3541 .51697 .36131 .48524 .35779 .48212 Mtetra
.932 .726 .601 r
.35779 .48212 .36131 .48524 .36845 .45322 .36498 .44979 Mtetra
.873 .758 .732 r
.36498 .44979 .36845 .45322 .37448 .44322 .37103 .43979 Mtetra
.944 .59 .307 r
.37103 .43979 .37448 .44322 .37911 .46449 .37563 .46141 Mtetra
.951 .642 .413 r
.37563 .46141 .37911 .46449 .38295 .50632 .37941 .50377 Mtetra
.947 .628 .397 r
.37941 .50377 .38295 .50632 .38721 .54197 .38362 .53977 Mtetra
0 .263 .671 r
.38362 .53977 .38721 .54197 .39288 .54514 .3893 .54284 Mtetra
.944 .735 .59 r
.3893 .54284 .39288 .54514 .39999 .51089 .39647 .50808 Mtetra
.945 .719 .564 r
.39647 .50808 .39999 .51089 .40753 .46155 .40409 .4582 Mtetra
.935 .728 .598 r
.40409 .4582 .40753 .46155 .4143 .43049 .41091 .42694 Mtetra
.814 .353 0 r
.41091 .42694 .4143 .43049 .41968 .43981 .41627 .43657 Mtetra
.955 .646 .408 r
.41627 .43657 .41968 .43981 .42395 .48708 .42048 .48452 Mtetra
.953 .65 .424 r
.42048 .48452 .42395 .48708 .42813 .54433 .42458 .5424 Mtetra
.94 .598 .35 r
.42458 .5424 .42813 .54433 .43331 .57208 .42974 .57029 Mtetra
.95 .764 .617 r
.42974 .57029 .43331 .57208 .43993 .54792 .43641 .54561 Mtetra
.954 .719 .543 r
.43641 .54561 .43993 .54792 .44734 .487 .44391 .48389 Mtetra
.951 .716 .548 r
.44391 .48389 .44734 .487 .45446 .4305 .4511 .4269 Mtetra
.908 .754 .679 r
.4511 .4269 .45446 .4305 .46056 .41563 .45723 .41215 Mtetra
.957 .633 .365 r
.45723 .41215 .46056 .41563 .46568 .45394 .4623 .45116 Mtetra
.957 .657 .422 r
.4623 .45116 .46568 .45394 .47042 .52461 .46696 .52273 Mtetra
.953 .644 .41 r
.46696 .52273 .47042 .52461 .47563 .58206 .47211 .58069 Mtetra
0 .482 .788 r
.47211 .58069 .47563 .58206 .48177 .58393 .47827 .58223 Mtetra
.962 .726 .536 r
.47827 .58223 .48177 .58393 .48859 .5265 .48516 .52387 Mtetra
.959 .713 .521 r
.48516 .52387 .48859 .5265 .49539 .44918 .49206 .44571 Mtetra
.953 .721 .551 r
.49206 .44571 .49539 .44918 .50171 .40244 .49844 .39874 Mtetra
.868 .438 .02 r
.49844 .39874 .50171 .40244 .50756 .41519 .50428 .412 Mtetra
.961 .654 .399 r
.50428 .412 .50756 .41519 .51329 .48136 .50994 .47916 Mtetra
.959 .656 .412 r
.50994 .47916 .51329 .48136 .51927 .56094 .51584 .55962 Mtetra
.946 .611 .357 r
.51584 .55962 .51927 .56094 .52555 .59909 .5221 .5979 Mtetra
.969 .761 .568 r
.5221 .5979 .52555 .59909 .53185 .56607 .52844 .56409 Mtetra
.966 .716 .506 r
.52844 .56409 .53185 .56607 .53785 .48444 .53454 .48137 Mtetra
.963 .713 .511 r
.53454 .48137 .53785 .48444 .54361 .40897 .54038 .40524 Mtetra
.94 .745 .612 r
.54038 .40524 .54361 .40897 .54951 .38528 .5463 .38166 Mtetra
.959 .626 .327 r
.5463 .38166 .54951 .38528 .55595 .42624 .55272 .42342 Mtetra
.963 .656 .393 r
.55272 .42342 .55595 .42624 .56303 .50743 .55974 .50567 Mtetra
.959 .645 .385 r
.55974 .50567 .56303 .50743 .57027 .57627 .56693 .57514 Mtetra
.692 .149 0 r
.56693 .57514 .57027 .57627 .57685 .58302 .57351 .58158 Mtetra
.973 .73 .508 r
.57351 .58158 .57685 .58302 .58231 .52141 .57902 .51895 Mtetra
.97 .714 .49 r
.57902 .51895 .58231 .52141 .58706 .43419 .58385 .43073 Mtetra
.966 .72 .515 r
.58385 .43073 .58706 .43419 .59211 .37618 .58896 .37235 Mtetra
.089 .431 .873 r
.58896 .37235 .59211 .37618 .59836 .37889 .59522 .37543 Mtetra
.964 .641 .345 r
.59522 .37543 .59836 .37889 .60604 .43809 .60287 .43552 Mtetra
.964 .649 .369 r
.60287 .43552 .60604 .43809 .61447 .51608 .61127 .51442 Mtetra
.952 .611 .323 r
.61127 .51442 .61447 .51608 .62225 .55964 .61902 .55827 Mtetra
.976 .796 .595 r
.61902 .55827 .62225 .55964 .62817 .53657 .62496 .53463 Mtetra
.976 .722 .484 r
.62496 .53463 .62817 .53657 .63236 .46287 .6292 .45993 Mtetra
.973 .717 .484 r
.6292 .45993 .63236 .46287 .63623 .38741 .63312 .38372 Mtetra
.963 .74 .554 r
.63312 .38372 .63623 .38741 .64135 .35386 .63828 .35003 Mtetra
.921 .536 .141 r
.63828 .35003 .64135 .35386 .64857 .37725 .6455 .3739 Mtetra
.964 .636 .324 r
.6455 .3739 .64857 .37725 .6575 .43984 .65441 .4373 Mtetra
.961 .63 .323 r
.65441 .4373 .6575 .43984 .66657 .49959 .66347 .49768 Mtetra
.862 .415 .041 r
.66347 .49768 .66657 .49959 .6739 .51424 .6708 .51233 Mtetra
.981 .75 .515 r
.6708 .51233 .6739 .51424 .67869 .47281 .67561 .47027 Mtetra
.979 .722 .473 r
.67561 .47027 .67869 .47281 .682 .40382 .67895 .40048 Mtetra
.976 .727 .494 r
.67895 .40048 .682 .40382 .68582 .35014 .68281 .34629 Mtetra
.896 .788 .733 r
.68281 .34629 .68582 .35014 .69174 .33985 .68875 .33602 Mtetra
.94 .576 .197 r
.68875 .33602 .69174 .33985 .70006 .37359 .69707 .37023 Mtetra
.958 .617 .275 r
.69707 .37023 .70006 .37359 .70961 .42632 .70662 .42358 Mtetra
.941 .573 .215 r
.70662 .42358 .70961 .42632 .71834 .46087 .71535 .4585 Mtetra
.908 .867 .787 r
.71535 .4585 .71834 .46087 .72461 .45235 .72163 .44983 Mtetra
.983 .741 .493 r
.72163 .44983 .72461 .45235 .72851 .4065 .72555 .40343 Mtetra
.981 .73 .479 r
.72555 .40343 .72851 .4065 .73176 .35334 .72882 .34968 Mtetra
.972 .753 .548 r
.72882 .34968 .73176 .35334 .73639 .32352 .73347 .31958 Mtetra
0 .127 .659 r
.73347 .31958 .73639 .32352 .74344 .33004 .74053 .32619 Mtetra
.929 .558 .154 r
.74053 .32619 .74344 .33004 .75246 .36343 .74955 .35997 Mtetra
.932 .562 .168 r
.74955 .35997 .75246 .36343 .76176 .39834 .75886 .39529 Mtetra
.693 .216 0 r
.75886 .39529 .76176 .39834 .76941 .40922 .76653 .40633 Mtetra
.975 .791 .592 r
.76653 .40633 .76941 .40922 .77462 .38793 .77176 .38482 Mtetra
.984 .747 .497 r
.77176 .38482 .77462 .38793 .77834 .34864 .77548 .34512 Mtetra
.98 .752 .52 r
.77548 .34512 .77834 .34864 .78242 .31553 .77957 .31163 Mtetra
.901 .801 .739 r
.77957 .31163 .78242 .31553 .78833 .30566 .78549 .30163 Mtetra
.723 .291 0 r
.78549 .30163 .78833 .30566 .79633 .32006 .7935 .31617 Mtetra
.876 .478 .02 r
.7935 .31617 .79633 .32006 .80533 .34486 .80252 .34125 Mtetra
.77 .334 0 r
.80252 .34125 .80533 .34486 .81364 .36053 .81085 .35716 Mtetra
.819 .831 .858 r
.81085 .35716 .81364 .36053 .82008 .35504 .8173 .35167 Mtetra
.979 .78 .567 r
.8173 .35167 .82008 .35504 .82481 .33162 .82204 .32804 Mtetra
.981 .768 .544 r
.82204 .32804 .82481 .33162 .82916 .30503 .82639 .30116 Mtetra
.95 .796 .656 r
.82639 .30116 .82916 .30503 .83458 .29013 .83182 .28606 Mtetra
.289 .541 .918 r
.83182 .28606 .83458 .29013 .8417 .29234 .83894 .28825 Mtetra
.636 .206 0 r
.83894 .28825 .8417 .29234 .85 .30554 .84726 .3016 Mtetra
0 0 .412 r
.84726 .3016 .85 .30554 .8582 .31707 .85548 .31329 Mtetra
.512 .693 .95 r
.85548 .31329 .8582 .31707 .8652 .31675 .8625 .31304 Mtetra
.941 .816 .693 r
.8625 .31304 .8652 .31675 .87086 .30414 .86817 .30034 Mtetra
.646 .752 .926 r
.26036 .49304 .26399 .49616 .26945 .49458 .26582 .49144 Mtetra
.871 .757 .734 r
.26582 .49144 .26945 .49458 .27555 .48471 .27194 .48148 Mtetra
.885 .747 .704 r
.27194 .48148 .27555 .48471 .28181 .47234 .27823 .469 Mtetra
.809 .761 .809 r
.27823 .469 .28181 .47234 .28755 .46688 .28399 .46351 Mtetra
.767 .279 0 r
.28399 .46351 .28755 .46688 .29241 .474 .28883 .47073 Mtetra
.934 .569 .292 r
.28883 .47073 .29241 .474 .29664 .49077 .29304 .48769 Mtetra
.928 .553 .271 r
.29304 .48769 .29664 .49077 .30102 .50634 .2974 .50341 Mtetra
0 .397 .829 r
.2974 .50341 .30102 .50634 .30633 .50885 .30271 .50593 Mtetra
.902 .754 .687 r
.30271 .50593 .30633 .50885 .31276 .49436 .30916 .49128 Mtetra
.919 .733 .634 r
.30916 .49128 .31276 .49436 .31969 .47115 .31614 .46784 Mtetra
.904 .741 .67 r
.31614 .46784 .31969 .47115 .32615 .45475 .32264 .45132 Mtetra
0 .377 .833 r
.32264 .45132 .32615 .45475 .33145 .45751 .32793 .45417 Mtetra
.944 .602 .341 r
.32793 .45417 .33145 .45751 .33564 .48006 .33208 .47698 Mtetra
.946 .622 .386 r
.33208 .47698 .33564 .48006 .33955 .50925 .33595 .50647 Mtetra
.923 .542 .256 r
.33595 .50647 .33955 .50925 .34431 .52501 .34069 .52235 Mtetra
.893 .78 .729 r
.34069 .52235 .34431 .52501 .35052 .51424 .34693 .5114 Mtetra
.934 .729 .601 r
.34693 .5114 .35052 .51424 .35779 .48212 .35426 .47895 Mtetra
.932 .725 .6 r
.35426 .47895 .35779 .48212 .36498 .44979 .36151 .44634 Mtetra
.873 .758 .733 r
.36151 .44634 .36498 .44979 .37103 .43979 .36757 .43634 Mtetra
.944 .592 .31 r
.36757 .43634 .37103 .43979 .37563 .46141 .37213 .45828 Mtetra
.951 .643 .414 r
.37213 .45828 .37563 .46141 .37941 .50377 .37585 .50109 Mtetra
.948 .63 .397 r
.37585 .50109 .37941 .50377 .38362 .53977 .38001 .53741 Mtetra
0 .298 .714 r
.38001 .53741 .38362 .53977 .3893 .54284 .3857 .54038 Mtetra
.943 .733 .589 r
.3857 .54038 .3893 .54284 .39647 .50808 .39294 .50516 Mtetra
.945 .718 .564 r
.39294 .50516 .39647 .50808 .40409 .4582 .40064 .4548 Mtetra
.935 .728 .598 r
.40064 .4548 .40409 .4582 .41091 .42694 .4075 .42338 Mtetra
.824 .367 0 r
.4075 .42338 .41091 .42694 .41627 .43657 .41285 .43328 Mtetra
.955 .647 .409 r
.41285 .43328 .41627 .43657 .42048 .48452 .41699 .48183 Mtetra
.953 .651 .424 r
.41699 .48183 .42048 .48452 .42458 .5424 .42102 .54028 Mtetra
.941 .599 .348 r
.42102 .54028 .42458 .5424 .42974 .57029 .42616 .56827 Mtetra
.948 .76 .616 r
.42616 .56827 .42974 .57029 .43641 .54561 .43287 .54312 Mtetra
.954 .717 .543 r
.43287 .54312 .43641 .54561 .44391 .48389 .44046 .4807 Mtetra
.951 .716 .547 r
.44046 .4807 .44391 .48389 .4511 .4269 .44774 .42328 Mtetra
.907 .754 .68 r
.44774 .42328 .4511 .4269 .45723 .41215 .45388 .40864 Mtetra
.957 .634 .367 r
.45388 .40864 .45723 .41215 .4623 .45116 .4589 .44827 Mtetra
.958 .658 .422 r
.4589 .44827 .4623 .45116 .46696 .52273 .46348 .52063 Mtetra
.954 .645 .409 r
.46348 .52063 .46696 .52273 .47211 .58069 .46857 .57903 Mtetra
.041 .56 .87 r
.46857 .57903 .47211 .58069 .47827 .58223 .47474 .58028 Mtetra
.961 .725 .536 r
.47474 .58028 .47827 .58223 .48516 .52387 .48172 .52109 Mtetra
.959 .712 .521 r
.48172 .52109 .48516 .52387 .49206 .44571 .48871 .44218 Mtetra
.952 .721 .551 r
.48871 .44218 .49206 .44571 .49844 .39874 .49515 .39503 Mtetra
.876 .45 .038 r
.49515 .39503 .49844 .39874 .50428 .412 .50098 .40874 Mtetra
.961 .654 .399 r
.50098 .40874 .50428 .412 .50994 .47916 .50658 .47677 Mtetra
.96 .657 .412 r
.50658 .47677 .50994 .47916 .51584 .55962 .5124 .55802 Mtetra
.948 .612 .353 r
.5124 .55802 .51584 .55962 .5221 .5979 .51863 .59639 Mtetra
.967 .757 .568 r
.51863 .59639 .5221 .5979 .52844 .56409 .52502 .56188 Mtetra
.966 .715 .506 r
.52502 .56188 .52844 .56409 .53454 .48137 .53121 .47819 Mtetra
.963 .713 .511 r
.53121 .47819 .53454 .48137 .54038 .40524 .53713 .40148 Mtetra
.94 .745 .612 r
.53713 .40148 .54038 .40524 .5463 .38166 .54308 .37802 Mtetra
.96 .628 .329 r
.54308 .37802 .5463 .38166 .55272 .42342 .54947 .42049 Mtetra
.964 .656 .393 r
.54947 .42049 .55272 .42342 .55974 .50567 .55642 .50367 Mtetra
.96 .646 .384 r
.55642 .50367 .55974 .50567 .56693 .57514 .56357 .57369 Mtetra
.657 .107 0 r
.56357 .57369 .56693 .57514 .57351 .58158 .57015 .57985 Mtetra
.972 .728 .508 r
.57015 .57985 .57351 .58158 .57902 .51895 .57572 .51631 Mtetra
.97 .713 .49 r
.57572 .51631 .57902 .51895 .58385 .43073 .58063 .42722 Mtetra
.965 .72 .515 r
.58063 .42722 .58385 .43073 .58896 .37235 .5858 .36851 Mtetra
.034 .394 .852 r
.5858 .36851 .58896 .37235 .59522 .37543 .59207 .37193 Mtetra
.964 .642 .346 r
.59207 .37193 .59522 .37543 .60287 .43552 .59969 .43281 Mtetra
.965 .65 .369 r
.59969 .43281 .60287 .43552 .61127 .51442 .60804 .51249 Mtetra
.953 .612 .32 r
.60804 .51249 .61127 .51442 .61902 .55827 .61577 .55659 Mtetra
.974 .79 .595 r
.61577 .55659 .61902 .55827 .62496 .53463 .62173 .53243 Mtetra
.975 .721 .484 r
.62173 .53243 .62496 .53463 .6292 .45993 .62602 .45686 Mtetra
.973 .716 .484 r
.62602 .45686 .6292 .45993 .63312 .38372 .63 .37998 Mtetra
.963 .74 .554 r
.63 .37998 .63312 .38372 .63828 .35003 .6352 .34618 Mtetra
.923 .539 .146 r
.6352 .34618 .63828 .35003 .6455 .3739 .64242 .37048 Mtetra
.964 .637 .324 r
.64242 .37048 .6455 .3739 .65441 .4373 .65131 .43459 Mtetra
.962 .631 .322 r
.65131 .43459 .65441 .4373 .66347 .49768 .66035 .49553 Mtetra
.859 .41 .025 r
.66035 .49553 .66347 .49768 .6708 .51233 .66767 .51017 Mtetra
.98 .748 .515 r
.66767 .51017 .6708 .51233 .67561 .47027 .67251 .46756 Mtetra
.978 .721 .474 r
.67251 .46756 .67561 .47027 .67895 .40048 .67589 .39705 Mtetra
.975 .726 .494 r
.67589 .39705 .67895 .40048 .68281 .34629 .67979 .34243 Mtetra
.896 .788 .733 r
.67979 .34243 .68281 .34629 .68875 .33602 .68575 .33218 Mtetra
.941 .578 .199 r
.68575 .33218 .68875 .33602 .69707 .37023 .69406 .36679 Mtetra
.958 .617 .275 r
.69406 .36679 .69707 .37023 .70662 .42358 .70361 .42068 Mtetra
.941 .574 .213 r
.70361 .42068 .70662 .42358 .71535 .4585 .71234 .45592 Mtetra
.906 .858 .783 r
.71234 .45592 .71535 .4585 .72163 .44983 .71863 .44711 Mtetra
.982 .74 .493 r
.71863 .44711 .72163 .44983 .72555 .40343 .72257 .40023 Mtetra
.98 .729 .479 r
.72257 .40023 .72555 .40343 .72882 .34968 .72587 .34598 Mtetra
.972 .752 .547 r
.72587 .34598 .72882 .34968 .73347 .31958 .73053 .31562 Mtetra
0 .119 .652 r
.73053 .31562 .73347 .31958 .74053 .32619 .7376 .32232 Mtetra
.929 .559 .156 r
.7376 .32232 .74053 .32619 .74955 .35997 .74663 .35644 Mtetra
.933 .563 .168 r
.74663 .35644 .74955 .35997 .75886 .39529 .75595 .39212 Mtetra
.69 .216 0 r
.75595 .39212 .75886 .39529 .76653 .40633 .76362 .40328 Mtetra
.974 .788 .592 r
.76362 .40328 .76653 .40633 .77176 .38482 .76887 .38159 Mtetra
.983 .745 .497 r
.76887 .38159 .77176 .38482 .77548 .34512 .77261 .34151 Mtetra
.98 .751 .52 r
.77261 .34151 .77548 .34512 .77957 .31163 .7767 .3077 Mtetra
.902 .8 .738 r
.7767 .3077 .77957 .31163 .78549 .30163 .78264 .29759 Mtetra
.727 .295 0 r
.78264 .29759 .78549 .30163 .7935 .31617 .79065 .31225 Mtetra
.877 .48 .022 r
.79065 .31225 .7935 .31617 .80252 .34125 .79968 .33758 Mtetra
.771 .336 0 r
.79968 .33758 .80252 .34125 .81085 .35716 .80803 .35368 Mtetra
.817 .826 .857 r
.80803 .35368 .81085 .35716 .8173 .35167 .8145 .3482 Mtetra
.978 .779 .567 r
.8145 .3482 .8173 .35167 .82204 .32804 .81925 .32438 Mtetra
.98 .767 .543 r
.81925 .32438 .82204 .32804 .82639 .30116 .82361 .29724 Mtetra
.95 .795 .654 r
.82361 .29724 .82639 .30116 .83182 .28606 .82904 .28197 Mtetra
.29 .542 .918 r
.82904 .28197 .83182 .28606 .83894 .28825 .83617 .28414 Mtetra
.641 .211 0 r
.83617 .28414 .83894 .28825 .84726 .3016 .8445 .29761 Mtetra
0 0 .406 r
.8445 .29761 .84726 .3016 .85548 .31329 .85274 .30945 Mtetra
.508 .688 .948 r
.85274 .30945 .85548 .31329 .8625 .31304 .85978 .30926 Mtetra
.94 .814 .692 r
.85978 .30926 .8625 .31304 .86817 .30034 .86546 .29648 Mtetra
.647 .75 .925 r
.25671 .48988 .26036 .49304 .26582 .49144 .26218 .48826 Mtetra
.871 .755 .733 r
.26218 .48826 .26582 .49144 .27194 .48148 .26832 .47822 Mtetra
.885 .746 .703 r
.26832 .47822 .27194 .48148 .27823 .469 .27464 .46565 Mtetra
.809 .761 .808 r
.27464 .46565 .27823 .469 .28399 .46351 .28041 .46013 Mtetra
.772 .286 0 r
.28041 .46013 .28399 .46351 .28883 .47073 .28524 .46743 Mtetra
.934 .57 .294 r
.28524 .46743 .28883 .47073 .29304 .48769 .28942 .48455 Mtetra
.929 .555 .272 r
.28942 .48455 .29304 .48769 .2974 .50341 .29376 .50041 Mtetra
0 .4 .834 r
.29376 .50041 .2974 .50341 .30271 .50593 .29907 .50293 Mtetra
.902 .752 .685 r
.29907 .50293 .30271 .50593 .30916 .49128 .30556 .48814 Mtetra
.919 .732 .633 r
.30556 .48814 .30916 .49128 .31614 .46784 .31258 .46451 Mtetra
.904 .741 .669 r
.31258 .46451 .31614 .46784 .32264 .45132 .31911 .44788 Mtetra
0 .365 .825 r
.31911 .44788 .32264 .45132 .32793 .45417 .3244 .4508 Mtetra
.944 .603 .343 r
.3244 .4508 .32793 .45417 .33208 .47698 .32851 .47384 Mtetra
.946 .623 .386 r
.32851 .47384 .33208 .47698 .33595 .50647 .33234 .50359 Mtetra
.924 .543 .255 r
.33234 .50359 .33595 .50647 .34069 .52235 .33706 .51956 Mtetra
.892 .776 .727 r
.33706 .51956 .34069 .52235 .34693 .5114 .34332 .50847 Mtetra
.934 .727 .601 r
.34332 .50847 .34693 .5114 .35426 .47895 .35071 .47572 Mtetra
.932 .724 .6 r
.35071 .47572 .35426 .47895 .36151 .44634 .35802 .44287 Mtetra
.873 .758 .733 r
.35802 .44287 .36151 .44634 .36757 .43634 .3641 .43287 Mtetra
.944 .593 .312 r
.3641 .43287 .36757 .43634 .37213 .45828 .36862 .45508 Mtetra
.951 .643 .414 r
.36862 .45508 .37213 .45828 .37585 .50109 .37228 .49829 Mtetra
.948 .631 .397 r
.37228 .49829 .37585 .50109 .38001 .53741 .3764 .53487 Mtetra
0 .329 .752 r
.3764 .53487 .38001 .53741 .3857 .54038 .3821 .53776 Mtetra
.942 .732 .589 r
.3821 .53776 .3857 .54038 .39294 .50516 .38939 .50215 Mtetra
.945 .717 .563 r
.38939 .50215 .39294 .50516 .40064 .4548 .39718 .45138 Mtetra
.935 .727 .597 r
.39718 .45138 .40064 .4548 .4075 .42338 .40408 .41981 Mtetra
.832 .378 0 r
.40408 .41981 .4075 .42338 .41285 .43328 .40942 .42995 Mtetra
.955 .648 .409 r
.40942 .42995 .41285 .43328 .41699 .48183 .4135 .47901 Mtetra
.954 .652 .424 r
.4135 .47901 .41699 .48183 .42102 .54028 .41745 .53794 Mtetra
.942 .6 .345 r
.41745 .53794 .42102 .54028 .42616 .56827 .42256 .56603 Mtetra
.946 .756 .615 r
.42256 .56603 .42616 .56827 .43287 .54312 .42932 .54047 Mtetra
.953 .716 .543 r
.42932 .54047 .43287 .54312 .44046 .4807 .43701 .47744 Mtetra
.95 .715 .547 r
.43701 .47744 .44046 .4807 .44774 .42328 .44436 .41965 Mtetra
.907 .754 .681 r
.44436 .41965 .44774 .42328 .45388 .40864 .45052 .40511 Mtetra
.957 .635 .369 r
.45052 .40511 .45388 .40864 .4589 .44827 .45549 .44527 Mtetra
.958 .658 .422 r
.45549 .44527 .4589 .44827 .46348 .52063 .45999 .51832 Mtetra
.955 .646 .408 r
.45999 .51832 .46348 .52063 .46857 .57903 .46502 .57709 Mtetra
.148 .617 .926 r
.46502 .57709 .46857 .57903 .47474 .58028 .47121 .57808 Mtetra
.96 .723 .536 r
.47121 .57808 .47474 .58028 .48172 .52109 .47826 .51818 Mtetra
.959 .712 .521 r
.47826 .51818 .48172 .52109 .48871 .44218 .48536 .43863 Mtetra
.952 .721 .551 r
.48536 .43863 .48871 .44218 .49515 .39503 .49185 .39131 Mtetra
.882 .46 .053 r
.49185 .39131 .49515 .39503 .50098 .40874 .49767 .40542 Mtetra
.962 .655 .4 r
.49767 .40542 .50098 .40874 .50658 .47677 .5032 .47421 Mtetra
.96 .657 .411 r
.5032 .47421 .50658 .47677 .5124 .55802 .50895 .55612 Mtetra
.949 .613 .35 r
.50895 .55612 .5124 .55802 .51863 .59639 .51514 .59457 Mtetra
.965 .753 .568 r
.51514 .59457 .51863 .59639 .52502 .56188 .52158 .55945 Mtetra
.965 .714 .507 r
.52158 .55945 .52502 .56188 .53121 .47819 .52786 .47492 Mtetra
.963 .713 .511 r
.52786 .47492 .53121 .47819 .53713 .40148 .53386 .39772 Mtetra
.94 .746 .613 r
.53386 .39772 .53713 .40148 .54308 .37802 .53985 .37435 Mtetra
.96 .629 .331 r
.53985 .37435 .54308 .37802 .54947 .42049 .5462 .41744 Mtetra
.964 .657 .393 r
.5462 .41744 .54947 .42049 .55642 .50367 .55309 .50143 Mtetra
.961 .647 .383 r
.55309 .50143 .55642 .50367 .56357 .57369 .56018 .57192 Mtetra
.615 .061 0 r
.56018 .57192 .56357 .57369 .57015 .57985 .56677 .57783 Mtetra
.971 .726 .509 r
.56677 .57783 .57015 .57985 .57572 .51631 .5724 .51349 Mtetra
.969 .712 .49 r
.5724 .51349 .57572 .51631 .58063 .42722 .5774 .42365 Mtetra
.965 .72 .515 r
.5774 .42365 .58063 .42722 .5858 .36851 .58262 .36466 Mtetra
0 .36 .831 r
.58262 .36466 .5858 .36851 .59207 .37193 .5889 .36838 Mtetra
.964 .642 .346 r
.5889 .36838 .59207 .37193 .59969 .43281 .59649 .42994 Mtetra
.965 .65 .368 r
.59649 .42994 .59969 .43281 .60804 .51249 .60479 .51031 Mtetra
.954 .613 .317 r
.60479 .51031 .60804 .51249 .61577 .55659 .61249 .55461 Mtetra
.971 .784 .594 r
.61249 .55461 .61577 .55659 .62173 .53243 .61847 .53 Mtetra
.974 .719 .485 r
.61847 .53 .62173 .53243 .62602 .45686 .62283 .45366 Mtetra
.973 .715 .484 r
.62283 .45366 .62602 .45686 .63 .37998 .62687 .37622 Mtetra
.963 .74 .554 r
.62687 .37622 .63 .37998 .6352 .34618 .6321 .34232 Mtetra
.924 .542 .151 r
.6321 .34232 .6352 .34618 .64242 .37048 .63933 .36699 Mtetra
.964 .638 .324 r
.63933 .36699 .64242 .37048 .65131 .43459 .64819 .43171 Mtetra
.962 .631 .321 r
.64819 .43171 .65131 .43459 .66035 .49553 .6572 .49313 Mtetra
.854 .406 .008 r
.6572 .49313 .66035 .49553 .66767 .51017 .66452 .50777 Mtetra
.978 .745 .516 r
.66452 .50777 .66767 .51017 .67251 .46756 .66939 .46466 Mtetra
.978 .72 .474 r
.66939 .46466 .67251 .46756 .67589 .39705 .67282 .39354 Mtetra
.975 .726 .494 r
.67282 .39354 .67589 .39705 .67979 .34243 .67675 .33854 Mtetra
.895 .787 .734 r
.67675 .33854 .67979 .34243 .68575 .33218 .68273 .32831 Mtetra
.941 .579 .201 r
.68273 .32831 .68575 .33218 .69406 .36679 .69104 .36327 Mtetra
.958 .618 .275 r
.69104 .36327 .69406 .36679 .70361 .42068 .70058 .41763 Mtetra
.941 .575 .211 r
.70058 .41763 .70361 .42068 .71234 .45592 .7093 .45315 Mtetra
.904 .848 .779 r
.7093 .45315 .71234 .45592 .71863 .44711 .7156 .44421 Mtetra
.981 .738 .493 r
.7156 .44421 .71863 .44711 .72257 .40023 .71957 .39691 Mtetra
.98 .728 .479 r
.71957 .39691 .72257 .40023 .72587 .34598 .7229 .34221 Mtetra
.972 .752 .546 r
.7229 .34221 .72587 .34598 .73053 .31562 .72758 .31164 Mtetra
0 .112 .647 r
.72758 .31164 .73053 .31562 .7376 .32232 .73466 .31842 Mtetra
.93 .56 .157 r
.73466 .31842 .7376 .32232 .74663 .35644 .74369 .35282 Mtetra
.933 .563 .169 r
.74369 .35282 .74663 .35644 .75595 .39212 .75301 .38882 Mtetra
.685 .215 0 r
.75301 .38882 .75595 .39212 .76362 .40328 .76069 .40009 Mtetra
.972 .786 .592 r
.76069 .40009 .76362 .40328 .76887 .38159 .76596 .37823 Mtetra
.983 .744 .497 r
.76596 .37823 .76887 .38159 .77261 .34151 .76972 .33783 Mtetra
.98 .75 .519 r
.76972 .33783 .77261 .34151 .7767 .3077 .77383 .30374 Mtetra
.903 .799 .736 r
.77383 .30374 .7767 .3077 .78264 .29759 .77977 .29353 Mtetra
.729 .298 0 r
.77977 .29353 .78264 .29759 .79065 .31225 .78779 .30829 Mtetra
.878 .482 .024 r
.78779 .30829 .79065 .31225 .79968 .33758 .79683 .33384 Mtetra
.772 .339 0 r
.79683 .33384 .79968 .33758 .80803 .35368 .80519 .35011 Mtetra
.815 .821 .855 r
.80519 .35011 .80803 .35368 .8145 .3482 .81168 .34463 Mtetra
.977 .777 .567 r
.81168 .34463 .8145 .3482 .81925 .32438 .81645 .32064 Mtetra
.98 .766 .542 r
.81645 .32064 .81925 .32438 .82361 .29724 .82082 .29328 Mtetra
.95 .794 .653 r
.82082 .29328 .82361 .29724 .82904 .28197 .82625 .27786 Mtetra
.291 .542 .918 r
.82625 .27786 .82904 .28197 .83617 .28414 .83339 .28002 Mtetra
.644 .215 0 r
.83339 .28002 .83617 .28414 .8445 .29761 .84173 .29359 Mtetra
0 0 .402 r
.84173 .29359 .8445 .29761 .85274 .30945 .84999 .30556 Mtetra
.505 .684 .947 r
.84999 .30556 .85274 .30945 .85978 .30926 .85704 .30541 Mtetra
.94 .812 .691 r
.85704 .30541 .85978 .30926 .86546 .29648 .86274 .29257 Mtetra
.648 .748 .923 r
.25305 .48667 .25671 .48988 .26218 .48826 .25853 .48504 Mtetra
.87 .754 .732 r
.25853 .48504 .26218 .48826 .26832 .47822 .26469 .47492 Mtetra
.885 .746 .703 r
.26469 .47492 .26832 .47822 .27464 .46565 .27103 .46227 Mtetra
.809 .761 .808 r
.27103 .46227 .27464 .46565 .28041 .46013 .27682 .45673 Mtetra
.776 .291 0 r
.27682 .45673 .28041 .46013 .28524 .46743 .28164 .4641 Mtetra
.935 .571 .295 r
.28164 .4641 .28524 .46743 .28942 .48455 .28579 .48135 Mtetra
.929 .556 .273 r
.28579 .48135 .28942 .48455 .29376 .50041 .29011 .49732 Mtetra
0 .404 .839 r
.29011 .49732 .29376 .50041 .29907 .50293 .29542 .49984 Mtetra
.901 .75 .684 r
.29542 .49984 .29907 .50293 .30556 .48814 .30194 .48493 Mtetra
.919 .731 .633 r
.30194 .48493 .30556 .48814 .31258 .46451 .30901 .46114 Mtetra
.904 .74 .669 r
.30901 .46114 .31258 .46451 .31911 .44788 .31556 .44443 Mtetra
0 .355 .817 r
.31556 .44443 .31911 .44788 .3244 .4508 .32085 .4474 Mtetra
.945 .604 .344 r
.32085 .4474 .3244 .4508 .32851 .47384 .32493 .47064 Mtetra
.947 .624 .387 r
.32493 .47064 .32851 .47384 .33234 .50359 .32872 .50059 Mtetra
.925 .544 .253 r
.32872 .50059 .33234 .50359 .33706 .51956 .33342 .51665 Mtetra
.891 .772 .724 r
.33342 .51665 .33706 .51956 .34332 .50847 .33971 .50543 Mtetra
.933 .726 .601 r
.33971 .50543 .34332 .50847 .35071 .47572 .34716 .47243 Mtetra
.932 .724 .6 r
.34716 .47243 .35071 .47572 .35802 .44287 .35451 .43938 Mtetra
.873 .758 .733 r
.35451 .43938 .35802 .44287 .3641 .43287 .36061 .42939 Mtetra
.945 .595 .314 r
.36061 .42939 .3641 .43287 .36862 .45508 .36511 .45182 Mtetra
.952 .644 .414 r
.36511 .45182 .36862 .45508 .37228 .49829 .36871 .49536 Mtetra
.949 .631 .396 r
.36871 .49536 .37228 .49829 .3764 .53487 .37278 .53216 Mtetra
0 .357 .785 r
.37278 .53216 .3764 .53487 .3821 .53776 .37848 .53497 Mtetra
.941 .73 .589 r
.37848 .53497 .3821 .53776 .38939 .50215 .38584 .49903 Mtetra
.944 .716 .563 r
.38584 .49903 .38939 .50215 .39718 .45138 .3937 .44791 Mtetra
.935 .727 .597 r
.3937 .44791 .39718 .45138 .40408 .41981 .40065 .41623 Mtetra
.839 .387 0 r
.40065 .41623 .40408 .41981 .40942 .42995 .40597 .42657 Mtetra
.955 .648 .41 r
.40597 .42657 .40942 .42995 .4135 .47901 .40999 .47606 Mtetra
.954 .653 .424 r
.40999 .47606 .4135 .47901 .41745 .53794 .41387 .53539 Mtetra
.944 .601 .341 r
.41387 .53539 .41745 .53794 .42256 .56603 .41896 .56355 Mtetra
.943 .752 .615 r
.41896 .56355 .42256 .56603 .42932 .54047 .42576 .53764 Mtetra
.952 .715 .543 r
.42576 .53764 .42932 .54047 .43701 .47744 .43354 .4741 Mtetra
.95 .715 .547 r
.43354 .4741 .43701 .47744 .44436 .41965 .44096 .416 Mtetra
.906 .755 .682 r
.44096 .416 .44436 .41965 .45052 .40511 .44715 .40156 Mtetra
.957 .635 .37 r
.44715 .40156 .45052 .40511 .45549 .44527 .45207 .44216 Mtetra
.958 .659 .422 r
.45207 .44216 .45549 .44527 .45999 .51832 .45649 .51578 Mtetra
.956 .647 .407 r
.45649 .51578 .45999 .51832 .46502 .57709 .46146 .57486 Mtetra
.24 .656 .961 r
.46146 .57486 .46502 .57709 .47121 .57808 .46765 .57563 Mtetra
.959 .722 .536 r
.46765 .57563 .47121 .57808 .47826 .51818 .47479 .51512 Mtetra
.958 .711 .521 r
.47479 .51512 .47826 .51818 .48536 .43863 .48198 .43503 Mtetra
.952 .721 .551 r
.48198 .43503 .48536 .43863 .49185 .39131 .48853 .38758 Mtetra
.887 .467 .065 r
.48853 .38758 .49185 .39131 .49767 .40542 .49434 .40203 Mtetra
.962 .655 .4 r
.49434 .40203 .49767 .40542 .5032 .47421 .4998 .47145 Mtetra
.961 .658 .411 r
.4998 .47145 .5032 .47421 .50895 .55612 .50547 .55391 Mtetra
.95 .615 .346 r
.50547 .55391 .50895 .55612 .51514 .59457 .51164 .59243 Mtetra
.963 .749 .568 r
.51164 .59243 .51514 .59457 .52158 .55945 .51812 .55678 Mtetra
.964 .713 .507 r
.51812 .55678 .52158 .55945 .52786 .47492 .5245 .47155 Mtetra
.962 .712 .511 r
.5245 .47155 .52786 .47492 .53386 .39772 .53059 .39394 Mtetra
.94 .746 .614 r
.53059 .39394 .53386 .39772 .53985 .37435 .5366 .37067 Mtetra
.96 .629 .332 r
.5366 .37067 .53985 .37435 .5462 .41744 .54293 .41427 Mtetra
.964 .657 .393 r
.54293 .41427 .5462 .41744 .55309 .50143 .54974 .49892 Mtetra
.961 .648 .381 r
.54974 .49892 .55309 .50143 .56018 .57192 .55678 .5698 Mtetra
.564 .012 0 r
.55678 .5698 .56018 .57192 .56677 .57783 .56337 .5755 Mtetra
.97 .724 .509 r
.56337 .5755 .56677 .57783 .5724 .51349 .56906 .51049 Mtetra
.969 .712 .491 r
.56906 .51049 .5724 .51349 .5774 .42365 .57414 .42002 Mtetra
.965 .719 .515 r
.57414 .42002 .5774 .42365 .58262 .36466 .57943 .36081 Mtetra
0 .331 .811 r
.57943 .36081 .58262 .36466 .5889 .36838 .58572 .36477 Mtetra
.964 .643 .347 r
.58572 .36477 .5889 .36838 .59649 .42994 .59327 .4269 Mtetra
.965 .651 .368 r
.59327 .4269 .59649 .42994 .60479 .51031 .60151 .50784 Mtetra
.955 .614 .313 r
.60151 .50784 .60479 .51031 .61249 .55461 .60919 .5523 Mtetra
.968 .778 .594 r
.60919 .5523 .61249 .55461 .61847 .53 .61519 .52731 Mtetra
.974 .718 .485 r
.61519 .52731 .61847 .53 .62283 .45366 .61961 .45033 Mtetra
.972 .715 .484 r
.61961 .45033 .62283 .45366 .62687 .37622 .62373 .37242 Mtetra
.962 .739 .554 r
.62373 .37242 .62687 .37622 .6321 .34232 .629 .33845 Mtetra
.925 .544 .154 r
.629 .33845 .6321 .34232 .63933 .36699 .63621 .36343 Mtetra
.965 .638 .325 r
.63621 .36343 .63933 .36699 .64819 .43171 .64504 .42865 Mtetra
.962 .632 .32 r
.64504 .42865 .64819 .43171 .6572 .49313 .65402 .49046 Mtetra
.849 .4 0 r
.65402 .49046 .6572 .49313 .66452 .50777 .66134 .50509 Mtetra
.977 .743 .517 r
.66134 .50509 .66452 .50777 .66939 .46466 .66624 .46157 Mtetra
.977 .719 .475 r
.66624 .46157 .66939 .46466 .67282 .39354 .66972 .38994 Mtetra
.975 .725 .494 r
.66972 .38994 .67282 .39354 .67675 .33854 .6737 .33463 Mtetra
.895 .787 .735 r
.6737 .33463 .67675 .33854 .68273 .32831 .6797 .32441 Mtetra
.942 .58 .203 r
.6797 .32441 .68273 .32831 .69104 .36327 .688 .35967 Mtetra
.959 .618 .275 r
.688 .35967 .69104 .36327 .70058 .41763 .69752 .41442 Mtetra
.941 .575 .209 r
.69752 .41442 .70058 .41763 .7093 .45315 .70623 .45015 Mtetra
.901 .839 .775 r
.70623 .45015 .7093 .45315 .7156 .44421 .71255 .44111 Mtetra
.98 .737 .494 r
.71255 .44111 .7156 .44421 .71957 .39691 .71654 .39345 Mtetra
.98 .727 .479 r
.71654 .39345 .71957 .39691 .7229 .34221 .71991 .3384 Mtetra
.972 .751 .546 r
.71991 .3384 .7229 .34221 .72758 .31164 .72462 .30764 Mtetra
0 .107 .642 r
.72462 .30764 .72758 .31164 .73466 .31842 .7317 .31448 Mtetra
.93 .561 .158 r
.7317 .31448 .73466 .31842 .74369 .35282 .74073 .34913 Mtetra
.933 .564 .168 r
.74073 .34913 .74369 .35282 .75301 .38882 .75005 .38537 Mtetra
.679 .212 0 r
.75005 .38537 .75301 .38882 .76069 .40009 .75774 .39674 Mtetra
.971 .783 .593 r
.75774 .39674 .76069 .40009 .76596 .37823 .76302 .37475 Mtetra
.982 .743 .497 r
.76302 .37475 .76596 .37823 .76972 .33783 .76681 .33408 Mtetra
.979 .749 .519 r
.76681 .33408 .76972 .33783 .77383 .30374 .77094 .29975 Mtetra
.903 .799 .734 r
.77094 .29975 .77383 .30374 .77977 .29353 .77689 .28945 Mtetra
.732 .3 0 r
.77689 .28945 .77977 .29353 .78779 .30829 .78492 .3043 Mtetra
.878 .483 .026 r
.78492 .3043 .78779 .30829 .79683 .33384 .79396 .33002 Mtetra
.772 .34 0 r
.79396 .33002 .79683 .33384 .80519 .35011 .80233 .34643 Mtetra
.813 .816 .853 r
.80233 .34643 .80519 .35011 .81168 .34463 .80883 .34096 Mtetra
.977 .775 .567 r
.80883 .34096 .81168 .34463 .81645 .32064 .81362 .31683 Mtetra
.98 .764 .542 r
.81362 .31683 .81645 .32064 .82082 .29328 .81801 .28928 Mtetra
.95 .793 .651 r
.81801 .28928 .82082 .29328 .82625 .27786 .82345 .27373 Mtetra
.292 .543 .918 r
.82345 .27373 .82625 .27786 .83339 .28002 .8306 .27588 Mtetra
.647 .217 0 r
.8306 .27588 .83339 .28002 .84173 .29359 .83894 .28953 Mtetra
.584 .15 0 r
.83894 .28953 .84173 .29359 .84999 .30556 .84721 .3016 Mtetra
.503 .68 .945 r
.84721 .3016 .84999 .30556 .85704 .30541 .85428 .30148 Mtetra
.939 .81 .691 r
.85428 .30148 .85704 .30541 .86274 .29257 .85999 .28859 Mtetra
.648 .746 .921 r
.24938 .48341 .25305 .48667 .25853 .48504 .25487 .48177 Mtetra
.87 .753 .731 r
.25487 .48177 .25853 .48504 .26469 .47492 .26105 .47159 Mtetra
.885 .745 .702 r
.26105 .47159 .26469 .47492 .27103 .46227 .26742 .45888 Mtetra
.809 .761 .808 r
.26742 .45888 .27103 .46227 .27682 .45673 .27321 .45332 Mtetra
.779 .295 0 r
.27321 .45332 .27682 .45673 .28164 .4641 .27802 .46075 Mtetra
.935 .572 .296 r
.27802 .46075 .28164 .4641 .28579 .48135 .28215 .4781 Mtetra
.93 .557 .272 r
.28215 .4781 .28579 .48135 .29011 .49732 .28645 .49414 Mtetra
0 .408 .845 r
.28645 .49414 .29011 .49732 .29542 .49984 .29177 .49667 Mtetra
.9 .748 .684 r
.29177 .49667 .29542 .49984 .30194 .48493 .29831 .48167 Mtetra
.918 .73 .632 r
.29831 .48167 .30194 .48493 .30901 .46114 .30542 .45775 Mtetra
.904 .74 .668 r
.30542 .45775 .30901 .46114 .31556 .44443 .312 .44096 Mtetra
0 .347 .811 r
.312 .44096 .31556 .44443 .32085 .4474 .31729 .44398 Mtetra
.945 .605 .345 r
.31729 .44398 .32085 .4474 .32493 .47064 .32134 .46736 Mtetra
.947 .625 .387 r
.32134 .46736 .32493 .47064 .32872 .50059 .32509 .49748 Mtetra
.926 .545 .25 r
.32509 .49748 .32872 .50059 .33342 .51665 .32977 .51359 Mtetra
.889 .768 .723 r
.32977 .51359 .33342 .51665 .33971 .50543 .33609 .50228 Mtetra
.932 .725 .6 r
.33609 .50228 .33971 .50543 .34716 .47243 .34359 .46907 Mtetra
.931 .723 .599 r
.34359 .46907 .34716 .47243 .35451 .43938 .35099 .43588 Mtetra
.872 .758 .733 r
.35099 .43588 .35451 .43938 .36061 .42939 .35711 .42589 Mtetra
.945 .595 .316 r
.35711 .42589 .36061 .42939 .36511 .45182 .36157 .44849 Mtetra
.952 .645 .414 r
.36157 .44849 .36511 .45182 .36871 .49536 .36512 .49229 Mtetra
.95 .632 .395 r
.36512 .49229 .36871 .49536 .37278 .53216 .36915 .52925 Mtetra
0 .382 .814 r
.36915 .52925 .37278 .53216 .37848 .53497 .37486 .532 Mtetra
.94 .728 .589 r
.37486 .532 .37848 .53497 .38584 .49903 .38227 .4958 Mtetra
.944 .716 .563 r
.38227 .4958 .38584 .49903 .3937 .44791 .39021 .44441 Mtetra
.935 .727 .597 r
.39021 .44441 .3937 .44791 .40065 .41623 .3972 .41263 Mtetra
.843 .394 0 r
.3972 .41263 .40065 .41623 .40597 .42657 .40251 .42314 Mtetra
.956 .649 .41 r
.40251 .42314 .40597 .42657 .40999 .47606 .40647 .47296 Mtetra
.955 .653 .423 r
.40647 .47296 .40999 .47606 .41387 .53539 .41028 .5326 Mtetra
.945 .602 .338 r
.41028 .5326 .41387 .53539 .41896 .56355 .41534 .56081 Mtetra
.941 .749 .614 r
.41534 .56081 .41896 .56355 .42576 .53764 .42219 .53462 Mtetra
.952 .714 .543 r
.42219 .53462 .42576 .53764 .43354 .4741 .43006 .47068 Mtetra
.95 .714 .547 r
.43006 .47068 .43354 .4741 .44096 .416 .43756 .41235 Mtetra
.906 .755 .683 r
.43756 .41235 .44096 .416 .44715 .40156 .44376 .39797 Mtetra
.957 .636 .371 r
.44376 .39797 .44715 .40156 .45207 .44216 .44864 .43893 Mtetra
.959 .659 .422 r
.44864 .43893 .45207 .44216 .45649 .51578 .45297 .513 Mtetra
.956 .648 .405 r
.45297 .513 .45649 .51578 .46146 .57486 .45789 .5723 Mtetra
.314 .677 .977 r
.45789 .5723 .46146 .57486 .46765 .57563 .46409 .57289 Mtetra
.958 .72 .537 r
.46409 .57289 .46765 .57563 .47479 .51512 .47131 .5119 Mtetra
.958 .71 .521 r
.47131 .5119 .47479 .51512 .48198 .43503 .4786 .4314 Mtetra
.952 .721 .551 r
.4786 .4314 .48198 .43503 .48853 .38758 .48521 .38385 Mtetra
.89 .473 .074 r
.48521 .38385 .48853 .38758 .49434 .40203 .491 .39857 Mtetra
.962 .656 .4 r
.491 .39857 .49434 .40203 .4998 .47145 .49639 .46848 Mtetra
.961 .659 .41 r
.49639 .46848 .4998 .47145 .50547 .55391 .50198 .55137 Mtetra
.952 .616 .342 r
.50198 .55137 .50547 .55391 .51164 .59243 .50812 .58992 Mtetra
.96 .745 .569 r
.50812 .58992 .51164 .59243 .51812 .55678 .51465 .55385 Mtetra
.964 .712 .507 r
.51465 .55385 .51812 .55678 .5245 .47155 .52112 .46807 Mtetra
.962 .712 .511 r
.52112 .46807 .5245 .47155 .53059 .39394 .5273 .39015 Mtetra
.94 .746 .614 r
.5273 .39015 .53059 .39394 .5366 .37067 .53335 .36695 Mtetra
.96 .63 .333 r
.53335 .36695 .5366 .37067 .54293 .41427 .53963 .41096 Mtetra
.965 .658 .392 r
.53963 .41096 .54293 .41427 .54974 .49892 .54637 .49614 Mtetra
.962 .648 .38 r
.54637 .49614 .54974 .49892 .55678 .5698 .55335 .56731 Mtetra
.504 0 0 r
.55335 .56731 .55678 .5698 .56337 .5755 .55994 .57283 Mtetra
.969 .723 .51 r
.55994 .57283 .56337 .5755 .56906 .51049 .56571 .50729 Mtetra
.968 .711 .491 r
.56571 .50729 .56906 .51049 .57414 .42002 .57088 .41632 Mtetra
.965 .719 .515 r
.57088 .41632 .57414 .42002 .57943 .36081 .57623 .35695 Mtetra
0 .306 .794 r
.57623 .35695 .57943 .36081 .58572 .36477 .58252 .36111 Mtetra
.965 .643 .347 r
.58252 .36111 .58572 .36477 .59327 .4269 .59003 .42369 Mtetra
.966 .651 .367 r
.59003 .42369 .59327 .4269 .60151 .50784 .59821 .50506 Mtetra
.956 .615 .309 r
.59821 .50506 .60151 .50784 .60919 .5523 .60586 .54964 Mtetra
.965 .772 .595 r
.60586 .54964 .60919 .5523 .61519 .52731 .61189 .52434 Mtetra
.973 .717 .486 r
.61189 .52434 .61519 .52731 .61961 .45033 .61638 .44685 Mtetra
.972 .714 .484 r
.61638 .44685 .61961 .45033 .62373 .37242 .62057 .36858 Mtetra
.962 .739 .554 r
.62057 .36858 .62373 .37242 .629 .33845 .62587 .33456 Mtetra
.926 .546 .157 r
.62587 .33456 .629 .33845 .63621 .36343 .63308 .35978 Mtetra
.965 .638 .324 r
.63308 .35978 .63621 .36343 .64504 .42865 .64187 .4254 Mtetra
.963 .633 .318 r
.64187 .4254 .64504 .42865 .65402 .49046 .65082 .48751 Mtetra
.842 .394 0 r
.65082 .48751 .65402 .49046 .66134 .50509 .65813 .50212 Mtetra
.976 .741 .518 r
.65813 .50212 .66134 .50509 .66624 .46157 .66307 .45828 Mtetra
.976 .718 .475 r
.66307 .45828 .66624 .46157 .66972 .38994 .66661 .38624 Mtetra
.974 .724 .494 r
.66661 .38624 .66972 .38994 .6737 .33463 .67064 .3307 Mtetra
.894 .787 .735 r
.67064 .3307 .6737 .33463 .6797 .32441 .67665 .32049 Mtetra
.942 .581 .204 r
.67665 .32049 .6797 .32441 .688 .35967 .68495 .35598 Mtetra
.959 .619 .274 r
.68495 .35598 .688 .35967 .69752 .41442 .69444 .41103 Mtetra
.941 .575 .206 r
.69444 .41103 .69752 .41442 .70623 .45015 .70314 .44693 Mtetra
.897 .829 .771 r
.70314 .44693 .70623 .45015 .71255 .44111 .70947 .4378 Mtetra
.979 .735 .495 r
.70947 .4378 .71255 .44111 .71654 .39345 .7135 .38987 Mtetra
.979 .727 .48 r
.7135 .38987 .71654 .39345 .71991 .3384 .71691 .33452 Mtetra
.971 .75 .546 r
.71691 .33452 .71991 .3384 .72462 .30764 .72165 .30362 Mtetra
0 .102 .638 r
.72165 .30362 .72462 .30764 .7317 .31448 .72874 .31051 Mtetra
.93 .561 .159 r
.72874 .31051 .7317 .31448 .74073 .34913 .73776 .34534 Mtetra
.933 .564 .167 r
.73776 .34534 .74073 .34913 .75005 .38537 .74706 .38179 Mtetra
.671 .208 0 r
.74706 .38179 .75005 .38537 .75774 .39674 .75476 .39322 Mtetra
.969 .78 .593 r
.75476 .39322 .75774 .39674 .76302 .37475 .76007 .37111 Mtetra
.982 .742 .498 r
.76007 .37111 .76302 .37475 .76681 .33408 .76388 .33023 Mtetra
.979 .748 .519 r
.76388 .33023 .76681 .33408 .77094 .29975 .76804 .29572 Mtetra
.903 .798 .733 r
.76804 .29572 .77094 .29975 .77689 .28945 .774 .28535 Mtetra
.733 .302 0 r
.774 .28535 .77689 .28945 .78492 .3043 .78203 .30026 Mtetra
.879 .484 .026 r
.78203 .30026 .78492 .3043 .79396 .33002 .79108 .32612 Mtetra
.771 .34 0 r
.79108 .32612 .79396 .33002 .80233 .34643 .79945 .34264 Mtetra
.81 .81 .85 r
.79945 .34264 .80233 .34643 .80883 .34096 .80597 .33716 Mtetra
.976 .773 .567 r
.80597 .33716 .80883 .34096 .81362 .31683 .81078 .31292 Mtetra
.979 .763 .542 r
.81078 .31292 .81362 .31683 .81801 .28928 .81518 .28523 Mtetra
.95 .792 .65 r
.81518 .28523 .81801 .28928 .82345 .27373 .82064 .26958 Mtetra
.293 .543 .918 r
.82064 .26958 .82345 .27373 .8306 .27588 .82779 .27171 Mtetra
.649 .219 0 r
.82779 .27171 .8306 .27588 .83894 .28953 .83614 .28542 Mtetra
.585 .152 0 r
.83614 .28542 .83894 .28953 .84721 .3016 .84442 .29757 Mtetra
.502 .676 .943 r
.84442 .29757 .84721 .3016 .85428 .30148 .8515 .29749 Mtetra
.938 .808 .69 r
.8515 .29749 .85428 .30148 .85999 .28859 .85723 .28454 Mtetra
.649 .744 .919 r
.24569 .4801 .24938 .48341 .25487 .48177 .25119 .47845 Mtetra
.87 .752 .73 r
.25119 .47845 .25487 .48177 .26105 .47159 .25739 .46823 Mtetra
.885 .745 .702 r
.25739 .46823 .26105 .47159 .26742 .45888 .26378 .45547 Mtetra
.809 .76 .808 r
.26378 .45547 .26742 .45888 .27321 .45332 .26959 .4499 Mtetra
.782 .298 0 r
.26959 .4499 .27321 .45332 .27802 .46075 .2744 .45736 Mtetra
.935 .573 .297 r
.2744 .45736 .27802 .46075 .28215 .4781 .2785 .47478 Mtetra
.93 .558 .272 r
.2785 .47478 .28215 .4781 .28645 .49414 .28278 .49089 Mtetra
0 .412 .85 r
.28278 .49089 .28645 .49414 .29177 .49667 .2881 .49341 Mtetra
.899 .746 .683 r
.2881 .49341 .29177 .49667 .29831 .48167 .29467 .47833 Mtetra
.918 .729 .632 r
.29467 .47833 .29831 .48167 .30542 .45775 .30182 .45432 Mtetra
.904 .739 .668 r
.30182 .45432 .30542 .45775 .312 .44096 .30843 .43749 Mtetra
0 .341 .807 r
.30843 .43749 .312 .44096 .31729 .44398 .31371 .44054 Mtetra
.945 .605 .345 r
.31371 .44054 .31729 .44398 .32134 .46736 .31774 .46402 Mtetra
.948 .625 .386 r
.31774 .46402 .32134 .46736 .32509 .49748 .32145 .49426 Mtetra
.927 .545 .247 r
.32145 .49426 .32509 .49748 .32977 .51359 .32612 .51041 Mtetra
.887 .765 .721 r
.32612 .51041 .32977 .51359 .33609 .50228 .33245 .49902 Mtetra
.932 .724 .6 r
.33245 .49902 .33609 .50228 .34359 .46907 .34001 .46566 Mtetra
.931 .723 .599 r
.34001 .46566 .34359 .46907 .35099 .43588 .34746 .43236 Mtetra
.872 .758 .733 r
.34746 .43236 .35099 .43588 .35711 .42589 .35359 .42237 Mtetra
.945 .596 .317 r
.35359 .42237 .35711 .42589 .36157 .44849 .35803 .4451 Mtetra
.952 .645 .414 r
.35803 .4451 .36157 .44849 .36512 .49229 .36152 .48908 Mtetra
.95 .633 .394 r
.36152 .48908 .36512 .49229 .36915 .52925 .36551 .52616 Mtetra
0 .402 .836 r
.36551 .52616 .36915 .52925 .37486 .532 .37123 .52886 Mtetra
.939 .727 .589 r
.37123 .52886 .37486 .532 .38227 .4958 .3787 .49246 Mtetra
.943 .715 .563 r
.3787 .49246 .38227 .4958 .39021 .44441 .3867 .44087 Mtetra
.935 .726 .597 r
.3867 .44087 .39021 .44441 .3972 .41263 .39374 .40903 Mtetra
.847 .399 0 r
.39374 .40903 .3972 .41263 .40251 .42314 .39904 .41965 Mtetra
.956 .649 .41 r
.39904 .41965 .40251 .42314 .40647 .47296 .40294 .46972 Mtetra
.955 .654 .423 r
.40294 .46972 .40647 .47296 .41028 .5326 .40668 .52959 Mtetra
.946 .603 .334 r
.40668 .52959 .41028 .5326 .41534 .56081 .41172 .55782 Mtetra
.939 .745 .614 r
.41172 .55782 .41534 .56081 .42219 .53462 .41861 .53142 Mtetra
.951 .714 .543 r
.41861 .53142 .42219 .53462 .43006 .47068 .42656 .46719 Mtetra
.949 .714 .547 r
.42656 .46719 .43006 .47068 .43756 .41235 .43414 .40868 Mtetra
.906 .755 .684 r
.43414 .40868 .43756 .41235 .44376 .39797 .44036 .39436 Mtetra
.957 .636 .371 r
.44036 .39436 .44376 .39797 .44864 .43893 .44519 .43558 Mtetra
.959 .66 .421 r
.44519 .43558 .44864 .43893 .45297 .513 .44945 .50997 Mtetra
.957 .649 .404 r
.44945 .50997 .45297 .513 .45789 .5723 .4543 .56944 Mtetra
.369 .684 .979 r
.4543 .56944 .45789 .5723 .46409 .57289 .46052 .56988 Mtetra
.956 .719 .537 r
.46052 .56988 .46409 .57289 .47131 .5119 .46781 .50853 Mtetra
.957 .71 .521 r
.46781 .50853 .47131 .5119 .4786 .4314 .4752 .42773 Mtetra
.952 .72 .551 r
.4752 .42773 .4786 .4314 .48521 .38385 .48187 .38012 Mtetra
.893 .477 .081 r
.48187 .38012 .48521 .38385 .491 .39857 .48765 .39503 Mtetra
.962 .656 .4 r
.48765 .39503 .491 .39857 .49639 .46848 .49297 .46531 Mtetra
.962 .659 .409 r
.49297 .46531 .49639 .46848 .50198 .55137 .49848 .54851 Mtetra
.953 .617 .338 r
.49848 .54851 .50198 .55137 .50812 .58992 .50458 .58707 Mtetra
.958 .742 .569 r
.50458 .58707 .50812 .58992 .51465 .55385 .51116 .55069 Mtetra
.963 .711 .508 r
.51116 .55069 .51465 .55385 .52112 .46807 .51773 .4645 Mtetra
.962 .711 .511 r
.51773 .4645 .52112 .46807 .5273 .39015 .524 .38635 Mtetra
.94 .746 .615 r
.524 .38635 .5273 .39015 .53335 .36695 .53007 .36321 Mtetra
.96 .63 .334 r
.53007 .36321 .53335 .36695 .53963 .41096 .53632 .40753 Mtetra
.965 .658 .392 r
.53632 .40753 .53963 .41096 .54637 .49614 .54299 .49308 Mtetra
.963 .649 .378 r
.54299 .49308 .54637 .49614 .55335 .56731 .5499 .56447 Mtetra
0 .087 .554 r
.5499 .56447 .55335 .56731 .55994 .57283 .5565 .56984 Mtetra
.967 .721 .511 r
.5565 .56984 .55994 .57283 .56571 .50729 .56233 .5039 Mtetra
.968 .71 .491 r
.56233 .5039 .56571 .50729 .57088 .41632 .5676 .41258 Mtetra
.965 .719 .515 r
.5676 .41258 .57088 .41632 .57623 .35695 .57302 .35308 Mtetra
0 .288 .78 r
.57302 .35308 .57623 .35695 .58252 .36111 .57932 .35739 Mtetra
.965 .643 .347 r
.57932 .35739 .58252 .36111 .59003 .42369 .58677 .4203 Mtetra
.966 .652 .366 r
.58677 .4203 .59003 .42369 .59821 .50506 .59489 .50199 Mtetra
.956 .616 .306 r
.59489 .50199 .59821 .50506 .60586 .54964 .60251 .54665 Mtetra
.962 .767 .595 r
.60251 .54665 .60586 .54964 .61189 .52434 .60857 .52112 Mtetra
.972 .716 .487 r
.60857 .52112 .61189 .52434 .61638 .44685 .61313 .44325 Mtetra
.972 .714 .485 r
.61313 .44325 .61638 .44685 .62057 .36858 .61739 .36471 Mtetra
.962 .739 .554 r
.61739 .36471 .62057 .36858 .62587 .33456 .62274 .33065 Mtetra
.927 .547 .159 r
.62274 .33065 .62587 .33456 .63308 .35978 .62994 .35606 Mtetra
.965 .639 .324 r
.62994 .35606 .63308 .35978 .64187 .4254 .63868 .42197 Mtetra
.963 .633 .317 r
.63868 .42197 .64187 .4254 .65082 .48751 .64759 .48429 Mtetra
.834 .388 0 r
.64759 .48429 .65082 .48751 .65813 .50212 .6549 .49889 Mtetra
.974 .739 .519 r
.6549 .49889 .65813 .50212 .66307 .45828 .65988 .4548 Mtetra
.976 .718 .476 r
.65988 .4548 .66307 .45828 .66661 .38624 .66348 .38246 Mtetra
.974 .724 .494 r
.66348 .38246 .66661 .38624 .67064 .3307 .66756 .32674 Mtetra
.894 .787 .735 r
.66756 .32674 .67064 .3307 .67665 .32049 .67359 .31655 Mtetra
.942 .581 .204 r
.67359 .31655 .67665 .32049 .68495 .35598 .68187 .3522 Mtetra
.959 .619 .274 r
.68187 .3522 .68495 .35598 .69444 .41103 .69133 .40746 Mtetra
.941 .575 .202 r
.69133 .40746 .69444 .41103 .70314 .44693 .70002 .44349 Mtetra
.893 .82 .768 r
.70002 .44349 .70314 .44693 .70947 .4378 .70636 .43429 Mtetra
.978 .734 .496 r
.70636 .43429 .70947 .4378 .7135 .38987 .71044 .38615 Mtetra
.979 .726 .48 r
.71044 .38615 .7135 .38987 .71691 .33452 .71389 .33059 Mtetra
.971 .75 .546 r
.71389 .33059 .71691 .33452 .72165 .30362 .71866 .29959 Mtetra
0 .1 .635 r
.71866 .29959 .72165 .30362 .72874 .31051 .72575 .30651 Mtetra
.931 .562 .159 r
.72575 .30651 .72874 .31051 .73776 .34534 .73476 .34147 Mtetra
.933 .565 .166 r
.73476 .34147 .73776 .34534 .74706 .38179 .74406 .37806 Mtetra
.663 .204 0 r
.74406 .37806 .74706 .38179 .75476 .39322 .75176 .38954 Mtetra
.968 .777 .594 r
.75176 .38954 .75476 .39322 .76007 .37111 .75709 .36735 Mtetra
.981 .741 .499 r
.75709 .36735 .76007 .37111 .76388 .33023 .76093 .32631 Mtetra
.978 .747 .519 r
.76093 .32631 .76388 .33023 .76804 .29572 .76512 .29166 Mtetra
.904 .797 .733 r
.76512 .29166 .76804 .29572 .774 .28535 .7711 .28124 Mtetra
.734 .303 0 r
.7711 .28124 .774 .28535 .78203 .30026 .77913 .29619 Mtetra
.879 .484 .027 r
.77913 .29619 .78203 .30026 .79108 .32612 .78817 .32215 Mtetra
.769 .34 0 r
.78817 .32215 .79108 .32612 .79945 .34264 .79655 .33874 Mtetra
.808 .805 .848 r
.79655 .33874 .79945 .34264 .80597 .33716 .80308 .33326 Mtetra
.975 .772 .567 r
.80308 .33326 .80597 .33716 .81078 .31292 .80791 .30894 Mtetra
.979 .762 .542 r
.80791 .30894 .81078 .31292 .81518 .28523 .81234 .28113 Mtetra
.95 .791 .65 r
.81234 .28113 .81518 .28523 .82064 .26958 .81781 .26541 Mtetra
.294 .544 .918 r
.81781 .26541 .82064 .26958 .82779 .27171 .82497 .26753 Mtetra
.65 .221 0 r
.82497 .26753 .82779 .27171 .83614 .28542 .83333 .28128 Mtetra
.585 .153 0 r
.83333 .28128 .83614 .28542 .84442 .29757 .84162 .29348 Mtetra
.501 .673 .941 r
.84162 .29348 .84442 .29757 .8515 .29749 .84871 .29341 Mtetra
.937 .806 .69 r
.84871 .29341 .8515 .29749 .85723 .28454 .85446 .28044 Mtetra
.649 .742 .918 r
.242 .47675 .24569 .4801 .25119 .47845 .2475 .47509 Mtetra
.869 .751 .73 r
.2475 .47509 .25119 .47845 .25739 .46823 .25372 .46484 Mtetra
.885 .744 .701 r
.25372 .46484 .25739 .46823 .26378 .45547 .26014 .45205 Mtetra
.809 .76 .807 r
.26014 .45205 .26378 .45547 .26959 .4499 .26595 .44646 Mtetra
.783 .3 0 r
.26595 .44646 .26959 .4499 .2744 .45736 .27075 .45394 Mtetra
.936 .573 .297 r
.27075 .45394 .2744 .45736 .2785 .47478 .27484 .47141 Mtetra
.931 .558 .271 r
.27484 .47141 .2785 .47478 .28278 .49089 .2791 .48755 Mtetra
0 .416 .855 r
.2791 .48755 .28278 .49089 .2881 .49341 .28442 .49006 Mtetra
.898 .745 .682 r
.28442 .49006 .2881 .49341 .29467 .47833 .29102 .47494 Mtetra
.917 .729 .632 r
.29102 .47494 .29467 .47833 .30182 .45432 .29821 .45086 Mtetra
.903 .739 .668 r
.29821 .45086 .30182 .45432 .30843 .43749 .30484 .43399 Mtetra
0 .337 .804 r
.30484 .43399 .30843 .43749 .31371 .44054 .31013 .43706 Mtetra
.945 .605 .346 r
.31013 .43706 .31371 .44054 .31774 .46402 .31412 .46061 Mtetra
.948 .626 .386 r
.31412 .46061 .31774 .46402 .32145 .49426 .3178 .49092 Mtetra
.927 .546 .243 r
.3178 .49092 .32145 .49426 .32612 .51041 .32245 .50709 Mtetra
.885 .761 .72 r
.32245 .50709 .32612 .51041 .33245 .49902 .32881 .49565 Mtetra
.931 .723 .6 r
.32881 .49565 .33245 .49902 .34001 .46566 .33641 .4622 Mtetra
.931 .722 .599 r
.33641 .4622 .34001 .46566 .34746 .43236 .34392 .42882 Mtetra
.872 .758 .734 r
.34392 .42882 .34746 .43236 .35359 .42237 .35006 .41883 Mtetra
.945 .596 .317 r
.35006 .41883 .35359 .42237 .35803 .4451 .35448 .44164 Mtetra
.953 .645 .414 r
.35448 .44164 .35803 .4451 .36152 .48908 .35792 .48574 Mtetra
.951 .634 .393 r
.35792 .48574 .36152 .48908 .36551 .52616 .36187 .52289 Mtetra
0 .417 .853 r
.36187 .52289 .36551 .52616 .37123 .52886 .36759 .52555 Mtetra
.938 .725 .589 r
.36759 .52555 .37123 .52886 .3787 .49246 .37511 .48902 Mtetra
.943 .715 .563 r
.37511 .48902 .3787 .49246 .3867 .44087 .38318 .4373 Mtetra
.935 .726 .597 r
.38318 .4373 .3867 .44087 .39374 .40903 .39027 .40542 Mtetra
.849 .402 0 r
.39027 .40542 .39374 .40903 .39904 .41965 .39556 .41612 Mtetra
.956 .649 .41 r
.39556 .41612 .39904 .41965 .40294 .46972 .3994 .46634 Mtetra
.956 .654 .422 r
.3994 .46634 .40294 .46972 .40668 .52959 .40308 .52634 Mtetra
.947 .604 .33 r
.40308 .52634 .40668 .52959 .41172 .55782 .40809 .55458 Mtetra
.937 .742 .614 r
.40809 .55458 .41172 .55782 .41861 .53142 .41502 .52805 Mtetra
.95 .713 .544 r
.41502 .52805 .41861 .53142 .42656 .46719 .42305 .46362 Mtetra
.949 .714 .547 r
.42305 .46362 .42656 .46719 .43414 .40868 .4307 .40501 Mtetra
.905 .755 .684 r
.4307 .40501 .43414 .40868 .44036 .39436 .43695 .39072 Mtetra
.957 .636 .371 r
.43695 .39072 .44036 .39436 .44519 .43558 .44174 .43211 Mtetra
.959 .66 .421 r
.44174 .43211 .44519 .43558 .44945 .50997 .44591 .50669 Mtetra
.958 .65 .403 r
.44591 .50669 .44945 .50997 .4543 .56944 .45071 .56627 Mtetra
.408 .683 .974 r
.45071 .56627 .4543 .56944 .46052 .56988 .45693 .56661 Mtetra
.955 .717 .538 r
.45693 .56661 .46052 .56988 .46781 .50853 .4643 .50503 Mtetra
.957 .709 .522 r
.4643 .50503 .46781 .50853 .4752 .42773 .47179 .42402 Mtetra
.952 .72 .551 r
.47179 .42402 .4752 .42773 .48187 .38012 .47851 .37638 Mtetra
.894 .48 .085 r
.47851 .37638 .48187 .38012 .48765 .39503 .48428 .39142 Mtetra
.962 .656 .4 r
.48428 .39142 .48765 .39503 .49297 .46531 .48954 .46192 Mtetra
.962 .66 .408 r
.48954 .46192 .49297 .46531 .49848 .54851 .49496 .54532 Mtetra
.954 .618 .333 r
.49496 .54532 .49848 .54851 .50458 .58707 .50103 .58388 Mtetra
.955 .739 .57 r
.50103 .58388 .50458 .58707 .51116 .55069 .50766 .54729 Mtetra
.962 .711 .508 r
.50766 .54729 .51116 .55069 .51773 .4645 .51433 .46083 Mtetra
.962 .711 .511 r
.51433 .46083 .51773 .4645 .524 .38635 .52068 .38255 Mtetra
.94 .747 .615 r
.52068 .38255 .524 .38635 .53007 .36321 .52679 .35945 Mtetra
.96 .631 .334 r
.52679 .35945 .53007 .36321 .53632 .40753 .533 .40395 Mtetra
.965 .659 .391 r
.533 .40395 .53632 .40753 .54299 .49308 .53959 .48975 Mtetra
.964 .65 .376 r
.53959 .48975 .54299 .49308 .5499 .56447 .54643 .56126 Mtetra
0 .129 .614 r
.54643 .56126 .5499 .56447 .5565 .56984 .55303 .56653 Mtetra
.966 .72 .512 r
.55303 .56653 .5565 .56984 .56233 .5039 .55894 .50033 Mtetra
.967 .71 .492 r
.55894 .50033 .56233 .5039 .5676 .41258 .56431 .40878 Mtetra
.965 .719 .515 r
.56431 .40878 .5676 .41258 .57302 .35308 .56979 .34921 Mtetra
0 .275 .771 r
.56979 .34921 .57302 .35308 .57932 .35739 .57609 .35362 Mtetra
.965 .644 .347 r
.57609 .35362 .57932 .35739 .58677 .4203 .5835 .41673 Mtetra
.966 .652 .365 r
.5835 .41673 .58677 .4203 .59489 .50199 .59155 .49861 Mtetra
.957 .616 .302 r
.59155 .49861 .59489 .50199 .60251 .54665 .59913 .54332 Mtetra
.958 .762 .596 r
.59913 .54332 .60251 .54665 .60857 .52112 .60522 .51763 Mtetra
.971 .715 .488 r
.60522 .51763 .60857 .52112 .61313 .44325 .60987 .43953 Mtetra
.971 .713 .485 r
.60987 .43953 .61313 .44325 .61739 .36471 .61421 .36081 Mtetra
.962 .739 .554 r
.61421 .36081 .61739 .36471 .62274 .33065 .61959 .32673 Mtetra
.927 .548 .16 r
.61959 .32673 .62274 .33065 .62994 .35606 .62678 .35225 Mtetra
.965 .639 .324 r
.62678 .35225 .62994 .35606 .63868 .42197 .63548 .41834 Mtetra
.963 .633 .315 r
.63548 .41834 .63868 .42197 .64759 .48429 .64433 .4808 Mtetra
.825 .38 0 r
.64433 .4808 .64759 .48429 .6549 .49889 .65164 .49537 Mtetra
.973 .737 .52 r
.65164 .49537 .6549 .49889 .65988 .4548 .65667 .45112 Mtetra
.975 .717 .476 r
.65667 .45112 .65988 .4548 .66348 .38246 .66034 .3786 Mtetra
.974 .724 .494 r
.66034 .3786 .66348 .38246 .66756 .32674 .66447 .32276 Mtetra
.894 .787 .736 r
.66447 .32276 .66756 .32674 .67359 .31655 .67052 .31258 Mtetra
.943 .581 .205 r
.67052 .31258 .67359 .31655 .68187 .3522 .67878 .34833 Mtetra
.959 .619 .273 r
.67878 .34833 .68187 .3522 .69133 .40746 .68821 .40373 Mtetra
.94 .575 .199 r
.68821 .40373 .69133 .40746 .70002 .44349 .69688 .43982 Mtetra
.889 .811 .765 r
.69688 .43982 .70002 .44349 .70636 .43429 .70323 .43058 Mtetra
.978 .733 .497 r
.70323 .43058 .70636 .43429 .71044 .38615 .70736 .3823 Mtetra
.978 .725 .481 r
.70736 .3823 .71044 .38615 .71389 .33059 .71086 .32661 Mtetra
.971 .749 .546 r
.71086 .32661 .71389 .33059 .71866 .29959 .71566 .29554 Mtetra
0 .098 .634 r
.71566 .29554 .71866 .29959 .72575 .30651 .72276 .30247 Mtetra
.931 .562 .159 r
.72276 .30247 .72575 .30651 .73476 .34147 .73175 .33752 Mtetra
.932 .565 .165 r
.73175 .33752 .73476 .34147 .74406 .37806 .74103 .37418 Mtetra
.653 .198 0 r
.74103 .37418 .74406 .37806 .75176 .38954 .74874 .38569 Mtetra
.966 .774 .594 r
.74874 .38569 .75176 .38954 .75709 .36735 .75409 .36345 Mtetra
.98 .74 .499 r
.75409 .36345 .75709 .36735 .76093 .32631 .75797 .32231 Mtetra
.978 .747 .52 r
.75797 .32231 .76093 .32631 .76512 .29166 .76219 .28757 Mtetra
.903 .797 .732 r
.76219 .28757 .76512 .29166 .7711 .28124 .76819 .27711 Mtetra
.735 .304 0 r
.76819 .27711 .7711 .28124 .77913 .29619 .77621 .29209 Mtetra
.879 .484 .026 r
.77621 .29209 .77913 .29619 .78817 .32215 .78525 .31809 Mtetra
.767 .339 0 r
.78525 .31809 .78817 .32215 .79655 .33874 .79363 .33473 Mtetra
.806 .8 .846 r
.79363 .33473 .79655 .33874 .80308 .33326 .80017 .32925 Mtetra
.974 .77 .568 r
.80017 .32925 .80308 .33326 .80791 .30894 .80503 .30487 Mtetra
.978 .761 .542 r
.80503 .30487 .80791 .30894 .81234 .28113 .80948 .27699 Mtetra
.95 .79 .649 r
.80948 .27699 .81234 .28113 .81781 .26541 .81497 .26121 Mtetra
.295 .544 .918 r
.81497 .26121 .81781 .26541 .82497 .26753 .82214 .26332 Mtetra
.65 .221 0 r
.82214 .26332 .82497 .26753 .83333 .28128 .8305 .2771 Mtetra
0 0 .398 r
.8305 .2771 .83333 .28128 .84162 .29348 .83879 .28933 Mtetra
.501 .67 .939 r
.83879 .28933 .84162 .29348 .84871 .29341 .8459 .28927 Mtetra
.936 .804 .69 r
.8459 .28927 .84871 .29341 .85446 .28044 .85166 .27627 Mtetra
.649 .74 .916 r
.23829 .47335 .242 .47675 .2475 .47509 .2438 .47168 Mtetra
.869 .75 .729 r
.2438 .47168 .2475 .47509 .25372 .46484 .25004 .46141 Mtetra
.884 .744 .701 r
.25004 .46141 .25372 .46484 .26014 .45205 .25647 .4486 Mtetra
.809 .76 .807 r
.25647 .4486 .26014 .45205 .26595 .44646 .2623 .44301 Mtetra
.783 .3 0 r
.2623 .44301 .26595 .44646 .27075 .45394 .2671 .4505 Mtetra
.936 .573 .296 r
.2671 .4505 .27075 .45394 .27484 .47141 .27117 .46797 Mtetra
.931 .558 .269 r
.27117 .46797 .27484 .47141 .2791 .48755 .27541 .48412 Mtetra
.008 .42 .86 r
.27541 .48412 .2791 .48755 .28442 .49006 .28074 .48663 Mtetra
.897 .743 .682 r
.28074 .48663 .28442 .49006 .29102 .47494 .28736 .47148 Mtetra
.917 .728 .632 r
.28736 .47148 .29102 .47494 .29821 .45086 .29458 .44738 Mtetra
.903 .739 .668 r
.29458 .44738 .29821 .45086 .30484 .43399 .30124 .43049 Mtetra
0 .336 .803 r
.30124 .43049 .30484 .43399 .31013 .43706 .30653 .43356 Mtetra
.945 .605 .345 r
.30653 .43356 .31013 .43706 .31412 .46061 .3105 .45713 Mtetra
.948 .626 .385 r
.3105 .45713 .31412 .46061 .3178 .49092 .31414 .48746 Mtetra
.928 .546 .239 r
.31414 .48746 .3178 .49092 .32245 .50709 .31878 .50363 Mtetra
.883 .758 .719 r
.31878 .50363 .32245 .50709 .32881 .49565 .32516 .49216 Mtetra
.93 .722 .6 r
.32516 .49216 .32881 .49565 .33641 .4622 .33281 .45867 Mtetra
.93 .722 .599 r
.33281 .45867 .33641 .4622 .34392 .42882 .34036 .42526 Mtetra
.872 .758 .734 r
.34036 .42526 .34392 .42882 .35006 .41883 .34652 .41527 Mtetra
.945 .597 .317 r
.34652 .41527 .35006 .41883 .35448 .44164 .35091 .43811 Mtetra
.953 .646 .414 r
.35091 .43811 .35448 .44164 .35792 .48574 .3543 .48224 Mtetra
.952 .635 .392 r
.3543 .48224 .35792 .48574 .36187 .52289 .35822 .51942 Mtetra
.021 .429 .865 r
.35822 .51942 .36187 .52289 .36759 .52555 .36394 .52205 Mtetra
.937 .724 .589 r
.36394 .52205 .36759 .52555 .37511 .48902 .37151 .48547 Mtetra
.942 .714 .564 r
.37151 .48547 .37511 .48902 .38318 .4373 .37965 .43369 Mtetra
.934 .726 .597 r
.37965 .43369 .38318 .4373 .39027 .40542 .38678 .4018 Mtetra
.85 .403 0 r
.38678 .4018 .39027 .40542 .39556 .41612 .39206 .41252 Mtetra
.956 .649 .41 r
.39206 .41252 .39556 .41612 .3994 .46634 .39585 .4628 Mtetra
.956 .655 .421 r
.39585 .4628 .3994 .46634 .40308 .52634 .39946 .52285 Mtetra
.949 .605 .326 r
.39946 .52285 .40308 .52634 .40809 .55458 .40445 .55109 Mtetra
.934 .739 .614 r
.40445 .55109 .40809 .55458 .41502 .52805 .41142 .52448 Mtetra
.95 .712 .544 r
.41142 .52448 .41502 .52805 .42305 .46362 .41953 .45998 Mtetra
.949 .713 .547 r
.41953 .45998 .42305 .46362 .4307 .40501 .42726 .40132 Mtetra
.905 .755 .685 r
.42726 .40132 .4307 .40501 .43695 .39072 .43352 .38706 Mtetra
.958 .637 .371 r
.43352 .38706 .43695 .39072 .44174 .43211 .43827 .4285 Mtetra
.96 .66 .42 r
.43827 .4285 .44174 .43211 .44591 .50669 .44237 .50317 Mtetra
.959 .651 .401 r
.44237 .50317 .44591 .50669 .45071 .56627 .4471 .56277 Mtetra
.436 .675 .964 r
.4471 .56277 .45071 .56627 .45693 .56661 .45333 .56305 Mtetra
.954 .716 .539 r
.45333 .56305 .45693 .56661 .4643 .50503 .46078 .50137 Mtetra
.956 .709 .522 r
.46078 .50137 .4643 .50503 .47179 .42402 .46836 .42029 Mtetra
.952 .72 .551 r
.46836 .42029 .47179 .42402 .47851 .37638 .47514 .37263 Mtetra
.895 .481 .087 r
.47514 .37263 .47851 .37638 .48428 .39142 .4809 .38773 Mtetra
.963 .657 .399 r
.4809 .38773 .48428 .39142 .48954 .46192 .48609 .45831 Mtetra
.963 .66 .407 r
.48609 .45831 .48954 .46192 .49496 .54532 .49143 .54178 Mtetra
.955 .619 .329 r
.49143 .54178 .49496 .54532 .50103 .58388 .49747 .58033 Mtetra
.953 .735 .571 r
.49747 .58033 .50103 .58388 .50766 .54729 .50414 .54364 Mtetra
.962 .71 .509 r
.50414 .54364 .50766 .54729 .51433 .46083 .51091 .45707 Mtetra
.961 .711 .512 r
.51091 .45707 .51433 .46083 .52068 .38255 .51735 .37873 Mtetra
.94 .747 .615 r
.51735 .37873 .52068 .38255 .52679 .35945 .52349 .35566 Mtetra
.96 .631 .334 r
.52349 .35566 .52679 .35945 .533 .40395 .52966 .40024 Mtetra
.965 .659 .391 r
.52966 .40024 .533 .40395 .53959 .48975 .53617 .48612 Mtetra
.964 .651 .375 r
.53617 .48612 .53959 .48975 .54643 .56126 .54295 .55767 Mtetra
0 .165 .664 r
.54295 .55767 .54643 .56126 .55303 .56653 .54955 .56288 Mtetra
.965 .718 .513 r
.54955 .56288 .55303 .56653 .55894 .50033 .55554 .49657 Mtetra
.967 .709 .492 r
.55554 .49657 .55894 .50033 .56431 .40878 .561 .40492 Mtetra
.964 .718 .515 r
.561 .40492 .56431 .40878 .56979 .34921 .56655 .34533 Mtetra
0 .269 .766 r
.56655 .34533 .56979 .34921 .57609 .35362 .57286 .34978 Mtetra
.965 .644 .346 r
.57286 .34978 .57609 .35362 .5835 .41673 .58021 .41297 Mtetra
.967 .653 .364 r
.58021 .41297 .5835 .41673 .59155 .49861 .58819 .49492 Mtetra
.957 .617 .297 r
.58819 .49492 .59155 .49861 .59913 .54332 .59573 .53964 Mtetra
.955 .757 .598 r
.59573 .53964 .59913 .54332 .60522 .51763 .60185 .51387 Mtetra
.971 .714 .489 r
.60185 .51387 .60522 .51763 .60987 .43953 .60658 .43566 Mtetra
.971 .713 .486 r
.60658 .43566 .60987 .43953 .61421 .36081 .61101 .35688 Mtetra
.962 .739 .554 r
.61101 .35688 .61421 .36081 .61959 .32673 .61643 .3228 Mtetra
.927 .548 .16 r
.61643 .3228 .61959 .32673 .62678 .35225 .6236 .34836 Mtetra
.965 .639 .323 r
.6236 .34836 .62678 .35225 .63548 .41834 .63225 .41451 Mtetra
.964 .634 .313 r
.63225 .41451 .63548 .41834 .64433 .4808 .64106 .47701 Mtetra
.815 .372 0 r
.64106 .47701 .64433 .4808 .65164 .49537 .64836 .49157 Mtetra
.971 .735 .522 r
.64836 .49157 .65164 .49537 .65667 .45112 .65343 .44724 Mtetra
.975 .716 .477 r
.65343 .44724 .65667 .45112 .66034 .3786 .65718 .37464 Mtetra
.974 .723 .495 r
.65718 .37464 .66034 .3786 .66447 .32276 .66137 .31876 Mtetra
.893 .786 .736 r
.66137 .31876 .66447 .32276 .67052 .31258 .66744 .30858 Mtetra
.943 .581 .204 r
.66744 .30858 .67052 .31258 .67878 .34833 .67567 .34437 Mtetra
.959 .619 .272 r
.67567 .34437 .67878 .34833 .68821 .40373 .68506 .3998 Mtetra
.94 .575 .195 r
.68506 .3998 .68821 .40373 .69688 .43982 .69371 .43591 Mtetra
.884 .802 .763 r
.69371 .43591 .69688 .43982 .70323 .43058 .70008 .42665 Mtetra
.977 .731 .498 r
.70008 .42665 .70323 .43058 .70736 .3823 .70425 .37831 Mtetra
.978 .725 .482 r
.70425 .37831 .70736 .3823 .71086 .32661 .70781 .32257 Mtetra
.97 .749 .546 r
.70781 .32257 .71086 .32661 .71566 .29554 .71265 .29147 Mtetra
0 .098 .634 r
.71265 .29147 .71566 .29554 .72276 .30247 .71975 .2984 Mtetra
.931 .562 .159 r
.71975 .2984 .72276 .30247 .73175 .33752 .72872 .33347 Mtetra
.932 .564 .163 r
.72872 .33347 .73175 .33752 .74103 .37418 .73798 .37016 Mtetra
.642 .191 0 r
.73798 .37016 .74103 .37418 .74874 .38569 .74568 .38167 Mtetra
.964 .772 .595 r
.74568 .38167 .74874 .38569 .75409 .36345 .75107 .3594 Mtetra
.98 .739 .5 r
.75107 .3594 .75409 .36345 .75797 .32231 .75499 .31822 Mtetra
.978 .746 .52 r
.75499 .31822 .75797 .32231 .76219 .28757 .75924 .28345 Mtetra
.903 .796 .732 r
.75924 .28345 .76219 .28757 .76819 .27711 .76526 .27297 Mtetra
.735 .304 0 r
.76526 .27297 .76819 .27711 .77621 .29209 .77328 .28794 Mtetra
.878 .484 .025 r
.77328 .28794 .77621 .29209 .78525 .31809 .78231 .31396 Mtetra
.764 .337 0 r
.78231 .31396 .78525 .31809 .79363 .33473 .79068 .3306 Mtetra
.804 .795 .843 r
.79068 .3306 .79363 .33473 .80017 .32925 .79724 .32512 Mtetra
.973 .769 .569 r
.79724 .32512 .80017 .32925 .80503 .30487 .80213 .30072 Mtetra
.977 .76 .543 r
.80213 .30072 .80503 .30487 .80948 .27699 .80661 .27281 Mtetra
.949 .79 .649 r
.80661 .27281 .80948 .27699 .81497 .26121 .81212 .257 Mtetra
.295 .545 .918 r
.81212 .257 .81497 .26121 .82214 .26332 .8193 .2591 Mtetra
.65 .221 0 r
.8193 .2591 .82214 .26332 .8305 .2771 .82766 .27287 Mtetra
0 0 .4 r
.82766 .27287 .8305 .2771 .83879 .28933 .83595 .28511 Mtetra
.502 .668 .937 r
.83595 .28511 .83879 .28933 .8459 .28927 .84307 .28505 Mtetra
.935 .802 .69 r
.84307 .28505 .8459 .28927 .85166 .27627 .84885 .27203 Mtetra
.649 .738 .914 r
.23458 .4699 .23829 .47335 .2438 .47168 .24009 .46822 Mtetra
.868 .749 .729 r
.24009 .46822 .2438 .47168 .25004 .46141 .24635 .45795 Mtetra
.884 .743 .701 r
.24635 .45795 .25004 .46141 .25647 .4486 .2528 .44514 Mtetra
.809 .76 .807 r
.2528 .44514 .25647 .4486 .2623 .44301 .25864 .43955 Mtetra
.782 .299 0 r
.25864 .43955 .2623 .44301 .2671 .4505 .26343 .44702 Mtetra
.936 .573 .295 r
.26343 .44702 .2671 .4505 .27117 .46797 .26749 .46447 Mtetra
.931 .558 .267 r
.26749 .46447 .27117 .46797 .27541 .48412 .27172 .4806 Mtetra
.022 .425 .864 r
.27172 .4806 .27541 .48412 .28074 .48663 .27704 .4831 Mtetra
.896 .742 .682 r
.27704 .4831 .28074 .48663 .28736 .47148 .28369 .46796 Mtetra
.916 .727 .632 r
.28369 .46796 .28736 .47148 .29458 .44738 .29094 .44386 Mtetra
.903 .739 .668 r
.29094 .44386 .29458 .44738 .30124 .43049 .29763 .42697 Mtetra
0 .337 .804 r
.29763 .42697 .30124 .43049 .30653 .43356 .30291 .43004 Mtetra
.945 .605 .345 r
.30291 .43004 .30653 .43356 .3105 .45713 .30686 .45358 Mtetra
.949 .626 .384 r
.30686 .45358 .3105 .45713 .31414 .48746 .31048 .48388 Mtetra
.928 .546 .235 r
.31048 .48388 .31414 .48746 .31878 .50363 .3151 .50004 Mtetra
.881 .754 .718 r
.3151 .50004 .31878 .50363 .32516 .49216 .3215 .48857 Mtetra
.929 .721 .601 r
.3215 .48857 .32516 .49216 .33281 .45867 .32919 .45509 Mtetra
.93 .721 .599 r
.32919 .45509 .33281 .45867 .34036 .42526 .33679 .42168 Mtetra
.872 .758 .734 r
.33679 .42168 .34036 .42526 .34652 .41527 .34296 .41169 Mtetra
.945 .596 .317 r
.34296 .41169 .34652 .41527 .35091 .43811 .34734 .43451 Mtetra
.953 .646 .413 r
.34734 .43451 .35091 .43811 .3543 .48224 .35068 .47861 Mtetra
.953 .635 .39 r
.35068 .47861 .3543 .48224 .35822 .51942 .35456 .51575 Mtetra
.05 .437 .873 r
.35456 .51575 .35822 .51942 .36394 .52205 .36029 .51838 Mtetra
.936 .722 .59 r
.36029 .51838 .36394 .52205 .37151 .48547 .36791 .4818 Mtetra
.942 .713 .564 r
.36791 .4818 .37151 .48547 .37965 .43369 .37611 .43005 Mtetra
.934 .726 .597 r
.37611 .43005 .37965 .43369 .38678 .4018 .38328 .39816 Mtetra
.849 .402 0 r
.38328 .39816 .38678 .4018 .39206 .41252 .38855 .40887 Mtetra
.956 .649 .409 r
.38855 .40887 .39206 .41252 .39585 .4628 .39229 .45911 Mtetra
.957 .655 .42 r
.39229 .45911 .39585 .4628 .39946 .52285 .39584 .51912 Mtetra
.95 .606 .322 r
.39584 .51912 .39946 .52285 .40445 .55109 .40081 .54733 Mtetra
.932 .736 .615 r
.40081 .54733 .40445 .55109 .41142 .52448 .40781 .52074 Mtetra
.949 .711 .544 r
.40781 .52074 .41142 .52448 .41953 .45998 .416 .45626 Mtetra
.949 .713 .548 r
.416 .45626 .41953 .45998 .42726 .40132 .42379 .39762 Mtetra
.905 .756 .685 r
.42379 .39762 .42726 .40132 .43352 .38706 .43008 .38336 Mtetra
.958 .637 .371 r
.43008 .38336 .43352 .38706 .43827 .4285 .43479 .42477 Mtetra
.96 .661 .42 r
.43479 .42477 .43827 .4285 .44237 .50317 .43881 .49938 Mtetra
.96 .652 .399 r
.43881 .49938 .44237 .50317 .4471 .56277 .44349 .55894 Mtetra
.453 .664 .952 r
.44349 .55894 .4471 .56277 .45333 .56305 .44973 .55922 Mtetra
.953 .715 .539 r
.44973 .55922 .45333 .56305 .46078 .50137 .45725 .49756 Mtetra
.956 .708 .522 r
.45725 .49756 .46078 .50137 .46836 .42029 .46492 .41651 Mtetra
.952 .72 .552 r
.46492 .41651 .46836 .42029 .47514 .37263 .47176 .36887 Mtetra
.895 .48 .087 r
.47176 .36887 .47514 .37263 .4809 .38773 .47751 .38395 Mtetra
.963 .657 .399 r
.47751 .38395 .4809 .38773 .48609 .45831 .48263 .45449 Mtetra
.963 .661 .406 r
.48263 .45449 .48609 .45831 .49143 .54178 .48789 .5379 Mtetra
.957 .62 .324 r
.48789 .5379 .49143 .54178 .49747 .58033 .49389 .57642 Mtetra
.95 .732 .572 r
.49389 .57642 .49747 .58033 .50414 .54364 .50061 .53974 Mtetra
.961 .709 .51 r
.50061 .53974 .50414 .54364 .51091 .45707 .50748 .45321 Mtetra
.961 .71 .512 r
.50748 .45321 .51091 .45707 .51735 .37873 .51401 .37491 Mtetra
.94 .747 .615 r
.51401 .37491 .51735 .37873 .52349 .35566 .52018 .35183 Mtetra
.96 .631 .334 r
.52018 .35183 .52349 .35566 .52966 .40024 .52631 .39638 Mtetra
.966 .659 .39 r
.52631 .39638 .52966 .40024 .53617 .48612 .53273 .4822 Mtetra
.965 .651 .373 r
.53273 .4822 .53617 .48612 .54295 .55767 .53945 .5537 Mtetra
0 .193 .7 r
.53945 .5537 .54295 .55767 .54955 .56288 .54605 .5589 Mtetra
.964 .717 .514 r
.54605 .5589 .54955 .56288 .55554 .49657 .55211 .49262 Mtetra
.966 .709 .493 r
.55211 .49262 .55554 .49657 .561 .40492 .55768 .40102 Mtetra
.964 .718 .516 r
.55768 .40102 .561 .40492 .56655 .34533 .5633 .34145 Mtetra
0 .27 .767 r
.5633 .34145 .56655 .34533 .57286 .34978 .5696 .34588 Mtetra
.965 .644 .346 r
.5696 .34588 .57286 .34978 .58021 .41297 .5769 .40902 Mtetra
.967 .653 .363 r
.5769 .40902 .58021 .41297 .58819 .49492 .5848 .49092 Mtetra
.958 .617 .293 r
.5848 .49092 .58819 .49492 .59573 .53964 .59231 .5356 Mtetra
.951 .753 .599 r
.59231 .5356 .59573 .53964 .60185 .51387 .59847 .50984 Mtetra
.97 .713 .49 r
.59847 .50984 .60185 .51387 .60658 .43566 .60328 .43166 Mtetra
.97 .712 .486 r
.60328 .43166 .60658 .43566 .61101 .35688 .60779 .35292 Mtetra
.962 .739 .555 r
.60779 .35292 .61101 .35688 .61643 .3228 .61326 .31885 Mtetra
.927 .547 .16 r
.61326 .31885 .61643 .3228 .6236 .34836 .62041 .34438 Mtetra
.965 .639 .322 r
.62041 .34438 .6236 .34836 .63225 .41451 .629 .41048 Mtetra
.964 .634 .311 r
.629 .41048 .63225 .41451 .64106 .47701 .63775 .47294 Mtetra
.804 .364 0 r
.63775 .47294 .64106 .47701 .64836 .49157 .64505 .48747 Mtetra
.97 .733 .523 r
.64505 .48747 .64836 .49157 .65343 .44724 .65017 .44317 Mtetra
.974 .715 .478 r
.65017 .44317 .65343 .44724 .65718 .37464 .654 .3706 Mtetra
.973 .723 .495 r
.654 .3706 .65718 .37464 .66137 .31876 .65825 .31474 Mtetra
.893 .786 .736 r
.65825 .31474 .66137 .31876 .66744 .30858 .66434 .30455 Mtetra
.942 .581 .204 r
.66434 .30455 .66744 .30858 .67567 .34437 .67255 .34031 Mtetra
.959 .619 .271 r
.67255 .34031 .67567 .34437 .68506 .3998 .68189 .3957 Mtetra
.939 .575 .191 r
.68189 .3957 .68506 .3998 .69371 .43591 .69051 .43178 Mtetra
.88 .793 .761 r
.69051 .43178 .69371 .43591 .70008 .42665 .6969 .42251 Mtetra
.976 .73 .5 r
.6969 .42251 .70008 .42665 .70425 .37831 .70113 .37419 Mtetra
.977 .724 .482 r
.70113 .37419 .70425 .37831 .70781 .32257 .70475 .31847 Mtetra
.97 .748 .547 r
.70475 .31847 .70781 .32257 .71265 .29147 .70962 .28738 Mtetra
0 .099 .635 r
.70962 .28738 .71265 .29147 .71975 .2984 .71673 .2943 Mtetra
.93 .562 .158 r
.71673 .2943 .71975 .2984 .72872 .33347 .72567 .32933 Mtetra
.931 .564 .161 r
.72567 .32933 .72872 .33347 .73798 .37016 .73491 .36599 Mtetra
.63 .183 0 r
.73491 .36599 .73798 .37016 .74568 .38167 .74261 .37748 Mtetra
.962 .769 .597 r
.74261 .37748 .74568 .38167 .75107 .3594 .74802 .35521 Mtetra
.979 .738 .501 r
.74802 .35521 .75107 .3594 .75499 .31822 .75199 .31405 Mtetra
.977 .745 .521 r
.75199 .31405 .75499 .31822 .75924 .28345 .75629 .27929 Mtetra
.903 .795 .732 r
.75629 .27929 .75924 .28345 .76526 .27297 .76232 .2688 Mtetra
.734 .303 0 r
.76232 .2688 .76526 .27297 .77328 .28794 .77034 .28375 Mtetra
.877 .483 .024 r
.77034 .28375 .77328 .28794 .78231 .31396 .77935 .30975 Mtetra
.76 .334 0 r
.77935 .30975 .78231 .31396 .79068 .3306 .78772 .32637 Mtetra
.802 .79 .841 r
.78772 .32637 .79068 .3306 .79724 .32512 .79429 .32087 Mtetra
.972 .767 .57 r
.79429 .32087 .79724 .32512 .80213 .30072 .79921 .29648 Mtetra
.977 .76 .544 r
.79921 .29648 .80213 .30072 .80661 .27281 .80373 .26858 Mtetra
.949 .789 .65 r
.80373 .26858 .80661 .27281 .81212 .257 .80926 .25277 Mtetra
.296 .545 .918 r
.80926 .25277 .81212 .257 .8193 .2591 .81645 .25485 Mtetra
.649 .22 0 r
.81645 .25485 .8193 .2591 .82766 .27287 .8248 .26861 Mtetra
0 0 .403 r
.8248 .26861 .82766 .27287 .83595 .28511 .83309 .28082 Mtetra
.504 .666 .935 r
.83309 .28082 .83595 .28511 .84307 .28505 .84022 .28075 Mtetra
.933 .8 .69 r
.84022 .28075 .84307 .28505 .84885 .27203 .84602 .26773 Mtetra
.649 .736 .913 r
.23085 .4664 .23458 .4699 .24009 .46822 .23637 .46471 Mtetra
.867 .748 .729 r
.23637 .46471 .24009 .46822 .24635 .45795 .24264 .45446 Mtetra
.883 .743 .702 r
.24264 .45446 .24635 .45795 .2528 .44514 .24911 .44167 Mtetra
.808 .76 .808 r
.24911 .44167 .2528 .44514 .25864 .43955 .25496 .43607 Mtetra
.78 .296 0 r
.25496 .43607 .25864 .43955 .26343 .44702 .25975 .44351 Mtetra
.936 .573 .294 r
.25975 .44351 .26343 .44702 .26749 .46447 .26379 .46092 Mtetra
.931 .558 .264 r
.26379 .46092 .26749 .46447 .27172 .4806 .26801 .477 Mtetra
.036 .429 .868 r
.26801 .477 .27172 .4806 .27704 .4831 .27334 .47949 Mtetra
.895 .74 .682 r
.27334 .47949 .27704 .4831 .28369 .46796 .28 .46437 Mtetra
.916 .727 .632 r
.28 .46437 .28369 .46796 .29094 .44386 .28729 .44031 Mtetra
.903 .738 .668 r
.28729 .44031 .29094 .44386 .29763 .42697 .294 .42344 Mtetra
0 .341 .807 r
.294 .42344 .29763 .42697 .30291 .43004 .29929 .42648 Mtetra
.945 .605 .344 r
.29929 .42648 .30291 .43004 .30686 .45358 .30322 .44996 Mtetra
.949 .626 .383 r
.30322 .44996 .30686 .45358 .31048 .48388 .3068 .48019 Mtetra
.928 .545 .23 r
.3068 .48019 .31048 .48388 .3151 .50004 .31142 .49631 Mtetra
.878 .751 .718 r
.31142 .49631 .3151 .50004 .3215 .48857 .31783 .48486 Mtetra
.928 .721 .601 r
.31783 .48486 .3215 .48857 .32919 .45509 .32557 .45144 Mtetra
.93 .721 .6 r
.32557 .45144 .32919 .45509 .33679 .42168 .3332 .41809 Mtetra
.872 .757 .734 r
.3332 .41809 .33679 .42168 .34296 .41169 .33939 .40809 Mtetra
.945 .596 .316 r
.33939 .40809 .34296 .41169 .34734 .43451 .34375 .43084 Mtetra
.953 .646 .412 r
.34375 .43084 .34734 .43451 .35068 .47861 .34706 .47483 Mtetra
.953 .636 .388 r
.34706 .47483 .35068 .47861 .35456 .51575 .3509 .5119 Mtetra
.075 .441 .877 r
.3509 .5119 .35456 .51575 .36029 .51838 .35663 .51453 Mtetra
.934 .721 .59 r
.35663 .51453 .36029 .51838 .36791 .4818 .36429 .47803 Mtetra
.941 .713 .564 r
.36429 .47803 .36791 .4818 .37611 .43005 .37255 .42637 Mtetra
.934 .726 .598 r
.37255 .42637 .37611 .43005 .38328 .39816 .37976 .39452 Mtetra
.848 .4 0 r
.37976 .39452 .38328 .39816 .38855 .40887 .38503 .40517 Mtetra
.956 .649 .409 r
.38503 .40517 .38855 .40887 .39229 .45911 .38872 .45528 Mtetra
.957 .656 .419 r
.38872 .45528 .39229 .45911 .39584 .51912 .39222 .51515 Mtetra
.951 .607 .317 r
.39222 .51515 .39584 .51912 .40081 .54733 .39716 .54333 Mtetra
.93 .733 .616 r
.39716 .54333 .40081 .54733 .40781 .52074 .4042 .5168 Mtetra
.948 .71 .545 r
.4042 .5168 .40781 .52074 .416 .45626 .41246 .45246 Mtetra
.948 .713 .548 r
.41246 .45246 .416 .45626 .42379 .39762 .42032 .39392 Mtetra
.905 .756 .685 r
.42032 .39392 .42379 .39762 .43008 .38336 .42663 .37963 Mtetra
.958 .636 .37 r
.42663 .37963 .43008 .38336 .43479 .42477 .4313 .42091 Mtetra
.96 .661 .419 r
.4313 .42091 .43479 .42477 .43881 .49938 .43525 .49535 Mtetra
.961 .652 .397 r
.43525 .49535 .43881 .49938 .44349 .55894 .43987 .5548 Mtetra
.463 .65 .94 r
.43987 .5548 .44349 .55894 .44973 .55922 .44611 .55511 Mtetra
.952 .713 .54 r
.44611 .55511 .44973 .55922 .45725 .49756 .45371 .4936 Mtetra
.956 .708 .523 r
.45371 .4936 .45725 .49756 .46492 .41651 .46147 .41271 Mtetra
.952 .72 .552 r
.46147 .41271 .46492 .41651 .47176 .36887 .46836 .36511 Mtetra
.894 .479 .085 r
.46836 .36511 .47176 .36887 .47751 .38395 .47411 .3801 Mtetra
.963 .657 .398 r
.47411 .3801 .47751 .38395 .48263 .45449 .47916 .45045 Mtetra
.964 .661 .405 r
.47916 .45045 .48263 .45449 .48789 .5379 .48433 .53368 Mtetra
.958 .621 .319 r
.48433 .53368 .48789 .5379 .49389 .57642 .49031 .57216 Mtetra
.948 .729 .574 r
.49031 .57216 .49389 .57642 .50061 .53974 .49707 .5356 Mtetra
.96 .708 .51 r
.49707 .5356 .50061 .53974 .50748 .45321 .50403 .44925 Mtetra
.961 .71 .512 r
.50403 .44925 .50748 .45321 .51401 .37491 .51065 .37107 Mtetra
.94 .747 .615 r
.51065 .37107 .51401 .37491 .52018 .35183 .51685 .34799 Mtetra
.96 .631 .333 r
.51685 .34799 .52018 .35183 .52631 .39638 .52294 .39238 Mtetra
.966 .659 .389 r
.52294 .39238 .52631 .39638 .53273 .4822 .52928 .478 Mtetra
.965 .652 .371 r
.52928 .478 .53273 .4822 .53945 .5537 .53593 .54936 Mtetra
0 .212 .725 r
.53593 .54936 .53945 .5537 .54605 .5589 .54254 .5546 Mtetra
.963 .715 .516 r
.54254 .5546 .54605 .5589 .55211 .49262 .54867 .48848 Mtetra
.966 .708 .494 r
.54867 .48848 .55211 .49262 .55768 .40102 .55434 .39705 Mtetra
.964 .718 .516 r
.55434 .39705 .55768 .40102 .5633 .34145 .56003 .33756 Mtetra
0 .277 .772 r
.56003 .33756 .5633 .34145 .5696 .34588 .56634 .34193 Mtetra
.965 .644 .345 r
.56634 .34193 .5696 .34588 .5769 .40902 .57357 .40489 Mtetra
.967 .653 .361 r
.57357 .40489 .5769 .40902 .5848 .49092 .5814 .48661 Mtetra
.958 .618 .288 r
.5814 .48661 .5848 .49092 .59231 .5356 .58887 .53122 Mtetra
.948 .748 .601 r
.58887 .53122 .59231 .5356 .59847 .50984 .59506 .50554 Mtetra
.969 .712 .491 r
.59506 .50554 .59847 .50984 .60328 .43166 .59997 .42753 Mtetra
.97 .712 .487 r
.59997 .42753 .60328 .43166 .60779 .35292 .60456 .34893 Mtetra
.962 .739 .555 r
.60456 .34893 .60779 .35292 .61326 .31885 .61007 .31488 Mtetra
.927 .547 .159 r
.61007 .31488 .61326 .31885 .62041 .34438 .61721 .34032 Mtetra
.965 .639 .321 r
.61721 .34032 .62041 .34438 .629 .41048 .62573 .40626 Mtetra
.964 .634 .309 r
.62573 .40626 .629 .41048 .63775 .47294 .63443 .46858 Mtetra
.792 .355 0 r
.63443 .46858 .63775 .47294 .64505 .48747 .64172 .4831 Mtetra
.968 .731 .525 r
.64172 .4831 .64505 .48747 .65017 .44317 .6469 .43889 Mtetra
.974 .715 .479 r
.6469 .43889 .65017 .44317 .654 .3706 .6508 .36646 Mtetra
.973 .722 .496 r
.6508 .36646 .654 .3706 .65825 .31474 .65513 .3107 Mtetra
.893 .786 .736 r
.65513 .3107 .65825 .31474 .66434 .30455 .66123 .3005 Mtetra
.942 .581 .203 r
.66123 .3005 .66434 .30455 .67255 .34031 .66941 .33616 Mtetra
.959 .619 .269 r
.66941 .33616 .67255 .34031 .68189 .3957 .6787 .39142 Mtetra
.938 .574 .186 r
.6787 .39142 .68189 .3957 .69051 .43178 .68729 .42741 Mtetra
.875 .785 .759 r
.68729 .42741 .69051 .43178 .6969 .42251 .6937 .41816 Mtetra
.975 .729 .501 r
.6937 .41816 .6969 .42251 .70113 .37419 .69799 .36993 Mtetra
.977 .723 .483 r
.69799 .36993 .70113 .37419 .70475 .31847 .70167 .31432 Mtetra
.97 .748 .547 r
.70167 .31432 .70475 .31847 .70962 .28738 .70658 .28327 Mtetra
0 .102 .637 r
.70658 .28327 .70962 .28738 .71673 .2943 .71369 .29016 Mtetra
.93 .561 .157 r
.71369 .29016 .71673 .2943 .72567 .32933 .72261 .32511 Mtetra
.931 .563 .158 r
.72261 .32511 .72567 .32933 .73491 .36599 .73181 .36167 Mtetra
.616 .174 0 r
.73181 .36167 .73491 .36599 .74261 .37748 .73951 .37312 Mtetra
.96 .767 .598 r
.73951 .37312 .74261 .37748 .74802 .35521 .74495 .35088 Mtetra
.978 .737 .503 r
.74495 .35088 .74802 .35521 .75199 .31405 .74898 .30979 Mtetra
.977 .745 .522 r
.74898 .30979 .75199 .31405 .75629 .27929 .75331 .27509 Mtetra
.902 .795 .732 r
.75331 .27509 .75629 .27929 .76232 .2688 .75936 .26462 Mtetra
.733 .301 0 r
.75936 .26462 .76232 .2688 .77034 .28375 .76738 .27953 Mtetra
.877 .482 .022 r
.76738 .27953 .77034 .28375 .77935 .30975 .77637 .30545 Mtetra
.755 .33 0 r
.77637 .30545 .77935 .30975 .78772 .32637 .78473 .32202 Mtetra
.8 .785 .838 r
.78473 .32202 .78772 .32637 .79429 .32087 .79132 .31651 Mtetra
.971 .766 .571 r
.79132 .31651 .79429 .32087 .79921 .29648 .79627 .29215 Mtetra
.976 .759 .545 r
.79627 .29215 .79921 .29648 .80373 .26858 .80082 .2643 Mtetra
.948 .788 .65 r
.80082 .2643 .80373 .26858 .80926 .25277 .80639 .24852 Mtetra
.297 .545 .918 r
.80639 .24852 .80926 .25277 .81645 .25485 .81358 .25059 Mtetra
.647 .218 0 r
.81358 .25059 .81645 .25485 .8248 .26861 .82193 .2643 Mtetra
0 0 .407 r
.82193 .2643 .8248 .26861 .83309 .28082 .83022 .27647 Mtetra
.507 .664 .933 r
.83022 .27647 .83309 .28082 .84022 .28075 .83735 .27637 Mtetra
.932 .798 .69 r
.83735 .27637 .84022 .28075 .84602 .26773 .84318 .26336 Mtetra
.649 .734 .911 r
.22711 .46285 .23085 .4664 .23637 .46471 .23263 .46116 Mtetra
.866 .747 .73 r
.23263 .46116 .23637 .46471 .24264 .45446 .23892 .45093 Mtetra
.883 .742 .702 r
.23892 .45093 .24264 .45446 .24911 .44167 .24541 .43817 Mtetra
.808 .759 .808 r
.24541 .43817 .24911 .44167 .25496 .43607 .25127 .43257 Mtetra
.777 .293 0 r
.25127 .43257 .25496 .43607 .25975 .44351 .25606 .43997 Mtetra
.936 .572 .292 r
.25606 .43997 .25975 .44351 .26379 .46092 .26009 .4573 Mtetra
.931 .557 .261 r
.26009 .4573 .26379 .46092 .26801 .477 .2643 .47332 Mtetra
.05 .433 .871 r
.2643 .47332 .26801 .477 .27334 .47949 .26963 .47579 Mtetra
.893 .739 .683 r
.26963 .47579 .27334 .47949 .28 .46437 .27631 .46071 Mtetra
.915 .726 .633 r
.27631 .46071 .28 .46437 .28729 .44031 .28362 .43673 Mtetra
.902 .738 .668 r
.28362 .43673 .28729 .44031 .294 .42344 .29035 .4199 Mtetra
0 .347 .811 r
.29035 .4199 .294 .42344 .29929 .42648 .29565 .4229 Mtetra
.945 .605 .343 r
.29565 .4229 .29929 .42648 .30322 .44996 .29956 .44627 Mtetra
.949 .626 .382 r
.29956 .44627 .30322 .44996 .3068 .48019 .30312 .47638 Mtetra
.928 .545 .225 r
.30312 .47638 .3068 .48019 .31142 .49631 .30773 .49244 Mtetra
.876 .748 .718 r
.30773 .49244 .31142 .49631 .31783 .48486 .31416 .48104 Mtetra
.928 .72 .602 r
.31416 .48104 .31783 .48486 .32557 .45144 .32193 .44774 Mtetra
.929 .721 .6 r
.32193 .44774 .32557 .45144 .3332 .41809 .3296 .41448 Mtetra
.871 .757 .734 r
.3296 .41448 .3332 .41809 .33939 .40809 .33581 .40447 Mtetra
.945 .595 .315 r
.33581 .40447 .33939 .40809 .34375 .43084 .34015 .4271 Mtetra
.954 .646 .411 r
.34015 .4271 .34375 .43084 .34706 .47483 .34342 .47091 Mtetra
.954 .636 .387 r
.34342 .47091 .34706 .47483 .3509 .5119 .34723 .50785 Mtetra
.095 .442 .879 r
.34723 .50785 .3509 .5119 .35663 .51453 .35296 .5105 Mtetra
.933 .72 .591 r
.35296 .5105 .35663 .51453 .36429 .47803 .36066 .47415 Mtetra
.941 .712 .565 r
.36066 .47415 .36429 .47803 .37255 .42637 .36898 .42266 Mtetra
.934 .726 .598 r
.36898 .42266 .37255 .42637 .37976 .39452 .37623 .39087 Mtetra
.845 .396 0 r
.37623 .39087 .37976 .39452 .38503 .40517 .3815 .40141 Mtetra
.957 .649 .408 r
.3815 .40141 .38503 .40517 .38872 .45528 .38514 .45129 Mtetra
.958 .656 .418 r
.38514 .45129 .38872 .45528 .39222 .51515 .38859 .51095 Mtetra
.952 .608 .313 r
.38859 .51095 .39222 .51515 .39716 .54333 .3935 .53907 Mtetra
.927 .73 .617 r
.3935 .53907 .39716 .54333 .4042 .5168 .40057 .51269 Mtetra
.947 .71 .546 r
.40057 .51269 .4042 .5168 .41246 .45246 .4089 .44859 Mtetra
.948 .712 .548 r
.4089 .44859 .41246 .45246 .42032 .39392 .41683 .3902 Mtetra
.906 .756 .685 r
.41683 .3902 .42032 .39392 .42663 .37963 .42316 .37588 Mtetra
.958 .636 .369 r
.42316 .37588 .42663 .37963 .4313 .42091 .4278 .41693 Mtetra
.961 .661 .418 r
.4278 .41693 .4313 .42091 .43525 .49535 .43168 .49107 Mtetra
.961 .653 .396 r
.43168 .49107 .43525 .49535 .43987 .5548 .43625 .55034 Mtetra
.465 .634 .927 r
.43625 .55034 .43987 .5548 .44611 .55511 .44249 .55073 Mtetra
.951 .712 .541 r
.44249 .55073 .44611 .55511 .45371 .4936 .45015 .4895 Mtetra
.955 .708 .523 r
.45015 .4895 .45371 .4936 .46147 .41271 .458 .40887 Mtetra
.951 .72 .552 r
.458 .40887 .46147 .41271 .46836 .36511 .46495 .36135 Mtetra
.892 .475 .08 r
.46495 .36135 .46836 .36511 .47411 .3801 .47069 .37617 Mtetra
.963 .657 .398 r
.47069 .37617 .47411 .3801 .47916 .45045 .47567 .4462 Mtetra
.964 .662 .404 r
.47567 .4462 .47916 .45045 .48433 .53368 .48077 .52913 Mtetra
.958 .622 .314 r
.48077 .52913 .48433 .53368 .49031 .57216 .48671 .56755 Mtetra
.945 .726 .575 r
.48671 .56755 .49031 .57216 .49707 .5356 .49351 .53121 Mtetra
.96 .708 .511 r
.49351 .53121 .49707 .5356 .50403 .44925 .50057 .4452 Mtetra
.961 .71 .513 r
.50057 .4452 .50403 .44925 .51065 .37107 .50728 .36723 Mtetra
.94 .747 .615 r
.50728 .36723 .51065 .37107 .51685 .34799 .51351 .34411 Mtetra
.96 .63 .332 r
.51351 .34411 .51685 .34799 .52294 .39238 .51956 .38824 Mtetra
.966 .66 .388 r
.51956 .38824 .52294 .39238 .52928 .478 .52582 .47351 Mtetra
.966 .652 .368 r
.52582 .47351 .52928 .478 .53593 .54936 .5324 .54466 Mtetra
0 .224 .74 r
.5324 .54466 .53593 .54936 .54254 .5546 .53901 .54997 Mtetra
.961 .714 .517 r
.53901 .54997 .54254 .5546 .54867 .48848 .54522 .48415 Mtetra
.965 .708 .494 r
.54522 .48415 .54867 .48848 .55434 .39705 .55099 .39304 Mtetra
.964 .718 .516 r
.55099 .39304 .55434 .39705 .56003 .33756 .55675 .33366 Mtetra
0 .29 .781 r
.55675 .33366 .56003 .33756 .56634 .34193 .56306 .33791 Mtetra
.965 .644 .344 r
.56306 .33791 .56634 .34193 .57357 .40489 .57023 .40058 Mtetra
.968 .653 .36 r
.57023 .40058 .57357 .40489 .5814 .48661 .57798 .48199 Mtetra
.958 .618 .284 r
.57798 .48199 .5814 .48661 .58887 .53122 .58541 .52649 Mtetra
.944 .744 .603 r
.58541 .52649 .58887 .53122 .59506 .50554 .59164 .50097 Mtetra
.968 .712 .492 r
.59164 .50097 .59506 .50554 .59997 .42753 .59663 .42327 Mtetra
.97 .712 .487 r
.59663 .42327 .59997 .42753 .60456 .34893 .60132 .34491 Mtetra
.961 .739 .555 r
.60132 .34491 .60456 .34893 .61007 .31488 .60687 .3109 Mtetra
.926 .545 .157 r
.60687 .3109 .61007 .31488 .61721 .34032 .61398 .33617 Mtetra
.965 .639 .32 r
.61398 .33617 .61721 .34032 .62573 .40626 .62244 .40184 Mtetra
.964 .634 .307 r
.62244 .40184 .62573 .40626 .63443 .46858 .63108 .46394 Mtetra
.778 .346 0 r
.63108 .46394 .63443 .46858 .64172 .4831 .63837 .47844 Mtetra
.966 .729 .527 r
.63837 .47844 .64172 .4831 .6469 .43889 .6436 .43442 Mtetra
.973 .714 .48 r
.6436 .43442 .6469 .43889 .6508 .36646 .64759 .36224 Mtetra
.973 .722 .496 r
.64759 .36224 .6508 .36646 .65513 .3107 .65198 .30664 Mtetra
.893 .786 .736 r
.65198 .30664 .65513 .3107 .66123 .3005 .6581 .29642 Mtetra
.942 .58 .202 r
.6581 .29642 .66123 .3005 .66941 .33616 .66625 .33192 Mtetra
.959 .619 .268 r
.66625 .33192 .66941 .33616 .6787 .39142 .67549 .38696 Mtetra
.937 .573 .182 r
.67549 .38696 .6787 .39142 .68729 .42741 .68405 .42282 Mtetra
.869 .777 .757 r
.68405 .42282 .68729 .42741 .6937 .41816 .69048 .4136 Mtetra
.974 .728 .503 r
.69048 .4136 .6937 .41816 .69799 .36993 .69482 .36554 Mtetra
.976 .723 .484 r
.69482 .36554 .69799 .36993 .70167 .31432 .69858 .31011 Mtetra
.969 .748 .548 r
.69858 .31011 .70167 .31432 .70658 .28327 .70353 .27915 Mtetra
0 .106 .641 r
.70353 .27915 .70658 .28327 .71369 .29016 .71064 .28599 Mtetra
.93 .56 .155 r
.71064 .28599 .71369 .29016 .72261 .32511 .71953 .32079 Mtetra
.93 .562 .155 r
.71953 .32079 .72261 .32511 .73181 .36167 .7287 .3572 Mtetra
.601 .164 0 r
.7287 .3572 .73181 .36167 .73951 .37312 .73639 .3686 Mtetra
.958 .764 .599 r
.73639 .3686 .73951 .37312 .74495 .35088 .74187 .34642 Mtetra
.977 .736 .504 r
.74187 .34642 .74495 .35088 .74898 .30979 .74594 .30545 Mtetra
.976 .744 .523 r
.74594 .30545 .74898 .30979 .75331 .27509 .75033 .27086 Mtetra
.901 .794 .733 r
.75033 .27086 .75331 .27509 .75936 .26462 .7564 .26042 Mtetra
.731 .299 0 r
.7564 .26042 .75936 .26462 .76738 .27953 .76441 .27527 Mtetra
.875 .481 .019 r
.76441 .27527 .76738 .27953 .77637 .30545 .77338 .30108 Mtetra
.75 .326 0 r
.77338 .30108 .77637 .30545 .78473 .32202 .78173 .31756 Mtetra
.798 .78 .836 r
.78173 .31756 .78473 .32202 .79132 .31651 .78833 .31204 Mtetra
.969 .765 .572 r
.78833 .31204 .79132 .31651 .79627 .29215 .79332 .28774 Mtetra
.975 .758 .546 r
.79332 .28774 .79627 .29215 .80082 .2643 .79791 .25997 Mtetra
.947 .788 .651 r
.79791 .25997 .80082 .2643 .80639 .24852 .8035 .24424 Mtetra
.298 .546 .918 r
.8035 .24424 .80639 .24852 .81358 .25059 .8107 .2463 Mtetra
.645 .216 0 r
.8107 .2463 .81358 .25059 .82193 .2643 .81904 .25995 Mtetra
0 0 .412 r
.81904 .25995 .82193 .2643 .83022 .27647 .82732 .27205 Mtetra
.51 .663 .931 r
.82732 .27205 .83022 .27647 .83735 .27637 .83446 .27192 Mtetra
.93 .797 .691 r
.83446 .27192 .83735 .27637 .84318 .26336 .84032 .25893 Mtetra
.649 .732 .91 r
.22335 .45926 .22711 .46285 .23263 .46116 .22889 .45757 Mtetra
.865 .747 .73 r
.22889 .45757 .23263 .46116 .23892 .45093 .23519 .44738 Mtetra
.882 .742 .702 r
.23519 .44738 .23892 .45093 .24541 .43817 .24169 .43466 Mtetra
.808 .759 .808 r
.24169 .43466 .24541 .43817 .25127 .43257 .24756 .42906 Mtetra
.773 .288 0 r
.24756 .42906 .25127 .43257 .25606 .43997 .25235 .4364 Mtetra
.936 .571 .29 r
.25235 .4364 .25606 .43997 .26009 .4573 .25637 .45362 Mtetra
.931 .556 .258 r
.25637 .45362 .26009 .4573 .2643 .47332 .26057 .46954 Mtetra
.064 .437 .875 r
.26057 .46954 .2643 .47332 .26963 .47579 .26591 .472 Mtetra
.892 .738 .683 r
.26591 .472 .26963 .47579 .27631 .46071 .27261 .457 Mtetra
.914 .726 .633 r
.27261 .457 .27631 .46071 .28362 .43673 .27994 .43311 Mtetra
.902 .738 .669 r
.27994 .43311 .28362 .43673 .29035 .4199 .2867 .41634 Mtetra
0 .355 .817 r
.2867 .41634 .29035 .4199 .29565 .4229 .29199 .41929 Mtetra
.945 .604 .341 r
.29199 .41929 .29565 .4229 .29956 .44627 .2959 .44251 Mtetra
.95 .626 .38 r
.2959 .44251 .29956 .44627 .30312 .47638 .29944 .47245 Mtetra
.928 .544 .219 r
.29944 .47245 .30312 .47638 .30773 .49244 .30403 .48844 Mtetra
.873 .745 .718 r
.30403 .48844 .30773 .49244 .31416 .48104 .31047 .47711 Mtetra
.927 .719 .602 r
.31047 .47711 .31416 .48104 .32193 .44774 .31828 .44397 Mtetra
.929 .72 .601 r
.31828 .44397 .32193 .44774 .3296 .41448 .32598 .41085 Mtetra
.871 .757 .734 r
.32598 .41085 .3296 .41448 .33581 .40447 .33221 .40083 Mtetra
.945 .594 .313 r
.33221 .40083 .33581 .40447 .34015 .4271 .33654 .42329 Mtetra
.954 .646 .41 r
.33654 .42329 .34015 .4271 .34342 .47091 .33978 .46686 Mtetra
.955 .636 .385 r
.33978 .46686 .34342 .47091 .34723 .50785 .34356 .50362 Mtetra
.111 .442 .878 r
.34356 .50362 .34723 .50785 .35296 .5105 .34929 .5063 Mtetra
.932 .718 .592 r
.34929 .5063 .35296 .5105 .36066 .47415 .35702 .47017 Mtetra
.94 .712 .565 r
.35702 .47017 .36066 .47415 .36898 .42266 .3654 .41891 Mtetra
.933 .725 .598 r
.3654 .41891 .36898 .42266 .37623 .39087 .37268 .3872 Mtetra
.841 .389 0 r
.37268 .3872 .37623 .39087 .3815 .40141 .37795 .3976 Mtetra
.957 .649 .407 r
.37795 .3976 .3815 .40141 .38514 .45129 .38156 .44716 Mtetra
.958 .656 .417 r
.38156 .44716 .38514 .45129 .38859 .51095 .38495 .50652 Mtetra
.953 .608 .308 r
.38495 .50652 .38859 .51095 .3935 .53907 .38984 .53455 Mtetra
.924 .727 .618 r
.38984 .53455 .3935 .53907 .40057 .51269 .39694 .5084 Mtetra
.947 .709 .546 r
.39694 .5084 .40057 .51269 .4089 .44859 .40533 .44464 Mtetra
.948 .712 .549 r
.40533 .44464 .4089 .44859 .41683 .3902 .41332 .38647 Mtetra
.906 .756 .684 r
.41332 .38647 .41683 .3902 .42316 .37588 .41968 .37209 Mtetra
.958 .636 .368 r
.41968 .37209 .42316 .37588 .4278 .41693 .42429 .41282 Mtetra
.961 .661 .417 r
.42429 .41282 .4278 .41693 .43168 .49107 .4281 .48653 Mtetra
.962 .654 .394 r
.4281 .48653 .43168 .49107 .43625 .55034 .43261 .54556 Mtetra
.463 .616 .915 r
.43261 .54556 .43625 .55034 .44249 .55073 .43886 .54607 Mtetra
.95 .711 .542 r
.43886 .54607 .44249 .55073 .45015 .4895 .44658 .48525 Mtetra
.955 .707 .524 r
.44658 .48525 .45015 .4895 .458 .40887 .45452 .40499 Mtetra
.951 .72 .552 r
.45452 .40499 .458 .40887 .46495 .36135 .46153 .35757 Mtetra
.889 .47 .073 r
.46153 .35757 .46495 .36135 .47069 .37617 .46726 .37216 Mtetra
.963 .657 .397 r
.46726 .37216 .47069 .37617 .47567 .4462 .47218 .44173 Mtetra
.965 .662 .402 r
.47218 .44173 .47567 .4462 .48077 .52913 .4772 .52424 Mtetra
.959 .623 .309 r
.4772 .52424 .48077 .52913 .48671 .56755 .4831 .56258 Mtetra
.943 .724 .577 r
.4831 .56258 .48671 .56755 .49351 .53121 .48995 .52658 Mtetra
.959 .707 .512 r
.48995 .52658 .49351 .53121 .50057 .4452 .4971 .44105 Mtetra
.96 .71 .513 r
.4971 .44105 .50057 .4452 .50728 .36723 .5039 .36338 Mtetra
.94 .747 .615 r
.5039 .36338 .50728 .36723 .51351 .34411 .51016 .3402 Mtetra
.96 .63 .331 r
.51016 .3402 .51351 .34411 .51956 .38824 .51617 .38397 Mtetra
.967 .66 .387 r
.51617 .38397 .51956 .38824 .52582 .47351 .52235 .46874 Mtetra
.967 .653 .366 r
.52235 .46874 .52582 .47351 .5324 .54466 .52886 .53958 Mtetra
0 .229 .747 r
.52886 .53958 .5324 .54466 .53901 .54997 .53546 .54501 Mtetra
.96 .713 .518 r
.53546 .54501 .53901 .54997 .54522 .48415 .54175 .47964 Mtetra
.965 .707 .495 r
.54175 .47964 .54522 .48415 .55099 .39304 .54763 .38896 Mtetra
.964 .718 .517 r
.54763 .38896 .55099 .39304 .55675 .33366 .55345 .32976 Mtetra
0 .31 .795 r
.55345 .32976 .55675 .33366 .56306 .33791 .55977 .33384 Mtetra
.965 .643 .343 r
.55977 .33384 .56306 .33791 .57023 .40058 .56688 .39609 Mtetra
.968 .654 .359 r
.56688 .39609 .57023 .40058 .57798 .48199 .57454 .47707 Mtetra
.959 .618 .279 r
.57454 .47707 .57798 .48199 .58541 .52649 .58193 .52142 Mtetra
.94 .74 .605 r
.58193 .52142 .58541 .52649 .59164 .50097 .58819 .49614 Mtetra
.967 .711 .493 r
.58819 .49614 .59164 .50097 .59663 .42327 .59328 .41888 Mtetra
.969 .711 .488 r
.59328 .41888 .59663 .42327 .60132 .34491 .59806 .34085 Mtetra
.961 .739 .556 r
.59806 .34085 .60132 .34491 .60687 .3109 .60366 .3069 Mtetra
.925 .544 .154 r
.60366 .3069 .60687 .3109 .61398 .33617 .61075 .33195 Mtetra
.965 .639 .319 r
.61075 .33195 .61398 .33617 .62244 .40184 .61914 .39723 Mtetra
.964 .634 .304 r
.61914 .39723 .62244 .40184 .63108 .46394 .62772 .45902 Mtetra
.764 .337 0 r
.62772 .45902 .63108 .46394 .63837 .47844 .63499 .4735 Mtetra
.965 .727 .529 r
.63499 .4735 .63837 .47844 .6436 .43442 .64028 .42975 Mtetra
.972 .714 .481 r
.64028 .42975 .6436 .43442 .64759 .36224 .64437 .35794 Mtetra
.972 .722 .497 r
.64437 .35794 .64759 .36224 .65198 .30664 .64883 .30255 Mtetra
.893 .786 .736 r
.64883 .30255 .65198 .30664 .6581 .29642 .65496 .29232 Mtetra
.941 .579 .2 r
.65496 .29232 .6581 .29642 .66625 .33192 .66308 .32758 Mtetra
.958 .619 .266 r
.66308 .32758 .66625 .33192 .67549 .38696 .67226 .38232 Mtetra
.936 .572 .176 r
.67226 .38232 .67549 .38696 .68405 .42282 .68078 .418 Mtetra
.864 .769 .756 r
.68078 .418 .68405 .42282 .69048 .4136 .68723 .40884 Mtetra
.973 .727 .504 r
.68723 .40884 .69048 .4136 .69482 .36554 .69164 .36102 Mtetra
.976 .722 .485 r
.69164 .36102 .69482 .36554 .69858 .31011 .69547 .30584 Mtetra
.969 .748 .549 r
.69547 .30584 .69858 .31011 .70353 .27915 .70047 .275 Mtetra
0 .111 .646 r
.70047 .275 .70353 .27915 .71064 .28599 .70757 .28178 Mtetra
.929 .559 .153 r
.70757 .28178 .71064 .28599 .71953 .32079 .71643 .31639 Mtetra
.929 .561 .152 r
.71643 .31639 .71953 .32079 .7287 .3572 .72556 .35259 Mtetra
.585 .153 0 r
.72556 .35259 .7287 .3572 .73639 .3686 .73325 .3639 Mtetra
.956 .762 .601 r
.73325 .3639 .73639 .3686 .74187 .34642 .73876 .34181 Mtetra
.977 .735 .506 r
.73876 .34181 .74187 .34642 .74594 .30545 .74289 .30103 Mtetra
.975 .744 .524 r
.74289 .30103 .74594 .30545 .75033 .27086 .74733 .2666 Mtetra
.9 .794 .734 r
.74733 .2666 .75033 .27086 .7564 .26042 .75342 .2562 Mtetra
.728 .297 0 r
.75342 .2562 .7564 .26042 .76441 .27527 .76142 .27097 Mtetra
.874 .479 .016 r
.76142 .27097 .76441 .27527 .77338 .30108 .77037 .29663 Mtetra
.744 .321 0 r
.77037 .29663 .77338 .30108 .78173 .31756 .7787 .31299 Mtetra
.796 .775 .834 r
.7787 .31299 .78173 .31756 .78833 .31204 .78532 .30746 Mtetra
.968 .763 .574 r
.78532 .30746 .78833 .31204 .79332 .28774 .79034 .28325 Mtetra
.975 .758 .548 r
.79034 .28325 .79332 .28774 .79791 .25997 .79498 .2556 Mtetra
.946 .787 .653 r
.79498 .2556 .79791 .25997 .8035 .24424 .8006 .23995 Mtetra
.299 .546 .918 r
.8006 .23995 .8035 .24424 .8107 .2463 .8078 .24199 Mtetra
.642 .213 0 r
.8078 .24199 .8107 .2463 .81904 .25995 .81614 .25556 Mtetra
0 0 .418 r
.81614 .25556 .81904 .25995 .82732 .27205 .82441 .26757 Mtetra
.514 .663 .929 r
.82441 .26757 .82732 .27205 .83446 .27192 .83156 .2674 Mtetra
.929 .795 .692 r
.83156 .2674 .83446 .27192 .84032 .25893 .83744 .25444 Mtetra
.649 .73 .909 r
.21959 .45561 .22335 .45926 .22889 .45757 .22513 .45392 Mtetra
.864 .746 .731 r
.22513 .45392 .22889 .45757 .23519 .44738 .23144 .44378 Mtetra
.882 .742 .703 r
.23144 .44378 .23519 .44738 .24169 .43466 .23796 .43113 Mtetra
.807 .759 .808 r
.23796 .43113 .24169 .43466 .24756 .42906 .24384 .42554 Mtetra
.768 .281 0 r
.24384 .42554 .24756 .42906 .25235 .4364 .24863 .4328 Mtetra
.935 .57 .287 r
.24863 .4328 .25235 .4364 .25637 .45362 .25265 .44988 Mtetra
.931 .555 .254 r
.25265 .44988 .25637 .45362 .26057 .46954 .25684 .46569 Mtetra
.078 .441 .878 r
.25684 .46569 .26057 .46954 .26591 .472 .26218 .46812 Mtetra
.891 .736 .684 r
.26218 .46812 .26591 .472 .27261 .457 .26889 .45322 Mtetra
.914 .725 .634 r
.26889 .45322 .27261 .457 .27994 .43311 .27625 .42947 Mtetra
.901 .738 .67 r
.27625 .42947 .27994 .43311 .2867 .41634 .28302 .41277 Mtetra
0 .365 .824 r
.28302 .41277 .2867 .41634 .29199 .41929 .28833 .41565 Mtetra
.945 .603 .339 r
.28833 .41565 .29199 .41929 .2959 .44251 .29222 .43868 Mtetra
.95 .626 .378 r
.29222 .43868 .2959 .44251 .29944 .47245 .29574 .46841 Mtetra
.928 .543 .213 r
.29574 .46841 .29944 .47245 .30403 .48844 .30033 .4843 Mtetra
.87 .742 .718 r
.30033 .4843 .30403 .48844 .31047 .47711 .30678 .47307 Mtetra
.926 .718 .603 r
.30678 .47307 .31047 .47711 .31828 .44397 .31461 .44015 Mtetra
.928 .72 .601 r
.31461 .44015 .31828 .44397 .32598 .41085 .32235 .4072 Mtetra
.871 .757 .734 r
.32235 .4072 .32598 .41085 .33221 .40083 .3286 .39718 Mtetra
.945 .593 .31 r
.3286 .39718 .33221 .40083 .33654 .42329 .33292 .41942 Mtetra
.954 .646 .409 r
.33292 .41942 .33654 .42329 .33978 .46686 .33613 .46266 Mtetra
.955 .637 .382 r
.33613 .46266 .33978 .46686 .34356 .50362 .33988 .49919 Mtetra
.124 .439 .876 r
.33988 .49919 .34356 .50362 .34929 .5063 .34561 .50191 Mtetra
.93 .717 .593 r
.34561 .50191 .34929 .5063 .35702 .47017 .35338 .46607 Mtetra
.94 .712 .566 r
.35338 .46607 .35702 .47017 .3654 .41891 .3618 .41513 Mtetra
.933 .725 .599 r
.3618 .41513 .3654 .41891 .37268 .3872 .36912 .38353 Mtetra
.835 .381 0 r
.36912 .38353 .37268 .3872 .37795 .3976 .37439 .39373 Mtetra
.957 .649 .406 r
.37439 .39373 .37795 .3976 .38156 .44716 .37797 .44289 Mtetra
.959 .657 .416 r
.37797 .44289 .38156 .44716 .38495 .50652 .38131 .50185 Mtetra
.953 .609 .303 r
.38131 .50185 .38495 .50652 .38984 .53455 .38618 .52978 Mtetra
.922 .725 .619 r
.38618 .52978 .38984 .53455 .39694 .5084 .3933 .50392 Mtetra
.946 .708 .547 r
.3933 .50392 .39694 .5084 .40533 .44464 .40175 .44061 Mtetra
.947 .712 .549 r
.40175 .44061 .40533 .44464 .41332 .38647 .4098 .38273 Mtetra
.906 .756 .684 r
.4098 .38273 .41332 .38647 .41968 .37209 .41618 .36828 Mtetra
.958 .635 .367 r
.41618 .36828 .41968 .37209 .42429 .41282 .42077 .40859 Mtetra
.961 .661 .416 r
.42077 .40859 .42429 .41282 .4281 .48653 .42452 .48176 Mtetra
.963 .654 .391 r
.42452 .48176 .4281 .48653 .43261 .54556 .42898 .54046 Mtetra
.456 .597 .903 r
.42898 .54046 .43261 .54556 .43886 .54607 .43522 .54114 Mtetra
.948 .71 .543 r
.43522 .54114 .43886 .54607 .44658 .48525 .44301 .48084 Mtetra
.954 .707 .524 r
.44301 .48084 .44658 .48525 .45452 .40499 .45103 .40108 Mtetra
.951 .72 .553 r
.45103 .40108 .45452 .40499 .46153 .35757 .45809 .35379 Mtetra
.885 .464 .063 r
.45809 .35379 .46153 .35757 .46726 .37216 .46382 .36808 Mtetra
.963 .657 .396 r
.46382 .36808 .46726 .37216 .47218 .44173 .46868 .43705 Mtetra
.965 .662 .401 r
.46868 .43705 .47218 .44173 .4772 .52424 .47362 .51902 Mtetra
.96 .623 .304 r
.47362 .51902 .4772 .52424 .4831 .56258 .47949 .55727 Mtetra
.94 .721 .579 r
.47949 .55727 .4831 .56258 .48995 .52658 .48637 .5217 Mtetra
.958 .706 .513 r
.48637 .5217 .48995 .52658 .4971 .44105 .49361 .4368 Mtetra
.96 .71 .514 r
.49361 .4368 .4971 .44105 .5039 .36338 .5005 .35951 Mtetra
.94 .747 .615 r
.5005 .35951 .5039 .36338 .51016 .3402 .50679 .33627 Mtetra
.96 .629 .329 r
.50679 .33627 .51016 .3402 .51617 .38397 .51277 .37956 Mtetra
.967 .66 .386 r
.51277 .37956 .51617 .38397 .52235 .46874 .51886 .46369 Mtetra
.967 .653 .364 r
.51886 .46369 .52235 .46874 .52886 .53958 .5253 .53414 Mtetra
0 .229 .749 r
.5253 .53414 .52886 .53958 .53546 .54501 .5319 .53972 Mtetra
.959 .711 .52 r
.5319 .53972 .53546 .54501 .54175 .47964 .53827 .47493 Mtetra
.964 .707 .496 r
.53827 .47493 .54175 .47964 .54763 .38896 .54425 .38483 Mtetra
.963 .718 .517 r
.54425 .38483 .54763 .38896 .55345 .32976 .55015 .32585 Mtetra
0 .336 .813 r
.55015 .32585 .55345 .32976 .55977 .33384 .55646 .3297 Mtetra
.965 .643 .342 r
.55646 .3297 .55977 .33384 .56688 .39609 .56351 .39141 Mtetra
.968 .654 .357 r
.56351 .39141 .56688 .39609 .57454 .47707 .57109 .47184 Mtetra
.959 .618 .274 r
.57109 .47184 .57454 .47707 .58193 .52142 .57843 .516 Mtetra
.936 .735 .608 r
.57843 .516 .58193 .52142 .58819 .49614 .58473 .49104 Mtetra
.967 .71 .494 r
.58473 .49104 .58819 .49614 .59328 .41888 .58992 .41435 Mtetra
.969 .711 .489 r
.58992 .41435 .59328 .41888 .59806 .34085 .59479 .33676 Mtetra
.961 .739 .556 r
.59479 .33676 .59806 .34085 .60366 .3069 .60043 .30289 Mtetra
.924 .541 .15 r
.60043 .30289 .60366 .3069 .61075 .33195 .6075 .32764 Mtetra
.965 .638 .318 r
.6075 .32764 .61075 .33195 .61914 .39723 .61582 .39242 Mtetra
.964 .634 .302 r
.61582 .39242 .61914 .39723 .62772 .45902 .62433 .45382 Mtetra
.748 .326 0 r
.62433 .45382 .62772 .45902 .63499 .4735 .63159 .46828 Mtetra
.963 .725 .531 r
.63159 .46828 .63499 .4735 .64028 .42975 .63695 .42488 Mtetra
.972 .713 .483 r
.63695 .42488 .64028 .42975 .64437 .35794 .64113 .35354 Mtetra
.972 .722 .498 r
.64113 .35354 .64437 .35794 .64883 .30255 .64566 .29844 Mtetra
.893 .786 .736 r
.64566 .29844 .64883 .30255 .65496 .29232 .65181 .28819 Mtetra
.941 .578 .198 r
.65181 .28819 .65496 .29232 .66308 .32758 .65989 .32316 Mtetra
.958 .618 .264 r
.65989 .32316 .66308 .32758 .67226 .38232 .66901 .37751 Mtetra
.935 .571 .171 r
.66901 .37751 .67226 .38232 .68078 .418 .6775 .41295 Mtetra
.858 .761 .755 r
.6775 .41295 .68078 .418 .68723 .40884 .68396 .40386 Mtetra
.972 .726 .506 r
.68396 .40386 .68723 .40884 .69164 .36102 .68844 .35636 Mtetra
.975 .722 .487 r
.68844 .35636 .69164 .36102 .69547 .30584 .69235 .30152 Mtetra
.968 .747 .55 r
.69235 .30152 .69547 .30584 .70047 .275 .69739 .27084 Mtetra
0 .118 .652 r
.69739 .27084 .70047 .275 .70757 .28178 .70449 .27754 Mtetra
.928 .558 .151 r
.70449 .27754 .70757 .28178 .71643 .31639 .71331 .31189 Mtetra
.928 .56 .148 r
.71331 .31189 .71643 .31639 .72556 .35259 .7224 .34784 Mtetra
0 0 .414 r
.7224 .34784 .72556 .35259 .73325 .3639 .73009 .35904 Mtetra
.954 .759 .603 r
.73009 .35904 .73325 .3639 .73876 .34181 .73563 .33707 Mtetra
.976 .735 .507 r
.73563 .33707 .73876 .34181 .74289 .30103 .73982 .29653 Mtetra
.975 .744 .525 r
.73982 .29653 .74289 .30103 .74733 .2666 .74431 .26231 Mtetra
.899 .793 .735 r
.74431 .26231 .74733 .2666 .75342 .2562 .75043 .25197 Mtetra
.725 .293 0 r
.75043 .25197 .75342 .2562 .76142 .27097 .75842 .26663 Mtetra
.872 .477 .012 r
.75842 .26663 .76142 .27097 .77037 .29663 .76734 .2921 Mtetra
.737 .314 0 r
.76734 .2921 .77037 .29663 .7787 .31299 .77566 .30831 Mtetra
.795 .77 .831 r
.77566 .30831 .7787 .31299 .78532 .30746 .78229 .30276 Mtetra
.967 .762 .576 r
.78229 .30276 .78532 .30746 .79034 .28325 .78735 .27867 Mtetra
.974 .757 .549 r
.78735 .27867 .79034 .28325 .79498 .2556 .79203 .25119 Mtetra
.945 .787 .654 r
.79203 .25119 .79498 .2556 .8006 .23995 .79768 .23563 Mtetra
.3 .546 .918 r
.79768 .23563 .8006 .23995 .8078 .24199 .8049 .23766 Mtetra
.637 .209 0 r
.8049 .23766 .8078 .24199 .81614 .25556 .81322 .25113 Mtetra
0 0 .426 r
.81322 .25113 .81614 .25556 .82441 .26757 .82149 .26302 Mtetra
.518 .663 .926 r
.82149 .26302 .82441 .26757 .83156 .2674 .82864 .2628 Mtetra
.927 .793 .692 r
.82864 .2628 .83156 .2674 .83744 .25444 .83454 .24988 Mtetra
.648 .728 .907 r
.21582 .45192 .21959 .45561 .22513 .45392 .22136 .45023 Mtetra
.863 .745 .731 r
.22136 .45023 .22513 .45392 .23144 .44378 .22768 .44016 Mtetra
.881 .742 .704 r
.22768 .44016 .23144 .44378 .23796 .43113 .23421 .42758 Mtetra
.807 .759 .809 r
.23421 .42758 .23796 .43113 .24384 .42554 .24011 .422 Mtetra
.762 .273 0 r
.24011 .422 .24384 .42554 .24863 .4328 .2449 .42916 Mtetra
.935 .568 .283 r
.2449 .42916 .24863 .4328 .25265 .44988 .24891 .44608 Mtetra
.931 .553 .249 r
.24891 .44608 .25265 .44988 .25684 .46569 .2531 .46175 Mtetra
.091 .445 .88 r
.2531 .46175 .25684 .46569 .26218 .46812 .25844 .46416 Mtetra
.889 .735 .684 r
.25844 .46416 .26218 .46812 .26889 .45322 .26517 .44937 Mtetra
.913 .725 .635 r
.26517 .44937 .26889 .45322 .27625 .42947 .27255 .4258 Mtetra
.901 .738 .67 r
.27255 .4258 .27625 .42947 .28302 .41277 .27934 .40918 Mtetra
0 .377 .833 r
.27934 .40918 .28302 .41277 .28833 .41565 .28465 .41198 Mtetra
.945 .602 .336 r
.28465 .41198 .28833 .41565 .29222 .43868 .28853 .43479 Mtetra
.95 .626 .376 r
.28853 .43479 .29222 .43868 .29574 .46841 .29204 .46426 Mtetra
.927 .541 .206 r
.29204 .46426 .29574 .46841 .30033 .4843 .29662 .48004 Mtetra
.867 .739 .719 r
.29662 .48004 .30033 .4843 .30678 .47307 .30308 .46892 Mtetra
.925 .718 .604 r
.30308 .46892 .30678 .47307 .31461 .44015 .31094 .43627 Mtetra
.928 .72 .602 r
.31094 .43627 .31461 .44015 .32235 .4072 .31871 .40353 Mtetra
.871 .757 .734 r
.31871 .40353 .32235 .4072 .3286 .39718 .32497 .3935 Mtetra
.944 .591 .307 r
.32497 .3935 .3286 .39718 .33292 .41942 .32929 .41548 Mtetra
.954 .646 .408 r
.32929 .41548 .33292 .41942 .33613 .46266 .33247 .45832 Mtetra
.956 .637 .38 r
.33247 .45832 .33613 .46266 .33988 .49919 .3362 .49459 Mtetra
.133 .435 .873 r
.3362 .49459 .33988 .49919 .34561 .50191 .34193 .49736 Mtetra
.929 .716 .594 r
.34193 .49736 .34561 .50191 .35338 .46607 .34972 .46187 Mtetra
.939 .711 .566 r
.34972 .46187 .35338 .46607 .3618 .41513 .35819 .41131 Mtetra
.933 .725 .599 r
.35819 .41131 .3618 .41513 .36912 .38353 .36555 .37984 Mtetra
.828 .371 0 r
.36555 .37984 .36912 .38353 .37439 .39373 .37082 .38982 Mtetra
.957 .649 .404 r
.37082 .38982 .37439 .39373 .37797 .44289 .37436 .43847 Mtetra
.959 .657 .414 r
.37436 .43847 .37797 .44289 .38131 .50185 .37767 .49695 Mtetra
.954 .609 .298 r
.37767 .49695 .38131 .50185 .38618 .52978 .38251 .52478 Mtetra
.919 .722 .621 r
.38251 .52478 .38618 .52978 .3933 .50392 .38965 .49926 Mtetra
.945 .708 .548 r
.38965 .49926 .3933 .50392 .40175 .44061 .39816 .43651 Mtetra
.947 .712 .55 r
.39816 .43651 .40175 .44061 .4098 .38273 .40627 .37898 Mtetra
.906 .756 .683 r
.40627 .37898 .4098 .38273 .41618 .36828 .41268 .36444 Mtetra
.957 .634 .365 r
.41268 .36444 .41618 .36828 .42077 .40859 .41723 .40424 Mtetra
.962 .661 .415 r
.41723 .40424 .42077 .40859 .42452 .48176 .42093 .47674 Mtetra
.964 .655 .389 r
.42093 .47674 .42452 .48176 .42898 .54046 .42534 .53507 Mtetra
.445 .578 .892 r
.42534 .53507 .42898 .54046 .43522 .54114 .43158 .53595 Mtetra
.947 .709 .545 r
.43158 .53595 .43522 .54114 .44301 .48084 .43942 .47629 Mtetra
.954 .706 .525 r
.43942 .47629 .44301 .48084 .45103 .40108 .44752 .39713 Mtetra
.951 .72 .553 r
.44752 .39713 .45103 .40108 .45809 .35379 .45464 .35 Mtetra
.88 .455 .05 r
.45464 .35 .45809 .35379 .46382 .36808 .46036 .36392 Mtetra
.963 .656 .394 r
.46036 .36392 .46382 .36808 .46868 .43705 .46516 .43217 Mtetra
.966 .663 .399 r
.46516 .43217 .46868 .43705 .47362 .51902 .47003 .51349 Mtetra
.96 .624 .299 r
.47003 .51349 .47362 .51902 .47949 .55727 .47586 .55162 Mtetra
.937 .718 .582 r
.47586 .55162 .47949 .55727 .48637 .5217 .48278 .51659 Mtetra
.957 .706 .514 r
.48278 .51659 .48637 .5217 .49361 .4368 .49012 .43246 Mtetra
.96 .709 .514 r
.49012 .43246 .49361 .4368 .5005 .35951 .49708 .35564 Mtetra
.94 .747 .615 r
.49708 .35564 .5005 .35951 .50679 .33627 .50341 .33232 Mtetra
.96 .628 .327 r
.50341 .33232 .50679 .33627 .51277 .37956 .50935 .37502 Mtetra
.967 .66 .385 r
.50935 .37502 .51277 .37956 .51886 .46369 .51536 .45838 Mtetra
.968 .654 .361 r
.51536 .45838 .51886 .46369 .5253 .53414 .52173 .52835 Mtetra
0 .224 .746 r
.52173 .52835 .5253 .53414 .5319 .53972 .52833 .53412 Mtetra
.957 .71 .522 r
.52833 .53412 .5319 .53972 .53827 .47493 .53477 .47004 Mtetra
.964 .706 .497 r
.53477 .47004 .53827 .47493 .54425 .38483 .54086 .38065 Mtetra
.963 .718 .518 r
.54086 .38065 .54425 .38483 .55015 .32585 .54682 .32194 Mtetra
0 .366 .833 r
.54682 .32194 .55015 .32585 .55646 .3297 .55314 .32552 Mtetra
.965 .643 .34 r
.55314 .32552 .55646 .3297 .56351 .39141 .56012 .38657 Mtetra
.968 .654 .355 r
.56012 .38657 .56351 .39141 .57109 .47184 .56761 .46633 Mtetra
.958 .618 .269 r
.56761 .46633 .57109 .47184 .57843 .516 .57492 .51026 Mtetra
.931 .731 .61 r
.57492 .51026 .57843 .516 .58473 .49104 .58125 .48568 Mtetra
.966 .709 .496 r
.58125 .48568 .58473 .49104 .58992 .41435 .58654 .40969 Mtetra
.969 .711 .49 r
.58654 .40969 .58992 .41435 .59479 .33676 .59151 .33264 Mtetra
.961 .739 .557 r
.59151 .33264 .59479 .33676 .60043 .30289 .59719 .29886 Mtetra
.922 .539 .146 r
.59719 .29886 .60043 .30289 .6075 .32764 .60423 .32325 Mtetra
.965 .638 .316 r
.60423 .32325 .6075 .32764 .61582 .39242 .61248 .38743 Mtetra
.964 .634 .299 r
.61248 .38743 .61582 .39242 .62433 .45382 .62092 .44835 Mtetra
.733 .316 0 r
.62092 .44835 .62433 .45382 .63159 .46828 .62818 .46278 Mtetra
.961 .724 .533 r
.62818 .46278 .63159 .46828 .63695 .42488 .63359 .41983 Mtetra
.971 .712 .484 r
.63359 .41983 .63695 .42488 .64113 .35354 .63787 .34905 Mtetra
.971 .722 .499 r
.63787 .34905 .64113 .35354 .64566 .29844 .64247 .29431 Mtetra
.893 .785 .736 r
.64247 .29431 .64566 .29844 .65181 .28819 .64865 .28403 Mtetra
.94 .577 .195 r
.64865 .28403 .65181 .28819 .65989 .32316 .65668 .31864 Mtetra
.958 .617 .262 r
.65668 .31864 .65989 .32316 .66901 .37751 .66574 .37252 Mtetra
.933 .569 .165 r
.66574 .37252 .66901 .37751 .6775 .41295 .67419 .40769 Mtetra
.852 .754 .754 r
.67419 .40769 .6775 .41295 .68396 .40386 .68067 .39869 Mtetra
.971 .725 .508 r
.68067 .39869 .68396 .40386 .68844 .35636 .68522 .35158 Mtetra
.975 .722 .488 r
.68522 .35158 .68844 .35636 .69235 .30152 .68921 .29714 Mtetra
.968 .747 .551 r
.68921 .29714 .69235 .30152 .69739 .27084 .6943 .26666 Mtetra
0 .126 .659 r
.6943 .26666 .69739 .27084 .70449 .27754 .7014 .27327 Mtetra
.927 .557 .148 r
.7014 .27327 .70449 .27754 .71331 .31189 .71018 .30732 Mtetra
.927 .558 .144 r
.71018 .30732 .71331 .31189 .7224 .34784 .71923 .34294 Mtetra
0 0 .431 r
.71923 .34294 .7224 .34784 .73009 .35904 .7269 .35402 Mtetra
.952 .757 .604 r
.7269 .35402 .73009 .35904 .73563 .33707 .73248 .33219 Mtetra
.975 .734 .509 r
.73248 .33219 .73563 .33707 .73982 .29653 .73674 .29195 Mtetra
.974 .744 .527 r
.73674 .29195 .73982 .29653 .74431 .26231 .74129 .25798 Mtetra
.897 .793 .737 r
.74129 .25798 .74431 .26231 .75043 .25197 .74743 .24771 Mtetra
.722 .289 0 r
.74743 .24771 .75043 .25197 .75842 .26663 .7554 .26225 Mtetra
.87 .475 .008 r
.7554 .26225 .75842 .26663 .76734 .2921 .76429 .28749 Mtetra
.729 .307 0 r
.76429 .28749 .76734 .2921 .77566 .30831 .77259 .30352 Mtetra
.793 .766 .829 r
.77259 .30352 .77566 .30831 .78229 .30276 .77923 .29796 Mtetra
.966 .761 .577 r
.77923 .29796 .78229 .30276 .78735 .27867 .78434 .27401 Mtetra
.973 .757 .551 r
.78434 .27401 .78735 .27867 .79203 .25119 .78907 .24673 Mtetra
.944 .787 .656 r
.78907 .24673 .79203 .25119 .79768 .23563 .79476 .23129 Mtetra
.3 .547 .919 r
.79476 .23129 .79768 .23563 .8049 .23766 .80198 .23331 Mtetra
.633 .204 0 r
.80198 .23331 .8049 .23766 .81322 .25113 .81029 .24665 Mtetra
0 0 .434 r
.81029 .24665 .81322 .25113 .82149 .26302 .81854 .25841 Mtetra
.523 .663 .924 r
.81854 .25841 .82149 .26302 .82864 .2628 .8257 .25813 Mtetra
.926 .792 .693 r
.8257 .25813 .82864 .2628 .83454 .24988 .83163 .24525 Mtetra
.648 .726 .906 r
.21203 .44819 .21582 .45192 .22136 .45023 .21758 .4465 Mtetra
.862 .744 .732 r
.21758 .4465 .22136 .45023 .22768 .44016 .22391 .4365 Mtetra
.88 .741 .705 r
.22391 .4365 .22768 .44016 .23421 .42758 .23045 .42401 Mtetra
.806 .759 .809 r
.23045 .42401 .23421 .42758 .24011 .422 .23636 .41845 Mtetra
.755 .264 0 r
.23636 .41845 .24011 .422 .2449 .42916 .24115 .4255 Mtetra
.934 .567 .279 r
.24115 .4255 .2449 .42916 .24891 .44608 .24517 .44223 Mtetra
.93 .551 .244 r
.24517 .44223 .24891 .44608 .2531 .46175 .24935 .45773 Mtetra
.104 .449 .883 r
.24935 .45773 .2531 .46175 .25844 .46416 .25469 .46012 Mtetra
.887 .734 .685 r
.25469 .46012 .25844 .46416 .26517 .44937 .26143 .44547 Mtetra
.912 .725 .636 r
.26143 .44547 .26517 .44937 .27255 .4258 .26883 .42209 Mtetra
.9 .738 .671 r
.26883 .42209 .27255 .4258 .27934 .40918 .27563 .40558 Mtetra
0 .391 .843 r
.27563 .40558 .27934 .40918 .28465 .41198 .28095 .40829 Mtetra
.945 .601 .333 r
.28095 .40829 .28465 .41198 .28853 .43479 .28483 .43083 Mtetra
.951 .625 .374 r
.28483 .43083 .28853 .43479 .29204 .46426 .28833 .46 Mtetra
.927 .539 .199 r
.28833 .46 .29204 .46426 .29662 .48004 .2929 .47565 Mtetra
.864 .736 .72 r
.2929 .47565 .29662 .48004 .30308 .46892 .29937 .46467 Mtetra
.924 .717 .605 r
.29937 .46467 .30308 .46892 .31094 .43627 .30725 .43233 Mtetra
.927 .72 .603 r
.30725 .43233 .31094 .43627 .31871 .40353 .31505 .39985 Mtetra
.871 .757 .734 r
.31505 .39985 .31871 .40353 .32497 .3935 .32133 .38981 Mtetra
.944 .59 .304 r
.32133 .38981 .32497 .3935 .32929 .41548 .32564 .41147 Mtetra
.955 .645 .406 r
.32564 .41147 .32929 .41548 .33247 .45832 .32881 .45386 Mtetra
.956 .637 .378 r
.32881 .45386 .33247 .45832 .3362 .49459 .33252 .48981 Mtetra
.139 .429 .869 r
.33252 .48981 .3362 .49459 .34193 .49736 .33824 .49265 Mtetra
.928 .715 .595 r
.33824 .49265 .34193 .49736 .34972 .46187 .34606 .45756 Mtetra
.939 .711 .567 r
.34606 .45756 .34972 .46187 .35819 .41131 .35457 .40745 Mtetra
.933 .725 .6 r
.35457 .40745 .35819 .41131 .36555 .37984 .36196 .37614 Mtetra
.819 .358 0 r
.36196 .37614 .36555 .37984 .37082 .38982 .36724 .38585 Mtetra
.957 .648 .403 r
.36724 .38585 .37082 .38982 .37436 .43847 .37076 .43393 Mtetra
.96 .657 .413 r
.37076 .43393 .37436 .43847 .37767 .49695 .37402 .49185 Mtetra
.954 .609 .293 r
.37402 .49185 .37767 .49695 .38251 .52478 .37884 .51954 Mtetra
.916 .72 .623 r
.37884 .51954 .38251 .52478 .38965 .49926 .38599 .49444 Mtetra
.944 .707 .549 r
.38599 .49444 .38965 .49926 .39816 .43651 .39456 .43234 Mtetra
.947 .712 .55 r
.39456 .43234 .39816 .43651 .40627 .37898 .40272 .37522 Mtetra
.907 .756 .682 r
.40272 .37522 .40627 .37898 .41268 .36444 .40915 .36057 Mtetra
.957 .633 .363 r
.40915 .36057 .41268 .36444 .41723 .40424 .41369 .39978 Mtetra
.962 .661 .414 r
.41369 .39978 .41723 .40424 .42093 .47674 .41734 .47151 Mtetra
.964 .655 .387 r
.41734 .47151 .42093 .47674 .42534 .53507 .42169 .52938 Mtetra
.431 .558 .882 r
.42169 .52938 .42534 .53507 .43158 .53595 .42793 .53051 Mtetra
.946 .708 .546 r
.42793 .53051 .43158 .53595 .43942 .47629 .43582 .4716 Mtetra
.953 .706 .526 r
.43582 .4716 .43942 .47629 .44752 .39713 .444 .39314 Mtetra
.951 .72 .553 r
.444 .39314 .44752 .39713 .45464 .35 .45117 .34621 Mtetra
.873 .445 .035 r
.45117 .34621 .45464 .35 .46036 .36392 .4569 .3597 Mtetra
.964 .656 .393 r
.4569 .3597 .46036 .36392 .46516 .43217 .46164 .42711 Mtetra
.966 .663 .398 r
.46164 .42711 .46516 .43217 .47003 .51349 .46644 .50766 Mtetra
.961 .624 .294 r
.46644 .50766 .47003 .51349 .47586 .55162 .47223 .54565 Mtetra
.934 .716 .584 r
.47223 .54565 .47586 .55162 .48278 .51659 .47919 .51125 Mtetra
.957 .705 .515 r
.47919 .51125 .48278 .51659 .49012 .43246 .4866 .42801 Mtetra
.959 .709 .515 r
.4866 .42801 .49012 .43246 .49708 .35564 .49366 .35175 Mtetra
.94 .747 .614 r
.49366 .35175 .49708 .35564 .50341 .33232 .50002 .32834 Mtetra
.96 .627 .325 r
.50002 .32834 .50341 .33232 .50935 .37502 .50592 .37036 Mtetra
.967 .66 .383 r
.50592 .37036 .50935 .37502 .51536 .45838 .51185 .45281 Mtetra
.968 .654 .359 r
.51185 .45281 .51536 .45838 .52173 .52835 .51815 .52222 Mtetra
0 .216 .739 r
.51815 .52222 .52173 .52835 .52833 .53412 .52475 .52821 Mtetra
.956 .709 .523 r
.52475 .52821 .52833 .53412 .53477 .47004 .53126 .46498 Mtetra
.963 .706 .498 r
.53126 .46498 .53477 .47004 .54086 .38065 .53745 .3764 Mtetra
.963 .718 .518 r
.53745 .3764 .54086 .38065 .54682 .32194 .54349 .31801 Mtetra
.033 .401 .855 r
.54349 .31801 .54682 .32194 .55314 .32552 .5498 .32128 Mtetra
.965 .642 .339 r
.5498 .32128 .55314 .32552 .56012 .38657 .55672 .38156 Mtetra
.969 .654 .353 r
.55672 .38156 .56012 .38657 .56761 .46633 .56413 .46054 Mtetra
.958 .618 .264 r
.56413 .46054 .56761 .46633 .57492 .51026 .57139 .5042 Mtetra
.927 .727 .613 r
.57139 .5042 .57492 .51026 .58125 .48568 .57776 .48008 Mtetra
.965 .709 .497 r
.57776 .48008 .58125 .48568 .58654 .40969 .58314 .40491 Mtetra
.968 .711 .491 r
.58314 .40491 .58654 .40969 .59151 .33264 .58821 .32848 Mtetra
.961 .739 .557 r
.58821 .32848 .59151 .33264 .59719 .29886 .59394 .29481 Mtetra
.921 .535 .14 r
.59394 .29481 .59719 .29886 .60423 .32325 .60095 .31879 Mtetra
.965 .638 .314 r
.60095 .31879 .60423 .32325 .61248 .38743 .60912 .38227 Mtetra
.964 .634 .296 r
.60912 .38227 .61248 .38743 .62092 .44835 .61749 .44263 Mtetra
.717 .307 0 r
.61749 .44263 .62092 .44835 .62818 .46278 .62474 .45703 Mtetra
.959 .722 .536 r
.62474 .45703 .62818 .46278 .63359 .41983 .63022 .41459 Mtetra
.97 .712 .485 r
.63022 .41459 .63359 .41983 .63787 .34905 .63459 .34448 Mtetra
.971 .722 .5 r
.63459 .34448 .63787 .34905 .64247 .29431 .63928 .29015 Mtetra
.893 .785 .735 r
.63928 .29015 .64247 .29431 .64865 .28403 .64547 .27985 Mtetra
.939 .575 .192 r
.64547 .27985 .64865 .28403 .65668 .31864 .65346 .31405 Mtetra
.958 .617 .259 r
.65346 .31405 .65668 .31864 .66574 .37252 .66245 .36738 Mtetra
.932 .567 .159 r
.66245 .36738 .66574 .37252 .67419 .40769 .67085 .40222 Mtetra
.847 .747 .753 r
.67085 .40222 .67419 .40769 .68067 .39869 .67736 .39333 Mtetra
.969 .724 .51 r
.67736 .39333 .68067 .39869 .68522 .35158 .68199 .34667 Mtetra
.974 .721 .49 r
.68199 .34667 .68522 .35158 .68921 .29714 .68606 .29271 Mtetra
.967 .747 .553 r
.68606 .29271 .68921 .29714 .6943 .26666 .6912 .26246 Mtetra
0 .135 .666 r
.6912 .26246 .6943 .26666 .7014 .27327 .69829 .26896 Mtetra
.926 .555 .145 r
.69829 .26896 .7014 .27327 .71018 .30732 .70703 .30266 Mtetra
.925 .557 .14 r
.70703 .30266 .71018 .30732 .71923 .34294 .71603 .33791 Mtetra
0 0 .448 r
.71603 .33791 .71923 .34294 .7269 .35402 .72369 .34885 Mtetra
.949 .755 .606 r
.72369 .34885 .7269 .35402 .73248 .33219 .72931 .32718 Mtetra
.974 .734 .511 r
.72931 .32718 .73248 .33219 .73674 .29195 .73364 .28729 Mtetra
.974 .743 .529 r
.73364 .28729 .73674 .29195 .74129 .25798 .73824 .25362 Mtetra
.896 .792 .739 r
.73824 .25362 .74129 .25798 .74743 .24771 .74441 .24344 Mtetra
.718 .285 0 r
.74441 .24344 .74743 .24771 .7554 .26225 .75237 .25783 Mtetra
.868 .472 .003 r
.75237 .25783 .7554 .26225 .76429 .28749 .76123 .28281 Mtetra
.72 .299 0 r
.76123 .28281 .76429 .28749 .77259 .30352 .76951 .29863 Mtetra
.792 .762 .826 r
.76951 .29863 .77259 .30352 .77923 .29796 .77616 .29305 Mtetra
.964 .76 .579 r
.77616 .29305 .77923 .29796 .78434 .27401 .78131 .26928 Mtetra
.972 .756 .553 r
.78131 .26928 .78434 .27401 .78907 .24673 .7861 .24222 Mtetra
.942 .786 .658 r
.7861 .24222 .78907 .24673 .79476 .23129 .79182 .22694 Mtetra
.301 .547 .919 r
.79182 .22694 .79476 .23129 .80198 .23331 .79905 .22894 Mtetra
.627 .198 0 r
.79905 .22894 .80198 .23331 .81029 .24665 .80735 .24214 Mtetra
0 0 .444 r
.80735 .24214 .81029 .24665 .81854 .25841 .81558 .25373 Mtetra
.529 .663 .922 r
.81558 .25373 .81854 .25841 .8257 .25813 .82275 .25338 Mtetra
.924 .79 .694 r
.82275 .25338 .8257 .25813 .83163 .24525 .8287 .24057 Mtetra
.647 .724 .905 r
.20823 .44441 .21203 .44819 .21758 .4465 .21379 .44271 Mtetra
.86 .744 .733 r
.21379 .44271 .21758 .4465 .22391 .4365 .22013 .43281 Mtetra
.879 .741 .706 r
.22013 .43281 .22391 .4365 .23045 .42401 .22668 .42042 Mtetra
.805 .759 .81 r
.22668 .42042 .23045 .42401 .23636 .41845 .23259 .41488 Mtetra
.746 .253 0 r
.23259 .41488 .23636 .41845 .24115 .4255 .23739 .42181 Mtetra
.934 .564 .275 r
.23739 .42181 .24115 .4255 .24517 .44223 .24141 .43832 Mtetra
.929 .549 .238 r
.24141 .43832 .24517 .44223 .24935 .45773 .2456 .45363 Mtetra
.118 .453 .885 r
.2456 .45363 .24935 .45773 .25469 .46012 .25094 .456 Mtetra
.886 .733 .686 r
.25094 .456 .25469 .46012 .26143 .44547 .25769 .4415 Mtetra
.911 .724 .637 r
.25769 .4415 .26143 .44547 .26883 .42209 .2651 .41835 Mtetra
.899 .737 .672 r
.2651 .41835 .26883 .42209 .27563 .40558 .27192 .40197 Mtetra
0 .406 .853 r
.27192 .40197 .27563 .40558 .28095 .40829 .27724 .40458 Mtetra
.945 .599 .33 r
.27724 .40458 .28095 .40829 .28483 .43083 .28112 .4268 Mtetra
.951 .624 .371 r
.28112 .4268 .28483 .43083 .28833 .46 .28462 .45563 Mtetra
.925 .537 .191 r
.28462 .45563 .28833 .46 .2929 .47565 .28918 .47112 Mtetra
.861 .733 .721 r
.28918 .47112 .2929 .47565 .29937 .46467 .29566 .46031 Mtetra
.923 .716 .606 r
.29566 .46031 .29937 .46467 .30725 .43233 .30356 .42834 Mtetra
.927 .72 .603 r
.30356 .42834 .30725 .43233 .31505 .39985 .31138 .39614 Mtetra
.871 .757 .734 r
.31138 .39614 .31505 .39985 .32133 .38981 .31768 .3861 Mtetra
.943 .587 .299 r
.31768 .3861 .32133 .38981 .32564 .41147 .32199 .40741 Mtetra
.955 .645 .404 r
.32199 .40741 .32564 .41147 .32881 .45386 .32514 .44927 Mtetra
.957 .637 .375 r
.32514 .44927 .32881 .45386 .33252 .48981 .32883 .48485 Mtetra
.144 .422 .864 r
.32883 .48485 .33252 .48981 .33824 .49265 .33455 .48776 Mtetra
.926 .714 .596 r
.33455 .48776 .33824 .49265 .34606 .45756 .34239 .45315 Mtetra
.938 .71 .568 r
.34239 .45315 .34606 .45756 .35457 .40745 .35093 .40355 Mtetra
.932 .725 .6 r
.35093 .40355 .35457 .40745 .36196 .37614 .35835 .37243 Mtetra
.807 .342 0 r
.35835 .37243 .36196 .37614 .36724 .38585 .36364 .38184 Mtetra
.957 .648 .401 r
.36364 .38184 .36724 .38585 .37076 .43393 .36714 .42925 Mtetra
.96 .657 .411 r
.36714 .42925 .37076 .43393 .37402 .49185 .37037 .48652 Mtetra
.955 .609 .288 r
.37037 .48652 .37402 .49185 .37884 .51954 .37517 .51405 Mtetra
.913 .717 .625 r
.37517 .51405 .37884 .51954 .38599 .49444 .38233 .48943 Mtetra
.944 .707 .55 r
.38233 .48943 .38599 .49444 .39456 .43234 .39094 .42808 Mtetra
.946 .711 .551 r
.39094 .42808 .39456 .43234 .40272 .37522 .39916 .37144 Mtetra
.907 .755 .681 r
.39916 .37144 .40272 .37522 .40915 .36057 .40562 .35668 Mtetra
.957 .632 .36 r
.40562 .35668 .40915 .36057 .41369 .39978 .41014 .39521 Mtetra
.962 .661 .412 r
.41014 .39521 .41369 .39978 .41734 .47151 .41374 .46605 Mtetra
.965 .655 .385 r
.41374 .46605 .41734 .47151 .42169 .52938 .41805 .5234 Mtetra
.414 .536 .871 r
.41805 .5234 .42169 .52938 .42793 .53051 .42428 .5248 Mtetra
.945 .707 .548 r
.42428 .5248 .42793 .53051 .43582 .4716 .43221 .46676 Mtetra
.953 .706 .527 r
.43221 .46676 .43582 .4716 .444 .39314 .44046 .38911 Mtetra
.95 .72 .554 r
.44046 .38911 .444 .39314 .45117 .34621 .44769 .34241 Mtetra
.865 .432 .016 r
.44769 .34241 .45117 .34621 .4569 .3597 .45342 .35541 Mtetra
.964 .656 .392 r
.45342 .35541 .4569 .3597 .46164 .42711 .45811 .42185 Mtetra
.966 .663 .396 r
.45811 .42185 .46164 .42711 .46644 .50766 .46284 .50152 Mtetra
.961 .625 .288 r
.46284 .50152 .46644 .50766 .47223 .54565 .46859 .53935 Mtetra
.93 .713 .587 r
.46859 .53935 .47223 .54565 .47919 .51125 .47558 .50566 Mtetra
.956 .704 .516 r
.47558 .50566 .47919 .51125 .4866 .42801 .48308 .42347 Mtetra
.959 .709 .516 r
.48308 .42347 .4866 .42801 .49366 .35175 .49021 .34785 Mtetra
.94 .747 .614 r
.49021 .34785 .49366 .35175 .50002 .32834 .49661 .32433 Mtetra
.959 .625 .322 r
.49661 .32433 .50002 .32834 .50592 .37036 .50248 .36558 Mtetra
.967 .659 .382 r
.50248 .36558 .50592 .37036 .51185 .45281 .50833 .44699 Mtetra
.968 .654 .356 r
.50833 .44699 .51185 .45281 .51815 .52222 .51456 .51575 Mtetra
0 .205 .731 r
.51456 .51575 .51815 .52222 .52475 .52821 .52115 .522 Mtetra
.955 .708 .525 r
.52115 .522 .52475 .52821 .53126 .46498 .52774 .45972 Mtetra
.963 .706 .499 r
.52774 .45972 .53126 .46498 .53745 .3764 .53403 .3721 Mtetra
.963 .718 .519 r
.53403 .3721 .53745 .3764 .54349 .31801 .54014 .31408 Mtetra
.088 .44 .877 r
.54014 .31408 .54349 .31801 .5498 .32128 .54646 .31699 Mtetra
.965 .641 .337 r
.54646 .31699 .5498 .32128 .55672 .38156 .55331 .37639 Mtetra
.969 .653 .352 r
.55331 .37639 .55672 .38156 .56413 .46054 .56063 .45447 Mtetra
.958 .618 .258 r
.56063 .45447 .56413 .46054 .57139 .5042 .56784 .49781 Mtetra
.922 .723 .616 r
.56784 .49781 .57139 .5042 .57776 .48008 .57425 .47421 Mtetra
.964 .708 .499 r
.57425 .47421 .57776 .48008 .58314 .40491 .57973 .39998 Mtetra
.968 .71 .492 r
.57973 .39998 .58314 .40491 .58821 .32848 .5849 .32429 Mtetra
.96 .738 .558 r
.5849 .32429 .58821 .32848 .59394 .29481 .59067 .29075 Mtetra
.918 .531 .134 r
.59067 .29075 .59394 .29481 .60095 .31879 .59765 .31426 Mtetra
.965 .637 .312 r
.59765 .31426 .60095 .31879 .60912 .38227 .60575 .37693 Mtetra
.964 .633 .293 r
.60575 .37693 .60912 .38227 .61749 .44263 .61405 .43665 Mtetra
.7 .296 0 r
.61405 .43665 .61749 .44263 .62474 .45703 .62128 .45101 Mtetra
.957 .721 .538 r
.62128 .45101 .62474 .45703 .63022 .41459 .62683 .40915 Mtetra
.97 .712 .487 r
.62683 .40915 .63022 .41459 .63459 .34448 .63131 .33982 Mtetra
.971 .721 .501 r
.63131 .33982 .63459 .34448 .63928 .29015 .63607 .28597 Mtetra
.893 .785 .735 r
.63607 .28597 .63928 .29015 .64547 .27985 .64227 .27564 Mtetra
.938 .573 .189 r
.64227 .27564 .64547 .27985 .65346 .31405 .65022 .30937 Mtetra
.957 .616 .257 r
.65022 .30937 .65346 .31405 .66245 .36738 .65914 .36207 Mtetra
.93 .565 .152 r
.65914 .36207 .66245 .36738 .67085 .40222 .6675 .39653 Mtetra
.841 .74 .753 r
.6675 .39653 .67085 .40222 .67736 .39333 .67403 .38777 Mtetra
.968 .723 .512 r
.67403 .38777 .67736 .39333 .68199 .34667 .67873 .34162 Mtetra
.974 .721 .491 r
.67873 .34162 .68199 .34667 .68606 .29271 .68289 .28821 Mtetra
.967 .747 .554 r
.68289 .28821 .68606 .29271 .6912 .26246 .68808 .25824 Mtetra
0 .146 .675 r
.68808 .25824 .6912 .26246 .69829 .26896 .69517 .26463 Mtetra
.925 .553 .142 r
.69517 .26463 .69829 .26896 .70703 .30266 .70386 .29792 Mtetra
.924 .554 .135 r
.70386 .29792 .70703 .30266 .71603 .33791 .71281 .33275 Mtetra
0 0 .467 r
.71281 .33275 .71603 .33791 .72369 .34885 .72046 .34351 Mtetra
.947 .753 .609 r
.72046 .34351 .72369 .34885 .72931 .32718 .72612 .32204 Mtetra
.973 .733 .513 r
.72612 .32204 .72931 .32718 .73364 .28729 .73052 .28255 Mtetra
.973 .743 .531 r
.73052 .28255 .73364 .28729 .73824 .25362 .73519 .24922 Mtetra
.894 .792 .741 r
.73519 .24922 .73824 .25362 .74441 .24344 .74138 .23915 Mtetra
.713 .279 0 r
.74138 .23915 .74441 .24344 .75237 .25783 .74933 .25338 Mtetra
.865 .468 0 r
.74933 .25338 .75237 .25783 .76123 .28281 .75815 .27805 Mtetra
.71 .29 0 r
.75815 .27805 .76123 .28281 .76951 .29863 .76641 .29363 Mtetra
.79 .758 .824 r
.76641 .29363 .76951 .29863 .77616 .29305 .77307 .28803 Mtetra
.963 .759 .582 r
.77307 .28803 .77616 .29305 .78131 .26928 .77827 .26446 Mtetra
.971 .756 .555 r
.77827 .26446 .78131 .26928 .7861 .24222 .78311 .23767 Mtetra
.941 .786 .661 r
.78311 .23767 .7861 .24222 .79182 .22694 .78886 .22256 Mtetra
.302 .547 .919 r
.78886 .22256 .79182 .22694 .79905 .22894 .7961 .22455 Mtetra
.621 .191 0 r
.7961 .22455 .79905 .22894 .80735 .24214 .80439 .23759 Mtetra
0 0 .455 r
.80439 .23759 .80735 .24214 .81558 .25373 .81261 .24899 Mtetra
.535 .664 .92 r
.81261 .24899 .81558 .25373 .82275 .25338 .81977 .24857 Mtetra
.922 .789 .696 r
.81977 .24857 .82275 .25338 .8287 .24057 .82575 .23583 Mtetra
.646 .722 .904 r
.20442 .44058 .20823 .44441 .21379 .44271 .20999 .43889 Mtetra
.859 .743 .734 r
.20999 .43889 .21379 .44271 .22013 .43281 .21633 .42908 Mtetra
.878 .741 .707 r
.21633 .42908 .22013 .43281 .22668 .42042 .22289 .41682 Mtetra
.805 .759 .81 r
.22289 .41682 .22668 .42042 .23259 .41488 .22881 .4113 Mtetra
.735 .24 0 r
.22881 .4113 .23259 .41488 .23739 .42181 .23362 .41809 Mtetra
.933 .562 .269 r
.23362 .41809 .23739 .42181 .24141 .43832 .23764 .43435 Mtetra
.929 .546 .231 r
.23764 .43435 .24141 .43832 .2456 .45363 .24183 .44945 Mtetra
.132 .458 .887 r
.24183 .44945 .2456 .45363 .25094 .456 .24718 .45178 Mtetra
.884 .732 .688 r
.24718 .45178 .25094 .456 .25769 .4415 .25393 .43747 Mtetra
.91 .724 .638 r
.25393 .43747 .25769 .4415 .2651 .41835 .26135 .41458 Mtetra
.899 .737 .673 r
.26135 .41458 .2651 .41835 .27192 .40197 .26819 .39834 Mtetra
.025 .423 .864 r
.26819 .39834 .27192 .40197 .27724 .40458 .27352 .40083 Mtetra
.944 .597 .326 r
.27352 .40083 .27724 .40458 .28112 .4268 .27741 .42272 Mtetra
.951 .623 .368 r
.27741 .42272 .28112 .4268 .28462 .45563 .2809 .45115 Mtetra
.924 .534 .182 r
.2809 .45115 .28462 .45563 .28918 .47112 .28546 .46647 Mtetra
.857 .73 .722 r
.28546 .46647 .28918 .47112 .29566 .46031 .29194 .45584 Mtetra
.922 .716 .607 r
.29194 .45584 .29566 .46031 .30356 .42834 .29985 .42428 Mtetra
.926 .719 .604 r
.29985 .42428 .30356 .42834 .31138 .39614 .30769 .39242 Mtetra
.87 .757 .734 r
.30769 .39242 .31138 .39614 .31768 .3861 .31401 .38237 Mtetra
.942 .585 .295 r
.31401 .38237 .31768 .3861 .32199 .40741 .31832 .40328 Mtetra
.955 .644 .402 r
.31832 .40328 .32199 .40741 .32514 .44927 .32146 .44455 Mtetra
.957 .636 .372 r
.32146 .44455 .32514 .44927 .32883 .48485 .32514 .47972 Mtetra
.146 .415 .858 r
.32514 .47972 .32883 .48485 .33455 .48776 .33085 .48271 Mtetra
.925 .713 .598 r
.33085 .48271 .33455 .48776 .34239 .45315 .33871 .44863 Mtetra
.937 .71 .569 r
.33871 .44863 .34239 .45315 .35093 .40355 .34728 .39962 Mtetra
.932 .725 .601 r
.34728 .39962 .35093 .40355 .35835 .37243 .35473 .36871 Mtetra
.793 .323 0 r
.35473 .36871 .35835 .37243 .36364 .38184 .36003 .37778 Mtetra
.957 .647 .399 r
.36003 .37778 .36364 .38184 .36714 .42925 .36352 .42444 Mtetra
.96 .657 .409 r
.36352 .42444 .36714 .42925 .37037 .48652 .36672 .48099 Mtetra
.955 .609 .282 r
.36672 .48099 .37037 .48652 .37517 .51405 .3715 .50833 Mtetra
.909 .715 .627 r
.3715 .50833 .37517 .51405 .38233 .48943 .37867 .48424 Mtetra
.943 .706 .551 r
.37867 .48424 .38233 .48943 .39094 .42808 .38732 .42374 Mtetra
.946 .711 .552 r
.38732 .42374 .39094 .42808 .39916 .37144 .39558 .36764 Mtetra
.908 .755 .68 r
.39558 .36764 .39916 .37144 .40562 .35668 .40207 .35276 Mtetra
.957 .631 .357 r
.40207 .35276 .40562 .35668 .41014 .39521 .40658 .39054 Mtetra
.962 .661 .411 r
.40658 .39054 .41014 .39521 .41374 .46605 .41013 .46037 Mtetra
.965 .656 .382 r
.41013 .46037 .41374 .46605 .41805 .5234 .4144 .51713 Mtetra
.395 .514 .861 r
.4144 .51713 .41805 .5234 .42428 .5248 .42062 .51882 Mtetra
.943 .706 .549 r
.42062 .51882 .42428 .5248 .43221 .46676 .4286 .46176 Mtetra
.952 .705 .528 r
.4286 .46176 .43221 .46676 .44046 .38911 .43692 .38503 Mtetra
.95 .72 .555 r
.43692 .38503 .44046 .38911 .44769 .34241 .44419 .33859 Mtetra
.854 .416 0 r
.44419 .33859 .44769 .34241 .45342 .35541 .44992 .35105 Mtetra
.964 .655 .39 r
.44992 .35105 .45342 .35541 .45811 .42185 .45457 .41641 Mtetra
.967 .663 .394 r
.45457 .41641 .45811 .42185 .46284 .50152 .45923 .49508 Mtetra
.961 .625 .283 r
.45923 .49508 .46284 .50152 .46859 .53935 .46495 .53272 Mtetra
.927 .71 .59 r
.46495 .53272 .46859 .53935 .47558 .50566 .47196 .49983 Mtetra
.955 .704 .517 r
.47196 .49983 .47558 .50566 .48308 .42347 .47954 .41881 Mtetra
.958 .709 .516 r
.47954 .41881 .48308 .42347 .49021 .34785 .48676 .34392 Mtetra
.94 .747 .613 r
.48676 .34392 .49021 .34785 .49661 .32433 .49318 .3203 Mtetra
.959 .624 .319 r
.49318 .3203 .49661 .32433 .50248 .36558 .49902 .36068 Mtetra
.967 .659 .38 r
.49902 .36068 .50248 .36558 .50833 .44699 .50479 .44092 Mtetra
.969 .654 .354 r
.50479 .44092 .50833 .44699 .51456 .51575 .51096 .50895 Mtetra
0 .193 .722 r
.51096 .50895 .51456 .51575 .52115 .522 .51755 .51547 Mtetra
.953 .707 .527 r
.51755 .51547 .52115 .522 .52774 .45972 .52421 .45426 Mtetra
.962 .705 .5 r
.52421 .45426 .52774 .45972 .53403 .3721 .5306 .36772 Mtetra
.962 .718 .52 r
.5306 .36772 .53403 .3721 .54014 .31408 .53677 .31013 Mtetra
.149 .48 .898 r
.53677 .31013 .54014 .31408 .54646 .31699 .54309 .31265 Mtetra
.965 .641 .335 r
.54309 .31265 .54646 .31699 .55331 .37639 .54988 .37107 Mtetra
.969 .653 .349 r
.54988 .37107 .55331 .37639 .56063 .45447 .55712 .44813 Mtetra
.957 .617 .252 r
.55712 .44813 .56063 .45447 .56784 .49781 .56428 .49111 Mtetra
.917 .719 .62 r
.56428 .49111 .56784 .49781 .57425 .47421 .57073 .46808 Mtetra
.963 .707 .501 r
.57073 .46808 .57425 .47421 .57973 .39998 .5763 .39492 Mtetra
.967 .71 .493 r
.5763 .39492 .57973 .39998 .5849 .32429 .58157 .32005 Mtetra
.96 .738 .559 r
.58157 .32005 .5849 .32429 .59067 .29075 .58739 .28668 Mtetra
.916 .526 .126 r
.58739 .28668 .59067 .29075 .59765 .31426 .59434 .30965 Mtetra
.965 .636 .31 r
.59434 .30965 .59765 .31426 .60575 .37693 .60236 .37142 Mtetra
.964 .633 .29 r
.60236 .37142 .60575 .37693 .61405 .43665 .61058 .43041 Mtetra
.682 .285 0 r
.61058 .43041 .61405 .43665 .62128 .45101 .61781 .44473 Mtetra
.955 .719 .541 r
.61781 .44473 .62128 .45101 .62683 .40915 .62342 .40353 Mtetra
.969 .711 .489 r
.62342 .40353 .62683 .40915 .63131 .33982 .628 .33506 Mtetra
.97 .721 .503 r
.628 .33506 .63131 .33982 .63607 .28597 .63284 .28176 Mtetra
.892 .785 .735 r
.63284 .28176 .63607 .28597 .64227 .27564 .63906 .27141 Mtetra
.937 .571 .185 r
.63906 .27141 .64227 .27564 .65022 .30937 .64697 .30461 Mtetra
.957 .615 .254 r
.64697 .30461 .65022 .30937 .65914 .36207 .65582 .3566 Mtetra
.928 .563 .145 r
.65582 .3566 .65914 .36207 .6675 .39653 .66413 .39063 Mtetra
.834 .733 .752 r
.66413 .39063 .6675 .39653 .67403 .38777 .67068 .38201 Mtetra
.967 .722 .515 r
.67068 .38201 .67403 .38777 .67873 .34162 .67546 .33645 Mtetra
.973 .721 .493 r
.67546 .33645 .67873 .34162 .68289 .28821 .6797 .28367 Mtetra
.966 .747 .556 r
.6797 .28367 .68289 .28821 .68808 .25824 .68495 .254 Mtetra
0 .158 .685 r
.68495 .254 .68808 .25824 .69517 .26463 .69204 .26026 Mtetra
.924 .551 .138 r
.69204 .26026 .69517 .26463 .70386 .29792 .70068 .2931 Mtetra
.922 .552 .13 r
.70068 .2931 .70386 .29792 .71281 .33275 .70958 .32744 Mtetra
0 0 .487 r
.70958 .32744 .71281 .33275 .72046 .34351 .71721 .33802 Mtetra
.944 .751 .611 r
.71721 .33802 .72046 .34351 .72612 .32204 .72291 .31677 Mtetra
.972 .733 .515 r
.72291 .31677 .72612 .32204 .73052 .28255 .72738 .27772 Mtetra
.972 .743 .533 r
.72738 .27772 .73052 .28255 .73519 .24922 .73212 .24479 Mtetra
.892 .791 .743 r
.73212 .24479 .73519 .24922 .74138 .23915 .73834 .23484 Mtetra
.707 .273 0 r
.73834 .23484 .74138 .23915 .74933 .25338 .74627 .24889 Mtetra
.862 .464 0 r
.74627 .24889 .74933 .25338 .75815 .27805 .75505 .27322 Mtetra
.699 .28 0 r
.75505 .27322 .75815 .27805 .76641 .29363 .76328 .28853 Mtetra
.789 .754 .822 r
.76328 .28853 .76641 .29363 .77307 .28803 .76996 .28291 Mtetra
.961 .758 .584 r
.76996 .28291 .77307 .28803 .77827 .26446 .7752 .25956 Mtetra
.97 .756 .558 r
.7752 .25956 .77827 .26446 .78311 .23767 .7801 .23308 Mtetra
.939 .786 .664 r
.7801 .23308 .78311 .23767 .78886 .22256 .7859 .21816 Mtetra
.302 .548 .919 r
.7859 .21816 .78886 .22256 .7961 .22455 .79314 .22014 Mtetra
.613 .184 0 r
.79314 .22014 .7961 .22455 .80439 .23759 .80141 .23299 Mtetra
0 0 .467 r
.80141 .23299 .80439 .23759 .81261 .24899 .80961 .24419 Mtetra
.541 .665 .917 r
.80961 .24419 .81261 .24899 .81977 .24857 .81678 .24368 Mtetra
.92 .787 .697 r
.81678 .24368 .81977 .24857 .82575 .23583 .82279 .23102 Mtetra
.646 .721 .903 r
.2006 .43671 .20442 .44058 .20999 .43889 .20617 .43502 Mtetra
.857 .743 .736 r
.20617 .43502 .20999 .43889 .21633 .42908 .21252 .42533 Mtetra
.877 .741 .708 r
.21252 .42533 .21633 .42908 .22289 .41682 .21909 .4132 Mtetra
.804 .758 .811 r
.21909 .4132 .22289 .41682 .22881 .4113 .22502 .4077 Mtetra
.723 .226 0 r
.22502 .4077 .22881 .4113 .23362 .41809 .22984 .41435 Mtetra
.932 .559 .263 r
.22984 .41435 .23362 .41809 .23764 .43435 .23386 .43034 Mtetra
.927 .543 .224 r
.23386 .43034 .23764 .43435 .24183 .44945 .23806 .4452 Mtetra
.144 .462 .889 r
.23806 .4452 .24183 .44945 .24718 .45178 .2434 .4475 Mtetra
.882 .731 .689 r
.2434 .4475 .24718 .45178 .25393 .43747 .25016 .43338 Mtetra
.909 .724 .639 r
.25016 .43338 .25393 .43747 .26135 .41458 .25759 .41078 Mtetra
.898 .737 .674 r
.25759 .41078 .26135 .41458 .26819 .39834 .26444 .39469 Mtetra
.052 .44 .875 r
.26444 .39469 .26819 .39834 .27352 .40083 .26979 .39707 Mtetra
.944 .595 .322 r
.26979 .39707 .27352 .40083 .27741 .42272 .27368 .41857 Mtetra
.951 .622 .365 r
.27368 .41857 .27741 .42272 .2809 .45115 .27717 .44658 Mtetra
.923 .531 .174 r
.27717 .44658 .2809 .45115 .28546 .46647 .28173 .46171 Mtetra
.854 .728 .724 r
.28173 .46171 .28546 .46647 .29194 .45584 .28821 .45128 Mtetra
.921 .715 .608 r
.28821 .45128 .29194 .45584 .29985 .42428 .29613 .42016 Mtetra
.925 .719 .605 r
.29613 .42016 .29985 .42428 .30769 .39242 .30399 .38867 Mtetra
.87 .757 .735 r
.30399 .38867 .30769 .39242 .31401 .38237 .31032 .37862 Mtetra
.942 .582 .289 r
.31032 .37862 .31401 .38237 .31832 .40328 .31465 .3991 Mtetra
.955 .644 .4 r
.31465 .3991 .31832 .40328 .32146 .44455 .31778 .43972 Mtetra
.958 .636 .369 r
.31778 .43972 .32146 .44455 .32514 .47972 .32145 .47443 Mtetra
.145 .407 .853 r
.32145 .47443 .32514 .47972 .33085 .48271 .32715 .47751 Mtetra
.923 .712 .599 r
.32715 .47751 .33085 .48271 .33871 .44863 .33502 .44401 Mtetra
.936 .71 .57 r
.33502 .44401 .33871 .44863 .34728 .39962 .34362 .39564 Mtetra
.931 .725 .602 r
.34362 .39564 .34728 .39962 .35473 .36871 .3511 .36498 Mtetra
.776 .301 0 r
.3511 .36498 .35473 .36871 .36003 .37778 .35641 .37368 Mtetra
.957 .646 .397 r
.35641 .37368 .36003 .37778 .36352 .42444 .35989 .41952 Mtetra
.961 .657 .407 r
.35989 .41952 .36352 .42444 .36672 .48099 .36307 .47527 Mtetra
.955 .609 .277 r
.36307 .47527 .36672 .48099 .3715 .50833 .36782 .50241 Mtetra
.906 .712 .63 r
.36782 .50241 .3715 .50833 .37867 .48424 .375 .4789 Mtetra
.942 .706 .552 r
.375 .4789 .37867 .48424 .38732 .42374 .38368 .41932 Mtetra
.945 .711 .553 r
.38368 .41932 .38732 .42374 .39558 .36764 .39199 .36383 Mtetra
.908 .755 .679 r
.39199 .36383 .39558 .36764 .40207 .35276 .3985 .34882 Mtetra
.957 .629 .354 r
.3985 .34882 .40207 .35276 .40658 .39054 .40301 .38577 Mtetra
.963 .661 .409 r
.40301 .38577 .40658 .39054 .41013 .46037 .40652 .4545 Mtetra
.966 .656 .38 r
.40652 .4545 .41013 .46037 .4144 .51713 .41075 .51061 Mtetra
.372 .492 .851 r
.41075 .51061 .4144 .51713 .42062 .51882 .41696 .51262 Mtetra
.942 .705 .551 r
.41696 .51262 .42062 .51882 .4286 .46176 .42497 .45663 Mtetra
.952 .705 .529 r
.42497 .45663 .4286 .46176 .43692 .38503 .43335 .38091 Mtetra
.95 .72 .555 r
.43335 .38091 .43692 .38503 .44419 .33859 .44068 .33477 Mtetra
.841 .396 0 r
.44068 .33477 .44419 .33859 .44992 .35105 .44642 .34664 Mtetra
.964 .655 .388 r
.44642 .34664 .44992 .35105 .45457 .41641 .45103 .41082 Mtetra
.967 .663 .393 r
.45103 .41082 .45457 .41641 .45923 .49508 .45563 .48838 Mtetra
.961 .625 .278 r
.45563 .48838 .45923 .49508 .46495 .53272 .46131 .52581 Mtetra
.924 .708 .593 r
.46131 .52581 .46495 .53272 .47196 .49983 .46834 .49379 Mtetra
.954 .703 .519 r
.46834 .49379 .47196 .49983 .47954 .41881 .476 .41406 Mtetra
.958 .709 .517 r
.476 .41406 .47954 .41881 .48676 .34392 .48329 .33998 Mtetra
.941 .747 .613 r
.48329 .33998 .48676 .34392 .49318 .3203 .48975 .31626 Mtetra
.958 .622 .315 r
.48975 .31626 .49318 .3203 .49902 .36068 .49556 .35569 Mtetra
.968 .659 .378 r
.49556 .35569 .49902 .36068 .50479 .44092 .50125 .43464 Mtetra
.969 .654 .351 r
.50125 .43464 .50479 .44092 .51096 .50895 .50735 .50186 Mtetra
0 .178 .71 r
.50735 .50186 .51096 .50895 .51755 .51547 .51394 .50867 Mtetra
.951 .706 .529 r
.51394 .50867 .51755 .51547 .52421 .45426 .52066 .44864 Mtetra
.962 .705 .501 r
.52066 .44864 .52421 .45426 .5306 .36772 .52715 .36328 Mtetra
.962 .718 .521 r
.52715 .36328 .5306 .36772 .53677 .31013 .5334 .30618 Mtetra
.212 .521 .916 r
.5334 .30618 .53677 .31013 .54309 .31265 .53972 .30827 Mtetra
.965 .64 .333 r
.53972 .30827 .54309 .31265 .54988 .37107 .54644 .36561 Mtetra
.969 .653 .347 r
.54644 .36561 .54988 .37107 .55712 .44813 .55359 .44155 Mtetra
.957 .616 .247 r
.55359 .44155 .55712 .44813 .56428 .49111 .56071 .48414 Mtetra
.912 .715 .623 r
.56071 .48414 .56428 .49111 .57073 .46808 .56719 .46174 Mtetra
.962 .706 .502 r
.56719 .46174 .57073 .46808 .5763 .39492 .57286 .38974 Mtetra
.967 .71 .494 r
.57286 .38974 .5763 .39492 .58157 .32005 .57823 .31578 Mtetra
.96 .739 .559 r
.57823 .31578 .58157 .32005 .58739 .28668 .58409 .28259 Mtetra
.913 .521 .117 r
.58409 .28259 .58739 .28668 .59434 .30965 .59102 .30499 Mtetra
.964 .635 .308 r
.59102 .30499 .59434 .30965 .60236 .37142 .59896 .36577 Mtetra
.963 .632 .286 r
.59896 .36577 .60236 .37142 .61058 .43041 .6071 .42395 Mtetra
.666 .275 0 r
.6071 .42395 .61058 .43041 .61781 .44473 .61432 .43822 Mtetra
.953 .718 .544 r
.61432 .43822 .61781 .44473 .62342 .40353 .62 .39773 Mtetra
.968 .711 .49 r
.62 .39773 .62342 .40353 .628 .33506 .62468 .33022 Mtetra
.97 .721 .504 r
.62468 .33022 .628 .33506 .63284 .28176 .6296 .27753 Mtetra
.892 .784 .735 r
.6296 .27753 .63284 .28176 .63906 .27141 .63584 .26715 Mtetra
.936 .568 .18 r
.63584 .26715 .63906 .27141 .64697 .30461 .6437 .29977 Mtetra
.956 .614 .251 r
.6437 .29977 .64697 .30461 .65582 .3566 .65247 .351 Mtetra
.925 .56 .138 r
.65247 .351 .65582 .3566 .66413 .39063 .66074 .38455 Mtetra
.828 .727 .753 r
.66074 .38455 .66413 .39063 .67068 .38201 .66731 .37608 Mtetra
.966 .722 .517 r
.66731 .37608 .67068 .38201 .67546 .33645 .67217 .33116 Mtetra
.972 .721 .495 r
.67217 .33116 .67546 .33645 .6797 .28367 .67651 .27906 Mtetra
.965 .747 .558 r
.67651 .27906 .6797 .28367 .68495 .254 .6818 .24974 Mtetra
0 .17 .696 r
.6818 .24974 .68495 .254 .69204 .26026 .68889 .25586 Mtetra
.922 .548 .133 r
.68889 .25586 .69204 .26026 .70068 .2931 .69748 .2882 Mtetra
.92 .549 .124 r
.69748 .2882 .70068 .2931 .70958 .32744 .70633 .32202 Mtetra
0 0 .505 r
.70633 .32202 .70958 .32744 .71721 .33802 .71395 .33239 Mtetra
.942 .749 .613 r
.71395 .33239 .71721 .33802 .72291 .31677 .71969 .31138 Mtetra
.971 .732 .518 r
.71969 .31138 .72291 .31677 .72738 .27772 .72423 .27283 Mtetra
.971 .743 .536 r
.72423 .27283 .72738 .27772 .73212 .24479 .72903 .24033 Mtetra
.889 .791 .746 r
.72903 .24033 .73212 .24479 .73834 .23484 .73528 .23051 Mtetra
.701 .266 0 r
.73528 .23051 .73834 .23484 .74627 .24889 .74319 .24437 Mtetra
.858 .46 0 r
.74319 .24437 .74627 .24889 .75505 .27322 .75194 .26832 Mtetra
.687 .268 0 r
.75194 .26832 .75505 .27322 .76328 .28853 .76014 .28333 Mtetra
.788 .751 .82 r
.76014 .28333 .76328 .28853 .76996 .28291 .76683 .27769 Mtetra
.96 .757 .586 r
.76683 .27769 .76996 .28291 .7752 .25956 .77212 .25459 Mtetra
.969 .756 .561 r
.77212 .25459 .7752 .25956 .7801 .23308 .77708 .22844 Mtetra
.937 .786 .667 r
.77708 .22844 .7801 .23308 .7859 .21816 .78292 .21374 Mtetra
.303 .548 .919 r
.78292 .21374 .7859 .21816 .79314 .22014 .79017 .21571 Mtetra
.605 .176 0 r
.79017 .21571 .79314 .22014 .80141 .23299 .79842 .22836 Mtetra
0 0 .48 r
.79842 .22836 .80141 .23299 .80961 .24419 .8066 .23933 Mtetra
.548 .667 .915 r
.8066 .23933 .80961 .24419 .81678 .24368 .81377 .23873 Mtetra
.918 .786 .699 r
.81377 .23873 .81678 .24368 .82279 .23102 .81981 .22616 Mtetra
.645 .719 .902 r
.19677 .4328 .2006 .43671 .20617 .43502 .20234 .43112 Mtetra
.856 .742 .737 r
.20234 .43112 .20617 .43502 .21252 .42533 .2087 .42155 Mtetra
.876 .741 .71 r
.2087 .42155 .21252 .42533 .21909 .4132 .21527 .40956 Mtetra
.803 .758 .812 r
.21527 .40956 .21909 .4132 .22502 .4077 .2212 .40409 Mtetra
.709 .209 0 r
.2212 .40409 .22502 .4077 .22984 .41435 .22604 .41057 Mtetra
.931 .555 .257 r
.22604 .41057 .22984 .41435 .23386 .43034 .23007 .42627 Mtetra
.926 .539 .216 r
.23007 .42627 .23386 .43034 .23806 .4452 .23427 .44089 Mtetra
.157 .466 .89 r
.23427 .44089 .23806 .4452 .2434 .4475 .23962 .44314 Mtetra
.88 .73 .691 r
.23962 .44314 .2434 .4475 .25016 .43338 .24639 .42924 Mtetra
.908 .723 .64 r
.24639 .42924 .25016 .43338 .25759 .41078 .25382 .40695 Mtetra
.897 .737 .676 r
.25382 .40695 .25759 .41078 .26444 .39469 .26068 .39104 Mtetra
.08 .459 .886 r
.26068 .39104 .26444 .39469 .26979 .39707 .26604 .39328 Mtetra
.943 .593 .317 r
.26604 .39328 .26979 .39707 .27368 .41857 .26994 .41437 Mtetra
.951 .621 .361 r
.26994 .41437 .27368 .41857 .27717 .44658 .27343 .44192 Mtetra
.921 .528 .164 r
.27343 .44192 .27717 .44658 .28173 .46171 .27799 .45684 Mtetra
.85 .726 .725 r
.27799 .45684 .28173 .46171 .28821 .45128 .28447 .44662 Mtetra
.92 .715 .61 r
.28447 .44662 .28821 .45128 .29613 .42016 .2924 .416 Mtetra
.925 .719 .607 r
.2924 .416 .29613 .42016 .30399 .38867 .30028 .3849 Mtetra
.87 .756 .735 r
.30028 .3849 .30399 .38867 .31032 .37862 .30662 .37486 Mtetra
.94 .579 .283 r
.30662 .37486 .31032 .37862 .31465 .3991 .31096 .39487 Mtetra
.955 .643 .398 r
.31096 .39487 .31465 .3991 .31778 .43972 .31409 .43479 Mtetra
.958 .636 .365 r
.31409 .43479 .31778 .43972 .32145 .47443 .31775 .469 Mtetra
.143 .399 .847 r
.31775 .469 .32145 .47443 .32715 .47751 .32345 .47216 Mtetra
.921 .711 .601 r
.32345 .47216 .32715 .47751 .33502 .44401 .33132 .43929 Mtetra
.936 .71 .571 r
.33132 .43929 .33502 .44401 .34362 .39564 .33994 .39163 Mtetra
.931 .725 .603 r
.33994 .39163 .34362 .39564 .3511 .36498 .34745 .36123 Mtetra
.755 .275 0 r
.34745 .36123 .3511 .36498 .35641 .37368 .35278 .36954 Mtetra
.957 .645 .395 r
.35278 .36954 .35641 .37368 .35989 .41952 .35625 .41449 Mtetra
.961 .657 .405 r
.35625 .41449 .35989 .41952 .36307 .47527 .35941 .46937 Mtetra
.955 .608 .271 r
.35941 .46937 .36307 .47527 .36782 .50241 .36414 .49628 Mtetra
.903 .71 .632 r
.36414 .49628 .36782 .50241 .375 .4789 .37132 .4734 Mtetra
.941 .705 .553 r
.37132 .4734 .375 .4789 .38368 .41932 .38003 .41482 Mtetra
.945 .711 .554 r
.38003 .41482 .38368 .41932 .39199 .36383 .38838 .35999 Mtetra
.909 .755 .678 r
.38838 .35999 .39199 .36383 .3985 .34882 .39492 .34486 Mtetra
.956 .627 .35 r
.39492 .34486 .3985 .34882 .40301 .38577 .39943 .38092 Mtetra
.963 .661 .407 r
.39943 .38092 .40301 .38577 .40652 .4545 .40291 .44846 Mtetra
.966 .656 .377 r
.40291 .44846 .40652 .4545 .41075 .51061 .4071 .50385 Mtetra
.348 .47 .841 r
.4071 .50385 .41075 .51061 .41696 .51262 .4133 .5062 Mtetra
.94 .704 .553 r
.4133 .5062 .41696 .51262 .42497 .45663 .42134 .45136 Mtetra
.951 .705 .53 r
.42134 .45136 .42497 .45663 .43335 .38091 .42978 .37674 Mtetra
.95 .72 .556 r
.42978 .37674 .43335 .38091 .44068 .33477 .43715 .33094 Mtetra
.824 .373 0 r
.43715 .33094 .44068 .33477 .44642 .34664 .4429 .34218 Mtetra
.964 .654 .386 r
.4429 .34218 .44642 .34664 .45103 .41082 .44747 .40507 Mtetra
.967 .663 .391 r
.44747 .40507 .45103 .41082 .45563 .48838 .45201 .48144 Mtetra
.961 .625 .272 r
.45201 .48144 .45563 .48838 .46131 .52581 .45766 .51862 Mtetra
.92 .705 .596 r
.45766 .51862 .46131 .52581 .46834 .49379 .46471 .48754 Mtetra
.953 .703 .52 r
.46471 .48754 .46834 .49379 .476 .41406 .47244 .4092 Mtetra
.958 .709 .518 r
.47244 .4092 .476 .41406 .48329 .33998 .4798 .33602 Mtetra
.941 .747 .613 r
.4798 .33602 .48329 .33998 .48975 .31626 .4863 .31219 Mtetra
.958 .62 .311 r
.4863 .31219 .48975 .31626 .49556 .35569 .49208 .3506 Mtetra
.968 .659 .377 r
.49208 .3506 .49556 .35569 .50125 .43464 .49771 .42816 Mtetra
.969 .654 .348 r
.49771 .42816 .50125 .43464 .50735 .50186 .50374 .49449 Mtetra
0 .162 .698 r
.50374 .49449 .50735 .50186 .51394 .50867 .51031 .5016 Mtetra
.95 .705 .532 r
.51031 .5016 .51394 .50867 .52066 .44864 .5171 .44285 Mtetra
.961 .705 .502 r
.5171 .44285 .52066 .44864 .52715 .36328 .52369 .35878 Mtetra
.962 .718 .521 r
.52369 .35878 .52715 .36328 .5334 .30618 .53 .30221 Mtetra
.277 .56 .931 r
.53 .30221 .5334 .30618 .53972 .30827 .53633 .30385 Mtetra
.964 .639 .33 r
.53633 .30385 .53972 .30827 .54644 .36561 .54299 .36003 Mtetra
.969 .653 .345 r
.54299 .36003 .54644 .36561 .55359 .44155 .55005 .43475 Mtetra
.956 .616 .241 r
.55005 .43475 .55359 .44155 .56071 .48414 .55712 .47689 Mtetra
.907 .711 .627 r
.55712 .47689 .56071 .48414 .56719 .46174 .56364 .45516 Mtetra
.961 .706 .504 r
.56364 .45516 .56719 .46174 .57286 .38974 .56941 .38443 Mtetra
.966 .71 .495 r
.56941 .38443 .57286 .38974 .57823 .31578 .57488 .31147 Mtetra
.959 .739 .56 r
.57488 .31147 .57823 .31578 .58409 .28259 .58079 .27848 Mtetra
.909 .515 .108 r
.58079 .27848 .58409 .28259 .59102 .30499 .58768 .30026 Mtetra
.964 .634 .305 r
.58768 .30026 .59102 .30499 .59896 .36577 .59554 .35997 Mtetra
.963 .631 .283 r
.59554 .35997 .59896 .36577 .6071 .42395 .60361 .41728 Mtetra
.649 .264 0 r
.60361 .41728 .6071 .42395 .61432 .43822 .61081 .43148 Mtetra
.951 .716 .546 r
.61081 .43148 .61432 .43822 .62 .39773 .61656 .39177 Mtetra
.968 .71 .492 r
.61656 .39177 .62 .39773 .62468 .33022 .62135 .3253 Mtetra
.969 .721 .506 r
.62135 .3253 .62468 .33022 .6296 .27753 .62635 .27327 Mtetra
.892 .784 .735 r
.62635 .27327 .6296 .27753 .63584 .26715 .63261 .26287 Mtetra
.934 .565 .175 r
.63261 .26287 .63584 .26715 .6437 .29977 .64042 .29487 Mtetra
.956 .612 .247 r
.64042 .29487 .6437 .29977 .65247 .351 .64911 .34526 Mtetra
.923 .557 .131 r
.64911 .34526 .65247 .351 .66074 .38455 .65734 .37829 Mtetra
.822 .721 .753 r
.65734 .37829 .66074 .38455 .66731 .37608 .66393 .36998 Mtetra
.965 .721 .519 r
.66393 .36998 .66731 .37608 .67217 .33116 .66886 .32576 Mtetra
.972 .721 .497 r
.66886 .32576 .67217 .33116 .67651 .27906 .67329 .27441 Mtetra
.965 .748 .561 r
.67329 .27441 .67651 .27906 .6818 .24974 .67865 .24546 Mtetra
0 .184 .706 r
.67865 .24546 .6818 .24974 .68889 .25586 .68573 .25143 Mtetra
.921 .546 .128 r
.68573 .25143 .68889 .25586 .69748 .2882 .69427 .28324 Mtetra
.918 .546 .118 r
.69427 .28324 .69748 .2882 .70633 .32202 .70306 .31649 Mtetra
0 0 .525 r
.70306 .31649 .70633 .32202 .71395 .33239 .71066 .32663 Mtetra
.94 .747 .616 r
.71066 .32663 .71395 .33239 .71969 .31138 .71644 .30587 Mtetra
.97 .732 .52 r
.71644 .30587 .71969 .31138 .72423 .27283 .72107 .26787 Mtetra
.97 .743 .538 r
.72107 .26787 .72423 .27283 .72903 .24033 .72594 .23583 Mtetra
.887 .79 .749 r
.72594 .23583 .72903 .24033 .73528 .23051 .73221 .22617 Mtetra
.694 .258 0 r
.73221 .22617 .73528 .23051 .74319 .24437 .74011 .23981 Mtetra
.855 .455 0 r
.74011 .23981 .74319 .24437 .75194 .26832 .74881 .26335 Mtetra
.674 .256 0 r
.74881 .26335 .75194 .26832 .76014 .28333 .75699 .27804 Mtetra
.787 .748 .818 r
.75699 .27804 .76014 .28333 .76683 .27769 .76369 .27237 Mtetra
.958 .757 .589 r
.76369 .27237 .76683 .27769 .77212 .25459 .76903 .24954 Mtetra
.968 .756 .564 r
.76903 .24954 .77212 .25459 .77708 .22844 .77405 .22376 Mtetra
.935 .786 .671 r
.77405 .22376 .77708 .22844 .78292 .21374 .77993 .20929 Mtetra
.304 .548 .919 r
.77993 .20929 .78292 .21374 .79017 .21571 .78719 .21125 Mtetra
.595 .166 0 r
.78719 .21125 .79017 .21571 .79842 .22836 .79542 .22369 Mtetra
0 0 .495 r
.79542 .22369 .79842 .22836 .8066 .23933 .80358 .23441 Mtetra
.555 .668 .913 r
.80358 .23441 .8066 .23933 .81377 .23873 .81075 .23371 Mtetra
.916 .784 .7 r
.81075 .23371 .81377 .23873 .81981 .22616 .81682 .22124 Mtetra
.644 .717 .901 r
.19293 .42885 .19677 .4328 .20234 .43112 .19851 .42717 Mtetra
.854 .742 .739 r
.19851 .42717 .20234 .43112 .2087 .42155 .20486 .41773 Mtetra
.874 .741 .712 r
.20486 .41773 .2087 .42155 .21527 .40956 .21144 .4059 Mtetra
.802 .758 .813 r
.21144 .4059 .21527 .40956 .2212 .40409 .21738 .40046 Mtetra
.693 .191 0 r
.21738 .40046 .2212 .40409 .22604 .41057 .22222 .40677 Mtetra
.93 .551 .25 r
.22222 .40677 .22604 .41057 .23007 .42627 .22627 .42216 Mtetra
.924 .535 .207 r
.22627 .42216 .23007 .42627 .23427 .44089 .23048 .4365 Mtetra
.17 .471 .892 r
.23048 .4365 .23427 .44089 .23962 .44314 .23584 .43871 Mtetra
.878 .729 .693 r
.23584 .43871 .23962 .44314 .24639 .42924 .2426 .42504 Mtetra
.907 .723 .642 r
.2426 .42504 .24639 .42924 .25382 .40695 .25004 .40309 Mtetra
.896 .738 .677 r
.25004 .40309 .25382 .40695 .26068 .39104 .2569 .38736 Mtetra
.109 .477 .896 r
.2569 .38736 .26068 .39104 .26604 .39328 .26227 .38947 Mtetra
.943 .59 .312 r
.26227 .38947 .26604 .39328 .26994 .41437 .26618 .41012 Mtetra
.951 .62 .357 r
.26618 .41012 .26994 .41437 .27343 .44192 .26969 .43716 Mtetra
.918 .523 .154 r
.26969 .43716 .27343 .44192 .27799 .45684 .27425 .45186 Mtetra
.846 .723 .727 r
.27425 .45186 .27799 .45684 .28447 .44662 .28073 .44187 Mtetra
.918 .714 .611 r
.28073 .44187 .28447 .44662 .2924 .416 .28866 .41177 Mtetra
.924 .719 .608 r
.28866 .41177 .2924 .416 .30028 .3849 .29655 .38112 Mtetra
.87 .756 .735 r
.29655 .38112 .30028 .3849 .30662 .37486 .30291 .37107 Mtetra
.939 .575 .276 r
.30291 .37107 .30662 .37486 .31096 .39487 .30726 .39059 Mtetra
.955 .642 .395 r
.30726 .39059 .31096 .39487 .31409 .43479 .3104 .42975 Mtetra
.958 .635 .362 r
.3104 .42975 .31409 .43479 .31775 .469 .31405 .46342 Mtetra
.141 .391 .842 r
.31405 .46342 .31775 .469 .32345 .47216 .31974 .46667 Mtetra
.92 .71 .603 r
.31974 .46667 .32345 .47216 .33132 .43929 .32761 .43447 Mtetra
.935 .709 .572 r
.32761 .43447 .33132 .43929 .33994 .39163 .33625 .38757 Mtetra
.93 .725 .604 r
.33625 .38757 .33994 .39163 .34745 .36123 .34378 .35747 Mtetra
.73 .245 0 r
.34378 .35747 .34745 .36123 .35278 .36954 .34913 .36537 Mtetra
.957 .644 .392 r
.34913 .36537 .35278 .36954 .35625 .41449 .35261 .40936 Mtetra
.962 .656 .403 r
.35261 .40936 .35625 .41449 .35941 .46937 .35575 .4633 Mtetra
.955 .608 .265 r
.35575 .4633 .35941 .46937 .36414 .49628 .36047 .48996 Mtetra
.899 .708 .635 r
.36047 .48996 .36414 .49628 .37132 .4734 .36764 .46773 Mtetra
.94 .705 .555 r
.36764 .46773 .37132 .4734 .38003 .41482 .37637 .41025 Mtetra
.944 .711 .555 r
.37637 .41025 .38003 .41482 .38838 .35999 .38476 .35614 Mtetra
.909 .754 .677 r
.38476 .35614 .38838 .35999 .39492 .34486 .39133 .34089 Mtetra
.956 .625 .346 r
.39133 .34089 .39492 .34486 .39943 .38092 .39583 .37598 Mtetra
.963 .66 .405 r
.39583 .37598 .39943 .38092 .40291 .44846 .39929 .44223 Mtetra
.967 .656 .374 r
.39929 .44223 .40291 .44846 .4071 .50385 .40345 .49684 Mtetra
.323 .446 .831 r
.40345 .49684 .4071 .50385 .4133 .5062 .40963 .49954 Mtetra
.939 .703 .555 r
.40963 .49954 .4133 .5062 .42134 .45136 .41769 .44594 Mtetra
.95 .705 .531 r
.41769 .44594 .42134 .45136 .42978 .37674 .42619 .37253 Mtetra
.949 .72 .557 r
.42619 .37253 .42978 .37674 .43715 .33094 .43361 .3271 Mtetra
.803 .345 0 r
.43361 .3271 .43715 .33094 .4429 .34218 .43937 .33768 Mtetra
.964 .653 .384 r
.43937 .33768 .4429 .34218 .44747 .40507 .44391 .39918 Mtetra
.968 .663 .389 r
.44391 .39918 .44747 .40507 .45201 .48144 .44839 .47426 Mtetra
.96 .624 .267 r
.44839 .47426 .45201 .48144 .45766 .51862 .454 .51115 Mtetra
.916 .703 .599 r
.454 .51115 .45766 .51862 .46471 .48754 .46107 .48107 Mtetra
.952 .702 .522 r
.46107 .48107 .46471 .48754 .47244 .4092 .46886 .40424 Mtetra
.957 .709 .519 r
.46886 .40424 .47244 .4092 .4798 .33602 .4763 .33203 Mtetra
.941 .746 .612 r
.4763 .33203 .4798 .33602 .4863 .31219 .48283 .30811 Mtetra
.957 .617 .306 r
.48283 .30811 .4863 .31219 .49208 .3506 .48859 .34543 Mtetra
.968 .658 .375 r
.48859 .34543 .49208 .3506 .49771 .42816 .49415 .42148 Mtetra
.97 .654 .345 r
.49415 .42148 .49771 .42816 .50374 .49449 .50011 .48685 Mtetra
0 .146 .686 r
.50011 .48685 .50374 .49449 .51031 .5016 .50668 .49427 Mtetra
.948 .703 .534 r
.50668 .49427 .51031 .5016 .5171 .44285 .51353 .43688 Mtetra
.96 .704 .504 r
.51353 .43688 .5171 .44285 .52369 .35878 .52021 .35421 Mtetra
.961 .718 .522 r
.52021 .35421 .52369 .35878 .53 .30221 .5266 .29823 Mtetra
.341 .597 .941 r
.5266 .29823 .53 .30221 .53633 .30385 .53292 .2994 Mtetra
.964 .637 .327 r
.53292 .2994 .53633 .30385 .54299 .36003 .53953 .35432 Mtetra
.969 .652 .343 r
.53953 .35432 .54299 .36003 .55005 .43475 .5465 .42773 Mtetra
.955 .615 .235 r
.5465 .42773 .55005 .43475 .55712 .47689 .55353 .46939 Mtetra
.901 .707 .631 r
.55353 .46939 .55712 .47689 .56364 .45516 .56008 .44837 Mtetra
.96 .705 .506 r
.56008 .44837 .56364 .45516 .56941 .38443 .56594 .379 Mtetra
.966 .71 .497 r
.56594 .379 .56941 .38443 .57488 .31147 .57151 .30711 Mtetra
.959 .739 .561 r
.57151 .30711 .57488 .31147 .58079 .27848 .57746 .27435 Mtetra
.905 .508 .097 r
.57746 .27435 .58079 .27848 .58768 .30026 .58433 .29548 Mtetra
.964 .633 .303 r
.58433 .29548 .58768 .30026 .59554 .35997 .59211 .35404 Mtetra
.963 .63 .279 r
.59211 .35404 .59554 .35997 .60361 .41728 .6001 .4104 Mtetra
.631 .253 0 r
.6001 .4104 .60361 .41728 .61081 .43148 .60729 .42452 Mtetra
.949 .715 .55 r
.60729 .42452 .61081 .43148 .61656 .39177 .61311 .38564 Mtetra
.967 .71 .494 r
.61311 .38564 .61656 .39177 .62135 .3253 .618 .32029 Mtetra
.969 .721 .507 r
.618 .32029 .62135 .3253 .62635 .27327 .62308 .26898 Mtetra
.892 .784 .735 r
.62308 .26898 .62635 .27327 .63261 .26287 .62936 .25857 Mtetra
.933 .562 .17 r
.62936 .25857 .63261 .26287 .64042 .29487 .63712 .28991 Mtetra
.955 .611 .244 r
.63712 .28991 .64042 .29487 .64911 .34526 .64574 .33938 Mtetra
.92 .554 .122 r
.64574 .33938 .64911 .34526 .65734 .37829 .65391 .37186 Mtetra
.816 .715 .753 r
.65391 .37186 .65734 .37829 .66393 .36998 .66052 .36371 Mtetra
.963 .72 .522 r
.66052 .36371 .66393 .36998 .66886 .32576 .66554 .32024 Mtetra
.971 .721 .499 r
.66554 .32024 .66886 .32576 .67329 .27441 .67006 .2697 Mtetra
.964 .748 .563 r
.67006 .2697 .67329 .27441 .67865 .24546 .67547 .24116 Mtetra
0 .198 .718 r
.67547 .24116 .67865 .24546 .68573 .25143 .68255 .24697 Mtetra
.919 .542 .123 r
.68255 .24697 .68573 .25143 .69427 .28324 .69104 .27821 Mtetra
.915 .543 .112 r
.69104 .27821 .69427 .28324 .70306 .31649 .69977 .31084 Mtetra
0 0 .545 r
.69977 .31084 .70306 .31649 .71066 .32663 .70736 .32073 Mtetra
.937 .745 .618 r
.70736 .32073 .71066 .32663 .71644 .30587 .71318 .30025 Mtetra
.969 .732 .523 r
.71318 .30025 .71644 .30587 .72107 .26787 .71788 .26283 Mtetra
.97 .744 .541 r
.71788 .26283 .72107 .26787 .72594 .23583 .72282 .23131 Mtetra
.884 .79 .752 r
.72282 .23131 .72594 .23583 .73221 .22617 .72913 .2218 Mtetra
.686 .25 0 r
.72913 .2218 .73221 .22617 .74011 .23981 .737 .23522 Mtetra
.85 .449 0 r
.737 .23522 .74011 .23981 .74881 .26335 .74567 .25832 Mtetra
.658 .242 0 r
.74567 .25832 .74881 .26335 .75699 .27804 .75381 .27266 Mtetra
.786 .745 .816 r
.75381 .27266 .75699 .27804 .76369 .27237 .76052 .26697 Mtetra
.956 .756 .592 r
.76052 .26697 .76369 .27237 .76903 .24954 .76591 .24443 Mtetra
.967 .756 .567 r
.76591 .24443 .76903 .24954 .77405 .22376 .771 .21905 Mtetra
.933 .786 .674 r
.771 .21905 .77405 .22376 .77993 .20929 .77692 .20483 Mtetra
.305 .549 .919 r
.77692 .20483 .77993 .20929 .78719 .21125 .78419 .20677 Mtetra
0 0 .396 r
.78419 .20677 .78719 .21125 .79542 .22369 .7924 .21899 Mtetra
0 0 .51 r
.7924 .21899 .79542 .22369 .80358 .23441 .80054 .22944 Mtetra
.562 .67 .911 r
.80054 .22944 .80358 .23441 .81075 .23371 .80771 .22863 Mtetra
.914 .783 .702 r
.80771 .22863 .81075 .23371 .81682 .22124 .81381 .21626 Mtetra
.643 .716 .901 r
.18907 .42486 .19293 .42885 .19851 .42717 .19465 .42318 Mtetra
.852 .741 .741 r
.19465 .42318 .19851 .42717 .20486 .41773 .20101 .41389 Mtetra
.873 .741 .714 r
.20101 .41389 .20486 .41773 .21144 .4059 .20759 .40223 Mtetra
.801 .758 .814 r
.20759 .40223 .21144 .4059 .21738 .40046 .21354 .39682 Mtetra
.675 .171 0 r
.21354 .39682 .21738 .40046 .22222 .40677 .21839 .40295 Mtetra
.928 .547 .241 r
.21839 .40295 .22222 .40677 .22627 .42216 .22246 .418 Mtetra
.922 .53 .197 r
.22246 .418 .22627 .42216 .23048 .4365 .22668 .43205 Mtetra
.182 .475 .893 r
.22668 .43205 .23048 .4365 .23584 .43871 .23204 .43422 Mtetra
.876 .728 .695 r
.23204 .43422 .23584 .43871 .2426 .42504 .2388 .42079 Mtetra
.906 .723 .644 r
.2388 .42079 .2426 .42504 .25004 .40309 .24624 .39921 Mtetra
.895 .738 .679 r
.24624 .39921 .25004 .40309 .2569 .38736 .25311 .38368 Mtetra
.139 .496 .906 r
.25311 .38368 .2569 .38736 .26227 .38947 .25849 .38564 Mtetra
.942 .587 .306 r
.25849 .38564 .26227 .38947 .26618 .41012 .26242 .40582 Mtetra
.951 .618 .353 r
.26242 .40582 .26618 .41012 .26969 .43716 .26594 .43233 Mtetra
.916 .519 .143 r
.26594 .43233 .26969 .43716 .27425 .45186 .2705 .44679 Mtetra
.843 .721 .729 r
.2705 .44679 .27425 .45186 .28073 .44187 .27698 .43704 Mtetra
.917 .714 .613 r
.27698 .43704 .28073 .44187 .28866 .41177 .28491 .4075 Mtetra
.923 .719 .609 r
.28491 .4075 .28866 .41177 .29655 .38112 .2928 .37731 Mtetra
.869 .756 .735 r
.2928 .37731 .29655 .38112 .30291 .37107 .29918 .36728 Mtetra
.938 .57 .268 r
.29918 .36728 .30291 .37107 .30726 .39059 .30355 .38627 Mtetra
.955 .641 .392 r
.30355 .38627 .30726 .39059 .3104 .42975 .30669 .42462 Mtetra
.959 .634 .358 r
.30669 .42462 .3104 .42975 .31405 .46342 .31035 .45771 Mtetra
.137 .382 .836 r
.31035 .45771 .31405 .46342 .31974 .46667 .31603 .46105 Mtetra
.918 .709 .605 r
.31603 .46105 .31974 .46667 .32761 .43447 .3239 .42957 Mtetra
.934 .709 .574 r
.3239 .42957 .32761 .43447 .33625 .38757 .33255 .38348 Mtetra
.93 .725 .605 r
.33255 .38348 .33625 .38757 .34378 .35747 .3401 .35369 Mtetra
.699 .209 0 r
.3401 .35369 .34378 .35747 .34913 .36537 .34547 .36116 Mtetra
.957 .643 .39 r
.34547 .36116 .34913 .36537 .35261 .40936 .34895 .40414 Mtetra
.962 .656 .401 r
.34895 .40414 .35261 .40936 .35575 .4633 .35208 .45708 Mtetra
.954 .607 .259 r
.35208 .45708 .35575 .4633 .36047 .48996 .35678 .48346 Mtetra
.895 .706 .638 r
.35678 .48346 .36047 .48996 .36764 .46773 .36395 .46193 Mtetra
.939 .704 .556 r
.36395 .46193 .36764 .46773 .37637 .41025 .3727 .4056 Mtetra
.944 .711 .556 r
.3727 .4056 .37637 .41025 .38476 .35614 .38113 .35226 Mtetra
.909 .754 .677 r
.38113 .35226 .38476 .35614 .39133 .34089 .38772 .33689 Mtetra
.956 .623 .341 r
.38772 .33689 .39133 .34089 .39583 .37598 .39223 .37098 Mtetra
.963 .66 .403 r
.39223 .37098 .39583 .37598 .39929 .44223 .39567 .43586 Mtetra
.967 .656 .371 r
.39567 .43586 .39929 .44223 .40345 .49684 .39979 .48963 Mtetra
.295 .423 .821 r
.39979 .48963 .40345 .49684 .40963 .49954 .40596 .49269 Mtetra
.937 .702 .557 r
.40596 .49269 .40963 .49954 .41769 .44594 .41404 .4404 Mtetra
.95 .704 .532 r
.41404 .4404 .41769 .44594 .42619 .37253 .42259 .36826 Mtetra
.949 .72 .558 r
.42259 .36826 .42619 .37253 .43361 .3271 .43006 .32325 Mtetra
.777 .311 0 r
.43006 .32325 .43361 .3271 .43937 .33768 .43583 .33313 Mtetra
.964 .652 .382 r
.43583 .33313 .43937 .33768 .44391 .39918 .44034 .39318 Mtetra
.968 .662 .387 r
.44034 .39318 .44391 .39918 .44839 .47426 .44477 .46687 Mtetra
.96 .624 .262 r
.44477 .46687 .44839 .47426 .454 .51115 .45035 .50346 Mtetra
.912 .7 .603 r
.45035 .50346 .454 .51115 .46107 .48107 .45743 .47442 Mtetra
.951 .702 .523 r
.45743 .47442 .46107 .48107 .46886 .40424 .46528 .39918 Mtetra
.957 .708 .52 r
.46528 .39918 .46886 .40424 .4763 .33203 .47279 .32801 Mtetra
.941 .746 .612 r
.47279 .32801 .4763 .33203 .48283 .30811 .47935 .30401 Mtetra
.956 .614 .301 r
.47935 .30401 .48283 .30811 .48859 .34543 .48509 .34018 Mtetra
.968 .657 .373 r
.48509 .34018 .48859 .34543 .49415 .42148 .49058 .41464 Mtetra
.97 .654 .342 r
.49058 .41464 .49415 .42148 .50011 .48685 .49649 .47897 Mtetra
0 .128 .673 r
.49649 .47897 .50011 .48685 .50668 .49427 .50305 .48671 Mtetra
.947 .702 .536 r
.50305 .48671 .50668 .49427 .51353 .43688 .50995 .43075 Mtetra
.96 .704 .505 r
.50995 .43075 .51353 .43688 .52021 .35421 .51672 .34958 Mtetra
.961 .718 .524 r
.51672 .34958 .52021 .35421 .5266 .29823 .52317 .29423 Mtetra
.402 .63 .947 r
.52317 .29423 .5266 .29823 .53292 .2994 .52951 .29491 Mtetra
.964 .636 .324 r
.52951 .29491 .53292 .2994 .53953 .35432 .53605 .34851 Mtetra
.969 .652 .34 r
.53605 .34851 .53953 .35432 .5465 .42773 .54295 .42053 Mtetra
.954 .613 .23 r
.54295 .42053 .5465 .42773 .55353 .46939 .54992 .46165 Mtetra
.896 .704 .635 r
.54992 .46165 .55353 .46939 .56008 .44837 .5565 .44138 Mtetra
.959 .705 .508 r
.5565 .44138 .56008 .44837 .56594 .379 .56246 .37344 Mtetra
.965 .71 .498 r
.56246 .37344 .56594 .379 .57151 .30711 .56812 .30271 Mtetra
.959 .739 .563 r
.56812 .30271 .57151 .30711 .57746 .27435 .57412 .27022 Mtetra
.9 .5 .084 r
.57412 .27022 .57746 .27435 .58433 .29548 .58097 .29066 Mtetra
.963 .632 .3 r
.58097 .29066 .58433 .29548 .59211 .35404 .58866 .34799 Mtetra
.962 .629 .276 r
.58866 .34799 .59211 .35404 .6001 .4104 .59658 .40334 Mtetra
0 0 .334 r
.59658 .40334 .6001 .4104 .60729 .42452 .60376 .41737 Mtetra
.947 .714 .553 r
.60376 .41737 .60729 .42452 .61311 .38564 .60964 .37936 Mtetra
.966 .71 .496 r
.60964 .37936 .61311 .38564 .618 .32029 .61463 .3152 Mtetra
.968 .721 .509 r
.61463 .3152 .618 .32029 .62308 .26898 .6198 .26467 Mtetra
.892 .783 .735 r
.6198 .26467 .62308 .26898 .62936 .25857 .6261 .25425 Mtetra
.931 .559 .164 r
.6261 .25425 .62936 .25857 .63712 .28991 .63381 .28489 Mtetra
.954 .609 .24 r
.63381 .28489 .63712 .28991 .64574 .33938 .64235 .3334 Mtetra
.917 .55 .114 r
.64235 .3334 .64574 .33938 .65391 .37186 .65047 .36527 Mtetra
.811 .709 .753 r
.65047 .36527 .65391 .37186 .66052 .36371 .6571 .3573 Mtetra
.962 .72 .525 r
.6571 .3573 .66052 .36371 .66554 .32024 .6622 .31462 Mtetra
.97 .721 .501 r
.6622 .31462 .66554 .32024 .67006 .2697 .66682 .26494 Mtetra
.963 .748 .565 r
.66682 .26494 .67006 .2697 .67547 .24116 .67229 .23683 Mtetra
0 .213 .729 r
.67229 .23683 .67547 .24116 .68255 .24697 .67936 .24249 Mtetra
.916 .539 .117 r
.67936 .24249 .68255 .24697 .69104 .27821 .68779 .27311 Mtetra
.913 .539 .104 r
.68779 .27311 .69104 .27821 .69977 .31084 .69647 .30509 Mtetra
0 0 .565 r
.69647 .30509 .69977 .31084 .70736 .32073 .70403 .31472 Mtetra
.935 .744 .621 r
.70403 .31472 .70736 .32073 .71318 .30025 .7099 .29453 Mtetra
.968 .732 .526 r
.7099 .29453 .71318 .30025 .71788 .26283 .71468 .25773 Mtetra
.969 .744 .544 r
.71468 .25773 .71788 .26283 .72282 .23131 .7197 .22675 Mtetra
.881 .789 .755 r
.7197 .22675 .72282 .23131 .72913 .2218 .72603 .21742 Mtetra
.677 .241 0 r
.72603 .21742 .72913 .2218 .737 .23522 .73389 .23059 Mtetra
.845 .443 0 r
.73389 .23059 .737 .23522 .74567 .25832 .74251 .25323 Mtetra
.642 .227 0 r
.74251 .25323 .74567 .25832 .75381 .27266 .75062 .2672 Mtetra
.785 .742 .814 r
.75062 .2672 .75381 .27266 .76052 .26697 .75734 .26148 Mtetra
.955 .755 .595 r
.75734 .26148 .76052 .26697 .76591 .24443 .76279 .23925 Mtetra
.965 .756 .57 r
.76279 .23925 .76591 .24443 .771 .21905 .76794 .21429 Mtetra
.931 .786 .678 r
.76794 .21429 .771 .21905 .77692 .20483 .7739 .20035 Mtetra
.305 .549 .919 r
.7739 .20035 .77692 .20483 .78419 .20677 .78118 .20228 Mtetra
0 0 .408 r
.78118 .20228 .78419 .20677 .7924 .21899 .78937 .21424 Mtetra
0 0 .526 r
.78937 .21424 .7924 .21899 .80054 .22944 .79748 .22442 Mtetra
.57 .672 .908 r
.79748 .22442 .80054 .22944 .80771 .22863 .80465 .22349 Mtetra
.912 .782 .704 r
.80465 .22349 .80771 .22863 .81381 .21626 .81078 .21124 Mtetra
.642 .714 .9 r
.1852 .42083 .18907 .42486 .19465 .42318 .19079 .41916 Mtetra
.85 .741 .743 r
.19079 .41916 .19465 .42318 .20101 .41389 .19715 .41002 Mtetra
.872 .741 .715 r
.19715 .41002 .20101 .41389 .20759 .40223 .20373 .39853 Mtetra
.799 .758 .815 r
.20373 .39853 .20759 .40223 .21354 .39682 .20968 .39317 Mtetra
.655 .148 0 r
.20968 .39317 .21354 .39682 .21839 .40295 .21455 .3991 Mtetra
.926 .542 .232 r
.21455 .3991 .21839 .40295 .22246 .418 .21863 .41379 Mtetra
.92 .525 .186 r
.21863 .41379 .22246 .418 .22668 .43205 .22287 .42753 Mtetra
.195 .48 .894 r
.22287 .42753 .22668 .43205 .23204 .43422 .22823 .42966 Mtetra
.874 .727 .697 r
.22823 .42966 .23204 .43422 .2388 .42079 .23499 .41649 Mtetra
.905 .723 .645 r
.23499 .41649 .2388 .42079 .24624 .39921 .24243 .39529 Mtetra
.894 .738 .68 r
.24243 .39529 .24624 .39921 .25311 .38368 .2493 .37997 Mtetra
.17 .515 .915 r
.2493 .37997 .25311 .38368 .25849 .38564 .2547 .38178 Mtetra
.941 .584 .3 r
.2547 .38178 .25849 .38564 .26242 .40582 .25865 .40148 Mtetra
.951 .617 .348 r
.25865 .40148 .26242 .40582 .26594 .43233 .26218 .42742 Mtetra
.912 .513 .131 r
.26218 .42742 .26594 .43233 .2705 .44679 .26675 .44161 Mtetra
.839 .719 .732 r
.26675 .44161 .2705 .44679 .27698 .43704 .27322 .43211 Mtetra
.916 .714 .615 r
.27322 .43211 .27698 .43704 .28491 .4075 .28114 .40316 Mtetra
.922 .719 .611 r
.28114 .40316 .28491 .4075 .2928 .37731 .28904 .37347 Mtetra
.869 .756 .736 r
.28904 .37347 .2928 .37731 .29918 .36728 .29544 .36346 Mtetra
.936 .566 .259 r
.29544 .36346 .29918 .36728 .30355 .38627 .29982 .3819 Mtetra
.956 .64 .389 r
.29982 .3819 .30355 .38627 .30669 .42462 .30299 .4194 Mtetra
.959 .633 .354 r
.30299 .4194 .30669 .42462 .31035 .45771 .30664 .45188 Mtetra
.134 .374 .831 r
.30664 .45188 .31035 .45771 .31603 .46105 .31231 .4553 Mtetra
.916 .708 .607 r
.31231 .4553 .31603 .46105 .3239 .42957 .32017 .42456 Mtetra
.933 .709 .575 r
.32017 .42456 .3239 .42957 .33255 .38348 .32883 .37934 Mtetra
.929 .725 .606 r
.32883 .37934 .33255 .38348 .3401 .35369 .33641 .34991 Mtetra
.663 .169 0 r
.33641 .34991 .3401 .35369 .34547 .36116 .3418 .35692 Mtetra
.957 .642 .387 r
.3418 .35692 .34547 .36116 .34895 .40414 .34529 .39884 Mtetra
.962 .655 .398 r
.34529 .39884 .34895 .40414 .35208 .45708 .34842 .45071 Mtetra
.954 .605 .253 r
.34842 .45071 .35208 .45708 .35678 .48346 .3531 .47678 Mtetra
.891 .703 .641 r
.3531 .47678 .35678 .48346 .36395 .46193 .36026 .45597 Mtetra
.938 .704 .558 r
.36026 .45597 .36395 .46193 .3727 .4056 .36902 .40086 Mtetra
.943 .711 .557 r
.36902 .40086 .3727 .4056 .38113 .35226 .37747 .34836 Mtetra
.909 .753 .676 r
.37747 .34836 .38113 .35226 .38772 .33689 .3841 .33288 Mtetra
.955 .62 .336 r
.3841 .33288 .38772 .33689 .39223 .37098 .38862 .36591 Mtetra
.963 .659 .401 r
.38862 .36591 .39223 .37098 .39567 .43586 .39204 .42934 Mtetra
.968 .655 .368 r
.39204 .42934 .39567 .43586 .39979 .48963 .39614 .48221 Mtetra
.267 .399 .811 r
.39614 .48221 .39979 .48963 .40596 .49269 .40229 .48563 Mtetra
.936 .701 .559 r
.40229 .48563 .40596 .49269 .41404 .4404 .41039 .43471 Mtetra
.949 .704 .533 r
.41039 .43471 .41404 .4404 .42259 .36826 .41897 .36394 Mtetra
.949 .72 .558 r
.41897 .36394 .42259 .36826 .43006 .32325 .42648 .31939 Mtetra
.744 .27 0 r
.42648 .31939 .43006 .32325 .43583 .33313 .43227 .32855 Mtetra
.964 .651 .379 r
.43227 .32855 .43583 .33313 .44034 .39318 .43676 .38706 Mtetra
.968 .662 .384 r
.43676 .38706 .44034 .39318 .44477 .46687 .44115 .45928 Mtetra
.959 .623 .256 r
.44115 .45928 .44477 .46687 .45035 .50346 .44669 .49551 Mtetra
.908 .698 .607 r
.44669 .49551 .45035 .50346 .45743 .47442 .45378 .46756 Mtetra
.95 .701 .525 r
.45378 .46756 .45743 .47442 .46528 .39918 .46168 .39401 Mtetra
.956 .708 .521 r
.46168 .39401 .46528 .39918 .47279 .32801 .46926 .32397 Mtetra
.941 .746 .612 r
.46926 .32397 .47279 .32801 .47935 .30401 .47586 .29989 Mtetra
.955 .611 .295 r
.47586 .29989 .47935 .30401 .48509 .34018 .48158 .33487 Mtetra
.968 .657 .37 r
.48158 .33487 .48509 .34018 .49058 .41464 .48701 .40763 Mtetra
.97 .654 .339 r
.48701 .40763 .49058 .41464 .49649 .47897 .49286 .47085 Mtetra
0 .112 .661 r
.49286 .47085 .49649 .47897 .50305 .48671 .4994 .4789 Mtetra
.945 .701 .539 r
.4994 .4789 .50305 .48671 .50995 .43075 .50636 .42445 Mtetra
.959 .704 .507 r
.50636 .42445 .50995 .43075 .51672 .34958 .51322 .34487 Mtetra
.961 .718 .525 r
.51322 .34487 .51672 .34958 .52317 .29423 .51974 .29021 Mtetra
.459 .659 .948 r
.51974 .29021 .52317 .29423 .52951 .29491 .52608 .29039 Mtetra
.963 .634 .321 r
.52608 .29039 .52951 .29491 .53605 .34851 .53257 .34261 Mtetra
.969 .651 .338 r
.53257 .34261 .53605 .34851 .54295 .42053 .53938 .41314 Mtetra
.953 .612 .223 r
.53938 .41314 .54295 .42053 .54992 .46165 .54631 .45368 Mtetra
.89 .7 .639 r
.54631 .45368 .54992 .46165 .5565 .44138 .55292 .43417 Mtetra
.958 .704 .51 r
.55292 .43417 .5565 .44138 .56246 .37344 .55897 .36776 Mtetra
.965 .71 .5 r
.55897 .36776 .56246 .37344 .56812 .30271 .56472 .29827 Mtetra
.958 .739 .564 r
.56472 .29827 .56812 .30271 .57412 .27022 .57077 .26606 Mtetra
.894 .491 .07 r
.57077 .26606 .57412 .27022 .58097 .29066 .57759 .28579 Mtetra
.963 .631 .296 r
.57759 .28579 .58097 .29066 .58866 .34799 .58521 .34183 Mtetra
.962 .628 .271 r
.58521 .34183 .58866 .34799 .59658 .40334 .59305 .3961 Mtetra
0 0 .35 r
.59305 .3961 .59658 .40334 .60376 .41737 .60021 .41001 Mtetra
.945 .712 .556 r
.60021 .41001 .60376 .41737 .60964 .37936 .60615 .37292 Mtetra
.965 .71 .498 r
.60615 .37292 .60964 .37936 .61463 .3152 .61126 .31003 Mtetra
.968 .722 .511 r
.61126 .31003 .61463 .3152 .6198 .26467 .61651 .26032 Mtetra
.891 .783 .735 r
.61651 .26032 .6198 .26467 .6261 .25425 .62282 .24991 Mtetra
.929 .555 .157 r
.62282 .24991 .6261 .25425 .63381 .28489 .63049 .27981 Mtetra
.953 .607 .236 r
.63049 .27981 .63381 .28489 .64235 .3334 .63895 .3273 Mtetra
.913 .546 .105 r
.63895 .3273 .64235 .3334 .65047 .36527 .64702 .35853 Mtetra
.805 .704 .754 r
.64702 .35853 .65047 .36527 .6571 .3573 .65366 .35073 Mtetra
.961 .719 .527 r
.65366 .35073 .6571 .3573 .6622 .31462 .65885 .30888 Mtetra
.969 .721 .504 r
.65885 .30888 .6622 .31462 .66682 .26494 .66356 .26012 Mtetra
.962 .748 .568 r
.66356 .26012 .66682 .26494 .67229 .23683 .66909 .23249 Mtetra
0 .228 .741 r
.66909 .23249 .67229 .23683 .67936 .24249 .67615 .23798 Mtetra
.914 .535 .111 r
.67615 .23798 .67936 .24249 .68779 .27311 .68453 .26796 Mtetra
.91 .535 .097 r
.68453 .26796 .68779 .27311 .69647 .30509 .69315 .29924 Mtetra
0 .018 .585 r
.69315 .29924 .69647 .30509 .70403 .31472 .7007 .30859 Mtetra
.932 .742 .623 r
.7007 .30859 .70403 .31472 .7099 .29453 .70661 .2887 Mtetra
.967 .731 .529 r
.70661 .2887 .7099 .29453 .71468 .25773 .71147 .25256 Mtetra
.968 .744 .547 r
.71147 .25256 .71468 .25773 .7197 .22675 .71656 .22216 Mtetra
.877 .789 .759 r
.71656 .22216 .7197 .22675 .72603 .21742 .72292 .21302 Mtetra
.668 .231 0 r
.72292 .21302 .72603 .21742 .73389 .23059 .73076 .22594 Mtetra
.84 .436 0 r
.73076 .22594 .73389 .23059 .74251 .25323 .73933 .24808 Mtetra
.624 .21 0 r
.73933 .24808 .74251 .25323 .75062 .2672 .74741 .26166 Mtetra
.784 .74 .812 r
.74741 .26166 .75062 .2672 .75734 .26148 .75415 .25591 Mtetra
.953 .755 .598 r
.75415 .25591 .75734 .26148 .76279 .23925 .75964 .23401 Mtetra
.964 .756 .574 r
.75964 .23401 .76279 .23925 .76794 .21429 .76486 .2095 Mtetra
.928 .786 .683 r
.76486 .2095 .76794 .21429 .7739 .20035 .77087 .19584 Mtetra
.306 .55 .919 r
.77087 .19584 .7739 .20035 .78118 .20228 .77815 .19776 Mtetra
0 0 .421 r
.77815 .19776 .78118 .20228 .78937 .21424 .78632 .20946 Mtetra
0 0 .544 r
.78632 .20946 .78937 .21424 .79748 .22442 .79441 .21934 Mtetra
.577 .674 .906 r
.79441 .21934 .79748 .22442 .80465 .22349 .80158 .21829 Mtetra
.91 .781 .706 r
.80158 .21829 .80465 .22349 .81078 .21124 .80774 .20617 Mtetra
.642 .713 .899 r
.18132 .41677 .1852 .42083 .19079 .41916 .18691 .4151 Mtetra
.848 .74 .745 r
.18691 .4151 .19079 .41916 .19715 .41002 .19327 .40611 Mtetra
.87 .741 .718 r
.19327 .40611 .19715 .41002 .20373 .39853 .19985 .39482 Mtetra
.798 .758 .816 r
.19985 .39482 .20373 .39853 .20968 .39317 .20581 .38949 Mtetra
.632 .123 0 r
.20581 .38949 .20968 .39317 .21455 .3991 .2107 .39523 Mtetra
.924 .537 .222 r
.2107 .39523 .21455 .3991 .21863 .41379 .2148 .40954 Mtetra
.917 .519 .174 r
.2148 .40954 .21863 .41379 .22287 .42753 .21905 .42296 Mtetra
.209 .485 .896 r
.21905 .42296 .22287 .42753 .22823 .42966 .22442 .42503 Mtetra
.871 .726 .699 r
.22442 .42503 .22823 .42966 .23499 .41649 .23117 .41213 Mtetra
.904 .723 .647 r
.23117 .41213 .23499 .41649 .24243 .39529 .2386 .39133 Mtetra
.893 .738 .682 r
.2386 .39133 .24243 .39529 .2493 .37997 .24548 .37625 Mtetra
.201 .533 .924 r
.24548 .37625 .2493 .37997 .2547 .38178 .25089 .37791 Mtetra
.94 .58 .292 r
.25089 .37791 .2547 .38178 .25865 .40148 .25486 .39708 Mtetra
.951 .614 .343 r
.25486 .39708 .25865 .40148 .26218 .42742 .25841 .42242 Mtetra
.908 .507 .117 r
.25841 .42242 .26218 .42742 .26675 .44161 .26299 .43634 Mtetra
.834 .716 .734 r
.26299 .43634 .26675 .44161 .27322 .43211 .26945 .42709 Mtetra
.914 .713 .617 r
.26945 .42709 .27322 .43211 .28114 .40316 .27737 .39877 Mtetra
.921 .719 .612 r
.27737 .39877 .28114 .40316 .28904 .37347 .28527 .36961 Mtetra
.868 .756 .736 r
.28527 .36961 .28904 .37347 .29544 .36346 .29168 .35963 Mtetra
.934 .56 .249 r
.29168 .35963 .29544 .36346 .29982 .3819 .29609 .3775 Mtetra
.956 .638 .385 r
.29609 .3775 .29982 .3819 .30299 .4194 .29927 .41409 Mtetra
.959 .632 .349 r
.29927 .41409 .30299 .4194 .30664 .45188 .30293 .4459 Mtetra
.131 .367 .826 r
.30293 .4459 .30664 .45188 .31231 .4553 .30859 .4494 Mtetra
.914 .707 .609 r
.30859 .4494 .31231 .4553 .32017 .42456 .31644 .41946 Mtetra
.932 .709 .577 r
.31644 .41946 .32017 .42456 .32883 .37934 .3251 .37515 Mtetra
.929 .725 .608 r
.3251 .37515 .32883 .37934 .33641 .34991 .3327 .3461 Mtetra
.619 .122 0 r
.3327 .3461 .33641 .34991 .3418 .35692 .33811 .35265 Mtetra
.957 .641 .383 r
.33811 .35265 .3418 .35692 .34529 .39884 .34162 .39345 Mtetra
.962 .655 .395 r
.34162 .39345 .34529 .39884 .34842 .45071 .34475 .44419 Mtetra
.953 .604 .245 r
.34475 .44419 .34842 .45071 .3531 .47678 .34942 .46991 Mtetra
.887 .7 .645 r
.34942 .46991 .3531 .47678 .36026 .45597 .35656 .44985 Mtetra
.937 .703 .56 r
.35656 .44985 .36026 .45597 .36902 .40086 .36533 .39604 Mtetra
.943 .711 .558 r
.36533 .39604 .36902 .40086 .37747 .34836 .37381 .34444 Mtetra
.91 .753 .675 r
.37381 .34444 .37747 .34836 .3841 .33288 .38047 .32885 Mtetra
.954 .617 .331 r
.38047 .32885 .3841 .33288 .38862 .36591 .385 .36078 Mtetra
.964 .658 .399 r
.385 .36078 .38862 .36591 .39204 .42934 .38841 .42268 Mtetra
.968 .655 .365 r
.38841 .42268 .39204 .42934 .39614 .48221 .39248 .47457 Mtetra
.24 .375 .799 r
.39248 .47457 .39614 .48221 .40229 .48563 .39862 .47834 Mtetra
.934 .7 .561 r
.39862 .47834 .40229 .48563 .41039 .43471 .40672 .42887 Mtetra
.948 .704 .535 r
.40672 .42887 .41039 .43471 .41897 .36394 .41534 .35955 Mtetra
.948 .72 .56 r
.41534 .35955 .41897 .36394 .42648 .31939 .4229 .31551 Mtetra
.701 .221 0 r
.4229 .31551 .42648 .31939 .43227 .32855 .4287 .32393 Mtetra
.964 .65 .376 r
.4287 .32393 .43227 .32855 .43676 .38706 .43317 .38082 Mtetra
.968 .662 .382 r
.43317 .38082 .43676 .38706 .44115 .45928 .43752 .45148 Mtetra
.959 .622 .25 r
.43752 .45148 .44115 .45928 .44669 .49551 .44303 .48731 Mtetra
.903 .695 .611 r
.44303 .48731 .44669 .49551 .45378 .46756 .45013 .46048 Mtetra
.949 .701 .527 r
.45013 .46048 .45378 .46756 .46168 .39401 .45808 .38872 Mtetra
.956 .708 .523 r
.45808 .38872 .46168 .39401 .46926 .32397 .46572 .31988 Mtetra
.94 .745 .612 r
.46572 .31988 .46926 .32397 .47586 .29989 .47235 .29576 Mtetra
.954 .608 .288 r
.47235 .29576 .47586 .29989 .48158 .33487 .47805 .32949 Mtetra
.968 .656 .368 r
.47805 .32949 .48158 .33487 .48701 .40763 .48343 .40047 Mtetra
.97 .653 .336 r
.48343 .40047 .48701 .40763 .49286 .47085 .48922 .4625 Mtetra
0 .097 .649 r
.48922 .4625 .49286 .47085 .4994 .4789 .49575 .47084 Mtetra
.943 .7 .542 r
.49575 .47084 .4994 .4789 .50636 .42445 .50276 .41797 Mtetra
.958 .704 .508 r
.50276 .41797 .50636 .42445 .51322 .34487 .5097 .34007 Mtetra
.96 .718 .526 r
.5097 .34007 .51322 .34487 .51974 .29021 .51629 .28617 Mtetra
.511 .684 .945 r
.51629 .28617 .51974 .29021 .52608 .29039 .52263 .28585 Mtetra
.963 .633 .317 r
.52263 .28585 .52608 .29039 .53257 .34261 .52907 .33661 Mtetra
.969 .65 .335 r
.52907 .33661 .53257 .34261 .53938 .41314 .5358 .40556 Mtetra
.951 .61 .217 r
.5358 .40556 .53938 .41314 .54631 .45368 .54269 .44547 Mtetra
.883 .695 .644 r
.54269 .44547 .54631 .45368 .55292 .43417 .54932 .42675 Mtetra
.957 .704 .513 r
.54932 .42675 .55292 .43417 .55897 .36776 .55546 .36194 Mtetra
.964 .709 .501 r
.55546 .36194 .55897 .36776 .56472 .29827 .56131 .29377 Mtetra
.957 .739 .565 r
.56131 .29377 .56472 .29827 .57077 .26606 .5674 .26189 Mtetra
.888 .48 .055 r
.5674 .26189 .57077 .26606 .57759 .28579 .5742 .28087 Mtetra
.962 .629 .293 r
.5742 .28087 .57759 .28579 .58521 .34183 .58174 .33555 Mtetra
.961 .627 .267 r
.58174 .33555 .58521 .34183 .59305 .3961 .5895 .38868 Mtetra
0 0 .366 r
.5895 .38868 .59305 .3961 .60021 .41001 .59665 .40245 Mtetra
.942 .711 .559 r
.59665 .40245 .60021 .41001 .60615 .37292 .60265 .36631 Mtetra
.964 .709 .5 r
.60265 .36631 .60615 .37292 .61126 .31003 .60786 .30476 Mtetra
.967 .722 .513 r
.60786 .30476 .61126 .31003 .61651 .26032 .6132 .25594 Mtetra
.89 .782 .736 r
.6132 .25594 .61651 .26032 .62282 .24991 .61953 .24555 Mtetra
.926 .55 .15 r
.61953 .24555 .62282 .24991 .63049 .27981 .62715 .27467 Mtetra
.952 .605 .231 r
.62715 .27467 .63049 .27981 .63895 .3273 .63553 .32108 Mtetra
.909 .541 .095 r
.63553 .32108 .63895 .3273 .64702 .35853 .64355 .35163 Mtetra
.799 .698 .754 r
.64355 .35163 .64702 .35853 .65366 .35073 .65021 .34401 Mtetra
.959 .718 .531 r
.65021 .34401 .65366 .35073 .65885 .30888 .65548 .30304 Mtetra
.969 .721 .506 r
.65548 .30304 .65885 .30888 .66356 .26012 .66029 .25525 Mtetra
.961 .749 .571 r
.66029 .25525 .66356 .26012 .66909 .23249 .66587 .22813 Mtetra
0 .244 .753 r
.66587 .22813 .66909 .23249 .67615 .23798 .67293 .23345 Mtetra
.911 .531 .104 r
.67293 .23345 .67615 .23798 .68453 .26796 .68126 .26274 Mtetra
.906 .53 .088 r
.68126 .26274 .68453 .26796 .69315 .29924 .68981 .29328 Mtetra
0 .042 .607 r
.68981 .29328 .69315 .29924 .7007 .30859 .69734 .30232 Mtetra
.929 .74 .626 r
.69734 .30232 .7007 .30859 .70661 .2887 .7033 .28277 Mtetra
.966 .731 .532 r
.7033 .28277 .70661 .2887 .71147 .25256 .70824 .24732 Mtetra
.967 .744 .551 r
.70824 .24732 .71147 .25256 .71656 .22216 .7134 .21754 Mtetra
.874 .788 .763 r
.7134 .21754 .71656 .22216 .72292 .21302 .7198 .2086 Mtetra
.658 .22 0 r
.7198 .2086 .72292 .21302 .73076 .22594 .72762 .22125 Mtetra
.834 .429 0 r
.72762 .22125 .73076 .22594 .73933 .24808 .73614 .24287 Mtetra
.604 .192 0 r
.73614 .24287 .73933 .24808 .74741 .26166 .74419 .25603 Mtetra
.783 .737 .81 r
.74419 .25603 .74741 .26166 .75415 .25591 .75093 .25025 Mtetra
.951 .754 .601 r
.75093 .25025 .75415 .25591 .75964 .23401 .75648 .2287 Mtetra
.963 .756 .578 r
.75648 .2287 .75964 .23401 .76486 .2095 .76177 .20467 Mtetra
.925 .786 .688 r
.76177 .20467 .76486 .2095 .77087 .19584 .76783 .19132 Mtetra
.307 .55 .919 r
.76783 .19132 .77087 .19584 .77815 .19776 .77512 .19321 Mtetra
0 0 .435 r
.77512 .19321 .77815 .19776 .78632 .20946 .78326 .20464 Mtetra
0 .004 .562 r
.78326 .20464 .78632 .20946 .79441 .21934 .79132 .2142 Mtetra
.585 .676 .903 r
.79132 .2142 .79441 .21934 .80158 .21829 .79849 .21303 Mtetra
.907 .779 .708 r
.79849 .21303 .80158 .21829 .80774 .20617 .80468 .20104 Mtetra
.641 .712 .899 r
.17743 .41267 .18132 .41677 .18691 .4151 .18303 .411 Mtetra
.846 .74 .747 r
.18303 .411 .18691 .4151 .19327 .40611 .18938 .40218 Mtetra
.868 .741 .72 r
.18938 .40218 .19327 .40611 .19985 .39482 .19595 .39109 Mtetra
.797 .758 .817 r
.19595 .39109 .19985 .39482 .20581 .38949 .20193 .38581 Mtetra
.606 .096 0 r
.20193 .38581 .20581 .38949 .2107 .39523 .20683 .39133 Mtetra
.922 .531 .211 r
.20683 .39133 .2107 .39523 .2148 .40954 .21095 .40526 Mtetra
.914 .512 .161 r
.21095 .40526 .2148 .40954 .21905 .42296 .21522 .41833 Mtetra
.221 .49 .897 r
.21522 .41833 .21905 .42296 .22442 .42503 .22059 .42034 Mtetra
.869 .726 .701 r
.22059 .42034 .22442 .42503 .23117 .41213 .22734 .40772 Mtetra
.902 .723 .65 r
.22734 .40772 .23117 .41213 .2386 .39133 .23476 .38735 Mtetra
.892 .738 .684 r
.23476 .38735 .2386 .39133 .24548 .37625 .24164 .37252 Mtetra
.231 .551 .931 r
.24164 .37252 .24548 .37625 .25089 .37791 .24707 .37401 Mtetra
.939 .576 .284 r
.24707 .37401 .25089 .37791 .25486 .39708 .25106 .39265 Mtetra
.95 .612 .338 r
.25106 .39265 .25486 .39708 .25841 .42242 .25464 .41737 Mtetra
.904 .5 .103 r
.25464 .41737 .25841 .42242 .26299 .43634 .25922 .43098 Mtetra
.83 .714 .737 r
.25922 .43098 .26299 .43634 .26945 .42709 .26568 .42201 Mtetra
.913 .713 .619 r
.26568 .42201 .26945 .42709 .27737 .39877 .27358 .39433 Mtetra
.92 .719 .614 r
.27358 .39433 .27737 .39877 .28527 .36961 .28148 .36573 Mtetra
.868 .756 .737 r
.28148 .36573 .28527 .36961 .29168 .35963 .28791 .35579 Mtetra
.932 .554 .239 r
.28791 .35579 .29168 .35963 .29609 .3775 .29234 .37306 Mtetra
.956 .637 .382 r
.29234 .37306 .29609 .3775 .29927 .41409 .29554 .40871 Mtetra
.959 .63 .344 r
.29554 .40871 .29927 .41409 .30293 .4459 .29921 .43983 Mtetra
.126 .36 .821 r
.29921 .43983 .30293 .4459 .30859 .4494 .30487 .4434 Mtetra
.912 .707 .612 r
.30487 .4434 .30859 .4494 .31644 .41946 .31271 .41427 Mtetra
.932 .709 .578 r
.31271 .41427 .31644 .41946 .3251 .37515 .32136 .37092 Mtetra
.928 .725 .609 r
.32136 .37092 .3251 .37515 .3327 .3461 .32897 .34228 Mtetra
.567 .069 0 r
.32897 .34228 .3327 .3461 .33811 .35265 .33441 .34836 Mtetra
.957 .639 .379 r
.33441 .34836 .33811 .35265 .34162 .39345 .33794 .388 Mtetra
.963 .654 .393 r
.33794 .388 .34162 .39345 .34475 .44419 .34108 .43756 Mtetra
.952 .602 .239 r
.34108 .43756 .34475 .44419 .34942 .46991 .34574 .4629 Mtetra
.882 .698 .649 r
.34574 .4629 .34942 .46991 .35656 .44985 .35286 .44361 Mtetra
.936 .703 .561 r
.35286 .44361 .35656 .44985 .36533 .39604 .36163 .39114 Mtetra
.942 .711 .559 r
.36163 .39114 .36533 .39604 .37381 .34444 .37013 .34048 Mtetra
.91 .753 .674 r
.37013 .34048 .37381 .34444 .38047 .32885 .37681 .32481 Mtetra
.954 .614 .324 r
.37681 .32481 .38047 .32885 .385 .36078 .38136 .3556 Mtetra
.964 .658 .396 r
.38136 .3556 .385 .36078 .38841 .42268 .38477 .41591 Mtetra
.968 .655 .362 r
.38477 .41591 .38841 .42268 .39248 .47457 .38883 .46678 Mtetra
.211 .352 .789 r
.38883 .46678 .39248 .47457 .39862 .47834 .39494 .4709 Mtetra
.932 .699 .564 r
.39494 .4709 .39862 .47834 .40672 .42887 .40305 .42291 Mtetra
.947 .704 .536 r
.40305 .42291 .40672 .42887 .41534 .35955 .4117 .35511 Mtetra
.948 .72 .561 r
.4117 .35511 .41534 .35955 .4229 .31551 .4193 .31161 Mtetra
.648 .162 0 r
.4193 .31161 .4229 .31551 .4287 .32393 .42512 .31929 Mtetra
.964 .649 .373 r
.42512 .31929 .4287 .32393 .43317 .38082 .42958 .37451 Mtetra
.969 .661 .379 r
.42958 .37451 .43317 .38082 .43752 .45148 .43389 .44353 Mtetra
.958 .621 .245 r
.43389 .44353 .43752 .45148 .44303 .48731 .43937 .47892 Mtetra
.898 .692 .615 r
.43937 .47892 .44303 .48731 .45013 .46048 .44647 .45324 Mtetra
.948 .7 .528 r
.44647 .45324 .45013 .46048 .45808 .38872 .45446 .38333 Mtetra
.955 .708 .524 r
.45446 .38333 .45808 .38872 .46572 .31988 .46216 .31577 Mtetra
.94 .745 .612 r
.46216 .31577 .46572 .31988 .47235 .29576 .46883 .29162 Mtetra
.953 .604 .281 r
.46883 .29162 .47235 .29576 .47805 .32949 .47452 .32407 Mtetra
.968 .655 .365 r
.47452 .32407 .47805 .32949 .48343 .40047 .47985 .3932 Mtetra
.97 .653 .332 r
.47985 .3932 .48343 .40047 .48922 .4625 .48558 .45396 Mtetra
0 .081 .637 r
.48558 .45396 .48922 .4625 .49575 .47084 .4921 .4626 Mtetra
.941 .699 .545 r
.4921 .4626 .49575 .47084 .50276 .41797 .49915 .41135 Mtetra
.957 .703 .51 r
.49915 .41135 .50276 .41797 .5097 .34007 .50617 .33521 Mtetra
.96 .718 .528 r
.50617 .33521 .5097 .34007 .51629 .28617 .51282 .28212 Mtetra
.558 .705 .939 r
.51282 .28212 .51629 .28617 .52263 .28585 .51918 .28129 Mtetra
.962 .631 .313 r
.51918 .28129 .52263 .28585 .52907 .33661 .52556 .33054 Mtetra
.969 .649 .332 r
.52556 .33054 .52907 .33661 .5358 .40556 .53222 .39786 Mtetra
.95 .608 .21 r
.53222 .39786 .5358 .40556 .54269 .44547 .53906 .43708 Mtetra
.877 .692 .648 r
.53906 .43708 .54269 .44547 .54932 .42675 .54571 .41916 Mtetra
.955 .703 .515 r
.54571 .41916 .54932 .42675 .55546 .36194 .55194 .35602 Mtetra
.963 .709 .503 r
.55194 .35602 .55546 .36194 .56131 .29377 .55788 .28922 Mtetra
.957 .739 .567 r
.55788 .28922 .56131 .29377 .5674 .26189 .56402 .2577 Mtetra
.88 .469 .037 r
.56402 .2577 .5674 .26189 .5742 .28087 .57079 .27593 Mtetra
.962 .628 .289 r
.57079 .27593 .5742 .28087 .58174 .33555 .57826 .32919 Mtetra
.96 .625 .262 r
.57826 .32919 .58174 .33555 .5895 .38868 .58595 .38112 Mtetra
0 0 .379 r
.58595 .38112 .5895 .38868 .59665 .40245 .59307 .39473 Mtetra
.94 .71 .563 r
.59307 .39473 .59665 .40245 .60265 .36631 .59914 .35957 Mtetra
.963 .709 .503 r
.59914 .35957 .60265 .36631 .60786 .30476 .60445 .29941 Mtetra
.966 .722 .515 r
.60445 .29941 .60786 .30476 .6132 .25594 .60987 .25153 Mtetra
.89 .782 .736 r
.60987 .25153 .6132 .25594 .61953 .24555 .61622 .24118 Mtetra
.924 .546 .142 r
.61622 .24118 .61953 .24555 .62715 .27467 .6238 .2695 Mtetra
.951 .603 .226 r
.6238 .2695 .62715 .27467 .63553 .32108 .6321 .31478 Mtetra
.905 .536 .085 r
.6321 .31478 .63553 .32108 .64355 .35163 .64006 .3446 Mtetra
.793 .694 .755 r
.64006 .3446 .64355 .35163 .65021 .34401 .64675 .33716 Mtetra
.958 .718 .534 r
.64675 .33716 .65021 .34401 .65548 .30304 .6521 .2971 Mtetra
.968 .721 .509 r
.6521 .2971 .65548 .30304 .66029 .25525 .657 .25033 Mtetra
.96 .749 .575 r
.657 .25033 .66029 .25525 .66587 .22813 .66265 .22374 Mtetra
0 .26 .765 r
.66265 .22374 .66587 .22813 .67293 .23345 .6697 .22889 Mtetra
.908 .526 .096 r
.6697 .22889 .67293 .23345 .68126 .26274 .67797 .25748 Mtetra
.902 .525 .079 r
.67797 .25748 .68126 .26274 .68981 .29328 .68646 .28724 Mtetra
0 .065 .627 r
.68646 .28724 .68981 .29328 .69734 .30232 .69397 .29597 Mtetra
.927 .739 .629 r
.69397 .29597 .69734 .30232 .7033 .28277 .69997 .27675 Mtetra
.965 .731 .535 r
.69997 .27675 .7033 .28277 .70824 .24732 .705 .24203 Mtetra
.965 .745 .554 r
.705 .24203 .70824 .24732 .7134 .21754 .71023 .21288 Mtetra
.87 .788 .767 r
.71023 .21288 .7134 .21754 .7198 .2086 .71666 .20416 Mtetra
.647 .208 0 r
.71666 .20416 .7198 .2086 .72762 .22125 .72446 .21653 Mtetra
.827 .42 0 r
.72446 .21653 .72762 .22125 .73614 .24287 .73293 .2376 Mtetra
0 0 .391 r
.73293 .2376 .73614 .24287 .74419 .25603 .74095 .25033 Mtetra
.783 .735 .809 r
.74095 .25033 .74419 .25603 .75093 .25025 .7477 .24452 Mtetra
.949 .754 .604 r
.7477 .24452 .75093 .25025 .75648 .2287 .75331 .22334 Mtetra
.961 .756 .582 r
.75331 .22334 .75648 .2287 .76177 .20467 .75866 .19981 Mtetra
.922 .786 .693 r
.75866 .19981 .76177 .20467 .76783 .19132 .76477 .18677 Mtetra
.308 .551 .919 r
.76477 .18677 .76783 .19132 .77512 .19321 .77206 .18865 Mtetra
0 0 .45 r
.77206 .18865 .77512 .19321 .78326 .20464 .78018 .19979 Mtetra
0 .025 .581 r
.78018 .19979 .78326 .20464 .79132 .2142 .78822 .20902 Mtetra
.592 .679 .901 r
.78822 .20902 .79132 .2142 .79849 .21303 .79539 .20772 Mtetra
.905 .778 .71 r
.79539 .20772 .79849 .21303 .80468 .20104 .80161 .19588 Mtetra
.64 .711 .898 r
.17352 .40854 .17743 .41267 .18303 .411 .17912 .40688 Mtetra
.843 .74 .749 r
.17912 .40688 .18303 .411 .18938 .40218 .18547 .39823 Mtetra
.867 .741 .722 r
.18547 .39823 .18938 .40218 .19595 .39109 .19205 .38734 Mtetra
.795 .757 .818 r
.19205 .38734 .19595 .39109 .20193 .38581 .19802 .38211 Mtetra
.577 .066 0 r
.19802 .38211 .20193 .38581 .20683 .39133 .20294 .38741 Mtetra
.919 .524 .199 r
.20294 .38741 .20683 .39133 .21095 .40526 .20709 .40094 Mtetra
.91 .504 .147 r
.20709 .40094 .21095 .40526 .21522 .41833 .21138 .41366 Mtetra
.234 .496 .898 r
.21138 .41366 .21522 .41833 .22059 .42034 .21676 .4156 Mtetra
.867 .725 .704 r
.21676 .4156 .22059 .42034 .22734 .40772 .2235 .40328 Mtetra
.901 .723 .652 r
.2235 .40328 .22734 .40772 .23476 .38735 .23091 .38335 Mtetra
.89 .738 .687 r
.23091 .38335 .23476 .38735 .24164 .37252 .23779 .36877 Mtetra
.261 .567 .937 r
.23779 .36877 .24164 .37252 .24707 .37401 .24323 .3701 Mtetra
.937 .571 .275 r
.24323 .3701 .24707 .37401 .25106 .39265 .24725 .38818 Mtetra
.95 .609 .332 r
.24725 .38818 .25106 .39265 .25464 .41737 .25085 .41225 Mtetra
.899 .493 .089 r
.25085 .41225 .25464 .41737 .25922 .43098 .25545 .42556 Mtetra
.826 .712 .739 r
.25545 .42556 .25922 .43098 .26568 .42201 .26189 .41685 Mtetra
.912 .713 .621 r
.26189 .41685 .26568 .42201 .27358 .39433 .26978 .38985 Mtetra
.919 .719 .616 r
.26978 .38985 .27358 .39433 .28148 .36573 .27768 .36183 Mtetra
.867 .756 .738 r
.27768 .36183 .28148 .36573 .28791 .35579 .28412 .35193 Mtetra
.929 .547 .227 r
.28412 .35193 .28791 .35579 .29234 .37306 .28857 .36859 Mtetra
.955 .635 .378 r
.28857 .36859 .29234 .37306 .29554 .40871 .29181 .40328 Mtetra
.959 .629 .339 r
.29181 .40328 .29554 .40871 .29921 .43983 .29549 .43367 Mtetra
.122 .354 .817 r
.29549 .43367 .29921 .43983 .30487 .4434 .30114 .4373 Mtetra
.91 .706 .614 r
.30114 .4373 .30487 .4434 .31271 .41427 .30896 .40901 Mtetra
.931 .709 .58 r
.30896 .40901 .31271 .41427 .32136 .37092 .31761 .36665 Mtetra
.927 .726 .611 r
.31761 .36665 .32136 .37092 .32897 .34228 .32523 .33845 Mtetra
.507 .011 0 r
.32523 .33845 .32897 .34228 .33441 .34836 .3307 .34405 Mtetra
.957 .637 .375 r
.3307 .34405 .33441 .34836 .33794 .388 .33425 .3825 Mtetra
.963 .653 .389 r
.33425 .3825 .33794 .388 .34108 .43756 .3374 .43082 Mtetra
.951 .6 .232 r
.3374 .43082 .34108 .43756 .34574 .4629 .34205 .45577 Mtetra
.878 .696 .652 r
.34205 .45577 .34574 .4629 .35286 .44361 .34916 .43726 Mtetra
.934 .702 .563 r
.34916 .43726 .35286 .44361 .36163 .39114 .35792 .38616 Mtetra
.941 .711 .561 r
.35792 .38616 .36163 .39114 .37013 .34048 .36643 .33649 Mtetra
.91 .752 .674 r
.36643 .33649 .37013 .34048 .37681 .32481 .37315 .32075 Mtetra
.953 .61 .317 r
.37315 .32075 .37681 .32481 .38136 .3556 .37772 .35038 Mtetra
.964 .657 .394 r
.37772 .35038 .38136 .3556 .38477 .41591 .38113 .40905 Mtetra
.968 .654 .358 r
.38113 .40905 .38477 .41591 .38883 .46678 .38517 .45885 Mtetra
.181 .329 .778 r
.38517 .45885 .38883 .46678 .39494 .4709 .39126 .4633 Mtetra
.93 .698 .566 r
.39126 .4633 .39494 .4709 .40305 .42291 .39937 .41684 Mtetra
.947 .704 .538 r
.39937 .41684 .40305 .42291 .4117 .35511 .40805 .35061 Mtetra
.947 .72 .562 r
.40805 .35061 .4117 .35511 .4193 .31161 .41568 .3077 Mtetra
.582 .093 0 r
.41568 .3077 .4193 .31161 .42512 .31929 .42152 .31463 Mtetra
.963 .647 .37 r
.42152 .31463 .42512 .31929 .42958 .37451 .42597 .36813 Mtetra
.969 .661 .377 r
.42597 .36813 .42958 .37451 .43389 .44353 .43026 .43546 Mtetra
.957 .62 .239 r
.43026 .43546 .43389 .44353 .43937 .47892 .4357 .47037 Mtetra
.894 .69 .619 r
.4357 .47037 .43937 .47892 .44647 .45324 .4428 .44584 Mtetra
.947 .7 .53 r
.4428 .44584 .44647 .45324 .45446 .38333 .45084 .37784 Mtetra
.955 .708 .526 r
.45084 .37784 .45446 .38333 .46216 .31577 .45859 .31161 Mtetra
.94 .745 .612 r
.45859 .31161 .46216 .31577 .46883 .29162 .46529 .28746 Mtetra
.951 .599 .273 r
.46529 .28746 .46883 .29162 .47452 .32407 .47097 .31861 Mtetra
.968 .654 .363 r
.47097 .31861 .47452 .32407 .47985 .3932 .47625 .38583 Mtetra
.97 .652 .329 r
.47625 .38583 .47985 .3932 .48558 .45396 .48193 .44528 Mtetra
0 .066 .626 r
.48193 .44528 .48558 .45396 .4921 .4626 .48844 .45418 Mtetra
.939 .698 .548 r
.48844 .45418 .4921 .4626 .49915 .41135 .49554 .40459 Mtetra
.957 .703 .512 r
.49554 .40459 .49915 .41135 .50617 .33521 .50263 .33027 Mtetra
.959 .718 .529 r
.50263 .33027 .50617 .33521 .51282 .28212 .50934 .27804 Mtetra
.598 .721 .93 r
.50934 .27804 .51282 .28212 .51918 .28129 .5157 .27671 Mtetra
.962 .628 .309 r
.5157 .27671 .51918 .28129 .52556 .33054 .52204 .32442 Mtetra
.968 .648 .329 r
.52204 .32442 .52556 .33054 .53222 .39786 .52863 .39003 Mtetra
.948 .606 .204 r
.52863 .39003 .53222 .39786 .53906 .43708 .53542 .42854 Mtetra
.87 .688 .653 r
.53542 .42854 .53906 .43708 .54571 .41916 .5421 .41143 Mtetra
.954 .703 .518 r
.5421 .41143 .54571 .41916 .55194 .35602 .54841 .34998 Mtetra
.963 .709 .505 r
.54841 .34998 .55194 .35602 .55788 .28922 .55444 .28463 Mtetra
.956 .739 .569 r
.55444 .28463 .55788 .28922 .56402 .2577 .56063 .2535 Mtetra
.872 .456 .018 r
.56063 .2535 .56402 .2577 .57079 .27593 .56737 .27095 Mtetra
.961 .626 .285 r
.56737 .27095 .57079 .27593 .57826 .32919 .57476 .32276 Mtetra
.959 .623 .258 r
.57476 .32276 .57826 .32919 .58595 .38112 .58238 .37344 Mtetra
0 0 .393 r
.58238 .37344 .58595 .38112 .59307 .39473 .58949 .38688 Mtetra
.938 .709 .566 r
.58949 .38688 .59307 .39473 .59914 .35957 .59562 .35272 Mtetra
.963 .709 .505 r
.59562 .35272 .59914 .35957 .60445 .29941 .60103 .29399 Mtetra
.966 .722 .518 r
.60103 .29399 .60445 .29941 .60987 .25153 .60653 .24709 Mtetra
.889 .782 .737 r
.60653 .24709 .60987 .25153 .61622 .24118 .61291 .23678 Mtetra
.921 .54 .134 r
.61291 .23678 .61622 .24118 .6238 .2695 .62043 .26428 Mtetra
.95 .6 .221 r
.62043 .26428 .6238 .2695 .6321 .31478 .62865 .3084 Mtetra
.901 .53 .074 r
.62865 .3084 .6321 .31478 .64006 .3446 .63656 .33748 Mtetra
.788 .69 .756 r
.63656 .33748 .64006 .3446 .64675 .33716 .64327 .3302 Mtetra
.956 .718 .537 r
.64327 .3302 .64675 .33716 .6521 .2971 .6487 .29108 Mtetra
.967 .721 .512 r
.6487 .29108 .6521 .2971 .657 .25033 .6537 .24536 Mtetra
.959 .749 .578 r
.6537 .24536 .657 .25033 .66265 .22374 .6594 .21933 Mtetra
0 .276 .776 r
.6594 .21933 .66265 .22374 .6697 .22889 .66646 .22431 Mtetra
.905 .521 .088 r
.66646 .22431 .6697 .22889 .67797 .25748 .67467 .25217 Mtetra
.898 .519 .069 r
.67467 .25217 .67797 .25748 .68646 .28724 .6831 .28113 Mtetra
0 .09 .647 r
.6831 .28113 .68646 .28724 .69397 .29597 .69059 .28953 Mtetra
.924 .738 .632 r
.69059 .28953 .69397 .29597 .69997 .27675 .69663 .27065 Mtetra
.964 .731 .539 r
.69663 .27065 .69997 .27675 .705 .24203 .70174 .23668 Mtetra
.964 .745 .558 r
.70174 .23668 .705 .24203 .71023 .21288 .70705 .2082 Mtetra
.865 .787 .772 r
.70705 .2082 .71023 .21288 .71666 .20416 .71351 .1997 Mtetra
.635 .196 0 r
.71351 .1997 .71666 .20416 .72446 .21653 .72129 .21178 Mtetra
.82 .411 0 r
.72129 .21178 .72446 .21653 .73293 .2376 .72971 .23229 Mtetra
0 0 .414 r
.72971 .23229 .73293 .2376 .74095 .25033 .73769 .24457 Mtetra
.783 .734 .807 r
.73769 .24457 .74095 .25033 .7477 .24452 .74446 .23872 Mtetra
.948 .753 .608 r
.74446 .23872 .7477 .24452 .75331 .22334 .75012 .21792 Mtetra
.959 .757 .586 r
.75012 .21792 .75331 .22334 .75866 .19981 .75554 .19491 Mtetra
.919 .786 .698 r
.75554 .19491 .75866 .19981 .76477 .18677 .76169 .18221 Mtetra
.309 .551 .92 r
.76169 .18221 .76477 .18677 .77206 .18865 .769 .18407 Mtetra
0 0 .466 r
.769 .18407 .77206 .18865 .78018 .19979 .77709 .19491 Mtetra
0 .047 .601 r
.77709 .19491 .78018 .19979 .78822 .20902 .7851 .2038 Mtetra
.6 .682 .899 r
.7851 .2038 .78822 .20902 .79539 .20772 .79227 .20236 Mtetra
.903 .777 .713 r
.79227 .20236 .79539 .20772 .80161 .19588 .79853 .19067 Mtetra
.639 .71 .898 r
.16961 .40438 .17352 .40854 .17912 .40688 .17521 .40272 Mtetra
.841 .74 .752 r
.17521 .40272 .17912 .40688 .18547 .39823 .18156 .39425 Mtetra
.865 .741 .725 r
.18156 .39425 .18547 .39823 .19205 .38734 .18812 .38358 Mtetra
.794 .757 .82 r
.18812 .38358 .19205 .38734 .19802 .38211 .1941 .37839 Mtetra
.545 .034 0 r
.1941 .37839 .19802 .38211 .20294 .38741 .19904 .38348 Mtetra
.916 .516 .185 r
.19904 .38348 .20294 .38741 .20709 .40094 .20322 .39658 Mtetra
.905 .495 .131 r
.20322 .39658 .20709 .40094 .21138 .41366 .20753 .40893 Mtetra
.247 .501 .9 r
.20753 .40893 .21138 .41366 .21676 .4156 .21292 .41081 Mtetra
.864 .724 .707 r
.21292 .41081 .21676 .4156 .2235 .40328 .21964 .39878 Mtetra
.899 .723 .654 r
.21964 .39878 .2235 .40328 .23091 .38335 .22704 .37931 Mtetra
.889 .739 .689 r
.22704 .37931 .23091 .38335 .23779 .36877 .23392 .365 Mtetra
.29 .583 .942 r
.23392 .365 .23779 .36877 .24323 .3701 .23938 .36617 Mtetra
.936 .566 .266 r
.23938 .36617 .24323 .3701 .24725 .38818 .24343 .38368 Mtetra
.95 .607 .325 r
.24343 .38368 .24725 .38818 .25085 .41225 .24706 .40708 Mtetra
.893 .484 .072 r
.24706 .40708 .25085 .41225 .25545 .42556 .25167 .42005 Mtetra
.821 .71 .742 r
.25167 .42005 .25545 .42556 .26189 .41685 .2581 .41161 Mtetra
.91 .712 .623 r
.2581 .41161 .26189 .41685 .26978 .38985 .26598 .38531 Mtetra
.918 .72 .618 r
.26598 .38531 .26978 .38985 .27768 .36183 .27386 .3579 Mtetra
.866 .755 .738 r
.27386 .3579 .27768 .36183 .28412 .35193 .28031 .34805 Mtetra
.926 .539 .213 r
.28031 .34805 .28412 .35193 .28857 .36859 .2848 .36409 Mtetra
.955 .633 .373 r
.2848 .36409 .28857 .36859 .29181 .40328 .28807 .39777 Mtetra
.959 .627 .334 r
.28807 .39777 .29181 .40328 .29549 .43367 .29177 .42741 Mtetra
.12 .349 .814 r
.29177 .42741 .29549 .43367 .30114 .4373 .29741 .43109 Mtetra
.908 .705 .617 r
.29741 .43109 .30114 .4373 .30896 .40901 .30521 .40365 Mtetra
.93 .708 .582 r
.30521 .40365 .30896 .40901 .31761 .36665 .31384 .36233 Mtetra
.926 .726 .612 r
.31384 .36233 .31761 .36665 .32523 .33845 .32147 .33459 Mtetra
0 .053 .559 r
.32147 .33459 .32523 .33845 .3307 .34405 .32697 .33973 Mtetra
.957 .635 .371 r
.32697 .33973 .3307 .34405 .33425 .3825 .33055 .37694 Mtetra
.963 .652 .386 r
.33055 .37694 .33425 .3825 .3374 .43082 .33372 .42398 Mtetra
.949 .598 .224 r
.33372 .42398 .3374 .43082 .34205 .45577 .33836 .44849 Mtetra
.873 .694 .656 r
.33836 .44849 .34205 .45577 .34916 .43726 .34545 .43077 Mtetra
.933 .702 .565 r
.34545 .43077 .34916 .43726 .35792 .38616 .3542 .3811 Mtetra
.941 .711 .563 r
.3542 .3811 .35792 .38616 .36643 .33649 .36272 .33248 Mtetra
.91 .752 .674 r
.36272 .33248 .36643 .33649 .37315 .32075 .36947 .31668 Mtetra
.951 .606 .309 r
.36947 .31668 .37315 .32075 .37772 .35038 .37406 .34513 Mtetra
.964 .656 .391 r
.37406 .34513 .37772 .35038 .38113 .40905 .37748 .4021 Mtetra
.968 .653 .354 r
.37748 .4021 .38113 .40905 .38517 .45885 .38151 .45076 Mtetra
.155 .307 .767 r
.38151 .45076 .38517 .45885 .39126 .4633 .38758 .45553 Mtetra
.928 .697 .569 r
.38758 .45553 .39126 .4633 .39937 .41684 .39568 .41062 Mtetra
.946 .703 .539 r
.39568 .41062 .39937 .41684 .40805 .35061 .40438 .34605 Mtetra
.946 .72 .563 r
.40438 .34605 .40805 .35061 .41568 .3077 .41204 .30377 Mtetra
0 0 .499 r
.41204 .30377 .41568 .3077 .42152 .31463 .41791 .30995 Mtetra
.963 .646 .366 r
.41791 .30995 .42152 .31463 .42597 .36813 .42236 .36169 Mtetra
.969 .66 .374 r
.42236 .36169 .42597 .36813 .43026 .43546 .42662 .42724 Mtetra
.955 .619 .233 r
.42662 .42724 .43026 .43546 .4357 .47037 .43204 .46163 Mtetra
.888 .686 .624 r
.43204 .46163 .4357 .47037 .4428 .44584 .43913 .43826 Mtetra
.946 .699 .533 r
.43913 .43826 .4428 .44584 .45084 .37784 .4472 .37223 Mtetra
.954 .708 .527 r
.4472 .37223 .45084 .37784 .45859 .31161 .455 .30741 Mtetra
.94 .745 .612 r
.455 .30741 .45859 .31161 .46529 .28746 .46174 .2833 Mtetra
.949 .594 .264 r
.46174 .2833 .46529 .28746 .47097 .31861 .46741 .31311 Mtetra
.968 .653 .36 r
.46741 .31311 .47097 .31861 .47625 .38583 .47265 .37836 Mtetra
.969 .651 .325 r
.47265 .37836 .47625 .38583 .48193 .44528 .47828 .43642 Mtetra
0 .053 .616 r
.47828 .43642 .48193 .44528 .48844 .45418 .48477 .44556 Mtetra
.937 .697 .551 r
.48477 .44556 .48844 .45418 .49554 .40459 .49191 .39766 Mtetra
.956 .703 .514 r
.49191 .39766 .49554 .40459 .50263 .33027 .49908 .32524 Mtetra
.959 .718 .531 r
.49908 .32524 .50263 .33027 .50934 .27804 .50584 .27393 Mtetra
.634 .735 .921 r
.50584 .27393 .50934 .27804 .5157 .27671 .51222 .27211 Mtetra
.961 .626 .304 r
.51222 .27211 .5157 .27671 .52204 .32442 .51851 .31824 Mtetra
.968 .647 .325 r
.51851 .31824 .52204 .32442 .52863 .39003 .52503 .38208 Mtetra
.946 .604 .196 r
.52503 .38208 .52863 .39003 .53542 .42854 .53177 .41982 Mtetra
.863 .684 .658 r
.53177 .41982 .53542 .42854 .5421 .41143 .53847 .40351 Mtetra
.953 .702 .52 r
.53847 .40351 .5421 .41143 .54841 .34998 .54486 .34382 Mtetra
.962 .709 .507 r
.54486 .34382 .54841 .34998 .55444 .28463 .55099 .27997 Mtetra
.956 .739 .571 r
.55099 .27997 .55444 .28463 .56063 .2535 .55722 .24927 Mtetra
.862 .442 0 r
.55722 .24927 .56063 .2535 .56737 .27095 .56394 .26595 Mtetra
.96 .624 .281 r
.56394 .26595 .56737 .27095 .57476 .32276 .57126 .31626 Mtetra
.958 .621 .252 r
.57126 .31626 .57476 .32276 .58238 .37344 .5788 .36563 Mtetra
0 0 .409 r
.5788 .36563 .58238 .37344 .58949 .38688 .58589 .37886 Mtetra
.935 .707 .57 r
.58589 .37886 .58949 .38688 .59562 .35272 .59209 .34572 Mtetra
.962 .709 .508 r
.59209 .34572 .59562 .35272 .60103 .29399 .5976 .28849 Mtetra
.965 .722 .52 r
.5976 .28849 .60103 .29399 .60653 .24709 .60318 .24261 Mtetra
.887 .781 .738 r
.60318 .24261 .60653 .24709 .61291 .23678 .60957 .23237 Mtetra
.917 .535 .125 r
.60957 .23237 .61291 .23678 .62043 .26428 .61705 .25903 Mtetra
.948 .597 .215 r
.61705 .25903 .62043 .26428 .62865 .3084 .6252 .30193 Mtetra
.895 .524 .062 r
.6252 .30193 .62865 .3084 .63656 .33748 .63305 .33022 Mtetra
.783 .685 .757 r
.63305 .33022 .63656 .33748 .64327 .3302 .63977 .32312 Mtetra
.955 .717 .54 r
.63977 .32312 .64327 .3302 .6487 .29108 .64528 .28497 Mtetra
.966 .721 .515 r
.64528 .28497 .6487 .29108 .6537 .24536 .65039 .24034 Mtetra
.957 .75 .582 r
.65039 .24034 .6537 .24536 .6594 .21933 .65615 .2149 Mtetra
0 .292 .788 r
.65615 .2149 .6594 .21933 .66646 .22431 .6632 .21971 Mtetra
.902 .515 .079 r
.6632 .21971 .66646 .22431 .67467 .25217 .67136 .24681 Mtetra
.894 .513 .058 r
.67136 .24681 .67467 .25217 .6831 .28113 .67972 .27494 Mtetra
0 .116 .668 r
.67972 .27494 .6831 .28113 .69059 .28953 .68719 .28298 Mtetra
.921 .737 .635 r
.68719 .28298 .69059 .28953 .69663 .27065 .69327 .26446 Mtetra
.962 .731 .542 r
.69327 .26446 .69663 .27065 .70174 .23668 .69846 .23127 Mtetra
.963 .746 .562 r
.69846 .23127 .70174 .23668 .70705 .2082 .70385 .20349 Mtetra
.861 .786 .776 r
.70385 .20349 .70705 .2082 .71351 .1997 .71034 .19523 Mtetra
.621 .182 0 r
.71034 .19523 .71351 .1997 .72129 .21178 .7181 .20701 Mtetra
.812 .401 0 r
.7181 .20701 .72129 .21178 .72971 .23229 .72648 .22693 Mtetra
0 0 .44 r
.72648 .22693 .72971 .23229 .73769 .24457 .73442 .23874 Mtetra
.783 .732 .806 r
.73442 .23874 .73769 .24457 .74446 .23872 .7412 .23286 Mtetra
.945 .753 .612 r
.7412 .23286 .74446 .23872 .75012 .21792 .74691 .21246 Mtetra
.958 .757 .591 r
.74691 .21246 .75012 .21792 .75554 .19491 .7524 .18998 Mtetra
.915 .786 .703 r
.7524 .18998 .75554 .19491 .76169 .18221 .75861 .17762 Mtetra
.31 .552 .92 r
.75861 .17762 .76169 .18221 .769 .18407 .76592 .17946 Mtetra
0 0 .483 r
.76592 .17946 .769 .18407 .77709 .19491 .77399 .18999 Mtetra
0 .07 .622 r
.77399 .18999 .77709 .19491 .7851 .2038 .78197 .19852 Mtetra
.608 .684 .896 r
.78197 .19852 .7851 .2038 .79227 .20236 .78914 .19696 Mtetra
.9 .776 .715 r
.78914 .19696 .79227 .20236 .79853 .19067 .79543 .18541 Mtetra
.638 .709 .898 r
.16567 .40018 .16961 .40438 .17521 .40272 .17128 .39853 Mtetra
.838 .739 .755 r
.17128 .39853 .17521 .40272 .18156 .39425 .17762 .39024 Mtetra
.863 .742 .728 r
.17762 .39024 .18156 .39425 .18812 .38358 .18418 .37979 Mtetra
.792 .757 .821 r
.18418 .37979 .18812 .38358 .1941 .37839 .19017 .37466 Mtetra
.51 0 0 r
.19017 .37466 .1941 .37839 .19904 .38348 .19513 .37952 Mtetra
.912 .507 .17 r
.19513 .37952 .19904 .38348 .20322 .39658 .19933 .39219 Mtetra
.9 .485 .114 r
.19933 .39219 .20322 .39658 .20753 .40893 .20367 .40416 Mtetra
.261 .507 .901 r
.20367 .40416 .20753 .40893 .21292 .41081 .20906 .40596 Mtetra
.861 .724 .709 r
.20906 .40596 .21292 .41081 .21964 .39878 .21578 .39424 Mtetra
.898 .723 .657 r
.21578 .39424 .21964 .39878 .22704 .37931 .22316 .37524 Mtetra
.887 .739 .691 r
.22316 .37524 .22704 .37931 .23392 .365 .23003 .36122 Mtetra
.318 .598 .946 r
.23003 .36122 .23392 .365 .23938 .36617 .23551 .36223 Mtetra
.934 .56 .255 r
.23551 .36223 .23938 .36617 .24343 .38368 .2396 .37914 Mtetra
.949 .603 .318 r
.2396 .37914 .24343 .38368 .24706 .40708 .24326 .40184 Mtetra
.886 .474 .054 r
.24326 .40184 .24706 .40708 .25167 .42005 .24788 .41447 Mtetra
.816 .708 .745 r
.24788 .41447 .25167 .42005 .2581 .41161 .25431 .40631 Mtetra
.908 .712 .626 r
.25431 .40631 .2581 .41161 .26598 .38531 .26216 .38072 Mtetra
.917 .72 .62 r
.26216 .38072 .26598 .38531 .27386 .3579 .27003 .35394 Mtetra
.865 .755 .74 r
.27003 .35394 .27386 .3579 .28031 .34805 .27649 .34417 Mtetra
.922 .53 .198 r
.27649 .34417 .28031 .34805 .2848 .36409 .28101 .35956 Mtetra
.955 .631 .368 r
.28101 .35956 .2848 .36409 .28807 .39777 .28432 .39221 Mtetra
.958 .625 .327 r
.28432 .39221 .28807 .39777 .29177 .42741 .28804 .42106 Mtetra
.119 .345 .811 r
.28804 .42106 .29177 .42741 .29741 .43109 .29367 .42478 Mtetra
.906 .705 .62 r
.29367 .42478 .29741 .43109 .30521 .40365 .30144 .39821 Mtetra
.929 .708 .584 r
.30144 .39821 .30521 .40365 .31384 .36233 .31006 .35796 Mtetra
.925 .726 .614 r
.31006 .35796 .31384 .36233 .32147 .33459 .3177 .33072 Mtetra
0 .12 .625 r
.3177 .33072 .32147 .33459 .32697 .33973 .32322 .33538 Mtetra
.956 .633 .366 r
.32322 .33538 .32697 .33973 .33055 .37694 .32684 .37133 Mtetra
.963 .651 .382 r
.32684 .37133 .33055 .37694 .33372 .42398 .33003 .41705 Mtetra
.948 .595 .215 r
.33003 .41705 .33372 .42398 .33836 .44849 .33467 .44109 Mtetra
.868 .691 .661 r
.33467 .44109 .33836 .44849 .34545 .43077 .34174 .42415 Mtetra
.932 .702 .567 r
.34174 .42415 .34545 .43077 .3542 .3811 .35047 .37596 Mtetra
.94 .711 .564 r
.35047 .37596 .3542 .3811 .36272 .33248 .359 .32842 Mtetra
.909 .751 .674 r
.359 .32842 .36272 .33248 .36947 .31668 .36577 .3126 Mtetra
.95 .601 .3 r
.36577 .3126 .36947 .31668 .37406 .34513 .37039 .33985 Mtetra
.964 .654 .388 r
.37039 .33985 .37406 .34513 .37748 .4021 .37383 .39507 Mtetra
.968 .652 .35 r
.37383 .39507 .37748 .4021 .38151 .45076 .37785 .44255 Mtetra
.129 .287 .757 r
.37785 .44255 .38151 .45076 .38758 .45553 .3839 .4476 Mtetra
.926 .697 .572 r
.3839 .4476 .38758 .45553 .39568 .41062 .39199 .40428 Mtetra
.945 .703 .541 r
.39199 .40428 .39568 .41062 .40438 .34605 .4007 .34141 Mtetra
.946 .72 .565 r
.4007 .34141 .40438 .34605 .41204 .30377 .4084 .29982 Mtetra
0 .074 .588 r
.4084 .29982 .41204 .30377 .41791 .30995 .41429 .30526 Mtetra
.963 .644 .362 r
.41429 .30526 .41791 .30995 .42236 .36169 .41874 .35519 Mtetra
.969 .659 .371 r
.41874 .35519 .42236 .36169 .42662 .42724 .42298 .41892 Mtetra
.954 .617 .227 r
.42298 .41892 .42662 .42724 .43204 .46163 .42837 .45272 Mtetra
.883 .683 .629 r
.42837 .45272 .43204 .46163 .43913 .43826 .43546 .43052 Mtetra
.945 .699 .535 r
.43546 .43052 .43913 .43826 .4472 .37223 .44355 .36652 Mtetra
.953 .708 .529 r
.44355 .36652 .4472 .37223 .455 .30741 .4514 .30317 Mtetra
.939 .744 .613 r
.4514 .30317 .455 .30741 .46174 .2833 .45817 .27912 Mtetra
.947 .589 .254 r
.45817 .27912 .46174 .2833 .46741 .31311 .46384 .30759 Mtetra
.967 .652 .357 r
.46384 .30759 .46741 .31311 .47265 .37836 .46904 .37081 Mtetra
.969 .65 .321 r
.46904 .37081 .47265 .37836 .47828 .43642 .47463 .42742 Mtetra
0 .042 .607 r
.47463 .42742 .47828 .43642 .48477 .44556 .4811 .43677 Mtetra
.934 .696 .554 r
.4811 .43677 .48477 .44556 .49191 .39766 .48827 .39059 Mtetra
.955 .703 .516 r
.48827 .39059 .49191 .39766 .49908 .32524 .49551 .32013 Mtetra
.958 .718 .533 r
.49551 .32013 .49908 .32524 .50584 .27393 .50233 .26979 Mtetra
.664 .745 .91 r
.50233 .26979 .50584 .27393 .51222 .27211 .50872 .26751 Mtetra
.96 .623 .299 r
.50872 .26751 .51222 .27211 .51851 .31824 .51497 .31201 Mtetra
.968 .646 .322 r
.51497 .31201 .51851 .31824 .52503 .38208 .52142 .37403 Mtetra
.944 .601 .189 r
.52142 .37403 .52503 .38208 .53177 .41982 .52812 .41095 Mtetra
.856 .679 .662 r
.52812 .41095 .53177 .41982 .53847 .40351 .53484 .39543 Mtetra
.952 .702 .523 r
.53484 .39543 .53847 .40351 .54486 .34382 .5413 .33755 Mtetra
.961 .709 .509 r
.5413 .33755 .54486 .34382 .55099 .27997 .54752 .27527 Mtetra
.955 .739 .573 r
.54752 .27527 .55099 .27997 .55722 .24927 .55379 .24503 Mtetra
.85 .425 0 r
.55379 .24503 .55722 .24927 .56394 .26595 .5605 .26093 Mtetra
.96 .621 .276 r
.5605 .26093 .56394 .26595 .57126 .31626 .56775 .30969 Mtetra
.957 .619 .247 r
.56775 .30969 .57126 .31626 .5788 .36563 .57522 .35771 Mtetra
0 0 .424 r
.57522 .35771 .5788 .36563 .58589 .37886 .58229 .3707 Mtetra
.932 .706 .574 r
.58229 .3707 .58589 .37886 .59209 .34572 .58854 .3386 Mtetra
.961 .709 .51 r
.58854 .3386 .59209 .34572 .5976 .28849 .59415 .28291 Mtetra
.964 .722 .523 r
.59415 .28291 .5976 .28849 .60318 .24261 .59981 .2381 Mtetra
.886 .781 .74 r
.59981 .2381 .60318 .24261 .60957 .23237 .60622 .22793 Mtetra
.914 .528 .114 r
.60622 .22793 .60957 .23237 .61705 .25903 .61366 .25374 Mtetra
.947 .594 .209 r
.61366 .25374 .61705 .25903 .6252 .30193 .62173 .2954 Mtetra
.889 .517 .049 r
.62173 .2954 .6252 .30193 .63305 .33022 .62953 .32287 Mtetra
.778 .681 .757 r
.62953 .32287 .63305 .33022 .63977 .32312 .63627 .31592 Mtetra
.953 .717 .544 r
.63627 .31592 .63977 .32312 .64528 .28497 .64186 .27877 Mtetra
.965 .721 .518 r
.64186 .27877 .64528 .28497 .65039 .24034 .64706 .23528 Mtetra
.956 .75 .586 r
.64706 .23528 .65039 .24034 .65615 .2149 .65288 .21045 Mtetra
0 .307 .798 r
.65288 .21045 .65615 .2149 .6632 .21971 .65992 .21508 Mtetra
.898 .509 .07 r
.65992 .21508 .6632 .21971 .67136 .24681 .66803 .24141 Mtetra
.888 .506 .047 r
.66803 .24141 .67136 .24681 .67972 .27494 .67633 .26868 Mtetra
0 .142 .688 r
.67633 .26868 .67972 .27494 .68719 .28298 .68377 .27636 Mtetra
.919 .735 .638 r
.68377 .27636 .68719 .28298 .69327 .26446 .6899 .25819 Mtetra
.961 .731 .546 r
.6899 .25819 .69327 .26446 .69846 .23127 .69518 .22581 Mtetra
.961 .746 .567 r
.69518 .22581 .69846 .23127 .70385 .20349 .70064 .19876 Mtetra
.856 .785 .781 r
.70064 .19876 .70385 .20349 .71034 .19523 .70716 .19073 Mtetra
.607 .168 0 r
.70716 .19073 .71034 .19523 .7181 .20701 .7149 .20221 Mtetra
.802 .39 0 r
.7149 .20221 .7181 .20701 .72648 .22693 .72323 .22152 Mtetra
0 0 .466 r
.72323 .22152 .72648 .22693 .73442 .23874 .73114 .23284 Mtetra
.782 .73 .804 r
.73114 .23284 .73442 .23874 .7412 .23286 .73792 .22693 Mtetra
.943 .753 .615 r
.73792 .22693 .7412 .23286 .74691 .21246 .74369 .20694 Mtetra
.956 .757 .595 r
.74369 .20694 .74691 .21246 .7524 .18998 .74926 .18502 Mtetra
.911 .786 .709 r
.74926 .18502 .7524 .18998 .75861 .17762 .75551 .17301 Mtetra
.312 .553 .92 r
.75551 .17301 .75861 .17762 .76592 .17946 .76283 .17483 Mtetra
0 0 .501 r
.76283 .17483 .76592 .17946 .77399 .18999 .77087 .18503 Mtetra
0 .095 .643 r
.77087 .18503 .77399 .18999 .78197 .19852 .77882 .1932 Mtetra
.615 .687 .894 r
.77882 .1932 .78197 .19852 .78914 .19696 .78599 .1915 Mtetra
.898 .775 .718 r
.78599 .1915 .78914 .19696 .79543 .18541 .79231 .18012 Mtetra
.638 .708 .898 r
.16173 .39597 .16567 .40018 .17128 .39853 .16734 .39432 Mtetra
.836 .739 .758 r
.16734 .39432 .17128 .39853 .17762 .39024 .17368 .38621 Mtetra
.861 .742 .73 r
.17368 .38621 .17762 .39024 .18418 .37979 .18023 .37599 Mtetra
.79 .757 .823 r
.18023 .37599 .18418 .37979 .19017 .37466 .18622 .37092 Mtetra
0 .036 .528 r
.18622 .37092 .19017 .37466 .19513 .37952 .1912 .37554 Mtetra
.907 .497 .154 r
.1912 .37554 .19513 .37952 .19933 .39219 .19544 .38778 Mtetra
.894 .474 .096 r
.19544 .38778 .19933 .39219 .20367 .40416 .1998 .39935 Mtetra
.273 .513 .902 r
.1998 .39935 .20367 .40416 .20906 .40596 .2052 .40108 Mtetra
.859 .724 .712 r
.2052 .40108 .20906 .40596 .21578 .39424 .2119 .38967 Mtetra
.896 .723 .659 r
.2119 .38967 .21578 .39424 .22316 .37524 .21926 .37115 Mtetra
.886 .739 .694 r
.21926 .37115 .22316 .37524 .23003 .36122 .22613 .35742 Mtetra
.344 .612 .949 r
.22613 .35742 .23003 .36122 .23551 .36223 .23163 .35826 Mtetra
.931 .553 .243 r
.23163 .35826 .23551 .36223 .2396 .37914 .23575 .37459 Mtetra
.948 .599 .31 r
.23575 .37459 .2396 .37914 .24326 .40184 .23944 .39658 Mtetra
.879 .463 .036 r
.23944 .39658 .24326 .40184 .24788 .41447 .24408 .40885 Mtetra
.812 .706 .748 r
.24408 .40885 .24788 .41447 .25431 .40631 .2505 .40096 Mtetra
.907 .712 .628 r
.2505 .40096 .25431 .40631 .26216 .38072 .25832 .37609 Mtetra
.916 .72 .623 r
.25832 .37609 .26216 .38072 .27003 .35394 .26618 .34996 Mtetra
.864 .755 .741 r
.26618 .34996 .27003 .35394 .27649 .34417 .27266 .34026 Mtetra
.918 .52 .182 r
.27266 .34026 .27649 .34417 .28101 .35956 .27721 .35502 Mtetra
.955 .629 .363 r
.27721 .35502 .28101 .35956 .28432 .39221 .28055 .38662 Mtetra
.958 .622 .321 r
.28055 .38662 .28432 .39221 .28804 .42106 .2843 .41466 Mtetra
.116 .342 .809 r
.2843 .41466 .28804 .42106 .29367 .42478 .28993 .41841 Mtetra
.904 .704 .623 r
.28993 .41841 .29367 .42478 .30144 .39821 .29767 .39272 Mtetra
.928 .708 .586 r
.29767 .39272 .30144 .39821 .31006 .35796 .30627 .35356 Mtetra
.925 .726 .616 r
.30627 .35356 .31006 .35796 .3177 .33072 .31391 .32683 Mtetra
0 .19 .688 r
.31391 .32683 .3177 .33072 .32322 .33538 .31946 .33103 Mtetra
.956 .63 .361 r
.31946 .33103 .32322 .33538 .32684 .37133 .32312 .36571 Mtetra
.963 .649 .379 r
.32312 .36571 .32684 .37133 .33003 .41705 .32634 .41008 Mtetra
.946 .591 .207 r
.32634 .41008 .33003 .41705 .33467 .44109 .33098 .43362 Mtetra
.863 .689 .665 r
.33098 .43362 .33467 .44109 .34174 .42415 .33802 .41746 Mtetra
.931 .701 .57 r
.33802 .41746 .34174 .42415 .35047 .37596 .34673 .37075 Mtetra
.939 .711 .566 r
.34673 .37075 .35047 .37596 .359 .32842 .35526 .32433 Mtetra
.909 .751 .674 r
.35526 .32433 .359 .32842 .36577 .3126 .36205 .30852 Mtetra
.949 .596 .291 r
.36205 .30852 .36577 .3126 .37039 .33985 .36671 .33456 Mtetra
.964 .653 .384 r
.36671 .33456 .37039 .33985 .37383 .39507 .37017 .388 Mtetra
.968 .651 .346 r
.37017 .388 .37383 .39507 .37785 .44255 .37418 .43426 Mtetra
.101 .267 .747 r
.37418 .43426 .37785 .44255 .3839 .4476 .38022 .43959 Mtetra
.924 .696 .575 r
.38022 .43959 .3839 .4476 .39199 .40428 .38829 .39786 Mtetra
.944 .703 .543 r
.38829 .39786 .39199 .40428 .4007 .34141 .39701 .33672 Mtetra
.945 .72 .566 r
.39701 .33672 .4007 .34141 .4084 .29982 .40473 .29586 Mtetra
0 .168 .675 r
.40473 .29586 .4084 .29982 .41429 .30526 .41065 .30057 Mtetra
.963 .642 .358 r
.41065 .30057 .41429 .30526 .41874 .35519 .41511 .34868 Mtetra
.969 .658 .368 r
.41511 .34868 .41874 .35519 .42298 .41892 .41933 .41054 Mtetra
.953 .615 .221 r
.41933 .41054 .42298 .41892 .42837 .45272 .4247 .44373 Mtetra
.877 .681 .634 r
.4247 .44373 .42837 .45272 .43546 .43052 .43178 .42267 Mtetra
.944 .699 .537 r
.43178 .42267 .43546 .43052 .44355 .36652 .43989 .36072 Mtetra
.953 .708 .531 r
.43989 .36072 .44355 .36652 .4514 .30317 .44778 .29888 Mtetra
.939 .744 .614 r
.44778 .29888 .4514 .30317 .45817 .27912 .45458 .27494 Mtetra
.945 .582 .242 r
.45458 .27494 .45817 .27912 .46384 .30759 .46026 .30206 Mtetra
.967 .65 .353 r
.46026 .30206 .46384 .30759 .46904 .37081 .46543 .36323 Mtetra
.969 .648 .317 r
.46543 .36323 .46904 .37081 .47463 .42742 .47097 .41836 Mtetra
0 .029 .598 r
.47097 .41836 .47463 .42742 .4811 .43677 .47743 .42788 Mtetra
.932 .696 .557 r
.47743 .42788 .4811 .43677 .48827 .39059 .48463 .38342 Mtetra
.954 .703 .518 r
.48463 .38342 .48827 .39059 .49551 .32013 .49193 .31496 Mtetra
.957 .718 .534 r
.49193 .31496 .49551 .32013 .50233 .26979 .4988 .26563 Mtetra
.69 .753 .899 r
.4988 .26563 .50233 .26979 .50872 .26751 .5052 .26289 Mtetra
.959 .62 .293 r
.5052 .26289 .50872 .26751 .51497 .31201 .51142 .30577 Mtetra
.967 .644 .318 r
.51142 .30577 .51497 .31201 .52142 .37403 .5178 .36593 Mtetra
.942 .598 .182 r
.5178 .36593 .52142 .37403 .52812 .41095 .52446 .402 Mtetra
.849 .676 .667 r
.52446 .402 .52812 .41095 .53484 .39543 .5312 .38726 Mtetra
.95 .702 .526 r
.5312 .38726 .53484 .39543 .5413 .33755 .53774 .33119 Mtetra
.961 .709 .511 r
.53774 .33119 .5413 .33755 .54752 .27527 .54403 .27051 Mtetra
.954 .74 .575 r
.54403 .27051 .54752 .27527 .55379 .24503 .55035 .24077 Mtetra
.837 .407 0 r
.55035 .24077 .55379 .24503 .5605 .26093 .55704 .2559 Mtetra
.959 .619 .271 r
.55704 .2559 .5605 .26093 .56775 .30969 .56422 .30309 Mtetra
.956 .616 .241 r
.56422 .30309 .56775 .30969 .57522 .35771 .57162 .34973 Mtetra
0 0 .438 r
.57162 .34973 .57522 .35771 .58229 .3707 .57868 .36247 Mtetra
.93 .706 .578 r
.57868 .36247 .58229 .3707 .58854 .3386 .58498 .3314 Mtetra
.96 .709 .513 r
.58498 .3314 .58854 .3386 .59415 .28291 .59069 .27727 Mtetra
.963 .723 .526 r
.59069 .27727 .59415 .28291 .59981 .2381 .59643 .23356 Mtetra
.884 .78 .742 r
.59643 .23356 .59981 .2381 .60622 .22793 .60286 .22349 Mtetra
.91 .521 .103 r
.60286 .22349 .60622 .22793 .61366 .25374 .61025 .24843 Mtetra
.945 .591 .203 r
.61025 .24843 .61366 .25374 .62173 .2954 .61825 .28883 Mtetra
.883 .509 .036 r
.61825 .28883 .62173 .2954 .62953 .32287 .626 .31545 Mtetra
.774 .679 .759 r
.626 .31545 .62953 .32287 .63627 .31592 .63275 .30866 Mtetra
.951 .717 .547 r
.63275 .30866 .63627 .31592 .64186 .27877 .63842 .27251 Mtetra
.964 .722 .521 r
.63842 .27251 .64186 .27877 .64706 .23528 .64371 .23017 Mtetra
.954 .751 .59 r
.64371 .23017 .64706 .23528 .65288 .21045 .64959 .20598 Mtetra
0 .323 .809 r
.64959 .20598 .65288 .21045 .65992 .21508 .65663 .21044 Mtetra
.893 .502 .059 r
.65663 .21044 .65992 .21508 .66803 .24141 .66468 .23598 Mtetra
.883 .498 .035 r
.66468 .23598 .66803 .24141 .67633 .26868 .67292 .26237 Mtetra
0 .169 .707 r
.67292 .26237 .67633 .26868 .68377 .27636 .68035 .26967 Mtetra
.916 .735 .642 r
.68035 .26967 .68377 .27636 .6899 .25819 .68652 .25188 Mtetra
.96 .732 .55 r
.68652 .25188 .6899 .25819 .69518 .22581 .69187 .22031 Mtetra
.96 .747 .571 r
.69187 .22031 .69518 .22581 .70064 .19876 .69742 .19399 Mtetra
.85 .784 .787 r
.69742 .19399 .70064 .19876 .70716 .19073 .70397 .18622 Mtetra
.592 .152 0 r
.70397 .18622 .70716 .19073 .7149 .20221 .71168 .19738 Mtetra
.792 .378 0 r
.71168 .19738 .7149 .20221 .72323 .22152 .71996 .21607 Mtetra
0 0 .493 r
.71996 .21607 .72323 .22152 .73114 .23284 .72784 .22691 Mtetra
.783 .73 .803 r
.72784 .22691 .73114 .23284 .73792 .22693 .73463 .22096 Mtetra
.941 .753 .619 r
.73463 .22096 .73792 .22693 .74369 .20694 .74046 .20138 Mtetra
.954 .758 .6 r
.74046 .20138 .74369 .20694 .74926 .18502 .74609 .18003 Mtetra
.907 .786 .715 r
.74609 .18003 .74926 .18502 .75551 .17301 .75239 .16839 Mtetra
.314 .554 .92 r
.75239 .16839 .75551 .17301 .76283 .17483 .75972 .17018 Mtetra
0 0 .519 r
.75972 .17018 .76283 .17483 .77087 .18503 .76774 .18005 Mtetra
0 .12 .664 r
.76774 .18005 .77087 .18503 .77882 .1932 .77566 .18785 Mtetra
.623 .69 .892 r
.77566 .18785 .77882 .1932 .78599 .1915 .78283 .18601 Mtetra
.895 .775 .721 r
.78283 .18601 .78599 .1915 .79231 .18012 .78919 .1748 Mtetra
.637 .707 .897 r
.15777 .39172 .16173 .39597 .16734 .39432 .16339 .39007 Mtetra
.833 .739 .76 r
.16339 .39007 .16734 .39432 .17368 .38621 .16971 .38216 Mtetra
.859 .742 .733 r
.16971 .38216 .17368 .38621 .18023 .37599 .17626 .37217 Mtetra
.788 .757 .824 r
.17626 .37217 .18023 .37599 .18622 .37092 .18225 .36716 Mtetra
0 .074 .568 r
.18225 .36716 .18622 .37092 .1912 .37554 .18726 .37155 Mtetra
.901 .486 .136 r
.18726 .37155 .1912 .37554 .19544 .38778 .19152 .38334 Mtetra
.886 .462 .075 r
.19152 .38334 .19544 .38778 .1998 .39935 .19591 .39451 Mtetra
.287 .52 .903 r
.19591 .39451 .1998 .39935 .2052 .40108 .20132 .39616 Mtetra
.856 .723 .716 r
.20132 .39616 .2052 .40108 .2119 .38967 .20801 .38506 Mtetra
.895 .724 .662 r
.20801 .38506 .2119 .38967 .21926 .37115 .21536 .36703 Mtetra
.884 .739 .697 r
.21536 .36703 .21926 .37115 .22613 .35742 .22222 .3536 Mtetra
.369 .624 .951 r
.22222 .3536 .22613 .35742 .23163 .35826 .22773 .35429 Mtetra
.928 .546 .23 r
.22773 .35429 .23163 .35826 .23575 .37459 .23189 .37 Mtetra
.947 .595 .301 r
.23189 .37 .23575 .37459 .23944 .39658 .23562 .39127 Mtetra
.87 .451 .014 r
.23562 .39127 .23944 .39658 .24408 .40885 .24028 .40317 Mtetra
.807 .704 .752 r
.24028 .40317 .24408 .40885 .2505 .40096 .24668 .39555 Mtetra
.905 .712 .631 r
.24668 .39555 .2505 .40096 .25832 .37609 .25448 .37142 Mtetra
.915 .72 .625 r
.25448 .37142 .25832 .37609 .26618 .34996 .26232 .34595 Mtetra
.863 .755 .742 r
.26232 .34595 .26618 .34996 .27266 .34026 .2688 .33635 Mtetra
.913 .509 .163 r
.2688 .33635 .27266 .34026 .27721 .35502 .27339 .35046 Mtetra
.955 .626 .357 r
.27339 .35046 .27721 .35502 .28055 .38662 .27678 .38099 Mtetra
.957 .62 .314 r
.27678 .38099 .28055 .38662 .2843 .41466 .28056 .4082 Mtetra
.117 .34 .807 r
.28056 .4082 .2843 .41466 .28993 .41841 .28618 .41195 Mtetra
.901 .703 .626 r
.28618 .41195 .28993 .41841 .29767 .39272 .29389 .38715 Mtetra
.926 .708 .588 r
.29389 .38715 .29767 .39272 .30627 .35356 .30247 .3491 Mtetra
.923 .726 .618 r
.30247 .3491 .30627 .35356 .31391 .32683 .31011 .32292 Mtetra
0 .259 .747 r
.31011 .32292 .31391 .32683 .31946 .33103 .31569 .32666 Mtetra
.956 .627 .355 r
.31569 .32666 .31946 .33103 .32312 .36571 .31939 .36005 Mtetra
.963 .648 .374 r
.31939 .36005 .32312 .36571 .32634 .41008 .32264 .40303 Mtetra
.943 .588 .198 r
.32264 .40303 .32634 .41008 .33098 .43362 .32728 .42605 Mtetra
.858 .687 .669 r
.32728 .42605 .33098 .43362 .33802 .41746 .3343 .41066 Mtetra
.929 .701 .572 r
.3343 .41066 .33802 .41746 .34673 .37075 .34298 .36546 Mtetra
.938 .711 .568 r
.34298 .36546 .34673 .37075 .35526 .32433 .35151 .32021 Mtetra
.909 .751 .674 r
.35151 .32021 .35526 .32433 .36205 .30852 .35833 .30442 Mtetra
.947 .59 .28 r
.35833 .30442 .36205 .30852 .36671 .33456 .36302 .32926 Mtetra
.964 .652 .381 r
.36302 .32926 .36671 .33456 .37017 .388 .3665 .38089 Mtetra
.968 .65 .342 r
.3665 .38089 .37017 .388 .37418 .43426 .37052 .42587 Mtetra
.079 .249 .738 r
.37052 .42587 .37418 .43426 .38022 .43959 .37653 .43144 Mtetra
.922 .695 .578 r
.37653 .43144 .38022 .43959 .38829 .39786 .38458 .39131 Mtetra
.943 .703 .545 r
.38458 .39131 .38829 .39786 .39701 .33672 .39331 .33195 Mtetra
.944 .72 .568 r
.39331 .33195 .39701 .33672 .40473 .29586 .40105 .29186 Mtetra
0 .264 .755 r
.40105 .29186 .40473 .29586 .41065 .30057 .407 .29587 Mtetra
.962 .64 .353 r
.407 .29587 .41065 .30057 .41511 .34868 .41147 .34213 Mtetra
.969 .657 .364 r
.41147 .34213 .41511 .34868 .41933 .41054 .41568 .40207 Mtetra
.951 .612 .214 r
.41568 .40207 .41933 .41054 .4247 .44373 .42103 .4346 Mtetra
.871 .678 .639 r
.42103 .4346 .4247 .44373 .43178 .42267 .4281 .41468 Mtetra
.942 .698 .54 r
.4281 .41468 .43178 .42267 .43989 .36072 .43623 .3548 Mtetra
.952 .708 .533 r
.43623 .3548 .43989 .36072 .44778 .29888 .44415 .29454 Mtetra
.938 .744 .614 r
.44415 .29454 .44778 .29888 .45458 .27494 .45098 .27074 Mtetra
.942 .575 .23 r
.45098 .27074 .45458 .27494 .46026 .30206 .45666 .29653 Mtetra
.967 .649 .35 r
.45666 .29653 .46026 .30206 .46543 .36323 .46181 .35559 Mtetra
.968 .647 .313 r
.46181 .35559 .46543 .36323 .47097 .41836 .46731 .40918 Mtetra
0 .022 .592 r
.46731 .40918 .47097 .41836 .47743 .42788 .47375 .41884 Mtetra
.93 .694 .561 r
.47375 .41884 .47743 .42788 .48463 .38342 .48098 .37611 Mtetra
.953 .702 .52 r
.48098 .37611 .48463 .38342 .49193 .31496 .48833 .3097 Mtetra
.957 .718 .536 r
.48833 .3097 .49193 .31496 .4988 .26563 .49526 .26144 Mtetra
.712 .758 .889 r
.49526 .26144 .4988 .26563 .5052 .26289 .50168 .25827 Mtetra
.958 .617 .287 r
.50168 .25827 .5052 .26289 .51142 .30577 .50786 .2995 Mtetra
.967 .642 .314 r
.50786 .2995 .51142 .30577 .5178 .36593 .51418 .35776 Mtetra
.939 .594 .173 r
.51418 .35776 .5178 .36593 .52446 .402 .5208 .39292 Mtetra
.841 .672 .672 r
.5208 .39292 .52446 .402 .5312 .38726 .52756 .37895 Mtetra
.949 .701 .529 r
.52756 .37895 .5312 .38726 .53774 .33119 .53416 .32473 Mtetra
.96 .71 .514 r
.53416 .32473 .53774 .33119 .54403 .27051 .54053 .2657 Mtetra
.953 .74 .578 r
.54053 .2657 .54403 .27051 .55035 .24077 .5469 .2365 Mtetra
.822 .387 0 r
.5469 .2365 .55035 .24077 .55704 .2559 .55357 .25085 Mtetra
.958 .616 .266 r
.55357 .25085 .55704 .2559 .56422 .30309 .56068 .29646 Mtetra
.955 .614 .235 r
.56068 .29646 .56422 .30309 .57162 .34973 .56802 .34167 Mtetra
0 0 .455 r
.56802 .34167 .57162 .34973 .57868 .36247 .57506 .35412 Mtetra
.927 .704 .582 r
.57506 .35412 .57868 .36247 .58498 .3314 .58141 .32409 Mtetra
.958 .709 .516 r
.58141 .32409 .58498 .3314 .59069 .27727 .58721 .27155 Mtetra
.962 .723 .529 r
.58721 .27155 .59069 .27727 .59643 .23356 .59303 .22898 Mtetra
.882 .78 .744 r
.59303 .22898 .59643 .23356 .60286 .22349 .59949 .21903 Mtetra
.905 .514 .092 r
.59949 .21903 .60286 .22349 .61025 .24843 .60684 .2431 Mtetra
.943 .587 .196 r
.60684 .2431 .61025 .24843 .61825 .28883 .61475 .2822 Mtetra
.876 .501 .021 r
.61475 .2822 .61825 .28883 .626 .31545 .62246 .30795 Mtetra
.769 .676 .759 r
.62246 .30795 .626 .31545 .63275 .30866 .62922 .3013 Mtetra
.95 .717 .551 r
.62922 .3013 .63275 .30866 .63842 .27251 .63497 .26617 Mtetra
.963 .722 .525 r
.63497 .26617 .63842 .27251 .64371 .23017 .64035 .22502 Mtetra
.953 .752 .595 r
.64035 .22502 .64371 .23017 .64959 .20598 .64629 .20148 Mtetra
0 .338 .818 r
.64629 .20148 .64959 .20598 .65663 .21044 .65333 .20578 Mtetra
.888 .495 .048 r
.65333 .20578 .65663 .21044 .66468 .23598 .66133 .23051 Mtetra
.876 .489 .021 r
.66133 .23051 .66468 .23598 .67292 .26237 .6695 .256 Mtetra
0 .196 .726 r
.6695 .256 .67292 .26237 .68035 .26967 .67691 .26292 Mtetra
.913 .733 .645 r
.67691 .26292 .68035 .26967 .68652 .25188 .68312 .24549 Mtetra
.958 .732 .554 r
.68312 .24549 .68652 .25188 .69187 .22031 .68856 .21476 Mtetra
.958 .748 .576 r
.68856 .21476 .69187 .22031 .69742 .19399 .69418 .1892 Mtetra
.845 .783 .792 r
.69418 .1892 .69742 .19399 .70397 .18622 .70076 .18168 Mtetra
0 0 .41 r
.70076 .18168 .70397 .18622 .71168 .19738 .70846 .19252 Mtetra
.781 .365 0 r
.70846 .19252 .71168 .19738 .71996 .21607 .71669 .21058 Mtetra
0 0 .522 r
.71669 .21058 .71996 .21607 .72784 .22691 .72452 .22091 Mtetra
.783 .728 .802 r
.72452 .22091 .72784 .22691 .73463 .22096 .73133 .21493 Mtetra
.939 .752 .623 r
.73133 .21493 .73463 .22096 .74046 .20138 .73722 .19579 Mtetra
.952 .759 .606 r
.73722 .19579 .74046 .20138 .74609 .18003 .74292 .17502 Mtetra
.903 .786 .722 r
.74292 .17502 .74609 .18003 .75239 .16839 .74926 .16374 Mtetra
.315 .555 .921 r
.74926 .16374 .75239 .16839 .75972 .17018 .7566 .16551 Mtetra
0 0 .539 r
.7566 .16551 .75972 .17018 .76774 .18005 .76459 .17504 Mtetra
0 .147 .686 r
.76459 .17504 .76774 .18005 .77566 .18785 .77249 .18246 Mtetra
.63 .692 .889 r
.77249 .18246 .77566 .18785 .78283 .18601 .77965 .18048 Mtetra
.892 .774 .724 r
.77965 .18048 .78283 .18601 .78919 .1748 .78604 .16944 Mtetra
.636 .706 .897 r
.1538 .38745 .15777 .39172 .16339 .39007 .15942 .3858 Mtetra
.83 .739 .763 r
.15942 .3858 .16339 .39007 .16971 .38216 .16574 .37808 Mtetra
.856 .742 .737 r
.16574 .37808 .16971 .38216 .17626 .37217 .17227 .36833 Mtetra
.786 .757 .826 r
.17227 .36833 .17626 .37217 .18225 .36716 .17827 .36338 Mtetra
0 .114 .608 r
.17827 .36338 .18225 .36716 .18726 .37155 .1833 .36753 Mtetra
.895 .474 .116 r
.1833 .36753 .18726 .37155 .19152 .38334 .1876 .37887 Mtetra
.878 .448 .052 r
.1876 .37887 .19152 .38334 .19591 .39451 .19202 .38963 Mtetra
.301 .526 .904 r
.19202 .38963 .19591 .39451 .20132 .39616 .19744 .39119 Mtetra
.853 .723 .719 r
.19744 .39119 .20132 .39616 .20801 .38506 .20411 .38041 Mtetra
.893 .724 .665 r
.20411 .38041 .20801 .38506 .21536 .36703 .21143 .36289 Mtetra
.882 .74 .7 r
.21143 .36289 .21536 .36703 .22222 .3536 .21829 .34976 Mtetra
.393 .636 .952 r
.21829 .34976 .22222 .3536 .22773 .35429 .22382 .35029 Mtetra
.925 .537 .215 r
.22382 .35029 .22773 .35429 .23189 .37 .22802 .36539 Mtetra
.946 .591 .291 r
.22802 .36539 .23189 .37 .23562 .39127 .23179 .38591 Mtetra
.859 .437 0 r
.23179 .38591 .23562 .39127 .24028 .40317 .23647 .39743 Mtetra
.802 .702 .755 r
.23647 .39743 .24028 .40317 .24668 .39555 .24286 .39008 Mtetra
.903 .712 .634 r
.24286 .39008 .24668 .39555 .25448 .37142 .25062 .3667 Mtetra
.913 .72 .628 r
.25062 .3667 .25448 .37142 .26232 .34595 .25844 .34192 Mtetra
.862 .755 .744 r
.25844 .34192 .26232 .34595 .2688 .33635 .26494 .33242 Mtetra
.907 .497 .143 r
.26494 .33242 .2688 .33635 .27339 .35046 .26956 .34588 Mtetra
.954 .623 .351 r
.26956 .34588 .27339 .35046 .27678 .38099 .273 .37532 Mtetra
.957 .616 .306 r
.273 .37532 .27678 .38099 .28056 .4082 .27681 .40166 Mtetra
.12 .34 .806 r
.27681 .40166 .28056 .4082 .28618 .41195 .28243 .40541 Mtetra
.898 .703 .629 r
.28243 .40541 .28618 .41195 .29389 .38715 .29011 .3815 Mtetra
.925 .708 .591 r
.29011 .3815 .29389 .38715 .30247 .3491 .29865 .3446 Mtetra
.922 .726 .62 r
.29865 .3446 .30247 .3491 .31011 .32292 .30629 .31899 Mtetra
0 .326 .799 r
.30629 .31899 .31011 .32292 .31569 .32666 .3119 .32228 Mtetra
.955 .624 .348 r
.3119 .32228 .31569 .32666 .31939 .36005 .31565 .35436 Mtetra
.963 .646 .37 r
.31565 .35436 .31939 .36005 .32264 .40303 .31893 .39592 Mtetra
.941 .583 .187 r
.31893 .39592 .32264 .40303 .32728 .42605 .32358 .41837 Mtetra
.852 .684 .674 r
.32358 .41837 .32728 .42605 .3343 .41066 .33057 .40375 Mtetra
.927 .701 .575 r
.33057 .40375 .3343 .41066 .34298 .36546 .33922 .36008 Mtetra
.937 .711 .57 r
.33922 .36008 .34298 .36546 .35151 .32021 .34774 .31604 Mtetra
.908 .75 .675 r
.34774 .31604 .35151 .32021 .35833 .30442 .35458 .30031 Mtetra
.944 .584 .268 r
.35458 .30031 .35833 .30442 .36302 .32926 .35931 .32394 Mtetra
.963 .65 .377 r
.35931 .32394 .36302 .32926 .3665 .38089 .36282 .37372 Mtetra
.968 .648 .337 r
.36282 .37372 .3665 .38089 .37052 .42587 .36685 .41739 Mtetra
.061 .234 .729 r
.36685 .41739 .37052 .42587 .37653 .43144 .37284 .42315 Mtetra
.919 .694 .581 r
.37284 .42315 .37653 .43144 .38458 .39131 .38087 .38463 Mtetra
.942 .703 .547 r
.38087 .38463 .38458 .39131 .39331 .33195 .38959 .32711 Mtetra
.944 .72 .57 r
.38959 .32711 .39331 .33195 .40105 .29186 .39736 .28785 Mtetra
0 .355 .823 r
.39736 .28785 .40105 .29186 .407 .29587 .40333 .29117 Mtetra
.962 .637 .348 r
.40333 .29117 .407 .29587 .41147 .34213 .40782 .33557 Mtetra
.968 .655 .361 r
.40782 .33557 .41147 .34213 .41568 .40207 .41203 .39354 Mtetra
.949 .609 .206 r
.41203 .39354 .41568 .40207 .42103 .4346 .41736 .42534 Mtetra
.864 .675 .644 r
.41736 .42534 .42103 .4346 .4281 .41468 .42441 .40653 Mtetra
.941 .697 .542 r
.42441 .40653 .4281 .41468 .43623 .3548 .43255 .34877 Mtetra
.951 .708 .535 r
.43255 .34877 .43623 .3548 .44415 .29454 .44051 .29014 Mtetra
.937 .744 .616 r
.44051 .29014 .44415 .29454 .45098 .27074 .44737 .26653 Mtetra
.938 .567 .216 r
.44737 .26653 .45098 .27074 .45666 .29653 .45305 .29098 Mtetra
.966 .647 .346 r
.45305 .29098 .45666 .29653 .46181 .35559 .45818 .34792 Mtetra
.968 .645 .308 r
.45818 .34792 .46181 .35559 .46731 .40918 .46365 .3999 Mtetra
0 .016 .587 r
.46365 .3999 .46731 .40918 .47375 .41884 .47008 .40966 Mtetra
.927 .693 .565 r
.47008 .40966 .47375 .41884 .48098 .37611 .47732 .36866 Mtetra
.952 .702 .523 r
.47732 .36866 .48098 .37611 .48833 .3097 .48473 .30434 Mtetra
.956 .718 .539 r
.48473 .30434 .48833 .3097 .49526 .26144 .4917 .25721 Mtetra
.73 .763 .879 r
.4917 .25721 .49526 .26144 .50168 .25827 .49813 .25364 Mtetra
.957 .614 .28 r
.49813 .25364 .50168 .25827 .50786 .2995 .50429 .29321 Mtetra
.966 .641 .309 r
.50429 .29321 .50786 .2995 .51418 .35776 .51055 .34952 Mtetra
.936 .59 .164 r
.51055 .34952 .51418 .35776 .5208 .39292 .51714 .38373 Mtetra
.833 .667 .677 r
.51714 .38373 .5208 .39292 .52756 .37895 .5239 .3705 Mtetra
.947 .701 .532 r
.5239 .3705 .52756 .37895 .53416 .32473 .53057 .31815 Mtetra
.959 .71 .517 r
.53057 .31815 .53416 .32473 .54053 .2657 .53702 .26082 Mtetra
.952 .74 .58 r
.53702 .26082 .54053 .2657 .5469 .2365 .54343 .2322 Mtetra
.804 .364 0 r
.54343 .2322 .5469 .2365 .55357 .25085 .55008 .24579 Mtetra
.956 .613 .26 r
.55008 .24579 .55357 .25085 .56068 .29646 .55714 .28978 Mtetra
.953 .611 .228 r
.55714 .28978 .56068 .29646 .56802 .34167 .56441 .33352 Mtetra
0 0 .473 r
.56441 .33352 .56802 .34167 .57506 .35412 .57143 .34565 Mtetra
.924 .703 .586 r
.57143 .34565 .57506 .35412 .58141 .32409 .57783 .31667 Mtetra
.957 .709 .52 r
.57783 .31667 .58141 .32409 .58721 .27155 .58372 .26575 Mtetra
.961 .724 .532 r
.58372 .26575 .58721 .27155 .59303 .22898 .58962 .22437 Mtetra
.88 .779 .746 r
.58962 .22437 .59303 .22898 .59949 .21903 .59609 .21455 Mtetra
.9 .506 .079 r
.59609 .21455 .59949 .21903 .60684 .2431 .6034 .23774 Mtetra
.941 .583 .188 r
.6034 .23774 .60684 .2431 .61475 .2822 .61125 .27551 Mtetra
.867 .491 .005 r
.61125 .27551 .61475 .2822 .62246 .30795 .6189 .30036 Mtetra
.765 .672 .76 r
.6189 .30036 .62246 .30795 .62922 .3013 .62568 .29385 Mtetra
.948 .716 .555 r
.62568 .29385 .62922 .3013 .63497 .26617 .6315 .25975 Mtetra
.962 .722 .529 r
.6315 .25975 .63497 .26617 .64035 .22502 .63698 .21982 Mtetra
.951 .752 .6 r
.63698 .21982 .64035 .22502 .64629 .20148 .64298 .19696 Mtetra
0 .352 .828 r
.64298 .19696 .64629 .20148 .65333 .20578 .65001 .2011 Mtetra
.883 .487 .036 r
.65001 .2011 .65333 .20578 .66133 .23051 .65796 .225 Mtetra
.869 .48 .006 r
.65796 .225 .66133 .23051 .6695 .256 .66607 .24957 Mtetra
0 .225 .744 r
.66607 .24957 .6695 .256 .67691 .26292 .67346 .25609 Mtetra
.91 .732 .648 r
.67346 .25609 .67691 .26292 .68312 .24549 .67971 .23904 Mtetra
.956 .732 .558 r
.67971 .23904 .68312 .24549 .68856 .21476 .68523 .20917 Mtetra
.956 .748 .582 r
.68523 .20917 .68856 .21476 .69418 .1892 .69092 .18438 Mtetra
.838 .782 .798 r
.69092 .18438 .69418 .1892 .70076 .18168 .69754 .17713 Mtetra
0 0 .429 r
.69754 .17713 .70076 .18168 .70846 .19252 .70521 .18764 Mtetra
.768 .351 0 r
.70521 .18764 .70846 .19252 .71669 .21058 .71339 .20504 Mtetra
0 0 .552 r
.71339 .20504 .71669 .21058 .72452 .22091 .7212 .21486 Mtetra
.783 .727 .801 r
.7212 .21486 .72452 .22091 .73133 .21493 .72802 .20885 Mtetra
.937 .752 .628 r
.72802 .20885 .73133 .21493 .73722 .19579 .73395 .19015 Mtetra
.949 .759 .611 r
.73395 .19015 .73722 .19579 .74292 .17502 .73973 .16997 Mtetra
.898 .786 .728 r
.73973 .16997 .74292 .17502 .74926 .16374 .74612 .15907 Mtetra
.318 .557 .921 r
.74612 .15907 .74926 .16374 .7566 .16551 .75346 .16081 Mtetra
0 .006 .559 r
.75346 .16081 .7566 .16551 .76459 .17504 .76143 .16999 Mtetra
0 .175 .708 r
.76143 .16999 .76459 .17504 .77249 .18246 .7693 .17702 Mtetra
.637 .694 .887 r
.7693 .17702 .77249 .18246 .77965 .18048 .77646 .1749 Mtetra
.889 .773 .727 r
.77646 .1749 .77965 .18048 .78604 .16944 .78289 .16405 Mtetra
.636 .706 .897 r
.14981 .38317 .1538 .38745 .15942 .3858 .15544 .38151 Mtetra
.827 .739 .767 r
.15544 .38151 .15942 .3858 .16574 .37808 .16175 .37399 Mtetra
.854 .743 .74 r
.16175 .37399 .16574 .37808 .17227 .36833 .16827 .36448 Mtetra
.784 .756 .828 r
.16827 .36448 .17227 .36833 .17827 .36338 .17427 .35959 Mtetra
0 .155 .647 r
.17427 .35959 .17827 .36338 .1833 .36753 .17932 .36351 Mtetra
.887 .46 .094 r
.17932 .36351 .1833 .36753 .1876 .37887 .18366 .37438 Mtetra
.868 .433 .028 r
.18366 .37438 .1876 .37887 .19202 .38963 .18811 .38473 Mtetra
.313 .533 .906 r
.18811 .38473 .19202 .38963 .19744 .39119 .19354 .3862 Mtetra
.85 .723 .722 r
.19354 .3862 .19744 .39119 .20411 .38041 .2002 .37574 Mtetra
.891 .724 .669 r
.2002 .37574 .20411 .38041 .21143 .36289 .20749 .35872 Mtetra
.88 .74 .703 r
.20749 .35872 .21143 .36289 .21829 .34976 .21434 .34591 Mtetra
.415 .646 .953 r
.21434 .34591 .21829 .34976 .22382 .35029 .21989 .34629 Mtetra
.921 .528 .199 r
.21989 .34629 .22382 .35029 .22802 .36539 .22413 .36077 Mtetra
.944 .585 .281 r
.22413 .36077 .22802 .36539 .23179 .38591 .22795 .38054 Mtetra
.848 .422 0 r
.22795 .38054 .23179 .38591 .23647 .39743 .23264 .39167 Mtetra
.798 .701 .758 r
.23264 .39167 .23647 .39743 .24286 .39008 .23902 .38458 Mtetra
.901 .712 .637 r
.23902 .38458 .24286 .39008 .25062 .3667 .24676 .36195 Mtetra
.912 .721 .631 r
.24676 .36195 .25062 .3667 .25844 .34192 .25455 .33786 Mtetra
.86 .755 .746 r
.25455 .33786 .25844 .34192 .26494 .33242 .26105 .32847 Mtetra
.899 .483 .121 r
.26105 .32847 .26494 .33242 .26956 .34588 .26572 .3413 Mtetra
.953 .62 .344 r
.26572 .3413 .26956 .34588 .273 .37532 .26921 .36964 Mtetra
.956 .613 .298 r
.26921 .36964 .273 .37532 .27681 .40166 .27305 .39511 Mtetra
.12 .34 .806 r
.27305 .39511 .27681 .40166 .28243 .40541 .27866 .39884 Mtetra
.896 .703 .633 r
.27866 .39884 .28243 .40541 .29011 .3815 .28631 .37581 Mtetra
.924 .709 .593 r
.28631 .37581 .29011 .3815 .29865 .3446 .29482 .34006 Mtetra
.921 .727 .623 r
.29482 .34006 .29865 .3446 .30629 .31899 .30246 .31504 Mtetra
0 .387 .843 r
.30246 .31504 .30629 .31899 .3119 .32228 .3081 .3179 Mtetra
.954 .621 .342 r
.3081 .3179 .3119 .32228 .31565 .35436 .3119 .34868 Mtetra
.963 .644 .365 r
.3119 .34868 .31565 .35436 .31893 .39592 .31522 .38881 Mtetra
.938 .579 .178 r
.31522 .38881 .31893 .39592 .32358 .41837 .31987 .41068 Mtetra
.847 .683 .679 r
.31987 .41068 .32358 .41837 .33057 .40375 .32683 .39679 Mtetra
.926 .701 .577 r
.32683 .39679 .33057 .40375 .33922 .36008 .33545 .35466 Mtetra
.936 .711 .572 r
.33545 .35466 .33922 .36008 .34774 .31604 .34396 .31184 Mtetra
.907 .75 .675 r
.34396 .31184 .34774 .31604 .35458 .30031 .35082 .29619 Mtetra
.942 .576 .255 r
.35082 .29619 .35458 .30031 .35931 .32394 .35559 .31864 Mtetra
.963 .648 .372 r
.35559 .31864 .35931 .32394 .36282 .37372 .35914 .36657 Mtetra
.967 .646 .332 r
.35914 .36657 .36282 .37372 .36685 .41739 .36318 .4089 Mtetra
.038 .219 .722 r
.36318 .4089 .36685 .41739 .37284 .42315 .36915 .41484 Mtetra
.917 .694 .584 r
.36915 .41484 .37284 .42315 .38087 .38463 .37715 .37791 Mtetra
.941 .703 .549 r
.37715 .37791 .38087 .38463 .38959 .32711 .38586 .32222 Mtetra
.943 .721 .572 r
.38586 .32222 .38959 .32711 .39736 .28785 .39365 .28381 Mtetra
.068 .437 .875 r
.39365 .28381 .39736 .28785 .40333 .29117 .39965 .28647 Mtetra
.961 .634 .343 r
.39965 .28647 .40333 .29117 .40782 .33557 .40416 .32902 Mtetra
.968 .654 .357 r
.40416 .32902 .40782 .33557 .41203 .39354 .40837 .38502 Mtetra
.947 .606 .199 r
.40837 .38502 .41203 .39354 .41736 .42534 .41368 .41607 Mtetra
.859 .673 .649 r
.41368 .41607 .41736 .42534 .42441 .40653 .42072 .39834 Mtetra
.939 .697 .545 r
.42072 .39834 .42441 .40653 .43255 .34877 .42887 .34268 Mtetra
.95 .708 .537 r
.42887 .34268 .43255 .34877 .44051 .29014 .43685 .28571 Mtetra
.937 .744 .617 r
.43685 .28571 .44051 .29014 .44737 .26653 .44374 .26231 Mtetra
.934 .558 .2 r
.44374 .26231 .44737 .26653 .45305 .29098 .44943 .28545 Mtetra
.966 .645 .341 r
.44943 .28545 .45305 .29098 .45818 .34792 .45454 .34026 Mtetra
.967 .643 .303 r
.45454 .34026 .45818 .34792 .46365 .3999 .45998 .39063 Mtetra
0 .009 .582 r
.45998 .39063 .46365 .3999 .47008 .40966 .46639 .40045 Mtetra
.925 .693 .568 r
.46639 .40045 .47008 .40966 .47732 .36866 .47366 .36116 Mtetra
.951 .702 .525 r
.47366 .36116 .47732 .36866 .48473 .30434 .48111 .29893 Mtetra
.955 .719 .541 r
.48111 .29893 .48473 .30434 .4917 .25721 .48813 .25295 Mtetra
.745 .766 .87 r
.48813 .25295 .4917 .25721 .49813 .25364 .49458 .24901 Mtetra
.955 .61 .273 r
.49458 .24901 .49813 .25364 .50429 .29321 .5007 .28694 Mtetra
.966 .638 .305 r
.5007 .28694 .50429 .29321 .51055 .34952 .50692 .3413 Mtetra
.933 .586 .156 r
.50692 .3413 .51055 .34952 .51714 .38373 .51346 .37453 Mtetra
.827 .665 .682 r
.51346 .37453 .51714 .38373 .5239 .3705 .52024 .36202 Mtetra
.946 .701 .535 r
.52024 .36202 .5239 .3705 .53057 .31815 .52697 .31152 Mtetra
.958 .71 .519 r
.52697 .31152 .53057 .31815 .53702 .26082 .53349 .2559 Mtetra
.951 .74 .583 r
.53349 .2559 .53702 .26082 .54343 .2322 .53994 .22788 Mtetra
.785 .34 0 r
.53994 .22788 .54343 .2322 .55008 .24579 .54658 .24073 Mtetra
.955 .609 .254 r
.54658 .24073 .55008 .24579 .55714 .28978 .55358 .28311 Mtetra
.951 .607 .221 r
.55358 .28311 .55714 .28978 .56441 .33352 .56079 .32538 Mtetra
0 0 .488 r
.56079 .32538 .56441 .33352 .57143 .34565 .56779 .33717 Mtetra
.921 .703 .59 r
.56779 .33717 .57143 .34565 .57783 .31667 .57424 .30921 Mtetra
.956 .709 .523 r
.57424 .30921 .57783 .31667 .58372 .26575 .58022 .25992 Mtetra
.961 .724 .535 r
.58022 .25992 .58372 .26575 .58962 .22437 .58619 .21972 Mtetra
.878 .779 .749 r
.58619 .21972 .58962 .22437 .59609 .21455 .59269 .21005 Mtetra
.894 .497 .065 r
.59269 .21005 .59609 .21455 .6034 .23774 .59996 .23237 Mtetra
.938 .578 .18 r
.59996 .23237 .6034 .23774 .61125 .27551 .60774 .26882 Mtetra
.859 .481 0 r
.60774 .26882 .61125 .27551 .6189 .30036 .61534 .29276 Mtetra
.762 .671 .762 r
.61534 .29276 .6189 .30036 .62568 .29385 .62213 .28637 Mtetra
.946 .716 .559 r
.62213 .28637 .62568 .29385 .6315 .25975 .62802 .2533 Mtetra
.961 .723 .533 r
.62802 .2533 .6315 .25975 .63698 .21982 .63359 .21459 Mtetra
.949 .753 .605 r
.63359 .21459 .63698 .21982 .64298 .19696 .63965 .19242 Mtetra
.018 .366 .836 r
.63965 .19242 .64298 .19696 .65001 .2011 .64668 .1964 Mtetra
.877 .478 .023 r
.64668 .1964 .65001 .2011 .65796 .225 .65458 .21949 Mtetra
.861 .47 0 r
.65458 .21949 .65796 .225 .66607 .24957 .66263 .24312 Mtetra
0 .252 .761 r
.66263 .24312 .66607 .24957 .67346 .25609 .66999 .24924 Mtetra
.908 .732 .652 r
.66999 .24924 .67346 .25609 .67971 .23904 .67628 .23256 Mtetra
.955 .733 .563 r
.67628 .23256 .67971 .23904 .68523 .20917 .68189 .20355 Mtetra
.955 .749 .587 r
.68189 .20355 .68523 .20917 .69092 .18438 .68765 .17954 Mtetra
.832 .781 .804 r
.68765 .17954 .69092 .18438 .69754 .17713 .6943 .17256 Mtetra
0 0 .448 r
.6943 .17256 .69754 .17713 .70521 .18764 .70196 .18274 Mtetra
.755 .335 0 r
.70196 .18274 .70521 .18764 .71339 .20504 .71009 .19949 Mtetra
0 .017 .58 r
.71009 .19949 .71339 .20504 .7212 .21486 .71786 .20879 Mtetra
.783 .727 .801 r
.71786 .20879 .7212 .21486 .72802 .20885 .72469 .20275 Mtetra
.934 .752 .632 r
.72469 .20275 .72802 .20885 .73395 .19015 .73068 .18449 Mtetra
.947 .76 .617 r
.73068 .18449 .73395 .19015 .73973 .16997 .73652 .16491 Mtetra
.893 .786 .735 r
.73652 .16491 .73973 .16997 .74612 .15907 .74297 .15439 Mtetra
.32 .558 .922 r
.74297 .15439 .74612 .15907 .75346 .16081 .75031 .15609 Mtetra
0 .028 .58 r
.75031 .15609 .75346 .16081 .76143 .16999 .75825 .16492 Mtetra
0 .203 .729 r
.75825 .16492 .76143 .16999 .7693 .17702 .76609 .17156 Mtetra
.644 .698 .885 r
.76609 .17156 .7693 .17702 .77646 .1749 .77325 .1693 Mtetra
.887 .773 .73 r
.77325 .1693 .77646 .1749 .78289 .16405 .77972 .15864 Mtetra
.635 .706 .897 r
.14581 .37886 .14981 .38317 .15544 .38151 .15144 .3772 Mtetra
.824 .739 .77 r
.15144 .3772 .15544 .38151 .16175 .37399 .15774 .36987 Mtetra
.851 .743 .743 r
.15774 .36987 .16175 .37399 .16827 .36448 .16425 .36061 Mtetra
.782 .756 .829 r
.16425 .36061 .16827 .36448 .17427 .35959 .17026 .35579 Mtetra
0 .197 .685 r
.17026 .35579 .17427 .35959 .17932 .36351 .17533 .35946 Mtetra
.878 .445 .069 r
.17533 .35946 .17932 .36351 .18366 .37438 .17971 .36988 Mtetra
.856 .415 0 r
.17971 .36988 .18366 .37438 .18811 .38473 .18419 .3798 Mtetra
.326 .539 .907 r
.18419 .3798 .18811 .38473 .19354 .3862 .18963 .38118 Mtetra
.847 .722 .726 r
.18963 .38118 .19354 .3862 .2002 .37574 .19627 .37104 Mtetra
.889 .725 .672 r
.19627 .37104 .2002 .37574 .20749 .35872 .20354 .35453 Mtetra
.878 .741 .706 r
.20354 .35453 .20749 .35872 .21434 .34591 .21037 .34204 Mtetra
.435 .656 .953 r
.21037 .34204 .21434 .34591 .21989 .34629 .21594 .34227 Mtetra
.916 .517 .182 r
.21594 .34227 .21989 .34629 .22413 .36077 .22022 .35613 Mtetra
.942 .579 .269 r
.22022 .35613 .22413 .36077 .22795 .38054 .22409 .37515 Mtetra
.834 .405 0 r
.22409 .37515 .22795 .38054 .23264 .39167 .22881 .38587 Mtetra
.793 .7 .762 r
.22881 .38587 .23264 .39167 .23902 .38458 .23518 .37904 Mtetra
.899 .712 .64 r
.23518 .37904 .23902 .38458 .24676 .36195 .24287 .35716 Mtetra
.911 .721 .634 r
.24287 .35716 .24676 .36195 .25455 .33786 .25064 .33378 Mtetra
.859 .755 .747 r
.25064 .33378 .25455 .33786 .26105 .32847 .25715 .32452 Mtetra
.891 .467 .096 r
.25715 .32452 .26105 .32847 .26572 .3413 .26186 .3367 Mtetra
.953 .616 .336 r
.26186 .3367 .26572 .3413 .26921 .36964 .2654 .36394 Mtetra
.954 .609 .289 r
.2654 .36394 .26921 .36964 .27305 .39511 .26928 .38852 Mtetra
.125 .342 .807 r
.26928 .38852 .27305 .39511 .27866 .39884 .27489 .39222 Mtetra
.893 .702 .636 r
.27489 .39222 .27866 .39884 .28631 .37581 .2825 .37007 Mtetra
.922 .709 .596 r
.2825 .37007 .28631 .37581 .29482 .34006 .29098 .33548 Mtetra
.92 .727 .625 r
.29098 .33548 .29482 .34006 .30246 .31504 .29861 .31107 Mtetra
.068 .443 .878 r
.29861 .31107 .30246 .31504 .3081 .3179 .30428 .31351 Mtetra
.953 .617 .334 r
.30428 .31351 .3081 .3179 .3119 .34868 .30813 .34299 Mtetra
.962 .642 .36 r
.30813 .34299 .3119 .34868 .31522 .38881 .3115 .38167 Mtetra
.934 .573 .166 r
.3115 .38167 .31522 .38881 .31987 .41068 .31616 .40293 Mtetra
.841 .681 .684 r
.31616 .40293 .31987 .41068 .32683 .39679 .32309 .38976 Mtetra
.925 .7 .58 r
.32309 .38976 .32683 .39679 .33545 .35466 .33167 .34917 Mtetra
.935 .711 .575 r
.33167 .34917 .33545 .35466 .34396 .31184 .34017 .3076 Mtetra
.906 .75 .676 r
.34017 .3076 .34396 .31184 .35082 .29619 .34704 .29206 Mtetra
.939 .568 .24 r
.34704 .29206 .35082 .29619 .35559 .31864 .35185 .31333 Mtetra
.963 .646 .368 r
.35185 .31333 .35559 .31864 .35914 .36657 .35544 .35941 Mtetra
.967 .644 .327 r
.35544 .35941 .35914 .36657 .36318 .4089 .3595 .40037 Mtetra
.023 .208 .715 r
.3595 .40037 .36318 .4089 .36915 .41484 .36546 .40644 Mtetra
.915 .693 .588 r
.36546 .40644 .36915 .41484 .37715 .37791 .37343 .37108 Mtetra
.94 .703 .552 r
.37343 .37108 .37715 .37791 .38586 .32222 .38212 .31726 Mtetra
.942 .721 .574 r
.38212 .31726 .38586 .32222 .39365 .28381 .38992 .27974 Mtetra
.178 .507 .911 r
.38992 .27974 .39365 .28381 .39965 .28647 .39595 .28177 Mtetra
.96 .631 .336 r
.39595 .28177 .39965 .28647 .40416 .32902 .40048 .32248 Mtetra
.968 .652 .353 r
.40048 .32248 .40416 .32902 .40837 .38502 .4047 .37648 Mtetra
.945 .602 .191 r
.4047 .37648 .40837 .38502 .41368 .41607 .41 .40673 Mtetra
.852 .669 .655 r
.41 .40673 .41368 .41607 .42072 .39834 .41703 .39005 Mtetra
.938 .697 .548 r
.41703 .39005 .42072 .39834 .42887 .34268 .42517 .33649 Mtetra
.949 .708 .539 r
.42517 .33649 .42887 .34268 .43685 .28571 .43318 .28121 Mtetra
.936 .744 .619 r
.43318 .28121 .43685 .28571 .44374 .26231 .44009 .25809 Mtetra
.929 .548 .183 r
.44009 .25809 .44374 .26231 .44943 .28545 .4458 .27993 Mtetra
.966 .643 .337 r
.4458 .27993 .44943 .28545 .45454 .34026 .45089 .33261 Mtetra
.967 .641 .298 r
.45089 .33261 .45454 .34026 .45998 .39063 .45631 .38131 Mtetra
0 .006 .58 r
.45631 .38131 .45998 .39063 .46639 .40045 .4627 .39115 Mtetra
.922 .692 .572 r
.4627 .39115 .46639 .40045 .47366 .36116 .46998 .35355 Mtetra
.95 .702 .528 r
.46998 .35355 .47366 .36116 .48111 .29893 .47748 .29344 Mtetra
.954 .719 .544 r
.47748 .29344 .48111 .29893 .48813 .25295 .48454 .24866 Mtetra
.758 .768 .861 r
.48454 .24866 .48813 .25295 .49458 .24901 .491 .24438 Mtetra
.954 .605 .265 r
.491 .24438 .49458 .24901 .5007 .28694 .4971 .28068 Mtetra
.965 .636 .3 r
.4971 .28068 .5007 .28694 .50692 .3413 .50327 .33306 Mtetra
.929 .581 .145 r
.50327 .33306 .50692 .3413 .51346 .37453 .50979 .36528 Mtetra
.819 .661 .687 r
.50979 .36528 .51346 .37453 .52024 .36202 .51657 .35344 Mtetra
.944 .7 .539 r
.51657 .35344 .52024 .36202 .52697 .31152 .52336 .3048 Mtetra
.957 .71 .522 r
.52336 .3048 .52697 .31152 .53349 .2559 .52995 .25093 Mtetra
.95 .741 .586 r
.52995 .25093 .53349 .2559 .53994 .22788 .53644 .22354 Mtetra
.762 .312 0 r
.53644 .22354 .53994 .22788 .54658 .24073 .54307 .23566 Mtetra
.953 .606 .247 r
.54307 .23566 .54658 .24073 .55358 .28311 .55001 .27643 Mtetra
.949 .603 .213 r
.55001 .27643 .55358 .28311 .56079 .32538 .55716 .31719 Mtetra
0 0 .507 r
.55716 .31719 .56079 .32538 .56779 .33717 .56414 .32862 Mtetra
.918 .702 .595 r
.56414 .32862 .56779 .33717 .57424 .30921 .57064 .30167 Mtetra
.955 .709 .526 r
.57064 .30167 .57424 .30921 .58022 .25992 .5767 .25402 Mtetra
.959 .725 .539 r
.5767 .25402 .58022 .25992 .58619 .21972 .58275 .21504 Mtetra
.875 .779 .752 r
.58275 .21504 .58619 .21972 .59269 .21005 .58927 .20555 Mtetra
.888 .487 .05 r
.58927 .20555 .59269 .21005 .59996 .23237 .5965 .227 Mtetra
.935 .573 .171 r
.5965 .227 .59996 .23237 .60774 .26882 .60421 .2621 Mtetra
.849 .469 0 r
.60421 .2621 .60774 .26882 .61534 .29276 .61177 .28512 Mtetra
.759 .669 .763 r
.61177 .28512 .61534 .29276 .62213 .28637 .61857 .27884 Mtetra
.944 .716 .563 r
.61857 .27884 .62213 .28637 .62802 .2533 .62453 .2468 Mtetra
.96 .723 .537 r
.62453 .2468 .62802 .2533 .63359 .21459 .63019 .20932 Mtetra
.947 .754 .61 r
.63019 .20932 .63359 .21459 .63965 .19242 .6363 .18786 Mtetra
.036 .38 .844 r
.6363 .18786 .63965 .19242 .64668 .1964 .64334 .19169 Mtetra
.87 .468 .008 r
.64334 .19169 .64668 .1964 .65458 .21949 .65118 .21394 Mtetra
.852 .458 0 r
.65118 .21394 .65458 .21949 .66263 .24312 .65918 .23664 Mtetra
.024 .28 .777 r
.65918 .23664 .66263 .24312 .66999 .24924 .66652 .24234 Mtetra
.905 .731 .655 r
.66652 .24234 .66999 .24924 .67628 .23256 .67285 .22603 Mtetra
.953 .733 .567 r
.67285 .22603 .67628 .23256 .68189 .20355 .67853 .1979 Mtetra
.953 .75 .593 r
.67853 .1979 .68189 .20355 .68765 .17954 .68437 .17468 Mtetra
.825 .779 .81 r
.68437 .17468 .68765 .17954 .6943 .17256 .69105 .16797 Mtetra
0 0 .468 r
.69105 .16797 .6943 .17256 .70196 .18274 .69868 .17781 Mtetra
.739 .318 0 r
.69868 .17781 .70196 .18274 .71009 .19949 .70677 .1939 Mtetra
0 .051 .61 r
.70677 .1939 .71009 .19949 .71786 .20879 .71451 .20268 Mtetra
.783 .727 .8 r
.71451 .20268 .71786 .20879 .72469 .20275 .72135 .1966 Mtetra
.932 .752 .637 r
.72135 .1966 .72469 .20275 .73068 .18449 .7274 .1788 Mtetra
.945 .761 .623 r
.7274 .1788 .73068 .18449 .73652 .16491 .73331 .15983 Mtetra
.888 .785 .742 r
.73331 .15983 .73652 .16491 .74297 .15439 .7398 .14968 Mtetra
.323 .56 .922 r
.7398 .14968 .74297 .15439 .75031 .15609 .74715 .15135 Mtetra
0 .052 .601 r
.74715 .15135 .75031 .15609 .75825 .16492 .75506 .15981 Mtetra
0 .232 .75 r
.75506 .15981 .75825 .16492 .76609 .17156 .76287 .16607 Mtetra
.65 .7 .883 r
.76287 .16607 .76609 .17156 .77325 .1693 .77004 .16367 Mtetra
.884 .772 .734 r
.77004 .16367 .77325 .1693 .77972 .15864 .77654 .1532 Mtetra
.635 .705 .897 r
.14179 .37453 .14581 .37886 .15144 .3772 .14743 .37287 Mtetra
.821 .739 .773 r
.14743 .37287 .15144 .3772 .15774 .36987 .15372 .36574 Mtetra
.849 .743 .747 r
.15372 .36574 .15774 .36987 .16425 .36061 .16022 .35672 Mtetra
.78 .756 .831 r
.16022 .35672 .16425 .36061 .17026 .35579 .16623 .35197 Mtetra
0 .239 .722 r
.16623 .35197 .17026 .35579 .17533 .35946 .17133 .3554 Mtetra
.868 .427 .042 r
.17133 .3554 .17533 .35946 .17971 .36988 .17574 .36535 Mtetra
.842 .395 0 r
.17574 .36535 .17971 .36988 .18419 .3798 .18026 .37485 Mtetra
.34 .546 .908 r
.18026 .37485 .18419 .3798 .18963 .38118 .1857 .37613 Mtetra
.843 .722 .729 r
.1857 .37613 .18963 .38118 .19627 .37104 .19233 .3663 Mtetra
.887 .725 .675 r
.19233 .3663 .19627 .37104 .20354 .35453 .19957 .35031 Mtetra
.876 .741 .71 r
.19957 .35031 .20354 .35453 .21037 .34204 .20639 .33815 Mtetra
.455 .664 .952 r
.20639 .33815 .21037 .34204 .21594 .34227 .21198 .33824 Mtetra
.911 .506 .162 r
.21198 .33824 .21594 .34227 .22022 .35613 .21631 .35148 Mtetra
.94 .573 .256 r
.21631 .35148 .22022 .35613 .22409 .37515 .22022 .36973 Mtetra
.817 .385 0 r
.22022 .36973 .22409 .37515 .22881 .38587 .22497 .38004 Mtetra
.788 .698 .765 r
.22497 .38004 .22881 .38587 .23518 .37904 .23132 .37345 Mtetra
.897 .712 .644 r
.23132 .37345 .23518 .37904 .24287 .35716 .23898 .35232 Mtetra
.909 .722 .637 r
.23898 .35232 .24287 .35716 .25064 .33378 .24672 .32966 Mtetra
.857 .755 .75 r
.24672 .32966 .25064 .33378 .25715 .32452 .25323 .32054 Mtetra
.88 .449 .068 r
.25323 .32054 .25715 .32452 .26186 .3367 .25798 .3321 Mtetra
.952 .612 .328 r
.25798 .3321 .26186 .3367 .2654 .36394 .26158 .35822 Mtetra
.953 .604 .279 r
.26158 .35822 .2654 .36394 .26928 .38852 .2655 .3819 Mtetra
.133 .346 .808 r
.2655 .3819 .26928 .38852 .27489 .39222 .27112 .38554 Mtetra
.891 .701 .64 r
.27112 .38554 .27489 .39222 .2825 .37007 .27869 .36426 Mtetra
.921 .709 .599 r
.27869 .36426 .2825 .37007 .29098 .33548 .28712 .33084 Mtetra
.919 .727 .628 r
.28712 .33084 .29098 .33548 .29861 .31107 .29474 .30707 Mtetra
.145 .492 .904 r
.29474 .30707 .29861 .31107 .30428 .31351 .30044 .30912 Mtetra
.952 .612 .326 r
.30044 .30912 .30428 .31351 .30813 .34299 .30435 .3373 Mtetra
.962 .639 .354 r
.30435 .3373 .30813 .34299 .3115 .38167 .30777 .37451 Mtetra
.93 .567 .153 r
.30777 .37451 .3115 .38167 .31616 .40293 .31245 .39512 Mtetra
.834 .678 .689 r
.31245 .39512 .31616 .40293 .32309 .38976 .31935 .38265 Mtetra
.923 .7 .583 r
.31935 .38265 .32309 .38976 .33167 .34917 .32788 .3436 Mtetra
.934 .711 .577 r
.32788 .3436 .33167 .34917 .34017 .3076 .33636 .30331 Mtetra
.905 .75 .678 r
.33636 .30331 .34017 .3076 .34704 .29206 .34325 .28792 Mtetra
.935 .558 .224 r
.34325 .28792 .34704 .29206 .35185 .31333 .3481 .30803 Mtetra
.963 .644 .363 r
.3481 .30803 .35185 .31333 .35544 .35941 .35174 .35224 Mtetra
.966 .642 .32 r
.35174 .35224 .35544 .35941 .3595 .40037 .35581 .39179 Mtetra
.012 .199 .71 r
.35581 .39179 .3595 .40037 .36546 .40644 .36176 .39795 Mtetra
.912 .692 .592 r
.36176 .39795 .36546 .40644 .37343 .37108 .36969 .36416 Mtetra
.939 .702 .554 r
.36969 .36416 .37343 .37108 .38212 .31726 .37837 .31222 Mtetra
.941 .721 .577 r
.37837 .31222 .38212 .31726 .38992 .27974 .38618 .27564 Mtetra
.274 .564 .934 r
.38618 .27564 .38992 .27974 .39595 .28177 .39224 .27708 Mtetra
.959 .628 .33 r
.39224 .27708 .39595 .28177 .40048 .32248 .3968 .31595 Mtetra
.968 .65 .348 r
.3968 .31595 .40048 .32248 .4047 .37648 .40103 .36791 Mtetra
.942 .598 .181 r
.40103 .36791 .4047 .37648 .41 .40673 .40632 .39732 Mtetra
.845 .666 .66 r
.40632 .39732 .41 .40673 .41703 .39005 .41333 .38165 Mtetra
.936 .697 .551 r
.41333 .38165 .41703 .39005 .42517 .33649 .42147 .3302 Mtetra
.948 .708 .542 r
.42147 .3302 .42517 .33649 .43318 .28121 .42949 .27666 Mtetra
.934 .743 .621 r
.42949 .27666 .43318 .28121 .44009 .25809 .43643 .25384 Mtetra
.924 .536 .164 r
.43643 .25384 .44009 .25809 .4458 .27993 .44215 .27443 Mtetra
.965 .64 .332 r
.44215 .27443 .4458 .27993 .45089 .33261 .44723 .32495 Mtetra
.966 .639 .292 r
.44723 .32495 .45089 .33261 .45631 .38131 .45263 .37196 Mtetra
0 .007 .58 r
.45263 .37196 .45631 .38131 .4627 .39115 .45901 .38176 Mtetra
.919 .691 .577 r
.45901 .38176 .4627 .39115 .46998 .35355 .4663 .34583 Mtetra
.949 .702 .53 r
.4663 .34583 .46998 .35355 .47748 .29344 .47383 .28786 Mtetra
.953 .719 .546 r
.47383 .28786 .47748 .29344 .48454 .24866 .48094 .24433 Mtetra
.768 .769 .853 r
.48094 .24433 .48454 .24866 .491 .24438 .48742 .23974 Mtetra
.952 .6 .256 r
.48742 .23974 .491 .24438 .4971 .28068 .4935 .27441 Mtetra
.964 .634 .294 r
.4935 .27441 .4971 .28068 .50327 .33306 .49962 .32479 Mtetra
.925 .575 .134 r
.49962 .32479 .50327 .33306 .50979 .36528 .5061 .35595 Mtetra
.811 .657 .692 r
.5061 .35595 .50979 .36528 .51657 .35344 .5129 .34478 Mtetra
.942 .7 .542 r
.5129 .34478 .51657 .35344 .52336 .3048 .51974 .29798 Mtetra
.956 .71 .525 r
.51974 .29798 .52336 .3048 .52995 .25093 .5264 .24589 Mtetra
.948 .741 .59 r
.5264 .24589 .52995 .25093 .53644 .22354 .53292 .21918 Mtetra
.736 .282 0 r
.53292 .21918 .53644 .22354 .54307 .23566 .53955 .2306 Mtetra
.952 .602 .239 r
.53955 .2306 .54307 .23566 .55001 .27643 .54644 .26973 Mtetra
.947 .599 .205 r
.54644 .26973 .55001 .27643 .55716 .31719 .55353 .30897 Mtetra
0 0 .526 r
.55353 .30897 .55716 .31719 .56414 .32862 .56049 .32 Mtetra
.915 .701 .599 r
.56049 .32 .56414 .32862 .57064 .30167 .56703 .29405 Mtetra
.953 .709 .53 r
.56703 .29405 .57064 .30167 .5767 .25402 .57317 .24805 Mtetra
.958 .725 .543 r
.57317 .24805 .5767 .25402 .58275 .21504 .57929 .21032 Mtetra
.872 .778 .755 r
.57929 .21032 .58275 .21504 .58927 .20555 .58583 .20102 Mtetra
.88 .476 .034 r
.58583 .20102 .58927 .20555 .5965 .227 .59303 .2216 Mtetra
.932 .568 .161 r
.59303 .2216 .5965 .227 .60421 .2621 .60068 .25535 Mtetra
.837 .455 0 r
.60068 .25535 .60421 .2621 .61177 .28512 .60818 .27742 Mtetra
.756 .667 .763 r
.60818 .27742 .61177 .28512 .61857 .27884 .615 .27124 Mtetra
.942 .716 .567 r
.615 .27124 .61857 .27884 .62453 .2468 .62103 .24024 Mtetra
.958 .724 .541 r
.62103 .24024 .62453 .2468 .63019 .20932 .62678 .20401 Mtetra
.945 .755 .616 r
.62678 .20401 .63019 .20932 .6363 .18786 .63294 .18327 Mtetra
.055 .392 .851 r
.63294 .18327 .6363 .18786 .64334 .19169 .63998 .18695 Mtetra
.862 .458 0 r
.63998 .18695 .64334 .19169 .65118 .21394 .64777 .20837 Mtetra
.841 .445 0 r
.64777 .20837 .65118 .21394 .65918 .23664 .65571 .23011 Mtetra
.066 .308 .792 r
.65571 .23011 .65918 .23664 .66652 .24234 .66303 .23539 Mtetra
.902 .731 .659 r
.66303 .23539 .66652 .24234 .67285 .22603 .6694 .21946 Mtetra
.951 .734 .572 r
.6694 .21946 .67285 .22603 .67853 .1979 .67516 .19221 Mtetra
.95 .751 .599 r
.67516 .19221 .67853 .1979 .68437 .17468 .68108 .16979 Mtetra
.817 .778 .816 r
.68108 .16979 .68437 .17468 .69105 .16797 .68778 .16335 Mtetra
0 0 .489 r
.68778 .16335 .69105 .16797 .69868 .17781 .6954 .17286 Mtetra
.722 .298 0 r
.6954 .17286 .69868 .17781 .70677 .1939 .70344 .18827 Mtetra
0 .086 .641 r
.70344 .18827 .70677 .1939 .71451 .20268 .71114 .19652 Mtetra
.783 .726 .799 r
.71114 .19652 .71451 .20268 .72135 .1966 .71799 .19042 Mtetra
.929 .752 .642 r
.71799 .19042 .72135 .1966 .7274 .1788 .7241 .17307 Mtetra
.942 .761 .629 r
.7241 .17307 .7274 .1788 .73331 .15983 .73008 .15472 Mtetra
.882 .785 .749 r
.73008 .15472 .73331 .15983 .7398 .14968 .73661 .14496 Mtetra
.326 .562 .923 r
.73661 .14496 .7398 .14968 .74715 .15135 .74397 .14659 Mtetra
0 .077 .624 r
.74397 .14659 .74715 .15135 .75506 .15981 .75186 .15468 Mtetra
0 .261 .77 r
.75186 .15468 .75506 .15981 .76287 .16607 .75964 .16054 Mtetra
.657 .702 .88 r
.75964 .16054 .76287 .16607 .77004 .16367 .76681 .15801 Mtetra
.881 .771 .737 r
.76681 .15801 .77004 .16367 .77654 .1532 .77334 .14773 Mtetra
.635 .705 .897 r
.13776 .37018 .14179 .37453 .14743 .37287 .14341 .36852 Mtetra
.818 .739 .777 r
.14341 .36852 .14743 .37287 .15372 .36574 .14968 .36158 Mtetra
.846 .744 .751 r
.14968 .36158 .15372 .36574 .16022 .35672 .15617 .35281 Mtetra
.778 .756 .833 r
.15617 .35281 .16022 .35672 .16623 .35197 .16218 .34813 Mtetra
0 .28 .757 r
.16218 .34813 .16623 .35197 .17133 .3554 .1673 .35133 Mtetra
.855 .407 .012 r
.1673 .35133 .17133 .3554 .17574 .36535 .17176 .36081 Mtetra
.826 .373 0 r
.17176 .36081 .17574 .36535 .18026 .37485 .17631 .36988 Mtetra
.354 .553 .909 r
.17631 .36988 .18026 .37485 .1857 .37613 .18177 .37106 Mtetra
.84 .722 .733 r
.18177 .37106 .1857 .37613 .19233 .3663 .18838 .36155 Mtetra
.885 .725 .679 r
.18838 .36155 .19233 .3663 .19957 .35031 .19559 .34607 Mtetra
.874 .742 .713 r
.19559 .34607 .19957 .35031 .20639 .33815 .2024 .33425 Mtetra
.472 .672 .951 r
.2024 .33425 .20639 .33815 .21198 .33824 .208 .33419 Mtetra
.904 .492 .14 r
.208 .33419 .21198 .33824 .21631 .35148 .21237 .34681 Mtetra
.937 .565 .242 r
.21237 .34681 .21631 .35148 .22022 .36973 .21634 .36429 Mtetra
.799 .363 0 r
.21634 .36429 .22022 .36973 .22497 .38004 .22111 .37418 Mtetra
.783 .697 .769 r
.22111 .37418 .22497 .38004 .23132 .37345 .22745 .36784 Mtetra
.895 .712 .647 r
.22745 .36784 .23132 .37345 .23898 .35232 .23508 .34746 Mtetra
.907 .722 .64 r
.23508 .34746 .23898 .35232 .24672 .32966 .24279 .32553 Mtetra
.855 .755 .752 r
.24279 .32553 .24672 .32966 .25323 .32054 .2493 .31656 Mtetra
.868 .428 .037 r
.2493 .31656 .25323 .32054 .25798 .3321 .25409 .32749 Mtetra
.951 .607 .319 r
.25409 .32749 .25798 .3321 .26158 .35822 .25775 .3525 Mtetra
.951 .599 .268 r
.25775 .3525 .26158 .35822 .2655 .3819 .26172 .37526 Mtetra
.141 .351 .811 r
.26172 .37526 .2655 .3819 .27112 .38554 .26733 .37883 Mtetra
.888 .701 .644 r
.26733 .37883 .27112 .38554 .27869 .36426 .27487 .35841 Mtetra
.919 .709 .602 r
.27487 .35841 .27869 .36426 .28712 .33084 .28325 .32617 Mtetra
.917 .728 .631 r
.28325 .32617 .28712 .33084 .29474 .30707 .29086 .30305 Mtetra
.214 .533 .923 r
.29086 .30305 .29474 .30707 .30044 .30912 .29659 .30472 Mtetra
.951 .608 .316 r
.29659 .30472 .30044 .30912 .30435 .3373 .30055 .33161 Mtetra
.961 .637 .347 r
.30055 .33161 .30435 .3373 .30777 .37451 .30403 .36734 Mtetra
.926 .559 .139 r
.30403 .36734 .30777 .37451 .31245 .39512 .30872 .38729 Mtetra
.828 .676 .694 r
.30872 .38729 .31245 .39512 .31935 .38265 .3156 .37549 Mtetra
.921 .7 .586 r
.3156 .37549 .31935 .38265 .32788 .3436 .32408 .33797 Mtetra
.933 .712 .58 r
.32408 .33797 .32788 .3436 .33636 .30331 .33253 .29899 Mtetra
.904 .75 .68 r
.33253 .29899 .33636 .30331 .34325 .28792 .33944 .28377 Mtetra
.93 .548 .205 r
.33944 .28377 .34325 .28792 .3481 .30803 .34434 .30275 Mtetra
.962 .641 .357 r
.34434 .30275 .3481 .30803 .35174 .35224 .34802 .34509 Mtetra
.966 .639 .314 r
.34802 .34509 .35174 .35224 .35581 .39179 .35212 .38321 Mtetra
.001 .193 .707 r
.35212 .38321 .35581 .39179 .36176 .39795 .35805 .38943 Mtetra
.909 .691 .596 r
.35805 .38943 .36176 .39795 .36969 .36416 .36596 .35717 Mtetra
.937 .702 .557 r
.36596 .35717 .36969 .36416 .37837 .31222 .37461 .30712 Mtetra
.94 .721 .579 r
.37461 .30712 .37837 .31222 .38618 .27564 .38242 .27151 Mtetra
.355 .608 .945 r
.38242 .27151 .38618 .27564 .39224 .27708 .38851 .2724 Mtetra
.959 .624 .322 r
.38851 .2724 .39224 .27708 .3968 .31595 .3931 .30945 Mtetra
.967 .648 .343 r
.3931 .30945 .3968 .31595 .40103 .36791 .39735 .35937 Mtetra
.939 .593 .172 r
.39735 .35937 .40103 .36791 .40632 .39732 .40264 .3879 Mtetra
.838 .663 .666 r
.40264 .3879 .40632 .39732 .41333 .38165 .40962 .37319 Mtetra
.935 .696 .554 r
.40962 .37319 .41333 .38165 .42147 .3302 .41775 .32384 Mtetra
.947 .708 .544 r
.41775 .32384 .42147 .3302 .42949 .27666 .42579 .27205 Mtetra
.933 .743 .623 r
.42579 .27205 .42949 .27666 .43643 .25384 .43276 .24959 Mtetra
.917 .523 .142 r
.43276 .24959 .43643 .25384 .44215 .27443 .43849 .26894 Mtetra
.964 .638 .326 r
.43849 .26894 .44215 .27443 .44723 .32495 .44357 .31732 Mtetra
.965 .636 .286 r
.44357 .31732 .44723 .32495 .45263 .37196 .44895 .36261 Mtetra
0 .009 .582 r
.44895 .36261 .45263 .37196 .45901 .38176 .45532 .37234 Mtetra
.916 .69 .581 r
.45532 .37234 .45901 .38176 .4663 .34583 .46262 .33803 Mtetra
.947 .702 .533 r
.46262 .33803 .4663 .34583 .47383 .28786 .47018 .28221 Mtetra
.952 .719 .549 r
.47018 .28221 .47383 .28786 .48094 .24433 .47732 .23996 Mtetra
.777 .77 .847 r
.47732 .23996 .48094 .24433 .48742 .23974 .48381 .23511 Mtetra
.95 .595 .247 r
.48381 .23511 .48742 .23974 .4935 .27441 .48988 .26817 Mtetra
.963 .631 .289 r
.48988 .26817 .4935 .27441 .49962 .32479 .49597 .31655 Mtetra
.921 .569 .122 r
.49597 .31655 .49962 .32479 .5061 .35595 .50242 .34663 Mtetra
.804 .654 .697 r
.50242 .34663 .5061 .35595 .5129 .34478 .50922 .33606 Mtetra
.941 .7 .546 r
.50922 .33606 .5129 .34478 .51974 .29798 .5161 .2911 Mtetra
.955 .71 .528 r
.5161 .2911 .51974 .29798 .5264 .24589 .52283 .2408 Mtetra
.947 .742 .594 r
.52283 .2408 .5264 .24589 .53292 .21918 .52939 .21479 Mtetra
.707 .249 0 r
.52939 .21479 .53292 .21918 .53955 .2306 .53601 .22553 Mtetra
.95 .597 .231 r
.53601 .22553 .53955 .2306 .54644 .26973 .54285 .26305 Mtetra
.944 .594 .196 r
.54285 .26305 .54644 .26973 .55353 .30897 .54988 .30074 Mtetra
0 0 .546 r
.54988 .30074 .55353 .30897 .56049 .32 .55683 .31136 Mtetra
.912 .7 .604 r
.55683 .31136 .56049 .32 .56703 .29405 .56342 .28639 Mtetra
.952 .709 .534 r
.56342 .28639 .56703 .29405 .57317 .24805 .56963 .24204 Mtetra
.957 .726 .547 r
.56963 .24204 .57317 .24805 .57929 .21032 .57581 .20557 Mtetra
.868 .777 .759 r
.57581 .20557 .57929 .21032 .58583 .20102 .58238 .19648 Mtetra
.872 .464 .016 r
.58238 .19648 .58583 .20102 .59303 .2216 .58955 .2162 Mtetra
.929 .562 .151 r
.58955 .2162 .59303 .2216 .60068 .25535 .59713 .2486 Mtetra
.824 .441 0 r
.59713 .2486 .60068 .25535 .60818 .27742 .60459 .2697 Mtetra
.754 .666 .765 r
.60459 .2697 .60818 .27742 .615 .27124 .61142 .26361 Mtetra
.94 .716 .572 r
.61142 .26361 .615 .27124 .62103 .24024 .61752 .23364 Mtetra
.957 .724 .546 r
.61752 .23364 .62103 .24024 .62678 .20401 .62335 .19867 Mtetra
.942 .756 .622 r
.62335 .19867 .62678 .20401 .63294 .18327 .62957 .17866 Mtetra
.072 .404 .858 r
.62957 .17866 .63294 .18327 .63998 .18695 .6366 .1822 Mtetra
.854 .446 0 r
.6366 .1822 .63998 .18695 .64777 .20837 .64435 .20278 Mtetra
.83 .431 0 r
.64435 .20278 .64777 .20837 .65571 .23011 .65223 .22356 Mtetra
.106 .336 .806 r
.65223 .22356 .65571 .23011 .66303 .23539 .65954 .22841 Mtetra
.9 .73 .663 r
.65954 .22841 .66303 .23539 .6694 .21946 .66594 .21287 Mtetra
.949 .734 .577 r
.66594 .21287 .6694 .21946 .67516 .19221 .67178 .18649 Mtetra
.948 .752 .605 r
.67178 .18649 .67516 .19221 .68108 .16979 .67776 .16488 Mtetra
.81 .776 .822 r
.67776 .16488 .68108 .16979 .68778 .16335 .6845 .15872 Mtetra
0 0 .511 r
.6845 .15872 .68778 .16335 .6954 .17286 .6921 .16789 Mtetra
.702 .278 0 r
.6921 .16789 .6954 .17286 .70344 .18827 .70009 .18262 Mtetra
0 .123 .67 r
.70009 .18262 .70344 .18827 .71114 .19652 .70776 .19034 Mtetra
.784 .726 .799 r
.70776 .19034 .71114 .19652 .71799 .19042 .71462 .18421 Mtetra
.927 .753 .647 r
.71462 .18421 .71799 .19042 .7241 .17307 .72078 .16733 Mtetra
.939 .762 .636 r
.72078 .16733 .7241 .17307 .73008 .15472 .72683 .14959 Mtetra
.876 .785 .757 r
.72683 .14959 .73008 .15472 .73661 .14496 .73341 .14021 Mtetra
.329 .564 .923 r
.73341 .14021 .73661 .14496 .74397 .14659 .74078 .1418 Mtetra
0 .103 .646 r
.74078 .1418 .74397 .14659 .75186 .15468 .74864 .14952 Mtetra
0 .291 .79 r
.74864 .14952 .75186 .15468 .75964 .16054 .7564 .15498 Mtetra
.663 .705 .878 r
.7564 .15498 .75964 .16054 .76681 .15801 .76356 .15232 Mtetra
.877 .771 .741 r
.76356 .15232 .76681 .15801 .77334 .14773 .77013 .14224 Mtetra
.634 .705 .898 r
.13372 .36582 .13776 .37018 .14341 .36852 .13936 .36416 Mtetra
.814 .739 .781 r
.13936 .36416 .14341 .36852 .14968 .36158 .14563 .35742 Mtetra
.843 .744 .754 r
.14563 .35742 .14968 .36158 .15617 .35281 .15211 .34889 Mtetra
.775 .756 .835 r
.15211 .34889 .15617 .35281 .16218 .34813 .15811 .34428 Mtetra
0 .321 .79 r
.15811 .34428 .16218 .34813 .1673 .35133 .16326 .34724 Mtetra
.84 .385 0 r
.16326 .34724 .1673 .35133 .17176 .36081 .16776 .35625 Mtetra
.807 .348 0 r
.16776 .35625 .17176 .36081 .17631 .36988 .17235 .3649 Mtetra
.366 .56 .91 r
.17235 .3649 .17631 .36988 .18177 .37106 .17782 .36598 Mtetra
.837 .722 .737 r
.17782 .36598 .18177 .37106 .18838 .36155 .18441 .35678 Mtetra
.882 .726 .683 r
.18441 .35678 .18838 .36155 .19559 .34607 .19159 .34181 Mtetra
.871 .742 .717 r
.19159 .34181 .19559 .34607 .2024 .33425 .19838 .33033 Mtetra
.488 .679 .95 r
.19838 .33033 .2024 .33425 .208 .33419 .204 .33013 Mtetra
.897 .477 .116 r
.204 .33013 .208 .33419 .21237 .34681 .20842 .34214 Mtetra
.934 .557 .227 r
.20842 .34214 .21237 .34681 .21634 .36429 .21245 .35886 Mtetra
.779 .339 0 r
.21245 .35886 .21634 .36429 .22111 .37418 .21725 .36832 Mtetra
.778 .696 .773 r
.21725 .36832 .22111 .37418 .22745 .36784 .22358 .36221 Mtetra
.893 .713 .651 r
.22358 .36221 .22745 .36784 .23508 .34746 .23116 .34258 Mtetra
.906 .723 .643 r
.23116 .34258 .23508 .34746 .24279 .32553 .23883 .32137 Mtetra
.853 .755 .755 r
.23883 .32137 .24279 .32553 .2493 .31656 .24535 .31256 Mtetra
.853 .406 .003 r
.24535 .31256 .2493 .31656 .25409 .32749 .25018 .32287 Mtetra
.95 .602 .309 r
.25018 .32287 .25409 .32749 .25775 .3525 .25391 .34679 Mtetra
.949 .593 .256 r
.25391 .34679 .25775 .3525 .26172 .37526 .25792 .36863 Mtetra
.149 .358 .814 r
.25792 .36863 .26172 .37526 .26733 .37883 .26354 .37211 Mtetra
.885 .701 .648 r
.26354 .37211 .26733 .37883 .27487 .35841 .27103 .35253 Mtetra
.918 .709 .605 r
.27103 .35253 .27487 .35841 .28325 .32617 .27937 .32147 Mtetra
.916 .728 .634 r
.27937 .32147 .28325 .32617 .29086 .30305 .28696 .29901 Mtetra
.275 .568 .936 r
.28696 .29901 .29086 .30305 .29659 .30472 .29272 .30033 Mtetra
.95 .602 .306 r
.29272 .30033 .29659 .30472 .30055 .33161 .29674 .32594 Mtetra
.961 .633 .341 r
.29674 .32594 .30055 .33161 .30403 .36734 .30028 .3602 Mtetra
.92 .551 .125 r
.30028 .3602 .30403 .36734 .30872 .38729 .30499 .37947 Mtetra
.823 .675 .699 r
.30499 .37947 .30872 .38729 .3156 .37549 .31184 .36831 Mtetra
.919 .7 .59 r
.31184 .36831 .3156 .37549 .32408 .33797 .32027 .3323 Mtetra
.932 .712 .583 r
.32027 .3323 .32408 .33797 .33253 .29899 .3287 .29462 Mtetra
.903 .75 .681 r
.3287 .29462 .33253 .29899 .33944 .28377 .33561 .27961 Mtetra
.925 .536 .185 r
.33561 .27961 .33944 .28377 .34434 .30275 .34055 .29748 Mtetra
.962 .638 .351 r
.34055 .29748 .34434 .30275 .34802 .34509 .34429 .33798 Mtetra
.965 .636 .307 r
.34429 .33798 .34802 .34509 .35212 .38321 .34843 .37467 Mtetra
0 .188 .705 r
.34843 .37467 .35212 .38321 .35805 .38943 .35434 .3809 Mtetra
.907 .691 .6 r
.35434 .3809 .35805 .38943 .36596 .35717 .36221 .35013 Mtetra
.936 .703 .56 r
.36221 .35013 .36596 .35717 .37461 .30712 .37083 .30196 Mtetra
.939 .721 .582 r
.37083 .30196 .37461 .30712 .38242 .27151 .37865 .26736 Mtetra
.423 .643 .948 r
.37865 .26736 .38242 .27151 .38851 .2724 .38476 .26773 Mtetra
.957 .62 .315 r
.38476 .26773 .38851 .2724 .3931 .30945 .38939 .30299 Mtetra
.967 .646 .338 r
.38939 .30299 .3931 .30945 .39735 .35937 .39366 .35088 Mtetra
.935 .588 .162 r
.39366 .35088 .39735 .35937 .40264 .3879 .39895 .3785 Mtetra
.831 .661 .672 r
.39895 .3785 .40264 .3879 .40962 .37319 .40591 .3647 Mtetra
.933 .696 .557 r
.40591 .3647 .40962 .37319 .41775 .32384 .41403 .31741 Mtetra
.946 .708 .547 r
.41403 .31741 .41775 .32384 .42579 .27205 .42207 .26739 Mtetra
.932 .744 .625 r
.42207 .26739 .42579 .27205 .43276 .24959 .42906 .24532 Mtetra
.909 .508 .118 r
.42906 .24532 .43276 .24959 .43849 .26894 .43481 .26348 Mtetra
.963 .635 .321 r
.43481 .26348 .43849 .26894 .44357 .31732 .43989 .30975 Mtetra
.964 .633 .28 r
.43989 .30975 .44357 .31732 .44895 .36261 .44526 .35331 Mtetra
0 .012 .584 r
.44526 .35331 .44895 .36261 .45532 .37234 .45162 .36292 Mtetra
.914 .69 .585 r
.45162 .36292 .45532 .37234 .46262 .33803 .45892 .3302 Mtetra
.946 .702 .536 r
.45892 .3302 .46262 .33803 .47018 .28221 .46651 .27651 Mtetra
.951 .72 .552 r
.46651 .27651 .47018 .28221 .47732 .23996 .47369 .23555 Mtetra
.783 .771 .841 r
.47369 .23555 .47732 .23996 .48381 .23511 .4802 .23048 Mtetra
.947 .589 .237 r
.4802 .23048 .48381 .23511 .48988 .26817 .48625 .26196 Mtetra
.962 .628 .282 r
.48625 .26196 .48988 .26817 .49597 .31655 .4923 .30835 Mtetra
.916 .562 .111 r
.4923 .30835 .49597 .31655 .50242 .34663 .49872 .33732 Mtetra
.797 .652 .702 r
.49872 .33732 .50242 .34663 .50922 .33606 .50553 .32733 Mtetra
.939 .7 .55 r
.50553 .32733 .50922 .33606 .5161 .2911 .51246 .28418 Mtetra
.954 .711 .532 r
.51246 .28418 .5161 .2911 .52283 .2408 .51924 .23567 Mtetra
.945 .742 .598 r
.51924 .23567 .52283 .2408 .52939 .21479 .52584 .21039 Mtetra
.674 .214 0 r
.52584 .21039 .52939 .21479 .53601 .22553 .53245 .22047 Mtetra
.947 .592 .222 r
.53245 .22047 .53601 .22553 .54285 .26305 .53925 .25639 Mtetra
.942 .589 .186 r
.53925 .25639 .54285 .26305 .54988 .30074 .54623 .29254 Mtetra
0 0 .566 r
.54623 .29254 .54988 .30074 .55683 .31136 .55317 .30272 Mtetra
.909 .7 .608 r
.55317 .30272 .55683 .31136 .56342 .28639 .55979 .2787 Mtetra
.951 .71 .537 r
.55979 .2787 .56342 .28639 .56963 .24204 .56608 .23599 Mtetra
.956 .726 .551 r
.56608 .23599 .56963 .24204 .57581 .20557 .57233 .20079 Mtetra
.864 .777 .763 r
.57233 .20079 .57581 .20557 .58238 .19648 .57892 .19193 Mtetra
.863 .451 0 r
.57892 .19193 .58238 .19648 .58955 .2162 .58605 .21081 Mtetra
.925 .555 .139 r
.58605 .21081 .58955 .2162 .59713 .2486 .59357 .24185 Mtetra
.81 .424 0 r
.59357 .24185 .59713 .2486 .60459 .2697 .60099 .26199 Mtetra
.752 .666 .766 r
.60099 .26199 .60459 .2697 .61142 .26361 .60783 .25597 Mtetra
.938 .717 .576 r
.60783 .25597 .61142 .26361 .61752 .23364 .61399 .22703 Mtetra
.955 .725 .55 r
.61399 .22703 .61752 .23364 .62335 .19867 .61991 .19331 Mtetra
.939 .757 .628 r
.61991 .19331 .62335 .19867 .62957 .17866 .62618 .17403 Mtetra
.089 .416 .864 r
.62618 .17403 .62957 .17866 .6366 .1822 .63321 .17744 Mtetra
.844 .433 0 r
.63321 .17744 .6366 .1822 .64435 .20278 .64092 .19718 Mtetra
.817 .415 0 r
.64092 .19718 .64435 .20278 .65223 .22356 .64874 .217 Mtetra
.145 .362 .819 r
.64874 .217 .65223 .22356 .65954 .22841 .65603 .22143 Mtetra
.897 .73 .667 r
.65603 .22143 .65954 .22841 .66594 .21287 .66247 .20626 Mtetra
.947 .735 .583 r
.66247 .20626 .66594 .21287 .67178 .18649 .66838 .18076 Mtetra
.946 .753 .612 r
.66838 .18076 .67178 .18649 .67776 .16488 .67444 .15996 Mtetra
.801 .774 .828 r
.67444 .15996 .67776 .16488 .6845 .15872 .68121 .15407 Mtetra
0 0 .532 r
.68121 .15407 .6845 .15872 .6921 .16789 .68879 .16289 Mtetra
.681 .255 0 r
.68879 .16289 .6921 .16789 .70009 .18262 .69674 .17695 Mtetra
0 .16 .699 r
.69674 .17695 .70009 .18262 .70776 .19034 .70437 .18415 Mtetra
.784 .726 .799 r
.70437 .18415 .70776 .19034 .71462 .18421 .71125 .17799 Mtetra
.924 .753 .652 r
.71125 .17799 .71462 .18421 .72078 .16733 .71746 .16158 Mtetra
.936 .763 .643 r
.71746 .16158 .72078 .16733 .72683 .14959 .72357 .14445 Mtetra
.87 .784 .764 r
.72357 .14445 .72683 .14959 .73341 .14021 .7302 .13545 Mtetra
.333 .567 .924 r
.7302 .13545 .73341 .14021 .74078 .1418 .73757 .13699 Mtetra
0 .13 .668 r
.73757 .13699 .74078 .1418 .74864 .14952 .74541 .14434 Mtetra
0 .32 .808 r
.74541 .14434 .74864 .14952 .7564 .15498 .75314 .1494 Mtetra
.669 .707 .877 r
.75314 .1494 .7564 .15498 .76356 .15232 .76031 .14661 Mtetra
.874 .771 .744 r
.76031 .14661 .76356 .15232 .77013 .14224 .76691 .13674 Mtetra
.634 .705 .898 r
.12965 .36145 .13372 .36582 .13936 .36416 .13531 .35978 Mtetra
.811 .739 .784 r
.13531 .35978 .13936 .36416 .14563 .35742 .14156 .35323 Mtetra
.84 .745 .758 r
.14156 .35323 .14563 .35742 .15211 .34889 .14802 .34495 Mtetra
.773 .756 .837 r
.14802 .34495 .15211 .34889 .15811 .34428 .15403 .34041 Mtetra
0 .36 .819 r
.15403 .34041 .15811 .34428 .16326 .34724 .15921 .34314 Mtetra
.823 .359 0 r
.15921 .34314 .16326 .34724 .16776 .35625 .16375 .35169 Mtetra
.785 .32 0 r
.16375 .35169 .16776 .35625 .17235 .3649 .16838 .35991 Mtetra
.379 .568 .911 r
.16838 .35991 .17235 .3649 .17782 .36598 .17386 .36088 Mtetra
.833 .722 .741 r
.17386 .36088 .17782 .36598 .18441 .35678 .18043 .35198 Mtetra
.88 .726 .687 r
.18043 .35198 .18441 .35678 .19159 .34181 .18758 .33753 Mtetra
.869 .743 .721 r
.18758 .33753 .19159 .34181 .19838 .33033 .19435 .32639 Mtetra
.503 .685 .948 r
.19435 .32639 .19838 .33033 .204 .33013 .19999 .32606 Mtetra
.887 .46 .09 r
.19999 .32606 .204 .33013 .20842 .34214 .20446 .33746 Mtetra
.93 .547 .21 r
.20446 .33746 .20842 .34214 .21245 .35886 .20854 .35341 Mtetra
.755 .312 0 r
.20854 .35341 .21245 .35886 .21725 .36832 .21337 .36245 Mtetra
.774 .695 .776 r
.21337 .36245 .21725 .36832 .22358 .36221 .21968 .35656 Mtetra
.891 .713 .655 r
.21968 .35656 .22358 .36221 .23116 .34258 .22723 .33766 Mtetra
.904 .723 .647 r
.22723 .33766 .23116 .34258 .23883 .32137 .23487 .31718 Mtetra
.85 .755 .757 r
.23487 .31718 .23883 .32137 .24535 .31256 .24138 .30854 Mtetra
.836 .38 0 r
.24138 .30854 .24535 .31256 .25018 .32287 .24626 .31826 Mtetra
.948 .597 .298 r
.24626 .31826 .25018 .32287 .25391 .34679 .25005 .34108 Mtetra
.946 .586 .243 r
.25005 .34108 .25391 .34679 .25792 .36863 .25411 .36199 Mtetra
.16 .365 .817 r
.25411 .36199 .25792 .36863 .26354 .37211 .25973 .36537 Mtetra
.882 .701 .653 r
.25973 .36537 .26354 .37211 .27103 .35253 .26718 .34662 Mtetra
.916 .709 .608 r
.26718 .34662 .27103 .35253 .27937 .32147 .27547 .31673 Mtetra
.914 .729 .638 r
.27547 .31673 .27937 .32147 .28696 .29901 .28304 .29495 Mtetra
.329 .597 .944 r
.28304 .29495 .28696 .29901 .29272 .30033 .28883 .29593 Mtetra
.948 .596 .295 r
.28883 .29593 .29272 .30033 .29674 .32594 .29292 .32029 Mtetra
.96 .63 .333 r
.29292 .32029 .29674 .32594 .30028 .3602 .29651 .35308 Mtetra
.914 .542 .108 r
.29651 .35308 .30028 .3602 .30499 .37947 .30125 .37165 Mtetra
.816 .673 .704 r
.30125 .37165 .30499 .37947 .31184 .36831 .30807 .36109 Mtetra
.917 .7 .593 r
.30807 .36109 .31184 .36831 .32027 .3323 .31645 .32658 Mtetra
.93 .712 .586 r
.31645 .32658 .32027 .3323 .3287 .29462 .32484 .29022 Mtetra
.901 .75 .684 r
.32484 .29022 .3287 .29462 .33561 .27961 .33177 .27544 Mtetra
.918 .522 .162 r
.33177 .27544 .33561 .27961 .34055 .29748 .33676 .29224 Mtetra
.961 .635 .345 r
.33676 .29224 .34055 .29748 .34429 .33798 .34056 .33091 Mtetra
.964 .633 .3 r
.34056 .33091 .34429 .33798 .34843 .37467 .34472 .36614 Mtetra
0 .187 .705 r
.34472 .36614 .34843 .37467 .35434 .3809 .35063 .37235 Mtetra
.904 .69 .604 r
.35063 .37235 .35434 .3809 .36221 .35013 .35845 .34304 Mtetra
.935 .703 .563 r
.35845 .34304 .36221 .35013 .37083 .30196 .36705 .29675 Mtetra
.937 .722 .585 r
.36705 .29675 .37083 .30196 .37865 .26736 .37486 .26317 Mtetra
.478 .669 .947 r
.37486 .26317 .37865 .26736 .38476 .26773 .381 .26307 Mtetra
.956 .615 .306 r
.381 .26307 .38476 .26773 .38939 .30299 .38567 .29657 Mtetra
.966 .643 .332 r
.38567 .29657 .38939 .30299 .39366 .35088 .38997 .34243 Mtetra
.931 .582 .15 r
.38997 .34243 .39366 .35088 .39895 .3785 .39525 .36911 Mtetra
.824 .658 .678 r
.39525 .36911 .39895 .3785 .40591 .3647 .4022 .35617 Mtetra
.931 .696 .561 r
.4022 .35617 .40591 .3647 .41403 .31741 .4103 .31091 Mtetra
.945 .709 .55 r
.4103 .31091 .41403 .31741 .42207 .26739 .41834 .26267 Mtetra
.931 .744 .628 r
.41834 .26267 .42207 .26739 .42906 .24532 .42535 .24104 Mtetra
.899 .491 .092 r
.42535 .24104 .42906 .24532 .43481 .26348 .43112 .25805 Mtetra
.963 .631 .314 r
.43112 .25805 .43481 .26348 .43989 .30975 .43621 .30222 Mtetra
.962 .63 .272 r
.43621 .30222 .43989 .30975 .44526 .35331 .44157 .34404 Mtetra
0 .018 .589 r
.44157 .34404 .44526 .35331 .45162 .36292 .44791 .35349 Mtetra
.911 .689 .59 r
.44791 .35349 .45162 .36292 .45892 .3302 .45522 .32231 Mtetra
.945 .702 .54 r
.45522 .32231 .45892 .3302 .46651 .27651 .46283 .27074 Mtetra
.95 .72 .556 r
.46283 .27074 .46651 .27651 .47369 .23555 .47004 .2311 Mtetra
.788 .771 .837 r
.47004 .2311 .47369 .23555 .4802 .23048 .47656 .22584 Mtetra
.945 .583 .225 r
.47656 .22584 .4802 .23048 .48625 .26196 .4826 .25578 Mtetra
.961 .624 .275 r
.4826 .25578 .48625 .26196 .4923 .30835 .48863 .30019 Mtetra
.91 .555 .097 r
.48863 .30019 .4923 .30835 .49872 .33732 .49503 .32803 Mtetra
.79 .649 .707 r
.49503 .32803 .49872 .33732 .50553 .32733 .50184 .31858 Mtetra
.937 .7 .554 r
.50184 .31858 .50553 .32733 .51246 .28418 .50881 .27721 Mtetra
.953 .711 .535 r
.50881 .27721 .51246 .28418 .51924 .23567 .51564 .23049 Mtetra
.943 .743 .602 r
.51564 .23049 .51924 .23567 .52584 .21039 .52228 .20596 Mtetra
.639 .176 0 r
.52228 .20596 .52584 .21039 .53245 .22047 .52888 .21541 Mtetra
.945 .587 .213 r
.52888 .21541 .53245 .22047 .53925 .25639 .53564 .24975 Mtetra
.938 .583 .176 r
.53564 .24975 .53925 .25639 .54623 .29254 .54258 .28436 Mtetra
0 .011 .587 r
.54258 .28436 .54623 .29254 .55317 .30272 .5495 .29408 Mtetra
.906 .7 .613 r
.5495 .29408 .55317 .30272 .55979 .2787 .55615 .27099 Mtetra
.949 .71 .542 r
.55615 .27099 .55979 .2787 .56608 .23599 .56251 .2299 Mtetra
.954 .727 .556 r
.56251 .2299 .56608 .23599 .57233 .20079 .56882 .19598 Mtetra
.86 .776 .768 r
.56882 .19598 .57233 .20079 .57892 .19193 .57544 .18736 Mtetra
.853 .437 0 r
.57544 .18736 .57892 .19193 .58605 .21081 .58254 .20541 Mtetra
.92 .547 .127 r
.58254 .20541 .58605 .21081 .59357 .24185 .59001 .2351 Mtetra
.793 .406 0 r
.59001 .2351 .59357 .24185 .60099 .26199 .59739 .25427 Mtetra
.751 .666 .767 r
.59739 .25427 .60099 .26199 .60783 .25597 .60423 .24832 Mtetra
.936 .717 .581 r
.60423 .24832 .60783 .25597 .61399 .22703 .61046 .22039 Mtetra
.954 .726 .555 r
.61046 .22039 .61399 .22703 .61991 .19331 .61645 .18792 Mtetra
.936 .758 .635 r
.61645 .18792 .61991 .19331 .62618 .17403 .62277 .16938 Mtetra
.104 .427 .87 r
.62277 .16938 .62618 .17403 .63321 .17744 .62981 .17266 Mtetra
.834 .42 0 r
.62981 .17266 .63321 .17744 .64092 .19718 .63747 .19157 Mtetra
.802 .397 0 r
.63747 .19157 .64092 .19718 .64874 .217 .64524 .21044 Mtetra
.184 .389 .83 r
.64524 .21044 .64874 .217 .65603 .22143 .65251 .21444 Mtetra
.894 .73 .67 r
.65251 .21444 .65603 .22143 .66247 .20626 .65899 .19963 Mtetra
.945 .736 .588 r
.65899 .19963 .66247 .20626 .66838 .18076 .66498 .17501 Mtetra
.943 .755 .619 r
.66498 .17501 .66838 .18076 .67444 .15996 .6711 .15501 Mtetra
.793 .772 .834 r
.6711 .15501 .67444 .15996 .68121 .15407 .6779 .1494 Mtetra
0 .007 .555 r
.6779 .1494 .68121 .15407 .68879 .16289 .68546 .15788 Mtetra
.657 .23 0 r
.68546 .15788 .68879 .16289 .69674 .17695 .69336 .17126 Mtetra
0 .197 .727 r
.69336 .17126 .69674 .17695 .70437 .18415 .70097 .17793 Mtetra
.784 .727 .799 r
.70097 .17793 .70437 .18415 .71125 .17799 .70786 .17176 Mtetra
.921 .753 .657 r
.70786 .17176 .71125 .17799 .71746 .16158 .71412 .1558 Mtetra
.933 .764 .65 r
.71412 .1558 .71746 .16158 .72357 .14445 .7203 .13929 Mtetra
.863 .784 .772 r
.7203 .13929 .72357 .14445 .7302 .13545 .72697 .13067 Mtetra
.337 .57 .925 r
.72697 .13067 .7302 .13545 .73757 .13699 .73435 .13215 Mtetra
0 .157 .691 r
.73435 .13215 .73757 .13699 .74541 .14434 .74216 .13913 Mtetra
.039 .348 .825 r
.74216 .13913 .74541 .14434 .75314 .1494 .74987 .1438 Mtetra
.674 .71 .875 r
.74987 .1438 .75314 .1494 .76031 .14661 .75704 .14089 Mtetra
.871 .77 .748 r
.75704 .14089 .76031 .14661 .76691 .13674 .76368 .13122 Mtetra
.634 .706 .898 r
.12558 .35706 .12965 .36145 .13531 .35978 .13124 .35539 Mtetra
.807 .739 .788 r
.13124 .35539 .13531 .35978 .14156 .35323 .13748 .34903 Mtetra
.837 .745 .762 r
.13748 .34903 .14156 .35323 .14802 .34495 .14392 .34099 Mtetra
.77 .755 .839 r
.14392 .34099 .14802 .34495 .15403 .34041 .14994 .33653 Mtetra
0 .397 .845 r
.14994 .33653 .15403 .34041 .15921 .34314 .15514 .33903 Mtetra
.802 .331 0 r
.15514 .33903 .15921 .34314 .16375 .35169 .15972 .34712 Mtetra
.759 .289 0 r
.15972 .34712 .16375 .35169 .16838 .35991 .16439 .35491 Mtetra
.392 .575 .911 r
.16439 .35491 .16838 .35991 .17386 .36088 .16988 .35577 Mtetra
.83 .722 .746 r
.16988 .35577 .17386 .36088 .18043 .35198 .17643 .34718 Mtetra
.878 .727 .691 r
.17643 .34718 .18043 .35198 .18758 .33753 .18355 .33324 Mtetra
.866 .743 .725 r
.18355 .33324 .18758 .33753 .19435 .32639 .19031 .32243 Mtetra
.517 .691 .947 r
.19031 .32243 .19435 .32639 .19999 .32606 .19596 .32198 Mtetra
.876 .441 .06 r
.19596 .32198 .19999 .32606 .20446 .33746 .20048 .33278 Mtetra
.925 .537 .191 r
.20048 .33278 .20446 .33746 .20854 .35341 .20461 .34797 Mtetra
.728 .282 0 r
.20461 .34797 .20854 .35341 .21337 .36245 .20948 .35657 Mtetra
.769 .694 .78 r
.20948 .35657 .21337 .36245 .21968 .35656 .21578 .3509 Mtetra
.888 .713 .659 r
.21578 .3509 .21968 .35656 .22723 .33766 .22328 .33273 Mtetra
.902 .724 .651 r
.22328 .33273 .22723 .33766 .23487 .31718 .23088 .31297 Mtetra
.848 .755 .76 r
.23088 .31297 .23487 .31718 .24138 .30854 .2374 .30451 Mtetra
.815 .35 0 r
.2374 .30451 .24138 .30854 .24626 .31826 .24232 .31364 Mtetra
.946 .59 .286 r
.24232 .31364 .24626 .31826 .25005 .34108 .24618 .33538 Mtetra
.943 .579 .229 r
.24618 .33538 .25005 .34108 .25411 .36199 .25029 .35537 Mtetra
.172 .374 .821 r
.25029 .35537 .25411 .36199 .25973 .36537 .25592 .35863 Mtetra
.879 .701 .657 r
.25592 .35863 .25973 .36537 .26718 .34662 .26333 .34068 Mtetra
.915 .71 .612 r
.26333 .34068 .26718 .34662 .27547 .31673 .27157 .31195 Mtetra
.912 .729 .641 r
.27157 .31195 .27547 .31673 .28304 .29495 .27911 .29086 Mtetra
.375 .621 .948 r
.27911 .29086 .28304 .29495 .28883 .29593 .28493 .29153 Mtetra
.946 .59 .283 r
.28493 .29153 .28883 .29593 .29292 .32029 .28908 .31466 Mtetra
.959 .626 .325 r
.28908 .31466 .29292 .32029 .29651 .35308 .29274 .34599 Mtetra
.907 .532 .09 r
.29274 .34599 .29651 .35308 .30125 .37165 .2975 .36383 Mtetra
.81 .671 .71 r
.2975 .36383 .30125 .37165 .30807 .36109 .30429 .35385 Mtetra
.916 .7 .597 r
.30429 .35385 .30807 .36109 .31645 .32658 .31262 .32081 Mtetra
.929 .713 .589 r
.31262 .32081 .31645 .32658 .32484 .29022 .32098 .28577 Mtetra
.9 .75 .686 r
.32098 .28577 .32484 .29022 .33177 .27544 .32791 .27126 Mtetra
.91 .506 .137 r
.32791 .27126 .33177 .27544 .33676 .29224 .33295 .28702 Mtetra
.96 .631 .338 r
.33295 .28702 .33676 .29224 .34056 .33091 .3368 .32388 Mtetra
.962 .629 .292 r
.3368 .32388 .34056 .33091 .34472 .36614 .341 .35765 Mtetra
0 .188 .706 r
.341 .35765 .34472 .36614 .35063 .37235 .34691 .3638 Mtetra
.901 .69 .608 r
.34691 .3638 .35063 .37235 .35845 .34304 .35469 .3359 Mtetra
.933 .703 .566 r
.35469 .3359 .35845 .34304 .36705 .29675 .36325 .29148 Mtetra
.936 .722 .588 r
.36325 .29148 .36705 .29675 .37486 .26317 .37106 .25894 Mtetra
.523 .688 .942 r
.37106 .25894 .37486 .26317 .381 .26307 .37723 .25841 Mtetra
.954 .61 .296 r
.37723 .25841 .381 .26307 .38567 .29657 .38193 .2902 Mtetra
.965 .64 .326 r
.38193 .2902 .38567 .29657 .38997 .34243 .38626 .33404 Mtetra
.927 .575 .138 r
.38626 .33404 .38997 .34243 .39525 .36911 .39155 .35974 Mtetra
.817 .656 .684 r
.39155 .35974 .39525 .36911 .4022 .35617 .39848 .34761 Mtetra
.929 .696 .564 r
.39848 .34761 .4022 .35617 .4103 .31091 .40656 .30436 Mtetra
.944 .709 .553 r
.40656 .30436 .4103 .31091 .41834 .26267 .4146 .25791 Mtetra
.929 .744 .631 r
.4146 .25791 .41834 .26267 .42535 .24104 .42163 .23674 Mtetra
.888 .472 .062 r
.42163 .23674 .42535 .24104 .43112 .25805 .42741 .25264 Mtetra
.961 .628 .307 r
.42741 .25264 .43112 .25805 .43621 .30222 .43251 .29475 Mtetra
.961 .626 .265 r
.43251 .29475 .43621 .30222 .44157 .34404 .43787 .33482 Mtetra
0 .027 .596 r
.43787 .33482 .44157 .34404 .44791 .35349 .4442 .34406 Mtetra
.908 .689 .595 r
.4442 .34406 .44791 .35349 .45522 .32231 .45151 .31438 Mtetra
.944 .702 .543 r
.45151 .31438 .45522 .32231 .46283 .27074 .45914 .26491 Mtetra
.949 .72 .559 r
.45914 .26491 .46283 .27074 .47004 .2311 .46638 .22662 Mtetra
.792 .77 .833 r
.46638 .22662 .47004 .2311 .47656 .22584 .47291 .22121 Mtetra
.941 .576 .213 r
.47291 .22121 .47656 .22584 .4826 .25578 .47895 .24964 Mtetra
.959 .62 .268 r
.47895 .24964 .4826 .25578 .48863 .30019 .48495 .29207 Mtetra
.904 .546 .082 r
.48495 .29207 .48863 .30019 .49503 .32803 .49132 .31878 Mtetra
.783 .647 .711 r
.49132 .31878 .49503 .32803 .50184 .31858 .49814 .30981 Mtetra
.935 .7 .558 r
.49814 .30981 .50184 .31858 .50881 .27721 .50515 .27019 Mtetra
.951 .712 .539 r
.50515 .27019 .50881 .27721 .51564 .23049 .51203 .22526 Mtetra
.942 .743 .607 r
.51203 .22526 .51564 .23049 .52228 .20596 .5187 .20151 Mtetra
.599 .136 0 r
.5187 .20151 .52228 .20596 .52888 .21541 .5253 .21036 Mtetra
.942 .581 .203 r
.5253 .21036 .52888 .21541 .53564 .24975 .53202 .24313 Mtetra
.935 .577 .164 r
.53202 .24313 .53564 .24975 .54258 .28436 .53891 .2762 Mtetra
0 .039 .608 r
.53891 .2762 .54258 .28436 .5495 .29408 .54582 .28545 Mtetra
.903 .699 .618 r
.54582 .28545 .5495 .29408 .55615 .27099 .55251 .26326 Mtetra
.948 .71 .546 r
.55251 .26326 .55615 .27099 .56251 .2299 .55894 .22378 Mtetra
.953 .728 .561 r
.55894 .22378 .56251 .2299 .56882 .19598 .56531 .19114 Mtetra
.855 .776 .773 r
.56531 .19114 .56882 .19598 .57544 .18736 .57194 .18278 Mtetra
.842 .422 0 r
.57194 .18278 .57544 .18736 .58254 .20541 .57902 .20001 Mtetra
.915 .539 .113 r
.57902 .20001 .58254 .20541 .59001 .2351 .58643 .22836 Mtetra
.775 .386 0 r
.58643 .22836 .59001 .2351 .59739 .25427 .59377 .24656 Mtetra
.75 .666 .769 r
.59377 .24656 .59739 .25427 .60423 .24832 .60062 .24066 Mtetra
.934 .717 .586 r
.60062 .24066 .60423 .24832 .61046 .22039 .60691 .21373 Mtetra
.952 .727 .561 r
.60691 .21373 .61046 .22039 .61645 .18792 .61298 .18251 Mtetra
.933 .759 .642 r
.61298 .18251 .61645 .18792 .62277 .16938 .61935 .16471 Mtetra
.119 .437 .875 r
.61935 .16471 .62277 .16938 .62981 .17266 .62639 .16786 Mtetra
.822 .404 0 r
.62639 .16786 .62981 .17266 .63747 .19157 .63401 .18594 Mtetra
.785 .378 0 r
.63401 .18594 .63747 .19157 .64524 .21044 .64173 .20386 Mtetra
.222 .414 .84 r
.64173 .20386 .64524 .21044 .65251 .21444 .64898 .20743 Mtetra
.892 .73 .674 r
.64898 .20743 .65251 .21444 .65899 .19963 .6555 .193 Mtetra
.943 .736 .594 r
.6555 .193 .65899 .19963 .66498 .17501 .66156 .16925 Mtetra
.94 .756 .626 r
.66156 .16925 .66498 .17501 .6711 .15501 .66775 .15005 Mtetra
.784 .77 .841 r
.66775 .15005 .6711 .15501 .6779 .1494 .67457 .14471 Mtetra
0 .032 .578 r
.67457 .14471 .6779 .1494 .68546 .15788 .68211 .15284 Mtetra
.631 .203 0 r
.68211 .15284 .68546 .15788 .69336 .17126 .68998 .16555 Mtetra
0 .235 .753 r
.68998 .16555 .69336 .17126 .70097 .17793 .69756 .1717 Mtetra
.785 .727 .799 r
.69756 .1717 .70097 .17793 .70786 .17176 .70446 .16551 Mtetra
.918 .754 .662 r
.70446 .16551 .70786 .17176 .71412 .1558 .71077 .15002 Mtetra
.929 .765 .657 r
.71077 .15002 .71412 .1558 .7203 .13929 .71702 .13412 Mtetra
.856 .783 .78 r
.71702 .13412 .7203 .13929 .72697 .13067 .72373 .12586 Mtetra
.342 .573 .925 r
.72373 .12586 .72697 .13067 .73435 .13215 .73111 .12729 Mtetra
0 .186 .713 r
.73111 .12729 .73435 .13215 .74216 .13913 .7389 .13389 Mtetra
.078 .377 .841 r
.7389 .13389 .74216 .13913 .74987 .1438 .74658 .13817 Mtetra
.679 .712 .873 r
.74658 .13817 .74987 .1438 .75704 .14089 .75375 .13514 Mtetra
.867 .77 .752 r
.75375 .13514 .75704 .14089 .76368 .13122 .76043 .12568 Mtetra
.634 .706 .898 r
.12148 .35266 .12558 .35706 .13124 .35539 .12715 .35099 Mtetra
.804 .739 .792 r
.12715 .35099 .13124 .35539 .13748 .34903 .13338 .34482 Mtetra
.834 .745 .766 r
.13338 .34482 .13748 .34903 .14392 .34099 .13981 .33702 Mtetra
.768 .755 .841 r
.13981 .33702 .14392 .34099 .14994 .33653 .14582 .33263 Mtetra
.033 .431 .868 r
.14582 .33263 .14994 .33653 .15514 .33903 .15105 .3349 Mtetra
.778 .299 0 r
.15105 .3349 .15514 .33903 .15972 .34712 .15568 .34254 Mtetra
.73 .254 0 r
.15568 .34254 .15972 .34712 .16439 .35491 .16038 .34991 Mtetra
.405 .582 .912 r
.16038 .34991 .16439 .35491 .16988 .35577 .16589 .35066 Mtetra
.826 .722 .75 r
.16589 .35066 .16988 .35577 .17643 .34718 .17242 .34236 Mtetra
.875 .728 .696 r
.17242 .34236 .17643 .34718 .18355 .33324 .17951 .32892 Mtetra
.863 .744 .729 r
.17951 .32892 .18355 .33324 .19031 .32243 .18624 .31845 Mtetra
.529 .695 .945 r
.18624 .31845 .19031 .32243 .19596 .32198 .19192 .31788 Mtetra
.863 .42 .028 r
.19192 .31788 .19596 .32198 .20048 .33278 .19648 .32809 Mtetra
.92 .525 .17 r
.19648 .32809 .20048 .33278 .20461 .34797 .20068 .34253 Mtetra
.697 .249 0 r
.20068 .34253 .20461 .34797 .20948 .35657 .20557 .3507 Mtetra
.765 .694 .784 r
.20557 .3507 .20948 .35657 .21578 .3509 .21186 .34523 Mtetra
.886 .714 .663 r
.21186 .34523 .21578 .3509 .22328 .33273 .21932 .32778 Mtetra
.9 .724 .655 r
.21932 .32778 .22328 .33273 .23088 .31297 .22689 .30874 Mtetra
.845 .755 .764 r
.22689 .30874 .23088 .31297 .2374 .30451 .2334 .30047 Mtetra
.79 .317 0 r
.2334 .30047 .2374 .30451 .24232 .31364 .23836 .30903 Mtetra
.944 .583 .273 r
.23836 .30903 .24232 .31364 .24618 .33538 .24229 .3297 Mtetra
.94 .571 .213 r
.24229 .3297 .24618 .33538 .25029 .35537 .24646 .34877 Mtetra
.186 .384 .826 r
.24646 .34877 .25029 .35537 .25592 .35863 .25209 .3519 Mtetra
.876 .701 .662 r
.25209 .3519 .25592 .35863 .26333 .34068 .25946 .33473 Mtetra
.913 .71 .615 r
.25946 .33473 .26333 .34068 .27157 .31195 .26764 .30714 Mtetra
.91 .73 .645 r
.26764 .30714 .27157 .31195 .27911 .29086 .27517 .28675 Mtetra
.414 .641 .95 r
.27517 .28675 .27911 .29086 .28493 .29153 .28101 .28713 Mtetra
.944 .582 .269 r
.28101 .28713 .28493 .29153 .28908 .31466 .28522 .30906 Mtetra
.958 .622 .316 r
.28522 .30906 .28908 .31466 .29274 .34599 .28895 .33893 Mtetra
.899 .52 .071 r
.28895 .33893 .29274 .34599 .2975 .36383 .29374 .35605 Mtetra
.804 .67 .715 r
.29374 .35605 .2975 .36383 .30429 .35385 .3005 .34661 Mtetra
.914 .7 .6 r
.3005 .34661 .30429 .35385 .31262 .32081 .30878 .31501 Mtetra
.928 .713 .592 r
.30878 .31501 .31262 .32081 .32098 .28577 .31709 .28129 Mtetra
.898 .75 .689 r
.31709 .28129 .32098 .28577 .32791 .27126 .32404 .26707 Mtetra
.901 .489 .109 r
.32404 .26707 .32791 .27126 .33295 .28702 .32912 .28182 Mtetra
.959 .627 .33 r
.32912 .28182 .33295 .28702 .3368 .32388 .33304 .3169 Mtetra
.961 .625 .283 r
.33304 .3169 .3368 .32388 .341 .35765 .33728 .34922 Mtetra
0 .192 .709 r
.33728 .34922 .341 .35765 .34691 .3638 .34318 .35527 Mtetra
.898 .69 .613 r
.34318 .35527 .34691 .3638 .35469 .3359 .35092 .32874 Mtetra
.932 .703 .569 r
.35092 .32874 .35469 .3359 .36325 .29148 .35944 .28615 Mtetra
.935 .722 .592 r
.35944 .28615 .36325 .29148 .37106 .25894 .36724 .25469 Mtetra
.56 .703 .936 r
.36724 .25469 .37106 .25894 .37723 .25841 .37343 .25377 Mtetra
.953 .604 .286 r
.37343 .25377 .37723 .25841 .38193 .2902 .37818 .28388 Mtetra
.964 .637 .319 r
.37818 .28388 .38193 .2902 .38626 .33404 .38254 .32572 Mtetra
.922 .568 .125 r
.38254 .32572 .38626 .33404 .39155 .35974 .38784 .35043 Mtetra
.81 .654 .689 r
.38784 .35043 .39155 .35974 .39848 .34761 .39475 .33906 Mtetra
.928 .696 .568 r
.39475 .33906 .39848 .34761 .40656 .30436 .40281 .29776 Mtetra
.942 .709 .556 r
.40281 .29776 .40656 .30436 .4146 .25791 .41084 .25309 Mtetra
.927 .744 .634 r
.41084 .25309 .4146 .25791 .42163 .23674 .41788 .23243 Mtetra
.874 .45 .03 r
.41788 .23243 .42163 .23674 .42741 .25264 .42369 .24727 Mtetra
.96 .624 .3 r
.42369 .24727 .42741 .25264 .43251 .29475 .42881 .28735 Mtetra
.959 .622 .256 r
.42881 .28735 .43251 .29475 .43787 .33482 .43416 .32568 Mtetra
0 .038 .604 r
.43416 .32568 .43787 .33482 .4442 .34406 .44049 .33468 Mtetra
.905 .688 .599 r
.44049 .33468 .4442 .34406 .45151 .31438 .44779 .30643 Mtetra
.942 .702 .547 r
.44779 .30643 .45151 .31438 .45914 .26491 .45544 .25903 Mtetra
.947 .721 .563 r
.45544 .25903 .45914 .26491 .46638 .22662 .4627 .2221 Mtetra
.795 .77 .831 r
.4627 .2221 .46638 .22662 .47291 .22121 .46925 .21658 Mtetra
.938 .568 .2 r
.46925 .21658 .47291 .22121 .47895 .24964 .47528 .24354 Mtetra
.957 .616 .26 r
.47528 .24354 .47895 .24964 .48495 .29207 .48126 .28402 Mtetra
.897 .536 .066 r
.48126 .28402 .48495 .29207 .49132 .31878 .48761 .30957 Mtetra
.777 .645 .716 r
.48761 .30957 .49132 .31878 .49814 .30981 .49444 .30106 Mtetra
.933 .7 .562 r
.49444 .30106 .49814 .30981 .50515 .27019 .50148 .26314 Mtetra
.95 .712 .543 r
.50148 .26314 .50515 .27019 .51203 .22526 .50841 .22 Mtetra
.94 .744 .611 r
.50841 .22 .51203 .22526 .5187 .20151 .51511 .19703 Mtetra
.557 .094 0 r
.51511 .19703 .5187 .20151 .5253 .21036 .5217 .20532 Mtetra
.939 .574 .191 r
.5217 .20532 .5253 .21036 .53202 .24313 .52839 .23655 Mtetra
.93 .57 .151 r
.52839 .23655 .53202 .24313 .53891 .2762 .53524 .26809 Mtetra
0 .067 .63 r
.53524 .26809 .53891 .2762 .54582 .28545 .54213 .27685 Mtetra
.9 .699 .623 r
.54213 .27685 .54582 .28545 .55251 .26326 .54886 .25552 Mtetra
.946 .711 .55 r
.54886 .25552 .55251 .26326 .55894 .22378 .55535 .21763 Mtetra
.951 .729 .566 r
.55535 .21763 .55894 .22378 .56531 .19114 .56177 .18626 Mtetra
.85 .775 .778 r
.56177 .18626 .56531 .19114 .57194 .18278 .56843 .17818 Mtetra
.83 .405 0 r
.56843 .17818 .57194 .18278 .57902 .20001 .57548 .19461 Mtetra
.91 .53 .099 r
.57548 .19461 .57902 .20001 .58643 .22836 .58284 .22164 Mtetra
.754 .363 0 r
.58284 .22164 .58643 .22836 .59377 .24656 .59014 .23888 Mtetra
.749 .667 .77 r
.59014 .23888 .59377 .24656 .60062 .24066 .59701 .23302 Mtetra
.932 .718 .59 r
.59701 .23302 .60062 .24066 .60691 .21373 .60335 .20706 Mtetra
.95 .728 .566 r
.60335 .20706 .60691 .21373 .61298 .18251 .60949 .17708 Mtetra
.93 .76 .65 r
.60949 .17708 .61298 .18251 .61935 .16471 .61592 .16002 Mtetra
.134 .446 .88 r
.61592 .16002 .61935 .16471 .62639 .16786 .62295 .16305 Mtetra
.809 .388 0 r
.62295 .16305 .62639 .16786 .63401 .18594 .63053 .18031 Mtetra
.766 .356 0 r
.63053 .18031 .63401 .18594 .64173 .20386 .63821 .19728 Mtetra
.259 .438 .849 r
.63821 .19728 .64173 .20386 .64898 .20743 .64545 .20043 Mtetra
.889 .73 .678 r
.64545 .20043 .64898 .20743 .6555 .193 .652 .18636 Mtetra
.941 .737 .6 r
.652 .18636 .6555 .193 .66156 .16925 .65812 .16348 Mtetra
.937 .757 .633 r
.65812 .16348 .66156 .16925 .66775 .15005 .66438 .14507 Mtetra
.774 .768 .847 r
.66438 .14507 .66775 .15005 .67457 .14471 .67123 .14 Mtetra
0 .057 .601 r
.67123 .14 .67457 .14471 .68211 .15284 .67876 .14778 Mtetra
.602 .175 0 r
.67876 .14778 .68211 .15284 .68998 .16555 .68658 .15982 Mtetra
0 .272 .777 r
.68658 .15982 .68998 .16555 .69756 .1717 .69413 .16546 Mtetra
.785 .727 .799 r
.69413 .16546 .69756 .1717 .70446 .16551 .70104 .15926 Mtetra
.915 .754 .668 r
.70104 .15926 .70446 .16551 .71077 .15002 .70741 .14423 Mtetra
.926 .766 .664 r
.70741 .14423 .71077 .15002 .71702 .13412 .71372 .12894 Mtetra
.848 .782 .787 r
.71372 .12894 .71702 .13412 .72373 .12586 .72047 .12104 Mtetra
.347 .576 .926 r
.72047 .12104 .72373 .12586 .73111 .12729 .72786 .12241 Mtetra
0 .214 .735 r
.72786 .12241 .73111 .12729 .7389 .13389 .73563 .12863 Mtetra
.117 .404 .855 r
.73563 .12863 .7389 .13389 .74658 .13817 .74329 .13253 Mtetra
.684 .714 .872 r
.74329 .13253 .74658 .13817 .75375 .13514 .75046 .12939 Mtetra
.864 .77 .756 r
.75046 .12939 .75375 .13514 .76043 .12568 .75717 .12014 Mtetra
.633 .706 .899 r
.11737 .34826 .12148 .35266 .12715 .35099 .12304 .34657 Mtetra
.8 .739 .796 r
.12304 .34657 .12715 .35099 .13338 .34482 .12926 .34059 Mtetra
.83 .746 .771 r
.12926 .34059 .13338 .34482 .13981 .33702 .13567 .33303 Mtetra
.765 .755 .844 r
.13567 .33303 .13981 .33702 .14582 .33263 .14169 .32871 Mtetra
.083 .464 .888 r
.14169 .32871 .14582 .33263 .15105 .3349 .14694 .33076 Mtetra
.749 .263 0 r
.14694 .33076 .15105 .3349 .15568 .34254 .15162 .33795 Mtetra
.695 .216 0 r
.15162 .33795 .15568 .34254 .16038 .34991 .15636 .3449 Mtetra
.417 .589 .913 r
.15636 .3449 .16038 .34991 .16589 .35066 .16188 .34554 Mtetra
.822 .722 .754 r
.16188 .34554 .16589 .35066 .17242 .34236 .16839 .33753 Mtetra
.872 .728 .7 r
.16839 .33753 .17242 .34236 .17951 .32892 .17544 .32459 Mtetra
.86 .744 .734 r
.17544 .32459 .17951 .32892 .18624 .31845 .18216 .31446 Mtetra
.54 .7 .943 r
.18216 .31446 .18624 .31845 .19192 .31788 .18785 .31377 Mtetra
.847 .395 0 r
.18785 .31377 .19192 .31788 .19648 .32809 .19247 .3234 Mtetra
.913 .511 .147 r
.19247 .3234 .19648 .32809 .20068 .34253 .19672 .3371 Mtetra
.661 .213 0 r
.19672 .3371 .20068 .34253 .20557 .3507 .20165 .34483 Mtetra
.76 .693 .787 r
.20165 .34483 .20557 .3507 .21186 .34523 .20793 .33955 Mtetra
.883 .714 .668 r
.20793 .33955 .21186 .34523 .21932 .32778 .21535 .3228 Mtetra
.898 .725 .659 r
.21535 .3228 .21932 .32778 .22689 .30874 .22287 .30449 Mtetra
.842 .755 .767 r
.22287 .30449 .22689 .30874 .2334 .30047 .22938 .29641 Mtetra
.762 .281 0 r
.22938 .29641 .2334 .30047 .23836 .30903 .23439 .30442 Mtetra
.941 .575 .258 r
.23439 .30442 .23836 .30903 .24229 .3297 .23838 .32404 Mtetra
.935 .561 .195 r
.23838 .32404 .24229 .3297 .24646 .34877 .24261 .34218 Mtetra
.202 .396 .831 r
.24261 .34218 .24646 .34877 .25209 .3519 .24825 .34516 Mtetra
.872 .701 .666 r
.24825 .34516 .25209 .3519 .25946 .33473 .25558 .32875 Mtetra
.911 .711 .619 r
.25558 .32875 .25946 .33473 .26764 .30714 .26371 .3023 Mtetra
.908 .73 .649 r
.26371 .3023 .26764 .30714 .27517 .28675 .27121 .28261 Mtetra
.448 .656 .949 r
.27121 .28261 .27517 .28675 .28101 .28713 .27707 .28273 Mtetra
.941 .574 .255 r
.27707 .28273 .28101 .28713 .28522 .30906 .28135 .30347 Mtetra
.957 .617 .306 r
.28135 .30347 .28522 .30906 .28895 .33893 .28515 .33191 Mtetra
.889 .507 .049 r
.28515 .33191 .28895 .33893 .29374 .35605 .28997 .34828 Mtetra
.798 .668 .72 r
.28997 .34828 .29374 .35605 .3005 .34661 .29671 .33935 Mtetra
.911 .7 .604 r
.29671 .33935 .3005 .34661 .30878 .31501 .30492 .30916 Mtetra
.926 .713 .596 r
.30492 .30916 .30878 .31501 .31709 .28129 .3132 .27676 Mtetra
.896 .75 .692 r
.3132 .27676 .31709 .28129 .32404 .26707 .32014 .26286 Mtetra
.889 .468 .078 r
.32014 .26286 .32404 .26707 .32912 .28182 .32527 .27665 Mtetra
.958 .623 .321 r
.32527 .27665 .32912 .28182 .33304 .3169 .32926 .30997 Mtetra
.959 .62 .273 r
.32926 .30997 .33304 .3169 .33728 .34922 .33354 .34083 Mtetra
0 .199 .713 r
.33354 .34083 .33728 .34922 .34318 .35527 .33944 .34675 Mtetra
.895 .689 .618 r
.33944 .34675 .34318 .35527 .35092 .32874 .34714 .32153 Mtetra
.93 .703 .573 r
.34714 .32153 .35092 .32874 .35944 .28615 .35561 .28078 Mtetra
.933 .723 .595 r
.35561 .28078 .35944 .28615 .36724 .25469 .3634 .2504 Mtetra
.589 .713 .93 r
.3634 .2504 .36724 .25469 .37343 .25377 .36962 .24913 Mtetra
.95 .598 .274 r
.36962 .24913 .37343 .25377 .37818 .28388 .37441 .2776 Mtetra
.963 .633 .312 r
.37441 .2776 .37818 .28388 .38254 .32572 .37882 .31746 Mtetra
.916 .559 .109 r
.37882 .31746 .38254 .32572 .38784 .35043 .38413 .34116 Mtetra
.803 .652 .695 r
.38413 .34116 .38784 .35043 .39475 .33906 .39101 .33049 Mtetra
.925 .696 .572 r
.39101 .33049 .39475 .33906 .40281 .29776 .39905 .2911 Mtetra
.941 .71 .56 r
.39905 .2911 .40281 .29776 .41084 .25309 .40707 .24822 Mtetra
.926 .744 .638 r
.40707 .24822 .41084 .25309 .41788 .23243 .41412 .2281 Mtetra
.857 .426 0 r
.41412 .2281 .41788 .23243 .42369 .24727 .41995 .24193 Mtetra
.959 .619 .291 r
.41995 .24193 .42369 .24727 .42881 .28735 .42509 .28001 Mtetra
.957 .617 .247 r
.42509 .28001 .42881 .28735 .43416 .32568 .43045 .31659 Mtetra
0 .052 .615 r
.43045 .31659 .43416 .32568 .44049 .33468 .43677 .32531 Mtetra
.901 .688 .604 r
.43677 .32531 .44049 .33468 .44779 .30643 .44407 .29845 Mtetra
.941 .703 .55 r
.44407 .29845 .44779 .30643 .45544 .25903 .45172 .2531 Mtetra
.946 .721 .567 r
.45172 .2531 .45544 .25903 .4627 .2221 .459 .21753 Mtetra
.796 .769 .829 r
.459 .21753 .4627 .2221 .46925 .21658 .46557 .21195 Mtetra
.934 .559 .185 r
.46557 .21195 .46925 .21658 .47528 .24354 .47159 .23747 Mtetra
.955 .611 .251 r
.47159 .23747 .47528 .24354 .48126 .28402 .47756 .27602 Mtetra
.888 .525 .048 r
.47756 .27602 .48126 .28402 .48761 .30957 .4839 .30041 Mtetra
.771 .643 .721 r
.4839 .30041 .48761 .30957 .49444 .30106 .49072 .2923 Mtetra
.931 .7 .566 r
.49072 .2923 .49444 .30106 .50148 .26314 .49779 .25606 Mtetra
.949 .712 .547 r
.49779 .25606 .50148 .26314 .50841 .22 .50476 .21469 Mtetra
.937 .745 .617 r
.50476 .21469 .50841 .22 .51511 .19703 .5115 .19253 Mtetra
0 0 .482 r
.5115 .19253 .51511 .19703 .5217 .20532 .51809 .20028 Mtetra
.935 .567 .179 r
.51809 .20028 .5217 .20532 .52839 .23655 .52475 .23 Mtetra
.925 .562 .137 r
.52475 .23 .52839 .23655 .53524 .26809 .53156 .26001 Mtetra
0 .098 .652 r
.53156 .26001 .53524 .26809 .54213 .27685 .53844 .26826 Mtetra
.897 .699 .628 r
.53844 .26826 .54213 .27685 .54886 .25552 .54519 .24778 Mtetra
.945 .711 .555 r
.54519 .24778 .54886 .25552 .55535 .21763 .55174 .21145 Mtetra
.949 .73 .571 r
.55174 .21145 .55535 .21763 .56177 .18626 .55823 .18136 Mtetra
.844 .774 .784 r
.55823 .18136 .56177 .18626 .56843 .17818 .5649 .17356 Mtetra
.816 .387 0 r
.5649 .17356 .56843 .17818 .57548 .19461 .57193 .18921 Mtetra
.903 .52 .082 r
.57193 .18921 .57548 .19461 .58284 .22164 .57924 .21493 Mtetra
.729 .338 0 r
.57924 .21493 .58284 .22164 .59014 .23888 .58651 .2312 Mtetra
.749 .667 .771 r
.58651 .2312 .59014 .23888 .59701 .23302 .59338 .22537 Mtetra
.93 .718 .596 r
.59338 .22537 .59701 .23302 .60335 .20706 .59978 .20038 Mtetra
.948 .729 .572 r
.59978 .20038 .60335 .20706 .60949 .17708 .606 .17162 Mtetra
.926 .761 .657 r
.606 .17162 .60949 .17708 .61592 .16002 .61247 .15531 Mtetra
.147 .455 .885 r
.61247 .15531 .61592 .16002 .62295 .16305 .61951 .15822 Mtetra
.794 .369 0 r
.61951 .15822 .62295 .16305 .63053 .18031 .62705 .17467 Mtetra
.744 .332 0 r
.62705 .17467 .63053 .18031 .63821 .19728 .63468 .1907 Mtetra
.295 .462 .856 r
.63468 .1907 .63821 .19728 .64545 .20043 .6419 .19343 Mtetra
.886 .73 .682 r
.6419 .19343 .64545 .20043 .652 .18636 .64849 .17972 Mtetra
.938 .738 .606 r
.64849 .17972 .652 .18636 .65812 .16348 .65468 .1577 Mtetra
.933 .758 .641 r
.65468 .1577 .65812 .16348 .66438 .14507 .66099 .14007 Mtetra
.765 .765 .853 r
.66099 .14007 .66438 .14507 .67123 .14 .66788 .13526 Mtetra
0 .083 .624 r
.66788 .13526 .67123 .14 .67876 .14778 .67539 .1427 Mtetra
0 0 .411 r
.67539 .1427 .67876 .14778 .68658 .15982 .68317 .15407 Mtetra
.012 .309 .8 r
.68317 .15407 .68658 .15982 .69413 .16546 .6907 .1592 Mtetra
.785 .728 .799 r
.6907 .1592 .69413 .16546 .70104 .15926 .69762 .15299 Mtetra
.912 .755 .674 r
.69762 .15299 .70104 .15926 .70741 .14423 .70404 .13844 Mtetra
.922 .767 .672 r
.70404 .13844 .70741 .14423 .71372 .12894 .7104 .12374 Mtetra
.84 .781 .795 r
.7104 .12374 .71372 .12894 .72047 .12104 .7172 .1162 Mtetra
.353 .579 .927 r
.7172 .1162 .72047 .12104 .72786 .12241 .72459 .1175 Mtetra
0 .243 .756 r
.72459 .1175 .72786 .12241 .73563 .12863 .73234 .12334 Mtetra
.156 .43 .867 r
.73234 .12334 .73563 .12863 .74329 .13253 .73998 .12686 Mtetra
.688 .716 .87 r
.73998 .12686 .74329 .13253 .75046 .12939 .74715 .12362 Mtetra
.86 .769 .761 r
.74715 .12362 .75046 .12939 .75717 .12014 .7539 .11458 Mtetra
.633 .706 .899 r
.11325 .34384 .11737 .34826 .12304 .34657 .11892 .34215 Mtetra
.796 .739 .8 r
.11892 .34215 .12304 .34657 .12926 .34059 .12513 .33635 Mtetra
.827 .746 .775 r
.12513 .33635 .12926 .34059 .13567 .33303 .13152 .32903 Mtetra
.762 .755 .846 r
.13152 .32903 .13567 .33303 .14169 .32871 .13754 .32478 Mtetra
.13 .494 .905 r
.13754 .32478 .14169 .32871 .14694 .33076 .14282 .32661 Mtetra
.715 .223 0 r
.14282 .32661 .14694 .33076 .15162 .33795 .14754 .33335 Mtetra
.656 .173 0 r
.14754 .33335 .15162 .33795 .15636 .3449 .15233 .33988 Mtetra
.43 .595 .913 r
.15233 .33988 .15636 .3449 .16188 .34554 .15786 .34041 Mtetra
.818 .722 .759 r
.15786 .34041 .16188 .34554 .16839 .33753 .16435 .33269 Mtetra
.869 .729 .705 r
.16435 .33269 .16839 .33753 .17544 .32459 .17137 .32024 Mtetra
.857 .745 .738 r
.17137 .32024 .17544 .32459 .18216 .31446 .17807 .31045 Mtetra
.551 .704 .941 r
.17807 .31045 .18216 .31446 .18785 .31377 .18377 .30965 Mtetra
.828 .367 0 r
.18377 .30965 .18785 .31377 .19247 .3234 .18844 .31871 Mtetra
.904 .495 .121 r
.18844 .31871 .19247 .3234 .19672 .3371 .19275 .33166 Mtetra
.621 .172 0 r
.19275 .33166 .19672 .3371 .20165 .34483 .19772 .33896 Mtetra
.756 .692 .791 r
.19772 .33896 .20165 .34483 .20793 .33955 .20399 .33386 Mtetra
.88 .715 .672 r
.20399 .33386 .20793 .33955 .21535 .3228 .21136 .31781 Mtetra
.895 .726 .664 r
.21136 .31781 .21535 .3228 .22287 .30449 .21884 .30021 Mtetra
.839 .755 .771 r
.21884 .30021 .22287 .30449 .22938 .29641 .22534 .29233 Mtetra
.727 .239 0 r
.22534 .29233 .22938 .29641 .23439 .30442 .23039 .2998 Mtetra
.938 .566 .242 r
.23039 .2998 .23439 .30442 .23838 .32404 .23447 .31838 Mtetra
.93 .55 .175 r
.23447 .31838 .23838 .32404 .24261 .34218 .23875 .33561 Mtetra
.22 .408 .836 r
.23875 .33561 .24261 .34218 .24825 .34516 .2444 .33842 Mtetra
.869 .701 .671 r
.2444 .33842 .24825 .34516 .25558 .32875 .25169 .32276 Mtetra
.909 .711 .623 r
.25169 .32276 .25558 .32875 .26371 .3023 .25976 .29743 Mtetra
.906 .731 .654 r
.25976 .29743 .26371 .3023 .27121 .28261 .26723 .27845 Mtetra
.477 .669 .948 r
.26723 .27845 .27121 .28261 .27707 .28273 .27312 .27832 Mtetra
.937 .564 .238 r
.27312 .27832 .27707 .28273 .28135 .30347 .27746 .29791 Mtetra
.955 .611 .295 r
.27746 .29791 .28135 .30347 .28515 .33191 .28134 .32493 Mtetra
.878 .491 .024 r
.28134 .32493 .28515 .33191 .28997 .34828 .28619 .34053 Mtetra
.792 .667 .725 r
.28619 .34053 .28997 .34828 .29671 .33935 .2929 .33208 Mtetra
.909 .7 .608 r
.2929 .33208 .29671 .33935 .30492 .30916 .30106 .30328 Mtetra
.924 .714 .6 r
.30106 .30328 .30492 .30916 .3132 .27676 .30929 .2722 Mtetra
.893 .75 .696 r
.30929 .2722 .3132 .27676 .32014 .26286 .31623 .25864 Mtetra
.875 .445 .043 r
.31623 .25864 .32014 .26286 .32527 .27665 .32141 .2715 Mtetra
.957 .618 .312 r
.32141 .2715 .32527 .27665 .32926 .30997 .32546 .30309 Mtetra
.957 .614 .262 r
.32546 .30309 .32926 .30997 .33354 .34083 .3298 .33249 Mtetra
.01 .209 .72 r
.3298 .33249 .33354 .34083 .33944 .34675 .33569 .33824 Mtetra
.891 .689 .622 r
.33569 .33824 .33944 .34675 .34714 .32153 .34335 .3143 Mtetra
.929 .703 .576 r
.34335 .3143 .34714 .32153 .35561 .28078 .35178 .27535 Mtetra
.931 .723 .599 r
.35178 .27535 .35561 .28078 .3634 .2504 .35955 .24608 Mtetra
.612 .721 .923 r
.35955 .24608 .3634 .2504 .36962 .24913 .36579 .2445 Mtetra
.948 .591 .261 r
.36579 .2445 .36962 .24913 .37441 .2776 .37063 .27138 Mtetra
.962 .629 .304 r
.37063 .27138 .37441 .2776 .37882 .31746 .37508 .30927 Mtetra
.908 .549 .092 r
.37508 .30927 .37882 .31746 .38413 .34116 .3804 .33193 Mtetra
.795 .649 .701 r
.3804 .33193 .38413 .34116 .39101 .33049 .38727 .32191 Mtetra
.923 .696 .576 r
.38727 .32191 .39101 .33049 .39905 .2911 .39527 .2844 Mtetra
.94 .71 .563 r
.39527 .2844 .39905 .2911 .40707 .24822 .40329 .2433 Mtetra
.923 .745 .642 r
.40329 .2433 .40707 .24822 .41412 .2281 .41035 .22375 Mtetra
.838 .398 0 r
.41035 .22375 .41412 .2281 .41995 .24193 .4162 .23661 Mtetra
.957 .615 .282 r
.4162 .23661 .41995 .24193 .42509 .28001 .42135 .27273 Mtetra
.954 .612 .237 r
.42135 .27273 .42509 .28001 .43045 .31659 .42672 .30757 Mtetra
0 .069 .628 r
.42672 .30757 .43045 .31659 .43677 .32531 .43304 .31596 Mtetra
.898 .687 .609 r
.43304 .31596 .43677 .32531 .44407 .29845 .44033 .29044 Mtetra
.939 .703 .554 r
.44033 .29044 .44407 .29845 .45172 .2531 .448 .24711 Mtetra
.944 .722 .571 r
.448 .24711 .45172 .2531 .459 .21753 .45529 .21293 Mtetra
.796 .769 .828 r
.45529 .21293 .459 .21753 .46557 .21195 .46187 .20731 Mtetra
.929 .549 .169 r
.46187 .20731 .46557 .21195 .47159 .23747 .4679 .23144 Mtetra
.953 .606 .241 r
.4679 .23144 .47159 .23747 .47756 .27602 .47385 .26808 Mtetra
.878 .512 .028 r
.47385 .26808 .47756 .27602 .4839 .30041 .48017 .29128 Mtetra
.765 .642 .725 r
.48017 .29128 .4839 .30041 .49072 .2923 .48701 .28355 Mtetra
.929 .7 .571 r
.48701 .28355 .49072 .2923 .49779 .25606 .4941 .24894 Mtetra
.947 .713 .551 r
.4941 .24894 .49779 .25606 .50476 .21469 .50111 .20933 Mtetra
.935 .745 .622 r
.50111 .20933 .50476 .21469 .5115 .19253 .50787 .18801 Mtetra
0 0 .527 r
.50787 .18801 .5115 .19253 .51809 .20028 .51446 .19525 Mtetra
.931 .559 .165 r
.51446 .19525 .51809 .20028 .52475 .23 .52109 .22347 Mtetra
.92 .553 .122 r
.52109 .22347 .52475 .23 .53156 .26001 .52787 .25197 Mtetra
0 .13 .675 r
.52787 .25197 .53156 .26001 .53844 .26826 .53474 .25969 Mtetra
.893 .699 .632 r
.53474 .25969 .53844 .26826 .54519 .24778 .54152 .24002 Mtetra
.943 .712 .56 r
.54152 .24002 .54519 .24778 .55174 .21145 .54813 .20525 Mtetra
.947 .731 .577 r
.54813 .20525 .55174 .21145 .55823 .18136 .55466 .17644 Mtetra
.838 .773 .79 r
.55466 .17644 .55823 .18136 .5649 .17356 .56136 .16893 Mtetra
.8 .367 0 r
.56136 .16893 .5649 .17356 .57193 .18921 .56837 .18381 Mtetra
.896 .508 .064 r
.56837 .18381 .57193 .18921 .57924 .21493 .57563 .20823 Mtetra
.701 .309 0 r
.57563 .20823 .57924 .21493 .58651 .2312 .58287 .22354 Mtetra
.748 .668 .772 r
.58287 .22354 .58651 .2312 .59338 .22537 .58975 .21773 Mtetra
.927 .719 .601 r
.58975 .21773 .59338 .22537 .59978 .20038 .5962 .1937 Mtetra
.946 .73 .578 r
.5962 .1937 .59978 .20038 .606 .17162 .60248 .16616 Mtetra
.922 .762 .666 r
.60248 .16616 .606 .17162 .61247 .15531 .609 .15057 Mtetra
.16 .464 .889 r
.609 .15057 .61247 .15531 .61951 .15822 .61604 .15337 Mtetra
.777 .349 0 r
.61604 .15337 .61951 .15822 .62705 .17467 .62355 .16901 Mtetra
.719 .305 0 r
.62355 .16901 .62705 .17467 .63468 .1907 .63114 .18412 Mtetra
.329 .484 .862 r
.63114 .18412 .63468 .1907 .6419 .19343 .63834 .18643 Mtetra
.883 .73 .687 r
.63834 .18643 .6419 .19343 .64849 .17972 .64496 .17308 Mtetra
.936 .739 .612 r
.64496 .17308 .64849 .17972 .65468 .1577 .65122 .15191 Mtetra
.93 .759 .649 r
.65122 .15191 .65468 .1577 .66099 .14007 .6576 .13506 Mtetra
.754 .762 .859 r
.6576 .13506 .66099 .14007 .66788 .13526 .6645 .13051 Mtetra
0 .11 .648 r
.6645 .13051 .66788 .13526 .67539 .1427 .672 .1376 Mtetra
0 0 .447 r
.672 .1376 .67539 .1427 .68317 .15407 .67975 .14831 Mtetra
.062 .344 .82 r
.67975 .14831 .68317 .15407 .6907 .1592 .68725 .15294 Mtetra
.785 .728 .8 r
.68725 .15294 .6907 .1592 .69762 .15299 .69418 .14673 Mtetra
.908 .755 .68 r
.69418 .14673 .69762 .15299 .70404 .13844 .70065 .13263 Mtetra
.917 .768 .68 r
.70065 .13263 .70404 .13844 .7104 .12374 .70708 .11853 Mtetra
.832 .78 .803 r
.70708 .11853 .7104 .12374 .7172 .1162 .71391 .11133 Mtetra
.359 .583 .928 r
.71391 .11133 .7172 .1162 .72459 .1175 .72131 .11256 Mtetra
0 .273 .777 r
.72131 .11256 .72459 .1175 .73234 .12334 .72903 .11803 Mtetra
.193 .455 .878 r
.72903 .11803 .73234 .12334 .73998 .12686 .73665 .12118 Mtetra
.692 .718 .869 r
.73665 .12118 .73998 .12686 .74715 .12362 .74383 .11783 Mtetra
.856 .769 .765 r
.74383 .11783 .74715 .12362 .7539 .11458 .75061 .10901 Mtetra
.633 .707 .899 r
.1091 .33942 .11325 .34384 .11892 .34215 .11478 .33772 Mtetra
.792 .739 .804 r
.11478 .33772 .11892 .34215 .12513 .33635 .12098 .3321 Mtetra
.823 .747 .779 r
.12098 .3321 .12513 .33635 .13152 .32903 .12736 .32501 Mtetra
.76 .755 .848 r
.12736 .32501 .13152 .32903 .13754 .32478 .13337 .32084 Mtetra
.175 .521 .918 r
.13337 .32084 .13754 .32478 .14282 .32661 .13868 .32245 Mtetra
.676 .178 0 r
.13868 .32245 .14282 .32661 .14754 .33335 .14345 .32876 Mtetra
.612 .128 0 r
.14345 .32876 .14754 .33335 .15233 .33988 .14827 .33488 Mtetra
.441 .602 .914 r
.14827 .33488 .15233 .33988 .15786 .34041 .15382 .3353 Mtetra
.815 .723 .763 r
.15382 .3353 .15786 .34041 .16435 .33269 .16029 .32785 Mtetra
.866 .73 .71 r
.16029 .32785 .16435 .33269 .17137 .32024 .16727 .31588 Mtetra
.854 .746 .743 r
.16727 .31588 .17137 .32024 .17807 .31045 .17395 .30642 Mtetra
.56 .707 .939 r
.17395 .30642 .17807 .31045 .18377 .30965 .17968 .30552 Mtetra
.805 .336 0 r
.17968 .30552 .18377 .30965 .18844 .31871 .18439 .31402 Mtetra
.894 .477 .092 r
.18439 .31402 .18844 .31871 .19275 .33166 .18877 .32625 Mtetra
.578 .13 0 r
.18877 .32625 .19275 .33166 .19772 .33896 .19377 .33312 Mtetra
.752 .693 .795 r
.19377 .33312 .19772 .33896 .20399 .33386 .20003 .32819 Mtetra
.877 .715 .677 r
.20003 .32819 .20399 .33386 .21136 .31781 .20735 .31281 Mtetra
.893 .727 .669 r
.20735 .31281 .21136 .31781 .21884 .30021 .21479 .29591 Mtetra
.836 .755 .774 r
.21479 .29591 .21884 .30021 .22534 .29233 .22129 .28824 Mtetra
.688 .194 0 r
.22129 .28824 .22534 .29233 .23039 .2998 .22638 .2952 Mtetra
.933 .555 .224 r
.22638 .2952 .23039 .2998 .23447 .31838 .23053 .31276 Mtetra
.923 .538 .154 r
.23053 .31276 .23447 .31838 .23875 .33561 .23487 .32908 Mtetra
.236 .421 .841 r
.23487 .32908 .23875 .33561 .2444 .33842 .24053 .33173 Mtetra
.866 .701 .676 r
.24053 .33173 .2444 .33842 .25169 .32276 .24778 .31677 Mtetra
.907 .712 .628 r
.24778 .31677 .25169 .32276 .25976 .29743 .25579 .29254 Mtetra
.904 .732 .658 r
.25579 .29254 .25976 .29743 .26723 .27845 .26323 .27427 Mtetra
.501 .68 .946 r
.26323 .27427 .26723 .27845 .27312 .27832 .26914 .27392 Mtetra
.933 .554 .22 r
.26914 .27392 .27312 .27832 .27746 .29791 .27356 .29239 Mtetra
.953 .605 .283 r
.27356 .29239 .27746 .29791 .28134 .32493 .2775 .31801 Mtetra
.865 .474 0 r
.2775 .31801 .28134 .32493 .28619 .34053 .2824 .33286 Mtetra
.787 .667 .731 r
.2824 .33286 .28619 .34053 .2929 .33208 .28908 .32485 Mtetra
.907 .701 .613 r
.28908 .32485 .2929 .33208 .30106 .30328 .29718 .29739 Mtetra
.923 .714 .603 r
.29718 .29739 .30106 .30328 .30929 .2722 .30536 .2676 Mtetra
.891 .75 .7 r
.30536 .2676 .30929 .2722 .31623 .25864 .3123 .2544 Mtetra
.858 .42 .004 r
.3123 .2544 .31623 .25864 .32141 .2715 .31753 .26638 Mtetra
.955 .613 .302 r
.31753 .26638 .32141 .2715 .32546 .30309 .32165 .2963 Mtetra
.954 .608 .25 r
.32165 .2963 .32546 .30309 .3298 .33249 .32604 .32426 Mtetra
.02 .22 .727 r
.32604 .32426 .3298 .33249 .33569 .33824 .33193 .32981 Mtetra
.888 .689 .627 r
.33193 .32981 .33569 .33824 .34335 .3143 .33955 .30708 Mtetra
.927 .704 .58 r
.33955 .30708 .34335 .3143 .35178 .27535 .34793 .26989 Mtetra
.93 .724 .603 r
.34793 .26989 .35178 .27535 .35955 .24608 .35568 .24172 Mtetra
.631 .727 .917 r
.35568 .24172 .35955 .24608 .36579 .2445 .36195 .23988 Mtetra
.945 .583 .248 r
.36195 .23988 .36579 .2445 .37063 .27138 .36683 .26523 Mtetra
.961 .624 .295 r
.36683 .26523 .37063 .27138 .37508 .30927 .37133 .3012 Mtetra
.901 .538 .075 r
.37133 .3012 .37508 .30927 .3804 .33193 .37667 .32282 Mtetra
.789 .649 .707 r
.37667 .32282 .3804 .33193 .38727 .32191 .38352 .3134 Mtetra
.921 .696 .58 r
.38352 .3134 .38727 .32191 .39527 .2844 .39149 .27769 Mtetra
.938 .71 .567 r
.39149 .27769 .39527 .2844 .40329 .2433 .39949 .23834 Mtetra
.921 .745 .646 r
.39949 .23834 .40329 .2433 .41035 .22375 .40656 .21938 Mtetra
.815 .367 0 r
.40656 .21938 .41035 .22375 .4162 .23661 .41243 .23133 Mtetra
.955 .609 .273 r
.41243 .23133 .4162 .23661 .42135 .27273 .41761 .26555 Mtetra
.952 .606 .226 r
.41761 .26555 .42135 .27273 .42672 .30757 .42299 .29867 Mtetra
0 .087 .641 r
.42299 .29867 .42672 .30757 .43304 .31596 .4293 .30672 Mtetra
.895 .687 .614 r
.4293 .30672 .43304 .31596 .44033 .29044 .43659 .28247 Mtetra
.937 .703 .558 r
.43659 .28247 .44033 .29044 .448 .24711 .44426 .2411 Mtetra
.943 .723 .576 r
.44426 .2411 .448 .24711 .45529 .21293 .45156 .2083 Mtetra
.796 .768 .828 r
.45156 .2083 .45529 .21293 .46187 .20731 .45816 .20267 Mtetra
.923 .538 .151 r
.45816 .20267 .46187 .20731 .4679 .23144 .46419 .22547 Mtetra
.951 .6 .231 r
.46419 .22547 .4679 .23144 .47385 .26808 .47013 .26024 Mtetra
.868 .499 .007 r
.47013 .26024 .47385 .26808 .48017 .29128 .47644 .28227 Mtetra
.761 .642 .73 r
.47644 .28227 .48017 .29128 .48701 .28355 .48328 .27488 Mtetra
.927 .701 .576 r
.48328 .27488 .48701 .28355 .4941 .24894 .4904 .24184 Mtetra
.946 .714 .556 r
.4904 .24184 .4941 .24894 .50111 .20933 .49744 .20395 Mtetra
.932 .746 .628 r
.49744 .20395 .50111 .20933 .50787 .18801 .50423 .18346 Mtetra
0 .036 .57 r
.50423 .18346 .50787 .18801 .51446 .19525 .51082 .19022 Mtetra
.926 .55 .151 r
.51082 .19022 .51446 .19525 .52109 .22347 .51743 .217 Mtetra
.913 .542 .105 r
.51743 .217 .52109 .22347 .52787 .25197 .52418 .24401 Mtetra
0 .162 .696 r
.52418 .24401 .52787 .25197 .53474 .25969 .53103 .25121 Mtetra
.891 .699 .638 r
.53103 .25121 .53474 .25969 .54152 .24002 .53784 .23232 Mtetra
.941 .713 .565 r
.53784 .23232 .54152 .24002 .54813 .20525 .5445 .19904 Mtetra
.945 .732 .583 r
.5445 .19904 .54813 .20525 .55466 .17644 .55108 .17149 Mtetra
.831 .772 .796 r
.55108 .17149 .55466 .17644 .56136 .16893 .5578 .16428 Mtetra
.783 .346 0 r
.5578 .16428 .56136 .16893 .56837 .18381 .56479 .17842 Mtetra
.887 .496 .045 r
.56479 .17842 .56837 .18381 .57563 .20823 .57201 .20157 Mtetra
.671 .278 0 r
.57201 .20157 .57563 .20823 .58287 .22354 .57922 .21593 Mtetra
.749 .67 .774 r
.57922 .21593 .58287 .22354 .58975 .21773 .58611 .21014 Mtetra
.925 .72 .606 r
.58611 .21014 .58975 .21773 .5962 .1937 .59261 .18703 Mtetra
.944 .731 .584 r
.59261 .18703 .5962 .1937 .60248 .16616 .59896 .16068 Mtetra
.918 .763 .674 r
.59896 .16068 .60248 .16616 .609 .15057 .60552 .14582 Mtetra
.173 .473 .893 r
.60552 .14582 .609 .15057 .61604 .15337 .61256 .14851 Mtetra
.758 .327 0 r
.61256 .14851 .61604 .15337 .62355 .16901 .62003 .16336 Mtetra
.691 .275 0 r
.62003 .16336 .62355 .16901 .63114 .18412 .62758 .17755 Mtetra
.361 .505 .867 r
.62758 .17755 .63114 .18412 .63834 .18643 .63478 .17946 Mtetra
.881 .731 .691 r
.63478 .17946 .63834 .18643 .64496 .17308 .64143 .16646 Mtetra
.933 .741 .619 r
.64143 .16646 .64496 .17308 .65122 .15191 .64775 .14612 Mtetra
.926 .761 .658 r
.64775 .14612 .65122 .15191 .6576 .13506 .65418 .13004 Mtetra
.744 .76 .865 r
.65418 .13004 .6576 .13506 .6645 .13051 .66112 .12573 Mtetra
0 .137 .671 r
.66112 .12573 .6645 .13051 .672 .1376 .6686 .13247 Mtetra
0 0 .484 r
.6686 .13247 .672 .1376 .67975 .14831 .67631 .14254 Mtetra
.11 .378 .838 r
.67631 .14254 .67975 .14831 .68725 .15294 .68379 .14668 Mtetra
.785 .729 .801 r
.68379 .14668 .68725 .15294 .69418 .14673 .69074 .14047 Mtetra
.905 .756 .686 r
.69074 .14047 .69418 .14673 .70065 .13263 .69725 .12684 Mtetra
.913 .769 .688 r
.69725 .12684 .70065 .13263 .70708 .11853 .70374 .11332 Mtetra
.824 .779 .81 r
.70374 .11332 .70708 .11853 .71391 .11133 .71061 .10645 Mtetra
.365 .587 .929 r
.71061 .10645 .71391 .11133 .72131 .11256 .71801 .10761 Mtetra
0 .302 .796 r
.71801 .10761 .72131 .11256 .72903 .11803 .72571 .1127 Mtetra
.229 .479 .888 r
.72571 .1127 .72903 .11803 .73665 .12118 .73331 .11548 Mtetra
.696 .72 .868 r
.73331 .11548 .73665 .12118 .74383 .11783 .7405 .11204 Mtetra
.852 .769 .769 r
.7405 .11204 .74383 .11783 .75061 .10901 .74731 .10344 Mtetra
.633 .707 .9 r
.10494 .33499 .1091 .33942 .11478 .33772 .11063 .33328 Mtetra
.788 .739 .808 r
.11063 .33328 .11478 .33772 .12098 .3321 .11681 .32783 Mtetra
.819 .747 .784 r
.11681 .32783 .12098 .3321 .12736 .32501 .12317 .32098 Mtetra
.757 .754 .85 r
.12317 .32098 .12736 .32501 .13337 .32084 .12919 .31687 Mtetra
.218 .546 .929 r
.12919 .31687 .13337 .32084 .13868 .32245 .13452 .31827 Mtetra
.631 .13 0 r
.13452 .31827 .13868 .32245 .14345 .32876 .13933 .32415 Mtetra
.562 .078 0 r
.13933 .32415 .14345 .32876 .14827 .33488 .1442 .32988 Mtetra
.453 .609 .914 r
.1442 .32988 .14827 .33488 .15382 .3353 .14976 .33018 Mtetra
.811 .723 .768 r
.14976 .33018 .15382 .3353 .16029 .32785 .15622 .323 Mtetra
.863 .731 .715 r
.15622 .323 .16029 .32785 .16727 .31588 .16316 .3115 Mtetra
.85 .746 .748 r
.16316 .3115 .16727 .31588 .17395 .30642 .16982 .30237 Mtetra
.569 .71 .937 r
.16982 .30237 .17395 .30642 .17968 .30552 .17556 .30138 Mtetra
.778 .3 0 r
.17556 .30138 .17968 .30552 .18439 .31402 .18033 .30933 Mtetra
.882 .457 .06 r
.18033 .30933 .18439 .31402 .18877 .32625 .18476 .32085 Mtetra
0 0 .461 r
.18476 .32085 .18877 .32625 .19377 .33312 .1898 .32729 Mtetra
.748 .693 .799 r
.1898 .32729 .19377 .33312 .20003 .32819 .19605 .32252 Mtetra
.874 .716 .682 r
.19605 .32252 .20003 .32819 .20735 .31281 .20333 .3078 Mtetra
.89 .727 .673 r
.20333 .3078 .20735 .31281 .21479 .29591 .21073 .29159 Mtetra
.832 .755 .778 r
.21073 .29159 .21479 .29591 .22129 .28824 .21722 .28414 Mtetra
.642 .144 0 r
.21722 .28414 .22129 .28824 .22638 .2952 .22236 .29059 Mtetra
.929 .544 .203 r
.22236 .29059 .22638 .2952 .23053 .31276 .22657 .30716 Mtetra
.915 .523 .13 r
.22657 .30716 .23053 .31276 .23487 .32908 .23098 .32259 Mtetra
.255 .435 .847 r
.23098 .32259 .23487 .32908 .24053 .33173 .23665 .32506 Mtetra
.862 .701 .681 r
.23665 .32506 .24053 .33173 .24778 .31677 .24386 .31078 Mtetra
.905 .712 .632 r
.24386 .31078 .24778 .31677 .25579 .29254 .25181 .28763 Mtetra
.902 .733 .663 r
.25181 .28763 .25579 .29254 .26323 .27427 .25922 .27006 Mtetra
.522 .688 .943 r
.25922 .27006 .26323 .27427 .26914 .27392 .26515 .26951 Mtetra
.928 .542 .199 r
.26515 .26951 .26914 .27392 .27356 .29239 .26964 .2869 Mtetra
.951 .598 .27 r
.26964 .2869 .27356 .29239 .2775 .31801 .27366 .31115 Mtetra
.85 .454 0 r
.27366 .31115 .2775 .31801 .2824 .33286 .27859 .32524 Mtetra
.781 .666 .736 r
.27859 .32524 .2824 .33286 .28908 .32485 .28525 .31763 Mtetra
.905 .701 .617 r
.28525 .31763 .28908 .32485 .29718 .29739 .29329 .29148 Mtetra
.921 .715 .608 r
.29329 .29148 .29718 .29739 .30536 .2676 .30142 .26297 Mtetra
.888 .75 .704 r
.30142 .26297 .30536 .2676 .3123 .2544 .30836 .25015 Mtetra
.838 .39 0 r
.30836 .25015 .3123 .2544 .31753 .26638 .31363 .26129 Mtetra
.953 .606 .29 r
.31363 .26129 .31753 .26638 .32165 .2963 .31782 .28957 Mtetra
.951 .601 .237 r
.31782 .28957 .32165 .2963 .32604 .32426 .32227 .31609 Mtetra
.037 .234 .736 r
.32227 .31609 .32604 .32426 .33193 .32981 .32817 .32142 Mtetra
.885 .689 .633 r
.32817 .32142 .33193 .32981 .33955 .30708 .33574 .29986 Mtetra
.925 .704 .584 r
.33574 .29986 .33955 .30708 .34793 .26989 .34407 .26439 Mtetra
.928 .725 .607 r
.34407 .26439 .34793 .26989 .35568 .24172 .3518 .23733 Mtetra
.645 .732 .912 r
.3518 .23733 .35568 .24172 .36195 .23988 .35808 .23527 Mtetra
.941 .574 .232 r
.35808 .23527 .36195 .23988 .36683 .26523 .36302 .25913 Mtetra
.959 .619 .285 r
.36302 .25913 .36683 .26523 .37133 .3012 .36756 .29322 Mtetra
.891 .525 .054 r
.36756 .29322 .37133 .3012 .37667 .32282 .37292 .31378 Mtetra
.783 .647 .712 r
.37292 .31378 .37667 .32282 .38352 .3134 .37976 .30491 Mtetra
.919 .696 .585 r
.37976 .30491 .38352 .3134 .39149 .27769 .3877 .27094 Mtetra
.937 .711 .571 r
.3877 .27094 .39149 .27769 .39949 .23834 .39568 .23333 Mtetra
.919 .745 .651 r
.39568 .23333 .39949 .23834 .40656 .21938 .40275 .215 Mtetra
.788 .333 0 r
.40275 .215 .40656 .21938 .41243 .23133 .40865 .22608 Mtetra
.953 .603 .262 r
.40865 .22608 .41243 .23133 .41761 .26555 .41385 .25845 Mtetra
.948 .599 .214 r
.41385 .25845 .41761 .26555 .42299 .29867 .41925 .28987 Mtetra
0 .109 .656 r
.41925 .28987 .42299 .29867 .4293 .30672 .42556 .29753 Mtetra
.891 .687 .62 r
.42556 .29753 .4293 .30672 .43659 .28247 .43284 .27449 Mtetra
.936 .704 .563 r
.43284 .27449 .43659 .28247 .44426 .2411 .4405 .23506 Mtetra
.941 .724 .58 r
.4405 .23506 .44426 .2411 .45156 .2083 .44782 .20363 Mtetra
.794 .767 .828 r
.44782 .20363 .45156 .2083 .45816 .20267 .45443 .19803 Mtetra
.917 .526 .132 r
.45443 .19803 .45816 .20267 .46419 .22547 .46046 .21953 Mtetra
.948 .594 .219 r
.46046 .21953 .46419 .22547 .47013 .26024 .4664 .25248 Mtetra
.855 .483 0 r
.4664 .25248 .47013 .26024 .47644 .28227 .47271 .27333 Mtetra
.756 .641 .734 r
.47271 .27333 .47644 .28227 .48328 .27488 .47954 .26623 Mtetra
.925 .701 .581 r
.47954 .26623 .48328 .27488 .4904 .24184 .48668 .23473 Mtetra
.944 .715 .561 r
.48668 .23473 .4904 .24184 .49744 .20395 .49376 .19854 Mtetra
.93 .747 .634 r
.49376 .19854 .49744 .20395 .50423 .18346 .50057 .17889 Mtetra
0 .079 .61 r
.50057 .17889 .50423 .18346 .51082 .19022 .50717 .1852 Mtetra
.921 .54 .135 r
.50717 .1852 .51082 .19022 .51743 .217 .51375 .21057 Mtetra
.906 .531 .087 r
.51375 .21057 .51743 .217 .52418 .24401 .52047 .23611 Mtetra
0 .195 .717 r
.52047 .23611 .52418 .24401 .53103 .25121 .52732 .24276 Mtetra
.887 .7 .643 r
.52732 .24276 .53103 .25121 .53784 .23232 .53415 .22462 Mtetra
.939 .714 .57 r
.53415 .22462 .53784 .23232 .5445 .19904 .54086 .19283 Mtetra
.943 .733 .589 r
.54086 .19283 .5445 .19904 .55108 .17149 .54749 .16651 Mtetra
.824 .771 .803 r
.54749 .16651 .55108 .17149 .5578 .16428 .55422 .15962 Mtetra
.763 .322 0 r
.55422 .15962 .5578 .16428 .56479 .17842 .5612 .17303 Mtetra
.877 .481 .024 r
.5612 .17303 .56479 .17842 .57201 .20157 .56838 .19494 Mtetra
.635 .243 0 r
.56838 .19494 .57201 .20157 .57922 .21593 .57556 .20836 Mtetra
.749 .672 .775 r
.57556 .20836 .57922 .21593 .58611 .21014 .58246 .20257 Mtetra
.922 .72 .612 r
.58246 .20257 .58611 .21014 .59261 .18703 .58901 .18037 Mtetra
.942 .732 .591 r
.58901 .18037 .59261 .18703 .59896 .16068 .59542 .15519 Mtetra
.913 .764 .683 r
.59542 .15519 .59896 .16068 .60552 .14582 .60202 .14105 Mtetra
.185 .481 .896 r
.60202 .14105 .60552 .14582 .61256 .14851 .60907 .14363 Mtetra
.737 .303 0 r
.60907 .14363 .61256 .14851 .62003 .16336 .61651 .1577 Mtetra
.659 .242 0 r
.61651 .1577 .62003 .16336 .62758 .17755 .62402 .171 Mtetra
.392 .524 .871 r
.62402 .171 .62758 .17755 .63478 .17946 .6312 .1725 Mtetra
.878 .731 .695 r
.6312 .1725 .63478 .17946 .64143 .16646 .63788 .15985 Mtetra
.93 .742 .626 r
.63788 .15985 .64143 .16646 .64775 .14612 .64426 .14034 Mtetra
.921 .762 .667 r
.64426 .14034 .64775 .14612 .65418 .13004 .65076 .125 Mtetra
.734 .756 .871 r
.65076 .125 .65418 .13004 .66112 .12573 .65771 .12093 Mtetra
0 .165 .694 r
.65771 .12093 .66112 .12573 .6686 .13247 .66518 .12733 Mtetra
0 0 .522 r
.66518 .12733 .6686 .13247 .67631 .14254 .67286 .13675 Mtetra
.157 .411 .853 r
.67286 .13675 .67631 .14254 .68379 .14668 .68032 .14042 Mtetra
.785 .73 .801 r
.68032 .14042 .68379 .14668 .69074 .14047 .68728 .13422 Mtetra
.901 .756 .692 r
.68728 .13422 .69074 .14047 .69725 .12684 .69384 .12104 Mtetra
.908 .77 .697 r
.69384 .12104 .69725 .12684 .70374 .11332 .70038 .10809 Mtetra
.815 .778 .817 r
.70038 .10809 .70374 .11332 .71061 .10645 .70729 .10155 Mtetra
.372 .591 .93 r
.70729 .10155 .71061 .10645 .71801 .10761 .71469 .10262 Mtetra
0 .331 .815 r
.71469 .10262 .71801 .10761 .72571 .1127 .72238 .10735 Mtetra
.264 .501 .896 r
.72238 .10735 .72571 .1127 .73331 .11548 .72996 .10977 Mtetra
.7 .722 .867 r
.72996 .10977 .73331 .11548 .7405 .11204 .73716 .10625 Mtetra
.848 .769 .774 r
.73716 .10625 .7405 .11204 .74731 .10344 .744 .09786 Mtetra
.633 .708 .9 r
.10076 .33055 .10494 .33499 .11063 .33328 .10645 .32883 Mtetra
.784 .739 .812 r
.10645 .32883 .11063 .33328 .11681 .32783 .11262 .32356 Mtetra
.815 .747 .788 r
.11262 .32356 .11681 .32783 .12317 .32098 .11897 .31693 Mtetra
.754 .754 .852 r
.11897 .31693 .12317 .32098 .12919 .31687 .12499 .31289 Mtetra
.257 .568 .938 r
.12499 .31289 .12919 .31687 .13452 .31827 .13035 .31409 Mtetra
.579 .076 0 r
.13035 .31409 .13452 .31827 .13933 .32415 .1352 .31955 Mtetra
0 0 .493 r
.1352 .31955 .13933 .32415 .1442 .32988 .14012 .32487 Mtetra
.464 .615 .914 r
.14012 .32487 .1442 .32988 .14976 .33018 .14569 .32507 Mtetra
.806 .723 .773 r
.14569 .32507 .14976 .33018 .15622 .323 .15212 .31815 Mtetra
.86 .731 .72 r
.15212 .31815 .15622 .323 .16316 .3115 .15904 .30711 Mtetra
.847 .747 .753 r
.15904 .30711 .16316 .3115 .16982 .30237 .16568 .2983 Mtetra
.577 .713 .935 r
.16568 .2983 .16982 .30237 .17556 .30138 .17143 .29722 Mtetra
.746 .26 0 r
.17143 .29722 .17556 .30138 .18033 .30933 .17625 .30464 Mtetra
.867 .433 .024 r
.17625 .30464 .18033 .30933 .18476 .32085 .18074 .31546 Mtetra
0 0 .512 r
.18074 .31546 .18476 .32085 .1898 .32729 .18582 .32147 Mtetra
.744 .692 .802 r
.18582 .32147 .1898 .32729 .19605 .32252 .19206 .31686 Mtetra
.871 .717 .687 r
.19206 .31686 .19605 .32252 .20333 .3078 .1993 .30278 Mtetra
.888 .728 .679 r
.1993 .30278 .20333 .3078 .21073 .29159 .20665 .28725 Mtetra
.829 .756 .783 r
.20665 .28725 .21073 .29159 .21722 .28414 .21314 .28001 Mtetra
.591 .09 0 r
.21314 .28001 .21722 .28414 .22236 .29059 .21831 .28598 Mtetra
.922 .53 .181 r
.21831 .28598 .22236 .29059 .22657 .30716 .2226 .30158 Mtetra
.906 .507 .102 r
.2226 .30158 .22657 .30716 .23098 .32259 .22707 .31613 Mtetra
.275 .449 .852 r
.22707 .31613 .23098 .32259 .23665 .32506 .23276 .31841 Mtetra
.858 .702 .687 r
.23276 .31841 .23665 .32506 .24386 .31078 .23992 .30479 Mtetra
.902 .713 .637 r
.23992 .30479 .24386 .31078 .25181 .28763 .24782 .28269 Mtetra
.899 .733 .668 r
.24782 .28269 .25181 .28763 .25922 .27006 .25519 .26583 Mtetra
.539 .695 .94 r
.25519 .26583 .25922 .27006 .26515 .26951 .26115 .26511 Mtetra
.921 .528 .177 r
.26115 .26511 .26515 .26951 .26964 .2869 .2657 .28143 Mtetra
.948 .59 .255 r
.2657 .28143 .26964 .2869 .27366 .31115 .26979 .30433 Mtetra
.831 .432 0 r
.26979 .30433 .27366 .31115 .27859 .32524 .27477 .31766 Mtetra
.775 .665 .741 r
.27477 .31766 .27859 .32524 .28525 .31763 .28141 .31042 Mtetra
.902 .702 .622 r
.28141 .31042 .28525 .31763 .29329 .29148 .28939 .28554 Mtetra
.919 .716 .612 r
.28939 .28554 .29329 .29148 .30142 .26297 .29747 .25831 Mtetra
.885 .751 .708 r
.29747 .25831 .30142 .26297 .30836 .25015 .3044 .24588 Mtetra
.814 .357 0 r
.3044 .24588 .30836 .25015 .31363 .26129 .30971 .25622 Mtetra
.951 .6 .278 r
.30971 .25622 .31363 .26129 .31782 .28957 .31398 .28289 Mtetra
.948 .593 .222 r
.31398 .28289 .31782 .28957 .32227 .31609 .31848 .308 Mtetra
.058 .251 .746 r
.31848 .308 .32227 .31609 .32817 .32142 .32439 .31308 Mtetra
.881 .689 .638 r
.32439 .31308 .32817 .32142 .33574 .29986 .33192 .29263 Mtetra
.923 .704 .589 r
.33192 .29263 .33574 .29986 .34407 .26439 .34019 .25885 Mtetra
.926 .725 .612 r
.34019 .25885 .34407 .26439 .3518 .23733 .3479 .23291 Mtetra
.657 .735 .907 r
.3479 .23291 .3518 .23733 .35808 .23527 .3542 .23066 Mtetra
.937 .564 .215 r
.3542 .23066 .35808 .23527 .36302 .25913 .35919 .25308 Mtetra
.957 .614 .274 r
.35919 .25308 .36302 .25913 .36756 .29322 .36378 .28531 Mtetra
.88 .511 .031 r
.36378 .28531 .36756 .29322 .37292 .31378 .36917 .30482 Mtetra
.777 .646 .718 r
.36917 .30482 .37292 .31378 .37976 .30491 .37599 .29644 Mtetra
.917 .697 .589 r
.37599 .29644 .37976 .30491 .3877 .27094 .3839 .26418 Mtetra
.935 .711 .576 r
.3839 .26418 .3877 .27094 .39568 .23333 .39185 .22828 Mtetra
.916 .746 .656 r
.39185 .22828 .39568 .23333 .40275 .215 .39892 .21059 Mtetra
.757 .294 0 r
.39892 .21059 .40275 .215 .40865 .22608 .40485 .22086 Mtetra
.95 .596 .25 r
.40485 .22086 .40865 .22608 .41385 .25845 .41008 .25141 Mtetra
.945 .592 .2 r
.41008 .25141 .41385 .25845 .41925 .28987 .4155 .28114 Mtetra
0 .133 .672 r
.4155 .28114 .41925 .28987 .42556 .29753 .42181 .2884 Mtetra
.888 .687 .625 r
.42181 .2884 .42556 .29753 .43284 .27449 .42908 .26652 Mtetra
.934 .704 .567 r
.42908 .26652 .43284 .27449 .4405 .23506 .43674 .22897 Mtetra
.939 .724 .586 r
.43674 .22897 .4405 .23506 .44782 .20363 .44406 .19892 Mtetra
.792 .766 .83 r
.44406 .19892 .44782 .20363 .45443 .19803 .45068 .19339 Mtetra
.909 .513 .111 r
.45068 .19339 .45443 .19803 .46046 .21953 .45672 .21363 Mtetra
.944 .586 .206 r
.45672 .21363 .46046 .21953 .4664 .25248 .46266 .24478 Mtetra
.839 .464 0 r
.46266 .24478 .4664 .25248 .47271 .27333 .46896 .26446 Mtetra
.752 .641 .738 r
.46896 .26446 .47271 .27333 .47954 .26623 .4758 .25763 Mtetra
.922 .701 .586 r
.4758 .25763 .47954 .26623 .48668 .23473 .48296 .22761 Mtetra
.942 .715 .566 r
.48296 .22761 .48668 .23473 .49376 .19854 .49006 .1931 Mtetra
.926 .748 .641 r
.49006 .1931 .49376 .19854 .50057 .17889 .49689 .17429 Mtetra
0 .122 .648 r
.49689 .17429 .50057 .17889 .50717 .1852 .50349 .18018 Mtetra
.914 .529 .117 r
.50349 .18018 .50717 .1852 .51375 .21057 .51006 .20417 Mtetra
.897 .518 .066 r
.51006 .20417 .51375 .21057 .52047 .23611 .51676 .22825 Mtetra
.009 .23 .738 r
.51676 .22825 .52047 .23611 .52732 .24276 .5236 .23437 Mtetra
.884 .7 .648 r
.5236 .23437 .52732 .24276 .53415 .22462 .53045 .21695 Mtetra
.937 .714 .576 r
.53045 .21695 .53415 .22462 .54086 .19283 .5372 .1866 Mtetra
.941 .734 .596 r
.5372 .1866 .54086 .19283 .54749 .16651 .54388 .16152 Mtetra
.816 .77 .809 r
.54388 .16152 .54749 .16651 .55422 .15962 .55063 .15494 Mtetra
.742 .297 0 r
.55063 .15494 .55422 .15962 .5612 .17303 .55759 .16764 Mtetra
.866 .465 0 r
.55759 .16764 .5612 .17303 .56838 .19494 .56474 .18831 Mtetra
0 0 .367 r
.56474 .18831 .56838 .19494 .57556 .20836 .57189 .20081 Mtetra
.75 .673 .776 r
.57189 .20081 .57556 .20836 .58246 .20257 .5788 .19503 Mtetra
.92 .721 .618 r
.5788 .19503 .58246 .20257 .58901 .18037 .5854 .17372 Mtetra
.939 .734 .598 r
.5854 .17372 .58901 .18037 .59542 .15519 .59186 .1497 Mtetra
.908 .765 .692 r
.59186 .1497 .59542 .15519 .60202 .14105 .59851 .13626 Mtetra
.197 .489 .9 r
.59851 .13626 .60202 .14105 .60907 .14363 .60556 .13873 Mtetra
.713 .276 0 r
.60556 .13873 .60907 .14363 .61651 .1577 .61297 .15203 Mtetra
.622 .206 0 r
.61297 .15203 .61651 .1577 .62402 .171 .62044 .16444 Mtetra
.422 .542 .873 r
.62044 .16444 .62402 .171 .6312 .1725 .62761 .16556 Mtetra
.875 .731 .7 r
.62761 .16556 .6312 .1725 .63788 .15985 .63433 .15325 Mtetra
.927 .743 .633 r
.63433 .15325 .63788 .15985 .64426 .14034 .64077 .13455 Mtetra
.917 .763 .676 r
.64077 .13455 .64426 .14034 .65076 .125 .64731 .11995 Mtetra
.723 .753 .876 r
.64731 .11995 .65076 .125 .65771 .12093 .6543 .11611 Mtetra
0 .194 .717 r
.6543 .11611 .65771 .12093 .66518 .12733 .66175 .12216 Mtetra
0 .006 .561 r
.66175 .12216 .66518 .12733 .67286 .13675 .6694 .13095 Mtetra
.203 .441 .866 r
.6694 .13095 .67286 .13675 .68032 .14042 .67683 .13416 Mtetra
.785 .73 .802 r
.67683 .13416 .68032 .14042 .68728 .13422 .68381 .12797 Mtetra
.897 .757 .698 r
.68381 .12797 .68728 .13422 .69384 .12104 .69042 .11524 Mtetra
.903 .77 .705 r
.69042 .11524 .69384 .12104 .70038 .10809 .69701 .10286 Mtetra
.807 .776 .825 r
.69701 .10286 .70038 .10809 .70729 .10155 .70396 .09663 Mtetra
.38 .596 .931 r
.70396 .09663 .70729 .10155 .71469 .10262 .71137 .09761 Mtetra
.028 .359 .832 r
.71137 .09761 .71469 .10262 .72238 .10735 .71903 .10197 Mtetra
.297 .522 .903 r
.71903 .10197 .72238 .10735 .72996 .10977 .7266 .10405 Mtetra
.703 .724 .866 r
.7266 .10405 .72996 .10977 .73716 .10625 .7338 .10044 Mtetra
.844 .768 .778 r
.7338 .10044 .73716 .10625 .744 .09786 .74068 .09227 Mtetra
.633 .709 .901 r
.09656 .32611 .10076 .33055 .10645 .32883 .10226 .32438 Mtetra
.779 .74 .816 r
.10226 .32438 .10645 .32883 .11262 .32356 .10842 .31928 Mtetra
.811 .748 .793 r
.10842 .31928 .11262 .32356 .11897 .31693 .11475 .31286 Mtetra
.751 .754 .854 r
.11475 .31286 .11897 .31693 .12499 .31289 .12077 .3089 Mtetra
.294 .588 .944 r
.12077 .3089 .12499 .31289 .13035 .31409 .12615 .30989 Mtetra
.52 .019 0 r
.12615 .30989 .13035 .31409 .1352 .31955 .13106 .31494 Mtetra
0 .03 .549 r
.13106 .31494 .1352 .31955 .14012 .32487 .13601 .31988 Mtetra
.475 .622 .914 r
.13601 .31988 .14012 .32487 .14569 .32507 .1416 .31996 Mtetra
.802 .723 .777 r
.1416 .31996 .14569 .32507 .15212 .31815 .14802 .3133 Mtetra
.856 .732 .726 r
.14802 .3133 .15212 .31815 .15904 .30711 .15489 .30271 Mtetra
.843 .747 .758 r
.15489 .30271 .15904 .30711 .16568 .2983 .16151 .29422 Mtetra
.584 .716 .934 r
.16151 .29422 .16568 .2983 .17143 .29722 .16728 .29305 Mtetra
.708 .215 0 r
.16728 .29305 .17143 .29722 .17625 .30464 .17215 .29995 Mtetra
.849 .406 0 r
.17215 .29995 .17625 .30464 .18074 .31546 .17671 .31009 Mtetra
0 .016 .562 r
.17671 .31009 .18074 .31546 .18582 .32147 .18182 .31568 Mtetra
.74 .693 .806 r
.18182 .31568 .18582 .32147 .19206 .31686 .18806 .31121 Mtetra
.868 .718 .693 r
.18806 .31121 .19206 .31686 .1993 .30278 .19525 .29775 Mtetra
.885 .729 .684 r
.19525 .29775 .1993 .30278 .20665 .28725 .20256 .2829 Mtetra
.825 .756 .787 r
.20256 .2829 .20665 .28725 .21314 .28001 .20903 .27588 Mtetra
.533 .033 0 r
.20903 .27588 .21314 .28001 .21831 .28598 .21425 .28138 Mtetra
.915 .515 .155 r
.21425 .28138 .21831 .28598 .2226 .30158 .21861 .29603 Mtetra
.894 .488 .072 r
.21861 .29603 .2226 .30158 .22707 .31613 .22314 .30972 Mtetra
.295 .463 .857 r
.22314 .30972 .22707 .31613 .23276 .31841 .22885 .3118 Mtetra
.855 .702 .692 r
.22885 .3118 .23276 .31841 .23992 .30479 .23597 .29881 Mtetra
.9 .714 .642 r
.23597 .29881 .23992 .30479 .24782 .28269 .24381 .27774 Mtetra
.896 .734 .673 r
.24381 .27774 .24782 .28269 .25519 .26583 .25115 .26157 Mtetra
.554 .701 .937 r
.25115 .26157 .25519 .26583 .26115 .26511 .25712 .26069 Mtetra
.914 .513 .151 r
.25712 .26069 .26115 .26511 .2657 .28143 .26174 .276 Mtetra
.944 .581 .239 r
.26174 .276 .2657 .28143 .26979 .30433 .26591 .29759 Mtetra
.81 .406 0 r
.26591 .29759 .26979 .30433 .27477 .31766 .27093 .31015 Mtetra
.77 .665 .747 r
.27093 .31015 .27477 .31766 .28141 .31042 .27756 .30326 Mtetra
.9 .702 .627 r
.27756 .30326 .28141 .31042 .28939 .28554 .28547 .27961 Mtetra
.917 .716 .617 r
.28547 .27961 .28939 .28554 .29747 .25831 .2935 .25362 Mtetra
.882 .751 .713 r
.2935 .25362 .29747 .25831 .3044 .24588 .30042 .2416 Mtetra
.785 .319 0 r
.30042 .2416 .3044 .24588 .30971 .25622 .30578 .25117 Mtetra
.948 .592 .264 r
.30578 .25117 .30971 .25622 .31398 .28289 .31012 .27629 Mtetra
.944 .584 .206 r
.31012 .27629 .31398 .28289 .31848 .308 .31468 .30001 Mtetra
.079 .269 .756 r
.31468 .30001 .31848 .308 .32439 .31308 .3206 .30481 Mtetra
.878 .689 .643 r
.3206 .30481 .32439 .31308 .33192 .29263 .32809 .28543 Mtetra
.921 .705 .593 r
.32809 .28543 .33192 .29263 .34019 .25885 .3363 .25329 Mtetra
.924 .726 .617 r
.3363 .25329 .34019 .25885 .3479 .23291 .34398 .22846 Mtetra
.666 .737 .903 r
.34398 .22846 .3479 .23291 .3542 .23066 .3503 .22605 Mtetra
.932 .553 .196 r
.3503 .22605 .3542 .23066 .35919 .25308 .35534 .2471 Mtetra
.954 .607 .262 r
.35534 .2471 .35919 .25308 .36378 .28531 .35999 .27752 Mtetra
.868 .494 .006 r
.35999 .27752 .36378 .28531 .36917 .30482 .3654 .29597 Mtetra
.771 .646 .723 r
.3654 .29597 .36917 .30482 .37599 .29644 .37221 .28804 Mtetra
.914 .697 .594 r
.37221 .28804 .37599 .29644 .3839 .26418 .38008 .25741 Mtetra
.933 .712 .58 r
.38008 .25741 .3839 .26418 .39185 .22828 .38801 .2232 Mtetra
.913 .747 .661 r
.38801 .2232 .39185 .22828 .39892 .21059 .39508 .20616 Mtetra
.721 .252 0 r
.39508 .20616 .39892 .21059 .40485 .22086 .40103 .21566 Mtetra
.947 .589 .236 r
.40103 .21566 .40485 .22086 .41008 .25141 .40629 .24446 Mtetra
.94 .583 .185 r
.40629 .24446 .41008 .25141 .4155 .28114 .41173 .27255 Mtetra
0 .158 .689 r
.41173 .27255 .4155 .28114 .42181 .2884 .41805 .27938 Mtetra
.885 .687 .631 r
.41805 .27938 .42181 .2884 .42908 .26652 .42531 .2586 Mtetra
.932 .705 .572 r
.42531 .2586 .42908 .26652 .43674 .22897 .43296 .22288 Mtetra
.937 .725 .591 r
.43296 .22288 .43674 .22897 .44406 .19892 .44029 .19418 Mtetra
.789 .765 .831 r
.44029 .19418 .44406 .19892 .45068 .19339 .44692 .18874 Mtetra
.9 .498 .087 r
.44692 .18874 .45068 .19339 .45672 .21363 .45297 .20778 Mtetra
.94 .578 .192 r
.45297 .20778 .45672 .21363 .46266 .24478 .45891 .23718 Mtetra
.822 .444 0 r
.45891 .23718 .46266 .24478 .46896 .26446 .46521 .2557 Mtetra
.749 .642 .742 r
.46521 .2557 .46896 .26446 .4758 .25763 .47205 .24909 Mtetra
.92 .702 .591 r
.47205 .24909 .4758 .25763 .48296 .22761 .47922 .22051 Mtetra
.94 .716 .571 r
.47922 .22051 .48296 .22761 .49006 .1931 .48635 .18764 Mtetra
.923 .749 .648 r
.48635 .18764 .49006 .1931 .49689 .17429 .4932 .16967 Mtetra
0 .162 .684 r
.4932 .16967 .49689 .17429 .50349 .18018 .4998 .17517 Mtetra
.907 .516 .098 r
.4998 .17517 .50349 .18018 .51006 .20417 .50635 .19781 Mtetra
.887 .503 .043 r
.50635 .19781 .51006 .20417 .51676 .22825 .51303 .22048 Mtetra
.054 .263 .757 r
.51303 .22048 .51676 .22825 .5236 .23437 .51987 .22605 Mtetra
.881 .7 .653 r
.51987 .22605 .5236 .23437 .53045 .21695 .52674 .20932 Mtetra
.935 .715 .581 r
.52674 .20932 .53045 .21695 .5372 .1866 .53354 .18038 Mtetra
.938 .736 .603 r
.53354 .18038 .5372 .1866 .54388 .16152 .54026 .1565 Mtetra
.808 .768 .816 r
.54026 .1565 .54388 .16152 .55063 .15494 .54702 .15024 Mtetra
.718 .27 0 r
.54702 .15024 .55063 .15494 .55759 .16764 .55397 .16226 Mtetra
.853 .448 0 r
.55397 .16226 .55759 .16764 .56474 .18831 .56109 .18173 Mtetra
0 0 .412 r
.56109 .18173 .56474 .18831 .57189 .20081 .56821 .19332 Mtetra
.751 .676 .778 r
.56821 .19332 .57189 .20081 .5788 .19503 .57513 .18754 Mtetra
.917 .722 .624 r
.57513 .18754 .5788 .19503 .5854 .17372 .58177 .1671 Mtetra
.937 .735 .605 r
.58177 .1671 .5854 .17372 .59186 .1497 .5883 .1442 Mtetra
.902 .766 .701 r
.5883 .1442 .59186 .1497 .59851 .13626 .59498 .13145 Mtetra
.209 .496 .903 r
.59498 .13145 .59851 .13626 .60556 .13873 .60203 .13382 Mtetra
.686 .247 0 r
.60203 .13382 .60556 .13873 .61297 .15203 .60941 .14636 Mtetra
0 0 .394 r
.60941 .14636 .61297 .15203 .62044 .16444 .61685 .15791 Mtetra
.449 .56 .875 r
.61685 .15791 .62044 .16444 .62761 .16556 .62402 .15865 Mtetra
.872 .732 .705 r
.62402 .15865 .62761 .16556 .63433 .15325 .63076 .14668 Mtetra
.924 .744 .64 r
.63076 .14668 .63433 .15325 .64077 .13455 .63726 .12878 Mtetra
.912 .765 .685 r
.63726 .12878 .64077 .13455 .64731 .11995 .64386 .11489 Mtetra
.713 .75 .881 r
.64386 .11489 .64731 .11995 .6543 .11611 .65086 .11127 Mtetra
0 .223 .739 r
.65086 .11127 .6543 .11611 .66175 .12216 .6583 .11698 Mtetra
0 .048 .599 r
.6583 .11698 .66175 .12216 .6694 .13095 .66592 .12514 Mtetra
.245 .47 .877 r
.66592 .12514 .6694 .13095 .67683 .13416 .67334 .1279 Mtetra
.784 .731 .804 r
.67334 .1279 .67683 .13416 .68381 .12797 .68033 .12174 Mtetra
.893 .758 .705 r
.68033 .12174 .68381 .12797 .69042 .11524 .68698 .10945 Mtetra
.897 .771 .714 r
.68698 .10945 .69042 .11524 .69701 .10286 .69363 .09761 Mtetra
.798 .774 .832 r
.69363 .09761 .69701 .10286 .70396 .09663 .70061 .09168 Mtetra
.388 .601 .932 r
.70061 .09168 .70396 .09663 .71137 .09761 .70802 .09257 Mtetra
.066 .386 .848 r
.70802 .09257 .71137 .09761 .71903 .10197 .71567 .09657 Mtetra
.328 .542 .908 r
.71567 .09657 .71903 .10197 .7266 .10405 .72322 .09831 Mtetra
.705 .725 .866 r
.72322 .09831 .7266 .10405 .7338 .10044 .73043 .09464 Mtetra
.839 .768 .783 r
.73043 .09464 .7338 .10044 .74068 .09227 .73734 .08668 Mtetra
.633 .709 .901 r
.09235 .32167 .09656 .32611 .10226 .32438 .09805 .31993 Mtetra
.775 .74 .821 r
.09805 .31993 .10226 .32438 .10842 .31928 .1042 .31499 Mtetra
.807 .748 .798 r
.1042 .31499 .10842 .31928 .11475 .31286 .11052 .30878 Mtetra
.748 .754 .857 r
.11052 .30878 .11475 .31286 .12077 .3089 .11653 .30489 Mtetra
.328 .606 .949 r
.11653 .30489 .12077 .3089 .12615 .30989 .12194 .30568 Mtetra
0 .04 .542 r
.12194 .30568 .12615 .30989 .13106 .31494 .12689 .31034 Mtetra
0 .086 .605 r
.12689 .31034 .13106 .31494 .13601 .31988 .13189 .3149 Mtetra
.485 .628 .915 r
.13189 .3149 .13601 .31988 .1416 .31996 .13749 .31487 Mtetra
.798 .724 .782 r
.13749 .31487 .1416 .31996 .14802 .3133 .14389 .30845 Mtetra
.852 .733 .731 r
.14389 .30845 .14802 .3133 .15489 .30271 .15073 .2983 Mtetra
.839 .748 .763 r
.15073 .2983 .15489 .30271 .16151 .29422 .15733 .29012 Mtetra
.591 .718 .932 r
.15733 .29012 .16151 .29422 .16728 .29305 .16311 .28887 Mtetra
.663 .165 0 r
.16311 .28887 .16728 .29305 .17215 .29995 .16803 .29526 Mtetra
.827 .375 0 r
.16803 .29526 .17215 .29995 .17671 .31009 .17265 .30474 Mtetra
0 .069 .611 r
.17265 .30474 .17671 .31009 .18182 .31568 .1778 .30993 Mtetra
.736 .693 .81 r
.1778 .30993 .18182 .31568 .18806 .31121 .18403 .30559 Mtetra
.865 .718 .698 r
.18403 .30559 .18806 .31121 .19525 .29775 .19118 .29273 Mtetra
.882 .73 .689 r
.19118 .29273 .19525 .29775 .20256 .2829 .19844 .27853 Mtetra
.821 .756 .791 r
.19844 .27853 .20256 .2829 .20903 .27588 .20491 .27172 Mtetra
0 .027 .53 r
.20491 .27172 .20903 .27588 .21425 .28138 .21017 .27678 Mtetra
.906 .498 .127 r
.21017 .27678 .21425 .28138 .21861 .29603 .2146 .29051 Mtetra
.88 .467 .039 r
.2146 .29051 .21861 .29603 .22314 .30972 .2192 .30336 Mtetra
.315 .478 .862 r
.2192 .30336 .22314 .30972 .22885 .3118 .22492 .30523 Mtetra
.851 .703 .698 r
.22492 .30523 .22885 .3118 .23597 .29881 .23201 .29285 Mtetra
.897 .715 .647 r
.23201 .29285 .23597 .29881 .24381 .27774 .23978 .27277 Mtetra
.893 .735 .679 r
.23978 .27277 .24381 .27774 .25115 .26157 .24708 .25729 Mtetra
.566 .705 .935 r
.24708 .25729 .25115 .26157 .25712 .26069 .25307 .25628 Mtetra
.905 .495 .123 r
.25307 .25628 .25712 .26069 .26174 .276 .25776 .2706 Mtetra
.94 .571 .22 r
.25776 .2706 .26174 .276 .26591 .29759 .26202 .29091 Mtetra
.785 .377 0 r
.26202 .29091 .26591 .29759 .27093 .31015 .26708 .30272 Mtetra
.766 .665 .752 r
.26708 .30272 .27093 .31015 .27756 .30326 .27369 .29615 Mtetra
.897 .703 .632 r
.27369 .29615 .27756 .30326 .28547 .27961 .28154 .27367 Mtetra
.915 .717 .622 r
.28154 .27367 .28547 .27961 .2935 .25362 .28951 .2489 Mtetra
.878 .751 .718 r
.28951 .2489 .2935 .25362 .30042 .2416 .29642 .23729 Mtetra
.751 .277 0 r
.29642 .23729 .30042 .2416 .30578 .25117 .30183 .24615 Mtetra
.945 .583 .248 r
.30183 .24615 .30578 .25117 .31012 .27629 .30624 .26977 Mtetra
.938 .574 .188 r
.30624 .26977 .31012 .27629 .31468 .30001 .31086 .29212 Mtetra
.102 .289 .767 r
.31086 .29212 .31468 .30001 .3206 .30481 .31679 .29663 Mtetra
.875 .69 .649 r
.31679 .29663 .3206 .30481 .32809 .28543 .32424 .27825 Mtetra
.919 .706 .598 r
.32424 .27825 .32809 .28543 .3363 .25329 .3324 .24771 Mtetra
.922 .727 .622 r
.3324 .24771 .3363 .25329 .34398 .22846 .34005 .22398 Mtetra
.672 .738 .9 r
.34005 .22398 .34398 .22846 .3503 .22605 .34639 .22145 Mtetra
.926 .54 .175 r
.34639 .22145 .3503 .22605 .35534 .2471 .35148 .24117 Mtetra
.952 .6 .249 r
.35148 .24117 .35534 .2471 .35999 .27752 .35618 .26984 Mtetra
.853 .475 0 r
.35618 .26984 .35999 .27752 .3654 .29597 .36163 .28723 Mtetra
.766 .646 .729 r
.36163 .28723 .3654 .29597 .37221 .28804 .36842 .27971 Mtetra
.912 .698 .599 r
.36842 .27971 .37221 .28804 .38008 .25741 .37625 .25065 Mtetra
.931 .713 .585 r
.37625 .25065 .38008 .25741 .38801 .2232 .38415 .21808 Mtetra
.91 .747 .667 r
.38415 .21808 .38801 .2232 .39508 .20616 .39122 .20171 Mtetra
.679 .206 0 r
.39122 .20171 .39508 .20616 .40103 .21566 .39719 .2105 Mtetra
.944 .58 .222 r
.39719 .2105 .40103 .21566 .40629 .24446 .40249 .2376 Mtetra
.935 .574 .168 r
.40249 .2376 .40629 .24446 .41173 .27255 .40795 .26407 Mtetra
0 .186 .707 r
.40795 .26407 .41173 .27255 .41805 .27938 .41427 .27046 Mtetra
.881 .688 .636 r
.41427 .27046 .41805 .27938 .42531 .2586 .42153 .25071 Mtetra
.93 .706 .577 r
.42153 .25071 .42531 .2586 .43296 .22288 .42917 .21677 Mtetra
.935 .726 .597 r
.42917 .21677 .43296 .22288 .44029 .19418 .4365 .18941 Mtetra
.785 .764 .834 r
.4365 .18941 .44029 .19418 .44692 .18874 .44314 .18408 Mtetra
.89 .482 .062 r
.44314 .18408 .44692 .18874 .45297 .20778 .4492 .20197 Mtetra
.935 .569 .176 r
.4492 .20197 .45297 .20778 .45891 .23718 .45514 .22966 Mtetra
.802 .421 0 r
.45514 .22966 .45891 .23718 .46521 .2557 .46144 .24704 Mtetra
.747 .643 .746 r
.46144 .24704 .46521 .2557 .47205 .24909 .46829 .24064 Mtetra
.918 .703 .596 r
.46829 .24064 .47205 .24909 .47922 .22051 .47547 .21343 Mtetra
.938 .717 .577 r
.47547 .21343 .47922 .22051 .48635 .18764 .48262 .18216 Mtetra
.92 .75 .656 r
.48262 .18216 .48635 .18764 .4932 .16967 .48949 .16503 Mtetra
0 .201 .716 r
.48949 .16503 .4932 .16967 .4998 .17517 .4961 .17016 Mtetra
.899 .503 .076 r
.4961 .17016 .4998 .17517 .50635 .19781 .50264 .1915 Mtetra
.875 .487 .018 r
.50264 .1915 .50635 .19781 .51303 .22048 .5093 .21278 Mtetra
.099 .297 .776 r
.5093 .21278 .51303 .22048 .51987 .22605 .51613 .21782 Mtetra
.878 .701 .659 r
.51613 .21782 .51987 .22605 .52674 .20932 .52303 .20175 Mtetra
.933 .717 .587 r
.52303 .20175 .52674 .20932 .53354 .18038 .52986 .17417 Mtetra
.936 .737 .61 r
.52986 .17417 .53354 .18038 .54026 .1565 .53662 .15147 Mtetra
.799 .767 .823 r
.53662 .15147 .54026 .1565 .54702 .15024 .5434 .14552 Mtetra
.691 .24 0 r
.5434 .14552 .54702 .15024 .55397 .16226 .55033 .15688 Mtetra
.838 .428 0 r
.55033 .15688 .55397 .16226 .56109 .18173 .55742 .17518 Mtetra
0 0 .459 r
.55742 .17518 .56109 .18173 .56821 .19332 .56453 .18589 Mtetra
.752 .678 .779 r
.56453 .18589 .56821 .19332 .57513 .18754 .57145 .1801 Mtetra
.914 .723 .63 r
.57145 .1801 .57513 .18754 .58177 .1671 .57814 .1605 Mtetra
.934 .737 .612 r
.57814 .1605 .58177 .1671 .5883 .1442 .58471 .1387 Mtetra
.896 .767 .711 r
.58471 .1387 .5883 .1442 .59498 .13145 .59144 .12662 Mtetra
.22 .504 .906 r
.59144 .12662 .59498 .13145 .60203 .13382 .59849 .12888 Mtetra
.657 .215 0 r
.59849 .12888 .60203 .13382 .60941 .14636 .60584 .14069 Mtetra
0 0 .439 r
.60584 .14069 .60941 .14636 .61685 .15791 .61325 .1514 Mtetra
.474 .575 .877 r
.61325 .1514 .61685 .15791 .62402 .15865 .62041 .15177 Mtetra
.869 .733 .709 r
.62041 .15177 .62402 .15865 .63076 .14668 .62719 .14014 Mtetra
.921 .745 .648 r
.62719 .14014 .63076 .14668 .63726 .12878 .63374 .12301 Mtetra
.907 .766 .695 r
.63374 .12301 .63726 .12878 .64386 .11489 .64039 .10981 Mtetra
.703 .747 .886 r
.64039 .10981 .64386 .11489 .65086 .11127 .64741 .1064 Mtetra
0 .252 .76 r
.64741 .1064 .65086 .11127 .6583 .11698 .65484 .11177 Mtetra
0 .091 .637 r
.65484 .11177 .6583 .11698 .66592 .12514 .66243 .11933 Mtetra
.286 .496 .886 r
.66243 .11933 .66592 .12514 .67334 .1279 .66983 .12166 Mtetra
.784 .732 .805 r
.66983 .12166 .67334 .1279 .68033 .12174 .67684 .11552 Mtetra
.889 .758 .712 r
.67684 .11552 .68033 .12174 .68698 .10945 .68353 .10367 Mtetra
.892 .772 .723 r
.68353 .10367 .68698 .10945 .69363 .09761 .69024 .09236 Mtetra
.788 .773 .839 r
.69024 .09236 .69363 .09761 .70061 .09168 .69725 .08672 Mtetra
.396 .606 .932 r
.69725 .08672 .70061 .09168 .70802 .09257 .70466 .08751 Mtetra
.104 .413 .862 r
.70466 .08751 .70802 .09257 .71567 .09657 .71229 .09115 Mtetra
.357 .56 .912 r
.71229 .09115 .71567 .09657 .72322 .09831 .71983 .09257 Mtetra
.708 .727 .865 r
.71983 .09257 .72322 .09831 .73043 .09464 .72705 .08883 Mtetra
.835 .768 .788 r
.72705 .08883 .73043 .09464 .73734 .08668 .73399 .08109 Mtetra
.634 .71 .902 r
.08812 .31722 .09235 .32167 .09805 .31993 .09383 .31547 Mtetra
.771 .74 .825 r
.09383 .31547 .09805 .31993 .1042 .31499 .09996 .31069 Mtetra
.803 .748 .802 r
.09996 .31069 .1042 .31499 .11052 .30878 .10626 .30469 Mtetra
.746 .753 .859 r
.10626 .30469 .11052 .30878 .11653 .30489 .11227 .30086 Mtetra
.359 .622 .952 r
.11227 .30086 .11653 .30489 .12194 .30568 .11772 .30147 Mtetra
0 .102 .604 r
.11772 .30147 .12194 .30568 .12689 .31034 .12271 .30573 Mtetra
0 .143 .657 r
.12271 .30573 .12689 .31034 .13189 .3149 .12775 .30992 Mtetra
.495 .634 .915 r
.12775 .30992 .13189 .3149 .13749 .31487 .13336 .30979 Mtetra
.794 .724 .787 r
.13336 .30979 .13749 .31487 .14389 .30845 .13974 .30361 Mtetra
.849 .734 .737 r
.13974 .30361 .14389 .30845 .15073 .2983 .14655 .29388 Mtetra
.835 .749 .769 r
.14655 .29388 .15073 .2983 .15733 .29012 .15313 .28601 Mtetra
.597 .72 .93 r
.15313 .28601 .15733 .29012 .16311 .28887 .15892 .28467 Mtetra
.611 .11 0 r
.15892 .28467 .16311 .28887 .16803 .29526 .1639 .29058 Mtetra
.801 .34 0 r
.1639 .29058 .16803 .29526 .17265 .30474 .16858 .29941 Mtetra
0 .122 .658 r
.16858 .29941 .17265 .30474 .1778 .30993 .17377 .30419 Mtetra
.733 .694 .813 r
.17377 .30419 .1778 .30993 .18403 .30559 .17999 .29998 Mtetra
.861 .719 .704 r
.17999 .29998 .18403 .30559 .19118 .29273 .18709 .28771 Mtetra
.878 .731 .695 r
.18709 .28771 .19118 .29273 .19844 .27853 .19431 .27414 Mtetra
.816 .756 .796 r
.19431 .27414 .19844 .27853 .20491 .27172 .20077 .26755 Mtetra
0 .089 .592 r
.20077 .26755 .20491 .27172 .21017 .27678 .20607 .27218 Mtetra
.895 .478 .095 r
.20607 .27218 .21017 .27678 .2146 .29051 .21058 .28502 Mtetra
.863 .442 .001 r
.21058 .28502 .2146 .29051 .2192 .30336 .21524 .29704 Mtetra
.335 .492 .867 r
.21524 .29704 .2192 .30336 .22492 .30523 .22098 .29871 Mtetra
.847 .703 .703 r
.22098 .29871 .22492 .30523 .23201 .29285 .22803 .2869 Mtetra
.895 .716 .652 r
.22803 .2869 .23201 .29285 .23978 .27277 .23574 .26779 Mtetra
.89 .736 .684 r
.23574 .26779 .23978 .27277 .24708 .25729 .24301 .25299 Mtetra
.577 .709 .933 r
.24301 .25299 .24708 .25729 .25307 .25628 .24901 .25185 Mtetra
.894 .475 .092 r
.24901 .25185 .25307 .25628 .25776 .2706 .25376 .26524 Mtetra
.935 .559 .2 r
.25376 .26524 .25776 .2706 .26202 .29091 .2581 .2843 Mtetra
.755 .344 0 r
.2581 .2843 .26202 .29091 .26708 .30272 .26321 .29536 Mtetra
.761 .666 .757 r
.26321 .29536 .26708 .30272 .27369 .29615 .2698 .28907 Mtetra
.894 .704 .637 r
.2698 .28907 .27369 .29615 .28154 .27367 .2776 .26773 Mtetra
.912 .718 .627 r
.2776 .26773 .28154 .27367 .28951 .2489 .28551 .24415 Mtetra
.875 .752 .724 r
.28551 .24415 .28951 .2489 .29642 .23729 .29241 .23298 Mtetra
.712 .231 0 r
.29241 .23298 .29642 .23729 .30183 .24615 .29786 .24115 Mtetra
.941 .574 .231 r
.29786 .24115 .30183 .24615 .30624 .26977 .30235 .26332 Mtetra
.932 .562 .167 r
.30235 .26332 .30624 .26977 .31086 .29212 .30703 .28433 Mtetra
.129 .311 .779 r
.30703 .28433 .31086 .29212 .31679 .29663 .31297 .28853 Mtetra
.871 .69 .655 r
.31297 .28853 .31679 .29663 .32424 .27825 .32038 .2711 Mtetra
.917 .706 .603 r
.32038 .2711 .32424 .27825 .3324 .24771 .32849 .24211 Mtetra
.919 .728 .628 r
.32849 .24211 .3324 .24771 .34005 .22398 .3361 .21946 Mtetra
.676 .739 .898 r
.3361 .21946 .34005 .22398 .34639 .22145 .34245 .21685 Mtetra
.919 .526 .152 r
.34245 .21685 .34639 .22145 .35148 .24117 .34759 .2353 Mtetra
.948 .592 .235 r
.34759 .2353 .35148 .24117 .35618 .26984 .35236 .26226 Mtetra
.835 .453 0 r
.35236 .26226 .35618 .26984 .36163 .28723 .35783 .2786 Mtetra
.761 .646 .734 r
.35783 .2786 .36163 .28723 .36842 .27971 .36462 .27144 Mtetra
.91 .698 .604 r
.36462 .27144 .36842 .27971 .37625 .25065 .37241 .24389 Mtetra
.929 .714 .59 r
.37241 .24389 .37625 .25065 .38415 .21808 .38028 .21293 Mtetra
.907 .748 .673 r
.38028 .21293 .38415 .21808 .39122 .20171 .38735 .19724 Mtetra
.633 .157 0 r
.38735 .19724 .39122 .20171 .39719 .2105 .39334 .20535 Mtetra
.939 .571 .206 r
.39334 .20535 .39719 .2105 .40249 .2376 .39867 .23082 Mtetra
.929 .563 .149 r
.39867 .23082 .40249 .2376 .40795 .26407 .40417 .2557 Mtetra
.011 .215 .725 r
.40417 .2557 .40795 .26407 .41427 .27046 .41049 .26163 Mtetra
.878 .688 .642 r
.41049 .26163 .41427 .27046 .42153 .25071 .41774 .24287 Mtetra
.928 .706 .582 r
.41774 .24287 .42153 .25071 .42917 .21677 .42536 .21065 Mtetra
.933 .727 .603 r
.42536 .21065 .42917 .21677 .4365 .18941 .43269 .18461 Mtetra
.78 .762 .837 r
.43269 .18461 .4365 .18941 .44314 .18408 .43934 .17941 Mtetra
.878 .463 .035 r
.43934 .17941 .44314 .18408 .4492 .20197 .44542 .1962 Mtetra
.93 .558 .159 r
.44542 .1962 .4492 .20197 .45514 .22966 .45137 .22224 Mtetra
.778 .394 0 r
.45137 .22224 .45514 .22966 .46144 .24704 .45767 .23849 Mtetra
.744 .645 .75 r
.45767 .23849 .46144 .24704 .46829 .24064 .46452 .23226 Mtetra
.915 .703 .602 r
.46452 .23226 .46829 .24064 .47547 .21343 .47171 .20637 Mtetra
.936 .718 .583 r
.47171 .20637 .47547 .21343 .48262 .18216 .47888 .17667 Mtetra
.916 .751 .663 r
.47888 .17667 .48262 .18216 .48949 .16503 .48577 .16037 Mtetra
0 .237 .744 r
.48577 .16037 .48949 .16503 .4961 .17016 .49238 .16515 Mtetra
.889 .487 .053 r
.49238 .16515 .4961 .17016 .50264 .1915 .49891 .18523 Mtetra
.861 .468 0 r
.49891 .18523 .50264 .1915 .5093 .21278 .50555 .20516 Mtetra
.144 .331 .792 r
.50555 .20516 .5093 .21278 .51613 .21782 .51238 .20966 Mtetra
.875 .702 .664 r
.51238 .20966 .51613 .21782 .52303 .20175 .5193 .19422 Mtetra
.93 .718 .594 r
.5193 .19422 .52303 .20175 .52986 .17417 .52617 .16797 Mtetra
.932 .739 .618 r
.52617 .16797 .52986 .17417 .53662 .15147 .53296 .14642 Mtetra
.79 .765 .83 r
.53296 .14642 .53662 .15147 .5434 .14552 .53976 .14078 Mtetra
.662 .209 0 r
.53976 .14078 .5434 .14552 .55033 .15688 .54668 .15149 Mtetra
.82 .405 0 r
.54668 .15149 .55033 .15688 .55742 .17518 .55375 .16866 Mtetra
0 0 .508 r
.55375 .16866 .55742 .17518 .56453 .18589 .56083 .1785 Mtetra
.753 .68 .781 r
.56083 .1785 .56453 .18589 .57145 .1801 .56777 .17271 Mtetra
.911 .724 .636 r
.56777 .17271 .57145 .1801 .57814 .1605 .57449 .15393 Mtetra
.931 .738 .62 r
.57449 .15393 .57814 .1605 .58471 .1387 .58112 .1332 Mtetra
.89 .768 .721 r
.58112 .1332 .58471 .1387 .59144 .12662 .58788 .12177 Mtetra
.232 .511 .909 r
.58788 .12177 .59144 .12662 .59849 .12888 .59493 .12393 Mtetra
.623 .181 0 r
.59493 .12393 .59849 .12888 .60584 .14069 .60226 .13501 Mtetra
0 0 .487 r
.60226 .13501 .60584 .14069 .61325 .1514 .60964 .1449 Mtetra
.498 .59 .877 r
.60964 .1449 .61325 .1514 .62041 .15177 .61679 .14492 Mtetra
.866 .734 .714 r
.61679 .14492 .62041 .15177 .62719 .14014 .6236 .13362 Mtetra
.917 .747 .656 r
.6236 .13362 .62719 .14014 .63374 .12301 .6302 .11725 Mtetra
.901 .767 .704 r
.6302 .11725 .63374 .12301 .64039 .10981 .6369 .10473 Mtetra
.692 .744 .891 r
.6369 .10473 .64039 .10981 .64741 .1064 .64394 .10151 Mtetra
0 .281 .781 r
.64394 .10151 .64741 .1064 .65484 .11177 .65136 .10654 Mtetra
0 .136 .674 r
.65136 .10654 .65484 .11177 .66243 .11933 .65893 .11351 Mtetra
.324 .52 .893 r
.65893 .11351 .66243 .11933 .66983 .12166 .66631 .11542 Mtetra
.783 .733 .807 r
.66631 .11542 .66983 .12166 .67684 .11552 .67333 .10931 Mtetra
.884 .759 .719 r
.67333 .10931 .67684 .11552 .68353 .10367 .68007 .0979 Mtetra
.886 .773 .732 r
.68007 .0979 .68353 .10367 .69024 .09236 .68682 .0871 Mtetra
.779 .771 .845 r
.68682 .0871 .69024 .09236 .69725 .08672 .69387 .08173 Mtetra
.405 .611 .933 r
.69387 .08173 .69725 .08672 .70466 .08751 .70129 .08241 Mtetra
.142 .439 .875 r
.70129 .08241 .70466 .08751 .71229 .09115 .7089 .08571 Mtetra
.385 .576 .915 r
.7089 .08571 .71229 .09115 .71983 .09257 .71643 .08681 Mtetra
.71 .728 .865 r
.71643 .08681 .71983 .09257 .72705 .08883 .72365 .08302 Mtetra
.83 .767 .793 r
.72365 .08302 .72705 .08883 .73399 .08109 .73063 .0755 Mtetra
.634 .711 .902 r
.08387 .31277 .08812 .31722 .09383 .31547 .08958 .31101 Mtetra
.766 .74 .829 r
.08958 .31101 .09383 .31547 .09996 .31069 .0957 .30638 Mtetra
.798 .749 .807 r
.0957 .30638 .09996 .31069 .10626 .30469 .10199 .30058 Mtetra
.743 .753 .861 r
.10199 .30058 .10626 .30469 .11227 .30086 .108 .29681 Mtetra
.388 .636 .954 r
.108 .29681 .11227 .30086 .11772 .30147 .11347 .29723 Mtetra
0 .164 .663 r
.11347 .29723 .11772 .30147 .12271 .30573 .11851 .30112 Mtetra
0 .199 .707 r
.11851 .30112 .12271 .30573 .12775 .30992 .12359 .30496 Mtetra
.505 .639 .915 r
.12359 .30496 .12775 .30992 .13336 .30979 .12922 .30472 Mtetra
.789 .725 .792 r
.12922 .30472 .13336 .30979 .13974 .30361 .13558 .29876 Mtetra
.845 .735 .743 r
.13558 .29876 .13974 .30361 .14655 .29388 .14236 .28945 Mtetra
.83 .749 .774 r
.14236 .28945 .14655 .29388 .15313 .28601 .14891 .28187 Mtetra
.602 .722 .929 r
.14891 .28187 .15313 .28601 .15892 .28467 .15472 .28047 Mtetra
.552 .05 0 r
.15472 .28047 .15892 .28467 .1639 .29058 .15974 .2859 Mtetra
.769 .3 0 r
.15974 .2859 .1639 .29058 .16858 .29941 .16448 .2941 Mtetra
0 .175 .702 r
.16448 .2941 .16858 .29941 .17377 .30419 .16971 .29849 Mtetra
.729 .694 .817 r
.16971 .29849 .17377 .30419 .17999 .29998 .17593 .29439 Mtetra
.857 .72 .71 r
.17593 .29439 .17999 .29998 .18709 .28771 .18299 .28268 Mtetra
.875 .732 .701 r
.18299 .28268 .18709 .28771 .19431 .27414 .19017 .26973 Mtetra
.812 .756 .8 r
.19017 .26973 .19431 .27414 .20077 .26755 .19661 .26336 Mtetra
0 .151 .651 r
.19661 .26336 .20077 .26755 .20607 .27218 .20195 .26758 Mtetra
.881 .455 .059 r
.20195 .26758 .20607 .27218 .21058 .28502 .20653 .27956 Mtetra
.843 .413 0 r
.20653 .27956 .21058 .28502 .21524 .29704 .21126 .29077 Mtetra
.356 .507 .871 r
.21126 .29077 .21524 .29704 .22098 .29871 .21701 .29223 Mtetra
.843 .704 .709 r
.21701 .29223 .22098 .29871 .22803 .2869 .22403 .28097 Mtetra
.892 .717 .658 r
.22403 .28097 .22803 .2869 .23574 .26779 .23168 .26281 Mtetra
.887 .737 .69 r
.23168 .26281 .23574 .26779 .24301 .25299 .23891 .24867 Mtetra
.585 .712 .93 r
.23891 .24867 .24301 .25299 .24901 .25185 .24493 .24743 Mtetra
.88 .452 .057 r
.24493 .24743 .24901 .25185 .25376 .26524 .24975 .2599 Mtetra
.928 .546 .177 r
.24975 .2599 .25376 .26524 .2581 .2843 .25417 .27775 Mtetra
.72 .306 0 r
.25417 .27775 .2581 .2843 .26321 .29536 .25932 .28807 Mtetra
.757 .666 .762 r
.25932 .28807 .26321 .29536 .2698 .28907 .2659 .28205 Mtetra
.891 .704 .643 r
.2659 .28205 .2698 .28907 .2776 .26773 .27364 .2618 Mtetra
.91 .719 .632 r
.27364 .2618 .2776 .26773 .28551 .24415 .28149 .23939 Mtetra
.871 .752 .729 r
.28149 .23939 .28551 .24415 .29241 .23298 .28838 .22864 Mtetra
.666 .18 0 r
.28838 .22864 .29241 .23298 .29786 .24115 .29387 .23616 Mtetra
.937 .563 .212 r
.29387 .23616 .29786 .24115 .30235 .26332 .29843 .25693 Mtetra
.925 .549 .144 r
.29843 .25693 .30235 .26332 .30703 .28433 .30318 .27663 Mtetra
.157 .333 .79 r
.30318 .27663 .30703 .28433 .31297 .28853 .30914 .28051 Mtetra
.867 .69 .66 r
.30914 .28051 .31297 .28853 .32038 .2711 .31651 .26398 Mtetra
.915 .707 .608 r
.31651 .26398 .32038 .2711 .32849 .24211 .32456 .23649 Mtetra
.917 .729 .633 r
.32456 .23649 .32849 .24211 .3361 .21946 .33214 .21492 Mtetra
.679 .74 .896 r
.33214 .21492 .3361 .21946 .34245 .21685 .3385 .21224 Mtetra
.91 .51 .126 r
.3385 .21224 .34245 .21685 .34759 .2353 .34369 .22949 Mtetra
.944 .582 .218 r
.34369 .22949 .34759 .2353 .35236 .26226 .34852 .25478 Mtetra
.814 .428 0 r
.34852 .25478 .35236 .26226 .35783 .2786 .35403 .27009 Mtetra
.757 .646 .739 r
.35403 .27009 .35783 .2786 .36462 .27144 .3608 .26325 Mtetra
.907 .699 .61 r
.3608 .26325 .36462 .27144 .37241 .24389 .36856 .23715 Mtetra
.927 .715 .596 r
.36856 .23715 .37241 .24389 .38028 .21293 .37639 .20776 Mtetra
.903 .749 .68 r
.37639 .20776 .38028 .21293 .38735 .19724 .38345 .19275 Mtetra
.582 .105 0 r
.38345 .19275 .38735 .19724 .39334 .20535 .38947 .20023 Mtetra
.934 .56 .188 r
.38947 .20023 .39334 .20535 .39867 .23082 .39484 .22412 Mtetra
.921 .55 .128 r
.39484 .22412 .39867 .23082 .40417 .2557 .40036 .24745 Mtetra
.049 .245 .742 r
.40036 .24745 .40417 .2557 .41049 .26163 .4067 .25291 Mtetra
.874 .689 .648 r
.4067 .25291 .41049 .26163 .41774 .24287 .41393 .23508 Mtetra
.926 .707 .588 r
.41393 .23508 .41774 .24287 .42536 .21065 .42155 .20453 Mtetra
.93 .728 .609 r
.42155 .20453 .42536 .21065 .43269 .18461 .42887 .17979 Mtetra
.775 .761 .841 r
.42887 .17979 .43269 .18461 .43934 .17941 .43553 .17474 Mtetra
.865 .443 .004 r
.43553 .17474 .43934 .17941 .44542 .1962 .44162 .19047 Mtetra
.923 .547 .14 r
.44162 .19047 .44542 .1962 .45137 .22224 .44758 .21489 Mtetra
.75 .363 0 r
.44758 .21489 .45137 .22224 .45767 .23849 .45389 .23003 Mtetra
.743 .646 .753 r
.45389 .23003 .45767 .23849 .46452 .23226 .46074 .22395 Mtetra
.912 .704 .608 r
.46074 .22395 .46452 .23226 .47171 .20637 .46794 .19934 Mtetra
.934 .719 .589 r
.46794 .19934 .47171 .20637 .47888 .17667 .47512 .17116 Mtetra
.911 .753 .672 r
.47512 .17116 .47888 .17667 .48577 .16037 .48202 .15568 Mtetra
0 .272 .77 r
.48202 .15568 .48577 .16037 .49238 .16515 .48864 .16013 Mtetra
.877 .47 .027 r
.48864 .16013 .49238 .16515 .49891 .18523 .49516 .179 Mtetra
.844 .446 0 r
.49516 .179 .49891 .18523 .50555 .20516 .5018 .1976 Mtetra
.188 .363 .807 r
.5018 .1976 .50555 .20516 .51238 .20966 .50863 .20158 Mtetra
.872 .703 .669 r
.50863 .20158 .51238 .20966 .5193 .19422 .51556 .18674 Mtetra
.928 .719 .6 r
.51556 .18674 .5193 .19422 .52617 .16797 .52246 .16178 Mtetra
.929 .74 .626 r
.52246 .16178 .52617 .16797 .53296 .14642 .52929 .14136 Mtetra
.78 .763 .838 r
.52929 .14136 .53296 .14642 .53976 .14078 .5361 .13603 Mtetra
.629 .175 0 r
.5361 .13603 .53976 .14078 .54668 .15149 .54302 .14611 Mtetra
.8 .38 0 r
.54302 .14611 .54668 .15149 .55375 .16866 .55006 .16216 Mtetra
0 0 .557 r
.55006 .16216 .55375 .16866 .56083 .1785 .55712 .17117 Mtetra
.754 .683 .782 r
.55712 .17117 .56083 .1785 .56777 .17271 .56407 .16537 Mtetra
.908 .725 .643 r
.56407 .16537 .56777 .17271 .57449 .15393 .57083 .14739 Mtetra
.928 .74 .628 r
.57083 .14739 .57449 .15393 .58112 .1332 .57751 .1277 Mtetra
.883 .769 .731 r
.57751 .1277 .58112 .1332 .58788 .12177 .5843 .1169 Mtetra
.243 .519 .912 r
.5843 .1169 .58788 .12177 .59493 .12393 .59136 .11896 Mtetra
.586 .144 0 r
.59136 .11896 .59493 .12393 .60226 .13501 .59867 .12933 Mtetra
0 0 .535 r
.59867 .12933 .60226 .13501 .60964 .1449 .60602 .13842 Mtetra
.519 .603 .877 r
.60602 .13842 .60964 .1449 .61679 .14492 .61317 .1381 Mtetra
.863 .734 .719 r
.61317 .1381 .61679 .14492 .6236 .13362 .62 .12714 Mtetra
.913 .748 .664 r
.62 .12714 .6236 .13362 .6302 .11725 .62665 .1115 Mtetra
.895 .768 .714 r
.62665 .1115 .6302 .11725 .6369 .10473 .6334 .09963 Mtetra
.682 .74 .895 r
.6334 .09963 .6369 .10473 .64394 .10151 .64046 .0966 Mtetra
0 .31 .8 r
.64046 .0966 .64394 .10151 .65136 .10654 .64787 .10129 Mtetra
0 .181 .71 r
.64787 .10129 .65136 .10654 .65893 .11351 .65541 .10768 Mtetra
.359 .542 .898 r
.65541 .10768 .65893 .11351 .66631 .11542 .66278 .10919 Mtetra
.782 .734 .808 r
.66278 .10919 .66631 .11542 .67333 .10931 .66982 .10312 Mtetra
.88 .76 .726 r
.66982 .10312 .67333 .10931 .68007 .0979 .6766 .09214 Mtetra
.879 .773 .74 r
.6766 .09214 .68007 .0979 .68682 .0871 .6834 .08184 Mtetra
.77 .769 .851 r
.6834 .08184 .68682 .0871 .69387 .08173 .69047 .07672 Mtetra
.414 .616 .934 r
.69047 .07672 .69387 .08173 .70129 .08241 .69789 .0773 Mtetra
.178 .463 .886 r
.69789 .0773 .70129 .08241 .7089 .08571 .7055 .08025 Mtetra
.41 .592 .918 r
.7055 .08025 .7089 .08571 .71643 .08681 .71301 .08105 Mtetra
.711 .73 .865 r
.71301 .08105 .71643 .08681 .72365 .08302 .72025 .07721 Mtetra
.825 .767 .798 r
.72025 .07721 .72365 .08302 .73063 .0755 .72725 .0699 Mtetra
.634 .711 .903 r
.0796 .30831 .08387 .31277 .08958 .31101 .08532 .30654 Mtetra
.762 .74 .833 r
.08532 .30654 .08958 .31101 .0957 .30638 .09143 .30206 Mtetra
.794 .749 .811 r
.09143 .30206 .0957 .30638 .10199 .30058 .0977 .29646 Mtetra
.74 .753 .863 r
.0977 .29646 .10199 .30058 .108 .29681 .10371 .29275 Mtetra
.414 .649 .955 r
.10371 .29275 .108 .29681 .11347 .29723 .1092 .29299 Mtetra
0 .226 .718 r
.1092 .29299 .11347 .29723 .11851 .30112 .11429 .29651 Mtetra
0 .254 .751 r
.11429 .29651 .11851 .30112 .12359 .30496 .11941 .3 Mtetra
.514 .645 .915 r
.11941 .3 .12359 .30496 .12922 .30472 .12505 .29965 Mtetra
.785 .725 .797 r
.12505 .29965 .12922 .30472 .13558 .29876 .1314 .29392 Mtetra
.84 .736 .748 r
.1314 .29392 .13558 .29876 .14236 .28945 .13814 .28502 Mtetra
.826 .75 .779 r
.13814 .28502 .14236 .28945 .14891 .28187 .14467 .27772 Mtetra
.608 .723 .927 r
.14467 .27772 .14891 .28187 .15472 .28047 .1505 .27624 Mtetra
0 .013 .514 r
.1505 .27624 .15472 .28047 .15974 .2859 .15557 .28121 Mtetra
.73 .254 0 r
.15557 .28121 .15974 .2859 .16448 .2941 .16037 .2888 Mtetra
0 .226 .742 r
.16037 .2888 .16448 .2941 .16971 .29849 .16564 .29281 Mtetra
.726 .695 .821 r
.16564 .29281 .16971 .29849 .17593 .29439 .17185 .28883 Mtetra
.854 .721 .716 r
.17185 .28883 .17593 .29439 .18299 .28268 .17887 .27766 Mtetra
.871 .734 .707 r
.17887 .27766 .18299 .28268 .19017 .26973 .186 .26531 Mtetra
.807 .756 .805 r
.186 .26531 .19017 .26973 .19661 .26336 .19244 .25915 Mtetra
0 .211 .705 r
.19244 .25915 .19661 .26336 .20195 .26758 .19782 .26298 Mtetra
.865 .428 .019 r
.19782 .26298 .20195 .26758 .20653 .27956 .20247 .27412 Mtetra
.817 .38 0 r
.20247 .27412 .20653 .27956 .21126 .29077 .20726 .28455 Mtetra
.376 .521 .875 r
.20726 .28455 .21126 .29077 .21701 .29223 .21303 .28579 Mtetra
.839 .705 .715 r
.21303 .28579 .21701 .29223 .22403 .28097 .22001 .27507 Mtetra
.889 .718 .664 r
.22001 .27507 .22403 .28097 .23168 .26281 .2276 .25781 Mtetra
.883 .738 .697 r
.2276 .25781 .23168 .26281 .23891 .24867 .2348 .24433 Mtetra
.592 .714 .929 r
.2348 .24433 .23891 .24867 .24493 .24743 .24083 .24299 Mtetra
.863 .426 .017 r
.24083 .24299 .24493 .24743 .24975 .2599 .24571 .25459 Mtetra
.92 .53 .151 r
.24571 .25459 .24975 .2599 .25417 .27775 .25021 .27126 Mtetra
.679 .263 0 r
.25021 .27126 .25417 .27775 .25932 .28807 .25541 .28086 Mtetra
.752 .667 .767 r
.25541 .28086 .25932 .28807 .2659 .28205 .26198 .27507 Mtetra
.888 .705 .648 r
.26198 .27507 .2659 .28205 .27364 .2618 .26966 .25588 Mtetra
.907 .72 .638 r
.26966 .25588 .27364 .2618 .28149 .23939 .27746 .2346 Mtetra
.866 .753 .735 r
.27746 .2346 .28149 .23939 .28838 .22864 .28433 .22428 Mtetra
.614 .124 0 r
.28433 .22428 .28838 .22864 .29387 .23616 .28986 .2312 Mtetra
.931 .55 .19 r
.28986 .2312 .29387 .23616 .29843 .25693 .2945 .25061 Mtetra
.916 .533 .118 r
.2945 .25061 .29843 .25693 .30318 .27663 .29932 .26903 Mtetra
.187 .357 .802 r
.29932 .26903 .30318 .27663 .30914 .28051 .30529 .27258 Mtetra
.864 .691 .666 r
.30529 .27258 .30914 .28051 .31651 .26398 .31262 .25691 Mtetra
.912 .708 .613 r
.31262 .25691 .31651 .26398 .32456 .23649 .32061 .23087 Mtetra
.914 .73 .64 r
.32061 .23087 .32456 .23649 .33214 .21492 .32816 .21035 Mtetra
.681 .74 .895 r
.32816 .21035 .33214 .21492 .3385 .21224 .33453 .20764 Mtetra
.9 .492 .097 r
.33453 .20764 .3385 .21224 .34369 .22949 .33978 .22372 Mtetra
.939 .572 .2 r
.33978 .22372 .34369 .22949 .34852 .25478 .34466 .24739 Mtetra
.789 .399 0 r
.34466 .24739 .34852 .25478 .35403 .27009 .35021 .26169 Mtetra
.753 .647 .744 r
.35021 .26169 .35403 .27009 .3608 .26325 .35697 .25513 Mtetra
.904 .699 .615 r
.35697 .25513 .3608 .26325 .36856 .23715 .36469 .23042 Mtetra
.925 .716 .601 r
.36469 .23042 .36856 .23715 .37639 .20776 .37249 .20257 Mtetra
.899 .749 .687 r
.37249 .20257 .37639 .20776 .38345 .19275 .37954 .18824 Mtetra
0 0 .471 r
.37954 .18824 .38345 .19275 .38947 .20023 .38558 .19513 Mtetra
.928 .548 .168 r
.38558 .19513 .38947 .20023 .39484 .22412 .39099 .21749 Mtetra
.912 .536 .105 r
.39099 .21749 .39484 .22412 .40036 .24745 .39655 .23931 Mtetra
.088 .276 .76 r
.39655 .23931 .40036 .24745 .4067 .25291 .4029 .24429 Mtetra
.871 .689 .654 r
.4029 .24429 .4067 .25291 .41393 .23508 .41012 .22735 Mtetra
.923 .708 .593 r
.41012 .22735 .41393 .23508 .42155 .20453 .41771 .1984 Mtetra
.927 .73 .616 r
.41771 .1984 .42155 .20453 .42887 .17979 .42503 .17494 Mtetra
.769 .759 .845 r
.42503 .17494 .42887 .17979 .43553 .17474 .4317 .17005 Mtetra
.848 .419 0 r
.4317 .17005 .43553 .17474 .44162 .19047 .4378 .18477 Mtetra
.916 .533 .118 r
.4378 .18477 .44162 .19047 .44758 .21489 .44377 .20763 Mtetra
.717 .328 0 r
.44377 .20763 .44758 .21489 .45389 .23003 .45009 .22169 Mtetra
.741 .648 .757 r
.45009 .22169 .45389 .23003 .46074 .22395 .45695 .21573 Mtetra
.91 .705 .614 r
.45695 .21573 .46074 .22395 .46794 .19934 .46416 .19235 Mtetra
.931 .721 .596 r
.46416 .19235 .46794 .19934 .47512 .17116 .47135 .16565 Mtetra
.907 .754 .68 r
.47135 .16565 .47512 .17116 .48202 .15568 .47827 .15097 Mtetra
0 .304 .793 r
.47827 .15097 .48202 .15568 .48864 .16013 .48489 .15512 Mtetra
.864 .451 0 r
.48489 .15512 .48864 .16013 .49516 .179 .4914 .1728 Mtetra
.824 .422 0 r
.4914 .1728 .49516 .179 .5018 .1976 .49803 .19012 Mtetra
.232 .394 .82 r
.49803 .19012 .5018 .1976 .50863 .20158 .50486 .19357 Mtetra
.869 .704 .675 r
.50486 .19357 .50863 .20158 .51556 .18674 .51181 .17931 Mtetra
.925 .72 .607 r
.51181 .17931 .51556 .18674 .52246 .16178 .51874 .15561 Mtetra
.926 .742 .635 r
.51874 .15561 .52246 .16178 .52929 .14136 .5256 .13629 Mtetra
.77 .761 .845 r
.5256 .13629 .52929 .14136 .5361 .13603 .53243 .13125 Mtetra
.594 .138 0 r
.53243 .13125 .5361 .13603 .54302 .14611 .53933 .14073 Mtetra
.776 .351 0 r
.53933 .14073 .54302 .14611 .55006 .16216 .54635 .1557 Mtetra
0 .041 .605 r
.54635 .1557 .55006 .16216 .55712 .17117 .55341 .16389 Mtetra
.755 .685 .784 r
.55341 .16389 .55712 .17117 .56407 .16537 .56036 .15808 Mtetra
.905 .726 .65 r
.56036 .15808 .56407 .16537 .57083 .14739 .56716 .14088 Mtetra
.924 .741 .637 r
.56716 .14088 .57083 .14739 .57751 .1277 .57388 .1222 Mtetra
.875 .769 .742 r
.57388 .1222 .57751 .1277 .5843 .1169 .5807 .11202 Mtetra
.255 .527 .915 r
.5807 .11202 .5843 .1169 .59136 .11896 .58777 .11396 Mtetra
0 0 .443 r
.58777 .11396 .59136 .11896 .59867 .12933 .59506 .12364 Mtetra
0 .025 .583 r
.59506 .12364 .59867 .12933 .60602 .13842 .60239 .13196 Mtetra
.54 .616 .877 r
.60239 .13196 .60602 .13842 .61317 .1381 .60953 .13132 Mtetra
.86 .735 .724 r
.60953 .13132 .61317 .1381 .62 .12714 .61639 .12068 Mtetra
.909 .749 .672 r
.61639 .12068 .62 .12714 .62665 .1115 .62309 .10577 Mtetra
.888 .769 .724 r
.62309 .10577 .62665 .1115 .6334 .09963 .62988 .09453 Mtetra
.673 .737 .899 r
.62988 .09453 .6334 .09963 .64046 .0966 .63696 .09166 Mtetra
0 .338 .819 r
.63696 .09166 .64046 .0966 .64787 .10129 .64436 .09601 Mtetra
0 .226 .744 r
.64436 .09601 .64787 .10129 .65541 .10768 .65188 .10184 Mtetra
.392 .562 .902 r
.65188 .10184 .65541 .10768 .66278 .10919 .65924 .10296 Mtetra
.781 .735 .81 r
.65924 .10296 .66278 .10919 .66982 .10312 .66629 .09695 Mtetra
.875 .76 .733 r
.66629 .09695 .66982 .10312 .6766 .09214 .67312 .08638 Mtetra
.873 .773 .749 r
.67312 .08638 .6766 .09214 .6834 .08184 .67996 .07657 Mtetra
.761 .766 .857 r
.67996 .07657 .6834 .08184 .69047 .07672 .68706 .07169 Mtetra
.424 .622 .935 r
.68706 .07169 .69047 .07672 .69789 .0773 .69449 .07215 Mtetra
.213 .486 .896 r
.69449 .07215 .69789 .0773 .7055 .08025 .70208 .07477 Mtetra
.434 .606 .919 r
.70208 .07477 .7055 .08025 .71301 .08105 .70958 .07528 Mtetra
.712 .731 .865 r
.70958 .07528 .71301 .08105 .72025 .07721 .71683 .0714 Mtetra
.82 .767 .802 r
.71683 .0714 .72025 .07721 .72725 .0699 .72387 .0643 Mtetra
.634 .712 .903 r
.07531 .30385 .0796 .30831 .08532 .30654 .08103 .30207 Mtetra
.757 .74 .837 r
.08103 .30207 .08532 .30654 .09143 .30206 .08713 .29773 Mtetra
.789 .749 .816 r
.08713 .29773 .09143 .30206 .0977 .29646 .09339 .29232 Mtetra
.737 .752 .865 r
.09339 .29232 .0977 .29646 .10371 .29275 .0994 .28867 Mtetra
.439 .66 .954 r
.0994 .28867 .10371 .29275 .1092 .29299 .10492 .28874 Mtetra
0 .285 .767 r
.10492 .28874 .1092 .29299 .11429 .29651 .11005 .2919 Mtetra
0 .306 .791 r
.11005 .2919 .11429 .29651 .11941 .3 .11521 .29505 Mtetra
.523 .65 .914 r
.11521 .29505 .11941 .3 .12505 .29965 .12087 .2946 Mtetra
.78 .725 .802 r
.12087 .2946 .12505 .29965 .1314 .29392 .1272 .28909 Mtetra
.836 .736 .754 r
.1272 .28909 .1314 .29392 .13814 .28502 .13391 .28057 Mtetra
.821 .75 .785 r
.13391 .28057 .13814 .28502 .14467 .27772 .14042 .27355 Mtetra
.612 .725 .926 r
.14042 .27355 .14467 .27772 .1505 .27624 .14625 .27201 Mtetra
0 .079 .581 r
.14625 .27201 .1505 .27624 .15557 .28121 .15138 .27653 Mtetra
.684 .202 0 r
.15138 .27653 .15557 .28121 .16037 .2888 .15624 .28353 Mtetra
0 .276 .778 r
.15624 .28353 .16037 .2888 .16564 .29281 .16155 .28716 Mtetra
.723 .696 .824 r
.16155 .28716 .16564 .29281 .17185 .28883 .16775 .28328 Mtetra
.85 .722 .722 r
.16775 .28328 .17185 .28883 .17887 .27766 .17473 .27264 Mtetra
.867 .735 .714 r
.17473 .27264 .17887 .27766 .186 .26531 .18182 .26088 Mtetra
.802 .756 .81 r
.18182 .26088 .186 .26531 .19244 .25915 .18824 .25493 Mtetra
0 .27 .755 r
.18824 .25493 .19244 .25915 .19782 .26298 .19366 .25838 Mtetra
.844 .397 0 r
.19366 .25838 .19782 .26298 .20247 .27412 .19839 .26871 Mtetra
.786 .342 0 r
.19839 .26871 .20247 .27412 .20726 .28455 .20324 .27837 Mtetra
.396 .535 .878 r
.20324 .27837 .20726 .28455 .21303 .28579 .20904 .2794 Mtetra
.835 .705 .721 r
.20904 .2794 .21303 .28579 .22001 .27507 .21598 .26918 Mtetra
.886 .719 .67 r
.21598 .26918 .22001 .27507 .2276 .25781 .22351 .25281 Mtetra
.879 .739 .703 r
.22351 .25281 .2276 .25781 .2348 .24433 .23066 .23997 Mtetra
.598 .716 .927 r
.23066 .23997 .2348 .24433 .24083 .24299 .23671 .23855 Mtetra
.843 .396 0 r
.23671 .23855 .24083 .24299 .24571 .25459 .24166 .2493 Mtetra
.911 .512 .121 r
.24166 .2493 .24571 .25459 .25021 .27126 .24624 .26483 Mtetra
.632 .215 0 r
.24624 .26483 .25021 .27126 .25541 .28086 .25149 .27372 Mtetra
.749 .668 .771 r
.25149 .27372 .25541 .28086 .26198 .27507 .25805 .26815 Mtetra
.885 .706 .654 r
.25805 .26815 .26198 .27507 .26966 .25588 .26567 .24996 Mtetra
.904 .721 .644 r
.26567 .24996 .26966 .25588 .27746 .2346 .27341 .22979 Mtetra
.862 .753 .742 r
.27341 .22979 .27746 .2346 .28433 .22428 .28026 .21991 Mtetra
.555 .065 0 r
.28026 .21991 .28433 .22428 .28986 .2312 .28583 .22625 Mtetra
.924 .535 .166 r
.28583 .22625 .28986 .2312 .2945 .25061 .29055 .24435 Mtetra
.904 .515 .089 r
.29055 .24435 .2945 .25061 .29932 .26903 .29543 .26153 Mtetra
.218 .38 .812 r
.29543 .26153 .29932 .26903 .30529 .27258 .30142 .26473 Mtetra
.86 .692 .672 r
.30142 .26473 .30529 .27258 .31262 .25691 .30872 .24987 Mtetra
.91 .709 .619 r
.30872 .24987 .31262 .25691 .32061 .23087 .31665 .22523 Mtetra
.911 .731 .646 r
.31665 .22523 .32061 .23087 .32816 .21035 .32416 .20576 Mtetra
.681 .739 .895 r
.32416 .20576 .32816 .21035 .33453 .20764 .33054 .20303 Mtetra
.888 .471 .066 r
.33054 .20303 .33453 .20764 .33978 .22372 .33584 .21799 Mtetra
.933 .56 .179 r
.33584 .21799 .33978 .22372 .34466 .24739 .34079 .24011 Mtetra
.758 .366 0 r
.34079 .24011 .34466 .24739 .35021 .26169 .34637 .25339 Mtetra
.749 .648 .749 r
.34637 .25339 .35021 .26169 .35697 .25513 .35313 .24709 Mtetra
.901 .7 .621 r
.35313 .24709 .35697 .25513 .36469 .23042 .36081 .22371 Mtetra
.922 .717 .607 r
.36081 .22371 .36469 .23042 .37249 .20257 .36857 .19735 Mtetra
.895 .75 .694 r
.36857 .19735 .37249 .20257 .37954 .18824 .37561 .1837 Mtetra
0 .004 .528 r
.37561 .1837 .37954 .18824 .38558 .19513 .38168 .19004 Mtetra
.921 .535 .145 r
.38168 .19004 .38558 .19513 .39099 .21749 .38713 .21093 Mtetra
.902 .519 .078 r
.38713 .21093 .39099 .21749 .39655 .23931 .39272 .23128 Mtetra
.129 .308 .776 r
.39272 .23128 .39655 .23931 .4029 .24429 .39908 .23578 Mtetra
.867 .69 .66 r
.39908 .23578 .4029 .24429 .41012 .22735 .40629 .21967 Mtetra
.921 .709 .599 r
.40629 .21967 .41012 .22735 .41771 .1984 .41387 .19228 Mtetra
.924 .731 .623 r
.41387 .19228 .41771 .1984 .42503 .17494 .42118 .17006 Mtetra
.762 .758 .849 r
.42118 .17006 .42503 .17494 .4317 .17005 .42785 .16536 Mtetra
.83 .394 0 r
.42785 .16536 .4317 .17005 .4378 .18477 .43397 .1791 Mtetra
.906 .518 .093 r
.43397 .1791 .4378 .18477 .44377 .20763 .43996 .20045 Mtetra
.678 .288 0 r
.43996 .20045 .44377 .20763 .45009 .22169 .44629 .21344 Mtetra
.74 .651 .76 r
.44629 .21344 .45009 .22169 .45695 .21573 .45315 .20759 Mtetra
.907 .706 .62 r
.45315 .20759 .45695 .21573 .46416 .19235 .46036 .18539 Mtetra
.929 .722 .603 r
.46036 .18539 .46416 .19235 .47135 .16565 .46757 .16013 Mtetra
.902 .755 .689 r
.46757 .16013 .47135 .16565 .47827 .15097 .47449 .14624 Mtetra
0 .334 .814 r
.47449 .14624 .47827 .15097 .48489 .15512 .48112 .1501 Mtetra
.848 .429 0 r
.48112 .1501 .48489 .15512 .4914 .1728 .48763 .16663 Mtetra
.801 .393 0 r
.48763 .16663 .4914 .1728 .49803 .19012 .49426 .18271 Mtetra
.274 .424 .831 r
.49426 .18271 .49803 .19012 .50486 .19357 .50109 .18565 Mtetra
.866 .705 .681 r
.50109 .18565 .50486 .19357 .51181 .17931 .50805 .17195 Mtetra
.922 .721 .614 r
.50805 .17195 .51181 .17931 .51874 .15561 .51501 .14946 Mtetra
.922 .743 .643 r
.51501 .14946 .51874 .15561 .5256 .13629 .52189 .1312 Mtetra
.76 .759 .852 r
.52189 .1312 .5256 .13629 .53243 .13125 .52874 .12646 Mtetra
0 0 .437 r
.52874 .12646 .53243 .13125 .53933 .14073 .53564 .13534 Mtetra
.747 .319 0 r
.53564 .13534 .53933 .14073 .54635 .1557 .54264 .14926 Mtetra
0 .098 .652 r
.54264 .14926 .54635 .1557 .55341 .16389 .54968 .15666 Mtetra
.756 .688 .786 r
.54968 .15666 .55341 .16389 .56036 .15808 .55665 .15085 Mtetra
.902 .728 .657 r
.55665 .15085 .56036 .15808 .56716 .14088 .56348 .1344 Mtetra
.92 .743 .646 r
.56348 .1344 .56716 .14088 .57388 .1222 .57024 .11671 Mtetra
.867 .77 .752 r
.57024 .11671 .57388 .1222 .5807 .11202 .57709 .10712 Mtetra
.267 .534 .917 r
.57709 .10712 .5807 .11202 .58777 .11396 .58416 .10894 Mtetra
0 0 .487 r
.58416 .10894 .58777 .11396 .59506 .12364 .59143 .11795 Mtetra
0 .079 .631 r
.59143 .11795 .59506 .12364 .60239 .13196 .59874 .12551 Mtetra
.558 .627 .876 r
.59874 .12551 .60239 .13196 .60953 .13132 .60588 .12457 Mtetra
.856 .736 .73 r
.60588 .12457 .60953 .13132 .61639 .12068 .61277 .11425 Mtetra
.904 .751 .681 r
.61277 .11425 .61639 .12068 .62309 .10577 .61951 .10004 Mtetra
.881 .77 .734 r
.61951 .10004 .62309 .10577 .62988 .09453 .62634 .08941 Mtetra
.663 .734 .902 r
.62634 .08941 .62988 .09453 .63696 .09166 .63345 .0867 Mtetra
.022 .366 .836 r
.63345 .0867 .63696 .09166 .64436 .09601 .64084 .09071 Mtetra
0 .27 .775 r
.64084 .09071 .64436 .09601 .65188 .10184 .64833 .09599 Mtetra
.422 .581 .905 r
.64833 .09599 .65188 .10184 .65924 .10296 .65568 .09675 Mtetra
.78 .735 .812 r
.65568 .09675 .65924 .10296 .66629 .09695 .66275 .0908 Mtetra
.869 .761 .74 r
.66275 .0908 .66629 .09695 .67312 .08638 .66962 .08063 Mtetra
.866 .774 .758 r
.66962 .08063 .67312 .08638 .67996 .07657 .6765 .07129 Mtetra
.752 .764 .863 r
.6765 .07129 .67996 .07657 .68706 .07169 .68363 .06663 Mtetra
.434 .628 .935 r
.68363 .06663 .68706 .07169 .69449 .07215 .69106 .06698 Mtetra
.247 .508 .904 r
.69106 .06698 .69449 .07215 .70208 .07477 .69864 .06926 Mtetra
.457 .618 .92 r
.69864 .06926 .70208 .07477 .70958 .07528 .70613 .0695 Mtetra
.713 .732 .865 r
.70613 .0695 .70958 .07528 .71683 .0714 .71339 .06559 Mtetra
.815 .766 .807 r
.71339 .06559 .71683 .0714 .72387 .0643 .72046 .0587 Mtetra
.634 .713 .904 r
.071 .29939 .07531 .30385 .08103 .30207 .07673 .2976 Mtetra
.752 .74 .841 r
.07673 .2976 .08103 .30207 .08713 .29773 .08282 .29339 Mtetra
.785 .749 .82 r
.08282 .29339 .08713 .29773 .09339 .29232 .08906 .28816 Mtetra
.734 .752 .867 r
.08906 .28816 .09339 .29232 .0994 .28867 .09507 .28457 Mtetra
.461 .67 .954 r
.09507 .28457 .0994 .28867 .10492 .28874 .10062 .28447 Mtetra
0 .342 .81 r
.10062 .28447 .10492 .28874 .11005 .2919 .10579 .28729 Mtetra
0 .355 .826 r
.10579 .28729 .11005 .2919 .11521 .29505 .11099 .29011 Mtetra
.531 .655 .914 r
.11099 .29011 .11521 .29505 .12087 .2946 .11667 .28956 Mtetra
.775 .726 .807 r
.11667 .28956 .12087 .2946 .1272 .28909 .12298 .28425 Mtetra
.831 .737 .761 r
.12298 .28425 .1272 .28909 .13391 .28057 .12966 .27611 Mtetra
.816 .75 .79 r
.12966 .27611 .13391 .28057 .14042 .27355 .13615 .26936 Mtetra
.617 .726 .924 r
.13615 .26936 .14042 .27355 .14625 .27201 .142 .26775 Mtetra
0 .147 .646 r
.142 .26775 .14625 .27201 .15138 .27653 .14717 .27185 Mtetra
.629 .144 0 r
.14717 .27185 .15138 .27653 .15624 .28353 .15209 .27827 Mtetra
0 .324 .81 r
.15209 .27827 .15624 .28353 .16155 .28716 .15744 .28154 Mtetra
.719 .696 .827 r
.15744 .28154 .16155 .28716 .16775 .28328 .16364 .27775 Mtetra
.845 .723 .728 r
.16364 .27775 .16775 .28328 .17473 .27264 .17058 .26762 Mtetra
.863 .736 .72 r
.17058 .26762 .17473 .27264 .18182 .26088 .17762 .25643 Mtetra
.797 .756 .815 r
.17762 .25643 .18182 .26088 .18824 .25493 .18403 .25069 Mtetra
0 .326 .798 r
.18403 .25069 .18824 .25493 .19366 .25838 .18949 .25377 Mtetra
.818 .361 0 r
.18949 .25377 .19366 .25838 .19839 .26871 .19428 .26332 Mtetra
.748 .297 0 r
.19428 .26332 .19839 .26871 .20324 .27837 .19921 .27223 Mtetra
.416 .548 .881 r
.19921 .27223 .20324 .27837 .20904 .2794 .20502 .27305 Mtetra
.83 .706 .727 r
.20502 .27305 .20904 .2794 .21598 .26918 .21193 .26332 Mtetra
.882 .72 .676 r
.21193 .26332 .21598 .26918 .22351 .25281 .2194 .2478 Mtetra
.875 .74 .71 r
.2194 .2478 .22351 .25281 .23066 .23997 .22652 .23559 Mtetra
.603 .718 .926 r
.22652 .23559 .23066 .23997 .23671 .23855 .23258 .23409 Mtetra
.818 .361 0 r
.23258 .23409 .23671 .23855 .24166 .2493 .23759 .24403 Mtetra
.898 .491 .087 r
.23759 .24403 .24166 .2493 .24624 .26483 .24225 .25845 Mtetra
0 0 .4 r
.24225 .25845 .24624 .26483 .25149 .27372 .24755 .26664 Mtetra
.745 .668 .776 r
.24755 .26664 .25149 .27372 .25805 .26815 .2541 .26127 Mtetra
.881 .707 .661 r
.2541 .26127 .25805 .26815 .26567 .24996 .26166 .24406 Mtetra
.901 .722 .651 r
.26166 .24406 .26567 .24996 .27341 .22979 .26934 .22496 Mtetra
.857 .754 .748 r
.26934 .22496 .27341 .22979 .28026 .21991 .27618 .21552 Mtetra
0 0 .509 r
.27618 .21552 .28026 .21991 .28583 .22625 .28178 .22131 Mtetra
.915 .519 .138 r
.28178 .22131 .28583 .22625 .29055 .24435 .28658 .23814 Mtetra
.89 .494 .055 r
.28658 .23814 .29055 .24435 .29543 .26153 .29153 .2541 Mtetra
.25 .404 .822 r
.29153 .2541 .29543 .26153 .30142 .26473 .29754 .25695 Mtetra
.855 .692 .679 r
.29754 .25695 .30142 .26473 .30872 .24987 .3048 .24287 Mtetra
.907 .71 .625 r
.3048 .24287 .30872 .24987 .31665 .22523 .31267 .21959 Mtetra
.907 .732 .653 r
.31267 .21959 .31665 .22523 .32416 .20576 .32015 .20114 Mtetra
.68 .739 .895 r
.32015 .20114 .32416 .20576 .33054 .20303 .32654 .19841 Mtetra
.873 .447 .03 r
.32654 .19841 .33054 .20303 .33584 .21799 .33188 .21231 Mtetra
.926 .546 .155 r
.33188 .21231 .33584 .21799 .34079 .24011 .3369 .2329 Mtetra
.721 .327 0 r
.3369 .2329 .34079 .24011 .34637 .25339 .34252 .24519 Mtetra
.746 .649 .753 r
.34252 .24519 .34637 .25339 .35313 .24709 .34928 .23912 Mtetra
.898 .701 .627 r
.34928 .23912 .35313 .24709 .36081 .22371 .35691 .21702 Mtetra
.919 .717 .614 r
.35691 .21702 .36081 .22371 .36857 .19735 .36464 .19211 Mtetra
.89 .751 .702 r
.36464 .19211 .36857 .19735 .37561 .1837 .37167 .17914 Mtetra
0 .061 .583 r
.37167 .17914 .37561 .1837 .38168 .19004 .37775 .18496 Mtetra
.913 .519 .12 r
.37775 .18496 .38168 .19004 .38713 .21093 .38325 .20442 Mtetra
.888 .5 .047 r
.38325 .20442 .38713 .21093 .39272 .23128 .38888 .22334 Mtetra
.172 .339 .791 r
.38888 .22334 .39272 .23128 .39908 .23578 .39525 .22735 Mtetra
.863 .69 .666 r
.39525 .22735 .39908 .23578 .40629 .21967 .40245 .21203 Mtetra
.918 .71 .606 r
.40245 .21203 .40629 .21967 .41387 .19228 .41001 .18616 Mtetra
.921 .732 .63 r
.41001 .18616 .41387 .19228 .42118 .17006 .41731 .16516 Mtetra
.755 .756 .853 r
.41731 .16516 .42118 .17006 .42785 .16536 .42398 .16065 Mtetra
.807 .364 0 r
.42398 .16065 .42785 .16536 .43397 .1791 .43012 .17345 Mtetra
.895 .5 .066 r
.43012 .17345 .43397 .1791 .43996 .20045 .43613 .19333 Mtetra
.631 .243 0 r
.43613 .19333 .43996 .20045 .44629 .21344 .44247 .20527 Mtetra
.739 .652 .763 r
.44247 .20527 .44629 .21344 .45315 .20759 .44934 .19952 Mtetra
.903 .707 .627 r
.44934 .19952 .45315 .20759 .46036 .18539 .45656 .17846 Mtetra
.926 .723 .61 r
.45656 .17846 .46036 .18539 .46757 .16013 .46376 .1546 Mtetra
.896 .756 .699 r
.46376 .1546 .46757 .16013 .47449 .14624 .4707 .14149 Mtetra
0 .362 .832 r
.4707 .14149 .47449 .14624 .48112 .1501 .47733 .14508 Mtetra
.83 .404 0 r
.47733 .14508 .48112 .1501 .48763 .16663 .48385 .16049 Mtetra
.772 .36 0 r
.48385 .16049 .48763 .16663 .49426 .18271 .49047 .17535 Mtetra
.315 .452 .84 r
.49047 .17535 .49426 .18271 .50109 .18565 .4973 .17779 Mtetra
.862 .705 .686 r
.4973 .17779 .50109 .18565 .50805 .17195 .50428 .16463 Mtetra
.919 .723 .621 r
.50428 .16463 .50805 .17195 .51501 .14946 .51127 .14332 Mtetra
.917 .745 .653 r
.51127 .14332 .51501 .14946 .52189 .1312 .51817 .1261 Mtetra
.749 .756 .858 r
.51817 .1261 .52189 .1312 .52874 .12646 .52503 .12164 Mtetra
0 0 .481 r
.52503 .12164 .52874 .12646 .53564 .13534 .53193 .12994 Mtetra
.714 .282 0 r
.53193 .12994 .53564 .13534 .54264 .14926 .53891 .14283 Mtetra
0 .155 .697 r
.53891 .14283 .54264 .14926 .54968 .15666 .54594 .14946 Mtetra
.757 .69 .787 r
.54594 .14946 .54968 .15666 .55665 .15085 .55292 .14366 Mtetra
.898 .729 .664 r
.55292 .14366 .55665 .15085 .56348 .1344 .55978 .12795 Mtetra
.916 .744 .655 r
.55978 .12795 .56348 .1344 .57024 .11671 .56659 .11122 Mtetra
.859 .77 .762 r
.56659 .11122 .57024 .11671 .57709 .10712 .57347 .10219 Mtetra
.28 .543 .92 r
.57347 .10219 .57709 .10712 .58416 .10894 .58054 .1039 Mtetra
0 0 .533 r
.58054 .1039 .58416 .10894 .59143 .11795 .58779 .11224 Mtetra
0 .135 .677 r
.58779 .11224 .59143 .11795 .59874 .12551 .59508 .11908 Mtetra
.575 .636 .875 r
.59508 .11908 .59874 .12551 .60588 .12457 .60222 .11784 Mtetra
.852 .736 .735 r
.60222 .11784 .60588 .12457 .61277 .11425 .60914 .10785 Mtetra
.899 .752 .689 r
.60914 .10785 .61277 .11425 .61951 .10004 .61592 .09433 Mtetra
.874 .77 .745 r
.61592 .09433 .61951 .10004 .62634 .08941 .62279 .08428 Mtetra
.655 .731 .905 r
.62279 .08428 .62634 .08941 .63345 .0867 .62992 .08171 Mtetra
.061 .394 .852 r
.62992 .08171 .63345 .0867 .64084 .09071 .6373 .08539 Mtetra
0 .313 .804 r
.6373 .08539 .64084 .09071 .64833 .09599 .64477 .09013 Mtetra
.45 .597 .906 r
.64477 .09013 .64833 .09599 .65568 .09675 .65212 .09054 Mtetra
.778 .736 .814 r
.65212 .09054 .65568 .09675 .66275 .0908 .6592 .08465 Mtetra
.864 .761 .747 r
.6592 .08465 .66275 .0908 .66962 .08063 .66611 .07489 Mtetra
.858 .774 .767 r
.66611 .07489 .66962 .08063 .6765 .07129 .67303 .066 Mtetra
.743 .762 .868 r
.67303 .066 .6765 .07129 .68363 .06663 .68019 .06155 Mtetra
.444 .633 .935 r
.68019 .06155 .68363 .06663 .69106 .06698 .68762 .06177 Mtetra
.28 .529 .911 r
.68762 .06177 .69106 .06698 .69864 .06926 .69519 .06374 Mtetra
.477 .63 .92 r
.69519 .06374 .69864 .06926 .70613 .0695 .70268 .0637 Mtetra
.714 .733 .866 r
.70268 .0637 .70613 .0695 .71339 .06559 .70995 .05978 Mtetra
.809 .765 .812 r
.70995 .05978 .71339 .06559 .72046 .0587 .71705 .05309 Mtetra
.634 .713 .904 r
.06667 .29491 .071 .29939 .07673 .2976 .07241 .29311 Mtetra
.747 .739 .844 r
.07241 .29311 .07673 .2976 .08282 .29339 .07849 .28904 Mtetra
.78 .749 .825 r
.07849 .28904 .08282 .29339 .08906 .28816 .08471 .28399 Mtetra
.731 .752 .869 r
.08471 .28399 .08906 .28816 .09507 .28457 .09073 .28046 Mtetra
.482 .679 .952 r
.09073 .28046 .09507 .28457 .10062 .28447 .0963 .28019 Mtetra
0 .395 .847 r
.0963 .28019 .10062 .28447 .10579 .28729 .10152 .28266 Mtetra
.034 .402 .856 r
.10152 .28266 .10579 .28729 .11099 .29011 .10676 .28516 Mtetra
.54 .658 .913 r
.10676 .28516 .11099 .29011 .11667 .28956 .11245 .28451 Mtetra
.77 .725 .811 r
.11245 .28451 .11667 .28956 .12298 .28425 .11875 .2794 Mtetra
.826 .737 .767 r
.11875 .2794 .12298 .28425 .12966 .27611 .12539 .27163 Mtetra
.811 .751 .796 r
.12539 .27163 .12966 .27611 .13615 .26936 .13185 .26516 Mtetra
.621 .728 .923 r
.13185 .26516 .13615 .26936 .142 .26775 .13772 .26348 Mtetra
0 .216 .709 r
.13772 .26348 .142 .26775 .14717 .27185 .14294 .26715 Mtetra
.562 .077 0 r
.14294 .26715 .14717 .27185 .15209 .27827 .14793 .273 Mtetra
.041 .369 .838 r
.14793 .273 .15209 .27827 .15744 .28154 .15331 .2759 Mtetra
.716 .696 .83 r
.15331 .2759 .15744 .28154 .16364 .27775 .15951 .27222 Mtetra
.84 .723 .735 r
.15951 .27222 .16364 .27775 .17058 .26762 .1664 .26259 Mtetra
.858 .736 .727 r
.1664 .26259 .17058 .26762 .17762 .25643 .1734 .25196 Mtetra
.792 .755 .82 r
.1734 .25196 .17762 .25643 .18403 .25069 .1798 .24643 Mtetra
0 .378 .836 r
.1798 .24643 .18403 .25069 .18949 .25377 .1853 .24915 Mtetra
.785 .318 0 r
.1853 .24915 .18949 .25377 .19428 .26332 .19016 .25792 Mtetra
.7 .244 0 r
.19016 .25792 .19428 .26332 .19921 .27223 .19515 .2661 Mtetra
.436 .559 .881 r
.19515 .2661 .19921 .27223 .20502 .27305 .20099 .2667 Mtetra
.825 .706 .733 r
.20099 .2667 .20502 .27305 .21193 .26332 .20787 .25744 Mtetra
.878 .72 .683 r
.20787 .25744 .21193 .26332 .2194 .2478 .21528 .24277 Mtetra
.87 .741 .717 r
.21528 .24277 .2194 .2478 .22652 .23559 .22235 .23118 Mtetra
.607 .719 .924 r
.22235 .23118 .22652 .23559 .23258 .23409 .22842 .22962 Mtetra
.787 .319 0 r
.22842 .22962 .23258 .23409 .23759 .24403 .2335 .23877 Mtetra
.882 .466 .047 r
.2335 .23877 .23759 .24403 .24225 .25845 .23824 .25209 Mtetra
0 0 .466 r
.23824 .25209 .24225 .25845 .24755 .26664 .2436 .25957 Mtetra
.74 .667 .779 r
.2436 .25957 .24755 .26664 .2541 .26127 .25013 .25439 Mtetra
.877 .707 .667 r
.25013 .25439 .2541 .26127 .26166 .24406 .25764 .23813 Mtetra
.897 .723 .657 r
.25764 .23813 .26166 .24406 .26934 .22496 .26526 .2201 Mtetra
.851 .754 .755 r
.26526 .2201 .26934 .22496 .27618 .21552 .27207 .21111 Mtetra
0 .062 .575 r
.27207 .21111 .27618 .21552 .28178 .22131 .27772 .21636 Mtetra
.904 .499 .106 r
.27772 .21636 .28178 .22131 .28658 .23814 .28259 .23195 Mtetra
.872 .468 .013 r
.28259 .23195 .28658 .23814 .29153 .2541 .28762 .2467 Mtetra
.286 .427 .829 r
.28762 .2467 .29153 .2541 .29754 .25695 .29365 .24919 Mtetra
.85 .691 .685 r
.29365 .24919 .29754 .25695 .3048 .24287 .30087 .23586 Mtetra
.903 .71 .632 r
.30087 .23586 .3048 .24287 .31267 .21959 .30868 .21392 Mtetra
.903 .733 .66 r
.30868 .21392 .31267 .21959 .32015 .20114 .31612 .19649 Mtetra
.678 .738 .896 r
.31612 .19649 .32015 .20114 .32654 .19841 .32251 .19378 Mtetra
.854 .419 0 r
.32251 .19378 .32654 .19841 .33188 .21231 .32791 .20663 Mtetra
.916 .529 .126 r
.32791 .20663 .33188 .21231 .3369 .2329 .333 .22572 Mtetra
.673 .279 0 r
.333 .22572 .3369 .2329 .34252 .24519 .33866 .23703 Mtetra
.741 .648 .757 r
.33866 .23703 .34252 .24519 .34928 .23912 .34541 .23115 Mtetra
.894 .7 .634 r
.34541 .23115 .34928 .23912 .35691 .21702 .35301 .21031 Mtetra
.916 .718 .62 r
.35301 .21031 .35691 .21702 .36464 .19211 .36069 .18684 Mtetra
.885 .752 .71 r
.36069 .18684 .36464 .19211 .37167 .17914 .3677 .17457 Mtetra
0 .118 .637 r
.3677 .17457 .37167 .17914 .37775 .18496 .37381 .17988 Mtetra
.902 .501 .09 r
.37381 .17988 .37775 .18496 .38325 .20442 .37935 .19794 Mtetra
.871 .476 .009 r
.37935 .19794 .38325 .20442 .38888 .22334 .38503 .21543 Mtetra
.218 .371 .803 r
.38503 .21543 .38888 .22334 .39525 .22735 .39141 .21895 Mtetra
.858 .69 .672 r
.39141 .21895 .39525 .22735 .40245 .21203 .3986 .20441 Mtetra
.914 .71 .612 r
.3986 .20441 .40245 .21203 .41001 .18616 .40613 .18002 Mtetra
.917 .733 .638 r
.40613 .18002 .41001 .18616 .41731 .16516 .41342 .16024 Mtetra
.747 .754 .858 r
.41342 .16024 .41731 .16516 .42398 .16065 .4201 .15593 Mtetra
.781 .331 0 r
.4201 .15593 .42398 .16065 .43012 .17345 .42625 .16781 Mtetra
.881 .479 .033 r
.42625 .16781 .43012 .17345 .43613 .19333 .43229 .18623 Mtetra
0 0 .387 r
.43229 .18623 .43613 .19333 .44247 .20527 .43865 .19714 Mtetra
.738 .653 .765 r
.43865 .19714 .44247 .20527 .44934 .19952 .44552 .19146 Mtetra
.899 .707 .634 r
.44552 .19146 .44934 .19952 .45656 .17846 .45273 .17152 Mtetra
.922 .724 .618 r
.45273 .17152 .45656 .17846 .46376 .1546 .45995 .14905 Mtetra
.89 .756 .709 r
.45995 .14905 .46376 .1546 .4707 .14149 .46689 .13672 Mtetra
.031 .389 .849 r
.46689 .13672 .4707 .14149 .47733 .14508 .47353 .14003 Mtetra
.807 .374 0 r
.47353 .14003 .47733 .14508 .48385 .16049 .48005 .15434 Mtetra
.736 .321 0 r
.48005 .15434 .48385 .16049 .49047 .17535 .48667 .168 Mtetra
.355 .478 .845 r
.48667 .168 .49047 .17535 .4973 .17779 .4935 .16995 Mtetra
.857 .705 .692 r
.4935 .16995 .4973 .17779 .50428 .16463 .5005 .15732 Mtetra
.915 .723 .629 r
.5005 .15732 .50428 .16463 .51127 .14332 .50751 .13718 Mtetra
.912 .746 .663 r
.50751 .13718 .51127 .14332 .51817 .1261 .51444 .12099 Mtetra
.737 .753 .865 r
.51444 .12099 .51817 .1261 .52503 .12164 .52131 .11681 Mtetra
0 0 .526 r
.52131 .11681 .52503 .12164 .53193 .12994 .5282 .12452 Mtetra
.673 .239 0 r
.5282 .12452 .53193 .12994 .53891 .14283 .53517 .13639 Mtetra
0 .215 .739 r
.53517 .13639 .53891 .14283 .54594 .14946 .5422 .14227 Mtetra
.756 .69 .788 r
.5422 .14227 .54594 .14946 .55292 .14366 .54918 .13648 Mtetra
.893 .729 .671 r
.54918 .13648 .55292 .14366 .55978 .12795 .55607 .12151 Mtetra
.911 .745 .664 r
.55607 .12151 .55978 .12795 .56659 .11122 .56291 .10572 Mtetra
.849 .769 .773 r
.56291 .10572 .56659 .11122 .57347 .10219 .56982 .09726 Mtetra
.294 .551 .923 r
.56982 .09726 .57347 .10219 .58054 .1039 .5769 .09883 Mtetra
0 .035 .58 r
.5769 .09883 .58054 .1039 .58779 .11224 .58414 .1065 Mtetra
0 .192 .722 r
.58414 .1065 .58779 .11224 .59508 .11908 .59141 .11262 Mtetra
.59 .644 .872 r
.59141 .11262 .59508 .11908 .60222 .11784 .59855 .11111 Mtetra
.847 .736 .74 r
.59855 .11111 .60222 .11784 .60914 .10785 .60549 .10146 Mtetra
.893 .752 .698 r
.60549 .10146 .60914 .10785 .61592 .09433 .61232 .08861 Mtetra
.865 .77 .755 r
.61232 .08861 .61592 .09433 .62279 .08428 .61923 .07914 Mtetra
.647 .728 .908 r
.61923 .07914 .62279 .08428 .62992 .08171 .62637 .07669 Mtetra
.101 .422 .867 r
.62637 .07669 .62992 .08171 .6373 .08539 .63374 .08003 Mtetra
.032 .355 .83 r
.63374 .08003 .6373 .08539 .64477 .09013 .6412 .08424 Mtetra
.476 .611 .906 r
.6412 .08424 .64477 .09013 .65212 .09054 .64854 .08432 Mtetra
.775 .735 .816 r
.64854 .08432 .65212 .09054 .6592 .08465 .65564 .0785 Mtetra
.857 .76 .754 r
.65564 .0785 .6592 .08465 .66611 .07489 .66258 .06915 Mtetra
.85 .773 .776 r
.66258 .06915 .66611 .07489 .67303 .066 .66955 .0607 Mtetra
.735 .76 .873 r
.66955 .0607 .67303 .066 .68019 .06155 .67673 .05645 Mtetra
.455 .64 .936 r
.67673 .05645 .68019 .06155 .68762 .06177 .68416 .05654 Mtetra
.313 .549 .917 r
.68416 .05654 .68762 .06177 .69519 .06374 .69172 .05818 Mtetra
.497 .64 .919 r
.69172 .05818 .69519 .06374 .70268 .0637 .6992 .05789 Mtetra
.714 .733 .866 r
.6992 .05789 .70268 .0637 .70995 .05978 .70649 .05395 Mtetra
.803 .764 .817 r
.70649 .05395 .70995 .05978 .71705 .05309 .71362 .04747 Mtetra
.634 .714 .904 r
.06233 .29042 .06667 .29491 .07241 .29311 .06807 .28861 Mtetra
.742 .739 .848 r
.06807 .28861 .07241 .29311 .07849 .28904 .07414 .28467 Mtetra
.775 .749 .829 r
.07414 .28467 .07849 .28904 .08471 .28399 .08035 .2798 Mtetra
.729 .751 .87 r
.08035 .2798 .08471 .28399 .09073 .28046 .08636 .27633 Mtetra
.501 .687 .95 r
.08636 .27633 .09073 .28046 .0963 .28019 .09196 .27589 Mtetra
.067 .444 .878 r
.09196 .27589 .0963 .28019 .10152 .28266 .09722 .27803 Mtetra
.099 .444 .88 r
.09722 .27803 .10152 .28266 .10676 .28516 .10251 .2802 Mtetra
.548 .663 .912 r
.10251 .2802 .10676 .28516 .11245 .28451 .10822 .27946 Mtetra
.764 .725 .816 r
.10822 .27946 .11245 .28451 .11875 .2794 .11449 .27455 Mtetra
.82 .738 .773 r
.11449 .27455 .11875 .2794 .12539 .27163 .1211 .26715 Mtetra
.806 .751 .801 r
.1211 .26715 .12539 .27163 .13185 .26516 .12754 .26094 Mtetra
.625 .729 .921 r
.12754 .26094 .13185 .26516 .13772 .26348 .13342 .2592 Mtetra
0 .283 .765 r
.13342 .2592 .13772 .26348 .14294 .26715 .13869 .26245 Mtetra
0 0 .513 r
.13869 .26245 .14294 .26715 .14793 .273 .14374 .26774 Mtetra
.104 .411 .861 r
.14374 .26774 .14793 .273 .15331 .2759 .14917 .27028 Mtetra
.712 .696 .833 r
.14917 .27028 .15331 .2759 .15951 .27222 .15536 .26669 Mtetra
.835 .723 .741 r
.15536 .26669 .15951 .27222 .1664 .26259 .16221 .25755 Mtetra
.853 .737 .734 r
.16221 .25755 .1664 .26259 .1734 .25196 .16916 .24747 Mtetra
.786 .755 .825 r
.16916 .24747 .1734 .25196 .1798 .24643 .17555 .24215 Mtetra
.039 .427 .867 r
.17555 .24215 .1798 .24643 .1853 .24915 .18109 .24452 Mtetra
.743 .267 0 r
.18109 .24452 .1853 .24915 .19016 .25792 .18603 .25254 Mtetra
.641 .183 0 r
.18603 .25254 .19016 .25792 .19515 .2661 .19108 .25999 Mtetra
.455 .571 .882 r
.19108 .25999 .19515 .2661 .20099 .2667 .19694 .26038 Mtetra
.82 .706 .739 r
.19694 .26038 .20099 .2667 .20787 .25744 .20379 .25157 Mtetra
.873 .721 .69 r
.20379 .25157 .20787 .25744 .21528 .24277 .21114 .23772 Mtetra
.865 .742 .725 r
.21114 .23772 .21528 .24277 .22235 .23118 .21816 .22676 Mtetra
.611 .721 .923 r
.21816 .22676 .22235 .23118 .22842 .22962 .22425 .22514 Mtetra
.747 .271 0 r
.22425 .22514 .22842 .22962 .2335 .23877 .22939 .23351 Mtetra
.861 .435 0 r
.22939 .23351 .2335 .23877 .23824 .25209 .23422 .24576 Mtetra
0 0 .533 r
.23422 .24576 .23824 .25209 .2436 .25957 .23963 .25255 Mtetra
.736 .668 .783 r
.23963 .25255 .2436 .25957 .25013 .25439 .24615 .24754 Mtetra
.873 .707 .674 r
.24615 .24754 .25013 .25439 .25764 .23813 .2536 .23221 Mtetra
.893 .724 .665 r
.2536 .23221 .25764 .23813 .26526 .2201 .26116 .21523 Mtetra
.845 .754 .763 r
.26116 .21523 .26526 .2201 .27207 .21111 .26795 .20668 Mtetra
0 .128 .638 r
.26795 .20668 .27207 .21111 .27772 .21636 .27364 .21142 Mtetra
.89 .475 .068 r
.27364 .21142 .27772 .21636 .28259 .23195 .27859 .22579 Mtetra
.848 .437 0 r
.27859 .22579 .28259 .23195 .28762 .2467 .28369 .23936 Mtetra
.319 .45 .836 r
.28369 .23936 .28762 .2467 .29365 .24919 .28974 .24149 Mtetra
.845 .691 .691 r
.28974 .24149 .29365 .24919 .30087 .23586 .29693 .22887 Mtetra
.899 .711 .638 r
.29693 .22887 .30087 .23586 .30868 .21392 .30468 .20824 Mtetra
.899 .734 .668 r
.30468 .20824 .30868 .21392 .31612 .19649 .31207 .19182 Mtetra
.676 .737 .897 r
.31207 .19182 .31612 .19649 .32251 .19378 .31847 .18914 Mtetra
.831 .386 0 r
.31847 .18914 .32251 .19378 .32791 .20663 .32392 .20098 Mtetra
.904 .509 .094 r
.32392 .20098 .32791 .20663 .333 .22572 .32908 .2186 Mtetra
0 0 .344 r
.32908 .2186 .333 .22572 .33866 .23703 .33479 .22893 Mtetra
.738 .649 .76 r
.33479 .22893 .33866 .23703 .34541 .23115 .34153 .22324 Mtetra
.89 .701 .641 r
.34153 .22324 .34541 .23115 .35301 .21031 .34909 .20361 Mtetra
.912 .719 .628 r
.34909 .20361 .35301 .21031 .36069 .18684 .35672 .18156 Mtetra
.879 .752 .719 r
.35672 .18156 .36069 .18684 .3677 .17457 .36372 .16997 Mtetra
0 .174 .687 r
.36372 .16997 .3677 .17457 .37381 .17988 .36985 .1748 Mtetra
.888 .479 .057 r
.36985 .1748 .37381 .17988 .37935 .19794 .37544 .1915 Mtetra
.849 .448 0 r
.37544 .1915 .37935 .19794 .38503 .21543 .38116 .20759 Mtetra
.261 .401 .815 r
.38116 .20759 .38503 .21543 .39141 .21895 .38756 .21061 Mtetra
.853 .689 .678 r
.38756 .21061 .39141 .21895 .3986 .20441 .39473 .19681 Mtetra
.911 .711 .62 r
.39473 .19681 .3986 .20441 .40613 .18002 .40224 .17388 Mtetra
.913 .734 .647 r
.40224 .17388 .40613 .18002 .41342 .16024 .40951 .1553 Mtetra
.739 .752 .863 r
.40951 .1553 .41342 .16024 .4201 .15593 .4162 .15118 Mtetra
.749 .292 0 r
.4162 .15118 .4201 .15593 .42625 .16781 .42237 .16217 Mtetra
.863 .455 0 r
.42237 .16217 .42625 .16781 .43229 .18623 .42843 .17916 Mtetra
0 0 .45 r
.42843 .17916 .43229 .18623 .43865 .19714 .43481 .18905 Mtetra
.737 .654 .768 r
.43481 .18905 .43865 .19714 .44552 .19146 .44168 .18346 Mtetra
.895 .707 .641 r
.44168 .18346 .44552 .19146 .45273 .17152 .4489 .16462 Mtetra
.918 .725 .626 r
.4489 .16462 .45273 .17152 .45995 .14905 .45611 .1435 Mtetra
.883 .757 .719 r
.45611 .1435 .45995 .14905 .46689 .13672 .46306 .13193 Mtetra
.069 .415 .864 r
.46306 .13193 .46689 .13672 .47353 .14003 .46971 .13498 Mtetra
.779 .341 0 r
.46971 .13498 .47353 .14003 .48005 .15434 .47623 .1482 Mtetra
.692 .275 0 r
.47623 .1482 .48005 .15434 .48667 .168 .48286 .16068 Mtetra
.392 .501 .85 r
.48286 .16068 .48667 .168 .4935 .16995 .4897 .16215 Mtetra
.853 .705 .698 r
.4897 .16215 .4935 .16995 .5005 .15732 .4967 .15005 Mtetra
.911 .724 .638 r
.4967 .15005 .5005 .15732 .50751 .13718 .50373 .13105 Mtetra
.907 .747 .673 r
.50373 .13105 .50751 .13718 .51444 .12099 .51068 .11586 Mtetra
.726 .75 .871 r
.51068 .11586 .51444 .12099 .52131 .11681 .51756 .11194 Mtetra
0 .034 .572 r
.51756 .11194 .52131 .11681 .5282 .12452 .52445 .11908 Mtetra
.626 .191 0 r
.52445 .11908 .5282 .12452 .53517 .13639 .53142 .12995 Mtetra
0 .271 .776 r
.53142 .12995 .53517 .13639 .5422 .14227 .53843 .1351 Mtetra
.756 .691 .789 r
.53843 .1351 .5422 .14227 .54918 .13648 .54543 .12934 Mtetra
.888 .729 .679 r
.54543 .12934 .54918 .13648 .55607 .12151 .55235 .1151 Mtetra
.905 .747 .674 r
.55235 .1151 .55607 .12151 .56291 .10572 .55923 .10023 Mtetra
.84 .769 .784 r
.55923 .10023 .56291 .10572 .56982 .09726 .56616 .0923 Mtetra
.309 .561 .926 r
.56616 .0923 .56982 .09726 .5769 .09883 .57324 .09373 Mtetra
0 .088 .628 r
.57324 .09373 .5769 .09883 .58414 .1065 .58047 .10074 Mtetra
0 .249 .762 r
.58047 .10074 .58414 .1065 .59141 .11262 .58772 .10616 Mtetra
.604 .652 .87 r
.58772 .10616 .59141 .11262 .59855 .11111 .59487 .1044 Mtetra
.842 .736 .746 r
.59487 .1044 .59855 .11111 .60549 .10146 .60183 .09508 Mtetra
.887 .753 .708 r
.60183 .09508 .60549 .10146 .61232 .08861 .6087 .08291 Mtetra
.857 .77 .765 r
.6087 .08291 .61232 .08861 .61923 .07914 .61565 .07398 Mtetra
.639 .726 .911 r
.61565 .07398 .61923 .07914 .62637 .07669 .6228 .07165 Mtetra
.141 .449 .881 r
.6228 .07165 .62637 .07669 .63374 .08003 .63017 .07463 Mtetra
.09 .396 .852 r
.63017 .07463 .63374 .08003 .6412 .08424 .63761 .07833 Mtetra
.499 .624 .905 r
.63761 .07833 .6412 .08424 .64854 .08432 .64494 .07808 Mtetra
.773 .735 .818 r
.64494 .07808 .64854 .08432 .65564 .0785 .65206 .07236 Mtetra
.851 .76 .762 r
.65206 .07236 .65564 .0785 .66258 .06915 .65904 .06341 Mtetra
.841 .772 .785 r
.65904 .06341 .66258 .06915 .66955 .0607 .66605 .05539 Mtetra
.726 .757 .877 r
.66605 .05539 .66955 .0607 .67673 .05645 .67325 .05132 Mtetra
.467 .646 .936 r
.67325 .05132 .67673 .05645 .68416 .05654 .68069 .05127 Mtetra
.344 .568 .922 r
.68069 .05127 .68416 .05654 .69172 .05818 .68824 .05259 Mtetra
.515 .65 .918 r
.68824 .05259 .69172 .05818 .6992 .05789 .69571 .05205 Mtetra
.713 .733 .866 r
.69571 .05205 .6992 .05789 .70649 .05395 .70301 .04811 Mtetra
.797 .763 .822 r
.70301 .04811 .70649 .05395 .71362 .04747 .71017 .04185 Mtetra
.635 .714 .904 r
.05797 .28593 .06233 .29042 .06807 .28861 .06372 .2841 Mtetra
.737 .738 .852 r
.06372 .2841 .06807 .28861 .07414 .28467 .06977 .28029 Mtetra
.769 .748 .834 r
.06977 .28029 .07414 .28467 .08035 .2798 .07597 .2756 Mtetra
.726 .751 .872 r
.07597 .2756 .08035 .2798 .08636 .27633 .08198 .27218 Mtetra
.519 .694 .948 r
.08198 .27218 .08636 .27633 .09196 .27589 .0876 .27158 Mtetra
.136 .488 .902 r
.0876 .27158 .09196 .27589 .09722 .27803 .09291 .27339 Mtetra
.161 .483 .899 r
.09291 .27339 .09722 .27803 .10251 .2802 .09824 .27525 Mtetra
.556 .667 .911 r
.09824 .27525 .10251 .2802 .10822 .27946 .10396 .2744 Mtetra
.759 .725 .821 r
.10396 .2744 .10822 .27946 .11449 .27455 .11022 .26969 Mtetra
.815 .738 .78 r
.11022 .26969 .11449 .27455 .1211 .26715 .11679 .26265 Mtetra
.8 .751 .807 r
.11679 .26265 .1211 .26715 .12754 .26094 .12322 .2567 Mtetra
.629 .73 .92 r
.12322 .2567 .12754 .26094 .13342 .2592 .12911 .2549 Mtetra
0 .348 .814 r
.12911 .2549 .13342 .2592 .13869 .26245 .13443 .25774 Mtetra
0 .072 .591 r
.13443 .25774 .13869 .26245 .14374 .26774 .13954 .26248 Mtetra
.163 .45 .879 r
.13954 .26248 .14374 .26774 .14917 .27028 .14501 .26468 Mtetra
.709 .696 .836 r
.14501 .26468 .14917 .27028 .15536 .26669 .15119 .26117 Mtetra
.829 .724 .748 r
.15119 .26117 .15536 .26669 .16221 .25755 .158 .25251 Mtetra
.848 .738 .742 r
.158 .25251 .16221 .25755 .16916 .24747 .16491 .24297 Mtetra
.78 .755 .83 r
.16491 .24297 .16916 .24747 .17555 .24215 .17129 .23785 Mtetra
.107 .471 .893 r
.17129 .23785 .17555 .24215 .18109 .24452 .17686 .23989 Mtetra
.69 .207 0 r
.17686 .23989 .18109 .24452 .18603 .25254 .18187 .24716 Mtetra
.57 .114 0 r
.18187 .24716 .18603 .25254 .19108 .25999 .187 .2539 Mtetra
.473 .582 .883 r
.187 .2539 .19108 .25999 .19694 .26038 .19288 .25408 Mtetra
.814 .706 .745 r
.19288 .25408 .19694 .26038 .20379 .25157 .19969 .24572 Mtetra
.868 .722 .697 r
.19969 .24572 .20379 .25157 .21114 .23772 .20698 .23268 Mtetra
.86 .743 .733 r
.20698 .23268 .21114 .23772 .21816 .22676 .21396 .22231 Mtetra
.614 .722 .922 r
.21396 .22231 .21816 .22676 .22425 .22514 .22006 .22065 Mtetra
.698 .214 0 r
.22006 .22065 .22425 .22514 .22939 .23351 .22527 .22825 Mtetra
.835 .398 0 r
.22527 .22825 .22939 .23351 .23422 .24576 .23018 .23945 Mtetra
0 .039 .598 r
.23018 .23945 .23422 .24576 .23963 .25255 .23564 .24557 Mtetra
.733 .668 .787 r
.23564 .24557 .23963 .25255 .24615 .24754 .24216 .24072 Mtetra
.868 .707 .681 r
.24216 .24072 .24615 .24754 .2536 .23221 .24955 .22629 Mtetra
.889 .725 .672 r
.24955 .22629 .2536 .23221 .26116 .21523 .25704 .21034 Mtetra
.838 .754 .77 r
.25704 .21034 .26116 .21523 .26795 .20668 .26381 .20223 Mtetra
0 .195 .698 r
.26381 .20223 .26795 .20668 .27364 .21142 .26954 .20648 Mtetra
.871 .446 .024 r
.26954 .20648 .27364 .21142 .27859 .22579 .27457 .21966 Mtetra
.818 .399 0 r
.27457 .21966 .27859 .22579 .28369 .23936 .27974 .23206 Mtetra
.352 .472 .842 r
.27974 .23206 .28369 .23936 .28974 .24149 .28582 .23383 Mtetra
.84 .691 .698 r
.28582 .23383 .28974 .24149 .29693 .22887 .29297 .22191 Mtetra
.895 .711 .646 r
.29297 .22191 .29693 .22887 .30468 .20824 .30066 .20255 Mtetra
.894 .735 .676 r
.30066 .20255 .30468 .20824 .31207 .19182 .308 .18713 Mtetra
.673 .736 .898 r
.308 .18713 .31207 .19182 .31847 .18914 .31441 .18449 Mtetra
.802 .347 0 r
.31441 .18449 .31847 .18914 .32392 .20098 .31992 .19534 Mtetra
.889 .485 .055 r
.31992 .19534 .32392 .20098 .32908 .2186 .32515 .21153 Mtetra
0 0 .412 r
.32515 .21153 .32908 .2186 .33479 .22893 .3309 .22089 Mtetra
.735 .649 .764 r
.3309 .22089 .33479 .22893 .34153 .22324 .33764 .21537 Mtetra
.885 .701 .648 r
.33764 .21537 .34153 .22324 .34909 .20361 .34515 .19693 Mtetra
.908 .72 .636 r
.34515 .19693 .34909 .20361 .35672 .18156 .35274 .17626 Mtetra
.872 .753 .728 r
.35274 .17626 .35672 .18156 .36372 .16997 .35972 .16535 Mtetra
0 .23 .733 r
.35972 .16535 .36372 .16997 .36985 .1748 .36588 .16972 Mtetra
.871 .453 .017 r
.36588 .16972 .36985 .1748 .37544 .1915 .37152 .18508 Mtetra
.821 .414 0 r
.37152 .18508 .37544 .1915 .38116 .20759 .37728 .19981 Mtetra
.304 .43 .824 r
.37728 .19981 .38116 .20759 .38756 .21061 .3837 .20234 Mtetra
.848 .689 .685 r
.3837 .20234 .38756 .21061 .39473 .19681 .39086 .18926 Mtetra
.907 .711 .627 r
.39086 .18926 .39473 .19681 .40224 .17388 .39834 .16775 Mtetra
.908 .735 .656 r
.39834 .16775 .40224 .17388 .40951 .1553 .40559 .15034 Mtetra
.73 .75 .868 r
.40559 .15034 .40951 .1553 .4162 .15118 .41228 .14643 Mtetra
.71 .248 0 r
.41228 .14643 .4162 .15118 .42237 .16217 .41848 .15653 Mtetra
.841 .425 0 r
.41848 .15653 .42237 .16217 .42843 .17916 .42456 .17213 Mtetra
0 0 .516 r
.42456 .17213 .42843 .17916 .43481 .18905 .43096 .18103 Mtetra
.736 .655 .77 r
.43096 .18103 .43481 .18905 .44168 .18346 .43784 .17551 Mtetra
.89 .707 .648 r
.43784 .17551 .44168 .18346 .4489 .16462 .44505 .15774 Mtetra
.914 .726 .635 r
.44505 .15774 .4489 .16462 .45611 .1435 .45226 .13795 Mtetra
.875 .758 .73 r
.45226 .13795 .45611 .1435 .46306 .13193 .45921 .12712 Mtetra
.106 .44 .878 r
.45921 .12712 .46306 .13193 .46971 .13498 .46587 .1299 Mtetra
.745 .301 0 r
.46587 .1299 .46971 .13498 .47623 .1482 .4724 .14206 Mtetra
.639 .221 0 r
.4724 .14206 .47623 .1482 .48286 .16068 .47903 .15338 Mtetra
.427 .523 .853 r
.47903 .15338 .48286 .16068 .4897 .16215 .48588 .15439 Mtetra
.848 .705 .704 r
.48588 .15439 .4897 .16215 .4967 .15005 .4929 .14282 Mtetra
.906 .725 .646 r
.4929 .14282 .4967 .15005 .50373 .13105 .49994 .12494 Mtetra
.901 .749 .684 r
.49994 .12494 .50373 .13105 .51068 .11586 .50691 .11073 Mtetra
.715 .747 .877 r
.50691 .11073 .51068 .11586 .51756 .11194 .5138 .10706 Mtetra
0 .085 .619 r
.5138 .10706 .51756 .11194 .52445 .11908 .52069 .11361 Mtetra
0 0 .415 r
.52069 .11361 .52445 .11908 .53142 .12995 .52765 .12351 Mtetra
.057 .325 .807 r
.52765 .12351 .53142 .12995 .53843 .1351 .53466 .12794 Mtetra
.756 .692 .791 r
.53466 .12794 .53843 .1351 .54543 .12934 .54167 .12222 Mtetra
.883 .73 .687 r
.54167 .12222 .54543 .12934 .55235 .1151 .54862 .10871 Mtetra
.899 .748 .685 r
.54862 .10871 .55235 .1151 .55923 .10023 .55553 .09474 Mtetra
.829 .768 .794 r
.55553 .09474 .55923 .10023 .56616 .0923 .56248 .08732 Mtetra
.325 .571 .928 r
.56248 .08732 .56616 .0923 .57324 .09373 .56957 .0886 Mtetra
0 .143 .676 r
.56957 .0886 .57324 .09373 .58047 .10074 .57678 .09495 Mtetra
0 .304 .798 r
.57678 .09495 .58047 .10074 .58772 .10616 .58403 .09969 Mtetra
.616 .658 .868 r
.58403 .09969 .58772 .10616 .59487 .1044 .59117 .09769 Mtetra
.837 .735 .752 r
.59117 .09769 .59487 .1044 .60183 .09508 .59816 .08872 Mtetra
.881 .753 .718 r
.59816 .08872 .60183 .09508 .6087 .08291 .60507 .07721 Mtetra
.847 .77 .776 r
.60507 .07721 .6087 .08291 .61565 .07398 .61205 .06882 Mtetra
.633 .723 .913 r
.61205 .06882 .61565 .07398 .6228 .07165 .61922 .06657 Mtetra
.182 .476 .893 r
.61922 .06657 .6228 .07165 .63017 .07463 .62658 .06921 Mtetra
.147 .434 .871 r
.62658 .06921 .63017 .07463 .63761 .07833 .63401 .07239 Mtetra
.52 .635 .904 r
.63401 .07239 .63761 .07833 .64494 .07808 .64133 .07185 Mtetra
.77 .735 .821 r
.64133 .07185 .64494 .07808 .65206 .07236 .64847 .06622 Mtetra
.844 .76 .77 r
.64847 .06622 .65206 .07236 .65904 .06341 .65549 .05768 Mtetra
.833 .772 .794 r
.65549 .05768 .65904 .06341 .66605 .05539 .66253 .05007 Mtetra
.718 .755 .881 r
.66253 .05007 .66605 .05539 .67325 .05132 .66976 .04617 Mtetra
.479 .652 .936 r
.66976 .04617 .67325 .05132 .68069 .05127 .6772 .04596 Mtetra
.373 .585 .925 r
.6772 .04596 .68069 .05127 .68824 .05259 .68474 .04697 Mtetra
.531 .658 .917 r
.68474 .04697 .68824 .05259 .69571 .05205 .69221 .0462 Mtetra
.713 .733 .867 r
.69221 .0462 .69571 .05205 .70301 .04811 .69952 .04227 Mtetra
.791 .762 .827 r
.69952 .04227 .70301 .04811 .71017 .04185 .70671 .03621 Mtetra
.635 .713 .904 r
.05359 .2814 .05797 .28593 .06372 .2841 .05935 .27955 Mtetra
.731 .736 .855 r
.05935 .27955 .06372 .2841 .06977 .28029 .06539 .27588 Mtetra
.763 .747 .838 r
.06539 .27588 .06977 .28029 .07597 .2756 .07157 .27137 Mtetra
.722 .75 .874 r
.07157 .27137 .07597 .2756 .08198 .27218 .07758 .26802 Mtetra
.537 .701 .945 r
.07758 .26802 .08198 .27218 .0876 .27158 .08323 .26725 Mtetra
.207 .529 .922 r
.08323 .26725 .0876 .27158 .09291 .27339 .08858 .26871 Mtetra
.225 .519 .915 r
.08858 .26871 .09291 .27339 .09824 .27525 .09396 .27023 Mtetra
.564 .668 .908 r
.09396 .27023 .09824 .27525 .10396 .2744 .0997 .26929 Mtetra
.752 .722 .824 r
.0997 .26929 .10396 .2744 .11022 .26969 .10594 .26478 Mtetra
.807 .737 .786 r
.10594 .26478 .11022 .26969 .11679 .26265 .11247 .25811 Mtetra
.793 .75 .813 r
.11247 .25811 .11679 .26265 .12322 .2567 .11887 .25244 Mtetra
.633 .731 .919 r
.11887 .25244 .12322 .2567 .12911 .2549 .12478 .25058 Mtetra
.017 .411 .858 r
.12478 .25058 .12911 .2549 .13443 .25774 .13015 .25299 Mtetra
0 .16 .674 r
.13015 .25299 .13443 .25774 .13954 .26248 .13533 .25715 Mtetra
.228 .486 .893 r
.13533 .25715 .13954 .26248 .14501 .26468 .14084 .25898 Mtetra
.704 .692 .836 r
.14084 .25898 .14501 .26468 .15119 .26117 .14702 .25557 Mtetra
.821 .721 .755 r
.14702 .25557 .15119 .26117 .158 .25251 .15378 .24741 Mtetra
.841 .737 .749 r
.15378 .24741 .158 .25251 .16491 .24297 .16064 .23844 Mtetra
.774 .753 .835 r
.16064 .23844 .16491 .24297 .17129 .23785 .167 .23354 Mtetra
.175 .513 .915 r
.167 .23354 .17129 .23785 .17686 .23989 .17261 .23521 Mtetra
.617 .131 0 r
.17261 .23521 .17686 .23989 .18187 .24716 .17771 .24171 Mtetra
0 0 .517 r
.17771 .24171 .18187 .24716 .187 .2539 .18291 .2477 Mtetra
.494 .589 .878 r
.18291 .2477 .187 .2539 .19288 .25408 .18881 .24766 Mtetra
.805 .701 .75 r
.18881 .24766 .19288 .25408 .19969 .24572 .19558 .23977 Mtetra
.861 .72 .705 r
.19558 .23977 .19969 .24572 .20698 .23268 .2028 .22757 Mtetra
.852 .742 .741 r
.2028 .22757 .20698 .23268 .21396 .22231 .20974 .21785 Mtetra
.617 .723 .921 r
.20974 .21785 .21396 .22231 .22006 .22065 .21585 .21613 Mtetra
.632 .143 0 r
.21585 .21613 .22006 .22065 .22527 .22825 .22113 .22294 Mtetra
.794 .348 0 r
.22113 .22294 .22527 .22825 .23018 .23945 .22613 .23304 Mtetra
0 .123 .671 r
.22613 .23304 .23018 .23945 .23564 .24557 .23165 .23844 Mtetra
.726 .662 .787 r
.23165 .23844 .23564 .24557 .24216 .24072 .23816 .23376 Mtetra
.86 .704 .688 r
.23816 .23376 .24216 .24072 .24955 .22629 .24549 .22028 Mtetra
.882 .724 .681 r
.24549 .22028 .24955 .22629 .25704 .21034 .25291 .2054 Mtetra
.83 .753 .778 r
.25291 .2054 .25704 .21034 .26381 .20223 .25966 .19776 Mtetra
0 .265 .756 r
.25966 .19776 .26381 .20223 .26954 .20648 .26542 .2015 Mtetra
.844 .408 0 r
.26542 .2015 .26954 .20648 .27457 .21966 .27054 .21344 Mtetra
.77 .346 0 r
.27054 .21344 .27457 .21966 .27974 .23206 .2758 .22462 Mtetra
.391 .49 .84 r
.2758 .22462 .27974 .23206 .28582 .23383 .2819 .226 Mtetra
.83 .686 .703 r
.2819 .226 .28582 .23383 .29297 .22191 .28902 .2148 Mtetra
.888 .709 .654 r
.28902 .2148 .29297 .22191 .30066 .20255 .29662 .19679 Mtetra
.887 .734 .686 r
.29662 .19679 .30066 .20255 .308 .18713 .30392 .1824 Mtetra
.669 .735 .899 r
.30392 .1824 .308 .18713 .31441 .18449 .31033 .17982 Mtetra
.761 .298 0 r
.31033 .17982 .31441 .18449 .31992 .19534 .3159 .18964 Mtetra
.866 .452 .002 r
.3159 .18964 .31992 .19534 .32515 .21153 .32121 .20432 Mtetra
0 0 .5 r
.32121 .20432 .32515 .21153 .3309 .22089 .32702 .21268 Mtetra
.728 .643 .763 r
.32702 .21268 .3309 .22089 .33764 .21537 .33375 .20733 Mtetra
.877 .697 .655 r
.33375 .20733 .33764 .21537 .34515 .19693 .34121 .19012 Mtetra
.902 .718 .644 r
.34121 .19012 .34515 .19693 .35274 .17626 .34874 .1709 Mtetra
.864 .752 .738 r
.34874 .1709 .35274 .17626 .35972 .16535 .35571 .16071 Mtetra
0 .288 .778 r
.35571 .16071 .35972 .16535 .36588 .16972 .36189 .1646 Mtetra
.846 .419 0 r
.36189 .1646 .36588 .16972 .37152 .18508 .36758 .17856 Mtetra
.776 .365 0 r
.36758 .17856 .37152 .18508 .37728 .19981 .3734 .19185 Mtetra
.353 .454 .825 r
.3734 .19185 .37728 .19981 .3837 .20234 .37984 .19388 Mtetra
.839 .684 .69 r
.37984 .19388 .3837 .20234 .39086 .18926 .38698 .18155 Mtetra
.9 .709 .636 r
.38698 .18155 .39086 .18926 .39834 .16775 .39442 .16152 Mtetra
.901 .735 .666 r
.39442 .16152 .39834 .16775 .40559 .15034 .40165 .14534 Mtetra
.72 .746 .873 r
.40165 .14534 .40559 .15034 .41228 .14643 .40834 .14164 Mtetra
.659 .193 0 r
.40834 .14164 .41228 .14643 .41848 .15653 .41457 .15082 Mtetra
.807 .385 0 r
.41457 .15082 .41848 .15653 .42456 .17213 .42069 .16496 Mtetra
0 .023 .593 r
.42069 .16496 .42456 .17213 .43096 .18103 .42711 .17282 Mtetra
.731 .649 .768 r
.42711 .17282 .43096 .18103 .43784 .17551 .43399 .16739 Mtetra
.882 .704 .656 r
.43399 .16739 .43784 .17551 .44505 .15774 .44119 .15075 Mtetra
.907 .725 .645 r
.44119 .15075 .44505 .15774 .45226 .13795 .4484 .13235 Mtetra
.865 .757 .741 r
.4484 .13235 .45226 .13795 .45921 .12712 .45535 .12229 Mtetra
.146 .467 .891 r
.45535 .12229 .45921 .12712 .46587 .1299 .46202 .12477 Mtetra
.698 .25 0 r
.46202 .12477 .46587 .1299 .4724 .14206 .46856 .13581 Mtetra
0 0 .413 r
.46856 .13581 .4724 .14206 .47903 .15338 .4752 .14593 Mtetra
.463 .538 .849 r
.4752 .14593 .47903 .15338 .48588 .15439 .48205 .14648 Mtetra
.839 .7 .709 r
.48205 .14648 .48588 .15439 .4929 .14282 .48908 .13547 Mtetra
.898 .723 .656 r
.48908 .13547 .4929 .14282 .49994 .12494 .49614 .11878 Mtetra
.892 .748 .696 r
.49614 .11878 .49994 .12494 .50691 .11073 .50312 .10558 Mtetra
.703 .743 .883 r
.50312 .10558 .50691 .11073 .5138 .10706 .51003 .10214 Mtetra
0 .143 .67 r
.51003 .10214 .5138 .10706 .52069 .11361 .51692 .10807 Mtetra
0 0 .489 r
.51692 .10807 .52069 .11361 .52765 .12351 .52387 .11693 Mtetra
.143 .379 .832 r
.52387 .11693 .52765 .12351 .53466 .12794 .53088 .12065 Mtetra
.751 .687 .79 r
.53088 .12065 .53466 .12794 .54167 .12222 .5379 .11499 Mtetra
.874 .726 .695 r
.5379 .11499 .54167 .12222 .54862 .10871 .54487 .10226 Mtetra
.89 .747 .696 r
.54487 .10226 .54862 .10871 .55553 .09474 .55181 .08923 Mtetra
.817 .766 .805 r
.55181 .08923 .55553 .09474 .56248 .08732 .55879 .08232 Mtetra
.345 .582 .931 r
.55879 .08232 .56248 .08732 .56957 .0886 .56588 .08341 Mtetra
0 .205 .726 r
.56588 .08341 .56957 .0886 .57678 .09495 .57308 .08906 Mtetra
.069 .36 .83 r
.57308 .08906 .57678 .09495 .58403 .09969 .58031 .09311 Mtetra
.627 .66 .862 r
.58031 .09311 .58403 .09969 .59117 .09769 .58746 .09089 Mtetra
.829 .731 .757 r
.58746 .09089 .59117 .09769 .59816 .08872 .59448 .0823 Mtetra
.871 .751 .727 r
.59448 .0823 .59816 .08872 .60507 .07721 .60142 .07149 Mtetra
.836 .768 .786 r
.60142 .07149 .60507 .07721 .61205 .06882 .60843 .06363 Mtetra
.628 .722 .914 r
.60843 .06363 .61205 .06882 .61922 .06657 .61562 .06146 Mtetra
.226 .504 .905 r
.61562 .06146 .61922 .06657 .62658 .06921 .62297 .06371 Mtetra
.207 .472 .887 r
.62297 .06371 .62658 .06921 .63401 .07239 .63039 .06637 Mtetra
.541 .643 .9 r
.63039 .06637 .63401 .07239 .64133 .07185 .63771 .06553 Mtetra
.764 .731 .822 r
.63771 .06553 .64133 .07185 .64847 .06622 .64487 .06003 Mtetra
.834 .756 .777 r
.64487 .06003 .64847 .06622 .65549 .05768 .65192 .05191 Mtetra
.822 .769 .803 r
.65192 .05191 .65549 .05768 .66253 .05007 .659 .04473 Mtetra
.71 .752 .885 r
.659 .04473 .66253 .05007 .66976 .04617 .66625 .04099 Mtetra
.492 .659 .935 r
.66625 .04099 .66976 .04617 .6772 .04596 .67369 .04061 Mtetra
.404 .602 .927 r
.67369 .04061 .6772 .04596 .68474 .04697 .68122 .04129 Mtetra
.548 .665 .914 r
.68122 .04129 .68474 .04697 .69221 .0462 .68869 .04029 Mtetra
.711 .73 .866 r
.68869 .04029 .69221 .0462 .69952 .04227 .69602 .03637 Mtetra
.783 .758 .831 r
.69602 .03637 .69952 .04227 .70671 .03621 .70324 .03055 Mtetra
.636 .713 .903 r
.04919 .27684 .05359 .2814 .05935 .27955 .05496 .27497 Mtetra
.725 .735 .859 r
.05496 .27497 .05935 .27955 .06539 .27588 .06099 .27144 Mtetra
.756 .746 .843 r
.06099 .27144 .06539 .27588 .07157 .27137 .06715 .26712 Mtetra
.719 .749 .876 r
.06715 .26712 .07157 .27137 .07758 .26802 .07316 .26383 Mtetra
.554 .707 .942 r
.07316 .26383 .07758 .26802 .08323 .26725 .07884 .2629 Mtetra
.273 .567 .935 r
.07884 .2629 .08323 .26725 .08858 .26871 .08424 .264 Mtetra
.285 .553 .925 r
.08424 .264 .08858 .26871 .09396 .27023 .08966 .26519 Mtetra
.573 .671 .905 r
.08966 .26519 .09396 .27023 .0997 .26929 .09542 .26413 Mtetra
.744 .719 .829 r
.09542 .26413 .0997 .26929 .10594 .26478 .10164 .25983 Mtetra
.799 .735 .793 r
.10164 .25983 .10594 .26478 .11247 .25811 .10813 .25355 Mtetra
.786 .749 .819 r
.10813 .25355 .11247 .25811 .11887 .25244 .11451 .24816 Mtetra
.637 .733 .917 r
.11451 .24816 .11887 .25244 .12478 .25058 .12043 .24623 Mtetra
.108 .471 .893 r
.12043 .24623 .12478 .25058 .13015 .25299 .12585 .2482 Mtetra
0 .251 .75 r
.12585 .2482 .13015 .25299 .13533 .25715 .1311 .25178 Mtetra
.287 .519 .902 r
.1311 .25178 .13533 .25715 .14084 .25898 .13666 .25324 Mtetra
.699 .69 .837 r
.13666 .25324 .14084 .25898 .14702 .25557 .14283 .24992 Mtetra
.813 .719 .762 r
.14283 .24992 .14702 .25557 .15378 .24741 .14955 .24228 Mtetra
.833 .736 .758 r
.14955 .24228 .15378 .24741 .16064 .23844 .15635 .23389 Mtetra
.767 .752 .84 r
.15635 .23389 .16064 .23844 .167 .23354 .1627 .2292 Mtetra
.241 .552 .931 r
.1627 .2292 .167 .23354 .17261 .23521 .16835 .23052 Mtetra
0 0 .476 r
.16835 .23052 .17261 .23521 .17771 .24171 .17353 .23622 Mtetra
0 .07 .612 r
.17353 .23622 .17771 .24171 .18291 .2477 .17881 .24145 Mtetra
.513 .596 .875 r
.17881 .24145 .18291 .2477 .18881 .24766 .18474 .24119 Mtetra
.797 .698 .756 r
.18474 .24119 .18881 .24766 .19558 .23977 .19147 .23377 Mtetra
.854 .719 .714 r
.19147 .23377 .19558 .23977 .2028 .22757 .19862 .22243 Mtetra
.844 .742 .75 r
.19862 .22243 .2028 .22757 .20974 .21785 .2055 .21336 Mtetra
.62 .723 .92 r
.2055 .21336 .20974 .21785 .21585 .21613 .21163 .21159 Mtetra
.546 .057 0 r
.21163 .21159 .21585 .21613 .22113 .22294 .21698 .2176 Mtetra
.737 .282 0 r
.21698 .2176 .22113 .22294 .22613 .23304 .22208 .22657 Mtetra
0 .207 .734 r
.22208 .22657 .22613 .23304 .23165 .23844 .22766 .23125 Mtetra
.72 .658 .788 r
.22766 .23125 .23165 .23844 .23816 .23376 .23416 .22673 Mtetra
.852 .702 .696 r
.23416 .22673 .23816 .23376 .24549 .22028 .24142 .21421 Mtetra
.875 .723 .69 r
.24142 .21421 .24549 .22028 .25291 .2054 .24876 .20044 Mtetra
.821 .752 .787 r
.24876 .20044 .25291 .2054 .25966 .19776 .25548 .19327 Mtetra
0 .336 .809 r
.25548 .19327 .25966 .19776 .26542 .2015 .26129 .19649 Mtetra
.806 .358 0 r
.26129 .19649 .26542 .2015 .27054 .21344 .2665 .20716 Mtetra
.704 .278 0 r
.2665 .20716 .27054 .21344 .2758 .22462 .27184 .21711 Mtetra
.425 .507 .84 r
.27184 .21711 .2758 .22462 .2819 .226 .27798 .2181 Mtetra
.821 .682 .709 r
.27798 .2181 .2819 .226 .28902 .2148 .28505 .20763 Mtetra
.881 .708 .662 r
.28505 .20763 .28902 .2148 .29662 .19679 .29258 .19097 Mtetra
.88 .734 .696 r
.29258 .19097 .29662 .19679 .30392 .1824 .29982 .17766 Mtetra
.666 .733 .9 r
.29982 .17766 .30392 .1824 .31033 .17982 .30623 .17512 Mtetra
.707 .235 0 r
.30623 .17512 .31033 .17982 .3159 .18964 .31187 .1839 Mtetra
.832 .409 0 r
.31187 .1839 .3159 .18964 .32121 .20432 .31726 .19705 Mtetra
0 .012 .584 r
.31726 .19705 .32121 .20432 .32702 .21268 .32313 .20437 Mtetra
.722 .639 .764 r
.32313 .20437 .32702 .21268 .33375 .20733 .32985 .1992 Mtetra
.869 .695 .663 r
.32985 .1992 .33375 .20733 .34121 .19012 .33726 .18325 Mtetra
.895 .718 .654 r
.33726 .18325 .34121 .19012 .34874 .1709 .34473 .16551 Mtetra
.855 .751 .748 r
.34473 .16551 .34874 .1709 .35571 .16071 .35167 .15604 Mtetra
0 .346 .82 r
.35167 .15604 .35571 .16071 .36189 .1646 .35788 .15945 Mtetra
.812 .375 0 r
.35788 .15945 .36189 .1646 .36758 .17856 .36364 .17198 Mtetra
.716 .304 0 r
.36364 .17198 .36758 .17856 .3734 .19185 .36951 .18382 Mtetra
.396 .477 .826 r
.36951 .18382 .3734 .19185 .37984 .19388 .37597 .18533 Mtetra
.83 .679 .696 r
.37597 .18533 .37984 .19388 .38698 .18155 .38309 .17377 Mtetra
.892 .707 .645 r
.38309 .17377 .38698 .18155 .39442 .16152 .39049 .15526 Mtetra
.893 .735 .678 r
.39049 .15526 .39442 .16152 .40165 .14534 .39769 .14033 Mtetra
.71 .744 .878 r
.39769 .14033 .40165 .14534 .40834 .14164 .40439 .13683 Mtetra
.594 .127 0 r
.40439 .13683 .40834 .14164 .41457 .15082 .41064 .14506 Mtetra
.762 .333 0 r
.41064 .14506 .41457 .15082 .42069 .16496 .4168 .15771 Mtetra
0 .109 .663 r
.4168 .15771 .42069 .16496 .42711 .17282 .42325 .16453 Mtetra
.727 .646 .768 r
.42325 .16453 .42711 .17282 .43399 .16739 .43013 .1592 Mtetra
.874 .701 .665 r
.43013 .1592 .43399 .16739 .44119 .15075 .43733 .14372 Mtetra
.899 .724 .656 r
.43733 .14372 .44119 .15075 .4484 .13235 .44452 .12673 Mtetra
.855 .756 .753 r
.44452 .12673 .4484 .13235 .45535 .12229 .45147 .11744 Mtetra
.189 .495 .904 r
.45147 .11744 .45535 .12229 .46202 .12477 .45815 .11961 Mtetra
.637 .187 0 r
.45815 .11961 .46202 .12477 .46856 .13581 .46471 .12948 Mtetra
0 0 .5 r
.46471 .12948 .46856 .13581 .4752 .14593 .47136 .13839 Mtetra
.494 .553 .846 r
.47136 .13839 .4752 .14593 .48205 .14648 .47822 .13849 Mtetra
.831 .696 .715 r
.47822 .13849 .48205 .14648 .48908 .13547 .48525 .12808 Mtetra
.89 .721 .667 r
.48525 .12808 .48908 .13547 .49614 .11878 .49232 .1126 Mtetra
.883 .748 .708 r
.49232 .1126 .49614 .11878 .50312 .10558 .49932 .10042 Mtetra
.692 .74 .888 r
.49932 .10042 .50312 .10558 .51003 .10214 .50623 .0972 Mtetra
0 .207 .723 r
.50623 .0972 .51003 .10214 .51692 .10807 .51313 .10246 Mtetra
0 .013 .567 r
.51313 .10246 .51692 .10807 .52387 .11693 .52007 .11028 Mtetra
.221 .427 .851 r
.52007 .11028 .52387 .11693 .53088 .12065 .52708 .11328 Mtetra
.748 .684 .79 r
.52708 .11328 .53088 .12065 .5379 .11499 .53411 .10772 Mtetra
.865 .724 .705 r
.53411 .10772 .5379 .11499 .54487 .10226 .54111 .09578 Mtetra
.881 .746 .709 r
.54111 .09578 .54487 .10226 .55181 .08923 .54808 .08372 Mtetra
.804 .764 .815 r
.54808 .08372 .55181 .08923 .55879 .08232 .55508 .07731 Mtetra
.368 .596 .934 r
.55508 .07731 .55879 .08232 .56588 .08341 .56217 .07818 Mtetra
0 .27 .774 r
.56217 .07818 .56588 .08341 .57308 .08906 .56936 .08311 Mtetra
.15 .413 .856 r
.56936 .08311 .57308 .08906 .58031 .09311 .57658 .08645 Mtetra
.636 .662 .858 r
.57658 .08645 .58031 .09311 .58746 .09089 .58374 .08403 Mtetra
.82 .728 .763 r
.58374 .08403 .58746 .09089 .59448 .0823 .59078 .07586 Mtetra
.861 .75 .738 r
.59078 .07586 .59448 .0823 .60142 .07149 .59776 .06576 Mtetra
.824 .766 .797 r
.59776 .06576 .60142 .07149 .60843 .06363 .6048 .05844 Mtetra
.624 .72 .916 r
.6048 .05844 .60843 .06363 .61562 .06146 .612 .05631 Mtetra
.271 .532 .915 r
.612 .05631 .61562 .06146 .62297 .06371 .61935 .05816 Mtetra
.266 .508 .9 r
.61935 .05816 .62297 .06371 .63039 .06637 .62675 .06028 Mtetra
.56 .651 .896 r
.62675 .06028 .63039 .06637 .63771 .06553 .63407 .05916 Mtetra
.759 .728 .824 r
.63407 .05916 .63771 .06553 .64487 .06003 .64125 .0538 Mtetra
.824 .754 .785 r
.64125 .0538 .64487 .06003 .65192 .05191 .64833 .04613 Mtetra
.811 .767 .812 r
.64833 .04613 .65192 .05191 .659 .04473 .65545 .03938 Mtetra
.703 .75 .888 r
.65545 .03938 .659 .04473 .66625 .04099 .66272 .03578 Mtetra
.507 .667 .935 r
.66272 .03578 .66625 .04099 .67369 .04061 .67017 .03522 Mtetra
.434 .618 .928 r
.67017 .03522 .67369 .04061 .68122 .04129 .67769 .03556 Mtetra
.563 .671 .911 r
.67769 .03556 .68122 .04129 .68869 .04029 .68516 .03433 Mtetra
.708 .729 .866 r
.68516 .03433 .68869 .04029 .69602 .03637 .6925 .03045 Mtetra
.774 .755 .836 r
.6925 .03045 .69602 .03637 .70324 .03055 .69975 .02486 Mtetra
.637 .713 .902 r
.04478 .27226 .04919 .27684 .05496 .27497 .05056 .27037 Mtetra
.719 .733 .862 r
.05056 .27037 .05496 .27497 .06099 .27144 .05657 .26697 Mtetra
.749 .745 .848 r
.05657 .26697 .06099 .27144 .06715 .26712 .06271 .26285 Mtetra
.715 .749 .878 r
.06271 .26285 .06715 .26712 .07316 .26383 .06872 .25963 Mtetra
.57 .713 .939 r
.06872 .25963 .07316 .26383 .07884 .2629 .07442 .25853 Mtetra
.334 .6 .944 r
.07442 .25853 .07884 .2629 .08424 .264 .07988 .25927 Mtetra
.341 .582 .932 r
.07988 .25927 .08424 .264 .08966 .26519 .08535 .26011 Mtetra
.581 .673 .903 r
.08535 .26011 .08966 .26519 .09542 .26413 .09113 .25894 Mtetra
.737 .717 .833 r
.09113 .25894 .09542 .26413 .10164 .25983 .09732 .25486 Mtetra
.79 .734 .801 r
.09732 .25486 .10164 .25983 .10813 .25355 .10378 .24897 Mtetra
.778 .748 .826 r
.10378 .24897 .10813 .25355 .11451 .24816 .11012 .24386 Mtetra
.641 .734 .916 r
.11012 .24386 .11451 .24816 .12043 .24623 .11606 .24187 Mtetra
.196 .525 .92 r
.11606 .24187 .12043 .24623 .12585 .2482 .12154 .2434 Mtetra
0 .339 .816 r
.12154 .2434 .12585 .2482 .1311 .25178 .12687 .24638 Mtetra
.342 .548 .908 r
.12687 .24638 .1311 .25178 .13666 .25324 .13247 .24746 Mtetra
.695 .687 .839 r
.13247 .24746 .13666 .25324 .14283 .24992 .13864 .24423 Mtetra
.804 .718 .77 r
.13864 .24423 .14283 .24992 .14955 .24228 .1453 .23711 Mtetra
.824 .736 .767 r
.1453 .23711 .14955 .24228 .15635 .23389 .15204 .22931 Mtetra
.759 .751 .846 r
.15204 .22931 .15635 .23389 .1627 .2292 .15838 .22485 Mtetra
.303 .587 .942 r
.15838 .22485 .1627 .2292 .16835 .23052 .16407 .22579 Mtetra
0 .069 .587 r
.16407 .22579 .16835 .23052 .17353 .23622 .16934 .23069 Mtetra
0 .173 .702 r
.16934 .23069 .17353 .23622 .17881 .24145 .1747 .23516 Mtetra
.53 .604 .871 r
.1747 .23516 .17881 .24145 .18474 .24119 .18065 .23466 Mtetra
.788 .695 .763 r
.18065 .23466 .18474 .24119 .19147 .23377 .18734 .22772 Mtetra
.845 .718 .723 r
.18734 .22772 .19147 .23377 .19862 .22243 .19441 .21726 Mtetra
.835 .741 .76 r
.19441 .21726 .19862 .22243 .2055 .21336 .20125 .20885 Mtetra
.623 .724 .919 r
.20125 .20885 .2055 .21336 .21163 .21159 .20738 .20703 Mtetra
0 .045 .559 r
.20738 .20703 .21163 .21159 .21698 .2176 .21281 .21222 Mtetra
.655 .196 0 r
.21281 .21222 .21698 .2176 .22208 .22657 .21802 .22006 Mtetra
.003 .286 .785 r
.21802 .22006 .22208 .22657 .22766 .23125 .22366 .224 Mtetra
.714 .655 .79 r
.22366 .224 .22766 .23125 .23416 .22673 .23015 .21965 Mtetra
.843 .7 .705 r
.23015 .21965 .23416 .22673 .24142 .21421 .23733 .20811 Mtetra
.867 .723 .701 r
.23733 .20811 .24142 .21421 .24876 .20044 .24459 .19544 Mtetra
.811 .751 .796 r
.24459 .19544 .24876 .20044 .25548 .19327 .25129 .18876 Mtetra
.019 .404 .855 r
.25129 .18876 .25548 .19327 .26129 .19649 .25714 .19146 Mtetra
.751 .292 0 r
.25714 .19146 .26129 .19649 .2665 .20716 .26245 .20085 Mtetra
.612 .19 0 r
.26245 .20085 .2665 .20716 .27184 .21711 .26789 .20954 Mtetra
.457 .524 .838 r
.26789 .20954 .27184 .21711 .27798 .2181 .27405 .21013 Mtetra
.812 .678 .716 r
.27405 .21013 .27798 .2181 .28505 .20763 .28108 .2004 Mtetra
.873 .706 .672 r
.28108 .2004 .28505 .20763 .29258 .19097 .28852 .18512 Mtetra
.872 .734 .707 r
.28852 .18512 .29258 .19097 .29982 .17766 .2957 .17289 Mtetra
.662 .732 .902 r
.2957 .17289 .29982 .17766 .30623 .17512 .30212 .17041 Mtetra
.633 .155 0 r
.30212 .17041 .30623 .17512 .31187 .1839 .30782 .17811 Mtetra
.784 .352 0 r
.30782 .17811 .31187 .1839 .31726 .19705 .31331 .18972 Mtetra
0 .108 .662 r
.31331 .18972 .31726 .19705 .32313 .20437 .31923 .19601 Mtetra
.717 .635 .766 r
.31923 .19601 .32313 .20437 .32985 .1992 .32595 .19102 Mtetra
.86 .692 .672 r
.32595 .19102 .32985 .1992 .33726 .18325 .3333 .17633 Mtetra
.887 .717 .665 r
.3333 .17633 .33726 .18325 .34473 .16551 .3407 .16009 Mtetra
.844 .751 .76 r
.3407 .16009 .34473 .16551 .35167 .15604 .34762 .15136 Mtetra
.035 .404 .857 r
.34762 .15136 .35167 .15604 .35788 .15945 .35386 .15426 Mtetra
.764 .316 0 r
.35386 .15426 .35788 .15945 .36364 .17198 .35968 .16535 Mtetra
.633 .224 0 r
.35968 .16535 .36364 .17198 .36951 .18382 .36561 .17572 Mtetra
.435 .498 .826 r
.36561 .17572 .36951 .18382 .37597 .18533 .3721 .17671 Mtetra
.82 .675 .703 r
.3721 .17671 .37597 .18533 .38309 .17377 .37919 .16594 Mtetra
.884 .706 .656 r
.37919 .16594 .38309 .17377 .39049 .15526 .38655 .14897 Mtetra
.885 .734 .69 r
.38655 .14897 .39049 .15526 .39769 .14033 .39372 .1353 Mtetra
.7 .741 .882 r
.39372 .1353 .39769 .14033 .40439 .13683 .40041 .13199 Mtetra
0 0 .484 r
.40041 .13199 .40439 .13683 .41064 .14506 .4067 .13925 Mtetra
.698 .265 0 r
.4067 .13925 .41064 .14506 .4168 .15771 .41291 .15039 Mtetra
0 .197 .724 r
.41291 .15039 .4168 .15771 .42325 .16453 .41938 .15616 Mtetra
.722 .643 .769 r
.41938 .15616 .42325 .16453 .43013 .1592 .42627 .15096 Mtetra
.864 .698 .674 r
.42627 .15096 .43013 .1592 .43733 .14372 .43345 .13665 Mtetra
.891 .724 .668 r
.43345 .13665 .43733 .14372 .44452 .12673 .44062 .1211 Mtetra
.843 .755 .767 r
.44062 .1211 .44452 .12673 .45147 .11744 .44757 .11257 Mtetra
.235 .524 .916 r
.44757 .11257 .45147 .11744 .45815 .11961 .45426 .1144 Mtetra
0 0 .432 r
.45426 .1144 .45815 .11961 .46471 .12948 .46084 .12309 Mtetra
0 .026 .59 r
.46084 .12309 .46471 .12948 .47136 .13839 .4675 .13078 Mtetra
.521 .566 .842 r
.4675 .13078 .47136 .13839 .47822 .13849 .47437 .13044 Mtetra
.821 .692 .722 r
.47437 .13044 .47822 .13849 .48525 .12808 .48141 .12066 Mtetra
.881 .72 .678 r
.48141 .12066 .48525 .12808 .49232 .1126 .48849 .1064 Mtetra
.872 .748 .722 r
.48849 .1064 .49232 .1126 .49932 .10042 .4955 .09524 Mtetra
.681 .737 .893 r
.4955 .09524 .49932 .10042 .50623 .0972 .50242 .09222 Mtetra
0 .274 .774 r
.50242 .09222 .50623 .0972 .51313 .10246 .50932 .0968 Mtetra
0 .101 .647 r
.50932 .0968 .51313 .10246 .52007 .11028 .51626 .10354 Mtetra
.293 .469 .863 r
.51626 .10354 .52007 .11028 .52708 .11328 .52327 .10584 Mtetra
.743 .681 .791 r
.52327 .10584 .52708 .11328 .53411 .10772 .53031 .1004 Mtetra
.855 .721 .715 r
.53031 .1004 .53411 .10772 .54111 .09578 .53733 .0893 Mtetra
.87 .745 .722 r
.53733 .0893 .54111 .09578 .54808 .08372 .54433 .0782 Mtetra
.791 .761 .826 r
.54433 .0782 .54808 .08372 .55508 .07731 .55135 .07227 Mtetra
.392 .61 .936 r
.55135 .07227 .55508 .07731 .56217 .07818 .55845 .07289 Mtetra
0 .336 .818 r
.55845 .07289 .56217 .07818 .56936 .08311 .56563 .07708 Mtetra
.228 .461 .875 r
.56563 .07708 .56936 .08311 .57658 .08645 .57284 .07972 Mtetra
.644 .664 .855 r
.57284 .07972 .57658 .08645 .58374 .08403 .58 .07713 Mtetra
.811 .724 .77 r
.58 .07713 .58374 .08403 .59078 .07586 .58706 .0694 Mtetra
.85 .748 .75 r
.58706 .0694 .59078 .07586 .59776 .06576 .59408 .06002 Mtetra
.811 .764 .808 r
.59408 .06002 .59776 .06576 .6048 .05844 .60116 .05323 Mtetra
.621 .72 .917 r
.60116 .05323 .6048 .05844 .612 .05631 .60836 .05113 Mtetra
.317 .56 .923 r
.60836 .05113 .612 .05631 .61935 .05816 .61571 .05255 Mtetra
.322 .541 .909 r
.61571 .05255 .61935 .05816 .62675 .06028 .62309 .05413 Mtetra
.576 .658 .892 r
.62309 .05413 .62675 .06028 .63407 .05916 .63041 .05274 Mtetra
.752 .725 .827 r
.63041 .05274 .63407 .05916 .64125 .0538 .63761 .04755 Mtetra
.813 .751 .794 r
.63761 .04755 .64125 .0538 .64833 .04613 .64473 .04034 Mtetra
.799 .764 .821 r
.64473 .04034 .64833 .04613 .65545 .03938 .65189 .03401 Mtetra
.696 .748 .892 r
.65189 .03401 .65545 .03938 .66272 .03578 .65918 .03055 Mtetra
.522 .675 .934 r
.65918 .03055 .66272 .03578 .67017 .03522 .66662 .02978 Mtetra
.463 .634 .928 r
.66662 .02978 .67017 .03522 .67769 .03556 .67413 .02978 Mtetra
.577 .677 .908 r
.67413 .02978 .67769 .03556 .68516 .03433 .6816 .02832 Mtetra
.705 .727 .867 r
.6816 .02832 .68516 .03433 .6925 .03045 .68896 .02449 Mtetra
.765 .752 .841 r
.68896 .02449 .6925 .03045 .69975 .02486 .69624 .01916 Mtetra
.638 .713 .901 r
.04036 .26764 .04478 .27226 .05056 .27037 .04614 .26572 Mtetra
.712 .731 .865 r
.04614 .26572 .05056 .27037 .05657 .26697 .05214 .26247 Mtetra
.741 .743 .853 r
.05214 .26247 .05657 .26697 .06271 .26285 .05825 .25855 Mtetra
.711 .747 .881 r
.05825 .25855 .06271 .26285 .06872 .25963 .06426 .25541 Mtetra
.585 .718 .935 r
.06426 .25541 .06872 .25963 .07442 .25853 .06999 .25414 Mtetra
.394 .629 .948 r
.06999 .25414 .07442 .25853 .07988 .25927 .07551 .2545 Mtetra
.396 .609 .934 r
.07551 .2545 .07988 .25927 .08535 .26011 .08103 .25497 Mtetra
.59 .674 .899 r
.08103 .25497 .08535 .26011 .09113 .25894 .08683 .25368 Mtetra
.728 .713 .836 r
.08683 .25368 .09113 .25894 .09732 .25486 .093 .24981 Mtetra
.779 .731 .808 r
.093 .24981 .09732 .25486 .10378 .24897 .09941 .24434 Mtetra
.768 .746 .833 r
.09941 .24434 .10378 .24897 .11012 .24386 .10572 .23954 Mtetra
.645 .735 .914 r
.10572 .23954 .11012 .24386 .11606 .24187 .11167 .23749 Mtetra
.282 .573 .938 r
.11167 .23749 .11606 .24187 .12154 .2434 .11722 .23854 Mtetra
.081 .426 .87 r
.11722 .23854 .12154 .2434 .12687 .24638 .12262 .24089 Mtetra
.398 .573 .908 r
.12262 .24089 .12687 .24638 .13247 .24746 .12827 .24156 Mtetra
.689 .682 .838 r
.12827 .24156 .13247 .24746 .13864 .24423 .13444 .23844 Mtetra
.792 .713 .777 r
.13444 .23844 .13864 .24423 .1453 .23711 .14104 .23187 Mtetra
.813 .733 .777 r
.14104 .23187 .1453 .23711 .15204 .22931 .14772 .2247 Mtetra
.75 .749 .851 r
.14772 .2247 .15204 .22931 .15838 .22485 .15403 .22048 Mtetra
.364 .619 .949 r
.15403 .22048 .15838 .22485 .16407 .22579 .15978 .22103 Mtetra
0 .195 .703 r
.15978 .22103 .16407 .22579 .16934 .23069 .16514 .22506 Mtetra
0 .283 .784 r
.16514 .22506 .16934 .23069 .1747 .23516 .17059 .22871 Mtetra
.548 .607 .864 r
.17059 .22871 .1747 .23516 .18065 .23466 .17657 .22798 Mtetra
.775 .688 .768 r
.17657 .22798 .18065 .23466 .18734 .22772 .18322 .22156 Mtetra
.833 .714 .733 r
.18322 .22156 .18734 .22772 .19441 .21726 .1902 .21203 Mtetra
.824 .739 .771 r
.1902 .21203 .19441 .21726 .20125 .20885 .19697 .20432 Mtetra
.627 .725 .918 r
.19697 .20432 .20125 .20885 .20738 .20703 .20312 .20244 Mtetra
0 .167 .674 r
.20312 .20244 .20738 .20703 .21281 .21222 .20863 .20675 Mtetra
0 0 .463 r
.20863 .20675 .21281 .21222 .21802 .22006 .21395 .21338 Mtetra
.13 .364 .823 r
.21395 .21338 .21802 .22006 .22366 .224 .21967 .21655 Mtetra
.705 .647 .789 r
.21967 .21655 .22366 .224 .23015 .21965 .22615 .21239 Mtetra
.83 .693 .713 r
.22615 .21239 .23015 .21965 .23733 .20811 .23324 .20188 Mtetra
.855 .72 .712 r
.23324 .20188 .23733 .20811 .24459 .19544 .24041 .1904 Mtetra
.799 .749 .806 r
.24041 .1904 .24459 .19544 .25129 .18876 .24707 .18423 Mtetra
.121 .471 .894 r
.24707 .18423 .25129 .18876 .25714 .19146 .25298 .18636 Mtetra
.662 .196 0 r
.25298 .18636 .25714 .19146 .26245 .20085 .2584 .19438 Mtetra
0 0 .498 r
.2584 .19438 .26245 .20085 .26789 .20954 .26394 .20174 Mtetra
.489 .535 .83 r
.26394 .20174 .26789 .20954 .27405 .21013 .27013 .20192 Mtetra
.797 .669 .722 r
.27013 .20192 .27405 .21013 .28108 .2004 .2771 .19298 Mtetra
.861 .701 .683 r
.2771 .19298 .28108 .2004 .28852 .18512 .28445 .17917 Mtetra
.86 .732 .72 r
.28445 .17917 .28852 .18512 .2957 .17289 .29156 .16809 Mtetra
.658 .73 .903 r
.29156 .16809 .2957 .17289 .30212 .17041 .29799 .16566 Mtetra
0 0 .472 r
.29799 .16566 .30212 .17041 .30782 .17811 .30377 .17222 Mtetra
.702 .265 0 r
.30377 .17222 .30782 .17811 .31331 .18972 .30936 .18217 Mtetra
0 .213 .734 r
.30936 .18217 .31331 .18972 .31923 .19601 .31535 .18737 Mtetra
.707 .625 .763 r
.31535 .18737 .31923 .19601 .32595 .19102 .32206 .18258 Mtetra
.846 .684 .681 r
.32206 .18258 .32595 .19102 .3333 .17633 .32933 .16926 Mtetra
.876 .714 .677 r
.32933 .16926 .3333 .17633 .3407 .16009 .33666 .15461 Mtetra
.831 .748 .773 r
.33666 .15461 .3407 .16009 .34762 .15136 .34355 .14666 Mtetra
.124 .463 .89 r
.34355 .14666 .34762 .15136 .35386 .15426 .34982 .14901 Mtetra
.687 .232 0 r
.34982 .14901 .35386 .15426 .35968 .16535 .35572 .15855 Mtetra
0 0 .461 r
.35572 .15855 .35968 .16535 .36561 .17572 .36172 .16735 Mtetra
.474 .513 .818 r
.36172 .16735 .36561 .17572 .3721 .17671 .36823 .16782 Mtetra
.805 .665 .709 r
.36823 .16782 .3721 .17671 .37919 .16594 .37529 .15791 Mtetra
.871 .7 .667 r
.37529 .15791 .37919 .16594 .38655 .14897 .3826 .14258 Mtetra
.872 .732 .704 r
.3826 .14258 .38655 .14897 .39372 .1353 .38973 .13024 Mtetra
.691 .737 .887 r
.38973 .13024 .39372 .1353 .40041 .13199 .39643 .12712 Mtetra
0 .055 .585 r
.39643 .12712 .40041 .13199 .4067 .13925 .40275 .13332 Mtetra
.598 .169 0 r
.40275 .13332 .4067 .13925 .41291 .15039 .40901 .14284 Mtetra
.061 .286 .775 r
.40901 .14284 .41291 .15039 .41938 .15616 .41551 .14753 Mtetra
.714 .634 .766 r
.41551 .14753 .41938 .15616 .42627 .15096 .4224 .14249 Mtetra
.85 .691 .684 r
.4224 .14249 .42627 .15096 .43345 .13665 .42956 .12946 Mtetra
.878 .72 .682 r
.42956 .12946 .43345 .13665 .44062 .1211 .43671 .11543 Mtetra
.828 .753 .78 r
.43671 .11543 .44062 .1211 .44757 .11257 .44365 .10769 Mtetra
.286 .555 .927 r
.44365 .10769 .44757 .11257 .45426 .1144 .45036 .10911 Mtetra
0 0 .538 r
.45036 .10911 .45426 .1144 .46084 .12309 .45696 .11653 Mtetra
0 .138 .684 r
.45696 .11653 .46084 .12309 .4675 .13078 .46365 .12293 Mtetra
.546 .573 .833 r
.46365 .12293 .4675 .13078 .47437 .13044 .47052 .12217 Mtetra
.807 .683 .727 r
.47052 .12217 .47437 .13044 .48141 .12066 .47756 .11309 Mtetra
.867 .715 .691 r
.47756 .11309 .48141 .12066 .48849 .1064 .48464 .10015 Mtetra
.858 .745 .737 r
.48464 .10015 .48849 .1064 .4955 .09524 .49166 .09005 Mtetra
.671 .734 .897 r
.49166 .09005 .4955 .09524 .50242 .09222 .49859 .0872 Mtetra
0 .349 .825 r
.49859 .0872 .50242 .09222 .50932 .0968 .5055 .09101 Mtetra
0 .203 .729 r
.5055 .09101 .50932 .0968 .51626 .10354 .51244 .09663 Mtetra
.364 .505 .867 r
.51244 .09663 .51626 .10354 .52327 .10584 .51946 .09821 Mtetra
.735 .673 .79 r
.51946 .09821 .52327 .10584 .53031 .1004 .5265 .09294 Mtetra
.841 .715 .725 r
.5265 .09294 .53031 .1004 .53733 .0893 .53354 .08275 Mtetra
.856 .742 .736 r
.53354 .08275 .53733 .0893 .54433 .0782 .54056 .07266 Mtetra
.776 .757 .836 r
.54056 .07266 .54433 .0782 .55135 .07227 .5476 .06721 Mtetra
.422 .626 .938 r
.5476 .06721 .55135 .07227 .55845 .07289 .5547 .06753 Mtetra
.091 .405 .858 r
.5547 .06753 .55845 .07289 .56563 .07708 .56188 .07092 Mtetra
.306 .505 .887 r
.56188 .07092 .56563 .07708 .57284 .07972 .56908 .07284 Mtetra
.649 .662 .849 r
.56908 .07284 .57284 .07972 .58 .07713 .57624 .0701 Mtetra
.797 .717 .776 r
.57624 .0701 .58 .07713 .58706 .0694 .58333 .06286 Mtetra
.835 .743 .762 r
.58333 .06286 .58706 .0694 .59408 .06002 .59039 .05426 Mtetra
.797 .76 .819 r
.59039 .05426 .59408 .06002 .60116 .05323 .59749 .048 Mtetra
.621 .72 .917 r
.59749 .048 .60116 .05323 .60836 .05113 .60471 .0459 Mtetra
.366 .588 .929 r
.60471 .0459 .60836 .05113 .61571 .05255 .61205 .04685 Mtetra
.378 .571 .914 r
.61205 .04685 .61571 .05255 .62309 .05413 .61942 .04786 Mtetra
.592 .661 .886 r
.61942 .04786 .62309 .05413 .63041 .05274 .62674 .04621 Mtetra
.744 .719 .828 r
.62674 .04621 .63041 .05274 .63761 .04755 .63396 .04123 Mtetra
.8 .745 .803 r
.63396 .04123 .63761 .04755 .64473 .04034 .64112 .03451 Mtetra
.785 .76 .83 r
.64112 .03451 .64473 .04034 .65189 .03401 .64831 .02863 Mtetra
.689 .746 .894 r
.64831 .02863 .65189 .03401 .65918 .03055 .65562 .02528 Mtetra
.539 .683 .932 r
.65562 .02528 .65918 .03055 .66662 .02978 .66306 .02429 Mtetra
.493 .648 .927 r
.66306 .02429 .66662 .02978 .67413 .02978 .67057 .02392 Mtetra
.59 .682 .904 r
.67057 .02392 .67413 .02978 .6816 .02832 .67803 .02224 Mtetra
.701 .723 .867 r
.67803 .02224 .6816 .02832 .68896 .02449 .68541 .01848 Mtetra
.755 .747 .846 r
.68541 .01848 .68896 .02449 .69624 .01916 .69272 .01342 Mtetra
.64 .713 .9 r
.03591 .263 .04036 .26764 .04614 .26572 .04171 .26104 Mtetra
.705 .729 .869 r
.04171 .26104 .04614 .26572 .05214 .26247 .04769 .25793 Mtetra
.732 .741 .858 r
.04769 .25793 .05214 .26247 .05825 .25855 .05378 .25423 Mtetra
.706 .746 .883 r
.05378 .25423 .05825 .25855 .06426 .25541 .05978 .25118 Mtetra
.6 .723 .931 r
.05978 .25118 .06426 .25541 .06999 .25414 .06555 .24973 Mtetra
.447 .654 .948 r
.06555 .24973 .06999 .25414 .07551 .2545 .07112 .24971 Mtetra
.446 .632 .934 r
.07112 .24971 .07551 .2545 .08103 .25497 .0767 .24979 Mtetra
.599 .677 .896 r
.0767 .24979 .08103 .25497 .08683 .25368 .08251 .24838 Mtetra
.719 .71 .841 r
.08251 .24838 .08683 .25368 .093 .24981 .08866 .24473 Mtetra
.768 .729 .817 r
.08866 .24473 .093 .24981 .09941 .24434 .09502 .23968 Mtetra
.758 .744 .84 r
.09502 .23968 .09941 .24434 .10572 .23954 .1013 .2352 Mtetra
.648 .736 .913 r
.1013 .2352 .10572 .23954 .11167 .23749 .10726 .23309 Mtetra
.36 .615 .948 r
.10726 .23309 .11167 .23749 .11722 .23854 .11288 .23366 Mtetra
.203 .5 .906 r
.11288 .23366 .11722 .23854 .12262 .24089 .11836 .23536 Mtetra
.446 .597 .907 r
.11836 .23536 .12262 .24089 .12827 .24156 .12407 .23562 Mtetra
.684 .679 .84 r
.12407 .23562 .12827 .24156 .13444 .23844 .13022 .2326 Mtetra
.779 .71 .787 r
.13022 .2326 .13444 .23844 .14104 .23187 .13677 .2266 Mtetra
.8 .732 .788 r
.13677 .2266 .14104 .23187 .14772 .2247 .14338 .22007 Mtetra
.741 .747 .857 r
.14338 .22007 .14772 .2247 .15403 .22048 .14967 .21608 Mtetra
.421 .647 .952 r
.14967 .21608 .15403 .22048 .15978 .22103 .15547 .21623 Mtetra
0 .322 .803 r
.15547 .21623 .15978 .22103 .16514 .22506 .16093 .2194 Mtetra
.083 .383 .844 r
.16093 .2194 .16514 .22506 .17059 .22871 .16647 .22222 Mtetra
.565 .613 .86 r
.16647 .22222 .17059 .22871 .17657 .22798 .17248 .22124 Mtetra
.763 .684 .775 r
.17248 .22124 .17657 .22798 .18322 .22156 .17908 .21534 Mtetra
.82 .712 .745 r
.17908 .21534 .18322 .22156 .1902 .21203 .18597 .20676 Mtetra
.811 .738 .783 r
.18597 .20676 .1902 .21203 .19697 .20432 .19268 .19976 Mtetra
.631 .727 .917 r
.19268 .19976 .19697 .20432 .20312 .20244 .19884 .19783 Mtetra
0 .295 .78 r
.19884 .19783 .20312 .20244 .20863 .20675 .20445 .20124 Mtetra
0 .067 .608 r
.20445 .20124 .20863 .20675 .21395 .21338 .20988 .20664 Mtetra
.239 .43 .848 r
.20988 .20664 .21395 .21338 .21967 .21655 .21568 .20902 Mtetra
.698 .642 .79 r
.21568 .20902 .21967 .21655 .22615 .21239 .22214 .20505 Mtetra
.816 .689 .724 r
.22214 .20505 .22615 .21239 .23324 .20188 .22915 .1956 Mtetra
.843 .718 .726 r
.22915 .1956 .23324 .20188 .24041 .1904 .23622 .18533 Mtetra
.786 .747 .817 r
.23622 .18533 .24041 .1904 .24707 .18423 .24284 .17968 Mtetra
.221 .533 .923 r
.24284 .17968 .24707 .18423 .25298 .18636 .2488 .18123 Mtetra
0 0 .465 r
.2488 .18123 .25298 .18636 .2584 .19438 .25434 .18785 Mtetra
0 .073 .63 r
.25434 .18785 .2584 .19438 .26394 .20174 .25998 .19386 Mtetra
.517 .547 .826 r
.25998 .19386 .26394 .20174 .27013 .20192 .26621 .19362 Mtetra
.784 .662 .729 r
.26621 .19362 .27013 .20192 .2771 .19298 .27313 .1855 Mtetra
.848 .698 .696 r
.27313 .1855 .2771 .19298 .28445 .17917 .28037 .17318 Mtetra
.847 .73 .735 r
.28037 .17318 .28445 .17917 .29156 .16809 .28741 .16327 Mtetra
.655 .729 .904 r
.28741 .16327 .29156 .16809 .29799 .16566 .29384 .16088 Mtetra
0 .081 .604 r
.29384 .16088 .29799 .16566 .30377 .17222 .2997 .16627 Mtetra
0 0 .405 r
.2997 .16627 .30377 .17222 .30936 .18217 .3054 .17454 Mtetra
.1 .307 .784 r
.3054 .17454 .30936 .18217 .31535 .18737 .31146 .17863 Mtetra
.7 .62 .764 r
.31146 .17863 .31535 .18737 .32206 .18258 .31816 .17407 Mtetra
.832 .679 .692 r
.31816 .17407 .32206 .18258 .32933 .16926 .32536 .16214 Mtetra
.863 .711 .692 r
.32536 .16214 .32933 .16926 .33666 .15461 .33261 .14911 Mtetra
.816 .746 .787 r
.33261 .14911 .33666 .15461 .34355 .14666 .33946 .14194 Mtetra
.213 .52 .916 r
.33946 .14194 .34355 .14666 .34982 .14901 .34576 .14371 Mtetra
.572 .118 0 r
.34576 .14371 .34982 .14901 .35572 .15855 .35174 .15165 Mtetra
0 .022 .59 r
.35174 .15165 .35572 .15855 .36172 .16735 .35783 .15888 Mtetra
.506 .529 .814 r
.35783 .15888 .36172 .16735 .36823 .16782 .36436 .15884 Mtetra
.791 .658 .716 r
.36436 .15884 .36823 .16782 .37529 .15791 .37139 .14982 Mtetra
.858 .696 .681 r
.37139 .14982 .37529 .15791 .3826 .14258 .37863 .13616 Mtetra
.859 .731 .72 r
.37863 .13616 .3826 .14258 .38973 .13024 .38572 .12517 Mtetra
.681 .735 .891 r
.38572 .12517 .38973 .13024 .39643 .12712 .39242 .12222 Mtetra
0 .173 .691 r
.39242 .12222 .39643 .12712 .40275 .13332 .39879 .12731 Mtetra
0 0 .515 r
.39879 .12731 .40275 .13332 .40901 .14284 .4051 .1352 Mtetra
.183 .363 .809 r
.4051 .1352 .40901 .14284 .41551 .14753 .41164 .1388 Mtetra
.707 .629 .767 r
.41164 .1388 .41551 .14753 .4224 .14249 .41853 .13395 Mtetra
.836 .685 .696 r
.41853 .13395 .4224 .14249 .42956 .12946 .42565 .12224 Mtetra
.865 .718 .698 r
.42565 .12224 .42956 .12946 .43671 .11543 .43278 .10975 Mtetra
.812 .75 .795 r
.43278 .10975 .43671 .11543 .44365 .10769 .43972 .10278 Mtetra
.339 .586 .935 r
.43972 .10278 .44365 .10769 .45036 .10911 .44644 .10377 Mtetra
0 .114 .651 r
.44644 .10377 .45036 .10911 .45696 .11653 .45307 .10987 Mtetra
0 .25 .762 r
.45307 .10987 .45696 .11653 .46365 .12293 .45978 .11498 Mtetra
.567 .582 .827 r
.45978 .11498 .46365 .12293 .47052 .12217 .46667 .11381 Mtetra
.793 .677 .735 r
.46667 .11381 .47052 .12217 .47756 .11309 .4737 .10548 Mtetra
.853 .711 .706 r
.4737 .10548 .47756 .11309 .48464 .10015 .48078 .09389 Mtetra
.843 .743 .754 r
.48078 .09389 .48464 .10015 .49166 .09005 .4878 .08486 Mtetra
.663 .731 .9 r
.4878 .08486 .49166 .09005 .49859 .0872 .49474 .08214 Mtetra
.094 .424 .869 r
.49474 .08214 .49859 .0872 .5055 .09101 .50166 .08515 Mtetra
0 .306 .799 r
.50166 .08515 .5055 .09101 .51244 .09663 .50861 .08961 Mtetra
.423 .537 .868 r
.50861 .08961 .51244 .09663 .51946 .09821 .51563 .09049 Mtetra
.728 .668 .792 r
.51563 .09049 .51946 .09821 .5265 .09294 .52268 .08543 Mtetra
.826 .71 .737 r
.52268 .08543 .5265 .09294 .53354 .08275 .52974 .07618 Mtetra
.84 .739 .752 r
.52974 .07618 .53354 .08275 .54056 .07266 .53678 .06712 Mtetra
.76 .754 .847 r
.53678 .06712 .54056 .07266 .5476 .06721 .54383 .06213 Mtetra
.453 .643 .939 r
.54383 .06213 .5476 .06721 .5547 .06753 .55094 .06212 Mtetra
.191 .47 .889 r
.55094 .06212 .5547 .06753 .56188 .07092 .55811 .06468 Mtetra
.376 .544 .894 r
.55811 .06468 .56188 .07092 .56908 .07284 .56531 .06589 Mtetra
.654 .662 .846 r
.56531 .06589 .56908 .07284 .57624 .0701 .57248 .06303 Mtetra
.784 .712 .784 r
.57248 .06303 .57624 .0701 .58333 .06286 .57959 .05631 Mtetra
.82 .739 .776 r
.57959 .05631 .58333 .06286 .59039 .05426 .58668 .04849 Mtetra
.781 .756 .831 r
.58668 .04849 .59039 .05426 .59749 .048 .59381 .04276 Mtetra
.622 .721 .917 r
.59381 .04276 .59749 .048 .60471 .0459 .60104 .04063 Mtetra
.414 .615 .933 r
.60104 .04063 .60471 .0459 .61205 .04685 .60837 .04109 Mtetra
.43 .599 .916 r
.60837 .04109 .61205 .04685 .61942 .04786 .61573 .04154 Mtetra
.605 .666 .883 r
.61573 .04154 .61942 .04786 .62674 .04621 .62306 .03964 Mtetra
.735 .715 .832 r
.62306 .03964 .62674 .04621 .63396 .04123 .63029 .03489 Mtetra
.785 .741 .812 r
.63029 .03489 .63396 .04123 .64112 .03451 .63749 .02868 Mtetra
.771 .756 .84 r
.63749 .02868 .64112 .03451 .64831 .02863 .64471 .02323 Mtetra
.683 .744 .897 r
.64471 .02323 .64831 .02863 .65562 .02528 .65204 .01999 Mtetra
.556 .692 .93 r
.65204 .01999 .65562 .02528 .66306 .02429 .65948 .01875 Mtetra
.521 .662 .925 r
.65948 .01875 .66306 .02429 .67057 .02392 .66698 .01801 Mtetra
.603 .687 .901 r
.66698 .01801 .67057 .02392 .67803 .02224 .67444 .01613 Mtetra
.697 .721 .868 r
.67444 .01613 .67803 .02224 .68541 .01848 .68184 .01244 Mtetra
.744 .743 .851 r
.68184 .01244 .68541 .01848 .69272 .01342 .68918 .00766 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.1391 .21522 m
.14374 .21986 L
s
[(-10)] .12983 .20593 .99848 1 Mshowa
.29214 .1553 m
.29652 .16018 L
s
[(-5)] .28339 .14552 .89526 1 Mshowa
.45462 .09167 m
.45869 .09682 L
s
[(0)] .44647 .08139 .79205 1 Mshowa
.62744 .024 m
.63116 .0294 L
s
[(5)] .62 .01319 .68883 1 Mshowa
.125 Mabswid
.16899 .20352 m
.17175 .20633 L
s
.19924 .19167 m
.20196 .19452 L
s
.22984 .17969 m
.23253 .18256 L
s
.2608 .16757 m
.26346 .17047 L
s
.32385 .14288 m
.32644 .14584 L
s
.35595 .13031 m
.35851 .1333 L
s
.38844 .11759 m
.39096 .12061 L
s
.42133 .10471 m
.42381 .10776 L
s
.48833 .07847 m
.49073 .08159 L
s
.52245 .06511 m
.52482 .06826 L
s
.55701 .05158 m
.55933 .05476 L
s
.592 .03788 m
.59428 .04109 L
s
.10955 .22679 m
.11236 .22955 L
s
.08035 .23823 m
.08318 .24096 L
s
.05147 .24953 m
.05434 .25223 L
s
.66334 .00995 m
.66552 .01322 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00d?ooool3o`0000Cooooo0_l00017ooooo`00dOoo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0004Kooooo002`ooooo`?o00005_oo
ool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00016ooooo`00[ooo
ool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00016ooooo`00/oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000A_ooool00;?ooooo00?o0000ooooooooool06_ooool2o`0000Cooooo
00Co0000oooooooooooo0000A_ooool00:oooooo1?l0000Booooo`;o00002_ooool00ol0003ooooo
ooooo`03ooooo`;o0000Aoooool00:oooooo00?o0000ooooooooool04?ooool3o`000003ooooool0
003ooooo05Sooooo002_ooooo`Go00003?ooool2o`0000Cooooo0_l0001Hooooo`00_Oooool3o`00
00Gooooo00Co_[kIo`000?oooooo0000Eoooool00;_ooooo0_l00003ooooo`04o`000?oooooooooo
ok:hgP;o_[kI00?o0000ooooool00000Eoooool00;Sooooo0ol00006ooooo`09oiZ_i_nb^=ko/[SN
ok:hg_nn_]Wo0000ol6of?oooooo000005Kooooo002fooooo`;o00000oooool01?n^_^GoS[7^ohja
k_n>/Nh2ohFYk0;oVZoV00Go/[SNok>igOnc^Mgo0000ol?0e`02ooooo`03o`000?oooooooooo05?o
oooo002cooooo`Co00000oooool3ojjni@04ohjak_n9[^koOZG]ogjUk@?oUjkW00?o/kWMokBjgOl0
00000_o3`=L2o`0005Gooooo002`ooooo`?o00001?ooool01Ol0003oooooooooooo5`MOo[[kU00;o
/;kT0_n9[^h2ogjUk@06oiN^ionC[NSo];[MokBjgOl0003o`l3G0_o6`MH00ooooooo0000ooooo`1C
ooooo`00[_ooool2o`0000Sooooo0_o8_Ll00oo5`MOob<;Dok2ni002ok:oi0;oQJc_0_mfX^d2oi>]
j003okBjgOne^]go000000;oa/7F0_ooool00ol0003oooooooooo`1Aooooo`00Zoooool3o`0000So
oooo00Co_;ODolRmcoo8_Loob;g?0_o8`]@00oo<`m;o/[oTok>oh`02oh6Zk`;oKik]0_n@ZnT2okFj
g@06o`000?o6`MKob<;DolS2e?oooooo0000Doooool00:Wooooo0_l00002ooooo`03o`000?oooooo
oooo00Cooooo00OoVZ[Rokbge?nl]mCo_;ODolRmcoo<_/gob<;D00;oc<?B0onc_n<2oh6Zk`;oKik]
0_n@ZnT01?ne^]go0000okJjgOo8`]@2ol[3d`03ooooool0003ooooo057ooooo002Vooooo`?o0000
1?ooool3oinhjP;oJIg^00KoKYWZoiZZh_nJZ^;oVZ[Rokbge?nn^=<2olbnc@05om30boo<`m;oclC?
olo4conc_n<00_ne`>82ogfXk`;oIi[]0_n<Z^T00ol0003o][_Mol[3d`02ol[3d`03ooooool0003o
oooo057ooooo0023ooooo`;o00007oooool2o`0000Kooooo0_o7`M@01?nO^>[oW[SZoijhj_mMU^d2
of2Bj@03oiZZh_nGZN;o_[SC00;o_[SC00?oc;k=om30boo?a<l00_o?a<l01?oBa<go]L3RokO1hOng
`N42ogZVk`04oenEk?n7Z>[oQjSZo`0000;o][_M00Gob/?Colc3d_ooooooooooo`00001Aooooo`00
P_ooool01?l0003oooooooooool0000Kooooo`Co00001_ooool01?oA_LKoal7Dolc2dOo<`]42oijh
jP;oDHo/0_mPT^T2oiNYhP06okjhdoo0^M?o`;WCom30booB`LSoclC?0_oBa<d3okO1h@;oMjG_0_mH
TN`00on7Z>[o0000okJkg@02okJkg@03olc3d_o=`m7ooooo00;o0000D?ooool008;ooooo00Co0000
oooooooooooo00006Oooool2o`0000Wooooo0_oA_LH3olc2d@03olo3c_nN^>[oW[SZ00;oDHo/00?o
DX[Xoi>Xi?nCZ>@00oo0^M<2om;1b005omG1a_oBa<goeLG;omG5bong`N400_ni`N02ogNUk`;oF97/
00Co0000oh>Vjonf^mgo][_M0_o=`m400oo?`looooooo`00001@ooooo`00P_ooool01?l0003ooooo
ooooool0000Fooooo`?o00002_ooool3om6maP04omFn`oo<`]7ocl?>olo3cP?oWkSZ00?oAHSZodB2
i_m4P^H00_nCZ>@01Oo0^M?o`[[Bol:jd_oB`LSoeL7600?oeLG;00CoelG8okW1h?nl`]oo_<;O0_md
Xnl00om@S>[o0000ognSj`03okJkg@05olg3dOo?`looooooooooool00000Coooool008;ooooo00Co
0000oooooooooooo00005?ooool2o`0000Cooooo0_mcY?02oc1hh`Gooooo00Kob;K8om6ma_oE_/?o
eKk3omVo_oo?`lh2om;4c004oinhj_nP^>WoX;SYocV1i`;oA8;V0_n?Y^D00oo2^];o`k_BomG1aP02
omS2a@05omG5booGaLSoelG8omW5a_nl`]l00_nn`mh00omaX^ooAhOYo`000002ognSj`;o][_M00?o
cl??om34c_o@a<h00_ooool00ol0003oooooooooo`1<ooooo`00P_ooool01?l0003oooooooooool0
000Aooooo`?o000000?oooooo`000?ooool00_ooool2ol;1f0;oLjC`00?o<7SSof2;i?mPRn@00onW
ZMP00oo8]/Soc;O6omFn``02omVo_`?od/C<00?oe/C9oj2hjOnR^NT00_l^NN@00oldN>?oRZCVohZT
iP02ol>kdP?of<;500CofL;3omO5b?oIaLKofLG60onn`mh2ofnPk`05o`000?m7QnWoNZ7[ogZQjonf
^md00oo@a<h00ooAa<goooooo`00001>ooooo`00Poooool2o`00013ooooo0_l00007ooooo`04omNm
`?o2`MSoa/7FolK1eP;oK:3`00Go5fOKof2;i?mPRnCoYjWHojJYf@02olbgaP?ofKno00Gog;nlom;4
c?oFa<Woe/C9omS5aP02oj:ij@03obiii?lUKmko9FoN00;oRZCV00?o`k_BolFld_oH`/D00_oI`/<3
omW5aP07om_6a?nn`mko`<?Lol33g?m_X>oo0000ocn2i`02ogBNj`;o][_M00?od<C>om74cOoAa<d0
0_ooool00ol0003oooooooooo`1;ooooo`00T_ooool3o`0000Sooooo0_oG_L03olK1eP05ol[2domT
W>oo05KAo`1FdOm>PN<00onVZMT00oo<]lKockW5omVo_`02ombo_004omk0^_oFa<Wof<G6omS5aP?o
XkWY00?o97;QobE_g_n5X^L00_n5X^L01_o5_=;ofL;3omW2`ooI`/?ofl;1omW5aP;oflK400KogLK2
ol33g?o2a=_oK9o_o`000?lfO>D2ogBNj`?o][_M00?odLC=om?4c?oCa<`00_ooool00ol0003ooooo
ooooo`1:ooooo`00Soooool4o`0000Wooooo0ooG_L001?oK_Kcoa/7Fol[2doo:`]<2oejHk`05o`1F
dOljM]oo>WKOojJYfOnTZMX00_o?^LD3ombo_006omk0^_oHaLKof<G6omS5a_oKaL?oXkWY0_nU^^P0
1?lIK=go5fGJohFRiomoWnL2olFld@05omW2`ooK`/7ofl;1omg2_ooKa/@00_oMa/801?oOaKoo`/CK
olG4fOl00002obefhP;oKi_[00?o][_MokJjgOoCa<`00_oCa<`00ooDa<_o0000o`00001<ooooo`00
SOooool2o`0000gooooo00KodkFlomNm`?oK_Kcofkflomjn^?o:`]<2olg3d0;oGYS_00?o04G6ocYf
gonTZMX00_nTZMX00oo?^LGodK[3ombo_002omk0^P07on70]ooHaLKoflG3om_5`ooMaL7oYK[XojNk
i`02o`mTfP03o`QJe?moWnOoaKcA00;oa[c@00?ofl;1omg2_ooM`[l00ooMa/801OoOaKooaLCIolG4
fOl0003oIic^00;o;GKR00GoJ9O[okJjgOnf^]go][[Mom?4c002omC4b`;ooooo00?o0000oooooooo
ool0BOooool008[ooooo0ol00005ooooo`;oZK_V00?o66cNo`1>c?l0C/`01?ooool2om>e_006omNg
^OoK_Kcog[jhomjn^?oQ_[GocL?@0_oAa<h2oeRDkP04o`0d^OlVJM_oY:WJoj:Yf`;odK[300Koe;_1
omk0^_oQ`;OohL2gon?0]OoKaL<2omg5`@06omo5__nW^nOoYk_Wo`mTf_l8F]CoNIcW0oo6_=03omg2
_`07omk2_OoMa/;oglFoomo5_oo5a=WoalGHo`000002ofNLkP04obA`gomRTn[oHY?ZokJjg@;o]K[M
00?oe<C;omG4bOoEa<T00_ooool00ol0003oooooooooo`18ooooo`00R?ooool2o`0000Sooooo00Go
ekk1ojVki_n[^nGo05WCo`1>c002ofb9gP05oooooonjZl[o^Z_:om>e_?oG]kT00ooN_[P01ooQ_[Go
dLC>om74c_oAa<koe<C;oe>BkOl09:d00_lAG=@2oj:Yf`03om6j`ooD^l7ohL2g00;ohL2g00Gohl2e
omg5`OoMaL7ogLG1omo5_P02ojVkiP05o`EMe_l0D<goNIcWogVLioo6_=000_o7_=002_oM`[oog/:m
omk2_OoO`[_oglFoon75_OoRaK_oalGHo`000?o9aMH2ofFKkP03oaYYg?mRTn[oHY?Z00;o]K[M0ooE
a<T00ooFa<Soooooo`00001:ooooo`00QOooool3o`0000;ooooo00?o0000ooooooooool01?ooool2
omNn`@06om^n_?n[^nGo[[cTo`16a_l0<k[oK8WN0onjZlX2omNg^@06omZh]ooN_[SohKjeon6n]OoS
_k;odLC>0_oDa</01?oGa<SoCho]o`0T[OlAG=@2oj2Xg0;oe;_100Koe[c0on70]ooS`;Gohl2eonC0
/_oMaL42omo5_P05on75^onY^nKo[;cVo`1FdOl0ALH00_mcV>L01?o7_=3oakc?olNlcooN`[d2omo2
^`;ohLFm00Koh/FkolW5e_o9aMKo0000olc6e?mSVNh2oa1Rf@05oe^?jOne^]go]K[MokFjgOoEa<T0
0_oFa<P2ooooo`03o`000?oooooooooo04Oooooo0023ooooo`;o00002oooool02?oJ][Coekk1om^n
_?oK_[cogknhojjli?l0=;Wo01VU0_mMPMd00onjZl[o_:c:okb/bP02omZh]`;ohKje0_oS_k801?oV
_jooe<C;omO4b?oGa<P2od^=k004o`0FX?l0CLcoX:SLomBk`@;oe[c00_oS`;D2onC0/P08onK0/?oO
aKkohLFkon75^ooSa;Wo[;cVo`1?c?l0>Kh2ofbDi`?oakc?0ooO`[/01ooQ`[Woh/Fkon;5^ooTaKWo
bLGFo`000?o<a]@00_mQV>h01?l@H]WoDh[Xoe>:j?ne^]d2okBig@03omK4b?oHa<Oooooo00;ooooo
00?o0000ooooooooool0A_ooool0083ooooo0ol0000=ooooo`05omZf]?oK_[cofkjlom^n_?oO_kP0
0_na_N<00ol0=;Wo01VUoef1g@03okb/bP;of[Rg00GogKVdon6n]OoS_k;ohknbonJo[`03omO4b004
omW4aOm;SNcoBhg/o`0o``;oWJSN00Coe[c0omNl__oG_;kohl2e0_oT`;801OoV`;3ohLFkon75^ooQ
aK_ohlBi00;o[[gU00Co04o<o`0i__m/U>OoK9CW0oo7_<l01?oO`[_ohL:ion72^OoR`[P2onC5^@04
onG5]_l0003oc/KColk6d`;oHIS^00Go1e_Doe>:j?mCR^So];WMok>ig@02omS4a`04omW4a_oooooo
0000o`0000kooooo0ol0000gooooo`00O_ooool2o`000003ooooool0003ooooo00;ooooo00?ocko;
oeJFkoooool01oooool2omZf]008omfg/?oK_[cogknhomno^?oR_kGo/KgSok>nh_l09:/2od]hg003
okb/b_nn[/[o_Zk:00;ogKVd00KogkVaon>o/_oV_jooi[n_onNo[?oGa<P2omW4a@05om_5`om7Rn_o
0028o`0o`onMZ=h00ooG_;h01_oH_;goi<2bonK0/?oV`;3oil2^on75^`;ohlBi0ona_^@00ol0AlOo
02jeofB?iP03olNlc`?ohL:i00Koh/:honC5^OoTaKWoiLFfo`000?o>a]<2om37d@;oGiO^00?o05C@
odb5ionc^Md00_nc^Md00ooHa<OofLC6ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`00000fooooo`00Noooool3o`0000Kooooo0_o?_l/00ooC`<OoBHk]ooooo`05
ooooo`;of[Jd0_oM]k001OoQ^:gogknhon:o]OoR_kGo/kkR00;o]koP00?o00>Aod]hg?nn[/X00_nn
[/X2omfi]003omni/OoV_jooi[n_00;oikn/00[ojKjYomW4aOoKaL?oflG3omg5`?m4R>[o0028o`0a
^?nJY]koekbn0_oH_;d2onK0/0;oil2^00Goj;n/on?4^OoUa;Koi/Bdok6ni002ok>ohP04o`10`_mK
R^GoFh[UolNlc`;ob;_>00CohL:ion;2^?oR`[Sohl:f0_oUaKH01ol0003od<OAom37dOo@am7od/O?
oefFkOl0CL/00_m3P>D00onc^Mgo/kSMomW4aP02om[4a0?ooooo00?o0000ooooooooool00oooool5
o`0000Gooooo00?o0000ooooooooool0=?ooool005Sooooo0ol0000Nooooo`;o00002?ooool01OoM
]k;ocko;om?0aooC`<Oo?8KZ00;o03o30oooool2ol^]_004omZf]?oM]k3ogKN`on6h[@?oh[ne00Co
i[n_okNoh?ni_mko00RB0_lhKMT00onn[/[o_jo:okn_bP02omni/@05on:j[ooV_jooikn/onNo[?oY
_ZT00ooKaL<01OoMaL3o@HKZod66j_l08ZgoUjCO00?of;bm00Gof[blonK0/?oW`:koil2^onRo[002
onG4]P03onK4]?oXa;7o/koR00;o][oQ00?o01NSoe^:iOmKR^D00oo8^lh02?oR`[Sohl:fon?2]_oU
aKKoilFdo`000?oXaK;od<OA0_oBall00omKUNgo04G6o`1=b`02od>0i@05ok>hgOoJa<Cof/C4om[4
a?oKa<<00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Cooooo001Gooooo`05
o`000?ooooooooooooooool000006_ooool3o`0000[ooooo00OogKNbom?0aooC`<Oodl37omO1a?ll
Q^[o03o300;oTICC0oo;[K`2omfg/0;ohKR]00CohkRZon:o]OoT_k;oi[n_0oni_mh00ol029;o>6gI
okn_bP02okn_bP;ogkVa00?oh[Z_onNo[?oW_j`00_oY_ZT01OoZ_ZOoflG3omg5`?oMaL3oglBm00;o
@HKZ00?o02:]oiNTgooH_;d00_oJ_;`2onO0[P;oj;n/00[ojKnYonK4]?oVa;Coj<BaonW3[onf_n7o
^L3Po`0a]ol05j?oDXGT0oo8^lh3on?2]P;oilFd00Go0000onS5/_oYa;3od/O?omC7c@02oeZDk@03
o`15a_ljN^?o>W[S00;o/[SN00Cof/C4om_4`ooKa<?og<C20_ooool00ol0003oooooooooo`08oooo
o`Co0000=oooool0057ooooo1Ol00005ooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`03
o`000?oooooooooo00Oooooo0_oM]k801ooP^:kodl37omO1a?oG`LCof/70oc1niol08jl00_nAU=<0
1Oo;[KcocZjjolj^^_oM]k3ohKR]00;ohkRZ0_oT_k800ooV_jooj;n/okVogP02okc0g@03o`00J_lT
HMCo_jo:00;o`:o:0_oR^Zl00ooS^Zgoikn/onVnZ@02onZnY`08on^nYOoMaL3oglBmomo4_OoRa;_o
?XCYo`0R[OnCX]l3omZl_003om^l^_oW`:koj;n/00;ojKnY00Coj[nWonS4/OoXa;7ojL>_0oni`>00
0ol0<KOoBGkRodUnhP03olRkcP0:on?2]_oT`[CoiL6bonO5]?l0003oj<FbonW4/?oZa:koe<O=omO7
b`;oFYC]00?o03k1oc5dh?nb^=h00_na]mh00ooKa<?og<C2omc4`P03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0>?ooool005_ooooo00?o0000ooooooooool04oooool3o`0000Co
oooo0_n^_>@7ooooo`;ogKNb0_oP^:h01_oT^J_oel74om[1`?oJ`L3ogL6mo`06U`;oRi;E0oo>[[X2
on6h[@;ohkRZ00KoiKVWonJo[ooV_jooj;n/onVnZOnl`=d2oko1f`;o3U?>00Oo`:o:ol6ab_oR^Zoo
h[Z_on>j[OoT^Z_ojKjY00;oj[jW00?ojkjUonbmXooOa;d00_oRa;/01OoSa;SoUR@0oi>RgonCX]oo
f[bl00;ofkbj00Gog;bionRo[?oY_jWojKnYonZoY`02onS4/@03onW3[ooZ`jgo^L3P00;o^l7N00Go
02ZaodUnh_m9O^;ob;_>olRkc@02onC2]003onG1/_oV`K7o000000;ojLB`00Coj/B^omO7booGal_o
fLS90_mHTnd2obM^g@03ok6gg_n`]mkog<C200;og<C200CogLG1ooooool0003o00002Oooool5o`00
03Kooooo001Gooooo`Co00004oooool3o`0000Kooooo00Cofk^hojjli?n`_>?o00231_ooool01OoF
[k;ogKNbon2h[_oP^:koi;V[00?of/7000?ogL6moa]`h?l01YL00_n;T]D01Oo>[[[od[6hom:a^?oQ
^:gohkRZ00;oiKVW00WoikVUonRo[?oX_jcojKjYonZnYono`M_o`/;Joj0`0?l>Dlh00oo1/LX2on>j
[@03onBjZooZ_ZOoj[jW00;ojkjU00Kok;fSon;4^ooRa;_oh/Bkon?4^?lhPNL3ohjPh003om^l^_oL
_;Wog;bi00;ojKnY0_oZ_jL01_o[_ZGojL>_on[3[OoZ`jgojl>Zok_1gP;o_/;M00?o006?ocihh?o8
^ld00_o8^ld2onG1/P03onK1/Ol0003ojLB`00;oj/B^00OoelO;omW8bOoIb<WoflS7oeNBk?l0;kKo
9fkM00?o/;ON00Cog<C2omg5`OoMaL7ogLG00_ooool00ol0003oooooooooo`11ooooo`00Eoooool0
0ol0003oooooooooo`0Booooo`;o00000_ooool00ol0003oooooooooo`04ooooo`05om^k^?oO^kCo
/;cSok2lhol008<01?ooool2omJ_/P;oh;R^0_oT^J/01_oV^JOof/70omg1_OoM`Kgogl:jo`00O`;o
QI3G0ooB/KP01OoD/[OohkRZonFiYooU^JOoikVU00;oj;n/00?ojKjYonZnYoo2`]X00_o2`]X2o`15
aP08ol6ab_o1/<WohkZ]on>j[OoT^Z_oiKZYonZnYoo[_ZD2onbmX`08onfmX?oRa;_ohlBhon?4^?le
O^OoWbh0ohjPh?n:WN03ombl^@03ombk^?oY_jWoj[nW00;ojkjU00KojL>_on[3[OoZ`jgojl>Zong2
Z?nn`]d2ol73f`;o<g3M00?ob;_=olRjcOo8^/d00_oV`K401_l0003ojLB`on[4[_o/a:cokLBYomW8
b@;oflS700Gog<S5oeJAk?l0;kKo7FOJok2ggP02ojnfg`03omg5`OoMaL3ogLG000;ooooo00?o0000
ooooooooool0@Oooool005Oooooo1Ol0000=ooooo`?o00002_ooool2om^k^004omnk]?nc_N7o/kgQ
ok>mh@;o;Uc?00OoooooomJ_/_oF[k;oeZnbomV`[ooP^:koi;V[00;oi[VW00Koj;VUomg1_OoO`[[o
gl:jon;1^?l007l2ohF@e`03om:a^?oD/[Ooe;:g00;oiKVW0_oW^JD01_oY^J?ojKjYonVnZOoZ_ZOo
k;jTol;2fP;oaL;H00Co04G6ol6`bOo1/<Wo`K390_oT^Z/01?oU^ZWojkjUon^nYOo/_J<2onfmX006
onjlW_oSa;SoiLBfonK4/oleO^Oo00280_n:WN000ooL_;Wog;^hombk^002onZoY`;ojkjU0_oZ`jd2
on_3ZP06ong2Z?o1`m_o`L?Kol73fol07:Go<g3M0oo8^/d02OoV`K7oil6_o`000?oX`Jkoj/B^onc4
[?o]a:WokL>Xom_8a`02omc8a@;oEI7/00Co02R`oa=Peon_]]oo[KKO0ooMaL03ooooo`03o`000?oo
oooooooo043ooooo001Wooooo`;o00003?ooool02OoK/Zkofk^homnk]?oO^kCoh[^`ok>mhOne_^3o
VB/0obiLc`02okBQa003omJ_/_oI/:oofK2_00;oi;V[0_oV^JL01_oX^JGogl:jomo2^_oO`[[oh/6h
on?1]@;oOXgH0ooD/[L00ooF/kGoiKVWonNiY@02onViX`06onVnZOoZ_ZOoj[jWonbnY?o]_J;oaL;H
0_o7`mH01?l0=kgo`K39ol6`bOoT^Z/2onFjZ@03onJjZ?o[_ZGok;fS00;okKfP00Kok[bNonG4]_oU
a;Koi/BconS3/OlbONH2ohBJh0?og;^h00OogK^fonZoYoo[_ZGok;jSonfnX_oZ`jgojl>Z00;okL:X
00Kok/:Vol73foo3`m[o01FOo`00NolXJMX2olRjc@04onK1/OoW`Joo0000onS1[P;ok<B/00?okLBY
ong3Z?oLb<D00_oLb<D01?oNb<?oEI7/oeFAk?l9FM<3ojffg`03omg5`?oNaKooglFn00?ooooo00?o
0000ooooooooool0?oooool006Cooooo1?l00003ooooo`03om2nbOoooooooooo00Oooooo00?ofk:^
omnk]?oO^k@00_oR^k001_oT_:go]KkPokRngol?BLKo;Uc?okBQa0?ofK2_00?ogK:/onBiZooV^JL0
0_oX^JD01_oY^J;ogl:jon;1^?oR`KSohl6eo`00J@;oOXgH00?oe;:gomJc]OoF/kD00_oW^JD2onVi
X`09onZiXOoZ_ZOok;jTonbnY?o]_J;okKfPolO3e_o:`mCo02Nb00?o`K3900?oiKZYonJjZ?oV^ZP0
0_o/_J<01?o]_J3ok[bNonjlW_o__9`2onK4/`03onS3/OoY`jko001l00;oQ9[P00[og;^homfk]_oM
^kKog[^eon^nYOo/_Z?okKjRonjmX?o[`j[okL:X0_o^`ZH01?o^`ZCo`l?JolK4f?l006T2oaaPeP;o
b;[=00Coil6_o`000?oX`JkojL6/0_o]a:T00oo]`jSok/>Vomc8a@02omk8``;oE93/00?o01ZUo`UI
don]]]l00_n/]Ml00ooNaKooglFnooooo`02ooooo`03o`000?oooooooooo03oooooo001Rooooo`;o
00001_ooool2om2nb@03oamfhooooooooooo00Gooooo0_oK/Zh03?oN/j[ogk^don:k/?oR^k3oi;b]
onJlZ_nh_]oo/T<0o`m9a_ndXLCo]Z;4omV`[`;ogK:/00?ogk>ZonJiYooX^JD00_oY^J801Oo[^J3o
h/6hon?1]OoS`KGoiL6b00;oMXWI0ooF/kD00ooI];CoikVUonViX`02onZiX@05on^iW_o/_ZCok;jT
onfmX_o]_J000oo:`m@01?l09k;o`K39ol6`bOoU^ZT2onJjZ004onNiY_o]_J3okKfPonjlWP;okkbL
00GokkbJonS3/OoX`k7ojL>^on_3[002ognGh0?ogK^f00Gog[^eonbnXoo]_Z;okKjRonjmX002ong2
Z0;ok/:V00Kok/:TolK4f?o8aMOob<GGo`00JOlLH=H2olRjc@05onS1[_l0003ojL6/onW1[?oZ`J/0
0_o]`jP02oo^`jKokl>Tomk8`ooPb<7ohLRooe>?k?l04ioo01ZUo`1Ac_n/]MooZkCP00;oglFn00?o
h<Fmooooooooool00_l00010ooooo`00Goooool3o`0000Oooooo00Kog;Jaom2nbOoD_lGoe;o5oamf
hon_>`04ooooo`;ofk:^0_oN/jX2on:k/0;oi;b]00Coi[bZokZog_nj_mko03:i0_nfX/@01?oI/:oo
gK:/omfb[?oO/jX2onRiY@;ojKVR00?ojkVPonbiW_oS`KD00_oU`K801?nS>03oMXWIogJ9fOoF/kD2
omVd]0;ojKVS0_oZ^J402Oo[^Ikok;jTonfmX_o]_J;okKfPonjmW_o:`mCoc<CBo`0IYP02ol6`b@;o
i[ZX0_oW^JH00ooX^JCokKfPonjlWP02onnlW006onnlV_oX`k7oj<>aonW3[_o[`jco:7KS0_moUn00
1?oM^kKog[^eomjk]OoO^k@2onfnXP04onjmX?o^_IkokL:Xonk2YP;ok/:T0oo8aML2o`00J@04o`mH
dOo8^/gob;[<o`0000;ojL6/00coj/6[ong3Z?o^`jKok/>Vono3Y?o``j;oh<S1on78_ooSb;goDXo/
o`0CWol0B/X2oj^dh004omo5__oPaKgoh<Fmon75_0?ooooo00?o0000ooooooooool0?Oooool005go
oooo0ol00009ooooo`06ombf/OoD_lGoe;o5omBoaOoH`<;o26OK1?ooool01oo:Z;Oofk:^omjcZ_oN
/j[oh[BWon:k/?oT_:d00_oV_:X01OoX_:Oo^[oNokg0g?l0<[Wo]Z;400;ogK:/0_oO/jX00ooQ]:Oo
j;VUonViXP02on^iX003onbiW_oU`K;oiL6b00;oi/6`0_m]QMX3omVd]003omZd/_oY^J?oj[VQ00;o
jkVN00Wok;RMonfmX_o]_J3okKfPonjmW_o__9coc<CBolk4d?l06JH00_o1/<T01?oV^ZSoikVVonNi
Y_oX^J@2onjlWP04onnlW?o__9[okkbJoo2kV@;ojL>^00Cojl>/onc3Z_l006CoNI?P0_oN^kD2omnk
]00:onfnX_o^_J3ok[fPonjmW_o__Icok/:Vonk2Y?o_`J;ol<6PolS5e`;oblGE00Ko001Yo`mHdOo8
^/cob;[<onW1[?l00002on[1Z`05on_1ZOo^`jKokl>Tono3Y?o``j800_oQb;l02?oSb;goDHk/oe6>
k?l0@/Go04[:oj^dh?nY]>3oh<Fm0_oQaK`3ooooo`03o`000?oooooooooo03gooooo001Jooooo`?o
00000oooool00ol0003oooooooooo`05ooooo`;og;Ja00Koh;J]omBoaOoH`<;of<32om[0_ol01IL2
ooooo`;obZRg0_oN/jX2on:dY`03onBdYOoT_:goi[bZ00;oj;bW00?ojK^Uokg0g?l06jT00_nhY<@0
1?oM/Zcogk>Zon6dYooQ]:L2onViXP05on^iX?o/^Ikok;VNonfiW?oU`K800_oV`K001?oX`JkoKHGJ
off5f_oI];@2omZd/P;oj[VQ00CojkVNonbhWOo/^9gok;RK0_o]_J001Oo^_IkokkbLoo2lV_o>a=3o
d<G?00;o`K390_oW^JH2onRiY004onViX_o__9cokkbLonnlVP;ol;^I00GolK^Gon_3[?o/`j[ok<>Z
ong2Z002og:?g`04omjk]OoO^kCogk^domnk/`;ok[fP00Sok[fNonnmW?o^`ZCok/:Tono1X_o``J3o
lL6Nol_5e@;ocLKC00Ko0do<olRjc?o8^/cob;[<o`000?oZ`J/2on_1Z@05onk3Y_o_`jCol<>Roo33
X_oa`Z400_oSb;d01_oTbKcoDHk/oe6>k?l0@/GoZKCPojRch@?ohLFl00Goh/Fkoooooooooooooooo
o`00000nooooo`00F?ooool2o`0000Cooooo00?oYk[Wo`0DV_ooool01_ooool2ombf/@;oh;J]00Ko
hkNZomS0`_oJ`;oof/2oomg0_?n1Qm03olZX]`05oljZ]OoN/j[oh[BWon:dYooT]:D00_oV_:X2onRl
Y`05onVkYOoZ^j?o_l7Ko`0KZOnhY<@00_oO/jX2on6dY`03on>dYOoY^J;ojkVP00;ok;VN00?okKVL
onfhV_oV`K000_oX`Jh2ofB0f@?of[Bb00?ofkBaonZiXOo[^Ih00_o/^9d00oo/^9_okKfPonjmWP02
onnlW008oo2lV_o@aLood<G?o`0:V_o1/<Wo`Jo8onNiY_oX^J@2onViXP;okkbL00GokkbJoo2kVOo`
^iWolK^Gon_3[002onc3ZP05ong2Z?o^`ZKoLXoOog:?gooO^k@00_oO^k<01_o^_J3ok[fNonjmW_o_
_Icol;bKonk2Y0;ol<6P00?olL6Noo;0W?o=a]<00_o?a]801Ol0ALKob;[<olRjc?l0003oj/6[00;o
jl6Y0_o_`j@01?o``j;olL:Qoo72XOoSb;d2onC9_004onG9^_mAS^_oDHk[o`0k_`;oZ;?Q00CohLFl
on;5^ooRaK_ohlFj0oooool00ol0003oooooooooo`0kooooo`00EOooool3o`0000Gooooo00?of;Zl
ojNjionX^^L01oooool01OoD[K7og;Jaon2f[OoP]ZgohkNZ00?of/2o00CogL2lo`00M_n1Qm3obZRg
0_o>Z[D2on:dY`;oi;BU00?oi[FRonJlZ_oX_:L00_oY^jD00ooZ^j?ojk^Qo`05U`02okZUa004omnc
Z_oQ]:OohkBUon>dY@;ojkVP00Cok;VNonfiW?o]^IcokKRJ0_oX`Jh2onW0[0;oI83I00?of[Bbom^d
/OoK];400_o[^Ih01_o/^9gok;RKonbhVoo]^9Wok[fNonnlW0;ol;bJ00?ol;^Hom35cooBaLd00_o1
[lP2onRiY0;ojKVR00CojKVQonnlV_o__9[ol;^I0_oa^iL2onc3ZP;okL:X00?ok/:Vofb:gom/R]l0
0ooO^k<00ooP^k7ok[fNonnmW002oo2lV`09oo2lVOo``J3ol<6Poo71W_ob`9col/2Jolo6d_oAam3o
03c000;ob;[<00Oo0000on_1ZOo[`JWojl2Xonc0Y_o_`jCol<>R00;olL:Q00Ool/:MonC9_?oUbK[o
iLVjonO9^?m@S^_o006?00?oY[?R00?oh/Fkon?5^_oSaKX00oooool00ol0003oooooooooo`0koooo
o`00Doooool2o`0000;ooooo00?o0000ooooooooool00_ooool2omRj_003ombk^?nX^^OoZ;[W00Go
oooo0_oD[K42on2f[@;ohkNZ00KoiKNWom[0_ooM`;cogL2lomo0^_miPm43oljZ]@03om6//ooR]:Oo
i;BU00;oi[FR00?oj;JPonRlYooY^jD00_oZ^j<01?o[^j7o`l;Io`05UonjYL@2on6dY`;ohkBU00Co
iKBTonbiW_o/^IkokKVL0_o]^9X01?o^^9Soj<6^onW0[?oZ`:T2oeYjf0?ofkBa00?og;B_onbhWOo/
^9d00_o/^9/00oo]^9Wok[fNonnlW002oo2lVP08oo2kV?oa^iKod/G=o`00S_o1[lSo`Jk8onRiY?oY
^J82onViX@03onZhWoo`^iWol;^I00;olK^G00?ol[ZConc3Z_o]`ZP00_o^`ZH01?o^`ZCoK8[Oofb:
gooO^k<2on2k/@06on6k/?o__Icol;bKoo2lVoo`_9Wol<6P0_oa`Ih00oob`9col/2Jom77d002om77
d00<o`0l`?o8^/co0000olRjc?o[`JWojl2Xonc0Y_o]`:Gol<>Roo72XOoa`Yool/:M0ooUbKX01_oW
bKSoD8g[o`00ROl0;;GoY[?RojBbhP?ohlFj0oooool2o`0003cooooo000Yooooo`?o00001?ooool2
o`0001kooooo0ol00008ooooo`?of;Zl00Cog;^homnk]?nY^nKo001W1?ooool2omB]/@03omR_[_oP
]ZgohkNZ00;oiKNW00Ooi[NTomg0_?oO`;[ogl2joj8i0?miPm7ocZZe00;odJbc0_oT]:D2onJeXP04
onRfX?oY^jGojK^UonZkX`;ojk^Q00Kok;^Oo`00Q?nkY/Co^jK4on6dYooS]:D2onFdY0;ok;VN00So
kKVLonfhV_o]^9[ok[RHonnhU_oY`:coj/2Yon^oY`;oFW[H00?ofkBaombd[ooL]:l00_o/^9d00oo/
^9_okKRIonfhV@02onnlW006oo2lV_o`^iSol;^Hoo6kU_oa^iGoe<G;0_o1[/P2onViXP;ojKVQ00Wo
j[ROoo2kVOo`^iWolK^Goo6kUOob^Y?ol[ZBong2Z?o^`ZH00_o^`Z@00oo_`Z;oI8KNon2k/@02on2k
/@03on6k/?o__Icol;bK00;ol;bI00golKbHoo71W_ob`9col/2Loo;0V_oc`9WodLO@om?7col007Oo
b;[<o`000?o8^/cojl2X00;ok<2V00OokL2Uoo72XOoa`Z7olL:Ooo;2WOob`YcoiLVj00;oilVh00Co
jLVeodn=jol008Co02be0_nT/^82on?5^P03onC6^Ooooooooooo00;ooooo00?o0000ooooooooool0
>Oooool002[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Jooooo`?o0000
2oooool02_oI/[;of;Zlombk^?oL^kSogk^don6k/_nZ^nKo6Dk8ooooooncW/<2omB]/@;of:n^0_oS
]jX2onFgY`03onJgY?oX^:;ogl2j00;ohL2h00OoKgoCom6//ooA[;?odJbcomB]/_oT]:Goi[FR00;o
j;JP00CojKJNonVkYOoZ^j?ojk^Q0_o/^il00oo]^Ygo0024ok^Va002on>dY@;oiKBT00Coi[BRonfi
W?o]^IcokKRJ0_o^^9P01?o_^9Koj/2Yon[0ZOo[_jL2oe1ce`04om^d/OoL]:oog;B_omfd[P;ok;RK
0_o]^9T01?o^]iKol;bJoo2lV_o`^iP2oo6kUP07oo6kUOob^i?o0022ol6^b?o0[/OojKVRonViX@02
onZhW`06on^hW_oa^iOolK^Goo6kUOob^Y?ol[ZB0_o^`ZH00oo^`ZCokl:Rono2XP02oeb1g@03on2k
/OoQ^k3ohK^`00;ol;bK00Col;bIoo6lV?oa_9SolKbF0_ob`9`2oo?0V@05oo>oUooCalooe<O=o`0X
/_l000000_o8^/`2onc0YP03ong0YOo]`:ColL:Q00;ol/:M00Gol/:Loo?2VooWbKSoj<VgonW9]@02
odn=j`04o`00Q?nS/N?oXk7Soj>ah`;oi<Ji00GoiLJhooooooooooooooooo`00000kooooo`008_oo
ool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Hooooo`;o0000
0_ooool01Ol0003oooooolVodOo9_m7o001g00Kooooo0_oI/[801?oL/jkog;^homnk]?oO^k@2on6k
/P05ojZki_ncW/?o/ik3ok>N`ooD[K400_oH[jh00ooL/JcohkNZonFgY`02onJgY007onRhX_oQ`;So
hL2hon70^?ngC@3oKgoCom6//`02omB]/P;oi[FR00?oj;JPonVfW_oY]Yh00_oZ^j<01Oo[^j7ok;^O
onbkWoo]^Ygo001c00;o_:O500GohkBUonFdY?oV]:;oi[BRonNdX002onfhVP;ok[RH00KokkRFonng
UOoZ`:WojknWonboYOm@LmL2ombd[`;ogKB^0_o/^9/00oo]^9Wok[NHonjgUP02oo2lVP06oo2kV?oa
^iKolK^Foo6kUOob^i?of<K80_o0[/L2onViX@03onZhWoo[^9kojkRN00;olK^G00KolK^Eoo:jToob
^Y;olkZ@onk2Y_o^`Z@2ono2XP05oo31X?mLPMgohK^`on6k/?oR^Zl00_o`_9/01_o`_9WolKbHoo6l
V?oa_9Kol/2Loo;0VP;oll2I00KolknGooBoU_oDalgoe/S<o`000?o8^/`2olRic0;okL2U00OokL2T
onk0Xoob`Ygol/:Moo;2W?oc`Y_om<:I00;ojLVe00Koj/Vcodn=jol0083o01jYoj>ahonQ/N<2onC6
^@03onG6^?oUa[Oooooo00;ooooo00?o0000ooooooooool0>?ooool002[ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Eooooo`?o00001Oooool3olVod@03olboc_l007Oooooo
00Cooooo0_oI/[801?oL/jkogkB/omnk]?oO^k@2on6k/P04on>k[ol0=[_o/ik3okBO``;of:n^0_oL
/J`2onFgY`05onJgY?oX^:;oj;RRonVhX?oQ`;P00_oR`;D01omUN]?oe:fbomB]/_oD[K;oeZn`onJe
X_oX]Z000_oY]Yh01?oY]Icojk^Qon^kXOo/^il2onfjW@03onjjVol007?o_:O500;oiKBT0_oV]:80
1?oW]:3okKRJonfhV_o^^9P2onnhUP04onngUOo`]i?ojknWonboY@;oAVcD00Cog;B_omfd[_oM]:ko
g[B/0_o]^9T00oo^]iSok[NFonngU002oo2kV00:oo6kU_oa^iGolK^Eoo:kToob^Y;o001eol2^aoo0
[LOojKVQonZhW`;ojkRN00Wok;RLoo6kUOob^Y?ol[ZCoo:jT_oc^Y3olkZ?onk2Y?o_`Z800_o``J02
oeAkg003on6k/?oR^Zooh[Z^00;ol;bI00KolKbHoo6lU_oa_9Kol[bEoo;0V_oc`9T2oo>oU`04ooBo
U_oFb<cof<S:o`0000?ob;W<00GokL2Uong0Y?o]`:Cok/2Soo;2W@02oo;2W007oo?2Vood`YWojLVe
onW9]OoZbK?ojlVbodn=j`02o`0NZ@;oXK7S0_oUa[P00ooUa[Ooooooooooo`02ooooo`03o`000?oo
oooooooo03Oooooo000Zooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004ooo
ool2o`0000Sooooo00GoekNiolVodOo<_lkoc;o>o`AWfP04ooooo`;ob:Vj0_oL/jh2omnd[0?ohK^b
00?ohk^_onBl[Ol0=[/00_ndWl<01ooH[jkog;6/omba[?oN/JWoiKNWonJgY?oX^:800_oY^:001_oZ
]ikoh/2eon?0/ooS`;?oIG[ComB]/P;oeZn`0_oX]Z001?oY]YkojKFLonVeW?o[]I/2onbkW`04onfj
WOo^^Y_ok[ZKo`00L`;o_:O400GoiKBTonJdX_oW]:3oikBPonRdWP02onjhV004onnhU_o_]iGokkNE
oo2gT`;ok;nU00CokKnTodI/e?oM]:kogKB^0_oN]:`2onfhV@04onjgV?o^]iKokkNDonnfT`;olK^F
00GolK^Eoo:kToob^i?ol[ZBoo>jT002ol2]a`;oj[RO00GojkRNonbhW?o/^9colK^Eoo:jT`02oo:j
TP08oo>jT?oc^Xookl:Rono2X_o``J3olL6Ooo71WOmDNm`2on:j[`04on:j[_oS^ZgolKbHoo6lV0;o
lKbF00Col[bEoo?0VOoc`9WolknG0_od_iH2omS8bP03o`000?l05ZCob;W<00;ob;W<00KokL2Tonk0
Xoo^`:?okl2Qoo;2W?oc`Y/2ooC2V@07ooC1V?oZbK?oj/Vcon_9/_o/bK7oCXg[o`0NZ@02oin`i004
onG6^?oUa[OoiLJgonK6]`?ooooo00?o0000ooooooooool0=oooool002Wooooo0_l00004ooooo`04
o`000?ooooooooooo`00013ooooo0ol000000ooooooo0000ooooo`06ooooo`;oekNi00Gof[Rfolbo
c_o?`<_ocl3;ojTb0003ooooo`;ob:Vj0_oL/jh2omnd[005on6eZOoQ^k;ohk^_on>k[ooT_:d00_l0
6jT00ondWl?og;6/omba[002omjaZ@;oi[NT00Coj;RRonVhX?oY^:3oj[NN0_oS`;<00ooU_k7oFWCC
omB]/P02omJ_/003omV`[ooY]YkojKJN00;ojKFL00CojkFKonbkWoo/^iookKZM0_o^^Y/00oo^^Y[o
001cokbWa002onJdXP03onNdX?oX]9koj;BN00;ok[RH00OokkRFonngUOo_]iGol;NCoo2gT_o/_jGo
kKnT00;o>fCA00GogKB^omjd[?oN]:cogk>[onjgV002onjgUP06onngU?o_]Y?olK^Foo6kU_oa^iGo
l[^C0_ob^Y801?oc^Y3o001Yol2]aoo0[LL2on^hWP;ok;RL00_ok;RKoo:jToob^Y;ol[ZBoo>jT?oc
^Xoom;V>ono2X_o``J3olL6Ooo71W@02od]ff`;oh[Z^00CohkZ]oo6lV?oa_9SolKbF0_ob_9D2oo?0
V@08oo>oUood_iKom;nFooFoTooHb<[o0000omW8bOl05Z@2olRic007ong0Y?o^`:?okl2Qono0XOo_
`:3oll:KooC2V@02ooC1V004on[9/oo[bK;ojlVbonc9/@;oCXc[00CoWk3Toif_i?oUa[OoiLJg0_oV
a[L3ooooo`;o0000>?ooool002[ooooo00?o0000ooooooooool00oooool2o`0000oooooo0_l0000;
ooooo`?oekNi00?of[Rfomfi/oo?`</00_oB`<T2ohB<d`?ob:Vj00Goc:^homnd[?oO]:cogkB/on6e
Z@02on>k[`;oi;b]00Goi[^[o`0KZOngX/Co]j;4omba[002omjaZ@04on2bYooX^:;oj;RRonVhX0;o
j[NN00CojkNMon?0/ooU_k7oi[n_0ooF[k001?oI/:oojKJNonVfW_oY]I`2on^eV`04on^eVOo]^Ygo
kKZMonjjV`;ok[ZJ00Go001SokbWa?nlYl?oi[BRonNdX002onRdWP04onRdWOo_^9KokkRFonngU@;o
l;NC00Gol;NBoo6gT?o]_jCok[nRoc]Td@02omjd[0;ogk>[00Kok[NHonjgU_o^]iKokkNDonnfToo`
]Y42oo6kU@05oo:kToob^Y;ol[ZBoo>jT?oc^Xl00_o0[LL2on^hWP05onbhW?o/^9_ok;RKonfhVOob
^Y800_oc^Y001?oc^Xoom;V>ooBiS?o``J02oo71W@03oo;1W?m;M]_oBgKK00;ohkZ]00?oi;Z/oo6l
U_oa_9H00_ob_9D02_oc^i;olknGoo>oUood_iKom;nDooFoTooe_i;o0000om_8aoo1E@02olRic0;o
k/2S0_o_`:400oo_`:3oll:KooC2V@02ooC1V007ooG1U_o[bK;ok<Vaonc9/Oo]bJkoCXc[o`00L`02
oif_i003onG6]ooVa[Ooi/Jg00Gooooo00?o0000ooooooooool0=Oooool003kooooo0ol00003oooo
o`;ockc800?oXK[Zo`1;aoooool01Oooool01Oo@/;WoekNiomZh]_oJ^;KogKVc00?od/3900Coe<37
ohB<don4S=?ob:Vj0_o<ZkP2omnd[0;ohKFY00?ohkFWon>k[ooT_:d00_oV^j/00ooW^jSo00>EokNR
a002omjaZ@;oh;:W00?oh[>UonVhX?oY^:000_oZ]ih01_o[]igok;NKonFo/OoV_jooCFkBomJ_/0;o
fK2_00?of[2]onVeW?oY]I`00_o[]I/01?o[]IWok;FGonjjVoo^^Y/2onjjVP03onniV?nlYl?o_:O3
00;oikBP00?oj;BNonRdWOoX]9d00_o_^9H01oo_]iGol;NCoo2gT_o`]i;olKN@oo6gSoo^_j800_l`
G<h01OoN]:cogk>[omncZooO/jWok[NF00;okkND00KokkJCoo2fTOoa^iGolK^Eoo:kToob^Y82oo>j
T004oo>jSoo0[LOo_jc6okn/aP;ok;RL0_o/^9/02?o]^9Wol[ZBoo>jT?oc^Y3olkZ?ooBiS_od^Hco
m;V;0_oa`Id00oob`IcocFD0od9`f@02on>j[@07onBj[?oa_9KolKbFoo:lUOob^i?olk^Boo>kT@02
ooBoUP0;ooBoU?oe_i?omKnBo`000?oKb<Oo`ED0o`0=W?o8^Lcob;[<onk0Xoo_`:400_o_`:02ooC2
V@03ooC1V?oe`IOomL6F00;ok<Va00Gok<V`ong9[_m>S>_o001_o`0<V@02oi^_i@03onK6]ooWa[Ko
ilNe00Cooooo00?o0000ooooooooool0=Oooool003cooooo0_l000000ooooooo0000ooooo`03oooo
o`;ockc80_nP^N/00ol0:Zcoooooooooo`02ooooo`;od;2i00Koe;6fomZh]_oM^K?ogKVcomni/?oB
`<T2omC0a`;oOHSD0oo<ZkP00oo?[KOogkB/on6eZ@02on>eY`03onFfYOoT_:goi[^[00;oik^X00Co
00>EokRS`onhXl?og[6Y0_oP/ZL01?oR/jGojKRPonVhX?oZ]ih2on^gW@04onbgVoo/]iWoi[n_onNo
[P;ofK2_0_oJ/:d2onVeW004on^eVoo[]IWojkFIonbeU`;ok[ZK00Kok[ZJonniV?o_^ISokkVGokbW
`onmY/<2onRdWP;oj;BM00CojKBKonngUOo_]iGol;NC0_o`]i801Ooa]i3olKN?onjnX?o^_Z3o<5c>
00;ogk>[0_oO/jT01_o^]iKokkNDonngU?o_]Y?ol;JAoo2fT0;ol[^C00Gol[ZBoo>jT?oc^XoolkZ?
oj8n0002okn/aP;ok;RL00Gok;RKonfhVOo]^9Wok[NHoo>jT002oo>jS`04ooBiS_od^Hcom;V;oo71
W@;ol/6L00?ol/2JocQYeolhJML00_oT^Z`01_oT^Z_ol[bEoo:lUOob^i?olk^Boo>kT@;om;nF0_oe
_i<01Ooe_i;o0000ooJnSooLbLKo00BD00;ob;[<0_o_`:400oo_`:3ol<2Ooo30WP02ooC1V009ooG1
Uooe`IKom/6Donc9/Oo/bK3okLV^onk9[Om>S>_o001_00?oVJkV0_oWakD00ooXakGoooooooooo`02
ooooo`03o`000?oooooooooo03Cooooo000iooooo`?o00001oooool02OoA][kockc8om:maOoB_LGo
X;W[oinijolmK]Wooooook:TbP03om2`^@03omBa]_oM^K?ogKVc00;ogkV`00CohKV^omC0aooF`LGo
e/750_mmR=@00oo<ZkSocjfgoln]]`02on6eZ@;ohkFW00?oiKJUonJkZooV^j/00_oW^jP00ooX^jOo
00>EokRS``02on2bY`;oh[>U00Cohk>TonZgW_oZ]ikojkNM0_o/]i/01Oo/]iWoikn^onNo[_m2I]3o
fK2_00;of[2]00?ofk2/on^eVoo[]I/00_o[]IT01Oo/]IOokKBFonjjV_o^^Y[okkVH00;okkVG0_nm
Y/<2onRdWP;oj;BM00GojKBKonngUOo_]iGol;NCoo2gTP02oo6gT003oo6gSoob]XkokkjO00;o95C:
00Gogk>[omncZOoO/jWoh;>XonngU002onnfT`03oo2fTOo`]Y3olKJ?00;ol[ZB00ColkZ@oo>jSood
^Xkom;Z>0ono[<H2onbhV`;okKRI00Cok[NHoo>jT?oc^Xoom;V>0_od^H`01?od^H_omKV:oo;1W?ob
`9X2oo?0V@04ocQYeooT^Zcoi;Z/onBjZ`;ol[bE0_oc^i800ooc^i7om;^@ooBoU002ooFoT`03ooFo
T_l0003om[j?00;ogLW500Oo00BDolRjc?o8^/gokl2Qono0X?o``9ool<2N00;om<6H00ComL6GooG1
U_of`ICom/6C0_o]bJh01_o^bJgok/V/odj<jol00HooVJkVoiN]iP;oilNe00?oj<NeonS7]?ooool0
0oooool00ol0003oooooooooo`0cooooo`00=_ooool3o`0000Wooooo0_oA][h3om:ma@04omFm`_nO
^N_oW[W[oce^f@;o/ZC:00God;2iomBa]_oD/KKoek>domfi/`02omni/004on6i[_oS^Jcoe/75omS1
``;oM8KF0oo?[KL00ooB[[GohKFYon>eY`02onFfY@03onJfXooV^j_oik^X00;oj;^W00Go001ookRS
`onjY<?oh;:Won:cY@02on>cY0;oj[NN00OojkNMonbgVoo/]i_ok;NIonfgV?oW_jkoj;n/00;of[2]
0_oK/:`2on^eV`04on^eVOo/]IOok;FGonfdUP;ok[ZJ00KokkVHonniUoo`^IKol;VFokfV`onmY/82
onRdW@;ojKBK00Goj[>Joo2gToo`]i?ol;NBoo6gT002oo6gS`04oo:fS_ob]XgokkjMobADbP;ogk>Y
0_oP/jP01_o_]iCokkJCoo2fTOo`]Y7ol;J@oo6fS`;ol[ZB00OolkZ@oo>jSood^Xkom;Z>ooBiS?no
[<Ko_j_600;ok;RK00OokKRIonjgV?o^]iSok[NGoo>jSood^Hkom;V<00;om;V;00GomKV:ooFiROob
`9[oll2Ioo?0V002obmSe0;oi;Z[00SoiKZZoo:kTooc^i;olk^Boo>kTOod^i3om;^>ooFoT`;omKnB
00Go0000ooJnSoof_Xkog/W4o`00S@03olRjc@05ono0X?o``9ool<2Noo70WOoe`IL00_oe`IH00oof
`ICom/6CooK1TP02onk9[@04onk9[?o_bJ_oCHc[o`00R`;oUjgV0_oXakD00ooXakCoooooooooo`02
ooooo`03o`000?oooooooooo03?ooooo000dooooo`?o000000?oooooo`000?ooool01oooool3om6f
_P06omFf^ooB_LGoeKg2omFm`_oH_KooW[W[0_lQGM800onbY<[o]:G9omBa]P02omNc]0;ogkV`0_oQ
^Jh01?oS^Jcof<73omS1`ooH`L<2ogB6eP03oln]]ooB[[GodZje00;ohkFW00KoiKJUonJfXooV]Z?o
ikFQonNkZ?oX^jL2onVkY@;o^ZC30_oR/jD2on>cY004onBcX_o[]igojkNMonbgV`;ok;NI00GokKNH
onffUooX_jco=ek=omZ`[@02om^`[004omb`Z_o[]IWojkFIonbeU`;okKBF00KokKBDonniV?o_^ISo
kkVGoo2iU_o`^I@2okfV`P;oj;BM0_oY]9/01_oZ/i[ol;NCoo2gToo`]i;olKN@oo6gS`;ol[J>00Go
l[J=onnnWOlIC<Ko6Dc6omncZ@02on2cZ007on6cYoo_]Y?ol;JAoo2fTOo`]Y3olKJ?oo6fSP02oo>j
T004oo>jSood^Xkom;V=ooBiS0?o_j_60_o]^9T2onjgV005onjgUooc^Xoom;V>ooBiS?od^H/00_oe
^HX01ooe^HWol/2Joo?0VOoc`9SodFX0obmSe?oT^Z/00_oU^ZX02?oV^ZWolk^Boo>kTOoc^i7om;^@
ooBkS_oe_i?omKnB0_of_Y401?l0003om[j>omk9a?oObL<3olRjc@06oo30Woo``9kol<2Noo70WOoa
`9comL6F0_of`I@00oof`I?om/6Bonk9[@02onk9[006ono9Zom=S>_o002;o`00RonE[NOoj<Ne0_oX
ak@01?oYb;Coooooooooooooool2o`0000Sooooo0_l0000Zooooo`00<_ooool2o`0000Gooooo00?o
_KoKof^Ulom[YO<00_lEH]P2ooooo`;o`jo600GodKJnomFf^ooE][_of;NiomFm`P02omRm_`03omZm
_OnM^N_o8EgB00;o]:G90ooG/k@00ooJ/k;ogkV`on6i[P02on>i[003onBiZ_oH`L?ofL7100;oK87G
0ooB[[D00ooD[k?ohkFWonFfY@02onJfX`0:onNeXOoX^jOoj;^WonVkYOoY^Z?o001YokZT`onlY/?o
h[>Uon>cY0;oi;>R00CoiK>PonbgVoo/]i_ok;NI0_o]]iP00oo]]YOok[JEonRoZP02om^`[0;og;2Z
0_o[]IT01Oo/]IOokKBFonfdU_o]]9Cok[BC00;okkVG00Ool;VFoo2iU?oa^I?o_JK2okfU`OoX]9go
jKBK00;oj[>J00Gojk>Hoo2gT_o`]i;olKN@oo6gS`02oo:fSP04oo:fSOob]Xcol;jLoaU<aP;oh;>X
0_oQ/jL01_o_]Y?ol;JAoo2fT?o`]Y3olKJ?oo6fSP;olkZ@00OolkZ?ooBjS_od^Hgom;V<ooFiRono
ZlKo_j_500;okKRI00Ook[NHonjgUoo^]iOokkNFooBiS_od^Hcom;V;00;omKV:00OomKV9oo?0VOoc
`9Woll2HooC0UolUG=7oi;Z[00;oiKZZ00ooi[ZYoo>kT_oc^i7olk^AooBkT?od^hkomK^=ooFoT_of
_Y7om[j?o`000?of_Xkomkj=omo9`ooPbL800oo8^/d01Oo``9kolL2Moo70WOoa`9col/2K00;om/6D
0_of`I82onk9[0;oklV[00?ol<VYodf<jol008/00_nC[>L00ooXakCojLRdonW8]004ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo0000:Oooool002oooooo0ol00005ooooo`;oc;_9
00Ko_KoKoknofOno_mWoGIkboaERf?n@W=`3ol>_aP?oeKJk00_of;NiomRm_ooH_Koof;foomZm_OoL
_[_oWKS/o`19b?ndYLWo]ZO:omNc]002omZc/P03ombd/?oQ^JkohkV/00;oi;VZ00?oiKVXomW1`OoK
`Kl00_m/PML00ooB[[Goe:ncomB_/`02onFfY@08onJfXooW]J7oikFQonReWooX^jOojK^UonVjXooZ
^Z82okbV``;ohk>T0_oT/j801?oU/j3ok;NKonbgVoo/]iT2onfgV005onffUoo^]YGojKnYobaFb_oK
/:`00_oL/:X01?oM/:Sok;FGonbeUoo]]9H2onfdU006onjdToo_^IOokkVGoo2iU_o`^IColKVC0_nm
YL42onVdV`;oj[>J00Kojk>Hoo2gT_o`]i;olKN@oo6gSoob]Xh2oo:fS@05oo:fS?oc]X_o3D?1o`e3
`OoP/jP00_oQ/jL01?oR/jGol;JAoo2fT?o`]Y02oo6fSP07oo:fS?oc^XoolkZ?ooBjS_od^Hgom;V<
ooFiR`03okn[a@;ok[NH0_o^]iL01Oo_]iKom;V<ooBiS?od^H_omKV:00;omKV900Gom[R7oo?0V?oc
`9Som<2Goa]FcP02onFjZP;oi[ZY00ooi[^Xoo>kTOod^i3om;^@ooBkS_oe^hgomK^<ooJnTOof_Xoo
0000ooJnS_og_Xgomkj<on39`_l007h00oo8^/d2oo70W@04oo70W?ob`9_om/6DooK1T`;om/6B00Co
ml6Aonk9[?o_bJ_oklVZ0_o`bJT00onJ;@3oTjcWoi6/j003onW8]003on[8/ooooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Yooooo`00;?ooool4o`0000Kooooo
0oo<^lT02?o@^lKo_koIol;0f?o2`=SoCIKao`18b?n@W=co`jo60_o6/<@01OoE][_of;NiomRg^OoJ
^;Kof;fo00;of[fm00Gog;jkomfm^Ol0=;_o03BkokJWbP03omZc/P03ombd/?oS^JcohkV/00;oi;VZ
00?oiKVXonJhY_oV^:H00_mTOML3omB_/`04omN`/_oV]Z?oi[JSonNeX@;oj;FO00Woj;FNonVkYOoY
^Z?oj[ZRo`00F?nlY/?o_:K2on>cY?oT/j800_oU/j001?oV/ikok;NIonbgVOo]]iP2onffU`03onjf
UOo^]YCojKnY00;og;2Z0_oM/:P2onbeU`05onfdU_o]]9CokKBDonjdToo^]9800_o`^IH01?o`^ICo
lKVCoo6hT_nmYL42onVdV`04onZcV_o[/iSojk>Hon^cU`;olKN@00SolKN?oo:fS_ob]Xgol[J=oo:f
S?oc]X_olkJ9o`e3`@;ohK>W0_oR/jD00oo`]Y7ol;J@oo6fS`02oo6fSP04oo:fS?ob]H_om;Z>ooBj
SP;om;V<00ComKV;ooFiROnoZlGo_j[50_o^]iP00oo^]iOokkNFonngUP02ooBiS006ooBiRooe^H[o
mKV9ooJiR?of^8Oom[R60_od`9L01?od_iKo6eK>onFjZ_oV^ZT2onJkZ003oo>kTOod^i3om;^>00;o
mK^=00ComK^<ooJkRoof_Xoo00000_og_Xd00oog_Xcon;j;on79`@03olRjc@07oo70WOoa`9colL2L
oo;0Voob`I[om/6CooK1TP02ooO1T@03ooO1T?o_bJ_oklVZ00;ol<VY00SolLVXoiX]0?nA[>SoTJcX
onW8]?oYb;?oj/Rcon_9/PCooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000Y
ooooo`00:_ooool2o`0000Wooooo0_o7]LT01Oo<^lWod;_6om2ka_oB_<Co`/3H00;oa<3G0_l0;;<0
1On<Vmgoa[34olVa`oo9/L?of;Ni00;of[Rf00Oog;RdomZm_OoL_[_og;jkomfm^OnK^>co03Bk00;o
^:S900Kof[>bombd/?oL];3og[B^on>i[?oT^JX2onFiZ0;oi[RV00CoikRTofAmeomTOMOoe:nc0_oG
/;82onJfX`04onNeXOoX]Iooj;FOonReWP;ojKZS00Coj[ZRon^jX?nlY/;o_:K20_oT/j82onFcX005
onJcW_o/]iWok;NIonfgV?o]]YL00_o^]YD01?o^]YCokkJCobaFb_oL/:X2omf`Z004omj`Yoo]]9Ko
kKBFonfdU0;ok[BC00Kok[BBonndTOo`^ICol;VDoo6iTooa^982okjU`0;oj[>J0_o[/iP01_o[/iOo
k;>Foo6gSooa]hool[J>oo:fS@;ol[J<00GolkJ;oo>fROl2>[co0SZlon6cY`02on:cY@04on>cY?o`
]Y3olKJ?oo6fSP;ol[J<00?ol[F;ooBjS_od^Xh00_od^H`00ooe^H_omKV9oknZa@02oknZa@;ok[NG
0_o_]iH02?o`]i?om;V;ooBiRooe^H[omKV9ooJiR?of^8Oom[R60_od`9L01?od_iCo44k:onJjZOoV
^ZT2onJkZ003onNkYood^i3om;^>00;omK^=00ComK^<ooJkRoof_Xoo00000_og_Xd01?og_Xcon;j;
on;:`?oRb/03olRjc@04oo70W?ob`9_ol/6Joo;1VP;om/6B0_og`I400oog`I3on<6?oo39Z@02oo39
Z@03oo79Z?m<S>_o001n00;oSj_Y0_oZb;<00oo[bK;oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo0000:Oooool002Oooooo0ol00003ooooo`;oYKcY0_mLWO83oooo
o`05ojn]eoo7]LWob[K6olZfa_o@^lH00_oB_<@01_oE_<;oa<3GolK0eOo6`=Go02bcohNJgP?obK73
0ooJ^;H00ooL^;Cog[Rbombn^`02omfm^@04omjm]ol07j_o01n[okRXb@;og;B`0_oN]:h00ooO]:co
i;VZonFiZ003onJhYP03onNhY?mJN=OoFWSG00?oek2b00Cof;2`onNeXOoW]J7oj;FO0_oX]Ih02OoY
]Icoj[ZRonZjX_o[^Z3o[4L0okbV`_nmYL7oi;>RonFcX002onJcWP05onNbWOo]]iSokKNHonffUoo^
]YD00_o^]Y@01?o_]Y?okkJBomb`Z_oM/:P2omj`Y`;okKBF00GokKBDonjdToo^]9;ok[BBonndT@02
oo2iU004oo6iTooa^9;ol[RAokjU`0;oj[>J00Gojk>Hon^cUoo[/iOok;>Foo6gS`02oo:fSP07oo:f
SOob]Xcol[J<oo>fRooc]XWolkJ8o`8j_002on:cY@;ohk>T00?ol;J@oo6fSooa]Xh00_ob]X`01?ob
]H_ol[F:ooBiSOod^H`2ooFiR`04ooFiROof^HSo_j[5oknZa@;ok[NG00CokkNFonngU?o`]i?om;V;
0_oe^HX02ooe^HWom[V8ooJhQoof^8Kom[R5ooBoU_od_iComKnCoa1>b_oV^ZWoi[^X00;oik^W00?o
j;^VooBkS_oe^hd00_oe^h`00oof^h_om[j>o`000002ooNnS@06ooNnS?oh_X_on;j:on?:_ol0073o
b;[=0_o8^lh00oob`9_ol/6Joo;1VP02ooK1TP;oml6A00Coml6@ooS1Sooh`Hkol<VY0_oabJP2odb<
j`?oSZ_Y0oo[bK84ooooo`;o00000oooool01?l0003oooooooooool0000Yooooo`009Oooool2o`00
0003ooooool0003ooooo00;ooooo0_o2_]L2ojFlj@05odRBl?lDKMkoLYSXog:Hj?n_[ML00oo:]/H0
1?o=]lGod[c4omFl`_oE_<83olK0e@04olO1e?nM8@3oQi[NolVa``;oc;;100Kof[Rfombh]?oL^;Co
g[Rbomnh/?oM_KT2omjm]`05omnm]Ol07j_o^JW9okVYbOoL];000_oN]:h00ooO]:coiKVXonFiZ002
onJhYP;oikRT00Coj;RSoeYheomJN=Ooek2b0_oH/;000ooI/:ooj;FOonReW`02onReWP05onVeW?oZ
]9_ojkZPon^jX?o/^Yl00_nmYL42onFcX0;oi[>N00Goik:MonfgV?o]]iSokKJGonjfU@02onjfU004
onnfToo_]Y;ogK2Xomf`Z0;og[2W00Cogk2UonfdU?o]]9Cok[BC0_o^]9801_o_]97okkB@oo6iTooa
^I?olKRBoo:hT@;o_ZFo0_o[/iP2on^cU`06onbcU_o//iCol[J>oo:fS_ob]Xgol[J<0_oc]X/01Ooc
]XWolkJ8o`0a]ol0<KOoh[>U00;ohk>T00Coi;:Soo6fSooa]Xkol[J<0_ob]H/01?ob]H[olkF9ooBi
S?oe^H/2ooFiR@04ooJiR?noZ/Go_j[5oknZa@;okkNF00?okkNDoo2gToo`]i800_oe^HX02?oe^HWo
m[V8ooJhQoof^8Kom[R5ooNhQ?od_iComKnC0_l6AlH01ooV^jSoik^WonNkYooX^jKom;^>ooFkSOoe
^h`00_of^h/02Oof^hWo0000ooNnSOog_Xgomkj<ooRnRooh_X[ohlZoon?:_P03olRkcP04oo;0Voob
`I[oll6Ioo?1V@?oml6A00Goml6@ooS1Sooh`Hkol<VYoo79Z002oo79Y`04odb;jol007OoSZ_YohbZ
jP?ojlVb00Kok<Vboooooooooooo0000ooooool00004ooooo`;o0000:_ooool002;ooooo0ol00005
ooooo`;oa;[A00Co`[kGolBneOo4_]GoYKcY0_nT^nX01OlDKMkoII;Xok2^e_n`[]Kob[K600;ocKO5
0ooE_<801_oG_;ooa/3EolO1e?o7`MCobL7Coh>Hg`?oc;;100Goc[>oombh]?oN^;;og[Rbomnh/003
omjm]`04omnm]OoQ_K?o00VIokVYb@;og[B^0_oO]:`01OoP]:[oiKVXonJhY_oV^:KoikRT00;oj;RS
00?oj;RQoe5ce_oH/;000_oH/;001?oI/:ooj;FOonReWooX]Ih2onVeW006onZdVoo[^Z3ojkZPonbj
WonhD`3o_JG10_oU/j001?oV/ikoik:MonNbWOoX/Y`2onffU`08onjfUOo^]YCokkJConnfToo_]Y;o
5TK2omf`Z?oN/:L2omn`Y@;okKBD00Gok[BConjdT_o_]97okkBAonndT002oo6iT`04oo6hT_ob^97o
af@0okjU_`;ojk>H00Gojk>GonbcU_o//iKok;>Doo:fSP02oo:fS@07oo:fS?oc]X_olkJ9oo>fROoc
]XSom;J8o`0a]`02on>cY0;oi;:S0_oa]Xh02?ob]Xcol[F;oo:eRoob]H[olkF9ooBiS?oe^H_omKV9
0oof^HP02?noZ/Go_j[4onngU_o_]iKokkNDoo2gToo`]i;omKV:0_oe^HT2ooJhQ`04ooJhQ_of^8Go
mkR4ooNhP`;omKnC00?o1TO6onNkYooW^jL00_oX^jH2ooFkS@03ooFkS?of^h_om[^:00;o000000So
mkj=ooNnS?og_Xcon;j;ooRnR_oh_XWohlZno`00I0;ob;_>0_ob`IX2oo?1V@06ooC1V?og`I7oml6@
ooO1T?oh`Hoon<6>0_oabJP2oo79Y`04oo;9Yom<Rn_o001gohbZjP?ojlVb00?ok<Vbooooooooool0
0_ooool00ol0003oooooooooo`0^ooooo`008?ooool2o`0000Oooooo00Go^;GGolBjdOo7^lkoak_>
olBne@02olNod`03ojBkj_nS^n[o6gST00;oEhcX00?o/:kFok6_e_o=]lD00_o@^<<01OoE_<;oekbo
omNl_ooI_;goal7D00;obL7C00?o063Foh>Hgoo<//400_o>/kl2omjh/P;ogkR`00Koh;R^omjm]ooO
_KGogkfeon6m/ol008P2ok^[b@04omjd[_oO]:coh;BZon2dZP;ohKBY00Goi[RVonNhY?oX^:?oj;RS
onRhX@02odU]e004omR`/?oI/:oofK2_omZa[@;oj;FN0_oY]I`01OoZ]9_oj[BJonbjWoo/^Yook;VM
00;o_ZK00_oV/ih2onNbW@06onRbW?o]]YOokKJGonjfUOo^]YCokkJC0_o_]Y800oo`]I7og[2Womj`
Y`02omn`Y@04on2`Y?o]]9Cok[BConjdTP;okkBA00SokkB@onncS_oa^9;olKRBoo:hTOob^93o_ZFo
oknT_P;ojk>G00Cok;>FonbcU?o//iCokK>C0_ob]Xd00oob]XcolkJ;oo>fR@02oo>fR004ooBfR?l0
:K;o036gon>cY0;oi;:S0_oa]Xh02?ob]Xcol[F;oo:eR_ob]H[olkF9oo>eR?oe^H_omKV90_of^HP0
1Oof^HOo_j[4oknZa?noZ/CokkND00;ol;NC00Col;NBoo6gTOoe^HWom[V80_of^8L00oof^8Kom[R5
ooNhQ002ooNhP`06ooFoToof_i;o0432onNkYooX^jKoj;^U0_oe^hd3o`000004ooJkROl0003omkj=
ooNnS0;on;j;00Son;j:ooRnROoh_XSoi<Zno`00I?o8^lkob;c?oo;1VP;oll6I00?om<6HooC1Uoog
`I000_oh`Hl00ooh`Hkon<6=oo79Z002oo79Y`03oo;9YoobbJKoXS@000;oRZ[Z00CojlVbonc9/_o/
bK;okLZa1?ooool00ol0003oooooooooo`0]ooooo`007Oooool4o`0000;ooooo00?oVKW^og:Wl_mb
XNl00onI[ND01_nh]MOo^[KFolNkc_o7^lkob[_=olNod`;obKoA0_nS^nX01OlKN>CoEhcXoeN<j?na
[mKo/[3F00;od;S300Kod[S1omNl_ooI_;gofKbmomZl^oo9`M<2ol[1d@07o`1Pe_mnU^3oOYKPoljc
_oo@];kog[Rbomnh/002on2h[P;ohKR]0_oQ_K<00ooR_;;o0028ok^[b@02omnd[0;oh;BZ0_oQ]:T2
onNhY005onRhXooX^:7oj;RQonVgX?m9KM@00_oI/:l2omZa[@;oj;FN00GojKFLonZdVooZ]9_oj[BJ
on^dV@02onbiW@05ol9M0?nnY/3oi[>NonJcW_oW/Yd00_oX/Y`01OoX/Y[ok[JEonjfUOo^]YCokkJC
00;okkJB00Col;FAo``n_OoN/:Oogk2U0_oP/:@2onjdT`06onjdT_o_]97okkB@onndT?o_/hkol;>=
0_ob^9400oob^93o_jBnoknT_P02on^cU`05onbcU_o//iCok;>DonfcToob]Xd00_ob]X`02ooc]X_o
lkJ9oo>fR?oc]XSom;J8ooBeQol0:K;ohk>TonBbXooT/Z7olKJ>00;ol[J<00Ool[F;oo:eR_ob]H[o
lkF9oo>eR?oc]HOomKV900;om[V800Gom[V7ooJiQ_noZ/Co`:[4onngU002oo2gT`05oo2gT_oa]i7o
lKN@ooJiR?of^8L00_of^8H01oof^8GomkR4ooNhPoog^8?omKnCooJoT_l0>Kh00_oX^jH3o`000009
ooFkS?of^h_om[^:ooJkROog^hSo0000ooNnS?oh_X_on;j:00;on;j900?on;j8ooVnQol006@00_o8
_<l3oo?1V@04ooC1V?od`IOoml6@ooS1S`;on<6>00Son<6=ooW1SOoabJOolLVWoo;9YoobbJKoC8_[
o`00K`;oR:W[00?ok<Vbonc:/Oo]b[401Oooool00ol0003oooooooooo`0/ooooo`007?ooool2o`00
00;ooooo0ond_^801_nI^NkoUKO_ofBQl_mbXNooVJgUoiN/iP?o^[KF00Koak_>olZkcOo<_<_oc;c;
olVodOo;_m02oj:kj`03o`AYfom9Q>Ko/[3F00;o/[3F00Kod;S3om:h`OoD^Kooe;VoomVl_OoJ_;/2
om^l^P04ol[1dOo<`M3oNICRogVDhP;od;Bn00CodKBmomnh/?oP^:koh;R^0_oQ^:d01?oR^:_oh[bb
on:l/_l007L2okb[b003omnd[?oP]:[oh;BZ00;ohKBY00Coh[BWonRhXooX^:?oj;RQ0_oY]j02ocmW
dP04omV`[ooJ/Jgof[6]omba[0;ojKFL00Coj[BKonZdV_oZ]9[ojkBI0_o/^Id00oo]^Ico_jFooknU
_`02onNbW@;oj;:L00Koj;:JonVbVOo^]YCok[JDonnfToo_]Y82oo2eT@03oo2eT?oO/:Gogk2U00;o
h;2T00Cok[BConjdT_o^]9;okkBA0_o_]9000oo_/hkol;>=oo:hT@02oo:hT003oo:hSonoY;ko_jBm
00;ok;>F00Cok;>DonfcToo]/i?okK>B0_ob]X`00ooc]X_olkJ9oo>fR002ooBfR006ooBeQol08Jco
i;:SonBbXooT/Z7oiK:P0_ob]X`01oob]H_ol[F:oo>eROoc]HWolkF8oo>eQooe^HT00_of^HP00oof
^HOom[V6ol2Za002ol2Za008oo2gToo`]i;ol;NBoo6gTOoa]i3om[V8ooJhQoof^8H2ooJhQ@05ooNh
Q?og^8?omkR3ooNhP_of_i800ol000000ooX^jGojK^UonZlY002ooJkR`07ooJkR_of^hWomk^8ooNk
R?l0003on;j;ooRnRP02ooRnR@03ooRnR?oi_XOonKj700?ob;c?00Koll6IooC1V?od`ISom<6GooG1
U_oh`Hl2ooS1SP04ooS1SOoi`HgonL6<oo;9Y`?ol/VV00CoBh_[ohNYk?n7ZNcoQjW/0_o]b[400oo]
bk7oooooooooo`02ooooo`03o`000?oooooooooo02cooooo000Looooo`03o`000?oooooo];[N00;o
^kgK00?o];kRokJohOnf_n400_nE]nl01OmTXO;oII__oiN/i_nG[>Ko^[KF00;o_;OE00?ob[_=olbl
boo<_</00_o;_m001_o<`<koXK[[oj6jjol04YOo>WcTok:`eP;o];7F00?od[S1omBi_ooD^Kl00_oJ
_;/2om^l^P03ombl^?o<`M3ocL7?00;oNICR00Cod;Bnom6d_OoP^:koh;R^0ooQ^:d01_oR^:_oh[bb
on:l/_oS_;3o001gokb[b0;o_J[70_oQ]:T2on:dY`03on>dYOoX^:?oj;RQ00;ojKNP00Coj[NOocmW
d_oJ/Jgof[6]0_oL/J`2onVeW005onZdVooZ]9[oj[BJon^dVOo[]9L00_o]^I`01Oo9IP3o_jFoonNb
WOoW/Ygoj;:L00;oj;:J00KojK:IonjfU?o^]YCokkJConnfT_o`]I42oo2eT005o`8g^OoO/:Goh;2T
on2`Y?oQ/:800_o^]9801oo_]97okkB@onncS_o_/hkol;>=oo2cS?ob^9000_ob^8l2oknT_@;ok;>F
00Gok;>DonfcToo]/i?okK>Boo:fS002oo>fR`03oo>fROoc]XSom;J800;om;F700Kom;F6o`0Q[?oT
/Z?oi;:QonFbX?ob]X`2oo:eR`06oo:eR_oc]HWolkF8oo>eR?oc]HOom;F60_of^HP00oof^HOom[V6
ooJhQ@02ol2Za008oo2gToo`]i;ol;NBoo6gTOoa]i3ol[N?ooJhQoof^8H2ooJhQ@03ooNhQ?og^8?o
000000;o000000?om[nAo`0b^OoX^jD00_oY^jD00ooZ_:Com[^;ooJkR`02ooJkR@;omk^800?omk^7
o`000?oh_XX00_oh_XT01Ooh_XSonKj7ooVnQooUbkcob;c?00;ob;g?0_od`IP01?od`IOomL6FooG1
U_oh`Hh2ooS1S@03ooW1SOoi`Hcol/VW00?ol/VV00Gol/ZVo`00KOn7ZNcoQJW/ong:/@03ong;/@?o
oooo0_l0000]ooooo`005?ooool2o`0000Kooooo00Go0000oj>fi_nd^]ko];[Nok^mf`02okfnfP05
okJohOng_n3oTKK`oi6fl?mEVO400_mGU>h01OnD[>Oo_;OEokjhe?nn^=Coc;c;00;oc[c900Wobko@
olc0c_o>`<goc/3=oinjjol04YOo>WcTokBae_ne/]H00ooD^Kl01ooE^Kgofkbjom^l^_oK_;[og;bh
omfl]_o=`Ll00_mdT^42om6d_@04om>d^ooP^:kohKR]on6h[@;oh[R[00CohkNYon:l/_oS_;3ohkb_
0onmZ/L2on6dZ@;oh[BW00CohkBUonRhXOoX^:7ojKNP0_oZ]il2ocMQc`04omZa[OoL/Jcog;6/omf`
ZP;oj[BK00Goj[BJon^dVOo[]9WojkBGonbdUP02onfiV`;o`:Fn0_oX/Y`2onRbVP06onVbVOoY/YSo
kkJConnfToo_]Y;ol;FA0_o`]I000oo`]Hooh;2Ton2`Y002on6`XP04onjdT_o_]97okkBAonndT0;o
kk>>00?ol;>=oo2cS?oa/h`00_ob^8l01_oc^8ko_jBmol2T_?o//iKok;>DonfcT`;okK>B00Ook[>@
oo>fRooc]X_olkJ9oo>fR?od]XSom;F700;om;F600Go01VVonBbXOoU/Z3oiK:PonJbW`02oo:eR`0;
oo:eR_oc]HWolkF8oo>eR?oc]HOom;F6ooBeQOof^HSom[V7ooJiQ_of^8D00oo0Z/@02?o`]i;olKNA
oo6gTOoa]i3ol[N?ooJhQoof^8Kom[R50ol000000oog^8?omkR2ooRhP@02ooJoT007o`0b^OoY^jGo
jK^UonZlY?o[_:?om[^:ooJkR@03ooNkR003ooNkQol0003on;j:00;on;j900Con;j8ooVnQooi_XOo
iL^l0oo8_Ll00ood`ISom<6GooC1U`02ooG1UP06ooS1S_oh`Hgon<6=ooW1SOoi`HconL:;0oobbJH0
1OobbZKollZVo`00KOn5ZNcokLZa00?okL^a1Oooool00ol0003oooooooooo`0Zooooo`004oooool0
1?l0003oooooooooool00005ooooo`03o`000?nS]^Ko][_M00;o][_M00Go_KkJoknnfOno_]Wo]koP
okRoh002ohfdl@05odFAkom8SNcoTZ_Woi:[ionn^=@00_o0^=801?o>_<Wod;c7om2laoo<`<h2olk0
c@03olo0bonN^^co002300?o]K;F00Goe;VoomFi_OoE^KgoekVlom^l^P02ombl^003omfl]_o>`Lko
c/7>00;oM9;Q0_oC];/2omBd^P09on6h[OoR^:_ohkNYon>gZOoT]jSohkb`on>l[ol006Ko_J[700;o
_Z_600GohKBYon:dYooS]:GohkBUonBdY002onVgX004onZgWooZ]igoj[NMocMQc`;og;6/0_oM/:X2
onZdV`05onZdV_o[]9WojkBGon^dUoo/]9H00_o]^I/01Oo9IP3o`:FnonRbW?oX/Ycoj;:J00;ojK:I
00KojK:HonnfToo_]Y;okkJBoo2eTOo`]I02oo2eS`05o`8g^OoP/:CohK2Ron6`X_oR[j400_o_]940
1oo_]93okk>>oo2cSOo`/hgol;><oo6cS?ob^8l00_oc^8h2ol2T_0;ok;>D00GokK>ConfcT_o]/i;o
k[>@oo>fR`02oo>fR@03oo>fR?od]XSom;F700;om;F600KomKF4o`0IY_oU/Z3oiK:PonJbWoob]H/2
oo:eRP06oo>eROoc]HSolkF7oo>eQood]HKom;F50_of^HL00oof^HKom[R5ooNhQ@02ol2Za005oo2g
T_oa]i7olKNAoo6gT?ob]hl00ol000000oog^8ComkR3ooNhP`02ooNhPP05ooRhPOof_i3om[n@ooNo
Sol0:k@00_oZ_:@00oo[_:?om[^:ooJkR@03ooNkR004ooNkQoog^hKo0000ooRnR@;on;j80_oi_XL0
0ooi_XKoi/^lolRmc`02olRmd006ooC1Uooe`IKomL6FooG1U_of`YCon<6=0_oi`Hd00ooi`HconL:;
ooW2R`02oo;9YP03oo;:Y_ocbZKoBh_[00;oQ:W]0oo]bk400oo^c;3oooooooooo`02ooooo`03o`00
0?oooooooooo02[ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
XkKVokJkg@02okRkg004oknnfOo1_]Oo`KkGokRoh0;o^;oO00CoRK?aocB7k?liQ>[oTZ_W0oo0^=83
om2la`04om6laOo>`<gocl3;olo0b`;oWKW/00Go02FUokFbe_nf/]Go][;EomFi_@02omNi_007omRi
^_oL_;SogKbfomfl]_oN^kCoc/7>olo1c002ofn?h@03om>d^ooD];[oe;Bj00;oh[R[0_oS]jT01?oT
]jSoiKNVon>l[ooT_:d3okj[aP;oh[BW00?ohkBUonBdY?oT]:@00_oY]j000ooZ]iooj[NMonZgW@02
obmKc@04omba[?oM/:[ogK2Zomf`Z0;oj[BJ00GojkBIon^dUoo[]9Ook;BFonbdU@02onjiVP05ol2U
__o1YKgoj;:JonRbV_oY/YT00_oY/YP01_oZ/YKokkJBonnfT_o`]I7ol;F@oo2eS`;olKF>00Goh;2T
on6`X_oR[j7ohZnQonndT@02onndT007onncS_o`/hgol;><oo2cS?oa/hcolK>;oo>hSP02oo>hS@05
ol2T_?o//iCok;>DonfcToo]/i800_o^/i002oo^/hoolkJ9oo>fR?oc]XSom;J8ooBeQood]HKom;F5
ooFeQ?l04J7oiK:P00;oi[:O00Koik:Noo:eR_ob]H[olkF9oo>eR?oc]HL2ooBeQP07ooBeQOof^HOo
m[V6ooJiQ_of^8GomkR5ol2Za002ol6Z``08oo6gTOl0003o0000o`000?ob]hkolkN=ooJhQOog^8@2
ooNhP`;omkR200Kon;R1ooRhP?of_i3omkn?o`0T/?oZ_:@2on^lX`03on^lX_of^hWomk^800;omk^8
0_og^hH00ooh^hGo0000ooRnR002ooVnQ`?onKj600Co[440olRmd?o9_]3obKk@0_oe`IH01_of`YGo
m/:DooS1SOoi`HgonL6<ooW2S0;onL:;00Con/:;oo;:Y_ocbZKollZV0_m;Rn/2oh>Yk@04ong;/Oo^
c;3ok/b`onk</0Cooooo00?o0000ooooooooool0:Oooool001?ooooo00Co0000oooooooooooo0000
1?ooool01?l0003oooooooooooooool2oj>fiP03okRkg?ni_=_o`KkG00;o`koF00So^;oOokW0goni
`=ooQ;7bob9li_lYNnKoT:_Xol2hdP;o`[WB00God;c7om6laOoA_<Godkc4olo0b`02om2obP05oifi
k?nL^Ngo2UkFokJbeOng/]@00ooG^K`00ooH^K[ogKbfomfl]P02omjk]004omnk/oo?`LcoJXcQofZ<
h@?oe;Bj00?oeKBhon:hZooS]jT00_oT]jP01OoU]jKoi;b]onBl[OoU^jco_Z_600;o_j_500Goh[BW
on>dYOoT]:Coi;BTonBdX`02onZgW`04onZgWOo[]icojkNLobmKc@;ogK2Z0_oM/:P2onZdVP07on^d
VOo[]9Ook;BFonbdU_o/]9GokKBDonjiV@02ol6U_@;oj;:J00GojK:IonVbV?oY/YSoj[:FonnfTP02
oo2eT@04oo2eT?o`]HoolKF>oo6eS@;ohK2R0_oR[j401OoS[iookkB@onndT?o_/hkol;>=00;ol;><
00?olK><oo6cRooa/hX00_oc^8d2ol6T^`;okK>C00GokK>BonjcT?o^/i3ok[>?onncSP02oo>fR004
ooBfR?od]HOom;F6ooBeQ@;omKF400Go016QonJbWooV/Yooik:Noo:eRP02oo>eR@06oo>eR?oc]HOo
m;F6ooBeQ_od]HGomKF40_of^HH01?of^8GomkR5ol6Z`oo1Z/<2o`000007oo6gT?ob]hool[N?oo:g
S_oc]hgom[R5ooNhQ002ooNhP`08ooNhP_oh^87on;R1ooRhP?oh^7oomkn?ooNoS_l09;02on^lX`05
on^lX_o/_:7omk^8ooNkR?og^hL00_og^hH00ooh^hGo0000ooRnR002ooVnQ`?onKj600ConKj5olVn
d?o9_]3obKk@0_oe`IH01_of`YGom/:DooK2U?oi`HgonL6<ooW2S0;onL:;00?on/:;oo;:Y_ocbZH0
0_ocbZH01?m;Rn_o001Woh:Yk_n2ZNh3onk</0Gooooo00?o0000ooooooooool0:?ooool001?ooooo
00Co0000oooooooooooo00001?ooool2o`0000;ooooo0onR]^L00oni_=_o^kcJol>oeP02olBoe@08
okW0gonj`=ko^/3Noh2_lolALN3o:G_VohjZjOo2^M82ol>id005om6laOoC_<Codkc4omBl`_o@_lX0
0_oB_lP00onL^NgoVkW]okNbe002okNbe005omNi_?oH^K[of;VjomVh^?oM_;H00_oN^k@00ooO^k?o
h;^aom31b`02ofZ<h@06omBd^_oE];SoeKBhomJd]ooS]jWoi;NX0_oU]jH01_oU]jGoi;b]onFk[?oV
^j_o_j_5ol2Za0;ohkBU00Coi;BTonBdXooT]:?oiK>Q0_oZ]id01Oo[]icojkNKobQEb_lXEL[ogK2Z
00;ogK2X00Gog[2Won^dVOo[]9WojkBGonbdUP02onbdU@05onfdU?o]/i?ok[VHol6U_Oo2YK/00_oY
/YT01OoY/YSoj[:FonZbU_o[/YGol;FA00;ol;F@00Kol;F?oo6eS_oa]HgolKF=on6`X_oR[j42on>_
W`05onndT?o_/hkokk>>oo2cSOo`/h`00_oa/h`00ooa/h_olK>:oo>hS@02oo>hS005ol6T^oo]/i?o
kK>ConfcT_o^/i000_o^/hl01oo_/hkolkJ8ooBfR?od]XSom;F7ooBeQ_od]HD00_oe]H@01Ol04J7o
i[:OonJbWooW/Ykoik>L00;olkF900?olkF8oo>eQood]HH00_od]HD01?oe]HCom[V6ooJhQOof^8D3
o`0000;o`J[300OolKN@oo:gSoob]hool[N>oo>gSOoc]hcomkR400;omkR300ComkR2ooRhPOoh^87o
n;R00_oh^7l00oog_hko01f[on^lX`02on^lXP05onblXOog^hSomk^8ooNkQoog^hH00_oh^hD01?oh
^hCo0000ooVnQooi_XL3ooVnQP04ooVnQOoj_XGobKk@olVod@;omL6F00Gom/:EooK2U?of`YComl:C
ooW1S003ooW2R`03oo[2Rooj`X[ollZV00;ollZV00?oll^VodZ;jol006L00_n1ZNh2onk</003ono=
/?oooooooooo00;ooooo0_l0000Yooooo`004oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00;ooooo0onR]^L01_nk_=[o_;cJokblf_o4_mGoa[oDok[0gP;o^l3N00?oNjgco`1U
f?n<ZNT00_n<ZNT00oo3^M3oaKW?om>la002omBl`P?od[o800Codko7oi^ikOnJ^>go]k;D0_nh/]<0
1OoH^K[ofKRhomVh^?oJ^;Oog[^d00;ogk^c00Coh;^aon6j/?oB`L[oIHSP0ooE];P01?oF];Ooi;NX
onBgZ?oU]jH2onFgY@03onJfY?oU^jcoi[^[00?o`:[40_oT]:@2onBdX`07onFcXOoZ]igoj[NMon^g
W?o[]i_ok;JJobQEbP02omf`Z0;og[2W0_o[]9T01oo[]9Ook;BFonbdUOo/]9GokKBDonfcToo^^IP0
0_o2YK/2onVbV@05onVbV?oZ/YKoj[:Fon^bUOo[/Y@00_o`]I001?o`]HoolKF>oo6eSOoa]H`2on:_
X@;ohjnO00Koi:nNonncS_o_/hkol;>=oo2cS?oa/h`2oo6cR`06oo6cR_ob/hWolkR<oo>hRoo1Y;_o
`ZBj0_o]/i801Oo^/i3ok[>?onjcSoo_/hkokk>=00;om;J800?om;F7ooBeQ_od]HD00_oe]H@01_oe
]H?o016QonNbW_oW/Ykoik>Loo>eR@;olkF800GolkF7ooBeQ_od]HGom;F5ooFeQ003o`000003ooNh
QOog^8?o`J[300;o`J[300?olKN@oo:gSoob]hh00_oc]hd01Ooc]hcolkN;ooNhPoog^8?omkR200;o
n;R100Con;R0ooRhOooh^7oon;Qn0_l07J/01oo[_:;ok;bQonblXOo]_J7omk^8ooNkQoog^hH00_oh
^hD01?oh^hCon;^3o`000?oi_XL3ooVnQP06ooVnQOoj_XGo[d@0olVodOo9`=7om/:E0oof`Y@00oog
`Y?onL:<ooW2R`02ooW2R`03oo[2Rooj`X[ollZV00;ollZV00?oll^Voo?;Yol006L00_n1Z^l01?o^
c;3oklf`ono=/?o_c[04ooooo`03o`000?oooooooooo02Oooooo000Dooooo`;o00001Oooool00ol0
003oooooooooo`03ooooo`?oX[KW00Ko_;cJokfmfOo6_mCoa[oDolNodonk`=h2ok_0g@;oMZ_d00Co
S:WYohZXjOo5^LooaKW?0ooD_<802?oF_<7od[o8om>oaooC_lOoe;o6oiZhkOnH^>ko^;;C0_ni/]80
1OoI^;Sof[RgomZh]ooK^;Gogk^c00;oh;^a00GohKZ`on:j[omPQMooH8GOomFd^002omJd]`03omNd
]OoT]jSoiKNV00;oiKNU00Koi[JTonJfXooV^j_oi[^Yol2Za?o1Z/<2onBdY004onBdXooU/j7oiK>Q
onJcX0;ojkNL00GojkNKonbfV_lQClOo8Do7omf`Z002omj`Y`05omn`Y_o[]9OojkBGonbdU_o/]9D0
0_o]]9@01Oo]/i?ok[>BonnhUoo2YK_oa:Fj00;ojK:H00Goj[:Fon^bUOo[/YGojk:Doo2eT002oo2e
S`06oo6eS_oa]HgolKF<oo:eS?oR[j7ohjnO0_oT[ih01Oo_/hkol;>=oo2cSOo`/hcolK><00;olK>;
00ColK>:oo:cROob/hSolkR;0_o2Y;X2onfcTP06onjcT?o^/hookk>>onncS_o_/hgom;J80_od]HL0
1_od]HKom;F5ooFeQ?oe]HComKF3o`09V`;oik:N00Koik>LonRcVooc]HSolkF8oo>eQood]HH3o`00
0004ooFePoof]H;omkR5ooNhQ@;omkR300Ko`J[3ol:[`oo2Zl?ol[N?oo:gS_oc]hd2oo>gS004oo>g
Roog^8?omkR3ooNhPP;on;R100Son;R0ooRhOooh^7oon;QnooNoSOl07J_ojkbRonblX@;okKfQ00?o
kKfPooNkQoog^hH00_oh^hD01?oh^hCon;^3ooVkPol00003ooVnQP04ooVnQOoj_XGon[j5olW0d@;o
bL7B0oof`Y@01?og`Y?oml>BooW2Rooi`X/2oo[2R`07oo[2R_oj`h[ollZVoo?:Y_ocbjKoll^WodZ:
j`02oh6Zk`05onk</?o_cK3oklf`ono>/?o`c[001?ooool00ol0003oooooooooo`0Vooooo`006ooo
ool00ol0003oooooooooo`04ooooo`;oX[KW0onm_MT01Oo6_mCoakoColRodOo8_m7o^l3M00;oL:Sd
00Ko04S4ohZXjOn:Z>WoaKW?olJic_oD_<82omJl`@06omNl_ooC_lOoe;o6omBoa_oE_lCoV;S^0oni
/]83omZh]`03om^h]OoP^k7oh;^a00;ohKZ`00Goh[Z_on>j[OmPQMooH8GOomJd]`02omNd]@;oiKNV
00KoiKNUonJfY?oV]ZCoi[JSonNfXOoV^jT3ol6Z``;oi;BS00CoiK>QonJcX?oV/j3oi[>O0_o[]i/0
0oo/]Y[ok;JIob5?a`02omj`Y`;ogk2V00Goh;2TonbdU_o/]9Kok;BEonfdU002onfcT`04onjcT_o^
/i7oa:FjolBU^P;ojK:H00Goj[:Fon^bUOo[/YGojk:DonbbT`02oo2eS`04oo6eS_oa]HgolKF<oo:e
S0;ohjnO0_oT[ih01_oU[igol;>=oo2cSOo`/hcolK><oo6cR`;olK>:00Kol[>9oo:cR?oc^8_om;R;
ol:T^_o3Y;T2onjcT006onjcSoo_/hkokk>>onncSOo`/hcom;F70_od]HH3ooFeQ003ooFePoof]H;o
ik:N00;oik>L00?oj;>Koo>eR?l000000_l00002ooBeQ@05ooFeQ?oe]H?om[F2ooNhQOog^8@00_og
^8<3ol:[``03oo:gSoob]hkolkN=00;olkN<00ColkN;ooBgR_og^8?omkR20_oh^8402?oh^83on;Qo
ooRhOooh^7komkn=o`0@X?o[_:;ok;bQ0_o]_J400oo]_J3omk^6ooNkQP02ooRkQ@04ooRkQ?oh^h?o
nK^3o`0000?onKj600?onKj5ooZnQOoj_XD00oo9`M83ooK2U004ooO3Toog`i;on<>BooW2R`;on/:;
00Con/::oo[3R_oj`h[oll^V0oocbjL00om9R^_oP:__oh2[k`02ono=/003ono>/?o`c[3ooooo00?o
oooo00?o0000ooooooooool09_ooool001[ooooo00?o0000ooooooooool01oooool01OnR]^Oo_KgI
oknmf?no_MSoakoC00;ob;oA00GobKo@okc0gOm`Z?CoL:Sdo`1>bP02ohNWj@03olJic_o7^Lgoe[c1
00;oekbo00Oof;bnomBoa_oE_lCoeKo4omJo`onG]nko^K;B00;o^K7B00Kof[Rgom^h]OoK^;Gog;Rd
on2k/OoQ^[02on:j[`03on>j[OmKPMkoFh7N00?oekBe00Cof;>conFgYOoU]jGoi[JT0_oV]Z<01?oW
]Z7oik^XonNkZ?o1Z/<2ol:Z`@05onBdXooU/j7oi[>PonJcX?oV/il00_o[]i/01Oo/]Y[ok;JIoaY9
a?lQClOog[2W00;ogk2V00Goh;2TonbdU_o/]9Kok;BEonfdU002onfcT`05onjcT_o^/i7okkRFolBU
^_o5YKT00_oZ/YH01Oo[/YGojk:Don^bU?o//Y?ol;F?00;olKF>00KolKF=oo6eS?ob]Hco02:/on>_
WooT[ih2onF_W@06oo2cSOo`/hcol;><oo6cS?oa/h_olK>:0_ob/hT00oob/hSol[>7ooBhR`02ol>T
^@;ok[>@00Kok[>?onncS_o_/hgokk>=oo2cS?od]HL2ooBeQP?omKF400ComKF3ooJeP_l00YKoik>L
0ol00002oo>eQ`05ooBeQ_od]HGom;F5ooFeQ?oe]H<00_of]H801Oog^8ComkR3ooNhPoog^8;o`Z_3
00;o`j_300?ol[N>oo>gSOoc]h`00_oc]h/01?od]h[omkR2ooNhP_oh^842ooRhP0;on;Qo00Kon;Qn
ooVhOOog_hgo012PonblXOo]_J42onfmX0;omk^60_oh^hD01_oh^hCon;^3ooVkPooi_XKo0000ooVn
QP;onKj50_oj_XD02_oj_hGobL7Bol[2d_o:`];om/:DooO2Toog`i?oml>BooS3T_oha982oo[2R`04
oo[2R_oj`h[on/>:oo?;YP?oll^W00Gol/bXoiDV0?n0Zo3oP:_`ono>/002oo3>/003oo3?/?oooooo
oooo00;ooooo00?o0000ooooooooool09Oooool001[ooooo0_l00009ooooo`05oj:fiono_MSo`;gG
ol2meoo8_m400_o9_m02okg0g0;oJJKd00Co04k:ohFVjOn5Y^WoakW=0_o8^L`02OoG_;oof;bnomVk
_?oI^kcoeKo4omJo`ooG_l;oUKO_okVadP02okZad@06om^h]OoL^;Cog;Rdomfg/_oQ^[3oh[Z_0_oS
^Zd01?oS^ZcoFh7Noe^1g_oG];D2omRc/`04omVc/_oU]jGoi[JTonJfX`;oikJQ00?oj;JPonNkZ?o2
Z/400_o2Z/42onFcX@04onJcX?oV/iooi[>OonNcW@;ok;JJ00Gok;JIonffV?lJBLCog[2Womn`YP02
on2`Y005on6`Xoo/]9Gok;BEonfdU?o]/i<00_o^/i801?o^/i7ok[>@olFU^Oo5YKT2onZbUP05on^b
UOo[/YCok;:ConbbToo//Y800_oa]Hh01?oa]HgolKF<oo:eS?ob]H/2onB_WP;oiJnM00KoiJnKoo2c
S?o`/hcolK><oo6cRooa/hX2oo:cR@03oo:cR?ob/hOolk>700;o`jBi00CoaJBhonjcSoo^/hookk>>
0_o_/hd01?o`/hcol;>;ooBeQ_od]HD3ooFeQ004ooFePol0003o0000o`0000;oj;>K00CojK>Joo>e
Qood]HKom;F60_od]HD01Ooe]HComKF3ooJeP_of]H;om[F100;omkR300SomkR2ol>[`oo3Zl?o`j_3
oo:gS_oc]hgolkN<oo>gR`;om;N:00?omkR2ooRhPOoh^8400_oh^802ooRhO`04ooRhO_oi^7gonKQm
ooNoS@;okKfQ00?okKfPonjmWoo__Yh00_oh^hD2ooRkQ006ooRkPooi^h?onK^2ooVnQ_l0003onKj5
0ooj_XD00ooj_hGon[n4ol[2dP02ol[3d`06ooO2Toog`i?oml>BooS3T_oha9;on/:;0_oj`XX2oo[3
RP0:oo[4R_ocbjOoll^Woo?;Yoobc:SoBH[ZoiDV0?n0[?3oklj`oo3>/0;ol<n`1Oooool00ol0003o
ooooooooo`0Tooooo`006_ooool00ol0003oooooooooo`09ooooo`05oj:fioo0_MOo`KgFol6me_o9
_m000_o;_ll01?nm`=co_/3Lof>Rm?mSX_@2oh>UjP?ob;W<00WobKW:omRl__oI^kcofK^lomZk^ooF
_l?oeko2omRo`?l07jP00_nj/M43ombh]004omfg/_oN]k7oh[Z_on>j[@;ohkZ/00?oi;Z[oeEmgOoH
/k<00_oH/k<01?oI/k;oi[JTonJfY?oV]Z<2onNfX@04onRfX?oX]Yooik^Wol:Z`@;oa:[00_oV/j02
onJcW`06onNcWOoX/icok;JIonbfVOo]]YSo54C10_oO/:H00ooP/:CohK2Son6`X`02onbdU@0<onfd
U?o]/i?ok[>BonjcT_o^/i7ok[>@omin0Oo5YKWoaZFgonZbU_o[/YGojk:D0_o//Y<01oo//Y;olKF>
oo6eSOoa]HgolKF<oo:eS?ob]H/00_oT[ih2onF_W@07onF_Voo`/hcolK><oo6cS?oa/h_olK>:oo:c
R@02oo:cR003oo:cQooc/hOo`jBi00;oaJBh0_o^/hl02?o_/hkokk>=oo2cS?o`/hcol;>;ooBeQ_od
]HGomKF40ol000000oof]H;om[F1o`00T002onRcV`04onVcV_oZ/iWom;F6ooBeQP;om;F500GomKF4
ooFePoof]H;om[F2ooJeP@02ooNhP`;omkR200Ko`j_3ol>/`_oc]hgolkN=oo>gS?oc]h/2ooBgRP04
ooFgR?oh^87on;R1ooRhP0?on;Qo00WonKQnooVhOOoi^7gonKQlo`0:Voo]_J7okKfPonjmWoo__Yh0
0_oh^hD2ooRkQ006ooRkPooi^h?onK^2ooVlPOl0003onKj50ooj_XD01_oj_hGon[n4oka@0?o:`m?o
blCDooO3T`;oml>B00Con<>BooS4T_oha97on/::0ooj`hX01ooja8[on/B;oo?;YoocbjOol/bXoo;<
ZOm9R^X00_n0[O401?o`c[3ol<n`oo3?/?o`d;43ooooo`;o00009_ooool001[ooooo00?o0000oooo
ooooool02Oooool2oj:fi`04ol6me_o3_MGo`kgEol^oc`;oc;o>00Co_/3Lokk0fonn`=_oFioc0_n3
YNX00oo8^LcobKW:olVibP03omVk_009omZk^ooK^kWoeko2omRo`?oI_[oo01nXokZadOnk/M3og;Rd
00;ogKNb00Cog[Naomjg[ooS^ZgohkZ/0_oT^Z/2oe1jg004omRc/ooI/k;ofK>bomZc/@;oi[JS00Go
ikJQonRfX?oX]Z3oj;JOonVfWP03olBZ`0;oi[>P00Coi[>OonNcWOoW/igoj;>L0_o/]YT01Oo]]YSo
kKJGoaA4`OoO/:Koh;2T00;ohK2S00Goh[2RonfdU?o]]9CokK>ConjcTP02onjcT@04onjcT?o_/i3o
aZFgolJU]`;ojk:E00Kojk:DonbbToo//Y;ok;:BonfbTOoa]Hd2oo6eS003oo:eS?ob]H_ol[F:00;o
iJnM0_oU[i/01_oV/9[olK><oo6cS?oa/h_olK>:oo:cR@;ol[>800?ol[>7oo>cQoo5Y;P00_o5Y;P0
1?o^/hookk>>onncS_o_/hd2oo2cS005oo2cRooa/h[o0000o`000?oe]H@00_oe]H<01?of]H;om[F1
o`00RooX/i/2onVcVP04onZcVOod]HKom;F5ooBeQ@;omKF400KomKF3ooJeP_of]H;om[F1ooJeP?og
^8<2ooNhPP03ooRhPOo3[<;olkN=00;olkN<00ColkN;ooBgR_od]hWomKN80_oh^8401Ooh^83on;Qo
ooRhOooh^7oonKQn00;onKQm0_oi^7`2onfmX005onjmWoo__YkokkjNooRkQOoh^h@00_oh^h<01Ooi
^h?onK^2ooVlPOoj_87o000000?on[j500?on[n5ooZoQ?oj_h@00_o;a=@01oo;aMComl>BooS3T_oh
`i;on<BBooS4TOoj`XX00ooj`hX01?oja8[on/B;oo_4Roobc:P2oo;<Z@04oo;=Zol006OoP:kaoh2^
l@;ol<n`0_o`d;44ooooo`03o`000?oooooooooo02?ooooo000Jooooo`03o`000?oooooooooo00[o
oooo0onR]^L00oo3_MGoa;gDolbocP02olfoc@07okk0fono`M_o_l7Koe>Kl_l09:SoPJ?ZolVibP02
ol^ib@06omVk_?oJ^k_of[^kom^k^OoL^kSof;o00_oI_[l01?l04Ico^k7@okbacooM]k82omjg/@04
omjg[ooS^ZcohkZ/onBjZ`;oiKVY0_m@N]`01?oI/k;of[>aomZc/OoK/jl2onNfX@06onRfX?oX]Yoo
j;JOonVfW_oX^ZGoa:[00_o5Z[l2onJcW`;oik>M00Koj;>LonRcVoo]]YSokKJHonffUolDA<42on2`
Y004on6`XooR/:;oh[2RonfdU0;okK>C00Gok[>BonjcTOo^/i3ok[>@onncT002olJU]`;ojk:E00Ko
jk:DonbbToo//Y;ok;:BonfbTOo]/Y02oo6eS003oo:eS?ob]H_ol[F:00;oiJnM0_oU[i/01ooV/9[o
lK><oo6cRooa/h_olK>:oo:cROob/hP00_ob/hL00ooc/hOolk>6olFT^002olJU]`;okk>>00?okk>=
oo2cS?l000000_l000001?oa/hWomKF4ooFeQ?oe]H<2ooJePP;om[F100Go002;onVcV_oZ/iWoj[>I
on^cV002ooBeQ@03ooFeQ?oe]H?omKF300;om[F200?om[F1ooJeP?of]Gl00_og^8800ooh^87oa:g2
olB]`P02oo>gS007oo>gRood]h[om;N9ooFgR?oe]hOon;R1ooRhP003ooRhO`03ooVhO_oi^7gonKQm
00?onKQl00Ook[fOonnnW_o__YkokkjNoo2oWOoh^hCon;^300;onK^300KonK^2ooVlPOoj_87on[b1
o`000?oj_XD2ooZoQ@;on[n400Go_500ol_4e?o;aMComl>BooS3TP02ooS4TP03ooS4TOoiaI7on/>:
00;on/>:00Con/B:oo[4Rooka8_ol/bX0_obc:T00oobcJ_olLf/o`00I`02oh6_lP?ol=2a00GolM6a
ooooooooooooooooo`00000Uooooo`006_ooool00ol0003oooooooooo`0;ooooo`06oj:fionR]^Ko
X[KVolBme?o5_M?ocKo=0_o>_l`01ono`M_o`<7Jol31f_m;U_7o01JJogjRj_o;^LT00_o<^LP01?oJ
^k_ofk^iom^k^OoL^kP3omVn_`03omZn__nl/Loo_;7?00;og[Na0_oN]jl00ooO]jkohkZ/onBjZ`02
onFiZ@;oBgKK0ooJ/k401?oK/jooikJQonNfXOoX]Z02onRfW`03onVfW_oY]IgoaJZo00;oaJZo0_oV
/il01OoW/igoj;>LonRcW?oX/i_ojK>J00;okKJG0_l>@;h2on6`X`;oh[2R00Gohk2PonfcToo]/i?o
k[>BonjcT@02onjcT004onncT?o_/hooaZFgolRU]P;ojk:D00Kok;:ConbbT_o//Y;okK:AonfbT?oa
]H`2oo:eS005oo:eRoob]H[ol[F9onF_WOoU[i/00_oV/9X01_oW/9WolK>;oo6cRooa/h[ol[>9oo:c
R0;ol[>700?olk>7oo>cQ_o6YKL00_o6YKL01?o_/hko0000o`000?l00002oo2cR`05oo6cR_oa/hWo
mKF4ooFeQ?oe]H<00_of]H82ooJeP@05o`00RooY/i[oj[>IonZcVOo[/iP00_od]HD00ooe]HComKF3
ooFeP`02ooJePP04ooJePOof]H3om[EoooNeO`?on;R100[oa:g2oo>gS?oc]h_olkN;ooBgR_od]hWo
mKN8ooFgQoof^8Kon;R00_oh^7l01?oh^7konKQnooVhOOoi^7d3ooVhO008o`00T?o__YkokkjNonnn
W_o`_igon;^4ooRkPooi^h<2ooVkPP06ooVlPOoj_87on[b1ooZnQOl0003on[n51?oj_h@01oo;aMCo
blKEol_6eOoh`i;on<BBooS4TOoia9400_oiaI401_oj`h[on/B:oo[4R_oja8_onlB;oo_5R`;ol/bY
00?ol/f[oo7=[?m8RNX00_n2/?82oo3@/@03oo3A/OoadK7olM:b00?ooooo00?o0000ooooooooool0
8_ooool001Wooooo00?o0000ooooooooool03Oooool01_nR]^KoX[GVolFmdoo5_M?oa[gBoljoc0;o
cko;00Go`<7Jol71f_o1`M[o00N<ogbPjP03olbib006olfia_oK^kWog;^hombk^?oL^kOofKjo0_oJ
_[h01Ol008?o_;7?okfac_oN]k7og[N_00;ogkN^00?oh;N]onBjZooU^JT00_oU^JP2od]ff`04omZc
/OoK/joofk>_ombc[P;oj;JP00Koj;JOonVfW_oY]YkojKFMonZeW?o5Z[l2olJZ_@;oik>M00Coj;>L
onRcVooX/i_ojK>J0_o]]YL01Oo]]YKo3T2non6`XooQ/:?oh[2R00;ohk2P00GokK>ConjcT_o^/i;o
k[>AonjcT002onncT004onncSoo8YKKob:Ffon^bU0;ok;:C00Kok;:BonfbTOo]/Y7okK:@onjbSoob
]H`2oo:eR`04oo:eR_ob]HWoiJnKonF_V`;oi[2J00Ooik2Ioo6cRooa/h[olK>:oo:cROob/hSol[>7
00;olk>700?olk>6oo>cQOl000000_l00002onncS@08oo2cS?o`/h_olK>:oo6cR_oa/hWol[>8ooFe
Q?oe]H<2ooJePP;om[F100?om[F0onVcV_oZ/iT00_o[/iP01?o[/iOom;F5ooFeQ?oe]H<3ooJePP04
ooJePOof]H3om[EoooNeO`?on;R10_o6[L802?oc]h_om;N:ooBgR_od]hWomKN8ooFgQoof^8Kon;R0
0_oh^7l01?oh^7konKQnooVhOOoi^7d3ooVhO008ooZiNoo__YkokkjNonnnW_o`_igolKnLooRkPooi
^h<2ooVkPP06ooVlPOoj_87on[b1ooZlP?l0003on[n51?oj_h@01ooj`8GoblKEolc7e_o<amKon<BB
ooS4TOoia9400ooiaI401ooja8[on/B;oo[4Rooka8_onlF;oo_5S?obcJ/00_oacJ`02?oacZkoB8WZ
oh>alon3/O?ol=2aoo3A/OoadK7olM:b1?ooool00ol0003oooooooooo`05ooooo`?o00006Oooool0
01Wooooo0_l0000?ooooo`;oX[GV00?oaKgColJmd_o7_M000_o?_l/01oo@_lWo`L7Jol71fOo1`MWo
00N<ogbPj_o<^LP00_o=^LH01_o>^LGog;^hombk]ooL^kOogKZeomZn_P;ofkjl00Co0023okfac_nn
/Lgog[N_0_oO]jh01?oP]jgohKN/onFiZOoU^JP2onJiY`03odIbf_oK/joofk>_00;og;>^00CogK>]
onRfWooX]YoojKJN0_oY]Id01?oZ]IcoaZZmolJZ_Oo6Z[d2onNcW@05onRcW?oX/i_oj;>KonVcV_oY
/iT00_o]]YH2o`Tk_0;oh[2R0_oS/:001_oT/9ook[>BonjcT_o^/i7ok[>@onncT0;okk>?00?ob:Ff
olVV]?o9Y[@00_o//Y<01oo//Y;okK:AonfbTOo]/Y3ok[:?oo:eS?ob]H/00_ob]HX01?ob]HWoiJnK
onF_VooV/9X2onN`V@07onR`V?oa/h[ol[>9oo:cROob/hSol[>7oo>cQ`03o`0000?ob:Ff0_o_/hd0
2?o`/hcol;>;oo6cR_oa/h[olK>9oo:cR?oe]HComKF30_of]H82ooJeP@03ooJeP?oZ/iWoj[>I00;o
jk>H00Cojk>GooBeQOoe]HComKF30oof]H801?of]H7om[F0ooJeOoog]Gl3ooRhP@03on>43?o6[L;o
ajk100;om;N:00?om;N9ooFgR?oe]hL00_of^8H2ooRhO`04ooRhO_oi^7gonKQmooVhO@?onKQl00?o
n[Ukon^<7oo__Yh00_o`_id00ooa_icolL2LooVkP`02ooVkPP06ooVlPOoj_87on[b1ooZlP?oj_Goo
00001?oj_h@00ooj`8Gonl25olc7eP02olc8eP03ooS4TOoia97onLFA00;onLFA00?on/B:oo[4Rook
a8/00_okaH/01ookaHcol/f[oo7=[?oacZgolLj^oo3>[ol006l00_n4/_<01?oadK7olM:boo7B/_oa
dk<2ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000001Sooooo000Iooooo`03o`000?oo
oooooooo00oooooo0_nR]NH01oo6_M;oakg@olNmd?o?_l_od;o9om6ob?o1`MT00_o2`MT00ol/QN_o
NIoYolfiaP02oljia@?og;^g00?ogKZeomjj]?oK_[`00_oL_[/2okjac@;ogkN^0_oP]jd01OoQ]jco
iKVXonFiZ?oV^JOoi[VV00;o@FoH00Cofk>_ombc[_oL/jkogK>]0_oX]Yl01_oY]YkojKFMonVeWOoZ
]Icoj[FKolJZ_@;oajZl0_oX/i`01OoX/i_ojK>JonVcV_oY/iWoj[>H00;ok[JF00Co2C^lon:`X_oR
/:;ohk2P0_oT/9l01oo^/i;ok[>AonjcTOo^/i3okk>@onncSoo_/hh00oo9Y[@01?o//Y?ok;:Bonbb
T_o]/Y42onfbT003onjbSoo^/Xkol[F;00;ol[F:00Col[F9oo>eROoV/9[oi[2J0_oW/9T01?oX/9So
lK>:oo:cROob/hT3o`0000;olk>60_oc/hD2olRU]P05olZV]?o`/hcol;><oo2cRooa/hX00_oa/hT2
oo:cR003ooFePoof]H;om[F200;om[F100Com[F0onZcVOoZ/iWojk>H0_o[/iL00oo//iKomKF4ooFe
P`03ooJePP05ooJePOof]H3om[EoooNeOoog]Gh00_oh^8401Ooh^83oajk1olN^`Ood]h[om;N900;o
mKN800KomKN7ooJhQ_of^8Kom[R5ooRhOooh^7h3ooVhO@?onKQl0_oj^G/01ol008Kol;nMoo2oWOoa
_icolL2LooVkPooi^h800_oi_842ooZlP@04ooZlP?oj_Goon[eoo`0000?on[n400Kon/25oo_0QOok
`HGoc<SFolg:eooia944ooW5T@03oo[6TOoja8_onlB;00;onlF;00[onlF<oo_6SOoacJcolLj]oo7>
[_o`cZooB8WZo`00Kon5]??olM6a0_oad[82oo7C/`?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Fooooo`006Oooool00ol0003oooooooooo`0@ooooo`;oX[GV00Goakg@olRmcoo8
_Lood;o9om6ob002om:oa`05ol;1fOo3`MSo8GkWogJMjOo>^LD00_o?^L@03?oL^kOogKZeomfj]OoN
^[CogkZcombn^ooL_[[oTb40okjacOno/LcogkN^on2g[@;ohKN/00Koh[J[onFiZ?oV^JOoi[VVonNi
YOm1KmP2ombc[P;ogK>]00Cog[>[onVfW_oY]YkojKFM0_oZ]I`01?oZ]I_oajZlolNZ_?o7Z[`2onRc
W007onRcVooY/i[ojK>IonVcVOoZ/iSok[JFonjfU@02o`Dh^P;ohk2P0_oT/9l01_oU/9kok[>Aonjc
TOo^/i3okk>@onncS`;okk>>0_o9Y[@01Oo;Y[?ok;:BonbbT_o]/Y7okK:@00;ok[:?00?ok[:>onnb
SOob]HX00_ob]HT01?oc]HWoi[2JonJ`V_oW/9T2onR`V0?o000000Col[>8oo:cQooc/hOolk>60ooc
/hD00oo8YKKobZJdolZV]002oo2cS003oo2cRooa/h[olK>900?ol[>800?omKF3ooJeP_of]H800_of
]H42ooJeP0;ojk>H0_o[/iL00oo//iKomKF4ooFeP`02ooJePP;om[F10_of]Gl01_og]GoomkEnooNe
OOoh^87on;R0olN^`@;ob:o100Com;N9ooFgR?oe]hOomKN70_of^8H00oof^8Gon;QoooVhOP03ooVh
O@?onKQl0_oj^G/00ol0087ol;nMoo6oW002oo70W003oo;0Vooi^h;onKb100?on[b100Con[b0ooZm
Oooj_Goo00000_oj_h@2oo[0Q@05oo_0QOok`HGo`eH0olg:eoo=bmL00ooiaI42oo[6T@07oo[7TOok
a8_onlF;oo_5RookaHconlJ=oo_7S@02oo7>[P03oo3>[oo_ck;oB8WZ00;oQkGd00ColM:boo7C/ooa
dk?olM>c1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo000Iooooo`03
o`000?oooooooooo017ooooo0_nR]NH01?o8_LoobKg>olVmc_oA_lP2om:oa`04om>na_o3`MSo`l7H
og>Kj@?ockW400god;W3omfj]OoN^[Cog[Zdomnj/ooO^[;og;jjomfn^OnC8@3o_k7<ol2abooP]jgo
hKN/00;oh[J[00Coh[JYonJiYooV^JKoikVU0_llJmL01OoL/jkogK>]omjcZooN/j_ogk>Z00;ojKFM
00Goj[FLonZeVooZ]I_ojkFJolNZ_002olVZ^`;oj;>K00SojK>JonVcVOoY/iWoj[>HonZcUoo^]YGo
k[JDo`Dh^P;ohk2P0_oT/9l02OoU/9kok[>AonjcT?o^/i3okk>@onncSoo_/hkol;>=olVV]002ol^V
/`;ok;:B00OokK:AonfbT?o^/Xook[:?onjbS_o_/Xgol[F:00;ol[F900?olkF9o`09V_oW/9T00ol0
00001ooY/9Ool[>9oo:cR?ob/hSol[>7oo>cQooc/hH00ooc/hD3olZV]005oo2cS?o`/h_ol;>;oo6c
R_oa/hT00oob/hP00oob/hOom[F2ooJePP02ooJeP@;om[F00_o[/iP01Oo[/iOok;>FonbcU_o]]9Co
mKF300;om[F20_of]H401oof]GoomkEoooNeOoog]GkomkEmooRhPOoh^8000oo8[l401?od]hWomKN8
ooFgQooe]hL2ooJhQP03ooJhQOog^8ConKQn00;onKQm1?oi^7`3ooZiN`03o`00POoa_icolL2L00;o
l/2K00?onK^2ooVlPOoj_8400_oj_8401_oj_83on[eoooZmOook_Goo0000ooZoQ0;on/2500Conl25
oo_1QOok`HKocL_G0_o>c=P2ooW5T@;on/JA00?on/NAoo_5RookaH/00_okaH`02_okaXgonlN=oo_7
S_o`cZool<n`ono?/_o^ck?o001]ohRgm?n;^?@3oo7C/`05oo3D]?ooooooooooooooool000001?oo
ool4o`0001Wooooo000Iooooo`03o`000?oooooooooo01;ooooo00?oX[GVoj:di_o9_Lh00_o:_Ld0
2?oB_lOodkk6om>na_oD_/Go`l7HolC1eomcVnWockW40_o@^L<02?oA^<;og[Zdomnj/ooO^[?ogkZb
on2j/?oM_[Wog[jh0_o0/L/2on6g[0;oh[J[00?oh[JYon>fZ?oV^JH00_oW^JD2oca[e`04omfc[OoN
/j_og[>[omncZP;ojKFM00Coj[FLonZeVoo[]I[ojkFJ0oo9Z[/2onRcV`07onVcV_oY/iWoj[>HonZc
V?oZ/iOojk>GonjfU002o`8e^0;oi;2O0_oU/9h01ooU/9cok[>@onjcT?o_/i3okk>?onncS_o`/hd0
0oo;Y[<01Oo=Y[7okK:AonfbTOo]/Y3ok[:?00;ok[:>0_o_/Xd00oob]HWolkF9oo>eR@02o`000006
onN`VOoX/9SojK2GonV`UooY/9Gol[>80_ob/hL01?oc/hOolk>6oo>cQOoc/hD2ooBcQ003olZV]?o<
Y[?oc:Jc00;ol;>;00?olK>:oo6cROob/hP00_ob/hP00oob/hOom[F2ooJeP@02ooJeP@;om[F000?o
mkEoon^cUoo[/iL00_o//iH02?o]]9Cok[BCooJeP_of]H;om[F1ooJeP?of]GoomkEo0_og]Gh01Oog
]GgomkImooRhP?oh^83ob:o100;obK3100?omKN8ooFgQoof^8H00_of^8H00oof^8GomkR4ooVhOP02
ooVhO@ConKQl0ooj^G/00ol007colKnLoo70W002oo;0V`04oo?1V_oi_87on[b1ooZlP@;on[b00_oj
_Gl01?ok_Goonkioo`000?oj`8D2oo_0Q@03oo_1QOok`HKoc/cH00;oc/cH00goc/kIooW5TOojaY7o
n/JAoo[7TOojb97onlF;oo_5S?okaXconlJ=oo_7SOokahkonlR@00;oklnb00Wok/ncodR9j_l006go
RkSdohfjm?oadk?olMBdoo3D]?o`eKD00oooool2o`0000;ooooo00?o0000ooooooooool06_ooool0
01Sooooo0ol0000Dooooo`;oX[CV00Cob[g=ol^mc?o;_Lcodkk60_oD_/D01OoE_/Coa<7GolG1e_m`
V^Wod;W300;odKS200cod[S1omnj/ooO^[;ogkZbon2j/?oQ^Joog[jhomjm]oo0/L_o`K7:on6g[?oR
]Z/2on:fZ@06on>fZ?oT]ZOoikVUonNiYOoW^JCoj;RS0_oN/j/2omncZP04on2cZOoZ]Icoj[FLonZe
V`?ojkFJ00?obJZkolZZ^Oo:Z[T00_oY/iX02?oY/iWoj[>HonZcUooZ/iOojk>GonjfU?o_]Y?o0SFh
0_oT/9l2onF`WP06onF`W?o^/i3okk>@onncT?o_/hookk>>0_o`/hd00oo;Y[?ocJJaolfV/@02onfb
T@04onfbT?o^/Xook[:>onjbSP;okk:=0ol000001?l01YSo00VJonN`VOoX/9P2onV`U`06onV`UOob
/hSol[>7oo:cQooc/hOolk>60_oc/hD2ooBcQ0?oc:Jc00Col;>;oo6cR_oa/h[olK>90oob/hP00oob
/hOom[F2ooJeP@02ooJeP@;om[F000ComkEoon^cUoo[/iOok;>F0_o]]9@01oo^]9?om[F2ooJeP_of
]H7om[F0ooJeOoog]Gl00_og]Gh01?og]GgomkImooRfOOoh^803olV``@03ooFgR?oe]hOom[R600;o
m[R600?om[R5ooNhQ?og^8<00_oi^7d4ooVhO0Con[Uk0_oa`9`01?ob`9_ol/6Koo?1V_od`YX2ooZl
P@;on[b00_oj_Gl01Ook_Goonkiooo^nOol0003onl2500;onl6500?onl66oo_2Q_o>c=P00_o>c]T3
oo[6T@04oo[7TOojb97on/RAoo_9T@;onlJ=00ConlN=oo_7S_okb93onlVA0_o^ck<00oo]d;OoB8WZ
o`00Q002ohnlm@;ol=Bd00Kol=Feoooooooooooo0000ooooool00002ooooo`Go00006?ooool000Go
oooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`0Eoooo
o`06oj:di_o;_Lcobkg<ol^mc?o<_L_oe;k50_oE_/@01OoF_/?oaL7FolG1e_m^V>WodKS200;od[S1
0_oO^[82on2j/008on6i[ooQ^Jkog[fgomnm]_o1/L[o`[79on:fZooR]ZT2on>fZ0;oi;JW0_oW^J@0
1?oX^:?o<fGDomjcZooO/jX2on2cZ@;oj[FL00Coj[FKon^eV_o[]I[ojkFI0oo:Z[T2onVcVP0;onVc
VOoZ/iSoj[>GonZcUoo[/iOojk>FonnfTol0<[Ko0SFhonB`WooU/9h00_oU/9`01OoV/9_okk>@onnc
Soo_/hookk>>00;ol;>=0oo=Y[401Oo]/Y7okK:@onfbT?o^/Xook[:>00?o000000Gol;:<oo>eROoc
]HSolkF8o`06V002onR`V005onV`UooY/9GojK2EonZ`U?ob/hL00_oc/hL00ooc/hKolk>5oo>cQ@02
ooBcQ004ooBcPoo<Y[?oc:JcolfW/P;olK>:00?olK>9oo:cR?ob/hP00_ob/hL01?oc/hGom[F1ooJe
POof]H42ooJeP004ooNeOol007Wok;>FonbcUP;okKBD00Ook[BConjdT_of]H;om[F1ooJeP?of]Goo
mkEo00;omkEn00KomkEmooNfOOoh]Wgon;IlooRhOoo9/<42ol^a`@04ooFgQoof^8Kom[R6ooJhQP;o
mkR400?omkR3ooVhOOoi^7d00ooi^7`00ooi^G_on[UkooZiN`02ooZiN`06ooZjN_ob`9_ol/2Koo;1
Vooc`I[om<:J0_oj_8401Ooj_83on[eoooZmOooj_Goonkeo00;onkio00?o0000oo_0QOok`HD00_ok
`HH01_ok`XKonl:7olk>fOo?cmWod=3Joo[6T@;on/NA0_ojb9403OokbI7onlJ=oo_7SOokahgonlR?
oo_8T?okbI7ok/nconk@]Oo]d;Ook=2io`00N?l008@00_nA_OD2oo3E]@05oo3F]ooooooooooooooo
ool000007oooool000Cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo01Kooooo00KoX[CVol^mc?o<_L_oc;g;olfmb_oE_/@2omJn``03omNn
`_o5`MKoa/7E00?od[S100?odkRoomnj/_oP^[000_oQ^Jl00ooQ^Jkogkffomnm]P02ol:ab@;oh[JY
0_oS]ZP2onBfY`04onBfY_oX^:?oj;RSonRhX`;ogk>Z0_oP/jT00ooQ/jSoj[FKonZeV`02on^eVP;o
jkFI00?obZZiolb[^?o<ZkP00_oY/iT02?oZ/iSoj[>Gon^cUoo[/iOojk>FonbcUOo_]Y?o03:f0_oU
/9h2onF`W005onJ`VooW/9[okk>?onncSoo_/hh00_o`/hd01Oo`/hcocJJaolfV/Oo?Yk3okK:@00?o
00000oo_/Xd01Oo`/Xcol;:;oo>eR?oc]HSo00BF00;oj;2H00GojK2GonV`UOoY/9Goj[2Doo:cQ`02
oo>cQ`03oo>cQ_oc/hGolk>500;om;>400Gom;>3olbV/oo=Yk;ocJNboo6cRP02oo6cR@;ol[>80_ob
/hL2oo>cQ@04ooJePOof]H3om[F0ooJeP0;omkEo0_o//iH02Oo]]9Cok[BConjdToo^]9;om[F2ooJe
POof]H3om[EoooNeO`02ooNeOP03ooNeOOog]Wgon;Im00;on;Il0oo;/L401?oe]hOom[R6ooJhQ_of
^8D2ooNhQ003ooNhPoog^H?onKQm00?onKQl1Ooj^G/02Ooj^W[o001boo;0Voob`I_oll6JooC2V_od
`iWon[b1ooZlP003ooZmO`06oo^mOook_Woonkiooo^nOol0003onl650_ok`HH01?ok`XKonl:7oo_3
Qoo?cmT2om3BfP;on/NA0_ojb9402?okbI7onlZBoo_7SOokahkonlR?oo_8T?okbI7onlZC0_o]d;L0
0oo/d;Wojm6ko`00N002oi>om004oo3E]Oo`eKKol=Jgoo3F^0?ooooo00?o0000ooooooooool07?oo
ool000Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Oooooo00KoX[CVolbmboo=_L[ocKg:oljmbOoF_/<2omNn`P04omNn`Oo6`MGoIiCYom:h
`@;odkRo00?oe;Rnon2j/?oQ^Jl00_oQ^Jh01ooR^Jgogkffon2m]Oo2/LWo`k78on:fZOoS]ZP00ooT
]ZL01ooT]ZKoiKJUonRhXooX^:?o;f;ComncZ_oP/jT00_oQ/jP01_oQ/jOojkFJon^eV_o[]I[ojkFI
onbeV0?oc:^h00GocJ^gonZcV?oZ/iSoj[>Gon^cU`02on^cUP03onbcUOo_]Y?o036e00;oiK2N00Go
iK2LonJ`VooV/9_oik2JonncS`02onncSP;ol;>=00?ol;><olfV/Ol000000_l00002onjbS`06onjb
S_o_/Xgokk:=onnbSOo`/Xcol;:;0_oc]HP01Ooc]HOo00BFonV`UooY/9OojK2E00;oj[2D00Cojk2C
oo>cQooc/hKolk>60_oc/hD2ooBcQ005ooBcPoo=Yk;ocJNbolfW/_o?Z;400_oa/hT2oo:cR005oo:c
Qooc/hKolk>5oo>cQOof]H400oof]H02ooNeO`04o`00NOo//iKokKBDonjdT`;ok[BB00GokkBAooJe
POof]H3om[EoooNeO`02ooNeOP03ooNeOOog]Wgon;Im00;on;Il00Con;Ikol^a`Oo<//7oc;;10_of
^8H01_of^8GomkR4ooNhQ?og^8?omkV3ooRiPP?onKQl1Ooj^G/2ooZjNP07oo;1Vooc`I[oll6JooC2
V_od`iWomL>IooZlP002ooZmO`;onkeo0ook_Wl00ook_goo0000oo_1QP02oo_2QP04oo_2Qook`hOo
nlB9om3BfP;odM?K0oojb9401?okbI;onlZBoo_;T_okahh2oo_8T003oo_9T_okbY?on/^D00;ok=2i
00?ojm6kodV:j_l029<00_nF`?@2oo3F]`03oo3F^?o_ek[ooooo00;ooooo00?o0000ooooooooool0
6oooool000Cooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Sooooo00KoX[CUolfmb_o>_LWoc[g9olnmb?oG_/82omNn`@09omRn`?o7`MGoIiCY
ofNDjOoC^;ooe;RnomFh_OoQ^JoohKV^00;oh[V]00CohkV/on2m]OoP_KCo`k780_o4/LL2onBfY`;o
i;JV00CoiKJUonFfY?oY^:;ojKRR0_oP/jT2on6cZ008on6cYoo[]I[ojkFJon^eV_o[]IWok;FHonbe
Uoo<ZkP2olf[]`;oj[>H00Soj[>Gon^cUoo[/iKojk>FonbcUOo//iCokkJBo`0a]@;oiK2L0_oV/9/0
1OoW/9[oj;2IonncS_o_/hkol;>=00?o00000_o?Yk001?oAYjook[:?onjbSoo^/Xh2onnbS@;ol;:<
00Gol;:;oo2bR_oc]HSolkF7o`04UP02onV`U`05onV`UOoZ/9Coj[2Don^`Tooc/hL00_oc/hH2oo>c
Q@;om;>40_od/h<01?o=Yk;ocjRaolnX/Ooa/hT3oo:cR005oo:cQooc/hKolk>5oo>cQOod/h@00_of
]H03ooNeO`04ooNeO_o]]9CokKBDonjdT`;ok[BB00GokkBAooJePOof]H3om[EoooNeO`02ooNeOP03
ooNeOOog]Wgon;Im00;on;Il00Oon;Ikolbb`Oo<//7oc;;1oljd`Oof^8Kom[R500;omkR400ComkR3
ooNiPooh^H;on;V20_oi^7`5ooZiN`?on[Yj00Koll6JooC2V_od`Y[om<>IooG3VOoj_802ooZmO`;o
nkeo0ook_Wl01?ok_gooo;moo`000?ok`XH2oo_2Q`05oo_3R?oka8WonlB:om7CfooAe=/00_ojb940
2ookbI7onlVBoo_:T_okbi;onlR?oo_8T?okbI7onlVBoo_:ToojbiCok=2i00;ojm6k00Woj=6oodZ:
jol029?oV<;doi_3m?o`e[SokmNionoG^_o^ek/00_ooool2o`0001cooooo0004ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01Wo
oooo00KoX[CUoljmbOo?_LSockg8om2maooG_/42omRn`008omVn_oo7`MCoI9?YofBCjOoD^;koeKRm
omJh_?oQ^Jh2on:i[@;ohkV/00Coh;fdolBaaoo4/LOoa;770_oT]ZL01?oT]ZKoiKJUonFfYOoU]Z@2
onVhXP03obaOd_oP/jWohK>X00;ohK>W00Koh[>Uon^eV_o[]I[ojkFIonbeV?o/]IL3olf[]`05oln[
]OoZ/iOoj[>Gon^cUoo[/iH00_o//iD00oo//iCokK>Co`0`]002onF`W004onJ`VooW/9[oik2JonR`
V@?o000000Col;>=oo2cS?oa/hcocjN`0_oAYjl00oo^/Xook[:>onjbSP02onnbS@;ol;:<00?ol;:;
oo2bR_oa/XX00_oc]HL01?l019KojK2GonV`UOoZ/9@2on^`T`03onbaT_oc/hKolk>500;olk>50_od
/h@2ooBcP`?ocjRa00KodJV_oo:cR?ob/hSol[>8oo:cQooc/hH2oo>cQ@03ooBcQ?of]H3om[F000?o
mkEo00GomkEnonfdU?o]]9Cok[BConjdTP02onndT@04oo2eT?of]Goom[EoooNeO`;omkEn00?omkEm
ooNfOOoh]Wd00_oh]W`00ooh]W_on;Qoolbb`@02oljd`@06ooJhQ_of^8GomkR4ooNhQ?og^8?omkV3
0_oh^H800ooh^H7onKQlooZiN`04ooZiN`?on[Yj00?oUBL0ooC2V_od`iT00_oe`iT01?ofa9Son[eo
ooZmOook_Gl4oo^nO`0Noo^oOool_goo0000oo_2Q_ok`XOonl>7oo_3R?oka8WonlB:olAD0?oAe=_o
d]KLoo[8TOokbI7onlVBoo_:T_okbi;onlbDoo_8T?okbI7onlVBoo_:ToojbiCon/bGon_A^ooYdKgo
j=6oonOA`Om;Rn_oVl?d0_nMaO@2onoG^P03onkG^ooooooooooo00;o00007?ooool000Cooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool06_ooool3oj:di@03olnmb?o@_LOof;k000;of;k000CofKjoomVn__o8`MCoHI7Y0_oE^;d00ooF
^;coh[V]on:i[@03on>i[003onBiZooQ_K?oa;7700;oa[7600?oi;JWonBfY_oU]ZD00_oU]Z@01_oV
]Z?ojKRQonVhXOl/Gm;ohK>Xon6cY`;oh[>U00Cohk>Ton^eVOo[]IWok;FH0_o/]IL00oo=ZkOocj^e
oln[]@02onZcU`08on^cUoo[/iKok;>EonbcUOo//iCokK>ConnfTOl0<;@2onJ`V`?o000000Koj;2H
oo2cSOo`/hgol;>=oo2cS?oa/h`3om6W[`03om:X[Oo^/Xkok[:>00;okk:=00Gol;:<oo2bRoo`/X_o
l;::oo6bRP02oo>eQ`04o`03UOoY/9GojK2EonZ`U0;ojk2C00?ok;6Boo>cQ_oc/hD00_oc/hD2ooBc
Q004ooBcPood/h;om;>2olnX/@;odJV_0oob/hP01oob/hOolk>6oo>cQOoc/hGom;>4ooBcPoof]H00
0oog]Gl2ooNeOP;ok[BC00Gok[BBonndTOo_]97ol;F@ooJeO`02ooNeO`05ooNeO_og]GgomkEmooNf
OOoh]Wd00_oh]W`2ooRfN`05ooVhO_o>]<7ockG0olne`?of^8D00_og^8@01_og^8?omkV3ooRiP_oh
^H;on;V1ooVhO0Con[Uk00gon[UjooZjN_oj^W[on[Yjoo^jN_nE9`3om<>IooG3VOoea9Wom/BHooK5
V?oj_Goonkeo00Conkio00_onkmoooboOool`7oo0000oo_2Qook`hOonl>8oo_4ROoka8[onlF<om;F
g002om;Gg004oo_9T_okbY;onlZBoo_;T`;onlbD00KonlVBoo_:TookbY?on/^Foo[<UoojcIT2onSA
_`06onOA`Om;Rn_o00ZGo`0LY?nPa_?okmNj0_o^ek/01Oo]f;gooooooooooooooooo000001_ooooo
0005ooooo`;o00002Oooool3o`0000Cooooo00?o0000ooooooooool06oooool3oj:di@03om2maooA
_LKof;k000;ofKjo00CofKjnomZn_OmMSnSoGHoX0_oF^;`00ooG^;_oh[V]on>i[002on>i[004onBi
ZooT^J[ohKfcolJaaP;oak;500?oi;JVonFfYOoU]Z@00ooV]Z<01?oY^:3o:5gAon6cYooQ/jL2on:c
Y@04on>cY?o[]IWojkFIonbeV0;ok;FG0oo?ZkD01Oo@[;Cojk>Gon^cUoo[/iKok;>E00;ok;>D0_o]
/i<01?l0<;Co0000o`000?oW/9X2onR`V@08onR`V?o`/hgol;>=oo2cSOo`/hcolK><oo6cRooAYjl2
om:X[@;ok[:>0_o_/Xd02?o`/Xcol;:;oo2bRoo`/X[olK::oo6bROoc]HOo00:D0_oY/9D01OoZ/9Co
jk2ConbaT_o//I;ok;6A00?olk>500Gom;>4ooBcPood/h?om;>2ooFdPP03om6Y[`?ol[>800Ool[>7
oo>cQ_oc/hGolk>5ooBcQ?od/h?om;B300?omkEo0_og]Gh2onjdT`05onjdT_o_]97ol;F@oo2eT?of
]Gl00_og]Gl01Oog]GkomkEmooNeOOog]Wgon;Im00;on;Il0_oh]W/01?oi]W[ockG0olne`?o?]L02
ooNhQ0;omkR300GomkV3ooRiP_oh^H;on;V1ooVjP@04ooZiN`Con[Yj00WonkYjoiTY0?od`iWomL>I
ooG4VOofa9Som/FHooO6V?ok_Gl01?ok_Wl01_ok_gooo;moooc0Oool`Goo0000oo_3Q`;onlB900Wo
nlB:oo_5S?okaXgod]OLom?Hg?oCfMgonlZBoo_;T_okbi<00_okc9@03?okcYKonlZCoo[;U?ojbiKo
n/bGoo[=VOoXdKooim71onGA`ooSdLGoC8c[o`0:U`;oX/Sc00Cok]NkonkH_?o]f;gok=Ro0_ooool0
0ol0003oooooooooo`0Iooooo`005oooool00ol0003oooooooooo`0Looooo`?oX[CU00?odKg6om:m
aOoI_[l00_oI_[h01?oJ_[gofkfloef?j?mMSnP2omNh^`03omNh^_oS^JcohkV/00;oi;V[00?oi;VZ
onFiZOo7//D00_o7//D2onFfY@05onFfY?oV]Z?oi[JSonJfXooW]Z800_lVFm001OoQ/jOoh[>Uon>c
Y?oS/jCoi;>S00;ok;FH0_o/]IL01Oo]]IKocj^eom2/]?o@[;Cojk>G00;ojk>F00?ok;>EonbcU?o]
/i<00ol000001?l0;kCoik2JonN`V_oX/9T2onR`V006onVaUoo`/hgol;><oo2cS?oa/hcolK>;0ooB
Z:d01_oDZJcokk:=onnbSOo_/Xgol;:<oo2bR`;ol;::00GolK::oo6bROoa/XSom;F6o`02U002onZ`
U004on^`Too//I;ok;6BonbaT@;olk>50_od/h@2ooBcP`03ooBcP_oe]8;omKB100;odJV_00CodjZ^
oo:cR?ob/hOol[>70ooc/hD00ood/hCom;>3ooBdP`03ooNeO`;omkEn00Co001/onjdT_o^]9;okkBA
0_o`]I001Ooa]XoomkEoooNeO_og]GkomkEm00;omkIm00?on;ImooRfO?oh]W`00_oh]W/01?oi]W[o
nKMjolne`?o@]l02ooNhQ003ooNhPoog^H?omkV300;on;V200?on;V1ooVjPOoj^G/00ooj^G/4ooZj
NP07oo^jN_ok^g[omL>IooG3VOoea9Wom/BHooK5V002ooO6V0?onkio0_ok_gl03?ol_gooo<1oooc1
Ool0003onl>8oo_4ROoka8[onlF;oo_5S?okaXgon/N?om?Hg0;oe=[M00Oonl^Boo_<U?okc9ConlbD
oo_>U_okcYOon/^D00;on/bG00kon/fIooW>W?oicikoiM73on?AaOoRdLOoCHc[o`0c]onUbO;oYl[b
ongH_Oo]f;kok=RooncI`0;ooooo00?o0000ooooooooool06?ooool001Oooooo00?o0000oooooooo
ool07Oooool2oj:di@?od[g500GofKjnomZn_OoJ_[gofkflom^m^`02oeZ=j005omNh^ooG^;[of;Ri
on>i[?oT^J/00_oT^JX00ooU^JWoiKVXolNba@02olRba0;oiKJT0ooV]Z<00ooW]Z;oikJQobIKd002
on:cY@04on>cY?oT/j?oi;>SonBcXP?ok;FG00GokKFFom2/]?o@[;Cod:bdom://P02on^cUP?o0000
0_o]/i<01Oo]/i;o02ndonN`V_oW/9[oj;2I00;oj;2H00GojK6Goo2cSOo`/hcol;><oo6cS002oo6c
R`03om:X[OoDZJcoe:V/00?okk:=00Wol;:<oo2bRoo`/X[ol;::oo6bR_oa/XWolK:8ooBeQ_l00Y@0
0_oZ/9@01_o[/9?ok;6BonbaT_o//I7okK6@oo>cQ@;om;>40_od/h<01?od/h;omKB2ooFdPOoAZJl2
om>Z[P03oo:cR?ob/hOol[>700?olk>500Com;>4ooBcPood]8?omKB20_og]Gl3ooNeOP;ok[BB00Go
kkBAoo2eT?o`]I3olKJ?ooNeO`02ooNeOP04ooNeOOog]Wgon;ImooRfO@;on;Il0_oh]W/01ooi]W[o
nKMjom2g`?o@]l3od[S0ooNhQ?og^8<00_og^H<2ooRiPP03ooRiPOoi^X7onKZ000?on[Uk1?oj^WX0
1?ok^W[onk]joo^kN_oea9T2ooK4V003ooK5V?ogaYSomlJH00?onkio0_ok_gl01ool_gooo<1oooc1
Oool`H3o0000oo_4ROoka8X00_okaH`01_okaXgon/N?oo[8TOoDf]goe=_Moo_;T`?onlbD00WonljF
oo_>Uookd9Won/bGoo[=VOoicI[onLjLooW?W_oSdLD00_oRdLL01Om?SN_o01jXo`0k_OnWb_;oZL_a
00;ok=Ro00?ok=W0ooooooooool00_l0000Iooooo`005oooool00ol0003oooooooooo`0Nooooo`;o
X[CU0_oB_LD01ooC_LCof[jmom^m_?oK_Kcofkfkombm^_mGRnP00_oG^;X01?oH^;WofKVhonBiZooT
^JX2onFiZ@;oiKVX00?ob;;4olVb`oo9//<00ooV]Z<2onNfXP05onNfXOlTFLoo95W?on:cYOoS/j@0
0_oT/j<01?oT/j;ok;FGonbeUoo/]IL2onfeUP03om2/]?oB[;;o000000;o000000?ok;>EonbcU?o]
/i<00_o]/i<01_o]/i;o032do`0_]?oW/9[oj;2IonR`V0;ojK6G00Ooj[6Foo2cS?oa/hcolK><oo6c
Rooa/h[odZR]00;oe:V/0oo_/Xd00oo`/Xcol;:;oo2bRP02oo6bRP05oo6bROoa/XSol[:8ooBeQ_l0
0Y@00_o[/9<01Oo//I;ok;6AonbaTOo]/I3olk>500;om;>40_od/h<00ood/h;omKB2ooFdP@03om>Z
[P03omFZ[Oob/hOolk>600?olk>500?om;>4ooBcPood]8<00_oe]8801Oog]GoomkEnooNeO_og]Gko
001X00;okkBA0_o`]I001_oa]XoolKJ>ooNeO_og]GkomkEmooNfO@;on;Im0_oh]W`2ooRfN`08ooVf
N_oi]g[onKMjom2g`?oB^<3omkR4ooNhPoog^H<3ooRiPP04ooRiPOoi^X7onKZ0ooVjO`;on[Uk1?oj
^WX01Ook^W[onk]joo^kN_ok_7[om/BH00;om/FH0_ogaYP01?ohb9Oonkiooo^nOook_gl2ooboO`07
ooc0Oool`Gooo<60ooc2POl0003onlB:oo_5S002oo_6S@07oo[7Soojb97on/RBomCKgOoEgMgoe]gM
oo_<U002oo_>UP0>oo_>Uookd9Wonm2Joo[=VOoicI[onLjLooW?W_ohd:;oh]77on3Ab_oNdLcoD8k/
o`0NZ?l0A<@2oj_<l@03oncI`?o[fL;oj]W300;ooooo00?o0000ooooooooool05oooool001Oooooo
00?o0000ooooooooool07oooool2oj:di@04om:maOoC_LCoe;g3om^m_0;ofkfk00?og;fjoe>9j?mC
RNP00_oH^;T01?oI^KSoi;VZonBiZ_oU^JT3onFiZ0?obK;300Cobk?3onJfXooV]Z?oikJR0_oW]Z40
1OoX]Z3o95W?on>cY?oS/jCoi;>S00;oi;>R00CoiK>RonbeUoo]]IKokKFF0ol000001?oB[;;odjfa
onbcUOo//iD3onfcT`;okK>B00Gok[>Ao`0`]?oX/9Woj;2IonR`V002onVaU`03onZaU_o`/hcolK><
00;olK>;00KolK>:omBY[?oDZJcoe:V/omJYZ_o_/Xd2oo2bS003oo2bRoo`/X[olK::00;olK:900Co
lK:8oo:bR?ob/hOo006D0_o[/9<01Oo//I;ok;6AonbaTOo]/I3ok[6?00;om;>40_od/h<01Ood/h;o
mKB2ooFdPOoe]87odjZ^00;oeJZ]00?ol[>7oo>cQ_oc/hD00_oc/hD00ood/hCom;>3ooBdP`02ooFd
PP05ooFdPOog]GkomkEnooNeO_og]Gd00_o_]942oo2eT007oo6fSooa]XkomkEnooNeO_og]GgomkIm
ooRfO@03ooRfO0;on;Ik00SonKIjooVgN_oi]g[onKMjom:h`?oC^/3omkR3ooNiP`?on;V200Kon;V1
ooVjPOoi^X3onKYoooZkOooj^G/4ooZjNP06oo^jN_ok^g[onk]joo^lN_nW<P3om/FH0_ogaYP01_oh
aiOon<RGooS9Uook_WoonkmoooboO`;oo<1o00goo<5oooc1P?ol`X7oo<>1o`000?okaHconlJ=oo_6
S_ojahoon/RAoo[8T_oDc]CoeMgM00;oe]kM00gonljFoo_>UookcYOonm2Ioo_@V_ojcIWonLjLooW?
W_ohcj3on=2RooOAY?oPdL[og]7<00;oDHo/0_l0C<X01On]cO3o[lk`on_I`_oZfL?ojMW400;ooooo
00?o0000ooooooooool05_ooool001Oooooo00?o0000ooooooooool08?ooool2oj:di@04om>ma?oD
_L?oeKg2omFm`P?og;fj0_mCRNP2omVi^003omZi^?oT^J[oiKVY00?oiKVX00Coi[VWolVb`oo;/l?o
bk?30_oV]Z<01?oW]Z;oikJQonNfXOoX]Z02ob9HcP;oi;>S00?oi;>RonFcX_oU/j800ol000000oo]
]IKokKFEom://P02om>]/@03onbcUOo//iCokK>C00;okK>C00CokK>BonjcTOo^/i7o036d0_oX/9T0
1_oX/9SojK6GonZaU_oZ/IKoj[6Eoo6cS0;olK>;00?olK>:oo:cROoDZJ`00_oFZJX01_o_/Xgol;:<
oo2bS?o`/X_ol;::oo6bRP;olK:900GolK:8oo:bR?ob/hOo006Don^`T`02onbaTP04onbaTOo]/I3o
kK6@onjaS`;om;>40_od/h<01?od/h;omKB2ooFdPOoe]843omFZ[@04omN/[?oc/hKolk>5oo>cQ@;o
m;>400Gom;>3ooBdPooe]8;omKB2ooFdP@03ooNeOP03ooNeOOl006Col;F@00;ol;F@00OolKJ?oo6f
S_ob]XgomkEnooNeOOog]Wgon;Im00?on;Il0_oh]W/01?oi]W[onKMjooVgN_oi]gX2om>j`004omFk
`?og^H?on;V2ooRiPP;on;V10_oi^X000ooi^Woon[]oooZkO`04ooZjNP?onk]j00?onkajoo^lNonW
<P000_ogaYP01oohaiOon<RGooS9UooibIOonkmoooboOool`7l00_ol`Gl01_ol`H3oo<:1ooc3POl0
003ooLB3oo_6S@;on/N?00Son/RAoo[8T_ojbYKonL^GomKNgOoGgmgoen3Moo_>U`;onm2I00_onm2J
oo[AW?ojdYkonLnNooS?X?ohd:;omm6TomkAc?oKdLkofM3@oe>@k002o`0c^@06ojo>l?nac^oo/Lk_
on[I`ooYfLCoimW70_ooool00ol0003oooooooooo`0Eooooo`005_ooool00ol0003oooooooooo`0R
ooooo`;oX[CU00Coe;g3omFm`_oE_L;oe[g20_oL_KX00ooM_KWoD8SWoe28i`02omZi^003om^i]ooU
^JWoiKVX00;oiKVX00?oi[VWonJiY_o;/l<00_o</l82onNfXP04onNfXOoX]Z3oj;JPonRfX0;o8US>
00Goi;>So`000?l0003o0000onFcX@03onfeUP06onfeUOoC[K7odjfaom>]/OoE[K3ok;>D0oo]/i<0
1Oo]/i;ok[>AonjcTOo^/i7o036d00;oj;2H00GojK6GonZaU_oZ/IKoj[6Eon^aU002oo6cR`03oo6c
R_ob/hWoeZVZ00;oeZVZ00Oof:ZXoo2bS?o`/X_ol;:;oo2bR_oa/X[olK:900;olK:800Col[:8oo:c
Qoob/hOo006D0_o//I801_o//I7okK6@onfaT?o^/Hook[:>ooBcQ0;om;>300?om;>2ooFdP_oe]840
0_oe]8401?oEZZgoejb/omN/[?oc/hH2oo>cQ@;om;>400Kom;>3ooBdPooe]8;omKB2ooFdPOof]842
ooNeOP04ooNeOOog]Wgol;F@oo2eT0;olKJ?00KolKJ>oo:fSOob]hcomkEmooNfOOoh]Wd2ooRfO0?o
n;Ik00SonKIjooVgN_oi]g[onKMjonf@9OoC^/3oeK_0ooNiP`;on;V200Gon;V1ooVjPOoi^X3onKZ0
ooVjO`02ooZkO`Con[Yj0ook^gX00ook_7[onkakoo^lN`02ooO6V008ooS7Uoohb9Oon<VGooW9Uooj
biOoo;moooc0Oool`Gl2ooc1P006ooc2POol`h7oo<>2o`000?omaHCon/N?0_ojb9401OojbICon/ZF
ooW;Uoo=cMWoemoM00;oen7M00Konm2Ioo_@V_okd9[on]6Loo[BW_oicih2ooS@XP0=ooOAY?ofdZWo
fm7>omW@d?oGd=;oEI7/o`0k_ol8IM[o/Lk_ok;?k_oYfLCoj=W6onOIa`02ooooo`03o`000?oooooo
oooo01Gooooo000Fooooo`03o`000?oooooooooo02?ooooo0_nS]>D01?oE_L;oe[g2omJm`_oF_L42
omfm^@06omfm^?m=Q^Oof[VhomZi^?oK^KOofkVf0_oU^JP2onJiY`05onJiY_o</l;oc;?2olbc`_o=
/l400_oW]Z43onRfX0?o000000Koi;>RonFcX_oU/j7oiK>QonJcX?o]]IH2onfeU@05onjeU?oC[K7o
eJf`omF]/?o//i@00_o]/i<2onfcTP?ok[>A00Go0c:eonR`V?oX/9SojK6GonZaUP02onZaU@07on^a
U?oa/h_olK>;oo6cR_ob/hWol[B9omJYZP02omRZZ007oo2bS?o`/X_ol;:;oo2bR_oa/X[olK:9oo6b
R002oo:bR0;ol[>700Go006DonbaT_o//I;ok;6AonfaT002onjaS`06onjbS_od/hCom;>3ooBcPood
/h;omKB20ooe]8401?oEZZgoejb/omN/[?oI[JX2oo>cQ@04ooBcQ?od/h?om;>3ooBdP`;omKB200Co
mKB1ooJdPOof]83omkEn0_og]Wd02_l0067ol;F@oo6fSooa]XoolKJ>oo:fSOob]hcomkEmooNfOOoh
]Wd2ooRfO0?on;Ik00GonKIjooVgN_oi]g[onKMjooVgN@02omFk`005omNm`?oh^H;on;V2ooRiPOoi
^X400_oi^X001?oi^Woon[]oooZkOooj_7h3ooZjNP?onk]j00Gonkajoo^lNook_7_onkekooS7U`02
ooS8U`07ooS9UooibIOon/^Goo[<Uool`7ooo<5oooc1P002ooc2P@0Kooc3POol`h;ooLB3o`000?om
aXGon/RAoo[8T_ojbICon/ZFooW;Uooic9_ob/cKomOQgOoHhMgof>;Moo_@V_ojdI_on]6Loo[BW_oi
dj7onMBSooOAY?ofdJOom]:YooCC[?oId=3oe<oD00;oEi;/00So04?4oaA]gondcnko]]3]onOIaooV
fLSoi=W:ooooo`;o00005_ooool001Kooooo00?o0000ooooooooool08oooool3oj>ei@04omJm`_oF
_L7oe[g1omNm`0;ogKfh00Gog[fhodV5iooK^KOofkVgom^i]P02ombi]@05onJiYooV^JKoi[VVonJi
Y_o</l800_o=/l42onNfX@04onRfX?l0003o0000onRfW`;o7UO>0_oU/j82onFcX@03onJcX?oW]9oo
kKFE00;ok[FD0ooE[K03onfcT`;okK>B0_o^/i42onjcT004o`<b]OoY/IOojK6GonZaUP;oj[6E00Oo
jk6DonbaTooa/h_olK>:oo:cROob]8WoeZVZ00;of:ZX00OofZ^Woo2bRoo`/X[ol;::oo6bR_oa/XWo
lK:800;ol[:80_ob/hL01Oob/hKo006DonbaTOo//I7okK6@00;ok[6?00?ok[:>onnbSOod/h<00_od
/h801?oe]8;omKB1ooFdPOoe]842omN/[0;ofJfZ0_oc/hD01?od/hCom;>3ooBcPood]8<2ooFdPP05
ooFdPOof]87om[B0ooNeO_og]Wd00_oh]Wd02Oo`]I3olKJ?oo6fS_oa]Xkol[J=oo:gS?oc]h_omkIm
ooRfO@02ooRfO0?on;Ik00KonKIjooVgN_oi]g[onKMjooVgNOoE^l02omNm`004omRo`?oh^H;on;V1
ooVjP@;onKZ000?onKYoooZkOooj^gl00_oj_7h2ooZjNP?onk]j0ook_7/03?ok_G_oo;elooS8Uooh
bIOonLVGooW:UoojbiOon/bGoo[=V?ol`Gooo<60ooc2P@;oo<>100Koo<>2oog4Pol0003ooLJ5oog7
Q_ojb982oo[:UP05ooW<VOoic9_on<fMolO;gOoHhMd00_oIh]d03?ojdIcon]:Noo[CWooidj7onMBS
ooOAY?ofdJOom]:YooCC[?obe;7oe<oDom;?e`;oFI?]0_lOMN<01onfd>go]m3]onKIb?oTfL[ohmW<
ooooool000005_ooool001Kooooo00?o0000ooooooooool09?ooool3oj>ei@04omJm`OoG_L3oekg0
omNm_`;og[fh0_m5PnH2om^i]P;og;Ve00OogKVdonJiY_oV^JKoi[VVonNiYOo=/l7oc[C000?o0000
00Goj;JPonRfWooX]YoojKJNoaiGcP02onFcXP05onFcXOoV/j3oi[>PonNdWooW]9h00oo^]I@00ooE
[K3oejj_omR^[@02onfcT`07onfcT_o^/i7ok[>AonjcTOo^/i3okk>@o`<b]@02onVaU`05onZaU_oZ
/IGojk6Don^aU?o//I<00_oa/hX01?ob/hWol[B9omRZZ?oHZZP2omZ[Y`07oo2bRoo`/X[ol;::oo6b
R_oa/XWolK:8oo:bR003oo:cQ`06oo:cQ_l00YCok;6AonbaTOo]/I3ok[6?0_o^/Xh01Oo_/Xgom;>3
ooBcP_od/h;omKB200?omKB100Som[B0omN/[?oI[J[ofJfZom^]ZOoc/hGom;>4ooBcP`;om;B300Co
mKB2ooFdPOoe]87om[B10_of]8001Oog]Wgon;ImooRfOOoh]WcolKJ?00;olKJ>00Gol[J=oo:gS?oc
]h_olkN;ooRfO@02ooRfO0?on;Ik00ConKIjooVgN_oi]g[onKMj0_oi]gT01_oG_L3of;o0omRo`?oh
^H;on;V1ooVjP@;onKZ000?onKYoooZkOooj^gl00_oj_7h00ook_7kon[Yjoo^kNP02oo^kNP?onkak
01_onkekoobmO?ol_Wcon<VGooW9UooibYOon/^Goo[<UoojcISonljHooc1P?ol`X7oo<>1ooc3P_om
a8;ooLB3oog5Q?l0003ooLN6oog8R?ojbYKonL^GooW<VOoic9_on<fMolG:g_o2bN000_oIh]d01ooI
hmgon]:Noo[CWooidj7onMBSooSEY_ofdZT00_oddj`02?obe;7olMBcom;?eoo?c]SoFiC]o`5IdolY
O>Ko]m3]0_nhd>`01OoTfL[oh]S=on3Hc_oooooo000001Gooooo000Fooooo`;o00009_ooool3oj>e
i@04omNm`?oG_KooekfoomRm_`;og[fg0_m5PnH3ombi]@04omfi]?oV^JKoi[VVonJiYP?o000000Go
c[C0olnd_ooX]Z3oj;JPonRfW`02onVfWP;o7UO>0_oU/j401?oV/j3oikBOonNdWooW]9h3onjeU0;o
ejj_00Cof:j]onfcToo]/i?okK>B0oo^/i401?o^/i3okk>@o`De]ol5=KL2onZaUP05onZaUOo[/ICo
k;6ConbaTooa/hX00_ob/hT2oo:dR@05omRZZ?oJZjOofZ^Wom^/Y_o`/XX00_oa/XX00ooa/XWolK:8
oo:bR003oo:cQ`03oo:cQ_oc/hKok;6A00;okK6@00?ok[6?onjbS_o^/Xh00_o_/Xd00ood/h;omKB2
ooFdPP03ooFdP@03ooJdP?oI[J[ofJfZ00;ofjfY00Colk>5ooBcQ?od/h?om;B30_oe]882ooFdP@04
ooJdPOof]83om[B0ooNfO@;on;Im00?on;Iloo6fSooa]Xh00_ob]Xd01?ob]hcolkN;oo>gRooh]Wd2
ooRfO0;on;Ik0_oi]WX3ooVgNP;onKMi0ooH_l001?oJ`L7on;V1ooVjPOoi^X02ooVjO`;on[]o0_oj
_7h00ook_7konkenoo^kNP02oo^kNP;onkak0_ok_G/01?ol_Gcoo;ilooboOOoibIL2oo[;U`07oo[<
UoojcISonljHoo_?VOol`X7oo<>1ooc3PP02oog4P`06oog5Q?omaXGo0000oog8R?ombH[onL^G0_oi
c9/04_ohcIgomlnRol;9h?nob>;ofN;Mom[SgOoJhmconM>QooWDXooieJGon=FVooSFZ?oddjcolm>^
oo;D/Ooae;?oclkHolc=fP;oGYK]00[o2f7Hoc>3jOlcPnWo^M3/okW@jooRf<goh=S>omoHd?oooooo
00005?ooool001Kooooo00?o0000ooooooooool09_ooool01?nS]NGoXkKUoj>fiOoG_Kl2omRm_`03
omVm__oO_KOogkfg00;o@X7V00?og;Veomfi]?oM^K@00ol00002onNiY@03oljd`?o?];oockBo00;o
j;JP00Goj;JOonVfW_oY]YkojKJNoaiGcP02onFcX@06onJcX?oW]9ooikBOonNdW_oX]9gok[FD0_o^
]I<2omR^[@03omZ_[?o]/i;okK>B00?ok[>A00Cok[>@onncT?o_/hoo1CFg0_oZ/IH01OoZ/IGojk6D
onbaToo//I?okK:B00;ol[>90_ob]8T2omZ[Y`;ofjbV00Kol;::oo6bR_oa/X[olK:9oo6bR?ob/XP3
oo:cQ`03oo:cQ_oc/hKo00BF00;okK6@00?ok[6?onjbS_o_/Xd00_o_/Xd00ood/h;omKB2ooFdPP03
ooFdP@;om[B000OofJfZom^]ZOoK[JWog:nXooBcQ?od/h?om;B300;omKB200?omKB1ooJdPOof]840
0_of]8000oog]Goon;ImooRfO@02ooRfO004oo6fS_ob]Xgol[J=oo:gS0;olkN;00?om;R:ooRfO?oh
]W`00_oh]W/00ooi]W[onKMjooVgNP02ooVgNP;onKMi00Gon[QiomRo`?oJ`L7of/71om_2`@02ooVj
P004ooVjOooj^goon[]oooZkO`;on[an00?onkanoo^mO_ok_Wd00_ok^gX2oo^lN`08oo^mNool_Gco
o;eloobnO?ol_ggoo;mnoo[;Uoojc9L2oo[=V00Eoo_>V?okciWonm6Iooc3POol`h;ooLB3oog5Q?om
aXCooLJ5oog7Q_l0003ooLV:oog;SOoic9_on<fMooS>X?ogcj;om/nUoko8h_nlan?of^?M00;of^?L
00KonMBSooWEYOoheJKon=JXooKG[?obe;42oo7D/`03onkE^Oo<cM[ob/cL00;oH9O^00Go56SLodN@
k_nid>_o^]3[on3HcP02omoHd003ooooool0003ooooo00Oooooo0ol00004ooooo`;o00000oooool0
01Gooooo00?o0000ooooooooool0:?ooool01?nS]^GoY;KVojBfi_oH_Kl3omVm_P;ogkff00Ko?h3V
o`000?l0003o0000omfi]?oN^K<3onNiY@04onRiY?o?];ood;Fnom2e_P;oj;JO0_oY]Yh00ooY]Ygo
j[JMoaeGcP02onJcX003onNdWooW]9koikBN00;oj;BM0_o^]I<2omR^[@03omZ_[?o]/i;okK>B00;o
k[>A0_o^/i001Oo_/i3okk>?o`Th^?l9>;Soj[6E00;ojk6D00Cok;6ConbbToo]/Y;ol[>90oob]8T0
1_ob]8SofZ^Wom^/Y_oK[:KogJbToo6bRP;olK:900ColK:8oo:bR?ob/hOol[>70_ob/hH00ooc/hKo
00FGonfaT002onjaS`06onjbS_o_/Xgokk:=onnbSOod/h;omKB21?oe]842ooJdP0;ofjfY0_oL[jP0
0ood/hCom;>3ooBdP`02ooFdPP03ooFdPOof]87om[B100;om[B000?omkEoooNeO_oh]Wd00_oh]W`0
1?oa]Xkol[J=oo:gS?ob]h`2oo>gR`03ooBhR_od^8Won;Il00;on;Ik00?onKIjooVgN_oi]gX00_oi
]gX2ooVgN@;on[Qi00?of/71om_2`OoK`/400_oi^X001?oi^Woon[]oooZkOooj^gl2ooZlOP05oo^l
O_ok_Gkonkimoo^nOOok^gX00_ok_7/02?ok_G_oo;eloobnO?ol_Wcoo;mmooboO_ol`7kon/bG0_oj
cIP02?okcYSonlnIoo_AVOokdY[onm:Koog4PoomaHCooLJ50_omahH02ol0003ooLV:oog;SOolc8ko
n<fMooS>X?ogcj;om/nUokc7honha^GoX2d000?of^?L00Won=FVooSFZ?ogej[om]N/ooCH/Ooae;?o
l=BfonkE^Oo:c=`00_o7bmd02OmSVNko7VoOoai_gom@U_3o^]3[ok_@j_oOf=3ogMOAomcGd`02o`00
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`005Oooool00ol0
003oooooooooo`0Zooooo`03ojBfi_oI_KkofKfn00;ofKfn0ol000002OlkO^GogKVdomfi]?oM^KCo
g[Vcomji/_oW^JGoikVTonRiY003om2e_P06om:e_OoY]YkojKJNonVfW_oY]Ygoj[JM0_lMEll2onNd
W`04onNdW_oX]9goj;BMonRdW@?ok[FC0_oJ[j`01OoK[j_ok[>AonjcTOo^/i7ok[>@00;okk>@0_o_
/hl00ol9>;Soj[6Eon^aU002onbaT`03onbbToo]/Y;okK:A00?ol[B900?ol[B8omZ[YooK[:H00_oM
[:@01Ooa/X[olK:9oo6bROoa/XSol[:800;ol[>70_ob/hH00ooc/hKolk>5o`05U`02onjaS`06onjb
S_o_/Xgokk:=onnbSOo`/X_omKB21?oe]842ooJdP007ooJdOooK[JWog:nXomb_Z?od/hCom;>3ooBd
P`02ooFdPP03ooFdPOof]87om[B000;om[B000?omkEoooNeO_og]Gh00ooh]W`00oob]Xgol[N<oo>g
R`02oo>gR`03ooBhR_od^8Won;Il00;on;Ik00?onKIjooVgN_oi]gX00_oi]gX2ooVgN@?on[Qi00Go
fl;1omg4`OoNa/7onKZ0ooVjO`02ooZkO`05ooZkO_oj_7kon[anoo^lO_ok_Gh00_ok_Wd01_ol_ggo
nkakoo^lNook_G_oo;eloobnO0;oo;mm00koo;mnooc0O_ol`H3on/fHoo_>V?okciWonm2Ioo_AVOok
dY[onm:Koo_DW?omaHCooLJ5oog7QP;ooLR800Co0000oog;SOolc8koo<fB0_ogcj801_ofcjGom=6[
oo?A[OneaNKoX2d0om[Sg0;of^;L00Gon=JXooKG[?ofejcom=Raoo?H/`02onkE^@03on_E__o7bmgo
a<[O00;oII[^00[o:7KSoeRKlOmHVo7o^m3Zok_@jOoLem?of]KDomSFe_oooooo00001oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo000Eooooo`03o`000?oooooooooo
02_ooooo00CoY;KVo`000?l0003o00000_oJ_Kd01?oP_KGo>7gUocQmiOoM^K@2omji/`06omji/_oO
^[;oikVTonRiY?oX^J?od;Fn0_oB]Kd01ooC][gojKJNonVfW_oY]Ygoj[JMonZfW?lMEll00_oW]9l0
1OoW]9koj;BMonRdWOoX]9gojKBL00;ok[FC0_oJ[j`01OoK[j_ok[>AonjcTOo^/i7ok[>@00;okk>@
0_o_/hl00ol9>;Soj[6Eon^aU002onbaT`04onbbToo]/Y;okK:AonjbT0;ol[B900?ol[B8om^/Y_oK
[:H00_oM[:@01OoN[J?olK:9oo6bR?oa/XSol[:800;ol[>700Gol[>6oo>cQ_oc/hKolk>5o`05U`02
onjaS`06onjbS_o_/Xgokk:=onnbSOo`/X_omKB21?oe]842ooJdP007ooJdOooK[JWog:nXomb_Z?oN
/:Oom;>3ooBdP`02ooFdPP03ooFdPOof]87om[B000;om[B000?omkEoooNeO_og]Gh00ooh]W`01?ob
]Xgol[N<oo>gRooc]h/2ooBhRP05ooBhROoe^8Won;IkooRfNooi]WX00ooi]gX3ooVgN@?on[Qi00Go
n[Uiomg4`OoNa/7oglS2ooVjO`02ooZkO`?on[an00_onkanoo^mO_ok_WgonkimooboOOol`7konkak
oo^mNool_Gcoo;ilooboO@02ooboOP05ooc0O_ol`H3oo<:1oo_>V?okciT00_okdIT01ookdY[onm:K
oo_DW?okeIgooLJ5oog7Q_omb8P00_ombHX02?l0003oo<b>ooc=T_olcYCom/nUooG@Z?oddJ_olm6]
0_nba>L00ol0?K[of^;Lom[Rg002om[Rg009ooGH[oodf;7olmRconkE^Oo]eKcojmFnonWE`Oo4b]oo
`/WP00;oJ9c^00Wo<GcUof2Ol_mPWo;o^m3Yok_?jOoJe]Cof=KFomOFeol000001oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo000Eooooo`;o0000:_ooool3o`000003
ojBfi_oI_Kkof[fm00;of[fm00Gofkflon2m]OlhONGo>7gUomji/`02omji/P03omnj/_oX^JCoj;VT
00;oj;VS00?od[Fmom>f_OoC][d00_oY]Yh2onZfW@03onZfW?lNF<oo7US?00;oikBN0ooX]9d01?oY
]9cojKBKonjeToo_]I82om^_Z`05omb`Z_o^/i7ok[>AonjcT?o_/i000oo_/hl01Oo`]8kojk6Don^a
U?o//I?ok;:C00;okK:B00?okK:AonjbT?ob]8T00oob]8P01OoK[:KogJbTomj]XooN[J?olK:900;o
lK:800Gol[:8oo:cQoob/hOol[>6oo>cQP03oo>cQ@03o`05Uoo^/Xkok[:>00;okk:=00?ol;:<oo2b
Rooa/hX01?oe]842ooJdP003ooJdOooL[jSog:nX00;og[2W00Kom;>3ooBdPooe]8;omKB2ooFdPOof
]843ooJdP004ooNeOoog]GkomkEnooNfOP?on;Il00?ol[N<oo>gRooc]h/00_od^8X01Ood^8WomKR9
ooRfNooh]W_onKIj00?onKMj0ooi]gT3ooZhN@05ooZiNOoNa/7og/K1omo8`_oQbl800_oj^gl3ooZl
OP05oo^lO_ok_Gkonkimoo^nOOol_gd00_ol`7h06ool`Gkoo;eloobnO?ol_ggoo;mnooc0O_ol`7oo
o<60ooc2POol`h?onlnIoo_AVOokdY[onm:Koo_CVooke9conmFMoo_GWookej3ooLR8oog9R_ombhgo
0000ooc<S_olcI;oo<jDoo_@V002ooCAZ`05oo?A[Oo`d[?o[l;Xojo2j?l007L00_oJh]`03OoJhMco
m=Raoo?H/oocf;?olMVhoo3I^_o[eKkojMG1onGEaonob>7o_LORofjOkoljP^P00_mWXo<01onkcnWo
_<oYomSFe_oGe]Ooe=GHooooool000001_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool0
0ol0003oooooooooo`0Wooooo`;o00001?ooool01onT]nKof[fmomZm_OoJ_Kgofkflom^n_?oP_K@0
0_leO>D01?oN^K;ogkZbomnj/_oP^[43onRiX`?odkJm00?oe;JlonVfWOoZ]Yd00_oZ]Y`01?o[]Yco
7US?onNdW_oW]9h2onRdW@;ojKBL00?ojKBKonZeVoo_]I800_oK[j/01OoL/:[ok[>AonjcTOo^/i3o
kk>@00?okk>?00Kol;B>on^aU?o[/ICok;6ConbbToo]/Y82onfbT@;ok[:@0_ob]8P00ooc]8SogJbT
omf/Y002omj]X`04on2^X_oa/XSol[:8oo:bR0;ol[>700?ol[>6oo>cQ_oc/hD00_oc/hD00ol01iWo
k[:>onjbSP02onnbS@03oo2bS?o`/X_olK>:00?omKB10oof]802ooJdO`05omb_Z?oN/:Oog[2Won2a
YOod]8<00_oe]8801_oe]87om[B1ooJdP?of]83om[EoooNeO`;omkEn00GomkInooNfOOoh]Wcon;Il
oo:gS002oo>gR`07ooBhR_od^8Wom;R9ooFhROof^HOon;IkooVfNP03ooVgNP?onKMi0ooj^7T2ooZi
N@;oglS200?ohL_2ooZkOooj^gl00_oj_7h2oo^lOP04oo^mO_ok_WgonkimooboO@;oo<1n00Ooo<5n
oobmO?ol_Wcoo;mmooboO_ol`7koo<6000;oo<:100Goo<>3ooc4Q?olaHKonm:Joo_BV`02oo_DW00B
oo_FW_okeioonmNPoo_IX_ombH[ooL^=ooc<S_l0003oo<fBooc>U?okd9Sonm6Koo?A[Oobd[3ol=:c
onoC]on/`NWoZL3Z0_l0HmH03OoJhMcofN7Loo?H/oobfKKolMVhoo3I^_oYeL7oimG4onGEaooReLWo
_LORok[6homaXNl00_m2QnX01_mdZoCo_<oYok_?jOnkcnWoe=GHom?DfP;o00001?ooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool00005ooooool0003oooooooooool000002_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo0ol00007ooooo`07ojBgi_oJ_Kgofkfl
om^m_?oK_[cofkjkon6m]002oc5ji004omnj/_oP^[7oh;Zaon6j/0?oj;VS00OodkJmomBf_?oD][co
jKJMonZfWOoZ]YcojkJL00;ojkNL00Co7UW@onRdWOoX]9goj;BM0_oY]9`01?oY]9_oj[FKonneT_o_
]I82omb`ZP04omj`ZOo^/i3ok[>@onncT0?okk>?0_o`]8h2onbaT`04onbbToo]/Y;okK:AonfbT@;o
k[:@0_ob]8P2oo>dR005omf/Y?oN[J?oh:jRon2^X_oa/XP00_ob/XP2oo:cQ`03oo:cQ_oc/hKolk>5
00;olk>500?o00ZKonjbS_o_/Xd00_o_/Xd01?o`/Xcol;:;oo6cR_oa/hT2ooFdP@?om[B00_of]7l2
omj`Y`;oh;6U00Goh[6TooFdP_oe]8;omKB1ooJdP@02ooJdP007ooJeOoog]GoomkEnooNeO_og]Wko
mkImooRfO@02ooRfO0;olkN;00Oom;R:ooBhROoe^8WomKR9ooJiQooh]W_onKIj00?onKMj0_oi]gT4
ooZhN@;on[Ui00GoglS2on7;`_oQbl;oh/g3ooZkO`02ooZlOP03oo^lO_ok_Gkonken00;onkim00_o
o;mmooc0O_ol`7koo<5noog2O_om`gooo;mmooboO_ol`7koo<60ooc2P@02ooc3P`0Cooc4Q?olaHKo
o<J7oo_BVooke9conmFMoo_FW_okeioonmNPoo_IX_okfZCooL^=ooc<S_olcI;o0000oo_?U_okd9So
nm6Koo?A[@02oo3B/`06onoC]onY`>[oYkk[o`1Bc_l03IOofN7L0_oIh=`01OoHgmcol=Vjoo3I^_o]
fKooiMG700;oh]G900?o^/KSokS5i?mdXnl00_m;SN`2ogZ^m0;o^loY00CodmCJom7Dg?l0003o0000
1Oooool00ol0003oooooooooo`03ooooo`;o00000oooool00005ooooool0003oooooooooool00000
1oooool5o`0000?ooooo00?o0000ooooooooool08_ooool3o`0000_ooooo00SoYKSVom^m_?oK_[co
fkjlom^n^ooL_[_ohKfdobiii0?oh;Za00gohKZ`on6k/?oX^J?oj;VSonViXooD][coeKNkomJh^ooZ
]Ygoj[JLon^fW?o[]icojkNK00;o7e[A0_oX]9d01_oY]9cojKBKonVdVooZ]I_ojkFJonneTP;og;2Z
00Cog[2YomnaYoo_/i3okk>@0_o_/hl3oo2dSP;ok;6C00?ok;:ConfbT_o]/Y400oo^/Y001?o_/hoo
l[B8oo>dR?oc]8L2omj]X`;oh:jR00?ohZjQoo:bR?ob/hL00_ob/hL00oob/hKolk>6oo>cQ@02oo>c
Q@03ooBcQ?l02Y_okk:=00;okk:=00Kol;:<oo2bRooa/h[olK>9oo:cROoe]843ooJdP0?om[Ao00Go
g[2Won2aYOoP/JGoh[6TooFdPP02ooFdP@05ooJdPOof]83om[B0ooJeOoog]Gl00_og]Gh02Oog]Wko
mkImooRfOOoh]Wgon;IlojY60?oc]h_om;R:ooBhR@02ooFhR@03ooJiQoog^XOonKIj00?onKMj0_oi
]gT4ooZhN@?on[Ui00CohL_2on;=`ooRcL?ohlo30_oj_7h00ook_7konkenoo^nO@02oo^nO@0<oobo
OOol`7koo<1nooc1O_om`WkooL=ooog4P?ol_gkoo<1nooc1P?ol`X7oo<>30_ola8@04oolaHKoo<J7
ooc7Roolb8gonmFMoo_GWookej3onmRQoo_IX_okfZCon]^Voo[LZ?olcI;oo<jDo`000?okd9Sonm6K
oo[BWooidj800_o_dkL04Oo[dkgoYkk[ojBmjol0FM?o9HCZomWPg?oHgmcoemoLoo3I^_o^fKgokMVo
onWJa?oReLWoh=C<omgDconhaNCo]/CU00;oN:G_00SoFYO_ogjam?mn/OCo^loYok_?j_oAe=cocmCM
o`00013ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0Oooooo`?o00003oooool01?nU^>Oofkjlom^n^ooK_[/2ombn^`07on6m
]?l[N>Coh;Zaon2j/OoQ^[3ohK^`on:k/002onViX`0:onViX_oE]k_oe[RkomNh^_oZ]YcojkJLon^g
W?o[]i_ok;NKoamJd@;oj;BM00CojKBLonVdVooZ]I_oj[FK0_o[]IX01?o_]I;og[2Yomj`ZOoO/JL2
onncT0;okk>?0oo`]8h01Oo`]8gok;:ConbbToo]/Y;okK:A00?ok[:@0_o_/hl01Ooc]8SolkB7omj]
XooN[J?oh:jR00;ohZjQ00Kol[:8oo:cQoob/hOol[>7oo:cQ_oc/hH2oo>cQ@;om;>400[o00fMonnb
SOo_/Xgokk:=oo2bS?o`/X_olK>:oo6cROob/hWomKB10_of]804ooJdO`;oh;6U0_oR/J@01?oe]8;o
mKB1ooFdPOof]842ooJdP006ooJeOoog]GoomkEnooNeO_og]WkomkIm0_oh]Wd02_oh]Wco[TP0ooBh
R_od^8[om;R9ooFhROof^HSom[V7ooNjQoog^XH3ooVgNP;onKMi1?oj^7T3ooZiN@08oo^jNOoRcL?o
hlo3on??`ooUe<Gon[anoo^lO_ok_Gh2oo^nO@;oo;mm0_ol`7h02_ol`GkooL9noog3Oooma83ooLF0
oog5POol`H3oo<:1ooc3Poola8@2ooc5QP06ooc6Qoolah_oo<R=oo_:T?o`ck3onmNP0_okfJ803_oj
fZGon]^Voo[LZ?oigJ_oo<jDo`000?okdI_on]6Moo[BWooidj;okm>gongC^_o[dkgoY;g[0_nR_>`0
3?l:H=Oo<hg^oc>=k_oGgmcoemkMongI_oo[f/;ojM[4onOIaooPe<cogMC?okK4i@;o]<CV00WoNjO_
of:Ll?n3/oCoPk?dok_?j_njd>_ocmCMolcDgol000004?ooool00005ooooool0003oooooooooool0
00002?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo01cooooo0ol0000Cooooo`03
ojFhiooK_[_og;jk00?og;jk00OohKfcobQghooQ^[3ohKZ`on6k/?oR^k3oh[^_00;ojKVR0_oF^;/0
1_oG^;[ojkJLon^fW?o[]icojkNKonbgV`;o85cB0_oY]9`00ooY]9_oj[FKon^eVP02on^eVP05on^f
VOoN/:Wogk6WomnaYooP/ZH00oo_/hl3oo2dSP05oo2dSOo//Y?okK:BonfbT_o]/Y400oo^/Y02onnc
S`03oo>dR?oc]8OolkB700;oh:jR0_oR[Z401_oS[iool[>7oo:cQoob/hOol[>6oo>cQP;olk>500Co
m;>4ooBdQ?od]8Co00fM0_o_/Xd2oo2bR`04oo6cR_oa/hWol[>9oo:cR0;om[B01?of]7l01_of]7ko
h;6Uon:aY?oS/j?omKB2ooFdP@;om[B10_of]8001_of]GoomkEoooNeO_og]GkomkInooNfO@;on;Im
00_on;MlooRfO?od^8[om;R:ooBhROoe^8Wom[V8ooJiQoog^XOomkZ6ooNkQP02ooVgNP;onKMi1?oj
^7T3ooZiN@;onkYi00Kohlo3onCAa?oUe<Goi]K6oo^lO_ok_Gh2oo^nO@0HooboOOol`7koo<1nooc0
O_ol`GkooL9noog3Oooma83ooLF0oog5POonah;oo/N3ooc3Poola8Coo<F6ooc6QoolahWoo<N;ooc8
SOokbY3onl^Cong@]_o/dKWonmZT0_ojfjH03_ojg:SonMf[ooSN[_ogg[3o0000oo[AWOojdYoonM>R
ooODZ?o[dkgojM?0onKD`ooTdlKoX;_/0_lDJ=`01?m=WOCoemkMomKMgOoEgMh2onWJa006onOIaooM
e<oofmCAomSDe?nda>Ko//?V0_moZNl2ofZQl@05ohbim?nid>_oooooooooool000004?ooool00005
ooooool0003oooooooooool000002Oooool2o`0000Cooooo0_l0000Jooooo`?o00005oooool00onU
^NOog;jkombn^`02ombn^`03omfn^ooQ_K?o97KS00;ohK^`00?oh[^`on:k[ooS^jl00_oY^J82omNh
^P04omRi^_o[]icojkNLon^gV`;ok;NK0_lPG=82onVdV`07onZeVoo[]I[ojkFJon^eV_o[]YWog[2Y
omnaY`02on2bYP?okk>?0oo`]8h01Oo`]8go8DW1onfbT_o]/Y;okK:A00;ok[:@0oo_/hl00oo_/hko
lkB7oo>dQ`02on2^XP;ohZjQ00?ohjnOoo:cQoob/hL00_ob/hH01?oc/hKolk>5oo>cQOod/h@2ooBd
Q003o`0=WOo_/Xgokk:=00;ol;:;00KolK>:oo6cROob/hWol[>8oo>dR?of]804ooJdO`06ooJdO_oR
/JCoh[6Ton>cXooU]:;omKB10_of]842ooJdP0;omkEo0_og]Gh01?og]WkomkImooRfOOoh]Wd2ooRg
O00;ooBhR_od^8Wom;R9ooFhROof^HSom[V7ooNjQoog^XKomk^6ooRkQOoi]gX00_oi]gT3ooZhN@Co
n[Ui0_ok^WT01_ok^gWoiMC5onGDaOoVe/KoimW7oo^mOP;onkim00?oo;mmooc0O_ol`7h00_ol`Gh0
3?om`WkooL=ooog4P?omaH3ooLF1ook7P_onah?oo/V5ooc4Q?olaHKoo<J7ooc7R`;oo<R=01ConlZ@
oo_;ToojcIOok=6ion[A_?l0CkWon]bXooWMZoohgJgon=j^ooON/?ofgkCo0000ooWCX_ohe:GommBX
ooGF[_oYdl3oi]C3onCCaP;oW[[/00[o7VoOo`1Fd?mHY?KoeMgNomCMg_oCg=ooimW7onKJbOoTf/co
f=CD0_oEdmL00onb`nKoooooooooo`07ooooo`03o`000?oooooooooo00gooooo0002ooooo`;o0000
2oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo0ol0000Kooooo`06ojFi
iooL_[_og;jkombn^ooM_[_ogKnj0_lQMN<2on:k/003on:k[ooS^joohkb_00;ojKVR0_oH^KX00ooI
^KWojkNKon^gV`02onbgV`05onbgV_lQGM?ojKBKonVdVooZ]I/00oo[]IX00oo[]YWogk6WomnaY`02
on2bYP03on6bY_o_/hookk>?00?ol;B>00?ol;B=oo6dSOo]/Y800_o]/Y42onjbT0?okk>?00Cokk>>
oo2cS_oc]8OolkB70_oR[Z42on>_W`05onB`W_ob/hOol[>6oo:cQ_oc/hH00_oc/hD01ood/hCom;B4
ooBdQ?od]8Co00fMoo2bS?o`/X/00_oa/hX2oo:cR@03oo:cR?oc]8Som[B000Com[Ao00Oom[AnooNd
O_oR/JCohk>SonFdX_oe]87om[B100?om[B00_og]Gl2ooNeOP04ooNfO_og]Wgon;ImooRfO@;on;Ml
00ConKMlooBhROoe^8WomKR90_of^HL01Oog^XOomkZ6ooNkQ_oh^hGon;b500;onKMi0ooj^7T3ooZi
N@?onkYi0_ok^gT01?oVe/KoimW7onOIaooWflP2oo^nO@0KooboOOol`7koo<1nooc1O_om`GkooL9n
oog3Oooma83ooLF0oog5POonah;oo/N3ook9QOonbXKoo/b9ooc6Qoolah_oo<R=ooc9S_okbY3onl^C
oo[=UoojcY[oj=6oonKA`_l0JloonMf[00;on=j^00_ommj`ooKO]?oegkKo0000ooODZ?ofeJ_omMJ^
ooCG/OoTdlKoh]?9omoCc@02oifik00:obUfhol2HMSoJjohof^_n?oCg=ood]cPonCJc?oRfloogm_C
omGCe`_ooooo00?o0000ooooooooool03Oooool001Cooooo00?o0000ooooooooool04oooool3o`00
01kooooo0_nU^^P00ooL_[_ogKjkomfn^`02omfo^P;o8GGS0_oR^jl00ooS^joohkb_onBl[`02onVi
XP03omRi^_oI^KWof[Zi00?ok;NK00?ok;NJob9Oe?lRGm@00_oZ]I/2on^eVP;ojkJI00?ok;JIomna
YooP/ZH00_oQ/ZH00ooS/jGol;B>oo2dSP02oo2dSP03oo2dSOoa]8go9dk400;okK:A0_o^/Y03onnc
S`04onncS_o`/hkol;B=oo>dQ`;ohZjQ0_oS[il00ooT/9kol[>7oo:cQP02oo>cQP;olk>500Oom;>4
ooBdQ?od]8Com;B3o`0@X?o`/Xcol;:;00;olK>:0_ob/hT00oob/hSolkB8oo>dQ`04ooJdO`07ooJd
O_og]7kohk>Son>cXooU]:;oi[BQooJdP@03ooJdP006ooNeOoog]GkomkEnooNeO_og]WkomkIm0_oh
]Wd2ooRgO0;onKMl0_oe^8T2ooJiQ`05ooNjQoog^XKomk^6ooRkQOoh_8D00_oi]gT3ooZhN@?on[Ui
0ook^WT2oo^kN@07oo^lNOoWfLOoim_8onOKb?oXh<[onkimooboO@02ooc0OP0@ooc1O_om`WkooL=o
oog3Oooma83ooLF0oog5POonah;oo/N3ook9QOonbXKoo/b9ook=R_olah_oo<R=oo_:T0;onl^C00So
n/fGoo[>V_ohd:3oi]72on?AaOoQdLSo7Y?[ooON/0;om]nd00?omMnfo`000?oge:P00_oeeZh01ood
ek7olMRgon;CbOoOdlgog=?@oibikOldO^H00_lAK=h01_mc/oWod]cPom7MhOo@g^?oh]_?omoKd`co
oooo00?o0000ooooooooool03Oooool001?ooooo00?o0000ooooooooool04_ooool2o`0002;ooooo
0_nV^^P01OoM_[_ogKnjomfo^_oM_k[oh[jc00;o7W?R0_oS^jl01?oS_:ooi;b_onBl[_oZ^J82omVi
^@04omZj^OoK^[Sok;NKonbgV`;ok;NJ0_lRGm@3on^eVP03on^fVOo/]YWok;JI00;oh;:V0_oQ/ZH0
0ooS/jGol;B>oo2dSP02oo2dSP04oo2dSOoa]8golKB=onfbT@?ok[:@0_o_/hl2onncSP06oo2cS_o`
]8golkB7oo>dQooR[Z7ohjnO0_oT/9h01?oU/Igol[>6oo>cQ_oc/hH2oo>cQ@0:ooBcQ?od]8Com;B4
ooBdPol05:?ol;:<oo2bRooa/h[olK>9oo:cR@;ol[>800?olkB8oo>dQooc]8H00oof]7l00oof]7ko
mkAnon>cX`02onFdXP03onJdXOof]87om[B000;om[B000KomkEoooNeO_og]GkomkEnooNfO_og]Wd2
ooRfO@;on;Ml0_oi]g`00ooe^8Wom[V8ooJiQ`02ooNjQ`06ooNjQ_og^hKon;^5ooRlQOoi_HConKMi
0ooj^7T3ooZiN@;onkYi0ook^gT01ook_7WonkajonOKb?oXgLWoj>3:onSSc?oYiLd00_ol`7h01Ool
`GkooL9noog3Oooma83ooLF000;ooLF100[oo/N2ook7PoonbHGoo/Z6ook<ROoncH[oo/j=oog?Sook
bY3onl^C0_ojcIL03OojcY[on=2PooSAXooSdLGohM78omkAc?m0Q^[o@:SfooGO]_odgkSoln2jo`00
0?o_h<000_odek401?oaf;OokmVkomoCcOoLdm02oi^hk@;o@8KY00?o;h?Zognln_o@g^<00_o>g^@=
ooooo`03o`000?oooooooooo00gooooo000Cooooo`03o`000?oooooooooo00oooooo0ol0000Uoooo
o`03ojJkj?nV^nWoY[_Y00;ogKnj00Cog[njon:n/olJL^;o6W;R0_oS_:l01?oT_:ooi;b^onBm[_oZ
^Z42omZj^@03om^j^?oL^kSok;NJ00;ok;NJ00?okKNJob=Qe_o[]IX00_o[]IX01_o[]YWok;JIonbf
VOo/]YWoh;:Von6bYP;ohk>U00Goi;>Too2dS_o`]8kol;B>oo2dS@02oo6dS@04obiDaoo^/Y3ok[:@
onjbT0;okk>?0_o_/hh01?o`/hkol;B=oo6dSOoc]8L2on>_W`;oi;2N00?oiK6Moo:cQ_oc/hH00ooc
/hD00ood/hCom;B4ooBdQ002ooBdP`05o`0DXoo`/X_olK>:oo6cROob/hT00_ob/hP01?oc]8SolkB7
oo>dQ_od]HH2ooJdO`03ooJdO_og]7komkEn00;oiKBR00Koi[BQonRfX?of]83om[B0ooJeOoog]Gl2
ooNeOP;omkIn00?omkImooRfOOoh]Wd00_oh]g`2ooVgO004ooVhO?of^HSom[V7ooNjQ`;omkZ600?o
mk^6ooRkQOoh_8D00_oi_H@3ooZhN@?on[Ui0_ok^WT3oo^kN@05oo^lNOok_7[oo;ejonSPb_oXhl`0
0_oYiLd02OoXj/ooo<1nooc1O_om`WkooL=ooog4P?omaH3ooLF1ook7PP02ook7P`09ook9QOonbXKo
o/b9ook=R_oncXgooLn?oogAToomdYGon/fG00;on/jJ00gon=2PooSAXooQdLSog]7<om_AcooHdM;o
BHc/oefio?och;[ol^2loo3P__l0003om=Na00;olMRg00?okmVkomcCd?oHdm<01Oooool2ohG0nP03
olkNi?oooooooooo00cooooo00?o0000ooooooooool03Oooool001?ooooo00?o0000ooooooooool0
3?ooool3o`0002Wooooo00CoY[_YojJljOnV_>WogKnj0_oN_kX00ooN`;[o5g7QoaMah@02onBl[`04
onBl[_oT_JkoiKf^onZjX@;ofkZh00Gog;^honbgV_o/]i[ok;NJonfgVP02obATe`;ojkFJ00CojkJI
onbfVOo/]YWokKJH0_oQ/ZH01OoS/jGoi;>TonBcY?oU]:?ol;B>00;ol;B=0_oa]8d01?oa]8cok[:@
onjbT?o^/Y02onncS`06onncS_o`/hkol;>>oo2dSOoa]8golKB<0_oS[il01OoT/9koiK6MonFaWOoW
/Icolk>600?olk>500?om;>4ooBdQ?od]8@00_od]8<01_l06:Kol;:;oo6cR_oa/hWol[>9oo:cR0;o
lkB800?olkB7oo>dQ_od]HH00_of]7l01?of]7komkEnooNeO_oU]:82onJdX@05onRfX?oY]ioom[B0
ooJeOoog]Gl00_og]Gh2ooNfOP03ooNfOOoh]Wgon;Im00;on;Ml0_oi]g`01Ooi^7conKQkooJiQoog
^XOomkZ600;omk^60_oh_8D2ooVmQ0;on[j400Con[QiooZiNOoj^GWon[Ui0_ok^WT2oo^kN@04oo^l
NOok_7[onkajoobmNP;oo;ik00kojNG=onSXc_oXj/ooincAonO_d_om`WkooL=ooog4P?omaH3ooLF1
ook7P_onah?oo/V5ook:QP;oo/b900Ooo/f:ook>SOomchoooM6CoogBUOole9[on/jJ00;on=2P00Oo
n=6SooKBZOoee:cofm7?omSAd_oDd=GoCho]00;oM/Cn00Ookn30o`000?o]h<Cok>77onoI^oo^fkoo
jmc301Oooooo00?o0000ooooooooool03Oooool001?ooooo0_l0000:ooooo`?o0000;Oooool3ojJl
j@;og[nj0_oN`;X2oa=`h0;oi;b^00Coi;f^onFm[_oU_Jkoj[ZQ0_oL^kP01OoM_;Sok;NJonbgV_o]
]i[okKRJ00;o96CG0_o[]YT2onbfV@04onffV?o]]iSohK:Von>cY@;oi;>T00?oiKBSoo2dS_o`]8d0
0ooa]8d01?oa]8co=U[9onjbT?o^/Y02onncS`05onncS_o`/hkol;B=oo2dSOoa]8d00_oa]8`2onB`
WP;oiK6M00?oik6Loo>cQ_oc/hD00_oc/hD00ood/hCom;B4ooBdQ002ooBdP`07ooFdPol06:KolK>:
oo6cROob/hWol[>8oo>dR002oo>dQ`05oo>dQ_od]HKom;F5ooJdOoof]7h00oog]Gh2onJdX@05onRf
X?oY]ioom[B0ooJeOoog]Gl00_og]Gh00oog]WkomkImooNfO@02ooRfO@;on;Ml0_oi]g`02Ooi^7co
nKQkooJiQoog^XOomkZ6ooNkQ_oh^hGon;b5ooVlQ@02ooVmQ0;on[j400Con[n3ooZiNOoj^GWon[Ui
0_ok^WT2oo^kN@03oo^lNOok_7[oo;ej00?oo;ik01goo;mlonSZcooWk=7oinoBonKadooUl]GohoCF
oog4P?omaH3ooLF1ook7P_onah?oo/V5ook:Q_onc8Woo/f:ook>S?oncXgooM2AoogAToomdYGoo=BJ
oocEW?ohd:3on=6SooOBY_ofdZWomMB/omSAdP02omC@e@09oeJCk_l0:k3oOlSnohO<o_o^hL;o0000
oncQaooYi<cok]^o01Sooooo00?o0000ooooooooool03Oooool001?ooooo00?o0000ooooooooool0
1_ooool3o`00037ooooo00?oY[cYojJmj_nV_NX00ooN`;X00ooN`;_o46oOoa1_g`02onBm[P;oiKf^
00GoiKj^onZjXOoM_;SogKbhomfm^002onfgVP;okKRJ00?o96KHon^fVOo[]YT00_o/]YT01Oo]]YSo
kKNHon>cYOoS/jGoi;>T00;oiKBS00?oi[FRoo2dSOoa]8d00_oa]8d2oo6dS006onjbT?o_/hookk>?
onncSoo_/hkol;>>0_o`]8d00ooa]8golKB<oo6dS002onB`WP04onFaWOoW/Icoik6LonRbV`?olk>5
00?om;>4ooBdQ?od]8@00_od]8<01ooe]8?o01bYoo6cR_oa/hWol[>9oo:cR?oc]8P00_oc]8L01Ooc
]8Kom;F6ooBeQOod]HGom[An00?omkEn00Ooi[BQonRfX?oX]Z3ojKNOonZhW_of]GoomkEo00;omkEn
00?omkInooNfOOoh]Wd00_oh]Wd2ooRgO0;onKMl00WonKQlooVhNooj^G_omkZ7ooNjQ_og^hKon;^5
ooRlQOoi_8D00_oi_H@2ooZnQ004ooZoPooj^GWon[UiooZiN@;onkYi0_ok^gT00ook_7Wonkajoobm
NP02oobnN`;oo;ml017oo<1moog1O_om`Wooi_7Con?de_oRm]OohOOHomohfOoMnM[of_[Look7Poon
bHGoo/Z6ook<ROoncH[oo/j=oog?S`02oogAT`05oocCUoole9[oo=FLoo[FXOohdJ<00_ofdZT01?oe
e:col]NdomC@eOo@cmP2ooooo`06o`0l__n?c_goU=7moncQaol0003ojNC<6_ooool00ol0003ooooo
ooooo`0<ooooo`004oooool00ol0003oooooooooo`03ooooo`?o0000=Oooool00onV_N[oY[g[ojJm
j`02omk0^P04omk0^ooN`K_o36kNo`a^gP?oiKf^0_oU_Zh01?o[^Z7ogKbhomfm^?oN_KL3onfhVP03
onfhVOlUJ=[ok;JI00;ok;JI00?okKJHonfgV?o]]iP00_oT/j@01?oU]:?oi[FRonJeX_oW]J43oo6d
S@;olKB<00Oo?Eo<onncSoo_/hookk>?onncS_o`/hkol;B=00;olKB=0_oa]8`00oob]H_oiK6MonFa
W@02onNaW005onRbVooc/hGolk>5oo>cQOod/h@00_od]8@2ooBdP`;omKB300Ko01bYoo:cROob/hWo
l[>8oo>dR?oc]8L2oo>dQP04ooBeQ_od]HGom;F5ooFfQ@ComkEn00Koj;JPonVgWooZ^9koj[RNonbi
WOog]Gl2ooNeOP03ooNfO_og]Wgon;Im00;on;Im0_oh]g`2ooVgO009ooVhO?oi^7_on[UkooZiNoog
^XKomk^6ooRkQOoh_8GonKb500;onKf40_oj_X@01?oj_h?onl23oo_1Pooj^GT2oo^jN@;onk]i00?o
nkaioo^lN_ol_GX00_ol_W/05Ool_gcoo<1moog1O_om`GkooL9ooog3P?oma8;ooLF3on7gf?oMnM[o
g?[KomWkg?oHnmgoeo_NomKkg_oEnmooo/f:ook>SOomchoooM6CoogBU@02oocDVP08oo_FW_ojeZ7o
nMVVooSIZOoee:colmF`oo;G]?o`fKT5ooooo`04oiSDoOnLf?cojNC<o`0001[ooooo00?o0000oooo
ooooool03?ooool001;ooooo00Co0000oooooooooooooooo0ol0000jooooo`;oY[k[0_oN`;/2omk1
^`03o`U]g_oU_JkoiKf^00?oiKj^00Goi[j^omfm^?oM_KSog[fgomnn]`02onfhVP03onfhVOlUJ]_o
9F[K00;ok;JI0_o]]iP2onjgU`05onBcY?oU]:?oi[FRonJeX_oW]J400_oa]8d3oo6dS007oo6eS?o_
/hookk>?onncSoo_/hkol;>>oo2dS@02oo6dS@;olKB<00Col[F;onFaWOoU/Igoik6L0_oX/Y/01?oY
/i[olk>5ooBcQ?od/h@2ooBdQ0;om;B30_oe]8<01ol07:Wol[>9oo:cROob/hSolkB8oo>dQooc]8H0
0_od]HH2ooBeQ@04ooFfQOog]GkomkEnooNeOP;omkEm00GojKNOonZhW_oZ^9kok;VMooNeO`02ooNe
OP03ooNfO_og]Wgon;Im00;on;Im0_oh]g`2ooVgO0;onKQk0ooj^G/00oog^hKon;^5ooRlQ@03ooVm
Q0;on[j400Con[n3oo_0Pook`H?oo<:30_ok^WT2oo^kN@03oo^lNOok_7[oo;ej00;oo;ik00Goo;ml
ooc0OOom`GkooL9ooog3P002oog4PP08oog5PoomahKooLR7oog:Roolbhgoeo_NomKkg_oFnml2omGj
h00;omKihOoFn>;oeoORoogBUOole9[oo=FLoo_FW_ojeZ7onMVVooSIZOoggJl00_obek@00oo`fKWo
ooooooooo`04ooooo`03oioJo?oooooo000001[ooooo00?o0000ooooooooool03?ooool001;ooooo
1?l0000nooooo`;oYKk[1?oN`K/00ooR_kCoiKf^onFn[P02onFn[P06onJn[_oV_joog[fgomjm]ooO
_[Ooh;ng0oo]^9T2obEZf`03onffV?o]]iSokKNH00;ok[NG0_oU]:<01OoV]J;oikFQonNeXOoW]Z7o
lKB=00?olKB<00?olKF<odAVcoo_/hl00_o_/hh00oo`/hkol;B=oo6dS@03oo6dS0;ol[F;0_oW/I`2
onRbV`03onVcV_oc/hGom;>400?om;B40_od]8<2ooFdP`08ooFeP_ob/hWol[>8oo:cR?oc]8SolkB7
oo>dQ_od]HH3ooBeQ@04ooFfQOog]GkomkEnooNeOP;omkEm00GojKNOonZhW_o/^Igok;VMonfjW002
ooNeOP04ooNfO_og]Wgon;ImooRfO@?on;Ml0_oi]g`2ooVhN`?on[Uk00?od5l0ooRlQOoh_8D00ooi
_H@02?oj_XCon[n3ooZoPook`8?onl63ooc2Pool`h?oo<B30_ok^gT00ook_7WonkajoobmNP02oobn
N`0HooboO?ol`7gooL5noog2Ooom`h3ooLB2oog5PoomaXGooLN6oog8QoombX_oo<^=ooc=TOolcYCo
nm2HooC?ZOocdJgoe_WQomKhh_oGmn;oeoKRomSdh_oHl^;on]JQ0_oifJH01?ohfJWommf_ooKO/oo`
fKT:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool001;ooooo0_l00011
ooooo`;oYKo/0ooN`K/2omk2_0;oiKj^0_oV_Zh2onJo[`;ogkjg00Ooh;ngon30]oo]^9WokKRIonjh
VOlTK=gokKJH00;okKNH0_o^]iL01?o^^9Ooi[FRonJeX_oW]J42onNfX@03onRgX?oa]8colKB<00;o
lKF<00Ool[F<onncSoo_/hkokk>>oo2cS_o`]8golKB=00?olKB<0_ob]H/2onNaW005onRbVooY/i[o
jK>Joo>cQOod/h@00ood]8@2ooBdP`;omKB300SomKF2oo:cROob/hSol[>8oo>dR?oc]8OolkB6ooBe
QP?om;F500ComKJ5ooJfQ?og]GkomkEn0_og]Gd2onZhWP;ok;VM00GokKZLonjkW?og]GkomkInooNf
O@02ooRfO@?on;Ml0_oi]g`2ooVhN`?on[Uk00?on[YkooRlQOoi_8D00_oi_H@2ooZnQ00<ooZoPook
_h?onl23oo_1Pool`X?oo<>3ooc4PoomaH?ooLJ4oo^lNOok_7[oo;ej0_ol_W/02Ool_gcoo<1moog1
O_om`WoooL>0oog4P_omaH?ooLN6oog8Q`02oog:R`0;ooc;SOolcI7oo<jDoo_@V?okdI_olm6]oo;B
/?o`dkCok]FiomSdh_oHln800ooHl>801?ohfJWommf_ooOM[oofgk<<ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool03?ooool001Cooooo00?o0000ooooooooool0?oooool01?nU_nco
YL3]ojG0kOoN`K/3omk2_003onFn[_oV_Zkoi[n_00;oi[n_00Koi/2_on2o]ooP_kOoh<2gon71]oo^
^9T2onjiV@?okKNH0_o^]iL01?o^^9Ooi[FRonJeX_oW]J42onNfX@03onRgX?oY]ioolKB<00;olKF<
00?ol[F<od]/d_o_/hh00_o`/hh01?o`]8golKB=oo6dS?oa]8`4oo:eR`;oj;:K0_oY/iX00oo[]9So
m;>4ooBdQ002ooBdQ0;om;B30_oe]8<2ooFePP06oo:cR?oc]8SolkB8oo>dQooc]8Kom;F60ood]HD0
1?oe]XGom[J4ooJgQ?og]Gh2ooNeO@;oj[RN00Ook;VMonfjW?o]^Ycok[^LooNeO_og]WkomkIm00;o
n;Im0_oh]g`3ooVgO0;onKQk0ooj^G/00ooj^W_on[]kooVlQ@02ooVmQ0;on[j400Con[n3oo^oPook
`8?onl630_ol`h<06_ola8?ooLF3oog6Q?omb8Coo/V5ook:QOonc8Koo;ikooboO?ol`7gooL5noog2
Ooom`h3ooLB2oog5PoomahKooLR7oog:Roolbhgoo<b?ooc=TOokciKonm2Hoo_AVoojeJ7ol=>d0_o^
eKT3ooooo`06omS`h_oHk^;oenoSomO`hoofgk?omN:g3?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00cooooo000Eooooo`03o`000?oooooooooo03oooooo00?oYL3]ojG1kOoN`[`0
0ooN`[`00ooN`[goi[j^onJo[`02onJo[`05onK0[ooP_kOoh<2gon30]ooQ`KL00_oR`[P2onjiV@;o
kKNH0_o^]iL01Oo^^9OokkRGonNeXOoW]J7oikJQ00;oj;NP00?ojKNOonZhWooa]H`00_ob]H`00om;
K=;okk>>oo2cSP02oo2dS@03oo6dSOoa]8colKB<00Col[F;0_oX/Y/01?oY/i[oj[>Ion^dV?od/h@2
ooBdQ0?om;B30_oe]8<2ooFePP06oo:cR?oc]8SolkB8oo>dQooc]8Kom;F60_od]HD2ooFfQ@03ooJf
Q?of]hCom[N300?omkEm0_o/^Id01_o]^Ycok[^LonjkW?o__9_omkInooNfO@;on;Im0_oh]g`2ooVg
O003ooVhO?oi^7_onKQk00?on[Uk00?on[YkooZkNook^g/00_oi_H@2ooZnQ004ooZoPook_h?onl23
oo_1P`;oo<>301Goo<B3oog5PoomaXCooLR4ook9QOonbXGoo/b6ook=QoonchWoom2:oooCSOooe8ko
o]F@ookHToomaH?ooLN6oog8QoombX_oo<^=ooc=TOolcY@00_okd9P01?ojdikon]FQoo[HY?o^eKT6
ooooo`03omO_hooEl^Cooooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<
ooooo`005_ooool00ol0003oooooooooo`10ooooo`06ojC1k_oN`[cog/:lomk2_?oN`[gog/>m0_oV
_jl01?oV`:ooi/6_onK1[ooP`;L2on71]`;oh/:h00?ohl>honjiVOlOL>000oo^]iL00oo^^9OokkRG
onnhU`02onNfX@07onRgX?oY]ioojKNOonZhWooa]Hcol[F<oo:eR`02oe9be004oo2cS_o`]8gol;B=
oo6dS@;olKB<1?ob]H/01_oc]X[oj;:KonVcV_oZ/iWojkBHonbeU`;om;B40ood]8<2ooFdP`;omKF2
00Kom[F2oo>dR?oc]8OolkB7oo>dQ_od]HH2ooBeQ@06ooFfQOoe]XCom[J4ooJgQ?of]h?omkN30_og
]Gd2onbiW@06onfjW?o^^icok[^LonnlVoo`_I[omkIm0_oh]Wd2ooRgO0;onKMl00?onKQlooVhNooi
^7/00ooj^G/01Ooj^W_on[]koo^kNook_7_onKf400;on[j400Con[n3oo_0Pook`H?onl630_ol`h<0
6_ola8?ooLF3oog7Q?omb8Coo/V5ook:QOonc8Koo/f7ook?ROood8[oom>=oooDS_oneI3oo]RCookI
UOomfiWooMbKoocNX?olgj;oo<fAooc>U?okd9Sonm6Koo[CW_ojeJ7on]RT6Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00_ooooo000Gooooo`;o0000@Oooool00onT`Nkog/:lomk2
_@02omk3_@04omk3__l0I]Goi/2_onK1[`;oil6`00SohL6gon;2^?oR`[Soh/:hon?3^?oSa;Wok[VI
oam`h0;ok[NG00?ok[RGonnhUoo_^9L00_oW]Z401_oX]j3ojKNOonVgWooZ^9oojkRNoo:eS0;ol[F;
0_mBL]@00oo`]8golKB=oo6dS@02oo6dS0Col[F;00SolkJ:onVcV_oY/i[oj[>Ion^dV?o/]IOokKFG
ooBdQ0;om;B30ooe]8<2ooFePP06ooJeP_oc]8SolkB7oo>dQooc]8Kom;F60_od]HD02Ooe]XGomKJ4
ooJfQ?of]hCom[N3ooNgPoog^8?omkEmooNfO@02onfjW005onjkW?o__9_okkbKoo2mV_oa_YX00_oh
]Wd2ooRgO0;onKMl00?onKQlooVhNooj^G/00ooj^G/01_oj^W_on[]koo^kNook_7_onkalooZnQ0;o
n[n300?onl23oo_1Pool`X<00_ol`h<06_ola8?ooLF3oog7Q?omb8Coo/V5ook;Q_onc8Koo/f7ook?
ROoodHcoom>=oooDS_oneY7oo]RCookIUOomfiWooMbKoocNX?olgj;onn2WooWR[Oohhjoonm6Koo[E
XOojf:ConMZX6_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo000Ioooo
o`03o`000?oooooooooo03oooooo00?oY<;^ojC2kooN`kd00_oN`kh01?oN`koogLBoonK1[ooW`K03
onO2/007on;2^?oS`kSohl>hon?4^OoTaKWokkZIoaaah002onjhU`;okkRG00CokkVFonRgX?oX]j3o
jKNO0_oZ^9l00oo[^9kok;VNoo:eR`02oo:eR`04oeUheoo`]8golKB=oo6dS@;olKB<0oob]H/2oo>f
RP;ojK>J0_o[]9P00oo/]IOokKFGooBdQ002ooBdP`?omKB30_oe]H800oof]H;om[J2oo>dQ`02oo>d
QP0=ooBeQ_od]HGom;F5ooFfQOoe]XCom[J4ooJgQ?of]h?omkN3ooNhPoog^8;omkImooRfO@02onjk
W004onnlVoo`_I[ol;fJoo6nVP;on;Im0_oh]g`2ooVgO003ooVhO?oi^7_on[Uk00?on[Uk02Kon[Yk
ooZkNook^g_onkakoo^lO?ok_Gcon[n3oo^oPook`8?onl63ooc2Pool`h?oo<B3oog5PoomaXCooLN4
oog8Q?onbHGoo/^6ook<Q_oncXSoo/n9oooAS?oodhgoomB>ookFTOonf9?oo]ZGoogKVOomgIgoo=jP
oo_PYOokh:OonN:]ooSS[oogiKCom^Rgoo[HY1_ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`0oooooo`03ojC2konS`noog/>n00;og/>o
00?ogLBoon71^?oW`K000_oW`[02onO3/@07on?3^?oSa;WohlBionC5^OoTa[[okkZIoaQah@03onnh
U`05onniU_o`^IKojKNOonVgWooZ^9l00_o[^9h01?o/^Ikok;ZNoo:eRoob]H/2oemmf@04oo6dSOoa
]8colKB<oo6dS0?ol[F;0ooc]XX01_oZ/iWojkBHon^dV?o/]IOokKFGonjfUP;om;B30ooe]8<2ooFe
PP04ooJeP_of]X;olkB7oo>dQP;om;F60_od]HD02?oe]XGomKJ4ooJfQ?of]hCom[N3ooNgPoog^8?o
mkR20_oh^H82onjkW006onnlVoo`_I[ol;fJoo6nV_oc`9Won;Im0_oh]g`2ooVgO003ooVhO?oi^7_o
n[Uk00;on[Uk0_oj^W/02Ooj^g_onk]koo^lNook_7conkeloobnO?ok_h?onl23oo_1P`02ooc3P`0E
ooc4PoomaH?ooLJ4oog8Q?onbHGoo/Z5ook<Q_oncHOoo/n9ooo@R_oodhgoomB>ookET?onf9?oo]VE
oogKVOomg9_oo=jPoocOX_okh:OonN:]00;on>>_00?omnFdooKX]oock[d07?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00_ooooo000Kooooo`03o`000?oooooooooo043ooooo00co
Xl?`omk3_ooMa;oogLC0omg4`OoQ`KSoh<6ionO2/?oW`k7oil>bonO4/_oSa;T2onC5^@04onC6^_oT
ak[oiLRkoa=`h0;okkRG00KokkVFoo2iU_oY]ioojKNOonZhWoo[^9h2onbiWP06onbjW_o]^Ygol[F;
oo:fRomOOMWolKB=0ooa]8`3oo:eR`ColkJ:00OojkBHonbeUoo/]IOokKFGonjfU_o_]iGom;B300;o
mKB30ooe]H801?of]H;om[J2o`0a^?oc]8H2ooBeQP;om;F500SomKJ5ooFfQ?of]XCom[N4ooJgPoog
]h?omkR3ooNhPP;on;V200Con;ImonnlVoo__9_ol;fJ0_oa_YX01?oc`9Wom<6IooRgO?oh]g`2ooVg
O003ooVhO?oi^7_on[Uk00;on[Uk00?on[YkooZkNook^g/00_ok_7/01_ok_7conkeloobnO?ol_gco
o;mmoo_1P`;oo<>300ooo<B3oog5PoomaXCooLR4ook9QOonbXGoo/b6ook=QoonchWoom6<oooCSOoo
e8koo]JAookHToohdZ801_ooool01OohhjoomnFdooKX]ooejk[olnjm01gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0;ooooo`007?ooool2o`00047ooooo00CoXl?`oj;3l?oMa<3o
gLC10_oLaL801ol0Hlkoil>aonO4/_oWa;;oilBconC5^OoTa[X00_oTakX00ooUb;_oiLVlo`a_g`02
onniUP05oo2iU_o`^YKoj[ROonZhWoo[^9h00_o/^Ih01?o/^YkokKZMonjkWOob]X/2ofF3g0?olKB<
0oob]H/3oo>fRP04oo>gROo[]9Sok;FGonbeU`;ok[JF00CokkNEonngU?oe]8?omKB30ooe]H801Oof
]H;om[J2ooJfP_l0=;_om;F600?om;F500SomKJ5ooFfQ?of]XCom[N4ooJgPoog]h?omkR3ooNhPP;o
n;V200[on;Z2ooRfOOo`_I[ol;fJoo6nV_ob_iWoll2IooC1VOoe`iSon;Ml0_oi]g`2ooVhN`?on[Uk
00Kon[YkooZkNook^g_onkakoo^lO?ok_G`2oobnO00DooboO?ol_ggoo<1moog2O_ol`h?oo<B3oog5
PoomahCooLR4ook9QOonbhKoo/b6ook>R?onchWooM2BoocBU_oldiSoo=NMoocIX?okgjHXooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool001kooooo00?o0000ooooooooool0
?oooool2oj;4l@06omg4`OoLaL;og<G2omc6`ooP`[[o06?=0_oWa;<00ooWaK?oilFdonC7^P02onG8
^`03onG9_?oUc;go1FgM00;ol;VF0_o`^YH2on^hWP07onbiW_o/^Ykok;ZNonfjWOo^^igok[bMoo>f
R`02ofF3g003oo6dS?ob]H_ol[F;00;ol[F;0ooc]XX01?oc]hWom;N9onbeUoo]]IL2onjfUP04onng
UOo_]iComKB3ooFdP`;omKF20_of]H82ooJfPP03o`0g_Ood]HKom;F500;om;F500SomKJ5ooJfQ?of
]XCom[N4ooJgPoog]h?omkR3ooNhPP;on;V200[on;Z2ooVjP_o`_I[ol;fJoo6nV_ob_iWoll2IooC1
VOoe`iSom/BH0_oi]g`2ooVhN`?on[Uk00Kon[YkooZkNook^g_onkakoo^lO?ok_G`2oobnO00<oobo
OOol`7gooL9noog2Ooom`goooLF1oog6P_omah?ooLR6oog9Qoomc8[ooLf<0_omci001_omd9;oo=:F
oocDVooleigoo=VPoo_OYRWooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0;oooo
o`007oooool00ol0003oooooooooo`0oooooo`;oX/Ca0_oLaL801OoLa/?oflK4omo2_?l0I<goilFc
00;oilFd00OoilJeonG8^ooUbKcoiL^lonG<_OoUcKookkbK00Col;ZF0_o/^Ih02Oo/^YkokKZMonfj
WOo^^igok[bMonnmWOoc]X_oJHWNoo6dS004oo:eR`?olkJ:00GolkN9ooBgROo/]IOokKFGonjfUP02
onngU@03onngU?o`^9ComKB300;omKF20_of]H82ooJfPP03ooJfPOl0=kgom;F500;om;F500KomKJ5
ooJfQ?of]hCom[N4ooJgPoog]h<2ooNhPP;on;V200?on;Z2ooVjP_oi^h400_oa_YX2oo?0V@05ooC1
VOoe`iSom/BHooO5V?oi]g`00_oi^7/3ooZiN`06ooZjNooj^g_onk]koo^lNook_7conkel0_ol_W`0
4?ol_ggoo<1moog2O_om`WoooL=ooog5POomaX;ooLN3oog8Q_ombHOooLb:oog=S?omci3ooM2BoocB
U_oldiP2oocGW@03oo_LX_okgjKooooo02Wooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0;ooooo`008?ooool00ol0003oooooooooo`0oooooo`0:oj74lOnQa?;oXLCbomc6`ooKa/Co
flK5om[6a_oN`kgo06K>onO6]@;oilNf00Koi/NgonG<_OoUc;goiLfoonG>`?l0HM03oo2jUP;ok;VN
00Ook;ZNonfjWOo^^igok[^MonjlWOo__IgolkJ;00;oKXkQ1?ob]H/3oo>fRP06oo>gROod]hWom;R9
onfeUoo^]YKokkNE0_o_]i@01?o`^9ColKVCooFeP_oe]H82ooJePP;om[J200Com[J1o`0i__od]HGo
m;F50_oe]XD01_of]XCom[N4ooJgPoof]h?omkN3ooNhPP?on;V200Kon;Z2ooVjP_oi^h7onK^1oo:o
VOoc`9T2ooC1V@04ooG3V?ofa9SomlFHooO7V0;onKQk0ooj^G/01_oj^W_on[]koo^kNook_7_onkal
oo^mO0;oo;il01?oo;mmooc0OOom`WkooL9ooog3OoomaH7ooLJ2oog7Poomb8KooL^8oog<R_omcXko
oLn@oog@T_oldYKoo=>HoocGWOolfJ3onmnV02cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0:ooooo`008Oooool00ol0003oooooooooo`10ooooo`03oj74l_oKa/CoflK500;of/K6
00CofLO7omk3__oWa[GoilNf0_oVakL01ooVb;SoiLfoonG=_ooUc/3oiLo1o`1Kb?o`^YH00_oa^iH2
onbjWP07onfjWOo^^igok[bMonjlWOo__Igol;jMoo>fR`02ofj>h@?ol[F;0ooc]XX01ooc]hWom;N9
ooBhROo]]IOok[JFonngUOo_]i@00_o`^9@2oo6iT`03ooFeP_of]H;om[F200;om[J20_of]X401ol0
>Kkom;F5ooFfQOoe]XCom[J4ooJgQ?of]h<00_og]h<01_og^8;on;V2ooRiP_oh^H;on;Z2ooVjPP;o
nK^100Con[b1oo?0VOod`IWomL>H0_ofa9P01?ogaISomlNHooW:V?oi^7/3ooZiN`0JooZjNooj^g_o
nk]koo^lNook_7conkeloobnO?ol_gcoo;mmooc0OOom`WkooL9ooog3OoomaH7ooLJ2oog7Q?oFolCo
d_o:om3odOo@omCod?oJom7ng?o@oMkodOcQolgmh?o8o]h]ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02_ooool002;ooooo0_l00011ooooo`;oX<Cb00Sof/K6omW7aooIalOogL>o
omg3`?oLa<7oi/NgonK8^0;oi/Ri00KoiLZkonG?`OoUcl7oiM72onGBa?l0C;H2oo6kUP;okKZM00Oo
k[^MonjlWOo__IgokkfMoo2nWOo`_igolL2M00;oLI?T00?ol[F;oo>fR_oc]XX00_oc]XX2ooBgR@05
ooBhROo^]YKok[JFonngUOo_]i@00_o`^9@2oo6iT`03oo:jT_of]H;om[F200;om[J20_of]X402_og
]X7o03ZoooFfQOoe]XCom[J4ooJgQ?of]h?omkN3ooNhPoog^883ooRiPP0:ooRjP_oi^X;onK^1ooVk
POoj_87on[f1ooC1VOoe`iSom/BHooO5V0;omlNH00?onLZHooW;V?ojcIP00_oj^G/04_oj^W_on[]k
oo^kNook_7_onkaloo^mO?ol_Wcoo;mlooboOOol`7gooL9noog2Ooom`gooh_bhomkm^ooHo/7odoo7
om;obSKooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`009?ooool00ol0
003oooooooooo`10ooooo`06oj34l_oIalOofLO8omS7bOoGb<[og<C10_oLa<801_oVb;Woi/VjonG:
^ooUb[goi<^nonGBa0;oiM?500?o04>[oo6lUooa_9L00_o^^id01_o^_9gokkfMonnmWOo`_Ygol;nM
oo70W@;oM9SW00?ol[F;oo>fR_oc]XX00_oc]XX2ooBgR@06ooBhROo^]YKok[JFonngUOo_]iCol;RD
0ooa^I<00oob^Y;olk^BooJePP02ooJfPP0<ooJfPOog]X7omkJ1ooNgPOl0>[oomKJ4ooJfQ?of]hCo
m[N3ooNgPoog^8?omkR20ooh^H808Ooh^X;onKZ2ooVkPOoi^h7on[b1ooZmPOoj_X7omL>HooK4V?og
aISomlNHooS8V?oibYSonL^Hoo[=V?okciWonm6IooZjNooj^g_onk]koo^lNook_7conkeloobnO?ol
_gcoo;mmooc0OOo`mZkokOR`onWj/_oNoK_onNN_ooK^]@0iooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool0@?ooool02OnOaO;oWlGcomS7
bOoGb<[oelS<omc4`_oKa<?of/C4o`1if@02onG:_@08onC;__oTc;ooiM?5onCDaooTe/SohmO:of80
0?ob_IL2onjlW@;okkfM00Col;jMoo2oWOoa`9gol/6M0_mdV>L4oo>fRP;om;N900Kom;R9ooFhROo_
]iGokkNEonngU?o`^9@3oo6iT`03oo:jT_oc^i;olkbB00;om[J200com[J1ooNfPOog]h7omkN1o`0i
_Ooe]XCom[J4ooJgQ?of]h?omkN3ooNhPoog^883ooRiPP03ooRjP_oi^X;onK^100;on[b101con[f1
ooZnPOofa9Som/BHooO5V?ogaiSon<RHooW:V?oibiSon/fHoo_?VOokdIWoo=FJoocGVoomfYcooMbM
oogQWooli:7onnNRooW]YOogkjSomO6Zoo3f[_oYn[;onn6WooWT[Ooiijoom^je>Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo000Vooooo`03o`000?oooooooooo043ooooo
0_nOa?<02?oGb<[oelS<omK8cOoKa<?of/C4omW4aOoHaLKo187O0_oTc;l01ooSc<7oh/g2on;=`ooS
el[ohmS<on;Jc_oQf]000_o__Id2oo2nW@04oo2oWOoa`9gol/6Moo;2W@;oMYgZ0_oc]XX01?oc]hWo
m;N9ooBgROod^8T2ooFhR@;okkND00?ol;RDoo6iTooa^I<00_ob^Y801_oc^i;olkbBooBmTOof]X;o
m[J1ooNfP@?omkN100Oo03VmooJfQ?of]hCom[N3ooNgPoog^8?omkR200?on;V200Con;Z2ooVjP_oi
^h7on[b10_oj_H400ooj_X7onkj1ooO5V002ooO7V0;onLZH01?onL^Hoo_?VOokdIWoo=>IoocEV_ol
ei_ooMZLoogLWOomhIooo>BQoo_WX_oikJGomnnXoo3f[_okgjGonn6WooWT[Ooiijoom^je03_ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`009oooool2o`00047ooooo0onO
a?<02OoFb<goeLS>omC8cooIa<Gof<G6omS5aoo4`mWohlc1on;=`P02on;=``0:on3>a_oWa;;oilFd
on7Jd?oPfm;okkfMoo2nWOo`_igolL2Moo;1W@;ol/:M00Goll>MogNRkOmgX^golkJ:oo>gR@02ooBg
R@04ooBhROoe^8WomKR9onngU0;ol;RD0_oa^I<02?ob^Y;olk^Boo>kT_oc_9;om;fAooFmTOof]X7o
mkJ11?og]h401_l0=[Wom[N4ooJgPoog]h?omkR3ooNhPP;on;V20_oh^X800ooi^X;onK^1ooZlP@02
ooZmP@0DooZnPOok_X7onkn2oo_1P_ohb9SonLZHooW;V?ojcISonlnIoo_AVOoldiWoo=FJoocGVoom
g9gooMnNoogQWookij;onNfUooO_Z?omfie2ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02_ooool002Wooooo00?o0000ooooooooool0@?ooool00onOa??oeLS>omC8c`02om?8d00C
omS5a_oGaLWoelG9omK5b_lGS^Soh/g3on7>aOoPc/Koglo8onO5]?oVaKGoi/JgomoMdoo`_Ygol;nM
oo70WOob`Igol/:Moo?3W@02oo?4WP;oMZK`00ColkN9ooBgROod]hWom;R90_oe^8T00ooe^HWol;RD
oo2hU002oo6iT`08oo:jT_oc^i;olkbBoo>lT_od_I7omKfAooJoTOog]X44ooNgP@06ooNhPOl0<K?o
m[N3ooNgPoog^8?omkR20_oh^H801Ooh^X;onKZ2ooVkPOoi^h7on[b100;on[f1017on[j1oo^nPOok
_h;onl62ooc2P_ol`h?onL^Hoo[=V?okciWonm6IoocEV_olei_ooMZLoogLWOomhIooo>BQoo_WXP16
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool002[ooooo00?o0000oooo
ooooool0@?ooool2oio4l`04om?8d?oBb=7od<SBomO5b@;oe/G:00Oo`/?JobFFk_lUU^koh<k6omo?
b?oNclWogLo;00;oiLJh00Woi<Jjom_OfOoa`9gol/6Moo;2WOoc`igollBNoo?5W_odail00_mcZO<0
0ood]hWom;R9ooBhR@02ooFhR@03ooFiROof^HWolKVC00;olKVC00?ol[ZBoo>kT_oc_9800_od_I40
0ooe_I7om[nAooO0T@04ooNgP@04ooNhPOoh^87o02ZYooNgP`;omkR20_oh^H801Ooh^X;onKZ2ooVk
POoi^h7on[b100;on[f100oon[j1oo^nPOok_h;onl62ooc2P_ol`h?oo<B3oog5Q?okdIWoo=>IoocE
V_olei_ooMZLoogLWOondXh0B?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wo
oooo000[ooooo`03o`000?oooooooooo047ooooo00WoWlCbom;8dOo@b=;oclWComK5b_oDaL_odlG<
ol;3foo1`m/00_ldW_<01ooNclWog<o=omc?cOoJd<kohlNkon;7_Oob`Id00_ob`Yd02?oc`igollBN
oo?5W_odaioom<RPofn/m_od]hWom;R90ooe^8T00ooe^HWom[V9ooJiR@02oo6iT`04oo:jT_oc^i;o
lkbBooBmT@;omKfA00Com[nAooO0TOog`I7on<:A0_og]h401Oog^87on;R1ooRiPOl08IgomkR200?o
n;V201Con;Z2ooVjP_oi^h7onK^1ooZlPOoj_H7on[j1oo^nPOok_h;onl22ooc2P_ol`h?oo<B3oog5
PoomaXCooLR5oog9Q_onbhSoo/f9ook?Rd_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`09ooooo`00;?ooool2o`00047ooooo0onOa?804Oo?bM?oc/WEolg8e_oCaLcod/G>om75coo0
`mco_l?Lod:VmooLclgof]3>omW@d?oHd=7oh/Nmon78__oPb<3oll>M00;ollBN00KollFNooC7Wood
b:3omLVQofR^nOod^8T2ooFhR@;omKV90_of^HT04?of^XWol[ZBoo:jT_oc^i;olkbBooBmTOoe_I7o
mKjAooJoTOog`97oml6AooS2TOoha97onLFAooNhPOoh^842ooRiP@06ooNhP_oh^H;on;V2ooRiP_oh
^X;onKZ20_oi^h403ooj_87on[f1ooZnPOok_X7onkn2oo_0P_ol`X;oo<>3ooc4PoomaH?ooLJ4oog8
QOonbXOoo/^8ook=R@1=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
02kooooo00?o0000ooooooooool0@?ooool2oio3lP0=olk9eOo<b=Ooc<SGom;5c_oAaLood<G@oko3
g?no`]goI:?dodn/nOoId=3of=3AomK@d`02on38`003omo8`_oNb<CollFN00;om<NO00Com<RPooG9
XOofcJ;om/jS0_oe^8T01_oe^HWom[V9ooJiROof^HWom[Z9oo:jTP;olk^B00colkbBooBmTOoe_I7o
mKjAooJoTOog`97oml6AooS2TOoha97onLFAooW6TOojb982ooRiP@06ooRjPOoh^H;on;V2ooRiP_oh
^X;onKZ20_oi^h403?oj_87on[f1ooZnPOok_X7onkn2oo_0P_ol`X;oo<>3ooc4PoomaHCooLJ4oog8
QE7ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`00;oooool00ol0003o
ooooooooo`10ooooo`;oWl?b00Coc<SGol[8f?oAaLood<G@0_o?aM403Ono`]go_/;Mof^Vm?mL/O_o
f=3AomK@dooEd=Codm3Fomo8`_oNb<CogLW5om_9aoodb:000_oebJ401OofcJ;om/jSooK@YOlmYoKo
mKV900;om[V90_of^XT02Oog^hWolk^Boo>lT_oc_9;om;fAooFmTOoe_Y7om[nAooO0T@02ooS2T@0>
ooS4TOoiaI7onLJAoo[8T_okbi?onlfCooc>U?old9GooM:FooRiP_oh^X;onKZ2ooVkPOoj_842ooZm
P@09ooZnPOok_X7onkn2oo_0P_ol`X;oo<>3ooc4PoomaHCooLJ405;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`00<?ooool00ol0003oooooooooo`11ooooo`07oio3l_o:
b=SobLSIolO8f_o?aM7oc/GBokk2g@02okg2gP04og6Ym?mQ]?coeM3Dom?@eP;od/oG00_ogLW5om_9
aooKbLOod/K>om76d?o@am7oXK_/oj:ljoo3fn_o`][/o`Z?gP02ooJiR@;om[Z900?omk^9ooNlROoc
_9800_od_I401_oe_I7om[nAooO0TOog`97on<:AooS4T@;onLFA00conLJAoo[8T_okbi?onlfCooc>
U?old9GooM:FoogGV?omfIWonKZ2ooVkPOoj_842ooZmP@07ooZnPOok_X7onkn2oo_1P_ol`X;oo<>3
ooc4P`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool0037ooooo0_l0
0012ooooo`0Koio3lOnO`_7oalSJolK8foo>aM;oc<GCol_5eOnl`]ko_<;Oogb^lol0HM?oK;Olom;?
eoo@cmWocm3Jom_9aooJbLWofL[;omO;cOo@am7oc/OCoj:ljonS_>_o`=[/okoIkOnmfNkoh]3500;o
m[Z900Comk^9ooNlROog_HWom;fA0_oe_I404oof_i7oml2AooO1TOoh`Y7on<BAooW5TOoiaY7on/RB
oo[9T_okbi?onlfCooc@UOomdYKooMBGoogGV?omfIWooMjMoogQW_oj_8400_oj_H401?oj_X7onkj1
oo^oP_ok`H9Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool003?ooooo
00?o0000ooooooooool0@?ooool2oio2l@09olK8foo3b=go`lSMol_5eOo:aMKo_<;Ook_2gon1/??o
0fkM00;oM;[l00Socm3Jolg?foo;d=gofL[;omO;cOoFc=3oc/OColc7e@?ooooo01_o06O<okcJkonj
fo7oh=?;omkDc_oooooomkf9ooRmROoh_XWomKjAooJoTOog`97oml6AooS2TOoha97onLFAooW6TOoj
b9;on/VBoo_;TookcI?oo=2EoogBU_omeiSooMVIoogLVoomgYd0HOooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo000dooooo`03o`000?oooooooooo043ooooo0_nO`_400oo3
b=go`/ONol[5eP02olS5e`0:ok_2gonj`^3oQ[;boaMkiOl0L]goNkgkol_@gOo9d=oob=7QomK<d0;o
e<cB1_ooool00onhg?;oooooooooo`05ooooo`0?ooJoTOog`97oml6AooS2TOoha97onLFAooW6TOoj
b9;onl^Coo_=ToolcYCoo=2EoogBU_omeiSooMVI06Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`00=Oooool00ol0003oooooooooo`11ooooo`08oio2lOo2amko`LOOolS5
eoo7a]WoaLKJok[2h?ni`^42ohnel0;o4WoU00CoP<3lolSAhOo5dN?oe<cB4Oooool02ooh`Y7on<BA
ooS4TOoiaI7onLJAoo[8T_okbi?onlfCooc@UOomdYKooMBG06Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`00=_ooool2o`00047ooooo0onO`_401Onoan7o_LSRolG6f_o4
a]co^L;Q00Cooooo00?oQ<;kooooooooool05?ooool01_oiaI7onLJAoo[8T_ojbI;onl^Coo_=Tf_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`00>?ooool00ol0003ooooo
ooooo`10ooooo`05oio2lOnmb>;o_<STokc8i?o4a]`0SOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo000iooooo`03o`000?oooooooooo043ooooo00?oX<;aooooooooool0
Soooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000jooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo000kooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0T?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo000looooo`;o0000?_ooool00ol0
003oooooooooo`2Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool003ko
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool003oooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`2Cooooo`05o`000?ooooooooooooooool000002Oooool0043ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`2Cooooo`05o`000?ooooooooooooooool000002Oooool0047ooooo
0_l0000iooooo`03o`000?oooooooooo09Cooooo00Co0000oooooooooooo00002Oooool004?ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooo000000Wooooo
0014ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0UOooool01?l0003ooooooooo
ool00008ooooo`00AOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo09Kooooo00?o
0000ooooool000002?ooool004Kooooo0_l0000dooooo`03o`000?oooooooooo09Oooooo0_l00008
ooooo`00B?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09Oooooo0ol00008oooo
o`00BOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09?ooooo1?l0000;ooooo`00
B_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo08oooooo1?l0000?ooooo`00Booo
ool2o`0002kooooo00?o0000ooooooooool0S?ooool3o`0001?ooooo001=ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0R?ooool4o`0001Kooooo001>ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0Q?ooool4o`0001[ooooo001?ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0P?ooool4o`0001kooooo001@ooooo`;o0000:Oooool00ol0003ooooo
ooooo`1looooo`Co00008_ooool005;ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`1hooooo`Co00009_ooool005?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1e
ooooo`?o0000:_ooool005Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1aoooo
o`Co0000;Oooool005Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1]ooooo`Co
0000<Oooool005Kooooo0_l0000Sooooo`03o`000?oooooooooo06Wooooo1?l0000eooooo`00F?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Gooooo1?l0000iooooo`00FOooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo1?l0000mooooo`00F_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo05kooooo0ol00011ooooo`00Foooool2o`0001ko
oooo00?o0000ooooooooool0F_ooool4o`0004Cooooo001Mooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0E_ooool4o`0004Sooooo001Nooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0D_ooool4o`0004cooooo001Oooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0C_ooool4o`00053ooooo001Pooooo`;o00006Oooool00ol0003oooooooooo`1:oooo
o`Co0000E?ooool006;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`?o
0000F?ooool006?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`13ooooo`Co0000
Foooool006Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`Co0000Gooo
ool006Gooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo1?l0001Sooooo`00Ioooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo1?l0001Wooooo`00J?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03Cooooo0ol0001[ooooo`00JOooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo033ooooo1?l0001^ooooo`00J_ooool2o`0000kooooo00?o
0000ooooooooool0;Oooool4o`0007;ooooo001/ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0:Oooool4o`0007Kooooo001]ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09Oooool4o`0007[ooooo001^ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08Oooool4o`0007kooooo001_ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
7_ooool3o`0008;ooooo001`ooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`Co0000QOoo
ool007;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000ROooool0
07?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000SOooool007Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000TOooool007Gooooo
0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002Eooooo`00Moooool01?l0003ooooooooo
ool00009ooooo`?o0000VOooool007Sooooo00?o0000ooooool000001Oooool4o`0009cooooo001i
ooooo`;o000000?oooooo`000?l000000_l0002Pooooo`00N_ooool2o`000:Cooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0681058, 0.0130696, \
0.00364897, 0.00364897}},
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.4 Wavefront Propagation with Gaussian Wavelets", "Subsection",
  CellTags->{"AOG0.", "6.4", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2"}],

Cell[CellGroupData[{

Cell["Introduction to Wavelet Analysis", "Subsubsection",
  CellTags->{
  "AOG0.", "6.4.1", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],

Cell[TextData[{
  "Wavelet analysis is a very new concept that is still in its infancy. This \
section introduces the idea and uses it in several examples. At the moment, \
there are two special functions used here for wavelet analysis: a new light \
source, called ",
  StyleBox["LineOfWavelets", "Input"],
  " that constructs a set of ",
  StyleBox["GaussianBeam", "Input"],
  " wavelet functions, and a special function, called ",
  StyleBox["FindField", "Input"],
  " that calculates the interference between the different Gaussian wavelets. \
Both ",
  StyleBox["LineOfWavelets", "Input"],
  " and ",
  StyleBox["FindField", "Input"],
  " will eventually become built-in functions of ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  ", along with several other functions that includes a point source function \
called ",
  StyleBox["WedgeOfWavelets", "Input"],
  ", but for the moment, they are defined here externally until their final \
formats are fully worked out. The permanent versions of these two functions \
may be altered and their present formats may not get supported in the future. \
Presently, these functions must be taken as \"experimental\". Currently, all \
calculations are only carried out in the two-dimensions of the optical and \
transverse axes. In the near future, there will be additional support for \
full three-dimensional calculations with the ",
  StyleBox["GridOfWavelets", "Input"],
  " and ",
  StyleBox["PointOfWavelets", "Input"],
  " source functions to be developed as well."
}], "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define LineOfWavelets (Evaluate This Subsection)", "Subsubsection",
  CellDingbat->None,
  CellTags->{"AOG0.", "6.4.2", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],

Cell[TextData[{
  " In this section, we define ",
  StyleBox["LineOfWavelets", "Input"],
  ". You must evaluate the following two subsections before running any \
wavelet analysis examples."
}], "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],

Cell["Clear[LineOfWavelets];", "Input",
  CellLabel->"In[517]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],

Cell["\<\
Options[LineOfWavelets]:={
\tPaddingFactor->1,
\tNumberOfRays->11,
\tWaveLength->.532,
\tIntrinsicMedium->Vacuum};\
\>", "Input",
  CellLabel->"In[518]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],

Cell["\<\
LineOfWavelets[linewidthin_,opts___]:=
Block[{divergence, y, options, beamspotsize, paddingfactor, numberofrays, \
wavelength, beamoffset, intrinsicmedium, refractiveindex, linewidth},
\toptions = Flatten[{opts,Options[LineOfWavelets]}];
\t{paddingfactor, numberofrays, wavelength, intrinsicmedium} = 
\t\t{PaddingFactor, NumberOfRays, WaveLength, IntrinsicMedium}/.options;
\tIf[paddingfactor<1&&numberofrays>1,
\t\tPrint[\"Warning, LineOfWavelets will not be uniform.\"];
\t\tPrint[\"Set PaddingFactor greater or equal to 1 for uniform illumination.\
\"]
\t];
\tIf[numberofrays>1,
\t\tlinewidth = linewidthin;
\t\tbeamoffset = linewidth/(numberofrays-1)
\t,
\t\tbeamoffset = linewidthin;
\t\tlinewidth = 0
\t];
\tbeamspotsize = beamoffset*paddingfactor;
\trefractiveindex = ModelRefractiveIndex[intrinsicmedium][options];
\tdivergence = 2*(wavelength*10^-3)/(Pi*refractiveindex*beamspotsize)+10^-10;
\tTable[
\t\tMove[GaussianBeam[beamspotsize,divergence,options],{0,y}],
\t\t{y,-linewidth/2,linewidth/2,beamoffset}]
];\
\>", "Input",
  CellLabel->"In[519]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define FindField (Evaluate This Subsection)", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  CellTags->{"AOG0.", "6.4.3", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],

Cell[TextData[{
  " In this section, we define ",
  StyleBox["FindField", "Input"],
  ". ",
  StyleBox["FindField", "Input"],
  " returns a symbolic function that represents either the field intensity \
(for  ",
  StyleBox["IntensityTransform->True", "Input"],
  ") or the complex optical field (",
  StyleBox["IntensityTransform->False", "Input"],
  "). You must evaluate this subsection (as well as the ",
  StyleBox["LineOfWavelets", "Input"],
  " subsection) before running any wavelet analysis examples."
}], "Text",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],

Cell["Clear[FindField];", "Input",
  CellLabel->"In[520]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],

Cell["\<\
Options[FindField]:=
\t{IntensityTransform->True,
\tCoherentSource->True,
\tNormalizeOutput->True,
\tCompiled->True};\
\>", "Input",
  CellLabel->"In[521]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],

Cell["\<\
FindField[opticalsystem_,opts___] :=
Block[{rp, sp, xc, yc, xp, yp, tx, ty, sc, zo, wo, W, R, field, k, wl, ol, \
minOL, gaussianresults, ds, scale, intensity, results, sourcewaist, width, \
centers, widths, options, intensitytransform, coherentsource, \
normalizeoutput, compiled},
\toptions = Flatten[{opts,Options[FindField]}];
\t\t{intensitytransform, coherentsource, normalizeoutput, compiled} = 
\t\t\t{IntensityTransform, CoherentSource, NormalizeOutput, \
Compiled}/.options;
\tgaussianresults = GaussianTrace[opticalsystem, \
ABCDConstruction->Horizontal, 
\t\tNumericalResults->True, ReportedSurfaces->{-1}];
\tIf[Head[gaussianresults[[1]]]=!=List,gaussianresults={gaussianresults}];
\tClear[xp,yp];
\tcenters = widths = {};
\tminOL = Sort[OpticalLength/.gaussianresults][[1]];
\tscale = 1/Length[gaussianresults];
\tfield = Map[
\t\t(
\t\t{zo,wo,sc,wl,ol,intensity} = 
\t\t\t{BeamScaleLength,BeamWaist,WaistDistance,WaveLength*10^-3,OpticalLength,\
Intensity/100}/.#;
\t\tsc = -sc;
\t\t{tx,ty} = (ABCDRotationMatrix/.#)[[1]][[{1,2}]];
\t\t{xc,yc} = (ABCDCenterPoint/.#)[[{1,2}]];
\t\tcenters = {centers,yc};
\t\tk = 2 Pi/wl;
\t\tds = Dot[{xp,yp-yc},{tx,ty}];
\t\trpSq = (xp)^2+(yp-yc)^2-ds^2;
\t\tol = ol - minOL + ds;
\t\tsp = sc + ds;
\t\tW = wo*Sqrt[1+(sp/zo)^2];
\t\twidth = W/.{xp->0,yp->0};
\t\twidths = {widths,width};
\t\tR = sp*(1+(zo/sp)^2);
\t\tenergy = \
NIntegrate[((Exp[-rpSq/W^2])^2/W)/.xp->0,{yp,yc-3*width,yc+3*width},\
MaxRecursion->12];
\t\tSqrt[intensity/W]*
\t\t\tExp[-rpSq/W^2]*Exp[-I(k*ol-ArcTan[zo,sp])]*Exp[-I*k*rpSq/(2*R)]/Sqrt[\
energy]
\t\t)&
\t,
\t\tgaussianresults
\t];
\tIf[intensitytransform === True,
\t\tIf[coherentsource === True,
\t\t\tfield = Abs[Apply[Plus,field]]^2
\t\t,
\t\t\tfield = Apply[Plus,Map[(Abs[#]^2)&,field]]
\t\t];
\t\tcenters = Sort[Flatten[centers]][[{1,-1}]];
\t\twidth = Sort[Flatten[widths]][[-1]];
\t\tIf[normalizeoutput=!=False,
\t\t\tfield = \
field/NIntegrate[field/.xp->0,{yp,-3*width+centers[[1]],3*width+centers[[2]]}]\

\t\t];
\t,
\t\tIf[normalizeoutput=!=False,
\t\t\tfield = scale*Apply[Plus,field]
\t\t,
\t\t\tfield = Apply[Plus,field]
\t\t]
\t];
\tfield = field/.{xp->#1,yp->#2};
\tIf[compiled===True,
\t\tApply[Compile,{{#1,#2}, field}]
\t,
\t\tApply[Function,{{#1,#2}, field}]
\t]
]\
\>", "Input",
  CellLabel->"In[522]:=",
  ShowGroupOpenCloseIcon->True,
  PrivateCellOptions->{"DefaultCellGroupOpen"->False},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Collimated Beam of Wavelets", "Subsubsection",
  CellTags->{"AOG0.", "6.4.4", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
waveletSystem = {
\tLineOfWavelets[10,NumberOfRays->9,PaddingFactor->1],
\tMove[Screen[50],50]}\
\>", "Input",
  CellLabel->"In[46]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            
            TagBox[\(Move[
                GaussianBeam[5\/4, 0.00027094547511964266`, 
                  IntrinsicMedium \[Rule] Vacuum, NumberOfRays \[Rule] 9, 
                  PaddingFactor \[Rule] 1], {0, \(-5.`\)}]\),
              HoldForm], ",", 
            
            TagBox[\(Move[
                GaussianBeam[5\/4, 0.00027094547511964266`, 
                  IntrinsicMedium \[Rule] Vacuum, NumberOfRays \[Rule] 9, 
                  PaddingFactor \[Rule] 1], {0, \(-3.75`\)}]\),
              HoldForm], ",", 
            
            TagBox[\(Move[
                GaussianBeam[5\/4, 0.00027094547511964266`, 
                  IntrinsicMedium \[Rule] Vacuum, NumberOfRays \[Rule] 9, 
                  PaddingFactor \[Rule] 1], {0, \(-2.5`\)}]\),
              HoldForm], ",", 
            
            TagBox[\(Move[
                GaussianBeam[5\/4, 0.00027094547511964266`, 
                  IntrinsicMedium \[Rule] Vacuum, NumberOfRays \[Rule] 9, 
                  PaddingFactor \[Rule] 1], {0, \(-1.25`\)}]\),
              HoldForm], ",", 
            
            TagBox[\(GaussianBeam[5\/4, 0.00027094547511964266`, 
                IntrinsicMedium \[Rule] Vacuum, NumberOfRays \[Rule] 9, 
                PaddingFactor \[Rule] 1]\),
              HoldForm], ",", 
            
            TagBox[\(Move[
                GaussianBeam[5\/4, 0.00027094547511964266`, 
                  IntrinsicMedium \[Rule] Vacuum, NumberOfRays \[Rule] 9, 
                  PaddingFactor \[Rule] 1], {0, 1.25`}]\),
              HoldForm], ",", 
            
            TagBox[\(Move[
                GaussianBeam[5\/4, 0.00027094547511964266`, 
                  IntrinsicMedium \[Rule] Vacuum, NumberOfRays \[Rule] 9, 
                  PaddingFactor \[Rule] 1], {0, 2.5`}]\),
              HoldForm], ",", 
            
            TagBox[\(Move[
                GaussianBeam[5\/4, 0.00027094547511964266`, 
                  IntrinsicMedium \[Rule] Vacuum, NumberOfRays \[Rule] 9, 
                  PaddingFactor \[Rule] 1], {0, 3.75`}]\),
              HoldForm], ",", 
            
            TagBox[\(Move[
                GaussianBeam[5\/4, 0.00027094547511964266`, 
                  IntrinsicMedium \[Rule] Vacuum, NumberOfRays \[Rule] 9, 
                  PaddingFactor \[Rule] 1], {0, 5.`}]\),
              HoldForm]}], "}"}], ",", 
        TagBox[\(Move[Screen[50], 50.`]\),
          HoldForm]}], "}"}]], "Output",
  CellLabel->"Out[46]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[waveletSystem,ShowGaussian->True,PlotType->TopView];\
\>", "Input",
  CellLabel->"In[47]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .02381 m
.97619 .18254 L
.97619 .34127 L
.97619 .5 L
.97619 .65873 L
.97619 .81746 L
.97619 .97619 L
.97619 .97619 L
.97619 .81746 L
.97619 .65873 L
.97619 .5 L
.97619 .34127 L
.97619 .18254 L
.97619 .02381 L
.97619 .02381 L
s
.97619 .5 m
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
.97619 .5 L
s
.97619 .97619 m
.97619 .95996 L
.97619 .91239 L
.97619 .83672 L
.97619 .7381 L
.97619 .62325 L
.97619 .5 L
.97619 .37675 L
.97619 .2619 L
.97619 .16328 L
.97619 .08761 L
.97619 .04004 L
.97619 .02381 L
.97619 .04004 L
.97619 .08761 L
.97619 .16328 L
.97619 .2619 L
.97619 .37675 L
.97619 .5 L
.97619 .62325 L
.97619 .7381 L
.97619 .83672 L
.97619 .91239 L
.97619 .95996 L
.97619 .97619 L
s
.039 .916 .04 r
1 Mabswid
.02381 .42857 m
.05556 .42857 L
.0873 .42857 L
.11905 .42857 L
.15079 .42857 L
.18254 .42857 L
.21429 .42857 L
.24603 .42857 L
.27778 .42857 L
.30952 .42857 L
.34127 .42857 L
.37302 .42857 L
.40476 .42857 L
.43651 .42857 L
.46825 .42857 L
.5 .42857 L
.53175 .42857 L
.56349 .42857 L
.59524 .42857 L
.62698 .42857 L
.65873 .42857 L
.69048 .42857 L
.72222 .42857 L
.75397 .42857 L
.78571 .42857 L
.81746 .42857 L
.84921 .42857 L
.88095 .42857 L
.9127 .42857 L
.94444 .42857 L
.97619 .42857 L
s
.02381 .38095 m
.05556 .38095 L
.0873 .38095 L
.11905 .38095 L
.15079 .38095 L
.18254 .38095 L
.21429 .38095 L
.24603 .38095 L
.27778 .38095 L
.30952 .38095 L
.34127 .38095 L
.37302 .38095 L
.40476 .38095 L
.43651 .38095 L
.46825 .38095 L
.5 .38095 L
.53175 .38095 L
.56349 .38095 L
.59524 .38095 L
.62698 .38095 L
.65873 .38095 L
.69048 .38095 L
.72222 .38095 L
.75397 .38095 L
.78571 .38095 L
.81746 .38095 L
.84921 .38095 L
.88095 .38095 L
.9127 .38095 L
.94444 .38095 L
.97619 .38095 L
s
0 0 0 r
.02381 .40476 m
.97619 .40476 L
s
% Start of user PostScript
0 -5. 50. -5. MAarrowhead1
% End of user PostScript
.97619 .40476 m
.97619 .40476 L
s
% Start of user PostScript
50. -5. MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .38333 m
.02381 .38476 L
.02381 .38619 L
.02381 .38762 L
.02381 .38905 L
.02381 .39048 L
.02381 .3919 L
.02381 .39333 L
.02381 .39476 L
.02381 .39619 L
.02381 .39762 L
.02381 .39905 L
.02381 .40048 L
.02381 .4019 L
.02381 .40333 L
.02381 .40476 L
.02381 .40619 L
.02381 .40762 L
.02381 .40905 L
.02381 .41048 L
.02381 .4119 L
.02381 .41333 L
.02381 .41476 L
.02381 .41619 L
.02381 .41762 L
.02381 .41905 L
.02381 .42048 L
.02381 .4219 L
.02381 .42333 L
.02381 .42476 L
.02381 .42619 L
s
.07143 .38333 m
.07143 .38476 L
.07143 .38619 L
.07143 .38762 L
.07143 .38905 L
.07143 .39048 L
.07143 .3919 L
.07143 .39333 L
.07143 .39476 L
.07143 .39619 L
.07143 .39762 L
.07143 .39905 L
.07143 .40048 L
.07143 .4019 L
.07143 .40333 L
.07143 .40476 L
.07143 .40619 L
.07143 .40762 L
.07143 .40905 L
.07143 .41048 L
.07143 .4119 L
.07143 .41333 L
.07143 .41476 L
.07143 .41619 L
.07143 .41762 L
.07143 .41905 L
.07143 .42048 L
.07143 .4219 L
.07143 .42333 L
.07143 .42476 L
.07143 .42619 L
s
.11905 .38333 m
.11905 .38476 L
.11905 .38619 L
.11905 .38762 L
.11905 .38905 L
.11905 .39048 L
.11905 .3919 L
.11905 .39333 L
.11905 .39476 L
.11905 .39619 L
.11905 .39762 L
.11905 .39905 L
.11905 .40048 L
.11905 .4019 L
.11905 .40333 L
.11905 .40476 L
.11905 .40619 L
.11905 .40762 L
.11905 .40905 L
.11905 .41048 L
.11905 .4119 L
.11905 .41333 L
.11905 .41476 L
.11905 .41619 L
.11905 .41762 L
.11905 .41905 L
.11905 .42048 L
.11905 .4219 L
.11905 .42333 L
.11905 .42476 L
.11905 .42619 L
s
.16667 .38333 m
.16667 .38476 L
.16667 .38619 L
.16667 .38762 L
.16667 .38905 L
.16667 .39048 L
.16667 .3919 L
.16667 .39333 L
.16667 .39476 L
.16667 .39619 L
.16667 .39762 L
.16667 .39905 L
.16667 .40048 L
.16667 .4019 L
.16667 .40333 L
.16667 .40476 L
.16667 .40619 L
.16667 .40762 L
.16667 .40905 L
.16667 .41048 L
.16667 .4119 L
.16667 .41333 L
.16667 .41476 L
.16667 .41619 L
.16667 .41762 L
.16667 .41905 L
.16667 .42048 L
.16667 .4219 L
.16667 .42333 L
.16667 .42476 L
.16667 .42619 L
s
.21429 .38333 m
.21429 .38476 L
.21429 .38619 L
.21429 .38762 L
.21429 .38905 L
.21429 .39048 L
.21429 .3919 L
.21429 .39333 L
.21429 .39476 L
.21429 .39619 L
.21429 .39762 L
.21429 .39905 L
.21429 .40048 L
.21429 .4019 L
.21429 .40333 L
.21429 .40476 L
.21429 .40619 L
.21429 .40762 L
.21429 .40905 L
.21429 .41048 L
.21429 .4119 L
.21429 .41333 L
.21429 .41476 L
.21429 .41619 L
.21429 .41762 L
.21429 .41905 L
.21429 .42048 L
.21429 .4219 L
.21429 .42333 L
.21429 .42476 L
.21429 .42619 L
s
.2619 .38333 m
.2619 .38476 L
.2619 .38619 L
.2619 .38762 L
.2619 .38905 L
.2619 .39048 L
.2619 .3919 L
.2619 .39333 L
.2619 .39476 L
.2619 .39619 L
.2619 .39762 L
.2619 .39905 L
.2619 .40048 L
.2619 .4019 L
.2619 .40333 L
.2619 .40476 L
.2619 .40619 L
.2619 .40762 L
.2619 .40905 L
.2619 .41048 L
.2619 .4119 L
.2619 .41333 L
.2619 .41476 L
.2619 .41619 L
.2619 .41762 L
.2619 .41905 L
.2619 .42048 L
.2619 .4219 L
.2619 .42333 L
.2619 .42476 L
.2619 .42619 L
s
.30952 .38333 m
.30952 .38476 L
.30952 .38619 L
.30952 .38762 L
.30952 .38905 L
.30952 .39048 L
.30952 .3919 L
.30952 .39333 L
.30952 .39476 L
.30952 .39619 L
.30952 .39762 L
.30952 .39905 L
.30952 .40048 L
.30952 .4019 L
.30952 .40333 L
.30952 .40476 L
.30952 .40619 L
.30952 .40762 L
.30952 .40905 L
.30952 .41048 L
.30952 .4119 L
.30952 .41333 L
.30952 .41476 L
.30952 .41619 L
.30952 .41762 L
.30952 .41905 L
.30952 .42048 L
.30952 .4219 L
.30952 .42333 L
.30952 .42476 L
.30952 .42619 L
s
.35714 .38333 m
.35714 .38476 L
.35714 .38619 L
.35714 .38762 L
.35714 .38905 L
.35714 .39048 L
.35714 .3919 L
.35714 .39333 L
.35714 .39476 L
.35714 .39619 L
.35714 .39762 L
.35714 .39905 L
.35714 .40048 L
.35714 .4019 L
.35714 .40333 L
.35714 .40476 L
.35714 .40619 L
.35714 .40762 L
.35714 .40905 L
.35714 .41048 L
.35714 .4119 L
.35714 .41333 L
.35714 .41476 L
.35714 .41619 L
.35714 .41762 L
.35714 .41905 L
.35714 .42048 L
.35714 .4219 L
.35714 .42333 L
.35714 .42476 L
.35714 .42619 L
s
.40476 .38333 m
.40476 .38476 L
.40476 .38619 L
.40476 .38762 L
.40476 .38905 L
.40476 .39048 L
.40476 .3919 L
.40476 .39333 L
.40476 .39476 L
.40476 .39619 L
.40476 .39762 L
.40476 .39905 L
.40476 .40048 L
.40476 .4019 L
.40476 .40333 L
.40476 .40476 L
.40476 .40619 L
.40476 .40762 L
.40476 .40905 L
.40476 .41048 L
.40476 .4119 L
.40476 .41333 L
.40476 .41476 L
.40476 .41619 L
.40476 .41762 L
.40476 .41905 L
.40476 .42048 L
.40476 .4219 L
.40476 .42333 L
.40476 .42476 L
.40476 .42619 L
s
.45238 .38333 m
.45238 .38476 L
.45238 .38619 L
.45238 .38762 L
.45238 .38905 L
.45238 .39048 L
.45238 .3919 L
.45238 .39333 L
.45238 .39476 L
.45238 .39619 L
.45238 .39762 L
.45238 .39905 L
.45238 .40048 L
.45238 .4019 L
.45238 .40333 L
.45238 .40476 L
.45238 .40619 L
.45238 .40762 L
.45238 .40905 L
.45238 .41048 L
.45238 .4119 L
.45238 .41333 L
.45238 .41476 L
.45238 .41619 L
.45238 .41762 L
.45238 .41905 L
.45238 .42048 L
.45238 .4219 L
.45238 .42333 L
.45238 .42476 L
.45238 .42619 L
s
.5 .38333 m
.5 .38476 L
.5 .38619 L
.5 .38762 L
.5 .38905 L
.5 .39048 L
.5 .3919 L
.5 .39333 L
.5 .39476 L
.5 .39619 L
.5 .39762 L
.5 .39905 L
.5 .40048 L
.5 .4019 L
.5 .40333 L
.5 .40476 L
.5 .40619 L
.5 .40762 L
.5 .40905 L
.5 .41048 L
.5 .4119 L
.5 .41333 L
.5 .41476 L
.5 .41619 L
.5 .41762 L
.5 .41905 L
.5 .42048 L
.5 .4219 L
.5 .42333 L
.5 .42476 L
.5 .42619 L
s
.54762 .38333 m
.54762 .38476 L
.54762 .38619 L
.54762 .38762 L
.54762 .38905 L
.54762 .39048 L
.54762 .3919 L
.54762 .39333 L
.54762 .39476 L
.54762 .39619 L
.54762 .39762 L
.54762 .39905 L
.54762 .40048 L
.54762 .4019 L
.54762 .40333 L
.54762 .40476 L
.54762 .40619 L
.54762 .40762 L
.54762 .40905 L
.54762 .41048 L
.54762 .4119 L
.54762 .41333 L
.54762 .41476 L
.54762 .41619 L
.54762 .41762 L
.54762 .41905 L
.54762 .42048 L
.54762 .4219 L
.54762 .42333 L
.54762 .42476 L
.54762 .42619 L
s
.59524 .38333 m
.59524 .38476 L
.59524 .38619 L
.59524 .38762 L
.59524 .38905 L
.59524 .39048 L
.59524 .3919 L
.59524 .39333 L
.59524 .39476 L
.59524 .39619 L
.59524 .39762 L
.59524 .39905 L
.59524 .40048 L
.59524 .4019 L
.59524 .40333 L
.59524 .40476 L
.59524 .40619 L
.59524 .40762 L
.59524 .40905 L
.59524 .41048 L
.59524 .4119 L
.59524 .41333 L
.59524 .41476 L
.59524 .41619 L
.59524 .41762 L
.59524 .41905 L
.59524 .42048 L
.59524 .4219 L
.59524 .42333 L
.59524 .42476 L
.59524 .42619 L
s
.64286 .38333 m
.64286 .38476 L
.64286 .38619 L
.64286 .38762 L
.64286 .38905 L
.64286 .39048 L
.64286 .3919 L
.64286 .39333 L
.64286 .39476 L
.64286 .39619 L
.64286 .39762 L
.64286 .39905 L
.64286 .40048 L
.64286 .4019 L
.64286 .40333 L
.64286 .40476 L
.64286 .40619 L
.64286 .40762 L
.64286 .40905 L
.64286 .41048 L
.64286 .4119 L
.64286 .41333 L
.64286 .41476 L
.64286 .41619 L
.64286 .41762 L
.64286 .41905 L
.64286 .42048 L
.64286 .4219 L
.64286 .42333 L
.64286 .42476 L
.64286 .42619 L
s
.69048 .38333 m
.69048 .38476 L
.69048 .38619 L
.69048 .38762 L
.69048 .38905 L
.69048 .39048 L
.69048 .3919 L
.69048 .39333 L
.69048 .39476 L
.69048 .39619 L
.69048 .39762 L
.69048 .39905 L
.69048 .40048 L
.69048 .4019 L
.69048 .40333 L
.69048 .40476 L
.69048 .40619 L
.69048 .40762 L
.69048 .40905 L
.69048 .41048 L
.69048 .4119 L
.69048 .41333 L
.69048 .41476 L
.69048 .41619 L
.69048 .41762 L
.69048 .41905 L
.69048 .42048 L
.69048 .4219 L
.69048 .42333 L
.69048 .42476 L
.69048 .42619 L
s
.7381 .38333 m
.7381 .38476 L
.7381 .38619 L
.7381 .38762 L
.7381 .38905 L
.7381 .39048 L
.7381 .3919 L
.7381 .39333 L
.7381 .39476 L
.7381 .39619 L
.7381 .39762 L
.7381 .39905 L
.7381 .40048 L
.7381 .4019 L
.7381 .40333 L
.7381 .40476 L
.7381 .40619 L
.7381 .40762 L
.7381 .40905 L
.7381 .41048 L
.7381 .4119 L
.7381 .41333 L
.7381 .41476 L
.7381 .41619 L
.7381 .41762 L
.7381 .41905 L
.7381 .42048 L
.7381 .4219 L
.7381 .42333 L
.7381 .42476 L
.7381 .42619 L
s
.78571 .38333 m
.78571 .38476 L
.78571 .38619 L
.78571 .38762 L
.78571 .38905 L
.78571 .39048 L
.78571 .3919 L
.78571 .39333 L
.78571 .39476 L
.78571 .39619 L
.78571 .39762 L
.78571 .39905 L
.78571 .40048 L
.78571 .4019 L
.78571 .40333 L
.78571 .40476 L
.78571 .40619 L
.78571 .40762 L
.78571 .40905 L
.78571 .41048 L
.78571 .4119 L
.78571 .41333 L
.78571 .41476 L
.78571 .41619 L
.78571 .41762 L
.78571 .41905 L
.78571 .42048 L
.78571 .4219 L
.78571 .42333 L
.78571 .42476 L
.78571 .42619 L
s
.83333 .38333 m
.83333 .38476 L
.83333 .38619 L
.83333 .38762 L
.83333 .38905 L
.83333 .39048 L
.83333 .3919 L
.83333 .39333 L
.83333 .39476 L
.83333 .39619 L
.83333 .39762 L
.83333 .39905 L
.83333 .40048 L
.83333 .4019 L
.83333 .40333 L
.83333 .40476 L
.83333 .40619 L
.83333 .40762 L
.83333 .40905 L
.83333 .41048 L
.83333 .4119 L
.83333 .41333 L
.83333 .41476 L
.83333 .41619 L
.83333 .41762 L
.83333 .41905 L
.83333 .42048 L
.83333 .42191 L
.83333 .42333 L
.83333 .42476 L
.83333 .42619 L
s
.88095 .38333 m
.88095 .38476 L
.88095 .38619 L
.88095 .38762 L
.88095 .38905 L
.88095 .39048 L
.88095 .3919 L
.88095 .39333 L
.88095 .39476 L
.88095 .39619 L
.88095 .39762 L
.88095 .39905 L
.88095 .40048 L
.88095 .4019 L
.88095 .40333 L
.88095 .40476 L
.88095 .40619 L
.88095 .40762 L
.88095 .40905 L
.88095 .41048 L
.88095 .4119 L
.88095 .41333 L
.88095 .41476 L
.88095 .41619 L
.88095 .41762 L
.88095 .41905 L
.88095 .42048 L
.88095 .42191 L
.88095 .42333 L
.88095 .42476 L
.88095 .42619 L
s
.92857 .38333 m
.92857 .38476 L
.92857 .38619 L
.92857 .38762 L
.92857 .38905 L
.92857 .39048 L
.92857 .3919 L
.92857 .39333 L
.92857 .39476 L
.92857 .39619 L
.92857 .39762 L
.92857 .39905 L
.92857 .40048 L
.92857 .4019 L
.92857 .40333 L
.92857 .40476 L
.92857 .40619 L
.92857 .40762 L
.92857 .40905 L
.92857 .41048 L
.92857 .4119 L
.92857 .41333 L
.92857 .41476 L
.92857 .41619 L
.92857 .41762 L
.92857 .41905 L
.92857 .42048 L
.92857 .42191 L
.92857 .42333 L
.92857 .42476 L
.92857 .42619 L
s
.02381 .45238 m
.05556 .45238 L
.0873 .45238 L
.11905 .45238 L
.15079 .45238 L
.18254 .45238 L
.21429 .45238 L
.24603 .45238 L
.27778 .45238 L
.30952 .45238 L
.34127 .45238 L
.37302 .45238 L
.40476 .45238 L
.43651 .45238 L
.46825 .45238 L
.5 .45238 L
.53175 .45238 L
.56349 .45238 L
.59524 .45238 L
.62698 .45238 L
.65873 .45238 L
.69048 .45238 L
.72222 .45238 L
.75397 .45238 L
.78571 .45238 L
.81746 .45238 L
.84921 .45238 L
.88095 .45238 L
.9127 .45238 L
.94444 .45238 L
.97619 .45238 L
s
.02381 .40476 m
.05556 .40476 L
.0873 .40476 L
.11905 .40476 L
.15079 .40476 L
.18254 .40476 L
.21429 .40476 L
.24603 .40476 L
.27778 .40476 L
.30952 .40476 L
.34127 .40476 L
.37302 .40476 L
.40476 .40476 L
.43651 .40476 L
.46825 .40476 L
.5 .40476 L
.53175 .40476 L
.56349 .40476 L
.59524 .40476 L
.62698 .40476 L
.65873 .40476 L
.69048 .40476 L
.72222 .40476 L
.75397 .40476 L
.78571 .40476 L
.81746 .40476 L
.84921 .40476 L
.88095 .40476 L
.9127 .40476 L
.94444 .40476 L
.97619 .40476 L
s
0 0 0 r
.02381 .42857 m
.97619 .42857 L
s
% Start of user PostScript
0 -3.75 50. -3.75 MAarrowhead1
% End of user PostScript
.97619 .42857 m
.97619 .42857 L
s
% Start of user PostScript
50. -3.75 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .40714 m
.02381 .40857 L
.02381 .41 L
.02381 .41143 L
.02381 .41286 L
.02381 .41429 L
.02381 .41571 L
.02381 .41714 L
.02381 .41857 L
.02381 .42 L
.02381 .42143 L
.02381 .42286 L
.02381 .42429 L
.02381 .42571 L
.02381 .42714 L
.02381 .42857 L
.02381 .43 L
.02381 .43143 L
.02381 .43286 L
.02381 .43429 L
.02381 .43571 L
.02381 .43714 L
.02381 .43857 L
.02381 .44 L
.02381 .44143 L
.02381 .44286 L
.02381 .44429 L
.02381 .44571 L
.02381 .44714 L
.02381 .44857 L
.02381 .45 L
s
.07143 .40714 m
.07143 .40857 L
.07143 .41 L
.07143 .41143 L
.07143 .41286 L
.07143 .41429 L
.07143 .41571 L
.07143 .41714 L
.07143 .41857 L
.07143 .42 L
.07143 .42143 L
.07143 .42286 L
.07143 .42429 L
.07143 .42571 L
.07143 .42714 L
.07143 .42857 L
.07143 .43 L
.07143 .43143 L
.07143 .43286 L
.07143 .43429 L
.07143 .43571 L
.07143 .43714 L
.07143 .43857 L
.07143 .44 L
.07143 .44143 L
.07143 .44286 L
.07143 .44429 L
.07143 .44571 L
.07143 .44714 L
.07143 .44857 L
.07143 .45 L
s
.11905 .40714 m
.11905 .40857 L
.11905 .41 L
.11905 .41143 L
.11905 .41286 L
.11905 .41429 L
.11905 .41571 L
.11905 .41714 L
.11905 .41857 L
.11905 .42 L
.11905 .42143 L
.11905 .42286 L
.11905 .42429 L
.11905 .42571 L
.11905 .42714 L
.11905 .42857 L
.11905 .43 L
.11905 .43143 L
.11905 .43286 L
.11905 .43429 L
.11905 .43571 L
.11905 .43714 L
.11905 .43857 L
.11905 .44 L
.11905 .44143 L
.11905 .44286 L
.11905 .44429 L
.11905 .44571 L
.11905 .44714 L
.11905 .44857 L
.11905 .45 L
s
.16667 .40714 m
.16667 .40857 L
.16667 .41 L
.16667 .41143 L
.16667 .41286 L
.16667 .41429 L
.16667 .41571 L
.16667 .41714 L
.16667 .41857 L
.16667 .42 L
.16667 .42143 L
.16667 .42286 L
.16667 .42429 L
.16667 .42571 L
.16667 .42714 L
.16667 .42857 L
.16667 .43 L
.16667 .43143 L
.16667 .43286 L
.16667 .43429 L
.16667 .43571 L
.16667 .43714 L
.16667 .43857 L
.16667 .44 L
.16667 .44143 L
.16667 .44286 L
.16667 .44429 L
.16667 .44571 L
.16667 .44714 L
.16667 .44857 L
.16667 .45 L
s
.21429 .40714 m
.21429 .40857 L
.21429 .41 L
.21429 .41143 L
.21429 .41286 L
.21429 .41429 L
.21429 .41571 L
.21429 .41714 L
.21429 .41857 L
.21429 .42 L
.21429 .42143 L
.21429 .42286 L
.21429 .42429 L
.21429 .42571 L
.21429 .42714 L
.21429 .42857 L
.21429 .43 L
.21429 .43143 L
.21429 .43286 L
.21429 .43429 L
.21429 .43571 L
.21429 .43714 L
.21429 .43857 L
.21429 .44 L
.21429 .44143 L
.21429 .44286 L
.21429 .44429 L
.21429 .44571 L
.21429 .44714 L
.21429 .44857 L
.21429 .45 L
s
.2619 .40714 m
.2619 .40857 L
.2619 .41 L
.2619 .41143 L
.2619 .41286 L
.2619 .41429 L
.2619 .41571 L
.2619 .41714 L
.2619 .41857 L
.2619 .42 L
.2619 .42143 L
.2619 .42286 L
.2619 .42429 L
.2619 .42571 L
.2619 .42714 L
.2619 .42857 L
.2619 .43 L
.2619 .43143 L
.2619 .43286 L
.2619 .43429 L
.2619 .43571 L
.2619 .43714 L
.2619 .43857 L
.2619 .44 L
.2619 .44143 L
.2619 .44286 L
.2619 .44429 L
.2619 .44571 L
.2619 .44714 L
.2619 .44857 L
.2619 .45 L
s
.30952 .40714 m
.30952 .40857 L
.30952 .41 L
.30952 .41143 L
.30952 .41286 L
.30952 .41429 L
.30952 .41571 L
.30952 .41714 L
.30952 .41857 L
.30952 .42 L
.30952 .42143 L
.30952 .42286 L
.30952 .42429 L
.30952 .42571 L
.30952 .42714 L
.30952 .42857 L
.30952 .43 L
.30952 .43143 L
.30952 .43286 L
.30952 .43429 L
.30952 .43571 L
.30952 .43714 L
.30952 .43857 L
.30952 .44 L
.30952 .44143 L
.30952 .44286 L
.30952 .44429 L
.30952 .44571 L
.30952 .44714 L
.30952 .44857 L
.30952 .45 L
s
.35714 .40714 m
.35714 .40857 L
.35714 .41 L
.35714 .41143 L
.35714 .41286 L
.35714 .41429 L
.35714 .41571 L
.35714 .41714 L
.35714 .41857 L
.35714 .42 L
.35714 .42143 L
.35714 .42286 L
.35714 .42429 L
.35714 .42571 L
.35714 .42714 L
.35714 .42857 L
.35714 .43 L
.35714 .43143 L
.35714 .43286 L
.35714 .43429 L
.35714 .43571 L
.35714 .43714 L
.35714 .43857 L
.35714 .44 L
.35714 .44143 L
.35714 .44286 L
.35714 .44429 L
.35714 .44571 L
.35714 .44714 L
.35714 .44857 L
.35714 .45 L
s
.40476 .40714 m
.40476 .40857 L
.40476 .41 L
.40476 .41143 L
.40476 .41286 L
.40476 .41429 L
.40476 .41571 L
.40476 .41714 L
.40476 .41857 L
.40476 .42 L
.40476 .42143 L
.40476 .42286 L
.40476 .42429 L
.40476 .42571 L
.40476 .42714 L
.40476 .42857 L
.40476 .43 L
.40476 .43143 L
.40476 .43286 L
.40476 .43429 L
.40476 .43571 L
.40476 .43714 L
.40476 .43857 L
.40476 .44 L
.40476 .44143 L
.40476 .44286 L
.40476 .44429 L
.40476 .44571 L
.40476 .44714 L
.40476 .44857 L
.40476 .45 L
s
.45238 .40714 m
.45238 .40857 L
.45238 .41 L
.45238 .41143 L
.45238 .41286 L
.45238 .41429 L
.45238 .41571 L
.45238 .41714 L
.45238 .41857 L
.45238 .42 L
.45238 .42143 L
.45238 .42286 L
.45238 .42429 L
.45238 .42571 L
.45238 .42714 L
.45238 .42857 L
.45238 .43 L
.45238 .43143 L
.45238 .43286 L
.45238 .43429 L
.45238 .43571 L
.45238 .43714 L
.45238 .43857 L
.45238 .44 L
.45238 .44143 L
.45238 .44286 L
.45238 .44429 L
.45238 .44571 L
.45238 .44714 L
.45238 .44857 L
.45238 .45 L
s
.5 .40714 m
.5 .40857 L
.5 .41 L
.5 .41143 L
.5 .41286 L
.5 .41429 L
.5 .41571 L
.5 .41714 L
.5 .41857 L
.5 .42 L
.5 .42143 L
.5 .42286 L
.5 .42429 L
.5 .42571 L
.5 .42714 L
.5 .42857 L
.5 .43 L
.5 .43143 L
.5 .43286 L
.5 .43429 L
.5 .43571 L
.5 .43714 L
.5 .43857 L
.5 .44 L
.5 .44143 L
.5 .44286 L
.5 .44429 L
.5 .44571 L
.5 .44714 L
.5 .44857 L
.5 .45 L
s
.54762 .40714 m
.54762 .40857 L
.54762 .41 L
.54762 .41143 L
.54762 .41286 L
.54762 .41429 L
.54762 .41571 L
.54762 .41714 L
.54762 .41857 L
.54762 .42 L
.54762 .42143 L
.54762 .42286 L
.54762 .42429 L
.54762 .42571 L
.54762 .42714 L
.54762 .42857 L
.54762 .43 L
.54762 .43143 L
.54762 .43286 L
.54762 .43429 L
.54762 .43571 L
.54762 .43714 L
.54762 .43857 L
.54762 .44 L
.54762 .44143 L
.54762 .44286 L
.54762 .44429 L
.54762 .44571 L
.54762 .44714 L
.54762 .44857 L
.54762 .45 L
s
.59524 .40714 m
.59524 .40857 L
.59524 .41 L
.59524 .41143 L
.59524 .41286 L
.59524 .41429 L
.59524 .41571 L
.59524 .41714 L
.59524 .41857 L
.59524 .42 L
.59524 .42143 L
.59524 .42286 L
.59524 .42429 L
.59524 .42571 L
.59524 .42714 L
.59524 .42857 L
.59524 .43 L
.59524 .43143 L
.59524 .43286 L
.59524 .43429 L
.59524 .43571 L
.59524 .43714 L
.59524 .43857 L
.59524 .44 L
.59524 .44143 L
.59524 .44286 L
.59524 .44429 L
.59524 .44571 L
.59524 .44714 L
.59524 .44857 L
.59524 .45 L
s
.64286 .40714 m
.64286 .40857 L
.64286 .41 L
.64286 .41143 L
.64286 .41286 L
.64286 .41429 L
.64286 .41571 L
.64286 .41714 L
.64286 .41857 L
.64286 .42 L
.64286 .42143 L
.64286 .42286 L
.64286 .42429 L
.64286 .42571 L
.64286 .42714 L
.64286 .42857 L
.64286 .43 L
.64286 .43143 L
.64286 .43286 L
.64286 .43429 L
.64286 .43571 L
.64286 .43714 L
.64286 .43857 L
.64286 .44 L
.64286 .44143 L
.64286 .44286 L
.64286 .44429 L
.64286 .44571 L
.64286 .44714 L
.64286 .44857 L
.64286 .45 L
s
.69048 .40714 m
.69048 .40857 L
.69048 .41 L
.69048 .41143 L
.69048 .41286 L
.69048 .41429 L
.69048 .41571 L
.69048 .41714 L
.69048 .41857 L
.69048 .42 L
.69048 .42143 L
.69048 .42286 L
.69048 .42429 L
.69048 .42571 L
.69048 .42714 L
.69048 .42857 L
.69048 .43 L
.69048 .43143 L
.69048 .43286 L
.69048 .43429 L
.69048 .43571 L
.69048 .43714 L
.69048 .43857 L
.69048 .44 L
.69048 .44143 L
.69048 .44286 L
.69048 .44429 L
.69048 .44571 L
.69048 .44714 L
.69048 .44857 L
.69048 .45 L
s
.7381 .40714 m
.7381 .40857 L
.7381 .41 L
.7381 .41143 L
.7381 .41286 L
.7381 .41429 L
.7381 .41571 L
.7381 .41714 L
.7381 .41857 L
.7381 .42 L
.7381 .42143 L
.7381 .42286 L
.7381 .42429 L
.7381 .42571 L
.7381 .42714 L
.7381 .42857 L
.7381 .43 L
.7381 .43143 L
.7381 .43286 L
.7381 .43429 L
.7381 .43571 L
.7381 .43714 L
.7381 .43857 L
.7381 .44 L
.7381 .44143 L
.7381 .44286 L
.7381 .44429 L
.7381 .44571 L
.7381 .44714 L
.7381 .44857 L
.7381 .45 L
s
.78571 .40714 m
.78571 .40857 L
.78571 .41 L
.78571 .41143 L
.78571 .41286 L
.78571 .41429 L
.78571 .41571 L
.78571 .41714 L
.78571 .41857 L
.78571 .42 L
.78571 .42143 L
.78571 .42286 L
.78571 .42429 L
.78571 .42571 L
.78571 .42714 L
.78571 .42857 L
.78571 .43 L
.78571 .43143 L
.78571 .43286 L
.78571 .43429 L
.78571 .43571 L
.78571 .43714 L
.78571 .43857 L
.78571 .44 L
.78571 .44143 L
.78571 .44286 L
.78571 .44429 L
.78571 .44571 L
.78571 .44714 L
.78571 .44857 L
.78571 .45 L
s
.83333 .40714 m
.83333 .40857 L
.83333 .41 L
.83333 .41143 L
.83333 .41286 L
.83333 .41429 L
.83333 .41571 L
.83333 .41714 L
.83333 .41857 L
.83333 .42 L
.83333 .42143 L
.83333 .42286 L
.83333 .42429 L
.83333 .42571 L
.83333 .42714 L
.83333 .42857 L
.83333 .43 L
.83333 .43143 L
.83333 .43286 L
.83333 .43429 L
.83333 .43571 L
.83333 .43714 L
.83333 .43857 L
.83333 .44 L
.83333 .44143 L
.83333 .44286 L
.83333 .44429 L
.83333 .44571 L
.83333 .44714 L
.83333 .44857 L
.83333 .45 L
s
.88095 .40714 m
.88095 .40857 L
.88095 .41 L
.88095 .41143 L
.88095 .41286 L
.88095 .41429 L
.88095 .41571 L
.88095 .41714 L
.88095 .41857 L
.88095 .42 L
.88095 .42143 L
.88095 .42286 L
.88095 .42429 L
.88095 .42571 L
.88095 .42714 L
.88095 .42857 L
.88095 .43 L
.88095 .43143 L
.88095 .43286 L
.88095 .43429 L
.88095 .43571 L
.88095 .43714 L
.88095 .43857 L
.88095 .44 L
.88095 .44143 L
.88095 .44286 L
.88095 .44429 L
.88095 .44571 L
.88095 .44714 L
.88095 .44857 L
.88095 .45 L
s
.92857 .40714 m
.92857 .40857 L
.92857 .41 L
.92857 .41143 L
.92857 .41286 L
.92857 .41429 L
.92857 .41571 L
.92857 .41714 L
.92857 .41857 L
.92857 .42 L
.92857 .42143 L
.92857 .42286 L
.92857 .42429 L
.92857 .42571 L
.92857 .42714 L
.92857 .42857 L
.92857 .43 L
.92857 .43143 L
.92857 .43286 L
.92857 .43429 L
.92857 .43571 L
.92857 .43714 L
.92857 .43857 L
.92857 .44 L
.92857 .44143 L
.92857 .44286 L
.92857 .44429 L
.92857 .44571 L
.92857 .44714 L
.92857 .44857 L
.92857 .45 L
s
.02381 .47619 m
.05556 .47619 L
.0873 .47619 L
.11905 .47619 L
.15079 .47619 L
.18254 .47619 L
.21429 .47619 L
.24603 .47619 L
.27778 .47619 L
.30952 .47619 L
.34127 .47619 L
.37302 .47619 L
.40476 .47619 L
.43651 .47619 L
.46825 .47619 L
.5 .47619 L
.53175 .47619 L
.56349 .47619 L
.59524 .47619 L
.62698 .47619 L
.65873 .47619 L
.69048 .47619 L
.72222 .47619 L
.75397 .47619 L
.78571 .47619 L
.81746 .47619 L
.84921 .47619 L
.88095 .47619 L
.9127 .47619 L
.94444 .47619 L
.97619 .47619 L
s
.02381 .42857 m
.05556 .42857 L
.0873 .42857 L
.11905 .42857 L
.15079 .42857 L
.18254 .42857 L
.21429 .42857 L
.24603 .42857 L
.27778 .42857 L
.30952 .42857 L
.34127 .42857 L
.37302 .42857 L
.40476 .42857 L
.43651 .42857 L
.46825 .42857 L
.5 .42857 L
.53175 .42857 L
.56349 .42857 L
.59524 .42857 L
.62698 .42857 L
.65873 .42857 L
.69048 .42857 L
.72222 .42857 L
.75397 .42857 L
.78571 .42857 L
.81746 .42857 L
.84921 .42857 L
.88095 .42857 L
.9127 .42857 L
.94444 .42857 L
.97619 .42857 L
s
0 0 0 r
.02381 .45238 m
.97619 .45238 L
s
% Start of user PostScript
0 -2.5 50. -2.5 MAarrowhead1
% End of user PostScript
.97619 .45238 m
.97619 .45238 L
s
% Start of user PostScript
50. -2.5 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .43095 m
.02381 .43238 L
.02381 .43381 L
.02381 .43524 L
.02381 .43667 L
.02381 .4381 L
.02381 .43952 L
.02381 .44095 L
.02381 .44238 L
.02381 .44381 L
.02381 .44524 L
.02381 .44667 L
.02381 .4481 L
.02381 .44952 L
.02381 .45095 L
.02381 .45238 L
.02381 .45381 L
.02381 .45524 L
.02381 .45667 L
.02381 .4581 L
.02381 .45952 L
.02381 .46095 L
.02381 .46238 L
.02381 .46381 L
.02381 .46524 L
.02381 .46667 L
.02381 .4681 L
.02381 .46952 L
.02381 .47095 L
.02381 .47238 L
.02381 .47381 L
s
.07143 .43095 m
.07143 .43238 L
.07143 .43381 L
.07143 .43524 L
.07143 .43667 L
.07143 .4381 L
.07143 .43952 L
.07143 .44095 L
.07143 .44238 L
.07143 .44381 L
.07143 .44524 L
.07143 .44667 L
.07143 .4481 L
.07143 .44952 L
.07143 .45095 L
.07143 .45238 L
.07143 .45381 L
.07143 .45524 L
.07143 .45667 L
.07143 .4581 L
.07143 .45952 L
.07143 .46095 L
.07143 .46238 L
.07143 .46381 L
.07143 .46524 L
.07143 .46667 L
.07143 .4681 L
.07143 .46952 L
.07143 .47095 L
.07143 .47238 L
.07143 .47381 L
s
.11905 .43095 m
.11905 .43238 L
.11905 .43381 L
.11905 .43524 L
.11905 .43667 L
.11905 .4381 L
.11905 .43952 L
.11905 .44095 L
.11905 .44238 L
.11905 .44381 L
.11905 .44524 L
.11905 .44667 L
.11905 .4481 L
.11905 .44952 L
.11905 .45095 L
.11905 .45238 L
.11905 .45381 L
.11905 .45524 L
.11905 .45667 L
.11905 .4581 L
.11905 .45952 L
.11905 .46095 L
.11905 .46238 L
.11905 .46381 L
.11905 .46524 L
.11905 .46667 L
.11905 .4681 L
.11905 .46952 L
.11905 .47095 L
.11905 .47238 L
.11905 .47381 L
s
.16667 .43095 m
.16667 .43238 L
.16667 .43381 L
.16667 .43524 L
.16667 .43667 L
.16667 .4381 L
.16667 .43952 L
.16667 .44095 L
.16667 .44238 L
.16667 .44381 L
.16667 .44524 L
.16667 .44667 L
.16667 .4481 L
.16667 .44952 L
.16667 .45095 L
.16667 .45238 L
.16667 .45381 L
.16667 .45524 L
.16667 .45667 L
.16667 .4581 L
.16667 .45952 L
.16667 .46095 L
.16667 .46238 L
.16667 .46381 L
.16667 .46524 L
.16667 .46667 L
.16667 .4681 L
.16667 .46952 L
.16667 .47095 L
.16667 .47238 L
.16667 .47381 L
s
.21429 .43095 m
.21429 .43238 L
.21429 .43381 L
.21429 .43524 L
.21429 .43667 L
.21429 .4381 L
.21429 .43952 L
.21429 .44095 L
.21429 .44238 L
.21429 .44381 L
.21429 .44524 L
.21429 .44667 L
.21429 .4481 L
.21429 .44952 L
.21429 .45095 L
.21429 .45238 L
.21429 .45381 L
.21429 .45524 L
.21429 .45667 L
.21429 .4581 L
.21429 .45952 L
.21429 .46095 L
.21429 .46238 L
.21429 .46381 L
.21429 .46524 L
.21429 .46667 L
.21429 .4681 L
.21429 .46952 L
.21429 .47095 L
.21429 .47238 L
.21429 .47381 L
s
.2619 .43095 m
.2619 .43238 L
.2619 .43381 L
.2619 .43524 L
.2619 .43667 L
.2619 .4381 L
.2619 .43952 L
.2619 .44095 L
.2619 .44238 L
.2619 .44381 L
.2619 .44524 L
.2619 .44667 L
.2619 .4481 L
.2619 .44952 L
.2619 .45095 L
.2619 .45238 L
.2619 .45381 L
.2619 .45524 L
.2619 .45667 L
.2619 .4581 L
.2619 .45952 L
.2619 .46095 L
.2619 .46238 L
.2619 .46381 L
.2619 .46524 L
.2619 .46667 L
.2619 .4681 L
.2619 .46952 L
.2619 .47095 L
.2619 .47238 L
.2619 .47381 L
s
.30952 .43095 m
.30952 .43238 L
.30952 .43381 L
.30952 .43524 L
.30952 .43667 L
.30952 .4381 L
.30952 .43952 L
.30952 .44095 L
.30952 .44238 L
.30952 .44381 L
.30952 .44524 L
.30952 .44667 L
.30952 .4481 L
.30952 .44952 L
.30952 .45095 L
.30952 .45238 L
.30952 .45381 L
.30952 .45524 L
.30952 .45667 L
.30952 .4581 L
.30952 .45952 L
.30952 .46095 L
.30952 .46238 L
.30952 .46381 L
.30952 .46524 L
.30952 .46667 L
.30952 .4681 L
.30952 .46952 L
.30952 .47095 L
.30952 .47238 L
.30952 .47381 L
s
.35714 .43095 m
.35714 .43238 L
.35714 .43381 L
.35714 .43524 L
.35714 .43667 L
.35714 .4381 L
.35714 .43952 L
.35714 .44095 L
.35714 .44238 L
.35714 .44381 L
.35714 .44524 L
.35714 .44667 L
.35714 .4481 L
.35714 .44952 L
.35714 .45095 L
.35714 .45238 L
.35714 .45381 L
.35714 .45524 L
.35714 .45667 L
.35714 .4581 L
.35714 .45952 L
.35714 .46095 L
.35714 .46238 L
.35714 .46381 L
.35714 .46524 L
.35714 .46667 L
.35714 .4681 L
.35714 .46952 L
.35714 .47095 L
.35714 .47238 L
.35714 .47381 L
s
.40476 .43095 m
.40476 .43238 L
.40476 .43381 L
.40476 .43524 L
.40476 .43667 L
.40476 .4381 L
.40476 .43952 L
.40476 .44095 L
.40476 .44238 L
.40476 .44381 L
.40476 .44524 L
.40476 .44667 L
.40476 .4481 L
.40476 .44952 L
.40476 .45095 L
.40476 .45238 L
.40476 .45381 L
.40476 .45524 L
.40476 .45667 L
.40476 .4581 L
.40476 .45952 L
.40476 .46095 L
.40476 .46238 L
.40476 .46381 L
.40476 .46524 L
.40476 .46667 L
.40476 .4681 L
.40476 .46952 L
.40476 .47095 L
.40476 .47238 L
.40476 .47381 L
s
.45238 .43095 m
.45238 .43238 L
.45238 .43381 L
.45238 .43524 L
.45238 .43667 L
.45238 .4381 L
.45238 .43952 L
.45238 .44095 L
.45238 .44238 L
.45238 .44381 L
.45238 .44524 L
.45238 .44667 L
.45238 .4481 L
.45238 .44952 L
.45238 .45095 L
.45238 .45238 L
.45238 .45381 L
.45238 .45524 L
.45238 .45667 L
.45238 .4581 L
.45238 .45952 L
.45238 .46095 L
.45238 .46238 L
.45238 .46381 L
.45238 .46524 L
.45238 .46667 L
.45238 .4681 L
.45238 .46952 L
.45238 .47095 L
.45238 .47238 L
.45238 .47381 L
s
.5 .43095 m
.5 .43238 L
.5 .43381 L
.5 .43524 L
.5 .43667 L
.5 .4381 L
.5 .43952 L
.5 .44095 L
.5 .44238 L
.5 .44381 L
.5 .44524 L
.5 .44667 L
.5 .4481 L
.5 .44952 L
.5 .45095 L
.5 .45238 L
.5 .45381 L
.5 .45524 L
.5 .45667 L
.5 .4581 L
.5 .45952 L
.5 .46095 L
.5 .46238 L
.5 .46381 L
.5 .46524 L
.5 .46667 L
.5 .4681 L
.5 .46952 L
.5 .47095 L
.5 .47238 L
.5 .47381 L
s
.54762 .43095 m
.54762 .43238 L
.54762 .43381 L
.54762 .43524 L
.54762 .43667 L
.54762 .4381 L
.54762 .43952 L
.54762 .44095 L
.54762 .44238 L
.54762 .44381 L
.54762 .44524 L
.54762 .44667 L
.54762 .4481 L
.54762 .44952 L
.54762 .45095 L
.54762 .45238 L
.54762 .45381 L
.54762 .45524 L
.54762 .45667 L
.54762 .4581 L
.54762 .45952 L
.54762 .46095 L
.54762 .46238 L
.54762 .46381 L
.54762 .46524 L
.54762 .46667 L
.54762 .4681 L
.54762 .46952 L
.54762 .47095 L
.54762 .47238 L
.54762 .47381 L
s
.59524 .43095 m
.59524 .43238 L
.59524 .43381 L
.59524 .43524 L
.59524 .43667 L
.59524 .4381 L
.59524 .43952 L
.59524 .44095 L
.59524 .44238 L
.59524 .44381 L
.59524 .44524 L
.59524 .44667 L
.59524 .4481 L
.59524 .44952 L
.59524 .45095 L
.59524 .45238 L
.59524 .45381 L
.59524 .45524 L
.59524 .45667 L
.59524 .4581 L
.59524 .45952 L
.59524 .46095 L
.59524 .46238 L
.59524 .46381 L
.59524 .46524 L
.59524 .46667 L
.59524 .4681 L
.59524 .46952 L
.59524 .47095 L
.59524 .47238 L
.59524 .47381 L
s
.64286 .43095 m
.64286 .43238 L
.64286 .43381 L
.64286 .43524 L
.64286 .43667 L
.64286 .4381 L
.64286 .43952 L
.64286 .44095 L
.64286 .44238 L
.64286 .44381 L
.64286 .44524 L
.64286 .44667 L
.64286 .4481 L
.64286 .44952 L
.64286 .45095 L
.64286 .45238 L
.64286 .45381 L
.64286 .45524 L
.64286 .45667 L
.64286 .4581 L
.64286 .45952 L
.64286 .46095 L
.64286 .46238 L
.64286 .46381 L
.64286 .46524 L
.64286 .46667 L
.64286 .4681 L
.64286 .46952 L
.64286 .47095 L
.64286 .47238 L
.64286 .47381 L
s
.69048 .43095 m
.69048 .43238 L
.69048 .43381 L
.69048 .43524 L
.69048 .43667 L
.69048 .4381 L
.69048 .43952 L
.69048 .44095 L
.69048 .44238 L
.69048 .44381 L
.69048 .44524 L
.69048 .44667 L
.69048 .4481 L
.69048 .44952 L
.69048 .45095 L
.69048 .45238 L
.69048 .45381 L
.69048 .45524 L
.69048 .45667 L
.69048 .4581 L
.69048 .45952 L
.69048 .46095 L
.69048 .46238 L
.69048 .46381 L
.69048 .46524 L
.69048 .46667 L
.69048 .4681 L
.69048 .46952 L
.69048 .47095 L
.69048 .47238 L
.69048 .47381 L
s
.7381 .43095 m
.7381 .43238 L
.7381 .43381 L
.7381 .43524 L
.7381 .43667 L
.7381 .4381 L
.7381 .43952 L
.7381 .44095 L
.7381 .44238 L
.7381 .44381 L
.7381 .44524 L
.7381 .44667 L
.7381 .4481 L
.7381 .44952 L
.7381 .45095 L
.7381 .45238 L
.7381 .45381 L
.7381 .45524 L
.7381 .45667 L
.7381 .4581 L
.7381 .45952 L
.7381 .46095 L
.7381 .46238 L
.7381 .46381 L
.7381 .46524 L
.7381 .46667 L
.7381 .4681 L
.7381 .46952 L
.7381 .47095 L
.7381 .47238 L
.7381 .47381 L
s
.78571 .43095 m
.78571 .43238 L
.78571 .43381 L
.78571 .43524 L
.78571 .43667 L
.78571 .4381 L
.78571 .43952 L
.78571 .44095 L
.78571 .44238 L
.78571 .44381 L
.78571 .44524 L
.78571 .44667 L
.78571 .4481 L
.78571 .44952 L
.78571 .45095 L
.78571 .45238 L
.78571 .45381 L
.78571 .45524 L
.78571 .45667 L
.78571 .4581 L
.78571 .45952 L
.78571 .46095 L
.78571 .46238 L
.78571 .46381 L
.78571 .46524 L
.78571 .46667 L
.78571 .4681 L
.78571 .46952 L
.78571 .47095 L
.78571 .47238 L
.78571 .47381 L
s
.83333 .43095 m
.83333 .43238 L
.83333 .43381 L
.83333 .43524 L
.83333 .43667 L
.83333 .4381 L
.83333 .43952 L
.83333 .44095 L
.83333 .44238 L
.83333 .44381 L
.83333 .44524 L
.83333 .44667 L
.83333 .4481 L
.83333 .44952 L
.83333 .45095 L
.83333 .45238 L
.83333 .45381 L
.83333 .45524 L
.83333 .45667 L
.83333 .4581 L
.83333 .45952 L
.83333 .46095 L
.83333 .46238 L
.83333 .46381 L
.83333 .46524 L
.83333 .46667 L
.83333 .4681 L
.83333 .46952 L
.83333 .47095 L
.83333 .47238 L
.83333 .47381 L
s
.88095 .43095 m
.88095 .43238 L
.88095 .43381 L
.88095 .43524 L
.88095 .43667 L
.88095 .4381 L
.88095 .43952 L
.88095 .44095 L
.88095 .44238 L
.88095 .44381 L
.88095 .44524 L
.88095 .44667 L
.88095 .4481 L
.88095 .44952 L
.88095 .45095 L
.88095 .45238 L
.88095 .45381 L
.88095 .45524 L
.88095 .45667 L
.88095 .4581 L
.88095 .45952 L
.88095 .46095 L
.88095 .46238 L
.88095 .46381 L
.88095 .46524 L
.88095 .46667 L
.88095 .4681 L
.88095 .46952 L
.88095 .47095 L
.88095 .47238 L
.88095 .47381 L
s
.92857 .43095 m
.92857 .43238 L
.92857 .43381 L
.92857 .43524 L
.92857 .43667 L
.92857 .43809 L
.92857 .43952 L
.92857 .44095 L
.92857 .44238 L
.92857 .44381 L
.92857 .44524 L
.92857 .44667 L
.92857 .4481 L
.92857 .44952 L
.92857 .45095 L
.92857 .45238 L
.92857 .45381 L
.92857 .45524 L
.92857 .45667 L
.92857 .4581 L
.92857 .45952 L
.92857 .46095 L
.92857 .46238 L
.92857 .46381 L
.92857 .46524 L
.92857 .46667 L
.92857 .4681 L
.92857 .46952 L
.92857 .47095 L
.92857 .47238 L
.92857 .47381 L
s
.02381 .5 m
.05556 .5 L
.0873 .5 L
.11905 .5 L
.15079 .5 L
.18254 .5 L
.21429 .5 L
.24603 .5 L
.27778 .5 L
.30952 .5 L
.34127 .5 L
.37302 .5 L
.40476 .5 L
.43651 .5 L
.46825 .5 L
.5 .5 L
.53175 .5 L
.56349 .5 L
.59524 .5 L
.62698 .5 L
.65873 .5 L
.69048 .5 L
.72222 .5 L
.75397 .5 L
.78571 .5 L
.81746 .5 L
.84921 .5 L
.88095 .5 L
.9127 .5 L
.94444 .5 L
.97619 .5 L
s
.02381 .45238 m
.05556 .45238 L
.0873 .45238 L
.11905 .45238 L
.15079 .45238 L
.18254 .45238 L
.21429 .45238 L
.24603 .45238 L
.27778 .45238 L
.30952 .45238 L
.34127 .45238 L
.37302 .45238 L
.40476 .45238 L
.43651 .45238 L
.46825 .45238 L
.5 .45238 L
.53175 .45238 L
.56349 .45238 L
.59524 .45238 L
.62698 .45238 L
.65873 .45238 L
.69048 .45238 L
.72222 .45238 L
.75397 .45238 L
.78571 .45238 L
.81746 .45238 L
.84921 .45238 L
.88095 .45238 L
.9127 .45238 L
.94444 .45238 L
.97619 .45238 L
s
0 0 0 r
.02381 .47619 m
.97619 .47619 L
s
% Start of user PostScript
0 -1.25 50. -1.25 MAarrowhead1
% End of user PostScript
.97619 .47619 m
.97619 .47619 L
s
% Start of user PostScript
50. -1.25 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .45476 m
.02381 .45619 L
.02381 .45762 L
.02381 .45905 L
.02381 .46048 L
.02381 .4619 L
.02381 .46333 L
.02381 .46476 L
.02381 .46619 L
.02381 .46762 L
.02381 .46905 L
.02381 .47048 L
.02381 .4719 L
.02381 .47333 L
.02381 .47476 L
.02381 .47619 L
.02381 .47762 L
.02381 .47905 L
.02381 .48048 L
.02381 .4819 L
.02381 .48333 L
.02381 .48476 L
.02381 .48619 L
.02381 .48762 L
.02381 .48905 L
.02381 .49048 L
.02381 .4919 L
.02381 .49333 L
.02381 .49476 L
.02381 .49619 L
.02381 .49762 L
s
.07143 .45476 m
.07143 .45619 L
.07143 .45762 L
.07143 .45905 L
.07143 .46048 L
.07143 .4619 L
.07143 .46333 L
.07143 .46476 L
.07143 .46619 L
.07143 .46762 L
.07143 .46905 L
.07143 .47048 L
.07143 .4719 L
.07143 .47333 L
.07143 .47476 L
.07143 .47619 L
.07143 .47762 L
.07143 .47905 L
.07143 .48048 L
.07143 .4819 L
.07143 .48333 L
.07143 .48476 L
.07143 .48619 L
.07143 .48762 L
.07143 .48905 L
.07143 .49048 L
.07143 .4919 L
.07143 .49333 L
.07143 .49476 L
.07143 .49619 L
.07143 .49762 L
s
.11905 .45476 m
.11905 .45619 L
.11905 .45762 L
.11905 .45905 L
.11905 .46048 L
.11905 .4619 L
.11905 .46333 L
.11905 .46476 L
.11905 .46619 L
.11905 .46762 L
.11905 .46905 L
.11905 .47048 L
.11905 .4719 L
.11905 .47333 L
.11905 .47476 L
.11905 .47619 L
.11905 .47762 L
.11905 .47905 L
.11905 .48048 L
.11905 .4819 L
.11905 .48333 L
.11905 .48476 L
.11905 .48619 L
.11905 .48762 L
.11905 .48905 L
.11905 .49048 L
.11905 .4919 L
.11905 .49333 L
.11905 .49476 L
.11905 .49619 L
.11905 .49762 L
s
.16667 .45476 m
.16667 .45619 L
.16667 .45762 L
.16667 .45905 L
.16667 .46048 L
.16667 .4619 L
.16667 .46333 L
.16667 .46476 L
.16667 .46619 L
.16667 .46762 L
.16667 .46905 L
.16667 .47048 L
.16667 .4719 L
.16667 .47333 L
.16667 .47476 L
.16667 .47619 L
.16667 .47762 L
.16667 .47905 L
.16667 .48048 L
.16667 .4819 L
.16667 .48333 L
.16667 .48476 L
.16667 .48619 L
.16667 .48762 L
.16667 .48905 L
.16667 .49048 L
.16667 .4919 L
.16667 .49333 L
.16667 .49476 L
.16667 .49619 L
.16667 .49762 L
s
.21429 .45476 m
.21429 .45619 L
.21429 .45762 L
.21429 .45905 L
.21429 .46048 L
.21429 .4619 L
.21429 .46333 L
.21429 .46476 L
.21429 .46619 L
.21429 .46762 L
.21429 .46905 L
.21429 .47048 L
.21429 .4719 L
.21429 .47333 L
.21429 .47476 L
.21429 .47619 L
.21429 .47762 L
.21429 .47905 L
.21429 .48048 L
.21429 .4819 L
.21429 .48333 L
.21429 .48476 L
.21429 .48619 L
.21429 .48762 L
.21429 .48905 L
.21429 .49048 L
.21429 .4919 L
.21429 .49333 L
.21429 .49476 L
.21429 .49619 L
.21429 .49762 L
s
.2619 .45476 m
.2619 .45619 L
.2619 .45762 L
.2619 .45905 L
.2619 .46048 L
.2619 .4619 L
.2619 .46333 L
.2619 .46476 L
.2619 .46619 L
.2619 .46762 L
.2619 .46905 L
.2619 .47048 L
.2619 .4719 L
.2619 .47333 L
.2619 .47476 L
.2619 .47619 L
.2619 .47762 L
.2619 .47905 L
.2619 .48048 L
.2619 .4819 L
.2619 .48333 L
.2619 .48476 L
.2619 .48619 L
.2619 .48762 L
.2619 .48905 L
.2619 .49048 L
.2619 .4919 L
.2619 .49333 L
.2619 .49476 L
.2619 .49619 L
.2619 .49762 L
s
.30952 .45476 m
.30952 .45619 L
.30952 .45762 L
.30952 .45905 L
.30952 .46048 L
.30952 .4619 L
.30952 .46333 L
.30952 .46476 L
.30952 .46619 L
.30952 .46762 L
.30952 .46905 L
.30952 .47048 L
.30952 .4719 L
.30952 .47333 L
.30952 .47476 L
.30952 .47619 L
.30952 .47762 L
.30952 .47905 L
.30952 .48048 L
.30952 .4819 L
.30952 .48333 L
.30952 .48476 L
.30952 .48619 L
.30952 .48762 L
.30952 .48905 L
.30952 .49048 L
.30952 .4919 L
.30952 .49333 L
.30952 .49476 L
.30952 .49619 L
.30952 .49762 L
s
.35714 .45476 m
.35714 .45619 L
.35714 .45762 L
.35714 .45905 L
.35714 .46048 L
.35714 .4619 L
.35714 .46333 L
.35714 .46476 L
.35714 .46619 L
.35714 .46762 L
.35714 .46905 L
.35714 .47048 L
.35714 .4719 L
.35714 .47333 L
.35714 .47476 L
.35714 .47619 L
.35714 .47762 L
.35714 .47905 L
.35714 .48048 L
.35714 .4819 L
.35714 .48333 L
.35714 .48476 L
.35714 .48619 L
.35714 .48762 L
.35714 .48905 L
.35714 .49048 L
.35714 .4919 L
.35714 .49333 L
.35714 .49476 L
.35714 .49619 L
.35714 .49762 L
s
.40476 .45476 m
.40476 .45619 L
.40476 .45762 L
.40476 .45905 L
.40476 .46048 L
.40476 .4619 L
.40476 .46333 L
.40476 .46476 L
.40476 .46619 L
.40476 .46762 L
.40476 .46905 L
.40476 .47048 L
.40476 .4719 L
.40476 .47333 L
.40476 .47476 L
.40476 .47619 L
.40476 .47762 L
.40476 .47905 L
.40476 .48048 L
.40476 .4819 L
.40476 .48333 L
.40476 .48476 L
.40476 .48619 L
.40476 .48762 L
.40476 .48905 L
.40476 .49048 L
.40476 .4919 L
.40476 .49333 L
.40476 .49476 L
.40476 .49619 L
.40476 .49762 L
s
.45238 .45476 m
.45238 .45619 L
.45238 .45762 L
.45238 .45905 L
.45238 .46048 L
.45238 .4619 L
.45238 .46333 L
.45238 .46476 L
.45238 .46619 L
.45238 .46762 L
.45238 .46905 L
.45238 .47048 L
.45238 .4719 L
.45238 .47333 L
.45238 .47476 L
.45238 .47619 L
.45238 .47762 L
.45238 .47905 L
.45238 .48048 L
.45238 .4819 L
.45238 .48333 L
.45238 .48476 L
.45238 .48619 L
.45238 .48762 L
.45238 .48905 L
.45238 .49048 L
.45238 .4919 L
.45238 .49333 L
.45238 .49476 L
.45238 .49619 L
.45238 .49762 L
s
.5 .45476 m
.5 .45619 L
.5 .45762 L
.5 .45905 L
.5 .46048 L
.5 .4619 L
.5 .46333 L
.5 .46476 L
.5 .46619 L
.5 .46762 L
.5 .46905 L
.5 .47048 L
.5 .4719 L
.5 .47333 L
.5 .47476 L
.5 .47619 L
.5 .47762 L
.5 .47905 L
.5 .48048 L
.5 .4819 L
.5 .48333 L
.5 .48476 L
.5 .48619 L
.5 .48762 L
.5 .48905 L
.5 .49048 L
.5 .4919 L
.5 .49333 L
.5 .49476 L
.5 .49619 L
.5 .49762 L
s
.54762 .45476 m
.54762 .45619 L
.54762 .45762 L
.54762 .45905 L
.54762 .46048 L
.54762 .4619 L
.54762 .46333 L
.54762 .46476 L
.54762 .46619 L
.54762 .46762 L
.54762 .46905 L
.54762 .47048 L
.54762 .4719 L
.54762 .47333 L
.54762 .47476 L
.54762 .47619 L
.54762 .47762 L
.54762 .47905 L
.54762 .48048 L
.54762 .4819 L
.54762 .48333 L
.54762 .48476 L
.54762 .48619 L
.54762 .48762 L
.54762 .48905 L
.54762 .49048 L
.54762 .4919 L
.54762 .49333 L
.54762 .49476 L
.54762 .49619 L
.54762 .49762 L
s
.59524 .45476 m
.59524 .45619 L
.59524 .45762 L
.59524 .45905 L
.59524 .46048 L
.59524 .4619 L
.59524 .46333 L
.59524 .46476 L
.59524 .46619 L
.59524 .46762 L
.59524 .46905 L
.59524 .47048 L
.59524 .4719 L
.59524 .47333 L
.59524 .47476 L
.59524 .47619 L
.59524 .47762 L
.59524 .47905 L
.59524 .48048 L
.59524 .4819 L
.59524 .48333 L
.59524 .48476 L
.59524 .48619 L
.59524 .48762 L
.59524 .48905 L
.59524 .49048 L
.59524 .4919 L
.59524 .49333 L
.59524 .49476 L
.59524 .49619 L
.59524 .49762 L
s
.64286 .45476 m
.64286 .45619 L
.64286 .45762 L
.64286 .45905 L
.64286 .46048 L
.64286 .4619 L
.64286 .46333 L
.64286 .46476 L
.64286 .46619 L
.64286 .46762 L
.64286 .46905 L
.64286 .47048 L
.64286 .4719 L
.64286 .47333 L
.64286 .47476 L
.64286 .47619 L
.64286 .47762 L
.64286 .47905 L
.64286 .48048 L
.64286 .4819 L
.64286 .48333 L
.64286 .48476 L
.64286 .48619 L
.64286 .48762 L
.64286 .48905 L
.64286 .49048 L
.64286 .4919 L
.64286 .49333 L
.64286 .49476 L
.64286 .49619 L
.64286 .49762 L
s
.69048 .45476 m
.69048 .45619 L
.69048 .45762 L
.69048 .45905 L
.69048 .46048 L
.69048 .4619 L
.69048 .46333 L
.69048 .46476 L
.69048 .46619 L
.69048 .46762 L
.69048 .46905 L
.69048 .47048 L
.69048 .4719 L
.69048 .47333 L
.69048 .47476 L
.69048 .47619 L
.69048 .47762 L
.69048 .47905 L
.69048 .48048 L
.69048 .4819 L
.69048 .48333 L
.69048 .48476 L
.69048 .48619 L
.69048 .48762 L
.69048 .48905 L
.69048 .49048 L
.69048 .4919 L
.69048 .49333 L
.69048 .49476 L
.69048 .49619 L
.69048 .49762 L
s
.7381 .45476 m
.7381 .45619 L
.7381 .45762 L
.7381 .45905 L
.7381 .46048 L
.7381 .4619 L
.7381 .46333 L
.7381 .46476 L
.7381 .46619 L
.7381 .46762 L
.7381 .46905 L
.7381 .47048 L
.7381 .4719 L
.7381 .47333 L
.7381 .47476 L
.7381 .47619 L
.7381 .47762 L
.7381 .47905 L
.7381 .48048 L
.7381 .4819 L
.7381 .48333 L
.7381 .48476 L
.7381 .48619 L
.7381 .48762 L
.7381 .48905 L
.7381 .49048 L
.7381 .4919 L
.7381 .49333 L
.7381 .49476 L
.7381 .49619 L
.7381 .49762 L
s
.78571 .45476 m
.78571 .45619 L
.78571 .45762 L
.78571 .45905 L
.78571 .46048 L
.78571 .4619 L
.78571 .46333 L
.78571 .46476 L
.78571 .46619 L
.78571 .46762 L
.78571 .46905 L
.78571 .47048 L
.78571 .4719 L
.78571 .47333 L
.78571 .47476 L
.78571 .47619 L
.78571 .47762 L
.78571 .47905 L
.78571 .48048 L
.78571 .4819 L
.78571 .48333 L
.78571 .48476 L
.78571 .48619 L
.78571 .48762 L
.78571 .48905 L
.78571 .49048 L
.78571 .4919 L
.78571 .49333 L
.78571 .49476 L
.78571 .49619 L
.78571 .49762 L
s
.83333 .45476 m
.83333 .45619 L
.83333 .45762 L
.83333 .45905 L
.83333 .46048 L
.83333 .4619 L
.83333 .46333 L
.83333 .46476 L
.83333 .46619 L
.83333 .46762 L
.83333 .46905 L
.83333 .47048 L
.83333 .4719 L
.83333 .47333 L
.83333 .47476 L
.83333 .47619 L
.83333 .47762 L
.83333 .47905 L
.83333 .48048 L
.83333 .4819 L
.83333 .48333 L
.83333 .48476 L
.83333 .48619 L
.83333 .48762 L
.83333 .48905 L
.83333 .49048 L
.83333 .4919 L
.83333 .49333 L
.83333 .49476 L
.83333 .49619 L
.83333 .49762 L
s
.88095 .45476 m
.88095 .45619 L
.88095 .45762 L
.88095 .45905 L
.88095 .46048 L
.88095 .4619 L
.88095 .46333 L
.88095 .46476 L
.88095 .46619 L
.88095 .46762 L
.88095 .46905 L
.88095 .47048 L
.88095 .4719 L
.88095 .47333 L
.88095 .47476 L
.88095 .47619 L
.88095 .47762 L
.88095 .47905 L
.88095 .48048 L
.88095 .4819 L
.88095 .48333 L
.88095 .48476 L
.88095 .48619 L
.88095 .48762 L
.88095 .48905 L
.88095 .49048 L
.88095 .49191 L
.88095 .49333 L
.88095 .49476 L
.88095 .49619 L
.88095 .49762 L
s
.92857 .45476 m
.92857 .45619 L
.92857 .45762 L
.92857 .45905 L
.92857 .46048 L
.92857 .4619 L
.92857 .46333 L
.92857 .46476 L
.92857 .46619 L
.92857 .46762 L
.92857 .46905 L
.92857 .47048 L
.92857 .4719 L
.92857 .47333 L
.92857 .47476 L
.92857 .47619 L
.92857 .47762 L
.92857 .47905 L
.92857 .48048 L
.92857 .4819 L
.92857 .48333 L
.92857 .48476 L
.92857 .48619 L
.92857 .48762 L
.92857 .48905 L
.92857 .49048 L
.92857 .49191 L
.92857 .49333 L
.92857 .49476 L
.92857 .49619 L
.92857 .49762 L
s
.02381 .52381 m
.05556 .52381 L
.0873 .52381 L
.11905 .52381 L
.15079 .52381 L
.18254 .52381 L
.21429 .52381 L
.24603 .52381 L
.27778 .52381 L
.30952 .52381 L
.34127 .52381 L
.37302 .52381 L
.40476 .52381 L
.43651 .52381 L
.46825 .52381 L
.5 .52381 L
.53175 .52381 L
.56349 .52381 L
.59524 .52381 L
.62698 .52381 L
.65873 .52381 L
.69048 .52381 L
.72222 .52381 L
.75397 .52381 L
.78571 .52381 L
.81746 .52381 L
.84921 .52381 L
.88095 .52381 L
.9127 .52381 L
.94444 .52381 L
.97619 .52381 L
s
.02381 .47619 m
.05556 .47619 L
.0873 .47619 L
.11905 .47619 L
.15079 .47619 L
.18254 .47619 L
.21429 .47619 L
.24603 .47619 L
.27778 .47619 L
.30952 .47619 L
.34127 .47619 L
.37302 .47619 L
.40476 .47619 L
.43651 .47619 L
.46825 .47619 L
.5 .47619 L
.53175 .47619 L
.56349 .47619 L
.59524 .47619 L
.62698 .47619 L
.65873 .47619 L
.69048 .47619 L
.72222 .47619 L
.75397 .47619 L
.78571 .47619 L
.81746 .47619 L
.84921 .47619 L
.88095 .47619 L
.9127 .47619 L
.94444 .47619 L
.97619 .47619 L
s
0 0 0 r
.02381 .5 m
.97619 .5 L
s
% Start of user PostScript
0 0 50. 0 MAarrowhead1
% End of user PostScript
.97619 .5 m
.97619 .5 L
s
% Start of user PostScript
50. 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .47857 m
.02381 .48 L
.02381 .48143 L
.02381 .48286 L
.02381 .48429 L
.02381 .48571 L
.02381 .48714 L
.02381 .48857 L
.02381 .49 L
.02381 .49143 L
.02381 .49286 L
.02381 .49429 L
.02381 .49571 L
.02381 .49714 L
.02381 .49857 L
.02381 .5 L
.02381 .50143 L
.02381 .50286 L
.02381 .50429 L
.02381 .50571 L
.02381 .50714 L
.02381 .50857 L
.02381 .51 L
.02381 .51143 L
.02381 .51286 L
.02381 .51429 L
.02381 .51571 L
.02381 .51714 L
.02381 .51857 L
.02381 .52 L
.02381 .52143 L
s
.07143 .47857 m
.07143 .48 L
.07143 .48143 L
.07143 .48286 L
.07143 .48429 L
.07143 .48571 L
.07143 .48714 L
.07143 .48857 L
.07143 .49 L
.07143 .49143 L
.07143 .49286 L
.07143 .49429 L
.07143 .49571 L
.07143 .49714 L
.07143 .49857 L
.07143 .5 L
.07143 .50143 L
.07143 .50286 L
.07143 .50429 L
.07143 .50571 L
.07143 .50714 L
.07143 .50857 L
.07143 .51 L
.07143 .51143 L
.07143 .51286 L
.07143 .51429 L
.07143 .51571 L
.07143 .51714 L
.07143 .51857 L
.07143 .52 L
.07143 .52143 L
s
.11905 .47857 m
.11905 .48 L
.11905 .48143 L
.11905 .48286 L
.11905 .48429 L
.11905 .48571 L
.11905 .48714 L
.11905 .48857 L
.11905 .49 L
.11905 .49143 L
.11905 .49286 L
.11905 .49429 L
.11905 .49571 L
.11905 .49714 L
.11905 .49857 L
.11905 .5 L
.11905 .50143 L
.11905 .50286 L
.11905 .50429 L
.11905 .50571 L
.11905 .50714 L
.11905 .50857 L
.11905 .51 L
.11905 .51143 L
.11905 .51286 L
.11905 .51429 L
.11905 .51571 L
.11905 .51714 L
.11905 .51857 L
.11905 .52 L
.11905 .52143 L
s
.16667 .47857 m
.16667 .48 L
.16667 .48143 L
.16667 .48286 L
.16667 .48429 L
.16667 .48571 L
.16667 .48714 L
.16667 .48857 L
.16667 .49 L
.16667 .49143 L
.16667 .49286 L
.16667 .49429 L
.16667 .49571 L
.16667 .49714 L
.16667 .49857 L
.16667 .5 L
.16667 .50143 L
.16667 .50286 L
.16667 .50429 L
.16667 .50571 L
.16667 .50714 L
.16667 .50857 L
.16667 .51 L
.16667 .51143 L
.16667 .51286 L
.16667 .51429 L
.16667 .51571 L
.16667 .51714 L
.16667 .51857 L
.16667 .52 L
.16667 .52143 L
s
.21429 .47857 m
.21429 .48 L
.21429 .48143 L
.21429 .48286 L
.21429 .48429 L
.21429 .48571 L
.21429 .48714 L
.21429 .48857 L
.21429 .49 L
.21429 .49143 L
.21429 .49286 L
.21429 .49429 L
.21429 .49571 L
.21429 .49714 L
.21429 .49857 L
.21429 .5 L
.21429 .50143 L
.21429 .50286 L
.21429 .50429 L
.21429 .50571 L
.21429 .50714 L
.21429 .50857 L
.21429 .51 L
.21429 .51143 L
.21429 .51286 L
.21429 .51429 L
.21429 .51571 L
.21429 .51714 L
.21429 .51857 L
.21429 .52 L
.21429 .52143 L
s
.2619 .47857 m
.2619 .48 L
.2619 .48143 L
.2619 .48286 L
.2619 .48429 L
.2619 .48571 L
.2619 .48714 L
.2619 .48857 L
.2619 .49 L
.2619 .49143 L
.2619 .49286 L
.2619 .49429 L
.2619 .49571 L
.2619 .49714 L
.2619 .49857 L
.2619 .5 L
.2619 .50143 L
.2619 .50286 L
.2619 .50429 L
.2619 .50571 L
.2619 .50714 L
.2619 .50857 L
.2619 .51 L
.2619 .51143 L
.2619 .51286 L
.2619 .51429 L
.2619 .51571 L
.2619 .51714 L
.2619 .51857 L
.2619 .52 L
.2619 .52143 L
s
.30952 .47857 m
.30952 .48 L
.30952 .48143 L
.30952 .48286 L
.30952 .48429 L
.30952 .48571 L
.30952 .48714 L
.30952 .48857 L
.30952 .49 L
.30952 .49143 L
.30952 .49286 L
.30952 .49429 L
.30952 .49571 L
.30952 .49714 L
.30952 .49857 L
.30952 .5 L
.30952 .50143 L
.30952 .50286 L
.30952 .50429 L
.30952 .50571 L
.30952 .50714 L
.30952 .50857 L
.30952 .51 L
.30952 .51143 L
.30952 .51286 L
.30952 .51429 L
.30952 .51571 L
.30952 .51714 L
.30952 .51857 L
.30952 .52 L
.30952 .52143 L
s
.35714 .47857 m
.35714 .48 L
.35714 .48143 L
.35714 .48286 L
.35714 .48429 L
.35714 .48571 L
.35714 .48714 L
.35714 .48857 L
.35714 .49 L
.35714 .49143 L
.35714 .49286 L
.35714 .49429 L
.35714 .49571 L
.35714 .49714 L
.35714 .49857 L
.35714 .5 L
.35714 .50143 L
.35714 .50286 L
.35714 .50429 L
.35714 .50571 L
.35714 .50714 L
.35714 .50857 L
.35714 .51 L
.35714 .51143 L
.35714 .51286 L
.35714 .51429 L
.35714 .51571 L
.35714 .51714 L
.35714 .51857 L
.35714 .52 L
.35714 .52143 L
s
.40476 .47857 m
.40476 .48 L
.40476 .48143 L
.40476 .48286 L
.40476 .48429 L
.40476 .48571 L
.40476 .48714 L
.40476 .48857 L
.40476 .49 L
.40476 .49143 L
.40476 .49286 L
.40476 .49429 L
.40476 .49571 L
.40476 .49714 L
.40476 .49857 L
.40476 .5 L
.40476 .50143 L
.40476 .50286 L
.40476 .50429 L
.40476 .50571 L
.40476 .50714 L
.40476 .50857 L
.40476 .51 L
.40476 .51143 L
.40476 .51286 L
.40476 .51429 L
.40476 .51571 L
.40476 .51714 L
.40476 .51857 L
.40476 .52 L
.40476 .52143 L
s
.45238 .47857 m
.45238 .48 L
.45238 .48143 L
.45238 .48286 L
.45238 .48429 L
.45238 .48571 L
.45238 .48714 L
.45238 .48857 L
.45238 .49 L
.45238 .49143 L
.45238 .49286 L
.45238 .49429 L
.45238 .49571 L
.45238 .49714 L
.45238 .49857 L
.45238 .5 L
.45238 .50143 L
.45238 .50286 L
.45238 .50429 L
.45238 .50571 L
.45238 .50714 L
.45238 .50857 L
.45238 .51 L
.45238 .51143 L
.45238 .51286 L
.45238 .51429 L
.45238 .51571 L
.45238 .51714 L
.45238 .51857 L
.45238 .52 L
.45238 .52143 L
s
.5 .47857 m
.5 .48 L
.5 .48143 L
.5 .48286 L
.5 .48429 L
.5 .48571 L
.5 .48714 L
.5 .48857 L
.5 .49 L
.5 .49143 L
.5 .49286 L
.5 .49429 L
.5 .49571 L
.5 .49714 L
.5 .49857 L
.5 .5 L
.5 .50143 L
.5 .50286 L
.5 .50429 L
.5 .50571 L
.5 .50714 L
.5 .50857 L
.5 .51 L
.5 .51143 L
.5 .51286 L
.5 .51429 L
.5 .51571 L
.5 .51714 L
.5 .51857 L
.5 .52 L
.5 .52143 L
s
.54762 .47857 m
.54762 .48 L
.54762 .48143 L
.54762 .48286 L
.54762 .48429 L
.54762 .48571 L
.54762 .48714 L
.54762 .48857 L
.54762 .49 L
.54762 .49143 L
.54762 .49286 L
.54762 .49429 L
.54762 .49571 L
.54762 .49714 L
.54762 .49857 L
.54762 .5 L
.54762 .50143 L
.54762 .50286 L
.54762 .50429 L
.54762 .50571 L
.54762 .50714 L
.54762 .50857 L
.54762 .51 L
.54762 .51143 L
.54762 .51286 L
.54762 .51429 L
.54762 .51571 L
.54762 .51714 L
.54762 .51857 L
.54762 .52 L
.54762 .52143 L
s
.59524 .47857 m
.59524 .48 L
.59524 .48143 L
.59524 .48286 L
.59524 .48429 L
.59524 .48571 L
.59524 .48714 L
.59524 .48857 L
.59524 .49 L
.59524 .49143 L
.59524 .49286 L
.59524 .49429 L
.59524 .49571 L
.59524 .49714 L
.59524 .49857 L
.59524 .5 L
.59524 .50143 L
.59524 .50286 L
.59524 .50429 L
.59524 .50571 L
.59524 .50714 L
.59524 .50857 L
.59524 .51 L
.59524 .51143 L
.59524 .51286 L
.59524 .51429 L
.59524 .51571 L
.59524 .51714 L
.59524 .51857 L
.59524 .52 L
.59524 .52143 L
s
.64286 .47857 m
.64286 .48 L
.64286 .48143 L
.64286 .48286 L
.64286 .48429 L
.64286 .48571 L
.64286 .48714 L
.64286 .48857 L
.64286 .49 L
.64286 .49143 L
.64286 .49286 L
.64286 .49429 L
.64286 .49571 L
.64286 .49714 L
.64286 .49857 L
.64286 .5 L
.64286 .50143 L
.64286 .50286 L
.64286 .50429 L
.64286 .50571 L
.64286 .50714 L
.64286 .50857 L
.64286 .51 L
.64286 .51143 L
.64286 .51286 L
.64286 .51429 L
.64286 .51571 L
.64286 .51714 L
.64286 .51857 L
.64286 .52 L
.64286 .52143 L
s
.69048 .47857 m
.69048 .48 L
.69048 .48143 L
.69048 .48286 L
.69048 .48429 L
.69048 .48571 L
.69048 .48714 L
.69048 .48857 L
.69048 .49 L
.69048 .49143 L
.69048 .49286 L
.69048 .49429 L
.69048 .49571 L
.69048 .49714 L
.69048 .49857 L
.69048 .5 L
.69048 .50143 L
.69048 .50286 L
.69048 .50429 L
.69048 .50571 L
.69048 .50714 L
.69048 .50857 L
.69048 .51 L
.69048 .51143 L
.69048 .51286 L
.69048 .51429 L
.69048 .51571 L
.69048 .51714 L
.69048 .51857 L
.69048 .52 L
.69048 .52143 L
s
.7381 .47857 m
.7381 .48 L
.7381 .48143 L
.7381 .48286 L
.7381 .48429 L
.7381 .48571 L
.7381 .48714 L
.7381 .48857 L
.7381 .49 L
.7381 .49143 L
.7381 .49286 L
.7381 .49429 L
.7381 .49571 L
.7381 .49714 L
.7381 .49857 L
.7381 .5 L
.7381 .50143 L
.7381 .50286 L
.7381 .50429 L
.7381 .50571 L
.7381 .50714 L
.7381 .50857 L
.7381 .51 L
.7381 .51143 L
.7381 .51286 L
.7381 .51429 L
.7381 .51571 L
.7381 .51714 L
.7381 .51857 L
.7381 .52 L
.7381 .52143 L
s
.78571 .47857 m
.78571 .48 L
.78571 .48143 L
.78571 .48286 L
.78571 .48429 L
.78571 .48571 L
.78571 .48714 L
.78571 .48857 L
.78571 .49 L
.78571 .49143 L
.78571 .49286 L
.78571 .49429 L
.78571 .49571 L
.78571 .49714 L
.78571 .49857 L
.78571 .5 L
.78571 .50143 L
.78571 .50286 L
.78571 .50429 L
.78571 .50571 L
.78571 .50714 L
.78571 .50857 L
.78571 .51 L
.78571 .51143 L
.78571 .51286 L
.78571 .51429 L
.78571 .51571 L
.78571 .51714 L
.78571 .51857 L
.78571 .52 L
.78571 .52143 L
s
.83333 .47857 m
.83333 .48 L
.83333 .48143 L
.83333 .48286 L
.83333 .48429 L
.83333 .48571 L
.83333 .48714 L
.83333 .48857 L
.83333 .49 L
.83333 .49143 L
.83333 .49286 L
.83333 .49429 L
.83333 .49571 L
.83333 .49714 L
.83333 .49857 L
.83333 .5 L
.83333 .50143 L
.83333 .50286 L
.83333 .50429 L
.83333 .50571 L
.83333 .50714 L
.83333 .50857 L
.83333 .51 L
.83333 .51143 L
.83333 .51286 L
.83333 .51429 L
.83333 .51571 L
.83333 .51714 L
.83333 .51857 L
.83333 .52 L
.83333 .52143 L
s
.88095 .47857 m
.88095 .48 L
.88095 .48143 L
.88095 .48286 L
.88095 .48429 L
.88095 .48571 L
.88095 .48714 L
.88095 .48857 L
.88095 .49 L
.88095 .49143 L
.88095 .49286 L
.88095 .49429 L
.88095 .49571 L
.88095 .49714 L
.88095 .49857 L
.88095 .5 L
.88095 .50143 L
.88095 .50286 L
.88095 .50429 L
.88095 .50571 L
.88095 .50714 L
.88095 .50857 L
.88095 .51 L
.88095 .51143 L
.88095 .51286 L
.88095 .51429 L
.88095 .51571 L
.88095 .51714 L
.88095 .51857 L
.88095 .52 L
.88095 .52143 L
s
.92857 .47857 m
.92857 .48 L
.92857 .48143 L
.92857 .48286 L
.92857 .48429 L
.92857 .48571 L
.92857 .48714 L
.92857 .48857 L
.92857 .49 L
.92857 .49143 L
.92857 .49286 L
.92857 .49429 L
.92857 .49571 L
.92857 .49714 L
.92857 .49857 L
.92857 .5 L
.92857 .50143 L
.92857 .50286 L
.92857 .50429 L
.92857 .50571 L
.92857 .50714 L
.92857 .50857 L
.92857 .51 L
.92857 .51143 L
.92857 .51286 L
.92857 .51429 L
.92857 .51571 L
.92857 .51714 L
.92857 .51857 L
.92857 .52 L
.92857 .52143 L
s
.02381 .54762 m
.05556 .54762 L
.0873 .54762 L
.11905 .54762 L
.15079 .54762 L
.18254 .54762 L
.21429 .54762 L
.24603 .54762 L
.27778 .54762 L
.30952 .54762 L
.34127 .54762 L
.37302 .54762 L
.40476 .54762 L
.43651 .54762 L
.46825 .54762 L
.5 .54762 L
.53175 .54762 L
.56349 .54762 L
.59524 .54762 L
.62698 .54762 L
.65873 .54762 L
.69048 .54762 L
.72222 .54762 L
.75397 .54762 L
.78571 .54762 L
.81746 .54762 L
.84921 .54762 L
.88095 .54762 L
.9127 .54762 L
.94444 .54762 L
.97619 .54762 L
s
.02381 .5 m
.05556 .5 L
.0873 .5 L
.11905 .5 L
.15079 .5 L
.18254 .5 L
.21429 .5 L
.24603 .5 L
.27778 .5 L
.30952 .5 L
.34127 .5 L
.37302 .5 L
.40476 .5 L
.43651 .5 L
.46825 .5 L
.5 .5 L
.53175 .5 L
.56349 .5 L
.59524 .5 L
.62698 .5 L
.65873 .5 L
.69048 .5 L
.72222 .5 L
.75397 .5 L
.78571 .5 L
.81746 .5 L
.84921 .5 L
.88095 .5 L
.9127 .5 L
.94444 .5 L
.97619 .5 L
s
0 0 0 r
.02381 .52381 m
.97619 .52381 L
s
% Start of user PostScript
0 1.25 50. 1.25 MAarrowhead1
% End of user PostScript
.97619 .52381 m
.97619 .52381 L
s
% Start of user PostScript
50. 1.25 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .50238 m
.02381 .50381 L
.02381 .50524 L
.02381 .50667 L
.02381 .5081 L
.02381 .50952 L
.02381 .51095 L
.02381 .51238 L
.02381 .51381 L
.02381 .51524 L
.02381 .51667 L
.02381 .5181 L
.02381 .51952 L
.02381 .52095 L
.02381 .52238 L
.02381 .52381 L
.02381 .52524 L
.02381 .52667 L
.02381 .5281 L
.02381 .52952 L
.02381 .53095 L
.02381 .53238 L
.02381 .53381 L
.02381 .53524 L
.02381 .53667 L
.02381 .5381 L
.02381 .53952 L
.02381 .54095 L
.02381 .54238 L
.02381 .54381 L
.02381 .54524 L
s
.07143 .50238 m
.07143 .50381 L
.07143 .50524 L
.07143 .50667 L
.07143 .5081 L
.07143 .50952 L
.07143 .51095 L
.07143 .51238 L
.07143 .51381 L
.07143 .51524 L
.07143 .51667 L
.07143 .5181 L
.07143 .51952 L
.07143 .52095 L
.07143 .52238 L
.07143 .52381 L
.07143 .52524 L
.07143 .52667 L
.07143 .5281 L
.07143 .52952 L
.07143 .53095 L
.07143 .53238 L
.07143 .53381 L
.07143 .53524 L
.07143 .53667 L
.07143 .5381 L
.07143 .53952 L
.07143 .54095 L
.07143 .54238 L
.07143 .54381 L
.07143 .54524 L
s
.11905 .50238 m
.11905 .50381 L
.11905 .50524 L
.11905 .50667 L
.11905 .5081 L
.11905 .50952 L
.11905 .51095 L
.11905 .51238 L
.11905 .51381 L
.11905 .51524 L
.11905 .51667 L
.11905 .5181 L
.11905 .51952 L
.11905 .52095 L
.11905 .52238 L
.11905 .52381 L
.11905 .52524 L
.11905 .52667 L
.11905 .5281 L
.11905 .52952 L
.11905 .53095 L
.11905 .53238 L
.11905 .53381 L
.11905 .53524 L
.11905 .53667 L
.11905 .5381 L
.11905 .53952 L
.11905 .54095 L
.11905 .54238 L
.11905 .54381 L
.11905 .54524 L
s
.16667 .50238 m
.16667 .50381 L
.16667 .50524 L
.16667 .50667 L
.16667 .5081 L
.16667 .50952 L
.16667 .51095 L
.16667 .51238 L
.16667 .51381 L
.16667 .51524 L
.16667 .51667 L
.16667 .5181 L
.16667 .51952 L
.16667 .52095 L
.16667 .52238 L
.16667 .52381 L
.16667 .52524 L
.16667 .52667 L
.16667 .5281 L
.16667 .52952 L
.16667 .53095 L
.16667 .53238 L
.16667 .53381 L
.16667 .53524 L
.16667 .53667 L
.16667 .5381 L
.16667 .53952 L
.16667 .54095 L
.16667 .54238 L
.16667 .54381 L
.16667 .54524 L
s
.21429 .50238 m
.21429 .50381 L
.21429 .50524 L
.21429 .50667 L
.21429 .5081 L
.21429 .50952 L
.21429 .51095 L
.21429 .51238 L
.21429 .51381 L
.21429 .51524 L
.21429 .51667 L
.21429 .5181 L
.21429 .51952 L
.21429 .52095 L
.21429 .52238 L
.21429 .52381 L
.21429 .52524 L
.21429 .52667 L
.21429 .5281 L
.21429 .52952 L
.21429 .53095 L
.21429 .53238 L
.21429 .53381 L
.21429 .53524 L
.21429 .53667 L
.21429 .5381 L
.21429 .53952 L
.21429 .54095 L
.21429 .54238 L
.21429 .54381 L
.21429 .54524 L
s
.2619 .50238 m
.2619 .50381 L
.2619 .50524 L
.2619 .50667 L
.2619 .5081 L
.2619 .50952 L
.2619 .51095 L
.2619 .51238 L
.2619 .51381 L
.2619 .51524 L
.2619 .51667 L
.2619 .5181 L
.2619 .51952 L
.2619 .52095 L
.2619 .52238 L
.2619 .52381 L
.2619 .52524 L
.2619 .52667 L
.2619 .5281 L
.2619 .52952 L
.2619 .53095 L
.2619 .53238 L
.2619 .53381 L
.2619 .53524 L
.2619 .53667 L
.2619 .5381 L
.2619 .53952 L
.2619 .54095 L
.2619 .54238 L
.2619 .54381 L
.2619 .54524 L
s
.30952 .50238 m
.30952 .50381 L
.30952 .50524 L
.30952 .50667 L
.30952 .5081 L
.30952 .50952 L
.30952 .51095 L
.30952 .51238 L
.30952 .51381 L
.30952 .51524 L
.30952 .51667 L
.30952 .5181 L
.30952 .51952 L
.30952 .52095 L
.30952 .52238 L
.30952 .52381 L
.30952 .52524 L
.30952 .52667 L
.30952 .5281 L
.30952 .52952 L
.30952 .53095 L
.30952 .53238 L
.30952 .53381 L
.30952 .53524 L
.30952 .53667 L
.30952 .5381 L
.30952 .53952 L
.30952 .54095 L
.30952 .54238 L
.30952 .54381 L
.30952 .54524 L
s
.35714 .50238 m
.35714 .50381 L
.35714 .50524 L
.35714 .50667 L
.35714 .5081 L
.35714 .50952 L
.35714 .51095 L
.35714 .51238 L
.35714 .51381 L
.35714 .51524 L
.35714 .51667 L
.35714 .5181 L
.35714 .51952 L
.35714 .52095 L
.35714 .52238 L
.35714 .52381 L
.35714 .52524 L
.35714 .52667 L
.35714 .5281 L
.35714 .52952 L
.35714 .53095 L
.35714 .53238 L
.35714 .53381 L
.35714 .53524 L
.35714 .53667 L
.35714 .5381 L
.35714 .53952 L
.35714 .54095 L
.35714 .54238 L
.35714 .54381 L
.35714 .54524 L
s
.40476 .50238 m
.40476 .50381 L
.40476 .50524 L
.40476 .50667 L
.40476 .5081 L
.40476 .50952 L
.40476 .51095 L
.40476 .51238 L
.40476 .51381 L
.40476 .51524 L
.40476 .51667 L
.40476 .5181 L
.40476 .51952 L
.40476 .52095 L
.40476 .52238 L
.40476 .52381 L
.40476 .52524 L
.40476 .52667 L
.40476 .5281 L
.40476 .52952 L
.40476 .53095 L
.40476 .53238 L
.40476 .53381 L
.40476 .53524 L
.40476 .53667 L
.40476 .5381 L
.40476 .53952 L
.40476 .54095 L
.40476 .54238 L
.40476 .54381 L
.40476 .54524 L
s
.45238 .50238 m
.45238 .50381 L
.45238 .50524 L
.45238 .50667 L
.45238 .5081 L
.45238 .50952 L
.45238 .51095 L
.45238 .51238 L
.45238 .51381 L
.45238 .51524 L
.45238 .51667 L
.45238 .5181 L
.45238 .51952 L
.45238 .52095 L
.45238 .52238 L
.45238 .52381 L
.45238 .52524 L
.45238 .52667 L
.45238 .5281 L
.45238 .52952 L
.45238 .53095 L
.45238 .53238 L
.45238 .53381 L
.45238 .53524 L
.45238 .53667 L
.45238 .5381 L
.45238 .53952 L
.45238 .54095 L
.45238 .54238 L
.45238 .54381 L
.45238 .54524 L
s
.5 .50238 m
.5 .50381 L
.5 .50524 L
.5 .50667 L
.5 .5081 L
.5 .50952 L
.5 .51095 L
.5 .51238 L
.5 .51381 L
.5 .51524 L
.5 .51667 L
.5 .5181 L
.5 .51952 L
.5 .52095 L
.5 .52238 L
.5 .52381 L
.5 .52524 L
.5 .52667 L
.5 .5281 L
.5 .52952 L
.5 .53095 L
.5 .53238 L
.5 .53381 L
.5 .53524 L
.5 .53667 L
.5 .5381 L
.5 .53952 L
.5 .54095 L
.5 .54238 L
.5 .54381 L
.5 .54524 L
s
.54762 .50238 m
.54762 .50381 L
.54762 .50524 L
.54762 .50667 L
.54762 .5081 L
.54762 .50952 L
.54762 .51095 L
.54762 .51238 L
.54762 .51381 L
.54762 .51524 L
.54762 .51667 L
.54762 .5181 L
.54762 .51952 L
.54762 .52095 L
.54762 .52238 L
.54762 .52381 L
.54762 .52524 L
.54762 .52667 L
.54762 .5281 L
.54762 .52952 L
.54762 .53095 L
.54762 .53238 L
.54762 .53381 L
.54762 .53524 L
.54762 .53667 L
.54762 .5381 L
.54762 .53952 L
.54762 .54095 L
.54762 .54238 L
.54762 .54381 L
.54762 .54524 L
s
.59524 .50238 m
.59524 .50381 L
.59524 .50524 L
.59524 .50667 L
.59524 .5081 L
.59524 .50952 L
.59524 .51095 L
.59524 .51238 L
.59524 .51381 L
.59524 .51524 L
.59524 .51667 L
.59524 .5181 L
.59524 .51952 L
.59524 .52095 L
.59524 .52238 L
.59524 .52381 L
.59524 .52524 L
.59524 .52667 L
.59524 .5281 L
.59524 .52952 L
.59524 .53095 L
.59524 .53238 L
.59524 .53381 L
.59524 .53524 L
.59524 .53667 L
.59524 .5381 L
.59524 .53952 L
.59524 .54095 L
.59524 .54238 L
.59524 .54381 L
.59524 .54524 L
s
.64286 .50238 m
.64286 .50381 L
.64286 .50524 L
.64286 .50667 L
.64286 .5081 L
.64286 .50952 L
.64286 .51095 L
.64286 .51238 L
.64286 .51381 L
.64286 .51524 L
.64286 .51667 L
.64286 .5181 L
.64286 .51952 L
.64286 .52095 L
.64286 .52238 L
.64286 .52381 L
.64286 .52524 L
.64286 .52667 L
.64286 .5281 L
.64286 .52952 L
.64286 .53095 L
.64286 .53238 L
.64286 .53381 L
.64286 .53524 L
.64286 .53667 L
.64286 .5381 L
.64286 .53952 L
.64286 .54095 L
.64286 .54238 L
.64286 .54381 L
.64286 .54524 L
s
.69048 .50238 m
.69048 .50381 L
.69048 .50524 L
.69048 .50667 L
.69048 .5081 L
.69048 .50952 L
.69048 .51095 L
.69048 .51238 L
.69048 .51381 L
.69048 .51524 L
.69048 .51667 L
.69048 .5181 L
.69048 .51952 L
.69048 .52095 L
.69048 .52238 L
.69048 .52381 L
.69048 .52524 L
.69048 .52667 L
.69048 .5281 L
.69048 .52952 L
.69048 .53095 L
.69048 .53238 L
.69048 .53381 L
.69048 .53524 L
.69048 .53667 L
.69048 .5381 L
.69048 .53952 L
.69048 .54095 L
.69048 .54238 L
.69048 .54381 L
.69048 .54524 L
s
.7381 .50238 m
.7381 .50381 L
.7381 .50524 L
.7381 .50667 L
.7381 .5081 L
.7381 .50952 L
.7381 .51095 L
.7381 .51238 L
.7381 .51381 L
.7381 .51524 L
.7381 .51667 L
.7381 .5181 L
.7381 .51952 L
.7381 .52095 L
.7381 .52238 L
.7381 .52381 L
.7381 .52524 L
.7381 .52667 L
.7381 .5281 L
.7381 .52952 L
.7381 .53095 L
.7381 .53238 L
.7381 .53381 L
.7381 .53524 L
.7381 .53667 L
.7381 .5381 L
.7381 .53952 L
.7381 .54095 L
.7381 .54238 L
.7381 .54381 L
.7381 .54524 L
s
.78571 .50238 m
.78571 .50381 L
.78571 .50524 L
.78571 .50667 L
.78571 .5081 L
.78571 .50952 L
.78571 .51095 L
.78571 .51238 L
.78571 .51381 L
.78571 .51524 L
.78571 .51667 L
.78571 .5181 L
.78571 .51952 L
.78571 .52095 L
.78571 .52238 L
.78571 .52381 L
.78571 .52524 L
.78571 .52667 L
.78571 .5281 L
.78571 .52952 L
.78571 .53095 L
.78571 .53238 L
.78571 .53381 L
.78571 .53524 L
.78571 .53667 L
.78571 .5381 L
.78571 .53952 L
.78571 .54095 L
.78571 .54238 L
.78571 .54381 L
.78571 .54524 L
s
.83333 .50238 m
.83333 .50381 L
.83333 .50524 L
.83333 .50667 L
.83333 .5081 L
.83333 .50952 L
.83333 .51095 L
.83333 .51238 L
.83333 .51381 L
.83333 .51524 L
.83333 .51667 L
.83333 .5181 L
.83333 .51952 L
.83333 .52095 L
.83333 .52238 L
.83333 .52381 L
.83333 .52524 L
.83333 .52667 L
.83333 .5281 L
.83333 .52952 L
.83333 .53095 L
.83333 .53238 L
.83333 .53381 L
.83333 .53524 L
.83333 .53667 L
.83333 .5381 L
.83333 .53952 L
.83333 .54095 L
.83333 .54238 L
.83333 .54381 L
.83333 .54524 L
s
.88095 .50238 m
.88095 .50381 L
.88095 .50524 L
.88095 .50667 L
.88095 .50809 L
.88095 .50952 L
.88095 .51095 L
.88095 .51238 L
.88095 .51381 L
.88095 .51524 L
.88095 .51667 L
.88095 .5181 L
.88095 .51952 L
.88095 .52095 L
.88095 .52238 L
.88095 .52381 L
.88095 .52524 L
.88095 .52667 L
.88095 .5281 L
.88095 .52952 L
.88095 .53095 L
.88095 .53238 L
.88095 .53381 L
.88095 .53524 L
.88095 .53667 L
.88095 .5381 L
.88095 .53952 L
.88095 .54095 L
.88095 .54238 L
.88095 .54381 L
.88095 .54524 L
s
.92857 .50238 m
.92857 .50381 L
.92857 .50524 L
.92857 .50667 L
.92857 .50809 L
.92857 .50952 L
.92857 .51095 L
.92857 .51238 L
.92857 .51381 L
.92857 .51524 L
.92857 .51667 L
.92857 .5181 L
.92857 .51952 L
.92857 .52095 L
.92857 .52238 L
.92857 .52381 L
.92857 .52524 L
.92857 .52667 L
.92857 .5281 L
.92857 .52952 L
.92857 .53095 L
.92857 .53238 L
.92857 .53381 L
.92857 .53524 L
.92857 .53667 L
.92857 .5381 L
.92857 .53952 L
.92857 .54095 L
.92857 .54238 L
.92857 .54381 L
.92857 .54524 L
s
.02381 .57143 m
.05556 .57143 L
.0873 .57143 L
.11905 .57143 L
.15079 .57143 L
.18254 .57143 L
.21429 .57143 L
.24603 .57143 L
.27778 .57143 L
.30952 .57143 L
.34127 .57143 L
.37302 .57143 L
.40476 .57143 L
.43651 .57143 L
.46825 .57143 L
.5 .57143 L
.53175 .57143 L
.56349 .57143 L
.59524 .57143 L
.62698 .57143 L
.65873 .57143 L
.69048 .57143 L
.72222 .57143 L
.75397 .57143 L
.78571 .57143 L
.81746 .57143 L
.84921 .57143 L
.88095 .57143 L
.9127 .57143 L
.94444 .57143 L
.97619 .57143 L
s
.02381 .52381 m
.05556 .52381 L
.0873 .52381 L
.11905 .52381 L
.15079 .52381 L
.18254 .52381 L
.21429 .52381 L
.24603 .52381 L
.27778 .52381 L
.30952 .52381 L
.34127 .52381 L
.37302 .52381 L
.40476 .52381 L
.43651 .52381 L
.46825 .52381 L
.5 .52381 L
.53175 .52381 L
.56349 .52381 L
.59524 .52381 L
.62698 .52381 L
.65873 .52381 L
.69048 .52381 L
.72222 .52381 L
.75397 .52381 L
.78571 .52381 L
.81746 .52381 L
.84921 .52381 L
.88095 .52381 L
.9127 .52381 L
.94444 .52381 L
.97619 .52381 L
s
0 0 0 r
.02381 .54762 m
.97619 .54762 L
s
% Start of user PostScript
0 2.5 50. 2.5 MAarrowhead1
% End of user PostScript
.97619 .54762 m
.97619 .54762 L
s
% Start of user PostScript
50. 2.5 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .52619 m
.02381 .52762 L
.02381 .52905 L
.02381 .53048 L
.02381 .5319 L
.02381 .53333 L
.02381 .53476 L
.02381 .53619 L
.02381 .53762 L
.02381 .53905 L
.02381 .54048 L
.02381 .5419 L
.02381 .54333 L
.02381 .54476 L
.02381 .54619 L
.02381 .54762 L
.02381 .54905 L
.02381 .55048 L
.02381 .5519 L
.02381 .55333 L
.02381 .55476 L
.02381 .55619 L
.02381 .55762 L
.02381 .55905 L
.02381 .56048 L
.02381 .5619 L
.02381 .56333 L
.02381 .56476 L
.02381 .56619 L
.02381 .56762 L
.02381 .56905 L
s
.07143 .52619 m
.07143 .52762 L
.07143 .52905 L
.07143 .53048 L
.07143 .5319 L
.07143 .53333 L
.07143 .53476 L
.07143 .53619 L
.07143 .53762 L
.07143 .53905 L
.07143 .54048 L
.07143 .5419 L
.07143 .54333 L
.07143 .54476 L
.07143 .54619 L
.07143 .54762 L
.07143 .54905 L
.07143 .55048 L
.07143 .5519 L
.07143 .55333 L
.07143 .55476 L
.07143 .55619 L
.07143 .55762 L
.07143 .55905 L
.07143 .56048 L
.07143 .5619 L
.07143 .56333 L
.07143 .56476 L
.07143 .56619 L
.07143 .56762 L
.07143 .56905 L
s
.11905 .52619 m
.11905 .52762 L
.11905 .52905 L
.11905 .53048 L
.11905 .5319 L
.11905 .53333 L
.11905 .53476 L
.11905 .53619 L
.11905 .53762 L
.11905 .53905 L
.11905 .54048 L
.11905 .5419 L
.11905 .54333 L
.11905 .54476 L
.11905 .54619 L
.11905 .54762 L
.11905 .54905 L
.11905 .55048 L
.11905 .5519 L
.11905 .55333 L
.11905 .55476 L
.11905 .55619 L
.11905 .55762 L
.11905 .55905 L
.11905 .56048 L
.11905 .5619 L
.11905 .56333 L
.11905 .56476 L
.11905 .56619 L
.11905 .56762 L
.11905 .56905 L
s
.16667 .52619 m
.16667 .52762 L
.16667 .52905 L
.16667 .53048 L
.16667 .5319 L
.16667 .53333 L
.16667 .53476 L
.16667 .53619 L
.16667 .53762 L
.16667 .53905 L
.16667 .54048 L
.16667 .5419 L
.16667 .54333 L
.16667 .54476 L
.16667 .54619 L
.16667 .54762 L
.16667 .54905 L
.16667 .55048 L
.16667 .5519 L
.16667 .55333 L
.16667 .55476 L
.16667 .55619 L
.16667 .55762 L
.16667 .55905 L
.16667 .56048 L
.16667 .5619 L
.16667 .56333 L
.16667 .56476 L
.16667 .56619 L
.16667 .56762 L
.16667 .56905 L
s
.21429 .52619 m
.21429 .52762 L
.21429 .52905 L
.21429 .53048 L
.21429 .5319 L
.21429 .53333 L
.21429 .53476 L
.21429 .53619 L
.21429 .53762 L
.21429 .53905 L
.21429 .54048 L
.21429 .5419 L
.21429 .54333 L
.21429 .54476 L
.21429 .54619 L
.21429 .54762 L
.21429 .54905 L
.21429 .55048 L
.21429 .5519 L
.21429 .55333 L
.21429 .55476 L
.21429 .55619 L
.21429 .55762 L
.21429 .55905 L
.21429 .56048 L
.21429 .5619 L
.21429 .56333 L
.21429 .56476 L
.21429 .56619 L
.21429 .56762 L
.21429 .56905 L
s
.2619 .52619 m
.2619 .52762 L
.2619 .52905 L
.2619 .53048 L
.2619 .5319 L
.2619 .53333 L
.2619 .53476 L
.2619 .53619 L
.2619 .53762 L
.2619 .53905 L
.2619 .54048 L
.2619 .5419 L
.2619 .54333 L
.2619 .54476 L
.2619 .54619 L
.2619 .54762 L
.2619 .54905 L
.2619 .55048 L
.2619 .5519 L
.2619 .55333 L
.2619 .55476 L
.2619 .55619 L
.2619 .55762 L
.2619 .55905 L
.2619 .56048 L
.2619 .5619 L
.2619 .56333 L
.2619 .56476 L
.2619 .56619 L
.2619 .56762 L
.2619 .56905 L
s
.30952 .52619 m
.30952 .52762 L
.30952 .52905 L
.30952 .53048 L
.30952 .5319 L
.30952 .53333 L
.30952 .53476 L
.30952 .53619 L
.30952 .53762 L
.30952 .53905 L
.30952 .54048 L
.30952 .5419 L
.30952 .54333 L
.30952 .54476 L
.30952 .54619 L
.30952 .54762 L
.30952 .54905 L
.30952 .55048 L
.30952 .5519 L
.30952 .55333 L
.30952 .55476 L
.30952 .55619 L
.30952 .55762 L
.30952 .55905 L
.30952 .56048 L
.30952 .5619 L
.30952 .56333 L
.30952 .56476 L
.30952 .56619 L
.30952 .56762 L
.30952 .56905 L
s
.35714 .52619 m
.35714 .52762 L
.35714 .52905 L
.35714 .53048 L
.35714 .5319 L
.35714 .53333 L
.35714 .53476 L
.35714 .53619 L
.35714 .53762 L
.35714 .53905 L
.35714 .54048 L
.35714 .5419 L
.35714 .54333 L
.35714 .54476 L
.35714 .54619 L
.35714 .54762 L
.35714 .54905 L
.35714 .55048 L
.35714 .5519 L
.35714 .55333 L
.35714 .55476 L
.35714 .55619 L
.35714 .55762 L
.35714 .55905 L
.35714 .56048 L
.35714 .5619 L
.35714 .56333 L
.35714 .56476 L
.35714 .56619 L
.35714 .56762 L
.35714 .56905 L
s
.40476 .52619 m
.40476 .52762 L
.40476 .52905 L
.40476 .53048 L
.40476 .5319 L
.40476 .53333 L
.40476 .53476 L
.40476 .53619 L
.40476 .53762 L
.40476 .53905 L
.40476 .54048 L
.40476 .5419 L
.40476 .54333 L
.40476 .54476 L
.40476 .54619 L
.40476 .54762 L
.40476 .54905 L
.40476 .55048 L
.40476 .5519 L
.40476 .55333 L
.40476 .55476 L
.40476 .55619 L
.40476 .55762 L
.40476 .55905 L
.40476 .56048 L
.40476 .5619 L
.40476 .56333 L
.40476 .56476 L
.40476 .56619 L
.40476 .56762 L
.40476 .56905 L
s
.45238 .52619 m
.45238 .52762 L
.45238 .52905 L
.45238 .53048 L
.45238 .5319 L
.45238 .53333 L
.45238 .53476 L
.45238 .53619 L
.45238 .53762 L
.45238 .53905 L
.45238 .54048 L
.45238 .5419 L
.45238 .54333 L
.45238 .54476 L
.45238 .54619 L
.45238 .54762 L
.45238 .54905 L
.45238 .55048 L
.45238 .5519 L
.45238 .55333 L
.45238 .55476 L
.45238 .55619 L
.45238 .55762 L
.45238 .55905 L
.45238 .56048 L
.45238 .5619 L
.45238 .56333 L
.45238 .56476 L
.45238 .56619 L
.45238 .56762 L
.45238 .56905 L
s
.5 .52619 m
.5 .52762 L
.5 .52905 L
.5 .53048 L
.5 .5319 L
.5 .53333 L
.5 .53476 L
.5 .53619 L
.5 .53762 L
.5 .53905 L
.5 .54048 L
.5 .5419 L
.5 .54333 L
.5 .54476 L
.5 .54619 L
.5 .54762 L
.5 .54905 L
.5 .55048 L
.5 .5519 L
.5 .55333 L
.5 .55476 L
.5 .55619 L
.5 .55762 L
.5 .55905 L
.5 .56048 L
.5 .5619 L
.5 .56333 L
.5 .56476 L
.5 .56619 L
.5 .56762 L
.5 .56905 L
s
.54762 .52619 m
.54762 .52762 L
.54762 .52905 L
.54762 .53048 L
.54762 .5319 L
.54762 .53333 L
.54762 .53476 L
.54762 .53619 L
.54762 .53762 L
.54762 .53905 L
.54762 .54048 L
.54762 .5419 L
.54762 .54333 L
.54762 .54476 L
.54762 .54619 L
.54762 .54762 L
.54762 .54905 L
.54762 .55048 L
.54762 .5519 L
.54762 .55333 L
.54762 .55476 L
.54762 .55619 L
.54762 .55762 L
.54762 .55905 L
.54762 .56048 L
.54762 .5619 L
.54762 .56333 L
.54762 .56476 L
.54762 .56619 L
.54762 .56762 L
.54762 .56905 L
s
.59524 .52619 m
.59524 .52762 L
.59524 .52905 L
.59524 .53048 L
.59524 .5319 L
.59524 .53333 L
.59524 .53476 L
.59524 .53619 L
.59524 .53762 L
.59524 .53905 L
.59524 .54048 L
.59524 .5419 L
.59524 .54333 L
.59524 .54476 L
.59524 .54619 L
.59524 .54762 L
.59524 .54905 L
.59524 .55048 L
.59524 .5519 L
.59524 .55333 L
.59524 .55476 L
.59524 .55619 L
.59524 .55762 L
.59524 .55905 L
.59524 .56048 L
.59524 .5619 L
.59524 .56333 L
.59524 .56476 L
.59524 .56619 L
.59524 .56762 L
.59524 .56905 L
s
.64286 .52619 m
.64286 .52762 L
.64286 .52905 L
.64286 .53048 L
.64286 .5319 L
.64286 .53333 L
.64286 .53476 L
.64286 .53619 L
.64286 .53762 L
.64286 .53905 L
.64286 .54048 L
.64286 .5419 L
.64286 .54333 L
.64286 .54476 L
.64286 .54619 L
.64286 .54762 L
.64286 .54905 L
.64286 .55048 L
.64286 .5519 L
.64286 .55333 L
.64286 .55476 L
.64286 .55619 L
.64286 .55762 L
.64286 .55905 L
.64286 .56048 L
.64286 .5619 L
.64286 .56333 L
.64286 .56476 L
.64286 .56619 L
.64286 .56762 L
.64286 .56905 L
s
.69048 .52619 m
.69048 .52762 L
.69048 .52905 L
.69048 .53048 L
.69048 .5319 L
.69048 .53333 L
.69048 .53476 L
.69048 .53619 L
.69048 .53762 L
.69048 .53905 L
.69048 .54048 L
.69048 .5419 L
.69048 .54333 L
.69048 .54476 L
.69048 .54619 L
.69048 .54762 L
.69048 .54905 L
.69048 .55048 L
.69048 .5519 L
.69048 .55333 L
.69048 .55476 L
.69048 .55619 L
.69048 .55762 L
.69048 .55905 L
.69048 .56048 L
.69048 .5619 L
.69048 .56333 L
.69048 .56476 L
.69048 .56619 L
.69048 .56762 L
.69048 .56905 L
s
.7381 .52619 m
.7381 .52762 L
.7381 .52905 L
.7381 .53048 L
.7381 .5319 L
.7381 .53333 L
.7381 .53476 L
.7381 .53619 L
.7381 .53762 L
.7381 .53905 L
.7381 .54048 L
.7381 .5419 L
.7381 .54333 L
.7381 .54476 L
.7381 .54619 L
.7381 .54762 L
.7381 .54905 L
.7381 .55048 L
.7381 .5519 L
.7381 .55333 L
.7381 .55476 L
.7381 .55619 L
.7381 .55762 L
.7381 .55905 L
.7381 .56048 L
.7381 .5619 L
.7381 .56333 L
.7381 .56476 L
.7381 .56619 L
.7381 .56762 L
.7381 .56905 L
s
.78571 .52619 m
.78571 .52762 L
.78571 .52905 L
.78571 .53048 L
.78571 .5319 L
.78571 .53333 L
.78571 .53476 L
.78571 .53619 L
.78571 .53762 L
.78571 .53905 L
.78571 .54048 L
.78571 .5419 L
.78571 .54333 L
.78571 .54476 L
.78571 .54619 L
.78571 .54762 L
.78571 .54905 L
.78571 .55048 L
.78571 .5519 L
.78571 .55333 L
.78571 .55476 L
.78571 .55619 L
.78571 .55762 L
.78571 .55905 L
.78571 .56048 L
.78571 .5619 L
.78571 .56333 L
.78571 .56476 L
.78571 .56619 L
.78571 .56762 L
.78571 .56905 L
s
.83333 .52619 m
.83333 .52762 L
.83333 .52905 L
.83333 .53048 L
.83333 .5319 L
.83333 .53333 L
.83333 .53476 L
.83333 .53619 L
.83333 .53762 L
.83333 .53905 L
.83333 .54048 L
.83333 .5419 L
.83333 .54333 L
.83333 .54476 L
.83333 .54619 L
.83333 .54762 L
.83333 .54905 L
.83333 .55048 L
.83333 .5519 L
.83333 .55333 L
.83333 .55476 L
.83333 .55619 L
.83333 .55762 L
.83333 .55905 L
.83333 .56048 L
.83333 .5619 L
.83333 .56333 L
.83333 .56476 L
.83333 .56619 L
.83333 .56762 L
.83333 .56905 L
s
.88095 .52619 m
.88095 .52762 L
.88095 .52905 L
.88095 .53048 L
.88095 .5319 L
.88095 .53333 L
.88095 .53476 L
.88095 .53619 L
.88095 .53762 L
.88095 .53905 L
.88095 .54048 L
.88095 .5419 L
.88095 .54333 L
.88095 .54476 L
.88095 .54619 L
.88095 .54762 L
.88095 .54905 L
.88095 .55048 L
.88095 .5519 L
.88095 .55333 L
.88095 .55476 L
.88095 .55619 L
.88095 .55762 L
.88095 .55905 L
.88095 .56048 L
.88095 .5619 L
.88095 .56333 L
.88095 .56476 L
.88095 .56619 L
.88095 .56762 L
.88095 .56905 L
s
.92857 .52619 m
.92857 .52762 L
.92857 .52905 L
.92857 .53048 L
.92857 .5319 L
.92857 .53333 L
.92857 .53476 L
.92857 .53619 L
.92857 .53762 L
.92857 .53905 L
.92857 .54048 L
.92857 .5419 L
.92857 .54333 L
.92857 .54476 L
.92857 .54619 L
.92857 .54762 L
.92857 .54905 L
.92857 .55048 L
.92857 .5519 L
.92857 .55333 L
.92857 .55476 L
.92857 .55619 L
.92857 .55762 L
.92857 .55905 L
.92857 .56048 L
.92857 .56191 L
.92857 .56333 L
.92857 .56476 L
.92857 .56619 L
.92857 .56762 L
.92857 .56905 L
s
.02381 .59524 m
.05556 .59524 L
.0873 .59524 L
.11905 .59524 L
.15079 .59524 L
.18254 .59524 L
.21429 .59524 L
.24603 .59524 L
.27778 .59524 L
.30952 .59524 L
.34127 .59524 L
.37302 .59524 L
.40476 .59524 L
.43651 .59524 L
.46825 .59524 L
.5 .59524 L
.53175 .59524 L
.56349 .59524 L
.59524 .59524 L
.62698 .59524 L
.65873 .59524 L
.69048 .59524 L
.72222 .59524 L
.75397 .59524 L
.78571 .59524 L
.81746 .59524 L
.84921 .59524 L
.88095 .59524 L
.9127 .59524 L
.94444 .59524 L
.97619 .59524 L
s
.02381 .54762 m
.05556 .54762 L
.0873 .54762 L
.11905 .54762 L
.15079 .54762 L
.18254 .54762 L
.21429 .54762 L
.24603 .54762 L
.27778 .54762 L
.30952 .54762 L
.34127 .54762 L
.37302 .54762 L
.40476 .54762 L
.43651 .54762 L
.46825 .54762 L
.5 .54762 L
.53175 .54762 L
.56349 .54762 L
.59524 .54762 L
.62698 .54762 L
.65873 .54762 L
.69048 .54762 L
.72222 .54762 L
.75397 .54762 L
.78571 .54762 L
.81746 .54762 L
.84921 .54762 L
.88095 .54762 L
.9127 .54762 L
.94444 .54762 L
.97619 .54762 L
s
0 0 0 r
.02381 .57143 m
.97619 .57143 L
s
% Start of user PostScript
0 3.75 50. 3.75 MAarrowhead1
% End of user PostScript
.97619 .57143 m
.97619 .57143 L
s
% Start of user PostScript
50. 3.75 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .55 m
.02381 .55143 L
.02381 .55286 L
.02381 .55429 L
.02381 .55571 L
.02381 .55714 L
.02381 .55857 L
.02381 .56 L
.02381 .56143 L
.02381 .56286 L
.02381 .56429 L
.02381 .56571 L
.02381 .56714 L
.02381 .56857 L
.02381 .57 L
.02381 .57143 L
.02381 .57286 L
.02381 .57429 L
.02381 .57571 L
.02381 .57714 L
.02381 .57857 L
.02381 .58 L
.02381 .58143 L
.02381 .58286 L
.02381 .58429 L
.02381 .58571 L
.02381 .58714 L
.02381 .58857 L
.02381 .59 L
.02381 .59143 L
.02381 .59286 L
s
.07143 .55 m
.07143 .55143 L
.07143 .55286 L
.07143 .55429 L
.07143 .55571 L
.07143 .55714 L
.07143 .55857 L
.07143 .56 L
.07143 .56143 L
.07143 .56286 L
.07143 .56429 L
.07143 .56571 L
.07143 .56714 L
.07143 .56857 L
.07143 .57 L
.07143 .57143 L
.07143 .57286 L
.07143 .57429 L
.07143 .57571 L
.07143 .57714 L
.07143 .57857 L
.07143 .58 L
.07143 .58143 L
.07143 .58286 L
.07143 .58429 L
.07143 .58571 L
.07143 .58714 L
.07143 .58857 L
.07143 .59 L
.07143 .59143 L
.07143 .59286 L
s
.11905 .55 m
.11905 .55143 L
.11905 .55286 L
.11905 .55429 L
.11905 .55571 L
.11905 .55714 L
.11905 .55857 L
.11905 .56 L
.11905 .56143 L
.11905 .56286 L
.11905 .56429 L
.11905 .56571 L
.11905 .56714 L
.11905 .56857 L
.11905 .57 L
.11905 .57143 L
.11905 .57286 L
.11905 .57429 L
.11905 .57571 L
.11905 .57714 L
.11905 .57857 L
.11905 .58 L
.11905 .58143 L
.11905 .58286 L
.11905 .58429 L
.11905 .58571 L
.11905 .58714 L
.11905 .58857 L
.11905 .59 L
.11905 .59143 L
.11905 .59286 L
s
.16667 .55 m
.16667 .55143 L
.16667 .55286 L
.16667 .55429 L
.16667 .55571 L
.16667 .55714 L
.16667 .55857 L
.16667 .56 L
.16667 .56143 L
.16667 .56286 L
.16667 .56429 L
.16667 .56571 L
.16667 .56714 L
.16667 .56857 L
.16667 .57 L
.16667 .57143 L
.16667 .57286 L
.16667 .57429 L
.16667 .57571 L
.16667 .57714 L
.16667 .57857 L
.16667 .58 L
.16667 .58143 L
.16667 .58286 L
.16667 .58429 L
.16667 .58571 L
.16667 .58714 L
.16667 .58857 L
.16667 .59 L
.16667 .59143 L
.16667 .59286 L
s
.21429 .55 m
.21429 .55143 L
.21429 .55286 L
.21429 .55429 L
.21429 .55571 L
.21429 .55714 L
.21429 .55857 L
.21429 .56 L
.21429 .56143 L
.21429 .56286 L
.21429 .56429 L
.21429 .56571 L
.21429 .56714 L
.21429 .56857 L
.21429 .57 L
.21429 .57143 L
.21429 .57286 L
.21429 .57429 L
.21429 .57571 L
.21429 .57714 L
.21429 .57857 L
.21429 .58 L
.21429 .58143 L
.21429 .58286 L
.21429 .58429 L
.21429 .58571 L
.21429 .58714 L
.21429 .58857 L
.21429 .59 L
.21429 .59143 L
.21429 .59286 L
s
.2619 .55 m
.2619 .55143 L
.2619 .55286 L
.2619 .55429 L
.2619 .55571 L
.2619 .55714 L
.2619 .55857 L
.2619 .56 L
.2619 .56143 L
.2619 .56286 L
.2619 .56429 L
.2619 .56571 L
.2619 .56714 L
.2619 .56857 L
.2619 .57 L
.2619 .57143 L
.2619 .57286 L
.2619 .57429 L
.2619 .57571 L
.2619 .57714 L
.2619 .57857 L
.2619 .58 L
.2619 .58143 L
.2619 .58286 L
.2619 .58429 L
.2619 .58571 L
.2619 .58714 L
.2619 .58857 L
.2619 .59 L
.2619 .59143 L
.2619 .59286 L
s
.30952 .55 m
.30952 .55143 L
.30952 .55286 L
.30952 .55429 L
.30952 .55571 L
.30952 .55714 L
.30952 .55857 L
.30952 .56 L
.30952 .56143 L
.30952 .56286 L
.30952 .56429 L
.30952 .56571 L
.30952 .56714 L
.30952 .56857 L
.30952 .57 L
.30952 .57143 L
.30952 .57286 L
.30952 .57429 L
.30952 .57571 L
.30952 .57714 L
.30952 .57857 L
.30952 .58 L
.30952 .58143 L
.30952 .58286 L
.30952 .58429 L
.30952 .58571 L
.30952 .58714 L
.30952 .58857 L
.30952 .59 L
.30952 .59143 L
.30952 .59286 L
s
.35714 .55 m
.35714 .55143 L
.35714 .55286 L
.35714 .55429 L
.35714 .55571 L
.35714 .55714 L
.35714 .55857 L
.35714 .56 L
.35714 .56143 L
.35714 .56286 L
.35714 .56429 L
.35714 .56571 L
.35714 .56714 L
.35714 .56857 L
.35714 .57 L
.35714 .57143 L
.35714 .57286 L
.35714 .57429 L
.35714 .57571 L
.35714 .57714 L
.35714 .57857 L
.35714 .58 L
.35714 .58143 L
.35714 .58286 L
.35714 .58429 L
.35714 .58571 L
.35714 .58714 L
.35714 .58857 L
.35714 .59 L
.35714 .59143 L
.35714 .59286 L
s
.40476 .55 m
.40476 .55143 L
.40476 .55286 L
.40476 .55429 L
.40476 .55571 L
.40476 .55714 L
.40476 .55857 L
.40476 .56 L
.40476 .56143 L
.40476 .56286 L
.40476 .56429 L
.40476 .56571 L
.40476 .56714 L
.40476 .56857 L
.40476 .57 L
.40476 .57143 L
.40476 .57286 L
.40476 .57429 L
.40476 .57571 L
.40476 .57714 L
.40476 .57857 L
.40476 .58 L
.40476 .58143 L
.40476 .58286 L
.40476 .58429 L
.40476 .58571 L
.40476 .58714 L
.40476 .58857 L
.40476 .59 L
.40476 .59143 L
.40476 .59286 L
s
.45238 .55 m
.45238 .55143 L
.45238 .55286 L
.45238 .55429 L
.45238 .55571 L
.45238 .55714 L
.45238 .55857 L
.45238 .56 L
.45238 .56143 L
.45238 .56286 L
.45238 .56429 L
.45238 .56571 L
.45238 .56714 L
.45238 .56857 L
.45238 .57 L
.45238 .57143 L
.45238 .57286 L
.45238 .57429 L
.45238 .57571 L
.45238 .57714 L
.45238 .57857 L
.45238 .58 L
.45238 .58143 L
.45238 .58286 L
.45238 .58429 L
.45238 .58571 L
.45238 .58714 L
.45238 .58857 L
.45238 .59 L
.45238 .59143 L
.45238 .59286 L
s
.5 .55 m
.5 .55143 L
.5 .55286 L
.5 .55429 L
.5 .55571 L
.5 .55714 L
.5 .55857 L
.5 .56 L
.5 .56143 L
.5 .56286 L
.5 .56429 L
.5 .56571 L
.5 .56714 L
.5 .56857 L
.5 .57 L
.5 .57143 L
.5 .57286 L
.5 .57429 L
.5 .57571 L
.5 .57714 L
.5 .57857 L
.5 .58 L
.5 .58143 L
.5 .58286 L
.5 .58429 L
.5 .58571 L
.5 .58714 L
.5 .58857 L
.5 .59 L
.5 .59143 L
.5 .59286 L
s
.54762 .55 m
.54762 .55143 L
.54762 .55286 L
.54762 .55429 L
.54762 .55571 L
.54762 .55714 L
.54762 .55857 L
.54762 .56 L
.54762 .56143 L
.54762 .56286 L
.54762 .56429 L
.54762 .56571 L
.54762 .56714 L
.54762 .56857 L
.54762 .57 L
.54762 .57143 L
.54762 .57286 L
.54762 .57429 L
.54762 .57571 L
.54762 .57714 L
.54762 .57857 L
.54762 .58 L
.54762 .58143 L
.54762 .58286 L
.54762 .58429 L
.54762 .58571 L
.54762 .58714 L
.54762 .58857 L
.54762 .59 L
.54762 .59143 L
.54762 .59286 L
s
.59524 .55 m
.59524 .55143 L
.59524 .55286 L
.59524 .55429 L
.59524 .55571 L
.59524 .55714 L
.59524 .55857 L
.59524 .56 L
.59524 .56143 L
.59524 .56286 L
.59524 .56429 L
.59524 .56571 L
.59524 .56714 L
.59524 .56857 L
.59524 .57 L
.59524 .57143 L
.59524 .57286 L
.59524 .57429 L
.59524 .57571 L
.59524 .57714 L
.59524 .57857 L
.59524 .58 L
.59524 .58143 L
.59524 .58286 L
.59524 .58429 L
.59524 .58571 L
.59524 .58714 L
.59524 .58857 L
.59524 .59 L
.59524 .59143 L
.59524 .59286 L
s
.64286 .55 m
.64286 .55143 L
.64286 .55286 L
.64286 .55429 L
.64286 .55571 L
.64286 .55714 L
.64286 .55857 L
.64286 .56 L
.64286 .56143 L
.64286 .56286 L
.64286 .56429 L
.64286 .56571 L
.64286 .56714 L
.64286 .56857 L
.64286 .57 L
.64286 .57143 L
.64286 .57286 L
.64286 .57429 L
.64286 .57571 L
.64286 .57714 L
.64286 .57857 L
.64286 .58 L
.64286 .58143 L
.64286 .58286 L
.64286 .58429 L
.64286 .58571 L
.64286 .58714 L
.64286 .58857 L
.64286 .59 L
.64286 .59143 L
.64286 .59286 L
s
.69048 .55 m
.69048 .55143 L
.69048 .55286 L
.69048 .55429 L
.69048 .55571 L
.69048 .55714 L
.69048 .55857 L
.69048 .56 L
.69048 .56143 L
.69048 .56286 L
.69048 .56429 L
.69048 .56571 L
.69048 .56714 L
.69048 .56857 L
.69048 .57 L
.69048 .57143 L
.69048 .57286 L
.69048 .57429 L
.69048 .57571 L
.69048 .57714 L
.69048 .57857 L
.69048 .58 L
.69048 .58143 L
.69048 .58286 L
.69048 .58429 L
.69048 .58571 L
.69048 .58714 L
.69048 .58857 L
.69048 .59 L
.69048 .59143 L
.69048 .59286 L
s
.7381 .55 m
.7381 .55143 L
.7381 .55286 L
.7381 .55429 L
.7381 .55571 L
.7381 .55714 L
.7381 .55857 L
.7381 .56 L
.7381 .56143 L
.7381 .56286 L
.7381 .56429 L
.7381 .56571 L
.7381 .56714 L
.7381 .56857 L
.7381 .57 L
.7381 .57143 L
.7381 .57286 L
.7381 .57429 L
.7381 .57571 L
.7381 .57714 L
.7381 .57857 L
.7381 .58 L
.7381 .58143 L
.7381 .58286 L
.7381 .58429 L
.7381 .58571 L
.7381 .58714 L
.7381 .58857 L
.7381 .59 L
.7381 .59143 L
.7381 .59286 L
s
.78571 .55 m
.78571 .55143 L
.78571 .55286 L
.78571 .55429 L
.78571 .55571 L
.78571 .55714 L
.78571 .55857 L
.78571 .56 L
.78571 .56143 L
.78571 .56286 L
.78571 .56429 L
.78571 .56571 L
.78571 .56714 L
.78571 .56857 L
.78571 .57 L
.78571 .57143 L
.78571 .57286 L
.78571 .57429 L
.78571 .57571 L
.78571 .57714 L
.78571 .57857 L
.78571 .58 L
.78571 .58143 L
.78571 .58286 L
.78571 .58429 L
.78571 .58571 L
.78571 .58714 L
.78571 .58857 L
.78571 .59 L
.78571 .59143 L
.78571 .59286 L
s
.83333 .55 m
.83333 .55143 L
.83333 .55286 L
.83333 .55429 L
.83333 .55571 L
.83333 .55714 L
.83333 .55857 L
.83333 .56 L
.83333 .56143 L
.83333 .56286 L
.83333 .56429 L
.83333 .56571 L
.83333 .56714 L
.83333 .56857 L
.83333 .57 L
.83333 .57143 L
.83333 .57286 L
.83333 .57429 L
.83333 .57571 L
.83333 .57714 L
.83333 .57857 L
.83333 .58 L
.83333 .58143 L
.83333 .58286 L
.83333 .58429 L
.83333 .58571 L
.83333 .58714 L
.83333 .58857 L
.83333 .59 L
.83333 .59143 L
.83333 .59286 L
s
.88095 .55 m
.88095 .55143 L
.88095 .55286 L
.88095 .55429 L
.88095 .55571 L
.88095 .55714 L
.88095 .55857 L
.88095 .56 L
.88095 .56143 L
.88095 .56286 L
.88095 .56429 L
.88095 .56571 L
.88095 .56714 L
.88095 .56857 L
.88095 .57 L
.88095 .57143 L
.88095 .57286 L
.88095 .57429 L
.88095 .57571 L
.88095 .57714 L
.88095 .57857 L
.88095 .58 L
.88095 .58143 L
.88095 .58286 L
.88095 .58429 L
.88095 .58571 L
.88095 .58714 L
.88095 .58857 L
.88095 .59 L
.88095 .59143 L
.88095 .59286 L
s
.92857 .55 m
.92857 .55143 L
.92857 .55286 L
.92857 .55429 L
.92857 .55571 L
.92857 .55714 L
.92857 .55857 L
.92857 .56 L
.92857 .56143 L
.92857 .56286 L
.92857 .56429 L
.92857 .56571 L
.92857 .56714 L
.92857 .56857 L
.92857 .57 L
.92857 .57143 L
.92857 .57286 L
.92857 .57429 L
.92857 .57571 L
.92857 .57714 L
.92857 .57857 L
.92857 .58 L
.92857 .58143 L
.92857 .58286 L
.92857 .58429 L
.92857 .58571 L
.92857 .58714 L
.92857 .58857 L
.92857 .59 L
.92857 .59143 L
.92857 .59286 L
s
.02381 .61905 m
.05556 .61905 L
.0873 .61905 L
.11905 .61905 L
.15079 .61905 L
.18254 .61905 L
.21429 .61905 L
.24603 .61905 L
.27778 .61905 L
.30952 .61905 L
.34127 .61905 L
.37302 .61905 L
.40476 .61905 L
.43651 .61905 L
.46825 .61905 L
.5 .61905 L
.53175 .61905 L
.56349 .61905 L
.59524 .61905 L
.62698 .61905 L
.65873 .61905 L
.69048 .61905 L
.72222 .61905 L
.75397 .61905 L
.78571 .61905 L
.81746 .61905 L
.84921 .61905 L
.88095 .61905 L
.9127 .61905 L
.94444 .61905 L
.97619 .61905 L
s
.02381 .57143 m
.05556 .57143 L
.0873 .57143 L
.11905 .57143 L
.15079 .57143 L
.18254 .57143 L
.21429 .57143 L
.24603 .57143 L
.27778 .57143 L
.30952 .57143 L
.34127 .57143 L
.37302 .57143 L
.40476 .57143 L
.43651 .57143 L
.46825 .57143 L
.5 .57143 L
.53175 .57143 L
.56349 .57143 L
.59524 .57143 L
.62698 .57143 L
.65873 .57143 L
.69048 .57143 L
.72222 .57143 L
.75397 .57143 L
.78571 .57143 L
.81746 .57143 L
.84921 .57143 L
.88095 .57143 L
.9127 .57143 L
.94444 .57143 L
.97619 .57143 L
s
0 0 0 r
.02381 .59524 m
.97619 .59524 L
s
% Start of user PostScript
0 5. 50. 5. MAarrowhead1
% End of user PostScript
.97619 .59524 m
.97619 .59524 L
s
% Start of user PostScript
50. 5. MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .57381 m
.02381 .57524 L
.02381 .57667 L
.02381 .5781 L
.02381 .57952 L
.02381 .58095 L
.02381 .58238 L
.02381 .58381 L
.02381 .58524 L
.02381 .58667 L
.02381 .5881 L
.02381 .58952 L
.02381 .59095 L
.02381 .59238 L
.02381 .59381 L
.02381 .59524 L
.02381 .59667 L
.02381 .5981 L
.02381 .59952 L
.02381 .60095 L
.02381 .60238 L
.02381 .60381 L
.02381 .60524 L
.02381 .60667 L
.02381 .6081 L
.02381 .60952 L
.02381 .61095 L
.02381 .61238 L
.02381 .61381 L
.02381 .61524 L
.02381 .61667 L
s
.07143 .57381 m
.07143 .57524 L
.07143 .57667 L
.07143 .5781 L
.07143 .57952 L
.07143 .58095 L
.07143 .58238 L
.07143 .58381 L
.07143 .58524 L
.07143 .58667 L
.07143 .5881 L
.07143 .58952 L
.07143 .59095 L
.07143 .59238 L
.07143 .59381 L
.07143 .59524 L
.07143 .59667 L
.07143 .5981 L
.07143 .59952 L
.07143 .60095 L
.07143 .60238 L
.07143 .60381 L
.07143 .60524 L
.07143 .60667 L
.07143 .6081 L
.07143 .60952 L
.07143 .61095 L
.07143 .61238 L
.07143 .61381 L
.07143 .61524 L
.07143 .61667 L
s
.11905 .57381 m
.11905 .57524 L
.11905 .57667 L
.11905 .5781 L
.11905 .57952 L
.11905 .58095 L
.11905 .58238 L
.11905 .58381 L
.11905 .58524 L
.11905 .58667 L
.11905 .5881 L
.11905 .58952 L
.11905 .59095 L
.11905 .59238 L
.11905 .59381 L
.11905 .59524 L
.11905 .59667 L
.11905 .5981 L
.11905 .59952 L
.11905 .60095 L
.11905 .60238 L
.11905 .60381 L
.11905 .60524 L
.11905 .60667 L
.11905 .6081 L
.11905 .60952 L
.11905 .61095 L
.11905 .61238 L
.11905 .61381 L
.11905 .61524 L
.11905 .61667 L
s
.16667 .57381 m
.16667 .57524 L
.16667 .57667 L
.16667 .5781 L
.16667 .57952 L
.16667 .58095 L
.16667 .58238 L
.16667 .58381 L
.16667 .58524 L
.16667 .58667 L
.16667 .5881 L
.16667 .58952 L
.16667 .59095 L
.16667 .59238 L
.16667 .59381 L
.16667 .59524 L
.16667 .59667 L
.16667 .5981 L
.16667 .59952 L
.16667 .60095 L
.16667 .60238 L
.16667 .60381 L
.16667 .60524 L
.16667 .60667 L
.16667 .6081 L
.16667 .60952 L
.16667 .61095 L
.16667 .61238 L
.16667 .61381 L
.16667 .61524 L
.16667 .61667 L
s
.21429 .57381 m
.21429 .57524 L
.21429 .57667 L
.21429 .5781 L
.21429 .57952 L
.21429 .58095 L
.21429 .58238 L
.21429 .58381 L
.21429 .58524 L
.21429 .58667 L
.21429 .5881 L
.21429 .58952 L
.21429 .59095 L
.21429 .59238 L
.21429 .59381 L
.21429 .59524 L
.21429 .59667 L
.21429 .5981 L
.21429 .59952 L
.21429 .60095 L
.21429 .60238 L
.21429 .60381 L
.21429 .60524 L
.21429 .60667 L
.21429 .6081 L
.21429 .60952 L
.21429 .61095 L
.21429 .61238 L
.21429 .61381 L
.21429 .61524 L
.21429 .61667 L
s
.2619 .57381 m
.2619 .57524 L
.2619 .57667 L
.2619 .5781 L
.2619 .57952 L
.2619 .58095 L
.2619 .58238 L
.2619 .58381 L
.2619 .58524 L
.2619 .58667 L
.2619 .5881 L
.2619 .58952 L
.2619 .59095 L
.2619 .59238 L
.2619 .59381 L
.2619 .59524 L
.2619 .59667 L
.2619 .5981 L
.2619 .59952 L
.2619 .60095 L
.2619 .60238 L
.2619 .60381 L
.2619 .60524 L
.2619 .60667 L
.2619 .6081 L
.2619 .60952 L
.2619 .61095 L
.2619 .61238 L
.2619 .61381 L
.2619 .61524 L
.2619 .61667 L
s
.30952 .57381 m
.30952 .57524 L
.30952 .57667 L
.30952 .5781 L
.30952 .57952 L
.30952 .58095 L
.30952 .58238 L
.30952 .58381 L
.30952 .58524 L
.30952 .58667 L
.30952 .5881 L
.30952 .58952 L
.30952 .59095 L
.30952 .59238 L
.30952 .59381 L
.30952 .59524 L
.30952 .59667 L
.30952 .5981 L
.30952 .59952 L
.30952 .60095 L
.30952 .60238 L
.30952 .60381 L
.30952 .60524 L
.30952 .60667 L
.30952 .6081 L
.30952 .60952 L
.30952 .61095 L
.30952 .61238 L
.30952 .61381 L
.30952 .61524 L
.30952 .61667 L
s
.35714 .57381 m
.35714 .57524 L
.35714 .57667 L
.35714 .5781 L
.35714 .57952 L
.35714 .58095 L
.35714 .58238 L
.35714 .58381 L
.35714 .58524 L
.35714 .58667 L
.35714 .5881 L
.35714 .58952 L
.35714 .59095 L
.35714 .59238 L
.35714 .59381 L
.35714 .59524 L
.35714 .59667 L
.35714 .5981 L
.35714 .59952 L
.35714 .60095 L
.35714 .60238 L
.35714 .60381 L
.35714 .60524 L
.35714 .60667 L
.35714 .6081 L
.35714 .60952 L
.35714 .61095 L
.35714 .61238 L
.35714 .61381 L
.35714 .61524 L
.35714 .61667 L
s
.40476 .57381 m
.40476 .57524 L
.40476 .57667 L
.40476 .5781 L
.40476 .57952 L
.40476 .58095 L
.40476 .58238 L
.40476 .58381 L
.40476 .58524 L
.40476 .58667 L
.40476 .5881 L
.40476 .58952 L
.40476 .59095 L
.40476 .59238 L
.40476 .59381 L
.40476 .59524 L
.40476 .59667 L
.40476 .5981 L
.40476 .59952 L
.40476 .60095 L
.40476 .60238 L
.40476 .60381 L
.40476 .60524 L
.40476 .60667 L
.40476 .6081 L
.40476 .60952 L
.40476 .61095 L
.40476 .61238 L
.40476 .61381 L
.40476 .61524 L
.40476 .61667 L
s
.45238 .57381 m
.45238 .57524 L
.45238 .57667 L
.45238 .5781 L
.45238 .57952 L
.45238 .58095 L
.45238 .58238 L
.45238 .58381 L
.45238 .58524 L
.45238 .58667 L
.45238 .5881 L
.45238 .58952 L
.45238 .59095 L
.45238 .59238 L
.45238 .59381 L
.45238 .59524 L
.45238 .59667 L
.45238 .5981 L
.45238 .59952 L
.45238 .60095 L
.45238 .60238 L
.45238 .60381 L
.45238 .60524 L
.45238 .60667 L
.45238 .6081 L
.45238 .60952 L
.45238 .61095 L
.45238 .61238 L
.45238 .61381 L
.45238 .61524 L
.45238 .61667 L
s
.5 .57381 m
.5 .57524 L
.5 .57667 L
.5 .5781 L
.5 .57952 L
.5 .58095 L
.5 .58238 L
.5 .58381 L
.5 .58524 L
.5 .58667 L
.5 .5881 L
.5 .58952 L
.5 .59095 L
.5 .59238 L
.5 .59381 L
.5 .59524 L
.5 .59667 L
.5 .5981 L
.5 .59952 L
.5 .60095 L
.5 .60238 L
.5 .60381 L
.5 .60524 L
.5 .60667 L
.5 .6081 L
.5 .60952 L
.5 .61095 L
.5 .61238 L
.5 .61381 L
.5 .61524 L
.5 .61667 L
s
.54762 .57381 m
.54762 .57524 L
.54762 .57667 L
.54762 .5781 L
.54762 .57952 L
.54762 .58095 L
.54762 .58238 L
.54762 .58381 L
.54762 .58524 L
.54762 .58667 L
.54762 .5881 L
.54762 .58952 L
.54762 .59095 L
.54762 .59238 L
.54762 .59381 L
.54762 .59524 L
.54762 .59667 L
.54762 .5981 L
.54762 .59952 L
.54762 .60095 L
.54762 .60238 L
.54762 .60381 L
.54762 .60524 L
.54762 .60667 L
.54762 .6081 L
.54762 .60952 L
.54762 .61095 L
.54762 .61238 L
.54762 .61381 L
.54762 .61524 L
.54762 .61667 L
s
.59524 .57381 m
.59524 .57524 L
.59524 .57667 L
.59524 .5781 L
.59524 .57952 L
.59524 .58095 L
.59524 .58238 L
.59524 .58381 L
.59524 .58524 L
.59524 .58667 L
.59524 .5881 L
.59524 .58952 L
.59524 .59095 L
.59524 .59238 L
.59524 .59381 L
.59524 .59524 L
.59524 .59667 L
.59524 .5981 L
.59524 .59952 L
.59524 .60095 L
.59524 .60238 L
.59524 .60381 L
.59524 .60524 L
.59524 .60667 L
.59524 .6081 L
.59524 .60952 L
.59524 .61095 L
.59524 .61238 L
.59524 .61381 L
.59524 .61524 L
.59524 .61667 L
s
.64286 .57381 m
.64286 .57524 L
.64286 .57667 L
.64286 .5781 L
.64286 .57952 L
.64286 .58095 L
.64286 .58238 L
.64286 .58381 L
.64286 .58524 L
.64286 .58667 L
.64286 .5881 L
.64286 .58952 L
.64286 .59095 L
.64286 .59238 L
.64286 .59381 L
.64286 .59524 L
.64286 .59667 L
.64286 .5981 L
.64286 .59952 L
.64286 .60095 L
.64286 .60238 L
.64286 .60381 L
.64286 .60524 L
.64286 .60667 L
.64286 .6081 L
.64286 .60952 L
.64286 .61095 L
.64286 .61238 L
.64286 .61381 L
.64286 .61524 L
.64286 .61667 L
s
.69048 .57381 m
.69048 .57524 L
.69048 .57667 L
.69048 .5781 L
.69048 .57952 L
.69048 .58095 L
.69048 .58238 L
.69048 .58381 L
.69048 .58524 L
.69048 .58667 L
.69048 .5881 L
.69048 .58952 L
.69048 .59095 L
.69048 .59238 L
.69048 .59381 L
.69048 .59524 L
.69048 .59667 L
.69048 .5981 L
.69048 .59952 L
.69048 .60095 L
.69048 .60238 L
.69048 .60381 L
.69048 .60524 L
.69048 .60667 L
.69048 .6081 L
.69048 .60952 L
.69048 .61095 L
.69048 .61238 L
.69048 .61381 L
.69048 .61524 L
.69048 .61667 L
s
.7381 .57381 m
.7381 .57524 L
.7381 .57667 L
.7381 .5781 L
.7381 .57952 L
.7381 .58095 L
.7381 .58238 L
.7381 .58381 L
.7381 .58524 L
.7381 .58667 L
.7381 .5881 L
.7381 .58952 L
.7381 .59095 L
.7381 .59238 L
.7381 .59381 L
.7381 .59524 L
.7381 .59667 L
.7381 .5981 L
.7381 .59952 L
.7381 .60095 L
.7381 .60238 L
.7381 .60381 L
.7381 .60524 L
.7381 .60667 L
.7381 .6081 L
.7381 .60952 L
.7381 .61095 L
.7381 .61238 L
.7381 .61381 L
.7381 .61524 L
.7381 .61667 L
s
.78571 .57381 m
.78571 .57524 L
.78571 .57667 L
.78571 .5781 L
.78571 .57952 L
.78571 .58095 L
.78571 .58238 L
.78571 .58381 L
.78571 .58524 L
.78571 .58667 L
.78571 .5881 L
.78571 .58952 L
.78571 .59095 L
.78571 .59238 L
.78571 .59381 L
.78571 .59524 L
.78571 .59667 L
.78571 .5981 L
.78571 .59952 L
.78571 .60095 L
.78571 .60238 L
.78571 .60381 L
.78571 .60524 L
.78571 .60667 L
.78571 .6081 L
.78571 .60952 L
.78571 .61095 L
.78571 .61238 L
.78571 .61381 L
.78571 .61524 L
.78571 .61667 L
s
.83333 .57381 m
.83333 .57524 L
.83333 .57667 L
.83333 .57809 L
.83333 .57952 L
.83333 .58095 L
.83333 .58238 L
.83333 .58381 L
.83333 .58524 L
.83333 .58667 L
.83333 .5881 L
.83333 .58952 L
.83333 .59095 L
.83333 .59238 L
.83333 .59381 L
.83333 .59524 L
.83333 .59667 L
.83333 .5981 L
.83333 .59952 L
.83333 .60095 L
.83333 .60238 L
.83333 .60381 L
.83333 .60524 L
.83333 .60667 L
.83333 .6081 L
.83333 .60952 L
.83333 .61095 L
.83333 .61238 L
.83333 .61381 L
.83333 .61524 L
.83333 .61667 L
s
.88095 .57381 m
.88095 .57524 L
.88095 .57667 L
.88095 .57809 L
.88095 .57952 L
.88095 .58095 L
.88095 .58238 L
.88095 .58381 L
.88095 .58524 L
.88095 .58667 L
.88095 .5881 L
.88095 .58952 L
.88095 .59095 L
.88095 .59238 L
.88095 .59381 L
.88095 .59524 L
.88095 .59667 L
.88095 .5981 L
.88095 .59952 L
.88095 .60095 L
.88095 .60238 L
.88095 .60381 L
.88095 .60524 L
.88095 .60667 L
.88095 .6081 L
.88095 .60952 L
.88095 .61095 L
.88095 .61238 L
.88095 .61381 L
.88095 .61524 L
.88095 .61667 L
s
.92857 .57381 m
.92857 .57524 L
.92857 .57667 L
.92857 .57809 L
.92857 .57952 L
.92857 .58095 L
.92857 .58238 L
.92857 .58381 L
.92857 .58524 L
.92857 .58667 L
.92857 .5881 L
.92857 .58952 L
.92857 .59095 L
.92857 .59238 L
.92857 .59381 L
.92857 .59524 L
.92857 .59667 L
.92857 .5981 L
.92857 .59952 L
.92857 .60095 L
.92857 .60238 L
.92857 .60381 L
.92857 .60524 L
.92857 .60667 L
.92857 .6081 L
.92857 .60952 L
.92857 .61095 L
.92857 .61238 L
.92857 .61381 L
.92857 .61524 L
.92857 .61667 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[47]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`00
0000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo
00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI
0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0
oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo
003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3o
ool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003o
ool0oooo00D0oooo00060?ooool02NX:5009jPX70?ooo`001P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00060?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`030?ooo`<000001@3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00@0oooo1P0000000`3oool000000?ooo`060?ooo`001P3ooooo00WZ2Q@02NX:1`3oool000H0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`040?ooo`D000000P3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00<0oooo0P00
00060?ooo`030000003oool0oooo00D0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo00D0oooo00060?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0103oool6000000030?ooo`000000oooo00H0
oooo00060?ooool02NX:5009jPX70?ooo`001P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3o
ool0oooo00@0oooo1@0000020?ooo`030000003oool0oooo00D0oooo00060?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo
00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo
00D0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo
00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo
00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo
00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo
00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo
00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo
00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00<0oooo
0`0000050?ooo`030000003oool0oooo00D0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool0103oool6000000030?ooo`000000oooo00H0oooo00060?ooool02NX:5009jPX7
0?ooo`001P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00@0oooo1@0000020?oo
o`030000003oool0oooo00D0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool00`3oool2000000H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00060?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3o
ool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`001P3oool0
0`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool0
0`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool0
0`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool0
0`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool0
0`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool0
0`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool0
0`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00<0oooo0`0000050?ooo`030000003oool0
oooo00D0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0103oool60000
00030?ooo`000000oooo00H0oooo00060?ooool02NX:5009jPX70?ooo`001P3oool00`09jPX0oooo
0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo
0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo
0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo
0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo
0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo
0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo
0?ooo`0;0?ooo`0300WZ2P3oool0oooo00@0oooo1@0000020?ooo`030000003oool0oooo00D0oooo
00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool00`3oool2000000H0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`030000003oool0oooo00D0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?oo
o`3oool02`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`09jPX0oooo0?ooo`0;0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`03
00WZ2P3oool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo00D0oooo00060?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0103oool6000000030?ooo`000000oooo00H0oooo
00060?ooool02NX:5009jPX70?ooo`001P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00@0oooo1@0000020?ooo`030000003oool0oooo00D0oooo00060?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo
00/0oooo00<02NX:0?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0
oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0
oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0
oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0
oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0
oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0
oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo00D0
oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo
0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo
0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo
0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo
0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo
0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo
0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00<0oooo0`00
00050?ooo`030000003oool0oooo00D0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:
0?ooo`3oool0103oool6000000030?ooo`000000oooo00H0oooo00060?ooool02NX:5009jPX70?oo
o`001P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00@0oooo1@0000020?ooo`03
0000003oool0oooo00D0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
0`3oool2000000H0oooo00<000000?ooo`3oool01@3oool000H0oooo00<02NX:0?ooo`3oool02`3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3o
ool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00060?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo
00D0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0
oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0103oool600000003
0?ooo`000000oooo00H0oooo00060?ooool02NX:5009jPX70?ooo`001P3oool00`09jPX0oooo0?oo
o`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?oo
o`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?oo
o`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?oo
o`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?oo
o`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?oo
o`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?oo
o`0;0?ooo`0300WZ2P3oool0oooo00@0oooo1@0000020?ooo`030000003oool0oooo00D0oooo0006
0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:
0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:
0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:
0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:
0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:
0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0:
0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool00`3oool2000000H0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?oo
o`030000003oool0oooo00D0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool00`3oool3000000D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`040?ooo`H0000000<0oooo0000003oool01P3oool000H0ooooo`09
jPXD00WZ2PL0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool0
0`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool0
0`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool0
0`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool0
0`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool0
0`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool0
0`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0103oool5
00000080oooo00<000000?ooo`3oool01@3oool000H0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`001P3oool00`09jPX0
oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0
oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0
oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0
oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0
oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0
oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0
oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo
00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?oo
o`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool00`3oool3000000D0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`04
0?ooo`H0000000<0oooo0000003oool01P3oool000H0oooo00<02NX:0000000000002`0000000`09
jPX000000000000;0000000300WZ2P000000000000X0000000<02NX:0000000000002`0000000`09
jPX000000000000;0000000300WZ2P000000000000X0000000<02NX:0000000000002`0000000`09
jPX000000000000;0000000300WZ2P000000000000X0000000<02NX:0000000000002`0000000`09
jPX000000000000;0000000300WZ2P000000000000X0000000<02NX:0000000000002`0000000`09
jPX000000000000;0000000300WZ2P000000000000X0000000<02NX:0000000000002`0000000`09
jPX000000000000;0000000300WZ2P000000000000X0000000<02NX:0000000000002`0000000`09
jPX000000000000<000000L0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool02`3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3o
ool0103oool500000080oooo00<000000?ooo`3oool01@3oool000H0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02P3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0;0?ooo`030000003oool0
oooo00D0oooo00060?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool02`3oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0
oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0
oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0
oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0
oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0
oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0
oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00/0
oooo00<000000?ooo`3oool01@3oool000H0ooooo`09jPXD00WZ2PL0oooo003o0?oooaT0oooo00<0
00000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?oo
o`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo
6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o
0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?oo
o`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool0
1@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0
oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000
oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<0
00000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?oo
o`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo
6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o
0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?oo
o`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool0
1@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0
oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000
oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<0
00000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?oo
o`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo
6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o
0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?oo
o`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool0
1@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0
oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000
oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<0
00000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?oo
o`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo
6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o
0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?oo
o`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool0
1@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0
oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000
oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<0
00000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?oo
o`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo
6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o
0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?oo
o`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool0
1@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0
oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000
oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<0
00000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?oo
o`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo
6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o
0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?oo
o`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool0
1@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0
oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000
oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<0
00000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?oo
o`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo
6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o
0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?oo
o`00o`3ooolI0?ooo`030000003oool0oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool0
1@3oool00?l0oooo6@3oool00`000000oooo0?ooo`050?ooo`00o`3ooolI0?ooo`030000003oool0
oooo00D0oooo003o0?oooaT0oooo00<000000?ooo`3oool01@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.25026, -26.2503, 0.182929, \
0.182929}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["intensity = FindField[waveletSystem]", "Input",
  CellLabel->"In[48]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],

Cell[BoxData[
    TagBox[\(CompiledFunction[
        0.04822561050015509`\ Abs[\(0.79894172846783`\ \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ \((\(-ArcTan[0.00010837823004787182`\ \
\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)]\) + \
11810.498697705989`\ #1)\) - \(5905.249348852994`\ \[ImaginaryI]\ \((\(-5\) + \
#2)\)\^2\)\/\(\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)\ \
\((1 + 8.513651950746305`*^7\/\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\
\) + #1)\)\^2)\)\) - \(0.6400004724200351`\ \((\(-5\) + #2)\)\^2\)\/\(1 + \
1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2\)\)\)\/\((1 + 1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\
\[InvisibleSpace]\)\) + #1)\)\^2)\)\^\(1/4\) + \(0.79894172846783`\ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \((\(-ArcTan[0.00010837823004787182`\ \
\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)]\) + \
11810.498697705989`\ #1)\) - \(5905.249348852994`\ \[ImaginaryI]\ \
\((\(-\(15\/4\)\) + #2)\)\^2\)\/\(\((\(\(57.92742446507327`\)\(\
\[InvisibleSpace]\)\) + #1)\)\ \((1 + \
8.513651950746305`*^7\/\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2)\)\) - \(0.6400004724200351`\ \((\(-\(15\/4\)\) + #2)\)\^2\)\/\(1 + \
1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2\)\)\)\/\((1 + 1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\
\[InvisibleSpace]\)\) + #1)\)\^2)\)\^\(1/4\) + \(0.79894172846783`\ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \((\(-ArcTan[0.00010837823004787182`\ \
\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)]\) + \
11810.498697705989`\ #1)\) - \(5905.249348852994`\ \[ImaginaryI]\ \
\((\(-\(5\/2\)\) + #2)\)\^2\)\/\(\((\(\(57.92742446507327`\)\(\
\[InvisibleSpace]\)\) + #1)\)\ \((1 + \
8.513651950746305`*^7\/\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2)\)\) - \(0.6400004724200351`\ \((\(-\(5\/2\)\) + #2)\)\^2\)\/\(1 + \
1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2\)\)\)\/\((1 + 1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\
\[InvisibleSpace]\)\) + #1)\)\^2)\)\^\(1/4\) + \(0.7989417284678298`\ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \((\(-ArcTan[0.00010837823004787182`\ \
\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)]\) + \
11810.498697705989`\ #1)\) - \(5905.249348852994`\ \[ImaginaryI]\ \
\((\(-\(5\/4\)\) + #2)\)\^2\)\/\(\((\(\(57.92742446507327`\)\(\
\[InvisibleSpace]\)\) + #1)\)\ \((1 + \
8.513651950746305`*^7\/\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2)\)\) - \(0.6400004724200351`\ \((\(-\(5\/4\)\) + #2)\)\^2\)\/\(1 + \
1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2\)\)\)\/\((1 + 1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\
\[InvisibleSpace]\)\) + #1)\)\^2)\)\^\(1/4\) + \(0.79894172846783`\ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \((\(-ArcTan[0.00010837823004787182`\ \
\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)]\) + \
11810.498697705989`\ #1)\) - \(5905.249348852994`\ \[ImaginaryI]\ #2\^2\)\/\(\
\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)\ \((1 + \
8.513651950746305`*^7\/\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2)\)\) - \(0.6400004724200351`\ #2\^2\)\/\(1 + 1.1745840748309428`*^-8\
\ \((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)\^2\)\)\)\/\((1 + \
1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2)\)\^\(1/4\) + \(0.7989417284678298`\ \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ \((\(-ArcTan[0.00010837823004787182`\ \
\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)]\) + \
11810.498697705989`\ #1)\) - \(5905.249348852994`\ \[ImaginaryI]\ \((5\/4 + \
#2)\)\^2\)\/\(\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)\ \
\((1 + 8.513651950746305`*^7\/\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\
\) + #1)\)\^2)\)\) - \(0.6400004724200351`\ \((5\/4 + #2)\)\^2\)\/\(1 + \
1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2\)\)\)\/\((1 + 1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\
\[InvisibleSpace]\)\) + #1)\)\^2)\)\^\(1/4\) + \(0.79894172846783`\ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \((\(-ArcTan[0.00010837823004787182`\ \
\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)]\) + \
11810.498697705989`\ #1)\) - \(5905.249348852994`\ \[ImaginaryI]\ \((5\/2 + \
#2)\)\^2\)\/\(\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)\ \
\((1 + 8.513651950746305`*^7\/\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\
\) + #1)\)\^2)\)\) - \(0.6400004724200351`\ \((5\/2 + #2)\)\^2\)\/\(1 + \
1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2\)\)\)\/\((1 + 1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\
\[InvisibleSpace]\)\) + #1)\)\^2)\)\^\(1/4\) + \(0.79894172846783`\ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \((\(-ArcTan[0.00010837823004787182`\ \
\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)]\) + \
11810.498697705989`\ #1)\) - \(5905.249348852994`\ \[ImaginaryI]\ \((15\/4 + \
#2)\)\^2\)\/\(\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)\ \
\((1 + 8.513651950746305`*^7\/\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\
\) + #1)\)\^2)\)\) - \(0.6400004724200351`\ \((15\/4 + #2)\)\^2\)\/\(1 + \
1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2\)\)\)\/\((1 + 1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\
\[InvisibleSpace]\)\) + #1)\)\^2)\)\^\(1/4\) + \(0.79894172846783`\ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \((\(-ArcTan[0.00010837823004787182`\ \
\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)]\) + \
11810.498697705989`\ #1)\) - \(5905.249348852994`\ \[ImaginaryI]\ \((5 + \
#2)\)\^2\)\/\(\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + #1)\)\ \
\((1 + 8.513651950746305`*^7\/\((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\
\) + #1)\)\^2)\)\) - \(0.6400004724200351`\ \((5 + #2)\)\^2\)\/\(1 + \
1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\[InvisibleSpace]\)\) + \
#1)\)\^2\)\)\)\/\((1 + 1.1745840748309428`*^-8\ \((\(\(57.92742446507327`\)\(\
\[InvisibleSpace]\)\) + #1)\)\^2)\)\^\(1/4\)]^2, "-CompiledCode-"]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[48]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[intensity[0,y],{y,-15,15},PlotRange->All];", "Input",
  CellLabel->"In[49]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0.0147151 6.08521 [
[.02381 .00222 -9 -9 ]
[.02381 .00222 9 0 ]
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.4875 .13642 -24 -4.5 ]
[.4875 .13642 0 4.5 ]
[.4875 .25812 -24 -4.5 ]
[.4875 .25812 0 4.5 ]
[.4875 .37983 -24 -4.5 ]
[.4875 .37983 0 4.5 ]
[.4875 .50153 -24 -4.5 ]
[.4875 .50153 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-15)] .02381 .00222 0 1 Mshowa
.18254 .01472 m
.18254 .02097 L
s
[(-10)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(-5)] .34127 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(5)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(10)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(15)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13642 m
.50625 .13642 L
s
[(0.02)] .4875 .13642 1 0 Mshowa
.5 .25812 m
.50625 .25812 L
s
[(0.04)] .4875 .25812 1 0 Mshowa
.5 .37983 m
.50625 .37983 L
s
[(0.06)] .4875 .37983 1 0 Mshowa
.5 .50153 m
.50625 .50153 L
s
[(0.08)] .4875 .50153 1 0 Mshowa
.125 Mabswid
.5 .04514 m
.50375 .04514 L
s
.5 .07557 m
.50375 .07557 L
s
.5 .10599 m
.50375 .10599 L
s
.5 .16685 m
.50375 .16685 L
s
.5 .19727 m
.50375 .19727 L
s
.5 .2277 m
.50375 .2277 L
s
.5 .28855 m
.50375 .28855 L
s
.5 .31898 m
.50375 .31898 L
s
.5 .3494 m
.50375 .3494 L
s
.5 .41025 m
.50375 .41025 L
s
.5 .44068 m
.50375 .44068 L
s
.5 .47111 m
.50375 .47111 L
s
.5 .53196 m
.50375 .53196 L
s
.5 .56238 m
.50375 .56238 L
s
.5 .59281 m
.50375 .59281 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04588 .01472 L
.04652 .01472 L
.04722 .01472 L
.04797 .01472 L
.04862 .01472 L
.04933 .01472 L
.05061 .01472 L
.05186 .01472 L
.05302 .01472 L
.05414 .01472 L
.05519 .01472 L
.05634 .01472 L
.05759 .01472 L
.05882 .01472 L
.06012 .01472 L
.06123 .01472 L
.06244 .01472 L
.06315 .01472 L
.06381 .01472 L
.06453 .01472 L
.06529 .01472 L
.06657 .01472 L
.06729 .01472 L
.06797 .01472 L
.06924 .01472 L
.0704 .01472 L
.07103 .01472 L
.07173 .01472 L
.073 .01472 L
Mistroke
.07376 .01472 L
.07448 .01472 L
.07513 .01472 L
.07583 .01472 L
.0766 .01472 L
.0774 .01472 L
.07809 .01472 L
.07885 .01472 L
.07956 .01472 L
.0802 .01472 L
.08095 .01472 L
.08166 .01472 L
.08291 .01472 L
.08362 .01472 L
.08427 .01472 L
.08544 .01472 L
.08669 .01472 L
.08787 .01472 L
.08896 .01472 L
.09016 .01472 L
.09148 .01472 L
.09214 .01472 L
.09285 .01472 L
.09413 .01472 L
.09483 .01472 L
.09548 .01472 L
.09619 .01472 L
.09695 .01472 L
.09821 .01472 L
.09893 .01472 L
.09961 .01472 L
.10086 .01472 L
.10201 .01472 L
.10333 .01472 L
.10458 .01472 L
.10572 .01472 L
.10694 .01472 L
.1081 .01472 L
.10916 .01472 L
.11033 .01472 L
.11162 .01472 L
.11227 .01472 L
.11297 .01472 L
.11422 .01472 L
.11491 .01472 L
.11554 .01472 L
.11624 .01472 L
.11698 .01472 L
.11822 .01472 L
.11892 .01472 L
Mistroke
.11958 .01472 L
.12081 .01472 L
.12194 .01472 L
.12323 .01472 L
.12446 .01472 L
.12562 .01472 L
.12668 .01472 L
.12789 .01472 L
.12903 .01472 L
.13009 .01472 L
.13107 .01472 L
.13214 .01472 L
.13327 .01472 L
.13441 .01472 L
.13564 .01472 L
.1368 .01472 L
.13785 .01472 L
.13909 .01472 L
.13979 .01472 L
.14043 .01472 L
.14162 .01472 L
.14288 .01472 L
.14402 .01472 L
.14526 .01472 L
.14656 .01472 L
.14777 .01472 L
.14891 .01472 L
.14994 .01472 L
.15113 .01472 L
.15226 .01472 L
.15348 .01472 L
.15478 .01472 L
.15589 .01472 L
.15711 .01472 L
.15842 .01472 L
.15915 .01472 L
.15982 .01472 L
.16113 .01472 L
.16236 .01472 L
.16352 .01472 L
.16456 .01472 L
.16577 .01472 L
.1669 .01472 L
.16796 .01472 L
.16893 .01472 L
.16999 .01472 L
.17111 .01472 L
.17225 .01472 L
.17347 .01472 L
.17462 .01472 L
Mistroke
.17566 .01472 L
.17689 .01472 L
.17758 .01472 L
.17823 .01472 L
.1794 .01472 L
.18065 .01472 L
.18185 .01472 L
.18316 .01472 L
.18441 .01472 L
.18556 .01472 L
.1867 .01472 L
.18773 .01472 L
.18893 .01472 L
.19005 .01472 L
.19128 .01472 L
.19258 .01472 L
.19369 .01472 L
.19491 .01472 L
.19623 .01472 L
.19696 .01472 L
.19763 .01472 L
.19894 .01472 L
.20017 .01472 L
.20122 .01472 L
.20238 .01472 L
.20359 .01472 L
.20472 .01472 L
.20578 .01472 L
.20675 .01472 L
.20781 .01472 L
.20894 .01472 L
.21008 .01472 L
.21129 .01472 L
.21244 .01472 L
.21349 .01472 L
.21472 .01472 L
.21541 .01472 L
.21605 .01472 L
.21723 .01472 L
.21847 .01472 L
.21968 .01472 L
.221 .01472 L
.22224 .01472 L
.2234 .01472 L
.22454 .01472 L
.22558 .01472 L
.22677 .01472 L
.2279 .01472 L
.22914 .01472 L
.23044 .01472 L
Mistroke
.23155 .01472 L
.23277 .01472 L
.23409 .01472 L
.23482 .01472 L
.2355 .01472 L
.2368 .01472 L
.23804 .01472 L
.23909 .01472 L
.24025 .01472 L
.24146 .01472 L
.2426 .01472 L
.24365 .01472 L
.24462 .01472 L
.24569 .01472 L
.24681 .01472 L
.24795 .01472 L
.24917 .01472 L
.25032 .01472 L
.25137 .01472 L
.2526 .01472 L
.25393 .01473 L
.25519 .01473 L
.25635 .01474 L
.2576 .01474 L
.25879 .01475 L
.26103 .01477 L
.26228 .01478 L
.26344 .0148 L
.26471 .01483 L
.26606 .01486 L
.26713 .01489 L
.26828 .01494 L
.27037 .01504 L
.27158 .01512 L
.27286 .01522 L
.27514 .01546 L
.27643 .01564 L
.2776 .01584 L
.27887 .01609 L
.28024 .01642 L
.28268 .0172 L
.28499 .01822 L
.28772 .01987 L
.29061 .02233 L
.29307 .02517 L
.29579 .02929 L
.29827 .03417 L
.30099 .04094 L
.30593 .05799 L
.31074 .08156 L
Mistroke
.3152 .11038 L
.32531 .19971 L
.33608 .31791 L
.34637 .42611 L
.35178 .47329 L
.3575 .51359 L
.36251 .54086 L
.36801 .56302 L
.37042 .57051 L
.37301 .57724 L
.37767 .58648 L
.38024 .59023 L
.38296 .59339 L
.38528 .59551 L
.38785 .59735 L
.3906 .59886 L
.39356 .60006 L
.39636 .60089 L
.39892 .60146 L
.40135 .60188 L
.4036 .60219 L
.40628 .60249 L
.40872 .60271 L
.41112 .60288 L
.41371 .60303 L
.41514 .60309 L
.41645 .60314 L
.41778 .60318 L
.41904 .60321 L
.42021 .60323 L
.42149 .60325 L
.42264 .60325 L
.42372 .60325 L
.42499 .60325 L
.42615 .60324 L
.42679 .60323 L
.42748 .60323 L
.42874 .60321 L
.43307 .60314 L
.43536 .60311 L
.43664 .60309 L
.43781 .60308 L
.43848 .60308 L
.4392 .60307 L
.44052 .60307 L
.44183 .60308 L
.44305 .60308 L
.44432 .6031 L
.44573 .60311 L
.44857 .60316 L
Mistroke
.45329 .60325 L
.45459 .60327 L
.45597 .60329 L
.45727 .6033 L
.45845 .60331 L
.45974 .60332 L
.46046 .60332 L
.46112 .60332 L
.46235 .60331 L
.46364 .6033 L
.46486 .60329 L
.46599 .60327 L
.46858 .60323 L
.47085 .60319 L
.47333 .60314 L
.47447 .60312 L
.47568 .60311 L
.47672 .60309 L
.47784 .60308 L
.47913 .60308 L
.48035 .60308 L
.48105 .60308 L
.48179 .60308 L
.48311 .60309 L
.4843 .6031 L
.4854 .60312 L
.48791 .60316 L
.4931 .60325 L
.49451 .60328 L
.49602 .6033 L
.4973 .60331 L
.49803 .60331 L
.49872 .60332 L
.49936 .60332 L
.50007 .60332 L
.50136 .60332 L
.50262 .60331 L
.50378 .6033 L
.50516 .60328 L
.50642 .60326 L
.50923 .60321 L
.51155 .60317 L
.514 .60312 L
.51528 .60311 L
.51596 .6031 L
.51668 .60309 L
.51796 .60308 L
.51915 .60308 L
.52039 .60308 L
.52108 .60308 L
Mistroke
.52173 .60308 L
.52291 .60309 L
.52416 .6031 L
.52633 .60313 L
.52873 .60318 L
.53303 .60326 L
.53421 .60328 L
.53547 .60329 L
.53666 .60331 L
.53774 .60331 L
.53895 .60332 L
.54027 .60332 L
.54151 .60331 L
.54266 .60331 L
.54386 .60329 L
.54518 .60328 L
.54784 .60323 L
.55033 .60318 L
.55268 .60314 L
.5548 .60311 L
.556 .60309 L
.5571 .60308 L
.55843 .60308 L
.55962 .60307 L
.56029 .60307 L
.561 .60308 L
.5623 .60308 L
.56298 .60309 L
.56372 .6031 L
.56521 .60311 L
.56789 .60315 L
.57041 .6032 L
.57179 .60322 L
.5731 .60323 L
.57433 .60324 L
.57501 .60325 L
.57565 .60325 L
.57677 .60325 L
.57797 .60325 L
.57917 .60324 L
.58049 .60322 L
.58173 .60319 L
.58288 .60316 L
.58506 .60308 L
.58738 .60297 L
.59011 .60279 L
.59268 .60259 L
.59502 .60235 L
.5975 .60205 L
.59968 .60171 L
Mistroke
.60208 .60125 L
.60629 .60011 L
.60866 .59919 L
.61121 .59792 L
.61361 .59636 L
.6158 .59458 L
.6206 .58909 L
.62303 .5853 L
.62571 .58013 L
.63044 .56798 L
.63488 .55232 L
.64009 .52761 L
.64487 .4981 L
.65564 .40656 L
.66556 .29946 L
.67616 .18489 L
.68131 .13766 L
.68617 .10082 L
.69053 .07463 L
.69526 .05329 L
.69984 .0387 L
.70245 .03263 L
.70489 .02815 L
.70745 .02449 L
.7098 .02193 L
.71251 .01971 L
.71508 .01818 L
.71728 .01722 L
.71962 .01646 L
.72183 .01595 L
.72383 .0156 L
.72619 .01531 L
.72752 .01519 L
.72874 .01509 L
.73099 .01497 L
.73212 .01492 L
.73336 .01488 L
.73458 .01484 L
.73588 .01481 L
.7373 .01479 L
.73862 .01477 L
.73976 .01476 L
.74098 .01475 L
.74233 .01474 L
.74359 .01474 L
.74472 .01473 L
.74596 .01473 L
.74725 .01472 L
.74845 .01472 L
.74958 .01472 L
Mistroke
.75061 .01472 L
.75179 .01472 L
.75291 .01472 L
.75412 .01472 L
.75545 .01472 L
.75684 .01472 L
.75814 .01472 L
.75935 .01472 L
.76046 .01472 L
.76174 .01472 L
.76295 .01472 L
.76426 .01472 L
.76566 .01472 L
.76685 .01472 L
.76816 .01472 L
.7689 .01472 L
.76957 .01472 L
.77029 .01472 L
.77109 .01472 L
.77242 .01472 L
.77315 .01472 L
.77383 .01472 L
.7751 .01472 L
.77575 .01472 L
.77645 .01472 L
.7777 .01472 L
.77887 .01472 L
.77958 .01472 L
.78025 .01472 L
.7815 .01472 L
.78221 .01472 L
.78286 .01472 L
.78357 .01472 L
.78434 .01472 L
.78563 .01472 L
.78686 .01472 L
.78805 .01472 L
.78914 .01472 L
.79033 .01472 L
.79163 .01472 L
.79229 .01472 L
.79299 .01472 L
.79426 .01472 L
.7955 .01472 L
.79665 .01472 L
.79791 .01472 L
.79855 .01472 L
.79925 .01472 L
.80043 .01472 L
.80169 .01472 L
Mistroke
.80289 .01472 L
.80398 .01472 L
.80505 .01472 L
.80604 .01472 L
.80713 .01472 L
.8083 .01472 L
.80952 .01472 L
.81068 .01472 L
.81172 .01472 L
.81284 .01472 L
.81407 .01472 L
.8152 .01472 L
.8165 .01472 L
.81774 .01472 L
.81887 .01472 L
.81993 .01472 L
.82108 .01472 L
.82231 .01472 L
.82302 .01472 L
.82367 .01472 L
.82438 .01472 L
.82513 .01472 L
.82639 .01472 L
.82711 .01472 L
.82778 .01472 L
.82903 .01472 L
.83017 .01472 L
.83148 .01472 L
.83273 .01472 L
.83394 .01472 L
.83463 .01472 L
.83527 .01472 L
.83657 .01472 L
.8373 .01472 L
.83797 .01472 L
.83916 .01472 L
.84046 .01472 L
.84168 .01472 L
.84282 .01472 L
.84351 .01472 L
.84425 .01472 L
.84495 .01472 L
.8456 .01472 L
.84682 .01472 L
.84812 .01472 L
.84879 .01472 L
.84951 .01472 L
.85082 .01472 L
.85161 .01472 L
.85236 .01472 L
Mistroke
.85304 .01472 L
.85378 .01472 L
.85499 .01472 L
.85611 .01472 L
.85733 .01472 L
.85862 .01472 L
.85974 .01472 L
.86079 .01472 L
.86194 .01472 L
.86317 .01472 L
.86386 .01472 L
.86451 .01472 L
.86521 .01472 L
.86596 .01472 L
.86722 .01472 L
.86793 .01472 L
.8686 .01472 L
.86984 .01472 L
.87098 .01472 L
.87229 .01472 L
.87354 .01472 L
.87422 .01472 L
.87486 .01472 L
.87606 .01472 L
.87735 .01472 L
.87808 .01472 L
.87875 .01472 L
.87987 .01472 L
.8811 .01472 L
.88239 .01472 L
.88358 .01472 L
.88427 .01472 L
.88501 .01472 L
.88571 .01472 L
.88635 .01472 L
.88758 .01472 L
.88887 .01472 L
.88954 .01472 L
.89026 .01472 L
.89157 .01472 L
.89232 .01472 L
.89312 .01472 L
.8938 .01472 L
.89454 .01472 L
.89518 .01472 L
.89586 .01472 L
.89708 .01472 L
.89839 .01472 L
.89914 .01472 L
.89984 .01472 L
Mistroke
.9011 .01472 L
.90225 .01472 L
.90288 .01472 L
.90357 .01472 L
.90483 .01472 L
.90595 .01472 L
.90718 .01472 L
.90847 .01472 L
.90968 .01472 L
.91081 .01472 L
.91184 .01472 L
.91298 .01472 L
.91418 .01472 L
.91549 .01472 L
.91668 .01472 L
.91734 .01472 L
.91806 .01472 L
.91936 .01472 L
.92057 .01472 L
.92186 .01472 L
.92297 .01472 L
.92418 .01472 L
.92491 .01472 L
.9256 .01472 L
.92691 .01472 L
.92763 .01472 L
.92831 .01472 L
.92905 .01472 L
.92984 .01472 L
.93052 .01472 L
.93127 .01472 L
.93197 .01472 L
.93262 .01472 L
.93384 .01472 L
.93514 .01472 L
.93636 .01472 L
.93705 .01472 L
.93768 .01472 L
.93885 .01472 L
.94009 .01472 L
.9412 .01472 L
.94224 .01472 L
.94339 .01472 L
.94462 .01472 L
.94585 .01472 L
.94655 .01472 L
.9472 .01472 L
.94851 .01472 L
.94925 .01472 L
.94992 .01472 L
Mistroke
.95112 .01472 L
.95242 .01472 L
.95364 .01472 L
.95478 .01472 L
.95583 .01472 L
.95697 .01472 L
.95804 .01472 L
.95902 .01472 L
.96016 .01472 L
.96141 .01472 L
.96259 .01472 L
.96368 .01472 L
.96492 .01472 L
.96608 .01472 L
.96712 .01472 L
.96825 .01472 L
.96948 .01472 L
.97078 .01472 L
.97189 .01472 L
.97311 .01472 L
.97389 .01472 L
.9746 .01472 L
.97542 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[49]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`003?ooool3o`0000?ooooo0ol0000Sooooo`?o00001?ooool2o`0002Gooooo0ol0001Aoooo
o`?o00009Oooool3o`0000Cooooo0_l0000Rooooo`?o00000oooool3o`0000[ooooo000=ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000004oooooo00Go
0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01oooool000Go
oooo1Ol00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool5o`0000?o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Mooooo`Go00001Oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Rooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool000gooooo00Co0000oooooooooooooooo1?l0
000Tooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool4o`00053ooooo
1?l0000Vooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008_ooool01?l0003o
ooooooooooooool4o`0000[ooooo000<ooooo`;o00000oooool00ol0003oooooooooo`0Tooooo`;o
00001?ooool01?l0003oooooooooool0000Sooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool09_ooool2o`0000Cooooo00Co0000oooooooooooo00008Oooool2o`0000?ooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooooooo1Ol0000Sooooo`03o`000?oooooo
oooo00?ooooo0_l0000Tooooo`Go0000Coooool5o`0002Gooooo00?o0000ooooooooool00oooool2
o`0002?ooooo00Co0000oooooooooooooooo1Ol00009ooooo`00T?ooool00ol0003oooooooooo`2=
ooooo`00T?ooool00ol0003oooooooooo`2=ooooo`00T?ooool00ol0003oooooooooo`2=ooooo`00
T?ooool00ol0003oooooooooo`2=ooooo`002?ooooooo`0001?o00001_ooool000kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`?o00001Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`Co00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo000>oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0;oooo
o`00F?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0E?ooool005Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo05Gooooo001Iooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`1Fooooo`00FOooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0E_ooool005[ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo05Kooooo001Jooooo`03o`000?oooooooooo03?o
oooo0_l0000eooooo`03o`000?oooooooooo05Kooooo001Jooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Gooooo`00Foooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0Eoooool005_ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo05Oooooo001Koooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1Hoooo
o`00Foooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0F?ooool005cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo05Sooooo001Looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`1Iooooo`00G?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0FOooool005gooooo00?o0000ooooooooool0<?ooool2o`00
03;ooooo00?o0000ooooooooool0FOooool005gooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo05Wooooo001Mooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Iooooo`00GOooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0F_ooool005gooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05[ooooo001Moooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Joooo
o`00G_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0F_ooool005kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo05[ooooo001Nooooo`03o`000?oooooooooo02oooooo0_l0000aooooo`03o`000?oo
oooooooo05[ooooo001Nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`1Jooooo`00G_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0F_ooool005kooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo05[ooooo001Nooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Kooooo`00G_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Foooool005oooooo00?o0000
ooooooooool05Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00004
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Foooool005oooooo00?o0000oooo
ooooool05?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05_ooooo
001Oooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00Cooooo0ol0000_ooooo`03o`000?oooooooooo05_o
oooo001Oooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`1Kooooo`00Goooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`1Kooooo`00Goooool00ol0003oooooooooo`0D
ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Kooooo`00
Goooool00ol0003oooooooooo`0Eooooo`;o00002_ooool2o`0000?ooooo0ol00005ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0G?ooool005oooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05cooooo001Pooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Looooo`00H?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0G?ooool0063o
oooo00?o0000ooooooooool0;Oooool2o`0002oooooo00?o0000ooooooooool0G?ooool0063ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05cooooo
001Pooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`1Looooo`00H?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0GOooool0063ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo05gooooo001Pooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`1Mooooo`00HOooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0GOooool0067ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05gooooo001Qooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Mooooo`00HOooool00ol0
003oooooooooo`0/ooooo`;o0000;_ooool00ol0003oooooooooo`1Mooooo`00HOooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0GOooool0067ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05kooooo
001Qooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`1Nooooo`00HOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0G_ooool0067ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo05kooooo001Rooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`1Nooooo`00H_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0G_ooool006;ooooo00?o0000ooooooooool0:ooo
ool2o`0002gooooo00?o0000ooooooooool0G_ooool006;ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05kooooo001Rooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Nooooo`00H_ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0G_ooool006;ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05kooooo
001Rooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1Oooooo`00H_ooool00ol0003oooooooooo`0Booooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00001?ooool3o`0000Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1O
ooooo`00H_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0Goooool006;ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0
0008ooooo`05o`000?ooooooooooo`000?ooool01Ol00004ooooo`?o0000:oooool00ol0003ooooo
ooooo`1Oooooo`00Hoooool00ol0003oooooooooo`0@ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`1Oooooo`00Hoooool00ol0003oooooooooo`0@ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Goooool006?ooooo00?o0000oooo
ooooool04?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l0
0005ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Goooool006?ooooo00?o0000
ooooooooool04Oooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`1Oooooo`00Hoooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Goooool006?ooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo05oooooo001Sooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Oooooo`00Hooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0H?oo
ool006?ooooo00?o0000ooooooooool0:_ooool2o`0002_ooooo00?o0000ooooooooool0H?ooool0
06?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
063ooooo001Sooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`1Pooooo`00I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0H?ooool006Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo063ooooo001Tooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`1Pooooo`00I?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0H?ooool006Cooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo063ooooo001Tooooo`03o`00
0?oooooooooo02Wooooo0_l0000[ooooo`03o`000?oooooooooo063ooooo001Tooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Pooooo`00I?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0H?ooool0
06Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
067ooooo001Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`1Qooooo`00I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0HOooool006Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo067ooooo001Tooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`1Qooooo`00IOooool00ol0003oooooooooo`0Xoooo
o`;o0000:_ooool00ol0003oooooooooo`1Qooooo`00IOooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0HOooool006Gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo067ooooo001Uooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Qooooo`00IOooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0HOooool0
06Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
067ooooo001Uooooo`03o`000?oooooooooo00oooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo067o
oooo001Uooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo067ooooo001Uooooo`03o`000?oooooooooo00kooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo067ooooo001Uooooo`03o`000?oo
oooooooo00kooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co
00001Oooool3o`0002Wooooo00?o0000ooooooooool0HOooool006Gooooo00?o0000ooooooooool0
3_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06;ooooo001Uooooo`03o`000?oooooooooo
00kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Rooooo`00IOooool0
0ol0003oooooooooo`0?ooooo`;o00002_ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0H_ooool006Gooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo06;ooooo001Uooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Rooooo`00I_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0H_ooool006Kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06;ooooo001V
ooooo`03o`000?oooooooooo02Oooooo0_l0000Yooooo`03o`000?oooooooooo06;ooooo001Voooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Roooo
o`00I_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0H_ooool006Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo06;ooooo001Vooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`1Sooooo`00I_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0Hoooool006Kooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06?ooooo001Vooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Sooooo`00Ioooool00ol0003ooooo
ooooo`0Vooooo`;o0000:?ooool00ol0003oooooooooo`1Sooooo`00Ioooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Hoooool006Oooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06?ooooo001Woooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Soooo
o`00Ioooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0I?ooool006Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo06Cooooo001Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`1Tooooo`00J?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0I?ooool006Sooooo00?o0000ooooooooool09Oooool2o`00
02Oooooo00?o0000ooooooooool0I?ooool006Sooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo06Cooooo001Xooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Tooooo`00J?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0I?ooool006Sooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06Cooooo001Xoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Uoooo
o`00J?ooool00ol0003oooooooooo`0<ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o
00000oooool3o`0000Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Uooooo`00
JOooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1Uooooo`00JOooool00ol0003oooooooooo`0:ooooo`04o`000?oooooooooo
o`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Uooooo`00JOooool00ol0003ooooooooo
o`0:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool3o`0000Go
oooo0ol0000Uooooo`03o`000?oooooooooo06Gooooo001Yooooo`03o`000?oooooooooo00[ooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Gooooo001Yoooo
o`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo06Kooooo001Yooooo`03o`000?oooooooooo00_ooooo0_l0000:ooooo`;o00000ooo
ool3o`0000Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Vooooo`00JOooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0I_ooool0
06Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
06Kooooo001Zooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1Wooooo`00J_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0Ioooool006[ooooo00?o0000ooooooooool08oooool2o`0002Cooooo00?o
0000ooooooooool0Ioooool006_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo06Oooooo001[ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Wooooo`00Joooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0J?ooool006_ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06Sooooo001[ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Xooooo`00K?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0J?ooool0
06cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
06Sooooo001/ooooo`03o`000?oooooooooo027ooooo0_l0000Sooooo`03o`000?oooooooooo06So
oooo001/ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`1Yooooo`00KOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0JOooool006gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo06Wooooo001^ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`1Zooooo`00K_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0J_ooool006oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06[ooooo001_ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1[ooooo`00L?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0K?ooool0
073ooooo0_l0000Nooooo`;o00007_ooool00ol0003oooooooooo`1]ooooo`00L_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo0_l0001`ooooo`00Looooolko`0007;ooooo
002@ooooo`03o`000?oooooooooo08gooooo002@ooooo`03o`000?oooooooooo08gooooo002@oooo
o`03o`000?oooooooooo08gooooo002@ooooo`03o`000?oooooooooo08gooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-16.7203, -0.00747725, \
0.115509, 0.000602598}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot3D[intensity[x,y],{x,0,50},{y,-15,15},PlotRange->All,PlotPoints->50];\
\>", "Input",
  CellLabel->"In[50]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.2768e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -11.924 -9 ]
[.14598 .19958 .07603 0 ]
[.27013 .15073 -11.4236 -9 ]
[.27013 .15073 .57641 0 ]
[.40046 .09948 -10.9232 -9 ]
[.40046 .09948 1.07679 0 ]
[.53743 .04564 -10.4228 -9 ]
[.53743 .04564 1.57717 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 18 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 12 3.0917 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01539 .31978 -30 -2.78854 ]
[.01539 .31978 0 6.21146 ]
[.00635 .37643 -24 -2.83661 ]
[.00635 .37643 0 6.16339 ]
[-0.00302 .43516 -30 -2.88664 ]
[-0.00302 .43516 0 6.11336 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(10)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(20)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(30)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(40)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(50)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06033 .24606 m
.06319 .24877 L
s
.08372 .23691 m
.08655 .23964 L
s
.10732 .22766 m
.11013 .23042 L
s
.13115 .21833 m
.13394 .22111 L
s
.17948 .19941 m
.18222 .20223 L
s
.20399 .18981 m
.2067 .19266 L
s
.22873 .18012 m
.23142 .183 L
s
.25371 .17034 m
.25638 .17324 L
s
.3044 .15049 m
.30701 .15344 L
s
.33011 .14043 m
.3327 .14339 L
s
.35608 .13026 m
.35864 .13325 L
s
.3823 .11999 m
.38483 .12301 L
s
.43553 .09915 m
.43799 .10222 L
s
.46254 .08857 m
.46497 .09167 L
s
.48982 .07789 m
.49222 .08101 L
s
.51738 .0671 m
.51975 .07024 L
s
.57333 .04519 m
.57563 .04838 L
s
.60174 .03407 m
.60401 .03728 L
s
.63044 .02283 m
.63267 .02607 L
s
.65944 .01147 m
.66163 .01474 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-10)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(10)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.76562 .11761 m
.76192 .11896 L
s
.78611 .14895 m
.78241 .15028 L
s
.806 .17938 m
.80229 .18068 L
s
.82531 .20892 m
.82159 .2102 L
s
.86231 .2655 m
.85857 .26675 L
s
.88003 .29262 m
.87629 .29385 L
s
.89727 .31899 m
.89353 .3202 L
s
.91405 .34465 m
.9103 .34584 L
s
.72272 .05198 m
.71904 .05338 L
s
.70024 .0176 m
.69657 .01902 L
s
.94627 .39394 m
.94251 .3951 L
s
.96176 .41762 m
.95799 .41877 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02766 .31512 m
.03379 .31278 L
s
[(0.025)] .01539 .31978 1 -0.38032 Mshowa
.01866 .37188 m
.02481 .3696 L
s
[(0.05)] .00635 .37643 1 -0.36964 Mshowa
.00933 .43073 m
.01551 .42852 L
s
[(0.075)] -0.00302 .43516 1 -0.35853 Mshowa
.125 Mabswid
.03462 .27114 m
.03829 .26971 L
s
.0329 .28202 m
.03657 .2806 L
s
.03116 .29297 m
.03484 .29156 L
s
.02942 .304 m
.03309 .3026 L
s
.02588 .32631 m
.02956 .32491 L
s
.0241 .33758 m
.02778 .33619 L
s
.0223 .34893 m
.02598 .34755 L
s
.02049 .36036 m
.02417 .35899 L
s
.01682 .38348 m
.02052 .38212 L
s
.01497 .39516 m
.01867 .39381 L
s
.0131 .40693 m
.01681 .40559 L
s
.01123 .41879 m
.01493 .41745 L
s
.00743 .44277 m
.01113 .44144 L
s
.00551 .45489 m
.00922 .45357 L
s
.00357 .4671 m
.00728 .46579 L
s
.00162 .4794 m
.00534 .4781 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.39889 .59791 .40512 .60371 .41558 .60058 .40937 .59475 Metetra
.664 .741 .908 r
.40937 .59475 .41558 .60058 .42607 .59743 .41989 .59158 Metetra
.664 .741 .908 r
.41989 .59158 .42607 .59743 .4366 .59427 .43045 .5884 Metetra
.664 .741 .908 r
.43045 .5884 .4366 .59427 .44718 .59109 .44106 .5852 Metetra
.664 .741 .908 r
.44106 .5852 .44718 .59109 .4578 .58791 .4517 .582 Metetra
.664 .741 .908 r
.4517 .582 .4578 .58791 .46846 .58471 .46239 .57878 Metetra
.664 .741 .908 r
.46239 .57878 .46846 .58471 .47916 .5815 .47312 .57554 Metetra
.664 .741 .908 r
.47312 .57554 .47916 .5815 .4899 .57828 .48389 .57229 Metetra
.664 .741 .908 r
.48389 .57229 .4899 .57828 .50069 .57504 .4947 .56904 Metetra
.664 .741 .908 r
.4947 .56904 .50069 .57504 .51152 .57179 .50556 .56576 Metetra
.664 .741 .908 r
.50556 .56576 .51152 .57179 .52239 .56853 .51646 .56248 Metetra
.664 .741 .908 r
.51646 .56248 .52239 .56853 .5333 .56526 .5274 .55918 Metetra
.664 .741 .908 r
.5274 .55918 .5333 .56526 .54426 .56197 .53839 .55587 Metetra
.664 .741 .908 r
.53839 .55587 .54426 .56197 .55526 .55867 .54942 .55254 Metetra
.664 .741 .908 r
.54942 .55254 .55526 .55867 .56631 .55536 .56049 .5492 Metetra
.664 .741 .908 r
.56049 .5492 .56631 .55536 .5774 .55203 .57161 .54585 Metetra
.664 .741 .908 r
.57161 .54585 .5774 .55203 .58853 .54869 .58277 .54249 Metetra
.664 .741 .908 r
.58277 .54249 .58853 .54869 .59971 .54534 .59398 .53911 Metetra
.664 .741 .908 r
.59398 .53911 .59971 .54534 .61094 .54197 .60524 .53572 Metetra
.664 .741 .908 r
.60524 .53572 .61094 .54197 .62221 .53859 .61654 .53231 Metetra
.664 .741 .908 r
.61654 .53231 .62221 .53859 .63352 .53519 .62788 .52889 Metetra
.664 .741 .908 r
.62788 .52889 .63352 .53519 .64488 .53178 .63928 .52546 Metetra
.664 .741 .908 r
.63928 .52546 .64488 .53178 .65629 .52836 .65071 .52201 Metetra
.664 .741 .908 r
.65071 .52201 .65629 .52836 .66774 .52493 .6622 .51855 Metetra
.664 .741 .908 r
.6622 .51855 .66774 .52493 .67924 .52148 .67373 .51507 Metetra
.664 .741 .908 r
.67373 .51507 .67924 .52148 .69079 .51801 .68531 .51158 Metetra
.664 .741 .908 r
.68531 .51158 .69079 .51801 .70238 .51453 .69694 .50808 Metetra
.664 .741 .908 r
.69694 .50808 .70238 .51453 .71403 .51104 .70861 .50456 Metetra
.664 .741 .908 r
.70861 .50456 .71403 .51104 .72572 .50753 .72034 .50102 Metetra
.664 .741 .908 r
.72034 .50102 .72572 .50753 .73745 .50401 .73211 .49747 Metetra
.664 .741 .908 r
.73211 .49747 .73745 .50401 .74924 .50048 .74393 .49391 Metetra
.664 .741 .908 r
.74393 .49391 .74924 .50048 .76108 .49693 .7558 .49033 Metetra
.664 .741 .908 r
.7558 .49033 .76108 .49693 .77296 .49336 .76772 .48674 Metetra
.664 .741 .908 r
.76772 .48674 .77296 .49336 .78489 .48978 .77968 .48313 Metetra
.664 .741 .908 r
.77968 .48313 .78489 .48978 .79688 .48619 .7917 .47951 Metetra
.664 .741 .908 r
.7917 .47951 .79688 .48619 .80891 .48258 .80377 .47587 Metetra
.664 .741 .908 r
.80377 .47587 .80891 .48258 .82099 .47895 .81589 .47222 Metetra
.664 .741 .908 r
.81589 .47222 .82099 .47895 .83313 .47531 .82806 .46855 Metetra
.664 .741 .908 r
.82806 .46855 .83313 .47531 .84531 .47166 .84028 .46487 Metetra
.664 .741 .908 r
.84028 .46487 .84531 .47166 .85755 .46799 .85256 .46117 Metetra
.664 .741 .908 r
.85256 .46117 .85755 .46799 .86983 .4643 .86488 .45745 Metetra
.664 .741 .908 r
.86488 .45745 .86983 .4643 .88217 .4606 .87726 .45372 Metetra
.664 .741 .908 r
.87726 .45372 .88217 .4606 .89457 .45688 .88969 .44998 Metetra
.664 .741 .908 r
.88969 .44998 .89457 .45688 .90701 .45315 .90217 .44621 Metetra
.664 .741 .908 r
.90217 .44621 .90701 .45315 .91951 .4494 .91471 .44243 Metetra
.664 .741 .908 r
.91471 .44243 .91951 .4494 .93206 .44563 .9273 .43864 Metetra
.664 .741 .908 r
.9273 .43864 .93206 .44563 .94466 .44185 .93994 .43483 Metetra
.664 .741 .908 r
.93994 .43483 .94466 .44185 .95732 .43805 .95264 .431 Metetra
.664 .741 .908 r
.95264 .431 .95732 .43805 .97003 .43424 .96539 .42716 Metetra
.664 .741 .908 r
.39262 .59207 .39889 .59791 .40937 .59475 .40313 .58889 Metetra
.664 .741 .908 r
.40313 .58889 .40937 .59475 .41989 .59158 .41367 .5857 Metetra
.664 .741 .908 r
.41367 .5857 .41989 .59158 .43045 .5884 .42426 .58249 Metetra
.664 .741 .908 r
.42426 .58249 .43045 .5884 .44106 .5852 .43489 .57927 Metetra
.664 .741 .908 r
.43489 .57927 .44106 .5852 .4517 .582 .44556 .57604 Metetra
.664 .741 .908 r
.44556 .57604 .4517 .582 .46239 .57878 .45627 .5728 Metetra
.664 .741 .908 r
.45627 .5728 .46239 .57878 .47312 .57554 .46703 .56954 Metetra
.664 .741 .908 r
.46703 .56954 .47312 .57554 .48389 .57229 .47782 .56627 Metetra
.664 .741 .908 r
.47782 .56627 .48389 .57229 .4947 .56904 .48867 .56298 Metetra
.664 .741 .908 r
.48867 .56298 .4947 .56904 .50556 .56576 .49955 .55969 Metetra
.664 .741 .908 r
.49955 .55969 .50556 .56576 .51646 .56248 .51048 .55638 Metetra
.664 .741 .908 r
.51048 .55638 .51646 .56248 .5274 .55918 .52145 .55305 Metetra
.664 .741 .908 r
.52145 .55305 .5274 .55918 .53839 .55587 .53246 .54972 Metetra
.664 .741 .908 r
.53246 .54972 .53839 .55587 .54942 .55254 .54352 .54637 Metetra
.664 .741 .908 r
.54352 .54637 .54942 .55254 .56049 .5492 .55463 .54301 Metetra
.664 .741 .908 r
.55463 .54301 .56049 .5492 .57161 .54585 .56578 .53963 Metetra
.664 .741 .908 r
.56578 .53963 .57161 .54585 .58277 .54249 .57697 .53624 Metetra
.664 .741 .908 r
.57697 .53624 .58277 .54249 .59398 .53911 .58821 .53284 Metetra
.664 .741 .908 r
.58821 .53284 .59398 .53911 .60524 .53572 .5995 .52942 Metetra
.664 .741 .908 r
.5995 .52942 .60524 .53572 .61654 .53231 .61083 .52599 Metetra
.664 .741 .908 r
.61083 .52599 .61654 .53231 .62788 .52889 .6222 .52254 Metetra
.664 .741 .908 r
.6222 .52254 .62788 .52889 .63928 .52546 .63363 .51908 Metetra
.664 .741 .908 r
.63363 .51908 .63928 .52546 .65071 .52201 .6451 .51561 Metetra
.664 .741 .908 r
.6451 .51561 .65071 .52201 .6622 .51855 .65661 .51212 Metetra
.664 .741 .908 r
.65661 .51212 .6622 .51855 .67373 .51507 .66818 .50862 Metetra
.664 .741 .908 r
.66818 .50862 .67373 .51507 .68531 .51158 .67979 .5051 Metetra
.664 .741 .908 r
.67979 .5051 .68531 .51158 .69694 .50808 .69145 .50157 Metetra
.664 .741 .908 r
.69145 .50157 .69694 .50808 .70861 .50456 .70316 .49802 Metetra
.664 .741 .908 r
.70316 .49802 .70861 .50456 .72034 .50102 .71492 .49446 Metetra
.664 .741 .908 r
.71492 .49446 .72034 .50102 .73211 .49747 .72672 .49089 Metetra
.664 .741 .908 r
.72672 .49089 .73211 .49747 .74393 .49391 .73858 .48729 Metetra
.664 .741 .908 r
.73858 .48729 .74393 .49391 .7558 .49033 .75048 .48369 Metetra
.664 .741 .908 r
.75048 .48369 .7558 .49033 .76772 .48674 .76243 .48007 Metetra
.664 .741 .908 r
.76243 .48007 .76772 .48674 .77968 .48313 .77444 .47643 Metetra
.664 .741 .908 r
.77444 .47643 .77968 .48313 .7917 .47951 .78649 .47278 Metetra
.664 .741 .908 r
.78649 .47278 .7917 .47951 .80377 .47587 .79859 .46912 Metetra
.664 .741 .908 r
.79859 .46912 .80377 .47587 .81589 .47222 .81075 .46544 Metetra
.664 .741 .908 r
.81075 .46544 .81589 .47222 .82806 .46855 .82296 .46174 Metetra
.664 .741 .908 r
.82296 .46174 .82806 .46855 .84028 .46487 .83522 .45803 Metetra
.664 .741 .908 r
.83522 .45803 .84028 .46487 .85256 .46117 .84753 .4543 Metetra
.664 .741 .908 r
.84753 .4543 .85256 .46117 .86488 .45745 .85989 .45055 Metetra
.664 .741 .908 r
.85989 .45055 .86488 .45745 .87726 .45372 .8723 .44679 Metetra
.664 .741 .908 r
.8723 .44679 .87726 .45372 .88969 .44998 .88477 .44302 Metetra
.664 .741 .908 r
.88477 .44302 .88969 .44998 .90217 .44621 .89729 .43922 Metetra
.664 .741 .908 r
.89729 .43922 .90217 .44621 .91471 .44243 .90987 .43542 Metetra
.664 .741 .908 r
.90987 .43542 .91471 .44243 .9273 .43864 .9225 .43159 Metetra
.664 .741 .908 r
.9225 .43159 .9273 .43864 .93994 .43483 .93518 .42775 Metetra
.664 .741 .908 r
.93518 .42775 .93994 .43483 .95264 .431 .94792 .42389 Metetra
.664 .741 .908 r
.94792 .42389 .95264 .431 .96539 .42716 .96071 .42002 Metetra
.664 .741 .908 r
.3863 .58619 .39262 .59207 .40313 .58889 .39683 .58298 Metetra
.664 .741 .908 r
.39683 .58298 .40313 .58889 .41367 .5857 .4074 .57977 Metetra
.664 .741 .908 r
.4074 .57977 .41367 .5857 .42426 .58249 .41802 .57654 Metetra
.664 .741 .908 r
.41802 .57654 .42426 .58249 .43489 .57927 .42867 .5733 Metetra
.664 .741 .908 r
.42867 .5733 .43489 .57927 .44556 .57604 .43937 .57004 Metetra
.664 .741 .908 r
.43937 .57004 .44556 .57604 .45627 .5728 .45011 .56677 Metetra
.664 .741 .908 r
.45011 .56677 .45627 .5728 .46703 .56954 .46089 .56349 Metetra
.664 .741 .908 r
.46089 .56349 .46703 .56954 .47782 .56627 .47172 .5602 Metetra
.664 .741 .908 r
.47172 .5602 .47782 .56627 .48867 .56298 .48259 .55689 Metetra
.664 .741 .908 r
.48259 .55689 .48867 .56298 .49955 .55969 .4935 .55357 Metetra
.664 .741 .908 r
.4935 .55357 .49955 .55969 .51048 .55638 .50446 .55023 Metetra
.664 .741 .908 r
.50446 .55023 .51048 .55638 .52145 .55305 .51546 .54689 Metetra
.664 .741 .908 r
.51546 .54689 .52145 .55305 .53246 .54972 .5265 .54352 Metetra
.664 .741 .908 r
.5265 .54352 .53246 .54972 .54352 .54637 .53759 .54015 Metetra
.664 .741 .908 r
.53759 .54015 .54352 .54637 .55463 .54301 .54872 .53676 Metetra
.664 .741 .908 r
.54872 .53676 .55463 .54301 .56578 .53963 .5599 .53336 Metetra
.664 .741 .908 r
.5599 .53336 .56578 .53963 .57697 .53624 .57113 .52994 Metetra
.664 .741 .908 r
.57113 .52994 .57697 .53624 .58821 .53284 .58239 .52651 Metetra
.664 .741 .908 r
.58239 .52651 .58821 .53284 .5995 .52942 .59371 .52307 Metetra
.664 .741 .908 r
.59371 .52307 .5995 .52942 .61083 .52599 .60507 .51961 Metetra
.664 .741 .908 r
.60507 .51961 .61083 .52599 .6222 .52254 .61648 .51614 Metetra
.664 .741 .908 r
.61648 .51614 .6222 .52254 .63363 .51908 .62794 .51266 Metetra
.664 .741 .908 r
.62794 .51266 .63363 .51908 .6451 .51561 .63944 .50916 Metetra
.664 .741 .908 r
.63944 .50916 .6451 .51561 .65661 .51212 .65099 .50564 Metetra
.664 .741 .908 r
.65099 .50564 .65661 .51212 .66818 .50862 .66258 .50211 Metetra
.664 .741 .908 r
.66258 .50211 .66818 .50862 .67979 .5051 .67423 .49857 Metetra
.664 .741 .908 r
.67423 .49857 .67979 .5051 .69145 .50157 .68592 .49501 Metetra
.664 .741 .908 r
.68592 .49501 .69145 .50157 .70316 .49802 .69766 .49144 Metetra
.664 .741 .908 r
.69766 .49144 .70316 .49802 .71492 .49446 .70945 .48785 Metetra
.664 .741 .908 r
.70945 .48785 .71492 .49446 .72672 .49089 .72129 .48425 Metetra
.664 .741 .908 r
.72129 .48425 .72672 .49089 .73858 .48729 .73318 .48063 Metetra
.664 .741 .908 r
.73318 .48063 .73858 .48729 .75048 .48369 .74512 .47699 Metetra
.664 .741 .908 r
.74512 .47699 .75048 .48369 .76243 .48007 .75711 .47335 Metetra
.664 .741 .908 r
.75711 .47335 .76243 .48007 .77444 .47643 .76915 .46968 Metetra
.664 .741 .908 r
.76915 .46968 .77444 .47643 .78649 .47278 .78124 .466 Metetra
.664 .741 .908 r
.78124 .466 .78649 .47278 .79859 .46912 .79338 .46231 Metetra
.664 .741 .908 r
.79338 .46231 .79859 .46912 .81075 .46544 .80557 .4586 Metetra
.664 .741 .908 r
.80557 .4586 .81075 .46544 .82296 .46174 .81781 .45487 Metetra
.664 .741 .908 r
.81781 .45487 .82296 .46174 .83522 .45803 .83011 .45113 Metetra
.664 .741 .908 r
.83011 .45113 .83522 .45803 .84753 .4543 .84246 .44737 Metetra
.664 .741 .908 r
.84246 .44737 .84753 .4543 .85989 .45055 .85486 .4436 Metetra
.664 .741 .908 r
.85486 .4436 .85989 .45055 .8723 .44679 .86731 .43981 Metetra
.664 .741 .908 r
.86731 .43981 .8723 .44679 .88477 .44302 .87982 .436 Metetra
.664 .741 .908 r
.87982 .436 .88477 .44302 .89729 .43922 .89238 .43218 Metetra
.664 .741 .908 r
.89238 .43218 .89729 .43922 .90987 .43542 .90499 .42834 Metetra
.664 .741 .908 r
.90499 .42834 .90987 .43542 .9225 .43159 .91766 .42449 Metetra
.664 .741 .908 r
.91766 .42449 .9225 .43159 .93518 .42775 .93038 .42061 Metetra
.664 .741 .908 r
.93038 .42061 .93518 .42775 .94792 .42389 .94316 .41673 Metetra
.664 .741 .908 r
.94316 .41673 .94792 .42389 .96071 .42002 .956 .41282 Metetra
.664 .741 .908 r
.37994 .58026 .3863 .58619 .39683 .58298 .39049 .57704 Metetra
.664 .741 .908 r
.39049 .57704 .39683 .58298 .4074 .57977 .40109 .57379 Metetra
.664 .741 .908 r
.40109 .57379 .4074 .57977 .41802 .57654 .41173 .57054 Metetra
.664 .741 .908 r
.41173 .57054 .41802 .57654 .42867 .5733 .42241 .56727 Metetra
.664 .741 .908 r
.42241 .56727 .42867 .5733 .43937 .57004 .43314 .564 Metetra
.664 .741 .908 r
.43314 .564 .43937 .57004 .45011 .56677 .4439 .5607 Metetra
.664 .741 .908 r
.4439 .5607 .45011 .56677 .46089 .56349 .45471 .5574 Metetra
.664 .741 .908 r
.45471 .5574 .46089 .56349 .47172 .5602 .46557 .55408 Metetra
.664 .741 .908 r
.46557 .55408 .47172 .5602 .48259 .55689 .47646 .55075 Metetra
.664 .741 .908 r
.47646 .55075 .48259 .55689 .4935 .55357 .4874 .5474 Metetra
.664 .741 .908 r
.4874 .5474 .4935 .55357 .50446 .55023 .49839 .54404 Metetra
.664 .741 .908 r
.49839 .54404 .50446 .55023 .51546 .54689 .50942 .54067 Metetra
.664 .741 .908 r
.50942 .54067 .51546 .54689 .5265 .54352 .52049 .53728 Metetra
.664 .741 .908 r
.52049 .53728 .5265 .54352 .53759 .54015 .53161 .53388 Metetra
.664 .741 .908 r
.53161 .53388 .53759 .54015 .54872 .53676 .54277 .53047 Metetra
.664 .741 .908 r
.54277 .53047 .54872 .53676 .5599 .53336 .55398 .52704 Metetra
.664 .741 .908 r
.55398 .52704 .5599 .53336 .57113 .52994 .56524 .5236 Metetra
.664 .741 .908 r
.56524 .5236 .57113 .52994 .58239 .52651 .57654 .52015 Metetra
.664 .741 .908 r
.57654 .52015 .58239 .52651 .59371 .52307 .58788 .51668 Metetra
.664 .741 .908 r
.58788 .51668 .59371 .52307 .60507 .51961 .59927 .51319 Metetra
.664 .741 .908 r
.59927 .51319 .60507 .51961 .61648 .51614 .61071 .50969 Metetra
.664 .741 .908 r
.61071 .50969 .61648 .51614 .62794 .51266 .6222 .50618 Metetra
.664 .741 .908 r
.6222 .50618 .62794 .51266 .63944 .50916 .63373 .50266 Metetra
.664 .741 .908 r
.63373 .50266 .63944 .50916 .65099 .50564 .64532 .49911 Metetra
.664 .741 .908 r
.64532 .49911 .65099 .50564 .66258 .50211 .65694 .49556 Metetra
.664 .741 .908 r
.65694 .49556 .66258 .50211 .67423 .49857 .66862 .49199 Metetra
.664 .741 .908 r
.66862 .49199 .67423 .49857 .68592 .49501 .68035 .4884 Metetra
.664 .741 .908 r
.68035 .4884 .68592 .49501 .69766 .49144 .69212 .4848 Metetra
.664 .741 .908 r
.69212 .4848 .69766 .49144 .70945 .48785 .70395 .48118 Metetra
.664 .741 .908 r
.70395 .48118 .70945 .48785 .72129 .48425 .71582 .47755 Metetra
.664 .741 .908 r
.71582 .47755 .72129 .48425 .73318 .48063 .72774 .47391 Metetra
.664 .741 .908 r
.72774 .47391 .73318 .48063 .74512 .47699 .73972 .47025 Metetra
.664 .741 .908 r
.73972 .47025 .74512 .47699 .75711 .47335 .75174 .46657 Metetra
.664 .741 .908 r
.75174 .46657 .75711 .47335 .76915 .46968 .76382 .46288 Metetra
.664 .741 .908 r
.76382 .46288 .76915 .46968 .78124 .466 .77594 .45917 Metetra
.664 .741 .908 r
.77594 .45917 .78124 .466 .79338 .46231 .78812 .45545 Metetra
.664 .741 .908 r
.78812 .45545 .79338 .46231 .80557 .4586 .80035 .45171 Metetra
.664 .741 .908 r
.80035 .45171 .80557 .4586 .81781 .45487 .81263 .44795 Metetra
.664 .741 .908 r
.81263 .44795 .81781 .45487 .83011 .45113 .82496 .44418 Metetra
.664 .741 .908 r
.82496 .44418 .83011 .45113 .84246 .44737 .83735 .44039 Metetra
.664 .741 .908 r
.83735 .44039 .84246 .44737 .85486 .4436 .84978 .43659 Metetra
.664 .741 .908 r
.84978 .43659 .85486 .4436 .86731 .43981 .86228 .43277 Metetra
.664 .741 .908 r
.86228 .43277 .86731 .43981 .87982 .436 .87482 .42893 Metetra
.664 .741 .908 r
.87482 .42893 .87982 .436 .89238 .43218 .88742 .42508 Metetra
.664 .741 .908 r
.88742 .42508 .89238 .43218 .90499 .42834 .90008 .42121 Metetra
.664 .741 .908 r
.90008 .42121 .90499 .42834 .91766 .42449 .91278 .41732 Metetra
.664 .741 .908 r
.91278 .41732 .91766 .42449 .93038 .42061 .92555 .41342 Metetra
.664 .741 .908 r
.92555 .41342 .93038 .42061 .94316 .41673 .93837 .4095 Metetra
.664 .741 .908 r
.93837 .4095 .94316 .41673 .956 .41282 .95124 .40556 Metetra
.664 .741 .908 r
.37353 .57429 .37994 .58026 .39049 .57704 .38411 .57104 Metetra
.664 .741 .908 r
.38411 .57104 .39049 .57704 .40109 .57379 .39473 .56778 Metetra
.664 .741 .908 r
.39473 .56778 .40109 .57379 .41173 .57054 .4054 .5645 Metetra
.664 .741 .908 r
.4054 .5645 .41173 .57054 .42241 .56727 .41611 .56121 Metetra
.664 .741 .908 r
.41611 .56121 .42241 .56727 .43314 .564 .42686 .55791 Metetra
.664 .741 .908 r
.42686 .55791 .43314 .564 .4439 .5607 .43765 .55459 Metetra
.664 .741 .908 r
.43765 .55459 .4439 .5607 .45471 .5574 .44849 .55126 Metetra
.664 .741 .908 r
.44849 .55126 .45471 .5574 .46557 .55408 .45937 .54792 Metetra
.664 .741 .908 r
.45937 .54792 .46557 .55408 .47646 .55075 .4703 .54456 Metetra
.664 .741 .908 r
.4703 .54456 .47646 .55075 .4874 .5474 .48126 .54119 Metetra
.664 .741 .908 r
.48126 .54119 .4874 .5474 .49839 .54404 .49228 .53781 Metetra
.664 .741 .908 r
.49228 .53781 .49839 .54404 .50942 .54067 .50334 .53441 Metetra
.664 .741 .908 r
.50334 .53441 .50942 .54067 .52049 .53728 .51444 .531 Metetra
.664 .741 .908 r
.51444 .531 .52049 .53728 .53161 .53388 .52558 .52757 Metetra
.664 .741 .908 r
.52558 .52757 .53161 .53388 .54277 .53047 .53678 .52413 Metetra
.664 .741 .908 r
.53678 .52413 .54277 .53047 .55398 .52704 .54802 .52068 Metetra
.664 .741 .908 r
.54802 .52068 .55398 .52704 .56524 .5236 .5593 .51721 Metetra
.664 .741 .908 r
.5593 .51721 .56524 .5236 .57654 .52015 .57063 .51373 Metetra
.664 .741 .908 r
.57063 .51373 .57654 .52015 .58788 .51668 .58201 .51023 Metetra
.664 .741 .908 r
.58201 .51023 .58788 .51668 .59927 .51319 .59343 .50672 Metetra
.664 .741 .908 r
.59343 .50672 .59927 .51319 .61071 .50969 .6049 .5032 Metetra
.664 .741 .908 r
.6049 .5032 .61071 .50969 .6222 .50618 .61642 .49966 Metetra
.664 .741 .908 r
.61642 .49966 .6222 .50618 .63373 .50266 .62799 .49611 Metetra
.664 .741 .908 r
.62799 .49611 .63373 .50266 .64532 .49911 .6396 .49254 Metetra
.664 .741 .908 r
.6396 .49254 .64532 .49911 .65694 .49556 .65126 .48895 Metetra
.664 .741 .908 r
.65126 .48895 .65694 .49556 .66862 .49199 .66297 .48536 Metetra
.664 .741 .908 r
.66297 .48536 .66862 .49199 .68035 .4884 .67473 .48174 Metetra
.664 .741 .908 r
.67473 .48174 .68035 .4884 .69212 .4848 .68654 .47811 Metetra
.664 .741 .908 r
.68654 .47811 .69212 .4848 .70395 .48118 .6984 .47447 Metetra
.664 .741 .908 r
.6984 .47447 .70395 .48118 .71582 .47755 .71031 .47081 Metetra
.664 .741 .908 r
.71031 .47081 .71582 .47755 .72774 .47391 .72227 .46714 Metetra
.664 .741 .908 r
.72227 .46714 .72774 .47391 .73972 .47025 .73427 .46345 Metetra
.664 .741 .908 r
.73427 .46345 .73972 .47025 .75174 .46657 .74633 .45974 Metetra
.664 .741 .908 r
.74633 .45974 .75174 .46657 .76382 .46288 .75844 .45602 Metetra
.664 .741 .908 r
.75844 .45602 .76382 .46288 .77594 .45917 .77061 .45228 Metetra
.664 .741 .908 r
.77061 .45228 .77594 .45917 .78812 .45545 .78282 .44853 Metetra
.664 .741 .908 r
.78282 .44853 .78812 .45545 .80035 .45171 .79508 .44476 Metetra
.664 .741 .908 r
.79508 .44476 .80035 .45171 .81263 .44795 .8074 .44098 Metetra
.664 .741 .908 r
.8074 .44098 .81263 .44795 .82496 .44418 .81977 .43718 Metetra
.664 .741 .908 r
.81977 .43718 .82496 .44418 .83735 .44039 .8322 .43336 Metetra
.664 .741 .908 r
.8322 .43336 .83735 .44039 .84978 .43659 .84467 .42952 Metetra
.664 .741 .908 r
.84467 .42952 .84978 .43659 .86228 .43277 .8572 .42567 Metetra
.664 .741 .908 r
.8572 .42567 .86228 .43277 .87482 .42893 .86979 .42181 Metetra
.664 .741 .908 r
.86979 .42181 .87482 .42893 .88742 .42508 .88243 .41792 Metetra
.664 .741 .908 r
.88243 .41792 .88742 .42508 .90008 .42121 .89512 .41402 Metetra
.664 .741 .908 r
.89512 .41402 .90008 .42121 .91278 .41732 .90787 .41011 Metetra
.664 .741 .908 r
.90787 .41011 .91278 .41732 .92555 .41342 .92067 .40617 Metetra
.664 .741 .908 r
.92067 .40617 .92555 .41342 .93837 .4095 .93353 .40222 Metetra
.664 .741 .908 r
.93353 .40222 .93837 .4095 .95124 .40556 .94645 .39825 Metetra
.664 .741 .908 r
.36707 .56828 .37353 .57429 .38411 .57104 .37768 .56501 Metetra
.664 .741 .908 r
.37768 .56501 .38411 .57104 .39473 .56778 .38833 .56172 Metetra
.664 .741 .908 r
.38833 .56172 .39473 .56778 .4054 .5645 .39902 .55842 Metetra
.664 .741 .908 r
.39902 .55842 .4054 .5645 .41611 .56121 .40975 .5551 Metetra
.664 .741 .908 r
.40975 .5551 .41611 .56121 .42686 .55791 .42053 .55177 Metetra
.664 .741 .908 r
.42053 .55177 .42686 .55791 .43765 .55459 .43135 .54843 Metetra
.664 .741 .908 r
.43135 .54843 .43765 .55459 .44849 .55126 .44222 .54508 Metetra
.664 .741 .908 r
.44222 .54508 .44849 .55126 .45937 .54792 .45313 .54171 Metetra
.664 .741 .908 r
.45313 .54171 .45937 .54792 .4703 .54456 .46408 .53833 Metetra
.664 .741 .908 r
.46408 .53833 .4703 .54456 .48126 .54119 .47508 .53493 Metetra
.664 .741 .908 r
.47508 .53493 .48126 .54119 .49228 .53781 .48612 .53152 Metetra
.664 .741 .908 r
.48612 .53152 .49228 .53781 .50334 .53441 .49721 .5281 Metetra
.664 .741 .908 r
.49721 .5281 .50334 .53441 .51444 .531 .50834 .52466 Metetra
.664 .741 .908 r
.50834 .52466 .51444 .531 .52558 .52757 .51952 .52121 Metetra
.664 .741 .908 r
.51952 .52121 .52558 .52757 .53678 .52413 .53074 .51775 Metetra
.664 .741 .908 r
.53074 .51775 .53678 .52413 .54802 .52068 .54201 .51427 Metetra
.664 .741 .908 r
.54201 .51427 .54802 .52068 .5593 .51721 .55332 .51077 Metetra
.664 .741 .908 r
.55332 .51077 .5593 .51721 .57063 .51373 .56468 .50726 Metetra
.664 .741 .908 r
.56468 .50726 .57063 .51373 .58201 .51023 .57609 .50374 Metetra
.664 .741 .908 r
.57609 .50374 .58201 .51023 .59343 .50672 .58755 .50021 Metetra
.664 .741 .908 r
.58755 .50021 .59343 .50672 .6049 .5032 .59905 .49665 Metetra
.664 .741 .908 r
.59905 .49665 .6049 .5032 .61642 .49966 .6106 .49309 Metetra
.664 .741 .908 r
.6106 .49309 .61642 .49966 .62799 .49611 .6222 .48951 Metetra
.664 .741 .908 r
.6222 .48951 .62799 .49611 .6396 .49254 .63384 .48591 Metetra
.664 .741 .908 r
.63384 .48591 .6396 .49254 .65126 .48895 .64554 .4823 Metetra
.664 .741 .908 r
.64554 .4823 .65126 .48895 .66297 .48536 .65728 .47867 Metetra
.664 .741 .908 r
.65728 .47867 .66297 .48536 .67473 .48174 .66907 .47503 Metetra
.664 .741 .908 r
.66907 .47503 .67473 .48174 .68654 .47811 .68092 .47137 Metetra
.664 .741 .908 r
.68092 .47137 .68654 .47811 .6984 .47447 .69281 .4677 Metetra
.664 .741 .908 r
.69281 .4677 .6984 .47447 .71031 .47081 .70475 .46402 Metetra
.664 .741 .908 r
.70475 .46402 .71031 .47081 .72227 .46714 .71675 .46031 Metetra
.664 .741 .908 r
.71675 .46031 .72227 .46714 .73427 .46345 .72879 .45659 Metetra
.664 .741 .908 r
.72879 .45659 .73427 .46345 .74633 .45974 .74088 .45286 Metetra
.664 .741 .908 r
.74088 .45286 .74633 .45974 .75844 .45602 .75303 .44911 Metetra
.664 .741 .908 r
.75303 .44911 .75844 .45602 .77061 .45228 .76523 .44534 Metetra
.664 .741 .908 r
.76523 .44534 .77061 .45228 .78282 .44853 .77748 .44156 Metetra
.664 .741 .908 r
.77748 .44156 .78282 .44853 .79508 .44476 .78978 .43776 Metetra
.664 .741 .908 r
.78978 .43776 .79508 .44476 .8074 .44098 .80214 .43395 Metetra
.664 .741 .908 r
.80214 .43395 .8074 .44098 .81977 .43718 .81454 .43012 Metetra
.664 .741 .908 r
.81454 .43012 .81977 .43718 .8322 .43336 .827 .42627 Metetra
.664 .741 .908 r
.827 .42627 .8322 .43336 .84467 .42952 .83952 .4224 Metetra
.664 .741 .908 r
.83952 .4224 .84467 .42952 .8572 .42567 .85209 .41852 Metetra
.664 .741 .908 r
.85209 .41852 .8572 .42567 .86979 .42181 .86471 .41462 Metetra
.664 .741 .908 r
.86471 .41462 .86979 .42181 .88243 .41792 .87739 .41071 Metetra
.664 .741 .908 r
.87739 .41071 .88243 .41792 .89512 .41402 .89013 .40678 Metetra
.664 .741 .908 r
.89013 .40678 .89512 .41402 .90787 .41011 .90292 .40283 Metetra
.664 .741 .908 r
.90292 .40283 .90787 .41011 .92067 .40617 .91576 .39886 Metetra
.664 .741 .908 r
.91576 .39886 .92067 .40617 .93353 .40222 .92866 .39488 Metetra
.664 .741 .908 r
.92866 .39488 .93353 .40222 .94645 .39825 .94162 .39088 Metetra
.664 .741 .908 r
.36056 .56222 .36707 .56828 .37768 .56501 .3712 .55892 Metetra
.664 .741 .908 r
.3712 .55892 .37768 .56501 .38833 .56172 .38187 .55561 Metetra
.664 .741 .908 r
.38187 .55561 .38833 .56172 .39902 .55842 .39259 .55229 Metetra
.664 .741 .908 r
.39259 .55229 .39902 .55842 .40975 .5551 .40336 .54895 Metetra
.664 .741 .908 r
.40336 .54895 .40975 .5551 .42053 .55177 .41416 .54559 Metetra
.664 .741 .908 r
.41416 .54559 .42053 .55177 .43135 .54843 .42501 .54223 Metetra
.664 .741 .908 r
.42501 .54223 .43135 .54843 .44222 .54508 .4359 .53885 Metetra
.664 .741 .908 r
.4359 .53885 .44222 .54508 .45313 .54171 .44684 .53545 Metetra
.664 .741 .908 r
.44684 .53545 .45313 .54171 .46408 .53833 .45782 .53205 Metetra
.664 .741 .908 r
.45782 .53205 .46408 .53833 .47508 .53493 .46885 .52863 Metetra
.664 .741 .908 r
.46885 .52863 .47508 .53493 .48612 .53152 .47992 .52519 Metetra
.664 .741 .908 r
.47992 .52519 .48612 .53152 .49721 .5281 .49103 .52174 Metetra
.664 .741 .908 r
.49103 .52174 .49721 .5281 .50834 .52466 .50219 .51828 Metetra
.664 .741 .908 r
.50219 .51828 .50834 .52466 .51952 .52121 .5134 .5148 Metetra
.664 .741 .908 r
.5134 .5148 .51952 .52121 .53074 .51775 .52465 .51131 Metetra
.664 .741 .908 r
.52465 .51131 .53074 .51775 .54201 .51427 .53595 .50781 Metetra
.664 .741 .908 r
.53595 .50781 .54201 .51427 .55332 .51077 .5473 .50429 Metetra
.664 .741 .908 r
.5473 .50429 .55332 .51077 .56468 .50726 .55869 .50075 Metetra
.664 .741 .908 r
.55869 .50075 .56468 .50726 .57609 .50374 .57013 .4972 Metetra
.664 .741 .908 r
.57013 .4972 .57609 .50374 .58755 .50021 .58161 .49364 Metetra
.664 .741 .908 r
.58161 .49364 .58755 .50021 .59905 .49665 .59315 .49006 Metetra
.664 .741 .908 r
.59315 .49006 .59905 .49665 .6106 .49309 .60473 .48646 Metetra
.664 .741 .908 r
.60473 .48646 .6106 .49309 .6222 .48951 .61636 .48286 Metetra
.664 .741 .908 r
.61636 .48286 .6222 .48951 .63384 .48591 .62804 .47923 Metetra
.664 .741 .908 r
.62804 .47923 .63384 .48591 .64554 .4823 .63977 .47559 Metetra
.664 .741 .908 r
.63977 .47559 .64554 .4823 .65728 .47867 .65155 .47194 Metetra
.664 .741 .908 r
.65155 .47194 .65728 .47867 .66907 .47503 .66337 .46827 Metetra
.664 .741 .908 r
.66337 .46827 .66907 .47503 .68092 .47137 .67525 .46458 Metetra
.664 .741 .908 r
.67525 .46458 .68092 .47137 .69281 .4677 .68718 .46088 Metetra
.664 .741 .908 r
.68718 .46088 .69281 .4677 .70475 .46402 .69915 .45717 Metetra
.664 .741 .908 r
.69915 .45717 .70475 .46402 .71675 .46031 .71118 .45343 Metetra
.664 .741 .908 r
.71118 .45343 .71675 .46031 .72879 .45659 .72326 .44969 Metetra
.664 .741 .908 r
.72326 .44969 .72879 .45659 .74088 .45286 .73539 .44592 Metetra
.664 .741 .908 r
.73539 .44592 .74088 .45286 .75303 .44911 .74757 .44214 Metetra
.664 .741 .908 r
.74757 .44214 .75303 .44911 .76523 .44534 .75981 .43835 Metetra
.664 .741 .908 r
.75981 .43835 .76523 .44534 .77748 .44156 .77209 .43453 Metetra
.664 .741 .908 r
.77209 .43453 .77748 .44156 .78978 .43776 .78443 .43071 Metetra
.664 .741 .908 r
.78443 .43071 .78978 .43776 .80214 .43395 .79683 .42686 Metetra
.664 .741 .908 r
.79683 .42686 .80214 .43395 .81454 .43012 .80927 .423 Metetra
.664 .741 .908 r
.80927 .423 .81454 .43012 .827 .42627 .82177 .41912 Metetra
.664 .741 .908 r
.82177 .41912 .827 .42627 .83952 .4224 .83433 .41523 Metetra
.664 .741 .908 r
.83433 .41523 .83952 .4224 .85209 .41852 .84693 .41131 Metetra
.664 .741 .908 r
.84693 .41131 .85209 .41852 .86471 .41462 .8596 .40738 Metetra
.664 .741 .908 r
.8596 .40738 .86471 .41462 .87739 .41071 .87232 .40344 Metetra
.664 .741 .908 r
.87232 .40344 .87739 .41071 .89013 .40678 .88509 .39947 Metetra
.664 .741 .908 r
.88509 .39947 .89013 .40678 .90292 .40283 .89792 .39549 Metetra
.664 .741 .908 r
.89792 .39549 .90292 .40283 .91576 .39886 .91081 .39149 Metetra
.664 .741 .908 r
.91081 .39149 .91576 .39886 .92866 .39488 .92375 .38748 Metetra
.664 .741 .908 r
.92375 .38748 .92866 .39488 .94162 .39088 .93675 .38345 Metetra
.664 .741 .908 r
.35401 .55612 .36056 .56222 .3712 .55892 .36467 .5528 Metetra
.664 .741 .908 r
.36467 .5528 .3712 .55892 .38187 .55561 .37537 .54946 Metetra
.664 .741 .908 r
.37537 .54946 .38187 .55561 .39259 .55229 .38612 .54611 Metetra
.664 .741 .908 r
.38612 .54611 .39259 .55229 .40336 .54895 .39691 .54275 Metetra
.664 .741 .908 r
.39691 .54275 .40336 .54895 .41416 .54559 .40774 .53937 Metetra
.664 .741 .908 r
.40774 .53937 .41416 .54559 .42501 .54223 .41862 .53598 Metetra
.664 .741 .908 r
.41862 .53598 .42501 .54223 .4359 .53885 .42954 .53257 Metetra
.664 .741 .908 r
.42954 .53257 .4359 .53885 .44684 .53545 .4405 .52915 Metetra
.664 .741 .908 r
.4405 .52915 .44684 .53545 .45782 .53205 .45151 .52572 Metetra
.664 .741 .908 r
.45151 .52572 .45782 .53205 .46885 .52863 .46257 .52227 Metetra
.664 .741 .908 r
.46257 .52227 .46885 .52863 .47992 .52519 .47367 .51881 Metetra
.664 .741 .908 r
.47367 .51881 .47992 .52519 .49103 .52174 .48481 .51534 Metetra
.664 .741 .908 r
.48481 .51534 .49103 .52174 .50219 .51828 .496 .51185 Metetra
.664 .741 .908 r
.496 .51185 .50219 .51828 .5134 .5148 .50724 .50835 Metetra
.664 .741 .908 r
.50724 .50835 .5134 .5148 .52465 .51131 .51852 .50483 Metetra
.664 .741 .908 r
.51852 .50483 .52465 .51131 .53595 .50781 .52985 .5013 Metetra
.664 .741 .908 r
.52985 .5013 .53595 .50781 .5473 .50429 .54123 .49775 Metetra
.664 .741 .908 r
.54123 .49775 .5473 .50429 .55869 .50075 .55265 .49419 Metetra
.664 .741 .908 r
.55265 .49419 .55869 .50075 .57013 .4972 .56412 .49061 Metetra
.664 .741 .908 r
.56412 .49061 .57013 .4972 .58161 .49364 .57564 .48702 Metetra
.664 .741 .908 r
.57564 .48702 .58161 .49364 .59315 .49006 .5872 .48341 Metetra
.664 .741 .908 r
.5872 .48341 .59315 .49006 .60473 .48646 .59882 .47979 Metetra
.664 .741 .908 r
.59882 .47979 .60473 .48646 .61636 .48286 .61048 .47615 Metetra
.664 .741 .908 r
.61048 .47615 .61636 .48286 .62804 .47923 .62219 .4725 Metetra
.664 .741 .908 r
.62219 .4725 .62804 .47923 .63977 .47559 .63395 .46883 Metetra
.664 .741 .908 r
.63395 .46883 .63977 .47559 .65155 .47194 .64577 .46515 Metetra
.664 .741 .908 r
.64577 .46515 .65155 .47194 .66337 .46827 .65763 .46145 Metetra
.664 .741 .908 r
.65763 .46145 .66337 .46827 .67525 .46458 .66954 .45774 Metetra
.664 .741 .908 r
.66954 .45774 .67525 .46458 .68718 .46088 .6815 .45401 Metetra
.664 .741 .908 r
.6815 .45401 .68718 .46088 .69915 .45717 .69351 .45026 Metetra
.664 .741 .908 r
.69351 .45026 .69915 .45717 .71118 .45343 .70557 .4465 Metetra
.664 .741 .908 r
.70557 .4465 .71118 .45343 .72326 .44969 .71769 .44273 Metetra
.664 .741 .908 r
.71769 .44273 .72326 .44969 .73539 .44592 .72985 .43893 Metetra
.664 .741 .908 r
.72985 .43893 .73539 .44592 .74757 .44214 .74207 .43512 Metetra
.664 .741 .908 r
.74207 .43512 .74757 .44214 .75981 .43835 .75434 .4313 Metetra
.664 .741 .908 r
.75434 .4313 .75981 .43835 .77209 .43453 .76667 .42745 Metetra
.664 .741 .908 r
.76667 .42745 .77209 .43453 .78443 .43071 .77904 .42359 Metetra
.664 .741 .908 r
.77904 .42359 .78443 .43071 .79683 .42686 .79148 .41972 Metetra
.664 .741 .908 r
.79148 .41972 .79683 .42686 .80927 .423 .80396 .41583 Metetra
.664 .741 .908 r
.80396 .41583 .80927 .423 .82177 .41912 .8165 .41192 Metetra
.664 .741 .908 r
.8165 .41192 .82177 .41912 .83433 .41523 .82909 .40799 Metetra
.664 .741 .908 r
.82909 .40799 .83433 .41523 .84693 .41131 .84174 .40405 Metetra
.664 .741 .908 r
.84174 .40405 .84693 .41131 .8596 .40738 .85444 .40009 Metetra
.664 .741 .908 r
.85444 .40009 .8596 .40738 .87232 .40344 .8672 .39611 Metetra
.664 .741 .908 r
.8672 .39611 .87232 .40344 .88509 .39947 .88001 .39211 Metetra
.664 .741 .908 r
.88001 .39211 .88509 .39947 .89792 .39549 .89289 .3881 Metetra
.664 .741 .908 r
.89289 .3881 .89792 .39549 .91081 .39149 .90581 .38407 Metetra
.664 .741 .908 r
.90581 .38407 .91081 .39149 .92375 .38748 .9188 .38002 Metetra
.664 .741 .908 r
.9188 .38002 .92375 .38748 .93675 .38345 .93184 .37595 Metetra
.664 .741 .908 r
.34741 .54998 .35401 .55612 .36467 .5528 .3581 .54663 Metetra
.664 .741 .908 r
.3581 .54663 .36467 .5528 .37537 .54946 .36882 .54327 Metetra
.664 .741 .908 r
.36882 .54327 .37537 .54946 .38612 .54611 .3796 .53989 Metetra
.664 .741 .908 r
.3796 .53989 .38612 .54611 .39691 .54275 .39041 .5365 Metetra
.664 .741 .908 r
.39041 .5365 .39691 .54275 .40774 .53937 .40127 .5331 Metetra
.664 .741 .908 r
.40127 .5331 .40774 .53937 .41862 .53598 .41218 .52968 Metetra
.664 .741 .908 r
.41218 .52968 .41862 .53598 .42954 .53257 .42313 .52625 Metetra
.664 .741 .908 r
.42313 .52625 .42954 .53257 .4405 .52915 .43412 .52281 Metetra
.664 .741 .908 r
.43412 .52281 .4405 .52915 .45151 .52572 .44516 .51935 Metetra
.664 .741 .908 r
.44516 .51935 .45151 .52572 .46257 .52227 .45624 .51587 Metetra
.664 .741 .908 r
.45624 .51587 .46257 .52227 .47367 .51881 .46737 .51239 Metetra
.664 .741 .908 r
.46737 .51239 .47367 .51881 .48481 .51534 .47854 .50889 Metetra
.664 .741 .908 r
.47854 .50889 .48481 .51534 .496 .51185 .48976 .50537 Metetra
.664 .741 .908 r
.48976 .50537 .496 .51185 .50724 .50835 .50103 .50184 Metetra
.664 .741 .908 r
.50103 .50184 .50724 .50835 .51852 .50483 .51234 .49829 Metetra
.664 .741 .908 r
.51234 .49829 .51852 .50483 .52985 .5013 .5237 .49474 Metetra
.664 .741 .908 r
.5237 .49474 .52985 .5013 .54123 .49775 .53511 .49116 Metetra
.664 .741 .908 r
.53511 .49116 .54123 .49775 .55265 .49419 .54656 .48757 Metetra
.664 .741 .908 r
.54656 .48757 .55265 .49419 .56412 .49061 .55806 .48397 Metetra
.664 .741 .908 r
.55806 .48397 .56412 .49061 .57564 .48702 .56961 .48035 Metetra
.664 .741 .908 r
.56961 .48035 .57564 .48702 .5872 .48341 .58121 .47671 Metetra
.664 .741 .908 r
.58121 .47671 .5872 .48341 .59882 .47979 .59286 .47306 Metetra
.664 .741 .908 r
.59286 .47306 .59882 .47979 .61048 .47615 .60455 .4694 Metetra
.664 .741 .908 r
.60455 .4694 .61048 .47615 .62219 .4725 .6163 .46572 Metetra
.664 .741 .908 r
.6163 .46572 .62219 .4725 .63395 .46883 .62809 .46202 Metetra
.664 .741 .908 r
.62809 .46202 .63395 .46883 .64577 .46515 .63994 .45831 Metetra
.664 .741 .908 r
.63994 .45831 .64577 .46515 .65763 .46145 .65183 .45458 Metetra
.664 .741 .908 r
.65183 .45458 .65763 .46145 .66954 .45774 .66378 .45084 Metetra
.664 .741 .908 r
.66378 .45084 .66954 .45774 .6815 .45401 .67578 .44708 Metetra
.664 .741 .908 r
.67578 .44708 .6815 .45401 .69351 .45026 .68782 .44331 Metetra
.664 .741 .908 r
.68782 .44331 .69351 .45026 .70557 .4465 .69992 .43952 Metetra
.664 .741 .908 r
.69992 .43952 .70557 .4465 .71769 .44273 .71207 .43571 Metetra
.664 .741 .908 r
.71207 .43571 .71769 .44273 .72985 .43893 .72427 .43189 Metetra
.664 .741 .908 r
.72427 .43189 .72985 .43893 .74207 .43512 .73653 .42805 Metetra
.664 .741 .908 r
.73653 .42805 .74207 .43512 .75434 .4313 .74884 .42419 Metetra
.664 .741 .908 r
.74884 .42419 .75434 .4313 .76667 .42745 .7612 .42032 Metetra
.664 .741 .908 r
.7612 .42032 .76667 .42745 .77904 .42359 .77361 .41643 Metetra
.664 .741 .908 r
.77361 .41643 .77904 .42359 .79148 .41972 .78608 .41252 Metetra
.664 .741 .908 r
.78608 .41252 .79148 .41972 .80396 .41583 .7986 .40859 Metetra
.664 .741 .908 r
.7986 .40859 .80396 .41583 .8165 .41192 .81118 .40465 Metetra
.664 .741 .908 r
.81118 .40465 .8165 .41192 .82909 .40799 .82381 .4007 Metetra
.664 .741 .908 r
.82381 .4007 .82909 .40799 .84174 .40405 .8365 .39672 Metetra
.664 .741 .908 r
.8365 .39672 .84174 .40405 .85444 .40009 .84924 .39273 Metetra
.664 .741 .908 r
.84924 .39273 .85444 .40009 .8672 .39611 .86204 .38872 Metetra
.664 .741 .908 r
.86204 .38872 .8672 .39611 .88001 .39211 .8749 .38469 Metetra
.664 .741 .908 r
.8749 .38469 .88001 .39211 .89289 .3881 .88781 .38064 Metetra
.664 .741 .908 r
.88781 .38064 .89289 .3881 .90581 .38407 .90078 .37658 Metetra
.664 .741 .908 r
.90078 .37658 .90581 .38407 .9188 .38002 .91381 .3725 Metetra
.664 .741 .908 r
.91381 .3725 .9188 .38002 .93184 .37595 .92689 .3684 Metetra
.664 .741 .908 r
.34076 .54378 .34741 .54998 .3581 .54663 .35147 .54041 Metetra
.664 .741 .908 r
.35147 .54041 .3581 .54663 .36882 .54327 .36223 .53702 Metetra
.664 .741 .908 r
.36223 .53702 .36882 .54327 .3796 .53989 .37303 .53362 Metetra
.664 .741 .908 r
.37303 .53362 .3796 .53989 .39041 .5365 .38387 .53021 Metetra
.664 .741 .908 r
.38387 .53021 .39041 .5365 .40127 .5331 .39476 .52678 Metetra
.664 .741 .908 r
.39476 .52678 .40127 .5331 .41218 .52968 .40569 .52334 Metetra
.664 .741 .908 r
.40569 .52334 .41218 .52968 .42313 .52625 .41667 .51988 Metetra
.664 .741 .908 r
.41667 .51988 .42313 .52625 .43412 .52281 .42769 .51641 Metetra
.664 .741 .908 r
.42769 .51641 .43412 .52281 .44516 .51935 .43875 .51292 Metetra
.664 .741 .908 r
.43875 .51292 .44516 .51935 .45624 .51587 .44986 .50943 Metetra
.664 .741 .908 r
.44986 .50943 .45624 .51587 .46737 .51239 .46102 .50591 Metetra
.664 .741 .908 r
.46102 .50591 .46737 .51239 .47854 .50889 .47223 .50238 Metetra
.664 .741 .908 r
.47223 .50238 .47854 .50889 .48976 .50537 .48348 .49884 Metetra
.664 .741 .908 r
.48348 .49884 .48976 .50537 .50103 .50184 .49477 .49528 Metetra
.664 .741 .908 r
.49477 .49528 .50103 .50184 .51234 .49829 .50612 .49171 Metetra
.664 .741 .908 r
.50612 .49171 .51234 .49829 .5237 .49474 .51751 .48812 Metetra
.664 .741 .908 r
.51751 .48812 .5237 .49474 .53511 .49116 .52894 .48452 Metetra
.664 .741 .908 r
.52894 .48452 .53511 .49116 .54656 .48757 .54043 .48091 Metetra
.664 .741 .908 r
.54043 .48091 .54656 .48757 .55806 .48397 .55196 .47727 Metetra
.664 .741 .908 r
.55196 .47727 .55806 .48397 .56961 .48035 .56354 .47363 Metetra
.664 .741 .908 r
.56354 .47363 .56961 .48035 .58121 .47671 .57517 .46996 Metetra
.664 .741 .908 r
.57517 .46996 .58121 .47671 .59286 .47306 .58685 .46629 Metetra
.664 .741 .908 r
.58685 .46629 .59286 .47306 .60455 .4694 .59858 .46259 Metetra
.664 .741 .908 r
.59858 .46259 .60455 .4694 .6163 .46572 .61036 .45888 Metetra
.664 .741 .908 r
.61036 .45888 .6163 .46572 .62809 .46202 .62219 .45516 Metetra
.664 .741 .908 r
.62219 .45516 .62809 .46202 .63994 .45831 .63407 .45142 Metetra
.664 .741 .908 r
.63407 .45142 .63994 .45831 .65183 .45458 .646 .44766 Metetra
.664 .741 .908 r
.646 .44766 .65183 .45458 .66378 .45084 .65798 .44389 Metetra
.664 .741 .908 r
.65798 .44389 .66378 .45084 .67578 .44708 .67001 .4401 Metetra
.664 .741 .908 r
.67001 .4401 .67578 .44708 .68782 .44331 .68209 .4363 Metetra
.664 .741 .908 r
.68209 .4363 .68782 .44331 .69992 .43952 .69422 .43248 Metetra
.664 .741 .908 r
.69422 .43248 .69992 .43952 .71207 .43571 .70641 .42864 Metetra
.664 .741 .908 r
.70641 .42864 .71207 .43571 .72427 .43189 .71865 .42478 Metetra
.664 .741 .908 r
.71865 .42478 .72427 .43189 .73653 .42805 .73094 .42091 Metetra
.664 .741 .908 r
.73094 .42091 .73653 .42805 .74884 .42419 .74329 .41703 Metetra
.664 .741 .908 r
.74329 .41703 .74884 .42419 .7612 .42032 .75568 .41312 Metetra
.664 .741 .908 r
.75568 .41312 .7612 .42032 .77361 .41643 .76814 .4092 Metetra
.664 .741 .908 r
.76814 .4092 .77361 .41643 .78608 .41252 .78064 .40526 Metetra
.664 .741 .908 r
.78064 .40526 .78608 .41252 .7986 .40859 .7932 .40131 Metetra
.664 .741 .908 r
.7932 .40131 .7986 .40859 .81118 .40465 .80582 .39733 Metetra
.664 .741 .908 r
.80582 .39733 .81118 .40465 .82381 .4007 .81849 .39334 Metetra
.664 .741 .908 r
.81849 .39334 .82381 .4007 .8365 .39672 .83122 .38933 Metetra
.664 .741 .908 r
.83122 .38933 .8365 .39672 .84924 .39273 .844 .38531 Metetra
.664 .741 .908 r
.844 .38531 .84924 .39273 .86204 .38872 .85684 .38127 Metetra
.664 .741 .908 r
.85684 .38127 .86204 .38872 .8749 .38469 .86974 .3772 Metetra
.664 .741 .908 r
.86974 .3772 .8749 .38469 .88781 .38064 .88269 .37313 Metetra
.664 .741 .908 r
.88269 .37313 .88781 .38064 .90078 .37658 .8957 .36903 Metetra
.664 .741 .908 r
.8957 .36903 .90078 .37658 .91381 .3725 .90877 .36491 Metetra
.664 .741 .908 r
.90877 .36491 .91381 .3725 .92689 .3684 .9219 .36078 Metetra
.664 .741 .908 r
.33406 .53754 .34076 .54378 .35147 .54041 .3448 .53415 Metetra
.664 .741 .908 r
.3448 .53415 .35147 .54041 .36223 .53702 .35558 .53073 Metetra
.664 .741 .908 r
.35558 .53073 .36223 .53702 .37303 .53362 .36641 .52731 Metetra
.664 .741 .908 r
.36641 .52731 .37303 .53362 .38387 .53021 .37728 .52387 Metetra
.664 .741 .908 r
.37728 .52387 .38387 .53021 .39476 .52678 .38819 .52041 Metetra
.664 .741 .908 r
.38819 .52041 .39476 .52678 .40569 .52334 .39915 .51694 Metetra
.664 .741 .908 r
.39915 .51694 .40569 .52334 .41667 .51988 .41016 .51346 Metetra
.664 .741 .908 r
.41016 .51346 .41667 .51988 .42769 .51641 .42121 .50996 Metetra
.664 .741 .908 r
.42121 .50996 .42769 .51641 .43875 .51292 .4323 .50645 Metetra
.664 .741 .908 r
.4323 .50645 .43875 .51292 .44986 .50943 .44344 .50293 Metetra
.664 .741 .908 r
.44344 .50293 .44986 .50943 .46102 .50591 .45463 .49939 Metetra
.664 .741 .908 r
.45463 .49939 .46102 .50591 .47223 .50238 .46586 .49583 Metetra
.664 .741 .908 r
.46586 .49583 .47223 .50238 .48348 .49884 .47714 .49226 Metetra
.664 .741 .908 r
.47714 .49226 .48348 .49884 .49477 .49528 .48847 .48868 Metetra
.664 .741 .908 r
.48847 .48868 .49477 .49528 .50612 .49171 .49984 .48508 Metetra
.664 .741 .908 r
.49984 .48508 .50612 .49171 .51751 .48812 .51126 .48146 Metetra
.664 .741 .908 r
.51126 .48146 .51751 .48812 .52894 .48452 .52273 .47783 Metetra
.664 .741 .908 r
.52273 .47783 .52894 .48452 .54043 .48091 .53425 .47419 Metetra
.664 .741 .908 r
.53425 .47419 .54043 .48091 .55196 .47727 .54581 .47053 Metetra
.664 .741 .908 r
.54581 .47053 .55196 .47727 .56354 .47363 .55743 .46685 Metetra
.664 .741 .908 r
.55743 .46685 .56354 .47363 .57517 .46996 .56909 .46316 Metetra
.664 .741 .908 r
.56909 .46316 .57517 .46996 .58685 .46629 .5808 .45946 Metetra
.664 .741 .908 r
.5808 .45946 .58685 .46629 .59858 .46259 .59256 .45573 Metetra
.664 .741 .908 r
.59256 .45573 .59858 .46259 .61036 .45888 .60438 .452 Metetra
.664 .741 .908 r
.60438 .452 .61036 .45888 .62219 .45516 .61624 .44824 Metetra
.664 .741 .908 r
.61624 .44824 .62219 .45516 .63407 .45142 .62815 .44447 Metetra
.664 .741 .908 r
.62815 .44447 .63407 .45142 .646 .44766 .64011 .44069 Metetra
.664 .741 .908 r
.64011 .44069 .646 .44766 .65798 .44389 .65213 .43688 Metetra
.664 .741 .908 r
.65213 .43688 .65798 .44389 .67001 .4401 .66419 .43306 Metetra
.664 .741 .908 r
.66419 .43306 .67001 .4401 .68209 .4363 .67631 .42923 Metetra
.664 .741 .908 r
.67631 .42923 .68209 .4363 .69422 .43248 .68848 .42538 Metetra
.664 .741 .908 r
.68848 .42538 .69422 .43248 .70641 .42864 .7007 .42151 Metetra
.664 .741 .908 r
.7007 .42151 .70641 .42864 .71865 .42478 .71298 .41762 Metetra
.664 .741 .908 r
.71298 .41762 .71865 .42478 .73094 .42091 .72531 .41372 Metetra
.664 .741 .908 r
.72531 .41372 .73094 .42091 .74329 .41703 .73769 .4098 Metetra
.664 .741 .908 r
.73769 .4098 .74329 .41703 .75568 .41312 .75013 .40587 Metetra
.664 .741 .908 r
.75013 .40587 .75568 .41312 .76814 .4092 .76262 .40192 Metetra
.664 .741 .908 r
.76262 .40192 .76814 .4092 .78064 .40526 .77516 .39795 Metetra
.664 .741 .908 r
.77516 .39795 .78064 .40526 .7932 .40131 .78776 .39396 Metetra
.664 .741 .908 r
.78776 .39396 .7932 .40131 .80582 .39733 .80042 .38995 Metetra
.664 .741 .908 r
.80042 .38995 .80582 .39733 .81849 .39334 .81313 .38593 Metetra
.664 .741 .908 r
.81313 .38593 .81849 .39334 .83122 .38933 .8259 .38189 Metetra
.664 .741 .908 r
.8259 .38189 .83122 .38933 .844 .38531 .83872 .37783 Metetra
.664 .741 .908 r
.83872 .37783 .844 .38531 .85684 .38127 .8516 .37375 Metetra
.664 .741 .908 r
.8516 .37375 .85684 .38127 .86974 .3772 .86454 .36966 Metetra
.664 .741 .908 r
.86454 .36966 .86974 .3772 .88269 .37313 .87753 .36555 Metetra
.664 .741 .908 r
.87753 .36555 .88269 .37313 .8957 .36903 .89059 .36142 Metetra
.664 .741 .908 r
.89059 .36142 .8957 .36903 .90877 .36491 .9037 .35727 Metetra
.664 .741 .908 r
.9037 .35727 .90877 .36491 .9219 .36078 .91687 .3531 Metetra
.664 .742 .908 r
.32731 .53127 .33406 .53754 .3448 .53415 .33807 .52784 Metetra
.664 .742 .908 r
.33807 .52784 .3448 .53415 .35558 .53073 .34888 .5244 Metetra
.664 .742 .908 r
.34888 .5244 .35558 .53073 .36641 .52731 .35974 .52095 Metetra
.664 .742 .908 r
.35974 .52095 .36641 .52731 .37728 .52387 .37063 .51749 Metetra
.664 .742 .908 r
.37063 .51749 .37728 .52387 .38819 .52041 .38158 .51401 Metetra
.664 .742 .908 r
.38158 .51401 .38819 .52041 .39915 .51694 .39256 .51051 Metetra
.664 .742 .908 r
.39256 .51051 .39915 .51694 .41016 .51346 .4036 .507 Metetra
.664 .742 .908 r
.4036 .507 .41016 .51346 .42121 .50996 .41468 .50348 Metetra
.664 .742 .908 r
.41468 .50348 .42121 .50996 .4323 .50645 .4258 .49994 Metetra
.664 .742 .908 r
.4258 .49994 .4323 .50645 .44344 .50293 .43697 .49639 Metetra
.664 .742 .908 r
.43697 .49639 .44344 .50293 .45463 .49939 .44819 .49282 Metetra
.664 .742 .908 r
.44819 .49282 .45463 .49939 .46586 .49583 .45945 .48924 Metetra
.664 .742 .908 r
.45945 .48924 .46586 .49583 .47714 .49226 .47076 .48564 Metetra
.664 .742 .908 r
.47076 .48564 .47714 .49226 .48847 .48868 .48211 .48203 Metetra
.664 .742 .908 r
.48211 .48203 .48847 .48868 .49984 .48508 .49352 .4784 Metetra
.664 .742 .908 r
.49352 .4784 .49984 .48508 .51126 .48146 .50497 .47476 Metetra
.664 .742 .908 r
.50497 .47476 .51126 .48146 .52273 .47783 .51647 .4711 Metetra
.664 .742 .908 r
.51647 .4711 .52273 .47783 .53425 .47419 .52802 .46743 Metetra
.664 .742 .908 r
.52802 .46743 .53425 .47419 .54581 .47053 .53962 .46374 Metetra
.664 .742 .908 r
.53962 .46374 .54581 .47053 .55743 .46685 .55126 .46003 Metetra
.664 .742 .908 r
.55126 .46003 .55743 .46685 .56909 .46316 .56296 .45631 Metetra
.664 .742 .908 r
.56296 .45631 .56909 .46316 .5808 .45946 .5747 .45258 Metetra
.664 .742 .908 r
.5747 .45258 .5808 .45946 .59256 .45573 .5865 .44883 Metetra
.664 .742 .908 r
.5865 .44883 .59256 .45573 .60438 .452 .59834 .44506 Metetra
.664 .742 .908 r
.59834 .44506 .60438 .452 .61624 .44824 .61024 .44128 Metetra
.664 .742 .908 r
.61024 .44128 .61624 .44824 .62815 .44447 .62219 .43748 Metetra
.664 .742 .908 r
.62219 .43748 .62815 .44447 .64011 .44069 .63418 .43366 Metetra
.664 .742 .908 r
.63418 .43366 .64011 .44069 .65213 .43688 .64623 .42983 Metetra
.664 .742 .908 r
.64623 .42983 .65213 .43688 .66419 .43306 .65833 .42598 Metetra
.664 .742 .908 r
.65833 .42598 .66419 .43306 .67631 .42923 .67049 .42211 Metetra
.664 .742 .908 r
.67049 .42211 .67631 .42923 .68848 .42538 .68269 .41823 Metetra
.664 .742 .908 r
.68269 .41823 .68848 .42538 .7007 .42151 .69495 .41433 Metetra
.664 .742 .908 r
.69495 .41433 .7007 .42151 .71298 .41762 .70727 .41042 Metetra
.664 .742 .908 r
.70727 .41042 .71298 .41762 .72531 .41372 .71963 .40648 Metetra
.664 .742 .908 r
.71963 .40648 .72531 .41372 .73769 .4098 .73205 .40253 Metetra
.664 .742 .908 r
.73205 .40253 .73769 .4098 .75013 .40587 .74452 .39857 Metetra
.664 .742 .908 r
.74452 .39857 .75013 .40587 .76262 .40192 .75705 .39458 Metetra
.664 .742 .908 r
.75705 .39458 .76262 .40192 .77516 .39795 .76964 .39058 Metetra
.664 .742 .908 r
.76964 .39058 .77516 .39795 .78776 .39396 .78228 .38656 Metetra
.664 .742 .908 r
.78228 .38656 .78776 .39396 .80042 .38995 .79497 .38252 Metetra
.664 .742 .908 r
.79497 .38252 .80042 .38995 .81313 .38593 .80772 .37846 Metetra
.664 .742 .908 r
.80772 .37846 .81313 .38593 .8259 .38189 .82053 .37439 Metetra
.664 .742 .908 r
.82053 .37439 .8259 .38189 .83872 .37783 .83339 .3703 Metetra
.664 .742 .908 r
.83339 .3703 .83872 .37783 .8516 .37375 .84632 .36619 Metetra
.664 .742 .908 r
.84632 .36619 .8516 .37375 .86454 .36966 .85929 .36206 Metetra
.664 .742 .908 r
.85929 .36206 .86454 .36966 .87753 .36555 .87233 .35791 Metetra
.664 .742 .908 r
.87233 .35791 .87753 .36555 .89059 .36142 .88543 .35375 Metetra
.664 .742 .908 r
.88543 .35375 .89059 .36142 .9037 .35727 .89858 .34957 Metetra
.664 .742 .908 r
.89858 .34957 .9037 .35727 .91687 .3531 .91179 .34536 Metetra
.663 .751 .915 r
.32049 .52524 .32731 .53127 .33807 .52784 .33128 .52179 Metetra
.663 .751 .915 r
.33128 .52179 .33807 .52784 .34888 .5244 .34212 .51832 Metetra
.663 .751 .915 r
.34212 .51832 .34888 .5244 .35974 .52095 .353 .51485 Metetra
.663 .751 .915 r
.353 .51485 .35974 .52095 .37063 .51749 .36393 .51135 Metetra
.663 .751 .915 r
.36393 .51135 .37063 .51749 .38158 .51401 .3749 .50785 Metetra
.663 .751 .915 r
.3749 .50785 .38158 .51401 .39256 .51051 .38591 .50433 Metetra
.663 .751 .915 r
.38591 .50433 .39256 .51051 .4036 .507 .39698 .50079 Metetra
.663 .751 .915 r
.39698 .50079 .4036 .507 .41468 .50348 .40808 .49724 Metetra
.663 .751 .915 r
.40808 .49724 .41468 .50348 .4258 .49994 .41924 .49367 Metetra
.663 .751 .915 r
.41924 .49367 .4258 .49994 .43697 .49639 .43044 .49009 Metetra
.663 .751 .915 r
.43044 .49009 .43697 .49639 .44819 .49282 .44169 .4865 Metetra
.663 .751 .915 r
.44169 .4865 .44819 .49282 .45945 .48924 .45298 .48289 Metetra
.663 .751 .915 r
.45298 .48289 .45945 .48924 .47076 .48564 .46432 .47927 Metetra
.663 .751 .915 r
.46432 .47927 .47076 .48564 .48211 .48203 .47571 .47563 Metetra
.663 .751 .915 r
.47571 .47563 .48211 .48203 .49352 .4784 .48714 .47197 Metetra
.663 .751 .915 r
.48714 .47197 .49352 .4784 .50497 .47476 .49863 .4683 Metetra
.663 .751 .915 r
.49863 .4683 .50497 .47476 .51647 .4711 .51016 .46461 Metetra
.663 .751 .915 r
.51016 .46461 .51647 .4711 .52802 .46743 .52174 .46091 Metetra
.663 .751 .915 r
.52174 .46091 .52802 .46743 .53962 .46374 .53337 .4572 Metetra
.663 .751 .915 r
.53337 .4572 .53962 .46374 .55126 .46003 .54505 .45346 Metetra
.663 .751 .915 r
.54505 .45346 .55126 .46003 .56296 .45631 .55678 .44971 Metetra
.663 .751 .915 r
.55678 .44971 .56296 .45631 .5747 .45258 .56856 .44595 Metetra
.663 .751 .915 r
.56856 .44595 .5747 .45258 .5865 .44883 .58039 .44217 Metetra
.663 .751 .915 r
.58039 .44217 .5865 .44883 .59834 .44506 .59227 .43837 Metetra
.663 .751 .915 r
.59227 .43837 .59834 .44506 .61024 .44128 .6042 .43456 Metetra
.663 .751 .915 r
.6042 .43456 .61024 .44128 .62219 .43748 .61618 .43073 Metetra
.663 .751 .915 r
.61618 .43073 .62219 .43748 .63418 .43366 .62822 .42688 Metetra
.663 .751 .915 r
.62822 .42688 .63418 .43366 .64623 .42983 .6403 .42302 Metetra
.663 .751 .915 r
.6403 .42302 .64623 .42983 .65833 .42598 .65244 .41914 Metetra
.663 .751 .915 r
.65244 .41914 .65833 .42598 .67049 .42211 .66463 .41524 Metetra
.663 .751 .915 r
.66463 .41524 .67049 .42211 .68269 .41823 .67687 .41133 Metetra
.663 .751 .915 r
.67687 .41133 .68269 .41823 .69495 .41433 .68917 .4074 Metetra
.663 .751 .915 r
.68917 .4074 .69495 .41433 .70727 .41042 .70152 .40345 Metetra
.663 .751 .915 r
.70152 .40345 .70727 .41042 .71963 .40648 .71393 .39949 Metetra
.663 .751 .915 r
.71393 .39949 .71963 .40648 .73205 .40253 .72638 .39551 Metetra
.663 .751 .915 r
.72638 .39551 .73205 .40253 .74452 .39857 .7389 .39151 Metetra
.663 .751 .915 r
.7389 .39151 .74452 .39857 .75705 .39458 .75147 .38749 Metetra
.663 .751 .915 r
.75147 .38749 .75705 .39458 .76964 .39058 .76409 .38346 Metetra
.663 .751 .915 r
.76409 .38346 .76964 .39058 .78228 .38656 .77677 .3794 Metetra
.663 .751 .915 r
.77677 .3794 .78228 .38656 .79497 .38252 .78951 .37533 Metetra
.663 .751 .915 r
.78951 .37533 .79497 .38252 .80772 .37846 .8023 .37124 Metetra
.663 .751 .915 r
.8023 .37124 .80772 .37846 .82053 .37439 .81515 .36714 Metetra
.663 .751 .915 r
.81515 .36714 .82053 .37439 .83339 .3703 .82805 .36301 Metetra
.663 .751 .915 r
.82805 .36301 .83339 .3703 .84632 .36619 .84102 .35887 Metetra
.663 .751 .915 r
.84102 .35887 .84632 .36619 .85929 .36206 .85404 .35471 Metetra
.663 .751 .915 r
.85404 .35471 .85929 .36206 .87233 .35791 .86712 .35053 Metetra
.663 .751 .915 r
.86712 .35053 .87233 .35791 .88543 .35375 .88026 .34633 Metetra
.663 .751 .915 r
.88026 .34633 .88543 .35375 .89858 .34957 .89346 .34211 Metetra
.663 .751 .915 r
.89346 .34211 .89858 .34957 .91179 .34536 .90672 .33787 Metetra
.594 .89 .99 r
.31334 .52348 .32049 .52524 .33128 .52179 .32418 .52001 Metetra
.594 .89 .99 r
.32418 .52001 .33128 .52179 .34212 .51832 .33506 .51652 Metetra
.594 .89 .99 r
.33506 .51652 .34212 .51832 .353 .51485 .34598 .51302 Metetra
.594 .89 .99 r
.34598 .51302 .353 .51485 .36393 .51135 .35695 .50951 Metetra
.594 .89 .99 r
.35695 .50951 .36393 .51135 .3749 .50785 .36796 .50598 Metetra
.594 .89 .99 r
.36796 .50598 .3749 .50785 .38591 .50433 .37902 .50244 Metetra
.594 .89 .99 r
.37902 .50244 .38591 .50433 .39698 .50079 .39013 .49888 Metetra
.594 .89 .99 r
.39013 .49888 .39698 .50079 .40808 .49724 .40128 .49531 Metetra
.594 .89 .99 r
.40128 .49531 .40808 .49724 .41924 .49367 .41248 .49172 Metetra
.594 .89 .99 r
.41248 .49172 .41924 .49367 .43044 .49009 .42372 .48812 Metetra
.594 .89 .99 r
.42372 .48812 .43044 .49009 .44169 .4865 .43501 .4845 Metetra
.594 .89 .99 r
.43501 .4845 .44169 .4865 .45298 .48289 .44635 .48087 Metetra
.594 .89 .99 r
.44635 .48087 .45298 .48289 .46432 .47927 .45774 .47722 Metetra
.594 .89 .99 r
.45774 .47722 .46432 .47927 .47571 .47563 .46918 .47355 Metetra
.594 .89 .99 r
.46918 .47355 .47571 .47563 .48714 .47197 .48066 .46988 Metetra
.594 .89 .99 r
.48066 .46988 .48714 .47197 .49863 .4683 .49219 .46618 Metetra
.594 .89 .99 r
.49219 .46618 .49863 .4683 .51016 .46461 .50377 .46247 Metetra
.594 .89 .99 r
.50377 .46247 .51016 .46461 .52174 .46091 .5154 .45874 Metetra
.594 .89 .99 r
.5154 .45874 .52174 .46091 .53337 .4572 .52708 .455 Metetra
.594 .89 .99 r
.52708 .455 .53337 .4572 .54505 .45346 .53881 .45125 Metetra
.594 .89 .99 r
.53881 .45125 .54505 .45346 .55678 .44971 .55059 .44747 Metetra
.594 .89 .99 r
.55059 .44747 .55678 .44971 .56856 .44595 .56242 .44368 Metetra
.594 .89 .99 r
.56242 .44368 .56856 .44595 .58039 .44217 .5743 .43988 Metetra
.594 .89 .99 r
.5743 .43988 .58039 .44217 .59227 .43837 .58623 .43605 Metetra
.594 .89 .99 r
.58623 .43605 .59227 .43837 .6042 .43456 .59821 .43221 Metetra
.594 .89 .99 r
.59821 .43221 .6042 .43456 .61618 .43073 .61025 .42836 Metetra
.594 .89 .99 r
.61025 .42836 .61618 .43073 .62822 .42688 .62233 .42449 Metetra
.594 .89 .99 r
.62233 .42449 .62822 .42688 .6403 .42302 .63447 .4206 Metetra
.594 .89 .99 r
.63447 .4206 .6403 .42302 .65244 .41914 .64666 .41669 Metetra
.594 .89 .99 r
.64666 .41669 .65244 .41914 .66463 .41524 .65891 .41277 Metetra
.594 .89 .99 r
.65891 .41277 .66463 .41524 .67687 .41133 .67121 .40883 Metetra
.594 .89 .99 r
.67121 .40883 .67687 .41133 .68917 .4074 .68356 .40487 Metetra
.594 .89 .99 r
.68356 .40487 .68917 .4074 .70152 .40345 .69597 .4009 Metetra
.594 .89 .99 r
.69597 .4009 .70152 .40345 .71393 .39949 .70843 .3969 Metetra
.594 .89 .99 r
.70843 .3969 .71393 .39949 .72638 .39551 .72094 .39289 Metetra
.594 .89 .99 r
.72094 .39289 .72638 .39551 .7389 .39151 .73351 .38887 Metetra
.594 .89 .99 r
.73351 .38887 .7389 .39151 .75147 .38749 .74614 .38482 Metetra
.594 .89 .99 r
.74614 .38482 .75147 .38749 .76409 .38346 .75882 .38076 Metetra
.594 .89 .99 r
.75882 .38076 .76409 .38346 .77677 .3794 .77156 .37668 Metetra
.594 .89 .99 r
.77156 .37668 .77677 .3794 .78951 .37533 .78436 .37258 Metetra
.594 .89 .99 r
.78436 .37258 .78951 .37533 .8023 .37124 .79721 .36846 Metetra
.594 .89 .99 r
.79721 .36846 .8023 .37124 .81515 .36714 .81012 .36432 Metetra
.594 .89 .99 r
.81012 .36432 .81515 .36714 .82805 .36301 .82309 .36017 Metetra
.594 .89 .99 r
.82309 .36017 .82805 .36301 .84102 .35887 .83612 .356 Metetra
.594 .89 .99 r
.83612 .356 .84102 .35887 .85404 .35471 .8492 .3518 Metetra
.594 .89 .99 r
.8492 .3518 .85404 .35471 .86712 .35053 .86235 .34759 Metetra
.594 .89 .99 r
.86235 .34759 .86712 .35053 .88026 .34633 .87555 .34336 Metetra
.594 .89 .99 r
.87555 .34336 .88026 .34633 .89346 .34211 .88881 .33911 Metetra
.594 .89 .99 r
.88881 .33911 .89346 .34211 .90672 .33787 .90214 .33484 Metetra
.455 .134 .331 r
.30462 .5447 .31334 .52348 .32418 .52001 .31557 .54123 Metetra
.455 .134 .331 r
.31557 .54123 .32418 .52001 .33506 .51652 .32656 .53775 Metetra
.455 .134 .331 r
.32656 .53775 .33506 .51652 .34598 .51302 .3376 .53425 Metetra
.455 .134 .331 r
.3376 .53425 .34598 .51302 .35695 .50951 .34868 .53074 Metetra
.455 .134 .331 r
.34868 .53074 .35695 .50951 .36796 .50598 .35982 .52721 Metetra
.455 .134 .331 r
.35982 .52721 .36796 .50598 .37902 .50244 .37099 .52367 Metetra
.455 .134 .331 r
.37099 .52367 .37902 .50244 .39013 .49888 .38222 .52011 Metetra
.455 .134 .331 r
.38222 .52011 .39013 .49888 .40128 .49531 .39349 .51654 Metetra
.455 .134 .331 r
.39349 .51654 .40128 .49531 .41248 .49172 .40481 .51295 Metetra
.455 .134 .331 r
.40481 .51295 .41248 .49172 .42372 .48812 .41618 .50935 Metetra
.455 .134 .331 r
.41618 .50935 .42372 .48812 .43501 .4845 .42759 .50573 Metetra
.455 .134 .331 r
.42759 .50573 .43501 .4845 .44635 .48087 .43906 .5021 Metetra
.455 .134 .331 r
.43906 .5021 .44635 .48087 .45774 .47722 .45057 .49845 Metetra
.455 .134 .331 r
.45057 .49845 .45774 .47722 .46918 .47355 .46213 .49479 Metetra
.455 .134 .331 r
.46213 .49479 .46918 .47355 .48066 .46988 .47375 .49111 Metetra
.455 .134 .331 r
.47375 .49111 .48066 .46988 .49219 .46618 .48541 .48741 Metetra
.455 .134 .331 r
.48541 .48741 .49219 .46618 .50377 .46247 .49712 .4837 Metetra
.455 .134 .331 r
.49712 .4837 .50377 .46247 .5154 .45874 .50888 .47997 Metetra
.455 .134 .331 r
.50888 .47997 .5154 .45874 .52708 .455 .52069 .47623 Metetra
.455 .134 .331 r
.52069 .47623 .52708 .455 .53881 .45125 .53255 .47247 Metetra
.455 .134 .331 r
.53255 .47247 .53881 .45125 .55059 .44747 .54447 .4687 Metetra
.455 .134 .331 r
.54447 .4687 .55059 .44747 .56242 .44368 .55644 .4649 Metetra
.455 .134 .331 r
.55644 .4649 .56242 .44368 .5743 .43988 .56845 .4611 Metetra
.455 .134 .331 r
.56845 .4611 .5743 .43988 .58623 .43605 .58052 .45727 Metetra
.455 .134 .331 r
.58052 .45727 .58623 .43605 .59821 .43221 .59265 .45343 Metetra
.455 .134 .331 r
.59265 .45343 .59821 .43221 .61025 .42836 .60482 .44957 Metetra
.455 .134 .331 r
.60482 .44957 .61025 .42836 .62233 .42449 .61705 .4457 Metetra
.455 .134 .331 r
.61705 .4457 .62233 .42449 .63447 .4206 .62934 .4418 Metetra
.455 .134 .331 r
.62934 .4418 .63447 .4206 .64666 .41669 .64167 .43789 Metetra
.455 .134 .331 r
.64167 .43789 .64666 .41669 .65891 .41277 .65407 .43397 Metetra
.455 .134 .331 r
.65407 .43397 .65891 .41277 .67121 .40883 .66651 .43002 Metetra
.455 .134 .331 r
.66651 .43002 .67121 .40883 .68356 .40487 .67901 .42606 Metetra
.455 .134 .331 r
.67901 .42606 .68356 .40487 .69597 .4009 .69157 .42208 Metetra
.455 .134 .331 r
.69157 .42208 .69597 .4009 .70843 .3969 .70418 .41809 Metetra
.455 .134 .331 r
.70418 .41809 .70843 .3969 .72094 .39289 .71685 .41407 Metetra
.455 .134 .331 r
.71685 .41407 .72094 .39289 .73351 .38887 .72958 .41004 Metetra
.455 .134 .331 r
.72958 .41004 .73351 .38887 .74614 .38482 .74236 .40599 Metetra
.455 .134 .331 r
.74236 .40599 .74614 .38482 .75882 .38076 .7552 .40192 Metetra
.455 .134 .331 r
.7552 .40192 .75882 .38076 .77156 .37668 .7681 .39783 Metetra
.455 .134 .331 r
.7681 .39783 .77156 .37668 .78436 .37258 .78106 .39373 Metetra
.455 .134 .331 r
.78106 .39373 .78436 .37258 .79721 .36846 .79407 .3896 Metetra
.455 .134 .331 r
.79407 .3896 .79721 .36846 .81012 .36432 .80715 .38546 Metetra
.455 .134 .331 r
.80715 .38546 .81012 .36432 .82309 .36017 .82028 .3813 Metetra
.455 .134 .331 r
.82028 .3813 .82309 .36017 .83612 .356 .83348 .37712 Metetra
.455 .134 .331 r
.83348 .37712 .83612 .356 .8492 .3518 .84673 .37292 Metetra
.455 .134 .331 r
.84673 .37292 .8492 .3518 .86235 .34759 .86004 .3687 Metetra
.455 .134 .331 r
.86004 .3687 .86235 .34759 .87555 .34336 .87342 .36446 Metetra
.455 .134 .331 r
.87342 .36446 .87555 .34336 .88881 .33911 .88686 .3602 Metetra
.455 .134 .331 r
.88686 .3602 .88881 .33911 .90214 .33484 .90035 .35592 Metetra
.524 .27 .472 r
.29308 .60497 .30462 .5447 .31557 .54123 .30426 .60154 Metetra
.524 .27 .472 r
.30426 .60154 .31557 .54123 .32656 .53775 .31549 .59811 Metetra
.524 .27 .472 r
.31549 .59811 .32656 .53775 .3376 .53425 .32677 .59465 Metetra
.524 .27 .472 r
.32677 .59465 .3376 .53425 .34868 .53074 .3381 .59118 Metetra
.524 .27 .472 r
.3381 .59118 .34868 .53074 .35982 .52721 .34947 .5877 Metetra
.524 .27 .472 r
.34947 .5877 .35982 .52721 .37099 .52367 .3609 .5842 Metetra
.524 .27 .472 r
.3609 .5842 .37099 .52367 .38222 .52011 .37237 .58069 Metetra
.524 .27 .472 r
.37237 .58069 .38222 .52011 .39349 .51654 .3839 .57716 Metetra
.524 .27 .472 r
.3839 .57716 .39349 .51654 .40481 .51295 .39547 .57362 Metetra
.524 .27 .472 r
.39547 .57362 .40481 .51295 .41618 .50935 .40709 .57006 Metetra
.524 .27 .472 r
.40709 .57006 .41618 .50935 .42759 .50573 .41877 .56649 Metetra
.524 .27 .472 r
.41877 .56649 .42759 .50573 .43906 .5021 .43049 .5629 Metetra
.524 .27 .472 r
.43049 .5629 .43906 .5021 .45057 .49845 .44227 .55929 Metetra
.524 .27 .472 r
.44227 .55929 .45057 .49845 .46213 .49479 .45409 .55567 Metetra
.524 .27 .472 r
.45409 .55567 .46213 .49479 .47375 .49111 .46597 .55204 Metetra
.524 .27 .472 r
.46597 .55204 .47375 .49111 .48541 .48741 .4779 .54838 Metetra
.524 .27 .472 r
.4779 .54838 .48541 .48741 .49712 .4837 .48989 .54472 Metetra
.524 .27 .472 r
.48989 .54472 .49712 .4837 .50888 .47997 .50192 .54103 Metetra
.524 .27 .472 r
.50192 .54103 .50888 .47997 .52069 .47623 .51401 .53733 Metetra
.524 .27 .472 r
.51401 .53733 .52069 .47623 .53255 .47247 .52615 .53361 Metetra
.524 .27 .472 r
.52615 .53361 .53255 .47247 .54447 .4687 .53835 .52988 Metetra
.524 .27 .472 r
.53835 .52988 .54447 .4687 .55644 .4649 .5506 .52613 Metetra
.524 .27 .472 r
.5506 .52613 .55644 .4649 .56845 .4611 .56291 .52236 Metetra
.524 .27 .472 r
.56291 .52236 .56845 .4611 .58052 .45727 .57527 .51858 Metetra
.524 .27 .472 r
.57527 .51858 .58052 .45727 .59265 .45343 .58768 .51478 Metetra
.524 .27 .472 r
.58768 .51478 .59265 .45343 .60482 .44957 .60015 .51096 Metetra
.524 .27 .472 r
.60015 .51096 .60482 .44957 .61705 .4457 .61268 .50712 Metetra
.524 .27 .472 r
.61268 .50712 .61705 .4457 .62934 .4418 .62526 .50327 Metetra
.524 .27 .472 r
.62526 .50327 .62934 .4418 .64167 .43789 .6379 .4994 Metetra
.524 .27 .472 r
.6379 .4994 .64167 .43789 .65407 .43397 .6506 .49551 Metetra
.524 .27 .472 r
.6506 .49551 .65407 .43397 .66651 .43002 .66336 .49161 Metetra
.524 .27 .472 r
.66336 .49161 .66651 .43002 .67901 .42606 .67617 .48768 Metetra
.524 .27 .472 r
.67617 .48768 .67901 .42606 .69157 .42208 .68904 .48374 Metetra
.524 .27 .472 r
.68904 .48374 .69157 .42208 .70418 .41809 .70197 .47979 Metetra
.524 .27 .472 r
.70197 .47979 .70418 .41809 .71685 .41407 .71496 .47581 Metetra
.524 .27 .472 r
.71496 .47581 .71685 .41407 .72958 .41004 .72801 .47181 Metetra
.524 .27 .472 r
.72801 .47181 .72958 .41004 .74236 .40599 .74112 .4678 Metetra
.524 .27 .472 r
.74112 .4678 .74236 .40599 .7552 .40192 .75429 .46377 Metetra
.524 .27 .472 r
.75429 .46377 .7552 .40192 .7681 .39783 .76752 .45972 Metetra
.524 .27 .472 r
.76752 .45972 .7681 .39783 .78106 .39373 .78081 .45565 Metetra
.524 .27 .472 r
.78081 .45565 .78106 .39373 .79407 .3896 .79416 .45156 Metetra
.524 .27 .472 r
.79416 .45156 .79407 .3896 .80715 .38546 .80758 .44745 Metetra
.524 .27 .472 r
.80758 .44745 .80715 .38546 .82028 .3813 .82106 .44333 Metetra
.524 .27 .472 r
.82106 .44333 .82028 .3813 .83348 .37712 .8346 .43918 Metetra
.524 .27 .472 r
.8346 .43918 .83348 .37712 .84673 .37292 .8482 .43502 Metetra
.524 .27 .472 r
.8482 .43502 .84673 .37292 .86004 .3687 .86187 .43083 Metetra
.524 .27 .472 r
.86187 .43083 .86004 .3687 .87342 .36446 .8756 .42663 Metetra
.524 .27 .472 r
.8756 .42663 .87342 .36446 .88686 .3602 .8894 .42241 Metetra
.524 .27 .472 r
.8894 .42241 .88686 .3602 .90035 .35592 .90326 .41816 Metetra
.523 .269 .47 r
.28106 .66684 .29308 .60497 .30426 .60154 .29249 .66347 Metetra
.523 .269 .47 r
.29249 .66347 .30426 .60154 .31549 .59811 .30397 .66008 Metetra
.523 .269 .47 r
.30397 .66008 .31549 .59811 .32677 .59465 .31549 .65668 Metetra
.523 .269 .47 r
.31549 .65668 .32677 .59465 .3381 .59118 .32707 .65326 Metetra
.523 .269 .47 r
.32707 .65326 .3381 .59118 .34947 .5877 .3387 .64983 Metetra
.523 .269 .47 r
.3387 .64983 .34947 .5877 .3609 .5842 .35037 .64639 Metetra
.523 .269 .47 r
.35037 .64639 .3609 .5842 .37237 .58069 .3621 .64293 Metetra
.523 .269 .47 r
.3621 .64293 .37237 .58069 .3839 .57716 .37389 .63945 Metetra
.523 .269 .47 r
.37389 .63945 .3839 .57716 .39547 .57362 .38572 .63596 Metetra
.523 .269 .47 r
.38572 .63596 .39547 .57362 .40709 .57006 .3976 .63245 Metetra
.523 .269 .47 r
.3976 .63245 .40709 .57006 .41877 .56649 .40954 .62893 Metetra
.523 .269 .47 r
.40954 .62893 .41877 .56649 .43049 .5629 .42154 .62539 Metetra
.523 .269 .47 r
.42154 .62539 .43049 .5629 .44227 .55929 .43358 .62183 Metetra
.523 .269 .47 r
.43358 .62183 .44227 .55929 .45409 .55567 .44568 .61826 Metetra
.523 .269 .47 r
.44568 .61826 .45409 .55567 .46597 .55204 .45783 .61468 Metetra
.523 .269 .47 r
.45783 .61468 .46597 .55204 .4779 .54838 .47004 .61108 Metetra
.523 .269 .47 r
.47004 .61108 .4779 .54838 .48989 .54472 .48231 .60746 Metetra
.523 .269 .47 r
.48231 .60746 .48989 .54472 .50192 .54103 .49463 .60382 Metetra
.523 .269 .47 r
.49463 .60382 .50192 .54103 .51401 .53733 .507 .60017 Metetra
.523 .269 .47 r
.507 .60017 .51401 .53733 .52615 .53361 .51943 .5965 Metetra
.523 .269 .47 r
.51943 .5965 .52615 .53361 .53835 .52988 .53192 .59282 Metetra
.523 .269 .47 r
.53192 .59282 .53835 .52988 .5506 .52613 .54446 .58912 Metetra
.523 .269 .47 r
.54446 .58912 .5506 .52613 .56291 .52236 .55706 .5854 Metetra
.523 .269 .47 r
.55706 .5854 .56291 .52236 .57527 .51858 .56972 .58166 Metetra
.523 .269 .47 r
.56972 .58166 .57527 .51858 .58768 .51478 .58244 .57791 Metetra
.523 .269 .47 r
.58244 .57791 .58768 .51478 .60015 .51096 .59521 .57414 Metetra
.523 .269 .47 r
.59521 .57414 .60015 .51096 .61268 .50712 .60805 .57035 Metetra
.523 .269 .47 r
.60805 .57035 .61268 .50712 .62526 .50327 .62094 .56655 Metetra
.523 .269 .47 r
.62094 .56655 .62526 .50327 .6379 .4994 .6339 .56273 Metetra
.523 .269 .47 r
.6339 .56273 .6379 .4994 .6506 .49551 .64691 .55889 Metetra
.523 .269 .47 r
.64691 .55889 .6506 .49551 .66336 .49161 .65998 .55503 Metetra
.523 .269 .47 r
.65998 .55503 .66336 .49161 .67617 .48768 .67312 .55115 Metetra
.523 .269 .47 r
.67312 .55115 .67617 .48768 .68904 .48374 .68631 .54726 Metetra
.523 .269 .47 r
.68631 .54726 .68904 .48374 .70197 .47979 .69957 .54335 Metetra
.523 .269 .47 r
.69957 .54335 .70197 .47979 .71496 .47581 .71289 .53942 Metetra
.523 .269 .47 r
.71289 .53942 .71496 .47581 .72801 .47181 .72628 .53547 Metetra
.523 .269 .47 r
.72628 .53547 .72801 .47181 .74112 .4678 .73972 .5315 Metetra
.523 .269 .47 r
.73972 .5315 .74112 .4678 .75429 .46377 .75323 .52751 Metetra
.523 .269 .47 r
.75323 .52751 .75429 .46377 .76752 .45972 .76681 .52351 Metetra
.523 .269 .47 r
.76681 .52351 .76752 .45972 .78081 .45565 .78044 .51948 Metetra
.523 .269 .47 r
.78044 .51948 .78081 .45565 .79416 .45156 .79415 .51544 Metetra
.523 .269 .47 r
.79415 .51544 .79416 .45156 .80758 .44745 .80792 .51138 Metetra
.523 .269 .47 r
.80792 .51138 .80758 .44745 .82106 .44333 .82175 .5073 Metetra
.523 .269 .47 r
.82175 .5073 .82106 .44333 .8346 .43918 .83565 .50319 Metetra
.523 .269 .47 r
.83565 .50319 .8346 .43918 .8482 .43502 .84962 .49907 Metetra
.523 .269 .47 r
.84962 .49907 .8482 .43502 .86187 .43083 .86365 .49493 Metetra
.523 .269 .47 r
.86365 .49493 .86187 .43083 .8756 .42663 .87776 .49077 Metetra
.523 .269 .47 r
.87776 .49077 .8756 .42663 .8894 .42241 .89193 .48659 Metetra
.523 .269 .47 r
.89193 .48659 .8894 .42241 .90326 .41816 .90617 .48239 Metetra
.471 .161 .358 r
.27125 .69312 .28106 .66684 .29249 .66347 .28281 .68976 Metetra
.471 .161 .358 r
.28281 .68976 .29249 .66347 .30397 .66008 .29442 .68638 Metetra
.471 .161 .358 r
.29442 .68638 .30397 .66008 .31549 .65668 .30608 .68299 Metetra
.471 .161 .358 r
.30608 .68299 .31549 .65668 .32707 .65326 .31779 .67959 Metetra
.471 .161 .358 r
.31779 .67959 .32707 .65326 .3387 .64983 .32955 .67617 Metetra
.471 .161 .358 r
.32955 .67617 .3387 .64983 .35037 .64639 .34137 .67274 Metetra
.471 .161 .358 r
.34137 .67274 .35037 .64639 .3621 .64293 .35324 .66929 Metetra
.471 .161 .358 r
.35324 .66929 .3621 .64293 .37389 .63945 .36516 .66582 Metetra
.471 .161 .358 r
.36516 .66582 .37389 .63945 .38572 .63596 .37714 .66234 Metetra
.471 .161 .358 r
.37714 .66234 .38572 .63596 .3976 .63245 .38917 .65885 Metetra
.471 .161 .358 r
.38917 .65885 .3976 .63245 .40954 .62893 .40125 .65534 Metetra
.471 .161 .358 r
.40125 .65534 .40954 .62893 .42154 .62539 .41339 .65181 Metetra
.471 .161 .358 r
.41339 .65181 .42154 .62539 .43358 .62183 .42558 .64827 Metetra
.471 .161 .358 r
.42558 .64827 .43358 .62183 .44568 .61826 .43783 .64471 Metetra
.471 .161 .358 r
.43783 .64471 .44568 .61826 .45783 .61468 .45013 .64113 Metetra
.471 .161 .358 r
.45013 .64113 .45783 .61468 .47004 .61108 .46249 .63754 Metetra
.471 .161 .358 r
.46249 .63754 .47004 .61108 .48231 .60746 .47491 .63393 Metetra
.471 .161 .358 r
.47491 .63393 .48231 .60746 .49463 .60382 .48739 .6303 Metetra
.471 .161 .358 r
.48739 .6303 .49463 .60382 .507 .60017 .49992 .62666 Metetra
.471 .161 .358 r
.49992 .62666 .507 .60017 .51943 .5965 .5125 .623 Metetra
.471 .161 .358 r
.5125 .623 .51943 .5965 .53192 .59282 .52515 .61933 Metetra
.471 .161 .358 r
.52515 .61933 .53192 .59282 .54446 .58912 .53786 .61564 Metetra
.471 .161 .358 r
.53786 .61564 .54446 .58912 .55706 .5854 .55062 .61193 Metetra
.471 .161 .358 r
.55062 .61193 .55706 .5854 .56972 .58166 .56344 .6082 Metetra
.471 .161 .358 r
.56344 .6082 .56972 .58166 .58244 .57791 .57633 .60446 Metetra
.471 .161 .358 r
.57633 .60446 .58244 .57791 .59521 .57414 .58927 .6007 Metetra
.471 .161 .358 r
.58927 .6007 .59521 .57414 .60805 .57035 .60227 .59692 Metetra
.471 .161 .358 r
.60227 .59692 .60805 .57035 .62094 .56655 .61534 .59312 Metetra
.471 .161 .358 r
.61534 .59312 .62094 .56655 .6339 .56273 .62846 .58931 Metetra
.471 .161 .358 r
.62846 .58931 .6339 .56273 .64691 .55889 .64165 .58547 Metetra
.471 .161 .358 r
.64165 .58547 .64691 .55889 .65998 .55503 .6549 .58162 Metetra
.471 .161 .358 r
.6549 .58162 .65998 .55503 .67312 .55115 .66821 .57775 Metetra
.471 .161 .358 r
.66821 .57775 .67312 .55115 .68631 .54726 .68159 .57387 Metetra
.471 .161 .358 r
.68159 .57387 .68631 .54726 .69957 .54335 .69502 .56996 Metetra
.471 .161 .358 r
.69502 .56996 .69957 .54335 .71289 .53942 .70853 .56604 Metetra
.471 .161 .358 r
.70853 .56604 .71289 .53942 .72628 .53547 .72209 .5621 Metetra
.471 .161 .358 r
.72209 .5621 .72628 .53547 .73972 .5315 .73573 .55813 Metetra
.471 .161 .358 r
.73573 .55813 .73972 .5315 .75323 .52751 .74942 .55415 Metetra
.471 .161 .358 r
.74942 .55415 .75323 .52751 .76681 .52351 .76319 .55015 Metetra
.471 .161 .358 r
.76319 .55015 .76681 .52351 .78044 .51948 .77702 .54613 Metetra
.471 .161 .358 r
.77702 .54613 .78044 .51948 .79415 .51544 .79091 .5421 Metetra
.471 .161 .358 r
.79091 .5421 .79415 .51544 .80792 .51138 .80488 .53804 Metetra
.471 .161 .358 r
.80488 .53804 .80792 .51138 .82175 .5073 .81891 .53396 Metetra
.471 .161 .358 r
.81891 .53396 .82175 .5073 .83565 .50319 .83301 .52986 Metetra
.471 .161 .358 r
.83301 .52986 .83565 .50319 .84962 .49907 .84718 .52574 Metetra
.471 .161 .358 r
.84718 .52574 .84962 .49907 .86365 .49493 .86142 .52161 Metetra
.471 .161 .358 r
.86142 .52161 .86365 .49493 .87776 .49077 .87572 .51745 Metetra
.471 .161 .358 r
.87572 .51745 .87776 .49077 .89193 .48659 .8901 .51327 Metetra
.471 .161 .358 r
.8901 .51327 .89193 .48659 .90617 .48239 .90455 .50907 Metetra
.262 .767 .752 r
.26304 .69491 .27125 .69312 .28281 .68976 .27466 .69154 Metetra
.262 .767 .752 r
.27466 .69154 .28281 .68976 .29442 .68638 .28632 .68815 Metetra
.262 .767 .752 r
.28632 .68815 .29442 .68638 .30608 .68299 .29804 .68474 Metetra
.262 .767 .752 r
.29804 .68474 .30608 .68299 .31779 .67959 .30981 .68132 Metetra
.262 .767 .752 r
.30981 .68132 .31779 .67959 .32955 .67617 .32163 .67788 Metetra
.262 .767 .752 r
.32163 .67788 .32955 .67617 .34137 .67274 .33351 .67443 Metetra
.262 .767 .752 r
.33351 .67443 .34137 .67274 .35324 .66929 .34543 .67096 Metetra
.262 .767 .752 r
.34543 .67096 .35324 .66929 .36516 .66582 .35742 .66748 Metetra
.262 .767 .752 r
.35742 .66748 .36516 .66582 .37714 .66234 .36945 .66398 Metetra
.262 .767 .752 r
.36945 .66398 .37714 .66234 .38917 .65885 .38154 .66046 Metetra
.262 .767 .752 r
.38154 .66046 .38917 .65885 .40125 .65534 .39369 .65693 Metetra
.262 .767 .752 r
.39369 .65693 .40125 .65534 .41339 .65181 .40589 .65338 Metetra
.262 .767 .752 r
.40589 .65338 .41339 .65181 .42558 .64827 .41814 .64982 Metetra
.262 .767 .752 r
.41814 .64982 .42558 .64827 .43783 .64471 .43046 .64624 Metetra
.262 .767 .752 r
.43046 .64624 .43783 .64471 .45013 .64113 .44283 .64265 Metetra
.262 .767 .752 r
.44283 .64265 .45013 .64113 .46249 .63754 .45525 .63903 Metetra
.262 .767 .752 r
.45525 .63903 .46249 .63754 .47491 .63393 .46773 .63541 Metetra
.262 .767 .752 r
.46773 .63541 .47491 .63393 .48739 .6303 .48027 .63176 Metetra
.262 .767 .752 r
.48027 .63176 .48739 .6303 .49992 .62666 .49287 .6281 Metetra
.262 .767 .752 r
.49287 .6281 .49992 .62666 .5125 .623 .50553 .62442 Metetra
.262 .767 .752 r
.50553 .62442 .5125 .623 .52515 .61933 .51824 .62072 Metetra
.262 .767 .752 r
.51824 .62072 .52515 .61933 .53786 .61564 .53102 .61701 Metetra
.262 .767 .752 r
.53102 .61701 .53786 .61564 .55062 .61193 .54385 .61328 Metetra
.262 .767 .752 r
.54385 .61328 .55062 .61193 .56344 .6082 .55674 .60953 Metetra
.262 .767 .752 r
.55674 .60953 .56344 .6082 .57633 .60446 .5697 .60576 Metetra
.262 .767 .752 r
.5697 .60576 .57633 .60446 .58927 .6007 .58271 .60198 Metetra
.262 .767 .752 r
.58271 .60198 .58927 .6007 .60227 .59692 .59579 .59818 Metetra
.262 .767 .752 r
.59579 .59818 .60227 .59692 .61534 .59312 .60892 .59436 Metetra
.262 .767 .752 r
.60892 .59436 .61534 .59312 .62846 .58931 .62212 .59052 Metetra
.262 .767 .752 r
.62212 .59052 .62846 .58931 .64165 .58547 .63539 .58666 Metetra
.262 .767 .752 r
.63539 .58666 .64165 .58547 .6549 .58162 .64871 .58279 Metetra
.262 .767 .752 r
.64871 .58279 .6549 .58162 .66821 .57775 .6621 .5789 Metetra
.262 .767 .752 r
.6621 .5789 .66821 .57775 .68159 .57387 .67555 .57499 Metetra
.262 .767 .752 r
.67555 .57499 .68159 .57387 .69502 .56996 .68907 .57106 Metetra
.262 .767 .752 r
.68907 .57106 .69502 .56996 .70853 .56604 .70265 .56711 Metetra
.262 .767 .752 r
.70265 .56711 .70853 .56604 .72209 .5621 .7163 .56314 Metetra
.262 .767 .752 r
.7163 .56314 .72209 .5621 .73573 .55813 .73001 .55916 Metetra
.262 .767 .752 r
.73001 .55916 .73573 .55813 .74942 .55415 .74379 .55515 Metetra
.262 .767 .752 r
.74379 .55515 .74942 .55415 .76319 .55015 .75764 .55112 Metetra
.262 .767 .752 r
.75764 .55112 .76319 .55015 .77702 .54613 .77155 .54708 Metetra
.262 .767 .752 r
.77155 .54708 .77702 .54613 .79091 .5421 .78553 .54301 Metetra
.262 .767 .752 r
.78553 .54301 .79091 .5421 .80488 .53804 .79958 .53893 Metetra
.262 .767 .752 r
.79958 .53893 .80488 .53804 .81891 .53396 .81369 .53483 Metetra
.262 .767 .752 r
.81369 .53483 .81891 .53396 .83301 .52986 .82788 .5307 Metetra
.262 .767 .752 r
.82788 .5307 .83301 .52986 .84718 .52574 .84214 .52656 Metetra
.262 .767 .752 r
.84214 .52656 .84718 .52574 .86142 .52161 .85646 .52239 Metetra
.262 .767 .752 r
.85646 .52239 .86142 .52161 .87572 .51745 .87086 .51821 Metetra
.262 .767 .752 r
.87086 .51821 .87572 .51745 .8901 .51327 .88533 .514 Metetra
.262 .767 .752 r
.88533 .514 .8901 .51327 .90455 .50907 .89987 .50977 Metetra
.638 .798 .959 r
.25526 .68984 .26304 .69491 .27466 .69154 .26691 .68643 Metetra
.638 .798 .959 r
.26691 .68643 .27466 .69154 .28632 .68815 .27861 .68302 Metetra
.638 .798 .959 r
.27861 .68302 .28632 .68815 .29804 .68474 .29036 .67958 Metetra
.638 .798 .959 r
.29036 .67958 .29804 .68474 .30981 .68132 .30217 .67613 Metetra
.638 .798 .959 r
.30217 .67613 .30981 .68132 .32163 .67788 .31403 .67267 Metetra
.638 .798 .959 r
.31403 .67267 .32163 .67788 .33351 .67443 .32594 .66919 Metetra
.638 .798 .959 r
.32594 .66919 .33351 .67443 .34543 .67096 .3379 .6657 Metetra
.638 .798 .959 r
.3379 .6657 .34543 .67096 .35742 .66748 .34992 .66218 Metetra
.638 .798 .959 r
.34992 .66218 .35742 .66748 .36945 .66398 .36199 .65866 Metetra
.638 .798 .959 r
.36199 .65866 .36945 .66398 .38154 .66046 .37412 .65511 Metetra
.638 .798 .959 r
.37412 .65511 .38154 .66046 .39369 .65693 .38631 .65156 Metetra
.638 .798 .959 r
.38631 .65156 .39369 .65693 .40589 .65338 .39855 .64798 Metetra
.638 .798 .959 r
.39855 .64798 .40589 .65338 .41814 .64982 .41084 .64439 Metetra
.638 .798 .959 r
.41084 .64439 .41814 .64982 .43046 .64624 .42319 .64078 Metetra
.638 .798 .959 r
.42319 .64078 .43046 .64624 .44283 .64265 .4356 .63716 Metetra
.638 .798 .959 r
.4356 .63716 .44283 .64265 .45525 .63903 .44807 .63351 Metetra
.638 .798 .959 r
.44807 .63351 .45525 .63903 .46773 .63541 .46059 .62986 Metetra
.638 .798 .959 r
.46059 .62986 .46773 .63541 .48027 .63176 .47317 .62618 Metetra
.638 .798 .959 r
.47317 .62618 .48027 .63176 .49287 .6281 .48581 .62249 Metetra
.638 .798 .959 r
.48581 .62249 .49287 .6281 .50553 .62442 .49851 .61878 Metetra
.638 .798 .959 r
.49851 .61878 .50553 .62442 .51824 .62072 .51127 .61505 Metetra
.638 .798 .959 r
.51127 .61505 .51824 .62072 .53102 .61701 .52408 .61131 Metetra
.638 .798 .959 r
.52408 .61131 .53102 .61701 .54385 .61328 .53696 .60755 Metetra
.638 .798 .959 r
.53696 .60755 .54385 .61328 .55674 .60953 .5499 .60377 Metetra
.638 .798 .959 r
.5499 .60377 .55674 .60953 .5697 .60576 .5629 .59997 Metetra
.638 .798 .959 r
.5629 .59997 .5697 .60576 .58271 .60198 .57596 .59615 Metetra
.638 .798 .959 r
.57596 .59615 .58271 .60198 .59579 .59818 .58908 .59232 Metetra
.638 .798 .959 r
.58908 .59232 .59579 .59818 .60892 .59436 .60226 .58847 Metetra
.638 .798 .959 r
.60226 .58847 .60892 .59436 .62212 .59052 .61551 .5846 Metetra
.638 .798 .959 r
.61551 .5846 .62212 .59052 .63539 .58666 .62882 .58071 Metetra
.638 .798 .959 r
.62882 .58071 .63539 .58666 .64871 .58279 .64219 .5768 Metetra
.638 .798 .959 r
.64219 .5768 .64871 .58279 .6621 .5789 .65563 .57288 Metetra
.638 .798 .959 r
.65563 .57288 .6621 .5789 .67555 .57499 .66913 .56894 Metetra
.638 .798 .959 r
.66913 .56894 .67555 .57499 .68907 .57106 .6827 .56497 Metetra
.638 .798 .959 r
.6827 .56497 .68907 .57106 .70265 .56711 .69633 .56099 Metetra
.638 .798 .959 r
.69633 .56099 .70265 .56711 .7163 .56314 .71003 .55699 Metetra
.639 .798 .959 r
.71003 .55699 .7163 .56314 .73001 .55916 .72379 .55297 Metetra
.639 .798 .959 r
.72379 .55297 .73001 .55916 .74379 .55515 .73762 .54893 Metetra
.639 .798 .959 r
.73762 .54893 .74379 .55515 .75764 .55112 .75152 .54487 Metetra
.639 .798 .959 r
.75152 .54487 .75764 .55112 .77155 .54708 .76548 .54079 Metetra
.639 .798 .959 r
.76548 .54079 .77155 .54708 .78553 .54301 .77952 .53669 Metetra
.639 .798 .959 r
.77952 .53669 .78553 .54301 .79958 .53893 .79362 .53257 Metetra
.639 .798 .959 r
.79362 .53257 .79958 .53893 .81369 .53483 .80779 .52843 Metetra
.639 .798 .959 r
.80779 .52843 .81369 .53483 .82788 .5307 .82203 .52427 Metetra
.639 .798 .959 r
.82203 .52427 .82788 .5307 .84214 .52656 .83635 .52009 Metetra
.639 .798 .959 r
.83635 .52009 .84214 .52656 .85646 .52239 .85073 .51589 Metetra
.639 .798 .959 r
.85073 .51589 .85646 .52239 .87086 .51821 .86518 .51166 Metetra
.639 .798 .959 r
.86518 .51166 .87086 .51821 .88533 .514 .87971 .50742 Metetra
.639 .798 .959 r
.87971 .50742 .88533 .514 .89987 .50977 .89431 .50315 Metetra
.646 .765 .935 r
.2475 .68362 .25526 .68984 .26691 .68643 .25918 .68019 Metetra
.646 .765 .935 r
.25918 .68019 .26691 .68643 .27861 .68302 .27091 .67674 Metetra
.646 .765 .935 r
.27091 .67674 .27861 .68302 .29036 .67958 .28269 .67328 Metetra
.646 .765 .935 r
.28269 .67328 .29036 .67958 .30217 .67613 .29453 .6698 Metetra
.646 .765 .935 r
.29453 .6698 .30217 .67613 .31403 .67267 .30642 .66631 Metetra
.646 .765 .935 r
.30642 .66631 .31403 .67267 .32594 .66919 .31836 .6628 Metetra
.646 .765 .935 r
.31836 .6628 .32594 .66919 .3379 .6657 .33036 .65928 Metetra
.646 .765 .935 r
.33036 .65928 .3379 .6657 .34992 .66218 .34242 .65574 Metetra
.646 .765 .935 r
.34242 .65574 .34992 .66218 .36199 .65866 .35452 .65218 Metetra
.646 .765 .935 r
.35452 .65218 .36199 .65866 .37412 .65511 .36669 .64861 Metetra
.646 .765 .935 r
.36669 .64861 .37412 .65511 .38631 .65156 .3789 .64502 Metetra
.646 .765 .935 r
.3789 .64502 .38631 .65156 .39855 .64798 .39118 .64141 Metetra
.646 .765 .935 r
.39118 .64141 .39855 .64798 .41084 .64439 .40351 .63779 Metetra
.646 .765 .935 r
.40351 .63779 .41084 .64439 .42319 .64078 .4159 .63415 Metetra
.646 .765 .935 r
.4159 .63415 .42319 .64078 .4356 .63716 .42834 .63049 Metetra
.646 .765 .935 r
.42834 .63049 .4356 .63716 .44807 .63351 .44084 .62682 Metetra
.646 .765 .935 r
.44084 .62682 .44807 .63351 .46059 .62986 .4534 .62313 Metetra
.646 .765 .935 r
.4534 .62313 .46059 .62986 .47317 .62618 .46602 .61943 Metetra
.646 .765 .935 r
.46602 .61943 .47317 .62618 .48581 .62249 .4787 .6157 Metetra
.646 .765 .935 r
.4787 .6157 .48581 .62249 .49851 .61878 .49144 .61196 Metetra
.646 .765 .935 r
.49144 .61196 .49851 .61878 .51127 .61505 .50423 .6082 Metetra
.646 .765 .935 r
.50423 .6082 .51127 .61505 .52408 .61131 .51709 .60442 Metetra
.646 .765 .935 r
.51709 .60442 .52408 .61131 .53696 .60755 .53001 .60063 Metetra
.646 .765 .935 r
.53001 .60063 .53696 .60755 .5499 .60377 .54298 .59682 Metetra
.646 .765 .935 r
.54298 .59682 .5499 .60377 .5629 .59997 .55602 .59299 Metetra
.646 .765 .935 r
.55602 .59299 .5629 .59997 .57596 .59615 .56913 .58914 Metetra
.646 .765 .935 r
.56913 .58914 .57596 .59615 .58908 .59232 .58229 .58527 Metetra
.646 .765 .935 r
.58229 .58527 .58908 .59232 .60226 .58847 .59551 .58139 Metetra
.646 .765 .935 r
.59551 .58139 .60226 .58847 .61551 .5846 .6088 .57748 Metetra
.646 .765 .935 r
.6088 .57748 .61551 .5846 .62882 .58071 .62216 .57356 Metetra
.646 .765 .935 r
.62216 .57356 .62882 .58071 .64219 .5768 .63557 .56962 Metetra
.646 .765 .935 r
.63557 .56962 .64219 .5768 .65563 .57288 .64905 .56566 Metetra
.646 .765 .935 r
.64905 .56566 .65563 .57288 .66913 .56894 .6626 .56168 Metetra
.646 .765 .935 r
.6626 .56168 .66913 .56894 .6827 .56497 .67621 .55768 Metetra
.646 .765 .935 r
.67621 .55768 .6827 .56497 .69633 .56099 .68989 .55366 Metetra
.646 .765 .935 r
.68989 .55366 .69633 .56099 .71003 .55699 .70363 .54963 Metetra
.646 .765 .935 r
.70363 .54963 .71003 .55699 .72379 .55297 .71744 .54557 Metetra
.646 .765 .935 r
.71744 .54557 .72379 .55297 .73762 .54893 .73132 .54149 Metetra
.646 .765 .935 r
.73132 .54149 .73762 .54893 .75152 .54487 .74526 .5374 Metetra
.646 .765 .935 r
.74526 .5374 .75152 .54487 .76548 .54079 .75928 .53328 Metetra
.646 .765 .935 r
.75928 .53328 .76548 .54079 .77952 .53669 .77336 .52914 Metetra
.646 .765 .935 r
.77336 .52914 .77952 .53669 .79362 .53257 .78751 .52499 Metetra
.646 .765 .935 r
.78751 .52499 .79362 .53257 .80779 .52843 .80174 .52081 Metetra
.646 .765 .935 r
.80174 .52081 .80779 .52843 .82203 .52427 .81603 .51661 Metetra
.646 .765 .935 r
.81603 .51661 .82203 .52427 .83635 .52009 .83039 .51239 Metetra
.646 .765 .935 r
.83039 .51239 .83635 .52009 .85073 .51589 .84483 .50815 Metetra
.646 .765 .935 r
.84483 .50815 .85073 .51589 .86518 .51166 .85933 .50389 Metetra
.646 .765 .935 r
.85933 .50389 .86518 .51166 .87971 .50742 .87391 .49961 Metetra
.646 .765 .935 r
.87391 .49961 .87971 .50742 .89431 .50315 .88856 .4953 Metetra
.646 .763 .934 r
.23968 .67729 .2475 .68362 .25918 .68019 .25139 .67383 Metetra
.646 .763 .934 r
.25139 .67383 .25918 .68019 .27091 .67674 .26315 .67036 Metetra
.646 .763 .934 r
.26315 .67036 .27091 .67674 .28269 .67328 .27496 .66687 Metetra
.646 .763 .934 r
.27496 .66687 .28269 .67328 .29453 .6698 .28683 .66336 Metetra
.646 .763 .934 r
.28683 .66336 .29453 .6698 .30642 .66631 .29876 .65984 Metetra
.646 .763 .934 r
.29876 .65984 .30642 .66631 .31836 .6628 .31073 .6563 Metetra
.646 .763 .934 r
.31073 .6563 .31836 .6628 .33036 .65928 .32276 .65275 Metetra
.646 .763 .934 r
.32276 .65275 .33036 .65928 .34242 .65574 .33485 .64918 Metetra
.646 .763 .934 r
.33485 .64918 .34242 .65574 .35452 .65218 .34699 .64559 Metetra
.646 .763 .934 r
.34699 .64559 .35452 .65218 .36669 .64861 .35919 .64199 Metetra
.646 .763 .934 r
.35919 .64199 .36669 .64861 .3789 .64502 .37144 .63837 Metetra
.646 .763 .934 r
.37144 .63837 .3789 .64502 .39118 .64141 .38375 .63473 Metetra
.646 .763 .934 r
.38375 .63473 .39118 .64141 .40351 .63779 .39612 .63108 Metetra
.646 .763 .934 r
.39612 .63108 .40351 .63779 .4159 .63415 .40854 .62741 Metetra
.646 .763 .934 r
.40854 .62741 .4159 .63415 .42834 .63049 .42102 .62372 Metetra
.646 .763 .934 r
.42102 .62372 .42834 .63049 .44084 .62682 .43356 .62002 Metetra
.646 .763 .934 r
.43356 .62002 .44084 .62682 .4534 .62313 .44616 .6163 Metetra
.646 .763 .934 r
.44616 .6163 .4534 .62313 .46602 .61943 .45881 .61256 Metetra
.646 .763 .934 r
.45881 .61256 .46602 .61943 .4787 .6157 .47153 .6088 Metetra
.646 .763 .934 r
.47153 .6088 .4787 .6157 .49144 .61196 .4843 .60503 Metetra
.646 .763 .934 r
.4843 .60503 .49144 .61196 .50423 .6082 .49714 .60124 Metetra
.646 .763 .934 r
.49714 .60124 .50423 .6082 .51709 .60442 .51004 .59743 Metetra
.646 .763 .934 r
.51004 .59743 .51709 .60442 .53001 .60063 .52299 .5936 Metetra
.646 .763 .934 r
.52299 .5936 .53001 .60063 .54298 .59682 .53601 .58976 Metetra
.646 .763 .934 r
.53601 .58976 .54298 .59682 .55602 .59299 .54909 .58589 Metetra
.646 .763 .934 r
.54909 .58589 .55602 .59299 .56913 .58914 .56223 .58201 Metetra
.646 .763 .934 r
.56223 .58201 .56913 .58914 .58229 .58527 .57544 .57811 Metetra
.646 .763 .934 r
.57544 .57811 .58229 .58527 .59551 .58139 .5887 .57419 Metetra
.646 .763 .934 r
.5887 .57419 .59551 .58139 .6088 .57748 .60204 .57025 Metetra
.646 .763 .934 r
.60204 .57025 .6088 .57748 .62216 .57356 .61543 .56629 Metetra
.646 .763 .934 r
.61543 .56629 .62216 .57356 .63557 .56962 .62889 .56232 Metetra
.646 .763 .934 r
.62889 .56232 .63557 .56962 .64905 .56566 .64242 .55832 Metetra
.646 .763 .934 r
.64242 .55832 .64905 .56566 .6626 .56168 .65601 .55431 Metetra
.646 .763 .934 r
.65601 .55431 .6626 .56168 .67621 .55768 .66966 .55027 Metetra
.646 .763 .934 r
.66966 .55027 .67621 .55768 .68989 .55366 .68339 .54622 Metetra
.646 .763 .934 r
.68339 .54622 .68989 .55366 .70363 .54963 .69718 .54215 Metetra
.646 .763 .934 r
.69718 .54215 .70363 .54963 .71744 .54557 .71103 .53805 Metetra
.646 .763 .934 r
.71103 .53805 .71744 .54557 .73132 .54149 .72496 .53394 Metetra
.646 .763 .934 r
.72496 .53394 .73132 .54149 .74526 .5374 .73895 .52981 Metetra
.646 .763 .934 r
.73895 .52981 .74526 .5374 .75928 .53328 .75301 .52565 Metetra
.646 .763 .934 r
.75301 .52565 .75928 .53328 .77336 .52914 .76715 .52148 Metetra
.646 .763 .934 r
.76715 .52148 .77336 .52914 .78751 .52499 .78135 .51728 Metetra
.646 .763 .934 r
.78135 .51728 .78751 .52499 .80174 .52081 .79562 .51307 Metetra
.646 .763 .934 r
.79562 .51307 .80174 .52081 .81603 .51661 .80996 .50883 Metetra
.646 .763 .934 r
.80996 .50883 .81603 .51661 .83039 .51239 .82438 .50457 Metetra
.646 .763 .934 r
.82438 .50457 .83039 .51239 .84483 .50815 .83886 .50029 Metetra
.646 .763 .934 r
.83886 .50029 .84483 .50815 .85933 .50389 .85342 .49599 Metetra
.646 .763 .934 r
.85342 .49599 .85933 .50389 .87391 .49961 .86805 .49167 Metetra
.646 .763 .934 r
.86805 .49167 .87391 .49961 .88856 .4953 .88276 .48732 Metetra
.646 .762 .933 r
.23179 .67088 .23968 .67729 .25139 .67383 .24353 .6674 Metetra
.646 .762 .933 r
.24353 .6674 .25139 .67383 .26315 .67036 .25532 .66389 Metetra
.646 .762 .933 r
.25532 .66389 .26315 .67036 .27496 .66687 .26717 .66037 Metetra
.646 .762 .933 r
.26717 .66037 .27496 .66687 .28683 .66336 .27907 .65684 Metetra
.646 .762 .933 r
.27907 .65684 .28683 .66336 .29876 .65984 .29103 .65329 Metetra
.646 .762 .933 r
.29103 .65329 .29876 .65984 .31073 .6563 .30304 .64972 Metetra
.646 .762 .933 r
.30304 .64972 .31073 .6563 .32276 .65275 .3151 .64613 Metetra
.646 .762 .933 r
.3151 .64613 .32276 .65275 .33485 .64918 .32722 .64253 Metetra
.646 .762 .933 r
.32722 .64253 .33485 .64918 .34699 .64559 .3394 .63892 Metetra
.646 .762 .933 r
.3394 .63892 .34699 .64559 .35919 .64199 .35163 .63528 Metetra
.646 .762 .933 r
.35163 .63528 .35919 .64199 .37144 .63837 .36392 .63163 Metetra
.646 .762 .933 r
.36392 .63163 .37144 .63837 .38375 .63473 .37626 .62796 Metetra
.646 .762 .933 r
.37626 .62796 .38375 .63473 .39612 .63108 .38866 .62428 Metetra
.646 .762 .933 r
.38866 .62428 .39612 .63108 .40854 .62741 .40112 .62058 Metetra
.646 .762 .933 r
.40112 .62058 .40854 .62741 .42102 .62372 .41364 .61686 Metetra
.646 .762 .933 r
.41364 .61686 .42102 .62372 .43356 .62002 .42621 .61312 Metetra
.646 .762 .933 r
.42621 .61312 .43356 .62002 .44616 .6163 .43885 .60937 Metetra
.646 .762 .933 r
.43885 .60937 .44616 .6163 .45881 .61256 .45154 .6056 Metetra
.646 .762 .933 r
.45154 .6056 .45881 .61256 .47153 .6088 .4643 .60181 Metetra
.646 .762 .933 r
.4643 .60181 .47153 .6088 .4843 .60503 .47711 .598 Metetra
.646 .762 .933 r
.47711 .598 .4843 .60503 .49714 .60124 .48998 .59418 Metetra
.646 .762 .933 r
.48998 .59418 .49714 .60124 .51004 .59743 .50292 .59034 Metetra
.646 .762 .933 r
.50292 .59034 .51004 .59743 .52299 .5936 .51592 .58648 Metetra
.646 .762 .933 r
.51592 .58648 .52299 .5936 .53601 .58976 .52897 .5826 Metetra
.646 .762 .933 r
.52897 .5826 .53601 .58976 .54909 .58589 .54209 .5787 Metetra
.646 .762 .933 r
.54209 .5787 .54909 .58589 .56223 .58201 .55528 .57478 Metetra
.646 .762 .933 r
.55528 .57478 .56223 .58201 .57544 .57811 .56852 .57085 Metetra
.646 .762 .933 r
.56852 .57085 .57544 .57811 .5887 .57419 .58183 .56689 Metetra
.646 .762 .933 r
.58183 .56689 .5887 .57419 .60204 .57025 .59521 .56292 Metetra
.646 .762 .933 r
.59521 .56292 .60204 .57025 .61543 .56629 .60865 .55893 Metetra
.646 .762 .933 r
.60865 .55893 .61543 .56629 .62889 .56232 .62215 .55491 Metetra
.646 .762 .933 r
.62215 .55491 .62889 .56232 .64242 .55832 .63572 .55088 Metetra
.646 .762 .933 r
.63572 .55088 .64242 .55832 .65601 .55431 .64936 .54683 Metetra
.646 .762 .933 r
.64936 .54683 .65601 .55431 .66966 .55027 .66306 .54276 Metetra
.646 .762 .933 r
.66306 .54276 .66966 .55027 .68339 .54622 .67683 .53867 Metetra
.646 .762 .933 r
.67683 .53867 .68339 .54622 .69718 .54215 .69066 .53456 Metetra
.646 .762 .933 r
.69066 .53456 .69718 .54215 .71103 .53805 .70457 .53043 Metetra
.646 .762 .933 r
.70457 .53043 .71103 .53805 .72496 .53394 .71854 .52628 Metetra
.646 .762 .933 r
.71854 .52628 .72496 .53394 .73895 .52981 .73258 .52211 Metetra
.646 .762 .933 r
.73258 .52211 .73895 .52981 .75301 .52565 .74669 .51792 Metetra
.646 .762 .933 r
.74669 .51792 .75301 .52565 .76715 .52148 .76087 .5137 Metetra
.646 .762 .933 r
.76087 .5137 .76715 .52148 .78135 .51728 .77512 .50947 Metetra
.646 .762 .933 r
.77512 .50947 .78135 .51728 .79562 .51307 .78944 .50521 Metetra
.646 .762 .933 r
.78944 .50521 .79562 .51307 .80996 .50883 .80384 .50094 Metetra
.646 .762 .933 r
.80384 .50094 .80996 .50883 .82438 .50457 .8183 .49664 Metetra
.646 .762 .933 r
.8183 .49664 .82438 .50457 .83886 .50029 .83284 .49232 Metetra
.646 .762 .933 r
.83284 .49232 .83886 .50029 .85342 .49599 .84745 .48798 Metetra
.646 .762 .933 r
.84745 .48798 .85342 .49599 .86805 .49167 .86214 .48362 Metetra
.646 .762 .933 r
.86214 .48362 .86805 .49167 .88276 .48732 .87689 .47923 Metetra
.646 .763 .934 r
.22384 .66444 .23179 .67088 .24353 .6674 .23561 .66092 Metetra
.646 .763 .934 r
.23561 .66092 .24353 .6674 .25532 .66389 .24743 .65739 Metetra
.646 .763 .934 r
.24743 .65739 .25532 .66389 .26717 .66037 .25931 .65384 Metetra
.646 .763 .934 r
.25931 .65384 .26717 .66037 .27907 .65684 .27125 .65027 Metetra
.646 .763 .934 r
.27125 .65027 .27907 .65684 .29103 .65329 .28323 .64669 Metetra
.646 .763 .934 r
.28323 .64669 .29103 .65329 .30304 .64972 .29528 .64309 Metetra
.646 .763 .934 r
.29528 .64309 .30304 .64972 .3151 .64613 .30737 .63948 Metetra
.646 .763 .934 r
.30737 .63948 .3151 .64613 .32722 .64253 .31953 .63585 Metetra
.646 .763 .934 r
.31953 .63585 .32722 .64253 .3394 .63892 .33174 .6322 Metetra
.646 .763 .934 r
.33174 .6322 .3394 .63892 .35163 .63528 .344 .62854 Metetra
.646 .763 .934 r
.344 .62854 .35163 .63528 .36392 .63163 .35632 .62485 Metetra
.646 .763 .934 r
.35632 .62485 .36392 .63163 .37626 .62796 .3687 .62116 Metetra
.646 .763 .934 r
.3687 .62116 .37626 .62796 .38866 .62428 .38114 .61744 Metetra
.646 .763 .934 r
.38114 .61744 .38866 .62428 .40112 .62058 .39364 .61371 Metetra
.646 .763 .934 r
.39364 .61371 .40112 .62058 .41364 .61686 .40619 .60996 Metetra
.646 .763 .934 r
.40619 .60996 .41364 .61686 .42621 .61312 .4188 .60619 Metetra
.646 .763 .934 r
.4188 .60619 .42621 .61312 .43885 .60937 .43148 .6024 Metetra
.646 .763 .934 r
.43148 .6024 .43885 .60937 .45154 .6056 .44421 .5986 Metetra
.646 .763 .934 r
.44421 .5986 .45154 .6056 .4643 .60181 .457 .59477 Metetra
.646 .763 .934 r
.457 .59477 .4643 .60181 .47711 .598 .46985 .59093 Metetra
.646 .763 .934 r
.46985 .59093 .47711 .598 .48998 .59418 .48277 .58708 Metetra
.646 .763 .934 r
.48277 .58708 .48998 .59418 .50292 .59034 .49574 .5832 Metetra
.646 .763 .934 r
.49574 .5832 .50292 .59034 .51592 .58648 .50878 .5793 Metetra
.646 .763 .934 r
.50878 .5793 .51592 .58648 .52897 .5826 .52188 .57539 Metetra
.646 .763 .934 r
.52188 .57539 .52897 .5826 .54209 .5787 .53504 .57146 Metetra
.646 .763 .934 r
.53504 .57146 .54209 .5787 .55528 .57478 .54826 .56751 Metetra
.646 .763 .934 r
.54826 .56751 .55528 .57478 .56852 .57085 .56155 .56354 Metetra
.646 .763 .934 r
.56155 .56354 .56852 .57085 .58183 .56689 .5749 .55955 Metetra
.646 .763 .934 r
.5749 .55955 .58183 .56689 .59521 .56292 .58832 .55554 Metetra
.646 .763 .934 r
.58832 .55554 .59521 .56292 .60865 .55893 .6018 .55151 Metetra
.646 .763 .934 r
.6018 .55151 .60865 .55893 .62215 .55491 .61535 .54746 Metetra
.646 .763 .934 r
.61535 .54746 .62215 .55491 .63572 .55088 .62896 .5434 Metetra
.646 .763 .934 r
.62896 .5434 .63572 .55088 .64936 .54683 .64264 .53931 Metetra
.646 .763 .934 r
.64264 .53931 .64936 .54683 .66306 .54276 .65639 .5352 Metetra
.646 .763 .934 r
.65639 .5352 .66306 .54276 .67683 .53867 .67021 .53107 Metetra
.646 .763 .934 r
.67021 .53107 .67683 .53867 .69066 .53456 .68409 .52693 Metetra
.646 .763 .934 r
.68409 .52693 .69066 .53456 .70457 .53043 .69804 .52276 Metetra
.646 .763 .934 r
.69804 .52276 .70457 .53043 .71854 .52628 .71206 .51857 Metetra
.646 .763 .934 r
.71206 .51857 .71854 .52628 .73258 .52211 .72615 .51436 Metetra
.646 .763 .934 r
.72615 .51436 .73258 .52211 .74669 .51792 .74031 .51013 Metetra
.646 .763 .934 r
.74031 .51013 .74669 .51792 .76087 .5137 .75454 .50588 Metetra
.646 .763 .934 r
.75454 .50588 .76087 .5137 .77512 .50947 .76884 .5016 Metetra
.646 .763 .934 r
.76884 .5016 .77512 .50947 .78944 .50521 .78321 .49731 Metetra
.646 .763 .934 r
.78321 .49731 .78944 .50521 .80384 .50094 .79765 .49299 Metetra
.646 .763 .934 r
.79765 .49299 .80384 .50094 .8183 .49664 .81217 .48866 Metetra
.646 .763 .934 r
.81217 .48866 .8183 .49664 .83284 .49232 .82676 .4843 Metetra
.646 .763 .934 r
.82676 .4843 .83284 .49232 .84745 .48798 .84143 .47992 Metetra
.646 .763 .934 r
.84143 .47992 .84745 .48798 .86214 .48362 .85616 .47551 Metetra
.646 .763 .934 r
.85616 .47551 .86214 .48362 .87689 .47923 .87098 .47109 Metetra
.646 .762 .934 r
.21582 .65793 .22384 .66444 .23561 .66092 .22762 .65439 Metetra
.646 .762 .934 r
.22762 .65439 .23561 .66092 .24743 .65739 .23948 .65082 Metetra
.646 .762 .934 r
.23948 .65082 .24743 .65739 .25931 .65384 .25139 .64724 Metetra
.646 .762 .934 r
.25139 .64724 .25931 .65384 .27125 .65027 .26335 .64365 Metetra
.646 .762 .934 r
.26335 .64365 .27125 .65027 .28323 .64669 .27537 .64004 Metetra
.646 .762 .934 r
.27537 .64004 .28323 .64669 .29528 .64309 .28745 .63641 Metetra
.646 .762 .934 r
.28745 .63641 .29528 .64309 .30737 .63948 .29958 .63276 Metetra
.646 .762 .934 r
.29958 .63276 .30737 .63948 .31953 .63585 .31177 .6291 Metetra
.646 .762 .934 r
.31177 .6291 .31953 .63585 .33174 .6322 .32401 .62542 Metetra
.646 .762 .934 r
.32401 .62542 .33174 .6322 .344 .62854 .33631 .62173 Metetra
.646 .762 .934 r
.33631 .62173 .344 .62854 .35632 .62485 .34867 .61801 Metetra
.646 .762 .934 r
.34867 .61801 .35632 .62485 .3687 .62116 .36108 .61428 Metetra
.646 .762 .934 r
.36108 .61428 .3687 .62116 .38114 .61744 .37356 .61053 Metetra
.646 .762 .934 r
.37356 .61053 .38114 .61744 .39364 .61371 .38609 .60677 Metetra
.646 .762 .934 r
.38609 .60677 .39364 .61371 .40619 .60996 .39868 .60298 Metetra
.646 .762 .934 r
.39868 .60298 .40619 .60996 .4188 .60619 .41133 .59918 Metetra
.646 .762 .934 r
.41133 .59918 .4188 .60619 .43148 .6024 .42404 .59536 Metetra
.646 .762 .934 r
.42404 .59536 .43148 .6024 .44421 .5986 .43681 .59153 Metetra
.646 .762 .934 r
.43681 .59153 .44421 .5986 .457 .59477 .44964 .58767 Metetra
.646 .762 .934 r
.44964 .58767 .457 .59477 .46985 .59093 .46253 .5838 Metetra
.646 .762 .934 r
.46253 .5838 .46985 .59093 .48277 .58708 .47548 .57991 Metetra
.646 .762 .934 r
.47548 .57991 .48277 .58708 .49574 .5832 .4885 .57599 Metetra
.646 .762 .934 r
.4885 .57599 .49574 .5832 .50878 .5793 .50158 .57206 Metetra
.646 .762 .934 r
.50158 .57206 .50878 .5793 .52188 .57539 .51472 .56812 Metetra
.646 .762 .934 r
.51472 .56812 .52188 .57539 .53504 .57146 .52792 .56415 Metetra
.646 .762 .934 r
.52792 .56415 .53504 .57146 .54826 .56751 .54118 .56016 Metetra
.646 .762 .934 r
.54118 .56016 .54826 .56751 .56155 .56354 .55452 .55616 Metetra
.646 .762 .934 r
.55452 .55616 .56155 .56354 .5749 .55955 .56791 .55213 Metetra
.646 .762 .934 r
.56791 .55213 .5749 .55955 .58832 .55554 .58137 .54809 Metetra
.646 .762 .934 r
.58137 .54809 .58832 .55554 .6018 .55151 .5949 .54402 Metetra
.646 .762 .934 r
.5949 .54402 .6018 .55151 .61535 .54746 .60849 .53994 Metetra
.646 .762 .934 r
.60849 .53994 .61535 .54746 .62896 .5434 .62215 .53583 Metetra
.646 .762 .934 r
.62215 .53583 .62896 .5434 .64264 .53931 .63587 .53171 Metetra
.646 .762 .934 r
.63587 .53171 .64264 .53931 .65639 .5352 .64966 .52757 Metetra
.646 .762 .934 r
.64966 .52757 .65639 .5352 .67021 .53107 .66353 .5234 Metetra
.646 .762 .934 r
.66353 .5234 .67021 .53107 .68409 .52693 .67745 .51921 Metetra
.646 .762 .934 r
.67745 .51921 .68409 .52693 .69804 .52276 .69145 .51501 Metetra
.646 .762 .934 r
.69145 .51501 .69804 .52276 .71206 .51857 .70552 .51078 Metetra
.646 .762 .934 r
.70552 .51078 .71206 .51857 .72615 .51436 .71966 .50653 Metetra
.646 .762 .934 r
.71966 .50653 .72615 .51436 .74031 .51013 .73387 .50226 Metetra
.646 .762 .934 r
.73387 .50226 .74031 .51013 .75454 .50588 .74815 .49797 Metetra
.646 .762 .934 r
.74815 .49797 .75454 .50588 .76884 .5016 .7625 .49366 Metetra
.646 .762 .934 r
.7625 .49366 .76884 .5016 .78321 .49731 .77692 .48933 Metetra
.646 .762 .934 r
.77692 .48933 .78321 .49731 .79765 .49299 .79142 .48497 Metetra
.646 .762 .934 r
.79142 .48497 .79765 .49299 .81217 .48866 .80599 .48059 Metetra
.646 .762 .934 r
.80599 .48059 .81217 .48866 .82676 .4843 .82063 .47619 Metetra
.646 .762 .934 r
.82063 .47619 .82676 .4843 .84143 .47992 .83535 .47177 Metetra
.646 .762 .934 r
.83535 .47177 .84143 .47992 .85616 .47551 .85014 .46732 Metetra
.646 .762 .934 r
.85014 .46732 .85616 .47551 .87098 .47109 .86501 .46286 Metetra
.646 .762 .934 r
.20773 .65137 .21582 .65793 .22762 .65439 .21957 .64779 Metetra
.646 .762 .934 r
.21957 .64779 .22762 .65439 .23948 .65082 .23145 .6442 Metetra
.646 .762 .934 r
.23145 .6442 .23948 .65082 .25139 .64724 .2434 .64059 Metetra
.646 .762 .934 r
.2434 .64059 .25139 .64724 .26335 .64365 .25539 .63696 Metetra
.646 .762 .934 r
.25539 .63696 .26335 .64365 .27537 .64004 .26745 .63332 Metetra
.646 .762 .934 r
.26745 .63332 .27537 .64004 .28745 .63641 .27956 .62966 Metetra
.646 .762 .934 r
.27956 .62966 .28745 .63641 .29958 .63276 .29172 .62598 Metetra
.646 .762 .934 r
.29172 .62598 .29958 .63276 .31177 .6291 .30394 .62229 Metetra
.646 .762 .934 r
.30394 .62229 .31177 .6291 .32401 .62542 .31622 .61858 Metetra
.646 .762 .934 r
.31622 .61858 .32401 .62542 .33631 .62173 .32856 .61485 Metetra
.646 .762 .934 r
.32856 .61485 .33631 .62173 .34867 .61801 .34095 .61111 Metetra
.646 .762 .934 r
.34095 .61111 .34867 .61801 .36108 .61428 .3534 .60734 Metetra
.646 .762 .934 r
.3534 .60734 .36108 .61428 .37356 .61053 .36591 .60356 Metetra
.646 .762 .934 r
.36591 .60356 .37356 .61053 .38609 .60677 .37848 .59976 Metetra
.646 .762 .934 r
.37848 .59976 .38609 .60677 .39868 .60298 .3911 .59595 Metetra
.646 .762 .934 r
.3911 .59595 .39868 .60298 .41133 .59918 .40379 .59211 Metetra
.646 .762 .934 r
.40379 .59211 .41133 .59918 .42404 .59536 .41654 .58826 Metetra
.646 .762 .934 r
.41654 .58826 .42404 .59536 .43681 .59153 .42935 .58439 Metetra
.646 .762 .934 r
.42935 .58439 .43681 .59153 .44964 .58767 .44222 .5805 Metetra
.646 .762 .934 r
.44222 .5805 .44964 .58767 .46253 .5838 .45515 .57659 Metetra
.646 .762 .934 r
.45515 .57659 .46253 .5838 .47548 .57991 .46814 .57266 Metetra
.646 .762 .934 r
.46814 .57266 .47548 .57991 .4885 .57599 .48119 .56872 Metetra
.646 .762 .934 r
.48119 .56872 .4885 .57599 .50158 .57206 .49431 .56475 Metetra
.646 .762 .934 r
.49431 .56475 .50158 .57206 .51472 .56812 .50749 .56077 Metetra
.646 .762 .934 r
.50749 .56077 .51472 .56812 .52792 .56415 .52073 .55677 Metetra
.646 .762 .934 r
.52073 .55677 .52792 .56415 .54118 .56016 .53404 .55275 Metetra
.646 .762 .934 r
.53404 .55275 .54118 .56016 .55452 .55616 .54742 .5487 Metetra
.646 .762 .934 r
.54742 .5487 .55452 .55616 .56791 .55213 .56085 .54464 Metetra
.646 .762 .934 r
.56085 .54464 .56791 .55213 .58137 .54809 .57436 .54056 Metetra
.646 .762 .934 r
.57436 .54056 .58137 .54809 .5949 .54402 .58793 .53646 Metetra
.646 .762 .934 r
.58793 .53646 .5949 .54402 .60849 .53994 .60156 .53234 Metetra
.646 .762 .934 r
.60156 .53234 .60849 .53994 .62215 .53583 .61527 .5282 Metetra
.646 .762 .934 r
.61527 .5282 .62215 .53583 .63587 .53171 .62904 .52404 Metetra
.646 .762 .934 r
.62904 .52404 .63587 .53171 .64966 .52757 .64288 .51985 Metetra
.646 .762 .934 r
.64288 .51985 .64966 .52757 .66353 .5234 .65678 .51565 Metetra
.646 .762 .934 r
.65678 .51565 .66353 .5234 .67745 .51921 .67076 .51143 Metetra
.646 .762 .934 r
.67076 .51143 .67745 .51921 .69145 .51501 .68481 .50718 Metetra
.646 .762 .934 r
.68481 .50718 .69145 .51501 .70552 .51078 .69892 .50291 Metetra
.646 .762 .934 r
.69892 .50291 .70552 .51078 .71966 .50653 .71311 .49863 Metetra
.646 .762 .934 r
.71311 .49863 .71966 .50653 .73387 .50226 .72737 .49432 Metetra
.646 .762 .934 r
.72737 .49432 .73387 .50226 .74815 .49797 .7417 .48999 Metetra
.646 .762 .934 r
.7417 .48999 .74815 .49797 .7625 .49366 .7561 .48563 Metetra
.646 .762 .934 r
.7561 .48563 .7625 .49366 .77692 .48933 .77057 .48126 Metetra
.646 .762 .934 r
.77057 .48126 .77692 .48933 .79142 .48497 .78512 .47686 Metetra
.646 .762 .934 r
.78512 .47686 .79142 .48497 .80599 .48059 .79974 .47244 Metetra
.646 .762 .934 r
.79974 .47244 .80599 .48059 .82063 .47619 .81444 .468 Metetra
.646 .762 .934 r
.81444 .468 .82063 .47619 .83535 .47177 .82921 .46354 Metetra
.646 .762 .934 r
.82921 .46354 .83535 .47177 .85014 .46732 .84405 .45905 Metetra
.646 .762 .934 r
.84405 .45905 .85014 .46732 .86501 .46286 .85898 .45454 Metetra
.646 .763 .934 r
.19958 .64476 .20773 .65137 .21957 .64779 .21144 .64116 Metetra
.646 .763 .934 r
.21144 .64116 .21957 .64779 .23145 .6442 .22336 .63753 Metetra
.646 .763 .934 r
.22336 .63753 .23145 .6442 .2434 .64059 .23534 .63389 Metetra
.646 .763 .934 r
.23534 .63389 .2434 .64059 .25539 .63696 .24737 .63024 Metetra
.646 .763 .934 r
.24737 .63024 .25539 .63696 .26745 .63332 .25945 .62656 Metetra
.646 .763 .934 r
.25945 .62656 .26745 .63332 .27956 .62966 .27159 .62287 Metetra
.646 .763 .934 r
.27159 .62287 .27956 .62966 .29172 .62598 .28379 .61916 Metetra
.646 .763 .934 r
.28379 .61916 .29172 .62598 .30394 .62229 .29605 .61544 Metetra
.646 .763 .934 r
.29605 .61544 .30394 .62229 .31622 .61858 .30836 .61169 Metetra
.646 .763 .934 r
.30836 .61169 .31622 .61858 .32856 .61485 .32073 .60793 Metetra
.646 .763 .934 r
.32073 .60793 .32856 .61485 .34095 .61111 .33316 .60416 Metetra
.646 .763 .934 r
.33316 .60416 .34095 .61111 .3534 .60734 .34565 .60036 Metetra
.646 .763 .934 r
.34565 .60036 .3534 .60734 .36591 .60356 .35819 .59655 Metetra
.646 .763 .934 r
.35819 .59655 .36591 .60356 .37848 .59976 .3708 .59272 Metetra
.646 .763 .934 r
.3708 .59272 .37848 .59976 .3911 .59595 .38346 .58887 Metetra
.646 .763 .934 r
.38346 .58887 .3911 .59595 .40379 .59211 .39619 .585 Metetra
.646 .763 .934 r
.39619 .585 .40379 .59211 .41654 .58826 .40897 .58111 Metetra
.646 .763 .934 r
.40897 .58111 .41654 .58826 .42935 .58439 .42182 .57721 Metetra
.646 .763 .934 r
.42182 .57721 .42935 .58439 .44222 .5805 .43472 .57328 Metetra
.646 .763 .934 r
.43472 .57328 .44222 .5805 .45515 .57659 .44769 .56934 Metetra
.646 .763 .934 r
.44769 .56934 .45515 .57659 .46814 .57266 .46073 .56538 Metetra
.646 .763 .934 r
.46073 .56538 .46814 .57266 .48119 .56872 .47382 .5614 Metetra
.646 .763 .934 r
.47382 .5614 .48119 .56872 .49431 .56475 .48698 .5574 Metetra
.646 .763 .934 r
.48698 .5574 .49431 .56475 .50749 .56077 .5002 .55338 Metetra
.646 .763 .934 r
.5002 .55338 .50749 .56077 .52073 .55677 .51349 .54934 Metetra
.646 .763 .934 r
.51349 .54934 .52073 .55677 .53404 .55275 .52684 .54528 Metetra
.646 .763 .934 r
.52684 .54528 .53404 .55275 .54742 .5487 .54025 .5412 Metetra
.646 .763 .934 r
.54025 .5412 .54742 .5487 .56085 .54464 .55373 .53711 Metetra
.646 .763 .934 r
.55373 .53711 .56085 .54464 .57436 .54056 .56728 .53299 Metetra
.646 .763 .934 r
.56728 .53299 .57436 .54056 .58793 .53646 .5809 .52885 Metetra
.646 .763 .934 r
.5809 .52885 .58793 .53646 .60156 .53234 .59458 .52469 Metetra
.646 .763 .934 r
.59458 .52469 .60156 .53234 .61527 .5282 .60833 .52051 Metetra
.646 .763 .934 r
.60833 .52051 .61527 .5282 .62904 .52404 .62214 .51631 Metetra
.646 .763 .934 r
.62214 .51631 .62904 .52404 .64288 .51985 .63603 .51209 Metetra
.646 .763 .934 r
.63603 .51209 .64288 .51985 .65678 .51565 .64998 .50785 Metetra
.646 .763 .934 r
.64998 .50785 .65678 .51565 .67076 .51143 .664 .50358 Metetra
.646 .763 .934 r
.664 .50358 .67076 .51143 .68481 .50718 .6781 .4993 Metetra
.646 .763 .934 r
.6781 .4993 .68481 .50718 .69892 .50291 .69226 .49499 Metetra
.646 .763 .934 r
.69226 .49499 .69892 .50291 .71311 .49863 .7065 .49067 Metetra
.646 .763 .934 r
.7065 .49067 .71311 .49863 .72737 .49432 .72081 .48632 Metetra
.646 .763 .934 r
.72081 .48632 .72737 .49432 .7417 .48999 .73519 .48195 Metetra
.646 .763 .934 r
.73519 .48195 .7417 .48999 .7561 .48563 .74964 .47755 Metetra
.646 .763 .934 r
.74964 .47755 .7561 .48563 .77057 .48126 .76416 .47314 Metetra
.646 .763 .934 r
.76416 .47314 .77057 .48126 .78512 .47686 .77876 .4687 Metetra
.646 .763 .934 r
.77876 .4687 .78512 .47686 .79974 .47244 .79344 .46424 Metetra
.646 .763 .934 r
.79344 .46424 .79974 .47244 .81444 .468 .80819 .45976 Metetra
.646 .763 .934 r
.80819 .45976 .81444 .468 .82921 .46354 .82301 .45525 Metetra
.646 .763 .934 r
.82301 .45525 .82921 .46354 .84405 .45905 .83791 .45072 Metetra
.646 .763 .934 r
.83791 .45072 .84405 .45905 .85898 .45454 .85289 .44617 Metetra
.646 .762 .933 r
.19135 .63807 .19958 .64476 .21144 .64116 .20325 .63443 Metetra
.646 .762 .933 r
.20325 .63443 .21144 .64116 .22336 .63753 .2152 .63078 Metetra
.646 .762 .933 r
.2152 .63078 .22336 .63753 .23534 .63389 .22721 .6271 Metetra
.646 .762 .933 r
.22721 .6271 .23534 .63389 .24737 .63024 .23927 .62342 Metetra
.646 .762 .933 r
.23927 .62342 .24737 .63024 .25945 .62656 .25139 .61971 Metetra
.646 .762 .933 r
.25139 .61971 .25945 .62656 .27159 .62287 .26357 .61599 Metetra
.646 .762 .933 r
.26357 .61599 .27159 .62287 .28379 .61916 .2758 .61225 Metetra
.646 .762 .933 r
.2758 .61225 .28379 .61916 .29605 .61544 .28809 .60849 Metetra
.646 .762 .933 r
.28809 .60849 .29605 .61544 .30836 .61169 .30044 .60472 Metetra
.646 .762 .933 r
.30044 .60472 .30836 .61169 .32073 .60793 .31284 .60092 Metetra
.646 .762 .933 r
.31284 .60092 .32073 .60793 .33316 .60416 .3253 .59711 Metetra
.646 .762 .933 r
.3253 .59711 .33316 .60416 .34565 .60036 .33783 .59328 Metetra
.646 .762 .933 r
.33783 .59328 .34565 .60036 .35819 .59655 .35041 .58944 Metetra
.646 .762 .933 r
.35041 .58944 .35819 .59655 .3708 .59272 .36305 .58557 Metetra
.646 .762 .933 r
.36305 .58557 .3708 .59272 .38346 .58887 .37575 .58169 Metetra
.646 .762 .933 r
.37575 .58169 .38346 .58887 .39619 .585 .38851 .57778 Metetra
.646 .762 .933 r
.38851 .57778 .39619 .585 .40897 .58111 .40134 .57386 Metetra
.646 .762 .933 r
.40134 .57386 .40897 .58111 .42182 .57721 .41422 .56992 Metetra
.646 .762 .933 r
.41422 .56992 .42182 .57721 .43472 .57328 .42717 .56596 Metetra
.646 .762 .933 r
.42717 .56596 .43472 .57328 .44769 .56934 .44018 .56199 Metetra
.646 .762 .933 r
.44018 .56199 .44769 .56934 .46073 .56538 .45325 .55799 Metetra
.646 .762 .933 r
.45325 .55799 .46073 .56538 .47382 .5614 .46639 .55397 Metetra
.646 .762 .933 r
.46639 .55397 .47382 .5614 .48698 .5574 .47958 .54994 Metetra
.646 .762 .933 r
.47958 .54994 .48698 .5574 .5002 .55338 .49285 .54588 Metetra
.646 .762 .933 r
.49285 .54588 .5002 .55338 .51349 .54934 .50617 .54181 Metetra
.646 .762 .933 r
.50617 .54181 .51349 .54934 .52684 .54528 .51957 .53771 Metetra
.646 .762 .933 r
.51957 .53771 .52684 .54528 .54025 .5412 .53303 .5336 Metetra
.646 .762 .933 r
.53303 .5336 .54025 .5412 .55373 .53711 .54655 .52946 Metetra
.646 .762 .933 r
.54655 .52946 .55373 .53711 .56728 .53299 .56014 .52531 Metetra
.646 .762 .933 r
.56014 .52531 .56728 .53299 .5809 .52885 .5738 .52113 Metetra
.646 .762 .933 r
.5738 .52113 .5809 .52885 .59458 .52469 .58753 .51693 Metetra
.646 .762 .933 r
.58753 .51693 .59458 .52469 .60833 .52051 .60132 .51272 Metetra
.646 .762 .933 r
.60132 .51272 .60833 .52051 .62214 .51631 .61518 .50848 Metetra
.646 .762 .933 r
.61518 .50848 .62214 .51631 .63603 .51209 .62911 .50422 Metetra
.646 .762 .933 r
.62911 .50422 .63603 .51209 .64998 .50785 .64311 .49994 Metetra
.646 .762 .933 r
.64311 .49994 .64998 .50785 .664 .50358 .65719 .49563 Metetra
.646 .762 .933 r
.65719 .49563 .664 .50358 .6781 .4993 .67133 .49131 Metetra
.646 .762 .933 r
.67133 .49131 .6781 .4993 .69226 .49499 .68554 .48696 Metetra
.646 .762 .933 r
.68554 .48696 .69226 .49499 .7065 .49067 .69983 .4826 Metetra
.646 .762 .933 r
.69983 .4826 .7065 .49067 .72081 .48632 .71418 .47821 Metetra
.646 .762 .933 r
.71418 .47821 .72081 .48632 .73519 .48195 .72861 .4738 Metetra
.646 .762 .933 r
.72861 .4738 .73519 .48195 .74964 .47755 .74312 .46936 Metetra
.646 .762 .933 r
.74312 .46936 .74964 .47755 .76416 .47314 .75769 .4649 Metetra
.646 .762 .933 r
.75769 .4649 .76416 .47314 .77876 .4687 .77235 .46042 Metetra
.646 .762 .933 r
.77235 .46042 .77876 .4687 .79344 .46424 .78707 .45592 Metetra
.646 .762 .933 r
.78707 .45592 .79344 .46424 .80819 .45976 .80187 .45139 Metetra
.646 .762 .933 r
.80187 .45139 .80819 .45976 .82301 .45525 .81675 .44684 Metetra
.646 .762 .933 r
.81675 .44684 .82301 .45525 .83791 .45072 .83171 .44227 Metetra
.646 .762 .933 r
.83171 .44227 .83791 .45072 .85289 .44617 .84674 .43768 Metetra
.646 .76 .932 r
.18307 .63126 .19135 .63807 .20325 .63443 .195 .6276 Metetra
.646 .76 .932 r
.195 .6276 .20325 .63443 .2152 .63078 .20698 .62391 Metetra
.646 .76 .932 r
.20698 .62391 .2152 .63078 .22721 .6271 .21902 .62021 Metetra
.646 .76 .932 r
.21902 .62021 .22721 .6271 .23927 .62342 .23111 .61649 Metetra
.646 .76 .932 r
.23111 .61649 .23927 .62342 .25139 .61971 .24327 .61275 Metetra
.646 .76 .932 r
.24327 .61275 .25139 .61971 .26357 .61599 .25547 .60899 Metetra
.646 .76 .932 r
.25547 .60899 .26357 .61599 .2758 .61225 .26774 .60522 Metetra
.646 .76 .932 r
.26774 .60522 .2758 .61225 .28809 .60849 .28006 .60143 Metetra
.646 .76 .932 r
.28006 .60143 .28809 .60849 .30044 .60472 .29244 .59762 Metetra
.646 .76 .932 r
.29244 .59762 .30044 .60472 .31284 .60092 .30488 .5938 Metetra
.646 .76 .932 r
.30488 .5938 .31284 .60092 .3253 .59711 .31738 .58995 Metetra
.646 .76 .932 r
.31738 .58995 .3253 .59711 .33783 .59328 .32994 .58609 Metetra
.646 .76 .932 r
.32994 .58609 .33783 .59328 .35041 .58944 .34256 .58221 Metetra
.646 .76 .932 r
.34256 .58221 .35041 .58944 .36305 .58557 .35524 .57831 Metetra
.646 .76 .932 r
.35524 .57831 .36305 .58557 .37575 .58169 .36798 .57439 Metetra
.646 .76 .932 r
.36798 .57439 .37575 .58169 .38851 .57778 .38078 .57045 Metetra
.646 .76 .932 r
.38078 .57045 .38851 .57778 .40134 .57386 .39364 .5665 Metetra
.646 .76 .932 r
.39364 .5665 .40134 .57386 .41422 .56992 .40656 .56252 Metetra
.646 .76 .932 r
.40656 .56252 .41422 .56992 .42717 .56596 .41955 .55853 Metetra
.646 .76 .932 r
.41955 .55853 .42717 .56596 .44018 .56199 .4326 .55452 Metetra
.646 .76 .932 r
.4326 .55452 .44018 .56199 .45325 .55799 .44571 .55048 Metetra
.646 .76 .932 r
.44571 .55048 .45325 .55799 .46639 .55397 .45888 .54643 Metetra
.646 .76 .932 r
.45888 .54643 .46639 .55397 .47958 .54994 .47212 .54236 Metetra
.646 .76 .932 r
.47212 .54236 .47958 .54994 .49285 .54588 .48543 .53827 Metetra
.646 .76 .932 r
.48543 .53827 .49285 .54588 .50617 .54181 .4988 .53416 Metetra
.646 .76 .932 r
.4988 .53416 .50617 .54181 .51957 .53771 .51223 .53002 Metetra
.646 .76 .932 r
.51223 .53002 .51957 .53771 .53303 .5336 .52573 .52587 Metetra
.646 .76 .932 r
.52573 .52587 .53303 .5336 .54655 .52946 .5393 .5217 Metetra
.646 .76 .932 r
.5393 .5217 .54655 .52946 .56014 .52531 .55294 .5175 Metetra
.646 .76 .932 r
.55294 .5175 .56014 .52531 .5738 .52113 .56664 .51329 Metetra
.646 .76 .932 r
.56664 .51329 .5738 .52113 .58753 .51693 .58041 .50905 Metetra
.646 .76 .932 r
.58041 .50905 .58753 .51693 .60132 .51272 .59425 .5048 Metetra
.646 .76 .932 r
.59425 .5048 .60132 .51272 .61518 .50848 .60816 .50052 Metetra
.646 .76 .932 r
.60816 .50052 .61518 .50848 .62911 .50422 .62213 .49622 Metetra
.646 .76 .932 r
.62213 .49622 .62911 .50422 .64311 .49994 .63618 .4919 Metetra
.646 .76 .932 r
.63618 .4919 .64311 .49994 .65719 .49563 .6503 .48756 Metetra
.646 .76 .932 r
.6503 .48756 .65719 .49563 .67133 .49131 .66449 .48319 Metetra
.646 .76 .932 r
.66449 .48319 .67133 .49131 .68554 .48696 .67875 .47881 Metetra
.646 .76 .932 r
.67875 .47881 .68554 .48696 .69983 .4826 .69309 .4744 Metetra
.646 .76 .932 r
.69309 .4744 .69983 .4826 .71418 .47821 .70749 .46997 Metetra
.646 .76 .932 r
.70749 .46997 .71418 .47821 .72861 .4738 .72197 .46551 Metetra
.646 .76 .932 r
.72197 .46551 .72861 .4738 .74312 .46936 .73653 .46104 Metetra
.646 .76 .932 r
.73653 .46104 .74312 .46936 .75769 .4649 .75116 .45654 Metetra
.646 .76 .932 r
.75116 .45654 .75769 .4649 .77235 .46042 .76586 .45201 Metetra
.646 .76 .932 r
.76586 .45201 .77235 .46042 .78707 .45592 .78064 .44747 Metetra
.646 .76 .932 r
.78064 .44747 .78707 .45592 .80187 .45139 .7955 .4429 Metetra
.646 .76 .932 r
.7955 .4429 .80187 .45139 .81675 .44684 .81043 .43831 Metetra
.646 .76 .932 r
.81043 .43831 .81675 .44684 .83171 .44227 .82544 .43369 Metetra
.646 .76 .932 r
.82544 .43369 .83171 .44227 .84674 .43768 .84053 .42905 Metetra
.648 .73 .909 r
.17482 .62328 .18307 .63126 .195 .6276 .18678 .61958 Metetra
.648 .73 .909 r
.18678 .61958 .195 .6276 .20698 .62391 .19879 .61586 Metetra
.648 .73 .909 r
.19879 .61586 .20698 .62391 .21902 .62021 .21086 .61212 Metetra
.648 .73 .909 r
.21086 .61212 .21902 .62021 .23111 .61649 .22298 .60837 Metetra
.648 .73 .909 r
.22298 .60837 .23111 .61649 .24327 .61275 .23516 .6046 Metetra
.648 .73 .909 r
.23516 .6046 .24327 .61275 .25547 .60899 .2474 .60081 Metetra
.648 .73 .909 r
.2474 .60081 .25547 .60899 .26774 .60522 .2597 .597 Metetra
.648 .73 .909 r
.2597 .597 .26774 .60522 .28006 .60143 .27205 .59318 Metetra
.648 .73 .909 r
.27205 .59318 .28006 .60143 .29244 .59762 .28446 .58934 Metetra
.648 .73 .909 r
.28446 .58934 .29244 .59762 .30488 .5938 .29694 .58547 Metetra
.648 .73 .909 r
.29694 .58547 .30488 .5938 .31738 .58995 .30947 .58159 Metetra
.648 .73 .909 r
.30947 .58159 .31738 .58995 .32994 .58609 .32206 .5777 Metetra
.648 .73 .909 r
.32206 .5777 .32994 .58609 .34256 .58221 .33471 .57378 Metetra
.648 .73 .909 r
.33471 .57378 .34256 .58221 .35524 .57831 .34742 .56984 Metetra
.648 .73 .909 r
.34742 .56984 .35524 .57831 .36798 .57439 .36019 .56589 Metetra
.648 .73 .909 r
.36019 .56589 .36798 .57439 .38078 .57045 .37302 .56192 Metetra
.648 .73 .909 r
.37302 .56192 .38078 .57045 .39364 .5665 .38592 .55792 Metetra
.648 .73 .909 r
.38592 .55792 .39364 .5665 .40656 .56252 .39888 .55391 Metetra
.648 .73 .909 r
.39888 .55391 .40656 .56252 .41955 .55853 .4119 .54988 Metetra
.648 .73 .909 r
.4119 .54988 .41955 .55853 .4326 .55452 .42498 .54583 Metetra
.648 .73 .909 r
.42498 .54583 .4326 .55452 .44571 .55048 .43813 .54176 Metetra
.648 .73 .909 r
.43813 .54176 .44571 .55048 .45888 .54643 .45134 .53767 Metetra
.648 .73 .909 r
.45134 .53767 .45888 .54643 .47212 .54236 .46461 .53356 Metetra
.648 .73 .909 r
.46461 .53356 .47212 .54236 .48543 .53827 .47796 .52943 Metetra
.648 .73 .909 r
.47796 .52943 .48543 .53827 .4988 .53416 .49136 .52528 Metetra
.648 .73 .909 r
.49136 .52528 .4988 .53416 .51223 .53002 .50484 .52111 Metetra
.648 .73 .909 r
.50484 .52111 .51223 .53002 .52573 .52587 .51838 .51691 Metetra
.648 .73 .909 r
.51838 .51691 .52573 .52587 .5393 .5217 .53198 .5127 Metetra
.648 .73 .909 r
.53198 .5127 .5393 .5217 .55294 .5175 .54566 .50847 Metetra
.648 .73 .909 r
.54566 .50847 .55294 .5175 .56664 .51329 .5594 .50421 Metetra
.648 .73 .909 r
.5594 .50421 .56664 .51329 .58041 .50905 .57321 .49994 Metetra
.648 .73 .909 r
.57321 .49994 .58041 .50905 .59425 .5048 .58709 .49564 Metetra
.648 .73 .909 r
.58709 .49564 .59425 .5048 .60816 .50052 .60104 .49132 Metetra
.648 .73 .909 r
.60104 .49132 .60816 .50052 .62213 .49622 .61506 .48698 Metetra
.648 .73 .909 r
.61506 .48698 .62213 .49622 .63618 .4919 .62915 .48262 Metetra
.648 .73 .909 r
.62915 .48262 .63618 .4919 .6503 .48756 .64331 .47823 Metetra
.648 .73 .909 r
.64331 .47823 .6503 .48756 .66449 .48319 .65754 .47383 Metetra
.648 .73 .909 r
.65754 .47383 .66449 .48319 .67875 .47881 .67185 .4694 Metetra
.648 .73 .909 r
.67185 .4694 .67875 .47881 .69309 .4744 .68623 .46494 Metetra
.648 .73 .909 r
.68623 .46494 .69309 .4744 .70749 .46997 .70068 .46047 Metetra
.648 .73 .909 r
.70068 .46047 .70749 .46997 .72197 .46551 .71521 .45597 Metetra
.648 .73 .909 r
.71521 .45597 .72197 .46551 .73653 .46104 .72981 .45145 Metetra
.648 .73 .909 r
.72981 .45145 .73653 .46104 .75116 .45654 .74448 .44691 Metetra
.648 .73 .909 r
.74448 .44691 .75116 .45654 .76586 .45201 .75923 .44234 Metetra
.648 .73 .909 r
.75923 .44234 .76586 .45201 .78064 .44747 .77406 .43775 Metetra
.648 .73 .909 r
.77406 .43775 .78064 .44747 .7955 .4429 .78897 .43314 Metetra
.648 .73 .909 r
.78897 .43314 .7955 .4429 .81043 .43831 .80395 .4285 Metetra
.648 .73 .909 r
.80395 .4285 .81043 .43831 .82544 .43369 .81901 .42383 Metetra
.648 .73 .909 r
.81901 .42383 .82544 .43369 .84053 .42905 .83415 .41915 Metetra
.631 .593 .793 r
.16725 .6082 .17482 .62328 .18678 .61958 .17921 .60446 Metetra
.631 .593 .793 r
.17921 .60446 .18678 .61958 .19879 .61586 .19123 .6007 Metetra
.631 .593 .793 r
.19123 .6007 .19879 .61586 .21086 .61212 .2033 .59692 Metetra
.631 .593 .793 r
.2033 .59692 .21086 .61212 .22298 .60837 .21543 .59312 Metetra
.631 .593 .793 r
.21543 .59312 .22298 .60837 .23516 .6046 .22762 .58931 Metetra
.631 .593 .793 r
.22762 .58931 .23516 .6046 .2474 .60081 .23986 .58547 Metetra
.631 .593 .793 r
.23986 .58547 .2474 .60081 .2597 .597 .25216 .58162 Metetra
.631 .593 .793 r
.25216 .58162 .2597 .597 .27205 .59318 .26452 .57775 Metetra
.631 .593 .793 r
.26452 .57775 .27205 .59318 .28446 .58934 .27694 .57387 Metetra
.631 .593 .793 r
.27694 .57387 .28446 .58934 .29694 .58547 .28942 .56996 Metetra
.631 .593 .793 r
.28942 .56996 .29694 .58547 .30947 .58159 .30195 .56604 Metetra
.631 .593 .793 r
.30195 .56604 .30947 .58159 .32206 .5777 .31455 .5621 Metetra
.631 .593 .793 r
.31455 .5621 .32206 .5777 .33471 .57378 .32721 .55813 Metetra
.631 .593 .793 r
.32721 .55813 .33471 .57378 .34742 .56984 .33993 .55415 Metetra
.631 .593 .793 r
.33993 .55415 .34742 .56984 .36019 .56589 .3527 .55015 Metetra
.631 .593 .793 r
.3527 .55015 .36019 .56589 .37302 .56192 .36554 .54613 Metetra
.631 .593 .793 r
.36554 .54613 .37302 .56192 .38592 .55792 .37845 .5421 Metetra
.631 .593 .793 r
.37845 .5421 .38592 .55792 .39888 .55391 .39141 .53804 Metetra
.631 .593 .793 r
.39141 .53804 .39888 .55391 .4119 .54988 .40444 .53396 Metetra
.631 .593 .793 r
.40444 .53396 .4119 .54988 .42498 .54583 .41753 .52986 Metetra
.631 .593 .793 r
.41753 .52986 .42498 .54583 .43813 .54176 .43069 .52574 Metetra
.631 .593 .793 r
.43069 .52574 .43813 .54176 .45134 .53767 .44391 .52161 Metetra
.631 .593 .793 r
.44391 .52161 .45134 .53767 .46461 .53356 .45719 .51745 Metetra
.631 .593 .793 r
.45719 .51745 .46461 .53356 .47796 .52943 .47054 .51327 Metetra
.631 .593 .793 r
.47054 .51327 .47796 .52943 .49136 .52528 .48396 .50907 Metetra
.631 .593 .793 r
.48396 .50907 .49136 .52528 .50484 .52111 .49744 .50485 Metetra
.631 .593 .793 r
.49744 .50485 .50484 .52111 .51838 .51691 .51099 .50061 Metetra
.631 .593 .793 r
.51099 .50061 .51838 .51691 .53198 .5127 .5246 .49635 Metetra
.631 .593 .793 r
.5246 .49635 .53198 .5127 .54566 .50847 .53829 .49207 Metetra
.631 .593 .793 r
.53829 .49207 .54566 .50847 .5594 .50421 .55204 .48776 Metetra
.631 .593 .793 r
.55204 .48776 .5594 .50421 .57321 .49994 .56586 .48344 Metetra
.631 .593 .793 r
.56586 .48344 .57321 .49994 .58709 .49564 .57975 .47909 Metetra
.631 .593 .793 r
.57975 .47909 .58709 .49564 .60104 .49132 .59371 .47472 Metetra
.631 .593 .793 r
.59371 .47472 .60104 .49132 .61506 .48698 .60774 .47033 Metetra
.631 .593 .793 r
.60774 .47033 .61506 .48698 .62915 .48262 .62184 .46591 Metetra
.631 .593 .793 r
.62184 .46591 .62915 .48262 .64331 .47823 .63601 .46148 Metetra
.631 .593 .793 r
.63601 .46148 .64331 .47823 .65754 .47383 .65026 .45702 Metetra
.631 .593 .793 r
.65026 .45702 .65754 .47383 .67185 .4694 .66457 .45254 Metetra
.631 .593 .793 r
.66457 .45254 .67185 .4694 .68623 .46494 .67896 .44803 Metetra
.631 .593 .793 r
.67896 .44803 .68623 .46494 .70068 .46047 .69343 .44351 Metetra
.631 .593 .793 r
.69343 .44351 .70068 .46047 .71521 .45597 .70796 .43896 Metetra
.631 .593 .793 r
.70796 .43896 .71521 .45597 .72981 .45145 .72258 .43438 Metetra
.631 .593 .793 r
.72258 .43438 .72981 .45145 .74448 .44691 .73726 .42979 Metetra
.631 .593 .793 r
.73726 .42979 .74448 .44691 .75923 .44234 .75203 .42516 Metetra
.631 .593 .793 r
.75203 .42516 .75923 .44234 .77406 .43775 .76687 .42052 Metetra
.631 .593 .793 r
.76687 .42052 .77406 .43775 .78897 .43314 .78178 .41585 Metetra
.631 .593 .793 r
.78178 .41585 .78897 .43314 .80395 .4285 .79678 .41116 Metetra
.631 .593 .793 r
.79678 .41116 .80395 .4285 .81901 .42383 .81185 .40644 Metetra
.631 .593 .793 r
.81185 .40644 .81901 .42383 .83415 .41915 .827 .4017 Metetra
.583 .432 .642 r
.16235 .56772 .16725 .6082 .17921 .60446 .17424 .56391 Metetra
.583 .432 .642 r
.17424 .56391 .17921 .60446 .19123 .6007 .18618 .56007 Metetra
.583 .432 .642 r
.18618 .56007 .19123 .6007 .2033 .59692 .19817 .55622 Metetra
.583 .432 .642 r
.19817 .55622 .2033 .59692 .21543 .59312 .21022 .55235 Metetra
.583 .432 .642 r
.21022 .55235 .21543 .59312 .22762 .58931 .22233 .54846 Metetra
.583 .432 .642 r
.22233 .54846 .22762 .58931 .23986 .58547 .23449 .54455 Metetra
.583 .432 .642 r
.23449 .54455 .23986 .58547 .25216 .58162 .24671 .54063 Metetra
.583 .432 .642 r
.24671 .54063 .25216 .58162 .26452 .57775 .25899 .53669 Metetra
.583 .432 .642 r
.25899 .53669 .26452 .57775 .27694 .57387 .27132 .53272 Metetra
.583 .432 .642 r
.27132 .53272 .27694 .57387 .28942 .56996 .28371 .52874 Metetra
.583 .432 .642 r
.28371 .52874 .28942 .56996 .30195 .56604 .29617 .52474 Metetra
.583 .432 .642 r
.29617 .52474 .30195 .56604 .31455 .5621 .30868 .52073 Metetra
.583 .432 .642 r
.30868 .52073 .31455 .5621 .32721 .55813 .32125 .51669 Metetra
.583 .432 .642 r
.32125 .51669 .32721 .55813 .33993 .55415 .33388 .51263 Metetra
.583 .432 .642 r
.33388 .51263 .33993 .55415 .3527 .55015 .34657 .50856 Metetra
.583 .432 .642 r
.34657 .50856 .3527 .55015 .36554 .54613 .35932 .50446 Metetra
.583 .432 .642 r
.35932 .50446 .36554 .54613 .37845 .5421 .37214 .50034 Metetra
.583 .432 .642 r
.37214 .50034 .37845 .5421 .39141 .53804 .38501 .49621 Metetra
.583 .432 .642 r
.38501 .49621 .39141 .53804 .40444 .53396 .39795 .49205 Metetra
.583 .432 .642 r
.39795 .49205 .40444 .53396 .41753 .52986 .41095 .48788 Metetra
.583 .432 .642 r
.41095 .48788 .41753 .52986 .43069 .52574 .42401 .48368 Metetra
.583 .432 .642 r
.42401 .48368 .43069 .52574 .44391 .52161 .43714 .47947 Metetra
.583 .432 .642 r
.43714 .47947 .44391 .52161 .45719 .51745 .45033 .47523 Metetra
.583 .432 .642 r
.45033 .47523 .45719 .51745 .47054 .51327 .46358 .47097 Metetra
.583 .432 .642 r
.46358 .47097 .47054 .51327 .48396 .50907 .4769 .4667 Metetra
.583 .432 .642 r
.4769 .4667 .48396 .50907 .49744 .50485 .49029 .4624 Metetra
.583 .432 .642 r
.49029 .4624 .49744 .50485 .51099 .50061 .50374 .45808 Metetra
.583 .432 .642 r
.50374 .45808 .51099 .50061 .5246 .49635 .51725 .45374 Metetra
.583 .432 .642 r
.51725 .45374 .5246 .49635 .53829 .49207 .53084 .44937 Metetra
.583 .432 .642 r
.53084 .44937 .53829 .49207 .55204 .48776 .54449 .44499 Metetra
.583 .432 .642 r
.54449 .44499 .55204 .48776 .56586 .48344 .55821 .44058 Metetra
.583 .432 .642 r
.55821 .44058 .56586 .48344 .57975 .47909 .572 .43615 Metetra
.583 .432 .642 r
.572 .43615 .57975 .47909 .59371 .47472 .58585 .4317 Metetra
.583 .432 .642 r
.58585 .4317 .59371 .47472 .60774 .47033 .59978 .42723 Metetra
.583 .432 .642 r
.59978 .42723 .60774 .47033 .62184 .46591 .61378 .42273 Metetra
.583 .432 .642 r
.61378 .42273 .62184 .46591 .63601 .46148 .62784 .41822 Metetra
.583 .432 .642 r
.62784 .41822 .63601 .46148 .65026 .45702 .64198 .41368 Metetra
.583 .432 .642 r
.64198 .41368 .65026 .45702 .66457 .45254 .65619 .40911 Metetra
.583 .432 .642 r
.65619 .40911 .66457 .45254 .67896 .44803 .67047 .40453 Metetra
.583 .432 .642 r
.67047 .40453 .67896 .44803 .69343 .44351 .68482 .39991 Metetra
.583 .432 .642 r
.68482 .39991 .69343 .44351 .70796 .43896 .69925 .39528 Metetra
.583 .432 .642 r
.69925 .39528 .70796 .43896 .72258 .43438 .71375 .39062 Metetra
.583 .432 .642 r
.71375 .39062 .72258 .43438 .73726 .42979 .72832 .38594 Metetra
.583 .432 .642 r
.72832 .38594 .73726 .42979 .75203 .42516 .74297 .38124 Metetra
.583 .432 .642 r
.74297 .38124 .75203 .42516 .76687 .42052 .7577 .37651 Metetra
.583 .432 .642 r
.7577 .37651 .76687 .42052 .78178 .41585 .7725 .37175 Metetra
.583 .432 .642 r
.7725 .37175 .78178 .41585 .79678 .41116 .78738 .36698 Metetra
.583 .432 .642 r
.78738 .36698 .79678 .41116 .81185 .40644 .80233 .36217 Metetra
.583 .432 .642 r
.80233 .36217 .81185 .40644 .827 .4017 .81737 .35734 Metetra
.56 .373 .584 r
.16164 .4901 .16235 .56772 .17424 .56391 .17332 .48617 Metetra
.56 .373 .584 r
.17332 .48617 .17424 .56391 .18618 .56007 .18506 .48223 Metetra
.56 .373 .584 r
.18506 .48223 .18618 .56007 .19817 .55622 .19685 .47826 Metetra
.56 .373 .584 r
.19685 .47826 .19817 .55622 .21022 .55235 .20869 .47428 Metetra
.56 .373 .584 r
.20869 .47428 .21022 .55235 .22233 .54846 .22059 .47027 Metetra
.56 .373 .584 r
.22059 .47027 .22233 .54846 .23449 .54455 .23254 .46625 Metetra
.56 .373 .584 r
.23254 .46625 .23449 .54455 .24671 .54063 .24455 .46222 Metetra
.56 .373 .584 r
.24455 .46222 .24671 .54063 .25899 .53669 .25661 .45816 Metetra
.56 .373 .584 r
.25661 .45816 .25899 .53669 .27132 .53272 .26873 .45408 Metetra
.56 .373 .584 r
.26873 .45408 .27132 .53272 .28371 .52874 .28091 .44999 Metetra
.56 .373 .584 r
.28091 .44999 .28371 .52874 .29617 .52474 .29314 .44587 Metetra
.56 .373 .584 r
.29314 .44587 .29617 .52474 .30868 .52073 .30543 .44174 Metetra
.56 .373 .584 r
.30543 .44174 .30868 .52073 .32125 .51669 .31778 .43759 Metetra
.56 .373 .584 r
.31778 .43759 .32125 .51669 .33388 .51263 .33019 .43341 Metetra
.56 .373 .584 r
.33019 .43341 .33388 .51263 .34657 .50856 .34265 .42922 Metetra
.56 .373 .584 r
.34265 .42922 .34657 .50856 .35932 .50446 .35517 .42501 Metetra
.56 .373 .584 r
.35517 .42501 .35932 .50446 .37214 .50034 .36775 .42078 Metetra
.56 .373 .584 r
.36775 .42078 .37214 .50034 .38501 .49621 .38039 .41653 Metetra
.56 .373 .584 r
.38039 .41653 .38501 .49621 .39795 .49205 .39309 .41225 Metetra
.56 .373 .584 r
.39309 .41225 .39795 .49205 .41095 .48788 .40585 .40796 Metetra
.56 .373 .584 r
.40585 .40796 .41095 .48788 .42401 .48368 .41868 .40365 Metetra
.56 .373 .584 r
.41868 .40365 .42401 .48368 .43714 .47947 .43156 .39932 Metetra
.56 .373 .584 r
.43156 .39932 .43714 .47947 .45033 .47523 .4445 .39496 Metetra
.56 .373 .584 r
.4445 .39496 .45033 .47523 .46358 .47097 .45751 .39059 Metetra
.56 .373 .584 r
.45751 .39059 .46358 .47097 .4769 .4667 .47058 .38619 Metetra
.56 .373 .584 r
.47058 .38619 .4769 .4667 .49029 .4624 .48371 .38177 Metetra
.56 .373 .584 r
.48371 .38177 .49029 .4624 .50374 .45808 .49691 .37734 Metetra
.56 .373 .584 r
.49691 .37734 .50374 .45808 .51725 .45374 .51017 .37288 Metetra
.56 .373 .584 r
.51017 .37288 .51725 .45374 .53084 .44937 .5235 .36839 Metetra
.56 .373 .584 r
.5235 .36839 .53084 .44937 .54449 .44499 .53688 .36389 Metetra
.56 .373 .584 r
.53688 .36389 .54449 .44499 .55821 .44058 .55034 .35937 Metetra
.56 .373 .584 r
.55034 .35937 .55821 .44058 .572 .43615 .56386 .35482 Metetra
.56 .373 .584 r
.56386 .35482 .572 .43615 .58585 .4317 .57745 .35025 Metetra
.56 .373 .584 r
.57745 .35025 .58585 .4317 .59978 .42723 .5911 .34566 Metetra
.56 .373 .584 r
.5911 .34566 .59978 .42723 .61378 .42273 .60482 .34104 Metetra
.56 .373 .584 r
.60482 .34104 .61378 .42273 .62784 .41822 .61861 .3364 Metetra
.56 .373 .584 r
.61861 .3364 .62784 .41822 .64198 .41368 .63247 .33174 Metetra
.56 .373 .584 r
.63247 .33174 .64198 .41368 .65619 .40911 .64639 .32706 Metetra
.56 .373 .584 r
.64639 .32706 .65619 .40911 .67047 .40453 .66039 .32235 Metetra
.56 .373 .584 r
.66039 .32235 .67047 .40453 .68482 .39991 .67446 .31762 Metetra
.56 .373 .584 r
.67446 .31762 .68482 .39991 .69925 .39528 .68859 .31287 Metetra
.56 .373 .584 r
.68859 .31287 .69925 .39528 .71375 .39062 .7028 .30809 Metetra
.56 .373 .584 r
.7028 .30809 .71375 .39062 .72832 .38594 .71708 .30329 Metetra
.56 .373 .584 r
.71708 .30329 .72832 .38594 .74297 .38124 .73143 .29846 Metetra
.56 .373 .584 r
.73143 .29846 .74297 .38124 .7577 .37651 .74585 .29361 Metetra
.56 .373 .584 r
.74585 .29361 .7577 .37651 .7725 .37175 .76034 .28873 Metetra
.56 .373 .584 r
.76034 .28873 .7725 .37175 .78738 .36698 .77491 .28383 Metetra
.56 .373 .584 r
.77491 .28383 .78738 .36698 .80233 .36217 .78956 .27891 Metetra
.56 .373 .584 r
.78956 .27891 .80233 .36217 .81737 .35734 .80428 .27396 Metetra
.559 .372 .583 r
.16108 .41376 .16164 .4901 .17332 .48617 .17257 .40973 Metetra
.559 .372 .583 r
.17257 .40973 .17332 .48617 .18506 .48223 .18411 .40567 Metetra
.559 .372 .583 r
.18411 .40567 .18506 .48223 .19685 .47826 .19569 .4016 Metetra
.559 .372 .583 r
.19569 .4016 .19685 .47826 .20869 .47428 .20734 .39751 Metetra
.559 .372 .583 r
.20734 .39751 .20869 .47428 .22059 .47027 .21903 .39341 Metetra
.559 .372 .583 r
.21903 .39341 .22059 .47027 .23254 .46625 .23078 .38928 Metetra
.559 .372 .583 r
.23078 .38928 .23254 .46625 .24455 .46222 .24258 .38514 Metetra
.559 .372 .583 r
.24258 .38514 .24455 .46222 .25661 .45816 .25443 .38097 Metetra
.559 .372 .583 r
.25443 .38097 .25661 .45816 .26873 .45408 .26634 .37679 Metetra
.559 .372 .583 r
.26634 .37679 .26873 .45408 .28091 .44999 .2783 .37259 Metetra
.559 .372 .583 r
.2783 .37259 .28091 .44999 .29314 .44587 .29031 .36837 Metetra
.559 .372 .583 r
.29031 .36837 .29314 .44587 .30543 .44174 .30239 .36413 Metetra
.559 .372 .583 r
.30239 .36413 .30543 .44174 .31778 .43759 .31451 .35987 Metetra
.559 .372 .583 r
.31451 .35987 .31778 .43759 .33019 .43341 .3267 .35559 Metetra
.559 .372 .583 r
.3267 .35559 .33019 .43341 .34265 .42922 .33893 .35129 Metetra
.559 .372 .583 r
.33893 .35129 .34265 .42922 .35517 .42501 .35123 .34697 Metetra
.559 .372 .583 r
.35123 .34697 .35517 .42501 .36775 .42078 .36358 .34264 Metetra
.559 .372 .583 r
.36358 .34264 .36775 .42078 .38039 .41653 .37599 .33828 Metetra
.559 .372 .583 r
.37599 .33828 .38039 .41653 .39309 .41225 .38846 .3339 Metetra
.559 .372 .583 r
.38846 .3339 .39309 .41225 .40585 .40796 .40099 .3295 Metetra
.559 .372 .583 r
.40099 .3295 .40585 .40796 .41868 .40365 .41357 .32508 Metetra
.559 .372 .583 r
.41357 .32508 .41868 .40365 .43156 .39932 .42622 .32064 Metetra
.559 .372 .583 r
.42622 .32064 .43156 .39932 .4445 .39496 .43892 .31617 Metetra
.559 .372 .583 r
.43892 .31617 .4445 .39496 .45751 .39059 .45168 .31169 Metetra
.559 .372 .583 r
.45168 .31169 .45751 .39059 .47058 .38619 .46451 .30719 Metetra
.559 .372 .583 r
.46451 .30719 .47058 .38619 .48371 .38177 .47739 .30266 Metetra
.559 .372 .583 r
.47739 .30266 .48371 .38177 .49691 .37734 .49034 .29812 Metetra
.559 .372 .583 r
.49034 .29812 .49691 .37734 .51017 .37288 .50334 .29355 Metetra
.559 .372 .583 r
.50334 .29355 .51017 .37288 .5235 .36839 .51641 .28896 Metetra
.559 .372 .583 r
.51641 .28896 .5235 .36839 .53688 .36389 .52954 .28434 Metetra
.559 .372 .583 r
.52954 .28434 .53688 .36389 .55034 .35937 .54274 .27971 Metetra
.559 .372 .583 r
.54274 .27971 .55034 .35937 .56386 .35482 .556 .27505 Metetra
.559 .372 .583 r
.556 .27505 .56386 .35482 .57745 .35025 .56932 .27037 Metetra
.559 .372 .583 r
.56932 .27037 .57745 .35025 .5911 .34566 .58271 .26567 Metetra
.559 .372 .583 r
.58271 .26567 .5911 .34566 .60482 .34104 .59616 .26095 Metetra
.559 .372 .583 r
.59616 .26095 .60482 .34104 .61861 .3364 .60967 .2562 Metetra
.559 .372 .583 r
.60967 .2562 .61861 .3364 .63247 .33174 .62326 .25143 Metetra
.559 .372 .583 r
.62326 .25143 .63247 .33174 .64639 .32706 .6369 .24664 Metetra
.559 .372 .583 r
.6369 .24664 .64639 .32706 .66039 .32235 .65062 .24182 Metetra
.559 .372 .583 r
.65062 .24182 .66039 .32235 .67446 .31762 .6644 .23698 Metetra
.559 .372 .583 r
.6644 .23698 .67446 .31762 .68859 .31287 .67825 .23211 Metetra
.559 .372 .583 r
.67825 .23211 .68859 .31287 .7028 .30809 .69217 .22722 Metetra
.559 .372 .583 r
.69217 .22722 .7028 .30809 .71708 .30329 .70616 .22231 Metetra
.559 .372 .583 r
.70616 .22231 .71708 .30329 .73143 .29846 .72021 .21737 Metetra
.559 .372 .583 r
.72021 .21737 .73143 .29846 .74585 .29361 .73434 .21241 Metetra
.559 .372 .583 r
.73434 .21241 .74585 .29361 .76034 .28873 .74853 .20743 Metetra
.559 .372 .583 r
.74853 .20743 .76034 .28873 .77491 .28383 .7628 .20242 Metetra
.559 .372 .583 r
.7628 .20242 .77491 .28383 .78956 .27891 .77714 .19738 Metetra
.559 .372 .583 r
.77714 .19738 .78956 .27891 .80428 .27396 .79155 .19232 Metetra
.587 .44 .649 r
.15621 .37762 .16108 .41376 .17257 .40973 .16763 .37352 Metetra
.587 .44 .649 r
.16763 .37352 .17257 .40973 .18411 .40567 .1791 .36941 Metetra
.587 .44 .649 r
.1791 .36941 .18411 .40567 .19569 .4016 .19062 .36528 Metetra
.587 .44 .649 r
.19062 .36528 .19569 .4016 .20734 .39751 .20219 .36113 Metetra
.587 .44 .649 r
.20219 .36113 .20734 .39751 .21903 .39341 .21382 .35696 Metetra
.587 .44 .649 r
.21382 .35696 .21903 .39341 .23078 .38928 .2255 .35277 Metetra
.587 .44 .649 r
.2255 .35277 .23078 .38928 .24258 .38514 .23723 .34857 Metetra
.587 .44 .649 r
.23723 .34857 .24258 .38514 .25443 .38097 .24901 .34434 Metetra
.587 .44 .649 r
.24901 .34434 .25443 .38097 .26634 .37679 .26085 .34009 Metetra
.587 .44 .649 r
.26085 .34009 .26634 .37679 .2783 .37259 .27274 .33583 Metetra
.587 .44 .649 r
.27274 .33583 .2783 .37259 .29031 .36837 .28468 .33155 Metetra
.587 .44 .649 r
.28468 .33155 .29031 .36837 .30239 .36413 .29668 .32724 Metetra
.587 .44 .649 r
.29668 .32724 .30239 .36413 .31451 .35987 .30874 .32292 Metetra
.587 .44 .649 r
.30874 .32292 .31451 .35987 .3267 .35559 .32085 .31858 Metetra
.587 .44 .649 r
.32085 .31858 .3267 .35559 .33893 .35129 .33301 .31422 Metetra
.587 .44 .649 r
.33301 .31422 .33893 .35129 .35123 .34697 .34523 .30983 Metetra
.587 .44 .649 r
.34523 .30983 .35123 .34697 .36358 .34264 .35751 .30543 Metetra
.587 .44 .649 r
.35751 .30543 .36358 .34264 .37599 .33828 .36984 .30101 Metetra
.587 .44 .649 r
.36984 .30101 .37599 .33828 .38846 .3339 .38224 .29656 Metetra
.587 .44 .649 r
.38224 .29656 .38846 .3339 .40099 .3295 .39468 .2921 Metetra
.587 .44 .649 r
.39468 .2921 .40099 .3295 .41357 .32508 .40719 .28761 Metetra
.587 .44 .649 r
.40719 .28761 .41357 .32508 .42622 .32064 .41976 .28311 Metetra
.587 .44 .649 r
.41976 .28311 .42622 .32064 .43892 .31617 .43238 .27858 Metetra
.587 .44 .649 r
.43238 .27858 .43892 .31617 .45168 .31169 .44507 .27403 Metetra
.587 .44 .649 r
.44507 .27403 .45168 .31169 .46451 .30719 .45781 .26946 Metetra
.587 .44 .649 r
.45781 .26946 .46451 .30719 .47739 .30266 .47061 .26487 Metetra
.587 .44 .649 r
.47061 .26487 .47739 .30266 .49034 .29812 .48348 .26026 Metetra
.587 .44 .649 r
.48348 .26026 .49034 .29812 .50334 .29355 .4964 .25562 Metetra
.587 .44 .649 r
.4964 .25562 .50334 .29355 .51641 .28896 .50939 .25097 Metetra
.587 .44 .649 r
.50939 .25097 .51641 .28896 .52954 .28434 .52243 .24629 Metetra
.587 .44 .649 r
.52243 .24629 .52954 .28434 .54274 .27971 .53554 .24159 Metetra
.587 .44 .649 r
.53554 .24159 .54274 .27971 .556 .27505 .54872 .23686 Metetra
.587 .44 .649 r
.54872 .23686 .556 .27505 .56932 .27037 .56195 .23212 Metetra
.587 .44 .649 r
.56195 .23212 .56932 .27037 .58271 .26567 .57525 .22735 Metetra
.587 .44 .649 r
.57525 .22735 .58271 .26567 .59616 .26095 .58861 .22255 Metetra
.587 .44 .649 r
.58861 .22255 .59616 .26095 .60967 .2562 .60204 .21774 Metetra
.587 .44 .649 r
.60204 .21774 .60967 .2562 .62326 .25143 .61554 .2129 Metetra
.587 .44 .649 r
.61554 .2129 .62326 .25143 .6369 .24664 .62909 .20804 Metetra
.587 .44 .649 r
.62909 .20804 .6369 .24664 .65062 .24182 .64272 .20315 Metetra
.587 .44 .649 r
.64272 .20315 .65062 .24182 .6644 .23698 .65641 .19824 Metetra
.587 .44 .649 r
.65641 .19824 .6644 .23698 .67825 .23211 .67017 .19331 Metetra
.587 .44 .649 r
.67017 .19331 .67825 .23211 .69217 .22722 .68399 .18835 Metetra
.587 .44 .649 r
.68399 .18835 .69217 .22722 .70616 .22231 .69788 .18337 Metetra
.587 .44 .649 r
.69788 .18337 .70616 .22231 .72021 .21737 .71185 .17836 Metetra
.587 .44 .649 r
.71185 .17836 .72021 .21737 .73434 .21241 .72588 .17333 Metetra
.587 .44 .649 r
.72588 .17333 .73434 .21241 .74853 .20743 .73998 .16827 Metetra
.587 .44 .649 r
.73998 .16827 .74853 .20743 .7628 .20242 .75414 .16319 Metetra
.587 .44 .649 r
.75414 .16319 .7628 .20242 .77714 .19738 .76838 .15809 Metetra
.587 .44 .649 r
.76838 .15809 .77714 .19738 .79155 .19232 .7827 .15295 Metetra
.648 .633 .822 r
.14862 .36524 .15621 .37762 .16763 .37352 .16005 .3611 Metetra
.648 .633 .822 r
.16005 .3611 .16763 .37352 .1791 .36941 .17153 .35695 Metetra
.648 .633 .822 r
.17153 .35695 .1791 .36941 .19062 .36528 .18307 .35278 Metetra
.648 .633 .822 r
.18307 .35278 .19062 .36528 .20219 .36113 .19465 .34859 Metetra
.648 .633 .822 r
.19465 .34859 .20219 .36113 .21382 .35696 .20629 .34438 Metetra
.648 .633 .822 r
.20629 .34438 .21382 .35696 .2255 .35277 .21798 .34015 Metetra
.648 .633 .822 r
.21798 .34015 .2255 .35277 .23723 .34857 .22973 .33591 Metetra
.648 .633 .822 r
.22973 .33591 .23723 .34857 .24901 .34434 .24153 .33164 Metetra
.648 .633 .822 r
.24153 .33164 .24901 .34434 .26085 .34009 .25338 .32736 Metetra
.648 .633 .822 r
.25338 .32736 .26085 .34009 .27274 .33583 .26528 .32305 Metetra
.648 .633 .822 r
.26528 .32305 .27274 .33583 .28468 .33155 .27724 .31873 Metetra
.648 .633 .822 r
.27724 .31873 .28468 .33155 .29668 .32724 .28926 .31438 Metetra
.648 .633 .822 r
.28926 .31438 .29668 .32724 .30874 .32292 .30133 .31002 Metetra
.648 .633 .822 r
.30133 .31002 .30874 .32292 .32085 .31858 .31345 .30564 Metetra
.648 .633 .822 r
.31345 .30564 .32085 .31858 .33301 .31422 .32563 .30123 Metetra
.648 .633 .822 r
.32563 .30123 .33301 .31422 .34523 .30983 .33787 .29681 Metetra
.648 .633 .822 r
.33787 .29681 .34523 .30983 .35751 .30543 .35016 .29236 Metetra
.648 .633 .822 r
.35016 .29236 .35751 .30543 .36984 .30101 .36251 .2879 Metetra
.648 .633 .822 r
.36251 .2879 .36984 .30101 .38224 .29656 .37492 .28341 Metetra
.648 .633 .822 r
.37492 .28341 .38224 .29656 .39468 .2921 .38739 .2789 Metetra
.648 .633 .822 r
.38739 .2789 .39468 .2921 .40719 .28761 .39991 .27438 Metetra
.648 .633 .822 r
.39991 .27438 .40719 .28761 .41976 .28311 .4125 .26983 Metetra
.648 .633 .822 r
.4125 .26983 .41976 .28311 .43238 .27858 .42514 .26526 Metetra
.648 .633 .822 r
.42514 .26526 .43238 .27858 .44507 .27403 .43784 .26066 Metetra
.648 .633 .822 r
.43784 .26066 .44507 .27403 .45781 .26946 .4506 .25605 Metetra
.648 .633 .822 r
.4506 .25605 .45781 .26946 .47061 .26487 .46342 .25141 Metetra
.648 .633 .822 r
.46342 .25141 .47061 .26487 .48348 .26026 .4763 .24676 Metetra
.648 .633 .822 r
.4763 .24676 .48348 .26026 .4964 .25562 .48925 .24208 Metetra
.648 .633 .822 r
.48925 .24208 .4964 .25562 .50939 .25097 .50225 .23737 Metetra
.648 .633 .822 r
.50225 .23737 .50939 .25097 .52243 .24629 .51532 .23265 Metetra
.648 .633 .822 r
.51532 .23265 .52243 .24629 .53554 .24159 .52845 .2279 Metetra
.648 .633 .822 r
.52845 .2279 .53554 .24159 .54872 .23686 .54164 .22313 Metetra
.648 .633 .822 r
.54164 .22313 .54872 .23686 .56195 .23212 .5549 .21834 Metetra
.648 .633 .822 r
.5549 .21834 .56195 .23212 .57525 .22735 .56822 .21352 Metetra
.648 .633 .822 r
.56822 .21352 .57525 .22735 .58861 .22255 .5816 .20868 Metetra
.648 .633 .822 r
.5816 .20868 .58861 .22255 .60204 .21774 .59505 .20382 Metetra
.648 .633 .822 r
.59505 .20382 .60204 .21774 .61554 .2129 .60856 .19894 Metetra
.648 .633 .822 r
.60856 .19894 .61554 .2129 .62909 .20804 .62214 .19403 Metetra
.648 .633 .822 r
.62214 .19403 .62909 .20804 .64272 .20315 .63579 .18909 Metetra
.648 .633 .822 r
.63579 .18909 .64272 .20315 .65641 .19824 .6495 .18413 Metetra
.648 .633 .822 r
.6495 .18413 .65641 .19824 .67017 .19331 .66328 .17915 Metetra
.648 .633 .822 r
.66328 .17915 .67017 .19331 .68399 .18835 .67713 .17414 Metetra
.648 .633 .822 r
.67713 .17414 .68399 .18835 .69788 .18337 .69105 .16911 Metetra
.648 .633 .822 r
.69105 .16911 .69788 .18337 .71185 .17836 .70503 .16406 Metetra
.648 .633 .822 r
.70503 .16406 .71185 .17836 .72588 .17333 .71909 .15898 Metetra
.648 .633 .822 r
.71909 .15898 .72588 .17333 .73998 .16827 .73321 .15387 Metetra
.648 .633 .822 r
.73321 .15387 .73998 .16827 .75414 .16319 .7474 .14874 Metetra
.648 .633 .822 r
.7474 .14874 .75414 .16319 .76838 .15809 .76167 .14358 Metetra
.648 .633 .822 r
.76167 .14358 .76838 .15809 .7827 .15295 .776 .1384 Metetra
.663 .733 .902 r
.14044 .35727 .14862 .36524 .16005 .3611 .1519 .35311 Metetra
.663 .733 .902 r
.1519 .35311 .16005 .3611 .17153 .35695 .16341 .34892 Metetra
.663 .733 .902 r
.16341 .34892 .17153 .35695 .18307 .35278 .17498 .34471 Metetra
.663 .733 .902 r
.17498 .34471 .18307 .35278 .19465 .34859 .18659 .34049 Metetra
.663 .733 .902 r
.18659 .34049 .19465 .34859 .20629 .34438 .19826 .33625 Metetra
.663 .733 .902 r
.19826 .33625 .20629 .34438 .21798 .34015 .20998 .33198 Metetra
.663 .733 .902 r
.20998 .33198 .21798 .34015 .22973 .33591 .22176 .3277 Metetra
.663 .733 .902 r
.22176 .3277 .22973 .33591 .24153 .33164 .23358 .3234 Metetra
.663 .733 .902 r
.23358 .3234 .24153 .33164 .25338 .32736 .24547 .31908 Metetra
.663 .733 .902 r
.24547 .31908 .25338 .32736 .26528 .32305 .2574 .31474 Metetra
.663 .733 .902 r
.2574 .31474 .26528 .32305 .27724 .31873 .26939 .31038 Metetra
.663 .733 .902 r
.26939 .31038 .27724 .31873 .28926 .31438 .28144 .30599 Metetra
.663 .733 .902 r
.28144 .30599 .28926 .31438 .30133 .31002 .29354 .30159 Metetra
.663 .733 .902 r
.29354 .30159 .30133 .31002 .31345 .30564 .3057 .29717 Metetra
.663 .733 .902 r
.3057 .29717 .31345 .30564 .32563 .30123 .31791 .29273 Metetra
.663 .733 .902 r
.31791 .29273 .32563 .30123 .33787 .29681 .33018 .28827 Metetra
.663 .733 .902 r
.33018 .28827 .33787 .29681 .35016 .29236 .34251 .28378 Metetra
.663 .733 .902 r
.34251 .28378 .35016 .29236 .36251 .2879 .35489 .27928 Metetra
.663 .733 .902 r
.35489 .27928 .36251 .2879 .37492 .28341 .36734 .27475 Metetra
.663 .733 .902 r
.36734 .27475 .37492 .28341 .38739 .2789 .37984 .27021 Metetra
.663 .733 .902 r
.37984 .27021 .38739 .2789 .39991 .27438 .3924 .26564 Metetra
.663 .733 .902 r
.3924 .26564 .39991 .27438 .4125 .26983 .40502 .26105 Metetra
.663 .733 .902 r
.40502 .26105 .4125 .26983 .42514 .26526 .41769 .25644 Metetra
.663 .733 .902 r
.41769 .25644 .42514 .26526 .43784 .26066 .43043 .25181 Metetra
.663 .733 .902 r
.43043 .25181 .43784 .26066 .4506 .25605 .44323 .24715 Metetra
.663 .733 .902 r
.44323 .24715 .4506 .25605 .46342 .25141 .45609 .24247 Metetra
.663 .733 .902 r
.45609 .24247 .46342 .25141 .4763 .24676 .46901 .23778 Metetra
.663 .733 .902 r
.46901 .23778 .4763 .24676 .48925 .24208 .48199 .23305 Metetra
.663 .733 .902 r
.48199 .23305 .48925 .24208 .50225 .23737 .49503 .22831 Metetra
.663 .733 .902 r
.49503 .22831 .50225 .23737 .51532 .23265 .50814 .22354 Metetra
.663 .733 .902 r
.50814 .22354 .51532 .23265 .52845 .2279 .52131 .21875 Metetra
.663 .733 .902 r
.52131 .21875 .52845 .2279 .54164 .22313 .53454 .21394 Metetra
.663 .733 .902 r
.53454 .21394 .54164 .22313 .5549 .21834 .54784 .20911 Metetra
.663 .733 .902 r
.54784 .20911 .5549 .21834 .56822 .21352 .5612 .20425 Metetra
.663 .733 .902 r
.5612 .20425 .56822 .21352 .5816 .20868 .57462 .19936 Metetra
.663 .733 .902 r
.57462 .19936 .5816 .20868 .59505 .20382 .58812 .19446 Metetra
.663 .733 .902 r
.58812 .19446 .59505 .20382 .60856 .19894 .60167 .18953 Metetra
.663 .733 .902 r
.60167 .18953 .60856 .19894 .62214 .19403 .6153 .18457 Metetra
.663 .733 .902 r
.6153 .18457 .62214 .19403 .63579 .18909 .62899 .17959 Metetra
.663 .733 .902 r
.62899 .17959 .63579 .18909 .6495 .18413 .64274 .17459 Metetra
.663 .733 .902 r
.64274 .17459 .6495 .18413 .66328 .17915 .65657 .16956 Metetra
.663 .733 .902 r
.65657 .16956 .66328 .17915 .67713 .17414 .67046 .16451 Metetra
.663 .733 .902 r
.67046 .16451 .67713 .17414 .69105 .16911 .68442 .15943 Metetra
.663 .733 .902 r
.68442 .15943 .69105 .16911 .70503 .16406 .69845 .15433 Metetra
.663 .733 .902 r
.69845 .15433 .70503 .16406 .71909 .15898 .71255 .1492 Metetra
.663 .733 .902 r
.71255 .1492 .71909 .15898 .73321 .15387 .72672 .14405 Metetra
.663 .733 .902 r
.72672 .14405 .73321 .15387 .7474 .14874 .74096 .13887 Metetra
.663 .733 .902 r
.74096 .13887 .7474 .14874 .76167 .14358 .75528 .13366 Metetra
.663 .733 .902 r
.75528 .13366 .76167 .14358 .776 .1384 .76966 .12843 Metetra
.664 .741 .908 r
.13216 .34956 .14044 .35727 .1519 .35311 .14365 .34535 Metetra
.664 .741 .908 r
.14365 .34535 .1519 .35311 .16341 .34892 .15519 .34113 Metetra
.664 .741 .908 r
.15519 .34113 .16341 .34892 .17498 .34471 .16679 .33689 Metetra
.664 .741 .908 r
.16679 .33689 .17498 .34471 .18659 .34049 .17843 .33263 Metetra
.664 .741 .908 r
.17843 .33263 .18659 .34049 .19826 .33625 .19013 .32835 Metetra
.664 .741 .908 r
.19013 .32835 .19826 .33625 .20998 .33198 .20188 .32405 Metetra
.664 .741 .908 r
.20188 .32405 .20998 .33198 .22176 .3277 .21369 .31974 Metetra
.664 .741 .908 r
.21369 .31974 .22176 .3277 .23358 .3234 .22555 .3154 Metetra
.664 .741 .908 r
.22555 .3154 .23358 .3234 .24547 .31908 .23746 .31104 Metetra
.664 .741 .908 r
.23746 .31104 .24547 .31908 .2574 .31474 .24943 .30666 Metetra
.664 .741 .908 r
.24943 .30666 .2574 .31474 .26939 .31038 .26145 .30226 Metetra
.664 .741 .908 r
.26145 .30226 .26939 .31038 .28144 .30599 .27353 .29784 Metetra
.664 .741 .908 r
.27353 .29784 .28144 .30599 .29354 .30159 .28567 .29341 Metetra
.664 .741 .908 r
.28567 .29341 .29354 .30159 .3057 .29717 .29786 .28895 Metetra
.664 .741 .908 r
.29786 .28895 .3057 .29717 .31791 .29273 .31011 .28447 Metetra
.664 .741 .908 r
.31011 .28447 .31791 .29273 .33018 .28827 .32241 .27997 Metetra
.664 .741 .908 r
.32241 .27997 .33018 .28827 .34251 .28378 .33477 .27544 Metetra
.664 .741 .908 r
.33477 .27544 .34251 .28378 .35489 .27928 .34719 .2709 Metetra
.664 .741 .908 r
.34719 .2709 .35489 .27928 .36734 .27475 .35967 .26634 Metetra
.664 .741 .908 r
.35967 .26634 .36734 .27475 .37984 .27021 .37221 .26175 Metetra
.664 .741 .908 r
.37221 .26175 .37984 .27021 .3924 .26564 .3848 .25714 Metetra
.664 .741 .908 r
.3848 .25714 .3924 .26564 .40502 .26105 .39746 .25251 Metetra
.664 .741 .908 r
.39746 .25251 .40502 .26105 .41769 .25644 .41017 .24786 Metetra
.664 .741 .908 r
.41017 .24786 .41769 .25644 .43043 .25181 .42295 .24319 Metetra
.664 .741 .908 r
.42295 .24319 .43043 .25181 .44323 .24715 .43579 .23849 Metetra
.664 .741 .908 r
.43579 .23849 .44323 .24715 .45609 .24247 .44868 .23377 Metetra
.664 .741 .908 r
.44868 .23377 .45609 .24247 .46901 .23778 .46164 .22903 Metetra
.664 .741 .908 r
.46164 .22903 .46901 .23778 .48199 .23305 .47467 .22427 Metetra
.664 .741 .908 r
.47467 .22427 .48199 .23305 .49503 .22831 .48775 .21948 Metetra
.664 .741 .908 r
.48775 .21948 .49503 .22831 .50814 .22354 .5009 .21468 Metetra
.664 .741 .908 r
.5009 .21468 .50814 .22354 .52131 .21875 .51411 .20984 Metetra
.664 .741 .908 r
.51411 .20984 .52131 .21875 .53454 .21394 .52738 .20499 Metetra
.664 .741 .908 r
.52738 .20499 .53454 .21394 .54784 .20911 .54072 .20011 Metetra
.664 .741 .908 r
.54072 .20011 .54784 .20911 .5612 .20425 .55412 .19521 Metetra
.664 .741 .908 r
.55412 .19521 .5612 .20425 .57462 .19936 .56759 .19028 Metetra
.664 .741 .908 r
.56759 .19028 .57462 .19936 .58812 .19446 .58113 .18533 Metetra
.664 .741 .908 r
.58113 .18533 .58812 .19446 .60167 .18953 .59473 .18035 Metetra
.664 .741 .908 r
.59473 .18035 .60167 .18953 .6153 .18457 .60839 .17535 Metetra
.664 .741 .908 r
.60839 .17535 .6153 .18457 .62899 .17959 .62213 .17033 Metetra
.664 .741 .908 r
.62213 .17033 .62899 .17959 .64274 .17459 .63593 .16528 Metetra
.664 .741 .908 r
.63593 .16528 .64274 .17459 .65657 .16956 .6498 .16021 Metetra
.664 .741 .908 r
.6498 .16021 .65657 .16956 .67046 .16451 .66374 .15511 Metetra
.664 .741 .908 r
.66374 .15511 .67046 .16451 .68442 .15943 .67775 .14998 Metetra
.664 .741 .908 r
.67775 .14998 .68442 .15943 .69845 .15433 .69183 .14483 Metetra
.664 .741 .908 r
.69183 .14483 .69845 .15433 .71255 .1492 .70598 .13966 Metetra
.664 .741 .908 r
.70598 .13966 .71255 .1492 .72672 .14405 .7202 .13446 Metetra
.664 .741 .908 r
.7202 .13446 .72672 .14405 .74096 .13887 .73449 .12923 Metetra
.664 .741 .908 r
.73449 .12923 .74096 .13887 .75528 .13366 .74885 .12397 Metetra
.664 .741 .908 r
.74885 .12397 .75528 .13366 .76966 .12843 .76329 .11869 Metetra
.664 .741 .908 r
.12381 .34178 .13216 .34956 .14365 .34535 .13533 .33755 Metetra
.664 .741 .908 r
.13533 .33755 .14365 .34535 .15519 .34113 .1469 .33329 Metetra
.664 .741 .908 r
.1469 .33329 .15519 .34113 .16679 .33689 .15852 .32901 Metetra
.664 .741 .908 r
.15852 .32901 .16679 .33689 .17843 .33263 .1702 .32472 Metetra
.664 .741 .908 r
.1702 .32472 .17843 .33263 .19013 .32835 .18193 .3204 Metetra
.664 .741 .908 r
.18193 .3204 .19013 .32835 .20188 .32405 .19371 .31607 Metetra
.664 .741 .908 r
.19371 .31607 .20188 .32405 .21369 .31974 .20555 .31171 Metetra
.664 .741 .908 r
.20555 .31171 .21369 .31974 .22555 .3154 .21744 .30734 Metetra
.664 .741 .908 r
.21744 .30734 .22555 .3154 .23746 .31104 .22939 .30294 Metetra
.664 .741 .908 r
.22939 .30294 .23746 .31104 .24943 .30666 .24139 .29853 Metetra
.664 .741 .908 r
.24139 .29853 .24943 .30666 .26145 .30226 .25344 .29409 Metetra
.664 .741 .908 r
.25344 .29409 .26145 .30226 .27353 .29784 .26555 .28963 Metetra
.664 .741 .908 r
.26555 .28963 .27353 .29784 .28567 .29341 .27772 .28516 Metetra
.664 .741 .908 r
.27772 .28516 .28567 .29341 .29786 .28895 .28995 .28066 Metetra
.664 .741 .908 r
.28995 .28066 .29786 .28895 .31011 .28447 .30223 .27614 Metetra
.664 .741 .908 r
.30223 .27614 .31011 .28447 .32241 .27997 .31457 .2716 Metetra
.664 .741 .908 r
.31457 .2716 .32241 .27997 .33477 .27544 .32697 .26704 Metetra
.664 .741 .908 r
.32697 .26704 .33477 .27544 .34719 .2709 .33942 .26246 Metetra
.664 .741 .908 r
.33942 .26246 .34719 .2709 .35967 .26634 .35194 .25785 Metetra
.664 .741 .908 r
.35194 .25785 .35967 .26634 .37221 .26175 .36451 .25323 Metetra
.664 .741 .908 r
.36451 .25323 .37221 .26175 .3848 .25714 .37714 .24858 Metetra
.664 .741 .908 r
.37714 .24858 .3848 .25714 .39746 .25251 .38984 .24391 Metetra
.664 .741 .908 r
.38984 .24391 .39746 .25251 .41017 .24786 .40259 .23922 Metetra
.664 .741 .908 r
.40259 .23922 .41017 .24786 .42295 .24319 .4154 .2345 Metetra
.664 .741 .908 r
.4154 .2345 .42295 .24319 .43579 .23849 .42828 .22976 Metetra
.664 .741 .908 r
.42828 .22976 .43579 .23849 .44868 .23377 .44121 .225 Metetra
.664 .741 .908 r
.44121 .225 .44868 .23377 .46164 .22903 .45421 .22022 Metetra
.664 .741 .908 r
.45421 .22022 .46164 .22903 .47467 .22427 .46728 .21542 Metetra
.664 .741 .908 r
.46728 .21542 .47467 .22427 .48775 .21948 .4804 .21059 Metetra
.664 .741 .908 r
.4804 .21059 .48775 .21948 .5009 .21468 .49359 .20574 Metetra
.664 .741 .908 r
.49359 .20574 .5009 .21468 .51411 .20984 .50684 .20086 Metetra
.664 .741 .908 r
.50684 .20086 .51411 .20984 .52738 .20499 .52016 .19596 Metetra
.664 .741 .908 r
.52016 .19596 .52738 .20499 .54072 .20011 .53354 .19104 Metetra
.664 .741 .908 r
.53354 .19104 .54072 .20011 .55412 .19521 .54698 .18609 Metetra
.664 .741 .908 r
.54698 .18609 .55412 .19521 .56759 .19028 .56049 .18112 Metetra
.664 .741 .908 r
.56049 .18112 .56759 .19028 .58113 .18533 .57407 .17612 Metetra
.664 .741 .908 r
.57407 .17612 .58113 .18533 .59473 .18035 .58772 .1711 Metetra
.664 .741 .908 r
.58772 .1711 .59473 .18035 .60839 .17535 .60143 .16606 Metetra
.664 .741 .908 r
.60143 .16606 .60839 .17535 .62213 .17033 .61521 .16099 Metetra
.664 .741 .908 r
.61521 .16099 .62213 .17033 .63593 .16528 .62906 .15589 Metetra
.664 .741 .908 r
.62906 .15589 .63593 .16528 .6498 .16021 .64298 .15077 Metetra
.664 .741 .908 r
.64298 .15077 .6498 .16021 .66374 .15511 .65696 .14563 Metetra
.664 .741 .908 r
.65696 .14563 .66374 .15511 .67775 .14998 .67102 .14045 Metetra
.664 .741 .908 r
.67102 .14045 .67775 .14998 .69183 .14483 .68515 .13526 Metetra
.664 .741 .908 r
.68515 .13526 .69183 .14483 .70598 .13966 .69934 .13003 Metetra
.664 .741 .908 r
.69934 .13003 .70598 .13966 .7202 .13446 .71361 .12478 Metetra
.664 .741 .908 r
.71361 .12478 .7202 .13446 .73449 .12923 .72795 .11951 Metetra
.664 .741 .908 r
.72795 .11951 .73449 .12923 .74885 .12397 .74237 .1142 Metetra
.664 .741 .908 r
.74237 .1142 .74885 .12397 .76329 .11869 .75685 .10887 Metetra
.664 .741 .908 r
.11539 .33394 .12381 .34178 .13533 .33755 .12694 .32967 Metetra
.664 .741 .908 r
.12694 .32967 .13533 .33755 .1469 .33329 .13854 .32538 Metetra
.664 .741 .908 r
.13854 .32538 .1469 .33329 .15852 .32901 .15019 .32107 Metetra
.664 .741 .908 r
.15019 .32107 .15852 .32901 .1702 .32472 .1619 .31673 Metetra
.664 .741 .908 r
.1619 .31673 .1702 .32472 .18193 .3204 .17366 .31238 Metetra
.664 .741 .908 r
.17366 .31238 .18193 .3204 .19371 .31607 .18547 .30801 Metetra
.664 .741 .908 r
.18547 .30801 .19371 .31607 .20555 .31171 .19734 .30362 Metetra
.664 .741 .908 r
.19734 .30362 .20555 .31171 .21744 .30734 .20926 .29921 Metetra
.664 .741 .908 r
.20926 .29921 .21744 .30734 .22939 .30294 .22124 .29477 Metetra
.664 .741 .908 r
.22124 .29477 .22939 .30294 .24139 .29853 .23328 .29032 Metetra
.664 .741 .908 r
.23328 .29032 .24139 .29853 .25344 .29409 .24536 .28585 Metetra
.664 .741 .908 r
.24536 .28585 .25344 .29409 .26555 .28963 .25751 .28135 Metetra
.664 .741 .908 r
.25751 .28135 .26555 .28963 .27772 .28516 .26971 .27684 Metetra
.664 .741 .908 r
.26971 .27684 .27772 .28516 .28995 .28066 .28197 .2723 Metetra
.664 .741 .908 r
.28197 .2723 .28995 .28066 .30223 .27614 .29429 .26774 Metetra
.664 .741 .908 r
.29429 .26774 .30223 .27614 .31457 .2716 .30666 .26316 Metetra
.664 .741 .908 r
.30666 .26316 .31457 .2716 .32697 .26704 .31909 .25856 Metetra
.664 .741 .908 r
.31909 .25856 .32697 .26704 .33942 .26246 .33159 .25394 Metetra
.664 .741 .908 r
.33159 .25394 .33942 .26246 .35194 .25785 .34414 .24929 Metetra
.664 .741 .908 r
.34414 .24929 .35194 .25785 .36451 .25323 .35675 .24463 Metetra
.664 .741 .908 r
.35675 .24463 .36451 .25323 .37714 .24858 .36942 .23994 Metetra
.664 .741 .908 r
.36942 .23994 .37714 .24858 .38984 .24391 .38215 .23523 Metetra
.664 .741 .908 r
.38215 .23523 .38984 .24391 .40259 .23922 .39494 .23049 Metetra
.664 .741 .908 r
.39494 .23049 .40259 .23922 .4154 .2345 .40779 .22574 Metetra
.664 .741 .908 r
.40779 .22574 .4154 .2345 .42828 .22976 .4207 .22096 Metetra
.664 .741 .908 r
.4207 .22096 .42828 .22976 .44121 .225 .43368 .21616 Metetra
.664 .741 .908 r
.43368 .21616 .44121 .225 .45421 .22022 .44672 .21133 Metetra
.664 .741 .908 r
.44672 .21133 .45421 .22022 .46728 .21542 .45982 .20648 Metetra
.664 .741 .908 r
.45982 .20648 .46728 .21542 .4804 .21059 .47298 .20161 Metetra
.664 .741 .908 r
.47298 .20161 .4804 .21059 .49359 .20574 .48621 .19672 Metetra
.664 .741 .908 r
.48621 .19672 .49359 .20574 .50684 .20086 .49951 .1918 Metetra
.664 .741 .908 r
.49951 .1918 .50684 .20086 .52016 .19596 .51286 .18685 Metetra
.664 .741 .908 r
.51286 .18685 .52016 .19596 .53354 .19104 .52629 .18189 Metetra
.664 .741 .908 r
.52629 .18189 .53354 .19104 .54698 .18609 .53978 .17689 Metetra
.664 .741 .908 r
.53978 .17689 .54698 .18609 .56049 .18112 .55333 .17188 Metetra
.664 .741 .908 r
.55333 .17188 .56049 .18112 .57407 .17612 .56696 .16684 Metetra
.664 .741 .908 r
.56696 .16684 .57407 .17612 .58772 .1711 .58065 .16177 Metetra
.664 .741 .908 r
.58065 .16177 .58772 .1711 .60143 .16606 .5944 .15668 Metetra
.664 .741 .908 r
.5944 .15668 .60143 .16606 .61521 .16099 .60823 .15156 Metetra
.664 .741 .908 r
.60823 .15156 .61521 .16099 .62906 .15589 .62212 .14642 Metetra
.664 .741 .908 r
.62212 .14642 .62906 .15589 .64298 .15077 .63609 .14125 Metetra
.664 .741 .908 r
.63609 .14125 .64298 .15077 .65696 .14563 .65012 .13606 Metetra
.664 .741 .908 r
.65012 .13606 .65696 .14563 .67102 .14045 .66423 .13084 Metetra
.664 .741 .908 r
.66423 .13084 .67102 .14045 .68515 .13526 .6784 .12559 Metetra
.664 .741 .908 r
.6784 .12559 .68515 .13526 .69934 .13003 .69265 .12032 Metetra
.664 .741 .908 r
.69265 .12032 .69934 .13003 .71361 .12478 .70697 .11502 Metetra
.664 .741 .908 r
.70697 .11502 .71361 .12478 .72795 .11951 .72136 .1097 Metetra
.664 .741 .908 r
.72136 .1097 .72795 .11951 .74237 .1142 .73582 .10434 Metetra
.664 .741 .908 r
.73582 .10434 .74237 .1142 .75685 .10887 .75036 .09896 Metetra
.664 .741 .908 r
.1069 .32604 .11539 .33394 .12694 .32967 .11848 .32173 Metetra
.664 .741 .908 r
.11848 .32173 .12694 .32967 .13854 .32538 .13011 .3174 Metetra
.664 .741 .908 r
.13011 .3174 .13854 .32538 .15019 .32107 .14179 .31305 Metetra
.664 .741 .908 r
.14179 .31305 .15019 .32107 .1619 .31673 .15353 .30868 Metetra
.664 .741 .908 r
.15353 .30868 .1619 .31673 .17366 .31238 .16532 .3043 Metetra
.664 .741 .908 r
.16532 .3043 .17366 .31238 .18547 .30801 .17717 .29989 Metetra
.664 .741 .908 r
.17717 .29989 .18547 .30801 .19734 .30362 .18906 .29546 Metetra
.664 .741 .908 r
.18906 .29546 .19734 .30362 .20926 .29921 .20102 .29101 Metetra
.664 .741 .908 r
.20102 .29101 .20926 .29921 .22124 .29477 .21303 .28654 Metetra
.664 .741 .908 r
.21303 .28654 .22124 .29477 .23328 .29032 .22509 .28204 Metetra
.664 .741 .908 r
.22509 .28204 .23328 .29032 .24536 .28585 .23722 .27753 Metetra
.664 .741 .908 r
.23722 .27753 .24536 .28585 .25751 .28135 .2494 .273 Metetra
.664 .741 .908 r
.2494 .273 .25751 .28135 .26971 .27684 .26163 .26844 Metetra
.664 .741 .908 r
.26163 .26844 .26971 .27684 .28197 .2723 .27392 .26387 Metetra
.664 .741 .908 r
.27392 .26387 .28197 .2723 .29429 .26774 .28628 .25927 Metetra
.664 .741 .908 r
.28628 .25927 .29429 .26774 .30666 .26316 .29869 .25465 Metetra
.664 .741 .908 r
.29869 .25465 .30666 .26316 .31909 .25856 .31115 .25001 Metetra
.664 .741 .908 r
.31115 .25001 .31909 .25856 .33159 .25394 .32368 .24535 Metetra
.664 .741 .908 r
.32368 .24535 .33159 .25394 .34414 .24929 .33627 .24066 Metetra
.664 .741 .908 r
.33627 .24066 .34414 .24929 .35675 .24463 .34891 .23595 Metetra
.664 .741 .908 r
.34891 .23595 .35675 .24463 .36942 .23994 .36162 .23122 Metetra
.664 .741 .908 r
.36162 .23122 .36942 .23994 .38215 .23523 .37439 .22647 Metetra
.664 .741 .908 r
.37439 .22647 .38215 .23523 .39494 .23049 .38722 .2217 Metetra
.664 .741 .908 r
.38722 .2217 .39494 .23049 .40779 .22574 .40011 .2169 Metetra
.664 .741 .908 r
.40011 .2169 .40779 .22574 .4207 .22096 .41306 .21208 Metetra
.664 .741 .908 r
.41306 .21208 .4207 .22096 .43368 .21616 .42608 .20723 Metetra
.664 .741 .908 r
.42608 .20723 .43368 .21616 .44672 .21133 .43915 .20236 Metetra
.664 .741 .908 r
.43915 .20236 .44672 .21133 .45982 .20648 .4523 .19747 Metetra
.664 .741 .908 r
.4523 .19747 .45982 .20648 .47298 .20161 .4655 .19256 Metetra
.664 .741 .908 r
.4655 .19256 .47298 .20161 .48621 .19672 .47877 .18762 Metetra
.664 .741 .908 r
.47877 .18762 .48621 .19672 .49951 .1918 .49211 .18265 Metetra
.664 .741 .908 r
.49211 .18265 .49951 .1918 .51286 .18685 .50551 .17766 Metetra
.664 .741 .908 r
.50551 .17766 .51286 .18685 .52629 .18189 .51897 .17265 Metetra
.664 .741 .908 r
.51897 .17265 .52629 .18189 .53978 .17689 .53251 .16761 Metetra
.664 .741 .908 r
.53251 .16761 .53978 .17689 .55333 .17188 .54611 .16255 Metetra
.664 .741 .908 r
.54611 .16255 .55333 .17188 .56696 .16684 .55977 .15746 Metetra
.664 .741 .908 r
.55977 .15746 .56696 .16684 .58065 .16177 .57351 .15235 Metetra
.664 .741 .908 r
.57351 .15235 .58065 .16177 .5944 .15668 .58731 .14721 Metetra
.664 .741 .908 r
.58731 .14721 .5944 .15668 .60823 .15156 .60118 .14205 Metetra
.664 .741 .908 r
.60118 .14205 .60823 .15156 .62212 .14642 .61512 .13686 Metetra
.664 .741 .908 r
.61512 .13686 .62212 .14642 .63609 .14125 .62914 .13164 Metetra
.664 .741 .908 r
.62914 .13164 .63609 .14125 .65012 .13606 .64322 .1264 Metetra
.664 .741 .908 r
.64322 .1264 .65012 .13606 .66423 .13084 .65737 .12113 Metetra
.664 .741 .908 r
.65737 .12113 .66423 .13084 .6784 .12559 .67159 .11584 Metetra
.664 .741 .908 r
.67159 .11584 .6784 .12559 .69265 .12032 .68589 .11052 Metetra
.664 .741 .908 r
.68589 .11052 .69265 .12032 .70697 .11502 .70026 .10517 Metetra
.664 .741 .908 r
.70026 .10517 .70697 .11502 .72136 .1097 .7147 .09979 Metetra
.664 .741 .908 r
.7147 .09979 .72136 .1097 .73582 .10434 .72922 .09439 Metetra
.664 .741 .908 r
.72922 .09439 .73582 .10434 .75036 .09896 .74381 .08896 Metetra
.664 .741 .908 r
.09834 .31807 .1069 .32604 .11848 .32173 .10995 .31372 Metetra
.664 .741 .908 r
.10995 .31372 .11848 .32173 .13011 .3174 .12161 .30936 Metetra
.664 .741 .908 r
.12161 .30936 .13011 .3174 .14179 .31305 .13332 .30497 Metetra
.664 .741 .908 r
.13332 .30497 .14179 .31305 .15353 .30868 .14509 .30057 Metetra
.664 .741 .908 r
.14509 .30057 .15353 .30868 .16532 .3043 .15691 .29614 Metetra
.664 .741 .908 r
.15691 .29614 .16532 .3043 .17717 .29989 .16879 .29169 Metetra
.664 .741 .908 r
.16879 .29169 .17717 .29989 .18906 .29546 .18072 .28723 Metetra
.664 .741 .908 r
.18072 .28723 .18906 .29546 .20102 .29101 .1927 .28274 Metetra
.664 .741 .908 r
.1927 .28274 .20102 .29101 .21303 .28654 .20475 .27823 Metetra
.664 .741 .908 r
.20475 .27823 .21303 .28654 .22509 .28204 .21684 .2737 Metetra
.664 .741 .908 r
.21684 .2737 .22509 .28204 .23722 .27753 .229 .26915 Metetra
.664 .741 .908 r
.229 .26915 .23722 .27753 .2494 .273 .24121 .26457 Metetra
.664 .741 .908 r
.24121 .26457 .2494 .273 .26163 .26844 .25348 .25998 Metetra
.664 .741 .908 r
.25348 .25998 .26163 .26844 .27392 .26387 .26581 .25536 Metetra
.664 .741 .908 r
.26581 .25536 .27392 .26387 .28628 .25927 .27819 .25073 Metetra
.664 .741 .908 r
.27819 .25073 .28628 .25927 .29869 .25465 .29064 .24607 Metetra
.664 .741 .908 r
.29064 .24607 .29869 .25465 .31115 .25001 .30314 .24138 Metetra
.664 .741 .908 r
.30314 .24138 .31115 .25001 .32368 .24535 .31571 .23668 Metetra
.664 .741 .908 r
.31571 .23668 .32368 .24535 .33627 .24066 .32833 .23195 Metetra
.664 .741 .908 r
.32833 .23195 .33627 .24066 .34891 .23595 .34101 .2272 Metetra
.664 .741 .908 r
.34101 .2272 .34891 .23595 .36162 .23122 .35376 .22243 Metetra
.664 .741 .908 r
.35376 .22243 .36162 .23122 .37439 .22647 .36656 .21764 Metetra
.664 .741 .908 r
.36656 .21764 .37439 .22647 .38722 .2217 .37943 .21282 Metetra
.664 .741 .908 r
.37943 .21282 .38722 .2217 .40011 .2169 .39236 .20798 Metetra
.664 .741 .908 r
.39236 .20798 .40011 .2169 .41306 .21208 .40535 .20311 Metetra
.664 .741 .908 r
.40535 .20311 .41306 .21208 .42608 .20723 .4184 .19823 Metetra
.664 .741 .908 r
.4184 .19823 .42608 .20723 .43915 .20236 .43152 .19331 Metetra
.664 .741 .908 r
.43152 .19331 .43915 .20236 .4523 .19747 .44471 .18838 Metetra
.664 .741 .908 r
.44471 .18838 .4523 .19747 .4655 .19256 .45795 .18342 Metetra
.664 .741 .908 r
.45795 .18342 .4655 .19256 .47877 .18762 .47126 .17843 Metetra
.664 .741 .908 r
.47126 .17843 .47877 .18762 .49211 .18265 .48464 .17342 Metetra
.664 .741 .908 r
.48464 .17342 .49211 .18265 .50551 .17766 .49808 .16839 Metetra
.664 .741 .908 r
.49808 .16839 .50551 .17766 .51897 .17265 .51159 .16333 Metetra
.664 .741 .908 r
.51159 .16333 .51897 .17265 .53251 .16761 .52517 .15825 Metetra
.664 .741 .908 r
.52517 .15825 .53251 .16761 .54611 .16255 .53881 .15314 Metetra
.664 .741 .908 r
.53881 .15314 .54611 .16255 .55977 .15746 .55253 .148 Metetra
.664 .741 .908 r
.55253 .148 .55977 .15746 .57351 .15235 .56631 .14284 Metetra
.664 .741 .908 r
.56631 .14284 .57351 .15235 .58731 .14721 .58015 .13766 Metetra
.664 .741 .908 r
.58015 .13766 .58731 .14721 .60118 .14205 .59407 .13245 Metetra
.664 .741 .908 r
.59407 .13245 .60118 .14205 .61512 .13686 .60806 .12721 Metetra
.664 .741 .908 r
.60806 .12721 .61512 .13686 .62914 .13164 .62212 .12195 Metetra
.664 .741 .908 r
.62212 .12195 .62914 .13164 .64322 .1264 .63625 .11666 Metetra
.664 .741 .908 r
.63625 .11666 .64322 .1264 .65737 .12113 .65045 .11134 Metetra
.664 .741 .908 r
.65045 .11134 .65737 .12113 .67159 .11584 .66472 .10599 Metetra
.664 .741 .908 r
.66472 .10599 .67159 .11584 .68589 .11052 .67907 .10062 Metetra
.664 .741 .908 r
.67907 .10062 .68589 .11052 .70026 .10517 .69349 .09522 Metetra
.664 .741 .908 r
.69349 .09522 .70026 .10517 .7147 .09979 .70798 .0898 Metetra
.664 .741 .908 r
.70798 .0898 .7147 .09979 .72922 .09439 .72255 .08434 Metetra
.664 .741 .908 r
.72255 .08434 .72922 .09439 .74381 .08896 .73719 .07886 Metetra
.664 .741 .908 r
.08971 .31003 .09834 .31807 .10995 .31372 .10135 .30565 Metetra
.664 .741 .908 r
.10135 .30565 .10995 .31372 .12161 .30936 .11304 .30125 Metetra
.664 .741 .908 r
.11304 .30125 .12161 .30936 .13332 .30497 .12478 .29682 Metetra
.664 .741 .908 r
.12478 .29682 .13332 .30497 .14509 .30057 .13658 .29238 Metetra
.664 .741 .908 r
.13658 .29238 .14509 .30057 .15691 .29614 .14843 .28791 Metetra
.664 .741 .908 r
.14843 .28791 .15691 .29614 .16879 .29169 .16033 .28343 Metetra
.664 .741 .908 r
.16033 .28343 .16879 .29169 .18072 .28723 .1723 .27892 Metetra
.664 .741 .908 r
.1723 .27892 .18072 .28723 .1927 .28274 .18432 .2744 Metetra
.664 .741 .908 r
.18432 .2744 .1927 .28274 .20475 .27823 .19639 .26985 Metetra
.664 .741 .908 r
.19639 .26985 .20475 .27823 .21684 .2737 .20852 .26528 Metetra
.664 .741 .908 r
.20852 .26528 .21684 .2737 .229 .26915 .22071 .26069 Metetra
.664 .741 .908 r
.22071 .26069 .229 .26915 .24121 .26457 .23296 .25608 Metetra
.664 .741 .908 r
.23296 .25608 .24121 .26457 .25348 .25998 .24526 .25144 Metetra
.664 .741 .908 r
.24526 .25144 .25348 .25998 .26581 .25536 .25762 .24678 Metetra
.664 .741 .908 r
.25762 .24678 .26581 .25536 .27819 .25073 .27004 .24211 Metetra
.664 .741 .908 r
.27004 .24211 .27819 .25073 .29064 .24607 .28252 .23741 Metetra
.664 .741 .908 r
.28252 .23741 .29064 .24607 .30314 .24138 .29506 .23268 Metetra
.664 .741 .908 r
.29506 .23268 .30314 .24138 .31571 .23668 .30766 .22794 Metetra
.664 .741 .908 r
.30766 .22794 .31571 .23668 .32833 .23195 .32032 .22317 Metetra
.664 .741 .908 r
.32032 .22317 .32833 .23195 .34101 .2272 .33304 .21838 Metetra
.664 .741 .908 r
.33304 .21838 .34101 .2272 .35376 .22243 .34582 .21356 Metetra
.664 .741 .908 r
.34582 .21356 .35376 .22243 .36656 .21764 .35866 .20872 Metetra
.664 .741 .908 r
.35866 .20872 .36656 .21764 .37943 .21282 .37157 .20386 Metetra
.664 .741 .908 r
.37157 .20386 .37943 .21282 .39236 .20798 .38454 .19898 Metetra
.664 .741 .908 r
.38454 .19898 .39236 .20798 .40535 .20311 .39757 .19407 Metetra
.664 .741 .908 r
.39757 .19407 .40535 .20311 .4184 .19823 .41066 .18914 Metetra
.664 .741 .908 r
.41066 .18914 .4184 .19823 .43152 .19331 .42382 .18418 Metetra
.664 .741 .908 r
.42382 .18418 .43152 .19331 .44471 .18838 .43705 .1792 Metetra
.664 .741 .908 r
.43705 .1792 .44471 .18838 .45795 .18342 .45033 .1742 Metetra
.664 .741 .908 r
.45033 .1742 .45795 .18342 .47126 .17843 .46369 .16917 Metetra
.664 .741 .908 r
.46369 .16917 .47126 .17843 .48464 .17342 .47711 .16411 Metetra
.664 .741 .908 r
.47711 .16411 .48464 .17342 .49808 .16839 .49059 .15903 Metetra
.664 .741 .908 r
.49059 .15903 .49808 .16839 .51159 .16333 .50415 .15393 Metetra
.664 .741 .908 r
.50415 .15393 .51159 .16333 .52517 .15825 .51777 .1488 Metetra
.664 .741 .908 r
.51777 .1488 .52517 .15825 .53881 .15314 .53145 .14364 Metetra
.664 .741 .908 r
.53145 .14364 .53881 .15314 .55253 .148 .54521 .13846 Metetra
.664 .741 .908 r
.54521 .13846 .55253 .148 .56631 .14284 .55904 .13325 Metetra
.664 .741 .908 r
.55904 .13325 .56631 .14284 .58015 .13766 .57293 .12802 Metetra
.664 .741 .908 r
.57293 .12802 .58015 .13766 .59407 .13245 .5869 .12276 Metetra
.664 .741 .908 r
.5869 .12276 .59407 .13245 .60806 .12721 .60093 .11747 Metetra
.664 .741 .908 r
.60093 .11747 .60806 .12721 .62212 .12195 .61504 .11216 Metetra
.664 .741 .908 r
.61504 .11216 .62212 .12195 .63625 .11666 .62921 .10682 Metetra
.664 .741 .908 r
.62921 .10682 .63625 .11666 .65045 .11134 .64346 .10145 Metetra
.664 .741 .908 r
.64346 .10145 .65045 .11134 .66472 .10599 .65779 .09606 Metetra
.664 .741 .908 r
.65779 .09606 .66472 .10599 .67907 .10062 .67218 .09063 Metetra
.664 .741 .908 r
.67218 .09063 .67907 .10062 .69349 .09522 .68665 .08518 Metetra
.664 .741 .908 r
.68665 .08518 .69349 .09522 .70798 .0898 .7012 .0797 Metetra
.664 .741 .908 r
.7012 .0797 .70798 .0898 .72255 .08434 .71581 .0742 Metetra
.664 .741 .908 r
.71581 .0742 .72255 .08434 .73719 .07886 .73051 .06866 Metetra
.664 .741 .908 r
.081 .30192 .08971 .31003 .10135 .30565 .09267 .2975 Metetra
.664 .741 .908 r
.09267 .2975 .10135 .30565 .11304 .30125 .10439 .29306 Metetra
.664 .741 .908 r
.10439 .29306 .11304 .30125 .12478 .29682 .11616 .2886 Metetra
.664 .741 .908 r
.11616 .2886 .12478 .29682 .13658 .29238 .12799 .28412 Metetra
.664 .741 .908 r
.12799 .28412 .13658 .29238 .14843 .28791 .13987 .27962 Metetra
.664 .741 .908 r
.13987 .27962 .14843 .28791 .16033 .28343 .15181 .27509 Metetra
.664 .741 .908 r
.15181 .27509 .16033 .28343 .1723 .27892 .1638 .27055 Metetra
.664 .741 .908 r
.1638 .27055 .1723 .27892 .18432 .2744 .17585 .26598 Metetra
.664 .741 .908 r
.17585 .26598 .18432 .2744 .19639 .26985 .18796 .2614 Metetra
.664 .741 .908 r
.18796 .2614 .19639 .26985 .20852 .26528 .20013 .25679 Metetra
.664 .741 .908 r
.20013 .25679 .20852 .26528 .22071 .26069 .21235 .25216 Metetra
.664 .741 .908 r
.21235 .25216 .22071 .26069 .23296 .25608 .22463 .2475 Metetra
.664 .741 .908 r
.22463 .2475 .23296 .25608 .24526 .25144 .23697 .24283 Metetra
.664 .741 .908 r
.23697 .24283 .24526 .25144 .25762 .24678 .24936 .23813 Metetra
.664 .741 .908 r
.24936 .23813 .25762 .24678 .27004 .24211 .26182 .23341 Metetra
.664 .741 .908 r
.26182 .23341 .27004 .24211 .28252 .23741 .27433 .22867 Metetra
.664 .741 .908 r
.27433 .22867 .28252 .23741 .29506 .23268 .28691 .2239 Metetra
.664 .741 .908 r
.28691 .2239 .29506 .23268 .30766 .22794 .29954 .21912 Metetra
.664 .741 .908 r
.29954 .21912 .30766 .22794 .32032 .22317 .31224 .2143 Metetra
.664 .741 .908 r
.31224 .2143 .32032 .22317 .33304 .21838 .325 .20947 Metetra
.664 .741 .908 r
.325 .20947 .33304 .21838 .34582 .21356 .33782 .20461 Metetra
.664 .741 .908 r
.33782 .20461 .34582 .21356 .35866 .20872 .3507 .19973 Metetra
.664 .741 .908 r
.3507 .19973 .35866 .20872 .37157 .20386 .36364 .19483 Metetra
.664 .741 .908 r
.36364 .19483 .37157 .20386 .38454 .19898 .37665 .1899 Metetra
.664 .741 .908 r
.37665 .1899 .38454 .19898 .39757 .19407 .38972 .18495 Metetra
.664 .741 .908 r
.38972 .18495 .39757 .19407 .41066 .18914 .40285 .17997 Metetra
.664 .741 .908 r
.40285 .17997 .41066 .18914 .42382 .18418 .41605 .17497 Metetra
.664 .741 .908 r
.41605 .17497 .42382 .18418 .43705 .1792 .42932 .16994 Metetra
.664 .741 .908 r
.42932 .16994 .43705 .1792 .45033 .1742 .44265 .16489 Metetra
.664 .741 .908 r
.44265 .16489 .45033 .1742 .46369 .16917 .45604 .15981 Metetra
.664 .741 .908 r
.45604 .15981 .46369 .16917 .47711 .16411 .4695 .15471 Metetra
.664 .741 .908 r
.4695 .15471 .47711 .16411 .49059 .15903 .48303 .14959 Metetra
.664 .741 .908 r
.48303 .14959 .49059 .15903 .50415 .15393 .49663 .14444 Metetra
.664 .741 .908 r
.49663 .14444 .50415 .15393 .51777 .1488 .51029 .13926 Metetra
.664 .741 .908 r
.51029 .13926 .51777 .1488 .53145 .14364 .52403 .13405 Metetra
.664 .741 .908 r
.52403 .13405 .53145 .14364 .54521 .13846 .53783 .12882 Metetra
.664 .741 .908 r
.53783 .12882 .54521 .13846 .55904 .13325 .5517 .12357 Metetra
.664 .741 .908 r
.5517 .12357 .55904 .13325 .57293 .12802 .56564 .11829 Metetra
.664 .741 .908 r
.56564 .11829 .57293 .12802 .5869 .12276 .57965 .11298 Metetra
.664 .741 .908 r
.57965 .11298 .5869 .12276 .60093 .11747 .59373 .10764 Metetra
.664 .741 .908 r
.59373 .10764 .60093 .11747 .61504 .11216 .60789 .10228 Metetra
.664 .741 .908 r
.60789 .10228 .61504 .11216 .62921 .10682 .62211 .09689 Metetra
.664 .741 .908 r
.62211 .09689 .62921 .10682 .64346 .10145 .63641 .09147 Metetra
.664 .741 .908 r
.63641 .09147 .64346 .10145 .65779 .09606 .65078 .08602 Metetra
.664 .741 .908 r
.65078 .08602 .65779 .09606 .67218 .09063 .66523 .08055 Metetra
.664 .741 .908 r
.66523 .08055 .67218 .09063 .68665 .08518 .67975 .07505 Metetra
.664 .741 .908 r
.67975 .07505 .68665 .08518 .7012 .0797 .69435 .06952 Metetra
.664 .741 .908 r
.69435 .06952 .7012 .0797 .71581 .0742 .70902 .06396 Metetra
.664 .741 .908 r
.70902 .06396 .71581 .0742 .73051 .06866 .72376 .05837 Metetra
.664 .741 .908 r
.07222 .29375 .081 .30192 .09267 .2975 .08392 .28929 Metetra
.664 .741 .908 r
.08392 .28929 .09267 .2975 .10439 .29306 .09567 .28481 Metetra
.664 .741 .908 r
.09567 .28481 .10439 .29306 .11616 .2886 .10747 .28031 Metetra
.664 .741 .908 r
.10747 .28031 .11616 .2886 .12799 .28412 .11933 .27579 Metetra
.664 .741 .908 r
.11933 .27579 .12799 .28412 .13987 .27962 .13124 .27125 Metetra
.664 .741 .908 r
.13124 .27125 .13987 .27962 .15181 .27509 .14321 .26669 Metetra
.664 .741 .908 r
.14321 .26669 .15181 .27509 .1638 .27055 .15524 .2621 Metetra
.664 .741 .908 r
.15524 .2621 .1638 .27055 .17585 .26598 .16732 .2575 Metetra
.664 .741 .908 r
.16732 .2575 .17585 .26598 .18796 .2614 .17946 .25287 Metetra
.664 .741 .908 r
.17946 .25287 .18796 .2614 .20013 .25679 .19166 .24822 Metetra
.664 .741 .908 r
.19166 .24822 .20013 .25679 .21235 .25216 .20391 .24355 Metetra
.664 .741 .908 r
.20391 .24355 .21235 .25216 .22463 .2475 .21623 .23885 Metetra
.664 .741 .908 r
.21623 .23885 .22463 .2475 .23697 .24283 .2286 .23414 Metetra
.664 .741 .908 r
.2286 .23414 .23697 .24283 .24936 .23813 .24103 .2294 Metetra
.664 .741 .908 r
.24103 .2294 .24936 .23813 .26182 .23341 .25352 .22464 Metetra
.664 .741 .908 r
.25352 .22464 .26182 .23341 .27433 .22867 .26607 .21985 Metetra
.664 .741 .908 r
.26607 .21985 .27433 .22867 .28691 .2239 .27868 .21505 Metetra
.664 .741 .908 r
.27868 .21505 .28691 .2239 .29954 .21912 .29135 .21022 Metetra
.664 .741 .908 r
.29135 .21022 .29954 .21912 .31224 .2143 .30409 .20536 Metetra
.664 .741 .908 r
.30409 .20536 .31224 .2143 .325 .20947 .31688 .20048 Metetra
.664 .741 .908 r
.31688 .20048 .325 .20947 .33782 .20461 .32974 .19558 Metetra
.664 .741 .908 r
.32974 .19558 .33782 .20461 .3507 .19973 .34266 .19066 Metetra
.664 .741 .908 r
.34266 .19066 .3507 .19973 .36364 .19483 .35564 .18571 Metetra
.664 .741 .908 r
.35564 .18571 .36364 .19483 .37665 .1899 .36869 .18074 Metetra
.664 .741 .908 r
.36869 .18074 .37665 .1899 .38972 .18495 .3818 .17574 Metetra
.664 .741 .908 r
.3818 .17574 .38972 .18495 .40285 .17997 .39497 .17072 Metetra
.664 .741 .908 r
.39497 .17072 .40285 .17997 .41605 .17497 .40821 .16567 Metetra
.664 .741 .908 r
.40821 .16567 .41605 .17497 .42932 .16994 .42152 .1606 Metetra
.664 .741 .908 r
.42152 .1606 .42932 .16994 .44265 .16489 .43489 .1555 Metetra
.664 .741 .908 r
.43489 .1555 .44265 .16489 .45604 .15981 .44833 .15038 Metetra
.664 .741 .908 r
.44833 .15038 .45604 .15981 .4695 .15471 .46183 .14523 Metetra
.664 .741 .908 r
.46183 .14523 .4695 .15471 .48303 .14959 .4754 .14006 Metetra
.664 .741 .908 r
.4754 .14006 .48303 .14959 .49663 .14444 .48904 .13486 Metetra
.664 .741 .908 r
.48904 .13486 .49663 .14444 .51029 .13926 .50275 .12963 Metetra
.664 .741 .908 r
.50275 .12963 .51029 .13926 .52403 .13405 .51653 .12438 Metetra
.664 .741 .908 r
.51653 .12438 .52403 .13405 .53783 .12882 .53038 .1191 Metetra
.664 .741 .908 r
.53038 .1191 .53783 .12882 .5517 .12357 .54429 .1138 Metetra
.664 .741 .908 r
.54429 .1138 .5517 .12357 .56564 .11829 .55828 .10846 Metetra
.664 .741 .908 r
.55828 .10846 .56564 .11829 .57965 .11298 .57234 .1031 Metetra
.664 .741 .908 r
.57234 .1031 .57965 .11298 .59373 .10764 .58647 .09772 Metetra
.664 .741 .908 r
.58647 .09772 .59373 .10764 .60789 .10228 .60067 .0923 Metetra
.664 .741 .908 r
.60067 .0923 .60789 .10228 .62211 .09689 .61495 .08686 Metetra
.664 .741 .908 r
.61495 .08686 .62211 .09689 .63641 .09147 .62929 .08139 Metetra
.664 .741 .908 r
.62929 .08139 .63641 .09147 .65078 .08602 .64372 .0759 Metetra
.664 .741 .908 r
.64372 .0759 .65078 .08602 .66523 .08055 .65821 .07037 Metetra
.664 .741 .908 r
.65821 .07037 .66523 .08055 .67975 .07505 .67278 .06481 Metetra
.664 .741 .908 r
.67278 .06481 .67975 .07505 .69435 .06952 .68743 .05923 Metetra
.664 .741 .908 r
.68743 .05923 .69435 .06952 .70902 .06396 .70215 .05362 Metetra
.664 .741 .908 r
.70215 .05362 .70902 .06396 .72376 .05837 .71695 .04798 Metetra
.664 .741 .908 r
.06337 .2855 .07222 .29375 .08392 .28929 .07509 .28101 Metetra
.664 .741 .908 r
.07509 .28101 .08392 .28929 .09567 .28481 .08687 .27649 Metetra
.664 .741 .908 r
.08687 .27649 .09567 .28481 .10747 .28031 .0987 .27195 Metetra
.664 .741 .908 r
.0987 .27195 .10747 .28031 .11933 .27579 .11059 .26739 Metetra
.664 .741 .908 r
.11059 .26739 .11933 .27579 .13124 .27125 .12254 .26281 Metetra
.664 .741 .908 r
.12254 .26281 .13124 .27125 .14321 .26669 .13454 .25821 Metetra
.664 .741 .908 r
.13454 .25821 .14321 .26669 .15524 .2621 .1466 .25358 Metetra
.664 .741 .908 r
.1466 .25358 .15524 .2621 .16732 .2575 .15871 .24894 Metetra
.664 .741 .908 r
.15871 .24894 .16732 .2575 .17946 .25287 .17088 .24427 Metetra
.664 .741 .908 r
.17088 .24427 .17946 .25287 .19166 .24822 .18312 .23958 Metetra
.664 .741 .908 r
.18312 .23958 .19166 .24822 .20391 .24355 .1954 .23486 Metetra
.664 .741 .908 r
.1954 .23486 .20391 .24355 .21623 .23885 .20775 .23013 Metetra
.664 .741 .908 r
.20775 .23013 .21623 .23885 .2286 .23414 .22016 .22537 Metetra
.664 .741 .908 r
.22016 .22537 .2286 .23414 .24103 .2294 .23262 .22059 Metetra
.664 .741 .908 r
.23262 .22059 .24103 .2294 .25352 .22464 .24515 .21579 Metetra
.664 .741 .908 r
.24515 .21579 .25352 .22464 .26607 .21985 .25774 .21096 Metetra
.664 .741 .908 r
.25774 .21096 .26607 .21985 .27868 .21505 .27038 .20611 Metetra
.664 .741 .908 r
.27038 .20611 .27868 .21505 .29135 .21022 .28309 .20124 Metetra
.664 .741 .908 r
.28309 .20124 .29135 .21022 .30409 .20536 .29586 .19634 Metetra
.664 .741 .908 r
.29586 .19634 .30409 .20536 .31688 .20048 .30869 .19142 Metetra
.664 .741 .908 r
.30869 .19142 .31688 .20048 .32974 .19558 .32159 .18647 Metetra
.664 .741 .908 r
.32159 .18647 .32974 .19558 .34266 .19066 .33455 .1815 Metetra
.664 .741 .908 r
.33455 .1815 .34266 .19066 .35564 .18571 .34757 .17651 Metetra
.664 .741 .908 r
.34757 .17651 .35564 .18571 .36869 .18074 .36065 .17149 Metetra
.664 .741 .908 r
.36065 .17149 .36869 .18074 .3818 .17574 .37381 .16645 Metetra
.664 .741 .908 r
.37381 .16645 .3818 .17574 .39497 .17072 .38702 .16138 Metetra
.664 .741 .908 r
.38702 .16138 .39497 .17072 .40821 .16567 .4003 .15629 Metetra
.664 .741 .908 r
.4003 .15629 .40821 .16567 .42152 .1606 .41365 .15117 Metetra
.664 .741 .908 r
.41365 .15117 .42152 .1606 .43489 .1555 .42706 .14602 Metetra
.664 .741 .908 r
.42706 .14602 .43489 .1555 .44833 .15038 .44054 .14085 Metetra
.664 .741 .908 r
.44054 .14085 .44833 .15038 .46183 .14523 .45409 .13566 Metetra
.664 .741 .908 r
.45409 .13566 .46183 .14523 .4754 .14006 .4677 .13044 Metetra
.664 .741 .908 r
.4677 .13044 .4754 .14006 .48904 .13486 .48139 .12519 Metetra
.664 .741 .908 r
.48139 .12519 .48904 .13486 .50275 .12963 .49514 .11991 Metetra
.664 .741 .908 r
.49514 .11991 .50275 .12963 .51653 .12438 .50896 .11461 Metetra
.664 .741 .908 r
.50896 .11461 .51653 .12438 .53038 .1191 .52286 .10929 Metetra
.664 .741 .908 r
.52286 .10929 .53038 .1191 .54429 .1138 .53682 .10393 Metetra
.664 .741 .908 r
.53682 .10393 .54429 .1138 .55828 .10846 .55085 .09855 Metetra
.664 .741 .908 r
.55085 .09855 .55828 .10846 .57234 .1031 .56496 .09314 Metetra
.664 .741 .908 r
.56496 .09314 .57234 .1031 .58647 .09772 .57914 .0877 Metetra
.664 .741 .908 r
.57914 .0877 .58647 .09772 .60067 .0923 .59339 .08224 Metetra
.664 .741 .908 r
.59339 .08224 .60067 .0923 .61495 .08686 .60771 .07674 Metetra
.664 .741 .908 r
.60771 .07674 .61495 .08686 .62929 .08139 .62211 .07122 Metetra
.664 .741 .908 r
.62211 .07122 .62929 .08139 .64372 .0759 .63658 .06567 Metetra
.664 .741 .908 r
.63658 .06567 .64372 .0759 .65821 .07037 .65113 .06009 Metetra
.664 .741 .908 r
.65113 .06009 .65821 .07037 .67278 .06481 .66575 .05448 Metetra
.664 .741 .908 r
.66575 .05448 .67278 .06481 .68743 .05923 .68045 .04885 Metetra
.664 .741 .908 r
.68045 .04885 .68743 .05923 .70215 .05362 .69523 .04318 Metetra
.664 .741 .908 r
.69523 .04318 .70215 .05362 .71695 .04798 .71008 .03748 Metetra
.664 .741 .908 r
.05443 .27718 .06337 .2855 .07509 .28101 .06619 .27265 Metetra
.664 .741 .908 r
.06619 .27265 .07509 .28101 .08687 .27649 .078 .26809 Metetra
.664 .741 .908 r
.078 .26809 .08687 .27649 .0987 .27195 .08986 .26352 Metetra
.664 .741 .908 r
.08986 .26352 .0987 .27195 .11059 .26739 .10178 .25892 Metetra
.664 .741 .908 r
.10178 .25892 .11059 .26739 .12254 .26281 .11376 .2543 Metetra
.664 .741 .908 r
.11376 .2543 .12254 .26281 .13454 .25821 .12579 .24965 Metetra
.664 .741 .908 r
.12579 .24965 .13454 .25821 .1466 .25358 .13788 .24499 Metetra
.664 .741 .908 r
.13788 .24499 .1466 .25358 .15871 .24894 .15003 .2403 Metetra
.664 .741 .908 r
.15003 .2403 .15871 .24894 .17088 .24427 .16223 .23559 Metetra
.664 .741 .908 r
.16223 .23559 .17088 .24427 .18312 .23958 .1745 .23086 Metetra
.664 .741 .908 r
.1745 .23086 .18312 .23958 .1954 .23486 .18682 .22611 Metetra
.664 .741 .908 r
.18682 .22611 .1954 .23486 .20775 .23013 .1992 .22133 Metetra
.664 .741 .908 r
.1992 .22133 .20775 .23013 .22016 .22537 .21164 .21653 Metetra
.664 .741 .908 r
.21164 .21653 .22016 .22537 .23262 .22059 .22414 .2117 Metetra
.664 .741 .908 r
.22414 .2117 .23262 .22059 .24515 .21579 .2367 .20686 Metetra
.664 .741 .908 r
.2367 .20686 .24515 .21579 .25774 .21096 .24933 .20199 Metetra
.664 .741 .908 r
.24933 .20199 .25774 .21096 .27038 .20611 .26201 .19709 Metetra
.664 .741 .908 r
.26201 .19709 .27038 .20611 .28309 .20124 .27476 .19218 Metetra
.664 .741 .908 r
.27476 .19218 .28309 .20124 .29586 .19634 .28756 .18723 Metetra
.664 .741 .908 r
.28756 .18723 .29586 .19634 .30869 .19142 .30043 .18227 Metetra
.664 .741 .908 r
.30043 .18227 .30869 .19142 .32159 .18647 .31337 .17728 Metetra
.664 .741 .908 r
.31337 .17728 .32159 .18647 .33455 .1815 .32636 .17226 Metetra
.664 .741 .908 r
.32636 .17226 .33455 .1815 .34757 .17651 .33942 .16722 Metetra
.664 .741 .908 r
.33942 .16722 .34757 .17651 .36065 .17149 .35255 .16216 Metetra
.664 .741 .908 r
.35255 .16216 .36065 .17149 .37381 .16645 .36574 .15707 Metetra
.664 .741 .908 r
.36574 .15707 .37381 .16645 .38702 .16138 .37899 .15196 Metetra
.664 .741 .908 r
.37899 .15196 .38702 .16138 .4003 .15629 .39232 .14682 Metetra
.664 .741 .908 r
.39232 .14682 .4003 .15629 .41365 .15117 .4057 .14165 Metetra
.664 .741 .908 r
.4057 .14165 .41365 .15117 .42706 .14602 .41916 .13646 Metetra
.664 .741 .908 r
.41916 .13646 .42706 .14602 .44054 .14085 .43268 .13124 Metetra
.664 .741 .908 r
.43268 .13124 .44054 .14085 .45409 .13566 .44627 .126 Metetra
.664 .741 .908 r
.44627 .126 .45409 .13566 .4677 .13044 .45993 .12073 Metetra
.664 .741 .908 r
.45993 .12073 .4677 .13044 .48139 .12519 .47366 .11543 Metetra
.664 .741 .908 r
.47366 .11543 .48139 .12519 .49514 .11991 .48746 .11011 Metetra
.664 .741 .908 r
.48746 .11011 .49514 .11991 .50896 .11461 .50132 .10476 Metetra
.664 .741 .908 r
.50132 .10476 .50896 .11461 .52286 .10929 .51526 .09938 Metetra
.664 .741 .908 r
.51526 .09938 .52286 .10929 .53682 .10393 .52927 .09397 Metetra
.664 .741 .908 r
.52927 .09397 .53682 .10393 .55085 .09855 .54335 .08854 Metetra
.664 .741 .908 r
.54335 .08854 .55085 .09855 .56496 .09314 .55751 .08308 Metetra
.664 .741 .908 r
.55751 .08308 .56496 .09314 .57914 .0877 .57173 .07759 Metetra
.664 .741 .908 r
.57173 .07759 .57914 .0877 .59339 .08224 .58603 .07207 Metetra
.664 .741 .908 r
.58603 .07207 .59339 .08224 .60771 .07674 .60041 .06653 Metetra
.664 .741 .908 r
.60041 .06653 .60771 .07674 .62211 .07122 .61485 .06095 Metetra
.664 .741 .908 r
.61485 .06095 .62211 .07122 .63658 .06567 .62938 .05535 Metetra
.664 .741 .908 r
.62938 .05535 .63658 .06567 .65113 .06009 .64397 .04972 Metetra
.664 .741 .908 r
.64397 .04972 .65113 .06009 .66575 .05448 .65865 .04405 Metetra
.664 .741 .908 r
.65865 .04405 .66575 .05448 .68045 .04885 .6734 .03836 Metetra
.664 .741 .908 r
.6734 .03836 .68045 .04885 .69523 .04318 .68823 .03264 Metetra
.664 .741 .908 r
.68823 .03264 .69523 .04318 .71008 .03748 .70314 .02689 Metetra
.664 .741 .908 r
.04542 .2688 .05443 .27718 .06619 .27265 .05721 .26422 Metetra
.664 .741 .908 r
.05721 .26422 .06619 .27265 .078 .26809 .06905 .25963 Metetra
.664 .741 .908 r
.06905 .25963 .078 .26809 .08986 .26352 .08094 .25501 Metetra
.664 .741 .908 r
.08094 .25501 .08986 .26352 .10178 .25892 .09289 .25037 Metetra
.664 .741 .908 r
.09289 .25037 .10178 .25892 .11376 .2543 .1049 .24571 Metetra
.664 .741 .908 r
.1049 .24571 .11376 .2543 .12579 .24965 .11697 .24102 Metetra
.664 .741 .908 r
.11697 .24102 .12579 .24965 .13788 .24499 .12909 .23632 Metetra
.664 .741 .908 r
.12909 .23632 .13788 .24499 .15003 .2403 .14127 .23159 Metetra
.664 .741 .908 r
.14127 .23159 .15003 .2403 .16223 .23559 .15351 .22684 Metetra
.664 .741 .908 r
.15351 .22684 .16223 .23559 .1745 .23086 .1658 .22206 Metetra
.664 .741 .908 r
.1658 .22206 .1745 .23086 .18682 .22611 .17816 .21727 Metetra
.664 .741 .908 r
.17816 .21727 .18682 .22611 .1992 .22133 .19057 .21245 Metetra
.664 .741 .908 r
.19057 .21245 .1992 .22133 .21164 .21653 .20305 .2076 Metetra
.664 .741 .908 r
.20305 .2076 .21164 .21653 .22414 .2117 .21559 .20274 Metetra
.664 .741 .908 r
.21559 .20274 .22414 .2117 .2367 .20686 .22818 .19785 Metetra
.664 .741 .908 r
.22818 .19785 .2367 .20686 .24933 .20199 .24084 .19293 Metetra
.664 .741 .908 r
.24084 .19293 .24933 .20199 .26201 .19709 .25356 .188 Metetra
.664 .741 .908 r
.25356 .188 .26201 .19709 .27476 .19218 .26634 .18303 Metetra
.664 .741 .908 r
.26634 .18303 .27476 .19218 .28756 .18723 .27919 .17805 Metetra
.664 .741 .908 r
.27919 .17805 .28756 .18723 .30043 .18227 .2921 .17304 Metetra
.664 .741 .908 r
.2921 .17304 .30043 .18227 .31337 .17728 .30507 .168 Metetra
.664 .741 .908 r
.30507 .168 .31337 .17728 .32636 .17226 .3181 .16294 Metetra
.664 .741 .908 r
.3181 .16294 .32636 .17226 .33942 .16722 .3312 .15786 Metetra
.664 .741 .908 r
.3312 .15786 .33942 .16722 .35255 .16216 .34437 .15274 Metetra
.664 .741 .908 r
.34437 .15274 .35255 .16216 .36574 .15707 .3576 .14761 Metetra
.664 .741 .908 r
.3576 .14761 .36574 .15707 .37899 .15196 .37089 .14245 Metetra
.664 .741 .908 r
.37089 .14245 .37899 .15196 .39232 .14682 .38426 .13726 Metetra
.664 .741 .908 r
.38426 .13726 .39232 .14682 .4057 .14165 .39769 .13205 Metetra
.664 .741 .908 r
.39769 .13205 .4057 .14165 .41916 .13646 .41118 .12681 Metetra
.664 .741 .908 r
.41118 .12681 .41916 .13646 .43268 .13124 .42475 .12154 Metetra
.664 .741 .908 r
.42475 .12154 .43268 .13124 .44627 .126 .43838 .11625 Metetra
.664 .741 .908 r
.43838 .11625 .44627 .126 .45993 .12073 .45209 .11093 Metetra
.664 .741 .908 r
.45209 .11093 .45993 .12073 .47366 .11543 .46586 .10558 Metetra
.664 .741 .908 r
.46586 .10558 .47366 .11543 .48746 .11011 .4797 .10021 Metetra
.664 .741 .908 r
.4797 .10021 .48746 .11011 .50132 .10476 .49362 .09481 Metetra
.664 .741 .908 r
.49362 .09481 .50132 .10476 .51526 .09938 .5076 .08938 Metetra
.664 .741 .908 r
.5076 .08938 .51526 .09938 .52927 .09397 .52166 .08392 Metetra
.664 .741 .908 r
.52166 .08392 .52927 .09397 .54335 .08854 .53578 .07844 Metetra
.664 .741 .908 r
.53578 .07844 .54335 .08854 .55751 .08308 .54998 .07292 Metetra
.664 .741 .908 r
.54998 .07292 .55751 .08308 .57173 .07759 .56426 .06738 Metetra
.664 .741 .908 r
.56426 .06738 .57173 .07759 .58603 .07207 .57861 .06181 Metetra
.664 .741 .908 r
.57861 .06181 .58603 .07207 .60041 .06653 .59303 .05621 Metetra
.664 .741 .908 r
.59303 .05621 .60041 .06653 .61485 .06095 .60753 .05058 Metetra
.664 .741 .908 r
.60753 .05058 .61485 .06095 .62938 .05535 .6221 .04493 Metetra
.664 .741 .908 r
.6221 .04493 .62938 .05535 .64397 .04972 .63675 .03924 Metetra
.664 .741 .908 r
.63675 .03924 .64397 .04972 .65865 .04405 .65148 .03352 Metetra
.664 .741 .908 r
.65148 .03352 .65865 .04405 .6734 .03836 .66628 .02778 Metetra
.664 .741 .908 r
.66628 .02778 .6734 .03836 .68823 .03264 .68117 .022 Metetra
.664 .741 .908 r
.68117 .022 .68823 .03264 .70314 .02689 .69613 .01619 Metetra
.664 .741 .908 r
.03634 .26033 .04542 .2688 .05721 .26422 .04815 .25572 Metetra
.664 .741 .908 r
.04815 .25572 .05721 .26422 .06905 .25963 .06002 .25108 Metetra
.664 .741 .908 r
.06002 .25108 .06905 .25963 .08094 .25501 .07194 .24643 Metetra
.664 .741 .908 r
.07194 .24643 .08094 .25501 .09289 .25037 .08393 .24175 Metetra
.664 .741 .908 r
.08393 .24175 .09289 .25037 .1049 .24571 .09597 .23704 Metetra
.664 .741 .908 r
.09597 .23704 .1049 .24571 .11697 .24102 .10806 .23232 Metetra
.664 .741 .908 r
.10806 .23232 .11697 .24102 .12909 .23632 .12022 .22757 Metetra
.664 .741 .908 r
.12022 .22757 .12909 .23632 .14127 .23159 .13243 .2228 Metetra
.664 .741 .908 r
.13243 .2228 .14127 .23159 .15351 .22684 .1447 .21801 Metetra
.664 .741 .908 r
.1447 .21801 .15351 .22684 .1658 .22206 .15703 .21319 Metetra
.664 .741 .908 r
.15703 .21319 .1658 .22206 .17816 .21727 .16942 .20835 Metetra
.664 .741 .908 r
.16942 .20835 .17816 .21727 .19057 .21245 .18187 .20349 Metetra
.664 .741 .908 r
.18187 .20349 .19057 .21245 .20305 .2076 .19438 .1986 Metetra
.664 .741 .908 r
.19438 .1986 .20305 .2076 .21559 .20274 .20695 .19369 Metetra
.664 .741 .908 r
.20695 .19369 .21559 .20274 .22818 .19785 .21959 .18876 Metetra
.664 .741 .908 r
.21959 .18876 .22818 .19785 .24084 .19293 .23228 .1838 Metetra
.664 .741 .908 r
.23228 .1838 .24084 .19293 .25356 .188 .24504 .17882 Metetra
.664 .741 .908 r
.24504 .17882 .25356 .188 .26634 .18303 .25786 .17381 Metetra
.664 .741 .908 r
.25786 .17381 .26634 .18303 .27919 .17805 .27074 .16878 Metetra
.664 .741 .908 r
.27074 .16878 .27919 .17805 .2921 .17304 .28368 .16372 Metetra
.664 .741 .908 r
.28368 .16372 .2921 .17304 .30507 .168 .29669 .15864 Metetra
.664 .741 .908 r
.29669 .15864 .30507 .168 .3181 .16294 .30977 .15353 Metetra
.664 .741 .908 r
.30977 .15353 .3181 .16294 .3312 .15786 .32291 .1484 Metetra
.664 .741 .908 r
.32291 .1484 .3312 .15786 .34437 .15274 .33611 .14324 Metetra
.664 .741 .908 r
.33611 .14324 .34437 .15274 .3576 .14761 .34938 .13806 Metetra
.664 .741 .908 r
.34938 .13806 .3576 .14761 .37089 .14245 .36272 .13285 Metetra
.664 .741 .908 r
.36272 .13285 .37089 .14245 .38426 .13726 .37612 .12761 Metetra
.664 .741 .908 r
.37612 .12761 .38426 .13726 .39769 .13205 .3896 .12235 Metetra
.664 .741 .908 r
.3896 .12235 .39769 .13205 .41118 .12681 .40314 .11706 Metetra
.664 .741 .908 r
.40314 .11706 .41118 .12681 .42475 .12154 .41674 .11175 Metetra
.664 .741 .908 r
.41674 .11175 .42475 .12154 .43838 .11625 .43042 .10641 Metetra
.664 .741 .908 r
.43042 .10641 .43838 .11625 .45209 .11093 .44417 .10104 Metetra
.664 .741 .908 r
.44417 .10104 .45209 .11093 .46586 .10558 .45799 .09564 Metetra
.664 .741 .908 r
.45799 .09564 .46586 .10558 .4797 .10021 .47187 .09021 Metetra
.664 .741 .908 r
.47187 .09021 .4797 .10021 .49362 .09481 .48583 .08476 Metetra
.664 .741 .908 r
.48583 .08476 .49362 .09481 .5076 .08938 .49986 .07928 Metetra
.664 .741 .908 r
.49986 .07928 .5076 .08938 .52166 .08392 .51397 .07377 Metetra
.664 .741 .908 r
.51397 .07377 .52166 .08392 .53578 .07844 .52814 .06824 Metetra
.664 .741 .908 r
.52814 .06824 .53578 .07844 .54998 .07292 .54239 .06267 Metetra
.664 .741 .908 r
.54239 .06267 .54998 .07292 .56426 .06738 .55671 .05708 Metetra
.664 .741 .908 r
.55671 .05708 .56426 .06738 .57861 .06181 .57111 .05145 Metetra
.664 .741 .908 r
.57111 .05145 .57861 .06181 .59303 .05621 .58558 .0458 Metetra
.664 .741 .908 r
.58558 .0458 .59303 .05621 .60753 .05058 .60013 .04012 Metetra
.664 .741 .908 r
.60013 .04012 .60753 .05058 .6221 .04493 .61476 .0344 Metetra
.664 .741 .908 r
.61476 .0344 .6221 .04493 .63675 .03924 .62946 .02866 Metetra
.664 .741 .908 r
.62946 .02866 .63675 .03924 .65148 .03352 .64424 .02289 Metetra
.664 .741 .908 r
.64424 .02289 .65148 .03352 .66628 .02778 .6591 .01709 Metetra
.664 .741 .908 r
.6591 .01709 .66628 .02778 .68117 .022 .67403 .01125 Metetra
.664 .741 .908 r
.67403 .01125 .68117 .022 .69613 .01619 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(10)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(20)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(30)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(40)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(50)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06033 .24606 m
.06319 .24877 L
s
.08372 .23691 m
.08655 .23964 L
s
.10732 .22766 m
.11013 .23042 L
s
.13115 .21833 m
.13394 .22111 L
s
.17948 .19941 m
.18222 .20223 L
s
.20399 .18981 m
.2067 .19266 L
s
.22873 .18012 m
.23142 .183 L
s
.25371 .17034 m
.25638 .17324 L
s
.3044 .15049 m
.30701 .15344 L
s
.33011 .14043 m
.3327 .14339 L
s
.35608 .13026 m
.35864 .13325 L
s
.3823 .11999 m
.38483 .12301 L
s
.43553 .09915 m
.43799 .10222 L
s
.46254 .08857 m
.46497 .09167 L
s
.48982 .07789 m
.49222 .08101 L
s
.51738 .0671 m
.51975 .07024 L
s
.57333 .04519 m
.57563 .04838 L
s
.60174 .03407 m
.60401 .03728 L
s
.63044 .02283 m
.63267 .02607 L
s
.65944 .01147 m
.66163 .01474 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[50]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00a03oool3o`0000@0oooo0_l0001C0?ooo`00``3oool01Ol00000oooo
0?ooo`3ooooo00000080oooo00Co00000?ooo`3ooooo0000DP3oool00<L0oooo00Co00000?ooo`3o
oooo00000P3oool00ol00000oooo0?ooo`1@0?ooo`00a`3oool01?l00000oooo0?ooool000020?oo
o`03o`00003oool0oooo0500oooo00330?ooo`Co00000`3oool01?l00000oooo0?ooool0001B0?oo
o`00``3oool00ol00000oooo0?ooo`040?ooo`04o`00003oool0ooooo`000580oooo00330?ooo`Go
00000`3oool2o`0005<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003>0?ooo`0300000?l00000oooo04l0oooo003;0?ooo`<0000000<0ooooo`00003oool0
C`3oool00<T0oooo0P0000020?ooo`;o000000<00000o`00003oool0CP3oool00<H0oooo00@00000
o`0000000000oooo0ol000020:Vmj00300000?l00000000004h0oooo002P0?ooo`?o00000`3oool2
o`0001`0oooo0P0000020?ooo`;o000000<0ZKgXo`00002Y_NP00P2Y_NP00`00003o00000000001>
0?ooo`00X@3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00?o00000?ooo`3oool05P3oool3
000000040?ooool0003o0000o`0000@0ZKgX00Oo00000:Vmj?l0000000000:Vmj?l00000000004d0
oooo002N0?ooo`Go00000P3oool01?l00000oooo0?ooool0000F0?ooo`0300000?l00000oooo00?o
00000`2Y_NP00ol00000ZKgX0:Vmj003o`0000060:Vmj0000000ZKgX0:Vmj?l000000000C03oool0
09h0oooo00Co00000?ooo`3ooooo00000`3oool01?l00000oooo0?ooool0000C0?ooo`<0000000D0
ooooo`000?l00000ZKgXo`0000040:Vmj0?o00000P2Y_NP01?l00000ZKgX0000002Y_NP2o`000003
0000003oool0oooo04X0oooo002O0?ooo`03o`00003ooooo000000<0oooo00Co00000?ooo`3ooooo
0000403oool300000080oooo0ol000030:Vmj006o`00002Y_NSo0000o`00002Y_NSo0000102Y_NP0
1ol000000000o`00002Y_NSo00000?ooo`000000B`3oool00:00oooo0_l000030?ooo`04o`00003o
ool0ooooo`0000h0oooo00<00000o`00003oool01?l000020:Vmj003o`00002Y_NP0ZKgX00?o0000
102Y_NP00ol00000ZKgX0:Vmj002o`0000070000002Y_NP0ZKgX0:Vmj?l00000oooo0000001:0?oo
o`00X@3oool00ol00000oooo0?ooo`020?ooo`;o0000303oool3000000?o00000P2Y_NP01?l00000
ZKgX0:Vmj02Y_NP3o`0000<0ZKgX00?o00000:Vmj02Y_NP01?l000020:Vmj0030000002Y_NP0ZKgX
00?o000000<000000?ooo`3oool0B03oool00;80oooo0P0000001@3ooooo0000o`00002Y_NSo0000
00@0ZKgX00Go00000:Vmj?l00000ZKgXo`0000040:Vmj0?o00000P2Y_NP01ol00000ZKgX0:Vmj02Y
_NSo000000000?l000000P2Y_NP00ol00000oooo000000190?ooo`00[`3oool200000004o`00003o
oooo0000o`0000@0ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj006o`00002Y_NSo0000o`00002Y
_NSo0000102Y_NP01Ol00000ZKgXo`00002Y_NP0000000@0ZKgX00?o00000?ooo`000000B03oool0
0:d0oooo0P0000001P3ooooo0000o`000?l00000ZKgXo`0000@0ZKgX0ol000030:Vmj003o`00002Y
_NP0ZKgX00;o0000102Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00@00000o`00002Y_NP0ZKgX
0ol000000`000000oooo0?ooo`160?ooo`00ZP3oool3000000050?ooool0003o00000:Vmj?l00000
0`2Y_NP01_l00000ZKgXo`000?l00000ZKgXo`0000@0ZKgX0ol000000`2Y_NSo00000:Vmj0030:Vm
j0?o00000P2Y_NP01?l00000ZKgX0:Vmj0000003o`0000<0ZKgX00?o00000000003oool0AP3oool0
0:P0oooo0P000004o`0000@0ZKgX00?o00000:Vmj02Y_NP00_l000040:Vmj006o`00002Y_NSo0000
o`00002Y_NSo00000`2Y_NP01_l00000ZKgXo`000?l00000ZKgXo`0000<0ZKgX0ol000000`000000
ZKgXo`0000040:Vmj003o`0000000000oooo04H0oooo002U0?ooo`<000001?l000020:Vmj003o`00
002Y_NP0ZKgX00Co00000P2Y_NP00ol00000ZKgX0:Vmj003o`0000@0ZKgX00?o00000:Vmj?l00000
0_l000040:Vmj007o`00002Y_NSo00000:Vmj?l00000ZKgX000000020:Vmj007o`00002Y_NSo0000
o`00002Y_NSo00000000000=0?ooo`?o0000103oool2o`000300oooo002S0?ooo`07o`0000000000
oooo0?ooool00000ZKgXo`0000040:Vmj0?o00000P2Y_NP01?l00000ZKgX0:Vmj02Y_NP3o`0000<0
ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000
00000:Vmj003o`0000@0ZKgX00?o00000000003oool0303oool00ol00000oooo0?ooo`020?ooo`04
o`00003oool0ooooo`0002l0oooo001k0?ooo`?o0000103oool2o`0001`0oooo0`000004o`0000<0
ZKgX00Ko00000:Vmj?l0003o00000:Vmj?l000040:Vmj0?o000000<0ZKgXo`00002Y_NP00`2Y_NP3
o`0000030:Vmj?l00000ZKgX00<0ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00;o000000<00000
o`00002Y_NP00P2Y_NP00ol00000ZKgX0:Vmj002o`0000030000003oool0oooo00<0oooo1Ol00003
0?ooo`03o`00003oool0oooo0080oooo00Co00000?ooo`3ooooo0000;`3oool007X0oooo00Go0000
0?ooo`3oool0ooooo`0000020?ooo`04o`00003oool0ooooo`0001T0oooo0P000000103ooooo0000
o`000?l000030:Vmj003o`00002Y_NP0ZKgX00;o0000102Y_NP00ol00000ZKgX0:Vmj002o`0000@0
ZKgX00Ko00000:Vmj?l0003o00000:Vmj?l000030:Vmj006o`00002Y_NSo0000o`00002Y_NSo0000
0`2Y_NP3o`000080ZKgX00<000000:Vmj02Y_NP00P2Y_NP3o`000080ZKgX00?o00000000003oool0
2`3oool00ol00000oooo0?ooo`020?ooo`04o`00003oool0ooooo`0002l0oooo001n0?ooo`04o`00
003oool0ooooo`000080oooo00?o00000?ooo`3oool0503oool01000003o00000000003oool2o`00
00030:Vmj?l00000ZKgX00<0ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y_NP00ol0
0000ZKgX0:Vmj003o`0000@0ZKgX00?o00000:Vmj02Y_NP00_l000040:Vmj005o`00002Y_NSo0000
0:Vmj?l000000`2Y_NP00`00003o00000:Vmj002o`0000030:Vmj?l00000ZKgX0080ZKgX0_l00000
0`000000oooo0?ooo`090?ooo`03o`00003oool0oooo0080oooo00Co00000?ooo`3ooooo0000;`3o
ool007`0oooo0_l000030?ooo`04o`00003oool0ooooo`0001@0oooo0P000000103ooooo0000o`00
0?l000040:Vmj006o`00002Y_NSo0000o`00002Y_NSo00000`2Y_NP3o`000080ZKgX00Co00000:Vm
j02Y_NP0ZKgX0ol000030:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y_NP00ol00000ZKgX0:Vmj003
o`0000<0ZKgX00Co00000:Vmj02Y_NP000000_l000040:Vmj0?o000000<0ZKgXo`00000000002P3o
ool2o`0000@0oooo00Co00000?ooo`3ooooo0000;`3oool007h0oooo00Co00000?ooo`3ooooo0000
0P3oool00ol00000oooo0?ooo`0?0?ooo`<000001?l000020:Vmj003o`00002Y_NP0ZKgX00?o0000
102Y_NP3o`0000030:Vmj?l00000ZKgX00<0ZKgX00Go00000:Vmj?l00000ZKgXo`0000040:Vmj0?o
00000P2Y_NP01?l00000ZKgX0:Vmj02Y_NP3o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000001000
0000ZKgX0:Vmj?l000020:Vmj0;o0000102Y_NP00ol0000000000?ooo`090?ooo`03o`00003oool0
oooo00<0oooo0_l0000`0?ooo`00NP3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co0000
0?ooo`3ooooo00003`3oool00`00003o0000o`000002o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol0
00030:Vmj003o`00002Y_NP0ZKgX00;o0000102Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00Ko
00000:Vmj?l0003o00000:Vmj?l000040:Vmj0?o000000<0ZKgXo`00002Y_NP00`2Y_NP3o`000004
0:Vmj?l00000ZKgX00000080ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00?o000000<000000?oo
o`3oool0?`3oool007/0oooo0ol000040?ooo`;o00003@3oool3000000040?ooool00000ZKgXo`00
00@0ZKgX0ol000000`2Y_NSo00000:Vmj0030:Vmj0?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`00
00<0ZKgX00?o00000:Vmj02Y_NP00_l000040:Vmj003o`00002Y_NP0ZKgX00;o0000102Y_NP01_l0
0000ZKgXo`000?l00000ZKgXo`0000<0ZKgX00Ko000000000?l0003o00000:Vmj?l000030:Vmj0?o
00000P2Y_NP00ol0000000000?ooo`100?ooo`00SP3oool3000000040?ooool0003o0000o`0000<0
ZKgX00Ko00000:Vmj?l0003o00000:Vmj?l000030:Vmj006o`00002Y_NSo0000o`00002Y_NSo0000
0`2Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP00P2Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP0
1?l000020:Vmj003o`00002Y_NP0ZKgX00?o0000102Y_NP01Ol00000ZKgXo`000?l00000000000@0
ZKgX0ol000000`2Y_NSo00000:Vmj0030:Vmj003o`0000000000oooo03l0oooo002<0?ooo`800000
1?l000030:Vmj003o`00002Y_NP0ZKgX00;o0000102Y_NP00ol00000ZKgX0:Vmj002o`0000@0ZKgX
00Go00000:Vmj?l00000ZKgXo`0000040:Vmj006o`00002Y_NSo0000o`00002Y_NSo00000`2Y_NP3
o`000080ZKgX00Co00000:Vmj02Y_NP0ZKgX0ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y
_NP01000003o00000:Vmj02Y_NP2o`0000@0ZKgX00?o00000:Vmj02Y_NP00ol000000`000000oooo
0?ooo`0m0?ooo`00R@3oool3000000?o000000<0ZKgXo`00002Y_NP00`2Y_NP3o`000080ZKgX00?o
00000:Vmj02Y_NP01?l000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vm
j003o`0000@0ZKgX0ol000000`2Y_NSo00000:Vmj0030:Vmj0?o000000<0ZKgXo`00002Y_NP00`2Y
_NP3o`0000030:Vmj?l00000ZKgX0080ZKgX00@00000o`000?l0003o00000P2Y_NP00ol00000ZKgX
0:Vmj004o`000080ZKgX00?o00000000003oool0?P3oool008L0oooo00?o00000000003oool00_l0
00000`2Y_NSo00000:Vmj0020:Vmj006o`00002Y_NSo0000o`00002Y_NSo00000`2Y_NP3o`000080
ZKgX00Co00000:Vmj02Y_NP0ZKgX0ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol0
0000ZKgX0:Vmj002o`0000@0ZKgX00?o00000:Vmj02Y_NP00_l000040:Vmj006o`00002Y_NSo0000
o`00002Y_NSo00000`2Y_NP01_l00000ZKgXo`0000000000ZKgXo`0000<0ZKgX0ol000020:Vmj003
o`00002Y_NP0ZKgX00?o000000<000000?ooo`3oool0?03oool008@0oooo0`000003o`0000@0ZKgX
00?o00000:Vmj02Y_NP00_l000040:Vmj005o`00002Y_NSo00000:Vmj?l00000102Y_NP01Ol00000
ZKgXo`00002Y_NSo000000@0ZKgX0ol000000`2Y_NSo00000:Vmj0030:Vmj0?o00000P2Y_NP00ol0
0000ZKgX0:Vmj004o`000080ZKgX00?o00000:Vmj02Y_NP00ol000040:Vmj003o`00002Y_NSo0000
00;o000000@0ZKgX0000002Y_NP0ZKgX0ol000000`2Y_NSo00000:Vmj0020:Vmj0?o00000P2Y_NP0
0ol00000oooo0000000m0?ooo`00PP3oool2000000030?ooool0003o000000;o000000@0ZKgXo`00
002Y_NP0ZKgX1?l000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj003
o`0000<0ZKgX00Ko00000:Vmj?l0003o00000:Vmj?l000030:Vmj006o`00002Y_NSo0000o`00002Y
_NSo00000`2Y_NP3o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0ZKgX
00?o00000`2Y_NP00ol0000000000:Vmj002o`0000@0ZKgX00Go00000:Vmj?l00000ZKgXo`000004
0:Vmj003o`0000000000oooo03`0oooo001H0?ooo`Go00000`3oool2o`0001d0oooo00@00000o`00
00000000oooo0_l000000`2Y_NSo00000:Vmj0020:Vmj0?o00000`2Y_NP00ol00000ZKgX0:Vmj003
o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0ZKgX00;o0000102Y_NP0
0ol00000ZKgX0:Vmj002o`0000@0ZKgX00Go00000:Vmj?l00000ZKgXo`0000040:Vmj0?o000000<0
ZKgXo`00002Y_NP00`2Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP00_l000001@00003o00000:Vm
j02Y_NSo00000080ZKgX0ol000030:Vmj003o`00002Y_NP0ZKgX00?o000000<000000?ooo`3oool0
>P3oool005T0oooo00Co00000?ooo`3ooooo00000P3oool01?l00000oooo0?ooool0000J0?ooo`80
00000P3oool2o`0000@0ZKgX00Go00000:Vmj?l00000ZKgXo`0000040:Vmj0?o000000<0ZKgXo`00
002Y_NP00`2Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP01?l000020:Vmj003o`00002Y_NP0ZKgX
00Co00000P2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00Ko00000:Vmj?l0003o00000:Vmj?l0
00030:Vmj006o`00002Y_NSo0000o`00002Y_NSo00000`2Y_NP3o`000080ZKgX00Co00000000002Y
_NP0ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y_NP00ol00000oooo0000000k0?oo
o`00FP3oool00ol00000oooo0?ooo`020?ooo`04o`00003oool0ooooo`0001L0oooo0`000004o`00
0080ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj006o`00002Y_NSo0000o`00002Y_NSo00000`2Y
_NP01_l00000ZKgXo`000?l00000ZKgXo`0000<0ZKgX0ol000020:Vmj004o`00002Y_NP0ZKgX0:Vm
j0?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000040:Vm
j003o`00002Y_NSo000000;o0000102Y_NP3o`0000030:Vmj?l00000ZKgX00<0ZKgX00D00000o`00
0?l00000ZKgXo`0000030:Vmj0?o00000`2Y_NP00ol00000ZKgX0:Vmj002o`0000030000003oool0
oooo03T0oooo001K0?ooo`05o`00003oool0oooo0?ooool000000P3oool00ol00000oooo0?ooo`0C
0?ooo`8000000ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj002
o`0000@0ZKgX00?o00000:Vmj02Y_NP00_l000040:Vmj005o`00002Y_NSo00000:Vmj?l00000102Y
_NP01Ol00000ZKgXo`00002Y_NSo000000@0ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00?o0000
0`2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00?o00000:Vmj02Y_NP00_l000040:Vmj005o`00
002Y_NP0ZKgXo`0000000000102Y_NP01Ol00000ZKgXo`00002Y_NSo000000@0ZKgX0ol00000102Y
^nKo00000?ooo`00000j0?ooo`00F03oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co0000
0?ooo`3ooooo00004P3oool3000000040?ooool00000ZKgXo`0000@0ZKgX0ol000000`2Y_NSo0000
0:Vmj0030:Vmj0?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZKgX00?o00000:Vmj02Y_NP0
0ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP01_l00000ZKgXo`000?l00000ZKgXo`00
00<0ZKgX0ol000000`2Y_NSo00000:Vmj0030:Vmj0?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`00
0080ZKgX00?o00000:Vmj02Y_NP01?l000000`2Y_NP00000o`0000020:Vmj0?o00000`2Y_NP01_l0
0000ZKgXo`000?l00000ZK_Vo`0000<0ZK_V00?o00000?ooo`000000>@3oool005P0oooo00Go0000
0?ooo`3oool0ooooo`0000020?ooo`04o`00003oool0ooooo`000100oooo00?o00000000003oool0
0ol000030:Vmj006o`00002Y_NSo0000o`00002Y_NSo00000`2Y_NP01_l00000ZKgXo`000?l00000
ZKgXo`0000<0ZKgX0ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vm
j003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000040:Vmj0?o000000<0ZKgXo`00002Y_NP00P2Y
_NP01_l00000ZKgXo`000?l00000ZKgXo`0000<0ZKgX0ol000020:Vmj004o`00002Y_NP0ZKgX0:Vm
j0?o00000`2Y_NP00ol00000ZKgX00000003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000040:Vk
iP03o`00002Y^nKo000000;o000000<000000?ooo`3oool0=`3oool005T0oooo0ol000040?ooo`;o
00003P3oool3000000?o00000`2Y_NP00ol00000ZKgX0:Vmj002o`0000@0ZKgX00?o00000:Vmj02Y
_NP00_l000040:Vmj005o`00002Y_NSo00000:Vmj?l00000102Y_NP3o`0000030:Vmj?l00000ZKgX
00<0ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj002o`00
00@0ZKgX00?o00000:Vmj02Y_NP00_l000040:Vmj005o`00002Y_NSo00000:Vmj?l00000102Y_NP0
1Ol00000ZKgXo`00002Y_NSo000000@0ZKgX0_l0000010000000ZKgX0:Vmj?l000020:Vmj0?o0000
0`2Y^nH00ol00000ZK_V0:VkiP03o`000080YJ;B00?o00000?ooo`000000>03oool006h0oooo0P00
0003o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y
_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00Ko00000:Vmj?l0003o00000:Vmj?l000030:Vmj006
o`00002Y_NSo0000o`00002Y_NSo00000`2Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP01?l00002
0:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00?o0000
0:Vmj02Y_NP00ol000030:Vmj007o`00002Y_NSo0000o`00002Y_NSo0000000000020:Vmj0?o0000
00<0ZK_Vo`00002Y^nH00`2Y^nH3o`0000030:FRd_l00000YJ;B00<0YJ;B00?o00000?ooo`000000
=`3oool006/0oooo00L00000o`0000000000ooooo`00002Y_NSo000000@0ZKgX0ol000020:Vmj003
o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00?o00000:Vmj02Y
_NP00_l000040:Vmj003o`00002Y_NP0ZKgX00;o0000102Y_NP3o`0000030:Vmj?l00000ZKgX0080
ZKgX0ol000020:Vmj004o`00002Y_NP0ZKgX0:Vmj0?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`00
0080ZKgX00?o00000:Vmj02Y_NP01?l000020:Vmj003o`00002Y_NP0ZKgX00?o0000102Y_NP01@00
003o0000o`00002Y^nKo000000<0ZK_V00Ko00000:Vki_l0003o00000:FRd_l000030:FRdP04o`00
002UX]80YJ;B0:FRdP;o000000<000000?ooo`3oool0=@3oool006T0oooo0P000000103ooooo0000
o`000?l000030:Vmj006o`00002Y_NSo0000o`00002Y_NSo00000`2Y_NP3o`0000030:Vmj?l00000
ZKgX00<0ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y_NP00ol00000ZKgX0:Vmj004
o`000080ZKgX00?o00000:Vmj02Y_NP00_l000040:Vmj005o`00002Y_NSo00000:Vmj?l00000102Y
_NP01Ol00000ZKgXo`00002Y_NSo000000@0ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00?o0000
0`2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00Go00000:Vmj02Y_NSo0000000000040:VkiP03
o`00002Y^nH0ZK_V00;o0000102UX]801Ol00000YJ;B0:FRd_l00000YJ;B00;o000000@0UW2Vo`00
003oool00000=P3oool006H0oooo00?o00000000000000000ol000030:Vmj003o`00002Y_NP0ZKgX
00;o0000102Y_NP01Ol00000ZKgXo`00002Y_NSo000000<0ZKgX00Ko00000:Vmj?l0003o00000:Vm
j?l000030:Vmj0?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00?o00000:Vmj02Y_NP0
0ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX
00Ko00000:Vmj?l0003o00000:Vmj?l000030:Vmj0?o000000<0ZKgXo`00002Y_NP00`2Y_NP3o`00
0080ZKgX00?o00000:Vmj02Y_NP01?l000000`2Y^nH00000o`0000020:VkiPCo000000<0YJ;Bo`00
002UX]800`2UX]800ol00000YJ;B0:FRdP02o`0000<0UW2V00Co00000?ooo`3oool00000=@3oool0
06<0oooo0`000003o`000080ZKgX00?o00000:Vmj02Y_NP01?l000020:Vmj003o`00002Y_NP0ZKgX
00?o00000`2Y_NP00ol00000ZKgX0:Vmj002o`0000@0ZKgX00Go00000:Vmj?l00000ZKgXo`000004
0:Vmj0?o000000<0ZKgXo`00002Y_NP00`2Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP00ol00003
0:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj002o`0000@0ZKgX0ol00000
0`2Y_NSo00000:Vmj0020:Vmj006o`00002Y_NSo0000o`00002Y_NSo00000`2Y_NP3o`000080ZK_V
00Co00000:VkiP2Y^nH000000ol000020:FRdP05o`00002UX]80YJ;B0:FRd_l000000P2UX]84o`00
000309I`Y_l00000UW2V00<0UW2V00?o00000?ooo`000000=@3oool003T0oooo0ol000040?ooo`;o
00007`3oool2000000?o000000<0ZKgXo`00002Y_NP00P2Y_NP3o`0000<0ZKgX00?o00000:Vmj02Y
_NP00ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`0000<0
ZKgX00Ko00000:Vmj?l0003o00000:Vmj?l000030:Vmj006o`00002Y_NSo0000o`00002Y_NSo0000
0`2Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP01?l000020:Vmj003o`00002Y_NP0ZKgX00Co0000
0P2Y_NP00ol00000ZKgX0:Vmj002o`0000@0ZKgX00?o00000:Vmj02Y_NP00_l000040:Vmj005o`00
002Y_NSo00000:Vki_l00000102Y^nH2o`0000030000002UX];o000000<0YJ;B00Co00000:FRdP2U
X]80YJ;B0ol0000209I`YP04o`00002FL:H0UW2Vo`0000@0UW2V00Co00000?ooo`3oool00000=03o
ool003X0oooo00?o00000?ooo`3oool00P3oool01?l00000oooo0?ooool0000K0?ooo`0300000?l0
0000000000;o000000<0ZKgXo`00002Y_NP00P2Y_NP00ol00000ZKgXo`0000020:Vmj004o`00002Y
_NP0ZKgX0:Vmj0?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZKgX00?o00000:Vmj02Y_NP0
0ol000030:Vmj003o`00002Y_NP0ZKgX00;o0000102Y_NP00ol00000ZKgX0:Vmj002o`0000@0ZKgX
0ol000000`2Y_NSo00000:Vmj0020:Vmj0?o00000P2Y_NP01?l00000ZKgX0:Vmj02Y_NP3o`000080
ZKgX00?o00000:Vmj02Y_NP01?l000020:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y_NP00ol00000
ZKgX0:Vmj003o`0000<0ZK_V00?o00000:VkiP2Y^nH00_l000001@2UX]8000000:FRdP2UX];o0000
00<0YJ;B0ol000000`2FL:Ko000009I`YP0209I`YP05o`00002FL:H0UW2V09I`Y_l000000`2FL:H0
1?l00000oooo0?ooo`00000d0?ooo`00>P3oool00ol00000oooo0?ooo`020?ooo`04o`00003oool0
ooooo`0001T0oooo0P000000103ooooo0000o`000?l000030:Vmj003o`00002Y_NP0ZKgX00;o0000
102Y_NP01Ol00000ZKgXo`00002Y_NSo000000<0ZKgX0ol000020:Vmj004o`00002Y_NP0ZKgX0:Vm
j0?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZKgX00?o00000:Vmj02Y_NP01?l000020:Vm
j003o`00002Y_NP0ZKgX00;o0000102Y_NP01Ol00000ZKgXo`00002Y_NSo000000@0ZKgX00Go0000
0:Vmj?l00000ZKgXo`0000030:Vmj0?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o
00000:Vmj02Y_NP01?l000020:VkiP03o`00002Y^nH0ZK_V00Co000000@0YJ;Bo`00002UX]800000
0P2UX]800ol00000YJ;B0:FRdP02o`0000<0UW2V00?o000009I`YP2FL:H00P2FL:H01?l00000UW2V
09I`Y_l0000309I`YP05o`00003oool0oooo0?ooo`000000<`3oool003X0oooo00?o00000?ooo`3o
ool00P3oool01?l00000oooo0?ooool0000F0?ooo`03o`0000000000000000?o00000`2Y_NP00ol0
0000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj005o`00002Y_NSo0000
0:Vmj?l00000102Y_NP01Ol00000ZKgXo`00002Y_NSo000000<0ZKgX0ol000030:Vmj003o`00002Y
_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol0
00030:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP01Ol00000ZKgXo`00002Y_NSo000000@0ZKgX
0ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y^nH00ol00000ZK_V0:VkiP03o`000080YJ;B
00Oo00000:FRdP2UX]80YJ;Bo`0000000000YJ;B00Co000000<0UW2Vo`00002FL:H00`2FL:H01Ol0
0000UW2V09I`YP2FL:Ko00000080UW2V00Go000009I`YP2FL:H0UW2Vo`0000040?ooo`030000003o
ool0oooo0300oooo000j0?ooo`03o`00003oool0oooo0080oooo00Co00000?ooo`3ooooo0000503o
ool2000000?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZKgX00?o00000:Vmj02Y_NP00ol0
00030:Vmj003o`00002Y_NP0ZKgX00;o00000`2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00Go
00000:Vmj?l00000ZKgXo`0000040:Vmj0?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZKgX
00?o00000:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX
0:Vmj003o`0000<0ZKgX00Ko00000:Vmj?l0003o00000:Vmj?l000030:Vmj0?o000000<0ZK_Vo`00
002Y^nH00`2Y^nH3o`0000030:FRd_l00000YJ;B00<0YJ;B00Ko00000:FRdP2UX];o000000000?l0
000209I`YP04o`00002FL:H0UW2Vo`0000@0UW2V00Go000009I`YP2FL:H0UW2Vo`00000209I`YP03
o`00002FL:H0UW2V0080UW2V00Go00000?ooo`3ooooo00000000000b0?ooo`00>@3oool2o`0000@0
oooo00Co00000?ooo`3ooooo00004@3oool3000000040?ooool00000ZKgXo`0000<0ZKgX0ol00003
0:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZKgX00?o0000
0:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0ZKgX00;o00000`2Y_NP01_l00000ZKgXo`000?l0
0000ZKgXo`0000<0ZKgX0ol000020:Vmj004o`00002Y_NP0ZKgX0:Vmj0?o00000P2Y_NP00ol00000
ZKgX0:Vmj004o`000080ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0ZKgX00;o
0000102Y_NP3o`0000030:Vki_l00000ZK_V0080ZK_V00Ko00000:Vki_l0003o00000:FRd_l00003
0:FRdP04o`00002UX]80YJ;B0:FRdP?o000000<0UW2V0000002FL:H00P2FL:H01Ol00000UW2V09I`
YP2FL:Ko000000<0UW2V00Go000009I`YP2FL:H0UW2Vo`00000209I`YP03o`00002FL:H0UW2V0080
UW2V00?o00000?ooo`3oool00P3oool00`000000oooo0?ooo`0_0?ooo`00>P3oool00ol00000oooo
0?ooo`030?ooo`;o0000403oool00`00003o00000?ooo`03o`0000<0ZKgX00Go00000:Vmj?l00000
ZKgXo`0000040:Vmj0?o000000<0ZKgXo`00002Y_NP00P2Y_NP3o`0000<0ZKgX00?o00000:Vmj02Y
_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y_NP00ol00000ZKgX0:Vmj002o`0000@0
ZKgX00Go00000:Vmj?l00000ZKgXo`0000040:Vmj005o`00002Y_NSo00000:Vmj?l000000`2Y_NP3
o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y_NP0
0ol00000ZKgX0:Vmj002o`0000@0ZK_V00?o00000:VkiP2Y^nH00_l000030:FRdP06o`00002UX]80
YJ;B0:FRd_l00000YJ;B0_l000001@2FL:Ko000009I`YP2FL:H0000000@0UW2V00Co000009I`YP2F
L:Ko00000`2FL:H01Ol00000UW2V09I`YP2FL:Ko000000<0UW2V00?o000009I`YP2FL:H00_l00005
0?ooo`030000003oool0oooo02h0oooo001?0?ooo`<000000ol000030:Vmj003o`00002Y_NP0ZKgX
00;o00000`2Y_NP01_l00000ZKgXo`000?l00000ZKgXo`0000<0ZKgX00Go00000:Vmj?l00000ZKgX
o`0000040:Vmj0?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00?o00000:Vmj02Y_NP0
0ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX
00Go00000:Vmj?l00000ZKgXo`0000040:Vmj0?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`0000<0
ZKgX00?o00000:Vmj02Y_NP00ol000020:VkiP03o`00002Y^nH0ZK_V00Co000000<0YJ;Bo`00002U
X]800`2UX]800ol00000YJ;Bo`000002o`0000<0UW2V00Go000009I`YP2FL:H00000o`00000309I`
YP04o`00002FL:H0UW2Vo`0000<0UW2V00?o000009I`YP2FL:H00P2FL:H00ol00000UW2V09I`YP03
o`00000308mOUOl00000oooo00@0oooo00<000000?ooo`3oool0;P3oool004`0oooo00?o00000000
000000000ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`00
00<0ZKgX00?o00000:Vmj02Y_NP00_l000030:Vmj006o`00002Y_NSo0000o`00002Y_NSo00000`2Y
_NP3o`000080ZKgX00?o00000:Vmj02Y_NP01?l000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y
_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj006o`00002Y
_NSo0000o`00002Y_NSo00000`2Y_NP3o`0000030:Vmj?l00000ZKgX00<0ZKgX0ol000020:VkiP03
o`00002Y^nH0ZK_V00?o00000P2UX]801Ol00000YJ;B0:FRdP2UX];o00000080YJ;B0ol0000209I`
YP03o`00002FL:H0UW2V0080UW2V00Co000009I`YP00003o00000`2FL:H01?l00000UW2V09I`Y_l0
000409I`YP06o`00002FL:H0UW2V09I`Y_l00000UW2V0_l0000308mOU@03o`00003oool0oooo00@0
oooo00<000000?ooo`3oool0;@3oool004X0oooo0`000002o`000080ZKgX00?o00000:Vmj02Y_NP0
1?l000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX
00?o00000:Vmj02Y_NP00ol000030:Vmj005o`00002Y_NSo00000:Vmj?l000000`2Y_NP3o`0000<0
ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y_NP00ol00000
ZKgX0:Vmj003o`0000<0ZKgX00?o00000:Vmj02Y_NP00_l000040:Vmj0?o000000<0ZKgXo`00002Y
_NP00P2Y_NP01_l00000ZKgXo`000?l00000ZK_Vo`0000<0ZK_V0ol000000`2UX];o00000:FRdP02
0:FRdP04o`00002UX]80YJ;B0:FRdP?o000000<0UW2Vo`00002FL:H00P2FL:H00ol00000UW2V09I`
YP0209I`YP04o`00002FL:H00000o`0000<0UW2V00Co000009I`YP2FL:Ko0000102FL:H00ol00000
UW2Vo`000003o`00000308mOUOl00000SenE0080SenE00?o00000?ooo`3oool01@3oool00`000000
oooo0?ooo`0/0?ooo`00B03oool2000000040?ooool00000ZKgXo`0000<0ZKgX0ol000030:Vmj003
o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZKgX00?o00000:Vmj02Y
_NP00ol000030:Vmj003o`00002Y_NP0ZKgX00;o00000`2Y_NP01Ol00000ZKgXo`00002Y_NSo0000
00@0ZKgX0ol000000`2Y_NSo00000:Vmj0020:Vmj0?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`00
0080ZKgX00?o00000:Vmj02Y_NP01?l000020:Vmj003o`00002Y_NP0ZKgX00;o0000102Y_NP00ol0
0000ZKgX0:Vmj002o`0000@0ZK_V0ol000000`2UX];o00000:FRdP020:FRdP04o`00002UX]80YJ;B
0:FRdP?o000000D0UW2Vo`00002FL:H0UW2Vo`00000409I`YP05o`00002FL:H0UW2V09I`Y_l00000
0P2FL:H01@000000UW2V09I`YP2FL:Ko000000<0UW2V00?o000009I`YP2FL:H00ol0000208mOU@04
o`00002?GiD0SenEo`0000@0SenE00?o00000?ooo`3oool0103oool00`000000oooo0?ooo`0/0?oo
o`00A@3oool01000003o00000000003oool2o`0000<0ZKgX00?o00000:Vmj?l000000P2Y_NP01?l0
0000ZKgX0:Vmj02Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0
ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZKgX00?o00000:Vmj02Y_NP00_l00003
0:Vmj006o`00002Y_NSo0000o`00002Y_NSo00000`2Y_NP01Ol00000ZKgXo`00002Y_NSo000000@0
ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`000080
ZKgX00?o00000:Vmj02Y_NP01?l000020:VkiP03o`00002Y^nH0ZK_V00;o0000102UX]801?l00000
YJ;B0:FRd_l000020:FRdP;o00000`2FL:H01Ol00000UW2V09I`YP2FL:Ko000000<0UW2V00Go0000
09I`YP2FL:H0UW2Vo`00000209I`YP030000002FL:H0UW2V0080UW2V00?o000009I`YP2FL:H00ol0
00000`2?GiGo000008mOU@0208mOU@04o`00002?GiD0SenEo`0000@0SenE00?o00000?ooo`3oool0
103oool00ol0000000000?ooo`0/0?ooo`00@`3oool2000000Co00000P2Y_NP00ol00000ZKgX0:Vm
j002o`0000@0ZKgX00Go00000:Vmj?l00000ZKgXo`0000030:Vmj0?o000000<0ZKgXo`00002Y_NP0
0`2Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0ZKgX00?o0000
0P2Y_NP00ol00000ZKgX0:Vmj002o`0000@0ZKgX00?o00000:Vmj02Y_NP00_l000030:Vmj006o`00
002Y_NSo0000o`00002Y_NSo00000`2Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP01?l000020:Vm
j003o`00002Y_NP0ZKgX00?o00000P2Y^nH00ol00000ZK_V0:VkiP04o`0000030:FRd_l00000YJ;B
00<0YJ;B00?o00000:FRdP2UX]800ol000000`2FL:Ko000009I`YP0309I`YP04o`00002FL:H0UW2V
o`0000<0UW2V00Go000009I`YP2FL:H0UW2Vo`00000209I`YP0300000?l00000UW2V0080UW2V00Co
000009I`Y_l0003o00000`2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Go000008mOU@2?
GiD0SenEo`0000080?ooo`030000003oool0oooo02X0oooo000Q0?ooo`;o00007@3oool00ol00000
000000000002o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o
00000`2Y_NP01Ol00000ZKgXo`00002Y_NSo000000<0ZKgX00Ko00000:Vmj?l0003o00000:Vmj?l0
00030:Vmj0?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZKgX00?o00000:Vmj02Y_NP00ol0
00020:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y_NP00ol00000ZKgX0:Vmj002o`0000@0ZKgX00Go
00000:Vmj?l00000ZKgXo`0000030:Vmj0?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZK_V
00?o00000:VkiP2Y^nH00ol000020:FRdP05o`00002UX]80YJ;B0:FRd_l000000P2UX]84o`000005
09I`Y_l00000UW2V09I`Y_l00000102FL:H01?l00000UW2V09I`Y_l0000309I`YP03o`00002FL:H0
UW2V0080UW2V00Go000009I`YP00003o000009I`YP04o`00000308mOUOl00000SenE0080SenE00?o
000008mOU@2?GiD00P2?GiD01?l00000SenE08mOUOl0000308mOU@03o`00003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool2o`000280oooo000P0?ooo`04o`00003oool0ooooo`0001X0oooo
0P000002o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o0000
0`2Y_NP00ol00000ZKgX0:Vmj002o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj005o`00
002Y_NSo00000:Vmj?l000000`2Y_NP3o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003
o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y
_NP00ol000030:Vmj005o`00002Y_NSo00000:Vmj?l000000`2Y_NP3o`000080ZK_V00Co00000:Vk
iP2Y^nH0ZK_V0ol000000`2UX];o00000:FRdP030:FRdP03o`00002UX]80YJ;B00?o00000P2FL:H0
1?l00000UW2V09I`Y_l0000309I`YP05o`00002FL:H0UW2V09I`Y_l000000`2FL:H01?l00000UW2V
09I`Y_l0000409I`YP03o`00002FL:H0000000;o00000P2?GiD01?l00000SenE08mOUOl0000408mO
U@05o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo000000T0oooo00<0
00000?ooo`3oool0103oool01?l00000oooo0?ooool0000Q0?ooo`00803oool01?l00000oooo0?oo
ool0000G0?ooo`<0000000?o00000:Vmj?l00000102Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP0
0ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX
00?o00000:Vmj02Y_NP00_l000030:Vmj005o`00002Y_NSo00000:Vmj?l00000102Y_NP3o`000080
ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y_NP00ol00000
ZKgX0:Vmj003o`0000<0ZKgX00?o00000:Vmj02Y_NP00_l000030:Vmj005o`00002Y_NSo00000:Vk
i_l00000102Y^nH01Ol00000ZK_Vo`00002UX];o000000<0YJ;B00Co00000:FRdP2UX]80YJ;B0ol0
00000`2FL:Ko000009I`YP0209I`YP05o`00002FL:H0UW2V09I`Y_l000000P2FL:H01Ol00000UW2V
09I`YP2FL:Ko000000<0UW2V00Go000009I`YP2FL:H0UW2Vo`00000209I`YP?o000000<00000o`00
002?GiD00P2?GiD01?l00000SenE08mOUOl0000408mOU@05o`00002?GiD0SenE08mOUOl000000P2?
GiD01Ol00000SenE08mOU@2?GiGo000000X0oooo00<000000?ooo`3oool00`3oool01?l00000oooo
0?ooool0000Q0?ooo`00803oool01?l00000oooo0?ooool0000D0?ooo`80000000Co00000?ooool0
003o00000`2Y_NP01_l00000ZKgXo`000?l00000ZKgXo`0000<0ZKgX0ol000020:Vmj003o`00002Y
_NP0ZKgX00Co00000P2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP01?l0
00020:Vmj003o`00002Y_NP0ZKgX00;o00000`2Y_NP01_l00000ZKgXo`000?l00000ZKgXo`0000<0
ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`000080
ZKgX00?o00000:Vmj02Y_NP01?l000020:Vmj003o`00002Y_NP0ZKgX00;o00000`2Y^nH00ol00000
ZK_V0:VkiP03o`0000<0YJ;B00Go00000:FRdP2UX];o00000:FRdP02o`00000509I`Y_l00000UW2V
09I`Y_l000000`2FL:H01Ol00000UW2V09I`YP2FL:Ko00000080UW2V00Go000009I`YP2FL:H0UW2V
o`00000309I`YP04o`00002FL:H0UW2V09I`YP?o000000D0SenEo`00002?GiD00000o`00000308mO
U@05o`00002?GiD0SenE08mOUOl000000`2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Go
000008mOU@2?GiD0SenEo`00000:0?ooo`030000003oool0oooo00<0oooo00Co00000?ooo`3ooooo
00008@3oool00200oooo00Co00000?ooo`3ooooo00004P3oool2000000040?ooool0003o0000o`00
0080ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj005o`00002Y_NSo00000:Vmj?l000000`2Y_NP3
o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP0
0ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00_l000040:Vmj005o`00002Y_NSo
00000:Vmj?l000000`2Y_NP3o`0000030:Vmj?l00000ZKgX00<0ZKgX0ol000020:Vmj003o`00002Y
_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZK_V00?o00000:VkiP2Y^nH00ol0
00020:FRdP05o`00002UX]80YJ;B0:FRd_l000000P2UX]82o`0000<0UW2V00Go000009I`YP2FL:H0
UW2Vo`00000209I`YP05o`00002FL:H0UW2V09I`Y_l000000P2FL:H00ol00000UW2V09I`YP0209I`
YP06o`00002FL:H0UW2V09I`Y_l00000UW2V0_l0000308mOU@04o`00002?GiD00000o`0000@0SenE
00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Go000008mO
U@2?GiD0SenEo`00000:0?ooo`030000003oool0oooo0080oooo00Co00000?ooo`3ooooo00008@3o
ool00200oooo00Co00000?ooo`3ooooo00003`3oool00`00003o000000000003o`000080ZKgX00?o
00000:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0ZKgX00;o00000`2Y_NP00ol00000ZKgXo`00
00020:Vmj004o`00002Y_NP0ZKgX0:Vmj0?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX
00?o00000:Vmj02Y_NP01?l000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX
0:Vmj003o`0000<0ZKgX00Go00000:Vmj?l00000ZKgXo`0000030:Vmj006o`00002Y_NSo0000o`00
002Y_NSo00000`2Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP00ol000030:VkiP03o`00002Y^nH0
ZK_V00?o000000<0YJ;Bo`00002UX]800`2UX]800ol00000YJ;Bo`000003o`00000309I`Y_l00000
UW2V00<0UW2V00Co000009I`YP2FL:Ko00000P2FL:H01Ol00000UW2V09I`YP2FL:Ko00000080UW2V
00?o000009I`YP2FL:H00P2FL:H00ol00000UW2Vo`000003o`00000308mOUOl00000SenE0080SenE
00Go000008mOU@000000SenEo`00000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Go000008mO
U@2?GiD0SenEo`00000308mOU@05o`00002?GiD0SenE08mOUOl000002P3oool00ol0000000000?oo
o`020?ooo`04o`00003oool0ooooo`000240oooo000Q0?ooo`;o00003P3oool2000000?o00000P2Y
_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y
_NP0ZKgX00;o0000102Y_NP01Ol00000ZKgXo`00002Y_NSo000000<0ZKgX0ol000020:Vmj003o`00
002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP0
0ol000030:Vmj003o`00002Y_NP0ZKgX00;o00000`2Y_NP00ol00000ZKgX0:Vmj002o`0000@0ZKgX
00Go00000:Vmj?l00000ZKgXo`0000030:Vmj0?o00000P2Y^nH00ol00000ZK_V0:VkiP04o`000003
0:FRd_l00000YJ;B0080YJ;B00?o00000:FRdP2UX]800ol0000209I`YP04o`00002FL:H0UW2Vo`00
00@0UW2V00Co000009I`YP2FL:Ko00000`2FL:H01?l00000UW2V09I`Y_l0000309I`YP03o`00002F
L:Ko000000?o00000P2?GiD01?l00000SenE08mOUOl0000308mOU@05o`00002?GiD0000008mOUOl0
00000`2?GiD01?l00000SenE08mOUOl0000308mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD0
1Ol00000SenE08mOU@2?GiGo000000T0oooo00?o00000?ooo`000000103oool2o`000280oooo000^
0?ooo`03o`0000000000000000;o00000P2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00?o0000
0:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj003
o`0000<0ZKgX00Go00000:Vmj?l00000ZKgXo`0000030:Vmj0?o00000`2Y_NP00ol00000ZKgX0:Vm
j003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00Co00000P2Y
_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj005o`00002Y
_NSo00000:Vki_l000000`2Y^nH3o`000080YJ;B00Go00000:FRdP2UX]80YJ;Bo`0000020:FRdP?o
000000<0UW2Vo`00002FL:H00P2FL:H01Ol00000UW2V09I`YP2FL:Ko000000<0UW2V00Co000009I`
YP2FL:Ko00000`2FL:H01_l00000UW2V09I`YP2FL:Ko000009I`YP?o00000P2?GiD01Ol00000SenE
08mOU@2?GiGo00000080SenE00Go000008mOU@2?GiD0SenEo`0000020000000308mOUOl00000SenE
0080SenE00Co000008mOU@2?GiGo00000`2?GiD00ol00000SenE08mOU@0208mOU@04o`00002?GiD0
SenEo`0000<0SenE00?o00000?ooo`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`00;03oool2
000000;o000000<0ZKgXo`00002Y_NP00P2Y_NP3o`000080ZKgX00?o00000:Vmj02Y_NP01?l00002
0:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00?o0000
0:Vmj02Y_NP00_l000030:Vmj005o`00002Y_NSo00000:Vmj?l00000102Y_NP3o`000080ZKgX00?o
00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vm
j003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0ZKgX00;o00000`2Y
^nH01Ol00000ZK_Vo`00002UX];o000000<0YJ;B00Wo00000:FRdP2UX]80YJ;Bo`00002UX];o0000
09I`Y_l000000P2FL:H00ol00000UW2V09I`YP0209I`YP04o`00002FL:H0UW2Vo`0000<0UW2V00Co
000009I`YP2FL:Ko00000`2FL:H01?l00000UW2V09I`YP2FL:H2o`00000308mOUOl00000SenE0080
SenE00Go000008mOU@2?GiD0SenEo`00000308mOU@08o`0000000000000000000?l00000000008mO
UOl0000308mOU@04o`00002?GiD0SenEo`0000@0SenE00Go000008mOU@2?GiD0SenEo`00000208mO
U@05o`00002?GiD0SenE08mOUOl000003@3oool00`000000oooo0?ooo`0T0?ooo`00:@3oool30000
00030?ooool0003o000000<0ZKgX00Go00000:Vmj?l00000ZKgXo`0000030:Vmj0?o00000`2Y_NP0
0ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0
ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj002o`0000<0ZKgX00Ko00000:Vmj?l0003o00000:Vm
j?l000030:Vmj0?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP0
1?l000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZK_V
00?o00000:VkiP2Y^nH00_l000030:FRdP06o`00002UX]80YJ;B0:FRd_l00000YJ;B0ol0000209I`
YP05o`00002FL:H0UW2V09I`Y_l000000`2FL:H01?l00000UW2V09I`Y_l0000309I`YP05o`00002F
L:H0UW2V09I`Y_l000000P2FL:H00ol00000UW2Vo`000002o`000080SenE00Go000008mOU@2?GiD0
SenEo`00000308mOU@03o`00002?GiD00000008000000`2?GiD01?l00000SenE00000?l0000308mO
U@04o`00002?GiD0SenEo`0000@0SenE00Go000008mOU@2?GiD0SenEo`00000308mOU@04o`00002?
GiD0SenEo`0000d0oooo00<000000?ooo`3oool0903oool002P0oooo1Ol000020:Vmj003o`00002Y
_NP0ZKgX00;o00000`2Y_NP00ol00000ZKgXo`0000020:Vmj004o`00002Y_NP0ZKgX0:Vmj0?o0000
0P2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP01?l000020:Vmj003o`00
002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj002o`0000@0ZKgX00Go00000:Vmj?l00000
ZKgXo`0000030:Vmj0?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00?o00000:Vmj02Y
_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y^nH00ol00000ZK_V0:VkiP04o`000003
0:FRd_l00000YJ;B0080YJ;B00?o00000:FRdP2UX]800ol0000209I`YP05o`00002FL:H0UW2V09I`
Y_l000000P2FL:H01Ol00000UW2V09I`YP2FL:Ko00000080UW2V00?o000009I`YP2FL:H00P2FL:H0
1Ol00000UW2V09I`Y_l00000UW2V00?o00000P2?GiD01?l00000SenE08mOUOl0000308mOU@03o`00
002?GiD0SenE00<000000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00D0000008mOU@2?
GiD0SenEo`00000308mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01Ol00000SenE08mOU@2?
GiGo00000080SenE00?o00000?ooo`3oool0303oool00`000000oooo0?ooo`0S0?ooo`00:03oool0
1@00003o00000:Vmj02Y_NSo00000080ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y
_NP01Ol00000ZKgXo`00002Y_NSo000000<0ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00?o0000
0`2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00
002Y_NP0ZKgX00?o00000`2Y_NP01Ol00000ZKgXo`00002Y_NSo000000<0ZKgX0ol000020:Vmj003
o`00002Y_NP0ZKgX00Co00000P2Y_NP00ol00000ZKgX0:Vmj003o`000080ZK_V00?o00000:VkiP2Y
^nH00ol000020:FRdP05o`00002UX]80YJ;B0:FRd_l000000P2UX]83o`00000309I`Y_l00000UW2V
0080UW2V00Go000009I`YP2FL:H0UW2Vo`00000209I`YP05o`00002FL:H0UW2V09I`Y_l000000P2F
L:H00ol00000UW2V09I`YP0209I`YP03o`00002FL:Ko000000;o000000<0SenEo`00002?GiD00P2?
GiD01Ol00000SenE08mOU@2?GiGo00000080SenE0`00000208mOU@04o`00002?GiD0SenEo`0000<0
SenE00Go000008mOU@2?GiGo00000000000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Go0000
08mOU@2?GiD0SenEo`00000308mOU@05o`00002?GiD0SenE08mOUOl000003P3oool00`000000oooo
0?ooo`0R0?ooo`00803oool2o`0000H0oooo00@00000o`00002Y_NP0ZKgX0ol000020:Vmj003o`00
002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj002o`0000<0ZKgX00Go00000:Vmj?l00000
ZKgXo`0000030:Vmj0?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y
_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj002o`0000<0
ZKgX00Go00000:Vmj?l00000ZKgXo`0000030:Vmj0?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`00
0080ZK_V00?o00000:VkiP2Y^nH00ol000000`2UX];o00000:FRdP030:FRdP03o`00002UX]80YJ;B
00?o000000D0UW2Vo`00002FL:H0UW2Vo`00000409I`YP04o`00002FL:H0UW2Vo`000080UW2V00Go
000009I`YP2FL:H0UW2Vo`00000309I`YP03o`00002FL:Ko000000?o000000D0SenEo`00002?GiD0
SenEo`00000308mOU@04o`00002?GiD0SenE08mOU@<0000000<0SenEo`00002?GiD00P2?GiD01?l0
0000SenE08mOUOl0000308mOU@05o`00002?GiD0SenE08mOU@0000000`2?GiD01?l00000SenE08mO
UOl0000308mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01Ol00000SenE08mOU@2?GiGo0000
00h0oooo00<000000?ooo`3oool08P3oool001l0oooo00Co00000?ooo`3ooooo00001@3oool01000
0000ooooo`000?l000020:Vmj003o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj003
o`000080ZKgX00?o00000:Vmj02Y_NP00_l000030:Vmj003o`00002Y_NSo00000080ZKgX00Co0000
0:Vmj02Y_NP0ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vm
j003o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00;o00000`2Y
_NP01Ol00000ZKgXo`00002Y_NSo000000@0ZKgX0ol000000`2Y^nKo00000:VkiP020:VkiP?o0000
00<0YJ;Bo`00002UX]800P2UX]800ol00000YJ;B0:FRdP04o`00000509I`Y_l00000UW2V09I`Y_l0
00000`2FL:H01Ol00000UW2V09I`YP2FL:Ko00000080UW2V00Co000009I`YP2FL:Ko0000102FL:H0
0ol00000UW2Vo`000002o`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mO
U@2?GiGo000000<0000000Go000008mOU@2?GiD0SenEo`00000308mOU@04o`00002?GiD0SenEo`00
00<0SenE00Ko000008mOU@2?GiD0SenEo`000000000208mOU@04o`00002?GiD0SenEo`0000<0SenE
00Go000008mOU@2?GiD0SenEo`00000308mOU@05o`00002?GiD0SenE08mOUOl000003@3oool00ol0
0000oooo0000000S0?ooo`007`3oool01?l00000oooo0?ooool000040?ooo`050000003oool0oooo
0?ooool000000P2Y_NP3o`0000<0ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0
ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj002o`0000@0ZKgX00?o00000:Vmj?l000000P2Y_NP0
0ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0
ZKgX00Co00000P2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00_l00003
0:Vmj006o`00002Y_NSo0000o`00002Y^nKo00000`2Y^nH01Ol00000ZK_Vo`00002UX];o000000<0
YJ;B00?o00000:FRdP2UX]800ol0000209I`YP04o`00002FL:H0UW2Vo`0000<0UW2V00Co000009I`
YP2FL:Ko00000`2FL:H01?l00000UW2V09I`Y_l0000309I`YP04o`00002FL:H0UW2V09I`YP;o0000
00<0SenEo`00002?GiD00P2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD000000000
00<0SenE00Go000008mOU@2?GiD0SenEo`00000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Wo
000008mOU@2?GiD0SenEo`00002?GiD0000008mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo
000000@0SenE00Ko000008mOU@2?GiD0SenEo`00002?GiD2o`0000l0oooo00<000000?ooo`3oool0
8@3oool001l0oooo00Co00000?ooo`3ooooo0000103oool00`000000oooo0?ooo`020?ooo`;o0000
0`2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00
002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX0ol000020:Vmj003o`00
002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00?o00000:Vmj02Y_NP0
0ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj002o`0000@0ZK_V
00?o00000:VkiP2Y^nH00_l000030:FRdP08o`00002UX]80YJ;Bo`00002UX];o000009I`Y_l00003
09I`YP05o`00002FL:H0UW2V09I`Y_l000000P2FL:H01?l00000UW2V09I`Y_l0000309I`YP05o`00
002FL:H0UW2V09I`Y_l000000P2FL:H00ol00000UW2Vo`000002o`000080SenE00Go000008mOU@2?
GiD0SenEo`00000208mOU@03o`00002?GiD0SenE00<000000P2?GiD01?l00000SenE08mOUOl00003
08mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01?l00000SenE08mOUOl0000308mOU@05o`00
002?GiD0SenE00000?l000000P2?GiD00ol00000SenE08mOU@0208mOU@05o`00002?GiD0SenE08mO
UOl000000`2?GiD2o`00000308mOUOl00000oooo00l0oooo00<000000?ooo`3oool0803oool001l0
oooo00Co00000?ooo`3ooooo0000103oool00`00003o00000?ooo`040?ooo`03o`00002Y_NP0ZKgX
00?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vm
j003o`00002Y_NP0ZKgX00?o00000`2Y_NP01Ol00000ZKgXo`00002Y_NSo000000<0ZKgX0ol00002
0:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZKgX00?o0000
0:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y^nH00ol00000ZK_V0:VkiP04
o`0000030:FRd_l00000YJ;B0080YJ;B00?o00000:FRdP2UX]800_l0000209I`YP05o`00002FL:H0
UW2V09I`Y_l000000`2FL:H01?l00000UW2V09I`Y_l0000209I`YP05o`00002FL:H0UW2V09I`Y_l0
00000`2FL:H00ol00000UW2Vo`000002o`000080SenE00Co000008mOU@2?GiGo00000`2?GiD00ol0
0000SenE08mOU@030000000308mOUOl00000SenE0080SenE00Co000008mOU@2?GiGo00000`2?GiD0
1Ol00000SenE08mOU@2?GiGo000000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE
08mOU@00003o00000080SenE00?o000008mOU@2?GiD00P2?GiD01_l00000SenE08mOU@2?GiGo0000
08mOU@?o00000P2?GiD00ol00000oooo0?ooo`0?0?ooo`030000003oool0oooo01l0oooo000O0?oo
o`04o`00003oool0ooooo`0000@0oooo00<000000?ooo`3oool01@3oool2o`000080ZKgX00?o0000
0:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj003
o`0000<0ZKgX00?o00000:Vmj02Y_NP00_l000030:Vmj005o`00002Y_NSo00000:Vmj?l000000`2Y
_NP3o`000080ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y
_NP00ol00000ZKgX0:Vmj003o`000080ZK_V00?o00000:VkiP2Y^nH00ol000020:FRdP05o`00002U
X]80YJ;B0:FRd_l000000P2UX]83o`00000309I`Y_l00000UW2V0080UW2V00Co000009I`YP2FL:Ko
00000`2FL:H01?l00000UW2V09I`Y_l0000209I`YP03o`00002FL:H0UW2V0080UW2V00?o000009I`
Y_l000000_l000000`2?GiGo000008mOU@0208mOU@04o`00002?GiD0SenEo`0000<0SenE0`000000
1@2?GiGo000008mOU@2?GiGo000000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE
08mOU@2?GiGo000000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOU@2?GiD0
000000<0SenE00Ko000008mOU@2?GiD0SenEo`00002?GiD4o`000080SenE00Co000008mOU@2?GiGo
00004@3oool00`000000oooo0?ooo`0O0?ooo`00803oool2o`0000D0oooo00<000000?ooo`3oool0
1P3oool00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00
002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP0
0_l000030:Vmj005o`00002Y_NSo00000:Vmj?l000000`2Y_NP3o`000080ZKgX00?o00000:Vmj02Y
_NP01?l000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y^nH00ol00000ZK_V0:VkiP03o`000003
0:FRd_l00000YJ;B00<0YJ;B00?o00000:FRd_l000000ol000001@2FL:Ko000009I`YP2FL:Ko0000
00<0UW2V00Co000009I`YP2FL:Ko00000`2FL:H01?l00000UW2V09I`Y_l0000309I`YP03o`00002F
L:Ko000000?o000000D0SenEo`00002?GiD0SenEo`00000308mOU@04o`00002?GiD0SenEo`0000<0
000000D0SenEo`00002?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD0
1?l00000SenE08mOUOl0000308mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE
08mOU@2?GiGo000000@0SenE00D0000008mOU@2?GiGo000008mOU@04o`000080SenE00Go000008mO
U@2?GiD0SenEo`00000308mOU@03o`00003oool0oooo00l0oooo00<000000?ooo`3oool07P3oool0
02H0oooo00?o00000000003oool0203oool2o`000080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vm
j003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj004o`000080ZKgX00?o00000:Vm
j02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00;o00000`2Y_NP01Ol00000ZKgXo`00002Y_NSo
000000<0ZKgX0ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y^nH00ol00000ZK_V0:VkiP03
o`0000030:FRd_l00000YJ;B0080YJ;B00?o00000:FRdP2UX]800ol0000209I`YP04o`00002FL:H0
UW2Vo`0000<0UW2V00Co000009I`YP2FL:Ko00000`2FL:H01?l00000UW2V09I`Y_l0000309I`YP03
o`00002FL:Ko000000;o00000P2?GiD01?l00000SenE08mOUOl0000208mOU@05o`00002?GiD0SenE
08mOUOl000000`0000001Ol00000SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo0000
0`2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Go000008mOU@2?GiD0SenEo`00000308mO
U@05o`00002?GiD0SenE08mOUOl000000`2?GiD01_l00000SenE08mOU@2?GiD0000008mOU@?o0000
0P2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Go000008mOU@2?GiD0SenEo`00000A0?oo
o`03o`0000000000oooo01h0oooo000V0?ooo`030000003oool0oooo00P0oooo00Co00000:Vmj02Y
_NP0ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`00
00<0ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol0
0000ZKgX0:Vmj002o`0000<0ZKgX00?o00000:Vmj?l000000P2Y_NP00ol00000ZKgX0:Vmj004o`00
0080ZK_V00?o00000:VkiP2Y^nH00ol000000`2UX];o00000:FRdP020:FRdP03o`00002UX]80YJ;B
00?o000000<0UW2Vo`00002FL:H00P2FL:H01?l00000UW2V09I`Y_l0000309I`YP04o`00002FL:H0
UW2Vo`0000<0UW2V00Go000009I`YP2FL:H0UW2Vo`00000209I`YP;o000000<0SenEo`00002?GiD0
0P2?GiD01?l00000SenE08mOUOl0000208mOU@03o`00002?GiD00000008000000`2?GiD01Ol00000
SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOU@2?
GiGo00000080SenE00Go000008mOU@2?GiD0SenEo`00000308mOU@05o`00002?GiD0SenE08mOUOl0
00000`2?GiD02?l00000SenE08mOU@2?GiGo00000000002?GiGo00000`2?GiD01Ol00000SenE08mO
U@2?GiGo000000@0SenE00Co000008mOU@2?GiGo00004P3oool00`000000oooo0?ooo`0M0?ooo`00
9P3oool00`000000oooo0?ooo`090?ooo`05o`00002Y_NSo00000:Vmj?l000000`2Y_NP3o`000080
ZKgX00?o00000:Vmj02Y_NP00ol000030:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000
ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00;o
00000`2Y_NP3o`000080ZK_V00Co00000:VkiP2Y^nH0ZK_V0ol000000`2UX];o00000:FRdP020:FR
dP03o`00002UX]80YJ;B00?o000000D0UW2Vo`00002FL:H0UW2Vo`00000309I`YP04o`00002FL:H0
UW2Vo`0000<0UW2V00Co000009I`YP2FL:Ko00000`2FL:H01_l00000UW2V09I`YP2FL:Ko000009I`
YP;o00000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00?o000008mOU@2?GiD00P000003
08mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE
08mOUOl0000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Go000008mOU@2?GiD0SenEo`000003
08mOU@06o`00002?GiD0SenE08mOUOl00000SenE0ol000000`2?GiD00000o`00000308mOU@03o`00
002?GiD0SenE0080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@03o`00003oool0oooo0140
oooo00<000000?ooo`3oool0703oool002H0oooo00<00000o`00003oool02P3oool01ol00000ZKgX
0:Vmj02Y_NSo00000:Vmj?l000000P2Y_NP00ol00000ZKgX0:Vmj003o`0000<0ZKgX00?o00000:Vm
j02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`00
0080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj005o`00002Y_NSo00000:Vki_l00000102Y^nH0
1Ol00000ZK_Vo`00002UX];o000000<0YJ;B00?o00000:FRdP2UX]800ol000001@2FL:Ko000009I`
YP2FL:Ko000000<0UW2V00Co000009I`YP2FL:Ko00000`2FL:H01?l00000UW2V09I`Y_l0000309I`
YP05o`00002FL:H0UW2Vo`00002FL:H01?l000001@2?GiGo000008mOU@2?GiGo000000<0SenE00?o
000008mOU@2?GiD00`0000000`2?GiGo000008mOU@0208mOU@04o`00002?GiD0SenEo`0000<0SenE
00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenE
o`0000@0SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@03o`00002?GiGo000000?o00000P2?
GiD01?l00000SenE08mOU@00000408mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01?l00000
SenE08mOUOl0000D0?ooo`030000003oool0oooo01/0oooo000V0?ooo`030000003oool0oooo00/0
oooo00?o00000:Vmj02Y_NP00_l000030:Vmj0?o00000`2Y_NP00ol00000ZKgX0:Vmj003o`000080
ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000
ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00_l000030:VkiP03o`00002Y^nH0ZK_V00?o
00000`2UX]802?l00000YJ;B0:FRd_l00000YJ;Bo`00002FL:Ko00000P2FL:H01Ol00000UW2V09I`
YP2FL:Ko00000080UW2V00Co000009I`YP2FL:Ko00000`2FL:H01?l00000UW2V09I`Y_l0000309I`
YP03o`00002FL:Ko000000;o00000P2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0
SenE08mOU@<0000000D0SenEo`00002?GiD0SenEo`00000308mOU@04o`00002?GiD0SenEo`0000<0
SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl0000308mOU@05o`00002?GiD0
SenE08mOUOl000000`2?GiD01_l00000SenE08mOU@2?GiGo000008mOU@?o00000P2?GiD01Ol00000
SenE08mOU@2?GiGo00000080SenE00<0000008mOU@2?GiD00P2?GiD01Ol00000SenE08mOU@2?GiGo
000000<0SenE00Go000008mOU@2?GiD0SenEo`00000C0?ooo`030000003oool0oooo01/0oooo000V
0?ooo`0300000?l00000oooo00`0oooo0_l000020:Vmj003o`00002Y_NSo00000080ZKgX00Co0000
0:Vmj02Y_NP0ZKgX0ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vm
j003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y
^nH00ol00000ZK_V0:VkiP03o`000080YJ;B00Go00000:FRdP2UX]80YJ;Bo`0000020:FRdP;o0000
0P2FL:H01Ol00000UW2V09I`YP2FL:Ko00000080UW2V00Co000009I`YP2FL:Ko00000`2FL:H01?l0
0000UW2V09I`Y_l0000309I`YP03o`00002FL:Ko000000;o000000<0SenEo`00002?GiD00P2?GiD0
1?l00000SenE08mOUOl0000208mOU@05o`0000000000000000000?l000000`2?GiD01?l00000SenE
08mOUOl0000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000`2?GiD0
1?l00000SenE08mOUOl0000308mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD00ol00000SenE
08mOU@03o`00000308mOUOl00000SenE0080SenE00Go000008mOU@2?GiD0SenEo`00000308mOU@05
0000002?GiD0SenE08mOUOl000000`2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00?o0000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0J0?ooo`009@3oool00ol0000000000?ooo`0>0?oo
o`03o`00002Y_NP0ZKgX00?o00000`2Y_NP00ol00000ZKgXo`0000020:Vmj003o`00002Y_NP0ZKgX
00?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vm
j003o`00002Y_NP0ZKgX00?o00000P2Y^nH00ol00000ZK_V0:VkiP03o`0000030:FRd_l00000YJ;B
00<0YJ;B00?o00000:FRd_l000000ol000001@2FL:Ko000009I`YP2FL:Ko000000<0UW2V00Co0000
09I`YP2FL:Ko00000P2FL:H01Ol00000UW2V09I`YP2FL:Ko00000080UW2V00?o000009I`Y_l00000
0ol000001@2?GiGo000008mOU@2?GiGo000000<0SenE00Co000008mOU@2?GiGo00000`0000001?l0
0000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo0000
0`2?GiD01?l00000SenE08mOUOl0000308mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01?l0
0000SenE08mOUOl0000308mOU@?o000000D0SenEo`00002?GiD0SenEo`00000308mOU@03o`00002?
GiD0SenE0080SenE00Go000008mOU@2?GiGo00000000000208mOU@05o`00002?GiD0SenE08mOUOl0
00000`2?GiD01Ol00000SenE08mOU@2?GiGo000001D0oooo00<000000?ooo`3oool06@3oool000H0
oooo0_l000040?ooo`03o`00003oool0oooo00<0oooo0_l000020?ooo`Go00000P3oool3o`0000D0
oooo00<000000?ooo`3oool03`3oool2o`0000<0ZKgX00?o00000:Vmj02Y_NP00_l000030:Vmj0?o
00000P2Y_NP00ol00000ZKgX0:Vmj003o`000080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003
o`00002Y_NP0ZKgX00?o00000P2Y^nH00ol00000ZK_V0:VkiP03o`0000030:FRd_l00000YJ;B0080
YJ;B00?o00000:FRdP2UX]800ol0000209I`YP04o`00002FL:H0UW2Vo`000080UW2V00Go000009I`
YP2FL:H0UW2Vo`00000209I`YP04o`00002FL:H0UW2Vo`0000<0UW2V00?o000009I`Y_l000000_l0
000208mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiD0SenEo`000003000000<0
SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0
SenEo`0000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOU@2?GiGo000000<0
SenE00Go000008mOU@2?GiGo000008mOU@03o`0000<0SenE00Co000008mOU@2?GiGo0000102?GiD0
1Ol00000SenE08mOU@2?GiGo00000080SenE00Go000008mOU@000000SenEo`00000308mOU@05o`00
002?GiD0SenE08mOUOl000000`2?GiD00ol00000oooo0?ooo`0B0?ooo`03o`0000000000oooo01X0
oooo00050?ooo`04o`00003oool0ooooo`0000P0oooo00Co00000?ooo`3ooooo00000P3oool01_l0
0000oooo0?ooool00000ooooo`0000<0oooo00?o00000?ooo`3oool00P3oool00`00003o00000?oo
o`0A0?ooo`03o`00002Y_NP0ZKgX00?o00000P2Y_NP01Ol00000ZKgXo`00002Y_NSo000000<0ZKgX
0ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y_NP00ol00000ZKgX0:Vmj003o`000080ZK_V
00?o00000:VkiP2Y^nH00ol000000`2UX];o00000:FRdP020:FRdP03o`00002UX]80YJ;B00?o0000
00<0UW2Vo`00002FL:H00P2FL:H01?l00000UW2V09I`Y_l0000209I`YP05o`00002FL:H0UW2V09I`
Y_l000000P2FL:H01Ol00000UW2V09I`YP2FL:Ko00000080UW2V0_l000000`2?GiGo000008mOU@02
08mOU@04o`00002?GiD0SenEo`000080SenE00?o000008mOU@0000000P00000308mOU@04o`00002?
GiD0SenEo`000080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mO
UOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Go000008mOU@2?GiD0SenEo`00
000308mOU@06o`00002?GiD0SenE08mOUOl00000SenE0ol0000208mOU@05o`00002?GiD0SenE08mO
UOl000000`2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00So000008mOU@2?GiGo000008mO
U@000000SenEo`0000<0SenE00?o000008mOU@2?GiD00P2?GiD01?l00000SenE08mOUOl0000F0?oo
o`030000003oool0oooo01P0oooo00050?ooo`04o`00003oool0ooooo`0000P0oooo00Co00000?oo
o`3ooooo00000`3oool00ol00000oooo0?ooo`050?ooo`03o`00003oool0oooo0080oooo00<00000
0?ooo`3oool04P3oool2o`000080ZKgX00?o00000:Vmj02Y_NP00_l000030:Vmj003o`00002Y_NSo
00000080ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00?o00000P2Y^nH0
0ol00000ZK_V0:VkiP03o`0000030:FRd_l00000YJ;B0080YJ;B00?o00000:FRdP2UX]800ol00000
1@2FL:Ko000009I`YP2FL:Ko000000<0UW2V00Co000009I`YP2FL:Ko00000`2FL:H01?l00000UW2V
09I`Y_l0000309I`YP05o`00002FL:H0UW2Vo`00002FL:H00_l0000208mOU@05o`00002?GiD0SenE
08mOUOl000000P2?GiD00ol00000SenE08mOU@0200000080SenE00Go000008mOU@2?GiD0SenEo`00
000208mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000
SenE08mOUOl0000308mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01Ol00000SenE08mOUOl0
0000SenE00Co000000<0SenEo`00002?GiD00P2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE
00Go000008mOU@2?GiD0SenEo`00000308mOU@04o`00002?GiD0SenEo`000080SenE00<00000o`00
002?GiD00`2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00?o00000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0G0?ooo`001@3oool01?l00000oooo0?ooool000080?ooo`04o`00003oool0
ooooo`0000@0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`020?ooo`030000003o
ool0oooo01<0oooo00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0ZKgX00;o00000`2Y
_NP3o`000080ZKgX00?o00000:Vmj02Y_NP00ol000020:VkiP03o`00002Y^nH0ZK_V00?o000000<0
YJ;Bo`00002UX]800P2UX]800ol00000YJ;B0:FRdP03o`00000509I`Y_l00000UW2V09I`Y_l00000
0`2FL:H01?l00000UW2V09I`Y_l0000309I`YP04o`00002FL:H0UW2Vo`0000<0UW2V00Go000009I`
YP2FL:Ko000009I`YP03o`00000508mOUOl00000SenE08mOUOl000000`2?GiD00ol00000SenE08mO
U@030000000508mOUOl00000SenE08mOUOl000000`2?GiD01?l00000SenE08mOUOl0000308mOU@04
o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@03o`00002?GiD0
SenE0080SenE00Co000008mOU@2?GiGo00000`2?GiD00ol00000SenEo`000002o`000080SenE00Co
000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Go000008mOU@2?
GiD0SenEo`00000308mOU@04o`00002?GiD0SenEo`0000<0SenE00<00000o`00002?GiD00P2?GiD0
1Ol00000SenE08mOU@2?GiGo000000<0SenE00?o00000?ooo`3oool0503oool00`000000oooo0?oo
o`0G0?ooo`001@3oool01?l00000oooo0?ooool000080?ooo`06o`00003oool0ooooo`00003ooooo
00000`3oool00ol00000ooooo`000003o`0000D0oooo00<000000?ooo`3oool0503oool2o`000080
ZKgX00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NSo00000080ZKgX00?o00000:Vmj02Y
_NP00ol000020:VkiP03o`00002Y^nH0ZK_V00?o000000<0YJ;Bo`00002UX]800P2UX]800ol00000
YJ;B0:FRdP03o`00000509I`Y_l00000UW2V09I`Y_l000000`2FL:H01?l00000UW2V09I`Y_l00003
09I`YP04o`00002FL:H0UW2Vo`000080UW2V00Ko000009I`YP2FL:H0UW2Vo`00002FL:H3o`000005
08mOUOl00000SenE08mOUOl000000P2?GiD01?l00000SenE08mOU@2?GiD30000000508mOUOl00000
SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Go000008mOU@2?GiD0
SenEo`00000208mOU@04o`00002?GiD0SenEo`0000<0SenE00Go000008mOU@2?GiD0SenEo`000003
08mOU@04o`00002?GiD0SenEo`000080SenE0ol000000`2?GiGo000008mOU@0208mOU@04o`00002?
GiD0SenEo`0000@0SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mO
UOl000000`2?GiD01?l00000SenE08mOUOl0000408mOU@050000002?GiD0SenE08mOUOl000000`2?
GiD01Ol00000SenE08mOU@2?GiGo000001@0oooo0ol000000`000000oooo0?ooo`0F0?ooo`001@3o
ool01?l00000oooo0?ooool000080?ooo`06o`00003oool0ooooo`00003ooooo00000`3oool00ol0
0000ooooo`0000070?ooo`03o`0000000000oooo01H0oooo00?o00000:Vmj02Y_NP00ol000020:Vm
j003o`00002Y_NP0ZKgX00;o00000`2Y_NP3o`000080ZK_V00?o00000:VkiP2Y^nH00ol000000`2U
X];o00000:FRdP020:FRdP03o`00002UX]80YJ;B00?o000000D0UW2Vo`00002FL:H0UW2Vo`000003
09I`YP04o`00002FL:H0UW2Vo`000080UW2V00Go000009I`YP2FL:H0UW2Vo`00000209I`YP05o`00
002FL:H0UW2Vo`00002FL:H01?l000001@2?GiGo000008mOU@2?GiGo00000080SenE00Co000008mO
U@2?GiGo00000`0000001Ol00000SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo0000
0`2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`000080SenE00?o000008mO
U@2?GiD00P2?GiD01?l00000SenE08mOUOl0000308mOU@03o`00002?GiD0SenE00?o000000D0SenE
o`00002?GiD0SenEo`00000308mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01Ol00000SenE
08mOU@2?GiGo00000080SenE00Go000008mOU@2?GiD0SenEo`00000308mOU@05o`00002?GiD0SenE
08mOUOl000000`2?GiD01@000000SenE08mOU@2?GiGo000000<0SenE00Go000008mOU@2?GiD0SenE
o`00000A0?ooo`?o000000GoM29Do`000?l0003o00000000000G0?ooo`001P3oool2o`0000X0oooo
0_l000030?ooo`?o00000P3oool5o`0000<0oooo00<000000?ooo`3oool05`3oool2o`000080ZKgX
00?o00000:Vmj02Y_NP00ol000020:Vmj005o`00002Y_NSo00000:Vki_l000000`2Y^nH3o`000003
0:FRd_l00000YJ;B0080YJ;B00?o00000:FRdP2UX]800ol000001@2FL:Ko000009I`YP2FL:Ko0000
00<0UW2V00Co000009I`YP2FL:Ko00000P2FL:H01?l00000UW2V09I`Y_l0000309I`YP05o`00002F
L:H0UW2Vo`00002FL:H00ol0000208mOU@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?
GiGo00000`0000001?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`000080SenE00Go
000008mOU@2?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000
SenE08mOU@2?GiGo000000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenEo`000?l0
000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Go000008mOU@2?GiD0SenEo`00000308mOU@05
o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo000000@0SenE00Co0000
08mOU@2?GiGo00000`2?GiD01Ol00000000008mOU@2?GiGo000000<0SenE00Go000008mOU@2?GiD0
SenEo`00000=0?ooo`Co000000SoM29Do`000?md8UCoM29Do`000?nY`>[o0000000001L0oooo000T
0?ooo`0300000?l00000oooo01P0oooo00?o00000:Vmj02Y_NP00ol000020:Vmj003o`00002Y_NP0
ZKgX00;o00000`2Y^nH01Ol00000ZK_Vo`00002UX];o000000<0YJ;B00So00000:FRdP2UX];o0000
0:FRd_l00000UW2Vo`000080UW2V00Go000009I`YP2FL:H0UW2Vo`00000209I`YP04o`00002FL:H0
UW2Vo`000080UW2V00Co000009I`YP2FL:Ko00000`2FL:H00ol00000UW2Vo`000002o`00000308mO
UOl00000SenE0080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000000000000000000308mO
U@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mO
UOl0000208mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01?l00000SenE08mOUOl0000308mO
U@05o`00002?GiD0SenEo`00002?GiD01?l000000`2?GiGo000008mOU@0208mOU@05o`00002?GiD0
SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Go000008mOU@2?GiD0
SenEo`00000208mOU@03o`00002?GiD0SenE0080SenE00Go000008mOU@2?GiD0SenEo`00000208mO
U@09o`00002?GiD0SenE08mOUOl00000SenE0000002?GiGo000000<0SenE00Go000008mOU@2?GiD0
SenEo`00000:0?ooo`?o00000_md8U@01?l0003oM29Dog@RE?l00002og@RE005o`000?nY`>[o0000
o`00000000005P3oool002@0oooo00<000000?ooo`3oool06@3oool2o`000080ZKgX00?o00000:Vm
j02Y_NP00ol000020:VkiP03o`00002Y^nH0ZK_V00;o00000`2UX]801?l00000YJ;B0:FRd_l00002
0:FRdP;o00000P2FL:H01Ol00000UW2V09I`YP2FL:Ko00000080UW2V00Co000009I`YP2FL:Ko0000
0P2FL:H01?l00000UW2V09I`Y_l0000309I`YP03o`00002FL:Ko000000;o000000D0SenEo`00002?
GiD0SenEo`00000308mOU@04o`00002?GiD0SenEo`0000<000000`2?GiD01?l00000SenE08mOUOl0
000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080
SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Ko0000
08mOU@2?GiD0SenEo`00002?GiD3o`000080SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000
SenE08mOU@2?GiGo000000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOU@2?
GiGo000000<0SenE00Go000008mOU@2?GiD0SenEo`00000308mOU@04o`00002?GiD0SenEo`0000<0
SenE00Go000008mOU@000000SenEo`00000408mOU@05o`00002?GiD0SenE08mOUOl000001P3oool3
o`000003og@RE?l0003oM29D00;oM29D00Co0000og@RE?md8UCo00000_md8U@2o`000004ojVmj?l0
0000oooo000000H0oooo0ol000040?ooo`;o00001P3oool002@0oooo00<000000?ooo`3oool06P3o
ool00ol00000ZKgX0:Vmj003o`000080ZK_V00?o00000:VkiP2Y^nH00ol000000`2UX];o00000:FR
dP020:FRdP03o`00002UX]80YJ;B00?o000000D0UW2Vo`00002FL:H0UW2Vo`00000309I`YP04o`00
002FL:H0UW2Vo`000080UW2V00Co000009I`YP2FL:Ko00000`2FL:H00ol00000UW2Vo`000002o`00
000508mOUOl00000SenE08mOUOl000000P2?GiD01_l00000SenE08mOU@2?GiGo000008mOU@800000
0P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo00000`2?GiD01?l0
0000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiD0SenE
o`00000308mOU@05o`00002?GiD0SenEo`00002?GiD01?l000000`2?GiGo000008mOU@0208mOU@04
o`00002?GiD0SenEo`0000<0SenE00Go000008mOU@2?GiD0SenEo`00000308mOU@04o`00002?GiD0
SenEo`0000<0SenE00Go000008mOU@2?GiD0SenEo`00000308mOU@05o`00002?GiD0SenE08mOUOl0
00000`2?GiD01?l00000SenE08mOUOl0000308mOU@06o`00002?GiD0SenE0000002?GiGo00000`2?
GiD01Ol00000SenE08mOU@2?GiGo00000080oooo1?l000001Omd8UCo0000og@RE?md8UCo000000?o
M29D00Go0000og@RE?md8UCo0000og@RE002o`0000;oZKgX0_l000000`000000oooo0?ooo`050?oo
o`03o`00003oool0oooo0080oooo00Co00000?ooo`3ooooo00001@3oool002@0oooo00<000000?oo
o`3oool06`3oool2o`000080ZK_V00?o00000:VkiP2Y^nH00ol000000`2UX];o00000:FRdP020:FR
dP03o`00002UX]80YJ;B00?o000000D0UW2Vo`00002FL:H0UW2Vo`00000209I`YP05o`00002FL:H0
UW2V09I`Y_l000000P2FL:H01?l00000UW2V09I`Y_l0000309I`YP03o`00002FL:Ko000000;o0000
00D0SenEo`00002?GiD0SenEo`00000208mOU@04o`00002?GiD0SenEo`000080SenE0`0000001@2?
GiGo000008mOU@2?GiGo000000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mO
UOl0000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo0000
0080SenE00Ko000008mOU@2?GiD0SenEo`00002?GiD3o`000080SenE00Co000008mOU@2?GiGo0000
0`2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01?l0
0000SenE08mOUOl0000308mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01Ol00000SenE08mO
U@2?GiGo000000<0SenE00Co000008mOU@2?GiGo0000102?GiD01Ol00000SenE08mOU@00003o0000
00<0SenE00?o000008mOUOl000001?l00002og@RE004o`000?md8UCoM29Do`0000;oM29D00Co0000
og@RE?md8UCo00000_md8U@3o`000008ohI5N?l0003o0000o`000?nY_NSo00000?ooo`0000060?oo
o`03o`00003oool0oooo0080oooo00Co00000?ooo`3ooooo00001@3oool002@0oooo00<000000?oo
o`3oool0703oool00ol00000ZK_V0:VkiP03o`0000030:FRd_l00000YJ;B0080YJ;B00?o00000:FR
dP2UX]800ol000001@2FL:Ko000009I`YP2FL:Ko00000080UW2V00Co000009I`YP2FL:Ko00000`2F
L:H01?l00000UW2V09I`Y_l0000309I`YP03o`00002FL:H0UW2V00;o000000D0SenEo`00002?GiD0
SenEo`00000208mOU@04o`00002?GiD0SenEo`000080SenE0`0000001@2?GiGo000008mOU@2?GiGo
00000080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl00000
0P2?GiD01?l00000SenE08mOUOl0000308mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01?l0
0000SenE08mOUOl0000208mOU@?o000000<0SenEo`00002?GiD00P2?GiD01?l00000SenE08mOUOl0
000308mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01?l00000SenE08mOUOl0000308mOU@04
o`00002?GiD0SenEo`0000@0SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOU@2?
GiGo000000<0SenE00Co000008mOU@2?GiGo0000102?GiD01_l00000SenE08mOU@2?GiD0000008mO
U@Co00000P2EKZ@2o`0000?oM29D00Co0000og@RE?md8UCo00000_md8U@00ol0003oM29Dog@RE003
o`000004ohI5N?l0003oQTEhohI5N0;o00000_nY_NP2o`0000030?ooo`000000oooo00@0oooo00?o
00000?ooo`3oool00P3oool01?l00000oooo0?ooool000050?ooo`008`3oool00`000000oooo0?oo
o`0N0?ooo`;o000000<0YJ;Bo`00002UX]800P2UX]800ol00000YJ;B0:FRdP03o`00000509I`Y_l0
0000UW2V09I`Y_l000000P2FL:H01?l00000UW2V09I`Y_l0000309I`YP04o`00002FL:H0UW2Vo`00
00<0UW2V00Go000009I`YP2FL:Ko000009I`YP02o`000080SenE00Co000008mOU@2?GiGo00000P2?
GiD00ol00000SenE08mOU@030000000508mOUOl00000SenE08mOUOl000000P2?GiD01?l00000SenE
08mOUOl0000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000P2?GiD0
1Ol00000SenE08mOU@2?GiGo000000<0SenE00Co000008mOU@2?GiGo00000P2?GiD3o`00000508mO
UOl00000SenE08mOUOl000000`2?GiD01?l00000SenE08mOUOl0000308mOU@05o`00002?GiD0SenE
08mOUOl000000`2?GiD01?l00000SenE08mOUOl0000308mOU@05o`00002?GiD0SenE08mOUOl00000
0`2?GiD01?l00000SenE08mOUOl0000308mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01Ol0
0000SenE08mOU@2?GiGo000000<0SenE00Ko000008mOUOl0003o000000000?l0000209E^Y004o`00
002EKZ@0UFjT09E^Y0;o00000omd8U@00ol0003oM29Do`000003og@RE004o`000?md8UCo0000o`00
00?oQTEh00?o0000ohI5N?n6AGP01?l00002ojVmj003o`0000000000oooo00@0oooo00?o00000?oo
o`3oool00P3oool01?l00000oooo0?ooool000050?ooo`008`3oool00`00003o0000o`00000N0?oo
o`05o`00002UX]80YJ;B0:FRd_l000000P2UX]83o`00000509I`Y_l00000UW2V09I`Y_l000000P2F
L:H01?l00000UW2V09I`Y_l0000309I`YP04o`00002FL:H0UW2Vo`0000<0UW2V00Go000009I`YP2F
L:Ko000009I`YP03o`00000508mOUOl00000SenE08mOUOl000000P2?GiD00ol00000SenE08mOU@03
00000005o`00002?GiD0SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000208mOU@05o`00
002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Go000008mO
U@2?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01?l00000SenEo`00
0?l0000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo0000102?GiD01?l0
0000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Go000008mOU@2?GiD0SenE
o`00000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Go000008mOU@2?GiD0SenEo`00000408mO
U@04o`00002?GiD0SenEo`000080SenE0ol0000209E^Y005o`0000000000UFjT09E^Y?l000000`2E
KZ@2o`0000;oM29D00Go0000og@RE?md8UCo0000og@RE004o`000003ohI5N?l0003oQTEh00;oQTEh
00Ko0000ohI5N?n6AGSo0000ojVmj?l00002ojVmj0?o000000@000000?ooo`3oool0oooo0_l00004
0?ooo`04o`00003oool0ooooo`0000D0oooo000:0?ooo`;o0000103oool00ol00000oooo0?ooo`03
0?ooo`;o00000`3oool3o`0000D0oooo00<000000?ooo`3oool07`3oool00ol00000YJ;B0:FRdP03
o`00000509I`Y_l00000UW2V09I`Y_l000000P2FL:H01?l00000UW2V09I`Y_l0000309I`YP04o`00
002FL:H0UW2Vo`000080UW2V00Ko000009I`YP2FL:H0UW2Vo`00002FL:H3o`00000508mOUOl00000
SenE08mOUOl000000P2?GiD00ol00000SenE08mOU@0300000004o`00002?GiD0SenEo`0000<0SenE
00Co000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Co000008mO
U@2?GiGo00000`2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo0000
0`2?GiD00ol00000SenEo`000002o`00000308mOUOl00000SenE0080SenE00Co000008mOU@2?GiGo
00000`2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Co000008mOU@2?GiGo00000`2?GiD0
1Ol00000SenE08mOU@2?GiGo00000080SenE00Go000008mOU@2?GiD0SenEo`00000308mOU@04o`00
002?GiD0SenEo`0000<0SenE00?o000008mOU@2?GiD00P2?GiD01Ol00000SenE08mOU@2?GiGo0000
0080SenE0ol000000`2EKZCo000009E^Y00209E^Y005o`00002EKZ@0000009E^Y?l00000102EKZ@0
1Ol0003oM29Dog@RE?l0003oM29D00?o00000_n6AGP01?l0003oQTEhohI5N?l00003ohI5N005o`00
0?n6AGSoQTEho`000?nY_NP00ol00002ojVmj003o`00003oool0000000<0oooo00?o00000?ooo`3o
ool00`3oool2o`0000H0oooo00090?ooo`04o`00003oool0ooooo`0000P0oooo00Ko00000?ooo`3o
oooo00000?ooool000030?ooo`03o`00003oool0oooo0080oooo00<000000?ooo`3oool0803oool2
o`00000509I`Y_l00000UW2V09I`Y_l000000P2FL:H01?l00000UW2V09I`Y_l0000309I`YP04o`00
002FL:H0UW2Vo`000080UW2V00Go000009I`YP2FL:Ko000009I`YP04o`00000508mOUOl00000SenE
08mOUOl000000P2?GiD00ol00000SenE08mOU@0300000004o`00002?GiD0SenEo`000080SenE00Go
000008mOU@2?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01?l00000
SenE08mOUOl0000208mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01?l00000SenE08mOUOl0
000208mOU@03o`00002?GiGo000000?o000000D0SenEo`00002?GiD0SenEo`00000308mOU@04o`00
002?GiD0SenEo`0000@0SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl00003
08mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE
00Go000008mOU@2?GiD0SenEo`00000308mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01?l0
0000SenEo`000?l0000309E^Y005o`00002EKZ@0UFjT09E^Y?l000000P2EKZ@00`000000UFjTo`00
000309E^Y0Go000000?oQTEho`000?n6AGP00_n6AGP01?l0003oQTEhohI5N?l00003ohI5N003o`00
0?n6AGSoQTEh00;o00000_nY_NP00ol0003oZKgXojVmj002o`0000030000003oool0oooo00l0oooo
00090?ooo`04o`00003oool0ooooo`0000P0oooo00Co00000?ooo`3ooooo00001@3oool00ol00000
oooo0?ooo`020?ooo`0300000?l00000oooo0200oooo00Co000009I`YP2FL:Ko00000P2FL:H01?l0
0000UW2V09I`Y_l0000309I`YP04o`00002FL:H0UW2Vo`000080UW2V00Go000009I`YP2FL:Ko0000
09I`YP03o`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl000020000
0004o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mO
U@2?GiGo00000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000308mO
U@05o`00002?GiD0SenE08mOUOl000000P2?GiD00ol00000SenEo`000002o`000080SenE00Co0000
08mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Go000008mOU@2?GiD0
SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo
000000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE
00Go000008mOU@2?GiD0SenEo`00000308mOU@03o`00002?GiGo000000?o000000<0UFjTo`00002E
KZ@00`2EKZ@02Ol00000UFjT09E^Y02EKZCo000009E^Y0000000UFjTo`00000309E^Y004o`000?n6
AGSoQTEho`0000;oQTEh00Go0000ohI5N?n6AGSoQTEho`000002ohI5N005o`000?n6AGSoQTEhohI5
N?l000000_n6AGP00ol0003oZKgXojVmj004o`000004ojVmj?l0003o000000000100oooo00090?oo
o`04o`00003oool0ooooo`0000P0oooo00Co00000?ooo`3ooooo00001@3oool00ol00000oooo0?oo
o`020?ooo`030000003oool0oooo0200oooo00Co000009I`YP2FL:Ko00000P2FL:H01Ol00000UW2V
09I`YP2FL:Ko00000080UW2V00Co000009I`YP2FL:Ko00000P2FL:H00ol00000UW2Vo`000002o`00
000308mOUOl00000SenE0080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000000000000000
000208mOU@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000
SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?
GiGo00000080SenE00Ko000008mOU@2?GiD0SenEo`00002?GiD3o`00000308mOUOl00000SenE0080
SenE00Co000008mOU@2?GiGo00000P2?GiD00ol00000SenE08mOU@0208mOU@04o`00002?GiD0SenE
o`0000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE
00Go000008mOU@2?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01Ol0
0000SenE08mOU@2?GiGo000000<0SenE00?o000008mOUOl000000ol0000209E^Y004o`00002EKZ@0
UFjTo`0000@0UFjT00Go000009E^Y02EKZ@0UFjTo`00000209E^Y00300000?l00000UFjT0080UFjT
00Co0000ohI5N?n6AGSo00000_n6AGP01Ol0003oQTEhohI5N?n6AGSo000000;oQTEh00Go0000ohI5
N?n6AGSoQTEho`000002ohI5N0?o00000_nY_NP3o`0000;oZKgX00<000000?ooo`3oool03P3oool0
00T0oooo00Co00000?ooo`3ooooo0000203oool01Ol00000oooo0?ooool00000oooo00Co0000103o
ool00`000000oooo0?ooo`0R0?ooo`03o`00002FL:Ko000000<0UW2V00Co000009I`YP2FL:Ko0000
0P2FL:H01Ol00000UW2V09I`Y_l00000UW2V00?o000000D0SenEo`00002?GiD0SenEo`00000308mO
U@04o`00002?GiD0SenEo`0000<000000P2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?
GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl0000208mO
U@05o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE08mOUOl00000SenE00Co000000D0
SenEo`00002?GiD0SenEo`00000308mOU@04o`00002?GiD0SenEo`000080SenE00?o000008mOU@2?
GiD00P2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Go0000
08mOU@2?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE
08mOU@2?GiGo000000@0SenE00Go000008mOU@2?GiGo000008mOU@04o`000080UFjT00Go000009E^
Y02EKZ@0UFjTo`00000309E^Y005o`00002EKZ@0UFjT09E^Y?l000000`2EKZ@01Ol00000UFjT09E^
Y02EKZ@0000000<0UFjT00Co0000ohI5N?n6AGSo00000_n6AGP01Ol0003oQTEhohI5N?n6AGSo0000
00;oQTEh00Go0000ohI5N?n6AGSoQTEho`000003ohI5N0;o000000CoZKgXo`000?nY_NSo00000_nY
_NP2o`0000030000003oool0oooo00d0oooo00090?ooo`04o`00003oool0ooooo`0000P0oooo00Ko
00000?ooo`3ooooo00000?ooool000070?ooo`0300000?l00000oooo0280oooo00Co000009I`YP2F
L:Ko00000P2FL:H01?l00000UW2V09I`Y_l0000209I`YP03o`00002FL:Ko000000;o000000D0SenE
o`00002?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000`00000208mOU@04o`00
002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl00002
08mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000308mOU@05o`00
002?GiD0SenEo`00002?GiD00ol0000208mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mO
U@2?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01?l00000SenE08mO
UOl0000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Go000008mOU@2?GiD0SenEo`00000208mO
U@05o`00002?GiD0SenE08mOUOl000000`2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00?o
000008mOUOl000000_l0000209E^Y005o`00002EKZ@0UFjT09E^Y?l000000`2EKZ@01Ol00000UFjT
09E^Y02EKZCo000000<0UFjT00Go000009E^Y02EKZ@0UFjTo`00000309E^Y003o`0000000000UFjT
0080UFjT00?o0000ohI5N?l000000_n6AGP01Ol0003oQTEhohI5N?n6AGSo000000;oQTEh00Go0000
ohI5N?n6AGSoQTEho`000003ohI5N0?o00000_nY_NP3o`0000;oZKgX00?o00000000003oool03@3o
ool000X0oooo0_l0000:0?ooo`;o00000P3oool5o`0000<0oooo00<000000?ooo`3oool08P3oool0
1?l00000UW2V09I`Y_l0000209I`YP05o`00002FL:H0UW2Vo`00002FL:H00ol000001@2?GiGo0000
08mOU@2?GiGo00000080SenE00Go000008mOU@2?GiGo000008mOU@0300000080SenE00Co000008mO
U@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`000080SenE
00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl0000208mOU@05o`00002?GiD0SenE
08mOUOl000000P2?GiD2o`00000308mOUOl00000SenE0080SenE00Co000008mOU@2?GiGo00000P2?
GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000
SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Go000008mOU@2?GiD0SenEo`00
000208mOU@05o`00002?GiD0SenE08mOUOl000000`2?GiD01Ol00000SenE08mOU@2?GiGo000000<0
SenE0_l000000`2EKZCo000009E^Y00209E^Y005o`00002EKZ@0UFjT09E^Y?l00000102EKZ@01?l0
0000UFjT09E^Y?l0000409E^Y004o`00002EKZ@0UFjTo`0000@0UFjT00L0000009E^Y02EKZ@0UFjT
o`000?n6AGSo000000;oQTEh00Go0000ohI5N?n6AGSoQTEho`000002ohI5N005o`000?n6AGSoQTEh
ohI5N?l000000on6AGP00ol0003oZKgXo`000002o`000004ojVmj?l0003oZKgXojVmj0;o000000<0
00000?ooo`3oool0303oool00280oooo00<000000?ooo`3oool08P3oool01?l00000UW2V09I`Y_l0
000209I`YP03o`00002FL:Ko000000;o000000D0SenEo`00002?GiD0SenEo`00000208mOU@05o`00
002?GiD0SenEo`00002?GiD00`00000208mOU@04o`00002?GiD0SenEo`000080SenE00Co000008mO
U@2?GiGo00000`2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`000080SenE
00Go000008mOU@2?GiD0SenEo`00000208mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mO
UOl0003o00000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo0000
0`2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Go000008mOU@2?GiD0SenEo`00000208mO
U@05o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Go
000008mOU@2?GiD0SenEo`00000308mOU@04o`00002?GiD0SenEo`0000<0SenE00?o000008mOUOl0
00000_l0000209E^Y005o`00002EKZ@0UFjT09E^Y?l00000102EKZ@01Ol00000UFjT09E^Y02EKZCo
000000<0UFjT00Go000009E^Y02EKZ@0UFjTo`00000209E^Y003o`00002EKZ@0UFjT0080UFjT00?o
000000000?l000000_l000001On6AGSo0000ohI5N?n6AGSo000000?oQTEh00Go0000ohI5N?n6AGSo
QTEho`000002ohI5N004o`000?n6AGSoQTEhohI5N0;o000000CoZKgXo`000?nY_NSoZKgX0ol00002
ojVmj003o`0000000000oooo00`0oooo000R0?ooo`0300000?l00000oooo0280oooo00Go000009I`
YP2FL:Ko000009I`YP03o`00000508mOUOl00000SenE08mOUOl000000P2?GiD01Ol00000SenE08mO
UOl00000SenE00<0000000<0SenEo`00002?GiD00P2?GiD01?l00000SenE08mOUOl0000208mOU@05
o`00002?GiD0SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0
SenEo`0000<0SenE00Co000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOUOl00000SenE00Co
000000D0SenEo`00002?GiD0SenEo`00000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Co0000
08mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`0000<0
SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Go0000
08mOU@2?GiD0SenEo`00000208mOU@03o`00002?GiGo000000?o00000P2EKZ@01Ol00000UFjT09E^
Y02EKZCo000000<0UFjT00Go000009E^Y02EKZ@0UFjTo`00000309E^Y005o`00002EKZ@0UFjT09E^
Y?l000000`2EKZ@01Ol00000UFjT09E^Y02EKZCo00000080UFjT0ol000001@00003oXIO;o`000?n6
AGSo000000;oQTEh00Go0000ohI5N?n6AGSoQTEho`000003ohI5N004o`000?n6AGSoQTEho`0000?o
QTEh00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00;o000000<000000?ooo`3o
ool02P3oool00280oooo00<000000?ooo`3oool08`3oool4o`00000508mOUOl00000SenE08mOUOl0
00000P2?GiD01?l00000SenE08mOUOl0000208mOU@80000000D0SenEo`00002?GiD0SenEo`000003
08mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@04o`00
002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl00002
08mOU@03o`00002?GiGo000000;o00000P2?GiD01?l00000SenE08mOUOl0000208mOU@05o`00002?
GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Go000008mOU@2?
GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?
GiGo00000080SenE00Go000008mOU@2?GiD0SenEo`00000308mOU@05o`00002?GiD0SenE08mOUOl0
00000`2?GiD00ol00000SenEo`000002o`000080UFjT00Go000009E^Y02EKZ@0UFjTo`00000309E^
Y005o`00002EKZ@0UFjT09E^Y?l000000`2EKZ@01Ol00000UFjT09E^Y02EKZCo000000<0UFjT00Go
000009E^Y02EKZ@0UFjTo`00000309E^Y0?o000000CoXIO;o`000?nQUl/000000_nQUl/2o`0000?o
QTEh00Co0000ohI5N?n6AGSo00000on6AGP01?l0003oQTEhohI5N?l00003ohI5N0?o000000CoZKgX
o`000?nY_NSoZKgX1?l000000onY_NSo00000000000<0?ooo`008@3oool00`000000oooo0?ooo`0T
0?ooo`03o`00002?GiGo00000080SenE00Co000008mOU@2?GiGo00000P2?GiD00ol00000SenE08mO
U@0300000004o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@04
o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0
000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD00ol00000SenEo`000002o`00000308mO
UOl00000SenE0080SenE00Co000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo0000
0080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?
GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@03
o`00002?GiD0SenE0080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@03o`00002?GiGo0000
00?o000000<0UFjTo`00002EKZ@00P2EKZ@01Ol00000UFjT09E^Y02EKZCo000000<0UFjT00Go0000
09E^Y02EKZ@0UFjTo`00000309E^Y005o`00002EKZ@0UFjT09E^Y?l000000`2EKZ@00ol00000UFjT
09E^Y00209E^Y004o`00002EKZCo0000o`0000CoXIO;00Co0000oj6Gb`00003oXIO;0_l00003ohI5
N004o`000?n6AGSoQTEho`0000?oQTEh00Co0000ohI5N?n6AGSo00000on6AGP2o`0000;oZKgX0ol0
0002ojVmj003o`000?nY_NSoZKgX00;o000000<000000?ooo`3oool02@3oool00240oooo00<00000
o`00003oool0903oool00ol00000SenEo`00000208mOU@04o`00002?GiD0SenEo`000080SenE0`00
00001?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?
GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo00000P2?
GiD01?l00000SenE08mOUOl0000308mOU@03o`00002?GiGo000000;o000000D0SenEo`00002?GiD0
SenEo`00000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000P2?GiD0
1Ol00000SenE08mOU@2?GiGo00000080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@05o`00
002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Go000008mO
U@2?GiD0SenEo`00000308mOU@03o`00002?GiGo000000;o00000P2EKZ@01?l00000UFjT09E^Y?l0
000309E^Y003o`00002EKZ@0UFjT0080UFjT00Co000009E^Y02EKZCo00000`2EKZ@01Ol00000UFjT
09E^Y02EKZCo000000@0UFjT00Ko000009E^Y02EKZ@0UFjTo`00002EKZ@4o`000003oj6Gbol0003o
XIO;00?oXIO;00Co0000oj6GbonQUl/000000_l00003ohI5N004o`000?n6AGSoQTEho`0000?oQTEh
00Go0000ohI5N?n6AGSo0000ohI5N006o`0000;oZKgX00?o0000ojVmj?nY_NP00ol000001?nY_NSo
00000?ooo`00000:0?ooo`008@3oool00`000000oooo0?ooo`0T0?ooo`03o`00002?GiGo00000080
SenE00?o000008mOU@2?GiD00`0000001?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenE
o`000080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@04o`00002?GiD0SenEo`0000<0SenE
00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000208mOU@03o`00002?GiGo0000
00?o000000D0SenEo`00002?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?
GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000
SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl0
000408mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiD0SenE0_l000000`2EKZCo
000009E^Y00209E^Y005o`00002EKZ@0UFjT09E^Y?l000000`2EKZ@01Ol00000UFjT09E^Y02EKZCo
000000<0UFjT00Co000009E^Y02EKZCo0000102EKZ@01_l00000UFjT09E^Y02EKZCo000009E^Y0Co
00000_nQUl/01Ol0003oXIO;oj6GbonQUl_o000000?oXIO;00Ko0000oj6GbonQUl_o000000000?l0
0003ohI5N004o`000?n6AGSoQTEho`0000?oQTEh00?o0000ohI5N?l000000_l00002ohE4N003o`00
0?nY_NSo000000;oZKgX1?l000001?nY_NSo0000ojVmj?nY_NP2o`0000030000003oool0oooo00P0
oooo000Q0?ooo`030000003oool0oooo02@0oooo00?o000008mOUOl000000P2?GiD300000004o`00
002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo
00000080SenE00Co000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE
00Co000008mOU@2?GiGo00000P2?GiD00ol00000SenEo`000002o`000080SenE00Co000008mOU@2?
GiGo00000P2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Co
000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Co000008mOU@2?
GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Go000008mOU@2?GiD0SenEo`00
000208mOU@06o`00002?GiD0SenE08mOUOl00000SenE0ol0000209E^Y005o`00002EKZ@0UFjT09E^
Y?l000000`2EKZ@01Ol00000UFjT09E^Y02EKZCo000000<0UFjT00Go000009E^Y02EKZ@0UFjTo`00
000209E^Y003o`00002EKZ@0UFjT0080UFjT00?o000009E^Y?l000000ol00002oj6Gb`05o`000?nQ
Ul_oXIO;oj6Gbol000000onQUl/00ol0003oXIO;oj6Gb`04o`000004ojFjj000003oYK[Xo`0000;o
QTEh00Co0000ohI5N?n6AGSo00000on6AGP2o`000003ohE4N?l0003oQDAh00;oQDAh00?o0000ojVm
j?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0000000000?ooo`080?oo
o`008@3oool00`00003o00000?ooo`0T0?ooo`03o`00002?GiD000000080000000Co000008mOU@2?
GiGo00000P2?GiD01?l00000SenE08mOUOl0000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?
GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?
GiGo00000P2?GiD00ol00000SenEo`000002o`00000308mOUOl00000SenE0080SenE00Co000008mO
U@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`0000<0SenE
00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenE
o`000080SenE00?o000008mOU@2?GiD00P2?GiD01?l00000SenE08mOUOl0000308mOU@05o`00002?
GiD0SenEo`00002?GiD01?l0000209E^Y004o`00002EKZ@0UFjTo`0000@0UFjT00Co000009E^Y02E
KZCo00000`2EKZ@01Ol00000UFjT09E^Y02EKZCo000000<0UFjT00Go000009E^Y02EKZ@0UFjTo`00
000209E^Y0?o00000_nQUl/00ol0003oXIO;oj6Gb`02oj6Gb`06o`000?nQUl_oXIO;oj6Gbol0003o
XIO;1?l00003ojFjj004o`000?nU^^SoYK[X000000;o000000KoQTEho`000?n6AGSoQTEho`000?n6
AGP3o`0000;oQDAh00Co0000ohE4N?n5A7SoQDAh0_l00002ojVmj003o`000?nY_NSoZKgX00?o0000
00CoZKgXo`000?nY_NSoZKgX0ol000000`000000oooo0?ooo`060?ooo`000P3oool2o`0000@0oooo
00?o00000?ooo`3oool00`3oool2o`0000@0oooo00?o00000?ooo`3oool00P3oool3o`0000D0oooo
00<000000?ooo`3oool08`3oool300000004o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?
GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo00000P2?
GiD01?l00000SenE08mOUOl0000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD00ol00000
SenEo`000002o`00000508mOUOl00000SenE08mOUOl000000`2?GiD01?l00000SenE08mOUOl00002
08mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000308mOU@05o`00
002?GiD0SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenE
o`0000<0SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@06o`00002?GiD0SenE08mOUOl00000
SenE0ol0000209E^Y005o`00002EKZ@0UFjT09E^Y?l000000`2EKZ@01Ol00000UFjT09E^Y02EKZCo
000000<0UFjT00Co000009E^Y02EKZCo00000`2EKZ@01Ol00000UFjT09E^Y02EKZCo000000<0UFjT
0ol000000onQUl_o0000oj6Gb`03oj6Gb`05o`000?nQUl_oXIO;oj6Gbol000000_nQUl/3o`0000;o
YK[X00?o0000ojFjj?nU^^P00_nU^^P3o`000006ojG2kP00003o0000ohI5N?l0003oQTEh0ol00002
ohE4N004o`000?n5A7SoQDAho`0000?oQDAh00?o0000ojVmj?nY_NP01?l000001?nY_NSo0000ojVm
j?nY_NP3o`0000;oZKgX00?o00000000003oool01`3oool000050?ooool00000oooo0?ooool00000
203oool01?l00000oooo0?ooool000030?ooo`05o`00003oool0oooo0?ooool000000`3oool01Ol0
0000oooo0?ooo`3oool0000002@0oooo0P000000103ooooo000008mOUOl0000208mOU@04o`00002?
GiD0SenEo`000080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@04o`00002?GiD0SenEo`00
0080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000308mOU@03o`00002?
GiGo000000;o000000D0SenEo`00002?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl0
00000P2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`000080SenE00Go0000
08mOU@2?GiD0SenEo`00000308mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiD0
SenEo`00000308mOU@04o`00002?GiD0SenEo`0000<0SenE00Go000008mOU@2?GiGo000008mOU@04
o`000003oiE^Y?l00000UFjT0080UFjT00Go000009E^Y02EKZ@0UFjTo`00000309E^Y005o`00002E
KZ@0UFjT09E^Y?l000000`2EKZ@01?l00000UFjT09E^Y?l0000409E^Y006o`00002EKZ@0UFjT09E^
Y?l00000UFjT0_l00004oj6Gb`05o`000?nQUl_oXIO;oj6Gbol000000onQUl/3o`000003ojFjj?l0
003oYK[X00?oYK[X00Ko0000ojFjj?l0003o0000ojG2k_l00003ojG2kP0600000?l0003o0000o`00
0?n5A7So00000on5A7P01?l0003oQDAhohE4N?l00003ohE4N0?o00000_nY_NP00ol0003oZKgXojVm
j003o`000003ojVmj?l0003o000000;o000000<0oooo0000003oool01`3oool000050?ooool00000
oooo0?ooool00000203oool01?l00000oooo0?ooool000040?ooo`03o`00003oool0oooo00@0oooo
00Ko00000?ooo`3oool0oooo00000?l0000P0?ooo`<000000`3oool00ol00000SenEo`00000208mO
U@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mO
UOl0000208mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiGo000008mOU@04o`00
000508mOUOl00000SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?
GiD0SenEo`000080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@04o`00002?GiD0SenEo`00
00<0SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@04o`00002?GiD0SenEo`0000<0SenE00Go
000008mOU@2?GiD0SenEo`00000208mOU@06o`00002?GiD0SenE08mOUOl00000SenE0ol00002oiE^
Y004o`000?nEKZCoUFjTo`0000<0UFjT00?o000009E^Y02EKZ@00P2EKZ@01?l00000UFjT09E^Y?l0
000309E^Y005o`00002EKZ@0UFjT09E^Y?l000000`2EKZ@01_l00000UFjT09E^Y02EKZCo000009E^
Y0Co000000?oXIO;o`000?nQUl/00onQUl/01_l0003oXIO;oj6GbonQUl_o0000oj6Gb`;o000000?o
YK[Xo`000?nU^^P00_nU^^P00ol0003oYK[XojFjj003o`0000CoYL;^0ol000000`00003o0000o`00
0002ohE4N005o`000?n5A7SoQDAhohE4N?l000000_n5A7P01ol0003oQDAhohE4N?n5A7So0000ojVm
j?l000000_nY_NP3o`000004ojVmj?l0003o0000o`0000D0oooo00<000000?ooo`3oool01P3oool0
00050?ooool00000oooo0?ooool00000203oool01?l00000oooo0?ooool000040?ooo`03o`00003o
ool0oooo00@0oooo00Go00000?ooo`3oool0oooo0000000N0?ooo`<000001P3oool00ol00000SenE
o`00000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000208mO
U@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD00ol00000SenEo`00
0002o`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000208mOU@05
o`00002?GiD0SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0
SenEo`0000<0SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl0000208mOU@05
o`00002?GiD0SenE08mOUOl000000`2?GiD01Ol00000SenE08mOUOl00000SenE00Co000000?oUFjT
o`000?nEKZ@00_nEKZ@01?l0003oUFjToiE^Y?l0000409E^Y005o`00002EKZ@0UFjT09E^Y?l00000
0P2EKZ@01Ol00000UFjT09E^Y02EKZCo000000<0UFjT00Ko000009E^Y02EKZ@0UFjTo`00002EKZ@4
o`0000;oXIO;00Go0000oj6GbonQUl_oXIO;o`000003oj6Gb`03o`000?nQUl_oXIO;00?o00001?nU
^^P00ol0003oYK[Xo`000003o`0000?oYL;^00?o0000ojG2k_nU`^h00_l00003ojG3kP0500000?l0
003oQDAhohE4N?l000000on5A7P01?l0003oQDAhohE4N?l00003ohE4N0Go000000CoZKgXo`000?l0
003o0000203oool00`000000oooo0?ooo`060?ooo`0000D0ooooo`00003oool0ooooo`0000080?oo
o`04o`00003oool0ooooo`0000D0oooo00?o00000?ooool000000ol000040?ooo`030000003oool0
oooo01T0oooo0`0000090?ooo`03o`00002?GiGo000000<0SenE00Co000008mOU@2?GiGo00000P2?
GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?
GiGo00000P2?GiD2o`00000308mOUOl00000SenE0080SenE00Co000008mOU@2?GiGo00000P2?GiD0
1?l00000SenE08mOUOl0000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01?l00000SenE
08mOUOl0000308mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl00003
08mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000`2?GiD00ol00000SenE
o`000002o`0000;oUFjT00Co0000oiE^Y?nEKZCo00000onEKZ@01Ol0003oUFjToiE^Y?nEKZCo0000
00<0UFjT00Go000009E^Y02EKZ@0UFjTo`00000209E^Y003o`00002EKZ@0UFjT0080UFjT00Ko0000
09E^Y02EKZ@0UFjTo`00002EKZ@3o`0000;oXIO;00?o0000oj6GbonQUl/00_nQUl/01?l0003oXIO;
oj6Gbol00002oj6Gb`Co00000onU^^P00ol0003oYK[XojFjj003o`0000?oYL;^00?o0000ojG2k_nU
`^h01?l00002ojG3kP08o`000?nU`nkoYL?^o`000000003o0000ohE4N?l00003ohE4N004o`000?n5
A7SoQDAho`0000?oQDAh00?o0000ojVmj?nY_NP00ol0000<0?ooo`030000003oool0oooo00D0oooo
00001@3ooooo00000?ooo`3ooooo000000P0oooo00Ko00000?ooo`3ooooo00000?ooool000030?oo
o`03o`00003ooooo000000L0oooo00<00000o`00003oool05P3oool3000000`0oooo00Co000008mO
U@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`000080SenE
00Co000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOUOl00000SenE00;o00000P2?GiD01Ol0
0000SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mO
UOl0000308mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiD0SenEo`00000308mO
U@04o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@05o`00002?
GiD0SenE08mOUOl000000P2?GiD00ol00000SenE08mOU@03o`000003oiE^Y?l0003oUFjT00;oUFjT
00Co0000oiE^Y?nEKZCo00001?nEKZ@01?l0003oUFjToiE^Y?l0000309E^Y005o`00002EKZ@0UFjT
09E^Y?l000000`2EKZ@01_l00000UFjT09E^Y02EKZCo000009E^Y0Co000000?oXIO;o`000?nQUl/0
0onQUl/01Ol0003oXIO;oj6GbonQUl_o000000;oXIO;0ol00003ojFjj003o`000?nU^^SoYK[X00Co
00000_nU`^h00ol0003oYL;^ojG2kP04o`0000;oYL?^00?o0000ojG3k_nU`nh01?l00002ojG3k`03
00000?n5A7So000000?oQDAh00Co0000ohE4N?n5A7So00000on5A7P3o`0000l0oooo00<000000?oo
o`3oool01@3oool00080oooo0_l0000:0?ooo`;o00000P3oool5o`0000030?ooool0003o000000?o
00000`3oool00`000000oooo0?ooo`0C0?ooo`<000003`3oool01?l00000SenE08mOUOl0000208mO
U@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mO
UOl0000208mOU@03o`00002?GiGo000000;o000000D0SenEo`00002?GiD0SenEo`00000308mOU@04
o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?
GiGo00000080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl0
00000P2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`0000<0SenE00?o0000
08mOU@2?GiD00ol000001OnEKZCo0000oiE^Y?nEKZCo000000?oUFjT00Go0000oiE^Y?nEKZCoUFjT
o`000003oiE^Y004o`000?nEKZCoUFjTo`0000<0UFjT00Go000009E^Y02EKZ@0UFjTo`00000309E^
Y003o`00002EKZCo000000?o00000_nQUl/01Ol0003oXIO;oj6GbonQUl_o000000?oXIO;00?o0000
oj6GbonQUl/01?l00002ojFjj003o`000?nU^^SoYK[X00Co00000_nU`^h00ol0003oYL;^ojG2kP04
o`0000;oYL?^00?o0000ojG3k_nU`nh01?l00003ojG3k`04o`000?nU`nooYL?_000000;o00000on5
A7P01Ol0003oQDAhohE4N?n5A7So000000;oQDAh00?o00000?ooo`3oool03`3oool00`000000oooo
0?ooo`050?ooo`007`3oool00`000000oooo0?ooo`0A0?ooo`<000004P3oool01?l00000SenE08mO
UOl0000208mOU@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01Ol0
0000SenE08mOUOl00000SenE00?o000000D0SenEo`00002?GiD0SenEo`00000208mOU@05o`00002?
GiD0SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`00
00<0SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@04o`00002?GiD0SenEo`0000<0SenE00Co
000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl0000208mOU@06o`00002?GiD0SenE08mO
UOl00000SenE0_l00003oiE^Y004o`000?nEKZCoUFjTo`0000CoUFjT00Co0000oiE^Y?nEKZCo0000
0onEKZ@01?l0003oUFjToiE^Y?l0000309E^Y003o`00002EKZ@0UFjT0080UFjT00?o000009E^Y?l0
00000_l00002oj6Gb`05o`000?nQUl_oXIO;oj6Gbol000000onQUl/00ol0003oXIO;oj6Gb`04o`00
00;oYK[X00?o0000ojFjj?nU^^P01?l00002ojG2kP03o`000?nU`^koYL;^00Co00000onU`nh00ol0
003oYL?^ojG3kP03o`0000?oYL?_00?o0000ojG3konU`nl01?l000000onU`nl00000o`000003ohE4
N005o`000?n5A7SoQDAhohE4N?l000000_n5A7P00ol00000oooo0?ooo`0?0?ooo`030000003oool0
oooo00D0oooo000O0?ooo`030000003oool0oooo00l0oooo0P00000E0?ooo`04o`00002?GiD0SenE
o`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000208mOU@03o`00
002?GiGo000000;o000000D0SenEo`00002?GiD0SenEo`00000208mOU@04o`00002?GiD0SenEo`00
00<0SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000208mOU@03o`00002?
GiD0SenE0080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000308mOU@04
o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000P2?GiD00ol00000SenEo`000003
o`000003oiE^Y?l0003oUFjT00;oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000003oiE^Y004o`000?nE
KZCoUFjTo`0000?oUFjT00Co0000oiE^Y?nEKZCo0000102EKZ@01?l00000UFjT09E^Y02EKZ@2o`00
0003oj6Gbol0003oXIO;00?oXIO;00Ko0000oj6GbonQUl_oXIO;o`000?nQUl/4o`0000;oYK[X00Co
0000ojFjj?nU^^SoYK[X0ol00003ojG2kP03o`000?nU`^koYL;^00?o00000onU`nh00ol0003oYL?^
ojG3kP04o`0000;oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`06o`000?nU`nooYL?_o`000000
003o00000_n5A7P01Ol0003oQDAhohE4N?n5A7So000000;oQDAh00?o00000?ooo`3oool03`3oool0
0`000000oooo0?ooo`050?ooo`007`3oool00`00003o00000?ooo`0<0?ooo`<000005`3oool01?l0
0000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiGo0000
08mOU@03o`00000508mOUOl00000SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000208mO
U@05o`00002?GiD0SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000208mOU@05o`00002?
GiD0SenE08mOUOl000000`2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`00
00<0SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOUOl00000SenE00?o00000_nE
KZ@01?l0003oUFjToiE^Y?l00004oiE^Y004o`000?nEKZCoUFjTo`0000?oUFjT00Co0000oiE^Y?nE
KZCo00000onEKZ@01Ol0003oUFjToiE^Y?nEKZCo000000<0UFjT00?o000009E^Y?l000000_l00003
oj6Gb`05o`000?nQUl_oXIO;oj6Gbol000000_nQUl/3o`0000;oYK[X00?o0000ojFjj?nU^^P00_nU
^^P01Ol0003oYK[Xo`000?nU`^ko000000CoYL;^0ol00002ojG3kP03o`000?nU`nkoYL?^00Co0000
0_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l000000onU`nl00000
o`000002ohE4N005o`000?n5A7SoQDAhohE4N?l000000_n5A7P00ol00000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00D0oooo000O0?ooo`030000003oool0oooo00T0oooo0`00000J0?ooo`04o`00
002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD00ol00000SenEo`000002o`00
000508mOUOl00000SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?
GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo0000
0080SenE00Go000008mOU@2?GiD0SenEo`00000208mOU@04o`00002?GiD0SenEo`0000<0SenE00Co
000008mOU@2?GiGo00000P2?GiD01_l00000SenE08mOU@2?GiGo000008mOU@?o000000?oUFjTo`00
0?nEKZ@00_nEKZ@01Ol0003oUFjToiE^Y?nEKZCo000000?oUFjT00Co0000oiE^Y?nEKZCo00000onE
KZ@01?l0003oUFjToiE^Y?l00004oiE^Y005o`000?nEKZCoUFjTo`00002EKZ@01?l00002oj6Gb`05
o`000?nQUl_oXIO;oj6Gbol000000onQUl/01Ol0003oXIO;o`000?nU^^So000000CoYK[X00?o0000
ojFjj?nU^^P00ol00003ojG2kP06o`000?nU`^ko0000o`000?nU`nko00000onU`nh3o`0000;oYL?_
00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl01ol0003oYL?_
ojG3k`00003o0000ohE4N?l000000on5A7P01?l0003oQDAhohE4N?l0000A0?ooo`030000003oool0
oooo00D0oooo000O0?ooo`030000003oool0oooo00H0oooo0`00000M0?ooo`04o`00002?GiD0SenE
o`000080SenE00Go000008mOU@2?GiGo000008mOU@03o`00000508mOUOl00000SenE08mOUOl00000
0P2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mO
U@2?GiD0SenEo`00000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01?l00000SenE08mO
UOl0000308mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiD0SenEo`00000208mO
U@05o`00002?GiD0SenEo`00002?GiD01?l000001OnEKZCo0000oiE^Y?nEKZCo000000?oUFjT00Go
0000oiE^Y?nEKZCoUFjTo`000003oiE^Y004o`000?nEKZCoUFjTo`0000?oUFjT00Go0000oiE^Y?nE
KZCoUFjTo`000003oiE^Y003o`000?nEKZCo000000;o00000_nQUl/01Ol0003oXIO;oj6GbonQUl_o
000000?oXIO;00?o0000oj6GbonQUl/00ol00003ojFjj003o`000?nU^^SoYK[X00Co00000_nU`^h0
0ol0003oYL;^ojG2kP03o`0000CoYL?^0ol000000onU`noo0000ojG3k`02ojG3k`?o00000onU`nl0
0ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l000001?nU`nl00000o`000?l0
0003ohE4N004o`000?n5A7SoQDAho`000180oooo00<000000?ooo`3oool0103oool001l0oooo00<0
0000o`00003oool00`3oool300000200oooo00Co000008mOU@2?GiGo00000P2?GiD00ol00000SenE
o`000002o`00000508mOUOl00000SenE08mOUOl000000P2?GiD01?l00000SenE08mOUOl0000208mO
U@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mO
U@2?GiGo00000080SenE00Co000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo0000
0080SenE00Co000008mOU@2?GiGo00000`2?GiD01Ol00000SenE08mOUOl00000SenE00?o00000_nE
KZ@01?l0003oUFjToiE^Y?l00002oiE^Y003o`000?nEKZCoUFjT00;oUFjT00Co0000oiE^Y?nEKZCo
00000onEKZ@01?l0003oUFjToiE^Y?l00004oiE^Y005o`000?nEKZCoUFjTo`000?nEKZ@01?l00000
0onQUl_o0000oj6Gb`03oj6Gb`06o`000?nQUl_oXIO;oj6Gbol0003oXIO;1?l00003ojFjj003o`00
0?nU^^SoYK[X00?o00000onU`^h00ol0003oYL;^ojG2kP03o`0000?oYL?^00?o0000ojG3k_nU`nh0
0_l00004ojG3k`03o`000?nU`noo000000;oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03o`00
0?nU`nooYL?_00Co00000_nU`nl01_l0003oYL?_ojG3kol000000000o`0000?oQDAh00Co0000ohE4
N?n5A7So00004P3oool00`000000oooo0?ooo`040?ooo`007P3oool010000000oooo0?ooo`3oool3
000002<0oooo00Go000008mOU@2?GiGo000008mOU@03o`00000508mOUOl00000SenE08mOUOl00000
0P2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`000080SenE00Co000008mO
U@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo000000<0SenE00Co000008mOU@2?GiGo0000
0P2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`000080SenE00Ko000008mO
U@2?GiD0SenEo`00002?GiD3o`000003oiE^Y?l0003oUFjT00;oUFjT00Co0000oiE^Y?nEKZCo0000
0onEKZ@01Ol0003oUFjToiE^Y?nEKZCo000000;oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000003oiE^
Y006o`000?nEKZCoUFjToiE^Y?l0003oUFjT0ol00002oj6Gb`05o`000?nQUl_oXIO;oj6Gbol00000
0onQUl/00ol0003oXIO;oj6Gb`03o`0000?oYK[X00?o0000ojFjj?nU^^P01?l00002ojG2kP03o`00
0?nU`^koYL;^00Co00000_nU`nh00ol0003oYL?^ojG3kP04o`0000;oYL?_00?o0000ojG3konU`nl0
0ol00003ojG3k`?o00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl0
1?l000000onU`nh00000o`000003ohE4N004o`000?n5A7So0000o`000180oooo00<000000?ooo`3o
ool0103oool001h0oooo1000000V0?ooo`03o`00002?GiGo000000;o000000D0SenEo`00002?GiD0
SenEo`00000208mOU@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD0
1?l00000SenE08mOUOl0000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01Ol00000SenE
08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo
00000080SenE00Go000008mOU@2?GiGo000008mOU@04o`000005oiE^Y?l0003oUFjToiE^Y?l00000
0onEKZ@01Ol0003oUFjToiE^Y?nEKZCo000000;oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000002oiE^
Y003o`000?nEKZCoUFjT00;oUFjT00Go0000oiE^Y?nEKZCo0000oiE^Y004o`000003oj6Gbol0003o
XIO;00?oXIO;00Co0000oj6GbonQUl_o00000_nQUl/4o`0000;oYK[X00?o0000ojFjj?nU^^P01?l0
0002ojG2kP03o`000?nU`^koYL;^00Co00000_nU`nh00ol0003oYL?^ojG3kP04o`0000;oYL?_00?o
0000ojG3konU`nl01?l00002ojG3k`06o`000?nU`noo0000o`000?nU`noo00000onU`nl3o`0000?o
YL?_00?o0000ojG3konU`nl00ol00003ojG3kP04o`000?nU`nkoYL?^000000Go000000?oN2UKo`00
003oool04@3oool00`000000oooo0?ooo`040?ooo`007P3oool00`00003o00000?ooo`0W0?ooo`;o
000000D0SenEo`00002?GiD0SenEo`00000208mOU@04o`00002?GiD0SenEo`000080SenE00Co0000
08mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`0000<0
SenE00Co000008mOU@2?GiGo00000`2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0
SenEo`0000<0SenE00Go000008mOU@2?GiGo000008mOU@03o`0000;oUFjT00Co0000oiE^Y?nEKZCo
00000_nEKZ@01Ol0003oUFjToiE^Y?nEKZCo000000?oUFjT00Co0000oiE^Y?nEKZCo00000onEKZ@0
1Ol0003oUFjToiE^Y?nEKZCo000000?oUFjT00?o0000oiE^Y?l000000_l00002oj6Gb`05o`000?nQ
Ul_oXIO;oj6Gbol000000onQUl/00ol0003oXIO;oj6Gb`03o`0000?oYK[X00?o0000ojFjj?nU^^P0
0ol00003ojG2kP03o`000?nU`^koYL;^00?o00000onU`nh00ol0003oYL?^ojG3kP03o`0000?oYL?_
00?o0000ojG3konU`nl00ol00003ojG3k`03o`000?nU`nooYL?_00;o00001?nU`nl00ol0003oYL?_
o`000002ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nh00ol0003oYL?^ojG3kP04o`000005ojG3
k`00003o0000ogPYFol000000_mh:E/00ol00000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0
oooo000P0?ooo`03o`00003oool0oooo02D0oooo00Co000008mOU@2?GiGo00000P2?GiD01?l00000
SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?
GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?
GiD0SenEo`00000208mOU@04o`00002?GiD0SenEo`000080SenE00Ko000008mOU@2?GiD0SenEo`00
002?GiD3o`000003oiE^Y?l0003oUFjT00;oUFjT00Co0000oiE^Y?nEKZCo00000onEKZ@01?l0003o
UFjToiE^Y?l00003oiE^Y004o`000?nEKZCoUFjTo`0000?oUFjT00Ko0000oiE^Y?nEKZCoUFjTo`00
0?nEKZ@4o`000003oj6Gbol0003oXIO;00?oXIO;00Co0000oj6GbonQUl_o00000_nQUl/4o`0000;o
YK[X00?o0000ojFjj?nU^^P01?l00002ojG2kP03o`000?nU`^koYL;^00Co00000_nU`nh00ol0003o
YL?^ojG3kP04o`0000;oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_00Co
00000_nU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_0ol00002ojG3kP03o`000?nU`nkoYL?^00Co
00000_nU`nl01Ol0003oYL?_ojG3kol00000000000;o00000_mh:E/00ol00000oooo0?ooo`0@0?oo
o`030000003oool0oooo00@0oooo000Q0?ooo`03o`00003oool0oooo02@0oooo00Co000008mOU@2?
GiGo00000P2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`000080SenE00Co
000008mOU@2?GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?
GiGo00000P2?GiD01Ol00000SenE08mOU@2?GiGo00000080SenE00Co000008mOU@2?GiGo00000P2?
GiD00ol00000SenEo`000003o`000005oiE^Y?l0003oUFjToiE^Y?l000000onEKZ@01Ol0003oUFjT
oiE^Y?nEKZCo000000;oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000002oiE^Y004o`000?nEKZCoUFjT
o`0000CoUFjT00?o0000oiE^Y?l000000_l00002oj6Gb`05o`000?nQUl_oXIO;oj6Gbol000000onQ
Ul/00ol0003oXIO;oj6Gb`03o`0000;oYK[X00Co0000ojFjj?nU^^SoYK[X0ol00002ojG2kP03o`00
0?nU`^koYL;^00Co00000_nU`nh00ol0003oYL?^ojG3kP04o`0000;oYL?_00?o0000ojG3konU`nl0
1?l00002ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_
00Co0000ojG3kol0003o00000_nU`nh00ol0003oYL?^ojG3kP03o`0000;oYL?_00?o0000ojG3konU
`nl01?l000001?nU`nl00000o`000?l00002ogPYF`03o`00003oool0oooo0100oooo00<000000?oo
o`3oool0103oool00280oooo00?o00000?ooo`3oool08`3oool01?l00000SenE08mOUOl0000208mO
U@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mO
UOl0000308mOU@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01Ol0
0000SenE08mOU@2?GiGo00000080SenE00Go000008mOU@2?GiGo000008mOU@03o`0000;oUFjT00Co
0000oiE^Y?nEKZCo00000_nEKZ@01Ol0003oUFjToiE^Y?nEKZCo000000?oUFjT00Co0000oiE^Y?nE
KZCo00000onEKZ@01?l0003oUFjToiE^Y?l00003oiE^Y004o`000?nEKZCoUFjToiE^Y0;o000000?o
XIO;o`000?nQUl/00onQUl/01?l0003oXIO;oj6Gbol00002oj6Gb`Co000000?oYK[Xo`000?nU^^P0
0onU^^P00ol0003oYK[Xo`000002ojG2kP03o`000?nU`^koYL;^00?o00000onU`nh00ol0003oYL?^
ojG3kP03o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`03o`000?nU`nooYL?_00?o0000
0onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl00_l00004ojG3kP?o0000
0_nU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00Go0000ojG3konU`nl00000o`000002ogPYF`03
o`00003oool0oooo0140oooo00<000000?ooo`3oool00`3oool002<0oooo0_l0000S0?ooo`04o`00
002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl00002
08mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE
08mOUOl0000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD00ol00000SenE08mOU@02o`00
0003oiE^Y?l0003oUFjT00;oUFjT00Co0000oiE^Y?nEKZCo00000onEKZ@01?l0003oUFjToiE^Y?l0
0003oiE^Y004o`000?nEKZCoUFjTo`0000?oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000002oiE^Y003
o`000?nEKZCo000000;o00000onQUl/01Ol0003oXIO;oj6GbonQUl_o000000;oXIO;0ol00002ojFj
j005o`000?nU^^SoYK[XojFjj?l000000_nU^^P3o`0000?oYL;^0ol00002ojG3kP03o`000?nU`nko
YL?^00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l00002
ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?^00Ko0000
ojG3k_l0003o0000ojG3kol00002ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`04o`000005oj?<
m@00003o0000ogPYFol000004`3oool00`000000oooo0?ooo`030?ooo`009@3oool00ol00000oooo
0?ooo`0P0?ooo`04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l0
0000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo0000
0P2?GiD01?l00000SenE08mOUOl0000208mOU@05o`00002?GiD0SenE08mOUOl000000P2?GiD01?l0
0000SenEo`000?l00002oiE^Y005o`000?nEKZCoUFjToiE^Y?l000000onEKZ@01?l0003oUFjToiE^
Y?l00003oiE^Y004o`000?nEKZCoUFjTo`0000;oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000003oiE^
Y003o`000?nEKZCo000000;o00000_nQUl/01Ol0003oXIO;oj6GbonQUl_o000000?oXIO;00Go0000
oj6Gbol0003oYK[Xo`000004ojFjj003o`000?nU^^So000000?o00000_nU`^h01?l0003oYL;^o`00
0?l00002ojG3kP03o`000?nU`nkoYL?^00?o00000onU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_
00?o0000ojG3konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_
ojG3k`04o`0000;oYL?^00?o0000ojG3k_nU`nh00ol00003ojG3k`?o00000_nU`nl00ol0003oYL?_
ojG3k`04o`0000;oXlce00Go0000oj?<mOnSc?Go000000000002o`0001<0oooo00<000000?ooo`3o
ool00`3oool002H0oooo00?o00000?ooo`3oool07`3oool01?l00000SenE08mOUOl0000208mOU@04
o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0
000308mOU@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01_l00000
SenE08mOU@2?GiGo000008mOU@?o000000GoUFjTo`000?nEKZCoUFjTo`000003oiE^Y005o`000?nE
KZCoUFjToiE^Y?l000000_nEKZ@01Ol0003oUFjToiE^Y?nEKZCo000000;oUFjT00Go0000oiE^Y?nE
KZCoUFjTo`000002oiE^Y003o`000?nEKZCo000000?o000000?oXIO;o`000?nQUl/00onQUl/01?l0
003oXIO;oj6Gbol00002oj6Gb`?o00000onU^^P00ol0003oYK[XojFjj003o`0000?oYL;^00?o0000
ojG2k_nU`^h00_l00004ojG3kP?o00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000
ojG3konU`nl00ol00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`03
o`0000;oYL?^00?o0000ojG3k_nU`nh01?l00002ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o
0000ojG3konU`nl00ol00002oj?<m@03o`000?nSc?GoXlce00Go000000<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`030?ooo`009`3oool00ol00000oooo0?ooo`0N0?ooo`04o`00002?GiD0
SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000208mOU@04
o`00002?GiD0SenEo`0000<0SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0
000208mOU@03o`00002?GiGo000000?o000000GoUFjTo`000?nEKZCoUFjTo`000003oiE^Y004o`00
0?nEKZCoUFjTo`0000?oUFjT00Co0000oiE^Y?nEKZCo00000onEKZ@01Ol0003oUFjToiE^Y?nEKZCo
000000;oUFjT00?o0000oiE^Y?l000000_l00002oj6Gb`05o`000?nQUl_oXIO;oj6Gbol000000onQ
Ul/00ol0003oXIO;oj6Gb`03o`0000;oYK[X00?o0000ojFjj?nU^^P01?l00002ojG2kP03o`000?nU
`^koYL;^00Co00000_nU`nh01_l0003oYL?^o`000?l0003oYL?_o`0000;oYL?_1?l00002ojG3k`03
o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU
`nl01?l00002ojG3kP03o`000?nU`nkoYL?^00?o00000onU`nl00ol0003oYL?_ojG3k`02o`0000Co
YL?_0ol00002oj?<m@03o`000?nSc?GoXlce00Go0000103oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00<0oooo000X0?ooo`;o00007P3oool01?l00000SenE08mOUOl0000208mOU@04
o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0
000308mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiGo000008mOU@03o`0000;o
UFjT00Co0000oiE^Y?nEKZCo00000onEKZ@01?l0003oUFjToiE^Y?l00003oiE^Y004o`000?nEKZCo
UFjTo`0000;oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000003oiE^Y003o`000?nEKZCo000000;o0000
00?oXIO;o`000?nQUl/00onQUl/01?l0003oXIO;oj6Gbol00002oj6Gb`Co00000_nU^^P00ol0003o
YK[XojFjj003o`0000?oYL;^00?o0000ojG2k_nU`^h00ol00003ojG3kP03o`000?nU`nkoYL?^00;o
00000onU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`03o`000?nU`nooYL?_00?o
00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?^00?o0000ojG3k_nU`nh01?l00002ojG3k`03
o`000?nU`nooYL?_00Co00000_nU`nl01_l0003oYL?_o`000?l0003oXlceo`0000;oXlce1Ol00009
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool002X0oooo00?o00000?oo
o`3oool06`3oool01?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`000080SenE00Co
000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000308mOU@04o`00002?GiD0SenEo`00
0080SenE00?o000008mOUOl000000_l000000onEKZCo0000oiE^Y002oiE^Y004o`000?nEKZCoUFjT
o`0000?oUFjT00Co0000oiE^Y?nEKZCo00000onEKZ@01?l0003oUFjToiE^Y?l00003oiE^Y005o`00
0?nEKZCoUFjTo`000?nEKZ@01?l000000onQUl_o0000oj6Gb`02oj6Gb`05o`000?nQUl_oXIO;oj6G
bol000000_nQUl/3o`0000?oYK[X00?o0000ojFjj?nU^^P00ol00002ojG2kP03o`000?nU`^koYL;^
00Co00000_nU`nh00ol0003oYL?^ojG3kP04o`0000;oYL?_00?o0000ojG3kol000000_nU`nl00ol0
003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_
00?o00000onU`nh00ol0003oYL?^ojG3kP03o`0000;oYL?_00?o0000ojG3konU`nl01?l00002ojG3
k`03o`000?nU`nooYL?_00?o00000_nSc?D5o`0000d0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`030?ooo`00:`3oool00ol00000oooo0?ooo`0J0?ooo`04o`00002?GiD0SenEo`00
0080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl0000208mOU@04o`00002?
GiD0SenEo`0000<0SenE00Go000008mOU@2?GiGo000008mOU@03o`000005oiE^Y?l0003oUFjToiE^
Y?l000000onEKZ@01?l0003oUFjToiE^Y?l00003oiE^Y004o`000?nEKZCoUFjTo`0000?oUFjT00Go
0000oiE^Y?nEKZCoUFjTo`000002oiE^Y003o`000?nEKZCo000000;o00000_nQUl/01Ol0003oXIO;
oj6GbonQUl_o000000;oXIO;00?o0000oj6GbonQUl/01?l00002ojFjj003o`000?nU^^SoYK[X00Co
00000_nU`^h00ol0003oYL;^ojG2kP03o`0000?oYL?^00?o0000ojG3k_nU`nh00ol00002ojG3k`03
o`000?nU`nooYL?_00Co00000_nU`nl3o`0000;oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03
o`000?nU`nooYL?_00Co00000_nU`nh00ol0003oYL?^ojG3kP04o`0000;oYL?_00?o0000ojG3konU
`nl00ol00003ojG3k`03o`000?nU`nooYL?_00?o00000_nSc?D5o`000140oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`020?ooo`00;03oool00ol00000oooo0?ooo`0I0?ooo`04o`00
002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo00000P2?GiD01?l00000SenE08mOUOl00002
08mOU@04o`00002?GiD0SenEo`0000<0SenE00?o000008mOUOl000000_l000001OnEKZCo0000oiE^
Y?nEKZCo000000?oUFjT00Co0000oiE^Y?nEKZCo00000_nEKZ@01Ol0003oUFjToiE^Y?nEKZCo0000
00;oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000003oiE^Y003o`000?nEKZCo000000;o000000?oXIO;
o`000?nQUl/00onQUl/01?l0003oXIO;oj6Gbol00002oj6Gb`?o00000onU^^P00ol0003oYK[XojFj
j003o`0000;oYL;^00?o0000ojG2k_nU`^h01?l00002ojG3kP03o`000?nU`nkoYL?^00Co00000_nU
`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_0ol00002ojG3k`03o`000?nU`nooYL?_00?o00000onU
`nl00ol0003oYL?_ojG3k`03o`0000;oYL?^00?o0000ojG3k_nU`nh01?l00002ojG3k`03o`000?nU
`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`000003oj?<mOl0003o000000?o00005P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo000]0?ooo`;o00006@3oool0
1?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo
00000P2?GiD01Ol00000SenE08mOUOl00000SenE00Co000000GoUFjTo`000?nEKZCoUFjTo`000003
oiE^Y004o`000?nEKZCoUFjTo`0000;oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000002oiE^Y005o`00
0?nEKZCoUFjToiE^Y?l000000_nEKZ@00ol0003oUFjTo`000003o`000003oj6Gbol0003oXIO;00;o
XIO;00Go0000oj6GbonQUl_oXIO;o`000002oj6Gb`?o00000_nU^^P00ol0003oYK[XojFjj004o`00
00;oYL;^00?o0000ojG2k_nU`^h00ol00003ojG3kP03o`000?nU`nkoYL?^00?o00000_nU`nl00ol0
003oYL?_ojG3k`04o`0000;oYL?_00Ko0000ojG3kol0003o0000ojG3kol00002ojG3k`Co00000_nU
`nl00ol0003oYL?_ojG3k`04o`0000;oYL?^00?o0000ojG3k_nU`nh00ol00003ojG3k`03o`000?nU
`nooYL?_00?o00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oXlce1Ol0000J0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool002l0oooo00?o00000?ooo`3oool05P3oool0
1?l00000SenE08mOUOl0000208mOU@04o`00002?GiD0SenEo`000080SenE00Co000008mOU@2?GiGo
00000P2?GiD00ol00000SenEo`000002o`0000;oUFjT00Co0000oiE^Y?nEKZCo00000_nEKZ@01Ol0
003oUFjToiE^Y?nEKZCo000000;oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000002oiE^Y005o`000?nE
KZCoUFjToiE^Y?l000000_nEKZ@00ol0003oUFjTo`000002o`0000;oXIO;00Go0000oj6GbonQUl_o
XIO;o`000002oj6Gb`03o`000?nQUl_oXIO;00Co00000_nU^^P00ol0003oYK[XojFjj003o`0000?o
YL;^00?o0000ojG2k_nU`^h00ol00002ojG3kP03o`000?nU`nkoYL?^00Co00000_nU`nl00ol0003o
YL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`?o00000onU`nl00ol0003o
YL?_ojG3k`03o`0000;oYL?^00?o0000ojG3k_nU`nh01?l00002ojG3k`03o`000?nU`nooYL?_00Co
00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oXlce1Ol0000N0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00P3oool00300oooo00?o00000?ooo`3oool05@3oool01?l00000SenE
08mOUOl0000208mOU@04o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiGo000008mOU@03
o`000003oiE^Y?l0003oUFjT00;oUFjT00Co0000oiE^Y?nEKZCo00000_nEKZ@01Ol0003oUFjToiE^
Y?nEKZCo000000;oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000002oiE^Y006o`000?nEKZCoUFjToiE^
Y?l0003oUFjT0ol000000onQUl_o0000oj6Gb`02oj6Gb`05o`000?nQUl_oXIO;oj6Gbol000000_nQ
Ul/3o`0000;oYK[X00?o0000ojFjj?nU^^P01?l00002ojG2kP03o`000?nU`^koYL;^00Co00000_nU
`nh00ol0003oYL?^ojG3kP03o`0000?oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU
`nooYL?_00Co00000_nU`nl3o`0000;oYL?_00?o0000ojG3konU`nl01?l00002ojG3kP03o`000?nU
`nkoYL?^00?o00000onU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_00?o0000ojG3konU`nl01?l0
00000onSc?Go0000o`000003o`0002<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`020?ooo`00<@3oool00ol00000oooo0?ooo`0D0?ooo`04o`00002?GiD0SenEo`000080SenE00Co
000008mOU@2?GiGo00000P2?GiD00ol00000SenEo`000002o`000005oiE^Y?l0003oUFjToiE^Y?l0
00000onEKZ@01?l0003oUFjToiE^Y?l00002oiE^Y005o`000?nEKZCoUFjToiE^Y?l000000_nEKZ@0
1Ol0003oUFjToiE^Y?nEKZCo000000;oUFjT00?o0000oiE^Y?l000000ol000000onQUl_o0000oj6G
b`02oj6Gb`06o`000?nQUl_oXIO;oj6Gbol0003oXIO;1?l00002ojFjj003o`000?nU^^SoYK[X00?o
00000onU`^h00ol0003oYL;^ojG2kP03o`0000;oYL?^00?o0000ojG3k_nU`nh01?l00002ojG3k`03
o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_00Co0000ojG3kol0
003o00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?^00?o0000ojG3k_nU`nh01?l00002ojG3
k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oXlce1Ol0000W0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00380oooo0_l0000D0?ooo`04
o`00002?GiD0SenEo`000080SenE00Go000008mOU@2?GiGo000008mOU@03o`000005oiE^Y?l0003o
UFjToiE^Y?l000000onEKZ@01?l0003oUFjToiE^Y?l00002oiE^Y005o`000?nEKZCoUFjToiE^Y?l0
00000_nEKZ@01Ol0003oUFjToiE^Y?nEKZCo000000;oUFjT00?o0000oiE^Y?l000000_l00002oj6G
b`05o`000?nQUl_oXIO;oj6Gbol000000_nQUl/00ol0003oXIO;oj6Gb`03o`0000?oYK[X00?o0000
ojFjj?nU^^P00ol00002ojG2kP03o`000?nU`^koYL;^00Co00000_nU`nh00ol0003oYL?^ojG3kP03
o`0000?oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl0
0ol0003oYL?_ojG3k`03o`0000;oYL?_1?l00002ojG3kP03o`000?nU`nkoYL?^00?o00000onU`nl0
0ol0003oYL?_ojG3k`03o`0000;oYL?_00?o0000ojG3konU`nl01?l000000onSc?Go0000o`000003
o`0002`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`00=03oool00ol0
0000oooo0?ooo`0A0?ooo`04o`00002?GiD0SenEo`000080SenE00?o000008mOUOl000000_l00000
1OnEKZCo0000oiE^Y?nEKZCo000000?oUFjT00Co0000oiE^Y?nEKZCo00000_nEKZ@01Ol0003oUFjT
oiE^Y?nEKZCo000000;oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000002oiE^Y003o`000?nEKZCo0000
00;o000000?oXIO;o`000?nQUl/00onQUl/01?l0003oXIO;oj6Gbol00002oj6Gb`?o00000_nU^^P0
0ol0003oYK[XojFjj004o`0000;oYL;^00?o0000ojG2k_nU`^h00ol00003ojG3kP03o`000?nU`nko
YL?^00?o00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl00ol00003
ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nl3o`0000;oYL?^00?o0000ojG3k_nU`nh01?l00002
ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oXlce1Ol0000_
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool003D0oooo00?o00000?oo
o`3oool0403oool01Ol00000SenE08mOUOl00000SenE00?o000000GoUFjTo`000?nEKZCoUFjTo`00
0003oiE^Y004o`000?nEKZCoUFjTo`0000;oUFjT00Go0000oiE^Y?nEKZCoUFjTo`000002oiE^Y004
o`000?nEKZCoUFjTo`0000?oUFjT00?o0000oiE^Y?l000000_l000000onQUl_o0000oj6Gb`02oj6G
b`05o`000?nQUl_oXIO;oj6Gbol000000_nQUl/3o`0000;oYK[X00?o0000ojFjj?nU^^P00ol00003
ojG2kP03o`000?nU`^koYL;^00?o00000_nU`nh00ol0003oYL?^ojG3kP04o`0000;oYL?_00?o0000
ojG3konU`nl00ol00003ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nl00ol0003oYL?_ojG3k`04
o`000003ojG3kol0003o000000;o00000_nU`nh00ol0003oYL?^ojG3kP03o`0000?oYL?_00?o0000
ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00Co00000_nSc?D4o`0003@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`010?ooo`00=P3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00002?GiGo000000;o000000GoUFjTo`000?nEKZCoUFjTo`000002oiE^Y005o`000?nEKZCo
UFjToiE^Y?l000000_nEKZ@01?l0003oUFjToiE^Y?l00003oiE^Y004o`000?nEKZCoUFjTo`0000;o
UFjT00?o0000oiE^Y?l000000ol000000onQUl_o0000oj6Gb`02oj6Gb`04o`000?nQUl_oXIO;o`00
00;oXIO;1?l00002ojFjj003o`000?nU^^SoYK[X00?o00000_nU`^h00ol0003oYL;^ojG2kP04o`00
00;oYL?^00?o0000ojG3k_nU`nh00ol00003ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nl00ol0
003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`?o00000onU`nh00ol0
003oYL?^ojG3kP03o`0000;oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_
00?o00000_nSc?D00ol0003oXlceo`000002o`0003P0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`010?ooo`00=`3oool2o`0000l0oooo0_l000001OnEKZCo0000oiE^Y?nEKZCo0000
00;oUFjT00Co0000oiE^Y?nEKZCo00000onEKZ@01?l0003oUFjToiE^Y?l00002oiE^Y005o`000?nE
KZCoUFjToiE^Y?l000000_nEKZ@00ol0003oUFjTo`000002o`0000;oXIO;00Go0000oj6GbonQUl_o
XIO;o`000002oj6Gb`03o`000?nQUl_oXIO;00?o00000onU^^P00ol0003oYK[XojFjj003o`0000;o
YL;^00?o0000ojG2k_nU`^h00ol00003ojG3kP03o`000?nU`nkoYL?^00?o00000_nU`nl00ol0003o
YL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00Co
00000_nU`nl3o`0000;oYL?^00?o0000ojG3k_nU`nh01?l00002ojG3k`03o`000?nU`nooYL?_00?o
00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oXlce00?o0000oj?<mOnSc?D00_l0000l0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool003T0oooo00?o00000?ooo`3oool0
303oool01?l0003oUFjToiE^Y?l00002oiE^Y004o`000?nEKZCoUFjTo`0000;oUFjT00Go0000oiE^
Y?nEKZCoUFjTo`000002oiE^Y005o`000?nEKZCoUFjToiE^Y?l000000_nEKZ@00ol0003oUFjTo`00
0002o`000003oj6Gbol0003oXIO;00?oXIO;00Co0000oj6GbonQUl_o00000_nQUl/3o`0000;oYK[X
00?o0000ojFjj?nU^^P01?l00002ojG2kP03o`000?nU`^koYL;^00?o00000_nU`nh00ol0003oYL?^
ojG3kP04o`0000;oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00Co0000
0_nU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_1?l00002ojG3kP03o`000?nU`nkoYL?^00?o0000
0_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl00ol00002oj?<m@03o`00
0?nSc?GoXlce00Co0000?P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo
000j0?ooo`03o`00003oool0oooo00/0oooo00Co0000oiE^Y?nEKZCo00000_nEKZ@01?l0003oUFjT
oiE^Y?l00003oiE^Y004o`000?nEKZCoUFjTo`0000?oUFjT00Go0000oiE^Y?nEKZCo0000oiE^Y003
o`000003oj6Gbol0003oXIO;00;oXIO;00Go0000oj6GbonQUl_oXIO;o`000002oj6Gb`?o00000_nU
^^P00ol0003oYK[XojFjj003o`0000?oYL;^00?o0000ojG2k_nU`^h00ol00002ojG3kP03o`000?nU
`nkoYL?^00?o00000onU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_00?o0000ojG3konU`nl00ol0
0003ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nl3o`0000;oYL?^00?o0000ojG3k_nU`nh01?l0
0002ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oXlce00?o
0000oj?<mOnSc?D00ol000130?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3o
ool003/0oooo00?o00000?ooo`3oool02P3oool01?l0003oUFjToiE^Y?l00002oiE^Y005o`000?nE
KZCoUFjToiE^Y?l000000_nEKZ@01Ol0003oUFjToiE^Y?nEKZCo000000;oUFjT00?o0000oiE^Y?l0
00000_l000000onQUl_o0000oj6Gb`02oj6Gb`04o`000?nQUl_oXIO;o`0000;oXIO;1?l00002ojFj
j003o`000?nU^^SoYK[X00?o00000_nU`^h00ol0003oYL;^ojG2kP04o`0000;oYL?^00?o0000ojG3
k_nU`nh00ol00002ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`03o`00
00;oYL?_00?o0000ojG3konU`nl01?l000000onU`noo0000o`000002o`0000;oYL?^00?o0000ojG3
k_nU`nh00ol00002ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`03o`00
00;oXlce00?o0000oj?<mOnSc?D01?l000170?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00@3oool003`0oooo00?o00000?ooo`3oool02@3oool01?l0003oUFjToiE^Y?l00003oiE^
Y004o`000?nEKZCoUFjTo`0000;oUFjT00Ko0000oiE^Y?nEKZCoUFjTo`000?nEKZ@3o`000003oj6G
bol0003oXIO;00;oXIO;00Co0000oj6GbonQUl_o00000_nQUl/3o`0000?oYK[X00?o0000ojFjj?nU
^^P00ol00002ojG2kP03o`000?nU`^koYL;^00?o00000onU`nh00ol0003oYL?^ojG3kP03o`0000;o
YL?_00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003o
YL?_ojG3k`03o`0000;oYL?_0ol00003ojG3kP03o`000?nU`nkoYL?^00?o00000_nU`nl00ol0003o
YL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl00ol00002oj?<m@03o`000?nSc?GoXlce00?o
0000B`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000m0?ooo`;o0000
2@3oool01Ol0003oUFjToiE^Y?nEKZCo000000;oUFjT00Co0000oiE^Y?nEKZCo00000_nEKZ@00ol0
003oUFjTo`000003o`000003oj6Gbol0003oXIO;00;oXIO;00Co0000oj6GbonQUl_o00000_nQUl/3
o`0000;oYK[X00?o0000ojFjj?nU^^P01?l00002ojG2kP03o`000?nU`^koYL;^00?o00000_nU`nh0
0ol0003oYL?^ojG3kP04o`0000;oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU`noo
YL?_00?o00000onU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_0ol00002ojG3kP03o`000?nU`nko
YL?^00Co00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_00?o0000ojG3konU`nl01?l00002
oj?<m@03o`000?nSc?GoXlce00?o0000C`3oool00`000000oooo0?ooo`080?ooo`4000000@3oool1
0?ooo`00?`3oool00ol00000oooo0?ooo`070?ooo`04o`000?nEKZCoUFjTo`0000;oUFjT00Go0000
oiE^Y?nEKZCo0000oiE^Y003o`0000;oXIO;00Go0000oj6GbonQUl_oXIO;o`000002oj6Gb`03o`00
0?nQUl_oXIO;00?o00000_nU^^P00ol0003oYK[XojFjj003o`0000?oYL;^00?o0000ojG2k_nU`^h0
0ol00002ojG3kP03o`000?nU`nkoYL?^00?o00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_
00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl3o`0000;oYL?^
00?o0000ojG3k_nU`nh00ol00002ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_
ojG3k`03o`0000;oXlce1ol0001C0?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`40oooo
00100?ooo`03o`00003oool0oooo00H0oooo00Co0000oiE^Y?nEKZCo00000_nEKZ@00ol0003oUFjT
o`000002o`000003oj6Gbol0003oXIO;00?oXIO;00Co0000oj6GbonQUl_o00000_nQUl/3o`0000;o
YK[X00?o0000ojFjj?nU^^P00ol00002ojG2kP03o`000?nU`^koYL;^00Co00000_nU`nh00ol0003o
YL?^ojG3kP03o`0000;oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`03o`000?nU`nooYL?_00?o
00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_1?l00002ojG3kP03o`000?nU`nkoYL?^00?o
00000_nU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl00ol00002oj?<m@Go
0000F@3oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`00@@3oool00ol00000oooo
0?ooo`050?ooo`05o`000?nEKZCoUFjTo`000?nEKZ@00ol000000onQUl_o0000oj6Gb`02oj6Gb`05
o`000?nQUl_oXIO;oj6Gbol000000_nQUl/3o`0000;oYK[X00?o0000ojFjj?nU^^P00ol00002ojG2
kP03o`000?nU`^koYL;^00?o00000onU`nh00ol0003oYL?^ojG3kP03o`0000;oYL?_00?o0000ojG3
konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`03o`00
00;oYL?_0ol00002ojG3kP03o`000?nU`nkoYL?^00Co00000_nU`nl00ol0003oYL?_ojG3k`03o`00
00;oYL?_00?o0000ojG3konU`nl01?l000000onSc?Go0000o`000003o`0005d0oooo00<000000?oo
o`3oool01P3oool100000040oooo0@3oool00480oooo0_l000050?ooo`03o`000?nEKZCo000000;o
000000?oXIO;o`000?nQUl/00_nQUl/01?l0003oXIO;oj6Gbol00002oj6Gb`Co00000_nU^^P00ol0
003oYK[XojFjj003o`0000;oYL;^00?o0000ojG2k_nU`^h00ol00002ojG3kP03o`000?nU`nkoYL?^
00Co00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_00?o0000ojG3konU`nl00ol00003ojG3
k`03o`000?nU`nooYL?_00?o00000_nU`nl3o`0000;oYL?^00?o0000ojG3k_nU`nh00ol00002ojG3
k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oXlce1Ol0001Q0?oo
o`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00140?ooo`03o`00003oool0oooo0080
oooo0_l000000onQUl_o0000oj6Gb`02oj6Gb`04o`000?nQUl_oXIO;o`0000;oXIO;0ol00003ojFj
j003o`000?nU^^SoYK[X00?o00000_nU`^h00ol0003oYL;^ojG2kP03o`0000;oYL?^00?o0000ojG3
k_nU`nh00ol00003ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nl00ol0003oYL?_ojG3k`03o`00
00;oYL?_1ol000000onU`noo0000o`000002o`0000;oYL?^00?o0000ojG3k_nU`nh00ol00002ojG3
k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`03o`0000;oXlce1Ol0001U0?oo
o`030000003oool0oooo00@0oooo0@0000010?ooo`40oooo00150?ooo`05o`00003oool0oooo0?oo
ool000000onQUl/01?l0003oXIO;oj6Gbol00002oj6Gb`?o00000_nU^^P00ol0003oYK[XojFjj004
o`0000;oYL;^00?o0000ojG2k_nU`^h00ol00002ojG3kP03o`000?nU`nkoYL?^00?o00000_nU`nl0
0ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`?o00000_nU`nl0
0ol0003oYL?_ojG3k`03o`0000?oYL?^00?o0000ojG3k_nU`nh00ol00002ojG3k`03o`000?nU`noo
YL?_00?o00000_nU`nl00ol0003oYL?_ojG3k`04o`000003oj?<mOl0003o000000?o0000JP3oool0
0`000000oooo0?ooo`030?ooo`4000000@3oool10?ooo`00AP3oool01Ol00000oooo0?ooo`3ooooo
000000;oXIO;00?o0000oj6GbonQUl/00ol00002ojFjj003o`000?nU^^SoYK[X00?o00000onU`^h0
0ol0003oYL;^ojG2kP03o`0000;oYL?^00?o0000ojG3k_nU`nh00ol00002ojG3k`03o`000?nU`noo
YL?_00?o00000onU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_0ol00002ojG3k`03o`000?nU`noo
YL?_00?o00000_nU`nh00ol0003oYL?^ojG3kP04o`0000;oYL?_00?o0000ojG3konU`nl00ol00002
ojG3k`03o`000?nU`nooYL?_00?o00000_nSc?D5o`0006d0oooo00<000000?ooo`3oool0103oool1
00000040oooo00170?ooo`;o000000@0ooooo`000?nQUl_oXIO;0ol00002ojFjj003o`000?nU^^So
YK[X00?o00000onU`^h00ol0003oYL;^ojG2kP03o`0000;oYL?^00?o0000ojG3k_nU`nh00ol00002
ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_0ol00002
ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nh00ol0003oYL?^ojG3kP03o`0000;oYL?_00?o0000
ojG3konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_00?o00000_nSc?D5o`000740oooo00<00000
0?ooo`3oool00`3oool100000040oooo00190?ooo`04o`00003ooooo0000o`0000;oYK[X00?o0000
ojFjj?nU^^P00ol00002ojG2kP03o`000?nU`^koYL;^00Co00000_nU`nh00ol0003oYL?^ojG3kP03
o`0000;oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`Ko00000_nU`nl4o`0000;oYL?_00?o0000
ojG3konU`nl00ol00002ojG3kP03o`000?nU`nkoYL?^00?o00000_nU`nl00ol0003oYL?_ojG3k`03
o`0000?oYL?_00?o0000ojG3konU`nl00ol00002oj?<m@Go0000M@3oool00`000000oooo0?ooo`02
0?ooo`4000000@3oool004X0oooo00?o00000?ooool000000_nU^^P3o`0000;oYL;^00?o0000ojG2
k_nU`^h00ol00003ojG3kP03o`000?nU`nkoYL?^00?o00000_nU`nl00ol0003oYL?_ojG3k`03o`00
00;oYL?_0ol00002ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`03o`00
00;oYL?^00?o0000ojG3k_nU`nh00ol00002ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nl00ol0
003oYL?_ojG3k`04o`000003oj?<mOl0003o000000?o0000NP3oool01@000000oooo0?ooo`3oool0
00000040oooo001;0?ooo`04o`00003ooooo0000o`0000;oYL;^00?o0000ojG2k_nU`^h00ol00003
ojG3kP03o`000?nU`nkoYL?^00?o00000_nU`nl6o`0000;oYL?_0ol00002ojG3k`03o`000?nU`noo
YL?_00?o00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?^00?o0000ojG3k_nU`nh00ol00002
ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oXlce1Ol0001m
0?ooo`050000003oool0oooo0?ooo`0000000@3oool004`0oooo0ol00002ojG2kP?o00000onU`nh0
0ol0003oYL?^ojG3kP03o`0000;oYL?_0ol00002ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nl0
0ol0003oYL?_ojG3k`03o`0000;oYL?_00?o0000ojG3konU`nl00ol00002ojG3kP03o`000?nU`nko
YL?^00Co00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_1_l00002oj?<m@Go0000P@3oool0
10000000oooo0?ooo`0000010?ooo`00CP3oool3o`0000;oYL?^1ol00002ojG3k`?o00000_nU`nl0
0ol0003oYL?_ojG3k`03o`0000;oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU`noo
YL?_00?o00000_nU`nh00ol0003oYL?^ojG3kP03o`0000?oYL?_00?o0000ojG3konU`nl00ol00002
ojG3k`?o00000_nSc?D00ol0003oXlceoj?<m@05o`0008D0oooo00<000000?ooo`0000000@3oool0
04l0oooo00Co00000?ooool0003o00000onU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_00?o0000
ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nl00ol0003oYL?_ojG3k`03
o`0000;oYL?^00?o0000ojG3k_nU`nh00ol00002ojG3k`Oo000000?oYL?_o`000?l000000_l00002
oj?<m@03o`000?nSc?GoXlce00?o0000RP3oool00`000000oooo0?ooo`0100000000D03oool01?l0
0000oooo0?ooool00002ojG3k`?o00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_00?o0000
ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nh00ol0003oYL?^ojG3kP03
o`0000;oYL?_0ol00002ojG3k`03o`000?nU`nooYL?_00?o00000_nSc?D00ol0003oXlceoj?<m@04
o`0008h0oooo0@0000010?ooo`400000001A0?ooo`;o000000<0ooooo`000?l000000_nU`nl00ol0
003oYL?_ojG3k`03o`0000;oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_
00?o00000_nU`nh6o`0000;oYL?_0ol00002ojG3k`03o`000?nU`nooYL?_00?o00000_nSc?D00ol0
003oXlceoj?<m@03o`0009<0oooo0P00000005<0oooo00?o00000?ooool000000_nU`nl3o`0000;o
YL?_00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nh3o`0000;o
YL?_00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00?o00000_nSc?D00ol0003o
Xlceoj?<m@03o`0009D0oooo0_l0000100000000E03oool01?l00000ooooo`000?l00002ojG3k`03
o`000?nU`nooYL?_00?o00000_nU`nl6o`0000;oYL?^0ol00002ojG3k`03o`000?nU`nooYL?_00?o
00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oXlce1ol0002C0?ooo`Co00000`3oool005D0oooo
00?o00000?ooo`3oool01Ol00002ojG3k`?o00000_nU`nh00ol0003oYL?^ojG3kP03o`0000;oYL?_
00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00?o00000_nSc?D5o`0000@0oooo
00?o00000?ooo`3oool0S@3oool4o`0000L0oooo001F0?ooo`;o000000@0ooooo`000?nU`nooYL?_
0ol00002ojG3kP03o`000?nU`nkoYL?^00?o00000_nU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_
00?o0000ojG3konU`nl00ol00002oj?<m@Go00001`3oool00ol00000oooo0?ooo`290?ooo`Co0000
2`3oool005P0oooo00Co00000?ooool0003o00000_nU`nh00ol0003oYL?^ojG3kP03o`0000;oYL?_
00?o0000ojG3konU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00?o00000_nSc?D5o`0000X0oooo
00?o00000?ooo`3oool0QP3oool3o`0000l0oooo001I0?ooo`03o`00003ooooo000000;oYL?^0ol0
0002ojG3k`03o`000?nU`nooYL?_00?o00000_nU`nl6o`0000;oXlce1Ol0000=0?ooo`03o`00003o
ool0oooo0880oooo1?l0000B0?ooo`00FP3oool01?l00000ooooo`000?l00002ojG3k`Ko00000_nU
`nl3o`0000;oXlce00?o0000oj?<mOnSc?D00ol0000B0?ooo`03o`00003oool0oooo07h0oooo1?l0
000F0?ooo`00F`3oool2o`0000030?ooool0003o000000;oYL?_00?o0000ojG3konU`nl00ol00002
oj?<m@03o`000?nSc?GoXlce00?o00005@3oool00ol00000oooo0?ooo`1j0?ooo`Co00006P3oool0
05d0oooo00?o00000?ooool000000_nU`nl3o`0000;oXlce00?o0000oj?<mOnSc?D00ol0000H0?oo
o`03o`00003oool0oooo07H0oooo1?l0000N0?ooo`00GP3oool01?l00000ooooo`000?l00002oj?<
m@Ko00006`3oool00ol00000oooo0?ooo`1b0?ooo`Co00008P3oool005l0oooo00?o00000?ooo`3o
ool01?l0000O0?ooo`03o`00003oool0oooo06h0oooo1?l0000V0?ooo`00H03oool2o`0002<0oooo
00?o00000?ooo`3oool0JP3oool4o`0002X0oooo001R0?ooo`03o`00003oool0oooo0200oooo00?o
00000?ooo`3oool0I`3oool3o`0002h0oooo001S0?ooo`03o`00003oool0oooo01l0oooo00?o0000
0?ooo`3oool0H`3oool4o`000340oooo001T0?ooo`03o`00003oool0oooo01h0oooo00?o00000?oo
o`3oool0G`3oool4o`0003D0oooo001U0?ooo`;o00007P3oool00ol00000oooo0?ooo`1K0?ooo`Co
0000>@3oool006L0oooo00?o00000?ooo`3oool06`3oool00ol00000oooo0?ooo`1G0?ooo`Co0000
?@3oool006P0oooo00?o00000?ooo`3oool06P3oool00ol00000oooo0?ooo`1C0?ooo`Co0000@@3o
ool006T0oooo00?o00000?ooo`3oool06@3oool00ol00000oooo0?ooo`1?0?ooo`Co0000A@3oool0
06X0oooo0_l0000I0?ooo`03o`00003oool0oooo04/0oooo1?l000190?ooo`00K03oool00ol00000
oooo0?ooo`0F0?ooo`03o`00003oool0oooo04P0oooo0ol0001=0?ooo`00K@3oool00ol00000oooo
0?ooo`0E0?ooo`03o`00003oool0oooo04@0oooo1?l0001@0?ooo`00KP3oool00ol00000oooo0?oo
o`0D0?ooo`03o`00003oool0oooo0400oooo1?l0001D0?ooo`00K`3oool00ol00000oooo0?ooo`0C
0?ooo`03o`00003oool0oooo03`0oooo1?l0001H0?ooo`00L03oool2o`0001<0oooo00?o00000?oo
o`3oool0>03oool4o`0005`0oooo001b0?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3o
ool0=03oool4o`000600oooo001c0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
<03oool4o`0006@0oooo001d0?ooo`03o`00003oool0oooo00d0oooo00?o00000?ooo`3oool0;@3o
ool4o`0006P0oooo001e0?ooo`;o00003@3oool00ol00000oooo0?ooo`0Z0?ooo`?o0000K03oool0
07L0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0V0?ooo`Co0000K`3oool007P0
oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`0R0?ooo`Co0000L`3oool007T0oooo
00?o00000?ooo`3oool0203oool00ol00000oooo0?ooo`0N0?ooo`Co0000M`3oool007X0oooo0_l0
00080?ooo`03o`00003oool0oooo01X0oooo1?l0001k0?ooo`00O03oool00ol00000oooo0?ooo`05
0?ooo`03o`00003oool0oooo01H0oooo1?l0001o0?ooo`00O@3oool00ol00000oooo0?ooo`040?oo
o`03o`00003oool0oooo0180oooo1?l000230?ooo`00OP3oool00ol00000oooo0?ooo`030?ooo`03
o`00003oool0oooo00h0oooo1?l000270?ooo`00O`3oool2o`0000<0oooo00?o00000?ooo`3oool0
2`3oool3o`0008/0oooo00210?ooo`04o`00003oool0ooooo`0000T0oooo1?l0002>0?ooo`00PP3o
ool00ol00000ooooo`0000050?ooo`Co0000TP3oool008<0oooo0_l000000`3ooooo0000o`000002
o`0009H0oooo00240?ooo`;o0000VP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.114416, -0.00319238, \
0.00371781, 0.00371781}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["One Wavelet with Lens", "Subsubsection",
  CellTags->{"AOG0.", "6.4.5", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],

Cell["\<\
waveletSystem = {
\tMove[LineOfWavelets[10,NumberOfRays->1],-50],
\tPlanoConvexLens[100,50,10],
\tMove[Screen[50],103]};\
\>", "Input",
  CellLabel->"In[51]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[waveletSystem,ShowGaussian->True,PlotType->TopView];\
\>", "Input",
  CellLabel->"In[52]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3468 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.335045 0.00622471 0.182923 0.00622471 [
[.36617 .00826 -3 -4.5 ]
[.36617 .00826 3 4.5 ]
[.97619 .00826 -3 -4.5 ]
[.97619 .00826 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .3468 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.37502 .0273 m
.39729 .0273 L
.39729 .07918 L
.35217 .07918 L
.37502 .0273 L
F
.35217 .07918 m
.39729 .07918 L
.39729 .13105 L
.33924 .13105 L
.35217 .07918 L
F
.33924 .13105 m
.39729 .13105 L
.39729 .18292 L
.33505 .18292 L
.33924 .13105 L
F
.33505 .18292 m
.39729 .18292 L
.39729 .2348 L
.33924 .2348 L
.33505 .18292 L
F
.33924 .2348 m
.39729 .2348 L
.39729 .28667 L
.35217 .28667 L
.33924 .2348 L
F
.35217 .28667 m
.39729 .28667 L
.39729 .33854 L
.37502 .33854 L
.35217 .28667 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.37502 .0273 m
.35217 .07918 L
.33924 .13105 L
.33505 .18292 L
.33924 .2348 L
.35217 .28667 L
.37502 .33854 L
.39729 .33854 L
.39729 .28667 L
.39729 .2348 L
.39729 .18292 L
.39729 .13105 L
.39729 .07918 L
.39729 .0273 L
.37502 .0273 L
s
.5 g
.37502 .18292 m
.39729 .18292 L
.39729 .18292 L
.35217 .18292 L
.37502 .18292 L
F
.35217 .18292 m
.39729 .18292 L
.39729 .18292 L
.33924 .18292 L
.35217 .18292 L
F
.33924 .18292 m
.39729 .18292 L
.39729 .18292 L
.33505 .18292 L
.33924 .18292 L
F
.33505 .18292 m
.39729 .18292 L
.39729 .18292 L
.33924 .18292 L
.33505 .18292 L
F
.33924 .18292 m
.39729 .18292 L
.39729 .18292 L
.35217 .18292 L
.33924 .18292 L
F
.35217 .18292 m
.39729 .18292 L
.39729 .18292 L
.37502 .18292 L
.35217 .18292 L
F
0 g
.37502 .18292 m
.35217 .18292 L
.33924 .18292 L
.33505 .18292 L
.33924 .18292 L
.35217 .18292 L
.37502 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.37502 .18292 L
s
.37502 .33854 m
.39729 .33854 L
.39729 .33324 L
.37502 .33324 L
.37502 .33854 L
s
.37502 .33324 m
.39729 .33324 L
.39729 .31769 L
.37502 .31769 L
.37502 .33324 L
s
.37502 .31769 m
.39729 .31769 L
.39729 .29296 L
.37502 .29296 L
.37502 .31769 L
s
.37502 .29296 m
.39729 .29296 L
.39729 .26073 L
.37502 .26073 L
.37502 .29296 L
s
.37502 .26073 m
.39729 .26073 L
.39729 .2232 L
.37502 .2232 L
.37502 .26073 L
s
.37502 .2232 m
.39729 .2232 L
.39729 .18292 L
.37502 .18292 L
.37502 .2232 L
s
.37502 .18292 m
.39729 .18292 L
.39729 .14265 L
.37502 .14265 L
.37502 .18292 L
s
.37502 .14265 m
.39729 .14265 L
.39729 .10511 L
.37502 .10511 L
.37502 .14265 L
s
.37502 .10511 m
.39729 .10511 L
.39729 .07288 L
.37502 .07288 L
.37502 .10511 L
s
.37502 .07288 m
.39729 .07288 L
.39729 .04815 L
.37502 .04815 L
.37502 .07288 L
s
.37502 .04815 m
.39729 .04815 L
.39729 .03261 L
.37502 .03261 L
.37502 .04815 L
s
.37502 .03261 m
.39729 .03261 L
.39729 .0273 L
.37502 .0273 L
.37502 .03261 L
s
.37502 .0273 m
.39729 .0273 L
.39729 .03261 L
.37502 .03261 L
.37502 .0273 L
s
.37502 .03261 m
.39729 .03261 L
.39729 .04815 L
.37502 .04815 L
.37502 .03261 L
s
.37502 .04815 m
.39729 .04815 L
.39729 .07288 L
.37502 .07288 L
.37502 .04815 L
s
.37502 .07288 m
.39729 .07288 L
.39729 .10511 L
.37502 .10511 L
.37502 .07288 L
s
.37502 .10511 m
.39729 .10511 L
.39729 .14265 L
.37502 .14265 L
.37502 .10511 L
s
.37502 .14265 m
.39729 .14265 L
.39729 .18292 L
.37502 .18292 L
.37502 .14265 L
s
.37502 .18292 m
.39729 .18292 L
.39729 .2232 L
.37502 .2232 L
.37502 .18292 L
s
.37502 .2232 m
.39729 .2232 L
.39729 .26073 L
.37502 .26073 L
.37502 .2232 L
s
.37502 .26073 m
.39729 .26073 L
.39729 .29296 L
.37502 .29296 L
.37502 .26073 L
s
.37502 .29296 m
.39729 .29296 L
.39729 .31769 L
.37502 .31769 L
.37502 .29296 L
s
.37502 .31769 m
.39729 .31769 L
.39729 .33324 L
.37502 .33324 L
.37502 .31769 L
s
.37502 .33324 m
.39729 .33324 L
.39729 .33854 L
.37502 .33854 L
.37502 .33324 L
s
.97619 .0273 m
.97619 .07918 L
.97619 .13105 L
.97619 .18292 L
.97619 .2348 L
.97619 .28667 L
.97619 .33854 L
.97619 .33854 L
.97619 .28667 L
.97619 .2348 L
.97619 .18292 L
.97619 .13105 L
.97619 .07918 L
.97619 .0273 L
.97619 .0273 L
s
.97619 .18292 m
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
s
.97619 .33854 m
.97619 .33324 L
.97619 .31769 L
.97619 .29296 L
.97619 .26073 L
.97619 .2232 L
.97619 .18292 L
.97619 .14265 L
.97619 .10511 L
.97619 .07288 L
.97619 .04815 L
.97619 .03261 L
.97619 .0273 L
.97619 .03261 L
.97619 .04815 L
.97619 .07288 L
.97619 .10511 L
.97619 .14265 L
.97619 .18292 L
.97619 .2232 L
.97619 .26073 L
.97619 .29296 L
.97619 .31769 L
.97619 .33324 L
.97619 .33854 L
s
0 0 0 r
[(L)] .36617 .00826 0 0 Mshowa
[(S)] .97619 .00826 0 0 Mshowa
.039 .916 .04 r
1 Mabswid
.02381 .24517 m
.03968 .24517 L
.05556 .24517 L
.07143 .24517 L
.0873 .24517 L
.10317 .24517 L
.11905 .24517 L
.13492 .24517 L
.15079 .24517 L
.16667 .24517 L
.18254 .24517 L
.19841 .24517 L
.21429 .24517 L
.23016 .24517 L
.24603 .24517 L
.2619 .24517 L
.27778 .24517 L
.29365 .24517 L
.30952 .24517 L
.3254 .24517 L
.34127 .24476 L
.35714 .24371 L
.37302 .24267 L
.38889 .24162 L
.40476 .24032 L
.42063 .23873 L
.43651 .23714 L
.45238 .23555 L
.46825 .23396 L
.48413 .23237 L
.5 .23078 L
.51587 .22919 L
.53175 .2276 L
.54762 .22601 L
.56349 .22442 L
.57937 .22283 L
.59524 .22124 L
.61111 .21965 L
.62698 .21806 L
.64286 .21647 L
.65873 .21489 L
.6746 .2133 L
.69048 .21171 L
.70635 .21012 L
.72222 .20853 L
.7381 .20694 L
.75397 .20535 L
.76984 .20376 L
.78571 .20217 L
.80159 .20058 L
Mistroke
.81746 .19899 L
.83333 .1974 L
.84921 .19581 L
.86508 .19422 L
.88095 .19263 L
.89683 .19104 L
.9127 .18945 L
.92857 .18786 L
.94444 .18627 L
.96032 .18468 L
.97619 .18309 L
Mfstroke
.02381 .12068 m
.03968 .12068 L
.05556 .12068 L
.07143 .12068 L
.0873 .12068 L
.10317 .12068 L
.11905 .12068 L
.13492 .12068 L
.15079 .12068 L
.16667 .12068 L
.18254 .12068 L
.19841 .12068 L
.21429 .12068 L
.23016 .12068 L
.24603 .12068 L
.2619 .12068 L
.27778 .12068 L
.29365 .12068 L
.30952 .12068 L
.3254 .12068 L
.34127 .12109 L
.35714 .12213 L
.37302 .12318 L
.38889 .12422 L
.40476 .12553 L
.42063 .12712 L
.43651 .12871 L
.45238 .13029 L
.46825 .13188 L
.48413 .13347 L
.5 .13506 L
.51587 .13665 L
.53175 .13824 L
.54762 .13983 L
.56349 .14142 L
.57937 .14301 L
.59524 .1446 L
.61111 .14619 L
.62698 .14778 L
.64286 .14937 L
.65873 .15096 L
.6746 .15255 L
.69048 .15414 L
.70635 .15573 L
.72222 .15732 L
.7381 .15891 L
.75397 .1605 L
.76984 .16209 L
.78571 .16368 L
.80159 .16527 L
Mistroke
.81746 .16686 L
.83333 .16845 L
.84921 .17003 L
.86508 .17162 L
.88095 .17321 L
.89683 .1748 L
.9127 .17639 L
.92857 .17798 L
.94444 .17957 L
.96032 .18116 L
.97619 .18275 L
Mfstroke
0 0 0 r
.02381 .18292 m
.33505 .18292 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
.33505 .18292 m
.39729 .18292 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
.39729 .18292 m
.97619 .18292 L
s
% Start of user PostScript
10. 0 103. 0 MAarrowhead1
% End of user PostScript
.97619 .18292 m
.97619 .18292 L
s
% Start of user PostScript
103. 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .1269 m
.02381 .13063 L
.02381 .13437 L
.02381 .1381 L
.02381 .14184 L
.02381 .14557 L
.02381 .14931 L
.02381 .15304 L
.02381 .15678 L
.02381 .16051 L
.02381 .16425 L
.02381 .16798 L
.02381 .17172 L
.02381 .17545 L
.02381 .17919 L
.02381 .18292 L
.02381 .18666 L
.02381 .19039 L
.02381 .19413 L
.02381 .19786 L
.02381 .2016 L
.02381 .20533 L
.02381 .20907 L
.02381 .2128 L
.02381 .21654 L
.02381 .22027 L
.02381 .22401 L
.02381 .22774 L
.02381 .23148 L
.02381 .23521 L
.02381 .23894 L
s
.04762 .1269 m
.04762 .13063 L
.04762 .13437 L
.04762 .1381 L
.04762 .14184 L
.04762 .14557 L
.04762 .14931 L
.04762 .15304 L
.04762 .15678 L
.04762 .16051 L
.04762 .16425 L
.04762 .16798 L
.04762 .17172 L
.04762 .17545 L
.04762 .17919 L
.04762 .18292 L
.04762 .18666 L
.04762 .19039 L
.04762 .19413 L
.04762 .19786 L
.04762 .2016 L
.04762 .20533 L
.04762 .20907 L
.04762 .2128 L
.04762 .21654 L
.04762 .22027 L
.04762 .22401 L
.04762 .22774 L
.04762 .23148 L
.04762 .23521 L
.04762 .23894 L
s
.07143 .1269 m
.07143 .13063 L
.07143 .13437 L
.07143 .1381 L
.07143 .14184 L
.07143 .14557 L
.07143 .14931 L
.07143 .15304 L
.07143 .15678 L
.07143 .16051 L
.07143 .16425 L
.07143 .16798 L
.07143 .17172 L
.07143 .17545 L
.07143 .17919 L
.07143 .18292 L
.07143 .18666 L
.07143 .19039 L
.07143 .19413 L
.07143 .19786 L
.07143 .2016 L
.07143 .20533 L
.07143 .20907 L
.07143 .2128 L
.07143 .21654 L
.07143 .22027 L
.07143 .22401 L
.07143 .22774 L
.07143 .23148 L
.07143 .23521 L
.07143 .23894 L
s
.09524 .1269 m
.09524 .13063 L
.09524 .13437 L
.09524 .1381 L
.09524 .14184 L
.09524 .14557 L
.09524 .14931 L
.09524 .15304 L
.09524 .15678 L
.09524 .16051 L
.09524 .16425 L
.09524 .16798 L
.09524 .17172 L
.09524 .17545 L
.09524 .17919 L
.09524 .18292 L
.09524 .18666 L
.09524 .19039 L
.09524 .19413 L
.09524 .19786 L
.09524 .2016 L
.09524 .20533 L
.09524 .20907 L
.09524 .2128 L
.09524 .21654 L
.09524 .22027 L
.09524 .22401 L
.09524 .22774 L
.09524 .23148 L
.09524 .23521 L
.09524 .23894 L
s
.11905 .1269 m
.11905 .13063 L
.11905 .13437 L
.11905 .1381 L
.11905 .14184 L
.11905 .14557 L
.11905 .14931 L
.11905 .15304 L
.11905 .15678 L
.11905 .16051 L
.11905 .16425 L
.11905 .16798 L
.11905 .17172 L
.11905 .17545 L
.11905 .17919 L
.11905 .18292 L
.11905 .18666 L
.11905 .19039 L
.11905 .19413 L
.11905 .19786 L
.11905 .2016 L
.11905 .20533 L
.11905 .20907 L
.11905 .2128 L
.11905 .21654 L
.11905 .22027 L
.11905 .22401 L
.11905 .22774 L
.11905 .23148 L
.11905 .23521 L
.11905 .23894 L
s
.14286 .1269 m
.14286 .13063 L
.14286 .13437 L
.14286 .1381 L
.14286 .14184 L
.14286 .14557 L
.14286 .14931 L
.14286 .15304 L
.14286 .15678 L
.14286 .16051 L
.14286 .16425 L
.14286 .16798 L
.14286 .17172 L
.14286 .17545 L
.14286 .17919 L
.14286 .18292 L
.14286 .18666 L
.14286 .19039 L
.14286 .19413 L
.14286 .19786 L
.14286 .2016 L
.14286 .20533 L
.14286 .20907 L
.14286 .2128 L
.14286 .21654 L
.14286 .22027 L
.14286 .22401 L
.14286 .22774 L
.14286 .23148 L
.14286 .23521 L
.14286 .23894 L
s
.16667 .1269 m
.16667 .13063 L
.16667 .13437 L
.16667 .1381 L
.16667 .14184 L
.16667 .14557 L
.16667 .14931 L
.16667 .15304 L
.16667 .15678 L
.16667 .16051 L
.16667 .16425 L
.16667 .16798 L
.16667 .17172 L
.16667 .17545 L
.16667 .17919 L
.16667 .18292 L
.16667 .18666 L
.16667 .19039 L
.16667 .19413 L
.16667 .19786 L
.16667 .2016 L
.16667 .20533 L
.16667 .20907 L
.16667 .2128 L
.16667 .21654 L
.16667 .22027 L
.16667 .22401 L
.16667 .22774 L
.16667 .23148 L
.16667 .23521 L
.16667 .23894 L
s
.19048 .1269 m
.19048 .13063 L
.19048 .13437 L
.19048 .1381 L
.19048 .14184 L
.19048 .14557 L
.19048 .14931 L
.19048 .15304 L
.19048 .15678 L
.19048 .16051 L
.19048 .16425 L
.19048 .16798 L
.19048 .17172 L
.19048 .17545 L
.19048 .17919 L
.19048 .18292 L
.19048 .18666 L
.19048 .19039 L
.19048 .19413 L
.19048 .19786 L
.19048 .2016 L
.19048 .20533 L
.19048 .20907 L
.19048 .2128 L
.19048 .21654 L
.19048 .22027 L
.19048 .22401 L
.19048 .22774 L
.19048 .23148 L
.19048 .23521 L
.19048 .23894 L
s
.21429 .1269 m
.21429 .13063 L
.21429 .13437 L
.21429 .1381 L
.21429 .14184 L
.21429 .14557 L
.21429 .14931 L
.21429 .15304 L
.21429 .15678 L
.21429 .16051 L
.21429 .16425 L
.21429 .16798 L
.21429 .17172 L
.21429 .17545 L
.21429 .17919 L
.21429 .18292 L
.21429 .18666 L
.21429 .19039 L
.21429 .19413 L
.21429 .19786 L
.21429 .2016 L
.21429 .20533 L
.21429 .20907 L
.21429 .2128 L
.21429 .21654 L
.21429 .22027 L
.21429 .22401 L
.21429 .22774 L
.21429 .23148 L
.21429 .23521 L
.21429 .23894 L
s
.2381 .1269 m
.2381 .13063 L
.2381 .13437 L
.2381 .1381 L
.2381 .14184 L
.2381 .14557 L
.2381 .14931 L
.2381 .15304 L
.2381 .15678 L
.2381 .16051 L
.2381 .16425 L
.2381 .16798 L
.2381 .17172 L
.2381 .17545 L
.2381 .17919 L
.2381 .18292 L
.2381 .18666 L
.2381 .19039 L
.2381 .19413 L
.2381 .19786 L
.2381 .2016 L
.2381 .20533 L
.2381 .20907 L
.2381 .2128 L
.2381 .21654 L
.2381 .22027 L
.2381 .22401 L
.2381 .22774 L
.2381 .23148 L
.2381 .23521 L
.2381 .23894 L
s
.2619 .1269 m
.2619 .13063 L
.2619 .13437 L
.2619 .1381 L
.2619 .14184 L
.2619 .14557 L
.2619 .14931 L
.2619 .15304 L
.2619 .15678 L
.2619 .16051 L
.2619 .16425 L
.2619 .16798 L
.2619 .17172 L
.2619 .17545 L
.2619 .17919 L
.2619 .18292 L
.2619 .18666 L
.2619 .19039 L
.2619 .19413 L
.2619 .19786 L
.2619 .2016 L
.2619 .20533 L
.2619 .20907 L
.2619 .2128 L
.2619 .21654 L
.2619 .22027 L
.2619 .22401 L
.2619 .22774 L
.2619 .23148 L
.2619 .23521 L
.2619 .23894 L
s
.28571 .1269 m
.28571 .13063 L
.28571 .13437 L
.28571 .1381 L
.28571 .14184 L
.28571 .14557 L
.28571 .14931 L
.28571 .15304 L
.28571 .15678 L
.28571 .16051 L
.28571 .16425 L
.28571 .16798 L
.28571 .17172 L
.28571 .17545 L
.28571 .17919 L
.28571 .18292 L
.28571 .18666 L
.28571 .19039 L
.28571 .19413 L
.28571 .19786 L
.28571 .2016 L
.28571 .20533 L
.28571 .20907 L
.28571 .2128 L
.28571 .21654 L
.28571 .22027 L
.28571 .22401 L
.28571 .22774 L
.28571 .23148 L
.28571 .23521 L
.28571 .23894 L
s
.30952 .1269 m
.30952 .13063 L
.30952 .13437 L
.30952 .1381 L
.30952 .14184 L
.30952 .14557 L
.30952 .14931 L
.30952 .15304 L
.30952 .15678 L
.30952 .16051 L
.30952 .16425 L
.30952 .16798 L
.30952 .17172 L
.30952 .17545 L
.30952 .17919 L
.30952 .18292 L
.30952 .18666 L
.30952 .19039 L
.30952 .19413 L
.30952 .19786 L
.30952 .2016 L
.30952 .20533 L
.30952 .20907 L
.30952 .2128 L
.30952 .21654 L
.30952 .22027 L
.30952 .22401 L
.30952 .22774 L
.30952 .23148 L
.30952 .23521 L
.30952 .23894 L
s
.33333 .1269 m
.33333 .13063 L
.33333 .13437 L
.33333 .1381 L
.33333 .14184 L
.33333 .14557 L
.33333 .14931 L
.33333 .15304 L
.33333 .15678 L
.33333 .16051 L
.33333 .16425 L
.33333 .16798 L
.33333 .17172 L
.33333 .17545 L
.33333 .17919 L
.33333 .18292 L
.33333 .18666 L
.33333 .19039 L
.33333 .19413 L
.33333 .19786 L
.33333 .2016 L
.33333 .20533 L
.33333 .20907 L
.33333 .2128 L
.33333 .21654 L
.33333 .22027 L
.33333 .22401 L
.33333 .22774 L
.33333 .23148 L
.33333 .23521 L
.33333 .23894 L
s
.35915 .12821 m
.35889 .13186 L
.35865 .13551 L
.35843 .13915 L
.35822 .1428 L
.35804 .14645 L
.35787 .1501 L
.35771 .15374 L
.35758 .15739 L
.35746 .16104 L
.35737 .16469 L
.35729 .16833 L
.35722 .17198 L
.35718 .17563 L
.35715 .17928 L
.35714 .18292 L
.35715 .18657 L
.35718 .19022 L
.35722 .19386 L
.35729 .19751 L
.35737 .20116 L
.35746 .20481 L
.35758 .20845 L
.35771 .2121 L
.35787 .21575 L
.35804 .2194 L
.35822 .22304 L
.35843 .22669 L
.35865 .23034 L
.35889 .23399 L
.35915 .23763 L
s
.38291 .12962 m
.38266 .13318 L
.38242 .13673 L
.3822 .14028 L
.382 .14384 L
.38182 .14739 L
.38166 .15094 L
.38151 .1545 L
.38138 .15805 L
.38127 .1616 L
.38117 .16516 L
.38109 .16871 L
.38103 .17226 L
.38099 .17582 L
.38096 .17937 L
.38095 .18292 L
.38096 .18648 L
.38099 .19003 L
.38103 .19358 L
.38109 .19714 L
.38117 .20069 L
.38127 .20424 L
.38138 .2078 L
.38151 .21135 L
.38166 .2149 L
.38182 .21846 L
.382 .22201 L
.3822 .22556 L
.38242 .22912 L
.38266 .23267 L
.38291 .23622 L
s
.40914 .13127 m
.40857 .13471 L
.40805 .13815 L
.40756 .1416 L
.40712 .14504 L
.40671 .14848 L
.40634 .15193 L
.40601 .15537 L
.40571 .15882 L
.40546 .16226 L
.40525 .1657 L
.40507 .16915 L
.40494 .17259 L
.40484 .17603 L
.40478 .17948 L
.40476 .18292 L
.40478 .18637 L
.40484 .18981 L
.40494 .19325 L
.40507 .1967 L
.40525 .20014 L
.40546 .20359 L
.40571 .20703 L
.40601 .21047 L
.40634 .21392 L
.40671 .21736 L
.40712 .2208 L
.40756 .22425 L
.40805 .22769 L
.40857 .23114 L
.40914 .23458 L
s
.43277 .13341 m
.43222 .13671 L
.43172 .14001 L
.43126 .14331 L
.43083 .14661 L
.43044 .14992 L
.43008 .15322 L
.42976 .15652 L
.42948 .15982 L
.42924 .16312 L
.42904 .16642 L
.42887 .16972 L
.42874 .17302 L
.42865 .17632 L
.42859 .17962 L
.42857 .18292 L
.42859 .18622 L
.42865 .18952 L
.42874 .19282 L
.42887 .19613 L
.42904 .19943 L
.42924 .20273 L
.42948 .20603 L
.42976 .20933 L
.43008 .21263 L
.43044 .21593 L
.43083 .21923 L
.43126 .22253 L
.43172 .22583 L
.43222 .22913 L
.43277 .23243 L
s
.45639 .13556 m
.45588 .13872 L
.45539 .14187 L
.45495 .14503 L
.45454 .14819 L
.45416 .15135 L
.45383 .1545 L
.45352 .15766 L
.45325 .16082 L
.45302 .16398 L
.45283 .16713 L
.45267 .17029 L
.45254 .17345 L
.45245 .17661 L
.4524 .17976 L
.45238 .18292 L
.4524 .18608 L
.45245 .18924 L
.45254 .1924 L
.45267 .19555 L
.45283 .19871 L
.45302 .20187 L
.45325 .20503 L
.45352 .20818 L
.45383 .21134 L
.45416 .2145 L
.45454 .21766 L
.45495 .22081 L
.45539 .22397 L
.45588 .22713 L
.45639 .23029 L
s
.48002 .1377 m
.47953 .14072 L
.47907 .14373 L
.47864 .14675 L
.47825 .14976 L
.47789 .15278 L
.47757 .15579 L
.47728 .15881 L
.47702 .16182 L
.4768 .16483 L
.47662 .16785 L
.47646 .17086 L
.47634 .17388 L
.47626 .17689 L
.47621 .17991 L
.47619 .18292 L
.47621 .18594 L
.47626 .18895 L
.47634 .19197 L
.47646 .19498 L
.47662 .198 L
.4768 .20101 L
.47702 .20402 L
.47728 .20704 L
.47757 .21005 L
.47789 .21307 L
.47825 .21608 L
.47864 .2191 L
.47907 .22211 L
.47953 .22513 L
.48002 .22814 L
s
.50365 .13985 m
.50318 .14272 L
.50274 .14559 L
.50234 .14846 L
.50196 .15134 L
.50162 .15421 L
.50131 .15708 L
.50104 .15995 L
.50079 .16282 L
.50058 .16569 L
.50041 .16856 L
.50026 .17144 L
.50015 .17431 L
.50006 .17718 L
.50002 .18005 L
.5 .18292 L
.50002 .18579 L
.50006 .18867 L
.50015 .19154 L
.50026 .19441 L
.50041 .19728 L
.50058 .20015 L
.50079 .20302 L
.50104 .20589 L
.50131 .20877 L
.50162 .21164 L
.50196 .21451 L
.50234 .21738 L
.50274 .22025 L
.50318 .22312 L
.50365 .226 L
s
.52728 .142 m
.52683 .14472 L
.52641 .14745 L
.52603 .15018 L
.52567 .15291 L
.52535 .15564 L
.52506 .15837 L
.5248 .16109 L
.52456 .16382 L
.52436 .16655 L
.52419 .16928 L
.52406 .17201 L
.52395 .17474 L
.52387 .17747 L
.52382 .18019 L
.52381 .18292 L
.52382 .18565 L
.52387 .18838 L
.52395 .19111 L
.52406 .19384 L
.52419 .19656 L
.52436 .19929 L
.52456 .20202 L
.5248 .20475 L
.52506 .20748 L
.52535 .21021 L
.52567 .21294 L
.52603 .21566 L
.52641 .21839 L
.52683 .22112 L
.52728 .22385 L
s
.5509 .14414 m
.55048 .14673 L
.55009 .14931 L
.54972 .1519 L
.54939 .15448 L
.54908 .15707 L
.5488 .15965 L
.54855 .16224 L
.54833 .16482 L
.54814 .16741 L
.54798 .17 L
.54785 .17258 L
.54775 .17517 L
.54768 .17775 L
.54763 .18034 L
.54762 .18292 L
.54763 .18551 L
.54768 .18809 L
.54775 .19068 L
.54785 .19326 L
.54798 .19585 L
.54814 .19843 L
.54833 .20102 L
.54855 .20361 L
.5488 .20619 L
.54908 .20878 L
.54939 .21136 L
.54972 .21395 L
.55009 .21653 L
.55048 .21912 L
.5509 .2217 L
s
.57453 .14629 m
.57413 .14873 L
.57376 .15117 L
.57341 .15361 L
.5731 .15606 L
.57281 .1585 L
.57255 .16094 L
.57231 .16338 L
.5721 .16583 L
.57193 .16827 L
.57177 .17071 L
.57165 .17315 L
.57155 .1756 L
.57148 .17804 L
.57144 .18048 L
.57143 .18292 L
.57144 .18536 L
.57148 .18781 L
.57155 .19025 L
.57165 .19269 L
.57177 .19513 L
.57193 .19758 L
.5721 .20002 L
.57231 .20246 L
.57255 .2049 L
.57281 .20735 L
.5731 .20979 L
.57341 .21223 L
.57376 .21467 L
.57413 .21712 L
.57453 .21956 L
s
.59816 .14843 m
.59778 .15073 L
.59743 .15303 L
.59711 .15533 L
.59681 .15763 L
.59654 .15993 L
.59629 .16223 L
.59607 .16453 L
.59587 .16683 L
.59571 .16913 L
.59556 .17143 L
.59545 .17373 L
.59535 .17602 L
.59529 .17832 L
.59525 .18062 L
.59524 .18292 L
.59525 .18522 L
.59529 .18752 L
.59535 .18982 L
.59545 .19212 L
.59556 .19442 L
.59571 .19672 L
.59587 .19902 L
.59607 .20132 L
.59629 .20362 L
.59654 .20592 L
.59681 .20821 L
.59711 .21051 L
.59743 .21281 L
.59778 .21511 L
.59816 .21741 L
s
.62179 .15058 m
.62143 .15274 L
.62111 .15489 L
.6208 .15705 L
.62052 .1592 L
.62027 .16136 L
.62003 .16352 L
.61983 .16567 L
.61964 .16783 L
.61949 .16999 L
.61935 .17214 L
.61924 .1743 L
.61916 .17645 L
.6191 .17861 L
.61906 .18077 L
.61905 .18292 L
.61906 .18508 L
.6191 .18723 L
.61916 .18939 L
.61924 .19155 L
.61935 .1937 L
.61949 .19586 L
.61964 .19802 L
.61983 .20017 L
.62003 .20233 L
.62027 .20448 L
.62052 .20664 L
.6208 .2088 L
.62111 .21095 L
.62143 .21311 L
.62179 .21527 L
s
.64542 .15273 m
.64509 .15474 L
.64478 .15675 L
.64449 .15876 L
.64423 .16078 L
.64399 .16279 L
.64378 .1648 L
.64358 .16682 L
.64341 .16883 L
.64327 .17084 L
.64314 .17286 L
.64304 .17487 L
.64296 .17688 L
.6429 .1789 L
.64287 .18091 L
.64286 .18292 L
.64287 .18494 L
.6429 .18695 L
.64296 .18896 L
.64304 .19098 L
.64314 .19299 L
.64327 .195 L
.64341 .19701 L
.64358 .19903 L
.64378 .20104 L
.64399 .20305 L
.64423 .20507 L
.64449 .20708 L
.64478 .20909 L
.64509 .21111 L
.64542 .21312 L
s
.66904 .15487 m
.66874 .15674 L
.66845 .15861 L
.66819 .16048 L
.66794 .16235 L
.66772 .16422 L
.66752 .16609 L
.66734 .16796 L
.66718 .16983 L
.66705 .1717 L
.66693 .17357 L
.66684 .17544 L
.66676 .17731 L
.66671 .17918 L
.66668 .18105 L
.66667 .18292 L
.66668 .18479 L
.66671 .18666 L
.66676 .18853 L
.66684 .1904 L
.66693 .19227 L
.66705 .19414 L
.66718 .19601 L
.66734 .19788 L
.66752 .19975 L
.66772 .20162 L
.66794 .20349 L
.66819 .20536 L
.66845 .20723 L
.66874 .2091 L
.66904 .21097 L
s
.69267 .15702 m
.69239 .15874 L
.69212 .16047 L
.69188 .1622 L
.69166 .16393 L
.69145 .16565 L
.69127 .16738 L
.6911 .16911 L
.69095 .17083 L
.69083 .17256 L
.69072 .17429 L
.69063 .17601 L
.69056 .17774 L
.69052 .17947 L
.69049 .1812 L
.69048 .18292 L
.69049 .18465 L
.69052 .18638 L
.69056 .1881 L
.69063 .18983 L
.69072 .19156 L
.69083 .19328 L
.69095 .19501 L
.6911 .19674 L
.69127 .19847 L
.69145 .20019 L
.69166 .20192 L
.69188 .20365 L
.69212 .20537 L
.69239 .2071 L
.69267 .20883 L
s
.7163 .15916 m
.71604 .16075 L
.7158 .16233 L
.71557 .16392 L
.71537 .1655 L
.71518 .16708 L
.71501 .16867 L
.71486 .17025 L
.71472 .17183 L
.71461 .17342 L
.71451 .175 L
.71443 .17659 L
.71437 .17817 L
.71432 .17975 L
.71429 .18134 L
.71429 .18292 L
.71429 .18451 L
.71432 .18609 L
.71437 .18767 L
.71443 .18926 L
.71451 .19084 L
.71461 .19243 L
.71472 .19401 L
.71486 .19559 L
.71501 .19718 L
.71518 .19876 L
.71537 .20035 L
.71557 .20193 L
.7158 .20351 L
.71604 .2051 L
.7163 .20668 L
s
.73993 .16131 m
.73969 .16275 L
.73947 .16419 L
.73927 .16563 L
.73908 .16707 L
.73891 .16851 L
.73875 .16995 L
.73862 .1714 L
.73849 .17284 L
.73839 .17428 L
.7383 .17572 L
.73823 .17716 L
.73817 .1786 L
.73813 .18004 L
.7381 .18148 L
.7381 .18292 L
.7381 .18436 L
.73813 .1858 L
.73817 .18725 L
.73823 .18869 L
.7383 .19013 L
.73839 .19157 L
.73849 .19301 L
.73862 .19445 L
.73875 .19589 L
.73891 .19733 L
.73908 .19877 L
.73927 .20021 L
.73947 .20165 L
.73969 .20309 L
.73993 .20454 L
s
.76355 .16346 m
.76334 .16475 L
.76314 .16605 L
.76296 .16735 L
.76279 .16865 L
.76264 .16994 L
.7625 .17124 L
.76237 .17254 L
.76226 .17384 L
.76217 .17514 L
.76209 .17643 L
.76202 .17773 L
.76197 .17903 L
.76193 .18033 L
.76191 .18162 L
.7619 .18292 L
.76191 .18422 L
.76193 .18552 L
.76197 .18682 L
.76202 .18811 L
.76209 .18941 L
.76217 .19071 L
.76226 .19201 L
.76237 .19331 L
.7625 .1946 L
.76264 .1959 L
.76279 .1972 L
.76296 .1985 L
.76314 .19979 L
.76334 .20109 L
.76355 .20239 L
s
.78718 .1656 m
.78699 .16676 L
.78682 .16791 L
.78665 .16907 L
.7865 .17022 L
.78637 .17137 L
.78624 .17253 L
.78613 .17368 L
.78603 .17484 L
.78595 .17599 L
.78588 .17715 L
.78582 .1783 L
.78577 .17946 L
.78574 .18061 L
.78572 .18177 L
.78571 .18292 L
.78572 .18408 L
.78574 .18523 L
.78577 .18639 L
.78582 .18754 L
.78588 .1887 L
.78595 .18985 L
.78603 .19101 L
.78613 .19216 L
.78624 .19332 L
.78637 .19447 L
.7865 .19562 L
.78665 .19678 L
.78682 .19793 L
.78699 .19909 L
.78718 .20024 L
s
.81081 .16775 m
.81064 .16876 L
.81049 .16977 L
.81035 .17078 L
.81022 .17179 L
.8101 .17281 L
.80999 .17382 L
.80989 .17483 L
.8098 .17584 L
.80973 .17685 L
.80967 .17786 L
.80962 .17888 L
.80958 .17989 L
.80955 .1809 L
.80953 .18191 L
.80952 .18292 L
.80953 .18393 L
.80955 .18495 L
.80958 .18596 L
.80962 .18697 L
.80967 .18798 L
.80973 .18899 L
.8098 .19 L
.80989 .19102 L
.80999 .19203 L
.8101 .19304 L
.81022 .19405 L
.81035 .19506 L
.81049 .19607 L
.81064 .19709 L
.81081 .1981 L
s
.83444 .16989 m
.83429 .17076 L
.83416 .17163 L
.83404 .1725 L
.83393 .17337 L
.83382 .17424 L
.83373 .1751 L
.83365 .17597 L
.83357 .17684 L
.83351 .17771 L
.83346 .17858 L
.83341 .17945 L
.83338 .18032 L
.83335 .18119 L
.83334 .18205 L
.83333 .18292 L
.83334 .18379 L
.83335 .18466 L
.83338 .18553 L
.83341 .1864 L
.83346 .18727 L
.83351 .18813 L
.83357 .189 L
.83365 .18987 L
.83373 .19074 L
.83382 .19161 L
.83393 .19248 L
.83404 .19335 L
.83416 .19421 L
.83429 .19508 L
.83444 .19595 L
s
.85806 .17204 m
.85795 .17276 L
.85784 .17349 L
.85773 .17422 L
.85764 .17494 L
.85755 .17567 L
.85747 .17639 L
.85741 .17712 L
.85734 .17784 L
.85729 .17857 L
.85725 .17929 L
.85721 .18002 L
.85718 .18075 L
.85716 .18147 L
.85715 .1822 L
.85714 .18292 L
.85715 .18365 L
.85716 .18437 L
.85718 .1851 L
.85721 .18582 L
.85725 .18655 L
.85729 .18728 L
.85734 .188 L
.85741 .18873 L
.85747 .18945 L
.85755 .19018 L
.85764 .1909 L
.85773 .19163 L
.85784 .19235 L
.85795 .19308 L
.85806 .19381 L
s
.88169 .17418 m
.8816 .17477 L
.88151 .17535 L
.88143 .17593 L
.88135 .17651 L
.88128 .1771 L
.88122 .17768 L
.88116 .17826 L
.88111 .17884 L
.88107 .17943 L
.88103 .18001 L
.88101 .18059 L
.88098 .18117 L
.88097 .18176 L
.88096 .18234 L
.88095 .18292 L
.88096 .18351 L
.88097 .18409 L
.88098 .18467 L
.88101 .18525 L
.88103 .18584 L
.88107 .18642 L
.88111 .187 L
.88116 .18758 L
.88122 .18817 L
.88128 .18875 L
.88135 .18933 L
.88143 .18991 L
.88151 .1905 L
.8816 .19108 L
.88169 .19166 L
s
.90532 .17633 m
.90525 .17677 L
.90518 .17721 L
.90512 .17765 L
.90506 .17809 L
.90501 .17853 L
.90496 .17897 L
.90492 .17941 L
.90488 .17985 L
.90485 .18029 L
.90482 .18073 L
.9048 .18116 L
.90478 .1816 L
.90477 .18204 L
.90476 .18248 L
.90476 .18292 L
.90476 .18336 L
.90477 .1838 L
.90478 .18424 L
.9048 .18468 L
.90482 .18512 L
.90485 .18556 L
.90488 .186 L
.90492 .18644 L
.90496 .18688 L
.90501 .18732 L
.90506 .18776 L
.90512 .1882 L
.90518 .18864 L
.90525 .18907 L
.90532 .18951 L
s
.92895 .17848 m
.9289 .17877 L
.92885 .17907 L
.92881 .17937 L
.92877 .17966 L
.92874 .17996 L
.92871 .18026 L
.92868 .18055 L
.92865 .18085 L
.92863 .18114 L
.92861 .18144 L
.9286 .18174 L
.92859 .18203 L
.92858 .18233 L
.92857 .18263 L
.92857 .18292 L
.92857 .18322 L
.92858 .18352 L
.92859 .18381 L
.9286 .18411 L
.92861 .1844 L
.92863 .1847 L
.92865 .185 L
.92868 .18529 L
.92871 .18559 L
.92874 .18589 L
.92877 .18618 L
.92881 .18648 L
.92885 .18678 L
.9289 .18707 L
.92895 .18737 L
s
.95258 .18062 m
.95255 .18078 L
.95253 .18093 L
.95251 .18108 L
.95249 .18124 L
.95247 .18139 L
.95245 .18154 L
.95244 .1817 L
.95242 .18185 L
.95241 .182 L
.9524 .18216 L
.95239 .18231 L
.95239 .18246 L
.95238 .18262 L
.95238 .18277 L
.95238 .18292 L
.95238 .18308 L
.95238 .18323 L
.95239 .18338 L
.95239 .18354 L
.9524 .18369 L
.95241 .18384 L
.95242 .184 L
.95244 .18415 L
.95245 .1843 L
.95247 .18446 L
.95249 .18461 L
.95251 .18476 L
.95253 .18492 L
.95255 .18507 L
.95258 .18522 L
s
0 0 m
1 0 L
1 .3468 L
0 .3468 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[52]:=",
  ImageSize->{288, 99.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Hb000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00I`3oool500000:D0oooo00@000000?ooo`00000000002`3oool006P0
oooo00@000000?ooo`3oool00000Y@3oool200000080oooo00<000000?ooo`3oool0203oool006P0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`02000000X0oooo001X0?ooo`030000
003oool0oooo0:L0oooo0`00000;0?ooo`00J03oool00`000000oooo0?ooo`2V0?ooo`8000000P3o
ool00`000000oooo0?ooo`080?ooo`00J03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0
oooo008000002P3oool006L0oooo0`00002X0?ooo`80000000<0oooo0000003oool02@3oool006`0
oooo1`00002Q0?ooo`030000003oool0oooo00T0oooo001/0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00J`3oool800000:40oooo00<0
00000?ooo`3oool02@3oool006/0oooo0P00000507moO`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool02@3oool006/0oooo0P00000507moO`030000003oool0oooo09l0oooo00<000000?oo
o`3oool02@3oool006X0oooo00<0000007moO`0000001@1oOgl00`000000oooo0?ooo`2O0?ooo`03
0000003oool0oooo00T0oooo001Z0?ooo`030000001oOgl0000000H00000X@3oool00`000000oooo
0?ooo`090?ooo`00J@3oool010000000Ogmo07moO`00000507moO`030000003oool0oooo09l0oooo
00<000000?ooo`3oool02@3oool006T0oooo00@0000007moO`1oOgl000001@1oOgl00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001Y0?ooo`040000001oOgl0Ogmo000000D0Ogmo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00J03oool01@000000Ogmo07mo
O`1oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00J03o
ool01@000000Ogmo07moO`1oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`090?ooo`00I`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I`3oool00`000000Ogmo07moO`02
07moO`L00000X@3oool00`000000oooo0?ooo`090?ooo`00I`3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?oo
o`00IP3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`090?ooo`00IP3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00IP3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`090?ooo`00I@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I@3oool00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`090?ooo`00I@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I03oool00`000000Ogmo
07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`090?ooo`00I03oool00`000000Ogmo07moO`0507moO`L00000X@3oool00`000000oooo0?oo
o`090?ooo`00I03oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I03oool00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?oo
o`00H`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`090?ooo`002P3ooomH00WZ2P030?ooo`000000Ogmo00L0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo
001R0?oooa402NX:X@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P000000Ogmo00P0Ogmo00<0000007moO`1oOgl00`1oOgl00`0000002NX:00WZ2P07
00WZ2YP0oooo00<000000?ooo`3oool02@3oool000X0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0000007moO`0407moO`0700WZ2P1oOgl0Ogmo07moO`000000Ogmo00WZ2P0307moO`050000003o
ool0oooo0?ooo`09jPX01@3oool900WZ2Xl0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0000007moO`0407moO`0700WZ2P1oOgl0Ogmo07moO`000000
Ogmo00WZ2P0307moO`050000003oool0oooo0?ooo`09jPX01@3oool00`09jPX0oooo0?ooo`060?oo
o`d02NX:PP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P000000Ogmo00@0Ogmo00L02NX:07moO`1oOgl0Ogmo0000001oOgl02NX:00<0Ogmo00@00000
0?ooo`3oool02NX:1P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<0
2NX:0?ooo`3oool01P3oool900WZ2WT0oooo00<000000?ooo`3oool02@3oool000X0oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0000007moO`0407moO`0700WZ2P1oOgl0Ogmo07moO`000000Ogmo
00WZ2P0307moO`040000003oool0oooo00WZ2PH0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool01009jPX0
oooo0?ooo`3oool900WZ2W00oooo00<000000?ooo`3oool02@3oool000X0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0000007moO`0307moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P0000000`09jPX0
00000000000200000080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool900WZ2VL0oooo00<000000?ooo`3o
ool02@3oool000X0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0000007moO`0307moO`0300WZ
2P1oOgl0Ogmo0080Ogmo00<0000007moO`09jPX00`1oOgl010000000oooo0?ooo`09jPX60?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool03@09jPYJ0?ooo`030000003oool0oooo00T0
oooo000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0000001oOgl00`1oOgl00`09jPX0Ogmo
07moO`0207moO`030000001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1P3oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo00WZ2P0800WZ2U40oooo00<000000?ooo`3oool02@3oool000X0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0000007moO`0307moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`09jPX0
0`1oOgl010000000oooo0?ooo`09jPX50?ooo`802NX:1@3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`020?ooo`T0
2NX:B03oool00`000000oooo0?ooo`090?ooo`002P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000Ogmo00WZ2P0307moO`040000
003oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo2P09jPXo0?ooo`030000003oool0oooo00T0oooo000:0?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0207moO`030000
001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1@3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool00`3oool200WZ2PD0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0=00WZ2S80
oooo00<000000?ooo`3oool02@3oool000X0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0Ogmo
07moO`0307moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`09jPX00`1oOgl010000000oooo
0?ooo`09jPX50?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00T02NX::@3oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
0`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl00`000000Ogmo00WZ2P0307moO`040000003oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`020?ooo`T02NX:803oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
0`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl00`000000Ogmo00WZ2P0307moO`040000003oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool00`3oool200WZ2PD0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool:00WZ2QL0oooo00<000000?ooo`3o
ool02@3oool000X0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00<0oooo00<0000000WZ2P0000001@3oool00`09jPX0Ogmo07moO`0307moO`0300WZ
2P1oOgl0Ogmo00<0000000<0Ogmo00WZ2P1oOgl00P1oOgl00`000000oooo00WZ2P060?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
0`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
0`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
0`3oool01009jPX0oooo0?ooo`3oool=00WZ2P80oooo0`0000050?ooo`030000003oool0oooo00T0
oooo000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P000000000000<0000000<0oooo00WZ2P1oOgl0101oOgl01009jPX0Ogmo
07moO`1oOgl30000000700WZ2P000000000007moO`000000oooo00WZ2P060?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`802NX:0P3oool4
00WZ2PD0000000<0oooo0000003oool02P3oool000X0oooo00<02NX:000000000000100000000`09
jPX00000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09
jPX00000000000030000000300WZ2P000000000000@0000000<02NX:000000000000100000000`09
jPX00000000000030000000300WZ2P000000000000@0000000<02NX:000000000000100000000`09
jPX00000000000030000000300WZ2P000000000000@0000000<02NX:000000000000100000000`09
jPX00000000000030000000300WZ2P000000000000@0000000<02NX:0000000000000`0000000`09
jPX00000000000040000000300WZ2P000000000000@0000000<02NX:0000000000000`0000000`09
jPX00000000000040000000300WZ2P000000000000@0000000<02NX:0000000000000`0000000`09
jPX00000000000040000000300WZ2P000000000000@0000000<02NX:0000000000000`0000000`09
jPX00000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09
jPX00000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09
jPX00000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09
jPX00000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09
jPX0000000000003000000802NX:1@0000000`09jPX0000000000005000000/0oooo000:0?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P0000000000008000000P3oool00`09jPX0Ogmo07moO`0307moO`0400WZ2P1oOgl0Ogmo07mo
O`<0000000L02NX:0000001oOgl0Ogmo0000003oool02NX:00H0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool0oooo0?ooo`T02NX:1@0000020?ooo`030000
003oool0oooo00T0oooo000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`030?ooo`0300000009jPX0oooo00D0oooo00<02NX:07moO`1oOgl00`1o
Ogl00`09jPX0Ogmo07moO`030000000307moO`09jPX0Ogmo0080Ogmo00<000000?ooo`09jPX01P3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00P02NX:203oool2000000H0oooo00<0
00000?ooo`3oool02@3oool000X0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0Ogmo07moO`03
07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`09jPX00`1oOgl010000000oooo0?ooo`09
jPX50?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool00`3oool200WZ2PD0oooo00<02NX:0?ooo`09jPX03@09jPXH0?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:07moO`1oOgl00`1oOgl0
0`09jPX0Ogmo07moO`0207moO`030000001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1@3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`T02NX:9P3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl00P1oOgl0
0`000000Ogmo00WZ2P0307moO`040000003oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0080oooo2009jPX_0?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:07moO`1oOgl00`1oOgl0
0`09jPX0Ogmo07moO`0207moO`030000001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1@3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPX50?ooo`0300WZ2P3o
ool0oooo00@0oooo00<02NX:0?ooo`09jPX02009jPXg0?ooo`030000003oool0oooo00T0oooo000:
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`02
07moO`030000001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1@3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`09jPX03009jPY00?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0000001oOgl00`1oOgl0
0`09jPX0Ogmo07moO`0207moO`030000001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1P3o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool200WZ2PD0oooo2@09jPY=0?ooo`030000003oool0oooo00T0oooo000:0?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0000001oOgl00`1oOgl00`09jPX0Ogmo07moO`0207moO`030000001oOgl0
2NX:00<0Ogmo00@000000?ooo`3oool02NX:1P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3o
ool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3o
ool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3o
ool0oooo00@0oooo00@02NX:0?ooo`3oool0oooo2@09jPYF0?ooo`030000003oool0oooo00T0oooo
000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?oo
o`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0000001oOgl00`1oOgl00`09jPX0Ogmo07mo
O`0207moO`030000001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1P3oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool01009jPX0oooo
0?ooo`3oool=00WZ2Ul0oooo00<000000?ooo`3oool02@3oool000X0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0000007moO`0307moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P0000000`09jPX00000
0000000200000080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`09jPX02009jPY/0?ooo`030000003oool0oooo00T0oooo
000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?oo
o`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0000001oOgl0101oOgl01`09jPX0Ogmo07mo
O`1oOgl0000007moO`09jPX00`1oOgl010000000oooo0?ooo`09jPX60?ooo`0300WZ2P3oool0oooo
00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo
00<0oooo2@09jPYe0?ooo`030000003oool0oooo00T0oooo000:0?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0000001oOgl0101oOgl01`09jPX0Ogmo07moO`1oOgl0000007moO`09jPX00`1oOgl0
1@000000oooo0?ooo`3oool02NX:00D0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?oo
o`070?ooo`T02NX:OP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P000000Ogmo00@0Ogmo00L02NX:07moO`1oOgl0Ogmo0000001oOgl02NX:00<0Ogmo
00D000000?ooo`3oool0oooo00WZ2P050?ooo`0400WZ2P3oool0oooo0?ooo`d02NX:Q`3oool00`00
0000oooo0?ooo`090?ooo`002P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P000000Ogmo00@0
Ogmo00L02NX:07moO`1oOgl0Ogmo0000001oOgl02NX:00<0Ogmo00<000000?ooo`3oool00P3oool9
00WZ2Y@0oooo00<000000?ooo`3oool02@3oool00680oooo00<0000007moO`1oOgl01@1oOgl=00WZ
2Yd0oooo00<000000?ooo`3oool02@3oool000X0ooooH009jPX207moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00H`3oool00`000000Ogmo
07moO`0607moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`090?ooo`00H`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00H`3oool00`000000Ogmo07moO`06
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`09
0?ooo`00I03oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I03oool00`000000Ogmo07moO`0507moO`L0
0000X@3oool00`000000oooo0?ooo`090?ooo`00I03oool00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I@3o
ool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`090?ooo`00I@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I@3oool00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`090?ooo`00I@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00IP3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`090?ooo`00IP3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00IP3oool00`000000Ogmo07moO`03
07moO`L00000X@3oool00`000000oooo0?ooo`090?ooo`00I`3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?oo
o`00I`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`090?ooo`00J03oool01@000000Ogmo07moO`1oOgl0000000D0
Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00J03oool01@000000Ogmo
07moO`1oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00
J03oool01@000000Ogmo07moO`1oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000
oooo0?ooo`090?ooo`00J@3oool010000000Ogmo07moO`00000507moO`030000003oool0oooo09l0
oooo00<000000?ooo`3oool02@3oool006T0oooo00<0000007moO`1oOgl01`00002Q0?ooo`030000
003oool0oooo00T0oooo001Z0?ooo`030000001oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`090?ooo`00JP3oool00`000000Ogmo0000000507moO`030000003oool0
oooo09l0oooo00<000000?ooo`3oool02@3oool006/0oooo0P00000507moO`030000003oool0oooo
09l0oooo00<000000?ooo`3oool02@3oool006/0oooo0P00000507moO`030000003oool0oooo09l0
oooo00<000000?ooo`3oool02@3oool006/0oooo2000002Q0?ooo`030000003oool0oooo00T0oooo
001/0?ooo`L00000X@3oool00`000000oooo0?ooo`090?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {98.875, 0}} -> {-56.197, -30.6532, 0.576286, \
0.576286}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}]
}, Open  ]],

Cell["intensity = FindField[waveletSystem];", "Input",
  CellLabel->"In[53]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],

Cell[CellGroupData[{

Cell["Plot[intensity[0,y],{y,-.05,.05},PlotRange->All];", "Input",
  CellLabel->"In[54]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 9.52381 0.0139246 0.0203101 [
[.11905 .00142 -15 -9 ]
[.11905 .00142 15 0 ]
[.30952 .00142 -15 -9 ]
[.30952 .00142 15 0 ]
[.69048 .00142 -12 -9 ]
[.69048 .00142 12 0 ]
[.88095 .00142 -12 -9 ]
[.88095 .00142 12 0 ]
[.4875 .11548 -6 -4.5 ]
[.4875 .11548 0 4.5 ]
[.4875 .21703 -12 -4.5 ]
[.4875 .21703 0 4.5 ]
[.4875 .31858 -12 -4.5 ]
[.4875 .31858 0 4.5 ]
[.4875 .42013 -12 -4.5 ]
[.4875 .42013 0 4.5 ]
[.4875 .52168 -12 -4.5 ]
[.4875 .52168 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .01392 m
.11905 .02017 L
s
[(-0.04)] .11905 .00142 0 1 Mshowa
.30952 .01392 m
.30952 .02017 L
s
[(-0.02)] .30952 .00142 0 1 Mshowa
.69048 .01392 m
.69048 .02017 L
s
[(0.02)] .69048 .00142 0 1 Mshowa
.88095 .01392 m
.88095 .02017 L
s
[(0.04)] .88095 .00142 0 1 Mshowa
.125 Mabswid
.16667 .01392 m
.16667 .01767 L
s
.21429 .01392 m
.21429 .01767 L
s
.2619 .01392 m
.2619 .01767 L
s
.35714 .01392 m
.35714 .01767 L
s
.40476 .01392 m
.40476 .01767 L
s
.45238 .01392 m
.45238 .01767 L
s
.54762 .01392 m
.54762 .01767 L
s
.59524 .01392 m
.59524 .01767 L
s
.64286 .01392 m
.64286 .01767 L
s
.7381 .01392 m
.7381 .01767 L
s
.78571 .01392 m
.78571 .01767 L
s
.83333 .01392 m
.83333 .01767 L
s
.07143 .01392 m
.07143 .01767 L
s
.02381 .01392 m
.02381 .01767 L
s
.92857 .01392 m
.92857 .01767 L
s
.97619 .01392 m
.97619 .01767 L
s
.25 Mabswid
0 .01392 m
1 .01392 L
s
.5 .11548 m
.50625 .11548 L
s
[(5)] .4875 .11548 1 0 Mshowa
.5 .21703 m
.50625 .21703 L
s
[(10)] .4875 .21703 1 0 Mshowa
.5 .31858 m
.50625 .31858 L
s
[(15)] .4875 .31858 1 0 Mshowa
.5 .42013 m
.50625 .42013 L
s
[(20)] .4875 .42013 1 0 Mshowa
.5 .52168 m
.50625 .52168 L
s
[(25)] .4875 .52168 1 0 Mshowa
.125 Mabswid
.5 .03423 m
.50375 .03423 L
s
.5 .05454 m
.50375 .05454 L
s
.5 .07485 m
.50375 .07485 L
s
.5 .09516 m
.50375 .09516 L
s
.5 .13579 m
.50375 .13579 L
s
.5 .1561 m
.50375 .1561 L
s
.5 .17641 m
.50375 .17641 L
s
.5 .19672 m
.50375 .19672 L
s
.5 .23734 m
.50375 .23734 L
s
.5 .25765 m
.50375 .25765 L
s
.5 .27796 m
.50375 .27796 L
s
.5 .29827 m
.50375 .29827 L
s
.5 .33889 m
.50375 .33889 L
s
.5 .3592 m
.50375 .3592 L
s
.5 .37951 m
.50375 .37951 L
s
.5 .39982 m
.50375 .39982 L
s
.5 .44044 m
.50375 .44044 L
s
.5 .46075 m
.50375 .46075 L
s
.5 .48106 m
.50375 .48106 L
s
.5 .50137 m
.50375 .50137 L
s
.5 .54199 m
.50375 .54199 L
s
.5 .5623 m
.50375 .5623 L
s
.5 .58261 m
.50375 .58261 L
s
.5 .60292 m
.50375 .60292 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .01472 m
.03279 .01494 L
.04262 .01524 L
.05288 .01565 L
.06244 .01614 L
.0828 .0176 L
.09421 .01876 L
.10458 .02009 L
.12373 .02341 L
.13453 .0259 L
.14451 .0287 L
.16324 .03549 L
.18386 .04586 L
.20327 .05911 L
.22415 .07797 L
.24528 .10274 L
.26537 .13224 L
.30357 .20517 L
.34421 .3043 L
.38334 .41021 L
.40332 .46266 L
.42492 .51396 L
.44402 .55184 L
.45487 .56932 L
.46499 .58262 L
.47461 .59234 L
.48001 .59649 L
.48493 .59943 L
.48744 .60062 L
.49011 .60164 L
.4915 .60208 L
.49304 .60249 L
.49445 .60279 L
.49574 .60301 L
.49698 .60316 L
.49829 .60327 L
.4996 .60332 L
.50034 .60332 L
.50103 .6033 L
.50229 .60323 L
.50343 .60312 L
.50475 .60293 L
.50599 .6027 L
.50838 .60211 L
.51062 .60138 L
.51571 .59909 L
.52068 .59602 L
.52601 .59181 L
.53565 .58187 L
.54446 .5703 L
Mistroke
.56348 .53795 L
.58422 .49317 L
.62492 .38781 L
.6641 .28263 L
.70573 .18541 L
.72664 .14566 L
.74585 .11502 L
.76583 .08895 L
.78445 .06957 L
.80332 .05419 L
.82399 .04151 L
.84439 .03246 L
.86296 .02656 L
.88208 .02226 L
.89288 .02046 L
.90285 .01911 L
.92156 .01723 L
.9322 .01646 L
.94217 .01589 L
.95083 .01549 L
.95993 .01516 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[54]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00803oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0`00000O0?oo
o`800000103oool00`000000oooo0?ooo`030?ooo`8000000P3oool500000500oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000020?ooo`D000007`3oool2000000@0oooo00<000000?oo
o`3oool00`3oool2000000@0oooo0`00000N0?ooo`007`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool07@3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000C`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000007P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool07@3oool001P0oooo1@0000020?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3o
ool000000?ooo`05000001L0oooo1@0000020?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`1?0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo0000
00P0oooo00D000000?ooo`3oool000000?ooo`05000001h0oooo000O0?ooo`040000003oool0oooo
000000P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo01d0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
04h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo01d0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo0000
0080oooo00<000000?ooo`3oool07@3oool001l0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0000001l0oooo00@000000?ooo`3oool00000203o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0C@3oool010000000
oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`0L0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0000000O0?ooo`007`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00<0oooo0P00000O0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo04d0oooo00@000000?ooo`3oool00000203oool01P000000
oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0703oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000<0oooo0P00000O0?ooo`00803oool2000000X0oooo0P00
00050?ooo`030000003oool0oooo01h0oooo0P00000:0?ooo`8000000`3oool300000540oooo0P00
000:0?ooo`8000000`3oool300000200oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?oo
o`0M0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?oo
o`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`001`3o
oooo000001800000203oool000d0oooo00<000000?ooo`3oool0203oool;000000@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`d00000203oool00`000000oooo0?ooo`0<
0?ooo`008`3oool5000003<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo02l0oooo1`00000T0?ooo`009`3oool700000640oooo00<000000?ooo`3o
ool0G`3oool4000002/0oooo000^0?ooo`800000G`3oool00`000000oooo0?ooo`1L0?ooo`<00000
;`3oool00300oooo0`00001L0?ooo`800000F`3oool200000380oooo000c0?ooo`800000FP3oool0
0`000000oooo0?ooo`1G0?ooo`<00000=03oool003D0oooo0P00001H0?ooo`030000003oool0oooo
05@0oooo0`00000g0?ooo`00=`3oool2000005H0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0h0?ooo`00>@3oool2000005@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`0i0?ooo`00>`3oool200000580oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`0j0?ooo`00?@3oool00`000000oooo0?ooo`1?0?ooo`800000D03oool2000003d0oooo000n0?oo
o`800000C`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03d0oooo00100?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool0C03oool200000400oooo00110?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`100?ooo`00@P3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0@@3o
ool004<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo0480oooo00140?ooo`030000003oool0oooo04P0oooo0P0000190?ooo`030000003oool0oooo
04<0oooo00140?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`140?ooo`00A@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0A@3oool004H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo04H0oooo00170?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`160?ooo`00B03oool00`000000oooo0?ooo`140?oo
o`800000A@3oool00`000000oooo0?ooo`170?ooo`00B@3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool0B03oool004X0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04P0oooo001:0?ooo`030000003o
ool0oooo03X0oooo0`0000050?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0B@3o
ool004/0oooo00<000000?ooo`3oool0>03oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`190?ooo`00C03oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1:
0?ooo`00C03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo0`0000100?oo
o`030000003oool0oooo04/0oooo001=0?ooo`030000003oool0oooo03H0oooo100000050?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0B`3oool004d0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
C03oool004h0oooo00<000000?ooo`3oool0=@3oool5000000@0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`1=0?ooo`00C`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool0C@3oool004l0oooo00<000000?ooo`3oool0?@3oool20000
03h0oooo00<000000?ooo`3oool0CP3oool00500oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo04h0oooo001@0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1?0?ooo`00D@3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0D03oool00540oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0500oooo001B0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1A0?oo
o`00D`3oool00`000000oooo0?ooo`0i0?ooo`800000>`3oool00`000000oooo0?ooo`1A0?ooo`00
D`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
DP3oool005@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0580oooo001D0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`1C0?ooo`00E@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0E03oool005D0oooo00<000000?ooo`3oool0=`3oool2000003P0
oooo00<000000?ooo`3oool0E03oool005H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo05D0oooo001F0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`1E0?ooo`00E`3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0EP3oool005P0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo05H0oooo001H0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1G0?ooo`00
F@3oool00`000000oooo0?ooo`0c0?ooo`800000=@3oool00`000000oooo0?ooo`1G0?ooo`00F@3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0E`3o
ool005X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo05P0oooo001J0?ooo`030000003oool0oooo02@0oooo0`0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo05P0oooo001K0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0F@3oool005/0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`00000b0?ooo`030000003oool0oooo
05T0oooo001K0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0FP3oool005`0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1J0?ooo`00G03oool00`000000
oooo0?ooo`0R0?ooo`800000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0FP3oool005d0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05/0
oooo001M0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`1K0?ooo`00G@3oool00`000000oooo0?ooo`0_0?ooo`800000<03oool00`000000oooo0?oo
o`1L0?ooo`00GP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0G03oool005h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo05d0oooo001O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`1M0?ooo`00G`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0G@3oool00600oooo00<000000?ooo`3oool0;03o
ool2000002h0oooo00<000000?ooo`3oool0GP3oool00600oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05h0oooo001P0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1O0?ooo`00H@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0G`3oool00640oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0600oooo
001R0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`1P0?ooo`00HP3oool00`000000oooo0?ooo`0Z0?ooo`800000;03oool00`000000oooo0?ooo`1P
0?ooo`00HP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0H@3oool006<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0640oooo001S0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3oool0:03oool2
000002X0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo06<0oooo001U0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1S0?ooo`00I@3oool00`000000oooo
0?ooo`0I0?ooo`<000000`3oool3000000D0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`1S0?ooo`00IP3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
I03oool006H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1T0?ooo`00IP3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool3
000002H0oooo00<000000?ooo`3oool0I@3oool006L0oooo00<000000?ooo`3oool0603oool01000
0000oooo0?ooo`3oool4000000D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1U
0?ooo`00I`3oool00`000000oooo0?ooo`0G0?ooo`8000000`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0I@3oool006L0oooo00<000000?ooo`3o
ool0603oool010000000oooo0?ooo`3oool5000000@0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`1V0?ooo`00J03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0IP3oool006P0oooo00<000000?ooo`3oool0903oool2000002D0oooo
00<000000?ooo`3oool0I`3oool006P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo06L0oooo001Y0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`1W0?ooo`00J@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0J03oool006T0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06P0oooo001Z0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1X0?ooo`00JP3o
ool00`000000oooo0?ooo`0R0?ooo`8000008`3oool00`000000oooo0?ooo`1Y0?ooo`00JP3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0J@3oool0
06/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
06X0oooo001[0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`1Z0?ooo`00J`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0JP3oool006`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo06/0oooo001/0?ooo`030000003oool0oooo0200oooo0P00000Q
0?ooo`030000003oool0oooo06/0oooo001/0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`1[0?ooo`00K@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0K03oool006d0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06`0oooo001]0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1]0?ooo`00KP3oool0
0`000000oooo0?ooo`0N0?ooo`8000007`3oool00`000000oooo0?ooo`1]0?ooo`00KP3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0K@3oool006h0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06h0
oooo001_0?ooo`030000003oool0oooo00h0oooo1@0000030?ooo`8000001@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo06h0oooo001_0?ooo`030000003oool0oooo00l0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0K`3oool00700oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`1_0?ooo`00L03oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`<00000703oool00`000000oooo0?ooo`1_0?ooo`00
L@3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0L03oool00740
oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0700oooo001a0?oo
o`030000003oool0oooo00d0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0740oooo001b0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`1a0?ooo`00LP3oool00`000000oooo0?ooo`0J0?ooo`800000
6`3oool00`000000oooo0?ooo`1a0?ooo`00L`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0LP3oool007<0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0780oooo001d0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1b0?ooo`00M03oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0L`3oool007@0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo07<0oooo
001e0?ooo`030000003oool0oooo01L0oooo0P00000H0?ooo`030000003oool0oooo07@0oooo001e
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1d
0?ooo`00MP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0M03oool007H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo07D0oooo001g0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`1e0?ooo`00M`3oool00`000000oooo0?ooo`0E0?ooo`8000005P3o
ool00`000000oooo0?ooo`1f0?ooo`00M`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0MP3oool007P0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo07H0oooo001h0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1g0?ooo`00N@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M`3oool007T0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07P0oooo001j
0?ooo`030000003oool0oooo0180oooo0P00000D0?ooo`030000003oool0oooo07P0oooo001j0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1i0?oo
o`00NP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0N@3oool007/0oooo00<000000?ooo`3oool00P3oool500000080oooo0`0000050?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0NP3oool007/0oooo00<000000?ooo`3oool00`3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo07X0oooo001l0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`<000004@3oool00`000000oooo
0?ooo`1j0?ooo`00O03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07/0oooo001m
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`0000050?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0N`3oool007d0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo000000080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0O03o
ool007h0oooo00<000000?ooo`3oool00`0000020?ooo`D00000103oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo07`0oooo001n0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`1m0?ooo`00O`3oool00`000000oooo0?ooo`0=0?ooo`80
00003`3oool00`000000oooo0?ooo`1m0?ooo`00O`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0OP3oool00800oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07l0oooo00200?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1o0?ooo`00P@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0P03oool00880
oooo00<000000?ooo`3oool02P3oool2000000`0oooo00<000000?ooo`3oool0P03oool00880oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0840oooo
00230?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`220?ooo`00P`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0PP3oool008@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo08<0oooo00240?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`230?ooo`00Q@3oool00`000000oooo0?ooo`070?ooo`800000
1`3oool2000008H0oooo00260?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`260?ooo`00Q`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0Q`3oool008P0oooo0P0000050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0Q`3oool008X0oooo0P0000030?ooo`040000003oool0oooo0?oo
o`<00000RP3oool008`0oooo1`00002=0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3o
ool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`00
0000oooo0?ooo`2>0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0553233, -2.24287, \
0.000385529, 0.180782}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot3D[intensity[x,y],{x,0,.55},{y,-.04,.04},PlotRange->All,PlotPoints->50];
\
\>", "Input",
  CellLabel->"In[55]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.48526e-16 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.24711 .15979 -17.2719 -9 ]
[.24711 .15979 .72814 0 ]
[.48682 .06553 -15.9072 -9 ]
[.48682 .06553 2.09282 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 30 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 30 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 24 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 24 3.14607 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01261 .33721 -18 -2.80331 ]
[.01261 .33721 0 6.19669 ]
[.00056 .41276 -18 -2.86754 ]
[.00056 .41276 0 6.13246 ]
[-0.01209 .49203 -18 -2.93525 ]
[-0.01209 .49203 0 6.06475 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.25599 .16945 m
.26043 .17428 L
s
[(0.2)] .24711 .15979 .9191 1 Mshowa
.49481 .07594 m
.4988 .08114 L
s
[(0.4)] .48682 .06553 .76746 1 Mshowa
.125 Mabswid
.09013 .23439 m
.09296 .23713 L
s
.14424 .21321 m
.14702 .216 L
s
.19951 .19156 m
.20223 .19441 L
s
.31372 .14684 m
.31632 .1498 L
s
.37274 .12374 m
.37527 .12675 L
s
.43308 .10011 m
.43555 .10317 L
s
.55796 .05121 m
.56028 .05439 L
s
.62258 .0259 m
.62482 .02914 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-0.04)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-0.02)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.02)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.04)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.71016 .03277 m
.70649 .03419 L
s
.73096 .06459 m
.72728 .06598 L
s
.75117 .0955 m
.74748 .09687 L
s
.78989 .15473 m
.78618 .15605 L
s
.80845 .18312 m
.80473 .18442 L
s
.8265 .21073 m
.82278 .21202 L
s
.86118 .26378 m
.85745 .26503 L
s
.87784 .28927 m
.87411 .2905 L
s
.89408 .3141 m
.89033 .31531 L
s
.92532 .36189 m
.92156 .36307 L
s
.94036 .3849 m
.9366 .38606 L
s
.95503 .40734 m
.95127 .40849 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02489 .33258 m
.03103 .33026 L
s
[(100)] .01261 .33721 1 -0.37704 Mshowa
.01289 .40829 m
.01906 .40605 L
s
[(200)] .00056 .41276 1 -0.36277 Mshowa
.0003 .48772 m
.0065 .48556 L
s
[(300)] -0.01209 .49203 1 -0.34772 Mshowa
.125 Mabswid
.03409 .27452 m
.03776 .27309 L
s
.03182 .28883 m
.03549 .28741 L
s
.02953 .30328 m
.03321 .30187 L
s
.02722 .31786 m
.0309 .31646 L
s
.02253 .34743 m
.02622 .34605 L
s
.02016 .36243 m
.02385 .36106 L
s
.01776 .37757 m
.02145 .37621 L
s
.01534 .39285 m
.01903 .3915 L
s
.01042 .42387 m
.01413 .42253 L
s
.00793 .4396 m
.01164 .43827 L
s
.00541 .45548 m
.00912 .45417 L
s
.00287 .47152 m
.00658 .47022 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.667 .746 .909 r
.39888 .5983 .40511 .60399 .41557 .60077 .40936 .59504 Metetra
.666 .745 .909 r
.40936 .59504 .41557 .60077 .42607 .59756 .41989 .59179 Metetra
.666 .744 .909 r
.41989 .59179 .42607 .59756 .4366 .59436 .43045 .58854 Metetra
.665 .743 .908 r
.43045 .58854 .4366 .59436 .44718 .59115 .44105 .58529 Metetra
.665 .743 .908 r
.44105 .58529 .44718 .59115 .4578 .58794 .4517 .58205 Metetra
.664 .742 .908 r
.4517 .58205 .4578 .58794 .46846 .58473 .46239 .5788 Metetra
.664 .742 .908 r
.46239 .5788 .46846 .58473 .47916 .58151 .47312 .57555 Metetra
.664 .742 .908 r
.47312 .57555 .47916 .58151 .4899 .57828 .48389 .5723 Metetra
.664 .741 .908 r
.48389 .5723 .4899 .57828 .50069 .57504 .4947 .56904 Metetra
.664 .741 .908 r
.4947 .56904 .50069 .57504 .51152 .57179 .50556 .56576 Metetra
.664 .741 .908 r
.50556 .56576 .51152 .57179 .52239 .56853 .51646 .56248 Metetra
.664 .741 .908 r
.51646 .56248 .52239 .56853 .5333 .56526 .5274 .55918 Metetra
.664 .741 .908 r
.5274 .55918 .5333 .56526 .54426 .56197 .53839 .55587 Metetra
.664 .741 .908 r
.53839 .55587 .54426 .56197 .55526 .55867 .54942 .55254 Metetra
.664 .741 .908 r
.54942 .55254 .55526 .55867 .56631 .55536 .56049 .5492 Metetra
.664 .741 .908 r
.56049 .5492 .56631 .55536 .5774 .55203 .57161 .54585 Metetra
.664 .741 .908 r
.57161 .54585 .5774 .55203 .58853 .54869 .58277 .54249 Metetra
.664 .741 .908 r
.58277 .54249 .58853 .54869 .59971 .54534 .59398 .53911 Metetra
.664 .741 .908 r
.59398 .53911 .59971 .54534 .61094 .54197 .60524 .53572 Metetra
.664 .741 .908 r
.60524 .53572 .61094 .54197 .62221 .53859 .61654 .53231 Metetra
.664 .741 .908 r
.61654 .53231 .62221 .53859 .63352 .53519 .62788 .52889 Metetra
.664 .741 .908 r
.62788 .52889 .63352 .53519 .64488 .53178 .63928 .52546 Metetra
.664 .741 .908 r
.63928 .52546 .64488 .53178 .65629 .52836 .65071 .52201 Metetra
.664 .741 .908 r
.65071 .52201 .65629 .52836 .66774 .52493 .6622 .51855 Metetra
.664 .741 .908 r
.6622 .51855 .66774 .52493 .67924 .52148 .67373 .51507 Metetra
.664 .741 .908 r
.67373 .51507 .67924 .52148 .69079 .51801 .68531 .51158 Metetra
.664 .741 .908 r
.68531 .51158 .69079 .51801 .70238 .51453 .69694 .50808 Metetra
.664 .741 .908 r
.69694 .50808 .70238 .51453 .71403 .51104 .70861 .50456 Metetra
.664 .741 .908 r
.70861 .50456 .71403 .51104 .72572 .50753 .72034 .50102 Metetra
.664 .741 .908 r
.72034 .50102 .72572 .50753 .73745 .50401 .73211 .49747 Metetra
.664 .741 .908 r
.73211 .49747 .73745 .50401 .74924 .50048 .74393 .49391 Metetra
.664 .741 .908 r
.74393 .49391 .74924 .50048 .76108 .49693 .7558 .49033 Metetra
.664 .741 .908 r
.7558 .49033 .76108 .49693 .77296 .49336 .76772 .48674 Metetra
.664 .741 .908 r
.76772 .48674 .77296 .49336 .78489 .48978 .77968 .48313 Metetra
.664 .741 .908 r
.77968 .48313 .78489 .48978 .79688 .48619 .7917 .47951 Metetra
.664 .741 .908 r
.7917 .47951 .79688 .48619 .80891 .48258 .80377 .47587 Metetra
.664 .741 .908 r
.80377 .47587 .80891 .48258 .82099 .47895 .81589 .47222 Metetra
.664 .741 .908 r
.81589 .47222 .82099 .47895 .83313 .47531 .82806 .46855 Metetra
.664 .741 .908 r
.82806 .46855 .83313 .47531 .84531 .47166 .84028 .46487 Metetra
.663 .741 .908 r
.84028 .46487 .84531 .47166 .85755 .46799 .85256 .46117 Metetra
.663 .741 .908 r
.85256 .46117 .85755 .46799 .86984 .4643 .86488 .45746 Metetra
.663 .741 .908 r
.86488 .45746 .86984 .4643 .88218 .46061 .87726 .45374 Metetra
.663 .741 .908 r
.87726 .45374 .88218 .46061 .89457 .4569 .88969 .45001 Metetra
.663 .741 .909 r
.88969 .45001 .89457 .4569 .90701 .45318 .90218 .44627 Metetra
.662 .742 .909 r
.90218 .44627 .90701 .45318 .91951 .44946 .91472 .44253 Metetra
.662 .742 .909 r
.91472 .44253 .91951 .44946 .93207 .44573 .92732 .43879 Metetra
.661 .742 .91 r
.92732 .43879 .93207 .44573 .94468 .442 .93997 .43505 Metetra
.661 .742 .911 r
.93997 .43505 .94468 .442 .95735 .43827 .95268 .43132 Metetra
.66 .743 .911 r
.95268 .43132 .95735 .43827 .97007 .43454 .96545 .42758 Metetra
.668 .747 .91 r
.3926 .5926 .39888 .5983 .40936 .59504 .40311 .5893 Metetra
.667 .746 .909 r
.40311 .5893 .40936 .59504 .41989 .59179 .41366 .586 Metetra
.667 .745 .909 r
.41366 .586 .41989 .59179 .43045 .58854 .42425 .5827 Metetra
.666 .744 .909 r
.42425 .5827 .43045 .58854 .44105 .58529 .43488 .57941 Metetra
.665 .743 .908 r
.43488 .57941 .44105 .58529 .4517 .58205 .44556 .57612 Metetra
.665 .743 .908 r
.44556 .57612 .4517 .58205 .46239 .5788 .45627 .57284 Metetra
.664 .742 .908 r
.45627 .57284 .46239 .5788 .47312 .57555 .46703 .56956 Metetra
.664 .742 .908 r
.46703 .56956 .47312 .57555 .48389 .5723 .47782 .56628 Metetra
.664 .742 .908 r
.47782 .56628 .48389 .5723 .4947 .56904 .48867 .56299 Metetra
.664 .741 .908 r
.48867 .56299 .4947 .56904 .50556 .56576 .49955 .55969 Metetra
.664 .741 .908 r
.49955 .55969 .50556 .56576 .51646 .56248 .51048 .55638 Metetra
.664 .741 .908 r
.51048 .55638 .51646 .56248 .5274 .55918 .52145 .55305 Metetra
.664 .741 .908 r
.52145 .55305 .5274 .55918 .53839 .55587 .53246 .54972 Metetra
.664 .741 .908 r
.53246 .54972 .53839 .55587 .54942 .55254 .54352 .54637 Metetra
.664 .741 .908 r
.54352 .54637 .54942 .55254 .56049 .5492 .55463 .54301 Metetra
.664 .741 .908 r
.55463 .54301 .56049 .5492 .57161 .54585 .56578 .53963 Metetra
.664 .741 .908 r
.56578 .53963 .57161 .54585 .58277 .54249 .57697 .53624 Metetra
.664 .741 .908 r
.57697 .53624 .58277 .54249 .59398 .53911 .58821 .53284 Metetra
.664 .741 .908 r
.58821 .53284 .59398 .53911 .60524 .53572 .5995 .52942 Metetra
.664 .741 .908 r
.5995 .52942 .60524 .53572 .61654 .53231 .61083 .52599 Metetra
.664 .741 .908 r
.61083 .52599 .61654 .53231 .62788 .52889 .6222 .52254 Metetra
.664 .741 .908 r
.6222 .52254 .62788 .52889 .63928 .52546 .63363 .51908 Metetra
.664 .741 .908 r
.63363 .51908 .63928 .52546 .65071 .52201 .6451 .51561 Metetra
.664 .741 .908 r
.6451 .51561 .65071 .52201 .6622 .51855 .65661 .51212 Metetra
.664 .741 .908 r
.65661 .51212 .6622 .51855 .67373 .51507 .66818 .50862 Metetra
.664 .741 .908 r
.66818 .50862 .67373 .51507 .68531 .51158 .67979 .5051 Metetra
.664 .741 .908 r
.67979 .5051 .68531 .51158 .69694 .50808 .69145 .50157 Metetra
.664 .741 .908 r
.69145 .50157 .69694 .50808 .70861 .50456 .70316 .49802 Metetra
.664 .741 .908 r
.70316 .49802 .70861 .50456 .72034 .50102 .71492 .49446 Metetra
.664 .741 .908 r
.71492 .49446 .72034 .50102 .73211 .49747 .72672 .49089 Metetra
.664 .741 .908 r
.72672 .49089 .73211 .49747 .74393 .49391 .73858 .48729 Metetra
.664 .741 .908 r
.73858 .48729 .74393 .49391 .7558 .49033 .75048 .48369 Metetra
.664 .741 .908 r
.75048 .48369 .7558 .49033 .76772 .48674 .76243 .48007 Metetra
.664 .741 .908 r
.76243 .48007 .76772 .48674 .77968 .48313 .77444 .47643 Metetra
.664 .741 .908 r
.77444 .47643 .77968 .48313 .7917 .47951 .78649 .47278 Metetra
.664 .741 .908 r
.78649 .47278 .7917 .47951 .80377 .47587 .79859 .46912 Metetra
.664 .741 .908 r
.79859 .46912 .80377 .47587 .81589 .47222 .81075 .46544 Metetra
.664 .741 .908 r
.81075 .46544 .81589 .47222 .82806 .46855 .82296 .46174 Metetra
.664 .741 .908 r
.82296 .46174 .82806 .46855 .84028 .46487 .83522 .45803 Metetra
.663 .741 .908 r
.83522 .45803 .84028 .46487 .85256 .46117 .84753 .4543 Metetra
.663 .741 .908 r
.84753 .4543 .85256 .46117 .86488 .45746 .85989 .45057 Metetra
.663 .741 .908 r
.85989 .45057 .86488 .45746 .87726 .45374 .87231 .44682 Metetra
.663 .741 .908 r
.87231 .44682 .87726 .45374 .88969 .45001 .88478 .44307 Metetra
.662 .742 .909 r
.88478 .44307 .88969 .45001 .90218 .44627 .8973 .43932 Metetra
.662 .742 .909 r
.8973 .43932 .90218 .44627 .91472 .44253 .90989 .43557 Metetra
.661 .742 .91 r
.90989 .43557 .91472 .44253 .92732 .43879 .92253 .43182 Metetra
.66 .743 .911 r
.92253 .43182 .92732 .43879 .93997 .43505 .93522 .42808 Metetra
.66 .743 .912 r
.93522 .42808 .93997 .43505 .95268 .43132 .94798 .42434 Metetra
.659 .744 .912 r
.94798 .42434 .95268 .43132 .96545 .42758 .96079 .4206 Metetra
.669 .749 .911 r
.38627 .58691 .3926 .5926 .40311 .5893 .39681 .58355 Metetra
.668 .748 .91 r
.39681 .58355 .40311 .5893 .41366 .586 .40739 .5802 Metetra
.668 .747 .91 r
.40739 .5802 .41366 .586 .42425 .5827 .41801 .57685 Metetra
.667 .746 .909 r
.41801 .57685 .42425 .5827 .43488 .57941 .42867 .57351 Metetra
.666 .744 .909 r
.42867 .57351 .43488 .57941 .44556 .57612 .43937 .57018 Metetra
.665 .744 .908 r
.43937 .57018 .44556 .57612 .45627 .57284 .45011 .56685 Metetra
.665 .743 .908 r
.45011 .56685 .45627 .57284 .46703 .56956 .46089 .56353 Metetra
.664 .742 .908 r
.46089 .56353 .46703 .56956 .47782 .56628 .47172 .56022 Metetra
.664 .742 .908 r
.47172 .56022 .47782 .56628 .48867 .56299 .48259 .5569 Metetra
.664 .742 .908 r
.48259 .5569 .48867 .56299 .49955 .55969 .4935 .55357 Metetra
.664 .741 .908 r
.4935 .55357 .49955 .55969 .51048 .55638 .50446 .55023 Metetra
.664 .741 .908 r
.50446 .55023 .51048 .55638 .52145 .55305 .51546 .54689 Metetra
.664 .741 .908 r
.51546 .54689 .52145 .55305 .53246 .54972 .5265 .54352 Metetra
.664 .741 .908 r
.5265 .54352 .53246 .54972 .54352 .54637 .53759 .54015 Metetra
.664 .741 .908 r
.53759 .54015 .54352 .54637 .55463 .54301 .54872 .53676 Metetra
.664 .741 .908 r
.54872 .53676 .55463 .54301 .56578 .53963 .5599 .53336 Metetra
.664 .741 .908 r
.5599 .53336 .56578 .53963 .57697 .53624 .57113 .52994 Metetra
.664 .741 .908 r
.57113 .52994 .57697 .53624 .58821 .53284 .58239 .52651 Metetra
.664 .741 .908 r
.58239 .52651 .58821 .53284 .5995 .52942 .59371 .52307 Metetra
.664 .741 .908 r
.59371 .52307 .5995 .52942 .61083 .52599 .60507 .51961 Metetra
.664 .741 .908 r
.60507 .51961 .61083 .52599 .6222 .52254 .61648 .51614 Metetra
.664 .741 .908 r
.61648 .51614 .6222 .52254 .63363 .51908 .62794 .51266 Metetra
.664 .741 .908 r
.62794 .51266 .63363 .51908 .6451 .51561 .63944 .50916 Metetra
.664 .741 .908 r
.63944 .50916 .6451 .51561 .65661 .51212 .65099 .50564 Metetra
.664 .741 .908 r
.65099 .50564 .65661 .51212 .66818 .50862 .66258 .50211 Metetra
.664 .741 .908 r
.66258 .50211 .66818 .50862 .67979 .5051 .67423 .49857 Metetra
.664 .741 .908 r
.67423 .49857 .67979 .5051 .69145 .50157 .68592 .49501 Metetra
.664 .741 .908 r
.68592 .49501 .69145 .50157 .70316 .49802 .69766 .49144 Metetra
.664 .741 .908 r
.69766 .49144 .70316 .49802 .71492 .49446 .70945 .48785 Metetra
.664 .741 .908 r
.70945 .48785 .71492 .49446 .72672 .49089 .72129 .48425 Metetra
.664 .741 .908 r
.72129 .48425 .72672 .49089 .73858 .48729 .73318 .48063 Metetra
.664 .741 .908 r
.73318 .48063 .73858 .48729 .75048 .48369 .74512 .47699 Metetra
.664 .741 .908 r
.74512 .47699 .75048 .48369 .76243 .48007 .75711 .47335 Metetra
.664 .741 .908 r
.75711 .47335 .76243 .48007 .77444 .47643 .76915 .46968 Metetra
.664 .741 .908 r
.76915 .46968 .77444 .47643 .78649 .47278 .78124 .466 Metetra
.664 .741 .908 r
.78124 .466 .78649 .47278 .79859 .46912 .79338 .46231 Metetra
.664 .741 .908 r
.79338 .46231 .79859 .46912 .81075 .46544 .80557 .4586 Metetra
.664 .741 .908 r
.80557 .4586 .81075 .46544 .82296 .46174 .81781 .45487 Metetra
.663 .741 .908 r
.81781 .45487 .82296 .46174 .83522 .45803 .83011 .45113 Metetra
.663 .741 .908 r
.83011 .45113 .83522 .45803 .84753 .4543 .84246 .44738 Metetra
.663 .741 .908 r
.84246 .44738 .84753 .4543 .85989 .45057 .85486 .44362 Metetra
.663 .741 .908 r
.85486 .44362 .85989 .45057 .87231 .44682 .86732 .43986 Metetra
.662 .742 .909 r
.86732 .43986 .87231 .44682 .88478 .44307 .87983 .4361 Metetra
.662 .742 .909 r
.87983 .4361 .88478 .44307 .8973 .43932 .89239 .43234 Metetra
.661 .742 .91 r
.89239 .43234 .8973 .43932 .90989 .43557 .90502 .42858 Metetra
.66 .743 .911 r
.90502 .42858 .90989 .43557 .92253 .43182 .9177 .42483 Metetra
.659 .743 .912 r
.9177 .42483 .92253 .43182 .93522 .42808 .93044 .42109 Metetra
.659 .744 .913 r
.93044 .42109 .93522 .42808 .94798 .42434 .94324 .41735 Metetra
.658 .745 .914 r
.94324 .41735 .94798 .42434 .96079 .4206 .9561 .41361 Metetra
.67 .751 .911 r
.3799 .58124 .38627 .58691 .39681 .58355 .39046 .57782 Metetra
.669 .75 .911 r
.39046 .57782 .39681 .58355 .40739 .5802 .40107 .57441 Metetra
.669 .749 .91 r
.40107 .57441 .40739 .5802 .41801 .57685 .41172 .571 Metetra
.668 .747 .91 r
.41172 .571 .41801 .57685 .42867 .57351 .4224 .5676 Metetra
.667 .746 .909 r
.4224 .5676 .42867 .57351 .43937 .57018 .43313 .56422 Metetra
.666 .745 .909 r
.43313 .56422 .43937 .57018 .45011 .56685 .4439 .56084 Metetra
.666 .744 .908 r
.4439 .56084 .45011 .56685 .46089 .56353 .45471 .55748 Metetra
.665 .743 .908 r
.45471 .55748 .46089 .56353 .47172 .56022 .46557 .55412 Metetra
.664 .742 .908 r
.46557 .55412 .47172 .56022 .48259 .5569 .47646 .55077 Metetra
.664 .742 .908 r
.47646 .55077 .48259 .5569 .4935 .55357 .4874 .54741 Metetra
.664 .741 .908 r
.4874 .54741 .4935 .55357 .50446 .55023 .49839 .54404 Metetra
.664 .741 .908 r
.49839 .54404 .50446 .55023 .51546 .54689 .50942 .54067 Metetra
.664 .741 .908 r
.50942 .54067 .51546 .54689 .5265 .54352 .52049 .53728 Metetra
.664 .741 .908 r
.52049 .53728 .5265 .54352 .53759 .54015 .53161 .53388 Metetra
.664 .741 .908 r
.53161 .53388 .53759 .54015 .54872 .53676 .54277 .53047 Metetra
.664 .741 .908 r
.54277 .53047 .54872 .53676 .5599 .53336 .55398 .52704 Metetra
.664 .741 .908 r
.55398 .52704 .5599 .53336 .57113 .52994 .56524 .5236 Metetra
.664 .741 .908 r
.56524 .5236 .57113 .52994 .58239 .52651 .57654 .52015 Metetra
.664 .741 .908 r
.57654 .52015 .58239 .52651 .59371 .52307 .58788 .51668 Metetra
.664 .741 .908 r
.58788 .51668 .59371 .52307 .60507 .51961 .59927 .51319 Metetra
.664 .741 .908 r
.59927 .51319 .60507 .51961 .61648 .51614 .61071 .50969 Metetra
.664 .741 .908 r
.61071 .50969 .61648 .51614 .62794 .51266 .6222 .50618 Metetra
.664 .741 .908 r
.6222 .50618 .62794 .51266 .63944 .50916 .63373 .50266 Metetra
.664 .741 .908 r
.63373 .50266 .63944 .50916 .65099 .50564 .64532 .49911 Metetra
.664 .741 .908 r
.64532 .49911 .65099 .50564 .66258 .50211 .65694 .49556 Metetra
.664 .741 .908 r
.65694 .49556 .66258 .50211 .67423 .49857 .66862 .49199 Metetra
.664 .741 .908 r
.66862 .49199 .67423 .49857 .68592 .49501 .68035 .4884 Metetra
.664 .741 .908 r
.68035 .4884 .68592 .49501 .69766 .49144 .69212 .4848 Metetra
.664 .741 .908 r
.69212 .4848 .69766 .49144 .70945 .48785 .70395 .48118 Metetra
.664 .741 .908 r
.70395 .48118 .70945 .48785 .72129 .48425 .71582 .47755 Metetra
.664 .741 .908 r
.71582 .47755 .72129 .48425 .73318 .48063 .72774 .47391 Metetra
.664 .741 .908 r
.72774 .47391 .73318 .48063 .74512 .47699 .73972 .47025 Metetra
.664 .741 .908 r
.73972 .47025 .74512 .47699 .75711 .47335 .75174 .46657 Metetra
.664 .741 .908 r
.75174 .46657 .75711 .47335 .76915 .46968 .76382 .46288 Metetra
.664 .741 .908 r
.76382 .46288 .76915 .46968 .78124 .466 .77594 .45917 Metetra
.664 .741 .908 r
.77594 .45917 .78124 .466 .79338 .46231 .78812 .45545 Metetra
.664 .741 .908 r
.78812 .45545 .79338 .46231 .80557 .4586 .80035 .45171 Metetra
.663 .741 .908 r
.80035 .45171 .80557 .4586 .81781 .45487 .81263 .44795 Metetra
.663 .741 .908 r
.81263 .44795 .81781 .45487 .83011 .45113 .82496 .44419 Metetra
.663 .741 .908 r
.82496 .44419 .83011 .45113 .84246 .44738 .83735 .44042 Metetra
.663 .741 .908 r
.83735 .44042 .84246 .44738 .85486 .44362 .84979 .43664 Metetra
.662 .741 .909 r
.84979 .43664 .85486 .44362 .86732 .43986 .86229 .43286 Metetra
.661 .742 .91 r
.86229 .43286 .86732 .43986 .87983 .4361 .87484 .42909 Metetra
.661 .742 .91 r
.87484 .42909 .87983 .4361 .89239 .43234 .88745 .42533 Metetra
.66 .743 .911 r
.88745 .42533 .89239 .43234 .90502 .42858 .90012 .42158 Metetra
.659 .743 .912 r
.90012 .42158 .90502 .42858 .9177 .42483 .91285 .41783 Metetra
.658 .744 .913 r
.91285 .41783 .9177 .42483 .93044 .42109 .92563 .4141 Metetra
.658 .745 .915 r
.92563 .4141 .93044 .42109 .94324 .41735 .93848 .41036 Metetra
.657 .746 .916 r
.93848 .41036 .94324 .41735 .9561 .41361 .95138 .40663 Metetra
.671 .754 .913 r
.37347 .57559 .3799 .58124 .39046 .57782 .38406 .57212 Metetra
.671 .752 .912 r
.38406 .57212 .39046 .57782 .40107 .57441 .3947 .56864 Metetra
.67 .751 .911 r
.3947 .56864 .40107 .57441 .41172 .571 .40538 .56517 Metetra
.669 .749 .91 r
.40538 .56517 .41172 .571 .4224 .5676 .41609 .5617 Metetra
.668 .748 .91 r
.41609 .5617 .4224 .5676 .43313 .56422 .42685 .55825 Metetra
.667 .746 .909 r
.42685 .55825 .43313 .56422 .4439 .56084 .43765 .55482 Metetra
.667 .745 .909 r
.43765 .55482 .4439 .56084 .45471 .55748 .44849 .5514 Metetra
.666 .744 .908 r
.44849 .5514 .45471 .55748 .46557 .55412 .45937 .54799 Metetra
.665 .743 .908 r
.45937 .54799 .46557 .55412 .47646 .55077 .4703 .5446 Metetra
.664 .742 .908 r
.4703 .5446 .47646 .55077 .4874 .54741 .48126 .5412 Metetra
.664 .742 .908 r
.48126 .5412 .4874 .54741 .49839 .54404 .49228 .53781 Metetra
.664 .741 .908 r
.49228 .53781 .49839 .54404 .50942 .54067 .50334 .53441 Metetra
.664 .741 .908 r
.50334 .53441 .50942 .54067 .52049 .53728 .51444 .531 Metetra
.664 .741 .908 r
.51444 .531 .52049 .53728 .53161 .53388 .52558 .52757 Metetra
.664 .741 .908 r
.52558 .52757 .53161 .53388 .54277 .53047 .53678 .52413 Metetra
.664 .741 .908 r
.53678 .52413 .54277 .53047 .55398 .52704 .54802 .52068 Metetra
.664 .741 .908 r
.54802 .52068 .55398 .52704 .56524 .5236 .5593 .51721 Metetra
.664 .741 .908 r
.5593 .51721 .56524 .5236 .57654 .52015 .57063 .51373 Metetra
.664 .741 .908 r
.57063 .51373 .57654 .52015 .58788 .51668 .58201 .51023 Metetra
.664 .741 .908 r
.58201 .51023 .58788 .51668 .59927 .51319 .59343 .50672 Metetra
.664 .741 .908 r
.59343 .50672 .59927 .51319 .61071 .50969 .6049 .5032 Metetra
.664 .741 .908 r
.6049 .5032 .61071 .50969 .6222 .50618 .61642 .49966 Metetra
.664 .741 .908 r
.61642 .49966 .6222 .50618 .63373 .50266 .62799 .49611 Metetra
.664 .741 .908 r
.62799 .49611 .63373 .50266 .64532 .49911 .6396 .49254 Metetra
.664 .741 .908 r
.6396 .49254 .64532 .49911 .65694 .49556 .65126 .48895 Metetra
.664 .741 .908 r
.65126 .48895 .65694 .49556 .66862 .49199 .66297 .48536 Metetra
.664 .741 .908 r
.66297 .48536 .66862 .49199 .68035 .4884 .67473 .48174 Metetra
.664 .741 .908 r
.67473 .48174 .68035 .4884 .69212 .4848 .68654 .47811 Metetra
.664 .741 .908 r
.68654 .47811 .69212 .4848 .70395 .48118 .6984 .47447 Metetra
.664 .741 .908 r
.6984 .47447 .70395 .48118 .71582 .47755 .71031 .47081 Metetra
.664 .741 .908 r
.71031 .47081 .71582 .47755 .72774 .47391 .72227 .46714 Metetra
.664 .741 .908 r
.72227 .46714 .72774 .47391 .73972 .47025 .73427 .46345 Metetra
.664 .741 .908 r
.73427 .46345 .73972 .47025 .75174 .46657 .74633 .45974 Metetra
.664 .741 .908 r
.74633 .45974 .75174 .46657 .76382 .46288 .75844 .45602 Metetra
.664 .741 .908 r
.75844 .45602 .76382 .46288 .77594 .45917 .77061 .45228 Metetra
.664 .741 .908 r
.77061 .45228 .77594 .45917 .78812 .45545 .78282 .44853 Metetra
.664 .741 .908 r
.78282 .44853 .78812 .45545 .80035 .45171 .79508 .44476 Metetra
.663 .741 .908 r
.79508 .44476 .80035 .45171 .81263 .44795 .8074 .44098 Metetra
.663 .741 .908 r
.8074 .44098 .81263 .44795 .82496 .44419 .81977 .43719 Metetra
.663 .741 .908 r
.81977 .43719 .82496 .44419 .83735 .44042 .8322 .4334 Metetra
.662 .741 .909 r
.8322 .4334 .83735 .44042 .84979 .43664 .84468 .42961 Metetra
.661 .742 .91 r
.84468 .42961 .84979 .43664 .86229 .43286 .85722 .42583 Metetra
.66 .742 .91 r
.85722 .42583 .86229 .43286 .87484 .42909 .86982 .42206 Metetra
.659 .743 .912 r
.86982 .42206 .87484 .42909 .88745 .42533 .88247 .41831 Metetra
.659 .744 .913 r
.88247 .41831 .88745 .42533 .90012 .42158 .89518 .41457 Metetra
.658 .745 .914 r
.89518 .41457 .90012 .42158 .91285 .41783 .90796 .41084 Metetra
.657 .746 .915 r
.90796 .41084 .91285 .41783 .92563 .4141 .92079 .40711 Metetra
.656 .747 .917 r
.92079 .40711 .92563 .4141 .93848 .41036 .93368 .40338 Metetra
.656 .748 .918 r
.93368 .40338 .93848 .41036 .95138 .40663 .94663 .39966 Metetra
.672 .757 .914 r
.36699 .56998 .37347 .57559 .38406 .57212 .37761 .56644 Metetra
.672 .755 .913 r
.37761 .56644 .38406 .57212 .3947 .56864 .38828 .5629 Metetra
.672 .754 .912 r
.38828 .5629 .3947 .56864 .40538 .56517 .39898 .55936 Metetra
.671 .752 .912 r
.39898 .55936 .40538 .56517 .41609 .5617 .40973 .55583 Metetra
.67 .75 .911 r
.40973 .55583 .41609 .5617 .42685 .55825 .42052 .5523 Metetra
.669 .749 .91 r
.42052 .5523 .42685 .55825 .43765 .55482 .43134 .5488 Metetra
.668 .747 .909 r
.43134 .5488 .43765 .55482 .44849 .5514 .44221 .54531 Metetra
.667 .745 .909 r
.44221 .54531 .44849 .5514 .45937 .54799 .45313 .54185 Metetra
.666 .744 .909 r
.45313 .54185 .45937 .54799 .4703 .5446 .46408 .5384 Metetra
.665 .743 .908 r
.46408 .5384 .4703 .5446 .48126 .5412 .47508 .53496 Metetra
.664 .742 .908 r
.47508 .53496 .48126 .5412 .49228 .53781 .48612 .53153 Metetra
.664 .742 .908 r
.48612 .53153 .49228 .53781 .50334 .53441 .49721 .5281 Metetra
.664 .741 .908 r
.49721 .5281 .50334 .53441 .51444 .531 .50834 .52466 Metetra
.664 .741 .908 r
.50834 .52466 .51444 .531 .52558 .52757 .51952 .52121 Metetra
.664 .741 .908 r
.51952 .52121 .52558 .52757 .53678 .52413 .53074 .51775 Metetra
.664 .741 .908 r
.53074 .51775 .53678 .52413 .54802 .52068 .54201 .51427 Metetra
.664 .741 .908 r
.54201 .51427 .54802 .52068 .5593 .51721 .55332 .51077 Metetra
.664 .741 .908 r
.55332 .51077 .5593 .51721 .57063 .51373 .56468 .50726 Metetra
.664 .741 .908 r
.56468 .50726 .57063 .51373 .58201 .51023 .57609 .50374 Metetra
.664 .741 .908 r
.57609 .50374 .58201 .51023 .59343 .50672 .58755 .50021 Metetra
.664 .741 .908 r
.58755 .50021 .59343 .50672 .6049 .5032 .59905 .49665 Metetra
.664 .741 .908 r
.59905 .49665 .6049 .5032 .61642 .49966 .6106 .49309 Metetra
.664 .741 .908 r
.6106 .49309 .61642 .49966 .62799 .49611 .6222 .48951 Metetra
.664 .741 .908 r
.6222 .48951 .62799 .49611 .6396 .49254 .63384 .48591 Metetra
.664 .741 .908 r
.63384 .48591 .6396 .49254 .65126 .48895 .64554 .4823 Metetra
.664 .741 .908 r
.64554 .4823 .65126 .48895 .66297 .48536 .65728 .47867 Metetra
.664 .741 .908 r
.65728 .47867 .66297 .48536 .67473 .48174 .66907 .47503 Metetra
.664 .741 .908 r
.66907 .47503 .67473 .48174 .68654 .47811 .68092 .47137 Metetra
.664 .741 .908 r
.68092 .47137 .68654 .47811 .6984 .47447 .69281 .4677 Metetra
.664 .741 .908 r
.69281 .4677 .6984 .47447 .71031 .47081 .70475 .46402 Metetra
.664 .741 .908 r
.70475 .46402 .71031 .47081 .72227 .46714 .71675 .46031 Metetra
.664 .741 .908 r
.71675 .46031 .72227 .46714 .73427 .46345 .72879 .45659 Metetra
.664 .741 .908 r
.72879 .45659 .73427 .46345 .74633 .45974 .74088 .45286 Metetra
.664 .741 .908 r
.74088 .45286 .74633 .45974 .75844 .45602 .75303 .44911 Metetra
.664 .741 .908 r
.75303 .44911 .75844 .45602 .77061 .45228 .76523 .44534 Metetra
.664 .741 .908 r
.76523 .44534 .77061 .45228 .78282 .44853 .77748 .44156 Metetra
.663 .741 .908 r
.77748 .44156 .78282 .44853 .79508 .44476 .78978 .43777 Metetra
.663 .741 .908 r
.78978 .43777 .79508 .44476 .8074 .44098 .80214 .43396 Metetra
.663 .741 .908 r
.80214 .43396 .8074 .44098 .81977 .43719 .81455 .43016 Metetra
.662 .741 .909 r
.81455 .43016 .81977 .43719 .8322 .4334 .82701 .42635 Metetra
.661 .742 .91 r
.82701 .42635 .8322 .4334 .84468 .42961 .83954 .42256 Metetra
.66 .742 .911 r
.83954 .42256 .84468 .42961 .85722 .42583 .85212 .41879 Metetra
.659 .743 .912 r
.85212 .41879 .85722 .42583 .86982 .42206 .86476 .41503 Metetra
.658 .744 .913 r
.86476 .41503 .86982 .42206 .88247 .41831 .87746 .4113 Metetra
.657 .745 .915 r
.87746 .4113 .88247 .41831 .89518 .41457 .89022 .40757 Metetra
.656 .746 .916 r
.89022 .40757 .89518 .41457 .90796 .41084 .90304 .40386 Metetra
.655 .747 .918 r
.90304 .40386 .90796 .41084 .92079 .40711 .91592 .40015 Metetra
.655 .749 .919 r
.91592 .40015 .92079 .40711 .93368 .40338 .92886 .39643 Metetra
.654 .75 .92 r
.92886 .39643 .93368 .40338 .94663 .39966 .94186 .39271 Metetra
.673 .76 .916 r
.36046 .56442 .36699 .56998 .37761 .56644 .37111 .56082 Metetra
.673 .759 .915 r
.37111 .56082 .37761 .56644 .38828 .5629 .38181 .55722 Metetra
.673 .757 .914 r
.38181 .55722 .38828 .5629 .39898 .55936 .39254 .5536 Metetra
.673 .756 .913 r
.39254 .5536 .39898 .55936 .40973 .55583 .40332 .54999 Metetra
.672 .754 .912 r
.40332 .54999 .40973 .55583 .42052 .5523 .41413 .54639 Metetra
.671 .752 .911 r
.41413 .54639 .42052 .5523 .43134 .5488 .42499 .5428 Metetra
.67 .75 .91 r
.42499 .5428 .43134 .5488 .44221 .54531 .43589 .53924 Metetra
.668 .747 .91 r
.43589 .53924 .44221 .54531 .45313 .54185 .44683 .5357 Metetra
.667 .746 .909 r
.44683 .5357 .45313 .54185 .46408 .5384 .45782 .53219 Metetra
.666 .744 .909 r
.45782 .53219 .46408 .5384 .47508 .53496 .46884 .5287 Metetra
.665 .743 .908 r
.46884 .5287 .47508 .53496 .48612 .53153 .47992 .52522 Metetra
.664 .742 .908 r
.47992 .52522 .48612 .53153 .49721 .5281 .49103 .52175 Metetra
.664 .742 .908 r
.49103 .52175 .49721 .5281 .50834 .52466 .50219 .51828 Metetra
.664 .741 .908 r
.50219 .51828 .50834 .52466 .51952 .52121 .5134 .5148 Metetra
.664 .741 .908 r
.5134 .5148 .51952 .52121 .53074 .51775 .52465 .51131 Metetra
.664 .741 .908 r
.52465 .51131 .53074 .51775 .54201 .51427 .53595 .50781 Metetra
.664 .741 .908 r
.53595 .50781 .54201 .51427 .55332 .51077 .5473 .50429 Metetra
.664 .741 .908 r
.5473 .50429 .55332 .51077 .56468 .50726 .55869 .50075 Metetra
.664 .741 .908 r
.55869 .50075 .56468 .50726 .57609 .50374 .57013 .4972 Metetra
.664 .741 .908 r
.57013 .4972 .57609 .50374 .58755 .50021 .58161 .49364 Metetra
.664 .741 .908 r
.58161 .49364 .58755 .50021 .59905 .49665 .59315 .49006 Metetra
.664 .741 .908 r
.59315 .49006 .59905 .49665 .6106 .49309 .60473 .48646 Metetra
.664 .741 .908 r
.60473 .48646 .6106 .49309 .6222 .48951 .61636 .48286 Metetra
.664 .741 .908 r
.61636 .48286 .6222 .48951 .63384 .48591 .62804 .47923 Metetra
.664 .741 .908 r
.62804 .47923 .63384 .48591 .64554 .4823 .63977 .47559 Metetra
.664 .741 .908 r
.63977 .47559 .64554 .4823 .65728 .47867 .65155 .47194 Metetra
.664 .741 .908 r
.65155 .47194 .65728 .47867 .66907 .47503 .66337 .46827 Metetra
.664 .741 .908 r
.66337 .46827 .66907 .47503 .68092 .47137 .67525 .46458 Metetra
.664 .741 .908 r
.67525 .46458 .68092 .47137 .69281 .4677 .68718 .46088 Metetra
.664 .741 .908 r
.68718 .46088 .69281 .4677 .70475 .46402 .69915 .45717 Metetra
.664 .741 .908 r
.69915 .45717 .70475 .46402 .71675 .46031 .71118 .45343 Metetra
.664 .741 .908 r
.71118 .45343 .71675 .46031 .72879 .45659 .72326 .44969 Metetra
.664 .741 .908 r
.72326 .44969 .72879 .45659 .74088 .45286 .73539 .44592 Metetra
.664 .741 .908 r
.73539 .44592 .74088 .45286 .75303 .44911 .74757 .44214 Metetra
.664 .741 .908 r
.74757 .44214 .75303 .44911 .76523 .44534 .75981 .43835 Metetra
.663 .741 .908 r
.75981 .43835 .76523 .44534 .77748 .44156 .77209 .43454 Metetra
.663 .741 .908 r
.77209 .43454 .77748 .44156 .78978 .43777 .78443 .43072 Metetra
.663 .741 .908 r
.78443 .43072 .78978 .43777 .80214 .43396 .79683 .4269 Metetra
.662 .741 .909 r
.79683 .4269 .80214 .43396 .81455 .43016 .80928 .42308 Metetra
.661 .742 .91 r
.80928 .42308 .81455 .43016 .82701 .42635 .82179 .41928 Metetra
.66 .742 .911 r
.82179 .41928 .82701 .42635 .83954 .42256 .83435 .4155 Metetra
.659 .743 .912 r
.83435 .4155 .83954 .42256 .85212 .41879 .84698 .41175 Metetra
.657 .744 .914 r
.84698 .41175 .85212 .41879 .86476 .41503 .85966 .40802 Metetra
.656 .745 .916 r
.85966 .40802 .86476 .41503 .87746 .4113 .87241 .40431 Metetra
.655 .747 .917 r
.87241 .40431 .87746 .4113 .89022 .40757 .88522 .40061 Metetra
.654 .748 .919 r
.88522 .40061 .89022 .40757 .90304 .40386 .89809 .39692 Metetra
.653 .75 .92 r
.89809 .39692 .90304 .40386 .91592 .40015 .91102 .39323 Metetra
.653 .751 .922 r
.91102 .39323 .91592 .40015 .92886 .39643 .924 .38952 Metetra
.653 .752 .923 r
.924 .38952 .92886 .39643 .94186 .39271 .93705 .3858 Metetra
.674 .764 .918 r
.35387 .55892 .36046 .56442 .37111 .56082 .36455 .55527 Metetra
.675 .763 .917 r
.36455 .55527 .37111 .56082 .38181 .55722 .37528 .5516 Metetra
.675 .761 .916 r
.37528 .5516 .38181 .55722 .39254 .5536 .38605 .54791 Metetra
.674 .76 .915 r
.38605 .54791 .39254 .5536 .40332 .54999 .39685 .54422 Metetra
.674 .758 .914 r
.39685 .54422 .40332 .54999 .41413 .54639 .4077 .54053 Metetra
.673 .756 .913 r
.4077 .54053 .41413 .54639 .42499 .5428 .41859 .53685 Metetra
.672 .753 .912 r
.41859 .53685 .42499 .5428 .43589 .53924 .42952 .5332 Metetra
.67 .751 .911 r
.42952 .5332 .43589 .53924 .44683 .5357 .44049 .52957 Metetra
.669 .748 .91 r
.44049 .52957 .44683 .5357 .45782 .53219 .45151 .52597 Metetra
.667 .746 .909 r
.45151 .52597 .45782 .53219 .46884 .5287 .46256 .52241 Metetra
.666 .744 .909 r
.46256 .52241 .46884 .5287 .47992 .52522 .47366 .51888 Metetra
.665 .743 .908 r
.47366 .51888 .47992 .52522 .49103 .52175 .48481 .51536 Metetra
.664 .742 .908 r
.48481 .51536 .49103 .52175 .50219 .51828 .496 .51186 Metetra
.664 .741 .908 r
.496 .51186 .50219 .51828 .5134 .5148 .50724 .50835 Metetra
.664 .741 .908 r
.50724 .50835 .5134 .5148 .52465 .51131 .51852 .50483 Metetra
.664 .741 .908 r
.51852 .50483 .52465 .51131 .53595 .50781 .52985 .5013 Metetra
.664 .741 .908 r
.52985 .5013 .53595 .50781 .5473 .50429 .54123 .49775 Metetra
.664 .741 .908 r
.54123 .49775 .5473 .50429 .55869 .50075 .55265 .49419 Metetra
.664 .741 .908 r
.55265 .49419 .55869 .50075 .57013 .4972 .56412 .49061 Metetra
.664 .741 .908 r
.56412 .49061 .57013 .4972 .58161 .49364 .57564 .48702 Metetra
.664 .741 .908 r
.57564 .48702 .58161 .49364 .59315 .49006 .5872 .48341 Metetra
.664 .741 .908 r
.5872 .48341 .59315 .49006 .60473 .48646 .59882 .47979 Metetra
.664 .741 .908 r
.59882 .47979 .60473 .48646 .61636 .48286 .61048 .47615 Metetra
.664 .741 .908 r
.61048 .47615 .61636 .48286 .62804 .47923 .62219 .4725 Metetra
.664 .741 .908 r
.62219 .4725 .62804 .47923 .63977 .47559 .63395 .46883 Metetra
.664 .741 .908 r
.63395 .46883 .63977 .47559 .65155 .47194 .64577 .46515 Metetra
.664 .741 .908 r
.64577 .46515 .65155 .47194 .66337 .46827 .65763 .46145 Metetra
.664 .741 .908 r
.65763 .46145 .66337 .46827 .67525 .46458 .66954 .45774 Metetra
.664 .741 .908 r
.66954 .45774 .67525 .46458 .68718 .46088 .6815 .45401 Metetra
.664 .741 .908 r
.6815 .45401 .68718 .46088 .69915 .45717 .69351 .45026 Metetra
.664 .741 .908 r
.69351 .45026 .69915 .45717 .71118 .45343 .70557 .4465 Metetra
.664 .741 .908 r
.70557 .4465 .71118 .45343 .72326 .44969 .71769 .44273 Metetra
.664 .741 .908 r
.71769 .44273 .72326 .44969 .73539 .44592 .72985 .43893 Metetra
.664 .741 .908 r
.72985 .43893 .73539 .44592 .74757 .44214 .74207 .43512 Metetra
.663 .741 .908 r
.74207 .43512 .74757 .44214 .75981 .43835 .75434 .4313 Metetra
.663 .741 .908 r
.75434 .4313 .75981 .43835 .77209 .43454 .76667 .42746 Metetra
.663 .741 .908 r
.76667 .42746 .77209 .43454 .78443 .43072 .77905 .42362 Metetra
.662 .741 .909 r
.77905 .42362 .78443 .43072 .79683 .4269 .79148 .41979 Metetra
.661 .742 .91 r
.79148 .41979 .79683 .4269 .80928 .42308 .80397 .41598 Metetra
.66 .742 .911 r
.80397 .41598 .80928 .42308 .82179 .41928 .81652 .4122 Metetra
.658 .743 .913 r
.81652 .4122 .82179 .41928 .83435 .4155 .82913 .40845 Metetra
.656 .744 .915 r
.82913 .40845 .83435 .4155 .84698 .41175 .84181 .40474 Metetra
.655 .746 .917 r
.84181 .40474 .84698 .41175 .85966 .40802 .85454 .40104 Metetra
.654 .747 .919 r
.85454 .40104 .85966 .40802 .87241 .40431 .86733 .39737 Metetra
.653 .749 .921 r
.86733 .39737 .87241 .40431 .88522 .40061 .88019 .39371 Metetra
.652 .751 .922 r
.88019 .39371 .88522 .40061 .89809 .39692 .89311 .39004 Metetra
.651 .753 .924 r
.89311 .39004 .89809 .39692 .91102 .39323 .90609 .38636 Metetra
.651 .754 .925 r
.90609 .38636 .91102 .39323 .924 .38952 .91912 .38267 Metetra
.651 .756 .926 r
.91912 .38267 .924 .38952 .93705 .3858 .93222 .37895 Metetra
.675 .768 .92 r
.34722 .55349 .35387 .55892 .36455 .55527 .35794 .54979 Metetra
.676 .767 .919 r
.35794 .54979 .36455 .55527 .37528 .5516 .3687 .54606 Metetra
.676 .766 .918 r
.3687 .54606 .37528 .5516 .38605 .54791 .37949 .54231 Metetra
.676 .765 .917 r
.37949 .54231 .38605 .54791 .39685 .54422 .39033 .53854 Metetra
.676 .763 .916 r
.39033 .53854 .39685 .54422 .4077 .54053 .40121 .53476 Metetra
.675 .76 .915 r
.40121 .53476 .4077 .54053 .41859 .53685 .41213 .53099 Metetra
.675 .758 .914 r
.41213 .53099 .41859 .53685 .42952 .5332 .4231 .52722 Metetra
.673 .755 .912 r
.4231 .52722 .42952 .5332 .44049 .52957 .4341 .52349 Metetra
.671 .752 .911 r
.4341 .52349 .44049 .52957 .45151 .52597 .44515 .51979 Metetra
.67 .749 .91 r
.44515 .51979 .45151 .52597 .46256 .52241 .45623 .51613 Metetra
.668 .746 .909 r
.45623 .51613 .46256 .52241 .47366 .51888 .46737 .51252 Metetra
.666 .744 .909 r
.46737 .51252 .47366 .51888 .48481 .51536 .47854 .50894 Metetra
.665 .743 .908 r
.47854 .50894 .48481 .51536 .496 .51186 .48976 .50539 Metetra
.664 .742 .908 r
.48976 .50539 .496 .51186 .50724 .50835 .50103 .50184 Metetra
.664 .741 .908 r
.50103 .50184 .50724 .50835 .51852 .50483 .51234 .4983 Metetra
.664 .741 .908 r
.51234 .4983 .51852 .50483 .52985 .5013 .5237 .49474 Metetra
.664 .741 .908 r
.5237 .49474 .52985 .5013 .54123 .49775 .53511 .49116 Metetra
.664 .741 .908 r
.53511 .49116 .54123 .49775 .55265 .49419 .54656 .48757 Metetra
.664 .741 .908 r
.54656 .48757 .55265 .49419 .56412 .49061 .55806 .48397 Metetra
.664 .741 .908 r
.55806 .48397 .56412 .49061 .57564 .48702 .56961 .48035 Metetra
.664 .741 .908 r
.56961 .48035 .57564 .48702 .5872 .48341 .58121 .47671 Metetra
.664 .741 .908 r
.58121 .47671 .5872 .48341 .59882 .47979 .59286 .47306 Metetra
.664 .741 .908 r
.59286 .47306 .59882 .47979 .61048 .47615 .60455 .4694 Metetra
.664 .741 .908 r
.60455 .4694 .61048 .47615 .62219 .4725 .6163 .46572 Metetra
.664 .741 .908 r
.6163 .46572 .62219 .4725 .63395 .46883 .62809 .46202 Metetra
.664 .741 .908 r
.62809 .46202 .63395 .46883 .64577 .46515 .63994 .45831 Metetra
.664 .741 .908 r
.63994 .45831 .64577 .46515 .65763 .46145 .65183 .45458 Metetra
.664 .741 .908 r
.65183 .45458 .65763 .46145 .66954 .45774 .66378 .45084 Metetra
.664 .741 .908 r
.66378 .45084 .66954 .45774 .6815 .45401 .67578 .44708 Metetra
.664 .741 .908 r
.67578 .44708 .6815 .45401 .69351 .45026 .68782 .44331 Metetra
.664 .741 .908 r
.68782 .44331 .69351 .45026 .70557 .4465 .69992 .43952 Metetra
.664 .741 .908 r
.69992 .43952 .70557 .4465 .71769 .44273 .71207 .43571 Metetra
.664 .741 .908 r
.71207 .43571 .71769 .44273 .72985 .43893 .72427 .43189 Metetra
.664 .741 .908 r
.72427 .43189 .72985 .43893 .74207 .43512 .73653 .42805 Metetra
.663 .741 .908 r
.73653 .42805 .74207 .43512 .75434 .4313 .74884 .4242 Metetra
.663 .741 .908 r
.74884 .4242 .75434 .4313 .76667 .42746 .7612 .42034 Metetra
.662 .741 .909 r
.7612 .42034 .76667 .42746 .77905 .42362 .77362 .4165 Metetra
.661 .741 .91 r
.77362 .4165 .77905 .42362 .79148 .41979 .78609 .41268 Metetra
.659 .742 .911 r
.78609 .41268 .79148 .41979 .80397 .41598 .79863 .40889 Metetra
.657 .743 .913 r
.79863 .40889 .80397 .41598 .81652 .4122 .81122 .40515 Metetra
.655 .745 .916 r
.81122 .40515 .81652 .4122 .82913 .40845 .82388 .40145 Metetra
.653 .746 .918 r
.82388 .40145 .82913 .40845 .84181 .40474 .8366 .39779 Metetra
.652 .748 .92 r
.8366 .39779 .84181 .40474 .85454 .40104 .84939 .39414 Metetra
.651 .751 .923 r
.84939 .39414 .85454 .40104 .86733 .39737 .86223 .39051 Metetra
.65 .753 .925 r
.86223 .39051 .86733 .39737 .88019 .39371 .87514 .38688 Metetra
.65 .755 .926 r
.87514 .38688 .88019 .39371 .89311 .39004 .8881 .38324 Metetra
.65 .756 .928 r
.8881 .38324 .89311 .39004 .90609 .38636 .90113 .37957 Metetra
.65 .758 .928 r
.90113 .37957 .90609 .38636 .91912 .38267 .91422 .37587 Metetra
.65 .759 .929 r
.91422 .37587 .91912 .38267 .93222 .37895 .92736 .37214 Metetra
.675 .772 .923 r
.34052 .54813 .34722 .55349 .35794 .54979 .35127 .5444 Metetra
.676 .771 .922 r
.35127 .5444 .35794 .54979 .3687 .54606 .36205 .54062 Metetra
.677 .771 .921 r
.36205 .54062 .3687 .54606 .37949 .54231 .37288 .53681 Metetra
.678 .77 .92 r
.37288 .53681 .37949 .54231 .39033 .53854 .38375 .53297 Metetra
.678 .768 .919 r
.38375 .53297 .39033 .53854 .40121 .53476 .39467 .52911 Metetra
.678 .766 .918 r
.39467 .52911 .40121 .53476 .41213 .53099 .40562 .52523 Metetra
.677 .764 .916 r
.40562 .52523 .41213 .53099 .4231 .52722 .41662 .52136 Metetra
.676 .761 .915 r
.41662 .52136 .4231 .52722 .4341 .52349 .42765 .5175 Metetra
.675 .757 .913 r
.42765 .5175 .4341 .52349 .44515 .51979 .43873 .51368 Metetra
.673 .754 .911 r
.43873 .51368 .44515 .51979 .45623 .51613 .44985 .5099 Metetra
.67 .75 .91 r
.44985 .5099 .45623 .51613 .46737 .51252 .46102 .50618 Metetra
.668 .747 .909 r
.46102 .50618 .46737 .51252 .47854 .50894 .47222 .50251 Metetra
.666 .744 .909 r
.47222 .50251 .47854 .50894 .48976 .50539 .48347 .49889 Metetra
.665 .743 .908 r
.48347 .49889 .48976 .50539 .50103 .50184 .49477 .4953 Metetra
.664 .742 .908 r
.49477 .4953 .50103 .50184 .51234 .4983 .50612 .49171 Metetra
.664 .741 .908 r
.50612 .49171 .51234 .4983 .5237 .49474 .51751 .48813 Metetra
.664 .741 .908 r
.51751 .48813 .5237 .49474 .53511 .49116 .52894 .48452 Metetra
.664 .741 .908 r
.52894 .48452 .53511 .49116 .54656 .48757 .54043 .48091 Metetra
.664 .741 .908 r
.54043 .48091 .54656 .48757 .55806 .48397 .55196 .47727 Metetra
.664 .741 .908 r
.55196 .47727 .55806 .48397 .56961 .48035 .56354 .47363 Metetra
.664 .741 .908 r
.56354 .47363 .56961 .48035 .58121 .47671 .57517 .46996 Metetra
.664 .741 .908 r
.57517 .46996 .58121 .47671 .59286 .47306 .58685 .46629 Metetra
.664 .741 .908 r
.58685 .46629 .59286 .47306 .60455 .4694 .59858 .46259 Metetra
.664 .741 .908 r
.59858 .46259 .60455 .4694 .6163 .46572 .61036 .45888 Metetra
.664 .741 .908 r
.61036 .45888 .6163 .46572 .62809 .46202 .62219 .45516 Metetra
.664 .741 .908 r
.62219 .45516 .62809 .46202 .63994 .45831 .63407 .45142 Metetra
.664 .741 .908 r
.63407 .45142 .63994 .45831 .65183 .45458 .646 .44766 Metetra
.664 .741 .908 r
.646 .44766 .65183 .45458 .66378 .45084 .65798 .44389 Metetra
.664 .741 .908 r
.65798 .44389 .66378 .45084 .67578 .44708 .67001 .4401 Metetra
.664 .741 .908 r
.67001 .4401 .67578 .44708 .68782 .44331 .68209 .4363 Metetra
.664 .741 .908 r
.68209 .4363 .68782 .44331 .69992 .43952 .69422 .43248 Metetra
.664 .741 .908 r
.69422 .43248 .69992 .43952 .71207 .43571 .70641 .42864 Metetra
.664 .741 .908 r
.70641 .42864 .71207 .43571 .72427 .43189 .71865 .42478 Metetra
.663 .741 .908 r
.71865 .42478 .72427 .43189 .73653 .42805 .73094 .42092 Metetra
.663 .741 .908 r
.73094 .42092 .73653 .42805 .74884 .4242 .74329 .41704 Metetra
.662 .741 .909 r
.74329 .41704 .74884 .4242 .7612 .42034 .75569 .41318 Metetra
.661 .741 .91 r
.75569 .41318 .7612 .42034 .77362 .4165 .76815 .40935 Metetra
.659 .742 .911 r
.76815 .40935 .77362 .4165 .78609 .41268 .78067 .40557 Metetra
.656 .743 .914 r
.78067 .40557 .78609 .41268 .79863 .40889 .79325 .40184 Metetra
.654 .745 .917 r
.79325 .40184 .79863 .40889 .81122 .40515 .80589 .39817 Metetra
.652 .747 .92 r
.80589 .39817 .81122 .40515 .82388 .40145 .8186 .39454 Metetra
.65 .75 .923 r
.8186 .39454 .82388 .40145 .8366 .39779 .83137 .39094 Metetra
.648 .752 .925 r
.83137 .39094 .8366 .39779 .84939 .39414 .84421 .38735 Metetra
.648 .755 .927 r
.84421 .38735 .84939 .39414 .86223 .39051 .8571 .38376 Metetra
.647 .757 .929 r
.8571 .38376 .86223 .39051 .87514 .38688 .87006 .38016 Metetra
.647 .759 .931 r
.87006 .38016 .87514 .38688 .8881 .38324 .88307 .37653 Metetra
.648 .761 .932 r
.88307 .37653 .8881 .38324 .90113 .37957 .89615 .37287 Metetra
.648 .762 .932 r
.89615 .37287 .90113 .37957 .91422 .37587 .90928 .36916 Metetra
.649 .763 .932 r
.90928 .36916 .91422 .37587 .92736 .37214 .92248 .3654 Metetra
.675 .776 .926 r
.33376 .54285 .34052 .54813 .35127 .5444 .34453 .5391 Metetra
.676 .776 .926 r
.34453 .5391 .35127 .5444 .36205 .54062 .35535 .5353 Metetra
.678 .776 .925 r
.35535 .5353 .36205 .54062 .37288 .53681 .36621 .53144 Metetra
.679 .776 .924 r
.36621 .53144 .37288 .53681 .38375 .53297 .37712 .52754 Metetra
.68 .775 .923 r
.37712 .52754 .38375 .53297 .39467 .52911 .38806 .5236 Metetra
.68 .773 .921 r
.38806 .5236 .39467 .52911 .40562 .52523 .39905 .51963 Metetra
.68 .771 .919 r
.39905 .51963 .40562 .52523 .41662 .52136 .41008 .51564 Metetra
.68 .768 .918 r
.41008 .51564 .41662 .52136 .42765 .5175 .42115 .51166 Metetra
.679 .764 .916 r
.42115 .51166 .42765 .5175 .43873 .51368 .43227 .50769 Metetra
.677 .76 .914 r
.43227 .50769 .43873 .51368 .44985 .5099 .44342 .50377 Metetra
.674 .756 .912 r
.44342 .50377 .44985 .5099 .46102 .50618 .45462 .4999 Metetra
.671 .751 .911 r
.45462 .4999 .46102 .50618 .47222 .50251 .46586 .49611 Metetra
.669 .747 .909 r
.46586 .49611 .47222 .50251 .48347 .49889 .47714 .49239 Metetra
.666 .744 .909 r
.47714 .49239 .48347 .49889 .49477 .4953 .48847 .48872 Metetra
.665 .742 .908 r
.48847 .48872 .49477 .4953 .50612 .49171 .49984 .48509 Metetra
.664 .742 .908 r
.49984 .48509 .50612 .49171 .51751 .48813 .51126 .48147 Metetra
.664 .741 .908 r
.51126 .48147 .51751 .48813 .52894 .48452 .52273 .47783 Metetra
.664 .741 .908 r
.52273 .47783 .52894 .48452 .54043 .48091 .53425 .47419 Metetra
.664 .741 .908 r
.53425 .47419 .54043 .48091 .55196 .47727 .54581 .47053 Metetra
.664 .741 .908 r
.54581 .47053 .55196 .47727 .56354 .47363 .55743 .46685 Metetra
.664 .741 .908 r
.55743 .46685 .56354 .47363 .57517 .46996 .56909 .46316 Metetra
.664 .741 .908 r
.56909 .46316 .57517 .46996 .58685 .46629 .5808 .45946 Metetra
.664 .741 .908 r
.5808 .45946 .58685 .46629 .59858 .46259 .59256 .45573 Metetra
.664 .741 .908 r
.59256 .45573 .59858 .46259 .61036 .45888 .60438 .452 Metetra
.664 .741 .908 r
.60438 .452 .61036 .45888 .62219 .45516 .61624 .44824 Metetra
.664 .741 .908 r
.61624 .44824 .62219 .45516 .63407 .45142 .62815 .44447 Metetra
.664 .741 .908 r
.62815 .44447 .63407 .45142 .646 .44766 .64011 .44069 Metetra
.664 .741 .908 r
.64011 .44069 .646 .44766 .65798 .44389 .65213 .43688 Metetra
.664 .741 .908 r
.65213 .43688 .65798 .44389 .67001 .4401 .66419 .43306 Metetra
.664 .741 .908 r
.66419 .43306 .67001 .4401 .68209 .4363 .67631 .42923 Metetra
.664 .741 .908 r
.67631 .42923 .68209 .4363 .69422 .43248 .68848 .42538 Metetra
.664 .741 .908 r
.68848 .42538 .69422 .43248 .70641 .42864 .7007 .42151 Metetra
.663 .741 .908 r
.7007 .42151 .70641 .42864 .71865 .42478 .71298 .41763 Metetra
.663 .741 .908 r
.71298 .41763 .71865 .42478 .73094 .42092 .72531 .41374 Metetra
.662 .741 .909 r
.72531 .41374 .73094 .42092 .74329 .41704 .73769 .40986 Metetra
.661 .741 .91 r
.73769 .40986 .74329 .41704 .75569 .41318 .75014 .40602 Metetra
.658 .742 .912 r
.75014 .40602 .75569 .41318 .76815 .40935 .76264 .40224 Metetra
.655 .743 .915 r
.76264 .40224 .76815 .40935 .78067 .40557 .77521 .39853 Metetra
.652 .745 .918 r
.77521 .39853 .78067 .40557 .79325 .40184 .78784 .39489 Metetra
.649 .748 .922 r
.78784 .39489 .79325 .40184 .80589 .39817 .80053 .39131 Metetra
.647 .751 .925 r
.80053 .39131 .80589 .39817 .8186 .39454 .81329 .38776 Metetra
.646 .754 .928 r
.81329 .38776 .8186 .39454 .83137 .39094 .82612 .38424 Metetra
.645 .757 .931 r
.82612 .38424 .83137 .39094 .84421 .38735 .839 .38071 Metetra
.644 .76 .933 r
.839 .38071 .84421 .38735 .8571 .38376 .85195 .37715 Metetra
.645 .763 .935 r
.85195 .37715 .8571 .38376 .87006 .38016 .86495 .37357 Metetra
.645 .765 .936 r
.86495 .37357 .87006 .38016 .88307 .37653 .87802 .36994 Metetra
.646 .766 .936 r
.87802 .36994 .88307 .37653 .89615 .37287 .89114 .36626 Metetra
.648 .767 .936 r
.89114 .36626 .89615 .37287 .90928 .36916 .90432 .36252 Metetra
.649 .768 .936 r
.90432 .36252 .90928 .36916 .92248 .3654 .91756 .35873 Metetra
.674 .779 .929 r
.32693 .53765 .33376 .54285 .34453 .5391 .33774 .5339 Metetra
.676 .781 .929 r
.33774 .5339 .34453 .5391 .35535 .5353 .34858 .53008 Metetra
.677 .781 .929 r
.34858 .53008 .35535 .5353 .36621 .53144 .35948 .5262 Metetra
.679 .782 .928 r
.35948 .5262 .36621 .53144 .37712 .52754 .37041 .52226 Metetra
.68 .782 .927 r
.37041 .52226 .37712 .52754 .38806 .5236 .38139 .51826 Metetra
.682 .781 .925 r
.38139 .51826 .38806 .5236 .39905 .51963 .39242 .51421 Metetra
.683 .779 .924 r
.39242 .51421 .39905 .51963 .41008 .51564 .40348 .51012 Metetra
.683 .777 .922 r
.40348 .51012 .41008 .51564 .42115 .51166 .41459 .50601 Metetra
.683 .773 .92 r
.41459 .50601 .42115 .51166 .43227 .50769 .42574 .50189 Metetra
.681 .769 .917 r
.42574 .50189 .43227 .50769 .44342 .50377 .43693 .4978 Metetra
.679 .764 .915 r
.43693 .4978 .44342 .50377 .45462 .4999 .44816 .49376 Metetra
.676 .758 .913 r
.44816 .49376 .45462 .4999 .46586 .49611 .45944 .48979 Metetra
.673 .753 .911 r
.45944 .48979 .46586 .49611 .47714 .49239 .47075 .48592 Metetra
.669 .748 .909 r
.47075 .48592 .47714 .49239 .48847 .48872 .48211 .48214 Metetra
.666 .744 .909 r
.48211 .48214 .48847 .48872 .49984 .48509 .49352 .47843 Metetra
.664 .742 .908 r
.49352 .47843 .49984 .48509 .51126 .48147 .50497 .47476 Metetra
.664 .742 .908 r
.50497 .47476 .51126 .48147 .52273 .47783 .51647 .47109 Metetra
.664 .741 .908 r
.51647 .47109 .52273 .47783 .53425 .47419 .52802 .46742 Metetra
.664 .741 .908 r
.52802 .46742 .53425 .47419 .54581 .47053 .53962 .46373 Metetra
.664 .741 .908 r
.53962 .46373 .54581 .47053 .55743 .46685 .55126 .46003 Metetra
.664 .741 .908 r
.55126 .46003 .55743 .46685 .56909 .46316 .56296 .45631 Metetra
.664 .741 .908 r
.56296 .45631 .56909 .46316 .5808 .45946 .5747 .45257 Metetra
.664 .741 .908 r
.5747 .45257 .5808 .45946 .59256 .45573 .5865 .44882 Metetra
.664 .741 .908 r
.5865 .44882 .59256 .45573 .60438 .452 .59834 .44505 Metetra
.664 .741 .908 r
.59834 .44505 .60438 .452 .61624 .44824 .61024 .44127 Metetra
.664 .741 .908 r
.61024 .44127 .61624 .44824 .62815 .44447 .62219 .43747 Metetra
.664 .741 .908 r
.62219 .43747 .62815 .44447 .64011 .44069 .63418 .43365 Metetra
.664 .741 .908 r
.63418 .43365 .64011 .44069 .65213 .43688 .64623 .42982 Metetra
.664 .741 .908 r
.64623 .42982 .65213 .43688 .66419 .43306 .65833 .42597 Metetra
.664 .741 .908 r
.65833 .42597 .66419 .43306 .67631 .42923 .67049 .42211 Metetra
.664 .741 .908 r
.67049 .42211 .67631 .42923 .68848 .42538 .68269 .41822 Metetra
.664 .741 .908 r
.68269 .41822 .68848 .42538 .7007 .42151 .69495 .41433 Metetra
.663 .741 .908 r
.69495 .41433 .7007 .42151 .71298 .41763 .70727 .41042 Metetra
.662 .741 .908 r
.70727 .41042 .71298 .41763 .72531 .41374 .71963 .40652 Metetra
.661 .741 .91 r
.71963 .40652 .72531 .41374 .73769 .40986 .73206 .40267 Metetra
.658 .742 .912 r
.73206 .40267 .73769 .40986 .75014 .40602 .74455 .39889 Metetra
.654 .743 .915 r
.74455 .39889 .75014 .40602 .76264 .40224 .7571 .39521 Metetra
.65 .746 .92 r
.7571 .39521 .76264 .40224 .77521 .39853 .76972 .39162 Metetra
.646 .749 .924 r
.76972 .39162 .77521 .39853 .78784 .39489 .7824 .3881 Metetra
.644 .753 .929 r
.7824 .3881 .78784 .39489 .80053 .39131 .79515 .38463 Metetra
.642 .757 .932 r
.79515 .38463 .80053 .39131 .81329 .38776 .80796 .38118 Metetra
.641 .761 .936 r
.80796 .38118 .81329 .38776 .82612 .38424 .82084 .37773 Metetra
.641 .764 .938 r
.82084 .37773 .82612 .38424 .839 .38071 .83377 .37424 Metetra
.641 .767 .939 r
.83377 .37424 .839 .38071 .85195 .37715 .84677 .37071 Metetra
.642 .769 .94 r
.84677 .37071 .85195 .37715 .86495 .37357 .85983 .36712 Metetra
.644 .771 .94 r
.85983 .36712 .86495 .37357 .87802 .36994 .87294 .36347 Metetra
.646 .772 .94 r
.87294 .36347 .87802 .36994 .89114 .36626 .88611 .35975 Metetra
.647 .773 .94 r
.88611 .35975 .89114 .36626 .90432 .36252 .89934 .35597 Metetra
.649 .773 .939 r
.89934 .35597 .90432 .36252 .91756 .35873 .91262 .35211 Metetra
.672 .783 .933 r
.32004 .53251 .32693 .53765 .33774 .5339 .33088 .52878 Metetra
.674 .785 .933 r
.33088 .52878 .33774 .5339 .34858 .53008 .34175 .52497 Metetra
.676 .786 .933 r
.34175 .52497 .34858 .53008 .35948 .5262 .35268 .5211 Metetra
.678 .788 .932 r
.35268 .5211 .35948 .5262 .37041 .52226 .36365 .51715 Metetra
.68 .789 .932 r
.36365 .51715 .37041 .52226 .38139 .51826 .37466 .51312 Metetra
.682 .789 .931 r
.37466 .51312 .38139 .51826 .39242 .51421 .38572 .50902 Metetra
.684 .789 .929 r
.38572 .50902 .39242 .51421 .40348 .51012 .39682 .50485 Metetra
.686 .787 .927 r
.39682 .50485 .40348 .51012 .41459 .50601 .40797 .50062 Metetra
.687 .784 .925 r
.40797 .50062 .41459 .50601 .42574 .50189 .41915 .49636 Metetra
.686 .78 .922 r
.41915 .49636 .42574 .50189 .43693 .4978 .43038 .49208 Metetra
.685 .775 .919 r
.43038 .49208 .43693 .4978 .44816 .49376 .44165 .48784 Metetra
.682 .769 .916 r
.44165 .48784 .44816 .49376 .45944 .48979 .45296 .48365 Metetra
.679 .761 .914 r
.45296 .48365 .45944 .48979 .47075 .48592 .46431 .47957 Metetra
.674 .754 .911 r
.46431 .47957 .47075 .48592 .48211 .48214 .47571 .47561 Metetra
.67 .748 .91 r
.47571 .47561 .48211 .48214 .49352 .47843 .48715 .47176 Metetra
.666 .744 .909 r
.48715 .47176 .49352 .47843 .50497 .47476 .49863 .46801 Metetra
.664 .742 .908 r
.49863 .46801 .50497 .47476 .51647 .47109 .51016 .4643 Metetra
.664 .741 .908 r
.51016 .4643 .51647 .47109 .52802 .46742 .52174 .4606 Metetra
.664 .741 .908 r
.52174 .4606 .52802 .46742 .53962 .46373 .53337 .45688 Metetra
.664 .741 .908 r
.53337 .45688 .53962 .46373 .55126 .46003 .54505 .45315 Metetra
.664 .741 .908 r
.54505 .45315 .55126 .46003 .56296 .45631 .55678 .4494 Metetra
.664 .741 .908 r
.55678 .4494 .56296 .45631 .5747 .45257 .56856 .44563 Metetra
.664 .741 .908 r
.56856 .44563 .5747 .45257 .5865 .44882 .58038 .44185 Metetra
.664 .741 .908 r
.58038 .44185 .5865 .44882 .59834 .44505 .59226 .43805 Metetra
.664 .741 .908 r
.59226 .43805 .59834 .44505 .61024 .44127 .60419 .43424 Metetra
.664 .741 .908 r
.60419 .43424 .61024 .44127 .62219 .43747 .61617 .43041 Metetra
.664 .741 .908 r
.61617 .43041 .62219 .43747 .63418 .43365 .62821 .42656 Metetra
.664 .741 .908 r
.62821 .42656 .63418 .43365 .64623 .42982 .64029 .4227 Metetra
.664 .741 .908 r
.64029 .4227 .64623 .42982 .65833 .42597 .65243 .41882 Metetra
.664 .741 .908 r
.65243 .41882 .65833 .42597 .67049 .42211 .66462 .41493 Metetra
.664 .741 .908 r
.66462 .41493 .67049 .42211 .68269 .41822 .67686 .41101 Metetra
.663 .741 .908 r
.67686 .41101 .68269 .41822 .69495 .41433 .68915 .40709 Metetra
.663 .741 .908 r
.68915 .40709 .69495 .41433 .70727 .41042 .70151 .40317 Metetra
.66 .741 .91 r
.70151 .40317 .70727 .41042 .71963 .40652 .71391 .3993 Metetra
.657 .741 .912 r
.71391 .3993 .71963 .40652 .73206 .40267 .72639 .39553 Metetra
.652 .743 .916 r
.72639 .39553 .73206 .40267 .74455 .39889 .73892 .39189 Metetra
.647 .746 .922 r
.73892 .39189 .74455 .39889 .7571 .39521 .75153 .38836 Metetra
.643 .751 .928 r
.75153 .38836 .7571 .39521 .76972 .39162 .7642 .38494 Metetra
.639 .756 .933 r
.7642 .38494 .76972 .39162 .7824 .3881 .77694 .38157 Metetra
.637 .761 .938 r
.77694 .38157 .7824 .3881 .79515 .38463 .78974 .37822 Metetra
.636 .766 .941 r
.78974 .37822 .79515 .38463 .80796 .38118 .80261 .37486 Metetra
.636 .77 .944 r
.80261 .37486 .80796 .38118 .82084 .37773 .81554 .37145 Metetra
.637 .773 .945 r
.81554 .37145 .82084 .37773 .83377 .37424 .82853 .36799 Metetra
.639 .775 .946 r
.82853 .36799 .83377 .37424 .84677 .37071 .84157 .36444 Metetra
.641 .777 .946 r
.84157 .36444 .84677 .37071 .85983 .36712 .85467 .36082 Metetra
.643 .778 .945 r
.85467 .36082 .85983 .36712 .87294 .36347 .86783 .35712 Metetra
.645 .778 .944 r
.86783 .35712 .87294 .36347 .88611 .35975 .88105 .35334 Metetra
.648 .778 .943 r
.88105 .35334 .88611 .35975 .89934 .35597 .89432 .34948 Metetra
.65 .778 .941 r
.89432 .34948 .89934 .35597 .91262 .35211 .90764 .34555 Metetra
.669 .786 .936 r
.31309 .52743 .32004 .53251 .33088 .52878 .32395 .52373 Metetra
.671 .788 .937 r
.32395 .52373 .33088 .52878 .34175 .52497 .33486 .51997 Metetra
.673 .791 .937 r
.33486 .51997 .34175 .52497 .35268 .5211 .34581 .51612 Metetra
.676 .793 .937 r
.34581 .51612 .35268 .5211 .36365 .51715 .35681 .51219 Metetra
.678 .796 .937 r
.35681 .51219 .36365 .51715 .37466 .51312 .36786 .50817 Metetra
.681 .797 .937 r
.36786 .50817 .37466 .51312 .38572 .50902 .37895 .50406 Metetra
.684 .798 .935 r
.37895 .50406 .38572 .50902 .39682 .50485 .39009 .49985 Metetra
.687 .798 .934 r
.39009 .49985 .39682 .50485 .40797 .50062 .40127 .49554 Metetra
.689 .797 .932 r
.40127 .49554 .40797 .50062 .41915 .49636 .4125 .49116 Metetra
.691 .794 .929 r
.4125 .49116 .41915 .49636 .43038 .49208 .42377 .48672 Metetra
.691 .79 .926 r
.42377 .48672 .43038 .49208 .44165 .48784 .43508 .48226 Metetra
.69 .783 .922 r
.43508 .48226 .44165 .48784 .45296 .48365 .44643 .47782 Metetra
.687 .775 .918 r
.44643 .47782 .45296 .48365 .46431 .47957 .45782 .47346 Metetra
.682 .766 .915 r
.45782 .47346 .46431 .47957 .47571 .47561 .46925 .46923 Metetra
.676 .757 .912 r
.46925 .46923 .47571 .47561 .48715 .47176 .48072 .46517 Metetra
.67 .749 .91 r
.48072 .46517 .48715 .47176 .49863 .46801 .49224 .46126 Metetra
.666 .744 .909 r
.49224 .46126 .49863 .46801 .51016 .4643 .5038 .45747 Metetra
.664 .742 .908 r
.5038 .45747 .51016 .4643 .52174 .4606 .51542 .45372 Metetra
.664 .741 .908 r
.51542 .45372 .52174 .4606 .53337 .45688 .52708 .44998 Metetra
.664 .741 .908 r
.52708 .44998 .53337 .45688 .54505 .45315 .53879 .44621 Metetra
.664 .741 .908 r
.53879 .44621 .54505 .45315 .55678 .4494 .55055 .44243 Metetra
.664 .741 .908 r
.55055 .44243 .55678 .4494 .56856 .44563 .56236 .43864 Metetra
.664 .741 .908 r
.56236 .43864 .56856 .44563 .58038 .44185 .57422 .43483 Metetra
.664 .741 .908 r
.57422 .43483 .58038 .44185 .59226 .43805 .58613 .431 Metetra
.664 .741 .908 r
.58613 .431 .59226 .43805 .60419 .43424 .5981 .42716 Metetra
.664 .741 .908 r
.5981 .42716 .60419 .43424 .61617 .43041 .61011 .4233 Metetra
.664 .741 .908 r
.61011 .4233 .61617 .43041 .62821 .42656 .62218 .41942 Metetra
.664 .741 .908 r
.62218 .41942 .62821 .42656 .64029 .4227 .6343 .41553 Metetra
.664 .741 .908 r
.6343 .41553 .64029 .4227 .65243 .41882 .64647 .41161 Metetra
.664 .741 .908 r
.64647 .41161 .65243 .41882 .66462 .41493 .6587 .40769 Metetra
.663 .741 .908 r
.6587 .40769 .66462 .41493 .67686 .41101 .67098 .40374 Metetra
.663 .741 .908 r
.67098 .40374 .67686 .41101 .68915 .40709 .68331 .39981 Metetra
.661 .741 .909 r
.68331 .39981 .68915 .40709 .70151 .40317 .6957 .39592 Metetra
.656 .741 .912 r
.6957 .39592 .70151 .40317 .71391 .3993 .70816 .39216 Metetra
.65 .743 .918 r
.70816 .39216 .71391 .3993 .72639 .39553 .72068 .38857 Metetra
.643 .747 .925 r
.72068 .38857 .72639 .39553 .73892 .39189 .73327 .38514 Metetra
.637 .753 .932 r
.73327 .38514 .73892 .39189 .75153 .38836 .74594 .38184 Metetra
.632 .759 .939 r
.74594 .38184 .75153 .38836 .7642 .38494 .75867 .37861 Metetra
.63 .766 .945 r
.75867 .37861 .7642 .38494 .77694 .38157 .77146 .37539 Metetra
.629 .772 .949 r
.77146 .37539 .77694 .38157 .78974 .37822 .78432 .37215 Metetra
.629 .777 .952 r
.78432 .37215 .78974 .37822 .80261 .37486 .79724 .36884 Metetra
.631 .781 .953 r
.79724 .36884 .80261 .37486 .81554 .37145 .81022 .36545 Metetra
.634 .783 .953 r
.81022 .36545 .81554 .37145 .82853 .36799 .82326 .36196 Metetra
.637 .785 .953 r
.82326 .36196 .82853 .36799 .84157 .36444 .83635 .35837 Metetra
.64 .785 .951 r
.83635 .35837 .84157 .36444 .85467 .36082 .84949 .35468 Metetra
.644 .785 .95 r
.84949 .35468 .85467 .36082 .86783 .35712 .8627 .35089 Metetra
.647 .785 .948 r
.8627 .35089 .86783 .35712 .88105 .35334 .87595 .34701 Metetra
.649 .784 .946 r
.87595 .34701 .88105 .35334 .89432 .34948 .88927 .34306 Metetra
.652 .782 .944 r
.88927 .34306 .89432 .34948 .90764 .34555 .90264 .33902 Metetra
.665 .787 .939 r
.30608 .52237 .31309 .52743 .32395 .52373 .31697 .51873 Metetra
.667 .791 .94 r
.31697 .51873 .32395 .52373 .33486 .51997 .3279 .51503 Metetra
.669 .794 .941 r
.3279 .51503 .33486 .51997 .34581 .51612 .33888 .51125 Metetra
.672 .798 .942 r
.33888 .51125 .34581 .51612 .35681 .51219 .34991 .50738 Metetra
.675 .802 .943 r
.34991 .50738 .35681 .51219 .36786 .50817 .36099 .50341 Metetra
.678 .805 .943 r
.36099 .50341 .36786 .50817 .37895 .50406 .37211 .49933 Metetra
.682 .808 .943 r
.37211 .49933 .37895 .50406 .39009 .49985 .38328 .49514 Metetra
.686 .81 .942 r
.38328 .49514 .39009 .49985 .40127 .49554 .3945 .49082 Metetra
.69 .811 .94 r
.3945 .49082 .40127 .49554 .4125 .49116 .40577 .48637 Metetra
.693 .81 .938 r
.40577 .48637 .4125 .49116 .42377 .48672 .41708 .48181 Metetra
.696 .808 .934 r
.41708 .48181 .42377 .48672 .43508 .48226 .42843 .47716 Metetra
.697 .802 .93 r
.42843 .47716 .43508 .48226 .44643 .47782 .43982 .47247 Metetra
.696 .794 .926 r
.43982 .47247 .44643 .47782 .45782 .47346 .45126 .46779 Metetra
.693 .784 .921 r
.45126 .46779 .45782 .47346 .46925 .46923 .46273 .4632 Metetra
.686 .772 .916 r
.46273 .4632 .46925 .46923 .48072 .46517 .47424 .45879 Metetra
.678 .76 .912 r
.47424 .45879 .48072 .46517 .49224 .46126 .4858 .4546 Metetra
.671 .75 .91 r
.4858 .4546 .49224 .46126 .5038 .45747 .4974 .45064 Metetra
.666 .744 .908 r
.4974 .45064 .5038 .45747 .51542 .45372 .50904 .4468 Metetra
.664 .742 .908 r
.50904 .4468 .51542 .45372 .52708 .44998 .52073 .44302 Metetra
.664 .741 .908 r
.52073 .44302 .52708 .44998 .53879 .44621 .53248 .43922 Metetra
.664 .741 .908 r
.53248 .43922 .53879 .44621 .55055 .44243 .54427 .43542 Metetra
.664 .741 .908 r
.54427 .43542 .55055 .44243 .56236 .43864 .55612 .43159 Metetra
.664 .741 .908 r
.55612 .43159 .56236 .43864 .57422 .43483 .56801 .42775 Metetra
.664 .741 .908 r
.56801 .42775 .57422 .43483 .58613 .431 .57996 .42389 Metetra
.664 .741 .908 r
.57996 .42389 .58613 .431 .5981 .42716 .59196 .42002 Metetra
.664 .741 .908 r
.59196 .42002 .5981 .42716 .61011 .4233 .60401 .41613 Metetra
.664 .741 .908 r
.60401 .41613 .61011 .4233 .62218 .41942 .61611 .41222 Metetra
.664 .741 .908 r
.61611 .41222 .62218 .41942 .6343 .41553 .62826 .40829 Metetra
.664 .741 .908 r
.62826 .40829 .6343 .41553 .64647 .41161 .64047 .40435 Metetra
.664 .741 .908 r
.64047 .40435 .64647 .41161 .6587 .40769 .65273 .40039 Metetra
.663 .741 .908 r
.65273 .40039 .6587 .40769 .67098 .40374 .66505 .39643 Metetra
.661 .741 .909 r
.66505 .39643 .67098 .40374 .68331 .39981 .67742 .39253 Metetra
.655 .741 .913 r
.67742 .39253 .68331 .39981 .6957 .39592 .68986 .38878 Metetra
.647 .743 .919 r
.68986 .38878 .6957 .39592 .70816 .39216 .70237 .38526 Metetra
.638 .748 .928 r
.70237 .38526 .70816 .39216 .72068 .38857 .71495 .38197 Metetra
.629 .755 .938 r
.71495 .38197 .72068 .38857 .73327 .38514 .7276 .37884 Metetra
.623 .764 .947 r
.7276 .37884 .73327 .38514 .74594 .38184 .74033 .3758 Metetra
.619 .773 .954 r
.74033 .3758 .74594 .38184 .75867 .37861 .75312 .37276 Metetra
.619 .781 .959 r
.75312 .37276 .75867 .37861 .77146 .37539 .76598 .36966 Metetra
.62 .787 .961 r
.76598 .36966 .77146 .37539 .78432 .37215 .77889 .36647 Metetra
.623 .791 .962 r
.77889 .36647 .78432 .37215 .79724 .36884 .79186 .36316 Metetra
.628 .794 .962 r
.79186 .36316 .79724 .36884 .81022 .36545 .80488 .35972 Metetra
.632 .795 .96 r
.80488 .35972 .81022 .36545 .82326 .36196 .81796 .35615 Metetra
.637 .795 .958 r
.81796 .35615 .82326 .36196 .83635 .35837 .8311 .35246 Metetra
.641 .794 .956 r
.8311 .35246 .83635 .35837 .84949 .35468 .84429 .34866 Metetra
.645 .793 .953 r
.84429 .34866 .84949 .35468 .8627 .35089 .85753 .34475 Metetra
.649 .791 .95 r
.85753 .34475 .8627 .35089 .87595 .34701 .87083 .34075 Metetra
.652 .789 .947 r
.87083 .34075 .87595 .34701 .88927 .34306 .88418 .33666 Metetra
.654 .787 .945 r
.88418 .33666 .88927 .34306 .90264 .33902 .89759 .3325 Metetra
.661 .788 .942 r
.299 .5173 .30608 .52237 .31697 .51873 .30992 .51375 Metetra
.662 .792 .944 r
.30992 .51375 .31697 .51873 .3279 .51503 .32088 .51014 Metetra
.664 .796 .945 r
.32088 .51014 .3279 .51503 .33888 .51125 .33188 .50646 Metetra
.666 .801 .947 r
.33188 .50646 .33888 .51125 .34991 .50738 .34294 .50268 Metetra
.669 .806 .948 r
.34294 .50268 .34991 .50738 .36099 .50341 .35405 .49881 Metetra
.672 .811 .949 r
.35405 .49881 .36099 .50341 .37211 .49933 .3652 .49483 Metetra
.676 .816 .95 r
.3652 .49483 .37211 .49933 .38328 .49514 .37641 .49071 Metetra
.681 .821 .95 r
.37641 .49071 .38328 .49514 .3945 .49082 .38766 .48644 Metetra
.686 .825 .949 r
.38766 .48644 .3945 .49082 .40577 .48637 .39896 .48202 Metetra
.692 .827 .948 r
.39896 .48202 .40577 .48637 .41708 .48181 .41031 .47742 Metetra
.697 .828 .945 r
.41031 .47742 .41708 .48181 .42843 .47716 .4217 .47267 Metetra
.702 .826 .941 r
.4217 .47267 .42843 .47716 .43982 .47247 .43314 .46777 Metetra
.705 .82 .936 r
.43314 .46777 .43982 .47247 .45126 .46779 .44462 .46278 Metetra
.705 .811 .931 r
.44462 .46278 .45126 .46779 .46273 .4632 .45614 .45778 Metetra
.701 .797 .924 r
.45614 .45778 .46273 .4632 .47424 .45879 .4677 .45289 Metetra
.693 .78 .918 r
.4677 .45289 .47424 .45879 .4858 .4546 .4793 .44824 Metetra
.682 .764 .913 r
.4793 .44824 .4858 .4546 .4974 .45064 .49093 .44391 Metetra
.671 .75 .91 r
.49093 .44391 .4974 .45064 .50904 .4468 .50261 .43987 Metetra
.665 .743 .908 r
.50261 .43987 .50904 .4468 .52073 .44302 .51434 .43601 Metetra
.664 .741 .908 r
.51434 .43601 .52073 .44302 .53248 .43922 .52612 .43218 Metetra
.664 .741 .908 r
.52612 .43218 .53248 .43922 .54427 .43542 .53794 .42834 Metetra
.664 .741 .908 r
.53794 .42834 .54427 .43542 .55612 .43159 .54982 .42449 Metetra
.664 .741 .908 r
.54982 .42449 .55612 .43159 .56801 .42775 .56175 .42061 Metetra
.664 .741 .908 r
.56175 .42061 .56801 .42775 .57996 .42389 .57373 .41673 Metetra
.664 .741 .908 r
.57373 .41673 .57996 .42389 .59196 .42002 .58576 .41282 Metetra
.664 .741 .908 r
.58576 .41282 .59196 .42002 .60401 .41613 .59785 .4089 Metetra
.664 .741 .908 r
.59785 .4089 .60401 .41613 .61611 .41222 .60999 .40496 Metetra
.664 .741 .908 r
.60999 .40496 .61611 .41222 .62826 .40829 .62218 .401 Metetra
.664 .741 .908 r
.62218 .401 .62826 .40829 .64047 .40435 .63442 .39703 Metetra
.663 .741 .908 r
.63442 .39703 .64047 .40435 .65273 .40039 .64672 .39304 Metetra
.661 .741 .909 r
.64672 .39304 .65273 .40039 .66505 .39643 .65908 .38912 Metetra
.654 .74 .913 r
.65908 .38912 .66505 .39643 .67742 .39253 .6715 .38539 Metetra
.643 .742 .921 r
.6715 .38539 .67742 .39253 .68986 .38878 .68399 .38197 Metetra
.629 .748 .933 r
.68399 .38197 .68986 .38878 .70237 .38526 .69656 .37887 Metetra
.617 .759 .947 r
.69656 .37887 .70237 .38526 .71495 .38197 .70921 .376 Metetra
.608 .771 .958 r
.70921 .376 .71495 .38197 .7276 .37884 .72193 .37321 Metetra
.603 .783 .967 r
.72193 .37321 .7276 .37884 .74033 .3758 .73472 .37041 Metetra
.603 .793 .972 r
.73472 .37041 .74033 .3758 .75312 .37276 .74757 .3675 Metetra
.607 .8 .974 r
.74757 .3675 .75312 .37276 .76598 .36966 .76048 .36445 Metetra
.612 .805 .974 r
.76048 .36445 .76598 .36966 .77889 .36647 .77344 .36122 Metetra
.619 .807 .972 r
.77344 .36122 .77889 .36647 .79186 .36316 .78646 .35782 Metetra
.627 .808 .969 r
.78646 .35782 .79186 .36316 .80488 .35972 .79952 .35426 Metetra
.633 .807 .966 r
.79952 .35426 .80488 .35972 .81796 .35615 .81264 .35055 Metetra
.639 .805 .963 r
.81264 .35055 .81796 .35615 .8311 .35246 .82582 .3467 Metetra
.645 .803 .959 r
.82582 .3467 .8311 .35246 .84429 .34866 .83904 .34273 Metetra
.649 .8 .955 r
.83904 .34273 .84429 .34866 .85753 .34475 .85232 .33866 Metetra
.653 .797 .952 r
.85232 .33866 .85753 .34475 .87083 .34075 .86566 .3345 Metetra
.656 .793 .948 r
.86566 .3345 .87083 .34075 .88418 .33666 .87905 .33026 Metetra
.658 .79 .945 r
.87905 .33026 .88418 .33666 .89759 .3325 .8925 .32595 Metetra
.655 .787 .944 r
.29187 .5122 .299 .5173 .30992 .51375 .3028 .50875 Metetra
.656 .791 .947 r
.3028 .50875 .30992 .51375 .32088 .51014 .31379 .50525 Metetra
.658 .796 .949 r
.31379 .50525 .32088 .51014 .33188 .50646 .32482 .50169 Metetra
.659 .802 .951 r
.32482 .50169 .33188 .50646 .34294 .50268 .3359 .49805 Metetra
.661 .808 .954 r
.3359 .49805 .34294 .50268 .35405 .49881 .34703 .49432 Metetra
.664 .815 .956 r
.34703 .49432 .35405 .49881 .3652 .49483 .35822 .49048 Metetra
.667 .822 .958 r
.35822 .49048 .3652 .49483 .37641 .49071 .36945 .48651 Metetra
.672 .829 .959 r
.36945 .48651 .37641 .49071 .38766 .48644 .38074 .48239 Metetra
.677 .836 .96 r
.38074 .48239 .38766 .48644 .39896 .48202 .39207 .47809 Metetra
.684 .843 .959 r
.39207 .47809 .39896 .48202 .41031 .47742 .40346 .47358 Metetra
.692 .849 .958 r
.40346 .47358 .41031 .47742 .4217 .47267 .41489 .46885 Metetra
.7 .852 .955 r
.41489 .46885 .4217 .47267 .43314 .46777 .42638 .46388 Metetra
.708 .851 .95 r
.42638 .46388 .43314 .46777 .44462 .46278 .43791 .45868 Metetra
.715 .846 .944 r
.43791 .45868 .44462 .46278 .45614 .45778 .44948 .45331 Metetra
.717 .834 .937 r
.44948 .45331 .45614 .45778 .4677 .45289 .46109 .44789 Metetra
.713 .816 .929 r
.46109 .44789 .4677 .45289 .4793 .44824 .47273 .44258 Metetra
.702 .793 .921 r
.47273 .44258 .4793 .44824 .49093 .44391 .48442 .4376 Metetra
.686 .769 .914 r
.48442 .4376 .49093 .44391 .50261 .43987 .49613 .43308 Metetra
.672 .751 .91 r
.49613 .43308 .50261 .43987 .51434 .43601 .50789 .42898 Metetra
.665 .743 .908 r
.50789 .42898 .51434 .43601 .52612 .43218 .5197 .42508 Metetra
.664 .741 .908 r
.5197 .42508 .52612 .43218 .53794 .42834 .53156 .42121 Metetra
.664 .741 .908 r
.53156 .42121 .53794 .42834 .54982 .42449 .54348 .41732 Metetra
.664 .741 .908 r
.54348 .41732 .54982 .42449 .56175 .42061 .55544 .41342 Metetra
.664 .741 .908 r
.55544 .41342 .56175 .42061 .57373 .41673 .56745 .4095 Metetra
.664 .741 .908 r
.56745 .4095 .57373 .41673 .58576 .41282 .57952 .40556 Metetra
.664 .741 .908 r
.57952 .40556 .58576 .41282 .59785 .4089 .59164 .40161 Metetra
.664 .741 .908 r
.59164 .40161 .59785 .4089 .60999 .40496 .60382 .39764 Metetra
.664 .741 .908 r
.60382 .39764 .60999 .40496 .62218 .401 .61604 .39365 Metetra
.663 .741 .908 r
.61604 .39365 .62218 .401 .63442 .39703 .62832 .38965 Metetra
.661 .741 .909 r
.62832 .38965 .63442 .39703 .64672 .39304 .64066 .38569 Metetra
.653 .739 .913 r
.64066 .38569 .64672 .39304 .65908 .38912 .65306 .38198 Metetra
.637 .741 .924 r
.65306 .38198 .65908 .38912 .6715 .38539 .66554 .37871 Metetra
.616 .749 .941 r
.66554 .37871 .6715 .38539 .68399 .38197 .67811 .37591 Metetra
.597 .764 .959 r
.67811 .37591 .68399 .38197 .69656 .37887 .69075 .37341 Metetra
.582 .78 .974 r
.69075 .37341 .69656 .37887 .70921 .376 .70348 .37099 Metetra
.576 .796 .983 r
.70348 .37099 .70921 .376 .72193 .37321 .71626 .3685 Metetra
.577 .809 .987 r
.71626 .3685 .72193 .37321 .73472 .37041 .72911 .36582 Metetra
.585 .818 .988 r
.72911 .36582 .73472 .37041 .74757 .3675 .74201 .36291 Metetra
.596 .823 .986 r
.74201 .36291 .74757 .3675 .76048 .36445 .75497 .35976 Metetra
.608 .825 .983 r
.75497 .35976 .76048 .36445 .77344 .36122 .76797 .35638 Metetra
.619 .825 .979 r
.76797 .35638 .77344 .36122 .78646 .35782 .78103 .35279 Metetra
.629 .822 .975 r
.78103 .35279 .78646 .35782 .79952 .35426 .79413 .34902 Metetra
.638 .819 .97 r
.79413 .34902 .79952 .35426 .81264 .35055 .80729 .34509 Metetra
.644 .815 .965 r
.80729 .34509 .81264 .35055 .82582 .3467 .8205 .34103 Metetra
.65 .81 .96 r
.8205 .34103 .82582 .3467 .83904 .34273 .83376 .33685 Metetra
.654 .805 .956 r
.83376 .33685 .83904 .34273 .85232 .33866 .84708 .33259 Metetra
.658 .801 .951 r
.84708 .33259 .85232 .33866 .86566 .3345 .86045 .32824 Metetra
.66 .796 .947 r
.86045 .32824 .86566 .3345 .87905 .33026 .87387 .32382 Metetra
.663 .792 .944 r
.87387 .32382 .87905 .33026 .8925 .32595 .88736 .31934 Metetra
.65 .784 .946 r
.28468 .50701 .29187 .5122 .3028 .50875 .29563 .50367 Metetra
.65 .789 .948 r
.29563 .50367 .3028 .50875 .31379 .50525 .30664 .5003 Metetra
.65 .794 .951 r
.30664 .5003 .31379 .50525 .32482 .50169 .31769 .49688 Metetra
.651 .8 .955 r
.31769 .49688 .32482 .50169 .3359 .49805 .3288 .4934 Metetra
.652 .807 .958 r
.3288 .4934 .3359 .49805 .34703 .49432 .33995 .48986 Metetra
.653 .815 .961 r
.33995 .48986 .34703 .49432 .35822 .49048 .35116 .48622 Metetra
.655 .824 .964 r
.35116 .48622 .35822 .49048 .36945 .48651 .36242 .48247 Metetra
.658 .833 .967 r
.36242 .48247 .36945 .48651 .38074 .48239 .37373 .47858 Metetra
.663 .844 .969 r
.37373 .47858 .38074 .48239 .39207 .47809 .3851 .47452 Metetra
.668 .855 .971 r
.3851 .47452 .39207 .47809 .40346 .47358 .39652 .47024 Metetra
.676 .865 .971 r
.39652 .47024 .40346 .47358 .41489 .46885 .40799 .46571 Metetra
.686 .875 .969 r
.40799 .46571 .41489 .46885 .42638 .46388 .41952 .46087 Metetra
.698 .883 .966 r
.41952 .46087 .42638 .46388 .43791 .45868 .43109 .45568 Metetra
.712 .886 .961 r
.43109 .45568 .43791 .45868 .44948 .45331 .44272 .45015 Metetra
.725 .883 .954 r
.44272 .45015 .44948 .45331 .46109 .44789 .45438 .4443 Metetra
.733 .87 .945 r
.45438 .4443 .46109 .44789 .47273 .44258 .46609 .43828 Metetra
.731 .846 .935 r
.46609 .43828 .47273 .44258 .48442 .4376 .47783 .43236 Metetra
.716 .812 .925 r
.47783 .43236 .48442 .4376 .49613 .43308 .48959 .42688 Metetra
.693 .777 .916 r
.48959 .42688 .49613 .43308 .50789 .42898 .5014 .42211 Metetra
.672 .752 .91 r
.5014 .42211 .50789 .42898 .5197 .42508 .51324 .41795 Metetra
.664 .742 .908 r
.51324 .41795 .5197 .42508 .53156 .42121 .52514 .41402 Metetra
.664 .741 .908 r
.52514 .41402 .53156 .42121 .54348 .41732 .53708 .41011 Metetra
.664 .741 .908 r
.53708 .41011 .54348 .41732 .55544 .41342 .54908 .40617 Metetra
.664 .741 .908 r
.54908 .40617 .55544 .41342 .56745 .4095 .56113 .40222 Metetra
.664 .741 .908 r
.56113 .40222 .56745 .4095 .57952 .40556 .57323 .39825 Metetra
.664 .741 .908 r
.57323 .39825 .57952 .40556 .59164 .40161 .58539 .39426 Metetra
.664 .741 .908 r
.58539 .39426 .59164 .40161 .60382 .39764 .59759 .39026 Metetra
.664 .741 .908 r
.59759 .39026 .60382 .39764 .61604 .39365 .60986 .38624 Metetra
.662 .741 .908 r
.60986 .38624 .61604 .39365 .62832 .38965 .62218 .38225 Metetra
.652 .739 .913 r
.62218 .38225 .62832 .38965 .64066 .38569 .63456 .37855 Metetra
.628 .738 .927 r
.63456 .37855 .64066 .38569 .65306 .38198 .64703 .37553 Metetra
.594 .749 .951 r
.64703 .37553 .65306 .38198 .66554 .37871 .65959 .3732 Metetra
.559 .769 .976 r
.65959 .3732 .66554 .37871 .67811 .37591 .67224 .37126 Metetra
.533 .792 .992 r
.67224 .37126 .67811 .37591 .69075 .37341 .68496 .36937 Metetra
.522 .812 .998 r
.68496 .36937 .69075 .37341 .70348 .37099 .69776 .36728 Metetra
.529 .828 .999 r
.69776 .36728 .70348 .37099 .71626 .3685 .7106 .36486 Metetra
.546 .839 .999 r
.7106 .36486 .71626 .3685 .72911 .36582 .7235 .36209 Metetra
.568 .846 .997 r
.7235 .36209 .72911 .36582 .74201 .36291 .73645 .35897 Metetra
.59 .848 .993 r
.73645 .35897 .74201 .36291 .75497 .35976 .74944 .35555 Metetra
.609 .846 .989 r
.74944 .35555 .75497 .35976 .76797 .35638 .76248 .35187 Metetra
.625 .841 .983 r
.76248 .35187 .76797 .35638 .78103 .35279 .77557 .34798 Metetra
.637 .835 .977 r
.77557 .34798 .78103 .35279 .79413 .34902 .7887 .34391 Metetra
.646 .829 .971 r
.7887 .34391 .79413 .34902 .80729 .34509 .80189 .33969 Metetra
.652 .822 .965 r
.80189 .33969 .80729 .34509 .8205 .34103 .81513 .33537 Metetra
.658 .815 .959 r
.81513 .33537 .8205 .34103 .83376 .33685 .82843 .33095 Metetra
.661 .809 .954 r
.82843 .33095 .83376 .33685 .84708 .33259 .84178 .32645 Metetra
.664 .803 .95 r
.84178 .32645 .84708 .33259 .86045 .32824 .85518 .32189 Metetra
.666 .798 .945 r
.85518 .32189 .86045 .32824 .87387 .32382 .86865 .31728 Metetra
.667 .793 .942 r
.86865 .31728 .87387 .32382 .88736 .31934 .88217 .31263 Metetra
.645 .78 .946 r
.27743 .5017 .28468 .50701 .29563 .50367 .28841 .49847 Metetra
.644 .785 .949 r
.28841 .49847 .29563 .50367 .30664 .5003 .29943 .49523 Metetra
.643 .79 .953 r
.29943 .49523 .30664 .5003 .31769 .49688 .31051 .49197 Metetra
.642 .796 .956 r
.31051 .49197 .31769 .49688 .3288 .4934 .32163 .48867 Metetra
.642 .803 .961 r
.32163 .48867 .3288 .4934 .33995 .48986 .33281 .48533 Metetra
.641 .812 .965 r
.33281 .48533 .33995 .48986 .35116 .48622 .34404 .48194 Metetra
.641 .821 .969 r
.34404 .48194 .35116 .48622 .36242 .48247 .35532 .47846 Metetra
.641 .832 .974 r
.35532 .47846 .36242 .48247 .37373 .47858 .36666 .47488 Metetra
.642 .845 .978 r
.36666 .47488 .37373 .47858 .3851 .47452 .37805 .47116 Metetra
.644 .859 .981 r
.37805 .47116 .3851 .47452 .39652 .47024 .38949 .46726 Metetra
.648 .874 .983 r
.38949 .46726 .39652 .47024 .40799 .46571 .401 .46312 Metetra
.654 .89 .982 r
.401 .46312 .40799 .46571 .41952 .46087 .41255 .45867 Metetra
.664 .906 .979 r
.41255 .45867 .41952 .46087 .43109 .45568 .42417 .45382 Metetra
.68 .92 .973 r
.42417 .45382 .43109 .45568 .44272 .45015 .43584 .44848 Metetra
.701 .931 .965 r
.43584 .44848 .44272 .45015 .45438 .4443 .44756 .4426 Metetra
.727 .934 .957 r
.44756 .4426 .45438 .4443 .46609 .43828 .45933 .43615 Metetra
.749 .924 .948 r
.45933 .43615 .46609 .43828 .47783 .43236 .47114 .42929 Metetra
.756 .894 .94 r
.47114 .42929 .47783 .43236 .48959 .42688 .48298 .42241 Metetra
.739 .845 .929 r
.48298 .42241 .48959 .42688 .5014 .42211 .49484 .41614 Metetra
.703 .789 .918 r
.49484 .41614 .5014 .42211 .51324 .41795 .50673 .411 Metetra
.673 .752 .91 r
.50673 .411 .51324 .41795 .52514 .41402 .51865 .40679 Metetra
.664 .742 .908 r
.51865 .40679 .52514 .41402 .53708 .41011 .53063 .40283 Metetra
.664 .741 .908 r
.53063 .40283 .53708 .41011 .54908 .40617 .54267 .39886 Metetra
.664 .741 .908 r
.54267 .39886 .54908 .40617 .56113 .40222 .55475 .39488 Metetra
.664 .741 .908 r
.55475 .39488 .56113 .40222 .57323 .39825 .56689 .39088 Metetra
.664 .741 .908 r
.56689 .39088 .57323 .39825 .58539 .39426 .57908 .38686 Metetra
.664 .741 .908 r
.57908 .38686 .58539 .39426 .59759 .39026 .59132 .38282 Metetra
.663 .741 .908 r
.59132 .38282 .59759 .39026 .60986 .38624 .60362 .3788 Metetra
.651 .738 .913 r
.60362 .3788 .60986 .38624 .62218 .38225 .61599 .37512 Metetra
.612 .734 .932 r
.61599 .37512 .62218 .38225 .63456 .37855 .62844 .37248 Metetra
.55 .745 .967 r
.62844 .37248 .63456 .37855 .64703 .37553 .64101 .37093 Metetra
.476 .769 .995 r
.64101 .37093 .64703 .37553 .65959 .3732 .65367 .3699 Metetra
.417 .789 .994 r
.65367 .3699 .65959 .3732 .67224 .37126 .66641 .36877 Metetra
.398 .807 .979 r
.66641 .36877 .67224 .37126 .68496 .36937 .67921 .36718 Metetra
.422 .83 .976 r
.67921 .36718 .68496 .36937 .69776 .36728 .69205 .36502 Metetra
.469 .852 .982 r
.69205 .36502 .69776 .36728 .7106 .36486 .70494 .36231 Metetra
.519 .867 .99 r
.70494 .36231 .7106 .36486 .7235 .36209 .71788 .35913 Metetra
.563 .873 .994 r
.71788 .35913 .7235 .36209 .73645 .35897 .73085 .35555 Metetra
.596 .871 .993 r
.73085 .35555 .73645 .35897 .74944 .35555 .74388 .35167 Metetra
.62 .864 .989 r
.74388 .35167 .74944 .35555 .76248 .35187 .75694 .34755 Metetra
.638 .855 .982 r
.75694 .34755 .76248 .35187 .77557 .34798 .77006 .34325 Metetra
.649 .845 .975 r
.77006 .34325 .77557 .34798 .7887 .34391 .78322 .3388 Metetra
.657 .835 .968 r
.78322 .3388 .7887 .34391 .80189 .33969 .79644 .33425 Metetra
.663 .826 .962 r
.79644 .33425 .80189 .33969 .81513 .33537 .80971 .32962 Metetra
.667 .818 .956 r
.80971 .32962 .81513 .33537 .82843 .33095 .82304 .32493 Metetra
.669 .81 .951 r
.82304 .32493 .82843 .33095 .84178 .32645 .83642 .32019 Metetra
.671 .803 .946 r
.83642 .32019 .84178 .32645 .85518 .32189 .84986 .31541 Metetra
.672 .798 .942 r
.84986 .31541 .85518 .32189 .86865 .31728 .86336 .3106 Metetra
.672 .792 .938 r
.86336 .3106 .86865 .31728 .88217 .31263 .87691 .30577 Metetra
.64 .775 .945 r
.27013 .49621 .27743 .5017 .28841 .49847 .28113 .4931 Metetra
.638 .779 .949 r
.28113 .4931 .28841 .49847 .29943 .49523 .29217 .48998 Metetra
.636 .784 .952 r
.29217 .48998 .29943 .49523 .31051 .49197 .30327 .48687 Metetra
.634 .789 .957 r
.30327 .48687 .31051 .49197 .32163 .48867 .31441 .48376 Metetra
.632 .796 .961 r
.31441 .48376 .32163 .48867 .33281 .48533 .32561 .48064 Metetra
.629 .804 .967 r
.32561 .48064 .33281 .48533 .34404 .48194 .33686 .4775 Metetra
.626 .814 .972 r
.33686 .4775 .34404 .48194 .35532 .47846 .34816 .47433 Metetra
.623 .825 .978 r
.34816 .47433 .35532 .47846 .36666 .47488 .35951 .47111 Metetra
.619 .838 .984 r
.35951 .47111 .36666 .47488 .37805 .47116 .37092 .46781 Metetra
.614 .853 .989 r
.37092 .46781 .37805 .47116 .38949 .46726 .38239 .46441 Metetra
.609 .87 .991 r
.38239 .46441 .38949 .46726 .401 .46312 .39391 .46083 Metetra
.604 .888 .99 r
.39391 .46083 .401 .46312 .41255 .45867 .4055 .45702 Metetra
.599 .907 .983 r
.4055 .45702 .41255 .45867 .42417 .45382 .41714 .45286 Metetra
.598 .924 .967 r
.41714 .45286 .42417 .45382 .43584 .44848 .42885 .44823 Metetra
.604 .94 .944 r
.42885 .44823 .43584 .44848 .44756 .4426 .44061 .44294 Metetra
.626 .956 .92 r
.44061 .44294 .44756 .4426 .45933 .43615 .45244 .4368 Metetra
.671 .972 .905 r
.45244 .4368 .45933 .43615 .47114 .42929 .46432 .42968 Metetra
.733 .983 .907 r
.46432 .42968 .47114 .42929 .48298 .42241 .47624 .42163 Metetra
.782 .966 .921 r
.47624 .42163 .48298 .42241 .49484 .41614 .48819 .41316 Metetra
.777 .901 .929 r
.48819 .41316 .49484 .41614 .50673 .411 .50014 .40549 Metetra
.72 .81 .921 r
.50014 .40549 .50673 .411 .51865 .40679 .51212 .39976 Metetra
.672 .752 .91 r
.51212 .39976 .51865 .40679 .53063 .40283 .52413 .3955 Metetra
.664 .741 .908 r
.52413 .3955 .53063 .40283 .54267 .39886 .5362 .39149 Metetra
.664 .741 .908 r
.5362 .39149 .54267 .39886 .55475 .39488 .54832 .38748 Metetra
.664 .741 .908 r
.54832 .38748 .55475 .39488 .56689 .39088 .56049 .38345 Metetra
.664 .741 .908 r
.56049 .38345 .56689 .39088 .57908 .38686 .57272 .37939 Metetra
.663 .741 .908 r
.57272 .37939 .57908 .38686 .59132 .38282 .585 .37534 Metetra
.65 .737 .913 r
.585 .37534 .59132 .38282 .60362 .3788 .59734 .37168 Metetra
.583 .724 .94 r
.59734 .37168 .60362 .3788 .61599 .37512 .60979 .36973 Metetra
.444 .723 .985 r
.60979 .36973 .61599 .37512 .62844 .37248 .62237 .36963 Metetra
.238 .702 .947 r
.62237 .36963 .62844 .37248 .64101 .37093 .63506 .37009 Metetra
.096 .648 .811 r
.63506 .37009 .64101 .37093 .65367 .3699 .64782 .37001 Metetra
.096 .653 .751 r
.64782 .37001 .65367 .3699 .66641 .36877 .66062 .36897 Metetra
.186 .719 .785 r
.66062 .36897 .66641 .36877 .67921 .36718 .67347 .36694 Metetra
.31 .801 .86 r
.67347 .36694 .67921 .36718 .69205 .36502 .68635 .36409 Metetra
.429 .862 .927 r
.68635 .36409 .69205 .36502 .70494 .36231 .69927 .36061 Metetra
.52 .892 .968 r
.69927 .36061 .70494 .36231 .71788 .35913 .71222 .35667 Metetra
.581 .897 .986 r
.71222 .35667 .71788 .35913 .73085 .35555 .72522 .3524 Metetra
.619 .89 .989 r
.72522 .3524 .73085 .35555 .74388 .35167 .73826 .34788 Metetra
.643 .877 .984 r
.73826 .34788 .74388 .35167 .75694 .34755 .75135 .34321 Metetra
.657 .862 .977 r
.75135 .34321 .75694 .34755 .77006 .34325 .76449 .33842 Metetra
.666 .849 .97 r
.76449 .33842 .77006 .34325 .78322 .3388 .77768 .33355 Metetra
.671 .836 .963 r
.77768 .33355 .78322 .3388 .79644 .33425 .79092 .32864 Metetra
.674 .826 .956 r
.79092 .32864 .79644 .33425 .80971 .32962 .80423 .32368 Metetra
.676 .816 .95 r
.80423 .32368 .80971 .32962 .82304 .32493 .81758 .31871 Metetra
.677 .808 .945 r
.81758 .31871 .82304 .32493 .83642 .32019 .831 .31372 Metetra
.677 .801 .941 r
.831 .31372 .83642 .32019 .84986 .31541 .84447 .30872 Metetra
.677 .795 .937 r
.84447 .30872 .84986 .31541 .86336 .3106 .858 .30371 Metetra
.677 .79 .934 r
.858 .30371 .86336 .3106 .87691 .30577 .8716 .29871 Metetra
.635 .768 .943 r
.26278 .49051 .27013 .49621 .28113 .4931 .2738 .48749 Metetra
.633 .771 .946 r
.2738 .48749 .28113 .4931 .29217 .48998 .28486 .48449 Metetra
.63 .775 .95 r
.28486 .48449 .29217 .48998 .30327 .48687 .29598 .48152 Metetra
.627 .78 .955 r
.29598 .48152 .30327 .48687 .31441 .48376 .30714 .47857 Metetra
.623 .786 .96 r
.30714 .47857 .31441 .48376 .32561 .48064 .31836 .47565 Metetra
.618 .793 .965 r
.31836 .47565 .32561 .48064 .33686 .4775 .32963 .47276 Metetra
.613 .801 .972 r
.32963 .47276 .33686 .4775 .34816 .47433 .34094 .46989 Metetra
.606 .811 .979 r
.34094 .46989 .34816 .47433 .35951 .47111 .35231 .46704 Metetra
.597 .823 .986 r
.35231 .46704 .35951 .47111 .37092 .46781 .36374 .4642 Metetra
.585 .836 .993 r
.36374 .4642 .37092 .46781 .38239 .46441 .37522 .46135 Metetra
.569 .851 .997 r
.37522 .46135 .38239 .46441 .39391 .46083 .38676 .45845 Metetra
.546 .867 .995 r
.38676 .45845 .39391 .46083 .4055 .45702 .39836 .45545 Metetra
.514 .879 .98 r
.39836 .45545 .4055 .45702 .41714 .45286 .41002 .45229 Metetra
.469 .88 .942 r
.41002 .45229 .41714 .45286 .42885 .44823 .42174 .44882 Metetra
.414 .863 .869 r
.42174 .44882 .42885 .44823 .44061 .44294 .43353 .44486 Metetra
.359 .826 .764 r
.43353 .44486 .44061 .44294 .45244 .4368 .44539 .44013 Metetra
.333 .789 .654 r
.44539 .44013 .45244 .4368 .46432 .42968 .45732 .43421 Metetra
.45732 .43421 .46432 .42968 .47624 .42163 .46932 .42662 Metetra
.492 .853 .605 r
.46932 .42662 .47624 .42163 .48819 .41316 .48137 .41701 Metetra
.693 .964 .728 r
.48137 .41701 .48819 .41316 .50014 .40549 .49344 .40582 Metetra
.822 .987 .876 r
.49344 .40582 .50014 .40549 .51212 .39976 .50552 .3953 Metetra
.754 .854 .924 r
.50552 .3953 .51212 .39976 .52413 .3955 .51758 .38839 Metetra
.673 .752 .911 r
.51758 .38839 .52413 .3955 .5362 .39149 .52968 .38407 Metetra
.664 .741 .908 r
.52968 .38407 .5362 .39149 .54832 .38748 .54184 .38002 Metetra
.664 .741 .908 r
.54184 .38002 .54832 .38748 .56049 .38345 .55405 .37595 Metetra
.663 .741 .908 r
.55405 .37595 .56049 .38345 .57272 .37939 .56631 .37187 Metetra
.647 .736 .914 r
.56631 .37187 .57272 .37939 .585 .37534 .57863 .36827 Metetra
.512 .696 .952 r
.57863 .36827 .585 .37534 .59734 .37168 .59108 .36779 Metetra
.09 .569 .905 r
.59108 .36779 .59734 .37168 .60979 .36973 .6037 .37061 Metetra
.341 0 0 r
.6037 .37061 .60979 .36973 .62237 .36963 .61643 .37359 Metetra
.37 0 0 r
.61643 .37359 .62237 .36963 .63506 .37009 .62922 .37481 Metetra
.281 0 0 r
.62922 .37481 .63506 .37009 .64782 .37001 .64203 .37403 Metetra
.131 0 0 r
.64203 .37403 .64782 .37001 .66062 .36897 .65487 .37165 Metetra
.65487 .37165 .66062 .36897 .67347 .36694 .66773 .36816 Metetra
.29 .784 .75 r
.66773 .36816 .67347 .36694 .68635 .36409 .68061 .36393 Metetra
.463 .888 .892 r
.68061 .36393 .68635 .36409 .69927 .36061 .69354 .35923 Metetra
.569 .921 .958 r
.69354 .35923 .69927 .36061 .71222 .35667 .7065 .35425 Metetra
.627 .916 .979 r
.7065 .35425 .71222 .35667 .72522 .3524 .71951 .3491 Metetra
.657 .899 .981 r
.71951 .3491 .72522 .3524 .73826 .34788 .73257 .34386 Metetra
.672 .879 .976 r
.73257 .34386 .73826 .34788 .75135 .34321 .74568 .33858 Metetra
.68 .861 .968 r
.74568 .33858 .75135 .34321 .76449 .33842 .75884 .33328 Metetra
.684 .845 .96 r
.75884 .33328 .76449 .33842 .77768 .33355 .77206 .32798 Metetra
.685 .832 .953 r
.77206 .32798 .77768 .33355 .79092 .32864 .78533 .3227 Metetra
.686 .82 .947 r
.78533 .3227 .79092 .32864 .80423 .32368 .79866 .31743 Metetra
.685 .811 .942 r
.79866 .31743 .80423 .32368 .81758 .31871 .81205 .31219 Metetra
.684 .803 .938 r
.81205 .31219 .81758 .31871 .831 .31372 .8255 .30696 Metetra
.683 .796 .934 r
.8255 .30696 .831 .31372 .84447 .30872 .83901 .30176 Metetra
.682 .79 .931 r
.83901 .30176 .84447 .30872 .858 .30371 .85258 .29657 Metetra
.681 .785 .929 r
.85258 .29657 .858 .30371 .8716 .29871 .86621 .2914 Metetra
.632 .76 .939 r
.25538 .48454 .26278 .49051 .2738 .48749 .26642 .48159 Metetra
.629 .763 .943 r
.26642 .48159 .2738 .48749 .28486 .48449 .27751 .47869 Metetra
.626 .765 .946 r
.27751 .47869 .28486 .48449 .29598 .48152 .28865 .47583 Metetra
.622 .769 .95 r
.28865 .47583 .29598 .48152 .30714 .47857 .29983 .47302 Metetra
.617 .773 .955 r
.29983 .47302 .30714 .47857 .31836 .47565 .31106 .47027 Metetra
.611 .778 .961 r
.31106 .47027 .31836 .47565 .32963 .47276 .32235 .4676 Metetra
.603 .784 .968 r
.32235 .4676 .32963 .47276 .34094 .46989 .33368 .46499 Metetra
.594 .792 .975 r
.33368 .46499 .34094 .46989 .35231 .46704 .34507 .46247 Metetra
.581 .801 .983 r
.34507 .46247 .35231 .46704 .36374 .4642 .35651 .46004 Metetra
.564 .811 .991 r
.35651 .46004 .36374 .4642 .37522 .46135 .368 .45771 Metetra
.539 .822 .998 r
.368 .45771 .37522 .46135 .38676 .45845 .37955 .45548 Metetra
.502 .832 .999 r
.37955 .45548 .38676 .45845 .39836 .45545 .39115 .45335 Metetra
.444 .834 .983 r
.39115 .45335 .39836 .45545 .41002 .45229 .40282 .45129 Metetra
.352 .813 .929 r
.40282 .45129 .41002 .45229 .42174 .44882 .41455 .44925 Metetra
.216 .74 .8 r
.41455 .44925 .42174 .44882 .43353 .44486 .42634 .44714 Metetra
.42634 .44714 .43353 .44486 .44539 .44013 .43821 .44477 Metetra
.088 0 0 r
.43821 .44477 .44539 .44013 .45732 .43421 .45015 .44176 Metetra
.163 0 0 r
.45015 .44176 .45732 .43421 .46932 .42662 .46218 .43747 Metetra
.162 0 0 r
.46218 .43747 .46932 .42662 .48137 .41701 .4743 .43078 Metetra
.07 0 .022 r
.4743 .43078 .48137 .41701 .49344 .40582 .48649 .42012 Metetra
.48649 .42012 .49344 .40582 .50552 .3953 .49873 .40448 Metetra
.606 .827 .436 r
.49873 .40448 .50552 .3953 .51758 .38839 .51095 .38725 Metetra
.83 .959 .895 r
.51095 .38725 .51758 .38839 .52968 .38407 .52311 .37706 Metetra
.679 .76 .913 r
.52311 .37706 .52968 .38407 .54184 .38002 .5353 .3725 Metetra
.663 .741 .908 r
.5353 .3725 .54184 .38002 .55405 .37595 .54755 .36841 Metetra
.634 .731 .918 r
.54755 .36841 .55405 .37595 .56631 .37187 .55985 .36518 Metetra
.221 .554 .933 r
.55985 .36518 .56631 .37187 .57863 .36827 .57233 .36879 Metetra
.652 .104 0 r
.57233 .36879 .57863 .36827 .59108 .36779 .58502 .37824 Metetra
.614 .194 .222 r
.58502 .37824 .59108 .36779 .6037 .37061 .59782 .38501 Metetra
.519 .134 .25 r
.59782 .38501 .6037 .37061 .61643 .37359 .61064 .3868 Metetra
.421 .027 .184 r
.61064 .3868 .61643 .37359 .62922 .37481 .62344 .38487 Metetra
.289 0 .042 r
.62344 .38487 .62922 .37481 .64203 .37403 .63624 .38075 Metetra
.091 0 0 r
.63624 .38075 .64203 .37403 .65487 .37165 .64906 .37546 Metetra
.64906 .37546 .65487 .37165 .66773 .36816 .66191 .36961 Metetra
.431 .867 .778 r
.66191 .36961 .66773 .36816 .68061 .36393 .67479 .36353 Metetra
.586 .942 .916 r
.67479 .36353 .68061 .36393 .69354 .35923 .68772 .35738 Metetra
.658 .941 .963 r
.68772 .35738 .69354 .35923 .7065 .35425 .70069 .35126 Metetra
.687 .917 .972 r
.70069 .35126 .7065 .35425 .71951 .3491 .71371 .34521 Metetra
.698 .891 .968 r
.71371 .34521 .71951 .3491 .73257 .34386 .72678 .33925 Metetra
.701 .868 .961 r
.72678 .33925 .73257 .34386 .74568 .33858 .73991 .33338 Metetra
.701 .849 .953 r
.73991 .33338 .74568 .33858 .75884 .33328 .7531 .32761 Metetra
.699 .833 .947 r
.7531 .32761 .75884 .33328 .77206 .32798 .76635 .32192 Metetra
.697 .82 .941 r
.76635 .32192 .77206 .32798 .78533 .3227 .77965 .31631 Metetra
.695 .81 .936 r
.77965 .31631 .78533 .3227 .79866 .31743 .79301 .31076 Metetra
.692 .801 .933 r
.79301 .31076 .79866 .31743 .81205 .31219 .80644 .30528 Metetra
.69 .794 .929 r
.80644 .30528 .81205 .31219 .8255 .30696 .81992 .29985 Metetra
.688 .788 .927 r
.81992 .29985 .8255 .30696 .83901 .30176 .83347 .29446 Metetra
.686 .783 .924 r
.83347 .29446 .83901 .30176 .85258 .29657 .84708 .28912 Metetra
.685 .779 .922 r
.84708 .28912 .85258 .29657 .86621 .2914 .86075 .28381 Metetra
.631 .752 .935 r
.24795 .47828 .25538 .48454 .26642 .48159 .25901 .47538 Metetra
.627 .753 .937 r
.25901 .47538 .26642 .48159 .27751 .47869 .27012 .47253 Metetra
.624 .755 .941 r
.27012 .47253 .27751 .47869 .28865 .47583 .28128 .46974 Metetra
.619 .757 .944 r
.28128 .46974 .28865 .47583 .29983 .47302 .29248 .46703 Metetra
.614 .759 .948 r
.29248 .46703 .29983 .47302 .31106 .47027 .30374 .4644 Metetra
.607 .762 .953 r
.30374 .4644 .31106 .47027 .32235 .4676 .31504 .46187 Metetra
.599 .765 .959 r
.31504 .46187 .32235 .4676 .33368 .46499 .32639 .45946 Metetra
.589 .77 .966 r
.32639 .45946 .33368 .46499 .34507 .46247 .33779 .45718 Metetra
.575 .775 .974 r
.33779 .45718 .34507 .46247 .35651 .46004 .34925 .45507 Metetra
.556 .78 .982 r
.34925 .45507 .35651 .46004 .368 .45771 .36075 .45315 Metetra
.529 .787 .992 r
.36075 .45315 .368 .45771 .37955 .45548 .37231 .45145 Metetra
.49 .791 .998 r
.37231 .45145 .37955 .45548 .39115 .45335 .38392 .45003 Metetra
.426 .789 .995 r
.38392 .45003 .39115 .45335 .40282 .45129 .39559 .44892 Metetra
.32 .765 .962 r
.39559 .44892 .40282 .45129 .41455 .44925 .40732 .4482 Metetra
.143 .68 .846 r
.40732 .4482 .41455 .44925 .42634 .44714 .4191 .44792 Metetra
.099 0 0 r
.4191 .44792 .42634 .44714 .43821 .44477 .43095 .44813 Metetra
.319 0 0 r
.43095 .44813 .43821 .44477 .45015 .44176 .44287 .44884 Metetra
.445 0 .026 r
.44287 .44884 .45015 .44176 .46218 .43747 .45487 .44993 Metetra
.494 .091 .206 r
.45487 .44993 .46218 .43747 .4743 .43078 .46697 .45093 Metetra
.492 .148 .31 r
.46697 .45093 .4743 .43078 .48649 .42012 .47917 .45043 Metetra
.445 .145 .361 r
.47917 .45043 .48649 .42012 .49873 .40448 .49151 .44487 Metetra
.323 .066 .36 r
.49151 .44487 .49873 .40448 .51095 .38725 .50397 .42724 Metetra
.062 0 .263 r
.50397 .42724 .51095 .38725 .52311 .37706 .51642 .3948 Metetra
.51642 .3948 .52311 .37706 .5353 .3725 .52872 .37128 Metetra
.393 .835 .942 r
.52872 .37128 .5353 .3725 .54755 .36841 .54103 .36877 Metetra
.821 .356 .112 r
.54103 .36877 .54755 .36841 .55985 .36518 .55361 .38777 Metetra
.726 .386 .404 r
.55361 .38777 .55985 .36518 .57233 .36879 .56646 .41042 Metetra
.58 .288 .437 r
.56646 .41042 .57233 .36879 .58502 .37824 .57932 .4173 Metetra
.49 .205 .408 r
.57932 .4173 .58502 .37824 .59782 .38501 .5921 .41345 Metetra
.403 .103 .339 r
.5921 .41345 .59782 .38501 .61064 .3868 .60484 .40534 Metetra
.28 0 .209 r
.60484 .40534 .61064 .3868 .62344 .38487 .61758 .39605 Metetra
.079 0 0 r
.61758 .39605 .62344 .38487 .63624 .38075 .63033 .38677 Metetra
.63033 .38677 .63624 .38075 .64906 .37546 .64311 .3779 Metetra
.523 .902 .733 r
.64311 .3779 .64906 .37546 .66191 .36961 .65594 .36952 Metetra
.674 .974 .899 r
.65594 .36952 .66191 .36961 .67479 .36353 .66882 .36162 Metetra
.723 .955 .948 r
.66882 .36162 .67479 .36353 .68772 .35738 .68175 .35415 Metetra
.733 .92 .955 r
.68175 .35415 .68772 .35738 .70069 .35126 .69474 .34703 Metetra
.731 .887 .952 r
.69474 .34703 .70069 .35126 .71371 .34521 .70778 .34023 Metetra
.726 .862 .945 r
.70778 .34023 .71371 .34521 .72678 .33925 .72088 .33368 Metetra
.72 .841 .939 r
.72088 .33368 .72678 .33925 .73991 .33338 .73404 .32735 Metetra
.714 .826 .934 r
.73404 .32735 .73991 .33338 .7531 .32761 .74725 .3212 Metetra
.709 .813 .93 r
.74725 .3212 .7531 .32761 .76635 .32192 .76053 .3152 Metetra
.704 .803 .927 r
.76053 .3152 .76635 .32192 .77965 .31631 .77387 .30934 Metetra
.7 .795 .924 r
.77387 .30934 .77965 .31631 .79301 .31076 .78727 .30358 Metetra
.697 .789 .922 r
.78727 .30358 .79301 .31076 .80644 .30528 .80073 .29791 Metetra
.694 .783 .92 r
.80073 .29791 .80644 .30528 .81992 .29985 .81426 .29232 Metetra
.691 .778 .918 r
.81426 .29232 .81992 .29985 .83347 .29446 .82785 .28679 Metetra
.689 .775 .917 r
.82785 .28679 .83347 .29446 .84708 .28912 .8415 .28132 Metetra
.687 .771 .916 r
.8415 .28132 .84708 .28912 .86075 .28381 .85522 .27589 Metetra
.63 .743 .929 r
.24048 .47171 .24795 .47828 .25901 .47538 .25156 .46881 Metetra
.627 .744 .931 r
.25156 .46881 .25901 .47538 .27012 .47253 .2627 .46598 Metetra
.623 .744 .933 r
.2627 .46598 .27012 .47253 .28128 .46974 .27388 .46322 Metetra
.619 .744 .936 r
.27388 .46322 .28128 .46974 .29248 .46703 .2851 .46054 Metetra
.614 .745 .939 r
.2851 .46054 .29248 .46703 .30374 .4644 .29638 .45796 Metetra
.608 .745 .942 r
.29638 .45796 .30374 .4644 .31504 .46187 .3077 .4555 Metetra
.6 .746 .946 r
.3077 .4555 .31504 .46187 .32639 .45946 .31908 .45317 Metetra
.59 .746 .951 r
.31908 .45317 .32639 .45946 .33779 .45718 .3305 .45102 Metetra
.578 .747 .957 r
.3305 .45102 .33779 .45718 .34925 .45507 .34198 .44906 Metetra
.562 .748 .964 r
.34198 .44906 .34925 .45507 .36075 .45315 .3535 .44735 Metetra
.539 .748 .972 r
.3535 .44735 .36075 .45315 .37231 .45145 .36507 .44595 Metetra
.508 .747 .981 r
.36507 .44595 .37231 .45145 .38392 .45003 .3767 .44492 Metetra
.461 .742 .989 r
.3767 .44492 .38392 .45003 .39559 .44892 .38837 .44436 Metetra
.385 .728 .99 r
.38837 .44436 .39559 .44892 .40732 .4482 .4001 .44442 Metetra
.256 .686 .963 r
.4001 .44442 .40732 .4482 .4191 .44792 .41189 .44527 Metetra
.032 .571 .849 r
.41189 .44527 .4191 .44792 .43095 .44813 .42372 .44718 Metetra
.283 0 0 r
.42372 .44718 .43095 .44813 .44287 .44884 .43562 .45054 Metetra
.541 0 0 r
.43562 .45054 .44287 .44884 .45487 .44993 .44757 .45593 Metetra
.657 .196 .146 r
.44757 .45593 .45487 .44993 .46697 .45093 .45959 .46426 Metetra
.691 .31 .321 r
.45959 .46426 .46697 .45093 .47917 .45043 .47169 .47697 Metetra
.692 .365 .419 r
.47169 .47697 .47917 .45043 .49151 .44487 .48389 .49622 Metetra
.675 .385 .473 r
.48389 .49622 .49151 .44487 .50397 .42724 .49624 .52442 Metetra
.639 .374 .501 r
.49624 .52442 .50397 .42724 .51642 .3948 .50888 .55852 Metetra
.574 .331 .51 r
.50888 .55852 .51642 .3948 .52872 .37128 .52188 .5754 Metetra
.532 .3 .509 r
.52188 .5754 .52872 .37128 .54103 .36877 .53503 .57016 Metetra
.486 .263 .501 r
.53503 .57016 .54103 .36877 .55361 .38777 .54808 .54032 Metetra
.428 .212 .481 r
.54808 .54032 .55361 .38777 .56646 .41042 .56084 .49811 Metetra
.362 .143 .441 r
.56084 .49811 .56646 .41042 .57932 .4173 .57348 .46329 Metetra
.254 .021 .355 r
.57348 .46329 .57932 .4173 .5921 .41345 .5861 .43706 Metetra
.06 0 .172 r
.5861 .43706 .5921 .41345 .60484 .40534 .59873 .41692 Metetra
.59873 .41692 .60484 .40534 .61758 .39605 .61141 .40085 Metetra
.643 .914 .617 r
.61141 .40085 .61758 .39605 .63033 .38677 .62414 .38753 Metetra
.794 .999 .842 r
.62414 .38753 .63033 .38677 .64311 .3779 .63693 .37612 Metetra
.811 .964 .907 r
.63693 .37612 .64311 .3779 .65594 .36952 .64977 .36607 Metetra
.795 .918 .921 r
.64977 .36607 .65594 .36952 .66882 .36162 .66266 .35703 Metetra
.776 .881 .922 r
.66266 .35703 .66882 .36162 .68175 .35415 .67562 .34874 Metetra
.759 .853 .92 r
.67562 .34874 .68175 .35415 .69474 .34703 .68863 .34103 Metetra
.746 .833 .918 r
.68863 .34103 .69474 .34703 .70778 .34023 .70171 .33378 Metetra
.734 .817 .916 r
.70171 .33378 .70778 .34023 .72088 .33368 .71484 .32688 Metetra
.725 .805 .914 r
.71484 .32688 .72088 .33368 .73404 .32735 .72804 .32027 Metetra
.718 .796 .913 r
.72804 .32027 .73404 .32735 .74725 .3212 .74129 .3139 Metetra
.712 .788 .912 r
.74129 .3139 .74725 .3212 .76053 .3152 .75461 .30772 Metetra
.706 .782 .911 r
.75461 .30772 .76053 .3152 .77387 .30934 .76799 .30169 Metetra
.702 .777 .91 r
.76799 .30169 .77387 .30934 .78727 .30358 .78143 .2958 Metetra
.698 .773 .91 r
.78143 .2958 .78727 .30358 .80073 .29791 .79494 .29001 Metetra
.695 .77 .91 r
.79494 .29001 .80073 .29791 .81426 .29232 .80851 .28432 Metetra
.692 .767 .909 r
.80851 .28432 .81426 .29232 .82785 .28679 .82214 .2787 Metetra
.689 .765 .909 r
.82214 .2787 .82785 .28679 .8415 .28132 .83584 .27314 Metetra
.687 .763 .909 r
.83584 .27314 .8415 .28132 .85522 .27589 .8496 .26763 Metetra
.631 .735 .923 r
.23297 .4648 .24048 .47171 .25156 .46881 .24408 .46188 Metetra
.628 .734 .924 r
.24408 .46188 .25156 .46881 .2627 .46598 .25524 .45902 Metetra
.625 .733 .925 r
.25524 .45902 .2627 .46598 .27388 .46322 .26644 .45623 Metetra
.621 .732 .926 r
.26644 .45623 .27388 .46322 .2851 .46054 .2777 .45352 Metetra
.617 .731 .928 r
.2777 .45352 .2851 .46054 .29638 .45796 .289 .45091 Metetra
.611 .729 .929 r
.289 .45091 .29638 .45796 .3077 .4555 .30035 .44842 Metetra
.605 .727 .931 r
.30035 .44842 .3077 .4555 .31908 .45317 .31175 .44607 Metetra
.597 .724 .933 r
.31175 .44607 .31908 .45317 .3305 .45102 .3232 .44388 Metetra
.588 .721 .936 r
.3232 .44388 .3305 .45102 .34198 .44906 .3347 .4419 Metetra
.576 .717 .939 r
.3347 .4419 .34198 .44906 .3535 .44735 .34625 .44017 Metetra
.561 .711 .942 r
.34625 .44017 .3535 .44735 .36507 .44595 .35785 .43873 Metetra
.542 .704 .945 r
.35785 .43873 .36507 .44595 .3767 .44492 .3695 .43768 Metetra
.516 .694 .949 r
.3695 .43768 .3767 .44492 .38837 .44436 .3812 .4371 Metetra
.481 .678 .952 r
.3812 .4371 .38837 .44436 .4001 .44442 .39296 .43713 Metetra
.431 .656 .954 r
.39296 .43713 .4001 .44442 .41189 .44527 .40476 .43795 Metetra
.358 .619 .95 r
.40476 .43795 .41189 .44527 .42372 .44718 .41662 .43984 Metetra
.245 .556 .933 r
.41662 .43984 .42372 .44718 .43562 .45054 .42853 .44318 Metetra
.067 .445 .878 r
.42853 .44318 .43562 .45054 .44757 .45593 .4405 .44856 Metetra
0 .252 .742 r
.4405 .44856 .44757 .45593 .45959 .46426 .45253 .45688 Metetra
.515 .022 0 r
.45253 .45688 .45959 .46426 .47169 .47697 .46462 .46959 Metetra
.756 .281 0 r
.46462 .46959 .47169 .47697 .48389 .49622 .47681 .48885 Metetra
.873 .441 .037 r
.47681 .48885 .48389 .49622 .49624 .52442 .48913 .51708 Metetra
.902 .491 .112 r
.48913 .51708 .49624 .52442 .50888 .55852 .50172 .55124 Metetra
.662 .169 0 r
.50172 .55124 .50888 .55852 .52188 .5754 .51472 .56812 Metetra
.687 .775 .918 r
.51472 .56812 .52188 .5754 .53503 .57016 .52792 .56285 Metetra
.921 .778 .686 r
.52792 .56285 .53503 .57016 .54808 .54032 .54105 .53291 Metetra
.941 .762 .631 r
.54105 .53291 .54808 .54032 .56084 .49811 .55394 .49059 Metetra
.932 .77 .657 r
.55394 .49059 .56084 .49811 .57348 .46329 .56668 .45567 Metetra
.913 .78 .701 r
.56668 .45567 .57348 .46329 .5861 .43706 .57938 .42936 Metetra
.887 .787 .744 r
.57938 .42936 .5861 .43706 .59873 .41692 .59209 .40915 Metetra
.86 .79 .781 r
.59209 .40915 .59873 .41692 .61141 .40085 .60484 .39303 Metetra
.834 .789 .809 r
.60484 .39303 .61141 .40085 .62414 .38753 .61762 .37965 Metetra
.811 .787 .83 r
.61762 .37965 .62414 .38753 .63693 .37612 .63046 .36819 Metetra
.79 .784 .847 r
.63046 .36819 .63693 .37612 .64977 .36607 .64335 .35809 Metetra
.773 .78 .859 r
.64335 .35809 .64977 .36607 .66266 .35703 .6563 .349 Metetra
.758 .777 .868 r
.6563 .349 .66266 .35703 .67562 .34874 .6693 .34067 Metetra
.746 .773 .875 r
.6693 .34067 .67562 .34874 .68863 .34103 .68237 .33292 Metetra
.736 .77 .881 r
.68237 .33292 .68863 .34103 .70171 .33378 .69549 .32562 Metetra
.727 .768 .885 r
.69549 .32562 .70171 .33378 .71484 .32688 .70867 .31868 Metetra
.72 .765 .889 r
.70867 .31868 .71484 .32688 .72804 .32027 .72191 .31203 Metetra
.714 .763 .891 r
.72191 .31203 .72804 .32027 .74129 .3139 .73521 .30562 Metetra
.708 .762 .894 r
.73521 .30562 .74129 .3139 .75461 .30772 .74858 .29939 Metetra
.704 .76 .896 r
.74858 .29939 .75461 .30772 .76799 .30169 .762 .29333 Metetra
.7 .758 .897 r
.762 .29333 .76799 .30169 .78143 .2958 .77549 .28739 Metetra
.696 .757 .899 r
.77549 .28739 .78143 .2958 .79494 .29001 .78905 .28156 Metetra
.693 .756 .9 r
.78905 .28156 .79494 .29001 .80851 .28432 .80266 .27582 Metetra
.691 .755 .901 r
.80266 .27582 .80851 .28432 .82214 .2787 .81635 .27016 Metetra
.688 .754 .902 r
.81635 .27016 .82214 .2787 .83584 .27314 .83009 .26456 Metetra
.686 .753 .902 r
.83009 .26456 .83584 .27314 .8496 .26763 .8439 .25902 Metetra
.634 .728 .916 r
.22543 .45756 .23297 .4648 .24408 .46188 .23657 .45457 Metetra
.631 .726 .916 r
.23657 .45457 .24408 .46188 .25524 .45902 .24775 .45164 Metetra
.628 .724 .916 r
.24775 .45164 .25524 .45902 .26644 .45623 .25899 .44877 Metetra
.625 .721 .916 r
.25899 .44877 .26644 .45623 .2777 .45352 .27027 .44597 Metetra
.622 .718 .916 r
.27027 .44597 .2777 .45352 .289 .45091 .28161 .44325 Metetra
.617 .715 .915 r
.28161 .44325 .289 .45091 .30035 .44842 .29299 .44064 Metetra
.613 .711 .915 r
.29299 .44064 .30035 .44842 .31175 .44607 .30442 .43814 Metetra
.607 .706 .914 r
.30442 .43814 .31175 .44607 .3232 .44388 .3159 .43578 Metetra
.601 .699 .912 r
.3159 .43578 .3232 .44388 .3347 .4419 .32744 .43358 Metetra
.594 .692 .91 r
.32744 .43358 .3347 .4419 .34625 .44017 .33902 .43158 Metetra
.586 .682 .907 r
.33902 .43158 .34625 .44017 .35785 .43873 .35066 .4298 Metetra
.576 .67 .903 r
.35066 .4298 .35785 .43873 .3695 .43768 .36235 .42829 Metetra
.565 .655 .896 r
.36235 .42829 .3695 .43768 .3812 .4371 .3741 .42711 Metetra
.554 .636 .887 r
.3741 .42711 .3812 .4371 .39296 .43713 .3859 .42631 Metetra
.542 .612 .873 r
.3859 .42631 .39296 .43713 .40476 .43795 .39776 .42594 Metetra
.53 .583 .853 r
.39776 .42594 .40476 .43795 .41662 .43984 .40968 .42608 Metetra
.523 .55 .825 r
.40968 .42608 .41662 .43984 .42853 .44318 .42167 .42672 Metetra
.522 .513 .787 r
.42167 .42672 .42853 .44318 .4405 .44856 .43374 .42774 Metetra
.534 .479 .74 r
.43374 .42774 .4405 .44856 .45253 .45688 .4459 .42867 Metetra
.562 .454 .689 r
.4459 .42867 .45253 .45688 .46462 .46959 .45819 .42809 Metetra
.601 .444 .64 r
.45819 .42809 .46462 .46959 .47681 .48885 .47065 .42241 Metetra
.638 .442 .602 r
.47065 .42241 .47681 .48885 .48913 .51708 .48331 .4046 Metetra
.642 .427 .576 r
.48331 .4046 .48913 .51708 .50172 .55124 .49605 .37191 Metetra
.593 .38 .56 r
.49605 .37191 .50172 .55124 .51472 .56812 .50858 .34819 Metetra
.549 .342 .552 r
.50858 .34819 .51472 .56812 .52792 .56285 .52099 .34558 Metetra
.508 .311 .548 r
.52099 .34558 .52792 .56285 .54105 .53291 .53353 .3646 Metetra
.489 .301 .552 r
.53353 .3646 .54105 .53291 .55394 .49059 .54634 .38728 Metetra
.521 .339 .574 r
.54634 .38728 .55394 .49059 .56668 .45567 .55925 .39412 Metetra
.574 .399 .608 r
.55925 .39412 .56668 .45567 .57938 .42936 .57215 .39016 Metetra
.623 .464 .646 r
.57215 .39016 .57938 .42936 .59209 .40915 .58503 .38192 Metetra
.662 .524 .685 r
.58503 .38192 .59209 .40915 .60484 .39303 .59791 .3725 Metetra
.689 .575 .722 r
.59791 .3725 .60484 .39303 .61762 .37965 .61081 .36308 Metetra
.706 .616 .754 r
.61081 .36308 .61762 .37965 .63046 .36819 .62375 .35407 Metetra
.715 .648 .782 r
.62375 .35407 .63046 .36819 .64335 .35809 .63672 .34556 Metetra
.718 .673 .805 r
.63672 .34556 .64335 .35809 .6563 .349 .64975 .33753 Metetra
.718 .691 .823 r
.64975 .33753 .6563 .349 .6693 .34067 .66282 .32993 Metetra
.717 .705 .838 r
.66282 .32993 .6693 .34067 .68237 .33292 .67595 .32269 Metetra
.714 .715 .849 r
.67595 .32269 .68237 .33292 .69549 .32562 .68913 .31575 Metetra
.711 .722 .859 r
.68913 .31575 .69549 .32562 .70867 .31868 .70237 .30908 Metetra
.707 .728 .867 r
.70237 .30908 .70867 .31868 .72191 .31203 .71566 .30262 Metetra
.704 .732 .873 r
.71566 .30262 .72191 .31203 .73521 .30562 .72902 .29635 Metetra
.701 .735 .878 r
.72902 .29635 .73521 .30562 .74858 .29939 .74244 .29023 Metetra
.698 .738 .882 r
.74244 .29023 .74858 .29939 .762 .29333 .75592 .28423 Metetra
.695 .74 .885 r
.75592 .28423 .762 .29333 .77549 .28739 .76946 .27835 Metetra
.692 .741 .888 r
.76946 .27835 .77549 .28739 .78905 .28156 .78307 .27255 Metetra
.69 .742 .891 r
.78307 .27255 .78905 .28156 .80266 .27582 .79673 .26684 Metetra
.688 .743 .893 r
.79673 .26684 .80266 .27582 .81635 .27016 .81047 .26118 Metetra
.686 .743 .895 r
.81047 .26118 .81635 .27016 .83009 .26456 .82426 .25559 Metetra
.685 .744 .896 r
.82426 .25559 .83009 .26456 .8439 .25902 .83813 .25003 Metetra
.637 .721 .909 r
.21785 .44999 .22543 .45756 .23657 .45457 .22902 .44691 Metetra
.635 .718 .908 r
.22902 .44691 .23657 .45457 .24775 .45164 .24024 .44386 Metetra
.633 .715 .907 r
.24024 .44386 .24775 .45164 .25899 .44877 .25151 .44086 Metetra
.63 .712 .905 r
.25151 .44086 .25899 .44877 .27027 .44597 .26283 .43791 Metetra
.628 .708 .904 r
.26283 .43791 .27027 .44597 .28161 .44325 .27419 .43502 Metetra
.625 .703 .901 r
.27419 .43502 .28161 .44325 .29299 .44064 .28561 .4322 Metetra
.622 .697 .899 r
.28561 .4322 .29299 .44064 .30442 .43814 .29708 .42945 Metetra
.619 .691 .895 r
.29708 .42945 .30442 .43814 .3159 .43578 .30861 .42678 Metetra
.616 .683 .89 r
.30861 .42678 .3159 .43578 .32744 .43358 .32018 .42421 Metetra
.612 .673 .884 r
.32018 .42421 .32744 .43358 .33902 .43158 .33181 .42174 Metetra
.609 .662 .876 r
.33181 .42174 .33902 .43158 .35066 .4298 .3435 .41937 Metetra
.606 .648 .866 r
.3435 .41937 .35066 .4298 .36235 .42829 .35524 .41709 Metetra
.604 .632 .852 r
.35524 .41709 .36235 .42829 .3741 .42711 .36705 .41488 Metetra
.602 .613 .835 r
.36705 .41488 .3741 .42711 .3859 .42631 .37892 .4127 Metetra
.603 .592 .813 r
.37892 .4127 .3859 .42631 .39776 .42594 .39086 .41045 Metetra
.606 .569 .787 r
.39086 .41045 .39776 .42594 .40968 .42608 .40287 .40792 Metetra
.613 .545 .755 r
.40287 .40792 .40968 .42608 .42167 .42672 .41498 .40476 Metetra
.623 .523 .72 r
.41498 .40476 .42167 .42672 .43374 .42774 .42718 .4003 Metetra
.637 .505 .685 r
.42718 .4003 .43374 .42774 .4459 .42867 .4395 .39342 Metetra
.652 .49 .652 r
.4395 .39342 .4459 .42867 .45819 .42809 .45195 .38253 Metetra
.661 .478 .626 r
.45195 .38253 .45819 .42809 .47065 .42241 .46449 .36661 Metetra
.65 .459 .611 r
.46449 .36661 .47065 .42241 .48331 .4046 .47703 .34909 Metetra
.614 .433 .613 r
.47703 .34909 .48331 .4046 .49605 .37191 .48943 .33869 Metetra
.603 .462 .663 r
.48943 .33869 .49605 .37191 .50858 .34819 .50181 .33395 Metetra
.644 .606 .797 r
.50181 .33395 .50858 .34819 .52099 .34558 .51423 .32968 Metetra
.621 .575 .781 r
.51423 .32968 .52099 .34558 .53353 .3646 .52671 .32629 Metetra
.514 .39 .648 r
.52671 .32629 .53353 .3646 .54634 .38728 .53929 .32979 Metetra
.48 .335 .606 r
.53929 .32979 .54634 .38728 .55925 .39412 .55204 .33918 Metetra
.5 .352 .612 r
.55204 .33918 .55925 .39412 .57215 .39016 .56492 .34587 Metetra
.536 .394 .635 r
.56492 .34587 .57215 .39016 .58503 .38192 .57787 .34753 Metetra
.574 .443 .663 r
.57787 .34753 .58503 .38192 .59791 .3725 .59084 .34544 Metetra
.608 .491 .694 r
.59084 .34544 .59791 .3725 .61081 .36308 .60385 .34114 Metetra
.635 .535 .724 r
.60385 .34114 .61081 .36308 .62375 .35407 .61688 .33566 Metetra
.655 .573 .751 r
.61688 .33566 .62375 .35407 .63672 .34556 .62995 .32961 Metetra
.67 .606 .775 r
.62995 .32961 .63672 .34556 .64975 .33753 .64305 .32332 Metetra
.679 .633 .796 r
.64305 .32332 .64975 .33753 .66282 .32993 .6562 .31697 Metetra
.685 .654 .813 r
.6562 .31697 .66282 .32993 .67595 .32269 .6694 .31064 Metetra
.689 .672 .828 r
.6694 .31064 .67595 .32269 .68913 .31575 .68265 .30439 Metetra
.691 .685 .84 r
.68265 .30439 .68913 .31575 .70237 .30908 .69595 .29822 Metetra
.691 .696 .85 r
.69595 .29822 .70237 .30908 .71566 .30262 .70931 .29215 Metetra
.691 .705 .858 r
.70931 .29215 .71566 .30262 .72902 .29635 .72273 .28617 Metetra
.69 .712 .865 r
.72273 .28617 .72902 .29635 .74244 .29023 .7362 .28028 Metetra
.689 .718 .871 r
.7362 .28028 .74244 .29023 .75592 .28423 .74974 .27446 Metetra
.688 .722 .876 r
.74974 .27446 .75592 .28423 .76946 .27835 .76334 .26871 Metetra
.687 .726 .88 r
.76334 .26871 .76946 .27835 .78307 .27255 .777 .26301 Metetra
.686 .729 .883 r
.777 .26301 .78307 .27255 .79673 .26684 .79072 .25737 Metetra
.684 .731 .886 r
.79072 .25737 .79673 .26684 .81047 .26118 .8045 .25178 Metetra
.683 .733 .889 r
.8045 .25178 .81047 .26118 .82426 .25559 .81836 .24622 Metetra
.682 .735 .891 r
.81836 .24622 .82426 .25559 .83813 .25003 .83227 .2407 Metetra
.64 .715 .902 r
.21024 .44213 .21785 .44999 .22902 .44691 .22144 .43891 Metetra
.639 .712 .9 r
.22144 .43891 .22902 .44691 .24024 .44386 .2327 .43571 Metetra
.638 .709 .898 r
.2327 .43571 .24024 .44386 .25151 .44086 .244 .43254 Metetra
.636 .705 .896 r
.244 .43254 .25151 .44086 .26283 .43791 .25535 .42939 Metetra
.635 .7 .893 r
.25535 .42939 .26283 .43791 .27419 .43502 .26676 .42627 Metetra
.634 .694 .889 r
.26676 .42627 .27419 .43502 .28561 .4322 .27822 .42318 Metetra
.632 .688 .884 r
.27822 .42318 .28561 .4322 .29708 .42945 .28973 .4201 Metetra
.631 .681 .879 r
.28973 .4201 .29708 .42945 .30861 .42678 .3013 .41705 Metetra
.63 .672 .872 r
.3013 .41705 .30861 .42678 .32018 .42421 .31293 .414 Metetra
.63 .662 .863 r
.31293 .414 .32018 .42421 .33181 .42174 .32461 .41093 Metetra
.63 .651 .852 r
.32461 .41093 .33181 .42174 .3435 .41937 .33635 .40782 Metetra
.63 .638 .839 r
.33635 .40782 .3435 .41937 .35524 .41709 .34816 .40462 Metetra
.632 .623 .823 r
.34816 .40462 .35524 .41709 .36705 .41488 .36003 .40124 Metetra
.635 .607 .805 r
.36003 .40124 .36705 .41488 .37892 .4127 .37198 .39755 Metetra
.64 .591 .783 r
.37198 .39755 .37892 .4127 .39086 .41045 .384 .39336 Metetra
.646 .574 .759 r
.384 .39336 .39086 .41045 .40287 .40792 .39611 .38839 Metetra
.655 .558 .733 r
.39611 .38839 .40287 .40792 .41498 .40476 .40831 .38221 Metetra
.664 .543 .708 r
.40831 .38221 .41498 .40476 .42718 .4003 .4206 .37434 Metetra
.672 .532 .686 r
.4206 .37434 .42718 .4003 .4395 .39342 .43298 .36443 Metetra
.675 .522 .671 r
.43298 .36443 .4395 .39342 .45195 .38253 .44541 .35292 Metetra
.667 .515 .669 r
.44541 .35292 .45195 .38253 .46449 .36661 .45783 .34208 Metetra
.648 .524 .698 r
.45783 .34208 .46449 .36661 .47703 .34909 .47018 .33489 Metetra
.649 .61 .796 r
.47018 .33489 .47703 .34909 .48943 .33869 .48253 .33033 Metetra
.663 .728 .898 r
.48253 .33033 .48943 .33869 .50181 .33395 .49494 .32604 Metetra
.664 .741 .908 r
.49494 .32604 .50181 .33395 .51423 .32968 .5074 .32173 Metetra
.663 .741 .908 r
.5074 .32173 .51423 .32968 .52671 .32629 .51992 .31741 Metetra
.647 .711 .894 r
.51992 .31741 .52671 .32629 .53929 .32979 .53249 .31357 Metetra
.561 .541 .789 r
.53249 .31357 .53929 .32979 .55204 .33918 .54515 .31288 Metetra
.509 .43 .702 r
.54515 .31288 .55204 .33918 .56492 .34587 .55793 .31553 Metetra
.513 .415 .681 r
.55793 .31553 .56492 .34587 .57787 .34753 .57083 .31835 Metetra
.537 .436 .687 r
.57083 .31835 .57787 .34753 .59084 .34544 .58382 .31938 Metetra
.565 .469 .704 r
.58382 .31938 .59084 .34544 .60385 .34114 .59687 .31839 Metetra
.592 .504 .724 r
.59687 .31839 .60385 .34114 .61688 .33566 .60996 .31578 Metetra
.615 .539 .746 r
.60996 .31578 .61688 .33566 .62995 .32961 .62309 .31203 Metetra
.633 .57 .766 r
.62309 .31203 .62995 .32961 .64305 .32332 .63627 .30754 Metetra
.647 .598 .785 r
.63627 .30754 .64305 .32332 .6562 .31697 .64949 .30258 Metetra
.658 .622 .801 r
.64949 .30258 .6562 .31697 .6694 .31064 .66276 .29732 Metetra
.666 .641 .816 r
.66276 .29732 .6694 .31064 .68265 .30439 .67607 .2919 Metetra
.671 .658 .828 r
.67607 .2919 .68265 .30439 .69595 .29822 .68944 .28638 Metetra
.675 .672 .839 r
.68944 .28638 .69595 .29822 .70931 .29215 .70286 .28082 Metetra
.678 .683 .848 r
.70286 .28082 .70931 .29215 .72273 .28617 .71634 .27523 Metetra
.679 .693 .856 r
.71634 .27523 .72273 .28617 .7362 .28028 .72988 .26965 Metetra
.68 .701 .862 r
.72988 .26965 .7362 .28028 .74974 .27446 .74347 .26408 Metetra
.68 .707 .868 r
.74347 .26408 .74974 .27446 .76334 .26871 .75713 .25853 Metetra
.68 .712 .873 r
.75713 .25853 .76334 .26871 .777 .26301 .77084 .25299 Metetra
.68 .717 .877 r
.77084 .25299 .777 .26301 .79072 .25737 .78462 .24748 Metetra
.679 .721 .88 r
.78462 .24748 .79072 .25737 .8045 .25178 .79846 .24198 Metetra
.679 .724 .884 r
.79846 .24198 .8045 .25178 .81836 .24622 .81237 .2365 Metetra
.678 .726 .886 r
.81237 .2365 .81836 .24622 .83227 .2407 .82634 .23103 Metetra
.644 .711 .896 r
.20259 .43399 .21024 .44213 .22144 .43891 .21383 .43061 Metetra
.644 .707 .893 r
.21383 .43061 .22144 .43891 .2327 .43571 .22512 .42724 Metetra
.643 .704 .89 r
.22512 .42724 .2327 .43571 .244 .43254 .23646 .42387 Metetra
.643 .699 .887 r
.23646 .42387 .244 .43254 .25535 .42939 .24786 .42049 Metetra
.642 .694 .883 r
.24786 .42049 .25535 .42939 .26676 .42627 .2593 .4171 Metetra
.642 .689 .878 r
.2593 .4171 .26676 .42627 .27822 .42318 .27081 .4137 Metetra
.642 .682 .873 r
.27081 .4137 .27822 .42318 .28973 .4201 .28237 .41026 Metetra
.642 .675 .866 r
.28237 .41026 .28973 .4201 .3013 .41705 .29398 .40677 Metetra
.643 .667 .858 r
.29398 .40677 .3013 .41705 .31293 .414 .30566 .4032 Metetra
.644 .657 .848 r
.30566 .4032 .31293 .414 .32461 .41093 .3174 .39952 Metetra
.646 .647 .837 r
.3174 .39952 .32461 .41093 .33635 .40782 .3292 .39566 Metetra
.649 .636 .824 r
.3292 .39566 .33635 .40782 .34816 .40462 .34107 .39156 Metetra
.653 .624 .808 r
.34107 .39156 .34816 .40462 .36003 .40124 .35301 .38711 Metetra
.658 .612 .792 r
.35301 .38711 .36003 .40124 .37198 .39755 .36502 .38217 Metetra
.664 .6 .774 r
.36502 .38217 .37198 .39755 .384 .39336 .37712 .37656 Metetra
.67 .589 .756 r
.37712 .37656 .384 .39336 .39611 .38839 .38929 .3701 Metetra
.677 .58 .739 r
.38929 .3701 .39611 .38839 .40831 .38221 .40153 .36263 Metetra
.683 .573 .726 r
.40153 .36263 .40831 .38221 .4206 .37434 .41384 .35421 Metetra
.685 .571 .721 r
.41384 .35421 .4206 .37434 .43298 .36443 .42619 .34537 Metetra
.68 .576 .731 r
.42619 .34537 .43298 .36443 .44541 .35292 .43853 .33734 Metetra
.67 .603 .772 r
.43853 .33734 .44541 .35292 .45783 .34208 .45085 .33127 Metetra
.663 .672 .848 r
.45085 .33127 .45783 .34208 .47018 .33489 .46319 .32671 Metetra
.663 .733 .902 r
.46319 .32671 .47018 .33489 .48253 .33033 .47557 .3224 Metetra
.664 .741 .908 r
.47557 .3224 .48253 .33033 .49494 .32604 .48801 .31807 Metetra
.664 .741 .908 r
.48801 .31807 .49494 .32604 .5074 .32173 .50051 .31372 Metetra
.664 .741 .908 r
.50051 .31372 .5074 .32173 .51992 .31741 .51306 .30936 Metetra
.663 .741 .908 r
.51306 .30936 .51992 .31741 .53249 .31357 .52568 .30498 Metetra
.65 .723 .902 r
.52568 .30498 .53249 .31357 .54515 .31288 .53835 .30102 Metetra
.597 .628 .852 r
.53835 .30102 .54515 .31288 .55793 .31553 .5511 .29878 Metetra
.553 .532 .786 r
.5511 .29878 .55793 .31553 .57083 .31835 .56395 .29841 Metetra
.543 .495 .752 r
.56395 .29841 .57083 .31835 .58382 .31938 .5769 .29862 Metetra
.554 .496 .744 r
.5769 .29862 .58382 .31938 .59687 .31839 .58994 .29828 Metetra
.572 .512 .749 r
.58994 .29828 .59687 .31839 .60996 .31578 .60306 .29695 Metetra
.592 .535 .76 r
.60306 .29695 .60996 .31578 .62309 .31203 .61623 .29463 Metetra
.609 .559 .773 r
.61623 .29463 .62309 .31203 .63627 .30754 .62945 .29147 Metetra
.624 .583 .787 r
.62945 .29147 .63627 .30754 .64949 .30258 .64273 .28766 Metetra
.637 .605 .801 r
.64273 .28766 .64949 .30258 .66276 .29732 .65605 .28338 Metetra
.647 .624 .813 r
.65605 .28338 .66276 .29732 .67607 .2919 .66943 .27876 Metetra
.654 .641 .824 r
.66943 .27876 .67607 .2919 .68944 .28638 .68286 .27391 Metetra
.66 .655 .834 r
.68286 .27391 .68944 .28638 .70286 .28082 .69634 .26888 Metetra
.665 .668 .843 r
.69634 .26888 .70286 .28082 .71634 .27523 .70988 .26373 Metetra
.668 .678 .851 r
.70988 .26373 .71634 .27523 .72988 .26965 .72348 .25851 Metetra
.67 .687 .857 r
.72348 .25851 .72988 .26965 .74347 .26408 .73713 .25322 Metetra
.672 .695 .863 r
.73713 .25322 .74347 .26408 .75713 .25853 .75084 .24791 Metetra
.673 .701 .868 r
.75084 .24791 .75713 .25853 .77084 .25299 .76462 .24256 Metetra
.674 .707 .872 r
.76462 .24256 .77084 .25299 .78462 .24748 .77845 .2372 Metetra
.674 .712 .876 r
.77845 .2372 .78462 .24748 .79846 .24198 .79235 .23183 Metetra
.674 .716 .88 r
.79235 .23183 .79846 .24198 .81237 .2365 .80631 .22645 Metetra
.674 .719 .883 r
.80631 .22645 .81237 .2365 .82634 .23103 .82034 .22107 Metetra
.649 .708 .89 r
.19491 .42561 .20259 .43399 .21383 .43061 .20618 .42207 Metetra
.649 .704 .887 r
.20618 .42207 .21383 .43061 .22512 .42724 .21751 .41851 Metetra
.649 .7 .884 r
.21751 .41851 .22512 .42724 .23646 .42387 .22889 .41492 Metetra
.649 .696 .88 r
.22889 .41492 .23646 .42387 .24786 .42049 .24033 .41129 Metetra
.649 .691 .875 r
.24033 .41129 .24786 .42049 .2593 .4171 .25182 .40763 Metetra
.65 .686 .87 r
.25182 .40763 .2593 .4171 .27081 .4137 .26336 .4039 Metetra
.651 .68 .864 r
.26336 .4039 .27081 .4137 .28237 .41026 .27497 .40009 Metetra
.652 .673 .857 r
.27497 .40009 .28237 .41026 .29398 .40677 .28664 .39617 Metetra
.654 .666 .849 r
.28664 .39617 .29398 .40677 .30566 .4032 .29836 .39211 Metetra
.657 .658 .839 r
.29836 .39211 .30566 .4032 .3174 .39952 .31015 .38786 Metetra
.66 .65 .829 r
.31015 .38786 .3174 .39952 .3292 .39566 .32201 .38336 Metetra
.664 .641 .817 r
.32201 .38336 .3292 .39566 .34107 .39156 .33394 .37854 Metetra
.668 .633 .805 r
.33394 .37854 .34107 .39156 .35301 .38711 .34593 .37332 Metetra
.674 .625 .792 r
.34593 .37332 .35301 .38711 .36502 .38217 .358 .3676 Metetra
.679 .618 .78 r
.358 .3676 .36502 .38217 .37712 .37656 .37013 .36131 Metetra
.684 .613 .77 r
.37013 .36131 .37712 .37656 .38929 .3701 .38233 .35446 Metetra
.688 .611 .764 r
.38233 .35446 .38929 .3701 .40153 .36263 .39458 .34718 Metetra
.69 .614 .766 r
.39458 .34718 .40153 .36263 .41384 .35421 .40686 .33987 Metetra
.686 .625 .782 r
.40686 .33987 .41384 .35421 .42619 .34537 .41916 .33319 Metetra
.677 .653 .818 r
.41916 .33319 .42619 .34537 .43853 .33734 .43145 .32766 Metetra
.667 .698 .869 r
.43145 .32766 .43853 .33734 .45085 .33127 .44377 .32307 Metetra
.664 .734 .902 r
.44377 .32307 .45085 .33127 .46319 .32671 .45613 .31874 Metetra
.664 .741 .908 r
.45613 .31874 .46319 .32671 .47557 .3224 .46855 .31439 Metetra
.664 .741 .908 r
.46855 .31439 .47557 .3224 .48801 .31807 .48103 .31003 Metetra
.664 .741 .908 r
.48103 .31003 .48801 .31807 .50051 .31372 .49356 .30565 Metetra
.664 .741 .908 r
.49356 .30565 .50051 .31372 .51306 .30936 .50615 .30125 Metetra
.664 .741 .908 r
.50615 .30125 .51306 .30936 .52568 .30498 .5188 .29682 Metetra
.663 .741 .908 r
.5188 .29682 .52568 .30498 .53835 .30102 .53151 .29241 Metetra
.651 .725 .903 r
.53151 .29241 .53835 .30102 .5511 .29878 .54428 .28835 Metetra
.618 .669 .877 r
.54428 .28835 .5511 .29878 .56395 .29841 .55713 .28533 Metetra
.586 .603 .836 r
.55713 .28533 .56395 .29841 .5769 .29862 .57006 .28344 Metetra
.574 .565 .807 r
.57006 .28344 .5769 .29862 .58994 .29828 .58309 .28207 Metetra
.576 .554 .793 r
.58309 .28207 .58994 .29828 .60306 .29695 .5962 .28058 Metetra
.586 .558 .79 r
.5962 .28058 .60306 .29695 .61623 .29463 .60938 .27864 Metetra
.598 .57 .794 r
.60938 .27864 .61623 .29463 .62945 .29147 .62263 .27611 Metetra
.611 .586 .801 r
.62263 .27611 .62945 .29147 .64273 .28766 .63595 .27302 Metetra
.623 .602 .809 r
.63595 .27302 .64273 .28766 .65605 .28338 .64932 .26944 Metetra
.633 .618 .818 r
.64932 .26944 .65605 .28338 .66943 .27876 .66275 .26546 Metetra
.641 .633 .826 r
.66275 .26546 .66943 .27876 .68286 .27391 .67623 .26116 Metetra
.648 .646 .835 r
.67623 .26116 .68286 .27391 .69634 .26888 .68976 .25662 Metetra
.654 .658 .842 r
.68976 .25662 .69634 .26888 .70988 .26373 .70336 .25189 Metetra
.658 .669 .849 r
.70336 .25189 .70988 .26373 .72348 .25851 .71701 .24701 Metetra
.661 .678 .855 r
.71701 .24701 .72348 .25851 .73713 .25322 .73072 .24202 Metetra
.664 .686 .861 r
.73072 .24202 .73713 .25322 .75084 .24791 .74449 .23695 Metetra
.666 .693 .865 r
.74449 .23695 .75084 .24791 .76462 .24256 .75832 .23181 Metetra
.668 .699 .87 r
.75832 .23181 .76462 .24256 .77845 .2372 .77221 .22662 Metetra
.669 .704 .874 r
.77221 .22662 .77845 .2372 .79235 .23183 .78617 .22139 Metetra
.67 .709 .877 r
.78617 .22139 .79235 .23183 .80631 .22645 .80019 .21613 Metetra
.67 .713 .88 r
.80019 .21613 .80631 .22645 .82034 .22107 .81427 .21084 Metetra
.653 .706 .886 r
.18718 .41704 .19491 .42561 .20618 .42207 .19849 .41332 Metetra
.653 .702 .882 r
.19849 .41332 .20618 .42207 .21751 .41851 .20986 .40957 Metetra
.654 .698 .879 r
.20986 .40957 .21751 .41851 .22889 .41492 .22128 .40576 Metetra
.655 .694 .875 r
.22128 .40576 .22889 .41492 .24033 .41129 .23275 .40189 Metetra
.656 .69 .87 r
.23275 .40189 .24033 .41129 .25182 .40763 .24429 .39795 Metetra
.657 .685 .865 r
.24429 .39795 .25182 .40763 .26336 .4039 .25588 .39392 Metetra
.659 .68 .859 r
.25588 .39392 .26336 .4039 .27497 .40009 .26753 .38977 Metetra
.661 .674 .852 r
.26753 .38977 .27497 .40009 .28664 .39617 .27924 .38547 Metetra
.664 .668 .844 r
.27924 .38547 .28664 .39617 .29836 .39211 .29102 .38099 Metetra
.667 .662 .836 r
.29102 .38099 .29836 .39211 .31015 .38786 .30286 .37629 Metetra
.67 .656 .828 r
.30286 .37629 .31015 .38786 .32201 .38336 .31476 .37132 Metetra
.674 .651 .819 r
.31476 .37132 .32201 .38336 .33394 .37854 .32673 .36604 Metetra
.679 .646 .81 r
.32673 .36604 .33394 .37854 .34593 .37332 .33877 .36041 Metetra
.683 .642 .802 r
.33877 .36041 .34593 .37332 .358 .3676 .35087 .35441 Metetra
.687 .64 .797 r
.35087 .35441 .358 .3676 .37013 .36131 .36302 .3481 Metetra
.69 .641 .796 r
.36302 .3481 .37013 .36131 .38233 .35446 .37522 .3416 Metetra
.69 .647 .802 r
.37522 .3416 .38233 .35446 .39458 .34718 .38745 .3352 Metetra
.687 .66 .818 r
.38745 .3352 .39458 .34718 .40686 .33987 .3997 .32926 Metetra
.679 .682 .846 r
.3997 .32926 .40686 .33987 .41916 .33319 .41197 .32403 Metetra
.669 .712 .88 r
.41197 .32403 .41916 .33319 .43145 .32766 .42427 .31943 Metetra
.664 .734 .902 r
.42427 .31943 .43145 .32766 .44377 .32307 .43661 .31506 Metetra
.664 .741 .908 r
.43661 .31506 .44377 .32307 .45613 .31874 .44901 .3107 Metetra
.664 .741 .908 r
.44901 .3107 .45613 .31874 .46855 .31439 .46147 .30632 Metetra
.664 .741 .908 r
.46147 .30632 .46855 .31439 .48103 .31003 .47398 .30192 Metetra
.664 .741 .908 r
.47398 .30192 .48103 .31003 .49356 .30565 .48656 .2975 Metetra
.664 .741 .908 r
.48656 .2975 .49356 .30565 .50615 .30125 .49919 .29306 Metetra
.664 .741 .908 r
.49919 .29306 .50615 .30125 .5188 .29682 .51187 .2886 Metetra
.664 .741 .908 r
.51187 .2886 .5188 .29682 .53151 .29241 .52462 .28412 Metetra
.662 .74 .908 r
.52462 .28412 .53151 .29241 .54428 .28835 .53743 .27967 Metetra
.652 .727 .904 r
.53743 .27967 .54428 .28835 .55713 .28533 .5503 .27551 Metetra
.63 .691 .888 r
.5503 .27551 .55713 .28533 .57006 .28344 .56324 .27204 Metetra
.609 .647 .863 r
.56324 .27204 .57006 .28344 .58309 .28207 .57626 .26927 Metetra
.597 .616 .842 r
.57626 .26927 .58309 .28207 .5962 .28058 .58937 .26691 Metetra
.595 .602 .828 r
.58937 .26691 .5962 .28058 .60938 .27864 .60256 .26459 Metetra
.6 .599 .822 r
.60256 .26459 .60938 .27864 .62263 .27611 .61583 .26206 Metetra
.607 .603 .822 r
.61583 .26206 .62263 .27611 .63595 .27302 .62917 .25919 Metetra
.616 .612 .824 r
.62917 .25919 .63595 .27302 .64932 .26944 .64257 .25596 Metetra
.624 .622 .828 r
.64257 .25596 .64932 .26944 .66275 .26546 .65603 .25237 Metetra
.632 .633 .834 r
.65603 .25237 .66275 .26546 .67623 .26116 .66956 .24847 Metetra
.639 .644 .839 r
.66956 .24847 .67623 .26116 .68976 .25662 .68315 .2443 Metetra
.645 .655 .845 r
.68315 .2443 .68976 .25662 .70336 .25189 .69679 .23991 Metetra
.65 .664 .85 r
.69679 .23991 .70336 .25189 .71701 .24701 .71049 .23534 Metetra
.654 .673 .856 r
.71049 .23534 .71701 .24701 .73072 .24202 .72426 .23062 Metetra
.657 .68 .86 r
.72426 .23062 .73072 .24202 .74449 .23695 .73808 .22577 Metetra
.66 .687 .865 r
.73808 .22577 .74449 .23695 .75832 .23181 .75197 .22083 Metetra
.662 .693 .869 r
.75197 .22083 .75832 .23181 .77221 .22662 .76592 .21581 Metetra
.664 .699 .872 r
.76592 .21581 .77221 .22662 .78617 .22139 .77993 .21072 Metetra
.665 .703 .876 r
.77993 .21072 .78617 .22139 .80019 .21613 .794 .20558 Metetra
.666 .708 .878 r
.794 .20558 .80019 .21613 .81427 .21084 .80814 .20039 Metetra
.657 .705 .882 r
.1794 .40832 .18718 .41704 .19849 .41332 .19075 .40443 Metetra
.658 .702 .879 r
.19075 .40443 .19849 .41332 .20986 .40957 .20216 .40049 Metetra
.659 .698 .875 r
.20216 .40049 .20986 .40957 .22128 .40576 .21362 .39647 Metetra
.66 .695 .871 r
.21362 .39647 .22128 .40576 .23275 .40189 .22514 .39238 Metetra
.662 .691 .867 r
.22514 .39238 .23275 .40189 .24429 .39795 .23671 .38819 Metetra
.663 .687 .862 r
.23671 .38819 .24429 .39795 .25588 .39392 .24835 .38389 Metetra
.665 .682 .856 r
.24835 .38389 .25588 .39392 .26753 .38977 .26004 .37945 Metetra
.668 .678 .85 r
.26004 .37945 .26753 .38977 .27924 .38547 .2718 .37485 Metetra
.671 .674 .844 r
.2718 .37485 .27924 .38547 .29102 .38099 .28361 .37006 Metetra
.674 .67 .838 r
.28361 .37006 .29102 .38099 .30286 .37629 .29549 .36506 Metetra
.677 .666 .832 r
.29549 .36506 .30286 .37629 .31476 .37132 .30744 .35982 Metetra
.681 .663 .826 r
.30744 .35982 .31476 .37132 .32673 .36604 .31944 .35433 Metetra
.684 .662 .822 r
.31944 .35433 .32673 .36604 .33877 .36041 .3315 .34862 Metetra
.687 .662 .82 r
.3315 .34862 .33877 .36041 .35087 .35441 .34361 .34272 Metetra
.689 .665 .822 r
.34361 .34272 .35087 .35441 .36302 .3481 .35577 .33677 Metetra
.688 .672 .829 r
.35577 .33677 .36302 .3481 .37522 .3416 .36796 .33093 Metetra
.685 .683 .843 r
.36796 .33093 .37522 .3416 .38745 .3352 .38018 .32542 Metetra
.678 .7 .864 r
.38018 .32542 .38745 .3352 .3997 .32926 .39242 .32039 Metetra
.67 .719 .886 r
.39242 .32039 .3997 .32926 .41197 .32403 .4047 .31578 Metetra
.665 .735 .902 r
.4047 .31578 .41197 .32403 .42427 .31943 .41702 .31138 Metetra
.664 .741 .907 r
.41702 .31138 .42427 .31943 .43661 .31506 .4294 .307 Metetra
.664 .741 .908 r
.4294 .307 .43661 .31506 .44901 .3107 .44184 .3026 Metetra
.664 .741 .908 r
.44184 .3026 .44901 .3107 .46147 .30632 .45433 .29819 Metetra
.664 .741 .908 r
.45433 .29819 .46147 .30632 .47398 .30192 .46688 .29375 Metetra
.664 .741 .908 r
.46688 .29375 .47398 .30192 .48656 .2975 .47949 .28929 Metetra
.664 .741 .908 r
.47949 .28929 .48656 .2975 .49919 .29306 .49216 .28481 Metetra
.664 .741 .908 r
.49216 .28481 .49919 .29306 .51187 .2886 .50488 .28031 Metetra
.664 .741 .908 r
.50488 .28031 .51187 .2886 .52462 .28412 .51767 .27579 Metetra
.663 .741 .908 r
.51767 .27579 .52462 .28412 .53743 .27967 .53051 .27125 Metetra
.661 .739 .908 r
.53051 .27125 .53743 .27967 .5503 .27551 .54342 .26676 Metetra
.653 .728 .904 r
.54342 .26676 .5503 .27551 .56324 .27204 .55639 .26251 Metetra
.638 .704 .894 r
.55639 .26251 .56324 .27204 .57626 .26927 .56943 .25872 Metetra
.623 .675 .878 r
.56943 .25872 .57626 .26927 .58937 .26691 .58255 .25541 Metetra
.613 .651 .863 r
.58255 .25541 .58937 .26691 .60256 .26459 .59575 .25239 Metetra
.61 .637 .852 r
.59575 .25239 .60256 .26459 .61583 .26206 .60903 .24946 Metetra
.612 .631 .846 r
.60903 .24946 .61583 .26206 .62917 .25919 .62238 .24644 Metetra
.616 .631 .843 r
.62238 .24644 .62917 .25919 .64257 .25596 .63581 .24323 Metetra
.622 .635 .843 r
.63581 .24323 .64257 .25596 .65603 .25237 .64931 .23978 Metetra
.628 .641 .845 r
.64931 .23978 .65603 .25237 .66956 .24847 .66287 .23609 Metetra
.633 .649 .847 r
.66287 .23609 .66956 .24847 .68315 .2443 .6765 .23215 Metetra
.639 .656 .851 r
.6765 .23215 .68315 .2443 .69679 .23991 .69018 .22799 Metetra
.644 .664 .855 r
.69018 .22799 .69679 .23991 .71049 .23534 .70394 .22365 Metetra
.648 .671 .858 r
.70394 .22365 .71049 .23534 .72426 .23062 .71775 .21913 Metetra
.651 .678 .862 r
.71775 .21913 .72426 .23062 .73808 .22577 .73162 .21448 Metetra
.654 .684 .866 r
.73162 .21448 .73808 .22577 .75197 .22083 .74556 .20971 Metetra
.657 .69 .869 r
.74556 .20971 .75197 .22083 .76592 .21581 .75956 .20484 Metetra
.659 .695 .872 r
.75956 .20484 .76592 .21581 .77993 .21072 .77363 .19989 Metetra
.661 .7 .875 r
.77363 .19989 .77993 .21072 .794 .20558 .78776 .19485 Metetra
.662 .704 .878 r
.78776 .19485 .794 .20558 .80814 .20039 .80195 .18976 Metetra
.661 .705 .88 r
.17157 .39951 .1794 .40832 .19075 .40443 .18296 .39545 Metetra
.662 .702 .877 r
.18296 .39545 .19075 .40443 .20216 .40049 .1944 .39133 Metetra
.663 .699 .873 r
.1944 .39133 .20216 .40049 .21362 .39647 .2059 .38713 Metetra
.665 .696 .869 r
.2059 .38713 .21362 .39647 .22514 .39238 .21746 .38284 Metetra
.666 .693 .865 r
.21746 .38284 .22514 .39238 .23671 .38819 .22908 .37844 Metetra
.668 .69 .861 r
.22908 .37844 .23671 .38819 .24835 .38389 .24075 .37391 Metetra
.671 .687 .857 r
.24075 .37391 .24835 .38389 .26004 .37945 .25248 .36926 Metetra
.673 .684 .852 r
.25248 .36926 .26004 .37945 .2718 .37485 .26428 .36444 Metetra
.676 .681 .848 r
.26428 .36444 .2718 .37485 .28361 .37006 .27613 .35946 Metetra
.679 .679 .843 r
.27613 .35946 .28361 .37006 .29549 .36506 .28804 .3543 Metetra
.681 .678 .84 r
.28804 .3543 .29549 .36506 .30744 .35982 .30001 .34897 Metetra
.684 .678 .838 r
.30001 .34897 .30744 .35982 .31944 .35433 .31204 .3435 Metetra
.686 .679 .838 r
.31204 .3435 .31944 .35433 .3315 .34862 .32411 .33792 Metetra
.687 .683 .841 r
.32411 .33792 .3315 .34862 .34361 .34272 .33623 .33234 Metetra
.686 .689 .848 r
.33623 .33234 .34361 .34272 .35577 .33677 .34839 .32686 Metetra
.682 .699 .859 r
.34839 .32686 .35577 .33677 .36796 .33093 .36057 .32163 Metetra
.676 .711 .875 r
.36057 .32163 .36796 .33093 .38018 .32542 .37279 .31672 Metetra
.67 .725 .891 r
.37279 .31672 .38018 .32542 .39242 .32039 .38505 .31211 Metetra
.665 .735 .902 r
.38505 .31211 .39242 .32039 .4047 .31578 .39735 .30768 Metetra
.664 .74 .907 r
.39735 .30768 .4047 .31578 .41702 .31138 .40971 .30328 Metetra
.664 .741 .908 r
.40971 .30328 .41702 .31138 .4294 .307 .42213 .29887 Metetra
.664 .741 .908 r
.42213 .29887 .4294 .307 .44184 .3026 .4346 .29443 Metetra
.664 .741 .908 r
.4346 .29443 .44184 .3026 .45433 .29819 .44713 .28998 Metetra
.664 .741 .908 r
.44713 .28998 .45433 .29819 .46688 .29375 .45972 .2855 Metetra
.664 .741 .908 r
.45972 .2855 .46688 .29375 .47949 .28929 .47236 .28101 Metetra
.664 .741 .908 r
.47236 .28101 .47949 .28929 .49216 .28481 .48507 .27649 Metetra
.664 .741 .908 r
.48507 .27649 .49216 .28481 .50488 .28031 .49783 .27195 Metetra
.664 .741 .908 r
.49783 .27195 .50488 .28031 .51767 .27579 .51066 .26739 Metetra
.664 .741 .908 r
.51066 .26739 .51767 .27579 .53051 .27125 .52354 .26281 Metetra
.663 .741 .908 r
.52354 .26281 .53051 .27125 .54342 .26676 .53649 .25822 Metetra
.661 .739 .908 r
.53649 .25822 .54342 .26676 .55639 .26251 .54949 .25368 Metetra
.654 .73 .905 r
.54949 .25368 .55639 .26251 .56943 .25872 .56257 .24933 Metetra
.643 .712 .898 r
.56257 .24933 .56943 .25872 .58255 .25541 .57571 .24531 Metetra
.633 .692 .887 r
.57571 .24531 .58255 .25541 .59575 .25239 .58893 .24161 Metetra
.625 .674 .877 r
.58893 .24161 .59575 .25239 .60903 .24946 .60222 .23814 Metetra
.622 .662 .868 r
.60222 .23814 .60903 .24946 .62238 .24644 .6156 .23476 Metetra
.621 .655 .862 r
.6156 .23476 .62238 .24644 .63581 .24323 .62904 .23135 Metetra
.624 .653 .859 r
.62904 .23135 .63581 .24323 .64931 .23978 .64257 .22783 Metetra
.627 .654 .857 r
.64257 .22783 .64931 .23978 .66287 .23609 .65616 .22415 Metetra
.631 .658 .858 r
.65616 .22415 .66287 .23609 .6765 .23215 .66982 .2203 Metetra
.636 .662 .859 r
.66982 .2203 .6765 .23215 .69018 .22799 .68355 .21626 Metetra
.64 .668 .861 r
.68355 .21626 .69018 .22799 .70394 .22365 .69734 .21206 Metetra
.644 .673 .863 r
.69734 .21206 .70394 .22365 .71775 .21913 .7112 .20769 Metetra
.647 .678 .866 r
.7112 .20769 .71775 .21913 .73162 .21448 .72512 .20318 Metetra
.65 .684 .868 r
.72512 .20318 .73162 .21448 .74556 .20971 .73911 .19854 Metetra
.653 .689 .871 r
.73911 .19854 .74556 .20971 .75956 .20484 .75316 .19379 Metetra
.655 .693 .874 r
.75316 .19379 .75956 .20484 .77363 .19989 .76728 .18895 Metetra
.657 .698 .876 r
.76728 .18895 .77363 .19989 .78776 .19485 .78146 .18401 Metetra
.659 .702 .878 r
.78146 .18401 .78776 .19485 .80195 .18976 .79571 .179 Metetra
.664 .706 .878 r
.16368 .39063 .17157 .39951 .18296 .39545 .17511 .38642 Metetra
.665 .704 .876 r
.17511 .38642 .18296 .39545 .1944 .39133 .18659 .38215 Metetra
.667 .701 .872 r
.18659 .38215 .1944 .39133 .2059 .38713 .19813 .37779 Metetra
.668 .699 .869 r
.19813 .37779 .2059 .38713 .21746 .38284 .20972 .37333 Metetra
.67 .697 .866 r
.20972 .37333 .21746 .38284 .22908 .37844 .22137 .36877 Metetra
.672 .694 .862 r
.22137 .36877 .22908 .37844 .24075 .37391 .23308 .36409 Metetra
.674 .692 .859 r
.23308 .36409 .24075 .37391 .25248 .36926 .24485 .35928 Metetra
.677 .691 .856 r
.24485 .35928 .25248 .36926 .26428 .36444 .25668 .35434 Metetra
.679 .69 .853 r
.25668 .35434 .26428 .36444 .27613 .35946 .26856 .34928 Metetra
.681 .69 .851 r
.26856 .34928 .27613 .35946 .28804 .3543 .2805 .34409 Metetra
.683 .69 .851 r
.2805 .34409 .28804 .3543 .30001 .34897 .29249 .3388 Metetra
.684 .692 .852 r
.29249 .3388 .30001 .34897 .31204 .3435 .30453 .33346 Metetra
.684 .696 .855 r
.30453 .33346 .31204 .3435 .32411 .33792 .31661 .32814 Metetra
.683 .702 .861 r
.31661 .32814 .32411 .33792 .33623 .33234 .32873 .32291 Metetra
.68 .709 .871 r
.32873 .32291 .33623 .33234 .34839 .32686 .34089 .31786 Metetra
.675 .719 .882 r
.34089 .31786 .34839 .32686 .36057 .32163 .35309 .31303 Metetra
.669 .728 .894 r
.35309 .31303 .36057 .32163 .37279 .31672 .36533 .30843 Metetra
.665 .736 .902 r
.36533 .30843 .37279 .31672 .38505 .31211 .37761 .30397 Metetra
.664 .74 .907 r
.37761 .30397 .38505 .31211 .39735 .30768 .38995 .29955 Metetra
.664 .741 .908 r
.38995 .29955 .39735 .30768 .40971 .30328 .40234 .29512 Metetra
.664 .741 .908 r
.40234 .29512 .40971 .30328 .42213 .29887 .41479 .29066 Metetra
.664 .741 .908 r
.41479 .29066 .42213 .29887 .4346 .29443 .4273 .28619 Metetra
.664 .741 .908 r
.4273 .28619 .4346 .29443 .44713 .28998 .43986 .2817 Metetra
.664 .741 .908 r
.43986 .2817 .44713 .28998 .45972 .2855 .45249 .27718 Metetra
.664 .741 .908 r
.45249 .27718 .45972 .2855 .47236 .28101 .46517 .27265 Metetra
.664 .741 .908 r
.46517 .27265 .47236 .28101 .48507 .27649 .47792 .26809 Metetra
.664 .741 .908 r
.47792 .26809 .48507 .27649 .49783 .27195 .49072 .26352 Metetra
.664 .741 .908 r
.49072 .26352 .49783 .27195 .51066 .26739 .50358 .25892 Metetra
.664 .741 .908 r
.50358 .25892 .51066 .26739 .52354 .26281 .51651 .2543 Metetra
.664 .741 .908 r
.51651 .2543 .52354 .26281 .53649 .25822 .52949 .24965 Metetra
.663 .741 .908 r
.52949 .24965 .53649 .25822 .54949 .25368 .54254 .24501 Metetra
.661 .738 .907 r
.54254 .24501 .54949 .25368 .56257 .24933 .55565 .24041 Metetra
.655 .731 .905 r
.55565 .24041 .56257 .24933 .57571 .24531 .56883 .23598 Metetra
.647 .718 .9 r
.56883 .23598 .57571 .24531 .58893 .24161 .58207 .23177 Metetra
.639 .703 .893 r
.58207 .23177 .58893 .24161 .60222 .23814 .59539 .22779 Metetra
.633 .69 .885 r
.59539 .22779 .60222 .23814 .6156 .23476 .60879 .22398 Metetra
.63 .68 .879 r
.60879 .22398 .6156 .23476 .62904 .23135 .62226 .22026 Metetra
.629 .674 .874 r
.62226 .22026 .62904 .23135 .64257 .22783 .63581 .21653 Metetra
.63 .671 .87 r
.63581 .21653 .64257 .22783 .65616 .22415 .64943 .21274 Metetra
.632 .67 .868 r
.64943 .21274 .65616 .22415 .66982 .2203 .66312 .20884 Metetra
.635 .672 .868 r
.66312 .20884 .66982 .2203 .68355 .21626 .67688 .20482 Metetra
.638 .674 .868 r
.67688 .20482 .68355 .21626 .69734 .21206 .69071 .20066 Metetra
.641 .678 .869 r
.69071 .20066 .69734 .21206 .7112 .20769 .70461 .19637 Metetra
.644 .681 .87 r
.70461 .19637 .7112 .20769 .72512 .20318 .71858 .19194 Metetra
.647 .685 .872 r
.71858 .19194 .72512 .20318 .73911 .19854 .73261 .18739 Metetra
.65 .69 .874 r
.73261 .18739 .73911 .19854 .75316 .19379 .74671 .18272 Metetra
.652 .693 .876 r
.74671 .18272 .75316 .19379 .76728 .18895 .76088 .17796 Metetra
.654 .697 .878 r
.76088 .17796 .76728 .18895 .78146 .18401 .77511 .1731 Metetra
.656 .701 .879 r
.77511 .1731 .78146 .18401 .79571 .179 .78941 .16816 Metetra
.667 .708 .878 r
.15574 .38172 .16368 .39063 .17511 .38642 .1672 .37739 Metetra
.668 .706 .876 r
.1672 .37739 .17511 .38642 .18659 .38215 .17871 .37299 Metetra
.67 .704 .873 r
.17871 .37299 .18659 .38215 .19813 .37779 .19028 .3685 Metetra
.671 .702 .87 r
.19028 .3685 .19813 .37779 .20972 .37333 .20191 .36391 Metetra
.673 .701 .868 r
.20191 .36391 .20972 .37333 .22137 .36877 .2136 .35924 Metetra
.675 .7 .865 r
.2136 .35924 .22137 .36877 .23308 .36409 .22534 .35445 Metetra
.677 .699 .863 r
.22534 .35445 .23308 .36409 .24485 .35928 .23714 .34957 Metetra
.678 .699 .862 r
.23714 .34957 .24485 .35928 .25668 .35434 .24899 .34459 Metetra
.68 .699 .861 r
.24899 .34459 .25668 .35434 .26856 .34928 .2609 .33952 Metetra
.681 .7 .861 r
.2609 .33952 .26856 .34928 .2805 .34409 .27285 .33439 Metetra
.682 .702 .863 r
.27285 .33439 .2805 .34409 .29249 .3388 .28486 .32922 Metetra
.681 .706 .866 r
.28486 .32922 .29249 .3388 .30453 .33346 .29691 .32408 Metetra
.68 .711 .871 r
.29691 .32408 .30453 .33346 .31661 .32814 .309 .31902 Metetra
.677 .717 .879 r
.309 .31902 .31661 .32814 .32873 .32291 .32114 .31409 Metetra
.673 .724 .887 r
.32114 .31409 .32873 .32291 .34089 .31786 .33331 .30933 Metetra
.669 .731 .896 r
.33331 .30933 .34089 .31786 .35309 .31303 .34552 .30473 Metetra
.666 .736 .903 r
.34552 .30473 .35309 .31303 .36533 .30843 .35779 .30025 Metetra
.664 .74 .906 r
.35779 .30025 .36533 .30843 .37761 .30397 .3701 .2958 Metetra
.664 .741 .908 r
.3701 .2958 .37761 .30397 .38995 .29955 .38247 .29135 Metetra
.664 .741 .908 r
.38247 .29135 .38995 .29955 .40234 .29512 .3949 .28688 Metetra
.664 .741 .908 r
.3949 .28688 .40234 .29512 .41479 .29066 .40739 .28239 Metetra
.664 .741 .908 r
.40739 .28239 .41479 .29066 .4273 .28619 .41993 .27788 Metetra
.664 .741 .908 r
.41993 .27788 .4273 .28619 .43986 .2817 .43254 .27335 Metetra
.664 .741 .908 r
.43254 .27335 .43986 .2817 .45249 .27718 .4452 .2688 Metetra
.664 .741 .908 r
.4452 .2688 .45249 .27718 .46517 .27265 .45792 .26422 Metetra
.664 .741 .908 r
.45792 .26422 .46517 .27265 .47792 .26809 .4707 .25963 Metetra
.664 .741 .908 r
.4707 .25963 .47792 .26809 .49072 .26352 .48355 .25501 Metetra
.664 .741 .908 r
.48355 .25501 .49072 .26352 .50358 .25892 .49645 .25037 Metetra
.664 .741 .908 r
.49645 .25037 .50358 .25892 .51651 .2543 .50941 .24571 Metetra
.664 .741 .908 r
.50941 .24571 .51651 .2543 .52949 .24965 .52244 .24102 Metetra
.663 .741 .908 r
.52244 .24102 .52949 .24965 .54254 .24501 .53553 .23632 Metetra
.663 .741 .908 r
.53553 .23632 .54254 .24501 .55565 .24041 .54868 .23162 Metetra
.66 .738 .907 r
.54868 .23162 .55565 .24041 .56883 .23598 .56189 .22697 Metetra
.656 .732 .905 r
.56189 .22697 .56883 .23598 .58207 .23177 .57517 .22244 Metetra
.65 .722 .901 r
.57517 .22244 .58207 .23177 .59539 .22779 .58852 .21808 Metetra
.644 .711 .896 r
.58852 .21808 .59539 .22779 .60879 .22398 .60194 .21388 Metetra
.639 .701 .891 r
.60194 .21388 .60879 .22398 .62226 .22026 .61544 .20981 Metetra
.636 .693 .886 r
.61544 .20981 .62226 .22026 .63581 .21653 .62902 .20581 Metetra
.635 .687 .882 r
.62902 .20581 .63581 .21653 .64943 .21274 .64267 .20182 Metetra
.635 .684 .879 r
.64267 .20182 .64943 .21274 .66312 .20884 .65639 .1978 Metetra
.637 .683 .877 r
.65639 .1978 .66312 .20884 .67688 .20482 .67019 .1937 Metetra
.639 .683 .876 r
.67019 .1937 .67688 .20482 .69071 .20066 .68405 .18951 Metetra
.641 .684 .875 r
.68405 .18951 .69071 .20066 .70461 .19637 .69799 .18522 Metetra
.643 .686 .876 r
.69799 .18522 .70461 .19637 .71858 .19194 .712 .18081 Metetra
.645 .689 .876 r
.712 .18081 .71858 .19194 .73261 .18739 .72607 .1763 Metetra
.648 .692 .877 r
.72607 .1763 .73261 .18739 .74671 .18272 .74022 .17168 Metetra
.65 .695 .879 r
.74022 .17168 .74671 .18272 .76088 .17796 .75443 .16697 Metetra
.652 .698 .88 r
.75443 .16697 .76088 .17796 .77511 .1731 .76872 .16216 Metetra
.654 .701 .881 r
.76872 .16216 .77511 .1731 .78941 .16816 .78307 .15727 Metetra
.669 .71 .878 r
.14772 .37282 .15574 .38172 .1672 .37739 .15921 .36839 Metetra
.67 .709 .876 r
.15921 .36839 .1672 .37739 .17871 .37299 .17076 .36388 Metetra
.672 .707 .875 r
.17076 .36388 .17871 .37299 .19028 .3685 .18237 .3593 Metetra
.673 .707 .873 r
.18237 .3593 .19028 .3685 .20191 .36391 .19402 .35463 Metetra
.675 .706 .871 r
.19402 .35463 .20191 .36391 .2136 .35924 .20574 .34988 Metetra
.676 .705 .87 r
.20574 .34988 .2136 .35924 .22534 .35445 .21751 .34504 Metetra
.677 .706 .869 r
.21751 .34504 .22534 .35445 .23714 .34957 .22933 .34014 Metetra
.679 .706 .868 r
.22933 .34014 .23714 .34957 .24899 .34459 .24121 .33517 Metetra
.679 .708 .869 r
.24121 .33517 .24899 .34459 .2609 .33952 .25314 .33015 Metetra
.68 .71 .871 r
.25314 .33015 .2609 .33952 .27285 .33439 .26511 .32512 Metetra
.679 .713 .874 r
.26511 .32512 .27285 .33439 .28486 .32922 .27713 .32012 Metetra
.678 .717 .878 r
.27713 .32012 .28486 .32922 .29691 .32408 .2892 .31518 Metetra
.675 .722 .884 r
.2892 .31518 .29691 .32408 .309 .31902 .3013 .31033 Metetra
.672 .727 .891 r
.3013 .31033 .309 .31902 .32114 .31409 .31345 .30562 Metetra
.669 .732 .898 r
.31345 .30562 .32114 .31409 .33331 .30933 .32565 .30102 Metetra
.666 .737 .903 r
.32565 .30102 .33331 .30933 .34552 .30473 .33789 .29651 Metetra
.664 .74 .906 r
.33789 .29651 .34552 .30473 .35779 .30025 .35018 .29204 Metetra
.664 .741 .908 r
.35018 .29204 .35779 .30025 .3701 .2958 .36253 .28757 Metetra
.664 .741 .908 r
.36253 .28757 .3701 .2958 .38247 .29135 .37494 .28308 Metetra
.664 .741 .908 r
.37494 .28308 .38247 .29135 .3949 .28688 .3874 .27858 Metetra
.664 .741 .908 r
.3874 .27858 .3949 .28688 .40739 .28239 .39993 .27405 Metetra
.664 .741 .908 r
.39993 .27405 .40739 .28239 .41993 .27788 .41251 .2695 Metetra
.664 .741 .908 r
.41251 .2695 .41993 .27788 .43254 .27335 .42515 .26493 Metetra
.664 .741 .908 r
.42515 .26493 .43254 .27335 .4452 .2688 .43785 .26033 Metetra
.664 .741 .908 r
.43785 .26033 .4452 .2688 .45792 .26422 .45061 .25572 Metetra
.664 .741 .908 r
.45061 .25572 .45792 .26422 .4707 .25963 .46343 .25108 Metetra
.664 .741 .908 r
.46343 .25108 .4707 .25963 .48355 .25501 .47631 .24643 Metetra
.664 .741 .908 r
.47631 .24643 .48355 .25501 .49645 .25037 .48925 .24175 Metetra
.664 .741 .908 r
.48925 .24175 .49645 .25037 .50941 .24571 .50225 .23704 Metetra
.664 .741 .908 r
.50225 .23704 .50941 .24571 .52244 .24102 .51532 .23232 Metetra
.664 .741 .908 r
.51532 .23232 .52244 .24102 .53553 .23632 .52845 .22757 Metetra
.663 .741 .908 r
.52845 .22757 .53553 .23632 .54868 .23162 .54164 .22281 Metetra
.663 .74 .908 r
.54164 .22281 .54868 .23162 .56189 .22697 .55489 .21804 Metetra
.66 .738 .907 r
.55489 .21804 .56189 .22697 .57517 .22244 .56821 .21333 Metetra
.657 .733 .906 r
.56821 .21333 .57517 .22244 .58852 .21808 .5816 .20871 Metetra
.652 .725 .903 r
.5816 .20871 .58852 .21808 .60194 .21388 .59506 .20422 Metetra
.648 .717 .899 r
.59506 .20422 .60194 .21388 .61544 .20981 .60859 .19984 Metetra
.644 .709 .895 r
.60859 .19984 .61544 .20981 .62902 .20581 .62219 .19556 Metetra
.641 .703 .891 r
.62219 .19556 .62902 .20581 .64267 .20182 .63587 .19134 Metetra
.64 .698 .888 r
.63587 .19134 .64267 .20182 .65639 .1978 .64963 .18713 Metetra
.64 .695 .885 r
.64963 .18713 .65639 .1978 .67019 .1937 .66346 .1829 Metetra
.64 .693 .883 r
.66346 .1829 .67019 .1937 .68405 .18951 .67736 .17862 Metetra
.642 .692 .882 r
.67736 .17862 .68405 .18951 .69799 .18522 .69133 .17427 Metetra
.643 .693 .881 r
.69133 .17427 .69799 .18522 .712 .18081 .70538 .16984 Metetra
.645 .694 .881 r
.70538 .16984 .712 .18081 .72607 .1763 .7195 .16532 Metetra
.647 .696 .881 r
.7195 .16532 .72607 .1763 .74022 .17168 .73369 .16071 Metetra
.649 .698 .882 r
.73369 .16071 .74022 .17168 .75443 .16697 .74795 .15601 Metetra
.65 .7 .883 r
.74795 .15601 .75443 .16697 .76872 .16216 .76228 .15122 Metetra
.652 .702 .884 r
.76228 .15122 .76872 .16216 .78307 .15727 .77668 .14636 Metetra
.671 .713 .88 r
.13963 .36395 .14772 .37282 .15921 .36839 .15116 .35944 Metetra
.672 .712 .878 r
.15116 .35944 .15921 .36839 .17076 .36388 .16274 .35486 Metetra
.673 .711 .877 r
.16274 .35486 .17076 .36388 .18237 .3593 .17437 .3502 Metetra
.674 .711 .876 r
.17437 .3502 .18237 .3593 .19402 .35463 .18606 .34548 Metetra
.675 .711 .875 r
.18606 .34548 .19402 .35463 .20574 .34988 .1978 .3407 Metetra
.676 .711 .874 r
.1978 .3407 .20574 .34988 .21751 .34504 .2096 .33585 Metetra
.677 .712 .875 r
.2096 .33585 .21751 .34504 .22933 .34014 .22144 .33096 Metetra
.678 .714 .876 r
.22144 .33096 .22933 .34014 .24121 .33517 .23334 .32604 Metetra
.678 .716 .877 r
.23334 .32604 .24121 .33517 .25314 .33015 .24528 .32112 Metetra
.677 .718 .88 r
.24528 .32112 .25314 .33015 .26511 .32512 .25728 .31621 Metetra
.676 .722 .884 r
.25728 .31621 .26511 .32512 .27713 .32012 .26931 .31135 Metetra
.674 .726 .889 r
.26931 .31135 .27713 .32012 .2892 .31518 .28139 .30657 Metetra
.671 .73 .894 r
.28139 .30657 .2892 .31518 .3013 .31033 .29352 .30188 Metetra
.668 .734 .899 r
.29352 .30188 .3013 .31033 .31345 .30562 .30569 .29729 Metetra
.666 .737 .903 r
.30569 .29729 .31345 .30562 .32565 .30102 .31791 .29276 Metetra
.664 .74 .906 r
.31791 .29276 .32565 .30102 .33789 .29651 .33018 .28827 Metetra
.664 .741 .907 r
.33018 .28827 .33789 .29651 .35018 .29204 .34251 .28378 Metetra
.664 .741 .908 r
.34251 .28378 .35018 .29204 .36253 .28757 .35489 .27927 Metetra
.664 .741 .908 r
.35489 .27927 .36253 .28757 .37494 .28308 .36734 .27475 Metetra
.664 .741 .908 r
.36734 .27475 .37494 .28308 .3874 .27858 .37984 .2702 Metetra
.664 .741 .908 r
.37984 .2702 .3874 .27858 .39993 .27405 .3924 .26563 Metetra
.664 .741 .908 r
.3924 .26563 .39993 .27405 .41251 .2695 .40502 .26104 Metetra
.664 .741 .908 r
.40502 .26104 .41251 .2695 .42515 .26493 .41769 .25643 Metetra
.664 .741 .908 r
.41769 .25643 .42515 .26493 .43785 .26033 .43043 .2518 Metetra
.664 .741 .908 r
.43043 .2518 .43785 .26033 .45061 .25572 .44323 .24714 Metetra
.664 .741 .908 r
.44323 .24714 .45061 .25572 .46343 .25108 .45609 .24247 Metetra
.664 .741 .908 r
.45609 .24247 .46343 .25108 .47631 .24643 .46901 .23777 Metetra
.664 .741 .908 r
.46901 .23777 .47631 .24643 .48925 .24175 .48199 .23305 Metetra
.664 .741 .908 r
.48199 .23305 .48925 .24175 .50225 .23704 .49503 .2283 Metetra
.664 .741 .908 r
.49503 .2283 .50225 .23704 .51532 .23232 .50814 .22354 Metetra
.664 .741 .908 r
.50814 .22354 .51532 .23232 .52845 .22757 .52131 .21875 Metetra
.664 .741 .908 r
.52131 .21875 .52845 .22757 .54164 .22281 .53454 .21393 Metetra
.663 .741 .908 r
.53454 .21393 .54164 .22281 .55489 .21804 .54784 .20911 Metetra
.662 .74 .908 r
.54784 .20911 .55489 .21804 .56821 .21333 .5612 .20429 Metetra
.66 .738 .907 r
.5612 .20429 .56821 .21333 .5816 .20871 .57463 .1995 Metetra
.657 .734 .906 r
.57463 .1995 .5816 .20871 .59506 .20422 .58812 .1948 Metetra
.654 .728 .904 r
.58812 .1948 .59506 .20422 .60859 .19984 .60169 .19018 Metetra
.65 .721 .901 r
.60169 .19018 .60859 .19984 .62219 .19556 .61533 .18565 Metetra
.647 .715 .898 r
.61533 .18565 .62219 .19556 .63587 .19134 .62904 .1812 Metetra
.645 .71 .894 r
.62904 .1812 .63587 .19134 .64963 .18713 .64283 .17679 Metetra
.644 .706 .892 r
.64283 .17679 .64963 .18713 .66346 .1829 .65669 .17239 Metetra
.643 .703 .89 r
.65669 .17239 .66346 .1829 .67736 .17862 .67063 .16798 Metetra
.644 .701 .888 r
.67063 .16798 .67736 .17862 .69133 .17427 .68464 .16353 Metetra
.644 .7 .887 r
.68464 .16353 .69133 .17427 .70538 .16984 .69873 .15903 Metetra
.645 .7 .886 r
.69873 .15903 .70538 .16984 .7195 .16532 .71288 .15446 Metetra
.647 .701 .886 r
.71288 .15446 .7195 .16532 .73369 .16071 .72712 .14982 Metetra
.648 .702 .886 r
.72712 .14982 .73369 .16071 .74795 .15601 .74142 .14511 Metetra
.65 .703 .886 r
.74142 .14511 .74795 .15601 .76228 .15122 .7558 .14032 Metetra
.651 .705 .886 r
.7558 .14032 .76228 .15122 .77668 .14636 .77024 .13545 Metetra
.672 .716 .882 r
.13147 .35513 .13963 .36395 .15116 .35944 .14303 .35056 Metetra
.673 .715 .881 r
.14303 .35056 .15116 .35944 .16274 .35486 .15463 .34592 Metetra
.674 .715 .88 r
.15463 .34592 .16274 .35486 .17437 .3502 .16629 .34123 Metetra
.675 .715 .879 r
.16629 .34123 .17437 .3502 .18606 .34548 .17801 .33649 Metetra
.675 .716 .879 r
.17801 .33649 .18606 .34548 .1978 .3407 .18977 .3317 Metetra
.676 .717 .88 r
.18977 .3317 .1978 .3407 .2096 .33585 .20159 .32687 Metetra
.676 .718 .881 r
.20159 .32687 .2096 .33585 .22144 .33096 .21346 .32202 Metetra
.676 .72 .882 r
.21346 .32202 .22144 .33096 .23334 .32604 .22538 .31717 Metetra
.675 .722 .885 r
.22538 .31717 .23334 .32604 .24528 .32112 .23734 .31234 Metetra
.674 .725 .888 r
.23734 .31234 .24528 .32112 .25728 .31621 .24935 .30754 Metetra
.672 .728 .892 r
.24935 .30754 .25728 .31621 .26931 .31135 .26141 .3028 Metetra
.67 .732 .896 r
.26141 .3028 .26931 .31135 .28139 .30657 .27351 .29814 Metetra
.668 .735 .9 r
.27351 .29814 .28139 .30657 .29352 .30188 .28566 .29354 Metetra
.666 .738 .904 r
.28566 .29354 .29352 .30188 .30569 .29729 .29785 .28899 Metetra
.665 .74 .906 r
.29785 .28899 .30569 .29729 .31791 .29276 .3101 .28448 Metetra
.664 .741 .907 r
.3101 .28448 .31791 .29276 .33018 .28827 .32241 .27997 Metetra
.664 .741 .908 r
.32241 .27997 .33018 .28827 .34251 .28378 .33477 .27544 Metetra
.664 .741 .908 r
.33477 .27544 .34251 .28378 .35489 .27927 .34719 .2709 Metetra
.664 .741 .908 r
.34719 .2709 .35489 .27927 .36734 .27475 .35967 .26634 Metetra
.664 .741 .908 r
.35967 .26634 .36734 .27475 .37984 .2702 .37221 .26175 Metetra
.664 .741 .908 r
.37221 .26175 .37984 .2702 .3924 .26563 .3848 .25714 Metetra
.664 .741 .908 r
.3848 .25714 .3924 .26563 .40502 .26104 .39746 .25251 Metetra
.664 .741 .908 r
.39746 .25251 .40502 .26104 .41769 .25643 .41017 .24786 Metetra
.664 .741 .908 r
.41017 .24786 .41769 .25643 .43043 .2518 .42295 .24319 Metetra
.664 .741 .908 r
.42295 .24319 .43043 .2518 .44323 .24714 .43579 .23849 Metetra
.664 .741 .908 r
.43579 .23849 .44323 .24714 .45609 .24247 .44868 .23377 Metetra
.664 .741 .908 r
.44868 .23377 .45609 .24247 .46901 .23777 .46164 .22903 Metetra
.664 .741 .908 r
.46164 .22903 .46901 .23777 .48199 .23305 .47467 .22427 Metetra
.664 .741 .908 r
.47467 .22427 .48199 .23305 .49503 .2283 .48775 .21948 Metetra
.664 .741 .908 r
.48775 .21948 .49503 .2283 .50814 .22354 .5009 .21468 Metetra
.664 .741 .908 r
.5009 .21468 .50814 .22354 .52131 .21875 .51411 .20984 Metetra
.664 .741 .908 r
.51411 .20984 .52131 .21875 .53454 .21393 .52738 .20499 Metetra
.663 .741 .908 r
.52738 .20499 .53454 .21393 .54784 .20911 .54072 .20011 Metetra
.663 .741 .908 r
.54072 .20011 .54784 .20911 .5612 .20429 .55412 .19522 Metetra
.662 .74 .908 r
.55412 .19522 .5612 .20429 .57463 .1995 .56759 .19034 Metetra
.661 .738 .907 r
.56759 .19034 .57463 .1995 .58812 .1948 .58113 .18548 Metetra
.658 .734 .906 r
.58113 .18548 .58812 .1948 .60169 .19018 .59473 .18069 Metetra
.655 .73 .904 r
.59473 .18069 .60169 .19018 .61533 .18565 .60841 .17596 Metetra
.652 .725 .902 r
.60841 .17596 .61533 .18565 .62904 .1812 .62216 .1713 Metetra
.65 .72 .9 r
.62216 .1713 .62904 .1812 .64283 .17679 .63598 .16669 Metetra
.648 .715 .897 r
.63598 .16669 .64283 .17679 .65669 .17239 .64988 .16212 Metetra
.647 .712 .895 r
.64988 .16212 .65669 .17239 .67063 .16798 .66386 .15756 Metetra
.646 .709 .893 r
.66386 .15756 .67063 .16798 .68464 .16353 .6779 .15298 Metetra
.646 .707 .891 r
.6779 .15298 .68464 .16353 .69873 .15903 .69203 .14838 Metetra
.647 .706 .89 r
.69203 .14838 .69873 .15903 .71288 .15446 .70623 .14374 Metetra
.647 .706 .89 r
.70623 .14374 .71288 .15446 .72712 .14982 .7205 .13904 Metetra
.648 .706 .889 r
.7205 .13904 .72712 .14982 .74142 .14511 .73485 .13428 Metetra
.649 .707 .889 r
.73485 .13428 .74142 .14511 .7558 .14032 .74927 .12946 Metetra
.65 .707 .889 r
.74927 .12946 .7558 .14032 .77024 .13545 .76376 .12457 Metetra
.672 .719 .884 r
.12323 .34636 .13147 .35513 .14303 .35056 .13481 .34175 Metetra
.673 .719 .883 r
.13481 .34175 .14303 .35056 .15463 .34592 .14645 .33708 Metetra
.674 .719 .883 r
.14645 .33708 .15463 .34592 .16629 .34123 .15813 .33237 Metetra
.674 .72 .883 r
.15813 .33237 .16629 .34123 .17801 .33649 .16987 .32763 Metetra
.675 .721 .884 r
.16987 .32763 .17801 .33649 .18977 .3317 .18166 .32285 Metetra
.675 .722 .885 r
.18166 .32285 .18977 .3317 .20159 .32687 .1935 .31806 Metetra
.675 .724 .886 r
.1935 .31806 .20159 .32687 .21346 .32202 .20539 .31327 Metetra
.674 .726 .889 r
.20539 .31327 .21346 .32202 .22538 .31717 .21733 .30849 Metetra
.673 .728 .891 r
.21733 .30849 .22538 .31717 .23734 .31234 .22931 .30374 Metetra
.671 .731 .894 r
.22931 .30374 .23734 .31234 .24935 .30754 .24134 .29903 Metetra
.669 .733 .898 r
.24134 .29903 .24935 .30754 .26141 .3028 .25342 .29437 Metetra
.668 .736 .901 r
.25342 .29437 .26141 .3028 .27351 .29814 .26554 .28977 Metetra
.666 .738 .904 r
.26554 .28977 .27351 .29814 .28566 .29354 .27772 .28521 Metetra
.665 .74 .906 r
.27772 .28521 .28566 .29354 .29785 .28899 .28995 .28067 Metetra
.664 .741 .907 r
.28995 .28067 .29785 .28899 .3101 .28448 .30223 .27614 Metetra
.664 .741 .908 r
.30223 .27614 .3101 .28448 .32241 .27997 .31457 .2716 Metetra
.664 .741 .908 r
.31457 .2716 .32241 .27997 .33477 .27544 .32697 .26704 Metetra
.664 .741 .908 r
.32697 .26704 .33477 .27544 .34719 .2709 .33942 .26246 Metetra
.664 .741 .908 r
.33942 .26246 .34719 .2709 .35967 .26634 .35194 .25785 Metetra
.664 .741 .908 r
.35194 .25785 .35967 .26634 .37221 .26175 .36451 .25323 Metetra
.664 .741 .908 r
.36451 .25323 .37221 .26175 .3848 .25714 .37714 .24858 Metetra
.664 .741 .908 r
.37714 .24858 .3848 .25714 .39746 .25251 .38984 .24391 Metetra
.664 .741 .908 r
.38984 .24391 .39746 .25251 .41017 .24786 .40259 .23922 Metetra
.664 .741 .908 r
.40259 .23922 .41017 .24786 .42295 .24319 .4154 .2345 Metetra
.664 .741 .908 r
.4154 .2345 .42295 .24319 .43579 .23849 .42828 .22976 Metetra
.664 .741 .908 r
.42828 .22976 .43579 .23849 .44868 .23377 .44121 .225 Metetra
.664 .741 .908 r
.44121 .225 .44868 .23377 .46164 .22903 .45421 .22022 Metetra
.664 .741 .908 r
.45421 .22022 .46164 .22903 .47467 .22427 .46728 .21542 Metetra
.664 .741 .908 r
.46728 .21542 .47467 .22427 .48775 .21948 .4804 .21059 Metetra
.664 .741 .908 r
.4804 .21059 .48775 .21948 .5009 .21468 .49359 .20574 Metetra
.664 .741 .908 r
.49359 .20574 .5009 .21468 .51411 .20984 .50684 .20086 Metetra
.664 .741 .908 r
.50684 .20086 .51411 .20984 .52738 .20499 .52016 .19596 Metetra
.664 .741 .908 r
.52016 .19596 .52738 .20499 .54072 .20011 .53354 .19104 Metetra
.663 .741 .908 r
.53354 .19104 .54072 .20011 .55412 .19522 .54698 .18609 Metetra
.663 .741 .908 r
.54698 .18609 .55412 .19522 .56759 .19034 .56049 .18114 Metetra
.662 .74 .908 r
.56049 .18114 .56759 .19034 .58113 .18548 .57407 .17619 Metetra
.661 .738 .907 r
.57407 .17619 .58113 .18548 .59473 .18069 .58772 .17126 Metetra
.659 .735 .906 r
.58772 .17126 .59473 .18069 .60841 .17596 .60144 .16638 Metetra
.656 .731 .905 r
.60144 .16638 .60841 .17596 .62216 .1713 .61523 .16155 Metetra
.654 .727 .903 r
.61523 .16155 .62216 .1713 .63598 .16669 .62909 .15677 Metetra
.652 .723 .901 r
.62909 .15677 .63598 .16669 .64988 .16212 .64303 .15202 Metetra
.65 .72 .899 r
.64303 .15202 .64988 .16212 .66386 .15756 .65704 .14731 Metetra
.649 .716 .897 r
.65704 .14731 .66386 .15756 .6779 .15298 .67113 .14259 Metetra
.649 .714 .896 r
.67113 .14259 .6779 .15298 .69203 .14838 .68529 .13787 Metetra
.648 .712 .894 r
.68529 .13787 .69203 .14838 .70623 .14374 .69953 .13313 Metetra
.649 .711 .893 r
.69953 .13313 .70623 .14374 .7205 .13904 .71384 .12835 Metetra
.649 .711 .893 r
.71384 .12835 .7205 .13904 .73485 .13428 .72823 .12352 Metetra
.65 .711 .892 r
.72823 .12352 .73485 .13428 .74927 .12946 .7427 .11865 Metetra
.651 .711 .892 r
.7427 .11865 .74927 .12946 .76376 .12457 .75724 .11371 Metetra
.672 .722 .886 r
.11491 .33766 .12323 .34636 .13481 .34175 .12652 .33302 Metetra
.673 .722 .886 r
.12652 .33302 .13481 .34175 .14645 .33708 .13818 .32834 Metetra
.673 .723 .887 r
.13818 .32834 .14645 .33708 .15813 .33237 .14989 .32362 Metetra
.674 .724 .887 r
.14989 .32362 .15813 .33237 .16987 .32763 .16165 .31889 Metetra
.674 .725 .888 r
.16165 .31889 .16987 .32763 .18166 .32285 .17346 .31414 Metetra
.673 .726 .89 r
.17346 .31414 .18166 .32285 .1935 .31806 .18532 .30939 Metetra
.673 .728 .891 r
.18532 .30939 .1935 .31806 .20539 .31327 .19723 .30465 Metetra
.672 .73 .894 r
.19723 .30465 .20539 .31327 .21733 .30849 .20919 .29993 Metetra
.67 .732 .896 r
.20919 .29993 .21733 .30849 .22931 .30374 .2212 .29524 Metetra
.669 .734 .899 r
.2212 .29524 .22931 .30374 .24134 .29903 .23325 .2906 Metetra
.667 .736 .902 r
.23325 .2906 .24134 .29903 .25342 .29437 .24535 .28599 Metetra
.666 .738 .904 r
.24535 .28599 .25342 .29437 .26554 .28977 .2575 .28141 Metetra
.665 .74 .906 r
.2575 .28141 .26554 .28977 .27772 .28521 .26971 .27686 Metetra
.664 .741 .907 r
.26971 .27686 .27772 .28521 .28995 .28067 .28197 .2723 Metetra
.664 .741 .908 r
.28197 .2723 .28995 .28067 .30223 .27614 .29429 .26774 Metetra
.664 .741 .908 r
.29429 .26774 .30223 .27614 .31457 .2716 .30666 .26316 Metetra
.664 .741 .908 r
.30666 .26316 .31457 .2716 .32697 .26704 .31909 .25856 Metetra
.664 .741 .908 r
.31909 .25856 .32697 .26704 .33942 .26246 .33159 .25394 Metetra
.664 .741 .908 r
.33159 .25394 .33942 .26246 .35194 .25785 .34414 .24929 Metetra
.664 .741 .908 r
.34414 .24929 .35194 .25785 .36451 .25323 .35675 .24463 Metetra
.664 .741 .908 r
.35675 .24463 .36451 .25323 .37714 .24858 .36942 .23994 Metetra
.664 .741 .908 r
.36942 .23994 .37714 .24858 .38984 .24391 .38215 .23523 Metetra
.664 .741 .908 r
.38215 .23523 .38984 .24391 .40259 .23922 .39494 .23049 Metetra
.664 .741 .908 r
.39494 .23049 .40259 .23922 .4154 .2345 .40779 .22574 Metetra
.664 .741 .908 r
.40779 .22574 .4154 .2345 .42828 .22976 .4207 .22096 Metetra
.664 .741 .908 r
.4207 .22096 .42828 .22976 .44121 .225 .43368 .21616 Metetra
.664 .741 .908 r
.43368 .21616 .44121 .225 .45421 .22022 .44672 .21133 Metetra
.664 .741 .908 r
.44672 .21133 .45421 .22022 .46728 .21542 .45982 .20648 Metetra
.664 .741 .908 r
.45982 .20648 .46728 .21542 .4804 .21059 .47298 .20161 Metetra
.664 .741 .908 r
.47298 .20161 .4804 .21059 .49359 .20574 .48621 .19672 Metetra
.664 .741 .908 r
.48621 .19672 .49359 .20574 .50684 .20086 .49951 .1918 Metetra
.664 .741 .908 r
.49951 .1918 .50684 .20086 .52016 .19596 .51286 .18685 Metetra
.664 .741 .908 r
.51286 .18685 .52016 .19596 .53354 .19104 .52629 .18189 Metetra
.664 .741 .908 r
.52629 .18189 .53354 .19104 .54698 .18609 .53978 .17689 Metetra
.663 .741 .908 r
.53978 .17689 .54698 .18609 .56049 .18114 .55333 .17188 Metetra
.663 .741 .908 r
.55333 .17188 .56049 .18114 .57407 .17619 .56696 .16686 Metetra
.662 .74 .908 r
.56696 .16686 .57407 .17619 .58772 .17126 .58065 .16184 Metetra
.661 .738 .907 r
.58065 .16184 .58772 .17126 .60144 .16638 .59441 .15684 Metetra
.659 .736 .906 r
.59441 .15684 .60144 .16638 .61523 .16155 .60824 .15187 Metetra
.657 .732 .905 r
.60824 .15187 .61523 .16155 .62909 .15677 .62214 .14694 Metetra
.655 .729 .904 r
.62214 .14694 .62909 .15677 .64303 .15202 .63612 .14205 Metetra
.653 .726 .902 r
.63612 .14205 .64303 .15202 .65704 .14731 .65017 .13718 Metetra
.652 .723 .901 r
.65017 .13718 .65704 .14731 .67113 .14259 .6643 .13233 Metetra
.651 .72 .899 r
.6643 .13233 .67113 .14259 .68529 .13787 .6785 .12748 Metetra
.651 .718 .898 r
.6785 .12748 .68529 .13787 .69953 .13313 .69278 .12262 Metetra
.65 .716 .897 r
.69278 .12262 .69953 .13313 .71384 .12835 .70714 .11774 Metetra
.65 .715 .896 r
.70714 .11774 .71384 .12835 .72823 .12352 .72157 .11284 Metetra
.651 .715 .895 r
.72157 .11284 .72823 .12352 .7427 .11865 .73608 .10789 Metetra
.651 .714 .894 r
.73608 .10789 .7427 .11865 .75724 .11371 .75066 .10289 Metetra
.672 .725 .889 r
.10651 .32901 .11491 .33766 .12652 .33302 .11814 .32435 Metetra
.672 .725 .889 r
.11814 .32435 .12652 .33302 .13818 .32834 .12983 .31967 Metetra
.673 .726 .89 r
.12983 .31967 .13818 .32834 .14989 .32362 .14156 .31496 Metetra
.672 .727 .891 r
.14156 .31496 .14989 .32362 .16165 .31889 .15334 .31025 Metetra
.672 .729 .892 r
.15334 .31025 .16165 .31889 .17346 .31414 .16518 .30553 Metetra
.672 .73 .894 r
.16518 .30553 .17346 .31414 .18532 .30939 .17706 .30082 Metetra
.671 .732 .896 r
.17706 .30082 .18532 .30939 .19723 .30465 .18899 .29612 Metetra
.67 .734 .898 r
.18899 .29612 .19723 .30465 .20919 .29993 .20097 .29145 Metetra
.668 .735 .9 r
.20097 .29145 .20919 .29993 .2212 .29524 .213 .2868 Metetra
.667 .737 .902 r
.213 .2868 .2212 .29524 .23325 .2906 .22508 .28219 Metetra
.666 .739 .904 r
.22508 .28219 .23325 .2906 .24535 .28599 .23721 .2776 Metetra
.665 .74 .906 r
.23721 .2776 .24535 .28599 .2575 .28141 .24939 .27302 Metetra
.664 .741 .907 r
.24939 .27302 .2575 .28141 .26971 .27686 .26163 .26845 Metetra
.664 .741 .908 r
.26163 .26845 .26971 .27686 .28197 .2723 .27392 .26387 Metetra
.664 .741 .908 r
.27392 .26387 .28197 .2723 .29429 .26774 .28628 .25927 Metetra
.664 .741 .908 r
.28628 .25927 .29429 .26774 .30666 .26316 .29869 .25465 Metetra
.664 .741 .908 r
.29869 .25465 .30666 .26316 .31909 .25856 .31115 .25001 Metetra
.664 .741 .908 r
.31115 .25001 .31909 .25856 .33159 .25394 .32368 .24535 Metetra
.664 .741 .908 r
.32368 .24535 .33159 .25394 .34414 .24929 .33627 .24066 Metetra
.664 .741 .908 r
.33627 .24066 .34414 .24929 .35675 .24463 .34891 .23595 Metetra
.664 .741 .908 r
.34891 .23595 .35675 .24463 .36942 .23994 .36162 .23122 Metetra
.664 .741 .908 r
.36162 .23122 .36942 .23994 .38215 .23523 .37439 .22647 Metetra
.664 .741 .908 r
.37439 .22647 .38215 .23523 .39494 .23049 .38722 .2217 Metetra
.664 .741 .908 r
.38722 .2217 .39494 .23049 .40779 .22574 .40011 .2169 Metetra
.664 .741 .908 r
.40011 .2169 .40779 .22574 .4207 .22096 .41306 .21208 Metetra
.664 .741 .908 r
.41306 .21208 .4207 .22096 .43368 .21616 .42608 .20723 Metetra
.664 .741 .908 r
.42608 .20723 .43368 .21616 .44672 .21133 .43915 .20236 Metetra
.664 .741 .908 r
.43915 .20236 .44672 .21133 .45982 .20648 .4523 .19747 Metetra
.664 .741 .908 r
.4523 .19747 .45982 .20648 .47298 .20161 .4655 .19256 Metetra
.664 .741 .908 r
.4655 .19256 .47298 .20161 .48621 .19672 .47877 .18762 Metetra
.664 .741 .908 r
.47877 .18762 .48621 .19672 .49951 .1918 .49211 .18265 Metetra
.664 .741 .908 r
.49211 .18265 .49951 .1918 .51286 .18685 .50551 .17766 Metetra
.664 .741 .908 r
.50551 .17766 .51286 .18685 .52629 .18189 .51897 .17265 Metetra
.664 .741 .908 r
.51897 .17265 .52629 .18189 .53978 .17689 .53251 .16761 Metetra
.663 .741 .908 r
.53251 .16761 .53978 .17689 .55333 .17188 .54611 .16255 Metetra
.663 .741 .908 r
.54611 .16255 .55333 .17188 .56696 .16686 .55977 .15747 Metetra
.663 .741 .908 r
.55977 .15747 .56696 .16686 .58065 .16184 .57351 .15238 Metetra
.662 .74 .908 r
.57351 .15238 .58065 .16184 .59441 .15684 .58731 .14729 Metetra
.661 .738 .907 r
.58731 .14729 .59441 .15684 .60824 .15187 .60119 .14222 Metetra
.659 .736 .906 r
.60119 .14222 .60824 .15187 .62214 .14694 .61513 .13716 Metetra
.658 .734 .905 r
.61513 .13716 .62214 .14694 .63612 .14205 .62915 .13213 Metetra
.656 .731 .904 r
.62915 .13213 .63612 .14205 .65017 .13718 .64325 .12713 Metetra
.655 .728 .903 r
.64325 .12713 .65017 .13718 .6643 .13233 .65742 .12214 Metetra
.654 .725 .902 r
.65742 .12214 .6643 .13233 .6785 .12748 .67166 .11717 Metetra
.653 .723 .901 r
.67166 .11717 .6785 .12748 .69278 .12262 .68598 .1122 Metetra
.652 .721 .899 r
.68598 .1122 .69278 .12262 .70714 .11774 .70038 .10721 Metetra
.652 .72 .898 r
.70038 .10721 .70714 .11774 .72157 .11284 .71486 .10221 Metetra
.652 .719 .898 r
.71486 .10221 .72157 .11284 .73608 .10789 .72941 .09718 Metetra
.652 .718 .897 r
.72941 .09718 .73608 .10789 .75066 .10289 .74404 .09211 Metetra
.672 .728 .892 r
.09803 .32041 .10651 .32901 .11814 .32435 .10968 .31575 Metetra
.672 .728 .892 r
.10968 .31575 .11814 .32435 .12983 .31967 .12139 .31107 Metetra
.672 .729 .893 r
.12139 .31107 .12983 .31967 .14156 .31496 .13315 .30637 Metetra
.671 .73 .894 r
.13315 .30637 .14156 .31496 .15334 .31025 .14495 .30168 Metetra
.671 .732 .896 r
.14495 .30168 .15334 .31025 .16518 .30553 .15681 .29699 Metetra
.67 .733 .897 r
.15681 .29699 .16518 .30553 .17706 .30082 .16872 .2923 Metetra
.669 .735 .899 r
.16872 .2923 .17706 .30082 .18899 .29612 .18067 .28764 Metetra
.668 .736 .901 r
.18067 .28764 .18899 .29612 .20097 .29145 .19268 .283 Metetra
.667 .738 .903 r
.19268 .283 .20097 .29145 .213 .2868 .20473 .27838 Metetra
.666 .739 .905 r
.20473 .27838 .213 .2868 .22508 .28219 .21684 .27377 Metetra
.665 .74 .906 r
.21684 .27377 .22508 .28219 .23721 .2776 .229 .26918 Metetra
.664 .741 .907 r
.229 .26918 .23721 .2776 .24939 .27302 .24121 .26458 Metetra
.664 .741 .907 r
.24121 .26458 .24939 .27302 .26163 .26845 .25348 .25998 Metetra
.664 .741 .908 r
.25348 .25998 .26163 .26845 .27392 .26387 .26581 .25536 Metetra
.664 .741 .908 r
.26581 .25536 .27392 .26387 .28628 .25927 .27819 .25073 Metetra
.664 .741 .908 r
.27819 .25073 .28628 .25927 .29869 .25465 .29064 .24607 Metetra
.664 .741 .908 r
.29064 .24607 .29869 .25465 .31115 .25001 .30314 .24138 Metetra
.664 .741 .908 r
.30314 .24138 .31115 .25001 .32368 .24535 .31571 .23668 Metetra
.664 .741 .908 r
.31571 .23668 .32368 .24535 .33627 .24066 .32833 .23195 Metetra
.664 .741 .908 r
.32833 .23195 .33627 .24066 .34891 .23595 .34101 .2272 Metetra
.664 .741 .908 r
.34101 .2272 .34891 .23595 .36162 .23122 .35376 .22243 Metetra
.664 .741 .908 r
.35376 .22243 .36162 .23122 .37439 .22647 .36656 .21764 Metetra
.664 .741 .908 r
.36656 .21764 .37439 .22647 .38722 .2217 .37943 .21282 Metetra
.664 .741 .908 r
.37943 .21282 .38722 .2217 .40011 .2169 .39236 .20798 Metetra
.664 .741 .908 r
.39236 .20798 .40011 .2169 .41306 .21208 .40535 .20311 Metetra
.664 .741 .908 r
.40535 .20311 .41306 .21208 .42608 .20723 .4184 .19823 Metetra
.664 .741 .908 r
.4184 .19823 .42608 .20723 .43915 .20236 .43152 .19331 Metetra
.664 .741 .908 r
.43152 .19331 .43915 .20236 .4523 .19747 .44471 .18838 Metetra
.664 .741 .908 r
.44471 .18838 .4523 .19747 .4655 .19256 .45795 .18342 Metetra
.664 .741 .908 r
.45795 .18342 .4655 .19256 .47877 .18762 .47126 .17843 Metetra
.664 .741 .908 r
.47126 .17843 .47877 .18762 .49211 .18265 .48464 .17342 Metetra
.664 .741 .908 r
.48464 .17342 .49211 .18265 .50551 .17766 .49808 .16839 Metetra
.664 .741 .908 r
.49808 .16839 .50551 .17766 .51897 .17265 .51159 .16333 Metetra
.664 .741 .908 r
.51159 .16333 .51897 .17265 .53251 .16761 .52517 .15825 Metetra
.664 .741 .908 r
.52517 .15825 .53251 .16761 .54611 .16255 .53881 .15314 Metetra
.663 .741 .908 r
.53881 .15314 .54611 .16255 .55977 .15747 .55253 .14801 Metetra
.663 .741 .908 r
.55253 .14801 .55977 .15747 .57351 .15238 .56631 .14286 Metetra
.663 .741 .908 r
.56631 .14286 .57351 .15238 .58731 .14729 .58015 .1377 Metetra
.662 .74 .908 r
.58015 .1377 .58731 .14729 .60119 .14222 .59407 .13253 Metetra
.661 .738 .907 r
.59407 .13253 .60119 .14222 .61513 .13716 .60807 .12738 Metetra
.66 .736 .907 r
.60807 .12738 .61513 .13716 .62915 .13213 .62213 .12224 Metetra
.658 .734 .906 r
.62213 .12224 .62915 .13213 .64325 .12713 .63627 .11711 Metetra
.657 .732 .905 r
.63627 .11711 .64325 .12713 .65742 .12214 .65048 .11201 Metetra
.656 .73 .904 r
.65048 .11201 .65742 .12214 .67166 .11717 .66477 .10691 Metetra
.655 .728 .903 r
.66477 .10691 .67166 .11717 .68598 .1122 .67913 .10182 Metetra
.654 .726 .902 r
.67913 .10182 .68598 .1122 .70038 .10721 .69357 .09673 Metetra
.653 .724 .901 r
.69357 .09673 .70038 .10721 .71486 .10221 .70809 .09162 Metetra
.653 .723 .9 r
.70809 .09162 .71486 .10221 .72941 .09718 .72269 .0865 Metetra
.653 .722 .899 r
.72269 .0865 .72941 .09718 .74404 .09211 .73737 .08135 Metetra
.671 .73 .894 r
.08946 .31185 .09803 .32041 .10968 .31575 .10114 .30718 Metetra
.671 .731 .895 r
.10114 .30718 .10968 .31575 .12139 .31107 .11287 .30251 Metetra
.67 .732 .896 r
.11287 .30251 .12139 .31107 .13315 .30637 .12465 .29783 Metetra
.67 .733 .897 r
.12465 .29783 .13315 .30637 .14495 .30168 .13648 .29315 Metetra
.669 .734 .899 r
.13648 .29315 .14495 .30168 .15681 .29699 .14836 .28848 Metetra
.668 .735 .9 r
.14836 .28848 .15681 .29699 .16872 .2923 .16029 .28382 Metetra
.667 .737 .902 r
.16029 .28382 .16872 .2923 .18067 .28764 .17227 .27918 Metetra
.666 .738 .903 r
.17227 .27918 .18067 .28764 .19268 .283 .1843 .27455 Metetra
.666 .739 .905 r
.1843 .27455 .19268 .283 .20473 .27838 .19638 .26993 Metetra
.665 .74 .906 r
.19638 .26993 .20473 .27838 .21684 .27377 .20852 .26531 Metetra
.664 .741 .907 r
.20852 .26531 .21684 .27377 .229 .26918 .22071 .2607 Metetra
.664 .741 .907 r
.22071 .2607 .229 .26918 .24121 .26458 .23295 .25608 Metetra
.664 .741 .908 r
.23295 .25608 .24121 .26458 .25348 .25998 .24526 .25144 Metetra
.664 .741 .908 r
.24526 .25144 .25348 .25998 .26581 .25536 .25762 .24678 Metetra
.664 .741 .908 r
.25762 .24678 .26581 .25536 .27819 .25073 .27004 .24211 Metetra
.664 .741 .908 r
.27004 .24211 .27819 .25073 .29064 .24607 .28252 .23741 Metetra
.664 .741 .908 r
.28252 .23741 .29064 .24607 .30314 .24138 .29506 .23268 Metetra
.664 .741 .908 r
.29506 .23268 .30314 .24138 .31571 .23668 .30766 .22794 Metetra
.664 .741 .908 r
.30766 .22794 .31571 .23668 .32833 .23195 .32032 .22317 Metetra
.664 .741 .908 r
.32032 .22317 .32833 .23195 .34101 .2272 .33304 .21838 Metetra
.664 .741 .908 r
.33304 .21838 .34101 .2272 .35376 .22243 .34582 .21356 Metetra
.664 .741 .908 r
.34582 .21356 .35376 .22243 .36656 .21764 .35866 .20872 Metetra
.664 .741 .908 r
.35866 .20872 .36656 .21764 .37943 .21282 .37157 .20386 Metetra
.664 .741 .908 r
.37157 .20386 .37943 .21282 .39236 .20798 .38454 .19898 Metetra
.664 .741 .908 r
.38454 .19898 .39236 .20798 .40535 .20311 .39757 .19407 Metetra
.664 .741 .908 r
.39757 .19407 .40535 .20311 .4184 .19823 .41066 .18914 Metetra
.664 .741 .908 r
.41066 .18914 .4184 .19823 .43152 .19331 .42382 .18418 Metetra
.664 .741 .908 r
.42382 .18418 .43152 .19331 .44471 .18838 .43705 .1792 Metetra
.664 .741 .908 r
.43705 .1792 .44471 .18838 .45795 .18342 .45033 .1742 Metetra
.664 .741 .908 r
.45033 .1742 .45795 .18342 .47126 .17843 .46369 .16917 Metetra
.664 .741 .908 r
.46369 .16917 .47126 .17843 .48464 .17342 .47711 .16411 Metetra
.664 .741 .908 r
.47711 .16411 .48464 .17342 .49808 .16839 .49059 .15903 Metetra
.664 .741 .908 r
.49059 .15903 .49808 .16839 .51159 .16333 .50415 .15393 Metetra
.664 .741 .908 r
.50415 .15393 .51159 .16333 .52517 .15825 .51777 .1488 Metetra
.664 .741 .908 r
.51777 .1488 .52517 .15825 .53881 .15314 .53145 .14364 Metetra
.664 .741 .908 r
.53145 .14364 .53881 .15314 .55253 .14801 .54521 .13846 Metetra
.663 .741 .908 r
.54521 .13846 .55253 .14801 .56631 .14286 .55904 .13326 Metetra
.663 .741 .908 r
.55904 .13326 .56631 .14286 .58015 .1377 .57293 .12803 Metetra
.663 .74 .908 r
.57293 .12803 .58015 .1377 .59407 .13253 .5869 .1228 Metetra
.662 .74 .908 r
.5869 .1228 .59407 .13253 .60807 .12738 .60093 .11756 Metetra
.661 .738 .907 r
.60093 .11756 .60807 .12738 .62213 .12224 .61504 .11233 Metetra
.66 .737 .907 r
.61504 .11233 .62213 .12224 .63627 .11711 .62922 .1071 Metetra
.659 .735 .906 r
.62922 .1071 .63627 .11711 .65048 .11201 .64348 .10188 Metetra
.658 .733 .905 r
.64348 .10188 .65048 .11201 .66477 .10691 .65781 .09668 Metetra
.657 .731 .904 r
.65781 .09668 .66477 .10691 .67913 .10182 .67222 .09147 Metetra
.656 .729 .903 r
.67222 .09147 .67913 .10182 .69357 .09673 .68671 .08627 Metetra
.655 .728 .903 r
.68671 .08627 .69357 .09673 .70809 .09162 .70128 .08106 Metetra
.655 .726 .902 r
.70128 .08106 .70809 .09162 .72269 .0865 .71592 .07584 Metetra
.654 .725 .901 r
.71592 .07584 .72269 .0865 .73737 .08135 .73065 .0706 Metetra
.67 .732 .897 r
.08081 .30332 .08946 .31185 .10114 .30718 .09251 .29865 Metetra
.67 .733 .897 r
.09251 .29865 .10114 .30718 .11287 .30251 .10426 .29399 Metetra
.669 .734 .899 r
.10426 .29399 .11287 .30251 .12465 .29783 .11607 .28932 Metetra
.669 .735 .9 r
.11607 .28932 .12465 .29783 .13648 .29315 .12792 .28465 Metetra
.668 .736 .901 r
.12792 .28465 .13648 .29315 .14836 .28848 .13983 .27999 Metetra
.667 .737 .902 r
.13983 .27999 .14836 .28848 .16029 .28382 .15178 .27534 Metetra
.666 .738 .904 r
.15178 .27534 .16029 .28382 .17227 .27918 .16379 .2707 Metetra
.665 .739 .905 r
.16379 .2707 .17227 .27918 .1843 .27455 .17585 .26607 Metetra
.665 .74 .906 r
.17585 .26607 .1843 .27455 .19638 .26993 .18796 .26144 Metetra
.664 .741 .907 r
.18796 .26144 .19638 .26993 .20852 .26531 .20012 .2568 Metetra
.664 .741 .907 r
.20012 .2568 .20852 .26531 .22071 .2607 .21235 .25216 Metetra
.664 .741 .908 r
.21235 .25216 .22071 .2607 .23295 .25608 .22463 .2475 Metetra
.664 .741 .908 r
.22463 .2475 .23295 .25608 .24526 .25144 .23697 .24283 Metetra
.664 .741 .908 r
.23697 .24283 .24526 .25144 .25762 .24678 .24936 .23813 Metetra
.664 .741 .908 r
.24936 .23813 .25762 .24678 .27004 .24211 .26182 .23341 Metetra
.664 .741 .908 r
.26182 .23341 .27004 .24211 .28252 .23741 .27433 .22867 Metetra
.664 .741 .908 r
.27433 .22867 .28252 .23741 .29506 .23268 .28691 .2239 Metetra
.664 .741 .908 r
.28691 .2239 .29506 .23268 .30766 .22794 .29954 .21912 Metetra
.664 .741 .908 r
.29954 .21912 .30766 .22794 .32032 .22317 .31224 .2143 Metetra
.664 .741 .908 r
.31224 .2143 .32032 .22317 .33304 .21838 .325 .20947 Metetra
.664 .741 .908 r
.325 .20947 .33304 .21838 .34582 .21356 .33782 .20461 Metetra
.664 .741 .908 r
.33782 .20461 .34582 .21356 .35866 .20872 .3507 .19973 Metetra
.664 .741 .908 r
.3507 .19973 .35866 .20872 .37157 .20386 .36364 .19483 Metetra
.664 .741 .908 r
.36364 .19483 .37157 .20386 .38454 .19898 .37665 .1899 Metetra
.664 .741 .908 r
.37665 .1899 .38454 .19898 .39757 .19407 .38972 .18495 Metetra
.664 .741 .908 r
.38972 .18495 .39757 .19407 .41066 .18914 .40285 .17997 Metetra
.664 .741 .908 r
.40285 .17997 .41066 .18914 .42382 .18418 .41605 .17497 Metetra
.664 .741 .908 r
.41605 .17497 .42382 .18418 .43705 .1792 .42932 .16994 Metetra
.664 .741 .908 r
.42932 .16994 .43705 .1792 .45033 .1742 .44265 .16489 Metetra
.664 .741 .908 r
.44265 .16489 .45033 .1742 .46369 .16917 .45604 .15981 Metetra
.664 .741 .908 r
.45604 .15981 .46369 .16917 .47711 .16411 .4695 .15471 Metetra
.664 .741 .908 r
.4695 .15471 .47711 .16411 .49059 .15903 .48303 .14959 Metetra
.664 .741 .908 r
.48303 .14959 .49059 .15903 .50415 .15393 .49663 .14444 Metetra
.664 .741 .908 r
.49663 .14444 .50415 .15393 .51777 .1488 .51029 .13926 Metetra
.664 .741 .908 r
.51029 .13926 .51777 .1488 .53145 .14364 .52403 .13405 Metetra
.664 .741 .908 r
.52403 .13405 .53145 .14364 .54521 .13846 .53783 .12882 Metetra
.664 .741 .908 r
.53783 .12882 .54521 .13846 .55904 .13326 .5517 .12357 Metetra
.663 .741 .908 r
.5517 .12357 .55904 .13326 .57293 .12803 .56564 .11829 Metetra
.663 .741 .908 r
.56564 .11829 .57293 .12803 .5869 .1228 .57965 .113 Metetra
.663 .74 .908 r
.57965 .113 .5869 .1228 .60093 .11756 .59373 .10769 Metetra
.662 .74 .908 r
.59373 .10769 .60093 .11756 .61504 .11233 .60789 .10237 Metetra
.661 .739 .907 r
.60789 .10237 .61504 .11233 .62922 .1071 .62212 .09706 Metetra
.66 .737 .907 r
.62212 .09706 .62922 .1071 .64348 .10188 .63642 .09174 Metetra
.659 .736 .906 r
.63642 .09174 .64348 .10188 .65781 .09668 .6508 .08643 Metetra
.658 .734 .906 r
.6508 .08643 .65781 .09668 .67222 .09147 .66526 .08113 Metetra
.657 .732 .905 r
.66526 .08113 .67222 .09147 .68671 .08627 .67979 .07582 Metetra
.657 .731 .904 r
.67979 .07582 .68671 .08627 .70128 .08106 .6944 .07051 Metetra
.656 .729 .903 r
.6944 .07051 .70128 .08106 .71592 .07584 .7091 .06519 Metetra
.656 .728 .903 r
.7091 .06519 .71592 .07584 .73065 .0706 .72387 .05986 Metetra
.669 .734 .899 r
.07207 .2948 .08081 .30332 .09251 .29865 .0838 .29014 Metetra
.669 .735 .9 r
.0838 .29014 .09251 .29865 .10426 .29399 .09557 .28547 Metetra
.668 .736 .901 r
.09557 .28547 .10426 .29399 .11607 .28932 .1074 .28081 Metetra
.667 .737 .902 r
.1074 .28081 .11607 .28932 .12792 .28465 .11928 .27615 Metetra
.667 .738 .903 r
.11928 .27615 .12792 .28465 .13983 .27999 .13121 .27149 Metetra
.666 .739 .904 r
.13121 .27149 .13983 .27999 .15178 .27534 .14319 .26684 Metetra
.665 .739 .905 r
.14319 .26684 .15178 .27534 .16379 .2707 .15523 .26219 Metetra
.665 .74 .906 r
.15523 .26219 .16379 .2707 .17585 .26607 .16732 .25754 Metetra
.664 .741 .907 r
.16732 .25754 .17585 .26607 .18796 .26144 .17946 .25289 Metetra
.664 .741 .907 r
.17946 .25289 .18796 .26144 .20012 .2568 .19166 .24823 Metetra
.664 .741 .908 r
.19166 .24823 .20012 .2568 .21235 .25216 .20391 .24355 Metetra
.664 .741 .908 r
.20391 .24355 .21235 .25216 .22463 .2475 .21623 .23885 Metetra
.664 .741 .908 r
.21623 .23885 .22463 .2475 .23697 .24283 .2286 .23414 Metetra
.664 .741 .908 r
.2286 .23414 .23697 .24283 .24936 .23813 .24103 .2294 Metetra
.664 .741 .908 r
.24103 .2294 .24936 .23813 .26182 .23341 .25352 .22464 Metetra
.664 .741 .908 r
.25352 .22464 .26182 .23341 .27433 .22867 .26607 .21985 Metetra
.664 .741 .908 r
.26607 .21985 .27433 .22867 .28691 .2239 .27868 .21505 Metetra
.664 .741 .908 r
.27868 .21505 .28691 .2239 .29954 .21912 .29135 .21022 Metetra
.664 .741 .908 r
.29135 .21022 .29954 .21912 .31224 .2143 .30409 .20536 Metetra
.664 .741 .908 r
.30409 .20536 .31224 .2143 .325 .20947 .31688 .20048 Metetra
.664 .741 .908 r
.31688 .20048 .325 .20947 .33782 .20461 .32974 .19558 Metetra
.664 .741 .908 r
.32974 .19558 .33782 .20461 .3507 .19973 .34266 .19066 Metetra
.664 .741 .908 r
.34266 .19066 .3507 .19973 .36364 .19483 .35564 .18571 Metetra
.664 .741 .908 r
.35564 .18571 .36364 .19483 .37665 .1899 .36869 .18074 Metetra
.664 .741 .908 r
.36869 .18074 .37665 .1899 .38972 .18495 .3818 .17574 Metetra
.664 .741 .908 r
.3818 .17574 .38972 .18495 .40285 .17997 .39497 .17072 Metetra
.664 .741 .908 r
.39497 .17072 .40285 .17997 .41605 .17497 .40821 .16567 Metetra
.664 .741 .908 r
.40821 .16567 .41605 .17497 .42932 .16994 .42152 .1606 Metetra
.664 .741 .908 r
.42152 .1606 .42932 .16994 .44265 .16489 .43489 .1555 Metetra
.664 .741 .908 r
.43489 .1555 .44265 .16489 .45604 .15981 .44833 .15038 Metetra
.664 .741 .908 r
.44833 .15038 .45604 .15981 .4695 .15471 .46183 .14523 Metetra
.664 .741 .908 r
.46183 .14523 .4695 .15471 .48303 .14959 .4754 .14006 Metetra
.664 .741 .908 r
.4754 .14006 .48303 .14959 .49663 .14444 .48904 .13486 Metetra
.664 .741 .908 r
.48904 .13486 .49663 .14444 .51029 .13926 .50275 .12963 Metetra
.664 .741 .908 r
.50275 .12963 .51029 .13926 .52403 .13405 .51653 .12438 Metetra
.664 .741 .908 r
.51653 .12438 .52403 .13405 .53783 .12882 .53038 .1191 Metetra
.664 .741 .908 r
.53038 .1191 .53783 .12882 .5517 .12357 .54429 .1138 Metetra
.663 .741 .908 r
.54429 .1138 .5517 .12357 .56564 .11829 .55828 .10847 Metetra
.663 .741 .908 r
.55828 .10847 .56564 .11829 .57965 .113 .57234 .10311 Metetra
.663 .741 .908 r
.57234 .10311 .57965 .113 .59373 .10769 .58647 .09774 Metetra
.663 .74 .908 r
.58647 .09774 .59373 .10769 .60789 .10237 .60067 .09236 Metetra
.662 .74 .908 r
.60067 .09236 .60789 .10237 .62212 .09706 .61495 .08696 Metetra
.661 .739 .907 r
.61495 .08696 .62212 .09706 .63642 .09174 .6293 .08156 Metetra
.661 .738 .907 r
.6293 .08156 .63642 .09174 .6508 .08643 .64373 .07616 Metetra
.66 .736 .906 r
.64373 .07616 .6508 .08643 .66526 .08113 .65823 .07076 Metetra
.659 .735 .906 r
.65823 .07076 .66526 .08113 .67979 .07582 .67281 .06536 Metetra
.658 .733 .905 r
.67281 .06536 .67979 .07582 .6944 .07051 .68747 .05995 Metetra
.657 .732 .905 r
.68747 .05995 .6944 .07051 .7091 .06519 .70221 .05453 Metetra
.657 .731 .904 r
.70221 .05453 .7091 .06519 .72387 .05986 .71703 .04911 Metetra
.668 .736 .901 r
.06325 .28628 .07207 .2948 .0838 .29014 .075 .28162 Metetra
.668 .736 .901 r
.075 .28162 .0838 .29014 .09557 .28547 .0868 .27695 Metetra
.667 .737 .902 r
.0868 .27695 .09557 .28547 .1074 .28081 .09866 .27229 Metetra
.667 .738 .903 r
.09866 .27229 .1074 .28081 .11928 .27615 .11056 .26762 Metetra
.666 .739 .904 r
.11056 .26762 .11928 .27615 .13121 .27149 .12252 .26296 Metetra
.665 .739 .905 r
.12252 .26296 .13121 .27149 .14319 .26684 .13453 .2583 Metetra
.665 .74 .906 r
.13453 .2583 .14319 .26684 .15523 .26219 .14659 .25363 Metetra
.664 .741 .907 r
.14659 .25363 .15523 .26219 .16732 .25754 .15871 .24896 Metetra
.664 .741 .907 r
.15871 .24896 .16732 .25754 .17946 .25289 .17088 .24428 Metetra
.664 .741 .908 r
.17088 .24428 .17946 .25289 .19166 .24823 .18311 .23958 Metetra
.664 .741 .908 r
.18311 .23958 .19166 .24823 .20391 .24355 .1954 .23487 Metetra
.664 .741 .908 r
.1954 .23487 .20391 .24355 .21623 .23885 .20775 .23013 Metetra
.664 .741 .908 r
.20775 .23013 .21623 .23885 .2286 .23414 .22016 .22537 Metetra
.664 .741 .908 r
.22016 .22537 .2286 .23414 .24103 .2294 .23262 .22059 Metetra
.664 .741 .908 r
.23262 .22059 .24103 .2294 .25352 .22464 .24515 .21579 Metetra
.664 .741 .908 r
.24515 .21579 .25352 .22464 .26607 .21985 .25774 .21096 Metetra
.664 .741 .908 r
.25774 .21096 .26607 .21985 .27868 .21505 .27038 .20611 Metetra
.664 .741 .908 r
.27038 .20611 .27868 .21505 .29135 .21022 .28309 .20124 Metetra
.664 .741 .908 r
.28309 .20124 .29135 .21022 .30409 .20536 .29586 .19634 Metetra
.664 .741 .908 r
.29586 .19634 .30409 .20536 .31688 .20048 .30869 .19142 Metetra
.664 .741 .908 r
.30869 .19142 .31688 .20048 .32974 .19558 .32159 .18647 Metetra
.664 .741 .908 r
.32159 .18647 .32974 .19558 .34266 .19066 .33455 .1815 Metetra
.664 .741 .908 r
.33455 .1815 .34266 .19066 .35564 .18571 .34757 .17651 Metetra
.664 .741 .908 r
.34757 .17651 .35564 .18571 .36869 .18074 .36065 .17149 Metetra
.664 .741 .908 r
.36065 .17149 .36869 .18074 .3818 .17574 .37381 .16645 Metetra
.664 .741 .908 r
.37381 .16645 .3818 .17574 .39497 .17072 .38702 .16138 Metetra
.664 .741 .908 r
.38702 .16138 .39497 .17072 .40821 .16567 .4003 .15629 Metetra
.664 .741 .908 r
.4003 .15629 .40821 .16567 .42152 .1606 .41365 .15117 Metetra
.664 .741 .908 r
.41365 .15117 .42152 .1606 .43489 .1555 .42706 .14602 Metetra
.664 .741 .908 r
.42706 .14602 .43489 .1555 .44833 .15038 .44054 .14085 Metetra
.664 .741 .908 r
.44054 .14085 .44833 .15038 .46183 .14523 .45409 .13566 Metetra
.664 .741 .908 r
.45409 .13566 .46183 .14523 .4754 .14006 .4677 .13044 Metetra
.664 .741 .908 r
.4677 .13044 .4754 .14006 .48904 .13486 .48139 .12519 Metetra
.664 .741 .908 r
.48139 .12519 .48904 .13486 .50275 .12963 .49514 .11991 Metetra
.664 .741 .908 r
.49514 .11991 .50275 .12963 .51653 .12438 .50896 .11461 Metetra
.664 .741 .908 r
.50896 .11461 .51653 .12438 .53038 .1191 .52286 .10929 Metetra
.664 .741 .908 r
.52286 .10929 .53038 .1191 .54429 .1138 .53682 .10393 Metetra
.664 .741 .908 r
.53682 .10393 .54429 .1138 .55828 .10847 .55085 .09855 Metetra
.663 .741 .908 r
.55085 .09855 .55828 .10847 .57234 .10311 .56496 .09314 Metetra
.663 .741 .908 r
.56496 .09314 .57234 .10311 .58647 .09774 .57914 .08771 Metetra
.663 .741 .908 r
.57914 .08771 .58647 .09774 .60067 .09236 .59339 .08226 Metetra
.663 .74 .908 r
.59339 .08226 .60067 .09236 .61495 .08696 .60771 .0768 Metetra
.662 .74 .908 r
.60771 .0768 .61495 .08696 .6293 .08156 .62211 .07132 Metetra
.662 .739 .907 r
.62211 .07132 .6293 .08156 .64373 .07616 .63659 .06584 Metetra
.661 .738 .907 r
.63659 .06584 .64373 .07616 .65823 .07076 .65114 .06035 Metetra
.66 .737 .907 r
.65114 .06035 .65823 .07076 .67281 .06536 .66577 .05486 Metetra
.659 .735 .906 r
.66577 .05486 .67281 .06536 .68747 .05995 .68048 .04936 Metetra
.659 .734 .905 r
.68048 .04936 .68747 .05995 .70221 .05453 .69527 .04385 Metetra
.658 .733 .905 r
.69527 .04385 .70221 .05453 .71703 .04911 .71013 .03833 Metetra
.667 .737 .902 r
.05435 .27776 .06325 .28628 .075 .28162 .06612 .27309 Metetra
.667 .738 .903 r
.06612 .27309 .075 .28162 .0868 .27695 .07795 .26842 Metetra
.666 .738 .904 r
.07795 .26842 .0868 .27695 .09866 .27229 .08983 .26374 Metetra
.666 .739 .905 r
.08983 .26374 .09866 .27229 .11056 .26762 .10176 .25907 Metetra
.665 .74 .906 r
.10176 .25907 .11056 .26762 .12252 .26296 .11375 .25439 Metetra
.665 .74 .906 r
.11375 .25439 .12252 .26296 .13453 .2583 .12578 .2497 Metetra
.664 .741 .907 r
.12578 .2497 .13453 .2583 .14659 .25363 .13788 .24501 Metetra
.664 .741 .907 r
.13788 .24501 .14659 .25363 .15871 .24896 .15003 .24031 Metetra
.664 .741 .908 r
.15003 .24031 .15871 .24896 .17088 .24428 .16223 .2356 Metetra
.664 .741 .908 r
.16223 .2356 .17088 .24428 .18311 .23958 .1745 .23086 Metetra
.664 .741 .908 r
.1745 .23086 .18311 .23958 .1954 .23487 .18682 .22611 Metetra
.664 .741 .908 r
.18682 .22611 .1954 .23487 .20775 .23013 .1992 .22133 Metetra
.664 .741 .908 r
.1992 .22133 .20775 .23013 .22016 .22537 .21164 .21653 Metetra
.664 .741 .908 r
.21164 .21653 .22016 .22537 .23262 .22059 .22414 .2117 Metetra
.664 .741 .908 r
.22414 .2117 .23262 .22059 .24515 .21579 .2367 .20686 Metetra
.664 .741 .908 r
.2367 .20686 .24515 .21579 .25774 .21096 .24933 .20199 Metetra
.664 .741 .908 r
.24933 .20199 .25774 .21096 .27038 .20611 .26201 .19709 Metetra
.664 .741 .908 r
.26201 .19709 .27038 .20611 .28309 .20124 .27476 .19218 Metetra
.664 .741 .908 r
.27476 .19218 .28309 .20124 .29586 .19634 .28756 .18723 Metetra
.664 .741 .908 r
.28756 .18723 .29586 .19634 .30869 .19142 .30043 .18227 Metetra
.664 .741 .908 r
.30043 .18227 .30869 .19142 .32159 .18647 .31337 .17728 Metetra
.664 .741 .908 r
.31337 .17728 .32159 .18647 .33455 .1815 .32636 .17226 Metetra
.664 .741 .908 r
.32636 .17226 .33455 .1815 .34757 .17651 .33942 .16722 Metetra
.664 .741 .908 r
.33942 .16722 .34757 .17651 .36065 .17149 .35255 .16216 Metetra
.664 .741 .908 r
.35255 .16216 .36065 .17149 .37381 .16645 .36574 .15707 Metetra
.664 .741 .908 r
.36574 .15707 .37381 .16645 .38702 .16138 .37899 .15196 Metetra
.664 .741 .908 r
.37899 .15196 .38702 .16138 .4003 .15629 .39232 .14682 Metetra
.664 .741 .908 r
.39232 .14682 .4003 .15629 .41365 .15117 .4057 .14165 Metetra
.664 .741 .908 r
.4057 .14165 .41365 .15117 .42706 .14602 .41916 .13646 Metetra
.664 .741 .908 r
.41916 .13646 .42706 .14602 .44054 .14085 .43268 .13124 Metetra
.664 .741 .908 r
.43268 .13124 .44054 .14085 .45409 .13566 .44627 .126 Metetra
.664 .741 .908 r
.44627 .126 .45409 .13566 .4677 .13044 .45993 .12073 Metetra
.664 .741 .908 r
.45993 .12073 .4677 .13044 .48139 .12519 .47366 .11543 Metetra
.664 .741 .908 r
.47366 .11543 .48139 .12519 .49514 .11991 .48746 .11011 Metetra
.664 .741 .908 r
.48746 .11011 .49514 .11991 .50896 .11461 .50132 .10476 Metetra
.664 .741 .908 r
.50132 .10476 .50896 .11461 .52286 .10929 .51526 .09938 Metetra
.664 .741 .908 r
.51526 .09938 .52286 .10929 .53682 .10393 .52927 .09397 Metetra
.664 .741 .908 r
.52927 .09397 .53682 .10393 .55085 .09855 .54335 .08854 Metetra
.664 .741 .908 r
.54335 .08854 .55085 .09855 .56496 .09314 .55751 .08308 Metetra
.663 .741 .908 r
.55751 .08308 .56496 .09314 .57914 .08771 .57173 .0776 Metetra
.663 .741 .908 r
.57173 .0776 .57914 .08771 .59339 .08226 .58603 .07209 Metetra
.663 .741 .908 r
.58603 .07209 .59339 .08226 .60771 .0768 .60041 .06656 Metetra
.663 .74 .908 r
.60041 .06656 .60771 .0768 .62211 .07132 .61486 .06101 Metetra
.662 .74 .908 r
.61486 .06101 .62211 .07132 .63659 .06584 .62938 .05545 Metetra
.662 .739 .907 r
.62938 .05545 .63659 .06584 .65114 .06035 .64398 .04988 Metetra
.661 .738 .907 r
.64398 .04988 .65114 .06035 .66577 .05486 .65866 .0443 Metetra
.66 .737 .907 r
.65866 .0443 .66577 .05486 .68048 .04936 .67342 .03872 Metetra
.66 .736 .906 r
.67342 .03872 .68048 .04936 .69527 .04385 .68826 .03312 Metetra
.659 .735 .906 r
.68826 .03312 .69527 .04385 .71013 .03833 .70318 .02751 Metetra
.667 .738 .903 r
.04536 .26921 .05435 .27776 .06612 .27309 .05716 .26453 Metetra
.666 .739 .904 r
.05716 .26453 .06612 .27309 .07795 .26842 .06901 .25985 Metetra
.666 .739 .905 r
.06901 .25985 .07795 .26842 .08983 .26374 .08092 .25516 Metetra
.665 .74 .906 r
.08092 .25516 .08983 .26374 .10176 .25907 .09288 .25046 Metetra
.665 .74 .906 r
.09288 .25046 .10176 .25907 .11375 .25439 .10489 .24576 Metetra
.664 .741 .907 r
.10489 .24576 .11375 .25439 .12578 .2497 .11696 .24105 Metetra
.664 .741 .907 r
.11696 .24105 .12578 .2497 .13788 .24501 .12909 .23633 Metetra
.664 .741 .908 r
.12909 .23633 .13788 .24501 .15003 .24031 .14127 .23159 Metetra
.664 .741 .908 r
.14127 .23159 .15003 .24031 .16223 .2356 .15351 .22684 Metetra
.664 .741 .908 r
.15351 .22684 .16223 .2356 .1745 .23086 .1658 .22206 Metetra
.664 .741 .908 r
.1658 .22206 .1745 .23086 .18682 .22611 .17816 .21727 Metetra
.664 .741 .908 r
.17816 .21727 .18682 .22611 .1992 .22133 .19057 .21245 Metetra
.664 .741 .908 r
.19057 .21245 .1992 .22133 .21164 .21653 .20305 .2076 Metetra
.664 .741 .908 r
.20305 .2076 .21164 .21653 .22414 .2117 .21559 .20274 Metetra
.664 .741 .908 r
.21559 .20274 .22414 .2117 .2367 .20686 .22818 .19785 Metetra
.664 .741 .908 r
.22818 .19785 .2367 .20686 .24933 .20199 .24084 .19293 Metetra
.664 .741 .908 r
.24084 .19293 .24933 .20199 .26201 .19709 .25356 .188 Metetra
.664 .741 .908 r
.25356 .188 .26201 .19709 .27476 .19218 .26634 .18303 Metetra
.664 .741 .908 r
.26634 .18303 .27476 .19218 .28756 .18723 .27919 .17805 Metetra
.664 .741 .908 r
.27919 .17805 .28756 .18723 .30043 .18227 .2921 .17304 Metetra
.664 .741 .908 r
.2921 .17304 .30043 .18227 .31337 .17728 .30507 .168 Metetra
.664 .741 .908 r
.30507 .168 .31337 .17728 .32636 .17226 .3181 .16294 Metetra
.664 .741 .908 r
.3181 .16294 .32636 .17226 .33942 .16722 .3312 .15786 Metetra
.664 .741 .908 r
.3312 .15786 .33942 .16722 .35255 .16216 .34437 .15274 Metetra
.664 .741 .908 r
.34437 .15274 .35255 .16216 .36574 .15707 .3576 .14761 Metetra
.664 .741 .908 r
.3576 .14761 .36574 .15707 .37899 .15196 .37089 .14245 Metetra
.664 .741 .908 r
.37089 .14245 .37899 .15196 .39232 .14682 .38426 .13726 Metetra
.664 .741 .908 r
.38426 .13726 .39232 .14682 .4057 .14165 .39769 .13205 Metetra
.664 .741 .908 r
.39769 .13205 .4057 .14165 .41916 .13646 .41118 .12681 Metetra
.664 .741 .908 r
.41118 .12681 .41916 .13646 .43268 .13124 .42475 .12154 Metetra
.664 .741 .908 r
.42475 .12154 .43268 .13124 .44627 .126 .43838 .11625 Metetra
.664 .741 .908 r
.43838 .11625 .44627 .126 .45993 .12073 .45209 .11093 Metetra
.664 .741 .908 r
.45209 .11093 .45993 .12073 .47366 .11543 .46586 .10558 Metetra
.664 .741 .908 r
.46586 .10558 .47366 .11543 .48746 .11011 .4797 .10021 Metetra
.664 .741 .908 r
.4797 .10021 .48746 .11011 .50132 .10476 .49362 .09481 Metetra
.664 .741 .908 r
.49362 .09481 .50132 .10476 .51526 .09938 .5076 .08938 Metetra
.664 .741 .908 r
.5076 .08938 .51526 .09938 .52927 .09397 .52166 .08392 Metetra
.664 .741 .908 r
.52166 .08392 .52927 .09397 .54335 .08854 .53578 .07844 Metetra
.664 .741 .908 r
.53578 .07844 .54335 .08854 .55751 .08308 .54998 .07292 Metetra
.663 .741 .908 r
.54998 .07292 .55751 .08308 .57173 .0776 .56426 .06738 Metetra
.663 .741 .908 r
.56426 .06738 .57173 .0776 .58603 .07209 .57861 .06182 Metetra
.663 .741 .908 r
.57861 .06182 .58603 .07209 .60041 .06656 .59303 .05623 Metetra
.663 .741 .908 r
.59303 .05623 .60041 .06656 .61486 .06101 .60753 .05062 Metetra
.663 .74 .908 r
.60753 .05062 .61486 .06101 .62938 .05545 .6221 .04499 Metetra
.662 .74 .908 r
.6221 .04499 .62938 .05545 .64398 .04988 .63676 .03935 Metetra
.662 .739 .907 r
.63676 .03935 .64398 .04988 .65866 .0443 .65149 .03369 Metetra
.661 .738 .907 r
.65149 .03369 .65866 .0443 .67342 .03872 .6663 .02802 Metetra
.661 .737 .907 r
.6663 .02802 .67342 .03872 .68826 .03312 .68119 .02234 Metetra
.66 .736 .906 r
.68119 .02234 .68826 .03312 .70318 .02751 .69616 .01664 Metetra
.666 .739 .905 r
.03629 .26063 .04536 .26921 .05716 .26453 .04812 .25593 Metetra
.665 .739 .905 r
.04812 .25593 .05716 .26453 .06901 .25985 .06 .25123 Metetra
.665 .74 .906 r
.06 .25123 .06901 .25985 .08092 .25516 .07193 .24652 Metetra
.665 .74 .906 r
.07193 .24652 .08092 .25516 .09288 .25046 .08392 .2418 Metetra
.664 .741 .907 r
.08392 .2418 .09288 .25046 .10489 .24576 .09596 .23708 Metetra
.664 .741 .907 r
.09596 .23708 .10489 .24576 .11696 .24105 .10806 .23233 Metetra
.664 .741 .908 r
.10806 .23233 .11696 .24105 .12909 .23633 .12022 .22758 Metetra
.664 .741 .908 r
.12022 .22758 .12909 .23633 .14127 .23159 .13243 .2228 Metetra
.664 .741 .908 r
.13243 .2228 .14127 .23159 .15351 .22684 .1447 .21801 Metetra
.664 .741 .908 r
.1447 .21801 .15351 .22684 .1658 .22206 .15703 .21319 Metetra
.664 .741 .908 r
.15703 .21319 .1658 .22206 .17816 .21727 .16942 .20835 Metetra
.664 .741 .908 r
.16942 .20835 .17816 .21727 .19057 .21245 .18187 .20349 Metetra
.664 .741 .908 r
.18187 .20349 .19057 .21245 .20305 .2076 .19438 .1986 Metetra
.664 .741 .908 r
.19438 .1986 .20305 .2076 .21559 .20274 .20695 .19369 Metetra
.664 .741 .908 r
.20695 .19369 .21559 .20274 .22818 .19785 .21959 .18876 Metetra
.664 .741 .908 r
.21959 .18876 .22818 .19785 .24084 .19293 .23228 .1838 Metetra
.664 .741 .908 r
.23228 .1838 .24084 .19293 .25356 .188 .24504 .17882 Metetra
.664 .741 .908 r
.24504 .17882 .25356 .188 .26634 .18303 .25786 .17381 Metetra
.664 .741 .908 r
.25786 .17381 .26634 .18303 .27919 .17805 .27074 .16878 Metetra
.664 .741 .908 r
.27074 .16878 .27919 .17805 .2921 .17304 .28368 .16372 Metetra
.664 .741 .908 r
.28368 .16372 .2921 .17304 .30507 .168 .29669 .15864 Metetra
.664 .741 .908 r
.29669 .15864 .30507 .168 .3181 .16294 .30977 .15353 Metetra
.664 .741 .908 r
.30977 .15353 .3181 .16294 .3312 .15786 .32291 .1484 Metetra
.664 .741 .908 r
.32291 .1484 .3312 .15786 .34437 .15274 .33611 .14324 Metetra
.664 .741 .908 r
.33611 .14324 .34437 .15274 .3576 .14761 .34938 .13806 Metetra
.664 .741 .908 r
.34938 .13806 .3576 .14761 .37089 .14245 .36272 .13285 Metetra
.664 .741 .908 r
.36272 .13285 .37089 .14245 .38426 .13726 .37612 .12761 Metetra
.664 .741 .908 r
.37612 .12761 .38426 .13726 .39769 .13205 .3896 .12235 Metetra
.664 .741 .908 r
.3896 .12235 .39769 .13205 .41118 .12681 .40314 .11706 Metetra
.664 .741 .908 r
.40314 .11706 .41118 .12681 .42475 .12154 .41674 .11175 Metetra
.664 .741 .908 r
.41674 .11175 .42475 .12154 .43838 .11625 .43042 .10641 Metetra
.664 .741 .908 r
.43042 .10641 .43838 .11625 .45209 .11093 .44417 .10104 Metetra
.664 .741 .908 r
.44417 .10104 .45209 .11093 .46586 .10558 .45799 .09564 Metetra
.664 .741 .908 r
.45799 .09564 .46586 .10558 .4797 .10021 .47187 .09021 Metetra
.664 .741 .908 r
.47187 .09021 .4797 .10021 .49362 .09481 .48583 .08476 Metetra
.664 .741 .908 r
.48583 .08476 .49362 .09481 .5076 .08938 .49986 .07928 Metetra
.664 .741 .908 r
.49986 .07928 .5076 .08938 .52166 .08392 .51397 .07377 Metetra
.664 .741 .908 r
.51397 .07377 .52166 .08392 .53578 .07844 .52814 .06824 Metetra
.664 .741 .908 r
.52814 .06824 .53578 .07844 .54998 .07292 .54239 .06267 Metetra
.664 .741 .908 r
.54239 .06267 .54998 .07292 .56426 .06738 .55671 .05708 Metetra
.663 .741 .908 r
.55671 .05708 .56426 .06738 .57861 .06182 .57111 .05146 Metetra
.663 .741 .908 r
.57111 .05146 .57861 .06182 .59303 .05623 .58559 .04581 Metetra
.663 .741 .908 r
.58559 .04581 .59303 .05623 .60753 .05062 .60013 .04014 Metetra
.663 .741 .908 r
.60013 .04014 .60753 .05062 .6221 .04499 .61476 .03444 Metetra
.663 .74 .908 r
.61476 .03444 .6221 .04499 .63676 .03935 .62946 .02873 Metetra
.662 .74 .908 r
.62946 .02873 .63676 .03935 .65149 .03369 .64424 .023 Metetra
.662 .739 .907 r
.64424 .023 .65149 .03369 .6663 .02802 .65911 .01725 Metetra
.661 .738 .907 r
.65911 .01725 .6663 .02802 .68119 .02234 .67405 .01149 Metetra
.661 .738 .907 r
.67405 .01149 .68119 .02234 .69616 .01664 .68907 .00571 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.25599 .16945 m
.26043 .17428 L
s
[(0.2)] .24711 .15979 .9191 1 Mshowa
.49481 .07594 m
.4988 .08114 L
s
[(0.4)] .48682 .06553 .76746 1 Mshowa
.125 Mabswid
.09013 .23439 m
.09296 .23713 L
s
.14424 .21321 m
.14702 .216 L
s
.19951 .19156 m
.20223 .19441 L
s
.31372 .14684 m
.31632 .1498 L
s
.37274 .12374 m
.37527 .12675 L
s
.43308 .10011 m
.43555 .10317 L
s
.55796 .05121 m
.56028 .05439 L
s
.62258 .0259 m
.62482 .02914 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[55]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00b@3oool2000000@0oooo00<0
00000?ooo`3oool00`3oool2000000@0oooo0`0000120?ooo`00b03oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0@@3oool00<40oooo1@00
00020?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3oool000000?ooo`0500000480
oooo00380?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`000002
0?ooo`030000003oool0oooo0440oooo00380?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo000000130?ooo`00b03oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000<0oooo0P0000130?ooo`00_@3oool2000000X0oooo0P00
000:0?ooo`8000001@3oool00`000000oooo0?ooo`110?ooo`00^P3oool500000640oooo002h0?oo
o`8000000P3oool010000000ZKcX00000000001P0?ooo`00]@3oool3000000040?ooo`0000000000
00000080ZKcX0`00001O0?ooo`00/`3oool2000000040?ooo`000000000000000080ZKcX00<00000
0:Vlj02Y_>P00`00001O0?ooo`00/03oool3000000050?ooo`00000000000:Vmj00000000`2Y_>P4
000000030:Rli`000000000005h0oooo002]0?ooo`<000000P3oool2000000@0ZKgX00L000000:Vl
j0000000ZKcX0000002X_>L000000080Z;cW0P00001M0?ooo`00Z`3oool2000000030?ooo`000000
0000008000000P2Y_NP00`000000ZKgX0:Vmj003000000<0ZKcX0P000000102X_>L0000000000000
001M0?ooo`00O`3oool2000000@0oooo00<000000?ooo`3oool00`3oool3000001X0oooo1P000002
0:Vmj0040000002Y_NP0ZKgX0:Vmj0<000000P2Y_>P010000000ZKcX0:Vlj02Y_>P3000000<0Z;cW
0P00001K0?ooo`00OP3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01L0oooo
0P0000001@3oool000000000002Y_NP0000000@0ZKgX0`0000000`2Y_NP000000:Vlj0030:Vlj0<0
000000<0Z;cW0000000000000`2X_>L2000005/0oooo001n0?ooo`040000003oool0oooo000000L0
oooo1@00000E0?ooo`<0000000<0oooo000000000000102Y_NP00`000000ZKgX0:Vmj002000000@0
ZKgX00<000000:Vlj02Y_>P00P0000040:Rli`060000002X_>L000000000002X^nL00000F`3oool0
07h0oooo00@000000?ooo`3oool000001`3oool010000000oooo0?ooo`00000D0?ooo`80000000@0
oooo00000000000000000P2Y_NP00`000000ZKgX0:Vmj00400000080ZKgX00<000000:Vmj02Y_NP0
100000020:Rlj0030000002X_>L0Z;cW00<00000102X^nL00`000000oooo0?ooo`1H0?ooo`00OP3o
ool010000000oooo0?ooo`0000080?ooo`030000003oool000000140oooo0`0000001@3oool00000
0000002Y_NP0000000<0ZKgX0`0000020:Vmj0040000002Y_NP0ZKgX0:Vmj0<000000`2Y_>P00`00
0000Z;cX0:Rlj003000000040:Rki`000000Z;_W00000080Z;_W0P00001J0?ooo`00OP3oool01000
0000oooo0?ooo`0000090?ooo`8000003`3oool6000000@0ZKgX00D000000:Vmj0000000ZKgX0000
00040:Vmj0050000002Y_NP000000:Vmj0000000102Y_>P3000000060:Rli`000000Z;_W0:Rki`00
0000Z;_W0`0000000`2X^nL000000000001I0?ooo`00O`3oool2000000/0oooo00<000000?ooo`3o
ool02P3oool700000080ZKgX00<000000:Vmj02Y_NP00`0000030:Vmj0030000002Y_NP0ZKgX00<0
00000`2Y_NP01P000000ZKcX000000000000Z;cX000000<0Z;cW00H000000:Rki`00000000000:Rk
i`0000030:Rki`800000F03oool009L0oooo1@0000020:Vmj0040000002Y_NP0ZKgX0:Vmj0<00000
0P2Y_NP00`000000ZKgX0:Vmj00400000080ZKgX00<000000:Vmj02Y_NP00`0000040:Rlj0030000
002X_>L0000000<000000`2X^nL00`000000Z;_W00000002000005P0oooo002D0?ooo`<0000000@0
oooo0000002Y_NP00000102Y_NP01@000000ZKgX0000002Y_NP0000000<0ZKgX0`0000020:Vmj004
0000002Y_NP0ZKgX0:Vmj0<000000`2Y_>P00`000000Z;cX0:Rlj003000000<0Z;_W00<000000:Rk
i`2X^nL00`0000030:Nji`800000EP3oool00980oooo0P000000103oool000000000000000030:Vm
j0030000002Y_NP0ZKgX00<000000`2Y_NP01@000000ZKgX0000002Y_NP0000000@0ZKgX00D00000
0:Vmj0000000ZKgX000000040:Vlj0<0000000<0Z;cW0000002X^nL00`2X^nL3000000030:Nji`00
0000Yk[W00<0Yk[W0P00001F0?ooo`00S`3oool6000000<0ZKgX00<000000:Vmj02Y_NP00`000002
0:Vmj0030000002Y_NP0ZKgX00<000000`2Y_NP00`000000ZKgX0:Vmj003000000<0ZKgX00H00000
0:Vlj000000000000:Rli`0000030:Rli`030000002X^nL0000000<000000`2W^^L01P000000Yk[W
000000000000YkWV000005H0oooo002<0?ooo`<000000P3oool00`000000ZKgX000000040:Vmj0<0
00000P2Y_NP00`000000ZKgX0:Vmj003000000<0ZKgX00<000000:Vmj02Y_NP00`0000030:Vmj003
0000002Y_NP0ZKgX00800000102X_>L00`000000Z;cW0000000200000080Z;_W00@000000:Rki`00
0000Yk[W0`0000040:NiiP030000003oool0oooo05<0oooo002:0?ooo`8000000P3oool3000000<0
ZKgX00H000000:Vmj000000000000:Vmj00000030:Vmj0<0000000<0ZKgX0000002Y_NP00`2Y_NP3
00000080ZKgX00<000000:Vmj02Y_NP0100000020:Vlj0030000002X_>L0Z;cW00<000000`2X^nL0
0`000000Z;_W00000003000000<0YkWV00<000000:NiiP2W^NH00`00001D0?ooo`00Q`3oool30000
00040?ooo`0000000000000000<0ZKgX00<000000:Vmj02Y_NP00P0000040:Vmj0<0000000<0ZKgX
0000002Y_NP00P2Y_NP01P000000ZKgX000000000000ZKgX000000<0ZKgX0`0000020:Vmj0040000
002Y_>P0ZKcX0:Vlj0<0000000<0Z;_W0000002X^nL00`2X^nL3000000030:Nji`000000YkWV00<0
YkWV0`0000000`2W^>H000000000001D0?ooo`00Q@3oool2000000040?ooo`000000000000000080
ZKgX00<000000:Vmj02Y_NP0100000020:Vmj0030000002Y_NP0ZKgX00800000102Y_NP00`000000
ZKgX0:Vmj002000000@0ZKgX00D000000:Vmj0000000ZKgX000000040:Vmj0<0000000<0Z;cW0000
002X^nL00P2X^nL01@000000Z;_W000000000000Yk[W008000000P2W^^L01P000000YkWV00000000
0000YkWV000000<0YkSV0P00001C0?ooo`00PP3oool3000000050?ooo`00000000000:Vmj0000000
0`2Y_NP300000080ZKgX00<000000:Vmj02Y_NP0100000020:Vmj0030000002Y_NP0ZKgX00@00000
0P2Y_NP00`000000ZKgX0:Vmj003000000<0ZKgX00<000000:Vmj02Y_NP00P0000040:Rli`030000
002X^nL0Z;_W00800000102W^^L5000000@0YkWV00<000000:NhiP0000000`00001B0?ooo`00P03o
ool200000080oooo0P0000040:Vmj0050000002Y_NP000000:Vmj00000000`2Y_NP300000080ZKgX
00@000000:Vmj02Y_NP0ZKgX0`0000030:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000
ZKgX0:Vmj00400000080Z;cX00<000000:Rli`2X_>L0100000020:Rki`030000002W^^L0Yk[W00<0
00000`2W^NH00`000000YkWV0:NiiP03000000<0Y[OU0P00001A0?ooo`00O@3oool700000080ZKgX
00<000000:Vmj02Y_NP00`0000030:Vmj0050000002Y_NP000000:Vmj0000000102Y_NP01@000000
ZKgX0000002Y_NP0000000@0ZKgX0`0000000`2Y_NP000000:Vmj0020:Vmj0<000000`2Y_NP00`00
0000Z;cX0:Rlj00300000080Z;_W00<000000:Rki`2X^nL0100000020:NiiP030000002W^NH0YkWV
00@0000000<0Y[SU0000002V]nD00`2V]nD2000000l0oooo0P0000040?ooo`030000003oool0oooo
00<0oooo0P0000020?ooo`D00000;@3oool007/0oooo0P000000103oool000000000000000020:Vm
j0030000002Y_NP0ZKgX00<000000`2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX00<000000:Vm
j02Y_NP00`0000030:Vmj0060000002Y_NP000000000002Y_NP000000`2Y_NP01@000000ZKgX0000
002Y_NP0000000@0ZKgX0`0000000`2X_>L000000:Rki`020:Rki`<000000P2W^^L010000000YkWV
0:NiiP2W^NH300000080Y[SU00H000000:Jhi@2V^>D0Y[SU0000002V]nD2000000030:Jfi0000000
000000d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000002d0oooo001h0?ooo`<0000000D0oooo000000000000ZKgX000000030:Vmj0<0
00000P2Y_NP00`000000ZKgX0:Vmj00400000080ZKgX00<000000:Vmj02Y_NP00`0000030:Vmj003
0000002Y_NP0ZKgX00800000102Y_NP00`000000ZKgX00000002000000<0ZKgX00H000000:Vmj000
000000000:Rlj00000030:Rli`050000002X^nL000000:Nji`000000102W^^L00`000000YkWV0000
0002000000@0Y[SU00<000000:Jhi@0000000P0000040:Jfi0030000003oool0oooo00@0oooo1@00
00020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0]0?ooo`00MP3oool200000080oooo0P0000040:Vmj0050000002Y_NP000000:Vmj000
00000`2Y_NP300000080ZKgX00@000000:Vmj02Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX
00@000000P2Y_NP00`000000ZKgX0:Vmj003000000<0ZKgX00<000000:Vmj02Y_NP00P0000040:Rl
j0030000002X_>L00000008000000`2W^^L00`000000Yk[W0:Nji`03000000040:JhiP000000Y[SV
00000080Y[SU0`0000030:Jgi@030000002V]^@0Y[KT00<00000303oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0;03oool007<0oooo0`00
0000103oool000000000000000020:Vmj0030000002Y_NP0ZKgX00<000000`2Y_NP01@000000ZKgX
0000002Y_NP0000000@0ZKgX00D000000:Vmj0000000ZKgX000000030:Vmj0<000000P2Y_NP00`00
0000ZKgX0:Vmj00400000080ZKgX00<000000:Vmj02Y_NP0100000020:Vlj0030000002X_>P0Z;cX
00<000000`2X^nL00`000000Yk[W0:Nji`0300000080YkWV00<000000:JhiP000000100000020:Jg
i@030000002V]nD0Y[OU00@0000000@0Y[KT0000003oool000002`3oool010000000oooo0?ooo`00
00080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0[0?ooo`00
L03oool700000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<00000
0`2Y_NP00`000000ZKgX0:Vmj003000000<0ZKgX00D000000:Vmj0000000ZKgX000000030:Vmj0<0
00000P2Y_NP010000000ZKgX0:Vmj02Y_NP300000080ZKgX00<000000:Vlj02Y_>P0100000020:Rk
i`030000002X^nL0Z;_W00@000000P2W^NH00`000000YkWV0:NiiP0300000080Y[OU00@000000:Jg
i@2V]nD0Y[OU0`0000020:Jfi0040000002V]^@0Y[KT0:Jfi08000002`3oool010000000oooo0?oo
o`0000080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0[0?oo
o`00@P3oool2000000@0oooo00@000000?ooo`3oool0oooo1@00000M0?ooo`D000000P2Y_NP01000
0000ZKgX0:Vmj02Y_NP300000080ZKgX00<000000:Vmj02Y_NP00`0000030:Vmj0030000002Y_NP0
ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj003000000<0ZKgX00D000000:Vmj0000000ZKgX0000
00040:Vmj0050000002Y_NP000000:Vmj00000000`2Y_NP300000080Z;cX00@000000:Rki`2X^nL0
Z;_W0`0000020:Nji`040000002W^NH0YkWV0:NiiP<0000000<0Y[OU0000000000000`2V]nD30000
00030:Jfi0000000Y[KT00<0Y[KT00<000000:Jfi00000000`00000;0?ooo`8000002P3oool20000
00<0oooo0`00000^0?ooo`00@@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000001X0oooo0`000000103oool000000:Vmj00000040:Vmj0050000002Y_NP000000:Vmj0000000
0`2Y_NP300000080ZKgX00<000000:Vmj02Y_NP0100000020:Vmj0030000002Y_NP0ZKgX00<00000
0`2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX00<000000:Vmj02Y_NP00`0000030:Vmj0050000
002Y_NP000000:Vlj0000000102X_>P01@000000Z;_W0000002W^nL0000000@0Yk[W0`0000000`2V
^>H000000:Jgi@020:Jgi@030000002V]nD0Y[OU00800000102V]^@00`000000Y[KT0:Jfi0030000
0080Y[CS00<000000?ooo`000000C03oool00440oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0H0?ooo`8000000P3oool2000000<0ZKgX00<000000:Vmj02Y_NP00`0000030:Vm
j0050000002Y_NP000000:Vmj00000000`2Y_NP3000000<0ZKgX00<000000:Vmj02Y_NP00`000002
0:Vmj0030000002Y_NP0ZKgX00@000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<00000
0:Vmj02Y_NP00`0000030:Vlj0030000002X_>P0Z;cX00<000000`2W^nL00`000000Yk[W0:Nji`02
000000@0Y[SV00<000000:Jgi@0000000`0000020:Jfi0030000002V]^@0Y[KT00@0000000<0Y[CS
0000002V]><00P2V]><3000004`0oooo00110?ooo`040000003oool0oooo000000X0oooo00<00000
0?ooo`3oool0503oool700000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0
ZKgX00<000000`2Y_NP01@000000ZKgX0000002Y_NP0000000@0ZKgX0`0000000`2Y_NP000000:Vm
j0020:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00400000080ZKgX00<000000:Vmj02Y_NP00`00
00030:Vmj0030000002Y_>P0ZKcX00<000000P2X^nL00`000000Yk_W0:Nki`0400000080Y[WV00<0
00000:JhiP2V^>H00`000000102U]^@000000:Ffi00000020:Jfi0<000000P2U]><02`000000Y[CS
0:Jdh`2V]><000000:Jdh`000000Y[CR0000003oool0000004/0oooo00110?ooo`040000003oool0
oooo000000L0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`D000000`2Y_NP00`000000ZKgX
0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000030:Vmj0030000002Y_NP0ZKgX00800000
0`2Y_NP01P000000ZKgX000000000000ZKgX000000<0ZKgX00D000000:Vmj0000000ZKgX00000003
0:Vmj0<000000`2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP010000002
0:Rli`030000002X^nL0Z;_W00<000000P2W^NH00`000000Y[WV0:JiiP04000000060:Jfi@000000
YKKT0:Ffi0000000YKKT0`0000000`2U]><000000:Fdh`030:Fdh`030000002V]><0000000800000
0`2V]>82000004/0oooo00110?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo0000000@0?ooo`<0000000@0oooo0000002Y_NP00000102Y_NP300000080ZKgX00<000000:Vm
j02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00@000000P2Y_NP00`000000ZKgX0:Vmj0020000
00@0ZKgX00<000000:Vmj02Y_NP00P0000030:Vmj0050000002Y_NP000000:Vmj0000000102Y_NP3
000000030:Vmj0000000ZKgX0080ZKgX0`0000020:Vlj0030000002X_>L0Z;cW00@000000P2W^^L0
0`000000YkWV0:NiiP0300000080Y[OU00H000000:Jfi@2V]^D0Y[KU0000002U]^@2000000030:Fd
h`000000YKCS0080YKCS00<000000:Fdh`2U]><00`0000020:JchP030000002V]>80Y[CR00@00000
BP3oool00480oooo0P0000090?ooo`<000003`3oool2000000040?ooo`0000000000000000<0ZKgX
00H000000:Vmj000000000000:Vmj00000030:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj0030000
00<0ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00@000000P2Y_NP00`00
0000ZKgX0:Vmj002000000<0ZKgX00H000000:Vmj000000000000:Vmj00000030:Vmj0050000002Y
_NP000000:Vmj00000000`2Y_>P300000080Z;_W00@000000:Nji`2W^^L0Yk[W0`0000000`2V^>H0
00000:Jgi@030:Jgi@030000002V]^D0Y[KU00<000000`2U]><00`000000YKCS0000000300000080
YK?R00<000000:JchP2V/n800`0000020:JchP030000003oool0000004T0oooo001L0?ooo`<00000
00@0oooo00000000000000000P2Y_NP00`000000ZKgX0:Vmj002000000@0ZKgX00D000000:Vmj000
0000ZKgX000000030:Vmj0<0000000<0ZKgX0000002Y_NP00`2Y_NP300000080ZKgX00<000000:Vm
j02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00@000000P2Y_NP00`000000ZKgX0:Vmj0020000
00@0ZKgX00<000000:Vmj00000000P0000030:Vmj0050000002Y_>P000000:Rli`000000102X^nL0
1@000000Yk[W0000002V^NH0000000<0Y[SV00<000000:Jgi@2V]nD0100000020:Fdi080000000@0
YKCS00000000000000000P2U/n8010000000YK?R0:FchP2U/n83000000030:JchP000000Y[?R00<0
Y[?R0`0000180?ooo`00FP3oool600000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000
002Y_NP0ZKgX00<000000`2Y_NP01@000000ZKgX0000002Y_NP0000000<0ZKgX00H000000:Vmj000
000000000:Vmj00000030:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj003000000<0ZKgX00<00000
0:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<000000`2Y_NP00`000000ZKgX0:Vmj002
000000<0Z;cW00<000000:Rki`2X^nL00`0000030:JiiP030000002V^>H0Y[SV00<000000P2U]N@0
0`000000YKCT0:Fdi004000000030:FchP000000YK?R00<0YK?R0`0000000`2V/^4000000:JchP02
0:JchP030000002V/n80Y[?R0080000000<0oooo0000003oool0A`3oool005L0oooo1@0000030:Vm
j0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj003000000<0ZKgX00<000000:Vm
j02Y_NP00P0000030:Vmj0030000002Y_NP0ZKgX00800000102Y_NP01@000000ZKgX0000002Y_NP0
000000<0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00@000000P2Y_NP00`000000ZKgX0:Vmj003
00000080ZKgX00<000000:Vmj02Y_NP0100000020:Vlj0030000002X_>L0Z;cW00<000000P2W^^L0
0`000000Y[WV0:JiiP0400000080YKKU00<000000:Fei02U]N@00`0000020:Bch`050000002U/n80
YK?R0:FchP0000000P2U/n82000000@0Y[;Q00<000000:JchP0000000`0000020:Nch@030000003o
ool0000004L0oooo001E0?ooo`80000000@0oooo0000002Y_NP00000102Y_NP300000080ZKgX00<0
00000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00@000000P2Y_NP00`000000ZKgX0:Vm
j00300000080ZKgX00<000000:Vmj02Y_NP00`0000030:Vmj0050000002Y_NP000000:Vmj0000000
0`2Y_NP300000080ZKgX00@000000:Vmj02Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<0
00000P2Y_NP00`000000ZKcX0:Vlj00400000080Yk_W00<000000:Nji`2W^^L00`0000020:Fgi@03
0000002U]^D0YKKU00@0000000<0Y;?S0000002T/n<00P2T/n<2000000030:FchP00000000000080
00000P2U/^400`000000Y[;Q0:Jbh@0300000080Y[;Q00@000000:Nch@2W/n40Yk?Q0`0000170?oo
o`00DP3oool3000000030?ooo`000000000000<0ZKgX00H000000:Vmj000000000000:Vmj0000003
0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj003000000<0ZKgX00<000000:Vmj02Y_NP00`000002
0:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj003000000<0ZKgX00D00000
0:Vmj0000000ZKgX000000040:Vmj0<0000000<0ZKgX0000002Y_NP00P2Y_NP300000080ZKgX00<0
00000:Vmj02Y_NP00`0000020:Rli`030000002W^nL0Yk_W00@0000000<0Y[SV0000002U]nD00P2U
]nD300000080Y;?S00D000000:Bch`2T/n<0Y;?S000000020:Bch`<000000P2U/N400`000000YK;Q
0:Fbh@04000000030:Jah@000000Y[;Q00<0Y[;Q00L000000:Nch@000000Yk?Q0000003oool00000
04H0oooo001@0?ooo`80000000@0oooo00000000000000000P2Y_NP00`000000ZKgX0:Vmj0030000
00<0ZKgX00D000000:Vmj0000000ZKgX000000030:Vmj0<0000000<0ZKgX0000002Y_NP00`2Y_NP3
00000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<000000`2Y_NP0
0`000000ZKgX0:Vmj002000000<0ZKgX00<000000:Vmj02Y_NP00P0000040:Vmj0050000002Y_NP0
00000:Vmj00000000`2Y_NP3000000030:Vlj0000000Z;cW0080Z;cW0`0000020:JiiP090000002V
^>H0Y[SV0:JhiP000000YKOU0000002T]>@0000000@0Y;?S00<000000:Bch`0000001@0000030:Fa
h@<000000P2U/N001@000000Y[7Q0:Jah@2V/N4000000080Y[;Q0`0000030:Nch@030000003oool0
000004D0oooo001=0?ooo`H000000P2Y_NP00`000000ZKgX0:Vmj003000000<0ZKgX00<000000:Vm
j02Y_NP00P0000030:Vmj0050000002Y_NP000000:Vmj00000000`2Y_NP01P000000ZKgX00000000
0000ZKgX000000<0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX
0:Vmj00400000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<00000
0`2Y_NP01@000000ZKgX0000002Y_NP0000000<0ZKcX00D000000:Rli`000000Yk[W000000040:Ji
iP030000002V^>H0Y[SV008000000`2T]>@00`000000Y;?S0:Bch`0300000080Y;7Q00T000000:Ba
h@000000Y;7Q0000002U/N4000000:F`h0000000102U/N000`000000Y[7Q0:Jah@0300000080Yk;P
00<000000:Nch@2W/n40100000150?ooo`00BP3oool600000080ZKgX00<000000:Vmj02Y_NP00`00
00020:Vmj0030000002Y_NP0ZKgX00@000000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX00<0
00000:Vmj02Y_NP00P0000040:Vmj0050000002Y_NP000000:Vmj00000000`2Y_NP300000080ZKgX
00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00@000000P2Y_NP00`000000ZKgX
0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000030:Vmj0030000002Y_>P0ZKcX00800000
0`2W^^L00`000000Y[WV0:JiiP0400000080YKGT00<000000:Bdi02T]>@00`0000000`2S/N800000
0:Bah@030:Bah@80000000<0Y;7Q0000000000000`2U/>000`000000YK7P0:Fah004000000030:Ja
h0000000Yk;P0080Yk;P0`0000020:Rch0040000003oool00000000004<0oooo00180?ooo`D00000
00<0ZKgX0000002Y_NP00P2Y_NP300000080ZKgX00<000000:Vmj02Y_NP00`0000030:Vmj0030000
002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP0
0`0000030:Vmj0050000002Y_NP000000:Vmj00000000`2Y_NP300000080ZKgX00<000000:Vmj02Y
_NP00`0000030:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080
ZKgX00<000000:Vmj02Y_NP0100000020:Rki`030000002W^^L0Yk[W00<000000P2U]nD00`000000
YKGT0:Fei004000000030:>ahP000000Xk7R0080Xk7R00<000000:Bah@2T/N40100000020:B_h003
0000002U/>00YK3P00<000000P2V/=l02@000000Y[7P0:Jah02V/N0000000:Nbh0000000Z;;P0000
00040:Rch0030000003oool0000004<0oooo00150?ooo`D0000000<0ZKgX0000002Y_NP00P2Y_NP0
1@000000ZKgX0000002Y_NP0000000<0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00@000000P2Y
_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y
_NP0ZKgX00<000000`2Y_NP01@000000ZKgX0000002Y_NP0000000<0ZKgX0`0000020:Vmj0030000
002Y_NP0ZKgX00@000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP0
0`0000020:Vlj0030000002X^nL0Z;_W00@000000P2V^>H00`000000YKOU0:Fgi@0300000080Xk;S
00D000000:>ahP2S/N80Xk7R000000020:>ahP<000000P2T[ml00`000000Y:oP0:B_h00400000003
0:F_g`000000Y[3O00<0Y[3O00<000000:Jah00000000P0000030:Rbh0030000002X/n00Z;?P0080
000000<0oooo0000003oool0@P3oool004<0oooo0P000000103oool000000000000000030:Vmj003
0000002Y_NP0ZKgX008000000`2Y_NP01@000000ZKgX0000002Y_NP0000000<0ZKgX0`0000030:Vm
j0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vm
j02Y_NP00`0000030:Vmj0030000002Y_NP0ZKgX008000000`2Y_NP01@000000ZKgX0000002Y_NP0
000000<0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00@000000P2Y_NP00`000000ZKgX0:Vmj003
00000080ZKgX00<000000:Vlj02Y_>P00`0000020:Nji`030000002V^>H0Y[SV00@0000000<0Y;?T
0000002S/^<00`2S/^<00`000000Xk7R0000000300000080XjkP00<000000:B_g`2T[ml00`000002
0:B^gP050000002U[ml0YJoO0:F_g`0000000P2V/=l300000080Yk7O00<000000:Rbh02X/^001000
00020:Vdh0030000003oool000000480oooo00100?ooo`H000000`2Y_NP00`000000ZKgX0:Vmj003
00000080ZKgX00<000000:Vmj02Y_NP00P0000030:Vmj0050000002Y_NP000000:Vmj0000000102Y
_NP300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y
_NP00`000000ZKgX0:Vmj00400000080ZKgX00<000000:Vmj02Y_NP00P0000030:Vmj0050000002Y
_NP000000:Vmj00000000`2Y_NP300000080ZKgX00<000000:Vmj02Y_NP0100000020:Vmj0030000
002Y_NP0ZKgX00<000000P2X^nL00`000000Yk[W0:Nji`0300000080Y;GU00D000000:Bci02T/n@0
Y;?T000000020:>bh`<000000P2S[^000`000000XjkP0:>^h006000000@0Y:kN00<000000:F_g`00
00000`0000020:N`gP030000002W/Ml0Yk7O00<000000P2Y/ml010000000ZKCP0:Vdh02Y]>020000
00030?ooo`000000oooo0400oooo000n0?ooo`D000000`2Y_NP00`000000ZKgX0:Vmj00300000080
ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX008000000`2Y_NP01P000000
ZKgX000000000000ZKgX000000<0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP0
0`000000ZKgX0:Vmj003000000<0ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0
ZKgX008000000`2Y_NP01@000000ZKgX0000002Y_NP0000000<0ZKgX0`0000020:Vmj0040000002Y
_NP0ZKgX0:Vmj0<000000P2X_>P00`000000Z;_W0:Rki`03000000030:FgiP000000Y;GU00<0Y;GU
00<000000:Bci02T/n@00`0000020::_h@030000002S[^00XjkP00<000000P2S[=h01@000000Y:gN
0000002T[Mh000000080Y:kN0`0000020:J_gP040000002W/=h0Yk3N0:N`gP<0000000<0Z;7O0000
002Y/ml00`2Y/ml3000000040:Zeh0000000oooo00000440oooo000k0?ooo`D000000P2Y_NP00`00
0000ZKgX0:Vmj00400000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX
00<000000P2Y_NP00`000000ZKgX0:Vmj002000000@0ZKgX00D000000:Vmj0000000ZKgX00000003
0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP010000002
0:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX00D00000
0:Vmj0000000ZKgX000000040:Vmj0050000002Y_NP000000:Vmj00000000`2X_>P3000000030:Ji
i`000000YKOV0080YKOV00<000000:Bei@2T]ND0100000020::_h@030000002R[n40XZoQ00<00000
00<0XZcN0000002S[=h00`2S[=h6000000030:F]g@000000YZoN00<0YZoN0`0000000`2X/=h00000
0:Rag`020:Rag`030000002Y/ml0ZK?O00800000102Z]N000`000000oooo000000100?ooo`00>@3o
ool2000000040?ooo`000000ZKgX000000<0ZKgX0`0000030:Vmj0030000002Y_NP0ZKgX00<00000
0P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000
002Y_NP0ZKgX00<000000`2Y_NP01@000000ZKgX0000002Y_NP0000000<0ZKgX0`0000020:Vmj003
0000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00400000080ZKgX00<000000:Vmj02Y
_NP00`0000020:Vmj0030000002Y_NP0ZKgX008000000`2Y_NP00`000000ZKgX0:Vmj003000000<0
ZKgX00D000000:Rlj0000000Z;_W000000030:Jii`030000002U]nH0YKOV00<000000P2R/N800`00
0000XZoQ0::_h@04000000030:6[gP000000XZcN0080XZcN00<000000:>/gP2S[=h00`0000020:B/
g0050000002U[Md0YJgM0:F]g@0000000P2V[mh2000000@0Z;3N00<000000:Rag`0000000`000002
0:Zch0030000002Z]N00Z[GP0080000000<0oooo000000000000?`3oool001L0oooo0P00000M0?oo
o`H000000`2Y_NP00`000000ZKgX000000020:Vmj0040000002Y_NP0ZKgX0:Vmj0<000000P2Y_NP0
0`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0
ZKgX00<000000`2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX00D000000:Vmj0000000ZKgX0000
00030:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP01000
00020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<0
00000:Vmj02Y_NP00`0000030:Rki`030000002V^NL0Y[WW00<000000P2S/n@00`000000X[7R0::a
hP0300000080XJ_N00D000000:6[gP2QZmh0XJ_N000000020::/gP<0000000@0Xj_L0000002T[=`0
00000P2T[=`00`000000YJgM0000000300000080YjoM00<000000:R`gP2X/=h00`0000020:Vbg`04
0000002Z/n00Z[?P0:Zch0<000000P2[]^400`000000oooo000000090?ooo`800000=03oool001H0
oooo00@000000?ooo`3oool000006P3oool2000000040?ooo`000000000000000080ZKgX00<00000
0:Vmj02Y_NP00`0000030:Vmj0050000002Y_NP000000:Vmj00000000`2Y_NP300000080ZKgX00<0
00000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vm
j00400000080ZKgX00<000000:Vmj02Y_NP00P0000030:Vmj0050000002Y_NP000000:Vmj0000000
0`2Y_NP300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00@00000
0P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Rlj0030000
002X^nL0Z;_W00@000000P2T]^D00`000000Xk?T0:>ci003000000030:6/g`000000XJ_N00<0XJ_N
00<000000:6[gP0000000`0000000`2RZM/000000:>[g0020:>[g080000000@0Y:cL000000000000
00000P2V[M`010000000YjoM0:N_g@2W[md3000000030:VagP000000ZK;O00<0ZK;O0`0000000`2[
]N0000000:^fh@020:^fh@80000000<0oooo0000003oool01P3oool010000000oooo0?ooo`00000c
0?ooo`005P3oool010000000oooo0?ooo`00000G0?ooo`H000000P2Y_NP00`000000ZKgX0:Vmj003
000000<0ZKgX00<000000:Vmj02Y_NP00P0000030:Vmj0050000002Y_NP000000:Vmj00000000`2Y
_NP300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<000000`2Y
_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00P0000030:Vmj0050000002Y
_NP000000:Vmj00000000`2Y_NP300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000
002Y_NP0ZKgX00@000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Rlj02X_>P0
0`0000020:JhiP030000002T]^D0Y;KU00@0000000<0XJkQ0000002Q[=l00P2Q[=l00`000000XJ_N
0:6[gP0300000080XJSK00D000000::Yf`2RZM/0XZWK000000020:>[g0<0000000<0YJ_K0000002V
[M`00`2V[M`3000000030:R_g@000000ZK7N0080ZK7N00<000000:Vbg`2Y/]l00P0000040:^eh0<0
000000@0[;SR0000003oool000001`3oool010000000oooo0?ooo`00000c0?ooo`005P3oool01000
0000oooo0?ooo`00000E0?ooo`D000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<00000
0:Vmj02Y_NP0100000020:Vmj0030000002Y_NP0ZKgX008000000`2Y_NP01@000000ZKgX0000002Y
_NP0000000<0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vm
j00400000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX008000000`2Y
_NP01@000000ZKgX0000002Y_NP0000000<0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<00000
0P2Y_NP00`000000ZKgX0:Vmj00400000080ZKgX00<000000:Vmj02Y_NP00`0000020:Nki`030000
002V^>H0Y[SV00<000000P2R/>801@000000XJkQ0:6^h@2Q[^4000000080XJcO0`0000000`2PYm/0
00000:6Xf`030:6Xf`030000002RZM/0000000<0000000<0Y:WJ0000002UZm/00P2UZm/00`000000
YZgL0:J]g002000000@0Z:oM00<000000:VagP0000000`0000020:^dg`030000002[]N00ZkGP0080
0000102/^>800`000000oooo000000060?ooo`040000003oool0oooo000003<0oooo000F0?ooo`04
0000003oool0oooo00000180oooo1@0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`00
0000ZKgX0:Vmj003000000<0ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX
008000000`2Y_NP00`000000ZKgX000000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`00
0000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP0100000020:Vmj0030000002Y_NP0ZKgX
00<000000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX00D000000:Vmj0000000ZKgX00000003
0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP010000002
0:Rlj0030000002W^nL0Yk_W00<0000000<0Xk?T0000002R/>800`2R/>800`000000XJkQ00000003
0000000309nWf`000000X:OK0080X:OK00<000000:6Xf`2QZ=/00`0000020:>Wf@030000002TZMX0
Y:WJ008000000P2UZm/300000080Z:kL00<000000:R_g@2X[md00`0000020:^bgP030000002[]=l0
ZkCO00@000000P2/]n400`000000[;SR0:bhhP0200000080oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`00000c0?ooo`005P3oool010000000oooo0?ooo`00000?0?ooo`D000000P2Y
_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000030:Vmj0030000002Y
_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00P00
00030:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`00
00030:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<0
00000:Vmj02Y_NP00P0000030:Vmj0050000002Y_NP000000:Vmj00000000`2Y_NP300000080ZKgX
00<000000:Vmj02Y_NP00`0000020:Vmj0030000002X_>P0Z;cX00@0000000<0YKOV0000002S/n@0
0P2S/n@00`000000X[3R0::`hP0300000080WZOL00D0000009nWf`2OYm/0WjOK000000020:2Wf`<0
000000<0XZKH0000002SYmT00`2SYmT00`000000Y:WJ00000003000000030:N/f`000000Z:kL0080
Z:kL0`0000000`2Z/Md000000:^bgP020:^bgP<000000P2/]^0010000000[;OQ0:bgh@2/]n430000
0080[KWR00<000000?ooo`0000001@3oool010000000oooo0?ooo`00000c0?ooo`005`3oool20000
00h0oooo0P000000103oool000000:Vmj00000030:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj003
000000<0ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP0
0`000000ZKgX0:Vmj00300000080ZKgX00D000000:Vmj0000000ZKgX000000030:Vmj0<000000P2Y
_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP0100000020:Vmj0030000002Y
_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00P00
00030:Vmj0050000002Y_NP000000:Vmj00000000`2Y_NP300000080ZKgX00<000000:Vmj02Y_NP0
0`0000020:Nki`050000002U]nH0YKOV0:FgiP0000000P2S/n@30000000309nYgP000000WZOL00<0
WZOL00<0000009nWf`0000000`0000000`2PY=P000000::Vf0020::Vf0030000002SYmT0XjOI00@0
000000<0YZWI0000002W[=/00P2W[=/01@000000Z:kL0000002Y[m`0000000<0Z[7M00D000000:^b
gP000000[;CO000000040:bfh0<0000000<0[KWR0000002]^N800P2]^N85000000@0oooo0P00000d
0?ooo`00903oool3000000030?ooo`000000000000<0ZKgX00D000000:Vmj0000000ZKgX00000003
0:Vmj0<000000`2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`000002
0:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX00D00000
0:Vmj0000000ZKgX000000030:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<0
00000:Vmj02Y_NP0100000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vm
j00300000080ZKgX00<000000:Vmj02Y_NP00P0000030:Vmj0050000002Y_NP000000:Vmj0000000
0`2Y_NP300000080ZKcX00<000000:Nki`2W^nL01`00000209n/h0040000002OZMh0WjWN00000080
WZOL0`00000209nRe`050000002PY=P0X:CH0:2Tf00000000P2RY]P3000000040:FWf00000000000
00000080YZWI00<000000:N/f`0000000P0000030:V_g0030000002Z/Md0Z[7M008000000`2/]=l0
0`000000[;KP0:bfh002000000@0[KWR0`0000001@2^_>@000000?ooo`3oool0000003X0oooo000R
0?ooo`80000000@0oooo00000000000000000P2Z_NL00`000000ZKgX0:Vmj00300000080ZKgX00<0
00000:Vmj00000000`2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`00
00020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<0
00000:Vmj02Y_NP00P0000030:Vmj0050000002Y_NP000000:Vmj00000000`2Y_NP300000080ZKgX
00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00@000000P2Y_NP00`000000ZKgX
0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00800000
0`2Y_NP00`000000ZKgX000000020:Vmj0030000002Y_>P0ZKcX00<0000000<0Y;KU0000002R/N<0
0P2R/N<00`000000WjcP09n/h0070000000309fQe`000000Wj;G00<0Wj;G00<000000:2Tf0000000
0`0000000`2SY=H0000000000004000000040:JYf@000000000000000080ZJgJ00<000000:V_g02Y
[m`010000000102//mh000000:bdg`2/]=l400000080[KSQ00<000000:fihP2]^N800P0000040:jl
i0030000003oool0000003X0oooo000O0?ooo`H000000P2Z_NL00`000000Z[gW0:Zmi`03000000<0
Z[gW00<000000:Vmj00000000P0000030:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00300000080
ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000
ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00P0000030:Vmj0050000002Y_NP000000:Vm
j00000000`2Y_NP300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX
00@000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vm
j0030000002Y_NP0ZKgX008000000`2Y_NP3000000030:Nji`000000Y;KU0080Y;KU00<000000::a
h`2R/N<00`00000209bSfP040000002LXMP0W:7H000000<0WJ7G00<0000009nRe`2OX]L00`000002
0:6Re@D0000000<0YJOH0000000000000P0000000`2XZmT000000:V]fP020:V]fP<000000P2//M`0
0`000000[;?N0:bcgP0300000080[[OP00<000000:fhh@2]^>40100000020:jkh`030000002^_>@0
[[cT008000000P3oool00`000000oooo0?ooo`0g0?ooo`007P3oool400000080Z[gW00<000000:Zm
i`2Z_NL00`0000030:Zmi`030000002Z_NL0Z[gW008000000`2Z_NL01@000000ZKgX0000002Z_NL0
000000<0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj003
00000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP0
0`000000ZKgX0:Vmj002000000<0ZKgX00<000000:Vmj00000000P2Y_NP00`000000ZKgX0:Vmj003
00000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00@0000000@0ZKgX
0000002Y_NP0ZKgX100000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP01@000000ZKgX0000
002Y_NP0000000<0Yk[W00<000000:Bfi@2T]^D00`0000000`2LY]`0000009bSfP0209bSfP050000
002LXMP0W:7H09bQf00000000P2MXML30000000309nOd`000000XJ;E00@0000000@0XjCF00000000
000000000P2WZ=L02@000000Z:_I0000002XZmT000000:V]fP000000ZjoK000000040:bag0800000
00<0[[KO0000002^]n000P2^]n0300000080[k_R00<000000:jkh`2^^n<0100000000`2__^D00000
0?ooo`020?ooo`030000003oool0oooo03H0oooo000M0?ooo`<000000P2Z_NL00`000000Z[gW0000
0002000000<0Z[gW00<000000:Zmi`2Z_NL00`0000020:Zmi`030000002Z_NL0Z[gW008000000`2Z
_NL01@000000ZKgX0000002Z_NL0000000<0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<00000
0P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000
002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX0`0000020:Vmj0030000
002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP0
0`0000020:Vmj0030000002Y_NP0ZKgX00@000000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX
00<000000:Nji`2W^^L00`0000000`2O[>00000009bVg00209bVg0060000002LXmX0W:?J09bSfP00
0000W:7H100000000`2MW=80000009nOd`0300000080XJ;E0`0000000`2UYMD000000:NXe`030:NX
e`030000002XZmT00000008000000`2[[m/00`000000[;7L0:bag002000000<0[[KO00D000000:jg
h0000000[k[R000000030:nkhP<000000P2__^D00`000000[kkU0:nni@0200000080oooo00<00000
0?ooo`3oool0=P3oool001H0oooo0P0000060?ooo`8000000P2Z_NL2000000<0Z[gW00<000000:Zm
i`2Z_NL00`0000020:Zmi`030000002Z_NL0Z[gW00<000000P2Z_NL00`000000Z[gW0:Zmi`020000
00<0Z[gW00D000000:Vmj0000000Z[gW000000030:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj003
00000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP0
0`000000ZKgX0:Vmj00300000080ZKgX00D000000:Vmj0000000ZKgX000000030:Vmj0<000000P2Y
_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y
_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj004000000040:Vmj0000000ZKgX0:Vmj0@00000
0P2S]>@010000000WjcP09n/h000000209bVg0H000000P2KV]800`000000WIcB0000000200000080
WioC0`0000000`2TX]<000000:FUe@020:FUe@030000002WZ=L0YjSG00@0000000@0ZjgI0000002[
[m/0ZjoK100000020:jdgP030000002^]]l0[[KO008000000`2_^^801@000000[k_R0000002`_^@0
000000<0[kkU0`0000020:o0iP030000003oool0oooo00800000=P3oool001D0oooo00@000000?oo
o`3oool000001@3oool010000000oooo0000000000020:Zli`030000002Z_NL0Z[gW00<000000P2Z
_>L00`000000Z[gW0:Zmi`0300000080Z[gW00<000000:Zmi`2Z_NL00`0000020:Zmi`030000002Z
_NL0Z[gW008000000`2Z_NL00`000000ZKgX000000020:Zmi`030000002Y_NP0ZKgX00<000000P2Y
_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y
_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX00D000000:Vmj0000000ZKgX
000000030:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP0
0`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080Yk[W
00<000000:>di02S]>@01`0000001@2HV]<0000009VIdP2IVM8000000080Vi[B0`0000000`2MW=80
000000000002000000030::Nd@000000Y:;C0080Y:;C00<000000:FUe@2UYMD00`000000102ZZmL0
00000:^]f@2[[MT400000080[[?L00@000000:jdgP2^]=h0[[CN0`000000102_^N4000000:njhP2_
^^83000000<0/;kT00D000000:nni@000000/<7V000000020:o0iP<000000P3oool00`000000oooo
0?ooo`0d0?ooo`005@3oool010000000oooo0?ooo`0000040?ooo`8000000P3oool00`000000Z[cW
0:Zli`0300000080Z[cW00<000000:Zli`2Z_>L00`0000020:Zli`030000002Z_NL0Z[gW00<00000
0P2Z_NL00`000000Z[gW0:Zmi`0300000080Z[gW00<000000:Zmi`2Z_NL00P0000030:Zmi`<00000
0P2Z_NL00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000
002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP0
0P0000030:Vmj0030000002Y_NP000000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000
002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP0
0`0000020:Vmj0030000002W^^L0Yk[W00<000000P2KYM`010000000V9gG09RMe`00000309RJd`03
0000002IVM80VIWB0080000000@0Vi[B00000000000000000P2OV/l010000000XYkA0::Nd@000003
0:BRd`<0000000<0Z:OE0000002ZZmL00P2ZZmL00`000000ZjgI00000002000000@0[[?L0`000000
102`^>0000000:nih@2_^N4300000080/;gT00<000000;2ni02`_^@00`0000020;31iP<000000P2_
`nP010000000oooo0?ooo`00000f0?ooo`005@3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0080oooo0P0000020:ZliP030000002Z_>L0Z[cW00<000000P2Z_>H00`000000Z[cW
0:Zli`0300000080Z[cW00<000000:Zmi`2Z_NL00`0000020:Zli`030000002Z_NL0Z[gW00<00000
0P2Z_NL01@000000Z[gW0000002Z_NL0000000<0Z[gW0`0000020:Zmi`030000002Y_NP0ZKgX00<0
00000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj003
0000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX0`0000020:Vmj003
0000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y
_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<0000000<0XK3S0000002KYM`00`2KYM`010000000
V9gG09RMe`00000209RJd`H0000000<0W9K=0000002OV/l00P2OV/l010000000XYkA0::Nd@2RW]43
000000030:NTdP000000Z:OE0080Z:OE00<000000:Z[e`2ZZmL00P000000102]/M/000000:faf`00
00020:jcg0800000102`^>0200000080/KgS00<000000;2mi02`_N@00`0000020;31iP030000002`
`NH000000080/<?X00<000000:o3j02_`nP00P0000020?ooo`030000003oool0oooo03<0oooo000E
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool010000000Z[cV0:Zl
iP2Z_>H300000080ZkcV00<000000:ZliP2Z_>H00`0000020:ZliP030000002Z_>L0Z[cW00<00000
0P2Z_>H00`000000Z[cW0:Zli`0300000080Z[cW00<000000:Zmi`2Z_NL00P0000030:Zmi`030000
002Z_NL000000080Z[gW00<000000:Zmi`2Z_NL00`0000020:Zmi`030000002Y_NP0ZKgX00<00000
0P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000
002Y_NP0ZKgX00<000000P2Y_NP01@000000ZKgX0000002Y_NP0000000<0ZKgX0`0000020:Vmj003
0000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y
_NP00`0000020:Jji`040000002Q/><0XK3S00000080VjGL2P0000000`2ITL/0000009bFc@0209bF
c@060000002OV/l0Wi[?09nJc`000000XYkA0P0000030:NTdP040000002XYmD0Z:OE0:RWe@<00000
00@0[JkI0000002]/M/0[K7K100000020;2ggP030000002`^>00/;SP008000000`2a_N<300000080
/L7V00<000000;31iP2``NH00P0000030;33j0<000000P2_aNX010000000oooo0?ooo`00000d0?oo
o`005@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000:Zl
iP0000000P2[_>H00`000000ZkcV0:^liP0300000080ZkcV00<000000:ZliP2Z_>H00`0000020:^l
iP030000002Z_>H0Z[cV00<000000P2Z_>H00`000000Z[cW0:Zli`0300000080Z[cW00<000000:Zm
i`2Z_NL00P0000030:Zmi`<000000P2Z_>L00`000000Z[gW0:Zmi`0300000080Z[gW00<000000:Vm
j02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj0030000
0080ZKgX00<000000:Vmj02Y_NP00P0000030:Vmj0030000002Y_NP000000080ZKgX00<000000:Vm
j02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj0030000
0080ZKgX00<000000:Jji`2V^^L01P0000000`2BT<h0000000000002000000<0UXk:00D0000009VA
b`2ITL/0VI7;0000000209bFc@030000002OV/l0Wi[?00<0000000<0YIo@0000002WY=800`2WY=83
000000030:b/eP000000[JkI0080[JkI00<000000:faf`0000000P0000030;2ggP<000000P2a_N80
1@000000/KgS0000002b`NH000000080/L7V100000020;74j0050000002``nP000000;36jP000000
0P2_aNX3000000030?ooo`000000oooo03<0oooo000F0?ooo`800000103oool2000000H0oooo00@0
00000:^liP2[_>H0ZkcV0`0000020:^liP030000002[_>H0ZkcV00<000000P2[_>H00`000000ZkcV
0:^liP0300000080ZkcV00<000000:ZliP2Z_>H00`0000020:^liP030000002Z_>L0Z[cW00<00000
0P2Z_>H01@000000Z[gW0000002Z_>H0000000<0Z[cW0`0000020:Zli`030000002Z_NL0Z[gW00<0
00000P2Z_NL00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj003
0000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj002000000<0ZKgX0`0000020:Vmj003
0000002Y_NP0ZKgX00<000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vm
j0@0000000@0WZ_P0000002FV]H0UY[F0`0000001@2BT<h0000009>=b`2CSL/000000080UXk:00D0
000009VAb`2ITL/0VI7;0000000209bFc@<0000000<0Xi[=0000002UWm000P2UWm000`000000YjCB
0:NTdP02000000@0[:cF00<000000:f^f@0000000P0000020;2fg@@0000000@0/[cQ0000002a_N80
/KgR0`0000020;;1iP<000000P2aaNP00`000000/LCX0;74j00300000080/<KZ0`0000020:o7k003
0000003oool0oooo00800000<P3oool001d0oooo00<000000?ooo`3oool01@3oool01@000000ZkcV
0000002[^nH0000000<0ZkcV0`0000020:^kiP030000002[_>H0ZkcV00<000000P2[^nH00`000000
ZkcV0:^liP0300000080ZkcV00<000000:^liP2[_>H00`0000020:^liP030000002Z_>H0Z[cV0080
00000`2Z_>H00`000000Z[cW000000020:^liP030000002Z_>L0Z[cW00<000000P2Z_>L00`000000
Z[gW0:Zmi`0300000080ZKgW00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<0
00000P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00D000000:Vmj0000000ZKgX000000020:Vm
j0@0000000@0ZKgX0000002Y_NP0ZKgX10000000102Y_NP000000:Vmj02Y_NP300000080Y[WW00<0
000009j[h02NZn000`0000001@2FV]H0000009:@cP2BT<h000000080Thg;00H0000009J>bP2FS/X0
UXk:0000002ITL/40000000309nEb@000000Xi[=0080Xi[=00<000000:FOd02UWm000`0000020:^X
d`030000002/[=H0[:cF00<000000P2`]=/00`000000/;KM0;2fg@02000000<0/[cQ0`0000020;?2
i@030000002b`NH000000080//GX00<000000;75j02aaNP00`0000020;37j`030000002`a^X00000
0080[lS/00<000000:o7k02_an`00P0000000`3oool000000000000b0?ooo`00703oool00`000000
oooo0?ooo`070?ooo`090000002[^nH0Zk_V0:^kiP000000ZkcV0000002[^nD0000000<0Zk_V0`00
00020:^ki@030000002[^nH0Zk_V00<000000P2[^nD00`000000ZkcV0:^liP0300000080Zk_U00<0
00000:^liP2[_>H00`0000020:^kiP030000002Z_>H0Z[cV008000000`2[_>H300000080ZkcV00<0
00000:Zli`2Z_>L00`0000020:Zli`030000002Y_NL0ZKgW00<000000P2Y_NL00`000000ZKgX0:Vm
j00300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y
_NP300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00<000000P2Y
_NP00`000000Y[WW0:Jii`030000000509j[h0000000UY[F09JJeP0000000P2BT<h900000080Vho5
00D0000009nEb@2OULT0WiG9000000020:>Jc@<0000000<0ZZC@0000002[Z=<00P2[Z=<300000003
0;2bf@000000/;CK0080/;CK0`0000001@2c_>0000000000002b_>4000000080]<;U00<000000;?2
i@2c`^D00P0000030;;5j0<000000P2ab>/00`000000/<O[0;37j`0200000080[lS/100000001@2^
b>d000000?ooo`3oool000000380oooo000L0?ooo`8000002@3oool00`000000Zk_V0:^kiP020000
00<0Zk_U00<000000:^kiP0000000P2[^nD00`000000Zk_U0:^ki@0300000080Zk_U00<000000:^k
i@2[^nD00`0000020:^ki@030000002[^nD0Zk_U00<000000P2[^nD00`000000Zk_V0:^kiP030000
0080Zk_U00D000000:^liP000000Zk_U000000030:^liP<000000P2[^nH00`000000Z[cW0:Zli`03
00000080Z[cW00<000000:Vmi`2Y_NL00`0000020:Vmi`030000002Y_NP0ZKgX00<0000000@0ZKgX
0000002Y_NP0ZKgX10000000102Y_NP000000:Vmj00000020:Vmj0030000002Y_NP0ZKgX00<00000
0P2Y_NP00`000000ZKgX0:Vmj00300000080ZKgX00<000000:Vmj02Y_NP03@0000001@2=O[h00000
09:3_`2BPkl000000080UhS200D0000009^?a@2KSlD0Vho50000000309nEb@050000002SV/d00000
0:ROc@0000000`2ZY=001@000000ZjSC0000002`[mL0000000<0/;;I00<000000;2df`0000000P2d
^ml00`000000/kcP0;>lh002000000<0]<;U0`0000020;?6j0050000002baNP000000;;9k0000000
0P2ab>/4000000040;39k@000000000000000080[/[^00<000000:k8k@2^b>d00`0000000`3oool0
00000?ooo`0`0?ooo`00703oool00`000000oooo0?ooo`090?ooo`8000000P2[^nD00`000000Zk_U
0:^ki@02000000<0Zk_U0`0000020:^ji0030000002[^nD0Zk_U00<000000P2/^^@00`000000Zk_U
0:^ki@0300000080[;[T00<000000:^ki@2[^nD00`0000020:^ki0030000002[^nD0Zk_U00800000
0`2[^nD00`000000ZkcV000000020:^ji0030000002[^nH0Zk_V00<000000P2[^nD00`000000Z[cW
0:Zli`0300000080Z[cW00<000000:Vmi`2Y_NL00`000000102Y_NP000000:Vmj02Y_NP300000080
ZKgX00<000000:Vmj02Y_NP00P0000030:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00300000080
ZKgX00<000000:Vmj02Y_NP01@00000209RPfP040000002=R<T0SHS9000000<0Rgk000D0000008en
_P2=O[h0SGjn0000000209:3_`040000002GR<80UhS2000000<0Vho500<0000009nEb@0000000P00
00020:ROc@040000002ZY=00ZZC@0:ZTd08000000`2`[mL00`000000/;;I0;2bf@02000000<0];_O
1@0000001@2d`^D000000000002db>T000000080/lKX0`0000020;;9k0<000000P2`bnd00`000000
/<W]000000020:k;k`030000002^b^h0[/[^00<000000P2]b^l300000340oooo000L0?ooo`030000
003oool0oooo00/0oooo00<000000:^ki@0000000P0000020:^ki@050000002[^nD000000:bji000
00000`2[^^@300000080[;[T00<000000:bji02/^^@00`0000020:bji0030000002/^^@0[;[T00<0
00000P2/^^@00`000000Zk_T0:^ki00300000080[;[T00<000000:^ki@2[^nD00P0000030:^ji0<0
00000P2/^^@00`000000Zk_U0:^ki@0300000080Zk_U00<000000:Zli`2Z_>L00`000000102Z_>H0
00000:Vmj02Y_NP300000080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP00000
0080ZKgX00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0ZKgX00@0000000D0ZKgX0000
002V^NH0Y[WV0000000209RPfP040000002=R<T0SHS900000080Rgk000D0000008en_P2=O[h0SGjn
0000000209:3_`040000002GR<80UhS200000080Vho50`0000020:FIb0040000002XWld0Z9o=0:RO
c@<0000000<0/:cC0000002`[mL00P2`[mL3000000030;Bjg@000000];_O0080000000@0]/?T0000
002e`n@0]L?T0P0000030;C8j@<000000P2cbn`00`000000//W/000000020;7=kP030000002`bnd0
/<_]008000000P2^bnl4000000030:g;k`000000[L[_0080000000@0[<[`0000003oool00000<03o
ool001`0oooo00<000000?ooo`3oool0303oool01P000000Zk[T0:^ji02[^^@000000:^ki@800000
0`2/^^@01@000000Zk[T0000002/^^@0000000<0[;[T0`0000020:bih`030000002/^^@0[;[T00<0
00000P2/^N<00`000000[;[T0:bji00300000080[;WS00<000000:bji02/^^@00`0000020:bih`05
0000002[^^@000000:bhhP0000000`2/^^@300000080[;WS00<000000:^ki@2[^nD00`000000102[
^^@000000:ZliP2Z_>H300000080Z[cV00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP0
ZKgX008000000`2Y_NP300000080ZKgX00<000000:Vmj02Y_NP010000000102Y_NP000000:Vmj02Y
_NP700000080SHS900D0000008]n`02;O/00Rgk00000000208en_P040000002BPkl0TX>o00000080
UhS20`0000000`2RTL@000000:FIb0030:FIb0040000002XWld00000000000@0/:cC0`000000102f
^=/000000;Bjg@2d^]d2000000<0]/?T0`0000001@2fbNT000000000002db>T000000080]<g]00<0
00000;?;k02cbn`00P0000020;7=kP@0000000@0[lg`00000000000000000P2]cO000`000000[L__
0:g;k`0300000080[<[`0P0000000`3oool000000000000^0?ooo`006`3oool2000000l0oooo00<0
00000:^ji02[^^@00P0000020:bji0030000002/^^@0[;[T008000000`2/^^@01@000000[;[T0000
002/^N<0000000<0[;WS0`0000020:bihP030000002/^N<0[;WS00<000000P2/^>800`000000[;WS
0:bih`0300000080[KSR00<000000:bih`2/^N<00P0000030:bhhP050000002/^^@000000:fgh@00
00000`2/^N<3000000040:bhh@000000Zk[T0:^ji0<000000P2[^N@00`000000Z[cV0:ZliP030000
0080Z[cV00<000000:Vmj02Y_NP00`0000020:Vmj0030000002Y_NP000000080ZKgX00<000000:Vm
j02Y_NP010000000102Y_NP000000:Vmj02Y_NP3000000050:Ffi0000000Sh[908n:b@0000000P22
K[<70000000308en_P000000000000D0000000<0WHVn0000002RTL@00P2RTL@00`000000YIW80:FI
b003000000030:nWd0000000/:cC0080/:cC0P0000040;Jhf`8000000P2h`n<00`000000]/?T0000
00020;O;j@030000002fbNT0]/WY008000000P2dcNd4000000040;7?k`000000000000000080[loa
00<000000:o=l00000000P2]c_400`000000[Lg`0:g=l003000000030:c<l@000000000000800000
00@0Z/_a0000003oool000002@3oool2000000@0oooo00<000000?ooo`3oool00`3oool200000080
oooo1@00000A0?ooo`006`3oool00`000000oooo0?ooo`0?0?ooo`8000000P2/^^@00`000000[;[T
0000000200000080[;WS00<000000:bji02/^^@00P0000030:bih`050000002/^N<000000:bhhP00
00000`2/^N8300000080[KSQ00<000000:bhhP2/^>800`0000020:fgh@030000002]^>80[KSR00<0
00000P2]]n000`000000[;SR0:bhhP02000000<0[KOQ00D000000:bih`000000[[GN000000020:bh
h@<000000P2]]]l00`000000ZkWT0:^ii00300000080ZkSR00<000000:ZliP2Z_>H00`0000020:Vk
iP030000002Y_NP0ZKgX00<000000P2Y_NP500000080ZKgX100000001@2Y_NP000000:Ffi02U]^@0
00000080Sh[900@00000089^/`22K[<000000P23JZh00`000000RFn_08U_[`0200000080T7Rd00@0
000009N1^@2GPKT000000`2MRKh020000000XY740::Aa0000000YIW80000002]X//000000`2_Ym00
0`000000/:cC000000020;Jgf@030000002f^=/0][SK008000000`2h`n<2000000<0]l_Y1`000002
0;;Al0030000002acnl000000080[m7b00<000000:o?l@2_co400P0000020:g>l@@0000000@0Zlgb
00000000000000000P2Zc?400`000000Z/_a0:[;l@02000000030?ooo`000000oooo00H0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0140oooo000K0?ooo`030000003oool0oooo0100oooo00<000000:bji02/^^@00P0000030:bih`03
0000002/^N<00000008000000P2/^N<00`000000[;WS0:bih`02000000<0[;SR00D000000:bihP00
0000[KOQ000000030:fhh@<000000P2]]n000`000000[KOQ0:fgh@0300000080[KKO00<000000:fg
h02]]n000`0000020:jfgP030000002]]n40[KOQ008000000`2^]Mh2000000030:jbf`000000[KKO
0080[KKO0`0000020:fcg@030000002[^>80ZkSR00<000000P2[]^400`000000ZK_V0:VkiP030000
0080ZK_V1@0000020:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00500000080Sh[900<00000089^
/`0000000P23JZh010000000RFn_08U_[`000003091h]0050000002GPKT0Uh6i09N1^@0000000P2M
RKh00`000000XY740::Aa002000000<0[J;;00<000000:nWd02_Ym000P0000030;Jgf@<000000P2j
a>801P000000^<?S0000002ic^T000000;O;j@80000000<0]]?_0000002ed>h00P000000102beO80
00000;;Al02bdO0200000080[m7b10000000102]d?<000000000000000020:_?l`<000000P2YcO<0
0`000000Z/ca0:[<l@03000000050:W:l@00000000000?ooo`0000001P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool04@3oool001/0oooo
0P00000B0?ooo`8000000P2/^N<00`000000[;WS0:bih`0200000080[;WS00<000000:bih`2/^N<0
0`0000020:bhhP030000002/^>80[;SR008000000`2]]n401@000000[KSQ0000002]]^00000000<0
[KOP0`0000020:jegP030000002]]]l0[KKO00<000000P2^]=d00`000000[[KN0:jfgP0300000004
0:jcg0000000[[GN0:jegP8000000`2^/]/01@000000[KKO0000002_[]L0000000<0[K?M0`000002
0:f^f0030000002[]^40ZkKQ00<000000P2Z/]h00`000000ZK_V0000000200000080ZK_V0`000002
0:Vji@030000002Y_NP0ZKgX00<0000000@0WY?700000023HjD0Pf>U0P0000001@2?R/T00000089^
/`22K[<000000080PfZ^00@0000008U_[`29Kjl000000P2@N;@01@000000Uh6i09N1^@2GPKT00000
0080WHVn0`0000000`2[VlH000000:fRb`020:fRb`<000000P2g]=H01@000000][OI0000002laN40
00000080^/CR0`0000020;W>j@<000000P2fdnl3000000030;;ElP00000000000080000000@0[mCc
00000000000000000P2/do@300000080Z]7d00D000000:_?l`000000ZLod000000020:W=l`@00000
00@0Z<_b00000000000000000P2Xb_42000000H0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0100oooo000K0?ooo`030000003oool0oooo
0180oooo00<000000:bih`2/^N<00`0000020:bhhP030000002/^N<00000008000000P2/^>800`00
0000[;SR0:bhhP0300000080[KOQ00<000000:fgh@2]]n400P0000030:ffh0050000002]]n000000
0:fegP0000000`2^]Mh300000080[[?L00<000000:jdg@2^]=d00`000000102_/]X000000:jcg02^
/m`300000080[k3I00<000000:jbf`2^/]/00P0000030:n^e`050000002]/md000000:nXd@000000
0`2][]P300000080[JOA00<000000:ZbgP0000000P0000030:V/f@8000000P2VW</00`000000ZK[U
0:Vji@03000000050:BKc0000000WY?709jCa`0000000P23HjD010000000NUFK000000000002089^
/`0400000023JZh0PfZ^00000080RFn_00D00000091h]02@N;@0T7Rd0000000209N1^@050000002M
RKh000000:NB`00000000`2[VlH01@000000[J;;0000002g/=80000000<0]kCF0P0000020;c5h@<0
00000P2kdNX300000080^=O`0`0000000`2cfO<000000000000600000080ZmKf0`000000102YdoH0
00000:[Am02ZdO@300000080ZLod0`0000020:S=l`<0000000@0Yl_b0000002Xb_40Z<[a10000005
0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`03
0000003oool0oooo00l0oooo00070?ooo`<00000103oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo01<0oooo0P0000020:bhhP030000002/^>80[;SR008000000P2/^>800`000000[;SR
0:bhhP0300000080[;OQ00<000000:fgh@2]]n400`0000020:ffg`030000002]]^00[KKP00800000
0`2]]Mh01@000000[[GN0000002^/m`0000000<0[[?L0`000000102_/MX000000:nbfP2_/]X30000
0080[jkG00<000000:n`f@2_/=T00`0000020;2/e0030000002_[]L0[jkG008000000`2_Z=401@00
0000[JkH0000002_WlP000000080[JOA10000000102[V/D000000:V/f@2Y[=T2000000@0YYc;0P00
00000`2JMZT000000:BKc0020:BKc0060000002NTlL0WY?700000023HjD000000P1jEI/200000005
089^/`000000PfZ^08=Z[P0000000P29Kjl01P000000T7Rd091h]02@N;@0000009N1^@<000000P2W
T/0010000000Zi_60:^KaP2[VlH2000000<0]k3B0`000000102naMl000000;c5h@0000020;kEj`03
0000002kdNX000000080^Mca00@000000;SGl0000000/mkf0`0000020:kLm`<000000P2ZfOP30000
00040:SEm`000000ZM?f0:WCmP<000000P2Xd?D3000000030:O>m000000000000080000000@0Ylcc
0000002Wbo80Yl_b0`0000020:O9l@040000003oool00000000000<0oooo00@000000?ooo`3oool0
0000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool03`3oool0
00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool05@3oool00`000000[;SR0:bhhP0300000080[;SR00<0
00000:bhhP0000000P0000020:bgh@030000002/]n40[;OQ00<000000P2]]]l00`000000[KKO0:ff
g`0300000080[KCN00<000000:fegP2]]Mh00P0000030:jcg0050000002^/m`000000:j`f@000000
0`2_/MX2000000030:n]eP000000[jkG0080[jkG0`0000000`2`Z]8000000;2/e0020;2/e0<00000
00<0/:G=0000002_Z=400P2_Z=4200000080[io8100000000`2^Tk/000000:^Ja@020:^Ja@800000
00<0YHJb0000002VW</00P2VW</2000000<0VWJY00@000000:BKc02TVl`000000P2NTlL00`000000
Pf>U0000000307YEV`@0000000<0PfZ^00000029Kjl00P29Kjl00`000000T7Rd0000000200000080
XXRi00@000000:NB`02WT/00Yi;00`000000102g[<h000000;N`dP2g/=82000000<0_/GO0P000003
0;kEj`8000000P2ig?430000000:0;?NmP000000[>7i0:cQn@000000[]cg0000002Xg?X000000:[I
n080000000@0Y]Si0000002XeOL0Z=Gg0`0000000`2Vd_L0000000000002000000040:K?m@000000
000000000080Y/cd00<000000:O<l`2Wc?<00`0000020:K9lP030000002WbO40YlWa00<000001@3o
ool2000000X0oooo0P0000030?ooo`<000004P3oool000P0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P00000G0?ooo`800000
0P2/^>800`000000[;SR0:bhhP0200000080[;OQ00<000000:bgh@2/]n400`0000020:bfg`030000
002]]]l0[KKO00<000000P2]]=h00`000000[KCN0:fdgP0300000080[[;L00<000000:jcg02^/m`0
0P0000030:j`f@040000002_/MX00000000000<0[jgF00D000000:n^e`000000[jWA000000030;2Z
dP050000002`[=@000000;2Tb`0000000`2`YLd010000000[jSA0000002`WL@3000000030:nOb000
000000000080[Y>k00<000000:^Ja@2[V/D00P0000030:F6/P050000002VW</0000009e^W0000000
0`2JMZT00`000000Y9_<0:BKc0020000000509jCa`000000Pf>U08=SY@0000000P1jEI/00`000000
OeZL07mJW0040000000608U_[`00000000000000002KOK4000000`2RR;T00`000000Yi;00:NB`002
000000@0]jc>0P0000020<;6gP030000002naMl000000080`][[00@000000;kEj`000000^n?c0`00
00020;;Tm`8000000P2/hOT300000080Z=cj100000001@2Vf?T00000000000000000YMCh00<00000
0P2Td?L300000080YLge00<000000:K<m02Vc?@00`000000102Vb_<000000:K9lP2VbO8400000004
0:K8l@0000000000000002X0oooo00080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01H0oooo00@00000
0:bhhP2/^>80[;SR0`0000020:bgh@030000002/]n400000008000000P2/]^000`000000[;KO0:bf
g`0300000080[KCN00<000000:fdgP2]]=h00`0000020:fbg0030000002^/]`0[[;L00<0000000@0
[[3I0000002^/=T0[[3I0`0000020:n]eP030000002_[MH0[jgF008000000`2_ZM400`000000/:[B
0;2ZdP02000000<0/:C;00<000000;2Uc@2`YLd0100000001P2`WL@00000000000000000[i:h0000
00<0[Y>k0P0000020:Z3Z`050000002UQ[80YHJb0:F6/P0000000`2MKY`010000000VWJY09YfZ@2J
MZT20000000408aGS@000000WY?700000080Pf>U00@0000007YEV`1jEI/000000P1oFY`00`000000
RFBR08UTXP0200000003099aZ@000000Vgfa0080Vgfa00@000000::8^@2RR;T0XXRi0P0000000`2g
YLP000000;N/cP020;N/cP8000000`32a]h300000080`][[0P000000102kho<000000:oZn02_j_P3
000000040:SVn`000000000000000080Y>3k0`0000000`2Sf_/0000000000002000000040:?EnP00
0000000000000080Xm7h0`000000102Sc_H000000:G=m@2UcOD4000000030:G;l`000000000000@0
00000P2Vb?83000000040:K7l0000000oooo000002T0oooo00080?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo01L0oooo00D000000:bhhP000000[;OQ000000030:bgh@80000000<0[;KP0000002/]^000P2/
]^03000000030:bdgP000000[KCN0080[KCN0`0000000`2]/]`000000:fbg0020:fbg0<0000000<0
[K3J0000002^/=T00P2^/=T2000000030:j]e`000000[jgF0080[jgF0`0000000`2_ZM8000000:nY
d@020:nYd@<0000000<0[j?<0000002`Y</00P2`Y</500000080/9g40P0000030:nB^0050000002^
Tk/0[Y>k0:jC^`0000000`2ZPj/01@000000YHJb0:F6/P2UQ[80000000<0WFjL00D0000009YfZ@2J
MZT0VWJY0000000208aGS@<000000P23HjD010000000NUFK07YEV`00000207mJW00400000029I:80
RFBR00000080TW6Y00D0000009]m/@2KOK40Vgfa000000020::8^@8000000`2gYLP00`000000]jc>
000000020<G7f`0300000032a]h000000080a^7/0`0000000`2kjo@0000000000003000000040:3Z
nP000000000000000080W^?m0`000000102NgOd0000000000000000209oGn`<0000000<0XM;i0000
000000000P000000102Rc_L000000:?>mP2Sc_H300000080Y<_d0`000000102Tb?<000000:G8lP2U
b?84000000040:G7l@000000Y/O`0:K7l0<00000:@3oool000L0oooo0P0000040?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0H0?ooo`09
0000002/]n40[;OQ0:bgh@000000[;OQ0000002/]^0000000080[;KP00D000000:bfh0000000[;CO
000000030:bdgP050000002]]=h000000:bcg@0000000`2]/]`01@000000[K;L0000002]/=/00000
00<0[K3J00@000000:j`f@00000000000`2^[ML01@000000[jgF0000002^ZM<0000000<0[jWB00D0
00000:nYd@000000[ZC=000000030:nSc0030000002`Y</00000008000000`2`W<<2000000030:jB
^@000000[i:h00<0[i:h00@000000:jC^`00000000000`2ZPj/00`000000YHJb0:F6/P02000000<0
WFjL00<0000009YfZ@2JMZT00P00000208aGS@0600000022Ch`0000000000023HjD000000P1jEI/0
10000000OeZL07mJW000000208UTXP050000002BLJT0TW6Y099aZ@0000000P2KOK401@000000XXRi
0000002dWL40000000@0]jG800@000000<G7f`35am/0aLOK0P0000001036hN`000000000002im?85
00000003097[m@000000000000X000000P2Kf?d30000000409kCnP000000000000000080X<kh00<0
00000:;>m`2Rc_L00`0000000`2SboD0000000000002000000040:?8l`000000Y<Sc0:C8l`<00000
0P2Uao400`000000YLOa0:G7l@03000000040:K5l00000000000000002P0oooo00080?ooo`030000
003oool0oooo00<0oooo0P0000040?ooo`8000000`3oool2000001/0oooo00<000000:bgh@2/]n40
0P0000030:bfh0040000002/]^000000000000<0[;CO00<000000:bdgP2/]=h00P0000030:bcg@03
0000002]/]`0[K;L008000000`2]/=/00`000000[K3J0:f`fP0200000080[JgG00<000000:j]e`2^
[ML00P0000030:jYd`030000002_ZM80[jWB008000000`2^Y<d00`000000[j?<0000000200000080
[ic500<000000;2L``2`W<<00P0000030:jB^@040000002_T[P0[i:h0:nB^080000000<0[8F[0000
002ZPj/00`2ZPj/2000000030:IeW0000000WFjL0080WFjL00<0000009YfZ@2JMZT00P00000208aG
S@0600000022Ch`0000000000023HjD000000P1jEI/01@000000OeZL07mJW01oFY`000000080RFBR
00@00000099aZ@2BLJT000000`2KOK401@000000]9g10;BM`@2dWL4000000080]jG800H000000<[8
f0000000aLOK0000003;jn/3000000030;WdlP000000U_7Z00H000000P24gOd300000003097Ho`00
0000000000D0000000D0Vm?k000000000000000009k>n007000000040:7;m@000000000000000080
XlSc00<000000:?8l`2Sb?<00`0000020:C7l@030000002Uao40YLOa00<0000000@0YLG`00000000
000000000P2Va>l3000002H0oooo000I0?ooo`030000003oool0oooo01/0oooo0P0000020:^fh@03
0000002/]^00[;KP008000000P2/]=l00`000000[;CO0:bdg`0300000080[;?N00<000000:bcg@2/
/md00`0000020:baf`030000002]/=/0[K3K00<0000000@0[JkI0000002][ML0[JgG0`0000020:fZ
e0030000002^ZM<0[ZWC00<0000000@0[JG?0000002^Y<d0[ZC=100000000`2]W/L000000:nLa@02
0:nLa@80000000<0[IBm0000002^T[T00P2^T[T00`000000[i:h0:nB^002000000<0[8F[00D00000
0:Z3Z`2ZPj/0ZX>[000000030:IeW0080000002MKY`0WFjL0000002JMZT0000009MQS`00000208aG
S@0600000022Ch`0PTn<00000023HjD000000P1jEI/01@000000OeZL07mJW01oFY`000000080RFBR
00@00000099aZ@2BLJT000000P2KOK42000000<0]9g100<000000;NUb00000000P3:b=P200000004
0<_[j`000000[?WV0:ciiP`0000000@0RmKo00000000000000000P2EdO`00`000000V=;l09SBo003
0000000509c>n@00000000000000002Ob_H00P0000020:3;mP<000000P2Rb?<00`000000XlSc0:?8
l`03000000030:C6lP000000000000D0000000@0YLG`00000000000000000P2Ua>l00`000000Y/C_
0:K4k`02000002L0oooo000I0?ooo`030000003oool0oooo01`0oooo00<000000:^fh@2[]^400`00
00020:^eh0030000002/]=l00000008000000P2[/mh00`000000[;?N0:bcgP0300000080[;7L00<0
00000:baf`2//M/00`000000102/[mX000000:f^f@2][]T3000000030:b[eP000000[J[D0080[J[D
0`000000102/Y]4000000:fUc`2]YLl3000000030:jTc@00000000000080[Ik700<000000:nLa@2_
W<D00P0000030:fD_@080000002^T[T0[Y:i0000002_T[P000000:b8[`0000030:b5Z`050000002Z
Pj/0ZX>[0:Z3Z`0000000`2VMI`010000000WFjL09e^W02MKY`20000000509MQS`000000S5N=08aG
S@0000000P22Ch`00`000000Pf>U0000000307YEV`040000001oFY`0OeZL00000080RFBR00@00000
099aZ@2BLJT0TW6Y0P0000020;2C^0050000002dWL40]9g10;BM`@0000000P3:b=P00`000000coKX
0000000900000080QLoo1P0000000`2Cco`00000000000050000000409_<n@000000000000000080
W/Wf00<0000009o:mP2Ob_H00`000000102Qao<000000:;8l`2Rb?<4000000040:?6lP0000000000
00000080Y<C`00<000000:C5l02TaO000`000000102Ua>l000000:G4k`2Ua>l4000000030:K3kP00
0000000002H0oooo000I0?ooo`030000003oool0oooo01d0oooo0P0000020:^eh0030000002[]N00
ZkGP008000000P2[]=l00`000000Zk?N0:^cgP0300000080Zk;M00<000000:bag02//M`00`000002
0:^_f`030000002/[mX000000080000000<0ZjcH0000002/ZmH00P2/ZmH01@000000[J[D0000002[
Ym<000000080[:KA0`0000001P2]YLl00000000000000000[9o:000000<0[Ik70P0000000`2[U/40
00000:fD_@020:fD_@030000002^T[T0[Y:i008000000P2/R:l01@000000[8F[0:b5Z`2/QJ/00000
0080ZX>[0P0000030:IeW0050000002MKY`0WFjL09e^W00000000P2GHHl010000000S5N=08aGS@00
0002089?S080000000D0Pf>U0000001jEI/0NUFK0000000207mJW00400000029I:80RFBR00000080
TW6Y0P0000030;2C^0030000002dWL40]9g10080000000<0b/SH0000003?m^P01@00000208o4n@03
00000028b_d0R<[m00<0000000@0U<Oi0000002Cbo/0Tl_k0`00000209[8m`030000002JboP0V/_h
00<0000000<0W/Oe0000000000001@0000000`2Qa_<000000000000400000080XlGa0`000000102T
a?0000000:C4l02Ta?04000000040:G3k`000000YLC_0:G4k`<000000P2U`nh00`000000Y/?^0:K3
kP03000002D0oooo000I0?ooo`8000007`3oool00`000000ZkGP0:^eh003000000040:^dh0000000
ZkCO0:^dg`<000000P2[/]h00`000000Zk;M0:^bg@03000000030:^`g0000000ZjoK0080ZjoK0P00
00000`2[[MT000000:^/f0020:^/f0030000002/ZmH0[:_F008000000P2[Ym<3000000060:bVd@00
000000000000002[X/h000000`2/WlX010000000[Ik70000000000030:^F`@080000002]U;d0[IBm
0000002^T[T000000:V;]@0000030:b8[`040000002/QJ/0[8F[0:b5Z`80000000<0ZGZP0000002V
MI`00P2VMI`01@000000WFjL09e^W02MKY`000000080Uf6?00@0000008aGS@2<Ehd000000P22Ch`0
10000000ODf=00000000000207YEV`040000001oFY`0OeZL000000<0RFBR0P0000000`2YQZl00000
0;2C^0020;2C^0040000002dWL4000000<o9e0H0000000<0V;oc0000000000001@0000000`2H`oD0
00000000000400000080VlGe1P000000102NaO@000000000000000020:74l@030000002QaO80XLGb
00@0000000@0X/C`0000002RaO40X/Ga0`000000102T`o0000000:C4l02Ta?0300000080YL?_00<0
00000:G3k`2U`nl00`0000020:G2kP030000002U`nh0YL?^00<0000000<0Y/;]0000000000009@3o
ool001T0oooo00<000000?ooo`3oool07`3oool200000080Z[GP00<000000:^dh00000000P000002
0:Zcg`030000002[/]h0Zk;N00<0000000<0Z[7M0000002[/=`00P2[/=`01@000000ZjoK0000002Z
[]/000000080ZjgI00<000000:^/f02[[=P00`0000001@2ZZMH00000000000000000ZjOC00<00000
00<0ZJCA0000002[X/h00P2[X/h00`000000[9o:00000002000000030:VIaP000000ZiK10080ZiK1
00<000000:fD_@2]U;d00P0000020:V;]@050000002/R:l0[8R_0:b8[`0000000`2/QJ/010000000
ZGZP0:UjX00000030:IeW0030000002MKY`0WFjL008000000P2GHHl010000000S5N=08aGS@000002
089?S0040000001mCHd0000000000080NUFK00H0000007mJW01oFY`0OeZL00000029I:82000000<0
ZHJ_00P000000;2C^02`TkP0/9>h0000003?bM@000000<_oe`80000000@0X;c]0000000000000000
0P2S_N`00`000000WKo`09fol00300000080XKo^00<0000009g2lP2M`_800`000000102Q`O000000
09o3lP2O`o8300000080XL;`00<000000:74l@2Qa?400`000000102S`_0000000:;4l02Ra?040000
00040:C2k`000000Y<?`0:C3l0<000000P2T`^h00`000000YL?_0:G3k`03000000030:G2kP000000
000000D0000000D0Y/;]00000000000000000:K1k@02000002@0oooo000I0?ooo`030000003oool0
oooo0200oooo00<000000:Zeh02Z]N000P0000020:Zdh0030000002Z/ml0Z[?O00<0000000<0Z[;N
0000002Z/Md00P2Z/Md00`000000Zk3L0:^`g002000000<0ZZkK00<000000:^]f@0000000P000000
0`2YZmP0000000000003000000040:^Wd`000000Z:KD000000<0ZJCA00<000000:^RcP0000000P00
00000`2XW<X000000:VIaP020:VIaP080000002[U/40ZiK10000002]U;d000000:N>^`0000030:V;
]@040000002/R:l0[8R_00000080[8F[0P0000020:UjX0050000002VMI`0YWFL0:IeW00000000P2M
KY`200000080Uf6?00@0000008aGS@2<Ehd000000P22Ch`00`000000ODf=07e=S@020000000307YE
V`000000OeZL0080OeZL0P0000000`2OMZD000000:V6[`020:V6[`050000002`TkP0/9>h0000003E
bLl01P0000020:Nmj@030000002S_N`0Xkg/00<000000P2T_N/00`000000XKo^0:6okP0300000004
0:>ok@000000XL7`0:71l0<000000P2S`>h00`000000XL;`0:72l003000000040:?1kP000000Xl;`
0:?2l0<0000000<0Y<7^0000000000000P2T`^l3000000030:G1kP000000000000D0000000@0YL7]
00000000000000000P2V`Nd00`000000Y/7]0:K1k@03000000040:K1k0000000Y/7]0:K1k@<00000
8`3oool001P0oooo0P00000S0?ooo`8000000P2Y]>000`000000Z[CP00000002000000030:Vbg`00
0000Z[;N0080Z[;N00<000000:Zag@2Z/Md00`0000020:V_g0030000002Z[]/000000080000000<0
ZJcJ0000000000000`0000020:ZYeP8000000`2XY]@00`000000ZJCA0:VTd@02000000030:NOcP00
0000Z9c:0080Z9c:00@000000:VIaP2YVLH000000P2[U/42000000<0Yhjk00@000000:V;]@2YRkD0
00000`2/R:l2000000050:ImYP000000ZGZP0:UjX00000000`2VMI`00`000000WFjL09e^W0020000
0080Uf6?00@0000008aGS@2<Ehd000000P22Ch`01@000000ODf=07e=S@000000QEJB0080000000@0
OeZL00000000000000000P2OMZD01`000000ZHJ_0:V6[`2YQZl000000;2C^00000000P3EbLl30000
0080ZKgX00<000000:Nmj@2W_NT00`000000102W_NT000000:Bmj`2T_N/4000000040:Fnj`000000
Xko]0:>ok@<000000P2T_n`00`000000Xl3^0:?0kP03000000030:C0k@000000000000@000000P2T
`>d6000000040:G1k@000000000000000080YL3/00<000000:G1k@2U`Nd00`000000102V`>`00000
0:K1k@2V`Nd4000000040:K0k0000000Y/7/0:K1k0<000000P2W`>`00`000000oooo0?ooo`0Q0?oo
o`00603oool00`000000oooo0?ooo`0S0?ooo`030000002Y]>00ZKCP0080000000<0ZK?P0000002Y
/]l00P2Y/]l00`000000Z[;N0:ZbgP0300000080ZK3M00<000000:V_g02Y[m`00P0000000`2X[]/0
00000000000300000080ZJ_H0`0000020:RXeP030000002XY]@0Z:KD00<0000000D0YZ;B0000002W
Wlh0Yio>000000020:RLbP030000002YVLH0ZIW600<0000000<0YI;20000002WS[/00P2WS[/01000
0000ZH^e0:V;]@0000020:b8[`8000000P2VOJH010000000ZGZP0:UjX00000040:IeW080000000D0
Y6fC0000002GHHl0Uf6?0000000208aGS@0400000022Ch`0PTn<00000080ODf=00<0000008EFTP25
EY800P000002099VV`040000002OMZD0WgJU000000@0ZHJ_00<000000=G9c`3EbLl00P000000102Y
_NP000000:Vmj02Y_NP3000000040:Vmj0000000YkgY0:Nmj@<000000P2W_NT00`000000YKk[0:Fn
j`03000000030:Jnj`000000000000D0000000@0YKk/00000000000000000P2V_^/00`000000YKo/
0:Fok003000000030:Jok0000000YL3/00@000000P2V_n`00`000000YL3/0:G0k003000000040:K0
k0000000Y/3/0:K0k0<000000P2V`>`00`000000Y/3/0:K0k003000000040:O0k0000000Yl3/0:O0
k0<000008P3oool001P0oooo00<000000?ooo`3oool0903oool2000000050:Vdh@000000ZK?P0:Vc
h00000000P2Y/]l300000080Z;7N00<000000:V`g@2Y/=d00`0000000`2X[md00000000000020000
0080ZJcJ0`0000020:NZf@030000002XZ=H0Z:SF00<0000000D0YJGF0000002VX]80YZ;B00000002
0:NOcP030000002XW<X0Z9c:00<0000000<0XiO80000002UT/800P2UT/8010000000Yhjk0:N>^`00
00030:V;]@80000000D0Xh6_0000002VOJH0YWfV000000030:UjX0040000002VMI`0YWFL0:IeW080
000000D0Y6fC0000002GHHl0Uf6?0000000208aGS@0400000022Ch`0PTn<00000080ODf=00@00000
08EFTP25EY8000000`2BIY/01@000000WgJU09mfY@2OMZD000000080ZHJ_0P0000000`3EbLl00000
000000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002W_NT0YkgY00<0
000000@0YkgY00000000000000000P2X_NT00`000000Y[kZ0:JnjP03000000040:NnjP000000Y[k[
0:Jnj`@0000000@0Y[k[0000002V_n`0Y[o/10000000102V_n/000000:Jok02V_n`3000000040:Jo
j`000000Y/3/0:K0k0<000000P2W_n/00`000000Y/3/0:K0k003000000040:Noj`000000Yl3/0:O0
k0<000000P2W_n/200000240oooo000H0?ooo`030000003oool0oooo02@0oooo00H000000:Vdh@2Y
]>40ZKCQ0000002Y/n0300000080Z;;O00<000000:RagP2X/Mh00`0000001`2W/=h0000000000000
0000Z:oM0000002X[]/00`0000020:J/f`030000002WZ]T0Yj[I00<0000000<0Y:SI0000002UYMH0
0P2UYMH01@000000YZ;B0:JRdP000000Yio>00<0000000<0XY_>0000002SUlP00P2SUlP010000000
YI;20:FB`P0000030:N>^`040000002YRkD0000000000080Xh6_00@000000:ImYP2VOJH000000`2Y
NZ0010000000YWFL0:IeW02VMI`2000000050:A]T`000000Uf6?09MQS`0000000`2<Ehd00`000000
PTn<0000000207e=S@0400000025EY80QEJB000000<0TVJK00L0000009mfY@2OMZD0WgJU0000002Y
QZl000000080g<[700<000000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP300000080ZKgX
1P000000102Y_NP000000000000000020:Rmj0030000002X_NT0Z;gY00<0000000@0Z;gY0000002W
_^X0YkkZ0`0000020:NnjP030000002V_^/0Y[k[00<0000000@0YkkZ0000002V_n/0Y[o[10000000
102W_^/000000:Joj`2V_n/300000080Yko[00<000000:Noj`2W_n/00`000000102W_n/000000:No
j`2W_n/3000000030:Noj`00000000000080000000<0Yko[0000003oool0803oool001P0oooo0P00
000V0?ooo`030000002Y]>400000008000000P2X/n400`000000Z;;O0:Rbg`03000000050:Nag`00
000000000000002W/=h01@0000020:J^g@030000002V[=/0YZcK00<0000000<0Y:[K0000002TZ=T0
0P2TZ=T00`000000YJGF00000005000000030:6OdP000000XY_>0080XY_>00@000000:>Gb02SUlP0
00000P2UT/800`000000Yhjk0:N>^`030000000509n5^0000000Xh6_0:>1[`0000000`2VOJH01000
0000ZGZP0:UjX00000030:IeW0040000002TKI<0Y6fC00000080Uf6?00L0000008aGS@2<Ehd0S5N=
00000022Ch`000000080ODf=00@0000008EFTP25EY8000000`2BIY/010000000WgJU09mfY@2OMZD2
000000<0g<[70P000000102Y_NP000000:Vmj02Y_NP300000080ZKgX0`000000102Y_NP000000:Vm
j02Y_NP300000080ZKgX00<000000:Rmj02X_NP00`000000102Y_NP000000:Rmj@2X_NT300000080
Z;gY00<000000:NnjP2W_^X00`000000102W_^T000000:NnjP2W_^X3000000030:NnjP0000000000
0080Ykk[0`000000102W_^X000000:Noj`2W_n/4000000030:NojP000000000000@0000000@0Yko[
00000000000000000P2W_nX00`000000Yko[0:Noj`03000001l0oooo00030?ooo`D000000`3oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo02H0oooo00@000000:Rdh@2X]>4000000P2X
/n4300000080Yk;Q0P0000001P2W/Ml00000000000000000Y[3O00000080YZoN00<000000:J^g@2V
[]d00`0000000`2T[=d000000:BZf`020:BZf`030000002TZ=T000000080000000D0XJKJ0000002Q
XmH0XJ?F000000030:6OdP040000002RVlh0XY_>00000080XiO81P0000001@2LRl40000009n5^02O
QKP000000080Xh6_00D000000:ImYP2VOJH0YWfV000000020:UjX0030000002VMI`0YWFL00800000
0P2TKI<010000000Uf6?09MQS`00000308aGS@0600000022Ch`0PTn<0000001mCHd000000P25EY80
1@000000TVJK099VV`2BIY/0000000<0WgJU00@000000=c:a`3Lb/L0g<[70P0000020:Vmj0<00000
0P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00300000004
0:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`000000Z;gY0:Rmj@03000000040:Rmj@000000YkkY
0:Nnj@<000000P2X_^T00`000000YkkZ00000003000000030:NnjP000000000000@000000P2W_^X3
000000040:RnjP000000YkkZ0:NnjP<000000P2X_^X00`000000YkoZ0:NojP03000000030:RnjP00
0000oooo00P0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`<000000P3o
ool000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0:03oool00`000000Z;CQ0000000200000080
Yk?Q1P0000000`2V/^4000000:J`g`020:J`g`030000002V[mh000000080000000<0Y:kO0000002T
[=d00P2T[=d00`000000Y:[K0:BZf`02000000030:6Yg0000000XJKJ0080XJKJ00@000000:6SeP2Q
XmH000000P2QWm860000000509ZGd0000000Vi7909^Ab@0000000P2LRl4010000000WhFh09n5^000
00030:>1[`040000002VOJH0YWfV00000080ZGZP00D000000:IeW0000000Xg6J000000020:A]T`04
0000002GHHl0Uf6?000000<0S5N=00@00000089?S022Ch`000000P1mCHd010000000QEJB08EFTP00
0003099VV`030000002OMZD0WgJU0080000000<0g<[70000002Y_NP00`0000020:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0
ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002X_NT0Z;gY0`0000020:Rm
j@030000002X_^T0Z;kY00L000000P2X_^T00`000000Z;kY0:Rnj@03000000040:Rnj@000000Z;kZ
0:RnjP<0000000@0Z;kY0000002X_^X0Z;kZ10000000102X_^X000000:RnjP2X_^X2000000L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0040oooo00050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo02T0oooo00<000000:NdhP2W]>801P000002
0:JchP050000002V/^40Y[;Q0000002V/=l00`0000020:B`h0040000002T[]l0Y:kO00000080Y:cM
0`0000001@2Q[=l000000:6Yg02QZM`000000080XJKJ1P0000001@2JXMX0000009ZLe@2JW=D00000
00<0VYO@00<0000009^Ab@0000000`2LRl4010000000WhFh09n5^00000020:>1[`040000002VOJH0
YWfV00000080ZGZP0P0000020:=aVP040000002TKI<0Y6fC00000080Uf6?00D0000008aGS@2<Ehd0
S5N=00000002089?S0040000001mCHd0ODf=00000080QEJB00L00000099VV`2BIY/0TVJK0000002O
MZD000000080hlVn0`0000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000
002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<0
000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0H0000000<0Z;gY0000000000000`0000020:Rn
j@@0000000@0Z;kY0000002X_^T0Z;kY0`000000102X_^T000000:Rnj@2X_^T300000080Z;kY00<0
00000:RnjP2X_^X00`0000000`2X_^T00000000000060?ooo`040000003oool0oooo000000P0oooo
00D000000?ooo`3oool000000?ooo`0500000080oooo00060?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?ooo`800000:P3oool6
00000080Y[CS00<000000:JchP2V/n801@0000020:BahP030000002T/>00Y;3P00H000000P2Q[^40
1@000000XJcO0:6/g`000000XJWL00<0000000D0VjWP0000002KYMd0VjGM0000000309ZQfP040000
002JW=D0VYcE00000080VYO@00@0000009^Ab@2KTLT000000P2LRl4010000000WhFh09n5^0000002
0:>1[`050000002VOJH0YWfV0000002YNZ000P0000030:=aVP040000002TKI<0Y6fC00000080Uf6?
00D0000008aGS@2<Ehd0S5N=00000002089?S0040000001mCHd0ODf=00000080QEJB00@00000099V
V`2BIY/0TVJK0P0000030>?9_P030000002Y_NP000000080000000@0ZKgX0000002Y_NP0ZKgX0`00
00020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000
002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP000000000000200000004
0:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX0000002X_NT0100000020:Rmj@030000002X_^T0Z;kY
00<0000000@0Z;kY0000002X_^T0Z;kY0`0000020:Rnj@030000002X_^T0Z;kY00<0000000@0Z;kY
0000002X_^T0Z;kY0P0000060?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool0
00000?ooo`0000020?ooo`030000003oool0oooo0040oooo00030?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool09P3oool300000080oooo00@000000:Jeh`2V]N<000000P2V]><3000000050:Bd
h`000000Y;;S0:Bbh`0000000P2T/N83000000030::ah`000000XK3R0080XK3R00<000000:6^h@2Q
[^401@00000209b/hP040000002KZN00VjWP00000080VjGM00<0000009ZQfP2JXMX04`0000001P2V
OJH00000000000000000VG6S000000<0Xg6J00@000000:A]T`2TKI<000000P2GHHl01@000000S5N=
08aGS@2<Ehd000000080PTn<00@0000007e=S@1mCHd000000P25EY8010000000TVJK099VV`2BIY/2
00000080hlVn0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj02Y_NP00`00
0000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj02Y_NP00`0000000`2Y_NP00000
00000004000000040:Vmj0000000000000000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP0
00000:Vmj02Y_NP4000000040:Vmj0000000Z;gY0:Rmj@<0000000@0Z;gX0000002X_^T0Z;kY0`00
00020:Rnj@030000002X_^T0Z;kY00<0000000<0Z;kY000000000000100000000`2X_^T000000000
00050?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo000000030?ooo`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02<0oooo0`000005
0?ooo`030000002V]N<0Y[GS00<000000P2T]>@01@000000Y;CS0:Bdh`000000Y;;S00<000000P2R
/n@010000000X[7S0::ah`0000020:6`hP<0000000D0W[3U0000002M[^<0WJkS0000000209b/hPT0
000000D0T:OU0000002=X^<0SJ;S0000000208ZLg`0300000027UMX000000080QHcC00@0000008F3
b@25PlT000000P28N[d20000000508md/0000000VG6S09UaX`0000000`2SLIX010000000Y6fC0:A]
T`00000209MQS`050000002<Ehd0S5N=08aGS@0000000P22Ch`010000000ODf=07e=S@00000208EF
TP050000002BIY/0TVJK099VV`0000000P3SbKh00`000000ZKgX000000020:Vmj0<000000P2Y_NP0
0`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vm
j003000000060:Vmj000000000000000002Y_NP000000P2Y_NP300000080ZKgX00<000000:Vmj02Y
_NP00`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj00000000`000000102Y
_NP000000:Rmj02X_NP3000000040:Vmj0000000Z;kY0:Rnj@@0000000H0Z;kY0000000000000000
0:Rnj@0000020:Rnj@<000000P2X_^T00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000`3oool2000000<0oooo00040?ooo`<00000103oool20000
00@0oooo0P0000030?ooo`030000003oool0oooo0280oooo0P0000090?ooo`8000000P2T]^D00`00
0000Y;CT0:Bdi00500000080X[CU00<000000::ci02R/n@01P00000209nbiP030000002N/>D00000
00D000000P2H/NP010000000UZkX09J^j000000209>[i`040000002@YnD0T:OU00000080SJ;S00H0
000008ZLg`2:W=l0000008NEfP00000208F<d`0600000025PlT0QH?900000028N[d000000P2?M;00
10000000VG6S09UaX`0000030:=aVP040000002TKI<0Y6fC00000080Uf6?00D0000008aGS@2<Ehd0
S5N=00000002089?S0040000001mCHd0ODf=00000080QEJB00@00000099VV`2BIY/0TVJK0P000000
0`3SbKh000000:Vmj00300000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y
_NP300000080ZKgX00<000000:Vmj02Y_NP00`0000001P2Y_NP00000000000000000ZKgX00000080
ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vm
j0030000002Y_NP0ZKgX00D000000P2Y_NP3000000030:Vmj0000000000000@000000P2Y_NP30000
00040:Vmj0000000Z;kY0:Rnj@<0000000@0ZKgY0000002X_^T0Z;kY0`0000040?ooo`8000002P3o
ool2000000D0oooo00<000000?ooo`3oool00@3oool001H0oooo0P00000P0?ooo`<00000303oool0
0`000000Y;KU0:Bfi@0300000080XkKV00<000000:>ei@0000000P2R]>D300000080X;GW00@00000
09nciP2O/nH000000P2O/^H200000080VkCY00@0000009Vbj@2I/^T000000P2H/NPE00000080QH?9
00<0000008Qj_@0000000P2?M;0010000000VG6S09UaX`0000030:=aVP040000002TKI<0Y6fC0000
0080Uf6?00D0000008aGS@2<Ehd0S5N=00000002089?S0040000001mCHd0ODf=00000080QEJB00@0
0000099VV`2BIY/000000P3Yak<300000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP00000
0:Vmj02Y_NP300000080ZKgX1P0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0`000002
0:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vm
j02Y_NP4000000030:Vmj0000000ZKgX00@0000000@0ZKgX00000000000000000P2Y_NP00`000000
ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NT0ZKgY0`000000
0`3oool000000?ooo`0K0?ooo`005P3oool00`000000oooo0?ooo`0L0?ooo`<00000403oool20000
0080XkOV00<000000:>fiP2S]^H01@0000020:6fi`030000002P]NL0X;GW00H0000000@0W;KZ0000
002K]>T0VkCY1P00000209>gl0030000002?]_4000000080R[Ca00<0000008BalP24/O8010000002
06jWm0050000001KW_<0Fikc0000000nS^h00`00000208Qj_@040000002?M;00SgB`00000080VG6S
00@000000:=aVP2SLIX000000P2TKI<010000000Uf6?09MQS`00000308aGS@0400000022Ch`0PTn<
00000080ODf=00L0000008EFTP25EY80QEJB0000002BIY/000000080jLNc00<000000:Vmj0000000
0P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vm
j0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX
0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX2P000000102Y_NP00000
0:Vmj02Y_NP4000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000004
0?ooo`030000003oool0oooo01X0oooo000F0?ooo`030000003oool0oooo01T0oooo0`00000D0?oo
o`030000002S]nH0XkOV00<000000P2R]nP00`000000X[OX000000020:6fi`<000000P2O]nX00`00
0000WKOZ09fgjP0500000080V;W^00@0000009Jhk`2F^>l000000P2C]o0800000080M[gm00<00000
06:jo@0000002P0000001@28N[d0000008md/02?M;0000000080VG6S00@000000:=aVP2SLIX00000
0P2TKI<010000000Uf6?09MQS`00000308aGS@0400000022Ch`0PTn<00000080ODf=00@0000008EF
TP25EY80QEJB0P0000020>W7/`030000002Y_NP0ZKgX00<0000000<0ZKgX00000000000010000002
0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP300000080ZKgX
00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vm
j0<000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0D000000P2Y_NP300000080ZKgX00<00000
0:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000P0oooo00<000000?ooo`3oool06@3o
ool001H0oooo00<000000?ooo`3oool05P3oool3000001P0oooo0P0000020:>hj0030000002R]nP0
X[OX00D000000P2O^>X00`000000WkOZ09ngjP030000000509bjk@000000V[[^09ZjkP0000000P2H
^Nh60000000408nomP000000RKoh08Von0l0000000<0VNcg0000000000000`00000208md/0040000
002ILJ<0VG6S00000080Xg6J00@000000:A]T`2TKI<000000P2GHHl01@000000S5N=08aGS@2<Ehd0
00000080PTn<00@0000007e=S@1mCHd000000`25EY8200000080jLNc0`000000102Y_NP000000000
000000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP0
00000:Vmj02Y_NP300000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3
000000030:Vmj0000000000000@000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000@0
ZKgX0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0
ZKgX0`00000;0?ooo`030000003oool0oooo01T0oooo000F0?ooo`800000503oool3000001`0oooo
00<000000:>hj02S^>P00`000000102Q^NX000000:2ijP2P^NX600000080WK_]00<0000009bjk@00
00001@00000209Nnl`030000002C_o@0Tkod00D000000P27bOd80000000308?QnP000000000000D0
000000H0]^;f000000000000000008md/000000209UaX`040000002SLIX0Xg6J00000080Y6fC00@0
000009MQS`2GHHl000000`2<Ehd010000000PTn<089?S000000207e=S@0500000025EY80QEJB08EF
TP0000000P3Yak<00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP00`000000102Y
_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0
ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000000000000020:Vmj0030000
002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP40000
00040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`00000>0?ooo`030000003o
ool0oooo01T0oooo000E0?ooo`030000003oool0oooo0140oooo0`00000P0?ooo`8000000P2R^^X0
0`000000XKWZ0000000200000080Wk_/00<0000009jkk@2N^nd01@00000209^nl@030000002I__80
VKkb00H0000000<0TlKi0000000000001000000208WBo`<0000000<0Rmgn0000000000000`000000
0`2YioX000000;;Rm`0300000080]mSa00<0000008md/00000000P2ILJ<010000000Xg6J0:=aVP00
00020:A]T`040000002GHHl0Uf6?000000<0S5N=00@00000089?S022Ch`000000P1mCHd010000000
QEJB08EFTP25EY82000000060>W7/`00000000000000002Y_NP000000P2Y_NP3000000040:Vmj000
0000ZKgX0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<000000:Vmj02Y_NP0
0`0000000`2Y_NP0000000000004000000040:Vmj0000000000000000080ZKgX00<000000:Vmj02Y
_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<000000P2Y_NP0
0`000000ZKgX00000003000000040:Vmj0000000ZKgX0:Vmj0<000004@3oool00`000000oooo0?oo
o`0I0?ooo`005@3oool00`000000oooo0?ooo`0?0?ooo`800000903oool00`000000X[[Z0::jjP02
00000080X;_/00<0000009nkk02O^n`00`00000209jnk`030000002M__00000000D000000P2I`oD0
0`000000U/Gg09K5m`0200000080U<gk300000020:OSn`@000000P2efO<3000000060;C?kP000000
SgB`0000002ILJ<000000`2SLIX00`000000Y6fC0000000309MQS`040000002<Ehd0S5N=00000080
PTn<00@0000007e=S@1mCHd000000P25EY801P000000k/FX0>k5Z0000000ZKgX00000080ZKgX0`00
0000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj02Y_NP00`0000000`2Y_NP00000
00000004000000040:Vmj0000000000000000080ZKgX00<000000:Vmj00000000P0000020:Vmj003
0000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP3
00000080ZKgX00<000000:Vmj02Y_NP02P00000D0?ooo`030000003oool0oooo01T0oooo000E0?oo
o`030000003oool0oooo00`0oooo0`00000W0?ooo`80000000@0XKc/0000002P^n`0X;_/0`000002
09nnkP030000002N_^l0W[k_008000000P2M`_800`000000Vl?c09_3l`060000000409S:n@000000
000000000080V=;l0`000000102Mf_d000000000000000020:GOn`<0000000<0[moh0000002cf_@0
0`0000020;CAk`D0000000<0VG6S0000002SLIX00P2SLIX010000000Y6fC0:A]T`00000209MQS`04
0000002<Ehd0S5N=00000080PTn<00L0000007e=S@1mCHd0ODf=00000025EY8000000080k/FX00<0
00000:Vmj00000000P000000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj02Y_NP0
0`0000001P2Y_NP00000000000000000ZKgX00000080ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX
008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX
0000002Y_NP0ZKgX0`0000020:Vmj0H0000000@0ZKgX00000000000000006P3oool00`000000oooo
0?ooo`0I0?ooo`005@3oool2000000X0oooo0`00000/0?ooo`@000000P2P_^h60000000409k1l@00
0000WL;b09g2lP<000000P2LaoH500000080Vloj0`00000209kFn`8000000P2Tfo/300000080[Mgh
100000020;?Cl0<0000000L0//_]0000002ab>/0/LS[0000002ILJ<0000000<0Xg6J00@000000:A]
T`2TKI<000000P2GHHl010000000S5N=08aGS@000002089?S0080000001mCHd0ODf=07e=S@000000
QEJB0000003^aJP300000080ZKgX00<000000:Vmj00000000P0000020:Vmj0H0000000H0ZKgX0000
0000000000000:Vmj00000020:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj000
0000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`000000102Y_NP000000:Vmj02Y_NP30000
0080ZKgX0`000000102Y_NP000000:Vmj02Y_NP3000000<0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0I0?ooo`005@3oool00`000000oooo0?ooo`060?ooo`<00000<03oool00`00
0000XKk]0000000200000080X<3_00<0000009o1l02O`O001@00000209g5m0<000000P2NboL00`00
0000W<gh0000000200000080Wm?j0`000000102Tf?X000000000000000020:_Jn0<0000000H0/MWe
0000002bdo4000000;?Cl00000020;;=kP030000002bbnd0000000<000000P2ILJ<010000000Xg6J
0:=aVP0000020:A]T`040000002GHHl0Uf6?00000080S5N=00@00000089?S022Ch`000000`1mCHd2
00000080k/FX00<000000:Vmj0000000100000020:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX0`00
0000102Y_NP000000:Vmj02Y_NP300000080ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP00000
0:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX000000000000100000020:Vm
j0<0000000@0ZKgX0000002Y_NP0ZKgX0`0000070?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0603oool001D0oooo00<000000?ooo`3oool00`3oool3000003@0oooo00@000000:70
k`2Q`>l000000P2P`>l3000000040:33lP000000WlCc09o4l`<000000P2ObOD500000080X=3h0`00
00020:CDn@8000000P2Yf?P300000080[mOe0P0000020;;Cl@<000000P2bcNh200000080[lK[0`00
00001@2ILJ<000000:=aVP2SLIX000000080Y6fC00@0000009MQS`2GHHl000000P2<Ehd010000000
PTn<089?S000000307e=S@8000000P3^aJP2000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX
0000002Y_NP0ZKgX0`0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0:Vm
j003000000040:Vmj0000000ZKgX0:Vmj0<0000000<0ZKgX00000000000010000000102Y_NP00000
0000000000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`00000;0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0603oool001@0oooo00@000000?ooo`3o
ool0oooo0`00000h0?ooo`D000000P2Q`o4500000080X<Od0`0000020:7;mP030000002QcOL00000
008000000P2Td_P3000000040:SEm`000000000000000080[MKe0`000000102ado80000000000000
00020;;>k`<0000000@0/<S/00000000000000000P2]`^T300000080Xg6J00@000000:A]T`2TKI<0
00000P2GHHl010000000S5N=08aGS@000002089?S0040000001mCHd0ODf=07e=S@80000000<0k/FX
0000000000000P2Y_NP300000080ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0
ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj003000000030:Vmj0000000000000@0000000@0ZKgX
00000000000000000P2Y_NP00`000000ZKgX0000000200000080ZKgX00<000000:Vmj02Y_NP00`00
0000102Y_NP000000:Vmj02Y_NP3000000h0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0H0?ooo`00503oool4000003`0oooo00<000000:72l02Q`_000`000000102RaO8000000:76
l`2Qa_<300000080X/Wd1@0000020:C?m`<000000P2Wd_H200000080[=Ce0`000000102_do800000
0000000000020;7?l0<0000000@0/<[]00000000000000000P2^a>X00`000000[L;Y0:g2j@030000
0080Xg6J00@000000:A]T`2TKI<000000P2GHHl010000000S5N=08aGS@000002089?S0050000001m
CHd0ODf=07e=S@0000000P3^aJP400000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000
002Y_NP0ZKgX00<0000000<0ZKgX000000000000100000001P2Y_NP00000000000000000ZKgX0000
0080ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj0030000
00040:Vmj0000000ZKgX0:Vmj0<000004P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01P0oooo0000103oool000000000000000040?ooo`800000103oool2000000@0oooo0P00000o
0?ooo`8000000P2Ra?400`000000X/Gb0000000200000080X/Sc0`0000020:C;m0030000002TcOH0
0000008000000P2Wd?H3000000040:[Bm@000000000000000080[];c0P0000020;3?l0<000000P2`
bnd200000080[lK[00<000000:k4jP2^a>X00`0000000`2/`>T00000000000020:=aVP040000002T
KI<0Y6fC00000080Uf6?00@0000008aGS@2<Ehd000000P22Ch`01@000000ODf=07e=S@1mCHd00000
0080k/FX00@000000:Vmj02Y_NP000000P2Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<0000000H0
ZKgX00000000000000000:Vmj00000020:Vmj0<000000P2Y_NP00`000000ZKgX0000000200000080
ZKgX00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000040:Vmj0000000ZKgX
0:Vmj0<000005P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01P0oooo00001@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo03h0oooo1@000000102Sao8000000000000000020:C:l`D0
00000P2Vc_D3000000040:W@m0000000000000000080[M3c0`000000102_co400000000000000002
0;3<kP<0000000@0[lO/0000002_a^/0[lK[0`000000102]`^T000000000000000020:^oj0030000
002SLIX000000080Y6fC00@0000009MQS`2GHHl000000P2<Ehd01@000000PTn<089?S022Ch`00000
0080ODf=100000020:Vmj0<0000000<0ZKgX00000000000010000000102Y_NP00000000000000002
0:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<00000
0:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000000000@000006@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01P0oooo00040?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03h0oooo00<000000:?6l@2Sa_400P0000020:C8lP<000000P2Vbo<00`000000Y/cd
0000000200000080ZLkd0P0000020:c?lP<000000P2^c_4200000080[lc_0`000000102_b>`00000
0:o7k02_an`300000080[L?Z0P0000020:_0j@060000002[_nP0ZkoX0000002SLIX000000P2TKI<0
10000000Uf6?09MQS`00000208aGS@0500000022Ch`0PTn<089?S00000000P1mCHd00`000000l<>Q
00000003000000040:Vmj0000000000000000080ZKgX00<000000:Vmj00000000P0000020:Vmj003
0000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj003000000040:Vmj0000000ZKgX0:Vm
j0<0000000<0ZKgX00000000000010000000102Y_NP0000000000000000P0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0603oool00080oooo0P0000030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`0n0?ooo`80000000@0
YLOb00000000000000000P2VbO800`000000Y/_c0:K;l`0200000080Z<gc0`000000102[c_800000
0000000000020:g>l@<0000000@0[lc_00000000000000000P2_bNd00`000000[lS/000000020000
0080[/CZ0`000000102/`NT000000:_0j@2[`>T3000000030:Znj000000000000080Y6fC00@00000
09MQS`2GHHl000000P2<Ehd01`000000PTn<089?S022Ch`0000007e=S@0000000P3``j400`000000
ZKgX0000000200000080ZKgX00<000000:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX00<0
000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP0000000000004000000060:Vmj00000000000
0000002Y_NP000000P2Y_NP3000002@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0G0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool01P3oool200000400oooo00<000000:K8lP2Vb?801P000000102Xbo800000
0000000000020:[=lP8000000P2/cO4300000080[/c_0P0000020:o9k@030000002_bNd0[lW]0080
00000P2^aN/3000000040:g2j@000000[<7Y0:c1j@<0000000<0ZkoX0000000000000`0000020:A]
T`040000002GHHl0Uf6?00000080S5N=00L00000089?S022Ch`0PTn<0000001mCHd000000080l<>Q
0P0000020:Vmj0030000002Y_NP0ZKgX00<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP0
000000000004000000060:Vmj000000000000000002Y_NP000000P2Y_NP3000000040:Vmj0000000
ZKgX0:Vmj0<00000:03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo0000
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo03h0oooo0P0000020:O9l@030000002Wb_80Yl[b0080
00000P2Ybo43000000040:c<l@000000000000000080[L__0`000000102^bNh000000:o9k@2_bNd3
000000040:k6k0000000000000000080[L?Z00<000000:g2j@0000000P0000020:^oj08000000P2Z
_^P300000080Y6fC00@0000009MQS`2GHHl000000`2<Ehd02P000000PTn<089?S0000000ODf=0000
003``j4000000:Vmj00000020:Vmj0<0000000<0ZKgX000000000000100000001P2Y_NP000000000
00000000ZKgX00000080ZKgX0`0000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000
ZKgX00000002000002/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`00
00@0oooo0000000000000000103oool2000000@0oooo0P00000<0?ooo`030000003oool0oooo03l0
oooo1@000000102Yb_4000000000000000020:_;l08000000P2]bnl3000000040:k9kP000000[/W^
0:k9kP<000000P2^an`200000080[/C[00<000000:g3jP2]`nX00P0000020:c1j@<0000000@0ZkkX
0000002Z_^P0Z[kX0`0000020:A]T`040000002GHHl0Uf6?000000<0S5N=00<00000089?S022Ch`0
0P0000020?33X@D0000000@0ZKgX00000000000000000P2Y_NP00`000000ZKgX0000000200000080
ZKgX00<000000:Vmj00000000P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000
ZKgX0:Vmj002000002l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`00
7@3oool00`000000oooo0?ooo`0o0?ooo`030000002YbO40ZLWa008000000P2Zb_03000000040:c:
k`000000000000000080[LW^00<000000:k9kP0000000P0000020:k7k0<0000000<0[/G[00000000
0000100000001P2/`NT00000000000000000ZkoX00000080ZkkX0`0000020:Znj0040000002TKI<0
Y6fC00000080Uf6?00D0000008aGS@2<Ehd0S5N=00000002089?S08000000P3``j4200000080ZKgX
0P0000020:Vmj0030000002Y_NP0ZKgX008000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX
00<000000:Vmj02Y_NP00`000000102Y_NP000000:Vmj02Y_NP300000380oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0G0?ooo`007P3oool200000400oooo0P000000102ZbO000000
0000000000020:_9k`8000000P2]bNh00`000000[LW^0:g9kP0200000080[/S]0`000000102^aN/0
00000000000000020:g3jP030000002]`^X00000008000000P2[`>T00`000000ZkoX000000020000
0080Z[kX1@0000001@2TKI<0000009MQS`2GHHl0000000<0S5N=00<00000089?S022Ch`00P000000
0`3``j4000000:Vmj003000000040:Vmj0000000ZKgX0:Vmj0<0000000@0ZKgX0000002Y_NP0ZKgX
0`0000000`2Y_NP0000000000004000000030:Vmj0000000000000@00000=P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01L0oooo000P0?ooo`030000003oool0oooo03l0oooo00<0
00000:_9k`2[bNl00`000000102/b>h000000:g9kP2]bNh3000000040:g8k@000000000000000080
[/K/0P0000020:g4j`030000002]`nX0[L?Z008000000P2/`NT500000080Z[kX0`0000001`2Z_^P0
00000:Vmj02Y_NP000000:A]T`0000000P2GHHl01@000000S5N=08aGS@2<Ehd000000080PTn<00<0
00000?33X@3``j400P000000102Y_NP000000:Vmj02Y_NP3000000030:Vmj0000000000000@00000
00H0ZKgX00000000000000000:Vmj00000020:Vmj0<00000?03oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01L0oooo000Q0?ooo`030000003oool0oooo03l0oooo0P0000020:c8kP03
0000002/b>h00000008000000P2]and200000080[LK/0`000000102]a>/000000:g4j`2]a>/30000
00040:c2j@000000000000000080Zl3Y00<000000:^oj00000000P0000020:Znj0030000002Z_^P0
000000<0000000D0Y6fC0000002GHHl0Uf6?0000000308aGS@0400000022Ch`0PTn<00000080l<>Q
1P000000102Y_NP000000000000000020:Vmj0030000002Y_NP00000008000000P2Y_NP00`000000
ZKgX0000000200000400oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`00
8P3oool00`000000oooo0?ooo`100?ooo`@000000P2]and3000000040:g6k0000000000000000080
[LG[00<000000:g4j`0000000P0000020:c2jP8000000P2/`>T00`000000Zl3Y0:_0j@0200000080
Z[kX00<000000:Znj02Z_^P00P0000020:Vmj0040000002Y_NP0000000000080Uf6?00D0000008aG
S@2<Ehd0S5N=00000002089?S0<000000P2Y_NP00`000000ZKgX0:Vmj00200000080ZKgX00<00000
0:Vmj02Y_NP00P0000020:Vmj0030000002Y_NP0ZKgX00800000A03oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo01H0oooo000S0?ooo`800000@@3oool00`000000[<O]000000020000
0080[LK]0P0000020:g5j`030000002]aN/0[LG[008000000P2]`nX3000000040:c1j@000000[<3Y
0:c0j@<0000000@0ZkoX0000002Z_^P0Z[kX0`0000000`2Z_^P000000000000500000080Uf6?00L0
000008aGS@2<Ehd0S5N=00000022Ch`000000080jlN_00<000000:Vmj02Y_NP00`000000102Y_NP0
00000:Vmj02Y_NP3000000040:Vmj0000000ZKgX0:Vmj0<00000AP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo01H0oooo000U0?ooo`030000003oool0oooo03l0oooo00<000000:c6
k@2/a^d00`000000102]aN`000000:g5j`2]aN/3000000040:g3jP000000000000000080[<;Y00<0
00000:c1j@0000000P0000000`2[_nP0000000000004000000040:Znj0000000000000000080ZKgX
00<000000:Vmj00000000P00000209MQS`070000002<Ehd0S5N=08aGS@000000PTn<000000020>_7
[`<0000000@0ZKgX0000002Y_NP0ZKgX0`0000000`2Y_NP0000000000004000004X0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0F0?ooo`009P3oool00`000000oooo0?ooo`0o0?oo
o`8000000P2/aN`500000080[LC[0P0000020:c2jP030000002/`^T0[<;Y008000000P2[`>T20000
0080ZkoX00<000000:Znj02Z_^P00P0000020:Znj0030000002Y_NP0ZKgX008000000P2Y_NP01000
0000Uf6?09MQS`00000308aGS@0500000022Ch`000000>_7[`0000000P2Y_NP500000080ZKgX0P00
001A0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool002L0oooo00<00000
0?ooo`3oool0@03oool2000000040:c4j`000000[LC[0:g4j`<0000000<0[<;Z0000000000001000
00001P2/`NT00000000000000000ZkoX00000080ZkoX0`000000102Z_^P000000:Znj02Z_^P30000
00030:Vmj00000000000008000000P2GHHl010000000S5N=08aGS@2<Ehd200000080jlN_0`000000
102Y_NP000000:Vmj02Y_NP3000005@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0F0?ooo`00:03oool200000440oooo00<000000:c4j`0000000P0000020:c3jP8000000P2/`NT0
0`000000[<7Y0000000200000080ZkoY00<000000:^oj00000000P0000020:Znj0D0000000@0ZKgX
00000000000000000P2Y_NP200000080Uf6?00@0000008aGS@2<Ehd0S5N=0P000000103[ajl00000
0:Vmj00000020:Vmj0<00000E`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0
oooo000Z0?ooo`030000003oool0oooo03l0oooo00<000000:c3j`2/`n/00`000000102/`^X00000
0:c1j@2/`NT200000080Zl3Y1@0000020:Znj0<0000000@0Z[kX0000002Z_^P0Z[kX0P0000020:Vm
j0030000002Y_NP0ZKgX00<0000000<0Uf6?0000002<Ehd00P2<Ehd2000000030>_7[`0000000000
00<00000F`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo000[0?ooo`03
0000003oool0oooo03l0oooo0P0000020:c2jP030000002/`^X000000080000000@0[<7Y00000000
000000000P2[_nP00`000000ZkoX00000002000000040:Znj0000000Z[kX0:Znj0<0000000@0ZKgX
0000002Y_NP0ZKgX0`0000000`2Y_NP00000000000020000000608aGS@00000000000000003[ajl0
0000H@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0oooo000/0?ooo`030000
003oool0oooo0400oooo100000020:c1j@8000000P2[`>T00`000000ZkoX0:^oj00200000080Z[kX
00<000000:Znj00000000P0000020:Znj0D0000000@0ZKgX00000000000000000P2Y_NP300000080
[lK[00<000000>_7[`000000H@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0
oooo000]0?ooo`800000@@3oool00`000000[<7Y00000002000000040:_0j@000000Zl3Y0:_0j@<0
000000<0ZkoX0000000000000`0000020:Znj0<0000000@0ZKgX0000002Y_NP0ZKgX0P0000020:Vm
j0030000002Y_NP0ZKgX00<000000P2_a^/2000006<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0E0?ooo`00;`3oool00`000000oooo0?ooo`0o0?ooo`030000002[`NT0Zl7Y00D0
00000P2[_nP200000080Z[kX00<000000:Znj00000000P000000102Z_^P000000:Vmj02Y_NP30000
00040:Vmj0000000ZKgX0:Vmj0<000000`3oool2000006H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0E0?ooo`00<03oool00`000000oooo0?ooo`0o0?ooo`80000000@0Zl3Y0000
002[_nT0ZkoY0`000000102[_nP000000:Znj02Z_^P200000080Z[kX1@0000020:Vmj0D00000K`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo000a0?ooo`030000003oool0
oooo03l0oooo00<000000:_0j@0000000P0000000`2[_nP0000000000004000000060:Znj0000000
00000000002Z_^P000000P2Y_NP3000007@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0E0?ooo`00<P3oool200000400oooo00<000000:^oj@2[_nT00P0000020:Znj0030000002Z
_^P0Z[kX008000000P2Z_^P00`000000Z[kX00000002000007P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0D0?ooo`00=03oool00`000000oooo0?ooo`0n0?ooo`80000000@0ZkoX
0000002Z_^P0Z[kX0`0000000`2Z_^P0000000000003000007`0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0D0?ooo`00=@3oool00`000000oooo0?ooo`0o0?ooo`@0000000@0Z[kX
0000000000000000PP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo000f
0?ooo`030000003oool0oooo03h0oooo00<000000:Znj02Z_^P00P0000250?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0503oool003L0oooo0P00000o0?ooo`800000R03oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo000i0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0
oooo000j0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01@0oooo000k0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo000l
0?ooo`800000>P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04`3oool003h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2;0?oo
o`050000003oool0oooo0?ooo`0000005@3oool003l0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`2;0?ooo`050000003oool0oooo0?ooo`0000005@3oool00400oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`2<0?ooo`040000003oool0oooo000001D0oooo00110?oo
o`800000=@3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0000001D0oooo00130?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0S@3oool00`000000oooo0000000E0?ooo`00
A03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`000000
503oool004D0oooo0P00000a0?ooo`030000003oool0oooo08l0oooo0P00000D0?ooo`00A`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo08h0oooo0`00000D0?ooo`00B03oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo08X0oooo1000000G0?ooo`00B@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo08L0oooo0`00000K0?ooo`00BP3oool2000002`0oooo
00<000000?ooo`3oool0P`3oool4000001h0oooo001<0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0O`3oool400000280oooo001=0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0N`3oool4000002H0oooo001>0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0M`3oool4000002X0oooo001?0?ooo`8000009`3oool00`000000oooo0?ooo`1d0?ooo`<0
0000;P3oool00540oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1`0?ooo`@00000
<@3oool00580oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1/0?ooo`@00000=@3o
ool005<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1X0?ooo`@00000>@3oool0
05@0oooo0P00000R0?ooo`030000003oool0oooo06@0oooo1000000m0?ooo`00EP3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0640oooo0`0000110?ooo`00E`3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo05d0oooo100000140?ooo`00F03oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo05X0oooo100000180?ooo`00F@3oool2000001`0oooo00<00000
0?ooo`3oool0EP3oool4000004`0oooo001K0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0DP3oool400000500oooo001L0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0C`3oool3000005@0oooo001M0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
B`3oool4000005L0oooo001N0?ooo`8000005`3oool00`000000oooo0?ooo`170?ooo`@00000F`3o
ool00600oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`130?ooo`@00000G`3oool0
0640oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0o0?ooo`@00000H`3oool00680
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`<00000I`3oool006<0oooo
0P00000B0?ooo`030000003oool0oooo03P0oooo1000001Z0?ooo`00I@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo03@0oooo1000001^0?ooo`00IP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0300oooo1000001b0?ooo`00I`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo02`0oooo1000001f0?ooo`00J03oool2000000d0oooo00<000000?ooo`3o
ool0:@3oool3000007X0oooo001Z0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
9@3oool4000007d0oooo001[0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08@3o
ool400000840oooo001/0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07@3oool4
000008D0oooo001]0?ooo`800000203oool00`000000oooo0?ooo`0I0?ooo`@00000R@3oool006l0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`<00000S@3oool00700oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`@00000T03oool00740oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`@00000U03oool00780oooo0P000003
0?ooo`030000003oool0oooo00X0oooo1000002H0?ooo`00M03oool010000000oooo0?ooo`000008
0?ooo`@00000W03oool007D0oooo00<000000?ooo`0000001@3oool300000:00oooo001f0?ooo`80
000000<0oooo0000000000000P00002S0?ooo`00M`3oool200000:L0oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0810885, -0.0127064, \
0.00386483, 0.00386483}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Two Wavelets with Lens", "Subsubsection",
  CellTags->{"AOG0.", "6.4.6", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
waveletSystem = {
\tMove[LineOfWavelets[10,NumberOfRays->2,PaddingFactor->.1],-50],
\tPlanoConvexLens[100,50,10],
\tMove[Screen[50],103]};\
\>", "Input",
  CellLabel->"In[523]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],

Cell[BoxData[
    \("Warning, LineOfWavelets will not be uniform."\)], "Print",
  CellLabel->"From In[523]:=",
  CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],

Cell[BoxData[
    \("Set PaddingFactor greater or equal to 1 for uniform illumination."\)], \
"Print",
  CellLabel->"From In[523]:=",
  CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[waveletSystem,ShowGaussian->True,PlotType->TopView];\
\>", "Input",
  CellLabel->"In[524]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3468 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.335043 0.00622468 0.182921 0.00622468 [
[.36617 .00826 -5.03125 -6 ]
[.36617 .00826 5.03125 6 ]
[.97618 .00826 -4.75 -6 ]
[.97618 .00826 4.75 6 ]
[ 0 0 0 0 ]
[ 1 .3468 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.37502 .0273 m
.39729 .0273 L
.39729 .07918 L
.35216 .07918 L
.37502 .0273 L
F
.35216 .07918 m
.39729 .07918 L
.39729 .13105 L
.33924 .13105 L
.35216 .07918 L
F
.33924 .13105 m
.39729 .13105 L
.39729 .18292 L
.33504 .18292 L
.33924 .13105 L
F
.33504 .18292 m
.39729 .18292 L
.39729 .23479 L
.33924 .23479 L
.33504 .18292 L
F
.33924 .23479 m
.39729 .23479 L
.39729 .28667 L
.35216 .28667 L
.33924 .23479 L
F
.35216 .28667 m
.39729 .28667 L
.39729 .33854 L
.37502 .33854 L
.35216 .28667 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.37502 .0273 m
.35216 .07918 L
.33924 .13105 L
.33504 .18292 L
.33924 .23479 L
.35216 .28667 L
.37502 .33854 L
.39729 .33854 L
.39729 .28667 L
.39729 .23479 L
.39729 .18292 L
.39729 .13105 L
.39729 .07918 L
.39729 .0273 L
.37502 .0273 L
s
.5 g
.37502 .18292 m
.39729 .18292 L
.39729 .18292 L
.35216 .18292 L
.37502 .18292 L
F
.35216 .18292 m
.39729 .18292 L
.39729 .18292 L
.33924 .18292 L
.35216 .18292 L
F
.33924 .18292 m
.39729 .18292 L
.39729 .18292 L
.33504 .18292 L
.33924 .18292 L
F
.33504 .18292 m
.39729 .18292 L
.39729 .18292 L
.33924 .18292 L
.33504 .18292 L
F
.33924 .18292 m
.39729 .18292 L
.39729 .18292 L
.35216 .18292 L
.33924 .18292 L
F
.35216 .18292 m
.39729 .18292 L
.39729 .18292 L
.37502 .18292 L
.35216 .18292 L
F
0 g
.37502 .18292 m
.35216 .18292 L
.33924 .18292 L
.33504 .18292 L
.33924 .18292 L
.35216 .18292 L
.37502 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.37502 .18292 L
s
.37502 .33854 m
.39729 .33854 L
.39729 .33324 L
.37502 .33324 L
.37502 .33854 L
s
.37502 .33324 m
.39729 .33324 L
.39729 .31769 L
.37502 .31769 L
.37502 .33324 L
s
.37502 .31769 m
.39729 .31769 L
.39729 .29296 L
.37502 .29296 L
.37502 .31769 L
s
.37502 .29296 m
.39729 .29296 L
.39729 .26073 L
.37502 .26073 L
.37502 .29296 L
s
.37502 .26073 m
.39729 .26073 L
.39729 .2232 L
.37502 .2232 L
.37502 .26073 L
s
.37502 .2232 m
.39729 .2232 L
.39729 .18292 L
.37502 .18292 L
.37502 .2232 L
s
.37502 .18292 m
.39729 .18292 L
.39729 .14264 L
.37502 .14264 L
.37502 .18292 L
s
.37502 .14264 m
.39729 .14264 L
.39729 .10511 L
.37502 .10511 L
.37502 .14264 L
s
.37502 .10511 m
.39729 .10511 L
.39729 .07288 L
.37502 .07288 L
.37502 .10511 L
s
.37502 .07288 m
.39729 .07288 L
.39729 .04815 L
.37502 .04815 L
.37502 .07288 L
s
.37502 .04815 m
.39729 .04815 L
.39729 .03261 L
.37502 .03261 L
.37502 .04815 L
s
.37502 .03261 m
.39729 .03261 L
.39729 .0273 L
.37502 .0273 L
.37502 .03261 L
s
.37502 .0273 m
.39729 .0273 L
.39729 .03261 L
.37502 .03261 L
.37502 .0273 L
s
.37502 .03261 m
.39729 .03261 L
.39729 .04815 L
.37502 .04815 L
.37502 .03261 L
s
.37502 .04815 m
.39729 .04815 L
.39729 .07288 L
.37502 .07288 L
.37502 .04815 L
s
.37502 .07288 m
.39729 .07288 L
.39729 .10511 L
.37502 .10511 L
.37502 .07288 L
s
.37502 .10511 m
.39729 .10511 L
.39729 .14264 L
.37502 .14264 L
.37502 .10511 L
s
.37502 .14264 m
.39729 .14264 L
.39729 .18292 L
.37502 .18292 L
.37502 .14264 L
s
.37502 .18292 m
.39729 .18292 L
.39729 .2232 L
.37502 .2232 L
.37502 .18292 L
s
.37502 .2232 m
.39729 .2232 L
.39729 .26073 L
.37502 .26073 L
.37502 .2232 L
s
.37502 .26073 m
.39729 .26073 L
.39729 .29296 L
.37502 .29296 L
.37502 .26073 L
s
.37502 .29296 m
.39729 .29296 L
.39729 .31769 L
.37502 .31769 L
.37502 .29296 L
s
.37502 .31769 m
.39729 .31769 L
.39729 .33324 L
.37502 .33324 L
.37502 .31769 L
s
.37502 .33324 m
.39729 .33324 L
.39729 .33854 L
.37502 .33854 L
.37502 .33324 L
s
.97618 .0273 m
.97618 .07918 L
.97618 .13105 L
.97618 .18292 L
.97618 .23479 L
.97618 .28667 L
.97618 .33854 L
.97618 .33854 L
.97618 .28667 L
.97618 .23479 L
.97618 .18292 L
.97618 .13105 L
.97618 .07918 L
.97618 .0273 L
.97618 .0273 L
s
.97618 .18292 m
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
s
.97618 .33854 m
.97618 .33324 L
.97618 .31769 L
.97618 .29296 L
.97618 .26073 L
.97618 .2232 L
.97618 .18292 L
.97618 .14264 L
.97618 .10511 L
.97618 .07288 L
.97618 .04815 L
.97618 .03261 L
.97618 .0273 L
.97618 .03261 L
.97618 .04815 L
.97618 .07288 L
.97618 .10511 L
.97618 .14264 L
.97618 .18292 L
.97618 .2232 L
.97618 .26073 L
.97618 .29296 L
.97618 .31769 L
.97618 .33324 L
.97618 .33854 L
s
0 0 0 r
gsave
.36617 .00826 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
69.062 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97618 .00826 -65.75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
68.500 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.039 .916 .04 r
1 Mabswid
.02381 .15802 m
.0397 .15802 L
.05558 .15802 L
.07147 .15802 L
.08735 .15802 L
.10324 .15802 L
.11912 .15802 L
.13501 .15802 L
.15089 .15802 L
.16678 .15802 L
.18267 .15802 L
.19855 .15802 L
.21444 .15802 L
.23032 .15802 L
.24621 .15802 L
.26209 .15802 L
.27798 .15802 L
.29387 .15802 L
.30975 .15802 L
.32564 .15802 L
.34131 .15817 L
.3572 .15859 L
.37308 .15901 L
.38896 .15943 L
.40473 .15994 L
.42061 .16058 L
.43648 .16122 L
.45235 .16186 L
.46823 .16249 L
.4841 .16313 L
.49998 .16377 L
.51585 .1644 L
.53172 .16504 L
.5476 .16568 L
.56347 .16632 L
.57934 .16695 L
.59522 .16759 L
.61109 .16823 L
.62697 .16887 L
.64284 .1695 L
.65871 .17014 L
.67459 .17078 L
.69046 .17142 L
.70633 .17205 L
.72221 .17269 L
.73808 .17333 L
.75395 .17397 L
.76983 .1746 L
.7857 .17524 L
.80158 .17588 L
Mistroke
.81745 .17652 L
.83332 .17715 L
.8492 .17779 L
.86507 .17843 L
.88094 .17907 L
.89682 .17971 L
.91269 .18035 L
.92856 .18099 L
.94444 .18163 L
.96031 .18229 L
.97618 .18303 L
Mfstroke
.02381 .14557 m
.0397 .14557 L
.05558 .14557 L
.07147 .14557 L
.08735 .14557 L
.10324 .14557 L
.11912 .14557 L
.13501 .14557 L
.15089 .14557 L
.16678 .14557 L
.18267 .14557 L
.19855 .14557 L
.21444 .14557 L
.23032 .14557 L
.24621 .14557 L
.26209 .14557 L
.27798 .14557 L
.29387 .14557 L
.30975 .14557 L
.32564 .14557 L
.34173 .14576 L
.3576 .14639 L
.37347 .14702 L
.38935 .14765 L
.40531 .14845 L
.42117 .14941 L
.43703 .15037 L
.45288 .15132 L
.46874 .15228 L
.4846 .15324 L
.50046 .1542 L
.51631 .15516 L
.53217 .15612 L
.54803 .15707 L
.56389 .15803 L
.57974 .15899 L
.5956 .15995 L
.61146 .16091 L
.62732 .16187 L
.64317 .16282 L
.65903 .16378 L
.67489 .16474 L
.69075 .1657 L
.70661 .16666 L
.72246 .16762 L
.73832 .16857 L
.75418 .16953 L
.77004 .17049 L
.78589 .17145 L
.80175 .17241 L
Mistroke
.81761 .17337 L
.83347 .17432 L
.84932 .17528 L
.86518 .17624 L
.88104 .1772 L
.8969 .17815 L
.91275 .17911 L
.92861 .18007 L
.94447 .18102 L
.96033 .18196 L
.97619 .18281 L
Mfstroke
0 0 0 r
.02381 .1518 m
.33655 .1518 L
s
% Start of user PostScript
-50. -5. 0.24154 -5. MAarrowhead1
% End of user PostScript
.33655 .1518 m
.39729 .15381 L
s
% Start of user PostScript
0.24154 -5. 10. -4.67726 MAarrowhead1
% End of user PostScript
.39729 .15381 m
.97618 .18292 L
s
% Start of user PostScript
10. -4.67726 103. -0.000304527 MAarrowhead1
% End of user PostScript
.97618 .18292 m
.97618 .18292 L
s
% Start of user PostScript
103. -0.000304527 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .1462 m
.02381 .14657 L
.02381 .14694 L
.02381 .14732 L
.02381 .14769 L
.02381 .14806 L
.02381 .14844 L
.02381 .14881 L
.02381 .14918 L
.02381 .14956 L
.02381 .14993 L
.02381 .1503 L
.02381 .15068 L
.02381 .15105 L
.02381 .15142 L
.02381 .1518 L
.02381 .15217 L
.02381 .15255 L
.02381 .15292 L
.02381 .15329 L
.02381 .15367 L
.02381 .15404 L
.02381 .15441 L
.02381 .15479 L
.02381 .15516 L
.02381 .15553 L
.02381 .15591 L
.02381 .15628 L
.02381 .15665 L
.02381 .15703 L
.02381 .1574 L
s
.04764 .1462 m
.04764 .14657 L
.04764 .14694 L
.04764 .14732 L
.04764 .14769 L
.04764 .14806 L
.04764 .14844 L
.04764 .14881 L
.04764 .14918 L
.04764 .14956 L
.04764 .14993 L
.04764 .1503 L
.04764 .15068 L
.04764 .15105 L
.04764 .15142 L
.04764 .1518 L
.04764 .15217 L
.04764 .15255 L
.04764 .15292 L
.04764 .15329 L
.04764 .15367 L
.04764 .15404 L
.04764 .15441 L
.04764 .15479 L
.04764 .15516 L
.04764 .15553 L
.04764 .15591 L
.04764 .15628 L
.04764 .15665 L
.04764 .15703 L
.04764 .1574 L
s
.07147 .1462 m
.07147 .14657 L
.07147 .14694 L
.07147 .14732 L
.07147 .14769 L
.07147 .14806 L
.07147 .14844 L
.07147 .14881 L
.07147 .14918 L
.07147 .14956 L
.07147 .14993 L
.07147 .1503 L
.07147 .15068 L
.07147 .15105 L
.07147 .15142 L
.07147 .1518 L
.07147 .15217 L
.07147 .15255 L
.07147 .15292 L
.07147 .15329 L
.07147 .15367 L
.07147 .15404 L
.07147 .15441 L
.07147 .15479 L
.07147 .15516 L
.07147 .15553 L
.07147 .15591 L
.07147 .15628 L
.07147 .15665 L
.07147 .15703 L
.07147 .1574 L
s
.0953 .1462 m
.0953 .14657 L
.0953 .14694 L
.0953 .14732 L
.0953 .14769 L
.0953 .14806 L
.0953 .14844 L
.0953 .14881 L
.0953 .14918 L
.0953 .14956 L
.0953 .14993 L
.0953 .1503 L
.0953 .15068 L
.0953 .15105 L
.0953 .15142 L
.0953 .1518 L
.0953 .15217 L
.0953 .15255 L
.0953 .15292 L
.0953 .15329 L
.0953 .15367 L
.0953 .15404 L
.0953 .15441 L
.0953 .15479 L
.0953 .15516 L
.0953 .15553 L
.0953 .15591 L
.0953 .15628 L
.0953 .15665 L
.0953 .15703 L
.0953 .1574 L
s
.11912 .1462 m
.11912 .14657 L
.11912 .14694 L
.11912 .14732 L
.11912 .14769 L
.11912 .14806 L
.11912 .14844 L
.11912 .14881 L
.11912 .14918 L
.11912 .14956 L
.11912 .14993 L
.11912 .1503 L
.11912 .15068 L
.11912 .15105 L
.11912 .15142 L
.11912 .1518 L
.11912 .15217 L
.11912 .15255 L
.11912 .15292 L
.11912 .15329 L
.11912 .15367 L
.11912 .15404 L
.11912 .15441 L
.11912 .15479 L
.11912 .15516 L
.11912 .15553 L
.11912 .15591 L
.11912 .15628 L
.11912 .15665 L
.11912 .15703 L
.11912 .1574 L
s
.14295 .1462 m
.14295 .14657 L
.14295 .14694 L
.14295 .14732 L
.14295 .14769 L
.14295 .14806 L
.14295 .14844 L
.14295 .14881 L
.14295 .14918 L
.14295 .14956 L
.14295 .14993 L
.14295 .1503 L
.14295 .15068 L
.14295 .15105 L
.14295 .15142 L
.14295 .1518 L
.14295 .15217 L
.14295 .15255 L
.14295 .15292 L
.14295 .15329 L
.14295 .15367 L
.14295 .15404 L
.14295 .15441 L
.14295 .15479 L
.14295 .15516 L
.14295 .15553 L
.14295 .15591 L
.14295 .15628 L
.14295 .15665 L
.14295 .15703 L
.14295 .1574 L
s
.16678 .1462 m
.16678 .14657 L
.16678 .14694 L
.16678 .14732 L
.16678 .14769 L
.16678 .14806 L
.16678 .14844 L
.16678 .14881 L
.16678 .14918 L
.16678 .14956 L
.16678 .14993 L
.16678 .1503 L
.16678 .15068 L
.16678 .15105 L
.16678 .15142 L
.16678 .1518 L
.16678 .15217 L
.16678 .15255 L
.16678 .15292 L
.16678 .15329 L
.16678 .15367 L
.16678 .15404 L
.16678 .15441 L
.16678 .15479 L
.16678 .15516 L
.16678 .15553 L
.16678 .15591 L
.16678 .15628 L
.16678 .15665 L
.16678 .15703 L
.16678 .1574 L
s
.19061 .1462 m
.19061 .14657 L
.19061 .14694 L
.19061 .14732 L
.19061 .14769 L
.19061 .14806 L
.19061 .14844 L
.19061 .14881 L
.19061 .14918 L
.19061 .14956 L
.19061 .14993 L
.19061 .1503 L
.19061 .15068 L
.19061 .15105 L
.19061 .15142 L
.19061 .1518 L
.19061 .15217 L
.19061 .15255 L
.19061 .15292 L
.19061 .15329 L
.19061 .15367 L
.19061 .15404 L
.19061 .15441 L
.19061 .15479 L
.19061 .15516 L
.19061 .15553 L
.19061 .15591 L
.19061 .15628 L
.19061 .15665 L
.19061 .15703 L
.19061 .1574 L
s
.21444 .1462 m
.21444 .14657 L
.21444 .14694 L
.21444 .14732 L
.21444 .14769 L
.21444 .14806 L
.21444 .14844 L
.21444 .14881 L
.21444 .14918 L
.21444 .14956 L
.21444 .14993 L
.21444 .1503 L
.21444 .15068 L
.21444 .15105 L
.21444 .15142 L
.21444 .1518 L
.21444 .15217 L
.21444 .15255 L
.21444 .15292 L
.21444 .15329 L
.21444 .15367 L
.21444 .15404 L
.21444 .15441 L
.21444 .15479 L
.21444 .15516 L
.21444 .15553 L
.21444 .15591 L
.21444 .15628 L
.21444 .15665 L
.21444 .15703 L
.21444 .1574 L
s
.23827 .1462 m
.23827 .14657 L
.23827 .14694 L
.23827 .14732 L
.23827 .14769 L
.23827 .14806 L
.23827 .14844 L
.23827 .14881 L
.23827 .14918 L
.23827 .14956 L
.23827 .14993 L
.23827 .1503 L
.23827 .15068 L
.23827 .15105 L
.23827 .15142 L
.23827 .1518 L
.23827 .15217 L
.23827 .15255 L
.23827 .15292 L
.23827 .15329 L
.23827 .15367 L
.23827 .15404 L
.23827 .15441 L
.23827 .15479 L
.23827 .15516 L
.23827 .15553 L
.23827 .15591 L
.23827 .15628 L
.23827 .15665 L
.23827 .15703 L
.23827 .1574 L
s
.26209 .1462 m
.26209 .14657 L
.26209 .14694 L
.26209 .14732 L
.26209 .14769 L
.26209 .14806 L
.26209 .14844 L
.26209 .14881 L
.26209 .14918 L
.26209 .14956 L
.26209 .14993 L
.26209 .1503 L
.26209 .15068 L
.26209 .15105 L
.26209 .15142 L
.26209 .1518 L
.26209 .15217 L
.26209 .15255 L
.26209 .15292 L
.26209 .15329 L
.26209 .15367 L
.26209 .15404 L
.26209 .15441 L
.26209 .15479 L
.26209 .15516 L
.26209 .15553 L
.26209 .15591 L
.26209 .15628 L
.26209 .15665 L
.26209 .15703 L
.26209 .1574 L
s
.28592 .1462 m
.28592 .14657 L
.28592 .14694 L
.28592 .14732 L
.28592 .14769 L
.28592 .14806 L
.28592 .14844 L
.28592 .14881 L
.28592 .14918 L
.28592 .14956 L
.28592 .14993 L
.28592 .1503 L
.28592 .15068 L
.28592 .15105 L
.28592 .15142 L
.28592 .1518 L
.28592 .15217 L
.28592 .15255 L
.28592 .15292 L
.28592 .15329 L
.28592 .15367 L
.28592 .15404 L
.28592 .15441 L
.28592 .15479 L
.28592 .15516 L
.28592 .15553 L
.28592 .15591 L
.28592 .15628 L
.28592 .15665 L
.28592 .15703 L
.28592 .1574 L
s
.30975 .1462 m
.30975 .14657 L
.30975 .14694 L
.30975 .14732 L
.30975 .14769 L
.30975 .14806 L
.30975 .14844 L
.30975 .14881 L
.30975 .14918 L
.30975 .14956 L
.30975 .14993 L
.30975 .1503 L
.30975 .15068 L
.30975 .15105 L
.30975 .15142 L
.30975 .1518 L
.30975 .15217 L
.30975 .15255 L
.30975 .15292 L
.30975 .15329 L
.30975 .15367 L
.30975 .15404 L
.30975 .15441 L
.30975 .15479 L
.30975 .15516 L
.30975 .15553 L
.30975 .15591 L
.30975 .15628 L
.30975 .15665 L
.30975 .15703 L
.30975 .1574 L
s
.33358 .1462 m
.33358 .14657 L
.33358 .14694 L
.33358 .14732 L
.33358 .14769 L
.33358 .14806 L
.33358 .14844 L
.33358 .14881 L
.33358 .14918 L
.33358 .14956 L
.33358 .14993 L
.33358 .1503 L
.33358 .15068 L
.33358 .15105 L
.33358 .15142 L
.33358 .1518 L
.33358 .15217 L
.33358 .15255 L
.33358 .15292 L
.33358 .15329 L
.33358 .15367 L
.33358 .15404 L
.33358 .15441 L
.33358 .15479 L
.33358 .15516 L
.33358 .15553 L
.33358 .15591 L
.33358 .15628 L
.33358 .15665 L
.33358 .15703 L
.33358 .1574 L
s
.3576 .147 m
.35758 .14736 L
.35757 .14773 L
.35756 .1481 L
.35754 .14846 L
.35753 .14883 L
.35751 .14919 L
.3575 .14956 L
.35749 .14993 L
.35747 .15029 L
.35746 .15066 L
.35745 .15102 L
.35743 .15139 L
.35742 .15176 L
.35741 .15212 L
.3574 .15249 L
.35739 .15285 L
.35737 .15322 L
.35736 .15359 L
.35735 .15395 L
.35734 .15432 L
.35733 .15468 L
.35732 .15505 L
.35731 .15542 L
.3573 .15578 L
.35729 .15615 L
.35728 .15651 L
.35726 .15688 L
.35726 .15725 L
.35725 .15761 L
.35724 .15798 L
s
.38141 .14793 m
.38139 .14829 L
.38138 .14864 L
.38137 .149 L
.38135 .14935 L
.38134 .14971 L
.38133 .15007 L
.38131 .15042 L
.3813 .15078 L
.38129 .15114 L
.38127 .15149 L
.38126 .15185 L
.38125 .15221 L
.38124 .15256 L
.38122 .15292 L
.38121 .15328 L
.3812 .15363 L
.38119 .15399 L
.38118 .15434 L
.38117 .1547 L
.38116 .15506 L
.38115 .15541 L
.38113 .15577 L
.38112 .15613 L
.38111 .15648 L
.3811 .15684 L
.38109 .1572 L
.38108 .15755 L
.38107 .15791 L
.38106 .15827 L
.38106 .15862 L
s
.40533 .14903 m
.4053 .14937 L
.40528 .14971 L
.40526 .15006 L
.40524 .1504 L
.40522 .15075 L
.40519 .15109 L
.40517 .15144 L
.40515 .15178 L
.40513 .15213 L
.40511 .15247 L
.4051 .15282 L
.40508 .15316 L
.40506 .15351 L
.40504 .15385 L
.40502 .1542 L
.40501 .15454 L
.40499 .15489 L
.40497 .15523 L
.40496 .15558 L
.40494 .15592 L
.40493 .15627 L
.40491 .15661 L
.4049 .15696 L
.40488 .1573 L
.40487 .15765 L
.40486 .15799 L
.40484 .15834 L
.40483 .15868 L
.40482 .15903 L
.40481 .15937 L
s
.42911 .15044 m
.42909 .15077 L
.42907 .1511 L
.42905 .15143 L
.42903 .15176 L
.42901 .15209 L
.42899 .15242 L
.42897 .15275 L
.42895 .15308 L
.42893 .15341 L
.42891 .15374 L
.42889 .15407 L
.42887 .1544 L
.42886 .15473 L
.42884 .15506 L
.42882 .15539 L
.4288 .15572 L
.42879 .15605 L
.42877 .15638 L
.42876 .15671 L
.42874 .15704 L
.42873 .15738 L
.42871 .15771 L
.4287 .15804 L
.42869 .15837 L
.42867 .1587 L
.42866 .15903 L
.42865 .15936 L
.42864 .15969 L
.42863 .16002 L
.42861 .16035 L
s
.4529 .15185 m
.45288 .15217 L
.45286 .15248 L
.45284 .1528 L
.45282 .15312 L
.4528 .15343 L
.45278 .15375 L
.45276 .15406 L
.45274 .15438 L
.45272 .15469 L
.4527 .15501 L
.45269 .15533 L
.45267 .15564 L
.45265 .15596 L
.45264 .15627 L
.45262 .15659 L
.4526 .15691 L
.45259 .15722 L
.45257 .15754 L
.45256 .15785 L
.45254 .15817 L
.45253 .15849 L
.45252 .1588 L
.4525 .15912 L
.45249 .15943 L
.45248 .15975 L
.45247 .16007 L
.45245 .16038 L
.45244 .1607 L
.45243 .16101 L
.45242 .16133 L
s
.47668 .15327 m
.47666 .15357 L
.47664 .15387 L
.47662 .15417 L
.47661 .15447 L
.47659 .15477 L
.47657 .15507 L
.47655 .15537 L
.47653 .15568 L
.47652 .15598 L
.4765 .15628 L
.47648 .15658 L
.47646 .15688 L
.47645 .15718 L
.47643 .15748 L
.47642 .15779 L
.4764 .15809 L
.47639 .15839 L
.47637 .15869 L
.47636 .15899 L
.47635 .15929 L
.47633 .1596 L
.47632 .1599 L
.47631 .1602 L
.4763 .1605 L
.47628 .1608 L
.47627 .1611 L
.47626 .16141 L
.47625 .16171 L
.47624 .16201 L
.47623 .16231 L
s
.50047 .15468 m
.50045 .15497 L
.50043 .15525 L
.50041 .15554 L
.50039 .15583 L
.50038 .15611 L
.50036 .1564 L
.50034 .15669 L
.50033 .15697 L
.50031 .15726 L
.50029 .15755 L
.50028 .15784 L
.50026 .15812 L
.50025 .15841 L
.50023 .1587 L
.50022 .15898 L
.5002 .15927 L
.50019 .15956 L
.50017 .15984 L
.50016 .16013 L
.50015 .16042 L
.50014 .16071 L
.50012 .16099 L
.50011 .16128 L
.5001 .16157 L
.50009 .16185 L
.50008 .16214 L
.50007 .16243 L
.50006 .16272 L
.50005 .163 L
.50004 .16329 L
s
.52426 .15609 m
.52424 .15637 L
.52422 .15664 L
.5242 .15691 L
.52418 .15718 L
.52417 .15745 L
.52415 .15773 L
.52413 .158 L
.52412 .15827 L
.5241 .15854 L
.52409 .15882 L
.52407 .15909 L
.52406 .15936 L
.52404 .15963 L
.52403 .15991 L
.52401 .16018 L
.524 .16045 L
.52399 .16073 L
.52398 .161 L
.52396 .16127 L
.52395 .16154 L
.52394 .16182 L
.52393 .16209 L
.52392 .16236 L
.5239 .16263 L
.52389 .16291 L
.52388 .16318 L
.52387 .16345 L
.52386 .16373 L
.52385 .164 L
.52384 .16427 L
s
.54804 .15751 m
.54802 .15776 L
.54801 .15802 L
.54799 .15828 L
.54797 .15854 L
.54796 .1588 L
.54794 .15905 L
.54793 .15931 L
.54791 .15957 L
.5479 .15983 L
.54788 .16009 L
.54787 .16034 L
.54785 .1606 L
.54784 .16086 L
.54783 .16112 L
.54781 .16138 L
.5478 .16163 L
.54779 .16189 L
.54778 .16215 L
.54776 .16241 L
.54775 .16267 L
.54774 .16293 L
.54773 .16318 L
.54772 .16344 L
.54771 .1637 L
.5477 .16396 L
.54769 .16422 L
.54768 .16448 L
.54767 .16473 L
.54766 .16499 L
.54765 .16525 L
s
.57183 .15892 m
.57181 .15916 L
.57179 .15941 L
.57178 .15965 L
.57176 .15989 L
.57175 .16014 L
.57173 .16038 L
.57172 .16062 L
.5717 .16087 L
.57169 .16111 L
.57168 .16136 L
.57166 .1616 L
.57165 .16184 L
.57164 .16209 L
.57162 .16233 L
.57161 .16257 L
.5716 .16282 L
.57159 .16306 L
.57158 .1633 L
.57156 .16355 L
.57155 .16379 L
.57154 .16404 L
.57153 .16428 L
.57152 .16452 L
.57151 .16477 L
.5715 .16501 L
.57149 .16526 L
.57148 .1655 L
.57148 .16574 L
.57147 .16599 L
.57146 .16623 L
s
.59561 .16033 m
.5956 .16056 L
.59558 .16079 L
.59557 .16102 L
.59555 .16125 L
.59554 .16148 L
.59552 .16171 L
.59551 .16194 L
.5955 .16217 L
.59548 .1624 L
.59547 .16262 L
.59546 .16285 L
.59545 .16308 L
.59543 .16331 L
.59542 .16354 L
.59541 .16377 L
.5954 .164 L
.59539 .16423 L
.59538 .16446 L
.59537 .16469 L
.59536 .16492 L
.59535 .16515 L
.59534 .16538 L
.59533 .1656 L
.59532 .16583 L
.59531 .16606 L
.5953 .16629 L
.59529 .16652 L
.59528 .16675 L
.59527 .16698 L
.59527 .16721 L
s
.6194 .16175 m
.61938 .16196 L
.61937 .16218 L
.61936 .16239 L
.61934 .16261 L
.61933 .16282 L
.61932 .16303 L
.6193 .16325 L
.61929 .16346 L
.61928 .16368 L
.61927 .16389 L
.61925 .16411 L
.61924 .16432 L
.61923 .16454 L
.61922 .16475 L
.61921 .16497 L
.6192 .16518 L
.61919 .1654 L
.61918 .16561 L
.61917 .16583 L
.61916 .16604 L
.61915 .16626 L
.61914 .16647 L
.61913 .16669 L
.61912 .1669 L
.61911 .16712 L
.6191 .16733 L
.6191 .16755 L
.61909 .16776 L
.61908 .16798 L
.61907 .16819 L
s
.64318 .16316 m
.64317 .16336 L
.64316 .16356 L
.64314 .16376 L
.64313 .16396 L
.64312 .16416 L
.64311 .16436 L
.64309 .16456 L
.64308 .16476 L
.64307 .16496 L
.64306 .16516 L
.64305 .16536 L
.64304 .16556 L
.64303 .16576 L
.64302 .16596 L
.64301 .16616 L
.643 .16636 L
.64299 .16656 L
.64298 .16677 L
.64297 .16697 L
.64296 .16717 L
.64295 .16737 L
.64294 .16757 L
.64293 .16777 L
.64293 .16797 L
.64292 .16817 L
.64291 .16837 L
.6429 .16857 L
.6429 .16877 L
.64289 .16897 L
.64288 .16917 L
s
.66697 .16457 m
.66696 .16476 L
.66694 .16494 L
.66693 .16513 L
.66692 .16532 L
.66691 .1655 L
.6669 .16569 L
.66689 .16587 L
.66688 .16606 L
.66687 .16625 L
.66685 .16643 L
.66684 .16662 L
.66683 .1668 L
.66682 .16699 L
.66681 .16717 L
.66681 .16736 L
.6668 .16755 L
.66679 .16773 L
.66678 .16792 L
.66677 .1681 L
.66676 .16829 L
.66675 .16848 L
.66675 .16866 L
.66674 .16885 L
.66673 .16903 L
.66672 .16922 L
.66672 .16941 L
.66671 .16959 L
.6667 .16978 L
.6667 .16996 L
.66669 .17015 L
s
.69076 .16599 m
.69074 .16616 L
.69073 .16633 L
.69072 .1665 L
.69071 .16667 L
.6907 .16684 L
.69069 .16701 L
.69068 .16719 L
.69067 .16736 L
.69066 .16753 L
.69065 .1677 L
.69064 .16787 L
.69063 .16804 L
.69062 .16821 L
.69061 .16839 L
.6906 .16856 L
.6906 .16873 L
.69059 .1689 L
.69058 .16907 L
.69057 .16924 L
.69056 .16942 L
.69056 .16959 L
.69055 .16976 L
.69054 .16993 L
.69053 .1701 L
.69053 .17027 L
.69052 .17044 L
.69051 .17062 L
.69051 .17079 L
.6905 .17096 L
.6905 .17113 L
s
.71454 .1674 m
.71453 .16756 L
.71452 .16771 L
.71451 .16787 L
.7145 .16803 L
.71449 .16818 L
.71448 .16834 L
.71447 .1685 L
.71446 .16866 L
.71445 .16881 L
.71444 .16897 L
.71444 .16913 L
.71443 .16928 L
.71442 .16944 L
.71441 .1696 L
.7144 .16975 L
.71439 .16991 L
.71439 .17007 L
.71438 .17023 L
.71437 .17038 L
.71436 .17054 L
.71436 .1707 L
.71435 .17085 L
.71434 .17101 L
.71434 .17117 L
.71433 .17133 L
.71433 .17148 L
.71432 .17164 L
.71431 .1718 L
.71431 .17195 L
.7143 .17211 L
s
.73833 .16881 m
.73832 .16896 L
.73831 .1691 L
.7383 .16924 L
.73829 .16938 L
.73828 .16953 L
.73827 .16967 L
.73826 .16981 L
.73825 .16995 L
.73825 .1701 L
.73824 .17024 L
.73823 .17038 L
.73822 .17052 L
.73822 .17067 L
.73821 .17081 L
.7382 .17095 L
.73819 .17109 L
.73819 .17124 L
.73818 .17138 L
.73817 .17152 L
.73817 .17166 L
.73816 .17181 L
.73815 .17195 L
.73815 .17209 L
.73814 .17224 L
.73814 .17238 L
.73813 .17252 L
.73813 .17266 L
.73812 .17281 L
.73812 .17295 L
.73811 .17309 L
s
.76211 .17023 m
.7621 .17035 L
.7621 .17048 L
.76209 .17061 L
.76208 .17074 L
.76207 .17087 L
.76206 .17099 L
.76206 .17112 L
.76205 .17125 L
.76204 .17138 L
.76203 .17151 L
.76203 .17164 L
.76202 .17176 L
.76201 .17189 L
.76201 .17202 L
.762 .17215 L
.76199 .17228 L
.76199 .1724 L
.76198 .17253 L
.76197 .17266 L
.76197 .17279 L
.76196 .17292 L
.76196 .17305 L
.76195 .17317 L
.76195 .1733 L
.76194 .17343 L
.76194 .17356 L
.76193 .17369 L
.76193 .17382 L
.76192 .17394 L
.76192 .17407 L
s
.7859 .17164 m
.78589 .17175 L
.78588 .17187 L
.78588 .17198 L
.78587 .17209 L
.78586 .17221 L
.78585 .17232 L
.78585 .17244 L
.78584 .17255 L
.78583 .17266 L
.78583 .17278 L
.78582 .17289 L
.78582 .173 L
.78581 .17312 L
.7858 .17323 L
.7858 .17335 L
.78579 .17346 L
.78579 .17357 L
.78578 .17369 L
.78578 .1738 L
.78577 .17391 L
.78577 .17403 L
.78576 .17414 L
.78576 .17426 L
.78575 .17437 L
.78575 .17448 L
.78574 .1746 L
.78574 .17471 L
.78573 .17482 L
.78573 .17494 L
.78573 .17505 L
s
.80968 .17305 m
.80968 .17315 L
.80967 .17325 L
.80966 .17335 L
.80966 .17345 L
.80965 .17355 L
.80965 .17365 L
.80964 .17375 L
.80963 .17385 L
.80963 .17395 L
.80962 .17405 L
.80962 .17414 L
.80961 .17424 L
.80961 .17434 L
.8096 .17444 L
.8096 .17454 L
.80959 .17464 L
.80959 .17474 L
.80958 .17484 L
.80958 .17494 L
.80957 .17504 L
.80957 .17514 L
.80956 .17524 L
.80956 .17534 L
.80956 .17544 L
.80955 .17554 L
.80955 .17563 L
.80954 .17573 L
.80954 .17583 L
.80954 .17593 L
.80953 .17603 L
s
.83347 .17447 m
.83346 .17455 L
.83346 .17464 L
.83345 .17472 L
.83345 .17481 L
.83344 .17489 L
.83344 .17497 L
.83343 .17506 L
.83343 .17514 L
.83342 .17523 L
.83342 .17531 L
.83341 .1754 L
.83341 .17548 L
.8334 .17557 L
.8334 .17565 L
.83339 .17574 L
.83339 .17582 L
.83339 .17591 L
.83338 .17599 L
.83338 .17608 L
.83337 .17616 L
.83337 .17625 L
.83337 .17633 L
.83336 .17642 L
.83336 .1765 L
.83336 .17659 L
.83335 .17667 L
.83335 .17676 L
.83335 .17684 L
.83334 .17693 L
.83334 .17701 L
s
.85726 .17588 m
.85725 .17595 L
.85725 .17602 L
.85724 .17609 L
.85724 .17616 L
.85723 .17623 L
.85723 .1763 L
.85722 .17637 L
.85722 .17644 L
.85722 .17651 L
.85721 .17658 L
.85721 .17665 L
.8572 .17672 L
.8572 .17679 L
.8572 .17686 L
.85719 .17694 L
.85719 .17701 L
.85719 .17708 L
.85718 .17715 L
.85718 .17722 L
.85718 .17729 L
.85717 .17736 L
.85717 .17743 L
.85717 .1775 L
.85716 .17757 L
.85716 .17764 L
.85716 .17771 L
.85716 .17778 L
.85715 .17785 L
.85715 .17792 L
.85715 .17799 L
s
.88104 .17729 m
.88104 .17735 L
.88103 .1774 L
.88103 .17746 L
.88103 .17752 L
.88102 .17757 L
.88102 .17763 L
.88102 .17768 L
.88101 .17774 L
.88101 .1778 L
.88101 .17785 L
.881 .17791 L
.881 .17796 L
.881 .17802 L
.88099 .17808 L
.88099 .17813 L
.88099 .17819 L
.88099 .17824 L
.88098 .1783 L
.88098 .17836 L
.88098 .17841 L
.88098 .17847 L
.88097 .17853 L
.88097 .17858 L
.88097 .17864 L
.88097 .17869 L
.88096 .17875 L
.88096 .17881 L
.88096 .17886 L
.88096 .17892 L
.88096 .17897 L
s
.90483 .1787 m
.90482 .17874 L
.90482 .17879 L
.90482 .17883 L
.90482 .17887 L
.90481 .17891 L
.90481 .17895 L
.90481 .17899 L
.90481 .17904 L
.9048 .17908 L
.9048 .17912 L
.9048 .17916 L
.9048 .1792 L
.90479 .17925 L
.90479 .17929 L
.90479 .17933 L
.90479 .17937 L
.90479 .17941 L
.90478 .17945 L
.90478 .1795 L
.90478 .17954 L
.90478 .17958 L
.90478 .17962 L
.90477 .17966 L
.90477 .17971 L
.90477 .17975 L
.90477 .17979 L
.90477 .17983 L
.90477 .17987 L
.90476 .17991 L
.90476 .17996 L
s
.92861 .18011 m
.92861 .18014 L
.92861 .18017 L
.92861 .1802 L
.92861 .18022 L
.9286 .18025 L
.9286 .18028 L
.9286 .18031 L
.9286 .18033 L
.9286 .18036 L
.9286 .18039 L
.92859 .18042 L
.92859 .18044 L
.92859 .18047 L
.92859 .1805 L
.92859 .18053 L
.92859 .18055 L
.92859 .18058 L
.92858 .18061 L
.92858 .18064 L
.92858 .18066 L
.92858 .18069 L
.92858 .18072 L
.92858 .18075 L
.92858 .18077 L
.92858 .1808 L
.92857 .18083 L
.92857 .18086 L
.92857 .18088 L
.92857 .18091 L
.92857 .18094 L
s
.9524 .18151 m
.9524 .18153 L
.9524 .18154 L
.9524 .18156 L
.9524 .18157 L
.95239 .18158 L
.95239 .1816 L
.95239 .18161 L
.95239 .18163 L
.95239 .18164 L
.95239 .18165 L
.95239 .18167 L
.95239 .18168 L
.95239 .18169 L
.95239 .18171 L
.95239 .18172 L
.95239 .18174 L
.95239 .18175 L
.95238 .18176 L
.95238 .18178 L
.95238 .18179 L
.95238 .18181 L
.95238 .18182 L
.95238 .18183 L
.95238 .18185 L
.95238 .18186 L
.95238 .18188 L
.95238 .18189 L
.95238 .1819 L
.95238 .18192 L
.95238 .18193 L
s
.02381 .22027 m
.0397 .22027 L
.05558 .22027 L
.07147 .22027 L
.08735 .22027 L
.10324 .22027 L
.11912 .22027 L
.13501 .22027 L
.15089 .22027 L
.16678 .22027 L
.18267 .22027 L
.19855 .22027 L
.21444 .22027 L
.23032 .22027 L
.24621 .22027 L
.26209 .22027 L
.27798 .22027 L
.29387 .22027 L
.30975 .22027 L
.32564 .22027 L
.34173 .22009 L
.3576 .21945 L
.37347 .21882 L
.38935 .21819 L
.40531 .21739 L
.42117 .21644 L
.43703 .21548 L
.45288 .21452 L
.46874 .21356 L
.4846 .2126 L
.50046 .21164 L
.51631 .21069 L
.53217 .20973 L
.54803 .20877 L
.56389 .20781 L
.57974 .20685 L
.5956 .20589 L
.61146 .20494 L
.62732 .20398 L
.64317 .20302 L
.65903 .20206 L
.67489 .2011 L
.69075 .20014 L
.70661 .19918 L
.72246 .19823 L
.73832 .19727 L
.75418 .19631 L
.77004 .19535 L
.78589 .19439 L
.80175 .19344 L
Mistroke
.81761 .19248 L
.83347 .19152 L
.84932 .19056 L
.86518 .1896 L
.88104 .18865 L
.8969 .18769 L
.91275 .18673 L
.92861 .18578 L
.94447 .18482 L
.96033 .18389 L
.97619 .18303 L
Mfstroke
.02381 .20782 m
.0397 .20782 L
.05558 .20782 L
.07147 .20782 L
.08735 .20782 L
.10324 .20782 L
.11912 .20782 L
.13501 .20782 L
.15089 .20782 L
.16678 .20782 L
.18267 .20782 L
.19855 .20782 L
.21444 .20782 L
.23032 .20782 L
.24621 .20782 L
.26209 .20782 L
.27798 .20782 L
.29387 .20782 L
.30975 .20782 L
.32564 .20782 L
.34131 .20768 L
.3572 .20726 L
.37308 .20684 L
.38896 .20642 L
.40473 .2059 L
.42061 .20526 L
.43648 .20463 L
.45235 .20399 L
.46823 .20335 L
.4841 .20271 L
.49998 .20208 L
.51585 .20144 L
.53172 .2008 L
.5476 .20016 L
.56347 .19953 L
.57934 .19889 L
.59522 .19825 L
.61109 .19761 L
.62697 .19698 L
.64284 .19634 L
.65871 .1957 L
.67459 .19506 L
.69046 .19443 L
.70633 .19379 L
.72221 .19315 L
.73808 .19251 L
.75395 .19188 L
.76983 .19124 L
.7857 .1906 L
.80158 .18996 L
Mistroke
.81745 .18933 L
.83332 .18869 L
.8492 .18805 L
.86507 .18741 L
.88094 .18678 L
.89682 .18614 L
.91269 .1855 L
.92856 .18486 L
.94444 .18421 L
.96031 .18356 L
.97618 .18281 L
Mfstroke
0 0 0 r
.02381 .21404 m
.33655 .21404 L
s
% Start of user PostScript
-50. 5. 0.24154 5. MAarrowhead1
% End of user PostScript
.33655 .21404 m
.39729 .21204 L
s
% Start of user PostScript
0.24154 5. 10. 4.67726 MAarrowhead1
% End of user PostScript
.39729 .21204 m
.97618 .18292 L
s
% Start of user PostScript
10. 4.67726 103. 0.000304527 MAarrowhead1
% End of user PostScript
.97618 .18292 m
.97618 .18292 L
s
% Start of user PostScript
103. 0.000304527 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .20844 m
.02381 .20882 L
.02381 .20919 L
.02381 .20956 L
.02381 .20994 L
.02381 .21031 L
.02381 .21068 L
.02381 .21106 L
.02381 .21143 L
.02381 .2118 L
.02381 .21218 L
.02381 .21255 L
.02381 .21292 L
.02381 .2133 L
.02381 .21367 L
.02381 .21404 L
.02381 .21442 L
.02381 .21479 L
.02381 .21517 L
.02381 .21554 L
.02381 .21591 L
.02381 .21629 L
.02381 .21666 L
.02381 .21703 L
.02381 .21741 L
.02381 .21778 L
.02381 .21815 L
.02381 .21853 L
.02381 .2189 L
.02381 .21927 L
.02381 .21965 L
s
.04764 .20844 m
.04764 .20882 L
.04764 .20919 L
.04764 .20956 L
.04764 .20994 L
.04764 .21031 L
.04764 .21068 L
.04764 .21106 L
.04764 .21143 L
.04764 .2118 L
.04764 .21218 L
.04764 .21255 L
.04764 .21292 L
.04764 .2133 L
.04764 .21367 L
.04764 .21404 L
.04764 .21442 L
.04764 .21479 L
.04764 .21517 L
.04764 .21554 L
.04764 .21591 L
.04764 .21629 L
.04764 .21666 L
.04764 .21703 L
.04764 .21741 L
.04764 .21778 L
.04764 .21815 L
.04764 .21853 L
.04764 .2189 L
.04764 .21927 L
.04764 .21965 L
s
.07147 .20844 m
.07147 .20882 L
.07147 .20919 L
.07147 .20956 L
.07147 .20994 L
.07147 .21031 L
.07147 .21068 L
.07147 .21106 L
.07147 .21143 L
.07147 .2118 L
.07147 .21218 L
.07147 .21255 L
.07147 .21292 L
.07147 .2133 L
.07147 .21367 L
.07147 .21404 L
.07147 .21442 L
.07147 .21479 L
.07147 .21517 L
.07147 .21554 L
.07147 .21591 L
.07147 .21629 L
.07147 .21666 L
.07147 .21703 L
.07147 .21741 L
.07147 .21778 L
.07147 .21815 L
.07147 .21853 L
.07147 .2189 L
.07147 .21927 L
.07147 .21965 L
s
.0953 .20844 m
.0953 .20882 L
.0953 .20919 L
.0953 .20956 L
.0953 .20994 L
.0953 .21031 L
.0953 .21068 L
.0953 .21106 L
.0953 .21143 L
.0953 .2118 L
.0953 .21218 L
.0953 .21255 L
.0953 .21292 L
.0953 .2133 L
.0953 .21367 L
.0953 .21404 L
.0953 .21442 L
.0953 .21479 L
.0953 .21517 L
.0953 .21554 L
.0953 .21591 L
.0953 .21629 L
.0953 .21666 L
.0953 .21703 L
.0953 .21741 L
.0953 .21778 L
.0953 .21815 L
.0953 .21853 L
.0953 .2189 L
.0953 .21927 L
.0953 .21965 L
s
.11912 .20844 m
.11912 .20882 L
.11912 .20919 L
.11912 .20956 L
.11912 .20994 L
.11912 .21031 L
.11912 .21068 L
.11912 .21106 L
.11912 .21143 L
.11912 .2118 L
.11912 .21218 L
.11912 .21255 L
.11912 .21292 L
.11912 .2133 L
.11912 .21367 L
.11912 .21404 L
.11912 .21442 L
.11912 .21479 L
.11912 .21517 L
.11912 .21554 L
.11912 .21591 L
.11912 .21629 L
.11912 .21666 L
.11912 .21703 L
.11912 .21741 L
.11912 .21778 L
.11912 .21815 L
.11912 .21853 L
.11912 .2189 L
.11912 .21927 L
.11912 .21965 L
s
.14295 .20844 m
.14295 .20882 L
.14295 .20919 L
.14295 .20956 L
.14295 .20994 L
.14295 .21031 L
.14295 .21068 L
.14295 .21106 L
.14295 .21143 L
.14295 .2118 L
.14295 .21218 L
.14295 .21255 L
.14295 .21292 L
.14295 .2133 L
.14295 .21367 L
.14295 .21404 L
.14295 .21442 L
.14295 .21479 L
.14295 .21517 L
.14295 .21554 L
.14295 .21591 L
.14295 .21629 L
.14295 .21666 L
.14295 .21703 L
.14295 .21741 L
.14295 .21778 L
.14295 .21815 L
.14295 .21853 L
.14295 .2189 L
.14295 .21927 L
.14295 .21965 L
s
.16678 .20844 m
.16678 .20882 L
.16678 .20919 L
.16678 .20956 L
.16678 .20994 L
.16678 .21031 L
.16678 .21068 L
.16678 .21106 L
.16678 .21143 L
.16678 .2118 L
.16678 .21218 L
.16678 .21255 L
.16678 .21292 L
.16678 .2133 L
.16678 .21367 L
.16678 .21404 L
.16678 .21442 L
.16678 .21479 L
.16678 .21517 L
.16678 .21554 L
.16678 .21591 L
.16678 .21629 L
.16678 .21666 L
.16678 .21703 L
.16678 .21741 L
.16678 .21778 L
.16678 .21815 L
.16678 .21853 L
.16678 .2189 L
.16678 .21927 L
.16678 .21965 L
s
.19061 .20844 m
.19061 .20882 L
.19061 .20919 L
.19061 .20956 L
.19061 .20994 L
.19061 .21031 L
.19061 .21068 L
.19061 .21106 L
.19061 .21143 L
.19061 .2118 L
.19061 .21218 L
.19061 .21255 L
.19061 .21292 L
.19061 .2133 L
.19061 .21367 L
.19061 .21404 L
.19061 .21442 L
.19061 .21479 L
.19061 .21517 L
.19061 .21554 L
.19061 .21591 L
.19061 .21629 L
.19061 .21666 L
.19061 .21703 L
.19061 .21741 L
.19061 .21778 L
.19061 .21815 L
.19061 .21853 L
.19061 .2189 L
.19061 .21927 L
.19061 .21965 L
s
.21444 .20844 m
.21444 .20882 L
.21444 .20919 L
.21444 .20956 L
.21444 .20994 L
.21444 .21031 L
.21444 .21068 L
.21444 .21106 L
.21444 .21143 L
.21444 .2118 L
.21444 .21218 L
.21444 .21255 L
.21444 .21292 L
.21444 .2133 L
.21444 .21367 L
.21444 .21404 L
.21444 .21442 L
.21444 .21479 L
.21444 .21517 L
.21444 .21554 L
.21444 .21591 L
.21444 .21629 L
.21444 .21666 L
.21444 .21703 L
.21444 .21741 L
.21444 .21778 L
.21444 .21815 L
.21444 .21853 L
.21444 .2189 L
.21444 .21927 L
.21444 .21965 L
s
.23827 .20844 m
.23827 .20882 L
.23827 .20919 L
.23827 .20956 L
.23827 .20994 L
.23827 .21031 L
.23827 .21068 L
.23827 .21106 L
.23827 .21143 L
.23827 .2118 L
.23827 .21218 L
.23827 .21255 L
.23827 .21292 L
.23827 .2133 L
.23827 .21367 L
.23827 .21404 L
.23827 .21442 L
.23827 .21479 L
.23827 .21517 L
.23827 .21554 L
.23827 .21591 L
.23827 .21629 L
.23827 .21666 L
.23827 .21703 L
.23827 .21741 L
.23827 .21778 L
.23827 .21815 L
.23827 .21853 L
.23827 .2189 L
.23827 .21927 L
.23827 .21965 L
s
.26209 .20844 m
.26209 .20882 L
.26209 .20919 L
.26209 .20956 L
.26209 .20994 L
.26209 .21031 L
.26209 .21068 L
.26209 .21106 L
.26209 .21143 L
.26209 .2118 L
.26209 .21218 L
.26209 .21255 L
.26209 .21292 L
.26209 .2133 L
.26209 .21367 L
.26209 .21404 L
.26209 .21442 L
.26209 .21479 L
.26209 .21517 L
.26209 .21554 L
.26209 .21591 L
.26209 .21629 L
.26209 .21666 L
.26209 .21703 L
.26209 .21741 L
.26209 .21778 L
.26209 .21815 L
.26209 .21853 L
.26209 .2189 L
.26209 .21927 L
.26209 .21965 L
s
.28592 .20844 m
.28592 .20882 L
.28592 .20919 L
.28592 .20956 L
.28592 .20994 L
.28592 .21031 L
.28592 .21068 L
.28592 .21106 L
.28592 .21143 L
.28592 .2118 L
.28592 .21218 L
.28592 .21255 L
.28592 .21292 L
.28592 .2133 L
.28592 .21367 L
.28592 .21404 L
.28592 .21442 L
.28592 .21479 L
.28592 .21517 L
.28592 .21554 L
.28592 .21591 L
.28592 .21629 L
.28592 .21666 L
.28592 .21703 L
.28592 .21741 L
.28592 .21778 L
.28592 .21815 L
.28592 .21853 L
.28592 .2189 L
.28592 .21927 L
.28592 .21965 L
s
.30975 .20844 m
.30975 .20882 L
.30975 .20919 L
.30975 .20956 L
.30975 .20994 L
.30975 .21031 L
.30975 .21068 L
.30975 .21106 L
.30975 .21143 L
.30975 .2118 L
.30975 .21218 L
.30975 .21255 L
.30975 .21292 L
.30975 .2133 L
.30975 .21367 L
.30975 .21404 L
.30975 .21442 L
.30975 .21479 L
.30975 .21517 L
.30975 .21554 L
.30975 .21591 L
.30975 .21629 L
.30975 .21666 L
.30975 .21703 L
.30975 .21741 L
.30975 .21778 L
.30975 .21815 L
.30975 .21853 L
.30975 .2189 L
.30975 .21927 L
.30975 .21965 L
s
.33358 .20844 m
.33358 .20882 L
.33358 .20919 L
.33358 .20956 L
.33358 .20994 L
.33358 .21031 L
.33358 .21068 L
.33358 .21106 L
.33358 .21143 L
.33358 .2118 L
.33358 .21218 L
.33358 .21255 L
.33358 .21292 L
.33358 .2133 L
.33358 .21367 L
.33358 .21404 L
.33358 .21442 L
.33358 .21479 L
.33358 .21517 L
.33358 .21554 L
.33358 .21591 L
.33358 .21629 L
.33358 .21666 L
.33358 .21703 L
.33358 .21741 L
.33358 .21778 L
.33358 .21815 L
.33358 .21853 L
.33358 .2189 L
.33358 .21927 L
.33358 .21965 L
s
.35724 .20787 m
.35725 .20823 L
.35726 .2086 L
.35726 .20896 L
.35728 .20933 L
.35729 .2097 L
.3573 .21006 L
.35731 .21043 L
.35732 .21079 L
.35733 .21116 L
.35734 .21153 L
.35735 .21189 L
.35736 .21226 L
.35737 .21262 L
.35739 .21299 L
.3574 .21336 L
.35741 .21372 L
.35742 .21409 L
.35743 .21445 L
.35745 .21482 L
.35746 .21518 L
.35747 .21555 L
.35749 .21592 L
.3575 .21628 L
.35751 .21665 L
.35753 .21701 L
.35754 .21738 L
.35756 .21775 L
.35757 .21811 L
.35758 .21848 L
.3576 .21884 L
s
.38106 .20722 m
.38106 .20758 L
.38107 .20793 L
.38108 .20829 L
.38109 .20865 L
.3811 .209 L
.38111 .20936 L
.38112 .20972 L
.38113 .21007 L
.38115 .21043 L
.38116 .21079 L
.38117 .21114 L
.38118 .2115 L
.38119 .21185 L
.3812 .21221 L
.38121 .21257 L
.38122 .21292 L
.38124 .21328 L
.38125 .21364 L
.38126 .21399 L
.38127 .21435 L
.38129 .21471 L
.3813 .21506 L
.38131 .21542 L
.38133 .21578 L
.38134 .21613 L
.38135 .21649 L
.38137 .21684 L
.38138 .2172 L
.38139 .21756 L
.38141 .21791 L
s
.40481 .20647 m
.40482 .20682 L
.40483 .20716 L
.40484 .20751 L
.40486 .20785 L
.40487 .2082 L
.40488 .20854 L
.4049 .20889 L
.40491 .20923 L
.40493 .20958 L
.40494 .20992 L
.40496 .21027 L
.40497 .21061 L
.40499 .21096 L
.40501 .2113 L
.40502 .21165 L
.40504 .21199 L
.40506 .21234 L
.40508 .21268 L
.4051 .21303 L
.40511 .21337 L
.40513 .21372 L
.40515 .21406 L
.40517 .21441 L
.40519 .21475 L
.40522 .21509 L
.40524 .21544 L
.40526 .21578 L
.40528 .21613 L
.4053 .21647 L
.40533 .21682 L
s
.42861 .20549 m
.42863 .20582 L
.42864 .20615 L
.42865 .20648 L
.42866 .20681 L
.42867 .20715 L
.42869 .20748 L
.4287 .20781 L
.42871 .20814 L
.42873 .20847 L
.42874 .2088 L
.42876 .20913 L
.42877 .20946 L
.42879 .20979 L
.4288 .21012 L
.42882 .21045 L
.42884 .21078 L
.42886 .21111 L
.42887 .21144 L
.42889 .21177 L
.42891 .2121 L
.42893 .21243 L
.42895 .21276 L
.42897 .21309 L
.42899 .21342 L
.42901 .21375 L
.42903 .21408 L
.42905 .21441 L
.42907 .21474 L
.42909 .21507 L
.42911 .2154 L
s
.45242 .20451 m
.45243 .20483 L
.45244 .20514 L
.45245 .20546 L
.45247 .20578 L
.45248 .20609 L
.45249 .20641 L
.4525 .20673 L
.45252 .20704 L
.45253 .20736 L
.45254 .20767 L
.45256 .20799 L
.45257 .20831 L
.45259 .20862 L
.4526 .20894 L
.45262 .20925 L
.45264 .20957 L
.45265 .20989 L
.45267 .2102 L
.45269 .21052 L
.4527 .21083 L
.45272 .21115 L
.45274 .21146 L
.45276 .21178 L
.45278 .2121 L
.4528 .21241 L
.45282 .21273 L
.45284 .21304 L
.45286 .21336 L
.45288 .21367 L
.4529 .21399 L
s
.47623 .20353 m
.47624 .20383 L
.47625 .20414 L
.47626 .20444 L
.47627 .20474 L
.47628 .20504 L
.4763 .20534 L
.47631 .20564 L
.47632 .20595 L
.47633 .20625 L
.47635 .20655 L
.47636 .20685 L
.47637 .20715 L
.47639 .20745 L
.4764 .20776 L
.47642 .20806 L
.47643 .20836 L
.47645 .20866 L
.47646 .20896 L
.47648 .20926 L
.4765 .20956 L
.47652 .20987 L
.47653 .21017 L
.47655 .21047 L
.47657 .21077 L
.47659 .21107 L
.47661 .21137 L
.47662 .21167 L
.47664 .21197 L
.47666 .21228 L
.47668 .21258 L
s
.50004 .20255 m
.50005 .20284 L
.50006 .20313 L
.50007 .20341 L
.50008 .2037 L
.50009 .20399 L
.5001 .20428 L
.50011 .20456 L
.50012 .20485 L
.50014 .20514 L
.50015 .20542 L
.50016 .20571 L
.50017 .206 L
.50019 .20629 L
.5002 .20657 L
.50022 .20686 L
.50023 .20715 L
.50025 .20743 L
.50026 .20772 L
.50028 .20801 L
.50029 .20829 L
.50031 .20858 L
.50033 .20887 L
.50034 .20916 L
.50036 .20944 L
.50038 .20973 L
.50039 .21002 L
.50041 .2103 L
.50043 .21059 L
.50045 .21088 L
.50047 .21116 L
s
.52384 .20157 m
.52385 .20185 L
.52386 .20212 L
.52387 .20239 L
.52388 .20266 L
.52389 .20294 L
.5239 .20321 L
.52392 .20348 L
.52393 .20375 L
.52394 .20403 L
.52395 .2043 L
.52396 .20457 L
.52398 .20485 L
.52399 .20512 L
.524 .20539 L
.52401 .20566 L
.52403 .20594 L
.52404 .20621 L
.52406 .20648 L
.52407 .20675 L
.52409 .20703 L
.5241 .2073 L
.52412 .20757 L
.52413 .20784 L
.52415 .20812 L
.52417 .20839 L
.52418 .20866 L
.5242 .20893 L
.52422 .20921 L
.52424 .20948 L
.52426 .20975 L
s
.54765 .20059 m
.54766 .20085 L
.54767 .20111 L
.54768 .20137 L
.54769 .20163 L
.5477 .20188 L
.54771 .20214 L
.54772 .2024 L
.54773 .20266 L
.54774 .20292 L
.54775 .20318 L
.54776 .20343 L
.54778 .20369 L
.54779 .20395 L
.5478 .20421 L
.54781 .20447 L
.54783 .20472 L
.54784 .20498 L
.54785 .20524 L
.54787 .2055 L
.54788 .20576 L
.5479 .20601 L
.54791 .20627 L
.54793 .20653 L
.54794 .20679 L
.54796 .20705 L
.54797 .2073 L
.54799 .20756 L
.54801 .20782 L
.54802 .20808 L
.54804 .20834 L
s
.57146 .19961 m
.57147 .19986 L
.57148 .2001 L
.57148 .20034 L
.57149 .20059 L
.5715 .20083 L
.57151 .20108 L
.57152 .20132 L
.57153 .20156 L
.57154 .20181 L
.57155 .20205 L
.57156 .20229 L
.57158 .20254 L
.57159 .20278 L
.5716 .20303 L
.57161 .20327 L
.57162 .20351 L
.57164 .20376 L
.57165 .204 L
.57166 .20424 L
.57168 .20449 L
.57169 .20473 L
.5717 .20497 L
.57172 .20522 L
.57173 .20546 L
.57175 .20571 L
.57176 .20595 L
.57178 .20619 L
.57179 .20644 L
.57181 .20668 L
.57183 .20692 L
s
.59527 .19863 m
.59527 .19886 L
.59528 .19909 L
.59529 .19932 L
.5953 .19955 L
.59531 .19978 L
.59532 .20001 L
.59533 .20024 L
.59534 .20047 L
.59535 .2007 L
.59536 .20093 L
.59537 .20116 L
.59538 .20138 L
.59539 .20161 L
.5954 .20184 L
.59541 .20207 L
.59542 .2023 L
.59543 .20253 L
.59545 .20276 L
.59546 .20299 L
.59547 .20322 L
.59548 .20345 L
.5955 .20368 L
.59551 .20391 L
.59552 .20414 L
.59554 .20436 L
.59555 .20459 L
.59557 .20482 L
.59558 .20505 L
.5956 .20528 L
.59561 .20551 L
s
.61907 .19765 m
.61908 .19787 L
.61909 .19808 L
.6191 .1983 L
.6191 .19851 L
.61911 .19873 L
.61912 .19894 L
.61913 .19916 L
.61914 .19937 L
.61915 .19959 L
.61916 .1998 L
.61917 .20002 L
.61918 .20023 L
.61919 .20045 L
.6192 .20066 L
.61921 .20088 L
.61922 .20109 L
.61923 .20131 L
.61924 .20152 L
.61925 .20173 L
.61927 .20195 L
.61928 .20216 L
.61929 .20238 L
.6193 .20259 L
.61932 .20281 L
.61933 .20302 L
.61934 .20324 L
.61936 .20345 L
.61937 .20367 L
.61938 .20388 L
.6194 .2041 L
s
.64288 .19667 m
.64289 .19687 L
.6429 .19707 L
.6429 .19727 L
.64291 .19747 L
.64292 .19767 L
.64293 .19788 L
.64293 .19808 L
.64294 .19828 L
.64295 .19848 L
.64296 .19868 L
.64297 .19888 L
.64298 .19908 L
.64299 .19928 L
.643 .19948 L
.64301 .19968 L
.64302 .19988 L
.64303 .20008 L
.64304 .20028 L
.64305 .20048 L
.64306 .20068 L
.64307 .20088 L
.64308 .20108 L
.64309 .20128 L
.64311 .20148 L
.64312 .20168 L
.64313 .20188 L
.64314 .20208 L
.64316 .20228 L
.64317 .20248 L
.64318 .20268 L
s
.66669 .19569 m
.6667 .19588 L
.6667 .19606 L
.66671 .19625 L
.66672 .19644 L
.66672 .19662 L
.66673 .19681 L
.66674 .19699 L
.66675 .19718 L
.66675 .19737 L
.66676 .19755 L
.66677 .19774 L
.66678 .19792 L
.66679 .19811 L
.6668 .1983 L
.66681 .19848 L
.66681 .19867 L
.66682 .19885 L
.66683 .19904 L
.66684 .19923 L
.66685 .19941 L
.66687 .1996 L
.66688 .19978 L
.66689 .19997 L
.6669 .20015 L
.66691 .20034 L
.66692 .20053 L
.66693 .20071 L
.66694 .2009 L
.66696 .20108 L
.66697 .20127 L
s
.6905 .19471 m
.6905 .19488 L
.69051 .19506 L
.69051 .19523 L
.69052 .1954 L
.69053 .19557 L
.69053 .19574 L
.69054 .19591 L
.69055 .19608 L
.69056 .19626 L
.69056 .19643 L
.69057 .1966 L
.69058 .19677 L
.69059 .19694 L
.6906 .19711 L
.6906 .19729 L
.69061 .19746 L
.69062 .19763 L
.69063 .1978 L
.69064 .19797 L
.69065 .19814 L
.69066 .19831 L
.69067 .19849 L
.69068 .19866 L
.69069 .19883 L
.6907 .199 L
.69071 .19917 L
.69072 .19934 L
.69073 .19951 L
.69074 .19968 L
.69076 .19986 L
s
.7143 .19373 m
.71431 .19389 L
.71431 .19405 L
.71432 .1942 L
.71433 .19436 L
.71433 .19452 L
.71434 .19467 L
.71434 .19483 L
.71435 .19499 L
.71436 .19515 L
.71436 .1953 L
.71437 .19546 L
.71438 .19562 L
.71439 .19577 L
.71439 .19593 L
.7144 .19609 L
.71441 .19625 L
.71442 .1964 L
.71443 .19656 L
.71444 .19672 L
.71444 .19687 L
.71445 .19703 L
.71446 .19719 L
.71447 .19734 L
.71448 .1975 L
.71449 .19766 L
.7145 .19782 L
.71451 .19797 L
.71452 .19813 L
.71453 .19829 L
.71454 .19844 L
s
.73811 .19275 m
.73812 .19289 L
.73812 .19304 L
.73813 .19318 L
.73813 .19332 L
.73814 .19347 L
.73814 .19361 L
.73815 .19375 L
.73815 .19389 L
.73816 .19404 L
.73817 .19418 L
.73817 .19432 L
.73818 .19446 L
.73819 .19461 L
.73819 .19475 L
.7382 .19489 L
.73821 .19503 L
.73822 .19518 L
.73822 .19532 L
.73823 .19546 L
.73824 .1956 L
.73825 .19575 L
.73825 .19589 L
.73826 .19603 L
.73827 .19617 L
.73828 .19632 L
.73829 .19646 L
.7383 .1966 L
.73831 .19674 L
.73832 .19689 L
.73833 .19703 L
s
.76192 .19177 m
.76192 .1919 L
.76193 .19203 L
.76193 .19216 L
.76194 .19228 L
.76194 .19241 L
.76195 .19254 L
.76195 .19267 L
.76196 .1928 L
.76196 .19293 L
.76197 .19305 L
.76197 .19318 L
.76198 .19331 L
.76199 .19344 L
.76199 .19357 L
.762 .19369 L
.76201 .19382 L
.76201 .19395 L
.76202 .19408 L
.76203 .19421 L
.76203 .19434 L
.76204 .19446 L
.76205 .19459 L
.76206 .19472 L
.76206 .19485 L
.76207 .19498 L
.76208 .1951 L
.76209 .19523 L
.7621 .19536 L
.7621 .19549 L
.76211 .19562 L
s
.78573 .19079 m
.78573 .1909 L
.78573 .19102 L
.78574 .19113 L
.78574 .19125 L
.78575 .19136 L
.78575 .19147 L
.78576 .19159 L
.78576 .1917 L
.78577 .19182 L
.78577 .19193 L
.78578 .19204 L
.78578 .19216 L
.78579 .19227 L
.78579 .19238 L
.7858 .1925 L
.7858 .19261 L
.78581 .19273 L
.78582 .19284 L
.78582 .19295 L
.78583 .19307 L
.78583 .19318 L
.78584 .19329 L
.78585 .19341 L
.78585 .19352 L
.78586 .19363 L
.78587 .19375 L
.78588 .19386 L
.78588 .19398 L
.78589 .19409 L
.7859 .1942 L
s
.80953 .18981 m
.80954 .18991 L
.80954 .19001 L
.80954 .19011 L
.80955 .19021 L
.80955 .19031 L
.80956 .19041 L
.80956 .19051 L
.80956 .19061 L
.80957 .19071 L
.80957 .1908 L
.80958 .1909 L
.80958 .191 L
.80959 .1911 L
.80959 .1912 L
.8096 .1913 L
.8096 .1914 L
.80961 .1915 L
.80961 .1916 L
.80962 .1917 L
.80962 .1918 L
.80963 .1919 L
.80963 .192 L
.80964 .1921 L
.80965 .19219 L
.80965 .19229 L
.80966 .19239 L
.80966 .19249 L
.80967 .19259 L
.80968 .19269 L
.80968 .19279 L
s
.83334 .18883 m
.83334 .18892 L
.83335 .189 L
.83335 .18909 L
.83335 .18917 L
.83336 .18926 L
.83336 .18934 L
.83336 .18942 L
.83337 .18951 L
.83337 .18959 L
.83337 .18968 L
.83338 .18976 L
.83338 .18985 L
.83339 .18993 L
.83339 .19002 L
.83339 .1901 L
.8334 .19019 L
.8334 .19027 L
.83341 .19036 L
.83341 .19044 L
.83342 .19053 L
.83342 .19061 L
.83343 .1907 L
.83343 .19078 L
.83344 .19087 L
.83344 .19095 L
.83345 .19104 L
.83345 .19112 L
.83346 .19121 L
.83346 .19129 L
.83347 .19138 L
s
.85715 .18785 m
.85715 .18792 L
.85715 .18799 L
.85716 .18806 L
.85716 .18813 L
.85716 .1882 L
.85716 .18827 L
.85717 .18834 L
.85717 .18841 L
.85717 .18848 L
.85718 .18855 L
.85718 .18863 L
.85718 .1887 L
.85719 .18877 L
.85719 .18884 L
.85719 .18891 L
.8572 .18898 L
.8572 .18905 L
.8572 .18912 L
.85721 .18919 L
.85721 .18926 L
.85722 .18933 L
.85722 .1894 L
.85722 .18947 L
.85723 .18954 L
.85723 .18961 L
.85724 .18968 L
.85724 .18975 L
.85725 .18982 L
.85725 .18989 L
.85726 .18996 L
s
.88096 .18687 m
.88096 .18692 L
.88096 .18698 L
.88096 .18704 L
.88096 .18709 L
.88097 .18715 L
.88097 .18721 L
.88097 .18726 L
.88097 .18732 L
.88098 .18737 L
.88098 .18743 L
.88098 .18749 L
.88098 .18754 L
.88099 .1876 L
.88099 .18765 L
.88099 .18771 L
.88099 .18777 L
.881 .18782 L
.881 .18788 L
.881 .18794 L
.88101 .18799 L
.88101 .18805 L
.88101 .1881 L
.88102 .18816 L
.88102 .18822 L
.88102 .18827 L
.88103 .18833 L
.88103 .18838 L
.88103 .18844 L
.88104 .1885 L
.88104 .18855 L
s
.90476 .18589 m
.90476 .18593 L
.90477 .18597 L
.90477 .18601 L
.90477 .18605 L
.90477 .1861 L
.90477 .18614 L
.90477 .18618 L
.90478 .18622 L
.90478 .18626 L
.90478 .1863 L
.90478 .18635 L
.90478 .18639 L
.90479 .18643 L
.90479 .18647 L
.90479 .18651 L
.90479 .18656 L
.90479 .1866 L
.9048 .18664 L
.9048 .18668 L
.9048 .18672 L
.9048 .18676 L
.90481 .18681 L
.90481 .18685 L
.90481 .18689 L
.90481 .18693 L
.90482 .18697 L
.90482 .18702 L
.90482 .18706 L
.90482 .1871 L
.90483 .18714 L
s
.92857 .1849 m
.92857 .18493 L
.92857 .18496 L
.92857 .18499 L
.92857 .18501 L
.92858 .18504 L
.92858 .18507 L
.92858 .1851 L
.92858 .18512 L
.92858 .18515 L
.92858 .18518 L
.92858 .18521 L
.92858 .18523 L
.92859 .18526 L
.92859 .18529 L
.92859 .18532 L
.92859 .18534 L
.92859 .18537 L
.92859 .1854 L
.92859 .18543 L
.9286 .18545 L
.9286 .18548 L
.9286 .18551 L
.9286 .18554 L
.9286 .18557 L
.9286 .18559 L
.92861 .18562 L
.92861 .18565 L
.92861 .18568 L
.92861 .1857 L
.92861 .18573 L
s
.95238 .18391 m
.95238 .18393 L
.95238 .18394 L
.95238 .18395 L
.95238 .18397 L
.95238 .18398 L
.95238 .184 L
.95238 .18401 L
.95238 .18402 L
.95238 .18404 L
.95238 .18405 L
.95238 .18406 L
.95238 .18408 L
.95239 .18409 L
.95239 .18411 L
.95239 .18412 L
.95239 .18413 L
.95239 .18415 L
.95239 .18416 L
.95239 .18418 L
.95239 .18419 L
.95239 .1842 L
.95239 .18422 L
.95239 .18423 L
.95239 .18425 L
.95239 .18426 L
.9524 .18427 L
.9524 .18429 L
.9524 .1843 L
.9524 .18431 L
.9524 .18433 L
s
0 0 m
1 0 L
1 .3468 L
0 .3468 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[524]:=",
  ImageSize->{288, 99.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Hb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00Ioooool6o`000:?ooooo0ol0
000=ooooo`00J?ooool01Ol0003ooooooooooooooooo00000:?ooooo00Co0000oooooooooooo0000
3?ooool006Sooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`0:ooooo`00J?ooool0
0ol0003oooooooooo`2Vooooo`;o00003Oooool006Sooooo00?o0000ooooooooool0YOooool00ol0
003oooooooooo`0=ooooo`00J?ooool00ol0003oooooooooo`2Uooooo`04o`000?ooooooooooo`00
00cooooo001Wooooo`?o0000Yoooool3o`0000cooooo001]ooooo`Oo0000W_ooool00ol0003ooooo
ooooo`0;ooooo`00KOooool7o`0009kooooo00?o0000ooooooooool02oooool006cooooo0_l00005
ogmoO`03o`000?oooooooooo09cooooo00?o0000ooooooooool02oooool006cooooo0_l00005ogmo
O`03o`000?oooooooooo09cooooo00?o0000ooooooooool02oooool006_ooooo00?o0000ogmoOol0
00001OmoOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo001[ooooo`03o`00
0?moOgoo000000GoOgmo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00J_oo
ool00ol0003oOgmoogmoO`07o`0009kooooo00?o0000ooooooooool02oooool006[ooooo00Co0000
ogmoOomoOgoo00001OmoOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo001Y
ooooo`05o`000?moOgooOgmoogmoOol000001OmoOgl00ol0003oooooooooo`2Looooo`03o`000?oo
oooooooo00_ooooo001Yooooo`05o`000?moOgooOgmoogmoOol000001OmoOgl00ol0003ooooooooo
o`2Looooo`03o`000?oooooooooo00_ooooo001Xooooo`03o`000?moOgooOgmo00;oOgmo00?o0000
ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo001Xoooo
o`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Loooo
o`03o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00?oOgmo1ol0002Nooooo`03
o`000?oooooooooo00_ooooo001Wooooo`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?mo
OgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Looooo`03o`000?oo
oooooooo00_ooooo001Vooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl00omoOgl0
0ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo001Vooooo`03o`000?moOgooOgmo
00CoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
00_ooooo001Uooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003o
ooooooooo`2Looooo`03o`000?oooooooooo00_ooooo001Uooooo`03o`000?moOgooOgmo00GoOgmo
00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo
001Uooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`2Looooo`03o`000?oooooooooo00_ooooo001Uooooo`03o`000?moOgooOgmo00GoOgmo00?o0000
ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo001Uoooo
o`03o`000?moOgooOgmo00GoOgmo1ol0002Nooooo`03o`000?oooooooooo00_ooooo001Tooooo`03
o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Looooo`03
o`000?oooooooooo00_ooooo001Tooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`000?mo
OgooOgmo00KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Looooo`03o`000?oo
oooooooo00_ooooo001Tooooo`03o`000?moOgooOgmo00KoOgmo00?o0000ogmoOomoOgl00omoOgl0
0ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo001Tooooo`03o`000?moOgooOgmo
00KoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
00_ooooo001Sooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003o
ooooooooo`2Looooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?moOgooOgmo00OoOgmo
00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo
001Sooooo`03o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`2Looooo`03o`000?oooooooooo00_ooooo001Sooooo`03o`000?moOgooOgmo00OoOgmo00?o0000
ogmoOomoOgl00omoOgl00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo001Soooo
o`03o`000?moOgooOgmo00OoOgmo1ol0002Nooooo`03o`000?oooooooooo00_ooooo000<ooooodko
2NX:00?o0000o`WZ2_l000002_l9jPX4ogmoO`?o00001OmoOgl00ol0003oooooooooo`2Looooo`03
o`000?oooooooooo00_ooooo000<ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:ooooooooool0
1?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooooooool0
0oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_l0003o000000?o000000?o2NX:ooooool00000
0omoOgl5o`WZ2P;o000000?o2NX:o`000?l9jPX03?l9jPZEooooo`03o`000?oooooooooo00_ooooo
000<ooooo`03o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol000000ol9jP[o0000o`00
0004o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol000000ol9jP[o0000o`00
0004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000001?l000000ol9jP[o0000o`00
0003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol000000ol9jP[o0000o`00
0004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000001?l000001ol9jP[o0000o`00
0?l0003oOgmoo`000?l9jPX01Ol000000ooooooo2NX:ooooo`05oooooa;o2NX:Q?ooool00ol0003o
ooooooooo`0;ooooo`003?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo
00?o2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo
00?o2NX:ooooooooool01?ooool00ol9jP[o0000o`000002o`000004ooooool9jP[oooooo`0000Co
Ogmo00Co2NX:ogmoOomoOgooOgmo0_l000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o0000
00?o000000?o2NX:o`000?l000001?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo
00;ooooo4_l9jPYbooooo`03o`000?oooooooooo00_ooooo000<ooooodko2NX:00?o0000o`WZ2_l9
jPX03_l9jPX3o`0000oo2NX:00?oooooo`000?l000000_l000000ol9jP[o0000o`000003o`0000;o
2NX:1Ol000000ol9jP[o0000o`000004ooooo`03o`WZ2_oooooooooo00?ooooo00Co2NX:oooooooo
oooooooo3Ol9jPYUooooo`03o`000?oooooooooo00_ooooo001Rooooo`03o`000?moOgooOgmo00So
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`07oooooaGo2NX:1?l000000ol9jP[o
0000o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000oooool01?l9jP[o
oooooooooooooolAo`WZ2UCooooo00?o0000ooooooooool02oooool006;ooooo00?o0000ogmoOomo
Ogl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo027ooooo3ol9jPX3o`000003
o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol000001?l9jP[o0000o`000?l00003oooo
oa;o2NX:@oooool00ol0003oooooooooo`0;ooooo`00H_ooool00ol0003oOgmoogmoO`08ogmoO`03
o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0=_ooool>o`WZ2P?o000000?o2NX:o`000?l0
00000ol000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000;ooooo4_l9jPXaooooo`03
o`000?oooooooooo00_ooooo001Rooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl0
0omoOgl00ol0003oooooooooo`1Aooooo`Ko2NX:0ol000000ol9jP[o0000o`000004o`000003o`WZ
2_l0003o000000?o000000Co2NX:o`000?l0003o00004Ol9jPXHooooo`;o00001_ooool00ol0003o
ooooooooo`0;ooooo`00H_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo
00?o0000ooooooooool0Joooool3o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l00000
1?l000001?l9jP[o0000o`000?l0000?o`WZ2PKooooo1Ol00003ooooo`03o`000?oooooooooo00_o
oooo001Rooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooo
ooooo`1oooooo`Wo000000?o2NX:o`000?l000001?l000001?l9jP[o0000o`000?l00002o`WZ2PSo
00003Oooool006;ooooo4_l00026ooooo`ko2NX:0ol000000ol9jP[o0000o`000005o`0000gooooo
001Rooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0003ooooooooo
o`1ZoooooaCo2NX:1?l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000Oo00000_oo
ool6o`0000;ooooo00?o0000ooooooooool02oooool006;ooooo00?o0000ogmoOomoOgl02?moOgl0
0ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo05Cooooo5_l9jPX4o`000003o`WZ2_l0003o
000000?o000000?o2NX:o`000?l000001ol0000Fooooo`;o00001_ooool00ol0003oooooooooo`0;
ooooo`00H_ooool00ol0003oOgmoogmoO`08ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000oooo
ooooool0>_oooolKo`WZ2P03ooooool0003o000000;o000000?o2NX:o`000?l000001?l000000ol9
jP[o0000o`000003o`000003o`WZ2_l0003o000003;ooooo00?o0000ooooooooool02oooool006;o
oooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo023o
oooo6ol9jPX5ooooo`03o`WZ2_oooooooooo00Co000000?o2NX:o`000?l000000ol000000ol9jP[o
0000o`000004o`000004o`WZ2_l0003o2NX:o`WZ2TCooooo00?o0000ooooooooool02oooool006;o
oooo00?o0000ogmoOomoOgl02?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo00Ko
oooo6ol9jPX5ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:ooooool000000ol000000ol9jP[o
0000o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`000?l000002?l9jPYAooooo`03
o`000?oooooooooo00_ooooo000<ooooodko2NX:0ol0000>o`WZ2P?o00003_l9jPX6ooooo`03o`WZ
2_oooooooooo00?ooooo0_l9jPX5ooooo`03o`WZ2_oooooo000000Co000000?o2NX:o`000?l00000
0ol000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o2NX:00[o2NX:H_ooool00ol0003ooooo
ooooo`0;ooooo`003?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o
2NX:ooooooooool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o
2NX:ooooooooool01?ooool00ol9jP[o0000o`000003o`000003o`WZ2_l0003oOgmo00CoOgmo00Co
2NX:ogmoOomoOgooOgmo0_l000002?l9jP[o0000o`000?l0003oOgmoo`000?oooooo2NX:1Oooool0
0ol9jP[oooooo`000004o`000003o`WZ2_l0003o000000Co000000?o2NX:o`000?l000000ol00000
0ol9jP[o0000o`WZ2P0=o`WZ2W?ooooo00?o0000ooooooooool02oooool000cooooo00?o2NX:o`00
0?l000001?l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`00
0?l000001?l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`00
0?l000000ol000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`00
0?l000001?l000000ol9jP[o0000o`000003o`000003o`WZ2_l0003o000000Co000000?o2NX:o`00
0?l000000ol000000ol9jP[o0000o`000004o`000003o`WZ2_l0003o000000?o000000?o2NX:o`00
0?l000001?l000000ol9jP[o0000o`000003o`0001;o2NX:QOooool00ol0003oooooooooo`0;oooo
o`003?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[oooooooooo`03ooooo`03o`WZ2_oooooooooo00Cooooo00?o2NX:oooooooo
ool00oooool00ol9jP[oooooooooo`04ooooo`03o`WZ2_oooooooooo00?ooooo00?o2NX:oooooooo
ool01?ooool00ol9jP[o0000o`000002o`000004ooooool9jP[oooooo`0000CoOgmo00Co2NX:ogmo
Ool9jP[o2NX:0_l000000ol9jP[o0000o`00000;o`WZ2YKooooo00?o0000ooooooooool02oooool0
00coooooC_l9jPX00ol0003o2NX:o`WZ2P0=o`WZ2P04ogmoOol0003o0000o`0000GoOgmo00?o0000
ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmoogmoO`07ogmo
O`Oo0000W_ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmoogmoO`07ogmoO`03
o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00
Hoooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0
W?ooool00ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmoogmoO`07ogmoO`03o`000?mo
OgooOgmo00?oOgmo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00Hoooool0
0ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0W?ooool0
0ol0003oooooooooo`0;ooooo`00Hoooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo
00?oOgmo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003o
OgmoogmoO`06ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0W?ooool00ol0003o
ooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo00?oOgmo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmo
O`06ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0;ooooo`00I?ooool00ol0003oOgmoogmoO`06ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000
ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00I?ooool00ol0003oOgmoogmoO`06ogmo
O`Oo0000W_ooool00ol0003oooooooooo`0;ooooo`00IOooool00ol0003oOgmoogmoO`05ogmoO`03
o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00
IOooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0
W?ooool00ol0003oooooooooo`0;ooooo`00IOooool00ol0003oOgmoogmoO`05ogmoO`03o`000?mo
OgooOgmo00?oOgmo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00IOooool0
0ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0W?ooool0
0ol0003oooooooooo`0;ooooo`00IOooool00ol0003oOgmoogmoO`05ogmoO`03o`000?moOgooOgmo
00?oOgmo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00I_ooool00ol0003o
OgmoogmoO`04ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0W?ooool00ol0003o
ooooooooo`0;ooooo`00I_ooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo00?oOgmo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00I_ooool00ol0003oOgmoogmo
O`04ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0;ooooo`00Ioooool00ol0003oOgmoogmoO`03ogmoO`Oo0000W_ooool00ol0003oooooooooo`0;
ooooo`00Ioooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000oooo
ooooool0W?ooool00ol0003oooooooooo`0;ooooo`00J?ooool00ol0003oOgmoogmoO`02ogmoO`03
o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00
J?ooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0
W?ooool00ol0003oooooooooo`0;ooooo`00JOooool01Ol0003oOgmoogmoOomoOgoo000000GoOgmo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00JOooool01Ol0003oOgmoogmo
OomoOgoo000000GoOgmo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`00J_oo
ool01?l0003oOgmoogmoOol00005ogmoO`03o`000?oooooooooo09cooooo00?o0000ooooooooool0
2oooool006[ooooo00?o0000ogmoOomoOgl01ol0002Nooooo`03o`000?oooooooooo00_ooooo001[
ooooo`03o`000?moOgoo000000GoOgmo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;
ooooo`00Joooool00ol0003oOgmoo`000005ogmoO`03o`000?oooooooooo09cooooo00?o0000oooo
ooooool02oooool006cooooo0_l00005ogmoO`03o`000?oooooooooo09cooooo00?o0000oooooooo
ool02oooool006cooooo2?l0002Nooooo`03o`000?oooooooooo00_ooooo001]ooooo`Oo0000W_oo
ool00ol0003oooooooooo`0;ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {98.875, 0}} -> {-57.5326, -31.5733, 0.585597, \
0.585597}},
  CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[intensity = FindField[waveletSystem]][[1]]/60/Second*\"Minute\"\
\>", "Input",
  CellLabel->"In[525]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],

Cell[BoxData[
    \(0.02700000000000197`\ "Minute"\)], "Output",
  CellLabel->"Out[525]=",
  CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[intensity[0,y],{y,-.07,.07},PlotRange->All];", "Input",
  CellLabel->"In[526]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 6.80272 0.0147151 0.00650447 [
[.09184 .00222 -15 -9 ]
[.09184 .00222 15 0 ]
[.22789 .00222 -15 -9 ]
[.22789 .00222 15 0 ]
[.36395 .00222 -15 -9 ]
[.36395 .00222 15 0 ]
[.63605 .00222 -12 -9 ]
[.63605 .00222 12 0 ]
[.77211 .00222 -12 -9 ]
[.77211 .00222 12 0 ]
[.90816 .00222 -12 -9 ]
[.90816 .00222 12 0 ]
[.4875 .1448 -12 -4.5 ]
[.4875 .1448 0 4.5 ]
[.4875 .27489 -12 -4.5 ]
[.4875 .27489 0 4.5 ]
[.4875 .40498 -12 -4.5 ]
[.4875 .40498 0 4.5 ]
[.4875 .53507 -12 -4.5 ]
[.4875 .53507 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09184 .01472 m
.09184 .02097 L
s
[(-0.06)] .09184 .00222 0 1 Mshowa
.22789 .01472 m
.22789 .02097 L
s
[(-0.04)] .22789 .00222 0 1 Mshowa
.36395 .01472 m
.36395 .02097 L
s
[(-0.02)] .36395 .00222 0 1 Mshowa
.63605 .01472 m
.63605 .02097 L
s
[(0.02)] .63605 .00222 0 1 Mshowa
.77211 .01472 m
.77211 .02097 L
s
[(0.04)] .77211 .00222 0 1 Mshowa
.90816 .01472 m
.90816 .02097 L
s
[(0.06)] .90816 .00222 0 1 Mshowa
.125 Mabswid
.12585 .01472 m
.12585 .01847 L
s
.15986 .01472 m
.15986 .01847 L
s
.19388 .01472 m
.19388 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.29592 .01472 m
.29592 .01847 L
s
.32993 .01472 m
.32993 .01847 L
s
.39796 .01472 m
.39796 .01847 L
s
.43197 .01472 m
.43197 .01847 L
s
.46599 .01472 m
.46599 .01847 L
s
.53401 .01472 m
.53401 .01847 L
s
.56803 .01472 m
.56803 .01847 L
s
.60204 .01472 m
.60204 .01847 L
s
.67007 .01472 m
.67007 .01847 L
s
.70408 .01472 m
.70408 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.80612 .01472 m
.80612 .01847 L
s
.84014 .01472 m
.84014 .01847 L
s
.87415 .01472 m
.87415 .01847 L
s
.05782 .01472 m
.05782 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.94218 .01472 m
.94218 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .1448 m
.50625 .1448 L
s
[(20)] .4875 .1448 1 0 Mshowa
.5 .27489 m
.50625 .27489 L
s
[(40)] .4875 .27489 1 0 Mshowa
.5 .40498 m
.50625 .40498 L
s
[(60)] .4875 .40498 1 0 Mshowa
.5 .53507 m
.50625 .53507 L
s
[(80)] .4875 .53507 1 0 Mshowa
.125 Mabswid
.5 .04724 m
.50375 .04724 L
s
.5 .07976 m
.50375 .07976 L
s
.5 .11228 m
.50375 .11228 L
s
.5 .17733 m
.50375 .17733 L
s
.5 .20985 m
.50375 .20985 L
s
.5 .24237 m
.50375 .24237 L
s
.5 .30742 m
.50375 .30742 L
s
.5 .33994 m
.50375 .33994 L
s
.5 .37246 m
.50375 .37246 L
s
.5 .43751 m
.50375 .43751 L
s
.5 .47003 m
.50375 .47003 L
s
.5 .50255 m
.50375 .50255 L
s
.5 .5676 m
.50375 .5676 L
s
.5 .60012 m
.50375 .60012 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02605 .01472 L
.02846 .01472 L
.03279 .01472 L
.03543 .01472 L
.03673 .01472 L
.03793 .01472 L
.03902 .01472 L
.04018 .01472 L
.04134 .01472 L
.04262 .01472 L
.04515 .01472 L
.04755 .01472 L
.04819 .01472 L
.04887 .01472 L
.04962 .01472 L
.05032 .01472 L
.051 .01472 L
.05165 .01472 L
.05285 .01472 L
.05402 .01472 L
.05525 .01472 L
.05631 .01472 L
.05746 .01472 L
.05871 .01472 L
.06004 .01472 L
.06244 .01472 L
.06526 .01472 L
.06787 .01472 L
.07067 .01472 L
.07144 .01472 L
.07226 .01472 L
.07298 .01472 L
.07376 .01472 L
.07508 .01472 L
.0758 .01472 L
.07647 .01472 L
.07768 .01472 L
.07896 .01472 L
.08045 .01472 L
.08186 .01472 L
.08311 .01472 L
.08377 .01472 L
.08448 .01472 L
.08574 .01472 L
.08692 .01472 L
.08761 .01472 L
.08827 .01472 L
.0895 .01472 L
.09065 .01472 L
Mistroke
.09171 .01472 L
.09288 .01472 L
.09413 .01472 L
.09549 .01472 L
.09695 .01472 L
.09961 .01472 L
.10458 .01472 L
.10696 .01472 L
.10765 .01472 L
.1083 .01472 L
.10951 .01472 L
.11066 .01472 L
.11172 .01472 L
.11288 .01472 L
.11411 .01472 L
.11671 .01472 L
.11807 .01472 L
.1195 .01472 L
.12076 .01472 L
.12148 .01472 L
.12214 .01472 L
.12331 .01472 L
.12456 .01472 L
.12586 .01472 L
.12659 .01472 L
.12726 .01472 L
.1285 .01472 L
.12981 .01472 L
.13099 .01472 L
.13209 .01472 L
.13458 .01472 L
.13987 .01472 L
.14132 .01472 L
.14287 .01472 L
.14418 .01472 L
.14493 .01472 L
.14564 .01472 L
.14691 .01472 L
.14755 .01472 L
.14825 .01472 L
.1495 .01472 L
.15065 .01472 L
.15349 .01472 L
.15473 .01472 L
.15538 .01472 L
.15607 .01472 L
.15735 .01472 L
.15853 .01472 L
.15963 .01472 L
.16085 .01472 L
Mistroke
.16212 .01472 L
.16284 .01472 L
.16349 .01472 L
.16476 .01472 L
.16596 .01472 L
.17097 .01472 L
.17569 .01472 L
.17775 .01472 L
.17879 .01472 L
.17993 .01472 L
.18116 .01472 L
.18232 .01472 L
.18338 .01472 L
.18451 .01472 L
.18575 .01472 L
.18709 .01472 L
.18953 .01472 L
.19069 .01472 L
.19191 .01472 L
.19295 .01472 L
.19411 .01472 L
.19475 .01472 L
.19543 .01472 L
.19665 .01472 L
.19795 .01472 L
.19869 .01472 L
.19938 .01472 L
.20064 .01472 L
.20178 .01472 L
.20433 .01472 L
.20887 .01472 L
.21127 .01472 L
.21257 .01472 L
.2138 .01472 L
.21486 .01472 L
.21601 .01472 L
.21728 .01472 L
.21844 .01472 L
.21949 .01472 L
.22064 .01472 L
.22172 .01472 L
.22272 .01472 L
.22521 .01472 L
.22656 .01472 L
.22782 .01472 L
.22849 .01472 L
.22919 .01472 L
.22998 .01472 L
.23069 .01472 L
.23134 .01472 L
Mistroke
.23205 .01472 L
.23333 .01472 L
.23453 .01472 L
.23585 .01472 L
.23722 .01473 L
.23851 .01473 L
.2433 .01477 L
.2455 .01478 L
.2479 .0148 L
.249 .01481 L
.25017 .01481 L
.25127 .01482 L
.25227 .01482 L
.25352 .01482 L
.25422 .01481 L
.25487 .01481 L
.25606 .0148 L
.25731 .01479 L
.26193 .01474 L
.26314 .01473 L
.26379 .01473 L
.26447 .01472 L
.26572 .01472 L
.26688 .01472 L
.26799 .01473 L
.26903 .01474 L
.27017 .01476 L
.2714 .0148 L
.27263 .01485 L
.27398 .01491 L
.2767 .01508 L
.28155 .01545 L
.28269 .01553 L
.28392 .01561 L
.28508 .01566 L
.28614 .0157 L
.28739 .01572 L
.28871 .01572 L
.28983 .01569 L
.29105 .01563 L
.2922 .01555 L
.29325 .01547 L
.29561 .01522 L
.29781 .01499 L
.29889 .01488 L
.29989 .0148 L
.30109 .01474 L
.30239 .01473 L
.3035 .01477 L
.30466 .01487 L
Mistroke
.30592 .01506 L
.30709 .01532 L
.30837 .0157 L
.30975 .0162 L
.31414 .01836 L
.31645 .01962 L
.3189 .0208 L
.32028 .02131 L
.32106 .02152 L
.3218 .02167 L
.32309 .02178 L
.32381 .02176 L
.32447 .02169 L
.3257 .02141 L
.3264 .02117 L
.32705 .0209 L
.32975 .01933 L
.33225 .01751 L
.33362 .01653 L
.3349 .01573 L
.33598 .0152 L
.33715 .01484 L
.33845 .01477 L
.33963 .01506 L
.34088 .01578 L
.34158 .0164 L
.34223 .0171 L
.34343 .01872 L
.3447 .02091 L
.3473 .02673 L
.35018 .03444 L
.35264 .04099 L
.35394 .044 L
.3553 .0466 L
.3565 .04825 L
.35782 .04927 L
.35901 .04939 L
.36012 .04876 L
.36128 .04736 L
.36254 .045 L
.36373 .04205 L
.36483 .03881 L
.36911 .02424 L
.37018 .02097 L
.37133 .01803 L
.37259 .01578 L
.37377 .01483 L
.37441 .01487 L
.3751 .01537 L
.37636 .01763 L
Mistroke
.37758 .02158 L
.37872 .0268 L
.3838 .06573 L
.38647 .09141 L
.38793 .10474 L
.38929 .11576 L
.39058 .12432 L
.39176 .13008 L
.39307 .13377 L
.39379 .13447 L
.39448 .13423 L
.39566 .13167 L
.39676 .12692 L
.39797 .11919 L
.39925 .10846 L
.4035 .06166 L
.40574 .03768 L
.40686 .02792 L
.40809 .01997 L
.40875 .01712 L
.40945 .01531 L
.41072 .01556 L
.41198 .02063 L
.41313 .02959 L
.4143 .04294 L
.41556 .06195 L
.41786 .10665 L
.42242 .21344 L
.42363 .23963 L
.42494 .26458 L
.42618 .28349 L
.42732 .29606 L
.42804 .30119 L
.42869 .30393 L
.42943 .30476 L
.43014 .30322 L
.43137 .29506 L
.43207 .28748 L
.43271 .27872 L
.43515 .23117 L
.43774 .16491 L
.44025 .09818 L
.44163 .06596 L
.44293 .04123 L
.44415 .02483 L
.44547 .01569 L
.44667 .0161 L
.44778 .02427 L
.44909 .04366 L
.45032 .07101 L
Mistroke
.45167 .11018 L
.45312 .16118 L
.45586 .27226 L
.45878 .38926 L
.4602 .43647 L
.46089 .45607 L
.46153 .47165 L
.46272 .49377 L
.46401 .50632 L
.46514 .50698 L
.46638 .49652 L
.46767 .47351 L
.46888 .4418 L
.47464 .20822 L
.47716 .10704 L
.47858 .06262 L
.4799 .03334 L
.48104 .01866 L
.48231 .01513 L
.48363 .02608 L
.48487 .04972 L
.48606 .08342 L
.48714 .12281 L
.48959 .23377 L
.49217 .36568 L
.49461 .48057 L
.49596 .53198 L
.49667 .5542 L
.49743 .57357 L
.49806 .58627 L
.49876 .59627 L
.49998 .60332 L
.50126 .59615 L
.50242 .57699 L
.50306 .56154 L
.50376 .54102 L
.50504 .49488 L
.50977 .26591 L
.51206 .15604 L
.51332 .10519 L
.5145 .06625 L
.51561 .03908 L
.5168 .02083 L
.51789 .01478 L
.51889 .01813 L
.52009 .03309 L
.52137 .06136 L
.52258 .09812 L
.52369 .13851 L
.52895 .36462 L
Mistroke
.53022 .4125 L
.53157 .45459 L
.53227 .47221 L
.53305 .48776 L
.53375 .49817 L
.53441 .50456 L
.53571 .50737 L
.5369 .4987 L
.53821 .47739 L
.53886 .4624 L
.53958 .44306 L
.54488 .24148 L
.54748 .13935 L
.54862 .10121 L
.54987 .06623 L
.551 .04206 L
.55205 .02622 L
.55316 .01686 L
.55436 .01522 L
.55566 .02292 L
.55689 .0385 L
.558 .05836 L
.55921 .08501 L
.56448 .22261 L
.566 .25611 L
.56674 .26987 L
.56743 .28068 L
.56871 .2958 L
.56938 .30086 L
.57009 .30397 L
.57129 .30398 L
.57258 .29686 L
.5738 .28385 L
.5749 .26732 L
.57761 .21272 L
.58017 .15205 L
.58239 .10128 L
.58478 .05633 L
.58615 .0373 L
.58741 .02489 L
.58867 .0174 L
.58986 .01486 L
.5911 .01662 L
.59241 .02285 L
.59365 .03215 L
.59478 .0428 L
.59757 .07416 L
.60014 .10254 L
.60129 .11323 L
.60236 .12152 L
Mistroke
.60348 .12813 L
.6047 .13275 L
.60595 .13449 L
.60708 .13349 L
.60839 .12944 L
.60963 .12303 L
.61071 .11572 L
.61186 .10656 L
.61392 .0877 L
.61858 .04483 L
.62096 .02854 L
.62216 .02265 L
.62347 .01809 L
.62459 .01577 L
.62579 .01481 L
.62692 .01524 L
.62795 .01659 L
.62924 .0194 L
.63044 .02281 L
.63314 .03199 L
.63568 .04035 L
.63692 .04373 L
.63805 .04621 L
.63909 .0479 L
.64009 .04893 L
.64113 .04942 L
.64227 .04923 L
.64344 .04831 L
.64469 .04661 L
.64586 .04442 L
.64693 .04204 L
.65141 .0301 L
.65395 .02373 L
.6552 .02112 L
.65633 .01911 L
.65746 .01748 L
.65869 .01614 L
.65999 .01523 L
.66122 .01481 L
.66252 .01478 L
.66317 .01491 L
.6639 .01515 L
.66517 .01577 L
.66637 .01652 L
.67087 .01974 L
.67197 .0204 L
.67314 .02098 L
.67442 .02144 L
.67561 .0217 L
.67629 .02177 L
Mistroke
.67702 .02178 L
.67771 .02173 L
.67835 .02164 L
.67956 .02135 L
.68084 .02091 L
.68313 .01985 L
.68564 .01849 L
.68833 .01706 L
.68982 .01638 L
.69122 .01583 L
.69253 .01542 L
.69322 .01525 L
.69395 .01509 L
.69524 .01488 L
.69644 .01477 L
.69757 .01473 L
.69881 .01474 L
.70011 .0148 L
.70132 .0149 L
.70579 .01537 L
.70711 .0155 L
.70835 .01559 L
.70946 .01566 L
.71067 .0157 L
.71199 .01572 L
.71265 .01572 L
.71338 .01571 L
.71467 .01567 L
.71588 .01562 L
.72011 .01532 L
.72462 .01499 L
.72596 .01491 L
.72721 .01485 L
.72844 .0148 L
.72956 .01477 L
.73064 .01474 L
.73177 .01473 L
.73291 .01472 L
.73415 .01472 L
.73485 .01472 L
.73551 .01472 L
.73675 .01473 L
.73953 .01476 L
.74213 .01479 L
.74328 .0148 L
.74454 .01481 L
.74572 .01481 L
.74683 .01482 L
.74801 .01482 L
.74927 .01481 L
Mistroke
.75058 .01481 L
.75123 .01481 L
.75195 .0148 L
.75441 .01478 L
.75905 .01475 L
.76165 .01473 L
.76288 .01473 L
.76401 .01472 L
.76508 .01472 L
.76622 .01472 L
.76735 .01472 L
.76861 .01472 L
.76969 .01472 L
.77085 .01472 L
.77194 .01472 L
.77294 .01472 L
.77541 .01472 L
.77773 .01472 L
.77901 .01472 L
.77969 .01472 L
.7804 .01472 L
.78166 .01472 L
.78282 .01472 L
.78391 .01472 L
.78508 .01472 L
.78618 .01472 L
.78719 .01472 L
.79198 .01472 L
.79446 .01472 L
.79709 .01472 L
.79846 .01472 L
.79997 .01472 L
.80063 .01472 L
.80135 .01472 L
.80264 .01472 L
.80392 .01472 L
.80466 .01472 L
.80533 .01472 L
.80657 .01472 L
.80727 .01472 L
.8079 .01472 L
.80909 .01472 L
.81038 .01472 L
.81272 .01472 L
.81393 .01472 L
.81509 .01472 L
.81572 .01472 L
.81642 .01472 L
.81763 .01472 L
.81878 .01472 L
Mistroke
.82001 .01472 L
.82106 .01472 L
.82221 .01472 L
.82765 .01472 L
.83004 .01472 L
.83139 .01472 L
.83264 .01472 L
.83398 .01472 L
.83519 .01472 L
.83648 .01472 L
.8372 .01472 L
.83787 .01472 L
.83855 .01472 L
.83927 .01472 L
.84057 .01472 L
.84129 .01472 L
.84197 .01472 L
.84271 .01472 L
.8435 .01472 L
.84607 .01472 L
.84747 .01472 L
.84879 .01472 L
.85003 .01472 L
.85068 .01472 L
.85137 .01472 L
.85259 .01472 L
.8537 .01472 L
.85491 .01472 L
.8562 .01472 L
.85742 .01472 L
.85853 .01472 L
.86383 .01472 L
.86654 .01472 L
.86798 .01472 L
.8695 .01472 L
.87082 .01472 L
.87153 .01472 L
.87229 .01472 L
.87298 .01472 L
.87362 .01472 L
.87486 .01472 L
.87604 .01472 L
.87729 .01472 L
.87847 .01472 L
.87954 .01472 L
.88081 .01472 L
.88218 .01472 L
.88466 .01472 L
.8859 .01472 L
.88661 .01472 L
Mistroke
.88727 .01472 L
.88796 .01472 L
.8886 .01472 L
.88933 .01472 L
.89002 .01472 L
.89125 .01472 L
.89239 .01472 L
.89364 .01472 L
.89496 .01472 L
.89951 .01472 L
.902 .01472 L
.90431 .01472 L
.90552 .01472 L
.90682 .01472 L
.90756 .01472 L
.90826 .01472 L
.90957 .01472 L
.91077 .01472 L
.91188 .01472 L
.9131 .01472 L
.9144 .01472 L
.91553 .01472 L
.91656 .01472 L
.91888 .01472 L
.91992 .01472 L
.92104 .01472 L
.9221 .01472 L
.92309 .01472 L
.92434 .01472 L
.92552 .01472 L
.92658 .01472 L
.92772 .01472 L
.92898 .01472 L
.9303 .01472 L
.93266 .01472 L
.93521 .01472 L
.93762 .01472 L
.93979 .01472 L
.94101 .01472 L
.94214 .01472 L
.94335 .01472 L
.94449 .01472 L
.94573 .01472 L
.94643 .01472 L
.94707 .01472 L
.94829 .01472 L
.94898 .01472 L
.94962 .01472 L
.95092 .01472 L
.95164 .01472 L
Mistroke
.9523 .01472 L
.9545 .01472 L
.9557 .01472 L
.95683 .01472 L
.95805 .01472 L
.95869 .01472 L
.95938 .01472 L
.96061 .01472 L
.96174 .01472 L
.96287 .01472 L
.96392 .01472 L
.9663 .01472 L
.97064 .01472 L
.97214 .01472 L
.97355 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[526]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000Aoooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool3o`00013ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go0000<_ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000;ooooo1Ol0000@ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00001?ooool3o`00013ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`?o00006?ooool001Sooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000<Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00003oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03_oo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`0Eooooo`004Oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool5o`0000;ooooo00Co
0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Go00002?ooool5o`0000;o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo037ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo
00Go00003oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0Eooooo`006?ooool01?l0003oooooooooool00008ooooo`05o`00
0?ooooooooooo`000?ooool01?l0000@ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00kooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000oooooooo
ool03_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l0000H
ooooo`006?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
4oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ool000004?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0_ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooo0000013ooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0001_ooooo000Hooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool2o`00013ooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0;ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000ooo
ool2o`00013ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo01Sooooo000Iooooo`;o00002_ooool2o`0000Cooooo0_l0000Aooooo`;o0000
2_ooool2o`0000Gooooo00?o0000ooooooooool03oooool2o`0000[ooooo0_l00003ooooo`?o0000
<oooool2o`0000[ooooo0_l00003ooooo`?o00004Oooool2o`0000[ooooo0_l00005ooooo`03o`00
0?oooooooooo00oooooo0_l0000:ooooo`;o00001?ooool2o`0001Sooooo002?ooooo`03o`000?oo
oooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo
08kooooo002?ooooo`03o`000?oooooooooo08kooooo0007oooooooo00004_l00008ooooo`003Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool2o`0000?ooooo00Co0000oooooooooooo00001Oooool01?l0003oooooo`000?l00005ooooo`03
o`000?oooooooooo00;o00001?ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003ooooooooo
o`03ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`02o`0000;ooooo0_l0
0004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0<ooooo`008?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Kooooo0ol00004
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000007ooooo`;o00002?oo
ool2o`0000Sooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_oo
ool2o`0000Sooooo0_l00007ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00006?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01oooooo001U
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool2o`0000Sooooo0_l0
0008ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo0_l0
0008ooooo`;o00001oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo06Cooooo
001Uooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool2o`0000Sooooo
0_l00008ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
0_l00008ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1Uooooo`00I_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oo
oooo0_l00008ooooo`;o00002?ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00008oooo
o`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo06Gooooo001Vooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000002?oo
ool2o`0000?ooooo00Co0000oooooooooooooooo0_l00008ooooo`03o`000?oooooo000000Kooooo
00Co0000oooooooooooo00001_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
06Kooooo001Wooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00006ooooo`03o`000?oooooo000000Sooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00002?ooool00ol0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0001Xooooo`00Ioooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooo`000008ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000Sooooo00?o0000
ooooool000001_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo0000J?ooool006Sooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooo`000008ooooo`;o00000oooool2o`0000;ooooo
0_l00008ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`03ooooo`;o0000JOooool006oooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000oooool01ol0003o
oooooooooooooooo0000ooooool000001oooool00ol0003oooooo`000006ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool0K_ooool006oooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000ooo
ool01ol0003ooooooooooooooooo0000ooooool000001oooool00ol0003oooooo`000006ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0K_ooool006oooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ool000000oooool01ol0003ooooooooooooooooo0000ooooool000001oooool00ol0003oooooo`00
0006ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0K_ooool006oooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooool000000oooool01ol0003ooooooooooooooooo0000ooooool000001oooool00ol0
003oooooo`000006ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1^
ooooo`00Koooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooool000001oooool00ol0003oooooo`000003ooooo`07o`000?ooooooooooooooool0003ooooo
o`000007ooooo`03o`000?oooooo000000Kooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo06kooooo001_ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000?ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000Oooooo00?o0000ooooool000001_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0Koooool006oooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000ooo
ool01ol0003ooooooooooooooooo0000ooooool000001oooool00ol0003oooooo`000006ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1_ooooo`00Koooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000001oooool00ol0
003oooooo`000003ooooo`07o`000?ooooooooooooooool0003oooooo`000007ooooo`03o`000?oo
oooo000000Kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo06oooooo
001`ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
o`000007ooooo`03o`000?oooooo000000?ooooo0_l00002ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
0000LOooool0073ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03
o`000?oooooo000000Oooooo00?o0000ooooool000000oooool01ol0003ooooooooooooooooo0000
ooooool000001oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00001aooooo`00L?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000?ooooo00Oo
0000ooooooooooooooooo`000?oooooo000000Kooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000LOooool0073ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooo`000003ooooo`07o`000?ooooooooooooooool0003oooooo`000006ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
0000077ooooo001`ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000000oooool01ol0003ooooooooo
oooooooo0000ooooool000001_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00001aooooo`00L?ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooo000000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Kooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000LOooool0
073ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooo`000003ooooo`07o`000?ooooooooooooooool0003o
ooooo`000006ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo0000077ooooo001`ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000000ooo
ool01ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001aooooo`00L?ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooo000000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Ko
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`00077ooooo001aooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooo000000?ooooo0_l00002ooooo`03o`000?oo
oooo000000Kooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000007;ooooo001aooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooo000000?ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000Kooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000007;ooooo001aooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo000000?ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000Kooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool00000L_ooool0077ooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool0
00000oooool01ol0003ooooooooooooooooo0000ooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001booooo`00LOooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooo`000003ooooo`07o`000?ooooooooooooooool0003oooooo`000006ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
07;ooooo001booooo`;o00001Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooool000000oooool01ol0003ooooooooooooooooo0000ooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1aooooo`00L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000001?l00003ooooo`;o000000?oooooo`000?ooool00_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool007Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02o`000006ooooool0003oooooooooool0003ooooo0ol00003oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0N?ooool007Wooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool000000_l00003ooooo`Co00000_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`1hooooo`00NOooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o0000
0oooool00ol0003oooooo`000002o`0000?ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1hoooo
o`00NOooool00ol0003oooooooooo`02ooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`03o`000?oooooo000000;o00000oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07Sooooo
001iooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;o
oooo00?o0000ooooool000000_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0N?ooool0
07Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03o`0000Cooooo0_l000000ooo
oooo0000ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0N?ooool007[ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo07Sooooo001jooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`1hooooo`00N_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0N?ooool007[ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07So
oooo001jooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000?ooooo0_l000001Ooooooo0000oooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07Sooooo001jooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo07Sooooo001jooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo07Wooooo001jooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo07Wooooo001jooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0001kooooo`00N_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000Nooo
ool007[ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0007_ooooo001jooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo0000Noooool007[ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool0001kooooo`00N_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o000000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
Noooool007[ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001kooooo`00N_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0007_ooooo001jooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo0000Noooool007[ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001koooo
o`00N_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0007_ooooo001jooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo0000Noooool007[ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool0001kooooo`00N_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0007_ooooo001j
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooo`00001looooo`00N_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000007cooooo001jooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000O?oo
ool007_ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooo`00001looooo`00Noooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000007cooooo001kooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000O?ooool007_o
oooo00?o0000ooooool000001?ooool3o`0000?ooooo0_l00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool00000O?ooool007_ooooo00?o0000ooooool000001Oooool01?l0003oooooooooooooool2
o`000004ooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000O?ooool007_ooooo00?o
0000ooooool000000_ooool5o`0000;ooooo0_l000001?oooooo0000ooooool00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000007cooooo001kooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
00000oooool2o`000004ooooool0003oooooo`0000;ooooo1?l00003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001looooo`00Noooool00ol0003o
ooooo`000003ooooo`03o`000?oooooo000000?ooooo0_l000001?oooooo0000ooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000007cooooo001kooooo`03o`000?oooooo000000Cooooo0_l00003oooo
o`;o000000Coooooo`000?oooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001looooo`00Noooool2
o`0000Kooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00Co0000oooooooooooo00000_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`00001looooo`00Noooool2o`0000Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo0_l0001looooo`00Noooool2o`0000Kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l0001looooo`00Noooool2o`0000Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l0001l
ooooo`00Noooool2o`0000Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo0_l0001looooo`00O?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07_ooooo0023
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01_l0003oooooo`000?l0
003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`22ooooo`00Pooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000Q?ooool008?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000008Cooooo0023ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000024ooooo`00Poooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000Q?ooool008?ooooo00Go0000oooooooooooooooo
o`000005ooooo`05o`000?oooooo0000ooooool000001Oooool01Ol0003ooooooooooooooooo0000
08Cooooo0023ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003oooooo`000?oooooo
000000Gooooo00Go0000ooooooooooooooooo`000024ooooo`00Q?ooool01?l0003oooooooooool0
0005ooooo`05o`000?oooooo0000ooooool000001Oooool01Ol0003ooooooooooooooooo000008Co
oooo0024ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooool0003oooooo`000005oooo
o`05o`000?ooooooooooooooool00000Q?ooool008Cooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooo`000002o`0000Gooooo00Go0000ooooooooooooooooo`000024ooooo`00Q?ooool0
1?l0003oooooooooool00005ooooo`05o`000?oooooo0000ooooool000001Oooool01?l0003ooooo
ooooool00025ooooo`00Q?ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo0000oooo
ool000001Oooool01?l0003oooooooooool00025ooooo`00Q?ooool01?l0003oooooooooool00005
ooooo`05o`000?oooooo0000ooooool000001Oooool01?l0003oooooooooool00025ooooo`00Q?oo
ool01?l0003oooooooooool00005ooooo`05o`000?oooooo0000ooooool000001Oooool01?l0003o
ooooooooool00025ooooo`00Q?ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo0000
ooooool000001Oooool01?l0003oooooooooool00025ooooo`00Q?ooool01?l0003oooooooooool0
0005ooooo`05o`000?oooooo0000ooooool000001Oooool01?l0003oooooooooool00025ooooo`00
Q?ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo0000ooooool000001Oooool01?l0
003oooooooooool00025ooooo`00Q?ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
0000ooooool000001Oooool01?l0003oooooooooool00025ooooo`00Q?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooo000000;o00001Oooool01?l0003oooooooooool00025ooooo`00
Q?ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo0000ooooool000001Oooool01?l0
003oooooooooool00025ooooo`00Q?ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
0000ooooool000001Oooool01?l0003oooooooooool00025ooooo`00Q?ooool01?l0003ooooooooo
ool00005ooooo`05o`000?oooooo0000ooooool000001Oooool01?l0003oooooooooool00025oooo
o`00Q?ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo0000ooooool000001Oooool0
1?l0003oooooooooool00025ooooo`00Q?ooool01?l0003oooooooooool00005ooooo`05o`000?oo
oooo0000ooooool000001Oooool01?l0003oooooooooool00025ooooo`00POooool4o`0000;ooooo
0ol00003ooooo`05o`000?oooooo0000ooooool000001Oooool01?l0003oooooooooool00025oooo
o`00P?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1Ol0003oooooo`000?oooooo000000Gooooo00Co0000oooooooooooo0000QOooool0083ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool0
00000_l00005ooooo`04o`000?ooooooooooo`0008Gooooo0020ooooo`Go00000_ooool01?l0003o
ooooooooool00002ooooo`05o`000?oooooo0000ooooool000001Oooool01?l0003oooooooooool0
0025ooooo`00P?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01Ol0003oooooo`000?oooooo000000Gooooo00Co0000oooooooooooo0000QOooool0087o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo
0000ooooool000001Oooool01?l0003oooooooooool00025ooooo`00P_ooool3o`0000;ooooo0ol0
0003ooooo`05o`000?oooooo0000ooooool000001Oooool01?l0003oooooooooool00025ooooo`00
Q?ooool01?l0003oooooooooool00005ooooo`05o`000?oooooo0000ooooool000001Oooool01?l0
003oooooooooool00025ooooo`00Q?ooool01?l0003oooooooooool00006ooooo`;o000000?ooooo
o`000?ooool01?ooool01?l0003oooooooooool00025ooooo`00Q?ooool01?l0003oooooooooool0
0006ooooo`;o000000?oooooo`000?ooool01?ooool01?l0003oooooooooool00025ooooo`00Q?oo
ool01?l0003oooooooooool00006ooooo`;o000000?oooooo`000?ooool01?ooool01?l0003ooooo
ooooool00025ooooo`00Q?ooool01?l0003oooooooooool00006ooooo`Co00001_ooool00ol0003o
ooooo`000025ooooo`00Q?ooool01?l0003oooooooooool00006ooooo`?o00001oooool00ol0003o
ooooo`000025ooooo`00Q?ooool01?l0003oooooooooool00006ooooo`?o00001oooool00ol0003o
ooooo`000025ooooo`00Q?ooool01?l0003oooooooooool00006ooooo`?o00001oooool00ol0003o
ooooo`000025ooooo`00Q?ooool01?l0003oooooooooool00006ooooo`?o00001oooool00ol0003o
ooooo`000025ooooo`00Q?ooool01?l0003oooooooooool00006ooooo`?o00001oooool00ol0003o
ooooo`000025ooooo`00Q?ooool00ol0003oooooo`000007ooooo`?o00001oooool00ol0003ooooo
o`000025ooooo`00Q?ooool00ol0003oooooo`000007ooooo`?o00001oooool00ol0003oooooo`00
0025ooooo`00QOooool2o`0000Oooooo0ol00007ooooo`03o`000?oooooo000008Gooooo0025oooo
o`;o00001oooool3o`0000Oooooo00?o0000ooooool00000QOooool008Gooooo0_l00007ooooo`?o
00001oooool2o`0008Kooooo0025ooooo`;o00001oooool3o`0000Oooooo0_l00026ooooo`00QOoo
ool2o`0000Oooooo0ol00007ooooo`;o0000Q_ooool008Gooooo0_l00007ooooo`?o00001oooool2
o`0008Kooooo0025ooooo`;o00001oooool3o`0000Oooooo0_l00026ooooo`00QOooool2o`0000Oo
oooo0ol00007ooooo`;o0000Q_ooool008Gooooo0_l00007ooooo`?o00001oooool2o`0008Kooooo
0025ooooo`;o00001oooool3o`0000Oooooo0_l00026ooooo`00QOooool00ol0003oooooooooo`06
ooooo`?o00001oooool2o`0008Kooooo0025ooooo`03o`000?oooooooooo00Kooooo0ol00007oooo
o`;o0000Q_ooool008kooooo0ol0002?ooooo`00S_ooool3o`0008oooooo002>ooooo`?o0000Sooo
ool008kooooo0ol0002?ooooo`00POooool3o`0000Cooooo0_l00004ooooo`?o0000Soooool0083o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo0ol0002?
ooooo`00P?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000ooo
ool3o`0008oooooo0021ooooo`?o00000oooool01?l0003oooooooooool00003ooooo`Co0000S_oo
ool0083ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo
0ol0002?ooooo`00P?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000oooool3o`0008oooooo0021ooooo`?o00001?ooool2o`0000Cooooo0ol0002?ooooo`00S_oo
ool3o`0008oooooo002>ooooo`?o0000Soooool008kooooo0ol0002?ooooo`00S_ooool3o`0008oo
oooo002>ooooo`?o0000Soooool008kooooo0ol0002?ooooo`00S_ooool3o`0008oooooo002>oooo
o`?o0000Soooool008kooooo0ol0002?ooooo`00S_ooool3o`0008oooooo002>ooooo`?o0000Sooo
ool008kooooo0_l0002@ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003o
ooooooooo`2>ooooo`00Soooool2o`0008oooooo002?ooooo`03o`000?oooooooooo08kooooo002?
ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo002?ooooo`03
o`000?oooooooooo08kooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0773522, -6.99528, \
0.00053904, 0.563756}},
  CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[intensity[-10,y],{y,-1,1},PlotRange->All];", "Input",
  CellLabel->"In[527]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0147151 0.143768 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -12 -9 ]
[.2619 .00222 12 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .15848 -6 -4.5 ]
[.4875 .15848 0 4.5 ]
[.4875 .30225 -6 -4.5 ]
[.4875 .30225 0 4.5 ]
[.4875 .44602 -6 -4.5 ]
[.4875 .44602 0 4.5 ]
[.4875 .58979 -6 -4.5 ]
[.4875 .58979 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-0.5)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(0.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .15848 m
.50625 .15848 L
s
[(1)] .4875 .15848 1 0 Mshowa
.5 .30225 m
.50625 .30225 L
s
[(2)] .4875 .30225 1 0 Mshowa
.5 .44602 m
.50625 .44602 L
s
[(3)] .4875 .44602 1 0 Mshowa
.5 .58979 m
.50625 .58979 L
s
[(4)] .4875 .58979 1 0 Mshowa
.125 Mabswid
.5 .04347 m
.50375 .04347 L
s
.5 .07222 m
.50375 .07222 L
s
.5 .10098 m
.50375 .10098 L
s
.5 .12973 m
.50375 .12973 L
s
.5 .18724 m
.50375 .18724 L
s
.5 .21599 m
.50375 .21599 L
s
.5 .24474 m
.50375 .24474 L
s
.5 .2735 m
.50375 .2735 L
s
.5 .331 m
.50375 .331 L
s
.5 .35976 m
.50375 .35976 L
s
.5 .38851 m
.50375 .38851 L
s
.5 .41726 m
.50375 .41726 L
s
.5 .47477 m
.50375 .47477 L
s
.5 .50353 m
.50375 .50353 L
s
.5 .53228 m
.50375 .53228 L
s
.5 .56103 m
.50375 .56103 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04588 .01472 L
.04652 .01472 L
.04722 .01472 L
.04797 .01472 L
.04862 .01472 L
.04933 .01472 L
.05061 .01472 L
.05186 .01472 L
.05302 .01472 L
.05414 .01472 L
.05519 .01472 L
.05634 .01472 L
.05759 .01472 L
.05882 .01472 L
.06012 .01472 L
.06123 .01472 L
.06244 .01472 L
.06315 .01472 L
.06381 .01472 L
.06453 .01472 L
.06529 .01472 L
.06657 .01472 L
.06729 .01472 L
.06797 .01472 L
.06924 .01472 L
.0704 .01472 L
.07103 .01472 L
.07173 .01472 L
.073 .01472 L
Mistroke
.07376 .01472 L
.07448 .01472 L
.07513 .01472 L
.07583 .01472 L
.0766 .01472 L
.0774 .01472 L
.07809 .01472 L
.07885 .01472 L
.07956 .01472 L
.0802 .01472 L
.0809 .01472 L
.08166 .01472 L
.08235 .01472 L
.083 .01472 L
.08427 .01472 L
.08544 .01472 L
.08669 .01472 L
.08787 .01472 L
.08896 .01472 L
.09016 .01472 L
.09148 .01472 L
.09214 .01472 L
.09285 .01472 L
.09413 .01472 L
.09483 .01472 L
.09548 .01472 L
.09618 .01472 L
.09695 .01472 L
.09824 .01472 L
.09895 .01472 L
.09961 .01472 L
.10086 .01472 L
.10201 .01472 L
.10333 .01472 L
.10458 .01472 L
.10572 .01472 L
.10694 .01472 L
.1081 .01472 L
.10916 .01472 L
.11033 .01472 L
.11162 .01472 L
.11227 .01472 L
.11297 .01472 L
.11422 .01472 L
.11554 .01472 L
.11629 .01472 L
.11698 .01472 L
.11824 .01472 L
.11958 .01472 L
.12078 .01472 L
Mistroke
.12191 .01472 L
.12314 .01472 L
.12446 .01472 L
.12569 .01472 L
.12682 .01472 L
.12807 .01472 L
.1294 .01472 L
.13066 .01472 L
.13185 .01472 L
.13292 .01472 L
.13408 .01472 L
.13514 .01472 L
.13631 .01472 L
.13753 .01472 L
.13866 .01472 L
.1407 .01472 L
.14184 .01472 L
.14288 .01472 L
.14406 .01472 L
.14517 .01472 L
.14638 .01472 L
.14769 .01472 L
.14899 .01472 L
.15036 .01472 L
.15152 .01473 L
.1528 .01473 L
.1551 .01474 L
.15639 .01474 L
.15756 .01475 L
.15865 .01476 L
.15983 .01477 L
.16198 .01479 L
.16327 .01481 L
.16448 .01483 L
.16591 .01487 L
.16723 .0149 L
.16991 .01501 L
.17138 .0151 L
.17278 .01519 L
.17526 .01543 L
.17755 .01573 L
.18007 .0162 L
.18147 .01654 L
.18274 .01691 L
.18508 .01777 L
.18764 .01906 L
.19031 .02091 L
.1928 .02322 L
.19514 .02606 L
.19727 .02933 L
Mistroke
.20204 .03974 L
.20471 .04789 L
.20718 .05727 L
.20983 .06965 L
.21275 .0864 L
.21767 .12294 L
.22288 .17424 L
.23366 .318 L
.24391 .47218 L
.24836 .52938 L
.25081 .55525 L
.25311 .57509 L
.25442 .5842 L
.25584 .59215 L
.25713 .59757 L
.25832 .601 L
.25944 .60284 L
.26067 .60328 L
.26196 .60198 L
.26316 .59914 L
.26441 .59456 L
.26556 .58886 L
.26818 .57103 L
.27049 .5501 L
.27294 .52316 L
.28186 .39816 L
.29151 .25391 L
.29658 .18888 L
.30192 .13312 L
.30676 .09437 L
.30933 .07817 L
.31207 .06381 L
.31459 .05299 L
.31689 .04493 L
.32138 .03321 L
.32372 .02881 L
.32589 .02559 L
.32826 .02281 L
.33078 .02057 L
.33296 .0191 L
.335 .01803 L
.33725 .01713 L
.33965 .01642 L
.3422 .01588 L
.34362 .01565 L
.34491 .01548 L
.34611 .01535 L
.34742 .01523 L
.34978 .01506 L
.35111 .01499 L
Mistroke
.35258 .01493 L
.354 .01488 L
.35553 .01484 L
.35696 .01481 L
.35827 .01479 L
.36082 .01476 L
.36207 .01475 L
.36339 .01475 L
.36577 .01473 L
.36709 .01473 L
.36833 .01473 L
.36968 .01472 L
.37115 .01472 L
.37233 .01472 L
.37363 .01472 L
.37499 .01472 L
.37625 .01472 L
.37743 .01472 L
.37851 .01472 L
.37975 .01472 L
.38092 .01472 L
.38208 .01472 L
.38332 .01472 L
.38449 .01472 L
.38556 .01472 L
.38681 .01472 L
.38818 .01472 L
.38947 .01472 L
.39066 .01472 L
.39188 .01472 L
.39303 .01472 L
.39429 .01472 L
.39565 .01472 L
.397 .01472 L
.39842 .01472 L
.39963 .01472 L
.40096 .01472 L
.40221 .01472 L
.40338 .01472 L
.40444 .01472 L
.40558 .01472 L
.40683 .01472 L
.40815 .01472 L
.40928 .01472 L
.41052 .01472 L
.41168 .01472 L
.41274 .01472 L
.41396 .01472 L
.41512 .01472 L
.41619 .01472 L
Mistroke
.41718 .01472 L
.41827 .01472 L
.41942 .01472 L
.42067 .01472 L
.42137 .01472 L
.42203 .01472 L
.42336 .01472 L
.4241 .01472 L
.42478 .01472 L
.426 .01472 L
.42732 .01472 L
.42856 .01472 L
.42971 .01472 L
.43035 .01472 L
.43104 .01472 L
.43228 .01472 L
.433 .01472 L
.43376 .01472 L
.43511 .01472 L
.4358 .01472 L
.43653 .01472 L
.43785 .01472 L
.43865 .01472 L
.43942 .01472 L
.4401 .01472 L
.44084 .01472 L
.4421 .01472 L
.44327 .01472 L
.44456 .01472 L
.44528 .01472 L
.44594 .01472 L
.44658 .01472 L
.44727 .01472 L
.44802 .01472 L
.44871 .01472 L
.44942 .01472 L
.45009 .01472 L
.45134 .01472 L
.45252 .01472 L
.45376 .01472 L
.45483 .01472 L
.45599 .01472 L
.45725 .01472 L
.45795 .01472 L
.45859 .01472 L
.45984 .01472 L
.46101 .01472 L
.46216 .01472 L
.46339 .01472 L
.46456 .01472 L
Mistroke
.46562 .01472 L
.46686 .01472 L
.46757 .01472 L
.46822 .01472 L
.46942 .01472 L
.4707 .01472 L
.47139 .01472 L
.47203 .01472 L
.47273 .01472 L
.47347 .01472 L
.47472 .01472 L
.47542 .01472 L
.47608 .01472 L
.47732 .01472 L
.47844 .01472 L
.47974 .01472 L
.48097 .01472 L
.48202 .01472 L
.48319 .01472 L
.48441 .01472 L
.48555 .01472 L
.48662 .01472 L
.48759 .01472 L
.48867 .01472 L
.4898 .01472 L
.49094 .01472 L
.49217 .01472 L
.49333 .01472 L
.49438 .01472 L
.49562 .01472 L
.49632 .01472 L
.49696 .01472 L
.49815 .01472 L
.4994 .01472 L
.50061 .01472 L
.50193 .01472 L
.50317 .01472 L
.50433 .01472 L
.50547 .01472 L
.50651 .01472 L
.5077 .01472 L
.50883 .01472 L
.51006 .01472 L
.51136 .01472 L
.51248 .01472 L
.5137 .01472 L
.51501 .01472 L
.51575 .01472 L
.51642 .01472 L
.51772 .01472 L
Mistroke
.51896 .01472 L
.52001 .01472 L
.52117 .01472 L
.52238 .01472 L
.52352 .01472 L
.52458 .01472 L
.52555 .01472 L
.52661 .01472 L
.52773 .01472 L
.52887 .01472 L
.53009 .01472 L
.53124 .01472 L
.53229 .01472 L
.53352 .01472 L
.53421 .01472 L
.53485 .01472 L
.53602 .01472 L
.53727 .01472 L
.53848 .01472 L
.5398 .01472 L
.54105 .01472 L
.54221 .01472 L
.54335 .01472 L
.54439 .01472 L
.54559 .01472 L
.54672 .01472 L
.54795 .01472 L
.54926 .01472 L
.55037 .01472 L
.55159 .01472 L
.55291 .01472 L
.55365 .01472 L
.55432 .01472 L
.55563 .01472 L
.55686 .01472 L
.55792 .01472 L
.55908 .01472 L
.56029 .01472 L
.56143 .01472 L
.56249 .01472 L
.56346 .01472 L
.56458 .01472 L
.56565 .01472 L
.56679 .01472 L
.56801 .01472 L
.56916 .01472 L
.5702 .01472 L
.57144 .01472 L
.57213 .01472 L
.57277 .01472 L
Mistroke
.57394 .01472 L
.57518 .01472 L
.5764 .01472 L
.57709 .01472 L
.57773 .01472 L
.5789 .01472 L
.58014 .01472 L
.58125 .01472 L
.58229 .01472 L
.58343 .01472 L
.58466 .01472 L
.58589 .01472 L
.58659 .01472 L
.58724 .01472 L
.58855 .01472 L
.58929 .01472 L
.58996 .01472 L
.59116 .01472 L
.59246 .01472 L
.59368 .01472 L
.59482 .01472 L
.59587 .01472 L
.59701 .01472 L
.59808 .01472 L
.59906 .01472 L
.6002 .01472 L
.60145 .01472 L
.60263 .01472 L
.60372 .01472 L
.60495 .01472 L
.60612 .01472 L
.60716 .01472 L
.60829 .01472 L
.60952 .01472 L
.61082 .01472 L
.61193 .01472 L
.61315 .01472 L
.61446 .01472 L
.61567 .01472 L
.617 .01472 L
.6184 .01472 L
.61963 .01472 L
.62077 .01472 L
.62203 .01472 L
.62338 .01472 L
.62451 .01472 L
.62575 .01472 L
.62704 .01472 L
.62824 .01472 L
.63039 .01472 L
Mistroke
.6316 .01473 L
.63269 .01473 L
.634 .01473 L
.63539 .01474 L
.63657 .01475 L
.63786 .01475 L
.63926 .01476 L
.64076 .01478 L
.64217 .0148 L
.64346 .01482 L
.64596 .01488 L
.64737 .01493 L
.64868 .01498 L
.65107 .01511 L
.65228 .0152 L
.65362 .01532 L
.65596 .01559 L
.65729 .01579 L
.65853 .01601 L
.66102 .01659 L
.66369 .01747 L
.66618 .01862 L
.66854 .02007 L
.67065 .02176 L
.67294 .02413 L
.67545 .02749 L
.6782 .03235 L
.68108 .03904 L
.68378 .04712 L
.6886 .06706 L
.69131 .08194 L
.69379 .09822 L
.69856 .13749 L
.70364 .19144 L
.71278 .31616 L
.72358 .47823 L
.72831 .53748 L
.731 .56413 L
.73231 .57489 L
.73351 .5833 L
.73467 .5901 L
.73593 .59594 L
.73662 .59844 L
.73726 .6003 L
.73852 .60267 L
.73974 .60332 L
.74043 .60296 L
.74108 .60215 L
.74239 .59913 L
.74313 .59662 L
Mistroke
.7438 .59381 L
.74639 .57873 L
.74786 .5673 L
.74923 .55493 L
.75493 .48807 L
.76462 .34417 L
.77511 .19752 L
.78059 .13864 L
.78564 .09715 L
.79047 .06814 L
.7929 .05695 L
.79558 .04692 L
.80021 .03424 L
.80281 .0292 L
.80518 .02563 L
.80739 .02302 L
.80979 .02082 L
.81206 .01924 L
.81417 .01811 L
.81683 .01705 L
.81927 .01635 L
.82195 .01581 L
.82329 .01561 L
.82477 .01542 L
.82726 .01519 L
.82866 .01509 L
.82993 .01502 L
.83112 .01497 L
.8324 .01492 L
.83361 .01488 L
.83474 .01485 L
.83698 .0148 L
.83816 .01479 L
.83944 .01477 L
.84077 .01476 L
.84204 .01475 L
.84319 .01474 L
.84442 .01474 L
.84559 .01473 L
.84664 .01473 L
.8487 .01472 L
.84985 .01472 L
.8511 .01472 L
.85226 .01472 L
.85337 .01472 L
.8546 .01472 L
.85573 .01472 L
.85695 .01472 L
.85828 .01472 L
.85943 .01472 L
Mistroke
.86066 .01472 L
.86171 .01472 L
.86286 .01472 L
.86421 .01472 L
.86545 .01472 L
.86681 .01472 L
.86824 .01472 L
.86949 .01472 L
.87065 .01472 L
.87193 .01472 L
.87329 .01472 L
.87471 .01472 L
.87601 .01472 L
.87745 .01472 L
.87817 .01472 L
.87896 .01472 L
.8803 .01472 L
.88103 .01472 L
.88173 .01472 L
.88309 .01472 L
.88432 .01472 L
.88553 .01472 L
.88681 .01472 L
.88802 .01472 L
.88912 .01472 L
.89042 .01472 L
.89114 .01472 L
.89181 .01472 L
.89305 .01472 L
.89435 .01472 L
.89557 .01472 L
.89627 .01472 L
.8969 .01472 L
.89808 .01472 L
.89932 .01472 L
.90043 .01472 L
.90147 .01472 L
.90262 .01472 L
.90385 .01472 L
.90508 .01472 L
.90578 .01472 L
.90643 .01472 L
.90775 .01472 L
.90849 .01472 L
.90915 .01472 L
.91035 .01472 L
.91166 .01472 L
.91288 .01472 L
.91402 .01472 L
.91507 .01472 L
Mistroke
.91621 .01472 L
.91728 .01472 L
.91826 .01472 L
.91941 .01472 L
.92066 .01472 L
.92184 .01472 L
.92293 .01472 L
.92405 .01472 L
.9251 .01472 L
.92625 .01472 L
.9275 .01472 L
.92873 .01472 L
.93003 .01472 L
.93114 .01472 L
.93236 .01472 L
.93367 .01472 L
.93488 .01472 L
.93552 .01472 L
.93622 .01472 L
.93694 .01472 L
.93763 .01472 L
.93888 .01472 L
.94003 .01472 L
.94066 .01472 L
.94135 .01472 L
.94261 .01472 L
.94384 .01472 L
.94495 .01472 L
.94623 .01472 L
.94744 .01472 L
.94857 .01472 L
.9496 .01472 L
.95073 .01472 L
.95193 .01472 L
.95324 .01472 L
.95442 .01472 L
.95508 .01472 L
.9558 .01472 L
.95709 .01472 L
.95831 .01472 L
.9596 .01472 L
.9607 .01472 L
.96191 .01472 L
.96261 .01472 L
.96333 .01472 L
.96463 .01472 L
.96536 .01472 L
.96603 .01472 L
.96677 .01472 L
.96757 .01472 L
Mistroke
.96825 .01472 L
.96899 .01472 L
.9697 .01472 L
.97034 .01472 L
.97157 .01472 L
.97287 .01472 L
.9737 .01472 L
.97459 .01472 L
.97542 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[527]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`003_ooool3o`0003Wooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0001aoooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000>?ooool3o`0000kooooo000?ooooo`03
o`000?oooooooooo03Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000006oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000003Sooooo
00?o0000ooooooooool03Oooool000Oooooo1Ol00003ooooo`03o`000?oooooooooo033ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0KOooool01?l0003ooooo
ooooool0000;ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool000oooooo
00?o0000ooooooooool0=oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo06go
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00gooooo000?ooooo`03o`000?oooooooooo03Oooooo00Co0000oooooooooooo00001oooool4o`00
073ooooo00Co0000oooooooooooo00001oooool4o`0003Wooooo00?o0000ooooooooool03Oooool0
00kooooo0_l0000iooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0LOooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo03Wooooo0_l0000?ooooo`003oooool0
0ol0003oooooooooo`0hooooo`;o00002?ooool5o`00073ooooo0_l00008ooooo`Go0000>?ooool0
0ol0003oooooooooo`0=ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003o
ooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003ooooooooo
o`2>ooooo`001oooooooo`0001;o00002?ooool000gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol00006
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03
ooooo`?o00001?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool000gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00oooooo0_l0000]ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool03?ooool003cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo02cooooo0_l0000Rooooo`03o`000?oooooooooo03_ooooo000looooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0>oooool003cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0looooo`00?Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo03cooooo000nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0??ooool003ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0_ooooo`;o0000;oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo03gooooo000nooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0?Oooool003kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0mooooo`00?oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03kooooo000ooooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0?_ooool003oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0nooooo`00@?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo03oooooo0010ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0?ooo
ool0043ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0aooooo`;o0000<Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03oooooo0010ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0?oooool0047ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0oooooo`00@Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo043ooooo
0011ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0@?ooool0047ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`10ooooo`00@Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo043ooooo0011ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0<_ooool2o`0003?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`10ooooo`00
@Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo043ooooo0012ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0@?ooool004;ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`10ooooo`00@_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
043ooooo0012ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0@?ooool004;ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`11ooooo`00@_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo047ooooo0012ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0<oooool2o`0003Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`11
ooooo`00@_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo047ooooo0012ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0@Oooool004;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`11ooooo`00@_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo047ooooo0012ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@Oooool0
04?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0[ooooo`?o00001Oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@Oooool004?o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo047o
oooo0013ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`04ooooo`?o0000=?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04;ooooo
0013ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`12ooooo`00@oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0@_ooool004?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0/oooo
o`;o00001_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0@_ooool004?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
@_ooool004?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`12ooooo`00@oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04;ooooo0013ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0=?ooool2o`0003Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`13ooooo`00@oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04?o
oooo0013ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@oooool004?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`13ooooo`00A?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo04?ooooo0014ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0@oooool004Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`13ooooo`00
A?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04?ooooo0014ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0=Oooool2o`0003Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`13ooooo`00A?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo04?ooooo0014ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@oooool004Co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`14ooooo`00A?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo04Cooooo0014ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0A?ooool004Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`14
ooooo`00A?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo0014ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0=_ooool2o`0003Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`14ooooo`00AOooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo04Cooooo0015ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0A?oo
ool004Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`14ooooo`00AOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo0015ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0A?ooool004Gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`14ooooo`00AOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo0015
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=_ooool2o`0003Oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`15ooooo`00AOooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo04Gooooo0015ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0AOooool004Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`15ooooo`00AOoo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Gooooo0015ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0;_ooool5o`0000Cooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Gooooo0016ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0;oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`15ooooo`00A_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01?ooool3o`00
03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`15ooooo`00A_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0AOooool004Kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0^ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0AOooool004Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0^ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0AOooool004Kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0_ooooo`?o00001Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0AOooool004Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`15ooooo`00A_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Kooooo0016oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0A_ooool004Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0gooooo`;o0000>?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo04Kooooo0016ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
A_ooool004Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`16ooooo`00A_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Kooooo0016ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0A_ooool004Oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`16ooooo`00Aoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Kooooo
0017ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0A_ooool004Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0gooooo`;o0000>Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo04Kooooo0017ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0A_ooool004Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`16ooooo`00
Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Kooooo0017ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0A_ooool004Oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`16ooooo`00Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
04Kooooo0017ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Aoooool004Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`;o0000>Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo04Oooooo0017ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0Aoooool004Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`17
ooooo`00B?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo0018ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool004Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`17ooooo`00B?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04Oooooo0018ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool0
04Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hooooo`;o0000>_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo0018ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0Aoooool004Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`17ooooo`00B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo0018
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool004Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0aooooo`?o00001Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool004Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool004So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oo
oooo0018ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool2o`0000Gooooo
0ol0000iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool004Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo0019
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04Sooooo0019ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool3
o`0000Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04Sooooo0019ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool004Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`18ooooo`00BOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo04Sooooo0019ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0>_ooool2o`0003_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`18ooooo`00BOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo0019oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`18ooooo`00BOooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo04Sooooo0019ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?oo
ool004Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`18ooooo`00BOooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo001:ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0>_ooool2o`0003_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`18ooooo`00B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo
001:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0BOooool004[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`19ooooo`00B_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04Wooooo001:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0BOooool004[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`00B_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Wooooo001:ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0>oooool2o`0003cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`19ooooo`00B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04Wooooo001:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B_ooool004_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1:ooooo`00Boooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04[ooooo001;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0B_ooool004_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1:oooo
o`00Boooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04[ooooo001;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0??ooool2o`0003gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1:ooooo`00Boooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo04[ooooo001<ooooo`05o`000?ooooooooooooooool00000?_ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0B_ooool004cooooo00Go0000
ooooooooooooooooo`00000nooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1:ooooo`00C?ooool01Ol0003ooooooooooooooooo000003kooooo00?o
0000ooooooooool0??ooool01Ol0003ooooooooooooooooo000004gooooo001<ooooo`05o`000?oo
ooooooooooooool00000=oooool3o`0000Cooooo00?o0000ooooooooool0??ooool01Ol0003ooooo
oooooooooooo000004gooooo001<ooooo`04o`000?ooooooooooo`0003Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0mooooo`04o`000?ooooooooooo`0004gooooo001<ooooo`04
o`000?ooooooooooo`0003Kooooo1Ol00004ooooo`03o`000?oooooooooo03gooooo00Co0000oooo
oooooooo0000COooool004cooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0
0005ooooo`?o0000?Oooool00ol0003oooooo`00001>ooooo`00C?ooool01?l0003oooooooooool0
000gooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`00
001>ooooo`00COooool2o`0003Wooooo0_l00005ooooo`03o`000?oooooooooo03kooooo0_l0001>
ooooo`00COooool2o`0003[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0noooo
o`;o0000C_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0
S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.10503, -0.316486, \
0.00770056, 0.0255059}},
  CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot3D[intensity[x,y],{x,-1,1},{y,-.05,.05},PlotRange->All,PlotPoints->100];
\
\>", "Input",
  CellLabel->"In[61]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37803e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -15.8219 -9 ]
[.50253 .05935 2.17811 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.73498 .04732 0 -6.2105 ]
[.73498 .04732 30 2.7895 ]
[.79846 .14452 0 -6.11593 ]
[.79846 .14452 30 2.88407 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.90976 .31495 0 -5.95504 ]
[.90976 .31495 24 3.04496 ]
[.95881 .39008 0 -5.88604 ]
[.95881 .39008 24 3.11396 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01593 .31641 -12 -2.78569 ]
[.01593 .31641 0 6.21431 ]
[.00747 .36945 -12 -2.83068 ]
[.00747 .36945 0 6.16932 ]
[-0.00129 .42431 -12 -2.87738 ]
[-0.00129 .42431 0 6.12262 ]
[-0.01035 .4811 -12 -2.9259 ]
[-0.01035 .4811 0 6.0741 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72272 .05198 m
.71658 .05431 L
s
[(-0.04)] .73498 .04732 -1 .38011 Mshowa
.78611 .14895 m
.77994 .15117 L
s
[(-0.02)] .79846 .14452 -1 .3591 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.89727 .31899 m
.89103 .32101 L
s
[(0.02)] .90976 .31495 -1 .32334 Mshowa
.94627 .39394 m
.94 .39587 L
s
[(0.04)] .95881 .39008 -1 .30801 Mshowa
.125 Mabswid
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.7708 .12553 m
.7671 .12688 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.9099 .3383 m
.90615 .3395 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.70593 .0263 m
.70226 .02771 L
s
.68874 0 m
.68507 .00144 L
s
.95792 .41176 m
.95416 .41291 L
s
.96935 .42924 m
.96558 .43037 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02819 .31174 m
.03432 .3094 L
s
[(20)] .01593 .31641 1 -0.38096 Mshowa
.01977 .36488 m
.02592 .3626 L
s
[(40)] .00747 .36945 1 -0.37096 Mshowa
.01106 .41986 m
.01723 .41764 L
s
[(60)] -0.00129 .42431 1 -0.36058 Mshowa
.00204 .47677 m
.00823 .4746 L
s
[(80)] -0.01035 .4811 1 -0.3498 Mshowa
.125 Mabswid
.03433 .27303 m
.038 .2716 L
s
.0323 .28582 m
.03597 .28441 L
s
.03025 .29873 m
.03393 .29732 L
s
.02611 .32486 m
.02979 .32346 L
s
.02402 .33809 m
.0277 .3367 L
s
.0219 .35143 m
.02559 .35005 L
s
.01762 .37845 m
.02131 .37709 L
s
.01545 .39214 m
.01915 .39078 L
s
.01326 .40594 m
.01696 .4046 L
s
.00883 .4339 m
.01254 .43258 L
s
.00659 .44807 m
.0103 .44675 L
s
.00432 .46236 m
.00803 .46105 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.592 .675 .898 r
.40014 .65394 .40324 .65755 .40848 .65626 .40536 .65338 Metetra
.643 .738 .918 r
.40536 .65338 .40848 .65626 .41376 .65421 .41062 .65208 Metetra
.696 .804 .932 r
.41062 .65208 .41376 .65421 .41906 .6514 .41591 .65 Metetra
.746 .866 .935 r
.41591 .65 .41906 .6514 .4244 .64787 .42124 .64715 Metetra
.787 .917 .926 r
.42124 .64715 .4244 .64787 .42975 .64371 .42659 .64359 Metetra
.817 .954 .906 r
.42659 .64359 .42975 .64371 .43513 .63901 .43196 .63939 Metetra
.834 .977 .881 r
.43196 .63939 .43513 .63901 .44051 .63388 .43735 .63464 Metetra
.843 .989 .856 r
.43735 .63464 .44051 .63388 .4459 .62847 .44275 .62948 Metetra
.847 .994 .837 r
.44275 .62948 .4459 .62847 .45129 .6229 .44815 .62403 Metetra
.849 .996 .826 r
.44815 .62403 .45129 .6229 .45668 .61731 .45356 .61843 Metetra
.85 .996 .825 r
.45356 .61843 .45668 .61731 .46207 .61181 .45896 .61281 Metetra
.85 .995 .833 r
.45896 .61281 .46207 .61181 .46745 .6065 .46436 .60728 Metetra
.849 .991 .847 r
.46436 .60728 .46745 .6065 .47283 .60145 .46976 .60195 Metetra
.845 .983 .865 r
.46976 .60195 .47283 .60145 .4782 .59673 .47515 .59689 Metetra
.837 .971 .883 r
.47515 .59689 .4782 .59673 .48356 .59235 .48054 .59216 Metetra
.826 .954 .9 r
.48054 .59216 .48356 .59235 .48893 .58834 .48592 .58778 Metetra
.81 .933 .912 r
.48592 .58778 .48893 .58834 .4943 .58469 .4913 .58376 Metetra
.793 .909 .921 r
.4913 .58376 .4943 .58469 .49966 .58137 .49668 .5801 Metetra
.774 .884 .925 r
.49668 .5801 .49966 .58137 .50503 .57836 .50207 .57678 Metetra
.755 .86 .927 r
.50207 .57678 .50503 .57836 .51041 .57562 .50745 .57376 Metetra
.738 .837 .926 r
.50745 .57376 .51041 .57562 .51579 .57312 .51284 .57102 Metetra
.722 .817 .924 r
.51284 .57102 .51579 .57312 .52118 .57081 .51824 .56851 Metetra
.709 .801 .922 r
.51824 .56851 .52118 .57081 .52657 .56866 .52365 .56619 Metetra
.698 .787 .919 r
.52365 .56619 .52657 .56866 .53198 .56665 .52906 .56404 Metetra
.69 .775 .917 r
.52906 .56404 .53198 .56665 .5374 .56473 .53448 .56202 Metetra
.683 .766 .915 r
.53448 .56202 .5374 .56473 .54282 .56289 .53992 .56009 Metetra
.678 .76 .913 r
.53992 .56009 .54282 .56289 .54826 .56111 .54536 .55824 Metetra
.674 .754 .912 r
.54536 .55824 .54826 .56111 .55371 .55936 .55082 .55645 Metetra
.671 .751 .911 r
.55082 .55645 .55371 .55936 .55917 .55765 .55628 .5547 Metetra
.668 .748 .91 r
.55628 .5547 .55917 .55765 .56463 .55596 .56176 .55298 Metetra
.667 .746 .909 r
.56176 .55298 .56463 .55596 .57011 .55428 .56724 .55127 Metetra
.666 .744 .909 r
.56724 .55127 .57011 .55428 .5756 .55261 .57274 .54959 Metetra
.665 .743 .909 r
.57274 .54959 .5756 .55261 .58111 .55095 .57825 .54791 Metetra
.665 .743 .908 r
.57825 .54791 .58111 .55095 .58662 .54928 .58377 .54623 Metetra
.664 .742 .908 r
.58377 .54623 .58662 .54928 .59214 .54762 .5893 .54456 Metetra
.664 .742 .908 r
.5893 .54456 .59214 .54762 .59768 .54595 .59484 .54288 Metetra
.664 .742 .908 r
.59484 .54288 .59768 .54595 .60322 .54429 .6004 .54121 Metetra
.664 .742 .908 r
.6004 .54121 .60322 .54429 .60878 .54262 .60596 .53953 Metetra
.664 .741 .908 r
.60596 .53953 .60878 .54262 .61435 .54095 .61154 .53786 Metetra
.664 .741 .908 r
.61154 .53786 .61435 .54095 .61993 .53927 .61712 .53617 Metetra
.664 .741 .908 r
.61712 .53617 .61993 .53927 .62552 .5376 .62272 .53449 Metetra
.664 .741 .908 r
.62272 .53449 .62552 .5376 .63112 .53591 .62833 .5328 Metetra
.664 .741 .908 r
.62833 .5328 .63112 .53591 .63673 .53423 .63395 .53111 Metetra
.664 .741 .908 r
.63395 .53111 .63673 .53423 .64235 .53254 .63958 .52942 Metetra
.664 .741 .908 r
.63958 .52942 .64235 .53254 .64799 .53085 .64522 .52772 Metetra
.664 .741 .908 r
.64522 .52772 .64799 .53085 .65364 .52916 .65088 .52602 Metetra
.664 .741 .908 r
.65088 .52602 .65364 .52916 .65929 .52746 .65654 .52432 Metetra
.664 .741 .908 r
.65654 .52432 .65929 .52746 .66496 .52576 .66222 .52261 Metetra
.664 .741 .908 r
.66222 .52261 .66496 .52576 .67064 .52406 .66791 .5209 Metetra
.664 .741 .908 r
.66791 .5209 .67064 .52406 .67633 .52235 .67361 .51919 Metetra
.664 .741 .908 r
.67361 .51919 .67633 .52235 .68204 .52064 .67932 .51747 Metetra
.664 .741 .908 r
.67932 .51747 .68204 .52064 .68775 .51892 .68504 .51575 Metetra
.664 .741 .908 r
.68504 .51575 .68775 .51892 .69348 .51721 .69078 .51403 Metetra
.664 .741 .908 r
.69078 .51403 .69348 .51721 .69922 .51548 .69652 .5123 Metetra
.664 .741 .908 r
.69652 .5123 .69922 .51548 .70497 .51376 .70228 .51057 Metetra
.664 .741 .908 r
.70228 .51057 .70497 .51376 .71073 .51203 .70805 .50883 Metetra
.664 .741 .908 r
.70805 .50883 .71073 .51203 .7165 .5103 .71383 .50709 Metetra
.663 .741 .908 r
.71383 .50709 .7165 .5103 .72229 .50857 .71962 .50535 Metetra
.663 .741 .908 r
.71962 .50535 .72229 .50857 .72808 .50683 .72543 .50361 Metetra
.663 .741 .908 r
.72543 .50361 .72808 .50683 .73389 .50509 .73125 .50186 Metetra
.663 .741 .908 r
.73125 .50186 .73389 .50509 .73971 .50334 .73708 .50012 Metetra
.663 .741 .908 r
.73708 .50012 .73971 .50334 .74555 .5016 .74292 .49837 Metetra
.663 .741 .909 r
.74292 .49837 .74555 .5016 .75139 .49986 .74877 .49662 Metetra
.662 .742 .909 r
.74877 .49662 .75139 .49986 .75725 .49812 .75464 .49488 Metetra
.661 .742 .91 r
.75464 .49488 .75725 .49812 .76312 .49638 .76051 .49315 Metetra
.66 .742 .91 r
.76051 .49315 .76312 .49638 .769 .49465 .76641 .49143 Metetra
.659 .742 .912 r
.76641 .49143 .769 .49465 .7749 .49293 .77231 .48972 Metetra
.657 .743 .913 r
.77231 .48972 .7749 .49293 .78081 .49124 .77823 .48805 Metetra
.654 .744 .916 r
.77823 .48805 .78081 .49124 .78673 .48957 .78417 .48641 Metetra
.65 .745 .919 r
.78417 .48641 .78673 .48957 .79267 .48794 .79012 .48482 Metetra
.645 .746 .923 r
.79012 .48482 .79267 .48794 .79863 .48636 .7961 .4833 Metetra
.638 .748 .928 r
.7961 .4833 .79863 .48636 .80461 .48485 .80209 .48186 Metetra
.629 .75 .934 r
.80209 .48186 .80461 .48485 .81061 .48342 .80811 .48052 Metetra
.617 .752 .942 r
.80811 .48052 .81061 .48342 .81663 .48209 .81415 .4793 Metetra
.602 .755 .951 r
.81415 .4793 .81663 .48209 .82267 .48089 .82021 .47822 Metetra
.583 .757 .961 r
.82021 .47822 .82267 .48089 .82875 .47983 .82631 .47731 Metetra
.558 .759 .972 r
.82631 .47731 .82875 .47983 .83486 .47893 .83245 .47658 Metetra
.527 .76 .982 r
.83245 .47658 .83486 .47893 .841 .47822 .83861 .47605 Metetra
.487 .757 .99 r
.83861 .47605 .841 .47822 .84717 .4777 .84482 .47572 Metetra
.439 .751 .994 r
.84482 .47572 .84717 .4777 .85339 .47739 .85106 .47561 Metetra
.38 .738 .991 r
.85106 .47561 .85339 .47739 .85964 .47728 .85735 .47572 Metetra
.315 .718 .978 r
.85735 .47572 .85964 .47728 .86593 .47739 .86368 .47602 Metetra
.245 .692 .956 r
.86368 .47602 .86593 .47739 .87227 .47769 .87005 .4765 Metetra
.177 .661 .926 r
.87005 .4765 .87227 .47769 .87865 .47816 .87645 .47713 Metetra
.117 .631 .893 r
.87645 .47713 .87865 .47816 .88506 .47879 .88289 .47789 Metetra
.073 .606 .863 r
.88289 .47789 .88506 .47879 .89151 .47952 .88937 .47871 Metetra
.047 .591 .843 r
.88937 .47871 .89151 .47952 .89799 .48032 .89587 .47955 Metetra
.043 .59 .837 r
.89587 .47955 .89799 .48032 .9045 .48114 .90239 .48036 Metetra
.062 .605 .847 r
.90239 .48036 .9045 .48114 .91102 .48192 .90892 .48108 Metetra
.105 .634 .872 r
.90892 .48108 .91102 .48192 .91756 .4826 .91546 .48166 Metetra
.171 .675 .908 r
.91546 .48166 .91756 .4826 .92411 .48314 .922 .48203 Metetra
.254 .72 .947 r
.922 .48203 .92411 .48314 .93065 .48348 .92853 .48215 Metetra
.346 .761 .979 r
.92853 .48215 .93065 .48348 .93718 .48356 .93504 .48198 Metetra
.437 .79 .997 r
.93504 .48198 .93718 .48356 .9437 .48336 .94154 .48148 Metetra
.516 .804 .998 r
.94154 .48148 .9437 .48336 .9502 .48284 .94801 .48063 Metetra
.58 .805 .985 r
.94801 .48063 .9502 .48284 .95667 .48197 .95445 .47941 Metetra
.628 .797 .963 r
.95445 .47941 .95667 .48197 .96312 .48074 .96085 .47782 Metetra
.662 .783 .938 r
.96085 .47782 .96312 .48074 .96953 .47914 .96723 .47587 Metetra
.686 .768 .914 r
.96723 .47587 .96953 .47914 .9759 .47719 .97357 .47356 Metetra
.546 .619 .876 r
.39706 .64962 .40014 .65394 .40536 .65338 .40225 .64975 Metetra
.592 .675 .898 r
.40225 .64975 .40536 .65338 .41062 .65208 .40749 .64919 Metetra
.644 .739 .918 r
.40749 .64919 .41062 .65208 .41591 .65 .41277 .64786 Metetra
.697 .805 .932 r
.41277 .64786 .41591 .65 .42124 .64715 .41808 .64575 Metetra
.747 .867 .935 r
.41808 .64575 .42124 .64715 .42659 .64359 .42342 .64288 Metetra
.789 .918 .925 r
.42342 .64288 .42659 .64359 .43196 .63939 .42879 .63928 Metetra
.818 .955 .905 r
.42879 .63928 .43196 .63939 .43735 .63464 .43418 .63503 Metetra
.835 .978 .88 r
.43418 .63503 .43735 .63464 .44275 .62948 .43958 .63025 Metetra
.844 .99 .854 r
.43958 .63025 .44275 .62948 .44815 .62403 .445 .62505 Metetra
.848 .995 .835 r
.445 .62505 .44815 .62403 .45356 .61843 .45042 .61956 Metetra
.849 .996 .825 r
.45042 .61956 .45356 .61843 .45896 .61281 .45584 .61393 Metetra
.85 .996 .824 r
.45584 .61393 .45896 .61281 .46436 .60728 .46126 .60828 Metetra
.85 .995 .832 r
.46126 .60828 .46436 .60728 .46976 .60195 .46667 .60274 Metetra
.849 .991 .847 r
.46667 .60274 .46976 .60195 .47515 .59689 .47208 .59739 Metetra
.845 .983 .865 r
.47208 .59739 .47515 .59689 .48054 .59216 .47749 .59231 Metetra
.837 .971 .884 r
.47749 .59231 .48054 .59216 .48592 .58778 .48289 .58757 Metetra
.825 .954 .9 r
.48289 .58757 .48592 .58778 .4913 .58376 .48829 .58318 Metetra
.81 .933 .913 r
.48829 .58318 .4913 .58376 .49668 .5801 .49369 .57915 Metetra
.792 .909 .921 r
.49369 .57915 .49668 .5801 .50207 .57678 .49908 .57549 Metetra
.773 .884 .925 r
.49908 .57549 .50207 .57678 .50745 .57376 .50448 .57216 Metetra
.755 .859 .927 r
.50448 .57216 .50745 .57376 .51284 .57102 .50988 .56914 Metetra
.738 .837 .926 r
.50988 .56914 .51284 .57102 .51824 .56851 .51529 .56639 Metetra
.722 .817 .924 r
.51529 .56639 .51824 .56851 .52365 .56619 .52071 .56388 Metetra
.709 .8 .922 r
.52071 .56388 .52365 .56619 .52906 .56404 .52613 .56155 Metetra
.698 .786 .919 r
.52613 .56155 .52906 .56404 .53448 .56202 .53156 .55939 Metetra
.69 .775 .917 r
.53156 .55939 .53448 .56202 .53992 .56009 .537 .55736 Metetra
.683 .766 .915 r
.537 .55736 .53992 .56009 .54536 .55824 .54245 .55542 Metetra
.678 .76 .913 r
.54245 .55542 .54536 .55824 .55082 .55645 .54792 .55357 Metetra
.674 .754 .912 r
.54792 .55357 .55082 .55645 .55628 .5547 .55339 .55176 Metetra
.671 .751 .911 r
.55339 .55176 .55628 .5547 .56176 .55298 .55887 .55 Metetra
.668 .748 .91 r
.55887 .55 .56176 .55298 .56724 .55127 .56437 .54827 Metetra
.667 .746 .909 r
.56437 .54827 .56724 .55127 .57274 .54959 .56987 .54656 Metetra
.666 .744 .909 r
.56987 .54656 .57274 .54959 .57825 .54791 .57539 .54486 Metetra
.665 .743 .909 r
.57539 .54486 .57825 .54791 .58377 .54623 .58091 .54317 Metetra
.665 .743 .908 r
.58091 .54317 .58377 .54623 .5893 .54456 .58645 .54149 Metetra
.664 .742 .908 r
.58645 .54149 .5893 .54456 .59484 .54288 .592 .53981 Metetra
.664 .742 .908 r
.592 .53981 .59484 .54288 .6004 .54121 .59756 .53812 Metetra
.664 .742 .908 r
.59756 .53812 .6004 .54121 .60596 .53953 .60313 .53644 Metetra
.664 .742 .908 r
.60313 .53644 .60596 .53953 .61154 .53786 .60872 .53475 Metetra
.664 .741 .908 r
.60872 .53475 .61154 .53786 .61712 .53617 .61431 .53307 Metetra
.664 .741 .908 r
.61431 .53307 .61712 .53617 .62272 .53449 .61991 .53138 Metetra
.664 .741 .908 r
.61991 .53138 .62272 .53449 .62833 .5328 .62553 .52968 Metetra
.664 .741 .908 r
.62553 .52968 .62833 .5328 .63395 .53111 .63116 .52799 Metetra
.664 .741 .908 r
.63116 .52799 .63395 .53111 .63958 .52942 .6368 .52629 Metetra
.664 .741 .908 r
.6368 .52629 .63958 .52942 .64522 .52772 .64245 .52458 Metetra
.664 .741 .908 r
.64245 .52458 .64522 .52772 .65088 .52602 .64811 .52288 Metetra
.664 .741 .908 r
.64811 .52288 .65088 .52602 .65654 .52432 .65378 .52117 Metetra
.664 .741 .908 r
.65378 .52117 .65654 .52432 .66222 .52261 .65947 .51945 Metetra
.664 .741 .908 r
.65947 .51945 .66222 .52261 .66791 .5209 .66516 .51773 Metetra
.664 .741 .908 r
.66516 .51773 .66791 .5209 .67361 .51919 .67087 .51601 Metetra
.664 .741 .908 r
.67087 .51601 .67361 .51919 .67932 .51747 .67659 .51429 Metetra
.664 .741 .908 r
.67659 .51429 .67932 .51747 .68504 .51575 .68232 .51256 Metetra
.664 .741 .908 r
.68232 .51256 .68504 .51575 .69078 .51403 .68806 .51083 Metetra
.664 .741 .908 r
.68806 .51083 .69078 .51403 .69652 .5123 .69382 .5091 Metetra
.664 .741 .908 r
.69382 .5091 .69652 .5123 .70228 .51057 .69958 .50736 Metetra
.664 .741 .908 r
.69958 .50736 .70228 .51057 .70805 .50883 .70536 .50562 Metetra
.663 .741 .908 r
.70536 .50562 .70805 .50883 .71383 .50709 .71115 .50388 Metetra
.663 .741 .908 r
.71115 .50388 .71383 .50709 .71962 .50535 .71695 .50213 Metetra
.663 .741 .908 r
.71695 .50213 .71962 .50535 .72543 .50361 .72277 .50038 Metetra
.663 .741 .908 r
.72277 .50038 .72543 .50361 .73125 .50186 .72859 .49863 Metetra
.663 .741 .908 r
.72859 .49863 .73125 .50186 .73708 .50012 .73443 .49688 Metetra
.663 .741 .909 r
.73443 .49688 .73708 .50012 .74292 .49837 .74028 .49513 Metetra
.662 .742 .909 r
.74028 .49513 .74292 .49837 .74877 .49662 .74614 .49338 Metetra
.661 .742 .91 r
.74614 .49338 .74877 .49662 .75464 .49488 .75202 .49164 Metetra
.66 .742 .91 r
.75202 .49164 .75464 .49488 .76051 .49315 .7579 .48992 Metetra
.659 .742 .912 r
.7579 .48992 .76051 .49315 .76641 .49143 .76381 .48821 Metetra
.657 .743 .913 r
.76381 .48821 .76641 .49143 .77231 .48972 .76972 .48652 Metetra
.654 .744 .915 r
.76972 .48652 .77231 .48972 .77823 .48805 .77565 .48488 Metetra
.65 .745 .918 r
.77565 .48488 .77823 .48805 .78417 .48641 .7816 .48328 Metetra
.645 .746 .922 r
.7816 .48328 .78417 .48641 .79012 .48482 .78757 .48175 Metetra
.639 .748 .927 r
.78757 .48175 .79012 .48482 .7961 .4833 .79356 .48029 Metetra
.63 .75 .934 r
.79356 .48029 .7961 .4833 .80209 .48186 .79957 .47894 Metetra
.619 .752 .941 r
.79957 .47894 .80209 .48186 .80811 .48052 .8056 .47771 Metetra
.604 .755 .95 r
.8056 .47771 .80811 .48052 .81415 .4793 .81166 .47661 Metetra
.585 .757 .96 r
.81166 .47661 .81415 .4793 .82021 .47822 .81776 .47569 Metetra
.56 .759 .971 r
.81776 .47569 .82021 .47822 .82631 .47731 .82388 .47494 Metetra
.529 .76 .981 r
.82388 .47494 .82631 .47731 .83245 .47658 .83004 .4744 Metetra
.489 .757 .99 r
.83004 .4744 .83245 .47658 .83861 .47605 .83624 .47406 Metetra
.44 .751 .994 r
.83624 .47406 .83861 .47605 .84482 .47572 .84247 .47394 Metetra
.381 .738 .991 r
.84247 .47394 .84482 .47572 .85106 .47561 .84875 .47404 Metetra
.314 .718 .978 r
.84875 .47404 .85106 .47561 .85735 .47572 .85507 .47434 Metetra
.242 .691 .955 r
.85507 .47434 .85735 .47572 .86368 .47602 .86143 .47483 Metetra
.172 .659 .924 r
.86143 .47483 .86368 .47602 .87005 .4765 .86783 .47548 Metetra
.11 .626 .889 r
.86783 .47548 .87005 .4765 .87645 .47713 .87426 .47624 Metetra
.063 .599 .857 r
.87426 .47624 .87645 .47713 .88289 .47789 .88073 .47709 Metetra
.035 .583 .835 r
.88073 .47709 .88289 .47789 .88937 .47871 .88722 .47796 Metetra
.029 .581 .827 r
.88722 .47796 .88937 .47871 .89587 .47955 .89373 .4788 Metetra
.047 .595 .836 r
.89373 .4788 .89587 .47955 .90239 .48036 .90026 .47956 Metetra
.09 .625 .862 r
.90026 .47956 .90239 .48036 .90892 .48108 .90679 .48017 Metetra
.156 .666 .899 r
.90679 .48017 .90892 .48108 .91546 .48166 .91333 .48057 Metetra
.24 .713 .941 r
.91333 .48057 .91546 .48166 .922 .48203 .91985 .48073 Metetra
.335 .756 .976 r
.91985 .48073 .922 .48203 .92853 .48215 .92636 .48059 Metetra
.428 .788 .996 r
.92636 .48059 .92853 .48215 .93504 .48198 .93286 .48012 Metetra
.511 .804 .999 r
.93286 .48012 .93504 .48198 .94154 .48148 .93932 .47929 Metetra
.577 .806 .986 r
.93932 .47929 .94154 .48148 .94801 .48063 .94576 .47808 Metetra
.626 .798 .965 r
.94576 .47808 .94801 .48063 .95445 .47941 .95217 .4765 Metetra
.662 .784 .939 r
.95217 .4765 .95445 .47941 .96085 .47782 .95854 .47455 Metetra
.686 .768 .914 r
.95854 .47455 .96085 .47782 .96723 .47587 .96488 .47224 Metetra
.703 .753 .89 r
.96488 .47224 .96723 .47587 .97357 .47356 .97118 .46959 Metetra
.507 .571 .854 r
.39399 .64465 .39706 .64962 .40225 .64975 .39916 .6454 Metetra
.546 .618 .876 r
.39916 .6454 .40225 .64975 .40749 .64919 .40438 .64554 Metetra
.592 .675 .898 r
.40438 .64554 .40749 .64919 .41277 .64786 .40964 .64496 Metetra
.644 .739 .918 r
.40964 .64496 .41277 .64786 .41808 .64575 .41493 .64361 Metetra
.699 .806 .932 r
.41493 .64361 .41808 .64575 .42342 .64288 .42026 .64148 Metetra
.749 .868 .935 r
.42026 .64148 .42342 .64288 .42879 .63928 .42562 .63857 Metetra
.79 .919 .925 r
.42562 .63857 .42879 .63928 .43418 .63503 .431 .63494 Metetra
.819 .956 .904 r
.431 .63494 .43418 .63503 .43958 .63025 .43641 .63065 Metetra
.836 .979 .878 r
.43641 .63065 .43958 .63025 .445 .62505 .44183 .62583 Metetra
.844 .99 .853 r
.44183 .62583 .445 .62505 .45042 .61956 .44726 .62059 Metetra
.848 .995 .834 r
.44726 .62059 .45042 .61956 .45584 .61393 .45269 .61507 Metetra
.849 .997 .824 r
.45269 .61507 .45584 .61393 .46126 .60828 .45813 .6094 Metetra
.85 .996 .823 r
.45813 .6094 .46126 .60828 .46667 .60274 .46356 .60373 Metetra
.85 .995 .832 r
.46356 .60373 .46667 .60274 .47208 .59739 .46899 .59816 Metetra
.849 .991 .847 r
.46899 .59816 .47208 .59739 .47749 .59231 .47442 .5928 Metetra
.845 .984 .865 r
.47442 .5928 .47749 .59231 .48289 .58757 .47984 .58771 Metetra
.837 .971 .884 r
.47984 .58771 .48289 .58757 .48829 .58318 .48526 .58296 Metetra
.825 .954 .9 r
.48526 .58296 .48829 .58318 .49369 .57915 .49067 .57856 Metetra
.81 .933 .913 r
.49067 .57856 .49369 .57915 .49908 .57549 .49608 .57453 Metetra
.792 .909 .921 r
.49608 .57453 .49908 .57549 .50448 .57216 .5015 .57086 Metetra
.773 .884 .925 r
.5015 .57086 .50448 .57216 .50988 .56914 .50691 .56752 Metetra
.754 .859 .927 r
.50691 .56752 .50988 .56914 .51529 .56639 .51233 .5645 Metetra
.737 .837 .926 r
.51233 .5645 .51529 .56639 .52071 .56388 .51776 .56174 Metetra
.722 .817 .924 r
.51776 .56174 .52071 .56388 .52613 .56155 .52319 .55922 Metetra
.709 .8 .922 r
.52319 .55922 .52613 .56155 .53156 .55939 .52863 .55689 Metetra
.698 .786 .919 r
.52863 .55689 .53156 .55939 .537 .55736 .53408 .55472 Metetra
.69 .775 .917 r
.53408 .55472 .537 .55736 .54245 .55542 .53954 .55268 Metetra
.683 .766 .915 r
.53954 .55268 .54245 .55542 .54792 .55357 .545 .55073 Metetra
.678 .76 .913 r
.545 .55073 .54792 .55357 .55339 .55176 .55048 .54887 Metetra
.674 .755 .912 r
.55048 .54887 .55339 .55176 .55887 .55 .55597 .54705 Metetra
.671 .751 .911 r
.55597 .54705 .55887 .55 .56437 .54827 .56148 .54528 Metetra
.668 .748 .91 r
.56148 .54528 .56437 .54827 .56987 .54656 .56699 .54354 Metetra
.667 .746 .909 r
.56699 .54354 .56987 .54656 .57539 .54486 .57251 .54182 Metetra
.666 .744 .909 r
.57251 .54182 .57539 .54486 .58091 .54317 .57804 .54011 Metetra
.665 .743 .909 r
.57804 .54011 .58091 .54317 .58645 .54149 .58359 .53841 Metetra
.665 .743 .908 r
.58359 .53841 .58645 .54149 .592 .53981 .58915 .53672 Metetra
.664 .742 .908 r
.58915 .53672 .592 .53981 .59756 .53812 .59471 .53503 Metetra
.664 .742 .908 r
.59471 .53503 .59756 .53812 .60313 .53644 .60029 .53333 Metetra
.664 .742 .908 r
.60029 .53333 .60313 .53644 .60872 .53475 .60588 .53164 Metetra
.664 .742 .908 r
.60588 .53164 .60872 .53475 .61431 .53307 .61148 .52995 Metetra
.664 .741 .908 r
.61148 .52995 .61431 .53307 .61991 .53138 .6171 .52825 Metetra
.664 .741 .908 r
.6171 .52825 .61991 .53138 .62553 .52968 .62272 .52655 Metetra
.664 .741 .908 r
.62272 .52655 .62553 .52968 .63116 .52799 .62836 .52485 Metetra
.664 .741 .908 r
.62836 .52485 .63116 .52799 .6368 .52629 .634 .52314 Metetra
.664 .741 .908 r
.634 .52314 .6368 .52629 .64245 .52458 .63966 .52143 Metetra
.664 .741 .908 r
.63966 .52143 .64245 .52458 .64811 .52288 .64533 .51972 Metetra
.664 .741 .908 r
.64533 .51972 .64811 .52288 .65378 .52117 .65101 .518 Metetra
.664 .741 .908 r
.65101 .518 .65378 .52117 .65947 .51945 .6567 .51628 Metetra
.664 .741 .908 r
.6567 .51628 .65947 .51945 .66516 .51773 .66241 .51456 Metetra
.664 .741 .908 r
.66241 .51456 .66516 .51773 .67087 .51601 .66812 .51283 Metetra
.664 .741 .908 r
.66812 .51283 .67087 .51601 .67659 .51429 .67385 .5111 Metetra
.664 .741 .908 r
.67385 .5111 .67659 .51429 .68232 .51256 .67959 .50937 Metetra
.664 .741 .908 r
.67959 .50937 .68232 .51256 .68806 .51083 .68534 .50763 Metetra
.664 .741 .908 r
.68534 .50763 .68806 .51083 .69382 .5091 .6911 .50589 Metetra
.664 .741 .908 r
.6911 .50589 .69382 .5091 .69958 .50736 .69688 .50414 Metetra
.663 .741 .908 r
.69688 .50414 .69958 .50736 .70536 .50562 .70266 .5024 Metetra
.663 .741 .908 r
.70266 .5024 .70536 .50562 .71115 .50388 .70846 .50065 Metetra
.663 .741 .908 r
.70846 .50065 .71115 .50388 .71695 .50213 .71427 .49889 Metetra
.663 .741 .908 r
.71427 .49889 .71695 .50213 .72277 .50038 .72009 .49714 Metetra
.663 .741 .908 r
.72009 .49714 .72277 .50038 .72859 .49863 .72592 .49539 Metetra
.663 .741 .909 r
.72592 .49539 .72859 .49863 .73443 .49688 .73177 .49363 Metetra
.662 .742 .909 r
.73177 .49363 .73443 .49688 .74028 .49513 .73763 .49188 Metetra
.662 .742 .909 r
.73763 .49188 .74028 .49513 .74614 .49338 .7435 .49014 Metetra
.661 .742 .91 r
.7435 .49014 .74614 .49338 .75202 .49164 .74938 .48841 Metetra
.659 .742 .911 r
.74938 .48841 .75202 .49164 .7579 .48992 .75528 .48669 Metetra
.657 .743 .913 r
.75528 .48669 .7579 .48992 .76381 .48821 .7612 .485 Metetra
.655 .744 .915 r
.7612 .485 .76381 .48821 .76972 .48652 .76712 .48335 Metetra
.651 .744 .918 r
.76712 .48335 .76972 .48652 .77565 .48488 .77307 .48174 Metetra
.646 .746 .922 r
.77307 .48174 .77565 .48488 .7816 .48328 .77903 .48019 Metetra
.639 .747 .927 r
.77903 .48019 .7816 .48328 .78757 .48175 .78501 .47873 Metetra
.631 .749 .933 r
.78501 .47873 .78757 .48175 .79356 .48029 .79102 .47736 Metetra
.62 .752 .941 r
.79102 .47736 .79356 .48029 .79957 .47894 .79705 .47611 Metetra
.605 .754 .949 r
.79705 .47611 .79957 .47894 .8056 .47771 .8031 .47501 Metetra
.586 .757 .959 r
.8031 .47501 .8056 .47771 .81166 .47661 .80919 .47406 Metetra
.562 .759 .97 r
.80919 .47406 .81166 .47661 .81776 .47569 .8153 .4733 Metetra
.531 .76 .981 r
.8153 .4733 .81776 .47569 .82388 .47494 .82145 .47274 Metetra
.491 .758 .989 r
.82145 .47274 .82388 .47494 .83004 .4744 .82764 .4724 Metetra
.442 .751 .994 r
.82764 .4724 .83004 .4744 .83624 .47406 .83387 .47227 Metetra
.382 .738 .991 r
.83387 .47227 .83624 .47406 .84247 .47394 .84014 .47236 Metetra
.314 .718 .978 r
.84014 .47236 .84247 .47394 .84875 .47404 .84645 .47266 Metetra
.24 .69 .955 r
.84645 .47266 .84875 .47404 .85507 .47434 .8528 .47316 Metetra
.168 .656 .922 r
.8528 .47316 .85507 .47434 .86143 .47483 .85919 .47381 Metetra
.103 .622 .885 r
.85919 .47381 .86143 .47483 .86783 .47548 .86561 .4746 Metetra
.054 .593 .851 r
.86561 .4746 .86783 .47548 .87426 .47624 .87207 .47547 Metetra
.023 .575 .827 r
.87207 .47547 .87426 .47624 .88073 .47709 .87855 .47637 Metetra
.016 .572 .818 r
.87855 .47637 .88073 .47709 .88722 .47796 .88506 .47724 Metetra
.032 .585 .826 r
.88506 .47724 .88722 .47796 .89373 .4788 .89158 .47803 Metetra
.074 .614 .851 r
.89158 .47803 .89373 .4788 .90026 .47956 .89811 .47867 Metetra
.14 .657 .89 r
.89811 .47867 .90026 .47956 .90679 .48017 .90464 .47912 Metetra
.226 .706 .934 r
.90464 .47912 .90679 .48017 .91333 .48057 .91116 .47931 Metetra
.323 .752 .972 r
.91116 .47931 .91333 .48057 .91985 .48073 .91767 .4792 Metetra
.42 .786 .995 r
.91767 .4792 .91985 .48073 .92636 .48059 .92416 .47875 Metetra
.505 .804 .999 r
.92416 .47875 .92636 .48059 .93286 .48012 .93062 .47794 Metetra
.574 .806 .987 r
.93062 .47794 .93286 .48012 .93932 .47929 .93706 .47676 Metetra
.625 .798 .966 r
.93706 .47676 .93932 .47929 .94576 .47808 .94346 .47518 Metetra
.661 .785 .94 r
.94346 .47518 .94576 .47808 .95217 .4765 .94983 .47323 Metetra
.687 .769 .914 r
.94983 .47323 .95217 .4765 .95854 .47455 .95617 .47091 Metetra
.704 .753 .89 r
.95617 .47091 .95854 .47455 .96488 .47224 .96247 .46825 Metetra
.715 .738 .869 r
.96247 .46825 .96488 .47224 .97118 .46959 .96874 .46528 Metetra
.476 .532 .835 r
.39093 .6391 .39399 .64465 .39916 .6454 .39609 .64039 Metetra
.506 .57 .854 r
.39609 .64039 .39916 .6454 .40438 .64554 .40129 .64116 Metetra
.546 .618 .875 r
.40129 .64116 .40438 .64554 .40964 .64496 .40652 .64129 Metetra
.593 .675 .898 r
.40652 .64129 .40964 .64496 .41493 .64361 .41179 .6407 Metetra
.645 .74 .918 r
.41179 .6407 .41493 .64361 .42026 .64148 .4171 .63933 Metetra
.7 .807 .932 r
.4171 .63933 .42026 .64148 .42562 .63857 .42245 .63718 Metetra
.75 .869 .934 r
.42245 .63718 .42562 .63857 .431 .63494 .42783 .63424 Metetra
.791 .921 .924 r
.42783 .63424 .431 .63494 .43641 .63065 .43323 .63056 Metetra
.82 .957 .903 r
.43323 .63056 .43641 .63065 .44183 .62583 .43865 .62624 Metetra
.837 .979 .877 r
.43865 .62624 .44183 .62583 .44726 .62059 .44409 .62138 Metetra
.845 .991 .852 r
.44409 .62138 .44726 .62059 .45269 .61507 .44953 .6161 Metetra
.848 .995 .832 r
.44953 .6161 .45269 .61507 .45813 .6094 .45498 .61055 Metetra
.849 .997 .822 r
.45498 .61055 .45813 .6094 .46356 .60373 .46043 .60485 Metetra
.85 .997 .822 r
.46043 .60485 .46356 .60373 .46899 .59816 .46588 .59915 Metetra
.85 .995 .831 r
.46588 .59915 .46899 .59816 .47442 .5928 .47133 .59357 Metetra
.849 .991 .846 r
.47133 .59357 .47442 .5928 .47984 .58771 .47677 .58819 Metetra
.845 .984 .865 r
.47677 .58819 .47984 .58771 .48526 .58296 .48221 .58309 Metetra
.837 .971 .884 r
.48221 .58309 .48526 .58296 .49067 .57856 .48764 .57832 Metetra
.825 .954 .9 r
.48764 .57832 .49067 .57856 .49608 .57453 .49307 .57392 Metetra
.81 .933 .913 r
.49307 .57392 .49608 .57453 .5015 .57086 .49849 .56988 Metetra
.792 .908 .921 r
.49849 .56988 .5015 .57086 .50691 .56752 .50392 .5662 Metetra
.773 .883 .926 r
.50392 .5662 .50691 .56752 .51233 .5645 .50936 .56286 Metetra
.754 .859 .927 r
.50936 .56286 .51233 .5645 .51776 .56174 .51479 .55983 Metetra
.737 .837 .926 r
.51479 .55983 .51776 .56174 .52319 .55922 .52023 .55707 Metetra
.722 .817 .924 r
.52023 .55707 .52319 .55922 .52863 .55689 .52568 .55454 Metetra
.709 .8 .922 r
.52568 .55454 .52863 .55689 .53408 .55472 .53114 .5522 Metetra
.698 .786 .919 r
.53114 .5522 .53408 .55472 .53954 .55268 .53661 .55002 Metetra
.69 .775 .917 r
.53661 .55002 .53954 .55268 .545 .55073 .54208 .54797 Metetra
.683 .767 .915 r
.54208 .54797 .545 .55073 .55048 .54887 .54757 .54602 Metetra
.678 .76 .913 r
.54757 .54602 .55048 .54887 .55597 .54705 .55307 .54414 Metetra
.674 .755 .912 r
.55307 .54414 .55597 .54705 .56148 .54528 .55857 .54232 Metetra
.671 .751 .911 r
.55857 .54232 .56148 .54528 .56699 .54354 .56409 .54054 Metetra
.669 .748 .91 r
.56409 .54054 .56699 .54354 .57251 .54182 .56962 .53879 Metetra
.667 .746 .909 r
.56962 .53879 .57251 .54182 .57804 .54011 .57517 .53706 Metetra
.666 .744 .909 r
.57517 .53706 .57804 .54011 .58359 .53841 .58072 .53534 Metetra
.665 .743 .909 r
.58072 .53534 .58359 .53841 .58915 .53672 .58628 .53363 Metetra
.665 .743 .908 r
.58628 .53363 .58915 .53672 .59471 .53503 .59186 .53192 Metetra
.664 .742 .908 r
.59186 .53192 .59471 .53503 .60029 .53333 .59744 .53022 Metetra
.664 .742 .908 r
.59744 .53022 .60029 .53333 .60588 .53164 .60304 .52852 Metetra
.664 .742 .908 r
.60304 .52852 .60588 .53164 .61148 .52995 .60865 .52682 Metetra
.664 .742 .908 r
.60865 .52682 .61148 .52995 .6171 .52825 .61427 .52511 Metetra
.664 .741 .908 r
.61427 .52511 .6171 .52825 .62272 .52655 .6199 .5234 Metetra
.664 .741 .908 r
.6199 .5234 .62272 .52655 .62836 .52485 .62554 .52169 Metetra
.664 .741 .908 r
.62554 .52169 .62836 .52485 .634 .52314 .6312 .51998 Metetra
.664 .741 .908 r
.6312 .51998 .634 .52314 .63966 .52143 .63686 .51826 Metetra
.664 .741 .908 r
.63686 .51826 .63966 .52143 .64533 .51972 .64254 .51654 Metetra
.664 .741 .908 r
.64254 .51654 .64533 .51972 .65101 .518 .64823 .51482 Metetra
.664 .741 .908 r
.64823 .51482 .65101 .518 .6567 .51628 .65393 .5131 Metetra
.664 .741 .908 r
.65393 .5131 .6567 .51628 .66241 .51456 .65964 .51137 Metetra
.664 .741 .908 r
.65964 .51137 .66241 .51456 .66812 .51283 .66537 .50963 Metetra
.664 .741 .908 r
.66537 .50963 .66812 .51283 .67385 .5111 .6711 .5079 Metetra
.664 .741 .908 r
.6711 .5079 .67385 .5111 .67959 .50937 .67685 .50616 Metetra
.664 .741 .908 r
.67685 .50616 .67959 .50937 .68534 .50763 .68261 .50441 Metetra
.664 .741 .908 r
.68261 .50441 .68534 .50763 .6911 .50589 .68838 .50266 Metetra
.663 .741 .908 r
.68838 .50266 .6911 .50589 .69688 .50414 .69416 .50091 Metetra
.663 .741 .908 r
.69416 .50091 .69688 .50414 .70266 .5024 .69995 .49916 Metetra
.663 .741 .908 r
.69995 .49916 .70266 .5024 .70846 .50065 .70576 .49741 Metetra
.663 .741 .908 r
.70576 .49741 .70846 .50065 .71427 .49889 .71158 .49565 Metetra
.663 .741 .908 r
.71158 .49565 .71427 .49889 .72009 .49714 .71741 .49389 Metetra
.663 .741 .908 r
.71741 .49389 .72009 .49714 .72592 .49539 .72325 .49213 Metetra
.662 .742 .909 r
.72325 .49213 .72592 .49539 .73177 .49363 .7291 .49038 Metetra
.662 .742 .909 r
.7291 .49038 .73177 .49363 .73763 .49188 .73497 .48863 Metetra
.661 .742 .91 r
.73497 .48863 .73763 .49188 .7435 .49014 .74085 .48689 Metetra
.659 .742 .911 r
.74085 .48689 .7435 .49014 .74938 .48841 .74675 .48517 Metetra
.657 .743 .913 r
.74675 .48517 .74938 .48841 .75528 .48669 .75265 .48347 Metetra
.655 .743 .915 r
.75265 .48347 .75528 .48669 .7612 .485 .75858 .48181 Metetra
.651 .744 .918 r
.75858 .48181 .7612 .485 .76712 .48335 .76452 .48019 Metetra
.647 .746 .922 r
.76452 .48019 .76712 .48335 .77307 .48174 .77048 .47864 Metetra
.64 .747 .926 r
.77048 .47864 .77307 .48174 .77903 .48019 .77645 .47716 Metetra
.632 .749 .932 r
.77645 .47716 .77903 .48019 .78501 .47873 .78245 .47578 Metetra
.621 .752 .94 r
.78245 .47578 .78501 .47873 .79102 .47736 .78847 .47452 Metetra
.606 .754 .949 r
.78847 .47452 .79102 .47736 .79705 .47611 .79452 .4734 Metetra
.588 .757 .959 r
.79452 .4734 .79705 .47611 .8031 .47501 .8006 .47244 Metetra
.564 .759 .97 r
.8006 .47244 .8031 .47501 .80919 .47406 .80671 .47166 Metetra
.533 .76 .98 r
.80671 .47166 .80919 .47406 .8153 .4733 .81285 .47109 Metetra
.493 .758 .989 r
.81285 .47109 .8153 .4733 .82145 .47274 .81903 .47073 Metetra
.443 .751 .994 r
.81903 .47073 .82145 .47274 .82764 .4724 .82525 .47059 Metetra
.383 .738 .991 r
.82525 .47059 .82764 .4724 .83387 .47227 .83151 .47068 Metetra
.314 .718 .978 r
.83151 .47068 .83387 .47227 .84014 .47236 .83781 .47098 Metetra
.238 .689 .954 r
.83781 .47098 .84014 .47236 .84645 .47266 .84415 .47148 Metetra
.163 .654 .92 r
.84415 .47148 .84645 .47266 .8528 .47316 .85053 .47215 Metetra
.097 .618 .881 r
.85053 .47215 .8528 .47316 .85919 .47381 .85695 .47295 Metetra
.044 .587 .845 r
.85695 .47295 .85919 .47381 .86561 .4746 .8634 .47384 Metetra
.012 .567 .819 r
.8634 .47384 .86561 .4746 .87207 .47547 .86988 .47477 Metetra
.002 .562 .808 r
.86988 .47477 .87207 .47547 .87855 .47637 .87637 .47567 Metetra
.018 .575 .815 r
.87637 .47567 .87855 .47637 .88506 .47724 .88289 .47649 Metetra
.058 .604 .84 r
.88289 .47649 .88506 .47724 .89158 .47803 .88941 .47717 Metetra
.124 .648 .88 r
.88941 .47717 .89158 .47803 .89811 .47867 .89594 .47765 Metetra
.211 .699 .926 r
.89594 .47765 .89811 .47867 .90464 .47912 .90245 .47788 Metetra
.311 .747 .968 r
.90245 .47788 .90464 .47912 .91116 .47931 .90896 .4778 Metetra
.411 .784 .993 r
.90896 .4778 .91116 .47931 .91767 .4792 .91544 .47738 Metetra
.499 .803 .999 r
.91544 .47738 .91767 .4792 .92416 .47875 .9219 .4766 Metetra
.57 .807 .988 r
.9219 .4766 .92416 .47875 .93062 .47794 .92834 .47542 Metetra
.623 .799 .967 r
.92834 .47542 .93062 .47794 .93706 .47676 .93474 .47386 Metetra
.661 .785 .94 r
.93474 .47386 .93706 .47676 .94346 .47518 .9411 .47191 Metetra
.687 .769 .914 r
.9411 .47191 .94346 .47518 .94983 .47323 .94744 .46959 Metetra
.704 .753 .89 r
.94744 .46959 .94983 .47323 .95617 .47091 .95374 .46691 Metetra
.716 .738 .869 r
.95374 .46691 .95617 .47091 .96247 .46825 .96001 .46392 Metetra
.724 .725 .851 r
.96001 .46392 .96247 .46825 .96874 .46528 .96625 .46065 Metetra
.452 .502 .82 r
.38789 .63308 .39093 .6391 .39609 .64039 .39303 .63481 Metetra
.475 .531 .835 r
.39303 .63481 .39609 .64039 .40129 .64116 .39821 .63611 Metetra
.506 .569 .853 r
.39821 .63611 .40129 .64116 .40652 .64129 .40342 .63688 Metetra
.545 .617 .875 r
.40342 .63688 .40652 .64129 .41179 .6407 .40867 .63701 Metetra
.593 .675 .898 r
.40867 .63701 .41179 .6407 .4171 .63933 .41396 .63641 Metetra
.646 .74 .918 r
.41396 .63641 .4171 .63933 .42245 .63718 .41929 .63502 Metetra
.701 .808 .931 r
.41929 .63502 .42245 .63718 .42783 .63424 .42465 .63284 Metetra
.751 .87 .934 r
.42465 .63284 .42783 .63424 .43323 .63056 .43005 .62987 Metetra
.792 .922 .924 r
.43005 .62987 .43323 .63056 .43865 .62624 .43547 .62616 Metetra
.821 .958 .902 r
.43547 .62616 .43865 .62624 .44409 .62138 .4409 .6218 Metetra
.837 .98 .876 r
.4409 .6218 .44409 .62138 .44953 .6161 .44636 .6169 Metetra
.845 .991 .85 r
.44636 .6169 .44953 .6161 .45498 .61055 .45182 .61158 Metetra
.848 .996 .831 r
.45182 .61158 .45498 .61055 .46043 .60485 .45728 .606 Metetra
.849 .997 .821 r
.45728 .606 .46043 .60485 .46588 .59915 .46275 .60028 Metetra
.85 .997 .822 r
.46275 .60028 .46588 .59915 .47133 .59357 .46822 .59455 Metetra
.85 .995 .831 r
.46822 .59455 .47133 .59357 .47677 .58819 .47368 .58895 Metetra
.848 .991 .846 r
.47368 .58895 .47677 .58819 .48221 .58309 .47913 .58355 Metetra
.844 .984 .865 r
.47913 .58355 .48221 .58309 .48764 .57832 .48458 .57844 Metetra
.837 .971 .884 r
.48458 .57844 .48764 .57832 .49307 .57392 .49003 .57366 Metetra
.825 .954 .901 r
.49003 .57366 .49307 .57392 .49849 .56988 .49548 .56925 Metetra
.809 .933 .913 r
.49548 .56925 .49849 .56988 .50392 .5662 .50092 .56521 Metetra
.791 .908 .921 r
.50092 .56521 .50392 .5662 .50936 .56286 .50636 .56153 Metetra
.772 .883 .926 r
.50636 .56153 .50936 .56286 .51479 .55983 .51181 .55818 Metetra
.754 .859 .927 r
.51181 .55818 .51479 .55983 .52023 .55707 .51727 .55514 Metetra
.737 .837 .926 r
.51727 .55514 .52023 .55707 .52568 .55454 .52272 .55237 Metetra
.722 .817 .924 r
.52272 .55237 .52568 .55454 .53114 .5522 .52819 .54983 Metetra
.709 .8 .922 r
.52819 .54983 .53114 .5522 .53661 .55002 .53367 .54749 Metetra
.698 .786 .919 r
.53367 .54749 .53661 .55002 .54208 .54797 .53915 .5453 Metetra
.689 .775 .917 r
.53915 .5453 .54208 .54797 .54757 .54602 .54464 .54324 Metetra
.683 .767 .915 r
.54464 .54324 .54757 .54602 .55307 .54414 .55015 .54128 Metetra
.678 .76 .913 r
.55015 .54128 .55307 .54414 .55857 .54232 .55566 .53939 Metetra
.674 .755 .912 r
.55566 .53939 .55857 .54232 .56409 .54054 .56119 .53756 Metetra
.671 .751 .911 r
.56119 .53756 .56409 .54054 .56962 .53879 .56673 .53577 Metetra
.669 .748 .91 r
.56673 .53577 .56962 .53879 .57517 .53706 .57228 .534 Metetra
.667 .746 .909 r
.57228 .534 .57517 .53706 .58072 .53534 .57784 .53226 Metetra
.666 .745 .909 r
.57784 .53226 .58072 .53534 .58628 .53363 .58341 .53053 Metetra
.665 .743 .909 r
.58341 .53053 .58628 .53363 .59186 .53192 .58899 .52882 Metetra
.665 .743 .908 r
.58899 .52882 .59186 .53192 .59744 .53022 .59458 .5271 Metetra
.664 .742 .908 r
.59458 .5271 .59744 .53022 .60304 .52852 .60019 .52539 Metetra
.664 .742 .908 r
.60019 .52539 .60304 .52852 .60865 .52682 .6058 .52368 Metetra
.664 .742 .908 r
.6058 .52368 .60865 .52682 .61427 .52511 .61143 .52196 Metetra
.664 .742 .908 r
.61143 .52196 .61427 .52511 .6199 .5234 .61707 .52025 Metetra
.664 .741 .908 r
.61707 .52025 .6199 .5234 .62554 .52169 .62272 .51853 Metetra
.664 .741 .908 r
.62272 .51853 .62554 .52169 .6312 .51998 .62838 .51681 Metetra
.664 .741 .908 r
.62838 .51681 .6312 .51998 .63686 .51826 .63406 .51509 Metetra
.664 .741 .908 r
.63406 .51509 .63686 .51826 .64254 .51654 .63974 .51336 Metetra
.664 .741 .908 r
.63974 .51336 .64254 .51654 .64823 .51482 .64544 .51163 Metetra
.664 .741 .908 r
.64544 .51163 .64823 .51482 .65393 .5131 .65115 .5099 Metetra
.664 .741 .908 r
.65115 .5099 .65393 .5131 .65964 .51137 .65687 .50816 Metetra
.664 .741 .908 r
.65687 .50816 .65964 .51137 .66537 .50963 .6626 .50642 Metetra
.664 .741 .908 r
.6626 .50642 .66537 .50963 .6711 .5079 .66834 .50468 Metetra
.664 .741 .908 r
.66834 .50468 .6711 .5079 .67685 .50616 .6741 .50293 Metetra
.664 .741 .908 r
.6741 .50293 .67685 .50616 .68261 .50441 .67986 .50118 Metetra
.663 .741 .908 r
.67986 .50118 .68261 .50441 .68838 .50266 .68564 .49943 Metetra
.663 .741 .908 r
.68564 .49943 .68838 .50266 .69416 .50091 .69143 .49767 Metetra
.663 .741 .908 r
.69143 .49767 .69416 .50091 .69995 .49916 .69723 .49592 Metetra
.663 .741 .908 r
.69723 .49592 .69995 .49916 .70576 .49741 .70305 .49415 Metetra
.663 .741 .908 r
.70305 .49415 .70576 .49741 .71158 .49565 .70887 .49239 Metetra
.663 .741 .908 r
.70887 .49239 .71158 .49565 .71741 .49389 .71471 .49063 Metetra
.662 .742 .909 r
.71471 .49063 .71741 .49389 .72325 .49213 .72056 .48887 Metetra
.662 .742 .909 r
.72056 .48887 .72325 .49213 .7291 .49038 .72643 .48712 Metetra
.661 .742 .91 r
.72643 .48712 .7291 .49038 .73497 .48863 .7323 .48538 Metetra
.66 .742 .911 r
.7323 .48538 .73497 .48863 .74085 .48689 .73819 .48365 Metetra
.658 .743 .913 r
.73819 .48365 .74085 .48689 .74675 .48517 .7441 .48195 Metetra
.655 .743 .915 r
.7441 .48195 .74675 .48517 .75265 .48347 .75002 .48028 Metetra
.652 .744 .917 r
.75002 .48028 .75265 .48347 .75858 .48181 .75595 .47865 Metetra
.647 .745 .921 r
.75595 .47865 .75858 .48181 .76452 .48019 .76191 .47708 Metetra
.641 .747 .926 r
.76191 .47708 .76452 .48019 .77048 .47864 .76788 .47559 Metetra
.633 .749 .932 r
.76788 .47559 .77048 .47864 .77645 .47716 .77387 .4742 Metetra
.622 .751 .939 r
.77387 .4742 .77645 .47716 .78245 .47578 .77989 .47292 Metetra
.608 .754 .948 r
.77989 .47292 .78245 .47578 .78847 .47452 .78593 .47178 Metetra
.589 .757 .958 r
.78593 .47178 .78847 .47452 .79452 .4734 .792 .47081 Metetra
.565 .759 .969 r
.792 .47081 .79452 .4734 .8006 .47244 .7981 .47002 Metetra
.534 .759 .98 r
.7981 .47002 .8006 .47244 .80671 .47166 .80424 .46943 Metetra
.495 .758 .989 r
.80424 .46943 .80671 .47166 .81285 .47109 .81041 .46906 Metetra
.445 .751 .994 r
.81041 .46906 .81285 .47109 .81903 .47073 .81662 .46891 Metetra
.384 .739 .991 r
.81662 .46891 .81903 .47073 .82525 .47059 .82287 .46899 Metetra
.314 .717 .978 r
.82287 .46899 .82525 .47059 .83151 .47068 .82916 .46929 Metetra
.237 .688 .953 r
.82916 .46929 .83151 .47068 .83781 .47098 .83549 .4698 Metetra
.159 .651 .918 r
.83549 .4698 .83781 .47098 .84415 .47148 .84186 .47048 Metetra
.09 .614 .877 r
.84186 .47048 .84415 .47148 .85053 .47215 .84827 .47129 Metetra
.035 .581 .839 r
.84827 .47129 .85053 .47215 .85695 .47295 .85471 .47221 Metetra
.001 .559 .81 r
.85471 .47221 .85695 .47295 .8634 .47384 .86118 .47316 Metetra
0 .553 .798 r
.86118 .47316 .8634 .47384 .86988 .47477 .86767 .4741 Metetra
.003 .564 .804 r
.86767 .4741 .86988 .47477 .87637 .47567 .87418 .47495 Metetra
.042 .593 .829 r
.87418 .47495 .87637 .47567 .88289 .47649 .8807 .47567 Metetra
.108 .638 .87 r
.8807 .47567 .88289 .47649 .88941 .47717 .88722 .47619 Metetra
.196 .691 .919 r
.88722 .47619 .88941 .47717 .89594 .47765 .89373 .47645 Metetra
.298 .742 .963 r
.89373 .47645 .89594 .47765 .90245 .47788 .90023 .4764 Metetra
.401 .781 .992 r
.90023 .4764 .90245 .47788 .90896 .4778 .90671 .47601 Metetra
.493 .803 1 r
.90671 .47601 .90896 .4778 .91544 .47738 .91317 .47525 Metetra
.567 .808 .989 r
.91317 .47525 .91544 .47738 .9219 .4766 .9196 .47409 Metetra
.622 .8 .968 r
.9196 .47409 .9219 .4766 .92834 .47542 .926 .47253 Metetra
.66 .786 .941 r
.926 .47253 .92834 .47542 .93474 .47386 .93236 .47059 Metetra
.687 .769 .914 r
.93236 .47059 .93474 .47386 .9411 .47191 .93869 .46826 Metetra
.705 .753 .89 r
.93869 .46826 .9411 .47191 .94744 .46959 .94499 .46557 Metetra
.717 .738 .868 r
.94499 .46557 .94744 .46959 .95374 .46691 .95126 .46256 Metetra
.724 .724 .85 r
.95126 .46256 .95374 .46691 .96001 .46392 .9575 .45927 Metetra
.729 .713 .835 r
.9575 .45927 .96001 .46392 .96625 .46065 .96371 .45573 Metetra
.436 .482 .809 r
.38486 .62671 .38789 .63308 .39303 .63481 .38998 .62875 Metetra
.451 .501 .819 r
.38998 .62875 .39303 .63481 .39821 .63611 .39514 .63049 Metetra
.474 .53 .834 r
.39514 .63049 .39821 .63611 .40342 .63688 .40033 .6318 Metetra
.506 .568 .853 r
.40033 .6318 .40342 .63688 .40867 .63701 .40557 .63258 Metetra
.545 .617 .875 r
.40557 .63258 .40867 .63701 .41396 .63641 .41084 .6327 Metetra
.593 .675 .897 r
.41084 .6327 .41396 .63641 .41929 .63502 .41615 .63208 Metetra
.647 .741 .918 r
.41615 .63208 .41929 .63502 .42465 .63284 .42149 .63068 Metetra
.702 .809 .931 r
.42149 .63068 .42465 .63284 .43005 .62987 .42687 .62847 Metetra
.753 .871 .934 r
.42687 .62847 .43005 .62987 .43547 .62616 .43228 .62547 Metetra
.794 .923 .923 r
.43228 .62547 .43547 .62616 .4409 .6218 .43772 .62172 Metetra
.822 .959 .901 r
.43772 .62172 .4409 .6218 .44636 .6169 .44317 .61733 Metetra
.838 .981 .874 r
.44317 .61733 .44636 .6169 .45182 .61158 .44864 .61239 Metetra
.846 .991 .849 r
.44864 .61239 .45182 .61158 .45728 .606 .45412 .60704 Metetra
.848 .996 .83 r
.45412 .60704 .45728 .606 .46275 .60028 .4596 .60142 Metetra
.849 .997 .82 r
.4596 .60142 .46275 .60028 .46822 .59455 .46508 .59567 Metetra
.85 .997 .821 r
.46508 .59567 .46822 .59455 .47368 .58895 .47056 .58993 Metetra
.85 .995 .83 r
.47056 .58993 .47368 .58895 .47913 .58355 .47604 .5843 Metetra
.848 .991 .846 r
.47604 .5843 .47913 .58355 .48458 .57844 .48151 .57889 Metetra
.844 .984 .865 r
.48151 .57889 .48458 .57844 .49003 .57366 .48697 .57377 Metetra
.836 .971 .884 r
.48697 .57377 .49003 .57366 .49548 .56925 .49244 .56899 Metetra
.824 .954 .901 r
.49244 .56899 .49548 .56925 .50092 .56521 .4979 .56456 Metetra
.809 .932 .913 r
.4979 .56456 .50092 .56521 .50636 .56153 .50336 .56052 Metetra
.791 .908 .922 r
.50336 .56052 .50636 .56153 .51181 .55818 .50882 .55683 Metetra
.772 .883 .926 r
.50882 .55683 .51181 .55818 .51727 .55514 .51428 .55347 Metetra
.754 .859 .927 r
.51428 .55347 .51727 .55514 .52272 .55237 .51975 .55043 Metetra
.737 .837 .926 r
.51975 .55043 .52272 .55237 .52819 .54983 .52523 .54765 Metetra
.721 .817 .924 r
.52523 .54765 .52819 .54983 .53367 .54749 .53071 .5451 Metetra
.709 .8 .922 r
.53071 .5451 .53367 .54749 .53915 .5453 .53621 .54275 Metetra
.698 .786 .919 r
.53621 .54275 .53915 .5453 .54464 .54324 .54171 .54055 Metetra
.689 .775 .917 r
.54171 .54055 .54464 .54324 .55015 .54128 .54722 .53848 Metetra
.683 .767 .915 r
.54722 .53848 .55015 .54128 .55566 .53939 .55274 .53651 Metetra
.678 .76 .913 r
.55274 .53651 .55566 .53939 .56119 .53756 .55828 .53461 Metetra
.674 .755 .912 r
.55828 .53461 .56119 .53756 .56673 .53577 .56382 .53277 Metetra
.671 .751 .911 r
.56382 .53277 .56673 .53577 .57228 .534 .56938 .53097 Metetra
.669 .748 .91 r
.56938 .53097 .57228 .534 .57784 .53226 .57494 .52919 Metetra
.667 .746 .909 r
.57494 .52919 .57784 .53226 .58341 .53053 .58052 .52744 Metetra
.666 .745 .909 r
.58052 .52744 .58341 .53053 .58899 .52882 .58611 .5257 Metetra
.665 .744 .909 r
.58611 .5257 .58899 .52882 .59458 .5271 .59171 .52397 Metetra
.665 .743 .908 r
.59171 .52397 .59458 .5271 .60019 .52539 .59732 .52225 Metetra
.664 .742 .908 r
.59732 .52225 .60019 .52539 .6058 .52368 .60295 .52053 Metetra
.664 .742 .908 r
.60295 .52053 .6058 .52368 .61143 .52196 .60858 .51881 Metetra
.664 .742 .908 r
.60858 .51881 .61143 .52196 .61707 .52025 .61423 .51708 Metetra
.664 .742 .908 r
.61423 .51708 .61707 .52025 .62272 .51853 .61989 .51536 Metetra
.664 .741 .908 r
.61989 .51536 .62272 .51853 .62838 .51681 .62556 .51363 Metetra
.664 .741 .908 r
.62556 .51363 .62838 .51681 .63406 .51509 .63124 .5119 Metetra
.664 .741 .908 r
.63124 .5119 .63406 .51509 .63974 .51336 .63693 .51017 Metetra
.664 .741 .908 r
.63693 .51017 .63974 .51336 .64544 .51163 .64264 .50843 Metetra
.664 .741 .908 r
.64264 .50843 .64544 .51163 .65115 .5099 .64835 .50669 Metetra
.664 .741 .908 r
.64835 .50669 .65115 .5099 .65687 .50816 .65408 .50495 Metetra
.664 .741 .908 r
.65408 .50495 .65687 .50816 .6626 .50642 .65982 .5032 Metetra
.664 .741 .908 r
.65982 .5032 .6626 .50642 .66834 .50468 .66557 .50145 Metetra
.664 .741 .908 r
.66557 .50145 .66834 .50468 .6741 .50293 .67133 .4997 Metetra
.663 .741 .908 r
.67133 .4997 .6741 .50293 .67986 .50118 .67711 .49794 Metetra
.663 .741 .908 r
.67711 .49794 .67986 .50118 .68564 .49943 .6829 .49618 Metetra
.663 .741 .908 r
.6829 .49618 .68564 .49943 .69143 .49767 .68869 .49442 Metetra
.663 .741 .908 r
.68869 .49442 .69143 .49767 .69723 .49592 .6945 .49266 Metetra
.663 .741 .908 r
.6945 .49266 .69723 .49592 .70305 .49415 .70033 .49089 Metetra
.663 .741 .908 r
.70033 .49089 .70305 .49415 .70887 .49239 .70616 .48913 Metetra
.662 .742 .909 r
.70616 .48913 .70887 .49239 .71471 .49063 .71201 .48737 Metetra
.662 .742 .909 r
.71201 .48737 .71471 .49063 .72056 .48887 .71787 .48561 Metetra
.661 .742 .91 r
.71787 .48561 .72056 .48887 .72643 .48712 .72374 .48386 Metetra
.66 .742 .911 r
.72374 .48386 .72643 .48712 .7323 .48538 .72963 .48213 Metetra
.658 .743 .912 r
.72963 .48213 .7323 .48538 .73819 .48365 .73553 .48042 Metetra
.656 .743 .914 r
.73553 .48042 .73819 .48365 .7441 .48195 .74144 .47874 Metetra
.652 .744 .917 r
.74144 .47874 .7441 .48195 .75002 .48028 .74737 .4771 Metetra
.648 .745 .921 r
.74737 .4771 .75002 .48028 .75595 .47865 .75332 .47552 Metetra
.642 .747 .925 r
.75332 .47552 .75595 .47865 .76191 .47708 .75929 .47402 Metetra
.633 .749 .931 r
.75929 .47402 .76191 .47708 .76788 .47559 .76527 .47262 Metetra
.623 .751 .938 r
.76527 .47262 .76788 .47559 .77387 .4742 .77129 .47132 Metetra
.609 .754 .947 r
.77129 .47132 .77387 .4742 .77989 .47292 .77732 .47017 Metetra
.591 .756 .957 r
.77732 .47017 .77989 .47292 .78593 .47178 .78338 .46918 Metetra
.567 .759 .968 r
.78338 .46918 .78593 .47178 .792 .47081 .78948 .46837 Metetra
.536 .759 .979 r
.78948 .46837 .792 .47081 .7981 .47002 .79561 .46777 Metetra
.497 .758 .988 r
.79561 .46777 .7981 .47002 .80424 .46943 .80177 .46739 Metetra
.447 .752 .994 r
.80177 .46739 .80424 .46943 .81041 .46906 .80797 .46723 Metetra
.386 .739 .991 r
.80797 .46723 .81041 .46906 .81662 .46891 .81421 .46731 Metetra
.314 .717 .978 r
.81421 .46731 .81662 .46891 .82287 .46899 .82049 .46761 Metetra
.235 .687 .953 r
.82049 .46761 .82287 .46899 .82916 .46929 .82682 .46811 Metetra
.155 .649 .916 r
.82682 .46811 .82916 .46929 .83549 .4698 .83318 .4688 Metetra
.083 .61 .873 r
.83318 .4688 .83549 .4698 .84186 .47048 .83958 .46964 Metetra
.026 .575 .833 r
.83958 .46964 .84186 .47048 .84827 .47129 .84601 .47057 Metetra
0 .551 .802 r
.84601 .47057 .84827 .47129 .85471 .47221 .85247 .47155 Metetra
0 .543 .787 r
.85247 .47155 .85471 .47221 .86118 .47316 .85896 .47252 Metetra
0 .554 .792 r
.85896 .47252 .86118 .47316 .86767 .4741 .86546 .47341 Metetra
.026 .582 .818 r
.86546 .47341 .86767 .4741 .87418 .47495 .87197 .47416 Metetra
.092 .628 .86 r
.87197 .47416 .87418 .47495 .8807 .47567 .87848 .47472 Metetra
.18 .682 .91 r
.87848 .47472 .8807 .47567 .88722 .47619 .88499 .47501 Metetra
.285 .736 .958 r
.88499 .47501 .88722 .47619 .89373 .47645 .89149 .475 Metetra
.391 .779 .99 r
.89149 .475 .89373 .47645 .90023 .4764 .89796 .47464 Metetra
.487 .802 1 r
.89796 .47464 .90023 .4764 .90671 .47601 .90442 .4739 Metetra
.564 .808 .99 r
.90442 .4739 .90671 .47601 .91317 .47525 .91085 .47275 Metetra
.62 .801 .969 r
.91085 .47275 .91317 .47525 .9196 .47409 .91724 .47121 Metetra
.66 .787 .942 r
.91724 .47121 .9196 .47409 .926 .47253 .9236 .46926 Metetra
.687 .77 .914 r
.9236 .46926 .926 .47253 .93236 .47059 .92993 .46693 Metetra
.705 .753 .889 r
.92993 .46693 .93236 .47059 .93869 .46826 .93623 .46423 Metetra
.717 .738 .867 r
.93623 .46423 .93869 .46826 .94499 .46557 .94249 .4612 Metetra
.725 .724 .849 r
.94249 .4612 .94499 .46557 .95126 .46256 .94873 .45788 Metetra
.73 .712 .834 r
.94873 .45788 .95126 .46256 .9575 .45927 .95494 .45431 Metetra
.733 .703 .822 r
.95494 .45431 .9575 .45927 .96371 .45573 .96114 .45054 Metetra
.427 .469 .801 r
.38183 .6201 .38486 .62671 .38998 .62875 .38694 .62233 Metetra
.435 .48 .808 r
.38694 .62233 .38998 .62875 .39514 .63049 .39209 .62438 Metetra
.45 .5 .818 r
.39209 .62438 .39514 .63049 .40033 .6318 .39726 .62614 Metetra
.474 .528 .833 r
.39726 .62614 .40033 .6318 .40557 .63258 .40247 .62746 Metetra
.505 .567 .852 r
.40247 .62746 .40557 .63258 .41084 .6327 .40772 .62824 Metetra
.546 .616 .874 r
.40772 .62824 .41084 .6327 .41615 .63208 .41301 .62836 Metetra
.594 .675 .897 r
.41301 .62836 .41615 .63208 .42149 .63068 .41834 .62773 Metetra
.648 .741 .918 r
.41834 .62773 .42149 .63068 .42687 .62847 .4237 .62631 Metetra
.703 .809 .931 r
.4237 .62631 .42687 .62847 .43228 .62547 .4291 .62407 Metetra
.754 .872 .933 r
.4291 .62407 .43228 .62547 .43772 .62172 .43453 .62103 Metetra
.795 .924 .922 r
.43453 .62103 .43772 .62172 .44317 .61733 .43998 .61726 Metetra
.823 .96 .9 r
.43998 .61726 .44317 .61733 .44864 .61239 .44545 .61282 Metetra
.839 .981 .873 r
.44545 .61282 .44864 .61239 .45412 .60704 .45094 .60785 Metetra
.846 .992 .848 r
.45094 .60785 .45412 .60704 .4596 .60142 .45643 .60247 Metetra
.848 .996 .829 r
.45643 .60247 .4596 .60142 .46508 .59567 .46193 .59682 Metetra
.849 .997 .82 r
.46193 .59682 .46508 .59567 .47056 .58993 .46743 .59105 Metetra
.85 .997 .82 r
.46743 .59105 .47056 .58993 .47604 .5843 .47292 .58528 Metetra
.85 .995 .83 r
.47292 .58528 .47604 .5843 .48151 .57889 .47841 .57964 Metetra
.848 .992 .846 r
.47841 .57964 .48151 .57889 .48697 .57377 .4839 .57421 Metetra
.844 .984 .865 r
.4839 .57421 .48697 .57377 .49244 .56899 .48938 .56908 Metetra
.836 .971 .884 r
.48938 .56908 .49244 .56899 .4979 .56456 .49486 .56428 Metetra
.824 .954 .901 r
.49486 .56428 .4979 .56456 .50336 .56052 .50033 .55986 Metetra
.809 .932 .914 r
.50033 .55986 .50336 .56052 .50882 .55683 .50581 .5558 Metetra
.791 .908 .922 r
.50581 .5558 .50882 .55683 .51428 .55347 .51129 .5521 Metetra
.772 .883 .926 r
.51129 .5521 .51428 .55347 .51975 .55043 .51677 .54874 Metetra
.753 .859 .927 r
.51677 .54874 .51975 .55043 .52523 .54765 .52226 .54569 Metetra
.736 .836 .926 r
.52226 .54569 .52523 .54765 .53071 .5451 .52775 .5429 Metetra
.721 .817 .924 r
.52775 .5429 .53071 .5451 .53621 .54275 .53325 .54035 Metetra
.709 .8 .922 r
.53325 .54035 .53621 .54275 .54171 .54055 .53876 .53798 Metetra
.698 .787 .919 r
.53876 .53798 .54171 .54055 .54722 .53848 .54428 .53578 Metetra
.689 .775 .917 r
.54428 .53578 .54722 .53848 .55274 .53651 .54981 .53369 Metetra
.683 .767 .915 r
.54981 .53369 .55274 .53651 .55828 .53461 .55535 .53171 Metetra
.678 .76 .913 r
.55535 .53171 .55828 .53461 .56382 .53277 .5609 .5298 Metetra
.674 .755 .912 r
.5609 .5298 .56382 .53277 .56938 .53097 .56647 .52795 Metetra
.671 .751 .911 r
.56647 .52795 .56938 .53097 .57494 .52919 .57204 .52614 Metetra
.669 .748 .91 r
.57204 .52614 .57494 .52919 .58052 .52744 .57763 .52436 Metetra
.667 .746 .909 r
.57763 .52436 .58052 .52744 .58611 .5257 .58322 .52259 Metetra
.666 .745 .909 r
.58322 .52259 .58611 .5257 .59171 .52397 .58883 .52085 Metetra
.665 .744 .909 r
.58883 .52085 .59171 .52397 .59732 .52225 .59445 .51911 Metetra
.665 .743 .908 r
.59445 .51911 .59732 .52225 .60295 .52053 .60008 .51737 Metetra
.664 .742 .908 r
.60008 .51737 .60295 .52053 .60858 .51881 .60573 .51564 Metetra
.664 .742 .908 r
.60573 .51564 .60858 .51881 .61423 .51708 .61138 .51391 Metetra
.664 .742 .908 r
.61138 .51391 .61423 .51708 .61989 .51536 .61705 .51217 Metetra
.664 .742 .908 r
.61705 .51217 .61989 .51536 .62556 .51363 .62272 .51044 Metetra
.664 .741 .908 r
.62272 .51044 .62556 .51363 .63124 .5119 .62841 .5087 Metetra
.664 .741 .908 r
.62841 .5087 .63124 .5119 .63693 .51017 .63411 .50696 Metetra
.664 .741 .908 r
.63411 .50696 .63693 .51017 .64264 .50843 .63982 .50522 Metetra
.664 .741 .908 r
.63982 .50522 .64264 .50843 .64835 .50669 .64555 .50347 Metetra
.664 .741 .908 r
.64555 .50347 .64835 .50669 .65408 .50495 .65128 .50172 Metetra
.664 .741 .908 r
.65128 .50172 .65408 .50495 .65982 .5032 .65703 .49997 Metetra
.664 .741 .908 r
.65703 .49997 .65982 .5032 .66557 .50145 .66279 .49821 Metetra
.663 .741 .908 r
.66279 .49821 .66557 .50145 .67133 .4997 .66856 .49645 Metetra
.663 .741 .908 r
.66856 .49645 .67133 .4997 .67711 .49794 .67434 .49469 Metetra
.663 .741 .908 r
.67434 .49469 .67711 .49794 .6829 .49618 .68014 .49293 Metetra
.663 .741 .908 r
.68014 .49293 .6829 .49618 .68869 .49442 .68595 .49116 Metetra
.663 .741 .908 r
.68595 .49116 .68869 .49442 .6945 .49266 .69176 .48939 Metetra
.663 .741 .908 r
.69176 .48939 .6945 .49266 .70033 .49089 .6976 .48762 Metetra
.663 .742 .909 r
.6976 .48762 .70033 .49089 .70616 .48913 .70344 .48585 Metetra
.662 .742 .909 r
.70344 .48585 .70616 .48913 .71201 .48737 .70929 .48409 Metetra
.661 .742 .91 r
.70929 .48409 .71201 .48737 .71787 .48561 .71516 .48234 Metetra
.66 .742 .911 r
.71516 .48234 .71787 .48561 .72374 .48386 .72105 .4806 Metetra
.658 .743 .912 r
.72105 .4806 .72374 .48386 .72963 .48213 .72694 .47888 Metetra
.656 .743 .914 r
.72694 .47888 .72963 .48213 .73553 .48042 .73285 .4772 Metetra
.653 .744 .917 r
.73285 .4772 .73553 .48042 .74144 .47874 .73878 .47555 Metetra
.648 .745 .92 r
.73878 .47555 .74144 .47874 .74737 .4771 .74472 .47397 Metetra
.642 .747 .925 r
.74472 .47397 .74737 .4771 .75332 .47552 .75068 .47245 Metetra
.634 .749 .931 r
.75068 .47245 .75332 .47552 .75929 .47402 .75666 .47103 Metetra
.624 .751 .938 r
.75666 .47103 .75929 .47402 .76527 .47262 .76267 .46973 Metetra
.61 .753 .946 r
.76267 .46973 .76527 .47262 .77129 .47132 .7687 .46856 Metetra
.592 .756 .956 r
.7687 .46856 .77129 .47132 .77732 .47017 .77475 .46755 Metetra
.569 .758 .967 r
.77475 .46755 .77732 .47017 .78338 .46918 .78084 .46673 Metetra
.538 .759 .978 r
.78084 .46673 .78338 .46918 .78948 .46837 .78696 .46611 Metetra
.499 .758 .988 r
.78696 .46611 .78948 .46837 .79561 .46777 .79312 .46571 Metetra
.449 .752 .993 r
.79312 .46571 .79561 .46777 .80177 .46739 .79931 .46555 Metetra
.387 .739 .992 r
.79931 .46555 .80177 .46739 .80797 .46723 .80554 .46562 Metetra
.314 .717 .978 r
.80554 .46562 .80797 .46723 .81421 .46731 .81181 .46591 Metetra
.233 .686 .952 r
.81181 .46591 .81421 .46731 .82049 .46761 .81813 .46642 Metetra
.152 .647 .914 r
.81813 .46642 .82049 .46761 .82682 .46811 .82448 .46712 Metetra
.077 .606 .869 r
.82448 .46712 .82682 .46811 .83318 .4688 .83087 .46797 Metetra
.017 .569 .826 r
.83087 .46797 .83318 .4688 .83958 .46964 .83729 .46893 Metetra
0 .543 .794 r
.83729 .46893 .83958 .46964 .84601 .47057 .84374 .46993 Metetra
0 .534 .777 r
.84374 .46993 .84601 .47057 .85247 .47155 .85022 .47093 Metetra
0 .543 .781 r
.85022 .47093 .85247 .47155 .85896 .47252 .85672 .47186 Metetra
.01 .571 .806 r
.85672 .47186 .85896 .47252 .86546 .47341 .86322 .47265 Metetra
.075 .617 .848 r
.86322 .47265 .86546 .47341 .87197 .47416 .86973 .47324 Metetra
.165 .674 .901 r
.86973 .47324 .87197 .47416 .87848 .47472 .87623 .47357 Metetra
.271 .73 .952 r
.87623 .47357 .87848 .47472 .88499 .47501 .88272 .47359 Metetra
.381 .776 .987 r
.88272 .47359 .88499 .47501 .89149 .475 .8892 .47326 Metetra
.48 .802 1 r
.8892 .47326 .89149 .475 .89796 .47464 .89565 .47254 Metetra
.56 .809 .991 r
.89565 .47254 .89796 .47464 .90442 .4739 .90207 .47142 Metetra
.619 .802 .97 r
.90207 .47142 .90442 .4739 .91085 .47275 .90847 .46988 Metetra
.659 .787 .943 r
.90847 .46988 .91085 .47275 .91724 .47121 .91483 .46793 Metetra
.687 .77 .915 r
.91483 .46793 .91724 .47121 .9236 .46926 .92115 .46559 Metetra
.706 .753 .889 r
.92115 .46559 .9236 .46926 .92993 .46693 .92745 .46289 Metetra
.718 .737 .867 r
.92745 .46289 .92993 .46693 .93623 .46423 .93371 .45984 Metetra
.726 .723 .848 r
.93371 .45984 .93623 .46423 .94249 .4612 .93995 .4565 Metetra
.731 .712 .833 r
.93995 .4565 .94249 .4612 .94873 .45788 .94616 .4529 Metetra
.734 .702 .821 r
.94616 .4529 .94873 .45788 .95494 .45431 .95235 .44909 Metetra
.735 .694 .811 r
.95235 .44909 .95494 .45431 .96114 .45054 .95853 .44512 Metetra
.423 .464 .798 r
.3788 .61337 .38183 .6201 .38694 .62233 .38391 .61567 Metetra
.426 .468 .8 r
.38391 .61567 .38694 .62233 .39209 .62438 .38904 .61792 Metetra
.434 .479 .807 r
.38904 .61792 .39209 .62438 .39726 .62614 .3942 .61999 Metetra
.45 .499 .818 r
.3942 .61999 .39726 .62614 .40247 .62746 .3994 .62176 Metetra
.473 .528 .833 r
.3994 .62176 .40247 .62746 .40772 .62824 .40463 .6231 Metetra
.505 .567 .852 r
.40463 .6231 .40772 .62824 .41301 .62836 .40989 .62387 Metetra
.546 .616 .874 r
.40989 .62387 .41301 .62836 .41834 .62773 .4152 .62398 Metetra
.594 .675 .897 r
.4152 .62398 .41834 .62773 .4237 .62631 .42055 .62334 Metetra
.649 .742 .918 r
.42055 .62334 .4237 .62631 .4291 .62407 .42593 .6219 Metetra
.704 .81 .931 r
.42593 .6219 .4291 .62407 .43453 .62103 .43135 .61964 Metetra
.755 .874 .933 r
.43135 .61964 .43453 .62103 .43998 .61726 .43679 .61657 Metetra
.796 .925 .922 r
.43679 .61657 .43998 .61726 .44545 .61282 .44226 .61276 Metetra
.824 .961 .899 r
.44226 .61276 .44545 .61282 .45094 .60785 .44775 .60829 Metetra
.839 .982 .872 r
.44775 .60829 .45094 .60785 .45643 .60247 .45325 .60328 Metetra
.846 .992 .847 r
.45325 .60328 .45643 .60247 .46193 .59682 .45876 .59787 Metetra
.849 .996 .828 r
.45876 .59787 .46193 .59682 .46743 .59105 .46427 .59219 Metetra
.849 .997 .819 r
.46427 .59219 .46743 .59105 .47292 .58528 .46978 .58639 Metetra
.85 .997 .82 r
.46978 .58639 .47292 .58528 .47841 .57964 .47529 .5806 Metetra
.85 .996 .83 r
.47529 .5806 .47841 .57964 .4839 .57421 .4808 .57494 Metetra
.848 .992 .846 r
.4808 .57494 .4839 .57421 .48938 .56908 .4863 .5695 Metetra
.844 .984 .865 r
.4863 .5695 .48938 .56908 .49486 .56428 .4918 .56436 Metetra
.836 .971 .885 r
.4918 .56436 .49486 .56428 .50033 .55986 .49729 .55956 Metetra
.824 .954 .901 r
.49729 .55956 .50033 .55986 .50581 .5558 .50278 .55512 Metetra
.808 .932 .914 r
.50278 .55512 .50581 .5558 .51129 .5521 .50828 .55106 Metetra
.79 .908 .922 r
.50828 .55106 .51129 .5521 .51677 .54874 .51377 .54736 Metetra
.772 .883 .926 r
.51377 .54736 .51677 .54874 .52226 .54569 .51927 .54399 Metetra
.753 .859 .927 r
.51927 .54399 .52226 .54569 .52775 .5429 .52477 .54093 Metetra
.736 .836 .926 r
.52477 .54093 .52775 .5429 .53325 .54035 .53028 .53813 Metetra
.721 .817 .924 r
.53028 .53813 .53325 .54035 .53876 .53798 .5358 .53557 Metetra
.709 .8 .922 r
.5358 .53557 .53876 .53798 .54428 .53578 .54133 .53319 Metetra
.698 .787 .919 r
.54133 .53319 .54428 .53578 .54981 .53369 .54687 .53098 Metetra
.69 .776 .917 r
.54687 .53098 .54981 .53369 .55535 .53171 .55242 .52888 Metetra
.683 .767 .915 r
.55242 .52888 .55535 .53171 .5609 .5298 .55797 .52689 Metetra
.678 .76 .913 r
.55797 .52689 .5609 .5298 .56647 .52795 .56354 .52497 Metetra
.674 .755 .912 r
.56354 .52497 .56647 .52795 .57204 .52614 .56913 .52311 Metetra
.671 .751 .911 r
.56913 .52311 .57204 .52614 .57763 .52436 .57472 .52128 Metetra
.669 .748 .91 r
.57472 .52128 .57763 .52436 .58322 .52259 .58032 .51949 Metetra
.667 .746 .909 r
.58032 .51949 .58322 .52259 .58883 .52085 .58594 .51772 Metetra
.666 .745 .909 r
.58594 .51772 .58883 .52085 .59445 .51911 .59157 .51596 Metetra
.665 .744 .909 r
.59157 .51596 .59445 .51911 .60008 .51737 .59721 .51421 Metetra
.665 .743 .908 r
.59721 .51421 .60008 .51737 .60573 .51564 .60286 .51246 Metetra
.664 .742 .908 r
.60286 .51246 .60573 .51564 .61138 .51391 .60852 .51072 Metetra
.664 .742 .908 r
.60852 .51072 .61138 .51391 .61705 .51217 .61419 .50898 Metetra
.664 .742 .908 r
.61419 .50898 .61705 .51217 .62272 .51044 .61988 .50724 Metetra
.664 .742 .908 r
.61988 .50724 .62272 .51044 .62841 .5087 .62557 .50549 Metetra
.664 .742 .908 r
.62557 .50549 .62841 .5087 .63411 .50696 .63128 .50374 Metetra
.664 .741 .908 r
.63128 .50374 .63411 .50696 .63982 .50522 .637 .50199 Metetra
.664 .741 .908 r
.637 .50199 .63982 .50522 .64555 .50347 .64273 .50024 Metetra
.664 .741 .908 r
.64273 .50024 .64555 .50347 .65128 .50172 .64848 .49848 Metetra
.664 .741 .908 r
.64848 .49848 .65128 .50172 .65703 .49997 .65423 .49673 Metetra
.664 .741 .908 r
.65423 .49673 .65703 .49997 .66279 .49821 .66 .49496 Metetra
.663 .741 .908 r
.66 .49496 .66279 .49821 .66856 .49645 .66578 .4932 Metetra
.663 .741 .908 r
.66578 .4932 .66856 .49645 .67434 .49469 .67157 .49143 Metetra
.663 .741 .908 r
.67157 .49143 .67434 .49469 .68014 .49293 .67737 .48966 Metetra
.663 .741 .908 r
.67737 .48966 .68014 .49293 .68595 .49116 .68319 .48788 Metetra
.663 .741 .908 r
.68319 .48788 .68595 .49116 .69176 .48939 .68901 .48611 Metetra
.663 .741 .909 r
.68901 .48611 .69176 .48939 .6976 .48762 .69485 .48434 Metetra
.662 .742 .909 r
.69485 .48434 .6976 .48762 .70344 .48585 .70071 .48257 Metetra
.661 .742 .91 r
.70071 .48257 .70344 .48585 .70929 .48409 .70657 .48082 Metetra
.66 .742 .911 r
.70657 .48082 .70929 .48409 .71516 .48234 .71245 .47907 Metetra
.658 .742 .912 r
.71245 .47907 .71516 .48234 .72105 .4806 .71834 .47735 Metetra
.656 .743 .914 r
.71834 .47735 .72105 .4806 .72694 .47888 .72425 .47565 Metetra
.653 .744 .916 r
.72425 .47565 .72694 .47888 .73285 .4772 .73017 .474 Metetra
.649 .745 .92 r
.73017 .474 .73285 .4772 .73878 .47555 .73611 .4724 Metetra
.643 .747 .924 r
.73611 .4724 .73878 .47555 .74472 .47397 .74206 .47088 Metetra
.635 .748 .93 r
.74206 .47088 .74472 .47397 .75068 .47245 .74804 .46945 Metetra
.625 .751 .937 r
.74804 .46945 .75068 .47245 .75666 .47103 .75404 .46813 Metetra
.611 .753 .946 r
.75404 .46813 .75666 .47103 .76267 .46973 .76006 .46694 Metetra
.594 .756 .956 r
.76006 .46694 .76267 .46973 .7687 .46856 .76611 .46592 Metetra
.571 .758 .967 r
.76611 .46592 .7687 .46856 .77475 .46755 .77219 .46508 Metetra
.54 .759 .978 r
.77219 .46508 .77475 .46755 .78084 .46673 .7783 .46445 Metetra
.501 .758 .988 r
.7783 .46445 .78084 .46673 .78696 .46611 .78445 .46404 Metetra
.451 .752 .993 r
.78445 .46404 .78696 .46611 .79312 .46571 .79063 .46386 Metetra
.389 .739 .992 r
.79063 .46386 .79312 .46571 .79931 .46555 .79686 .46392 Metetra
.315 .717 .979 r
.79686 .46392 .79931 .46555 .80554 .46562 .80312 .46422 Metetra
.232 .685 .952 r
.80312 .46422 .80554 .46562 .81181 .46591 .80942 .46473 Metetra
.148 .645 .912 r
.80942 .46473 .81181 .46591 .81813 .46642 .81576 .46544 Metetra
.071 .602 .866 r
.81576 .46544 .81813 .46642 .82448 .46712 .82214 .4663 Metetra
.009 .563 .82 r
.82214 .4663 .82448 .46712 .83087 .46797 .82856 .46728 Metetra
0 .535 .785 r
.82856 .46728 .83087 .46797 .83729 .46893 .835 .46831 Metetra
0 .524 .767 r
.835 .46831 .83729 .46893 .84374 .46993 .84147 .46934 Metetra
0 .532 .769 r
.84147 .46934 .84374 .46993 .85022 .47093 .84796 .47031 Metetra
0 .56 .793 r
.84796 .47031 .85022 .47093 .85672 .47186 .85446 .47113 Metetra
.058 .606 .837 r
.85446 .47113 .85672 .47186 .86322 .47265 .86096 .47176 Metetra
.149 .664 .892 r
.86096 .47176 .86322 .47265 .86973 .47324 .86746 .47213 Metetra
.257 .724 .946 r
.86746 .47213 .86973 .47324 .87623 .47357 .87394 .47218 Metetra
.371 .772 .985 r
.87394 .47218 .87623 .47357 .88272 .47359 .88042 .47188 Metetra
.473 .801 1 r
.88042 .47188 .88272 .47359 .8892 .47326 .88686 .47118 Metetra
.556 .809 .992 r
.88686 .47118 .8892 .47326 .89565 .47254 .89328 .47008 Metetra
.617 .803 .971 r
.89328 .47008 .89565 .47254 .90207 .47142 .89967 .46855 Metetra
.659 .788 .943 r
.89967 .46855 .90207 .47142 .90847 .46988 .90603 .46661 Metetra
.687 .771 .915 r
.90603 .46661 .90847 .46988 .91483 .46793 .91236 .46426 Metetra
.706 .753 .889 r
.91236 .46426 .91483 .46793 .92115 .46559 .91865 .46154 Metetra
.718 .737 .866 r
.91865 .46154 .92115 .46559 .92745 .46289 .92491 .45847 Metetra
.726 .723 .847 r
.92491 .45847 .92745 .46289 .93371 .45984 .93114 .45511 Metetra
.731 .711 .832 r
.93114 .45511 .93371 .45984 .93995 .4565 .93735 .45148 Metetra
.734 .701 .82 r
.93735 .45148 .93995 .4565 .94616 .4529 .94354 .44764 Metetra
.736 .693 .81 r
.94354 .44764 .94616 .4529 .95235 .44909 .94972 .44364 Metetra
.736 .687 .803 r
.94972 .44364 .95235 .44909 .95853 .44512 .95588 .43952 Metetra
.425 .465 .798 r
.37577 .60662 .3788 .61337 .38391 .61567 .38087 .60889 Metetra
.422 .462 .797 r
.38087 .60889 .38391 .61567 .38904 .61792 .386 .61121 Metetra
.425 .466 .8 r
.386 .61121 .38904 .61792 .3942 .61999 .39115 .61348 Metetra
.433 .478 .806 r
.39115 .61348 .3942 .61999 .3994 .62176 .39633 .61557 Metetra
.449 .497 .817 r
.39633 .61557 .3994 .62176 .40463 .6231 .40154 .61735 Metetra
.473 .527 .832 r
.40154 .61735 .40463 .6231 .40989 .62387 .40679 .6187 Metetra
.505 .566 .851 r
.40679 .6187 .40989 .62387 .4152 .62398 .41208 .61947 Metetra
.546 .616 .874 r
.41208 .61947 .4152 .62398 .42055 .62334 .4174 .61958 Metetra
.595 .676 .897 r
.4174 .61958 .42055 .62334 .42593 .6219 .42277 .61893 Metetra
.65 .742 .917 r
.42277 .61893 .42593 .6219 .43135 .61964 .42817 .61746 Metetra
.705 .811 .931 r
.42817 .61746 .43135 .61964 .43679 .61657 .4336 .61517 Metetra
.756 .874 .933 r
.4336 .61517 .43679 .61657 .44226 .61276 .43907 .61207 Metetra
.797 .926 .921 r
.43907 .61207 .44226 .61276 .44775 .60829 .44455 .60823 Metetra
.824 .961 .899 r
.44455 .60823 .44775 .60829 .45325 .60328 .45006 .60372 Metetra
.84 .982 .871 r
.45006 .60372 .45325 .60328 .45876 .59787 .45557 .59868 Metetra
.846 .992 .846 r
.45557 .59868 .45876 .59787 .46427 .59219 .4611 .59324 Metetra
.849 .996 .827 r
.4611 .59324 .46427 .59219 .46978 .58639 .46663 .58753 Metetra
.849 .997 .818 r
.46663 .58753 .46978 .58639 .47529 .5806 .47215 .58171 Metetra
.85 .997 .819 r
.47215 .58171 .47529 .5806 .4808 .57494 .47768 .5759 Metetra
.849 .996 .829 r
.47768 .5759 .4808 .57494 .4863 .5695 .4832 .57023 Metetra
.848 .992 .846 r
.4832 .57023 .4863 .5695 .4918 .56436 .48872 .56478 Metetra
.844 .984 .865 r
.48872 .56478 .4918 .56436 .49729 .55956 .49423 .55962 Metetra
.836 .971 .885 r
.49423 .55962 .49729 .55956 .50278 .55512 .49974 .55481 Metetra
.824 .954 .902 r
.49974 .55481 .50278 .55512 .50828 .55106 .50525 .55037 Metetra
.808 .932 .914 r
.50525 .55037 .50828 .55106 .51377 .54736 .51076 .5463 Metetra
.79 .908 .922 r
.51076 .5463 .51377 .54736 .51927 .54399 .51627 .54259 Metetra
.771 .883 .926 r
.51627 .54259 .51927 .54399 .52477 .54093 .52178 .53921 Metetra
.753 .859 .927 r
.52178 .53921 .52477 .54093 .53028 .53813 .5273 .53614 Metetra
.736 .836 .927 r
.5273 .53614 .53028 .53813 .5358 .53557 .53283 .53334 Metetra
.721 .817 .924 r
.53283 .53334 .5358 .53557 .54133 .53319 .53837 .53076 Metetra
.708 .8 .922 r
.53837 .53076 .54133 .53319 .54687 .53098 .54391 .52838 Metetra
.698 .787 .919 r
.54391 .52838 .54687 .53098 .55242 .52888 .54947 .52615 Metetra
.69 .776 .917 r
.54947 .52615 .55242 .52888 .55797 .52689 .55504 .52405 Metetra
.683 .767 .915 r
.55504 .52405 .55797 .52689 .56354 .52497 .56061 .52204 Metetra
.678 .76 .913 r
.56061 .52204 .56354 .52497 .56913 .52311 .5662 .52011 Metetra
.674 .755 .912 r
.5662 .52011 .56913 .52311 .57472 .52128 .5718 .51824 Metetra
.671 .751 .911 r
.5718 .51824 .57472 .52128 .58032 .51949 .57741 .5164 Metetra
.669 .748 .91 r
.57741 .5164 .58032 .51949 .58594 .51772 .58304 .5146 Metetra
.667 .746 .909 r
.58304 .5146 .58594 .51772 .59157 .51596 .58867 .51282 Metetra
.666 .745 .909 r
.58867 .51282 .59157 .51596 .59721 .51421 .59432 .51105 Metetra
.665 .744 .909 r
.59432 .51105 .59721 .51421 .60286 .51246 .59998 .50929 Metetra
.665 .743 .908 r
.59998 .50929 .60286 .51246 .60852 .51072 .60565 .50753 Metetra
.664 .742 .908 r
.60565 .50753 .60852 .51072 .61419 .50898 .61133 .50578 Metetra
.664 .742 .908 r
.61133 .50578 .61419 .50898 .61988 .50724 .61702 .50402 Metetra
.664 .742 .908 r
.61702 .50402 .61988 .50724 .62557 .50549 .62272 .50227 Metetra
.664 .742 .908 r
.62272 .50227 .62557 .50549 .63128 .50374 .62844 .50052 Metetra
.664 .741 .908 r
.62844 .50052 .63128 .50374 .637 .50199 .63417 .49876 Metetra
.664 .741 .908 r
.63417 .49876 .637 .50199 .64273 .50024 .63991 .497 Metetra
.664 .741 .908 r
.63991 .497 .64273 .50024 .64848 .49848 .64566 .49523 Metetra
.664 .741 .908 r
.64566 .49523 .64848 .49848 .65423 .49673 .65142 .49347 Metetra
.664 .741 .908 r
.65142 .49347 .65423 .49673 .66 .49496 .6572 .4917 Metetra
.663 .741 .908 r
.6572 .4917 .66 .49496 .66578 .4932 .66298 .48992 Metetra
.663 .741 .908 r
.66298 .48992 .66578 .4932 .67157 .49143 .66878 .48815 Metetra
.663 .741 .908 r
.66878 .48815 .67157 .49143 .67737 .48966 .6746 .48637 Metetra
.663 .741 .908 r
.6746 .48637 .67737 .48966 .68319 .48788 .68042 .4846 Metetra
.663 .741 .908 r
.68042 .4846 .68319 .48788 .68901 .48611 .68625 .48282 Metetra
.662 .741 .909 r
.68625 .48282 .68901 .48611 .69485 .48434 .6921 .48105 Metetra
.661 .742 .91 r
.6921 .48105 .69485 .48434 .70071 .48257 .69796 .47929 Metetra
.66 .742 .91 r
.69796 .47929 .70071 .48257 .70657 .48082 .70384 .47754 Metetra
.659 .742 .912 r
.70384 .47754 .70657 .48082 .71245 .47907 .70972 .47581 Metetra
.656 .743 .914 r
.70972 .47581 .71245 .47907 .71834 .47735 .71563 .47411 Metetra
.653 .744 .916 r
.71563 .47411 .71834 .47735 .72425 .47565 .72154 .47245 Metetra
.649 .745 .92 r
.72154 .47245 .72425 .47565 .73017 .474 .72748 .47084 Metetra
.643 .746 .924 r
.72748 .47084 .73017 .474 .73611 .4724 .73343 .46931 Metetra
.636 .748 .93 r
.73343 .46931 .73611 .4724 .74206 .47088 .7394 .46786 Metetra
.626 .751 .937 r
.7394 .46786 .74206 .47088 .74804 .46945 .74539 .46653 Metetra
.613 .753 .945 r
.74539 .46653 .74804 .46945 .75404 .46813 .75141 .46533 Metetra
.595 .756 .955 r
.75141 .46533 .75404 .46813 .76006 .46694 .75745 .46429 Metetra
.572 .758 .966 r
.75745 .46429 .76006 .46694 .76611 .46592 .76352 .46344 Metetra
.542 .759 .977 r
.76352 .46344 .76611 .46592 .77219 .46508 .76963 .46279 Metetra
.503 .758 .987 r
.76963 .46279 .77219 .46508 .7783 .46445 .77577 .46236 Metetra
.453 .752 .993 r
.77577 .46236 .7783 .46445 .78445 .46404 .78194 .46218 Metetra
.39 .74 .992 r
.78194 .46218 .78445 .46404 .79063 .46386 .78815 .46223 Metetra
.315 .717 .979 r
.78815 .46223 .79063 .46386 .79686 .46392 .79441 .46252 Metetra
.231 .684 .952 r
.79441 .46252 .79686 .46392 .80312 .46422 .8007 .46304 Metetra
.145 .643 .911 r
.8007 .46304 .80312 .46422 .80942 .46473 .80703 .46375 Metetra
.065 .598 .862 r
.80703 .46375 .80942 .46473 .81576 .46544 .81341 .46463 Metetra
0 .557 .814 r
.81341 .46463 .81576 .46544 .82214 .4663 .81981 .46563 Metetra
0 .527 .777 r
.81981 .46563 .82214 .4663 .82856 .46728 .82625 .46669 Metetra
0 .514 .756 r
.82625 .46669 .82856 .46728 .835 .46831 .83271 .46775 Metetra
0 .521 .757 r
.83271 .46775 .835 .46831 .84147 .46934 .83919 .46875 Metetra
0 .548 .78 r
.83919 .46875 .84147 .46934 .84796 .47031 .84568 .46961 Metetra
.041 .595 .825 r
.84568 .46961 .84796 .47031 .85446 .47113 .85217 .47028 Metetra
.132 .655 .882 r
.85217 .47028 .85446 .47113 .86096 .47176 .85867 .47068 Metetra
.243 .717 .939 r
.85867 .47068 .86096 .47176 .86746 .47213 .86515 .47077 Metetra
.36 .769 .982 r
.86515 .47077 .86746 .47213 .87394 .47218 .87162 .4705 Metetra
.466 .8 .999 r
.87162 .4705 .87394 .47218 .88042 .47188 .87806 .46983 Metetra
.552 .809 .993 r
.87806 .46983 .88042 .47188 .88686 .47118 .88448 .46874 Metetra
.615 .803 .972 r
.88448 .46874 .88686 .47118 .89328 .47008 .89087 .46722 Metetra
.658 .789 .944 r
.89087 .46722 .89328 .47008 .89967 .46855 .89722 .46528 Metetra
.687 .771 .915 r
.89722 .46528 .89967 .46855 .90603 .46661 .90354 .46293 Metetra
.706 .753 .889 r
.90354 .46293 .90603 .46661 .91236 .46426 .90983 .46019 Metetra
.719 .737 .865 r
.90983 .46019 .91236 .46426 .91865 .46154 .91609 .45711 Metetra
.727 .723 .846 r
.91609 .45711 .91865 .46154 .92491 .45847 .92232 .45371 Metetra
.732 .711 .831 r
.92232 .45371 .92491 .45847 .93114 .45511 .92853 .45006 Metetra
.735 .7 .818 r
.92853 .45006 .93114 .45511 .93735 .45148 .93472 .44619 Metetra
.736 .692 .809 r
.93472 .44619 .93735 .45148 .94354 .44764 .94089 .44215 Metetra
.737 .686 .802 r
.94089 .44215 .94354 .44764 .94972 .44364 .94706 .43799 Metetra
.737 .681 .797 r
.94706 .43799 .94972 .44364 .95588 .43952 .95321 .43376 Metetra
.432 .471 .801 r
.37272 .59996 .37577 .60662 .38087 .60889 .37783 .6021 Metetra
.424 .463 .797 r
.37783 .6021 .38087 .60889 .386 .61121 .38296 .60439 Metetra
.421 .461 .796 r
.38296 .60439 .386 .61121 .39115 .61348 .3881 .60673 Metetra
.423 .465 .799 r
.3881 .60673 .39115 .61348 .39633 .61557 .39327 .60901 Metetra
.432 .476 .805 r
.39327 .60901 .39633 .61557 .40154 .61735 .39847 .61112 Metetra
.448 .496 .816 r
.39847 .61112 .40154 .61735 .40679 .6187 .4037 .61292 Metetra
.472 .526 .832 r
.4037 .61292 .40679 .6187 .41208 .61947 .40897 .61427 Metetra
.505 .565 .851 r
.40897 .61427 .41208 .61947 .4174 .61958 .41428 .61504 Metetra
.546 .616 .873 r
.41428 .61504 .4174 .61958 .42277 .61893 .41962 .61514 Metetra
.595 .676 .897 r
.41962 .61514 .42277 .61893 .42817 .61746 .425 .61447 Metetra
.65 .743 .917 r
.425 .61447 .42817 .61746 .4336 .61517 .43042 .61299 Metetra
.706 .812 .931 r
.43042 .61299 .4336 .61517 .43907 .61207 .43587 .61067 Metetra
.758 .875 .932 r
.43587 .61067 .43907 .61207 .44455 .60823 .44135 .60754 Metetra
.798 .927 .92 r
.44135 .60754 .44455 .60823 .45006 .60372 .44686 .60366 Metetra
.825 .962 .898 r
.44686 .60366 .45006 .60372 .45557 .59868 .45238 .59913 Metetra
.84 .983 .87 r
.45238 .59913 .45557 .59868 .4611 .59324 .45791 .59405 Metetra
.847 .992 .845 r
.45791 .59405 .4611 .59324 .46663 .58753 .46345 .58858 Metetra
.849 .996 .826 r
.46345 .58858 .46663 .58753 .47215 .58171 .469 .58285 Metetra
.849 .997 .818 r
.469 .58285 .47215 .58171 .47768 .5759 .47454 .577 Metetra
.849 .997 .819 r
.47454 .577 .47768 .5759 .4832 .57023 .48008 .57118 Metetra
.849 .996 .829 r
.48008 .57118 .4832 .57023 .48872 .56478 .48561 .56549 Metetra
.848 .992 .846 r
.48561 .56549 .48872 .56478 .49423 .55962 .49115 .56002 Metetra
.843 .984 .866 r
.49115 .56002 .49423 .55962 .49974 .55481 .49668 .55486 Metetra
.835 .971 .885 r
.49668 .55486 .49974 .55481 .50525 .55037 .5022 .55004 Metetra
.823 .954 .902 r
.5022 .55004 .50525 .55037 .51076 .5463 .50773 .54559 Metetra
.808 .932 .914 r
.50773 .54559 .51076 .5463 .51627 .54259 .51325 .54151 Metetra
.79 .908 .922 r
.51325 .54151 .51627 .54259 .52178 .53921 .51878 .53779 Metetra
.771 .883 .926 r
.51878 .53779 .52178 .53921 .5273 .53614 .52431 .53441 Metetra
.753 .859 .928 r
.52431 .53441 .5273 .53614 .53283 .53334 .52985 .53133 Metetra
.736 .836 .927 r
.52985 .53133 .53283 .53334 .53837 .53076 .53539 .52852 Metetra
.721 .817 .925 r
.53539 .52852 .53837 .53076 .54391 .52838 .54095 .52593 Metetra
.708 .801 .922 r
.54095 .52593 .54391 .52838 .54947 .52615 .54651 .52354 Metetra
.698 .787 .919 r
.54651 .52354 .54947 .52615 .55504 .52405 .55209 .5213 Metetra
.69 .776 .917 r
.55209 .5213 .55504 .52405 .56061 .52204 .55767 .51918 Metetra
.683 .767 .915 r
.55767 .51918 .56061 .52204 .5662 .52011 .56327 .51717 Metetra
.678 .76 .913 r
.56327 .51717 .5662 .52011 .5718 .51824 .56887 .51522 Metetra
.674 .755 .912 r
.56887 .51522 .5718 .51824 .57741 .5164 .57449 .51334 Metetra
.671 .751 .911 r
.57449 .51334 .57741 .5164 .58304 .5146 .58012 .51149 Metetra
.669 .748 .91 r
.58012 .51149 .58304 .5146 .58867 .51282 .58577 .50968 Metetra
.667 .746 .909 r
.58577 .50968 .58867 .51282 .59432 .51105 .59142 .50788 Metetra
.666 .745 .909 r
.59142 .50788 .59432 .51105 .59998 .50929 .59708 .5061 Metetra
.665 .744 .909 r
.59708 .5061 .59998 .50929 .60565 .50753 .60276 .50433 Metetra
.665 .743 .908 r
.60276 .50433 .60565 .50753 .61133 .50578 .60845 .50257 Metetra
.664 .742 .908 r
.60845 .50257 .61133 .50578 .61702 .50402 .61415 .5008 Metetra
.664 .742 .908 r
.61415 .5008 .61702 .50402 .62272 .50227 .61986 .49904 Metetra
.664 .742 .908 r
.61986 .49904 .62272 .50227 .62844 .50052 .62559 .49727 Metetra
.664 .741 .908 r
.62559 .49727 .62844 .50052 .63417 .49876 .63132 .49551 Metetra
.664 .741 .908 r
.63132 .49551 .63417 .49876 .63991 .497 .63707 .49374 Metetra
.664 .741 .908 r
.63707 .49374 .63991 .497 .64566 .49523 .64283 .49197 Metetra
.664 .741 .908 r
.64283 .49197 .64566 .49523 .65142 .49347 .6486 .49019 Metetra
.663 .741 .908 r
.6486 .49019 .65142 .49347 .6572 .4917 .65439 .48842 Metetra
.663 .741 .908 r
.65439 .48842 .6572 .4917 .66298 .48992 .66018 .48664 Metetra
.663 .741 .908 r
.66018 .48664 .66298 .48992 .66878 .48815 .66599 .48486 Metetra
.663 .741 .908 r
.66599 .48486 .66878 .48815 .6746 .48637 .67181 .48308 Metetra
.663 .741 .909 r
.67181 .48308 .6746 .48637 .68042 .4846 .67764 .4813 Metetra
.662 .742 .909 r
.67764 .4813 .68042 .4846 .68625 .48282 .68348 .47953 Metetra
.661 .742 .91 r
.68348 .47953 .68625 .48282 .6921 .48105 .68934 .47776 Metetra
.66 .742 .911 r
.68934 .47776 .6921 .48105 .69796 .47929 .69521 .47601 Metetra
.659 .743 .912 r
.69521 .47601 .69796 .47929 .70384 .47754 .70109 .47428 Metetra
.657 .743 .914 r
.70109 .47428 .70384 .47754 .70972 .47581 .70699 .47257 Metetra
.654 .744 .916 r
.70699 .47257 .70972 .47581 .71563 .47411 .7129 .4709 Metetra
.65 .745 .919 r
.7129 .4709 .71563 .47411 .72154 .47245 .71883 .46928 Metetra
.644 .746 .924 r
.71883 .46928 .72154 .47245 .72748 .47084 .72478 .46774 Metetra
.637 .748 .929 r
.72478 .46774 .72748 .47084 .73343 .46931 .73075 .46628 Metetra
.627 .75 .936 r
.73075 .46628 .73343 .46931 .7394 .46786 .73673 .46493 Metetra
.614 .753 .944 r
.73673 .46493 .7394 .46786 .74539 .46653 .74274 .46372 Metetra
.597 .756 .954 r
.74274 .46372 .74539 .46653 .75141 .46533 .74878 .46266 Metetra
.574 .758 .965 r
.74878 .46266 .75141 .46533 .75745 .46429 .75484 .46179 Metetra
.544 .759 .977 r
.75484 .46179 .75745 .46429 .76352 .46344 .76094 .46112 Metetra
.505 .758 .987 r
.76094 .46112 .76352 .46344 .76963 .46279 .76707 .46069 Metetra
.455 .753 .993 r
.76707 .46069 .76963 .46279 .77577 .46236 .77323 .46049 Metetra
.392 .74 .992 r
.77323 .46049 .77577 .46236 .78194 .46218 .77944 .46053 Metetra
.316 .717 .979 r
.77944 .46053 .78194 .46218 .78815 .46223 .78568 .46082 Metetra
.23 .684 .951 r
.78568 .46082 .78815 .46223 .79441 .46252 .79197 .46134 Metetra
.142 .641 .909 r
.79197 .46134 .79441 .46252 .8007 .46304 .79829 .46206 Metetra
.059 .594 .858 r
.79829 .46206 .8007 .46304 .80703 .46375 .80465 .46295 Metetra
0 .551 .808 r
.80465 .46295 .80703 .46375 .81341 .46463 .81105 .46397 Metetra
0 .519 .768 r
.81105 .46397 .81341 .46463 .81981 .46563 .81747 .46506 Metetra
0 .504 .745 r
.81747 .46506 .81981 .46563 .82625 .46669 .82392 .46615 Metetra
0 .509 .744 r
.82392 .46615 .82625 .46669 .83271 .46775 .8304 .46718 Metetra
0 .536 .767 r
.8304 .46718 .83271 .46775 .83919 .46875 .83688 .46808 Metetra
.025 .583 .812 r
.83688 .46808 .83919 .46875 .84568 .46961 .84337 .46879 Metetra
.116 .645 .872 r
.84337 .46879 .84568 .46961 .85217 .47028 .84986 .46923 Metetra
.228 .71 .932 r
.84986 .46923 .85217 .47028 .85867 .47068 .85634 .46935 Metetra
.348 .765 .978 r
.85634 .46935 .85867 .47068 .86515 .47077 .8628 .46911 Metetra
.459 .799 .999 r
.8628 .46911 .86515 .47077 .87162 .4705 .86924 .46846 Metetra
.548 .81 .994 r
.86924 .46846 .87162 .4705 .87806 .46983 .87565 .46739 Metetra
.613 .804 .973 r
.87565 .46739 .87806 .46983 .88448 .46874 .88204 .46588 Metetra
.658 .79 .945 r
.88204 .46588 .88448 .46874 .89087 .46722 .88839 .46394 Metetra
.687 .771 .915 r
.88839 .46394 .89087 .46722 .89722 .46528 .89471 .46159 Metetra
.707 .753 .888 r
.89471 .46159 .89722 .46528 .90354 .46293 .901 .45884 Metetra
.719 .737 .865 r
.901 .45884 .90354 .46293 .90983 .46019 .90726 .45574 Metetra
.727 .722 .845 r
.90726 .45574 .90983 .46019 .91609 .45711 .91349 .45232 Metetra
.732 .71 .83 r
.91349 .45232 .91609 .45711 .92232 .45371 .91969 .44864 Metetra
.735 .7 .817 r
.91969 .44864 .92232 .45371 .92853 .45006 .92588 .44473 Metetra
.737 .692 .808 r
.92588 .44473 .92853 .45006 .93472 .44619 .93205 .44066 Metetra
.737 .685 .8 r
.93205 .44066 .93472 .44619 .94089 .44215 .93821 .43647 Metetra
.737 .68 .795 r
.93821 .43647 .94089 .44215 .94706 .43799 .94437 .4322 Metetra
.736 .676 .792 r
.94437 .4322 .94706 .43799 .95321 .43376 .95053 .4279 Metetra
.442 .483 .806 r
.36967 .59347 .37272 .59996 .37783 .6021 .37479 .5954 Metetra
.431 .47 .8 r
.37479 .5954 .37783 .6021 .38296 .60439 .37991 .59755 Metetra
.423 .462 .796 r
.37991 .59755 .38296 .60439 .3881 .60673 .38506 .59986 Metetra
.42 .46 .795 r
.38506 .59986 .3881 .60673 .39327 .60901 .39022 .60222 Metetra
.423 .464 .798 r
.39022 .60222 .39327 .60901 .39847 .61112 .39541 .60452 Metetra
.431 .475 .805 r
.39541 .60452 .39847 .61112 .4037 .61292 .40062 .60664 Metetra
.448 .495 .816 r
.40062 .60664 .4037 .61292 .40897 .61427 .40587 .60845 Metetra
.472 .525 .831 r
.40587 .60845 .40897 .61427 .41428 .61504 .41116 .6098 Metetra
.504 .565 .85 r
.41116 .6098 .41428 .61504 .41962 .61514 .41648 .61058 Metetra
.546 .616 .873 r
.41648 .61058 .41962 .61514 .425 .61447 .42185 .61067 Metetra
.596 .676 .896 r
.42185 .61067 .425 .61447 .43042 .61299 .42725 .60999 Metetra
.651 .744 .917 r
.42725 .60999 .43042 .61299 .43587 .61067 .43269 .60848 Metetra
.708 .813 .93 r
.43269 .60848 .43587 .61067 .44135 .60754 .43816 .60614 Metetra
.759 .876 .932 r
.43816 .60614 .44135 .60754 .44686 .60366 .44365 .60298 Metetra
.799 .927 .92 r
.44365 .60298 .44686 .60366 .45238 .59913 .44918 .59907 Metetra
.826 .963 .897 r
.44918 .59907 .45238 .59913 .45791 .59405 .45471 .5945 Metetra
.841 .983 .869 r
.45471 .5945 .45791 .59405 .46345 .58858 .46026 .58939 Metetra
.847 .993 .844 r
.46026 .58939 .46345 .58858 .469 .58285 .46582 .58389 Metetra
.849 .996 .826 r
.46582 .58389 .469 .58285 .47454 .577 .47138 .57814 Metetra
.849 .997 .817 r
.47138 .57814 .47454 .577 .48008 .57118 .47694 .57227 Metetra
.849 .997 .819 r
.47694 .57227 .48008 .57118 .48561 .56549 .48249 .56643 Metetra
.849 .996 .829 r
.48249 .56643 .48561 .56549 .49115 .56002 .48804 .56072 Metetra
.848 .992 .846 r
.48804 .56072 .49115 .56002 .49668 .55486 .49359 .55524 Metetra
.843 .984 .866 r
.49359 .55524 .49668 .55486 .5022 .55004 .49913 .55007 Metetra
.835 .971 .885 r
.49913 .55007 .5022 .55004 .50773 .54559 .50468 .54524 Metetra
.823 .954 .902 r
.50468 .54524 .50773 .54559 .51325 .54151 .51022 .54079 Metetra
.807 .932 .914 r
.51022 .54079 .51325 .54151 .51878 .53779 .51576 .5367 Metetra
.79 .908 .923 r
.51576 .5367 .51878 .53779 .52431 .53441 .5213 .53297 Metetra
.771 .883 .927 r
.5213 .53297 .52431 .53441 .52985 .53133 .52685 .52958 Metetra
.753 .859 .928 r
.52685 .52958 .52985 .53133 .53539 .52852 .53241 .52649 Metetra
.736 .837 .927 r
.53241 .52649 .53539 .52852 .54095 .52593 .53797 .52367 Metetra
.721 .817 .925 r
.53797 .52367 .54095 .52593 .54651 .52354 .54354 .52107 Metetra
.709 .801 .922 r
.54354 .52107 .54651 .52354 .55209 .5213 .54913 .51867 Metetra
.698 .787 .92 r
.54913 .51867 .55209 .5213 .55767 .51918 .55472 .51642 Metetra
.69 .776 .917 r
.55472 .51642 .55767 .51918 .56327 .51717 .56032 .51429 Metetra
.683 .767 .915 r
.56032 .51429 .56327 .51717 .56887 .51522 .56594 .51226 Metetra
.678 .76 .913 r
.56594 .51226 .56887 .51522 .57449 .51334 .57156 .51031 Metetra
.674 .755 .912 r
.57156 .51031 .57449 .51334 .58012 .51149 .5772 .50841 Metetra
.671 .751 .911 r
.5772 .50841 .58012 .51149 .58577 .50968 .58285 .50655 Metetra
.669 .748 .91 r
.58285 .50655 .58577 .50968 .59142 .50788 .58851 .50473 Metetra
.667 .746 .909 r
.58851 .50473 .59142 .50788 .59708 .5061 .59418 .50292 Metetra
.666 .745 .909 r
.59418 .50292 .59708 .5061 .60276 .50433 .59987 .50113 Metetra
.665 .744 .909 r
.59987 .50113 .60276 .50433 .60845 .50257 .60556 .49935 Metetra
.665 .743 .908 r
.60556 .49935 .60845 .50257 .61415 .5008 .61127 .49757 Metetra
.664 .742 .908 r
.61127 .49757 .61415 .5008 .61986 .49904 .61699 .4958 Metetra
.664 .742 .908 r
.61699 .4958 .61986 .49904 .62559 .49727 .62272 .49402 Metetra
.664 .742 .908 r
.62272 .49402 .62559 .49727 .63132 .49551 .62847 .49225 Metetra
.664 .742 .908 r
.62847 .49225 .63132 .49551 .63707 .49374 .63422 .49047 Metetra
.664 .741 .908 r
.63422 .49047 .63707 .49374 .64283 .49197 .63999 .48869 Metetra
.664 .741 .908 r
.63999 .48869 .64283 .49197 .6486 .49019 .64577 .48691 Metetra
.663 .741 .908 r
.64577 .48691 .6486 .49019 .65439 .48842 .65156 .48513 Metetra
.663 .741 .908 r
.65156 .48513 .65439 .48842 .66018 .48664 .65737 .48335 Metetra
.663 .742 .908 r
.65737 .48335 .66018 .48664 .66599 .48486 .66318 .48157 Metetra
.663 .742 .909 r
.66318 .48157 .66599 .48486 .67181 .48308 .66901 .47979 Metetra
.662 .742 .909 r
.66901 .47979 .67181 .48308 .67764 .4813 .67485 .47801 Metetra
.661 .742 .91 r
.67485 .47801 .67764 .4813 .68348 .47953 .6807 .47624 Metetra
.66 .742 .911 r
.6807 .47624 .68348 .47953 .68934 .47776 .68657 .47448 Metetra
.659 .743 .912 r
.68657 .47448 .68934 .47776 .69521 .47601 .69245 .47274 Metetra
.657 .743 .914 r
.69245 .47274 .69521 .47601 .70109 .47428 .69834 .47103 Metetra
.654 .744 .916 r
.69834 .47103 .70109 .47428 .70699 .47257 .70425 .46935 Metetra
.65 .745 .919 r
.70425 .46935 .70699 .47257 .7129 .4709 .71017 .46772 Metetra
.645 .746 .923 r
.71017 .46772 .7129 .4709 .71883 .46928 .71612 .46616 Metetra
.638 .748 .928 r
.71612 .46616 .71883 .46928 .72478 .46774 .72208 .46469 Metetra
.628 .75 .935 r
.72208 .46469 .72478 .46774 .73075 .46628 .72806 .46333 Metetra
.615 .753 .943 r
.72806 .46333 .73075 .46628 .73673 .46493 .73406 .4621 Metetra
.598 .755 .953 r
.73406 .4621 .73673 .46493 .74274 .46372 .74009 .46103 Metetra
.576 .758 .964 r
.74009 .46103 .74274 .46372 .74878 .46266 .74615 .46014 Metetra
.546 .759 .976 r
.74615 .46014 .74878 .46266 .75484 .46179 .75223 .45946 Metetra
.508 .758 .986 r
.75223 .45946 .75484 .46179 .76094 .46112 .75836 .459 Metetra
.458 .753 .993 r
.75836 .459 .76094 .46112 .76707 .46069 .76451 .45879 Metetra
.394 .74 .992 r
.76451 .45879 .76707 .46069 .77323 .46049 .77071 .45883 Metetra
.317 .718 .979 r
.77071 .45883 .77323 .46049 .77944 .46053 .77694 .45911 Metetra
.229 .683 .951 r
.77694 .45911 .77944 .46053 .78568 .46082 .78322 .45963 Metetra
.138 .639 .908 r
.78322 .45963 .78568 .46082 .79197 .46134 .78953 .46036 Metetra
.053 .59 .855 r
.78953 .46036 .79197 .46134 .79829 .46206 .79588 .46127 Metetra
0 .545 .802 r
.79588 .46127 .79829 .46206 .80465 .46295 .80227 .46231 Metetra
0 .511 .759 r
.80227 .46231 .80465 .46295 .81105 .46397 .80868 .46342 Metetra
0 .494 .734 r
.80868 .46342 .81105 .46397 .81747 .46506 .81513 .46454 Metetra
0 .498 .732 r
.81513 .46454 .81747 .46506 .82392 .46615 .82159 .46561 Metetra
0 .524 .754 r
.82159 .46561 .82392 .46615 .8304 .46718 .82807 .46655 Metetra
.008 .571 .799 r
.82807 .46655 .8304 .46718 .83688 .46808 .83455 .4673 Metetra
.099 .634 .861 r
.83455 .4673 .83688 .46808 .84337 .46879 .84103 .46777 Metetra
.213 .702 .925 r
.84103 .46777 .84337 .46879 .84986 .46923 .84751 .46793 Metetra
.337 .761 .975 r
.84751 .46793 .84986 .46923 .85634 .46935 .85396 .46772 Metetra
.451 .797 .998 r
.85396 .46772 .85634 .46935 .8628 .46911 .8604 .4671 Metetra
.544 .81 .995 r
.8604 .4671 .8628 .46911 .86924 .46846 .86681 .46604 Metetra
.611 .805 .974 r
.86681 .46604 .86924 .46846 .87565 .46739 .87319 .46455 Metetra
.657 .79 .946 r
.87319 .46455 .87565 .46739 .88204 .46588 .87954 .46261 Metetra
.688 .772 .916 r
.87954 .46261 .88204 .46588 .88839 .46394 .88586 .46025 Metetra
.707 .753 .888 r
.88586 .46025 .88839 .46394 .89471 .46159 .89215 .45749 Metetra
.72 .736 .864 r
.89215 .45749 .89471 .46159 .901 .45884 .8984 .45437 Metetra
.728 .722 .844 r
.8984 .45437 .901 .45884 .90726 .45574 .90463 .45093 Metetra
.733 .709 .828 r
.90463 .45093 .90726 .45574 .91349 .45232 .91084 .44721 Metetra
.736 .699 .816 r
.91084 .44721 .91349 .45232 .91969 .44864 .91702 .44327 Metetra
.737 .691 .806 r
.91702 .44327 .91969 .44864 .92588 .44473 .92319 .43917 Metetra
.738 .684 .799 r
.92319 .43917 .92588 .44473 .93205 .44066 .92935 .43494 Metetra
.737 .679 .794 r
.92935 .43494 .93205 .44066 .93821 .43647 .93551 .43063 Metetra
.737 .676 .791 r
.93551 .43063 .93821 .43647 .94437 .4322 .94166 .4263 Metetra
.735 .673 .79 r
.94166 .4263 .94437 .4322 .95053 .4279 .94783 .42197 Metetra
.456 .498 .814 r
.3666 .5872 .36967 .59347 .37479 .5954 .37173 .58886 Metetra
.441 .482 .806 r
.37173 .58886 .37479 .5954 .37991 .59755 .37686 .59081 Metetra
.43 .469 .799 r
.37686 .59081 .37991 .59755 .38506 .59986 .382 .59298 Metetra
.422 .461 .795 r
.382 .59298 .38506 .59986 .39022 .60222 .38717 .5953 Metetra
.419 .458 .795 r
.38717 .5953 .39022 .60222 .39541 .60452 .39235 .59768 Metetra
.422 .463 .797 r
.39235 .59768 .39541 .60452 .40062 .60664 .39755 .6 Metetra
.431 .474 .804 r
.39755 .6 .40062 .60664 .40587 .60845 .40279 .60214 Metetra
.447 .494 .815 r
.40279 .60214 .40587 .60845 .41116 .6098 .40806 .60395 Metetra
.471 .524 .831 r
.40806 .60395 .41116 .6098 .41648 .61058 .41336 .60531 Metetra
.504 .564 .85 r
.41336 .60531 .41648 .61058 .42185 .61067 .41871 .60609 Metetra
.546 .615 .873 r
.41871 .60609 .42185 .61067 .42725 .60999 .42409 .60617 Metetra
.597 .676 .896 r
.42409 .60617 .42725 .60999 .43269 .60848 .42951 .60547 Metetra
.652 .744 .917 r
.42951 .60547 .43269 .60848 .43816 .60614 .43497 .60394 Metetra
.709 .813 .93 r
.43497 .60394 .43816 .60614 .44365 .60298 .44045 .60157 Metetra
.76 .877 .931 r
.44045 .60157 .44365 .60298 .44918 .59907 .44597 .59838 Metetra
.8 .928 .919 r
.44597 .59838 .44918 .59907 .45471 .5945 .45151 .59444 Metetra
.827 .963 .896 r
.45151 .59444 .45471 .5945 .46026 .58939 .45706 .58984 Metetra
.841 .983 .869 r
.45706 .58984 .46026 .58939 .46582 .58389 .46263 .5847 Metetra
.847 .993 .843 r
.46263 .5847 .46582 .58389 .47138 .57814 .4682 .57917 Metetra
.849 .996 .825 r
.4682 .57917 .47138 .57814 .47694 .57227 .47377 .57339 Metetra
.849 .997 .817 r
.47377 .57339 .47694 .57227 .48249 .56643 .47935 .56751 Metetra
.849 .997 .819 r
.47935 .56751 .48249 .56643 .48804 .56072 .48492 .56165 Metetra
.849 .996 .829 r
.48492 .56165 .48804 .56072 .49359 .55524 .49049 .55593 Metetra
.847 .992 .846 r
.49049 .55593 .49359 .55524 .49913 .55007 .49605 .55044 Metetra
.843 .984 .866 r
.49605 .55044 .49913 .55007 .50468 .54524 .50161 .54526 Metetra
.835 .971 .886 r
.50161 .54526 .50468 .54524 .51022 .54079 .50717 .54042 Metetra
.823 .954 .902 r
.50717 .54042 .51022 .54079 .51576 .5367 .51272 .53596 Metetra
.807 .932 .915 r
.51272 .53596 .51576 .5367 .5213 .53297 .51828 .53186 Metetra
.789 .908 .923 r
.51828 .53186 .5213 .53297 .52685 .52958 .52384 .52813 Metetra
.771 .883 .927 r
.52384 .52813 .52685 .52958 .53241 .52649 .52941 .52473 Metetra
.753 .859 .928 r
.52941 .52473 .53241 .52649 .53797 .52367 .53498 .52163 Metetra
.736 .837 .927 r
.53498 .52163 .53797 .52367 .54354 .52107 .54056 .5188 Metetra
.721 .817 .925 r
.54056 .5188 .54354 .52107 .54913 .51867 .54615 .51619 Metetra
.709 .801 .922 r
.54615 .51619 .54913 .51867 .55472 .51642 .55175 .51377 Metetra
.698 .787 .92 r
.55175 .51377 .55472 .51642 .56032 .51429 .55737 .51151 Metetra
.69 .776 .917 r
.55737 .51151 .56032 .51429 .56594 .51226 .56299 .50937 Metetra
.683 .768 .915 r
.56299 .50937 .56594 .51226 .57156 .51031 .56862 .50733 Metetra
.678 .761 .913 r
.56862 .50733 .57156 .51031 .5772 .50841 .57427 .50536 Metetra
.674 .756 .912 r
.57427 .50536 .5772 .50841 .58285 .50655 .57992 .50346 Metetra
.671 .752 .911 r
.57992 .50346 .58285 .50655 .58851 .50473 .58559 .50159 Metetra
.669 .749 .91 r
.58559 .50159 .58851 .50473 .59418 .50292 .59127 .49975 Metetra
.667 .747 .91 r
.59127 .49975 .59418 .50292 .59987 .50113 .59696 .49793 Metetra
.666 .745 .909 r
.59696 .49793 .59987 .50113 .60556 .49935 .60267 .49613 Metetra
.665 .744 .909 r
.60267 .49613 .60556 .49935 .61127 .49757 .60838 .49434 Metetra
.665 .743 .909 r
.60838 .49434 .61127 .49757 .61699 .4958 .61411 .49255 Metetra
.664 .743 .908 r
.61411 .49255 .61699 .4958 .62272 .49402 .61985 .49077 Metetra
.664 .742 .908 r
.61985 .49077 .62272 .49402 .62847 .49225 .6256 .48899 Metetra
.664 .742 .908 r
.6256 .48899 .62847 .49225 .63422 .49047 .63137 .4872 Metetra
.664 .742 .909 r
.63137 .4872 .63422 .49047 .63999 .48869 .63714 .48542 Metetra
.663 .742 .909 r
.63714 .48542 .63999 .48869 .64577 .48691 .64293 .48363 Metetra
.663 .742 .909 r
.64293 .48363 .64577 .48691 .65156 .48513 .64873 .48185 Metetra
.663 .742 .909 r
.64873 .48185 .65156 .48513 .65737 .48335 .65454 .48006 Metetra
.663 .742 .909 r
.65454 .48006 .65737 .48335 .66318 .48157 .66036 .47828 Metetra
.662 .742 .909 r
.66036 .47828 .66318 .48157 .66901 .47979 .6662 .47649 Metetra
.662 .742 .91 r
.6662 .47649 .66901 .47979 .67485 .47801 .67205 .47472 Metetra
.661 .743 .911 r
.67205 .47472 .67485 .47801 .6807 .47624 .67791 .47295 Metetra
.659 .743 .912 r
.67791 .47295 .6807 .47624 .68657 .47448 .68379 .4712 Metetra
.657 .743 .913 r
.68379 .4712 .68657 .47448 .69245 .47274 .68968 .46948 Metetra
.655 .744 .915 r
.68968 .46948 .69245 .47274 .69834 .47103 .69558 .46779 Metetra
.651 .745 .918 r
.69558 .46779 .69834 .47103 .70425 .46935 .7015 .46615 Metetra
.646 .746 .922 r
.7015 .46615 .70425 .46935 .71017 .46772 .70744 .46458 Metetra
.638 .747 .927 r
.70744 .46458 .71017 .46772 .71612 .46616 .71339 .46309 Metetra
.629 .75 .934 r
.71339 .46309 .71612 .46616 .72208 .46469 .71937 .46172 Metetra
.616 .752 .942 r
.71937 .46172 .72208 .46469 .72806 .46333 .72536 .46047 Metetra
.6 .755 .952 r
.72536 .46047 .72806 .46333 .73406 .4621 .73139 .45938 Metetra
.578 .757 .963 r
.73139 .45938 .73406 .4621 .74009 .46103 .73744 .45848 Metetra
.548 .759 .975 r
.73744 .45848 .74009 .46103 .74615 .46014 .74352 .45779 Metetra
.51 .758 .986 r
.74352 .45779 .74615 .46014 .75223 .45946 .74963 .45732 Metetra
.46 .753 .993 r
.74963 .45732 .75223 .45946 .75836 .459 .75578 .4571 Metetra
.396 .741 .992 r
.75578 .4571 .75836 .459 .76451 .45879 .76196 .45713 Metetra
.318 .718 .979 r
.76196 .45713 .76451 .45879 .77071 .45883 .76819 .45741 Metetra
.228 .683 .951 r
.76819 .45741 .77071 .45883 .77694 .45911 .77445 .45793 Metetra
.135 .637 .906 r
.77445 .45793 .77694 .45911 .78322 .45963 .78075 .45867 Metetra
.047 .586 .851 r
.78075 .45867 .78322 .45963 .78953 .46036 .7871 .45959 Metetra
0 .539 .796 r
.7871 .45959 .78953 .46036 .79588 .46127 .79347 .46064 Metetra
0 .503 .75 r
.79347 .46064 .79588 .46127 .80227 .46231 .79988 .46178 Metetra
0 .484 .723 r
.79988 .46178 .80227 .46231 .80868 .46342 .80631 .46294 Metetra
0 .486 .719 r
.80631 .46294 .80868 .46342 .81513 .46454 .81277 .46404 Metetra
0 .511 .74 r
.81277 .46404 .81513 .46454 .82159 .46561 .81924 .46502 Metetra
0 .559 .786 r
.81924 .46502 .82159 .46561 .82807 .46655 .82571 .4658 Metetra
.082 .623 .849 r
.82571 .4658 .82807 .46655 .83455 .4673 .83219 .46631 Metetra
.198 .694 .917 r
.83219 .46631 .83455 .4673 .84103 .46777 .83866 .46651 Metetra
.325 .756 .971 r
.83866 .46651 .84103 .46777 .84751 .46793 .84511 .46633 Metetra
.443 .796 .997 r
.84511 .46633 .84751 .46793 .85396 .46772 .85155 .46573 Metetra
.539 .81 .996 r
.85155 .46573 .85396 .46772 .8604 .4671 .85795 .46469 Metetra
.609 .806 .975 r
.85795 .46469 .8604 .4671 .86681 .46604 .86433 .46321 Metetra
.657 .791 .946 r
.86433 .46321 .86681 .46604 .87319 .46455 .87068 .46128 Metetra
.688 .772 .916 r
.87068 .46128 .87319 .46455 .87954 .46261 .877 .45891 Metetra
.708 .753 .888 r
.877 .45891 .87954 .46261 .88586 .46025 .88328 .45614 Metetra
.721 .736 .864 r
.88328 .45614 .88586 .46025 .89215 .45749 .88953 .45299 Metetra
.729 .721 .844 r
.88953 .45299 .89215 .45749 .8984 .45437 .89576 .44953 Metetra
.734 .709 .827 r
.89576 .44953 .8984 .45437 .90463 .45093 .90196 .44578 Metetra
.736 .698 .815 r
.90196 .44578 .90463 .45093 .91084 .44721 .90814 .44181 Metetra
.738 .69 .805 r
.90814 .44181 .91084 .44721 .91702 .44327 .91431 .43767 Metetra
.738 .683 .798 r
.91431 .43767 .91702 .44327 .92319 .43917 .92047 .4334 Metetra
.738 .678 .793 r
.92047 .4334 .92319 .43917 .92935 .43494 .92663 .42906 Metetra
.737 .675 .79 r
.92663 .42906 .92935 .43494 .93551 .43063 .93278 .42469 Metetra
.736 .672 .789 r
.93278 .42469 .93551 .43063 .94166 .4263 .93894 .42033 Metetra
.734 .671 .789 r
.93894 .42033 .94166 .4263 .94783 .42197 .94512 .41601 Metetra
.473 .517 .823 r
.36351 .58121 .3666 .5872 .37173 .58886 .36865 .58256 Metetra
.456 .498 .813 r
.36865 .58256 .37173 .58886 .37686 .59081 .37379 .58424 Metetra
.441 .481 .805 r
.37379 .58424 .37686 .59081 .382 .59298 .37894 .58619 Metetra
.429 .468 .799 r
.37894 .58619 .382 .59298 .38717 .5953 .38411 .58838 Metetra
.421 .46 .795 r
.38411 .58838 .38717 .5953 .39235 .59768 .38929 .59072 Metetra
.418 .457 .794 r
.38929 .59072 .39235 .59768 .39755 .6 .39449 .59311 Metetra
.421 .461 .797 r
.39449 .59311 .39755 .6 .40279 .60214 .39971 .59545 Metetra
.43 .473 .803 r
.39971 .59545 .40279 .60214 .40806 .60395 .40497 .5976 Metetra
.446 .494 .815 r
.40497 .5976 .40806 .60395 .41336 .60531 .41026 .59943 Metetra
.471 .524 .83 r
.41026 .59943 .41336 .60531 .41871 .60609 .41558 .60079 Metetra
.504 .564 .85 r
.41558 .60079 .41871 .60609 .42409 .60617 .42094 .60156 Metetra
.547 .615 .873 r
.42094 .60156 .42409 .60617 .42951 .60547 .42634 .60163 Metetra
.597 .677 .896 r
.42634 .60163 .42951 .60547 .43497 .60394 .43178 .60092 Metetra
.653 .745 .917 r
.43178 .60092 .43497 .60394 .44045 .60157 .43726 .59937 Metetra
.71 .814 .93 r
.43726 .59937 .44045 .60157 .44597 .59838 .44276 .59697 Metetra
.761 .878 .931 r
.44276 .59697 .44597 .59838 .45151 .59444 .4483 .59375 Metetra
.801 .929 .919 r
.4483 .59375 .45151 .59444 .45706 .58984 .45385 .58978 Metetra
.827 .963 .896 r
.45385 .58978 .45706 .58984 .46263 .5847 .45942 .58515 Metetra
.841 .983 .868 r
.45942 .58515 .46263 .5847 .4682 .57917 .46501 .57998 Metetra
.847 .993 .843 r
.46501 .57998 .4682 .57917 .47377 .57339 .47059 .57443 Metetra
.849 .996 .825 r
.47059 .57443 .47377 .57339 .47935 .56751 .47618 .56862 Metetra
.849 .997 .816 r
.47618 .56862 .47935 .56751 .48492 .56165 .48177 .56272 Metetra
.849 .997 .819 r
.48177 .56272 .48492 .56165 .49049 .55593 .48736 .55684 Metetra
.849 .996 .829 r
.48736 .55684 .49049 .55593 .49605 .55044 .49294 .55111 Metetra
.847 .992 .846 r
.49294 .55111 .49605 .55044 .50161 .54526 .49852 .54562 Metetra
.843 .984 .866 r
.49852 .54562 .50161 .54526 .50717 .54042 .5041 .54042 Metetra
.835 .971 .886 r
.5041 .54042 .50717 .54042 .51272 .53596 .50967 .53558 Metetra
.822 .954 .902 r
.50967 .53558 .51272 .53596 .51828 .53186 .51524 .53111 Metetra
.807 .932 .915 r
.51524 .53111 .51828 .53186 .52384 .52813 .52082 .52701 Metetra
.789 .908 .923 r
.52082 .52701 .52384 .52813 .52941 .52473 .5264 .52326 Metetra
.77 .883 .927 r
.5264 .52326 .52941 .52473 .53498 .52163 .53198 .51985 Metetra
.752 .859 .928 r
.53198 .51985 .53498 .52163 .54056 .5188 .53757 .51674 Metetra
.736 .837 .927 r
.53757 .51674 .54056 .5188 .54615 .51619 .54317 .5139 Metetra
.721 .818 .925 r
.54317 .5139 .54615 .51619 .55175 .51377 .54878 .51128 Metetra
.709 .801 .922 r
.54878 .51128 .55175 .51377 .55737 .51151 .5544 .50885 Metetra
.698 .788 .92 r
.5544 .50885 .55737 .51151 .56299 .50937 .56003 .50658 Metetra
.69 .777 .917 r
.56003 .50658 .56299 .50937 .56862 .50733 .56567 .50443 Metetra
.683 .768 .915 r
.56567 .50443 .56862 .50733 .57427 .50536 .57132 .50238 Metetra
.678 .761 .914 r
.57132 .50238 .57427 .50536 .57992 .50346 .57699 .5004 Metetra
.674 .756 .912 r
.57699 .5004 .57992 .50346 .58559 .50159 .58266 .49848 Metetra
.671 .752 .911 r
.58266 .49848 .58559 .50159 .59127 .49975 .58835 .4966 Metetra
.669 .749 .911 r
.58835 .4966 .59127 .49975 .59696 .49793 .59405 .49475 Metetra
.667 .747 .91 r
.59405 .49475 .59696 .49793 .60267 .49613 .59976 .49292 Metetra
.666 .746 .91 r
.59976 .49292 .60267 .49613 .60838 .49434 .60548 .49111 Metetra
.665 .744 .909 r
.60548 .49111 .60838 .49434 .61411 .49255 .61122 .48931 Metetra
.665 .744 .909 r
.61122 .48931 .61411 .49255 .61985 .49077 .61697 .48751 Metetra
.664 .743 .909 r
.61697 .48751 .61985 .49077 .6256 .48899 .62273 .48572 Metetra
.664 .743 .909 r
.62273 .48572 .6256 .48899 .63137 .4872 .6285 .48393 Metetra
.664 .743 .909 r
.6285 .48393 .63137 .4872 .63714 .48542 .63428 .48214 Metetra
.663 .742 .909 r
.63428 .48214 .63714 .48542 .64293 .48363 .64008 .48034 Metetra
.663 .742 .909 r
.64008 .48034 .64293 .48363 .64873 .48185 .64588 .47855 Metetra
.663 .742 .909 r
.64588 .47855 .64873 .48185 .65454 .48006 .6517 .47676 Metetra
.663 .742 .909 r
.6517 .47676 .65454 .48006 .66036 .47828 .65754 .47497 Metetra
.662 .742 .909 r
.65754 .47497 .66036 .47828 .6662 .47649 .66338 .47318 Metetra
.661 .742 .91 r
.66338 .47318 .6662 .47649 .67205 .47472 .66924 .47141 Metetra
.66 .742 .911 r
.66924 .47141 .67205 .47472 .67791 .47295 .67511 .46965 Metetra
.658 .742 .912 r
.67511 .46965 .67791 .47295 .68379 .4712 .681 .46792 Metetra
.655 .743 .914 r
.681 .46792 .68379 .4712 .68968 .46948 .68689 .46622 Metetra
.651 .744 .917 r
.68689 .46622 .68968 .46948 .69558 .46779 .69281 .46457 Metetra
.646 .745 .921 r
.69281 .46457 .69558 .46779 .7015 .46615 .69874 .46299 Metetra
.639 .747 .926 r
.69874 .46299 .7015 .46615 .70744 .46458 .70469 .46149 Metetra
.63 .749 .933 r
.70469 .46149 .70744 .46458 .71339 .46309 .71066 .4601 Metetra
.618 .751 .941 r
.71066 .4601 .71339 .46309 .71937 .46172 .71665 .45884 Metetra
.601 .754 .951 r
.71665 .45884 .71937 .46172 .72536 .46047 .72267 .45774 Metetra
.579 .757 .962 r
.72267 .45774 .72536 .46047 .73139 .45938 .72871 .45683 Metetra
.55 .759 .974 r
.72871 .45683 .73139 .45938 .73744 .45848 .73478 .45612 Metetra
.512 .758 .985 r
.73478 .45612 .73744 .45848 .74352 .45779 .74089 .45564 Metetra
.461 .753 .993 r
.74089 .45564 .74352 .45779 .74963 .45732 .74703 .4554 Metetra
.397 .741 .992 r
.74703 .4554 .74963 .45732 .75578 .4571 .7532 .45543 Metetra
.318 .718 .979 r
.7532 .45543 .75578 .4571 .76196 .45713 .75942 .4557 Metetra
.227 .682 .95 r
.75942 .4557 .76196 .45713 .76819 .45741 .76567 .45622 Metetra
.131 .635 .904 r
.76567 .45622 .76819 .45741 .77445 .45793 .77196 .45697 Metetra
.041 .582 .847 r
.77196 .45697 .77445 .45793 .78075 .45867 .77829 .4579 Metetra
0 .533 .789 r
.77829 .4579 .78075 .45867 .7871 .45959 .78466 .45897 Metetra
0 .494 .742 r
.78466 .45897 .7871 .45959 .79347 .46064 .79106 .46014 Metetra
0 .474 .712 r
.79106 .46014 .79347 .46064 .79988 .46178 .79748 .46132 Metetra
0 .475 .707 r
.79748 .46132 .79988 .46178 .80631 .46294 .80393 .46246 Metetra
0 .499 .727 r
.80393 .46246 .80631 .46294 .81277 .46404 .81039 .46347 Metetra
0 .546 .772 r
.81039 .46347 .81277 .46404 .81924 .46502 .81686 .46429 Metetra
.065 .612 .837 r
.81686 .46429 .81924 .46502 .82571 .4658 .82333 .46485 Metetra
.182 .686 .908 r
.82333 .46485 .82571 .4658 .83219 .46631 .82979 .46508 Metetra
.312 .751 .966 r
.82979 .46508 .83219 .46631 .83866 .46651 .83624 .46493 Metetra
.435 .794 .996 r
.83624 .46493 .83866 .46651 .84511 .46633 .84267 .46436 Metetra
.535 .811 .997 r
.84267 .46436 .84511 .46633 .85155 .46573 .84908 .46334 Metetra
.607 .807 .977 r
.84908 .46334 .85155 .46573 .85795 .46469 .85545 .46187 Metetra
.656 .792 .947 r
.85545 .46187 .85795 .46469 .86433 .46321 .8618 .45994 Metetra
.688 .773 .916 r
.8618 .45994 .86433 .46321 .87068 .46128 .86811 .45757 Metetra
.708 .754 .887 r
.86811 .45757 .87068 .46128 .877 .45891 .87439 .45478 Metetra
.721 .736 .863 r
.87439 .45478 .877 .45891 .88328 .45614 .88064 .45162 Metetra
.729 .721 .843 r
.88064 .45162 .88328 .45614 .88953 .45299 .88687 .44813 Metetra
.734 .708 .826 r
.88687 .44813 .88953 .45299 .89576 .44953 .89307 .44435 Metetra
.737 .698 .813 r
.89307 .44435 .89576 .44953 .90196 .44578 .89925 .44035 Metetra
.738 .689 .804 r
.89925 .44035 .90196 .44578 .90814 .44181 .90542 .43617 Metetra
.739 .683 .797 r
.90542 .43617 .90814 .44181 .91431 .43767 .91158 .43186 Metetra
.738 .678 .792 r
.91158 .43186 .91431 .43767 .92047 .4334 .91773 .42749 Metetra
.737 .674 .789 r
.91773 .42749 .92047 .4334 .92663 .42906 .92389 .42308 Metetra
.736 .672 .787 r
.92389 .42308 .92663 .42906 .93278 .42469 .93005 .41868 Metetra
.734 .67 .788 r
.93005 .41868 .93278 .42469 .93894 .42033 .93622 .41433 Metetra
.732 .67 .789 r
.93622 .41433 .93894 .42033 .94512 .41601 .9424 .41006 Metetra
.492 .539 .833 r
.3604 .57551 .36351 .58121 .36865 .58256 .36556 .57654 Metetra
.472 .517 .822 r
.36556 .57654 .36865 .58256 .37379 .58424 .37071 .5779 Metetra
.455 .497 .813 r
.37071 .5779 .37379 .58424 .37894 .58619 .37587 .57959 Metetra
.44 .48 .805 r
.37587 .57959 .37894 .58619 .38411 .58838 .38104 .58155 Metetra
.428 .467 .798 r
.38104 .58155 .38411 .58838 .38929 .59072 .38622 .58375 Metetra
.42 .459 .794 r
.38622 .58375 .38929 .59072 .39449 .59311 .39142 .58611 Metetra
.417 .456 .793 r
.39142 .58611 .39449 .59311 .39971 .59545 .39664 .58852 Metetra
.42 .46 .796 r
.39664 .58852 .39971 .59545 .40497 .5976 .40188 .59087 Metetra
.429 .472 .803 r
.40188 .59087 .40497 .5976 .41026 .59943 .40716 .59303 Metetra
.446 .493 .814 r
.40716 .59303 .41026 .59943 .41558 .60079 .41247 .59487 Metetra
.471 .523 .83 r
.41247 .59487 .41558 .60079 .42094 .60156 .41781 .59623 Metetra
.505 .564 .849 r
.41781 .59623 .42094 .60156 .42634 .60163 .42319 .597 Metetra
.547 .615 .872 r
.42319 .597 .42634 .60163 .43178 .60092 .42861 .59706 Metetra
.598 .677 .896 r
.42861 .59706 .43178 .60092 .43726 .59937 .43407 .59633 Metetra
.654 .745 .917 r
.43407 .59633 .43726 .59937 .44276 .59697 .43956 .59475 Metetra
.711 .815 .93 r
.43956 .59475 .44276 .59697 .4483 .59375 .44509 .59233 Metetra
.762 .879 .931 r
.44509 .59233 .4483 .59375 .45385 .58978 .45064 .58908 Metetra
.802 .929 .918 r
.45064 .58908 .45385 .58978 .45942 .58515 .45621 .58508 Metetra
.828 .964 .895 r
.45621 .58508 .45942 .58515 .46501 .57998 .4618 .58042 Metetra
.842 .984 .867 r
.4618 .58042 .46501 .57998 .47059 .57443 .4674 .57523 Metetra
.848 .993 .842 r
.4674 .57523 .47059 .57443 .47618 .56862 .473 .56965 Metetra
.849 .997 .824 r
.473 .56965 .47618 .56862 .48177 .56272 .47861 .56383 Metetra
.849 .997 .816 r
.47861 .56383 .48177 .56272 .48736 .55684 .48421 .5579 Metetra
.849 .997 .819 r
.48421 .5579 .48736 .55684 .49294 .55111 .48981 .55201 Metetra
.849 .996 .83 r
.48981 .55201 .49294 .55111 .49852 .54562 .49541 .54627 Metetra
.847 .992 .847 r
.49541 .54627 .49852 .54562 .5041 .54042 .50101 .54077 Metetra
.842 .984 .867 r
.50101 .54077 .5041 .54042 .50967 .53558 .5066 .53557 Metetra
.834 .971 .886 r
.5066 .53557 .50967 .53558 .51524 .53111 .51219 .53071 Metetra
.822 .953 .903 r
.51219 .53071 .51524 .53111 .52082 .52701 .51778 .52623 Metetra
.807 .932 .915 r
.51778 .52623 .52082 .52701 .5264 .52326 .52337 .52212 Metetra
.789 .908 .923 r
.52337 .52212 .5264 .52326 .53198 .51985 .52897 .51837 Metetra
.77 .883 .927 r
.52897 .51837 .53198 .51985 .53757 .51674 .53457 .51495 Metetra
.752 .859 .928 r
.53457 .51495 .53757 .51674 .54317 .5139 .54018 .51183 Metetra
.736 .837 .927 r
.54018 .51183 .54317 .5139 .54878 .51128 .5458 .50898 Metetra
.721 .818 .925 r
.5458 .50898 .54878 .51128 .5544 .50885 .55142 .50635 Metetra
.709 .801 .923 r
.55142 .50635 .5544 .50885 .56003 .50658 .55706 .50391 Metetra
.698 .788 .92 r
.55706 .50391 .56003 .50658 .56567 .50443 .56271 .50162 Metetra
.69 .777 .918 r
.56271 .50162 .56567 .50443 .57132 .50238 .56837 .49946 Metetra
.683 .768 .916 r
.56837 .49946 .57132 .50238 .57699 .5004 .57404 .49739 Metetra
.678 .761 .914 r
.57404 .49739 .57699 .5004 .58266 .49848 .57972 .4954 Metetra
.674 .756 .912 r
.57972 .4954 .58266 .49848 .58835 .4966 .58542 .49347 Metetra
.671 .752 .911 r
.58542 .49347 .58835 .4966 .59405 .49475 .59112 .49158 Metetra
.669 .749 .911 r
.59112 .49158 .59405 .49475 .59976 .49292 .59684 .48972 Metetra
.667 .747 .91 r
.59684 .48972 .59976 .49292 .60548 .49111 .60257 .48788 Metetra
.666 .745 .909 r
.60257 .48788 .60548 .49111 .61122 .48931 .60832 .48606 Metetra
.665 .744 .909 r
.60832 .48606 .61122 .48931 .61697 .48751 .61407 .48425 Metetra
.665 .743 .909 r
.61407 .48425 .61697 .48751 .62273 .48572 .61984 .48244 Metetra
.664 .742 .908 r
.61984 .48244 .62273 .48572 .6285 .48393 .62562 .48063 Metetra
.664 .742 .908 r
.62562 .48063 .6285 .48393 .63428 .48214 .63141 .47882 Metetra
.664 .741 .908 r
.63141 .47882 .63428 .48214 .64008 .48034 .63721 .47702 Metetra
.663 .741 .908 r
.63721 .47702 .64008 .48034 .64588 .47855 .64303 .47522 Metetra
.663 .741 .908 r
.64303 .47522 .64588 .47855 .6517 .47676 .64886 .47342 Metetra
.662 .741 .908 r
.64886 .47342 .6517 .47676 .65754 .47497 .6547 .47163 Metetra
.661 .74 .909 r
.6547 .47163 .65754 .47497 .66338 .47318 .66055 .46984 Metetra
.66 .741 .91 r
.66055 .46984 .66338 .47318 .66924 .47141 .66642 .46808 Metetra
.658 .741 .911 r
.66642 .46808 .66924 .47141 .67511 .46965 .6723 .46634 Metetra
.655 .742 .913 r
.6723 .46634 .67511 .46965 .681 .46792 .67819 .46463 Metetra
.652 .743 .916 r
.67819 .46463 .681 .46792 .68689 .46622 .6841 .46298 Metetra
.647 .744 .92 r
.6841 .46298 .68689 .46622 .69281 .46457 .69003 .46139 Metetra
.64 .746 .926 r
.69003 .46139 .69281 .46457 .69874 .46299 .69597 .45989 Metetra
.63 .748 .933 r
.69597 .45989 .69874 .46299 .70469 .46149 .70194 .45849 Metetra
.618 .751 .941 r
.70194 .45849 .70469 .46149 .71066 .4601 .70792 .45722 Metetra
.602 .754 .951 r
.70792 .45722 .71066 .4601 .71665 .45884 .71393 .45611 Metetra
.58 .757 .962 r
.71393 .45611 .71665 .45884 .72267 .45774 .71997 .45518 Metetra
.551 .759 .974 r
.71997 .45518 .72267 .45774 .72871 .45683 .72603 .45446 Metetra
.513 .759 .985 r
.72603 .45446 .72871 .45683 .73478 .45612 .73213 .45396 Metetra
.462 .754 .993 r
.73213 .45396 .73478 .45612 .74089 .45564 .73826 .45372 Metetra
.398 .742 .992 r
.73826 .45372 .74089 .45564 .74703 .4554 .74443 .45373 Metetra
.318 .718 .979 r
.74443 .45373 .74703 .4554 .7532 .45543 .75063 .454 Metetra
.226 .682 .95 r
.75063 .454 .7532 .45543 .75942 .4557 .75688 .45452 Metetra
.128 .633 .902 r
.75688 .45452 .75942 .4557 .76567 .45622 .76316 .45527 Metetra
.036 .579 .844 r
.76316 .45527 .76567 .45622 .77196 .45697 .76948 .45621 Metetra
0 .527 .784 r
.76948 .45621 .77196 .45697 .77829 .4579 .77584 .4573 Metetra
0 .487 .734 r
.77584 .4573 .77829 .4579 .78466 .45897 .78222 .45849 Metetra
0 .465 .702 r
.78222 .45849 .78466 .45897 .79106 .46014 .78864 .4597 Metetra
.128 0 0 r
.78864 .4597 .79106 .46014 .79748 .46132 .79508 .46087 Metetra
0 .487 .714 r
.79508 .46087 .79748 .46132 .80393 .46246 .80153 .46192 Metetra
0 .534 .759 r
.80153 .46192 .80393 .46246 .81039 .46347 .80799 .46278 Metetra
.048 .601 .825 r
.80799 .46278 .81039 .46347 .81686 .46429 .81445 .46338 Metetra
.167 .677 .899 r
.81445 .46338 .81686 .46429 .82333 .46485 .82091 .46364 Metetra
.3 .746 .961 r
.82091 .46364 .82333 .46485 .82979 .46508 .82736 .46353 Metetra
.426 .792 .995 r
.82736 .46353 .82979 .46508 .83624 .46493 .83378 .46298 Metetra
.53 .811 .997 r
.83378 .46298 .83624 .46493 .84267 .46436 .84018 .46199 Metetra
.605 .808 .978 r
.84018 .46199 .84267 .46436 .84908 .46334 .84655 .46052 Metetra
.655 .793 .948 r
.84655 .46052 .84908 .46334 .85545 .46187 .8529 .4586 Metetra
.688 .773 .916 r
.8529 .4586 .85545 .46187 .8618 .45994 .85921 .45622 Metetra
.709 .754 .887 r
.85921 .45622 .8618 .45994 .86811 .45757 .86549 .45342 Metetra
.722 .736 .862 r
.86549 .45342 .86811 .45757 .87439 .45478 .87174 .45024 Metetra
.73 .72 .842 r
.87174 .45024 .87439 .45478 .88064 .45162 .87796 .44672 Metetra
.735 .707 .825 r
.87796 .44672 .88064 .45162 .88687 .44813 .88416 .44292 Metetra
.738 .697 .812 r
.88416 .44292 .88687 .44813 .89307 .44435 .89034 .43888 Metetra
.739 .688 .802 r
.89034 .43888 .89307 .44435 .89925 .44035 .89651 .43466 Metetra
.739 .682 .795 r
.89651 .43466 .89925 .44035 .90542 .43617 .90266 .43032 Metetra
.739 .677 .79 r
.90266 .43032 .90542 .43617 .91158 .43186 .90882 .42591 Metetra
.738 .673 .787 r
.90882 .42591 .91158 .43186 .91773 .42749 .91497 .42147 Metetra
.736 .671 .786 r
.91497 .42147 .91773 .42749 .92389 .42308 .92113 .41704 Metetra
.735 .67 .787 r
.92113 .41704 .92389 .42308 .93005 .41868 .9273 .41265 Metetra
.733 .669 .788 r
.9273 .41265 .93005 .41868 .93622 .41433 .93349 .40835 Metetra
.73 .67 .791 r
.93349 .40835 .93622 .41433 .9424 .41006 .93969 .40414 Metetra
.511 .561 .843 r
.35727 .57014 .3604 .57551 .36556 .57654 .36244 .57082 Metetra
.491 .538 .833 r
.36244 .57082 .36556 .57654 .37071 .5779 .36761 .57185 Metetra
.472 .516 .822 r
.36761 .57185 .37071 .5779 .37587 .57959 .37278 .57322 Metetra
.454 .496 .813 r
.37278 .57322 .37587 .57959 .38104 .58155 .37796 .57491 Metetra
.439 .479 .804 r
.37796 .57491 .38104 .58155 .38622 .58375 .38315 .57689 Metetra
.427 .466 .798 r
.38315 .57689 .38622 .58375 .39142 .58611 .38835 .5791 Metetra
.419 .458 .794 r
.38835 .5791 .39142 .58611 .39664 .58852 .39357 .58147 Metetra
.416 .455 .793 r
.39357 .58147 .39664 .58852 .40188 .59087 .3988 .5839 Metetra
.419 .459 .795 r
.3988 .5839 .40188 .59087 .40716 .59303 .40407 .58627 Metetra
.429 .471 .802 r
.40407 .58627 .40716 .59303 .41247 .59487 .40936 .58844 Metetra
.446 .492 .814 r
.40936 .58844 .41247 .59487 .41781 .59623 .41469 .59028 Metetra
.471 .523 .829 r
.41469 .59028 .41781 .59623 .42319 .597 .42005 .59164 Metetra
.505 .564 .849 r
.42005 .59164 .42319 .597 .42861 .59706 .42545 .59241 Metetra
.548 .615 .872 r
.42545 .59241 .42861 .59706 .43407 .59633 .43089 .59245 Metetra
.599 .677 .896 r
.43089 .59245 .43407 .59633 .43956 .59475 .43637 .5917 Metetra
.655 .746 .917 r
.43637 .5917 .43956 .59475 .44509 .59233 .44188 .59011 Metetra
.712 .816 .93 r
.44188 .59011 .44509 .59233 .45064 .58908 .44743 .58766 Metetra
.763 .879 .93 r
.44743 .58766 .45064 .58908 .45621 .58508 .45299 .58438 Metetra
.803 .93 .918 r
.45299 .58438 .45621 .58508 .4618 .58042 .45858 .58035 Metetra
.828 .964 .894 r
.45858 .58035 .4618 .58042 .4674 .57523 .46419 .57566 Metetra
.842 .984 .867 r
.46419 .57566 .4674 .57523 .473 .56965 .4698 .57045 Metetra
.848 .993 .842 r
.4698 .57045 .473 .56965 .47861 .56383 .47542 .56484 Metetra
.849 .997 .824 r
.47542 .56484 .47861 .56383 .48421 .5579 .48105 .559 Metetra
.849 .997 .816 r
.48105 .559 .48421 .5579 .48981 .55201 .48667 .55306 Metetra
.849 .997 .819 r
.48667 .55306 .48981 .55201 .49541 .54627 .49228 .54716 Metetra
.849 .996 .83 r
.49228 .54716 .49541 .54627 .50101 .54077 .4979 .5414 Metetra
.847 .992 .847 r
.4979 .5414 .50101 .54077 .5066 .53557 .50351 .53589 Metetra
.842 .984 .867 r
.50351 .53589 .5066 .53557 .51219 .53071 .50912 .53068 Metetra
.834 .971 .886 r
.50912 .53068 .51219 .53071 .51778 .52623 .51472 .52582 Metetra
.822 .953 .903 r
.51472 .52582 .51778 .52623 .52337 .52212 .52033 .52133 Metetra
.806 .932 .915 r
.52033 .52133 .52337 .52212 .52897 .51837 .52594 .51721 Metetra
.789 .907 .923 r
.52594 .51721 .52897 .51837 .53457 .51495 .53155 .51345 Metetra
.77 .883 .927 r
.53155 .51345 .53457 .51495 .54018 .51183 .53717 .51002 Metetra
.752 .859 .928 r
.53717 .51002 .54018 .51183 .5458 .50898 .5428 .50689 Metetra
.736 .837 .927 r
.5428 .50689 .5458 .50898 .55142 .50635 .54843 .50403 Metetra
.721 .818 .925 r
.54843 .50403 .55142 .50635 .55706 .50391 .55408 .50138 Metetra
.709 .801 .922 r
.55408 .50138 .55706 .50391 .56271 .50162 .55973 .49893 Metetra
.699 .788 .92 r
.55973 .49893 .56271 .50162 .56837 .49946 .5654 .49663 Metetra
.69 .777 .917 r
.5654 .49663 .56837 .49946 .57404 .49739 .57108 .49445 Metetra
.684 .768 .915 r
.57108 .49445 .57404 .49739 .57972 .4954 .57677 .49237 Metetra
.678 .761 .913 r
.57677 .49237 .57972 .4954 .58542 .49347 .58247 .49037 Metetra
.675 .755 .912 r
.58247 .49037 .58542 .49347 .59112 .49158 .58819 .48842 Metetra
.672 .751 .91 r
.58819 .48842 .59112 .49158 .59684 .48972 .59391 .48651 Metetra
.669 .748 .909 r
.59391 .48651 .59684 .48972 .60257 .48788 .59965 .48464 Metetra
.668 .746 .909 r
.59965 .48464 .60257 .48788 .60832 .48606 .6054 .48278 Metetra
.667 .744 .908 r
.6054 .48278 .60832 .48606 .61407 .48425 .61116 .48094 Metetra
.666 .742 .907 r
.61116 .48094 .61407 .48425 .61984 .48244 .61694 .47911 Metetra
.665 .741 .907 r
.61694 .47911 .61984 .48244 .62562 .48063 .62273 .47729 Metetra
.664 .74 .907 r
.62273 .47729 .62562 .48063 .63141 .47882 .62853 .47547 Metetra
.664 .74 .907 r
.62853 .47547 .63141 .47882 .63721 .47702 .63434 .47366 Metetra
.663 .74 .907 r
.63434 .47366 .63721 .47702 .64303 .47522 .64016 .47185 Metetra
.662 .739 .907 r
.64016 .47185 .64303 .47522 .64886 .47342 .646 .47006 Metetra
.661 .74 .908 r
.646 .47006 .64886 .47342 .6547 .47163 .65185 .46827 Metetra
.66 .74 .909 r
.65185 .46827 .6547 .47163 .66055 .46984 .65771 .4665 Metetra
.658 .741 .911 r
.65771 .4665 .66055 .46984 .66642 .46808 .66359 .46476 Metetra
.655 .742 .914 r
.66359 .46476 .66642 .46808 .6723 .46634 .66948 .46306 Metetra
.651 .743 .917 r
.66948 .46306 .6723 .46634 .67819 .46463 .67538 .4614 Metetra
.646 .745 .921 r
.67538 .4614 .67819 .46463 .6841 .46298 .6813 .45981 Metetra
.64 .747 .927 r
.6813 .45981 .6841 .46298 .69003 .46139 .68724 .4583 Metetra
.63 .75 .934 r
.68724 .4583 .69003 .46139 .69597 .45989 .6932 .4569 Metetra
.618 .753 .942 r
.6932 .4569 .69597 .45989 .70194 .45849 .69918 .45562 Metetra
.602 .756 .952 r
.69918 .45562 .70194 .45849 .70792 .45722 .70519 .45449 Metetra
.581 .759 .963 r
.70519 .45449 .70792 .45722 .71393 .45611 .71121 .45355 Metetra
.552 .761 .975 r
.71121 .45355 .71393 .45611 .71997 .45518 .71727 .45281 Metetra
.514 .76 .985 r
.71727 .45281 .71997 .45518 .72603 .45446 .72336 .4523 Metetra
.464 .755 .993 r
.72336 .4523 .72603 .45446 .73213 .45396 .72948 .45204 Metetra
.399 .742 .993 r
.72948 .45204 .73213 .45396 .73826 .45372 .73564 .45204 Metetra
.319 .719 .98 r
.73564 .45204 .73826 .45372 .74443 .45373 .74183 .4523 Metetra
.227 .682 .95 r
.74183 .4523 .74443 .45373 .75063 .454 .74807 .45281 Metetra
.128 .633 .902 r
.74807 .45281 .75063 .454 .75688 .45452 .75434 .45356 Metetra
.033 .577 .842 r
.75434 .45356 .75688 .45452 .76316 .45527 .76065 .45451 Metetra
0 .523 .78 r
.76065 .45451 .76316 .45527 .76948 .45621 .76699 .45562 Metetra
0 .481 .727 r
.76699 .45562 .76948 .45621 .77584 .4573 .77337 .45683 Metetra
.136 0 0 r
.77337 .45683 .77584 .4573 .78222 .45849 .77978 .45807 Metetra
.14 0 0 r
.77978 .45807 .78222 .45849 .78864 .4597 .78621 .45928 Metetra
0 .475 .701 r
.78621 .45928 .78864 .4597 .79508 .46087 .79265 .46037 Metetra
0 .521 .745 r
.79265 .46037 .79508 .46087 .80153 .46192 .7991 .46127 Metetra
.031 .589 .813 r
.7991 .46127 .80153 .46192 .80799 .46278 .80556 .4619 Metetra
.15 .668 .89 r
.80556 .4619 .80799 .46278 .81445 .46338 .81201 .4622 Metetra
.286 .74 .956 r
.81201 .4622 .81445 .46338 .82091 .46364 .81845 .46212 Metetra
.417 .79 .994 r
.81845 .46212 .82091 .46364 .82736 .46353 .82487 .4616 Metetra
.525 .811 .998 r
.82487 .4616 .82736 .46353 .83378 .46298 .83127 .46063 Metetra
.603 .808 .979 r
.83127 .46063 .83378 .46298 .84018 .46199 .83764 .45918 Metetra
.655 .793 .949 r
.83764 .45918 .84018 .46199 .84655 .46052 .84398 .45726 Metetra
.688 .774 .917 r
.84398 .45726 .84655 .46052 .8529 .4586 .85029 .45488 Metetra
.709 .754 .887 r
.85029 .45488 .8529 .4586 .85921 .45622 .85657 .45207 Metetra
.722 .736 .862 r
.85657 .45207 .85921 .45622 .86549 .45342 .86281 .44886 Metetra
.731 .72 .841 r
.86281 .44886 .86549 .45342 .87174 .45024 .86904 .44532 Metetra
.735 .707 .824 r
.86904 .44532 .87174 .45024 .87796 .44672 .87523 .44148 Metetra
.738 .696 .811 r
.87523 .44148 .87796 .44672 .88416 .44292 .88141 .43741 Metetra
.739 .688 .801 r
.88141 .43741 .88416 .44292 .89034 .43888 .88758 .43316 Metetra
.74 .681 .794 r
.88758 .43316 .89034 .43888 .89651 .43466 .89373 .42878 Metetra
.739 .676 .789 r
.89373 .42878 .89651 .43466 .90266 .43032 .89989 .42432 Metetra
.738 .672 .786 r
.89989 .42432 .90266 .43032 .90882 .42591 .90604 .41985 Metetra
.737 .67 .785 r
.90604 .41985 .90882 .42591 .91497 .42147 .9122 .41538 Metetra
.735 .669 .785 r
.9122 .41538 .91497 .42147 .92113 .41704 .91837 .41097 Metetra
.733 .669 .787 r
.91837 .41097 .92113 .41704 .9273 .41265 .92455 .40664 Metetra
.73 .669 .79 r
.92455 .40664 .9273 .41265 .93349 .40835 .93075 .40241 Metetra
.728 .671 .794 r
.93075 .40241 .93349 .40835 .93969 .40414 .93698 .3983 Metetra
.531 .584 .853 r
.35412 .56507 .35727 .57014 .36244 .57082 .3593 .56542 Metetra
.511 .561 .843 r
.3593 .56542 .36244 .57082 .36761 .57185 .36449 .56611 Metetra
.491 .538 .832 r
.36449 .56611 .36761 .57185 .37278 .57322 .36968 .56714 Metetra
.471 .515 .822 r
.36968 .56714 .37278 .57322 .37796 .57491 .37487 .56851 Metetra
.453 .495 .812 r
.37487 .56851 .37796 .57491 .38315 .57689 .38006 .57021 Metetra
.438 .478 .804 r
.38006 .57021 .38315 .57689 .38835 .5791 .38527 .5722 Metetra
.426 .465 .797 r
.38527 .5722 .38835 .5791 .39357 .58147 .39049 .57443 Metetra
.418 .457 .793 r
.39049 .57443 .39357 .58147 .3988 .5839 .39572 .57681 Metetra
.415 .454 .792 r
.39572 .57681 .3988 .5839 .40407 .58627 .40098 .57925 Metetra
.419 .458 .795 r
.40098 .57925 .40407 .58627 .40936 .58844 .40626 .58163 Metetra
.428 .471 .802 r
.40626 .58163 .40936 .58844 .41469 .59028 .41158 .58381 Metetra
.445 .491 .813 r
.41158 .58381 .41469 .59028 .42005 .59164 .41692 .58566 Metetra
.471 .522 .829 r
.41692 .58566 .42005 .59164 .42545 .59241 .42231 .58702 Metetra
.505 .563 .849 r
.42231 .58702 .42545 .59241 .43089 .59245 .42773 .58778 Metetra
.548 .616 .872 r
.42773 .58778 .43089 .59245 .43637 .5917 .43319 .58781 Metetra
.599 .678 .896 r
.43319 .58781 .43637 .5917 .44188 .59011 .43869 .58705 Metetra
.656 .746 .916 r
.43869 .58705 .44188 .59011 .44743 .58766 .44422 .58543 Metetra
.713 .816 .929 r
.44422 .58543 .44743 .58766 .45299 .58438 .44978 .58295 Metetra
.764 .88 .93 r
.44978 .58295 .45299 .58438 .45858 .58035 .45536 .57965 Metetra
.803 .93 .917 r
.45536 .57965 .45858 .58035 .46419 .57566 .46097 .57559 Metetra
.829 .964 .894 r
.46097 .57559 .46419 .57566 .4698 .57045 .46659 .57087 Metetra
.843 .984 .866 r
.46659 .57087 .4698 .57045 .47542 .56484 .47222 .56563 Metetra
.848 .993 .841 r
.47222 .56563 .47542 .56484 .48105 .559 .47786 .56 Metetra
.849 .997 .824 r
.47786 .56 .48105 .559 .48667 .55306 .4835 .55414 Metetra
.849 .997 .816 r
.4835 .55414 .48667 .55306 .49228 .54716 .48913 .54819 Metetra
.849 .997 .819 r
.48913 .54819 .49228 .54716 .4979 .5414 .49477 .54227 Metetra
.848 .996 .83 r
.49477 .54227 .4979 .5414 .50351 .53589 .5004 .53651 Metetra
.847 .992 .847 r
.5004 .53651 .50351 .53589 .50912 .53068 .50602 .53099 Metetra
.842 .984 .867 r
.50602 .53099 .50912 .53068 .51472 .52582 .51165 .52577 Metetra
.834 .971 .887 r
.51165 .52577 .51472 .52582 .52033 .52133 .51727 .5209 Metetra
.822 .953 .903 r
.51727 .5209 .52033 .52133 .52594 .51721 .52289 .51641 Metetra
.806 .931 .915 r
.52289 .51641 .52594 .51721 .53155 .51345 .52852 .51228 Metetra
.788 .907 .923 r
.52852 .51228 .53155 .51345 .53717 .51002 .53415 .50851 Metetra
.77 .883 .927 r
.53415 .50851 .53717 .51002 .5428 .50689 .53979 .50506 Metetra
.752 .859 .928 r
.53979 .50506 .5428 .50689 .54843 .50403 .54543 .50192 Metetra
.736 .837 .927 r
.54543 .50192 .54843 .50403 .55408 .50138 .55109 .49904 Metetra
.721 .818 .925 r
.55109 .49904 .55408 .50138 .55973 .49893 .55675 .49638 Metetra
.709 .801 .922 r
.55675 .49638 .55973 .49893 .5654 .49663 .56242 .49391 Metetra
.699 .787 .919 r
.56242 .49391 .5654 .49663 .57108 .49445 .56811 .49159 Metetra
.691 .776 .917 r
.56811 .49159 .57108 .49445 .57677 .49237 .57381 .4894 Metetra
.684 .767 .914 r
.57381 .4894 .57677 .49237 .58247 .49037 .57952 .4873 Metetra
.679 .76 .912 r
.57952 .4873 .58247 .49037 .58819 .48842 .58524 .48528 Metetra
.675 .755 .911 r
.58524 .48528 .58819 .48842 .59391 .48651 .59097 .48332 Metetra
.672 .75 .91 r
.59097 .48332 .59391 .48651 .59965 .48464 .59672 .4814 Metetra
.67 .747 .909 r
.59672 .4814 .59965 .48464 .6054 .48278 .60248 .47951 Metetra
.668 .745 .908 r
.60248 .47951 .6054 .48278 .61116 .48094 .60825 .47764 Metetra
.666 .743 .908 r
.60825 .47764 .61116 .48094 .61694 .47911 .61403 .47579 Metetra
.665 .742 .908 r
.61403 .47579 .61694 .47911 .62273 .47729 .61982 .47396 Metetra
.664 .742 .908 r
.61982 .47396 .62273 .47729 .62853 .47547 .62563 .47214 Metetra
.663 .741 .908 r
.62563 .47214 .62853 .47547 .63434 .47366 .63145 .47033 Metetra
.662 .742 .909 r
.63145 .47033 .63434 .47366 .64016 .47185 .63729 .46853 Metetra
.661 .742 .91 r
.63729 .46853 .64016 .47185 .646 .47006 .64313 .46674 Metetra
.659 .743 .912 r
.64313 .46674 .646 .47006 .65185 .46827 .64899 .46498 Metetra
.657 .744 .914 r
.64899 .46498 .65185 .46827 .65771 .4665 .65486 .46324 Metetra
.655 .745 .916 r
.65486 .46324 .65771 .4665 .66359 .46476 .66075 .46154 Metetra
.651 .747 .92 r
.66075 .46154 .66359 .46476 .66948 .46306 .66665 .45988 Metetra
.646 .749 .924 r
.66665 .45988 .66948 .46306 .67538 .4614 .67257 .45828 Metetra
.64 .751 .929 r
.67257 .45828 .67538 .4614 .6813 .45981 .6785 .45676 Metetra
.631 .753 .936 r
.6785 .45676 .6813 .45981 .68724 .4583 .68445 .45534 Metetra
.619 .756 .944 r
.68445 .45534 .68724 .4583 .6932 .4569 .69043 .45405 Metetra
.603 .758 .953 r
.69043 .45405 .6932 .4569 .69918 .45562 .69642 .4529 Metetra
.582 .76 .963 r
.69642 .4529 .69918 .45562 .70519 .45449 .70245 .45193 Metetra
.554 .762 .974 r
.70245 .45193 .70519 .45449 .71121 .45355 .70849 .45117 Metetra
.517 .761 .985 r
.70849 .45117 .71121 .45355 .71727 .45281 .71457 .45064 Metetra
.468 .756 .993 r
.71457 .45064 .71727 .45281 .72336 .4523 .72069 .45035 Metetra
.404 .743 .993 r
.72069 .45035 .72336 .4523 .72948 .45204 .72683 .45033 Metetra
.325 .72 .981 r
.72683 .45033 .72948 .45204 .73564 .45204 .73302 .45058 Metetra
.231 .683 .952 r
.73302 .45058 .73564 .45204 .74183 .4523 .73924 .45108 Metetra
.13 .634 .904 r
.73924 .45108 .74183 .4523 .74807 .45281 .7455 .45183 Metetra
.033 .576 .843 r
.7455 .45183 .74807 .45281 .75434 .45356 .7518 .45279 Metetra
0 .52 .778 r
.7518 .45279 .75434 .45356 .76065 .45451 .75813 .45392 Metetra
0 .475 .722 r
.75813 .45392 .76065 .45451 .76699 .45562 .7645 .45515 Metetra
.146 0 0 r
.7645 .45515 .76699 .45562 .77337 .45683 .7709 .45643 Metetra
.153 0 0 r
.7709 .45643 .77337 .45683 .77978 .45807 .77732 .45767 Metetra
.13 0 0 r
.77732 .45767 .77978 .45807 .78621 .45928 .78375 .4588 Metetra
0 .508 .731 r
.78375 .4588 .78621 .45928 .79265 .46037 .7902 .45974 Metetra
.013 .576 .799 r
.7902 .45974 .79265 .46037 .7991 .46127 .79665 .46042 Metetra
.133 .657 .879 r
.79665 .46042 .7991 .46127 .80556 .4619 .8031 .46076 Metetra
.272 .734 .95 r
.8031 .46076 .80556 .4619 .81201 .4622 .80953 .46071 Metetra
.408 .788 .992 r
.80953 .46071 .81201 .4622 .81845 .46212 .81595 .46022 Metetra
.519 .811 .999 r
.81595 .46022 .81845 .46212 .82487 .4616 .82234 .45927 Metetra
.6 .809 .98 r
.82234 .45927 .82487 .4616 .83127 .46063 .82871 .45783 Metetra
.654 .794 .95 r
.82871 .45783 .83127 .46063 .83764 .45918 .83504 .45591 Metetra
.688 .774 .917 r
.83504 .45591 .83764 .45918 .84398 .45726 .84135 .45353 Metetra
.71 .754 .887 r
.84135 .45353 .84398 .45726 .85029 .45488 .84763 .4507 Metetra
.723 .735 .861 r
.84763 .4507 .85029 .45488 .85657 .45207 .85387 .44748 Metetra
.731 .719 .84 r
.85387 .44748 .85657 .45207 .86281 .44886 .86009 .44391 Metetra
.736 .706 .823 r
.86009 .44391 .86281 .44886 .86904 .44532 .86629 .44004 Metetra
.739 .695 .81 r
.86629 .44004 .86904 .44532 .87523 .44148 .87247 .43593 Metetra
.74 .687 .8 r
.87247 .43593 .87523 .44148 .88141 .43741 .87863 .43164 Metetra
.74 .68 .793 r
.87863 .43164 .88141 .43741 .88758 .43316 .88479 .42723 Metetra
.739 .675 .788 r
.88479 .42723 .88758 .43316 .89373 .42878 .89094 .42274 Metetra
.738 .671 .785 r
.89094 .42274 .89373 .42878 .89989 .42432 .89709 .41822 Metetra
.737 .669 .784 r
.89709 .41822 .89989 .42432 .90604 .41985 .90325 .41372 Metetra
.735 .668 .784 r
.90325 .41372 .90604 .41985 .9122 .41538 .90942 .40928 Metetra
.733 .668 .786 r
.90942 .40928 .9122 .41538 .91837 .41097 .9156 .40492 Metetra
.731 .668 .789 r
.9156 .40492 .91837 .41097 .92455 .40664 .9218 .40066 Metetra
.728 .67 .793 r
.9218 .40066 .92455 .40664 .93075 .40241 .92803 .39653 Metetra
.725 .672 .798 r
.92803 .39653 .93075 .40241 .93698 .3983 .93427 .39254 Metetra
.55 .607 .863 r
.35094 .56029 .35412 .56507 .3593 .56542 .35614 .56033 Metetra
.531 .584 .853 r
.35614 .56033 .3593 .56542 .36449 .56611 .36134 .56069 Metetra
.511 .561 .843 r
.36134 .56069 .36449 .56611 .36968 .56714 .36655 .56137 Metetra
.49 .537 .832 r
.36655 .56137 .36968 .56714 .37487 .56851 .37175 .5624 Metetra
.471 .515 .822 r
.37175 .5624 .37487 .56851 .38006 .57021 .37696 .56378 Metetra
.453 .495 .812 r
.37696 .56378 .38006 .57021 .38527 .5722 .38218 .56548 Metetra
.437 .477 .803 r
.38218 .56548 .38527 .5722 .39049 .57443 .3874 .56749 Metetra
.425 .464 .797 r
.3874 .56749 .39049 .57443 .39572 .57681 .39264 .56973 Metetra
.417 .456 .793 r
.39264 .56973 .39572 .57681 .40098 .57925 .3979 .57212 Metetra
.415 .453 .792 r
.3979 .57212 .40098 .57925 .40626 .58163 .40317 .57458 Metetra
.418 .458 .794 r
.40317 .57458 .40626 .58163 .41158 .58381 .40847 .57697 Metetra
.428 .47 .801 r
.40847 .57697 .41158 .58381 .41692 .58566 .41381 .57916 Metetra
.445 .491 .813 r
.41381 .57916 .41692 .58566 .42231 .58702 .41917 .581 Metetra
.471 .522 .829 r
.41917 .581 .42231 .58702 .42773 .58778 .42458 .58237 Metetra
.505 .563 .849 r
.42458 .58237 .42773 .58778 .43319 .58781 .43002 .58311 Metetra
.549 .616 .872 r
.43002 .58311 .43319 .58781 .43869 .58705 .4355 .58314 Metetra
.6 .678 .896 r
.4355 .58314 .43869 .58705 .44422 .58543 .44101 .58235 Metetra
.657 .747 .916 r
.44101 .58235 .44422 .58543 .44978 .58295 .44656 .58071 Metetra
.714 .817 .929 r
.44656 .58071 .44978 .58295 .45536 .57965 .45214 .57821 Metetra
.765 .88 .93 r
.45214 .57821 .45536 .57965 .46097 .57559 .45775 .57488 Metetra
.804 .931 .917 r
.45775 .57488 .46097 .57559 .46659 .57087 .46337 .57079 Metetra
.829 .965 .893 r
.46337 .57079 .46659 .57087 .47222 .56563 .46901 .56605 Metetra
.843 .984 .866 r
.46901 .56605 .47222 .56563 .47786 .56 .47466 .56078 Metetra
.848 .993 .841 r
.47466 .56078 .47786 .56 .4835 .55414 .48031 .55514 Metetra
.849 .997 .824 r
.48031 .55514 .4835 .55414 .48913 .54819 .48596 .54926 Metetra
.849 .997 .816 r
.48596 .54926 .48913 .54819 .49477 .54227 .49162 .54329 Metetra
.849 .997 .819 r
.49162 .54329 .49477 .54227 .5004 .53651 .49727 .53736 Metetra
.848 .996 .831 r
.49727 .53736 .5004 .53651 .50602 .53099 .50291 .53159 Metetra
.846 .992 .848 r
.50291 .53159 .50602 .53099 .51165 .52577 .50855 .52606 Metetra
.842 .984 .868 r
.50855 .52606 .51165 .52577 .51727 .5209 .51419 .52084 Metetra
.833 .971 .887 r
.51419 .52084 .51727 .5209 .52289 .51641 .51983 .51596 Metetra
.821 .953 .903 r
.51983 .51596 .52289 .51641 .52852 .51228 .52547 .51146 Metetra
.806 .931 .916 r
.52547 .51146 .52852 .51228 .53415 .50851 .53112 .50732 Metetra
.788 .908 .923 r
.53112 .50732 .53415 .50851 .53979 .50506 .53677 .50354 Metetra
.77 .883 .927 r
.53677 .50354 .53979 .50506 .54543 .50192 .54242 .50008 Metetra
.752 .859 .928 r
.54242 .50008 .54543 .50192 .55109 .49904 .54808 .49693 Metetra
.736 .838 .927 r
.54808 .49693 .55109 .49904 .55675 .49638 .55376 .49403 Metetra
.722 .818 .925 r
.55376 .49403 .55675 .49638 .56242 .49391 .55944 .49136 Metetra
.709 .802 .923 r
.55944 .49136 .56242 .49391 .56811 .49159 .56513 .48888 Metetra
.699 .789 .92 r
.56513 .48888 .56811 .49159 .57381 .4894 .57084 .48655 Metetra
.691 .778 .918 r
.57084 .48655 .57381 .4894 .57952 .4873 .57655 .48434 Metetra
.684 .769 .916 r
.57655 .48434 .57952 .4873 .58524 .48528 .58228 .48223 Metetra
.679 .762 .914 r
.58228 .48223 .58524 .48528 .59097 .48332 .58802 .4802 Metetra
.675 .757 .913 r
.58802 .4802 .59097 .48332 .59672 .4814 .59378 .47824 Metetra
.671 .754 .912 r
.59378 .47824 .59672 .4814 .60248 .47951 .59954 .47631 Metetra
.669 .751 .912 r
.59954 .47631 .60248 .47951 .60825 .47764 .60532 .47442 Metetra
.667 .749 .912 r
.60532 .47442 .60825 .47764 .61403 .47579 .61111 .47256 Metetra
.665 .749 .912 r
.61111 .47256 .61403 .47579 .61982 .47396 .61691 .47072 Metetra
.664 .748 .913 r
.61691 .47072 .61982 .47396 .62563 .47214 .62273 .4689 Metetra
.662 .748 .914 r
.62273 .4689 .62563 .47214 .63145 .47033 .62856 .4671 Metetra
.661 .749 .915 r
.62856 .4671 .63145 .47033 .63729 .46853 .6344 .46531 Metetra
.659 .749 .916 r
.6344 .46531 .63729 .46853 .64313 .46674 .64026 .46354 Metetra
.657 .75 .918 r
.64026 .46354 .64313 .46674 .64899 .46498 .64612 .46179 Metetra
.655 .751 .92 r
.64612 .46179 .64899 .46498 .65486 .46324 .65201 .46007 Metetra
.651 .751 .923 r
.65201 .46007 .65486 .46324 .66075 .46154 .6579 .4584 Metetra
.647 .752 .926 r
.6579 .4584 .66075 .46154 .66665 .45988 .66382 .45678 Metetra
.641 .753 .93 r
.66382 .45678 .66665 .45988 .67257 .45828 .66974 .45524 Metetra
.632 .755 .936 r
.66974 .45524 .67257 .45828 .6785 .45676 .67569 .45379 Metetra
.621 .756 .943 r
.67569 .45379 .6785 .45676 .68445 .45534 .68166 .45247 Metetra
.606 .758 .951 r
.68166 .45247 .68445 .45534 .69043 .45405 .68765 .45129 Metetra
.586 .759 .961 r
.68765 .45129 .69043 .45405 .69642 .4529 .69366 .45029 Metetra
.559 .76 .972 r
.69366 .45029 .69642 .4529 .70245 .45193 .6997 .44949 Metetra
.523 .759 .983 r
.6997 .44949 .70245 .45193 .70849 .45117 .70577 .44893 Metetra
.475 .755 .991 r
.70577 .44893 .70849 .45117 .71457 .45064 .71187 .44862 Metetra
.413 .743 .993 r
.71187 .44862 .71457 .45064 .72069 .45035 .71801 .44859 Metetra
.334 .721 .983 r
.71801 .44859 .72069 .45035 .72683 .45033 .72418 .44882 Metetra
.239 .685 .955 r
.72418 .44882 .72683 .45033 .73302 .45058 .7304 .44933 Metetra
.135 .635 .908 r
.7304 .44933 .73302 .45058 .73924 .45108 .73665 .45008 Metetra
.033 .575 .844 r
.73665 .45008 .73924 .45108 .7455 .45183 .74294 .45106 Metetra
0 .516 .776 r
.74294 .45106 .7455 .45183 .7518 .45279 .74926 .45221 Metetra
0 .468 .715 r
.74926 .45221 .7518 .45279 .75813 .45392 .75562 .45347 Metetra
.157 0 0 r
.75562 .45347 .75813 .45392 .7645 .45515 .762 .45478 Metetra
.167 0 0 r
.762 .45478 .7645 .45515 .7709 .45643 .76841 .45606 Metetra
.147 0 0 r
.76841 .45606 .7709 .45643 .77732 .45767 .77484 .45724 Metetra
0 .493 .714 r
.77484 .45724 .77732 .45767 .78375 .4588 .78128 .45822 Metetra
0 .562 .783 r
.78128 .45822 .78375 .4588 .7902 .45974 .78772 .45894 Metetra
.114 .646 .867 r
.78772 .45894 .7902 .45974 .79665 .46042 .79416 .45932 Metetra
.257 .727 .943 r
.79416 .45932 .79665 .46042 .8031 .46076 .80059 .4593 Metetra
.397 .785 .989 r
.80059 .4593 .8031 .46076 .80953 .46071 .807 .45884 Metetra
.514 .811 .999 r
.807 .45884 .80953 .46071 .81595 .46022 .81339 .45791 Metetra
.598 .81 .981 r
.81339 .45791 .81595 .46022 .82234 .45927 .81975 .45648 Metetra
.653 .795 .951 r
.81975 .45648 .82234 .45927 .82871 .45783 .82609 .45457 Metetra
.688 .775 .917 r
.82609 .45457 .82871 .45783 .83504 .45591 .83239 .45218 Metetra
.71 .754 .887 r
.83239 .45218 .83504 .45591 .84135 .45353 .83867 .44934 Metetra
.724 .735 .86 r
.83867 .44934 .84135 .45353 .84763 .4507 .84491 .4461 Metetra
.732 .719 .839 r
.84491 .4461 .84763 .4507 .85387 .44748 .85113 .4425 Metetra
.737 .705 .822 r
.85113 .4425 .85387 .44748 .86009 .44391 .85733 .4386 Metetra
.739 .695 .808 r
.85733 .4386 .86009 .44391 .86629 .44004 .8635 .43446 Metetra
.74 .686 .798 r
.8635 .43446 .86629 .44004 .87247 .43593 .86967 .43013 Metetra
.74 .679 .791 r
.86967 .43013 .87247 .43593 .87863 .43164 .87582 .42567 Metetra
.74 .674 .786 r
.87582 .42567 .87863 .43164 .88479 .42723 .88197 .42115 Metetra
.739 .67 .784 r
.88197 .42115 .88479 .42723 .89094 .42274 .88812 .41659 Metetra
.737 .668 .783 r
.88812 .41659 .89094 .42274 .89709 .41822 .89428 .41206 Metetra
.735 .667 .783 r
.89428 .41206 .89709 .41822 .90325 .41372 .90045 .40758 Metetra
.733 .667 .785 r
.90045 .40758 .90325 .41372 .90942 .40928 .90664 .40319 Metetra
.731 .668 .788 r
.90664 .40319 .90942 .40928 .9156 .40492 .91284 .39891 Metetra
.728 .669 .792 r
.91284 .39891 .9156 .40492 .9218 .40066 .91906 .39476 Metetra
.726 .672 .797 r
.91906 .39476 .9218 .40066 .92803 .39653 .92531 .39075 Metetra
.723 .674 .802 r
.92531 .39075 .92803 .39653 .93427 .39254 .93158 .38689 Metetra
.569 .628 .871 r
.34774 .5558 .35094 .56029 .35614 .56033 .35295 .55555 Metetra
.55 .607 .863 r
.35295 .55555 .35614 .56033 .36134 .56069 .35817 .55558 Metetra
.531 .584 .853 r
.35817 .55558 .36134 .56069 .36655 .56137 .3634 .55592 Metetra
.51 .56 .843 r
.3634 .55592 .36655 .56137 .37175 .5624 .36862 .55661 Metetra
.49 .537 .832 r
.36862 .55661 .37175 .5624 .37696 .56378 .37384 .55764 Metetra
.47 .514 .822 r
.37384 .55764 .37696 .56378 .38218 .56548 .37907 .55902 Metetra
.452 .494 .812 r
.37907 .55902 .38218 .56548 .3874 .56749 .3843 .56074 Metetra
.436 .476 .803 r
.3843 .56074 .3874 .56749 .39264 .56973 .38955 .56275 Metetra
.424 .463 .796 r
.38955 .56275 .39264 .56973 .3979 .57212 .3948 .565 Metetra
.417 .455 .792 r
.3948 .565 .3979 .57212 .40317 .57458 .40008 .56741 Metetra
.414 .452 .791 r
.40008 .56741 .40317 .57458 .40847 .57697 .40537 .56988 Metetra
.417 .457 .794 r
.40537 .56988 .40847 .57697 .41381 .57916 .4107 .57227 Metetra
.427 .469 .801 r
.4107 .57227 .41381 .57916 .41917 .581 .41605 .57447 Metetra
.445 .49 .812 r
.41605 .57447 .41917 .581 .42458 .58237 .42144 .57632 Metetra
.471 .522 .828 r
.42144 .57632 .42458 .58237 .43002 .58311 .42686 .57768 Metetra
.505 .563 .848 r
.42686 .57768 .43002 .58311 .4355 .58314 .43232 .57842 Metetra
.549 .616 .872 r
.43232 .57842 .4355 .58314 .44101 .58235 .43782 .57843 Metetra
.601 .678 .895 r
.43782 .57843 .44101 .58235 .44656 .58071 .44336 .57762 Metetra
.658 .747 .916 r
.44336 .57762 .44656 .58071 .45214 .57821 .44892 .57596 Metetra
.715 .817 .929 r
.44892 .57596 .45214 .57821 .45775 .57488 .45452 .57343 Metetra
.766 .881 .929 r
.45452 .57343 .45775 .57488 .46337 .57079 .46014 .57007 Metetra
.805 .931 .916 r
.46014 .57007 .46337 .57079 .46901 .56605 .46579 .56595 Metetra
.83 .965 .893 r
.46579 .56595 .46901 .56605 .47466 .56078 .47144 .56119 Metetra
.843 .984 .866 r
.47144 .56119 .47466 .56078 .48031 .55514 .47711 .5559 Metetra
.848 .993 .841 r
.47711 .5559 .48031 .55514 .48596 .54926 .48278 .55024 Metetra
.849 .997 .824 r
.48278 .55024 .48596 .54926 .49162 .54329 .48845 .54434 Metetra
.849 .997 .817 r
.48845 .54434 .49162 .54329 .49727 .53736 .49411 .53836 Metetra
.849 .997 .82 r
.49411 .53836 .49727 .53736 .50291 .53159 .49978 .53243 Metetra
.848 .996 .831 r
.49978 .53243 .50291 .53159 .50855 .52606 .50544 .52665 Metetra
.846 .992 .848 r
.50544 .52665 .50855 .52606 .51419 .52084 .5111 .52111 Metetra
.841 .984 .868 r
.5111 .52111 .51419 .52084 .51983 .51596 .51676 .51588 Metetra
.833 .971 .887 r
.51676 .51588 .51983 .51596 .52547 .51146 .52241 .511 Metetra
.821 .954 .904 r
.52241 .511 .52547 .51146 .53112 .50732 .52807 .50649 Metetra
.805 .932 .916 r
.52807 .50649 .53112 .50732 .53677 .50354 .53373 .50235 Metetra
.788 .909 .924 r
.53373 .50235 .53677 .50354 .54242 .50008 .5394 .49856 Metetra
.77 .884 .928 r
.5394 .49856 .54242 .50008 .54808 .49693 .54507 .4951 Metetra
.752 .861 .929 r
.54507 .4951 .54808 .49693 .55376 .49403 .55075 .49194 Metetra
.736 .84 .929 r
.55075 .49194 .55376 .49403 .55944 .49136 .55644 .48903 Metetra
.721 .821 .927 r
.55644 .48903 .55944 .49136 .56513 .48888 .56214 .48636 Metetra
.709 .806 .925 r
.56214 .48636 .56513 .48888 .57084 .48655 .56786 .48387 Metetra
.698 .793 .923 r
.56786 .48387 .57084 .48655 .57655 .48434 .57358 .48154 Metetra
.69 .782 .921 r
.57358 .48154 .57655 .48434 .58228 .48223 .57932 .47933 Metetra
.683 .774 .92 r
.57932 .47933 .58228 .48223 .58802 .4802 .58506 .47722 Metetra
.678 .768 .919 r
.58506 .47722 .58802 .4802 .59378 .47824 .59083 .4752 Metetra
.674 .763 .918 r
.59083 .4752 .59378 .47824 .59954 .47631 .5966 .47323 Metetra
.67 .76 .918 r
.5966 .47323 .59954 .47631 .60532 .47442 .60239 .47131 Metetra
.668 .757 .917 r
.60239 .47131 .60532 .47442 .61111 .47256 .60818 .46942 Metetra
.666 .756 .917 r
.60818 .46942 .61111 .47256 .61691 .47072 .614 .46757 Metetra
.664 .754 .917 r
.614 .46757 .61691 .47072 .62273 .4689 .61982 .46573 Metetra
.663 .753 .918 r
.61982 .46573 .62273 .4689 .62856 .4671 .62566 .46391 Metetra
.661 .752 .918 r
.62566 .46391 .62856 .4671 .6344 .46531 .63151 .46211 Metetra
.659 .751 .918 r
.63151 .46211 .6344 .46531 .64026 .46354 .63737 .46033 Metetra
.657 .751 .919 r
.63737 .46033 .64026 .46354 .64612 .46179 .64325 .45858 Metetra
.654 .75 .92 r
.64325 .45858 .64612 .46179 .65201 .46007 .64914 .45687 Metetra
.65 .749 .922 r
.64914 .45687 .65201 .46007 .6579 .4584 .65504 .45522 Metetra
.644 .749 .925 r
.65504 .45522 .6579 .4584 .66382 .45678 .66097 .45364 Metetra
.636 .749 .93 r
.66097 .45364 .66382 .45678 .66974 .45524 .66691 .45215 Metetra
.626 .75 .936 r
.66691 .45215 .66974 .45524 .67569 .45379 .67287 .45079 Metetra
.611 .751 .944 r
.67287 .45079 .67569 .45379 .68166 .45247 .67885 .44958 Metetra
.592 .752 .954 r
.67885 .44958 .68166 .45247 .68765 .45129 .68486 .44855 Metetra
.566 .754 .966 r
.68486 .44855 .68765 .45129 .69366 .45029 .69089 .44773 Metetra
.531 .754 .978 r
.69089 .44773 .69366 .45029 .6997 .44949 .69695 .44715 Metetra
.484 .751 .988 r
.69695 .44715 .6997 .44949 .70577 .44893 .70304 .44684 Metetra
.421 .741 .993 r
.70304 .44684 .70577 .44893 .71187 .44862 .70917 .4468 Metetra
.341 .721 .985 r
.70917 .4468 .71187 .44862 .71801 .44859 .71534 .44704 Metetra
.243 .685 .957 r
.71534 .44704 .71801 .44859 .72418 .44882 .72154 .44755 Metetra
.134 .633 .908 r
.72154 .44755 .72418 .44882 .7304 .44933 .72778 .44833 Metetra
.027 .571 .84 r
.72778 .44833 .7304 .44933 .73665 .45008 .73406 .44932 Metetra
0 .508 .767 r
.73406 .44932 .73665 .45008 .74294 .45106 .74037 .4505 Metetra
0 .456 .702 r
.74037 .4505 .74294 .45106 .74926 .45221 .74672 .4518 Metetra
.174 0 0 r
.74672 .4518 .74926 .45221 .75562 .45347 .75309 .45315 Metetra
.185 0 0 r
.75309 .45315 .75562 .45347 .762 .45478 .75949 .45447 Metetra
.167 0 0 r
.75949 .45447 .762 .45478 .76841 .45606 .76591 .45568 Metetra
.115 0 0 r
.76591 .45568 .76841 .45606 .77484 .45724 .77234 .45671 Metetra
0 .547 .765 r
.77234 .45671 .77484 .45724 .78128 .45822 .77878 .45746 Metetra
.094 .634 .853 r
.77878 .45746 .78128 .45822 .78772 .45894 .78521 .45788 Metetra
.241 .72 .935 r
.78521 .45788 .78772 .45894 .79416 .45932 .79163 .4579 Metetra
.387 .782 .987 r
.79163 .4579 .79416 .45932 .80059 .4593 .79804 .45746 Metetra
.508 .811 1 r
.79804 .45746 .80059 .4593 .807 .45884 .80443 .45655 Metetra
.595 .811 .983 r
.80443 .45655 .807 .45884 .81339 .45791 .81079 .45513 Metetra
.652 .796 .951 r
.81079 .45513 .81339 .45791 .81975 .45648 .81712 .45322 Metetra
.688 .775 .917 r
.81712 .45322 .81975 .45648 .82609 .45457 .82342 .45082 Metetra
.711 .754 .886 r
.82342 .45082 .82609 .45457 .83239 .45218 .82969 .44797 Metetra
.724 .735 .86 r
.82969 .44797 .83239 .45218 .83867 .44934 .83594 .44471 Metetra
.732 .718 .838 r
.83594 .44471 .83867 .44934 .84491 .4461 .84215 .44109 Metetra
.737 .705 .821 r
.84215 .44109 .84491 .4461 .85113 .4425 .84835 .43715 Metetra
.74 .694 .807 r
.84835 .43715 .85113 .4425 .85733 .4386 .85452 .43298 Metetra
.741 .685 .797 r
.85452 .43298 .85733 .4386 .8635 .43446 .86069 .42861 Metetra
.741 .678 .79 r
.86069 .42861 .8635 .43446 .86967 .43013 .86684 .42412 Metetra
.74 .673 .785 r
.86684 .42412 .86967 .43013 .87582 .42567 .87299 .41955 Metetra
.739 .67 .782 r
.87299 .41955 .87582 .42567 .88197 .42115 .87914 .41496 Metetra
.737 .667 .782 r
.87914 .41496 .88197 .42115 .88812 .41659 .8853 .41039 Metetra
.736 .666 .782 r
.8853 .41039 .88812 .41659 .89428 .41206 .89147 .40588 Metetra
.733 .666 .784 r
.89147 .40588 .89428 .41206 .90045 .40758 .89765 .40146 Metetra
.731 .667 .787 r
.89765 .40146 .90045 .40758 .90664 .40319 .90385 .39716 Metetra
.729 .669 .791 r
.90385 .39716 .90664 .40319 .91284 .39891 .91008 .39299 Metetra
.726 .671 .796 r
.91008 .39299 .91284 .39891 .91906 .39476 .91632 .38896 Metetra
.723 .674 .802 r
.91632 .38896 .91906 .39476 .92531 .39075 .92259 .38508 Metetra
.72 .677 .808 r
.92259 .38508 .92531 .39075 .93158 .38689 .92889 .38136 Metetra
.586 .648 .879 r
.34451 .55155 .34774 .5558 .35295 .55555 .34975 .55104 Metetra
.569 .629 .871 r
.34975 .55104 .35295 .55555 .35817 .55558 .35498 .55077 Metetra
.55 .607 .863 r
.35498 .55077 .35817 .55558 .3634 .55592 .36022 .5508 Metetra
.531 .584 .853 r
.36022 .5508 .3634 .55592 .36862 .55661 .36546 .55114 Metetra
.51 .56 .843 r
.36546 .55114 .36862 .55661 .37384 .55764 .3707 .55182 Metetra
.489 .537 .832 r
.3707 .55182 .37384 .55764 .37907 .55902 .37594 .55285 Metetra
.469 .514 .821 r
.37594 .55285 .37907 .55902 .3843 .56074 .38119 .55424 Metetra
.451 .493 .811 r
.38119 .55424 .3843 .56074 .38955 .56275 .38644 .55596 Metetra
.436 .476 .803 r
.38644 .55596 .38955 .56275 .3948 .565 .3917 .55798 Metetra
.424 .462 .796 r
.3917 .55798 .3948 .565 .40008 .56741 .39698 .56025 Metetra
.416 .454 .792 r
.39698 .56025 .40008 .56741 .40537 .56988 .40227 .56267 Metetra
.413 .451 .791 r
.40227 .56267 .40537 .56988 .4107 .57227 .40759 .56514 Metetra
.417 .456 .793 r
.40759 .56514 .4107 .57227 .41605 .57447 .41293 .56755 Metetra
.427 .469 .8 r
.41293 .56755 .41605 .57447 .42144 .57632 .41831 .56975 Metetra
.445 .49 .812 r
.41831 .56975 .42144 .57632 .42686 .57768 .42371 .5716 Metetra
.471 .521 .828 r
.42371 .5716 .42686 .57768 .43232 .57842 .42916 .57296 Metetra
.506 .563 .848 r
.42916 .57296 .43232 .57842 .43782 .57843 .43464 .57369 Metetra
.55 .616 .872 r
.43464 .57369 .43782 .57843 .44336 .57762 .44016 .57368 Metetra
.602 .679 .895 r
.44016 .57368 .44336 .57762 .44892 .57596 .44571 .57285 Metetra
.659 .748 .916 r
.44571 .57285 .44892 .57596 .45452 .57343 .4513 .57117 Metetra
.716 .818 .929 r
.4513 .57117 .45452 .57343 .46014 .57007 .45692 .56861 Metetra
.766 .881 .929 r
.45692 .56861 .46014 .57007 .46579 .56595 .46256 .56523 Metetra
.805 .931 .916 r
.46256 .56523 .46579 .56595 .47144 .56119 .46822 .56109 Metetra
.83 .965 .893 r
.46822 .56109 .47144 .56119 .47711 .5559 .47389 .5563 Metetra
.843 .984 .865 r
.47389 .5563 .47711 .5559 .48278 .55024 .47957 .55099 Metetra
.848 .993 .841 r
.47957 .55099 .48278 .55024 .48845 .54434 .48525 .54531 Metetra
.849 .996 .824 r
.48525 .54531 .48845 .54434 .49411 .53836 .49094 .5394 Metetra
.849 .997 .817 r
.49094 .5394 .49411 .53836 .49978 .53243 .49662 .53341 Metetra
.848 .997 .82 r
.49662 .53341 .49978 .53243 .50544 .52665 .50231 .52747 Metetra
.848 .996 .831 r
.50231 .52747 .50544 .52665 .5111 .52111 .50798 .52168 Metetra
.845 .992 .849 r
.50798 .52168 .5111 .52111 .51676 .51588 .51366 .51614 Metetra
.841 .984 .868 r
.51366 .51614 .51676 .51588 .52241 .511 .51933 .51091 Metetra
.832 .971 .888 r
.51933 .51091 .52241 .511 .52807 .50649 .52501 .50602 Metetra
.82 .954 .904 r
.52501 .50602 .52807 .50649 .53373 .50235 .53068 .50151 Metetra
.805 .933 .916 r
.53068 .50151 .53373 .50235 .5394 .49856 .53636 .49736 Metetra
.787 .909 .924 r
.53636 .49736 .5394 .49856 .54507 .4951 .54204 .49357 Metetra
.769 .885 .929 r
.54204 .49357 .54507 .4951 .55075 .49194 .54773 .4901 Metetra
.752 .862 .93 r
.54773 .4901 .55075 .49194 .55644 .48903 .55343 .48694 Metetra
.735 .841 .93 r
.55343 .48694 .55644 .48903 .56214 .48636 .55914 .48403 Metetra
.721 .822 .928 r
.55914 .48403 .56214 .48636 .56786 .48387 .56486 .48134 Metetra
.709 .806 .926 r
.56486 .48134 .56786 .48387 .57358 .48154 .57059 .47885 Metetra
.698 .793 .924 r
.57059 .47885 .57358 .48154 .57932 .47933 .57634 .47651 Metetra
.69 .782 .921 r
.57634 .47651 .57932 .47933 .58506 .47722 .58209 .47429 Metetra
.683 .773 .919 r
.58209 .47429 .58506 .47722 .59083 .4752 .58786 .47217 Metetra
.678 .766 .917 r
.58786 .47217 .59083 .4752 .5966 .47323 .59364 .47012 Metetra
.674 .76 .916 r
.59364 .47012 .5966 .47323 .60239 .47131 .59944 .46814 Metetra
.671 .756 .914 r
.59944 .46814 .60239 .47131 .60818 .46942 .60524 .46619 Metetra
.669 .751 .912 r
.60524 .46619 .60818 .46942 .614 .46757 .61106 .46428 Metetra
.667 .748 .911 r
.61106 .46428 .614 .46757 .61982 .46573 .61689 .4624 Metetra
.665 .745 .91 r
.61689 .4624 .61982 .46573 .62566 .46391 .62274 .46054 Metetra
.663 .742 .909 r
.62274 .46054 .62566 .46391 .63151 .46211 .6286 .45871 Metetra
.661 .74 .909 r
.6286 .45871 .63151 .46211 .63737 .46033 .63447 .45691 Metetra
.657 .738 .909 r
.63447 .45691 .63737 .46033 .64325 .45858 .64035 .45516 Metetra
.653 .737 .911 r
.64035 .45516 .64325 .45858 .64914 .45687 .64625 .45346 Metetra
.647 .736 .914 r
.64625 .45346 .64914 .45687 .65504 .45522 .65217 .45185 Metetra
.64 .736 .919 r
.65217 .45185 .65504 .45522 .66097 .45364 .6581 .45034 Metetra
.629 .738 .926 r
.6581 .45034 .66097 .45364 .66691 .45215 .66406 .44897 Metetra
.615 .74 .935 r
.66406 .44897 .66691 .45215 .67287 .45079 .67003 .44775 Metetra
.596 .743 .947 r
.67003 .44775 .67287 .45079 .67885 .44958 .67603 .44672 Metetra
.57 .747 .96 r
.67603 .44672 .67885 .44958 .68486 .44855 .68206 .44591 Metetra
.534 .749 .975 r
.68206 .44591 .68486 .44855 .69089 .44773 .68811 .44534 Metetra
.485 .748 .987 r
.68811 .44534 .69089 .44773 .69695 .44715 .6942 .44504 Metetra
.42 .739 .992 r
.6942 .44504 .69695 .44715 .70304 .44684 .70032 .44502 Metetra
.334 .718 .983 r
.70032 .44502 .70304 .44684 .70917 .4468 .70647 .44528 Metetra
.231 .68 .953 r
.70647 .44528 .70917 .4468 .71534 .44704 .71267 .44582 Metetra
.117 .624 .898 r
.71267 .44582 .71534 .44704 .72154 .44755 .7189 .44661 Metetra
.006 .558 .824 r
.7189 .44661 .72154 .44755 .72778 .44833 .72516 .44763 Metetra
0 .491 .745 r
.72516 .44763 .72778 .44833 .73406 .44932 .73147 .44884 Metetra
.157 0 0 r
.73147 .44884 .73406 .44932 .74037 .4505 .7378 .45016 Metetra
.196 0 0 r
.7378 .45016 .74037 .4505 .74672 .4518 .74417 .45154 Metetra
.207 0 0 r
.74417 .45154 .74672 .4518 .75309 .45315 .75056 .45289 Metetra
.188 0 0 r
.75056 .45289 .75309 .45315 .75949 .45447 .75697 .45414 Metetra
.136 0 0 r
.75697 .45414 .75949 .45447 .76591 .45568 .76339 .4552 Metetra
0 .532 .747 r
.76339 .4552 .76591 .45568 .77234 .45671 .76982 .45599 Metetra
.076 .622 .839 r
.76982 .45599 .77234 .45671 .77878 .45746 .77624 .45644 Metetra
.226 .713 .927 r
.77624 .45644 .77878 .45746 .78521 .45788 .78266 .45649 Metetra
.377 .78 .984 r
.78266 .45649 .78521 .45788 .79163 .4579 .78906 .45608 Metetra
.503 .811 1 r
.78906 .45608 .79163 .4579 .79804 .45746 .79544 .45518 Metetra
.593 .812 .983 r
.79544 .45518 .79804 .45746 .80443 .45655 .8018 .45378 Metetra
.652 .797 .952 r
.8018 .45378 .80443 .45655 .81079 .45513 .80813 .45187 Metetra
.688 .775 .917 r
.80813 .45187 .81079 .45513 .81712 .45322 .81443 .44947 Metetra
.711 .754 .886 r
.81443 .44947 .81712 .45322 .82342 .45082 .8207 .4466 Metetra
.725 .734 .859 r
.8207 .4466 .82342 .45082 .82969 .44797 .82694 .44332 Metetra
.733 .718 .837 r
.82694 .44332 .82969 .44797 .83594 .44471 .83316 .43967 Metetra
.738 .704 .819 r
.83316 .43967 .83594 .44471 .84215 .44109 .83935 .4357 Metetra
.74 .693 .806 r
.83935 .4357 .84215 .44109 .84835 .43715 .84552 .43149 Metetra
.741 .684 .796 r
.84552 .43149 .84835 .43715 .85452 .43298 .85169 .42709 Metetra
.741 .677 .789 r
.85169 .42709 .85452 .43298 .86069 .42861 .85784 .42255 Metetra
.741 .672 .784 r
.85784 .42255 .86069 .42861 .86684 .42412 .86399 .41795 Metetra
.739 .669 .781 r
.86399 .41795 .86684 .42412 .87299 .41955 .87014 .41332 Metetra
.738 .667 .78 r
.87014 .41332 .87299 .41955 .87914 .41496 .8763 .40872 Metetra
.736 .666 .781 r
.8763 .40872 .87914 .41496 .8853 .41039 .88247 .40418 Metetra
.734 .666 .783 r
.88247 .40418 .8853 .41039 .89147 .40588 .88865 .39973 Metetra
.731 .667 .786 r
.88865 .39973 .89147 .40588 .89765 .40146 .89485 .3954 Metetra
.729 .668 .791 r
.89485 .3954 .89765 .40146 .90385 .39716 .90107 .39121 Metetra
.726 .671 .796 r
.90107 .39121 .90385 .39716 .91008 .39299 .90732 .38716 Metetra
.723 .674 .801 r
.90732 .38716 .91008 .39299 .91632 .38896 .91359 .38327 Metetra
.72 .677 .808 r
.91359 .38327 .91632 .38896 .92259 .38508 .91989 .37954 Metetra
.717 .681 .814 r
.91989 .37954 .92259 .38508 .92889 .38136 .92621 .37596 Metetra
.6 .666 .885 r
.34126 .54752 .34451 .55155 .34975 .55104 .34651 .54677 Metetra
.586 .648 .879 r
.34651 .54677 .34975 .55104 .35498 .55077 .35177 .54625 Metetra
.569 .629 .871 r
.35177 .54625 .35498 .55077 .36022 .5508 .35702 .54598 Metetra
.55 .607 .863 r
.35702 .54598 .36022 .5508 .36546 .55114 .36228 .546 Metetra
.53 .584 .853 r
.36228 .546 .36546 .55114 .3707 .55182 .36754 .54633 Metetra
.51 .56 .843 r
.36754 .54633 .3707 .55182 .37594 .55285 .37279 .54701 Metetra
.489 .536 .832 r
.37279 .54701 .37594 .55285 .38119 .55424 .37805 .54804 Metetra
.469 .513 .821 r
.37805 .54804 .38119 .55424 .38644 .55596 .38332 .54943 Metetra
.451 .492 .811 r
.38332 .54943 .38644 .55596 .3917 .55798 .38859 .55116 Metetra
.435 .475 .802 r
.38859 .55116 .3917 .55798 .39698 .56025 .39387 .55319 Metetra
.423 .461 .795 r
.39387 .55319 .39698 .56025 .40227 .56267 .39917 .55547 Metetra
.415 .453 .791 r
.39917 .55547 .40227 .56267 .40759 .56514 .40448 .5579 Metetra
.413 .451 .79 r
.40448 .5579 .40759 .56514 .41293 .56755 .40982 .56038 Metetra
.416 .455 .793 r
.40982 .56038 .41293 .56755 .41831 .56975 .41518 .5628 Metetra
.427 .468 .8 r
.41518 .5628 .41831 .56975 .42371 .5716 .42057 .565 Metetra
.445 .49 .812 r
.42057 .565 .42371 .5716 .42916 .57296 .426 .56685 Metetra
.471 .521 .828 r
.426 .56685 .42916 .57296 .43464 .57369 .43147 .5682 Metetra
.506 .564 .848 r
.43147 .5682 .43464 .57369 .44016 .57368 .43697 .56892 Metetra
.551 .617 .871 r
.43697 .56892 .44016 .57368 .44571 .57285 .44251 .56889 Metetra
.603 .679 .895 r
.44251 .56889 .44571 .57285 .4513 .57117 .44808 .56805 Metetra
.66 .749 .916 r
.44808 .56805 .4513 .57117 .45692 .56861 .45369 .56634 Metetra
.717 .819 .928 r
.45369 .56634 .45692 .56861 .46256 .56523 .45932 .56376 Metetra
.767 .882 .929 r
.45932 .56376 .46256 .56523 .46822 .56109 .46498 .56035 Metetra
.806 .931 .916 r
.46498 .56035 .46822 .56109 .47389 .5563 .47066 .55618 Metetra
.831 .965 .892 r
.47066 .55618 .47389 .5563 .47957 .55099 .47635 .55137 Metetra
.844 .984 .865 r
.47635 .55137 .47957 .55099 .48525 .54531 .48205 .54604 Metetra
.849 .993 .841 r
.48205 .54604 .48525 .54531 .49094 .5394 .48775 .54034 Metetra
.85 .996 .825 r
.48775 .54034 .49094 .5394 .49662 .53341 .49345 .53442 Metetra
.849 .997 .818 r
.49345 .53442 .49662 .53341 .50231 .52747 .49915 .52842 Metetra
.849 .997 .821 r
.49915 .52842 .50231 .52747 .50798 .52168 .50485 .52247 Metetra
.848 .995 .833 r
.50485 .52247 .50798 .52168 .51366 .51614 .51054 .51667 Metetra
.846 .991 .85 r
.51054 .51667 .51366 .51614 .51933 .51091 .51623 .51112 Metetra
.841 .983 .869 r
.51623 .51112 .51933 .51091 .52501 .50602 .52192 .50588 Metetra
.833 .97 .888 r
.52192 .50588 .52501 .50602 .53068 .50151 .52761 .50099 Metetra
.82 .952 .904 r
.52761 .50099 .53068 .50151 .53636 .49736 .53331 .49647 Metetra
.805 .93 .916 r
.53331 .49647 .53636 .49736 .54204 .49357 .539 .4923 Metetra
.788 .906 .923 r
.539 .4923 .54204 .49357 .54773 .4901 .5447 .48849 Metetra
.77 .881 .926 r
.5447 .48849 .54773 .4901 .55343 .48694 .55041 .48501 Metetra
.752 .856 .927 r
.55041 .48501 .55343 .48694 .55914 .48403 .55613 .48182 Metetra
.736 .834 .925 r
.55613 .48182 .55914 .48403 .56486 .48134 .56186 .47888 Metetra
.722 .814 .922 r
.56186 .47888 .56486 .48134 .57059 .47885 .5676 .47617 Metetra
.71 .797 .919 r
.5676 .47617 .57059 .47885 .57634 .47651 .57335 .47363 Metetra
.7 .782 .915 r
.57335 .47363 .57634 .47651 .58209 .47429 .57911 .47125 Metetra
.692 .769 .911 r
.57911 .47125 .58209 .47429 .58786 .47217 .58489 .46899 Metetra
.685 .759 .907 r
.58489 .46899 .58786 .47217 .59364 .47012 .59067 .46682 Metetra
.68 .75 .904 r
.59067 .46682 .59364 .47012 .59944 .46814 .59647 .46473 Metetra
.676 .743 .901 r
.59647 .46473 .59944 .46814 .60524 .46619 .60228 .4627 Metetra
.673 .737 .899 r
.60228 .4627 .60524 .46619 .61106 .46428 .60811 .46072 Metetra
.669 .733 .897 r
.60811 .46072 .61106 .46428 .61689 .4624 .61395 .45879 Metetra
.666 .729 .896 r
.61395 .45879 .61689 .4624 .62274 .46054 .6198 .4569 Metetra
.663 .727 .897 r
.6198 .4569 .62274 .46054 .6286 .45871 .62567 .45507 Metetra
.659 .725 .898 r
.62567 .45507 .6286 .45871 .63447 .45691 .63155 .45329 Metetra
.654 .726 .902 r
.63155 .45329 .63447 .45691 .64035 .45516 .63744 .45159 Metetra
.647 .727 .907 r
.63744 .45159 .64035 .45516 .64625 .45346 .64335 .44999 Metetra
.639 .73 .914 r
.64335 .44999 .64625 .45346 .65217 .45185 .64928 .4485 Metetra
.628 .734 .924 r
.64928 .4485 .65217 .45185 .6581 .45034 .65523 .44715 Metetra
.612 .739 .935 r
.65523 .44715 .6581 .45034 .66406 .44897 .6612 .44596 Metetra
.591 .744 .95 r
.6612 .44596 .66406 .44897 .67003 .44775 .6672 .44497 Metetra
.563 .75 .965 r
.6672 .44497 .67003 .44775 .67603 .44672 .67322 .44419 Metetra
.523 .754 .98 r
.67322 .44419 .67603 .44672 .68206 .44591 .67926 .44365 Metetra
.47 .752 .991 r
.67926 .44365 .68206 .44591 .68811 .44534 .68534 .44338 Metetra
.397 .741 .992 r
.68534 .44338 .68811 .44534 .6942 .44504 .69146 .44338 Metetra
.305 .715 .976 r
.69146 .44338 .6942 .44504 .70032 .44502 .6976 .44365 Metetra
.196 .67 .936 r
.6976 .44365 .70032 .44502 .70647 .44528 .70379 .4442 Metetra
.08 .607 .872 r
.70379 .4442 .70647 .44528 .71267 .44582 .71001 .44501 Metetra
0 .537 .792 r
.71001 .44501 .71267 .44582 .7189 .44661 .71626 .44603 Metetra
0 .47 .714 r
.71626 .44603 .7189 .44661 .72516 .44763 .72255 .44724 Metetra
.18 0 0 r
.72255 .44724 .72516 .44763 .73147 .44884 .72888 .44858 Metetra
.216 0 0 r
.72888 .44858 .73147 .44884 .7378 .45016 .73523 .44997 Metetra
.223 0 0 r
.73523 .44997 .7378 .45016 .74417 .45154 .74161 .45134 Metetra
.202 0 0 r
.74161 .45134 .74417 .45154 .75056 .45289 .74801 .45261 Metetra
.15 0 0 r
.74801 .45261 .75056 .45289 .75697 .45414 .75442 .45369 Metetra
0 .521 .735 r
.75442 .45369 .75697 .45414 .76339 .4552 .76084 .45451 Metetra
.064 .614 .831 r
.76084 .45451 .76339 .4552 .76982 .45599 .76726 .45499 Metetra
.217 .708 .923 r
.76726 .45499 .76982 .45599 .77624 .45644 .77367 .45506 Metetra
.37 .777 .983 r
.77367 .45506 .77624 .45644 .78266 .45649 .78006 .45468 Metetra
.499 .81 1 r
.78006 .45468 .78266 .45649 .78906 .45608 .78644 .4538 Metetra
.591 .812 .984 r
.78644 .4538 .78906 .45608 .79544 .45518 .79279 .45241 Metetra
.651 .796 .952 r
.79279 .45241 .79544 .45518 .8018 .45378 .79912 .4505 Metetra
.688 .775 .917 r
.79912 .4505 .8018 .45378 .80813 .45187 .80541 .4481 Metetra
.711 .753 .885 r
.80541 .4481 .80813 .45187 .81443 .44947 .81168 .44522 Metetra
.725 .734 .858 r
.81168 .44522 .81443 .44947 .8207 .4466 .81792 .44192 Metetra
.733 .717 .836 r
.81792 .44192 .8207 .4466 .82694 .44332 .82414 .43824 Metetra
.738 .703 .818 r
.82414 .43824 .82694 .44332 .83316 .43967 .83033 .43425 Metetra
.741 .692 .805 r
.83033 .43425 .83316 .43967 .83935 .4357 .83651 .43 Metetra
.742 .683 .795 r
.83651 .43 .83935 .4357 .84552 .43149 .84267 .42556 Metetra
.742 .676 .787 r
.84267 .42556 .84552 .43149 .85169 .42709 .84882 .42099 Metetra
.741 .671 .783 r
.84882 .42099 .85169 .42709 .85784 .42255 .85497 .41634 Metetra
.74 .668 .78 r
.85497 .41634 .85784 .42255 .86399 .41795 .86112 .41168 Metetra
.738 .666 .779 r
.86112 .41168 .86399 .41795 .87014 .41332 .86728 .40704 Metetra
.736 .665 .78 r
.86728 .40704 .87014 .41332 .8763 .40872 .87345 .40247 Metetra
.734 .665 .782 r
.87345 .40247 .8763 .40872 .88247 .40418 .87963 .39799 Metetra
.731 .666 .785 r
.87963 .39799 .88247 .40418 .88865 .39973 .88584 .39364 Metetra
.729 .668 .79 r
.88584 .39364 .88865 .39973 .89485 .3954 .89206 .38943 Metetra
.726 .67 .795 r
.89206 .38943 .89485 .3954 .90107 .39121 .8983 .38536 Metetra
.723 .673 .801 r
.8983 .38536 .90107 .39121 .90732 .38716 .90457 .38146 Metetra
.72 .677 .807 r
.90457 .38146 .90732 .38716 .91359 .38327 .91087 .37771 Metetra
.717 .68 .814 r
.91087 .37771 .91359 .38327 .91989 .37954 .9172 .37412 Metetra
.713 .685 .821 r
.9172 .37412 .91989 .37954 .92621 .37596 .92355 .37069 Metetra
.613 .681 .89 r
.338 .54367 .34126 .54752 .34651 .54677 .34326 .54273 Metetra
.601 .666 .885 r
.34326 .54273 .34651 .54677 .35177 .54625 .34853 .54197 Metetra
.586 .649 .879 r
.34853 .54197 .35177 .54625 .35702 .54598 .3538 .54144 Metetra
.569 .629 .872 r
.3538 .54144 .35702 .54598 .36228 .546 .35907 .54116 Metetra
.55 .607 .863 r
.35907 .54116 .36228 .546 .36754 .54633 .36435 .54117 Metetra
.53 .584 .853 r
.36435 .54117 .36754 .54633 .37279 .54701 .36962 .5415 Metetra
.509 .56 .843 r
.36962 .5415 .37279 .54701 .37805 .54804 .3749 .54217 Metetra
.488 .536 .832 r
.3749 .54217 .37805 .54804 .38332 .54943 .38018 .54321 Metetra
.468 .513 .821 r
.38018 .54321 .38332 .54943 .38859 .55116 .38546 .5446 Metetra
.45 .492 .811 r
.38546 .5446 .38859 .55116 .39387 .55319 .39075 .54634 Metetra
.434 .474 .802 r
.39075 .54634 .39387 .55319 .39917 .55547 .39606 .54838 Metetra
.422 .461 .795 r
.39606 .54838 .39917 .55547 .40448 .5579 .40137 .55066 Metetra
.415 .452 .791 r
.40137 .55066 .40448 .5579 .40982 .56038 .4067 .5531 Metetra
.412 .45 .79 r
.4067 .5531 .40982 .56038 .41518 .5628 .41206 .55559 Metetra
.416 .455 .793 r
.41206 .55559 .41518 .5628 .42057 .565 .41744 .55801 Metetra
.427 .468 .8 r
.41744 .55801 .42057 .565 .426 .56685 .42286 .56022 Metetra
.445 .49 .811 r
.42286 .56022 .426 .56685 .43147 .5682 .42831 .56207 Metetra
.471 .521 .828 r
.42831 .56207 .43147 .5682 .43697 .56892 .43379 .56341 Metetra
.507 .564 .848 r
.43379 .56341 .43697 .56892 .44251 .56889 .43931 .56412 Metetra
.551 .617 .871 r
.43931 .56412 .44251 .56889 .44808 .56805 .44487 .56407 Metetra
.603 .68 .895 r
.44487 .56407 .44808 .56805 .45369 .56634 .45047 .56321 Metetra
.661 .749 .916 r
.45047 .56321 .45369 .56634 .45932 .56376 .45609 .56147 Metetra
.718 .819 .928 r
.45609 .56147 .45932 .56376 .46498 .56035 .46175 .55887 Metetra
.768 .882 .928 r
.46175 .55887 .46498 .56035 .47066 .55618 .46742 .55543 Metetra
.806 .931 .915 r
.46742 .55543 .47066 .55618 .47635 .55137 .47312 .55124 Metetra
.831 .965 .892 r
.47312 .55124 .47635 .55137 .48205 .54604 .47883 .54641 Metetra
.844 .984 .865 r
.47883 .54641 .48205 .54604 .48775 .54034 .48454 .54106 Metetra
.849 .993 .841 r
.48454 .54106 .48775 .54034 .49345 .53442 .49026 .53534 Metetra
.85 .996 .825 r
.49026 .53534 .49345 .53442 .49915 .52842 .49598 .52941 Metetra
.85 .997 .819 r
.49598 .52941 .49915 .52842 .50485 .52247 .50169 .52339 Metetra
.85 .997 .822 r
.50169 .52339 .50485 .52247 .51054 .51667 .50741 .51742 Metetra
.849 .995 .834 r
.50741 .51742 .51054 .51667 .51623 .51112 .51312 .51162 Metetra
.847 .99 .851 r
.51312 .51162 .51623 .51112 .52192 .50588 .51882 .50605 Metetra
.843 .981 .87 r
.51882 .50605 .52192 .50588 .52761 .50099 .52453 .50079 Metetra
.834 .967 .889 r
.52453 .50079 .52761 .50099 .53331 .49647 .53024 .49588 Metetra
.822 .948 .904 r
.53024 .49588 .53331 .49647 .539 .4923 .53595 .49132 Metetra
.807 .925 .914 r
.53595 .49132 .539 .4923 .5447 .48849 .54166 .48713 Metetra
.789 .899 .92 r
.54166 .48713 .5447 .48849 .55041 .48501 .54738 .48328 Metetra
.771 .873 .922 r
.54738 .48328 .55041 .48501 .55613 .48182 .55311 .47976 Metetra
.754 .848 .921 r
.55311 .47976 .55613 .48182 .56186 .47888 .55884 .47652 Metetra
.738 .825 .919 r
.55884 .47652 .56186 .47888 .5676 .47617 .56459 .47354 Metetra
.724 .804 .915 r
.56459 .47354 .5676 .47617 .57335 .47363 .57035 .47078 Metetra
.711 .787 .911 r
.57035 .47078 .57335 .47363 .57911 .47125 .57612 .4682 Metetra
.701 .772 .907 r
.57612 .4682 .57911 .47125 .58489 .46899 .5819 .46578 Metetra
.692 .76 .903 r
.5819 .46578 .58489 .46899 .59067 .46682 .58769 .46348 Metetra
.685 .75 .901 r
.58769 .46348 .59067 .46682 .59647 .46473 .5935 .4613 Metetra
.679 .743 .899 r
.5935 .4613 .59647 .46473 .60228 .4627 .59932 .45921 Metetra
.674 .739 .899 r
.59932 .45921 .60228 .4627 .60811 .46072 .60515 .45721 Metetra
.669 .736 .9 r
.60515 .45721 .60811 .46072 .61395 .45879 .611 .45528 Metetra
.663 .735 .903 r
.611 .45528 .61395 .45879 .6198 .4569 .61686 .45344 Metetra
.658 .736 .907 r
.61686 .45344 .6198 .4569 .62567 .45507 .62273 .45167 Metetra
.651 .739 .913 r
.62273 .45167 .62567 .45507 .63155 .45329 .62862 .45 Metetra
.643 .743 .921 r
.62862 .45 .63155 .45329 .63744 .45159 .63453 .44843 Metetra
.633 .748 .931 r
.63453 .44843 .63744 .45159 .64335 .44999 .64046 .44699 Metetra
.619 .755 .943 r
.64046 .44699 .64335 .44999 .64928 .4485 .6464 .44568 Metetra
.6 .762 .956 r
.6464 .44568 .64928 .4485 .65523 .44715 .65237 .44453 Metetra
.575 .768 .97 r
.65237 .44453 .65523 .44715 .6612 .44596 .65836 .44356 Metetra
.542 .772 .983 r
.65836 .44356 .6612 .44596 .6672 .44497 .66437 .4428 Metetra
.496 .772 .993 r
.66437 .4428 .6672 .44497 .67322 .44419 .67042 .44227 Metetra
.436 .765 .996 r
.67042 .44227 .67322 .44419 .67926 .44365 .67649 .44199 Metetra
.359 .745 .987 r
.67649 .44199 .67926 .44365 .68534 .44338 .68259 .44196 Metetra
.265 .71 .96 r
.68259 .44196 .68534 .44338 .69146 .44338 .68873 .44221 Metetra
.159 .659 .912 r
.68873 .44221 .69146 .44338 .6976 .44365 .6949 .44272 Metetra
.052 .594 .846 r
.6949 .44272 .6976 .44365 .70379 .4442 .7011 .44349 Metetra
0 .526 .771 r
.7011 .44349 .70379 .4442 .71001 .44501 .70735 .44449 Metetra
0 .464 .7 r
.70735 .44449 .71001 .44501 .71626 .44603 .71363 .44567 Metetra
.184 0 0 r
.71363 .44567 .71626 .44603 .72255 .44724 .71994 .44698 Metetra
.216 0 0 r
.71994 .44698 .72255 .44724 .72888 .44858 .72628 .44837 Metetra
.222 0 0 r
.72628 .44837 .72888 .44858 .73523 .44997 .73264 .44974 Metetra
.201 0 0 r
.73264 .44974 .73523 .44997 .74161 .45134 .73903 .45102 Metetra
.149 0 0 r
.73903 .45102 .74161 .45134 .74801 .45261 .74543 .45213 Metetra
0 .52 .737 r
.74543 .45213 .74801 .45261 .75442 .45369 .75184 .45298 Metetra
.062 .611 .831 r
.75184 .45298 .75442 .45369 .76084 .45451 .75825 .45349 Metetra
.212 .704 .922 r
.75825 .45349 .76084 .45451 .76726 .45499 .76465 .4536 Metetra
.366 .774 .982 r
.76465 .4536 .76726 .45499 .77367 .45506 .77104 .45324 Metetra
.496 .808 1 r
.77104 .45324 .77367 .45506 .78006 .45468 .77742 .45239 Metetra
.589 .811 .984 r
.77742 .45239 .78006 .45468 .78644 .4538 .78376 .45102 Metetra
.65 .796 .952 r
.78376 .45102 .78644 .4538 .79279 .45241 .79009 .44912 Metetra
.688 .775 .917 r
.79009 .44912 .79279 .45241 .79912 .4505 .79638 .44672 Metetra
.711 .753 .885 r
.79638 .44672 .79912 .4505 .80541 .4481 .80265 .44384 Metetra
.725 .733 .857 r
.80265 .44384 .80541 .4481 .81168 .44522 .80889 .44052 Metetra
.734 .717 .835 r
.80889 .44052 .81168 .44522 .81792 .44192 .81511 .43682 Metetra
.739 .703 .817 r
.81511 .43682 .81792 .44192 .82414 .43824 .8213 .43279 Metetra
.741 .691 .804 r
.8213 .43279 .82414 .43824 .83033 .43425 .82747 .42851 Metetra
.742 .683 .793 r
.82747 .42851 .83033 .43425 .83651 .43 .83364 .42403 Metetra
.742 .676 .786 r
.83364 .42403 .83651 .43 .84267 .42556 .83979 .41942 Metetra
.741 .671 .781 r
.83979 .41942 .84267 .42556 .84882 .42099 .84594 .41474 Metetra
.74 .667 .779 r
.84594 .41474 .84882 .42099 .85497 .41634 .85209 .41003 Metetra
.738 .665 .778 r
.85209 .41003 .85497 .41634 .86112 .41168 .85825 .40536 Metetra
.736 .664 .779 r
.85825 .40536 .86112 .41168 .86728 .40704 .86442 .40076 Metetra
.734 .664 .781 r
.86442 .40076 .86728 .40704 .87345 .40247 .8706 .39625 Metetra
.732 .665 .785 r
.8706 .39625 .87345 .40247 .87963 .39799 .8768 .39187 Metetra
.729 .667 .789 r
.8768 .39187 .87963 .39799 .88584 .39364 .88302 .38764 Metetra
.726 .67 .794 r
.88302 .38764 .88584 .39364 .89206 .38943 .88927 .38356 Metetra
.723 .673 .8 r
.88927 .38356 .89206 .38943 .8983 .38536 .89554 .37964 Metetra
.72 .676 .807 r
.89554 .37964 .8983 .38536 .90457 .38146 .90184 .37588 Metetra
.717 .68 .814 r
.90184 .37588 .90457 .38146 .91087 .37771 .90816 .37229 Metetra
.713 .684 .821 r
.90816 .37229 .91087 .37771 .9172 .37412 .91451 .36885 Metetra
.71 .689 .828 r
.91451 .36885 .9172 .37412 .92355 .37069 .92089 .36555 Metetra
.624 .694 .894 r
.33471 .53998 .338 .54367 .34326 .54273 .33999 .53887 Metetra
.614 .681 .89 r
.33999 .53887 .34326 .54273 .34853 .54197 .34527 .53791 Metetra
.601 .666 .885 r
.34527 .53791 .34853 .54197 .3538 .54144 .35056 .53715 Metetra
.586 .649 .879 r
.35056 .53715 .3538 .54144 .35907 .54116 .35585 .5366 Metetra
.569 .629 .872 r
.35585 .5366 .35907 .54116 .36435 .54117 .36114 .53631 Metetra
.55 .607 .863 r
.36114 .53631 .36435 .54117 .36962 .5415 .36643 .53631 Metetra
.53 .584 .853 r
.36643 .53631 .36962 .5415 .3749 .54217 .37172 .53664 Metetra
.509 .56 .843 r
.37172 .53664 .3749 .54217 .38018 .54321 .37702 .53731 Metetra
.488 .535 .832 r
.37702 .53731 .38018 .54321 .38546 .5446 .38232 .53835 Metetra
.468 .512 .821 r
.38232 .53835 .38546 .5446 .39075 .54634 .38762 .53975 Metetra
.449 .491 .811 r
.38762 .53975 .39075 .54634 .39606 .54838 .39293 .54149 Metetra
.434 .473 .802 r
.39293 .54149 .39606 .54838 .40137 .55066 .39825 .54353 Metetra
.422 .46 .795 r
.39825 .54353 .40137 .55066 .4067 .5531 .40358 .54582 Metetra
.414 .452 .79 r
.40358 .54582 .4067 .5531 .41206 .55559 .40894 .54827 Metetra
.412 .449 .79 r
.40894 .54827 .41206 .55559 .41744 .55801 .41431 .55078 Metetra
.416 .454 .792 r
.41431 .55078 .41744 .55801 .42286 .56022 .41972 .5532 Metetra
.426 .467 .8 r
.41972 .5532 .42286 .56022 .42831 .56207 .42515 .55541 Metetra
.445 .489 .811 r
.42515 .55541 .42831 .56207 .43379 .56341 .43062 .55725 Metetra
.472 .521 .828 r
.43062 .55725 .43379 .56341 .43931 .56412 .43613 .55859 Metetra
.507 .564 .848 r
.43613 .55859 .43931 .56412 .44487 .56407 .44167 .55928 Metetra
.552 .617 .871 r
.44167 .55928 .44487 .56407 .45047 .56321 .44725 .55922 Metetra
.604 .68 .895 r
.44725 .55922 .45047 .56321 .45609 .56147 .45286 .55833 Metetra
.662 .75 .916 r
.45286 .55833 .45609 .56147 .46175 .55887 .45851 .55657 Metetra
.718 .82 .928 r
.45851 .55657 .46175 .55887 .46742 .55543 .46418 .55394 Metetra
.769 .882 .928 r
.46418 .55394 .46742 .55543 .47312 .55124 .46988 .55048 Metetra
.807 .932 .915 r
.46988 .55048 .47312 .55124 .47883 .54641 .47559 .54627 Metetra
.831 .965 .892 r
.47559 .54627 .47883 .54641 .48454 .54106 .48132 .54141 Metetra
.844 .984 .865 r
.48132 .54141 .48454 .54106 .49026 .53534 .48705 .53605 Metetra
.849 .993 .841 r
.48705 .53605 .49026 .53534 .49598 .52941 .49278 .53032 Metetra
.85 .996 .825 r
.49278 .53032 .49598 .52941 .50169 .52339 .49852 .52437 Metetra
.849 .997 .819 r
.49852 .52437 .50169 .52339 .50741 .51742 .50425 .51834 Metetra
.849 .997 .822 r
.50425 .51834 .50741 .51742 .51312 .51162 .50998 .51236 Metetra
.848 .995 .833 r
.50998 .51236 .51312 .51162 .51882 .50605 .5157 .50654 Metetra
.846 .991 .85 r
.5157 .50654 .51882 .50605 .52453 .50079 .52143 .50097 Metetra
.842 .982 .87 r
.52143 .50097 .52453 .50079 .53024 .49588 .52715 .4957 Metetra
.833 .969 .888 r
.52715 .4957 .53024 .49588 .53595 .49132 .53288 .49077 Metetra
.821 .951 .904 r
.53288 .49077 .53595 .49132 .54166 .48713 .5386 .4862 Metetra
.806 .929 .915 r
.5386 .4862 .54166 .48713 .54738 .48328 .54434 .48199 Metetra
.789 .906 .922 r
.54434 .48199 .54738 .48328 .55311 .47976 .55007 .47813 Metetra
.771 .882 .926 r
.55007 .47813 .55311 .47976 .55884 .47652 .55582 .47459 Metetra
.754 .859 .927 r
.55582 .47459 .55884 .47652 .56459 .47354 .56157 .47135 Metetra
.737 .839 .927 r
.56157 .47135 .56459 .47354 .57035 .47078 .56734 .46838 Metetra
.723 .821 .926 r
.56734 .46838 .57035 .47078 .57612 .4682 .57312 .46563 Metetra
.71 .807 .926 r
.57312 .46563 .57612 .4682 .5819 .46578 .5789 .46308 Metetra
.698 .796 .926 r
.5789 .46308 .5819 .46578 .58769 .46348 .58471 .46071 Metetra
.688 .789 .927 r
.58471 .46071 .58769 .46348 .5935 .4613 .59052 .45849 Metetra
.679 .784 .929 r
.59052 .45849 .5935 .4613 .59932 .45921 .59635 .45639 Metetra
.67 .782 .933 r
.59635 .45639 .59932 .45921 .60515 .45721 .60219 .45442 Metetra
.662 .782 .938 r
.60219 .45442 .60515 .45721 .611 .45528 .60805 .45255 Metetra
.653 .784 .944 r
.60805 .45255 .611 .45528 .61686 .45344 .61392 .45078 Metetra
.644 .787 .951 r
.61392 .45078 .61686 .45344 .62273 .45167 .61981 .44911 Metetra
.632 .791 .958 r
.61981 .44911 .62273 .45167 .62862 .45 .62572 .44755 Metetra
.619 .795 .967 r
.62572 .44755 .62862 .45 .63453 .44843 .63164 .4461 Metetra
.602 .799 .975 r
.63164 .4461 .63453 .44843 .64046 .44699 .63758 .44477 Metetra
.581 .802 .983 r
.63758 .44477 .64046 .44699 .6464 .44568 .64354 .44359 Metetra
.554 .802 .991 r
.64354 .44359 .6464 .44568 .65237 .44453 .64952 .44257 Metetra
.52 .799 .997 r
.64952 .44257 .65237 .44453 .65836 .44356 .65553 .44174 Metetra
.477 .792 .999 r
.65553 .44174 .65836 .44356 .66437 .4428 .66156 .44112 Metetra
.422 .777 .996 r
.66156 .44112 .66437 .4428 .67042 .44227 .66762 .44074 Metetra
.355 .754 .985 r
.66762 .44074 .67042 .44227 .67649 .44199 .67371 .44062 Metetra
.275 .72 .961 r
.67371 .44062 .67649 .44199 .68259 .44196 .67983 .44076 Metetra
.185 .674 .924 r
.67983 .44076 .68259 .44196 .68873 .44221 .68599 .44119 Metetra
.09 .618 .872 r
.68599 .44119 .68873 .44221 .6949 .44272 .69218 .44187 Metetra
0 .557 .81 r
.69218 .44187 .6949 .44272 .7011 .44349 .69841 .4428 Metetra
0 .498 .747 r
.69841 .4428 .7011 .44349 .70735 .44449 .70467 .44394 Metetra
.143 0 0 r
.70467 .44394 .70735 .44449 .71363 .44567 .71097 .44523 Metetra
.181 0 0 r
.71097 .44523 .71363 .44567 .71994 .44698 .7173 .44661 Metetra
.194 0 0 r
.7173 .44661 .71994 .44698 .72628 .44837 .72365 .448 Metetra
.18 0 0 r
.72365 .448 .72628 .44837 .73264 .44974 .73003 .44932 Metetra
.135 0 0 r
.73003 .44932 .73264 .44974 .73903 .45102 .73642 .45047 Metetra
0 .524 .75 r
.73642 .45047 .73903 .45102 .74543 .45213 .74282 .45136 Metetra
.062 .609 .836 r
.74282 .45136 .74543 .45213 .75184 .45298 .74922 .45193 Metetra
.207 .699 .922 r
.74922 .45193 .75184 .45298 .75825 .45349 .75562 .45208 Metetra
.359 .769 .981 r
.75562 .45208 .75825 .45349 .76465 .4536 .762 .45178 Metetra
.49 .805 1 r
.762 .45178 .76465 .4536 .77104 .45324 .76837 .45096 Metetra
.585 .81 .985 r
.76837 .45096 .77104 .45324 .77742 .45239 .77472 .44962 Metetra
.648 .797 .954 r
.77472 .44962 .77742 .45239 .78376 .45102 .78104 .44774 Metetra
.688 .776 .918 r
.78104 .44774 .78376 .45102 .79009 .44912 .78734 .44534 Metetra
.712 .754 .885 r
.78734 .44534 .79009 .44912 .79638 .44672 .7936 .44246 Metetra
.726 .734 .857 r
.7936 .44246 .79638 .44672 .80265 .44384 .79984 .43912 Metetra
.734 .717 .834 r
.79984 .43912 .80265 .44384 .80889 .44052 .80606 .4354 Metetra
.739 .702 .816 r
.80606 .4354 .80889 .44052 .81511 .43682 .81225 .43134 Metetra
.742 .691 .803 r
.81225 .43134 .81511 .43682 .8213 .43279 .81842 .42702 Metetra
.743 .682 .792 r
.81842 .42702 .8213 .43279 .82747 .42851 .82458 .4225 Metetra
.743 .675 .785 r
.82458 .4225 .82747 .42851 .83364 .42403 .83074 .41785 Metetra
.742 .67 .78 r
.83074 .41785 .83364 .42403 .83979 .41942 .83689 .41313 Metetra
.74 .666 .778 r
.83689 .41313 .83979 .41942 .84594 .41474 .84304 .40839 Metetra
.739 .664 .777 r
.84304 .40839 .84594 .41474 .85209 .41003 .8492 .40368 Metetra
.737 .663 .778 r
.8492 .40368 .85209 .41003 .85825 .40536 .85537 .39904 Metetra
.734 .664 .78 r
.85537 .39904 .85825 .40536 .86442 .40076 .86155 .3945 Metetra
.732 .665 .784 r
.86155 .3945 .86442 .40076 .8706 .39625 .86775 .3901 Metetra
.729 .666 .788 r
.86775 .3901 .8706 .39625 .8768 .39187 .87397 .38584 Metetra
.726 .669 .794 r
.87397 .38584 .8768 .39187 .88302 .38764 .88022 .38175 Metetra
.723 .672 .8 r
.88022 .38175 .88302 .38764 .88927 .38356 .88649 .37781 Metetra
.72 .676 .806 r
.88649 .37781 .88927 .38356 .89554 .37964 .89279 .37405 Metetra
.717 .68 .814 r
.89279 .37405 .89554 .37964 .90184 .37588 .89911 .37045 Metetra
.713 .684 .821 r
.89911 .37045 .90184 .37588 .90816 .37229 .90546 .367 Metetra
.71 .689 .828 r
.90546 .367 .90816 .37229 .91451 .36885 .91184 .36371 Metetra
.706 .693 .835 r
.91184 .36371 .91451 .36885 .92089 .36555 .91824 .36055 Metetra
.633 .705 .898 r
.3314 .53641 .33471 .53998 .33999 .53887 .33669 .53516 Metetra
.625 .695 .895 r
.33669 .53516 .33999 .53887 .34527 .53791 .34199 .53404 Metetra
.614 .682 .891 r
.34199 .53404 .34527 .53791 .35056 .53715 .34729 .53307 Metetra
.601 .667 .886 r
.34729 .53307 .35056 .53715 .35585 .5366 .3526 .5323 Metetra
.586 .649 .879 r
.3526 .5323 .35585 .5366 .36114 .53631 .3579 .53174 Metetra
.569 .629 .872 r
.3579 .53174 .36114 .53631 .36643 .53631 .36321 .53144 Metetra
.55 .607 .863 r
.36321 .53144 .36643 .53631 .37172 .53664 .36852 .53144 Metetra
.53 .584 .854 r
.36852 .53144 .37172 .53664 .37702 .53731 .37383 .53176 Metetra
.509 .559 .843 r
.37383 .53176 .37702 .53731 .38232 .53835 .37915 .53243 Metetra
.487 .535 .832 r
.37915 .53243 .38232 .53835 .38762 .53975 .38446 .53347 Metetra
.467 .512 .821 r
.38446 .53347 .38762 .53975 .39293 .54149 .38979 .53487 Metetra
.449 .491 .81 r
.38979 .53487 .39293 .54149 .39825 .54353 .39512 .53661 Metetra
.433 .473 .801 r
.39512 .53661 .39825 .54353 .40358 .54582 .40046 .53867 Metetra
.421 .459 .794 r
.40046 .53867 .40358 .54582 .40894 .54827 .40581 .54096 Metetra
.414 .451 .79 r
.40581 .54096 .40894 .54827 .41431 .55078 .41119 .54342 Metetra
.411 .449 .789 r
.41119 .54342 .41431 .55078 .41972 .5532 .41658 .54593 Metetra
.415 .454 .792 r
.41658 .54593 .41972 .5532 .42515 .55541 .42201 .54836 Metetra
.426 .467 .799 r
.42201 .54836 .42515 .55541 .43062 .55725 .42746 .55056 Metetra
.445 .489 .811 r
.42746 .55056 .43062 .55725 .43613 .55859 .43295 .5524 Metetra
.472 .522 .827 r
.43295 .5524 .43613 .55859 .44167 .55928 .43848 .55373 Metetra
.508 .564 .848 r
.43848 .55373 .44167 .55928 .44725 .55922 .44404 .5544 Metetra
.553 .618 .871 r
.44404 .5544 .44725 .55922 .45286 .55833 .44964 .55433 Metetra
.605 .681 .895 r
.44964 .55433 .45286 .55833 .45851 .55657 .45528 .55342 Metetra
.662 .751 .916 r
.45528 .55342 .45851 .55657 .46418 .55394 .46094 .55163 Metetra
.719 .82 .928 r
.46094 .55163 .46418 .55394 .46988 .55048 .46663 .54898 Metetra
.769 .883 .928 r
.46663 .54898 .46988 .55048 .47559 .54627 .47235 .5455 Metetra
.807 .932 .915 r
.47235 .5455 .47559 .54627 .48132 .54141 .47808 .54127 Metetra
.831 .966 .892 r
.47808 .54127 .48132 .54141 .48705 .53605 .48382 .5364 Metetra
.843 .985 .865 r
.48382 .5364 .48705 .53605 .49278 .53032 .48957 .53103 Metetra
.847 .994 .841 r
.48957 .53103 .49278 .53032 .49852 .52437 .49532 .52529 Metetra
.847 .997 .824 r
.49532 .52529 .49852 .52437 .50425 .51834 .50107 .51935 Metetra
.846 .998 .817 r
.50107 .51935 .50425 .51834 .50998 .51236 .50682 .51333 Metetra
.844 .998 .819 r
.50682 .51333 .50998 .51236 .5157 .50654 .51256 .50736 Metetra
.842 .997 .83 r
.51256 .50736 .5157 .50654 .52143 .50097 .51831 .50156 Metetra
.839 .994 .846 r
.51831 .50156 .52143 .50097 .52715 .4957 .52405 .49601 Metetra
.833 .988 .866 r
.52405 .49601 .52715 .4957 .53288 .49077 .52979 .49076 Metetra
.825 .979 .886 r
.52979 .49076 .53288 .49077 .5386 .4862 .53553 .48587 Metetra
.813 .966 .904 r
.53553 .48587 .5386 .4862 .54434 .48199 .54128 .48134 Metetra
.798 .95 .92 r
.54128 .48134 .54434 .48199 .55007 .47813 .54703 .47718 Metetra
.781 .932 .932 r
.54703 .47718 .55007 .47813 .55582 .47459 .55279 .47338 Metetra
.763 .913 .94 r
.55279 .47338 .55582 .47459 .56157 .47135 .55855 .46991 Metetra
.745 .896 .947 r
.55855 .46991 .56157 .47135 .56734 .46838 .56433 .46675 Metetra
.727 .881 .952 r
.56433 .46675 .56734 .46838 .57312 .46563 .57011 .46385 Metetra
.711 .868 .956 r
.57011 .46385 .57312 .46563 .5789 .46308 .57591 .4612 Metetra
.696 .857 .959 r
.57591 .4612 .5789 .46308 .58471 .46071 .58172 .45875 Metetra
.683 .849 .963 r
.58172 .45875 .58471 .46071 .59052 .45849 .58755 .45648 Metetra
.67 .843 .966 r
.58755 .45648 .59052 .45849 .59635 .45639 .59339 .45435 Metetra
.659 .838 .969 r
.59339 .45435 .59635 .45639 .60219 .45442 .59924 .45235 Metetra
.649 .834 .971 r
.59924 .45235 .60219 .45442 .60805 .45255 .60511 .45047 Metetra
.64 .831 .974 r
.60511 .45047 .60805 .45255 .61392 .45078 .61099 .44868 Metetra
.63 .827 .976 r
.61099 .44868 .61392 .45078 .61981 .44911 .61689 .44699 Metetra
.62 .823 .978 r
.61689 .44699 .61981 .44911 .62572 .44755 .62281 .4454 Metetra
.609 .818 .98 r
.62281 .4454 .62572 .44755 .63164 .4461 .62874 .44393 Metetra
.595 .812 .983 r
.62874 .44393 .63164 .4461 .63758 .44477 .63469 .44259 Metetra
.578 .804 .985 r
.63469 .44259 .63758 .44477 .64354 .44359 .64066 .4414 Metetra
.556 .796 .988 r
.64066 .4414 .64354 .44359 .64952 .44257 .64666 .4404 Metetra
.528 .787 .992 r
.64666 .4404 .64952 .44257 .65553 .44174 .65267 .43961 Metetra
.491 .775 .995 r
.65267 .43961 .65553 .44174 .66156 .44112 .65872 .43908 Metetra
.443 .759 .995 r
.65872 .43908 .66156 .44112 .66762 .44074 .66479 .43882 Metetra
.382 .738 .991 r
.66479 .43882 .66762 .44074 .67371 .44062 .6709 .43885 Metetra
.306 .709 .977 r
.6709 .43885 .67371 .44062 .67983 .44076 .67704 .43918 Metetra
.216 .668 .949 r
.67704 .43918 .67983 .44076 .68599 .44119 .68322 .43981 Metetra
.118 .617 .904 r
.68322 .43981 .68599 .44119 .69218 .44187 .68943 .44072 Metetra
.021 .56 .846 r
.68943 .44072 .69218 .44187 .69841 .4428 .69568 .44186 Metetra
0 .503 .782 r
.69568 .44186 .69841 .4428 .70467 .44394 .70197 .44319 Metetra
0 .458 .725 r
.70197 .44319 .70467 .44394 .71097 .44523 .70829 .44462 Metetra
.16 0 0 r
.70829 .44462 .71097 .44523 .7173 .44661 .71463 .44608 Metetra
.163 0 0 r
.71463 .44608 .7173 .44661 .72365 .448 .721 .44748 Metetra
0 .458 .696 r
.721 .44748 .72365 .448 .73003 .44932 .72738 .44872 Metetra
0 .514 .748 r
.72738 .44872 .73003 .44932 .73642 .45047 .73378 .4497 Metetra
.042 .595 .826 r
.73378 .4497 .73642 .45047 .74282 .45136 .74018 .45035 Metetra
.184 .686 .911 r
.74018 .45035 .74282 .45136 .74922 .45193 .74657 .45058 Metetra
.338 .762 .975 r
.74657 .45058 .74922 .45193 .75562 .45208 .75295 .45033 Metetra
.476 .804 1 r
.75295 .45033 .75562 .45208 .762 .45178 .75932 .44956 Metetra
.578 .813 .988 r
.75932 .44956 .762 .45178 .76837 .45096 .76566 .44825 Metetra
.646 .8 .957 r
.76566 .44825 .76837 .45096 .77472 .44962 .77198 .44639 Metetra
.687 .779 .921 r
.77198 .44639 .77472 .44962 .78104 .44774 .77827 .444 Metetra
.712 .756 .887 r
.77827 .444 .78104 .44774 .78734 .44534 .78454 .4411 Metetra
.727 .735 .858 r
.78454 .4411 .78734 .44534 .7936 .44246 .79077 .43775 Metetra
.736 .717 .834 r
.79077 .43775 .7936 .44246 .79984 .43912 .79699 .43399 Metetra
.74 .703 .816 r
.79699 .43399 .79984 .43912 .80606 .4354 .80318 .4299 Metetra
.743 .691 .802 r
.80318 .4299 .80606 .4354 .81225 .43134 .80935 .42554 Metetra
.743 .682 .791 r
.80935 .42554 .81225 .43134 .81842 .42702 .81552 .42098 Metetra
.743 .674 .784 r
.81552 .42098 .81842 .42702 .82458 .4225 .82167 .41628 Metetra
.742 .669 .779 r
.82167 .41628 .82458 .4225 .83074 .41785 .82782 .41152 Metetra
.741 .666 .776 r
.82782 .41152 .83074 .41785 .83689 .41313 .83397 .40673 Metetra
.739 .663 .776 r
.83397 .40673 .83689 .41313 .84304 .40839 .84013 .40199 Metetra
.737 .663 .777 r
.84013 .40199 .84304 .40839 .8492 .40368 .8463 .39732 Metetra
.735 .663 .779 r
.8463 .39732 .8492 .40368 .85537 .39904 .85248 .39275 Metetra
.732 .664 .783 r
.85248 .39275 .85537 .39904 .86155 .3945 .85868 .38832 Metetra
.729 .666 .788 r
.85868 .38832 .86155 .3945 .86775 .3901 .86491 .38404 Metetra
.726 .669 .793 r
.86491 .38404 .86775 .3901 .87397 .38584 .87115 .37993 Metetra
.723 .672 .799 r
.87115 .37993 .87397 .38584 .88022 .38175 .87742 .37599 Metetra
.72 .676 .806 r
.87742 .37599 .88022 .38175 .88649 .37781 .88372 .37221 Metetra
.717 .68 .813 r
.88372 .37221 .88649 .37781 .89279 .37405 .89004 .3686 Metetra
.713 .684 .821 r
.89004 .3686 .89279 .37405 .89911 .37045 .89639 .36515 Metetra
.709 .689 .828 r
.89639 .36515 .89911 .37045 .90546 .367 .90277 .36185 Metetra
.706 .693 .836 r
.90277 .36185 .90546 .367 .91184 .36371 .90918 .3587 Metetra
.702 .698 .843 r
.90918 .3587 .91184 .36371 .91824 .36055 .91561 .35567 Metetra
.641 .714 .9 r
.32807 .53294 .3314 .53641 .33669 .53516 .33338 .53158 Metetra
.634 .705 .898 r
.33338 .53158 .33669 .53516 .34199 .53404 .33869 .53032 Metetra
.625 .695 .895 r
.33869 .53032 .34199 .53404 .34729 .53307 .344 .52919 Metetra
.614 .682 .891 r
.344 .52919 .34729 .53307 .3526 .5323 .34932 .52821 Metetra
.601 .667 .886 r
.34932 .52821 .3526 .5323 .3579 .53174 .35465 .52742 Metetra
.586 .65 .88 r
.35465 .52742 .3579 .53174 .36321 .53144 .35997 .52685 Metetra
.569 .63 .872 r
.35997 .52685 .36321 .53144 .36852 .53144 .3653 .52655 Metetra
.55 .608 .863 r
.3653 .52655 .36852 .53144 .37383 .53176 .37063 .52653 Metetra
.53 .584 .854 r
.37063 .52653 .37383 .53176 .37915 .53243 .37596 .52685 Metetra
.508 .559 .843 r
.37596 .52685 .37915 .53243 .38446 .53347 .38129 .52752 Metetra
.487 .535 .832 r
.38129 .52752 .38446 .53347 .38979 .53487 .38663 .52856 Metetra
.467 .511 .82 r
.38663 .52856 .38979 .53487 .39512 .53661 .39197 .52996 Metetra
.448 .49 .81 r
.39197 .52996 .39512 .53661 .40046 .53867 .39732 .53171 Metetra
.432 .472 .801 r
.39732 .53171 .40046 .53867 .40581 .54096 .40268 .53377 Metetra
.42 .459 .794 r
.40268 .53377 .40581 .54096 .41119 .54342 .40805 .53608 Metetra
.413 .45 .79 r
.40805 .53608 .41119 .54342 .41658 .54593 .41345 .53854 Metetra
.411 .448 .789 r
.41345 .53854 .41658 .54593 .42201 .54836 .41886 .54105 Metetra
.415 .454 .792 r
.41886 .54105 .42201 .54836 .42746 .55056 .42431 .54348 Metetra
.426 .467 .799 r
.42431 .54348 .42746 .55056 .43295 .5524 .42979 .54569 Metetra
.445 .489 .811 r
.42979 .54569 .43295 .5524 .43848 .55373 .4353 .54752 Metetra
.472 .522 .827 r
.4353 .54752 .43848 .55373 .44404 .5544 .44085 .54883 Metetra
.509 .565 .848 r
.44085 .54883 .44404 .5544 .44964 .55433 .44643 .54949 Metetra
.554 .618 .871 r
.44643 .54949 .44964 .55433 .45528 .55342 .45205 .5494 Metetra
.606 .682 .895 r
.45205 .5494 .45528 .55342 .46094 .55163 .45771 .54846 Metetra
.663 .751 .915 r
.45771 .54846 .46094 .55163 .46663 .54898 .46339 .54666 Metetra
.72 .821 .928 r
.46339 .54666 .46663 .54898 .47235 .5455 .4691 .54399 Metetra
.769 .883 .928 r
.4691 .54399 .47235 .5455 .47808 .54127 .47483 .54049 Metetra
.807 .932 .915 r
.47483 .54049 .47808 .54127 .48382 .5364 .48058 .53624 Metetra
.831 .966 .892 r
.48058 .53624 .48382 .5364 .48957 .53103 .48634 .53137 Metetra
.842 .985 .865 r
.48634 .53137 .48957 .53103 .49532 .52529 .4921 .52599 Metetra
.846 .994 .841 r
.4921 .52599 .49532 .52529 .50107 .51935 .49787 .52026 Metetra
.845 .997 .824 r
.49787 .52026 .50107 .51935 .50682 .51333 .50364 .51433 Metetra
.842 .998 .817 r
.50364 .51433 .50682 .51333 .51256 .50736 .5094 .50833 Metetra
.84 .999 .819 r
.5094 .50833 .51256 .50736 .51831 .50156 .51517 .5024 Metetra
.837 .998 .829 r
.51517 .5024 .51831 .50156 .52405 .49601 .52093 .49663 Metetra
.832 .996 .845 r
.52093 .49663 .52405 .49601 .52979 .49076 .52669 .49112 Metetra
.826 .991 .865 r
.52669 .49112 .52979 .49076 .53553 .48587 .53244 .48593 Metetra
.817 .983 .886 r
.53244 .48593 .53553 .48587 .54128 .48134 .53821 .48109 Metetra
.805 .971 .906 r
.53821 .48109 .54128 .48134 .54703 .47718 .54397 .47662 Metetra
.791 .956 .922 r
.54397 .47662 .54703 .47718 .55279 .47338 .54974 .47251 Metetra
.774 .938 .935 r
.54974 .47251 .55279 .47338 .55855 .46991 .55552 .46876 Metetra
.757 .919 .944 r
.55552 .46876 .55855 .46991 .56433 .46675 .5613 .46533 Metetra
.741 .899 .95 r
.5613 .46533 .56433 .46675 .57011 .46385 .5671 .4622 Metetra
.726 .88 .952 r
.5671 .4622 .57011 .46385 .57591 .4612 .57291 .45932 Metetra
.712 .861 .953 r
.57291 .45932 .57591 .4612 .58172 .45875 .57873 .45665 Metetra
.7 .843 .951 r
.57873 .45665 .58172 .45875 .58755 .45648 .58456 .45418 Metetra
.691 .826 .948 r
.58456 .45418 .58755 .45648 .59339 .45435 .5904 .45185 Metetra
.682 .81 .944 r
.5904 .45185 .59339 .45435 .59924 .45235 .59626 .44966 Metetra
.675 .795 .938 r
.59626 .44966 .59924 .45235 .60511 .45047 .60214 .44759 Metetra
.668 .78 .933 r
.60214 .44759 .60511 .45047 .61099 .44868 .60803 .44562 Metetra
.66 .766 .928 r
.60803 .44562 .61099 .44868 .61689 .44699 .61393 .44378 Metetra
.652 .753 .924 r
.61393 .44378 .61689 .44699 .62281 .4454 .61985 .44206 Metetra
.641 .741 .921 r
.61985 .44206 .62281 .4454 .62874 .44393 .62579 .44049 Metetra
.629 .731 .921 r
.62579 .44049 .62874 .44393 .63469 .44259 .63175 .43911 Metetra
.612 .723 .925 r
.63175 .43911 .63469 .44259 .64066 .4414 .63773 .43795 Metetra
.591 .717 .931 r
.63773 .43795 .64066 .4414 .64666 .4404 .64373 .43704 Metetra
.563 .712 .941 r
.64373 .43704 .64666 .4404 .65267 .43961 .64976 .43643 Metetra
.526 .708 .954 r
.64976 .43643 .65267 .43961 .65872 .43908 .65583 .43612 Metetra
.476 .703 .968 r
.65583 .43612 .65872 .43908 .66479 .43882 .66192 .43616 Metetra
.408 .692 .978 r
.66192 .43616 .66479 .43882 .6709 .43885 .66805 .43654 Metetra
.318 .672 .976 r
.66805 .43654 .6709 .43885 .67704 .43918 .67422 .43724 Metetra
.206 .635 .95 r
.67422 .43724 .67704 .43918 .68322 .43981 .68043 .43826 Metetra
.081 .579 .895 r
.68043 .43826 .68322 .43981 .68943 .44072 .68667 .43952 Metetra
0 .512 .816 r
.68667 .43952 .68943 .44072 .69568 .44186 .69295 .44099 Metetra
0 .45 .734 r
.69295 .44099 .69568 .44186 .70197 .44319 .69926 .44256 Metetra
.187 0 0 r
.69926 .44256 .70197 .44319 .70829 .44462 .7056 .44417 Metetra
.206 0 0 r
.7056 .44417 .70829 .44462 .71463 .44608 .71196 .4457 Metetra
.187 0 0 r
.71196 .4457 .71463 .44608 .721 .44748 .71834 .44706 Metetra
.128 0 0 r
.71834 .44706 .721 .44748 .72738 .44872 .72473 .44816 Metetra
0 .55 .768 r
.72473 .44816 .72738 .44872 .73378 .4497 .73112 .44889 Metetra
.123 .654 .869 r
.73112 .44889 .73378 .4497 .74018 .45035 .73751 .44919 Metetra
.293 .748 .955 r
.73751 .44919 .74018 .45035 .74657 .45058 .74389 .449 Metetra
.45 .806 .997 r
.74389 .449 .74657 .45058 .75295 .45033 .75025 .44826 Metetra
.567 .821 .993 r
.75025 .44826 .75295 .45033 .75932 .44956 .75659 .44697 Metetra
.643 .808 .962 r
.75659 .44697 .75932 .44956 .76566 .44825 .7629 .44511 Metetra
.688 .785 .924 r
.7629 .44511 .76566 .44825 .77198 .44639 .76919 .4427 Metetra
.714 .76 .889 r
.76919 .4427 .77198 .44639 .77827 .444 .77545 .43978 Metetra
.729 .737 .858 r
.77545 .43978 .77827 .444 .78454 .4411 .78169 .43639 Metetra
.737 .718 .834 r
.78169 .43639 .78454 .4411 .79077 .43775 .7879 .4326 Metetra
.741 .703 .815 r
.7879 .4326 .79077 .43775 .79699 .43399 .79409 .42846 Metetra
.743 .69 .8 r
.79409 .42846 .79699 .43399 .80318 .4299 .80027 .42406 Metetra
.744 .681 .79 r
.80027 .42406 .80318 .4299 .80935 .42554 .80643 .41945 Metetra
.744 .673 .782 r
.80643 .41945 .80935 .42554 .81552 .42098 .81258 .41471 Metetra
.743 .668 .778 r
.81258 .41471 .81552 .42098 .82167 .41628 .81873 .4099 Metetra
.741 .665 .775 r
.81873 .4099 .82167 .41628 .82782 .41152 .82488 .40507 Metetra
.739 .662 .775 r
.82488 .40507 .82782 .41152 .83397 .40673 .83104 .40029 Metetra
.737 .662 .776 r
.83104 .40029 .83397 .40673 .84013 .40199 .83721 .39558 Metetra
.735 .662 .778 r
.83721 .39558 .84013 .40199 .8463 .39732 .8434 .39099 Metetra
.732 .663 .782 r
.8434 .39099 .8463 .39732 .85248 .39275 .8496 .38654 Metetra
.729 .665 .787 r
.8496 .38654 .85248 .39275 .85868 .38832 .85582 .38224 Metetra
.726 .668 .792 r
.85582 .38224 .85868 .38832 .86491 .38404 .86207 .37811 Metetra
.723 .671 .799 r
.86207 .37811 .86491 .38404 .87115 .37993 .86834 .37415 Metetra
.72 .675 .806 r
.86834 .37415 .87115 .37993 .87742 .37599 .87464 .37037 Metetra
.716 .68 .813 r
.87464 .37037 .87742 .37599 .88372 .37221 .88096 .36675 Metetra
.713 .684 .821 r
.88096 .36675 .88372 .37221 .89004 .3686 .88731 .3633 Metetra
.709 .689 .828 r
.88731 .3633 .89004 .3686 .89639 .36515 .89369 .36 Metetra
.706 .693 .836 r
.89369 .36 .89639 .36515 .90277 .36185 .90009 .35684 Metetra
.702 .698 .843 r
.90009 .35684 .90277 .36185 .90918 .3587 .90652 .35382 Metetra
.698 .702 .85 r
.90652 .35382 .90918 .3587 .91561 .35567 .91298 .35091 Metetra
.647 .721 .902 r
.32473 .52955 .32807 .53294 .33338 .53158 .33005 .5281 Metetra
.641 .714 .9 r
.33005 .5281 .33338 .53158 .33869 .53032 .33537 .52673 Metetra
.634 .706 .898 r
.33537 .52673 .33869 .53032 .344 .52919 .3407 .52546 Metetra
.625 .695 .895 r
.3407 .52546 .344 .52919 .34932 .52821 .34603 .52431 Metetra
.614 .683 .891 r
.34603 .52431 .34932 .52821 .35465 .52742 .35137 .52332 Metetra
.601 .668 .886 r
.35137 .52332 .35465 .52742 .35997 .52685 .35671 .52252 Metetra
.586 .65 .88 r
.35671 .52252 .35997 .52685 .3653 .52655 .36205 .52194 Metetra
.569 .63 .872 r
.36205 .52194 .3653 .52655 .37063 .52653 .3674 .52162 Metetra
.55 .608 .864 r
.3674 .52162 .37063 .52653 .37596 .52685 .37274 .52161 Metetra
.529 .584 .854 r
.37274 .52161 .37596 .52685 .38129 .52752 .37809 .52192 Metetra
.508 .559 .843 r
.37809 .52192 .38129 .52752 .38663 .52856 .38344 .52259 Metetra
.487 .534 .832 r
.38344 .52259 .38663 .52856 .39197 .52996 .3888 .52362 Metetra
.466 .511 .82 r
.3888 .52362 .39197 .52996 .39732 .53171 .39416 .52503 Metetra
.447 .49 .81 r
.39416 .52503 .39732 .53171 .40268 .53377 .39953 .52678 Metetra
.432 .472 .801 r
.39953 .52678 .40268 .53377 .40805 .53608 .40491 .52885 Metetra
.42 .458 .794 r
.40491 .52885 .40805 .53608 .41345 .53854 .4103 .53116 Metetra
.413 .45 .79 r
.4103 .53116 .41345 .53854 .41886 .54105 .41572 .53363 Metetra
.411 .448 .789 r
.41572 .53363 .41886 .54105 .42431 .54348 .42116 .53614 Metetra
.415 .453 .792 r
.42116 .53614 .42431 .54348 .42979 .54569 .42663 .53857 Metetra
.427 .467 .799 r
.42663 .53857 .42979 .54569 .4353 .54752 .43212 .54077 Metetra
.446 .49 .811 r
.43212 .54077 .4353 .54752 .44085 .54883 .43766 .54259 Metetra
.473 .522 .827 r
.43766 .54259 .44085 .54883 .44643 .54949 .44323 .54389 Metetra
.51 .565 .848 r
.44323 .54389 .44643 .54949 .45205 .5494 .44883 .54454 Metetra
.555 .619 .871 r
.44883 .54454 .45205 .5494 .45771 .54846 .45447 .54442 Metetra
.607 .682 .895 r
.45447 .54442 .45771 .54846 .46339 .54666 .46015 .54346 Metetra
.664 .751 .915 r
.46015 .54346 .46339 .54666 .4691 .54399 .46585 .54163 Metetra
.721 .819 .926 r
.46585 .54163 .4691 .54399 .47483 .54049 .47158 .53893 Metetra
.77 .881 .926 r
.47158 .53893 .47483 .54049 .48058 .53624 .47733 .5354 Metetra
.808 .93 .914 r
.47733 .5354 .48058 .53624 .48634 .53137 .4831 .53113 Metetra
.832 .962 .892 r
.4831 .53113 .48634 .53137 .4921 .52599 .48888 .52624 Metetra
.845 .981 .868 r
.48888 .52624 .4921 .52599 .49787 .52026 .49466 .52084 Metetra
.851 .991 .846 r
.49466 .52084 .49787 .52026 .50364 .51433 .50044 .5151 Metetra
.852 .994 .832 r
.50044 .5151 .50364 .51433 .5094 .50833 .50623 .50915 Metetra
.853 .995 .827 r
.50623 .50915 .5094 .50833 .51517 .5024 .51201 .50313 Metetra
.853 .994 .831 r
.51201 .50313 .51517 .5024 .52093 .49663 .51779 .49718 Metetra
.852 .991 .843 r
.51779 .49718 .52093 .49663 .52669 .49112 .52356 .49139 Metetra
.85 .984 .859 r
.52356 .49139 .52669 .49112 .53244 .48593 .52934 .48584 Metetra
.844 .972 .877 r
.52934 .48584 .53244 .48593 .53821 .48109 .53511 .4806 Metetra
.835 .954 .893 r
.53511 .4806 .53821 .48109 .54397 .47662 .54089 .47569 Metetra
.822 .93 .904 r
.54089 .47569 .54397 .47662 .54974 .47251 .54667 .47114 Metetra
.805 .902 .909 r
.54667 .47114 .54974 .47251 .55552 .46876 .55246 .46693 Metetra
.787 .87 .91 r
.55246 .46693 .55552 .46876 .5613 .46533 .55825 .46305 Metetra
.768 .838 .905 r
.55825 .46305 .5613 .46533 .5671 .4622 .56406 .45947 Metetra
.75 .806 .897 r
.56406 .45947 .5671 .4622 .57291 .45932 .56987 .45616 Metetra
.733 .777 .888 r
.56987 .45616 .57291 .45932 .57873 .45665 .57569 .4531 Metetra
.718 .75 .878 r
.57569 .4531 .57873 .45665 .58456 .45418 .58153 .45025 Metetra
.704 .727 .868 r
.58153 .45025 .58456 .45418 .5904 .45185 .58737 .4476 Metetra
.692 .707 .859 r
.58737 .4476 .5904 .45185 .59626 .44966 .59323 .44513 Metetra
.681 .69 .852 r
.59323 .44513 .59626 .44966 .60214 .44759 .59911 .44284 Metetra
.67 .677 .848 r
.59911 .44284 .60214 .44759 .60803 .44562 .605 .44073 Metetra
.659 .667 .846 r
.605 .44073 .60803 .44562 .61393 .44378 .61091 .43882 Metetra
.648 .66 .848 r
.61091 .43882 .61393 .44378 .61985 .44206 .61683 .43713 Metetra
.635 .656 .853 r
.61683 .43713 .61985 .44206 .62579 .44049 .62278 .4357 Metetra
.619 .655 .864 r
.62278 .4357 .62579 .44049 .63175 .43911 .62875 .43455 Metetra
.598 .657 .879 r
.62875 .43455 .63175 .43911 .63773 .43795 .63475 .43372 Metetra
.571 .662 .899 r
.63475 .43372 .63773 .43795 .64373 .43704 .64078 .43323 Metetra
.532 .669 .925 r
.64078 .43323 .64373 .43704 .64976 .43643 .64684 .4331 Metetra
.474 .674 .952 r
.64684 .4331 .64976 .43643 .65583 .43612 .65293 .43333 Metetra
.388 .672 .972 r
.65293 .43333 .65583 .43612 .66192 .43616 .65906 .43393 Metetra
.265 .648 .966 r
.65906 .43393 .66192 .43616 .66805 .43654 .66522 .43486 Metetra
.108 .59 .91 r
.66522 .43486 .66805 .43654 .67422 .43724 .67142 .4361 Metetra
0 .5 .801 r
.67142 .4361 .67422 .43724 .68043 .43826 .67766 .43758 Metetra
.191 0 0 r
.67766 .43758 .68043 .43826 .68667 .43952 .68394 .43923 Metetra
.279 0 0 r
.68394 .43923 .68667 .43952 .69295 .44099 .69024 .44098 Metetra
.323 0 0 r
.69024 .44098 .69295 .44099 .69926 .44256 .69657 .44272 Metetra
.331 0 0 r
.69657 .44272 .69926 .44256 .7056 .44417 .70293 .44436 Metetra
.304 0 0 r
.70293 .44436 .7056 .44417 .71196 .4457 .7093 .4458 Metetra
.24 0 0 r
.7093 .4458 .71196 .4457 .71834 .44706 .71568 .44695 Metetra
.129 0 0 r
.71568 .44695 .71834 .44706 .72473 .44816 .72206 .44772 Metetra
.034 .599 .785 r
.72206 .44772 .72473 .44816 .73112 .44889 .72844 .44803 Metetra
.233 .728 .916 r
.72844 .44803 .73112 .44889 .73751 .44919 .73481 .44784 Metetra
.422 .808 .989 r
.73481 .44784 .73751 .44919 .74389 .449 .74117 .44709 Metetra
.559 .83 .996 r
.74117 .44709 .74389 .449 .75025 .44826 .7475 .44577 Metetra
.643 .816 .966 r
.7475 .44577 .75025 .44826 .75659 .44697 .75381 .44387 Metetra
.69 .789 .926 r
.75381 .44387 .75659 .44697 .7629 .44511 .7601 .44143 Metetra
.716 .762 .889 r
.7601 .44143 .7629 .44511 .76919 .4427 .76636 .43846 Metetra
.73 .737 .857 r
.76636 .43846 .76919 .4427 .77545 .43978 .77259 .43503 Metetra
.738 .717 .832 r
.77259 .43503 .77545 .43978 .78169 .43639 .7788 .43119 Metetra
.742 .701 .813 r
.7788 .43119 .78169 .43639 .7879 .4326 .78499 .42701 Metetra
.744 .689 .798 r
.78499 .42701 .7879 .4326 .79409 .42846 .79116 .42255 Metetra
.744 .679 .788 r
.79116 .42255 .79409 .42846 .80027 .42406 .79732 .4179 Metetra
.744 .672 .78 r
.79732 .4179 .80027 .42406 .80643 .41945 .80348 .41311 Metetra
.743 .667 .776 r
.80348 .41311 .80643 .41945 .81258 .41471 .80963 .40826 Metetra
.741 .663 .773 r
.80963 .40826 .81258 .41471 .81873 .4099 .81578 .4034 Metetra
.739 .661 .773 r
.81578 .4034 .81873 .4099 .82488 .40507 .82194 .39858 Metetra
.737 .66 .774 r
.82194 .39858 .82488 .40507 .83104 .40029 .82811 .39384 Metetra
.735 .661 .777 r
.82811 .39384 .83104 .40029 .83721 .39558 .83429 .38922 Metetra
.732 .662 .781 r
.83429 .38922 .83721 .39558 .8434 .39099 .8405 .38474 Metetra
.729 .664 .786 r
.8405 .38474 .8434 .39099 .8496 .38654 .84672 .38043 Metetra
.726 .667 .792 r
.84672 .38043 .8496 .38654 .85582 .38224 .85297 .37628 Metetra
.723 .671 .798 r
.85297 .37628 .85582 .38224 .86207 .37811 .85924 .37231 Metetra
.72 .675 .805 r
.85924 .37231 .86207 .37811 .86834 .37415 .86554 .36852 Metetra
.716 .679 .813 r
.86554 .36852 .86834 .37415 .87464 .37037 .87186 .3649 Metetra
.713 .684 .821 r
.87186 .3649 .87464 .37037 .88096 .36675 .87821 .36144 Metetra
.709 .689 .828 r
.87821 .36144 .88096 .36675 .88731 .3633 .88459 .35814 Metetra
.705 .693 .836 r
.88459 .35814 .88731 .3633 .89369 .36 .89099 .35498 Metetra
.702 .698 .843 r
.89099 .35498 .89369 .36 .90009 .35684 .89742 .35196 Metetra
.698 .702 .85 r
.89742 .35196 .90009 .35684 .90652 .35382 .90387 .34906 Metetra
.695 .707 .857 r
.90387 .34906 .90652 .35382 .91298 .35091 .91035 .34626 Metetra
.651 .726 .904 r
.32137 .52622 .32473 .52955 .33005 .5281 .3267 .5247 Metetra
.647 .721 .902 r
.3267 .5247 .33005 .5281 .33537 .52673 .33203 .52324 Metetra
.641 .714 .901 r
.33203 .52324 .33537 .52673 .3407 .52546 .33737 .52185 Metetra
.634 .706 .898 r
.33737 .52185 .3407 .52546 .34603 .52431 .34272 .52056 Metetra
.625 .696 .895 r
.34272 .52056 .34603 .52431 .35137 .52332 .34807 .5194 Metetra
.615 .683 .891 r
.34807 .5194 .35137 .52332 .35671 .52252 .35342 .5184 Metetra
.602 .668 .886 r
.35342 .5184 .35671 .52252 .36205 .52194 .35878 .51759 Metetra
.586 .65 .88 r
.35878 .51759 .36205 .52194 .3674 .52162 .36414 .517 Metetra
.569 .63 .872 r
.36414 .517 .3674 .52162 .37274 .52161 .36951 .51668 Metetra
.55 .608 .864 r
.36951 .51668 .37274 .52161 .37809 .52192 .37487 .51665 Metetra
.529 .584 .854 r
.37487 .51665 .37809 .52192 .38344 .52259 .38024 .51696 Metetra
.508 .559 .843 r
.38024 .51696 .38344 .52259 .3888 .52362 .38561 .51763 Metetra
.486 .534 .831 r
.38561 .51763 .3888 .52362 .39416 .52503 .39098 .51866 Metetra
.466 .51 .82 r
.39098 .51866 .39416 .52503 .39953 .52678 .39637 .52007 Metetra
.447 .489 .81 r
.39637 .52007 .39953 .52678 .40491 .52885 .40175 .52183 Metetra
.431 .471 .801 r
.40175 .52183 .40491 .52885 .4103 .53116 .40715 .5239 Metetra
.419 .458 .794 r
.40715 .5239 .4103 .53116 .41572 .53363 .41257 .52622 Metetra
.412 .45 .789 r
.41257 .52622 .41572 .53363 .42116 .53614 .41801 .52869 Metetra
.411 .448 .788 r
.41801 .52869 .42116 .53614 .42663 .53857 .42347 .5312 Metetra
.415 .453 .792 r
.42347 .5312 .42663 .53857 .43212 .54077 .42896 .53363 Metetra
.427 .467 .799 r
.42896 .53363 .43212 .54077 .43766 .54259 .43448 .53583 Metetra
.446 .49 .811 r
.43448 .53583 .43766 .54259 .44323 .54389 .44003 .53764 Metetra
.474 .523 .827 r
.44003 .53764 .44323 .54389 .44883 .54454 .44562 .53892 Metetra
.511 .566 .848 r
.44562 .53892 .44883 .54454 .45447 .54442 .45125 .53954 Metetra
.556 .619 .871 r
.45125 .53954 .45447 .54442 .46015 .54346 .45691 .53939 Metetra
.609 .682 .894 r
.45691 .53939 .46015 .54346 .46585 .54163 .46261 .5384 Metetra
.666 .75 .913 r
.46261 .5384 .46585 .54163 .47158 .53893 .46833 .53653 Metetra
.722 .818 .924 r
.46833 .53653 .47158 .53893 .47733 .5354 .47408 .53379 Metetra
.772 .878 .924 r
.47408 .53379 .47733 .5354 .4831 .53113 .47985 .53022 Metetra
.81 .925 .912 r
.47985 .53022 .4831 .53113 .48888 .52624 .48563 .5259 Metetra
.836 .957 .891 r
.48563 .5259 .48888 .52624 .49466 .52084 .49143 .52094 Metetra
.851 .975 .869 r
.49143 .52094 .49466 .52084 .50044 .5151 .49723 .51548 Metetra
.86 .984 .85 r
.49723 .51548 .50044 .5151 .50623 .50915 .50303 .50967 Metetra
.865 .986 .839 r
.50303 .50967 .50623 .50915 .51201 .50313 .50883 .50363 Metetra
.869 .985 .837 r
.50883 .50363 .51201 .50313 .51779 .49718 .51463 .49751 Metetra
.871 .98 .842 r
.51463 .49751 .51779 .49718 .52356 .49139 .52042 .49144 Metetra
.871 .97 .853 r
.52042 .49144 .52356 .49139 .52934 .48584 .52621 .48551 Metetra
.867 .954 .864 r
.52621 .48551 .52934 .48584 .53511 .4806 .53201 .47981 Metetra
.857 .93 .873 r
.53201 .47981 .53511 .4806 .54089 .47569 .5378 .47439 Metetra
.843 .901 .878 r
.5378 .47439 .54089 .47569 .54667 .47114 .54359 .46929 Metetra
.824 .867 .878 r
.54359 .46929 .54667 .47114 .55246 .46693 .54938 .46453 Metetra
.802 .832 .874 r
.54938 .46453 .55246 .46693 .55825 .46305 .55518 .46012 Metetra
.78 .798 .867 r
.55518 .46012 .55825 .46305 .56406 .45947 .56099 .45604 Metetra
.759 .766 .859 r
.56099 .45604 .56406 .45947 .56987 .45616 .56681 .4523 Metetra
.739 .739 .852 r
.56681 .4523 .56987 .45616 .57569 .4531 .57263 .44886 Metetra
.721 .717 .846 r
.57263 .44886 .57569 .4531 .58153 .45025 .57847 .44573 Metetra
.705 .7 .842 r
.57847 .44573 .58153 .45025 .58737 .4476 .58432 .4429 Metetra
.69 .687 .842 r
.58432 .4429 .58737 .4476 .59323 .44513 .59019 .44035 Metetra
.676 .679 .845 r
.59019 .44035 .59323 .44513 .59911 .44284 .59607 .43811 Metetra
.662 .675 .852 r
.59607 .43811 .59911 .44284 .605 .44073 .60197 .43616 Metetra
.646 .677 .865 r
.60197 .43616 .605 .44073 .61091 .43882 .6079 .43453 Metetra
.627 .683 .883 r
.6079 .43453 .61091 .43882 .61683 .43713 .61384 .43324 Metetra
.601 .694 .908 r
.61384 .43324 .61683 .43713 .62278 .4357 .61981 .43228 Metetra
.562 .708 .939 r
.61981 .43228 .62278 .4357 .62875 .43455 .62581 .43168 Metetra
.502 .721 .971 r
.62581 .43168 .62875 .43455 .63475 .43372 .63183 .43145 Metetra
.404 .722 .989 r
.63183 .43145 .63475 .43372 .64078 .43323 .63789 .43158 Metetra
.253 .687 .961 r
.63789 .43158 .64078 .43323 .64684 .4331 .64398 .43206 Metetra
.056 .594 .854 r
.64398 .43206 .64684 .4331 .65293 .43333 .65011 .43287 Metetra
.137 0 0 r
.65011 .43287 .65293 .43333 .65906 .43393 .65627 .43399 Metetra
.283 0 0 r
.65627 .43399 .65906 .43393 .66522 .43486 .66247 .43536 Metetra
.374 0 0 r
.66247 .43536 .66522 .43486 .67142 .4361 .6687 .43693 Metetra
.425 0 0 r
.6687 .43693 .67142 .4361 .67766 .43758 .67496 .43862 Metetra
.448 0 0 r
.67496 .43862 .67766 .43758 .68394 .43923 .68125 .44037 Metetra
.45 0 0 r
.68125 .44037 .68394 .43923 .69024 .44098 .68757 .44208 Metetra
.432 0 0 r
.68757 .44208 .69024 .44098 .69657 .44272 .69391 .44367 Metetra
.391 0 0 r
.69391 .44367 .69657 .44272 .70293 .44436 .70027 .44504 Metetra
.316 0 0 r
.70027 .44504 .70293 .44436 .7093 .4458 .70663 .44611 Metetra
.194 0 0 r
.70663 .44611 .7093 .4458 .71568 .44695 .713 .44679 Metetra
0 .568 .725 r
.713 .44679 .71568 .44695 .72206 .44772 .71937 .44702 Metetra
.216 .724 .896 r
.71937 .44702 .72206 .44772 .72844 .44803 .72573 .44674 Metetra
.425 .814 .987 r
.72573 .44674 .72844 .44803 .73481 .44784 .73207 .44592 Metetra
.567 .833 .995 r
.73207 .44592 .73481 .44784 .74117 .44709 .73839 .44453 Metetra
.649 .814 .963 r
.73839 .44453 .74117 .44709 .7475 .44577 .7447 .44258 Metetra
.693 .784 .921 r
.7447 .44258 .7475 .44577 .75381 .44387 .75098 .44008 Metetra
.717 .756 .883 r
.75098 .44008 .75381 .44387 .7601 .44143 .75723 .43707 Metetra
.73 .732 .852 r
.75723 .43707 .7601 .44143 .76636 .43846 .76346 .4336 Metetra
.737 .712 .828 r
.76346 .4336 .76636 .43846 .77259 .43503 .76967 .42971 Metetra
.741 .697 .809 r
.76967 .42971 .77259 .43503 .7788 .43119 .77586 .42549 Metetra
.743 .685 .795 r
.77586 .42549 .7788 .43119 .78499 .42701 .78203 .421 Metetra
.744 .676 .785 r
.78203 .421 .78499 .42701 .79116 .42255 .7882 .4163 Metetra
.743 .669 .778 r
.7882 .4163 .79116 .42255 .79732 .4179 .79435 .41148 Metetra
.742 .665 .774 r
.79435 .41148 .79732 .4179 .80348 .41311 .8005 .4066 Metetra
.741 .661 .772 r
.8005 .4066 .80348 .41311 .80963 .40826 .80666 .4017 Metetra
.739 .66 .772 r
.80666 .4017 .80963 .40826 .81578 .4034 .81282 .39685 Metetra
.737 .659 .773 r
.81282 .39685 .81578 .4034 .82194 .39858 .81899 .39209 Metetra
.735 .66 .776 r
.81899 .39209 .82194 .39858 .82811 .39384 .82517 .38744 Metetra
.732 .662 .78 r
.82517 .38744 .82811 .39384 .83429 .38922 .83138 .38294 Metetra
.729 .664 .785 r
.83138 .38294 .83429 .38922 .8405 .38474 .8376 .37861 Metetra
.726 .667 .791 r
.8376 .37861 .8405 .38474 .84672 .38043 .84385 .37445 Metetra
.723 .671 .798 r
.84385 .37445 .84672 .38043 .85297 .37628 .85012 .37047 Metetra
.72 .675 .805 r
.85012 .37047 .85297 .37628 .85924 .37231 .85642 .36667 Metetra
.716 .679 .813 r
.85642 .36667 .85924 .37231 .86554 .36852 .86274 .36304 Metetra
.713 .684 .821 r
.86274 .36304 .86554 .36852 .87186 .3649 .86909 .35958 Metetra
.709 .689 .828 r
.86909 .35958 .87186 .3649 .87821 .36144 .87547 .35628 Metetra
.705 .693 .836 r
.87547 .35628 .87821 .36144 .88459 .35814 .88187 .35312 Metetra
.702 .698 .844 r
.88187 .35312 .88459 .35814 .89099 .35498 .8883 .3501 Metetra
.698 .703 .851 r
.8883 .3501 .89099 .35498 .89742 .35196 .89475 .3472 Metetra
.694 .707 .857 r
.89475 .3472 .89742 .35196 .90387 .34906 .90123 .34441 Metetra
.691 .711 .864 r
.90123 .34441 .90387 .34906 .91035 .34626 .90773 .34171 Metetra
.655 .73 .905 r
.318 .52293 .32137 .52622 .3267 .5247 .32333 .52135 Metetra
.651 .726 .904 r
.32333 .52135 .3267 .5247 .33203 .52324 .32868 .51982 Metetra
.647 .721 .903 r
.32868 .51982 .33203 .52324 .33737 .52185 .33403 .51834 Metetra
.641 .715 .901 r
.33403 .51834 .33737 .52185 .34272 .52056 .33938 .51694 Metetra
.634 .706 .898 r
.33938 .51694 .34272 .52056 .34807 .5194 .34475 .51565 Metetra
.626 .696 .895 r
.34475 .51565 .34807 .5194 .35342 .5184 .35012 .51447 Metetra
.615 .683 .891 r
.35012 .51447 .35342 .5184 .35878 .51759 .35549 .51346 Metetra
.602 .668 .886 r
.35549 .51346 .35878 .51759 .36414 .517 .36087 .51263 Metetra
.587 .65 .88 r
.36087 .51263 .36414 .517 .36951 .51668 .36625 .51204 Metetra
.569 .63 .873 r
.36625 .51204 .36951 .51668 .37487 .51665 .37163 .51171 Metetra
.55 .608 .864 r
.37163 .51171 .37487 .51665 .38024 .51696 .37701 .51168 Metetra
.529 .584 .854 r
.37701 .51168 .38024 .51696 .38561 .51763 .3824 .51198 Metetra
.507 .559 .843 r
.3824 .51198 .38561 .51763 .39098 .51866 .38779 .51264 Metetra
.486 .534 .831 r
.38779 .51264 .39098 .51866 .39637 .52007 .39318 .51368 Metetra
.465 .51 .82 r
.39318 .51368 .39637 .52007 .40175 .52183 .39858 .51509 Metetra
.446 .489 .809 r
.39858 .51509 .40175 .52183 .40715 .5239 .40399 .51685 Metetra
.431 .471 .8 r
.40399 .51685 .40715 .5239 .41257 .52622 .40941 .51893 Metetra
.419 .457 .793 r
.40941 .51893 .41257 .52622 .41801 .52869 .41485 .52125 Metetra
.412 .449 .789 r
.41485 .52125 .41801 .52869 .42347 .5312 .42031 .52372 Metetra
.41 .448 .788 r
.42031 .52372 .42347 .5312 .42896 .53363 .42579 .52624 Metetra
.415 .453 .792 r
.42579 .52624 .42896 .53363 .43448 .53583 .4313 .52866 Metetra
.427 .467 .799 r
.4313 .52866 .43448 .53583 .44003 .53764 .43684 .53085 Metetra
.446 .49 .811 r
.43684 .53085 .44003 .53764 .44562 .53892 .44242 .53265 Metetra
.474 .523 .828 r
.44242 .53265 .44562 .53892 .45125 .53954 .44803 .53392 Metetra
.511 .567 .848 r
.44803 .53392 .45125 .53954 .45691 .53939 .45368 .53451 Metetra
.557 .621 .872 r
.45368 .53451 .45691 .53939 .46261 .5384 .45936 .53434 Metetra
.61 .684 .895 r
.45936 .53434 .46261 .5384 .46833 .53653 .46508 .53332 Metetra
.668 .753 .915 r
.46508 .53332 .46833 .53653 .47408 .53379 .47082 .53142 Metetra
.724 .822 .926 r
.47082 .53142 .47408 .53379 .47985 .53022 .47659 .52864 Metetra
.773 .882 .925 r
.47659 .52864 .47985 .53022 .48563 .5259 .48238 .52503 Metetra
.811 .93 .912 r
.48238 .52503 .48563 .5259 .49143 .52094 .48818 .52067 Metetra
.836 .961 .89 r
.48818 .52067 .49143 .52094 .49723 .51548 .49399 .51567 Metetra
.85 .979 .866 r
.49399 .51567 .49723 .51548 .50303 .50967 .49981 .51016 Metetra
.858 .988 .845 r
.49981 .51016 .50303 .50967 .50883 .50363 .50563 .50429 Metetra
.861 .991 .832 r
.50563 .50429 .50883 .50363 .51463 .49751 .51145 .4982 Metetra
.864 .991 .828 r
.51145 .4982 .51463 .49751 .52042 .49144 .51726 .49202 Metetra
.865 .989 .833 r
.51726 .49202 .52042 .49144 .52621 .48551 .52307 .48589 Metetra
.865 .985 .843 r
.52307 .48589 .52621 .48551 .53201 .47981 .52888 .47991 Metetra
.861 .977 .857 r
.52888 .47991 .53201 .47981 .5378 .47439 .53469 .47417 Metetra
.854 .965 .873 r
.53469 .47417 .5378 .47439 .54359 .46929 .5405 .46873 Metetra
.843 .951 .887 r
.5405 .46873 .54359 .46929 .54938 .46453 .5463 .46364 Metetra
.827 .934 .9 r
.5463 .46364 .54938 .46453 .55518 .46012 .55212 .45894 Metetra
.808 .918 .912 r
.55212 .45894 .55518 .46012 .56099 .45604 .55794 .45464 Metetra
.787 .904 .923 r
.55794 .45464 .56099 .45604 .56681 .4523 .56377 .45075 Metetra
.764 .894 .935 r
.56377 .45075 .56681 .4523 .57263 .44886 .5696 .44726 Metetra
.737 .888 .949 r
.5696 .44726 .57263 .44886 .57847 .44573 .57546 .44418 Metetra
.705 .888 .964 r
.57546 .44418 .57847 .44573 .58432 .4429 .58132 .44149 Metetra
.662 .89 .98 r
.58132 .44149 .58432 .4429 .59019 .44035 .58721 .43918 Metetra
.602 .891 .99 r
.58721 .43918 .59019 .44035 .59607 .43811 .59311 .43726 Metetra
.512 .878 .98 r
.59311 .43726 .59607 .43811 .60197 .43616 .59903 .43569 Metetra
.381 .832 .931 r
.59903 .43569 .60197 .43616 .6079 .43453 .60498 .43449 Metetra
.21 .735 .822 r
.60498 .43449 .6079 .43453 .61384 .43324 .61095 .43363 Metetra
.61095 .43363 .61384 .43324 .61981 .43228 .61694 .43311 Metetra
.133 0 0 r
.61694 .43311 .61981 .43228 .62581 .43168 .62297 .43292 Metetra
.254 0 0 r
.62297 .43292 .62581 .43168 .63183 .43145 .62902 .43304 Metetra
.339 0 0 r
.62902 .43304 .63183 .43145 .63789 .43158 .63511 .43345 Metetra
.397 0 0 r
.63511 .43345 .63789 .43158 .64398 .43206 .64122 .43413 Metetra
.436 0 0 r
.64122 .43413 .64398 .43206 .65011 .43287 .64737 .43506 Metetra
.461 0 0 r
.64737 .43506 .65011 .43287 .65627 .43399 .65355 .43619 Metetra
.476 0 0 r
.65355 .43619 .65627 .43399 .66247 .43536 .65976 .43749 Metetra
.481 0 0 r
.65976 .43749 .66247 .43536 .6687 .43693 .666 .43889 Metetra
.476 0 0 r
.666 .43889 .6687 .43693 .67496 .43862 .67227 .44034 Metetra
.459 0 0 r
.67227 .44034 .67496 .43862 .68125 .44037 .67857 .44176 Metetra
.424 0 0 r
.67857 .44176 .68125 .44037 .68757 .44208 .68488 .44307 Metetra
.364 0 0 r
.68488 .44307 .68757 .44208 .69391 .44367 .69121 .4442 Metetra
.263 0 0 r
.69121 .4442 .69391 .44367 .70027 .44504 .69756 .44506 Metetra
.109 0 0 r
.69756 .44506 .70027 .44504 .70663 .44611 .70391 .44558 Metetra
.098 .646 .827 r
.70391 .44558 .70663 .44611 .713 .44679 .71026 .44568 Metetra
.315 .765 .958 r
.71026 .44568 .713 .44679 .71937 .44702 .7166 .44531 Metetra
.485 .813 1 r
.7166 .44531 .71937 .44702 .72573 .44674 .72293 .44442 Metetra
.593 .812 .983 r
.72293 .44442 .72573 .44674 .73207 .44592 .72925 .44299 Metetra
.656 .79 .946 r
.72925 .44299 .73207 .44592 .73839 .44453 .73555 .44102 Metetra
.693 .764 .906 r
.73555 .44102 .73839 .44453 .7447 .44258 .74182 .43851 Metetra
.714 .74 .872 r
.74182 .43851 .7447 .44258 .75098 .44008 .74808 .43549 Metetra
.727 .72 .844 r
.74808 .43549 .75098 .44008 .75723 .43707 .75431 .43201 Metetra
.734 .704 .822 r
.75431 .43201 .75723 .43707 .76346 .4336 .76052 .42812 Metetra
.739 .691 .805 r
.76052 .42812 .76346 .4336 .76967 .42971 .76671 .42389 Metetra
.741 .681 .792 r
.76671 .42389 .76967 .42971 .77586 .42549 .77288 .41938 Metetra
.742 .673 .783 r
.77288 .41938 .77586 .42549 .78203 .421 .77905 .41467 Metetra
.743 .667 .776 r
.77905 .41467 .78203 .421 .7882 .4163 .7852 .40983 Metetra
.742 .663 .773 r
.7852 .40983 .7882 .4163 .79435 .41148 .79136 .40492 Metetra
.741 .66 .771 r
.79136 .40492 .79435 .41148 .8005 .4066 .79751 .4 Metetra
.739 .659 .771 r
.79751 .4 .8005 .4066 .80666 .4017 .80368 .39512 Metetra
.737 .659 .772 r
.80368 .39512 .80666 .4017 .81282 .39685 .80985 .39033 Metetra
.735 .659 .775 r
.80985 .39033 .81282 .39685 .81899 .39209 .81604 .38566 Metetra
.732 .661 .78 r
.81604 .38566 .81899 .39209 .82517 .38744 .82224 .38114 Metetra
.73 .664 .785 r
.82224 .38114 .82517 .38744 .83138 .38294 .82847 .37679 Metetra
.727 .667 .791 r
.82847 .37679 .83138 .38294 .8376 .37861 .83472 .37262 Metetra
.723 .671 .798 r
.83472 .37262 .8376 .37861 .84385 .37445 .84099 .36863 Metetra
.72 .675 .805 r
.84099 .36863 .84385 .37445 .85012 .37047 .84729 .36482 Metetra
.716 .679 .813 r
.84729 .36482 .85012 .37047 .85642 .36667 .85361 .36118 Metetra
.713 .684 .821 r
.85361 .36118 .85642 .36667 .86274 .36304 .85996 .35772 Metetra
.709 .689 .829 r
.85996 .35772 .86274 .36304 .86909 .35958 .86633 .35442 Metetra
.705 .694 .836 r
.86633 .35442 .86909 .35958 .87547 .35628 .87274 .35126 Metetra
.701 .698 .844 r
.87274 .35126 .87547 .35628 .88187 .35312 .87916 .34824 Metetra
.698 .703 .851 r
.87916 .34824 .88187 .35312 .8883 .3501 .88561 .34534 Metetra
.694 .707 .858 r
.88561 .34534 .8883 .3501 .89475 .3472 .89209 .34255 Metetra
.691 .711 .864 r
.89209 .34255 .89475 .3472 .90123 .34441 .89859 .33985 Metetra
.687 .715 .87 r
.89859 .33985 .90123 .34441 .90773 .34171 .90511 .33724 Metetra
.657 .733 .906 r
.31461 .51967 .318 .52293 .32333 .52135 .31995 .51805 Metetra
.655 .731 .905 r
.31995 .51805 .32333 .52135 .32868 .51982 .32531 .51646 Metetra
.651 .727 .904 r
.32531 .51646 .32868 .51982 .33403 .51834 .33067 .51491 Metetra
.647 .722 .903 r
.33067 .51491 .33403 .51834 .33938 .51694 .33603 .51342 Metetra
.642 .715 .901 r
.33603 .51342 .33938 .51694 .34475 .51565 .34141 .51201 Metetra
.635 .707 .898 r
.34141 .51201 .34475 .51565 .35012 .51447 .34679 .5107 Metetra
.626 .696 .895 r
.34679 .5107 .35012 .51447 .35549 .51346 .35218 .50952 Metetra
.615 .684 .891 r
.35218 .50952 .35549 .51346 .36087 .51263 .35757 .50849 Metetra
.602 .668 .886 r
.35757 .50849 .36087 .51263 .36625 .51204 .36296 .50765 Metetra
.587 .651 .88 r
.36296 .50765 .36625 .51204 .37163 .51171 .36836 .50705 Metetra
.569 .63 .873 r
.36836 .50705 .37163 .51171 .37701 .51168 .37376 .50671 Metetra
.55 .608 .864 r
.37376 .50671 .37701 .51168 .3824 .51198 .37917 .50667 Metetra
.529 .583 .854 r
.37917 .50667 .3824 .51198 .38779 .51264 .38457 .50697 Metetra
.507 .558 .843 r
.38457 .50697 .38779 .51264 .39318 .51368 .38998 .50763 Metetra
.485 .533 .831 r
.38998 .50763 .39318 .51368 .39858 .51509 .39539 .50867 Metetra
.465 .51 .82 r
.39539 .50867 .39858 .51509 .40399 .51685 .40081 .51008 Metetra
.446 .488 .809 r
.40081 .51008 .40399 .51685 .40941 .51893 .40624 .51185 Metetra
.43 .47 .8 r
.40624 .51185 .40941 .51893 .41485 .52125 .41169 .51393 Metetra
.418 .457 .793 r
.41169 .51393 .41485 .52125 .42031 .52372 .41714 .51625 Metetra
.411 .449 .789 r
.41714 .51625 .42031 .52372 .42579 .52624 .42262 .51873 Metetra
.41 .447 .788 r
.42262 .51873 .42579 .52624 .4313 .52866 .42813 .52125 Metetra
.415 .453 .792 r
.42813 .52125 .4313 .52866 .43684 .53085 .43366 .52367 Metetra
.426 .467 .799 r
.43366 .52367 .43684 .53085 .44242 .53265 .43922 .52586 Metetra
.446 .49 .812 r
.43922 .52586 .44242 .53265 .44803 .53392 .44482 .52765 Metetra
.474 .524 .829 r
.44482 .52765 .44803 .53392 .45368 .53451 .45045 .52891 Metetra
.51 .568 .85 r
.45045 .52891 .45368 .53451 .45936 .53434 .45612 .52951 Metetra
.556 .623 .874 r
.45612 .52951 .45936 .53434 .46508 .53332 .46183 .52933 Metetra
.609 .689 .899 r
.46183 .52933 .46508 .53332 .47082 .53142 .46756 .52832 Metetra
.666 .761 .921 r
.46756 .52832 .47082 .53142 .47659 .52864 .47333 .52642 Metetra
.722 .833 .934 r
.47333 .52642 .47659 .52864 .48238 .52503 .47911 .52367 Metetra
.77 .899 .933 r
.47911 .52367 .48238 .52503 .48818 .52067 .48492 .5201 Metetra
.803 .95 .916 r
.48492 .5201 .48818 .52067 .49399 .51567 .49074 .51579 Metetra
.819 .982 .886 r
.49074 .51579 .49399 .51567 .49981 .51016 .49657 .51087 Metetra
.819 .997 .848 r
.49657 .51087 .49981 .51016 .50563 .50429 .5024 .50547 Metetra
.807 1 .808 r
.5024 .50547 .50563 .50429 .51145 .4982 .50824 .49973 Metetra
.785 .994 .772 r
.50824 .49973 .51145 .4982 .51726 .49202 .51407 .49381 Metetra
.757 .983 .741 r
.51407 .49381 .51726 .49202 .52307 .48589 .51991 .48784 Metetra
.724 .969 .715 r
.51991 .48784 .52307 .48589 .52888 .47991 .52574 .48196 Metetra
.683 .951 .693 r
.52574 .48196 .52888 .47991 .53469 .47417 .53157 .47628 Metetra
.634 .929 .671 r
.53157 .47628 .53469 .47417 .5405 .46873 .53739 .47088 Metetra
.572 .898 .644 r
.53739 .47088 .5405 .46873 .5463 .46364 .54323 .46584 Metetra
.495 .855 .61 r
.54323 .46584 .5463 .46364 .55212 .45894 .54906 .46119 Metetra
.54906 .46119 .55212 .45894 .55794 .45464 .5549 .45698 Metetra
.5549 .45698 .55794 .45464 .56377 .45075 .56075 .4532 Metetra
.56075 .4532 .56377 .45075 .5696 .44726 .56661 .44985 Metetra
.56661 .44985 .5696 .44726 .57546 .44418 .57249 .44692 Metetra
.022 0 0 r
.57249 .44692 .57546 .44418 .58132 .44149 .57838 .44439 Metetra
.108 0 0 r
.57838 .44439 .58132 .44149 .58721 .43918 .58428 .44222 Metetra
.178 0 0 r
.58428 .44222 .58721 .43918 .59311 .43726 .59021 .44039 Metetra
.232 0 0 r
.59021 .44039 .59311 .43726 .59903 .43569 .59615 .43888 Metetra
.274 0 0 r
.59615 .43888 .59903 .43569 .60498 .43449 .60212 .43766 Metetra
.306 0 0 r
.60212 .43766 .60498 .43449 .61095 .43363 .60811 .43671 Metetra
.329 0 0 r
.60811 .43671 .61095 .43363 .61694 .43311 .61412 .43603 Metetra
.346 0 0 r
.61412 .43603 .61694 .43311 .62297 .43292 .62015 .4356 Metetra
.358 0 0 r
.62015 .4356 .62297 .43292 .62902 .43304 .62622 .43543 Metetra
.364 0 0 r
.62622 .43543 .62902 .43304 .63511 .43345 .63231 .4355 Metetra
.365 0 0 r
.63231 .4355 .63511 .43345 .64122 .43413 .63843 .4358 Metetra
.359 0 0 r
.63843 .4358 .64122 .43413 .64737 .43506 .64458 .43634 Metetra
.346 0 0 r
.64458 .43634 .64737 .43506 .65355 .43619 .65076 .43707 Metetra
.323 0 0 r
.65076 .43707 .65355 .43619 .65976 .43749 .65697 .43797 Metetra
.286 0 0 r
.65697 .43797 .65976 .43749 .666 .43889 .66321 .43898 Metetra
.231 0 0 r
.66321 .43898 .666 .43889 .67227 .44034 .66947 .44005 Metetra
.154 0 0 r
.66947 .44005 .67227 .44034 .67857 .44176 .67576 .4411 Metetra
0 .523 .759 r
.67576 .4411 .67857 .44176 .68488 .44307 .68207 .44205 Metetra
.069 .604 .859 r
.68207 .44205 .68488 .44307 .69121 .4442 .6884 .4428 Metetra
.204 .677 .937 r
.6884 .4428 .69121 .4442 .69756 .44506 .69473 .44328 Metetra
.336 .73 .983 r
.69473 .44328 .69756 .44506 .70391 .44558 .70107 .4434 Metetra
.451 .76 .995 r
.70107 .4434 .70391 .44558 .71026 .44568 .70741 .44308 Metetra
.541 .769 .982 r
.70741 .44308 .71026 .44568 .7166 .44531 .71374 .44228 Metetra
.607 .764 .955 r
.71374 .44228 .7166 .44531 .72293 .44442 .72005 .44095 Metetra
.654 .753 .922 r
.72005 .44095 .72293 .44442 .72925 .44299 .72635 .43907 Metetra
.686 .738 .891 r
.72635 .43907 .72925 .44299 .73555 .44102 .73263 .43665 Metetra
.707 .723 .863 r
.73263 .43665 .73555 .44102 .74182 .43851 .73889 .43371 Metetra
.721 .71 .839 r
.73889 .43371 .74182 .43851 .74808 .43549 .74513 .4303 Metetra
.731 .698 .819 r
.74513 .4303 .74808 .43549 .75431 .43201 .75134 .42645 Metetra
.737 .688 .804 r
.75134 .42645 .75431 .43201 .76052 .42812 .75754 .42225 Metetra
.74 .679 .792 r
.75754 .42225 .76052 .42812 .76671 .42389 .76372 .41776 Metetra
.742 .672 .783 r
.76372 .41776 .76671 .42389 .77288 .41938 .76988 .41305 Metetra
.743 .667 .776 r
.76988 .41305 .77288 .41938 .77905 .41467 .77604 .40819 Metetra
.742 .663 .772 r
.77604 .40819 .77905 .41467 .7852 .40983 .7822 .40326 Metetra
.741 .661 .771 r
.7822 .40326 .7852 .40983 .79136 .40492 .78836 .39831 Metetra
.74 .659 .771 r
.78836 .39831 .79136 .40492 .79751 .4 .79452 .39341 Metetra
.738 .659 .772 r
.79452 .39341 .79751 .4 .80368 .39512 .8007 .38859 Metetra
.736 .66 .775 r
.8007 .38859 .80368 .39512 .80985 .39033 .80689 .3839 Metetra
.733 .661 .779 r
.80689 .3839 .80985 .39033 .81604 .38566 .81309 .37936 Metetra
.73 .664 .785 r
.81309 .37936 .81604 .38566 .82224 .38114 .81932 .37498 Metetra
.727 .667 .791 r
.81932 .37498 .82224 .38114 .82847 .37679 .82557 .37079 Metetra
.724 .671 .798 r
.82557 .37079 .82847 .37679 .83472 .37262 .83184 .36679 Metetra
.72 .675 .805 r
.83184 .36679 .83472 .37262 .84099 .36863 .83814 .36297 Metetra
.717 .679 .813 r
.83814 .36297 .84099 .36863 .84729 .36482 .84446 .35933 Metetra
.713 .684 .821 r
.84446 .35933 .84729 .36482 .85361 .36118 .85081 .35586 Metetra
.709 .689 .829 r
.85081 .35586 .85361 .36118 .85996 .35772 .85718 .35255 Metetra
.705 .694 .837 r
.85718 .35255 .85996 .35772 .86633 .35442 .86358 .3494 Metetra
.701 .699 .844 r
.86358 .3494 .86633 .35442 .87274 .35126 .87001 .34638 Metetra
.698 .703 .851 r
.87001 .34638 .87274 .35126 .87916 .34824 .87646 .34348 Metetra
.694 .708 .858 r
.87646 .34348 .87916 .34824 .88561 .34534 .88294 .34069 Metetra
.69 .712 .865 r
.88294 .34069 .88561 .34534 .89209 .34255 .88943 .338 Metetra
.687 .715 .87 r
.88943 .338 .89209 .34255 .89859 .33985 .89595 .33539 Metetra
.684 .719 .876 r
.89595 .33539 .89859 .33985 .90511 .33724 .9025 .33285 Metetra
.659 .736 .906 r
.31121 .51643 .31461 .51967 .31995 .51805 .31656 .51477 Metetra
.657 .734 .906 r
.31656 .51477 .31995 .51805 .32531 .51646 .32192 .51313 Metetra
.655 .731 .905 r
.32192 .51313 .32531 .51646 .33067 .51491 .32729 .51153 Metetra
.652 .727 .904 r
.32729 .51153 .33067 .51491 .33603 .51342 .33267 .50997 Metetra
.647 .722 .903 r
.33267 .50997 .33603 .51342 .34141 .51201 .33805 .50847 Metetra
.642 .715 .901 r
.33805 .50847 .34141 .51201 .34679 .5107 .34344 .50705 Metetra
.635 .707 .899 r
.34344 .50705 .34679 .5107 .35218 .50952 .34884 .50573 Metetra
.626 .697 .896 r
.34884 .50573 .35218 .50952 .35757 .50849 .35425 .50453 Metetra
.615 .684 .892 r
.35425 .50453 .35757 .50849 .36296 .50765 .35966 .50349 Metetra
.602 .669 .887 r
.35966 .50349 .36296 .50765 .36836 .50705 .36507 .50265 Metetra
.587 .651 .88 r
.36507 .50265 .36836 .50705 .37376 .50671 .37049 .50203 Metetra
.569 .63 .873 r
.37049 .50203 .37376 .50671 .37917 .50667 .37591 .50168 Metetra
.549 .608 .864 r
.37591 .50168 .37917 .50667 .38457 .50697 .38133 .50164 Metetra
.528 .583 .854 r
.38133 .50164 .38457 .50697 .38998 .50763 .38676 .50194 Metetra
.507 .558 .843 r
.38676 .50194 .38998 .50763 .39539 .50867 .39219 .5026 Metetra
.485 .533 .831 r
.39219 .5026 .39539 .50867 .40081 .51008 .39762 .50363 Metetra
.464 .509 .82 r
.39762 .50363 .40081 .51008 .40624 .51185 .40306 .50505 Metetra
.445 .488 .809 r
.40306 .50505 .40624 .51185 .41169 .51393 .40851 .50682 Metetra
.43 .47 .8 r
.40851 .50682 .41169 .51393 .41714 .51625 .41397 .5089 Metetra
.418 .456 .793 r
.41397 .5089 .41714 .51625 .42262 .51873 .41945 .51123 Metetra
.411 .448 .789 r
.41945 .51123 .42262 .51873 .42813 .52125 .42495 .51371 Metetra
.41 .447 .788 r
.42495 .51371 .42813 .52125 .43366 .52367 .43048 .51623 Metetra
.415 .453 .791 r
.43048 .51623 .43366 .52367 .43922 .52586 .43603 .51865 Metetra
.426 .467 .799 r
.43603 .51865 .43922 .52586 .44482 .52765 .44161 .52083 Metetra
.446 .49 .812 r
.44161 .52083 .44482 .52765 .45045 .52891 .44723 .52263 Metetra
.473 .524 .829 r
.44723 .52263 .45045 .52891 .45612 .52951 .45289 .52389 Metetra
.509 .568 .85 r
.45289 .52389 .45612 .52951 .46183 .52933 .45858 .52449 Metetra
.554 .623 .875 r
.45858 .52449 .46183 .52933 .46756 .52832 .46431 .52433 Metetra
.606 .689 .902 r
.46431 .52433 .46756 .52832 .47333 .52642 .47006 .52334 Metetra
.661 .762 .925 r
.47006 .52334 .47333 .52642 .47911 .52367 .47584 .5215 Metetra
.716 .838 .94 r
.47584 .5215 .47911 .52367 .48492 .5201 .48165 .51882 Metetra
.761 .906 .94 r
.48165 .51882 .48492 .5201 .49074 .51579 .48748 .51535 Metetra
.789 .959 .921 r
.48748 .51535 .49074 .51579 .49657 .51087 .49331 .51118 Metetra
.796 .99 .884 r
.49331 .51118 .49657 .51087 .5024 .50547 .49916 .50644 Metetra
.78 .998 .832 r
.49916 .50644 .5024 .50547 .50824 .49973 .50501 .50125 Metetra
.745 .987 .773 r
.50501 .50125 .50824 .49973 .51407 .49381 .51087 .49577 Metetra
.696 .961 .713 r
.51087 .49577 .51407 .49381 .51991 .48784 .51672 .49014 Metetra
.639 .926 .655 r
.51672 .49014 .51991 .48784 .52574 .48196 .52257 .4845 Metetra
.576 .886 .603 r
.52257 .4845 .52574 .48196 .53157 .47628 .52842 .47897 Metetra
.51 .843 .557 r
.52842 .47897 .53157 .47628 .53739 .47088 .53427 .47365 Metetra
.53427 .47365 .53739 .47088 .54323 .46584 .54013 .46861 Metetra
.54013 .46861 .54323 .46584 .54906 .46119 .54598 .4639 Metetra
.54598 .4639 .54906 .46119 .5549 .45698 .55184 .45955 Metetra
.55184 .45955 .5549 .45698 .56075 .4532 .55771 .45558 Metetra
.55771 .45558 .56075 .4532 .56661 .44985 .56359 .45196 Metetra
.56359 .45196 .56661 .44985 .57249 .44692 .56948 .44868 Metetra
.56948 .44868 .57249 .44692 .57838 .44439 .57538 .44573 Metetra
.291 .764 .646 r
.57538 .44573 .57838 .44439 .58428 .44222 .5813 .44307 Metetra
.344 .815 .745 r
.5813 .44307 .58428 .44222 .59021 .44039 .58723 .44069 Metetra
.408 .86 .848 r
.58723 .44069 .59021 .44039 .59615 .43888 .59318 .43858 Metetra
.469 .884 .932 r
.59318 .43858 .59615 .43888 .60212 .43766 .59914 .43675 Metetra
.513 .876 .982 r
.59914 .43675 .60212 .43766 .60811 .43671 .60513 .43519 Metetra
.535 .843 .999 r
.60513 .43519 .60811 .43671 .61412 .43603 .61113 .43393 Metetra
.537 .8 .994 r
.61113 .43393 .61412 .43603 .62015 .4356 .61717 .43298 Metetra
.528 .755 .98 r
.61717 .43298 .62015 .4356 .62622 .43543 .62323 .43237 Metetra
.51 .715 .964 r
.62323 .43237 .62622 .43543 .63231 .4355 .62931 .43211 Metetra
.488 .681 .952 r
.62931 .43211 .63231 .4355 .63843 .4358 .63543 .4322 Metetra
.462 .654 .943 r
.63543 .4322 .63843 .4358 .64458 .43634 .64159 .43262 Metetra
.435 .633 .939 r
.64159 .43262 .64458 .43634 .65076 .43707 .64777 .43334 Metetra
.407 .618 .938 r
.64777 .43334 .65076 .43707 .65697 .43797 .65399 .43431 Metetra
.382 .61 .939 r
.65399 .43431 .65697 .43797 .66321 .43898 .66024 .43545 Metetra
.362 .608 .943 r
.66024 .43545 .66321 .43898 .66947 .44005 .66652 .43667 Metetra
.352 .614 .949 r
.66652 .43667 .66947 .44005 .67576 .4411 .67283 .43787 Metetra
.357 .628 .955 r
.67283 .43787 .67576 .4411 .68207 .44205 .67915 .43893 Metetra
.38 .649 .962 r
.67915 .43893 .68207 .44205 .6884 .4428 .68549 .43975 Metetra
.421 .675 .968 r
.68549 .43975 .6884 .4428 .69473 .44328 .69183 .44021 Metetra
.474 .702 .968 r
.69183 .44021 .69473 .44328 .70107 .4434 .69817 .44024 Metetra
.534 .724 .961 r
.69817 .44024 .70107 .4434 .70741 .44308 .70451 .43975 Metetra
.59 .737 .945 r
.70451 .43975 .70741 .44308 .71374 .44228 .71084 .4387 Metetra
.638 .74 .923 r
.71084 .4387 .71374 .44228 .72005 .44095 .71714 .43706 Metetra
.675 .736 .897 r
.71714 .43706 .72005 .44095 .72635 .43907 .72343 .43483 Metetra
.702 .728 .871 r
.72343 .43483 .72635 .43907 .73263 .43665 .72969 .43204 Metetra
.72 .717 .847 r
.72969 .43204 .73263 .43665 .73889 .43371 .73594 .42872 Metetra
.732 .706 .826 r
.73594 .42872 .73889 .43371 .74513 .4303 .74216 .42494 Metetra
.739 .695 .81 r
.74216 .42494 .74513 .4303 .75134 .42645 .74836 .42076 Metetra
.743 .686 .796 r
.74836 .42076 .75134 .42645 .75754 .42225 .75454 .41627 Metetra
.745 .678 .786 r
.75454 .41627 .75754 .42225 .76372 .41776 .76071 .41155 Metetra
.746 .672 .779 r
.76071 .41155 .76372 .41776 .76988 .41305 .76687 .40666 Metetra
.745 .667 .774 r
.76687 .40666 .76988 .41305 .77604 .40819 .77303 .40169 Metetra
.744 .664 .772 r
.77303 .40169 .77604 .40819 .7822 .40326 .77919 .3967 Metetra
.742 .662 .771 r
.77919 .3967 .7822 .40326 .78836 .39831 .78536 .39176 Metetra
.739 .661 .772 r
.78536 .39176 .78836 .39831 .79452 .39341 .79153 .3869 Metetra
.737 .661 .775 r
.79153 .3869 .79452 .39341 .8007 .38859 .79772 .38217 Metetra
.734 .662 .779 r
.79772 .38217 .8007 .38859 .80689 .3839 .80393 .37759 Metetra
.731 .664 .784 r
.80393 .37759 .80689 .3839 .81309 .37936 .81015 .37319 Metetra
.728 .667 .79 r
.81015 .37319 .81309 .37936 .81932 .37498 .8164 .36897 Metetra
.724 .671 .797 r
.8164 .36897 .81932 .37498 .82557 .37079 .82268 .36495 Metetra
.72 .675 .805 r
.82268 .36495 .82557 .37079 .83184 .36679 .82897 .36112 Metetra
.717 .679 .813 r
.82897 .36112 .83184 .36679 .83814 .36297 .83529 .35747 Metetra
.713 .684 .821 r
.83529 .35747 .83814 .36297 .84446 .35933 .84164 .35399 Metetra
.709 .689 .829 r
.84164 .35399 .84446 .35933 .85081 .35586 .84802 .35069 Metetra
.705 .694 .837 r
.84802 .35069 .85081 .35586 .85718 .35255 .85442 .34753 Metetra
.701 .699 .844 r
.85442 .34753 .85718 .35255 .86358 .3494 .86084 .34451 Metetra
.697 .703 .852 r
.86084 .34451 .86358 .3494 .87001 .34638 .86729 .34161 Metetra
.694 .708 .859 r
.86729 .34161 .87001 .34638 .87646 .34348 .87376 .33883 Metetra
.69 .712 .865 r
.87376 .33883 .87646 .34348 .88294 .34069 .88026 .33614 Metetra
.687 .716 .871 r
.88026 .33614 .88294 .34069 .88943 .338 .88678 .33353 Metetra
.684 .719 .876 r
.88678 .33353 .88943 .338 .89595 .33539 .89332 .33099 Metetra
.681 .722 .881 r
.89332 .33099 .89595 .33539 .9025 .33285 .89988 .32852 Metetra
.66 .737 .907 r
.30779 .51319 .31121 .51643 .31656 .51477 .31315 .51151 Metetra
.659 .736 .906 r
.31315 .51151 .31656 .51477 .32192 .51313 .31852 .50984 Metetra
.657 .734 .906 r
.31852 .50984 .32192 .51313 .32729 .51153 .3239 .50819 Metetra
.655 .731 .905 r
.3239 .50819 .32729 .51153 .33267 .50997 .32928 .50658 Metetra
.652 .727 .904 r
.32928 .50658 .33267 .50997 .33805 .50847 .33468 .50501 Metetra
.647 .722 .903 r
.33468 .50501 .33805 .50847 .34344 .50705 .34008 .50349 Metetra
.642 .716 .901 r
.34008 .50349 .34344 .50705 .34884 .50573 .34549 .50206 Metetra
.635 .707 .899 r
.34549 .50206 .34884 .50573 .35425 .50453 .35091 .50073 Metetra
.626 .697 .896 r
.35091 .50073 .35425 .50453 .35966 .50349 .35633 .49952 Metetra
.615 .684 .892 r
.35633 .49952 .35966 .50349 .36507 .50265 .36176 .49847 Metetra
.602 .669 .887 r
.36176 .49847 .36507 .50265 .37049 .50203 .36719 .49761 Metetra
.587 .651 .88 r
.36719 .49761 .37049 .50203 .37591 .50168 .37263 .49699 Metetra
.569 .63 .873 r
.37263 .49699 .37591 .50168 .38133 .50164 .37807 .49663 Metetra
.549 .608 .864 r
.37807 .49663 .38133 .50164 .38676 .50194 .38351 .49659 Metetra
.528 .583 .854 r
.38351 .49659 .38676 .50194 .39219 .5026 .38895 .49688 Metetra
.506 .558 .843 r
.38895 .49688 .39219 .5026 .39762 .50363 .3944 .49753 Metetra
.484 .533 .831 r
.3944 .49753 .39762 .50363 .40306 .50505 .39986 .49857 Metetra
.464 .509 .82 r
.39986 .49857 .40306 .50505 .40851 .50682 .40532 .49998 Metetra
.445 .487 .809 r
.40532 .49998 .40851 .50682 .41397 .5089 .41079 .50175 Metetra
.43 .469 .8 r
.41079 .50175 .41397 .5089 .41945 .51123 .41627 .50384 Metetra
.418 .456 .793 r
.41627 .50384 .41945 .51123 .42495 .51371 .42177 .50616 Metetra
.412 .448 .788 r
.42177 .50616 .42495 .51371 .43048 .51623 .42729 .50864 Metetra
.411 .447 .787 r
.42729 .50864 .43048 .51623 .43603 .51865 .43284 .51114 Metetra
.416 .453 .791 r
.43284 .51114 .43603 .51865 .44161 .52083 .43842 .51355 Metetra
.429 .467 .798 r
.43842 .51355 .44161 .52083 .44723 .52263 .44402 .51572 Metetra
.449 .49 .809 r
.44402 .51572 .44723 .52263 .45289 .52389 .44967 .51748 Metetra
.477 .523 .825 r
.44967 .51748 .45289 .52389 .45858 .52449 .45534 .51871 Metetra
.514 .565 .845 r
.45534 .51871 .45858 .52449 .46431 .52433 .46106 .51928 Metetra
.559 .617 .867 r
.46106 .51928 .46431 .52433 .47006 .52334 .4668 .51908 Metetra
.61 .677 .889 r
.4668 .51908 .47006 .52334 .47584 .5215 .47258 .51805 Metetra
.664 .741 .907 r
.47258 .51805 .47584 .5215 .48165 .51882 .47838 .51616 Metetra
.718 .805 .919 r
.47838 .51616 .48165 .51882 .48748 .51535 .48421 .51343 Metetra
.766 .861 .92 r
.48421 .51343 .48748 .51535 .49331 .51118 .49005 .50991 Metetra
.803 .906 .912 r
.49005 .50991 .49331 .51118 .49916 .50644 .49591 .50569 Metetra
.83 .938 .898 r
.49591 .50569 .49916 .50644 .50501 .50125 .50178 .50087 Metetra
.847 .956 .882 r
.50178 .50087 .50501 .50125 .51087 .49577 .50764 .4956 Metetra
.858 .964 .869 r
.50764 .4956 .51087 .49577 .51672 .49014 .51352 .49001 Metetra
.865 .965 .862 r
.51352 .49001 .51672 .49014 .52257 .4845 .51939 .48423 Metetra
.869 .957 .861 r
.51939 .48423 .52257 .4845 .52842 .47897 .52525 .47839 Metetra
.868 .941 .864 r
.52525 .47839 .52842 .47897 .53427 .47365 .53112 .4726 Metetra
.862 .915 .865 r
.53112 .4726 .53427 .47365 .54013 .46861 .53699 .46694 Metetra
.848 .878 .863 r
.53699 .46694 .54013 .46861 .54598 .4639 .54285 .4615 Metetra
.827 .834 .854 r
.54285 .4615 .54598 .4639 .55184 .45955 .54872 .45631 Metetra
.801 .786 .839 r
.54872 .45631 .55184 .45955 .55771 .45558 .55459 .45142 Metetra
.773 .737 .82 r
.55459 .45142 .55771 .45558 .56359 .45196 .56047 .44684 Metetra
.745 .693 .801 r
.56047 .44684 .56359 .45196 .56948 .44868 .56635 .44259 Metetra
.72 .653 .783 r
.56635 .44259 .56948 .44868 .57538 .44573 .57224 .4387 Metetra
.696 .62 .767 r
.57224 .4387 .57538 .44573 .5813 .44307 .57815 .43518 Metetra
.676 .592 .753 r
.57815 .43518 .5813 .44307 .58723 .44069 .58407 .43205 Metetra
.657 .568 .743 r
.58407 .43205 .58723 .44069 .59318 .43858 .59 .42935 Metetra
.64 .549 .737 r
.59 .42935 .59318 .43858 .59914 .43675 .59596 .42711 Metetra
.623 .534 .733 r
.59596 .42711 .59914 .43675 .60513 .43519 .60194 .42536 Metetra
.607 .522 .733 r
.60194 .42536 .60513 .43519 .61113 .43393 .60794 .42414 Metetra
.59 .513 .736 r
.60794 .42414 .61113 .43393 .61717 .43298 .61398 .42346 Metetra
.571 .506 .743 r
.61398 .42346 .61717 .43298 .62323 .43237 .62005 .42332 Metetra
.55 .502 .755 r
.62005 .42332 .62323 .43237 .62931 .43211 .62615 .42373 Metetra
.526 .501 .771 r
.62615 .42373 .62931 .43211 .63543 .4322 .6323 .42462 Metetra
.496 .502 .793 r
.6323 .42462 .63543 .4322 .64159 .43262 .63848 .42594 Metetra
.46 .507 .821 r
.63848 .42594 .64159 .43262 .64777 .43334 .6447 .4276 Metetra
.415 .517 .853 r
.6447 .4276 .64777 .43334 .65399 .43431 .65096 .42948 Metetra
.363 .53 .887 r
.65096 .42948 .65399 .43431 .66024 .43545 .65725 .43147 Metetra
.306 .547 .917 r
.65725 .43147 .66024 .43545 .66652 .43667 .66357 .43341 Metetra
.257 .568 .938 r
.66357 .43341 .66652 .43667 .67283 .43787 .6699 .43518 Metetra
.233 .598 .95 r
.6699 .43518 .67283 .43787 .67915 .43893 .67625 .43664 Metetra
.25 .64 .962 r
.67625 .43664 .67915 .43893 .68549 .43975 .68261 .43767 Metetra
.311 .693 .978 r
.68261 .43767 .68549 .43975 .69183 .44021 .68897 .43816 Metetra
.405 .748 .994 r
.68897 .43816 .69183 .44021 .69817 .44024 .69531 .43805 Metetra
.509 .788 .996 r
.69531 .43805 .69817 .44024 .70451 .43975 .70165 .43728 Metetra
.599 .804 .978 r
.70165 .43728 .70451 .43975 .71084 .4387 .70796 .43584 Metetra
.664 .799 .947 r
.70796 .43584 .71084 .4387 .71714 .43706 .71425 .43374 Metetra
.706 .781 .911 r
.71425 .43374 .71714 .43706 .72343 .43483 .72052 .431 Metetra
.73 .76 .877 r
.72052 .431 .72343 .43483 .72969 .43204 .72676 .4277 Metetra
.743 .738 .847 r
.72676 .4277 .72969 .43204 .73594 .42872 .73298 .42389 Metetra
.75 .719 .824 r
.73298 .42389 .73594 .42872 .74216 .42494 .73918 .41965 Metetra
.752 .704 .806 r
.73918 .41965 .74216 .42494 .74836 .42076 .74537 .41508 Metetra
.753 .691 .792 r
.74537 .41508 .74836 .42076 .75454 .41627 .75154 .41027 Metetra
.751 .681 .783 r
.75154 .41027 .75454 .41627 .76071 .41155 .7577 .4053 Metetra
.749 .673 .776 r
.7577 .4053 .76071 .41155 .76687 .40666 .76385 .40024 Metetra
.747 .667 .773 r
.76385 .40024 .76687 .40666 .77303 .40169 .77001 .39517 Metetra
.744 .664 .771 r
.77001 .39517 .77303 .40169 .77919 .3967 .77618 .39015 Metetra
.741 .662 .772 r
.77618 .39015 .77919 .3967 .78536 .39176 .78235 .38523 Metetra
.738 .661 .774 r
.78235 .38523 .78536 .39176 .79153 .3869 .78854 .38044 Metetra
.735 .662 .778 r
.78854 .38044 .79153 .3869 .79772 .38217 .79475 .37582 Metetra
.731 .664 .783 r
.79475 .37582 .79772 .38217 .80393 .37759 .80097 .37139 Metetra
.728 .667 .79 r
.80097 .37139 .80393 .37759 .81015 .37319 .80722 .36715 Metetra
.724 .67 .797 r
.80722 .36715 .81015 .37319 .8164 .36897 .81349 .3631 Metetra
.72 .674 .804 r
.81349 .3631 .8164 .36897 .82268 .36495 .81979 .35925 Metetra
.717 .679 .812 r
.81979 .35925 .82268 .36495 .82897 .36112 .82611 .3556 Metetra
.713 .683 .82 r
.82611 .3556 .82897 .36112 .83529 .35747 .83246 .35212 Metetra
.709 .688 .829 r
.83246 .35212 .83529 .35747 .84164 .35399 .83883 .34881 Metetra
.705 .694 .837 r
.83883 .34881 .84164 .35399 .84802 .35069 .84523 .34565 Metetra
.701 .698 .844 r
.84523 .34565 .84802 .35069 .85442 .34753 .85166 .34263 Metetra
.697 .703 .852 r
.85166 .34263 .85442 .34753 .86084 .34451 .8581 .33974 Metetra
.693 .708 .859 r
.8581 .33974 .86084 .34451 .86729 .34161 .86457 .33696 Metetra
.69 .712 .865 r
.86457 .33696 .86729 .34161 .87376 .33883 .87107 .33427 Metetra
.687 .716 .871 r
.87107 .33427 .87376 .33883 .88026 .33614 .87759 .33167 Metetra
.683 .719 .876 r
.87759 .33167 .88026 .33614 .88678 .33353 .88412 .32914 Metetra
.681 .722 .881 r
.88412 .32914 .88678 .33353 .89332 .33099 .89068 .32667 Metetra
.678 .725 .885 r
.89068 .32667 .89332 .33099 .89988 .32852 .89726 .32425 Metetra
.661 .739 .907 r
.30436 .50996 .30779 .51319 .31315 .51151 .30973 .50826 Metetra
.661 .738 .907 r
.30973 .50826 .31315 .51151 .31852 .50984 .3151 .50656 Metetra
.659 .736 .907 r
.3151 .50656 .31852 .50984 .3239 .50819 .32049 .50488 Metetra
.657 .734 .906 r
.32049 .50488 .3239 .50819 .32928 .50658 .32588 .50322 Metetra
.655 .731 .905 r
.32588 .50322 .32928 .50658 .33468 .50501 .33129 .5016 Metetra
.652 .727 .904 r
.33129 .5016 .33468 .50501 .34008 .50349 .3367 .50001 Metetra
.648 .722 .903 r
.3367 .50001 .34008 .50349 .34549 .50206 .34212 .49849 Metetra
.642 .716 .901 r
.34212 .49849 .34549 .50206 .35091 .50073 .34755 .49704 Metetra
.635 .707 .899 r
.34755 .49704 .35091 .50073 .35633 .49952 .35299 .4957 Metetra
.626 .697 .896 r
.35299 .4957 .35633 .49952 .36176 .49847 .35843 .49448 Metetra
.615 .684 .892 r
.35843 .49448 .36176 .49847 .36719 .49761 .36388 .49342 Metetra
.602 .669 .887 r
.36388 .49342 .36719 .49761 .37263 .49699 .36933 .49255 Metetra
.587 .651 .881 r
.36933 .49255 .37263 .49699 .37807 .49663 .37478 .49192 Metetra
.569 .63 .873 r
.37478 .49192 .37807 .49663 .38351 .49659 .38024 .49156 Metetra
.549 .608 .864 r
.38024 .49156 .38351 .49659 .38895 .49688 .3857 .4915 Metetra
.528 .583 .854 r
.3857 .4915 .38895 .49688 .3944 .49753 .39116 .49179 Metetra
.506 .558 .843 r
.39116 .49179 .3944 .49753 .39986 .49857 .39663 .49244 Metetra
.484 .532 .831 r
.39663 .49244 .39986 .49857 .40532 .49998 .40211 .49348 Metetra
.463 .508 .82 r
.40211 .49348 .40532 .49998 .41079 .50175 .40759 .49489 Metetra
.445 .487 .809 r
.40759 .49489 .41079 .50175 .41627 .50384 .41308 .49666 Metetra
.43 .469 .799 r
.41308 .49666 .41627 .50384 .42177 .50616 .41858 .49873 Metetra
.419 .456 .792 r
.41858 .49873 .42177 .50616 .42729 .50864 .42411 .50105 Metetra
.413 .449 .788 r
.42411 .50105 .42729 .50864 .43284 .51114 .42965 .50351 Metetra
.413 .448 .787 r
.42965 .50351 .43284 .51114 .43842 .51355 .43522 .50599 Metetra
.42 .454 .79 r
.43522 .50599 .43842 .51355 .44402 .51572 .44082 .50836 Metetra
.434 .469 .796 r
.44082 .50836 .44402 .51572 .44967 .51748 .44645 .51046 Metetra
.456 .492 .807 r
.44645 .51046 .44967 .51748 .45534 .51871 .45212 .51215 Metetra
.487 .523 .82 r
.45212 .51215 .45534 .51871 .46106 .51928 .45782 .51327 Metetra
.526 .564 .836 r
.45782 .51327 .46106 .51928 .4668 .51908 .46355 .5137 Metetra
.572 .611 .853 r
.46355 .5137 .4668 .51908 .47258 .51805 .46932 .51333 Metetra
.624 .662 .866 r
.46932 .51333 .47258 .51805 .47838 .51616 .47512 .51209 Metetra
.677 .712 .875 r
.47512 .51209 .47838 .51616 .48421 .51343 .48095 .50994 Metetra
.727 .757 .877 r
.48095 .50994 .48421 .51343 .49005 .50991 .4868 .5069 Metetra
.77 .791 .871 r
.4868 .5069 .49005 .50991 .49591 .50569 .49266 .503 Metetra
.803 .813 .859 r
.49266 .503 .49591 .50569 .50178 .50087 .49854 .49833 Metetra
.826 .821 .844 r
.49854 .49833 .50178 .50087 .50764 .4956 .50442 .49299 Metetra
.838 .817 .828 r
.50442 .49299 .50764 .4956 .51352 .49001 .5103 .48713 Metetra
.841 .802 .812 r
.5103 .48713 .51352 .49001 .51939 .48423 .51619 .48086 Metetra
.836 .778 .797 r
.51619 .48086 .51939 .48423 .52525 .47839 .52207 .47435 Metetra
.823 .749 .782 r
.52207 .47435 .52525 .47839 .53112 .4726 .52795 .46772 Metetra
.805 .717 .767 r
.52795 .46772 .53112 .4726 .53699 .46694 .53382 .46111 Metetra
.785 .684 .753 r
.53382 .46111 .53699 .46694 .54285 .4615 .53969 .45464 Metetra
.763 .652 .74 r
.53969 .45464 .54285 .4615 .54872 .45631 .54556 .44842 Metetra
.741 .623 .729 r
.54556 .44842 .54872 .45631 .55459 .45142 .55142 .44254 Metetra
.72 .598 .719 r
.55142 .44254 .55459 .45142 .56047 .44684 .55729 .43709 Metetra
.7 .576 .712 r
.55729 .43709 .56047 .44684 .56635 .44259 .56317 .43215 Metetra
.682 .557 .707 r
.56317 .43215 .56635 .44259 .57224 .4387 .56905 .42778 Metetra
.665 .542 .705 r
.56905 .42778 .57224 .4387 .57815 .43518 .57495 .42405 Metetra
.648 .53 .706 r
.57495 .42405 .57815 .43518 .58407 .43205 .58086 .42102 Metetra
.632 .521 .71 r
.58086 .42102 .58407 .43205 .59 .42935 .5868 .4187 Metetra
.614 .515 .719 r
.5868 .4187 .59 .42935 .59596 .42711 .59277 .41715 Metetra
.593 .512 .732 r
.59277 .41715 .59596 .42711 .60194 .42536 .59876 .41635 Metetra
.567 .512 .753 r
.59876 .41635 .60194 .42536 .60794 .42414 .60479 .4163 Metetra
.532 .516 .783 r
.60479 .4163 .60794 .42414 .61398 .42346 .61087 .41695 Metetra
.478 .523 .825 r
.61087 .41695 .61398 .42346 .62005 .42332 .61698 .41825 Metetra
.386 .53 .878 r
.61698 .41825 .62005 .42332 .62615 .42373 .62313 .42009 Metetra
.216 .516 .914 r
.62313 .42009 .62615 .42373 .6323 .42462 .62933 .42237 Metetra
0 .428 .833 r
.62933 .42237 .6323 .42462 .63848 .42594 .63556 .42495 Metetra
.334 0 0 r
.63556 .42495 .63848 .42594 .6447 .4276 .64183 .42768 Metetra
.474 0 0 r
.64183 .42768 .6447 .4276 .65096 .42948 .64814 .43041 Metetra
.519 0 0 r
.64814 .43041 .65096 .42948 .65725 .43147 .65446 .43296 Metetra
.519 0 0 r
.65446 .43296 .65725 .43147 .66357 .43341 .66081 .4352 Metetra
.492 0 0 r
.66081 .4352 .66357 .43341 .6699 .43518 .66716 .43699 Metetra
.439 0 0 r
.66716 .43699 .6699 .43518 .67625 .43664 .67352 .43822 Metetra
.347 0 0 r
.67352 .43822 .67625 .43664 .68261 .43767 .67987 .4388 Metetra
.188 0 0 r
.67987 .4388 .68261 .43767 .68897 .43816 .68621 .43867 Metetra
.68621 .43867 .68897 .43816 .69531 .43805 .69254 .4378 Metetra
.381 .841 .898 r
.69254 .4378 .69531 .43805 .70165 .43728 .69884 .4362 Metetra
.609 .91 .982 r
.69884 .4362 .70165 .43728 .70796 .43584 .70512 .43389 Metetra
.714 .88 .958 r
.70512 .43389 .70796 .43584 .71425 .43374 .71138 .43093 Metetra
.752 .827 .91 r
.71138 .43093 .71425 .43374 .72052 .431 .71761 .42739 Metetra
.764 .781 .867 r
.71761 .42739 .72052 .431 .72676 .4277 .72382 .42334 Metetra
.766 .745 .834 r
.72382 .42334 .72676 .4277 .73298 .42389 .73001 .41889 Metetra
.764 .718 .81 r
.73001 .41889 .73298 .42389 .73918 .41965 .73619 .41412 Metetra
.76 .699 .793 r
.73619 .41412 .73918 .41965 .74537 .41508 .74235 .40912 Metetra
.756 .684 .782 r
.74235 .40912 .74537 .41508 .75154 .41027 .74851 .40399 Metetra
.752 .674 .774 r
.74851 .40399 .75154 .41027 .7577 .4053 .75466 .3988 Metetra
.749 .666 .77 r
.75466 .3988 .7577 .4053 .76385 .40024 .76081 .39362 Metetra
.745 .662 .768 r
.76081 .39362 .76385 .40024 .77001 .39517 .76698 .38851 Metetra
.741 .659 .769 r
.76698 .38851 .77001 .39517 .77618 .39015 .77315 .38352 Metetra
.738 .659 .772 r
.77315 .38352 .77618 .39015 .78235 .38523 .77934 .37867 Metetra
.734 .659 .776 r
.77934 .37867 .78235 .38523 .78854 .38044 .78554 .37401 Metetra
.731 .661 .781 r
.78554 .37401 .78854 .38044 .79475 .37582 .79177 .36954 Metetra
.727 .664 .788 r
.79177 .36954 .79475 .37582 .80097 .37139 .79802 .36528 Metetra
.724 .668 .795 r
.79802 .36528 .80097 .37139 .80722 .36715 .80429 .36122 Metetra
.72 .672 .803 r
.80429 .36122 .80722 .36715 .81349 .3631 .81059 .35737 Metetra
.716 .677 .811 r
.81059 .35737 .81349 .3631 .81979 .35925 .81691 .35371 Metetra
.712 .682 .82 r
.81691 .35371 .81979 .35925 .82611 .3556 .82326 .35023 Metetra
.708 .688 .828 r
.82326 .35023 .82611 .3556 .83246 .35212 .82963 .34692 Metetra
.704 .693 .836 r
.82963 .34692 .83246 .35212 .83883 .34881 .83603 .34376 Metetra
.7 .698 .845 r
.83603 .34376 .83883 .34881 .84523 .34565 .84245 .34075 Metetra
.697 .703 .852 r
.84245 .34075 .84523 .34565 .85166 .34263 .8489 .33786 Metetra
.693 .708 .859 r
.8489 .33786 .85166 .34263 .8581 .33974 .85537 .33508 Metetra
.689 .712 .866 r
.85537 .33508 .8581 .33974 .86457 .33696 .86186 .3324 Metetra
.686 .716 .872 r
.86186 .3324 .86457 .33696 .87107 .33427 .86838 .3298 Metetra
.683 .72 .877 r
.86838 .3298 .87107 .33427 .87759 .33167 .87491 .32728 Metetra
.68 .723 .882 r
.87491 .32728 .87759 .33167 .88412 .32914 .88147 .32481 Metetra
.678 .726 .886 r
.88147 .32481 .88412 .32914 .89068 .32667 .88805 .3224 Metetra
.676 .728 .889 r
.88805 .3224 .89068 .32667 .89726 .32425 .89464 .32002 Metetra
.662 .74 .907 r
.30092 .50673 .30436 .50996 .30973 .50826 .30629 .50501 Metetra
.661 .739 .907 r
.30629 .50501 .30973 .50826 .3151 .50656 .31167 .50329 Metetra
.661 .738 .907 r
.31167 .50329 .3151 .50656 .32049 .50488 .31707 .50159 Metetra
.659 .736 .907 r
.31707 .50159 .32049 .50488 .32588 .50322 .32247 .4999 Metetra
.658 .734 .906 r
.32247 .4999 .32588 .50322 .33129 .5016 .32788 .49823 Metetra
.655 .731 .905 r
.32788 .49823 .33129 .5016 .3367 .50001 .33331 .49659 Metetra
.652 .727 .904 r
.33331 .49659 .3367 .50001 .34212 .49849 .33874 .49499 Metetra
.648 .722 .903 r
.33874 .49499 .34212 .49849 .34755 .49704 .34418 .49346 Metetra
.642 .716 .901 r
.34418 .49346 .34755 .49704 .35299 .4957 .34962 .492 Metetra
.635 .708 .899 r
.34962 .492 .35299 .4957 .35843 .49448 .35508 .49064 Metetra
.626 .697 .896 r
.35508 .49064 .35843 .49448 .36388 .49342 .36054 .48941 Metetra
.615 .685 .892 r
.36054 .48941 .36388 .49342 .36933 .49255 .366 .48834 Metetra
.602 .669 .887 r
.366 .48834 .36933 .49255 .37478 .49192 .37147 .48747 Metetra
.587 .651 .881 r
.37147 .48747 .37478 .49192 .38024 .49156 .37695 .48682 Metetra
.569 .631 .873 r
.37695 .48682 .38024 .49156 .3857 .4915 .38242 .48646 Metetra
.549 .608 .864 r
.38242 .48646 .3857 .4915 .39116 .49179 .3879 .4864 Metetra
.528 .583 .854 r
.3879 .4864 .39116 .49179 .39663 .49244 .39339 .48668 Metetra
.505 .558 .843 r
.39339 .48668 .39663 .49244 .40211 .49348 .39888 .48733 Metetra
.484 .532 .831 r
.39888 .48733 .40211 .49348 .40759 .49489 .40437 .48837 Metetra
.463 .508 .82 r
.40437 .48837 .40759 .49489 .41308 .49666 .40987 .48978 Metetra
.444 .487 .809 r
.40987 .48978 .41308 .49666 .41858 .49873 .41538 .49155 Metetra
.429 .469 .8 r
.41538 .49155 .41858 .49873 .42411 .50105 .42091 .49362 Metetra
.418 .456 .793 r
.42091 .49362 .42411 .50105 .42965 .50351 .42645 .49593 Metetra
.412 .449 .789 r
.42645 .49593 .42965 .50351 .43522 .50599 .43202 .49838 Metetra
.413 .449 .789 r
.43202 .49838 .43522 .50599 .44082 .50836 .43761 .50084 Metetra
.42 .456 .792 r
.43761 .50084 .44082 .50836 .44645 .51046 .44324 .50318 Metetra
.434 .472 .799 r
.44324 .50318 .44645 .51046 .45212 .51215 .44889 .50524 Metetra
.457 .496 .811 r
.44889 .50524 .45212 .51215 .45782 .51327 .45458 .50686 Metetra
.489 .53 .826 r
.45458 .50686 .45782 .51327 .46355 .5137 .4603 .5079 Metetra
.53 .574 .844 r
.4603 .5079 .46355 .5137 .46932 .51333 .46606 .50821 Metetra
.579 .625 .862 r
.46606 .50821 .46932 .51333 .47512 .51209 .47186 .50769 Metetra
.634 .682 .877 r
.47186 .50769 .47512 .51209 .48095 .50994 .47768 .50627 Metetra
.69 .738 .888 r
.47768 .50627 .48095 .50994 .4868 .5069 .48353 .50391 Metetra
.744 .791 .89 r
.48353 .50391 .4868 .5069 .49266 .503 .4894 .50062 Metetra
.79 .833 .885 r
.4894 .50062 .49266 .503 .49854 .49833 .49528 .49645 Metetra
.827 .864 .873 r
.49528 .49645 .49854 .49833 .50442 .49299 .50117 .49148 Metetra
.854 .883 .859 r
.50117 .49148 .50442 .49299 .5103 .48713 .50707 .48585 Metetra
.872 .894 .846 r
.50707 .48585 .5103 .48713 .51619 .48086 .51297 .4797 Metetra
.882 .897 .837 r
.51297 .4797 .51619 .48086 .52207 .47435 .51887 .4732 Metetra
.887 .897 .831 r
.51887 .4732 .52207 .47435 .52795 .46772 .52476 .46652 Metetra
.886 .895 .831 r
.52476 .46652 .52795 .46772 .53382 .46111 .53065 .45984 Metetra
.882 .893 .835 r
.53065 .45984 .53382 .46111 .53969 .45464 .53654 .45332 Metetra
.874 .895 .845 r
.53654 .45332 .53969 .45464 .54556 .44842 .54242 .44714 Metetra
.861 .903 .861 r
.54242 .44714 .54556 .44842 .55142 .44254 .54831 .44142 Metetra
.842 .92 .885 r
.54831 .44142 .55142 .44254 .55729 .43709 .55419 .4363 Metetra
.807 .947 .914 r
.55419 .4363 .55729 .43709 .56317 .43215 .56009 .43187 Metetra
.726 .971 .931 r
.56009 .43187 .56317 .43215 .56905 .42778 .566 .42822 Metetra
.521 .918 .86 r
.566 .42822 .56905 .42778 .57495 .42405 .57193 .4254 Metetra
.57193 .4254 .57495 .42405 .58086 .42102 .57788 .42342 Metetra
.199 0 0 r
.57788 .42342 .58086 .42102 .5868 .4187 .58386 .42229 Metetra
.39 0 .02 r
.58386 .42229 .5868 .4187 .59277 .41715 .58987 .42197 Metetra
.486 .062 .16 r
.58987 .42197 .59277 .41715 .59876 .41635 .59592 .4224 Metetra
.536 .142 .243 r
.59592 .4224 .59876 .41635 .60479 .4163 .602 .42351 Metetra
.563 .191 .293 r
.602 .42351 .60479 .4163 .61087 .41695 .60813 .42517 Metetra
.578 .22 .325 r
.60813 .42517 .61087 .41695 .61698 .41825 .61429 .42726 Metetra
.586 .237 .344 r
.61429 .42726 .61698 .41825 .62313 .42009 .62049 .42965 Metetra
.589 .245 .355 r
.62049 .42965 .62313 .42009 .62933 .42237 .62672 .43217 Metetra
.588 .246 .358 r
.62672 .43217 .62933 .42237 .63556 .42495 .63298 .43469 Metetra
.583 .241 .355 r
.63298 .43469 .63556 .42495 .64183 .42768 .63927 .43704 Metetra
.575 .229 .345 r
.63927 .43704 .64183 .42768 .64814 .43041 .64558 .43909 Metetra
.562 .208 .326 r
.64558 .43909 .64814 .43041 .65446 .43296 .6519 .44072 Metetra
.542 .176 .295 r
.6519 .44072 .65446 .43296 .66081 .4352 .65823 .44182 Metetra
.51 .125 .246 r
.65823 .44182 .66081 .4352 .66716 .43699 .66455 .44231 Metetra
.455 .042 .164 r
.66455 .44231 .66716 .43699 .67352 .43822 .67087 .44213 Metetra
.355 0 .021 r
.67087 .44213 .67352 .43822 .67987 .4388 .67718 .44125 Metetra
.151 0 0 r
.67718 .44125 .67987 .4388 .68621 .43867 .68347 .43968 Metetra
.68347 .43968 .68621 .43867 .69254 .4378 .68974 .43742 Metetra
.608 .944 .938 r
.68974 .43742 .69254 .4378 .69884 .4362 .69599 .43452 Metetra
.745 .906 .948 r
.69599 .43452 .69884 .4362 .70512 .43389 .70223 .43104 Metetra
.773 .829 .896 r
.70223 .43104 .70512 .43389 .71138 .43093 .70844 .42706 Metetra
.773 .77 .85 r
.70844 .42706 .71138 .43093 .71761 .42739 .71463 .42264 Metetra
.768 .729 .817 r
.71463 .42264 .71761 .42739 .72382 .42334 .72081 .41788 Metetra
.762 .701 .795 r
.72081 .41788 .72382 .42334 .73001 .41889 .72697 .41286 Metetra
.757 .682 .779 r
.72697 .41286 .73001 .41889 .73619 .41412 .73312 .40768 Metetra
.752 .669 .77 r
.73312 .40768 .73619 .41412 .74235 .40912 .73928 .4024 Metetra
.748 .66 .764 r
.73928 .4024 .74235 .40912 .74851 .40399 .74543 .3971 Metetra
.744 .655 .761 r
.74543 .3971 .74851 .40399 .75466 .3988 .75158 .39184 Metetra
.741 .652 .761 r
.75158 .39184 .75466 .3988 .76081 .39362 .75774 .38667 Metetra
.738 .651 .763 r
.75774 .38667 .76081 .39362 .76698 .38851 .76392 .38163 Metetra
.735 .651 .767 r
.76392 .38163 .76698 .38851 .77315 .38352 .77011 .37677 Metetra
.732 .653 .772 r
.77011 .37677 .77315 .38352 .77934 .37867 .77632 .37209 Metetra
.729 .656 .778 r
.77632 .37209 .77934 .37867 .78554 .37401 .78254 .36762 Metetra
.726 .66 .785 r
.78254 .36762 .78554 .37401 .79177 .36954 .7888 .36335 Metetra
.722 .665 .793 r
.7888 .36335 .79177 .36954 .79802 .36528 .79507 .35929 Metetra
.719 .67 .801 r
.79507 .35929 .79802 .36528 .80429 .36122 .80137 .35544 Metetra
.715 .676 .81 r
.80137 .35544 .80429 .36122 .81059 .35737 .80769 .35179 Metetra
.712 .681 .819 r
.80769 .35179 .81059 .35737 .81691 .35371 .81404 .34832 Metetra
.708 .687 .828 r
.81404 .34832 .81691 .35371 .82326 .35023 .82041 .34501 Metetra
.704 .693 .837 r
.82041 .34501 .82326 .35023 .82963 .34692 .82681 .34187 Metetra
.7 .698 .845 r
.82681 .34187 .82963 .34692 .83603 .34376 .83323 .33886 Metetra
.696 .703 .853 r
.83323 .33886 .83603 .34376 .84245 .34075 .83968 .33598 Metetra
.693 .708 .86 r
.83968 .33598 .84245 .34075 .8489 .33786 .84615 .33321 Metetra
.689 .712 .866 r
.84615 .33321 .8489 .33786 .85537 .33508 .85264 .33053 Metetra
.686 .716 .872 r
.85264 .33053 .85537 .33508 .86186 .3324 .85915 .32794 Metetra
.683 .72 .877 r
.85915 .32794 .86186 .3324 .86838 .3298 .86568 .32541 Metetra
.68 .723 .882 r
.86568 .32541 .86838 .3298 .87491 .32728 .87224 .32295 Metetra
.678 .726 .886 r
.87224 .32295 .87491 .32728 .88147 .32481 .87881 .32054 Metetra
.675 .728 .89 r
.87881 .32054 .88147 .32481 .88805 .3224 .8854 .31817 Metetra
.673 .73 .893 r
.8854 .31817 .88805 .3224 .89464 .32002 .89201 .31583 Metetra
.663 .74 .908 r
.29746 .5035 .30092 .50673 .30629 .50501 .30284 .50176 Metetra
.662 .74 .907 r
.30284 .50176 .30629 .50501 .31167 .50329 .30823 .50003 Metetra
.662 .739 .907 r
.30823 .50003 .31167 .50329 .31707 .50159 .31363 .4983 Metetra
.661 .738 .907 r
.31363 .4983 .31707 .50159 .32247 .4999 .31904 .49658 Metetra
.659 .736 .907 r
.31904 .49658 .32247 .4999 .32788 .49823 .32446 .49488 Metetra
.658 .734 .906 r
.32446 .49488 .32788 .49823 .33331 .49659 .32989 .4932 Metetra
.655 .731 .905 r
.32989 .4932 .33331 .49659 .33874 .49499 .33533 .49155 Metetra
.652 .728 .904 r
.33533 .49155 .33874 .49499 .34418 .49346 .34078 .48994 Metetra
.648 .723 .903 r
.34078 .48994 .34418 .49346 .34962 .492 .34624 .4884 Metetra
.642 .716 .901 r
.34624 .4884 .34962 .492 .35508 .49064 .35171 .48693 Metetra
.635 .708 .899 r
.35171 .48693 .35508 .49064 .36054 .48941 .35718 .48556 Metetra
.626 .698 .896 r
.35718 .48556 .36054 .48941 .366 .48834 .36266 .48432 Metetra
.615 .685 .892 r
.36266 .48432 .366 .48834 .37147 .48747 .36814 .48324 Metetra
.602 .669 .887 r
.36814 .48324 .37147 .48747 .37695 .48682 .37363 .48235 Metetra
.586 .651 .881 r
.37363 .48235 .37695 .48682 .38242 .48646 .37912 .4817 Metetra
.568 .63 .873 r
.37912 .4817 .38242 .48646 .3879 .4864 .38462 .48133 Metetra
.548 .607 .864 r
.38462 .48133 .3879 .4864 .39339 .48668 .39012 .48127 Metetra
.527 .583 .854 r
.39012 .48127 .39339 .48668 .39888 .48733 .39562 .48155 Metetra
.505 .557 .843 r
.39562 .48155 .39888 .48733 .40437 .48837 .40113 .48221 Metetra
.482 .532 .832 r
.40113 .48221 .40437 .48837 .40987 .48978 .40665 .48325 Metetra
.461 .508 .82 r
.40665 .48325 .40987 .48978 .41538 .49155 .41217 .48467 Metetra
.442 .486 .81 r
.41217 .48467 .41538 .49155 .42091 .49362 .4177 .48645 Metetra
.426 .469 .801 r
.4177 .48645 .42091 .49362 .42645 .49593 .42325 .48855 Metetra
.414 .456 .795 r
.42325 .48855 .42645 .49593 .43202 .49838 .42881 .49089 Metetra
.406 .449 .792 r
.42881 .49089 .43202 .49838 .43761 .50084 .4344 .49337 Metetra
.404 .448 .793 r
.4344 .49337 .43761 .50084 .44324 .50318 .44002 .49588 Metetra
.408 .456 .799 r
.44002 .49588 .44324 .50318 .44889 .50524 .44566 .49828 Metetra
.418 .473 .81 r
.44566 .49828 .44889 .50524 .45458 .50686 .45134 .50042 Metetra
.436 .501 .827 r
.45134 .50042 .45458 .50686 .4603 .5079 .45705 .50215 Metetra
.462 .541 .852 r
.45705 .50215 .4603 .5079 .46606 .50821 .46279 .50333 Metetra
.497 .598 .885 r
.46279 .50333 .46606 .50821 .47186 .50769 .46857 .50383 Metetra
.54 .674 .925 r
.46857 .50383 .47186 .50769 .47768 .50627 .47438 .50356 Metetra
.589 .77 .966 r
.47438 .50356 .47768 .50627 .48353 .50391 .48022 .50245 Metetra
.629 .875 .988 r
.48022 .50245 .48353 .50391 .4894 .50062 .48609 .50049 Metetra
.623 .947 .941 r
.48609 .50049 .4894 .50062 .49528 .49645 .49197 .49769 Metetra
.523 .91 .77 r
.49197 .49769 .49528 .49645 .50117 .49148 .49788 .49414 Metetra
.49788 .49414 .50117 .49148 .50707 .48585 .50379 .48993 Metetra
.50379 .48993 .50707 .48585 .51297 .4797 .50971 .4852 Metetra
.50971 .4852 .51297 .4797 .51887 .4732 .51563 .48012 Metetra
.112 0 .07 r
.51563 .48012 .51887 .4732 .52476 .46652 .52155 .47485 Metetra
.204 0 .168 r
.52155 .47485 .52476 .46652 .53065 .45984 .52748 .46958 Metetra
.277 0 .238 r
.52748 .46958 .53065 .45984 .53654 .45332 .5334 .46447 Metetra
.335 .03 .291 r
.5334 .46447 .53654 .45332 .54242 .44714 .53933 .45967 Metetra
.382 .085 .331 r
.53933 .45967 .54242 .44714 .54831 .44142 .54527 .4553 Metetra
.42 .129 .361 r
.54527 .4553 .54831 .44142 .55419 .4363 .55121 .45148 Metetra
.451 .164 .384 r
.55121 .45148 .55419 .4363 .56009 .43187 .55716 .44826 Metetra
.476 .192 .402 r
.55716 .44826 .56009 .43187 .566 .42822 .56313 .44568 Metetra
.496 .214 .415 r
.56313 .44568 .566 .42822 .57193 .4254 .56912 .44376 Metetra
.512 .231 .425 r
.56912 .44376 .57193 .4254 .57788 .42342 .57513 .44246 Metetra
.524 .244 .432 r
.57513 .44246 .57788 .42342 .58386 .42229 .58117 .44173 Metetra
.534 .254 .437 r
.58117 .44173 .58386 .42229 .58987 .42197 .58723 .44152 Metetra
.541 .261 .439 r
.58723 .44152 .58987 .42197 .59592 .4224 .59332 .44173 Metetra
.546 .264 .438 r
.59332 .44173 .59592 .4224 .602 .42351 .59944 .44227 Metetra
.55 .265 .436 r
.59944 .44227 .602 .42351 .60813 .42517 .60559 .44303 Metetra
.551 .263 .431 r
.60559 .44303 .60813 .42517 .61429 .42726 .61177 .4439 Metetra
.551 .257 .422 r
.61177 .4439 .61429 .42726 .62049 .42965 .61797 .44479 Metetra
.548 .247 .41 r
.61797 .44479 .62049 .42965 .62672 .43217 .62419 .44558 Metetra
.541 .231 .392 r
.62419 .44558 .62672 .43217 .63298 .43469 .63043 .44619 Metetra
.53 .207 .365 r
.63043 .44619 .63298 .43469 .63927 .43704 .63668 .44653 Metetra
.511 .169 .324 r
.63668 .44653 .63927 .43704 .64558 .43909 .64294 .44652 Metetra
.477 .107 .258 r
.64294 .44652 .64558 .43909 .6519 .44072 .64921 .44609 Metetra
.411 0 .145 r
.64921 .44609 .6519 .44072 .65823 .44182 .65548 .44521 Metetra
.268 0 0 r
.65548 .44521 .65823 .44182 .66455 .44231 .66175 .44382 Metetra
.66175 .44382 .66455 .44231 .67087 .44213 .66801 .44192 Metetra
.519 .912 .92 r
.66801 .44192 .67087 .44213 .67718 .44125 .67427 .4395 Metetra
.707 .892 .964 r
.67427 .4395 .67718 .44125 .68347 .43968 .68051 .43658 Metetra
.743 .805 .902 r
.68051 .43658 .68347 .43968 .68974 .43742 .68673 .43316 Metetra
.746 .743 .849 r
.68673 .43316 .68974 .43742 .69599 .43452 .69295 .42931 Metetra
.744 .703 .813 r
.69295 .42931 .69599 .43452 .70223 .43104 .69914 .42505 Metetra
.741 .676 .788 r
.69914 .42505 .70223 .43104 .70844 .42706 .70533 .42047 Metetra
.738 .659 .772 r
.70533 .42047 .70844 .42706 .71463 .42264 .7115 .41561 Metetra
.737 .648 .761 r
.7115 .41561 .71463 .42264 .72081 .41788 .71767 .41056 Metetra
.736 .641 .754 r
.71767 .41056 .72081 .41788 .72697 .41286 .72383 .40537 Metetra
.735 .637 .75 r
.72383 .40537 .72697 .41286 .73312 .40768 .72998 .40011 Metetra
.734 .635 .749 r
.72998 .40011 .73312 .40768 .73928 .4024 .73614 .39485 Metetra
.733 .635 .75 r
.73614 .39485 .73928 .4024 .74543 .3971 .7423 .38963 Metetra
.732 .637 .753 r
.7423 .38963 .74543 .3971 .75158 .39184 .74847 .38451 Metetra
.731 .639 .757 r
.74847 .38451 .75158 .39184 .75774 .38667 .75465 .37952 Metetra
.73 .643 .762 r
.75465 .37952 .75774 .38667 .76392 .38163 .76085 .37469 Metetra
.728 .647 .768 r
.76085 .37469 .76392 .38163 .77011 .37677 .76706 .37005 Metetra
.726 .652 .776 r
.76706 .37005 .77011 .37677 .77632 .37209 .7733 .36561 Metetra
.723 .657 .784 r
.7733 .36561 .77632 .37209 .78254 .36762 .77955 .36137 Metetra
.721 .663 .792 r
.77955 .36137 .78254 .36762 .7888 .36335 .78583 .35734 Metetra
.718 .669 .801 r
.78583 .35734 .7888 .36335 .79507 .35929 .79213 .3535 Metetra
.714 .675 .81 r
.79213 .3535 .79507 .35929 .80137 .35544 .79845 .34986 Metetra
.711 .681 .82 r
.79845 .34986 .80137 .35544 .80769 .35179 .8048 .3464 Metetra
.707 .687 .829 r
.8048 .3464 .80769 .35179 .81404 .34832 .81118 .34311 Metetra
.704 .693 .837 r
.81118 .34311 .81404 .34832 .82041 .34501 .81757 .33998 Metetra
.7 .699 .846 r
.81757 .33998 .82041 .34501 .82681 .34187 .82399 .33698 Metetra
.696 .704 .853 r
.82399 .33698 .82681 .34187 .83323 .33886 .83044 .3341 Metetra
.692 .709 .861 r
.83044 .3341 .83323 .33886 .83968 .33598 .83691 .33133 Metetra
.689 .713 .867 r
.83691 .33133 .83968 .33598 .84615 .33321 .8434 .32866 Metetra
.686 .717 .873 r
.8434 .32866 .84615 .33321 .85264 .33053 .84991 .32607 Metetra
.683 .721 .878 r
.84991 .32607 .85264 .33053 .85915 .32794 .85644 .32355 Metetra
.68 .724 .883 r
.85644 .32355 .85915 .32794 .86568 .32541 .86299 .32109 Metetra
.677 .726 .887 r
.86299 .32109 .86568 .32541 .87224 .32295 .86956 .31868 Metetra
.675 .729 .89 r
.86956 .31868 .87224 .32295 .87881 .32054 .87615 .31631 Metetra
.673 .731 .893 r
.87615 .31631 .87881 .32054 .8854 .31817 .88276 .31398 Metetra
.672 .732 .896 r
.88276 .31398 .8854 .31817 .89201 .31583 .88938 .31167 Metetra
.663 .741 .908 r
.29399 .50026 .29746 .5035 .30284 .50176 .29938 .49851 Metetra
.663 .74 .908 r
.29938 .49851 .30284 .50176 .30823 .50003 .30477 .49676 Metetra
.662 .74 .907 r
.30477 .49676 .30823 .50003 .31363 .4983 .31018 .49502 Metetra
.662 .739 .907 r
.31018 .49502 .31363 .4983 .31904 .49658 .3156 .49328 Metetra
.661 .738 .907 r
.3156 .49328 .31904 .49658 .32446 .49488 .32103 .49155 Metetra
.659 .736 .907 r
.32103 .49155 .32446 .49488 .32989 .4932 .32647 .48984 Metetra
.658 .734 .906 r
.32647 .48984 .32989 .4932 .33533 .49155 .33192 .48815 Metetra
.655 .732 .905 r
.33192 .48815 .33533 .49155 .34078 .48994 .33738 .48648 Metetra
.652 .728 .904 r
.33738 .48648 .34078 .48994 .34624 .4884 .34284 .48487 Metetra
.648 .723 .903 r
.34284 .48487 .34624 .4884 .35171 .48693 .34832 .48331 Metetra
.642 .716 .901 r
.34832 .48331 .35171 .48693 .35718 .48556 .3538 .48182 Metetra
.635 .708 .899 r
.3538 .48182 .35718 .48556 .36266 .48432 .35929 .48044 Metetra
.626 .698 .896 r
.35929 .48044 .36266 .48432 .36814 .48324 .36479 .47919 Metetra
.615 .685 .892 r
.36479 .47919 .36814 .48324 .37363 .48235 .3703 .4781 Metetra
.602 .669 .887 r
.3703 .4781 .37363 .48235 .37912 .4817 .3758 .47721 Metetra
.586 .651 .881 r
.3758 .47721 .37912 .4817 .38462 .48133 .38131 .47655 Metetra
.568 .63 .873 r
.38131 .47655 .38462 .48133 .39012 .48127 .38683 .47617 Metetra
.548 .607 .864 r
.38683 .47617 .39012 .48127 .39562 .48155 .39235 .47611 Metetra
.526 .582 .854 r
.39235 .47611 .39562 .48155 .40113 .48221 .39787 .47639 Metetra
.504 .557 .843 r
.39787 .47639 .40113 .48221 .40665 .48325 .4034 .47705 Metetra
.481 .531 .831 r
.4034 .47705 .40665 .48325 .41217 .48467 .40894 .4781 Metetra
.46 .507 .82 r
.40894 .4781 .41217 .48467 .4177 .48645 .41448 .47954 Metetra
.44 .485 .81 r
.41448 .47954 .4177 .48645 .42325 .48855 .42003 .48135 Metetra
.423 .467 .801 r
.42003 .48135 .42325 .48855 .42881 .49089 .4256 .48348 Metetra
.409 .453 .795 r
.4256 .48348 .42881 .49089 .4344 .49337 .43119 .48588 Metetra
.399 .445 .792 r
.43119 .48588 .4344 .49337 .44002 .49588 .43679 .48843 Metetra
.394 .444 .794 r
.43679 .48843 .44002 .49588 .44566 .49828 .44243 .49105 Metetra
.393 .45 .801 r
.44243 .49105 .44566 .49828 .45134 .50042 .44809 .49359 Metetra
.397 .465 .814 r
.44809 .49359 .45134 .50042 .45705 .50215 .45379 .49593 Metetra
.405 .492 .835 r
.45379 .49593 .45705 .50215 .46279 .50333 .45952 .49792 Metetra
.418 .533 .867 r
.45952 .49792 .46279 .50333 .46857 .50383 .46528 .49945 Metetra
.433 .594 .911 r
.46528 .49945 .46857 .50383 .47438 .50356 .47108 .5004 Metetra
.444 .679 .964 r
.47108 .5004 .47438 .50356 .48022 .50245 .4769 .50068 Metetra
.428 .778 .997 r
.4769 .50068 .48022 .50245 .48609 .50049 .48276 .50027 Metetra
.323 .805 .892 r
.48276 .50027 .48609 .50049 .49197 .49769 .48864 .49914 Metetra
.48864 .49914 .49197 .49769 .49788 .49414 .49455 .49733 Metetra
.076 0 0 r
.49455 .49733 .49788 .49414 .50379 .48993 .50047 .4949 Metetra
.194 0 .002 r
.50047 .4949 .50379 .48993 .50971 .4852 .50641 .49195 Metetra
.268 0 .136 r
.50641 .49195 .50971 .4852 .51563 .48012 .51235 .48859 Metetra
.319 0 .22 r
.51235 .48859 .51563 .48012 .52155 .47485 .51831 .48494 Metetra
.356 .034 .276 r
.51831 .48494 .52155 .47485 .52748 .46958 .52427 .48114 Metetra
.384 .076 .314 r
.52427 .48114 .52748 .46958 .5334 .46447 .53023 .47729 Metetra
.407 .107 .341 r
.53023 .47729 .5334 .46447 .53933 .45967 .5362 .47352 Metetra
.425 .131 .36 r
.5362 .47352 .53933 .45967 .54527 .4553 .54218 .46989 Metetra
.439 .148 .373 r
.54218 .46989 .54527 .4553 .55121 .45148 .54817 .46648 Metetra
.45 .16 .38 r
.54817 .46648 .55121 .45148 .55716 .44826 .55417 .46332 Metetra
.458 .168 .384 r
.55417 .46332 .55716 .44826 .56313 .44568 .56018 .46043 Metetra
.464 .171 .382 r
.56018 .46043 .56313 .44568 .56912 .44376 .5662 .45783 Metetra
.467 .17 .377 r
.5662 .45783 .56912 .44376 .57513 .44246 .57224 .4555 Metetra
.468 .163 .365 r
.57224 .4555 .57513 .44246 .58117 .44173 .57829 .45343 Metetra
.464 .149 .346 r
.57829 .45343 .58117 .44173 .58723 .44152 .58436 .4516 Metetra
.456 .126 .316 r
.58436 .4516 .58723 .44152 .59332 .44173 .59045 .44998 Metetra
.44 .087 .268 r
.59045 .44998 .59332 .44173 .59944 .44227 .59655 .44854 Metetra
.408 .019 .186 r
.59655 .44854 .59944 .44227 .60559 .44303 .60268 .44726 Metetra
.341 0 .036 r
.60268 .44726 .60559 .44303 .61177 .4439 .60882 .4461 Metetra
.181 0 0 r
.60882 .4461 .61177 .4439 .61797 .44479 .61499 .44503 Metetra
.174 .71 .764 r
.61499 .44503 .61797 .44479 .62419 .44558 .62117 .444 Metetra
.494 .827 .999 r
.62117 .444 .62419 .44558 .63043 .44619 .62737 .44296 Metetra
.591 .745 .95 r
.62737 .44296 .63043 .44619 .63668 .44653 .63358 .44186 Metetra
.616 .672 .881 r
.63358 .44186 .63668 .44653 .64294 .44652 .63981 .44063 Metetra
.625 .627 .832 r
.63981 .44063 .64294 .44652 .64921 .44609 .64605 .43922 Metetra
.632 .6 .799 r
.64605 .43922 .64921 .44609 .65548 .44521 .65229 .43756 Metetra
.638 .584 .777 r
.65229 .43756 .65548 .44521 .66175 .44382 .65853 .4356 Metetra
.646 .576 .762 r
.65853 .4356 .66175 .44382 .66801 .44192 .66478 .4333 Metetra
.654 .574 .752 r
.66478 .4333 .66801 .44192 .67427 .4395 .67102 .43063 Metetra
.663 .574 .745 r
.67102 .43063 .67427 .4395 .68051 .43658 .67726 .42757 Metetra
.672 .577 .74 r
.67726 .42757 .68051 .43658 .68673 .43316 .68348 .42413 Metetra
.681 .582 .737 r
.68348 .42413 .68673 .43316 .69295 .42931 .6897 .42032 Metetra
.69 .587 .735 r
.6897 .42032 .69295 .42931 .69914 .42505 .6959 .41617 Metetra
.698 .593 .735 r
.6959 .41617 .69914 .42505 .70533 .42047 .7021 .41173 Metetra
.705 .599 .735 r
.7021 .41173 .70533 .42047 .7115 .41561 .70829 .40706 Metetra
.711 .605 .737 r
.70829 .40706 .7115 .41561 .71767 .41056 .71447 .4022 Metetra
.716 .612 .739 r
.71447 .4022 .71767 .41056 .72383 .40537 .72064 .39723 Metetra
.721 .618 .742 r
.72064 .39723 .72383 .40537 .72998 .40011 .72682 .39221 Metetra
.724 .624 .746 r
.72682 .39221 .72998 .40011 .73614 .39485 .73299 .38719 Metetra
.726 .63 .751 r
.73299 .38719 .73614 .39485 .7423 .38963 .73918 .38222 Metetra
.727 .636 .757 r
.73918 .38222 .7423 .38963 .74847 .38451 .74537 .37735 Metetra
.727 .642 .763 r
.74537 .37735 .74847 .38451 .75465 .37952 .75158 .37261 Metetra
.727 .648 .77 r
.75158 .37261 .75465 .37952 .76085 .37469 .7578 .36804 Metetra
.725 .654 .778 r
.7578 .36804 .76085 .37469 .76706 .37005 .76404 .36364 Metetra
.724 .66 .786 r
.76404 .36364 .76706 .37005 .7733 .36561 .77029 .35944 Metetra
.721 .666 .795 r
.77029 .35944 .7733 .36561 .77955 .36137 .77657 .35543 Metetra
.718 .672 .804 r
.77657 .35543 .77955 .36137 .78583 .35734 .78288 .35161 Metetra
.715 .678 .813 r
.78288 .35161 .78583 .35734 .79213 .3535 .7892 .34798 Metetra
.711 .684 .822 r
.7892 .34798 .79213 .3535 .79845 .34986 .79555 .34453 Metetra
.708 .69 .831 r
.79555 .34453 .79845 .34986 .8048 .3464 .80193 .34124 Metetra
.704 .695 .839 r
.80193 .34124 .8048 .3464 .81118 .34311 .80832 .33811 Metetra
.7 .701 .847 r
.80832 .33811 .81118 .34311 .81757 .33998 .81474 .33511 Metetra
.696 .706 .855 r
.81474 .33511 .81757 .33998 .82399 .33698 .82119 .33224 Metetra
.692 .71 .862 r
.82119 .33224 .82399 .33698 .83044 .3341 .82765 .32947 Metetra
.689 .714 .868 r
.82765 .32947 .83044 .3341 .83691 .33133 .83414 .3268 Metetra
.685 .718 .874 r
.83414 .3268 .83691 .33133 .8434 .32866 .84065 .32421 Metetra
.682 .721 .879 r
.84065 .32421 .8434 .32866 .84991 .32607 .84717 .3217 Metetra
.68 .724 .883 r
.84717 .3217 .84991 .32607 .85644 .32355 .85372 .31924 Metetra
.677 .727 .887 r
.85372 .31924 .85644 .32355 .86299 .32109 .86029 .31683 Metetra
.675 .729 .891 r
.86029 .31683 .86299 .32109 .86956 .31868 .86688 .31446 Metetra
.673 .731 .894 r
.86688 .31446 .86956 .31868 .87615 .31631 .87348 .31212 Metetra
.671 .733 .896 r
.87348 .31212 .87615 .31631 .88276 .31398 .88011 .30981 Metetra
.67 .734 .898 r
.88011 .30981 .88276 .31398 .88938 .31167 .88675 .30753 Metetra
.663 .741 .908 r
.29051 .497 .29399 .50026 .29938 .49851 .2959 .49525 Metetra
.663 .741 .908 r
.2959 .49525 .29938 .49851 .30477 .49676 .3013 .49349 Metetra
.663 .74 .908 r
.3013 .49349 .30477 .49676 .31018 .49502 .30672 .49173 Metetra
.662 .74 .907 r
.30672 .49173 .31018 .49502 .3156 .49328 .31214 .48998 Metetra
.662 .739 .907 r
.31214 .48998 .3156 .49328 .32103 .49155 .31758 .48823 Metetra
.661 .738 .907 r
.31758 .48823 .32103 .49155 .32647 .48984 .32303 .48649 Metetra
.66 .736 .907 r
.32303 .48649 .32647 .48984 .33192 .48815 .32848 .48476 Metetra
.658 .734 .906 r
.32848 .48476 .33192 .48815 .33738 .48648 .33395 .48306 Metetra
.655 .732 .905 r
.33395 .48306 .33738 .48648 .34284 .48487 .33943 .48139 Metetra
.652 .728 .905 r
.33943 .48139 .34284 .48487 .34832 .48331 .34491 .47976 Metetra
.648 .723 .903 r
.34491 .47976 .34832 .48331 .3538 .48182 .35041 .47819 Metetra
.643 .717 .901 r
.35041 .47819 .3538 .48182 .35929 .48044 .35591 .47669 Metetra
.635 .708 .899 r
.35591 .47669 .35929 .48044 .36479 .47919 .36142 .4753 Metetra
.627 .698 .896 r
.36142 .4753 .36479 .47919 .3703 .4781 .36694 .47404 Metetra
.615 .685 .892 r
.36694 .47404 .3703 .4781 .3758 .47721 .37246 .47294 Metetra
.602 .669 .887 r
.37246 .47294 .3758 .47721 .38131 .47655 .37799 .47203 Metetra
.586 .651 .881 r
.37799 .47203 .38131 .47655 .38683 .47617 .38352 .47137 Metetra
.568 .63 .873 r
.38352 .47137 .38683 .47617 .39235 .47611 .38905 .47098 Metetra
.548 .607 .864 r
.38905 .47098 .39235 .47611 .39787 .47639 .39459 .4709 Metetra
.527 .582 .853 r
.39459 .4709 .39787 .47639 .4034 .47705 .40014 .47118 Metetra
.505 .556 .842 r
.40014 .47118 .4034 .47705 .40894 .4781 .40568 .47183 Metetra
.483 .53 .829 r
.40568 .47183 .40894 .4781 .41448 .47954 .41124 .47287 Metetra
.462 .505 .817 r
.41124 .47287 .41448 .47954 .42003 .48135 .4168 .4743 Metetra
.444 .483 .806 r
.4168 .4743 .42003 .48135 .4256 .48348 .42238 .47609 Metetra
.428 .465 .796 r
.42238 .47609 .4256 .48348 .43119 .48588 .42797 .4782 Metetra
.417 .451 .788 r
.42797 .4782 .43119 .48588 .43679 .48843 .43358 .48057 Metetra
.411 .443 .783 r
.43358 .48057 .43679 .48843 .44243 .49105 .43921 .4831 Metetra
.41 .441 .781 r
.43921 .4831 .44243 .49105 .44809 .49359 .44487 .48568 Metetra
.415 .445 .783 r
.44487 .48568 .44809 .49359 .45379 .49593 .45056 .48818 Metetra
.426 .456 .788 r
.45056 .48818 .45379 .49593 .45952 .49792 .45628 .49047 Metetra
.444 .475 .797 r
.45628 .49047 .45952 .49792 .46528 .49945 .46203 .49241 Metetra
.468 .502 .81 r
.46203 .49241 .46528 .49945 .47108 .5004 .46781 .49388 Metetra
.5 .535 .825 r
.46781 .49388 .47108 .5004 .4769 .50068 .47363 .49475 Metetra
.537 .576 .841 r
.47363 .49475 .4769 .50068 .48276 .50027 .47948 .49495 Metetra
.579 .62 .857 r
.47948 .49495 .48276 .50027 .48864 .49914 .48536 .49441 Metetra
.624 .666 .87 r
.48536 .49441 .48864 .49914 .49455 .49733 .49127 .49312 Metetra
.668 .707 .877 r
.49127 .49312 .49455 .49733 .50047 .4949 .4972 .49108 Metetra
.707 .74 .877 r
.4972 .49108 .50047 .4949 .50641 .49195 .50314 .48833 Metetra
.738 .759 .869 r
.50314 .48833 .50641 .49195 .51235 .48859 .50909 .48494 Metetra
.76 .762 .855 r
.50909 .48494 .51235 .48859 .51831 .48494 .51506 .48101 Metetra
.77 .751 .835 r
.51506 .48101 .51831 .48494 .52427 .48114 .52103 .47663 Metetra
.769 .726 .812 r
.52103 .47663 .52427 .48114 .53023 .47729 .527 .47191 Metetra
.759 .692 .787 r
.527 .47191 .53023 .47729 .5362 .47352 .53298 .46696 Metetra
.743 .654 .762 r
.53298 .46696 .5362 .47352 .54218 .46989 .53896 .4619 Metetra
.723 .616 .738 r
.53896 .4619 .54218 .46989 .54817 .46648 .54494 .45684 Metetra
.702 .58 .716 r
.54494 .45684 .54817 .46648 .55417 .46332 .55092 .45188 Metetra
.682 .549 .697 r
.55092 .45188 .55417 .46332 .56018 .46043 .55691 .44711 Metetra
.663 .521 .681 r
.55691 .44711 .56018 .46043 .5662 .45783 .5629 .44263 Metetra
.646 .498 .668 r
.5629 .44263 .5662 .45783 .57224 .4555 .5689 .43852 Metetra
.631 .479 .658 r
.5689 .43852 .57224 .4555 .57829 .45343 .57491 .43485 Metetra
.618 .463 .65 r
.57491 .43485 .57829 .45343 .58436 .4516 .58094 .43167 Metetra
.606 .45 .644 r
.58094 .43167 .58436 .4516 .59045 .44998 .58698 .42903 Metetra
.596 .44 .64 r
.58698 .42903 .59045 .44998 .59655 .44854 .59305 .42694 Metetra
.587 .431 .637 r
.59305 .42694 .59655 .44854 .60268 .44726 .59915 .42539 Metetra
.579 .425 .637 r
.59915 .42539 .60268 .44726 .60882 .4461 .60527 .42434 Metetra
.573 .421 .637 r
.60527 .42434 .60882 .4461 .61499 .44503 .61142 .42374 Metetra
.568 .419 .64 r
.61142 .42374 .61499 .44503 .62117 .444 .6176 .42348 Metetra
.564 .419 .643 r
.6176 .42348 .62117 .444 .62737 .44296 .6238 .42347 Metetra
.562 .422 .649 r
.6238 .42347 .62737 .44296 .63358 .44186 .63003 .42357 Metetra
.563 .428 .655 r
.63003 .42357 .63358 .44186 .63981 .44063 .63629 .42366 Metetra
.566 .437 .664 r
.63629 .42366 .63981 .44063 .64605 .43922 .64255 .4236 Metetra
.572 .449 .674 r
.64255 .4236 .64605 .43922 .65229 .43756 .64883 .42327 Metetra
.581 .464 .684 r
.64883 .42327 .65229 .43756 .65853 .4356 .65512 .42257 Metetra
.594 .482 .696 r
.65512 .42257 .65853 .4356 .66478 .4333 .66141 .42141 Metetra
.61 .503 .708 r
.66141 .42141 .66478 .4333 .67102 .43063 .66769 .41975 Metetra
.627 .525 .719 r
.66769 .41975 .67102 .43063 .67726 .42757 .67396 .41756 Metetra
.646 .547 .729 r
.67396 .41756 .67726 .42757 .68348 .42413 .68022 .41484 Metetra
.664 .568 .737 r
.68022 .41484 .68348 .42413 .6897 .42032 .68646 .41161 Metetra
.681 .587 .744 r
.68646 .41161 .6897 .42032 .6959 .41617 .69269 .40794 Metetra
.696 .603 .749 r
.69269 .40794 .6959 .41617 .7021 .41173 .69891 .40387 Metetra
.708 .617 .753 r
.69891 .40387 .7021 .41173 .70829 .40706 .70512 .39949 Metetra
.718 .628 .756 r
.70512 .39949 .70829 .40706 .71447 .4022 .71132 .39488 Metetra
.725 .637 .759 r
.71132 .39488 .71447 .4022 .72064 .39723 .71751 .39011 Metetra
.73 .644 .762 r
.71751 .39011 .72064 .39723 .72682 .39221 .7237 .38527 Metetra
.733 .649 .766 r
.7237 .38527 .72682 .39221 .73299 .38719 .7299 .38041 Metetra
.735 .654 .77 r
.7299 .38041 .73299 .38719 .73918 .38222 .7361 .37561 Metetra
.735 .659 .775 r
.7361 .37561 .73918 .38222 .74537 .37735 .74231 .37091 Metetra
.733 .663 .78 r
.74231 .37091 .74537 .37735 .75158 .37261 .74854 .36634 Metetra
.731 .667 .787 r
.74854 .36634 .75158 .37261 .7578 .36804 .75478 .36194 Metetra
.729 .671 .794 r
.75478 .36194 .7578 .36804 .76404 .36364 .76104 .35772 Metetra
.725 .675 .801 r
.76104 .35772 .76404 .36364 .77029 .35944 .76732 .35368 Metetra
.722 .68 .809 r
.76732 .35368 .77029 .35944 .77657 .35543 .77362 .34985 Metetra
.718 .685 .817 r
.77362 .34985 .77657 .35543 .78288 .35161 .77994 .34619 Metetra
.714 .689 .825 r
.77994 .34619 .78288 .35161 .7892 .34798 .78629 .34272 Metetra
.709 .694 .833 r
.78629 .34272 .7892 .34798 .79555 .34453 .79266 .33942 Metetra
.705 .699 .841 r
.79266 .33942 .79555 .34453 .80193 .34124 .79906 .33628 Metetra
.701 .703 .849 r
.79906 .33628 .80193 .34124 .80832 .33811 .80548 .33327 Metetra
.697 .707 .856 r
.80548 .33327 .80832 .33811 .81474 .33511 .81192 .33039 Metetra
.693 .712 .863 r
.81192 .33039 .81474 .33511 .82119 .33224 .81838 .32762 Metetra
.689 .715 .869 r
.81838 .32762 .82119 .33224 .82765 .32947 .82486 .32495 Metetra
.685 .719 .875 r
.82486 .32495 .82765 .32947 .83414 .3268 .83137 .32236 Metetra
.682 .722 .88 r
.83137 .32236 .83414 .3268 .84065 .32421 .8379 .31984 Metetra
.679 .725 .884 r
.8379 .31984 .84065 .32421 .84717 .3217 .84444 .31738 Metetra
.677 .727 .888 r
.84444 .31738 .84717 .3217 .85372 .31924 .85101 .31497 Metetra
.675 .73 .891 r
.85101 .31497 .85372 .31924 .86029 .31683 .85759 .3126 Metetra
.673 .731 .894 r
.85759 .3126 .86029 .31683 .86688 .31446 .86419 .31026 Metetra
.671 .733 .896 r
.86419 .31026 .86688 .31446 .87348 .31212 .87081 .30795 Metetra
.67 .734 .898 r
.87081 .30795 .87348 .31212 .88011 .30981 .87745 .30567 Metetra
.669 .736 .9 r
.87745 .30567 .88011 .30981 .88675 .30753 .8841 .3034 Metetra
.663 .741 .908 r
.28701 .49374 .29051 .497 .2959 .49525 .29241 .49198 Metetra
.663 .741 .908 r
.29241 .49198 .2959 .49525 .3013 .49349 .29782 .49021 Metetra
.663 .741 .908 r
.29782 .49021 .3013 .49349 .30672 .49173 .30324 .48844 Metetra
.663 .74 .908 r
.30324 .48844 .30672 .49173 .31214 .48998 .30867 .48667 Metetra
.662 .74 .908 r
.30867 .48667 .31214 .48998 .31758 .48823 .31412 .48491 Metetra
.662 .739 .907 r
.31412 .48491 .31758 .48823 .32303 .48649 .31957 .48315 Metetra
.661 .738 .907 r
.31957 .48315 .32303 .48649 .32848 .48476 .32504 .4814 Metetra
.66 .737 .907 r
.32504 .4814 .32848 .48476 .33395 .48306 .33051 .47966 Metetra
.658 .735 .906 r
.33051 .47966 .33395 .48306 .33943 .48139 .336 .47795 Metetra
.656 .732 .906 r
.336 .47795 .33943 .48139 .34491 .47976 .34149 .47626 Metetra
.652 .728 .905 r
.34149 .47626 .34491 .47976 .35041 .47819 .347 .47462 Metetra
.648 .723 .903 r
.347 .47462 .35041 .47819 .35591 .47669 .35251 .47304 Metetra
.643 .717 .902 r
.35251 .47304 .35591 .47669 .36142 .4753 .35803 .47153 Metetra
.636 .708 .899 r
.35803 .47153 .36142 .4753 .36694 .47404 .36356 .47013 Metetra
.627 .698 .896 r
.36356 .47013 .36694 .47404 .37246 .47294 .3691 .46885 Metetra
.616 .685 .892 r
.3691 .46885 .37246 .47294 .37799 .47203 .37464 .46774 Metetra
.602 .669 .887 r
.37464 .46774 .37799 .47203 .38352 .47137 .38018 .46682 Metetra
.587 .651 .881 r
.38018 .46682 .38352 .47137 .38905 .47098 .38574 .46615 Metetra
.569 .63 .873 r
.38574 .46615 .38905 .47098 .39459 .4709 .39129 .46574 Metetra
.549 .607 .863 r
.39129 .46574 .39459 .4709 .40014 .47118 .39685 .46565 Metetra
.528 .582 .852 r
.39685 .46565 .40014 .47118 .40568 .47183 .40241 .4659 Metetra
.507 .556 .84 r
.40241 .4659 .40568 .47183 .41124 .47287 .40798 .46651 Metetra
.487 .53 .827 r
.40798 .46651 .41124 .47287 .4168 .4743 .41356 .46751 Metetra
.469 .506 .814 r
.41356 .46751 .4168 .4743 .42238 .47609 .41915 .46886 Metetra
.454 .485 .801 r
.41915 .46886 .42238 .47609 .42797 .4782 .42475 .47055 Metetra
.444 .468 .79 r
.42475 .47055 .42797 .4782 .43358 .48057 .43037 .47252 Metetra
.439 .455 .779 r
.43037 .47252 .43358 .48057 .43921 .4831 .436 .47469 Metetra
.441 .448 .771 r
.436 .47469 .43921 .4831 .44487 .48568 .44166 .47695 Metetra
.449 .447 .764 r
.44166 .47695 .44487 .48568 .45056 .48818 .44735 .47918 Metetra
.465 .451 .758 r
.44735 .47918 .45056 .48818 .45628 .49047 .45307 .48121 Metetra
.487 .46 .753 r
.45307 .48121 .45628 .49047 .46203 .49241 .45882 .4829 Metetra
.513 .472 .748 r
.45882 .4829 .46203 .49241 .46781 .49388 .46461 .48408 Metetra
.543 .485 .741 r
.46461 .48408 .46781 .49388 .47363 .49475 .47042 .48461 Metetra
.573 .498 .733 r
.47042 .48461 .47363 .49475 .47948 .49495 .47628 .48434 Metetra
.601 .509 .722 r
.47628 .48434 .47948 .49495 .48536 .49441 .48216 .48317 Metetra
.625 .516 .71 r
.48216 .48317 .48536 .49441 .49127 .49312 .48807 .48105 Metetra
.644 .52 .697 r
.48807 .48105 .49127 .49312 .4972 .49108 .494 .47793 Metetra
.657 .519 .683 r
.494 .47793 .4972 .49108 .50314 .48833 .49994 .47385 Metetra
.665 .514 .671 r
.49994 .47385 .50314 .48833 .50909 .48494 .50589 .46888 Metetra
.667 .507 .659 r
.50589 .46888 .50909 .48494 .51506 .48101 .51185 .46312 Metetra
.666 .499 .648 r
.51185 .46312 .51506 .48101 .52103 .47663 .51781 .45673 Metetra
.663 .489 .639 r
.51781 .45673 .52103 .47663 .527 .47191 .52377 .4499 Metetra
.657 .478 .631 r
.52377 .4499 .527 .47191 .53298 .46696 .52972 .44282 Metetra
.649 .468 .624 r
.52972 .44282 .53298 .46696 .53896 .4619 .53567 .43572 Metetra
.641 .457 .619 r
.53567 .43572 .53896 .4619 .54494 .45684 .54161 .42882 Metetra
.632 .448 .615 r
.54161 .42882 .54494 .45684 .55092 .45188 .54755 .42234 Metetra
.623 .438 .612 r
.54755 .42234 .55092 .45188 .55691 .44711 .55348 .41647 Metetra
.614 .43 .61 r
.55348 .41647 .55691 .44711 .5629 .44263 .55943 .41139 Metetra
.604 .422 .609 r
.55943 .41139 .5629 .44263 .5689 .43852 .56539 .40723 Metetra
.594 .415 .608 r
.56539 .40723 .5689 .43852 .57491 .43485 .57137 .40408 Metetra
.584 .408 .61 r
.57137 .40408 .57491 .43485 .58094 .43167 .57737 .40198 Metetra
.573 .402 .612 r
.57737 .40198 .58094 .43167 .58698 .42903 .58341 .40094 Metetra
.562 .397 .616 r
.58341 .40094 .58698 .42903 .59305 .42694 .58948 .40088 Metetra
.55 .393 .621 r
.58948 .40088 .59305 .42694 .59915 .42539 .59559 .40171 Metetra
.539 .391 .629 r
.59559 .40171 .59915 .42539 .60527 .42434 .60175 .40327 Metetra
.526 .391 .639 r
.60175 .40327 .60527 .42434 .61142 .42374 .60794 .40537 Metetra
.514 .394 .654 r
.60794 .40537 .61142 .42374 .6176 .42348 .61417 .4078 Metetra
.503 .402 .673 r
.61417 .4078 .6176 .42348 .6238 .42347 .62044 .41035 Metetra
.493 .416 .698 r
.62044 .41035 .6238 .42347 .63003 .42357 .62673 .41279 Metetra
.487 .44 .73 r
.62673 .41279 .63003 .42357 .63629 .42366 .63305 .41492 Metetra
.488 .475 .77 r
.63305 .41492 .63629 .42366 .64255 .4236 .63938 .41656 Metetra
.5 .525 .814 r
.63938 .41656 .64255 .4236 .64883 .42327 .64571 .41758 Metetra
.526 .586 .858 r
.64571 .41758 .64883 .42327 .65512 .42257 .65204 .41787 Metetra
.566 .65 .892 r
.65204 .41787 .65512 .42257 .66141 .42141 .65836 .41737 Metetra
.615 .707 .911 r
.65836 .41737 .66141 .42141 .66769 .41975 .66466 .41607 Metetra
.664 .748 .912 r
.66466 .41607 .66769 .41975 .67396 .41756 .67095 .41399 Metetra
.706 .769 .901 r
.67095 .41399 .67396 .41756 .68022 .41484 .67722 .4112 Metetra
.737 .775 .883 r
.67722 .4112 .68022 .41484 .68646 .41161 .68346 .40778 Metetra
.757 .769 .863 r
.68346 .40778 .68646 .41161 .69269 .40794 .68969 .40382 Metetra
.768 .758 .844 r
.68969 .40382 .69269 .40794 .69891 .40387 .6959 .39943 Metetra
.772 .745 .828 r
.6959 .39943 .69891 .40387 .70512 .39949 .7021 .39473 Metetra
.772 .732 .816 r
.7021 .39473 .70512 .39949 .71132 .39488 .7083 .38982 Metetra
.77 .72 .806 r
.7083 .38982 .71132 .39488 .71751 .39011 .71449 .3848 Metetra
.766 .71 .8 r
.71449 .3848 .71751 .39011 .7237 .38527 .72068 .37976 Metetra
.761 .702 .796 r
.72068 .37976 .7237 .38527 .7299 .38041 .72687 .37477 Metetra
.756 .696 .795 r
.72687 .37477 .7299 .38041 .7361 .37561 .73308 .36989 Metetra
.75 .692 .796 r
.73308 .36989 .7361 .37561 .74231 .37091 .73929 .36516 Metetra
.744 .689 .798 r
.73929 .36516 .74231 .37091 .74854 .36634 .74553 .36062 Metetra
.738 .688 .802 r
.74553 .36062 .74854 .36634 .75478 .36194 .75178 .35628 Metetra
.733 .688 .807 r
.75178 .35628 .75478 .36194 .76104 .35772 .75806 .35214 Metetra
.727 .689 .813 r
.75806 .35214 .76104 .35772 .76732 .35368 .76436 .34822 Metetra
.722 .691 .82 r
.76436 .34822 .76732 .35368 .77362 .34985 .77068 .34451 Metetra
.717 .694 .827 r
.77068 .34451 .77362 .34985 .77994 .34619 .77702 .34099 Metetra
.711 .697 .835 r
.77702 .34099 .77994 .34619 .78629 .34272 .78339 .33765 Metetra
.706 .7 .842 r
.78339 .33765 .78629 .34272 .79266 .33942 .78978 .33447 Metetra
.702 .704 .849 r
.78978 .33447 .79266 .33942 .79906 .33628 .79619 .33144 Metetra
.697 .708 .856 r
.79619 .33144 .79906 .33628 .80548 .33327 .80263 .32855 Metetra
.693 .712 .863 r
.80263 .32855 .80548 .33327 .81192 .33039 .80909 .32577 Metetra
.689 .715 .869 r
.80909 .32577 .81192 .33039 .81838 .32762 .81557 .32309 Metetra
.685 .719 .875 r
.81557 .32309 .81838 .32762 .82486 .32495 .82208 .3205 Metetra
.682 .722 .88 r
.82208 .3205 .82486 .32495 .83137 .32236 .8286 .31798 Metetra
.679 .725 .884 r
.8286 .31798 .83137 .32236 .8379 .31984 .83514 .31552 Metetra
.677 .727 .888 r
.83514 .31552 .8379 .31984 .84444 .31738 .8417 .31311 Metetra
.675 .729 .891 r
.8417 .31311 .84444 .31738 .85101 .31497 .84828 .31074 Metetra
.673 .731 .894 r
.84828 .31074 .85101 .31497 .85759 .3126 .85488 .3084 Metetra
.671 .733 .897 r
.85488 .3084 .85759 .3126 .86419 .31026 .8615 .30609 Metetra
.67 .734 .899 r
.8615 .30609 .86419 .31026 .87081 .30795 .86813 .3038 Metetra
.669 .736 .9 r
.86813 .3038 .87081 .30795 .87745 .30567 .87478 .30153 Metetra
.668 .737 .902 r
.87478 .30153 .87745 .30567 .8841 .3034 .88145 .29927 Metetra
.663 .741 .908 r
.2835 .49047 .28701 .49374 .29241 .49198 .2889 .4887 Metetra
.663 .741 .908 r
.2889 .4887 .29241 .49198 .29782 .49021 .29432 .48692 Metetra
.663 .741 .908 r
.29432 .48692 .29782 .49021 .30324 .48844 .29975 .48514 Metetra
.663 .741 .908 r
.29975 .48514 .30324 .48844 .30867 .48667 .30519 .48336 Metetra
.663 .74 .908 r
.30519 .48336 .30867 .48667 .31412 .48491 .31064 .48159 Metetra
.662 .74 .908 r
.31064 .48159 .31412 .48491 .31957 .48315 .3161 .47981 Metetra
.662 .739 .907 r
.3161 .47981 .31957 .48315 .32504 .4814 .32158 .47804 Metetra
.661 .738 .907 r
.32158 .47804 .32504 .4814 .33051 .47966 .32706 .47628 Metetra
.66 .737 .907 r
.32706 .47628 .33051 .47966 .336 .47795 .33255 .47453 Metetra
.658 .735 .906 r
.33255 .47453 .336 .47795 .34149 .47626 .33806 .4728 Metetra
.656 .732 .906 r
.33806 .4728 .34149 .47626 .347 .47462 .34357 .47111 Metetra
.652 .728 .905 r
.34357 .47111 .347 .47462 .35251 .47304 .34909 .46945 Metetra
.648 .723 .903 r
.34909 .46945 .35251 .47304 .35803 .47153 .35463 .46786 Metetra
.643 .717 .902 r
.35463 .46786 .35803 .47153 .36356 .47013 .36017 .46634 Metetra
.636 .709 .899 r
.36017 .46634 .36356 .47013 .3691 .46885 .36571 .46493 Metetra
.627 .698 .896 r
.36571 .46493 .3691 .46885 .37464 .46774 .37127 .46364 Metetra
.616 .685 .893 r
.37127 .46364 .37464 .46774 .38018 .46682 .37683 .46252 Metetra
.602 .67 .888 r
.37683 .46252 .38018 .46682 .38574 .46615 .38239 .4616 Metetra
.586 .652 .881 r
.38239 .4616 .38574 .46615 .39129 .46574 .38796 .46091 Metetra
.569 .631 .874 r
.38796 .46091 .39129 .46574 .39685 .46565 .39354 .4605 Metetra
.549 .608 .864 r
.39354 .4605 .39685 .46565 .40241 .4659 .39912 .46039 Metetra
.528 .583 .854 r
.39912 .46039 .40241 .4659 .40798 .46651 .40471 .46063 Metetra
.507 .558 .842 r
.40471 .46063 .40798 .46651 .41356 .46751 .4103 .46122 Metetra
.487 .534 .83 r
.4103 .46122 .41356 .46751 .41915 .46886 .4159 .46217 Metetra
.47 .511 .818 r
.4159 .46217 .41915 .46886 .42475 .47055 .42151 .46347 Metetra
.456 .491 .807 r
.42151 .46347 .42475 .47055 .43037 .47252 .42713 .46508 Metetra
.447 .476 .796 r
.42713 .46508 .43037 .47252 .436 .47469 .43277 .46693 Metetra
.444 .466 .788 r
.43277 .46693 .436 .47469 .44166 .47695 .43844 .46892 Metetra
.448 .462 .781 r
.43844 .46892 .44166 .47695 .44735 .47918 .44412 .47095 Metetra
.459 .464 .776 r
.44412 .47095 .44735 .47918 .45307 .48121 .44984 .47285 Metetra
.478 .473 .773 r
.44984 .47285 .45307 .48121 .45882 .4829 .45559 .47447 Metetra
.504 .487 .771 r
.45559 .47447 .45882 .4829 .46461 .48408 .46137 .47563 Metetra
.536 .505 .769 r
.46137 .47563 .46461 .48408 .47042 .48461 .46719 .47617 Metetra
.571 .526 .766 r
.46719 .47617 .47042 .48461 .47628 .48434 .47303 .47594 Metetra
.606 .547 .761 r
.47303 .47594 .47628 .48434 .48216 .48317 .47891 .47481 Metetra
.641 .566 .755 r
.47891 .47481 .48216 .48317 .48807 .48105 .48482 .47269 Metetra
.671 .583 .748 r
.48482 .47269 .48807 .48105 .494 .47793 .49075 .46956 Metetra
.697 .596 .739 r
.49075 .46956 .494 .47793 .49994 .47385 .4967 .46545 Metetra
.717 .606 .732 r
.4967 .46545 .49994 .47385 .50589 .46888 .50266 .46045 Metetra
.731 .612 .725 r
.50266 .46045 .50589 .46888 .51185 .46312 .50862 .45469 Metetra
.742 .618 .721 r
.50862 .45469 .51185 .46312 .51781 .45673 .51458 .44839 Metetra
.749 .622 .719 r
.51458 .44839 .51781 .45673 .52377 .4499 .52054 .44179 Metetra
.753 .628 .722 r
.52054 .44179 .52377 .4499 .52972 .44282 .5265 .43514 Metetra
.754 .636 .729 r
.5265 .43514 .52972 .44282 .53567 .43572 .53245 .42873 Metetra
.755 .649 .744 r
.53245 .42873 .53567 .43572 .54161 .42882 .5384 .42281 Metetra
.755 .673 .771 r
.5384 .42281 .54161 .42882 .54755 .42234 .54436 .41764 Metetra
.752 .715 .817 r
.54436 .41764 .54755 .42234 .55348 .41647 .55032 .4134 Metetra
.735 .794 .899 r
.55032 .4134 .55348 .41647 .55943 .41139 .5563 .41025 Metetra
.597 .894 .988 r
.5563 .41025 .55943 .41139 .56539 .40723 .5623 .40825 Metetra
.031 0 0 r
.5623 .40825 .56539 .40723 .57137 .40408 .56833 .40743 Metetra
.428 0 .015 r
.56833 .40743 .57137 .40408 .57737 .40198 .57439 .40773 Metetra
.538 .134 .223 r
.57439 .40773 .57737 .40198 .58341 .40094 .58049 .40903 Metetra
.576 .212 .315 r
.58049 .40903 .58341 .40094 .58948 .40088 .58663 .41115 Metetra
.59 .25 .362 r
.58663 .41115 .58948 .40088 .59559 .40171 .59282 .41387 Metetra
.594 .269 .389 r
.59282 .41387 .59559 .40171 .60175 .40327 .59904 .41695 Metetra
.593 .278 .404 r
.59904 .41695 .60175 .40327 .60794 .40537 .6053 .42013 Metetra
.588 .279 .412 r
.6053 .42013 .60794 .40537 .61417 .4078 .61159 .42314 Metetra
.58 .274 .414 r
.61159 .42314 .61417 .4078 .62044 .41035 .6179 .42575 Metetra
.568 .264 .412 r
.6179 .42575 .62044 .41035 .62673 .41279 .62422 .42776 Metetra
.553 .248 .404 r
.62422 .42776 .62673 .41279 .63305 .41492 .63055 .42901 Metetra
.533 .225 .39 r
.63055 .42901 .63305 .41492 .63938 .41656 .63688 .42938 Metetra
.507 .193 .369 r
.63688 .42938 .63938 .41656 .64571 .41758 .64319 .42882 Metetra
.469 .146 .335 r
.64319 .42882 .64571 .41758 .65204 .41787 .64949 .42731 Metetra
.413 .077 .283 r
.64949 .42731 .65204 .41787 .65836 .41737 .65576 .4249 Metetra
.325 0 .195 r
.65576 .4249 .65836 .41737 .66466 .41607 .66202 .42166 Metetra
.171 0 .042 r
.66202 .42166 .66466 .41607 .67095 .41399 .66825 .41769 Metetra
.66825 .41769 .67095 .41399 .67722 .4112 .67446 .41312 Metetra
.511 .863 .613 r
.67446 .41312 .67722 .4112 .68346 .40778 .68065 .40807 Metetra
.785 .998 .844 r
.68065 .40807 .68346 .40778 .68969 .40382 .68683 .40268 Metetra
.851 .945 .88 r
.68683 .40268 .68969 .40382 .6959 .39943 .69299 .39707 Metetra
.845 .869 .86 r
.69299 .39707 .6959 .39943 .7021 .39473 .69915 .39137 Metetra
.825 .81 .836 r
.69915 .39137 .7021 .39473 .7083 .38982 .70532 .38566 Metetra
.806 .768 .818 r
.70532 .38566 .7083 .38982 .71449 .3848 .71148 .38003 Metetra
.789 .738 .806 r
.71148 .38003 .71449 .3848 .72068 .37976 .71766 .37455 Metetra
.775 .718 .799 r
.71766 .37455 .72068 .37976 .72687 .37477 .72384 .36927 Metetra
.763 .704 .796 r
.72384 .36927 .72687 .37477 .73308 .36989 .73005 .36422 Metetra
.753 .695 .796 r
.73005 .36422 .73308 .36989 .73929 .36516 .73627 .35942 Metetra
.744 .689 .799 r
.73627 .35942 .73929 .36516 .74553 .36062 .74251 .35488 Metetra
.736 .687 .803 r
.74251 .35488 .74553 .36062 .75178 .35628 .74878 .3506 Metetra
.729 .686 .809 r
.74878 .3506 .75178 .35628 .75806 .35214 .75507 .34656 Metetra
.723 .687 .815 r
.75507 .34656 .75806 .35214 .76436 .34822 .76139 .34277 Metetra
.717 .69 .823 r
.76139 .34277 .76436 .34822 .77068 .34451 .76773 .33919 Metetra
.711 .693 .831 r
.76773 .33919 .77068 .34451 .77702 .34099 .77409 .33581 Metetra
.706 .697 .839 r
.77409 .33581 .77702 .34099 .78339 .33765 .78048 .33261 Metetra
.701 .701 .847 r
.78048 .33261 .78339 .33765 .78978 .33447 .78689 .32957 Metetra
.697 .705 .854 r
.78689 .32957 .78978 .33447 .79619 .33144 .79333 .32667 Metetra
.692 .709 .861 r
.79333 .32667 .79619 .33144 .80263 .32855 .79978 .32388 Metetra
.688 .713 .868 r
.79978 .32388 .80263 .32855 .80909 .32577 .80626 .32121 Metetra
.685 .717 .874 r
.80626 .32121 .80909 .32577 .81557 .32309 .81276 .31861 Metetra
.682 .721 .879 r
.81276 .31861 .81557 .32309 .82208 .3205 .81928 .31609 Metetra
.679 .724 .884 r
.81928 .31609 .82208 .3205 .8286 .31798 .82582 .31364 Metetra
.676 .727 .888 r
.82582 .31364 .8286 .31798 .83514 .31552 .83238 .31123 Metetra
.674 .729 .891 r
.83238 .31123 .83514 .31552 .8417 .31311 .83896 .30886 Metetra
.672 .731 .894 r
.83896 .30886 .8417 .31311 .84828 .31074 .84555 .30653 Metetra
.671 .733 .897 r
.84555 .30653 .84828 .31074 .85488 .3084 .85217 .30422 Metetra
.669 .734 .899 r
.85217 .30422 .85488 .3084 .8615 .30609 .8588 .30193 Metetra
.668 .736 .9 r
.8588 .30193 .8615 .30609 .86813 .3038 .86544 .29966 Metetra
.667 .737 .902 r
.86544 .29966 .86813 .3038 .87478 .30153 .87211 .2974 Metetra
.667 .738 .903 r
.87211 .2974 .87478 .30153 .88145 .29927 .87879 .29515 Metetra
.663 .741 .908 r
.27997 .48719 .2835 .49047 .2889 .4887 .28539 .48541 Metetra
.663 .741 .908 r
.28539 .48541 .2889 .4887 .29432 .48692 .29081 .48362 Metetra
.663 .741 .908 r
.29081 .48362 .29432 .48692 .29975 .48514 .29625 .48184 Metetra
.663 .741 .908 r
.29625 .48184 .29975 .48514 .30519 .48336 .30169 .48005 Metetra
.663 .741 .908 r
.30169 .48005 .30519 .48336 .31064 .48159 .30715 .47826 Metetra
.663 .74 .908 r
.30715 .47826 .31064 .48159 .3161 .47981 .31262 .47647 Metetra
.662 .74 .908 r
.31262 .47647 .3161 .47981 .32158 .47804 .3181 .47468 Metetra
.662 .739 .907 r
.3181 .47468 .32158 .47804 .32706 .47628 .32359 .4729 Metetra
.661 .738 .907 r
.32359 .4729 .32706 .47628 .33255 .47453 .32909 .47113 Metetra
.66 .737 .907 r
.32909 .47113 .33255 .47453 .33806 .4728 .33461 .46937 Metetra
.658 .735 .906 r
.33461 .46937 .33806 .4728 .34357 .47111 .34013 .46763 Metetra
.656 .732 .906 r
.34013 .46763 .34357 .47111 .34909 .46945 .34566 .46592 Metetra
.652 .728 .905 r
.34566 .46592 .34909 .46945 .35463 .46786 .3512 .46426 Metetra
.648 .723 .904 r
.3512 .46426 .35463 .46786 .36017 .46634 .35675 .46266 Metetra
.643 .717 .902 r
.35675 .46266 .36017 .46634 .36571 .46493 .36231 .46113 Metetra
.635 .709 .9 r
.36231 .46113 .36571 .46493 .37127 .46364 .36788 .45971 Metetra
.626 .699 .897 r
.36788 .45971 .37127 .46364 .37683 .46252 .37345 .45842 Metetra
.615 .686 .893 r
.37345 .45842 .37683 .46252 .38239 .4616 .37903 .4573 Metetra
.601 .671 .889 r
.37903 .4573 .38239 .4616 .38796 .46091 .38462 .45638 Metetra
.585 .653 .883 r
.38462 .45638 .38796 .46091 .39354 .4605 .39021 .4557 Metetra
.566 .632 .877 r
.39021 .4557 .39354 .4605 .39912 .46039 .3958 .4553 Metetra
.545 .61 .869 r
.3958 .4553 .39912 .46039 .40471 .46063 .4014 .45523 Metetra
.522 .586 .86 r
.4014 .45523 .40471 .46063 .4103 .46122 .407 .45552 Metetra
.497 .561 .851 r
.407 .45552 .4103 .46122 .4159 .46217 .41261 .45618 Metetra
.472 .537 .843 r
.41261 .45618 .4159 .46217 .42151 .46347 .41823 .45724 Metetra
.447 .515 .835 r
.41823 .45724 .42151 .46347 .42713 .46508 .42386 .45867 Metetra
.423 .495 .829 r
.42386 .45867 .42713 .46508 .43277 .46693 .4295 .46046 Metetra
.399 .48 .827 r
.4295 .46046 .43277 .46693 .43844 .46892 .43516 .46255 Metetra
.375 .47 .83 r
.43516 .46255 .43844 .46892 .44412 .47095 .44084 .46486 Metetra
.351 .468 .839 r
.44084 .46486 .44412 .47095 .44984 .47285 .44654 .46729 Metetra
.322 .475 .857 r
.44654 .46729 .44984 .47285 .45559 .47447 .45227 .46972 Metetra
.282 .493 .886 r
.45227 .46972 .45559 .47447 .46137 .47563 .45803 .47201 Metetra
.21 .523 .918 r
.45803 .47201 .46137 .47563 .46719 .47617 .46383 .47403 Metetra
.06 .536 .894 r
.46383 .47403 .46719 .47617 .47303 .47594 .46965 .47564 Metetra
.192 0 0 r
.46965 .47564 .47303 .47594 .47891 .47481 .47551 .47672 Metetra
.368 0 0 r
.47551 .47672 .47891 .47481 .48482 .47269 .4814 .4772 Metetra
.429 0 .099 r
.4814 .4772 .48482 .47269 .49075 .46956 .48732 .47703 Metetra
.451 .081 .243 r
.48732 .47703 .49075 .46956 .4967 .46545 .49327 .47621 Metetra
.464 .136 .325 r
.49327 .47621 .4967 .46545 .50266 .46045 .49924 .47479 Metetra
.475 .174 .376 r
.49924 .47479 .50266 .46045 .50862 .45469 .50522 .47286 Metetra
.485 .202 .41 r
.50522 .47286 .50862 .45469 .51458 .44839 .51122 .47056 Metetra
.494 .224 .434 r
.51122 .47056 .51458 .44839 .52054 .44179 .51723 .46806 Metetra
.504 .242 .451 r
.51723 .46806 .52054 .44179 .5265 .43514 .52325 .46554 Metetra
.513 .257 .464 r
.52325 .46554 .5265 .43514 .53245 .42873 .52929 .46316 Metetra
.521 .269 .474 r
.52929 .46316 .53245 .42873 .5384 .42281 .53533 .46109 Metetra
.528 .28 .482 r
.53533 .46109 .5384 .42281 .54436 .41764 .54139 .45944 Metetra
.535 .288 .488 r
.54139 .45944 .54436 .41764 .55032 .4134 .54747 .45832 Metetra
.54 .295 .492 r
.54747 .45832 .55032 .4134 .5563 .41025 .55357 .45773 Metetra
.545 .3 .495 r
.55357 .45773 .5563 .41025 .5623 .40825 .5597 .45767 Metetra
.548 .304 .498 r
.5597 .45767 .5623 .40825 .56833 .40743 .56585 .45806 Metetra
.55 .307 .499 r
.56585 .45806 .56833 .40743 .57439 .40773 .57203 .45878 Metetra
.552 .308 .499 r
.57203 .45878 .57439 .40773 .58049 .40903 .57823 .45966 Metetra
.552 .307 .499 r
.57823 .45966 .58049 .40903 .58663 .41115 .58446 .46054 Metetra
.55 .305 .498 r
.58446 .46054 .58663 .41115 .59282 .41387 .59071 .46122 Metetra
.547 .302 .495 r
.59071 .46122 .59282 .41387 .59904 .41695 .59697 .46153 Metetra
.543 .296 .492 r
.59697 .46153 .59904 .41695 .6053 .42013 .60325 .46129 Metetra
.537 .288 .487 r
.60325 .46129 .6053 .42013 .61159 .42314 .60953 .46039 Metetra
.528 .278 .48 r
.60953 .46039 .61159 .42314 .6179 .42575 .6158 .45871 Metetra
.515 .262 .47 r
.6158 .45871 .6179 .42575 .62422 .42776 .62207 .45622 Metetra
.498 .242 .456 r
.62207 .45622 .62422 .42776 .63055 .42901 .62832 .45291 Metetra
.474 .212 .436 r
.62832 .45291 .63055 .42901 .63688 .42938 .63455 .44879 Metetra
.439 .169 .406 r
.63455 .44879 .63688 .42938 .64319 .42882 .64077 .44394 Metetra
.382 .101 .357 r
.64077 .44394 .64319 .42882 .64949 .42731 .64696 .43846 Metetra
.286 0 .271 r
.64696 .43846 .64949 .42731 .65576 .4249 .65314 .43245 Metetra
.098 0 .102 r
.65314 .43245 .65576 .4249 .66202 .42166 .65929 .42603 Metetra
.65929 .42603 .66202 .42166 .66825 .41769 .66543 .41934 Metetra
.756 .971 .695 r
.66543 .41934 .66825 .41769 .67446 .41312 .67156 .41249 Metetra
.893 .959 .833 r
.67156 .41249 .67446 .41312 .68065 .40807 .67769 .40559 Metetra
.872 .857 .824 r
.67769 .40559 .68065 .40807 .68683 .40268 .68381 .39876 Metetra
.836 .782 .8 r
.68381 .39876 .68683 .40268 .69299 .39707 .68993 .39207 Metetra
.808 .734 .782 r
.68993 .39207 .69299 .39707 .69915 .39137 .69606 .38558 Metetra
.786 .702 .771 r
.69606 .38558 .69915 .39137 .70532 .38566 .70221 .37936 Metetra
.77 .682 .766 r
.70221 .37936 .70532 .38566 .71148 .38003 .70836 .37343 Metetra
.758 .669 .764 r
.70836 .37343 .71148 .38003 .71766 .37455 .71454 .36782 Metetra
.748 .662 .766 r
.71454 .36782 .71766 .37455 .72384 .36927 .72073 .36253 Metetra
.739 .659 .77 r
.72073 .36253 .72384 .36927 .73005 .36422 .72695 .35758 Metetra
.732 .658 .776 r
.72695 .35758 .73005 .36422 .73627 .35942 .73319 .35293 Metetra
.726 .66 .784 r
.73319 .35293 .73627 .35942 .74251 .35488 .73945 .34859 Metetra
.721 .663 .792 r
.73945 .34859 .74251 .35488 .74878 .3506 .74574 .34452 Metetra
.716 .668 .802 r
.74574 .34452 .74878 .3506 .75507 .34656 .75206 .34072 Metetra
.711 .674 .812 r
.75206 .34072 .75507 .34656 .76139 .34277 .7584 .33714 Metetra
.707 .68 .822 r
.7584 .33714 .76139 .34277 .76773 .33919 .76476 .33378 Metetra
.702 .686 .832 r
.76476 .33378 .76773 .33919 .77409 .33581 .77115 .3306 Metetra
.698 .693 .841 r
.77115 .3306 .77409 .33581 .78048 .33261 .77756 .32757 Metetra
.694 .699 .85 r
.77756 .32757 .78048 .33261 .78689 .32957 .784 .32469 Metetra
.69 .704 .858 r
.784 .32469 .78689 .32957 .79333 .32667 .79045 .32193 Metetra
.687 .71 .866 r
.79045 .32193 .79333 .32667 .79978 .32388 .79693 .31927 Metetra
.684 .715 .872 r
.79693 .31927 .79978 .32388 .80626 .32121 .80343 .31669 Metetra
.681 .719 .878 r
.80343 .31669 .80626 .32121 .81276 .31861 .80995 .31418 Metetra
.678 .722 .883 r
.80995 .31418 .81276 .31861 .81928 .31609 .81648 .31173 Metetra
.676 .726 .887 r
.81648 .31173 .81928 .31609 .82582 .31364 .82304 .30933 Metetra
.674 .728 .891 r
.82304 .30933 .82582 .31364 .83238 .31123 .82961 .30697 Metetra
.672 .731 .894 r
.82961 .30697 .83238 .31123 .83896 .30886 .83621 .30464 Metetra
.67 .733 .897 r
.83621 .30464 .83896 .30886 .84555 .30653 .84282 .30234 Metetra
.669 .734 .899 r
.84282 .30234 .84555 .30653 .85217 .30422 .84944 .30005 Metetra
.668 .736 .901 r
.84944 .30005 .85217 .30422 .8588 .30193 .85609 .29778 Metetra
.667 .737 .902 r
.85609 .29778 .8588 .30193 .86544 .29966 .86275 .29552 Metetra
.666 .738 .903 r
.86275 .29552 .86544 .29966 .87211 .2974 .86942 .29327 Metetra
.666 .738 .904 r
.86942 .29327 .87211 .2974 .87879 .29515 .87611 .29103 Metetra
.663 .741 .908 r
.27644 .48389 .27997 .48719 .28539 .48541 .28186 .4821 Metetra
.663 .741 .908 r
.28186 .4821 .28539 .48541 .29081 .48362 .28729 .48031 Metetra
.663 .741 .908 r
.28729 .48031 .29081 .48362 .29625 .48184 .29273 .47852 Metetra
.663 .741 .908 r
.29273 .47852 .29625 .48184 .30169 .48005 .29818 .47672 Metetra
.663 .741 .908 r
.29818 .47672 .30169 .48005 .30715 .47826 .30365 .47492 Metetra
.663 .741 .908 r
.30365 .47492 .30715 .47826 .31262 .47647 .30912 .47312 Metetra
.663 .74 .908 r
.30912 .47312 .31262 .47647 .3181 .47468 .31461 .47132 Metetra
.662 .74 .908 r
.31461 .47132 .3181 .47468 .32359 .4729 .32011 .46952 Metetra
.662 .739 .907 r
.32011 .46952 .32359 .4729 .32909 .47113 .32562 .46773 Metetra
.661 .738 .907 r
.32562 .46773 .32909 .47113 .33461 .46937 .33114 .46595 Metetra
.66 .737 .907 r
.33114 .46595 .33461 .46937 .34013 .46763 .33667 .46417 Metetra
.658 .735 .906 r
.33667 .46417 .34013 .46763 .34566 .46592 .34221 .46243 Metetra
.656 .732 .906 r
.34221 .46243 .34566 .46592 .3512 .46426 .34776 .46071 Metetra
.652 .728 .905 r
.34776 .46071 .3512 .46426 .35675 .46266 .35332 .45903 Metetra
.648 .723 .904 r
.35332 .45903 .35675 .46266 .36231 .46113 .35889 .45742 Metetra
.642 .717 .902 r
.35889 .45742 .36231 .46113 .36788 .45971 .36447 .45589 Metetra
.635 .709 .9 r
.36447 .45589 .36788 .45971 .37345 .45842 .37006 .45446 Metetra
.626 .698 .897 r
.37006 .45446 .37345 .45842 .37903 .4573 .37565 .45317 Metetra
.614 .685 .894 r
.37565 .45317 .37903 .4573 .38462 .45638 .38125 .45205 Metetra
.599 .67 .889 r
.38125 .45205 .38462 .45638 .39021 .4557 .38685 .45114 Metetra
.582 .652 .884 r
.38685 .45114 .39021 .4557 .3958 .4553 .39246 .45049 Metetra
.562 .631 .878 r
.39246 .45049 .3958 .4553 .4014 .45523 .39807 .45014 Metetra
.538 .608 .871 r
.39807 .45014 .4014 .45523 .407 .45552 .40369 .45014 Metetra
.512 .583 .863 r
.40369 .45014 .407 .45552 .41261 .45618 .40931 .45053 Metetra
.482 .557 .855 r
.40931 .45053 .41261 .45618 .41823 .45724 .41493 .45135 Metetra
.449 .53 .848 r
.41493 .45135 .41823 .45724 .42386 .45867 .42057 .45263 Metetra
.412 .504 .843 r
.42057 .45263 .42386 .45867 .4295 .46046 .42621 .45438 Metetra
.369 .478 .84 r
.42621 .45438 .4295 .46046 .43516 .46255 .43186 .4566 Metetra
.316 .453 .84 r
.43186 .4566 .43516 .46255 .44084 .46486 .43753 .45926 Metetra
.244 .427 .844 r
.43753 .45926 .44084 .46486 .44654 .46729 .44322 .46233 Metetra
.135 .392 .844 r
.44322 .46233 .44654 .46729 .45227 .46972 .44893 .46575 Metetra
0 .331 .812 r
.44893 .46575 .45227 .46972 .45803 .47201 .45466 .46943 Metetra
0 .194 .645 r
.45466 .46943 .45803 .47201 .46383 .47403 .46042 .47329 Metetra
.587 .012 0 r
.46042 .47329 .46383 .47403 .46965 .47564 .46622 .47722 Metetra
.656 .156 .049 r
.46622 .47722 .46965 .47564 .47551 .47672 .47205 .48112 Metetra
.645 .224 .231 r
.47205 .48112 .47551 .47672 .4814 .4772 .47791 .4849 Metetra
.622 .256 .328 r
.47791 .4849 .4814 .4772 .48732 .47703 .48381 .48847 Metetra
.602 .273 .385 r
.48381 .48847 .48732 .47703 .49327 .47621 .48975 .49176 Metetra
.586 .282 .42 r
.48975 .49176 .49327 .47621 .49924 .47479 .49572 .49471 Metetra
.575 .288 .443 r
.49572 .49471 .49924 .47479 .50522 .47286 .50172 .49729 Metetra
.567 .292 .458 r
.50172 .49729 .50522 .47286 .51122 .47056 .50776 .49949 Metetra
.56 .294 .47 r
.50776 .49949 .51122 .47056 .51723 .46806 .51382 .5013 Metetra
.556 .296 .478 r
.51382 .5013 .51723 .46806 .52325 .46554 .51992 .50272 Metetra
.552 .297 .483 r
.51992 .50272 .52325 .46554 .52929 .46316 .52604 .50376 Metetra
.549 .298 .487 r
.52604 .50376 .52929 .46316 .53533 .46109 .53218 .50443 Metetra
.546 .297 .49 r
.53218 .50443 .53533 .46109 .54139 .45944 .53834 .5047 Metetra
.543 .296 .492 r
.53834 .5047 .54139 .45944 .54747 .45832 .54453 .50457 Metetra
.54 .295 .492 r
.54453 .50457 .54747 .45832 .55357 .45773 .55073 .50401 Metetra
.537 .292 .491 r
.55073 .50401 .55357 .45773 .5597 .45767 .55694 .50298 Metetra
.532 .287 .489 r
.55694 .50298 .5597 .45767 .56585 .45806 .56317 .50144 Metetra
.527 .281 .486 r
.56317 .50144 .56585 .45806 .57203 .45878 .5694 .49934 Metetra
.52 .273 .481 r
.5694 .49934 .57203 .45878 .57823 .45966 .57564 .49665 Metetra
.51 .262 .474 r
.57564 .49665 .57823 .45966 .58446 .46054 .58188 .49334 Metetra
.497 .246 .464 r
.58188 .49334 .58446 .46054 .59071 .46122 .58812 .4894 Metetra
.479 .224 .449 r
.58812 .4894 .59071 .46122 .59697 .46153 .59435 .48482 Metetra
.451 .19 .425 r
.59435 .48482 .59697 .46153 .60325 .46129 .60057 .47964 Metetra
.406 .135 .387 r
.60057 .47964 .60325 .46129 .60953 .46039 .60678 .47388 Metetra
.323 .037 .315 r
.60678 .47388 .60953 .46039 .6158 .45871 .61298 .46761 Metetra
.145 0 .157 r
.61298 .46761 .6158 .45871 .62207 .45622 .61915 .4609 Metetra
.61915 .4609 .62207 .45622 .62832 .45291 .62532 .45382 Metetra
.866 .995 .772 r
.62532 .45382 .62832 .45291 .63455 .44879 .63147 .44647 Metetra
.886 .856 .807 r
.63147 .44647 .63455 .44879 .64077 .44394 .63761 .43893 Metetra
.828 .736 .763 r
.63761 .43893 .64077 .44394 .64696 .43846 .64373 .4313 Metetra
.788 .668 .732 r
.64373 .4313 .64696 .43846 .65314 .43245 .64985 .42366 Metetra
.761 .628 .712 r
.64985 .42366 .65314 .43245 .65929 .42603 .65596 .41608 Metetra
.744 .604 .701 r
.65596 .41608 .65929 .42603 .66543 .41934 .66208 .40865 Metetra
.732 .589 .695 r
.66208 .40865 .66543 .41934 .67156 .41249 .66819 .40141 Metetra
.724 .58 .693 r
.66819 .40141 .67156 .41249 .67769 .40559 .67431 .39443 Metetra
.718 .576 .694 r
.67431 .39443 .67769 .40559 .68381 .39876 .68043 .38772 Metetra
.714 .575 .697 r
.68043 .38772 .68381 .39876 .68993 .39207 .68657 .38133 Metetra
.712 .577 .702 r
.68657 .38133 .68993 .39207 .69606 .38558 .69273 .37528 Metetra
.71 .581 .708 r
.69273 .37528 .69606 .38558 .70221 .37936 .6989 .36955 Metetra
.709 .586 .717 r
.6989 .36955 .70221 .37936 .70836 .37343 .70509 .36417 Metetra
.708 .594 .726 r
.70509 .36417 .70836 .37343 .71454 .36782 .71129 .35911 Metetra
.707 .602 .737 r
.71129 .35911 .71454 .36782 .72073 .36253 .71753 .35437 Metetra
.706 .612 .749 r
.71753 .35437 .72073 .36253 .72695 .35758 .72378 .34994 Metetra
.705 .622 .761 r
.72378 .34994 .72695 .35758 .73319 .35293 .73006 .34578 Metetra
.704 .633 .775 r
.73006 .34578 .73319 .35293 .73945 .34859 .73636 .34188 Metetra
.703 .644 .788 r
.73636 .34188 .73945 .34859 .74574 .34452 .74268 .33822 Metetra
.701 .655 .801 r
.74268 .33822 .74574 .34452 .75206 .34072 .74903 .33477 Metetra
.699 .665 .814 r
.74903 .33477 .75206 .34072 .7584 .33714 .7554 .3315 Metetra
.696 .675 .826 r
.7554 .3315 .7584 .33714 .76476 .33378 .76179 .32841 Metetra
.693 .685 .837 r
.76179 .32841 .76476 .33378 .77115 .3306 .7682 .32546 Metetra
.69 .693 .848 r
.7682 .32546 .77115 .3306 .77756 .32757 .77464 .32263 Metetra
.688 .701 .857 r
.77464 .32263 .77756 .32757 .784 .32469 .7811 .31991 Metetra
.685 .707 .865 r
.7811 .31991 .784 .32469 .79045 .32193 .78758 .31729 Metetra
.682 .713 .872 r
.78758 .31729 .79045 .32193 .79693 .31927 .79407 .31474 Metetra
.679 .718 .878 r
.79407 .31474 .79693 .31927 .80343 .31669 .80059 .31225 Metetra
.677 .722 .884 r
.80059 .31225 .80343 .31669 .80995 .31418 .80713 .30982 Metetra
.675 .726 .888 r
.80713 .30982 .80995 .31418 .81648 .31173 .81368 .30743 Metetra
.673 .729 .892 r
.81368 .30743 .81648 .31173 .82304 .30933 .82025 .30508 Metetra
.671 .731 .895 r
.82025 .30508 .82304 .30933 .82961 .30697 .82684 .30276 Metetra
.67 .733 .897 r
.82684 .30276 .82961 .30697 .83621 .30464 .83345 .30046 Metetra
.669 .735 .899 r
.83345 .30046 .83621 .30464 .84282 .30234 .84007 .29818 Metetra
.668 .736 .901 r
.84007 .29818 .84282 .30234 .84944 .30005 .84671 .29591 Metetra
.667 .737 .902 r
.84671 .29591 .84944 .30005 .85609 .29778 .85337 .29365 Metetra
.666 .738 .903 r
.85337 .29365 .85609 .29778 .86275 .29552 .86004 .29139 Metetra
.666 .739 .904 r
.86004 .29139 .86275 .29552 .86942 .29327 .86673 .28915 Metetra
.665 .739 .905 r
.86673 .28915 .86942 .29327 .87611 .29103 .87343 .2869 Metetra
.664 .741 .908 r
.27288 .48059 .27644 .48389 .28186 .4821 .27831 .47879 Metetra
.663 .741 .908 r
.27831 .47879 .28186 .4821 .28729 .48031 .28375 .47699 Metetra
.663 .741 .908 r
.28375 .47699 .28729 .48031 .29273 .47852 .2892 .47519 Metetra
.663 .741 .908 r
.2892 .47519 .29273 .47852 .29818 .47672 .29466 .47338 Metetra
.663 .741 .908 r
.29466 .47338 .29818 .47672 .30365 .47492 .30013 .47157 Metetra
.663 .741 .908 r
.30013 .47157 .30365 .47492 .30912 .47312 .30561 .46976 Metetra
.663 .741 .908 r
.30561 .46976 .30912 .47312 .31461 .47132 .31111 .46795 Metetra
.663 .74 .908 r
.31111 .46795 .31461 .47132 .32011 .46952 .31661 .46614 Metetra
.662 .74 .908 r
.31661 .46614 .32011 .46952 .32562 .46773 .32213 .46433 Metetra
.662 .739 .907 r
.32213 .46433 .32562 .46773 .33114 .46595 .32766 .46253 Metetra
.661 .738 .907 r
.32766 .46253 .33114 .46595 .33667 .46417 .3332 .46073 Metetra
.66 .737 .907 r
.3332 .46073 .33667 .46417 .34221 .46243 .33875 .45895 Metetra
.658 .735 .906 r
.33875 .45895 .34221 .46243 .34776 .46071 .34431 .45719 Metetra
.656 .732 .906 r
.34431 .45719 .34776 .46071 .35332 .45903 .34988 .45546 Metetra
.653 .728 .905 r
.34988 .45546 .35332 .45903 .35889 .45742 .35546 .45377 Metetra
.648 .723 .903 r
.35546 .45377 .35889 .45742 .36447 .45589 .36104 .45215 Metetra
.643 .716 .901 r
.36104 .45215 .36447 .45589 .37006 .45446 .36664 .4506 Metetra
.635 .708 .899 r
.36664 .4506 .37006 .45446 .37565 .45317 .37225 .44916 Metetra
.626 .697 .896 r
.37225 .44916 .37565 .45317 .38125 .45205 .37786 .44785 Metetra
.614 .683 .891 r
.37786 .44785 .38125 .45205 .38685 .45114 .38348 .44672 Metetra
.6 .666 .886 r
.38348 .44672 .38685 .45114 .39246 .45049 .3891 .44579 Metetra
.584 .647 .878 r
.3891 .44579 .39246 .45049 .39807 .45014 .39473 .44512 Metetra
.564 .624 .87 r
.39473 .44512 .39807 .45014 .40369 .45014 .40036 .44476 Metetra
.542 .598 .859 r
.40036 .44476 .40369 .45014 .40931 .45053 .406 .44474 Metetra
.519 .57 .847 r
.406 .44474 .40931 .45053 .41493 .45135 .41164 .44512 Metetra
.494 .541 .834 r
.41164 .44512 .41493 .45135 .42057 .45263 .41729 .44593 Metetra
.469 .512 .82 r
.41729 .44593 .42057 .45263 .42621 .45438 .42294 .44721 Metetra
.444 .484 .806 r
.42294 .44721 .42621 .45438 .43186 .4566 .42861 .44896 Metetra
.42 .457 .792 r
.42861 .44896 .43186 .4566 .43753 .45926 .43429 .45119 Metetra
.398 .433 .78 r
.43429 .45119 .43753 .45926 .44322 .46233 .43998 .45389 Metetra
.379 .412 .769 r
.43998 .45389 .44322 .46233 .44893 .46575 .44569 .457 Metetra
.364 .396 .761 r
.44569 .457 .44893 .46575 .45466 .46943 .45142 .46046 Metetra
.352 .384 .755 r
.45142 .46046 .45466 .46943 .46042 .47329 .45717 .4642 Metetra
.345 .378 .752 r
.45717 .4642 .46042 .47329 .46622 .47722 .46296 .4681 Metetra
.343 .376 .752 r
.46296 .4681 .46622 .47722 .47205 .48112 .46878 .47206 Metetra
.347 .381 .754 r
.46878 .47206 .47205 .48112 .47791 .4849 .47464 .47593 Metetra
.36 .391 .758 r
.47464 .47593 .47791 .4849 .48381 .48847 .48053 .4796 Metetra
.38 .407 .763 r
.48053 .4796 .48381 .48847 .48975 .49176 .48646 .48293 Metetra
.41 .426 .766 r
.48646 .48293 .48975 .49176 .49572 .49471 .49242 .48579 Metetra
.446 .447 .766 r
.49242 .48579 .49572 .49471 .50172 .49729 .49842 .4881 Metetra
.485 .465 .761 r
.49842 .4881 .50172 .49729 .50776 .49949 .50446 .48975 Metetra
.523 .478 .749 r
.50446 .48975 .50776 .49949 .51382 .5013 .51052 .49068 Metetra
.555 .485 .731 r
.51052 .49068 .51382 .5013 .51992 .50272 .51661 .49086 Metetra
.579 .485 .711 r
.51661 .49086 .51992 .50272 .52604 .50376 .52272 .49028 Metetra
.596 .48 .691 r
.52272 .49028 .52604 .50376 .53218 .50443 .52885 .48894 Metetra
.606 .472 .672 r
.52885 .48894 .53218 .50443 .53834 .5047 .53499 .48689 Metetra
.611 .463 .656 r
.53499 .48689 .53834 .5047 .54453 .50457 .54114 .48417 Metetra
.614 .454 .642 r
.54114 .48417 .54453 .50457 .55073 .50401 .5473 .48085 Metetra
.614 .446 .631 r
.5473 .48085 .55073 .50401 .55694 .50298 .55346 .47702 Metetra
.613 .438 .622 r
.55346 .47702 .55694 .50298 .56317 .50144 .55963 .47276 Metetra
.611 .432 .615 r
.55963 .47276 .56317 .50144 .5694 .49934 .56579 .46815 Metetra
.609 .426 .609 r
.56579 .46815 .5694 .49934 .57564 .49665 .57196 .46326 Metetra
.607 .422 .605 r
.57196 .46326 .57564 .49665 .58188 .49334 .57812 .45817 Metetra
.606 .418 .602 r
.57812 .45817 .58188 .49334 .58812 .4894 .58429 .45294 Metetra
.605 .416 .6 r
.58429 .45294 .58812 .4894 .59435 .48482 .59045 .44762 Metetra
.604 .415 .598 r
.59045 .44762 .59435 .48482 .60057 .47964 .59662 .44224 Metetra
.604 .415 .598 r
.59662 .44224 .60057 .47964 .60678 .47388 .60278 .43682 Metetra
.605 .415 .599 r
.60278 .43682 .60678 .47388 .61298 .46761 .60895 .43138 Metetra
.606 .417 .6 r
.60895 .43138 .61298 .46761 .61915 .4609 .61511 .42593 Metetra
.608 .42 .602 r
.61511 .42593 .61915 .4609 .62532 .45382 .62128 .42048 Metetra
.61 .423 .604 r
.62128 .42048 .62532 .45382 .63147 .44647 .62745 .41503 Metetra
.613 .428 .608 r
.62745 .41503 .63147 .44647 .63761 .43893 .63361 .40959 Metetra
.617 .434 .612 r
.63361 .40959 .63761 .43893 .64373 .4313 .63978 .40416 Metetra
.621 .441 .617 r
.63978 .40416 .64373 .4313 .64985 .42366 .64596 .39876 Metetra
.626 .449 .623 r
.64596 .39876 .64985 .42366 .65596 .41608 .65213 .39341 Metetra
.632 .459 .631 r
.65213 .39341 .65596 .41608 .66208 .40865 .65831 .38811 Metetra
.638 .47 .639 r
.65831 .38811 .66208 .40865 .66819 .40141 .66449 .3829 Metetra
.644 .481 .648 r
.66449 .3829 .66819 .40141 .67431 .39443 .67068 .37779 Metetra
.651 .495 .658 r
.67068 .37779 .67431 .39443 .68043 .38772 .67688 .37281 Metetra
.658 .509 .67 r
.67688 .37281 .68043 .38772 .68657 .38133 .68308 .36797 Metetra
.664 .524 .683 r
.68308 .36797 .68657 .38133 .69273 .37528 .6893 .36329 Metetra
.671 .54 .697 r
.6893 .36329 .69273 .37528 .6989 .36955 .69554 .35879 Metetra
.677 .556 .711 r
.69554 .35879 .6989 .36955 .70509 .36417 .70178 .35446 Metetra
.682 .573 .727 r
.70178 .35446 .70509 .36417 .71129 .35911 .70805 .35033 Metetra
.687 .59 .742 r
.70805 .35033 .71129 .35911 .71753 .35437 .71433 .34638 Metetra
.69 .607 .758 r
.71433 .34638 .71753 .35437 .72378 .34994 .72063 .34261 Metetra
.693 .623 .774 r
.72063 .34261 .72378 .34994 .73006 .34578 .72694 .33902 Metetra
.694 .639 .79 r
.72694 .33902 .73006 .34578 .73636 .34188 .73328 .3356 Metetra
.695 .653 .804 r
.73328 .3356 .73636 .34188 .74268 .33822 .73964 .33234 Metetra
.694 .666 .818 r
.73964 .33234 .74268 .33822 .74903 .33477 .74602 .32922 Metetra
.693 .678 .831 r
.74602 .32922 .74903 .33477 .7554 .3315 .75242 .32624 Metetra
.691 .688 .843 r
.75242 .32624 .7554 .3315 .76179 .32841 .75884 .32337 Metetra
.689 .697 .853 r
.75884 .32337 .76179 .32841 .7682 .32546 .76527 .32061 Metetra
.686 .705 .862 r
.76527 .32061 .7682 .32546 .77464 .32263 .77173 .31794 Metetra
.684 .711 .869 r
.77173 .31794 .77464 .32263 .7811 .31991 .77821 .31534 Metetra
.681 .717 .876 r
.77821 .31534 .7811 .31991 .78758 .31729 .78471 .31282 Metetra
.679 .721 .882 r
.78471 .31282 .78758 .31729 .79407 .31474 .79122 .31035 Metetra
.676 .725 .886 r
.79122 .31035 .79407 .31474 .80059 .31225 .79776 .30793 Metetra
.674 .728 .89 r
.79776 .30793 .80059 .31225 .80713 .30982 .80431 .30555 Metetra
.673 .731 .894 r
.80431 .30555 .80713 .30982 .81368 .30743 .81087 .30321 Metetra
.671 .733 .896 r
.81087 .30321 .81368 .30743 .82025 .30508 .81746 .30089 Metetra
.67 .734 .899 r
.81746 .30089 .82025 .30508 .82684 .30276 .82406 .29859 Metetra
.669 .736 .9 r
.82406 .29859 .82684 .30276 .83345 .30046 .83068 .2963 Metetra
.668 .737 .902 r
.83068 .2963 .83345 .30046 .84007 .29818 .83732 .29403 Metetra
.667 .738 .903 r
.83732 .29403 .84007 .29818 .84671 .29591 .84397 .29177 Metetra
.666 .738 .904 r
.84397 .29177 .84671 .29591 .85337 .29365 .85064 .28952 Metetra
.666 .739 .905 r
.85064 .28952 .85337 .29365 .86004 .29139 .85733 .28727 Metetra
.665 .739 .905 r
.85733 .28727 .86004 .29139 .86673 .28915 .86403 .28502 Metetra
.665 .74 .906 r
.86403 .28502 .86673 .28915 .87343 .2869 .87074 .28277 Metetra
.664 .741 .908 r
.26932 .47727 .27288 .48059 .27831 .47879 .27475 .47546 Metetra
.664 .741 .908 r
.27475 .47546 .27831 .47879 .28375 .47699 .2802 .47366 Metetra
.663 .741 .908 r
.2802 .47366 .28375 .47699 .2892 .47519 .28565 .47185 Metetra
.663 .741 .908 r
.28565 .47185 .2892 .47519 .29466 .47338 .29112 .47003 Metetra
.663 .741 .908 r
.29112 .47003 .29466 .47338 .30013 .47157 .2966 .46822 Metetra
.663 .741 .908 r
.2966 .46822 .30013 .47157 .30561 .46976 .30209 .4664 Metetra
.663 .741 .908 r
.30209 .4664 .30561 .46976 .31111 .46795 .30759 .46458 Metetra
.663 .741 .908 r
.30759 .46458 .31111 .46795 .31661 .46614 .3131 .46275 Metetra
.663 .74 .908 r
.3131 .46275 .31661 .46614 .32213 .46433 .31863 .46093 Metetra
.662 .74 .908 r
.31863 .46093 .32213 .46433 .32766 .46253 .32416 .45911 Metetra
.662 .739 .907 r
.32416 .45911 .32766 .46253 .3332 .46073 .32971 .4573 Metetra
.661 .738 .907 r
.32971 .4573 .3332 .46073 .33875 .45895 .33527 .45549 Metetra
.66 .737 .907 r
.33527 .45549 .33875 .45895 .34431 .45719 .34084 .45369 Metetra
.658 .735 .906 r
.34084 .45369 .34431 .45719 .34988 .45546 .34641 .45192 Metetra
.656 .732 .905 r
.34641 .45192 .34988 .45546 .35546 .45377 .352 .45017 Metetra
.653 .728 .904 r
.352 .45017 .35546 .45377 .36104 .45215 .3576 .44847 Metetra
.649 .723 .903 r
.3576 .44847 .36104 .45215 .36664 .4506 .36321 .44682 Metetra
.644 .716 .9 r
.36321 .44682 .36664 .4506 .37225 .44916 .36883 .44525 Metetra
.637 .707 .897 r
.36883 .44525 .37225 .44916 .37786 .44785 .37445 .44378 Metetra
.628 .695 .893 r
.37445 .44378 .37786 .44785 .38348 .44672 .38009 .44243 Metetra
.618 .681 .887 r
.38009 .44243 .38348 .44672 .3891 .44579 .38573 .44124 Metetra
.606 .663 .88 r
.38573 .44124 .3891 .44579 .39473 .44512 .39137 .44024 Metetra
.592 .642 .869 r
.39137 .44024 .39473 .44512 .40036 .44476 .39702 .43946 Metetra
.576 .618 .857 r
.39702 .43946 .40036 .44476 .406 .44474 .40268 .43894 Metetra
.561 .591 .841 r
.40268 .43894 .406 .44474 .41164 .44512 .40835 .43871 Metetra
.545 .562 .823 r
.40835 .43871 .41164 .44512 .41729 .44593 .41402 .43879 Metetra
.531 .533 .802 r
.41402 .43879 .41729 .44593 .42294 .44721 .4197 .43919 Metetra
.52 .505 .78 r
.4197 .43919 .42294 .44721 .42861 .44896 .42539 .43991 Metetra
.513 .479 .757 r
.42539 .43991 .42861 .44896 .43429 .45119 .4311 .44094 Metetra
.509 .457 .734 r
.4311 .44094 .43429 .45119 .43998 .45389 .43682 .44222 Metetra
.51 .439 .712 r
.43682 .44222 .43998 .45389 .44569 .457 .44256 .44368 Metetra
.514 .425 .692 r
.44256 .44368 .44569 .457 .45142 .46046 .44832 .44524 Metetra
.521 .414 .673 r
.44832 .44524 .45142 .46046 .45717 .4642 .4541 .44677 Metetra
.53 .407 .657 r
.4541 .44677 .45717 .4642 .46296 .4681 .45992 .44815 Metetra
.539 .402 .643 r
.45992 .44815 .46296 .4681 .46878 .47206 .46576 .44923 Metetra
.549 .399 .63 r
.46576 .44923 .46878 .47206 .47464 .47593 .47164 .44988 Metetra
.558 .397 .619 r
.47164 .44988 .47464 .47593 .48053 .4796 .47754 .44995 Metetra
.565 .396 .61 r
.47754 .44995 .48053 .4796 .48646 .48293 .48348 .44934 Metetra
.572 .394 .603 r
.48348 .44934 .48646 .48293 .49242 .48579 .48944 .44796 Metetra
.577 .393 .596 r
.48944 .44796 .49242 .48579 .49842 .4881 .49542 .44579 Metetra
.58 .392 .59 r
.49542 .44579 .49842 .4881 .50446 .48975 .50142 .44282 Metetra
.583 .39 .586 r
.50142 .44282 .50446 .48975 .51052 .49068 .50743 .43912 Metetra
.584 .388 .582 r
.50743 .43912 .51052 .49068 .51661 .49086 .51346 .4348 Metetra
.584 .386 .579 r
.51346 .4348 .51661 .49086 .52272 .49028 .51948 .42999 Metetra
.584 .384 .576 r
.51948 .42999 .52272 .49028 .52885 .48894 .52552 .42489 Metetra
.582 .381 .574 r
.52552 .42489 .52885 .48894 .53499 .48689 .53155 .41966 Metetra
.58 .379 .572 r
.53155 .41966 .53499 .48689 .54114 .48417 .53758 .41452 Metetra
.578 .376 .571 r
.53758 .41452 .54114 .48417 .5473 .48085 .54362 .40963 Metetra
.576 .374 .57 r
.54362 .40963 .5473 .48085 .55346 .47702 .54966 .40515 Metetra
.573 .372 .57 r
.54966 .40515 .55346 .47702 .55963 .47276 .55571 .40119 Metetra
.57 .37 .57 r
.55571 .40119 .55963 .47276 .56579 .46815 .56177 .39783 Metetra
.568 .368 .57 r
.56177 .39783 .56579 .46815 .57196 .46326 .56785 .39507 Metetra
.565 .367 .571 r
.56785 .39507 .57196 .46326 .57812 .45817 .57395 .39291 Metetra
.563 .366 .572 r
.57395 .39291 .57812 .45817 .58429 .45294 .58007 .39127 Metetra
.561 .366 .574 r
.58007 .39127 .58429 .45294 .59045 .44762 .58622 .39005 Metetra
.56 .367 .577 r
.58622 .39005 .59045 .44762 .59662 .44224 .59238 .38915 Metetra
.56 .369 .58 r
.59238 .38915 .59662 .44224 .60278 .43682 .59857 .38841 Metetra
.56 .373 .584 r
.59857 .38841 .60278 .43682 .60895 .43138 .60478 .38771 Metetra
.562 .377 .588 r
.60478 .38771 .60895 .43138 .61511 .42593 .61101 .38693 Metetra
.565 .384 .594 r
.61101 .38693 .61511 .42593 .62128 .42048 .61725 .38595 Metetra
.57 .392 .602 r
.61725 .38595 .62128 .42048 .62745 .41503 .6235 .3847 Metetra
.576 .403 .61 r
.6235 .3847 .62745 .41503 .63361 .40959 .62975 .38311 Metetra
.583 .416 .62 r
.62975 .38311 .63361 .40959 .63978 .40416 .63601 .38115 Metetra
.593 .431 .631 r
.63601 .38115 .63978 .40416 .64596 .39876 .64227 .37882 Metetra
.604 .449 .644 r
.64227 .37882 .64596 .39876 .65213 .39341 .64853 .37614 Metetra
.616 .469 .658 r
.64853 .37614 .65213 .39341 .65831 .38811 .65478 .37314 Metetra
.63 .49 .674 r
.65478 .37314 .65831 .38811 .66449 .3829 .66104 .36987 Metetra
.643 .514 .69 r
.66104 .36987 .66449 .3829 .67068 .37779 .6673 .36639 Metetra
.657 .537 .707 r
.6673 .36639 .67068 .37779 .67688 .37281 .67355 .36276 Metetra
.669 .561 .724 r
.67355 .36276 .67688 .37281 .68308 .36797 .67982 .35902 Metetra
.68 .584 .741 r
.67982 .35902 .68308 .36797 .6893 .36329 .68608 .35525 Metetra
.69 .606 .757 r
.68608 .35525 .6893 .36329 .69554 .35879 .69236 .35148 Metetra
.697 .625 .773 r
.69236 .35148 .69554 .35879 .70178 .35446 .69864 .34775 Metetra
.702 .643 .787 r
.69864 .34775 .70178 .35446 .70805 .35033 .70494 .34409 Metetra
.705 .659 .801 r
.70494 .34409 .70805 .35033 .71433 .34638 .71125 .34053 Metetra
.707 .672 .814 r
.71125 .34053 .71433 .34638 .72063 .34261 .71758 .33708 Metetra
.707 .683 .825 r
.71758 .33708 .72063 .34261 .72694 .33902 .72392 .33375 Metetra
.705 .693 .836 r
.72392 .33375 .72694 .33902 .73328 .3356 .73028 .33054 Metetra
.703 .701 .845 r
.73028 .33054 .73328 .3356 .73964 .33234 .73666 .32745 Metetra
.7 .708 .854 r
.73666 .32745 .73964 .33234 .74602 .32922 .74306 .32448 Metetra
.696 .713 .862 r
.74306 .32448 .74602 .32922 .75242 .32624 .74947 .32161 Metetra
.693 .718 .868 r
.74947 .32161 .75242 .32624 .75884 .32337 .75591 .31885 Metetra
.689 .722 .874 r
.75591 .31885 .75884 .32337 .76527 .32061 .76236 .31616 Metetra
.686 .725 .879 r
.76236 .31616 .76527 .32061 .77173 .31794 .76884 .31356 Metetra
.683 .728 .884 r
.76884 .31356 .77173 .31794 .77821 .31534 .77533 .31102 Metetra
.68 .73 .888 r
.77533 .31102 .77821 .31534 .78471 .31282 .78184 .30855 Metetra
.677 .732 .891 r
.78184 .30855 .78471 .31282 .79122 .31035 .78837 .30612 Metetra
.675 .733 .894 r
.78837 .30612 .79122 .31035 .79776 .30793 .79492 .30373 Metetra
.673 .735 .896 r
.79492 .30373 .79776 .30793 .80431 .30555 .80148 .30137 Metetra
.671 .736 .898 r
.80148 .30137 .80431 .30555 .81087 .30321 .80807 .29904 Metetra
.67 .737 .9 r
.80807 .29904 .81087 .30321 .81746 .30089 .81466 .29674 Metetra
.669 .737 .902 r
.81466 .29674 .81746 .30089 .82406 .29859 .82128 .29445 Metetra
.668 .738 .903 r
.82128 .29445 .82406 .29859 .83068 .2963 .82791 .29217 Metetra
.667 .739 .904 r
.82791 .29217 .83068 .2963 .83732 .29403 .83456 .2899 Metetra
.666 .739 .905 r
.83456 .2899 .83732 .29403 .84397 .29177 .84122 .28764 Metetra
.666 .74 .905 r
.84122 .28764 .84397 .29177 .85064 .28952 .8479 .28539 Metetra
.665 .74 .906 r
.8479 .28539 .85064 .28952 .85733 .28727 .8546 .28314 Metetra
.665 .74 .906 r
.8546 .28314 .85733 .28727 .86403 .28502 .86131 .28088 Metetra
.665 .74 .906 r
.86131 .28088 .86403 .28502 .87074 .28277 .86804 .27863 Metetra
.664 .741 .908 r
.26574 .47393 .26932 .47727 .27475 .47546 .27118 .47212 Metetra
.664 .741 .908 r
.27118 .47212 .27475 .47546 .2802 .47366 .27663 .47031 Metetra
.664 .741 .908 r
.27663 .47031 .2802 .47366 .28565 .47185 .2821 .46849 Metetra
.663 .741 .908 r
.2821 .46849 .28565 .47185 .29112 .47003 .28757 .46667 Metetra
.663 .741 .908 r
.28757 .46667 .29112 .47003 .2966 .46822 .29306 .46485 Metetra
.663 .741 .908 r
.29306 .46485 .2966 .46822 .30209 .4664 .29855 .46302 Metetra
.663 .741 .908 r
.29855 .46302 .30209 .4664 .30759 .46458 .30406 .46119 Metetra
.663 .741 .908 r
.30406 .46119 .30759 .46458 .3131 .46275 .30958 .45936 Metetra
.663 .741 .908 r
.30958 .45936 .3131 .46275 .31863 .46093 .31511 .45753 Metetra
.663 .74 .908 r
.31511 .45753 .31863 .46093 .32416 .45911 .32065 .45569 Metetra
.662 .74 .908 r
.32065 .45569 .32416 .45911 .32971 .4573 .32621 .45386 Metetra
.662 .739 .907 r
.32621 .45386 .32971 .4573 .33527 .45549 .33177 .45203 Metetra
.661 .738 .907 r
.33177 .45203 .33527 .45549 .34084 .45369 .33735 .45021 Metetra
.66 .737 .907 r
.33735 .45021 .34084 .45369 .34641 .45192 .34294 .44841 Metetra
.658 .735 .906 r
.34294 .44841 .34641 .45192 .352 .45017 .34854 .44662 Metetra
.656 .732 .906 r
.34854 .44662 .352 .45017 .3576 .44847 .35414 .44486 Metetra
.653 .729 .905 r
.35414 .44486 .3576 .44847 .36321 .44682 .35976 .44314 Metetra
.649 .724 .903 r
.35976 .44314 .36321 .44682 .36883 .44525 .36539 .44148 Metetra
.644 .718 .901 r
.36539 .44148 .36883 .44525 .37445 .44378 .37103 .43989 Metetra
.638 .709 .899 r
.37103 .43989 .37445 .44378 .38009 .44243 .37667 .43839 Metetra
.63 .699 .895 r
.37667 .43839 .38009 .44243 .38573 .44124 .38233 .437 Metetra
.62 .686 .89 r
.38233 .437 .38573 .44124 .39137 .44024 .38799 .43576 Metetra
.609 .67 .883 r
.38799 .43576 .39137 .44024 .39702 .43946 .39366 .43468 Metetra
.597 .651 .874 r
.39366 .43468 .39702 .43946 .40268 .43894 .39933 .4338 Metetra
.584 .63 .863 r
.39933 .4338 .40268 .43894 .40835 .43871 .40502 .43314 Metetra
.572 .606 .849 r
.40502 .43314 .40835 .43871 .41402 .43879 .41071 .4327 Metetra
.56 .582 .832 r
.41071 .4327 .41402 .43879 .4197 .43919 .41641 .43249 Metetra
.55 .557 .814 r
.41641 .43249 .4197 .43919 .42539 .43991 .42212 .43251 Metetra
.544 .534 .794 r
.42212 .43251 .42539 .43991 .4311 .44094 .42785 .43271 Metetra
.541 .513 .774 r
.42785 .43271 .4311 .44094 .43682 .44222 .43359 .43305 Metetra
.542 .495 .753 r
.43359 .43305 .43682 .44222 .44256 .44368 .43935 .43345 Metetra
.546 .48 .733 r
.43935 .43345 .44256 .44368 .44832 .44524 .44513 .43382 Metetra
.553 .469 .715 r
.44513 .43382 .44832 .44524 .4541 .44677 .45094 .43404 Metetra
.562 .461 .698 r
.45094 .43404 .4541 .44677 .45992 .44815 .45677 .43399 Metetra
.572 .456 .682 r
.45677 .43399 .45992 .44815 .46576 .44923 .46263 .43354 Metetra
.582 .452 .669 r
.46263 .43354 .46576 .44923 .47164 .44988 .46852 .43258 Metetra
.592 .45 .657 r
.46852 .43258 .47164 .44988 .47754 .44995 .47443 .43102 Metetra
.6 .448 .647 r
.47443 .43102 .47754 .44995 .48348 .44934 .48037 .42879 Metetra
.607 .447 .639 r
.48037 .42879 .48348 .44934 .48944 .44796 .48632 .42588 Metetra
.612 .446 .633 r
.48632 .42588 .48944 .44796 .49542 .44579 .49229 .42233 Metetra
.616 .445 .627 r
.49229 .42233 .49542 .44579 .50142 .44282 .49828 .41824 Metetra
.618 .443 .624 r
.49828 .41824 .50142 .44282 .50743 .43912 .50427 .41373 Metetra
.619 .442 .621 r
.50427 .41373 .50743 .43912 .51346 .4348 .51026 .40901 Metetra
.618 .441 .62 r
.51026 .40901 .51346 .4348 .51948 .42999 .51626 .40427 Metetra
.616 .439 .62 r
.51626 .40427 .51948 .42999 .52552 .42489 .52226 .39974 Metetra
.612 .438 .622 r
.52226 .39974 .52552 .42489 .53155 .41966 .52827 .39561 Metetra
.607 .437 .626 r
.52827 .39561 .53155 .41966 .53758 .41452 .53428 .39208 Metetra
.601 .437 .632 r
.53428 .39208 .53758 .41452 .54362 .40963 .5403 .38927 Metetra
.593 .438 .641 r
.5403 .38927 .54362 .40963 .54966 .40515 .54634 .38726 Metetra
.583 .442 .655 r
.54634 .38726 .54966 .40515 .55571 .40119 .5524 .38608 Metetra
.57 .449 .675 r
.5524 .38608 .55571 .40119 .56177 .39783 .55848 .38567 Metetra
.553 .463 .708 r
.55848 .38567 .56177 .39783 .56785 .39507 .56459 .38593 Metetra
.525 .489 .759 r
.56459 .38593 .56785 .39507 .57395 .39291 .57073 .38672 Metetra
.47 .537 .844 r
.57073 .38672 .57395 .39291 .58007 .39127 .5769 .38785 Metetra
.316 .602 .949 r
.5769 .38785 .58007 .39127 .58622 .39005 .5831 .38913 Metetra
0 .499 .764 r
.5831 .38913 .58622 .39005 .59238 .38915 .58932 .39035 Metetra
.356 0 0 r
.58932 .39035 .59238 .38915 .59857 .38841 .59557 .39133 Metetra
.424 0 0 r
.59557 .39133 .59857 .38841 .60478 .38771 .60183 .3919 Metetra
.428 0 .066 r
.60183 .3919 .60478 .38771 .61101 .38693 .6081 .39195 Metetra
.409 0 .108 r
.6081 .39195 .61101 .38693 .61725 .38595 .61438 .39138 Metetra
.376 0 .115 r
.61438 .39138 .61725 .38595 .6235 .3847 .62065 .39016 Metetra
.328 0 .095 r
.62065 .39016 .6235 .3847 .62975 .38311 .62693 .38829 Metetra
.263 0 .047 r
.62693 .38829 .62975 .38311 .63601 .38115 .63319 .3858 Metetra
.173 0 0 r
.63319 .3858 .63601 .38115 .64227 .37882 .63945 .38275 Metetra
.048 0 0 r
.63945 .38275 .64227 .37882 .64853 .37614 .64571 .37923 Metetra
.64571 .37923 .64853 .37614 .65478 .37314 .65195 .37534 Metetra
.65195 .37534 .65478 .37314 .66104 .36987 .65819 .37117 Metetra
.538 .905 .717 r
.65819 .37117 .66104 .36987 .6673 .36639 .66443 .36681 Metetra
.686 .98 .848 r
.66443 .36681 .6673 .36639 .67355 .36276 .67067 .36236 Metetra
.763 .983 .908 r
.67067 .36236 .67355 .36276 .67982 .35902 .67692 .3579 Metetra
.79 .951 .924 r
.67692 .3579 .67982 .35902 .68608 .35525 .68317 .35348 Metetra
.793 .911 .921 r
.68317 .35348 .68608 .35525 .69236 .35148 .68943 .34915 Metetra
.785 .874 .913 r
.68943 .34915 .69236 .35148 .69864 .34775 .69571 .34496 Metetra
.774 .842 .904 r
.69571 .34496 .69864 .34775 .70494 .34409 .702 .34093 Metetra
.761 .817 .896 r
.702 .34093 .70494 .34409 .71125 .34053 .7083 .33707 Metetra
.749 .796 .891 r
.7083 .33707 .71125 .34053 .71758 .33708 .71463 .33339 Metetra
.738 .781 .887 r
.71463 .33339 .71758 .33708 .72392 .33375 .72097 .32989 Metetra
.728 .769 .885 r
.72097 .32989 .72392 .33375 .73028 .33054 .72734 .32656 Metetra
.719 .759 .884 r
.72734 .32656 .73028 .33054 .73666 .32745 .73372 .32338 Metetra
.711 .752 .885 r
.73372 .32338 .73666 .32745 .74306 .32448 .74013 .32035 Metetra
.704 .747 .886 r
.74013 .32035 .74306 .32448 .74947 .32161 .74655 .31745 Metetra
.698 .744 .887 r
.74655 .31745 .74947 .32161 .75591 .31885 .753 .31466 Metetra
.692 .741 .889 r
.753 .31466 .75591 .31885 .76236 .31616 .75946 .31198 Metetra
.687 .74 .891 r
.75946 .31198 .76236 .31616 .76884 .31356 .76595 .30937 Metetra
.683 .739 .893 r
.76595 .30937 .76884 .31356 .77533 .31102 .77245 .30684 Metetra
.68 .738 .895 r
.77245 .30684 .77533 .31102 .78184 .30855 .77898 .30437 Metetra
.677 .738 .897 r
.77898 .30437 .78184 .30855 .78837 .30612 .78552 .30195 Metetra
.674 .738 .898 r
.78552 .30195 .78837 .30612 .79492 .30373 .79208 .29957 Metetra
.672 .738 .9 r
.79208 .29957 .79492 .30373 .80148 .30137 .79865 .29722 Metetra
.671 .738 .901 r
.79865 .29722 .80148 .30137 .80807 .29904 .80525 .2949 Metetra
.669 .739 .902 r
.80525 .2949 .80807 .29904 .81466 .29674 .81186 .2926 Metetra
.668 .739 .903 r
.81186 .2926 .81466 .29674 .82128 .29445 .81848 .29031 Metetra
.667 .739 .904 r
.81848 .29031 .82128 .29445 .82791 .29217 .82513 .28804 Metetra
.666 .74 .905 r
.82513 .28804 .82791 .29217 .83456 .2899 .83179 .28577 Metetra
.666 .74 .905 r
.83179 .28577 .83456 .2899 .84122 .28764 .83846 .28351 Metetra
.665 .74 .906 r
.83846 .28351 .84122 .28764 .8479 .28539 .84516 .28125 Metetra
.665 .74 .906 r
.84516 .28125 .8479 .28539 .8546 .28314 .85186 .27899 Metetra
.665 .74 .907 r
.85186 .27899 .8546 .28314 .86131 .28088 .85859 .27674 Metetra
.664 .741 .907 r
.85859 .27674 .86131 .28088 .86804 .27863 .86533 .27448 Metetra
.664 .741 .908 r
.26215 .47059 .26574 .47393 .27118 .47212 .2676 .46877 Metetra
.664 .741 .908 r
.2676 .46877 .27118 .47212 .27663 .47031 .27305 .46695 Metetra
.664 .741 .908 r
.27305 .46695 .27663 .47031 .2821 .46849 .27852 .46513 Metetra
.664 .741 .908 r
.27852 .46513 .2821 .46849 .28757 .46667 .284 .4633 Metetra
.663 .741 .908 r
.284 .4633 .28757 .46667 .29306 .46485 .2895 .46147 Metetra
.663 .741 .908 r
.2895 .46147 .29306 .46485 .29855 .46302 .295 .45963 Metetra
.663 .741 .908 r
.295 .45963 .29855 .46302 .30406 .46119 .30052 .45779 Metetra
.663 .741 .908 r
.30052 .45779 .30406 .46119 .30958 .45936 .30604 .45595 Metetra
.663 .741 .908 r
.30604 .45595 .30958 .45936 .31511 .45753 .31158 .45411 Metetra
.663 .741 .908 r
.31158 .45411 .31511 .45753 .32065 .45569 .31713 .45227 Metetra
.663 .74 .908 r
.31713 .45227 .32065 .45569 .32621 .45386 .32269 .45042 Metetra
.662 .74 .908 r
.32269 .45042 .32621 .45386 .33177 .45203 .32827 .44858 Metetra
.662 .739 .908 r
.32827 .44858 .33177 .45203 .33735 .45021 .33385 .44674 Metetra
.661 .739 .907 r
.33385 .44674 .33735 .45021 .34294 .44841 .33944 .44491 Metetra
.66 .737 .907 r
.33944 .44491 .34294 .44841 .34854 .44662 .34505 .4431 Metetra
.658 .736 .907 r
.34505 .4431 .34854 .44662 .35414 .44486 .35067 .44131 Metetra
.656 .733 .907 r
.35067 .44131 .35414 .44486 .35976 .44314 .35629 .43954 Metetra
.652 .73 .906 r
.35629 .43954 .35976 .44314 .36539 .44148 .36193 .43783 Metetra
.648 .726 .906 r
.36193 .43783 .36539 .44148 .37103 .43989 .36758 .43617 Metetra
.642 .721 .906 r
.36758 .43617 .37103 .43989 .37667 .43839 .37323 .4346 Metetra
.635 .715 .905 r
.37323 .4346 .37667 .43839 .38233 .437 .3789 .43313 Metetra
.625 .708 .905 r
.3789 .43313 .38233 .437 .38799 .43576 .38457 .4318 Metetra
.613 .699 .905 r
.38457 .4318 .38799 .43576 .39366 .43468 .39025 .43063 Metetra
.598 .688 .906 r
.39025 .43063 .39366 .43468 .39933 .4338 .39593 .42967 Metetra
.579 .677 .907 r
.39593 .42967 .39933 .4338 .40502 .43314 .40162 .42895 Metetra
.555 .665 .91 r
.40162 .42895 .40502 .43314 .41071 .4327 .40732 .42852 Metetra
.526 .653 .915 r
.40732 .42852 .41071 .4327 .41641 .43249 .41302 .4284 Metetra
.488 .642 .924 r
.41302 .4284 .41641 .43249 .42212 .43251 .41873 .42863 Metetra
.437 .631 .936 r
.41873 .42863 .42212 .43251 .42785 .43271 .42445 .42922 Metetra
.359 .618 .95 r
.42445 .42922 .42785 .43271 .43359 .43305 .43018 .43018 Metetra
.227 .591 .947 r
.43018 .43018 .43359 .43305 .43935 .43345 .43592 .43151 Metetra
0 .502 .855 r
.43592 .43151 .43935 .43345 .44513 .43382 .44168 .43318 Metetra
.322 0 0 r
.44168 .43318 .44513 .43382 .45094 .43404 .44745 .43516 Metetra
.521 0 0 r
.44745 .43516 .45094 .43404 .45677 .43399 .45325 .43738 Metetra
.581 .121 .125 r
.45325 .43738 .45677 .43399 .46263 .43354 .45907 .43979 Metetra
.591 .199 .268 r
.45907 .43979 .46263 .43354 .46852 .43258 .46492 .44232 Metetra
.586 .241 .35 r
.46492 .44232 .46852 .43258 .47443 .43102 .47079 .4449 Metetra
.579 .265 .4 r
.47079 .4449 .47443 .43102 .48037 .42879 .4767 .44746 Metetra
.573 .28 .432 r
.4767 .44746 .48037 .42879 .48632 .42588 .48264 .44996 Metetra
.567 .289 .454 r
.48264 .44996 .48632 .42588 .49229 .42233 .4886 .45234 Metetra
.563 .296 .47 r
.4886 .45234 .49229 .42233 .49828 .41824 .4946 .4546 Metetra
.559 .301 .481 r
.4946 .4546 .49828 .41824 .50427 .41373 .50062 .45673 Metetra
.557 .304 .489 r
.50062 .45673 .50427 .41373 .51026 .40901 .50668 .45872 Metetra
.555 .307 .495 r
.50668 .45872 .51026 .40901 .51626 .40427 .51276 .46059 Metetra
.553 .309 .5 r
.51276 .46059 .51626 .40427 .52226 .39974 .51888 .46233 Metetra
.552 .311 .503 r
.51888 .46233 .52226 .39974 .52827 .39561 .52502 .46393 Metetra
.551 .312 .506 r
.52502 .46393 .52827 .39561 .53428 .39208 .53118 .46537 Metetra
.55 .312 .508 r
.53118 .46537 .53428 .39208 .5403 .38927 .53737 .46658 Metetra
.549 .312 .509 r
.53737 .46658 .5403 .38927 .54634 .38726 .54359 .46751 Metetra
.547 .311 .51 r
.54359 .46751 .54634 .38726 .5524 .38608 .54983 .46804 Metetra
.545 .31 .51 r
.54983 .46804 .5524 .38608 .55848 .38567 .55609 .46808 Metetra
.542 .308 .51 r
.55609 .46808 .55848 .38567 .56459 .38593 .56236 .46751 Metetra
.539 .305 .509 r
.56236 .46751 .56459 .38593 .57073 .38672 .56864 .46622 Metetra
.535 .302 .508 r
.56864 .46622 .57073 .38672 .5769 .38785 .57493 .46414 Metetra
.531 .297 .506 r
.57493 .46414 .5769 .38785 .5831 .38913 .58121 .4612 Metetra
.525 .292 .503 r
.58121 .4612 .5831 .38913 .58932 .39035 .58749 .45738 Metetra
.519 .285 .5 r
.58749 .45738 .58932 .39035 .59557 .39133 .59376 .45269 Metetra
.511 .277 .495 r
.59376 .45269 .59557 .39133 .60183 .3919 .60002 .44718 Metetra
.501 .266 .49 r
.60002 .44718 .60183 .3919 .6081 .39195 .60626 .44094 Metetra
.49 .254 .483 r
.60626 .44094 .6081 .39195 .61438 .39138 .61247 .43407 Metetra
.476 .238 .473 r
.61247 .43407 .61438 .39138 .62065 .39016 .61867 .4267 Metetra
.459 .218 .461 r
.61867 .4267 .62065 .39016 .62693 .38829 .62486 .41899 Metetra
.436 .192 .444 r
.62486 .41899 .62693 .38829 .63319 .3858 .63102 .41107 Metetra
.408 .158 .42 r
.63102 .41107 .63319 .3858 .63945 .38275 .63718 .40308 Metetra
.369 .112 .388 r
.63718 .40308 .63945 .38275 .64571 .37923 .64333 .39516 Metetra
.315 .048 .339 r
.64333 .39516 .64571 .37923 .65195 .37534 .64948 .38741 Metetra
.236 0 .265 r
.64948 .38741 .65195 .37534 .65819 .37117 .65563 .37992 Metetra
.114 0 .144 r
.65563 .37992 .65819 .37117 .66443 .36681 .66179 .37276 Metetra
.66179 .37276 .66443 .36681 .67067 .36236 .66795 .36598 Metetra
.66795 .36598 .67067 .36236 .67692 .3579 .67414 .35961 Metetra
.651 .935 .67 r
.67414 .35961 .67692 .3579 .68317 .35348 .68034 .35367 Metetra
.796 .999 .846 r
.68034 .35367 .68317 .35348 .68943 .34915 .68656 .34814 Metetra
.825 .959 .899 r
.68656 .34814 .68943 .34915 .69571 .34496 .6928 .34302 Metetra
.812 .903 .904 r
.6928 .34302 .69571 .34496 .702 .34093 .69907 .33828 Metetra
.791 .855 .898 r
.69907 .33828 .702 .34093 .7083 .33707 .70536 .33389 Metetra
.77 .819 .891 r
.70536 .33389 .7083 .33707 .71463 .33339 .71168 .32983 Metetra
.752 .793 .886 r
.71168 .32983 .71463 .33339 .72097 .32989 .71802 .32606 Metetra
.737 .774 .883 r
.71802 .32606 .72097 .32989 .72734 .32656 .72438 .32255 Metetra
.724 .76 .881 r
.72438 .32255 .72734 .32656 .73372 .32338 .73077 .31925 Metetra
.714 .751 .882 r
.73077 .31925 .73372 .32338 .74013 .32035 .73718 .31615 Metetra
.705 .745 .883 r
.73718 .31615 .74013 .32035 .74655 .31745 .74362 .31321 Metetra
.697 .741 .885 r
.74362 .31321 .74655 .31745 .753 .31466 .75007 .31041 Metetra
.691 .738 .887 r
.75007 .31041 .753 .31466 .75946 .31198 .75655 .30772 Metetra
.686 .737 .889 r
.75655 .30772 .75946 .31198 .76595 .30937 .76305 .30513 Metetra
.682 .736 .892 r
.76305 .30513 .76595 .30937 .77245 .30684 .76956 .30261 Metetra
.678 .736 .894 r
.76956 .30261 .77245 .30684 .77898 .30437 .7761 .30016 Metetra
.675 .736 .896 r
.7761 .30016 .77898 .30437 .78552 .30195 .78265 .29775 Metetra
.673 .736 .898 r
.78265 .29775 .78552 .30195 .79208 .29957 .78922 .29538 Metetra
.671 .737 .9 r
.78922 .29538 .79208 .29957 .79865 .29722 .79581 .29305 Metetra
.669 .737 .901 r
.79581 .29305 .79865 .29722 .80525 .2949 .80242 .29074 Metetra
.668 .738 .902 r
.80242 .29074 .80525 .2949 .81186 .2926 .80904 .28844 Metetra
.667 .738 .903 r
.80904 .28844 .81186 .2926 .81848 .29031 .81568 .28616 Metetra
.666 .739 .904 r
.81568 .28616 .81848 .29031 .82513 .28804 .82233 .28389 Metetra
.666 .739 .905 r
.82233 .28389 .82513 .28804 .83179 .28577 .82901 .28162 Metetra
.665 .74 .905 r
.82901 .28162 .83179 .28577 .83846 .28351 .83569 .27936 Metetra
.665 .74 .906 r
.83569 .27936 .83846 .28351 .84516 .28125 .8424 .2771 Metetra
.665 .74 .906 r
.8424 .2771 .84516 .28125 .85186 .27899 .84912 .27484 Metetra
.664 .74 .907 r
.84912 .27484 .85186 .27899 .85859 .27674 .85585 .27257 Metetra
.664 .741 .907 r
.85585 .27257 .85859 .27674 .86533 .27448 .8626 .27031 Metetra
.664 .741 .908 r
.25854 .46723 .26215 .47059 .2676 .46877 .264 .46541 Metetra
.664 .741 .908 r
.264 .46541 .2676 .46877 .27305 .46695 .26946 .46358 Metetra
.664 .741 .908 r
.26946 .46358 .27305 .46695 .27852 .46513 .27494 .46175 Metetra
.664 .741 .908 r
.27494 .46175 .27852 .46513 .284 .4633 .28043 .45991 Metetra
.664 .741 .908 r
.28043 .45991 .284 .4633 .2895 .46147 .28592 .45807 Metetra
.663 .741 .908 r
.28592 .45807 .2895 .46147 .295 .45963 .29144 .45623 Metetra
.663 .741 .908 r
.29144 .45623 .295 .45963 .30052 .45779 .29696 .45438 Metetra
.663 .741 .908 r
.29696 .45438 .30052 .45779 .30604 .45595 .30249 .45254 Metetra
.663 .741 .908 r
.30249 .45254 .30604 .45595 .31158 .45411 .30804 .45068 Metetra
.663 .741 .908 r
.30804 .45068 .31158 .45411 .31713 .45227 .31359 .44883 Metetra
.663 .741 .908 r
.31359 .44883 .31713 .45227 .32269 .45042 .31916 .44698 Metetra
.663 .74 .908 r
.31916 .44698 .32269 .45042 .32827 .44858 .32474 .44512 Metetra
.662 .74 .908 r
.32474 .44512 .32827 .44858 .33385 .44674 .33033 .44327 Metetra
.662 .739 .908 r
.33033 .44327 .33385 .44674 .33944 .44491 .33594 .44142 Metetra
.661 .739 .908 r
.33594 .44142 .33944 .44491 .34505 .4431 .34155 .43959 Metetra
.659 .737 .908 r
.34155 .43959 .34505 .4431 .35067 .44131 .34718 .43777 Metetra
.657 .736 .908 r
.34718 .43777 .35067 .44131 .35629 .43954 .35281 .43598 Metetra
.654 .733 .908 r
.35281 .43598 .35629 .43954 .36193 .43783 .35846 .43422 Metetra
.65 .731 .908 r
.35846 .43422 .36193 .43783 .36758 .43617 .36411 .43252 Metetra
.645 .727 .908 r
.36411 .43252 .36758 .43617 .37323 .4346 .36978 .4309 Metetra
.637 .722 .909 r
.36978 .4309 .37323 .4346 .3789 .43313 .37545 .42938 Metetra
.627 .716 .911 r
.37545 .42938 .3789 .43313 .38457 .4318 .38113 .42801 Metetra
.613 .709 .914 r
.38113 .42801 .38457 .4318 .39025 .43063 .38681 .42682 Metetra
.594 .701 .918 r
.38681 .42682 .39025 .43063 .39593 .42967 .3925 .42586 Metetra
.567 .692 .925 r
.3925 .42586 .39593 .42967 .40162 .42895 .3982 .42521 Metetra
.529 .681 .935 r
.3982 .42521 .40162 .42895 .40732 .42852 .40389 .42494 Metetra
.472 .667 .948 r
.40389 .42494 .40732 .42852 .41302 .4284 .40959 .42511 Metetra
.377 .642 .959 r
.40959 .42511 .41302 .4284 .41873 .42863 .41529 .42583 Metetra
.21 .586 .945 r
.41529 .42583 .41873 .42863 .42445 .42922 .42099 .42717 Metetra
0 .437 .813 r
.42099 .42717 .42445 .42922 .43018 .43018 .42669 .42924 Metetra
.441 0 0 r
.42669 .42924 .43018 .43018 .43592 .43151 .4324 .43211 Metetra
.635 .098 0 r
.4324 .43211 .43592 .43151 .44168 .43318 .43812 .43586 Metetra
.689 .235 .169 r
.43812 .43586 .44168 .43318 .44745 .43516 .44384 .44055 Metetra
.693 .301 .3 r
.44384 .44055 .44745 .43516 .45325 .43738 .44958 .44621 Metetra
.683 .333 .375 r
.44958 .44621 .45325 .43738 .45907 .43979 .45533 .45284 Metetra
.67 .348 .421 r
.45533 .45284 .45907 .43979 .46492 .44232 .46112 .46041 Metetra
.656 .355 .45 r
.46112 .46041 .46492 .44232 .47079 .4449 .46693 .46886 Metetra
.643 .357 .47 r
.46693 .46886 .47079 .4449 .4767 .44746 .47278 .47807 Metetra
.632 .357 .484 r
.47278 .47807 .4767 .44746 .48264 .44996 .47868 .48788 Metetra
.621 .355 .493 r
.47868 .48788 .48264 .44996 .4886 .45234 .48464 .49809 Metetra
.611 .352 .5 r
.48464 .49809 .4886 .45234 .4946 .4546 .49064 .50846 Metetra
.602 .348 .505 r
.49064 .50846 .4946 .4546 .50062 .45673 .49671 .51871 Metetra
.593 .344 .508 r
.49671 .51871 .50062 .45673 .50668 .45872 .50284 .52854 Metetra
.586 .34 .511 r
.50284 .52854 .50668 .45872 .51276 .46059 .50903 .53763 Metetra
.578 .335 .512 r
.50903 .53763 .51276 .46059 .51888 .46233 .51528 .54566 Metetra
.571 .331 .513 r
.51528 .54566 .51888 .46233 .52502 .46393 .52159 .55233 Metetra
.563 .325 .513 r
.52159 .55233 .52502 .46393 .53118 .46537 .52793 .55737 Metetra
.556 .32 .513 r
.52793 .55737 .53118 .46537 .53737 .46658 .53432 .56055 Metetra
.549 .314 .512 r
.53432 .56055 .53737 .46658 .54359 .46751 .54073 .5617 Metetra
.541 .308 .511 r
.54073 .5617 .54359 .46751 .54983 .46804 .54715 .56072 Metetra
.532 .301 .51 r
.54715 .56072 .54983 .46804 .55609 .46808 .55357 .55759 Metetra
.523 .293 .507 r
.55357 .55759 .55609 .46808 .56236 .46751 .55998 .55238 Metetra
.513 .284 .504 r
.55998 .55238 .56236 .46751 .56864 .46622 .56637 .5452 Metetra
.502 .274 .5 r
.56637 .5452 .56864 .46622 .57493 .46414 .57273 .53625 Metetra
.489 .261 .495 r
.57273 .53625 .57493 .46414 .58121 .4612 .57905 .52578 Metetra
.473 .247 .489 r
.57905 .52578 .58121 .4612 .58749 .45738 .58533 .51407 Metetra
.455 .228 .48 r
.58533 .51407 .58749 .45738 .59376 .45269 .59157 .50142 Metetra
.431 .205 .469 r
.59157 .50142 .59376 .45269 .60002 .44718 .59777 .48814 Metetra
.402 .176 .453 r
.59777 .48814 .60002 .44718 .60626 .44094 .60393 .47453 Metetra
.362 .136 .43 r
.60393 .47453 .60626 .44094 .61247 .43407 .61006 .46086 Metetra
.308 .08 .396 r
.61006 .46086 .61247 .43407 .61867 .4267 .61616 .44737 Metetra
.228 0 .343 r
.61616 .44737 .61867 .4267 .62486 .41899 .62225 .43427 Metetra
.104 0 .255 r
.62225 .43427 .62486 .41899 .63102 .41107 .62832 .42172 Metetra
0 0 .1 r
.62832 .42172 .63102 .41107 .63718 .40308 .63439 .40984 Metetra
.63439 .40984 .63718 .40308 .64333 .39516 .64046 .39872 Metetra
.767 .901 .505 r
.64046 .39872 .64333 .39516 .64948 .38741 .64654 .3884 Metetra
.926 .974 .716 r
.64654 .3884 .64948 .38741 .65563 .37992 .65264 .37891 Metetra
.929 .92 .784 r
.65264 .37891 .65563 .37992 .66179 .37276 .65875 .37024 Metetra
.892 .852 .797 r
.65875 .37024 .66179 .37276 .66795 .36598 .66489 .36235 Metetra
.853 .8 .798 r
.66489 .36235 .66795 .36598 .67414 .35961 .67105 .3552 Metetra
.821 .763 .797 r
.67105 .3552 .67414 .35961 .68034 .35367 .67724 .34873 Metetra
.795 .737 .798 r
.67724 .34873 .68034 .35367 .68656 .34814 .68346 .34289 Metetra
.774 .72 .801 r
.68346 .34289 .68656 .34814 .6928 .34302 .6897 .33761 Metetra
.757 .709 .806 r
.6897 .33761 .6928 .34302 .69907 .33828 .69598 .33283 Metetra
.743 .702 .813 r
.69598 .33283 .69907 .33828 .70536 .33389 .70228 .32848 Metetra
.731 .699 .82 r
.70228 .32848 .70536 .33389 .71168 .32983 .70861 .3245 Metetra
.721 .699 .828 r
.70861 .3245 .71168 .32983 .71802 .32606 .71497 .32084 Metetra
.712 .7 .837 r
.71497 .32084 .71802 .32606 .72438 .32255 .72135 .31745 Metetra
.705 .702 .845 r
.72135 .31745 .72438 .32255 .73077 .31925 .72775 .31428 Metetra
.698 .706 .853 r
.72775 .31428 .73077 .31925 .73718 .31615 .73418 .31131 Metetra
.692 .709 .861 r
.73418 .31131 .73718 .31615 .74362 .31321 .74064 .30848 Metetra
.688 .713 .868 r
.74064 .30848 .74362 .31321 .75007 .31041 .74711 .30579 Metetra
.683 .717 .875 r
.74711 .30579 .75007 .31041 .75655 .30772 .7536 .30319 Metetra
.68 .721 .88 r
.7536 .30319 .75655 .30772 .76305 .30513 .76012 .30067 Metetra
.677 .724 .885 r
.76012 .30067 .76305 .30513 .76956 .30261 .76665 .29822 Metetra
.674 .727 .889 r
.76665 .29822 .76956 .30261 .7761 .30016 .7732 .29582 Metetra
.672 .729 .893 r
.7732 .29582 .7761 .30016 .78265 .29775 .77977 .29346 Metetra
.67 .731 .896 r
.77977 .29346 .78265 .29775 .78922 .29538 .78635 .29113 Metetra
.669 .733 .898 r
.78635 .29113 .78922 .29538 .79581 .29305 .79295 .28882 Metetra
.668 .735 .9 r
.79295 .28882 .79581 .29305 .80242 .29074 .79957 .28653 Metetra
.667 .736 .902 r
.79957 .28653 .80242 .29074 .80904 .28844 .80621 .28425 Metetra
.666 .737 .903 r
.80621 .28425 .80904 .28844 .81568 .28616 .81286 .28198 Metetra
.665 .738 .904 r
.81286 .28198 .81568 .28616 .82233 .28389 .81953 .27971 Metetra
.665 .739 .905 r
.81953 .27971 .82233 .28389 .82901 .28162 .82621 .27745 Metetra
.665 .739 .906 r
.82621 .27745 .82901 .28162 .83569 .27936 .83291 .27519 Metetra
.664 .74 .906 r
.83291 .27519 .83569 .27936 .8424 .2771 .83963 .27292 Metetra
.664 .74 .906 r
.83963 .27292 .8424 .2771 .84912 .27484 .84636 .27066 Metetra
.664 .74 .907 r
.84636 .27066 .84912 .27484 .85585 .27257 .85311 .26839 Metetra
.664 .74 .907 r
.85311 .26839 .85585 .27257 .8626 .27031 .85987 .26612 Metetra
.664 .741 .908 r
.25492 .46386 .25854 .46723 .264 .46541 .26038 .46203 Metetra
.664 .741 .908 r
.26038 .46203 .264 .46541 .26946 .46358 .26585 .46019 Metetra
.664 .741 .908 r
.26585 .46019 .26946 .46358 .27494 .46175 .27134 .45836 Metetra
.664 .741 .908 r
.27134 .45836 .27494 .46175 .28043 .45991 .27683 .45651 Metetra
.664 .741 .908 r
.27683 .45651 .28043 .45991 .28592 .45807 .28234 .45467 Metetra
.664 .741 .908 r
.28234 .45467 .28592 .45807 .29144 .45623 .28786 .45282 Metetra
.663 .741 .908 r
.28786 .45282 .29144 .45623 .29696 .45438 .29339 .45096 Metetra
.663 .741 .908 r
.29339 .45096 .29696 .45438 .30249 .45254 .29893 .44911 Metetra
.663 .741 .908 r
.29893 .44911 .30249 .45254 .30804 .45068 .30448 .44725 Metetra
.663 .741 .908 r
.30448 .44725 .30804 .45068 .31359 .44883 .31004 .44538 Metetra
.663 .741 .908 r
.31004 .44538 .31359 .44883 .31916 .44698 .31562 .44352 Metetra
.663 .741 .908 r
.31562 .44352 .31916 .44698 .32474 .44512 .32121 .44165 Metetra
.663 .74 .908 r
.32121 .44165 .32474 .44512 .33033 .44327 .32681 .43978 Metetra
.662 .74 .908 r
.32681 .43978 .33033 .44327 .33594 .44142 .33242 .43792 Metetra
.662 .739 .907 r
.33242 .43792 .33594 .44142 .34155 .43959 .33804 .43606 Metetra
.661 .738 .907 r
.33804 .43606 .34155 .43959 .34718 .43777 .34367 .43422 Metetra
.659 .736 .907 r
.34367 .43422 .34718 .43777 .35281 .43598 .34932 .43239 Metetra
.657 .734 .906 r
.34932 .43239 .35281 .43598 .35846 .43422 .35497 .43058 Metetra
.654 .731 .905 r
.35497 .43058 .35846 .43422 .36411 .43252 .36064 .42882 Metetra
.65 .726 .904 r
.36064 .42882 .36411 .43252 .36978 .4309 .36631 .42711 Metetra
.644 .72 .903 r
.36631 .42711 .36978 .4309 .37545 .42938 .37199 .42549 Metetra
.637 .712 .901 r
.37199 .42549 .37545 .42938 .38113 .42801 .37769 .42397 Metetra
.626 .701 .899 r
.37769 .42397 .38113 .42801 .38681 .42682 .38338 .42261 Metetra
.613 .687 .896 r
.38338 .42261 .38681 .42682 .3925 .42586 .38909 .42144 Metetra
.595 .67 .892 r
.38909 .42144 .3925 .42586 .3982 .42521 .3948 .42053 Metetra
.573 .648 .886 r
.3948 .42053 .3982 .42521 .40389 .42494 .40051 .41995 Metetra
.544 .621 .879 r
.40051 .41995 .40389 .42494 .40959 .42511 .40622 .41978 Metetra
.51 .589 .87 r
.40622 .41978 .40959 .42511 .41529 .42583 .41194 .42011 Metetra
.469 .552 .858 r
.41194 .42011 .41529 .42583 .42099 .42717 .41765 .42103 Metetra
.42 .509 .844 r
.41765 .42103 .42099 .42717 .42669 .42924 .42337 .42264 Metetra
.364 .46 .825 r
.42337 .42264 .42669 .42924 .4324 .43211 .42909 .42505 Metetra
.301 .406 .804 r
.42909 .42505 .4324 .43211 .43812 .43586 .43481 .42834 Metetra
.232 .349 .778 r
.43481 .42834 .43812 .43586 .44384 .44055 .44053 .43259 Metetra
.16 .29 .749 r
.44053 .43259 .44384 .44055 .44958 .44621 .44627 .43784 Metetra
.086 .23 .717 r
.44627 .43784 .44958 .44621 .45533 .45284 .45203 .44411 Metetra
.016 .174 .685 r
.45203 .44411 .45533 .45284 .46112 .46041 .45781 .45137 Metetra
0 .124 .654 r
.45781 .45137 .46112 .46041 .46693 .46886 .46361 .45954 Metetra
0 .084 .628 r
.46361 .45954 .46693 .46886 .47278 .47807 .46946 .46848 Metetra
0 .06 .61 r
.46946 .46848 .47278 .47807 .47868 .48788 .47535 .47801 Metetra
0 .054 .605 r
.47535 .47801 .47868 .48788 .48464 .49809 .48129 .48787 Metetra
0 .07 .613 r
.48129 .48787 .48464 .49809 .49064 .50846 .48729 .49776 Metetra
0 .109 .632 r
.48729 .49776 .49064 .50846 .49671 .51871 .49334 .50735 Metetra
.078 .167 .655 r
.49334 .50735 .49671 .51871 .50284 .52854 .49946 .51629 Metetra
.195 .233 .674 r
.49946 .51629 .50284 .52854 .50903 .53763 .50564 .52421 Metetra
.31 .297 .682 r
.50564 .52421 .50903 .53763 .51528 .54566 .51188 .53076 Metetra
.409 .348 .678 r
.51188 .53076 .51528 .54566 .52159 .55233 .51816 .53565 Metetra
.485 .386 .668 r
.51816 .53565 .52159 .55233 .52793 .55737 .52449 .53862 Metetra
.54 .412 .655 r
.52449 .53862 .52793 .55737 .53432 .56055 .53085 .53951 Metetra
.579 .43 .643 r
.53085 .53951 .53432 .56055 .54073 .5617 .53722 .53823 Metetra
.606 .441 .631 r
.53722 .53823 .54073 .5617 .54715 .56072 .5436 .5348 Metetra
.625 .447 .622 r
.5436 .5348 .54715 .56072 .55357 .55759 .54997 .5293 Metetra
.638 .452 .615 r
.54997 .5293 .55357 .55759 .55998 .55238 .55633 .52191 Metetra
.646 .454 .609 r
.55633 .52191 .55998 .55238 .56637 .5452 .56266 .51287 Metetra
.652 .456 .605 r
.56266 .51287 .56637 .5452 .57273 .53625 .56896 .50247 Metetra
.656 .456 .602 r
.56896 .50247 .57273 .53625 .57905 .52578 .57522 .491 Metetra
.659 .457 .6 r
.57522 .491 .57905 .52578 .58533 .51407 .58146 .4788 Metetra
.661 .457 .598 r
.58146 .4788 .58533 .51407 .59157 .50142 .58765 .46616 Metetra
.662 .458 .598 r
.58765 .46616 .59157 .50142 .59777 .48814 .59382 .45338 Metetra
.662 .459 .599 r
.59382 .45338 .59777 .48814 .60393 .47453 .59997 .44071 Metetra
.662 .46 .6 r
.59997 .44071 .60393 .47453 .61006 .46086 .60609 .42836 Metetra
.662 .461 .602 r
.60609 .42836 .61006 .46086 .61616 .44737 .6122 .41651 Metetra
.662 .463 .605 r
.6122 .41651 .61616 .44737 .62225 .43427 .61831 .40527 Metetra
.662 .466 .609 r
.61831 .40527 .62225 .43427 .62832 .42172 .62442 .39474 Metetra
.663 .47 .613 r
.62442 .39474 .62832 .42172 .63439 .40984 .63053 .38497 Metetra
.663 .474 .619 r
.63053 .38497 .63439 .40984 .64046 .39872 .63665 .37597 Metetra
.664 .48 .626 r
.63665 .37597 .64046 .39872 .64654 .3884 .64279 .36774 Metetra
.664 .486 .634 r
.64279 .36774 .64654 .3884 .65264 .37891 .64894 .36025 Metetra
.665 .494 .644 r
.64894 .36025 .65264 .37891 .65875 .37024 .65512 .35346 Metetra
.666 .504 .655 r
.65512 .35346 .65875 .37024 .66489 .36235 .66132 .34732 Metetra
.668 .515 .667 r
.66132 .34732 .66489 .36235 .67105 .3552 .66755 .34176 Metetra
.67 .527 .681 r
.66755 .34176 .67105 .3552 .67724 .34873 .6738 .33672 Metetra
.671 .54 .697 r
.6738 .33672 .67724 .34873 .68346 .34289 .68008 .33215 Metetra
.673 .555 .714 r
.68008 .33215 .68346 .34289 .6897 .33761 .68638 .32797 Metetra
.675 .571 .731 r
.68638 .32797 .6897 .33761 .69598 .33283 .6927 .32415 Metetra
.676 .588 .75 r
.6927 .32415 .69598 .33283 .70228 .32848 .69905 .32062 Metetra
.677 .605 .768 r
.69905 .32062 .70228 .32848 .70861 .3245 .70543 .31733 Metetra
.677 .622 .786 r
.70543 .31733 .70861 .3245 .71497 .32084 .71183 .31426 Metetra
.677 .639 .804 r
.71183 .31426 .71497 .32084 .72135 .31745 .71824 .31135 Metetra
.677 .654 .82 r
.71824 .31135 .72135 .31745 .72775 .31428 .72468 .30859 Metetra
.676 .668 .835 r
.72468 .30859 .72775 .31428 .73418 .31131 .73114 .30594 Metetra
.675 .681 .848 r
.73114 .30594 .73418 .31131 .74064 .30848 .73762 .30338 Metetra
.674 .692 .859 r
.73762 .30338 .74064 .30848 .74711 .30579 .74412 .3009 Metetra
.673 .701 .868 r
.74412 .3009 .74711 .30579 .7536 .30319 .75063 .29847 Metetra
.671 .709 .876 r
.75063 .29847 .7536 .30319 .76012 .30067 .75717 .29609 Metetra
.67 .716 .883 r
.75717 .29609 .76012 .30067 .76665 .29822 .76372 .29375 Metetra
.669 .721 .888 r
.76372 .29375 .76665 .29822 .7732 .29582 .77028 .29143 Metetra
.668 .725 .892 r
.77028 .29143 .7732 .29582 .77977 .29346 .77687 .28913 Metetra
.667 .729 .896 r
.77687 .28913 .77977 .29346 .78635 .29113 .78347 .28685 Metetra
.666 .731 .898 r
.78347 .28685 .78635 .29113 .79295 .28882 .79008 .28457 Metetra
.666 .734 .901 r
.79008 .28457 .79295 .28882 .79957 .28653 .79672 .28231 Metetra
.665 .735 .902 r
.79672 .28231 .79957 .28653 .80621 .28425 .80337 .28005 Metetra
.665 .737 .903 r
.80337 .28005 .80621 .28425 .81286 .28198 .81003 .27779 Metetra
.665 .738 .905 r
.81003 .27779 .81286 .28198 .81953 .27971 .81671 .27553 Metetra
.664 .739 .905 r
.81671 .27553 .81953 .27971 .82621 .27745 .82341 .27327 Metetra
.664 .739 .906 r
.82341 .27327 .82621 .27745 .83291 .27519 .83012 .271 Metetra
.664 .74 .906 r
.83012 .271 .83291 .27519 .83963 .27292 .83685 .26874 Metetra
.664 .74 .907 r
.83685 .26874 .83963 .27292 .84636 .27066 .84359 .26647 Metetra
.664 .74 .907 r
.84359 .26647 .84636 .27066 .85311 .26839 .85035 .2642 Metetra
.664 .741 .907 r
.85035 .2642 .85311 .26839 .85987 .26612 .85712 .26192 Metetra
.664 .741 .908 r
.25129 .46048 .25492 .46386 .26038 .46203 .25676 .45864 Metetra
.664 .741 .908 r
.25676 .45864 .26038 .46203 .26585 .46019 .26223 .4568 Metetra
.664 .741 .908 r
.26223 .4568 .26585 .46019 .27134 .45836 .26772 .45495 Metetra
.664 .741 .908 r
.26772 .45495 .27134 .45836 .27683 .45651 .27323 .4531 Metetra
.664 .741 .908 r
.27323 .4531 .27683 .45651 .28234 .45467 .27874 .45125 Metetra
.664 .741 .908 r
.27874 .45125 .28234 .45467 .28786 .45282 .28426 .44939 Metetra
.664 .741 .908 r
.28426 .44939 .28786 .45282 .29339 .45096 .2898 .44753 Metetra
.664 .741 .908 r
.2898 .44753 .29339 .45096 .29893 .44911 .29535 .44566 Metetra
.663 .741 .908 r
.29535 .44566 .29893 .44911 .30448 .44725 .30091 .4438 Metetra
.663 .741 .908 r
.30091 .4438 .30448 .44725 .31004 .44538 .30648 .44192 Metetra
.663 .741 .908 r
.30648 .44192 .31004 .44538 .31562 .44352 .31206 .44005 Metetra
.663 .741 .908 r
.31206 .44005 .31562 .44352 .32121 .44165 .31766 .43817 Metetra
.663 .741 .908 r
.31766 .43817 .32121 .44165 .32681 .43978 .32326 .43629 Metetra
.663 .74 .907 r
.32326 .43629 .32681 .43978 .33242 .43792 .32888 .43441 Metetra
.663 .74 .907 r
.32888 .43441 .33242 .43792 .33804 .43606 .33451 .43253 Metetra
.662 .739 .907 r
.33451 .43253 .33804 .43606 .34367 .43422 .34015 .43065 Metetra
.661 .737 .906 r
.34015 .43065 .34367 .43422 .34932 .43239 .34581 .42878 Metetra
.66 .735 .905 r
.34581 .42878 .34932 .43239 .35497 .43058 .35147 .42692 Metetra
.659 .732 .903 r
.35147 .42692 .35497 .43058 .36064 .42882 .35715 .42508 Metetra
.657 .727 .901 r
.35715 .42508 .36064 .42882 .36631 .42711 .36283 .42326 Metetra
.654 .72 .897 r
.36283 .42326 .36631 .42711 .37199 .42549 .36853 .42147 Metetra
.651 .711 .892 r
.36853 .42147 .37199 .42549 .37769 .42397 .37424 .41974 Metetra
.646 .698 .884 r
.37424 .41974 .37769 .42397 .38338 .42261 .37996 .41807 Metetra
.64 .681 .874 r
.37996 .41807 .38338 .42261 .38909 .42144 .38568 .41649 Metetra
.632 .66 .859 r
.38568 .41649 .38909 .42144 .3948 .42053 .39142 .41502 Metetra
.622 .634 .841 r
.39142 .41502 .3948 .42053 .40051 .41995 .39716 .4137 Metetra
.611 .603 .819 r
.39716 .4137 .40051 .41995 .40622 .41978 .40291 .41255 Metetra
.598 .569 .792 r
.40291 .41255 .40622 .41978 .41194 .42011 .40867 .41162 Metetra
.585 .534 .763 r
.40867 .41162 .41194 .42011 .41765 .42103 .41444 .41093 Metetra
.572 .499 .734 r
.41444 .41093 .41765 .42103 .42337 .42264 .42021 .41053 Metetra
.561 .467 .705 r
.42021 .41053 .42337 .42264 .42909 .42505 .42599 .41043 Metetra
.552 .439 .678 r
.42599 .41043 .42909 .42505 .43481 .42834 .43178 .41067 Metetra
.544 .415 .655 r
.43178 .41067 .43481 .42834 .44053 .43259 .43759 .41126 Metetra
.539 .396 .634 r
.43759 .41126 .44053 .43259 .44627 .43784 .4434 .41219 Metetra
.536 .381 .618 r
.4434 .41219 .44627 .43784 .45203 .44411 .44924 .41344 Metetra
.535 .37 .604 r
.44924 .41344 .45203 .44411 .45781 .45137 .45509 .41498 Metetra
.535 .362 .593 r
.45509 .41498 .45781 .45137 .46361 .45954 .46096 .41674 Metetra
.535 .356 .584 r
.46096 .41674 .46361 .45954 .46946 .46848 .46685 .41864 Metetra
.537 .352 .578 r
.46685 .41864 .46946 .46848 .47535 .47801 .47278 .42059 Metetra
.539 .349 .572 r
.47278 .42059 .47535 .47801 .48129 .48787 .47873 .42247 Metetra
.541 .347 .568 r
.47873 .42247 .48129 .48787 .48729 .49776 .48471 .42417 Metetra
.543 .347 .564 r
.48471 .42417 .48729 .49776 .49334 .50735 .49072 .42557 Metetra
.545 .346 .562 r
.49072 .42557 .49334 .50735 .49946 .51629 .49676 .42655 Metetra
.548 .346 .56 r
.49676 .42655 .49946 .51629 .50564 .52421 .50283 .42702 Metetra
.55 .347 .558 r
.50283 .42702 .50564 .52421 .51188 .53076 .50892 .42689 Metetra
.552 .347 .557 r
.50892 .42689 .51188 .53076 .51816 .53565 .51504 .42611 Metetra
.554 .348 .556 r
.51504 .42611 .51816 .53565 .52449 .53862 .52117 .42464 Metetra
.556 .349 .555 r
.52117 .42464 .52449 .53862 .53085 .53951 .52732 .42249 Metetra
.558 .35 .555 r
.52732 .42249 .53085 .53951 .53722 .53823 .53349 .41968 Metetra
.56 .351 .555 r
.53349 .41968 .53722 .53823 .5436 .5348 .53966 .41626 Metetra
.561 .353 .555 r
.53966 .41626 .5436 .5348 .54997 .5293 .54583 .4123 Metetra
.563 .354 .555 r
.54583 .4123 .54997 .5293 .55633 .52191 .55201 .40787 Metetra
.564 .356 .556 r
.55201 .40787 .55633 .52191 .56266 .51287 .55819 .40308 Metetra
.566 .357 .557 r
.55819 .40308 .56266 .51287 .56896 .50247 .56437 .39801 Metetra
.567 .359 .558 r
.56437 .39801 .56896 .50247 .57522 .491 .57055 .39276 Metetra
.569 .361 .559 r
.57055 .39276 .57522 .491 .58146 .4788 .57672 .38741 Metetra
.57 .364 .561 r
.57672 .38741 .58146 .4788 .58765 .46616 .5829 .38204 Metetra
.572 .366 .563 r
.5829 .38204 .58765 .46616 .59382 .45338 .58909 .37672 Metetra
.574 .369 .566 r
.58909 .37672 .59382 .45338 .59997 .44071 .59527 .37151 Metetra
.576 .373 .569 r
.59527 .37151 .59997 .44071 .60609 .42836 .60146 .36644 Metetra
.578 .377 .573 r
.60146 .36644 .60609 .42836 .6122 .41651 .60766 .36156 Metetra
.581 .382 .577 r
.60766 .36156 .6122 .41651 .61831 .40527 .61386 .35687 Metetra
.584 .388 .582 r
.61386 .35687 .61831 .40527 .62442 .39474 .62008 .3524 Metetra
.587 .395 .589 r
.62008 .3524 .62442 .39474 .63053 .38497 .62631 .34815 Metetra
.59 .403 .596 r
.62631 .34815 .63053 .38497 .63665 .37597 .63255 .34411 Metetra
.594 .412 .605 r
.63255 .34411 .63665 .37597 .64279 .36774 .63881 .34028 Metetra
.599 .423 .615 r
.63881 .34028 .64279 .36774 .64894 .36025 .64508 .33665 Metetra
.604 .436 .627 r
.64508 .33665 .64894 .36025 .65512 .35346 .65136 .33321 Metetra
.61 .451 .641 r
.65136 .33321 .65512 .35346 .66132 .34732 .65767 .32993 Metetra
.616 .467 .657 r
.65767 .32993 .66132 .34732 .66755 .34176 .66398 .32681 Metetra
.623 .486 .675 r
.66398 .32681 .66755 .34176 .6738 .33672 .67032 .32382 Metetra
.629 .507 .694 r
.67032 .32382 .6738 .33672 .68008 .33215 .67667 .32096 Metetra
.636 .529 .715 r
.67667 .32096 .68008 .33215 .68638 .32797 .68304 .3182 Metetra
.643 .552 .737 r
.68304 .3182 .68638 .32797 .6927 .32415 .68943 .31553 Metetra
.648 .575 .759 r
.68943 .31553 .6927 .32415 .69905 .32062 .69583 .31294 Metetra
.654 .598 .78 r
.69583 .31294 .69905 .32062 .70543 .31733 .70226 .31042 Metetra
.658 .62 .8 r
.70226 .31042 .70543 .31733 .71183 .31426 .70869 .30796 Metetra
.661 .64 .819 r
.70869 .30796 .71183 .31426 .71824 .31135 .71515 .30555 Metetra
.663 .659 .835 r
.71515 .30555 .71824 .31135 .72468 .30859 .72162 .30317 Metetra
.665 .674 .849 r
.72162 .30317 .72468 .30859 .73114 .30594 .72811 .30082 Metetra
.666 .688 .861 r
.72811 .30082 .73114 .30594 .73762 .30338 .73461 .2985 Metetra
.666 .699 .871 r
.73461 .2985 .73762 .30338 .74412 .3009 .74113 .2962 Metetra
.666 .708 .879 r
.74113 .2962 .74412 .3009 .75063 .29847 .74766 .29392 Metetra
.666 .716 .885 r
.74766 .29392 .75063 .29847 .75717 .29609 .75422 .29164 Metetra
.666 .721 .891 r
.75422 .29164 .75717 .29609 .76372 .29375 .76078 .28938 Metetra
.665 .726 .894 r
.76078 .28938 .76372 .29375 .77028 .29143 .76737 .28712 Metetra
.665 .73 .898 r
.76737 .28712 .77028 .29143 .77687 .28913 .77396 .28487 Metetra
.665 .732 .9 r
.77396 .28487 .77687 .28913 .78347 .28685 .78058 .28261 Metetra
.665 .735 .902 r
.78058 .28261 .78347 .28685 .79008 .28457 .78721 .28036 Metetra
.664 .736 .903 r
.78721 .28036 .79008 .28457 .79672 .28231 .79385 .27811 Metetra
.664 .737 .904 r
.79385 .27811 .79672 .28231 .80337 .28005 .80051 .27586 Metetra
.664 .738 .905 r
.80051 .27586 .80337 .28005 .81003 .27779 .80719 .2736 Metetra
.664 .739 .906 r
.80719 .2736 .81003 .27779 .81671 .27553 .81388 .27134 Metetra
.664 .74 .906 r
.81388 .27134 .81671 .27553 .82341 .27327 .82059 .26908 Metetra
.664 .74 .907 r
.82059 .26908 .82341 .27327 .83012 .271 .82731 .26682 Metetra
.664 .74 .907 r
.82731 .26682 .83012 .271 .83685 .26874 .83405 .26455 Metetra
.664 .741 .907 r
.83405 .26455 .83685 .26874 .84359 .26647 .84081 .26227 Metetra
.664 .741 .907 r
.84081 .26227 .84359 .26647 .85035 .2642 .84758 .25999 Metetra
.664 .741 .908 r
.84758 .25999 .85035 .2642 .85712 .26192 .85436 .25771 Metetra
.664 .741 .908 r
.24764 .45708 .25129 .46048 .25676 .45864 .25311 .45523 Metetra
.664 .741 .908 r
.25311 .45523 .25676 .45864 .26223 .4568 .2586 .45339 Metetra
.664 .741 .908 r
.2586 .45339 .26223 .4568 .26772 .45495 .2641 .45153 Metetra
.664 .741 .908 r
.2641 .45153 .26772 .45495 .27323 .4531 .2696 .44968 Metetra
.664 .741 .908 r
.2696 .44968 .27323 .4531 .27874 .45125 .27512 .44781 Metetra
.664 .741 .908 r
.27512 .44781 .27874 .45125 .28426 .44939 .28066 .44595 Metetra
.664 .741 .908 r
.28066 .44595 .28426 .44939 .2898 .44753 .2862 .44408 Metetra
.664 .741 .908 r
.2862 .44408 .2898 .44753 .29535 .44566 .29176 .44221 Metetra
.664 .741 .908 r
.29176 .44221 .29535 .44566 .30091 .4438 .29732 .44033 Metetra
.664 .741 .908 r
.29732 .44033 .30091 .4438 .30648 .44192 .3029 .43845 Metetra
.663 .741 .908 r
.3029 .43845 .30648 .44192 .31206 .44005 .30849 .43657 Metetra
.663 .741 .908 r
.30849 .43657 .31206 .44005 .31766 .43817 .31409 .43468 Metetra
.663 .741 .908 r
.31409 .43468 .31766 .43817 .32326 .43629 .31971 .43279 Metetra
.663 .741 .908 r
.31971 .43279 .32326 .43629 .32888 .43441 .32533 .4309 Metetra
.663 .74 .907 r
.32533 .4309 .32888 .43441 .33451 .43253 .33097 .429 Metetra
.663 .74 .907 r
.33097 .429 .33451 .43253 .34015 .43065 .33662 .42711 Metetra
.663 .739 .907 r
.33662 .42711 .34015 .43065 .34581 .42878 .34228 .42521 Metetra
.662 .738 .906 r
.34228 .42521 .34581 .42878 .35147 .42692 .34796 .42331 Metetra
.662 .736 .905 r
.34796 .42331 .35147 .42692 .35715 .42508 .35364 .42142 Metetra
.661 .734 .903 r
.35364 .42142 .35715 .42508 .36283 .42326 .35934 .41953 Metetra
.66 .73 .901 r
.35934 .41953 .36283 .42326 .36853 .42147 .36505 .41765 Metetra
.659 .725 .898 r
.36505 .41765 .36853 .42147 .37424 .41974 .37077 .41579 Metetra
.658 .717 .893 r
.37077 .41579 .37424 .41974 .37996 .41807 .3765 .41393 Metetra
.655 .708 .886 r
.3765 .41393 .37996 .41807 .38568 .41649 .38224 .4121 Metetra
.653 .695 .876 r
.38224 .4121 .38568 .41649 .39142 .41502 .388 .4103 Metetra
.65 .678 .863 r
.388 .4103 .39142 .41502 .39716 .4137 .39376 .40852 Metetra
.645 .657 .847 r
.39376 .40852 .39716 .4137 .40291 .41255 .39954 .40677 Metetra
.64 .633 .827 r
.39954 .40677 .40291 .41255 .40867 .41162 .40533 .40506 Metetra
.634 .606 .804 r
.40533 .40506 .40867 .41162 .41444 .41093 .41113 .40338 Metetra
.627 .577 .778 r
.41113 .40338 .41444 .41093 .42021 .41053 .41695 .40172 Metetra
.619 .547 .751 r
.41695 .40172 .42021 .41053 .42599 .41043 .42278 .40008 Metetra
.612 .519 .725 r
.42278 .40008 .42599 .41043 .43178 .41067 .42862 .39846 Metetra
.605 .493 .7 r
.42862 .39846 .43178 .41067 .43759 .41126 .43447 .39682 Metetra
.598 .471 .678 r
.43447 .39682 .43759 .41126 .4434 .41219 .44034 .39516 Metetra
.593 .451 .658 r
.44034 .39516 .4434 .41219 .44924 .41344 .44623 .39345 Metetra
.588 .435 .641 r
.44623 .39345 .44924 .41344 .45509 .41498 .45213 .39167 Metetra
.584 .421 .627 r
.45213 .39167 .45509 .41498 .46096 .41674 .45804 .38981 Metetra
.581 .41 .615 r
.45804 .38981 .46096 .41674 .46685 .41864 .46397 .38784 Metetra
.578 .401 .606 r
.46397 .38784 .46685 .41864 .47278 .42059 .46992 .38577 Metetra
.576 .394 .598 r
.46992 .38577 .47278 .42059 .47873 .42247 .47588 .3836 Metetra
.573 .388 .592 r
.47588 .3836 .47873 .42247 .48471 .42417 .48185 .38133 Metetra
.572 .383 .587 r
.48185 .38133 .48471 .42417 .49072 .42557 .48783 .37897 Metetra
.57 .379 .583 r
.48783 .37897 .49072 .42557 .49676 .42655 .49383 .37657 Metetra
.569 .375 .579 r
.49383 .37657 .49676 .42655 .50283 .42702 .49984 .37415 Metetra
.567 .373 .577 r
.49984 .37415 .50283 .42702 .50892 .42689 .50587 .37175 Metetra
.566 .371 .575 r
.50587 .37175 .50892 .42689 .51504 .42611 .5119 .36939 Metetra
.565 .369 .574 r
.5119 .36939 .51504 .42611 .52117 .42464 .51794 .36712 Metetra
.564 .368 .574 r
.51794 .36712 .52117 .42464 .52732 .42249 .524 .36496 Metetra
.563 .367 .574 r
.524 .36496 .52732 .42249 .53349 .41968 .53007 .36291 Metetra
.563 .367 .574 r
.53007 .36291 .53349 .41968 .53966 .41626 .53616 .36099 Metetra
.563 .368 .575 r
.53616 .36099 .53966 .41626 .54583 .4123 .54226 .35919 Metetra
.562 .369 .577 r
.54226 .35919 .54583 .4123 .55201 .40787 .54837 .35748 Metetra
.563 .371 .579 r
.54837 .35748 .55201 .40787 .55819 .40308 .5545 .35585 Metetra
.564 .373 .582 r
.5545 .35585 .55819 .40308 .56437 .39801 .56065 .35425 Metetra
.565 .377 .586 r
.56065 .35425 .56437 .39801 .57055 .39276 .56681 .35267 Metetra
.567 .382 .59 r
.56681 .35267 .57055 .39276 .57672 .38741 .57299 .35107 Metetra
.569 .387 .596 r
.57299 .35107 .57672 .38741 .5829 .38204 .57918 .34942 Metetra
.572 .395 .603 r
.57918 .34942 .5829 .38204 .58909 .37672 .58539 .34769 Metetra
.576 .404 .611 r
.58539 .34769 .58909 .37672 .59527 .37151 .59161 .34588 Metetra
.581 .414 .62 r
.59161 .34588 .59527 .37151 .60146 .36644 .59784 .34396 Metetra
.587 .427 .632 r
.59784 .34396 .60146 .36644 .60766 .36156 .60408 .34194 Metetra
.593 .442 .645 r
.60408 .34194 .60766 .36156 .61386 .35687 .61034 .33982 Metetra
.601 .459 .66 r
.61034 .33982 .61386 .35687 .62008 .3524 .61661 .3376 Metetra
.609 .478 .677 r
.61661 .3376 .62008 .3524 .62631 .34815 .62289 .3353 Metetra
.618 .5 .696 r
.62289 .3353 .62631 .34815 .63255 .34411 .62918 .33294 Metetra
.628 .523 .716 r
.62918 .33294 .63255 .34411 .63881 .34028 .63548 .33052 Metetra
.637 .548 .737 r
.63548 .33052 .63881 .34028 .64508 .33665 .64179 .32806 Metetra
.646 .573 .759 r
.64179 .32806 .64508 .33665 .65136 .33321 .64812 .32558 Metetra
.653 .598 .78 r
.64812 .32558 .65136 .33321 .65767 .32993 .65445 .32309 Metetra
.66 .622 .8 r
.65445 .32309 .65767 .32993 .66398 .32681 .66081 .3206 Metetra
.665 .644 .819 r
.66081 .3206 .66398 .32681 .67032 .32382 .66717 .31812 Metetra
.669 .663 .835 r
.66717 .31812 .67032 .32382 .67667 .32096 .67355 .31565 Metetra
.671 .68 .85 r
.67355 .31565 .67667 .32096 .68304 .3182 .67994 .3132 Metetra
.673 .694 .862 r
.67994 .3132 .68304 .3182 .68943 .31553 .68635 .31077 Metetra
.673 .705 .872 r
.68635 .31077 .68943 .31553 .69583 .31294 .69278 .30837 Metetra
.673 .715 .88 r
.69278 .30837 .69583 .31294 .70226 .31042 .69921 .30598 Metetra
.673 .722 .886 r
.69921 .30598 .70226 .31042 .70869 .30796 .70567 .30362 Metetra
.672 .727 .891 r
.70567 .30362 .70869 .30796 .71515 .30555 .71214 .30128 Metetra
.671 .731 .895 r
.71214 .30128 .71515 .30555 .72162 .30317 .71862 .29896 Metetra
.67 .734 .898 r
.71862 .29896 .72162 .30317 .72811 .30082 .72512 .29665 Metetra
.669 .736 .9 r
.72512 .29665 .72811 .30082 .73461 .2985 .73164 .29435 Metetra
.668 .738 .902 r
.73164 .29435 .73461 .2985 .74113 .2962 .73817 .29207 Metetra
.667 .739 .904 r
.73817 .29207 .74113 .2962 .74766 .29392 .74472 .28979 Metetra
.667 .74 .905 r
.74472 .28979 .74766 .29392 .75422 .29164 .75128 .28752 Metetra
.666 .74 .905 r
.75128 .28752 .75422 .29164 .76078 .28938 .75786 .28526 Metetra
.666 .741 .906 r
.75786 .28526 .76078 .28938 .76737 .28712 .76445 .283 Metetra
.665 .741 .907 r
.76445 .283 .76737 .28712 .77396 .28487 .77106 .28074 Metetra
.665 .741 .907 r
.77106 .28074 .77396 .28487 .78058 .28261 .77769 .27848 Metetra
.665 .741 .907 r
.77769 .27848 .78058 .28261 .78721 .28036 .78433 .27623 Metetra
.664 .741 .907 r
.78433 .27623 .78721 .28036 .79385 .27811 .79098 .27397 Metetra
.664 .741 .907 r
.79098 .27397 .79385 .27811 .80051 .27586 .79765 .2717 Metetra
.664 .741 .908 r
.79765 .2717 .80051 .27586 .80719 .2736 .80434 .26944 Metetra
.664 .741 .908 r
.80434 .26944 .80719 .2736 .81388 .27134 .81105 .26717 Metetra
.664 .741 .908 r
.81105 .26717 .81388 .27134 .82059 .26908 .81776 .2649 Metetra
.664 .741 .908 r
.81776 .2649 .82059 .26908 .82731 .26682 .8245 .26263 Metetra
.664 .741 .908 r
.8245 .26263 .82731 .26682 .83405 .26455 .83125 .26035 Metetra
.664 .741 .908 r
.83125 .26035 .83405 .26455 .84081 .26227 .83802 .25806 Metetra
.664 .741 .908 r
.83802 .25806 .84081 .26227 .84758 .25999 .8448 .25577 Metetra
.664 .741 .908 r
.8448 .25577 .84758 .25999 .85436 .25771 .8516 .25348 Metetra
.664 .741 .908 r
.24398 .45367 .24764 .45708 .25311 .45523 .24946 .45182 Metetra
.664 .741 .908 r
.24946 .45182 .25311 .45523 .2586 .45339 .25495 .44996 Metetra
.664 .741 .908 r
.25495 .44996 .2586 .45339 .2641 .45153 .26045 .4481 Metetra
.664 .741 .908 r
.26045 .4481 .2641 .45153 .2696 .44968 .26597 .44624 Metetra
.664 .741 .908 r
.26597 .44624 .2696 .44968 .27512 .44781 .2715 .44437 Metetra
.664 .741 .908 r
.2715 .44437 .27512 .44781 .28066 .44595 .27704 .4425 Metetra
.664 .741 .908 r
.27704 .4425 .28066 .44595 .2862 .44408 .28259 .44062 Metetra
.664 .741 .908 r
.28259 .44062 .2862 .44408 .29176 .44221 .28815 .43874 Metetra
.664 .741 .908 r
.28815 .43874 .29176 .44221 .29732 .44033 .29372 .43686 Metetra
.664 .741 .908 r
.29372 .43686 .29732 .44033 .3029 .43845 .29931 .43497 Metetra
.663 .741 .908 r
.29931 .43497 .3029 .43845 .30849 .43657 .30491 .43308 Metetra
.663 .741 .908 r
.30491 .43308 .30849 .43657 .31409 .43468 .31051 .43118 Metetra
.663 .741 .908 r
.31051 .43118 .31409 .43468 .31971 .43279 .31614 .42929 Metetra
.663 .741 .908 r
.31614 .42929 .31971 .43279 .32533 .4309 .32177 .42739 Metetra
.663 .741 .908 r
.32177 .42739 .32533 .4309 .33097 .429 .32741 .42549 Metetra
.663 .741 .908 r
.32741 .42549 .33097 .429 .33662 .42711 .33307 .42359 Metetra
.662 .741 .909 r
.33307 .42359 .33662 .42711 .34228 .42521 .33874 .42169 Metetra
.662 .742 .909 r
.33874 .42169 .34228 .42521 .34796 .42331 .34442 .41979 Metetra
.661 .742 .91 r
.34442 .41979 .34796 .42331 .35364 .42142 .35011 .41791 Metetra
.66 .742 .911 r
.35011 .41791 .35364 .42142 .35934 .41953 .35581 .41604 Metetra
.658 .743 .913 r
.35581 .41604 .35934 .41953 .36505 .41765 .36153 .41419 Metetra
.655 .745 .916 r
.36153 .41419 .36505 .41765 .37077 .41579 .36725 .41237 Metetra
.651 .747 .92 r
.36725 .41237 .37077 .41579 .3765 .41393 .37299 .41061 Metetra
.646 .752 .926 r
.37299 .41061 .3765 .41393 .38224 .4121 .37873 .40891 Metetra
.638 .758 .935 r
.37873 .40891 .38224 .4121 .388 .4103 .38449 .4073 Metetra
.625 .768 .948 r
.38449 .4073 .388 .4103 .39376 .40852 .39025 .40581 Metetra
.604 .781 .966 r
.39025 .40581 .39376 .40852 .39954 .40677 .39602 .40447 Metetra
.567 .799 .987 r
.39602 .40447 .39954 .40677 .40533 .40506 .4018 .40333 Metetra
.494 .814 1 r
.4018 .40333 .40533 .40506 .41113 .40338 .40758 .40243 Metetra
.337 .786 .955 r
.40758 .40243 .41113 .40338 .41695 .40172 .41337 .40182 Metetra
.045 .614 .722 r
.41337 .40182 .41695 .40172 .42278 .40008 .41917 .40156 Metetra
.265 0 0 r
.41917 .40156 .42278 .40008 .42862 .39846 .42497 .40169 Metetra
.44 0 .003 r
.42497 .40169 .42862 .39846 .43447 .39682 .43078 .40228 Metetra
.518 .102 .191 r
.43078 .40228 .43447 .39682 .44034 .39516 .4366 .40335 Metetra
.553 .187 .299 r
.4366 .40335 .44034 .39516 .44623 .39345 .44243 .40495 Metetra
.569 .236 .365 r
.44243 .40495 .44623 .39345 .45213 .39167 .44827 .40709 Metetra
.576 .267 .408 r
.44827 .40709 .45213 .39167 .45804 .38981 .45413 .40976 Metetra
.579 .286 .436 r
.45413 .40976 .45804 .38981 .46397 .38784 .46001 .41292 Metetra
.578 .299 .456 r
.46001 .41292 .46397 .38784 .46992 .38577 .46592 .41651 Metetra
.577 .306 .47 r
.46592 .41651 .46992 .38577 .47588 .3836 .47185 .42044 Metetra
.574 .311 .48 r
.47185 .42044 .47588 .3836 .48185 .38133 .47781 .42458 Metetra
.57 .313 .488 r
.47781 .42458 .48185 .38133 .48783 .37897 .48381 .42879 Metetra
.566 .314 .493 r
.48381 .42879 .48783 .37897 .49383 .37657 .48985 .43289 Metetra
.562 .314 .497 r
.48985 .43289 .49383 .37657 .49984 .37415 .49593 .43671 Metetra
.558 .313 .5 r
.49593 .43671 .49984 .37415 .50587 .37175 .50204 .44005 Metetra
.554 .311 .502 r
.50204 .44005 .50587 .37175 .5119 .36939 .50819 .44273 Metetra
.549 .309 .504 r
.50819 .44273 .5119 .36939 .51794 .36712 .51438 .44459 Metetra
.545 .306 .504 r
.51438 .44459 .51794 .36712 .524 .36496 .5206 .4455 Metetra
.54 .303 .505 r
.5206 .4455 .524 .36496 .53007 .36291 .52684 .44535 Metetra
.535 .3 .505 r
.52684 .44535 .53007 .36291 .53616 .36099 .5331 .44409 Metetra
.531 .296 .504 r
.5331 .44409 .53616 .36099 .54226 .35919 .53937 .44172 Metetra
.526 .292 .503 r
.53937 .44172 .54226 .35919 .54837 .35748 .54565 .43825 Metetra
.521 .287 .502 r
.54565 .43825 .54837 .35748 .5545 .35585 .55193 .43377 Metetra
.515 .282 .5 r
.55193 .43377 .5545 .35585 .56065 .35425 .55821 .42838 Metetra
.51 .277 .497 r
.55821 .42838 .56065 .35425 .56681 .35267 .56447 .42223 Metetra
.504 .271 .494 r
.56447 .42223 .56681 .35267 .57299 .35107 .57073 .41546 Metetra
.498 .264 .491 r
.57073 .41546 .57299 .35107 .57918 .34942 .57697 .40824 Metetra
.491 .257 .486 r
.57697 .40824 .57918 .34942 .58539 .34769 .58321 .40073 Metetra
.484 .248 .48 r
.58321 .40073 .58539 .34769 .59161 .34588 .58943 .39307 Metetra
.475 .238 .473 r
.58943 .39307 .59161 .34588 .59784 .34396 .59565 .38541 Metetra
.466 .226 .465 r
.59565 .38541 .59784 .34396 .60408 .34194 .60186 .37787 Metetra
.455 .211 .454 r
.60186 .37787 .60408 .34194 .61034 .33982 .60807 .37054 Metetra
.443 .194 .44 r
.60807 .37054 .61034 .33982 .61661 .3376 .61428 .36351 Metetra
.428 .172 .422 r
.61428 .36351 .61661 .3376 .62289 .3353 .6205 .35682 Metetra
.409 .144 .399 r
.6205 .35682 .62289 .3353 .62918 .33294 .62672 .35051 Metetra
.384 .109 .367 r
.62672 .35051 .62918 .33294 .63548 .33052 .63296 .3446 Metetra
.352 .061 .324 r
.63296 .3446 .63548 .33052 .64179 .32806 .63921 .3391 Metetra
.308 0 .263 r
.63921 .3391 .64179 .32806 .64812 .32558 .64548 .33398 Metetra
.245 0 .176 r
.64548 .33398 .64812 .32558 .65445 .32309 .65176 .32924 Metetra
.152 0 .047 r
.65176 .32924 .65445 .32309 .66081 .3206 .65806 .32484 Metetra
.014 0 0 r
.65806 .32484 .66081 .3206 .66717 .31812 .66438 .32077 Metetra
.66438 .32077 .66717 .31812 .67355 .31565 .67073 .31697 Metetra
.393 .825 .671 r
.67073 .31697 .67355 .31565 .67994 .3132 .67709 .31344 Metetra
.557 .934 .862 r
.67709 .31344 .67994 .3132 .68635 .31077 .68347 .31012 Metetra
.643 .95 .949 r
.68347 .31012 .68635 .31077 .69278 .30837 .68987 .30699 Metetra
.678 .923 .972 r
.68987 .30699 .69278 .30837 .69921 .30598 .6963 .30403 Metetra
.689 .887 .971 r
.6963 .30403 .69921 .30598 .70567 .30362 .70274 .3012 Metetra
.69 .855 .962 r
.70274 .3012 .70567 .30362 .71214 .30128 .7092 .29849 Metetra
.687 .829 .951 r
.7092 .29849 .71214 .30128 .71862 .29896 .71568 .29587 Metetra
.683 .808 .942 r
.71568 .29587 .71862 .29896 .72512 .29665 .72218 .29333 Metetra
.68 .792 .934 r
.72218 .29333 .72512 .29665 .73164 .29435 .7287 .29085 Metetra
.677 .78 .928 r
.7287 .29085 .73164 .29435 .73817 .29207 .73523 .28842 Metetra
.674 .771 .923 r
.73523 .28842 .73817 .29207 .74472 .28979 .74178 .28603 Metetra
.672 .764 .92 r
.74178 .28603 .74472 .28979 .75128 .28752 .74835 .28368 Metetra
.67 .758 .917 r
.74835 .28368 .75128 .28752 .75786 .28526 .75493 .28134 Metetra
.669 .754 .914 r
.75493 .28134 .75786 .28526 .76445 .283 .76154 .27902 Metetra
.668 .751 .913 r
.76154 .27902 .76445 .283 .77106 .28074 .76815 .27672 Metetra
.667 .749 .912 r
.76815 .27672 .77106 .28074 .77769 .27848 .77479 .27443 Metetra
.666 .747 .911 r
.77479 .27443 .77769 .27848 .78433 .27623 .78144 .27214 Metetra
.665 .745 .91 r
.78144 .27214 .78433 .27623 .79098 .27397 .7881 .26985 Metetra
.665 .744 .909 r
.7881 .26985 .79098 .27397 .79765 .2717 .79479 .26757 Metetra
.665 .744 .909 r
.79479 .26757 .79765 .2717 .80434 .26944 .80148 .26529 Metetra
.664 .743 .909 r
.80148 .26529 .80434 .26944 .81105 .26717 .8082 .26301 Metetra
.664 .743 .909 r
.8082 .26301 .81105 .26717 .81776 .2649 .81493 .26072 Metetra
.664 .742 .908 r
.81493 .26072 .81776 .2649 .8245 .26263 .82167 .25843 Metetra
.664 .742 .908 r
.82167 .25843 .8245 .26263 .83125 .26035 .82843 .25614 Metetra
.664 .742 .908 r
.82843 .25614 .83125 .26035 .83802 .25806 .83521 .25384 Metetra
.664 .742 .908 r
.83521 .25384 .83802 .25806 .8448 .25577 .842 .25154 Metetra
.664 .742 .908 r
.842 .25154 .8448 .25577 .8516 .25348 .84881 .24924 Metetra
.664 .741 .908 r
.2403 .45025 .24398 .45367 .24946 .45182 .24579 .44839 Metetra
.664 .741 .908 r
.24579 .44839 .24946 .45182 .25495 .44996 .25129 .44652 Metetra
.664 .741 .908 r
.25129 .44652 .25495 .44996 .26045 .4481 .2568 .44466 Metetra
.664 .741 .908 r
.2568 .44466 .26045 .4481 .26597 .44624 .26232 .44278 Metetra
.664 .741 .908 r
.26232 .44278 .26597 .44624 .2715 .44437 .26785 .44091 Metetra
.664 .741 .908 r
.26785 .44091 .2715 .44437 .27704 .4425 .2734 .43903 Metetra
.664 .741 .908 r
.2734 .43903 .27704 .4425 .28259 .44062 .27896 .43715 Metetra
.664 .741 .908 r
.27896 .43715 .28259 .44062 .28815 .43874 .28453 .43526 Metetra
.664 .741 .908 r
.28453 .43526 .28815 .43874 .29372 .43686 .29011 .43337 Metetra
.663 .741 .908 r
.29011 .43337 .29372 .43686 .29931 .43497 .2957 .43147 Metetra
.663 .741 .908 r
.2957 .43147 .29931 .43497 .30491 .43308 .30131 .42958 Metetra
.663 .741 .908 r
.30131 .42958 .30491 .43308 .31051 .43118 .30692 .42768 Metetra
.663 .741 .908 r
.30692 .42768 .31051 .43118 .31614 .42929 .31255 .42577 Metetra
.663 .741 .908 r
.31255 .42577 .31614 .42929 .32177 .42739 .31819 .42387 Metetra
.663 .742 .909 r
.31819 .42387 .32177 .42739 .32741 .42549 .32384 .42197 Metetra
.662 .742 .909 r
.32384 .42197 .32741 .42549 .33307 .42359 .32951 .42007 Metetra
.662 .742 .91 r
.32951 .42007 .33307 .42359 .33874 .42169 .33518 .41817 Metetra
.66 .742 .911 r
.33518 .41817 .33874 .42169 .34442 .41979 .34087 .41629 Metetra
.659 .743 .912 r
.34087 .41629 .34442 .41979 .35011 .41791 .34657 .41443 Metetra
.656 .745 .915 r
.34657 .41443 .35011 .41791 .35581 .41604 .35227 .41261 Metetra
.652 .747 .919 r
.35227 .41261 .35581 .41604 .36153 .41419 .35799 .41084 Metetra
.646 .75 .925 r
.35799 .41084 .36153 .41419 .36725 .41237 .36372 .40914 Metetra
.636 .755 .934 r
.36372 .40914 .36725 .41237 .37299 .41061 .36945 .40755 Metetra
.621 .762 .947 r
.36945 .40755 .37299 .41061 .37873 .40891 .37519 .40612 Metetra
.596 .773 .965 r
.37519 .40612 .37873 .40891 .38449 .4073 .38094 .40489 Metetra
.549 .785 .986 r
.38094 .40489 .38449 .4073 .39025 .40581 .38669 .40394 Metetra
.455 .787 .999 r
.38669 .40394 .39025 .40581 .39602 .40447 .39244 .40335 Metetra
.253 .729 .938 r
.39244 .40335 .39602 .40447 .4018 .40333 .39818 .40324 Metetra
.099 0 0 r
.39818 .40324 .4018 .40333 .40758 .40243 .40393 .40372 Metetra
.411 0 0 r
.40393 .40372 .40758 .40243 .41337 .40182 .40967 .40493 Metetra
.556 .081 .081 r
.40967 .40493 .41337 .40182 .41917 .40156 .41541 .40702 Metetra
.612 .206 .248 r
.41541 .40702 .41917 .40156 .42497 .40169 .42113 .41013 Metetra
.634 .274 .342 r
.42113 .41013 .42497 .40169 .43078 .40228 .42686 .41442 Metetra
.642 .313 .399 r
.42686 .41442 .43078 .40228 .4366 .40335 .43258 .42002 Metetra
.643 .335 .435 r
.43258 .42002 .4366 .40335 .44243 .40495 .43831 .42702 Metetra
.64 .349 .46 r
.43831 .42702 .44243 .40495 .44827 .40709 .44405 .43548 Metetra
.636 .356 .476 r
.44405 .43548 .44827 .40709 .45413 .40976 .4498 .4454 Metetra
.631 .359 .488 r
.4498 .4454 .45413 .40976 .46001 .41292 .45558 .4567 Metetra
.624 .36 .497 r
.45558 .4567 .46001 .41292 .46592 .41651 .4614 .4692 Metetra
.618 .359 .503 r
.4614 .4692 .46592 .41651 .47185 .42044 .46728 .48266 Metetra
.61 .356 .507 r
.46728 .48266 .47185 .42044 .47781 .42458 .47321 .49673 Metetra
.603 .353 .511 r
.47321 .49673 .47781 .42458 .48381 .42879 .47922 .51096 Metetra
.595 .348 .513 r
.47922 .51096 .48381 .42879 .48985 .43289 .4853 .52488 Metetra
.587 .343 .514 r
.4853 .52488 .48985 .43289 .49593 .43671 .49147 .53792 Metetra
.579 .338 .515 r
.49147 .53792 .49593 .43671 .50204 .44005 .49772 .54954 Metetra
.571 .332 .515 r
.49772 .54954 .50204 .44005 .50819 .44273 .50405 .5592 Metetra
.563 .326 .515 r
.50405 .5592 .50819 .44273 .51438 .44459 .51044 .56644 Metetra
.554 .32 .515 r
.51044 .56644 .51438 .44459 .5206 .4455 .5169 .5709 Metetra
.545 .313 .514 r
.5169 .5709 .5206 .4455 .52684 .44535 .52339 .57232 Metetra
.537 .306 .513 r
.52339 .57232 .52684 .44535 .5331 .44409 .52991 .57062 Metetra
.528 .299 .512 r
.52991 .57062 .5331 .44409 .53937 .44172 .53644 .56584 Metetra
.519 .292 .51 r
.53644 .56584 .53937 .44172 .54565 .43825 .54295 .55817 Metetra
.51 .284 .508 r
.54295 .55817 .54565 .43825 .55193 .43377 .54944 .5479 Metetra
.5 .276 .505 r
.54944 .5479 .55193 .43377 .55821 .42838 .55589 .53545 Metetra
.491 .268 .502 r
.55589 .53545 .55821 .42838 .56447 .42223 .5623 .52127 Metetra
.481 .259 .499 r
.5623 .52127 .56447 .42223 .57073 .41546 .56866 .50582 Metetra
.471 .249 .495 r
.56866 .50582 .57073 .41546 .57697 .40824 .57497 .4896 Metetra
.46 .238 .49 r
.57497 .4896 .57697 .40824 .58321 .40073 .58123 .47304 Metetra
.448 .227 .484 r
.58123 .47304 .58321 .40073 .58943 .39307 .58745 .45653 Metetra
.436 .214 .477 r
.58745 .45653 .58943 .39307 .59565 .38541 .59364 .44041 Metetra
.422 .2 .469 r
.59364 .44041 .59565 .38541 .60186 .37787 .5998 .42494 Metetra
.407 .183 .458 r
.5998 .42494 .60186 .37787 .60807 .37054 .60595 .41032 Metetra
.391 .163 .445 r
.60595 .41032 .60807 .37054 .61428 .36351 .61208 .39669 Metetra
.371 .139 .427 r
.61208 .39669 .61428 .36351 .6205 .35682 .61822 .38411 Metetra
.347 .11 .405 r
.61822 .38411 .6205 .35682 .62672 .35051 .62436 .37263 Metetra
.318 .073 .375 r
.62436 .37263 .62672 .35051 .63296 .3446 .63051 .36222 Metetra
.281 .024 .335 r
.63051 .36222 .63296 .3446 .63921 .3391 .63668 .35285 Metetra
.232 0 .279 r
.63668 .35285 .63921 .3391 .64548 .33398 .64288 .34445 Metetra
.164 0 .198 r
.64288 .34445 .64548 .33398 .65176 .32924 .6491 .33695 Metetra
.068 0 .08 r
.6491 .33695 .65176 .32924 .65806 .32484 .65534 .33025 Metetra
.65534 .33025 .65806 .32484 .66438 .32077 .66161 .32427 Metetra
.66161 .32427 .66438 .32077 .67073 .31697 .66791 .31892 Metetra
.463 .838 .6 r
.66791 .31892 .67073 .31697 .67709 .31344 .67423 .31412 Metetra
.621 .956 .808 r
.67423 .31412 .67709 .31344 .68347 .31012 .68059 .30978 Metetra
.699 .976 .915 r
.68059 .30978 .68347 .31012 .68987 .30699 .68697 .30583 Metetra
.724 .947 .953 r
.68697 .30583 .68987 .30699 .6963 .30403 .69337 .30222 Metetra
.724 .907 .959 r
.69337 .30222 .6963 .30403 .70274 .3012 .6998 .29887 Metetra
.717 .87 .954 r
.6998 .29887 .70274 .3012 .7092 .29849 .70625 .29575 Metetra
.708 .84 .946 r
.70625 .29575 .7092 .29849 .71568 .29587 .71273 .29282 Metetra
.699 .817 .938 r
.71273 .29282 .71568 .29587 .72218 .29333 .71923 .29003 Metetra
.692 .799 .931 r
.71923 .29003 .72218 .29333 .7287 .29085 .72574 .28735 Metetra
.686 .785 .926 r
.72574 .28735 .7287 .29085 .73523 .28842 .73228 .28477 Metetra
.681 .774 .921 r
.73228 .28477 .73523 .28842 .74178 .28603 .73883 .28226 Metetra
.677 .766 .918 r
.73883 .28226 .74178 .28603 .74835 .28368 .74541 .27981 Metetra
.674 .76 .916 r
.74541 .27981 .74835 .28368 .75493 .28134 .752 .27741 Metetra
.672 .755 .914 r
.752 .27741 .75493 .28134 .76154 .27902 .75861 .27503 Metetra
.67 .752 .912 r
.75861 .27503 .76154 .27902 .76815 .27672 .76524 .27268 Metetra
.668 .749 .911 r
.76524 .27268 .76815 .27672 .77479 .27443 .77188 .27035 Metetra
.667 .747 .91 r
.77188 .27035 .77479 .27443 .78144 .27214 .77854 .26803 Metetra
.666 .746 .91 r
.77854 .26803 .78144 .27214 .7881 .26985 .78521 .26572 Metetra
.666 .745 .909 r
.78521 .26572 .7881 .26985 .79479 .26757 .79191 .26342 Metetra
.665 .744 .909 r
.79191 .26342 .79479 .26757 .80148 .26529 .79861 .26112 Metetra
.665 .743 .909 r
.79861 .26112 .80148 .26529 .8082 .26301 .80534 .25882 Metetra
.664 .743 .908 r
.80534 .25882 .8082 .26301 .81493 .26072 .81208 .25652 Metetra
.664 .742 .908 r
.81208 .25652 .81493 .26072 .82167 .25843 .81884 .25422 Metetra
.664 .742 .908 r
.81884 .25422 .82167 .25843 .82843 .25614 .82561 .25191 Metetra
.664 .742 .908 r
.82561 .25191 .82843 .25614 .83521 .25384 .8324 .24961 Metetra
.664 .742 .908 r
.8324 .24961 .83521 .25384 .842 .25154 .8392 .24729 Metetra
.664 .742 .908 r
.8392 .24729 .842 .25154 .84881 .24924 .84602 .24498 Metetra
.664 .741 .908 r
.23661 .44681 .2403 .45025 .24579 .44839 .24211 .44494 Metetra
.664 .741 .908 r
.24211 .44494 .24579 .44839 .25129 .44652 .24761 .44307 Metetra
.664 .741 .908 r
.24761 .44307 .25129 .44652 .2568 .44466 .25313 .4412 Metetra
.664 .741 .908 r
.25313 .4412 .2568 .44466 .26232 .44278 .25866 .43932 Metetra
.664 .741 .908 r
.25866 .43932 .26232 .44278 .26785 .44091 .2642 .43744 Metetra
.664 .741 .908 r
.2642 .43744 .26785 .44091 .2734 .43903 .26975 .43555 Metetra
.664 .741 .908 r
.26975 .43555 .2734 .43903 .27896 .43715 .27532 .43366 Metetra
.664 .741 .908 r
.27532 .43366 .27896 .43715 .28453 .43526 .28089 .43176 Metetra
.664 .741 .908 r
.28089 .43176 .28453 .43526 .29011 .43337 .28648 .42987 Metetra
.663 .741 .908 r
.28648 .42987 .29011 .43337 .2957 .43147 .29208 .42796 Metetra
.663 .741 .908 r
.29208 .42796 .2957 .43147 .30131 .42958 .29769 .42606 Metetra
.663 .741 .908 r
.29769 .42606 .30131 .42958 .30692 .42768 .30332 .42415 Metetra
.663 .741 .908 r
.30332 .42415 .30692 .42768 .31255 .42577 .30895 .42224 Metetra
.663 .741 .908 r
.30895 .42224 .31255 .42577 .31819 .42387 .3146 .42033 Metetra
.663 .741 .908 r
.3146 .42033 .31819 .42387 .32384 .42197 .32026 .41842 Metetra
.662 .741 .908 r
.32026 .41842 .32384 .42197 .32951 .42007 .32593 .41651 Metetra
.661 .741 .909 r
.32593 .41651 .32951 .42007 .33518 .41817 .33161 .41461 Metetra
.66 .74 .909 r
.33161 .41461 .33518 .41817 .34087 .41629 .3373 .41272 Metetra
.659 .74 .91 r
.3373 .41272 .34087 .41629 .34657 .41443 .34301 .41086 Metetra
.656 .739 .911 r
.34301 .41086 .34657 .41443 .35227 .41261 .34872 .40902 Metetra
.652 .738 .912 r
.34872 .40902 .35227 .41261 .35799 .41084 .35445 .40724 Metetra
.647 .736 .915 r
.35445 .40724 .35799 .41084 .36372 .40914 .36018 .40554 Metetra
.638 .734 .918 r
.36018 .40554 .36372 .40914 .36945 .40755 .36593 .40394 Metetra
.627 .73 .922 r
.36593 .40394 .36945 .40755 .37519 .40612 .37167 .4025 Metetra
.61 .725 .927 r
.37167 .4025 .37519 .40612 .38094 .40489 .37743 .40126 Metetra
.586 .716 .933 r
.37743 .40126 .38094 .40489 .38669 .40394 .38318 .40031 Metetra
.551 .703 .94 r
.38318 .40031 .38669 .40394 .39244 .40335 .38894 .39972 Metetra
.501 .682 .947 r
.38894 .39972 .39244 .40335 .39818 .40324 .39469 .3996 Metetra
.427 .648 .951 r
.39469 .3996 .39818 .40324 .40393 .40372 .40044 .40007 Metetra
.321 .593 .943 r
.40044 .40007 .40393 .40372 .40967 .40493 .40619 .40128 Metetra
.17 .506 .911 r
.40619 .40128 .40967 .40493 .41541 .40702 .41192 .40336 Metetra
0 .377 .836 r
.41192 .40336 .41541 .40702 .42113 .41013 .41766 .40647 Metetra
0 .209 .708 r
.41766 .40647 .42113 .41013 .42686 .41442 .42338 .41076 Metetra
0 .031 .541 r
.42338 .41076 .42686 .41442 .43258 .42002 .4291 .41635 Metetra
.617 .124 0 r
.4291 .41635 .43258 .42002 .43831 .42702 .43483 .42336 Metetra
.724 .243 0 r
.43483 .42336 .43831 .42702 .44405 .43548 .44056 .43182 Metetra
.793 .327 0 r
.44056 .43182 .44405 .43548 .4498 .4454 .44631 .44174 Metetra
.834 .383 0 r
.44631 .44174 .4498 .4454 .45558 .4567 .45209 .45304 Metetra
.86 .42 .009 r
.45209 .45304 .45558 .4567 .4614 .4692 .4579 .46555 Metetra
.874 .443 .042 r
.4579 .46555 .4614 .4692 .46728 .48266 .46377 .47902 Metetra
.881 .454 .058 r
.46377 .47902 .46728 .48266 .47321 .49673 .46969 .49309 Metetra
.881 .454 .058 r
.46969 .49309 .47321 .49673 .47922 .51096 .47569 .50734 Metetra
.874 .442 .041 r
.47569 .50734 .47922 .51096 .4853 .52488 .48177 .52126 Metetra
.856 .415 .001 r
.48177 .52126 .4853 .52488 .49147 .53792 .48793 .53431 Metetra
.82 .363 0 r
.48793 .53431 .49147 .53792 .49772 .54954 .49417 .54593 Metetra
.745 .266 0 r
.49417 .54593 .49772 .54954 .50405 .5592 .5005 .5556 Metetra
.579 .081 0 r
.5005 .5556 .50405 .5592 .51044 .56644 .5069 .56284 Metetra
0 .244 .73 r
.5069 .56284 .51044 .56644 .5169 .5709 .51335 .5673 Metetra
.284 .593 .948 r
.51335 .5673 .5169 .5709 .52339 .57232 .51986 .56872 Metetra
.628 .756 .939 r
.51986 .56872 .52339 .57232 .52991 .57062 .52638 .56701 Metetra
.784 .795 .862 r
.52638 .56701 .52991 .57062 .53644 .56584 .53292 .56221 Metetra
.854 .797 .795 r
.53292 .56221 .53644 .56584 .54295 .55817 .53945 .55453 Metetra
.889 .792 .747 r
.53945 .55453 .54295 .55817 .54944 .5479 .54596 .54425 Metetra
.908 .785 .714 r
.54596 .54425 .54944 .5479 .55589 .53545 .55243 .53177 Metetra
.919 .78 .691 r
.55243 .53177 .55589 .53545 .5623 .52127 .55886 .51757 Metetra
.926 .776 .677 r
.55886 .51757 .5623 .52127 .56866 .50582 .56525 .5021 Metetra
.929 .774 .668 r
.56525 .5021 .56866 .50582 .57497 .4896 .57158 .48585 Metetra
.931 .773 .663 r
.57158 .48585 .57497 .4896 .58123 .47304 .57787 .46927 Metetra
.931 .773 .663 r
.57787 .46927 .58123 .47304 .58745 .45653 .58411 .45273 Metetra
.93 .774 .666 r
.58411 .45273 .58745 .45653 .59364 .44041 .59032 .43659 Metetra
.928 .775 .671 r
.59032 .43659 .59364 .44041 .5998 .42494 .59651 .4211 Metetra
.924 .777 .68 r
.59651 .4211 .5998 .42494 .60595 .41032 .60268 .40646 Metetra
.919 .779 .691 r
.60268 .40646 .60595 .41032 .61208 .39669 .60883 .39281 Metetra
.912 .782 .704 r
.60883 .39281 .61208 .39669 .61822 .38411 .61499 .38021 Metetra
.904 .784 .718 r
.61499 .38021 .61822 .38411 .62436 .37263 .62115 .36871 Metetra
.894 .786 .735 r
.62115 .36871 .62436 .37263 .63051 .36222 .62732 .35829 Metetra
.882 .788 .752 r
.62732 .35829 .63051 .36222 .63668 .35285 .63351 .3489 Metetra
.868 .789 .77 r
.63351 .3489 .63668 .35285 .64288 .34445 .63972 .34049 Metetra
.853 .789 .788 r
.63972 .34049 .64288 .34445 .6491 .33695 .64595 .33297 Metetra
.837 .788 .805 r
.64595 .33297 .6491 .33695 .65534 .33025 .65221 .32626 Metetra
.819 .786 .821 r
.65221 .32626 .65534 .33025 .66161 .32427 .65849 .32027 Metetra
.802 .783 .835 r
.65849 .32027 .66161 .32427 .66791 .31892 .6648 .31491 Metetra
.784 .779 .848 r
.6648 .31491 .66791 .31892 .67423 .31412 .67114 .3101 Metetra
.768 .775 .859 r
.67114 .3101 .67423 .31412 .68059 .30978 .6775 .30575 Metetra
.752 .771 .869 r
.6775 .30575 .68059 .30978 .68697 .30583 .6839 .30179 Metetra
.738 .767 .877 r
.6839 .30179 .68697 .30583 .69337 .30222 .69031 .29816 Metetra
.725 .763 .883 r
.69031 .29816 .69337 .30222 .6998 .29887 .69675 .29481 Metetra
.714 .76 .889 r
.69675 .29481 .6998 .29887 .70625 .29575 .70322 .29168 Metetra
.704 .757 .893 r
.70322 .29168 .70625 .29575 .71273 .29282 .7097 .28873 Metetra
.696 .754 .896 r
.7097 .28873 .71273 .29282 .71923 .29003 .71621 .28593 Metetra
.69 .751 .899 r
.71621 .28593 .71923 .29003 .72574 .28735 .72274 .28325 Metetra
.684 .749 .901 r
.72274 .28325 .72574 .28735 .73228 .28477 .72929 .28066 Metetra
.68 .748 .902 r
.72929 .28066 .73228 .28477 .73883 .28226 .73585 .27814 Metetra
.676 .746 .904 r
.73585 .27814 .73883 .28226 .74541 .27981 .74244 .27568 Metetra
.673 .745 .905 r
.74244 .27568 .74541 .27981 .752 .27741 .74904 .27326 Metetra
.671 .744 .905 r
.74904 .27326 .752 .27741 .75861 .27503 .75566 .27088 Metetra
.669 .744 .906 r
.75566 .27088 .75861 .27503 .76524 .27268 .7623 .26852 Metetra
.668 .743 .906 r
.7623 .26852 .76524 .27268 .77188 .27035 .76895 .26618 Metetra
.667 .743 .907 r
.76895 .26618 .77188 .27035 .77854 .26803 .77562 .26385 Metetra
.666 .742 .907 r
.77562 .26385 .77854 .26803 .78521 .26572 .78231 .26153 Metetra
.666 .742 .907 r
.78231 .26153 .78521 .26572 .79191 .26342 .78901 .25922 Metetra
.665 .742 .907 r
.78901 .25922 .79191 .26342 .79861 .26112 .79573 .25691 Metetra
.665 .742 .908 r
.79573 .25691 .79861 .26112 .80534 .25882 .80246 .2546 Metetra
.664 .742 .908 r
.80246 .2546 .80534 .25882 .81208 .25652 .80922 .25229 Metetra
.664 .742 .908 r
.80922 .25229 .81208 .25652 .81884 .25422 .81598 .24998 Metetra
.664 .742 .908 r
.81598 .24998 .81884 .25422 .82561 .25191 .82277 .24766 Metetra
.664 .741 .908 r
.82277 .24766 .82561 .25191 .8324 .24961 .82957 .24534 Metetra
.664 .741 .908 r
.82957 .24534 .8324 .24961 .8392 .24729 .83638 .24302 Metetra
.664 .741 .908 r
.83638 .24302 .8392 .24729 .84602 .24498 .84322 .2407 Metetra
.664 .741 .908 r
.23291 .44336 .23661 .44681 .24211 .44494 .23841 .44149 Metetra
.664 .741 .908 r
.23841 .44149 .24211 .44494 .24761 .44307 .24392 .43961 Metetra
.664 .741 .908 r
.24392 .43961 .24761 .44307 .25313 .4412 .24944 .43773 Metetra
.664 .741 .908 r
.24944 .43773 .25313 .4412 .25866 .43932 .25498 .43584 Metetra
.664 .741 .908 r
.25498 .43584 .25866 .43932 .2642 .43744 .26053 .43395 Metetra
.664 .741 .908 r
.26053 .43395 .2642 .43744 .26975 .43555 .26609 .43206 Metetra
.664 .741 .908 r
.26609 .43206 .26975 .43555 .27532 .43366 .27166 .43016 Metetra
.664 .741 .908 r
.27166 .43016 .27532 .43366 .28089 .43176 .27724 .42826 Metetra
.664 .741 .908 r
.27724 .42826 .28089 .43176 .28648 .42987 .28284 .42635 Metetra
.664 .741 .908 r
.28284 .42635 .28648 .42987 .29208 .42796 .28844 .42444 Metetra
.663 .741 .908 r
.28844 .42444 .29208 .42796 .29769 .42606 .29406 .42253 Metetra
.663 .741 .908 r
.29406 .42253 .29769 .42606 .30332 .42415 .29969 .42061 Metetra
.663 .741 .908 r
.29969 .42061 .30332 .42415 .30895 .42224 .30534 .41869 Metetra
.663 .741 .908 r
.30534 .41869 .30895 .42224 .3146 .42033 .31099 .41677 Metetra
.663 .741 .908 r
.31099 .41677 .3146 .42033 .32026 .41842 .31666 .41484 Metetra
.663 .74 .908 r
.31666 .41484 .32026 .41842 .32593 .41651 .32234 .41292 Metetra
.662 .74 .907 r
.32234 .41292 .32593 .41651 .33161 .41461 .32803 .411 Metetra
.662 .739 .907 r
.32803 .411 .33161 .41461 .3373 .41272 .33373 .40908 Metetra
.661 .737 .906 r
.33373 .40908 .3373 .41272 .34301 .41086 .33945 .40717 Metetra
.66 .735 .905 r
.33945 .40717 .34301 .41086 .34872 .40902 .34517 .40528 Metetra
.658 .731 .904 r
.34517 .40528 .34872 .40902 .35445 .40724 .35091 .40341 Metetra
.655 .726 .901 r
.35091 .40341 .35445 .40724 .36018 .40554 .35665 .40157 Metetra
.652 .718 .897 r
.35665 .40157 .36018 .40554 .36593 .40394 .36241 .39978 Metetra
.647 .707 .891 r
.36241 .39978 .36593 .40394 .37167 .4025 .36818 .39806 Metetra
.64 .691 .881 r
.36818 .39806 .37167 .4025 .37743 .40126 .37396 .39643 Metetra
.632 .67 .868 r
.37396 .39643 .37743 .40126 .38318 .40031 .37974 .39492 Metetra
.622 .642 .85 r
.37974 .39492 .38318 .40031 .38894 .39972 .38553 .39356 Metetra
.609 .609 .826 r
.38553 .39356 .38894 .39972 .39469 .3996 .39133 .39239 Metetra
.595 .571 .797 r
.39133 .39239 .39469 .3996 .40044 .40007 .39713 .39147 Metetra
.58 .53 .764 r
.39713 .39147 .40044 .40007 .40619 .40128 .40294 .39084 Metetra
.565 .491 .731 r
.40294 .39084 .40619 .40128 .41192 .40336 .40876 .39056 Metetra
.551 .454 .698 r
.40876 .39056 .41192 .40336 .41766 .40647 .41458 .39067 Metetra
.54 .423 .668 r
.41458 .39067 .41766 .40647 .42338 .41076 .4204 .39124 Metetra
.532 .397 .643 r
.4204 .39124 .42338 .41076 .4291 .41635 .42624 .3923 Metetra
.526 .377 .622 r
.42624 .3923 .4291 .41635 .43483 .42336 .43208 .39389 Metetra
.522 .361 .605 r
.43208 .39389 .43483 .42336 .44056 .43182 .43793 .39601 Metetra
.52 .35 .591 r
.43793 .39601 .44056 .43182 .44631 .44174 .4438 .39867 Metetra
.519 .342 .58 r
.4438 .39867 .44631 .44174 .45209 .45304 .44969 .40182 Metetra
.52 .336 .572 r
.44969 .40182 .45209 .45304 .4579 .46555 .4556 .4054 Metetra
.521 .333 .566 r
.4556 .4054 .4579 .46555 .46377 .47902 .46154 .40932 Metetra
.523 .331 .561 r
.46154 .40932 .46377 .47902 .46969 .49309 .46751 .41345 Metetra
.525 .329 .557 r
.46751 .41345 .46969 .49309 .47569 .50734 .47351 .41766 Metetra
.528 .329 .555 r
.47351 .41766 .47569 .50734 .48177 .52126 .47956 .42175 Metetra
.531 .33 .552 r
.47956 .42175 .48177 .52126 .48793 .53431 .48564 .42556 Metetra
.533 .33 .551 r
.48564 .42556 .48793 .53431 .49417 .54593 .49177 .42889 Metetra
.536 .332 .55 r
.49177 .42889 .49417 .54593 .5005 .5556 .49793 .43156 Metetra
.539 .333 .549 r
.49793 .43156 .5005 .5556 .5069 .56284 .50413 .4334 Metetra
.542 .335 .549 r
.50413 .4334 .5069 .56284 .51335 .5673 .51037 .43429 Metetra
.546 .337 .549 r
.51037 .43429 .51335 .5673 .51986 .56872 .51663 .43413 Metetra
.549 .34 .549 r
.51663 .43413 .51986 .56872 .52638 .56701 .52292 .43285 Metetra
.552 .342 .549 r
.52292 .43285 .52638 .56701 .53292 .56221 .52922 .43044 Metetra
.555 .345 .55 r
.52922 .43044 .53292 .56221 .53945 .55453 .53553 .42694 Metetra
.558 .348 .551 r
.53553 .42694 .53945 .55453 .54596 .54425 .54185 .42243 Metetra
.562 .351 .552 r
.54185 .42243 .54596 .54425 .55243 .53177 .54816 .41701 Metetra
.565 .354 .553 r
.54816 .41701 .55243 .53177 .55886 .51757 .55447 .41082 Metetra
.569 .358 .555 r
.55447 .41082 .55886 .51757 .56525 .5021 .56077 .40401 Metetra
.573 .362 .557 r
.56077 .40401 .56525 .5021 .57158 .48585 .56706 .39675 Metetra
.577 .367 .559 r
.56706 .39675 .57158 .48585 .57787 .46927 .57334 .38919 Metetra
.581 .372 .562 r
.57334 .38919 .57787 .46927 .58411 .45273 .57961 .3815 Metetra
.585 .377 .566 r
.57961 .3815 .58411 .45273 .59032 .43659 .58587 .3738 Metetra
.589 .384 .57 r
.58587 .3738 .59032 .43659 .59651 .4211 .59212 .36621 Metetra
.594 .391 .575 r
.59212 .36621 .59651 .4211 .60268 .40646 .59838 .35884 Metetra
.599 .399 .581 r
.59838 .35884 .60268 .40646 .60883 .39281 .60463 .35177 Metetra
.605 .408 .589 r
.60463 .35177 .60883 .39281 .61499 .38021 .61089 .34504 Metetra
.61 .418 .597 r
.61089 .34504 .61499 .38021 .62115 .36871 .61716 .3387 Metetra
.616 .43 .607 r
.61716 .3387 .62115 .36871 .62732 .35829 .62344 .33275 Metetra
.623 .444 .619 r
.62344 .33275 .62732 .35829 .63351 .3489 .62972 .32721 Metetra
.63 .459 .633 r
.62972 .32721 .63351 .3489 .63972 .34049 .63603 .32206 Metetra
.637 .476 .648 r
.63603 .32206 .63972 .34049 .64595 .33297 .64235 .31729 Metetra
.644 .496 .666 r
.64235 .31729 .64595 .33297 .65221 .32626 .64869 .31286 Metetra
.651 .517 .686 r
.64869 .31286 .65221 .32626 .65849 .32027 .65504 .30875 Metetra
.658 .539 .708 r
.65504 .30875 .65849 .32027 .6648 .31491 .66142 .30492 Metetra
.664 .562 .73 r
.66142 .30492 .6648 .31491 .67114 .3101 .66782 .30135 Metetra
.669 .586 .753 r
.66782 .30135 .67114 .3101 .6775 .30575 .67423 .29801 Metetra
.673 .609 .775 r
.67423 .29801 .6775 .30575 .6839 .30179 .68067 .29485 Metetra
.676 .631 .797 r
.68067 .29485 .6839 .30179 .69031 .29816 .68712 .29185 Metetra
.677 .651 .816 r
.68712 .29185 .69031 .29816 .69675 .29481 .6936 .289 Metetra
.678 .668 .834 r
.6936 .289 .69675 .29481 .70322 .29168 .70009 .28626 Metetra
.677 .683 .849 r
.70009 .28626 .70322 .29168 .7097 .28873 .7066 .28361 Metetra
.676 .696 .861 r
.7066 .28361 .7097 .28873 .71621 .28593 .71314 .28104 Metetra
.675 .706 .871 r
.71314 .28104 .71621 .28593 .72274 .28325 .71968 .27853 Metetra
.673 .714 .88 r
.71968 .27853 .72274 .28325 .72929 .28066 .72625 .27608 Metetra
.672 .721 .886 r
.72625 .27608 .72929 .28066 .73585 .27814 .73283 .27366 Metetra
.67 .726 .891 r
.73283 .27366 .73585 .27814 .74244 .27568 .73943 .27127 Metetra
.669 .73 .895 r
.73943 .27127 .74244 .27568 .74904 .27326 .74605 .26891 Metetra
.668 .733 .898 r
.74605 .26891 .74904 .27326 .75566 .27088 .75268 .26656 Metetra
.667 .735 .901 r
.75268 .26656 .75566 .27088 .7623 .26852 .75934 .26423 Metetra
.666 .737 .902 r
.75934 .26423 .7623 .26852 .76895 .26618 .766 .26191 Metetra
.666 .738 .904 r
.766 .26191 .76895 .26618 .77562 .26385 .77268 .25959 Metetra
.665 .739 .905 r
.77268 .25959 .77562 .26385 .78231 .26153 .77938 .25728 Metetra
.665 .739 .906 r
.77938 .25728 .78231 .26153 .78901 .25922 .7861 .25496 Metetra
.665 .74 .906 r
.7861 .25496 .78901 .25922 .79573 .25691 .79283 .25265 Metetra
.664 .74 .907 r
.79283 .25265 .79573 .25691 .80246 .2546 .79958 .25034 Metetra
.664 .741 .907 r
.79958 .25034 .80246 .2546 .80922 .25229 .80634 .24802 Metetra
.664 .741 .907 r
.80634 .24802 .80922 .25229 .81598 .24998 .81312 .2457 Metetra
.664 .741 .907 r
.81312 .2457 .81598 .24998 .82277 .24766 .81991 .24338 Metetra
.664 .741 .907 r
.81991 .24338 .82277 .24766 .82957 .24534 .82673 .24106 Metetra
.664 .741 .908 r
.82673 .24106 .82957 .24534 .83638 .24302 .83355 .23873 Metetra
.664 .741 .908 r
.83355 .23873 .83638 .24302 .84322 .2407 .8404 .23639 Metetra
.664 .741 .908 r
.22919 .4399 .23291 .44336 .23841 .44149 .23469 .43802 Metetra
.664 .741 .908 r
.23469 .43802 .23841 .44149 .24392 .43961 .24021 .43613 Metetra
.664 .741 .908 r
.24021 .43613 .24392 .43961 .24944 .43773 .24574 .43424 Metetra
.664 .741 .908 r
.24574 .43424 .24944 .43773 .25498 .43584 .25129 .43235 Metetra
.664 .741 .908 r
.25129 .43235 .25498 .43584 .26053 .43395 .25684 .43045 Metetra
.664 .741 .908 r
.25684 .43045 .26053 .43395 .26609 .43206 .26241 .42855 Metetra
.664 .741 .908 r
.26241 .42855 .26609 .43206 .27166 .43016 .26799 .42664 Metetra
.664 .741 .908 r
.26799 .42664 .27166 .43016 .27724 .42826 .27358 .42473 Metetra
.664 .741 .908 r
.27358 .42473 .27724 .42826 .28284 .42635 .27918 .42282 Metetra
.664 .741 .908 r
.27918 .42282 .28284 .42635 .28844 .42444 .28479 .4209 Metetra
.663 .741 .908 r
.28479 .4209 .28844 .42444 .29406 .42253 .29042 .41898 Metetra
.663 .741 .908 r
.29042 .41898 .29406 .42253 .29969 .42061 .29606 .41706 Metetra
.663 .741 .908 r
.29606 .41706 .29969 .42061 .30534 .41869 .30171 .41513 Metetra
.663 .741 .908 r
.30171 .41513 .30534 .41869 .31099 .41677 .30737 .4132 Metetra
.663 .741 .908 r
.30737 .4132 .31099 .41677 .31666 .41484 .31305 .41126 Metetra
.663 .741 .908 r
.31305 .41126 .31666 .41484 .32234 .41292 .31873 .40933 Metetra
.663 .741 .908 r
.31873 .40933 .32234 .41292 .32803 .411 .32443 .40739 Metetra
.662 .74 .908 r
.32443 .40739 .32803 .411 .33373 .40908 .33014 .40546 Metetra
.662 .74 .908 r
.33014 .40546 .33373 .40908 .33945 .40717 .33586 .40353 Metetra
.661 .739 .907 r
.33586 .40353 .33945 .40717 .34517 .40528 .3416 .4016 Metetra
.66 .737 .906 r
.3416 .4016 .34517 .40528 .35091 .40341 .34734 .39969 Metetra
.659 .734 .905 r
.34734 .39969 .35091 .40341 .35665 .40157 .3531 .39778 Metetra
.658 .731 .903 r
.3531 .39778 .35665 .40157 .36241 .39978 .35887 .39589 Metetra
.656 .725 .9 r
.35887 .39589 .36241 .39978 .36818 .39806 .36465 .39402 Metetra
.654 .717 .894 r
.36465 .39402 .36818 .39806 .37396 .39643 .37045 .39218 Metetra
.652 .705 .886 r
.37045 .39218 .37396 .39643 .37974 .39492 .37625 .39036 Metetra
.648 .69 .875 r
.37625 .39036 .37974 .39492 .38553 .39356 .38207 .38857 Metetra
.644 .669 .859 r
.38207 .38857 .38553 .39356 .39133 .39239 .38789 .38682 Metetra
.64 .644 .839 r
.38789 .38682 .39133 .39239 .39713 .39147 .39373 .3851 Metetra
.634 .614 .813 r
.39373 .3851 .39713 .39147 .40294 .39084 .39959 .38341 Metetra
.626 .582 .784 r
.39959 .38341 .40294 .39084 .40876 .39056 .40545 .38173 Metetra
.618 .548 .754 r
.40545 .38173 .40876 .39056 .41458 .39067 .41133 .38006 Metetra
.61 .516 .723 r
.41133 .38006 .41458 .39067 .4204 .39124 .41722 .37839 Metetra
.602 .487 .694 r
.41722 .37839 .4204 .39124 .42624 .3923 .42313 .37669 Metetra
.595 .461 .668 r
.42313 .37669 .42624 .3923 .43208 .39389 .42906 .37494 Metetra
.588 .439 .646 r
.42906 .37494 .43208 .39389 .43793 .39601 .435 .37312 Metetra
.583 .421 .628 r
.435 .37312 .43793 .39601 .4438 .39867 .44095 .37122 Metetra
.578 .406 .613 r
.44095 .37122 .4438 .39867 .44969 .40182 .44692 .36922 Metetra
.574 .394 .6 r
.44692 .36922 .44969 .40182 .4556 .4054 .45291 .36711 Metetra
.571 .385 .59 r
.45291 .36711 .4556 .4054 .46154 .40932 .45891 .36489 Metetra
.568 .377 .582 r
.45891 .36489 .46154 .40932 .46751 .41345 .46493 .36257 Metetra
.565 .37 .576 r
.46493 .36257 .46751 .41345 .47351 .41766 .47096 .36018 Metetra
.563 .365 .571 r
.47096 .36018 .47351 .41766 .47956 .42175 .477 .35773 Metetra
.561 .361 .567 r
.477 .35773 .47956 .42175 .48564 .42556 .48306 .35527 Metetra
.559 .358 .564 r
.48306 .35527 .48564 .42556 .49177 .42889 .48913 .35282 Metetra
.558 .355 .561 r
.48913 .35282 .49177 .42889 .49793 .43156 .49521 .35043 Metetra
.556 .352 .559 r
.49521 .35043 .49793 .43156 .50413 .4334 .5013 .34811 Metetra
.555 .351 .558 r
.5013 .34811 .50413 .4334 .51037 .43429 .5074 .3459 Metetra
.554 .349 .557 r
.5074 .3459 .51037 .43429 .51663 .43413 .51351 .34382 Metetra
.554 .348 .556 r
.51351 .34382 .51663 .43413 .52292 .43285 .51964 .34185 Metetra
.553 .348 .556 r
.51964 .34185 .52292 .43285 .52922 .43044 .52578 .34001 Metetra
.553 .348 .556 r
.52578 .34001 .52922 .43044 .53553 .42694 .53194 .33826 Metetra
.552 .348 .557 r
.53194 .33826 .53553 .42694 .54185 .42243 .53811 .33658 Metetra
.553 .349 .558 r
.53811 .33658 .54185 .42243 .54816 .41701 .5443 .33495 Metetra
.553 .35 .559 r
.5443 .33495 .54816 .41701 .55447 .41082 .55051 .33333 Metetra
.554 .351 .561 r
.55051 .33333 .55447 .41082 .56077 .40401 .55673 .33169 Metetra
.555 .354 .563 r
.55673 .33169 .56077 .40401 .56706 .39675 .56296 .32999 Metetra
.556 .357 .566 r
.56296 .32999 .56706 .39675 .57334 .38919 .56921 .32822 Metetra
.558 .36 .569 r
.56921 .32822 .57334 .38919 .57961 .3815 .57548 .32637 Metetra
.56 .365 .573 r
.57548 .32637 .57961 .3815 .58587 .3738 .58176 .32441 Metetra
.563 .37 .578 r
.58176 .32441 .58587 .3738 .59212 .36621 .58805 .32234 Metetra
.566 .377 .584 r
.58805 .32234 .59212 .36621 .59838 .35884 .59435 .32017 Metetra
.57 .384 .591 r
.59435 .32017 .59838 .35884 .60463 .35177 .60067 .31791 Metetra
.574 .394 .599 r
.60067 .31791 .60463 .35177 .61089 .34504 .607 .31557 Metetra
.58 .404 .609 r
.607 .31557 .61089 .34504 .61716 .3387 .61334 .31316 Metetra
.585 .417 .62 r
.61334 .31316 .61716 .3387 .62344 .33275 .61969 .31069 Metetra
.592 .431 .633 r
.61969 .31069 .62344 .33275 .62972 .32721 .62605 .30819 Metetra
.599 .448 .648 r
.62605 .30819 .62972 .32721 .63603 .32206 .63243 .30567 Metetra
.607 .467 .665 r
.63243 .30567 .63603 .32206 .64235 .31729 .63882 .30313 Metetra
.615 .487 .684 r
.63882 .30313 .64235 .31729 .64869 .31286 .64522 .30059 Metetra
.623 .51 .704 r
.64522 .30059 .64869 .31286 .65504 .30875 .65163 .29806 Metetra
.631 .533 .725 r
.65163 .29806 .65504 .30875 .66142 .30492 .65806 .29554 Metetra
.639 .558 .747 r
.65806 .29554 .66142 .30492 .66782 .30135 .66451 .29305 Metetra
.646 .582 .769 r
.66451 .29305 .66782 .30135 .67423 .29801 .67097 .29057 Metetra
.652 .606 .79 r
.67097 .29057 .67423 .29801 .68067 .29485 .67744 .28812 Metetra
.656 .628 .81 r
.67744 .28812 .68067 .29485 .68712 .29185 .68393 .28569 Metetra
.66 .648 .827 r
.68393 .28569 .68712 .29185 .6936 .289 .69044 .28328 Metetra
.663 .666 .843 r
.69044 .28328 .6936 .289 .70009 .28626 .69696 .28089 Metetra
.665 .681 .856 r
.69696 .28089 .70009 .28626 .7066 .28361 .7035 .27852 Metetra
.666 .694 .867 r
.7035 .27852 .7066 .28361 .71314 .28104 .71005 .27616 Metetra
.666 .704 .876 r
.71005 .27616 .71314 .28104 .71968 .27853 .71662 .27382 Metetra
.666 .713 .883 r
.71662 .27382 .71968 .27853 .72625 .27608 .7232 .27149 Metetra
.666 .719 .888 r
.7232 .27149 .72625 .27608 .73283 .27366 .7298 .26917 Metetra
.666 .724 .893 r
.7298 .26917 .73283 .27366 .73943 .27127 .73642 .26685 Metetra
.666 .729 .896 r
.73642 .26685 .73943 .27127 .74605 .26891 .74305 .26454 Metetra
.665 .732 .899 r
.74305 .26454 .74605 .26891 .75268 .26656 .7497 .26223 Metetra
.665 .734 .901 r
.7497 .26223 .75268 .26656 .75934 .26423 .75636 .25992 Metetra
.665 .736 .903 r
.75636 .25992 .75934 .26423 .766 .26191 .76304 .25762 Metetra
.665 .737 .904 r
.76304 .25762 .766 .26191 .77268 .25959 .76974 .25531 Metetra
.664 .738 .905 r
.76974 .25531 .77268 .25959 .77938 .25728 .77645 .253 Metetra
.664 .739 .906 r
.77645 .253 .77938 .25728 .7861 .25496 .78318 .25069 Metetra
.664 .74 .906 r
.78318 .25069 .7861 .25496 .79283 .25265 .78992 .24838 Metetra
.664 .74 .907 r
.78992 .24838 .79283 .25265 .79958 .25034 .79668 .24606 Metetra
.664 .74 .907 r
.79668 .24606 .79958 .25034 .80634 .24802 .80345 .24374 Metetra
.664 .741 .907 r
.80345 .24374 .80634 .24802 .81312 .2457 .81024 .24142 Metetra
.664 .741 .907 r
.81024 .24142 .81312 .2457 .81991 .24338 .81705 .23909 Metetra
.664 .741 .908 r
.81705 .23909 .81991 .24338 .82673 .24106 .82387 .23675 Metetra
.664 .741 .908 r
.82387 .23675 .82673 .24106 .83355 .23873 .83071 .23441 Metetra
.664 .741 .908 r
.83071 .23441 .83355 .23873 .8404 .23639 .83757 .23207 Metetra
.664 .741 .908 r
.22545 .43642 .22919 .4399 .23469 .43802 .23097 .43453 Metetra
.664 .741 .908 r
.23097 .43453 .23469 .43802 .24021 .43613 .23649 .43264 Metetra
.664 .741 .908 r
.23649 .43264 .24021 .43613 .24574 .43424 .24203 .43074 Metetra
.664 .741 .908 r
.24203 .43074 .24574 .43424 .25129 .43235 .24758 .42884 Metetra
.664 .741 .908 r
.24758 .42884 .25129 .43235 .25684 .43045 .25314 .42694 Metetra
.664 .741 .908 r
.25314 .42694 .25684 .43045 .26241 .42855 .25872 .42503 Metetra
.664 .741 .908 r
.25872 .42503 .26241 .42855 .26799 .42664 .2643 .42311 Metetra
.664 .741 .908 r
.2643 .42311 .26799 .42664 .27358 .42473 .2699 .4212 Metetra
.663 .741 .908 r
.2699 .4212 .27358 .42473 .27918 .42282 .27551 .41928 Metetra
.663 .741 .908 r
.27551 .41928 .27918 .42282 .28479 .4209 .28113 .41735 Metetra
.663 .741 .908 r
.28113 .41735 .28479 .4209 .29042 .41898 .28676 .41543 Metetra
.663 .741 .908 r
.28676 .41543 .29042 .41898 .29606 .41706 .29241 .4135 Metetra
.663 .742 .908 r
.29241 .4135 .29606 .41706 .30171 .41513 .29807 .41156 Metetra
.663 .742 .909 r
.29807 .41156 .30171 .41513 .30737 .4132 .30374 .40963 Metetra
.663 .742 .909 r
.30374 .40963 .30737 .4132 .31305 .41126 .30942 .4077 Metetra
.662 .742 .909 r
.30942 .4077 .31305 .41126 .31873 .40933 .31511 .40577 Metetra
.662 .743 .91 r
.31511 .40577 .31873 .40933 .32443 .40739 .32081 .40384 Metetra
.661 .744 .911 r
.32081 .40384 .32443 .40739 .33014 .40546 .32653 .40193 Metetra
.659 .745 .913 r
.32653 .40193 .33014 .40546 .33586 .40353 .33226 .40003 Metetra
.657 .747 .916 r
.33226 .40003 .33586 .40353 .3416 .4016 .338 .39816 Metetra
.654 .749 .92 r
.338 .39816 .3416 .4016 .34734 .39969 .34375 .39632 Metetra
.65 .754 .925 r
.34375 .39632 .34734 .39969 .3531 .39778 .34951 .39453 Metetra
.644 .76 .933 r
.34951 .39453 .3531 .39778 .35887 .39589 .35527 .39281 Metetra
.635 .768 .944 r
.35527 .39281 .35887 .39589 .36465 .39402 .36105 .39118 Metetra
.621 .781 .958 r
.36105 .39118 .36465 .39402 .37045 .39218 .36684 .38966 Metetra
.598 .797 .976 r
.36684 .38966 .37045 .39218 .37625 .39036 .37263 .38829 Metetra
.557 .816 .994 r
.37263 .38829 .37625 .39036 .38207 .38857 .37843 .38709 Metetra
.478 .826 .997 r
.37843 .38709 .38207 .38857 .38789 .38682 .38423 .38611 Metetra
.321 .788 .934 r
.38423 .38611 .38789 .38682 .39373 .3851 .39005 .38537 Metetra
.058 .623 .709 r
.39005 .38537 .39373 .3851 .39959 .38341 .39586 .38492 Metetra
.214 0 0 r
.39586 .38492 .39959 .38341 .40545 .38173 .40169 .38478 Metetra
.386 0 0 r
.40169 .38478 .40545 .38173 .41133 .38006 .40752 .38498 Metetra
.473 .037 .128 r
.40752 .38498 .41133 .38006 .41722 .37839 .41336 .38552 Metetra
.516 .128 .244 r
.41336 .38552 .41722 .37839 .42313 .37669 .41921 .38642 Metetra
.538 .185 .317 r
.41921 .38642 .42313 .37669 .42906 .37494 .42507 .38763 Metetra
.549 .221 .366 r
.42507 .38763 .42906 .37494 .435 .37312 .43095 .38913 Metetra
.553 .245 .399 r
.43095 .38913 .435 .37312 .44095 .37122 .43685 .39086 Metetra
.555 .26 .422 r
.43685 .39086 .44095 .37122 .44692 .36922 .44278 .39273 Metetra
.554 .27 .439 r
.44278 .39273 .44692 .36922 .45291 .36711 .44873 .39464 Metetra
.552 .276 .451 r
.44873 .39464 .45291 .36711 .45891 .36489 .45471 .39649 Metetra
.548 .28 .46 r
.45471 .39649 .45891 .36489 .46493 .36257 .46072 .39816 Metetra
.545 .281 .467 r
.46072 .39816 .46493 .36257 .47096 .36018 .46677 .39952 Metetra
.541 .282 .472 r
.46677 .39952 .47096 .36018 .477 .35773 .47285 .40046 Metetra
.536 .281 .475 r
.47285 .40046 .477 .35773 .48306 .35527 .47896 .40089 Metetra
.532 .279 .478 r
.47896 .40089 .48306 .35527 .48913 .35282 .4851 .40071 Metetra
.527 .277 .479 r
.4851 .40071 .48913 .35282 .49521 .35043 .49127 .39988 Metetra
.522 .274 .48 r
.49127 .39988 .49521 .35043 .5013 .34811 .49746 .39836 Metetra
.517 .27 .479 r
.49746 .39836 .5013 .34811 .5074 .3459 .50368 .39615 Metetra
.512 .266 .478 r
.50368 .39615 .5074 .3459 .51351 .34382 .50991 .39327 Metetra
.507 .261 .477 r
.50991 .39327 .51351 .34382 .51964 .34185 .51616 .38978 Metetra
.501 .255 .474 r
.51616 .38978 .51964 .34185 .52578 .34001 .52241 .38575 Metetra
.495 .249 .47 r
.52241 .38575 .52578 .34001 .53194 .33826 .52867 .38125 Metetra
.488 .241 .466 r
.52867 .38125 .53194 .33826 .53811 .33658 .53493 .37637 Metetra
.481 .232 .46 r
.53493 .37637 .53811 .33658 .5443 .33495 .5412 .37123 Metetra
.473 .222 .452 r
.5412 .37123 .5443 .33495 .55051 .33333 .54746 .36589 Metetra
.463 .209 .442 r
.54746 .36589 .55051 .33333 .55673 .33169 .55373 .36046 Metetra
.451 .193 .43 r
.55373 .36046 .55673 .33169 .56296 .32999 .56 .35501 Metetra
.437 .173 .414 r
.56 .35501 .56296 .32999 .56921 .32822 .56627 .34961 Metetra
.42 .148 .393 r
.56627 .34961 .56921 .32822 .57548 .32637 .57254 .34432 Metetra
.398 .116 .365 r
.57254 .34432 .57548 .32637 .58176 .32441 .57882 .33917 Metetra
.368 .073 .327 r
.57882 .33917 .58176 .32441 .58805 .32234 .5851 .33421 Metetra
.328 .016 .274 r
.5851 .33421 .58805 .32234 .59435 .32017 .59139 .32945 Metetra
.272 0 .198 r
.59139 .32945 .59435 .32017 .60067 .31791 .59769 .3249 Metetra
.188 0 .085 r
.59769 .3249 .60067 .31791 .607 .31557 .604 .32057 Metetra
.063 0 0 r
.604 .32057 .607 .31557 .61334 .31316 .61033 .31646 Metetra
.61033 .31646 .61334 .31316 .61969 .31069 .61666 .31256 Metetra
.61666 .31256 .61969 .31069 .62605 .30819 .62301 .30886 Metetra
.529 .919 .813 r
.62301 .30886 .62605 .30819 .63243 .30567 .62937 .30534 Metetra
.641 .958 .928 r
.62937 .30534 .63243 .30567 .63882 .30313 .63575 .30199 Metetra
.688 .938 .965 r
.63575 .30199 .63882 .30313 .64522 .30059 .64215 .2988 Metetra
.702 .901 .967 r
.64215 .2988 .64522 .30059 .65163 .29806 .64856 .29575 Metetra
.704 .866 .959 r
.64856 .29575 .65163 .29806 .65806 .29554 .65498 .29281 Metetra
.7 .837 .948 r
.65498 .29281 .65806 .29554 .66451 .29305 .66143 .28999 Metetra
.695 .815 .939 r
.66143 .28999 .66451 .29305 .67097 .29057 .66789 .28726 Metetra
.69 .797 .931 r
.66789 .28726 .67097 .29057 .67744 .28812 .67437 .2846 Metetra
.686 .784 .925 r
.67437 .2846 .67744 .28812 .68393 .28569 .68086 .28201 Metetra
.682 .773 .92 r
.68086 .28201 .68393 .28569 .69044 .28328 .68737 .27948 Metetra
.679 .766 .917 r
.68737 .27948 .69044 .28328 .69696 .28089 .6939 .277 Metetra
.676 .76 .914 r
.6939 .277 .69696 .28089 .7035 .27852 .70044 .27456 Metetra
.674 .755 .912 r
.70044 .27456 .7035 .27852 .71005 .27616 .70701 .27214 Metetra
.672 .752 .911 r
.70701 .27214 .71005 .27616 .71662 .27382 .71358 .26976 Metetra
.67 .749 .91 r
.71358 .26976 .71662 .27382 .7232 .27149 .72018 .26739 Metetra
.669 .747 .909 r
.72018 .26739 .7232 .27149 .7298 .26917 .72679 .26504 Metetra
.668 .746 .909 r
.72679 .26504 .7298 .26917 .73642 .26685 .73341 .2627 Metetra
.667 .745 .908 r
.73341 .2627 .73642 .26685 .74305 .26454 .74005 .26037 Metetra
.666 .744 .908 r
.74005 .26037 .74305 .26454 .7497 .26223 .74671 .25804 Metetra
.666 .743 .908 r
.74671 .25804 .7497 .26223 .75636 .25992 .75339 .25572 Metetra
.665 .743 .908 r
.75339 .25572 .75636 .25992 .76304 .25762 .76008 .2534 Metetra
.665 .742 .908 r
.76008 .2534 .76304 .25762 .76974 .25531 .76678 .25108 Metetra
.665 .742 .908 r
.76678 .25108 .76974 .25531 .77645 .253 .7735 .24876 Metetra
.664 .742 .908 r
.7735 .24876 .77645 .253 .78318 .25069 .78024 .24644 Metetra
.664 .742 .908 r
.78024 .24644 .78318 .25069 .78992 .24838 .787 .24411 Metetra
.664 .742 .908 r
.787 .24411 .78992 .24838 .79668 .24606 .79377 .24179 Metetra
.664 .742 .908 r
.79377 .24179 .79668 .24606 .80345 .24374 .80055 .23945 Metetra
.664 .742 .908 r
.80055 .23945 .80345 .24374 .81024 .24142 .80735 .23712 Metetra
.664 .741 .908 r
.80735 .23712 .81024 .24142 .81705 .23909 .81417 .23478 Metetra
.664 .741 .908 r
.81417 .23478 .81705 .23909 .82387 .23675 .82101 .23244 Metetra
.664 .741 .908 r
.82101 .23244 .82387 .23675 .83071 .23441 .82786 .23009 Metetra
.664 .741 .908 r
.82786 .23009 .83071 .23441 .83757 .23207 .83472 .22773 Metetra
.664 .741 .908 r
.2217 .43293 .22545 .43642 .23097 .43453 .22723 .43103 Metetra
.664 .741 .908 r
.22723 .43103 .23097 .43453 .23649 .43264 .23276 .42913 Metetra
.664 .741 .908 r
.23276 .42913 .23649 .43264 .24203 .43074 .2383 .42723 Metetra
.664 .741 .908 r
.2383 .42723 .24203 .43074 .24758 .42884 .24386 .42532 Metetra
.664 .741 .908 r
.24386 .42532 .24758 .42884 .25314 .42694 .24943 .42341 Metetra
.664 .741 .908 r
.24943 .42341 .25314 .42694 .25872 .42503 .25501 .42149 Metetra
.664 .741 .908 r
.25501 .42149 .25872 .42503 .2643 .42311 .2606 .41957 Metetra
.663 .741 .908 r
.2606 .41957 .2643 .42311 .2699 .4212 .26621 .41765 Metetra
.663 .741 .908 r
.26621 .41765 .2699 .4212 .27551 .41928 .27182 .41572 Metetra
.663 .741 .908 r
.27182 .41572 .27551 .41928 .28113 .41735 .27745 .41379 Metetra
.663 .741 .908 r
.27745 .41379 .28113 .41735 .28676 .41543 .28309 .41186 Metetra
.663 .742 .908 r
.28309 .41186 .28676 .41543 .29241 .4135 .28874 .40992 Metetra
.663 .742 .909 r
.28874 .40992 .29241 .4135 .29807 .41156 .29441 .40799 Metetra
.662 .742 .909 r
.29441 .40799 .29807 .41156 .30374 .40963 .30008 .40606 Metetra
.662 .742 .91 r
.30008 .40606 .30374 .40963 .30942 .4077 .30577 .40413 Metetra
.661 .743 .911 r
.30577 .40413 .30942 .4077 .31511 .40577 .31147 .40222 Metetra
.659 .744 .913 r
.31147 .40222 .31511 .40577 .32081 .40384 .31718 .40032 Metetra
.657 .745 .915 r
.31718 .40032 .32081 .40384 .32653 .40193 .3229 .39845 Metetra
.654 .747 .918 r
.3229 .39845 .32653 .40193 .33226 .40003 .32863 .39662 Metetra
.649 .75 .923 r
.32863 .39662 .33226 .40003 .338 .39816 .33437 .39484 Metetra
.642 .755 .931 r
.33437 .39484 .338 .39816 .34375 .39632 .34012 .39315 Metetra
.632 .762 .941 r
.34012 .39315 .34375 .39632 .34951 .39453 .34588 .39157 Metetra
.615 .771 .955 r
.34588 .39157 .34951 .39453 .35527 .39281 .35164 .39014 Metetra
.588 .783 .973 r
.35164 .39014 .35527 .39281 .36105 .39118 .3574 .38891 Metetra
.538 .795 .992 r
.3574 .38891 .36105 .39118 .36684 .38966 .36317 .38794 Metetra
.443 .795 .997 r
.36317 .38794 .36684 .38966 .37263 .38829 .36894 .3873 Metetra
.251 .735 .928 r
.36894 .3873 .37263 .38829 .37843 .38709 .3747 .38707 Metetra
.062 0 0 r
.3747 .38707 .37843 .38709 .38423 .38611 .38046 .38734 Metetra
.353 0 0 r
.38046 .38734 .38423 .38611 .39005 .38537 .38622 .38821 Metetra
.509 .014 .016 r
.38622 .38821 .39005 .38537 .39586 .38492 .39197 .38978 Metetra
.577 .15 .193 r
.39197 .38978 .39586 .38492 .40169 .38478 .39772 .39216 Metetra
.607 .228 .298 r
.39772 .39216 .40169 .38478 .40752 .38498 .40346 .39542 Metetra
.62 .275 .363 r
.40346 .39542 .40752 .38498 .41336 .38552 .4092 .39964 Metetra
.624 .303 .406 r
.4092 .39964 .41336 .38552 .41921 .38642 .41494 .40488 Metetra
.624 .32 .435 r
.41494 .40488 .41921 .38642 .42507 .38763 .42068 .41115 Metetra
.621 .331 .455 r
.42068 .41115 .42507 .38763 .43095 .38913 .42644 .41841 Metetra
.617 .337 .47 r
.42644 .41841 .43095 .38913 .43685 .39086 .43223 .42659 Metetra
.611 .339 .48 r
.43223 .42659 .43685 .39086 .44278 .39273 .43804 .43555 Metetra
.605 .34 .488 r
.43804 .43555 .44278 .39273 .44873 .39464 .44389 .4451 Metetra
.598 .338 .494 r
.44389 .4451 .44873 .39464 .45471 .39649 .44979 .45499 Metetra
.591 .336 .498 r
.44979 .45499 .45471 .39649 .46072 .39816 .45575 .46492 Metetra
.584 .333 .501 r
.45575 .46492 .46072 .39816 .46677 .39952 .46178 .47454 Metetra
.577 .329 .504 r
.46178 .47454 .46677 .39952 .47285 .40046 .46788 .4835 Metetra
.569 .324 .505 r
.46788 .4835 .47285 .40046 .47896 .40089 .47404 .49144 Metetra
.562 .32 .506 r
.47404 .49144 .47896 .40089 .4851 .40071 .48028 .49799 Metetra
.555 .315 .507 r
.48028 .49799 .4851 .40071 .49127 .39988 .48659 .50287 Metetra
.547 .309 .507 r
.48659 .50287 .49127 .39988 .49746 .39836 .49295 .50581 Metetra
.54 .304 .506 r
.49295 .50581 .49746 .39836 .50368 .39615 .49937 .50665 Metetra
.533 .299 .506 r
.49937 .50665 .50368 .39615 .50991 .39327 .50582 .5053 Metetra
.526 .293 .505 r
.50582 .5053 .50991 .39327 .51616 .38978 .5123 .50178 Metetra
.519 .287 .504 r
.5123 .50178 .51616 .38978 .52241 .38575 .5188 .49617 Metetra
.512 .282 .502 r
.5188 .49617 .52241 .38575 .52867 .38125 .52529 .48865 Metetra
.505 .276 .501 r
.52529 .48865 .52867 .38125 .53493 .37637 .53178 .47947 Metetra
.498 .27 .498 r
.53178 .47947 .53493 .37637 .5412 .37123 .53825 .4689 Metetra
.491 .263 .496 r
.53825 .4689 .5412 .37123 .54746 .36589 .54469 .45727 Metetra
.484 .256 .493 r
.54469 .45727 .54746 .36589 .55373 .36046 .5511 .4449 Metetra
.476 .249 .49 r
.5511 .4449 .55373 .36046 .56 .35501 .55748 .43209 Metetra
.469 .242 .486 r
.55748 .43209 .56 .35501 .56627 .34961 .56384 .41913 Metetra
.461 .233 .481 r
.56384 .41913 .56627 .34961 .57254 .34432 .57017 .40629 Metetra
.453 .224 .475 r
.57017 .40629 .57254 .34432 .57882 .33917 .57647 .39378 Metetra
.444 .213 .468 r
.57647 .39378 .57882 .33917 .5851 .33421 .58276 .38176 Metetra
.434 .201 .459 r
.58276 .38176 .5851 .33421 .59139 .32945 .58903 .37036 Metetra
.423 .186 .448 r
.58903 .37036 .59139 .32945 .59769 .3249 .5953 .35968 Metetra
.41 .169 .435 r
.5953 .35968 .59769 .3249 .604 .32057 .60157 .34977 Metetra
.395 .148 .417 r
.60157 .34977 .604 .32057 .61033 .31646 .60784 .34064 Metetra
.376 .121 .395 r
.60784 .34064 .61033 .31646 .61666 .31256 .61412 .33228 Metetra
.352 .087 .364 r
.61412 .33228 .61666 .31256 .62301 .30886 .62041 .32467 Metetra
.321 .042 .324 r
.62041 .32467 .62301 .30886 .62937 .30534 .62671 .31776 Metetra
.279 0 .267 r
.62671 .31776 .62937 .30534 .63575 .30199 .63304 .3115 Metetra
.22 0 .186 r
.63304 .3115 .63575 .30199 .64215 .2988 .63938 .30583 Metetra
.135 0 .068 r
.63938 .30583 .64215 .2988 .64856 .29575 .64574 .30069 Metetra
.009 0 0 r
.64574 .30069 .64856 .29575 .65498 .29281 .65213 .29602 Metetra
.65213 .29602 .65498 .29281 .66143 .28999 .65854 .29175 Metetra
.369 .794 .605 r
.65854 .29175 .66143 .28999 .66789 .28726 .66497 .28782 Metetra
.54 .924 .817 r
.66497 .28782 .66789 .28726 .67437 .2846 .67142 .2842 Metetra
.638 .957 .928 r
.67142 .2842 .67437 .2846 .68086 .28201 .6779 .28082 Metetra
.679 .937 .966 r
.6779 .28082 .68086 .28201 .68737 .27948 .68439 .27766 Metetra
.692 .902 .971 r
.68439 .27766 .68737 .27948 .6939 .277 .69091 .27466 Metetra
.693 .868 .964 r
.69091 .27466 .6939 .277 .70044 .27456 .69745 .27181 Metetra
.69 .839 .955 r
.69745 .27181 .70044 .27456 .70701 .27214 .704 .26908 Metetra
.686 .817 .945 r
.704 .26908 .70701 .27214 .71358 .26976 .71058 .26643 Metetra
.682 .799 .937 r
.71058 .26643 .71358 .26976 .72018 .26739 .71717 .26386 Metetra
.678 .786 .931 r
.71717 .26386 .72018 .26739 .72679 .26504 .72378 .26135 Metetra
.675 .775 .926 r
.72378 .26135 .72679 .26504 .73341 .2627 .73041 .25888 Metetra
.673 .767 .921 r
.73041 .25888 .73341 .2627 .74005 .26037 .73706 .25645 Metetra
.671 .761 .918 r
.73706 .25645 .74005 .26037 .74671 .25804 .74373 .25404 Metetra
.669 .756 .916 r
.74373 .25404 .74671 .25804 .75339 .25572 .75041 .25166 Metetra
.668 .753 .914 r
.75041 .25166 .75339 .25572 .76008 .2534 .75711 .24928 Metetra
.667 .75 .912 r
.75711 .24928 .76008 .2534 .76678 .25108 .76382 .24692 Metetra
.666 .748 .911 r
.76382 .24692 .76678 .25108 .7735 .24876 .77055 .24457 Metetra
.666 .746 .91 r
.77055 .24457 .7735 .24876 .78024 .24644 .7773 .24222 Metetra
.665 .745 .91 r
.7773 .24222 .78024 .24644 .787 .24411 .78406 .23987 Metetra
.665 .744 .909 r
.78406 .23987 .787 .24411 .79377 .24179 .79085 .23752 Metetra
.664 .743 .909 r
.79085 .23752 .79377 .24179 .80055 .23945 .79764 .23517 Metetra
.664 .743 .909 r
.79764 .23517 .80055 .23945 .80735 .23712 .80446 .23282 Metetra
.664 .743 .909 r
.80446 .23282 .80735 .23712 .81417 .23478 .81128 .23047 Metetra
.664 .742 .908 r
.81128 .23047 .81417 .23478 .82101 .23244 .81813 .22811 Metetra
.664 .742 .908 r
.81813 .22811 .82101 .23244 .82786 .23009 .82499 .22575 Metetra
.664 .742 .908 r
.82499 .22575 .82786 .23009 .83472 .22773 .83187 .22338 Metetra
.664 .741 .908 r
.21794 .42943 .2217 .43293 .22723 .43103 .22347 .42752 Metetra
.664 .741 .908 r
.22347 .42752 .22723 .43103 .23276 .42913 .22901 .42561 Metetra
.664 .741 .908 r
.22901 .42561 .23276 .42913 .2383 .42723 .23456 .4237 Metetra
.664 .741 .908 r
.23456 .4237 .2383 .42723 .24386 .42532 .24012 .42179 Metetra
.664 .741 .908 r
.24012 .42179 .24386 .42532 .24943 .42341 .2457 .41987 Metetra
.663 .741 .908 r
.2457 .41987 .24943 .42341 .25501 .42149 .25129 .41794 Metetra
.663 .741 .908 r
.25129 .41794 .25501 .42149 .2606 .41957 .25689 .41602 Metetra
.663 .741 .908 r
.25689 .41602 .2606 .41957 .26621 .41765 .2625 .41409 Metetra
.663 .741 .908 r
.2625 .41409 .26621 .41765 .27182 .41572 .26812 .41215 Metetra
.663 .741 .908 r
.26812 .41215 .27182 .41572 .27745 .41379 .27376 .41022 Metetra
.663 .741 .908 r
.27376 .41022 .27745 .41379 .28309 .41186 .27941 .40828 Metetra
.663 .742 .909 r
.27941 .40828 .28309 .41186 .28874 .40992 .28506 .40634 Metetra
.662 .742 .909 r
.28506 .40634 .28874 .40992 .29441 .40799 .29074 .40441 Metetra
.662 .742 .91 r
.29074 .40441 .29441 .40799 .30008 .40606 .29642 .40248 Metetra
.661 .742 .91 r
.29642 .40248 .30008 .40606 .30577 .40413 .30211 .40056 Metetra
.659 .743 .912 r
.30211 .40056 .30577 .40413 .31147 .40222 .30782 .39866 Metetra
.657 .743 .913 r
.30782 .39866 .31147 .40222 .31718 .40032 .31353 .39678 Metetra
.654 .744 .916 r
.31353 .39678 .31718 .40032 .3229 .39845 .31926 .39495 Metetra
.65 .746 .92 r
.31926 .39495 .3229 .39845 .32863 .39662 .32499 .39316 Metetra
.644 .747 .924 r
.32499 .39316 .32863 .39662 .33437 .39484 .33074 .39146 Metetra
.635 .749 .931 r
.33074 .39146 .33437 .39484 .34012 .39315 .33649 .38986 Metetra
.622 .752 .94 r
.33649 .38986 .34012 .39315 .34588 .39157 .34224 .38841 Metetra
.603 .755 .951 r
.34224 .38841 .34588 .39157 .35164 .39014 .348 .38714 Metetra
.575 .756 .964 r
.348 .38714 .35164 .39014 .3574 .38891 .35376 .38611 Metetra
.532 .755 .978 r
.35376 .38611 .3574 .38891 .36317 .38794 .35953 .38538 Metetra
.466 .746 .99 r
.35953 .38538 .36317 .38794 .36894 .3873 .36529 .38504 Metetra
.361 .719 .987 r
.36529 .38504 .36894 .3873 .3747 .38707 .37104 .38515 Metetra
.2 .652 .946 r
.37104 .38515 .3747 .38707 .38046 .38734 .3768 .3858 Metetra
0 .521 .83 r
.3768 .3858 .38046 .38734 .38622 .38821 .38254 .38709 Metetra
.263 0 0 r
.38254 .38709 .38622 .38821 .39197 .38978 .38828 .38911 Metetra
.464 0 0 r
.38828 .38911 .39197 .38978 .39772 .39216 .39402 .39194 Metetra
.597 .03 0 r
.39402 .39194 .39772 .39216 .40346 .39542 .39975 .39566 Metetra
.678 .147 0 r
.39975 .39566 .40346 .39542 .4092 .39964 .40548 .40032 Metetra
.728 .228 .047 r
.40548 .40032 .4092 .39964 .41494 .40488 .41121 .40597 Metetra
.759 .285 .119 r
.41121 .40597 .41494 .40488 .42068 .41115 .41696 .4126 Metetra
.779 .325 .17 r
.41696 .4126 .42068 .41115 .42644 .41841 .42271 .42018 Metetra
.793 .354 .206 r
.42271 .42018 .42644 .41841 .43223 .42659 .42849 .42865 Metetra
.802 .374 .231 r
.42849 .42865 .43223 .42659 .43804 .43555 .43431 .43788 Metetra
.807 .387 .248 r
.43431 .43788 .43804 .43555 .44389 .4451 .44016 .44773 Metetra
.808 .394 .261 r
.44016 .44773 .44389 .4451 .44979 .45499 .44606 .45798 Metetra
.805 .395 .271 r
.44606 .45798 .44979 .45499 .45575 .46492 .45202 .46839 Metetra
.796 .39 .28 r
.45202 .46839 .45575 .46492 .46178 .47454 .45804 .47869 Metetra
.781 .378 .289 r
.45804 .47869 .46178 .47454 .46788 .4835 .46413 .48856 Metetra
.757 .36 .3 r
.46413 .48856 .46788 .4835 .47404 .49144 .47029 .49769 Metetra
.725 .336 .312 r
.47029 .49769 .47404 .49144 .48028 .49799 .47653 .50574 Metetra
.684 .306 .325 r
.47653 .50574 .48028 .49799 .48659 .50287 .48284 .51242 Metetra
.636 .273 .338 r
.48284 .51242 .48659 .50287 .49295 .50581 .48921 .51745 Metetra
.584 .239 .35 r
.48921 .51745 .49295 .50581 .49937 .50665 .49564 .5206 Metetra
.534 .207 .36 r
.49564 .5206 .49937 .50665 .50582 .5053 .50212 .52169 Metetra
.487 .178 .369 r
.50212 .52169 .50582 .5053 .5123 .50178 .50864 .52063 Metetra
.446 .154 .375 r
.50864 .52063 .5123 .50178 .5188 .49617 .51519 .51739 Metetra
.411 .134 .38 r
.51519 .51739 .5188 .49617 .52529 .48865 .52174 .51204 Metetra
.382 .117 .383 r
.52174 .51204 .52529 .48865 .53178 .47947 .5283 .5047 Metetra
.359 .104 .385 r
.5283 .5047 .53178 .47947 .53825 .4689 .53485 .49557 Metetra
.339 .092 .385 r
.53485 .49557 .53825 .4689 .54469 .45727 .54138 .48491 Metetra
.322 .081 .384 r
.54138 .48491 .54469 .45727 .5511 .4449 .54788 .47299 Metetra
.307 .071 .382 r
.54788 .47299 .5511 .4449 .55748 .43209 .55435 .46012 Metetra
.294 .061 .379 r
.55435 .46012 .55748 .43209 .56384 .41913 .56078 .44662 Metetra
.282 .05 .374 r
.56078 .44662 .56384 .41913 .57017 .40629 .56718 .43278 Metetra
.269 .038 .367 r
.56718 .43278 .57017 .40629 .57647 .39378 .57355 .41889 Metetra
.257 .025 .358 r
.57355 .41889 .57647 .39378 .58276 .38176 .57988 .40518 Metetra
.243 .01 .347 r
.57988 .40518 .58276 .38176 .58903 .37036 .5862 .39186 Metetra
.228 0 .332 r
.5862 .39186 .58903 .37036 .5953 .35968 .59249 .3791 Metetra
.21 0 .313 r
.59249 .3791 .5953 .35968 .60157 .34977 .59877 .36703 Metetra
.188 0 .289 r
.59877 .36703 .60157 .34977 .60784 .34064 .60505 .35572 Metetra
.161 0 .258 r
.60505 .35572 .60784 .34064 .61412 .33228 .61132 .34522 Metetra
.128 0 .217 r
.61132 .34522 .61412 .33228 .62041 .32467 .61761 .33556 Metetra
.085 0 .163 r
.61761 .33556 .62041 .32467 .62671 .31776 .6239 .32672 Metetra
.029 0 .092 r
.6239 .32672 .62671 .31776 .63304 .3115 .6302 .31867 Metetra
.6302 .31867 .63304 .3115 .63938 .30583 .63653 .31138 Metetra
.63653 .31138 .63938 .30583 .64574 .30069 .64287 .30477 Metetra
.64287 .30477 .64574 .30069 .65213 .29602 .64923 .29879 Metetra
.64923 .29879 .65213 .29602 .65854 .29175 .65562 .29338 Metetra
.535 .89 .669 r
.65562 .29338 .65854 .29175 .66497 .28782 .66203 .28847 Metetra
.636 .962 .814 r
.66203 .28847 .66497 .28782 .67142 .2842 .66847 .284 Metetra
.693 .978 .903 r
.66847 .284 .67142 .2842 .6779 .28082 .67493 .2799 Metetra
.717 .96 .945 r
.67493 .2799 .6779 .28082 .68439 .27766 .68141 .27613 Metetra
.722 .928 .959 r
.68141 .27613 .68439 .27766 .69091 .27466 .68792 .27262 Metetra
.718 .895 .96 r
.68792 .27262 .69091 .27466 .69745 .27181 .69445 .26935 Metetra
.711 .865 .955 r
.69445 .26935 .69745 .27181 .704 .26908 .701 .26626 Metetra
.703 .84 .948 r
.701 .26626 .704 .26908 .71058 .26643 .70757 .26333 Metetra
.696 .819 .941 r
.70757 .26333 .71058 .26643 .71717 .26386 .71417 .26052 Metetra
.689 .803 .935 r
.71417 .26052 .71717 .26386 .72378 .26135 .72078 .25782 Metetra
.684 .789 .93 r
.72078 .25782 .72378 .26135 .73041 .25888 .72741 .25519 Metetra
.68 .779 .925 r
.72741 .25519 .73041 .25888 .73706 .25645 .73406 .25264 Metetra
.676 .771 .922 r
.73406 .25264 .73706 .25645 .74373 .25404 .74073 .25013 Metetra
.674 .764 .919 r
.74073 .25013 .74373 .25404 .75041 .25166 .74742 .24766 Metetra
.671 .759 .916 r
.74742 .24766 .75041 .25166 .75711 .24928 .75413 .24522 Metetra
.67 .755 .914 r
.75413 .24522 .75711 .24928 .76382 .24692 .76085 .2428 Metetra
.668 .752 .913 r
.76085 .2428 .76382 .24692 .77055 .24457 .76759 .2404 Metetra
.667 .749 .912 r
.76759 .2404 .77055 .24457 .7773 .24222 .77435 .23802 Metetra
.666 .748 .911 r
.77435 .23802 .7773 .24222 .78406 .23987 .78112 .23564 Metetra
.666 .746 .91 r
.78112 .23564 .78406 .23987 .79085 .23752 .78791 .23326 Metetra
.665 .745 .91 r
.78791 .23326 .79085 .23752 .79764 .23517 .79472 .23089 Metetra
.665 .744 .909 r
.79472 .23089 .79764 .23517 .80446 .23282 .80154 .22852 Metetra
.665 .743 .909 r
.80154 .22852 .80446 .23282 .81128 .23047 .80838 .22615 Metetra
.664 .743 .909 r
.80838 .22615 .81128 .23047 .81813 .22811 .81524 .22377 Metetra
.664 .743 .909 r
.81524 .22377 .81813 .22811 .82499 .22575 .82211 .2214 Metetra
.664 .742 .908 r
.82211 .2214 .82499 .22575 .83187 .22338 .829 .21902 Metetra
.664 .741 .908 r
.21416 .42591 .21794 .42943 .22347 .42752 .2197 .424 Metetra
.664 .741 .908 r
.2197 .424 .22347 .42752 .22901 .42561 .22524 .42208 Metetra
.664 .741 .908 r
.22524 .42208 .22901 .42561 .23456 .4237 .2308 .42016 Metetra
.664 .741 .908 r
.2308 .42016 .23456 .4237 .24012 .42179 .23637 .41824 Metetra
.663 .741 .908 r
.23637 .41824 .24012 .42179 .2457 .41987 .24196 .41631 Metetra
.663 .741 .908 r
.24196 .41631 .2457 .41987 .25129 .41794 .24755 .41438 Metetra
.663 .741 .908 r
.24755 .41438 .25129 .41794 .25689 .41602 .25316 .41245 Metetra
.663 .741 .908 r
.25316 .41245 .25689 .41602 .2625 .41409 .25878 .41051 Metetra
.663 .741 .908 r
.25878 .41051 .2625 .41409 .26812 .41215 .26441 .40857 Metetra
.663 .741 .908 r
.26441 .40857 .26812 .41215 .27376 .41022 .27005 .40663 Metetra
.663 .742 .909 r
.27005 .40663 .27376 .41022 .27941 .40828 .2757 .40469 Metetra
.662 .742 .909 r
.2757 .40469 .27941 .40828 .28506 .40634 .28137 .40275 Metetra
.662 .742 .909 r
.28137 .40275 .28506 .40634 .29074 .40441 .28705 .40081 Metetra
.661 .742 .91 r
.28705 .40081 .29074 .40441 .29642 .40248 .29274 .39889 Metetra
.66 .742 .911 r
.29274 .39889 .29642 .40248 .30211 .40056 .29844 .39698 Metetra
.658 .743 .912 r
.29844 .39698 .30211 .40056 .30782 .39866 .30415 .39509 Metetra
.656 .743 .914 r
.30415 .39509 .30782 .39866 .31353 .39678 .30987 .39323 Metetra
.652 .743 .917 r
.30987 .39323 .31353 .39678 .31926 .39495 .3156 .39141 Metetra
.647 .744 .92 r
.3156 .39141 .31926 .39495 .32499 .39316 .32134 .38966 Metetra
.641 .744 .924 r
.32134 .38966 .32499 .39316 .33074 .39146 .32709 .38799 Metetra
.632 .744 .929 r
.32709 .38799 .33074 .39146 .33649 .38986 .33284 .38642 Metetra
.62 .743 .934 r
.33284 .38642 .33649 .38986 .34224 .38841 .33861 .385 Metetra
.605 .74 .94 r
.33861 .385 .34224 .38841 .348 .38714 .34437 .38374 Metetra
.586 .735 .946 r
.34437 .38374 .348 .38714 .35376 .38611 .35014 .38269 Metetra
.562 .725 .951 r
.35014 .38269 .35376 .38611 .35953 .38538 .35591 .38188 Metetra
.534 .71 .952 r
.35591 .38188 .35953 .38538 .36529 .38504 .36169 .38136 Metetra
.504 .686 .949 r
.36169 .38136 .36529 .38504 .37104 .38515 .36747 .38116 Metetra
.475 .655 .939 r
.36747 .38116 .37104 .38515 .3768 .3858 .37325 .38131 Metetra
.454 .615 .918 r
.37325 .38131 .3768 .3858 .38254 .38709 .37903 .38183 Metetra
.442 .569 .886 r
.37903 .38183 .38254 .38709 .38828 .38911 .38482 .38272 Metetra
.441 .52 .843 r
.38482 .38272 .38828 .38911 .39402 .39194 .39062 .38398 Metetra
.449 .475 .794 r
.39062 .38398 .39402 .39194 .39975 .39566 .39643 .38559 Metetra
.461 .436 .744 r
.39643 .38559 .39975 .39566 .40548 .40032 .40225 .38751 Metetra
.474 .406 .7 r
.40225 .38751 .40548 .40032 .41121 .40597 .40809 .38968 Metetra
.487 .384 .664 r
.40809 .38968 .41121 .40597 .41696 .4126 .41396 .39204 Metetra
.498 .369 .636 r
.41396 .39204 .41696 .4126 .42271 .42018 .41985 .39451 Metetra
.507 .359 .614 r
.41985 .39451 .42271 .42018 .42849 .42865 .42577 .39704 Metetra
.514 .351 .598 r
.42577 .39704 .42849 .42865 .43431 .43788 .43172 .39955 Metetra
.52 .346 .586 r
.43172 .39955 .43431 .43788 .44016 .44773 .4377 .40199 Metetra
.524 .342 .576 r
.4377 .40199 .44016 .44773 .44606 .45798 .44372 .40432 Metetra
.528 .339 .569 r
.44372 .40432 .44606 .45798 .45202 .46839 .44977 .40652 Metetra
.53 .337 .564 r
.44977 .40652 .45202 .46839 .45804 .47869 .45585 .40859 Metetra
.532 .336 .56 r
.45585 .40859 .45804 .47869 .46413 .48856 .46197 .41052 Metetra
.534 .334 .556 r
.46197 .41052 .46413 .48856 .47029 .49769 .46811 .41233 Metetra
.535 .333 .554 r
.46811 .41233 .47029 .49769 .47653 .50574 .47429 .414 Metetra
.536 .333 .552 r
.47429 .414 .47653 .50574 .48284 .51242 .4805 .41554 Metetra
.537 .333 .551 r
.4805 .41554 .48284 .51242 .48921 .51745 .48674 .41691 Metetra
.538 .333 .55 r
.48674 .41691 .48921 .51745 .49564 .5206 .493 .41806 Metetra
.539 .333 .55 r
.493 .41806 .49564 .5206 .50212 .52169 .4993 .41891 Metetra
.54 .335 .55 r
.4993 .41891 .50212 .52169 .50864 .52063 .50563 .41936 Metetra
.542 .336 .551 r
.50563 .41936 .50864 .52063 .51519 .51739 .51198 .41931 Metetra
.545 .339 .552 r
.51198 .41931 .51519 .51739 .52174 .51204 .51836 .41865 Metetra
.548 .342 .553 r
.51836 .41865 .52174 .51204 .5283 .5047 .52475 .41726 Metetra
.552 .347 .556 r
.52475 .41726 .5283 .5047 .53485 .49557 .53117 .41506 Metetra
.557 .352 .558 r
.53117 .41506 .53485 .49557 .54138 .48491 .53759 .412 Metetra
.563 .359 .562 r
.53759 .412 .54138 .48491 .54788 .47299 .54402 .40804 Metetra
.571 .368 .566 r
.54402 .40804 .54788 .47299 .55435 .46012 .55045 .40321 Metetra
.58 .378 .572 r
.55045 .40321 .55435 .46012 .56078 .44662 .55688 .39754 Metetra
.591 .391 .578 r
.55688 .39754 .56078 .44662 .56718 .43278 .5633 .39113 Metetra
.604 .406 .587 r
.5633 .39113 .56718 .43278 .57355 .41889 .56971 .38408 Metetra
.62 .425 .597 r
.56971 .38408 .57355 .41889 .57988 .40518 .5761 .37654 Metetra
.638 .448 .609 r
.5761 .37654 .57988 .40518 .5862 .39186 .58249 .36864 Metetra
.659 .475 .624 r
.58249 .36864 .5862 .39186 .59249 .3791 .58885 .36053 Metetra
.682 .507 .642 r
.58885 .36053 .59249 .3791 .59877 .36703 .59521 .35236 Metetra
.708 .544 .664 r
.59521 .35236 .59877 .36703 .60505 .35572 .60157 .34425 Metetra
.736 .586 .688 r
.60157 .34425 .60505 .35572 .61132 .34522 .60791 .33632 Metetra
.764 .633 .716 r
.60791 .33632 .61132 .34522 .61761 .33556 .61426 .32865 Metetra
.79 .683 .746 r
.61426 .32865 .61761 .33556 .6239 .32672 .62061 .32131 Metetra
.812 .732 .776 r
.62061 .32131 .6239 .32672 .6302 .31867 .62696 .31437 Metetra
.826 .777 .806 r
.62696 .31437 .6302 .31867 .63653 .31138 .63332 .30783 Metetra
.832 .814 .833 r
.63332 .30783 .63653 .31138 .64287 .30477 .6397 .30172 Metetra
.83 .841 .856 r
.6397 .30172 .64287 .30477 .64923 .29879 .64609 .29604 Metetra
.821 .859 .876 r
.64609 .29604 .64923 .29879 .65562 .29338 .6525 .29076 Metetra
.808 .868 .892 r
.6525 .29076 .65562 .29338 .66203 .28847 .65893 .28587 Metetra
.793 .869 .904 r
.65893 .28587 .66203 .28847 .66847 .284 .66538 .28135 Metetra
.777 .864 .914 r
.66538 .28135 .66847 .284 .67493 .2799 .67185 .27715 Metetra
.762 .856 .92 r
.67185 .27715 .67493 .2799 .68141 .27613 .67835 .27324 Metetra
.747 .845 .924 r
.67835 .27324 .68141 .27613 .68792 .27262 .68486 .26958 Metetra
.734 .833 .926 r
.68486 .26958 .68792 .27262 .69445 .26935 .6914 .26616 Metetra
.722 .821 .926 r
.6914 .26616 .69445 .26935 .701 .26626 .69795 .26292 Metetra
.712 .809 .926 r
.69795 .26292 .701 .26626 .70757 .26333 .70453 .25985 Metetra
.703 .799 .924 r
.70453 .25985 .70757 .26333 .71417 .26052 .71113 .25692 Metetra
.696 .789 .923 r
.71113 .25692 .71417 .26052 .72078 .25782 .71775 .2541 Metetra
.69 .781 .921 r
.71775 .2541 .72078 .25782 .72741 .25519 .72439 .25138 Metetra
.684 .774 .919 r
.72439 .25138 .72741 .25519 .73406 .25264 .73105 .24874 Metetra
.68 .768 .917 r
.73105 .24874 .73406 .25264 .74073 .25013 .73773 .24615 Metetra
.677 .763 .916 r
.73773 .24615 .74073 .25013 .74742 .24766 .74442 .24362 Metetra
.674 .759 .914 r
.74442 .24362 .74742 .24766 .75413 .24522 .75114 .24113 Metetra
.672 .755 .913 r
.75114 .24113 .75413 .24522 .76085 .2428 .75787 .23866 Metetra
.67 .752 .912 r
.75787 .23866 .76085 .2428 .76759 .2404 .76462 .23622 Metetra
.669 .75 .911 r
.76462 .23622 .76759 .2404 .77435 .23802 .77138 .2338 Metetra
.668 .748 .911 r
.77138 .2338 .77435 .23802 .78112 .23564 .77817 .23139 Metetra
.667 .747 .91 r
.77817 .23139 .78112 .23564 .78791 .23326 .78497 .22899 Metetra
.666 .746 .91 r
.78497 .22899 .78791 .23326 .79472 .23089 .79179 .22659 Metetra
.665 .745 .909 r
.79179 .22659 .79472 .23089 .80154 .22852 .79862 .2242 Metetra
.665 .744 .909 r
.79862 .2242 .80154 .22852 .80838 .22615 .80547 .22181 Metetra
.665 .743 .909 r
.80547 .22181 .80838 .22615 .81524 .22377 .81234 .21942 Metetra
.664 .743 .909 r
.81234 .21942 .81524 .22377 .82211 .2214 .81922 .21703 Metetra
.664 .743 .908 r
.81922 .21703 .82211 .2214 .829 .21902 .82613 .21463 Metetra
.664 .741 .908 r
.21037 .42238 .21416 .42591 .2197 .424 .21591 .42046 Metetra
.664 .741 .908 r
.21591 .42046 .2197 .424 .22524 .42208 .22146 .41854 Metetra
.664 .741 .908 r
.22146 .41854 .22524 .42208 .2308 .42016 .22703 .41661 Metetra
.663 .741 .908 r
.22703 .41661 .2308 .42016 .23637 .41824 .23261 .41468 Metetra
.663 .741 .908 r
.23261 .41468 .23637 .41824 .24196 .41631 .2382 .41274 Metetra
.663 .741 .908 r
.2382 .41274 .24196 .41631 .24755 .41438 .2438 .41081 Metetra
.663 .741 .908 r
.2438 .41081 .24755 .41438 .25316 .41245 .24941 .40887 Metetra
.663 .741 .908 r
.24941 .40887 .25316 .41245 .25878 .41051 .25504 .40692 Metetra
.663 .741 .908 r
.25504 .40692 .25878 .41051 .26441 .40857 .26068 .40498 Metetra
.663 .742 .909 r
.26068 .40498 .26441 .40857 .27005 .40663 .26633 .40303 Metetra
.662 .742 .909 r
.26633 .40303 .27005 .40663 .2757 .40469 .27199 .40109 Metetra
.662 .742 .909 r
.27199 .40109 .2757 .40469 .28137 .40275 .27766 .39915 Metetra
.661 .742 .91 r
.27766 .39915 .28137 .40275 .28705 .40081 .28334 .39722 Metetra
.66 .742 .911 r
.28334 .39722 .28705 .40081 .29274 .39889 .28904 .3953 Metetra
.658 .743 .912 r
.28904 .3953 .29274 .39889 .29844 .39698 .29475 .3934 Metetra
.656 .743 .914 r
.29475 .3934 .29844 .39698 .30415 .39509 .30046 .39153 Metetra
.653 .744 .917 r
.30046 .39153 .30415 .39509 .30987 .39323 .30619 .3897 Metetra
.649 .745 .92 r
.30619 .3897 .30987 .39323 .3156 .39141 .31192 .38792 Metetra
.643 .746 .924 r
.31192 .38792 .3156 .39141 .32134 .38966 .31767 .38622 Metetra
.635 .747 .929 r
.31767 .38622 .32134 .38966 .32709 .38799 .32342 .38461 Metetra
.625 .748 .936 r
.32342 .38461 .32709 .38799 .33284 .38642 .32918 .38311 Metetra
.611 .749 .943 r
.32918 .38311 .33284 .38642 .33861 .385 .33494 .38176 Metetra
.594 .749 .951 r
.33494 .38176 .33861 .385 .34437 .38374 .34071 .38058 Metetra
.573 .747 .959 r
.34071 .38058 .34437 .38374 .35014 .38269 .34648 .3796 Metetra
.547 .742 .967 r
.34648 .3796 .35014 .38269 .35591 .38188 .35226 .37883 Metetra
.517 .734 .972 r
.35226 .37883 .35591 .38188 .36169 .38136 .35805 .37829 Metetra
.488 .721 .974 r
.35805 .37829 .36169 .38136 .36747 .38116 .36383 .37799 Metetra
.463 .704 .972 r
.36383 .37799 .36747 .38116 .37325 .38131 .36963 .37791 Metetra
.45 .683 .964 r
.36963 .37791 .37325 .38131 .37903 .38183 .37544 .37802 Metetra
.453 .658 .948 r
.37544 .37802 .37903 .38183 .38482 .38272 .38126 .37827 Metetra
.473 .628 .921 r
.38126 .37827 .38482 .38272 .39062 .38398 .3871 .37858 Metetra
.501 .594 .879 r
.3871 .37858 .39062 .38398 .39643 .38559 .39297 .37886 Metetra
.53 .557 .828 r
.39297 .37886 .39643 .38559 .40225 .38751 .39886 .37899 Metetra
.553 .522 .775 r
.39886 .37899 .40225 .38751 .40809 .38968 .40479 .37885 Metetra
.57 .492 .727 r
.40479 .37885 .40809 .38968 .41396 .39204 .41074 .3783 Metetra
.581 .467 .688 r
.41074 .3783 .41396 .39204 .41985 .39451 .41674 .37723 Metetra
.587 .447 .657 r
.41674 .37723 .41985 .39451 .42577 .39704 .42277 .37555 Metetra
.59 .43 .634 r
.42277 .37555 .42577 .39704 .43172 .39955 .42884 .3732 Metetra
.59 .417 .615 r
.42884 .3732 .43172 .39955 .4377 .40199 .43493 .37015 Metetra
.589 .406 .601 r
.43493 .37015 .4377 .40199 .44372 .40432 .44106 .36646 Metetra
.587 .396 .59 r
.44106 .36646 .44372 .40432 .44977 .40652 .44721 .36221 Metetra
.583 .388 .582 r
.44721 .36221 .44977 .40652 .45585 .40859 .45337 .35755 Metetra
.579 .38 .575 r
.45337 .35755 .45585 .40859 .46197 .41052 .45954 .35266 Metetra
.575 .373 .569 r
.45954 .35266 .46197 .41052 .46811 .41233 .46571 .34776 Metetra
.57 .366 .565 r
.46571 .34776 .46811 .41233 .47429 .414 .47188 .34307 Metetra
.565 .36 .561 r
.47188 .34307 .47429 .414 .4805 .41554 .47805 .33879 Metetra
.56 .355 .559 r
.47805 .33879 .4805 .41554 .48674 .41691 .48422 .33511 Metetra
.556 .35 .556 r
.48422 .33511 .48674 .41691 .493 .41806 .49039 .33217 Metetra
.551 .345 .555 r
.49039 .33217 .493 .41806 .4993 .41891 .49656 .33003 Metetra
.547 .342 .553 r
.49656 .33003 .4993 .41891 .50563 .41936 .50273 .32873 Metetra
.544 .339 .552 r
.50273 .32873 .50563 .41936 .51198 .41931 .50893 .32821 Metetra
.541 .336 .552 r
.50893 .32821 .51198 .41931 .51836 .41865 .51514 .32838 Metetra
.539 .335 .552 r
.51514 .32838 .51836 .41865 .52475 .41726 .52137 .32907 Metetra
.537 .334 .553 r
.52137 .32907 .52475 .41726 .53117 .41506 .52763 .33012 Metetra
.536 .334 .554 r
.52763 .33012 .53117 .41506 .53759 .412 .53391 .33131 Metetra
.536 .336 .555 r
.53391 .33131 .53759 .412 .54402 .40804 .54023 .33244 Metetra
.538 .338 .557 r
.54023 .33244 .54402 .40804 .55045 .40321 .54657 .33333 Metetra
.54 .341 .56 r
.54657 .33333 .55045 .40321 .55688 .39754 .55293 .33381 Metetra
.543 .346 .564 r
.55293 .33381 .55688 .39754 .5633 .39113 .55931 .33375 Metetra
.548 .353 .568 r
.55931 .33375 .5633 .39113 .56971 .38408 .56571 .33307 Metetra
.554 .361 .574 r
.56571 .33307 .56971 .38408 .5761 .37654 .57212 .33172 Metetra
.561 .371 .581 r
.57212 .33172 .5761 .37654 .58249 .36864 .57853 .32972 Metetra
.57 .383 .589 r
.57853 .32972 .58249 .36864 .58885 .36053 .58495 .32709 Metetra
.581 .398 .599 r
.58495 .32709 .58885 .36053 .59521 .35236 .59137 .3239 Metetra
.593 .415 .61 r
.59137 .3239 .59521 .35236 .60157 .34425 .59779 .32023 Metetra
.607 .436 .624 r
.59779 .32023 .60157 .34425 .60791 .33632 .60421 .31618 Metetra
.622 .459 .64 r
.60421 .31618 .60791 .33632 .61426 .32865 .61063 .31184 Metetra
.639 .486 .659 r
.61063 .31184 .61426 .32865 .62061 .32131 .61705 .30732 Metetra
.656 .516 .681 r
.61705 .30732 .62061 .32131 .62696 .31437 .62347 .30271 Metetra
.674 .548 .704 r
.62347 .30271 .62696 .31437 .63332 .30783 .6299 .29807 Metetra
.691 .583 .73 r
.6299 .29807 .63332 .30783 .6397 .30172 .63633 .29348 Metetra
.706 .618 .756 r
.63633 .29348 .6397 .30172 .64609 .29604 .64278 .28899 Metetra
.718 .651 .782 r
.64278 .28899 .64609 .29604 .6525 .29076 .64923 .28464 Metetra
.727 .682 .807 r
.64923 .28464 .6525 .29076 .65893 .28587 .6557 .28045 Metetra
.731 .709 .829 r
.6557 .28045 .65893 .28587 .66538 .28135 .66218 .27643 Metetra
.732 .73 .849 r
.66218 .27643 .66538 .28135 .67185 .27715 .66868 .27259 Metetra
.73 .747 .865 r
.66868 .27259 .67185 .27715 .67835 .27324 .6752 .26893 Metetra
.726 .758 .878 r
.6752 .26893 .67835 .27324 .68486 .26958 .68173 .26544 Metetra
.72 .765 .888 r
.68173 .26544 .68486 .26958 .6914 .26616 .68829 .26211 Metetra
.714 .769 .896 r
.68829 .26211 .6914 .26616 .69795 .26292 .69486 .25893 Metetra
.707 .77 .901 r
.69486 .25893 .69795 .26292 .70453 .25985 .70145 .25588 Metetra
.701 .77 .905 r
.70145 .25588 .70453 .25985 .71113 .25692 .70806 .25294 Metetra
.695 .768 .908 r
.70806 .25294 .71113 .25692 .71775 .2541 .71469 .2501 Metetra
.69 .766 .909 r
.71469 .2501 .71775 .2541 .72439 .25138 .72134 .24735 Metetra
.685 .763 .91 r
.72134 .24735 .72439 .25138 .73105 .24874 .72801 .24468 Metetra
.681 .76 .911 r
.72801 .24468 .73105 .24874 .73773 .24615 .7347 .24206 Metetra
.678 .757 .911 r
.7347 .24206 .73773 .24615 .74442 .24362 .7414 .23949 Metetra
.675 .755 .911 r
.7414 .23949 .74442 .24362 .75114 .24113 .74813 .23696 Metetra
.673 .753 .911 r
.74813 .23696 .75114 .24113 .75787 .23866 .75487 .23447 Metetra
.671 .751 .91 r
.75487 .23447 .75787 .23866 .76462 .23622 .76163 .232 Metetra
.67 .749 .91 r
.76163 .232 .76462 .23622 .77138 .2338 .76841 .22955 Metetra
.668 .748 .91 r
.76841 .22955 .77138 .2338 .77817 .23139 .7752 .22711 Metetra
.667 .747 .91 r
.7752 .22711 .77817 .23139 .78497 .22899 .78201 .22469 Metetra
.667 .746 .909 r
.78201 .22469 .78497 .22899 .79179 .22659 .78884 .22227 Metetra
.666 .745 .909 r
.78884 .22227 .79179 .22659 .79862 .2242 .79568 .21986 Metetra
.665 .744 .909 r
.79568 .21986 .79862 .2242 .80547 .22181 .80255 .21746 Metetra
.665 .743 .909 r
.80255 .21746 .80547 .22181 .81234 .21942 .80943 .21505 Metetra
.665 .743 .909 r
.80943 .21505 .81234 .21942 .81922 .21703 .81632 .21264 Metetra
.664 .743 .908 r
.81632 .21264 .81922 .21703 .82613 .21463 .82323 .21023 Metetra
.664 .741 .908 r
.20656 .41883 .21037 .42238 .21591 .42046 .21211 .41691 Metetra
.664 .741 .908 r
.21211 .41691 .21591 .42046 .22146 .41854 .21767 .41497 Metetra
.663 .741 .908 r
.21767 .41497 .22146 .41854 .22703 .41661 .22324 .41304 Metetra
.663 .741 .908 r
.22324 .41304 .22703 .41661 .23261 .41468 .22883 .4111 Metetra
.663 .741 .908 r
.22883 .4111 .23261 .41468 .2382 .41274 .23442 .40916 Metetra
.663 .741 .908 r
.23442 .40916 .2382 .41274 .2438 .41081 .24003 .40722 Metetra
.663 .741 .908 r
.24003 .40722 .2438 .41081 .24941 .40887 .24565 .40527 Metetra
.663 .741 .908 r
.24565 .40527 .24941 .40887 .25504 .40692 .25129 .40332 Metetra
.663 .742 .909 r
.25129 .40332 .25504 .40692 .26068 .40498 .25693 .40137 Metetra
.662 .742 .909 r
.25693 .40137 .26068 .40498 .26633 .40303 .26259 .39943 Metetra
.662 .742 .909 r
.26259 .39943 .26633 .40303 .27199 .40109 .26825 .39748 Metetra
.661 .742 .91 r
.26825 .39748 .27199 .40109 .27766 .39915 .27393 .39555 Metetra
.66 .743 .911 r
.27393 .39555 .27766 .39915 .28334 .39722 .27962 .39363 Metetra
.658 .743 .913 r
.27962 .39363 .28334 .39722 .28904 .3953 .28532 .39173 Metetra
.656 .744 .915 r
.28532 .39173 .28904 .3953 .29475 .3934 .29104 .38985 Metetra
.653 .745 .918 r
.29104 .38985 .29475 .3934 .30046 .39153 .29676 .38802 Metetra
.648 .747 .921 r
.29676 .38802 .30046 .39153 .30619 .3897 .30249 .38625 Metetra
.642 .749 .927 r
.30249 .38625 .30619 .3897 .31192 .38792 .30822 .38455 Metetra
.633 .752 .933 r
.30822 .38455 .31192 .38792 .31767 .38622 .31397 .38296 Metetra
.621 .755 .942 r
.31397 .38296 .31767 .38622 .32342 .38461 .31972 .38148 Metetra
.605 .76 .953 r
.31972 .38148 .32342 .38461 .32918 .38311 .32547 .38017 Metetra
.581 .764 .966 r
.32547 .38017 .32918 .38311 .33494 .38176 .33123 .37905 Metetra
.546 .769 .98 r
.33123 .37905 .33494 .38176 .34071 .38058 .33699 .37816 Metetra
.496 .77 .993 r
.33699 .37816 .34071 .38058 .34648 .3796 .34275 .37752 Metetra
.419 .762 .996 r
.34275 .37752 .34648 .3796 .35226 .37883 .34852 .37718 Metetra
.304 .732 .971 r
.34852 .37718 .35226 .37883 .35805 .37829 .35428 .37716 Metetra
.141 .658 .89 r
.35428 .37716 .35805 .37829 .36383 .37799 .36005 .37747 Metetra
0 .527 .728 r
.36005 .37747 .36383 .37799 .36963 .37791 .36582 .3781 Metetra
.241 0 0 r
.36582 .3781 .36963 .37791 .37544 .37802 .3716 .37903 Metetra
.375 0 0 r
.3716 .37903 .37544 .37802 .38126 .37827 .3774 .38022 Metetra
.456 0 0 r
.3774 .38022 .38126 .37827 .3871 .37858 .38321 .3816 Metetra
.498 .004 .013 r
.38321 .3816 .3871 .37858 .39297 .37886 .38904 .38307 Metetra
.516 .06 .107 r
.38904 .38307 .39297 .37886 .39886 .37899 .3949 .38452 Metetra
.519 .096 .176 r
.3949 .38452 .39886 .37899 .40479 .37885 .40079 .38582 Metetra
.514 .117 .227 r
.40079 .38582 .40479 .37885 .41074 .3783 .40672 .38681 Metetra
.502 .129 .265 r
.40672 .38681 .41074 .3783 .41674 .37723 .41268 .38736 Metetra
.488 .135 .293 r
.41268 .38736 .41674 .37723 .42277 .37555 .4187 .38732 Metetra
.472 .136 .314 r
.4187 .38732 .42277 .37555 .42884 .3732 .42475 .38659 Metetra
.457 .134 .33 r
.42475 .38659 .42884 .3732 .43493 .37015 .43084 .38508 Metetra
.441 .131 .342 r
.43084 .38508 .43493 .37015 .44106 .36646 .43698 .38276 Metetra
.427 .126 .35 r
.43698 .38276 .44106 .36646 .44721 .36221 .44314 .37964 Metetra
.414 .121 .355 r
.44314 .37964 .44721 .36221 .45337 .35755 .44934 .37577 Metetra
.403 .115 .358 r
.44934 .37577 .45337 .35755 .45954 .35266 .45555 .37127 Metetra
.393 .108 .357 r
.45555 .37127 .45954 .35266 .46571 .34776 .46178 .36628 Metetra
.384 .1 .354 r
.46178 .36628 .46571 .34776 .47188 .34307 .46802 .36098 Metetra
.375 .09 .346 r
.46802 .36098 .47188 .34307 .47805 .33879 .47426 .35557 Metetra
.365 .076 .334 r
.47426 .35557 .47805 .33879 .48422 .33511 .4805 .35023 Metetra
.353 .055 .313 r
.4805 .35023 .48422 .33511 .49039 .33217 .48674 .34516 Metetra
.336 .024 .281 r
.48674 .34516 .49039 .33217 .49656 .33003 .49298 .3405 Metetra
.307 0 .225 r
.49298 .3405 .49656 .33003 .50273 .32873 .49922 .33636 Metetra
.254 0 .122 r
.49922 .33636 .50273 .32873 .50893 .32821 .50546 .33283 Metetra
.13 0 0 r
.50546 .33283 .50893 .32821 .51514 .32838 .51171 .32992 Metetra
.51171 .32992 .51514 .32838 .52137 .32907 .51796 .32761 Metetra
.563 .873 .994 r
.51796 .32761 .52137 .32907 .52763 .33012 .52423 .32583 Metetra
.609 .706 .913 r
.52423 .32583 .52763 .33012 .53391 .33131 .53052 .32448 Metetra
.594 .593 .821 r
.53052 .32448 .53391 .33131 .54023 .33244 .53682 .32344 Metetra
.583 .534 .765 r
.53682 .32344 .54023 .33244 .54657 .33333 .54315 .32257 Metetra
.578 .502 .733 r
.54315 .32257 .54657 .33333 .55293 .33381 .5495 .32175 Metetra
.578 .485 .713 r
.5495 .32175 .55293 .33381 .55931 .33375 .55586 .32083 Metetra
.582 .478 .702 r
.55586 .32083 .55931 .33375 .56571 .33307 .56224 .31972 Metetra
.588 .478 .696 r
.56224 .31972 .56571 .33307 .57212 .33172 .56864 .31833 Metetra
.597 .483 .695 r
.56864 .31833 .57212 .33172 .57853 .32972 .57505 .3166 Metetra
.607 .492 .697 r
.57505 .3166 .57853 .32972 .58495 .32709 .58147 .31449 Metetra
.618 .505 .702 r
.58147 .31449 .58495 .32709 .59137 .3239 .5879 .312 Metetra
.631 .52 .709 r
.5879 .312 .59137 .3239 .59779 .32023 .59433 .30916 Metetra
.644 .538 .719 r
.59433 .30916 .59779 .32023 .60421 .31618 .60077 .306 Metetra
.658 .558 .731 r
.60077 .306 .60421 .31618 .61063 .31184 .60721 .30256 Metetra
.672 .58 .744 r
.60721 .30256 .61063 .31184 .61705 .30732 .61366 .2989 Metetra
.685 .603 .759 r
.61366 .2989 .61705 .30732 .62347 .30271 .62011 .29509 Metetra
.697 .627 .774 r
.62011 .29509 .62347 .30271 .6299 .29807 .62657 .29118 Metetra
.708 .651 .79 r
.62657 .29118 .6299 .29807 .63633 .29348 .63303 .28722 Metetra
.717 .673 .807 r
.63303 .28722 .63633 .29348 .64278 .28899 .6395 .28327 Metetra
.723 .694 .823 r
.6395 .28327 .64278 .28899 .64923 .28464 .64598 .27936 Metetra
.727 .713 .837 r
.64598 .27936 .64923 .28464 .6557 .28045 .65248 .27553 Metetra
.728 .729 .851 r
.65248 .27553 .6557 .28045 .66218 .27643 .65898 .27179 Metetra
.728 .742 .863 r
.65898 .27179 .66218 .27643 .66868 .27259 .6655 .26816 Metetra
.725 .752 .874 r
.6655 .26816 .66868 .27259 .6752 .26893 .67204 .26466 Metetra
.721 .759 .882 r
.67204 .26466 .6752 .26893 .68173 .26544 .67859 .26127 Metetra
.716 .763 .89 r
.67859 .26127 .68173 .26544 .68829 .26211 .68516 .25801 Metetra
.711 .766 .895 r
.68516 .25801 .68829 .26211 .69486 .25893 .69175 .25487 Metetra
.705 .767 .9 r
.69175 .25487 .69486 .25893 .70145 .25588 .69835 .25183 Metetra
.7 .766 .903 r
.69835 .25183 .70145 .25588 .70806 .25294 .70497 .24889 Metetra
.695 .765 .906 r
.70497 .24889 .70806 .25294 .71469 .2501 .71162 .24604 Metetra
.69 .763 .907 r
.71162 .24604 .71469 .2501 .72134 .24735 .71828 .24327 Metetra
.686 .761 .908 r
.71828 .24327 .72134 .24735 .72801 .24468 .72496 .24057 Metetra
.682 .759 .909 r
.72496 .24057 .72801 .24468 .7347 .24206 .73165 .23792 Metetra
.679 .756 .91 r
.73165 .23792 .7347 .24206 .7414 .23949 .73837 .23532 Metetra
.676 .754 .91 r
.73837 .23532 .7414 .23949 .74813 .23696 .7451 .23277 Metetra
.674 .752 .91 r
.7451 .23277 .74813 .23696 .75487 .23447 .75186 .23024 Metetra
.672 .751 .91 r
.75186 .23024 .75487 .23447 .76163 .232 .75863 .22775 Metetra
.67 .749 .91 r
.75863 .22775 .76163 .232 .76841 .22955 .76541 .22527 Metetra
.669 .748 .909 r
.76541 .22527 .76841 .22955 .7752 .22711 .77222 .22282 Metetra
.668 .747 .909 r
.77222 .22282 .7752 .22711 .78201 .22469 .77904 .22037 Metetra
.667 .746 .909 r
.77904 .22037 .78201 .22469 .78884 .22227 .78588 .21794 Metetra
.666 .745 .909 r
.78588 .21794 .78884 .22227 .79568 .21986 .79274 .21551 Metetra
.666 .744 .909 r
.79274 .21551 .79568 .21986 .80255 .21746 .79961 .21308 Metetra
.665 .744 .909 r
.79961 .21308 .80255 .21746 .80943 .21505 .8065 .21066 Metetra
.665 .743 .908 r
.8065 .21066 .80943 .21505 .81632 .21264 .81341 .20824 Metetra
.665 .743 .908 r
.81341 .20824 .81632 .21264 .82323 .21023 .82033 .20581 Metetra
.664 .741 .908 r
.20274 .41527 .20656 .41883 .21211 .41691 .20829 .41334 Metetra
.663 .741 .908 r
.20829 .41334 .21211 .41691 .21767 .41497 .21386 .4114 Metetra
.663 .741 .908 r
.21386 .4114 .21767 .41497 .22324 .41304 .21944 .40946 Metetra
.663 .741 .908 r
.21944 .40946 .22324 .41304 .22883 .4111 .22503 .40752 Metetra
.663 .741 .908 r
.22503 .40752 .22883 .4111 .23442 .40916 .23064 .40557 Metetra
.663 .741 .908 r
.23064 .40557 .23442 .40916 .24003 .40722 .23625 .40362 Metetra
.663 .741 .908 r
.23625 .40362 .24003 .40722 .24565 .40527 .24188 .40167 Metetra
.663 .742 .909 r
.24188 .40167 .24565 .40527 .25129 .40332 .24752 .39971 Metetra
.662 .742 .909 r
.24752 .39971 .25129 .40332 .25693 .40137 .25317 .39776 Metetra
.662 .742 .909 r
.25317 .39776 .25693 .40137 .26259 .39943 .25883 .39582 Metetra
.661 .742 .91 r
.25883 .39582 .26259 .39943 .26825 .39748 .26451 .39388 Metetra
.66 .743 .911 r
.26451 .39388 .26825 .39748 .27393 .39555 .27019 .39196 Metetra
.658 .743 .913 r
.27019 .39196 .27393 .39555 .27962 .39363 .27589 .39005 Metetra
.656 .744 .915 r
.27589 .39005 .27962 .39363 .28532 .39173 .28159 .38818 Metetra
.652 .745 .918 r
.28159 .38818 .28532 .39173 .29104 .38985 .28731 .38636 Metetra
.647 .747 .922 r
.28731 .38636 .29104 .38985 .29676 .38802 .29303 .38459 Metetra
.641 .75 .928 r
.29303 .38459 .29676 .38802 .30249 .38625 .29876 .3829 Metetra
.631 .753 .935 r
.29876 .3829 .30249 .38625 .30822 .38455 .3045 .38132 Metetra
.618 .757 .944 r
.3045 .38132 .30822 .38455 .31397 .38296 .31024 .37988 Metetra
.599 .761 .956 r
.31024 .37988 .31397 .38296 .31972 .38148 .31598 .37861 Metetra
.571 .766 .971 r
.31598 .37861 .31972 .38148 .32547 .38017 .32173 .37756 Metetra
.529 .769 .985 r
.32173 .37756 .32547 .38017 .33123 .37905 .32747 .37676 Metetra
.463 .766 .996 r
.32747 .37676 .33123 .37905 .33699 .37816 .33322 .37627 Metetra
.357 .745 .987 r
.33322 .37627 .33699 .37816 .34275 .37752 .33896 .37614 Metetra
.193 .681 .925 r
.33896 .37614 .34275 .37752 .34852 .37718 .3447 .37641 Metetra
0 .543 .768 r
.3447 .37641 .34852 .37718 .35428 .37716 .35043 .37712 Metetra
.26 0 0 r
.35043 .37712 .35428 .37716 .36005 .37747 .35617 .3783 Metetra
.43 0 0 r
.35617 .3783 .36005 .37747 .36582 .3781 .3619 .37996 Metetra
.529 .002 0 r
.3619 .37996 .36582 .3781 .3716 .37903 .36764 .38211 Metetra
.58 .103 .086 r
.36764 .38211 .3716 .37903 .3774 .38022 .37338 .38473 Metetra
.604 .169 .187 r
.37338 .38473 .3774 .38022 .38321 .3816 .37913 .38778 Metetra
.613 .212 .258 r
.37913 .38778 .38321 .3816 .38904 .38307 .3849 .39118 Metetra
.613 .239 .31 r
.3849 .39118 .38904 .38307 .3949 .38452 .39069 .39487 Metetra
.608 .257 .349 r
.39069 .39487 .3949 .38452 .40079 .38582 .39651 .39872 Metetra
.6 .267 .378 r
.39651 .39872 .40079 .38582 .40672 .38681 .40237 .40262 Metetra
.59 .273 .401 r
.40237 .40262 .40672 .38681 .41268 .38736 .40826 .40645 Metetra
.58 .276 .418 r
.40826 .40645 .41268 .38736 .4187 .38732 .41419 .41006 Metetra
.569 .277 .432 r
.41419 .41006 .4187 .38732 .42475 .38659 .42018 .41333 Metetra
.559 .277 .443 r
.42018 .41333 .42475 .38659 .43084 .38508 .42621 .41612 Metetra
.55 .276 .452 r
.42621 .41612 .43084 .38508 .43698 .38276 .43228 .41835 Metetra
.542 .274 .46 r
.43228 .41835 .43698 .38276 .44314 .37964 .43841 .41991 Metetra
.535 .273 .465 r
.43841 .41991 .44314 .37964 .44934 .37577 .44458 .42073 Metetra
.528 .272 .47 r
.44458 .42073 .44934 .37577 .45555 .37127 .4508 .4208 Metetra
.523 .27 .474 r
.4508 .4208 .45555 .37127 .46178 .36628 .45705 .42008 Metetra
.519 .269 .476 r
.45705 .42008 .46178 .36628 .46802 .36098 .46334 .41859 Metetra
.515 .268 .479 r
.46334 .41859 .46802 .36098 .47426 .35557 .46966 .41638 Metetra
.512 .267 .48 r
.46966 .41638 .47426 .35557 .4805 .35023 .476 .41348 Metetra
.509 .265 .481 r
.476 .41348 .4805 .35023 .48674 .34516 .48237 .40998 Metetra
.506 .264 .482 r
.48237 .40998 .48674 .34516 .49298 .3405 .48874 .40595 Metetra
.504 .262 .481 r
.48874 .40595 .49298 .3405 .49922 .33636 .49513 .40148 Metetra
.502 .26 .481 r
.49513 .40148 .49922 .33636 .50546 .33283 .50153 .39666 Metetra
.499 .258 .48 r
.50153 .39666 .50546 .33283 .51171 .32992 .50793 .39156 Metetra
.496 .255 .478 r
.50793 .39156 .51171 .32992 .51796 .32761 .51434 .38625 Metetra
.493 .251 .475 r
.51434 .38625 .51796 .32761 .52423 .32583 .52075 .3808 Metetra
.489 .246 .472 r
.52075 .3808 .52423 .32583 .53052 .32448 .52716 .37525 Metetra
.485 .24 .467 r
.52716 .37525 .53052 .32448 .53682 .32344 .53357 .36964 Metetra
.479 .232 .461 r
.53357 .36964 .53682 .32344 .54315 .32257 .53998 .36399 Metetra
.472 .222 .453 r
.53998 .36399 .54315 .32257 .5495 .32175 .54639 .35833 Metetra
.463 .209 .443 r
.54639 .35833 .5495 .32175 .55586 .32083 .55281 .35265 Metetra
.45 .192 .43 r
.55281 .35265 .55586 .32083 .56224 .31972 .55922 .34697 Metetra
.435 .171 .413 r
.55922 .34697 .56224 .31972 .56864 .31833 .56564 .34129 Metetra
.414 .142 .39 r
.56564 .34129 .56864 .31833 .57505 .3166 .57205 .33562 Metetra
.385 .105 .36 r
.57205 .33562 .57505 .3166 .58147 .31449 .57847 .32997 Metetra
.346 .053 .317 r
.57847 .32997 .58147 .31449 .5879 .312 .58489 .32434 Metetra
.292 0 .257 r
.58489 .32434 .5879 .312 .59433 .30916 .59131 .31876 Metetra
.214 0 .171 r
.59131 .31876 .59433 .30916 .60077 .306 .59774 .31324 Metetra
.102 0 .046 r
.59774 .31324 .60077 .306 .60721 .30256 .60416 .30781 Metetra
.60416 .30781 .60721 .30256 .61366 .2989 .6106 .30248 Metetra
.6106 .30248 .61366 .2989 .62011 .29509 .61703 .29728 Metetra
.476 .842 .597 r
.61703 .29728 .62011 .29509 .62657 .29118 .62348 .29222 Metetra
.638 .957 .776 r
.62348 .29222 .62657 .29118 .63303 .28722 .62993 .28732 Metetra
.727 .989 .874 r
.62993 .28732 .63303 .28722 .6395 .28327 .6364 .28261 Metetra
.764 .977 .918 r
.6364 .28261 .6395 .28327 .64598 .27936 .64288 .27807 Metetra
.774 .949 .933 r
.64288 .27807 .64598 .27936 .65248 .27553 .64937 .27373 Metetra
.772 .92 .936 r
.64937 .27373 .65248 .27553 .65898 .27179 .65587 .26957 Metetra
.764 .893 .935 r
.65587 .26957 .65898 .27179 .6655 .26816 .66239 .2656 Metetra
.754 .87 .932 r
.66239 .2656 .6655 .26816 .67204 .26466 .66893 .26181 Metetra
.744 .85 .929 r
.66893 .26181 .67204 .26466 .67859 .26127 .67549 .2582 Metetra
.734 .833 .926 r
.67549 .2582 .67859 .26127 .68516 .25801 .68206 .25474 Metetra
.725 .819 .924 r
.68206 .25474 .68516 .25801 .69175 .25487 .68865 .25143 Metetra
.716 .807 .922 r
.68865 .25143 .69175 .25487 .69835 .25183 .69526 .24825 Metetra
.709 .797 .92 r
.69526 .24825 .69835 .25183 .70497 .24889 .70189 .24519 Metetra
.702 .788 .918 r
.70189 .24519 .70497 .24889 .71162 .24604 .70854 .24224 Metetra
.696 .781 .917 r
.70854 .24224 .71162 .24604 .71828 .24327 .71521 .23938 Metetra
.691 .774 .915 r
.71521 .23938 .71828 .24327 .72496 .24057 .7219 .2366 Metetra
.686 .769 .914 r
.7219 .2366 .72496 .24057 .73165 .23792 .72861 .23388 Metetra
.682 .764 .913 r
.72861 .23388 .73165 .23792 .73837 .23532 .73533 .23123 Metetra
.679 .76 .913 r
.73533 .23123 .73837 .23532 .7451 .23277 .74207 .22862 Metetra
.676 .757 .912 r
.74207 .22862 .7451 .23277 .75186 .23024 .74883 .22605 Metetra
.674 .754 .911 r
.74883 .22605 .75186 .23024 .75863 .22775 .75561 .22352 Metetra
.672 .752 .911 r
.75561 .22352 .75863 .22775 .76541 .22527 .76241 .22101 Metetra
.67 .75 .91 r
.76241 .22101 .76541 .22527 .77222 .22282 .76923 .21853 Metetra
.669 .748 .91 r
.76923 .21853 .77222 .22282 .77904 .22037 .77606 .21605 Metetra
.668 .747 .91 r
.77606 .21605 .77904 .22037 .78588 .21794 .78291 .21359 Metetra
.667 .746 .909 r
.78291 .21359 .78588 .21794 .79274 .21551 .78977 .21114 Metetra
.666 .745 .909 r
.78977 .21114 .79274 .21551 .79961 .21308 .79666 .2087 Metetra
.666 .744 .909 r
.79666 .2087 .79961 .21308 .8065 .21066 .80356 .20626 Metetra
.665 .744 .909 r
.80356 .20626 .8065 .21066 .81341 .20824 .81048 .20382 Metetra
.665 .743 .909 r
.81048 .20382 .81341 .20824 .82033 .20581 .81741 .20138 Metetra
.663 .741 .908 r
.1989 .4117 .20274 .41527 .20829 .41334 .20446 .40976 Metetra
.663 .741 .908 r
.20446 .40976 .20829 .41334 .21386 .4114 .21004 .40781 Metetra
.663 .741 .908 r
.21004 .40781 .21386 .4114 .21944 .40946 .21562 .40586 Metetra
.663 .741 .908 r
.21562 .40586 .21944 .40946 .22503 .40752 .22122 .40391 Metetra
.663 .741 .908 r
.22122 .40391 .22503 .40752 .23064 .40557 .22683 .40196 Metetra
.663 .741 .908 r
.22683 .40196 .23064 .40557 .23625 .40362 .23245 .40001 Metetra
.663 .742 .909 r
.23245 .40001 .23625 .40362 .24188 .40167 .23809 .39805 Metetra
.662 .742 .909 r
.23809 .39805 .24188 .40167 .24752 .39971 .24373 .3961 Metetra
.662 .742 .91 r
.24373 .3961 .24752 .39971 .25317 .39776 .24939 .39415 Metetra
.661 .742 .91 r
.24939 .39415 .25317 .39776 .25883 .39582 .25506 .39221 Metetra
.66 .743 .911 r
.25506 .39221 .25883 .39582 .26451 .39388 .26074 .39028 Metetra
.658 .743 .913 r
.26074 .39028 .26451 .39388 .27019 .39196 .26643 .38838 Metetra
.656 .744 .915 r
.26643 .38838 .27019 .39196 .27589 .39005 .27213 .3865 Metetra
.652 .745 .918 r
.27213 .3865 .27589 .39005 .28159 .38818 .27784 .38467 Metetra
.647 .747 .922 r
.27784 .38467 .28159 .38818 .28731 .38636 .28356 .38291 Metetra
.641 .749 .927 r
.28356 .38291 .28731 .38636 .29303 .38459 .28928 .38122 Metetra
.631 .752 .935 r
.28928 .38122 .29303 .38459 .29876 .3829 .29501 .37964 Metetra
.618 .755 .944 r
.29501 .37964 .29876 .3829 .3045 .38132 .30075 .3782 Metetra
.599 .759 .955 r
.30075 .3782 .3045 .38132 .31024 .37988 .30648 .37693 Metetra
.572 .762 .968 r
.30648 .37693 .31024 .37988 .31598 .37861 .31222 .37588 Metetra
.533 .763 .982 r
.31222 .37588 .31598 .37861 .32173 .37756 .31796 .37509 Metetra
.474 .759 .993 r
.31796 .37509 .32173 .37756 .32747 .37676 .32369 .3746 Metetra
.387 .742 .992 r
.32369 .3746 .32747 .37676 .33322 .37627 .32942 .37447 Metetra
.258 .697 .961 r
.32942 .37447 .33322 .37627 .33896 .37614 .33515 .37474 Metetra
.085 .608 .878 r
.33515 .37474 .33896 .37614 .3447 .37641 .34087 .37545 Metetra
0 .472 .73 r
.34087 .37545 .3447 .37641 .35043 .37712 .34659 .37662 Metetra
.291 0 0 r
.34659 .37662 .35043 .37712 .35617 .3783 .35231 .37827 Metetra
.427 0 0 r
.35231 .37827 .35617 .3783 .3619 .37996 .35803 .3804 Metetra
.516 0 0 r
.35803 .3804 .3619 .37996 .36764 .38211 .36375 .38299 Metetra
.573 .024 0 r
.36375 .38299 .36764 .38211 .37338 .38473 .36949 .38599 Metetra
.607 .078 0 r
.36949 .38599 .37338 .38473 .37913 .38778 .37524 .38934 Metetra
.627 .114 .006 r
.37524 .38934 .37913 .38778 .3849 .39118 .38101 .39296 Metetra
.638 .134 .034 r
.38101 .39296 .3849 .39118 .39069 .39487 .38681 .39676 Metetra
.641 .141 .045 r
.38681 .39676 .39069 .39487 .39651 .39872 .39264 .40064 Metetra
.639 .137 .042 r
.39264 .40064 .39651 .39872 .40237 .40262 .3985 .40449 Metetra
.63 .124 .027 r
.3985 .40449 .40237 .40262 .40826 .40645 .40441 .40821 Metetra
.615 .1 .001 r
.40441 .40821 .40826 .40645 .41419 .41006 .41036 .41171 Metetra
.593 .069 0 r
.41036 .41171 .41419 .41006 .42018 .41333 .41636 .41493 Metetra
.566 .033 0 r
.41636 .41493 .42018 .41333 .42621 .41612 .4224 .41781 Metetra
.537 0 0 r
.4224 .41781 .42621 .41612 .43228 .41835 .42848 .42031 Metetra
.51 0 0 r
.42848 .42031 .43228 .41835 .43841 .41991 .43461 .42242 Metetra
.491 0 0 r
.43461 .42242 .43841 .41991 .44458 .42073 .44078 .42413 Metetra
.481 0 .012 r
.44078 .42413 .44458 .42073 .4508 .4208 .44698 .42545 Metetra
.478 .023 .091 r
.44698 .42545 .4508 .4208 .45705 .42008 .45323 .42637 Metetra
.478 .061 .17 r
.45323 .42637 .45705 .42008 .46334 .41859 .4595 .42691 Metetra
.478 .097 .237 r
.4595 .42691 .46334 .41859 .46966 .41638 .46581 .42706 Metetra
.479 .126 .29 r
.46581 .42706 .46966 .41638 .476 .41348 .47215 .42679 Metetra
.478 .149 .33 r
.47215 .42679 .476 .41348 .48237 .40998 .47852 .42607 Metetra
.477 .166 .359 r
.47852 .42607 .48237 .40998 .48874 .40595 .48491 .42488 Metetra
.475 .178 .38 r
.48491 .42488 .48874 .40595 .49513 .40148 .49133 .42317 Metetra
.473 .186 .396 r
.49133 .42317 .49513 .40148 .50153 .39666 .49777 .42089 Metetra
.469 .19 .407 r
.49777 .42089 .50153 .39666 .50793 .39156 .50422 .418 Metetra
.465 .192 .415 r
.50422 .418 .50793 .39156 .51434 .38625 .5107 .41448 Metetra
.46 .192 .419 r
.5107 .41448 .51434 .38625 .52075 .3808 .51718 .41032 Metetra
.454 .189 .422 r
.51718 .41032 .52075 .3808 .52716 .37525 .52367 .40551 Metetra
.447 .185 .422 r
.52367 .40551 .52716 .37525 .53357 .36964 .53016 .40007 Metetra
.439 .179 .421 r
.53016 .40007 .53357 .36964 .53998 .36399 .53666 .39405 Metetra
.429 .17 .418 r
.53666 .39405 .53998 .36399 .54639 .35833 .54315 .38751 Metetra
.419 .16 .413 r
.54315 .38751 .54639 .35833 .55281 .35265 .54963 .38052 Metetra
.406 .147 .405 r
.54963 .38052 .55281 .35265 .55922 .34697 .55611 .37315 Metetra
.391 .132 .396 r
.55611 .37315 .55922 .34697 .56564 .34129 .56258 .3655 Metetra
.374 .113 .383 r
.56258 .3655 .56564 .34129 .57205 .33562 .56904 .35767 Metetra
.354 .089 .367 r
.56904 .35767 .57205 .33562 .57847 .32997 .57549 .34974 Metetra
.33 .061 .346 r
.57549 .34974 .57847 .32997 .58489 .32434 .58193 .3418 Metetra
.3 .026 .319 r
.58193 .3418 .58489 .32434 .59131 .31876 .58836 .33393 Metetra
.264 0 .285 r
.58836 .33393 .59131 .31876 .59774 .31324 .59479 .3262 Metetra
.219 0 .24 r
.59479 .3262 .59774 .31324 .60416 .30781 .60122 .31868 Metetra
.162 0 .181 r
.60122 .31868 .60416 .30781 .6106 .30248 .60764 .31141 Metetra
.089 0 .102 r
.60764 .31141 .6106 .30248 .61703 .29728 .61407 .30443 Metetra
.61407 .30443 .61703 .29728 .62348 .29222 .6205 .29777 Metetra
.6205 .29777 .62348 .29222 .62993 .28732 .62695 .29145 Metetra
.62695 .29145 .62993 .28732 .6364 .28261 .6334 .28547 Metetra
.6334 .28547 .6364 .28261 .64288 .27807 .63986 .27983 Metetra
.565 .902 .666 r
.63986 .27983 .64288 .27807 .64937 .27373 .64634 .27453 Metetra
.668 .97 .798 r
.64634 .27453 .64937 .27373 .65587 .26957 .65284 .26955 Metetra
.726 .988 .88 r
.65284 .26955 .65587 .26957 .66239 .2656 .65935 .26487 Metetra
.751 .975 .923 r
.65935 .26487 .66239 .2656 .66893 .26181 .66588 .26049 Metetra
.756 .948 .941 r
.66588 .26049 .66893 .26181 .67549 .2582 .67243 .25636 Metetra
.752 .919 .947 r
.67243 .25636 .67549 .2582 .68206 .25474 .679 .25247 Metetra
.744 .89 .946 r
.679 .25247 .68206 .25474 .68865 .25143 .68559 .2488 Metetra
.734 .865 .942 r
.68559 .2488 .68865 .25143 .69526 .24825 .6922 .24532 Metetra
.724 .844 .938 r
.6922 .24532 .69526 .24825 .70189 .24519 .69883 .24201 Metetra
.715 .825 .934 r
.69883 .24201 .70189 .24519 .70854 .24224 .70548 .23884 Metetra
.707 .81 .929 r
.70548 .23884 .70854 .24224 .71521 .23938 .71215 .2358 Metetra
.699 .798 .926 r
.71215 .2358 .71521 .23938 .7219 .2366 .71884 .23288 Metetra
.693 .787 .923 r
.71884 .23288 .7219 .2366 .72861 .23388 .72556 .23004 Metetra
.688 .779 .92 r
.72556 .23004 .72861 .23388 .73533 .23123 .73229 .22728 Metetra
.684 .772 .918 r
.73229 .22728 .73533 .23123 .74207 .22862 .73904 .22459 Metetra
.68 .766 .916 r
.73904 .22459 .74207 .22862 .74883 .22605 .74581 .22195 Metetra
.677 .761 .915 r
.74581 .22195 .74883 .22605 .75561 .22352 .75259 .21935 Metetra
.674 .757 .913 r
.75259 .21935 .75561 .22352 .76241 .22101 .7594 .21679 Metetra
.672 .754 .912 r
.7594 .21679 .76241 .22101 .76923 .21853 .76622 .21426 Metetra
.671 .752 .911 r
.76622 .21426 .76923 .21853 .77606 .21605 .77307 .21175 Metetra
.669 .75 .911 r
.77307 .21175 .77606 .21605 .78291 .21359 .77992 .20926 Metetra
.668 .748 .91 r
.77992 .20926 .78291 .21359 .78977 .21114 .7868 .20678 Metetra
.667 .747 .91 r
.7868 .20678 .78977 .21114 .79666 .2087 .7937 .20431 Metetra
.666 .746 .909 r
.7937 .20431 .79666 .2087 .80356 .20626 .80061 .20185 Metetra
.666 .745 .909 r
.80061 .20185 .80356 .20626 .81048 .20382 .80754 .19939 Metetra
.665 .744 .909 r
.80754 .19939 .81048 .20382 .81741 .20138 .81449 .19694 Metetra
.663 .741 .908 r
.19505 .40811 .1989 .4117 .20446 .40976 .20061 .40616 Metetra
.663 .741 .908 r
.20061 .40616 .20446 .40976 .21004 .40781 .2062 .40421 Metetra
.663 .741 .908 r
.2062 .40421 .21004 .40781 .21562 .40586 .21179 .40226 Metetra
.663 .741 .908 r
.21179 .40226 .21562 .40586 .22122 .40391 .2174 .4003 Metetra
.663 .741 .908 r
.2174 .4003 .22122 .40391 .22683 .40196 .22301 .39834 Metetra
.663 .742 .909 r
.22301 .39834 .22683 .40196 .23245 .40001 .22864 .39638 Metetra
.662 .742 .909 r
.22864 .39638 .23245 .40001 .23809 .39805 .23428 .39443 Metetra
.662 .742 .91 r
.23428 .39443 .23809 .39805 .24373 .3961 .23993 .39248 Metetra
.661 .742 .91 r
.23993 .39248 .24373 .3961 .24939 .39415 .2456 .39053 Metetra
.66 .743 .911 r
.2456 .39053 .24939 .39415 .25506 .39221 .25127 .3886 Metetra
.658 .743 .913 r
.25127 .3886 .25506 .39221 .26074 .39028 .25696 .38669 Metetra
.655 .744 .915 r
.25696 .38669 .26074 .39028 .26643 .38838 .26265 .38482 Metetra
.652 .745 .918 r
.26265 .38482 .26643 .38838 .27213 .3865 .26836 .38298 Metetra
.647 .747 .922 r
.26836 .38298 .27213 .3865 .27784 .38467 .27407 .38121 Metetra
.641 .749 .927 r
.27407 .38121 .27784 .38467 .28356 .38291 .27979 .37952 Metetra
.632 .751 .934 r
.27979 .37952 .28356 .38291 .28928 .38122 .28551 .37793 Metetra
.619 .754 .942 r
.28551 .37793 .28928 .38122 .29501 .37964 .29124 .37648 Metetra
.601 .757 .953 r
.29124 .37648 .29501 .37964 .30075 .3782 .29697 .37519 Metetra
.576 .76 .965 r
.29697 .37519 .30075 .3782 .30648 .37693 .3027 .37411 Metetra
.541 .761 .978 r
.3027 .37411 .30648 .37693 .31222 .37588 .30843 .37328 Metetra
.49 .757 .989 r
.30843 .37328 .31222 .37588 .31796 .37509 .31416 .37274 Metetra
.419 .744 .993 r
.31416 .37274 .31796 .37509 .32369 .3746 .31988 .37253 Metetra
.32 .714 .98 r
.31988 .37253 .32369 .3746 .32942 .37447 .3256 .37268 Metetra
.194 .659 .94 r
.3256 .37268 .32942 .37447 .33515 .37474 .33132 .37321 Metetra
.051 .578 .866 r
.33132 .37321 .33515 .37474 .34087 .37545 .33704 .37415 Metetra
0 .482 .772 r
.33704 .37415 .34087 .37545 .34659 .37662 .34276 .37547 Metetra
0 .394 .683 r
.34276 .37547 .34659 .37662 .35231 .37827 .34848 .37716 Metetra
.265 0 0 r
.34848 .37716 .35231 .37827 .35803 .3804 .35422 .37915 Metetra
.287 0 0 r
.35422 .37915 .35803 .3804 .36375 .38299 .35997 .38136 Metetra
0 .329 .673 r
.35997 .38136 .36375 .38299 .36949 .38599 .36574 .3837 Metetra
0 .397 .785 r
.36574 .3837 .36949 .38599 .37524 .38934 .37154 .38604 Metetra
.069 .479 .891 r
.37154 .38604 .37524 .38934 .38101 .39296 .37738 .38823 Metetra
.279 .517 .903 r
.37738 .38823 .38101 .39296 .38681 .39676 .38326 .39015 Metetra
.419 .507 .842 r
.38326 .39015 .38681 .39676 .39264 .40064 .38919 .39164 Metetra
.495 .482 .772 r
.38919 .39164 .39264 .40064 .3985 .40449 .39516 .39261 Metetra
.535 .459 .717 r
.39516 .39261 .3985 .40449 .40441 .40821 .40119 .39295 Metetra
.556 .44 .676 r
.40119 .39295 .40441 .40821 .41036 .41171 .40726 .39263 Metetra
.567 .425 .647 r
.40726 .39263 .41036 .41171 .41636 .41493 .41337 .39164 Metetra
.572 .412 .626 r
.41337 .39164 .41636 .41493 .4224 .41781 .41953 .39004 Metetra
.574 .402 .611 r
.41953 .39004 .4224 .41781 .42848 .42031 .42571 .38792 Metetra
.573 .393 .599 r
.42571 .38792 .42848 .42031 .43461 .42242 .43192 .38543 Metetra
.571 .385 .59 r
.43192 .38543 .43461 .42242 .44078 .42413 .43815 .38272 Metetra
.568 .377 .583 r
.43815 .38272 .44078 .42413 .44698 .42545 .44439 .37999 Metetra
.564 .371 .578 r
.44439 .37999 .44698 .42545 .45323 .42637 .45064 .37741 Metetra
.559 .365 .574 r
.45064 .37741 .45323 .42637 .4595 .42691 .4569 .37514 Metetra
.555 .36 .571 r
.4569 .37514 .4595 .42691 .46581 .42706 .46316 .37331 Metetra
.55 .355 .569 r
.46316 .37331 .46581 .42706 .47215 .42679 .46942 .37201 Metetra
.546 .351 .568 r
.46942 .37201 .47215 .42679 .47852 .42607 .4757 .37126 Metetra
.542 .348 .568 r
.4757 .37126 .47852 .42607 .48491 .42488 .48199 .37104 Metetra
.539 .346 .568 r
.48199 .37104 .48491 .42488 .49133 .42317 .48829 .37129 Metetra
.536 .346 .57 r
.48829 .37129 .49133 .42317 .49777 .42089 .49462 .37186 Metetra
.535 .347 .573 r
.49462 .37186 .49777 .42089 .50422 .418 .50097 .37261 Metetra
.535 .35 .577 r
.50097 .37261 .50422 .418 .5107 .41448 .50735 .37335 Metetra
.537 .355 .583 r
.50735 .37335 .5107 .41448 .51718 .41032 .51375 .37389 Metetra
.541 .364 .591 r
.51375 .37389 .51718 .41032 .52367 .40551 .52018 .37404 Metetra
.549 .378 .602 r
.52018 .37404 .52367 .40551 .53016 .40007 .52664 .37365 Metetra
.561 .397 .616 r
.52664 .37365 .53016 .40007 .53666 .39405 .53311 .37256 Metetra
.579 .425 .637 r
.53311 .37256 .53666 .39405 .54315 .38751 .5396 .3707 Metetra
.605 .465 .664 r
.5396 .3707 .54315 .38751 .54963 .38052 .54611 .36799 Metetra
.644 .523 .702 r
.54611 .36799 .54963 .38052 .55611 .37315 .55262 .36444 Metetra
.697 .606 .751 r
.55262 .36444 .55611 .37315 .56258 .3655 .55913 .36008 Metetra
.765 .721 .811 r
.55913 .36008 .56258 .3655 .56904 .35767 .56563 .35496 Metetra
.834 .858 .863 r
.56563 .35496 .56904 .35767 .57549 .34974 .57213 .3492 Metetra
.86 .972 .863 r
.57213 .3492 .57549 .34974 .58193 .3418 .57863 .34289 Metetra
.803 .996 .778 r
.57863 .34289 .58193 .3418 .58836 .33393 .58511 .33618 Metetra
.7 .945 .655 r
.58511 .33618 .58836 .33393 .59479 .3262 .59158 .32918 Metetra
.61 .881 .556 r
.59158 .32918 .59479 .3262 .60122 .31868 .59805 .32202 Metetra
.556 .838 .5 r
.59805 .32202 .60122 .31868 .60764 .31141 .60451 .31482 Metetra
.534 .823 .483 r
.60451 .31482 .60764 .31141 .61407 .30443 .61096 .30767 Metetra
.539 .831 .498 r
.61096 .30767 .61407 .30443 .6205 .29777 .61742 .30068 Metetra
.564 .857 .538 r
.61742 .30068 .6205 .29777 .62695 .29145 .62387 .29389 Metetra
.603 .893 .596 r
.62387 .29389 .62695 .29145 .6334 .28547 .63034 .28737 Metetra
.648 .932 .665 r
.63034 .28737 .6334 .28547 .63986 .27983 .63681 .28116 Metetra
.692 .966 .737 r
.63681 .28116 .63986 .27983 .64634 .27453 .64329 .27526 Metetra
.729 .988 .803 r
.64329 .27526 .64634 .27453 .65284 .26955 .64979 .2697 Metetra
.755 .995 .857 r
.64979 .2697 .65284 .26955 .65935 .26487 .6563 .26448 Metetra
.769 .988 .896 r
.6563 .26448 .65935 .26487 .66588 .26049 .66283 .25957 Metetra
.773 .971 .921 r
.66283 .25957 .66588 .26049 .67243 .25636 .66937 .25497 Metetra
.769 .948 .936 r
.66937 .25497 .67243 .25636 .679 .25247 .67594 .25065 Metetra
.761 .922 .942 r
.67594 .25065 .679 .25247 .68559 .2488 .68253 .24659 Metetra
.751 .897 .944 r
.68253 .24659 .68559 .2488 .6922 .24532 .68914 .24277 Metetra
.74 .874 .942 r
.68914 .24277 .6922 .24532 .69883 .24201 .69577 .23917 Metetra
.729 .853 .939 r
.69577 .23917 .69883 .24201 .70548 .23884 .70242 .23575 Metetra
.719 .834 .936 r
.70242 .23575 .70548 .23884 .71215 .2358 .7091 .23249 Metetra
.71 .818 .932 r
.7091 .23249 .71215 .2358 .71884 .23288 .71579 .22937 Metetra
.703 .805 .928 r
.71579 .22937 .71884 .23288 .72556 .23004 .7225 .22638 Metetra
.696 .793 .925 r
.7225 .22638 .72556 .23004 .73229 .22728 .72924 .22348 Metetra
.69 .784 .922 r
.72924 .22348 .73229 .22728 .73904 .22459 .736 .22067 Metetra
.685 .776 .92 r
.736 .22067 .73904 .22459 .74581 .22195 .74277 .21794 Metetra
.681 .769 .918 r
.74277 .21794 .74581 .22195 .75259 .21935 .74957 .21526 Metetra
.678 .764 .916 r
.74957 .21526 .75259 .21935 .7594 .21679 .75638 .21263 Metetra
.675 .76 .914 r
.75638 .21263 .7594 .21679 .76622 .21426 .76321 .21004 Metetra
.673 .756 .913 r
.76321 .21004 .76622 .21426 .77307 .21175 .77006 .20748 Metetra
.671 .753 .912 r
.77006 .20748 .77307 .21175 .77992 .20926 .77693 .20495 Metetra
.67 .751 .911 r
.77693 .20495 .77992 .20926 .7868 .20678 .78382 .20244 Metetra
.668 .749 .911 r
.78382 .20244 .7868 .20678 .7937 .20431 .79072 .19993 Metetra
.667 .747 .91 r
.79072 .19993 .7937 .20431 .80061 .20185 .79765 .19744 Metetra
.667 .746 .91 r
.79765 .19744 .80061 .20185 .80754 .19939 .80459 .19496 Metetra
.666 .745 .909 r
.80459 .19496 .80754 .19939 .81449 .19694 .81155 .19248 Metetra
.663 .741 .908 r
.19118 .40451 .19505 .40811 .20061 .40616 .19675 .40256 Metetra
.663 .741 .908 r
.19675 .40256 .20061 .40616 .2062 .40421 .20234 .4006 Metetra
.663 .741 .908 r
.20234 .4006 .2062 .40421 .21179 .40226 .20794 .39864 Metetra
.663 .741 .908 r
.20794 .39864 .21179 .40226 .2174 .4003 .21355 .39668 Metetra
.663 .742 .909 r
.21355 .39668 .2174 .4003 .22301 .39834 .21918 .39471 Metetra
.662 .742 .909 r
.21918 .39471 .22301 .39834 .22864 .39638 .22481 .39275 Metetra
.662 .742 .91 r
.22481 .39275 .22864 .39638 .23428 .39443 .23046 .3908 Metetra
.661 .742 .91 r
.23046 .3908 .23428 .39443 .23993 .39248 .23612 .38885 Metetra
.66 .743 .911 r
.23612 .38885 .23993 .39248 .2456 .39053 .24179 .38692 Metetra
.658 .743 .913 r
.24179 .38692 .2456 .39053 .25127 .3886 .24747 .38501 Metetra
.655 .744 .915 r
.24747 .38501 .25127 .3886 .25696 .38669 .25316 .38313 Metetra
.652 .745 .918 r
.25316 .38313 .25696 .38669 .26265 .38482 .25885 .38129 Metetra
.647 .747 .922 r
.25885 .38129 .26265 .38482 .26836 .38298 .26456 .37951 Metetra
.641 .749 .927 r
.26456 .37951 .26836 .38298 .27407 .38121 .27027 .37782 Metetra
.632 .751 .934 r
.27027 .37782 .27407 .38121 .27979 .37952 .27599 .37622 Metetra
.619 .754 .942 r
.27599 .37622 .27979 .37952 .28551 .37793 .28171 .37476 Metetra
.602 .757 .953 r
.28171 .37476 .28551 .37793 .29124 .37648 .28744 .37346 Metetra
.578 .76 .965 r
.28744 .37346 .29124 .37648 .29697 .37519 .29316 .37237 Metetra
.543 .762 .978 r
.29316 .37237 .29697 .37519 .3027 .37411 .29888 .37151 Metetra
.495 .759 .989 r
.29888 .37151 .3027 .37411 .30843 .37328 .3046 .37094 Metetra
.425 .748 .994 r
.3046 .37094 .30843 .37328 .31416 .37274 .31032 .37068 Metetra
.33 .72 .982 r
.31032 .37068 .31416 .37274 .31988 .37253 .31603 .37076 Metetra
.207 .669 .943 r
.31603 .37076 .31988 .37253 .3256 .37268 .32174 .37122 Metetra
.064 .591 .869 r
.32174 .37122 .3256 .37268 .33132 .37321 .32745 .37204 Metetra
0 .495 .77 r
.32745 .37204 .33132 .37321 .33704 .37415 .33316 .37321 Metetra
.191 0 0 r
.33316 .37321 .33704 .37415 .34276 .37547 .33888 .3747 Metetra
.268 0 0 r
.33888 .3747 .34276 .37547 .34848 .37716 .34461 .37644 Metetra
.304 0 0 r
.34461 .37644 .34848 .37716 .35422 .37915 .35036 .37833 Metetra
.292 0 0 r
.35036 .37833 .35422 .37915 .35997 .38136 .35613 .38024 Metetra
.217 0 0 r
.35613 .38024 .35997 .38136 .36574 .3837 .36194 .38203 Metetra
0 .493 .814 r
.36194 .38203 .36574 .3837 .37154 .38604 .36779 .38353 Metetra
.192 .613 .946 r
.36779 .38353 .37154 .38604 .37738 .38823 .37369 .38456 Metetra
.417 .657 .959 r
.37369 .38456 .37738 .38823 .38326 .39015 .37964 .38496 Metetra
.547 .632 .888 r
.37964 .38496 .38326 .39015 .38919 .39164 .38566 .38456 Metetra
.607 .591 .809 r
.38566 .38456 .38919 .39164 .39516 .39261 .39172 .38324 Metetra
.633 .554 .748 r
.39172 .38324 .39516 .39261 .40119 .39295 .39785 .38092 Metetra
.644 .524 .703 r
.39785 .38092 .40119 .39295 .40726 .39263 .40403 .37756 Metetra
.646 .5 .671 r
.40403 .37756 .40726 .39263 .41337 .39164 .41025 .37319 Metetra
.644 .48 .647 r
.41025 .37319 .41337 .39164 .41953 .39004 .41651 .3679 Metetra
.639 .463 .629 r
.41651 .3679 .41953 .39004 .42571 .38792 .42279 .36186 Metetra
.632 .447 .615 r
.42279 .36186 .42571 .38792 .43192 .38543 .42909 .35525 Metetra
.624 .433 .604 r
.42909 .35525 .43192 .38543 .43815 .38272 .4354 .34833 Metetra
.614 .42 .595 r
.4354 .34833 .43815 .38272 .44439 .37999 .4417 .34137 Metetra
.605 .407 .588 r
.4417 .34137 .44439 .37999 .45064 .37741 .44799 .33465 Metetra
.595 .396 .582 r
.44799 .33465 .45064 .37741 .4569 .37514 .45427 .32844 Metetra
.584 .385 .577 r
.45427 .32844 .4569 .37514 .46316 .37331 .46053 .32298 Metetra
.574 .375 .573 r
.46053 .32298 .46316 .37331 .46942 .37201 .46677 .31849 Metetra
.564 .365 .569 r
.46677 .31849 .46942 .37201 .4757 .37126 .473 .31509 Metetra
.555 .356 .567 r
.473 .31509 .4757 .37126 .48199 .37104 .47922 .31289 Metetra
.546 .349 .564 r
.47922 .31289 .48199 .37104 .48829 .37129 .48544 .31188 Metetra
.538 .342 .563 r
.48544 .31188 .48829 .37129 .49462 .37186 .49167 .31201 Metetra
.531 .337 .562 r
.49167 .31201 .49462 .37186 .50097 .37261 .49791 .31317 Metetra
.526 .333 .562 r
.49791 .31317 .50097 .37261 .50735 .37335 .50418 .31516 Metetra
.521 .33 .562 r
.50418 .31516 .50735 .37335 .51375 .37389 .51047 .31777 Metetra
.518 .329 .564 r
.51047 .31777 .51375 .37389 .52018 .37404 .5168 .32075 Metetra
.516 .329 .566 r
.5168 .32075 .52018 .37404 .52664 .37365 .52316 .32382 Metetra
.516 .332 .57 r
.52316 .32382 .52664 .37365 .53311 .37256 .52956 .32672 Metetra
.518 .337 .574 r
.52956 .32672 .53311 .37256 .5396 .3707 .53599 .32922 Metetra
.523 .344 .58 r
.53599 .32922 .5396 .3707 .54611 .36799 .54245 .3311 Metetra
.53 .355 .589 r
.54245 .3311 .54611 .36799 .55262 .36444 .54894 .3322 Metetra
.54 .37 .599 r
.54894 .3322 .55262 .36444 .55913 .36008 .55545 .33241 Metetra
.554 .389 .612 r
.55545 .33241 .55913 .36008 .56563 .35496 .56197 .33165 Metetra
.573 .414 .628 r
.56197 .33165 .56563 .35496 .57213 .3492 .5685 .32994 Metetra
.596 .446 .648 r
.5685 .32994 .57213 .3492 .57863 .34289 .57503 .32729 Metetra
.625 .485 .672 r
.57503 .32729 .57863 .34289 .58511 .33618 .58156 .3238 Metetra
.659 .534 .7 r
.58156 .3238 .58511 .33618 .59158 .32918 .58809 .31956 Metetra
.699 .592 .733 r
.58809 .31956 .59158 .32918 .59805 .32202 .59461 .3147 Metetra
.741 .657 .768 r
.59461 .3147 .59805 .32202 .60451 .31482 .60113 .30936 Metetra
.782 .727 .802 r
.60113 .30936 .60451 .31482 .61096 .30767 .60763 .30367 Metetra
.816 .795 .832 r
.60763 .30367 .61096 .30767 .61742 .30068 .61413 .29775 Metetra
.84 .853 .854 r
.61413 .29775 .61742 .30068 .62387 .29389 .62063 .29174 Metetra
.852 .898 .869 r
.62063 .29174 .62387 .29389 .63034 .28737 .62713 .28572 Metetra
.852 .928 .878 r
.62713 .28572 .63034 .28737 .63681 .28116 .63363 .27978 Metetra
.846 .946 .884 r
.63363 .27978 .63681 .28116 .64329 .27526 .64014 .274 Metetra
.837 .953 .892 r
.64014 .274 .64329 .27526 .64979 .2697 .64666 .26842 Metetra
.826 .954 .9 r
.64666 .26842 .64979 .2697 .6563 .26448 .65318 .26307 Metetra
.814 .949 .909 r
.65318 .26307 .6563 .26448 .66283 .25957 .65972 .25798 Metetra
.803 .939 .918 r
.65972 .25798 .66283 .25957 .66937 .25497 .66628 .25316 Metetra
.791 .926 .925 r
.66628 .25316 .66937 .25497 .67594 .25065 .67286 .24859 Metetra
.778 .911 .931 r
.67286 .24859 .67594 .25065 .68253 .24659 .67945 .24428 Metetra
.766 .894 .934 r
.67945 .24428 .68253 .24659 .68914 .24277 .68606 .24022 Metetra
.753 .876 .935 r
.68606 .24022 .68914 .24277 .69577 .23917 .6927 .23637 Metetra
.742 .859 .935 r
.6927 .23637 .69577 .23917 .70242 .23575 .69935 .23273 Metetra
.731 .843 .934 r
.69935 .23273 .70242 .23575 .7091 .23249 .70603 .22927 Metetra
.721 .828 .932 r
.70603 .22927 .7091 .23249 .71579 .22937 .71273 .22597 Metetra
.712 .815 .929 r
.71273 .22597 .71579 .22937 .7225 .22638 .71945 .22281 Metetra
.704 .803 .927 r
.71945 .22281 .7225 .22638 .72924 .22348 .72619 .21977 Metetra
.697 .793 .924 r
.72619 .21977 .72924 .22348 .736 .22067 .73295 .21684 Metetra
.691 .784 .922 r
.73295 .21684 .736 .22067 .74277 .21794 .73973 .214 Metetra
.687 .777 .92 r
.73973 .214 .74277 .21794 .74957 .21526 .74653 .21123 Metetra
.682 .77 .918 r
.74653 .21123 .74957 .21526 .75638 .21263 .75335 .20852 Metetra
.679 .765 .916 r
.75335 .20852 .75638 .21263 .76321 .21004 .76019 .20586 Metetra
.676 .761 .915 r
.76019 .20586 .76321 .21004 .77006 .20748 .76705 .20324 Metetra
.674 .757 .913 r
.76705 .20324 .77006 .20748 .77693 .20495 .77393 .20066 Metetra
.672 .754 .912 r
.77393 .20066 .77693 .20495 .78382 .20244 .78083 .1981 Metetra
.67 .752 .912 r
.78083 .1981 .78382 .20244 .79072 .19993 .78774 .19556 Metetra
.669 .75 .911 r
.78774 .19556 .79072 .19993 .79765 .19744 .79467 .19304 Metetra
.668 .748 .91 r
.79467 .19304 .79765 .19744 .80459 .19496 .80162 .19053 Metetra
.667 .747 .91 r
.80162 .19053 .80459 .19496 .81155 .19248 .80859 .18803 Metetra
.663 .741 .908 r
.18729 .4009 .19118 .40451 .19675 .40256 .19287 .39894 Metetra
.663 .741 .908 r
.19287 .39894 .19675 .40256 .20234 .4006 .19847 .39697 Metetra
.663 .741 .908 r
.19847 .39697 .20234 .4006 .20794 .39864 .20408 .39501 Metetra
.663 .742 .909 r
.20408 .39501 .20794 .39864 .21355 .39668 .2097 .39304 Metetra
.662 .742 .909 r
.2097 .39304 .21355 .39668 .21918 .39471 .21533 .39108 Metetra
.662 .742 .91 r
.21533 .39108 .21918 .39471 .22481 .39275 .22097 .38912 Metetra
.661 .742 .91 r
.22097 .38912 .22481 .39275 .23046 .3908 .22662 .38717 Metetra
.66 .743 .911 r
.22662 .38717 .23046 .3908 .23612 .38885 .23228 .38524 Metetra
.658 .743 .913 r
.23228 .38524 .23612 .38885 .24179 .38692 .23796 .38332 Metetra
.655 .744 .915 r
.23796 .38332 .24179 .38692 .24747 .38501 .24364 .38144 Metetra
.652 .745 .918 r
.24364 .38144 .24747 .38501 .25316 .38313 .24933 .3796 Metetra
.647 .747 .922 r
.24933 .3796 .25316 .38313 .25885 .38129 .25503 .37782 Metetra
.641 .749 .927 r
.25503 .37782 .25885 .38129 .26456 .37951 .26074 .37612 Metetra
.632 .752 .934 r
.26074 .37612 .26456 .37951 .27027 .37782 .26645 .37452 Metetra
.619 .755 .943 r
.26645 .37452 .27027 .37782 .27599 .37622 .27217 .37305 Metetra
.602 .758 .953 r
.27217 .37305 .27599 .37622 .28171 .37476 .27788 .37175 Metetra
.577 .761 .966 r
.27788 .37175 .28171 .37476 .28744 .37346 .2836 .37065 Metetra
.543 .763 .979 r
.2836 .37065 .28744 .37346 .29316 .37237 .28931 .36979 Metetra
.492 .761 .99 r
.28931 .36979 .29316 .37237 .29888 .37151 .29502 .36921 Metetra
.42 .749 .994 r
.29502 .36921 .29888 .37151 .3046 .37094 .30073 .36896 Metetra
.317 .719 .979 r
.30073 .36896 .3046 .37094 .31032 .37068 .30643 .36905 Metetra
.179 .66 .929 r
.30643 .36905 .31032 .37068 .31603 .37076 .31213 .36951 Metetra
.016 .565 .831 r
.31213 .36951 .31603 .37076 .32174 .37122 .31782 .37036 Metetra
0 .445 .694 r
.31782 .37036 .32174 .37122 .32745 .37204 .32351 .37159 Metetra
.283 0 0 r
.32351 .37159 .32745 .37204 .33316 .37321 .32921 .37315 Metetra
.38 0 0 r
.32921 .37315 .33316 .37321 .33888 .3747 .33492 .37501 Metetra
.442 0 0 r
.33492 .37501 .33888 .3747 .34461 .37644 .34064 .37706 Metetra
.473 0 0 r
.34064 .37706 .34461 .37644 .35036 .37833 .34638 .37921 Metetra
.482 0 0 r
.34638 .37921 .35036 .37833 .35613 .38024 .35216 .38132 Metetra
.468 0 0 r
.35216 .38132 .35613 .38024 .36194 .38203 .35797 .38324 Metetra
.431 0 0 r
.35797 .38324 .36194 .38203 .36779 .38353 .36383 .3848 Metetra
.365 0 0 r
.36383 .3848 .36779 .38353 .37369 .38456 .36975 .38584 Metetra
.26 0 0 r
.36975 .38584 .37369 .38456 .37964 .38496 .37571 .38621 Metetra
.106 0 0 r
.37571 .38621 .37964 .38496 .38566 .38456 .38174 .38576 Metetra
.38174 .38576 .38566 .38456 .39172 .38324 .38783 .3844 Metetra
.316 .797 .732 r
.38783 .3844 .39172 .38324 .39785 .38092 .39397 .38204 Metetra
.512 .91 .805 r
.39397 .38204 .39785 .38092 .40403 .37756 .40017 .37867 Metetra
.656 .97 .832 r
.40017 .37867 .40403 .37756 .41025 .37319 .40641 .37432 Metetra
.751 .994 .832 r
.40641 .37432 .41025 .37319 .41651 .3679 .41269 .36904 Metetra
.811 1 .822 r
.41269 .36904 .41651 .3679 .42279 .36186 .419 .36297 Metetra
.849 .998 .811 r
.419 .36297 .42279 .36186 .42909 .35525 .42533 .35624 Metetra
.874 .992 .806 r
.42533 .35624 .42909 .35525 .4354 .34833 .43167 .34906 Metetra
.891 .984 .808 r
.43167 .34906 .4354 .34833 .4417 .34137 .43801 .34164 Metetra
.899 .969 .817 r
.43801 .34164 .4417 .34137 .44799 .33465 .44434 .33419 Metetra
.898 .943 .83 r
.44434 .33419 .44799 .33465 .45427 .32844 .45066 .32695 Metetra
.88 .898 .839 r
.45066 .32695 .45427 .32844 .46053 .32298 .45697 .32013 Metetra
.843 .831 .836 r
.45697 .32013 .46053 .32298 .46677 .31849 .46326 .31394 Metetra
.789 .749 .816 r
.46326 .31394 .46677 .31849 .473 .31509 .46953 .30856 Metetra
.728 .664 .786 r
.46953 .30856 .473 .31509 .47922 .31289 .47579 .30411 Metetra
.67 .586 .752 r
.47579 .30411 .47922 .31289 .48544 .31188 .48204 .30071 Metetra
.621 .521 .719 r
.48204 .30071 .48544 .31188 .49167 .31201 .48829 .29838 Metetra
.582 .47 .692 r
.48829 .29838 .49167 .31201 .49791 .31317 .49454 .29712 Metetra
.552 .432 .67 r
.49454 .29712 .49791 .31317 .50418 .31516 .50081 .29688 Metetra
.531 .404 .652 r
.50081 .29688 .50418 .31516 .51047 .31777 .50709 .29754 Metetra
.516 .384 .64 r
.50709 .29754 .51047 .31777 .5168 .32075 .51339 .29895 Metetra
.507 .372 .631 r
.51339 .29895 .5168 .32075 .52316 .32382 .51972 .30091 Metetra
.502 .364 .626 r
.51972 .30091 .52316 .32382 .52956 .32672 .52608 .30321 Metetra
.501 .362 .623 r
.52608 .30321 .52956 .32672 .53599 .32922 .53248 .30563 Metetra
.503 .363 .624 r
.53248 .30563 .53599 .32922 .54245 .3311 .53891 .30793 Metetra
.508 .369 .626 r
.53891 .30793 .54245 .3311 .54894 .3322 .54537 .30992 Metetra
.517 .378 .631 r
.54537 .30992 .54894 .3322 .55545 .33241 .55186 .31142 Metetra
.529 .391 .638 r
.55186 .31142 .55545 .33241 .56197 .33165 .55837 .31226 Metetra
.543 .409 .648 r
.55837 .31226 .56197 .33165 .5685 .32994 .5649 .31237 Metetra
.561 .431 .66 r
.5649 .31237 .5685 .32994 .57503 .32729 .57145 .31166 Metetra
.583 .458 .675 r
.57145 .31166 .57503 .32729 .58156 .3238 .578 .31014 Metetra
.608 .49 .693 r
.578 .31014 .58156 .3238 .58809 .31956 .58456 .30782 Metetra
.636 .527 .714 r
.58456 .30782 .58809 .31956 .59461 .3147 .59111 .30477 Metetra
.666 .57 .737 r
.59111 .30477 .59461 .3147 .60113 .30936 .59767 .30106 Metetra
.698 .616 .761 r
.59767 .30106 .60113 .30936 .60763 .30367 .60422 .29681 Metetra
.73 .666 .786 r
.60422 .29681 .60763 .30367 .61413 .29775 .61076 .29212 Metetra
.76 .715 .811 r
.61076 .29212 .61413 .29775 .62063 .29174 .6173 .2871 Metetra
.785 .762 .833 r
.6173 .2871 .62063 .29174 .62713 .28572 .62384 .28188 Metetra
.803 .804 .852 r
.62384 .28188 .62713 .28572 .63363 .27978 .63038 .27654 Metetra
.815 .838 .867 r
.63038 .27654 .63363 .27978 .64014 .274 .63692 .27119 Metetra
.819 .864 .88 r
.63692 .27119 .64014 .274 .64666 .26842 .64346 .26588 Metetra
.819 .881 .89 r
.64346 .26588 .64666 .26842 .65318 .26307 .65001 .26068 Metetra
.813 .891 .899 r
.65001 .26068 .65318 .26307 .65972 .25798 .65657 .25564 Metetra
.806 .894 .907 r
.65657 .25564 .65972 .25798 .66628 .25316 .66314 .25079 Metetra
.796 .893 .913 r
.66314 .25079 .66628 .25316 .67286 .24859 .66973 .24614 Metetra
.785 .887 .919 r
.66973 .24614 .67286 .24859 .67945 .24428 .67634 .24171 Metetra
.773 .879 .923 r
.67634 .24171 .67945 .24428 .68606 .24022 .68296 .23749 Metetra
.762 .868 .926 r
.68296 .23749 .68606 .24022 .6927 .23637 .6896 .23348 Metetra
.75 .856 .928 r
.6896 .23348 .6927 .23637 .69935 .23273 .69627 .22967 Metetra
.739 .844 .928 r
.69627 .22967 .69935 .23273 .70603 .22927 .70295 .22605 Metetra
.729 .832 .928 r
.70295 .22605 .70603 .22927 .71273 .22597 .70965 .22259 Metetra
.72 .82 .927 r
.70965 .22259 .71273 .22597 .71945 .22281 .71638 .21929 Metetra
.711 .809 .926 r
.71638 .21929 .71945 .22281 .72619 .21977 .72312 .21611 Metetra
.704 .799 .924 r
.72312 .21611 .72619 .21977 .73295 .21684 .72989 .21306 Metetra
.697 .79 .922 r
.72989 .21306 .73295 .21684 .73973 .214 .73668 .21011 Metetra
.692 .782 .92 r
.73668 .21011 .73973 .214 .74653 .21123 .74349 .20724 Metetra
.687 .776 .919 r
.74349 .20724 .74653 .21123 .75335 .20852 .75031 .20445 Metetra
.683 .77 .917 r
.75031 .20445 .75335 .20852 .76019 .20586 .75716 .20171 Metetra
.679 .765 .916 r
.75716 .20171 .76019 .20586 .76705 .20324 .76403 .19903 Metetra
.676 .761 .914 r
.76403 .19903 .76705 .20324 .77393 .20066 .77092 .19639 Metetra
.674 .757 .913 r
.77092 .19639 .77393 .20066 .78083 .1981 .77782 .19378 Metetra
.672 .754 .912 r
.77782 .19378 .78083 .1981 .78774 .19556 .78475 .1912 Metetra
.67 .752 .912 r
.78475 .1912 .78774 .19556 .79467 .19304 .79169 .18864 Metetra
.669 .75 .911 r
.79169 .18864 .79467 .19304 .80162 .19053 .79865 .1861 Metetra
.668 .748 .91 r
.79865 .1861 .80162 .19053 .80859 .18803 .80563 .18357 Metetra
.663 .741 .908 r
.18339 .39727 .18729 .4009 .19287 .39894 .18898 .3953 Metetra
.663 .742 .908 r
.18898 .3953 .19287 .39894 .19847 .39697 .19458 .39333 Metetra
.663 .742 .909 r
.19458 .39333 .19847 .39697 .20408 .39501 .2002 .39137 Metetra
.662 .742 .909 r
.2002 .39137 .20408 .39501 .2097 .39304 .20582 .3894 Metetra
.662 .742 .91 r
.20582 .3894 .2097 .39304 .21533 .39108 .21146 .38744 Metetra
.661 .742 .91 r
.21146 .38744 .21533 .39108 .22097 .38912 .21711 .38549 Metetra
.66 .743 .912 r
.21711 .38549 .22097 .38912 .22662 .38717 .22276 .38355 Metetra
.658 .743 .913 r
.22276 .38355 .22662 .38717 .23228 .38524 .22843 .38163 Metetra
.655 .744 .915 r
.22843 .38163 .23228 .38524 .23796 .38332 .23411 .37975 Metetra
.652 .745 .918 r
.23411 .37975 .23796 .38332 .24364 .38144 .2398 .3779 Metetra
.647 .747 .922 r
.2398 .3779 .24364 .38144 .24933 .3796 .24549 .37612 Metetra
.641 .749 .927 r
.24549 .37612 .24933 .3796 .25503 .37782 .25119 .37442 Metetra
.632 .752 .934 r
.25119 .37442 .25503 .37782 .26074 .37612 .2569 .37282 Metetra
.619 .755 .943 r
.2569 .37282 .26074 .37612 .26645 .37452 .2626 .37135 Metetra
.602 .758 .953 r
.2626 .37135 .26645 .37452 .27217 .37305 .26831 .37005 Metetra
.577 .762 .966 r
.26831 .37005 .27217 .37305 .27788 .37175 .27402 .36895 Metetra
.541 .763 .979 r
.27402 .36895 .27788 .37175 .2836 .37065 .27973 .36809 Metetra
.49 .761 .991 r
.27973 .36809 .2836 .37065 .28931 .36979 .28543 .36751 Metetra
.415 .749 .994 r
.28543 .36751 .28931 .36979 .29502 .36921 .29112 .36726 Metetra
.308 .717 .977 r
.29112 .36726 .29502 .36921 .30073 .36896 .29681 .36737 Metetra
.164 .653 .921 r
.29681 .36737 .30073 .36896 .30643 .36905 .30249 .36786 Metetra
0 .549 .812 r
.30249 .36786 .30643 .36905 .31213 .36951 .30817 .36875 Metetra
.179 0 0 r
.30817 .36875 .31213 .36951 .31782 .37036 .31384 .37004 Metetra
.32 0 0 r
.31384 .37004 .31782 .37036 .32351 .37159 .31952 .3717 Metetra
.419 0 0 r
.31952 .3717 .32351 .37159 .32921 .37315 .3252 .37369 Metetra
.483 0 0 r
.3252 .37369 .32921 .37315 .33492 .37501 .33089 .37594 Metetra
.52 0 0 r
.33089 .37594 .33492 .37501 .34064 .37706 .3366 .37835 Metetra
.536 0 0 r
.3366 .37835 .34064 .37706 .34638 .37921 .34234 .38082 Metetra
.536 0 0 r
.34234 .38082 .34638 .37921 .35216 .38132 .34811 .38321 Metetra
.523 0 0 r
.34811 .38321 .35216 .38132 .35797 .38324 .35393 .38538 Metetra
.497 0 0 r
.35393 .38538 .35797 .38324 .36383 .3848 .35979 .3872 Metetra
.457 0 0 r
.35979 .3872 .36383 .3848 .36975 .38584 .3657 .38852 Metetra
.405 0 0 r
.3657 .38852 .36975 .38584 .37571 .38621 .37167 .38923 Metetra
.343 0 0 r
.37167 .38923 .37571 .38621 .38174 .38576 .3777 .38925 Metetra
.281 0 0 r
.3777 .38925 .38174 .38576 .38783 .3844 .38378 .38852 Metetra
.228 0 0 r
.38378 .38852 .38783 .3844 .39397 .38204 .38991 .387 Metetra
.196 0 0 r
.38991 .387 .39397 .38204 .40017 .37867 .39609 .38472 Metetra
.189 0 0 r
.39609 .38472 .40017 .37867 .40641 .37432 .40231 .38171 Metetra
.203 0 .065 r
.40231 .38171 .40641 .37432 .41269 .36904 .40857 .37804 Metetra
.231 0 .134 r
.40857 .37804 .41269 .36904 .419 .36297 .41485 .37381 Metetra
.264 0 .196 r
.41485 .37381 .419 .36297 .42533 .35624 .42116 .36912 Metetra
.298 0 .248 r
.42116 .36912 .42533 .35624 .43167 .34906 .42747 .36408 Metetra
.328 .026 .29 r
.42747 .36408 .43167 .34906 .43801 .34164 .4338 .35882 Metetra
.355 .062 .322 r
.4338 .35882 .43801 .34164 .44434 .33419 .44014 .35343 Metetra
.377 .092 .347 r
.44014 .35343 .44434 .33419 .45066 .32695 .44647 .34804 Metetra
.396 .115 .365 r
.44647 .34804 .45066 .32695 .45697 .32013 .45281 .34275 Metetra
.411 .134 .379 r
.45281 .34275 .45697 .32013 .46326 .31394 .45914 .33766 Metetra
.424 .148 .388 r
.45914 .33766 .46326 .31394 .46953 .30856 .46547 .33287 Metetra
.435 .159 .395 r
.46547 .33287 .46953 .30856 .47579 .30411 .4718 .32846 Metetra
.444 .167 .398 r
.4718 .32846 .47579 .30411 .48204 .30071 .47813 .32449 Metetra
.452 .173 .398 r
.47813 .32449 .48204 .30071 .48829 .29838 .48445 .32104 Metetra
.459 .175 .394 r
.48445 .32104 .48829 .29838 .49454 .29712 .49079 .31813 Metetra
.465 .175 .387 r
.49079 .31813 .49454 .29712 .50081 .29688 .49712 .31579 Metetra
.47 .171 .376 r
.49712 .31579 .50081 .29688 .50709 .29754 .50347 .314 Metetra
.473 .162 .358 r
.50347 .314 .50709 .29754 .51339 .29895 .50983 .31272 Metetra
.473 .146 .331 r
.50983 .31272 .51339 .29895 .51972 .30091 .51621 .3119 Metetra
.469 .119 .288 r
.51621 .3119 .51972 .30091 .52608 .30321 .52261 .31144 Metetra
.456 .071 .219 r
.52261 .31144 .52608 .30321 .53248 .30563 .52904 .31122 Metetra
.422 0 .101 r
.52904 .31122 .53248 .30563 .53891 .30793 .53548 .31112 Metetra
.334 0 0 r
.53548 .31112 .53891 .30793 .54537 .30992 .54195 .311 Metetra
.119 0 0 r
.54195 .311 .54537 .30992 .55186 .31142 .54845 .31074 Metetra
.23 .737 .888 r
.54845 .31074 .55186 .31142 .55837 .31226 .55496 .31019 Metetra
.474 .804 1 r
.55496 .31019 .55837 .31226 .5649 .31237 .56149 .30927 Metetra
.582 .78 .974 r
.56149 .30927 .5649 .31237 .57145 .31166 .56804 .30787 Metetra
.636 .758 .936 r
.56804 .30787 .57145 .31166 .578 .31014 .5746 .30596 Metetra
.672 .749 .908 r
.5746 .30596 .578 .31014 .58456 .30782 .58116 .3035 Metetra
.701 .752 .891 r
.58116 .3035 .58456 .30782 .59111 .30477 .58773 .3005 Metetra
.726 .763 .882 r
.58773 .3005 .59111 .30477 .59767 .30106 .5943 .29698 Metetra
.749 .779 .878 r
.5943 .29698 .59767 .30106 .60422 .29681 .60087 .293 Metetra
.769 .798 .877 r
.60087 .293 .60422 .29681 .61076 .29212 .60743 .28861 Metetra
.786 .819 .878 r
.60743 .28861 .61076 .29212 .6173 .2871 .614 .28391 Metetra
.8 .838 .88 r
.614 .28391 .6173 .2871 .62384 .28188 .62056 .27896 Metetra
.81 .856 .884 r
.62056 .27896 .62384 .28188 .63038 .27654 .62712 .27386 Metetra
.816 .871 .887 r
.62712 .27386 .63038 .27654 .63692 .27119 .63368 .26868 Metetra
.818 .883 .891 r
.63368 .26868 .63692 .27119 .64346 .26588 .64025 .26348 Metetra
.817 .891 .896 r
.64025 .26348 .64346 .26588 .65001 .26068 .64682 .25834 Metetra
.813 .895 .901 r
.64682 .25834 .65001 .26068 .65657 .25564 .6534 .2533 Metetra
.807 .896 .906 r
.6534 .2533 .65657 .25564 .66314 .25079 .65999 .2484 Metetra
.799 .893 .911 r
.65999 .2484 .66314 .25079 .66973 .24614 .66659 .24367 Metetra
.79 .888 .916 r
.66659 .24367 .66973 .24614 .67634 .24171 .67321 .23912 Metetra
.78 .88 .92 r
.67321 .23912 .67634 .24171 .68296 .23749 .67984 .23477 Metetra
.769 .871 .923 r
.67984 .23477 .68296 .23749 .6896 .23348 .68649 .23062 Metetra
.758 .86 .925 r
.68649 .23062 .6896 .23348 .69627 .22967 .69316 .22665 Metetra
.748 .849 .926 r
.69316 .22665 .69627 .22967 .70295 .22605 .69985 .22287 Metetra
.737 .838 .926 r
.69985 .22287 .70295 .22605 .70965 .22259 .70656 .21927 Metetra
.728 .826 .926 r
.70656 .21927 .70965 .22259 .71638 .21929 .7133 .21582 Metetra
.719 .816 .925 r
.7133 .21582 .71638 .21929 .72312 .21611 .72005 .21251 Metetra
.711 .806 .924 r
.72005 .21251 .72312 .21611 .72989 .21306 .72682 .20933 Metetra
.704 .797 .923 r
.72682 .20933 .72989 .21306 .73668 .21011 .73362 .20626 Metetra
.697 .788 .921 r
.73362 .20626 .73668 .21011 .74349 .20724 .74043 .2033 Metetra
.692 .781 .919 r
.74043 .2033 .74349 .20724 .75031 .20445 .74727 .20041 Metetra
.687 .775 .918 r
.74727 .20041 .75031 .20445 .75716 .20171 .75412 .1976 Metetra
.683 .769 .917 r
.75412 .1976 .75716 .20171 .76403 .19903 .761 .19485 Metetra
.68 .765 .915 r
.761 .19485 .76403 .19903 .77092 .19639 .76789 .19214 Metetra
.677 .76 .914 r
.76789 .19214 .77092 .19639 .77782 .19378 .77481 .18948 Metetra
.674 .757 .913 r
.77481 .18948 .77782 .19378 .78475 .1912 .78174 .18685 Metetra
.672 .754 .912 r
.78174 .18685 .78475 .1912 .79169 .18864 .78869 .18425 Metetra
.671 .752 .912 r
.78869 .18425 .79169 .18864 .79865 .1861 .79566 .18167 Metetra
.669 .75 .911 r
.79566 .18167 .79865 .1861 .80563 .18357 .80265 .17911 Metetra
.663 .742 .908 r
.17948 .39363 .18339 .39727 .18898 .3953 .18507 .39166 Metetra
.663 .742 .909 r
.18507 .39166 .18898 .3953 .19458 .39333 .19068 .38969 Metetra
.662 .742 .909 r
.19068 .38969 .19458 .39333 .2002 .39137 .1963 .38772 Metetra
.662 .742 .91 r
.1963 .38772 .2002 .39137 .20582 .3894 .20193 .38575 Metetra
.661 .742 .91 r
.20193 .38575 .20582 .3894 .21146 .38744 .20757 .3838 Metetra
.659 .743 .912 r
.20757 .3838 .21146 .38744 .21711 .38549 .21323 .38186 Metetra
.658 .743 .913 r
.21323 .38186 .21711 .38549 .22276 .38355 .21889 .37994 Metetra
.655 .744 .915 r
.21889 .37994 .22276 .38355 .22843 .38163 .22456 .37805 Metetra
.652 .746 .918 r
.22456 .37805 .22843 .38163 .23411 .37975 .23024 .37621 Metetra
.647 .747 .922 r
.23024 .37621 .23411 .37975 .2398 .3779 .23593 .37442 Metetra
.641 .749 .928 r
.23593 .37442 .2398 .3779 .24549 .37612 .24162 .37271 Metetra
.631 .752 .934 r
.24162 .37271 .24549 .37612 .25119 .37442 .24732 .37111 Metetra
.619 .755 .943 r
.24732 .37111 .25119 .37442 .2569 .37282 .25302 .36964 Metetra
.601 .758 .954 r
.25302 .36964 .2569 .37282 .2626 .37135 .25873 .36834 Metetra
.577 .762 .966 r
.25873 .36834 .2626 .37135 .26831 .37005 .26442 .36724 Metetra
.541 .763 .979 r
.26442 .36724 .26831 .37005 .27402 .36895 .27012 .36638 Metetra
.49 .761 .991 r
.27012 .36638 .27402 .36895 .27973 .36809 .27581 .3658 Metetra
.416 .749 .994 r
.27581 .3658 .27973 .36809 .28543 .36751 .2815 .36554 Metetra
.309 .717 .977 r
.2815 .36554 .28543 .36751 .29112 .36726 .28717 .36565 Metetra
.167 .654 .922 r
.28717 .36565 .29112 .36726 .29681 .36737 .29284 .36614 Metetra
0 .552 .818 r
.29284 .36614 .29681 .36737 .30249 .36786 .2985 .36703 Metetra
.171 0 0 r
.2985 .36703 .30249 .36786 .30817 .36875 .30416 .36832 Metetra
.309 0 0 r
.30416 .36832 .30817 .36875 .31384 .37004 .30982 .36999 Metetra
.408 0 0 r
.30982 .36999 .31384 .37004 .31952 .3717 .31548 .37199 Metetra
.471 0 0 r
.31548 .37199 .31952 .3717 .3252 .37369 .32115 .37426 Metetra
.506 0 0 r
.32115 .37426 .3252 .37369 .33089 .37594 .32684 .3767 Metetra
.52 0 0 r
.32684 .3767 .33089 .37594 .3366 .37835 .33256 .3792 Metetra
.514 0 0 r
.33256 .3792 .3366 .37835 .34234 .38082 .33831 .38162 Metetra
.486 0 0 r
.33831 .38162 .34234 .38082 .34811 .38321 .3441 .38384 Metetra
.43 0 0 r
.3441 .38384 .34811 .38321 .35393 .38538 .34995 .38569 Metetra
.327 0 0 r
.34995 .38569 .35393 .38538 .35979 .3872 .35584 .38707 Metetra
.154 0 0 r
.35584 .38707 .35979 .3872 .3657 .38852 .3618 .38785 Metetra
.096 .644 .83 r
.3618 .38785 .3657 .38852 .37167 .38923 .36781 .38795 Metetra
.358 .787 .97 r
.36781 .38795 .37167 .38923 .3777 .38925 .37387 .38733 Metetra
.543 .834 .999 r
.37387 .38733 .3777 .38925 .38378 .38852 .37999 .38597 Metetra
.645 .825 .97 r
.37999 .38597 .38378 .38852 .38991 .387 .38616 .38391 Metetra
.697 .804 .931 r
.38616 .38391 .38991 .387 .39609 .38472 .39237 .38121 Metetra
.725 .786 .9 r
.39237 .38121 .39609 .38472 .40231 .38171 .39861 .37797 Metetra
.742 .777 .881 r
.39861 .37797 .40231 .38171 .40857 .37804 .40487 .37431 Metetra
.755 .78 .874 r
.40487 .37431 .40857 .37804 .41485 .37381 .41116 .37035 Metetra
.765 .797 .879 r
.41116 .37035 .41485 .37381 .42116 .36912 .41746 .36623 Metetra
.774 .83 .896 r
.41746 .36623 .42116 .36912 .42747 .36408 .42376 .36208 Metetra
.777 .885 .923 r
.42376 .36208 .42747 .36408 .4338 .35882 .43007 .35799 Metetra
.75 .951 .942 r
.43007 .35799 .4338 .35882 .44014 .35343 .43638 .35405 Metetra
.615 .958 .868 r
.43638 .35405 .44014 .35343 .44647 .34804 .4427 .35033 Metetra
.4427 .35033 .44647 .34804 .45281 .34275 .44901 .34688 Metetra
.02 0 0 r
.44901 .34688 .45281 .34275 .45914 .33766 .45533 .3437 Metetra
.21 0 .01 r
.45533 .3437 .45914 .33766 .46547 .33287 .46166 .34082 Metetra
.313 0 .142 r
.46166 .34082 .46547 .33287 .4718 .32846 .46799 .33822 Metetra
.372 .013 .22 r
.46799 .33822 .4718 .32846 .47813 .32449 .47433 .33588 Metetra
.407 .065 .269 r
.47433 .33588 .47813 .32449 .48445 .32104 .48068 .33378 Metetra
.43 .098 .299 r
.48068 .33378 .48445 .32104 .49079 .31813 .48704 .3319 Metetra
.445 .119 .318 r
.48704 .3319 .49079 .31813 .49712 .31579 .49342 .33021 Metetra
.454 .132 .329 r
.49342 .33021 .49712 .31579 .50347 .314 .49981 .32868 Metetra
.459 .138 .334 r
.49981 .32868 .50347 .314 .50983 .31272 .50622 .32727 Metetra
.461 .139 .333 r
.50622 .32727 .50983 .31272 .51621 .3119 .51265 .32595 Metetra
.46 .134 .327 r
.51265 .32595 .51621 .3119 .52261 .31144 .5191 .32468 Metetra
.455 .124 .314 r
.5191 .32468 .52261 .31144 .52904 .31122 .52556 .32339 Metetra
.445 .106 .296 r
.52556 .32339 .52904 .31122 .53548 .31112 .53205 .32204 Metetra
.429 .079 .268 r
.53205 .32204 .53548 .31112 .54195 .311 .53855 .32056 Metetra
.404 .04 .229 r
.53855 .32056 .54195 .311 .54845 .31074 .54507 .31889 Metetra
.365 0 .174 r
.54507 .31889 .54845 .31074 .55496 .31019 .55161 .31696 Metetra
.308 0 .097 r
.55161 .31696 .55496 .31019 .56149 .30927 .55815 .31473 Metetra
.221 0 0 r
.55815 .31473 .56149 .30927 .56804 .30787 .56472 .31215 Metetra
.094 0 0 r
.56472 .31215 .56804 .30787 .5746 .30596 .57129 .30918 Metetra
.57129 .30918 .5746 .30596 .58116 .3035 .57786 .30581 Metetra
.57786 .30581 .58116 .3035 .58773 .3005 .58444 .30204 Metetra
.467 .867 .694 r
.58444 .30204 .58773 .3005 .5943 .29698 .59102 .2979 Metetra
.608 .95 .798 r
.59102 .2979 .5943 .29698 .60087 .293 .5976 .29341 Metetra
.7 .984 .852 r
.5976 .29341 .60087 .293 .60743 .28861 .60418 .28862 Metetra
.755 .992 .878 r
.60418 .28862 .60743 .28861 .614 .28391 .61076 .28359 Metetra
.787 .989 .888 r
.61076 .28359 .614 .28391 .62056 .27896 .61733 .27837 Metetra
.806 .983 .893 r
.61733 .27837 .62056 .27896 .62712 .27386 .62391 .27304 Metetra
.816 .975 .896 r
.62391 .27304 .62712 .27386 .63368 .26868 .63049 .26764 Metetra
.821 .966 .899 r
.63049 .26764 .63368 .26868 .64025 .26348 .63707 .26226 Metetra
.822 .958 .902 r
.63707 .26226 .64025 .26348 .64682 .25834 .64365 .25692 Metetra
.819 .949 .906 r
.64365 .25692 .64682 .25834 .6534 .2533 .65024 .25169 Metetra
.814 .939 .91 r
.65024 .25169 .6534 .2533 .65999 .2484 .65684 .24659 Metetra
.807 .929 .914 r
.65684 .24659 .65999 .2484 .66659 .24367 .66346 .24166 Metetra
.799 .918 .918 r
.66346 .24166 .66659 .24367 .67321 .23912 .67008 .23691 Metetra
.789 .905 .922 r
.67008 .23691 .67321 .23912 .67984 .23477 .67672 .23236 Metetra
.779 .892 .925 r
.67672 .23236 .67984 .23477 .68649 .23062 .68338 .228 Metetra
.768 .879 .927 r
.68338 .228 .68649 .23062 .69316 .22665 .69006 .22384 Metetra
.757 .866 .928 r
.69006 .22384 .69316 .22665 .69985 .22287 .69676 .21988 Metetra
.747 .852 .928 r
.69676 .21988 .69985 .22287 .70656 .21927 .70347 .21609 Metetra
.737 .84 .928 r
.70347 .21609 .70656 .21927 .7133 .21582 .71021 .21248 Metetra
.727 .827 .927 r
.71021 .21248 .7133 .21582 .72005 .21251 .71697 .20902 Metetra
.718 .816 .926 r
.71697 .20902 .72005 .21251 .72682 .20933 .72375 .2057 Metetra
.711 .806 .924 r
.72375 .2057 .72682 .20933 .73362 .20626 .73055 .20251 Metetra
.703 .797 .923 r
.73055 .20251 .73362 .20626 .74043 .2033 .73737 .19943 Metetra
.697 .788 .921 r
.73737 .19943 .74043 .2033 .74727 .20041 .74421 .19644 Metetra
.692 .781 .919 r
.74421 .19644 .74727 .20041 .75412 .1976 .75107 .19354 Metetra
.687 .775 .918 r
.75107 .19354 .75412 .1976 .761 .19485 .75796 .1907 Metetra
.683 .769 .917 r
.75796 .1907 .761 .19485 .76789 .19214 .76486 .18793 Metetra
.68 .765 .915 r
.76486 .18793 .76789 .19214 .77481 .18948 .77178 .1852 Metetra
.677 .761 .914 r
.77178 .1852 .77481 .18948 .78174 .18685 .77872 .18252 Metetra
.674 .757 .913 r
.77872 .18252 .78174 .18685 .78869 .18425 .78569 .17987 Metetra
.672 .754 .912 r
.78569 .17987 .78869 .18425 .79566 .18167 .79267 .17725 Metetra
.671 .752 .912 r
.79267 .17725 .79566 .18167 .80265 .17911 .79967 .17465 Metetra
.663 .742 .909 r
.17554 .38998 .17948 .39363 .18507 .39166 .18115 .38801 Metetra
.662 .742 .909 r
.18115 .38801 .18507 .39166 .19068 .38969 .18676 .38603 Metetra
.662 .742 .91 r
.18676 .38603 .19068 .38969 .1963 .38772 .19239 .38407 Metetra
.661 .742 .911 r
.19239 .38407 .1963 .38772 .20193 .38575 .19802 .38211 Metetra
.659 .743 .912 r
.19802 .38211 .20193 .38575 .20757 .3838 .20367 .38016 Metetra
.658 .744 .913 r
.20367 .38016 .20757 .3838 .21323 .38186 .20933 .37824 Metetra
.655 .744 .915 r
.20933 .37824 .21323 .38186 .21889 .37994 .21499 .37635 Metetra
.652 .746 .918 r
.21499 .37635 .21889 .37994 .22456 .37805 .22067 .37451 Metetra
.647 .747 .922 r
.22067 .37451 .22456 .37805 .23024 .37621 .22635 .37272 Metetra
.64 .749 .928 r
.22635 .37272 .23024 .37621 .23593 .37442 .23204 .37101 Metetra
.631 .752 .935 r
.23204 .37101 .23593 .37442 .24162 .37271 .23773 .36941 Metetra
.619 .755 .943 r
.23773 .36941 .24162 .37271 .24732 .37111 .24342 .36793 Metetra
.601 .758 .954 r
.24342 .36793 .24732 .37111 .25302 .36964 .24912 .36663 Metetra
.577 .762 .966 r
.24912 .36663 .25302 .36964 .25873 .36834 .25481 .36552 Metetra
.541 .763 .979 r
.25481 .36552 .25873 .36834 .26442 .36724 .2605 .36465 Metetra
.491 .761 .991 r
.2605 .36465 .26442 .36724 .27012 .36638 .26618 .36407 Metetra
.417 .749 .994 r
.26618 .36407 .27012 .36638 .27581 .3658 .27185 .36381 Metetra
.313 .718 .978 r
.27185 .36381 .27581 .3658 .2815 .36554 .27752 .3639 Metetra
.173 .657 .926 r
.27752 .3639 .2815 .36554 .28717 .36565 .28317 .36438 Metetra
.008 .559 .826 r
.28317 .36438 .28717 .36565 .29284 .36614 .28882 .36525 Metetra
.156 0 0 r
.28882 .36525 .29284 .36614 .2985 .36703 .29447 .36651 Metetra
.293 0 0 r
.29447 .36651 .2985 .36703 .30416 .36832 .30011 .36815 Metetra
.39 0 0 r
.30011 .36815 .30416 .36832 .30982 .36999 .30575 .37011 Metetra
.451 0 0 r
.30575 .37011 .30982 .36999 .31548 .37199 .31141 .37231 Metetra
.483 0 0 r
.31141 .37231 .31548 .37199 .32115 .37426 .31709 .37467 Metetra
.489 0 0 r
.31709 .37467 .32115 .37426 .32684 .3767 .32279 .37705 Metetra
.47 0 0 r
.32279 .37705 .32684 .3767 .33256 .3792 .32853 .37932 Metetra
.414 0 0 r
.32853 .37932 .33256 .3792 .33831 .38162 .33432 .38132 Metetra
.296 0 0 r
.33432 .38132 .33831 .38162 .3441 .38384 .34016 .3829 Metetra
0 .504 .75 r
.34016 .3829 .3441 .38384 .34995 .38569 .34606 .38391 Metetra
.233 .688 .951 r
.34606 .38391 .34995 .38569 .35584 .38707 .35202 .38422 Metetra
.482 .747 .987 r
.35202 .38422 .35584 .38707 .3618 .38785 .35804 .38373 Metetra
.607 .716 .922 r
.35804 .38373 .3618 .38785 .36781 .38795 .36413 .38237 Metetra
.658 .667 .848 r
.36413 .38237 .36781 .38795 .37387 .38733 .37028 .38014 Metetra
.677 .625 .789 r
.37028 .38014 .37387 .38733 .37999 .38597 .37648 .37705 Metetra
.682 .59 .746 r
.37648 .37705 .37999 .38597 .38616 .38391 .38273 .37317 Metetra
.681 .562 .715 r
.38273 .37317 .38616 .38391 .39237 .38121 .38901 .36862 Metetra
.676 .539 .691 r
.38901 .36862 .39237 .38121 .39861 .37797 .39532 .36353 Metetra
.669 .52 .673 r
.39532 .36353 .39861 .37797 .40487 .37431 .40165 .35808 Metetra
.66 .503 .66 r
.40165 .35808 .40487 .37431 .41116 .37035 .40798 .35244 Metetra
.651 .487 .649 r
.40798 .35244 .41116 .37035 .41746 .36623 .41431 .34679 Metetra
.641 .474 .641 r
.41431 .34679 .41746 .36623 .42376 .36208 .42064 .3413 Metetra
.631 .461 .635 r
.42064 .3413 .42376 .36208 .43007 .35799 .42697 .33614 Metetra
.62 .45 .63 r
.42697 .33614 .43007 .35799 .43638 .35405 .43328 .33143 Metetra
.61 .44 .627 r
.43328 .33143 .43638 .35405 .4427 .35033 .43958 .32727 Metetra
.599 .431 .626 r
.43958 .32727 .4427 .35033 .44901 .34688 .44587 .32373 Metetra
.589 .424 .626 r
.44587 .32373 .44901 .34688 .45533 .3437 .45215 .32086 Metetra
.579 .418 .627 r
.45215 .32086 .45533 .3437 .46166 .34082 .45844 .31865 Metetra
.57 .414 .63 r
.45844 .31865 .46166 .34082 .46799 .33822 .46472 .31709 Metetra
.561 .411 .636 r
.46472 .31709 .46799 .33822 .47433 .33588 .47101 .31612 Metetra
.552 .411 .643 r
.47101 .31612 .47433 .33588 .48068 .33378 .47732 .31567 Metetra
.544 .414 .654 r
.47732 .31567 .48068 .33378 .48704 .3319 .48364 .31566 Metetra
.535 .421 .67 r
.48364 .31566 .48704 .3319 .49342 .33021 .48997 .31599 Metetra
.528 .432 .69 r
.48997 .31599 .49342 .33021 .49981 .32868 .49634 .31654 Metetra
.52 .45 .718 r
.49634 .31654 .49981 .32868 .50622 .32727 .50272 .31722 Metetra
.512 .478 .755 r
.50272 .31722 .50622 .32727 .51265 .32595 .50914 .3179 Metetra
.504 .517 .804 r
.50914 .3179 .51265 .32595 .5191 .32468 .51558 .31849 Metetra
.494 .574 .865 r
.51558 .31849 .5191 .32468 .52556 .32339 .52205 .31888 Metetra
.478 .647 .932 r
.52205 .31888 .52556 .32339 .53205 .32204 .52854 .319 Metetra
.45 .727 .985 r
.52854 .319 .53205 .32204 .53855 .32056 .53506 .31875 Metetra
.408 .789 .991 r
.53506 .31875 .53855 .32056 .54507 .31889 .5416 .31808 Metetra
.361 .815 .939 r
.5416 .31808 .54507 .31889 .55161 .31696 .54816 .31693 Metetra
.331 .814 .859 r
.54816 .31693 .55161 .31696 .55815 .31473 .55473 .31528 Metetra
.329 .812 .79 r
.55473 .31528 .55815 .31473 .56472 .31215 .56132 .31308 Metetra
.354 .821 .746 r
.56132 .31308 .56472 .31215 .57129 .30918 .56792 .31035 Metetra
.398 .841 .728 r
.56792 .31035 .57129 .30918 .57786 .30581 .57452 .3071 Metetra
.455 .87 .728 r
.57452 .3071 .57786 .30581 .58444 .30204 .58112 .30334 Metetra
.518 .901 .74 r
.58112 .30334 .58444 .30204 .59102 .2979 .58772 .29913 Metetra
.579 .931 .758 r
.58772 .29913 .59102 .2979 .5976 .29341 .59432 .29451 Metetra
.636 .956 .778 r
.59432 .29451 .5976 .29341 .60418 .28862 .60092 .28955 Metetra
.684 .975 .797 r
.60092 .28955 .60418 .28862 .61076 .28359 .60752 .2843 Metetra
.724 .988 .815 r
.60752 .2843 .61076 .28359 .61733 .27837 .61412 .27885 Metetra
.755 .995 .832 r
.61412 .27885 .61733 .27837 .62391 .27304 .62071 .27327 Metetra
.779 .998 .847 r
.62071 .27327 .62391 .27304 .63049 .26764 .6273 .26761 Metetra
.796 .997 .861 r
.6273 .26761 .63049 .26764 .63707 .26226 .6339 .26195 Metetra
.806 .992 .874 r
.6339 .26195 .63707 .26226 .64365 .25692 .64049 .25633 Metetra
.812 .985 .886 r
.64049 .25633 .64365 .25692 .65024 .25169 .6471 .25082 Metetra
.814 .976 .897 r
.6471 .25082 .65024 .25169 .65684 .24659 .65371 .24543 Metetra
.811 .964 .906 r
.65371 .24543 .65684 .24659 .66346 .24166 .66033 .24022 Metetra
.806 .951 .914 r
.66033 .24022 .66346 .24166 .67008 .23691 .66696 .23519 Metetra
.799 .937 .92 r
.66696 .23519 .67008 .23691 .67672 .23236 .67361 .23037 Metetra
.79 .921 .925 r
.67361 .23037 .67672 .23236 .68338 .228 .68027 .22576 Metetra
.78 .905 .928 r
.68027 .22576 .68338 .228 .69006 .22384 .68696 .22136 Metetra
.769 .889 .93 r
.68696 .22136 .69006 .22384 .69676 .21988 .69366 .21716 Metetra
.758 .873 .931 r
.69366 .21716 .69676 .21988 .70347 .21609 .70038 .21316 Metetra
.748 .858 .931 r
.70038 .21316 .70347 .21609 .71021 .21248 .70712 .20935 Metetra
.737 .844 .93 r
.70712 .20935 .71021 .21248 .71697 .20902 .71388 .20571 Metetra
.728 .831 .929 r
.71388 .20571 .71697 .20902 .72375 .2057 .72067 .20222 Metetra
.719 .819 .927 r
.72067 .20222 .72375 .2057 .73055 .20251 .72747 .19888 Metetra
.711 .808 .925 r
.72747 .19888 .73055 .20251 .73737 .19943 .7343 .19566 Metetra
.704 .798 .923 r
.7343 .19566 .73737 .19943 .74421 .19644 .74115 .19256 Metetra
.698 .79 .922 r
.74115 .19256 .74421 .19644 .75107 .19354 .74802 .18955 Metetra
.692 .782 .92 r
.74802 .18955 .75107 .19354 .75796 .1907 .75491 .18662 Metetra
.688 .776 .918 r
.75491 .18662 .75796 .1907 .76486 .18793 .76182 .18376 Metetra
.683 .77 .917 r
.76182 .18376 .76486 .18793 .77178 .1852 .76875 .18097 Metetra
.68 .765 .915 r
.76875 .18097 .77178 .1852 .77872 .18252 .7757 .17822 Metetra
.677 .761 .914 r
.7757 .17822 .77872 .18252 .78569 .17987 .78267 .17552 Metetra
.675 .758 .913 r
.78267 .17552 .78569 .17987 .79267 .17725 .78966 .17284 Metetra
.673 .755 .912 r
.78966 .17284 .79267 .17725 .79967 .17465 .79667 .1702 Metetra
.662 .742 .909 r
.17159 .38632 .17554 .38998 .18115 .38801 .1772 .38435 Metetra
.662 .742 .91 r
.1772 .38435 .18115 .38801 .18676 .38603 .18282 .38238 Metetra
.661 .742 .911 r
.18282 .38238 .18676 .38603 .19239 .38407 .18845 .38041 Metetra
.659 .743 .912 r
.18845 .38041 .19239 .38407 .19802 .38211 .1941 .37847 Metetra
.658 .744 .913 r
.1941 .37847 .19802 .38211 .20367 .38016 .19975 .37654 Metetra
.655 .744 .916 r
.19975 .37654 .20367 .38016 .20933 .37824 .20541 .37465 Metetra
.652 .746 .919 r
.20541 .37465 .20933 .37824 .21499 .37635 .21108 .3728 Metetra
.647 .747 .923 r
.21108 .3728 .21499 .37635 .22067 .37451 .21675 .37101 Metetra
.64 .749 .928 r
.21675 .37101 .22067 .37451 .22635 .37272 .22244 .3693 Metetra
.631 .752 .935 r
.22244 .3693 .22635 .37272 .23204 .37101 .22812 .3677 Metetra
.619 .755 .943 r
.22812 .3677 .23204 .37101 .23773 .36941 .23381 .36622 Metetra
.601 .759 .954 r
.23381 .36622 .23773 .36941 .24342 .36793 .23949 .36491 Metetra
.577 .762 .966 r
.23949 .36491 .24342 .36793 .24912 .36663 .24518 .3638 Metetra
.542 .764 .979 r
.24518 .3638 .24912 .36663 .25481 .36552 .25086 .36293 Metetra
.491 .761 .991 r
.25086 .36293 .25481 .36552 .2605 .36465 .25653 .36234 Metetra
.418 .749 .994 r
.25653 .36234 .2605 .36465 .26618 .36407 .26219 .36207 Metetra
.314 .719 .978 r
.26219 .36207 .26618 .36407 .27185 .36381 .26784 .36215 Metetra
.176 .658 .927 r
.26784 .36215 .27185 .36381 .27752 .3639 .27349 .36262 Metetra
.013 .562 .829 r
.27349 .36262 .27752 .3639 .28317 .36438 .27912 .36347 Metetra
0 .44 .693 r
.27912 .36347 .28317 .36438 .28882 .36525 .28475 .36472 Metetra
.287 0 0 r
.28475 .36472 .28882 .36525 .29447 .36651 .29038 .36633 Metetra
.385 0 0 r
.29038 .36633 .29447 .36651 .30011 .36815 .29601 .36825 Metetra
.446 0 0 r
.29601 .36825 .30011 .36815 .30575 .37011 .30165 .37042 Metetra
.478 0 0 r
.30165 .37042 .30575 .37011 .31141 .37231 .30731 .37273 Metetra
.484 0 0 r
.30731 .37273 .31141 .37231 .31709 .37467 .313 .37506 Metetra
.464 0 0 r
.313 .37506 .31709 .37467 .32279 .37705 .31873 .37726 Metetra
.408 0 0 r
.31873 .37726 .32279 .37705 .32853 .37932 .3245 .37917 Metetra
.293 0 0 r
.3245 .37917 .32853 .37932 .33432 .38132 .33033 .38062 Metetra
0 .504 .725 r
.33033 .38062 .33432 .38132 .34016 .3829 .33622 .38148 Metetra
.222 .701 .935 r
.33622 .38148 .34016 .3829 .34606 .38391 .34218 .38158 Metetra
.485 .784 .997 r
.34218 .38158 .34606 .38391 .35202 .38422 .3482 .38083 Metetra
.626 .766 .946 r
.3482 .38083 .35202 .38422 .35804 .38373 .3543 .37914 Metetra
.687 .72 .874 r
.3543 .37914 .35804 .38373 .36413 .38237 .36046 .37648 Metetra
.711 .677 .815 r
.36046 .37648 .36413 .38237 .37028 .38014 .36668 .37285 Metetra
.72 .641 .77 r
.36668 .37285 .37028 .38014 .37648 .37705 .37296 .36832 Metetra
.72 .613 .736 r
.37296 .36832 .37648 .37705 .38273 .37317 .37927 .36297 Metetra
.717 .589 .712 r
.37927 .36297 .38273 .37317 .38901 .36862 .38562 .35693 Metetra
.711 .569 .693 r
.38562 .35693 .38901 .36862 .39532 .36353 .39199 .35035 Metetra
.703 .551 .678 r
.39199 .35035 .39532 .36353 .40165 .35808 .39837 .34341 Metetra
.694 .534 .666 r
.39837 .34341 .40165 .35808 .40798 .35244 .40475 .33629 Metetra
.683 .518 .656 r
.40475 .33629 .40798 .35244 .41431 .34679 .41113 .32916 Metetra
.671 .502 .648 r
.41113 .32916 .41431 .34679 .42064 .3413 .4175 .32221 Metetra
.658 .487 .641 r
.4175 .32221 .42064 .3413 .42697 .33614 .42385 .3156 Metetra
.645 .471 .634 r
.42385 .3156 .42697 .33614 .43328 .33143 .43018 .30947 Metetra
.631 .456 .629 r
.43018 .30947 .43328 .33143 .43958 .32727 .43649 .30396 Metetra
.616 .442 .623 r
.43649 .30396 .43958 .32727 .44587 .32373 .44279 .29916 Metetra
.602 .428 .619 r
.44279 .29916 .44587 .32373 .45215 .32086 .44907 .29516 Metetra
.587 .415 .615 r
.44907 .29516 .45215 .32086 .45844 .31865 .45534 .29201 Metetra
.574 .402 .612 r
.45534 .29201 .45844 .31865 .46472 .31709 .4616 .28974 Metetra
.56 .391 .609 r
.4616 .28974 .46472 .31709 .47101 .31612 .46787 .28833 Metetra
.548 .382 .608 r
.46787 .28833 .47101 .31612 .47732 .31567 .47413 .28776 Metetra
.537 .373 .607 r
.47413 .28776 .47732 .31567 .48364 .31566 .48041 .28797 Metetra
.526 .366 .607 r
.48041 .28797 .48364 .31566 .48997 .31599 .4867 .28886 Metetra
.517 .361 .609 r
.4867 .28886 .48997 .31599 .49634 .31654 .49301 .29033 Metetra
.509 .358 .612 r
.49301 .29033 .49634 .31654 .50272 .31722 .49935 .29225 Metetra
.502 .357 .616 r
.49935 .29225 .50272 .31722 .50914 .3179 .50572 .29446 Metetra
.497 .359 .623 r
.50572 .29446 .50914 .3179 .51558 .31849 .51212 .29682 Metetra
.494 .364 .632 r
.51212 .29682 .51558 .31849 .52205 .31888 .51855 .29917 Metetra
.494 .373 .644 r
.51855 .29917 .52205 .31888 .52854 .319 .52502 .30135 Metetra
.497 .387 .659 r
.52502 .30135 .52854 .319 .53506 .31875 .53152 .30322 Metetra
.503 .407 .678 r
.53152 .30322 .53506 .31875 .5416 .31808 .53806 .30465 Metetra
.515 .434 .702 r
.53806 .30465 .5416 .31808 .54816 .31693 .54462 .30553 Metetra
.533 .471 .732 r
.54462 .30553 .54816 .31693 .55473 .31528 .5512 .30578 Metetra
.558 .518 .767 r
.5512 .30578 .55473 .31528 .56132 .31308 .55781 .30535 Metetra
.591 .577 .806 r
.55781 .30535 .56132 .31308 .56792 .31035 .56443 .30419 Metetra
.63 .647 .848 r
.56443 .30419 .56792 .31035 .57452 .3071 .57105 .30231 Metetra
.674 .723 .886 r
.57105 .30231 .57452 .3071 .58112 .30334 .57769 .29973 Metetra
.717 .799 .916 r
.57769 .29973 .58112 .30334 .58772 .29913 .58432 .29648 Metetra
.753 .866 .931 r
.58432 .29648 .58772 .29913 .59432 .29451 .59096 .29264 Metetra
.779 .918 .932 r
.59096 .29264 .59432 .29451 .60092 .28955 .59759 .28827 Metetra
.795 .952 .921 r
.59759 .28827 .60092 .28955 .60752 .2843 .60422 .28345 Metetra
.804 .973 .905 r
.60422 .28345 .60752 .2843 .61412 .27885 .61085 .27828 Metetra
.809 .983 .891 r
.61085 .27828 .61412 .27885 .62071 .27327 .61747 .27285 Metetra
.812 .989 .88 r
.61747 .27285 .62071 .27327 .6273 .26761 .62408 .26724 Metetra
.814 .99 .875 r
.62408 .26724 .6273 .26761 .6339 .26195 .6307 .26154 Metetra
.816 .99 .875 r
.6307 .26154 .6339 .26195 .64049 .25633 .63731 .25581 Metetra
.818 .987 .879 r
.63731 .25581 .64049 .25633 .6471 .25082 .64393 .25012 Metetra
.818 .982 .887 r
.64393 .25012 .6471 .25082 .65371 .24543 .65056 .24453 Metetra
.816 .976 .895 r
.65056 .24453 .65371 .24543 .66033 .24022 .65719 .23908 Metetra
.813 .966 .904 r
.65719 .23908 .66033 .24022 .66696 .23519 .66384 .2338 Metetra
.807 .955 .912 r
.66384 .2338 .66696 .23519 .67361 .23037 .67049 .22871 Metetra
.8 .941 .919 r
.67049 .22871 .67361 .23037 .68027 .22576 .67716 .22384 Metetra
.791 .926 .925 r
.67716 .22384 .68027 .22576 .68696 .22136 .68385 .21917 Metetra
.781 .91 .929 r
.68385 .21917 .68696 .22136 .69366 .21716 .69056 .21472 Metetra
.77 .894 .931 r
.69056 .21472 .69366 .21716 .70038 .21316 .69728 .21049 Metetra
.759 .878 .932 r
.69728 .21049 .70038 .21316 .70712 .20935 .70403 .20645 Metetra
.749 .862 .932 r
.70403 .20645 .70712 .20935 .71388 .20571 .7108 .2026 Metetra
.738 .847 .931 r
.7108 .2026 .71388 .20571 .72067 .20222 .71758 .19892 Metetra
.729 .834 .93 r
.71758 .19892 .72067 .20222 .72747 .19888 .72439 .19541 Metetra
.72 .821 .928 r
.72439 .19541 .72747 .19888 .7343 .19566 .73122 .19203 Metetra
.712 .81 .926 r
.73122 .19203 .7343 .19566 .74115 .19256 .73808 .18879 Metetra
.705 .8 .924 r
.73808 .18879 .74115 .19256 .74802 .18955 .74495 .18565 Metetra
.698 .791 .922 r
.74495 .18565 .74802 .18955 .75491 .18662 .75185 .18262 Metetra
.693 .783 .92 r
.75185 .18262 .75491 .18662 .76182 .18376 .75877 .17966 Metetra
.688 .777 .919 r
.75877 .17966 .76182 .18376 .76875 .18097 .7657 .17678 Metetra
.684 .771 .917 r
.7657 .17678 .76875 .18097 .7757 .17822 .77266 .17396 Metetra
.68 .766 .916 r
.77266 .17396 .7757 .17822 .78267 .17552 .77964 .17119 Metetra
.678 .762 .915 r
.77964 .17119 .78267 .17552 .78966 .17284 .78664 .16846 Metetra
.675 .758 .913 r
.78664 .16846 .78966 .17284 .79667 .1702 .79366 .16577 Metetra
.661 .742 .91 r
.16763 .38265 .17159 .38632 .1772 .38435 .17324 .38068 Metetra
.661 .742 .911 r
.17324 .38068 .1772 .38435 .18282 .38238 .17887 .37872 Metetra
.659 .743 .912 r
.17887 .37872 .18282 .38238 .18845 .38041 .18451 .37677 Metetra
.657 .744 .914 r
.18451 .37677 .18845 .38041 .1941 .37847 .19015 .37484 Metetra
.655 .745 .916 r
.19015 .37484 .1941 .37847 .19975 .37654 .19581 .37295 Metetra
.651 .746 .919 r
.19581 .37295 .19975 .37654 .20541 .37465 .20147 .3711 Metetra
.647 .747 .923 r
.20147 .3711 .20541 .37465 .21108 .3728 .20714 .36931 Metetra
.64 .75 .928 r
.20714 .36931 .21108 .3728 .21675 .37101 .21281 .3676 Metetra
.631 .752 .935 r
.21281 .3676 .21675 .37101 .22244 .3693 .21849 .36599 Metetra
.618 .755 .944 r
.21849 .36599 .22244 .3693 .22812 .3677 .22417 .36451 Metetra
.601 .759 .954 r
.22417 .36451 .22812 .3677 .23381 .36622 .22985 .3632 Metetra
.576 .762 .966 r
.22985 .3632 .23381 .36622 .23949 .36491 .23553 .36208 Metetra
.541 .764 .979 r
.23553 .36208 .23949 .36491 .24518 .3638 .2412 .36121 Metetra
.491 .761 .991 r
.2412 .36121 .24518 .3638 .25086 .36293 .24686 .36061 Metetra
.418 .75 .994 r
.24686 .36061 .25086 .36293 .25653 .36234 .25251 .36034 Metetra
.315 .719 .978 r
.25251 .36034 .25653 .36234 .26219 .36207 .25815 .36041 Metetra
.177 .659 .927 r
.25815 .36041 .26219 .36207 .26784 .36215 .26378 .36086 Metetra
.013 .563 .829 r
.26378 .36086 .26784 .36215 .27349 .36262 .26941 .36171 Metetra
0 .441 .692 r
.26941 .36171 .27349 .36262 .27912 .36347 .27502 .36295 Metetra
.288 0 0 r
.27502 .36295 .27912 .36347 .28475 .36472 .28063 .36455 Metetra
.387 0 0 r
.28063 .36455 .28475 .36472 .29038 .36633 .28624 .36647 Metetra
.449 0 0 r
.28624 .36647 .29038 .36633 .29601 .36825 .29186 .36864 Metetra
.483 0 0 r
.29186 .36864 .29601 .36825 .30165 .37042 .29751 .37095 Metetra
.492 0 0 r
.29751 .37095 .30165 .37042 .30731 .37273 .30317 .37329 Metetra
.477 0 0 r
.30317 .37329 .30731 .37273 .313 .37506 .30888 .37551 Metetra
.433 0 0 r
.30888 .37551 .313 .37506 .31873 .37726 .31463 .37746 Metetra
.344 0 0 r
.31463 .37746 .31873 .37726 .3245 .37917 .32044 .37898 Metetra
.182 0 0 r
.32044 .37898 .3245 .37917 .33033 .38062 .32631 .37991 Metetra
.074 .626 .821 r
.32631 .37991 .33033 .38062 .33622 .38148 .33225 .38013 Metetra
.364 .787 .974 r
.33225 .38013 .33622 .38148 .34218 .38158 .33826 .37951 Metetra
.572 .835 .995 r
.33826 .37951 .34218 .38158 .3482 .38083 .34434 .37799 Metetra
.68 .815 .948 r
.34434 .37799 .3482 .38083 .3543 .37914 .35049 .37553 Metetra
.732 .781 .892 r
.35049 .37553 .3543 .37914 .36046 .37648 .3567 .37215 Metetra
.757 .751 .846 r
.3567 .37215 .36046 .37648 .36668 .37285 .36296 .36787 Metetra
.771 .727 .813 r
.36296 .36787 .36668 .37285 .37296 .36832 .36927 .3628 Metetra
.779 .711 .789 r
.36927 .3628 .37296 .36832 .37927 .36297 .37561 .35705 Metetra
.784 .701 .772 r
.37561 .35705 .37927 .36297 .38562 .35693 .38198 .35074 Metetra
.787 .694 .762 r
.38198 .35074 .38562 .35693 .39199 .35035 .38837 .34402 Metetra
.79 .692 .756 r
.38837 .34402 .39199 .35035 .39837 .34341 .39476 .33704 Metetra
.792 .691 .754 r
.39476 .33704 .39837 .34341 .40475 .33629 .40115 .32995 Metetra
.792 .692 .755 r
.40115 .32995 .40475 .33629 .41113 .32916 .40754 .32288 Metetra
.791 .694 .757 r
.40754 .32288 .41113 .32916 .4175 .32221 .41391 .31595 Metetra
.786 .693 .761 r
.41391 .31595 .4175 .32221 .42385 .3156 .42028 .30927 Metetra
.778 .689 .765 r
.42028 .30927 .42385 .3156 .43018 .30947 .42662 .30296 Metetra
.765 .68 .768 r
.42662 .30296 .43018 .30947 .43649 .30396 .43296 .29708 Metetra
.747 .664 .769 r
.43296 .29708 .43649 .30396 .44279 .29916 .43928 .29173 Metetra
.724 .641 .766 r
.43928 .29173 .44279 .29916 .44907 .29516 .44558 .28697 Metetra
.696 .612 .759 r
.44558 .28697 .44907 .29516 .45534 .29201 .45187 .28287 Metetra
.665 .578 .748 r
.45187 .28287 .45534 .29201 .4616 .28974 .45816 .27948 Metetra
.634 .543 .734 r
.45816 .27948 .4616 .28974 .46787 .28833 .46444 .27685 Metetra
.604 .508 .719 r
.46444 .27685 .46787 .28833 .47413 .28776 .47072 .27498 Metetra
.576 .476 .703 r
.47072 .27498 .47413 .28776 .48041 .28797 .477 .27391 Metetra
.552 .448 .69 r
.477 .27391 .48041 .28797 .4867 .28886 .4833 .2736 Metetra
.531 .424 .678 r
.4833 .2736 .4867 .28886 .49301 .29033 .4896 .27401 Metetra
.514 .405 .668 r
.4896 .27401 .49301 .29033 .49935 .29225 .49593 .27509 Metetra
.5 .39 .661 r
.49593 .27509 .49935 .29225 .50572 .29446 .50228 .27674 Metetra
.49 .38 .656 r
.50228 .27674 .50572 .29446 .51212 .29682 .50866 .27883 Metetra
.482 .374 .654 r
.50866 .27883 .51212 .29682 .51855 .29917 .51507 .28123 Metetra
.478 .371 .655 r
.51507 .28123 .51855 .29917 .52502 .30135 .52152 .28379 Metetra
.477 .374 .658 r
.52152 .28379 .52502 .30135 .53152 .30322 .528 .28633 Metetra
.479 .38 .664 r
.528 .28633 .53152 .30322 .53806 .30465 .53451 .28871 Metetra
.485 .391 .674 r
.53451 .28871 .53806 .30465 .54462 .30553 .54106 .29076 Metetra
.496 .408 .686 r
.54106 .29076 .54462 .30553 .5512 .30578 .54764 .29234 Metetra
.511 .431 .703 r
.54764 .29234 .5512 .30578 .55781 .30535 .55425 .29335 Metetra
.531 .461 .723 r
.55425 .29335 .55781 .30535 .56443 .30419 .56088 .29368 Metetra
.556 .499 .747 r
.56088 .29368 .56443 .30419 .57105 .30231 .56752 .29327 Metetra
.587 .545 .774 r
.56752 .29327 .57105 .30231 .57769 .29973 .57418 .29211 Metetra
.624 .599 .804 r
.57418 .29211 .57769 .29973 .58432 .29648 .58084 .29018 Metetra
.665 .659 .834 r
.58084 .29018 .58432 .29648 .59096 .29264 .58751 .28752 Metetra
.706 .722 .862 r
.58751 .28752 .59096 .29264 .59759 .28827 .59418 .28419 Metetra
.745 .784 .885 r
.59418 .28419 .59759 .28827 .60422 .28345 .60084 .28026 Metetra
.778 .84 .899 r
.60084 .28026 .60422 .28345 .61085 .27828 .6075 .2758 Metetra
.803 .886 .905 r
.6075 .2758 .61085 .27828 .61747 .27285 .61416 .27093 Metetra
.819 .92 .904 r
.61416 .27093 .61747 .27285 .62408 .26724 .62081 .26572 Metetra
.827 .943 .9 r
.62081 .26572 .62408 .26724 .6307 .26154 .62745 .26029 Metetra
.831 .957 .895 r
.62745 .26029 .6307 .26154 .63731 .25581 .63409 .25471 Metetra
.831 .965 .892 r
.63409 .25471 .63731 .25581 .64393 .25012 .64074 .24907 Metetra
.829 .968 .892 r
.64074 .24907 .64393 .25012 .65056 .24453 .64738 .24344 Metetra
.826 .968 .895 r
.64738 .24344 .65056 .24453 .65719 .23908 .65403 .23788 Metetra
.821 .964 .9 r
.65403 .23788 .65719 .23908 .66384 .2338 .66069 .23245 Metetra
.816 .957 .906 r
.66069 .23245 .66384 .2338 .67049 .22871 .66736 .22717 Metetra
.809 .948 .913 r
.66736 .22717 .67049 .22871 .67716 .22384 .67404 .22207 Metetra
.801 .937 .919 r
.67404 .22207 .67716 .22384 .68385 .21917 .68074 .21718 Metetra
.792 .924 .924 r
.68074 .21718 .68385 .21917 .69056 .21472 .68745 .21249 Metetra
.782 .909 .928 r
.68745 .21249 .69056 .21472 .69728 .21049 .69418 .20802 Metetra
.771 .894 .931 r
.69418 .20802 .69728 .21049 .70403 .20645 .70093 .20375 Metetra
.76 .878 .932 r
.70093 .20375 .70403 .20645 .7108 .2026 .7077 .19968 Metetra
.749 .863 .932 r
.7077 .19968 .7108 .2026 .71758 .19892 .7145 .1958 Metetra
.739 .849 .931 r
.7145 .1958 .71758 .19892 .72439 .19541 .72131 .1921 Metetra
.729 .835 .93 r
.72131 .1921 .72439 .19541 .73122 .19203 .72815 .18855 Metetra
.721 .823 .928 r
.72815 .18855 .73122 .19203 .73808 .18879 .735 .18515 Metetra
.712 .811 .926 r
.735 .18515 .73808 .18879 .74495 .18565 .74188 .18187 Metetra
.705 .801 .924 r
.74188 .18187 .74495 .18565 .75185 .18262 .74879 .17871 Metetra
.699 .792 .923 r
.74879 .17871 .75185 .18262 .75877 .17966 .75571 .17565 Metetra
.693 .784 .921 r
.75571 .17565 .75877 .17966 .7657 .17678 .76265 .17267 Metetra
.689 .778 .919 r
.76265 .17267 .7657 .17678 .77266 .17396 .76962 .16976 Metetra
.684 .772 .917 r
.76962 .16976 .77266 .17396 .77964 .17119 .77661 .16691 Metetra
.681 .767 .916 r
.77661 .16691 .77964 .17119 .78664 .16846 .78362 .16412 Metetra
.678 .762 .915 r
.78362 .16412 .78664 .16846 .79366 .16577 .79064 .16136 Metetra
.66 .743 .911 r
.16365 .37899 .16763 .38265 .17324 .38068 .16927 .37702 Metetra
.659 .743 .912 r
.16927 .37702 .17324 .38068 .17887 .37872 .1749 .37507 Metetra
.657 .744 .914 r
.1749 .37507 .17887 .37872 .18451 .37677 .18054 .37314 Metetra
.655 .745 .916 r
.18054 .37314 .18451 .37677 .19015 .37484 .18619 .37124 Metetra
.651 .746 .919 r
.18619 .37124 .19015 .37484 .19581 .37295 .19184 .36939 Metetra
.646 .748 .923 r
.19184 .36939 .19581 .37295 .20147 .3711 .19751 .3676 Metetra
.64 .75 .928 r
.19751 .3676 .20147 .3711 .20714 .36931 .20317 .36589 Metetra
.631 .752 .935 r
.20317 .36589 .20714 .36931 .21281 .3676 .20885 .36428 Metetra
.618 .755 .944 r
.20885 .36428 .21281 .3676 .21849 .36599 .21452 .3628 Metetra
.601 .759 .954 r
.21452 .3628 .21849 .36599 .22417 .36451 .22019 .36148 Metetra
.576 .762 .967 r
.22019 .36148 .22417 .36451 .22985 .3632 .22586 .36037 Metetra
.541 .764 .98 r
.22586 .36037 .22985 .3632 .23553 .36208 .23152 .35949 Metetra
.491 .762 .991 r
.23152 .35949 .23553 .36208 .2412 .36121 .23717 .35889 Metetra
.418 .75 .994 r
.23717 .35889 .2412 .36121 .24686 .36061 .24281 .35861 Metetra
.315 .72 .978 r
.24281 .35861 .24686 .36061 .25251 .36034 .24844 .35867 Metetra
.177 .659 .928 r
.24844 .35867 .25251 .36034 .25815 .36041 .25406 .35912 Metetra
.014 .563 .829 r
.25406 .35912 .25815 .36041 .26378 .36086 .25967 .35996 Metetra
0 .441 .692 r
.25967 .35996 .26378 .36086 .26941 .36171 .26527 .36119 Metetra
.289 0 0 r
.26527 .36119 .26941 .36171 .27502 .36295 .27086 .36278 Metetra
.388 0 0 r
.27086 .36278 .27502 .36295 .28063 .36455 .27645 .3647 Metetra
.452 0 0 r
.27645 .3647 .28063 .36455 .28624 .36647 .28206 .36687 Metetra
.486 0 0 r
.28206 .36687 .28624 .36647 .29186 .36864 .28768 .3692 Metetra
.497 0 0 r
.28768 .3692 .29186 .36864 .29751 .37095 .29332 .37156 Metetra
.485 0 0 r
.29332 .37156 .29751 .37095 .30317 .37329 .29901 .37382 Metetra
.446 0 0 r
.29901 .37382 .30317 .37329 .30888 .37551 .30474 .37582 Metetra
.367 0 0 r
.30474 .37582 .30888 .37551 .31463 .37746 .31053 .37741 Metetra
.222 0 0 r
.31053 .37741 .31463 .37746 .32044 .37898 .31638 .37844 Metetra
.011 .582 .769 r
.31638 .37844 .32044 .37898 .32631 .37991 .3223 .37878 Metetra
.298 .761 .946 r
.3223 .37878 .32631 .37991 .33225 .38013 .32829 .37833 Metetra
.527 .836 .999 r
.32829 .37833 .33225 .38013 .33826 .37951 .33435 .37702 Metetra
.656 .832 .968 r
.33435 .37702 .33826 .37951 .34434 .37799 .34048 .37482 Metetra
.719 .803 .917 r
.34048 .37482 .34434 .37799 .35049 .37553 .34667 .37174 Metetra
.751 .775 .872 r
.34667 .37174 .35049 .37553 .3567 .37215 .35292 .36784 Metetra
.769 .754 .839 r
.35292 .36784 .3567 .37215 .36296 .36787 .35921 .36321 Metetra
.781 .742 .817 r
.35921 .36321 .36296 .36787 .36927 .3628 .36554 .35797 Metetra
.79 .738 .804 r
.36554 .35797 .36927 .3628 .37561 .35705 .37189 .35225 Metetra
.799 .741 .799 r
.37189 .35225 .37561 .35705 .38198 .35074 .37826 .3462 Metetra
.808 .752 .801 r
.37826 .3462 .38198 .35074 .38837 .34402 .38464 .33996 Metetra
.819 .773 .809 r
.38464 .33996 .38837 .34402 .39476 .33704 .39101 .33366 Metetra
.832 .804 .824 r
.39101 .33366 .39476 .33704 .40115 .32995 .39739 .32741 Metetra
.844 .847 .846 r
.39739 .32741 .40115 .32995 .40754 .32288 .40375 .3213 Metetra
.853 .901 .869 r
.40375 .3213 .40754 .32288 .41391 .31595 .41011 .3154 Metetra
.843 .959 .885 r
.41011 .3154 .41391 .31595 .42028 .30927 .41646 .30977 Metetra
.792 .995 .868 r
.41646 .30977 .42028 .30927 .42662 .30296 .4228 .30445 Metetra
.671 .97 .788 r
.4228 .30445 .42662 .30296 .43296 .29708 .42913 .29945 Metetra
.495 .867 .648 r
.42913 .29945 .43296 .29708 .43928 .29173 .43545 .2948 Metetra
.43545 .2948 .43928 .29173 .44558 .28697 .44177 .2905 Metetra
.44177 .2905 .44558 .28697 .45187 .28287 .44808 .2866 Metetra
.44808 .2866 .45187 .28287 .45816 .27948 .4544 .2831 Metetra
.4544 .2831 .45816 .27948 .46444 .27685 .46071 .28004 Metetra
.46071 .28004 .46444 .27685 .47072 .27498 .46703 .27745 Metetra
.46703 .27745 .47072 .27498 .477 .27391 .47335 .27537 Metetra
.47335 .27537 .477 .27391 .4833 .2736 .47968 .27384 Metetra
.163 .702 .765 r
.47968 .27384 .4833 .2736 .4896 .27401 .48602 .27286 Metetra
.279 .751 .939 r
.48602 .27286 .4896 .27401 .49593 .27509 .49237 .27246 Metetra
.362 .709 .986 r
.49237 .27246 .49593 .27509 .50228 .27674 .49874 .2726 Metetra
.401 .629 .946 r
.49874 .2726 .50228 .27674 .50866 .27883 .50514 .27324 Metetra
.417 .559 .889 r
.50514 .27324 .50866 .27883 .51507 .28123 .51156 .27433 Metetra
.426 .51 .842 r
.51156 .27433 .51507 .28123 .52152 .28379 .518 .27577 Metetra
.433 .479 .807 r
.518 .27577 .52152 .28379 .528 .28633 .52448 .27744 Metetra
.442 .462 .784 r
.52448 .27744 .528 .28633 .53451 .28871 .53099 .27922 Metetra
.453 .455 .77 r
.53099 .27922 .53451 .28871 .54106 .29076 .53753 .28095 Metetra
.466 .457 .764 r
.53753 .28095 .54106 .29076 .54764 .29234 .54411 .2825 Metetra
.483 .467 .764 r
.54411 .2825 .54764 .29234 .55425 .29335 .55071 .28373 Metetra
.503 .484 .768 r
.55071 .28373 .55425 .29335 .56088 .29368 .55734 .28451 Metetra
.527 .507 .778 r
.55734 .28451 .56088 .29368 .56752 .29327 .56399 .28474 Metetra
.554 .538 .791 r
.56399 .28474 .56752 .29327 .57418 .29211 .57066 .28433 Metetra
.586 .575 .808 r
.57066 .28433 .57418 .29211 .58084 .29018 .57734 .28325 Metetra
.621 .618 .827 r
.57734 .28325 .58084 .29018 .58751 .28752 .58403 .28148 Metetra
.658 .666 .847 r
.58403 .28148 .58751 .28752 .59418 .28419 .59072 .27901 Metetra
.695 .717 .865 r
.59072 .27901 .59418 .28419 .60084 .28026 .59742 .27589 Metetra
.731 .767 .882 r
.59742 .27589 .60084 .28026 .6075 .2758 .60411 .27218 Metetra
.763 .815 .893 r
.60411 .27218 .6075 .2758 .61416 .27093 .6108 .26794 Metetra
.789 .857 .9 r
.6108 .26794 .61416 .27093 .62081 .26572 .61748 .26327 Metetra
.808 .891 .903 r
.61748 .26327 .62081 .26572 .62745 .26029 .62416 .25825 Metetra
.821 .916 .902 r
.62416 .25825 .62745 .26029 .63409 .25471 .63083 .25298 Metetra
.827 .934 .9 r
.63083 .25298 .63409 .25471 .64074 .24907 .6375 .24754 Metetra
.83 .946 .898 r
.6375 .24754 .64074 .24907 .64738 .24344 .64417 .24201 Metetra
.829 .952 .898 r
.64417 .24201 .64738 .24344 .65403 .23788 .65085 .23647 Metetra
.826 .954 .9 r
.65085 .23647 .65403 .23788 .66069 .23245 .65752 .23098 Metetra
.822 .952 .903 r
.65752 .23098 .66069 .23245 .66736 .22717 .66421 .2256 Metetra
.816 .948 .908 r
.66421 .2256 .66736 .22717 .67404 .22207 .6709 .22035 Metetra
.809 .94 .914 r
.6709 .22035 .67404 .22207 .68074 .21718 .67761 .21527 Metetra
.801 .93 .919 r
.67761 .21527 .68074 .21718 .68745 .21249 .68433 .21038 Metetra
.791 .919 .924 r
.68433 .21038 .68745 .21249 .69418 .20802 .69107 .2057 Metetra
.781 .906 .927 r
.69107 .2057 .69418 .20802 .70093 .20375 .69783 .20121 Metetra
.771 .892 .93 r
.69783 .20121 .70093 .20375 .7077 .19968 .70461 .19693 Metetra
.76 .877 .931 r
.70461 .19693 .7077 .19968 .7145 .1958 .7114 .19285 Metetra
.75 .863 .932 r
.7114 .19285 .7145 .1958 .72131 .1921 .71822 .18894 Metetra
.739 .849 .931 r
.71822 .18894 .72131 .1921 .72815 .18855 .72506 .18521 Metetra
.73 .835 .93 r
.72506 .18521 .72815 .18855 .735 .18515 .73193 .18164 Metetra
.721 .823 .928 r
.73193 .18164 .735 .18515 .74188 .18187 .73881 .17821 Metetra
.713 .812 .927 r
.73881 .17821 .74188 .18187 .74879 .17871 .74572 .17491 Metetra
.706 .802 .925 r
.74572 .17491 .74879 .17871 .75571 .17565 .75265 .17172 Metetra
.699 .793 .923 r
.75265 .17172 .75571 .17565 .76265 .17267 .7596 .16863 Metetra
.694 .785 .921 r
.7596 .16863 .76265 .17267 .76962 .16976 .76657 .16562 Metetra
.689 .778 .919 r
.76657 .16562 .76962 .16976 .77661 .16691 .77356 .16269 Metetra
.685 .772 .918 r
.77356 .16269 .77661 .16691 .78362 .16412 .78058 .15981 Metetra
.681 .767 .916 r
.78058 .15981 .78362 .16412 .79064 .16136 .78762 .15699 Metetra
.659 .743 .912 r
.15964 .37532 .16365 .37899 .16927 .37702 .16527 .37336 Metetra
.657 .744 .914 r
.16527 .37336 .16927 .37702 .1749 .37507 .1709 .37143 Metetra
.655 .745 .916 r
.1709 .37143 .1749 .37507 .18054 .37314 .17655 .36953 Metetra
.651 .746 .919 r
.17655 .36953 .18054 .37314 .18619 .37124 .1822 .36768 Metetra
.646 .748 .923 r
.1822 .36768 .18619 .37124 .19184 .36939 .18786 .36589 Metetra
.64 .75 .929 r
.18786 .36589 .19184 .36939 .19751 .3676 .19352 .36417 Metetra
.631 .752 .935 r
.19352 .36417 .19751 .3676 .20317 .36589 .19918 .36256 Metetra
.618 .756 .944 r
.19918 .36256 .20317 .36589 .20885 .36428 .20485 .36108 Metetra
.6 .759 .955 r
.20485 .36108 .20885 .36428 .21452 .3628 .21051 .35977 Metetra
.576 .762 .967 r
.21051 .35977 .21452 .3628 .22019 .36148 .21617 .35865 Metetra
.541 .764 .98 r
.21617 .35865 .22019 .36148 .22586 .36037 .22182 .35777 Metetra
.491 .762 .991 r
.22182 .35777 .22586 .36037 .23152 .35949 .22746 .35716 Metetra
.418 .75 .994 r
.22746 .35716 .23152 .35949 .23717 .35889 .23309 .35688 Metetra
.316 .72 .979 r
.23309 .35688 .23717 .35889 .24281 .35861 .23871 .35694 Metetra
.178 .66 .928 r
.23871 .35694 .24281 .35861 .24844 .35867 .24432 .35738 Metetra
.015 .564 .83 r
.24432 .35738 .24844 .35867 .25406 .35912 .24991 .3582 Metetra
0 .442 .693 r
.24991 .3582 .25406 .35912 .25967 .35996 .25549 .35942 Metetra
.287 0 0 r
.25549 .35942 .25967 .35996 .26527 .36119 .26107 .36101 Metetra
.387 0 0 r
.26107 .36101 .26527 .36119 .27086 .36278 .26665 .36292 Metetra
.451 0 0 r
.26665 .36292 .27086 .36278 .27645 .3647 .27223 .36509 Metetra
.486 0 0 r
.27223 .36509 .27645 .3647 .28206 .36687 .27783 .36741 Metetra
.497 0 0 r
.27783 .36741 .28206 .36687 .28768 .3692 .28346 .36978 Metetra
.485 0 0 r
.28346 .36978 .28768 .3692 .29332 .37156 .28912 .37204 Metetra
.446 0 0 r
.28912 .37204 .29332 .37156 .29901 .37382 .29484 .37406 Metetra
.365 0 0 r
.29484 .37406 .29901 .37382 .30474 .37582 .3006 .37567 Metetra
.215 0 0 r
.3006 .37567 .30474 .37582 .31053 .37741 .30644 .37673 Metetra
.028 .593 .792 r
.30644 .37673 .31053 .37741 .31638 .37844 .31234 .3771 Metetra
.321 .765 .963 r
.31234 .3771 .31638 .37844 .3223 .37878 .31832 .37668 Metetra
.542 .822 .998 r
.31832 .37668 .3223 .37878 .32829 .37833 .32437 .37539 Metetra
.659 .805 .953 r
.32437 .37539 .32829 .37833 .33435 .37702 .33049 .37322 Metetra
.713 .768 .895 r
.33049 .37322 .33435 .37702 .34048 .37482 .33668 .37018 Metetra
.738 .733 .847 r
.33668 .37018 .34048 .37482 .34667 .37174 .34293 .36631 Metetra
.749 .706 .811 r
.34293 .36631 .34667 .37174 .35292 .36784 .34922 .36172 Metetra
.754 .686 .786 r
.34922 .36172 .35292 .36784 .35921 .36321 .35555 .35653 Metetra
.756 .672 .768 r
.35555 .35653 .35921 .36321 .36554 .35797 .36191 .35088 Metetra
.757 .662 .757 r
.36191 .35088 .36554 .35797 .37189 .35225 .36828 .34492 Metetra
.757 .657 .752 r
.36828 .34492 .37189 .35225 .37826 .3462 .37466 .33882 Metetra
.756 .656 .751 r
.37466 .33882 .37826 .3462 .38464 .33996 .38103 .33269 Metetra
.756 .658 .754 r
.38103 .33269 .38464 .33996 .39101 .33366 .3874 .32669 Metetra
.756 .665 .762 r
.3874 .32669 .39101 .33366 .39739 .32741 .39377 .3209 Metetra
.756 .677 .775 r
.39377 .3209 .39739 .32741 .40375 .3213 .40012 .3154 Metetra
.758 .696 .793 r
.40012 .3154 .40375 .3213 .41011 .3154 .40646 .31025 Metetra
.76 .722 .817 r
.40646 .31025 .41011 .3154 .41646 .30977 .41278 .30547 Metetra
.763 .758 .849 r
.41278 .30547 .41646 .30977 .4228 .30445 .4191 .30107 Metetra
.762 .806 .887 r
.4191 .30107 .4228 .30445 .42913 .29945 .42542 .29705 Metetra
.753 .863 .93 r
.42542 .29705 .42913 .29945 .43545 .2948 .43173 .29337 Metetra
.719 .92 .961 r
.43173 .29337 .43545 .2948 .44177 .2905 .43804 .29003 Metetra
.636 .946 .952 r
.43804 .29003 .44177 .2905 .44808 .2866 .44435 .287 Metetra
.489 .903 .866 r
.44435 .287 .44808 .2866 .4544 .2831 .45066 .28426 Metetra
.31 .791 .719 r
.45066 .28426 .4544 .2831 .46071 .28004 .45698 .28179 Metetra
.45698 .28179 .46071 .28004 .46703 .27745 .46331 .27961 Metetra
.46331 .27961 .46703 .27745 .47335 .27537 .46965 .27771 Metetra
.047 0 0 r
.46965 .27771 .47335 .27537 .47968 .27384 .47601 .27612 Metetra
.095 0 0 r
.47601 .27612 .47968 .27384 .48602 .27286 .48237 .27485 Metetra
.117 0 0 r
.48237 .27485 .48602 .27286 .49237 .27246 .48875 .27393 Metetra
.114 0 0 r
.48875 .27393 .49237 .27246 .49874 .2726 .49515 .27337 Metetra
.083 0 0 r
.49515 .27337 .49874 .2726 .50514 .27324 .50156 .27317 Metetra
.018 0 0 r
.50156 .27317 .50514 .27324 .51156 .27433 .508 .27332 Metetra
.077 .62 .846 r
.508 .27332 .51156 .27433 .518 .27577 .51446 .27378 Metetra
.181 .645 .937 r
.51446 .27378 .518 .27577 .52448 .27744 .52095 .27449 Metetra
.271 .638 .964 r
.52095 .27449 .52448 .27744 .53099 .27922 .52747 .27538 Metetra
.338 .617 .953 r
.52747 .27538 .53099 .27922 .53753 .28095 .53402 .27635 Metetra
.388 .599 .93 r
.53402 .27635 .53753 .28095 .54411 .2825 .54059 .2773 Metetra
.429 .589 .908 r
.54059 .2773 .54411 .2825 .55071 .28373 .5472 .2781 Metetra
.465 .588 .892 r
.5472 .2781 .55071 .28373 .55734 .28451 .55383 .27865 Metetra
.499 .596 .882 r
.55383 .27865 .55734 .28451 .56399 .28474 .56048 .27883 Metetra
.533 .612 .877 r
.56048 .27883 .56399 .28474 .57066 .28433 .56716 .27856 Metetra
.567 .635 .878 r
.56716 .27856 .57066 .28433 .57734 .28325 .57385 .27775 Metetra
.602 .664 .882 r
.57385 .27775 .57734 .28325 .58403 .28148 .58055 .27636 Metetra
.638 .697 .888 r
.58055 .27636 .58403 .28148 .59072 .27901 .58727 .27436 Metetra
.674 .734 .895 r
.58727 .27436 .59072 .27901 .59742 .27589 .59398 .27174 Metetra
.708 .772 .902 r
.59398 .27174 .59742 .27589 .60411 .27218 .6007 .26854 Metetra
.74 .81 .907 r
.6007 .26854 .60411 .27218 .6108 .26794 .60742 .26479 Metetra
.767 .845 .91 r
.60742 .26479 .6108 .26794 .61748 .26327 .61413 .26057 Metetra
.789 .875 .91 r
.61413 .26057 .61748 .26327 .62416 .25825 .62084 .25593 Metetra
.806 .9 .908 r
.62084 .25593 .62416 .25825 .63083 .25298 .62754 .25097 Metetra
.817 .919 .905 r
.62754 .25097 .63083 .25298 .6375 .24754 .63424 .24576 Metetra
.824 .933 .903 r
.63424 .24576 .6375 .24754 .64417 .24201 .64094 .24038 Metetra
.827 .942 .901 r
.64094 .24038 .64417 .24201 .65085 .23647 .64763 .23492 Metetra
.826 .947 .9 r
.64763 .23492 .65085 .23647 .65752 .23098 .65433 .22944 Metetra
.824 .949 .902 r
.65433 .22944 .65752 .23098 .66421 .2256 .66104 .224 Metetra
.82 .947 .905 r
.66104 .224 .66421 .2256 .6709 .22035 .66775 .21865 Metetra
.815 .942 .91 r
.66775 .21865 .6709 .22035 .67761 .21527 .67447 .21344 Metetra
.808 .935 .914 r
.67447 .21344 .67761 .21527 .68433 .21038 .6812 .20838 Metetra
.8 .926 .919 r
.6812 .20838 .68433 .21038 .69107 .2057 .68795 .20351 Metetra
.79 .915 .924 r
.68795 .20351 .69107 .2057 .69783 .20121 .69472 .19882 Metetra
.781 .903 .927 r
.69472 .19882 .69783 .20121 .70461 .19693 .7015 .19433 Metetra
.77 .889 .929 r
.7015 .19433 .70461 .19693 .7114 .19285 .7083 .19004 Metetra
.76 .876 .931 r
.7083 .19004 .7114 .19285 .71822 .18894 .71513 .18594 Metetra
.75 .862 .931 r
.71513 .18594 .71822 .18894 .72506 .18521 .72197 .18202 Metetra
.74 .848 .931 r
.72197 .18202 .72506 .18521 .73193 .18164 .72884 .17827 Metetra
.73 .835 .93 r
.72884 .17827 .73193 .18164 .73881 .17821 .73573 .17468 Metetra
.721 .823 .928 r
.73573 .17468 .73881 .17821 .74572 .17491 .74264 .17122 Metetra
.713 .812 .927 r
.74264 .17122 .74572 .17491 .75265 .17172 .74958 .16789 Metetra
.706 .802 .925 r
.74958 .16789 .75265 .17172 .7596 .16863 .75653 .16467 Metetra
.7 .794 .923 r
.75653 .16467 .7596 .16863 .76657 .16562 .76351 .16156 Metetra
.694 .786 .921 r
.76351 .16156 .76657 .16562 .77356 .16269 .77051 .15852 Metetra
.69 .779 .919 r
.77051 .15852 .77356 .16269 .78058 .15981 .77754 .15556 Metetra
.685 .773 .918 r
.77754 .15556 .78058 .15981 .78762 .15699 .78458 .15267 Metetra
.657 .744 .914 r
.15562 .37166 .15964 .37532 .16527 .37336 .16125 .36972 Metetra
.654 .745 .916 r
.16125 .36972 .16527 .37336 .1709 .37143 .16689 .36782 Metetra
.651 .746 .919 r
.16689 .36782 .1709 .37143 .17655 .36953 .17254 .36597 Metetra
.646 .748 .923 r
.17254 .36597 .17655 .36953 .1822 .36768 .17819 .36417 Metetra
.639 .75 .929 r
.17819 .36417 .1822 .36768 .18786 .36589 .18384 .36246 Metetra
.63 .753 .936 r
.18384 .36246 .18786 .36589 .19352 .36417 .1895 .36085 Metetra
.618 .756 .944 r
.1895 .36085 .19352 .36417 .19918 .36256 .19516 .35937 Metetra
.6 .759 .955 r
.19516 .35937 .19918 .36256 .20485 .36108 .20081 .35805 Metetra
.576 .763 .967 r
.20081 .35805 .20485 .36108 .21051 .35977 .20646 .35693 Metetra
.541 .764 .98 r
.20646 .35693 .21051 .35977 .21617 .35865 .2121 .35605 Metetra
.491 .762 .991 r
.2121 .35605 .21617 .35865 .22182 .35777 .21774 .35544 Metetra
.418 .75 .994 r
.21774 .35544 .22182 .35777 .22746 .35716 .22336 .35514 Metetra
.316 .72 .979 r
.22336 .35514 .22746 .35716 .23309 .35688 .22896 .3552 Metetra
.179 .661 .928 r
.22896 .3552 .23309 .35688 .23871 .35694 .23456 .35563 Metetra
.017 .565 .831 r
.23456 .35563 .23871 .35694 .24432 .35738 .24014 .35645 Metetra
0 .444 .695 r
.24014 .35645 .24432 .35738 .24991 .3582 .2457 .35766 Metetra
.285 0 0 r
.2457 .35766 .24991 .3582 .25549 .35942 .25127 .35924 Metetra
.385 0 0 r
.25127 .35924 .25549 .35942 .26107 .36101 .25682 .36114 Metetra
.449 0 0 r
.25682 .36114 .26107 .36101 .26665 .36292 .26239 .36329 Metetra
.484 0 0 r
.26239 .36329 .26665 .36292 .27223 .36509 .26797 .36561 Metetra
.495 0 0 r
.26797 .36561 .27223 .36509 .27783 .36741 .27358 .36796 Metetra
.483 0 0 r
.27358 .36796 .27783 .36741 .28346 .36978 .27923 .37022 Metetra
.443 0 0 r
.27923 .37022 .28346 .36978 .28912 .37204 .28492 .37223 Metetra
.359 0 0 r
.28492 .37223 .28912 .37204 .29484 .37406 .29067 .37384 Metetra
.204 0 0 r
.29067 .37384 .29484 .37406 .3006 .37567 .29649 .37488 Metetra
.05 .607 .813 r
.29649 .37488 .3006 .37567 .30644 .37673 .30238 .37523 Metetra
.346 .771 .974 r
.30238 .37523 .30644 .37673 .31234 .3771 .30835 .37478 Metetra
.558 .815 .994 r
.30835 .37478 .31234 .3771 .31832 .37668 .31439 .37346 Metetra
.665 .789 .94 r
.31439 .37346 .31832 .37668 .32437 .37539 .32051 .37122 Metetra
.714 .749 .88 r
.32051 .37122 .32437 .37539 .33049 .37322 .3267 .36808 Metetra
.735 .713 .83 r
.3267 .36808 .33049 .37322 .33668 .37018 .33296 .36409 Metetra
.743 .684 .793 r
.33296 .36409 .33668 .37018 .34293 .36631 .33926 .35934 Metetra
.746 .661 .766 r
.33926 .35934 .34293 .36631 .34922 .36172 .3456 .35394 Metetra
.745 .643 .747 r
.3456 .35394 .34922 .36172 .35555 .35653 .35198 .34804 Metetra
.743 .629 .733 r
.35198 .34804 .35555 .35653 .36191 .35088 .35837 .3418 Metetra
.738 .617 .723 r
.35837 .3418 .36191 .35088 .36828 .34492 .36477 .33536 Metetra
.733 .607 .717 r
.36477 .33536 .36828 .34492 .37466 .33882 .37117 .32888 Metetra
.727 .599 .713 r
.37117 .32888 .37466 .33882 .38103 .33269 .37756 .32249 Metetra
.72 .592 .711 r
.37756 .32249 .38103 .33269 .3874 .32669 .38394 .3163 Metetra
.712 .585 .711 r
.38394 .3163 .3874 .32669 .39377 .3209 .39031 .31041 Metetra
.704 .579 .712 r
.39031 .31041 .39377 .3209 .40012 .3154 .39666 .30489 Metetra
.695 .574 .715 r
.39666 .30489 .40012 .3154 .40646 .31025 .403 .29978 Metetra
.685 .569 .718 r
.403 .29978 .40646 .31025 .41278 .30547 .40932 .29512 Metetra
.676 .565 .723 r
.40932 .29512 .41278 .30547 .4191 .30107 .41563 .2909 Metetra
.666 .563 .729 r
.41563 .2909 .4191 .30107 .42542 .29705 .42193 .28714 Metetra
.656 .562 .736 r
.42193 .28714 .42542 .29705 .43173 .29337 .42823 .28381 Metetra
.647 .562 .745 r
.42823 .28381 .43173 .29337 .43804 .29003 .43453 .28089 Metetra
.638 .565 .756 r
.43453 .28089 .43804 .29003 .44435 .287 .44083 .27834 Metetra
.629 .57 .769 r
.44083 .27834 .44435 .287 .45066 .28426 .44713 .27615 Metetra
.62 .578 .785 r
.44713 .27615 .45066 .28426 .45698 .28179 .45344 .27429 Metetra
.61 .589 .804 r
.45344 .27429 .45698 .28179 .46331 .27961 .45976 .27272 Metetra
.599 .602 .826 r
.45976 .27272 .46331 .27961 .46965 .27771 .46609 .27144 Metetra
.584 .616 .85 r
.46609 .27144 .46965 .27771 .47601 .27612 .47244 .27044 Metetra
.565 .631 .876 r
.47244 .27044 .47601 .27612 .48237 .27485 .4788 .26969 Metetra
.541 .644 .901 r
.4788 .26969 .48237 .27485 .48875 .27393 .48518 .26921 Metetra
.511 .653 .922 r
.48518 .26921 .48875 .27393 .49515 .27337 .49158 .26898 Metetra
.478 .656 .938 r
.49158 .26898 .49515 .27337 .50156 .27317 .498 .269 Metetra
.445 .653 .948 r
.498 .269 .50156 .27317 .508 .27332 .50444 .26924 Metetra
.416 .644 .951 r
.50444 .26924 .508 .27332 .51446 .27378 .51091 .2697 Metetra
.396 .634 .951 r
.51091 .2697 .51446 .27378 .52095 .27449 .51741 .27033 Metetra
.386 .624 .947 r
.51741 .27033 .52095 .27449 .52747 .27538 .52393 .27107 Metetra
.388 .616 .942 r
.52393 .27107 .52747 .27538 .53402 .27635 .53049 .27187 Metetra
.399 .613 .936 r
.53049 .27187 .53402 .27635 .54059 .2773 .53707 .27265 Metetra
.419 .614 .931 r
.53707 .27265 .54059 .2773 .5472 .2781 .54368 .27332 Metetra
.444 .621 .926 r
.54368 .27332 .5472 .2781 .55383 .27865 .55031 .2738 Metetra
.475 .633 .923 r
.55031 .2738 .55383 .27865 .56048 .27883 .55697 .27398 Metetra
.508 .65 .922 r
.55697 .27398 .56048 .27883 .56716 .27856 .56366 .27378 Metetra
.543 .672 .922 r
.56366 .27378 .56716 .27856 .57385 .27775 .57036 .27314 Metetra
.58 .698 .923 r
.57036 .27314 .57385 .27775 .58055 .27636 .57708 .27199 Metetra
.617 .727 .925 r
.57708 .27199 .58055 .27636 .58727 .27436 .58381 .27029 Metetra
.654 .759 .927 r
.58381 .27029 .58727 .27436 .59398 .27174 .59054 .26802 Metetra
.689 .791 .928 r
.59054 .26802 .59398 .27174 .6007 .26854 .59728 .26518 Metetra
.721 .823 .928 r
.59728 .26518 .6007 .26854 .60742 .26479 .60402 .26181 Metetra
.75 .852 .926 r
.60402 .26181 .60742 .26479 .61413 .26057 .61076 .25794 Metetra
.774 .879 .923 r
.61076 .25794 .61413 .26057 .62084 .25593 .6175 .25362 Metetra
.792 .901 .918 r
.6175 .25362 .62084 .25593 .62754 .25097 .62423 .24893 Metetra
.806 .918 .913 r
.62423 .24893 .62754 .25097 .63424 .24576 .63095 .24394 Metetra
.816 .932 .908 r
.63095 .24394 .63424 .24576 .64094 .24038 .63768 .23872 Metetra
.822 .941 .904 r
.63768 .23872 .64094 .24038 .64763 .23492 .6444 .23336 Metetra
.824 .947 .902 r
.6444 .23336 .64763 .23492 .65433 .22944 .65112 .22791 Metetra
.824 .95 .902 r
.65112 .22791 .65433 .22944 .66104 .224 .65785 .22245 Metetra
.822 .949 .903 r
.65785 .22245 .66104 .224 .66775 .21865 .66458 .21703 Metetra
.818 .947 .906 r
.66458 .21703 .66775 .21865 .67447 .21344 .67131 .2117 Metetra
.813 .941 .911 r
.67131 .2117 .67447 .21344 .6812 .20838 .67806 .2065 Metetra
.806 .934 .915 r
.67806 .2065 .6812 .20838 .68795 .20351 .68482 .20145 Metetra
.798 .925 .92 r
.68482 .20145 .68795 .20351 .69472 .19882 .6916 .19658 Metetra
.79 .914 .924 r
.6916 .19658 .69472 .19882 .7015 .19433 .69839 .19189 Metetra
.78 .901 .927 r
.69839 .19189 .7015 .19433 .7083 .19004 .7052 .1874 Metetra
.77 .888 .929 r
.7052 .1874 .7083 .19004 .71513 .18594 .71203 .1831 Metetra
.76 .875 .931 r
.71203 .1831 .71513 .18594 .72197 .18202 .71888 .17898 Metetra
.749 .861 .931 r
.71888 .17898 .72197 .18202 .72884 .17827 .72575 .17505 Metetra
.74 .848 .931 r
.72575 .17505 .72884 .17827 .73573 .17468 .73264 .17127 Metetra
.73 .835 .93 r
.73264 .17127 .73573 .17468 .74264 .17122 .73956 .16766 Metetra
.722 .824 .928 r
.73956 .16766 .74264 .17122 .74958 .16789 .7465 .16418 Metetra
.714 .813 .927 r
.7465 .16418 .74958 .16789 .75653 .16467 .75346 .16082 Metetra
.707 .803 .925 r
.75346 .16082 .75653 .16467 .76351 .16156 .76045 .15758 Metetra
.7 .794 .923 r
.76045 .15758 .76351 .16156 .77051 .15852 .76745 .15444 Metetra
.695 .786 .921 r
.76745 .15444 .77051 .15852 .77754 .15556 .77448 .15138 Metetra
.69 .78 .92 r
.77448 .15138 .77754 .15556 .78458 .15267 .78153 .14839 Metetra
.654 .745 .916 r
.15158 .36801 .15562 .37166 .16125 .36972 .15722 .36611 Metetra
.651 .746 .919 r
.15722 .36611 .16125 .36972 .16689 .36782 .16285 .36425 Metetra
.646 .748 .924 r
.16285 .36425 .16689 .36782 .17254 .36597 .1685 .36246 Metetra
.639 .75 .929 r
.1685 .36246 .17254 .36597 .17819 .36417 .17415 .36074 Metetra
.63 .753 .936 r
.17415 .36074 .17819 .36417 .18384 .36246 .1798 .35913 Metetra
.617 .756 .945 r
.1798 .35913 .18384 .36246 .1895 .36085 .18545 .35765 Metetra
.6 .76 .955 r
.18545 .35765 .1895 .36085 .19516 .35937 .19109 .35633 Metetra
.575 .763 .967 r
.19109 .35633 .19516 .35937 .20081 .35805 .19674 .35521 Metetra
.54 .765 .98 r
.19674 .35521 .20081 .35805 .20646 .35693 .20237 .35432 Metetra
.49 .762 .991 r
.20237 .35432 .20646 .35693 .2121 .35605 .20799 .35371 Metetra
.418 .75 .994 r
.20799 .35371 .2121 .35605 .21774 .35544 .2136 .35341 Metetra
.316 .721 .979 r
.2136 .35341 .21774 .35544 .22336 .35514 .2192 .35346 Metetra
.18 .661 .929 r
.2192 .35346 .22336 .35514 .22896 .3552 .22478 .35388 Metetra
.018 .567 .832 r
.22478 .35388 .22896 .3552 .23456 .35563 .23034 .35469 Metetra
0 .446 .696 r
.23034 .35469 .23456 .35563 .24014 .35645 .23589 .35589 Metetra
.283 0 0 r
.23589 .35589 .24014 .35645 .2457 .35766 .24144 .35746 Metetra
.383 0 0 r
.24144 .35746 .2457 .35766 .25127 .35924 .24698 .35935 Metetra
.447 0 0 r
.24698 .35935 .25127 .35924 .25682 .36114 .25253 .36149 Metetra
.483 0 0 r
.25253 .36149 .25682 .36114 .26239 .36329 .25809 .3638 Metetra
.494 0 0 r
.25809 .3638 .26239 .36329 .26797 .36561 .26368 .36614 Metetra
.482 0 0 r
.26368 .36614 .26797 .36561 .27358 .36796 .26931 .3684 Metetra
.442 0 0 r
.26931 .3684 .27358 .36796 .27923 .37022 .27498 .3704 Metetra
.358 0 0 r
.27498 .3704 .27923 .37022 .28492 .37223 .28071 .372 Metetra
.203 0 0 r
.28071 .372 .28492 .37223 .29067 .37384 .28652 .37304 Metetra
.051 .608 .813 r
.28652 .37304 .29067 .37384 .29649 .37488 .29239 .37339 Metetra
.346 .771 .974 r
.29239 .37339 .29649 .37488 .30238 .37523 .29835 .37293 Metetra
.559 .816 .994 r
.29835 .37293 .30238 .37523 .30835 .37478 .30439 .37159 Metetra
.667 .791 .941 r
.30439 .37159 .30835 .37478 .31439 .37346 .31051 .36932 Metetra
.716 .752 .88 r
.31051 .36932 .31439 .37346 .32051 .37122 .3167 .36614 Metetra
.737 .716 .831 r
.3167 .36614 .32051 .37122 .3267 .36808 .32296 .36209 Metetra
.747 .688 .795 r
.32296 .36209 .3267 .36808 .33296 .36409 .32927 .35726 Metetra
.751 .666 .768 r
.32927 .35726 .33296 .36409 .33926 .35934 .33562 .35176 Metetra
.751 .65 .749 r
.33562 .35176 .33926 .35934 .3456 .35394 .34201 .34573 Metetra
.75 .637 .736 r
.34201 .34573 .3456 .35394 .35198 .34804 .34841 .33932 Metetra
.747 .627 .726 r
.34841 .33932 .35198 .34804 .35837 .3418 .35483 .33269 Metetra
.743 .619 .721 r
.35483 .33269 .35837 .3418 .36477 .33536 .36125 .32597 Metetra
.739 .613 .718 r
.36125 .32597 .36477 .33536 .37117 .32888 .36766 .31929 Metetra
.734 .607 .716 r
.36766 .31929 .37117 .32888 .37756 .32249 .37406 .31277 Metetra
.728 .602 .717 r
.37406 .31277 .37756 .32249 .38394 .3163 .38045 .3065 Metetra
.72 .597 .718 r
.38045 .3065 .38394 .3163 .39031 .31041 .38682 .30054 Metetra
.712 .592 .72 r
.38682 .30054 .39031 .31041 .39666 .30489 .39318 .29495 Metetra
.703 .586 .722 r
.39318 .29495 .39666 .30489 .403 .29978 .39952 .28976 Metetra
.692 .579 .724 r
.39952 .28976 .403 .29978 .40932 .29512 .40584 .28499 Metetra
.681 .572 .726 r
.40584 .28499 .40932 .29512 .41563 .2909 .41216 .28064 Metetra
.669 .563 .726 r
.41216 .28064 .41563 .2909 .42193 .28714 .41847 .27671 Metetra
.657 .554 .727 r
.41847 .27671 .42193 .28714 .42823 .28381 .42477 .2732 Metetra
.644 .544 .727 r
.42477 .2732 .42823 .28381 .43453 .28089 .43107 .2701 Metetra
.631 .534 .727 r
.43107 .2701 .43453 .28089 .44083 .27834 .43737 .2674 Metetra
.619 .525 .726 r
.43737 .2674 .44083 .27834 .44713 .27615 .44367 .26509 Metetra
.606 .516 .726 r
.44367 .26509 .44713 .27615 .45344 .27429 .44997 .26316 Metetra
.594 .508 .727 r
.44997 .26316 .45344 .27429 .45976 .27272 .45629 .26159 Metetra
.582 .501 .729 r
.45629 .26159 .45976 .27272 .46609 .27144 .46261 .26039 Metetra
.57 .495 .732 r
.46261 .26039 .46609 .27144 .47244 .27044 .46895 .25954 Metetra
.558 .491 .736 r
.46895 .25954 .47244 .27044 .4788 .26969 .4753 .25902 Metetra
.546 .487 .741 r
.4753 .25902 .4788 .26969 .48518 .26921 .48167 .25883 Metetra
.533 .485 .748 r
.48167 .25883 .48518 .26921 .49158 .26898 .48806 .25894 Metetra
.52 .483 .756 r
.48806 .25894 .49158 .26898 .498 .269 .49447 .25933 Metetra
.506 .483 .765 r
.49447 .25933 .498 .269 .50444 .26924 .50091 .25997 Metetra
.493 .484 .775 r
.50091 .25997 .50444 .26924 .51091 .2697 .50737 .26083 Metetra
.481 .486 .786 r
.50737 .26083 .51091 .2697 .51741 .27033 .51387 .26186 Metetra
.47 .49 .797 r
.51387 .26186 .51741 .27033 .52393 .27107 .52039 .26299 Metetra
.462 .497 .809 r
.52039 .26299 .52393 .27107 .53049 .27187 .52694 .26417 Metetra
.458 .506 .82 r
.52694 .26417 .53049 .27187 .53707 .27265 .53352 .26532 Metetra
.46 .519 .832 r
.53352 .26532 .53707 .27265 .54368 .27332 .54013 .26636 Metetra
.467 .537 .845 r
.54013 .26636 .54368 .27332 .55031 .2738 .54677 .26721 Metetra
.481 .558 .858 r
.54677 .26721 .55031 .2738 .55697 .27398 .55344 .26778 Metetra
.5 .584 .871 r
.55344 .26778 .55697 .27398 .56366 .27378 .56013 .26798 Metetra
.526 .615 .884 r
.56013 .26798 .56366 .27378 .57036 .27314 .56685 .26775 Metetra
.556 .649 .897 r
.56685 .26775 .57036 .27314 .57708 .27199 .57358 .26703 Metetra
.589 .686 .908 r
.57358 .26703 .57708 .27199 .58381 .27029 .58032 .26578 Metetra
.625 .725 .918 r
.58032 .26578 .58381 .27029 .59054 .26802 .58708 .26396 Metetra
.661 .764 .926 r
.58708 .26396 .59054 .26802 .59728 .26518 .59384 .26157 Metetra
.695 .801 .931 r
.59384 .26157 .59728 .26518 .60402 .26181 .60061 .25862 Metetra
.727 .835 .932 r
.60061 .25862 .60402 .26181 .61076 .25794 .60737 .25514 Metetra
.754 .866 .93 r
.60737 .25514 .61076 .25794 .6175 .25362 .61413 .25118 Metetra
.776 .892 .926 r
.61413 .25118 .6175 .25362 .62423 .24893 .62089 .24679 Metetra
.794 .912 .921 r
.62089 .24679 .62423 .24893 .63095 .24394 .62765 .24205 Metetra
.807 .928 .915 r
.62765 .24205 .63095 .24394 .63768 .23872 .6344 .23702 Metetra
.815 .939 .909 r
.6344 .23702 .63768 .23872 .6444 .23336 .64114 .23178 Metetra
.82 .947 .905 r
.64114 .23178 .6444 .23336 .65112 .22791 .64789 .22639 Metetra
.823 .951 .903 r
.64789 .22639 .65112 .22791 .65785 .22245 .65464 .22094 Metetra
.823 .952 .903 r
.65464 .22094 .65785 .22245 .66458 .21703 .66139 .21548 Metetra
.821 .951 .904 r
.66139 .21548 .66458 .21703 .67131 .2117 .66814 .21006 Metetra
.817 .948 .907 r
.66814 .21006 .67131 .2117 .67806 .2065 .67491 .20474 Metetra
.812 .942 .911 r
.67491 .20474 .67806 .2065 .68482 .20145 .68168 .19954 Metetra
.805 .934 .916 r
.68168 .19954 .68482 .20145 .6916 .19658 .68847 .19449 Metetra
.798 .925 .92 r
.68847 .19449 .6916 .19658 .69839 .19189 .69527 .18962 Metetra
.789 .913 .924 r
.69527 .18962 .69839 .19189 .7052 .1874 .70208 .18492 Metetra
.779 .901 .927 r
.70208 .18492 .7052 .1874 .71203 .1831 .70892 .18042 Metetra
.77 .888 .929 r
.70892 .18042 .71203 .1831 .71888 .17898 .71578 .17611 Metetra
.759 .875 .931 r
.71578 .17611 .71888 .17898 .72575 .17505 .72266 .17198 Metetra
.749 .861 .931 r
.72266 .17198 .72575 .17505 .73264 .17127 .72955 .16802 Metetra
.74 .848 .931 r
.72955 .16802 .73264 .17127 .73956 .16766 .73648 .16423 Metetra
.731 .836 .93 r
.73648 .16423 .73956 .16766 .7465 .16418 .74342 .16059 Metetra
.722 .824 .928 r
.74342 .16059 .7465 .16418 .75346 .16082 .75039 .15708 Metetra
.714 .813 .927 r
.75039 .15708 .75346 .16082 .76045 .15758 .75738 .1537 Metetra
.707 .803 .925 r
.75738 .1537 .76045 .15758 .76745 .15444 .76439 .15044 Metetra
.701 .795 .923 r
.76439 .15044 .76745 .15444 .77448 .15138 .77143 .14727 Metetra
.695 .787 .921 r
.77143 .14727 .77448 .15138 .78153 .14839 .77848 .14418 Metetra
.651 .746 .92 r
.14752 .36439 .15158 .36801 .15722 .36611 .15315 .36254 Metetra
.646 .748 .924 r
.15315 .36254 .15722 .36611 .16285 .36425 .15879 .36074 Metetra
.639 .75 .929 r
.15879 .36074 .16285 .36425 .1685 .36246 .16443 .35902 Metetra
.63 .753 .936 r
.16443 .35902 .1685 .36246 .17415 .36074 .17008 .35741 Metetra
.617 .756 .945 r
.17008 .35741 .17415 .36074 .1798 .35913 .17572 .35593 Metetra
.599 .76 .955 r
.17572 .35593 .1798 .35913 .18545 .35765 .18136 .35461 Metetra
.575 .763 .968 r
.18136 .35461 .18545 .35765 .19109 .35633 .18699 .35349 Metetra
.54 .765 .98 r
.18699 .35349 .19109 .35633 .19674 .35521 .19262 .3526 Metetra
.49 .762 .991 r
.19262 .3526 .19674 .35521 .20237 .35432 .19823 .35199 Metetra
.418 .751 .994 r
.19823 .35199 .20237 .35432 .20799 .35371 .20383 .35168 Metetra
.316 .721 .979 r
.20383 .35168 .20799 .35371 .2136 .35341 .20941 .35172 Metetra
.181 .662 .929 r
.20941 .35172 .2136 .35341 .2192 .35346 .21498 .35214 Metetra
.02 .568 .833 r
.21498 .35214 .2192 .35346 .22478 .35388 .22053 .35294 Metetra
0 .448 .698 r
.22053 .35294 .22478 .35388 .23034 .35469 .22607 .35413 Metetra
.281 0 0 r
.22607 .35413 .23034 .35469 .23589 .35589 .2316 .35568 Metetra
.381 0 0 r
.2316 .35568 .23589 .35589 .24144 .35746 .23712 .35756 Metetra
.446 0 0 r
.23712 .35756 .24144 .35746 .24698 .35935 .24265 .35969 Metetra
.482 0 0 r
.24265 .35969 .24698 .35935 .25253 .36149 .24819 .36199 Metetra
.493 0 0 r
.24819 .36199 .25253 .36149 .25809 .3638 .25376 .36433 Metetra
.482 0 0 r
.25376 .36433 .25809 .3638 .26368 .36614 .25937 .36658 Metetra
.442 0 0 r
.25937 .36658 .26368 .36614 .26931 .3684 .26502 .36858 Metetra
.36 0 0 r
.26502 .36858 .26931 .3684 .27498 .3704 .27074 .37018 Metetra
.207 0 0 r
.27074 .37018 .27498 .3704 .28071 .372 .27653 .37123 Metetra
.043 .602 .806 r
.27653 .37123 .28071 .372 .28652 .37304 .28239 .37159 Metetra
.337 .769 .97 r
.28239 .37159 .28652 .37304 .29239 .37339 .28833 .37115 Metetra
.554 .819 .995 r
.28833 .37115 .29239 .37339 .29835 .37293 .29436 .36982 Metetra
.665 .796 .945 r
.29436 .36982 .29835 .37293 .30439 .37159 .30047 .36757 Metetra
.716 .758 .885 r
.30047 .36757 .30439 .37159 .31051 .36932 .30666 .36441 Metetra
.739 .723 .837 r
.30666 .36441 .31051 .36932 .3167 .36614 .31292 .36039 Metetra
.75 .696 .8 r
.31292 .36039 .3167 .36614 .32296 .36209 .31923 .35558 Metetra
.755 .676 .774 r
.31923 .35558 .32296 .36209 .32927 .35726 .32559 .3501 Metetra
.757 .661 .756 r
.32559 .3501 .32927 .35726 .33562 .35176 .33198 .3441 Metetra
.757 .651 .744 r
.33198 .3441 .33562 .35176 .34201 .34573 .33839 .33773 Metetra
.756 .644 .737 r
.33839 .33773 .34201 .34573 .34841 .33932 .34481 .33112 Metetra
.755 .64 .733 r
.34481 .33112 .34841 .33932 .35483 .33269 .35124 .32444 Metetra
.754 .638 .733 r
.35124 .32444 .35483 .33269 .36125 .32597 .35766 .3178 Metetra
.752 .639 .736 r
.35766 .3178 .36125 .32597 .36766 .31929 .36407 .31131 Metetra
.75 .642 .741 r
.36407 .31131 .36766 .31929 .37406 .31277 .37046 .30506 Metetra
.748 .647 .748 r
.37046 .30506 .37406 .31277 .38045 .3065 .37684 .2991 Metetra
.746 .652 .757 r
.37684 .2991 .38045 .3065 .38682 .30054 .3832 .29348 Metetra
.742 .659 .768 r
.3832 .29348 .38682 .30054 .39318 .29495 .38955 .28821 Metetra
.738 .666 .779 r
.38955 .28821 .39318 .29495 .39952 .28976 .39589 .28329 Metetra
.733 .672 .791 r
.39589 .28329 .39952 .28976 .40584 .28499 .40221 .27874 Metetra
.725 .676 .801 r
.40221 .27874 .40584 .28499 .41216 .28064 .40853 .27452 Metetra
.717 .677 .81 r
.40853 .27452 .41216 .28064 .41847 .27671 .41485 .27063 Metetra
.706 .674 .816 r
.41485 .27063 .41847 .27671 .42477 .2732 .42116 .26705 Metetra
.694 .667 .82 r
.42116 .26705 .42477 .2732 .43107 .2701 .42747 .26378 Metetra
.68 .656 .82 r
.42747 .26378 .43107 .2701 .43737 .2674 .43378 .26081 Metetra
.664 .642 .817 r
.43378 .26081 .43737 .2674 .44367 .26509 .44009 .25815 Metetra
.648 .624 .812 r
.44009 .25815 .44367 .26509 .44997 .26316 .44641 .2558 Metetra
.631 .604 .804 r
.44641 .2558 .44997 .26316 .45629 .26159 .45274 .25378 Metetra
.613 .583 .796 r
.45274 .25378 .45629 .26159 .46261 .26039 .45907 .2521 Metetra
.595 .562 .787 r
.45907 .2521 .46261 .26039 .46895 .25954 .46542 .25078 Metetra
.578 .542 .779 r
.46542 .25078 .46895 .25954 .4753 .25902 .47178 .24983 Metetra
.561 .523 .771 r
.47178 .24983 .4753 .25902 .48167 .25883 .47815 .24925 Metetra
.544 .506 .764 r
.47815 .24925 .48167 .25883 .48806 .25894 .48454 .24905 Metetra
.528 .491 .759 r
.48454 .24905 .48806 .25894 .49447 .25933 .49095 .24922 Metetra
.513 .479 .756 r
.49095 .24922 .49447 .25933 .50091 .25997 .49738 .24974 Metetra
.5 .469 .754 r
.49738 .24974 .50091 .25997 .50737 .26083 .50384 .25056 Metetra
.488 .461 .754 r
.50384 .25056 .50737 .26083 .51387 .26186 .51032 .25165 Metetra
.477 .456 .756 r
.51032 .25165 .51387 .26186 .52039 .26299 .51684 .25294 Metetra
.469 .455 .76 r
.51684 .25294 .52039 .26299 .52694 .26417 .52338 .25437 Metetra
.465 .458 .766 r
.52338 .25437 .52694 .26417 .53352 .26532 .52996 .25585 Metetra
.463 .464 .774 r
.52996 .25585 .53352 .26532 .54013 .26636 .53657 .25729 Metetra
.466 .475 .784 r
.53657 .25729 .54013 .26636 .54677 .26721 .54321 .2586 Metetra
.474 .492 .796 r
.54321 .2586 .54677 .26721 .55344 .26778 .54988 .25968 Metetra
.487 .513 .811 r
.54988 .25968 .55344 .26778 .56013 .26798 .55658 .26045 Metetra
.505 .541 .827 r
.55658 .26045 .56013 .26798 .56685 .26775 .5633 .26081 Metetra
.528 .573 .844 r
.5633 .26081 .56685 .26775 .57358 .26703 .57004 .2607 Metetra
.557 .611 .862 r
.57004 .2607 .57358 .26703 .58032 .26578 .5768 .26007 Metetra
.589 .652 .88 r
.5768 .26007 .58032 .26578 .58708 .26396 .58358 .25886 Metetra
.624 .696 .896 r
.58358 .25886 .58708 .26396 .59384 .26157 .59036 .25706 Metetra
.659 .741 .91 r
.59036 .25706 .59384 .26157 .60061 .25862 .59715 .25468 Metetra
.694 .784 .92 r
.59715 .25468 .60061 .25862 .60737 .25514 .60394 .25172 Metetra
.726 .823 .925 r
.60394 .25172 .60737 .25514 .61413 .25118 .61074 .24823 Metetra
.754 .858 .927 r
.61074 .24823 .61413 .25118 .62089 .24679 .61752 .24425 Metetra
.776 .887 .925 r
.61752 .24425 .62089 .24679 .62765 .24205 .62431 .23984 Metetra
.794 .91 .92 r
.62431 .23984 .62765 .24205 .6344 .23702 .63109 .23508 Metetra
.806 .927 .915 r
.63109 .23508 .6344 .23702 .64114 .23178 .63786 .23004 Metetra
.815 .939 .91 r
.63786 .23004 .64114 .23178 .64789 .22639 .64464 .22479 Metetra
.819 .947 .906 r
.64464 .22479 .64789 .22639 .65464 .22094 .65141 .21941 Metetra
.822 .951 .903 r
.65141 .21941 .65464 .22094 .66139 .21548 .65818 .21395 Metetra
.821 .953 .903 r
.65818 .21395 .66139 .21548 .66814 .21006 .66495 .20849 Metetra
.82 .951 .905 r
.66495 .20849 .66814 .21006 .67491 .20474 .67174 .20308 Metetra
.816 .948 .908 r
.67174 .20308 .67491 .20474 .68168 .19954 .67852 .19775 Metetra
.811 .942 .912 r
.67852 .19775 .68168 .19954 .68847 .19449 .68532 .19255 Metetra
.805 .934 .917 r
.68532 .19255 .68847 .19449 .69527 .18962 .69214 .1875 Metetra
.797 .924 .921 r
.69214 .1875 .69527 .18962 .70208 .18492 .69896 .18262 Metetra
.788 .913 .925 r
.69896 .18262 .70208 .18492 .70892 .18042 .70581 .17792 Metetra
.779 .901 .928 r
.70581 .17792 .70892 .18042 .71578 .17611 .71267 .1734 Metetra
.769 .888 .93 r
.71267 .1734 .71578 .17611 .72266 .17198 .71955 .16907 Metetra
.759 .875 .931 r
.71955 .16907 .72266 .17198 .72955 .16802 .72646 .16492 Metetra
.749 .861 .931 r
.72646 .16492 .72955 .16802 .73648 .16423 .73339 .16095 Metetra
.74 .848 .931 r
.73339 .16095 .73648 .16423 .74342 .16059 .74033 .15713 Metetra
.731 .836 .93 r
.74033 .15713 .74342 .16059 .75039 .15708 .74731 .15347 Metetra
.722 .824 .928 r
.74731 .15347 .75039 .15708 .75738 .1537 .7543 .14994 Metetra
.715 .814 .927 r
.7543 .14994 .75738 .1537 .76439 .15044 .76132 .14653 Metetra
.708 .804 .925 r
.76132 .14653 .76439 .15044 .77143 .14727 .76836 .14324 Metetra
.701 .795 .923 r
.76836 .14324 .77143 .14727 .77848 .14418 .77542 .14005 Metetra
.645 .748 .924 r
.14344 .36082 .14752 .36439 .15315 .36254 .14907 .35902 Metetra
.639 .75 .93 r
.14907 .35902 .15315 .36254 .15879 .36074 .1547 .3573 Metetra
.629 .753 .936 r
.1547 .3573 .15879 .36074 .16443 .35902 .16034 .35569 Metetra
.617 .756 .945 r
.16034 .35569 .16443 .35902 .17008 .35741 .16597 .35421 Metetra
.599 .76 .956 r
.16597 .35421 .17008 .35741 .17572 .35593 .1716 .35289 Metetra
.574 .763 .968 r
.1716 .35289 .17572 .35593 .18136 .35461 .17723 .35177 Metetra
.539 .765 .981 r
.17723 .35177 .18136 .35461 .18699 .35349 .18284 .35088 Metetra
.49 .762 .991 r
.18284 .35088 .18699 .35349 .19262 .3526 .18845 .35026 Metetra
.418 .751 .994 r
.18845 .35026 .19262 .3526 .19823 .35199 .19403 .34995 Metetra
.317 .721 .979 r
.19403 .34995 .19823 .35199 .20383 .35168 .19961 .34999 Metetra
.182 .663 .929 r
.19961 .34999 .20383 .35168 .20941 .35172 .20516 .35039 Metetra
.022 .569 .834 r
.20516 .35039 .20941 .35172 .21498 .35214 .2107 .35119 Metetra
0 .449 .7 r
.2107 .35119 .21498 .35214 .22053 .35294 .21622 .35236 Metetra
.278 0 0 r
.21622 .35236 .22053 .35294 .22607 .35413 .22173 .3539 Metetra
.379 0 0 r
.22173 .3539 .22607 .35413 .2316 .35568 .22724 .35577 Metetra
.444 0 0 r
.22724 .35577 .2316 .35568 .23712 .35756 .23275 .35789 Metetra
.48 0 0 r
.23275 .35789 .23712 .35756 .24265 .35969 .23828 .36017 Metetra
.493 0 0 r
.23828 .36017 .24265 .35969 .24819 .36199 .24383 .36251 Metetra
.482 0 0 r
.24383 .36251 .24819 .36199 .25376 .36433 .24941 .36475 Metetra
.443 0 0 r
.24941 .36475 .25376 .36433 .25937 .36658 .25505 .36676 Metetra
.361 0 0 r
.25505 .36676 .25937 .36658 .26502 .36858 .26075 .36836 Metetra
.21 0 0 r
.26075 .36836 .26502 .36858 .27074 .37018 .26651 .36942 Metetra
.037 .598 .802 r
.26651 .36942 .27074 .37018 .27653 .37123 .27236 .36979 Metetra
.331 .766 .968 r
.27236 .36979 .27653 .37123 .28239 .37159 .2783 .36937 Metetra
.549 .819 .996 r
.2783 .36937 .28239 .37159 .28833 .37115 .28431 .36806 Metetra
.663 .798 .947 r
.28431 .36806 .28833 .37115 .29436 .36982 .29042 .36584 Metetra
.715 .76 .888 r
.29042 .36584 .29436 .36982 .30047 .36757 .2966 .36271 Metetra
.739 .725 .839 r
.2966 .36271 .30047 .36757 .30666 .36441 .30285 .35871 Metetra
.75 .698 .802 r
.30285 .35871 .30666 .36441 .31292 .36039 .30917 .35393 Metetra
.755 .678 .776 r
.30917 .35393 .31292 .36039 .31923 .35558 .31553 .34849 Metetra
.757 .663 .758 r
.31553 .34849 .31923 .35558 .32559 .3501 .32192 .34254 Metetra
.757 .653 .746 r
.32192 .34254 .32559 .3501 .33198 .3441 .32834 .33621 Metetra
.757 .646 .739 r
.32834 .33621 .33198 .3441 .33839 .33773 .33477 .32968 Metetra
.756 .643 .736 r
.33477 .32968 .33839 .33773 .34481 .33112 .3412 .32307 Metetra
.755 .643 .737 r
.3412 .32307 .34481 .33112 .35124 .32444 .34762 .31653 Metetra
.754 .645 .741 r
.34762 .31653 .35124 .32444 .35766 .3178 .35403 .31017 Metetra
.753 .65 .748 r
.35403 .31017 .35766 .3178 .36407 .31131 .36043 .30405 Metetra
.752 .658 .758 r
.36043 .30405 .36407 .31131 .37046 .30506 .36681 .29826 Metetra
.751 .669 .771 r
.36681 .29826 .37046 .30506 .37684 .2991 .37317 .29281 Metetra
.75 .683 .787 r
.37317 .29281 .37684 .2991 .3832 .29348 .37952 .28773 Metetra
.749 .7 .805 r
.37952 .28773 .3832 .29348 .38955 .28821 .38585 .28302 Metetra
.747 .719 .826 r
.38585 .28302 .38955 .28821 .39589 .28329 .39217 .27864 Metetra
.745 .741 .848 r
.39217 .27864 .39589 .28329 .40221 .27874 .39849 .27458 Metetra
.741 .763 .871 r
.39849 .27458 .40221 .27874 .40853 .27452 .4048 .2708 Metetra
.735 .785 .893 r
.4048 .2708 .40853 .27452 .41485 .27063 .41111 .26728 Metetra
.727 .805 .913 r
.41111 .26728 .41485 .27063 .42116 .26705 .41743 .26398 Metetra
.717 .82 .929 r
.41743 .26398 .42116 .26705 .42747 .26378 .42374 .26087 Metetra
.705 .828 .941 r
.42374 .26087 .42747 .26378 .43378 .26081 .43006 .25796 Metetra
.691 .829 .949 r
.43006 .25796 .43378 .26081 .44009 .25815 .43639 .25523 Metetra
.678 .822 .953 r
.43639 .25523 .44009 .25815 .44641 .2558 .44273 .2527 Metetra
.663 .807 .952 r
.44273 .2527 .44641 .2558 .45274 .25378 .44907 .25037 Metetra
.648 .784 .947 r
.44907 .25037 .45274 .25378 .45907 .2521 .45543 .24827 Metetra
.63 .754 .936 r
.45543 .24827 .45907 .2521 .46542 .25078 .46179 .24643 Metetra
.611 .718 .921 r
.46179 .24643 .46542 .25078 .47178 .24983 .46817 .24489 Metetra
.591 .679 .902 r
.46817 .24489 .47178 .24983 .47815 .24925 .47456 .24368 Metetra
.57 .641 .882 r
.47456 .24368 .47815 .24925 .48454 .24905 .48096 .24282 Metetra
.548 .603 .861 r
.48096 .24282 .48454 .24905 .49095 .24922 .48738 .24233 Metetra
.528 .57 .841 r
.48738 .24233 .49095 .24922 .49738 .24974 .49382 .24223 Metetra
.51 .54 .823 r
.49382 .24223 .49738 .24974 .50384 .25056 .50028 .2425 Metetra
.493 .515 .808 r
.50028 .2425 .50384 .25056 .51032 .25165 .50677 .24312 Metetra
.48 .495 .796 r
.50677 .24312 .51032 .25165 .51684 .25294 .51328 .24406 Metetra
.469 .481 .787 r
.51328 .24406 .51684 .25294 .52338 .25437 .51982 .24525 Metetra
.462 .471 .782 r
.51982 .24525 .52338 .25437 .52996 .25585 .5264 .24661 Metetra
.458 .467 .78 r
.5264 .24661 .52996 .25585 .53657 .25729 .533 .24808 Metetra
.458 .468 .781 r
.533 .24808 .53657 .25729 .54321 .2586 .53964 .24954 Metetra
.462 .474 .785 r
.53964 .24954 .54321 .2586 .54988 .25968 .54631 .25089 Metetra
.471 .486 .792 r
.54631 .25089 .54988 .25968 .55658 .26045 .553 .25203 Metetra
.485 .504 .803 r
.553 .25203 .55658 .26045 .5633 .26081 .55973 .25287 Metetra
.503 .528 .816 r
.55973 .25287 .5633 .26081 .57004 .2607 .56648 .25331 Metetra
.526 .558 .831 r
.56648 .25331 .57004 .2607 .5768 .26007 .57326 .25328 Metetra
.554 .593 .848 r
.57326 .25328 .5768 .26007 .58358 .25886 .58005 .2527 Metetra
.585 .633 .865 r
.58005 .2527 .58358 .25886 .59036 .25706 .58685 .25155 Metetra
.62 .677 .883 r
.58685 .25155 .59036 .25706 .59715 .25468 .59366 .24981 Metetra
.655 .722 .898 r
.59366 .24981 .59715 .25468 .60394 .25172 .60048 .24746 Metetra
.69 .767 .91 r
.60048 .24746 .60394 .25172 .61074 .24823 .6073 .24453 Metetra
.723 .809 .918 r
.6073 .24453 .61074 .24823 .61752 .24425 .61412 .24107 Metetra
.751 .846 .922 r
.61412 .24107 .61752 .24425 .62431 .23984 .62093 .23711 Metetra
.774 .878 .922 r
.62093 .23711 .62431 .23984 .63109 .23508 .62774 .23272 Metetra
.792 .903 .919 r
.62774 .23272 .63109 .23508 .63786 .23004 .63455 .22798 Metetra
.805 .922 .915 r
.63455 .22798 .63786 .23004 .64464 .22479 .64135 .22296 Metetra
.814 .935 .91 r
.64135 .22296 .64464 .22479 .65141 .21941 .64815 .21772 Metetra
.818 .944 .907 r
.64815 .21772 .65141 .21941 .65818 .21395 .65495 .21235 Metetra
.821 .949 .905 r
.65495 .21235 .65818 .21395 .66495 .20849 .66175 .20691 Metetra
.821 .951 .904 r
.66175 .20691 .66495 .20849 .67174 .20308 .66855 .20145 Metetra
.819 .95 .906 r
.66855 .20145 .67174 .20308 .67852 .19775 .67535 .19604 Metetra
.815 .947 .909 r
.67535 .19604 .67852 .19775 .68532 .19255 .68217 .19072 Metetra
.81 .941 .913 r
.68217 .19072 .68532 .19255 .69214 .1875 .68899 .18552 Metetra
.804 .933 .917 r
.68899 .18552 .69214 .1875 .69896 .18262 .69583 .18046 Metetra
.796 .924 .921 r
.69583 .18046 .69896 .18262 .70581 .17792 .70269 .17557 Metetra
.788 .913 .925 r
.70269 .17557 .70581 .17792 .71267 .1734 .70956 .17086 Metetra
.779 .901 .928 r
.70956 .17086 .71267 .1734 .71955 .16907 .71645 .16634 Metetra
.769 .888 .93 r
.71645 .16634 .71955 .16907 .72646 .16492 .72336 .16199 Metetra
.759 .875 .931 r
.72336 .16199 .72646 .16492 .73339 .16095 .73029 .15782 Metetra
.75 .862 .931 r
.73029 .15782 .73339 .16095 .74033 .15713 .73724 .15382 Metetra
.74 .849 .931 r
.73724 .15382 .74033 .15713 .74731 .15347 .74422 .14999 Metetra
.731 .836 .93 r
.74422 .14999 .74731 .15347 .7543 .14994 .75122 .1463 Metetra
.723 .825 .928 r
.75122 .1463 .7543 .14994 .76132 .14653 .75824 .14275 Metetra
.715 .814 .927 r
.75824 .14275 .76132 .14653 .76836 .14324 .76529 .13932 Metetra
.708 .805 .925 r
.76529 .13932 .76836 .14324 .77542 .14005 .77236 .136 Metetra
.638 .751 .93 r
.13932 .3573 .14344 .36082 .14907 .35902 .14495 .35558 Metetra
.629 .753 .937 r
.14495 .35558 .14907 .35902 .1547 .3573 .15058 .35397 Metetra
.616 .757 .946 r
.15058 .35397 .1547 .3573 .16034 .35569 .15621 .35249 Metetra
.599 .76 .956 r
.15621 .35249 .16034 .35569 .16597 .35421 .16183 .35117 Metetra
.574 .763 .968 r
.16183 .35117 .16597 .35421 .1716 .35289 .16745 .35004 Metetra
.539 .765 .981 r
.16745 .35004 .1716 .35289 .17723 .35177 .17305 .34915 Metetra
.489 .763 .991 r
.17305 .34915 .17723 .35177 .18284 .35088 .17865 .34853 Metetra
.417 .751 .994 r
.17865 .34853 .18284 .35088 .18845 .35026 .18422 .34822 Metetra
.317 .721 .979 r
.18422 .34822 .18845 .35026 .19403 .34995 .18978 .34825 Metetra
.183 .663 .929 r
.18978 .34825 .19403 .34995 .19961 .34999 .19532 .34865 Metetra
.023 .57 .835 r
.19532 .34865 .19961 .34999 .20516 .35039 .20085 .34943 Metetra
0 .451 .702 r
.20085 .34943 .20516 .35039 .2107 .35119 .20635 .3506 Metetra
.276 0 0 r
.20635 .3506 .2107 .35119 .21622 .35236 .21185 .35213 Metetra
.377 0 0 r
.21185 .35213 .21622 .35236 .22173 .3539 .21734 .35398 Metetra
.442 0 0 r
.21734 .35398 .22173 .3539 .22724 .35577 .22283 .35609 Metetra
.479 0 0 r
.22283 .35609 .22724 .35577 .23275 .35789 .22834 .35836 Metetra
.491 0 0 r
.22834 .35836 .23275 .35789 .23828 .36017 .23387 .36068 Metetra
.481 0 0 r
.23387 .36068 .23828 .36017 .24383 .36251 .23944 .36292 Metetra
.442 0 0 r
.23944 .36292 .24383 .36251 .24941 .36475 .24505 .36492 Metetra
.361 0 0 r
.24505 .36492 .24941 .36475 .25505 .36676 .25073 .36653 Metetra
.211 0 0 r
.25073 .36653 .25505 .36676 .26075 .36836 .25648 .3676 Metetra
.034 .596 .8 r
.25648 .3676 .26075 .36836 .26651 .36942 .26232 .36798 Metetra
.328 .765 .968 r
.26232 .36798 .26651 .36942 .27236 .36979 .26824 .36756 Metetra
.547 .818 .996 r
.26824 .36756 .27236 .36979 .2783 .36937 .27425 .36627 Metetra
.662 .797 .947 r
.27425 .36627 .2783 .36937 .28431 .36806 .28034 .36406 Metetra
.714 .759 .888 r
.28034 .36406 .28431 .36806 .29042 .36584 .28652 .36094 Metetra
.738 .724 .838 r
.28652 .36094 .29042 .36584 .2966 .36271 .29278 .35695 Metetra
.749 .697 .802 r
.29278 .35695 .2966 .36271 .30285 .35871 .29909 .35218 Metetra
.754 .676 .775 r
.29909 .35218 .30285 .35871 .30917 .35393 .30545 .34674 Metetra
.755 .66 .757 r
.30545 .34674 .30917 .35393 .31553 .34849 .31186 .34079 Metetra
.755 .649 .744 r
.31186 .34079 .31553 .34849 .32192 .34254 .31828 .33446 Metetra
.754 .642 .737 r
.31828 .33446 .32192 .34254 .32834 .33621 .32472 .32792 Metetra
.752 .637 .733 r
.32472 .32792 .32834 .33621 .33477 .32968 .33116 .32131 Metetra
.75 .635 .733 r
.33116 .32131 .33477 .32968 .3412 .32307 .33759 .31476 Metetra
.748 .635 .735 r
.33759 .31476 .3412 .32307 .34762 .31653 .34401 .3084 Metetra
.745 .637 .74 r
.34401 .3084 .34762 .31653 .35403 .31017 .35041 .3023 Metetra
.742 .641 .748 r
.35041 .3023 .35403 .31017 .36043 .30405 .35679 .29653 Metetra
.739 .647 .758 r
.35679 .29653 .36043 .30405 .36681 .29826 .36316 .29114 Metetra
.735 .655 .771 r
.36316 .29114 .36681 .29826 .37317 .29281 .36951 .28612 Metetra
.731 .665 .785 r
.36951 .28612 .37317 .29281 .37952 .28773 .37584 .28149 Metetra
.727 .677 .801 r
.37584 .28149 .37952 .28773 .38585 .28302 .38216 .27723 Metetra
.723 .691 .819 r
.38216 .27723 .38585 .28302 .39217 .27864 .38847 .27331 Metetra
.718 .706 .838 r
.38847 .27331 .39217 .27864 .39849 .27458 .39478 .26969 Metetra
.713 .723 .858 r
.39478 .26969 .39849 .27458 .4048 .2708 .40108 .26634 Metetra
.708 .741 .878 r
.40108 .26634 .4048 .2708 .41111 .26728 .40739 .26321 Metetra
.702 .76 .897 r
.40739 .26321 .41111 .26728 .41743 .26398 .4137 .26028 Metetra
.695 .779 .916 r
.4137 .26028 .41743 .26398 .42374 .26087 .42001 .2575 Metetra
.687 .796 .933 r
.42001 .2575 .42374 .26087 .43006 .25796 .42634 .25486 Metetra
.677 .811 .947 r
.42634 .25486 .43006 .25796 .43639 .25523 .43267 .25234 Metetra
.666 .822 .958 r
.43267 .25234 .43639 .25523 .44273 .2527 .43902 .24994 Metetra
.654 .828 .967 r
.43902 .24994 .44273 .2527 .44907 .25037 .44537 .24766 Metetra
.641 .828 .972 r
.44537 .24766 .44907 .25037 .45543 .24827 .45174 .24551 Metetra
.627 .821 .975 r
.45174 .24551 .45543 .24827 .46179 .24643 .45812 .24352 Metetra
.613 .806 .974 r
.45812 .24352 .46179 .24643 .46817 .24489 .46451 .24172 Metetra
.597 .785 .97 r
.46451 .24172 .46817 .24489 .47456 .24368 .47092 .24014 Metetra
.58 .756 .962 r
.47092 .24014 .47456 .24368 .48096 .24282 .47734 .23884 Metetra
.561 .721 .948 r
.47734 .23884 .48096 .24282 .48738 .24233 .48378 .23783 Metetra
.542 .683 .931 r
.48378 .23783 .48738 .24233 .49382 .24223 .49023 .23715 Metetra
.522 .644 .91 r
.49023 .23715 .49382 .24223 .50028 .2425 .4967 .23682 Metetra
.503 .606 .888 r
.4967 .23682 .50028 .2425 .50677 .24312 .50319 .23685 Metetra
.487 .572 .868 r
.50319 .23685 .50677 .24312 .51328 .24406 .50971 .23722 Metetra
.473 .544 .849 r
.50971 .23722 .51328 .24406 .51982 .24525 .51625 .2379 Metetra
.462 .521 .833 r
.51625 .2379 .51982 .24525 .5264 .24661 .52283 .23886 Metetra
.455 .504 .82 r
.52283 .23886 .5264 .24661 .533 .24808 .52943 .24001 Metetra
.452 .494 .812 r
.52943 .24001 .533 .24808 .53964 .24954 .53606 .24129 Metetra
.453 .49 .807 r
.53606 .24129 .53964 .24954 .54631 .25089 .54273 .24259 Metetra
.459 .492 .806 r
.54273 .24259 .54631 .25089 .553 .25203 .54943 .24381 Metetra
.469 .501 .809 r
.54943 .24381 .553 .25203 .55973 .25287 .55616 .24486 Metetra
.483 .516 .815 r
.55616 .24486 .55973 .25287 .56648 .25331 .56291 .24562 Metetra
.502 .537 .824 r
.56291 .24562 .56648 .25331 .57326 .25328 .56969 .24601 Metetra
.526 .563 .836 r
.56969 .24601 .57326 .25328 .58005 .2527 .57649 .24594 Metetra
.554 .596 .85 r
.57649 .24594 .58005 .2527 .58685 .25155 .58331 .24536 Metetra
.585 .633 .865 r
.58331 .24536 .58685 .25155 .59366 .24981 .59014 .2442 Metetra
.618 .674 .881 r
.59014 .2442 .59366 .24981 .60048 .24746 .59699 .24246 Metetra
.653 .717 .895 r
.59699 .24246 .60048 .24746 .6073 .24453 .60383 .24013 Metetra
.688 .76 .907 r
.60383 .24013 .6073 .24453 .61412 .24107 .61068 .23723 Metetra
.72 .801 .915 r
.61068 .23723 .61412 .24107 .62093 .23711 .61752 .23378 Metetra
.748 .838 .92 r
.61752 .23378 .62093 .23711 .62774 .23272 .62436 .22985 Metetra
.772 .87 .921 r
.62436 .22985 .62774 .23272 .63455 .22798 .6312 .22549 Metetra
.79 .896 .919 r
.6312 .22549 .63455 .22798 .64135 .22296 .63803 .22077 Metetra
.803 .916 .915 r
.63803 .22077 .64135 .22296 .64815 .21772 .64486 .21577 Metetra
.812 .931 .911 r
.64486 .21577 .64815 .21772 .65495 .21235 .65169 .21056 Metetra
.817 .94 .908 r
.65169 .21056 .65495 .21235 .66175 .20691 .65851 .20521 Metetra
.819 .946 .906 r
.65851 .20521 .66175 .20691 .66855 .20145 .66534 .19978 Metetra
.819 .948 .905 r
.66534 .19978 .66855 .20145 .67535 .19604 .67216 .19434 Metetra
.818 .948 .907 r
.67216 .19434 .67535 .19604 .68217 .19072 .679 .18895 Metetra
.814 .945 .91 r
.679 .18895 .68217 .19072 .68899 .18552 .68584 .18363 Metetra
.809 .939 .913 r
.68584 .18363 .68899 .18552 .69583 .18046 .69269 .17843 Metetra
.803 .932 .918 r
.69269 .17843 .69583 .18046 .70269 .17557 .69955 .17337 Metetra
.796 .923 .922 r
.69955 .17337 .70269 .17557 .70956 .17086 .70644 .16848 Metetra
.787 .912 .925 r
.70644 .16848 .70956 .17086 .71645 .16634 .71333 .16376 Metetra
.778 .9 .928 r
.71333 .16376 .71645 .16634 .72336 .16199 .72025 .15922 Metetra
.769 .888 .93 r
.72025 .15922 .72336 .16199 .73029 .15782 .72719 .15486 Metetra
.759 .875 .931 r
.72719 .15486 .73029 .15782 .73724 .15382 .73415 .15067 Metetra
.75 .862 .931 r
.73415 .15067 .73724 .15382 .74422 .14999 .74113 .14665 Metetra
.74 .849 .931 r
.74113 .14665 .74422 .14999 .75122 .1463 .74813 .14279 Metetra
.731 .837 .93 r
.74813 .14279 .75122 .1463 .75824 .14275 .75516 .13908 Metetra
.723 .825 .928 r
.75516 .13908 .75824 .14275 .76529 .13932 .76221 .1355 Metetra
.715 .815 .927 r
.76221 .1355 .76529 .13932 .77236 .136 .76929 .13205 Metetra
.629 .754 .937 r
.13518 .35386 .13932 .3573 .14495 .35558 .14081 .35225 Metetra
.616 .757 .946 r
.14081 .35225 .14495 .35558 .15058 .35397 .14643 .35076 Metetra
.598 .76 .956 r
.14643 .35076 .15058 .35397 .15621 .35249 .15204 .34944 Metetra
.573 .764 .968 r
.15204 .34944 .15621 .35249 .16183 .35117 .15765 .34832 Metetra
.538 .765 .981 r
.15765 .34832 .16183 .35117 .16745 .35004 .16324 .34743 Metetra
.489 .763 .992 r
.16324 .34743 .16745 .35004 .17305 .34915 .16882 .34681 Metetra
.417 .751 .994 r
.16882 .34681 .17305 .34915 .17865 .34853 .17439 .34649 Metetra
.317 .722 .979 r
.17439 .34649 .17865 .34853 .18422 .34822 .17994 .34652 Metetra
.183 .664 .93 r
.17994 .34652 .18422 .34822 .18978 .34825 .18547 .34691 Metetra
.025 .571 .836 r
.18547 .34691 .18978 .34825 .19532 .34865 .19097 .34768 Metetra
0 .453 .704 r
.19097 .34768 .19532 .34865 .20085 .34943 .19647 .34883 Metetra
.273 0 0 r
.19647 .34883 .20085 .34943 .20635 .3506 .20195 .35035 Metetra
.374 0 0 r
.20195 .35035 .20635 .3506 .21185 .35213 .20742 .35219 Metetra
.44 0 0 r
.20742 .35219 .21185 .35213 .21734 .35398 .2129 .35428 Metetra
.477 0 0 r
.2129 .35428 .21734 .35398 .22283 .35609 .21838 .35654 Metetra
.49 0 0 r
.21838 .35654 .22283 .35609 .22834 .35836 .22389 .35885 Metetra
.479 0 0 r
.22389 .35885 .22834 .35836 .23387 .36068 .22944 .36108 Metetra
.441 0 0 r
.22944 .36108 .23387 .36068 .23944 .36292 .23504 .36308 Metetra
.361 0 0 r
.23504 .36308 .23944 .36292 .24505 .36492 .2407 .36469 Metetra
.212 0 0 r
.2407 .36469 .24505 .36492 .25073 .36653 .24644 .36576 Metetra
.033 .595 .8 r
.24644 .36576 .25073 .36653 .25648 .3676 .25225 .36614 Metetra
.326 .763 .967 r
.25225 .36614 .25648 .3676 .26232 .36798 .25816 .36574 Metetra
.546 .817 .996 r
.25816 .36574 .26232 .36798 .26824 .36756 .26416 .36445 Metetra
.661 .796 .947 r
.26416 .36445 .26824 .36756 .27425 .36627 .27025 .36225 Metetra
.713 .758 .887 r
.27025 .36225 .27425 .36627 .28034 .36406 .27643 .35914 Metetra
.737 .723 .838 r
.27643 .35914 .28034 .36406 .28652 .36094 .28268 .35515 Metetra
.748 .695 .801 r
.28268 .35515 .28652 .36094 .29278 .35695 .289 .35037 Metetra
.753 .674 .774 r
.289 .35037 .29278 .35695 .29909 .35218 .29537 .34492 Metetra
.755 .659 .755 r
.29537 .34492 .29909 .35218 .30545 .34674 .30178 .33894 Metetra
.755 .647 .743 r
.30178 .33894 .30545 .34674 .31186 .34079 .30821 .33258 Metetra
.753 .639 .735 r
.30821 .33258 .31186 .34079 .31828 .33446 .31466 .326 Metetra
.751 .634 .731 r
.31466 .326 .31828 .33446 .32472 .32792 .32111 .31935 Metetra
.749 .631 .73 r
.32111 .31935 .32472 .32792 .33116 .32131 .32755 .31275 Metetra
.746 .63 .731 r
.32755 .31275 .33116 .32131 .33759 .31476 .33398 .30632 Metetra
.742 .63 .735 r
.33398 .30632 .33759 .31476 .34401 .3084 .3404 .30016 Metetra
.738 .632 .742 r
.3404 .30016 .34401 .3084 .35041 .3023 .34679 .29432 Metetra
.734 .635 .75 r
.34679 .29432 .35041 .3023 .35679 .29653 .35316 .28884 Metetra
.729 .64 .759 r
.35316 .28884 .35679 .29653 .36316 .29114 .35952 .28375 Metetra
.723 .644 .77 r
.35952 .28375 .36316 .29114 .36951 .28612 .36585 .27904 Metetra
.717 .65 .781 r
.36585 .27904 .36951 .28612 .37584 .28149 .37218 .27471 Metetra
.71 .655 .793 r
.37218 .27471 .37584 .28149 .38216 .27723 .37849 .27072 Metetra
.704 .661 .805 r
.37849 .27072 .38216 .27723 .38847 .27331 .3848 .26706 Metetra
.697 .666 .816 r
.3848 .26706 .38847 .27331 .39478 .26969 .3911 .26367 Metetra
.69 .672 .828 r
.3911 .26367 .39478 .26969 .40108 .26634 .3974 .26054 Metetra
.683 .678 .838 r
.3974 .26054 .40108 .26634 .40739 .26321 .4037 .25762 Metetra
.677 .683 .848 r
.4037 .25762 .40739 .26321 .4137 .26028 .41001 .25488 Metetra
.672 .689 .858 r
.41001 .25488 .4137 .26028 .42001 .2575 .41633 .25229 Metetra
.666 .696 .868 r
.41633 .25229 .42001 .2575 .42634 .25486 .42266 .24984 Metetra
.661 .703 .878 r
.42266 .24984 .42634 .25486 .43267 .25234 .42899 .2475 Metetra
.656 .71 .887 r
.42899 .2475 .43267 .25234 .43902 .24994 .43534 .24526 Metetra
.651 .716 .896 r
.43534 .24526 .43902 .24994 .44537 .24766 .4417 .24313 Metetra
.644 .722 .905 r
.4417 .24313 .44537 .24766 .45174 .24551 .44808 .2411 Metetra
.637 .726 .912 r
.44808 .2411 .45174 .24551 .45812 .24352 .45446 .23918 Metetra
.627 .727 .919 r
.45446 .23918 .45812 .24352 .46451 .24172 .46086 .2374 Metetra
.615 .724 .923 r
.46086 .2374 .46451 .24172 .47092 .24014 .46728 .23579 Metetra
.6 .716 .926 r
.46728 .23579 .47092 .24014 .47734 .23884 .47371 .23437 Metetra
.583 .704 .925 r
.47371 .23437 .47734 .23884 .48378 .23783 .48016 .23317 Metetra
.565 .686 .921 r
.48016 .23317 .48378 .23783 .49023 .23715 .48662 .23223 Metetra
.545 .664 .914 r
.48662 .23223 .49023 .23715 .4967 .23682 .4931 .23157 Metetra
.525 .638 .904 r
.4931 .23157 .4967 .23682 .50319 .23685 .4996 .23122 Metetra
.506 .612 .892 r
.4996 .23122 .50319 .23685 .50971 .23722 .50613 .23119 Metetra
.488 .585 .878 r
.50613 .23119 .50971 .23722 .51625 .2379 .51267 .23147 Metetra
.473 .561 .864 r
.51267 .23147 .51625 .2379 .52283 .23886 .51925 .23203 Metetra
.462 .54 .851 r
.51925 .23203 .52283 .23886 .52943 .24001 .52585 .23284 Metetra
.455 .524 .84 r
.52585 .23284 .52943 .24001 .53606 .24129 .53249 .23383 Metetra
.452 .514 .831 r
.53249 .23383 .53606 .24129 .54273 .24259 .53915 .23494 Metetra
.453 .509 .826 r
.53915 .23494 .54273 .24259 .54943 .24381 .54585 .23608 Metetra
.459 .51 .824 r
.54585 .23608 .54943 .24381 .55616 .24486 .55257 .23715 Metetra
.47 .518 .825 r
.55257 .23715 .55616 .24486 .56291 .24562 .55933 .23805 Metetra
.485 .531 .829 r
.55933 .23805 .56291 .24562 .56969 .24601 .56612 .23869 Metetra
.504 .55 .836 r
.56612 .23869 .56969 .24601 .57649 .24594 .57293 .23897 Metetra
.528 .575 .846 r
.57293 .23897 .57649 .24594 .58331 .24536 .57976 .23881 Metetra
.556 .606 .858 r
.57976 .23881 .58331 .24536 .59014 .2442 .5866 .23815 Metetra
.587 .641 .871 r
.5866 .23815 .59014 .2442 .59699 .24246 .59346 .23694 Metetra
.62 .679 .885 r
.59346 .23694 .59699 .24246 .60383 .24013 .60033 .23517 Metetra
.654 .72 .897 r
.60033 .23517 .60383 .24013 .61068 .23723 .6072 .23281 Metetra
.687 .761 .908 r
.6072 .23281 .61068 .23723 .61752 .23378 .61408 .2299 Metetra
.719 .8 .915 r
.61408 .2299 .61752 .23378 .62436 .22985 .62095 .22646 Metetra
.746 .836 .92 r
.62095 .22646 .62436 .22985 .6312 .22549 .62782 .22253 Metetra
.77 .867 .921 r
.62782 .22253 .6312 .22549 .63803 .22077 .63468 .21819 Metetra
.788 .893 .919 r
.63468 .21819 .63803 .22077 .64486 .21577 .64154 .2135 Metetra
.801 .913 .916 r
.64154 .2135 .64486 .21577 .65169 .21056 .6484 .20852 Metetra
.81 .927 .912 r
.6484 .20852 .65169 .21056 .65851 .20521 .65525 .20333 Metetra
.816 .937 .909 r
.65525 .20333 .65851 .20521 .66534 .19978 .6621 .198 Metetra
.818 .943 .907 r
.6621 .198 .66534 .19978 .67216 .19434 .66895 .19259 Metetra
.818 .946 .907 r
.66895 .19259 .67216 .19434 .679 .18895 .6758 .18717 Metetra
.816 .946 .908 r
.6758 .18717 .679 .18895 .68584 .18363 .68266 .18179 Metetra
.813 .943 .911 r
.68266 .18179 .68584 .18363 .69269 .17843 .68953 .17648 Metetra
.808 .938 .914 r
.68953 .17648 .69269 .17843 .69955 .17337 .69641 .17128 Metetra
.802 .931 .918 r
.69641 .17128 .69955 .17337 .70644 .16848 .7033 .16623 Metetra
.795 .922 .922 r
.7033 .16623 .70644 .16848 .71333 .16376 .71021 .16133 Metetra
.787 .911 .925 r
.71021 .16133 .71333 .16376 .72025 .15922 .71714 .1566 Metetra
.778 .9 .928 r
.71714 .1566 .72025 .15922 .72719 .15486 .72408 .15205 Metetra
.769 .887 .93 r
.72408 .15205 .72719 .15486 .73415 .15067 .73105 .14767 Metetra
.759 .875 .931 r
.73105 .14767 .73415 .15067 .74113 .14665 .73803 .14347 Metetra
.75 .862 .931 r
.73803 .14347 .74113 .14665 .74813 .14279 .74504 .13943 Metetra
.74 .849 .931 r
.74504 .13943 .74813 .14279 .75516 .13908 .75208 .13555 Metetra
.732 .837 .93 r
.75208 .13555 .75516 .13908 .76221 .1355 .75913 .13181 Metetra
.723 .826 .929 r
.75913 .13181 .76221 .1355 .76929 .13205 .76621 .12821 Metetra
.615 .757 .946 r
.13101 .35052 .13518 .35386 .14081 .35225 .13662 .34904 Metetra
.597 .761 .957 r
.13662 .34904 .14081 .35225 .14643 .35076 .14223 .34772 Metetra
.573 .764 .969 r
.14223 .34772 .14643 .35076 .15204 .34944 .14783 .34659 Metetra
.538 .765 .981 r
.14783 .34659 .15204 .34944 .15765 .34832 .15341 .3457 Metetra
.488 .763 .992 r
.15341 .3457 .15765 .34832 .16324 .34743 .15898 .34508 Metetra
.417 .751 .994 r
.15898 .34508 .16324 .34743 .16882 .34681 .16454 .34476 Metetra
.317 .722 .979 r
.16454 .34476 .16882 .34681 .17439 .34649 .17007 .34478 Metetra
.184 .664 .93 r
.17007 .34478 .17439 .34649 .17994 .34652 .17559 .34516 Metetra
.026 .573 .837 r
.17559 .34516 .17994 .34652 .18547 .34691 .18108 .34592 Metetra
0 .455 .706 r
.18108 .34592 .18547 .34691 .19097 .34768 .18656 .34707 Metetra
.271 0 0 r
.18656 .34707 .19097 .34768 .19647 .34883 .19203 .34857 Metetra
.372 0 0 r
.19203 .34857 .19647 .34883 .20195 .35035 .19748 .35039 Metetra
.438 0 0 r
.19748 .35039 .20195 .35035 .20742 .35219 .20294 .35247 Metetra
.475 0 0 r
.20294 .35247 .20742 .35219 .2129 .35428 .20841 .35472 Metetra
.488 0 0 r
.20841 .35472 .2129 .35428 .21838 .35654 .2139 .35702 Metetra
.478 0 0 r
.2139 .35702 .21838 .35654 .22389 .35885 .21943 .35924 Metetra
.44 0 0 r
.21943 .35924 .22389 .35885 .22944 .36108 .22501 .36123 Metetra
.36 0 0 r
.22501 .36123 .22944 .36108 .23504 .36308 .23065 .36284 Metetra
.212 0 0 r
.23065 .36284 .23504 .36308 .2407 .36469 .23637 .36391 Metetra
.032 .594 .8 r
.23637 .36391 .2407 .36469 .24644 .36576 .24217 .3643 Metetra
.325 .762 .967 r
.24217 .3643 .24644 .36576 .25225 .36614 .24807 .3639 Metetra
.545 .817 .996 r
.24807 .3639 .25225 .36614 .25816 .36574 .25406 .36262 Metetra
.66 .796 .948 r
.25406 .36262 .25816 .36574 .26416 .36445 .26014 .36043 Metetra
.713 .758 .888 r
.26014 .36043 .26416 .36445 .27025 .36225 .26631 .35732 Metetra
.737 .723 .838 r
.26631 .35732 .27025 .36225 .27643 .35914 .27257 .35334 Metetra
.748 .695 .801 r
.27257 .35334 .27643 .35914 .28268 .35515 .27889 .34856 Metetra
.753 .674 .774 r
.27889 .34856 .28268 .35515 .289 .35037 .28526 .3431 Metetra
.755 .659 .755 r
.28526 .3431 .289 .35037 .29537 .34492 .29168 .33711 Metetra
.755 .648 .743 r
.29168 .33711 .29537 .34492 .30178 .33894 .29812 .33073 Metetra
.754 .64 .735 r
.29812 .33073 .30178 .33894 .30821 .33258 .30458 .32413 Metetra
.752 .634 .73 r
.30458 .32413 .30821 .33258 .31466 .326 .31104 .31744 Metetra
.749 .632 .729 r
.31104 .31744 .31466 .326 .32111 .31935 .31749 .3108 Metetra
.747 .631 .731 r
.31749 .3108 .32111 .31935 .32755 .31275 .32394 .30434 Metetra
.743 .632 .736 r
.32394 .30434 .32755 .31275 .33398 .30632 .33036 .29812 Metetra
.74 .634 .742 r
.33036 .29812 .33398 .30632 .3404 .30016 .33676 .29223 Metetra
.736 .638 .75 r
.33676 .29223 .3404 .30016 .34679 .29432 .34314 .2867 Metetra
.731 .643 .76 r
.34314 .2867 .34679 .29432 .35316 .28884 .3495 .28154 Metetra
.726 .648 .771 r
.3495 .28154 .35316 .28884 .35952 .28375 .35584 .27677 Metetra
.721 .654 .782 r
.35584 .27677 .35952 .28375 .36585 .27904 .36217 .27235 Metetra
.714 .66 .794 r
.36217 .27235 .36585 .27904 .37218 .27471 .36849 .26828 Metetra
.708 .665 .806 r
.36849 .26828 .37218 .27471 .37849 .27072 .37479 .26451 Metetra
.701 .67 .816 r
.37479 .26451 .37849 .27072 .3848 .26706 .3811 .26102 Metetra
.694 .673 .825 r
.3811 .26102 .3848 .26706 .3911 .26367 .3874 .25777 Metetra
.687 .676 .833 r
.3874 .25777 .3911 .26367 .3974 .26054 .39371 .25473 Metetra
.68 .677 .84 r
.39371 .25473 .3974 .26054 .4037 .25762 .40001 .25187 Metetra
.674 .677 .845 r
.40001 .25187 .4037 .25762 .41001 .25488 .40633 .24916 Metetra
.668 .676 .849 r
.40633 .24916 .41001 .25488 .41633 .25229 .41265 .24659 Metetra
.662 .675 .852 r
.41265 .24659 .41633 .25229 .42266 .24984 .41898 .24415 Metetra
.656 .673 .855 r
.41898 .24415 .42266 .24984 .42899 .2475 .42533 .24181 Metetra
.651 .672 .857 r
.42533 .24181 .42899 .2475 .43534 .24526 .43168 .23957 Metetra
.645 .67 .859 r
.43168 .23957 .43534 .24526 .4417 .24313 .43805 .23744 Metetra
.639 .668 .862 r
.43805 .23744 .4417 .24313 .44808 .2411 .44443 .23542 Metetra
.633 .666 .864 r
.44443 .23542 .44808 .2411 .45446 .23918 .45082 .23351 Metetra
.625 .663 .867 r
.45082 .23351 .45446 .23918 .46086 .2374 .45723 .23173 Metetra
.616 .66 .87 r
.45723 .23173 .46086 .2374 .46728 .23579 .46365 .23011 Metetra
.606 .655 .872 r
.46365 .23011 .46728 .23579 .47371 .23437 .47008 .22865 Metetra
.594 .649 .874 r
.47008 .22865 .47371 .23437 .48016 .23317 .47654 .22739 Metetra
.579 .64 .875 r
.47654 .22739 .48016 .23317 .48662 .23223 .48301 .22635 Metetra
.563 .629 .875 r
.48301 .22635 .48662 .23223 .4931 .23157 .48949 .22555 Metetra
.546 .615 .872 r
.48949 .22555 .4931 .23157 .4996 .23122 .496 .22503 Metetra
.528 .599 .869 r
.496 .22503 .4996 .23122 .50613 .23119 .50253 .22478 Metetra
.51 .582 .863 r
.50253 .22478 .50613 .23119 .51267 .23147 .50908 .22482 Metetra
.493 .564 .856 r
.50908 .22482 .51267 .23147 .51925 .23203 .51566 .22514 Metetra
.479 .548 .849 r
.51566 .22514 .51925 .23203 .52585 .23284 .52226 .22571 Metetra
.467 .534 .842 r
.52226 .22571 .52585 .23284 .53249 .23383 .5289 .2265 Metetra
.459 .523 .836 r
.5289 .2265 .53249 .23383 .53915 .23494 .53556 .22745 Metetra
.456 .516 .831 r
.53556 .22745 .53915 .23494 .54585 .23608 .54226 .22849 Metetra
.457 .514 .829 r
.54226 .22849 .54585 .23608 .55257 .23715 .54899 .22954 Metetra
.463 .517 .828 r
.54899 .22954 .55257 .23715 .55933 .23805 .55574 .2305 Metetra
.473 .526 .831 r
.55574 .2305 .55933 .23805 .56612 .23869 .56253 .2313 Metetra
.488 .54 .836 r
.56253 .2313 .56612 .23869 .57293 .23897 .56935 .23183 Metetra
.508 .559 .843 r
.56935 .23183 .57293 .23897 .57976 .23881 .57619 .232 Metetra
.531 .584 .853 r
.57619 .232 .57976 .23881 .5866 .23815 .58304 .23175 Metetra
.559 .614 .864 r
.58304 .23175 .5866 .23815 .59346 .23694 .58992 .23101 Metetra
.589 .648 .877 r
.58992 .23101 .59346 .23694 .60033 .23517 .59681 .22974 Metetra
.622 .686 .889 r
.59681 .22974 .60033 .23517 .6072 .23281 .6037 .22791 Metetra
.655 .725 .9 r
.6037 .22791 .6072 .23281 .61408 .2299 .6106 .22552 Metetra
.688 .764 .91 r
.6106 .22552 .61408 .2299 .62095 .22646 .6175 .22258 Metetra
.718 .802 .917 r
.6175 .22258 .62095 .22646 .62782 .22253 .6244 .21912 Metetra
.746 .836 .92 r
.6244 .21912 .62782 .22253 .63468 .21819 .6313 .2152 Metetra
.768 .866 .921 r
.6313 .2152 .63468 .21819 .64154 .2135 .63819 .21086 Metetra
.786 .891 .919 r
.63819 .21086 .64154 .2135 .6484 .20852 .64507 .20618 Metetra
.8 .911 .916 r
.64507 .20618 .6484 .20852 .65525 .20333 .65196 .20122 Metetra
.809 .925 .913 r
.65196 .20122 .65525 .20333 .6621 .198 .65883 .19605 Metetra
.814 .935 .91 r
.65883 .19605 .6621 .198 .66895 .19259 .66571 .19074 Metetra
.817 .941 .908 r
.66571 .19074 .66895 .19259 .6758 .18717 .67259 .18535 Metetra
.817 .943 .908 r
.67259 .18535 .6758 .18717 .68266 .18179 .67947 .17995 Metetra
.815 .943 .909 r
.67947 .17995 .68266 .18179 .68953 .17648 .68636 .17457 Metetra
.812 .941 .911 r
.68636 .17457 .68953 .17648 .69641 .17128 .69325 .16927 Metetra
.807 .936 .915 r
.69325 .16927 .69641 .17128 .7033 .16623 .70016 .16408 Metetra
.801 .929 .918 r
.70016 .16408 .7033 .16623 .71021 .16133 .70708 .15903 Metetra
.794 .92 .922 r
.70708 .15903 .71021 .16133 .71714 .1566 .71401 .15413 Metetra
.786 .91 .925 r
.71401 .15413 .71714 .1566 .72408 .15205 .72097 .14939 Metetra
.778 .899 .928 r
.72097 .14939 .72408 .15205 .73105 .14767 .72794 .14483 Metetra
.768 .887 .93 r
.72794 .14483 .73105 .14767 .73803 .14347 .73493 .14043 Metetra
.759 .874 .931 r
.73493 .14043 .73803 .14347 .74504 .13943 .74195 .13621 Metetra
.75 .862 .931 r
.74195 .13621 .74504 .13943 .75208 .13555 .74899 .13215 Metetra
.741 .849 .931 r
.74899 .13215 .75208 .13555 .75913 .13181 .75605 .12825 Metetra
.732 .838 .93 r
.75605 .12825 .75913 .13181 .76621 .12821 .76313 .12449 Metetra
.597 .761 .957 r
.1268 .34731 .13101 .35052 .13662 .34904 .1324 .34599 Metetra
.572 .764 .969 r
.1324 .34599 .13662 .34904 .14223 .34772 .13799 .34487 Metetra
.537 .766 .982 r
.13799 .34487 .14223 .34772 .14783 .34659 .14356 .34398 Metetra
.487 .763 .992 r
.14356 .34398 .14783 .34659 .15341 .3457 .14913 .34335 Metetra
.416 .751 .994 r
.14913 .34335 .15341 .3457 .15898 .34508 .15467 .34303 Metetra
.317 .722 .979 r
.15467 .34303 .15898 .34508 .16454 .34476 .16019 .34304 Metetra
.185 .665 .93 r
.16019 .34304 .16454 .34476 .17007 .34478 .16569 .34342 Metetra
.028 .574 .838 r
.16569 .34342 .17007 .34478 .17559 .34516 .17117 .34417 Metetra
0 .457 .708 r
.17117 .34417 .17559 .34516 .18108 .34592 .17664 .3453 Metetra
.268 0 0 r
.17664 .3453 .18108 .34592 .18656 .34707 .18208 .34679 Metetra
.369 0 0 r
.18208 .34679 .18656 .34707 .19203 .34857 .18752 .3486 Metetra
.435 0 0 r
.18752 .3486 .19203 .34857 .19748 .35039 .19296 .35066 Metetra
.473 0 0 r
.19296 .35066 .19748 .35039 .20294 .35247 .19841 .35289 Metetra
.486 0 0 r
.19841 .35289 .20294 .35247 .20841 .35472 .20389 .35518 Metetra
.476 0 0 r
.20389 .35518 .20841 .35472 .2139 .35702 .2094 .35739 Metetra
.439 0 0 r
.2094 .35739 .2139 .35702 .21943 .35924 .21496 .35937 Metetra
.359 0 0 r
.21496 .35937 .21943 .35924 .22501 .36123 .22058 .36097 Metetra
.211 0 0 r
.22058 .36097 .22501 .36123 .23065 .36284 .22628 .36204 Metetra
.031 .593 .8 r
.22628 .36204 .23065 .36284 .23637 .36391 .23207 .36244 Metetra
.323 .761 .966 r
.23207 .36244 .23637 .36391 .24217 .3643 .23796 .36205 Metetra
.543 .816 .997 r
.23796 .36205 .24217 .3643 .24807 .3639 .24394 .36078 Metetra
.659 .796 .948 r
.24394 .36078 .24807 .3639 .25406 .36262 .25001 .3586 Metetra
.712 .758 .888 r
.25001 .3586 .25406 .36262 .26014 .36043 .25618 .3555 Metetra
.737 .723 .839 r
.25618 .3555 .26014 .36043 .26631 .35732 .26243 .35152 Metetra
.748 .696 .801 r
.26243 .35152 .26631 .35732 .27257 .35334 .26875 .34675 Metetra
.753 .675 .774 r
.26875 .34675 .27257 .35334 .27889 .34856 .27513 .34129 Metetra
.755 .659 .756 r
.27513 .34129 .27889 .34856 .28526 .3431 .28156 .3353 Metetra
.755 .648 .743 r
.28156 .3353 .28526 .3431 .29168 .33711 .28801 .32891 Metetra
.754 .64 .735 r
.28801 .32891 .29168 .33711 .29812 .33073 .29448 .3223 Metetra
.752 .635 .731 r
.29448 .3223 .29812 .33073 .30458 .32413 .30095 .3156 Metetra
.75 .633 .73 r
.30095 .3156 .30458 .32413 .31104 .31744 .30741 .30895 Metetra
.748 .632 .732 r
.30741 .30895 .31104 .31744 .31749 .3108 .31386 .30247 Metetra
.745 .634 .737 r
.31386 .30247 .31749 .3108 .32394 .30434 .32029 .29625 Metetra
.742 .637 .744 r
.32029 .29625 .32394 .30434 .33036 .29812 .3267 .29034 Metetra
.738 .642 .753 r
.3267 .29034 .33036 .29812 .33676 .29223 .33308 .2848 Metetra
.734 .648 .764 r
.33308 .2848 .33676 .29223 .34314 .2867 .33945 .27964 Metetra
.73 .656 .776 r
.33945 .27964 .34314 .2867 .3495 .28154 .34579 .27486 Metetra
.725 .664 .789 r
.34579 .27486 .3495 .28154 .35584 .27677 .35212 .27045 Metetra
.72 .673 .803 r
.35212 .27045 .35584 .27677 .36217 .27235 .35844 .26636 Metetra
.714 .682 .817 r
.35844 .26636 .36217 .27235 .36849 .26828 .36475 .26258 Metetra
.709 .691 .831 r
.36475 .26258 .36849 .26828 .37479 .26451 .37105 .25907 Metetra
.703 .698 .843 r
.37105 .25907 .37479 .26451 .3811 .26102 .37735 .25578 Metetra
.697 .705 .854 r
.37735 .25578 .3811 .26102 .3874 .25777 .38365 .25269 Metetra
.691 .71 .863 r
.38365 .25269 .3874 .25777 .39371 .25473 .38996 .24976 Metetra
.686 .714 .87 r
.38996 .24976 .39371 .25473 .40001 .25187 .39628 .24697 Metetra
.68 .715 .875 r
.39628 .24697 .40001 .25187 .40633 .24916 .4026 .24429 Metetra
.675 .715 .879 r
.4026 .24429 .40633 .24916 .41265 .24659 .40893 .2417 Metetra
.67 .713 .881 r
.40893 .2417 .41265 .24659 .41898 .24415 .41527 .23921 Metetra
.665 .71 .881 r
.41527 .23921 .41898 .24415 .42533 .24181 .42162 .23679 Metetra
.66 .705 .88 r
.42162 .23679 .42533 .24181 .43168 .23957 .42799 .23446 Metetra
.654 .699 .879 r
.42799 .23446 .43168 .23957 .43805 .23744 .43437 .23221 Metetra
.648 .692 .877 r
.43437 .23221 .43805 .23744 .44443 .23542 .44076 .23006 Metetra
.641 .684 .874 r
.44076 .23006 .44443 .23542 .45082 .23351 .44716 .22801 Metetra
.633 .675 .872 r
.44716 .22801 .45082 .23351 .45723 .23173 .45358 .22609 Metetra
.625 .666 .869 r
.45358 .22609 .45723 .23173 .46365 .23011 .46001 .22432 Metetra
.614 .655 .867 r
.46001 .22432 .46365 .23011 .47008 .22865 .46645 .22271 Metetra
.603 .644 .864 r
.46645 .22271 .47008 .22865 .47654 .22739 .47291 .22128 Metetra
.59 .633 .862 r
.47291 .22128 .47654 .22739 .48301 .22635 .47939 .22008 Metetra
.575 .62 .859 r
.47939 .22008 .48301 .22635 .48949 .22555 .48588 .21911 Metetra
.56 .606 .856 r
.48588 .21911 .48949 .22555 .496 .22503 .49239 .2184 Metetra
.543 .591 .852 r
.49239 .2184 .496 .22503 .50253 .22478 .49893 .21796 Metetra
.526 .576 .848 r
.49893 .21796 .50253 .22478 .50908 .22482 .50548 .2178 Metetra
.51 .561 .843 r
.50548 .2178 .50908 .22482 .51566 .22514 .51206 .21793 Metetra
.495 .546 .838 r
.51206 .21793 .51566 .22514 .52226 .22571 .51867 .21831 Metetra
.481 .533 .833 r
.51867 .21831 .52226 .22571 .5289 .2265 .5253 .21894 Metetra
.47 .522 .829 r
.5253 .21894 .5289 .2265 .53556 .22745 .53197 .21976 Metetra
.463 .514 .826 r
.53197 .21976 .53556 .22745 .54226 .22849 .53866 .22071 Metetra
.46 .51 .824 r
.53866 .22071 .54226 .22849 .54899 .22954 .54539 .22174 Metetra
.461 .511 .823 r
.54539 .22174 .54899 .22954 .55574 .2305 .55215 .22276 Metetra
.466 .516 .825 r
.55215 .22276 .55574 .2305 .56253 .2313 .55894 .22368 Metetra
.477 .526 .83 r
.55894 .22368 .56253 .2313 .56935 .23183 .56575 .22441 Metetra
.492 .542 .836 r
.56575 .22441 .56935 .23183 .57619 .232 .5726 .22487 Metetra
.511 .563 .845 r
.5726 .22487 .57619 .232 .58304 .23175 .57947 .22498 Metetra
.534 .588 .855 r
.57947 .22498 .58304 .23175 .58992 .23101 .58635 .22466 Metetra
.562 .619 .867 r
.58635 .22466 .58992 .23101 .59681 .22974 .59326 .22385 Metetra
.592 .653 .879 r
.59326 .22385 .59681 .22974 .6037 .22791 .60017 .22251 Metetra
.624 .69 .891 r
.60017 .22251 .6037 .22791 .6106 .22552 .6071 .22063 Metetra
.657 .728 .902 r
.6071 .22063 .6106 .22552 .6175 .22258 .61402 .2182 Metetra
.689 .767 .911 r
.61402 .2182 .6175 .22258 .6244 .21912 .62095 .21524 Metetra
.718 .803 .918 r
.62095 .21524 .6244 .21912 .6313 .2152 .62788 .21176 Metetra
.745 .837 .921 r
.62788 .21176 .6313 .2152 .63819 .21086 .6348 .20783 Metetra
.767 .866 .922 r
.6348 .20783 .63819 .21086 .64507 .20618 .64172 .2035 Metetra
.785 .89 .92 r
.64172 .2035 .64507 .20618 .65196 .20122 .64863 .19882 Metetra
.798 .909 .917 r
.64863 .19882 .65196 .20122 .65883 .19605 .65554 .19387 Metetra
.807 .923 .914 r
.65554 .19387 .65883 .19605 .66571 .19074 .66245 .18872 Metetra
.813 .933 .911 r
.66245 .18872 .66571 .19074 .67259 .18535 .66935 .18342 Metetra
.815 .939 .909 r
.66935 .18342 .67259 .18535 .67947 .17995 .67625 .17806 Metetra
.816 .942 .909 r
.67625 .17806 .67947 .17995 .68636 .17457 .68316 .17266 Metetra
.814 .942 .91 r
.68316 .17266 .68636 .17457 .69325 .16927 .69008 .1673 Metetra
.811 .939 .912 r
.69008 .1673 .69325 .16927 .70016 .16408 .697 .16201 Metetra
.806 .934 .915 r
.697 .16201 .70016 .16408 .70708 .15903 .70393 .15683 Metetra
.8 .928 .919 r
.70393 .15683 .70708 .15903 .71401 .15413 .71088 .15177 Metetra
.793 .919 .922 r
.71088 .15177 .71401 .15413 .72097 .14939 .71784 .14687 Metetra
.786 .909 .926 r
.71784 .14687 .72097 .14939 .72794 .14483 .72483 .14212 Metetra
.777 .898 .928 r
.72483 .14212 .72794 .14483 .73493 .14043 .73183 .13755 Metetra
.768 .886 .93 r
.73183 .13755 .73493 .14043 .74195 .13621 .73885 .13314 Metetra
.759 .874 .931 r
.73885 .13314 .74195 .13621 .74899 .13215 .74589 .1289 Metetra
.75 .862 .931 r
.74589 .1289 .74899 .13215 .75605 .12825 .75296 .12482 Metetra
.741 .85 .931 r
.75296 .12482 .75605 .12825 .76313 .12449 .76005 .1209 Metetra
.571 .764 .97 r
.12255 .34427 .1268 .34731 .1324 .34599 .12813 .34314 Metetra
.536 .766 .982 r
.12813 .34314 .1324 .34599 .13799 .34487 .1337 .34225 Metetra
.487 .763 .992 r
.1337 .34225 .13799 .34487 .14356 .34398 .13925 .34162 Metetra
.416 .751 .994 r
.13925 .34162 .14356 .34398 .14913 .34335 .14478 .3413 Metetra
.316 .722 .979 r
.14478 .3413 .14913 .34335 .15467 .34303 .15029 .34131 Metetra
.185 .665 .93 r
.15029 .34131 .15467 .34303 .16019 .34304 .15578 .34167 Metetra
.03 .575 .839 r
.15578 .34167 .16019 .34304 .16569 .34342 .16125 .34242 Metetra
0 .46 .71 r
.16125 .34242 .16569 .34342 .17117 .34417 .16669 .34353 Metetra
.265 0 0 r
.16669 .34353 .17117 .34417 .17664 .3453 .17212 .34501 Metetra
.366 0 0 r
.17212 .34501 .17664 .3453 .18208 .34679 .17755 .3468 Metetra
.432 0 0 r
.17755 .3468 .18208 .34679 .18752 .3486 .18297 .34885 Metetra
.47 0 0 r
.18297 .34885 .18752 .3486 .19296 .35066 .1884 .35107 Metetra
.484 0 0 r
.1884 .35107 .19296 .35066 .19841 .35289 .19385 .35334 Metetra
.474 0 0 r
.19385 .35334 .19841 .35289 .20389 .35518 .19934 .35553 Metetra
.437 0 0 r
.19934 .35553 .20389 .35518 .2094 .35739 .20489 .35751 Metetra
.358 0 0 r
.20489 .35751 .2094 .35739 .21496 .35937 .21049 .3591 Metetra
.21 0 0 r
.21049 .3591 .21496 .35937 .22058 .36097 .21618 .36017 Metetra
.031 .593 .8 r
.21618 .36017 .22058 .36097 .22628 .36204 .22195 .36057 Metetra
.321 .76 .966 r
.22195 .36057 .22628 .36204 .23207 .36244 .22782 .36019 Metetra
.541 .815 .997 r
.22782 .36019 .23207 .36244 .23796 .36205 .23379 .35893 Metetra
.658 .796 .949 r
.23379 .35893 .23796 .36205 .24394 .36078 .23986 .35676 Metetra
.712 .758 .889 r
.23986 .35676 .24394 .36078 .25001 .3586 .24603 .35367 Metetra
.737 .723 .839 r
.24603 .35367 .25001 .3586 .25618 .3555 .25228 .3497 Metetra
.748 .696 .802 r
.25228 .3497 .25618 .3555 .26243 .35152 .2586 .34493 Metetra
.753 .675 .775 r
.2586 .34493 .26243 .35152 .26875 .34675 .26499 .33948 Metetra
.755 .659 .756 r
.26499 .33948 .26875 .34675 .27513 .34129 .27141 .33348 Metetra
.755 .648 .743 r
.27141 .33348 .27513 .34129 .28156 .3353 .27787 .32709 Metetra
.754 .64 .735 r
.27787 .32709 .28156 .3353 .28801 .32891 .28435 .32047 Metetra
.752 .635 .731 r
.28435 .32047 .28801 .32891 .29448 .3223 .29083 .31376 Metetra
.75 .633 .73 r
.29083 .31376 .29448 .3223 .30095 .3156 .2973 .3071 Metetra
.748 .632 .732 r
.2973 .3071 .30095 .3156 .30741 .30895 .30376 .30062 Metetra
.745 .634 .737 r
.30376 .30062 .30741 .30895 .31386 .30247 .3102 .29439 Metetra
.742 .638 .744 r
.3102 .29439 .31386 .30247 .32029 .29625 .31661 .28848 Metetra
.738 .643 .753 r
.31661 .28848 .32029 .29625 .3267 .29034 .323 .28294 Metetra
.734 .649 .765 r
.323 .28294 .3267 .29034 .33308 .2848 .32937 .27779 Metetra
.73 .657 .777 r
.32937 .27779 .33308 .2848 .33945 .27964 .33572 .27302 Metetra
.725 .666 .791 r
.33572 .27302 .33945 .27964 .34579 .27486 .34205 .26862 Metetra
.72 .676 .806 r
.34205 .26862 .34579 .27486 .35212 .27045 .34836 .26457 Metetra
.715 .686 .821 r
.34836 .26457 .35212 .27045 .35844 .26636 .35467 .26081 Metetra
.709 .697 .836 r
.35467 .26081 .35844 .26636 .36475 .26258 .36097 .25733 Metetra
.704 .707 .85 r
.36097 .25733 .36475 .26258 .37105 .25907 .36727 .25408 Metetra
.698 .716 .863 r
.36727 .25408 .37105 .25907 .37735 .25578 .37357 .25102 Metetra
.693 .725 .875 r
.37357 .25102 .37735 .25578 .38365 .25269 .37987 .24811 Metetra
.688 .733 .885 r
.37987 .24811 .38365 .25269 .38996 .24976 .38618 .24533 Metetra
.684 .739 .893 r
.38618 .24533 .38996 .24976 .39628 .24697 .3925 .24265 Metetra
.68 .744 .9 r
.3925 .24265 .39628 .24697 .4026 .24429 .39882 .24005 Metetra
.676 .748 .905 r
.39882 .24005 .4026 .24429 .40893 .2417 .40516 .23751 Metetra
.673 .75 .908 r
.40516 .23751 .40893 .2417 .41527 .23921 .41151 .23502 Metetra
.67 .75 .91 r
.41151 .23502 .41527 .23921 .42162 .23679 .41788 .23258 Metetra
.667 .748 .911 r
.41788 .23258 .42162 .23679 .42799 .23446 .42425 .23019 Metetra
.663 .744 .91 r
.42425 .23019 .42799 .23446 .43437 .23221 .43064 .22785 Metetra
.659 .738 .909 r
.43064 .22785 .43437 .23221 .44076 .23006 .43705 .22557 Metetra
.653 .73 .906 r
.43705 .22557 .44076 .23006 .44716 .22801 .44346 .22337 Metetra
.646 .721 .902 r
.44346 .22337 .44716 .22801 .45358 .22609 .44989 .22127 Metetra
.638 .709 .898 r
.44989 .22127 .45358 .22609 .46001 .22432 .45633 .21928 Metetra
.629 .696 .893 r
.45633 .21928 .46001 .22432 .46645 .22271 .46279 .21744 Metetra
.618 .681 .887 r
.46279 .21744 .46645 .22271 .47291 .22128 .46926 .21577 Metetra
.605 .665 .881 r
.46926 .21577 .47291 .22128 .47939 .22008 .47575 .2143 Metetra
.591 .648 .875 r
.47575 .2143 .47939 .22008 .48588 .21911 .48225 .21306 Metetra
.575 .629 .868 r
.48225 .21306 .48588 .21911 .49239 .2184 .48877 .21207 Metetra
.559 .611 .861 r
.48877 .21207 .49239 .2184 .49893 .21796 .49531 .21135 Metetra
.542 .592 .854 r
.49531 .21135 .49893 .21796 .50548 .2178 .50187 .21092 Metetra
.525 .574 .847 r
.50187 .21092 .50548 .2178 .51206 .21793 .50846 .21078 Metetra
.509 .556 .84 r
.50846 .21078 .51206 .21793 .51867 .21831 .51506 .21092 Metetra
.494 .541 .833 r
.51506 .21092 .51867 .21831 .5253 .21894 .5217 .21133 Metetra
.481 .527 .828 r
.5217 .21133 .5253 .21894 .53197 .21976 .52836 .21197 Metetra
.471 .517 .823 r
.52836 .21197 .53197 .21976 .53866 .22071 .53506 .21281 Metetra
.465 .51 .82 r
.53506 .21281 .53866 .22071 .54539 .22174 .54178 .21377 Metetra
.462 .507 .819 r
.54178 .21377 .54539 .22174 .55215 .22276 .54854 .21479 Metetra
.463 .508 .819 r
.54854 .21479 .55215 .22276 .55894 .22368 .55533 .21579 Metetra
.469 .514 .822 r
.55533 .21579 .55894 .22368 .56575 .22441 .56215 .21668 Metetra
.479 .525 .827 r
.56215 .21668 .56575 .22441 .5726 .22487 .569 .21737 Metetra
.494 .542 .834 r
.569 .21737 .5726 .22487 .57947 .22498 .57587 .21779 Metetra
.513 .563 .844 r
.57587 .21779 .57947 .22498 .58635 .22466 .58277 .21784 Metetra
.537 .589 .854 r
.58277 .21784 .58635 .22466 .59326 .22385 .58969 .21746 Metetra
.564 .62 .867 r
.58969 .21746 .59326 .22385 .60017 .22251 .59662 .21661 Metetra
.594 .654 .879 r
.59662 .21661 .60017 .22251 .6071 .22063 .60356 .21523 Metetra
.625 .691 .891 r
.60356 .21523 .6071 .22063 .61402 .2182 .61052 .2133 Metetra
.657 .729 .902 r
.61052 .2133 .61402 .2182 .62095 .21524 .61747 .21084 Metetra
.689 .767 .911 r
.61747 .21084 .62095 .21524 .62788 .21176 .62443 .20785 Metetra
.718 .804 .918 r
.62443 .20785 .62788 .21176 .6348 .20783 .63138 .20436 Metetra
.744 .837 .921 r
.63138 .20436 .6348 .20783 .64172 .2035 .63833 .20043 Metetra
.766 .865 .922 r
.63833 .20043 .64172 .2035 .64863 .19882 .64527 .19609 Metetra
.784 .889 .92 r
.64527 .19609 .64863 .19882 .65554 .19387 .65221 .19142 Metetra
.796 .907 .918 r
.65221 .19142 .65554 .19387 .66245 .18872 .65915 .18648 Metetra
.805 .921 .915 r
.65915 .18648 .66245 .18872 .66935 .18342 .66608 .18134 Metetra
.811 .931 .912 r
.66608 .18134 .66935 .18342 .67625 .17806 .67301 .17607 Metetra
.814 .937 .91 r
.67301 .17607 .67625 .17806 .68316 .17266 .67995 .17071 Metetra
.814 .94 .91 r
.67995 .17071 .68316 .17266 .69008 .1673 .68688 .16533 Metetra
.813 .94 .911 r
.68688 .16533 .69008 .1673 .697 .16201 .69382 .15998 Metetra
.81 .937 .913 r
.69382 .15998 .697 .16201 .70393 .15683 .70077 .1547 Metetra
.805 .933 .916 r
.70077 .1547 .70393 .15683 .71088 .15177 .70774 .14952 Metetra
.799 .926 .919 r
.70774 .14952 .71088 .15177 .71784 .14687 .71471 .14447 Metetra
.793 .918 .923 r
.71471 .14447 .71784 .14687 .72483 .14212 .7217 .13956 Metetra
.785 .908 .926 r
.7217 .13956 .72483 .14212 .73183 .13755 .72871 .13481 Metetra
.777 .897 .928 r
.72871 .13481 .73183 .13755 .73885 .13314 .73574 .13022 Metetra
.768 .886 .93 r
.73574 .13022 .73885 .13314 .74589 .1289 .74279 .1258 Metetra
.759 .874 .931 r
.74279 .1258 .74589 .1289 .75296 .12482 .74986 .12154 Metetra
.75 .862 .931 r
.74986 .12154 .75296 .12482 .76005 .1209 .75696 .11744 Metetra
.536 .766 .982 r
.11825 .34142 .12255 .34427 .12813 .34314 .12381 .34052 Metetra
.486 .763 .992 r
.12381 .34052 .12813 .34314 .1337 .34225 .12935 .33989 Metetra
.415 .751 .994 r
.12935 .33989 .1337 .34225 .13925 .34162 .13487 .33957 Metetra
.316 .722 .978 r
.13487 .33957 .13925 .34162 .14478 .3413 .14037 .33957 Metetra
.186 .666 .93 r
.14037 .33957 .14478 .3413 .15029 .34131 .14584 .33993 Metetra
.031 .576 .84 r
.14584 .33993 .15029 .34131 .15578 .34167 .1513 .34066 Metetra
0 .462 .712 r
.1513 .34066 .15578 .34167 .16125 .34242 .15673 .34177 Metetra
.262 0 0 r
.15673 .34177 .16125 .34242 .16669 .34353 .16214 .34323 Metetra
.363 0 0 r
.16214 .34323 .16669 .34353 .17212 .34501 .16755 .345 Metetra
.429 0 0 r
.16755 .345 .17212 .34501 .17755 .3468 .17295 .34704 Metetra
.467 0 0 r
.17295 .34704 .17755 .3468 .18297 .34885 .17837 .34923 Metetra
.481 0 0 r
.17837 .34923 .18297 .34885 .1884 .35107 .1838 .35149 Metetra
.472 0 0 r
.1838 .35149 .1884 .35107 .19385 .35334 .18927 .35367 Metetra
.435 0 0 r
.18927 .35367 .19385 .35334 .19934 .35553 .1948 .35563 Metetra
.356 0 0 r
.1948 .35563 .19934 .35553 .20489 .35751 .20039 .35722 Metetra
.209 0 0 r
.20039 .35722 .20489 .35751 .21049 .3591 .20606 .35829 Metetra
.031 .593 .8 r
.20606 .35829 .21049 .3591 .21618 .36017 .21181 .35869 Metetra
.32 .759 .966 r
.21181 .35869 .21618 .36017 .22195 .36057 .21767 .35831 Metetra
.54 .815 .997 r
.21767 .35831 .22195 .36057 .22782 .36019 .22363 .35707 Metetra
.657 .796 .949 r
.22363 .35707 .22782 .36019 .23379 .35893 .22969 .35491 Metetra
.711 .758 .889 r
.22969 .35491 .23379 .35893 .23986 .35676 .23585 .35182 Metetra
.736 .723 .839 r
.23585 .35182 .23986 .35676 .24603 .35367 .2421 .34786 Metetra
.748 .696 .802 r
.2421 .34786 .24603 .35367 .25228 .3497 .24843 .3431 Metetra
.753 .675 .775 r
.24843 .3431 .25228 .3497 .2586 .34493 .25482 .33765 Metetra
.755 .659 .756 r
.25482 .33765 .2586 .34493 .26499 .33948 .26125 .33165 Metetra
.755 .648 .743 r
.26125 .33165 .26499 .33948 .27141 .33348 .26772 .32526 Metetra
.754 .64 .735 r
.26772 .32526 .27141 .33348 .27787 .32709 .27421 .31863 Metetra
.752 .635 .731 r
.27421 .31863 .27787 .32709 .28435 .32047 .2807 .31191 Metetra
.75 .633 .73 r
.2807 .31191 .28435 .32047 .29083 .31376 .28718 .30524 Metetra
.748 .632 .732 r
.28718 .30524 .29083 .31376 .2973 .3071 .29364 .29873 Metetra
.745 .634 .737 r
.29364 .29873 .2973 .3071 .30376 .30062 .30009 .29249 Metetra
.741 .637 .744 r
.30009 .29249 .30376 .30062 .3102 .29439 .30651 .28657 Metetra
.738 .642 .753 r
.30651 .28657 .3102 .29439 .31661 .28848 .31291 .28102 Metetra
.734 .648 .764 r
.31291 .28102 .31661 .28848 .323 .28294 .31928 .27586 Metetra
.729 .655 .776 r
.31928 .27586 .323 .28294 .32937 .27779 .32563 .27109 Metetra
.724 .664 .79 r
.32563 .27109 .32937 .27779 .33572 .27302 .33196 .26669 Metetra
.719 .673 .804 r
.33196 .26669 .33572 .27302 .34205 .26862 .33827 .26263 Metetra
.713 .682 .818 r
.33827 .26263 .34205 .26862 .34836 .26457 .34458 .25889 Metetra
.707 .691 .833 r
.34458 .25889 .34836 .26457 .35467 .26081 .35088 .25542 Metetra
.701 .7 .846 r
.35088 .25542 .35467 .26081 .36097 .25733 .35717 .25218 Metetra
.695 .709 .859 r
.35717 .25218 .36097 .25733 .36727 .25408 .36347 .24914 Metetra
.69 .717 .87 r
.36347 .24914 .36727 .25408 .37357 .25102 .36976 .24626 Metetra
.685 .724 .88 r
.36976 .24626 .37357 .25102 .37987 .24811 .37607 .24351 Metetra
.681 .731 .888 r
.37607 .24351 .37987 .24811 .38618 .24533 .38238 .24087 Metetra
.677 .736 .895 r
.38238 .24087 .38618 .24533 .3925 .24265 .3887 .2383 Metetra
.674 .741 .901 r
.3887 .2383 .3925 .24265 .39882 .24005 .39504 .23578 Metetra
.671 .746 .906 r
.39504 .23578 .39882 .24005 .40516 .23751 .40138 .23332 Metetra
.669 .75 .911 r
.40138 .23332 .40516 .23751 .41151 .23502 .40774 .23088 Metetra
.668 .752 .914 r
.40774 .23088 .41151 .23502 .41788 .23258 .41411 .22848 Metetra
.666 .754 .916 r
.41411 .22848 .41788 .23258 .42425 .23019 .4205 .22609 Metetra
.664 .755 .918 r
.4205 .22609 .42425 .23019 .43064 .22785 .4269 .22374 Metetra
.661 .754 .919 r
.4269 .22374 .43064 .22785 .43705 .22557 .43331 .22142 Metetra
.658 .751 .919 r
.43331 .22142 .43705 .22557 .44346 .22337 .43974 .21914 Metetra
.653 .746 .918 r
.43974 .21914 .44346 .22337 .44989 .22127 .44618 .21693 Metetra
.647 .739 .916 r
.44618 .21693 .44989 .22127 .45633 .21928 .45263 .2148 Metetra
.64 .729 .913 r
.45263 .2148 .45633 .21928 .46279 .21744 .4591 .21278 Metetra
.631 .716 .909 r
.4591 .21278 .46279 .21744 .46926 .21577 .46559 .21089 Metetra
.62 .702 .903 r
.46559 .21089 .46926 .21577 .47575 .2143 .47209 .20917 Metetra
.607 .685 .897 r
.47209 .20917 .47575 .2143 .48225 .21306 .4786 .20765 Metetra
.592 .666 .89 r
.4786 .20765 .48225 .21306 .48877 .21207 .48513 .20635 Metetra
.576 .645 .882 r
.48513 .20635 .48877 .21207 .49531 .21135 .49168 .20531 Metetra
.559 .624 .873 r
.49168 .20531 .49531 .21135 .50187 .21092 .49825 .20455 Metetra
.541 .602 .864 r
.49825 .20455 .50187 .21092 .50846 .21078 .50483 .20407 Metetra
.524 .581 .854 r
.50483 .20407 .50846 .21078 .51506 .21092 .51145 .2039 Metetra
.508 .562 .845 r
.51145 .2039 .51506 .21092 .5217 .21133 .51808 .20401 Metetra
.493 .544 .837 r
.51808 .20401 .5217 .21133 .52836 .21197 .52475 .2044 Metetra
.481 .529 .83 r
.52475 .2044 .52836 .21197 .53506 .21281 .53144 .20502 Metetra
.471 .518 .824 r
.53144 .20502 .53506 .21281 .54178 .21377 .53817 .20583 Metetra
.465 .51 .82 r
.53817 .20583 .54178 .21377 .54854 .21479 .54492 .20677 Metetra
.463 .507 .818 r
.54492 .20677 .54854 .21479 .55533 .21579 .55171 .20776 Metetra
.465 .508 .819 r
.55171 .20776 .55533 .21579 .56215 .21668 .55853 .20873 Metetra
.471 .515 .821 r
.55853 .20873 .56215 .21668 .569 .21737 .56538 .20958 Metetra
.481 .526 .826 r
.56538 .20958 .569 .21737 .57587 .21779 .57226 .21023 Metetra
.496 .542 .834 r
.57226 .21023 .57587 .21779 .58277 .21784 .57917 .2106 Metetra
.516 .564 .843 r
.57917 .2106 .58277 .21784 .58969 .21746 .58609 .21061 Metetra
.539 .59 .854 r
.58609 .21061 .58969 .21746 .59662 .21661 .59304 .21019 Metetra
.565 .621 .866 r
.59304 .21019 .59662 .21661 .60356 .21523 .6 .20928 Metetra
.595 .655 .879 r
.6 .20928 .60356 .21523 .61052 .2133 .60698 .20786 Metetra
.626 .692 .891 r
.60698 .20786 .61052 .2133 .61747 .21084 .61396 .20591 Metetra
.658 .73 .902 r
.61396 .20591 .61747 .21084 .62443 .20785 .62094 .20342 Metetra
.689 .767 .911 r
.62094 .20342 .62443 .20785 .63138 .20436 .62792 .20041 Metetra
.718 .803 .918 r
.62792 .20041 .63138 .20436 .63833 .20043 .6349 .19691 Metetra
.743 .836 .921 r
.6349 .19691 .63833 .20043 .64527 .19609 .64188 .19297 Metetra
.765 .864 .922 r
.64188 .19297 .64527 .19609 .65221 .19142 .64885 .18863 Metetra
.782 .887 .921 r
.64885 .18863 .65221 .19142 .65915 .18648 .65582 .18397 Metetra
.795 .906 .918 r
.65582 .18397 .65915 .18648 .66608 .18134 .66278 .17905 Metetra
.804 .919 .915 r
.66278 .17905 .66608 .18134 .67301 .17607 .66974 .17392 Metetra
.81 .929 .913 r
.66974 .17392 .67301 .17607 .67995 .17071 .6767 .16865 Metetra
.812 .935 .911 r
.6767 .16865 .67995 .17071 .68688 .16533 .68366 .16331 Metetra
.813 .938 .911 r
.68366 .16331 .68688 .16533 .69382 .15998 .69063 .15795 Metetra
.811 .938 .912 r
.69063 .15795 .69382 .15998 .70077 .1547 .6976 .15261 Metetra
.809 .936 .914 r
.6976 .15261 .70077 .1547 .70774 .14952 .70457 .14734 Metetra
.804 .931 .917 r
.70457 .14734 .70774 .14952 .71471 .14447 .71156 .14216 Metetra
.799 .925 .92 r
.71156 .14216 .71471 .14447 .7217 .13956 .71857 .1371 Metetra
.792 .917 .923 r
.71857 .1371 .7217 .13956 .72871 .13481 .72559 .13219 Metetra
.784 .907 .926 r
.72559 .13219 .72871 .13481 .73574 .13022 .73262 .12743 Metetra
.776 .897 .928 r
.73262 .12743 .73574 .13022 .74279 .1258 .73968 .12283 Metetra
.767 .885 .93 r
.73968 .12283 .74279 .1258 .74986 .12154 .74676 .1184 Metetra
.759 .873 .931 r
.74676 .1184 .74986 .12154 .75696 .11744 .75386 .11412 Metetra
.485 .763 .992 r
.1139 .33879 .11825 .34142 .12381 .34052 .11943 .33816 Metetra
.414 .751 .994 r
.11943 .33816 .12381 .34052 .12935 .33989 .12494 .33783 Metetra
.316 .722 .978 r
.12494 .33783 .12935 .33989 .13487 .33957 .13043 .33783 Metetra
.187 .666 .931 r
.13043 .33783 .13487 .33957 .14037 .33957 .13589 .33819 Metetra
.033 .578 .841 r
.13589 .33819 .14037 .33957 .14584 .33993 .14133 .33891 Metetra
0 .464 .714 r
.14133 .33891 .14584 .33993 .1513 .34066 .14674 .34 Metetra
.258 0 0 r
.14674 .34 .1513 .34066 .15673 .34177 .15214 .34145 Metetra
.359 0 0 r
.15214 .34145 .15673 .34177 .16214 .34323 .15753 .34321 Metetra
.426 0 0 r
.15753 .34321 .16214 .34323 .16755 .345 .16292 .34522 Metetra
.465 0 0 r
.16292 .34522 .16755 .345 .17295 .34704 .16831 .3474 Metetra
.479 0 0 r
.16831 .3474 .17295 .34704 .17837 .34923 .17373 .34964 Metetra
.469 0 0 r
.17373 .34964 .17837 .34923 .1838 .35149 .17918 .3518 Metetra
.432 0 0 r
.17918 .3518 .1838 .35149 .18927 .35367 .18469 .35375 Metetra
.353 0 0 r
.18469 .35375 .18927 .35367 .1948 .35563 .19026 .35534 Metetra
.207 0 0 r
.19026 .35534 .1948 .35563 .20039 .35722 .19591 .3564 Metetra
.031 .593 .801 r
.19591 .3564 .20039 .35722 .20606 .35829 .20166 .3568 Metetra
.319 .759 .966 r
.20166 .3568 .20606 .35829 .21181 .35869 .2075 .35643 Metetra
.538 .814 .997 r
.2075 .35643 .21181 .35869 .21767 .35831 .21345 .35519 Metetra
.656 .796 .95 r
.21345 .35519 .21767 .35831 .22363 .35707 .21951 .35304 Metetra
.71 .758 .89 r
.21951 .35304 .22363 .35707 .22969 .35491 .22566 .34997 Metetra
.736 .724 .84 r
.22566 .34997 .22969 .35491 .23585 .35182 .23191 .34602 Metetra
.747 .696 .802 r
.23191 .34602 .23585 .35182 .2421 .34786 .23824 .34126 Metetra
.753 .675 .775 r
.23824 .34126 .2421 .34786 .24843 .3431 .24463 .33582 Metetra
.755 .659 .756 r
.24463 .33582 .24843 .3431 .25482 .33765 .25107 .32982 Metetra
.755 .648 .743 r
.25107 .32982 .25482 .33765 .26125 .33165 .25755 .32342 Metetra
.754 .64 .735 r
.25755 .32342 .26125 .33165 .26772 .32526 .26404 .31678 Metetra
.752 .635 .73 r
.26404 .31678 .26772 .32526 .27421 .31863 .27054 .31004 Metetra
.75 .632 .729 r
.27054 .31004 .27421 .31863 .2807 .31191 .27703 .30336 Metetra
.748 .632 .732 r
.27703 .30336 .2807 .31191 .28718 .30524 .28351 .29684 Metetra
.745 .633 .736 r
.28351 .29684 .28718 .30524 .29364 .29873 .28996 .29058 Metetra
.741 .636 .743 r
.28996 .29058 .29364 .29873 .30009 .29249 .29639 .28464 Metetra
.738 .641 .752 r
.29639 .28464 .30009 .29249 .30651 .28657 .30279 .27908 Metetra
.734 .647 .763 r
.30279 .27908 .30651 .28657 .31291 .28102 .30917 .2739 Metetra
.729 .654 .775 r
.30917 .2739 .31291 .28102 .31928 .27586 .31552 .26911 Metetra
.724 .662 .789 r
.31552 .26911 .31928 .27586 .32563 .27109 .32186 .26469 Metetra
.718 .671 .803 r
.32186 .26469 .32563 .27109 .33196 .26669 .32817 .26062 Metetra
.712 .68 .817 r
.32817 .26062 .33196 .26669 .33827 .26263 .33448 .25687 Metetra
.706 .688 .83 r
.33448 .25687 .33827 .26263 .34458 .25889 .34077 .25338 Metetra
.7 .696 .843 r
.34077 .25338 .34458 .25889 .35088 .25542 .34706 .25014 Metetra
.694 .703 .854 r
.34706 .25014 .35088 .25542 .35717 .25218 .35336 .24709 Metetra
.688 .71 .865 r
.35336 .24709 .35717 .25218 .36347 .24914 .35965 .2442 Metetra
.683 .715 .873 r
.35965 .2442 .36347 .24914 .36976 .24626 .36595 .24145 Metetra
.679 .72 .88 r
.36595 .24145 .36976 .24626 .37607 .24351 .37226 .2388 Metetra
.675 .724 .886 r
.37226 .2388 .37607 .24351 .38238 .24087 .37857 .23623 Metetra
.672 .727 .891 r
.37857 .23623 .38238 .24087 .3887 .2383 .3849 .23372 Metetra
.669 .73 .895 r
.3849 .23372 .3887 .2383 .39504 .23578 .39124 .23127 Metetra
.667 .733 .899 r
.39124 .23127 .39504 .23578 .40138 .23332 .39759 .22884 Metetra
.665 .735 .902 r
.39759 .22884 .40138 .23332 .40774 .23088 .40396 .22645 Metetra
.664 .737 .904 r
.40396 .22645 .40774 .23088 .41411 .22848 .41034 .22407 Metetra
.663 .739 .906 r
.41034 .22407 .41411 .22848 .4205 .22609 .41673 .22171 Metetra
.661 .74 .908 r
.41673 .22171 .4205 .22609 .4269 .22374 .42314 .21937 Metetra
.66 .741 .91 r
.42314 .21937 .4269 .22374 .43331 .22142 .42956 .21706 Metetra
.658 .741 .911 r
.42956 .21706 .43331 .22142 .43974 .21914 .436 .21477 Metetra
.655 .739 .912 r
.436 .21477 .43974 .21914 .44618 .21693 .44245 .21252 Metetra
.651 .737 .912 r
.44245 .21252 .44618 .21693 .45263 .2148 .44892 .21032 Metetra
.646 .732 .912 r
.44892 .21032 .45263 .2148 .4591 .21278 .4554 .20821 Metetra
.639 .725 .911 r
.4554 .20821 .4591 .21278 .46559 .21089 .46189 .20619 Metetra
.63 .716 .908 r
.46189 .20619 .46559 .21089 .47209 .20917 .4684 .2043 Metetra
.619 .704 .905 r
.4684 .2043 .47209 .20917 .4786 .20765 .47493 .20257 Metetra
.607 .689 .9 r
.47493 .20257 .4786 .20765 .48513 .20635 .48147 .20103 Metetra
.592 .671 .895 r
.48147 .20103 .48513 .20635 .49168 .20531 .48803 .19971 Metetra
.576 .652 .887 r
.48803 .19971 .49168 .20531 .49825 .20455 .4946 .19864 Metetra
.559 .631 .879 r
.4946 .19864 .49825 .20455 .50483 .20407 .5012 .19784 Metetra
.542 .609 .87 r
.5012 .19784 .50483 .20407 .51145 .2039 .50782 .19733 Metetra
.524 .588 .86 r
.50782 .19733 .51145 .2039 .51808 .20401 .51446 .19712 Metetra
.508 .567 .851 r
.51446 .19712 .51808 .20401 .52475 .2044 .52112 .19719 Metetra
.493 .549 .842 r
.52112 .19719 .52475 .2044 .53144 .20502 .52782 .19754 Metetra
.481 .533 .834 r
.52782 .19754 .53144 .20502 .53817 .20583 .53454 .19812 Metetra
.472 .521 .827 r
.53454 .19812 .53817 .20583 .54492 .20677 .5413 .19889 Metetra
.466 .513 .823 r
.5413 .19889 .54492 .20677 .55171 .20776 .54808 .19978 Metetra
.464 .51 .82 r
.54808 .19978 .55171 .20776 .55853 .20873 .5549 .20072 Metetra
.466 .511 .82 r
.5549 .20072 .55853 .20873 .56538 .20958 .56176 .20164 Metetra
.473 .517 .823 r
.56176 .20164 .56538 .20958 .57226 .21023 .56864 .20244 Metetra
.483 .528 .827 r
.56864 .20244 .57226 .21023 .57917 .2106 .57555 .20304 Metetra
.498 .544 .834 r
.57555 .20304 .57917 .2106 .58609 .21061 .58248 .20336 Metetra
.518 .566 .843 r
.58248 .20336 .58609 .21061 .59304 .21019 .58944 .20331 Metetra
.541 .592 .854 r
.58944 .20331 .59304 .21019 .6 .20928 .59642 .20284 Metetra
.567 .622 .866 r
.59642 .20284 .6 .20928 .60698 .20786 .60341 .20189 Metetra
.596 .656 .879 r
.60341 .20189 .60698 .20786 .61396 .20591 .61041 .20044 Metetra
.627 .692 .891 r
.61041 .20044 .61396 .20591 .62094 .20342 .61742 .19845 Metetra
.658 .73 .902 r
.61742 .19845 .62094 .20342 .62792 .20041 .62443 .19593 Metetra
.689 .767 .911 r
.62443 .19593 .62792 .20041 .6349 .19691 .63145 .19291 Metetra
.717 .802 .917 r
.63145 .19291 .6349 .19691 .64188 .19297 .63845 .1894 Metetra
.742 .834 .921 r
.63845 .1894 .64188 .19297 .64885 .18863 .64546 .18545 Metetra
.764 .862 .922 r
.64546 .18545 .64885 .18863 .65582 .18397 .65246 .18112 Metetra
.781 .885 .921 r
.65246 .18112 .65582 .18397 .66278 .17905 .65945 .17647 Metetra
.793 .904 .919 r
.65945 .17647 .66278 .17905 .66974 .17392 .66644 .17155 Metetra
.802 .917 .916 r
.66644 .17155 .66974 .17392 .6767 .16865 .67343 .16644 Metetra
.808 .927 .914 r
.67343 .16644 .6767 .16865 .68366 .16331 .68042 .16119 Metetra
.811 .933 .912 r
.68042 .16119 .68366 .16331 .69063 .15795 .68741 .15586 Metetra
.812 .936 .912 r
.68741 .15586 .69063 .15795 .6976 .15261 .6944 .15051 Metetra
.81 .936 .913 r
.6944 .15051 .6976 .15261 .70457 .14734 .7014 .14518 Metetra
.807 .934 .915 r
.7014 .14518 .70457 .14734 .71156 .14216 .7084 .13991 Metetra
.803 .93 .917 r
.7084 .13991 .71156 .14216 .71857 .1371 .71542 .13474 Metetra
.798 .923 .92 r
.71542 .13474 .71857 .1371 .72559 .13219 .72245 .12969 Metetra
.791 .916 .923 r
.72245 .12969 .72559 .13219 .73262 .12743 .7295 .12477 Metetra
.784 .906 .926 r
.7295 .12477 .73262 .12743 .73968 .12283 .73657 .12 Metetra
.776 .896 .928 r
.73657 .12 .73968 .12283 .74676 .1184 .74365 .11539 Metetra
.767 .885 .93 r
.74365 .11539 .74676 .1184 .75386 .11412 .75076 .11094 Metetra
.414 .752 .994 r
.10949 .33643 .1139 .33879 .11943 .33816 .11499 .3361 Metetra
.316 .722 .978 r
.11499 .3361 .11943 .33816 .12494 .33783 .12047 .3361 Metetra
.187 .667 .931 r
.12047 .3361 .12494 .33783 .13043 .33783 .12591 .33644 Metetra
.035 .579 .842 r
.12591 .33644 .13043 .33783 .13589 .33819 .13134 .33716 Metetra
0 .467 .717 r
.13134 .33716 .13589 .33819 .14133 .33891 .13674 .33823 Metetra
.255 0 0 r
.13674 .33823 .14133 .33891 .14674 .34 .14212 .33966 Metetra
.356 0 0 r
.14212 .33966 .14674 .34 .15214 .34145 .1475 .34141 Metetra
.423 0 0 r
.1475 .34141 .15214 .34145 .15753 .34321 .15286 .3434 Metetra
.461 0 0 r
.15286 .3434 .15753 .34321 .16292 .34522 .15824 .34556 Metetra
.476 0 0 r
.15824 .34556 .16292 .34522 .16831 .3474 .16364 .34778 Metetra
.467 0 0 r
.16364 .34778 .16831 .3474 .17373 .34964 .16907 .34993 Metetra
.429 0 0 r
.16907 .34993 .17373 .34964 .17918 .3518 .17456 .35187 Metetra
.351 0 0 r
.17456 .35187 .17918 .3518 .18469 .35375 .18012 .35344 Metetra
.205 0 0 r
.18012 .35344 .18469 .35375 .19026 .35534 .18575 .3545 Metetra
.032 .594 .803 r
.18575 .3545 .19026 .35534 .19591 .3564 .19148 .3549 Metetra
.318 .758 .966 r
.19148 .3549 .19591 .3564 .20166 .3568 .19731 .35453 Metetra
.537 .814 .997 r
.19731 .35453 .20166 .3568 .2075 .35643 .20325 .3533 Metetra
.655 .796 .95 r
.20325 .3533 .2075 .35643 .21345 .35519 .2093 .35116 Metetra
.71 .758 .89 r
.2093 .35116 .21345 .35519 .21951 .35304 .21545 .3481 Metetra
.735 .724 .84 r
.21545 .3481 .21951 .35304 .22566 .34997 .2217 .34416 Metetra
.747 .696 .803 r
.2217 .34416 .22566 .34997 .23191 .34602 .22803 .33941 Metetra
.753 .675 .775 r
.22803 .33941 .23191 .34602 .23824 .34126 .23442 .33397 Metetra
.755 .659 .756 r
.23442 .33397 .23824 .34126 .24463 .33582 .24087 .32797 Metetra
.755 .648 .743 r
.24087 .32797 .24463 .33582 .25107 .32982 .24735 .32157 Metetra
.754 .64 .735 r
.24735 .32157 .25107 .32982 .25755 .32342 .25386 .31492 Metetra
.752 .635 .73 r
.25386 .31492 .25755 .32342 .26404 .31678 .26037 .30818 Metetra
.75 .632 .729 r
.26037 .30818 .26404 .31678 .27054 .31004 .26687 .30148 Metetra
.748 .632 .731 r
.26687 .30148 .27054 .31004 .27703 .30336 .27335 .29494 Metetra
.745 .633 .736 r
.27335 .29494 .27703 .30336 .28351 .29684 .27982 .28867 Metetra
.742 .636 .743 r
.27982 .28867 .28351 .29684 .28996 .29058 .28625 .28272 Metetra
.738 .641 .752 r
.28625 .28272 .28996 .29058 .29639 .28464 .29266 .27713 Metetra
.734 .647 .763 r
.29266 .27713 .29639 .28464 .30279 .27908 .29904 .27194 Metetra
.729 .654 .775 r
.29904 .27194 .30279 .27908 .30917 .2739 .3054 .26714 Metetra
.724 .663 .789 r
.3054 .26714 .30917 .2739 .31552 .26911 .31173 .26271 Metetra
.719 .671 .803 r
.31173 .26271 .31552 .26911 .32186 .26469 .31805 .25863 Metetra
.713 .68 .817 r
.31805 .25863 .32186 .26469 .32817 .26062 .32435 .25486 Metetra
.707 .689 .831 r
.32435 .25486 .32817 .26062 .33448 .25687 .33065 .25137 Metetra
.701 .697 .843 r
.33065 .25137 .33448 .25687 .34077 .25338 .33694 .24811 Metetra
.695 .704 .855 r
.33694 .24811 .34077 .25338 .34706 .25014 .34322 .24505 Metetra
.689 .711 .865 r
.34322 .24505 .34706 .25014 .35336 .24709 .34952 .24215 Metetra
.684 .716 .873 r
.34952 .24215 .35336 .24709 .35965 .2442 .35581 .23938 Metetra
.679 .72 .88 r
.35581 .23938 .35965 .2442 .36595 .24145 .36211 .23671 Metetra
.676 .724 .886 r
.36211 .23671 .36595 .24145 .37226 .2388 .36843 .23413 Metetra
.672 .726 .89 r
.36843 .23413 .37226 .2388 .37857 .23623 .37475 .2316 Metetra
.67 .728 .893 r
.37475 .2316 .37857 .23623 .3849 .23372 .38108 .22912 Metetra
.668 .729 .896 r
.38108 .22912 .3849 .23372 .39124 .23127 .38743 .22668 Metetra
.666 .73 .897 r
.38743 .22668 .39124 .23127 .39759 .22884 .39379 .22427 Metetra
.664 .73 .899 r
.39379 .22427 .39759 .22884 .40396 .22645 .40016 .22187 Metetra
.663 .73 .9 r
.40016 .22187 .40396 .22645 .41034 .22407 .40655 .2195 Metetra
.662 .73 .9 r
.40655 .2195 .41034 .22407 .41673 .22171 .41296 .21713 Metetra
.661 .73 .901 r
.41296 .21713 .41673 .22171 .42314 .21937 .41937 .21479 Metetra
.659 .73 .902 r
.41937 .21479 .42314 .21937 .42956 .21706 .4258 .21246 Metetra
.657 .73 .903 r
.4258 .21246 .42956 .21706 .436 .21477 .43225 .21016 Metetra
.655 .729 .903 r
.43225 .21016 .436 .21477 .44245 .21252 .43871 .20788 Metetra
.652 .727 .904 r
.43871 .20788 .44245 .21252 .44892 .21032 .44519 .20565 Metetra
.648 .724 .904 r
.44519 .20565 .44892 .21032 .4554 .20821 .45168 .20348 Metetra
.643 .72 .904 r
.45168 .20348 .4554 .20821 .46189 .20619 .45819 .20138 Metetra
.636 .714 .903 r
.45819 .20138 .46189 .20619 .4684 .2043 .46471 .19939 Metetra
.628 .706 .902 r
.46471 .19939 .4684 .2043 .47493 .20257 .47124 .19751 Metetra
.618 .695 .9 r
.47124 .19751 .47493 .20257 .48147 .20103 .47779 .1958 Metetra
.605 .682 .896 r
.47779 .1958 .48147 .20103 .48803 .19971 .48436 .19427 Metetra
.591 .667 .892 r
.48436 .19427 .48803 .19971 .4946 .19864 .49095 .19295 Metetra
.576 .649 .886 r
.49095 .19295 .4946 .19864 .5012 .19784 .49755 .19188 Metetra
.559 .63 .878 r
.49755 .19188 .5012 .19784 .50782 .19733 .50417 .19108 Metetra
.542 .61 .87 r
.50417 .19108 .50782 .19733 .51446 .19712 .51082 .19055 Metetra
.525 .589 .862 r
.51082 .19055 .51446 .19712 .52112 .19719 .51749 .19032 Metetra
.508 .57 .853 r
.51749 .19032 .52112 .19719 .52782 .19754 .52419 .19037 Metetra
.494 .552 .844 r
.52419 .19037 .52782 .19754 .53454 .19812 .53091 .19068 Metetra
.482 .536 .836 r
.53091 .19068 .53454 .19812 .5413 .19889 .53767 .19122 Metetra
.473 .525 .83 r
.53767 .19122 .5413 .19889 .54808 .19978 .54445 .19194 Metetra
.467 .517 .825 r
.54445 .19194 .54808 .19978 .5549 .20072 .55127 .19278 Metetra
.466 .513 .823 r
.55127 .19278 .5549 .20072 .56176 .20164 .55812 .19367 Metetra
.468 .514 .822 r
.55812 .19367 .56176 .20164 .56864 .20244 .565 .19453 Metetra
.475 .52 .825 r
.565 .19453 .56864 .20244 .57555 .20304 .57192 .19527 Metetra
.486 .531 .829 r
.57192 .19527 .57555 .20304 .58248 .20336 .57886 .19581 Metetra
.501 .547 .836 r
.57886 .19581 .58248 .20336 .58944 .20331 .58582 .19607 Metetra
.52 .568 .845 r
.58582 .19607 .58944 .20331 .59642 .20284 .59281 .19597 Metetra
.543 .594 .855 r
.59281 .19597 .59642 .20284 .60341 .20189 .59982 .19544 Metetra
.569 .624 .867 r
.59982 .19544 .60341 .20189 .61041 .20044 .60684 .19445 Metetra
.598 .657 .879 r
.60684 .19445 .61041 .20044 .61742 .19845 .61387 .19295 Metetra
.628 .693 .891 r
.61387 .19295 .61742 .19845 .62443 .19593 .62091 .19093 Metetra
.659 .73 .902 r
.62091 .19093 .62443 .19593 .63145 .19291 .62795 .18839 Metetra
.689 .766 .911 r
.62795 .18839 .63145 .19291 .63845 .1894 .63499 .18535 Metetra
.717 .801 .917 r
.63499 .18535 .63845 .1894 .64546 .18545 .64203 .18183 Metetra
.741 .833 .921 r
.64203 .18183 .64546 .18545 .65246 .18112 .64906 .17788 Metetra
.762 .86 .922 r
.64906 .17788 .65246 .18112 .65945 .17647 .65609 .17356 Metetra
.779 .883 .921 r
.65609 .17356 .65945 .17647 .66644 .17155 .66311 .16891 Metetra
.792 .901 .919 r
.66311 .16891 .66644 .17155 .67343 .16644 .67013 .16401 Metetra
.801 .915 .917 r
.67013 .16401 .67343 .16644 .68042 .16119 .67715 .15891 Metetra
.807 .925 .914 r
.67715 .15891 .68042 .16119 .68741 .15586 .68416 .15367 Metetra
.809 .931 .913 r
.68416 .15367 .68741 .15586 .6944 .15051 .69118 .14836 Metetra
.81 .934 .913 r
.69118 .14836 .6944 .15051 .7014 .14518 .6982 .14302 Metetra
.809 .934 .914 r
.6982 .14302 .7014 .14518 .7084 .13991 .70522 .1377 Metetra
.806 .932 .915 r
.70522 .1377 .7084 .13991 .71542 .13474 .71226 .13244 Metetra
.802 .928 .918 r
.71226 .13244 .71542 .13474 .72245 .12969 .7193 .12727 Metetra
.797 .922 .921 r
.7193 .12727 .72245 .12969 .7295 .12477 .72636 .12221 Metetra
.79 .914 .924 r
.72636 .12221 .7295 .12477 .73657 .12 .73344 .11729 Metetra
.783 .905 .926 r
.73344 .11729 .73657 .12 .74365 .11539 .74054 .11252 Metetra
.775 .895 .928 r
.74054 .11252 .74365 .11539 .75076 .11094 .74765 .1079 Metetra
.315 .723 .978 r
.10502 .33437 .10949 .33643 .11499 .3361 .11048 .33436 Metetra
.188 .667 .931 r
.11048 .33436 .11499 .3361 .12047 .3361 .11592 .3347 Metetra
.037 .58 .843 r
.11592 .3347 .12047 .3361 .12591 .33644 .12133 .3354 Metetra
0 .469 .719 r
.12133 .3354 .12591 .33644 .13134 .33716 .12672 .33647 Metetra
.251 0 0 r
.12672 .33647 .13134 .33716 .13674 .33823 .13209 .33788 Metetra
.352 0 0 r
.13209 .33788 .13674 .33823 .14212 .33966 .13744 .3396 Metetra
.419 0 0 r
.13744 .3396 .14212 .33966 .1475 .34141 .14279 .34158 Metetra
.458 0 0 r
.14279 .34158 .1475 .34141 .15286 .3434 .14815 .34372 Metetra
.473 0 0 r
.14815 .34372 .15286 .3434 .15824 .34556 .15353 .34592 Metetra
.464 0 0 r
.15353 .34592 .15824 .34556 .16364 .34778 .15895 .34805 Metetra
.426 0 0 r
.15895 .34805 .16364 .34778 .16907 .34993 .16442 .34997 Metetra
.348 0 0 r
.16442 .34997 .16907 .34993 .17456 .35187 .16995 .35153 Metetra
.202 0 0 r
.16995 .35153 .17456 .35187 .18012 .35344 .17557 .35258 Metetra
.034 .595 .804 r
.17557 .35258 .18012 .35344 .18575 .3545 .18129 .35299 Metetra
.318 .757 .966 r
.18129 .35299 .18575 .3545 .19148 .3549 .18711 .35262 Metetra
.536 .813 .997 r
.18711 .35262 .19148 .3549 .19731 .35453 .19304 .35139 Metetra
.653 .795 .95 r
.19304 .35139 .19731 .35453 .20325 .3533 .19908 .34926 Metetra
.709 .758 .891 r
.19908 .34926 .20325 .3533 .2093 .35116 .20522 .34621 Metetra
.735 .724 .841 r
.20522 .34621 .2093 .35116 .21545 .3481 .21147 .34228 Metetra
.747 .696 .803 r
.21147 .34228 .21545 .3481 .2217 .34416 .21779 .33755 Metetra
.752 .675 .776 r
.21779 .33755 .2217 .34416 .22803 .33941 .22419 .33211 Metetra
.755 .659 .756 r
.22419 .33211 .22803 .33941 .23442 .33397 .23065 .32612 Metetra
.755 .648 .743 r
.23065 .32612 .23442 .33397 .24087 .32797 .23714 .31972 Metetra
.754 .64 .735 r
.23714 .31972 .24087 .32797 .24735 .32157 .24365 .31306 Metetra
.752 .635 .73 r
.24365 .31306 .24735 .32157 .25386 .31492 .25017 .30631 Metetra
.75 .632 .729 r
.25017 .30631 .25386 .31492 .26037 .30818 .25668 .2996 Metetra
.748 .632 .731 r
.25668 .2996 .26037 .30818 .26687 .30148 .26318 .29305 Metetra
.745 .633 .736 r
.26318 .29305 .26687 .30148 .27335 .29494 .26965 .28676 Metetra
.742 .636 .743 r
.26965 .28676 .27335 .29494 .27982 .28867 .27609 .28079 Metetra
.738 .641 .752 r
.27609 .28079 .27982 .28867 .28625 .28272 .2825 .2752 Metetra
.734 .647 .763 r
.2825 .2752 .28625 .28272 .29266 .27713 .28889 .26999 Metetra
.729 .655 .775 r
.28889 .26999 .29266 .27713 .29904 .27194 .29525 .26518 Metetra
.724 .663 .789 r
.29525 .26518 .29904 .27194 .3054 .26714 .30158 .26075 Metetra
.719 .672 .803 r
.30158 .26075 .3054 .26714 .31173 .26271 .3079 .25666 Metetra
.713 .681 .817 r
.3079 .25666 .31173 .26271 .31805 .25863 .3142 .25289 Metetra
.707 .69 .831 r
.3142 .25289 .31805 .25863 .32435 .25486 .3205 .24939 Metetra
.701 .698 .844 r
.3205 .24939 .32435 .25486 .33065 .25137 .32678 .24613 Metetra
.695 .706 .856 r
.32678 .24613 .33065 .25137 .33694 .24811 .33307 .24306 Metetra
.689 .713 .867 r
.33307 .24306 .33694 .24811 .34322 .24505 .33936 .24016 Metetra
.684 .719 .876 r
.33936 .24016 .34322 .24505 .34952 .24215 .34565 .23739 Metetra
.68 .724 .883 r
.34565 .23739 .34952 .24215 .35581 .23938 .35195 .23471 Metetra
.676 .728 .889 r
.35195 .23471 .35581 .23938 .36211 .23671 .35825 .23212 Metetra
.673 .731 .893 r
.35825 .23212 .36211 .23671 .36843 .23413 .36457 .22959 Metetra
.671 .733 .897 r
.36457 .22959 .36843 .23413 .37475 .2316 .3709 .22709 Metetra
.669 .735 .899 r
.3709 .22709 .37475 .2316 .38108 .22912 .37724 .22464 Metetra
.667 .736 .901 r
.37724 .22464 .38108 .22912 .38743 .22668 .3836 .2222 Metetra
.666 .736 .902 r
.3836 .2222 .38743 .22668 .39379 .22427 .38997 .21978 Metetra
.665 .736 .903 r
.38997 .21978 .39379 .22427 .40016 .22187 .39635 .21737 Metetra
.664 .736 .903 r
.39635 .21737 .40016 .22187 .40655 .2195 .40275 .21498 Metetra
.663 .735 .903 r
.40275 .21498 .40655 .2195 .41296 .21713 .40916 .21259 Metetra
.662 .734 .903 r
.40916 .21259 .41296 .21713 .41937 .21479 .41559 .21022 Metetra
.661 .733 .903 r
.41559 .21022 .41937 .21479 .4258 .21246 .42203 .20786 Metetra
.659 .731 .903 r
.42203 .20786 .4258 .21246 .43225 .21016 .42849 .20552 Metetra
.657 .729 .902 r
.42849 .20552 .43225 .21016 .43871 .20788 .43496 .2032 Metetra
.654 .726 .902 r
.43496 .2032 .43871 .20788 .44519 .20565 .44145 .20092 Metetra
.651 .723 .901 r
.44145 .20092 .44519 .20565 .45168 .20348 .44795 .19869 Metetra
.647 .719 .901 r
.44795 .19869 .45168 .20348 .45819 .20138 .45446 .19652 Metetra
.641 .714 .9 r
.45446 .19652 .45819 .20138 .46471 .19939 .46099 .19443 Metetra
.634 .707 .899 r
.46099 .19443 .46471 .19939 .47124 .19751 .46754 .19244 Metetra
.626 .699 .897 r
.46754 .19244 .47124 .19751 .47779 .1958 .4741 .19058 Metetra
.616 .688 .895 r
.4741 .19058 .47779 .1958 .48436 .19427 .48068 .18888 Metetra
.604 .676 .892 r
.48068 .18888 .48436 .19427 .49095 .19295 .48727 .18737 Metetra
.59 .661 .887 r
.48727 .18737 .49095 .19295 .49755 .19188 .49389 .18607 Metetra
.574 .644 .882 r
.49389 .18607 .49755 .19188 .50417 .19108 .50052 .185 Metetra
.558 .626 .876 r
.50052 .185 .50417 .19108 .51082 .19055 .50717 .18421 Metetra
.541 .607 .868 r
.50717 .18421 .51082 .19055 .51749 .19032 .51385 .18368 Metetra
.524 .588 .86 r
.51385 .18368 .51749 .19032 .52419 .19037 .52055 .18344 Metetra
.509 .569 .852 r
.52055 .18344 .52419 .19037 .53091 .19068 .52727 .18347 Metetra
.495 .552 .844 r
.52727 .18347 .53091 .19068 .53767 .19122 .53403 .18376 Metetra
.483 .538 .837 r
.53403 .18376 .53767 .19122 .54445 .19194 .54081 .18427 Metetra
.474 .526 .831 r
.54081 .18427 .54445 .19194 .55127 .19278 .54763 .18495 Metetra
.469 .519 .827 r
.54763 .18495 .55127 .19278 .55812 .19367 .55448 .18574 Metetra
.468 .516 .824 r
.55448 .18574 .55812 .19367 .565 .19453 .56136 .18658 Metetra
.47 .517 .824 r
.56136 .18658 .565 .19453 .57192 .19527 .56827 .18738 Metetra
.477 .523 .826 r
.56827 .18738 .57192 .19527 .57886 .19581 .57522 .18806 Metetra
.488 .534 .831 r
.57522 .18806 .57886 .19581 .58582 .19607 .58219 .18854 Metetra
.503 .55 .838 r
.58219 .18854 .58582 .19607 .59281 .19597 .58919 .18874 Metetra
.522 .571 .846 r
.58919 .18874 .59281 .19597 .59982 .19544 .59621 .18858 Metetra
.545 .597 .857 r
.59621 .18858 .59982 .19544 .60684 .19445 .60325 .188 Metetra
.571 .626 .868 r
.60325 .188 .60684 .19445 .61387 .19295 .6103 .18696 Metetra
.599 .659 .88 r
.6103 .18696 .61387 .19295 .62091 .19093 .61736 .18542 Metetra
.629 .694 .892 r
.61736 .18542 .62091 .19093 .62795 .18839 .62443 .18336 Metetra
.659 .73 .902 r
.62443 .18336 .62795 .18839 .63499 .18535 .63149 .1808 Metetra
.689 .766 .911 r
.63149 .1808 .63499 .18535 .64203 .18183 .63856 .17774 Metetra
.716 .8 .917 r
.63856 .17774 .64203 .18183 .64906 .17788 .64563 .17421 Metetra
.74 .831 .921 r
.64563 .17421 .64906 .17788 .65609 .17356 .65269 .17026 Metetra
.761 .859 .922 r
.65269 .17026 .65609 .17356 .66311 .16891 .65975 .16594 Metetra
.778 .881 .921 r
.65975 .16594 .66311 .16891 .67013 .16401 .6668 .1613 Metetra
.79 .899 .919 r
.6668 .1613 .67013 .16401 .67715 .15891 .67384 .15641 Metetra
.799 .913 .917 r
.67384 .15641 .67715 .15891 .68416 .15367 .68089 .15132 Metetra
.805 .923 .915 r
.68089 .15132 .68416 .15367 .69118 .14836 .68793 .1461 Metetra
.808 .929 .914 r
.68793 .1461 .69118 .14836 .6982 .14302 .69497 .1408 Metetra
.809 .932 .914 r
.69497 .1408 .6982 .14302 .70522 .1377 .70202 .13547 Metetra
.808 .932 .914 r
.70202 .13547 .70522 .1377 .71226 .13244 .70908 .13016 Metetra
.805 .931 .916 r
.70908 .13016 .71226 .13244 .7193 .12727 .71614 .12491 Metetra
.801 .927 .918 r
.71614 .12491 .7193 .12727 .72636 .12221 .72322 .11974 Metetra
.796 .921 .921 r
.72322 .11974 .72636 .12221 .73344 .11729 .73031 .11468 Metetra
.789 .913 .924 r
.73031 .11468 .73344 .11729 .74054 .11252 .73741 .10976 Metetra
.782 .904 .926 r
.73741 .10976 .74054 .11252 .74765 .1079 .74454 .10498 Metetra
.188 .668 .931 r
.10048 .33262 .10502 .33437 .11048 .33436 .10591 .33295 Metetra
.039 .582 .844 r
.10591 .33295 .11048 .33436 .11592 .3347 .1113 .33365 Metetra
0 .472 .721 r
.1113 .33365 .11592 .3347 .12133 .3354 .11667 .3347 Metetra
.247 0 0 r
.11667 .3347 .12133 .3354 .12672 .33647 .12203 .3361 Metetra
.348 0 0 r
.12203 .3361 .12672 .33647 .13209 .33788 .12736 .3378 Metetra
.415 0 0 r
.12736 .3378 .13209 .33788 .13744 .3396 .1327 .33975 Metetra
.454 0 0 r
.1327 .33975 .13744 .3396 .14279 .34158 .13804 .34187 Metetra
.469 0 0 r
.13804 .34187 .14279 .34158 .14815 .34372 .1434 .34405 Metetra
.46 0 0 r
.1434 .34405 .14815 .34372 .15353 .34592 .1488 .34616 Metetra
.423 0 0 r
.1488 .34616 .15353 .34592 .15895 .34805 .15425 .34807 Metetra
.344 0 0 r
.15425 .34807 .15895 .34805 .16442 .34997 .15977 .34962 Metetra
.199 0 0 r
.15977 .34962 .16442 .34997 .16995 .35153 .16537 .35066 Metetra
.036 .596 .806 r
.16537 .35066 .16995 .35153 .17557 .35258 .17107 .35106 Metetra
.318 .757 .966 r
.17107 .35106 .17557 .35258 .18129 .35299 .17688 .35069 Metetra
.535 .812 .997 r
.17688 .35069 .18129 .35299 .18711 .35262 .1828 .34948 Metetra
.652 .795 .951 r
.1828 .34948 .18711 .35262 .19304 .35139 .18883 .34736 Metetra
.708 .758 .891 r
.18883 .34736 .19304 .35139 .19908 .34926 .19497 .34432 Metetra
.734 .724 .841 r
.19497 .34432 .19908 .34926 .20522 .34621 .20121 .3404 Metetra
.747 .696 .803 r
.20121 .3404 .20522 .34621 .21147 .34228 .20754 .33567 Metetra
.752 .675 .776 r
.20754 .33567 .21147 .34228 .21779 .33755 .21395 .33025 Metetra
.754 .659 .756 r
.21395 .33025 .21779 .33755 .22419 .33211 .22041 .32426 Metetra
.755 .648 .743 r
.22041 .32426 .22419 .33211 .23065 .32612 .22691 .31786 Metetra
.754 .64 .735 r
.22691 .31786 .23065 .32612 .23714 .31972 .23343 .3112 Metetra
.752 .635 .73 r
.23343 .3112 .23714 .31972 .24365 .31306 .23995 .30444 Metetra
.75 .632 .729 r
.23995 .30444 .24365 .31306 .25017 .30631 .24648 .29772 Metetra
.748 .632 .731 r
.24648 .29772 .25017 .30631 .25668 .2996 .25298 .29116 Metetra
.745 .633 .736 r
.25298 .29116 .25668 .2996 .26318 .29305 .25946 .28485 Metetra
.742 .636 .743 r
.25946 .28485 .26318 .29305 .26965 .28676 .26591 .27888 Metetra
.738 .641 .752 r
.26591 .27888 .26965 .28676 .27609 .28079 .27233 .27327 Metetra
.734 .647 .763 r
.27233 .27327 .27609 .28079 .2825 .2752 .27872 .26805 Metetra
.73 .655 .775 r
.27872 .26805 .2825 .2752 .28889 .26999 .28508 .26323 Metetra
.724 .663 .789 r
.28508 .26323 .28889 .26999 .29525 .26518 .29142 .25878 Metetra
.719 .672 .803 r
.29142 .25878 .29525 .26518 .30158 .26075 .29774 .25469 Metetra
.713 .681 .818 r
.29774 .25469 .30158 .26075 .3079 .25666 .30404 .25091 Metetra
.707 .69 .832 r
.30404 .25091 .3079 .25666 .3142 .25289 .31033 .24742 Metetra
.701 .699 .845 r
.31033 .24742 .3142 .25289 .3205 .24939 .31661 .24415 Metetra
.695 .707 .857 r
.31661 .24415 .3205 .24939 .32678 .24613 .32289 .24109 Metetra
.689 .714 .867 r
.32289 .24109 .32678 .24613 .33307 .24306 .32918 .23819 Metetra
.684 .72 .876 r
.32918 .23819 .33307 .24306 .33936 .24016 .33546 .23542 Metetra
.68 .725 .884 r
.33546 .23542 .33936 .24016 .34565 .23739 .34176 .23275 Metetra
.676 .729 .89 r
.34176 .23275 .34565 .23739 .35195 .23471 .34806 .23015 Metetra
.673 .733 .895 r
.34806 .23015 .35195 .23471 .35825 .23212 .35437 .22762 Metetra
.671 .735 .899 r
.35437 .22762 .35825 .23212 .36457 .22959 .3607 .22513 Metetra
.669 .738 .902 r
.3607 .22513 .36457 .22959 .3709 .22709 .36703 .22267 Metetra
.668 .739 .904 r
.36703 .22267 .3709 .22709 .37724 .22464 .37338 .22023 Metetra
.666 .74 .905 r
.37338 .22023 .37724 .22464 .3836 .2222 .37975 .2178 Metetra
.666 .741 .906 r
.37975 .2178 .3836 .2222 .38997 .21978 .38612 .21538 Metetra
.665 .741 .907 r
.38612 .21538 .38997 .21978 .39635 .21737 .39252 .21297 Metetra
.664 .742 .907 r
.39252 .21297 .39635 .21737 .40275 .21498 .39892 .21056 Metetra
.664 .741 .908 r
.39892 .21056 .40275 .21498 .40916 .21259 .40535 .20816 Metetra
.663 .741 .907 r
.40535 .20816 .40916 .21259 .41559 .21022 .41178 .20576 Metetra
.662 .739 .907 r
.41178 .20576 .41559 .21022 .42203 .20786 .41824 .20336 Metetra
.661 .738 .907 r
.41824 .20336 .42203 .20786 .42849 .20552 .4247 .20098 Metetra
.66 .736 .906 r
.4247 .20098 .42849 .20552 .43496 .2032 .43119 .19862 Metetra
.658 .733 .905 r
.43119 .19862 .43496 .2032 .44145 .20092 .43768 .19628 Metetra
.655 .73 .905 r
.43768 .19628 .44145 .20092 .44795 .19869 .4442 .19398 Metetra
.651 .726 .903 r
.4442 .19398 .44795 .19869 .45446 .19652 .45072 .19173 Metetra
.647 .721 .902 r
.45072 .19173 .45446 .19652 .46099 .19443 .45726 .18955 Metetra
.641 .714 .901 r
.45726 .18955 .46099 .19443 .46754 .19244 .46382 .18745 Metetra
.634 .707 .899 r
.46382 .18745 .46754 .19244 .4741 .19058 .47039 .18545 Metetra
.625 .697 .897 r
.47039 .18545 .4741 .19058 .48068 .18888 .47698 .1836 Metetra
.614 .686 .894 r
.47698 .1836 .48068 .18888 .48727 .18737 .48359 .1819 Metetra
.602 .673 .89 r
.48359 .1819 .48727 .18737 .49389 .18607 .49021 .18039 Metetra
.588 .658 .885 r
.49021 .18039 .49389 .18607 .50052 .185 .49685 .1791 Metetra
.573 .641 .88 r
.49685 .1791 .50052 .185 .50717 .18421 .50351 .17804 Metetra
.557 .623 .874 r
.50351 .17804 .50717 .18421 .51385 .18368 .51019 .17725 Metetra
.54 .605 .866 r
.51019 .17725 .51385 .18368 .52055 .18344 .51689 .17673 Metetra
.524 .586 .859 r
.51689 .17673 .52055 .18344 .52727 .18347 .52362 .17648 Metetra
.509 .568 .851 r
.52362 .17648 .52727 .18347 .53403 .18376 .53038 .1765 Metetra
.495 .552 .844 r
.53038 .1765 .53403 .18376 .54081 .18427 .53716 .17677 Metetra
.484 .538 .837 r
.53716 .17677 .54081 .18427 .54763 .18495 .54398 .17726 Metetra
.475 .527 .831 r
.54398 .17726 .54763 .18495 .55448 .18574 .55083 .1779 Metetra
.471 .52 .827 r
.55083 .1779 .55448 .18574 .56136 .18658 .55771 .17865 Metetra
.469 .518 .825 r
.55771 .17865 .56136 .18658 .56827 .18738 .56462 .17944 Metetra
.472 .519 .825 r
.56462 .17944 .56827 .18738 .57522 .18806 .57157 .18019 Metetra
.479 .526 .828 r
.57157 .18019 .57522 .18806 .58219 .18854 .57855 .18081 Metetra
.49 .537 .832 r
.57855 .18081 .58219 .18854 .58919 .18874 .58555 .18122 Metetra
.505 .553 .839 r
.58555 .18122 .58919 .18874 .59621 .18858 .59258 .18136 Metetra
.524 .574 .848 r
.59258 .18136 .59621 .18858 .60325 .188 .59963 .18114 Metetra
.547 .599 .858 r
.59963 .18114 .60325 .188 .6103 .18696 .6067 .18051 Metetra
.572 .629 .869 r
.6067 .18051 .6103 .18696 .61736 .18542 .61378 .17941 Metetra
.6 .661 .881 r
.61378 .17941 .61736 .18542 .62443 .18336 .62087 .17783 Metetra
.63 .695 .892 r
.62087 .17783 .62443 .18336 .63149 .1808 .62796 .17574 Metetra
.66 .731 .902 r
.62796 .17574 .63149 .1808 .63856 .17774 .63506 .17315 Metetra
.689 .766 .911 r
.63506 .17315 .63856 .17774 .64563 .17421 .64216 .17007 Metetra
.715 .8 .917 r
.64216 .17007 .64563 .17421 .65269 .17026 .64925 .16654 Metetra
.739 .83 .921 r
.64925 .16654 .65269 .17026 .65975 .16594 .65634 .16258 Metetra
.76 .857 .922 r
.65634 .16258 .65975 .16594 .6668 .1613 .66343 .15826 Metetra
.776 .879 .922 r
.66343 .15826 .6668 .1613 .67384 .15641 .67051 .15363 Metetra
.789 .897 .92 r
.67051 .15363 .67384 .15641 .68089 .15132 .67758 .14875 Metetra
.798 .911 .918 r
.67758 .14875 .68089 .15132 .68793 .1461 .68465 .14368 Metetra
.803 .92 .916 r
.68465 .14368 .68793 .1461 .69497 .1408 .69173 .13847 Metetra
.807 .927 .915 r
.69173 .13847 .69497 .1408 .70202 .13547 .6988 .13318 Metetra
.807 .93 .914 r
.6988 .13318 .70202 .13547 .70908 .13016 .70588 .12787 Metetra
.806 .931 .915 r
.70588 .12787 .70908 .13016 .71614 .12491 .71296 .12257 Metetra
.804 .929 .917 r
.71296 .12257 .71614 .12491 .72322 .11974 .72005 .11732 Metetra
.8 .925 .919 r
.72005 .11732 .72322 .11974 .73031 .11468 .72716 .11215 Metetra
.795 .919 .922 r
.72716 .11215 .73031 .11468 .73741 .10976 .73428 .1071 Metetra
.789 .912 .924 r
.73428 .1071 .73741 .10976 .74454 .10498 .74141 .10217 Metetra
.041 .583 .845 r
.09587 .33121 .10048 .33262 .10591 .33295 .10125 .33189 Metetra
0 .474 .724 r
.10125 .33189 .10591 .33295 .1113 .33365 .10661 .33293 Metetra
.243 0 0 r
.10661 .33293 .1113 .33365 .11667 .3347 .11195 .33431 Metetra
.344 0 0 r
.11195 .33431 .11667 .3347 .12203 .3361 .11727 .33599 Metetra
.411 0 0 r
.11727 .33599 .12203 .3361 .12736 .3378 .12259 .33793 Metetra
.451 0 0 r
.12259 .33793 .12736 .3378 .1327 .33975 .12791 .34002 Metetra
.465 0 0 r
.12791 .34002 .1327 .33975 .13804 .34187 .13325 .34218 Metetra
.457 0 0 r
.13325 .34218 .13804 .34187 .1434 .34405 .13863 .34427 Metetra
.419 0 0 r
.13863 .34427 .1434 .34405 .1488 .34616 .14407 .34616 Metetra
.34 0 0 r
.14407 .34616 .1488 .34616 .15425 .34807 .14957 .34769 Metetra
.195 0 0 r
.14957 .34769 .15425 .34807 .15977 .34962 .15516 .34873 Metetra
.038 .597 .809 r
.15516 .34873 .15977 .34962 .16537 .35066 .16084 .34912 Metetra
.318 .757 .966 r
.16084 .34912 .16537 .35066 .17107 .35106 .16664 .34876 Metetra
.534 .812 .997 r
.16664 .34876 .17107 .35106 .17688 .35069 .17254 .34755 Metetra
.651 .795 .951 r
.17254 .34755 .17688 .35069 .1828 .34948 .17857 .34544 Metetra
.707 .758 .892 r
.17857 .34544 .1828 .34948 .18883 .34736 .1847 .34241 Metetra
.734 .724 .842 r
.1847 .34241 .18883 .34736 .19497 .34432 .19094 .33851 Metetra
.746 .696 .804 r
.19094 .33851 .19497 .34432 .20121 .3404 .19727 .33379 Metetra
.752 .675 .776 r
.19727 .33379 .20121 .3404 .20754 .33567 .20368 .32838 Metetra
.754 .659 .757 r
.20368 .32838 .20754 .33567 .21395 .33025 .21015 .32239 Metetra
.755 .648 .743 r
.21015 .32239 .21395 .33025 .22041 .32426 .21665 .31599 Metetra
.754 .64 .735 r
.21665 .31599 .22041 .32426 .22691 .31786 .22318 .30933 Metetra
.752 .635 .73 r
.22318 .30933 .22691 .31786 .23343 .3112 .22972 .30257 Metetra
.75 .632 .729 r
.22972 .30257 .23343 .3112 .23995 .30444 .23625 .29584 Metetra
.748 .632 .731 r
.23625 .29584 .23995 .30444 .24648 .29772 .24276 .28926 Metetra
.745 .633 .736 r
.24276 .28926 .24648 .29772 .25298 .29116 .24925 .28295 Metetra
.742 .636 .743 r
.24925 .28295 .25298 .29116 .25946 .28485 .25571 .27695 Metetra
.738 .641 .752 r
.25571 .27695 .25946 .28485 .26591 .27888 .26213 .27133 Metetra
.734 .647 .763 r
.26213 .27133 .26591 .27888 .27233 .27327 .26853 .26611 Metetra
.73 .655 .775 r
.26853 .26611 .27233 .27327 .27872 .26805 .27489 .26127 Metetra
.725 .663 .789 r
.27489 .26127 .27872 .26805 .28508 .26323 .28123 .25682 Metetra
.719 .672 .803 r
.28123 .25682 .28508 .26323 .29142 .25878 .28755 .25272 Metetra
.713 .681 .818 r
.28755 .25272 .29142 .25878 .29774 .25469 .29385 .24894 Metetra
.707 .69 .832 r
.29385 .24894 .29774 .25469 .30404 .25091 .30014 .24543 Metetra
.701 .699 .845 r
.30014 .24543 .30404 .25091 .31033 .24742 .30642 .24217 Metetra
.695 .707 .857 r
.30642 .24217 .31033 .24742 .31661 .24415 .3127 .2391 Metetra
.689 .713 .867 r
.3127 .2391 .31661 .24415 .32289 .24109 .31898 .2362 Metetra
.684 .719 .876 r
.31898 .2362 .32289 .24109 .32918 .23819 .32526 .23342 Metetra
.68 .724 .884 r
.32526 .23342 .32918 .23819 .33546 .23542 .33155 .23075 Metetra
.676 .729 .89 r
.33155 .23075 .33546 .23542 .34176 .23275 .33784 .22816 Metetra
.673 .732 .894 r
.33784 .22816 .34176 .23275 .34806 .23015 .34415 .22563 Metetra
.67 .735 .898 r
.34415 .22563 .34806 .23015 .35437 .22762 .35047 .22314 Metetra
.669 .737 .901 r
.35047 .22314 .35437 .22762 .3607 .22513 .3568 .22068 Metetra
.667 .738 .903 r
.3568 .22068 .3607 .22513 .36703 .22267 .36315 .21824 Metetra
.666 .74 .905 r
.36315 .21824 .36703 .22267 .37338 .22023 .3695 .21581 Metetra
.665 .741 .906 r
.3695 .21581 .37338 .22023 .37975 .2178 .37588 .21339 Metetra
.665 .741 .907 r
.37588 .21339 .37975 .2178 .38612 .21538 .38226 .21098 Metetra
.664 .742 .908 r
.38226 .21098 .38612 .21538 .39252 .21297 .38866 .20857 Metetra
.664 .743 .908 r
.38866 .20857 .39252 .21297 .39892 .21056 .39508 .20616 Metetra
.664 .743 .909 r
.39508 .20616 .39892 .21056 .40535 .20816 .40151 .20374 Metetra
.664 .743 .909 r
.40151 .20374 .40535 .20816 .41178 .20576 .40796 .20133 Metetra
.663 .742 .909 r
.40796 .20133 .41178 .20576 .41824 .20336 .41442 .19892 Metetra
.662 .742 .909 r
.41442 .19892 .41824 .20336 .4247 .20098 .4209 .19651 Metetra
.661 .741 .909 r
.4209 .19651 .4247 .20098 .43119 .19862 .42739 .19411 Metetra
.66 .739 .908 r
.42739 .19411 .43119 .19862 .43768 .19628 .4339 .19173 Metetra
.658 .736 .908 r
.4339 .19173 .43768 .19628 .4442 .19398 .44042 .18937 Metetra
.655 .733 .907 r
.44042 .18937 .4442 .19398 .45072 .19173 .44696 .18705 Metetra
.652 .729 .906 r
.44696 .18705 .45072 .19173 .45726 .18955 .45352 .18478 Metetra
.647 .724 .904 r
.45352 .18478 .45726 .18955 .46382 .18745 .46008 .18258 Metetra
.641 .717 .903 r
.46008 .18258 .46382 .18745 .47039 .18545 .46667 .18047 Metetra
.634 .708 .9 r
.46667 .18047 .47039 .18545 .47698 .1836 .47327 .17846 Metetra
.624 .698 .898 r
.47327 .17846 .47698 .1836 .48359 .1819 .47988 .17659 Metetra
.614 .686 .894 r
.47988 .17659 .48359 .1819 .49021 .18039 .48651 .17489 Metetra
.601 .673 .89 r
.48651 .17489 .49021 .18039 .49685 .1791 .49316 .17338 Metetra
.587 .657 .885 r
.49316 .17338 .49685 .1791 .50351 .17804 .49983 .17208 Metetra
.572 .64 .88 r
.49983 .17208 .50351 .17804 .51019 .17725 .50652 .17103 Metetra
.556 .622 .873 r
.50652 .17103 .51019 .17725 .51689 .17673 .51323 .17024 Metetra
.54 .603 .866 r
.51323 .17024 .51689 .17673 .52362 .17648 .51996 .16971 Metetra
.524 .585 .858 r
.51996 .16971 .52362 .17648 .53038 .1765 .52672 .16946 Metetra
.509 .567 .85 r
.52672 .16946 .53038 .1765 .53716 .17677 .53351 .16947 Metetra
.495 .552 .843 r
.53351 .16947 .53716 .17677 .54398 .17726 .54032 .16972 Metetra
.485 .538 .837 r
.54032 .16972 .54398 .17726 .55083 .1779 .54717 .17018 Metetra
.477 .528 .831 r
.54717 .17018 .55083 .1779 .55771 .17865 .55405 .17079 Metetra
.472 .522 .828 r
.55405 .17079 .55771 .17865 .56462 .17944 .56096 .1715 Metetra
.471 .52 .826 r
.56096 .1715 .56462 .17944 .57157 .18019 .56791 .17224 Metetra
.474 .522 .826 r
.56791 .17224 .57157 .18019 .57855 .18081 .57489 .17293 Metetra
.481 .528 .829 r
.57489 .17293 .57855 .18081 .58555 .18122 .58189 .1735 Metetra
.492 .54 .833 r
.58189 .1735 .58555 .18122 .59258 .18136 .58893 .17385 Metetra
.508 .556 .84 r
.58893 .17385 .59258 .18136 .59963 .18114 .59599 .17393 Metetra
.527 .577 .849 r
.59599 .17393 .59963 .18114 .6067 .18051 .60307 .17365 Metetra
.549 .602 .859 r
.60307 .17365 .6067 .18051 .61378 .17941 .61017 .17296 Metetra
.574 .631 .87 r
.61017 .17296 .61378 .17941 .62087 .17783 .61728 .17182 Metetra
.602 .663 .881 r
.61728 .17182 .62087 .17783 .62796 .17574 .6244 .1702 Metetra
.631 .697 .892 r
.6244 .1702 .62796 .17574 .63506 .17315 .63153 .16807 Metetra
.66 .732 .902 r
.63153 .16807 .63506 .17315 .64216 .17007 .63865 .16545 Metetra
.688 .766 .911 r
.63865 .16545 .64216 .17007 .64925 .16654 .64578 .16236 Metetra
.715 .799 .917 r
.64578 .16236 .64925 .16654 .65634 .16258 .6529 .15881 Metetra
.739 .829 .921 r
.6529 .15881 .65634 .16258 .66343 .15826 .66002 .15485 Metetra
.759 .855 .922 r
.66002 .15485 .66343 .15826 .67051 .15363 .66713 .15053 Metetra
.775 .877 .922 r
.66713 .15053 .67051 .15363 .67758 .14875 .67424 .14591 Metetra
.787 .895 .92 r
.67424 .14591 .67758 .14875 .68465 .14368 .68135 .14104 Metetra
.796 .909 .918 r
.68135 .14104 .68465 .14368 .69173 .13847 .68845 .13598 Metetra
.802 .918 .916 r
.68845 .13598 .69173 .13847 .6988 .13318 .69555 .13078 Metetra
.805 .925 .915 r
.69555 .13078 .6988 .13318 .70588 .12787 .70265 .12551 Metetra
.806 .928 .915 r
.70265 .12551 .70588 .12787 .71296 .12257 .70976 .12021 Metetra
.805 .929 .916 r
.70976 .12021 .71296 .12257 .72005 .11732 .71687 .11491 Metetra
.803 .927 .917 r
.71687 .11491 .72005 .11732 .72716 .11215 .72399 .10967 Metetra
.799 .923 .919 r
.72399 .10967 .72716 .11215 .73428 .1071 .73113 .10451 Metetra
.794 .918 .922 r
.73113 .10451 .73428 .1071 .74141 .10217 .73827 .09945 Metetra
0 .477 .727 r
.09119 .33013 .09587 .33121 .10125 .33189 .09653 .33116 Metetra
.239 0 0 r
.09653 .33116 .10125 .33189 .10661 .33293 .10185 .33252 Metetra
.339 0 0 r
.10185 .33252 .10661 .33293 .11195 .33431 .10715 .33419 Metetra
.407 0 0 r
.10715 .33419 .11195 .33431 .11727 .33599 .11245 .3361 Metetra
.446 0 0 r
.11245 .3361 .11727 .33599 .12259 .33793 .11776 .33817 Metetra
.461 0 0 r
.11776 .33817 .12259 .33793 .12791 .34002 .12309 .3403 Metetra
.453 0 0 r
.12309 .3403 .12791 .34002 .13325 .34218 .12845 .34237 Metetra
.415 0 0 r
.12845 .34237 .13325 .34218 .13863 .34427 .13386 .34424 Metetra
.336 0 0 r
.13386 .34424 .13863 .34427 .14407 .34616 .13935 .34576 Metetra
.191 0 0 r
.13935 .34576 .14407 .34616 .14957 .34769 .14492 .34678 Metetra
.041 .599 .812 r
.14492 .34678 .14957 .34769 .15516 .34873 .15059 .34718 Metetra
.319 .757 .967 r
.15059 .34718 .15516 .34873 .16084 .34912 .15637 .34681 Metetra
.533 .811 .997 r
.15637 .34681 .16084 .34912 .16664 .34876 .16227 .34561 Metetra
.65 .795 .952 r
.16227 .34561 .16664 .34876 .17254 .34755 .16829 .3435 Metetra
.707 .758 .893 r
.16829 .3435 .17254 .34755 .17857 .34544 .17442 .34049 Metetra
.733 .724 .842 r
.17442 .34049 .17857 .34544 .1847 .34241 .18065 .3366 Metetra
.746 .696 .804 r
.18065 .3366 .1847 .34241 .19094 .33851 .18698 .3319 Metetra
.752 .675 .777 r
.18698 .3319 .19094 .33851 .19727 .33379 .19339 .32649 Metetra
.754 .66 .757 r
.19339 .32649 .19727 .33379 .20368 .32838 .19986 .32051 Metetra
.755 .648 .743 r
.19986 .32051 .20368 .32838 .21015 .32239 .20638 .31412 Metetra
.754 .64 .735 r
.20638 .31412 .21015 .32239 .21665 .31599 .21292 .30746 Metetra
.752 .635 .73 r
.21292 .30746 .21665 .31599 .22318 .30933 .21946 .30069 Metetra
.75 .632 .729 r
.21946 .30069 .22318 .30933 .22972 .30257 .226 .29395 Metetra
.748 .632 .731 r
.226 .29395 .22972 .30257 .23625 .29584 .23252 .28737 Metetra
.745 .633 .736 r
.23252 .28737 .23625 .29584 .24276 .28926 .23902 .28104 Metetra
.742 .636 .742 r
.23902 .28104 .24276 .28926 .24925 .28295 .24548 .27503 Metetra
.738 .641 .751 r
.24548 .27503 .24925 .28295 .25571 .27695 .25192 .2694 Metetra
.734 .647 .762 r
.25192 .2694 .25571 .27695 .26213 .27133 .25832 .26416 Metetra
.73 .655 .775 r
.25832 .26416 .26213 .27133 .26853 .26611 .26468 .25931 Metetra
.725 .663 .789 r
.26468 .25931 .26853 .26611 .27489 .26127 .27102 .25485 Metetra
.719 .672 .803 r
.27102 .25485 .27489 .26127 .28123 .25682 .27734 .25074 Metetra
.713 .681 .818 r
.27734 .25074 .28123 .25682 .28755 .25272 .28364 .24695 Metetra
.707 .69 .832 r
.28364 .24695 .28755 .25272 .29385 .24894 .28993 .24344 Metetra
.701 .699 .845 r
.28993 .24344 .29385 .24894 .30014 .24543 .29621 .24017 Metetra
.695 .707 .857 r
.29621 .24017 .30014 .24543 .30642 .24217 .30248 .2371 Metetra
.689 .713 .867 r
.30248 .2371 .30642 .24217 .3127 .2391 .30876 .2342 Metetra
.684 .719 .876 r
.30876 .2342 .3127 .2391 .31898 .2362 .31504 .23142 Metetra
.679 .724 .884 r
.31504 .23142 .31898 .2362 .32526 .23342 .32132 .22875 Metetra
.676 .728 .889 r
.32132 .22875 .32526 .23342 .33155 .23075 .32761 .22615 Metetra
.673 .731 .894 r
.32761 .22615 .33155 .23075 .33784 .22816 .33391 .22361 Metetra
.67 .734 .898 r
.33391 .22361 .33784 .22816 .34415 .22563 .34023 .22112 Metetra
.668 .736 .9 r
.34023 .22112 .34415 .22563 .35047 .22314 .34655 .21866 Metetra
.667 .737 .903 r
.34655 .21866 .35047 .22314 .3568 .22068 .35289 .21621 Metetra
.666 .738 .904 r
.35289 .21621 .3568 .22068 .36315 .21824 .35924 .21378 Metetra
.665 .739 .905 r
.35924 .21378 .36315 .21824 .3695 .21581 .36561 .21136 Metetra
.665 .74 .906 r
.36561 .21136 .3695 .21581 .37588 .21339 .37199 .20895 Metetra
.664 .74 .907 r
.37199 .20895 .37588 .21339 .38226 .21098 .37839 .20653 Metetra
.664 .741 .907 r
.37839 .20653 .38226 .21098 .38866 .20857 .3848 .20412 Metetra
.664 .741 .908 r
.3848 .20412 .38866 .20857 .39508 .20616 .39122 .2017 Metetra
.664 .741 .908 r
.39122 .2017 .39508 .20616 .40151 .20374 .39766 .19928 Metetra
.663 .741 .908 r
.39766 .19928 .40151 .20374 .40796 .20133 .40412 .19686 Metetra
.663 .741 .908 r
.40412 .19686 .40796 .20133 .41442 .19892 .41059 .19444 Metetra
.663 .741 .908 r
.41059 .19444 .41442 .19892 .4209 .19651 .41708 .19202 Metetra
.662 .741 .909 r
.41708 .19202 .4209 .19651 .42739 .19411 .42358 .1896 Metetra
.661 .74 .908 r
.42358 .1896 .42739 .19411 .4339 .19173 .4301 .18719 Metetra
.66 .739 .908 r
.4301 .18719 .4339 .19173 .44042 .18937 .43663 .18479 Metetra
.658 .737 .908 r
.43663 .18479 .44042 .18937 .44696 .18705 .44318 .18242 Metetra
.655 .734 .907 r
.44318 .18242 .44696 .18705 .45352 .18478 .44975 .18009 Metetra
.652 .73 .906 r
.44975 .18009 .45352 .18478 .46008 .18258 .45633 .17781 Metetra
.647 .725 .905 r
.45633 .17781 .46008 .18258 .46667 .18047 .46292 .17559 Metetra
.641 .718 .904 r
.46292 .17559 .46667 .18047 .47327 .17846 .46953 .17346 Metetra
.633 .709 .901 r
.46953 .17346 .47327 .17846 .47988 .17659 .47616 .17145 Metetra
.624 .699 .899 r
.47616 .17145 .47988 .17659 .48651 .17489 .4828 .16957 Metetra
.613 .687 .895 r
.4828 .16957 .48651 .17489 .49316 .17338 .48946 .16786 Metetra
.601 .673 .891 r
.48946 .16786 .49316 .17338 .49983 .17208 .49614 .16634 Metetra
.587 .657 .886 r
.49614 .16634 .49983 .17208 .50652 .17103 .50283 .16504 Metetra
.571 .64 .88 r
.50283 .16504 .50652 .17103 .51323 .17024 .50955 .16398 Metetra
.555 .622 .873 r
.50955 .16398 .51323 .17024 .51996 .16971 .51629 .16318 Metetra
.539 .603 .866 r
.51629 .16318 .51996 .16971 .52672 .16946 .52305 .16265 Metetra
.523 .585 .858 r
.52305 .16265 .52672 .16946 .53351 .16947 .52984 .16239 Metetra
.509 .567 .85 r
.52984 .16239 .53351 .16947 .54032 .16972 .53666 .16238 Metetra
.496 .552 .843 r
.53666 .16238 .54032 .16972 .54717 .17018 .54351 .16261 Metetra
.485 .539 .837 r
.54351 .16261 .54717 .17018 .55405 .17079 .55039 .16304 Metetra
.478 .529 .832 r
.55039 .16304 .55405 .17079 .56096 .1715 .5573 .16362 Metetra
.474 .523 .828 r
.5573 .16362 .56096 .1715 .56791 .17224 .56424 .16429 Metetra
.473 .521 .827 r
.56424 .16429 .56791 .17224 .57489 .17293 .57122 .16498 Metetra
.476 .524 .827 r
.57122 .16498 .57489 .17293 .58189 .1735 .57823 .16562 Metetra
.484 .531 .83 r
.57823 .16562 .58189 .1735 .58893 .17385 .58527 .16613 Metetra
.495 .542 .835 r
.58527 .16613 .58893 .17385 .59599 .17393 .59234 .16642 Metetra
.51 .559 .841 r
.59234 .16642 .59599 .17393 .60307 .17365 .59943 .16644 Metetra
.529 .579 .85 r
.59943 .16644 .60307 .17365 .61017 .17296 .60654 .1661 Metetra
.551 .604 .86 r
.60654 .1661 .61017 .17296 .61728 .17182 .61367 .16536 Metetra
.576 .633 .871 r
.61367 .16536 .61728 .17182 .6244 .1702 .62081 .16417 Metetra
.603 .664 .882 r
.62081 .16417 .6244 .1702 .63153 .16807 .62796 .1625 Metetra
.632 .698 .893 r
.62796 .1625 .63153 .16807 .63865 .16545 .63511 .16035 Metetra
.661 .732 .903 r
.63511 .16035 .63865 .16545 .64578 .16236 .64227 .1577 Metetra
.688 .766 .911 r
.64227 .1577 .64578 .16236 .6529 .15881 .64943 .15459 Metetra
.714 .798 .917 r
.64943 .15459 .6529 .15881 .66002 .15485 .65658 .15103 Metetra
.738 .828 .921 r
.65658 .15103 .66002 .15485 .66713 .15053 .66373 .14707 Metetra
.757 .854 .922 r
.66373 .14707 .66713 .15053 .67424 .14591 .67087 .14275 Metetra
.773 .876 .922 r
.67087 .14275 .67424 .14591 .68135 .14104 .67801 .13814 Metetra
.786 .893 .921 r
.67801 .13814 .68135 .14104 .68845 .13598 .68514 .13327 Metetra
.794 .907 .919 r
.68514 .13327 .68845 .13598 .69555 .13078 .69227 .12822 Metetra
.8 .916 .917 r
.69227 .12822 .69555 .13078 .70265 .12551 .6994 .12304 Metetra
.804 .923 .916 r
.6994 .12304 .70265 .12551 .70976 .12021 .70653 .11778 Metetra
.805 .926 .916 r
.70653 .11778 .70976 .12021 .71687 .11491 .71367 .11249 Metetra
.804 .927 .916 r
.71367 .11249 .71687 .11491 .72399 .10967 .72081 .10721 Metetra
.801 .925 .918 r
.72081 .10721 .72399 .10967 .73113 .10451 .72796 .10197 Metetra
.798 .922 .92 r
.72796 .10197 .73113 .10451 .73827 .09945 .73512 .09681 Metetra
.235 0 0 r
.08642 .32939 .09119 .33013 .09653 .33116 .09173 .33073 Metetra
.335 0 0 r
.09173 .33073 .09653 .33116 .10185 .33252 .09702 .33238 Metetra
.402 0 0 r
.09702 .33238 .10185 .33252 .10715 .33419 .1023 .33426 Metetra
.442 0 0 r
.1023 .33426 .10715 .33419 .11245 .3361 .10759 .33631 Metetra
.457 0 0 r
.10759 .33631 .11245 .3361 .11776 .33817 .1129 .33842 Metetra
.448 0 0 r
.1129 .33842 .11776 .33817 .12309 .3403 .11824 .34047 Metetra
.411 0 0 r
.11824 .34047 .12309 .3403 .12845 .34237 .12364 .34232 Metetra
.332 0 0 r
.12364 .34232 .12845 .34237 .13386 .34424 .12911 .34382 Metetra
.187 0 0 r
.12911 .34382 .13386 .34424 .13935 .34576 .13466 .34483 Metetra
.045 .601 .815 r
.13466 .34483 .13935 .34576 .14492 .34678 .14032 .34522 Metetra
.319 .756 .967 r
.14032 .34522 .14492 .34678 .15059 .34718 .14609 .34485 Metetra
.532 .811 .997 r
.14609 .34485 .15059 .34718 .15637 .34681 .15198 .34365 Metetra
.649 .794 .952 r
.15198 .34365 .15637 .34681 .16227 .34561 .15798 .34156 Metetra
.706 .758 .893 r
.15798 .34156 .16227 .34561 .16829 .3435 .16411 .33856 Metetra
.733 .724 .843 r
.16411 .33856 .16829 .3435 .17442 .34049 .17034 .33468 Metetra
.745 .697 .805 r
.17034 .33468 .17442 .34049 .18065 .3366 .17667 .32999 Metetra
.751 .676 .777 r
.17667 .32999 .18065 .3366 .18698 .3319 .18309 .3246 Metetra
.754 .66 .757 r
.18309 .3246 .18698 .3319 .19339 .32649 .18956 .31863 Metetra
.754 .648 .744 r
.18956 .31863 .19339 .32649 .19986 .32051 .19608 .31224 Metetra
.754 .64 .735 r
.19608 .31224 .19986 .32051 .20638 .31412 .20263 .30558 Metetra
.752 .635 .73 r
.20263 .30558 .20638 .31412 .21292 .30746 .20918 .29881 Metetra
.75 .632 .729 r
.20918 .29881 .21292 .30746 .21946 .30069 .21573 .29206 Metetra
.748 .632 .731 r
.21573 .29206 .21946 .30069 .226 .29395 .22226 .28547 Metetra
.745 .633 .735 r
.22226 .28547 .226 .29395 .23252 .28737 .22877 .27913 Metetra
.742 .636 .742 r
.22877 .27913 .23252 .28737 .23902 .28104 .23524 .27311 Metetra
.738 .641 .751 r
.23524 .27311 .23902 .28104 .24548 .27503 .24168 .26747 Metetra
.734 .647 .762 r
.24168 .26747 .24548 .27503 .25192 .2694 .24808 .26221 Metetra
.73 .655 .775 r
.24808 .26221 .25192 .2694 .25832 .26416 .25445 .25736 Metetra
.725 .663 .789 r
.25445 .25736 .25832 .26416 .26468 .25931 .2608 .25288 Metetra
.719 .672 .803 r
.2608 .25288 .26468 .25931 .27102 .25485 .26712 .24877 Metetra
.713 .681 .818 r
.26712 .24877 .27102 .25485 .27734 .25074 .27342 .24497 Metetra
.707 .69 .832 r
.27342 .24497 .27734 .25074 .28364 .24695 .2797 .24146 Metetra
.701 .699 .845 r
.2797 .24146 .28364 .24695 .28993 .24344 .28598 .23818 Metetra
.695 .707 .857 r
.28598 .23818 .28993 .24344 .29621 .24017 .29225 .23511 Metetra
.689 .714 .867 r
.29225 .23511 .29621 .24017 .30248 .2371 .29852 .2322 Metetra
.684 .719 .876 r
.29852 .2322 .30248 .2371 .30876 .2342 .30479 .22942 Metetra
.679 .724 .884 r
.30479 .22942 .30876 .2342 .31504 .23142 .31107 .22674 Metetra
.676 .728 .89 r
.31107 .22674 .31504 .23142 .32132 .22875 .31736 .22414 Metetra
.673 .732 .894 r
.31736 .22414 .32132 .22875 .32761 .22615 .32365 .2216 Metetra
.67 .734 .898 r
.32365 .2216 .32761 .22615 .33391 .22361 .32996 .2191 Metetra
.668 .736 .901 r
.32996 .2191 .33391 .22361 .34023 .22112 .33628 .21663 Metetra
.667 .737 .903 r
.33628 .21663 .34023 .22112 .34655 .21866 .34261 .21418 Metetra
.666 .738 .904 r
.34261 .21418 .34655 .21866 .35289 .21621 .34896 .21175 Metetra
.665 .739 .905 r
.34896 .21175 .35289 .21621 .35924 .21378 .35532 .20932 Metetra
.665 .739 .906 r
.35532 .20932 .35924 .21378 .36561 .21136 .3617 .2069 Metetra
.664 .74 .906 r
.3617 .2069 .36561 .21136 .37199 .20895 .36809 .20448 Metetra
.664 .74 .907 r
.36809 .20448 .37199 .20895 .37839 .20653 .37449 .20206 Metetra
.664 .74 .907 r
.37449 .20206 .37839 .20653 .3848 .20412 .38091 .19964 Metetra
.664 .74 .907 r
.38091 .19964 .3848 .20412 .39122 .2017 .38735 .19721 Metetra
.663 .74 .907 r
.38735 .19721 .39122 .2017 .39766 .19928 .3938 .19478 Metetra
.663 .74 .907 r
.3938 .19478 .39766 .19928 .40412 .19686 .40026 .19235 Metetra
.663 .74 .907 r
.40026 .19235 .40412 .19686 .41059 .19444 .40675 .18991 Metetra
.663 .74 .907 r
.40675 .18991 .41059 .19444 .41708 .19202 .41324 .18748 Metetra
.662 .74 .908 r
.41324 .18748 .41708 .19202 .42358 .1896 .41976 .18505 Metetra
.662 .739 .908 r
.41976 .18505 .42358 .1896 .4301 .18719 .42628 .18262 Metetra
.661 .739 .908 r
.42628 .18262 .4301 .18719 .43663 .18479 .43283 .18019 Metetra
.659 .737 .907 r
.43283 .18019 .43663 .18479 .44318 .18242 .43939 .17779 Metetra
.657 .735 .907 r
.43939 .17779 .44318 .18242 .44975 .18009 .44596 .17541 Metetra
.655 .733 .907 r
.44596 .17541 .44975 .18009 .45633 .17781 .45255 .17307 Metetra
.651 .729 .906 r
.45255 .17307 .45633 .17781 .46292 .17559 .45916 .17077 Metetra
.646 .724 .905 r
.45916 .17077 .46292 .17559 .46953 .17346 .46578 .16855 Metetra
.64 .717 .904 r
.46578 .16855 .46953 .17346 .47616 .17145 .47242 .16641 Metetra
.633 .709 .902 r
.47242 .16641 .47616 .17145 .4828 .16957 .47907 .16439 Metetra
.623 .699 .899 r
.47907 .16439 .4828 .16957 .48946 .16786 .48574 .16251 Metetra
.613 .687 .895 r
.48574 .16251 .48946 .16786 .49614 .16634 .49243 .16079 Metetra
.6 .673 .891 r
.49243 .16079 .49614 .16634 .50283 .16504 .49913 .15927 Metetra
.586 .657 .886 r
.49913 .15927 .50283 .16504 .50955 .16398 .50585 .15796 Metetra
.571 .64 .88 r
.50585 .15796 .50955 .16398 .51629 .16318 .5126 .1569 Metetra
.555 .621 .873 r
.5126 .1569 .51629 .16318 .52305 .16265 .51937 .15609 Metetra
.539 .603 .866 r
.51937 .15609 .52305 .16265 .52984 .16239 .52616 .15555 Metetra
.523 .585 .858 r
.52616 .15555 .52984 .16239 .53666 .16238 .53298 .15527 Metetra
.509 .568 .851 r
.53298 .15527 .53666 .16238 .54351 .16261 .53983 .15525 Metetra
.496 .553 .843 r
.53983 .15525 .54351 .16261 .55039 .16304 .54671 .15546 Metetra
.486 .54 .837 r
.54671 .15546 .55039 .16304 .5573 .16362 .55362 .15586 Metetra
.479 .531 .832 r
.55362 .15586 .5573 .16362 .56424 .16429 .56057 .1564 Metetra
.475 .525 .829 r
.56057 .1564 .56424 .16429 .57122 .16498 .56754 .15702 Metetra
.475 .523 .828 r
.56754 .15702 .57122 .16498 .57823 .16562 .57455 .15767 Metetra
.478 .526 .828 r
.57455 .15767 .57823 .16562 .58527 .16613 .58159 .15825 Metetra
.486 .533 .831 r
.58159 .15825 .58527 .16613 .59234 .16642 .58867 .1587 Metetra
.497 .545 .836 r
.58867 .1587 .59234 .16642 .59943 .16644 .59576 .15894 Metetra
.512 .561 .842 r
.59576 .15894 .59943 .16644 .60654 .1661 .60289 .15889 Metetra
.531 .582 .851 r
.60289 .15889 .60654 .1661 .61367 .16536 .61003 .1585 Metetra
.553 .607 .861 r
.61003 .1585 .61367 .16536 .62081 .16417 .61719 .15771 Metetra
.578 .635 .872 r
.61719 .15771 .62081 .16417 .62796 .1625 .62436 .15647 Metetra
.605 .666 .883 r
.62436 .15647 .62796 .1625 .63511 .16035 .63154 .15476 Metetra
.633 .699 .893 r
.63154 .15476 .63511 .16035 .64227 .1577 .63873 .15257 Metetra
.661 .733 .903 r
.63873 .15257 .64227 .1577 .64943 .15459 .64591 .1499 Metetra
.688 .766 .911 r
.64591 .1499 .64943 .15459 .65658 .15103 .6531 .14676 Metetra
.714 .798 .917 r
.6531 .14676 .65658 .15103 .66373 .14707 .66028 .14319 Metetra
.737 .827 .92 r
.66028 .14319 .66373 .14707 .67087 .14275 .66746 .13923 Metetra
.756 .852 .922 r
.66746 .13923 .67087 .14275 .67801 .13814 .67463 .13491 Metetra
.772 .874 .922 r
.67463 .13491 .67801 .13814 .68514 .13327 .6818 .1303 Metetra
.784 .891 .921 r
.6818 .1303 .68514 .13327 .69227 .12822 .68896 .12545 Metetra
.793 .904 .919 r
.68896 .12545 .69227 .12822 .6994 .12304 .69612 .12041 Metetra
.799 .914 .918 r
.69612 .12041 .6994 .12304 .70653 .11778 .70328 .11524 Metetra
.802 .92 .917 r
.70328 .11524 .70653 .11778 .71367 .11249 .71044 .10999 Metetra
.803 .924 .917 r
.71044 .10999 .71367 .11249 .72081 .10721 .7176 .10471 Metetra
.802 .925 .917 r
.7176 .10471 .72081 .10721 .72796 .10197 .72478 .09944 Metetra
.8 .923 .919 r
.72478 .09944 .72796 .10197 .73512 .09681 .73196 .09421 Metetra
.33 0 0 r
.08159 .32894 .08642 .32939 .09173 .33073 .08686 .33056 Metetra
.398 0 0 r
.08686 .33056 .09173 .33073 .09702 .33238 .09213 .33243 Metetra
.437 0 0 r
.09213 .33243 .09702 .33238 .1023 .33426 .0974 .33445 Metetra
.453 0 0 r
.0974 .33445 .1023 .33426 .10759 .33631 .10269 .33653 Metetra
.444 0 0 r
.10269 .33653 .10759 .33631 .1129 .33842 .10802 .33856 Metetra
.406 0 0 r
.10802 .33856 .1129 .33842 .11824 .34047 .1134 .34038 Metetra
.327 0 0 r
.1134 .34038 .11824 .34047 .12364 .34232 .11885 .34187 Metetra
.182 0 0 r
.11885 .34187 .12364 .34232 .12911 .34382 .12439 .34287 Metetra
.048 .604 .818 r
.12439 .34287 .12911 .34382 .13466 .34483 .13003 .34325 Metetra
.321 .756 .968 r
.13003 .34325 .13466 .34483 .14032 .34522 .13579 .34288 Metetra
.531 .81 .997 r
.13579 .34288 .14032 .34522 .14609 .34485 .14166 .34169 Metetra
.648 .794 .952 r
.14166 .34169 .14609 .34485 .15198 .34365 .14766 .3396 Metetra
.705 .758 .894 r
.14766 .3396 .15198 .34365 .15798 .34156 .15378 .33662 Metetra
.732 .724 .844 r
.15378 .33662 .15798 .34156 .16411 .33856 .16001 .33275 Metetra
.745 .697 .806 r
.16001 .33275 .16411 .33856 .17034 .33468 .16635 .32808 Metetra
.751 .676 .778 r
.16635 .32808 .17034 .33468 .17667 .32999 .17276 .3227 Metetra
.754 .66 .758 r
.17276 .3227 .17667 .32999 .18309 .3246 .17924 .31674 Metetra
.754 .648 .744 r
.17924 .31674 .18309 .3246 .18956 .31863 .18577 .31035 Metetra
.754 .64 .735 r
.18577 .31035 .18956 .31863 .19608 .31224 .19232 .3037 Metetra
.752 .635 .731 r
.19232 .3037 .19608 .31224 .20263 .30558 .19889 .29692 Metetra
.75 .632 .729 r
.19889 .29692 .20263 .30558 .20918 .29881 .20544 .29017 Metetra
.748 .632 .731 r
.20544 .29017 .20918 .29881 .21573 .29206 .21198 .28357 Metetra
.745 .633 .735 r
.21198 .28357 .21573 .29206 .22226 .28547 .2185 .27722 Metetra
.742 .636 .742 r
.2185 .27722 .22226 .28547 .22877 .27913 .22498 .27119 Metetra
.739 .641 .751 r
.22498 .27119 .22877 .27913 .23524 .27311 .23142 .26553 Metetra
.735 .647 .762 r
.23142 .26553 .23524 .27311 .24168 .26747 .23783 .26027 Metetra
.73 .655 .775 r
.23783 .26027 .24168 .26747 .24808 .26221 .2442 .2554 Metetra
.725 .663 .788 r
.2442 .2554 .24808 .26221 .25445 .25736 .25055 .25092 Metetra
.719 .672 .803 r
.25055 .25092 .25445 .25736 .2608 .25288 .25687 .24679 Metetra
.713 .681 .818 r
.25687 .24679 .2608 .25288 .26712 .24877 .26317 .24299 Metetra
.707 .69 .832 r
.26317 .24299 .26712 .24877 .27342 .24497 .26945 .23947 Metetra
.701 .699 .845 r
.26945 .23947 .27342 .24497 .2797 .24146 .27572 .23619 Metetra
.695 .707 .857 r
.27572 .23619 .2797 .24146 .28598 .23818 .28199 .23311 Metetra
.689 .714 .868 r
.28199 .23311 .28598 .23818 .29225 .23511 .28826 .23019 Metetra
.684 .72 .877 r
.28826 .23019 .29225 .23511 .29852 .2322 .29453 .22741 Metetra
.679 .725 .884 r
.29453 .22741 .29852 .2322 .30479 .22942 .3008 .22473 Metetra
.676 .729 .89 r
.3008 .22473 .30479 .22942 .31107 .22674 .30708 .22213 Metetra
.673 .732 .895 r
.30708 .22213 .31107 .22674 .31736 .22414 .31337 .21958 Metetra
.67 .734 .898 r
.31337 .21958 .31736 .22414 .32365 .2216 .31967 .21708 Metetra
.668 .736 .901 r
.31967 .21708 .32365 .2216 .32996 .2191 .32599 .21461 Metetra
.667 .738 .903 r
.32599 .21461 .32996 .2191 .33628 .21663 .33232 .21216 Metetra
.666 .739 .904 r
.33232 .21216 .33628 .21663 .34261 .21418 .33866 .20972 Metetra
.665 .739 .905 r
.33866 .20972 .34261 .21418 .34896 .21175 .34501 .20729 Metetra
.665 .74 .906 r
.34501 .20729 .34896 .21175 .35532 .20932 .35138 .20486 Metetra
.664 .74 .907 r
.35138 .20486 .35532 .20932 .3617 .2069 .35777 .20243 Metetra
.664 .74 .907 r
.35777 .20243 .3617 .2069 .36809 .20448 .36416 .2 Metetra
.664 .741 .907 r
.36416 .2 .36809 .20448 .37449 .20206 .37058 .19757 Metetra
.664 .741 .907 r
.37058 .19757 .37449 .20206 .38091 .19964 .37701 .19514 Metetra
.664 .741 .907 r
.37701 .19514 .38091 .19964 .38735 .19721 .38345 .1927 Metetra
.663 .741 .907 r
.38345 .1927 .38735 .19721 .3938 .19478 .38992 .19026 Metetra
.663 .74 .907 r
.38992 .19026 .3938 .19478 .40026 .19235 .39639 .18782 Metetra
.663 .74 .907 r
.39639 .18782 .40026 .19235 .40675 .18991 .40288 .18537 Metetra
.663 .74 .907 r
.40288 .18537 .40675 .18991 .41324 .18748 .40939 .18292 Metetra
.663 .74 .907 r
.40939 .18292 .41324 .18748 .41976 .18505 .41591 .18047 Metetra
.662 .739 .907 r
.41591 .18047 .41976 .18505 .42628 .18262 .42245 .17802 Metetra
.661 .739 .907 r
.42245 .17802 .42628 .18262 .43283 .18019 .42901 .17558 Metetra
.66 .738 .907 r
.42901 .17558 .43283 .18019 .43939 .17779 .43558 .17314 Metetra
.659 .736 .907 r
.43558 .17314 .43939 .17779 .44596 .17541 .44216 .17073 Metetra
.657 .734 .907 r
.44216 .17073 .44596 .17541 .45255 .17307 .44876 .16833 Metetra
.654 .731 .906 r
.44876 .16833 .45255 .17307 .45916 .17077 .45538 .16598 Metetra
.65 .728 .905 r
.45538 .16598 .45916 .17077 .46578 .16855 .46201 .16368 Metetra
.646 .723 .904 r
.46201 .16368 .46578 .16855 .47242 .16641 .46866 .16145 Metetra
.639 .716 .903 r
.46866 .16145 .47242 .16641 .47907 .16439 .47532 .15931 Metetra
.632 .708 .901 r
.47532 .15931 .47907 .16439 .48574 .16251 .482 .15728 Metetra
.623 .698 .898 r
.482 .15728 .48574 .16251 .49243 .16079 .4887 .15539 Metetra
.612 .686 .895 r
.4887 .15539 .49243 .16079 .49913 .15927 .49541 .15367 Metetra
.599 .672 .891 r
.49541 .15367 .49913 .15927 .50585 .15796 .50215 .15215 Metetra
.585 .656 .886 r
.50215 .15215 .50585 .15796 .5126 .1569 .5089 .15084 Metetra
.57 .639 .88 r
.5089 .15084 .5126 .1569 .51937 .15609 .51567 .14977 Metetra
.554 .621 .873 r
.51567 .14977 .51937 .15609 .52616 .15555 .52247 .14895 Metetra
.538 .603 .866 r
.52247 .14895 .52616 .15555 .53298 .15527 .5293 .1484 Metetra
.523 .585 .858 r
.5293 .1484 .53298 .15527 .53983 .15525 .53615 .14811 Metetra
.509 .568 .851 r
.53615 .14811 .53983 .15525 .54671 .15546 .54303 .14807 Metetra
.497 .553 .844 r
.54303 .14807 .54671 .15546 .55362 .15586 .54994 .14825 Metetra
.487 .541 .838 r
.54994 .14825 .55362 .15586 .56057 .1564 .55688 .14862 Metetra
.48 .532 .833 r
.55688 .14862 .56057 .1564 .56754 .15702 .56386 .14912 Metetra
.477 .527 .83 r
.56386 .14912 .56754 .15702 .57455 .15767 .57087 .1497 Metetra
.477 .525 .829 r
.57087 .1497 .57455 .15767 .58159 .15825 .57791 .1503 Metetra
.48 .528 .829 r
.57791 .1503 .58159 .15825 .58867 .1587 .58498 .15083 Metetra
.488 .536 .832 r
.58498 .15083 .58867 .1587 .59576 .15894 .59209 .15122 Metetra
.499 .548 .837 r
.59209 .15122 .59576 .15894 .60289 .15889 .59922 .1514 Metetra
.514 .564 .844 r
.59922 .1514 .60289 .15889 .61003 .1585 .60637 .15129 Metetra
.533 .584 .852 r
.60637 .15129 .61003 .1585 .61719 .15771 .61355 .15084 Metetra
.555 .609 .862 r
.61355 .15084 .61719 .15771 .62436 .15647 .62074 .15 Metetra
.579 .637 .872 r
.62074 .15 .62436 .15647 .63154 .15476 .62794 .14871 Metetra
.606 .668 .883 r
.62794 .14871 .63154 .15476 .63873 .15257 .63515 .14696 Metetra
.634 .7 .894 r
.63515 .14696 .63873 .15257 .64591 .1499 .64237 .14473 Metetra
.661 .733 .903 r
.64237 .14473 .64591 .1499 .6531 .14676 .64958 .14204 Metetra
.688 .766 .911 r
.64958 .14204 .6531 .14676 .66028 .14319 .6568 .13888 Metetra
.713 .797 .917 r
.6568 .13888 .66028 .14319 .66746 .13923 .66401 .1353 Metetra
.736 .826 .92 r
.66401 .1353 .66746 .13923 .67463 .13491 .67122 .13133 Metetra
.755 .851 .922 r
.67122 .13133 .67463 .13491 .6818 .1303 .67842 .12702 Metetra
.77 .872 .922 r
.67842 .12702 .6818 .1303 .68896 .12545 .68561 .12242 Metetra
.783 .889 .921 r
.68561 .12242 .68896 .12545 .69612 .12041 .69281 .11757 Metetra
.791 .902 .92 r
.69281 .11757 .69612 .12041 .70328 .11524 .7 .11255 Metetra
.797 .912 .918 r
.7 .11255 .70328 .11524 .71044 .10999 .70719 .10739 Metetra
.801 .918 .917 r
.70719 .10739 .71044 .10999 .7176 .10471 .71438 .10215 Metetra
.802 .922 .917 r
.71438 .10215 .7176 .10471 .72478 .09944 .72157 .09688 Metetra
.801 .923 .918 r
.72157 .09688 .72478 .09944 .73196 .09421 .72877 .09161 Metetra
.393 0 0 r
.07669 .32875 .08159 .32894 .08686 .33056 .08194 .33059 Metetra
.433 0 0 r
.08194 .33059 .08686 .33056 .09213 .33243 .08719 .33259 Metetra
.448 0 0 r
.08719 .33259 .09213 .33243 .0974 .33445 .09247 .33464 Metetra
.439 0 0 r
.09247 .33464 .0974 .33445 .10269 .33653 .09778 .33664 Metetra
.401 0 0 r
.09778 .33664 .10269 .33653 .10802 .33856 .10314 .33844 Metetra
.321 0 0 r
.10314 .33844 .10802 .33856 .1134 .34038 .10857 .33991 Metetra
.176 0 0 r
.10857 .33991 .1134 .34038 .11885 .34187 .1141 .3409 Metetra
.053 .607 .822 r
.1141 .3409 .11885 .34187 .12439 .34287 .11973 .34127 Metetra
.322 .757 .969 r
.11973 .34127 .12439 .34287 .13003 .34325 .12547 .3409 Metetra
.531 .809 .997 r
.12547 .3409 .13003 .34325 .13579 .34288 .13133 .33971 Metetra
.647 .794 .953 r
.13133 .33971 .13579 .34288 .14166 .34169 .13732 .33763 Metetra
.704 .758 .894 r
.13732 .33763 .14166 .34169 .14766 .3396 .14344 .33466 Metetra
.731 .724 .844 r
.14344 .33466 .14766 .3396 .15378 .33662 .14967 .33081 Metetra
.745 .697 .806 r
.14967 .33081 .15378 .33662 .16001 .33275 .156 .32615 Metetra
.751 .676 .778 r
.156 .32615 .16001 .33275 .16635 .32808 .16241 .32078 Metetra
.754 .66 .758 r
.16241 .32078 .16635 .32808 .17276 .3227 .1689 .31484 Metetra
.754 .649 .744 r
.1689 .31484 .17276 .3227 .17924 .31674 .17543 .30846 Metetra
.754 .641 .735 r
.17543 .30846 .17924 .31674 .18577 .31035 .18199 .30181 Metetra
.752 .635 .731 r
.18199 .30181 .18577 .31035 .19232 .3037 .18857 .29504 Metetra
.751 .632 .729 r
.18857 .29504 .19232 .3037 .19889 .29692 .19513 .28828 Metetra
.748 .632 .731 r
.19513 .28828 .19889 .29692 .20544 .29017 .20168 .28167 Metetra
.745 .633 .735 r
.20168 .28167 .20544 .29017 .21198 .28357 .2082 .27531 Metetra
.742 .636 .742 r
.2082 .27531 .21198 .28357 .2185 .27722 .21469 .26927 Metetra
.739 .641 .751 r
.21469 .26927 .2185 .27722 .22498 .27119 .22114 .2636 Metetra
.735 .647 .762 r
.22114 .2636 .22498 .27119 .23142 .26553 .22756 .25832 Metetra
.73 .655 .775 r
.22756 .25832 .23142 .26553 .23783 .26027 .23393 .25344 Metetra
.725 .663 .788 r
.23393 .25344 .23783 .26027 .2442 .2554 .24028 .24895 Metetra
.719 .672 .803 r
.24028 .24895 .2442 .2554 .25055 .25092 .2466 .24482 Metetra
.713 .681 .817 r
.2466 .24482 .25055 .25092 .25687 .24679 .2529 .241 Metetra
.707 .69 .832 r
.2529 .241 .25687 .24679 .26317 .24299 .25918 .23748 Metetra
.701 .699 .845 r
.25918 .23748 .26317 .24299 .26945 .23947 .26545 .23419 Metetra
.695 .707 .857 r
.26545 .23419 .26945 .23947 .27572 .23619 .27171 .23111 Metetra
.689 .714 .868 r
.27171 .23111 .27572 .23619 .28199 .23311 .27798 .22819 Metetra
.684 .72 .877 r
.27798 .22819 .28199 .23311 .28826 .23019 .28424 .2254 Metetra
.679 .725 .884 r
.28424 .2254 .28826 .23019 .29453 .22741 .29051 .22272 Metetra
.675 .729 .89 r
.29051 .22272 .29453 .22741 .3008 .22473 .29679 .22011 Metetra
.672 .732 .895 r
.29679 .22011 .3008 .22473 .30708 .22213 .30307 .21756 Metetra
.67 .734 .898 r
.30307 .21756 .30708 .22213 .31337 .21958 .30937 .21506 Metetra
.668 .736 .901 r
.30937 .21506 .31337 .21958 .31967 .21708 .31568 .21258 Metetra
.667 .738 .903 r
.31568 .21258 .31967 .21708 .32599 .21461 .322 .21013 Metetra
.666 .739 .904 r
.322 .21013 .32599 .21461 .33232 .21216 .32833 .20769 Metetra
.665 .74 .906 r
.32833 .20769 .33232 .21216 .33866 .20972 .33468 .20525 Metetra
.665 .74 .906 r
.33468 .20525 .33866 .20972 .34501 .20729 .34105 .20282 Metetra
.664 .741 .907 r
.34105 .20282 .34501 .20729 .35138 .20486 .34742 .20039 Metetra
.664 .741 .907 r
.34742 .20039 .35138 .20486 .35777 .20243 .35382 .19796 Metetra
.664 .741 .907 r
.35382 .19796 .35777 .20243 .36416 .2 .36023 .19552 Metetra
.664 .741 .908 r
.36023 .19552 .36416 .2 .37058 .19757 .36665 .19308 Metetra
.664 .741 .908 r
.36665 .19308 .37058 .19757 .37701 .19514 .37309 .19064 Metetra
.664 .741 .908 r
.37309 .19064 .37701 .19514 .38345 .1927 .37954 .18819 Metetra
.664 .741 .908 r
.37954 .18819 .38345 .1927 .38992 .19026 .38601 .18574 Metetra
.663 .741 .908 r
.38601 .18574 .38992 .19026 .39639 .18782 .3925 .18328 Metetra
.663 .741 .908 r
.3925 .18328 .39639 .18782 .40288 .18537 .399 .18082 Metetra
.663 .741 .908 r
.399 .18082 .40288 .18537 .40939 .18292 .40552 .17835 Metetra
.663 .74 .908 r
.40552 .17835 .40939 .18292 .41591 .18047 .41205 .17588 Metetra
.663 .74 .908 r
.41205 .17588 .41591 .18047 .42245 .17802 .4186 .17342 Metetra
.662 .739 .907 r
.4186 .17342 .42245 .17802 .42901 .17558 .42517 .17095 Metetra
.661 .739 .907 r
.42517 .17095 .42901 .17558 .43558 .17314 .43175 .16849 Metetra
.66 .738 .907 r
.43175 .16849 .43558 .17314 .44216 .17073 .43834 .16604 Metetra
.659 .736 .907 r
.43834 .16604 .44216 .17073 .44876 .16833 .44495 .16361 Metetra
.657 .734 .906 r
.44495 .16361 .44876 .16833 .45538 .16598 .45158 .16121 Metetra
.654 .731 .906 r
.45158 .16121 .45538 .16598 .46201 .16368 .45822 .15884 Metetra
.65 .727 .905 r
.45822 .15884 .46201 .16368 .46866 .16145 .46488 .15653 Metetra
.645 .722 .904 r
.46488 .15653 .46866 .16145 .47532 .15931 .47156 .15429 Metetra
.639 .715 .903 r
.47156 .15429 .47532 .15931 .482 .15728 .47825 .15215 Metetra
.631 .707 .901 r
.47825 .15215 .482 .15728 .4887 .15539 .48495 .15012 Metetra
.622 .697 .898 r
.48495 .15012 .4887 .15539 .49541 .15367 .49168 .14822 Metetra
.611 .685 .895 r
.49168 .14822 .49541 .15367 .50215 .15215 .49842 .1465 Metetra
.598 .671 .891 r
.49842 .1465 .50215 .15215 .5089 .15084 .50518 .14497 Metetra
.584 .655 .885 r
.50518 .14497 .5089 .15084 .51567 .14977 .51197 .14366 Metetra
.569 .638 .88 r
.51197 .14366 .51567 .14977 .52247 .14895 .51877 .14259 Metetra
.554 .62 .873 r
.51877 .14259 .52247 .14895 .5293 .1484 .5256 .14177 Metetra
.538 .602 .866 r
.5256 .14177 .5293 .1484 .53615 .14811 .53245 .14121 Metetra
.523 .585 .858 r
.53245 .14121 .53615 .14811 .54303 .14807 .53934 .1409 Metetra
.509 .568 .851 r
.53934 .1409 .54303 .14807 .54994 .14825 .54625 .14084 Metetra
.497 .554 .844 r
.54625 .14084 .54994 .14825 .55688 .14862 .55319 .14099 Metetra
.488 .542 .838 r
.55319 .14099 .55688 .14862 .56386 .14912 .56017 .14133 Metetra
.481 .534 .834 r
.56017 .14133 .56386 .14912 .57087 .1497 .56717 .14179 Metetra
.478 .529 .831 r
.56717 .14179 .57087 .1497 .57791 .1503 .57422 .14233 Metetra
.478 .527 .83 r
.57422 .14233 .57791 .1503 .58498 .15083 .58129 .14287 Metetra
.482 .531 .83 r
.58129 .14287 .58498 .15083 .59209 .15122 .5884 .14335 Metetra
.49 .538 .833 r
.5884 .14335 .59209 .15122 .59922 .1514 .59553 .14368 Metetra
.502 .55 .838 r
.59553 .14368 .59922 .1514 .60637 .15129 .6027 .1438 Metetra
.517 .566 .845 r
.6027 .1438 .60637 .15129 .61355 .15084 .60988 .14364 Metetra
.535 .587 .853 r
.60988 .14364 .61355 .15084 .62074 .15 .61709 .14313 Metetra
.557 .611 .863 r
.61709 .14313 .62074 .15 .62794 .14871 .62431 .14223 Metetra
.581 .639 .873 r
.62431 .14223 .62794 .14871 .63515 .14696 .63155 .14089 Metetra
.607 .669 .884 r
.63155 .14089 .63515 .14696 .64237 .14473 .63879 .1391 Metetra
.634 .701 .894 r
.63879 .1391 .64237 .14473 .64958 .14204 .64603 .13684 Metetra
.662 .734 .903 r
.64603 .13684 .64958 .14204 .6568 .13888 .65328 .13412 Metetra
.688 .766 .911 r
.65328 .13412 .6568 .13888 .66401 .1353 .66052 .13095 Metetra
.713 .797 .917 r
.66052 .13095 .66401 .1353 .67122 .13133 .66777 .12736 Metetra
.735 .825 .92 r
.66777 .12736 .67122 .13133 .67842 .12702 .675 .12338 Metetra
.754 .849 .922 r
.675 .12338 .67842 .12702 .68561 .12242 .68223 .11907 Metetra
.769 .87 .922 r
.68223 .11907 .68561 .12242 .69281 .11757 .68946 .11447 Metetra
.781 .887 .921 r
.68946 .11447 .69281 .11757 .7 .11255 .69668 .10964 Metetra
.79 .9 .92 r
.69668 .10964 .7 .11255 .70719 .10739 .7039 .10462 Metetra
.796 .91 .919 r
.7039 .10462 .70719 .10739 .71438 .10215 .71112 .09947 Metetra
.799 .916 .918 r
.71112 .09947 .71438 .10215 .72157 .09688 .71834 .09425 Metetra
.8 .92 .918 r
.71834 .09425 .72157 .09688 .72877 .09161 .72557 .08898 Metetra
.427 0 0 r
.07173 .32875 .07669 .32875 .08194 .33059 .07696 .33072 Metetra
.443 0 0 r
.07696 .33072 .08194 .33059 .08719 .33259 .08222 .33275 Metetra
.434 0 0 r
.08222 .33275 .08719 .33259 .09247 .33464 .08751 .33472 Metetra
.396 0 0 r
.08751 .33472 .09247 .33464 .09778 .33664 .09286 .3365 Metetra
.315 0 0 r
.09286 .3365 .09778 .33664 .10314 .33844 .09828 .33794 Metetra
.17 0 0 r
.09828 .33794 .10314 .33844 .10857 .33991 .10379 .33891 Metetra
.057 .61 .826 r
.10379 .33891 .10857 .33991 .1141 .3409 .1094 .33927 Metetra
.324 .757 .97 r
.1094 .33927 .1141 .3409 .11973 .34127 .11513 .33891 Metetra
.53 .809 .997 r
.11513 .33891 .11973 .34127 .12547 .3409 .12098 .33772 Metetra
.646 .793 .953 r
.12098 .33772 .12547 .3409 .13133 .33971 .12697 .33565 Metetra
.703 .758 .895 r
.12697 .33565 .13133 .33971 .13732 .33763 .13307 .33269 Metetra
.731 .725 .845 r
.13307 .33269 .13732 .33763 .14344 .33466 .1393 .32886 Metetra
.744 .697 .807 r
.1393 .32886 .14344 .33466 .14967 .33081 .14563 .32421 Metetra
.751 .676 .779 r
.14563 .32421 .14967 .33081 .156 .32615 .15205 .31886 Metetra
.753 .66 .759 r
.15205 .31886 .156 .32615 .16241 .32078 .15854 .31293 Metetra
.754 .649 .745 r
.15854 .31293 .16241 .32078 .1689 .31484 .16508 .30656 Metetra
.754 .641 .736 r
.16508 .30656 .1689 .31484 .17543 .30846 .17165 .29992 Metetra
.752 .635 .731 r
.17165 .29992 .17543 .30846 .18199 .30181 .17823 .29314 Metetra
.751 .633 .729 r
.17823 .29314 .18199 .30181 .18857 .29504 .1848 .28639 Metetra
.748 .632 .731 r
.1848 .28639 .18857 .29504 .19513 .28828 .19136 .27977 Metetra
.746 .633 .735 r
.19136 .27977 .19513 .28828 .20168 .28167 .19789 .2734 Metetra
.742 .636 .742 r
.19789 .2734 .20168 .28167 .2082 .27531 .20439 .26735 Metetra
.739 .641 .751 r
.20439 .26735 .2082 .27531 .21469 .26927 .21084 .26166 Metetra
.735 .647 .762 r
.21084 .26166 .21469 .26927 .22114 .2636 .21726 .25638 Metetra
.73 .655 .775 r
.21726 .25638 .22114 .2636 .22756 .25832 .22364 .25149 Metetra
.725 .663 .788 r
.22364 .25149 .22756 .25832 .23393 .25344 .22999 .24698 Metetra
.72 .672 .803 r
.22999 .24698 .23393 .25344 .24028 .24895 .23631 .24284 Metetra
.714 .681 .817 r
.23631 .24284 .24028 .24895 .2466 .24482 .24261 .23902 Metetra
.707 .69 .832 r
.24261 .23902 .2466 .24482 .2529 .241 .24889 .23548 Metetra
.701 .699 .845 r
.24889 .23548 .2529 .241 .25918 .23748 .25516 .23219 Metetra
.695 .707 .857 r
.25516 .23219 .25918 .23748 .26545 .23419 .26142 .2291 Metetra
.689 .714 .868 r
.26142 .2291 .26545 .23419 .27171 .23111 .26768 .22618 Metetra
.684 .72 .877 r
.26768 .22618 .27171 .23111 .27798 .22819 .27393 .22339 Metetra
.679 .725 .884 r
.27393 .22339 .27798 .22819 .28424 .2254 .2802 .2207 Metetra
.675 .729 .89 r
.2802 .2207 .28424 .2254 .29051 .22272 .28647 .21809 Metetra
.672 .732 .895 r
.28647 .21809 .29051 .22272 .29679 .22011 .29275 .21554 Metetra
.67 .734 .898 r
.29275 .21554 .29679 .22011 .30307 .21756 .29904 .21303 Metetra
.668 .736 .901 r
.29904 .21303 .30307 .21756 .30937 .21506 .30534 .21055 Metetra
.667 .738 .903 r
.30534 .21055 .30937 .21506 .31568 .21258 .31166 .20809 Metetra
.666 .739 .905 r
.31166 .20809 .31568 .21258 .322 .21013 .31799 .20565 Metetra
.665 .74 .906 r
.31799 .20565 .322 .21013 .32833 .20769 .32433 .20321 Metetra
.665 .74 .906 r
.32433 .20321 .32833 .20769 .33468 .20525 .33069 .20077 Metetra
.664 .741 .907 r
.33069 .20077 .33468 .20525 .34105 .20282 .33706 .19834 Metetra
.664 .741 .907 r
.33706 .19834 .34105 .20282 .34742 .20039 .34345 .1959 Metetra
.664 .741 .907 r
.34345 .1959 .34742 .20039 .35382 .19796 .34985 .19346 Metetra
.664 .741 .908 r
.34985 .19346 .35382 .19796 .36023 .19552 .35627 .19102 Metetra
.664 .741 .908 r
.35627 .19102 .36023 .19552 .36665 .19308 .3627 .18857 Metetra
.664 .741 .908 r
.3627 .18857 .36665 .19308 .37309 .19064 .36915 .18612 Metetra
.664 .741 .908 r
.36915 .18612 .37309 .19064 .37954 .18819 .37562 .18366 Metetra
.664 .741 .908 r
.37562 .18366 .37954 .18819 .38601 .18574 .3821 .18119 Metetra
.664 .741 .908 r
.3821 .18119 .38601 .18574 .3925 .18328 .38859 .17873 Metetra
.663 .741 .908 r
.38859 .17873 .3925 .18328 .399 .18082 .3951 .17625 Metetra
.663 .741 .908 r
.3951 .17625 .399 .18082 .40552 .17835 .40163 .17377 Metetra
.663 .741 .908 r
.40163 .17377 .40552 .17835 .41205 .17588 .40817 .17129 Metetra
.663 .741 .908 r
.40817 .17129 .41205 .17588 .4186 .17342 .41473 .16881 Metetra
.663 .74 .908 r
.41473 .16881 .4186 .17342 .42517 .17095 .42131 .16632 Metetra
.662 .74 .908 r
.42131 .16632 .42517 .17095 .43175 .16849 .4279 .16384 Metetra
.661 .739 .907 r
.4279 .16384 .43175 .16849 .43834 .16604 .4345 .16136 Metetra
.66 .738 .907 r
.4345 .16136 .43834 .16604 .44495 .16361 .44113 .1589 Metetra
.659 .736 .907 r
.44113 .1589 .44495 .16361 .45158 .16121 .44776 .15645 Metetra
.656 .734 .906 r
.44776 .15645 .45158 .16121 .45822 .15884 .45442 .15403 Metetra
.653 .731 .906 r
.45442 .15403 .45822 .15884 .46488 .15653 .46109 .15166 Metetra
.649 .726 .905 r
.46109 .15166 .46488 .15653 .47156 .15429 .46777 .14934 Metetra
.644 .721 .904 r
.46777 .14934 .47156 .15429 .47825 .15215 .47448 .14709 Metetra
.638 .714 .902 r
.47448 .14709 .47825 .15215 .48495 .15012 .48119 .14494 Metetra
.63 .706 .9 r
.48119 .14494 .48495 .15012 .49168 .14822 .48793 .1429 Metetra
.621 .696 .898 r
.48793 .1429 .49168 .14822 .49842 .1465 .49468 .141 Metetra
.61 .683 .894 r
.49468 .141 .49842 .1465 .50518 .14497 .50145 .13928 Metetra
.597 .67 .89 r
.50145 .13928 .50518 .14497 .51197 .14366 .50824 .13775 Metetra
.583 .654 .885 r
.50824 .13775 .51197 .14366 .51877 .14259 .51506 .13643 Metetra
.569 .637 .879 r
.51506 .13643 .51877 .14259 .5256 .14177 .52189 .13536 Metetra
.553 .62 .873 r
.52189 .13536 .5256 .14177 .53245 .14121 .52875 .13453 Metetra
.538 .602 .866 r
.52875 .13453 .53245 .14121 .53934 .1409 .53563 .13396 Metetra
.523 .585 .858 r
.53563 .13396 .53934 .1409 .54625 .14084 .54255 .13364 Metetra
.51 .569 .851 r
.54255 .13364 .54625 .14084 .55319 .14099 .54949 .13355 Metetra
.498 .555 .845 r
.54949 .13355 .55319 .14099 .56017 .14133 .55646 .13368 Metetra
.489 .543 .839 r
.55646 .13368 .56017 .14133 .56717 .14179 .56347 .13398 Metetra
.483 .535 .834 r
.56347 .13398 .56717 .14179 .57422 .14233 .57051 .13441 Metetra
.48 .53 .832 r
.57051 .13441 .57422 .14233 .58129 .14287 .57759 .1349 Metetra
.48 .53 .831 r
.57759 .1349 .58129 .14287 .5884 .14335 .5847 .13539 Metetra
.484 .533 .831 r
.5847 .13539 .5884 .14335 .59553 .14368 .59184 .13581 Metetra
.492 .541 .834 r
.59184 .13581 .59553 .14368 .6027 .1438 .59901 .13608 Metetra
.504 .553 .839 r
.59901 .13608 .6027 .1438 .60988 .14364 .6062 .13614 Metetra
.519 .569 .846 r
.6062 .13614 .60988 .14364 .61709 .14313 .61342 .13592 Metetra
.537 .589 .854 r
.61342 .13592 .61709 .14313 .62431 .14223 .62066 .13536 Metetra
.559 .613 .864 r
.62066 .13536 .62431 .14223 .63155 .14089 .62791 .1344 Metetra
.583 .641 .874 r
.62791 .1344 .63155 .14089 .63879 .1391 .63518 .13302 Metetra
.609 .671 .884 r
.63518 .13302 .63879 .1391 .64603 .13684 .64245 .13119 Metetra
.635 .702 .894 r
.64245 .13119 .64603 .13684 .65328 .13412 .64972 .1289 Metetra
.662 .734 .903 r
.64972 .1289 .65328 .13412 .66052 .13095 .657 .12615 Metetra
.688 .766 .911 r
.657 .12615 .66052 .13095 .66777 .12736 .66428 .12296 Metetra
.712 .796 .917 r
.66428 .12296 .66777 .12736 .675 .12338 .67155 .11935 Metetra
.734 .823 .92 r
.67155 .11935 .675 .12338 .68223 .11907 .67881 .11538 Metetra
.752 .848 .922 r
.67881 .11538 .68223 .11907 .68946 .11447 .68608 .11106 Metetra
.768 .868 .922 r
.68608 .11106 .68946 .11447 .69668 .10964 .69333 .10647 Metetra
.779 .885 .922 r
.69333 .10647 .69668 .10964 .7039 .10462 .70058 .10164 Metetra
.788 .898 .921 r
.70058 .10164 .7039 .10462 .71112 .09947 .70783 .09664 Metetra
.794 .908 .919 r
.70783 .09664 .71112 .09947 .71834 .09425 .71508 .0915 Metetra
.798 .914 .919 r
.71508 .0915 .71834 .09425 .72557 .08898 .72234 .08628 Metetra
.437 0 0 r
.06672 .32885 .07173 .32875 .07696 .33072 .07196 .33085 Metetra
.428 0 0 r
.07196 .33085 .07696 .33072 .08222 .33275 .07723 .33279 Metetra
.39 0 0 r
.07723 .33279 .08222 .33275 .08751 .33472 .08256 .33454 Metetra
.309 0 0 r
.08256 .33454 .08751 .33472 .09286 .3365 .08796 .33597 Metetra
.164 0 0 r
.08796 .33597 .09286 .3365 .09828 .33794 .09346 .33692 Metetra
.062 .613 .83 r
.09346 .33692 .09828 .33794 .10379 .33891 .09906 .33727 Metetra
.326 .757 .971 r
.09906 .33727 .10379 .33891 .1094 .33927 .10477 .3369 Metetra
.53 .808 .997 r
.10477 .3369 .1094 .33927 .11513 .33891 .11062 .33571 Metetra
.645 .793 .953 r
.11062 .33571 .11513 .33891 .12098 .33772 .11659 .33366 Metetra
.702 .758 .895 r
.11659 .33366 .12098 .33772 .12697 .33565 .12269 .33071 Metetra
.73 .725 .846 r
.12269 .33071 .12697 .33565 .13307 .33269 .12891 .32689 Metetra
.744 .698 .807 r
.12891 .32689 .13307 .33269 .1393 .32886 .13524 .32227 Metetra
.75 .676 .779 r
.13524 .32227 .1393 .32886 .14563 .32421 .14166 .31693 Metetra
.753 .661 .759 r
.14166 .31693 .14563 .32421 .15205 .31886 .14816 .31101 Metetra
.754 .649 .745 r
.14816 .31101 .15205 .31886 .15854 .31293 .1547 .30466 Metetra
.754 .641 .736 r
.1547 .30466 .15854 .31293 .16508 .30656 .16128 .29802 Metetra
.752 .636 .731 r
.16128 .29802 .16508 .30656 .17165 .29992 .16787 .29125 Metetra
.751 .633 .73 r
.16787 .29125 .17165 .29992 .17823 .29314 .17445 .28449 Metetra
.748 .632 .731 r
.17445 .28449 .17823 .29314 .1848 .28639 .18102 .27787 Metetra
.746 .633 .735 r
.18102 .27787 .1848 .28639 .19136 .27977 .18756 .27149 Metetra
.743 .636 .742 r
.18756 .27149 .19136 .27977 .19789 .2734 .19406 .26543 Metetra
.739 .641 .751 r
.19406 .26543 .19789 .2734 .20439 .26735 .20052 .25973 Metetra
.735 .647 .762 r
.20052 .25973 .20439 .26735 .21084 .26166 .20694 .25443 Metetra
.73 .655 .774 r
.20694 .25443 .21084 .26166 .21726 .25638 .21333 .24953 Metetra
.725 .663 .788 r
.21333 .24953 .21726 .25638 .22364 .25149 .21968 .24501 Metetra
.72 .672 .803 r
.21968 .24501 .22364 .25149 .22999 .24698 .226 .24086 Metetra
.714 .681 .817 r
.226 .24086 .22999 .24698 .23631 .24284 .2323 .23703 Metetra
.707 .691 .832 r
.2323 .23703 .23631 .24284 .24261 .23902 .23858 .23349 Metetra
.701 .699 .845 r
.23858 .23349 .24261 .23902 .24889 .23548 .24484 .23019 Metetra
.695 .707 .857 r
.24484 .23019 .24889 .23548 .25516 .23219 .2511 .2271 Metetra
.689 .714 .868 r
.2511 .2271 .25516 .23219 .26142 .2291 .25735 .22417 Metetra
.684 .72 .877 r
.25735 .22417 .26142 .2291 .26768 .22618 .26361 .22138 Metetra
.679 .725 .884 r
.26361 .22138 .26768 .22618 .27393 .22339 .26987 .21868 Metetra
.675 .729 .89 r
.26987 .21868 .27393 .22339 .2802 .2207 .27613 .21607 Metetra
.672 .732 .895 r
.27613 .21607 .2802 .2207 .28647 .21809 .28241 .21352 Metetra
.67 .735 .898 r
.28241 .21352 .28647 .21809 .29275 .21554 .28869 .211 Metetra
.668 .736 .901 r
.28869 .211 .29275 .21554 .29904 .21303 .29499 .20852 Metetra
.667 .738 .903 r
.29499 .20852 .29904 .21303 .30534 .21055 .3013 .20606 Metetra
.666 .739 .905 r
.3013 .20606 .30534 .21055 .31166 .20809 .30762 .20361 Metetra
.665 .74 .906 r
.30762 .20361 .31166 .20809 .31799 .20565 .31396 .20116 Metetra
.665 .74 .906 r
.31396 .20116 .31799 .20565 .32433 .20321 .32031 .19872 Metetra
.664 .74 .907 r
.32031 .19872 .32433 .20321 .33069 .20077 .32668 .19628 Metetra
.664 .741 .907 r
.32668 .19628 .33069 .20077 .33706 .19834 .33306 .19384 Metetra
.664 .741 .907 r
.33306 .19384 .33706 .19834 .34345 .1959 .33946 .1914 Metetra
.664 .741 .908 r
.33946 .1914 .34345 .1959 .34985 .19346 .34587 .18895 Metetra
.664 .741 .908 r
.34587 .18895 .34985 .19346 .35627 .19102 .35229 .1865 Metetra
.664 .741 .908 r
.35229 .1865 .35627 .19102 .3627 .18857 .35874 .18404 Metetra
.664 .741 .908 r
.35874 .18404 .3627 .18857 .36915 .18612 .3652 .18158 Metetra
.664 .741 .908 r
.3652 .18158 .36915 .18612 .37562 .18366 .37167 .17911 Metetra
.664 .741 .908 r
.37167 .17911 .37562 .18366 .3821 .18119 .37816 .17663 Metetra
.664 .741 .908 r
.37816 .17663 .3821 .18119 .38859 .17873 .38467 .17415 Metetra
.663 .741 .908 r
.38467 .17415 .38859 .17873 .3951 .17625 .39119 .17167 Metetra
.663 .741 .908 r
.39119 .17167 .3951 .17625 .40163 .17377 .39772 .16918 Metetra
.663 .741 .908 r
.39772 .16918 .40163 .17377 .40817 .17129 .40428 .16668 Metetra
.663 .741 .908 r
.40428 .16668 .40817 .17129 .41473 .16881 .41085 .16418 Metetra
.663 .741 .908 r
.41085 .16418 .41473 .16881 .42131 .16632 .41743 .16168 Metetra
.663 .74 .908 r
.41743 .16168 .42131 .16632 .4279 .16384 .42403 .15918 Metetra
.662 .74 .908 r
.42403 .15918 .4279 .16384 .4345 .16136 .43065 .15668 Metetra
.661 .739 .908 r
.43065 .15668 .4345 .16136 .44113 .1589 .43728 .15419 Metetra
.66 .738 .907 r
.43728 .15419 .44113 .1589 .44776 .15645 .44393 .1517 Metetra
.658 .736 .907 r
.44393 .1517 .44776 .15645 .45442 .15403 .4506 .14924 Metetra
.656 .734 .907 r
.4506 .14924 .45442 .15403 .46109 .15166 .45728 .14681 Metetra
.653 .73 .906 r
.45728 .14681 .46109 .15166 .46777 .14934 .46397 .14442 Metetra
.649 .726 .905 r
.46397 .14442 .46777 .14934 .47448 .14709 .47069 .14209 Metetra
.644 .721 .904 r
.47069 .14209 .47448 .14709 .48119 .14494 .47741 .13984 Metetra
.637 .714 .902 r
.47741 .13984 .48119 .14494 .48793 .1429 .48416 .13768 Metetra
.629 .705 .9 r
.48416 .13768 .48793 .1429 .49468 .141 .49092 .13563 Metetra
.62 .695 .898 r
.49092 .13563 .49468 .141 .50145 .13928 .4977 .13374 Metetra
.609 .682 .894 r
.4977 .13374 .50145 .13928 .50824 .13775 .5045 .13201 Metetra
.596 .669 .89 r
.5045 .13201 .50824 .13775 .51506 .13643 .51132 .13047 Metetra
.583 .653 .885 r
.51132 .13047 .51506 .13643 .52189 .13536 .51817 .12915 Metetra
.568 .636 .879 r
.51817 .12915 .52189 .13536 .52875 .13453 .52503 .12807 Metetra
.553 .619 .872 r
.52503 .12807 .52875 .13453 .53563 .13396 .53192 .12724 Metetra
.537 .602 .865 r
.53192 .12724 .53563 .13396 .54255 .13364 .53884 .12665 Metetra
.523 .585 .858 r
.53884 .12665 .54255 .13364 .54949 .13355 .54578 .12632 Metetra
.51 .569 .851 r
.54578 .12632 .54949 .13355 .55646 .13368 .55276 .12622 Metetra
.499 .555 .845 r
.55276 .12622 .55646 .13368 .56347 .13398 .55976 .12632 Metetra
.49 .544 .839 r
.55976 .12632 .56347 .13398 .57051 .13441 .5668 .12658 Metetra
.484 .536 .835 r
.5668 .12658 .57051 .13441 .57759 .1349 .57388 .12697 Metetra
.481 .532 .832 r
.57388 .12697 .57759 .1349 .5847 .13539 .58099 .12741 Metetra
.482 .532 .832 r
.58099 .12741 .5847 .13539 .59184 .13581 .58813 .12785 Metetra
.486 .535 .833 r
.58813 .12785 .59184 .13581 .59901 .13608 .5953 .12822 Metetra
.494 .543 .836 r
.5953 .12822 .59901 .13608 .6062 .13614 .6025 .12843 Metetra
.506 .555 .84 r
.6025 .12843 .6062 .13614 .61342 .13592 .60973 .12843 Metetra
.521 .572 .847 r
.60973 .12843 .61342 .13592 .62066 .13536 .61698 .12815 Metetra
.54 .592 .855 r
.61698 .12815 .62066 .13536 .62791 .1344 .62425 .12753 Metetra
.561 .616 .864 r
.62425 .12753 .62791 .1344 .63518 .13302 .63154 .12652 Metetra
.584 .643 .875 r
.63154 .12652 .63518 .13302 .64245 .13119 .63883 .1251 Metetra
.61 .672 .885 r
.63883 .1251 .64245 .13119 .64972 .1289 .64614 .12322 Metetra
.636 .703 .895 r
.64614 .12322 .64972 .1289 .657 .12615 .65344 .1209 Metetra
.662 .735 .903 r
.65344 .1209 .657 .12615 .66428 .12296 .66075 .11812 Metetra
.688 .766 .911 r
.66075 .11812 .66428 .12296 .67155 .11935 .66806 .11491 Metetra
.712 .795 .916 r
.66806 .11491 .67155 .11935 .67881 .11538 .67536 .1113 Metetra
.733 .822 .92 r
.67536 .1113 .67881 .11538 .68608 .11106 .68265 .10731 Metetra
.751 .846 .922 r
.68265 .10731 .68608 .11106 .69333 .10647 .68995 .103 Metetra
.766 .866 .923 r
.68995 .103 .69333 .10647 .70058 .10164 .69723 .09841 Metetra
.778 .883 .922 r
.69723 .09841 .70058 .10164 .70783 .09664 .70452 .09359 Metetra
.787 .896 .921 r
.70452 .09359 .70783 .09664 .71508 .0915 .7118 .08859 Metetra
.793 .906 .92 r
.7118 .08859 .71508 .0915 .72234 .08628 .71908 .08347 Metetra
.423 0 0 r
.06167 .32894 .06672 .32885 .07196 .33085 .06693 .33086 Metetra
.384 0 0 r
.06693 .33086 .07196 .33085 .07723 .33279 .07224 .33258 Metetra
.302 0 0 r
.07224 .33258 .07723 .33279 .08256 .33454 .07763 .33399 Metetra
.157 0 0 r
.07763 .33399 .08256 .33454 .08796 .33597 .08311 .33492 Metetra
.068 .616 .834 r
.08311 .33492 .08796 .33597 .09346 .33692 .08869 .33526 Metetra
.328 .758 .972 r
.08869 .33526 .09346 .33692 .09906 .33727 .0944 .33488 Metetra
.53 .807 .997 r
.0944 .33488 .09906 .33727 .10477 .3369 .10023 .3337 Metetra
.644 .792 .953 r
.10023 .3337 .10477 .3369 .11062 .33571 .10619 .33165 Metetra
.702 .758 .896 r
.10619 .33165 .11062 .33571 .11659 .33366 .11229 .32872 Metetra
.729 .725 .846 r
.11229 .32872 .11659 .33366 .12269 .33071 .11851 .32492 Metetra
.743 .698 .808 r
.11851 .32492 .12269 .33071 .12891 .32689 .12483 .32031 Metetra
.75 .677 .78 r
.12483 .32031 .12891 .32689 .13524 .32227 .13126 .31499 Metetra
.753 .661 .76 r
.13126 .31499 .13524 .32227 .14166 .31693 .13775 .30909 Metetra
.754 .649 .746 r
.13775 .30909 .14166 .31693 .14816 .31101 .1443 .30275 Metetra
.754 .641 .736 r
.1443 .30275 .14816 .31101 .1547 .30466 .15089 .29612 Metetra
.752 .636 .731 r
.15089 .29612 .1547 .30466 .16128 .29802 .15749 .28935 Metetra
.751 .633 .73 r
.15749 .28935 .16128 .29802 .16787 .29125 .16408 .28259 Metetra
.748 .632 .731 r
.16408 .28259 .16787 .29125 .17445 .28449 .17065 .27597 Metetra
.746 .633 .735 r
.17065 .27597 .17445 .28449 .18102 .27787 .1772 .26958 Metetra
.743 .636 .742 r
.1772 .26958 .18102 .27787 .18756 .27149 .18371 .2635 Metetra
.739 .641 .751 r
.18371 .2635 .18756 .27149 .19406 .26543 .19018 .2578 Metetra
.735 .647 .762 r
.19018 .2578 .19406 .26543 .20052 .25973 .19661 .25249 Metetra
.73 .655 .774 r
.19661 .25249 .20052 .25973 .20694 .25443 .203 .24757 Metetra
.725 .663 .788 r
.203 .24757 .20694 .25443 .21333 .24953 .20935 .24305 Metetra
.72 .672 .803 r
.20935 .24305 .21333 .24953 .21968 .24501 .21567 .23888 Metetra
.714 .681 .817 r
.21567 .23888 .21968 .24501 .226 .24086 .22197 .23504 Metetra
.707 .691 .832 r
.22197 .23504 .226 .24086 .2323 .23703 .22824 .2315 Metetra
.701 .699 .845 r
.22824 .2315 .2323 .23703 .23858 .23349 .23451 .22819 Metetra
.695 .707 .857 r
.23451 .22819 .23858 .23349 .24484 .23019 .24076 .22509 Metetra
.689 .714 .868 r
.24076 .22509 .24484 .23019 .2511 .2271 .24701 .22216 Metetra
.684 .72 .877 r
.24701 .22216 .2511 .2271 .25735 .22417 .25326 .21936 Metetra
.679 .725 .884 r
.25326 .21936 .25735 .22417 .26361 .22138 .25951 .21666 Metetra
.675 .729 .89 r
.25951 .21666 .26361 .22138 .26987 .21868 .26577 .21405 Metetra
.672 .732 .895 r
.26577 .21405 .26987 .21868 .27613 .21607 .27204 .21149 Metetra
.67 .735 .899 r
.27204 .21149 .27613 .21607 .28241 .21352 .27832 .20897 Metetra
.668 .736 .901 r
.27832 .20897 .28241 .21352 .28869 .211 .28461 .20648 Metetra
.667 .738 .903 r
.28461 .20648 .28869 .211 .29499 .20852 .29092 .20402 Metetra
.666 .739 .905 r
.29092 .20402 .29499 .20852 .3013 .20606 .29723 .20156 Metetra
.665 .74 .906 r
.29723 .20156 .3013 .20606 .30762 .20361 .30357 .19911 Metetra
.665 .74 .906 r
.30357 .19911 .30762 .20361 .31396 .20116 .30991 .19667 Metetra
.664 .74 .907 r
.30991 .19667 .31396 .20116 .32031 .19872 .31627 .19422 Metetra
.664 .741 .907 r
.31627 .19422 .32031 .19872 .32668 .19628 .32265 .19178 Metetra
.664 .741 .907 r
.32265 .19178 .32668 .19628 .33306 .19384 .32904 .18933 Metetra
.664 .741 .908 r
.32904 .18933 .33306 .19384 .33946 .1914 .33544 .18687 Metetra
.664 .741 .908 r
.33544 .18687 .33946 .1914 .34587 .18895 .34187 .18442 Metetra
.664 .741 .908 r
.34187 .18442 .34587 .18895 .35229 .1865 .3483 .18195 Metetra
.664 .741 .908 r
.3483 .18195 .35229 .1865 .35874 .18404 .35475 .17949 Metetra
.664 .741 .908 r
.35475 .17949 .35874 .18404 .3652 .18158 .36122 .17701 Metetra
.664 .741 .908 r
.36122 .17701 .3652 .18158 .37167 .17911 .36771 .17453 Metetra
.664 .741 .908 r
.36771 .17453 .37167 .17911 .37816 .17663 .37421 .17205 Metetra
.664 .741 .908 r
.37421 .17205 .37816 .17663 .38467 .17415 .38072 .16956 Metetra
.663 .741 .908 r
.38072 .16956 .38467 .17415 .39119 .17167 .38725 .16706 Metetra
.663 .741 .908 r
.38725 .16706 .39119 .17167 .39772 .16918 .3938 .16456 Metetra
.663 .741 .908 r
.3938 .16456 .39772 .16918 .40428 .16668 .40036 .16205 Metetra
.663 .741 .908 r
.40036 .16205 .40428 .16668 .41085 .16418 .40694 .15954 Metetra
.663 .741 .908 r
.40694 .15954 .41085 .16418 .41743 .16168 .41354 .15702 Metetra
.663 .741 .908 r
.41354 .15702 .41743 .16168 .42403 .15918 .42015 .1545 Metetra
.663 .74 .908 r
.42015 .1545 .42403 .15918 .43065 .15668 .42678 .15198 Metetra
.662 .74 .908 r
.42678 .15198 .43065 .15668 .43728 .15419 .43342 .14947 Metetra
.661 .739 .908 r
.43342 .14947 .43728 .15419 .44393 .1517 .44008 .14696 Metetra
.66 .738 .907 r
.44008 .14696 .44393 .1517 .4506 .14924 .44675 .14446 Metetra
.658 .736 .907 r
.44675 .14446 .4506 .14924 .45728 .14681 .45345 .14199 Metetra
.656 .733 .907 r
.45345 .14199 .45728 .14681 .46397 .14442 .46015 .13954 Metetra
.653 .73 .906 r
.46015 .13954 .46397 .14442 .47069 .14209 .46688 .13714 Metetra
.649 .726 .905 r
.46688 .13714 .47069 .14209 .47741 .13984 .47362 .1348 Metetra
.643 .72 .904 r
.47362 .1348 .47741 .13984 .48416 .13768 .48038 .13254 Metetra
.637 .713 .902 r
.48038 .13254 .48416 .13768 .49092 .13563 .48715 .13037 Metetra
.629 .704 .9 r
.48715 .13037 .49092 .13563 .4977 .13374 .49394 .12832 Metetra
.619 .694 .897 r
.49394 .12832 .4977 .13374 .5045 .13201 .50075 .12642 Metetra
.608 .682 .894 r
.50075 .12642 .5045 .13201 .51132 .13047 .50758 .12468 Metetra
.596 .668 .89 r
.50758 .12468 .51132 .13047 .51817 .12915 .51443 .12315 Metetra
.582 .652 .885 r
.51443 .12315 .51817 .12915 .52503 .12807 .5213 .12182 Metetra
.567 .636 .879 r
.5213 .12182 .52503 .12807 .53192 .12724 .52819 .12074 Metetra
.552 .618 .872 r
.52819 .12074 .53192 .12724 .53884 .12665 .53511 .11989 Metetra
.537 .601 .865 r
.53511 .11989 .53884 .12665 .54578 .12632 .54206 .1193 Metetra
.523 .585 .858 r
.54206 .1193 .54578 .12632 .55276 .12622 .54904 .11895 Metetra
.51 .569 .851 r
.54904 .11895 .55276 .12622 .55976 .12632 .55605 .11882 Metetra
.499 .556 .845 r
.55605 .11882 .55976 .12632 .5668 .12658 .56309 .1189 Metetra
.491 .545 .84 r
.56309 .1189 .5668 .12658 .57388 .12697 .57016 .11913 Metetra
.485 .538 .836 r
.57016 .11913 .57388 .12697 .58099 .12741 .57727 .11947 Metetra
.483 .534 .833 r
.57727 .11947 .58099 .12741 .58813 .12785 .58441 .11987 Metetra
.484 .534 .833 r
.58441 .11987 .58813 .12785 .5953 .12822 .59158 .12026 Metetra
.489 .538 .834 r
.59158 .12026 .5953 .12822 .6025 .12843 .59879 .12056 Metetra
.497 .546 .837 r
.59879 .12056 .6025 .12843 .60973 .12843 .60602 .12072 Metetra
.508 .558 .842 r
.60602 .12072 .60973 .12843 .61698 .12815 .61328 .12066 Metetra
.523 .574 .848 r
.61328 .12066 .61698 .12815 .62425 .12753 .62057 .12032 Metetra
.542 .594 .856 r
.62057 .12032 .62425 .12753 .63154 .12652 .62787 .11965 Metetra
.563 .618 .865 r
.62787 .11965 .63154 .12652 .63883 .1251 .63519 .11859 Metetra
.586 .645 .875 r
.63519 .11859 .63883 .1251 .64614 .12322 .64252 .11711 Metetra
.611 .674 .885 r
.64252 .11711 .64614 .12322 .65344 .1209 .64985 .1152 Metetra
.637 .704 .895 r
.64985 .1152 .65344 .1209 .66075 .11812 .65719 .11284 Metetra
.663 .735 .904 r
.65719 .11284 .66075 .11812 .66806 .11491 .66453 .11003 Metetra
.688 .766 .911 r
.66453 .11003 .66806 .11491 .67536 .1113 .67186 .10681 Metetra
.711 .795 .916 r
.67186 .10681 .67536 .1113 .68265 .10731 .6792 .10318 Metetra
.732 .821 .92 r
.6792 .10318 .68265 .10731 .68995 .103 .68652 .09919 Metetra
.75 .845 .922 r
.68652 .09919 .68995 .103 .69723 .09841 .69385 .09488 Metetra
.765 .865 .923 r
.69385 .09488 .69723 .09841 .70452 .09359 .70116 .09029 Metetra
.776 .881 .922 r
.70116 .09029 .70452 .09359 .7118 .08859 .70848 .08548 Metetra
.785 .894 .921 r
.70848 .08548 .7118 .08859 .71908 .08347 .71579 .08049 Metetra
.377 0 0 r
.05661 .32892 .06167 .32894 .06693 .33086 .06191 .33062 Metetra
.295 0 0 r
.06191 .33062 .06693 .33086 .07224 .33258 .06728 .33199 Metetra
.15 0 0 r
.06728 .33199 .07224 .33258 .07763 .33399 .07274 .33291 Metetra
.073 .62 .839 r
.07274 .33291 .07763 .33399 .08311 .33492 .07831 .33324 Metetra
.33 .758 .973 r
.07831 .33324 .08311 .33492 .08869 .33526 .084 .33286 Metetra
.53 .807 .997 r
.084 .33286 .08869 .33526 .0944 .33488 .08982 .33167 Metetra
.644 .792 .954 r
.08982 .33167 .0944 .33488 .10023 .3337 .09578 .32963 Metetra
.701 .758 .897 r
.09578 .32963 .10023 .3337 .10619 .33165 .10187 .32671 Metetra
.729 .725 .847 r
.10187 .32671 .10619 .33165 .11229 .32872 .10808 .32293 Metetra
.743 .698 .809 r
.10808 .32293 .11229 .32872 .11851 .32492 .11441 .31834 Metetra
.75 .677 .781 r
.11441 .31834 .11851 .32492 .12483 .32031 .12083 .31304 Metetra
.753 .661 .76 r
.12083 .31304 .12483 .32031 .13126 .31499 .12733 .30716 Metetra
.754 .65 .746 r
.12733 .30716 .13126 .31499 .13775 .30909 .13389 .30083 Metetra
.753 .641 .737 r
.13389 .30083 .13775 .30909 .1443 .30275 .14048 .29421 Metetra
.752 .636 .732 r
.14048 .29421 .1443 .30275 .15089 .29612 .14708 .28745 Metetra
.751 .633 .73 r
.14708 .28745 .15089 .29612 .15749 .28935 .15368 .28069 Metetra
.748 .632 .731 r
.15368 .28069 .15749 .28935 .16408 .28259 .16027 .27406 Metetra
.746 .634 .735 r
.16027 .27406 .16408 .28259 .17065 .27597 .16682 .26767 Metetra
.743 .637 .742 r
.16682 .26767 .17065 .27597 .1772 .26958 .17334 .26158 Metetra
.739 .641 .751 r
.17334 .26158 .1772 .26958 .18371 .2635 .17982 .25586 Metetra
.735 .647 .762 r
.17982 .25586 .18371 .2635 .19018 .2578 .18625 .25054 Metetra
.731 .655 .774 r
.18625 .25054 .19018 .2578 .19661 .25249 .19264 .24561 Metetra
.726 .663 .788 r
.19264 .24561 .19661 .25249 .203 .24757 .199 .24108 Metetra
.72 .672 .802 r
.199 .24108 .203 .24757 .20935 .24305 .20532 .2369 Metetra
.714 .681 .817 r
.20532 .2369 .20935 .24305 .21567 .23888 .21161 .23306 Metetra
.707 .691 .832 r
.21161 .23306 .21567 .23888 .22197 .23504 .21789 .2295 Metetra
.701 .699 .845 r
.21789 .2295 .22197 .23504 .22824 .2315 .22415 .22619 Metetra
.695 .707 .857 r
.22415 .22619 .22824 .2315 .23451 .22819 .2304 .22308 Metetra
.689 .714 .868 r
.2304 .22308 .23451 .22819 .24076 .22509 .23665 .22014 Metetra
.684 .72 .877 r
.23665 .22014 .24076 .22509 .24701 .22216 .24289 .21734 Metetra
.679 .725 .884 r
.24289 .21734 .24701 .22216 .25326 .21936 .24914 .21464 Metetra
.675 .729 .89 r
.24914 .21464 .25326 .21936 .25951 .21666 .2554 .21202 Metetra
.672 .732 .895 r
.2554 .21202 .25951 .21666 .26577 .21405 .26166 .20945 Metetra
.67 .735 .899 r
.26166 .20945 .26577 .21405 .27204 .21149 .26793 .20693 Metetra
.668 .737 .901 r
.26793 .20693 .27204 .21149 .27832 .20897 .27422 .20444 Metetra
.667 .738 .903 r
.27422 .20444 .27832 .20897 .28461 .20648 .28052 .20197 Metetra
.666 .739 .905 r
.28052 .20197 .28461 .20648 .29092 .20402 .28683 .19951 Metetra
.665 .74 .906 r
.28683 .19951 .29092 .20402 .29723 .20156 .29315 .19706 Metetra
.665 .74 .906 r
.29315 .19706 .29723 .20156 .30357 .19911 .29949 .19461 Metetra
.664 .741 .907 r
.29949 .19461 .30357 .19911 .30991 .19667 .30585 .19216 Metetra
.664 .741 .907 r
.30585 .19216 .30991 .19667 .31627 .19422 .31222 .18971 Metetra
.664 .741 .907 r
.31222 .18971 .31627 .19422 .32265 .19178 .3186 .18726 Metetra
.664 .741 .908 r
.3186 .18726 .32265 .19178 .32904 .18933 .325 .1848 Metetra
.664 .741 .908 r
.325 .1848 .32904 .18933 .33544 .18687 .33141 .18233 Metetra
.664 .741 .908 r
.33141 .18233 .33544 .18687 .34187 .18442 .33785 .17987 Metetra
.664 .741 .908 r
.33785 .17987 .34187 .18442 .3483 .18195 .34429 .17739 Metetra
.664 .741 .908 r
.34429 .17739 .3483 .18195 .35475 .17949 .35075 .17491 Metetra
.664 .741 .908 r
.35075 .17491 .35475 .17949 .36122 .17701 .35723 .17243 Metetra
.664 .741 .908 r
.35723 .17243 .36122 .17701 .36771 .17453 .36373 .16994 Metetra
.664 .741 .908 r
.36373 .16994 .36771 .17453 .37421 .17205 .37023 .16744 Metetra
.664 .741 .908 r
.37023 .16744 .37421 .17205 .38072 .16956 .37676 .16494 Metetra
.664 .741 .908 r
.37676 .16494 .38072 .16956 .38725 .16706 .3833 .16243 Metetra
.663 .741 .908 r
.3833 .16243 .38725 .16706 .3938 .16456 .38986 .15992 Metetra
.663 .741 .908 r
.38986 .15992 .3938 .16456 .40036 .16205 .39643 .1574 Metetra
.663 .741 .908 r
.39643 .1574 .40036 .16205 .40694 .15954 .40302 .15487 Metetra
.663 .741 .908 r
.40302 .15487 .40694 .15954 .41354 .15702 .40963 .15234 Metetra
.663 .741 .908 r
.40963 .15234 .41354 .15702 .42015 .1545 .41625 .14981 Metetra
.663 .741 .908 r
.41625 .14981 .42015 .1545 .42678 .15198 .42288 .14727 Metetra
.662 .74 .908 r
.42288 .14727 .42678 .15198 .43342 .14947 .42954 .14474 Metetra
.662 .74 .908 r
.42954 .14474 .43342 .14947 .44008 .14696 .43621 .14221 Metetra
.661 .739 .908 r
.43621 .14221 .44008 .14696 .44675 .14446 .4429 .13968 Metetra
.66 .737 .907 r
.4429 .13968 .44675 .14446 .45345 .14199 .4496 .13717 Metetra
.658 .736 .907 r
.4496 .13717 .45345 .14199 .46015 .13954 .45632 .13468 Metetra
.656 .733 .907 r
.45632 .13468 .46015 .13954 .46688 .13714 .46305 .13222 Metetra
.652 .73 .906 r
.46305 .13222 .46688 .13714 .47362 .1348 .4698 .12981 Metetra
.648 .725 .905 r
.4698 .12981 .47362 .1348 .48038 .13254 .47657 .12746 Metetra
.643 .719 .904 r
.47657 .12746 .48038 .13254 .48715 .13037 .48336 .12518 Metetra
.636 .712 .902 r
.48336 .12518 .48715 .13037 .49394 .12832 .49016 .12301 Metetra
.628 .703 .9 r
.49016 .12301 .49394 .12832 .50075 .12642 .49698 .12095 Metetra
.618 .693 .897 r
.49698 .12095 .50075 .12642 .50758 .12468 .50382 .11905 Metetra
.607 .681 .894 r
.50382 .11905 .50758 .12468 .51443 .12315 .51067 .11731 Metetra
.595 .667 .889 r
.51067 .11731 .51443 .12315 .5213 .12182 .51755 .11577 Metetra
.581 .651 .884 r
.51755 .11577 .5213 .12182 .52819 .12074 .52445 .11444 Metetra
.566 .635 .878 r
.52445 .11444 .52819 .12074 .53511 .11989 .53138 .11335 Metetra
.552 .618 .872 r
.53138 .11335 .53511 .11989 .54206 .1193 .53833 .1125 Metetra
.537 .601 .865 r
.53833 .1125 .54206 .1193 .54904 .11895 .54531 .11189 Metetra
.523 .585 .858 r
.54531 .11189 .54904 .11895 .55605 .11882 .55232 .11152 Metetra
.511 .57 .852 r
.55232 .11152 .55605 .11882 .56309 .1189 .55936 .11137 Metetra
.5 .557 .845 r
.55936 .11137 .56309 .1189 .57016 .11913 .56643 .11142 Metetra
.492 .547 .84 r
.56643 .11142 .57016 .11913 .57727 .11947 .57354 .11162 Metetra
.487 .539 .836 r
.57354 .11162 .57727 .11947 .58441 .11987 .58068 .11192 Metetra
.485 .536 .834 r
.58068 .11192 .58441 .11987 .59158 .12026 .58786 .11227 Metetra
.486 .536 .834 r
.58786 .11227 .59158 .12026 .59879 .12056 .59506 .1126 Metetra
.491 .54 .835 r
.59506 .1126 .59879 .12056 .60602 .12072 .6023 .11285 Metetra
.499 .548 .838 r
.6023 .11285 .60602 .12072 .61328 .12066 .60957 .11295 Metetra
.511 .561 .843 r
.60957 .11295 .61328 .12066 .62057 .12032 .61686 .11283 Metetra
.526 .577 .849 r
.61686 .11283 .62057 .12032 .62787 .11965 .62418 .11244 Metetra
.544 .597 .857 r
.62418 .11244 .62787 .11965 .63519 .11859 .63152 .1117 Metetra
.565 .62 .866 r
.63152 .1117 .63519 .11859 .64252 .11711 .63886 .11059 Metetra
.588 .647 .876 r
.63886 .11059 .64252 .11711 .64985 .1152 .64622 .10907 Metetra
.612 .675 .886 r
.64622 .10907 .64985 .1152 .65719 .11284 .65359 .10711 Metetra
.638 .705 .895 r
.65359 .10711 .65719 .11284 .66453 .11003 .66096 .10472 Metetra
.663 .736 .904 r
.66096 .10472 .66453 .11003 .67186 .10681 .66833 .10189 Metetra
.688 .766 .911 r
.66833 .10189 .67186 .10681 .6792 .10318 .6757 .09864 Metetra
.711 .794 .916 r
.6757 .09864 .6792 .10318 .68652 .09919 .68306 .09501 Metetra
.731 .82 .92 r
.68306 .09501 .68652 .09919 .69385 .09488 .69042 .09101 Metetra
.749 .843 .922 r
.69042 .09101 .69385 .09488 .70116 .09029 .69777 .0867 Metetra
.763 .863 .923 r
.69777 .0867 .70116 .09029 .70848 .08548 .70512 .08211 Metetra
.775 .879 .922 r
.70512 .08211 .70848 .08548 .71579 .08049 .71247 .07731 Metetra
.288 0 0 r
.05155 .32864 .05661 .32892 .06191 .33062 .0569 .32999 Metetra
.142 0 0 r
.0569 .32999 .06191 .33062 .06728 .33199 .06235 .33089 Metetra
.08 .624 .844 r
.06235 .33089 .06728 .33199 .07274 .33291 .06791 .33121 Metetra
.333 .759 .974 r
.06791 .33121 .07274 .33291 .07831 .33324 .07359 .33082 Metetra
.53 .806 .997 r
.07359 .33082 .07831 .33324 .084 .33286 .0794 .32964 Metetra
.643 .792 .954 r
.0794 .32964 .084 .33286 .08982 .33167 .08535 .3276 Metetra
.7 .758 .897 r
.08535 .3276 .08982 .33167 .09578 .32963 .09143 .3247 Metetra
.728 .725 .848 r
.09143 .3247 .09578 .32963 .10187 .32671 .09764 .32093 Metetra
.742 .698 .81 r
.09764 .32093 .10187 .32671 .10808 .32293 .10396 .31636 Metetra
.749 .677 .781 r
.10396 .31636 .10808 .32293 .11441 .31834 .11039 .31108 Metetra
.752 .662 .761 r
.11039 .31108 .11441 .31834 .12083 .31304 .11689 .30522 Metetra
.754 .65 .747 r
.11689 .30522 .12083 .31304 .12733 .30716 .12345 .2989 Metetra
.753 .642 .737 r
.12345 .2989 .12733 .30716 .13389 .30083 .13005 .29229 Metetra
.752 .636 .732 r
.13005 .29229 .13389 .30083 .14048 .29421 .13666 .28554 Metetra
.751 .633 .73 r
.13666 .28554 .14048 .29421 .14708 .28745 .14327 .27878 Metetra
.748 .632 .731 r
.14327 .27878 .14708 .28745 .15368 .28069 .14986 .27215 Metetra
.746 .634 .735 r
.14986 .27215 .15368 .28069 .16027 .27406 .15642 .26575 Metetra
.743 .637 .742 r
.15642 .26575 .16027 .27406 .16682 .26767 .16295 .25966 Metetra
.739 .641 .751 r
.16295 .25966 .16682 .26767 .17334 .26158 .16943 .25393 Metetra
.735 .647 .762 r
.16943 .25393 .17334 .26158 .17982 .25586 .17587 .2486 Metetra
.731 .655 .774 r
.17587 .2486 .17982 .25586 .18625 .25054 .18226 .24366 Metetra
.726 .663 .788 r
.18226 .24366 .18625 .25054 .19264 .24561 .18862 .23911 Metetra
.72 .672 .802 r
.18862 .23911 .19264 .24561 .199 .24108 .19494 .23492 Metetra
.714 .681 .817 r
.19494 .23492 .199 .24108 .20532 .2369 .20124 .23107 Metetra
.708 .691 .832 r
.20124 .23107 .20532 .2369 .21161 .23306 .20751 .2275 Metetra
.701 .699 .845 r
.20751 .2275 .21161 .23306 .21789 .2295 .21377 .22418 Metetra
.695 .707 .857 r
.21377 .22418 .21789 .2295 .22415 .22619 .22002 .22107 Metetra
.689 .714 .868 r
.22002 .22107 .22415 .22619 .2304 .22308 .22626 .21813 Metetra
.684 .72 .877 r
.22626 .21813 .2304 .22308 .23665 .22014 .2325 .21532 Metetra
.679 .725 .885 r
.2325 .21532 .23665 .22014 .24289 .21734 .23875 .21261 Metetra
.675 .729 .89 r
.23875 .21261 .24289 .21734 .24914 .21464 .245 .20999 Metetra
.672 .732 .895 r
.245 .20999 .24914 .21464 .2554 .21202 .25125 .20742 Metetra
.67 .735 .899 r
.25125 .20742 .2554 .21202 .26166 .20945 .25752 .20489 Metetra
.668 .737 .901 r
.25752 .20489 .26166 .20945 .26793 .20693 .2638 .2024 Metetra
.667 .738 .903 r
.2638 .2024 .26793 .20693 .27422 .20444 .27009 .19992 Metetra
.666 .739 .905 r
.27009 .19992 .27422 .20444 .28052 .20197 .2764 .19746 Metetra
.665 .74 .906 r
.2764 .19746 .28052 .20197 .28683 .19951 .28272 .195 Metetra
.665 .74 .906 r
.28272 .195 .28683 .19951 .29315 .19706 .28905 .19255 Metetra
.664 .741 .907 r
.28905 .19255 .29315 .19706 .29949 .19461 .2954 .19009 Metetra
.664 .741 .907 r
.2954 .19009 .29949 .19461 .30585 .19216 .30176 .18764 Metetra
.664 .741 .907 r
.30176 .18764 .30585 .19216 .31222 .18971 .30814 .18518 Metetra
.664 .741 .908 r
.30814 .18518 .31222 .18971 .3186 .18726 .31453 .18272 Metetra
.664 .741 .908 r
.31453 .18272 .3186 .18726 .325 .1848 .32094 .18025 Metetra
.664 .741 .908 r
.32094 .18025 .325 .1848 .33141 .18233 .32737 .17777 Metetra
.664 .741 .908 r
.32737 .17777 .33141 .18233 .33785 .17987 .33381 .1753 Metetra
.664 .741 .908 r
.33381 .1753 .33785 .17987 .34429 .17739 .34026 .17281 Metetra
.664 .741 .908 r
.34026 .17281 .34429 .17739 .35075 .17491 .34674 .17032 Metetra
.664 .741 .908 r
.34674 .17032 .35075 .17491 .35723 .17243 .35322 .16783 Metetra
.664 .741 .908 r
.35322 .16783 .35723 .17243 .36373 .16994 .35973 .16532 Metetra
.664 .741 .908 r
.35973 .16532 .36373 .16994 .37023 .16744 .36625 .16281 Metetra
.664 .741 .908 r
.36625 .16281 .37023 .16744 .37676 .16494 .37278 .1603 Metetra
.664 .741 .908 r
.37278 .1603 .37676 .16494 .3833 .16243 .37933 .15778 Metetra
.664 .741 .908 r
.37933 .15778 .3833 .16243 .38986 .15992 .3859 .15525 Metetra
.663 .741 .908 r
.3859 .15525 .38986 .15992 .39643 .1574 .39248 .15272 Metetra
.663 .741 .908 r
.39248 .15272 .39643 .1574 .40302 .15487 .39908 .15019 Metetra
.663 .741 .908 r
.39908 .15019 .40302 .15487 .40963 .15234 .4057 .14764 Metetra
.663 .741 .908 r
.4057 .14764 .40963 .15234 .41625 .14981 .41233 .1451 Metetra
.663 .741 .908 r
.41233 .1451 .41625 .14981 .42288 .14727 .41898 .14255 Metetra
.663 .741 .908 r
.41898 .14255 .42288 .14727 .42954 .14474 .42564 .13999 Metetra
.662 .74 .908 r
.42564 .13999 .42954 .14474 .43621 .14221 .43232 .13744 Metetra
.662 .739 .908 r
.43232 .13744 .43621 .14221 .4429 .13968 .43902 .13489 Metetra
.661 .739 .907 r
.43902 .13489 .4429 .13968 .4496 .13717 .44573 .13235 Metetra
.66 .737 .907 r
.44573 .13235 .4496 .13717 .45632 .13468 .45246 .12983 Metetra
.658 .735 .907 r
.45246 .12983 .45632 .13468 .46305 .13222 .45921 .12732 Metetra
.655 .733 .906 r
.45921 .12732 .46305 .13222 .4698 .12981 .46597 .12485 Metetra
.652 .729 .906 r
.46597 .12485 .4698 .12981 .47657 .12746 .47275 .12243 Metetra
.648 .725 .905 r
.47275 .12243 .47657 .12746 .48336 .12518 .47955 .12007 Metetra
.642 .719 .904 r
.47955 .12007 .48336 .12518 .49016 .12301 .48636 .11778 Metetra
.635 .712 .902 r
.48636 .11778 .49016 .12301 .49698 .12095 .49319 .1156 Metetra
.627 .703 .9 r
.49319 .1156 .49698 .12095 .50382 .11905 .50004 .11354 Metetra
.618 .692 .897 r
.50004 .11354 .50382 .11905 .51067 .11731 .50691 .11163 Metetra
.606 .68 .893 r
.50691 .11163 .51067 .11731 .51755 .11577 .51379 .10989 Metetra
.594 .666 .889 r
.51379 .10989 .51755 .11577 .52445 .11444 .5207 .10834 Metetra
.58 .651 .884 r
.5207 .10834 .52445 .11444 .53138 .11335 .52763 .10701 Metetra
.566 .634 .878 r
.52763 .10701 .53138 .11335 .53833 .1125 .53459 .10591 Metetra
.551 .617 .872 r
.53459 .10591 .53833 .1125 .54531 .11189 .54157 .10505 Metetra
.537 .601 .865 r
.54157 .10505 .54531 .11189 .55232 .11152 .54858 .10443 Metetra
.523 .585 .858 r
.54858 .10443 .55232 .11152 .55936 .11137 .55562 .10404 Metetra
.511 .57 .852 r
.55562 .10404 .55936 .11137 .56643 .11142 .5627 .10387 Metetra
.501 .558 .846 r
.5627 .10387 .56643 .11142 .57354 .11162 .5698 .10389 Metetra
.493 .548 .841 r
.5698 .10389 .57354 .11162 .58068 .11192 .57694 .10405 Metetra
.488 .541 .837 r
.57694 .10405 .58068 .11192 .58786 .11227 .58412 .10431 Metetra
.486 .538 .835 r
.58412 .10431 .58786 .11227 .59506 .1126 .59133 .10461 Metetra
.488 .538 .834 r
.59133 .10461 .59506 .1126 .6023 .11285 .59857 .10489 Metetra
.493 .542 .836 r
.59857 .10489 .6023 .11285 .60957 .11295 .60584 .10509 Metetra
.501 .551 .839 r
.60584 .10509 .60957 .11295 .61686 .11283 .61314 .10513 Metetra
.513 .563 .844 r
.61314 .10513 .61686 .11283 .62418 .11244 .62047 .10495 Metetra
.528 .579 .85 r
.62047 .10495 .62418 .11244 .63152 .1117 .62782 .10449 Metetra
.546 .599 .858 r
.62782 .10449 .63152 .1117 .63886 .11059 .63519 .1037 Metetra
.566 .622 .867 r
.63519 .1037 .63886 .11059 .64622 .10907 .64257 .10254 Metetra
.589 .648 .877 r
.64257 .10254 .64622 .10907 .65359 .10711 .64996 .10097 Metetra
.613 .677 .886 r
.64996 .10097 .65359 .10711 .66096 .10472 .65736 .09897 Metetra
.638 .706 .896 r
.65736 .09897 .66096 .10472 .66833 .10189 .66476 .09654 Metetra
.663 .736 .904 r
.66476 .09654 .66833 .10189 .6757 .09864 .67216 .09369 Metetra
.688 .765 .911 r
.67216 .09369 .6757 .09864 .68306 .09501 .67956 .09042 Metetra
.71 .793 .916 r
.67956 .09042 .68306 .09501 .69042 .09101 .68695 .08677 Metetra
.73 .819 .92 r
.68695 .08677 .69042 .09101 .69777 .0867 .69434 .08277 Metetra
.748 .842 .922 r
.69434 .08277 .69777 .0867 .70512 .08211 .70173 .07846 Metetra
.762 .861 .923 r
.70173 .07846 .70512 .08211 .71247 .07731 .70911 .07388 Metetra
.134 0 0 r
.04651 .32799 .05155 .32864 .0569 .32999 .05195 .32886 Metetra
.086 .628 .849 r
.05195 .32886 .0569 .32999 .06235 .33089 .05749 .32916 Metetra
.336 .759 .975 r
.05749 .32916 .06235 .33089 .06791 .33121 .06316 .32877 Metetra
.53 .805 .996 r
.06316 .32877 .06791 .33121 .07359 .33082 .06896 .32759 Metetra
.642 .791 .954 r
.06896 .32759 .07359 .33082 .0794 .32964 .07489 .32556 Metetra
.699 .758 .898 r
.07489 .32556 .0794 .32964 .08535 .3276 .08097 .32267 Metetra
.727 .726 .849 r
.08097 .32267 .08535 .3276 .09143 .3247 .08717 .31892 Metetra
.742 .699 .81 r
.08717 .31892 .09143 .3247 .09764 .32093 .0935 .31437 Metetra
.749 .678 .782 r
.0935 .31437 .09764 .32093 .10396 .31636 .09992 .30912 Metetra
.752 .662 .761 r
.09992 .30912 .10396 .31636 .11039 .31108 .10643 .30327 Metetra
.753 .65 .747 r
.10643 .30327 .11039 .31108 .11689 .30522 .11299 .29697 Metetra
.753 .642 .738 r
.11299 .29697 .11689 .30522 .12345 .2989 .11959 .29038 Metetra
.752 .636 .732 r
.11959 .29038 .12345 .2989 .13005 .29229 .12621 .28363 Metetra
.751 .633 .73 r
.12621 .28363 .13005 .29229 .13666 .28554 .13283 .27688 Metetra
.748 .633 .732 r
.13283 .27688 .13666 .28554 .14327 .27878 .13943 .27024 Metetra
.746 .634 .736 r
.13943 .27024 .14327 .27878 .14986 .27215 .146 .26384 Metetra
.743 .637 .742 r
.146 .26384 .14986 .27215 .15642 .26575 .15254 .25774 Metetra
.739 .641 .751 r
.15254 .25774 .15642 .26575 .16295 .25966 .15902 .252 Metetra
.735 .647 .761 r
.15902 .252 .16295 .25966 .16943 .25393 .16547 .24665 Metetra
.731 .655 .774 r
.16547 .24665 .16943 .25393 .17587 .2486 .17187 .2417 Metetra
.726 .663 .788 r
.17187 .2417 .17587 .2486 .18226 .24366 .17823 .23714 Metetra
.72 .672 .802 r
.17823 .23714 .18226 .24366 .18862 .23911 .18455 .23294 Metetra
.714 .681 .817 r
.18455 .23294 .18862 .23911 .19494 .23492 .19085 .22908 Metetra
.708 .691 .831 r
.19085 .22908 .19494 .23492 .20124 .23107 .19712 .2255 Metetra
.701 .699 .845 r
.19712 .2255 .20124 .23107 .20751 .2275 .20337 .22217 Metetra
.695 .707 .857 r
.20337 .22217 .20751 .2275 .21377 .22418 .20962 .21906 Metetra
.689 .714 .868 r
.20962 .21906 .21377 .22418 .22002 .22107 .21585 .21611 Metetra
.684 .72 .877 r
.21585 .21611 .22002 .22107 .22626 .21813 .22209 .21329 Metetra
.679 .725 .885 r
.22209 .21329 .22626 .21813 .2325 .21532 .22833 .21058 Metetra
.675 .729 .891 r
.22833 .21058 .2325 .21532 .23875 .21261 .23457 .20795 Metetra
.672 .732 .895 r
.23457 .20795 .23875 .21261 .245 .20999 .24083 .20538 Metetra
.67 .735 .899 r
.24083 .20538 .245 .20999 .25125 .20742 .24709 .20285 Metetra
.668 .737 .901 r
.24709 .20285 .25125 .20742 .25752 .20489 .25336 .20035 Metetra
.667 .738 .903 r
.25336 .20035 .25752 .20489 .2638 .2024 .25965 .19787 Metetra
.666 .739 .905 r
.25965 .19787 .2638 .2024 .27009 .19992 .26595 .1954 Metetra
.665 .74 .906 r
.26595 .1954 .27009 .19992 .2764 .19746 .27226 .19294 Metetra
.665 .74 .906 r
.27226 .19294 .2764 .19746 .28272 .195 .27859 .19048 Metetra
.664 .741 .907 r
.27859 .19048 .28272 .195 .28905 .19255 .28493 .18802 Metetra
.664 .741 .907 r
.28493 .18802 .28905 .19255 .2954 .19009 .29129 .18556 Metetra
.664 .741 .907 r
.29129 .18556 .2954 .19009 .30176 .18764 .29766 .1831 Metetra
.664 .741 .908 r
.29766 .1831 .30176 .18764 .30814 .18518 .30405 .18063 Metetra
.664 .741 .908 r
.30405 .18063 .30814 .18518 .31453 .18272 .31045 .17816 Metetra
.664 .741 .908 r
.31045 .17816 .31453 .18272 .32094 .18025 .31687 .17568 Metetra
.664 .741 .908 r
.31687 .17568 .32094 .18025 .32737 .17777 .3233 .17319 Metetra
.664 .741 .908 r
.3233 .17319 .32737 .17777 .33381 .1753 .32975 .17071 Metetra
.664 .741 .908 r
.32975 .17071 .33381 .1753 .34026 .17281 .33622 .16821 Metetra
.664 .741 .908 r
.33622 .16821 .34026 .17281 .34674 .17032 .3427 .16571 Metetra
.664 .741 .908 r
.3427 .16571 .34674 .17032 .35322 .16783 .3492 .1632 Metetra
.664 .741 .908 r
.3492 .1632 .35322 .16783 .35973 .16532 .35571 .16069 Metetra
.664 .741 .908 r
.35571 .16069 .35973 .16532 .36625 .16281 .36224 .15817 Metetra
.664 .741 .908 r
.36224 .15817 .36625 .16281 .37278 .1603 .36878 .15564 Metetra
.664 .741 .908 r
.36878 .15564 .37278 .1603 .37933 .15778 .37534 .15311 Metetra
.664 .741 .908 r
.37534 .15311 .37933 .15778 .3859 .15525 .38192 .15057 Metetra
.664 .741 .908 r
.38192 .15057 .3859 .15525 .39248 .15272 .38851 .14803 Metetra
.663 .741 .908 r
.38851 .14803 .39248 .15272 .39908 .15019 .39512 .14548 Metetra
.663 .741 .908 r
.39512 .14548 .39908 .15019 .4057 .14764 .40175 .14292 Metetra
.663 .741 .908 r
.40175 .14292 .4057 .14764 .41233 .1451 .40839 .14036 Metetra
.663 .741 .908 r
.40839 .14036 .41233 .1451 .41898 .14255 .41505 .1378 Metetra
.663 .741 .908 r
.41505 .1378 .41898 .14255 .42564 .13999 .42172 .13523 Metetra
.663 .74 .908 r
.42172 .13523 .42564 .13999 .43232 .13744 .42842 .13266 Metetra
.662 .74 .908 r
.42842 .13266 .43232 .13744 .43902 .13489 .43512 .13009 Metetra
.662 .739 .908 r
.43512 .13009 .43902 .13489 .44573 .13235 .44185 .12753 Metetra
.661 .738 .907 r
.44185 .12753 .44573 .13235 .45246 .12983 .44859 .12497 Metetra
.659 .737 .907 r
.44859 .12497 .45246 .12983 .45921 .12732 .45535 .12243 Metetra
.657 .735 .907 r
.45535 .12243 .45921 .12732 .46597 .12485 .46212 .11991 Metetra
.655 .732 .906 r
.46212 .11991 .46597 .12485 .47275 .12243 .46891 .11743 Metetra
.651 .729 .906 r
.46891 .11743 .47275 .12243 .47955 .12007 .47572 .11499 Metetra
.647 .724 .905 r
.47572 .11499 .47955 .12007 .48636 .11778 .48254 .11262 Metetra
.642 .718 .903 r
.48254 .11262 .48636 .11778 .49319 .1156 .48938 .11033 Metetra
.635 .711 .902 r
.48938 .11033 .49319 .1156 .50004 .11354 .49624 .10814 Metetra
.626 .702 .9 r
.49624 .10814 .50004 .11354 .50691 .11163 .50312 .10607 Metetra
.617 .691 .897 r
.50312 .10607 .50691 .11163 .51379 .10989 .51002 .10416 Metetra
.605 .679 .893 r
.51002 .10416 .51379 .10989 .5207 .10834 .51693 .10241 Metetra
.593 .665 .889 r
.51693 .10241 .5207 .10834 .52763 .10701 .52387 .10086 Metetra
.579 .65 .884 r
.52387 .10086 .52763 .10701 .53459 .10591 .53084 .09952 Metetra
.565 .634 .878 r
.53084 .09952 .53459 .10591 .54157 .10505 .53782 .09842 Metetra
.551 .617 .872 r
.53782 .09842 .54157 .10505 .54858 .10443 .54484 .09755 Metetra
.537 .6 .865 r
.54484 .09755 .54858 .10443 .55562 .10404 .55188 .09691 Metetra
.523 .585 .858 r
.55188 .09691 .55562 .10404 .5627 .10387 .55895 .09651 Metetra
.511 .571 .852 r
.55895 .09651 .5627 .10387 .5698 .10389 .56606 .09631 Metetra
.502 .559 .846 r
.56606 .09631 .5698 .10389 .57694 .10405 .5732 .0963 Metetra
.494 .549 .841 r
.5732 .0963 .57694 .10405 .58412 .10431 .58037 .09642 Metetra
.489 .543 .838 r
.58037 .09642 .58412 .10431 .59133 .10461 .58758 .09664 Metetra
.488 .54 .836 r
.58758 .09664 .59133 .10461 .59857 .10489 .59483 .09689 Metetra
.49 .54 .835 r
.59483 .09689 .59857 .10489 .60584 .10509 .6021 .09712 Metetra
.495 .545 .837 r
.6021 .09712 .60584 .10509 .61314 .10513 .60941 .09726 Metetra
.503 .553 .84 r
.60941 .09726 .61314 .10513 .62047 .10495 .61674 .09724 Metetra
.515 .566 .845 r
.61674 .09724 .62047 .10495 .62782 .10449 .6241 .097 Metetra
.53 .582 .851 r
.6241 .097 .62782 .10449 .63519 .1037 .63149 .09648 Metetra
.548 .602 .859 r
.63149 .09648 .63519 .1037 .64257 .10254 .63889 .09564 Metetra
.568 .625 .868 r
.63889 .09564 .64257 .10254 .64996 .10097 .6463 .09442 Metetra
.591 .65 .877 r
.6463 .09442 .64996 .10097 .65736 .09897 .65372 .09281 Metetra
.615 .678 .887 r
.65372 .09281 .65736 .09897 .66476 .09654 .66115 .09077 Metetra
.639 .707 .896 r
.66115 .09077 .66476 .09654 .67216 .09369 .66859 .08831 Metetra
.664 .737 .904 r
.66859 .08831 .67216 .09369 .67956 .09042 .67602 .08543 Metetra
.687 .765 .911 r
.67602 .08543 .67956 .09042 .68695 .08677 .68345 .08215 Metetra
.71 .793 .916 r
.68345 .08215 .68695 .08677 .69434 .08277 .69088 .07848 Metetra
.729 .818 .92 r
.69088 .07848 .69434 .08277 .70173 .07846 .6983 .07447 Metetra
.746 .84 .922 r
.6983 .07447 .70173 .07846 .70911 .07388 .70571 .07016 Metetra
.093 .632 .854 r
.04152 .32683 .04651 .32799 .05195 .32886 .04705 .32711 Metetra
.339 .76 .976 r
.04705 .32711 .05195 .32886 .05749 .32916 .0527 .32671 Metetra
.53 .805 .996 r
.0527 .32671 .05749 .32916 .06316 .32877 .05849 .32553 Metetra
.641 .791 .954 r
.05849 .32553 .06316 .32877 .06896 .32759 .06442 .32351 Metetra
.698 .758 .898 r
.06442 .32351 .06896 .32759 .07489 .32556 .07049 .32063 Metetra
.727 .726 .849 r
.07049 .32063 .07489 .32556 .08097 .32267 .07669 .3169 Metetra
.741 .699 .811 r
.07669 .3169 .08097 .32267 .08717 .31892 .08301 .31237 Metetra
.748 .678 .783 r
.08301 .31237 .08717 .31892 .0935 .31437 .08943 .30714 Metetra
.752 .662 .762 r
.08943 .30714 .0935 .31437 .09992 .30912 .09594 .30131 Metetra
.753 .651 .748 r
.09594 .30131 .09992 .30912 .10643 .30327 .10251 .29503 Metetra
.753 .642 .738 r
.10251 .29503 .10643 .30327 .11299 .29697 .10912 .28845 Metetra
.752 .637 .733 r
.10912 .28845 .11299 .29697 .11959 .29038 .11575 .28171 Metetra
.751 .634 .731 r
.11575 .28171 .11959 .29038 .12621 .28363 .12238 .27497 Metetra
.749 .633 .732 r
.12238 .27497 .12621 .28363 .13283 .27688 .12898 .26833 Metetra
.746 .634 .736 r
.12898 .26833 .13283 .27688 .13943 .27024 .13556 .26192 Metetra
.743 .637 .742 r
.13556 .26192 .13943 .27024 .146 .26384 .1421 .25582 Metetra
.74 .641 .751 r
.1421 .25582 .146 .26384 .15254 .25774 .1486 .25007 Metetra
.736 .647 .761 r
.1486 .25007 .15254 .25774 .15902 .252 .15504 .24471 Metetra
.731 .655 .774 r
.15504 .24471 .15902 .252 .16547 .24665 .16145 .23974 Metetra
.726 .663 .788 r
.16145 .23974 .16547 .24665 .17187 .2417 .16781 .23517 Metetra
.72 .672 .802 r
.16781 .23517 .17187 .2417 .17823 .23714 .17413 .23096 Metetra
.714 .681 .817 r
.17413 .23096 .17823 .23714 .18455 .23294 .18043 .22709 Metetra
.708 .691 .831 r
.18043 .22709 .18455 .23294 .19085 .22908 .1867 .2235 Metetra
.701 .699 .845 r
.1867 .2235 .19085 .22908 .19712 .2255 .19295 .22017 Metetra
.695 .707 .857 r
.19295 .22017 .19712 .2255 .20337 .22217 .19919 .21704 Metetra
.689 .714 .868 r
.19919 .21704 .20337 .22217 .20962 .21906 .20543 .21408 Metetra
.684 .72 .877 r
.20543 .21408 .20962 .21906 .21585 .21611 .21166 .21126 Metetra
.679 .725 .885 r
.21166 .21126 .21585 .21611 .22209 .21329 .21789 .20855 Metetra
.675 .729 .891 r
.21789 .20855 .22209 .21329 .22833 .21058 .22413 .20591 Metetra
.672 .732 .895 r
.22413 .20591 .22833 .21058 .23457 .20795 .23038 .20334 Metetra
.67 .735 .899 r
.23038 .20334 .23457 .20795 .24083 .20538 .23663 .2008 Metetra
.668 .737 .901 r
.23663 .2008 .24083 .20538 .24709 .20285 .2429 .1983 Metetra
.667 .738 .903 r
.2429 .1983 .24709 .20285 .25336 .20035 .24918 .19581 Metetra
.666 .739 .905 r
.24918 .19581 .25336 .20035 .25965 .19787 .25547 .19334 Metetra
.665 .74 .906 r
.25547 .19334 .25965 .19787 .26595 .1954 .26178 .19087 Metetra
.664 .74 .906 r
.26178 .19087 .26595 .1954 .27226 .19294 .2681 .18841 Metetra
.664 .741 .907 r
.2681 .18841 .27226 .19294 .27859 .19048 .27444 .18595 Metetra
.664 .741 .907 r
.27444 .18595 .27859 .19048 .28493 .18802 .28079 .18348 Metetra
.664 .741 .907 r
.28079 .18348 .28493 .18802 .29129 .18556 .28716 .18101 Metetra
.664 .741 .908 r
.28716 .18101 .29129 .18556 .29766 .1831 .29354 .17854 Metetra
.664 .741 .908 r
.29354 .17854 .29766 .1831 .30405 .18063 .29993 .17606 Metetra
.664 .741 .908 r
.29993 .17606 .30405 .18063 .31045 .17816 .30635 .17358 Metetra
.664 .741 .908 r
.30635 .17358 .31045 .17816 .31687 .17568 .31278 .17109 Metetra
.664 .741 .908 r
.31278 .17109 .31687 .17568 .3233 .17319 .31922 .16859 Metetra
.664 .741 .908 r
.31922 .16859 .3233 .17319 .32975 .17071 .32568 .16609 Metetra
.664 .741 .908 r
.32568 .16609 .32975 .17071 .33622 .16821 .33215 .16359 Metetra
.664 .741 .908 r
.33215 .16359 .33622 .16821 .3427 .16571 .33864 .16108 Metetra
.664 .741 .908 r
.33864 .16108 .3427 .16571 .3492 .1632 .34515 .15856 Metetra
.664 .741 .908 r
.34515 .15856 .3492 .1632 .35571 .16069 .35167 .15603 Metetra
.664 .741 .908 r
.35167 .15603 .35571 .16069 .36224 .15817 .35821 .1535 Metetra
.664 .741 .908 r
.35821 .1535 .36224 .15817 .36878 .15564 .36477 .15096 Metetra
.664 .741 .908 r
.36477 .15096 .36878 .15564 .37534 .15311 .37134 .14842 Metetra
.664 .741 .908 r
.37134 .14842 .37534 .15311 .38192 .15057 .37793 .14587 Metetra
.664 .741 .908 r
.37793 .14587 .38192 .15057 .38851 .14803 .38453 .14332 Metetra
.664 .741 .908 r
.38453 .14332 .38851 .14803 .39512 .14548 .39115 .14075 Metetra
.663 .741 .908 r
.39115 .14075 .39512 .14548 .40175 .14292 .39778 .13819 Metetra
.663 .741 .908 r
.39778 .13819 .40175 .14292 .40839 .14036 .40444 .13561 Metetra
.663 .741 .908 r
.40444 .13561 .40839 .14036 .41505 .1378 .41111 .13304 Metetra
.663 .741 .908 r
.41111 .13304 .41505 .1378 .42172 .13523 .41779 .13045 Metetra
.663 .741 .908 r
.41779 .13045 .42172 .13523 .42842 .13266 .42449 .12787 Metetra
.663 .74 .908 r
.42449 .12787 .42842 .13266 .43512 .13009 .43121 .12528 Metetra
.662 .74 .908 r
.43121 .12528 .43512 .13009 .44185 .12753 .43795 .12269 Metetra
.662 .739 .908 r
.43795 .12269 .44185 .12753 .44859 .12497 .4447 .12011 Metetra
.661 .738 .907 r
.4447 .12011 .44859 .12497 .45535 .12243 .45147 .11754 Metetra
.659 .737 .907 r
.45147 .11754 .45535 .12243 .46212 .11991 .45825 .11498 Metetra
.657 .735 .907 r
.45825 .11498 .46212 .11991 .46891 .11743 .46505 .11245 Metetra
.655 .732 .906 r
.46505 .11245 .46891 .11743 .47572 .11499 .47187 .10995 Metetra
.651 .728 .906 r
.47187 .10995 .47572 .11499 .48254 .11262 .47871 .10751 Metetra
.647 .724 .905 r
.47871 .10751 .48254 .11262 .48938 .11033 .48556 .10512 Metetra
.641 .718 .903 r
.48556 .10512 .48938 .11033 .49624 .10814 .49243 .10282 Metetra
.634 .71 .902 r
.49243 .10282 .49624 .10814 .50312 .10607 .49932 .10062 Metetra
.626 .701 .899 r
.49932 .10062 .50312 .10607 .51002 .10416 .50622 .09855 Metetra
.616 .69 .896 r
.50622 .09855 .51002 .10416 .51693 .10241 .51315 .09663 Metetra
.605 .678 .893 r
.51315 .09663 .51693 .10241 .52387 .10086 .5201 .09488 Metetra
.592 .664 .889 r
.5201 .09488 .52387 .10086 .53084 .09952 .52707 .09333 Metetra
.579 .649 .883 r
.52707 .09333 .53084 .09952 .53782 .09842 .53406 .09199 Metetra
.565 .633 .878 r
.53406 .09199 .53782 .09842 .54484 .09755 .54108 .09087 Metetra
.55 .616 .871 r
.54108 .09087 .54484 .09755 .55188 .09691 .54813 .08999 Metetra
.536 .6 .865 r
.54813 .08999 .55188 .09691 .55895 .09651 .5552 .08934 Metetra
.523 .585 .858 r
.5552 .08934 .55895 .09651 .56606 .09631 .56231 .08892 Metetra
.512 .571 .852 r
.56231 .08892 .56606 .09631 .5732 .0963 .56945 .08869 Metetra
.502 .559 .847 r
.56945 .08869 .5732 .0963 .58037 .09642 .57662 .08865 Metetra
.495 .55 .842 r
.57662 .08865 .58037 .09642 .58758 .09664 .58383 .08874 Metetra
.491 .544 .839 r
.58383 .08874 .58758 .09664 .59483 .09689 .59107 .08891 Metetra
.49 .541 .837 r
.59107 .08891 .59483 .09689 .6021 .09712 .59835 .08911 Metetra
.492 .542 .836 r
.59835 .08911 .6021 .09712 .60941 .09726 .60566 .08929 Metetra
.497 .547 .838 r
.60566 .08929 .60941 .09726 .61674 .09724 .613 .08937 Metetra
.505 .556 .841 r
.613 .08937 .61674 .09724 .6241 .097 .62037 .08929 Metetra
.517 .568 .846 r
.62037 .08929 .6241 .097 .63149 .09648 .62776 .08899 Metetra
.532 .584 .853 r
.62776 .08899 .63149 .09648 .63889 .09564 .63518 .08842 Metetra
.55 .604 .86 r
.63518 .08842 .63889 .09564 .6463 .09442 .64261 .08752 Metetra
.57 .627 .869 r
.64261 .08752 .6463 .09442 .65372 .09281 .65006 .08625 Metetra
.592 .652 .878 r
.65006 .08625 .65372 .09281 .66115 .09077 .65752 .08459 Metetra
.616 .679 .887 r
.65752 .08459 .66115 .09077 .66859 .08831 .66498 .08251 Metetra
.64 .708 .896 r
.66498 .08251 .66859 .08831 .67602 .08543 .67244 .08002 Metetra
.664 .737 .904 r
.67244 .08002 .67602 .08543 .68345 .08215 .67991 .07711 Metetra
.687 .765 .911 r
.67991 .07711 .68345 .08215 .69088 .07848 .68737 .07381 Metetra
.709 .792 .916 r
.68737 .07381 .69088 .07848 .6983 .07447 .69483 .07013 Metetra
.728 .817 .92 r
.69483 .07013 .6983 .07447 .70571 .07016 .70228 .06611 Metetra
.342 .761 .977 r
.03659 .32505 .04152 .32683 .04705 .32711 .04223 .32464 Metetra
.53 .804 .996 r
.04223 .32464 .04705 .32711 .0527 .32671 .04801 .32346 Metetra
.64 .79 .954 r
.04801 .32346 .0527 .32671 .05849 .32553 .05393 .32144 Metetra
.697 .758 .899 r
.05393 .32144 .05849 .32553 .06442 .32351 .05999 .31858 Metetra
.726 .726 .85 r
.05999 .31858 .06442 .32351 .07049 .32063 .06619 .31487 Metetra
.741 .699 .812 r
.06619 .31487 .07049 .32063 .07669 .3169 .07251 .31036 Metetra
.748 .679 .784 r
.07251 .31036 .07669 .3169 .08301 .31237 .07893 .30515 Metetra
.752 .663 .763 r
.07893 .30515 .08301 .31237 .08943 .30714 .08544 .29935 Metetra
.753 .651 .748 r
.08544 .29935 .08943 .30714 .09594 .30131 .09201 .29309 Metetra
.753 .643 .739 r
.09201 .29309 .09594 .30131 .10251 .29503 .09863 .28652 Metetra
.752 .637 .733 r
.09863 .28652 .10251 .29503 .10912 .28845 .10526 .2798 Metetra
.751 .634 .731 r
.10526 .2798 .10912 .28845 .11575 .28171 .1119 .27305 Metetra
.749 .633 .732 r
.1119 .27305 .11575 .28171 .12238 .27497 .11851 .26642 Metetra
.746 .634 .736 r
.11851 .26642 .12238 .27497 .12898 .26833 .1251 .26001 Metetra
.743 .637 .742 r
.1251 .26001 .12898 .26833 .13556 .26192 .13164 .25389 Metetra
.74 .641 .751 r
.13164 .25389 .13556 .26192 .1421 .25582 .13815 .24813 Metetra
.736 .647 .761 r
.13815 .24813 .1421 .25582 .1486 .25007 .1446 .24276 Metetra
.731 .655 .774 r
.1446 .24276 .1486 .25007 .15504 .24471 .15101 .23779 Metetra
.726 .663 .787 r
.15101 .23779 .15504 .24471 .16145 .23974 .15737 .2332 Metetra
.721 .672 .802 r
.15737 .2332 .16145 .23974 .16781 .23517 .1637 .22898 Metetra
.714 .681 .817 r
.1637 .22898 .16781 .23517 .17413 .23096 .16999 .22509 Metetra
.708 .691 .831 r
.16999 .22509 .17413 .23096 .18043 .22709 .17626 .2215 Metetra
.702 .699 .845 r
.17626 .2215 .18043 .22709 .1867 .2235 .18251 .21815 Metetra
.695 .707 .857 r
.18251 .21815 .1867 .2235 .19295 .22017 .18875 .21502 Metetra
.689 .714 .868 r
.18875 .21502 .19295 .22017 .19919 .21704 .19498 .21206 Metetra
.684 .72 .877 r
.19498 .21206 .19919 .21704 .20543 .21408 .20121 .20923 Metetra
.679 .725 .885 r
.20121 .20923 .20543 .21408 .21166 .21126 .20743 .20651 Metetra
.675 .729 .891 r
.20743 .20651 .21166 .21126 .21789 .20855 .21367 .20387 Metetra
.672 .732 .895 r
.21367 .20387 .21789 .20855 .22413 .20591 .21991 .20129 Metetra
.67 .735 .899 r
.21991 .20129 .22413 .20591 .23038 .20334 .22616 .19875 Metetra
.668 .737 .901 r
.22616 .19875 .23038 .20334 .23663 .2008 .23242 .19624 Metetra
.667 .738 .903 r
.23242 .19624 .23663 .2008 .2429 .1983 .23869 .19375 Metetra
.666 .739 .905 r
.23869 .19375 .2429 .1983 .24918 .19581 .24498 .19127 Metetra
.665 .74 .906 r
.24498 .19127 .24918 .19581 .25547 .19334 .25128 .1888 Metetra
.664 .74 .906 r
.25128 .1888 .25547 .19334 .26178 .19087 .2576 .18633 Metetra
.664 .741 .907 r
.2576 .18633 .26178 .19087 .2681 .18841 .26393 .18387 Metetra
.664 .741 .907 r
.26393 .18387 .2681 .18841 .27444 .18595 .27027 .1814 Metetra
.664 .741 .907 r
.27027 .1814 .27444 .18595 .28079 .18348 .27663 .17892 Metetra
.664 .741 .908 r
.27663 .17892 .28079 .18348 .28716 .18101 .28301 .17644 Metetra
.664 .741 .908 r
.28301 .17644 .28716 .18101 .29354 .17854 .2894 .17396 Metetra
.664 .741 .908 r
.2894 .17396 .29354 .17854 .29993 .17606 .2958 .17147 Metetra
.664 .741 .908 r
.2958 .17147 .29993 .17606 .30635 .17358 .30223 .16898 Metetra
.664 .741 .908 r
.30223 .16898 .30635 .17358 .31278 .17109 .30866 .16648 Metetra
.664 .741 .908 r
.30866 .16648 .31278 .17109 .31922 .16859 .31512 .16397 Metetra
.664 .741 .908 r
.31512 .16397 .31922 .16859 .32568 .16609 .32159 .16146 Metetra
.664 .741 .908 r
.32159 .16146 .32568 .16609 .33215 .16359 .32807 .15894 Metetra
.664 .741 .908 r
.32807 .15894 .33215 .16359 .33864 .16108 .33457 .15642 Metetra
.664 .741 .908 r
.33457 .15642 .33864 .16108 .34515 .15856 .34109 .15389 Metetra
.664 .741 .908 r
.34109 .15389 .34515 .15856 .35167 .15603 .34762 .15135 Metetra
.664 .741 .908 r
.34762 .15135 .35167 .15603 .35821 .1535 .35417 .14881 Metetra
.664 .741 .908 r
.35417 .14881 .35821 .1535 .36477 .15096 .36073 .14626 Metetra
.664 .741 .908 r
.36073 .14626 .36477 .15096 .37134 .14842 .36731 .14371 Metetra
.664 .741 .908 r
.36731 .14371 .37134 .14842 .37793 .14587 .37391 .14115 Metetra
.664 .741 .908 r
.37391 .14115 .37793 .14587 .38453 .14332 .38052 .13858 Metetra
.664 .741 .908 r
.38052 .13858 .38453 .14332 .39115 .14075 .38715 .13601 Metetra
.664 .741 .908 r
.38715 .13601 .39115 .14075 .39778 .13819 .3938 .13343 Metetra
.663 .741 .908 r
.3938 .13343 .39778 .13819 .40444 .13561 .40046 .13084 Metetra
.663 .741 .908 r
.40046 .13084 .40444 .13561 .41111 .13304 .40714 .12825 Metetra
.663 .741 .908 r
.40714 .12825 .41111 .13304 .41779 .13045 .41384 .12565 Metetra
.663 .741 .908 r
.41384 .12565 .41779 .13045 .42449 .12787 .42055 .12305 Metetra
.663 .741 .908 r
.42055 .12305 .42449 .12787 .43121 .12528 .42728 .12045 Metetra
.663 .74 .908 r
.42728 .12045 .43121 .12528 .43795 .12269 .43403 .11784 Metetra
.662 .74 .908 r
.43403 .11784 .43795 .12269 .4447 .12011 .44079 .11524 Metetra
.661 .739 .908 r
.44079 .11524 .4447 .12011 .45147 .11754 .44757 .11264 Metetra
.66 .738 .907 r
.44757 .11264 .45147 .11754 .45825 .11498 .45436 .11005 Metetra
.659 .737 .907 r
.45436 .11005 .45825 .11498 .46505 .11245 .46118 .10748 Metetra
.657 .734 .907 r
.46118 .10748 .46505 .11245 .47187 .10995 .46801 .10494 Metetra
.654 .732 .906 r
.46801 .10494 .47187 .10995 .47871 .10751 .47485 .10243 Metetra
.651 .728 .906 r
.47485 .10243 .47871 .10751 .48556 .10512 .48172 .09997 Metetra
.646 .723 .905 r
.48172 .09997 .48556 .10512 .49243 .10282 .4886 .09757 Metetra
.64 .717 .903 r
.4886 .09757 .49243 .10282 .49932 .10062 .4955 .09526 Metetra
.633 .709 .901 r
.4955 .09526 .49932 .10062 .50622 .09855 .50241 .09306 Metetra
.625 .7 .899 r
.50241 .09306 .50622 .09855 .51315 .09663 .50935 .09098 Metetra
.615 .689 .896 r
.50935 .09098 .51315 .09663 .5201 .09488 .51631 .08905 Metetra
.604 .677 .893 r
.51631 .08905 .5201 .09488 .52707 .09333 .52328 .0873 Metetra
.591 .663 .888 r
.52328 .0873 .52707 .09333 .53406 .09199 .53029 .08574 Metetra
.578 .648 .883 r
.53029 .08574 .53406 .09199 .54108 .09087 .53731 .08439 Metetra
.564 .632 .877 r
.53731 .08439 .54108 .09087 .54813 .08999 .54436 .08327 Metetra
.55 .616 .871 r
.54436 .08327 .54813 .08999 .5552 .08934 .55144 .08238 Metetra
.536 .6 .865 r
.55144 .08238 .5552 .08934 .56231 .08892 .55855 .08171 Metetra
.524 .585 .858 r
.55855 .08171 .56231 .08892 .56945 .08869 .56569 .08127 Metetra
.512 .572 .852 r
.56569 .08127 .56945 .08869 .57662 .08865 .57286 .08102 Metetra
.503 .56 .847 r
.57286 .08102 .57662 .08865 .58383 .08874 .58007 .08094 Metetra
.496 .551 .842 r
.58007 .08094 .58383 .08874 .59107 .08891 .58731 .08099 Metetra
.492 .546 .839 r
.58731 .08099 .59107 .08891 .59835 .08911 .59459 .08112 Metetra
.491 .543 .838 r
.59459 .08112 .59835 .08911 .60566 .08929 .6019 .08128 Metetra
.493 .545 .837 r
.6019 .08128 .60566 .08929 .613 .08937 .60924 .0814 Metetra
.499 .549 .839 r
.60924 .0814 .613 .08937 .62037 .08929 .61662 .08142 Metetra
.508 .558 .842 r
.61662 .08142 .62037 .08929 .62776 .08899 .62402 .08128 Metetra
.519 .571 .847 r
.62402 .08128 .62776 .08899 .63518 .08842 .63145 .08093 Metetra
.534 .587 .854 r
.63145 .08093 .63518 .08842 .64261 .08752 .6389 .08029 Metetra
.552 .606 .861 r
.6389 .08029 .64261 .08752 .65006 .08625 .64636 .07933 Metetra
.572 .629 .87 r
.64636 .07933 .65006 .08625 .65752 .08459 .65384 .07802 Metetra
.594 .654 .879 r
.65384 .07802 .65752 .08459 .66498 .08251 .66133 .07631 Metetra
.617 .681 .888 r
.66133 .07631 .66498 .08251 .67244 .08002 .66883 .07419 Metetra
.641 .709 .896 r
.66883 .07419 .67244 .08002 .67991 .07711 .67633 .07167 Metetra
.664 .737 .904 r
.67633 .07167 .67991 .07711 .68737 .07381 .68382 .06873 Metetra
.687 .765 .911 r
.68382 .06873 .68737 .07381 .69483 .07013 .69132 .06541 Metetra
.708 .792 .916 r
.69132 .06541 .69483 .07013 .70228 .06611 .69881 .06172 Metetra
.53 .803 .996 r
.03175 .32256 .03659 .32505 .04223 .32464 .03751 .32137 Metetra
.639 .79 .954 r
.03751 .32137 .04223 .32464 .04801 .32346 .04342 .31937 Metetra
.696 .758 .9 r
.04342 .31937 .04801 .32346 .05393 .32144 .04948 .31652 Metetra
.725 .726 .851 r
.04948 .31652 .05393 .32144 .05999 .31858 .05567 .31282 Metetra
.74 .7 .813 r
.05567 .31282 .05999 .31858 .06619 .31487 .06198 .30834 Metetra
.748 .679 .784 r
.06198 .30834 .06619 .31487 .07251 .31036 .0684 .30315 Metetra
.751 .663 .764 r
.0684 .30315 .07251 .31036 .07893 .30515 .07491 .29737 Metetra
.753 .651 .749 r
.07491 .29737 .07893 .30515 .08544 .29935 .08149 .29114 Metetra
.753 .643 .739 r
.08149 .29114 .08544 .29935 .09201 .29309 .08811 .28459 Metetra
.752 .637 .734 r
.08811 .28459 .09201 .29309 .09863 .28652 .09475 .27787 Metetra
.751 .634 .731 r
.09475 .27787 .09863 .28652 .10526 .2798 .1014 .27114 Metetra
.749 .633 .732 r
.1014 .27114 .10526 .2798 .1119 .27305 .10802 .26451 Metetra
.746 .634 .736 r
.10802 .26451 .1119 .27305 .11851 .26642 .11461 .25809 Metetra
.743 .637 .742 r
.11461 .25809 .11851 .26642 .1251 .26001 .12117 .25197 Metetra
.74 .642 .751 r
.12117 .25197 .1251 .26001 .13164 .25389 .12767 .2462 Metetra
.736 .648 .761 r
.12767 .2462 .13164 .25389 .13815 .24813 .13413 .24082 Metetra
.731 .655 .774 r
.13413 .24082 .13815 .24813 .1446 .24276 .14054 .23583 Metetra
.726 .663 .787 r
.14054 .23583 .1446 .24276 .15101 .23779 .14691 .23123 Metetra
.721 .672 .802 r
.14691 .23123 .15101 .23779 .15737 .2332 .15324 .227 Metetra
.715 .681 .817 r
.15324 .227 .15737 .2332 .1637 .22898 .15953 .2231 Metetra
.708 .691 .831 r
.15953 .2231 .1637 .22898 .16999 .22509 .1658 .21949 Metetra
.702 .699 .845 r
.1658 .21949 .16999 .22509 .17626 .2215 .17205 .21614 Metetra
.695 .707 .857 r
.17205 .21614 .17626 .2215 .18251 .21815 .17828 .213 Metetra
.689 .714 .868 r
.17828 .213 .18251 .21815 .18875 .21502 .18451 .21003 Metetra
.684 .72 .877 r
.18451 .21003 .18875 .21502 .19498 .21206 .19073 .2072 Metetra
.679 .725 .885 r
.19073 .2072 .19498 .21206 .20121 .20923 .19696 .20447 Metetra
.675 .729 .891 r
.19696 .20447 .20121 .20923 .20743 .20651 .20318 .20182 Metetra
.672 .732 .895 r
.20318 .20182 .20743 .20651 .21367 .20387 .20942 .19924 Metetra
.67 .735 .899 r
.20942 .19924 .21367 .20387 .21991 .20129 .21566 .19669 Metetra
.668 .737 .902 r
.21566 .19669 .21991 .20129 .22616 .19875 .22192 .19418 Metetra
.667 .738 .903 r
.22192 .19418 .22616 .19875 .23242 .19624 .22819 .19169 Metetra
.666 .739 .905 r
.22819 .19169 .23242 .19624 .23869 .19375 .23447 .1892 Metetra
.665 .74 .906 r
.23447 .1892 .23869 .19375 .24498 .19127 .24076 .18673 Metetra
.664 .74 .907 r
.24076 .18673 .24498 .19127 .25128 .1888 .24707 .18425 Metetra
.664 .741 .907 r
.24707 .18425 .25128 .1888 .2576 .18633 .25339 .18178 Metetra
.664 .741 .907 r
.25339 .18178 .2576 .18633 .26393 .18387 .25973 .17931 Metetra
.664 .741 .908 r
.25973 .17931 .26393 .18387 .27027 .1814 .26609 .17683 Metetra
.664 .741 .908 r
.26609 .17683 .27027 .1814 .27663 .17892 .27246 .17434 Metetra
.664 .741 .908 r
.27246 .17434 .27663 .17892 .28301 .17644 .27884 .17186 Metetra
.664 .741 .908 r
.27884 .17186 .28301 .17644 .2894 .17396 .28524 .16936 Metetra
.664 .741 .908 r
.28524 .16936 .2894 .17396 .2958 .17147 .29166 .16686 Metetra
.664 .741 .908 r
.29166 .16686 .2958 .17147 .30223 .16898 .29809 .16436 Metetra
.664 .741 .908 r
.29809 .16436 .30223 .16898 .30866 .16648 .30453 .16185 Metetra
.664 .741 .908 r
.30453 .16185 .30866 .16648 .31512 .16397 .311 .15933 Metetra
.664 .741 .908 r
.311 .15933 .31512 .16397 .32159 .16146 .31747 .15681 Metetra
.664 .741 .908 r
.31747 .15681 .32159 .16146 .32807 .15894 .32397 .15428 Metetra
.664 .741 .908 r
.32397 .15428 .32807 .15894 .33457 .15642 .33048 .15175 Metetra
.664 .741 .908 r
.33048 .15175 .33457 .15642 .34109 .15389 .33701 .1492 Metetra
.664 .741 .908 r
.33701 .1492 .34109 .15389 .34762 .15135 .34355 .14666 Metetra
.664 .741 .908 r
.34355 .14666 .34762 .15135 .35417 .14881 .35011 .1441 Metetra
.664 .741 .908 r
.35011 .1441 .35417 .14881 .36073 .14626 .35668 .14154 Metetra
.664 .741 .908 r
.35668 .14154 .36073 .14626 .36731 .14371 .36327 .13898 Metetra
.664 .741 .908 r
.36327 .13898 .36731 .14371 .37391 .14115 .36988 .1364 Metetra
.664 .741 .908 r
.36988 .1364 .37391 .14115 .38052 .13858 .3765 .13382 Metetra
.664 .741 .908 r
.3765 .13382 .38052 .13858 .38715 .13601 .38314 .13124 Metetra
.664 .741 .908 r
.38314 .13124 .38715 .13601 .3938 .13343 .3898 .12865 Metetra
.664 .741 .908 r
.3898 .12865 .3938 .13343 .40046 .13084 .39647 .12605 Metetra
.663 .741 .908 r
.39647 .12605 .40046 .13084 .40714 .12825 .40316 .12344 Metetra
.663 .741 .908 r
.40316 .12344 .40714 .12825 .41384 .12565 .40987 .12083 Metetra
.663 .741 .908 r
.40987 .12083 .41384 .12565 .42055 .12305 .41659 .11822 Metetra
.663 .741 .908 r
.41659 .11822 .42055 .12305 .42728 .12045 .42333 .1156 Metetra
.663 .741 .908 r
.42333 .1156 .42728 .12045 .43403 .11784 .43009 .11298 Metetra
.663 .74 .908 r
.43009 .11298 .43403 .11784 .44079 .11524 .43686 .11036 Metetra
.662 .74 .908 r
.43686 .11036 .44079 .11524 .44757 .11264 .44365 .10774 Metetra
.661 .739 .908 r
.44365 .10774 .44757 .11264 .45436 .11005 .45046 .10512 Metetra
.66 .738 .907 r
.45046 .10512 .45436 .11005 .46118 .10748 .45728 .10252 Metetra
.659 .736 .907 r
.45728 .10252 .46118 .10748 .46801 .10494 .46412 .09993 Metetra
.657 .734 .907 r
.46412 .09993 .46801 .10494 .47485 .10243 .47098 .09737 Metetra
.654 .731 .906 r
.47098 .09737 .47485 .10243 .48172 .09997 .47786 .09485 Metetra
.65 .727 .905 r
.47786 .09485 .48172 .09997 .4886 .09757 .48475 .09237 Metetra
.645 .722 .904 r
.48475 .09237 .4886 .09757 .4955 .09526 .49166 .08997 Metetra
.64 .716 .903 r
.49166 .08997 .4955 .09526 .50241 .09306 .49859 .08765 Metetra
.633 .709 .901 r
.49859 .08765 .50241 .09306 .50935 .09098 .50553 .08544 Metetra
.624 .699 .899 r
.50553 .08544 .50935 .09098 .51631 .08905 .5125 .08336 Metetra
.614 .688 .896 r
.5125 .08336 .51631 .08905 .52328 .0873 .51949 .08142 Metetra
.603 .676 .892 r
.51949 .08142 .52328 .0873 .53029 .08574 .52649 .07966 Metetra
.591 .662 .888 r
.52649 .07966 .53029 .08574 .53731 .08439 .53353 .0781 Metetra
.577 .647 .883 r
.53353 .0781 .53731 .08439 .54436 .08327 .54058 .07674 Metetra
.563 .632 .877 r
.54058 .07674 .54436 .08327 .55144 .08238 .54767 .07561 Metetra
.55 .616 .871 r
.54767 .07561 .55144 .08238 .55855 .08171 .55478 .07471 Metetra
.536 .6 .865 r
.55478 .07471 .55855 .08171 .56569 .08127 .56192 .07403 Metetra
.524 .585 .858 r
.56192 .07403 .56569 .08127 .57286 .08102 .56909 .07356 Metetra
.513 .572 .853 r
.56909 .07356 .57286 .08102 .58007 .08094 .5763 .07329 Metetra
.504 .561 .847 r
.5763 .07329 .58007 .08094 .58731 .08099 .58354 .07318 Metetra
.498 .553 .843 r
.58354 .07318 .58731 .08099 .59459 .08112 .59082 .07319 Metetra
.494 .547 .84 r
.59082 .07319 .59459 .08112 .6019 .08128 .59813 .07327 Metetra
.493 .545 .838 r
.59813 .07327 .6019 .08128 .60924 .0814 .60548 .07338 Metetra
.495 .547 .838 r
.60548 .07338 .60924 .0814 .61662 .08142 .61285 .07344 Metetra
.501 .552 .84 r
.61285 .07344 .61662 .08142 .62402 .08128 .62026 .07341 Metetra
.51 .561 .843 r
.62026 .07341 .62402 .08128 .63145 .08093 .6277 .07321 Metetra
.522 .573 .848 r
.6277 .07321 .63145 .08093 .6389 .08029 .63516 .0728 Metetra
.536 .589 .855 r
.63516 .0728 .6389 .08029 .64636 .07933 .64265 .0721 Metetra
.554 .609 .862 r
.64265 .0721 .64636 .07933 .65384 .07802 .65015 .07109 Metetra
.574 .631 .871 r
.65015 .07109 .65384 .07802 .66133 .07631 .65766 .06972 Metetra
.595 .656 .879 r
.65766 .06972 .66133 .07631 .66883 .07419 .66518 .06797 Metetra
.618 .682 .888 r
.66518 .06797 .66883 .07419 .67633 .07167 .67271 .06581 Metetra
.641 .71 .897 r
.67271 .06581 .67633 .07167 .68382 .06873 .68024 .06325 Metetra
.665 .738 .904 r
.68024 .06325 .68382 .06873 .69132 .06541 .68777 .06029 Metetra
.687 .765 .911 r
.68777 .06029 .69132 .06541 .69881 .06172 .6953 .05695 Metetra
.638 .789 .954 r
.027 .31928 .03175 .32256 .03751 .32137 .0329 .31728 Metetra
.695 .758 .9 r
.0329 .31728 .03751 .32137 .04342 .31937 .03894 .31444 Metetra
.724 .726 .852 r
.03894 .31444 .04342 .31937 .04948 .31652 .04513 .31077 Metetra
.739 .7 .814 r
.04513 .31077 .04948 .31652 .05567 .31282 .05144 .30631 Metetra
.747 .679 .785 r
.05144 .30631 .05567 .31282 .06198 .30834 .05786 .30115 Metetra
.751 .664 .764 r
.05786 .30115 .06198 .30834 .0684 .30315 .06437 .29539 Metetra
.753 .652 .75 r
.06437 .29539 .0684 .30315 .07491 .29737 .07095 .28918 Metetra
.753 .643 .74 r
.07095 .28918 .07491 .29737 .08149 .29114 .07758 .28265 Metetra
.752 .638 .734 r
.07758 .28265 .08149 .29114 .08811 .28459 .08422 .27595 Metetra
.751 .635 .732 r
.08422 .27595 .08811 .28459 .09475 .27787 .09087 .26922 Metetra
.749 .634 .733 r
.09087 .26922 .09475 .27787 .1014 .27114 .09751 .26259 Metetra
.746 .635 .736 r
.09751 .26259 .1014 .27114 .10802 .26451 .10411 .25617 Metetra
.743 .637 .742 r
.10411 .25617 .10802 .26451 .11461 .25809 .11067 .25005 Metetra
.74 .642 .751 r
.11067 .25005 .11461 .25809 .12117 .25197 .11718 .24427 Metetra
.736 .648 .761 r
.11718 .24427 .12117 .25197 .12767 .2462 .12364 .23887 Metetra
.732 .655 .773 r
.12364 .23887 .12767 .2462 .13413 .24082 .13006 .23387 Metetra
.726 .663 .787 r
.13006 .23387 .13413 .24082 .14054 .23583 .13643 .22926 Metetra
.721 .672 .802 r
.13643 .22926 .14054 .23583 .14691 .23123 .14276 .22502 Metetra
.715 .681 .816 r
.14276 .22502 .14691 .23123 .15324 .227 .14905 .22111 Metetra
.708 .691 .831 r
.14905 .22111 .15324 .227 .15953 .2231 .15532 .21749 Metetra
.702 .699 .845 r
.15532 .21749 .15953 .2231 .1658 .21949 .16157 .21413 Metetra
.695 .707 .857 r
.16157 .21413 .1658 .21949 .17205 .21614 .1678 .21098 Metetra
.689 .714 .868 r
.1678 .21098 .17205 .21614 .17828 .213 .17402 .208 Metetra
.684 .72 .877 r
.17402 .208 .17828 .213 .18451 .21003 .18024 .20516 Metetra
.679 .725 .885 r
.18024 .20516 .18451 .21003 .19073 .2072 .18645 .20243 Metetra
.675 .729 .891 r
.18645 .20243 .19073 .2072 .19696 .20447 .19268 .19977 Metetra
.672 .733 .895 r
.19268 .19977 .19696 .20447 .20318 .20182 .19891 .19718 Metetra
.67 .735 .899 r
.19891 .19718 .20318 .20182 .20942 .19924 .20515 .19463 Metetra
.668 .737 .902 r
.20515 .19463 .20942 .19924 .21566 .19669 .21139 .19212 Metetra
.667 .738 .903 r
.21139 .19212 .21566 .19669 .22192 .19418 .21766 .18962 Metetra
.666 .739 .905 r
.21766 .18962 .22192 .19418 .22819 .19169 .22393 .18713 Metetra
.665 .74 .906 r
.22393 .18713 .22819 .19169 .23447 .1892 .23022 .18465 Metetra
.664 .74 .907 r
.23022 .18465 .23447 .1892 .24076 .18673 .23652 .18217 Metetra
.664 .741 .907 r
.23652 .18217 .24076 .18673 .24707 .18425 .24284 .17969 Metetra
.664 .741 .907 r
.24284 .17969 .24707 .18425 .25339 .18178 .24917 .17721 Metetra
.664 .741 .908 r
.24917 .17721 .25339 .18178 .25973 .17931 .25552 .17473 Metetra
.664 .741 .908 r
.25552 .17473 .25973 .17931 .26609 .17683 .26188 .17224 Metetra
.664 .741 .908 r
.26188 .17224 .26609 .17683 .27246 .17434 .26826 .16975 Metetra
.664 .741 .908 r
.26826 .16975 .27246 .17434 .27884 .17186 .27465 .16725 Metetra
.664 .741 .908 r
.27465 .16725 .27884 .17186 .28524 .16936 .28106 .16475 Metetra
.664 .741 .908 r
.28106 .16475 .28524 .16936 .29166 .16686 .28749 .16224 Metetra
.664 .741 .908 r
.28749 .16224 .29166 .16686 .29809 .16436 .29393 .15972 Metetra
.664 .741 .908 r
.29393 .15972 .29809 .16436 .30453 .16185 .30038 .1572 Metetra
.664 .741 .908 r
.30038 .1572 .30453 .16185 .311 .15933 .30686 .15467 Metetra
.664 .741 .908 r
.30686 .15467 .311 .15933 .31747 .15681 .31334 .15214 Metetra
.664 .741 .908 r
.31334 .15214 .31747 .15681 .32397 .15428 .31985 .1496 Metetra
.664 .741 .908 r
.31985 .1496 .32397 .15428 .33048 .15175 .32637 .14705 Metetra
.664 .741 .908 r
.32637 .14705 .33048 .15175 .33701 .1492 .3329 .1445 Metetra
.664 .741 .908 r
.3329 .1445 .33701 .1492 .34355 .14666 .33946 .14194 Metetra
.664 .741 .908 r
.33946 .14194 .34355 .14666 .35011 .1441 .34603 .13937 Metetra
.664 .741 .908 r
.34603 .13937 .35011 .1441 .35668 .14154 .35261 .1368 Metetra
.664 .741 .908 r
.35261 .1368 .35668 .14154 .36327 .13898 .35921 .13422 Metetra
.664 .741 .908 r
.35921 .13422 .36327 .13898 .36988 .1364 .36583 .13164 Metetra
.664 .741 .908 r
.36583 .13164 .36988 .1364 .3765 .13382 .37246 .12904 Metetra
.664 .741 .908 r
.37246 .12904 .3765 .13382 .38314 .13124 .37911 .12645 Metetra
.664 .741 .908 r
.37911 .12645 .38314 .13124 .3898 .12865 .38578 .12384 Metetra
.664 .741 .908 r
.38578 .12384 .3898 .12865 .39647 .12605 .39246 .12123 Metetra
.663 .741 .908 r
.39246 .12123 .39647 .12605 .40316 .12344 .39916 .11862 Metetra
.663 .741 .908 r
.39916 .11862 .40316 .12344 .40987 .12083 .40588 .11599 Metetra
.663 .741 .908 r
.40588 .11599 .40987 .12083 .41659 .11822 .41261 .11337 Metetra
.663 .741 .908 r
.41261 .11337 .41659 .11822 .42333 .1156 .41936 .11073 Metetra
.663 .741 .908 r
.41936 .11073 .42333 .1156 .43009 .11298 .42613 .1081 Metetra
.663 .741 .908 r
.42613 .1081 .43009 .11298 .43686 .11036 .43292 .10546 Metetra
.663 .74 .908 r
.43292 .10546 .43686 .11036 .44365 .10774 .43972 .10282 Metetra
.662 .74 .908 r
.43972 .10282 .44365 .10774 .45046 .10512 .44653 .10018 Metetra
.661 .739 .908 r
.44653 .10018 .45046 .10512 .45728 .10252 .45337 .09755 Metetra
.66 .738 .907 r
.45337 .09755 .45728 .10252 .46412 .09993 .46022 .09492 Metetra
.658 .736 .907 r
.46022 .09492 .46412 .09993 .47098 .09737 .46709 .09232 Metetra
.656 .734 .907 r
.46709 .09232 .47098 .09737 .47786 .09485 .47398 .08975 Metetra
.653 .731 .906 r
.47398 .08975 .47786 .09485 .48475 .09237 .48088 .08721 Metetra
.65 .727 .905 r
.48088 .08721 .48475 .09237 .49166 .08997 .4878 .08473 Metetra
.645 .722 .904 r
.4878 .08473 .49166 .08997 .49859 .08765 .49474 .08231 Metetra
.639 .716 .903 r
.49474 .08231 .49859 .08765 .50553 .08544 .5017 .07998 Metetra
.632 .708 .901 r
.5017 .07998 .50553 .08544 .5125 .08336 .50868 .07777 Metetra
.623 .698 .899 r
.50868 .07777 .5125 .08336 .51949 .08142 .51567 .07568 Metetra
.613 .688 .896 r
.51567 .07568 .51949 .08142 .52649 .07966 .52269 .07374 Metetra
.602 .675 .892 r
.52269 .07374 .52649 .07966 .53353 .0781 .52973 .07197 Metetra
.59 .661 .888 r
.52973 .07197 .53353 .0781 .54058 .07674 .53679 .0704 Metetra
.577 .647 .883 r
.53679 .0704 .54058 .07674 .54767 .07561 .54388 .06904 Metetra
.563 .631 .877 r
.54388 .06904 .54767 .07561 .55478 .07471 .551 .0679 Metetra
.549 .615 .871 r
.551 .0679 .55478 .07471 .56192 .07403 .55814 .06698 Metetra
.536 .6 .865 r
.55814 .06698 .56192 .07403 .56909 .07356 .56532 .06629 Metetra
.524 .586 .859 r
.56532 .06629 .56909 .07356 .5763 .07329 .57252 .0658 Metetra
.513 .573 .853 r
.57252 .0658 .5763 .07329 .58354 .07318 .57976 .0655 Metetra
.505 .562 .848 r
.57976 .0655 .58354 .07318 .59082 .07319 .58704 .06535 Metetra
.499 .554 .844 r
.58704 .06535 .59082 .07319 .59813 .07327 .59435 .06532 Metetra
.495 .549 .841 r
.59435 .06532 .59813 .07327 .60548 .07338 .6017 .06536 Metetra
.495 .547 .839 r
.6017 .06536 .60548 .07338 .61285 .07344 .60908 .06542 Metetra
.497 .549 .839 r
.60908 .06542 .61285 .07344 .62026 .07341 .61649 .06543 Metetra
.503 .554 .841 r
.61649 .06543 .62026 .07341 .6277 .07321 .62394 .06534 Metetra
.512 .563 .844 r
.62394 .06534 .6277 .07321 .63516 .0728 .63141 .06508 Metetra
.524 .576 .849 r
.63141 .06508 .63516 .0728 .64265 .0721 .6389 .0646 Metetra
.538 .592 .856 r
.6389 .0646 .64265 .0721 .65015 .07109 .64642 .06385 Metetra
.556 .611 .863 r
.64642 .06385 .65015 .07109 .65766 .06972 .65395 .06279 Metetra
.575 .633 .871 r
.65395 .06279 .65766 .06972 .66518 .06797 .6615 .06137 Metetra
.597 .657 .88 r
.6615 .06137 .66518 .06797 .67271 .06581 .66906 .05957 Metetra
.619 .684 .889 r
.66906 .05957 .67271 .06581 .68024 .06325 .67662 .05737 Metetra
.642 .711 .897 r
.67662 .05737 .68024 .06325 .68777 .06029 .68418 .05478 Metetra
.665 .738 .905 r
.68418 .05478 .68777 .06029 .6953 .05695 .69174 .05179 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[61]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00^`3oool3o`000680oooo002l0?ooo`03o`00003oool0oooo0640oooo002l0?ooo`03o`00
003oool0oooo0640oooo002l0?ooo`03o`00003oool0oooo0640oooo002l0?ooo`03o`00003oool0
oooo0640oooo002k0?ooo`;o0000H`3oool00;`0oooo00?o00000?ooo`3oool0H@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00<00oooo00<00000o`00003o
ool0G@3oool00;d0oooo0`0000000`3ooooo00000?ooo`1M0?ooo`00^`3oool2000000@0oooo00?o
00000000003oool0G03oool00;P0oooo0`0000060?ooo`030000003oool0000005`0oooo002e0?oo
o`80000000?o00000?ooo`3oool01`3oool00`000000oooo0000001L0?ooo`00/`3oool2000000<0
oooo00?o00000?ooo`3oool01P3oool010000000oooo0?ooo`00001K0?ooo`00/03oool3000000h0
oooo00D000000?ooo`3oool0oooo0000001J0?ooo`00PP3oool2o`0000@0oooo00?o00000?ooo`3o
ool00P3oool3o`0001h0oooo00?o00000000003oool0403oool01@000000oooo0?ooool000000000
05X0oooo00210?ooo`04o`00003oool0ooooo`0000L0oooo00Go00000?ooo`3oool0ooooo`00000J
0?ooo`<0000000?o00000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00`0oooo0_l000040?ooo`03o`00003oool0oooo00<0oooo0_l000040?ooo`?o0000=P3oool0
0840oooo00Co00000?ooo`3ooooo00002`3oool00ol00000oooo0?ooo`0F0?ooo`8000005P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00Co00000?ooo`3ooooo0000203o
ool01?l00000oooo0?ooool000040?ooo`03o`00003oool0oooo03D0oooo00210?ooo`04o`00003o
ool0ooooo`0000/0oooo00?o00000?ooo`3oool04`3oool3000001P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`Go00000P3oool01?l00000oooo0?ooool000080?ooo`05
o`00003oool0ooooo`00003oool01Ol0000f0?ooo`00P@3oool01?l00000oooo0?ooool000070?oo
o`Co0000503oool00`00003o00000?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool01?l00000oooo0?ooool000080?ooo`06o`00003oool0ooooo`00003ooooo0000
0P3oool00ol00000oooo0?ooo`0e0?ooo`00P@3oool01?l00000oooo0?ooool000070?ooo`03o`00
003oool0oooo0180oooo0`0000000`3ooooo00000?ooo`0K0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool01?l00000oooo0?ooool000080?ooo`04o`00003oool0ooooo`00
0080oooo00?o00000?ooool00000=`3oool00880oooo0_l000080?ooo`Go00003@3oool300000240
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`04o`00003oool0ooooo`00
00P0oooo00Co00000?ooo`3ooooo00000`3oool2o`0003L0oooo002L0?ooo`800000803oool4o`00
00030000003oool0oooo00<0oooo0_l000000`000000oooo0?ooo`080?ooo`;o00002P3oool2o`00
00D0oooo00?o00000?ooo`3oool0=@3oool009T0oooo0P000002o`0001l0oooo0_l000001@2T]^Go
00000:Zliol00000000000L0oooo00<000000?ooo`3oool0D`3oool009L0oooo0P00000N0?ooo`Go
000000<0WZoSo`000?l000000_l000000`2_`nT00000o`0000070?ooo`030000003oool0oooo0580
oooo002D0?ooo`<000001`3ooolIo`00000308jLg?l00000Tj;N00?o000000<0Y;GUo`00002Z_>L0
0_l000000`00003o0000o`0000070?ooo`030000003oool0oooo0540oooo002B0?ooo`03o`000000
0000oooo00<0oooo1_l000000`2<WMko000008VIg@02o`00000E08>Bf_l00000PHoIo`00001oSMSo
000007j<eol00000OXcFo`00001oS=Ko0000082=eol00000Pi3Ho`000026TmWo000008VGfol00000
SYcL00?o000000<0WZkSo`00002T]ND00_l00000102_`nWo00000000002jdN/2o`0000H0oooo00<0
00000?ooo`3oool0D@3oool008l0oooo0`0000000ol00000oooo0?ooo`03o`00000509NYhol00000
TjGRo`00002@XN006ol000000`2BXMko0000o`000003o`0000070:Vliol0003o00000;G:jP00003o
00000;kGk002o`0000H0oooo00<000000?ooo`3oool0D03oool008d0oooo0P0000020?ooo`Co0000
00<0W;3Uo`00002J[>@01Ol000001@2<WMko000008VIgOl00000QYGK00;o000001<0PHoHo`00001o
SMOo000007j<eol00000OX_Fo`00001nS=Ko0000082=eol00000PXoGo`000025T]Wo000008VFf_l0
0000SI_L00?o000000<0WJkSo`00002T]ND00_l000001`2_`nWo0000o`0000000000^]7[o`000033
g>`00_l000050?ooo`03o`0000000000oooo0500oooo002:0?ooo`<0000000L0ooooo`000?l0003o
00000:6ei_l00000Wk;V00Go000000<0TjGRo`00002@XN006ol000000`2BXMko0000o`000003o`00
000:0:Vliol0003o00000;G;j_l000000000o`00002oenco00000<KQk0;o00001@3oool00`000000
oooo0?ooo`1?0?ooo`00Q`3oool2000000;o000000D0ooooo`000?l0003o00000:>gi`04o`000003
09f`iOl00000VZgT00Go000000L0S9gNo`000029VMgo000008JEfol00000Pi;J00;o00000140OXgG
o`00001mRmKo000007f;e_l00000OX_Fo`00001oS=Ko000008:>eol00000Q9;Ho`000028U][o0000
08fKg003o`00000309f]hol00000XkGU00;o000000H0[l?Yo`00002ebn[o00000000002oen`3o`00
00030<STjol0003o000000D0oooo00<000000?ooo`3oool0CP3oool008D0oooo0P0000000`3ooooo
0000o`000002o`0000070:Jjiol0003o0000o`00002R]NKo000009nbiP04o`00000409NYhol0003o
0000092Qh1_o000000@0TJ3No`000?l00000WJgS0_l000000`2Y_>Oo00000:o3j@02o`0000050;[A
j`00003o0000o`000036hN`00ol000000`3<jN_o00000?ooo`040?ooo`030000003oool0oooo04d0
oooo00220?ooo`<0000000H0ooooo`000?l00000Yk_Xo`00002W^nL2o`0000030:Fhiol00000XkOW
00?o000000<0WK3Uo`00002J[N@01Ol000002@2<WMko000008VIgOl00000QIGKo`000023T][o0000
082?f002o`00000A07f;e_l00000OH[Fo`00001mR]Ko000007n<e_l00000PHkGo`000024TMSo0000
08REf_l00000S9[Lo`00002AX=h00ol000000`2S]>Go0000o`000002o`00000:0;G;j_l0003o0000
00000?l00000`mg/o`000039iN_o00000<cYj`?o0000103oool00`000000oooo0?ooo`1=0?ooo`00
H@3oool2o`0001d0oooo00<00000o`00003oool00ol000000`2X_>So0000o`000002o`0000030:Jj
iol0003o000000?o000000<0Wk?Vo`000?l000000_l00000102GZN?o0000o`00002@X^0No`000006
09f]hol0003o00000:Vliol00000/<?Y0_l00000102kdN_o000000000033gN`6o`0000040<g/jol0
003o0000o`0000<0oooo00<000000?ooo`3oool0C03oool00600oooo00Co00000?ooo`3ooooo0000
6@3oool30000000:0?ooool0003o00000:Vmj?l00000Z;cXo`00002X^nSo00000:Nki`;o000000<0
YKWWo`00002S]nL00ol000000`2M/>Go000009Z]i005o`00000908fMgol00000RIWMo`000025UM_o
000008:Bf_l00000P8oH00;o00000140OH_Fo`00001lR]Ko000007f:eOl00000OX_Fo`000020SMOo
000008>@f?l00000QiCIo`00002<V]_o0000096OgP03o`0000030:>diOl0003o000000;o000000D0
]/_Zo`000?l00000_mS/00000004o`0000050<cZjol0003o0000o`00003<k>/00_l000040?ooo`03
0000003oool0oooo04/0oooo001P0?ooo`04o`00003oool0ooooo`0001L0oooo0P0000001@3ooooo
0000o`000?l00000ZKgX00Co000000D0Z;cXo`000?l0003o00000:Jji`05o`0000030:2ci_l0003o
000000;o000000D0Uj[So`00002DY^;o0000092Rh00Lo`00000709JUh?l0003o0000o`00002Y_>Oo
00000;34j@02o`0000040;_Bjol0003o0000000000;o000000D0bnS[o`000?l0003o00000<g/jP06
o`0000030?ooool00000000004d0oooo001P0?ooo`04o`00003oool0ooooo`0001@0oooo00Co0000
000000000000oooo0ol000001P2Y_NSo0000o`00002Y_NSo00000:Rlj0?o000000H0Yk_Wo`000?l0
0000YKWWo`00002T]nL3o`00000309f`iOl00000VZgT00Oo000000T0RIWMo`000025UM_o000008:A
f_l00000P8kHo`00001nS=L00_l000003`1lRMGo000007b9eOl00000OX[Fo`000020SMKo000008>@
f?l00000QiCIo`00002;VM_o0000092Og@03o`0000030:>diOl00000ZKcW00;o000000H0]/_Zo`00
0?l00000`=S/o`0000000003o`0000050<g[j_l0003o0000o`00003=k>/00_l000001039jNco0000
o`000?l000020?ooo`030000003oool0oooo04X0oooo001P0?ooo`04o`00003oool0ooooo`000140
oooo0`000004o`0000050:Vmj?l0003o0000o`00002Y_NP01?l000001@2X_>So0000o`000?l00000
Y[[W00Co000000<0X[KVo`00002P/nH00ol000000`2HZ^?o000009BVhP0No`00000309JUh?l0003o
000000?o000000@0/<CYo`000?l00000^m;[0_l000001034g^`00000o`00003<jN/3o`0000030<g]
j_l0003o000000Co000000D0a^G]o`000?l00000oooo0000001<0?ooo`00H03oool01?l00000oooo
0?ooool0000?0?ooo`8000000P3oool01?l00000ZKgXo`00002Y_NP2o`0000070:Vmj?l00000ZKgX
o`00002Y_NSo00000:Rlj002o`0000070:Rlj?l00000Yk_Wo`00002U^NOo00000:Bgi`04o`000003
09jaiOl0003o000000?o000000<0T:;Po`00002=W]l00_l000002@25UM_o000008:Af_l00000OhkH
o`00001mS=Oo000007b9eP02o`00000=07b9eOl00000OH[Eo`00001oS=Ko000008:?eol00000QY?I
o`00002;V=_o0000092Ng@03o`0000030:>diOl00000ZKcW00;o000000@0]/_Zo`000?l00000`=W/
0_l000001000003o0000o`00003=jnX7o`0000050<SWkOl0003o00000<CRk_l000000P3oool00`00
0000oooo0?ooo`190?ooo`00H@3oool2o`0000d0oooo0`000004o`0000050:Vmj?l0003o0000o`00
002Y_NP01?l000001@2Y_NSo0000o`000?l00000Z;cX00Co000000D0Y[[Wo`000?l0003o00000::f
iP05o`00000309RZhol00000U:KR01ko000000<0UZGOo`00002L[>800ol00000102`a>Wo0000o`00
002kd^/2o`0000040<CNk?l0000000000<cYj`?o000000@0c^gZo`000?l00000bn_[0ol000000`36
iNgo0000o`000003o`0000030?ooo`000000oooo04T0oooo001^0?ooo`0300000?l00000oooo00;o
000000<0ZKgXo`00002Y_NP00ol000001P2Y_NSo0000o`00002Y_NSo00000:Vmj0;o000000D0ZKgX
o`000?l0003o00000:Rlj005o`0000060:Bhiol0003o00000:2ci_l00000W[7U1Ol000001@2AX^7o
000008fNgol00000RIWM00;o000000T0PY7Io`00001oS]So000007f;eol00000O8WFo`00001kR=D0
0_l000003@1mRMGo000007n;e_l00000PXkGo`000025T]Wo000008ZHfol00000T9kMo`00002FYMl0
0ol00000102Y_>Oo0000o`00002fbnX2o`0000070<7Ik?l0003o00000<SSj`00003o00000<g/jP07
o`0000040<SWkOl0003o00000<CRkP;o000000@0_MW^o`000?l000000000BP3oool006/0oooo0`00
00020?ooo`03o`00002Y_NSo000000?o000000D0ZKgXo`000?l0003o00000:Vmj004o`0000050:Vm
j?l0003o0000o`00002X_>P00_l000000`2W^nOo00000:Jji`03o`0000030::fi_l0003o000000;o
000000@0VjkTo`000?l00000U:KR8?l000001@2L[>;o0000o`000?l00000/<CY00;o000000@0_=?[
o`000?l00000aMo/0_l000001@3<j^X00000o`000?l00000c^kZ00;o000000D0c>c[o`000?l0003o
00000<KUk@02o`0000040;oLk_l0003o00000;_FkP;o000000<000000?ooo`3oool0303oool2o`00
00@0oooo00?o00000?ooo`3oool00`3oool2o`000080oooo1Ol0000V0?ooo`00J@3oool200000003
0?ooool0003o000000;o000000D0ZKgXo`00002Y_NSo00000:Vmj002o`0000050:Vmj?l00000ZKgX
o`00002Y_NP01?l000001@2Y_NSo0000o`000?l00000Z;cX00Co000000L0YKWWo`000?l0003o0000
0:6di_l00000W[7U00Go000000L0TJ;Qo`00002=W]oo000008VJgOl00000QIGK00;o000000T0OhkH
o`00001mRmKo000007^9eOl00000NhSDo`00001kR=@00_l000002`1nRmKo0000086>eol00000QI;H
o`00002:Um[o000008nMgOl00000UJCO00?o000000@0ZK_Wo`000?l00000]/cZ0_l000001031fNco
0000o`000038i>/2o`00000300000?l0003o000000Go000000@0b>S]o`000?l00000a>;^0_l00000
1`2mfNko0000o`00002idngo00000?ooo`000000303oool01?l00000oooo0?ooool000080?ooo`04
o`00003oool0ooooo`000080oooo00Co00000?ooo`3ooooo00009P3oool006H0oooo00<00000o`00
000000000P3oool00ol00000ZKgXo`000003o`0000050:Vmj?l0003o0000o`00002Y_NP01?l00000
1@2Y_NSo00000:Vmj?l00000ZKgX00;o000000L0ZKgXo`00002X_>So00000:Nkj?l00000Y[[W00;o
000000<0Y;SWo`00002S]^H00ol000000`2K[^Co000009R[h`0Qo`00000509^[h_l0003o0000o`00
002`a>T00_l00000102ldn_o0000o`000035gn`2o`0000050<g[j_l000000000o`00003>k^T00_l0
00001@3<k>_o0000o`000?l00000a^G]00;o000000@0_mc^o`000?l00000^mK^1?l000000`000000
oooo0?ooo`030?ooo`Go00000P3oool01?l00000oooo0?ooool000080?ooo`04o`00003oool0oooo
o`0000<0oooo00?o00000?ooo`3oool09P3oool006@0oooo0P0000000`3ooooo0000o`000002o`00
00050:Vmj?l00000ZKgXo`00002Y_NP00ol00000102Y_NSo0000o`00002Y_NP4o`0000050:Vmj?l0
003o0000o`00002Y_NP01?l000001@2X_>So0000o`000?l00000Y[WW00Go000000<0W[7Uo`000?l0
00000_l00000202EYn;o0000o`00002=W]oo000008VJgOl00000QIGK0_l000002@1oS]So000007f;
e_l00000NhSEo`00001jQmCo000007Z7e002o`00000;07f:eOl00000PHgFo`000024TMSo000008VF
f_l00000SicMo`00002EY=l00ol00000102Y^nOo0000o`00002fc>X2o`0000040<7Jk?l0003o0000
0<WTj`;o000000<0c^gZ00000?l000001Ol000000`38j>go0000o`000003o`0000060;gIk_l0003o
00000;WCkOl00000]Lk/0_l000000`000000oooo0?ooo`090?ooo`04o`00003oool0ooooo`0000P0
oooo00Co00000?ooo`3ooooo0000103oool00ol00000oooo0?ooo`0U0?ooo`00H@3oool300000004
0?ooool0003o00000:Vmj0Co000000D0ZKgXo`000?l0003o00000:Vmj004o`0000050:Vmj?l00000
ZKgXo`00002Y_NP00ol000001P2Y_NSo0000o`00002Y_NSo00000:Rlj0?o000000H0Yk[Wo`000?l0
0000Y;SWo`00002S]^H3o`00000309b^i?l00000V:_S027o000000D0Vj_Ro`00002R/nCo00000;34
j@02o`0000040;cCjol0003o00000<GPk0;o000000D0cN_Zo`000?l0000000000<o_j@02o`000005
0<c/jol0003o0000o`000036iNd00_l00000102og>ko0000o`00002ke^h4o`0000040;?;k?l0003o
0000000000X0oooo00Co00000?ooo`3ooooo0000203oool01_l00000oooo0?ooool00000ooooo`00
00<0oooo00?o00000?ooo`3oool0903oool005h0oooo00@00000o`0000000000oooo0ol000001P2Y
_NSo0000o`00002Y_NSo00000:Vmj0?o000000@0ZKgXo`000?l00000ZKgX1?l000001@2Y_NSo0000
o`000?l00000ZKgX00?o000000<0ZKgXo`000?l000000_l000001@2X_>So0000o`000?l00000Y[WW
00Co000000<0XKCVo`000?l000000ol000000`2EYn;o0000096Sh@02o`00000308VJgOl0003o0000
00Co000000T0O8[Fo`00001kR=Go000007Z7e?l00000NXKDo`00001kQm@00_l000002@20S=Ko0000
08B@f?l00000R9KJo`00002>W=co000009BSg`06o`0000040;K<j_l0003o00000<7Jk0;o000000H0
bNG[o`000?l00000c^gYo`0000000005o`0000030<WXkOl0003o000000?o000000H0_MW^o`000?l0
0000^M?]o`00002ecN`2o`0000030;79jol00000000000X0oooo00Co00000?ooo`3ooooo0000203o
ool01_l00000oooo0?ooool00000ooooo`0000<0oooo00?o00000?ooo`3oool0903oool005`0oooo
0P0000001@3ooooo0000o`000?l00000ZKgX00Co000000D0ZKgXo`000?l0003o00000:Vmj003o`00
00060:Vmj?l0003o00000:Vmj?l00000ZKgX0ol00000102Y_NSo0000o`00002Y_NP3o`0000030:Vm
j?l0003o000000;o000000L0Yk_Xo`000?l0003o00000:Bhiol00000XkKV00;o000000@0Wk;Uo`00
0?l00000VJ_T1ol000001@25UM_o000008:AfOl00000OhgH01Go000000D0Vj_Ro`00002R/nCo0000
0;34j@02o`0000040;cCjol0003o00000<KPk0Ko000000D00000o`000?l0003o00000<_[k003o`00
00030<CSk_l00000_mc^00;o000000<0^mK^o`000?l000000_l000000`2cbnco0000o`000002o`00
00030000003oool0oooo00P0oooo0_l0000:0?ooo`;o00000`3oool3o`0002L0oooo001I0?ooo`<0
000000D0ooooo`000?l0003o00000:Vmj002o`0000030:Vmj?l00000ZKgX00?o000000@0ZKgXo`00
0?l00000ZKgX0ol000000`2Y_NSo0000o`000002o`0000050:Vmj?l0003o0000o`00002Y_NP00_l0
00001`2Y_NSo00000:Vmj?l00000Z;cXo`00002X_>P00_l000000`2W^nOo00000:Jii`03o`000003
0:6di_l0003o000000?o000000D0UJORo`00002AXn7o000008fNg`09o`00000907Z8eOl00000NXKD
o`00001jQ]Co000007Z7e?l00000O8WD00;o000000L0Pi3Ho`000028UM[o000008jKg?l00000U:?O
00Co000000<0ZK_Wo`00002fc>X00_l000001032f^co0000o`000039iN/3o`0000030<o_jOl00000
000000Co000000<0bNS/o`000?l000000ol000001P2mfNko0000o`00002hd^go00000;C=k0;o0000
00H0/LW[o`000?l0003o00000?ooo`0000140?ooo`00;03oool2o`0000@0oooo00?o00000?ooo`3o
ool00P3oool3o`0001d0oooo0P0000001@3ooooo0000o`000?l00000ZKgX00?o000000<0ZKgXo`00
0?l000000_l000001@2Y_NSo0000o`000?l00000ZKgX00;o000000L0ZKgXo`00002Y_NSo00000:Vm
j?l00000ZKgX00;o000000D0ZKgXo`000?l0003o00000:Vmj004o`0000050:Vmj?l0003o0000o`00
002W^nL01?l000001`2U^>Oo0000o`000?l00000Wk;Uo`00002L[nD02?l000001`25UM_o000008:A
fOl00000OXgGo`00001lR]H04ol000000`2JZ^;o00000::bi004o`0000040;gDjol0003o00000<KQ
k0Ko000000D0co3Y00000?l0003o00000<_[k003o`0000030<CSk_l00000_mc^00;o000000<0^mK^
o`000?l000000_l00000102cbnco0000o`00002`an/3o`0000030000003oool0oooo0480oooo000[
0?ooo`04o`00003oool0ooooo`0000L0oooo00Go00000?ooo`3oool0ooooo`00000I0?ooo`800000
1Ol000001P2Y_NSo0000o`00002Y_NSo00000:Vmj0;o000000D0ZKgXo`000?l0003o00000:Vmj003
o`0000030:Vmj?l0003o000000;o000000D0ZKgXo`000?l0003o00000:Vmj002o`0000070:Vmj?l0
0000ZKgXo`00002Y_NSo00000:Vmj002o`0000050:Rlj?l0003o0000o`00002W^nL01Ol000000`2Q
]NKo0000o`000003o`00000309JXh_l00000TZ?Q00go000000L0NHKDo`00001iQM?o000007Z6dol0
0000O8SD00;o000000L0PhoGo`000027U=Wo000008fKg?l00000Tj;O00Co000000<0ZK_Wo`00002g
c>X00_l000001032fnco0000o`00003:i^/3o`0000050=3`jOl0003o00000000003>knX00_l00000
0`39jNco0000o`000003o`0000060;gIk_l0003o00000;SBkOl00000]<g/0_l000001@2abN_o0000
o`000?l00000[/CZ00;o000000<000000?ooo`3oool0@@3oool002@0oooo1Ol000020?ooo`04o`00
003oool0ooooo`0000/0oooo00?o00000?ooo`3oool05@3oool2000000050?ooool0003o0000o`00
002Y_NP00ol000000`2Y_NSo0000o`000002o`0000050:Vmj?l0003o0000o`00002Y_NP00_l00000
1@2Y_NSo00000:Vmj?l00000ZKgX00Co000000D0ZKgXo`000?l0003o00000:Vmj004o`0000050:Vm
j?l0003o0000o`00002Y_NP00ol000001P2X^nOo0000o`00002V^^Oo00000:Fii`?o000000<0Wk;V
o`00002L[nD01Ol000000`2>Wmoo000008VJg@02o`00000708:AfOl00000OXgGo`00001lRMKo0000
07Z7e00Ao`00000309ZYhOl00000XK;T00Co000000@0_MC[o`000?l00000an7[1ol00000103?l>T0
0000o`00003;k>`3o`0000030<CSk_l00000_mc^00;o000000<0^mK^o`000?l000000_l00000102c
bnco0000o`00002`an/3o`0000040:g3j_l0003o000000000480oooo000[0?ooo`04o`00003oool0
ooooo`0000/0oooo00?o00000?ooo`3oool04P3oool3000000050?ooool0003o0000o`00002Y_NP0
0_l000000`2Y_NSo00000:Vmj002o`0000050:Vmj?l0003o0000o`00002Y_NP00ol000000`2Y_NSo
0000o`000002o`0000050:Vmj?l00000ZKgXo`00002Y_NP00ol00000102Y_NSo0000o`00002Y_NP4
o`0000050:Vmj?l0003o0000o`00002X_>P00ol000000`2W^nOo0000o`000002o`0000030:>giol0
0000X[GV00?o000000<0VJcTo`00002FZ>804?l000001`1iQM?o000007V6dol00000NhODo`00001n
R]D00_l000001@27U=Wo000008fJg?l00000Tj;N00Co000000<0Z;_Vo`00002gc>X00_l000001032
fnco0000o`00003:i^/3o`0000050=3`j?l0003o0000o`00000000000ol000000`37i^go0000o`00
0007o`0000040;C=k?l0003o00000;78j`Ko000000<0[<;Yo`0000000000@P3oool002/0oooo00Co
00000?ooo`3ooooo00001`3oool4o`000180oooo0P0000000ol00000ooooo`000002o`0000050:Vm
j?l0003o0000o`00002Y_NP01?l000001@2Y_NSo0000o`000?l00000ZKgX00;o000000D0ZKgXo`00
002Y_NSo00000:Vmj004o`0000050:Vmj?l0003o0000o`00002Y_NP01?l000001@2Y_NSo00000:Vm
j?l00000ZKgX00?o000000X0ZKgXo`000?l00000Z;cXo`00002X^nSo00000:Jjiol00000YKWW2ol0
00001@2>Wmoo000008ZJgOl00000QYGK00;o000000D0OXgGo`00001lRMKo000007Z7e00Ao`000003
09ZYhOl00000XK;T00;o000000<0/<CYo`00002me>/00_l000000`37h^_o0000o`000005o`000004
0<o`jOl0000000000<_/k0?o000000@0a>?^o`000?l00000_MW^0_l000001@2hd^go0000o`000?l0
0000//_/00Co000000<0[/CZo`00002]`nX01?l000000`000000oooo0?ooo`0o0?ooo`00:`3oool0
1?l00000oooo0?ooool000070?ooo`03o`00003oool0oooo0140oooo0P0000020?ooo`?o000000@0
ZKgXo`000?l00000ZKgX1?l000001@2Y_NSo0000o`000?l00000ZKgX00?o000000<0ZKgXo`000?l0
00000_l000001@2Y_NSo00000:Vmj?l00000ZKgX00;o000000D0ZKgXo`000?l0003o00000:Vmj004
o`0000050:Vmj?l0003o0000o`00002Y_NP00ol000000`2X_>So0000o`000002o`0000050:Nkj?l0
003o0000o`00002T]nL00ol000000`2M[nCo000009V/h`0Bo`00000907R5dol00000NHGCo`00001k
QmCo000007f:eOl00000PXkG00;o000000<0S9[Ko`00002BXMh01?l000000`2X^nKo0000o`000002
o`0000050<?Lk?l0003o0000o`00003=jnX00_l000000`3@lNSo0000o`000002o`00000400000?l0
003o00000<OVk@;o000000@0_mc^o`000?l00000^]G^1_l000000`2ab>_o00000:o5jP04o`000003
0:c2jOl00000Zl3Y00;o000000<000000?ooo`3oool0?P3oool002`0oooo0_l000080?ooo`Go0000
303oool3000000050?ooool0003o0000o`00002Y_NP01?l000001@2Y_NSo00000:Vmj?l00000ZKgX
00?o000000@0ZKgXo`000?l00000ZKgX0ol000000`2Y_NSo0000o`000002o`0000050:Vmj?l0003o
0000o`00002Y_NP00ol000001P2Y_NSo0000o`00002Y_NSo00000:Vmj0;o000000D0ZKgXo`000?l0
003o00000:Vmj003o`0000030:Rlj?l0003o000000;o000000L0Y[[Wo`000?l0003o00000::ei_l0
0000Wk;U00?o000000<0UZSRo`00002BY>400_l000001@2:V]go000008JFfol00000PY7I00;o0000
00D0NhWFo`00001iQ]Co000007R5d`0?o`00000309VYhOl00000XK7T00;o000000<0/<CYo`00002m
eN/00_l000001@37h^_o0000o`000?l00000cnkY00?o000000D0d?7Yo`000?l0000000000<WYk002
o`0000040<GSkOl0003o00000;gIkP;o000000<0^=;]o`00002dcN`01_l000000`2^`n[o0000o`00
0004o`0000030:^ojOl0000000000400oooo00150?ooo`0400000?l00000oooo0?ooo`;o000000D0
ZKgXo`000?l0003o00000:Vmj004o`0000050:Vmj?l0003o0000o`00002Y_NP00ol00000202Y_NSo
0000o`00002Y_NSo00000:Vmj?l00000ZKgX1?l000001@2Y_NSo0000o`000?l00000ZKgX00?o0000
00<0ZKgXo`000?l000000_l000001@2Y_NSo0000o`000?l00000ZKgX00;o000000L0ZKgXo`00002Y
_NSo00000:Rlj?l00000Yk_X00?o000000<0Y;OWo`000?l000000ol000000`2J[>?o0000o`00000B
o`00000707R4dol00000NXKCo`00001mRMCo0000086=eP02o`00000308bIfol00000TZ7N00Co0000
00H0Z;[Vo`000?l00000]lgZo`000033g>`3o`0000040<k[j_l0003o00000=7aj0Go000000<00000
o`000037i^d00_l00000102og>ko0000o`00002jeNh4o`0000050;;:k?l0003o0000o`00002^aNX0
0_l000001@2]`^Wo0000o`000?l00000Zl3Y00Co000000<000000?ooo`3oool0?@3oool00480oooo
0`0000001@3ooooo0000o`000?l00000Z[gW00;o000000L0Z[gWo`00002Y_NSo00000:Vmiol00000
ZKgX00;o000000D0ZKgXo`000?l0003o00000:Vmj003o`0000030:Vmj?l0003o000000;o000000D0
ZKgXo`00002Y_NSo00000:Vmj003o`0000040:Vmj?l0003o00000:Vmj0?o000000<0ZKgXo`000?l0
00000_l000001@2Y_NSo0000o`000?l00000ZKgX00Co000000D0Z;gXo`000?l0003o00000:Jji`03
o`0000030::di_l0003o000000?o000000D0UjWSo`00002BY>7o000008jPh007o`00000707^9e_l0
0000NHKDo`00001hQ=?o000007N4dP0=o`00000309VXhOl00000XK7T00;o000000<0/<CYo`000?l0
00000_l000001@38hn_o0000o`000?l00000d>kY00Co000000@0co3Yo`000?l0000000001Ol00000
1P2mfNko0000o`00002hd^go00000;C<k0;o000000D0/LS[o`000?l0003o00000:k3jP02o`000005
0:c1jOl0003o0000o`00002[_nT00ol000000`000000oooo0?ooo`0m0?ooo`00@03oool200000080
oooo0_l000001@2Z_>Oo0000o`000?l00000Z[gW00Co000000D0Z[gWo`000?l0003o00000:Vmi`03
o`0000080:Vmj?l0003o00000:Vmj?l00000ZKgXo`00002Y_NP4o`0000050:Vmj?l0003o0000o`00
002Y_NP00ol000001P2Y_NSo0000o`00002Y_NSo00000:Vmj0?o000000@0ZKgXo`000?l00000ZKgX
0ol000000`2Y_NSo0000o`000002o`0000050:Rlj?l0003o0000o`00002U^>H00ol000000`2P/^Go
000009f`i@08o`00000508JFg?l00000PY7Jo`00001nSMP02_l000002@1jQM?o000007b8e?l00000
P8cFo`000025T]So000008^Hf`05o`0000060:Rji_l0003o00000;O=j_l00000`mg/0ol000001@3>
k>Wo0000o`000?l00000dO;X00?o000000L0c>c[o`000000003o00000<GSkOl00000_mc^00;o0000
00<0^]G^o`000?l000000_l000001@2bb^co0000o`000?l00000[/CZ00;o000000D0[L;Yo`000?l0
003o00000:_0j@02o`0000050:^oj?l00000Z[oXo`0000000000?P3oool003d0oooo00@00000o`00
00000000oooo0ol00000202[_>Ko0000o`00002[_>Ko00000:Zliol00000Z[cW1?l000001@2Z_NOo
0000o`000?l00000Z[gW00?o000000<0Z[gWo`000?l000000_l000001@2Y_NSo00000:Vmj?l00000
ZKgX00;o000000D0ZKgXo`000?l0003o00000:Vmj003o`0000030:Vmj?l0003o000000;o000000D0
ZKgXo`000?l0003o00000:Vmj002o`0000070:Vmj?l00000ZKgXo`00002Y_NSo00000:Rmj003o`00
00060:Jiiol0003o00000:Bfi_l00000X[CV0ol00000102J[^Go0000o`00002CY^8;o`00000707V6
e?l00000MhCCo`00001gPm;o000007N3dP0;o`00000309VXhOl0003o000000;o000000H0/<CYo`00
0?l00000_]K[o`000038hn/8o`0000050<oajOl0003o00000<[Yk00000001?l000001P2mfNko0000
o`00002hd^go00000;C<k0;o000000D0/LO[o`000?l0003o00000:k3jP02o`0000050:c1jOl0003o
0000o`00002[_nT01_l000000`000000oooo0?ooo`0k0?ooo`00>`3oool200000080oooo0_l00000
0`2/^nGo0000o`000002o`0000050:^li_l0003o0000o`00002[_>H00ol00000202Z_>Oo0000o`00
002Z_>Oo00000:Zmiol00000Z[gW1?l000001@2Z_NOo0000o`000?l00000Z[gW00?o000000X0ZKgX
o`000?l00000ZKgXo`00002Y_NSo00000:Vmj?l00000ZKgX0_l000001@2Y_NSo0000o`000?l00000
ZKgX00?o000000<0ZKgXo`000?l000000_l000001@2Y_NSo0000o`000?l00000Z;_W00?o000000<0
YKSVo`000?l000000ol000000`2N/NKo0000o`000003o`00000308nQhOl00000RY_N00;o000000D0
PY7Io`00001nS=Oo000007^8e@0:o`00000707b7e?l00000P8cFo`000025TMSo000008^HfP03o`00
00030:2ai?l00000Z;[V00;o000000<0]lg[o`000?l000000ol000001@3?k>Wo0000o`000?l00000
dO?W00Ko000000@000000<GTk_l00000_mc^1ol00000102bbN_o0000o`00002_a^/3o`0000050:g2
jOl0003o0000o`00002[`>T00_l000001`2Z_nSo0000o`000?l00000Z[kXo`0000000000?@3oool0
03P0oooo0`0000000`3ooooo0000o`000002o`0000050:bji?l00000[;[To`00002/^nD00_l00000
1@2/^nGo0000o`000?l00000ZkcV00?o000000<0ZkcVo`000?l000000_l000001@2Z_>Oo00000:Zl
iol00000Z[gW00;o000000D0Z[gWo`000?l0003o00000:Zmi`03o`0000030:Zmiol0003o000000;o
000000D0ZKgXo`000?l0003o00000:Vmj003o`0000040:Vmj?l0003o00000:Vmj0?o000000<0ZKkX
o`000?l000001_l000001`2W^NKo0000o`000?l00000Y;SWo`00002R]^L00ol000000`2K/>Ko0000
09N[i@0>o`00000507N3d_l00000MX;Ao`00001gP]402ol000000`2HYn7o0000o`000002o`000004
0;34jOl0003o00000;kFj`;o000000D0c>WZo`000?l0003o00000=7bi`03o`0000080<oajOl0003o
0000o`000037ind00000o`000032h>h2o`0000050;[DkOl0003o0000o`00002cc>`00_l000000`2a
an_o0000o`000004o`0000050:c1jOl0003o0000o`00002[_nT00_l000001`2Z_^So0000o`000?l0
0000Z[kXo`0000000000?03oool003D0oooo00<00000o`00000000000`3oool00ol00000[kSPo`00
0003o`0000050:fih_l0003o0000o`00002/^^@00ol00000102/^nGo0000o`00002/^nD3o`000003
0:^li_l0003o000000;o000000D0ZkcVo`000?l0003o00000:Zli`03o`0000080:Zmiol0003o0000
0:Zmiol00000Z[gWo`00002Z_NL4o`0000050:Zmiol0003o0000o`00002Y_NL00ol00000102Y_NSo
0000o`00002Y_^P3o`0000070:Vmj?l00000ZKgXo`00002X^nOo00000:RjiP03o`0000030:Fiiol0
003o000000;o000000<0XKOXo`000?l000000ol000001P2CYN7o0000o`00002:V]go000008JDfP;o
000000D0OX_Fo`00001kQmCo000007R4dP08o`00000707^7dol00000Oh_Eo`000024T=Oo000008ZG
fP03o`0000030:2ai?l00000Z;[V00;o000000<0]lg[o`000?l000000ol000001@3?kNWo0000o`00
0?l00000dO?W00Oo000000@0aNC^00000?l00000_=S^0_l000001@2gd>go0000o`000?l00000//W[
00;o000000<0[lK[o`00002]`nX02?l000001@2Z_nSo0000o`000?l00000Z[kX00;o000000<0Z[kX
o`0000000000>`3oool003<0oooo0P0000020?ooo`09o`00003ooooo0000o`00002`]]ko00000;2f
g_l00000[kSP00?o000000@0[KWRo`000?l00000[KWR0ol000002P2/^^Co0000o`00002/^^?o0000
0:bkiOl00000[;_Uo`00002[_>H2o`0000050:^li_l0003o0000o`00002[_>H00ol000000`2Z_>Oo
0000o`000002o`0000050:Zmiol00000Z[gWo`00002Z_NL00_l000001@2Z_NOo0000o`000?l00000
Z[gW00?o000000D0ZKgXo`000?l0003o00000:Vmj004o`0000050:Vkiol0003o0000o`00002W^^L0
0ol000000`2U^nWo0000o`000003o`00000309^_iOl0003o0000013o000000D0MX7Ao`00001gP]7o
000007R3dP08o`000003092NgOl0003o000000?o000000@0/<CYo`000?l00000_]K[0_l000001@3=
jN[o0000o`000?l00000d_;W00Co000000@0c^oYo`000?l00000b>S]0_l000001000003o0000o`00
002jdnd6o`0000030;78jol0003o000000;o000000D0[<;Yo`00002/`NWo00000:^oj@08o`000005
0:Znj?l0003o0000o`0000000000>`3oool00100oooo0ol0000M0?ooo`<000000`3oool3o`000005
0;6dfol0003o0000o`00002`]]h00_l000001@2`]]ko0000o`000?l00000[kSP00;o000000D0[kSP
o`00002]^N;o00000:fihP04o`0000050:bjhol0003o0000o`00002/^nD00ol00000102[_>Go0000
o`00002[^nD3o`0000030:^li_l0003o000000;o000000D0Z[cWo`000?l0003o00000:Zli`03o`00
00080:Zmiol0003o00000:Zmiol00000Z[gXo`00002Z_NP3o`0000030:Vliol0003o000000;o0000
00D0Z;[Vo`000?l0003o00000:Nmj@03o`0000030:>jjOl0003o000000?o000000<0UjGOo`00002C
XMh00_l000001@2:Um[o000008JBf?l00000PXkG00;o000000<0NhKCo`00001hQ=800_l000000`1f
PM7o0000o`000005o`00000307j:eOl00000Q93G00Go000000<0Wk3To`00002X^^H00_l00000102g
cN_o0000o`000034gN/3o`0000050=7aj?l0003o0000o`00003Al^L00ol000001`3:k>co0000o`00
0?l00000`]o^0000002lend00_l000000`2hd>co00000;C<k004o`0000030:o6jol00000[L?Z00Ko
000000D0ZkoXo`00002Z_^So00000:Znj004o`0000050:Znj?l0003o0000o`0000000000203oool2
o`000300oooo000A0?ooo`03o`00003oool0oooo01X0oooo00<00000o`00003oool00`3oool3o`00
00040;>bf?l0003o00000;>bf0Co000000D0/KCKo`00002a]=_o00000;2fgP02o`0000050;2fg_l0
003o0000o`00002_^>000ol00000102]^N;o0000o`00002]^N83o`0000050:bjhol0003o0000o`00
002/^nD00_l000001@2/^nGo00000:^kiOl00000Zk_U00Co000000D0ZkcVo`000?l0003o00000:Zl
i`03o`0000030:Zmiol0003o000000;o000000T0Z[gWo`00002Z_>Oo00000:Vliol00000ZK[Vo`00
002Y^^H00_l000001@2X_NSo0000o`000?l00000Ykk[00?o000000<0XK;To`00002N[^<05Ol00000
1@1fP]7o000007R3d_l00000NXKC00Co000000D0RIKJo`00002@W]go000009RWh@03o`0000040;34
jOl0003o00000;kFj`;o000000<0cN[Zo`000?l000000_l000001@3BlnOo0000o`000?l00000co3Y
00?o000000H0a>?^o`000?l000000000o`00002jdnd2o`0000030;K?kOl00000//_/00Ko000000D0
[<7Yo`000?l0003o00000:^oj006o`0000030:Znj?l00000Z[kX00Ko000000<000000?ooo`3oool0
103oool01?l00000oooo0?ooool0000_0?ooo`002@3oool5o`0000<0oooo00?o00000?ooo`3oool0
5`3oool3000000030?ooool00000oooo0080oooo00Co00000;N^d?l00000]K3D0_l000001@2e/=Co
00000;F`e?l00000/k;H00?o000000@0/KCKo`000?l00000/KCK0ol00000102`]]ko0000o`00002`
]]h3o`0000080:nhh?l0003o00000:nhh?l00000[KWRo`00002]^N83o`0000030:bjhol0003o0000
00;o000000D0[;_Uo`00002/^nCo00000:^ki@03o`0000040:^li_l0003o00000:^liP?o000000<0
ZkgWo`000?l000000_l000001@2Z_>Ko0000o`000?l00000ZK[V00?o000000D0ZKgXo`000?l0003o
00000:S0j`02o`0000030:Fhi_l00000XkGU00?o000000H0VZCMo`000?l00000TikKo`00002?Vm/9
o`00000307R5e?l00000MX?C01;o000000@0Z;[Vo`000?l00000]lgZ0_l000001@35gN_o0000o`00
0?l00000dO;W00?o000000<0dO;Wo`000?l000001Ol000000`31gNgo000000000002o`0000030;SA
kOl0003o000000;o000000D0/<S/o`000?l0003o00000:g2jP02o`0000050:c0jOl0003o0000o`00
002[_nP00ol000000`2Z_^So0000o`000002o`0000070:Znj?l00000ZKkXo`00002Y_NSo00000000
00060?ooo`04o`00003oool0ooooo`0002l0oooo000A0?ooo`03o`00003oool0oooo01D0oooo0P00
00070?ooo`;o000000@0]jk@o`000?l00000]jkA0ol00000102e/=Co0000o`00002e/=@3o`000008
0;>bf?l0003o00000;>bf?l00000/KCKo`00002a]=/2o`0000050;6dfol00000/;KNo`00002`]]h0
1?l000002@2_^>3o00000:nhh?l00000[KWRo`00002]^N;o00000:fjh`02o`0000050:fjhol0003o
0000o`00002/^n@00ol00000202[_>Go0000o`00002[_>Ko00000:^li_l00000ZkcV1?l000001@2Z
^^Go0000o`000?l00000ZKcW00?o000000D0ZL7[o`000?l0003o00000:Nji`05o`00000309fWgOl0
003o000000Go000000H0RigOo`000?l00000PYCLo`00001nT=/8o`00000507J2d_l00000MhCCo`00
001jQ]@00_l000001`22T=So000008RFf_l00000SikMo`00002GYn400ol00000102``nSo0000o`00
002ne^/7o`0000030=;ci_l0003o000000;o000000@0c?3[o`000?l00000a>7]0_l000000`2ofNd0
0000o`000002o`0000030;K@kOl00000//_/00;o000000D0[lG[o`000?l0003o00000:c1j@03o`00
00040:^oj?l0003o00000:Zoj0?o000000<0Z[kXo`000?l000001_l000000`2Y_NSo000000000005
0?ooo`04o`00003oool0ooooo`0002l0oooo000A0?ooo`03o`00003oool0oooo0180oooo00<00000
o`0000000000203oool2o`0000090;R/cOl00000^:c=0;R/cOl00000^:c=o`00002f[]7o00000080
]ZkA00Ko00000;J^dOl00000]K3Do`00002e/=@4o`0000050;>bf?l00000/k;Ho`00002a]=/00_l0
00001@2a]=_o00000;6dfol00000/;KN00;o000000D0/;KNo`000?l0003o00000:nhh003o`000005
0:fih_l0003o0000o`00002]^^<00_l000001@2]^^?o0000o`000?l00000[;_U00Co000000D0Zk_U
o`00002[^^Co00000:^ji@03o`0000040:Zli_l0003o00000:_0j@?o000000L0ZKkXo`000?l0003o
00000:B_gol00000XZcO00?o000000<0VjOOo`00002HY]l03_l000000`1eQMKo000007B4e00?o`00
000509n_hol0003o0000o`00002hc>X00ol00000103:in_o0000o`00003Al^L4o`0000050=3diol0
003o0000o`000037i>`00_l000001032g>co0000o`0000000006o`0000030;37jol0003o000000Co
000000D0[<3Xo`000?l0003o00000:^oj003o`0000040:Znj?l0003o00000:Znj0?o000000<0ZKgX
o`000?l000001?l000000`000000oooo0?ooo`020?ooo`04o`00003oool0ooooo`0002l0oooo000@
0?ooo`;o00004P3oool200000080oooo00?o00000?ooo`3oool0103oool2o`0000050;VYbOl0003o
0000o`00002h[<d00_l000001@2h[<go0000o`000?l00000]ZkA00;o000000P0]ZkAo`000?l00000
]ZkAo`00002f[]7o00000;B`e0;o000000D0];3Do`000?l0003o00000;>bf003o`0000040;6dfol0
003o00000;6df`?o000000P0/;KNo`000?l00000/;KMo`00002_^>3o00000:nhh0?o000000P0[[WR
o`000?l00000[[WRo`00002]^^?o00000:fjh`Co000000D0[;WSo`000?l0003o00000:^ji@03o`00
00040:^ojOl0003o00000:^oj0?o000000<0Yk;Qo`00002U/N000ol000000`2OZMgo000009fXgP03
o`00000409Fdk?l0003o000008^Yj@Co000000<0O9GPo`00001iSmd00_l000000`1dQ]Oo0000o`00
0003o`00000507J4dol00000NHKDo`00001lR]H00_l000000`27UM[o000008nMg@05o`0000040:o2
j?l0003o00000;oFj`?o000000<0d?3Xo`000?l000000_l000000`3Cm>Ko0000o`000002o`000003
0<WWk?l00000a=k/00Co000000<000000;SEkol000001Ol000000`2^`nWo00000:g1j008o`000005
0:^ojOl0003o0000o`00002Z_^P00_l000001@2Y_^So0000o`000?l00000ZKgX00?o000000<0ZKgX
o`0000000000103oool01?l00000oooo0?ooool0000_0?ooo`004@3oool00ol00000oooo0?ooo`0=
0?ooo`<000002P3oool02Ol00000^jO50;^WaOl00000^jO6o`00002iZLWo00000;VYb@02o`000005
0;VYbOl00000^:c=o`00002h[<d00_l000001@2h[<go00000;J^dOl00000]ZkA00;o00000P2f[]42
o`0000080;B`e?l0003o00000;B`e?l00000/k;Ho`00002c/]P2o`0000050;>bf?l00000/KCKo`00
002a]=/01?l000001`2`]]go00000;2fgOl00000[kSPo`00002_^>001?l000001@2^^N;o00000:fh
hOl00000[KWR00;o000000D0[;WRo`000?l0003o00000:bmiP03o`0000050:boj?l0003o0000o`00
002X]>401Ol000000`2RZ]go0000o`000009o`00000308FTj?l00000P9_S00So000000<0Lh?Do`00
001cP]<02ol000000`2FY=ko000009j]hP03o`0000050;S=j_l0003o0000o`00003;j>/00ol00000
0`3ClNKo0000o`000002o`0000030<kcjOl0003o000000Co000000P0`>3_o`00002jf_000000o`00
002dcngo00000;36jPKo000000D0[<7Yo`00002/`>Wo00000:_0j@08o`0000050:Vnj?l0003o0000
o`00002Y_NP00_l000001`2Y_NSo0000o`000?l00000ZKgXo`0000000000103oool2o`000300oooo
000N0?ooo`0300000?l00000000000`0oooo0_l00000102kYlGo0000o`00002kYlH2o`0000050;^W
a_l00000^jO6o`00002iZLT00_l000001@2iZLWo00000;VYbOl00000^:c=00;o000000D0^:c=o`00
002h[<go00000;J^d@02o`0000050;J^dOl00000]ZkAo`00002d/=@00_l000001@2d/=Co00000;B`
e?l00000/k;H00;o000000D0/k;Ho`00002c/]So00000;6df`02o`0000090;6dfol0003o0000o`00
002`]]go00000;2fgOl00000[kSP00;o000000D0[kOOo`000?l0003o00000:fhh@03o`0000040:fl
iOl0003o00000:jniP?o000000L0ZkKQo`000?l0003o00000:J/fol00000YJ_K00?o000000D0XkWY
o`000?l0003o000009S8n00=o`00000407J5eOl0003o000007=nc`Go000000D0N8CCo`00001lQmCo
0000086<eP02o`00000308jKfol0003o000000;o000000<0YkOUo`000?l000000_l000000`36hnco
0000o`00000:o`0000040<[Sj_l0003o00000<CTk`Co000000<00000o`000?l000000_l000001@2_
`^So0000o`000?l00000[L7Y00Ko000000D0Zl3Yo`000?l0003o00000:Znj004o`0000050:Vmj?l0
003o0000o`00002Y_NP00ol000001P2Y_NSo0000o`00002Y_NSo0000000003D0oooo000L0?ooo`80
00000P3oool00ol00000oooo0?ooo`090?ooo`;o000000X0_:G2o`00002lYL80_:G2o`00002lYL;o
00000;^Wa_l00000^jO60_l000020;^WaP;o000000@0^JW9o`000?l00000^JW90ol00000102h[<go
0000o`00002h[<d3o`0000040;J^dOl0003o00000;J^d@?o000000@0];3Do`000?l00000];3D0ol0
0000102c/]So0000o`00002c/]P3o`0000040;6dfol0003o00000;6df`?o000000D0/;KMo`000?l0
003o00000:jgg`02o`0000050:nihOl0003o0000o`00002__N@00ol000001P2/]n7o0000o`00002Y
[=[o00000:N/fP?o000000<0Y[OUo`000?l000001Ol000000`2G[NKo0000096Th@02o`00000308NA
eol00000PX[B00;o000000<0NWk;o`00001hNlT01Ol00000101cOLko0000o`00001hP<l8o`000003
09FRgOl00000WZcQ00;o000000<0/<CXo`000031fnd00_l000001@3;jN_o0000o`000?l00000e?;U
00Go000000@0c>CYo`000?l00000anW^0_l000000`30iO7o0000o`000002000000030;?9jol00000
/<?X00;o000000D0[l?Xo`00002^`^Wo00000:g3jP03o`0000080:_1jOl0003o00000:ZojOl00000
Z[kXo`00002Y_NP8o`0000050:Vmj?l0003o0000o`00002Y_NP00ol000000`000000oooo0?ooo`0c
0?ooo`006@3oool3000000h0oooo0_l000020;fT`0;o000000@0_:G2o`000?l00000_:G20_l00000
1@2lYL;o00000;bU`_l00000^jO600;o000000T0^jO6o`00002kYlH0^jO6o`00002jYlKo00000;VY
bOl000000P2iZLT01_l00000^JW9o`00002h[<go00000;R/c@;o000000D0^:c=o`00002f[]7o0000
0;J^d@02o`0000050;J^dOl00000];3Do`00002d/=@00_l000001@2d/=Co00000;>bf?l00000/k;H
00?o000000@0/KCJo`000?l00000/K?J0ol00000202`]mko0000o`00002a^Moo00000;2kh_l00000
[kKN0ol000000`2[[MWo0000o`000002o`0000070:Vch?l0003o0000o`00002WdoOo00000:G8lP0B
o`00000407Ihb?l0003o000007Ega`Go000000<0NhC@o`000020RM800_l000000`2=V=Wo0000o`00
0002o`0000030:NhiOl0003o000000;o000000D0a^C]o`000?l0003o00000=7[i`08o`0000030<_T
jOl0003o000000;o00000`0000001_l000000000o`00002a`nOo00000;34j0Ko000000D0[<?[o`00
0?l0003o00000:Zoj@06o`0000050:Vmiol00000ZKgXo`00002Y_NP03?l000000`000000oooo0?oo
o`0b0?ooo`00603oool2o`0000l0oooo00Co00000;jS_Ol00000_JC00_l000002P2mY<3o00000;fT
`02mY<3o00000;fT`?l00000_:G2o`00002lYL82o`000080_:G30_l00000102kYlKo0000o`00002j
YlH3o`0000040;VYbOl0003o00000;VYb@;o000000D0^JW9o`00002iZLWo00000;R/c@02o`000005
0;R/cOl00000^:c=o`00002f[]400_l000001@2f[]7o00000;J^dOl00000];3D00;o000000L0];3D
o`00002d/=Co00000;>beol00000/k;G00;o000000D0/k?Ho`00002a]M_o00000;:gg004o`000009
0;2eg?l00000[ZgGo`00002/[MSo00000:b`fol00000Z[;N00;o000000<0[Lobo`000?l000000ol0
00000`2LUL_o000009R?b@02o`00000308n5aOl00000Rh7300;o000000<0Pg[1o`00001oN<400_l0
00000`1jM<7o0000o`000005o`00000407Iib?l0003o000007b1c@Ko000000<0UJ;Mo`00002N[N80
0_l000000`2ab>_o00000<7MkP03o`0000030<kVj?l0003o000000;o000000D0cocRo`000?l0003o
00000<kTj003o`0000<0000000<0^M7/o`00002da>H00_l000001@00003o0000o`000?l00000/<O[
00?o000000@0[LG/o`000?l00000Zl7Z0ol000001@2Z_NSo0000o`000?l00000ZKgW00Ko000000D0
ZKgXo`000?l0003o00000:Vmj003o`0000050:Vmj?l0003o0000o`0000000000=03oool001P0oooo
00<00000o`000?l000003@3oool2o`000080_Z>m00?o00000;jS_@2nXkd00_l00000102mY<3o0000
o`00002mY<02o`0000050;fT`?l00000_JC0o`00002lYL<00_l000002P2lYL?o00000;bU``2lYL?o
00000;bU`ol00000^ZO6o`00002jYlH2o`0000050;ZWa_l00000^JW9o`00002iZLT00_l000020;VY
b@;o000000@0^:c=o`000?l00000^:c=0ol00000102f[]7o0000o`00002f[]43o`0000080;B`e?l0
003o00000;B`e?l00000];3Eo`00002c/mP2o`0000050;BdfOl00000/k;Go`00002b]=X00ol00000
1@2^[MOo0000o`000?l00000[;3K00;o000000H0[l_^o`000?l00000/=Cbo`00002UWll2o`000080
W9G;3ol00000101hM<;o0000o`00001fM/H7o`0000030827d?l00000QXkD00Go000000H0Z;gXo`00
0?l00000^]G^o`000036hN`3o`0000030=;Zi_l0003o000000?o000000<0d>GVo`000?l000000`00
00000ol00000^mG]o`000003o`0000050;C5i_l0003o00000000002bbN`00_l000001@2_bNko0000
o`000?l00000Zl;[00Ko000000D0Z[cWo`000?l0003o00000:Zmi`03o`0000050:Zmj?l0003o0000
o`00002Y_NP00_l000001@2Y_NSo0000o`000?l00000ZKgX00?o000000<000000?ooo`3oool0<@3o
ool00100oooo0_l000060?ooo`040000003oool0ooooo`0000/0oooo00?o00000;jR_02nX[`00ol0
00001@2nXkgo0000o`00002nXkgo00000080_Z>m00Ko00000;jS_Ol00000_JC0o`00002mY<02o`00
0080_JC00_l00000102lYL?o0000o`00002lYL<2o`0000050;bU`ol00000_:G3o`00002jYlH00_l0
00001@2jYlKo00000;ZWa_l00000^JW900;o000000X0^JW9o`00002iZLT0^JW9o`00002iZLWo0000
0;R/cOl00000^:c=0_l000001@2hZlgo00000;J^dOl00000]ZkA00?o000000@0];3Eo`000?l00000
]K;F0ol00000102c/]Oo0000o`00002a[=<3o`0000030:j]e_l0003o000000So000000<0YIo?o`00
0?l000000ol000001P2AO[_o0000o`00002;O;go000008Ql_`;o000000<0PG_3o`00001nNlH02?l0
00000`1gNLSo000007Umb`06o`00000308jLg?l0003o000000?o000000<0/Lg^o`000?l000000ol0
00000`3>i>Oo0000o`000003o`0000030=7TiOl000000000008000000_l000001P2nfNgo0000o`00
002g`n?o00000;K4i@;o000000@0]/o]o`000?l0000000001ol000001@2Z_^So00000:Zki_l00000
Z[cW00Ko000000D0Z[gXo`000?l0003o00000:Znj003o`0000050:Vmj?l0003o0000o`00002Y_NP0
0_l000001@2Y_NSo0000o`000?l0000000000380oooo000?0?ooo`04o`00003oool0ooooo`0000D0
oooo00D000000?ooo`3oool0ooooo`00000:0?ooo`04o`00002nX[co0000o`000080_Z:l00?o0000
0;jR_02nX[`00_l000000`2nXkgo0000o`0000020;jS_@06o`00002nXkgo00000;jS_Ol00000_JC0
0_l000002P2mY<3o00000;fT`02mY<3o00000;fT`?l00000_:G3o`00002lYL<2o`000080_:G30_l0
0000102jYlKo0000o`00002jYlH3o`0000040;VYbOl0003o00000;VYb@;o000000D0^JW9o`00002i
ZLWo00000;R[c@02o`0000070;N[cOl00000^:c=o`00002f[]7o00000;N_dP02o`0000050;J^dOl0
0000]K3Do`00002cZm000ol00000102`[=?o0000o`00002e_N02o`0000050;[>jOl00000/J[Ao`00
002^Ym400ol000001@2KQ;Wo0000o`00002DP;[o00000080TGjk0_l000001P2;O;go0000o`000025
Nl7o0000085k``?o000000<0N7g<o`00001fOll02?l000000`21R]?o0000o`000003o`00000309ni
jol00000ZL?]00;o000000@0^=;]o`000?l00000bM_V1?l000000`3BmnKo000000000002000000Co
000000<0`Mk^o`00002h`^400_l000000`2h`n?o00000;SBk@02o`0000030;?Gl_l00000000000?o
000000<0ZkkXo`000?l000001_l000001@2Z_>Ko00000:Znj?l00000Z[gX00[o000000D0ZKgXo`00
0?l0003o00000:Vmj003o`0000030:Vmj?l0000000000380oooo000?0?ooo`04o`00003oool0oooo
o`0000@0oooo00<00000o`00003oool00`3oool00ol00000oooo0?ooo`060?ooo`06o`00002oX[_o
00000;nR^ol00000_Z:l0_l000001@2nX[co0000o`00002nX[co00000080_Z:l0ol000001@2nXkgo
00000;jS_@2nXkgo00000080_Z:m0_l00000102mY<3o0000o`00002mY<02o`0000050;fT`?l00000
_JC0o`00002lYL<00_l000002P2kYL?o00000;^U``2kYL?o00000;^U`ol00000^ZO6o`00002jYlH2
o`0000050;ZWa_l00000^JW9o`00002iZLT00_l000020;VYb@;o000000P0^:c=o`000?l00000^:g>
o`00002h[<go00000;J^d@;o000000L0]J[>o`00002dZLko00000;:Zd?l00000][WK00;o000000D0
_<STo`000?l0003o00000;6Zd@03o`00000409j6^Ol00000VhBi09^4^AGo000000D0MHCDo`00001g
RMSo000007^>f`02o`00000508JMh_l00000SZKUo`00002F[nP01_l00000102mcnSo0000o`00003A
jnL2o`0000<0000000<0dMgQo`000?l000001ol000000`2i`^3o0000o`000007o`00000500000?l0
003o0000o`00002Z^N@00ol000000`2[^nGo0000o`000006o`0000030:Znj?l00000Z[kX00?o0000
00<0ZKgXo`000?l000001_l000001`2Y_NSo0000o`000?l00000ZKgXo`0000000000<@3oool000l0
oooo00Co00000?ooo`3ooooo0000103oool00`000000oooo0?ooo`040?ooo`03o`00003oool0oooo
00@0oooo0_l000001@2oX[_o00000;nR^`2oX[_o00000080_j:k00Ko00000;nR^ol00000_Z:lo`00
002nX[`2o`000080_Z:l00?o00000;jR_?l000000_l000001@2nX[go0000o`00002nX[go00000080
_J:m00Ko00000;fR_Ol00000_JC0o`00002mY<02o`000080_:C00_l00000102kYL?o0000o`00002k
YL<2o`0000050;^U`ol00000^jG3o`00002jYlH00_l000001@2jYlKo00000;ZWa_l00000^JW900Co
00000P2iZ/X2o`0000040;R/cOl0003o00000;JXb`?o000000H0]:W>o`000?l00000]kCFo`00002m
`mh2o`0000090;N]col00000]:c@o`00002TRk[o00000:68^_l00000WXJi00Co000000<0VI[Co`00
002EWMT07?l000001@2M^^co00000:bkiOl00000]LGV00;o000000<0`m3To`00000000000P000002
o`0000030=3FgOl0003o000000;o000000D0^[[Io`00002j_Mco00000;Zog@02o`0000040;oHk?l0
003o00000;7NmP?o000000D0[<3Yo`000?l0000000000:Zhh`02o`0000050:^ii?l0003o0000o`00
002[_^L00ol000000`2[_nWo0000o`000004o`0000050:Vmj?l00000ZKgXo`00002Y_NL00ol00000
0`2Y_NOo0000o`000006o`0000030:Vmj?l0000000000300oooo000?0?ooo`04o`00003oool0oooo
o`0000@0oooo00<000000?ooo`3oool01@3oool01?l00000oooo0?ooo`3oool2o`000080`::k00?o
00000<2R^ol000000_l000000`2oX[_o0000o`0000020;nR^`06o`00002oX[_o00000;nQ^ol00000
_Z:l0_l000001@2nX[co00000;jR_02nX[co00000080_Z:l0_l000000`2mX[go0000o`0000020;fR
_@06o`00002mX[go00000;fR_Ol00000_:C00_l000002P2lY<3o00000;bT`02lY<3o00000;bT`?l0
0000^jG3o`00002kYL<2o`000080^jG30_l00000202jYlKo0000o`00002jYlKo00000;ZXa_l00000
^J[:0_l000002P2iZLWo00000;RWb02hYlSo00000;NVaol00000]JO;o`00002i/=42o`0000050;jm
fOl00000^Jg=o`00002g[Ll00ol000020:B;^PCo000000@0WY?8o`000?l00000VI[C1Ol000000`27
K:go000008=WZ`0Ko`0000040;_4h@0000000000000000;o000000<0cm_Ro`00003@e]d00ol00000
0`2j]]Ko00000;Zjf@02o`0000030;^jfOl00000`m_[00Go000000D0[L;Yo`000?l0003o00000:Zd
h002o`0000030000002/^>;o000000;o000000@0[;kWo`000?l00000[<7Y0ol000001@2Z_nWo0000
o`000?l00000ZKgX00Ko000000D0Z[cWo`000?l0003o00000:Zmi`03o`0000030:Zmiol0003o0000
00?o000000<00000o`00003oool0;P3oool000l0oooo00Co00000?ooo`3ooooo0000103oool00`00
0000oooo0?ooo`060?ooo`06o`00003ooooo00000<2S^ol00000`::k0_l000001@30X[_o00000<2R
^`30X[_o00000080`::k0ol000001@2oX[_o00000;nQ^`2oXK_o00000080_j6k0_l00000102nX[co
0000o`00002nX[`2o`0000040;jR_?l00000_Z:l0;jR_0?o000000D0_J:mo`00002mX[d0_J:mo`00
00020;fR_@;o000000@0_:C0o`000?l00000_:C00_l000001@2lY<3o00000;bT`?l00000^jG300;o
000000@0^jG3o`00002kYL<0^jG30_l00000102jZ<Ko0000o`00002jYlH3o`0000040;RWb?l0003o
00000;NVa`;o000000@0^Zg=o`00002o^=<0_kSC0_l000001P2i[Lgo0000o`00002[T;Wo00000:R=
^PCo000000<0XI74o`00002NTlP00ol000000`2JP[So000009=i/`02o`00000308M/[Ol00000PfN[
00;o000000L0OF6Wo`00001kGjOo000006ijc_l00000LGK800Go000000H0MiKTo`000?l00000R9cP
o`00002AX^03o`0000030:RZf?l00000/KOM0080000000<0amOVo`000?l000000ol000000`3=cM[o
0000o`000002o`0000040;Zfe_l0003o00000;^ee0_o000000P0Z[7Mo`000?l00000[;CNo`000000
003o00000:joiP?o000000<0[<;Zo`000?l000001?l000001@2Z_NSo0000o`000?l00000ZKcW00?o
000000D0Z[cWo`000?l0003o00000:Zmi`02o`0000050:Zmiol0003o0000o`00002Z_NL00ol00000
0`2Z_NOo00000000000_0?ooo`00403oool2o`0000D0oooo00<000000?ooo`3oool01`3oool2o`00
0080`:>k00?o00000<2S^`30Xk/00_l000001030X[_o0000o`000030X[/2o`000080`::j00?o0000
0<2R^_l000000_l000001@2oXK_o0000o`00002oXK_o00000080_j6k00Ko00000;nQ^ol00000_Z:l
o`00002nX[`2o`000080_Z:l00?o00000;jR_?l000000_l000001@2mX[go0000o`00002mX[ko0000
0080_J:n00Ko00000;fR__l00000_:C0o`00002lY<02o`000080_:C00_l000001@2kYL?o0000o`00
002kY/?o00000080^jG300Go00000;^T`_l00000^JG5o`0000020;VTa@03o`00002kZ/So000000;o
000000P0_kSCo`000?l00000^jc:o`00002^T[Wo00000:^@^@?o000000<0YHnno`00002ST<400ol0
00020:ZC_`;o000000<0VX:ho`00002CNK<00_l000001`27K:go000008=WZol00000OF6Wo`00001k
GjL01_l000000`1gM<?o000007]g``06o`00000309JCc_l0003o000000<0000000<0_/SRo`000?l0
00000ol000020<S3e@;o000000D0]jc>o`00002i/M;o00000;Z^cP02o`0000090<_Niol0003o0000
o`00002_b>co00000:RUdol00000ZJ[G00?o000000P0[K;Lo`000?l0003o00000:noiP00003o0000
0:k6j`?o000000<0Zl;Zo`00002Z_NL02?l000001@2Z^nKo0000o`000?l00000Z[cW00?o000000D0
Z[gWo`000?l0003o00000:Zmi`02o`0000070:Zmiol0003o0000o`00002Z_NOo00000000000^0?oo
o`005`3oool00`000000oooo0?ooo`070?ooo`03o`000030Y;go000000;o000000D0`:>ko`000?l0
0000`:>ko`0000020<2S^`04o`000030X[_o00000<2R^P;o000000D0`::jo`000030X[X0`::jo`00
00020<2R^P;o000000<0_j6ko`000?l000000P2oXK/01_l00000_j6ko`00002oXK_o00000;jR_0;o
000000D0_Z:lo`00002nX[`0_Z:lo`0000020;jR_0;o000000@0_J:no`000?l00000_J:n0_l00000
1@2mX[ko00000;fR__l00000_:C000;o000000@0_:C0o`00002lY<00_:C00_l00000102kYL?o0000
o`00002kY<83o`0000060;VTaOl0003o00000;^Zb?l00000_k?>0_l00000102lZ/Oo0000o`000?l0
00020:jB^@;o000000<0Yhnlo`00002USkh01?l000000`2bW<;o0000o`00000<o`00000707eQYol0
003o0000o`00001jGjSo000007YQZ@05o`000005081ka?l0003o000008f9b_l000000`0000000ol0
0000];SLo`000003o`0000040<WAh?l0003o00000<S3e@?o000000H0]jc>o`000?l00000]jK8o`00
003>g^@7o`0000050:RUdol0003o0000o`00002][]T00_l000000`2b`NGo0000o`000002o`000003
00000?l0003o000000?o000000T0Z[gWo`00002Z^NCo00000:ZjiOl00000Z[[Uo`00002Z^nD02_l0
00001@2Z_NOo0000o`000?l00000Z[gW00?o000000D0Z[gWo`000?l0003o00000000000^0?ooo`00
5P3oool00`000000oooo0?ooo`070?ooo`;o000000D0`:Bmo`000030Y;d0`:Bmo`0000020<2T_@;o
000000<0`:>ko`000?l000000P30X[/00ol00000`::k0<2R^`02o`0000040<2R^_l0003o00000<2R
^P;o000000@0`::jo`000030X[X0`::j0ol000000`2oXK_o00000;nQ^`02o`000080_j6k0_l00000
102nX[co0000o`00002nX[`2o`00000:0;jR_?l00000_Z:l0;jR_?l00000_Z:lo`00002mX[ko0000
0;fR_P;o00000P2mXkh2o`0000050;bT`?l0003o00000;bT`?l000000P2lXkl01_l00000^j:oo`00
002jXl;o00000;bWa@;o000000P0_jk9o`00002mZ<@0_JS4o`00002cU[So00000;6D^@?o000000<0
ZY2jo`000?l000000ol000001@2iY<Co0000o`000?l00000TVJL00;o000000<0S66Ko`000029Gi/0
0_l000000`24G9_o0000089KW006o`00000307YOZ?l00000NV6Y00;o000000<0OVR_o`000?l00000
0_l0000300000004o`00002OVLgo00000:ZXe@Co000000<0a<cPo`000032]ll01_l000000`2dW/7o
00000;NVb004o`0000030:FDa?l00000YY_:00?o000000D0[JK@o`000?l0003o00000;C1i002o`00
00070;;Al?l00000[/[_o`000000003o00000:Zmi`0<o`0000030:^kiOl00000ZkcV00?o000000<0
ZkgWo`000?l000002_l000001@2Z_NOo00000:Zliol00000000002d0oooo000F0?ooo`0300000?l0
0000oooo00D0oooo0_l000020<2V_`;o000000@0`:Bmo`000?l00000`:Bm0_l000001030Y;co0000
0<2T_030Y;`3o`0000050<2R^ol0003o00000<2R^ol000000P30X[/01_l00000`::ko`000030X[[o
00000<2R^P;o00000P30XKX01_l00000_j6jo`00002oXK[o00000;nQ^`;o000000X0_j6ko`00002o
XK/0_j6ko`00002oXK_o00000;jR_?l00000_Z:l0_l000020;jR_006o`00002nX[co00000;jR_?l0
0000_J>n1?l000020;fS_P;o000000@0_:>oo`000?l00000^j:o0_l000001`2mYL;o00000<2[aOl0
0000_jk9o`00002mZ<@00_l000020;>F^0;o00000P2]T;T2o`0000090<3Lk_l00000_jW4o`00002i
Y<Co000009IZWOl00000TVJL00;o000000<0S66Ko`000029Gi/00_l000000`24G9_o0000089KW002
o`00000607mKWol0003o000007YNYol00000NUnX0ol000000`1nJ:oo0000000000020000000508io
_ol00000UX_6o`00002OVLd01?l00000302oan3o0000o`00002jZ/Wo00000=OJf_l00000/Z36o`00
002`UK[o00000;BN`@Ko000000D0YIC4o`000?l0003o00000:fQc002o`0000030;W3h_l0003o0000
00Ko000000D0ZkcVo`000000003o00000:Zeh@03o`0000050:^gh_l0003o0000o`00002/^^@01_l0
00001@2[_>Ko0000o`000?l00000ZkcV00?o000000D0ZkcVo`000?l0003o00000:ZliP08o`000003
0000003oool0oooo00H0oooo0_l000040?ooo`03o`00003oool0oooo00<0oooo0_l000020?ooo`Go
00003`3oool001H0oooo00<000000?ooo`3oool0103oool01?l00000`:W3o`000030Y[l2o`00000:
0<2V_ol00000`:Jo0<2V_ol00000`:Joo`000030Y;co00000<2T_0;o00000P30Y;`00ol00000`:Bl
0<2T_002o`0000040<2R^ol0003o00000<2R^`;o000000D0`::ko`000030X[_o00000<2Q^P02o`00
00050;nQ^_l00000_j6j0;nQ^_l000000P2oXKX2o`0000040;nQ^ol0003o00000;nQ^`;o000000@0
_j6ko`00002oXK/0_j6k0ol000002P2nX[co00000;jR_02nX[co00000;jR_?l00000_Z:lo`00002m
Xkh2o`00000:0;fR_Ol00000_:6m0;bQ_Ol00000_JBoo`00002mYL;o00000<2[a@;o000000@0_ZK1
o`00002fUkP0]YNh1?l00000102]T;Wo0000o`000033c^<2o`0000070;nYa?l0003o0000o`00002F
JYgo0000099VW002o`00000308aQVol00000REnK00;o000000<0Q5bKo`000022Fi`00_l000000`1o
Fioo0000o`000004o`00000607YQZ@000000000000000?l00000PVjc1_l000000`2gc>[o00000;W3
h@02o`0000030;:M`_l00000^Z[900;o000000<0[i[2o`000?l000000P2`UKX01Ol00000e=OKo`00
0?l00000XHRi00?o000000D0ZiK0o`00002/VlKo00000;c4h004o`0000050;3Jm_l0003o0000o`00
002[^nD00ol00000102Z/]h00000o`00002//mh3o`0000050:fih_l0003o0000o`00002/_>D00ol0
00001@2/_>Ko0000o`000?l00000ZkcV00;o000000D0Zk_Vo`000?l0003o00000:^liP03o`000005
0:^li_l0003o0000o`00002Z_>H00ol000000`000000oooo0?ooo`050?ooo`04o`00003oool0oooo
o`0000P0oooo00Co00000?ooo`3ooooo00000P3oool01?l00000oooo0?ooool0000?0?ooo`005P3o
ool00`000000oooo0?ooo`030?ooo`;o000000@0`:W3o`000?l00000`:W30ol000001030Y[oo0000
o`000030Y[l2o`0000050<2V_ol00000`JJoo`000030Y;`00_l000001@30Y;co0000o`000031Y;co
00000080`JBl00Ko00000<6T_?l00000`::ko`000030X[/2o`000080`::k00?o00000<2R^_l00000
0_l000001@2oXK[o0000o`00002oXK[o00000080_j6j00Ko00000;nQ^_l00000_j6ko`00002oXK/2
o`000080_j6k00?o00000;nQ^ol000000_l000001@2nX[co00000;jR_02nX[co00000080_Z6l0_l0
0000102lXKgo0000o`00002mY;l2o`0000040<2X`_l00000_jFo0;nU_`;o000000@0]YNho`000?l0
0000/I:g0ol000001`33`]Wo0000o`000?l00000`jk4o`00002MLIl00_l00000102FJYgo0000099V
W02BIY`2o`00000608aQVol0003o000008IMVol00000Q5bK0ol000001@1oFioo0000o`00001nGjCo
000000<000001ol000000`2QYMWo00000:bihP02o`0000050;?0i?l00000ZY6lo`00002bWL800ol0
0000102_V/;o0000o`00002/S;@2o`0000040=C@eOl00000Wh:d09n2]0;o000000<0ZHnjo`00002[
U/001?l000000`2il_?o0000o`000002o`0000050:bji?l0003o0000o`00002Z[=T00ol000001@2/
/M/00000o`000?l00000[[SQ00?o000000@0[KcTo`000?l00000[KcU0ol000001@2/_>Go0000o`00
0?l00000Zk_U00?o000000<0Zk_Uo`000?l000001?l000001@2[^nKo0000o`000?l00000ZkcV00?o
000000<000000?ooo`3oool0103oool01?l00000oooo0?ooool000080?ooo`04o`00003oool0oooo
o`0000<0oooo00?o00000?ooo`3oool03`3oool001H0oooo00<00000o`00003oool00P3oool2o`00
00090;n]b?l00000_jg80;n]b?l00000_jg8o`000030ZL?o00000080`:W300Ko00000<2Y`_l00000
`:Joo`000031Y[l2o`000080`JJn00Ko00000<6V__l00000`JBlo`000031Y;`2o`000080`JBl00Ko
00000<6T_?l00000`J>lo`000030X[/2o`0000050<2R^_l00000`::j0<2R^_l000000P30X[X2o`00
00030;nQ^_l0003o00000080_j6j00Ko00000;nQ^_l00000_j6jo`00002oXK/2o`0000060;nQ^ol0
0000_j6k0;nQ^ol00000_j6k0ol000001@2nXKco0000o`00002mXKco00000080_Z>m00?o00000<2V
_ol000000_l000002@2oYKoo0000o`00002hV;Oo00000;BD]_l00000/I:go`0000020<:hd@;o0000
0P37/<<2o`00000309eaWol0003o00000080UVZM00Go0000099VW?l0003o000008aQV`02o`000003
08IMVol00000Q5bK00;o000000<0P5^Mo`000?l000000`0000000`1oHjSo0000081X[@02o`000005
08Qh^ol00000SXC4o`00002GTlh01ol000020:ZA_003o`000038^/go000000;o000000L0YhB^o`00
002/S;Co00000=C@eOl00000WGb_00Co00000P2YSkX00ol00000a<KKo`000009o`0000040:VXeOl0
003o00000:f[e@?o000000D00000o`000?l0003o00000:nlh`03o`0000030:jliOl0003o000000Co
000000D0[;[So`000?l0003o00000:bji003o`0000050:bki?l00000[;_To`00002[^nD02_l00000
0`000000oooo0?ooo`030?ooo`04o`00003oool0ooooo`0000P0oooo00Co00000?ooo`3ooooo0000
103oool00ol00000oooo0?ooo`0>0?ooo`005@3oool01?l0000000000?ooo`3oool2o`0000050;fc
d?l0003o0000o`00002o[LP00_l000001@2o[LSo0000o`000?l00000`:W300;o000000P0`:W2o`00
0?l00000`:W2o`000030ZL;o00000<6V_P;o000000D0`JJno`000?l00000`JJno`0000020<6V_P?o
000000D0`JBlo`000031Xk`0`J>lo`0000020<6S_0;o000000@0`::jo`000?l00000`::j0_l00000
1030X[[o00000<2R^P30X[X3o`0000050;nQ^_l00000_j6j0;nQ^_l000000P2oX[X2o`0000050;nQ
^ol0003o00000;nQ^ol000000P2oXK/00ol00000_Z6k0;jQ^`02o`0000050;jS_Ol0003o00000<2V
_ol000000P2oY;d00ol00000^YZg0;ZJ]`02o`000080]9Bf0_l000001@32^=7o0000o`000?l00000
ak3300?o000000L0WG6Oo`00002JKIko000009IZWOl00000TVJL00;o000000H0S66Ko`000?l00000
QUfKo`000024G9/2o`0000<000000_l00000201nGjCo0000o`000020J:go000008=_/ol00000R7Rk
1Ol000001@2EMJco000009]m/Ol00000XXJf00?o000000@0b;[=o`00002SO:So00000P2WQ:h3o`00
000609]gZ_l0003o00000:J4[ol00000Z8Ve0_l000000`38amWo0000o`000002o`0000050:bdgol0
0000YiW7o`00002XW/`00ol000001@2]Ym7o0000o`000?l00000/KGL00;o000000D000000;2lhol0
003o00000:nmi003o`0000050:jjhol00000[KSQo`00002]^N803_l000001`2/^nCo00000:bki?l0
0000Zk_Uo`00002[^nD00ol000000`000000oooo0?ooo`030?ooo`04o`00003oool0ooooo`0000P0
oooo00Ko00000?ooo`3ooooo00000?ooool000030?ooo`03o`00003oool0oooo00d0oooo00060?oo
o`Go00000`3oool2o`0000D0oooo00D00000o`000?l0003o00000;VifP02o`0000050;VifOl00000
_K?@o`00002m//l00_l000001@2m//oo00000;n]b?l00000_jg800;o000000<0_jg7o`000030ZL80
0_l000002P30ZL;o00000<2Y`P30ZL;o00000<2Y`_l00000`JJno`000031Y[h2o`000080`JJn00?o
00000<6U__l000000_l000001@31Xkco0000o`000031Xkco00000080`J>l00Ko00000<6S_?l00000
`::jo`000030X[X2o`000080`::j00?o00000<2R^_l000000_l000001@2oX[[o0000o`00002oX[[o
00000080_j:j0_l00000102oXK_o0000o`00002nXK/2o`0000040;nR_?l00000`JFm0<6U_@;o0000
00<0_jBmo`000?l000000P2jV[L00ol00000]YFfo`000002o`0000030<:bbol0003o00000080bK72
00Co00000:EhX_l0003o00000P2MLIl2o`00000309IZWOl0003o000000So00000P000005o`000003
07iOY?l00000Of>X00So000000D0SfjXo`00002EMJco000009]m/@03o`000080_JS40_l000020:=l
Z0Go000000<0VgNZo`000?l000000P2VQ:l2o`0000050<S7fOl0003o0000o`00002//M`00ol00000
102WVLOo0000o`00002]WlT3o`0000050;Bcf?l0003o0000o`00002d_^800_l000000`000000/KgS
o`000009o`0000070:fgh?l00000[[SPo`00002]^>;o00000:fihP03o`0000030:fjhol0003o0000
00So000000D0[;_To`000?l0003o0000000000040?ooo`04o`00003oool0ooooo`0000P0oooo00Ko
00000?ooo`3ooooo00000?ooool000030?ooo`03o`00003oool0oooo00d0oooo00070?ooo`04o`00
003oool0ooooo`000080oooo00Co00000?ooo`3ooooo0000103oool00`000000XlWdo`000003o`00
00050;;2i_l0003o0000o`00002i^MT00ol00000202m//oo0000o`00002m//oo00000;fbcol00000
_jg70_l000001@2o[LOo0000o`000?l00000`:W200;o000000P0`:W2o`000?l00000`:S2o`000031
Z<;o00000<6V_P;o000000D0`JFno`000031YKh0`JFno`0000020<6U_P;o000000<0`J>lo`000?l0
00000P31Xk`01_l00000`J>lo`000031Xkco00000<2R^P;o000000H0`::jo`000030X[/0`::ko`00
0030X[/3o`0000050;nR^_l0003o00000;nQ^_l000000P2oXKX01_l00000_j:ko`00002oX[co0000
0<6U_@;o000000@0`:>lo`00002kVkL0^i^g0ol00000202fUKKo00000<6]aP31[LKo00000=[Vg_l0
0000bK720_l000001@2UN:;o00000:5dXOl00000WG6O00Co000000@0TFVQo`000?l00000SFVT0_l0
0003000000;o000000<0Pg[1o`000021Q<d02?l000000`24H:7o000008MTX`02o`00000408m^Z?l0
0000UGF/09Ee[0;o000000<0/YNko`00002mZ<@00ol000020:=lZ004o`00003?^lKo000009UbY@Co
00000P2VQ:l01?l00000cLSEo`00002[ZMD3o`00000=0:B=_?l00000YI?2o`00002]V/Co00000:fO
bOl00000][?Fo`00002d/mSo00000;K0h@02o`00000;0;Boh_l0003o00000000002`^=oo00000:nd
g?l00000[kKNo`00002_]=d02_l000001@2^^>7o0000o`000?l00000[KWR00?o000000D0[K[So`00
0?l0003o00000:bjh`03o`0000040:bji?l0003o0000000000@0oooo0_l0000:0?ooo`;o00000`3o
ool3o`000100oooo00080?ooo`03o`00003oool0oooo0080oooo00Co00000?ooo`3ooooo0000103o
ool00`00003o0000o`000004o`0000050:?:m?l0003o0000o`00002b`^D00ol00000202j^MWo0000
o`00002j^MWo00000;fbcol00000_[;?0_l000001@2n//ko00000;n]aol00000_jg700;o000000D0
`:g7o`000030Z<;o00000<6X`P02o`000080`JS20_l000001031YKko0000o`000031YKh2o`000004
0<6U__l00000`JFn0<6U_P?o000000D0`J>lo`000031Xk`0`J>lo`0000020<6S_0;o000000D0`::k
o`000?l00000`::ko`0000020<2R^`03o`000030X[X0`::j00;o000000@0_j6jo`000?l00000_j:k
0_l000001031Y;co00000<6S^`31Xk/2o`0000030;^K]ol0003o00000080^9Nf0_l000002`31[LKo
00000=SHf?l00000b[71o`00002XO:Co00000:EhX_l00000XGBQ00Co000000<0U6^Po`00002AJJ40
0_l000030000000408Q[Zol00000Qfj`08M^/0;o000000<0Pg[1o`000?l000001Ol000001P20G9oo
0000o`000024H:7o000008MTX`;o000000<0SfjXo`000?l000000_l000001P2bUk_o0000o`00002K
Kioo000009meX`?o000000L0ck_6o`000?l0003o00000:=iYOl00000Y7jZ00;o000000<0dLWBo`00
0?l000000_l000000`2RQkOo00000:B=_003o`0000050:fJa?l0003o0000o`00002f/mH00_l00000
0`2i`^7o00000;K0hP03o`0000030;6ggP00003o000000Co000000L0/;?Ko`00002`]=_o00000:ne
gOl00000/;KN00?o000000D0[kSOo`000?l0003o00000:jhh@02o`0000050:jhhOl0003o0000o`00
002^^N800ol000001`2]^N;o0000o`000?l00000[K[So`0000000000:03oool000T0oooo00Go0000
0?ooo`3oool0ooooo`0000020?ooo`03o`00003oool0oooo0080oooo00@000000?ooo`3oool0oooo
2?l000001@2Tb_Co0000o`000?l00000/l;U00Co000000D0^[WHo`00002j^MSo00000;jbcP02o`00
00050;jbc_l00000_[;>o`000030[LL00_l000001@30[LOo00000<2]aol00000`JS200;o000000X0
`JS1o`000031Z<40`JS1o`000031Z<7o00000<6U__l00000`JFn0_l000020<6U_P03o`000031YKko
000000;o000000<0`J>lo`000?l000000_l000020<6S_0;o000000@0`::ko`000?l00000`::j0_l0
00001P30X[_o00000<2S^`30Xk_o00000<6T_0?o000000P0`J>ko`000?l00000_Ibgo`00002jVKKo
00000;RG]P;o000000D0`J[3o`00003Hf=So00000<Za`@02o`000080Z7bT1?l000001@2IKZ3o0000
o`00002DJj3o000000<0000000Go000008eYY?l0003o000008Q[Z`07o`00000308ADT?l0003o0000
00Go000000<0Q62Qo`000027I:<01?l000000`2OO:co00000:R8/`03o`000080VfnO0_l000020<Z^
_P;o000000<0XGFRo`00002SNJD00ol000001P3AbM;o0000o`00002OO:co00000:61/@?o000000D0
[9:ko`000?l0003o00000;^bd@03o`0000030;c6h_l0003o000000;o000000T0/kGJo`000?l0003o
00000;2`e`000000/JoFo`00002`/MT02?l000001@2a]]co0000o`000?l00000/;ON00?o000000D0
[kOOo`000?l0003o00000:jhh003o`0000030:jihOl0003o000000Co000000<0[KWRo`0000000000
9`3oool000H0oooo00Go00000?ooo`3oool0ooooo`0000020?ooo`04o`00003oool0ooooo`0000@0
oooo00<000000?ooo`3oool01@3oool;o`0000050;?2iOl0003o0000o`00002j^MP00_l000001@2j
^MSo0000o`000?l00000_[;>00;o000000D0_[;>o`000?l0003o00000<2]a`02o`0000050<2]a_l0
003o0000o`000031Z<400_l000002031Z<7o0000o`000031Z<7o00000<6X`Ol00000`JFn0_l00000
2P31YKko00000<6U_P31YKko00000<6U__l00000`JFno`000031Xk`2o`00000:0<6S_?l00000`J>l
0<6S_?l00000`:>lo`000030X[_o00000<2S^`;o000000T0`JBlo`000031Xk/0`J>ko`00002nW[So
00000;fL]ol000000P2jVKH00ol00000`JS1o`000003o`0000040<Za`Ol0003o0000o`000080Z7bT
0_l00000102LL:3o000009U^X?l00003000000;o000000<0SfVRo`00002=JJ@01Ol000001P26EHoo
0000o`000024E93o000008ADT0;o000000<0Q5JBo`000025F9@01ol00000102HLZGo000009ml[02O
O:`4o`000080VfnO0_l000002@3:[[ko0000o`000?l00000XGFRo`00002SNJGo00000=K9cP04o`00
0080Wgb/0_l000001`2/S[Ko00000:bB^ol00000_[?@o`00002k/]401?l000000`2ja>;o00000;>c
f003o`0000050;6]e?l0003o0000o`00000000000_l000001`2b/MOo00000;>cf?l00000/[CJo`00
002b]M/00ol00000102a]]co0000o`00002a]M`3o`0000050;2fgOl0003o0000o`00002_]ml00ol0
00000`2^^>3o00000:jhh005o`0000030000003oool0oooo02D0oooo00060?ooo`05o`00003oool0
oooo0?ooool000000P3oool01?l00000oooo0?ooool000040?ooo`030000003oool0oooo00X0oooo
3?l000001`2c`^Go00000;?2iOl00000^kWHo`00002k^MP00_l000001@2k^MSo00000;jbc_l00000
_[;>00;o000000D0_[;=o`000030[<Ko00000<2/aP02o`0000050<2/a_l00000`JS1o`000031Z<40
0_l000001@31Z<7o0000o`000?l00000`JFn00;o000000<0`JFno`000031YKh00_l000020<6U_P;o
000000@0`J>lo`000?l00000`:>l0_l000001031Y;co00000<6U_@31YKd2o`0000030<6S^ol0003o
00000080_Yjh00?o00000;^K]ol000000_l000000`31Z<7o0000o`0000020<Z``@04o`00002^Q:Oo
00000:^0Y@Co000000L0W72P000000000000000009I/X?l00000U6^P00Oo000000@0REN@o`000?l0
0000QUF?0_l000000`24E93o000008ADT002o`00000308AFT_l00000QERD00;o000000<0RUjIo`00
002=Hi`00_l00000102HLZGo000009ml[02OO:`2o`000080UfZL00Co000009]_Wol00000`j:g1?l0
00020:5eXPCo000000<0W7>To`000?l000000P2OO:`2o`000080[8jf0_l000000`2n/m3o0000o`00
0007o`0000050;6WcOl00000/J[Ao`00002bZ]000ol000001@00003o0000o`000?l00000/k?H00Co
000000D0/k?Io`00002b]=_o00000;:dfP03o`0000050;6eg?l0003o0000o`00002`]]d02?l00000
1`2_]mko00000:nhh?l00000[kSPo`00000000009P3oool000L0oooo0ol000040?ooo`;o0000103o
ool00`000000oooo0?ooo`0A0?ooo`_o000000D0]<;To`000?l0003o00000;^if002o`0000050;^i
eol00000^kWGo`00002n//d00_l000001@2n//go00000;nbcOl00000`:c600;o000000X0`:c6o`00
0030[<H0`:c6o`000030[<Ko00000<6X`Ol00000`JS10_l000001@31Z<7o00000<6X`Ol00000`JFn
00;o000000X0`JFno`000031YKh0`JFno`000031Y[ko00000<6T_?l00000`JFm0_l000001031Y;co
00000;nP^@2oX;T3o`0000080;^K]ol00000`JO00<6W`?l00000dLG?o`00003:/<42o`0000050:j4
Yol00000Zh2Uo`00002QMZ800`0000001?l00000VFjPo`00002FK:04o`000006091MTOl0003o0000
08]IT?l00000REN@0_l000001P26EHoo0000o`000024E93o000008ADT0;o000000<0Q5JBo`000025
F9@00_l000000`2:GYWo000008eSW002o`000080V7:U0ol000000`2DIIWo000009MZW003o`000009
0<>R]ol00000WFjKo`00002OLIko00000:5eX_l00000f/W900;o000000<0W7>To`00002MMjP00ol0
00001@2[R[;o0000o`000?l00000`KG>00;o000000T0`]7Uo`00002d[=3o00000;B^dol00000/J?:
o`00002aYld01?l000001@2f[<oo0000o`0000000000][7D00?o000000<0];?Go`00002d/]L01_l0
00001@2c/]So0000o`000?l00000/[?J00?o000000L0/KGKo`00002a]M_o00000;2fgOl00000/;KM
00Ko000000<0[kONo`00000000009@3oool001@0oooo00<000000?ooo`3oool05P3oool;o`000005
0;C2i?l0003o0000o`00002k^ML00_l000001@2k^MOo0000o`000?l00000_k;=00;o000000D0_k;=
o`000?l0003o00000<2/aP02o`00000:0<2/a_l0003o00000<2/a_l00000`:c6o`000031Z<7o0000
0<6X`@;o00000P31Z<42o`0000040<6U__l0003o00000<6V_P;o000000L0`JNno`000031Y[ko0000
0<6T_?l00000_j2i00;o00000P2lWKT2o`00000:0<6W`?l00000c/3=o`00003:/L7o00000;68Z_l0
0000[XBWo`0000<000000_l0000209a`X0Go000000L0TUnBo`00002@GI7o000008iKTOl00000ReV@
00?o000000H0QUF?o`000?l00000Q5B@o`000024E902o`00000308AFT_l00000QERD00;o000000L0
RUjIo`00002=Hico0000099YX?l00000V7:U00?o000000@0U6FIo`00002GJYco00000P2lU[02o`00
000309e^Vol00000Wg6N00;o000000D0g/W5o`00002JKj3o000009acY003o`000080ZhJ^0_l00000
1036^<go0000o`000036enL3o`0000050;B/d?l0003o0000o`00002aXlX00_l000002`2cY<Wo0000
0;N[cOl00000]Zc?o`00002g/=;o000000000?l00000][;E00;o000000L0]K7Eo`00002e/=Co0000
0;Bae_l00000];7F00?o000000D0/k;Ho`000?l0003o00000;:cfP06o`0000070;6efol00000/KGK
o`00002`]]go00000;2fg@03o`0000030000003oool0oooo02<0oooo000D0?ooo`030000003oool0
oooo01P0oooo3ol000001`2d`^Co00000;G2i?l00000^kWGo`00002l^ML00_l000001@2l^MOo0000
0;nbcOl00000_k;=00;o000000D0_k;=o`000030[<Ko00000<2/aP02o`0000050<2/a_l00000`:c6
o`000031Z<400_l000002P31Z<7o00000<6X`@31Z<7o00000<6Y`_l00000`JNno`000031Y[h2o`00
00050;nS_?l00000_Z6ko`00002lWKT01?l000001P3>`<go0000o`00003:/L7o00000;68ZP<00000
00L0Y7VTo`00002QMZ;o000009icXOl00000W72P00;o000000<0V6FDo`000?l000000P2BGi82o`00
000308iKTOl00000ReV@00;o000000<0QeJ?o`000026EHl00ol000001P24E93o0000o`000024EY;o
000008EHU0;o00000P2:GYT00ol00000SF>Lo`000003o`000080TF:F1?l000020;bF/0;o00000P2M
KY/2o`0000030=k9aOl0003o00000080VVnP0_l00000202[Pj[o00000:^6[P2[QZko00000<^lc?l0
0000doGV0_l00000202cY<Wo00000;BXcOl00000/9_2o`00002aWlKo00000P2dX/H2o`00000:0;N[
cOl0003o00000;V_d?l00000^;3Ao`000000003o00000;J`d`?o000000<0]K3Do`000?l000000_l0
00001@2e[m?o0000o`000?l00000];7F00?o000000D0/k;Ho`00002c/]So00000;:cfP08o`000005
0;6dfol0003o0000o`0000000000903oool001@0oooo00<00000o`00003oool06@3oool00ol00000
WL7bo`00000@o`0000050;G2i?l00000]L;So`00002l^ML00_l000001@2l^MOo00000;bie_l00000
_k;=00;o000000L0_k;=o`00002o//go00000<2/a_l00000`:c600;o00000P30[<H2o`0000040<6X
`Ol0003o00000<6Y`P;o000000L0`JW1o`000030Y[oo00000;nS_?l00000_Z6k00;o000000D0`JW1
o`00003<_L`0c;g<o`0000020<Va``04o`000000000000000;68ZP;o000000@0Y7VTo`00002QMZ80
XGJR1Ol000001@2HIICo000009ERTol00000TUnB00;o000000<0SU^Ao`00002;FI000_l000000`27
EXoo000008IES`02o`00000408ADT?l00000Q5B@o`000080Q5JB00Oo000008EHU?l0003o000008YN
VOl00000SF>L00?o000000<0SejDo`00002AHYH00_l000020;F;Z@;o000000@0W6^Ho`00002MKY/0
WFjK1?l000000`2IK9go000009Y_X002o`000080Zh>Z1_l000000`2bWlGo00000;>Tb@03o`000005
0;2K`_l0003o0000o`00002dX/H01?l000001`2j[loo0000o`000?l00000^;3Ao`00000000000_l0
00002`2g[M3o0000o`000?l00000]ZkAo`00002f[]7o00000;F_dol00000]K3C00?o000000@0];7F
o`000?l00000];7F0ol000001`2c/]So00000;>bf?l00000/[?Io`00002b/mT00ol00000102a]=_o
0000o`000000000S0?ooo`00503oool00`000000oooo0?ooo`0J0?ooo`03o`00002Q`Noo000000;o
000000D0WL7bo`000?l0003o000009W2m00=o`0000040;G2hol0003o00000;K2h`?o000000D0_;WF
o`000?l0003o00000;nbc@02o`0000050;nacOl00000_k7=o`000030[<H00_l000000`31[LKo0000
0<6]aP02o`0000050<6]a_l0003o0000o`000030Y[l00_l000001`2nY;oo00000<6/a?l00000`JW1
o`00003<_L`00_l00003000000030;>=[Ol0003o000000;o00000P2TNJ@00ol00000XGJRo`000004
o`000080V6FD0_l000001P2BGi;o0000o`00002>Fi7o000008]IT0;o000000<0QeJ?o`000026EHl0
0_l000000`24E93o000008ADT002o`00000308AFT_l00000QERD00;o000000T0RUjIo`000?l0003o
00000=GKg?l00000SejDo`00002AHYH00_l000020;F;Z@;o000000P0W6^Ho`00002MKY/0WFjKo`00
003QbL3o000009QYVPGo00000P2[PjX00ol00000d/?<o`000003o`0000040;:OaOl0003o00000:jB
^P?o000000L0]9boo`000?l0003o00000;VXb?l00000_:o=00;o000000/0^k3>o`000?l0003o0000
0;R^col000000000o`00002g[M3o00000;J/c`03o`0000030;J^dOl0003o000000;o000000D0]ZkA
o`00002e/=Co00000;F`e003o`0000030;Bae_l0003o000000Ko000000L0/k;Go`000?l0003o0000
0;:cfOl00000000002<0oooo000D0?ooo`030000003oool0oooo01/0oooo00?o00000:?0k_l00000
0_l000001@2Q`>oo0000o`000?l00000WL7a00?o000000<0VL;do`000?l000002ol00000102f`^?o
0000o`00002f`^<3o`0000050;bie_l0003o0000o`00002o/Ld00_l000002P2o//go0000o`00002o
//go00000;nbc?l00000`Jg6o`000030Z/@2o`0000050;jYa?l00000_ZBoo`000031[<@00_l00000
1@3:_<d0000000000000003o00000080]Y6a0_l000001@2XP:So00000:IlY_l00000Y7VT00Co0000
00D0WF^Ho`00002JJ9Ko000009QUU002o`000006099OT_l0003o000008iKTOl00000ReV@0_l00000
0`27EXoo000008IES`02o`00000308ADT?l00000Q5B@00;o000000<0Q5JBo`000025F9@01?l00002
0<>hc`;o000000<0SejDo`00002AHYH00_l000020;F;Z@;o00000P2LJiP01?l00000WFjKo`000?l0
000209QYVP;o000000<0ZWjTo`00002ZPJL00_l00000403Jc<co0000o`00002^UKgo00000;2K`Ol0
0000[Hjfo`00002^T[[o00000;BJ_?l00000]9boo`00002kZ<H2o`0000070;j`c?l00000_;3=o`00
002k/<ko00000;V/c@03o`0000030;N/c@00003o000000;o000000T0^:_=o`000?l0003o00000;N]
col00000]jg?o`00002f[]401?l000002`2f[m;o0000o`000?l00000]K3Do`00002e/=?o00000;Ba
e_l00000];7F00?o000000<0/k;Go`000?l000000_l000000`000000oooo0?ooo`0P0?ooo`004`3o
ool00`00003o0000o`00000M0?oooako000000D0Z<_bo`000?l0003o00000;K2h`03o`0000040;bi
e_l0003o00000;fieP?o000000P0_k;<o`000?l00000_k3;o`00002n[l_o00000;jYa0;o000000<0
`Jo9o`00000000000P0000001037]/Wo00000;NF]_l000020;JA/@;o00000P2XP:P5o`00000709m^
V_l00000WF^Ho`00002JJ9Ko000009QUU002o`000006099OT_l0003o000008iKTOl00000ReV@0_l0
00000`27EXoo000008IES`02o`00000308ADT?l00000Q5B@00;o000000<0Q5JBo`000025F9@00_l0
00000`2bVl3o00000<>hc`03o`00000508mNU?l00000TF:Fo`00002^PJ@01?l0000209a[V006o`00
002MKY_o000009MWV?l00000V6VJ0_l000001@2ZOZCo00000:Z1Yol00000f/c<00?o000000@0[YFm
o`000?l0003o00000P2]S[H2o`00000:0;BJ_?l0003o00000;fXaOl00000`;7;o`00002n/<co0000
0;b`c@Co000000/0^JS9o`000?l0003o00000;RYbP000000^:[;o`00002hZlgo00000;R/c@03o`00
000:0;N]col0003o00000;N]d?l00000]jg@o`00002f[m;o00000;J_dP?o000000<0]K3Co`000?l0
00000_l000002P2e/=?o0000o`000?l00000];7Fo`00002d/MGo00000?ooo`00000Q0?ooo`001P3o
ool3o`0000<0oooo0_l000050?ooo`030000003oool0oooo01l0oooo0ol000001@2V_^_o0000o`00
0?l00000YKo/00?o000000D0Xko]o`000?l0003o00000:70k`0Ao`0000050:W<l_l0003o0000o`00
002g`^<00_l000001@2g`^;o00000;fie_l00000_;OD00?o000000@0_Zo;o`000?l00000_kC?0`00
00000ol00000aK[@0<Fjd002o`000080]iJf1?l000020:R0Z0;o000000<0a]CUo`000?l000000P2O
KYX2o`00000309YXU_l00000V6FD00;o000000H0TUnBo`000?l00000SU^Ao`00002;FI02o`000003
08MFSol00000QUF?00;o000000<0Q5B@o`000024E9000_l000000`24EY;o0000o`000002o`000080
/Y_000Go000008aJTOl0003o000008mNU003o`0000070:j1Y?l00000VFJDo`00002JJ9Ko000009a[
V003o`00000309MWV?l00000V6VJ00;o00000P2ZOZ@3o`0000070:R9]?l00000Zhnio`00002YQZko
00000:^:/P03o`0000070;FH^Ol00000_jW4o`00002mZ<Go00000<2ab`04o`0000070;^ZbOl00000
^JO7o`00002iZ<Wo00000;VXb002o`00000;0000002hZ/_o0000o`00002iZl_o00000;V[c?l00000
^:c=o`00002h[<h00ol000000`2g[M3o0000o`000002o`00000;0;N]d?l0003o0000o`00002f[m;o
00000;J_d_l00000]K3Co`00002e/=<00ol00000102d/MGo0000o`000000000Q0?ooo`001`3oool0
1Ol00000oooo0?ooo`3ooooo00000080oooo00?o00000?ooo`3oool00P3oool00`000000oooo0?oo
o`0P0?ooo`?o000000D0YkkZo`000?l0003o00000:Jnj`03o`0000050:Fok?l0003o0000o`00002S
_nd00ol000001@2Q`>oo0000o`000?l00000W/7a00?o000000<0VL;do`000?l000001ol000000`2Z
bo7o0000o`000002o`0000060;O0hOl00000][oQo`00002l]]Co00000`0000001@30a]oo0000o`00
0?l00000aK[@00;o000000L0^9blo`000?l0003o00000:f9/?l00000ZhF/00?o000000@0`lcQo`00
0?l0003o00000P2OKYX2o`00000309YXU_l00000V6FD00co000000H0QUF?o`000?l00000Q5B@o`00
0024E904o`00000309YgZOl00000Y8Fc00?o000000D0S5ZAo`000?l00000SejDo`0000020:QiW`;o
000000D0VFJDo`00002JJ9Ko000009a[V003o`00000;09MWV?l0003o0000o`00002YO:;o00000:Yn
Y?l00000i=[<o`00002XRK@00ol000020:V6[P;o00000P2eU[L2o`0000030;nYa?l0003o000000;o
000000L0_k7;o`00002kZLOo00000;^ZbOl00000^JO700;o000000L0^JK6o`00002jYlOo00000;VX
b0000000^ZW900?o000000<0^J_<o`000?l000000_l000002`2iZlco0000o`000?l00000^:c>o`00
002h[<ko00000;N]d?l00000]jg@00So000000P0]ZoBo`000?l0003o00000;F`dol00000oooo0000
0200oooo00040?ooo`Go00000P3oool01?l00000oooo0?ooool000040?ooo`030000003oool0oooo
0280oooo0_l000001@2X_^Wo0000o`000?l00000YkkZ00?o000000D0Y[k[o`000?l0003o00000:Fo
k003o`0000050:>okOl0003o0000o`00002Q`>l00ol000001@2N`O7o0000o`000?l00000V/;c00[o
000000<0Z/W`o`00000000000P0000002?l00000^<gZo`000?l00000^lOTo`000031`=So00000P2h
Y<D2o`0000030:j?]ol00000[HV`00?o000000P0`LOOo`000?l00000XgJQo`00002QLYgo000009m^
VP;o000000<0VVRFo`000?l000000_l000001P2<FY7o0000o`00002:FI7o000008UHT@;o000000<0
R5RBo`000?l000001ol000002@2DK:?o000009YgZOl00000Y8Fco`00002;F93o000008aJT@04o`00
0080Z7VO0_l0000209UVU0;o000000T0W6^Ho`000?l0003o000009MWV?l00000ZGZPo`00002YO:80
1?l000001@2TPk3o0000o`00002XPZ_o00000080ZHJ^0_l000001`2eU[Oo0000o`000032Zl?o0000
0<Jgc?l000000P31///2o`00000:0;^Yaol0003o00000;ZUaOl00000^ZG4o`00002iY/Ko00000;ZW
a`;o000000<0^jW70000002kZLP00ol000001`2jZ/[o00000;ZZb_l00000^J_<o`00002iZl`00ol0
00000`2h[<ko0000o`000002o`0000070;R/c_l00000^:g>o`00002g[]3o00000;N^d003o`000003
0;J_d_l0003o000000;o000000<0oooo0000003oool01`3oool2o`0000@0oooo00?o00000?ooo`3o
ool00`3oool2o`0000@0oooo0ol000020?ooo`00103oool01?l00000oooo0?ooool000030?ooo`04
o`00003oool0ooooo`0000@0oooo00<00000o`00003oool08`3oool2o`0000050:RnjOl0003o0000
o`00002X_^T00ol000001@2W_^[o0000o`000?l00000Y[k[01So00000`000005o`0000030:k@l_l0
003o000000?o000000@0^:C5o`000?l0003o00000P2^SkL2o`00000:0;g6hOl0003o00000:AjYOl0
0000XgJQo`00002QLYgo000009m^VPCo000000@0SefBo`000?l00000S5ZA0_l000000`2:FI7o0000
08UHT@02o`00000308QHT_l00000R5VC00;o000000<0RUfGo`00002<H9X00_l00000102DK:?o0000
09YgZ@2JMjT2o`00000308]HT?l00000S5ZA00;o000000@0Xg:Ko`00002XNIl0Z7VO0_l0000209UV
U0?o000000P0ilRgo`000?l00000UfNHo`00002YNZ3o00000:UlXP;o000000<0XGf/o`000?l00000
0_l000020:R2Z`?o000000<0]IBeo`000035[/@00_l000001039_<ko0000o`000031///2o`000004
0;bXa_l00000^ZC30;ZT``;o000000<0^ZG4o`000?l000000_l000001P2kZ<Ko0000o`000?l00000
0000o`000080^jW80_l000000`2jZ/[o0000o`000002o`0000060;VZb_l0003o0000o`00002iZlco
00000P2iZl`2o`0000030;R]c_l0003o000000;o000000L0^:g>o`000?l0003o00000;N^d?l00000
]jk@00;o000000<000000?ooo`3oool01@3oool01?l00000oooo0?ooool000080?ooo`04o`00003o
ool0ooooo`0000@0oooo00?o00000?ooo`3oool00@3oool000D0oooo00?o00000?ooool000000`3o
ool01?l00000oooo0?ooool000040?ooo`030000003oool0oooo02@0oooo0_l000001@2Y_NWo0000
o`000?l00000Z;kY00?o000000<0Z;kYo`000?l000000ol000001@2W_^[o0000o`000?l00000Y[k[
00?o000000D0YKo/o`000?l0003o00000:Bok@03o`0000030:70kol0003o000000<000002Ol00000
0`2Pa?;o0000o`000003o`0000030:fObOl00000[YNn00?o000000@0^LWVo`000?l0003o00000P2T
NZD2o`0000030:5bWOl0003o000000;o000000<0T5jCo`00002?GI800_l000001P2<FY7o0000o`00
002:FI7o000008UHT@;o000000<0R5RBo`000028FI<00_l000000`2:GIOo000008aPVP02o`000080
U6bS1?l000000`2;F93o000008aJT@02o`0000040:=bVol00000Z7VO0:QiW`;o00000P2IIY@2o`00
00030>O8]ol0003o000000?o00000P2YNZ03o`0000030:5m[?l00000Y7^U00;o00000P2XPZ/00ol0
0000]Y>co`000002o`0000030<F^a?l00000bKc>00;o000000<0`[?;o`00002lYlD00ol000000`2j
Y<?o0000o`000002o`00000;0;bVa?l00000_:S5o`00002kZ<Ko00000;bYaol000000000o`00002k
ZLP00_l000002@2jZLSo00000;ZYb?l00000^ZW8o`00002iZ/[o00000;VZbP03o`00000<0;V[c?l0
003o00000;V/c?l00000^Jc<o`00002i[<co00000;R]c_l00000^:g>0ol000001@2g[]3o0000o`00
003oool0000000H0oooo00Co00000?ooo`3ooooo0000203oool01Ol00000oooo0?ooool00000oooo
00Go00000P3oool000H0oooo0_l000030?ooo`04o`00003oool0ooooo`0000@0oooo00<000000?oo
o`3oool09@3oool2o`0000050:Vmj?l0003o0000o`00002Y_NT01Ol000001@2X_^Wo0000o`000?l0
0000Z;kY00?o000000D0YkkZo`000?l0003o00000:Jnj`03o`0000040:Fok?l0003o0000o`000080
00000_l000001@2R`>ko0000o`000?l00000Wko_00Wo000000<0Z:[Io`000?l000001_l000001@2T
Q[?o00000:EoZol00000Y7ZU00Co000000H0TV:Go`000?l00000T5jCo`00002?GI82o`00000608aJ
TOl0003o000008YITOl00000RERA0_l000000`28F9;o000008QIT`02o`00000908YMUol00000S62J
o`00002?IIgo000009A/Xol00000REJ>00;o000000<0ReR@o`000?l000000_l000020:=bV`?o0000
00<0V6BCo`00002IIY@00ol000001@2EHiCo0000o`00002YNIko00000080ZGZP00?o000009ehZ02M
N:P00_l000000`2TNjGo00000:InZ003o`0000030;JC/ol00000bK?500;o000000<0c/CAo`000034
]L`00_l000000`2kY/Co00000;VQ`003o`0000070;^S`Ol00000_:K3o`00002lY/Co00000;bXa@02
o`0000070;bYa_l00000_:W6o`000000003o00000;^Ya`02o`0000040;^Yaol0003o00000;ZYb0;o
000000L0^ZW9o`00002jZ/Wo00000;V[b_l00000^J_;00;o000000@0^J_;o`000?l00000^Jc<0_l0
00000`2i[<go00000;V/c@03o`0000050;R]c_l00000oooo0?ooo`0000001@3oool01?l00000oooo
0?ooool000080?ooo`06o`00003oool0ooooo`00003ooooo00000P3oool00ol00000oooo0?ooo`01
0?ooo`001`3oool00ol00000oooo0?ooo`020?ooo`;o0000103oool00`00003o00000?ooo`0W0?oo
o`;o000000<0ZKgXo`000?l000000ol000001@2Y_NSo0000o`000?l00000ZKgX00?o000000D0Z;kY
o`000?l0003o00000:Rnj@03o`0000040:Nnj_l0003o0000o`0000<0000000?o00000:Fojol00000
2_l000000`2J`O?o0000o`000008o`000080ViO?0_l000000`2TQ[?o0000o`000003o`000003099T
VOl00000TV:G00;o000000<0T5jCo`00002?GI800_l000001P2<FY7o0000o`00002:FI7o000008UH
T@;o000000<0R5RBo`000028FI<00_l000001@2:GIOo000008aPV_l00000SfFM00?o000000H0REJ>
o`000?l00000ReR@o`00002JIiH2o`000080Xg:K0ol000001`2HI9?o000009UVU?l00000jLRdo`00
002EHi@00_l000020:UiWP03o`00002YNZ3o000000Co00000P2TNjD2o`000080]Y>b0ol000000`3C
cmKo0000o`000002o`00000;0;ZT`ol0003o0000o`00002iXL3o00000;^S`?l00000^j?1o`00002l
Y/<00_l000001`2mZ<Co00000;fYaOl00000_:W6o`00002lZLH00_l000000`00003o00000;bXaP03
o`0000040;^Yaol00000^jW70;^Ya`;o000000<0^Z[9o`000?l000000_l000001P2jZ/Wo0000o`00
0?l00000^J_;o`000080^J_;0_l000000`2i[<go00000;V/c@03o`000080oooo00<000000?ooo`3o
ool00`3oool01?l00000oooo0?ooool000080?ooo`04o`00003oool0ooooo`000080oooo00?o0000
0?ooool000000`3oool00180oooo00<000000?ooo`3oool0:03oool5o`0000040:Vmj?l0003o0000
0:Vmj0?o000000D0ZKgXo`000?l0003o00000:Vmj003o`0000040:RnjOl0003o0000o`0000<00000
1ol000001@2V_^[o0000o`000?l00000Y;o/00Oo000000D0X/Cao`000?l0003o00000:JdhP02o`00
000306^1eol0003o000000Go000000H0TVVPo`000?l00000TVBIo`00002BHYL2o`000003091NTol0
0000SefB00;o000000H0S5ZAo`000?l00000RUVAo`000029F942o`00000708QHT_l00000R5VCo`00
0029FYGo000008YMU`02o`00000508mUWOl00000REJ>o`000029EXh01?l000002`2JIiKo000009i/
V?l00000Xg:Ko`00002FHY7o000009QTTol00000VFJD00?o000000<0UF>Do`000?l000000P2YNIh4
o`0000050:5eXOl00000XgRSo`00002TNjD00_l00000102fTk;o0000o`00003>^lP2o`0000060<Fk
d?l00000^J?2o`00002jY<?o00000P2iWkh2o`0000050;^S`?l0003o00000;fV`_l000000P2nZL@2
o`0000030;fYaOl0003o000000;o000000L0_:S5o`00002lZ<D000000;bXa_l00000_:S600?o0000
00<0^jW7o`000?l000000_l000001`2kZLSo00000;^Zb?l00000^Z[9o`00002jZ/T00ol000000`2i
Zl_o0000o`000002o`0000060;V[bol00000^Jc<o`00002i[<go00000P3oool00`000000oooo0?oo
o`020?ooo`04o`00003oool0ooooo`0000P0oooo00Co00000?ooo`3ooooo00000`3oool2o`0000<0
oooo000B0?ooo`030000003oool0oooo02T0oooo00?o00000:Vmj?l000000_l00000102Y_NSo0000
o`00002Y_NP3o`0000050:Vmj?l0003o0000o`00002Y_NP00ol00003000000Co000000@0Z;gYo`00
0?l00000Z;kY0ol000001@2W_^[o0000o`000?l00000Y[o/00?o000000D0Y/7/o`000?l0003o0000
0:NiiP03o`0000050:6[g_l0003o0000o`00001nNlD00_l00000102>L:go0000o`00002BJJ02o`00
0003099TVOl00000TV:G00;o000000<0T5jCo`00002?GI800_l000002P2<FY7o0000o`00002:FI7o
000008UHTOl00000RERAo`000028F982o`00000308UJUOl00000RUfG00Co000000<0REJ>o`000029
EXh00_l00000202GI9?o000009YWU_l00000WVbHo`00002SLY_o00000P2FHY42o`00000509UVU?l0
003o0000o`00002EHi@00_l000020:UiWP;o000000D0X7:Oo`00002QMJ7o00000:=hX`03o`000003
0;NC/Ol00000e/S<00Co000000<0aK_@o`00002iXl800ol000001@2iWkko0000o`00002kX[oo0000
0080_ZO20_l000000`2nZLCo0000o`000002o`00000<0;fYaOl00000_JS5o`00002lZ<Go00000;bX
a@00003o00000;bXaOl00000_:S60ol00000102lZLOo00000;bYa`2lZLL2o`0000030;^Zb?l0003o
000000;o000000H0^j[8o`000?l0003o00000;Z[b_l000020;Z[bP;o000000<0^Jc<o`000?l00000
0ol000000`000000oooo0?ooo`030?ooo`;o00002P3oool2o`0000D0oooo00?o00000?ooo`3oool0
0@3oool00180oooo00<000000?ooo`3oool0:P3oool00ol00000ZKgXo`000002o`0000040:Vmj?l0
003o00000:Vmj0?o000000@0ZKgXo`000?l0003o00000`000004o`0000030:Vmj?l0003o000000Co
000000D0Z;kYo`000?l0003o00000:RnjP03o`0000050:Roj_l0003o0000o`00002X^nL00ol00000
0`2U]>Co0000o`000007o`00000408i`[Ol0003o0000099YX0;o000000<0TVBIo`00002BHYL00_l0
00000`2@GY?o000008mMTP02o`00000508aJTOl00000ReVAo`00002:FI400_l000000`29F97o0000
08QHTP02o`00000308UJUOl00000RUfG00Co000000<0REJ>o`000029EXh00_l000001@2GI9?o0000
09YWU_l00000WVbH00?o00000P2FHY43o`0000030>_7/?l0003o000000;o000000<0ZGRLo`00002Y
NIh00_l00000102PLYoo00000:5eX@2QMJ42o`000080^IBa0ol000000`3IlN7o00000<Fnd`02o`00
00060;NP`Ol00000]ibmo`00002hW[go00000P2kX[l2o`0000030;jW`_l0003o000000;o000000L0
_j[5o`00002nZLGo00000;fYaOl00000_JS500;o000000@0_JS5o`00002mZ<D000000_l000000`2l
Z<Ko00000;bYaP03o`0000030;bYaol0003o000000;o000000L0^jW7o`00002kZ/So00000;^Zb?l0
0000^j[900?o000000<0^Z_:o`000?l000000_l00000102jZl_o00000;Z[bol000020?ooo`030000
003oool0oooo01T0oooo000B0?ooo`0300000?l00000oooo02/0oooo00?o00000:Vmj?l000000_l0
0000102Y_NSo0000o`00002Y_NP3o`0000<000001?l000001@2Y_NSo0000o`000?l00000ZKgX00;o
000000D0ZKgXo`000?l0003o00000:Vnj@03o`0000050:VnjOl0003o0000o`00002Y_NP00ol00000
1@2W^NKo0000o`000?l00000X;[/00_o00000P2BJJ002?l00000TVBIo`00002BHYOo0000095PUOl0
0000T5jC0_l000001P2>G9;o0000o`00002;FI7o000008YIT@;o000000<0RERAo`000028F9800_l0
00001@29FYGo0000o`000?l00000REF=00;o000000<0REJ>o`000?l000000_l00000102GI9?o0000
09YWUP2JIiH2o`00000409EPT?l00000UV:A09IRT@;o000000L0jlN`o`000?l0003o00000:UgVol0
0000ZGRL00Co000000@0X7:Oo`00002QMJ40XGFQ0_l000020;VD/@Co000000L0a<;Ho`00002eWL3o
00000;NP`Ol00000]ibm00?o000000<0^j:oo`000?l000000_l000001030[<Ko00000;n/aP2o[<H2
o`0000050;jYaOl0003o00000;fYaOl000000P2mZ<D2o`0000030;fXaOl00000000000;o000000d0
_JW6o`00002mZLKo00000;bYa_l00000_:W7o`00002lZLOo00000;^Yaol00000^j[800Co000000H0
^j[8o`000?l0003o00000;^[bOl000020;^[b@;o000000<0^Z_;o`000?l000000P3oool00`000000
oooo0?ooo`0H0?ooo`004P3oool00`000000oooo0?ooo`0/0?ooo`03o`00002Y_NSo000000;o0000
00<0ZKgXo`000?l000000`000004o`0000050:Vmj?l0003o0000o`00002Y_NP01_l000001@2Y_NSo
0000o`000?l00000ZKgX00?o000000D0ZKgXo`000?l0003o00000:Rli`03o`0000030:Flj_l0003o
000000Oo000000L0YJSHo`000?l0003o0000095/YOl00000TVVP00;o000000H0TVBIo`000?l00000
TF2Eo`00002@GY<2o`00000608iLT_l0003o000008]ITOl00000RUVA0_l000000`29F97o000008QH
TP04o`00000308UESOl00000REF=00Co000000D0TUj@o`000?l00000UfBCo`00000209YWUP;o0000
0P2EH9000ol00000UV:Ao`000002o`00000309=PT_l0003o00000080ZGNK0_l000000`2MKico0000
o`0000020:1bW`04o`00002QMJ7o00000;^F/@Co000000D0`LCLo`000?l0003o00000;FM`002o`00
00030;JJ_?l00000_:C100?o000000@0`:_5o`000031[lP0`Jo80_l000001P2o[<Ko0000o`00002n
Z/Ko00000;fYa@?o000000<0_JS5o`000?l000000_l000001`2mZLD000000;fZa_l00000_JW6o`00
002mZLH00_l00000102mZLKo0000o`00002lZLL2o`0000090;bZaol00000_:[7o`00002lZ/So0000
0;^Zb?l00000^j[800?o000000<0^j_9o`000?l000000_l000001@2jZl[o00000?ooo`3oool00000
01X0oooo000A0?ooo`030000003oool0oooo02h0oooo00Co00000:Vmj?l0003o00000`000004o`00
00050:Vmj?l0003o0000o`00002Y_NP00ol00000102Y_NSo0000o`00002Y_NP3o`0000050:Vmj?l0
003o0000o`00002Y_NP03Ol000001`2V_n_o0000o`000?l00000Yk7Po`00002V[M`01_l00000102B
JJ3o0000o`00002BI9T2o`000003095PUOl00000T5jC00;o000000H0SUbBo`000?l00000ReVAo`00
002:FI42o`00000308UHTOl00000R5RB00Co000000<0REF=o`000029EHd00_l000000`2@Fhoo0000
099NT002o`000080UfBC00Co000009YWU_l0003o00000P2EH9000ol00000UV:Ao`000002o`000003
09=PT_l0003o00000080ZGNK0_l000001@2MKico000009i`WOl00000X7:O00?o000000<0^iJao`00
0?l000000ol000001@2^U[ko0000o`000?l00000]9Vl00?o000000@0_:C1o`000031[/L0`Jk70_l0
00001P31[lSo0000o`000030[/So00000;j/a`;o000000<0_Z[6o`00002nZ/H00ol000001`2mZ/Ko
00000;jZa_l00000_JW5o`00000000001?l000001`2mZ/Oo0000o`000?l00000_:[7o`00002lZ/L0
0ol000000`2lZ/Oo00000;bZb002o`0000030;bZb?l00000_:_800?o000000@0^j_9o`00002kZlT0
^j_90_l000020?ooo`03o`0000000000oooo01P0oooo000A0?ooo`0300000?l0003o000002l0oooo
0`000004o`0000050:Vmj?l0003o0000o`00002Y_NP00ol000001@2Y_NSo0000o`000?l00000ZKgX
00;o000000D0ZKgXo`000?l0003o00000:Vmj006o`0000040:Vmj?l0003o00000:Rnj@?o000000D0
Z;kYo`000?l0003o00000:Rgi006o`00000409bJdOl0003o000009F8``Co000000H0TVBIo`000?l0
0000TF2Eo`00002@GY<2o`00000608iLT_l0003o000008]ITOl00000RUVA0_l000001@29F97o0000
o`000?l00000ReJ=00Oo000000<0T5^?o`00002BGY000_l0000209MTT`04o`00002JIiKo0000o`00
0080UF2@00Ko000009IRTOl00000k<J^o`00002CH982o`000080ZGNK0_l000001P2MKico000009i`
WOl00000X7:Oo`000080_YZc1?l00000202YTKco00000:jF__l00000/YNlo`00002dVKco00000P2l
YL82o`0000060<6^aol0003o00000<:bbol00000`;3:1?l000001P2m[<So0000o`000?l00000_Z[6
o`000080_Z_70_l000000`2nZ/Ko0000o`000002o`00000700000?l00000_J_7o`00002mZ/Oo0000
0;fZa`02o`0000030;f[aol00000_J_700?o000000@0_:[8o`00002lZlP0_:_80_l000000`2lZlSo
00000;b[b003o`0000030;^[bOl0003o000000;o00000`3oool00`000000oooo0?ooo`0F0?ooo`00
0`3oool3o`0000@0oooo0_l000050?ooo`030000003oool0oooo02d0oooo0P0000001@3ooooo0000
o`000?l00000ZKgX00?o000000D0ZKgXo`000?l0003o00000:Vmj003o`0000030:Vmj?l0003o0000
00Co000000<0ZKgXo`000?l000001?l000000`2Y_NSo0000o`000004o`0000050:Vmj?l0003o0000
o`00002X^^H00ol000000`2U/^;o0000o`00000>o`000003095PUOl00000T5jC00;o000000H0SUbB
o`000?l00000ReVAo`00002:FI49o`00000308aGSOl00000SER>00;o000000<0T5^?o`00002BGY00
0_l0000209MTT`08o`00002JIiKo000009AOSol00000UF2@o`00002FHY43o`00000309=PT_l0003o
00000080ZGNK0_l0000209e_W0Co000000@0_YZco`000?l00000X8Jh0_l000001@2YTKco0000o`00
0?l00000/YNl00?o000000H0_:G2o`000?l00000`k?;o`000033]ll4o`0000070;j_bol00000_Jg:
o`00002m[<So00000;f/b003o`0000030;j[aol0003o000000;o000000L0_Zc8o`00002n[<So0000
0;f[a`000000_J_700Co000000L0_J_8o`000?l0003o00000;f[aol00000_J_800?o000000<0_:_8
o`000?l000000_l000000`2lZlSo00000;b[b@03o`0000050;^[bOl00000^j_90;^[bOl000000P3o
ool00`000000oooo0?ooo`0F0?ooo`000P3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co
00000?ooo`3ooooo0000103oool00`000000oooo0?ooo`0Z0?ooo`<000001@3oool2o`0000050:Vm
j?l0003o0000o`00002Y_NP00ol000001@2Y_NSo0000o`000?l00000ZKgX00;o000000<0ZKgXo`00
0?l000001?l000001@2Y_NSo0000o`000?l00000ZKgX00;o000000D0ZKgXo`000?l0003o00000:Vl
i`03o`0000030:NhiOl0003o000000;o000000<0W:oUo`000?l000001_l00000101[P]So0000o`00
0023FIT7o`00000308iLT_l0003o000000Oo000000<0RUF<o`00002:EXd00_l000000`2<Ehgo0000
08eHSP02o`00000?091KSol00000TUj@o`00002DH9;o000009MTTol00000VVNFo`00002DGhoo0000
09EPT?l00000UV:A00Go000000<0ZGJJo`00002YMi/00_l0000209e_W0;o00000P32X;H00ol00000
W82eo`0000020:26^0;o000000T0[YBlo`00002`U[co00000;f]bOl00000_:S5o`000034^]401?l0
00001`2o^=;o00000;facol00000_Zo;o`00002m[LX00_l000000`2m[/[o00000;j_b`03o`000003
0;j]bOl00000_Zk:00?o000000`0_Zc8o`000?l000000000o`00002m[LWo00000;f]bOl00000_J_8
o`00002m[<P4o`0000060;f/bOl0003o0000o`00002lZlSo00000P2l[<T2o`0000030;b[bOl00000
_:c900?o000000<0^j_9o`000?l000000`3oool00`000000oooo0?ooo`0E0?ooo`000P3oool01Ol0
0000oooo0?ooo`3ooooo00000080oooo00Co00000?ooo`3ooooo0000103oool00`000000oooo0?oo
o`0W0?ooo`<000002@3oool2o`0000050:Vmj?l0003o0000o`00002Y_NP00ol000001@2Y_NSo0000
o`000?l00000ZKgX00Go000000D0ZKgXo`000?l0003o00000:Vmj006o`0000050:Vmj?l0003o0000
o`00002X^nL00ol000000`2T^>Oo0000o`000002o`00000309Rcjol0003o000000So000000D0PeVI
o`000?l0003o000008MFT@07o`00000408UESOl0003o000008UES0;o000000<0RUF<o`00002:EXd0
0_l000000`2<Ehgo000008eHSP02o`000007091KSol00000TUj@o`00002DH9;o000009MTT`03o`00
000309AOSol00000UF2@00;o000000H0kLJ[o`000?l00000ZGJJo`00002YMYX3o`00000309a]Vol0
0000WFnL00;o000000D0`Z2fo`00002HNk;o000009b0]@04o`0000050:jD_?l0003o0000o`00002m
[LT01?l000000`33amgo00000;jlf003o`0000060;facol0003o00000;b`cOl00000_K3>0ol00000
0`2n[l_o00000;j`c002o`00000:0;j`c?l00000_[3=o`00002n[/[o00000;j^b_l00000_Jk;0000
00;o000000<0_Jg9o`000?l000000_l000001`2m[L[o00000;f]b_l00000_Jc9o`00002m[<T00ol0
00000`2l[<Wo0000o`000002o`0000030;b/bOl00000_:c:00?o000000@0_:c:o`00003oool0oooo
0_l000000`000000oooo0?ooo`0D0?ooo`000P3oool4o`0000<0oooo00Co00000?ooo`3ooooo0000
0`3oool00ol0000000000?ooo`0U0?ooo`<000003@3oool2o`0000050:Vmj?l0003o0000o`00002Y
_NP02Ol000001@2Y_NSo0000o`000?l00000ZKgX00?o000000@0ZKgXo`000?l00000ZKgX0ol00000
1@2Y_>Oo0000o`000?l00000Yk_W00?o000000<0XkSXo`000?l000000_l000000`2I/>Oo0000o`00
0007o`00000508=IVOl0003o0000o`000027EY400_l000001P28EXoo0000o`000028EHgo000008UE
S@;o000000H0REF<o`000?l00000RUF<o`00002:EXd2o`00000308aGSOl00000SER>00;o000000P0
T5^?o`00002BGY3o000009APT_l00000UfBCo`000080Tef?0_l000000`2EH93o0000o`000003o`00
00030:UfV_l00000ZGJJ00?o000000L0W6fKo`00002MKico00000<V[^ol00000U7J_00Co000000D0
ZI:no`000?l0003o00000;jnf@08o`0000030;[2h?l00000^;OH00?o000000<0^k;Ao`000?l00000
0_l000001`2l]]?o0000o`000?l00000_K?@o`00002m/m000ol000000`2n/<go0000o`000003o`00
000<0;f^bol0000000000;f^bol00000_Jo;o`00002m[lco00000;f]b_l00000_Jg:1?l000001`2m
[/_o0000o`000?l00000_Jg:o`00002l[LX00ol000000`2l[<[o00000;b]bP02o`0000060;b]b_l0
003o00000?ooool0000000005P3oool00080oooo00?o00000?ooo`3oool0103oool01?l00000oooo
0?ooool000030?ooo`030000003oool0oooo0280oooo0`00000A0?ooo`;o000000<0ZKgXo`000?l0
00000ol000001@2Y_NSo0000o`000?l00000ZKgX00?o000000D0ZKgXo`000?l0003o00000:Vmj006
o`0000030:Vmj?l0003o000000Wo000000<0X[OWo`000?l000000_l00000102HY]oo0000o`00002B
VmT2o`00000308b>d?l0003o000000?o000000D0QUNCo`000?l0003o000008QFS`02o`00000308QE
SOl00000REF=00;o000000H0REF<o`000?l00000RUF<o`00002:EXd2o`00000308aGSOl00000SER>
00;o000000@0T5^?o`00002BGY00TUj@0_l00000102GI9?o000009=MS`2CGHl2o`00000309EPT?l0
0000kLJ[00?o00000P2YMYX2o`000080W6bJ1?l000000`39Zk_o0000o`000002o`0000050:NB`?l0
0000ZI:no`00002nc^H03Ol000002`2d^Mco0000o`000?l00000^[SHo`00002j^m[o00000;bfdol0
0000_;OD00Co000000d0_;OEo`000?l0003o00000;fcd?l00000_K?Ao`00002m/<go00000;fac_l0
0000000000?o000000`0_Jo<o`000?l00000_Jo<o`00002m[lco00000;f`cOl00000_Jk;o`00002m
[//2o`0000030;f^c?l00000_:k<00?o000000<0_:g;o`00002l[//00ol000030?ooo`030000003o
ool0oooo01@0oooo00030?ooo`03o`00003oool0oooo00<0oooo00Co00000?ooo`3ooooo00000`3o
ool00`000000oooo0?ooo`0O0?ooo`<000005@3oool4o`0000050:Vmj?l0003o0000o`00002Y_NP0
0ol000001@2Y_NSo0000o`000?l00000ZKgX00?o000000<0ZKgXo`000?l000001ol00000102X_>So
0000o`00002V^^L5o`0000030:6biOl0003o000000go000000D0QUNCo`000?l0003o000008QFS`02
o`00000308QESOl00000REF=00;o000000H0REF<o`000?l00000RUF<o`00002:EXd2o`00000308aG
SOl00000SER>00;o000000@0T5^?o`00002BGY00TUj@1?l0000209=MS`;o000000@0UF2@o`000?l0
0000TUj@0_l000020:UfVP?o000000@0W6bJo`000?l00000dkc30ol000000`2SULKo00000:FC``0<
o`0000050:>mk?l0003o0000o`00002__>@00ol000000`2f_Moo0000o`000006o`0000070;Zlfol0
0000^[cKo`00002l]mGo00000;^ge@03o`0000030;fcdOl0003o000000;o000000L0_;CA0000002l
]=;o00000;fac_l00000_K7>00Go000000<0_K3=o`000?l000000_l000001`2l/<go0000o`000?l0
0000_:k<o`00002l[l`00ol000000`2l[/_o00000;b^c002o`000080oooo00<000000?ooo`3oool0
503oool000@0oooo0_l000040?ooo`;o0000103oool00`000000oooo0?ooo`0L0?ooo`<000006@3o
ool4o`0000050:Vmj?l0003o0000o`00002Y_NP00ol000001@2Y_NSo0000o`000?l00000ZKgX00Go
000000D0ZKgXo`000?l0003o00000:Vmj006o`0000030:Jiiol0003o000000Co000000<0VjWQo`00
0?l000001?l000001027R<go0000o`000023N/43o`00000508IGTol0003o0000o`000028EXl00_l0
00000`28EHgo000008UES@02o`00000608UES?l0003o000008YES?l00000RUJ=0_l000000`2<Ehgo
000008eHSP02o`000080T5^?00?o0000099NT?l000000_l000000`2BG8ko000009=MS`03o`000003
0>k6Z_l00000TUj@00;o00000P2YMYX01?l00000Vf^Jo`00002LK9X3o`00000309nPe?l0003o0000
01Co000000L0Yl[bo`000?l0003o00000;78jol00000/<W]00?o000000<0]/;So`000?l000001_l0
00001`2i^m_o0000o`000?l00000^kOFo`00002k]mH00ol000000`00003o0000o`000002o`00000=
0;bdd_l00000_;CBo`00002l//oo00000;bbcol00000_;;@o`00002l/<go00000;b`cP04o`000008
0;bac_l0003o0000o`00002l[lgo00000;b_cOl000020?ooo`030000003oool0oooo01@0oooo000@
0?ooo`0300000?l00000oooo01T0oooo0`00000L0?ooo`03o`00002Y_NSo000000;o000000D0ZKgX
o`000?l0003o00000:Vmj009o`0000050:Vmj?l0003o0000o`00002Y_NP00ol00000102Y_NSo0000
o`00002W^nL3o`0000030:Bgi_l0003o000000Go000000@0T9oNo`000?l00000Q97H2?l000001026
Ei?o0000o`000027EY03o`00000308QESOl00000REF=00;o000000H0REF<o`000?l00000RUF<o`00
002:EXd2o`00000308aGSOl00000SER>00;o00000P2@Fhl00ol00000TUj@o`000002o`000003099L
S_l00000Tef?00Oo000000L0ZGFIo`00002YMY[o000009][V_l00000W6bJ027o000000L0Y<kfo`00
0?l0003o00000:o7jol00000/<K[00?o000000D0]/3Ro`000?l0003o00000;Vkf`04o`0000070;Vl
g?l0003o0000o`000000003o00000;^he`03o`0000030;bdd_l0003o000000?o000000<0_;;@o`00
0?l000000_l000001`2l/]3o00000;bcdOl00000_;7>o`00002l/Ll01Ol000030?ooo`030000003o
ool0oooo01<0oooo000@0?ooo`030000003oool0oooo01H0oooo0`00000P0?ooo`03o`00002Y_NSo
000000;o000000<0ZKgXo`000?l000000ol000001@2Y_NSo0000o`000?l00000ZKgX00?o000000D0
ZKgXo`000?l0003o00000:Vmj006o`0000050:Njiol0003o0000o`00002R]NH03ol00000101[M<[o
0000o`000026Ei<2o`00000708MFT?l0003o0000o`000028EHgo000008UES@02o`00000608UES?l0
003o000008YES?l00000RUJ=0_l000002@2<Ehgo000008eHS_l00000SUZ>o`00002@Fhoo0000099N
T003o`000003099LS_l00000Tef?00;o000000<0k/JZo`000?l000000_l000001@2YMIWo00000:Uf
V_l00000Vf^J00Ko000000<0Xk[Yo`000?l000008Ol000001@2Vbo?o0000o`000?l00000/<KZ00Go
000000D0]/7Ro`000?l0003o00000;Vlg002o`00000300000?l00000^;cL00?o000000<0^[SGo`00
002j^=L00ol000000`2k]M?o00000;^ed`03o`0000030;bcdOl0003o000000;o000000<0^k?Ao`00
002k/m800ol000020?ooo`030000003oool0oooo01<0oooo000@0?ooo`030000003oool0oooo01@0
oooo0P00000T0?ooo`_o000000D0ZKgXo`000?l0003o00000:Vmj003o`0000050:Vmj?l0003o0000
o`00002Y_NP00_l000001@2X_>Oo0000o`000?l00000YKWW00Co000000<0WJoTo`000?l000002Ol0
00000`1YPMOo0000o`000005o`00000708MFT?l0003o0000o`000028EHgo000008UES@02o`000006
08UES?l0003o000008YES?l00000RUJ=0_l000003`2<Ehgo000008eHS_l00000SUZ>o`00002@Fhoo
0000099NT?l00000TE^>o`00002BG8ko000009=MS`03o`000005099MT?l00000ZGFIo`00002YMIT0
0_l00000102KJYWo0000o`00002X^ND_o`0000050:K;lol0003o0000o`00002`a^X00ol000000`2e
`N?o000000000003o`0000030;Rlg?l0003o000000;o000000L0^;cMo`000?l0003o00000;Zhf?l0
0000^[SH00?o000000<0^kKDo`00002k]]@00ol000000`2k/m;o00000;^cdP02o`0000030?ooo`00
0000oooo01@0oooo000?0?ooo`030000003oool0oooo0180oooo0`00000X0?ooo`?o000000@0ZKgX
o`000?l00000ZKgX0ol000001@2Y_NSo0000o`000?l00000ZKgX00ko000000<0Y;OVo`000?l00000
0_l000000`2IZn?o0000o`00000=o`000004065Ya?l0003o000008MFT0;o000000@0R5F>o`000?l0
0000REF=0_l000001P29EHco0000o`00002:EHco000008YFS@;o000000@0S5N=o`00002=F8h0SER>
0_l000002@2@Fhoo0000099NT?l00000TE^>o`00002BG8ko000009=MS`03o`000004099MT?l00000
ZGFI0:UeV@?o000000D0VfZIo`000?l0003o00000:Vmj003o`0000030:Nojol0003o000000Co0000
00D0Xl3]o`000?l0003o00000:6ok`0Zo`00000700000?l0003o0000o`00002e`N?o00000;G0h`03
o`0000030;RlgOl0003o000000?o000000<0^[WHo`000?l000000_l000002P2i^MWo0000o`000?l0
0000^[KEo`00002j]]Go00000?ooo`00000E0?ooo`003`3oool00`00003o00000?ooo`0?0?ooo`<0
0000;03oool3o`0000040:Vmj?l0003o00000:Vmj0Wo000000D0ZKgXo`000?l0003o00000:Vlj003
o`0000030:Nkiol0003o000000;o000000<0X[GVo`000?l000000_l00000102FY^7o0000o`00002<
Vmd8o`00000306Ijdol0003o000000?o000000H0QeJ@o`000?l00000R5F>o`000028EHd3o`000006
08UES?l0003o000008YES?l00000RUJ=0_l0000208aGS@0?o`00002=F8ko0000o`00002@Fhoo0000
099NT?l00000TE^>o`00002BG8ko000009=MSol00000k/FY00?o00000P2YMIT4o`0000030:Znj?l0
003o000003_o000000<00000o`000?l000000ol000001`2`aN[o0000o`000?l00000]<3So`00002d
`><00ol000000`2g_=go00000;Nlg@03o`0000030;VifOl0003o000000?o000000<0oooo0000003o
ool0503oool000l0oooo00<000000?ooo`3oool0303oool300000300oooo2Ol00000102Y_NSo0000
o`00002Y_NP3o`0000050:Vmj?l0003o0000o`00002X_>P00ol000000`2V^^Oo0000o`000002o`00
00030:2biOl0003o000000_o000000<0M7g>o`000?l000000_l00000101IMmKo0000o`000027EY02
o`00000308QES_l00000R5F=00?o000000H0REF<o`000?l00000RUF<o`00002:EXd2o`000080S5N=
00Go000008eHS_l0003o0000091KS`02o`000006091JSOl0003o0000099LS_l00000Tef?0ol00000
102YMIWo00000:UeV@2YMITBo`0000050:NmjOl0003o0000o`00002V_^X00ol000000`2U_^co0000
o`00000Uo`00000300000?l0003o0000013o000000L0]<3So`000?l0003o00000;Nlg_l00000]kcN
00?o000000<000000?ooo`3oool04`3oool000l0oooo00<000000?ooo`3oool02@3oool3000003@0
oooo1Ol000000`2Y_NSo0000o`000004o`0000050:Vmj?l0003o0000o`00002Y_NP00ol000000`2X
_>Oo0000o`000006o`00000309f_i?l0003o000000So000000<0N87@o`000?l000000_l000000`1a
MlWo0000o`000002o`00000608MFT?l0003o000008QES_l00000R5F=0_l000001P29EHgo000008UE
S?l00000RUF<o`000080RUJ=0_l000000`2<Ehgo000008eHSP02o`000004091KSol0003o0000091J
S@;o000000<0TUb>o`00002CGHl00ol00000102YMIWo00000:UeV@2YMIT;o`0000050:Vmj?l0003o
0000o`00002X_NP00ol000001@2X_NWo0000o`000?l00000YkkZ02_o000000<00000o`000?l00000
2Ol000000`2XbO7o0000o`00000=o`0000030000003oool0oooo01<0oooo000?0?ooo`0300000?l0
0000oooo00H0oooo0`00000h0?ooo`03o`00002Y_NSo000000;o000000@0ZKgXo`000?l00000ZKgX
0ol000000`2Y_NSo0000o`000008o`0000030:Bgi_l0003o000000Co000000<0UZKQo`000?l00000
1?l000000`1kQmCo0000o`000002o`000003075gb_l0003o000000;o000000<0MGK6o`000?l00000
0_l000000`28EHko000008QES@02o`00000308UESOl00000REF<00;o000000<0RUF<o`00002:EXd0
0_l000000`2<Ehgo000008eHSP02o`000004091KSol00000T5Z=091JS@;o000000<0TUb>o`00002C
GHl00ol000020:UeV@04o`00002YMIWo00000:Zoj@Ko000000D0ZKgXo`000?l0003o00000:Vmj003
o`0000030:Vmj?l0003o000000ko000000D0Y[k[o`000?l0003o00000:Bok00No`00000300000?l0
003o000000_o000000D0Wlcgo`000?l0003o00000:W8l003o`0000030:o4jOl00000[lCY00?o0000
00<000000?ooo`3oool04P3oool000040?ooool0003o0000o`0000@0oooo0_l000050?ooo`030000
003oool0oooo00<0oooo0`00000l0?ooo`03o`00002Y_NSo000000_o000000D0ZKcXo`000?l0003o
00000:Nki`04o`0000030::ei_l0003o000000Go000000@0S9_Mo`000?l00000PHkG1?l000000`1a
Nlko0000o`000002o`000003071baOl0003o000000Co000000<0R5F>o`000028EHd00_l000000`29
EHgo000008UES002o`00000308YES?l00000RUJ=00;o000000<0S5N=o`00002=F8h00_l00000102@
Fhoo0000o`00002@FXd2o`000004099LS_l0003o00000>k5Z@;o00000P2YMIT00ol00000ZGFIo`00
0004o`0000050:Vmj?l0003o0000o`00002Y_NP02Ol000000`2Y_NSo0000o`000004o`0000050:Rm
jOl0003o0000o`00002W_^T00ol000000`2W_^[o0000o`00000Po`00000300000?l0003o000001Go
000000@0ZLS`o`000?l000000000503oool00005o`00003oool0oooo0?ooool000000P3oool01?l0
0000oooo0?ooool000030?ooo`040000003oool0oooo0?ooo`<00000@03oool3o`0000050:Vmj?l0
003o0000o`00002Y_NP00ol00000102Y_NSo0000o`00002X_>P3o`0000030:Jjiol0003o000000;o
000000<0X;;Uo`000?l000002_l000000`1ePM7o0000o`000007o`00000707Mc`_l0003o0000o`00
0028EHko000008QES@02o`00000308UESOl00000REF<00;o000000<0RUF<o`00002:EXd00_l00000
0`2<Ehgo000008eHSP03o`00000508mISOl00000T5Z=o`00002AFhh01_l000020:UeV@Co000000<0
Z[gXo`000?l000001ol000001@2Y_NSo0000o`000?l00000ZKgX00Ko000000<0ZKgXo`000?l00000
2ol000000`2W_^[o0000o`000004o`0000050:Fnk?l0003o0000o`00002S_nd02?l0000<0?ooo`03
0000003oool0oooo00D0oooo4Ol000020?ooo`030000003oool0oooo0180oooo00001Ol00000oooo
0?ooo`3ooooo00000080oooo00Co00000?ooo`3ooooo00000`3oool4000004D0oooo0_l000001@2Y
_NSo0000o`000?l00000ZKgX00Ko000000D0Z;_Wo`000?l0003o00000:Fii`04o`00000309f_i?l0
003o000000So000000<0MX;Ao`000?l000000_l000000`1XLl_o000006Uab007o`00000308QES_l0
0000R5F=00;o000000<0REF=o`000029EH`00_l000000`2:EHco000008YFS@02o`00000308aGSOl0
0000SER>00;o000000H0SUV=o`000?l00000T5Z=o`00002AFhh2o`0000060>k5ZOl0003o00000:Ud
VOl00000ZGFI1ol000001@2Y_^So0000o`000?l00000ZKgX00?o000000<0ZKgXo`000?l000002_l0
00001@2Y_NSo0000o`000?l00000ZKgX00?o000000<0Z;gYo`000?l000001?l000000`2W_^[o0000
o`000009o`000140oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0B0?ooo`0000@0
ooooo`000?l0003o00000`3oool01?l00000oooo0?ooool000030?ooo`0300000?l00000oooo04L0
oooo0_l000000`2Y_NSo0000o`00000<o`0000030:Bgi_l0003o000000?o000000<0UZKQo`000?l0
00001?l000000`1kR=Co0000o`000002o`00000306ehcOl0003o000000Co000000<0JW78o`000?l0
00000_l000000`28EHko000008QES@02o`00000308UESOl00000REF<00;o000000<0RUF<o`00002:
EXd00_l000000`2<Ehgo000008eHSP02o`00000608iISOl0003o0000091JSOl00000TE^>0ol00000
1`2XM9Wo00000:UdVOl00000ZGFIo`00002Z_nP00_l000001@2Z_^So0000o`000?l00000ZKgX00?o
000000<0ZKgXo`000?l000002_l000001@2Y_NSo0000o`000?l00000ZKgX013o000000CoZ;kYo`00
0?l0003o00005`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00001Ol0
0000oooo0?ooo`3ooooo00000080oooo00Co00000?ooo`3ooooo00001@3oool00ol00000oooo0?oo
o`160?ooo`Co000000D0ZKgXo`000?l0003o00000:Vlj003o`0000030:Nkiol0003o000000So0000
00D0TJ7Oo`000?l0003o0000086>e`04o`000003075lcol0003o000000;o000000<0Ig;:o`00001T
LL/01?l000001@1aNLco0000o`000?l00000R5F=00;o000000<0REF=o`000029EH`00_l000000`2:
EHco000008YFS@02o`00000308aGSOl00000SER>00;o000000H0SUV=o`000?l00000T5Z=o`00002A
Fhh3o`0000050:QdVOl00000ZGBIo`00002YMIT01Ol000000`2Y_^So0000o`000007o`0000030:Vm
j?l0003o000000Co000000D0ZKgXo`000?l0003o00000:Vmj00<o`0000050:Vmj?l0003o0000o`00
0?nX_NP00ol0000K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool00005
o`00003oool0oooo0?ooool000000P3oool01?l00000oooo0?ooool000060?ooo`03o`00003oool0
oooo04D0oooo00?o00000:Vmj?l000000_l000001@2Y_NSo0000o`000?l00000Z;cX00Ko000000<0
X[CVo`000?l000002ol000000`1fP]7o0000o`000002o`00000306]dbol0003o000000Co000000<0
IGO@o`000?l000000ol000001P28EHgo0000o`000029EHgo000008UES0;o000000<0RUF<o`00002:
EXd00_l000000`2<Ehgo000008eHSP02o`00000608iISOl0003o0000091JSOl00000TE^>0ol00002
0:QdV@_o000000D0ZKgXo`000?l0003o00000:Vmj006o`0000030:Vmj?l0003o000000Oo000000<0
ZKgXo`000?l000001?l000001@2Y_NSo0000o`000?l0003oZKgX00?o00007P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0180oooo0000103ooooo0000o`000?l000040?ooo`;o0000
203oool00ol00000oooo0?ooo`150?ooo`03o`00002Y_NSo000000go000000<0X;;Uo`000?l00000
2?l000000`1kR=Co0000o`000002o`00000306ihc?l0003o000000;o000000<0JG;9o`000?l00000
2_l000000`29EHgo000008UES002o`00000308YES?l00000RUJ=00;o000000H0S5N=o`000?l00000
SUR<o`00002>FHd2o`000003091JSOl00000TE^>00?o00000P2XM9T8o`0000050:Vmj?l0003o0000
o`00002Y_NP03?l000001@2Y_NSo0000o`000?l00000ZKgX00Ko000000<0ZKgXo`000?l000001Ol0
000R0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool001<0oooo0_l00016
0?ooo`Oo000000D0Z;_Wo`000?l0003o00000:Fhi`05o`00000309Z[hol0003o000000Co000000<0
PHkGo`000?l000004Ol000000`1oVN;o0000o`000002o`00000308UESOl00000REF<00;o000000<0
RUF<o`00002:EXd00_l000001P2<Ehgo0000o`00002>F8co000008iIS@;o000000<0T5Z=o`00002A
Fhh00ol000020:QdV@Go000000<0Z[kXo`000?l000001ol000000`2Y_NSo0000o`000004o`000005
0:Vmj?l0003o0000o`00002Y_NP03?l0000X0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool04@3oool001D0oooo00?o00000?ooo`3oool0A@3oool2o`0000050:Vlj?l0003o0000o`00
002W^nL00ol000000`2T]nKo0000o`000003o`00000509JVhOl0003o0000o`000027UMX02_l00000
0`1YL/Wo0000o`000004o`00000307Ancol0003o000000Ko000000<0REF=o`000029EH`00_l00000
0`2:EHco000008YFS@05o`00000308iHS?l00000SUV=00;o000000<0T5Z=o`000?l000000_l00000
0`2WM9[o00000:QdV@08o`0000050:Vmj?l0003o0000o`00002Y_NP01_l000000`2Y_NSo0000o`00
000>o`0002`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`005P3oool0
0ol00000oooo0?ooo`150?oooaco000000<0JgC;o`000?l000000_l000000`1ZLl[o000006mhb`0<
o`00000608UES?l0003o000008YES?l00000RUJ=0_l000001P2<Ehco0000o`00002>F8co000008iI
S@;o000000<0T5Z=o`000?l000000_l000000`2WM9[o00000:QdV@05o`0000050:Vmj?l0003o0000
o`00002Y_NP03?l000001@2Y_NSo0000o`000?l00000ZKgX00Ko0000;`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0140oooo000G0?ooo`03o`00003oool0oooo04D0oooo00Go0000
0:Rliol0003o00000:Jji`04o`0000030:2biOl0003o000001;o000000<0J7;9o`000?l000001ol0
00000`2BW=[o0000o`000002o`00000308MDSOl0003o000000;o000000<0RUF<o`000?l000000_l0
00001P2<Ehco0000o`00002>F8co000008iIS@;o000000P0T5Z=o`000?l00000YWBJo`00002WM9[o
00000:QdV@;o000000<0Z[kXo`000?l000003_l000001@2Y_NSo0000o`000?l00000ZKgX00Ko0000
<`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo000H0?ooo`;o0000AP3o
ool01Ol00000Z;_Wo`000?l00000YKSW00Co000000<0WJkTo`000?l000002?l000000`1gP]7o0000
o`000002o`00000306]dbol00000JG;900Co000000<0KGO<o`000?l000000_l000002023T=So0000
o`00002L[N?o00000;OFl?l00000QeB=1ol000000`2;EXco000008aGS002o`00000308iHS?l00000
SUV=00;o000000<0T5Z=o`000?l000000P2VM9X8o`0000050:Vmj?l0003o0000o`00002Y_NP01_l0
00000`2Y_NSo0000o`000007o`0003P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`006P3oool00ol00000oooo0?ooo`140?ooo`Co000000<0Y;KVo`000?l000000_l00000
0`2IZn;o0000o`000005o`00000307b8e?l0003o000000;o000000<0KWS=o`000?l000004_l00000
1027E8go0000o`000029E8`2o`00000508YES?l00000ReJ<o`00002<Eh`00_l000000`2>F8co0000
08iIS@03o`0000040>_7/?l00000YWBJ0:IdVP;o000000@0Z[kXo`000?l00000Z[kX0ol000000`2Y
_NSo0000o`00000:o`000004ojVmj?l0003o0000o`0003/0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`006`3oool00ol00000oooo0?ooo`140?ooo`[o000000@0TJ7Oo`00
0?l00000QiGJ1Ol000000`1bOLoo0000o`000005o`00000306Ycb_l00000KGO<00So000000@0Z/;[
o`000?l00000cncY0ol000002029E8co0000o`00002:EHco000008]FS?l00000S5N<0_l000000`2>
F8co000008iIS@05o`000080YWBJ3?l000000`2Y_NSo0000o`000004o`000004ojVmj?l0003o0000
o`0003l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`00703oool00ol0
0000oooo0?ooo`140?oooa3o000000<0Mh;Ao`000?l000001Ol000000`1YL/Wo0000o`000006o`00
000308:AfOl0003o000000?o000000<0aN3/o`000?l000000_l000002029E8co0000o`00002:EHco
000008]FS?l00000S5N<0_l000000`2>F8co000008iIS@02o`0000050>_7/?l00000YGBKo`00002V
M9X01Ol000001@2Y_NSo0000o`000?l00000ZKgX00[o0000@`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0100oooo000M0?ooo`;o0000A@3oool2o`00000309naiOl0003o000000So
000000<0O8SDo`000?l000000ol000000`1[ML_o000006UcbP04o`00000306egc?l0003o000000;o
000000H0PY7Io`000?l00000W:oUo`00002hdN`6o`00000808UDS?l0003o000008YES?l00000ReJ<
o`00002<Eh`2o`00000308iHS?l00000SUV=00?o00000P2UM9/00ol00000YWBJo`00000?o`0004P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`007`3oool00ol00000oooo
0?ooo`130?ooo`;o000000<0WJkSo`000?l000001Ol000000`22SmOo0000o`00000:o`00000306Yc
b_l0003o000000;o000000<0NHGCo`000?l000002ol000002029E8co0000o`00002:EHco000008]F
S?l00000S5N<0_l000001@2>F8co000008iISOl00000j<Rf00;o000000<0YGBKo`000?l000002Ol0
00001?nY_NSo0000o`000?l0001;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
403oool00200oooo00?o00000?ooo`3oool0@`3oool3o`00000409JVhOl0003o000008bKg0_o0000
00<0JG?:o`000?l000001?l000000`1bOLoo0000o`000004o`0000030:W0j_l0003o000000Ko0000
00P0REB<o`000?l00000RUF<o`00002;EXco000008aGS0;o000000<0SUR<o`00002>FHd00_l00000
1@2SLigo00000:EdVol00000Z[kX00[o0000C`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0100oooo000Q0?ooo`03o`00003oool0oooo04<0oooo3ol000000`1/ML_o0000o`000005
o`000003075mcol0003o000000Oo000000<0a>;]o`000?l000001?l000002029E8co0000o`00002:
EHco000008]FS?l00000S5N<0_l000001@2>F8co000008iISOl00000Wg:O00_o0000E03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo000R0?ooo`03o`00003oool0oooo0480
oooo2ol000000`1cOLoo0000o`000007o`00000306egc?l0003o000000;o000000<0PY3Io`00002=
W]h03_l000001@2:EHco000008]FS?l00000S5N<00;o000000D0SUR<o`000?l0003o000009mbW`04
o`000004ojZnj?l0003o0000o`0005P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0@0?ooo`008`3oool2o`0004<0oooo1ol000000`1mRMCo0000o`000003o`00000306afbol00000
JW?:00;o000000<0JWC:o`000?l000000_l000000`1hQM?o0000o`00000@o`00000508YES?l00000
ReJ<o`00002<Eh`00_l000001@2>F8co0000o`000?l00000Wg:O00Go0000F`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0100oooo000U0?ooo`03o`00003oool0oooo0440oooo2_l0
00000`1_NLgo0000o`000007o`000003075mcol0003o000000Co000000<0ZKoZo`000?l000002ol0
00001@2:EHco000008]FS?l00000S5N<00?o000000<0f/c;o`000?l000000ol0001O0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool002H0oooo00?o00000?ooo`3oool0@@3o
ool00ol00000QiGJo`000004o`00000307=ncol0003o000000Go000000<0JWC;o`000?l000002ol0
00000`3>k^[o0000o`00000:o`00000308]FS?l00000S5N<00;o000000<0f/c;o`000?l00000I03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo000W0?ooo`03o`00003oool0
oooo0400oooo2ol000000`1ZM<[o000006UcbP04o`000003075mcol0003o0000013o000000<0d_CV
o`000?l000002?l0001W0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool0
02P0oooo0_l000110?ooo`Go000000<0Lgk?o`000?l000001ol000000`1]N<co0000o`000003o`00
000508fMg_l0003o0000o`00002gdNd04ol0001Y0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03`3oool002X0oooo00?o00000?ooo`3oool0?`3oool2o`00000307R4d_l0003o0000
00Go000000<0JW?:o`00001ZM</01Ol000001021T=Wo0000o`00002J[NDCo`0006d0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00:`3oool00ol00000oooo0?ooo`0n0?oo
o`So000000<0JgC;o`000?l000001Ol000000`1hQM?o0000o`00000Ao`000003olKRk?l00000oooo
0700oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`00;03oool00ol00000
oooo0?ooo`0m0?ooo`ko000000<0LGg@o`000?l000001?l000000`2X_n[o0000o`00000:o`000003
ol_Xjol0003o00000780oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`00
;@3oool2o`0003h0oooo1_l00000101[ML_o0000o`00001[ML/<o`0000030<?Qk_l0003o000000Wo
0000M@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo000_0?ooo`03o`00
003oool0oooo03/0oooo1?l000000`1]Mlco0000o`000005o`000003079md?l0003o000000;o0000
00<0S9gOo`000?l000003?l0001h0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3P3oool00300oooo00?o00000?ooo`3oool0>`3oool9o`00000306ehcOl0003o000000Go000000<0
VJgUo`000?l000002_l0001j0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3o
ool00340oooo00?o00000?ooo`3oool0>`3oool01Ol00000KWS<o`000?l00000JgG;01Oo0000N`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo000b0?ooo`;o0000>`3oool7
o`00000406iicOl0003o000007R6e0Go000000<0YkkZo`000?l000002?l0001m0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03P3oool003@0oooo00?o00000?ooo`3oool0>@3oool4
o`00000306afc?l0003o000000[o000000<0c>g[o`000?l000001?l000200?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool03P3oool003D0oooo00?o00000?ooo`3oool0>03oool@o`00
00030<;Ok_l0003o000000Go0000P@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00h0oooo000f0?ooo`03o`00003oool0oooo03L0oooo1_l000000`1bO]3o0000o`00000>o`000880
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`00=`3oool2o`0003L0oooo
00Go000006afc?l0003o000006ijcP05o`00000508^Mgol0003o0000o`00002dcnh01_l000250?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool003T0oooo00?o00000?ooo`3o
ool0=@3oool:o`00000309R]iOl0003o000000Ko0000Q`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo000j0?ooo`03o`00003oool0oooo03D0oooo00?o000006mjc_l00000
3ol000280?ooo`050000003oool0oooo0?ooo`0000003`3oool003/0oooo00?o00000?ooo`3oool0
=03ooolAo`0008T0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`00?03oool2o`0003D0oooo
00?o000007>0dOl000001Ol00000102U_N_o0000o`00003:jn`2o`0008`0oooo00@000000?ooo`3o
ool000003`3oool003h0oooo00?o00000?ooo`3oool0<P3oool>o`0008d0oooo00<000000?ooo`00
00003`3oool003l0oooo00?o00000?ooo`3oool0<@3oool9o`0000040;oNkol0003o0000o`0008h0
oooo00@000000?ooo`3oool000003P3oool00400oooo00?o00000?ooo`3oool0<@3oool:o`000940
oooo00<000000?ooo`0000003P3oool00440oooo0_l0000b0?ooo`So0000T`3oool2000000h0oooo
00130?ooo`03o`00003oool0oooo0300oooo1_l0002C0?ooo`;o000000<000000?ooo`3oool0303o
ool004@0oooo00?o00000?ooo`3oool0;`3oool4o`000940oooo1?l0000A0?ooo`00A@3oool00ol0
0000oooo0?ooo`0^0?ooo`03o`00003oool0oooo08h0oooo1?l0000E0?ooo`00AP3oool00ol00000
oooo0?ooo`0]0?ooo`03o`00003oool0oooo08/0oooo0ol0000I0?ooo`00A`3oool2o`0002d0oooo
00?o00000?ooo`3oool0Q`3oool4o`0001`0oooo00190?ooo`03o`00003oool0oooo02X0oooo00?o
00000?ooo`3oool0P`3oool4o`000200oooo001:0?ooo`03o`00003oool0oooo02T0oooo00?o0000
0?ooo`3oool0O`3oool4o`0002@0oooo001;0?ooo`03o`00003oool0oooo02P0oooo00?o00000?oo
o`3oool0N`3oool4o`0002P0oooo001<0?ooo`;o0000:03oool00ol00000oooo0?ooo`1h0?ooo`?o
0000;03oool004h0oooo00?o00000?ooo`3oool09@3oool00ol00000oooo0?ooo`1d0?ooo`Co0000
;`3oool004l0oooo00?o00000?ooo`3oool0903oool00ol00000oooo0?ooo`1`0?ooo`Co0000<`3o
ool00500oooo00?o00000?ooo`3oool08`3oool00ol00000oooo0?ooo`1/0?ooo`Co0000=`3oool0
0540oooo0_l0000S0?ooo`03o`00003oool0oooo06P0oooo1?l0000k0?ooo`00D`3oool00ol00000
oooo0?ooo`0P0?ooo`03o`00003oool0oooo06D0oooo0ol0000o0?ooo`00E03oool00ol00000oooo
0?ooo`0O0?ooo`03o`00003oool0oooo0640oooo1?l000120?ooo`00E@3oool00ol00000oooo0?oo
o`0N0?ooo`03o`00003oool0oooo05d0oooo1?l000160?ooo`00EP3oool2o`0001h0oooo00?o0000
0?ooo`3oool0F@3oool4o`0004X0oooo001H0?ooo`03o`00003oool0oooo01/0oooo00?o00000?oo
o`3oool0E@3oool4o`0004h0oooo001I0?ooo`03o`00003oool0oooo01X0oooo00?o00000?ooo`3o
ool0DP3oool3o`000580oooo001J0?ooo`03o`00003oool0oooo01T0oooo00?o00000?ooo`3oool0
CP3oool4o`0005D0oooo001K0?ooo`;o00006@3oool00ol00000oooo0?ooo`1:0?ooo`Co0000F@3o
ool005d0oooo00?o00000?ooo`3oool05P3oool00ol00000oooo0?ooo`160?ooo`Co0000G@3oool0
05h0oooo00?o00000?ooo`3oool05@3oool00ol00000oooo0?ooo`120?ooo`Co0000H@3oool005l0
oooo00?o00000?ooo`3oool0503oool00ol00000oooo0?ooo`0o0?ooo`?o0000I@3oool00600oooo
0_l0000D0?ooo`03o`00003oool0oooo03/0oooo1?l0001X0?ooo`00HP3oool00ol00000oooo0?oo
o`0A0?ooo`03o`00003oool0oooo03L0oooo1?l0001/0?ooo`00H`3oool00ol00000oooo0?ooo`0@
0?ooo`03o`00003oool0oooo03<0oooo1?l0001`0?ooo`00I03oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo02l0oooo1?l0001d0?ooo`00I@3oool00ol00000oooo0?ooo`0=0?ooo`03
o`00003oool0oooo02d0oooo0ol0001h0?ooo`00IP3oool2o`0000d0oooo00?o00000?ooo`3oool0
:@3oool4o`0007/0oooo001X0?ooo`03o`00003oool0oooo00X0oooo00?o00000?ooo`3oool09@3o
ool4o`0007l0oooo001Y0?ooo`03o`00003oool0oooo00T0oooo00?o00000?ooo`3oool08@3oool4
o`0008<0oooo001Z0?ooo`03o`00003oool0oooo00P0oooo00?o00000?ooo`3oool07@3oool4o`00
08L0oooo001[0?ooo`;o0000203oool00ol00000oooo0?ooo`0J0?ooo`?o0000R`3oool006d0oooo
00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0F0?ooo`Co0000SP3oool006h0oooo00?o
00000?ooo`3oool0103oool00ol00000oooo0?ooo`0B0?ooo`Co0000TP3oool006l0oooo00?o0000
0?ooo`3oool00`3oool00ol00000oooo0?ooo`0>0?ooo`Co0000UP3oool00700oooo0_l000030?oo
o`03o`00003oool0oooo00X0oooo1?l0002J0?ooo`00LP3oool01?l00000oooo0?ooool000090?oo
o`?o0000WP3oool007<0oooo00?o00000?ooool000001@3oool4o`000:40oooo001d0?ooo`;o0000
00<0ooooo`000?l000000_l0002U0?ooo`00M@3oool2o`000:T0oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.054002, 0.00159468, \
0.00367817, 0.00367817}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Three Wavelets with Lens", "Subsubsection",
  CellTags->{"AOG0.", "6.4.7", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
waveletSystem = {
\tMove[LineOfWavelets[10,NumberOfRays->3,PaddingFactor->.1],-50],
\tPlanoConvexLens[100,50,10],
\tMove[Screen[50],103]};\
\>", "Input",
  CellLabel->"In[62]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],

Cell[BoxData[
    \("Warning, LineOfWavelets will not be uniform."\)], "Print",
  CellLabel->"From In[62]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],

Cell[BoxData[
    \("Set PaddingFactor greater or equal to 1 for uniform illumination."\)], \
"Print",
  CellLabel->"From In[62]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[waveletSystem,ShowGaussian->True,PlotType->TopView];\
\>", "Input",
  CellLabel->"In[63]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .34679 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.335042 0.00622464 0.18292 0.00622464 [
[.36616 .00826 -3 -4.5 ]
[.36616 .00826 3 4.5 ]
[.97618 .00826 -3 -4.5 ]
[.97618 .00826 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .34679 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.37502 .0273 m
.39729 .0273 L
.39729 .07918 L
.35216 .07918 L
.37502 .0273 L
F
.35216 .07918 m
.39729 .07918 L
.39729 .13105 L
.33924 .13105 L
.35216 .07918 L
F
.33924 .13105 m
.39729 .13105 L
.39729 .18292 L
.33504 .18292 L
.33924 .13105 L
F
.33504 .18292 m
.39729 .18292 L
.39729 .23479 L
.33924 .23479 L
.33504 .18292 L
F
.33924 .23479 m
.39729 .23479 L
.39729 .28666 L
.35216 .28666 L
.33924 .23479 L
F
.35216 .28666 m
.39729 .28666 L
.39729 .33854 L
.37502 .33854 L
.35216 .28666 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.37502 .0273 m
.35216 .07918 L
.33924 .13105 L
.33504 .18292 L
.33924 .23479 L
.35216 .28666 L
.37502 .33854 L
.39729 .33854 L
.39729 .28666 L
.39729 .23479 L
.39729 .18292 L
.39729 .13105 L
.39729 .07918 L
.39729 .0273 L
.37502 .0273 L
s
.5 g
.37502 .18292 m
.39729 .18292 L
.39729 .18292 L
.35216 .18292 L
.37502 .18292 L
F
.35216 .18292 m
.39729 .18292 L
.39729 .18292 L
.33924 .18292 L
.35216 .18292 L
F
.33924 .18292 m
.39729 .18292 L
.39729 .18292 L
.33504 .18292 L
.33924 .18292 L
F
.33504 .18292 m
.39729 .18292 L
.39729 .18292 L
.33924 .18292 L
.33504 .18292 L
F
.33924 .18292 m
.39729 .18292 L
.39729 .18292 L
.35216 .18292 L
.33924 .18292 L
F
.35216 .18292 m
.39729 .18292 L
.39729 .18292 L
.37502 .18292 L
.35216 .18292 L
F
0 g
.37502 .18292 m
.35216 .18292 L
.33924 .18292 L
.33504 .18292 L
.33924 .18292 L
.35216 .18292 L
.37502 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.37502 .18292 L
s
.37502 .33854 m
.39729 .33854 L
.39729 .33323 L
.37502 .33323 L
.37502 .33854 L
s
.37502 .33323 m
.39729 .33323 L
.39729 .31769 L
.37502 .31769 L
.37502 .33323 L
s
.37502 .31769 m
.39729 .31769 L
.39729 .29296 L
.37502 .29296 L
.37502 .31769 L
s
.37502 .29296 m
.39729 .29296 L
.39729 .26073 L
.37502 .26073 L
.37502 .29296 L
s
.37502 .26073 m
.39729 .26073 L
.39729 .2232 L
.37502 .2232 L
.37502 .26073 L
s
.37502 .2232 m
.39729 .2232 L
.39729 .18292 L
.37502 .18292 L
.37502 .2232 L
s
.37502 .18292 m
.39729 .18292 L
.39729 .14264 L
.37502 .14264 L
.37502 .18292 L
s
.37502 .14264 m
.39729 .14264 L
.39729 .10511 L
.37502 .10511 L
.37502 .14264 L
s
.37502 .10511 m
.39729 .10511 L
.39729 .07288 L
.37502 .07288 L
.37502 .10511 L
s
.37502 .07288 m
.39729 .07288 L
.39729 .04815 L
.37502 .04815 L
.37502 .07288 L
s
.37502 .04815 m
.39729 .04815 L
.39729 .03261 L
.37502 .03261 L
.37502 .04815 L
s
.37502 .03261 m
.39729 .03261 L
.39729 .0273 L
.37502 .0273 L
.37502 .03261 L
s
.37502 .0273 m
.39729 .0273 L
.39729 .03261 L
.37502 .03261 L
.37502 .0273 L
s
.37502 .03261 m
.39729 .03261 L
.39729 .04815 L
.37502 .04815 L
.37502 .03261 L
s
.37502 .04815 m
.39729 .04815 L
.39729 .07288 L
.37502 .07288 L
.37502 .04815 L
s
.37502 .07288 m
.39729 .07288 L
.39729 .10511 L
.37502 .10511 L
.37502 .07288 L
s
.37502 .10511 m
.39729 .10511 L
.39729 .14264 L
.37502 .14264 L
.37502 .10511 L
s
.37502 .14264 m
.39729 .14264 L
.39729 .18292 L
.37502 .18292 L
.37502 .14264 L
s
.37502 .18292 m
.39729 .18292 L
.39729 .2232 L
.37502 .2232 L
.37502 .18292 L
s
.37502 .2232 m
.39729 .2232 L
.39729 .26073 L
.37502 .26073 L
.37502 .2232 L
s
.37502 .26073 m
.39729 .26073 L
.39729 .29296 L
.37502 .29296 L
.37502 .26073 L
s
.37502 .29296 m
.39729 .29296 L
.39729 .31769 L
.37502 .31769 L
.37502 .29296 L
s
.37502 .31769 m
.39729 .31769 L
.39729 .33323 L
.37502 .33323 L
.37502 .31769 L
s
.37502 .33323 m
.39729 .33323 L
.39729 .33854 L
.37502 .33854 L
.37502 .33323 L
s
.97618 .0273 m
.97618 .07918 L
.97618 .13105 L
.97618 .18292 L
.97618 .23479 L
.97618 .28666 L
.97618 .33854 L
.97618 .33854 L
.97618 .28666 L
.97618 .23479 L
.97618 .18292 L
.97618 .13105 L
.97618 .07918 L
.97618 .0273 L
.97618 .0273 L
s
.97618 .18292 m
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
.97618 .18292 L
s
.97618 .33854 m
.97618 .33323 L
.97618 .31769 L
.97618 .29296 L
.97618 .26073 L
.97618 .2232 L
.97618 .18292 L
.97618 .14264 L
.97618 .10511 L
.97618 .07288 L
.97618 .04815 L
.97618 .03261 L
.97618 .0273 L
.97618 .03261 L
.97618 .04815 L
.97618 .07288 L
.97618 .10511 L
.97618 .14264 L
.97618 .18292 L
.97618 .2232 L
.97618 .26073 L
.97618 .29296 L
.97618 .31769 L
.97618 .33323 L
.97618 .33854 L
s
0 0 0 r
[(L)] .36616 .00826 0 0 Mshowa
[(S)] .97618 .00826 0 0 Mshowa
.039 .916 .04 r
1 Mabswid
.02381 .15491 m
.0397 .15491 L
.05558 .15491 L
.07147 .15491 L
.08735 .15491 L
.10324 .15491 L
.11912 .15491 L
.13501 .15491 L
.15089 .15491 L
.16678 .15491 L
.18267 .15491 L
.19855 .15491 L
.21444 .15491 L
.23032 .15491 L
.24621 .15491 L
.26209 .15491 L
.27798 .15491 L
.29386 .15491 L
.30975 .15491 L
.32564 .15491 L
.34142 .15507 L
.35729 .15554 L
.37317 .15601 L
.38905 .15648 L
.40488 .15707 L
.42075 .15779 L
.43662 .15851 L
.45248 .15922 L
.46835 .15994 L
.48422 .16066 L
.50009 .16138 L
.51596 .1621 L
.53183 .16281 L
.5477 .16353 L
.56357 .16425 L
.57944 .16497 L
.59531 .16569 L
.61118 .1664 L
.62705 .16712 L
.64292 .16784 L
.65879 .16856 L
.67466 .16928 L
.69053 .16999 L
.7064 .17071 L
.72227 .17143 L
.73814 .17215 L
.75401 .17287 L
.76988 .17359 L
.78575 .17431 L
.80161 .17503 L
Mistroke
.81748 .17575 L
.83335 .17647 L
.84922 .17719 L
.86509 .17791 L
.88096 .17863 L
.89683 .17936 L
.9127 .18009 L
.92857 .18083 L
.94444 .18157 L
.9603 .18234 L
.97617 .18313 L
Mfstroke
.02381 .14868 m
.0397 .14868 L
.05558 .14868 L
.07147 .14868 L
.08735 .14868 L
.10324 .14868 L
.11912 .14868 L
.13501 .14868 L
.15089 .14868 L
.16678 .14868 L
.18267 .14868 L
.19855 .14868 L
.21444 .14868 L
.23032 .14868 L
.24621 .14868 L
.26209 .14868 L
.27798 .14868 L
.29386 .14868 L
.30975 .14868 L
.32564 .14868 L
.34162 .14886 L
.3575 .14944 L
.37337 .15001 L
.38925 .15059 L
.40517 .15132 L
.42103 .1522 L
.43689 .15308 L
.45275 .15395 L
.46861 .15483 L
.48447 .15571 L
.50033 .15659 L
.5162 .15746 L
.53206 .15834 L
.54792 .15922 L
.56378 .1601 L
.57964 .16098 L
.5955 .16185 L
.61136 .16273 L
.62723 .16361 L
.64309 .16449 L
.65895 .16536 L
.67481 .16624 L
.69067 .16712 L
.70653 .168 L
.7224 .16887 L
.73826 .16975 L
.75412 .17063 L
.76998 .1715 L
.78584 .17238 L
.8017 .17326 L
Mistroke
.81757 .17413 L
.83343 .17501 L
.84929 .17588 L
.86515 .17676 L
.88101 .17763 L
.89687 .1785 L
.91274 .17936 L
.9286 .18022 L
.94446 .18107 L
.96033 .18191 L
.97619 .18271 L
Mfstroke
0 0 0 r
.02381 .1518 m
.33655 .1518 L
s
% Start of user PostScript
-50. -5. 0.24154 -5. MAarrowhead1
% End of user PostScript
.33655 .1518 m
.39729 .15381 L
s
% Start of user PostScript
0.24154 -5. 10. -4.67726 MAarrowhead1
% End of user PostScript
.39729 .15381 m
.97618 .18292 L
s
% Start of user PostScript
10. -4.67726 103. -0.000304527 MAarrowhead1
% End of user PostScript
.97618 .18292 m
.97618 .18292 L
s
% Start of user PostScript
103. -0.000304527 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .149 m
.02381 .14918 L
.02381 .14937 L
.02381 .14956 L
.02381 .14974 L
.02381 .14993 L
.02381 .15012 L
.02381 .1503 L
.02381 .15049 L
.02381 .15068 L
.02381 .15086 L
.02381 .15105 L
.02381 .15124 L
.02381 .15142 L
.02381 .15161 L
.02381 .1518 L
.02381 .15198 L
.02381 .15217 L
.02381 .15236 L
.02381 .15254 L
.02381 .15273 L
.02381 .15292 L
.02381 .1531 L
.02381 .15329 L
.02381 .15348 L
.02381 .15366 L
.02381 .15385 L
.02381 .15404 L
.02381 .15422 L
.02381 .15441 L
.02381 .1546 L
s
.04764 .149 m
.04764 .14918 L
.04764 .14937 L
.04764 .14956 L
.04764 .14974 L
.04764 .14993 L
.04764 .15012 L
.04764 .1503 L
.04764 .15049 L
.04764 .15068 L
.04764 .15086 L
.04764 .15105 L
.04764 .15124 L
.04764 .15142 L
.04764 .15161 L
.04764 .1518 L
.04764 .15198 L
.04764 .15217 L
.04764 .15236 L
.04764 .15254 L
.04764 .15273 L
.04764 .15292 L
.04764 .1531 L
.04764 .15329 L
.04764 .15348 L
.04764 .15366 L
.04764 .15385 L
.04764 .15404 L
.04764 .15422 L
.04764 .15441 L
.04764 .1546 L
s
.07147 .149 m
.07147 .14918 L
.07147 .14937 L
.07147 .14956 L
.07147 .14974 L
.07147 .14993 L
.07147 .15012 L
.07147 .1503 L
.07147 .15049 L
.07147 .15068 L
.07147 .15086 L
.07147 .15105 L
.07147 .15124 L
.07147 .15142 L
.07147 .15161 L
.07147 .1518 L
.07147 .15198 L
.07147 .15217 L
.07147 .15236 L
.07147 .15254 L
.07147 .15273 L
.07147 .15292 L
.07147 .1531 L
.07147 .15329 L
.07147 .15348 L
.07147 .15366 L
.07147 .15385 L
.07147 .15404 L
.07147 .15422 L
.07147 .15441 L
.07147 .1546 L
s
.09529 .149 m
.09529 .14918 L
.09529 .14937 L
.09529 .14956 L
.09529 .14974 L
.09529 .14993 L
.09529 .15012 L
.09529 .1503 L
.09529 .15049 L
.09529 .15068 L
.09529 .15086 L
.09529 .15105 L
.09529 .15124 L
.09529 .15142 L
.09529 .15161 L
.09529 .1518 L
.09529 .15198 L
.09529 .15217 L
.09529 .15236 L
.09529 .15254 L
.09529 .15273 L
.09529 .15292 L
.09529 .1531 L
.09529 .15329 L
.09529 .15348 L
.09529 .15366 L
.09529 .15385 L
.09529 .15404 L
.09529 .15422 L
.09529 .15441 L
.09529 .1546 L
s
.11912 .149 m
.11912 .14918 L
.11912 .14937 L
.11912 .14956 L
.11912 .14974 L
.11912 .14993 L
.11912 .15012 L
.11912 .1503 L
.11912 .15049 L
.11912 .15068 L
.11912 .15086 L
.11912 .15105 L
.11912 .15124 L
.11912 .15142 L
.11912 .15161 L
.11912 .1518 L
.11912 .15198 L
.11912 .15217 L
.11912 .15236 L
.11912 .15254 L
.11912 .15273 L
.11912 .15292 L
.11912 .1531 L
.11912 .15329 L
.11912 .15348 L
.11912 .15366 L
.11912 .15385 L
.11912 .15404 L
.11912 .15423 L
.11912 .15441 L
.11912 .1546 L
s
.14295 .149 m
.14295 .14918 L
.14295 .14937 L
.14295 .14956 L
.14295 .14974 L
.14295 .14993 L
.14295 .15012 L
.14295 .1503 L
.14295 .15049 L
.14295 .15068 L
.14295 .15086 L
.14295 .15105 L
.14295 .15124 L
.14295 .15142 L
.14295 .15161 L
.14295 .1518 L
.14295 .15198 L
.14295 .15217 L
.14295 .15236 L
.14295 .15254 L
.14295 .15273 L
.14295 .15292 L
.14295 .1531 L
.14295 .15329 L
.14295 .15348 L
.14295 .15366 L
.14295 .15385 L
.14295 .15404 L
.14295 .15423 L
.14295 .15441 L
.14295 .1546 L
s
.16678 .149 m
.16678 .14918 L
.16678 .14937 L
.16678 .14956 L
.16678 .14974 L
.16678 .14993 L
.16678 .15012 L
.16678 .1503 L
.16678 .15049 L
.16678 .15068 L
.16678 .15086 L
.16678 .15105 L
.16678 .15124 L
.16678 .15142 L
.16678 .15161 L
.16678 .1518 L
.16678 .15198 L
.16678 .15217 L
.16678 .15236 L
.16678 .15254 L
.16678 .15273 L
.16678 .15292 L
.16678 .1531 L
.16678 .15329 L
.16678 .15348 L
.16678 .15366 L
.16678 .15385 L
.16678 .15404 L
.16678 .15423 L
.16678 .15441 L
.16678 .1546 L
s
.19061 .149 m
.19061 .14918 L
.19061 .14937 L
.19061 .14956 L
.19061 .14974 L
.19061 .14993 L
.19061 .15012 L
.19061 .1503 L
.19061 .15049 L
.19061 .15068 L
.19061 .15086 L
.19061 .15105 L
.19061 .15124 L
.19061 .15142 L
.19061 .15161 L
.19061 .1518 L
.19061 .15198 L
.19061 .15217 L
.19061 .15236 L
.19061 .15254 L
.19061 .15273 L
.19061 .15292 L
.19061 .1531 L
.19061 .15329 L
.19061 .15348 L
.19061 .15366 L
.19061 .15385 L
.19061 .15404 L
.19061 .15423 L
.19061 .15441 L
.19061 .1546 L
s
.21444 .149 m
.21444 .14918 L
.21444 .14937 L
.21444 .14956 L
.21444 .14974 L
.21444 .14993 L
.21444 .15012 L
.21444 .1503 L
.21444 .15049 L
.21444 .15068 L
.21444 .15086 L
.21444 .15105 L
.21444 .15124 L
.21444 .15142 L
.21444 .15161 L
.21444 .1518 L
.21444 .15198 L
.21444 .15217 L
.21444 .15236 L
.21444 .15254 L
.21444 .15273 L
.21444 .15292 L
.21444 .1531 L
.21444 .15329 L
.21444 .15348 L
.21444 .15367 L
.21444 .15385 L
.21444 .15404 L
.21444 .15423 L
.21444 .15441 L
.21444 .1546 L
s
.23826 .149 m
.23826 .14918 L
.23826 .14937 L
.23826 .14956 L
.23826 .14974 L
.23826 .14993 L
.23826 .15012 L
.23826 .1503 L
.23826 .15049 L
.23826 .15068 L
.23826 .15086 L
.23826 .15105 L
.23826 .15124 L
.23826 .15142 L
.23826 .15161 L
.23826 .1518 L
.23826 .15198 L
.23826 .15217 L
.23826 .15236 L
.23826 .15254 L
.23826 .15273 L
.23826 .15292 L
.23826 .1531 L
.23826 .15329 L
.23826 .15348 L
.23826 .15367 L
.23826 .15385 L
.23826 .15404 L
.23826 .15423 L
.23826 .15441 L
.23826 .1546 L
s
.26209 .149 m
.26209 .14918 L
.26209 .14937 L
.26209 .14956 L
.26209 .14974 L
.26209 .14993 L
.26209 .15012 L
.26209 .1503 L
.26209 .15049 L
.26209 .15068 L
.26209 .15086 L
.26209 .15105 L
.26209 .15124 L
.26209 .15142 L
.26209 .15161 L
.26209 .1518 L
.26209 .15198 L
.26209 .15217 L
.26209 .15236 L
.26209 .15254 L
.26209 .15273 L
.26209 .15292 L
.26209 .1531 L
.26209 .15329 L
.26209 .15348 L
.26209 .15367 L
.26209 .15385 L
.26209 .15404 L
.26209 .15423 L
.26209 .15441 L
.26209 .1546 L
s
.28592 .14899 m
.28592 .14918 L
.28592 .14937 L
.28592 .14956 L
.28592 .14974 L
.28592 .14993 L
.28592 .15012 L
.28592 .1503 L
.28592 .15049 L
.28592 .15068 L
.28592 .15086 L
.28592 .15105 L
.28592 .15124 L
.28592 .15142 L
.28592 .15161 L
.28592 .1518 L
.28592 .15198 L
.28592 .15217 L
.28592 .15236 L
.28592 .15254 L
.28592 .15273 L
.28592 .15292 L
.28592 .1531 L
.28592 .15329 L
.28592 .15348 L
.28592 .15367 L
.28592 .15385 L
.28592 .15404 L
.28592 .15423 L
.28592 .15441 L
.28592 .1546 L
s
.30975 .14899 m
.30975 .14918 L
.30975 .14937 L
.30975 .14956 L
.30975 .14974 L
.30975 .14993 L
.30975 .15012 L
.30975 .1503 L
.30975 .15049 L
.30975 .15068 L
.30975 .15086 L
.30975 .15105 L
.30975 .15124 L
.30975 .15142 L
.30975 .15161 L
.30975 .1518 L
.30975 .15198 L
.30975 .15217 L
.30975 .15236 L
.30975 .15254 L
.30975 .15273 L
.30975 .15292 L
.30975 .15311 L
.30975 .15329 L
.30975 .15348 L
.30975 .15367 L
.30975 .15385 L
.30975 .15404 L
.30975 .15423 L
.30975 .15441 L
.30975 .1546 L
s
.33358 .14899 m
.33358 .14918 L
.33358 .14937 L
.33358 .14956 L
.33358 .14974 L
.33358 .14993 L
.33358 .15012 L
.33358 .1503 L
.33358 .15049 L
.33358 .15068 L
.33358 .15086 L
.33358 .15105 L
.33358 .15124 L
.33358 .15142 L
.33358 .15161 L
.33358 .1518 L
.33358 .15198 L
.33358 .15217 L
.33358 .15236 L
.33358 .15254 L
.33358 .15273 L
.33358 .15292 L
.33358 .15311 L
.33358 .15329 L
.33358 .15348 L
.33358 .15367 L
.33358 .15385 L
.33358 .15404 L
.33358 .15423 L
.33358 .15441 L
.33358 .1546 L
s
.35749 .14974 m
.35748 .14992 L
.35748 .15011 L
.35747 .15029 L
.35746 .15047 L
.35746 .15066 L
.35745 .15084 L
.35745 .15102 L
.35744 .15121 L
.35743 .15139 L
.35743 .15157 L
.35742 .15175 L
.35741 .15194 L
.35741 .15212 L
.3574 .1523 L
.3574 .15249 L
.35739 .15267 L
.35738 .15285 L
.35738 .15304 L
.35737 .15322 L
.35737 .1534 L
.35736 .15359 L
.35735 .15377 L
.35735 .15395 L
.35734 .15413 L
.35734 .15432 L
.35733 .1545 L
.35733 .15468 L
.35732 .15487 L
.35732 .15505 L
.35731 .15523 L
s
.3813 .1506 m
.3813 .15078 L
.38129 .15096 L
.38128 .15113 L
.38128 .15131 L
.38127 .15149 L
.38127 .15167 L
.38126 .15185 L
.38125 .15203 L
.38125 .1522 L
.38124 .15238 L
.38123 .15256 L
.38123 .15274 L
.38122 .15292 L
.38122 .1531 L
.38121 .15327 L
.3812 .15345 L
.3812 .15363 L
.38119 .15381 L
.38119 .15399 L
.38118 .15417 L
.38118 .15434 L
.38117 .15452 L
.38117 .1547 L
.38116 .15488 L
.38115 .15506 L
.38115 .15524 L
.38114 .15541 L
.38114 .15559 L
.38113 .15577 L
.38113 .15595 L
s
.40516 .15161 m
.40515 .15178 L
.40514 .15195 L
.40513 .15212 L
.40512 .1523 L
.40511 .15247 L
.4051 .15264 L
.40509 .15281 L
.40508 .15299 L
.40507 .15316 L
.40507 .15333 L
.40506 .1535 L
.40505 .15368 L
.40504 .15385 L
.40503 .15402 L
.40502 .1542 L
.40501 .15437 L
.405 .15454 L
.405 .15471 L
.40499 .15489 L
.40498 .15506 L
.40497 .15523 L
.40496 .1554 L
.40495 .15558 L
.40495 .15575 L
.40494 .15592 L
.40493 .15609 L
.40492 .15627 L
.40492 .15644 L
.40491 .15661 L
.4049 .15678 L
s
.42895 .15291 m
.42894 .15308 L
.42893 .15324 L
.42893 .15341 L
.42892 .15357 L
.42891 .15374 L
.4289 .1539 L
.42889 .15407 L
.42888 .15423 L
.42887 .1544 L
.42886 .15457 L
.42885 .15473 L
.42884 .1549 L
.42884 .15506 L
.42883 .15523 L
.42882 .15539 L
.42881 .15556 L
.4288 .15572 L
.42879 .15589 L
.42879 .15605 L
.42878 .15622 L
.42877 .15638 L
.42876 .15655 L
.42876 .15671 L
.42875 .15688 L
.42874 .15705 L
.42873 .15721 L
.42873 .15738 L
.42872 .15754 L
.42871 .15771 L
.4287 .15787 L
s
.45275 .15422 m
.45274 .15438 L
.45273 .15453 L
.45272 .15469 L
.45271 .15485 L
.4527 .15501 L
.45269 .15517 L
.45268 .15532 L
.45268 .15548 L
.45267 .15564 L
.45266 .1558 L
.45265 .15596 L
.45264 .15611 L
.45263 .15627 L
.45263 .15643 L
.45262 .15659 L
.45261 .15675 L
.4526 .1569 L
.45259 .15706 L
.45259 .15722 L
.45258 .15738 L
.45257 .15754 L
.45256 .1577 L
.45256 .15785 L
.45255 .15801 L
.45254 .15817 L
.45254 .15833 L
.45253 .15849 L
.45252 .15864 L
.45251 .1588 L
.45251 .15896 L
s
.47654 .15552 m
.47653 .15567 L
.47652 .15582 L
.47651 .15597 L
.4765 .15613 L
.4765 .15628 L
.47649 .15643 L
.47648 .15658 L
.47647 .15673 L
.47646 .15688 L
.47645 .15703 L
.47645 .15718 L
.47644 .15733 L
.47643 .15748 L
.47642 .15763 L
.47642 .15779 L
.47641 .15794 L
.4764 .15809 L
.47639 .15824 L
.47639 .15839 L
.47638 .15854 L
.47637 .15869 L
.47636 .15884 L
.47636 .15899 L
.47635 .15914 L
.47634 .15929 L
.47634 .15945 L
.47633 .1596 L
.47632 .15975 L
.47632 .1599 L
.47631 .16005 L
s
.50033 .15683 m
.50032 .15697 L
.50031 .15711 L
.50031 .15726 L
.5003 .1574 L
.50029 .15755 L
.50028 .15769 L
.50027 .15783 L
.50027 .15798 L
.50026 .15812 L
.50025 .15826 L
.50024 .15841 L
.50024 .15855 L
.50023 .15869 L
.50022 .15884 L
.50021 .15898 L
.50021 .15913 L
.5002 .15927 L
.50019 .15941 L
.50019 .15956 L
.50018 .1597 L
.50017 .15984 L
.50017 .15999 L
.50016 .16013 L
.50015 .16028 L
.50015 .16042 L
.50014 .16056 L
.50013 .16071 L
.50013 .16085 L
.50012 .16099 L
.50011 .16114 L
s
.52412 .15813 m
.52412 .15827 L
.52411 .1584 L
.5241 .15854 L
.52409 .15868 L
.52408 .15881 L
.52408 .15895 L
.52407 .15909 L
.52406 .15922 L
.52405 .15936 L
.52405 .1595 L
.52404 .15963 L
.52403 .15977 L
.52403 .15991 L
.52402 .16004 L
.52401 .16018 L
.52401 .16032 L
.524 .16045 L
.52399 .16059 L
.52399 .16073 L
.52398 .16086 L
.52397 .161 L
.52397 .16113 L
.52396 .16127 L
.52395 .16141 L
.52395 .16154 L
.52394 .16168 L
.52394 .16182 L
.52393 .16195 L
.52392 .16209 L
.52392 .16223 L
s
.54792 .15944 m
.54791 .15957 L
.5479 .1597 L
.54789 .15982 L
.54789 .15995 L
.54788 .16008 L
.54787 .16021 L
.54786 .16034 L
.54786 .16047 L
.54785 .1606 L
.54784 .16073 L
.54784 .16086 L
.54783 .16099 L
.54782 .16112 L
.54782 .16125 L
.54781 .16138 L
.5478 .16151 L
.5478 .16163 L
.54779 .16176 L
.54779 .16189 L
.54778 .16202 L
.54777 .16215 L
.54777 .16228 L
.54776 .16241 L
.54775 .16254 L
.54775 .16267 L
.54774 .1628 L
.54774 .16293 L
.54773 .16306 L
.54773 .16319 L
.54772 .16332 L
s
.57171 .16074 m
.5717 .16086 L
.57169 .16099 L
.57169 .16111 L
.57168 .16123 L
.57167 .16135 L
.57167 .16147 L
.57166 .1616 L
.57165 .16172 L
.57165 .16184 L
.57164 .16196 L
.57163 .16208 L
.57163 .16221 L
.57162 .16233 L
.57161 .16245 L
.57161 .16257 L
.5716 .16269 L
.5716 .16282 L
.57159 .16294 L
.57158 .16306 L
.57158 .16318 L
.57157 .16331 L
.57157 .16343 L
.57156 .16355 L
.57156 .16367 L
.57155 .16379 L
.57155 .16392 L
.57154 .16404 L
.57153 .16416 L
.57153 .16428 L
.57152 .16441 L
s
.5955 .16205 m
.59549 .16216 L
.59549 .16228 L
.59548 .16239 L
.59547 .16251 L
.59547 .16262 L
.59546 .16274 L
.59546 .16285 L
.59545 .16297 L
.59544 .16308 L
.59544 .16319 L
.59543 .16331 L
.59542 .16342 L
.59542 .16354 L
.59541 .16365 L
.59541 .16377 L
.5954 .16388 L
.5954 .164 L
.59539 .16411 L
.59538 .16423 L
.59538 .16434 L
.59537 .16446 L
.59537 .16457 L
.59536 .16469 L
.59536 .1648 L
.59535 .16492 L
.59535 .16503 L
.59534 .16515 L
.59534 .16526 L
.59533 .16538 L
.59533 .16549 L
s
.61929 .16335 m
.61929 .16346 L
.61928 .16357 L
.61927 .16367 L
.61927 .16378 L
.61926 .16389 L
.61926 .164 L
.61925 .1641 L
.61924 .16421 L
.61924 .16432 L
.61923 .16443 L
.61923 .16454 L
.61922 .16464 L
.61922 .16475 L
.61921 .16486 L
.61921 .16497 L
.6192 .16507 L
.61919 .16518 L
.61919 .16529 L
.61918 .1654 L
.61918 .16551 L
.61917 .16561 L
.61917 .16572 L
.61916 .16583 L
.61916 .16594 L
.61915 .16604 L
.61915 .16615 L
.61914 .16626 L
.61914 .16637 L
.61914 .16648 L
.61913 .16658 L
s
.64309 .16465 m
.64308 .16476 L
.64307 .16486 L
.64307 .16496 L
.64306 .16506 L
.64306 .16516 L
.64305 .16526 L
.64305 .16536 L
.64304 .16546 L
.64304 .16556 L
.64303 .16566 L
.64302 .16576 L
.64302 .16586 L
.64301 .16596 L
.64301 .16606 L
.643 .16616 L
.643 .16626 L
.64299 .16636 L
.64299 .16646 L
.64298 .16657 L
.64298 .16667 L
.64297 .16677 L
.64297 .16687 L
.64297 .16697 L
.64296 .16707 L
.64296 .16717 L
.64295 .16727 L
.64295 .16737 L
.64294 .16747 L
.64294 .16757 L
.64293 .16767 L
s
.66688 .16596 m
.66687 .16605 L
.66687 .16615 L
.66686 .16624 L
.66686 .16633 L
.66685 .16643 L
.66685 .16652 L
.66684 .16661 L
.66684 .16671 L
.66683 .1668 L
.66683 .16689 L
.66682 .16699 L
.66682 .16708 L
.66681 .16717 L
.66681 .16727 L
.6668 .16736 L
.6668 .16745 L
.66679 .16755 L
.66679 .16764 L
.66678 .16773 L
.66678 .16783 L
.66677 .16792 L
.66677 .16801 L
.66677 .16811 L
.66676 .1682 L
.66676 .16829 L
.66675 .16839 L
.66675 .16848 L
.66675 .16857 L
.66674 .16867 L
.66674 .16876 L
s
.69067 .16726 m
.69067 .16735 L
.69066 .16744 L
.69066 .16752 L
.69065 .16761 L
.69065 .16769 L
.69064 .16778 L
.69064 .16787 L
.69063 .16795 L
.69063 .16804 L
.69062 .16813 L
.69062 .16821 L
.69061 .1683 L
.69061 .16838 L
.6906 .16847 L
.6906 .16856 L
.6906 .16864 L
.69059 .16873 L
.69059 .16882 L
.69058 .1689 L
.69058 .16899 L
.69058 .16907 L
.69057 .16916 L
.69057 .16925 L
.69056 .16933 L
.69056 .16942 L
.69056 .16951 L
.69055 .16959 L
.69055 .16968 L
.69054 .16976 L
.69054 .16985 L
s
.71446 .16857 m
.71446 .16865 L
.71445 .16873 L
.71445 .1688 L
.71445 .16888 L
.71444 .16896 L
.71444 .16904 L
.71443 .16912 L
.71443 .1692 L
.71442 .16928 L
.71442 .16936 L
.71441 .16944 L
.71441 .16952 L
.71441 .1696 L
.7144 .16967 L
.7144 .16975 L
.71439 .16983 L
.71439 .16991 L
.71439 .16999 L
.71438 .17007 L
.71438 .17015 L
.71438 .17023 L
.71437 .17031 L
.71437 .17039 L
.71436 .17047 L
.71436 .17054 L
.71436 .17062 L
.71435 .1707 L
.71435 .17078 L
.71435 .17086 L
.71434 .17094 L
s
.73826 .16987 m
.73825 .16994 L
.73825 .17001 L
.73824 .17009 L
.73824 .17016 L
.73824 .17023 L
.73823 .1703 L
.73823 .17037 L
.73822 .17045 L
.73822 .17052 L
.73822 .17059 L
.73821 .17066 L
.73821 .17073 L
.7382 .17081 L
.7382 .17088 L
.7382 .17095 L
.73819 .17102 L
.73819 .17109 L
.73819 .17117 L
.73818 .17124 L
.73818 .17131 L
.73818 .17138 L
.73817 .17145 L
.73817 .17153 L
.73817 .1716 L
.73816 .17167 L
.73816 .17174 L
.73816 .17181 L
.73815 .17189 L
.73815 .17196 L
.73815 .17203 L
s
.76205 .17117 m
.76204 .17124 L
.76204 .1713 L
.76204 .17137 L
.76203 .17143 L
.76203 .1715 L
.76203 .17156 L
.76202 .17163 L
.76202 .17169 L
.76202 .17176 L
.76201 .17182 L
.76201 .17189 L
.76201 .17195 L
.762 .17202 L
.762 .17208 L
.762 .17215 L
.76199 .17221 L
.76199 .17228 L
.76199 .17234 L
.76198 .17241 L
.76198 .17247 L
.76198 .17254 L
.76197 .1726 L
.76197 .17267 L
.76197 .17273 L
.76196 .1728 L
.76196 .17286 L
.76196 .17293 L
.76196 .17299 L
.76195 .17306 L
.76195 .17312 L
s
.78584 .17248 m
.78584 .17254 L
.78583 .17259 L
.78583 .17265 L
.78583 .17271 L
.78582 .17277 L
.78582 .17282 L
.78582 .17288 L
.78581 .17294 L
.78581 .173 L
.78581 .17306 L
.78581 .17311 L
.7858 .17317 L
.7858 .17323 L
.7858 .17329 L
.78579 .17334 L
.78579 .1734 L
.78579 .17346 L
.78578 .17352 L
.78578 .17358 L
.78578 .17363 L
.78578 .17369 L
.78577 .17375 L
.78577 .17381 L
.78577 .17386 L
.78577 .17392 L
.78576 .17398 L
.78576 .17404 L
.78576 .1741 L
.78576 .17415 L
.78575 .17421 L
s
.80963 .17378 m
.80963 .17383 L
.80963 .17388 L
.80962 .17393 L
.80962 .17398 L
.80962 .17403 L
.80962 .17408 L
.80961 .17413 L
.80961 .17419 L
.80961 .17424 L
.8096 .17429 L
.8096 .17434 L
.8096 .17439 L
.8096 .17444 L
.80959 .17449 L
.80959 .17454 L
.80959 .17459 L
.80959 .17464 L
.80958 .17469 L
.80958 .17474 L
.80958 .17479 L
.80958 .17485 L
.80957 .1749 L
.80957 .17495 L
.80957 .175 L
.80957 .17505 L
.80957 .1751 L
.80956 .17515 L
.80956 .1752 L
.80956 .17525 L
.80956 .1753 L
s
.83343 .17508 m
.83342 .17512 L
.83342 .17517 L
.83342 .17521 L
.83342 .17526 L
.83341 .1753 L
.83341 .17534 L
.83341 .17539 L
.83341 .17543 L
.8334 .17547 L
.8334 .17552 L
.8334 .17556 L
.8334 .17561 L
.83339 .17565 L
.83339 .17569 L
.83339 .17574 L
.83339 .17578 L
.83339 .17583 L
.83338 .17587 L
.83338 .17591 L
.83338 .17596 L
.83338 .176 L
.83338 .17604 L
.83337 .17609 L
.83337 .17613 L
.83337 .17618 L
.83337 .17622 L
.83337 .17626 L
.83336 .17631 L
.83336 .17635 L
.83336 .17639 L
s
.85722 .17638 m
.85722 .17642 L
.85721 .17645 L
.85721 .17649 L
.85721 .17653 L
.85721 .17657 L
.85721 .1766 L
.8572 .17664 L
.8572 .17668 L
.8572 .17671 L
.8572 .17675 L
.8572 .17679 L
.85719 .17682 L
.85719 .17686 L
.85719 .1769 L
.85719 .17693 L
.85719 .17697 L
.85718 .17701 L
.85718 .17705 L
.85718 .17708 L
.85718 .17712 L
.85718 .17716 L
.85718 .17719 L
.85717 .17723 L
.85717 .17727 L
.85717 .1773 L
.85717 .17734 L
.85717 .17738 L
.85717 .17741 L
.85716 .17745 L
.85716 .17749 L
s
.88101 .17768 m
.88101 .17771 L
.88101 .17774 L
.88101 .17777 L
.881 .1778 L
.881 .17783 L
.881 .17786 L
.881 .17789 L
.881 .17792 L
.881 .17795 L
.88099 .17798 L
.88099 .17801 L
.88099 .17804 L
.88099 .17807 L
.88099 .1781 L
.88099 .17813 L
.88099 .17816 L
.88098 .17819 L
.88098 .17822 L
.88098 .17825 L
.88098 .17828 L
.88098 .17831 L
.88098 .17834 L
.88098 .17837 L
.88097 .1784 L
.88097 .17843 L
.88097 .17846 L
.88097 .17849 L
.88097 .17852 L
.88097 .17855 L
.88097 .17858 L
s
.9048 .17897 m
.9048 .17899 L
.9048 .17902 L
.9048 .17904 L
.9048 .17907 L
.9048 .17909 L
.9048 .17911 L
.90479 .17914 L
.90479 .17916 L
.90479 .17919 L
.90479 .17921 L
.90479 .17923 L
.90479 .17926 L
.90479 .17928 L
.90479 .1793 L
.90479 .17933 L
.90478 .17935 L
.90478 .17938 L
.90478 .1794 L
.90478 .17942 L
.90478 .17945 L
.90478 .17947 L
.90478 .17949 L
.90478 .17952 L
.90477 .17954 L
.90477 .17957 L
.90477 .17959 L
.90477 .17961 L
.90477 .17964 L
.90477 .17966 L
.90477 .17969 L
s
.9286 .18025 m
.9286 .18027 L
.9286 .18029 L
.92859 .18031 L
.92859 .18033 L
.92859 .18034 L
.92859 .18036 L
.92859 .18038 L
.92859 .1804 L
.92859 .18042 L
.92859 .18043 L
.92859 .18045 L
.92859 .18047 L
.92859 .18049 L
.92858 .18051 L
.92858 .18052 L
.92858 .18054 L
.92858 .18056 L
.92858 .18058 L
.92858 .1806 L
.92858 .18062 L
.92858 .18063 L
.92858 .18065 L
.92858 .18067 L
.92858 .18069 L
.92857 .18071 L
.92857 .18072 L
.92857 .18074 L
.92857 .18076 L
.92857 .18078 L
.92857 .1808 L
s
.95239 .18152 m
.95239 .18153 L
.95239 .18154 L
.95239 .18156 L
.95239 .18157 L
.95239 .18158 L
.95239 .1816 L
.95239 .18161 L
.95239 .18163 L
.95239 .18164 L
.95239 .18165 L
.95238 .18167 L
.95238 .18168 L
.95238 .18169 L
.95238 .18171 L
.95238 .18172 L
.95238 .18174 L
.95238 .18175 L
.95238 .18176 L
.95238 .18178 L
.95238 .18179 L
.95238 .1818 L
.95238 .18182 L
.95238 .18183 L
.95238 .18185 L
.95237 .18186 L
.95237 .18187 L
.95237 .18189 L
.95237 .1819 L
.95237 .18191 L
.95237 .18193 L
s
.02381 .18603 m
.03968 .18603 L
.05556 .18603 L
.07143 .18603 L
.0873 .18603 L
.10317 .18603 L
.11905 .18603 L
.13492 .18603 L
.15079 .18603 L
.16667 .18603 L
.18254 .18603 L
.19841 .18603 L
.21428 .18603 L
.23016 .18603 L
.24603 .18603 L
.2619 .18603 L
.27777 .18603 L
.29365 .18603 L
.30952 .18603 L
.32539 .18603 L
.34127 .18601 L
.35714 .18596 L
.37301 .18591 L
.38888 .18586 L
.40476 .18579 L
.42063 .18571 L
.4365 .18563 L
.45238 .18555 L
.46825 .18548 L
.48412 .1854 L
.49999 .18532 L
.51587 .18524 L
.53174 .18516 L
.54761 .18508 L
.56349 .185 L
.57936 .18492 L
.59523 .18484 L
.6111 .18476 L
.62698 .18468 L
.64285 .18461 L
.65872 .18453 L
.6746 .18445 L
.69047 .18437 L
.70634 .18429 L
.72221 .18421 L
.73809 .18413 L
.75396 .18406 L
.76983 .18398 L
.78571 .1839 L
.80158 .18382 L
Mistroke
.81745 .18374 L
.83332 .18367 L
.8492 .18359 L
.86507 .18352 L
.88094 .18344 L
.89682 .18337 L
.91269 .1833 L
.92856 .18324 L
.94443 .18319 L
.96031 .18315 L
.97618 .18313 L
Mfstroke
.02381 .17981 m
.03968 .17981 L
.05556 .17981 L
.07143 .17981 L
.0873 .17981 L
.10317 .17981 L
.11905 .17981 L
.13492 .17981 L
.15079 .17981 L
.16667 .17981 L
.18254 .17981 L
.19841 .17981 L
.21428 .17981 L
.23016 .17981 L
.24603 .17981 L
.2619 .17981 L
.27777 .17981 L
.29365 .17981 L
.30952 .17981 L
.32539 .17981 L
.34127 .17983 L
.35714 .17988 L
.37301 .17993 L
.38888 .17998 L
.40476 .18005 L
.42063 .18013 L
.4365 .18021 L
.45238 .18029 L
.46825 .18037 L
.48412 .18044 L
.49999 .18052 L
.51587 .1806 L
.53174 .18068 L
.54761 .18076 L
.56349 .18084 L
.57936 .18092 L
.59523 .181 L
.6111 .18108 L
.62698 .18116 L
.64285 .18124 L
.65872 .18131 L
.6746 .18139 L
.69047 .18147 L
.70634 .18155 L
.72221 .18163 L
.73809 .18171 L
.75396 .18179 L
.76983 .18186 L
.78571 .18194 L
.80158 .18202 L
Mistroke
.81745 .1821 L
.83332 .18217 L
.8492 .18225 L
.86507 .18232 L
.88094 .1824 L
.89682 .18247 L
.91269 .18254 L
.92856 .1826 L
.94443 .18266 L
.96031 .1827 L
.97618 .18271 L
Mfstroke
0 0 0 r
.02381 .18292 m
.33504 .18292 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
.33504 .18292 m
.39729 .18292 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
.39729 .18292 m
.97618 .18292 L
s
% Start of user PostScript
10. 0 103. 0 MAarrowhead1
% End of user PostScript
.97618 .18292 m
.97618 .18292 L
s
% Start of user PostScript
103. 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .18012 m
.02381 .18031 L
.02381 .18049 L
.02381 .18068 L
.02381 .18087 L
.02381 .18105 L
.02381 .18124 L
.02381 .18143 L
.02381 .18161 L
.02381 .1818 L
.02381 .18199 L
.02381 .18217 L
.02381 .18236 L
.02381 .18255 L
.02381 .18273 L
.02381 .18292 L
.02381 .18311 L
.02381 .18329 L
.02381 .18348 L
.02381 .18367 L
.02381 .18385 L
.02381 .18404 L
.02381 .18423 L
.02381 .18441 L
.02381 .1846 L
.02381 .18479 L
.02381 .18497 L
.02381 .18516 L
.02381 .18535 L
.02381 .18553 L
.02381 .18572 L
s
.04762 .18012 m
.04762 .18031 L
.04762 .18049 L
.04762 .18068 L
.04762 .18087 L
.04762 .18105 L
.04762 .18124 L
.04762 .18143 L
.04762 .18161 L
.04762 .1818 L
.04762 .18199 L
.04762 .18217 L
.04762 .18236 L
.04762 .18255 L
.04762 .18273 L
.04762 .18292 L
.04762 .18311 L
.04762 .18329 L
.04762 .18348 L
.04762 .18367 L
.04762 .18385 L
.04762 .18404 L
.04762 .18423 L
.04762 .18441 L
.04762 .1846 L
.04762 .18479 L
.04762 .18497 L
.04762 .18516 L
.04762 .18535 L
.04762 .18553 L
.04762 .18572 L
s
.07143 .18012 m
.07143 .18031 L
.07143 .18049 L
.07143 .18068 L
.07143 .18087 L
.07143 .18105 L
.07143 .18124 L
.07143 .18143 L
.07143 .18161 L
.07143 .1818 L
.07143 .18199 L
.07143 .18217 L
.07143 .18236 L
.07143 .18255 L
.07143 .18273 L
.07143 .18292 L
.07143 .18311 L
.07143 .18329 L
.07143 .18348 L
.07143 .18367 L
.07143 .18385 L
.07143 .18404 L
.07143 .18423 L
.07143 .18441 L
.07143 .1846 L
.07143 .18479 L
.07143 .18497 L
.07143 .18516 L
.07143 .18535 L
.07143 .18553 L
.07143 .18572 L
s
.09524 .18012 m
.09524 .18031 L
.09524 .18049 L
.09524 .18068 L
.09524 .18087 L
.09524 .18105 L
.09524 .18124 L
.09524 .18143 L
.09524 .18161 L
.09524 .1818 L
.09524 .18199 L
.09524 .18217 L
.09524 .18236 L
.09524 .18255 L
.09524 .18273 L
.09524 .18292 L
.09524 .18311 L
.09524 .18329 L
.09524 .18348 L
.09524 .18367 L
.09524 .18385 L
.09524 .18404 L
.09524 .18423 L
.09524 .18441 L
.09524 .1846 L
.09524 .18479 L
.09524 .18497 L
.09524 .18516 L
.09524 .18535 L
.09524 .18553 L
.09524 .18572 L
s
.11905 .18012 m
.11905 .18031 L
.11905 .18049 L
.11905 .18068 L
.11905 .18087 L
.11905 .18105 L
.11905 .18124 L
.11905 .18143 L
.11905 .18161 L
.11905 .1818 L
.11905 .18199 L
.11905 .18217 L
.11905 .18236 L
.11905 .18255 L
.11905 .18273 L
.11905 .18292 L
.11905 .18311 L
.11905 .18329 L
.11905 .18348 L
.11905 .18367 L
.11905 .18385 L
.11905 .18404 L
.11905 .18423 L
.11905 .18441 L
.11905 .1846 L
.11905 .18479 L
.11905 .18497 L
.11905 .18516 L
.11905 .18535 L
.11905 .18553 L
.11905 .18572 L
s
.14286 .18012 m
.14286 .18031 L
.14286 .18049 L
.14286 .18068 L
.14286 .18087 L
.14286 .18105 L
.14286 .18124 L
.14286 .18143 L
.14286 .18161 L
.14286 .1818 L
.14286 .18199 L
.14286 .18217 L
.14286 .18236 L
.14286 .18255 L
.14286 .18273 L
.14286 .18292 L
.14286 .18311 L
.14286 .18329 L
.14286 .18348 L
.14286 .18367 L
.14286 .18385 L
.14286 .18404 L
.14286 .18423 L
.14286 .18441 L
.14286 .1846 L
.14286 .18479 L
.14286 .18497 L
.14286 .18516 L
.14286 .18535 L
.14286 .18554 L
.14286 .18572 L
s
.16667 .18012 m
.16667 .18031 L
.16667 .18049 L
.16667 .18068 L
.16667 .18087 L
.16667 .18105 L
.16667 .18124 L
.16667 .18143 L
.16667 .18161 L
.16667 .1818 L
.16667 .18199 L
.16667 .18217 L
.16667 .18236 L
.16667 .18255 L
.16667 .18273 L
.16667 .18292 L
.16667 .18311 L
.16667 .18329 L
.16667 .18348 L
.16667 .18367 L
.16667 .18385 L
.16667 .18404 L
.16667 .18423 L
.16667 .18441 L
.16667 .1846 L
.16667 .18479 L
.16667 .18497 L
.16667 .18516 L
.16667 .18535 L
.16667 .18554 L
.16667 .18572 L
s
.19047 .18012 m
.19047 .18031 L
.19047 .18049 L
.19047 .18068 L
.19047 .18087 L
.19047 .18105 L
.19047 .18124 L
.19047 .18143 L
.19047 .18161 L
.19047 .1818 L
.19047 .18199 L
.19047 .18217 L
.19047 .18236 L
.19047 .18255 L
.19047 .18273 L
.19047 .18292 L
.19047 .18311 L
.19047 .18329 L
.19047 .18348 L
.19047 .18367 L
.19047 .18385 L
.19047 .18404 L
.19047 .18423 L
.19047 .18441 L
.19047 .1846 L
.19047 .18479 L
.19047 .18497 L
.19047 .18516 L
.19047 .18535 L
.19047 .18554 L
.19047 .18572 L
s
.21428 .18012 m
.21428 .18031 L
.21428 .18049 L
.21428 .18068 L
.21428 .18087 L
.21428 .18105 L
.21428 .18124 L
.21428 .18143 L
.21428 .18161 L
.21428 .1818 L
.21428 .18199 L
.21428 .18217 L
.21428 .18236 L
.21428 .18255 L
.21428 .18273 L
.21428 .18292 L
.21428 .18311 L
.21428 .18329 L
.21428 .18348 L
.21428 .18367 L
.21428 .18385 L
.21428 .18404 L
.21428 .18423 L
.21428 .18441 L
.21428 .1846 L
.21428 .18479 L
.21428 .18498 L
.21428 .18516 L
.21428 .18535 L
.21428 .18554 L
.21428 .18572 L
s
.23809 .18012 m
.23809 .18031 L
.23809 .18049 L
.23809 .18068 L
.23809 .18087 L
.23809 .18105 L
.23809 .18124 L
.23809 .18143 L
.23809 .18161 L
.23809 .1818 L
.23809 .18199 L
.23809 .18217 L
.23809 .18236 L
.23809 .18255 L
.23809 .18273 L
.23809 .18292 L
.23809 .18311 L
.23809 .18329 L
.23809 .18348 L
.23809 .18367 L
.23809 .18385 L
.23809 .18404 L
.23809 .18423 L
.23809 .18441 L
.23809 .1846 L
.23809 .18479 L
.23809 .18498 L
.23809 .18516 L
.23809 .18535 L
.23809 .18554 L
.23809 .18572 L
s
.2619 .18012 m
.2619 .18031 L
.2619 .18049 L
.2619 .18068 L
.2619 .18087 L
.2619 .18105 L
.2619 .18124 L
.2619 .18143 L
.2619 .18161 L
.2619 .1818 L
.2619 .18199 L
.2619 .18217 L
.2619 .18236 L
.2619 .18255 L
.2619 .18273 L
.2619 .18292 L
.2619 .18311 L
.2619 .18329 L
.2619 .18348 L
.2619 .18367 L
.2619 .18385 L
.2619 .18404 L
.2619 .18423 L
.2619 .18441 L
.2619 .1846 L
.2619 .18479 L
.2619 .18498 L
.2619 .18516 L
.2619 .18535 L
.2619 .18554 L
.2619 .18572 L
s
.28571 .18012 m
.28571 .18031 L
.28571 .18049 L
.28571 .18068 L
.28571 .18087 L
.28571 .18105 L
.28571 .18124 L
.28571 .18143 L
.28571 .18161 L
.28571 .1818 L
.28571 .18199 L
.28571 .18217 L
.28571 .18236 L
.28571 .18255 L
.28571 .18273 L
.28571 .18292 L
.28571 .18311 L
.28571 .18329 L
.28571 .18348 L
.28571 .18367 L
.28571 .18385 L
.28571 .18404 L
.28571 .18423 L
.28571 .18442 L
.28571 .1846 L
.28571 .18479 L
.28571 .18498 L
.28571 .18516 L
.28571 .18535 L
.28571 .18554 L
.28571 .18572 L
s
.30952 .18012 m
.30952 .1803 L
.30952 .18049 L
.30952 .18068 L
.30952 .18087 L
.30952 .18105 L
.30952 .18124 L
.30952 .18143 L
.30952 .18161 L
.30952 .1818 L
.30952 .18199 L
.30952 .18217 L
.30952 .18236 L
.30952 .18255 L
.30952 .18273 L
.30952 .18292 L
.30952 .18311 L
.30952 .18329 L
.30952 .18348 L
.30952 .18367 L
.30952 .18385 L
.30952 .18404 L
.30952 .18423 L
.30952 .18442 L
.30952 .1846 L
.30952 .18479 L
.30952 .18498 L
.30952 .18516 L
.30952 .18535 L
.30952 .18554 L
.30952 .18572 L
s
.33333 .18012 m
.33333 .1803 L
.33333 .18049 L
.33333 .18068 L
.33333 .18087 L
.33333 .18105 L
.33333 .18124 L
.33333 .18143 L
.33333 .18161 L
.33333 .1818 L
.33333 .18199 L
.33333 .18217 L
.33333 .18236 L
.33333 .18255 L
.33333 .18273 L
.33333 .18292 L
.33333 .18311 L
.33333 .18329 L
.33333 .18348 L
.33333 .18367 L
.33333 .18385 L
.33333 .18404 L
.33333 .18423 L
.33333 .18442 L
.33333 .1846 L
.33333 .18479 L
.33333 .18498 L
.33333 .18516 L
.33333 .18535 L
.33333 .18554 L
.33333 .18572 L
s
.35714 .18018 m
.35714 .18037 L
.35714 .18055 L
.35714 .18073 L
.35714 .18091 L
.35714 .1811 L
.35714 .18128 L
.35714 .18146 L
.35714 .18164 L
.35714 .18183 L
.35714 .18201 L
.35714 .18219 L
.35714 .18237 L
.35714 .18256 L
.35714 .18274 L
.35714 .18292 L
.35714 .1831 L
.35714 .18329 L
.35714 .18347 L
.35714 .18365 L
.35714 .18383 L
.35714 .18402 L
.35714 .1842 L
.35714 .18438 L
.35714 .18456 L
.35714 .18475 L
.35714 .18493 L
.35714 .18511 L
.35714 .18529 L
.35714 .18548 L
.35714 .18566 L
s
.38095 .18025 m
.38095 .18043 L
.38095 .18061 L
.38095 .18079 L
.38095 .18096 L
.38095 .18114 L
.38095 .18132 L
.38095 .1815 L
.38095 .18168 L
.38095 .18185 L
.38095 .18203 L
.38095 .18221 L
.38095 .18239 L
.38095 .18256 L
.38095 .18274 L
.38095 .18292 L
.38095 .1831 L
.38095 .18328 L
.38095 .18345 L
.38095 .18363 L
.38095 .18381 L
.38095 .18399 L
.38095 .18417 L
.38095 .18434 L
.38095 .18452 L
.38095 .1847 L
.38095 .18488 L
.38095 .18505 L
.38095 .18523 L
.38095 .18541 L
.38095 .18559 L
s
.40477 .18034 m
.40477 .18051 L
.40477 .18068 L
.40476 .18085 L
.40476 .18102 L
.40476 .1812 L
.40476 .18137 L
.40476 .18154 L
.40476 .18171 L
.40476 .18189 L
.40476 .18206 L
.40476 .18223 L
.40476 .1824 L
.40476 .18258 L
.40476 .18275 L
.40476 .18292 L
.40476 .18309 L
.40476 .18327 L
.40476 .18344 L
.40476 .18361 L
.40476 .18378 L
.40476 .18395 L
.40476 .18413 L
.40476 .1843 L
.40476 .18447 L
.40476 .18464 L
.40476 .18482 L
.40476 .18499 L
.40477 .18516 L
.40477 .18533 L
.40477 .18551 L
s
.42858 .18044 m
.42858 .18061 L
.42857 .18077 L
.42857 .18094 L
.42857 .1811 L
.42857 .18127 L
.42857 .18143 L
.42857 .1816 L
.42857 .18176 L
.42857 .18193 L
.42857 .18209 L
.42857 .18226 L
.42857 .18242 L
.42857 .18259 L
.42857 .18276 L
.42857 .18292 L
.42857 .18309 L
.42857 .18325 L
.42857 .18342 L
.42857 .18358 L
.42857 .18375 L
.42857 .18391 L
.42857 .18408 L
.42857 .18424 L
.42857 .18441 L
.42857 .18457 L
.42857 .18474 L
.42857 .1849 L
.42857 .18507 L
.42858 .18523 L
.42858 .1854 L
s
.45239 .18055 m
.45238 .18071 L
.45238 .18087 L
.45238 .18102 L
.45238 .18118 L
.45238 .18134 L
.45238 .1815 L
.45238 .18166 L
.45238 .18181 L
.45238 .18197 L
.45238 .18213 L
.45238 .18229 L
.45238 .18245 L
.45238 .1826 L
.45238 .18276 L
.45238 .18292 L
.45238 .18308 L
.45238 .18324 L
.45238 .18339 L
.45238 .18355 L
.45238 .18371 L
.45238 .18387 L
.45238 .18403 L
.45238 .18418 L
.45238 .18434 L
.45238 .1845 L
.45238 .18466 L
.45238 .18482 L
.45238 .18498 L
.45238 .18513 L
.45239 .18529 L
s
.4762 .18066 m
.47619 .18081 L
.47619 .18096 L
.47619 .18111 L
.47619 .18126 L
.47619 .18141 L
.47619 .18156 L
.47619 .18171 L
.47619 .18186 L
.47619 .18201 L
.47619 .18217 L
.47619 .18232 L
.47619 .18247 L
.47619 .18262 L
.47619 .18277 L
.47619 .18292 L
.47619 .18307 L
.47619 .18322 L
.47619 .18337 L
.47619 .18352 L
.47619 .18368 L
.47619 .18383 L
.47619 .18398 L
.47619 .18413 L
.47619 .18428 L
.47619 .18443 L
.47619 .18458 L
.47619 .18473 L
.47619 .18488 L
.47619 .18503 L
.4762 .18518 L
s
.5 .18076 m
.5 .18091 L
.5 .18105 L
.5 .1812 L
.5 .18134 L
.5 .18148 L
.5 .18163 L
.5 .18177 L
.5 .18191 L
.5 .18206 L
.5 .1822 L
.5 .18235 L
.5 .18249 L
.49999 .18263 L
.49999 .18278 L
.49999 .18292 L
.49999 .18306 L
.49999 .18321 L
.5 .18335 L
.5 .1835 L
.5 .18364 L
.5 .18378 L
.5 .18393 L
.5 .18407 L
.5 .18421 L
.5 .18436 L
.5 .1845 L
.5 .18465 L
.5 .18479 L
.5 .18493 L
.5 .18508 L
s
.52381 .18087 m
.52381 .18101 L
.52381 .18114 L
.52381 .18128 L
.52381 .18142 L
.52381 .18155 L
.52381 .18169 L
.52381 .18183 L
.52381 .18196 L
.52381 .1821 L
.5238 .18224 L
.5238 .18237 L
.5238 .18251 L
.5238 .18265 L
.5238 .18278 L
.5238 .18292 L
.5238 .18306 L
.5238 .18319 L
.5238 .18333 L
.5238 .18347 L
.5238 .1836 L
.52381 .18374 L
.52381 .18388 L
.52381 .18401 L
.52381 .18415 L
.52381 .18429 L
.52381 .18442 L
.52381 .18456 L
.52381 .1847 L
.52381 .18483 L
.52381 .18497 L
s
.54762 .18098 m
.54762 .18111 L
.54762 .18124 L
.54762 .18137 L
.54762 .1815 L
.54762 .18163 L
.54762 .18175 L
.54762 .18188 L
.54762 .18201 L
.54761 .18214 L
.54761 .18227 L
.54761 .1824 L
.54761 .18253 L
.54761 .18266 L
.54761 .18279 L
.54761 .18292 L
.54761 .18305 L
.54761 .18318 L
.54761 .18331 L
.54761 .18344 L
.54761 .18357 L
.54761 .1837 L
.54762 .18383 L
.54762 .18396 L
.54762 .18409 L
.54762 .18422 L
.54762 .18435 L
.54762 .18447 L
.54762 .1846 L
.54762 .18473 L
.54762 .18486 L
s
.57143 .18108 m
.57143 .18121 L
.57143 .18133 L
.57143 .18145 L
.57143 .18157 L
.57143 .1817 L
.57143 .18182 L
.57142 .18194 L
.57142 .18206 L
.57142 .18219 L
.57142 .18231 L
.57142 .18243 L
.57142 .18255 L
.57142 .18268 L
.57142 .1828 L
.57142 .18292 L
.57142 .18304 L
.57142 .18317 L
.57142 .18329 L
.57142 .18341 L
.57142 .18353 L
.57142 .18365 L
.57142 .18378 L
.57142 .1839 L
.57143 .18402 L
.57143 .18414 L
.57143 .18427 L
.57143 .18439 L
.57143 .18451 L
.57143 .18463 L
.57143 .18476 L
s
.59524 .18119 m
.59524 .18131 L
.59524 .18142 L
.59524 .18154 L
.59524 .18165 L
.59524 .18177 L
.59523 .18188 L
.59523 .182 L
.59523 .18211 L
.59523 .18223 L
.59523 .18234 L
.59523 .18246 L
.59523 .18257 L
.59523 .18269 L
.59523 .18281 L
.59523 .18292 L
.59523 .18304 L
.59523 .18315 L
.59523 .18327 L
.59523 .18338 L
.59523 .1835 L
.59523 .18361 L
.59523 .18373 L
.59523 .18384 L
.59523 .18396 L
.59524 .18407 L
.59524 .18419 L
.59524 .1843 L
.59524 .18442 L
.59524 .18453 L
.59524 .18465 L
s
.61905 .1813 m
.61905 .18141 L
.61905 .18151 L
.61905 .18162 L
.61904 .18173 L
.61904 .18184 L
.61904 .18195 L
.61904 .18205 L
.61904 .18216 L
.61904 .18227 L
.61904 .18238 L
.61904 .18249 L
.61904 .1826 L
.61904 .1827 L
.61904 .18281 L
.61904 .18292 L
.61904 .18303 L
.61904 .18314 L
.61904 .18325 L
.61904 .18335 L
.61904 .18346 L
.61904 .18357 L
.61904 .18368 L
.61904 .18379 L
.61904 .18389 L
.61904 .184 L
.61904 .18411 L
.61905 .18422 L
.61905 .18433 L
.61905 .18444 L
.61905 .18454 L
s
.64286 .1814 m
.64286 .18151 L
.64286 .18161 L
.64285 .18171 L
.64285 .18181 L
.64285 .18191 L
.64285 .18201 L
.64285 .18211 L
.64285 .18221 L
.64285 .18231 L
.64285 .18242 L
.64285 .18252 L
.64285 .18262 L
.64285 .18272 L
.64285 .18282 L
.64285 .18292 L
.64285 .18302 L
.64285 .18312 L
.64285 .18322 L
.64285 .18332 L
.64285 .18343 L
.64285 .18353 L
.64285 .18363 L
.64285 .18373 L
.64285 .18383 L
.64285 .18393 L
.64285 .18403 L
.64285 .18413 L
.64286 .18423 L
.64286 .18434 L
.64286 .18444 L
s
.66667 .18151 m
.66666 .1816 L
.66666 .1817 L
.66666 .18179 L
.66666 .18189 L
.66666 .18198 L
.66666 .18207 L
.66666 .18217 L
.66666 .18226 L
.66666 .18236 L
.66666 .18245 L
.66666 .18254 L
.66666 .18264 L
.66666 .18273 L
.66666 .18283 L
.66666 .18292 L
.66666 .18301 L
.66666 .18311 L
.66666 .1832 L
.66666 .1833 L
.66666 .18339 L
.66666 .18348 L
.66666 .18358 L
.66666 .18367 L
.66666 .18377 L
.66666 .18386 L
.66666 .18395 L
.66666 .18405 L
.66666 .18414 L
.66666 .18424 L
.66667 .18433 L
s
.69047 .18162 m
.69047 .1817 L
.69047 .18179 L
.69047 .18188 L
.69047 .18196 L
.69047 .18205 L
.69047 .18214 L
.69047 .18223 L
.69047 .18231 L
.69047 .1824 L
.69047 .18249 L
.69047 .18257 L
.69047 .18266 L
.69047 .18275 L
.69047 .18283 L
.69047 .18292 L
.69047 .18301 L
.69047 .18309 L
.69047 .18318 L
.69047 .18327 L
.69047 .18335 L
.69047 .18344 L
.69047 .18353 L
.69047 .18362 L
.69047 .1837 L
.69047 .18379 L
.69047 .18388 L
.69047 .18396 L
.69047 .18405 L
.69047 .18414 L
.69047 .18422 L
s
.71428 .18172 m
.71428 .1818 L
.71428 .18188 L
.71428 .18196 L
.71428 .18204 L
.71428 .18212 L
.71428 .1822 L
.71428 .18228 L
.71428 .18236 L
.71428 .18244 L
.71428 .18252 L
.71428 .1826 L
.71428 .18268 L
.71428 .18276 L
.71428 .18284 L
.71428 .18292 L
.71428 .183 L
.71428 .18308 L
.71428 .18316 L
.71428 .18324 L
.71428 .18332 L
.71428 .1834 L
.71428 .18348 L
.71428 .18356 L
.71428 .18364 L
.71428 .18372 L
.71428 .1838 L
.71428 .18388 L
.71428 .18396 L
.71428 .18404 L
.71428 .18412 L
s
.73809 .18183 m
.73809 .1819 L
.73809 .18197 L
.73809 .18205 L
.73809 .18212 L
.73809 .18219 L
.73809 .18227 L
.73809 .18234 L
.73809 .18241 L
.73809 .18248 L
.73809 .18256 L
.73809 .18263 L
.73809 .1827 L
.73809 .18277 L
.73809 .18285 L
.73809 .18292 L
.73809 .18299 L
.73809 .18307 L
.73809 .18314 L
.73809 .18321 L
.73809 .18328 L
.73809 .18336 L
.73809 .18343 L
.73809 .1835 L
.73809 .18358 L
.73809 .18365 L
.73809 .18372 L
.73809 .18379 L
.73809 .18387 L
.73809 .18394 L
.73809 .18401 L
s
.7619 .18193 m
.7619 .182 L
.7619 .18207 L
.7619 .18213 L
.7619 .1822 L
.7619 .18226 L
.7619 .18233 L
.7619 .18239 L
.7619 .18246 L
.7619 .18253 L
.7619 .18259 L
.7619 .18266 L
.7619 .18272 L
.7619 .18279 L
.7619 .18285 L
.7619 .18292 L
.7619 .18299 L
.7619 .18305 L
.7619 .18312 L
.7619 .18318 L
.7619 .18325 L
.7619 .18331 L
.7619 .18338 L
.7619 .18345 L
.7619 .18351 L
.7619 .18358 L
.7619 .18364 L
.7619 .18371 L
.7619 .18377 L
.7619 .18384 L
.7619 .18391 L
s
.78571 .18204 m
.78571 .1821 L
.78571 .18216 L
.78571 .18222 L
.78571 .18227 L
.78571 .18233 L
.78571 .18239 L
.78571 .18245 L
.78571 .18251 L
.78571 .18257 L
.78571 .18263 L
.78571 .18269 L
.78571 .18274 L
.78571 .1828 L
.78571 .18286 L
.78571 .18292 L
.78571 .18298 L
.78571 .18304 L
.78571 .1831 L
.78571 .18316 L
.78571 .18321 L
.78571 .18327 L
.78571 .18333 L
.78571 .18339 L
.78571 .18345 L
.78571 .18351 L
.78571 .18357 L
.78571 .18363 L
.78571 .18368 L
.78571 .18374 L
.78571 .1838 L
s
.80952 .18214 m
.80952 .1822 L
.80952 .18225 L
.80952 .1823 L
.80952 .18235 L
.80952 .1824 L
.80952 .18245 L
.80952 .18251 L
.80952 .18256 L
.80952 .18261 L
.80952 .18266 L
.80952 .18271 L
.80952 .18277 L
.80952 .18282 L
.80952 .18287 L
.80952 .18292 L
.80952 .18297 L
.80952 .18302 L
.80952 .18308 L
.80952 .18313 L
.80952 .18318 L
.80952 .18323 L
.80952 .18328 L
.80952 .18333 L
.80952 .18339 L
.80952 .18344 L
.80952 .18349 L
.80952 .18354 L
.80952 .18359 L
.80952 .18365 L
.80952 .1837 L
s
.83333 .18225 m
.83333 .18229 L
.83333 .18234 L
.83333 .18238 L
.83333 .18243 L
.83333 .18247 L
.83333 .18252 L
.83333 .18256 L
.83332 .18261 L
.83332 .18265 L
.83332 .1827 L
.83332 .18274 L
.83332 .18279 L
.83332 .18283 L
.83332 .18288 L
.83332 .18292 L
.83332 .18297 L
.83332 .18301 L
.83332 .18306 L
.83332 .1831 L
.83332 .18314 L
.83332 .18319 L
.83332 .18323 L
.83333 .18328 L
.83333 .18332 L
.83333 .18337 L
.83333 .18341 L
.83333 .18346 L
.83333 .1835 L
.83333 .18355 L
.83333 .18359 L
s
.85714 .18235 m
.85714 .18239 L
.85714 .18243 L
.85714 .18246 L
.85713 .1825 L
.85713 .18254 L
.85713 .18258 L
.85713 .18262 L
.85713 .18265 L
.85713 .18269 L
.85713 .18273 L
.85713 .18277 L
.85713 .18281 L
.85713 .18284 L
.85713 .18288 L
.85713 .18292 L
.85713 .18296 L
.85713 .183 L
.85713 .18303 L
.85713 .18307 L
.85713 .18311 L
.85713 .18315 L
.85713 .18319 L
.85713 .18322 L
.85713 .18326 L
.85713 .1833 L
.85713 .18334 L
.85714 .18338 L
.85714 .18341 L
.85714 .18345 L
.85714 .18349 L
s
.88094 .18245 m
.88094 .18248 L
.88094 .18251 L
.88094 .18254 L
.88094 .18258 L
.88094 .18261 L
.88094 .18264 L
.88094 .18267 L
.88094 .1827 L
.88094 .18273 L
.88094 .18276 L
.88094 .18279 L
.88094 .18283 L
.88094 .18286 L
.88094 .18289 L
.88094 .18292 L
.88094 .18295 L
.88094 .18298 L
.88094 .18301 L
.88094 .18305 L
.88094 .18308 L
.88094 .18311 L
.88094 .18314 L
.88094 .18317 L
.88094 .1832 L
.88094 .18323 L
.88094 .18327 L
.88094 .1833 L
.88094 .18333 L
.88094 .18336 L
.88094 .18339 L
s
.90475 .18255 m
.90475 .18257 L
.90475 .1826 L
.90475 .18262 L
.90475 .18265 L
.90475 .18267 L
.90475 .1827 L
.90475 .18272 L
.90475 .18275 L
.90475 .18277 L
.90475 .1828 L
.90475 .18282 L
.90475 .18285 L
.90475 .18287 L
.90475 .1829 L
.90475 .18292 L
.90475 .18295 L
.90475 .18297 L
.90475 .183 L
.90475 .18302 L
.90475 .18305 L
.90475 .18307 L
.90475 .1831 L
.90475 .18312 L
.90475 .18315 L
.90475 .18317 L
.90475 .1832 L
.90475 .18322 L
.90475 .18325 L
.90475 .18327 L
.90475 .1833 L
s
.92856 .18263 m
.92856 .18265 L
.92856 .18267 L
.92856 .18269 L
.92856 .18271 L
.92856 .18273 L
.92856 .18275 L
.92856 .18277 L
.92856 .18279 L
.92856 .18281 L
.92856 .18282 L
.92856 .18284 L
.92856 .18286 L
.92856 .18288 L
.92856 .1829 L
.92856 .18292 L
.92856 .18294 L
.92856 .18296 L
.92856 .18298 L
.92856 .183 L
.92856 .18302 L
.92856 .18304 L
.92856 .18305 L
.92856 .18307 L
.92856 .18309 L
.92856 .18311 L
.92856 .18313 L
.92856 .18315 L
.92856 .18317 L
.92856 .18319 L
.92856 .18321 L
s
.95237 .1827 m
.95237 .18272 L
.95237 .18273 L
.95237 .18275 L
.95237 .18276 L
.95237 .18277 L
.95237 .18279 L
.95237 .1828 L
.95237 .18282 L
.95237 .18283 L
.95237 .18285 L
.95237 .18286 L
.95237 .18288 L
.95237 .18289 L
.95237 .18291 L
.95237 .18292 L
.95237 .18294 L
.95237 .18295 L
.95237 .18296 L
.95237 .18298 L
.95237 .18299 L
.95237 .18301 L
.95237 .18302 L
.95237 .18304 L
.95237 .18305 L
.95237 .18307 L
.95237 .18308 L
.95237 .1831 L
.95237 .18311 L
.95237 .18312 L
.95237 .18314 L
s
.02381 .21716 m
.0397 .21716 L
.05558 .21716 L
.07147 .21716 L
.08735 .21716 L
.10324 .21716 L
.11912 .21716 L
.13501 .21716 L
.15089 .21716 L
.16678 .21716 L
.18267 .21716 L
.19855 .21716 L
.21444 .21716 L
.23032 .21716 L
.24621 .21716 L
.26209 .21716 L
.27798 .21716 L
.29386 .21716 L
.30975 .21716 L
.32564 .21716 L
.34162 .21698 L
.3575 .21641 L
.37337 .21583 L
.38925 .21525 L
.40517 .21452 L
.42103 .21364 L
.43689 .21277 L
.45275 .21189 L
.46861 .21101 L
.48447 .21013 L
.50033 .20925 L
.5162 .20838 L
.53206 .2075 L
.54792 .20662 L
.56378 .20574 L
.57964 .20486 L
.5955 .20399 L
.61136 .20311 L
.62723 .20223 L
.64309 .20135 L
.65895 .20048 L
.67481 .1996 L
.69067 .19872 L
.70653 .19784 L
.7224 .19697 L
.73826 .19609 L
.75412 .19521 L
.76998 .19434 L
.78584 .19346 L
.8017 .19258 L
Mistroke
.81757 .19171 L
.83343 .19083 L
.84929 .18996 L
.86515 .18909 L
.88101 .18821 L
.89687 .18734 L
.91274 .18648 L
.9286 .18562 L
.94446 .18477 L
.96033 .18394 L
.97619 .18313 L
Mfstroke
.02381 .21093 m
.0397 .21093 L
.05558 .21093 L
.07147 .21093 L
.08735 .21093 L
.10324 .21093 L
.11912 .21093 L
.13501 .21093 L
.15089 .21093 L
.16678 .21093 L
.18267 .21093 L
.19855 .21093 L
.21444 .21093 L
.23032 .21093 L
.24621 .21093 L
.26209 .21093 L
.27798 .21093 L
.29386 .21093 L
.30975 .21093 L
.32564 .21093 L
.34142 .21077 L
.35729 .2103 L
.37317 .20983 L
.38905 .20936 L
.40488 .20877 L
.42075 .20805 L
.43662 .20733 L
.45248 .20662 L
.46835 .2059 L
.48422 .20518 L
.50009 .20446 L
.51596 .20375 L
.53183 .20303 L
.5477 .20231 L
.56357 .20159 L
.57944 .20087 L
.59531 .20016 L
.61118 .19944 L
.62705 .19872 L
.64292 .198 L
.65879 .19728 L
.67466 .19656 L
.69053 .19585 L
.7064 .19513 L
.72227 .19441 L
.73814 .19369 L
.75401 .19297 L
.76988 .19225 L
.78575 .19153 L
.80161 .19081 L
Mistroke
.81748 .19009 L
.83335 .18937 L
.84922 .18865 L
.86509 .18793 L
.88096 .18721 L
.89683 .18648 L
.9127 .18575 L
.92857 .18501 L
.94444 .18427 L
.9603 .1835 L
.97617 .18271 L
Mfstroke
0 0 0 r
.02381 .21404 m
.33655 .21404 L
s
% Start of user PostScript
-50. 5. 0.24154 5. MAarrowhead1
% End of user PostScript
.33655 .21404 m
.39729 .21203 L
s
% Start of user PostScript
0.24154 5. 10. 4.67726 MAarrowhead1
% End of user PostScript
.39729 .21203 m
.97618 .18292 L
s
% Start of user PostScript
10. 4.67726 103. 0.000304527 MAarrowhead1
% End of user PostScript
.97618 .18292 m
.97618 .18292 L
s
% Start of user PostScript
103. 0.000304527 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .21124 m
.02381 .21143 L
.02381 .21162 L
.02381 .2118 L
.02381 .21199 L
.02381 .21218 L
.02381 .21236 L
.02381 .21255 L
.02381 .21274 L
.02381 .21292 L
.02381 .21311 L
.02381 .2133 L
.02381 .21348 L
.02381 .21367 L
.02381 .21386 L
.02381 .21404 L
.02381 .21423 L
.02381 .21442 L
.02381 .2146 L
.02381 .21479 L
.02381 .21498 L
.02381 .21516 L
.02381 .21535 L
.02381 .21554 L
.02381 .21572 L
.02381 .21591 L
.02381 .2161 L
.02381 .21628 L
.02381 .21647 L
.02381 .21666 L
.02381 .21684 L
s
.04764 .21124 m
.04764 .21143 L
.04764 .21162 L
.04764 .2118 L
.04764 .21199 L
.04764 .21218 L
.04764 .21236 L
.04764 .21255 L
.04764 .21274 L
.04764 .21292 L
.04764 .21311 L
.04764 .2133 L
.04764 .21348 L
.04764 .21367 L
.04764 .21386 L
.04764 .21404 L
.04764 .21423 L
.04764 .21442 L
.04764 .2146 L
.04764 .21479 L
.04764 .21498 L
.04764 .21516 L
.04764 .21535 L
.04764 .21554 L
.04764 .21572 L
.04764 .21591 L
.04764 .2161 L
.04764 .21628 L
.04764 .21647 L
.04764 .21666 L
.04764 .21684 L
s
.07147 .21124 m
.07147 .21143 L
.07147 .21162 L
.07147 .2118 L
.07147 .21199 L
.07147 .21218 L
.07147 .21236 L
.07147 .21255 L
.07147 .21274 L
.07147 .21292 L
.07147 .21311 L
.07147 .2133 L
.07147 .21348 L
.07147 .21367 L
.07147 .21386 L
.07147 .21404 L
.07147 .21423 L
.07147 .21442 L
.07147 .2146 L
.07147 .21479 L
.07147 .21498 L
.07147 .21516 L
.07147 .21535 L
.07147 .21554 L
.07147 .21572 L
.07147 .21591 L
.07147 .2161 L
.07147 .21628 L
.07147 .21647 L
.07147 .21666 L
.07147 .21684 L
s
.09529 .21124 m
.09529 .21143 L
.09529 .21162 L
.09529 .2118 L
.09529 .21199 L
.09529 .21218 L
.09529 .21236 L
.09529 .21255 L
.09529 .21274 L
.09529 .21292 L
.09529 .21311 L
.09529 .2133 L
.09529 .21348 L
.09529 .21367 L
.09529 .21386 L
.09529 .21404 L
.09529 .21423 L
.09529 .21442 L
.09529 .2146 L
.09529 .21479 L
.09529 .21498 L
.09529 .21516 L
.09529 .21535 L
.09529 .21554 L
.09529 .21572 L
.09529 .21591 L
.09529 .2161 L
.09529 .21628 L
.09529 .21647 L
.09529 .21666 L
.09529 .21684 L
s
.11912 .21124 m
.11912 .21143 L
.11912 .21162 L
.11912 .2118 L
.11912 .21199 L
.11912 .21218 L
.11912 .21236 L
.11912 .21255 L
.11912 .21274 L
.11912 .21292 L
.11912 .21311 L
.11912 .2133 L
.11912 .21348 L
.11912 .21367 L
.11912 .21386 L
.11912 .21404 L
.11912 .21423 L
.11912 .21442 L
.11912 .2146 L
.11912 .21479 L
.11912 .21498 L
.11912 .21516 L
.11912 .21535 L
.11912 .21554 L
.11912 .21572 L
.11912 .21591 L
.11912 .2161 L
.11912 .21628 L
.11912 .21647 L
.11912 .21666 L
.11912 .21684 L
s
.14295 .21124 m
.14295 .21143 L
.14295 .21162 L
.14295 .2118 L
.14295 .21199 L
.14295 .21218 L
.14295 .21236 L
.14295 .21255 L
.14295 .21274 L
.14295 .21292 L
.14295 .21311 L
.14295 .2133 L
.14295 .21348 L
.14295 .21367 L
.14295 .21386 L
.14295 .21404 L
.14295 .21423 L
.14295 .21442 L
.14295 .2146 L
.14295 .21479 L
.14295 .21498 L
.14295 .21516 L
.14295 .21535 L
.14295 .21554 L
.14295 .21572 L
.14295 .21591 L
.14295 .2161 L
.14295 .21628 L
.14295 .21647 L
.14295 .21666 L
.14295 .21685 L
s
.16678 .21124 m
.16678 .21143 L
.16678 .21162 L
.16678 .2118 L
.16678 .21199 L
.16678 .21218 L
.16678 .21236 L
.16678 .21255 L
.16678 .21274 L
.16678 .21292 L
.16678 .21311 L
.16678 .2133 L
.16678 .21348 L
.16678 .21367 L
.16678 .21386 L
.16678 .21404 L
.16678 .21423 L
.16678 .21442 L
.16678 .2146 L
.16678 .21479 L
.16678 .21498 L
.16678 .21516 L
.16678 .21535 L
.16678 .21554 L
.16678 .21572 L
.16678 .21591 L
.16678 .2161 L
.16678 .21628 L
.16678 .21647 L
.16678 .21666 L
.16678 .21685 L
s
.19061 .21124 m
.19061 .21143 L
.19061 .21162 L
.19061 .2118 L
.19061 .21199 L
.19061 .21218 L
.19061 .21236 L
.19061 .21255 L
.19061 .21274 L
.19061 .21292 L
.19061 .21311 L
.19061 .2133 L
.19061 .21348 L
.19061 .21367 L
.19061 .21386 L
.19061 .21404 L
.19061 .21423 L
.19061 .21442 L
.19061 .2146 L
.19061 .21479 L
.19061 .21498 L
.19061 .21516 L
.19061 .21535 L
.19061 .21554 L
.19061 .21572 L
.19061 .21591 L
.19061 .2161 L
.19061 .21628 L
.19061 .21647 L
.19061 .21666 L
.19061 .21685 L
s
.21444 .21124 m
.21444 .21143 L
.21444 .21162 L
.21444 .2118 L
.21444 .21199 L
.21444 .21218 L
.21444 .21236 L
.21444 .21255 L
.21444 .21274 L
.21444 .21292 L
.21444 .21311 L
.21444 .2133 L
.21444 .21348 L
.21444 .21367 L
.21444 .21386 L
.21444 .21404 L
.21444 .21423 L
.21444 .21442 L
.21444 .2146 L
.21444 .21479 L
.21444 .21498 L
.21444 .21516 L
.21444 .21535 L
.21444 .21554 L
.21444 .21572 L
.21444 .21591 L
.21444 .2161 L
.21444 .21629 L
.21444 .21647 L
.21444 .21666 L
.21444 .21685 L
s
.23826 .21124 m
.23826 .21143 L
.23826 .21162 L
.23826 .2118 L
.23826 .21199 L
.23826 .21218 L
.23826 .21236 L
.23826 .21255 L
.23826 .21274 L
.23826 .21292 L
.23826 .21311 L
.23826 .2133 L
.23826 .21348 L
.23826 .21367 L
.23826 .21386 L
.23826 .21404 L
.23826 .21423 L
.23826 .21442 L
.23826 .2146 L
.23826 .21479 L
.23826 .21498 L
.23826 .21516 L
.23826 .21535 L
.23826 .21554 L
.23826 .21572 L
.23826 .21591 L
.23826 .2161 L
.23826 .21629 L
.23826 .21647 L
.23826 .21666 L
.23826 .21685 L
s
.26209 .21124 m
.26209 .21143 L
.26209 .21162 L
.26209 .2118 L
.26209 .21199 L
.26209 .21218 L
.26209 .21236 L
.26209 .21255 L
.26209 .21274 L
.26209 .21292 L
.26209 .21311 L
.26209 .2133 L
.26209 .21348 L
.26209 .21367 L
.26209 .21386 L
.26209 .21404 L
.26209 .21423 L
.26209 .21442 L
.26209 .2146 L
.26209 .21479 L
.26209 .21498 L
.26209 .21516 L
.26209 .21535 L
.26209 .21554 L
.26209 .21572 L
.26209 .21591 L
.26209 .2161 L
.26209 .21629 L
.26209 .21647 L
.26209 .21666 L
.26209 .21685 L
s
.28592 .21124 m
.28592 .21143 L
.28592 .21162 L
.28592 .2118 L
.28592 .21199 L
.28592 .21218 L
.28592 .21236 L
.28592 .21255 L
.28592 .21274 L
.28592 .21292 L
.28592 .21311 L
.28592 .2133 L
.28592 .21348 L
.28592 .21367 L
.28592 .21386 L
.28592 .21404 L
.28592 .21423 L
.28592 .21442 L
.28592 .2146 L
.28592 .21479 L
.28592 .21498 L
.28592 .21516 L
.28592 .21535 L
.28592 .21554 L
.28592 .21573 L
.28592 .21591 L
.28592 .2161 L
.28592 .21629 L
.28592 .21647 L
.28592 .21666 L
.28592 .21685 L
s
.30975 .21124 m
.30975 .21143 L
.30975 .21161 L
.30975 .2118 L
.30975 .21199 L
.30975 .21218 L
.30975 .21236 L
.30975 .21255 L
.30975 .21274 L
.30975 .21292 L
.30975 .21311 L
.30975 .2133 L
.30975 .21348 L
.30975 .21367 L
.30975 .21386 L
.30975 .21404 L
.30975 .21423 L
.30975 .21442 L
.30975 .2146 L
.30975 .21479 L
.30975 .21498 L
.30975 .21516 L
.30975 .21535 L
.30975 .21554 L
.30975 .21573 L
.30975 .21591 L
.30975 .2161 L
.30975 .21629 L
.30975 .21647 L
.30975 .21666 L
.30975 .21685 L
s
.33358 .21124 m
.33358 .21143 L
.33358 .21161 L
.33358 .2118 L
.33358 .21199 L
.33358 .21218 L
.33358 .21236 L
.33358 .21255 L
.33358 .21274 L
.33358 .21292 L
.33358 .21311 L
.33358 .2133 L
.33358 .21348 L
.33358 .21367 L
.33358 .21386 L
.33358 .21404 L
.33358 .21423 L
.33358 .21442 L
.33358 .2146 L
.33358 .21479 L
.33358 .21498 L
.33358 .21516 L
.33358 .21535 L
.33358 .21554 L
.33358 .21573 L
.33358 .21591 L
.33358 .2161 L
.33358 .21629 L
.33358 .21647 L
.33358 .21666 L
.33358 .21685 L
s
.35731 .21061 m
.35732 .21079 L
.35732 .21097 L
.35733 .21116 L
.35733 .21134 L
.35734 .21152 L
.35734 .21171 L
.35735 .21189 L
.35735 .21207 L
.35736 .21226 L
.35737 .21244 L
.35737 .21262 L
.35738 .2128 L
.35738 .21299 L
.35739 .21317 L
.3574 .21335 L
.3574 .21354 L
.35741 .21372 L
.35741 .2139 L
.35742 .21409 L
.35743 .21427 L
.35743 .21445 L
.35744 .21464 L
.35745 .21482 L
.35745 .215 L
.35746 .21518 L
.35746 .21537 L
.35747 .21555 L
.35748 .21573 L
.35748 .21592 L
.35749 .2161 L
s
.38113 .20989 m
.38113 .21007 L
.38114 .21025 L
.38114 .21043 L
.38115 .2106 L
.38115 .21078 L
.38116 .21096 L
.38117 .21114 L
.38117 .21132 L
.38118 .2115 L
.38118 .21167 L
.38119 .21185 L
.38119 .21203 L
.3812 .21221 L
.3812 .21239 L
.38121 .21257 L
.38122 .21274 L
.38122 .21292 L
.38123 .2131 L
.38123 .21328 L
.38124 .21346 L
.38125 .21364 L
.38125 .21381 L
.38126 .21399 L
.38127 .21417 L
.38127 .21435 L
.38128 .21453 L
.38128 .21471 L
.38129 .21488 L
.3813 .21506 L
.3813 .21524 L
s
.4049 .20906 m
.40491 .20923 L
.40492 .2094 L
.40492 .20957 L
.40493 .20975 L
.40494 .20992 L
.40495 .21009 L
.40495 .21027 L
.40496 .21044 L
.40497 .21061 L
.40498 .21078 L
.40499 .21096 L
.405 .21113 L
.405 .2113 L
.40501 .21147 L
.40502 .21165 L
.40503 .21182 L
.40504 .21199 L
.40505 .21216 L
.40506 .21234 L
.40507 .21251 L
.40507 .21268 L
.40508 .21285 L
.40509 .21303 L
.4051 .2132 L
.40511 .21337 L
.40512 .21354 L
.40513 .21372 L
.40514 .21389 L
.40515 .21406 L
.40516 .21423 L
s
.4287 .20797 m
.42871 .20813 L
.42872 .2083 L
.42873 .20846 L
.42873 .20863 L
.42874 .2088 L
.42875 .20896 L
.42876 .20913 L
.42876 .20929 L
.42877 .20946 L
.42878 .20962 L
.42879 .20979 L
.42879 .20995 L
.4288 .21012 L
.42881 .21028 L
.42882 .21045 L
.42883 .21061 L
.42884 .21078 L
.42884 .21095 L
.42885 .21111 L
.42886 .21128 L
.42887 .21144 L
.42888 .21161 L
.42889 .21177 L
.4289 .21194 L
.42891 .2121 L
.42892 .21227 L
.42893 .21243 L
.42893 .2126 L
.42894 .21276 L
.42895 .21293 L
s
.45251 .20688 m
.45251 .20704 L
.45252 .2072 L
.45253 .20735 L
.45254 .20751 L
.45254 .20767 L
.45255 .20783 L
.45256 .20799 L
.45256 .20815 L
.45257 .2083 L
.45258 .20846 L
.45259 .20862 L
.45259 .20878 L
.4526 .20894 L
.45261 .20909 L
.45262 .20925 L
.45263 .20941 L
.45263 .20957 L
.45264 .20973 L
.45265 .20988 L
.45266 .21004 L
.45267 .2102 L
.45268 .21036 L
.45268 .21052 L
.45269 .21068 L
.4527 .21083 L
.45271 .21099 L
.45272 .21115 L
.45273 .21131 L
.45274 .21147 L
.45275 .21162 L
s
.47631 .20579 m
.47632 .20594 L
.47632 .20609 L
.47633 .20624 L
.47634 .2064 L
.47634 .20655 L
.47635 .2067 L
.47636 .20685 L
.47636 .207 L
.47637 .20715 L
.47638 .2073 L
.47639 .20745 L
.47639 .2076 L
.4764 .20775 L
.47641 .2079 L
.47642 .20806 L
.47642 .20821 L
.47643 .20836 L
.47644 .20851 L
.47645 .20866 L
.47645 .20881 L
.47646 .20896 L
.47647 .20911 L
.47648 .20926 L
.47649 .20941 L
.4765 .20956 L
.4765 .20972 L
.47651 .20987 L
.47652 .21002 L
.47653 .21017 L
.47654 .21032 L
s
.50011 .2047 m
.50012 .20485 L
.50013 .20499 L
.50013 .20513 L
.50014 .20528 L
.50015 .20542 L
.50015 .20556 L
.50016 .20571 L
.50017 .20585 L
.50017 .206 L
.50018 .20614 L
.50019 .20628 L
.50019 .20643 L
.5002 .20657 L
.50021 .20671 L
.50021 .20686 L
.50022 .207 L
.50023 .20715 L
.50024 .20729 L
.50024 .20743 L
.50025 .20758 L
.50026 .20772 L
.50027 .20786 L
.50027 .20801 L
.50028 .20815 L
.50029 .2083 L
.5003 .20844 L
.50031 .20858 L
.50031 .20873 L
.50032 .20887 L
.50033 .20901 L
s
.52392 .20361 m
.52392 .20375 L
.52393 .20389 L
.52394 .20402 L
.52394 .20416 L
.52395 .2043 L
.52395 .20443 L
.52396 .20457 L
.52397 .20471 L
.52397 .20484 L
.52398 .20498 L
.52399 .20512 L
.52399 .20525 L
.524 .20539 L
.52401 .20553 L
.52401 .20566 L
.52402 .2058 L
.52403 .20593 L
.52403 .20607 L
.52404 .20621 L
.52405 .20634 L
.52405 .20648 L
.52406 .20662 L
.52407 .20675 L
.52408 .20689 L
.52408 .20703 L
.52409 .20716 L
.5241 .2073 L
.52411 .20744 L
.52412 .20757 L
.52412 .20771 L
s
.54772 .20252 m
.54773 .20265 L
.54773 .20278 L
.54774 .20291 L
.54774 .20304 L
.54775 .20317 L
.54775 .2033 L
.54776 .20343 L
.54777 .20356 L
.54777 .20369 L
.54778 .20382 L
.54779 .20395 L
.54779 .20408 L
.5478 .20421 L
.5478 .20434 L
.54781 .20446 L
.54782 .20459 L
.54782 .20472 L
.54783 .20485 L
.54784 .20498 L
.54784 .20511 L
.54785 .20524 L
.54786 .20537 L
.54786 .2055 L
.54787 .20563 L
.54788 .20576 L
.54789 .20589 L
.54789 .20602 L
.5479 .20615 L
.54791 .20628 L
.54792 .2064 L
s
.57152 .20144 m
.57153 .20156 L
.57153 .20168 L
.57154 .2018 L
.57155 .20192 L
.57155 .20205 L
.57156 .20217 L
.57156 .20229 L
.57157 .20241 L
.57157 .20254 L
.57158 .20266 L
.57158 .20278 L
.57159 .2029 L
.5716 .20302 L
.5716 .20315 L
.57161 .20327 L
.57161 .20339 L
.57162 .20351 L
.57163 .20363 L
.57163 .20376 L
.57164 .20388 L
.57165 .204 L
.57165 .20412 L
.57166 .20425 L
.57167 .20437 L
.57167 .20449 L
.57168 .20461 L
.57169 .20473 L
.57169 .20486 L
.5717 .20498 L
.57171 .2051 L
s
.59533 .20035 m
.59533 .20046 L
.59534 .20058 L
.59534 .20069 L
.59535 .20081 L
.59535 .20092 L
.59536 .20104 L
.59536 .20115 L
.59537 .20127 L
.59537 .20138 L
.59538 .2015 L
.59538 .20161 L
.59539 .20173 L
.5954 .20184 L
.5954 .20196 L
.59541 .20207 L
.59541 .20219 L
.59542 .2023 L
.59542 .20242 L
.59543 .20253 L
.59544 .20265 L
.59544 .20276 L
.59545 .20288 L
.59546 .20299 L
.59546 .20311 L
.59547 .20322 L
.59547 .20334 L
.59548 .20345 L
.59549 .20357 L
.59549 .20368 L
.5955 .2038 L
s
.61913 .19926 m
.61914 .19937 L
.61914 .19947 L
.61914 .19958 L
.61915 .19969 L
.61915 .1998 L
.61916 .1999 L
.61916 .20001 L
.61917 .20012 L
.61917 .20023 L
.61918 .20034 L
.61918 .20044 L
.61919 .20055 L
.61919 .20066 L
.6192 .20077 L
.61921 .20087 L
.61921 .20098 L
.61922 .20109 L
.61922 .2012 L
.61923 .20131 L
.61923 .20141 L
.61924 .20152 L
.61924 .20163 L
.61925 .20174 L
.61926 .20184 L
.61926 .20195 L
.61927 .20206 L
.61927 .20217 L
.61928 .20228 L
.61929 .20238 L
.61929 .20249 L
s
.64293 .19817 m
.64294 .19827 L
.64294 .19837 L
.64295 .19847 L
.64295 .19857 L
.64296 .19867 L
.64296 .19877 L
.64297 .19887 L
.64297 .19897 L
.64297 .19907 L
.64298 .19917 L
.64298 .19928 L
.64299 .19938 L
.64299 .19948 L
.643 .19958 L
.643 .19968 L
.64301 .19978 L
.64301 .19988 L
.64302 .19998 L
.64302 .20008 L
.64303 .20018 L
.64304 .20028 L
.64304 .20038 L
.64305 .20048 L
.64305 .20058 L
.64306 .20068 L
.64306 .20078 L
.64307 .20088 L
.64307 .20099 L
.64308 .20109 L
.64309 .20119 L
s
.66674 .19708 m
.66674 .19717 L
.66675 .19727 L
.66675 .19736 L
.66675 .19745 L
.66676 .19755 L
.66676 .19764 L
.66677 .19773 L
.66677 .19783 L
.66677 .19792 L
.66678 .19801 L
.66678 .19811 L
.66679 .1982 L
.66679 .19829 L
.6668 .19839 L
.6668 .19848 L
.66681 .19857 L
.66681 .19867 L
.66682 .19876 L
.66682 .19885 L
.66683 .19895 L
.66683 .19904 L
.66684 .19913 L
.66684 .19923 L
.66685 .19932 L
.66685 .19941 L
.66686 .19951 L
.66686 .1996 L
.66687 .1997 L
.66687 .19979 L
.66688 .19988 L
s
.69054 .19599 m
.69054 .19608 L
.69055 .19616 L
.69055 .19625 L
.69056 .19634 L
.69056 .19642 L
.69056 .19651 L
.69057 .19659 L
.69057 .19668 L
.69058 .19677 L
.69058 .19685 L
.69058 .19694 L
.69059 .19703 L
.69059 .19711 L
.6906 .1972 L
.6906 .19728 L
.6906 .19737 L
.69061 .19746 L
.69061 .19754 L
.69062 .19763 L
.69062 .19772 L
.69063 .1978 L
.69063 .19789 L
.69064 .19797 L
.69064 .19806 L
.69065 .19815 L
.69065 .19823 L
.69066 .19832 L
.69066 .19841 L
.69067 .19849 L
.69067 .19858 L
s
.71434 .1949 m
.71435 .19498 L
.71435 .19506 L
.71435 .19514 L
.71436 .19522 L
.71436 .1953 L
.71436 .19538 L
.71437 .19545 L
.71437 .19553 L
.71438 .19561 L
.71438 .19569 L
.71438 .19577 L
.71439 .19585 L
.71439 .19593 L
.71439 .19601 L
.7144 .19609 L
.7144 .19617 L
.71441 .19625 L
.71441 .19632 L
.71441 .1964 L
.71442 .19648 L
.71442 .19656 L
.71443 .19664 L
.71443 .19672 L
.71444 .1968 L
.71444 .19688 L
.71445 .19696 L
.71445 .19704 L
.71445 .19712 L
.71446 .19719 L
.71446 .19727 L
s
.73815 .19381 m
.73815 .19388 L
.73815 .19395 L
.73816 .19403 L
.73816 .1941 L
.73816 .19417 L
.73817 .19424 L
.73817 .19431 L
.73817 .19439 L
.73818 .19446 L
.73818 .19453 L
.73818 .1946 L
.73819 .19467 L
.73819 .19475 L
.73819 .19482 L
.7382 .19489 L
.7382 .19496 L
.7382 .19503 L
.73821 .19511 L
.73821 .19518 L
.73822 .19525 L
.73822 .19532 L
.73822 .19539 L
.73823 .19547 L
.73823 .19554 L
.73824 .19561 L
.73824 .19568 L
.73824 .19575 L
.73825 .19583 L
.73825 .1959 L
.73826 .19597 L
s
.76195 .19272 m
.76195 .19279 L
.76196 .19285 L
.76196 .19292 L
.76196 .19298 L
.76196 .19304 L
.76197 .19311 L
.76197 .19317 L
.76197 .19324 L
.76198 .1933 L
.76198 .19337 L
.76198 .19343 L
.76199 .1935 L
.76199 .19356 L
.76199 .19363 L
.762 .19369 L
.762 .19376 L
.762 .19382 L
.76201 .19389 L
.76201 .19395 L
.76201 .19402 L
.76202 .19408 L
.76202 .19415 L
.76202 .19421 L
.76203 .19428 L
.76203 .19434 L
.76203 .19441 L
.76204 .19447 L
.76204 .19454 L
.76204 .1946 L
.76205 .19467 L
s
.78575 .19163 m
.78576 .19169 L
.78576 .19175 L
.78576 .1918 L
.78576 .19186 L
.78577 .19192 L
.78577 .19198 L
.78577 .19203 L
.78577 .19209 L
.78578 .19215 L
.78578 .19221 L
.78578 .19227 L
.78578 .19232 L
.78579 .19238 L
.78579 .19244 L
.78579 .1925 L
.7858 .19255 L
.7858 .19261 L
.7858 .19267 L
.78581 .19273 L
.78581 .19279 L
.78581 .19284 L
.78581 .1929 L
.78582 .19296 L
.78582 .19302 L
.78582 .19307 L
.78583 .19313 L
.78583 .19319 L
.78583 .19325 L
.78584 .19331 L
.78584 .19336 L
s
.80956 .19054 m
.80956 .19059 L
.80956 .19064 L
.80956 .19069 L
.80957 .19074 L
.80957 .19079 L
.80957 .19084 L
.80957 .19089 L
.80957 .19094 L
.80958 .191 L
.80958 .19105 L
.80958 .1911 L
.80958 .19115 L
.80959 .1912 L
.80959 .19125 L
.80959 .1913 L
.80959 .19135 L
.8096 .1914 L
.8096 .19145 L
.8096 .1915 L
.8096 .19155 L
.80961 .1916 L
.80961 .19166 L
.80961 .19171 L
.80962 .19176 L
.80962 .19181 L
.80962 .19186 L
.80962 .19191 L
.80963 .19196 L
.80963 .19201 L
.80963 .19206 L
s
.83336 .18945 m
.83336 .18949 L
.83336 .18953 L
.83337 .18958 L
.83337 .18962 L
.83337 .18967 L
.83337 .18971 L
.83337 .18975 L
.83338 .1898 L
.83338 .18984 L
.83338 .18988 L
.83338 .18993 L
.83338 .18997 L
.83339 .19002 L
.83339 .19006 L
.83339 .1901 L
.83339 .19015 L
.83339 .19019 L
.8334 .19023 L
.8334 .19028 L
.8334 .19032 L
.8334 .19037 L
.83341 .19041 L
.83341 .19045 L
.83341 .1905 L
.83341 .19054 L
.83342 .19058 L
.83342 .19063 L
.83342 .19067 L
.83342 .19072 L
.83343 .19076 L
s
.85716 .18835 m
.85716 .18839 L
.85717 .18843 L
.85717 .18846 L
.85717 .1885 L
.85717 .18854 L
.85717 .18857 L
.85717 .18861 L
.85718 .18865 L
.85718 .18868 L
.85718 .18872 L
.85718 .18876 L
.85718 .1888 L
.85718 .18883 L
.85719 .18887 L
.85719 .18891 L
.85719 .18894 L
.85719 .18898 L
.85719 .18902 L
.8572 .18905 L
.8572 .18909 L
.8572 .18913 L
.8572 .18916 L
.8572 .1892 L
.85721 .18924 L
.85721 .18928 L
.85721 .18931 L
.85721 .18935 L
.85721 .18939 L
.85722 .18942 L
.85722 .18946 L
s
.88097 .18726 m
.88097 .18729 L
.88097 .18732 L
.88097 .18735 L
.88097 .18738 L
.88097 .18741 L
.88097 .18744 L
.88098 .18747 L
.88098 .1875 L
.88098 .18753 L
.88098 .18756 L
.88098 .18759 L
.88098 .18762 L
.88098 .18765 L
.88099 .18768 L
.88099 .18771 L
.88099 .18774 L
.88099 .18777 L
.88099 .1878 L
.88099 .18783 L
.88099 .18786 L
.881 .18789 L
.881 .18792 L
.881 .18795 L
.881 .18798 L
.881 .18801 L
.881 .18804 L
.88101 .18807 L
.88101 .1881 L
.88101 .18813 L
.88101 .18816 L
s
.90477 .18616 m
.90477 .18618 L
.90477 .1862 L
.90477 .18623 L
.90477 .18625 L
.90477 .18627 L
.90477 .1863 L
.90478 .18632 L
.90478 .18635 L
.90478 .18637 L
.90478 .18639 L
.90478 .18642 L
.90478 .18644 L
.90478 .18647 L
.90478 .18649 L
.90479 .18651 L
.90479 .18654 L
.90479 .18656 L
.90479 .18658 L
.90479 .18661 L
.90479 .18663 L
.90479 .18666 L
.90479 .18668 L
.90479 .1867 L
.9048 .18673 L
.9048 .18675 L
.9048 .18677 L
.9048 .1868 L
.9048 .18682 L
.9048 .18685 L
.9048 .18687 L
s
.92857 .18505 m
.92857 .18506 L
.92857 .18508 L
.92857 .1851 L
.92857 .18512 L
.92857 .18514 L
.92858 .18515 L
.92858 .18517 L
.92858 .18519 L
.92858 .18521 L
.92858 .18523 L
.92858 .18524 L
.92858 .18526 L
.92858 .18528 L
.92858 .1853 L
.92858 .18532 L
.92858 .18533 L
.92859 .18535 L
.92859 .18537 L
.92859 .18539 L
.92859 .18541 L
.92859 .18542 L
.92859 .18544 L
.92859 .18546 L
.92859 .18548 L
.92859 .1855 L
.92859 .18551 L
.92859 .18553 L
.9286 .18555 L
.9286 .18557 L
.9286 .18559 L
s
.95237 .18391 m
.95237 .18393 L
.95237 .18394 L
.95237 .18395 L
.95237 .18397 L
.95237 .18398 L
.95238 .184 L
.95238 .18401 L
.95238 .18402 L
.95238 .18404 L
.95238 .18405 L
.95238 .18406 L
.95238 .18408 L
.95238 .18409 L
.95238 .18411 L
.95238 .18412 L
.95238 .18413 L
.95238 .18415 L
.95238 .18416 L
.95238 .18417 L
.95239 .18419 L
.95239 .1842 L
.95239 .18422 L
.95239 .18423 L
.95239 .18424 L
.95239 .18426 L
.95239 .18427 L
.95239 .18428 L
.95239 .1843 L
.95239 .18431 L
.95239 .18433 L
s
0 0 m
1 0 L
1 .34679 L
0 .34679 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[63]:=",
  ImageSize->{288, 99.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Hb000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00I`3oool500000:D0oooo00@000000?ooo`00000000002`3oool006P0
oooo00@000000?ooo`3oool00000Y@3oool200000080oooo00<000000?ooo`3oool0203oool006P0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`02000000X0oooo001X0?ooo`030000
003oool0oooo0:L0oooo0`00000;0?ooo`00J03oool00`000000oooo0?ooo`2V0?ooo`8000000P3o
ool00`000000oooo0?ooo`080?ooo`00J03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0
oooo008000002P3oool006L0oooo0`00002X0?ooo`80000000<0oooo0000003oool02@3oool006`0
oooo1`00002Q0?ooo`030000003oool0oooo00T0oooo001/0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00J`3oool800000:40oooo00<0
00000?ooo`3oool02@3oool006/0oooo0P00000507moO`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool02@3oool006/0oooo0P00000507moO`030000003oool0oooo09l0oooo00<000000?oo
o`3oool02@3oool006X0oooo00<0000007moO`0000001@1oOgl00`000000oooo0?ooo`2O0?ooo`03
0000003oool0oooo00T0oooo001Z0?ooo`030000001oOgl0000000H00000X@3oool00`000000oooo
0?ooo`090?ooo`00J@3oool010000000Ogmo07moO`00000507moO`030000003oool0oooo09l0oooo
00<000000?ooo`3oool02@3oool006T0oooo00@0000007moO`1oOgl000001@1oOgl00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001Y0?ooo`040000001oOgl0Ogmo000000D0Ogmo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00J03oool01@000000Ogmo07mo
O`1oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00J03o
ool01@000000Ogmo07moO`1oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`090?ooo`00I`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I`3oool00`000000Ogmo07moO`02
07moO`L00000X@3oool00`000000oooo0?ooo`090?ooo`00I`3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?oo
o`00IP3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`090?ooo`00IP3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00IP3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`090?ooo`00I@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I@3oool00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`090?ooo`00I@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I03oool00`000000Ogmo
07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`090?ooo`00I03oool00`000000Ogmo07moO`0507moO`L00000X@3oool00`000000oooo0?oo
o`090?ooo`00I03oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I03oool00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?oo
o`00H`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`090?ooo`00H`3oool00`000000Ogmo07moO`0607moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00H`3o
ool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`090?ooo`00HP3oool00`000000Ogmo07moO`0707moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00HP3oool00`00
0000Ogmo07moO`0707moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`090?ooo`00HP3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00HP3oool00`000000Ogmo
07moO`0707moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`090?ooo`00HP3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00F@3oool3000000H0oooo00<00000
07moO`1oOgl01@1oOgl900000:40oooo00<000000?ooo`3oool02@3oool000X0ooooD@09jPX50000
00X02NX:1@00000307moO`030000003oool0oooo09l0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<02NX:000000000000100000000`09jPX00000000000040000000300WZ2P000000000000<0
000000<02NX:000000000000100000000`09jPX00000000000030000000300WZ2P000000000000@0
000000<02NX:000000000000100000000`09jPX00000000000030000000300WZ2P000000000000@0
000000<02NX:000000000000100000000`09jPX00000000000030000000300WZ2P000000000000@0
000000<02NX:000000000000100000000`09jPX00000000000030000000300WZ2P000000000000@0
000000@02NX:00000000000000003`09jPZC0?ooo`030000003oool0oooo00T0oooo000:0?oooe40
2NX:1000000<00WZ2P<0000000<02NX:0000000000000`00000200WZ2PD0000000<02NX:0000003o
ool00`3ooolB00WZ2X40oooo00<000000?ooo`3oool02@3oool005T0oooo0P0000060?ooo`030000
001oOgl0Ogmo00H0Ogmo1000000407moO`0300000009jPX02NX:00P02NX:1@0000000`09jPX00000
000000030000000300WZ2P000000000000@0000000@02NX:0000003oool0oooo4@09jPY`0?ooo`03
0000003oool0oooo00T0oooo001Q0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl0
0`1oOgl00`000000oooo0?ooo`0E0?ooo`L02NX:1@0000000`09jPX00000000000030000000300WZ
2P000000000000@0000000<02NX:0000000000004009jPYN0?ooo`030000003oool0oooo00T0oooo
001Q0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0[0?ooo`H02NX:100000000`09jPX00000000000030000000300WZ2P000000000000@0000000<0
2NX:0000000000003P09jPY<0?ooo`030000003oool0oooo00T0oooo001Q0?ooo`030000001oOgl0
Ogmo00P0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`110?ooo`@02NX:0`000002
00WZ2PD0000000<02NX:000000000000100000000`09jPX000000000000;00WZ2S/0oooo00<00000
0?ooo`3oool02@3oool00640oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0307mo
O`030000003oool0oooo05L0oooo0P09jPX30000000300WZ2P000000000000@0000000<02NX:0000
00000000100000000`09jPX000000000000900WZ2R40oooo0P0000060?ooo`030000003oool0oooo
00T0oooo001I0?ooo`<000001@3oool00`000000Ogmo07moO`0607moO`<000001@1oOgl00`000000
oooo0?ooo`1]0?ooo`<0000000<02NX:000000000000100000000`09jPX000000000000400000004
00WZ2P0000000000000000H02NX:3`3oool5000000<0oooo00<000000?ooo`3oool02@3oool000X0
ooooD@09jPX5000000/02NX:0`0000000`09jPX000000000001X00WZ2Qh0oooo0P0000000`09jPX0
0000000000040000000300WZ2P000000000000<0000000<02NX:0000000000000P00000200WZ2PP0
00002`3oool000X0oooo00<02NX:000000000000100000000`09jPX00000000000040000000300WZ
2P000000000000<0000000<02NX:000000000000100000000`09jPX00000000000030000000300WZ
2P000000000000@0000000<02NX:000000000000100000000`09jPX00000000000030000000300WZ
2P000000000000@0000000<02NX:000000000000100000000`09jPX00000000000030000000300WZ
2P000000000000@0000000<02NX:000000000000100000000`09jPX00000000000030000000300WZ
2P000000000000@0000000<02NX:0000000000000`0000000`09jPX00000000000040000000300WZ
2P000000000000@0000000<02NX:0000000000000`0000000`09jPX00000000000040000000300WZ
2P000000000000@0000000<02NX:0000000000000`0000000`09jPX00000000000040000000300WZ
2P000000000000@0000000<02NX:0000000000000`0000000`09jPX00000000000040000000300WZ
2P000000000000<0000000<02NX:000000000000100000000`09jPX00000000000040000000300WZ
2P000000000000<0000000<02NX:000000000000100000000`09jPX00000000000040000000300WZ
2P000000000000<0000000<02NX:000000000000100000000`09jPX00000000000040000000300WZ
2P000000000000<0000000<02NX:000000000000100000001009jPX0000000000000000600WZ2P<0
000000<02NX:0000000000001@00000;0?ooo`002P3ooomA00WZ2P@000003009jPX30000000300WZ
2P0000002NX:01`02NX:H@3oool800WZ2P<0000000<02NX:000000000000100000000`09jPX00000
000000030000000400WZ2P000000000000000080oooo1P0000020?ooo`030000003oool0oooo00T0
oooo001I0?ooo`8000001P3oool00`000000Ogmo07moO`0607moO`<000001@1oOgl00`000000oooo
0?ooo`1S0?ooo`T02NX:100000000`09jPX00000000000040000000300WZ2P000000000000@00000
00@02NX:0000000000002NX:5@3oool2000000H0oooo00<000000?ooo`3oool02@3oool00640oooo
00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo04d0oooo
2`09jPX40000000300WZ2P000000000000@0000000<02NX:000000000000100000000`09jPX00000
00WZ2P0400WZ2Rh0oooo00<000000?ooo`3oool02@3oool00640oooo00<0000007moO`1oOgl0201o
Ogl00`000000Ogmo07moO`0307moO`030000003oool0oooo03L0oooo3@09jPX4000000802NX:1@00
00000`09jPX00000000000040000000400WZ2P0000002NX:00WZ2TD0oooo00<000000?ooo`3oool0
2@3oool00640oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0307moO`030000003o
ool0oooo0240oooo3`09jPX50000000300WZ2P000000000000<0000000<02NX:0000000000001000
00000`09jPX0000000WZ2P0500WZ2UD0oooo00<000000?ooo`3oool02@3oool005T0oooo0`000005
0?ooo`030000001oOgl0Ogmo00H0Ogmo0`00000507moO`030000003oool0oooo00/0oooo4009jPX6
0000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09jPX0000000WZ2P06
00WZ2VP0oooo00<000000?ooo`3oool02@3oool005X0oooo1P0000000`3oool0000007moO`0207mo
O`H02NX:0`0000000`09jPX000000000000;00WZ2PH0000000<02NX:0000000000000`0000000`09
jPX0000000000004000000/02NX:NP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`09jPX0
0000000000040000000300WZ2P000000000000@0000000<02NX:0000000000000`0000000`09jPX0
0000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09jPX0
0000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09jPX0
0000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09jPX0
0000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09jPX0
0000000000040000000300WZ2P000000000000<000003P09jPZ;0?ooo`030000003oool0oooo00T0
oooo000:0?oooe402NX:1000000<00WZ2P<0000000<02NX:00000009jPX01P09jPZM0?ooo`030000
003oool0oooo00T0oooo001I0?ooo`8000001`3oool00`000000Ogmo07moO`0507moO`<000001@1o
Ogl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001R0?ooo`030000001oOgl0
Ogmo00L0Ogmo1`00002Q0?ooo`030000003oool0oooo00T0oooo001R0?ooo`030000001oOgl0Ogmo
00L0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo
00T0oooo001R0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001R0?ooo`030000001oOgl0Ogmo00L0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo
001R0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo00T0oooo001R0?ooo`030000001oOgl0Ogmo00L0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001S0?oo
o`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?oo
o`030000003oool0oooo00T0oooo001S0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001S0?ooo`030000
001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo00T0oooo001S0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001T0?ooo`030000001oOgl0
Ogmo00D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo00T0oooo001T0?ooo`030000001oOgl0Ogmo00D0Ogmo1`00002Q0?ooo`030000003oool0oooo
00T0oooo001T0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001U0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo
001U0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo00T0oooo001U0?ooo`030000001oOgl0Ogmo00@0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001U0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?oo
o`030000003oool0oooo00T0oooo001V0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001V0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo00T0oooo001V0?ooo`030000001oOgl0Ogmo00<0Ogmo1`00002Q0?ooo`030000003o
ool0oooo00T0oooo001W0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001W0?ooo`030000001oOgl0Ogmo
0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo
00T0oooo001X0?ooo`050000001oOgl0Ogmo07moO`0000001@1oOgl00`000000oooo0?ooo`2O0?oo
o`030000003oool0oooo00T0oooo001X0?ooo`050000001oOgl0Ogmo07moO`0000001@1oOgl00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001X0?ooo`050000001oOgl0Ogmo07mo
O`0000001@1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001Y0?ooo`04
0000001oOgl0Ogmo000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?oo
o`00J@3oool00`000000Ogmo07moO`0700000:40oooo00<000000?ooo`3oool02@3oool006X0oooo
00<0000007moO`0000001@1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo
001Z0?ooo`030000001oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`090?ooo`00J`3oool2000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`09
0?ooo`00J`3oool2000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?oo
o`00J`3oool800000:40oooo00<000000?ooo`3oool02@3oool006`0oooo1`00002Q0?ooo`030000
003oool0oooo00T0oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {98.875, 0}} -> {-56.1948, -30.653, 0.576276, \
0.576276}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[intensity = FindField[waveletSystem]][[1]]/60/Second*\"Minute\"\
\>", "Input",
  CellLabel->"In[64]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],

Cell[BoxData[
    \(0.6852777777777779`\ "Minute"\)], "Output",
  CellLabel->"Out[64]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[intensity[0,y],{y,-.07,.07},PlotRange->All];", "Input",
  CellLabel->"In[65]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 6.80272 0.0146882 0.0119712 [
[.09184 .00219 -15 -9 ]
[.09184 .00219 15 0 ]
[.22789 .00219 -15 -9 ]
[.22789 .00219 15 0 ]
[.36395 .00219 -15 -9 ]
[.36395 .00219 15 0 ]
[.63605 .00219 -12 -9 ]
[.63605 .00219 12 0 ]
[.77211 .00219 -12 -9 ]
[.77211 .00219 12 0 ]
[.90816 .00219 -12 -9 ]
[.90816 .00219 12 0 ]
[.4875 .1344 -12 -4.5 ]
[.4875 .1344 0 4.5 ]
[.4875 .25411 -12 -4.5 ]
[.4875 .25411 0 4.5 ]
[.4875 .37382 -12 -4.5 ]
[.4875 .37382 0 4.5 ]
[.4875 .49354 -12 -4.5 ]
[.4875 .49354 0 4.5 ]
[.4875 .61325 -12 -4.5 ]
[.4875 .61325 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09184 .01469 m
.09184 .02094 L
s
[(-0.06)] .09184 .00219 0 1 Mshowa
.22789 .01469 m
.22789 .02094 L
s
[(-0.04)] .22789 .00219 0 1 Mshowa
.36395 .01469 m
.36395 .02094 L
s
[(-0.02)] .36395 .00219 0 1 Mshowa
.63605 .01469 m
.63605 .02094 L
s
[(0.02)] .63605 .00219 0 1 Mshowa
.77211 .01469 m
.77211 .02094 L
s
[(0.04)] .77211 .00219 0 1 Mshowa
.90816 .01469 m
.90816 .02094 L
s
[(0.06)] .90816 .00219 0 1 Mshowa
.125 Mabswid
.12585 .01469 m
.12585 .01844 L
s
.15986 .01469 m
.15986 .01844 L
s
.19388 .01469 m
.19388 .01844 L
s
.2619 .01469 m
.2619 .01844 L
s
.29592 .01469 m
.29592 .01844 L
s
.32993 .01469 m
.32993 .01844 L
s
.39796 .01469 m
.39796 .01844 L
s
.43197 .01469 m
.43197 .01844 L
s
.46599 .01469 m
.46599 .01844 L
s
.53401 .01469 m
.53401 .01844 L
s
.56803 .01469 m
.56803 .01844 L
s
.60204 .01469 m
.60204 .01844 L
s
.67007 .01469 m
.67007 .01844 L
s
.70408 .01469 m
.70408 .01844 L
s
.7381 .01469 m
.7381 .01844 L
s
.80612 .01469 m
.80612 .01844 L
s
.84014 .01469 m
.84014 .01844 L
s
.87415 .01469 m
.87415 .01844 L
s
.05782 .01469 m
.05782 .01844 L
s
.02381 .01469 m
.02381 .01844 L
s
.94218 .01469 m
.94218 .01844 L
s
.97619 .01469 m
.97619 .01844 L
s
.25 Mabswid
0 .01469 m
1 .01469 L
s
.5 .1344 m
.50625 .1344 L
s
[(10)] .4875 .1344 1 0 Mshowa
.5 .25411 m
.50625 .25411 L
s
[(20)] .4875 .25411 1 0 Mshowa
.5 .37382 m
.50625 .37382 L
s
[(30)] .4875 .37382 1 0 Mshowa
.5 .49354 m
.50625 .49354 L
s
[(40)] .4875 .49354 1 0 Mshowa
.5 .61325 m
.50625 .61325 L
s
[(50)] .4875 .61325 1 0 Mshowa
.125 Mabswid
.5 .03863 m
.50375 .03863 L
s
.5 .06257 m
.50375 .06257 L
s
.5 .08652 m
.50375 .08652 L
s
.5 .11046 m
.50375 .11046 L
s
.5 .15834 m
.50375 .15834 L
s
.5 .18228 m
.50375 .18228 L
s
.5 .20623 m
.50375 .20623 L
s
.5 .23017 m
.50375 .23017 L
s
.5 .27805 m
.50375 .27805 L
s
.5 .302 m
.50375 .302 L
s
.5 .32594 m
.50375 .32594 L
s
.5 .34988 m
.50375 .34988 L
s
.5 .39777 m
.50375 .39777 L
s
.5 .42171 m
.50375 .42171 L
s
.5 .44565 m
.50375 .44565 L
s
.5 .46959 m
.50375 .46959 L
s
.5 .51748 m
.50375 .51748 L
s
.5 .54142 m
.50375 .54142 L
s
.5 .56536 m
.50375 .56536 L
s
.5 .5893 m
.50375 .5893 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .01479 m
.02605 .01482 L
.02846 .01484 L
.02962 .01486 L
.03072 .01487 L
.0317 .01487 L
.03279 .01488 L
.03398 .01488 L
.03524 .01489 L
.03641 .01488 L
.0375 .01488 L
.03879 .01487 L
.03997 .01486 L
.04262 .01483 L
.04748 .01476 L
.04881 .01475 L
.05023 .01473 L
.05092 .01473 L
.05157 .01472 L
.05278 .01472 L
.05396 .01472 L
.0552 .01472 L
.05626 .01472 L
.05742 .01473 L
.05868 .01474 L
.06002 .01476 L
.06244 .01479 L
.06507 .01483 L
.0664 .01484 L
.06716 .01484 L
.06787 .01485 L
.06863 .01485 L
.06934 .01485 L
.07011 .01485 L
.07093 .01485 L
.07163 .01484 L
.07228 .01484 L
.07376 .01482 L
.07643 .01479 L
.07774 .01477 L
.07895 .01475 L
.07962 .01475 L
.08034 .01474 L
.08106 .01474 L
.08185 .01474 L
.0825 .01474 L
.08321 .01475 L
.08448 .01478 L
.08513 .0148 L
.08582 .01482 L
Mistroke
.08706 .01488 L
.08854 .01497 L
.08987 .01507 L
.09499 .01563 L
.09956 .01619 L
.10082 .01633 L
.10216 .01645 L
.10343 .01655 L
.10458 .01661 L
.10578 .01664 L
.10709 .01665 L
.10833 .01662 L
.10947 .01656 L
.11066 .01648 L
.11197 .01635 L
.11463 .01603 L
.11698 .01571 L
.11945 .01538 L
.12156 .01516 L
.12275 .01508 L
.12386 .01502 L
.12518 .015 L
.12637 .01501 L
.12703 .01503 L
.12775 .01507 L
.12904 .01516 L
.13045 .01531 L
.13194 .01549 L
.13462 .01584 L
.13693 .01613 L
.13823 .01625 L
.13942 .01633 L
.14009 .01636 L
.14082 .01638 L
.14151 .01638 L
.14215 .01637 L
.14338 .01632 L
.1447 .01622 L
.14925 .01564 L
.15036 .01549 L
.15154 .01536 L
.15284 .01526 L
.15405 .01524 L
.15473 .01526 L
.15547 .01531 L
.15617 .01539 L
.15681 .0155 L
.15803 .01579 L
.15932 .01622 L
.1605 .01674 L
Mistroke
.16161 .01733 L
.16415 .01903 L
.16866 .02279 L
.17089 .02465 L
.17295 .02614 L
.17419 .02685 L
.17531 .02736 L
.17656 .02773 L
.17725 .02785 L
.17789 .0279 L
.17903 .02784 L
.18007 .02762 L
.18121 .02721 L
.18242 .02659 L
.18729 .0227 L
.18969 .02051 L
.1919 .01874 L
.19314 .01796 L
.19445 .01735 L
.19577 .01698 L
.19652 .0169 L
.19722 .01691 L
.19844 .0171 L
.19956 .01748 L
.20078 .01811 L
.20207 .01896 L
.20631 .02252 L
.20742 .02345 L
.20863 .02436 L
.2097 .02503 L
.21083 .02558 L
.21148 .0258 L
.21218 .02597 L
.21343 .02604 L
.21465 .02585 L
.21579 .02542 L
.21696 .02478 L
.21802 .02402 L
.22041 .02198 L
.22159 .02091 L
.22288 .01985 L
.22408 .01903 L
.2252 .01851 L
.2265 .01829 L
.22715 .01836 L
.22787 .01861 L
.22912 .01948 L
.23029 .02084 L
.23148 .0228 L
.23261 .02519 L
Mistroke
.23471 .03099 L
.23945 .04854 L
.24194 .05839 L
.24427 .06646 L
.24554 .06998 L
.24671 .07248 L
.248 .07436 L
.24871 .07494 L
.24939 .0752 L
.25006 .07515 L
.25078 .07476 L
.25207 .07321 L
.25287 .07174 L
.25361 .07002 L
.255 .066 L
.26019 .04562 L
.26243 .03682 L
.26367 .03268 L
.26484 .02944 L
.2655 .02796 L
.26622 .02666 L
.26748 .02522 L
.26876 .02489 L
.26995 .02562 L
.27117 .02737 L
.27232 .02986 L
.27495 .0379 L
.27753 .04747 L
.27894 .05256 L
.28026 .05681 L
.28142 .05993 L
.28247 .06211 L
.28364 .06369 L
.28489 .06428 L
.28594 .06388 L
.28708 .06252 L
.28815 .06042 L
.28914 .05783 L
.29171 .04909 L
.29415 .03988 L
.29521 .03628 L
.29634 .03307 L
.29758 .03061 L
.29873 .02961 L
.29999 .03021 L
.30118 .0326 L
.30224 .03638 L
.3034 .04226 L
.30467 .05089 L
.30601 .06232 L
Mistroke
.30842 .08777 L
.31279 .14228 L
.3152 .17001 L
.31639 .18144 L
.31748 .1902 L
.31876 .19785 L
.31943 .20065 L
.32015 .20264 L
.3213 .20364 L
.32258 .20151 L
.32376 .19658 L
.32503 .18825 L
.32623 .17784 L
.32733 .16645 L
.33255 .10087 L
.33392 .08444 L
.33541 .06901 L
.3361 .06301 L
.33682 .05752 L
.33812 .05011 L
.33939 .04613 L
.34057 .04544 L
.34187 .04802 L
.3426 .05093 L
.34327 .05443 L
.34442 .06219 L
.34567 .07272 L
.34794 .09547 L
.35024 .11943 L
.3515 .13136 L
.35268 .14099 L
.35368 .14756 L
.35477 .15271 L
.35597 .1558 L
.35707 .15605 L
.35828 .15346 L
.35956 .14751 L
.36078 .13919 L
.36188 .12974 L
.36462 .10164 L
.36715 .07594 L
.36843 .0656 L
.36907 .06145 L
.36977 .0579 L
.37048 .05554 L
.37124 .05447 L
.37196 .05498 L
.37262 .05682 L
.37388 .06422 L
.3746 .07073 L
Mistroke
.37527 .07827 L
.37648 .09577 L
.37778 .11935 L
.38279 .24342 L
.38552 .3162 L
.38807 .3727 L
.38941 .39448 L
.39015 .4038 L
.39084 .41031 L
.39158 .41516 L
.39239 .41767 L
.39316 .41733 L
.39387 .41468 L
.3951 .40484 L
.3958 .39639 L
.39645 .38669 L
.3992 .33039 L
.40393 .20307 L
.40651 .13982 L
.40777 .11518 L
.40891 .09749 L
.41017 .0838 L
.41086 .07904 L
.41152 .07639 L
.41223 .07553 L
.41288 .0766 L
.41361 .07975 L
.41437 .08523 L
.4156 .09836 L
.41675 .11475 L
.41937 .16196 L
.42179 .20902 L
.42311 .23256 L
.42435 .25148 L
.42506 .26045 L
.42583 .26839 L
.42653 .2739 L
.42717 .27743 L
.42844 .2799 L
.42908 .27883 L
.42978 .27587 L
.43108 .26576 L
.43225 .25172 L
.4349 .20746 L
.43738 .15873 L
.43847 .13818 L
.43967 .11791 L
.44073 .10303 L
.44188 .09133 L
.44309 .08484 L
Mistroke
.44423 .08496 L
.44487 .08783 L
.44556 .09334 L
.44682 .10982 L
.44805 .13371 L
.44919 .16243 L
.45355 .31517 L
.4582 .49371 L
.45955 .53497 L
.4608 .56588 L
.46211 .58882 L
.46281 .59675 L
.46355 .60183 L
.46487 .60193 L
.46613 .5915 L
.46725 .57374 L
.46848 .54612 L
.47128 .4568 L
.47425 .33957 L
.47682 .23981 L
.47817 .19399 L
.4796 .15354 L
.48083 .12641 L
.48152 .11459 L
.48217 .10602 L
.48332 .09672 L
.48454 .0949 L
.48579 .10131 L
.48697 .11434 L
.48803 .13102 L
.48918 .15339 L
.49181 .21461 L
.49464 .2803 L
.49602 .3063 L
.49732 .32518 L
.49849 .33629 L
.49976 .34147 L
.50101 .33924 L
.50214 .33111 L
.50344 .31499 L
.50467 .29409 L
.50921 .18978 L
.51165 .13694 L
.51287 .11659 L
.51357 .10767 L
.51421 .1013 L
.51493 .09667 L
.51557 .09473 L
.51632 .09532 L
.51703 .09875 L
Mistroke
.51827 .11162 L
.51897 .12271 L
.51962 .13533 L
.52484 .3033 L
.52759 .41335 L
.52908 .46983 L
.53047 .51634 L
.5318 .55316 L
.53301 .5786 L
.5337 .58931 L
.53435 .5967 L
.53504 .60155 L
.53579 .60332 L
.53702 .59826 L
.53832 .58233 L
.53943 .56068 L
.54066 .52922 L
.54528 .36204 L
.54967 .19674 L
.55084 .16156 L
.55209 .13067 L
.5528 .11627 L
.55346 .10549 L
.55472 .09079 L
.55587 .08469 L
.5571 .08544 L
.55827 .09257 L
.55934 .10393 L
.56062 .12245 L
.56181 .1433 L
.56452 .1963 L
.566 .22395 L
.56739 .24662 L
.56864 .26272 L
.56934 .26966 L
.56999 .27454 L
.5711 .2793 L
.57233 .27913 L
.5736 .27296 L
.5748 .26195 L
.5761 .24506 L
.57728 .22592 L
.57995 .17531 L
.5824 .12881 L
.58361 .1093 L
.58471 .09457 L
.58599 .08237 L
.58667 .07832 L
.58738 .07596 L
.58853 .07651 L
Mistroke
.58979 .08348 L
.59099 .09609 L
.59207 .11241 L
.59452 .16333 L
.59893 .28185 L
.6014 .3446 L
.60276 .37292 L
.60403 .39396 L
.60469 .40244 L
.6054 .40957 L
.60618 .41495 L
.60691 .41747 L
.60821 .41611 L
.60886 .41259 L
.60957 .40665 L
.61089 .39013 L
.6121 .36952 L
.61479 .30825 L
.61965 .17822 L
.62216 .12055 L
.62338 .09797 L
.6245 .08126 L
.62568 .06799 L
.62694 .05879 L
.6276 .05605 L
.62832 .0546 L
.62963 .05584 L
.63085 .06096 L
.63195 .06835 L
.63441 .09134 L
.63656 .11429 L
.63883 .13607 L
.64012 .14554 L
.64084 .14971 L
.64152 .15272 L
.64271 .1558 L
.64398 .15587 L
.6447 .15443 L
.64548 .15172 L
.64622 .14812 L
.6469 .14395 L
.64955 .12154 L
.6544 .07208 L
.65573 .06107 L
.65646 .05609 L
.65713 .05223 L
.65833 .04741 L
.65963 .04535 L
.66089 .04672 L
.66208 .05102 L
Mistroke
.66314 .05728 L
.6643 .0664 L
.66689 .09398 L
.66928 .1244 L
.67155 .15342 L
.67368 .17692 L
.67484 .18719 L
.67589 .19458 L
.67707 .20032 L
.67833 .20337 L
.6796 .20309 L
.68025 .20167 L
.68096 .19912 L
.68222 .19227 L
.6834 .18332 L
.68605 .1562 L
.68891 .12079 L
.69142 .08968 L
.69411 .06122 L
.69541 .05029 L
.69664 .04204 L
.69775 .03643 L
.69894 .03227 L
.70009 .03011 L
.70136 .02964 L
.70268 .03101 L
.70391 .03372 L
.70507 .03718 L
.70612 .04088 L
.7085 .04988 L
.70974 .05432 L
.71106 .05842 L
.71182 .06036 L
.71251 .06182 L
.71321 .06296 L
.71386 .06371 L
.71514 .06428 L
.71631 .06373 L
.7176 .06199 L
.71825 .0607 L
.71896 .05899 L
.72422 .0409 L
.72561 .03598 L
.72712 .03132 L
.72781 .02953 L
.72855 .02791 L
.72987 .02582 L
.73117 .0249 L
.7324 .02514 L
.7331 .02575 L
Mistroke
.73374 .0266 L
.73445 .02786 L
.73519 .02952 L
.73751 .03662 L
.74005 .04661 L
.74259 .05717 L
.74392 .06232 L
.74534 .06708 L
.74658 .07048 L
.74723 .07194 L
.74794 .07323 L
.74917 .07472 L
.75033 .07521 L
.75153 .07478 L
.75283 .07326 L
.75407 .07089 L
.75521 .06797 L
.75967 .0521 L
.76218 .04205 L
.7649 .03222 L
.76615 .02842 L
.76747 .02502 L
.7686 .02264 L
.76982 .02069 L
.77055 .0198 L
.77122 .01918 L
.77253 .01845 L
.77326 .0183 L
.77405 .01833 L
.7748 .01851 L
.77549 .0188 L
.77668 .01952 L
.77798 .02055 L
.78062 .0229 L
.78182 .0239 L
.7831 .02481 L
.78384 .02524 L
.78451 .02556 L
.78581 .02595 L
.78703 .02605 L
.78836 .02585 L
.7896 .02539 L
.79075 .02476 L
.79554 .0209 L
.79788 .01899 L
.79891 .0183 L
.80002 .01768 L
.80122 .0172 L
.80235 .01695 L
.80365 .01691 L
Mistroke
.80486 .01712 L
.80608 .01757 L
.80678 .01792 L
.80743 .0183 L
.81017 .02039 L
.81529 .02497 L
.81669 .02603 L
.81746 .02652 L
.81819 .02693 L
.81887 .02725 L
.81961 .02753 L
.82089 .02783 L
.82208 .0279 L
.82338 .02775 L
.82403 .02758 L
.82473 .02734 L
.826 .02675 L
.82847 .02515 L
.83072 .02333 L
.83567 .01917 L
.83702 .01819 L
.83847 .01729 L
.83971 .01664 L
.84106 .01608 L
.84171 .01586 L
.8424 .01567 L
.84363 .01542 L
.84478 .01529 L
.84604 .01524 L
.84717 .01526 L
.84838 .01535 L
.84952 .01548 L
.85055 .01561 L
.85277 .01592 L
.85394 .01607 L
.85518 .01621 L
.85627 .0163 L
.85746 .01636 L
.85855 .01638 L
.85956 .01637 L
.86074 .01632 L
.862 .01623 L
.86319 .01611 L
.86427 .01599 L
.86941 .01532 L
.87066 .01519 L
.87197 .01509 L
.87266 .01505 L
.87342 .01502 L
.8741 .015 L
Mistroke
.87475 .015 L
.87601 .01502 L
.87717 .01507 L
.87781 .01511 L
.87851 .01517 L
.87977 .01529 L
.88443 .0159 L
.88698 .01624 L
.88824 .01637 L
.88938 .01648 L
.89037 .01655 L
.89142 .01661 L
.89247 .01664 L
.89361 .01665 L
.89478 .01663 L
.89603 .01658 L
.89721 .0165 L
.89829 .01641 L
.90758 .01532 L
.90984 .0151 L
.91227 .01492 L
.91366 .01484 L
.91494 .0148 L
.91622 .01476 L
.91744 .01475 L
.91873 .01474 L
.91946 .01474 L
.92012 .01474 L
.9214 .01476 L
.9226 .01477 L
.92554 .01481 L
.92683 .01483 L
.92751 .01484 L
.92824 .01484 L
.92945 .01485 L
.93057 .01485 L
.93186 .01485 L
.93304 .01484 L
.93431 .01483 L
.9357 .01482 L
.93822 .01478 L
.94039 .01475 L
.94153 .01474 L
.94273 .01473 L
.94379 .01472 L
.94495 .01472 L
.946 .01472 L
.94697 .01472 L
.94823 .01472 L
.94942 .01473 L
Mistroke
.95049 .01474 L
.95164 .01475 L
.95663 .01482 L
.95919 .01485 L
.96043 .01486 L
.96158 .01487 L
.96278 .01488 L
.96407 .01488 L
.96474 .01489 L
.96547 .01488 L
.96617 .01488 L
.96681 .01488 L
.96804 .01487 L
.96919 .01487 L
.97135 .01485 L
.97619 .01479 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[65]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`006`3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`00000@0?oo
o`800000103oool00`000000oooo0?ooo`030?ooo`800000103oool300000100oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P0000020?ooo`D00000<03oool2000000@0oooo00<000000?oo
o`3oool00`3oool200000080oooo1@00000@0?ooo`800000103oool00`000000oooo0?ooo`030?oo
o`800000103oool3000000l0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?oo
o`<000006P3oool001X0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000;`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000003`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03@3o
ool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo0?ooo`0G0?ooo`004`3oool500000080oooo00@000000?ooo`3oool00000203oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01@3oool500000080oooo00@0
00000?ooo`3oool00000203oool01@000000oooo0?ooo`000000oooo00D00000203oool500000080
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo02l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00l0oooo00@000000?ooo`3oool00000203oool01@000000oooo0?ooo`000000oooo
00D000003P3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0G0?ooo`006P3oool010000000oooo0?ooo`0000080?ooo`050000
003oool0oooo0000003oool01000000?0?ooo`040000003oool0oooo000000P0oooo00H000000?oo
o`3oool000000?ooo`0000020?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0oooo00@00000
0?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3o
ool03@3oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool01000000J
0?ooo`006P3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
4P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`000000403oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0000000l0oooo00@000000?ooo`3oool0
0000203oool01P000000oooo0?ooo`000000oooo000001d0oooo000J0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool200000100oooo00@000000?ooo`3o
ool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0;@3o
ool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool000000`3oool00`00
0000oooo0?ooo`0=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3o
ool2000000l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo01X0oooo000K0?ooo`8000002P3oool2000000@0oooo0P00000@0?ooo`800000
2P3oool2000000D0oooo00<000000?ooo`3oool03`3oool2000000X0oooo0P0000030?ooo`<00000
<@3oool2000000X0oooo0P0000030?ooo`<000004@3oool2000000X0oooo0P0000050?ooo`030000
003oool0oooo00h0oooo0P00000:0?ooo`800000103oool2000001X0oooo002?0?ooo`030000003o
ool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo
08h0oooo002?0?ooo`030000003oool0oooo08h0oooo00090?ooool000003P00000:0?ooo`00403o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`8000001P3oool4000000D0oooo0`0000070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`<000001@3o
ool4000000D0oooo0`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo000R0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool4
000002<0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo0P0000000`3oool000000?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0240oooo000g0?ooo`@000001P3oool3
000000<0oooo00<000000?ooo`3oool01P3oool3000003`0oooo00<000000?ooo`3oool0>P3oool3
000000P0oooo00@000000?ooo`3oool0oooo0`0000050?ooo`D00000>03oool004P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo000000060?ooo`800000=03oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`17
0?ooo`00B03oool00`000000oooo0?ooo`050?ooo`030000003oool0000000H0oooo0P00000d0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`0000001@3oool00`000000oooo000000070?oo
o`030000003oool0oooo04L0oooo00180?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0000003@0oooo0P00000c0?ooo`030000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo04L0oooo00190?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
000003@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo000000040?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`180?ooo`00B@3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000090?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo04P0oooo
00190?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`000000203oool2000002T0oooo00<000000?ooo`3oool09`3oool2000000P0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`190?ooo`00B@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`800000:@3oool0
0`000000oooo0?ooo`0W0?ooo`800000203oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000004/0oooo001:0?ooo`050000003o
ool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`0000001P3oool200000240oooo00<000000?ooo`3oool07`3oool2000000H0
oooo00<000000?ooo`0000001`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool0000004/0oooo001:0?ooo`050000003oool0oooo
0?ooo`0000001P3oool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo00000006
0?ooo`8000008@3oool00`000000oooo0?ooo`0O0?ooo`8000001P3oool00`000000oooo00000007
0?ooo`040000003oool0oooo0?ooo`@000001@3oool01@000000oooo0?ooo`3oool0000004/0oooo
001:0?ooo`040000003oool0oooo000000L0oooo0P0000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`0000001P3oool200000240oooo0P00000P0?ooo`8000001P3oool00`000000oooo
000000070?ooo`030000003oool0oooo0080oooo0P0000060?ooo`040000003oool0oooo000004`0
oooo001;0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
000000060?ooo`8000008@3oool00`000000oooo0?ooo`0O0?ooo`8000001@3oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000C03oool004/0oooo
00<000000?ooo`0000003@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000D0
oooo0P00000Q0?ooo`030000003oool0oooo01l0oooo0P0000050?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0000001<0?ooo`00C03oool2000000d0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`030000003oool00000
00T0oooo0P00000F0?ooo`030000003oool0oooo01@0oooo0P0000090?ooo`8000001@3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo00/0oooo0`00001<0?ooo`00G03oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000203o
ool2000001H0oooo00<000000?ooo`3oool0503oool2000000P0oooo00<000000?ooo`0000001@3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo05/0oooo001L0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000080?ooo`80
00005P3oool00`000000oooo0?ooo`0D0?ooo`800000203oool010000000oooo0?ooo`0000040?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`1K0?ooo`00G03oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000203o
ool2000000L0oooo00<000000?ooo`3oool0303oool2000000d0oooo00<000000?ooo`3oool01@3o
ool2000000P0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool0F`3oool005`0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000P0oooo0P0000060?ooo`8000003P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0P0000080?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo05/0oooo001L
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000080?ooo`8000001P3oool2000000X0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00P0oooo0P0000060?ooo`800000203oool010000000oooo0?ooo`0000040?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`1K0?ooo`00G03oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`00
00080?ooo`8000001P3oool2000000X0oooo00D000000?ooo`3oool0oooo000000030?ooo`800000
2@3oool2000000H0oooo0P0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05/0oooo001L0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0000
00P0oooo0P0000060?ooo`8000002P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P000008
0?ooo`030000003oool0000000H0oooo0P0000080?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05/0oooo001L
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003o
ool0oooo000000P0oooo0P0000060?ooo`030000003oool0000000P0oooo0P0000030?ooo`040000
003oool0oooo0?ooo`800000203oool00`000000oooo000000050?ooo`030000003oool0000000P0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`00G03oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000070?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`000000203oool2000000<0oooo00@000000?ooo`3oool0oooo
0P0000080?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000001`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo05/0oooo001L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0000000P0oooo00<000000?ooo`0000000P3oool2
00000080oooo0P0000080?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000001`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo05/0oooo001M0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000P0oooo00<000000?ooo`00
00000P3oool01P000000oooo0?ooo`000000oooo000000P0oooo00<000000?ooo`0000001@3oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0F`3oool005d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000P0
oooo00<000000?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000000P0oooo00<00000
0?ooo`0000001@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
F`3oool005d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0000000800000103oool3000000050?ooo`000000oooo0?ooo`0000000P3oool00`00
0000oooo000000080?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool000001`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo05/0oooo001M0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool000001@3oool010000000oooo0000000000040?ooo`060000003oool0oooo0000
003oool000000P3oool01P000000oooo0?ooo`000000oooo000000P0oooo00<000000?ooo`000000
1@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0F`3oool005d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000050?ooo`040000003oool0
0000000000@0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`060000003oool0oooo0000
003oool00000203oool00`000000oooo000000050?ooo`040000003oool0oooo000000L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1K0?ooo`00G@3oool01@000000oooo0?ooo`3oool0000000D0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0000
00D0oooo00@000000?ooo`0000000000103oool01P000000oooo0?ooo`000000oooo00000080oooo
100000000`3oool000000?ooo`070?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3o
ool000001`3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo05/0oooo001M0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000
1@3oool010000000oooo0000000000040?ooo`060000003oool0oooo0000003oool000000P3oool0
1P000000oooo0?ooo`000000oooo000000P0oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`0000070?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0F`3oool005d0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?oo
o`0000050?ooo`040000003oool00000000000@0oooo00H000000?ooo`3oool000000?ooo`000002
0?ooo`060000003oool0oooo0000003oool00000203oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000L0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00D0
00000?ooo`3oool0oooo0000001N0?ooo`00G@3oool01@000000oooo0?ooo`3oool0000000H0oooo
0P0000040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000001@3oool010000000
oooo0000000000050?ooo`<0000000D0oooo0000003oool0oooo000000020?ooo`030000003oool0
000000P0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000070?ooo`070000
003oool0oooo0?ooo`000000oooo000000060?ooo`050000003oool0oooo0?ooo`000000GP3oool0
05d0oooo00D000000?ooo`3oool0oooo000000060?ooo`800000103oool00`000000oooo0?ooo`05
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000203oool00`000000oooo
000000020?ooo`060000003oool0oooo0000003oool00000203oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00P3oool2000000H0oooo00D0
00000?ooo`3oool0oooo0000001N0?ooo`00G@3oool01@000000oooo0?ooo`3oool0000000H0oooo
0P0000050?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`0000080?ooo`030000003oool000000080oooo00H000000?ooo`3oool000000?ooo`00
00080?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo00<0oooo0P0000060?ooo`050000003oool0oooo0?ooo`000000GP3oool005h0
oooo00@000000?ooo`3oool000001P3oool2000000D0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`0000000P3o
ool2000000040?ooo`000000oooo000000P0oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00D000000?oo
o`3oool0oooo0000001N0?ooo`00GP3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0
oooo00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000080?ooo`030000
003oool000000080oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`040000003oool0oooo
000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00/0oooo00D0
00000?ooo`3oool0oooo0000001N0?ooo`00GP3oool010000000oooo0?ooo`00000=0?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000080?oo
o`030000003oool000000080oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`040000003o
ool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00/0
oooo00D000000?ooo`3oool0oooo0000001N0?ooo`00GP3oool010000000oooo0?ooo`00000=0?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00080?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`060?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000001N0?ooo`00GP3oool010000000
oooo0?ooo`00000=0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`0000000P3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000`3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00001O0?oo
o`00GP3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`040000003oool0oooo000000L0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo000000020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0
00000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`00001O0?ooo`00GP3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000L0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool02`3oool010000000oooo0?ooo`00001O0?ooo`00GP3oool010000000oooo0?ooo`00
000=0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000
003oool0oooo000000L0oooo00@000000?ooo`3oool000000P3oool3000000<0oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000G`3oool005h0oooo00<00000
0?ooo`0000003P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0000001O0?ooo`00GP3oool00`000000oooo0000000>0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool01@3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000005l0oooo001N
0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`000000G`3oool005l0oooo0P00000>0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool01@3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0<0?ooo`800000H03oool005l0oooo0P00000>
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0103oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0<0?ooo`800000H03o
ool006l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`060000003oool0oooo0?ooo`000000
oooo0`0000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`1^0?ooo`00K`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0KP3oool006l0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1^0?ooo`00L03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06h0oooo001`0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0103oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0KP3oool00700oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1^0?ooo`00L03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00@0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06h0oooo001`0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00@0oooo00H000000?ooo`3oool0oooo0000003oool3000000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1^0?ooo`00L03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1^0?ooo`00L03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`1^0?ooo`00L03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool5000000<0oooo0P0000030?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo06h0oooo001`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000030?ooo`80000000H0oooo0000003oool0oooo0000003oool200000080oooo00@0
00000?ooo`0000000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06l0oooo
001`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`00000000000`3oool3000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1_0?ooo`00L03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool2000000<0oooo00@0
00000?ooo`00000000000`3oool4000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1_0?ooo`00L03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0000003oool000000080oooo00@000000?ooo`000000
00000`3oool3000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1_0?ooo`00
L03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
0P3oool01@000000oooo0000003oool000000080oooo00@000000?ooo`00000000000`3oool30000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1_0?ooo`00L03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool3000000@0
oooo0P0000040?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06l0
oooo001`0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo06l0oooo001`0?ooo`050000003oool0oooo0?ooo`0000001P3oool2000000D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0K`3oool00700oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<0
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0K`3oool00700oooo00D000000?ooo`3oool0
oooo000000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06l0
oooo001`0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06l0oooo001`0?ooo`050000
003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo0`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo06l0oooo001`0?ooo`050000003oool0oooo0?ooo`00
00003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo06l0oooo001`0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06l0
oooo001`0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06l0oooo001`0?ooo`050000
003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo0`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo06l0oooo001`0?ooo`050000003oool0oooo0?ooo`00
00003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo06l0oooo001`0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06l0
oooo001`0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0303oool01@000000oooo0?ooo`3oool000000740oooo001`0?ooo`050000003oool0oooo0?oo
o`0000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`0000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0
00000740oooo001`0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000740oooo001`0?ooo`050000003oool0
oooo0?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`00
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool01@000000oooo0?oo
o`3oool000000740oooo001`0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000740oooo001`0?ooo`050000
003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool01@000000
oooo0?ooo`3oool000000740oooo001`0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000740oooo001`0?oo
o`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00`0oooo00@000000?ooo`3oool00000LP3oool00700oooo00D000000?ooo`3oool0oooo0000
000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool010000000oooo0?oo
o`00001b0?ooo`00L@3oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0303oool010000000oooo0?ooo`00001b0?ooo`00L@3oool010000000oooo
0?ooo`00000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo0000
0780oooo001a0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0<0?ooo`040000003oool0oooo00000780oooo001a0?ooo`030000003oool00000
00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo
00000780oooo001a0?ooo`030000003oool0000000d0oooo0`0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool01000
0000oooo0?ooo`00001b0?ooo`00L@3oool00`000000oooo0000000<0?ooo`030000003oool0oooo
008000000P3oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000LP3oool0
0740oooo00<000000?ooo`0000003`3oool200000080oooo0P0000000`3oool000000?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?oo
o`040000003oool0oooo00000780oooo001a0?ooo`030000003oool0000000h0oooo0P0000030?oo
o`80000000<0oooo0000003oool00`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0<0?ooo`040000003oool0oooo00000780oooo001a0?ooo`030000003oool00000
00l0oooo0P0000020?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00001b
0?ooo`00L@3oool00`000000oooo0000000<0?ooo`030000003oool0oooo008000000P3oool20000
00030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000LP3oool00740oooo00<000000?oo
o`0000003@3oool3000000@0oooo0P0000050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000780oooo001a0?ooo`03
0000003oool0000000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool000000780oooo001a0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000780oooo001a0?ooo`030000003o
ool0000000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000001@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000LP3o
ool00780oooo0P00000?0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool2000007<0oooo001b
0?ooo`8000003`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo0P00001c0?ooo`00LP3oool2
00000100oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool2000007<0oooo001b0?ooo`800000403oool0
10000000oooo0?ooo`0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`800000L`3oool00780oooo0P00000@0?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo0P00001c0?ooo`00LP3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0L@3oool008@0oooo00@000000?ooo`3oool000001`3o
ool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`220?ooo`00Q03oool0
10000000oooo0?ooo`0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`220?ooo`00Q03oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`220?ooo`00Q03oool0
10000000oooo0?ooo`0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`220?ooo`00Q03oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`220?ooo`00Q03oool0
10000000oooo0?ooo`0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`220?ooo`00Q03oool010000000oooo0?ooo`0000070?ooo`8000001P3o
ool01@000000oooo0?ooo`3oool0000008@0oooo00240?ooo`040000003oool0oooo000000L0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000250?ooo`00Q03oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000Q@3oool008@0
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo
000008D0oooo00240?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`0000250?ooo`00Q03oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool00000Q@3oool008@0oooo00@000000?ooo`3oool00000
1`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000008D0oooo00240?ooo`040000
003oool0oooo000000L0oooo0P0000060?ooo`040000003oool0oooo000008D0oooo00240?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000025
0?ooo`00Q03oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool00000Q@3oool00880oooo0`0000020?ooo`<000001@3oool00`000000oooo0?ooo`05
0?ooo`040000003oool0oooo000008D0oooo00230?ooo`8000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000Q@3oool00800oooo1@00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`0000250?ooo`00P03oool00`000000oooo0?ooo`0200000080oooo00@000000?ooo`3oool0
0000103oool3000000D0oooo00@000000?ooo`3oool00000Q@3oool00840oooo00@000000?ooo`00
000000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool00000Q@3oool00880oooo0`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000250?ooo`00P`3oool200000080oooo0`00
00050?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000Q@3oool008@0oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000008D0
oooo00240?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`0000250?ooo`00Q03oool010000000oooo0?ooo`0000070?ooo`8000001P3oool01000
0000oooo0?ooo`0000250?ooo`00Q03oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`3oool00000Q@3oool008@0oooo00@000000?ooo`3oool000001`3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000008D0oooo00240?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000250?ooo`00
Q03oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool00000Q@3oool008@0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo000008D0oooo00240?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000250?ooo`00Q03oool010000000oooo0?ooo`000007
0?ooo`8000001`3oool00`000000oooo000000250?ooo`00Q03oool010000000oooo0?ooo`000007
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000Q@3oool008@0oooo00@000000?oo
o`3oool000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000008D0oooo00250?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000250?oo
o`00Q@3oool00`000000oooo000000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
0000Q@3oool008D0oooo0P0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
Q@3oool008D0oooo0P0000080?ooo`8000001`3oool00`000000oooo000000250?ooo`00Q@3oool2
000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000250?ooo`00Q@3oool20000
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000250?ooo`00Q@3oool2000000P0
oooo00<000000?ooo`3oool01P3oool2000008H0oooo00250?ooo`800000203oool00`000000oooo
0?ooo`060?ooo`800000QP3oool008D0oooo0P0000080?ooo`030000003oool0oooo00H0oooo0P00
00260?ooo`00Q@3oool2000000P0oooo00<000000?ooo`3oool01P3oool2000008H0oooo00250?oo
o`800000203oool2000000L0oooo0P0000260?ooo`00Q@3oool2000000P0oooo00<000000?ooo`3o
ool01P3oool2000008H0oooo00250?ooo`800000203oool00`000000oooo0?ooo`060?ooo`800000
QP3oool00840oooo0`000000103oool000000000003oool2000000D0oooo00<000000?ooo`3oool0
1P3oool2000008H0oooo00200?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo08h0oooo00240?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2>0?ooo`00Q03oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00002>0?ooo`00P03oool4000000<0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo000009D0oooo00200?ooo`D000000`3oool2000009H0oooo
003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0788689, -3.85515, \
0.000549609, 0.312319}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[intensity[-10,y],{y,-1,1},PlotRange->All];", "Input",
  CellLabel->"In[66]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0147151 0.127727 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -12 -9 ]
[.2619 .00222 12 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .14244 -6 -4.5 ]
[.4875 .14244 0 4.5 ]
[.4875 .27017 -6 -4.5 ]
[.4875 .27017 0 4.5 ]
[.4875 .3979 -6 -4.5 ]
[.4875 .3979 0 4.5 ]
[.4875 .52562 -6 -4.5 ]
[.4875 .52562 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-0.5)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(0.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .14244 m
.50625 .14244 L
s
[(1)] .4875 .14244 1 0 Mshowa
.5 .27017 m
.50625 .27017 L
s
[(2)] .4875 .27017 1 0 Mshowa
.5 .3979 m
.50625 .3979 L
s
[(3)] .4875 .3979 1 0 Mshowa
.5 .52562 m
.50625 .52562 L
s
[(4)] .4875 .52562 1 0 Mshowa
.125 Mabswid
.5 .04026 m
.50375 .04026 L
s
.5 .06581 m
.50375 .06581 L
s
.5 .09135 m
.50375 .09135 L
s
.5 .1169 m
.50375 .1169 L
s
.5 .16799 m
.50375 .16799 L
s
.5 .19353 m
.50375 .19353 L
s
.5 .21908 m
.50375 .21908 L
s
.5 .24462 m
.50375 .24462 L
s
.5 .29572 m
.50375 .29572 L
s
.5 .32126 m
.50375 .32126 L
s
.5 .34681 m
.50375 .34681 L
s
.5 .37235 m
.50375 .37235 L
s
.5 .42344 m
.50375 .42344 L
s
.5 .44899 m
.50375 .44899 L
s
.5 .47453 m
.50375 .47453 L
s
.5 .50008 m
.50375 .50008 L
s
.5 .55117 m
.50375 .55117 L
s
.5 .57672 m
.50375 .57672 L
s
.5 .60226 m
.50375 .60226 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04588 .01472 L
.04652 .01472 L
.04722 .01472 L
.04797 .01472 L
.04862 .01472 L
.04933 .01472 L
.05061 .01472 L
.05186 .01472 L
.05302 .01472 L
.05414 .01472 L
.05519 .01472 L
.05634 .01472 L
.05759 .01472 L
.05882 .01472 L
.06012 .01472 L
.06123 .01472 L
.06244 .01472 L
.06315 .01472 L
.06381 .01472 L
.06453 .01472 L
.06529 .01472 L
.06657 .01472 L
.06729 .01472 L
.06797 .01472 L
.06924 .01472 L
.0704 .01472 L
.07103 .01472 L
.07173 .01472 L
.073 .01472 L
Mistroke
.07376 .01472 L
.07448 .01472 L
.07513 .01472 L
.07583 .01472 L
.0766 .01472 L
.0774 .01472 L
.07809 .01472 L
.07885 .01472 L
.07956 .01472 L
.0802 .01472 L
.08095 .01472 L
.08166 .01472 L
.08291 .01472 L
.08362 .01472 L
.08427 .01472 L
.08544 .01472 L
.08669 .01472 L
.08787 .01472 L
.08896 .01472 L
.09016 .01472 L
.09148 .01472 L
.09214 .01472 L
.09285 .01472 L
.09413 .01472 L
.09483 .01472 L
.09548 .01472 L
.09619 .01472 L
.09695 .01472 L
.09821 .01472 L
.09893 .01472 L
.09961 .01472 L
.10086 .01472 L
.10201 .01472 L
.10333 .01472 L
.10458 .01472 L
.10572 .01472 L
.10694 .01472 L
.1081 .01472 L
.10916 .01472 L
.11033 .01472 L
.11162 .01472 L
.11227 .01472 L
.11297 .01472 L
.11422 .01472 L
.11491 .01472 L
.11554 .01472 L
.11624 .01472 L
.11698 .01472 L
.11822 .01472 L
.11892 .01472 L
Mistroke
.11958 .01472 L
.12081 .01472 L
.12194 .01472 L
.12323 .01472 L
.12446 .01472 L
.12562 .01472 L
.12668 .01472 L
.12789 .01472 L
.12903 .01472 L
.13009 .01472 L
.13107 .01472 L
.13214 .01472 L
.13327 .01472 L
.13441 .01472 L
.13564 .01472 L
.1368 .01472 L
.13785 .01472 L
.13909 .01472 L
.13979 .01472 L
.14043 .01472 L
.14162 .01472 L
.14288 .01472 L
.14402 .01472 L
.14526 .01472 L
.14656 .01472 L
.14777 .01472 L
.14891 .01472 L
.14994 .01472 L
.15113 .01472 L
.15226 .01472 L
.15348 .01472 L
.15478 .01472 L
.15589 .01472 L
.15711 .01472 L
.15842 .01472 L
.15915 .01472 L
.15982 .01472 L
.16113 .01472 L
.16236 .01472 L
.16352 .01472 L
.16456 .01472 L
.16577 .01472 L
.1669 .01472 L
.16796 .01472 L
.16893 .01472 L
.16999 .01472 L
.17111 .01472 L
.17225 .01472 L
.17347 .01472 L
.17462 .01472 L
Mistroke
.17566 .01472 L
.17689 .01472 L
.17758 .01472 L
.17823 .01472 L
.1794 .01472 L
.18065 .01472 L
.18185 .01472 L
.18316 .01472 L
.18441 .01472 L
.18556 .01472 L
.1867 .01472 L
.18773 .01472 L
.18893 .01472 L
.19005 .01472 L
.19128 .01472 L
.19258 .01472 L
.19369 .01472 L
.19491 .01472 L
.19623 .01473 L
.19696 .01473 L
.19763 .01473 L
.19894 .01474 L
.20017 .01476 L
.20122 .01477 L
.20238 .0148 L
.20359 .01483 L
.20472 .01488 L
.20578 .01494 L
.20675 .01501 L
.20781 .01511 L
.20894 .01525 L
.21008 .01544 L
.21129 .01572 L
.21244 .01606 L
.21349 .01646 L
.21472 .01708 L
.21605 .01796 L
.21731 .01906 L
.21847 .02035 L
.21972 .02213 L
.22091 .02425 L
.22314 .0297 L
.22439 .0338 L
.22554 .03841 L
.22816 .05242 L
.23046 .06978 L
.23255 .09046 L
.23496 .12108 L
.23722 .15708 L
.24726 .38798 L
Mistroke
.24991 .45508 L
.25275 .51917 L
.25412 .54534 L
.25542 .56624 L
.25659 .58136 L
.25786 .59351 L
.25901 .6004 L
.26028 .60331 L
.26092 .60288 L
.2616 .601 L
.26285 .59393 L
.26402 .58307 L
.26525 .56751 L
.26745 .53032 L
.27248 .41421 L
.27797 .27412 L
.2826 .17384 L
.28515 .13063 L
.28755 .09802 L
.28979 .07426 L
.29222 .05488 L
.29442 .04205 L
.29645 .03345 L
.29771 .02939 L
.2989 .02626 L
.30114 .02193 L
.30239 .0202 L
.30354 .01894 L
.30481 .01786 L
.30617 .01699 L
.30723 .01647 L
.30839 .01603 L
.30948 .01571 L
.31048 .01548 L
.31159 .01528 L
.3128 .01512 L
.31406 .015 L
.31524 .01492 L
.31653 .01485 L
.31726 .01483 L
.31793 .01481 L
.31916 .01478 L
.32047 .01476 L
.32164 .01474 L
.32273 .01473 L
.32393 .01473 L
.32522 .01472 L
.32593 .01472 L
.32659 .01472 L
.32731 .01472 L
Mistroke
.32808 .01472 L
.32881 .01472 L
.3295 .01472 L
.3308 .01472 L
.33207 .01472 L
.33325 .01472 L
.33453 .01472 L
.33518 .01472 L
.33589 .01472 L
.3372 .01472 L
.33841 .01472 L
.33904 .01472 L
.33973 .01472 L
.34046 .01472 L
.34114 .01472 L
.34238 .01472 L
.34353 .01472 L
.34478 .01472 L
.3461 .01472 L
.34722 .01472 L
.34841 .01472 L
.34953 .01472 L
.35055 .01472 L
.35175 .01472 L
.35305 .01472 L
.35428 .01472 L
.35541 .01472 L
.35662 .01472 L
.35791 .01472 L
.35913 .01472 L
.36025 .01472 L
.36156 .01472 L
.36229 .01472 L
.36298 .01472 L
.36423 .01472 L
.36494 .01472 L
.36557 .01472 L
.36625 .01472 L
.36696 .01472 L
.36824 .01472 L
.36895 .01472 L
.36961 .01472 L
.37034 .01472 L
.37111 .01472 L
.37179 .01472 L
.37252 .01472 L
.37321 .01472 L
.37384 .01472 L
.37505 .01472 L
.37633 .01472 L
Mistroke
.37753 .01472 L
.37884 .01472 L
.38008 .01472 L
.38123 .01472 L
.38237 .01472 L
.38341 .01472 L
.3846 .01472 L
.38573 .01472 L
.38696 .01472 L
.38826 .01472 L
.38937 .01472 L
.39058 .01472 L
.3919 .01472 L
.39263 .01472 L
.3933 .01472 L
.39461 .01472 L
.39584 .01472 L
.39689 .01472 L
.39805 .01472 L
.39926 .01472 L
.40039 .01472 L
.40145 .01472 L
.40242 .01472 L
.40348 .01472 L
.4046 .01472 L
.40574 .01472 L
.40696 .01472 L
.40811 .01472 L
.40915 .01472 L
.41038 .01472 L
.41108 .01472 L
.41172 .01472 L
.41289 .01472 L
.41414 .01472 L
.41534 .01472 L
.41666 .01472 L
.41791 .01472 L
.41906 .01472 L
.4202 .01472 L
.42124 .01472 L
.42244 .01472 L
.42356 .01472 L
.4248 .01472 L
.4261 .01472 L
.42721 .01472 L
.42843 .01472 L
.42974 .01472 L
.43048 .01472 L
.43115 .01472 L
.43246 .01473 L
Mistroke
.43369 .01473 L
.43474 .01474 L
.4359 .01474 L
.43711 .01476 L
.43825 .01477 L
.43931 .0148 L
.44028 .01482 L
.44134 .01486 L
.44246 .01491 L
.44361 .01499 L
.44483 .01509 L
.44598 .01523 L
.44702 .01538 L
.44825 .01562 L
.44958 .01598 L
.45084 .01642 L
.452 .01695 L
.45326 .01768 L
.45445 .01858 L
.45668 .02093 L
.45793 .02275 L
.45909 .02483 L
.46044 .02784 L
.46171 .03135 L
.46402 .03981 L
.4661 .05033 L
.46835 .06544 L
.47078 .08702 L
.47328 .11584 L
.47602 .15581 L
.48155 .26225 L
.48629 .37151 L
.49143 .48442 L
.49276 .5087 L
.49417 .53101 L
.49547 .54803 L
.4967 .56042 L
.49784 .56864 L
.49907 .57372 L
.49976 .57481 L
.50043 .57464 L
.50168 .57113 L
.50279 .56449 L
.50399 .55393 L
.50511 .54085 L
.50613 .52657 L
.511 .43382 L
.5163 .31091 L
.5219 .19201 L
.52668 .11626 L
Mistroke
.5294 .0852 L
.53193 .06326 L
.53443 .04735 L
.53679 .03651 L
.53891 .02955 L
.54011 .02653 L
.54122 .02423 L
.54352 .02069 L
.54482 .01924 L
.54605 .01818 L
.54734 .01731 L
.54852 .01669 L
.54981 .01617 L
.55118 .01576 L
.55248 .01547 L
.55367 .01528 L
.55504 .01511 L
.55633 .01499 L
.55752 .01492 L
.55863 .01486 L
.55984 .01482 L
.56112 .01479 L
.56241 .01476 L
.56313 .01475 L
.56379 .01475 L
.56508 .01474 L
.5663 .01473 L
.56698 .01473 L
.56771 .01472 L
.56902 .01472 L
.56983 .01472 L
.57058 .01472 L
.57132 .01472 L
.572 .01472 L
.57316 .01472 L
.57441 .01472 L
.57557 .01472 L
.57666 .01472 L
.57794 .01472 L
.57912 .01472 L
.58041 .01472 L
.58106 .01472 L
.58178 .01472 L
.58244 .01472 L
.58312 .01472 L
.58435 .01472 L
.58567 .01472 L
.58642 .01472 L
.58711 .01472 L
.58838 .01472 L
Mistroke
.58953 .01472 L
.59017 .01472 L
.59086 .01472 L
.59211 .01472 L
.59326 .01472 L
.59434 .01472 L
.59552 .01472 L
.59679 .01472 L
.59742 .01472 L
.59811 .01472 L
.59937 .01472 L
.6006 .01472 L
.60173 .01472 L
.60278 .01472 L
.60377 .01472 L
.60486 .01472 L
.60603 .01472 L
.60719 .01472 L
.60841 .01472 L
.60945 .01472 L
.61059 .01472 L
.61191 .01472 L
.61312 .01472 L
.61376 .01472 L
.61446 .01472 L
.61518 .01472 L
.61587 .01472 L
.61712 .01472 L
.61827 .01472 L
.6189 .01472 L
.61959 .01472 L
.62085 .01472 L
.62208 .01472 L
.62319 .01472 L
.62448 .01472 L
.62569 .01472 L
.62681 .01472 L
.62785 .01472 L
.62898 .01472 L
.63018 .01472 L
.63148 .01472 L
.63267 .01472 L
.63333 .01472 L
.63404 .01472 L
.63534 .01472 L
.63656 .01472 L
.63785 .01472 L
.63895 .01472 L
.64016 .01472 L
.64085 .01472 L
Mistroke
.64158 .01472 L
.64288 .01472 L
.64361 .01472 L
.64428 .01472 L
.64502 .01472 L
.64581 .01472 L
.6465 .01472 L
.64724 .01472 L
.64795 .01472 L
.64859 .01472 L
.64982 .01472 L
.65112 .01472 L
.65233 .01472 L
.65365 .01472 L
.6549 .01472 L
.65605 .01472 L
.6572 .01472 L
.65824 .01472 L
.65944 .01472 L
.66056 .01472 L
.6618 .01472 L
.6631 .01472 L
.66422 .01472 L
.66544 .01472 L
.66675 .01472 L
.66749 .01472 L
.66816 .01472 L
.66947 .01472 L
.6707 .01472 L
.67176 .01472 L
.67292 .01472 L
.67413 .01472 L
.67527 .01473 L
.67633 .01473 L
.6773 .01474 L
.67842 .01474 L
.67948 .01476 L
.68063 .01477 L
.68185 .0148 L
.683 .01484 L
.68404 .01488 L
.68527 .01495 L
.68661 .01506 L
.68786 .0152 L
.68902 .01538 L
.69028 .01564 L
.69148 .01598 L
.69255 .01637 L
.69371 .01693 L
.69498 .01771 L
Mistroke
.69633 .01882 L
.69748 .02004 L
.69875 .02176 L
.701 .02604 L
.70227 .02933 L
.70343 .03304 L
.70558 .04203 L
.70783 .05521 L
.7103 .07511 L
.71294 .10406 L
.71543 .1397 L
.7177 .17952 L
.72294 .29642 L
.72849 .43875 L
.73078 .4933 L
.73324 .54318 L
.73465 .56606 L
.73594 .58258 L
.73723 .59452 L
.73846 .60125 L
.73957 .60332 L
.74075 .60134 L
.74186 .59556 L
.74286 .58713 L
.74405 .57347 L
.74534 .55451 L
.74766 .51063 L
.75758 .26528 L
.7603 .20449 L
.76321 .14966 L
.76593 .10884 L
.76846 .07986 L
.77103 .05795 L
.77238 .04906 L
.77382 .04133 L
.77624 .03164 L
.77761 .02761 L
.7789 .02463 L
.78007 .02247 L
.7813 .02065 L
.78235 .0194 L
.78349 .01833 L
.78471 .01743 L
.78584 .01678 L
.78719 .01619 L
.78842 .01579 L
.78974 .01548 L
.79113 .01524 L
.79232 .01509 L
.79363 .01498 L
Mistroke
.79436 .01493 L
.79503 .01489 L
.79575 .01486 L
.79654 .01483 L
.79727 .0148 L
.79794 .01479 L
.79858 .01477 L
.79927 .01476 L
.80048 .01475 L
.80162 .01474 L
.80228 .01473 L
.80298 .01473 L
.80422 .01472 L
.80553 .01472 L
.80674 .01472 L
.80744 .01472 L
.80807 .01472 L
.80876 .01472 L
.80949 .01472 L
.81068 .01472 L
.81179 .01472 L
.81247 .01472 L
.81312 .01472 L
.81433 .01472 L
.8156 .01472 L
.81678 .01472 L
.81807 .01472 L
.8188 .01472 L
.81945 .01472 L
.82064 .01472 L
.82173 .01472 L
.82292 .01472 L
.82418 .01472 L
.82528 .01472 L
.82631 .01472 L
.82744 .01472 L
.82864 .01472 L
.82932 .01472 L
.83003 .01472 L
.83132 .01472 L
.83203 .01472 L
.8327 .01472 L
.83343 .01472 L
.83423 .01472 L
.83487 .01472 L
.83557 .01472 L
.8363 .01472 L
.83699 .01472 L
.83821 .01472 L
.83952 .01472 L
Mistroke
.8408 .01472 L
.84152 .01472 L
.84219 .01472 L
.84341 .01472 L
.84471 .01472 L
.84587 .01472 L
.84696 .01472 L
.84815 .01472 L
.84943 .01472 L
.85012 .01472 L
.85076 .01472 L
.85197 .01472 L
.85328 .01472 L
.85401 .01472 L
.85469 .01472 L
.85582 .01472 L
.85706 .01472 L
.85835 .01472 L
.85956 .01472 L
.86025 .01472 L
.86099 .01472 L
.8617 .01472 L
.86235 .01472 L
.86359 .01472 L
.86489 .01472 L
.86557 .01472 L
.8663 .01472 L
.86761 .01472 L
.86837 .01472 L
.86917 .01472 L
.86986 .01472 L
.8706 .01472 L
.87126 .01472 L
.87196 .01472 L
.87325 .01472 L
.8745 .01472 L
.87565 .01472 L
.87689 .01472 L
.8776 .01472 L
.87826 .01472 L
.87896 .01472 L
.87959 .01472 L
.88033 .01472 L
.88102 .01472 L
.88219 .01472 L
.88343 .01472 L
.88449 .01472 L
.88566 .01472 L
.88691 .01472 L
.88762 .01472 L
Mistroke
.88826 .01472 L
.88945 .01472 L
.89071 .01472 L
.89194 .01472 L
.89263 .01472 L
.89327 .01472 L
.89445 .01472 L
.8957 .01472 L
.89681 .01472 L
.89786 .01472 L
.899 .01472 L
.90024 .01472 L
.90154 .01472 L
.90228 .01472 L
.90297 .01472 L
.90422 .01472 L
.90492 .01472 L
.90556 .01472 L
.90676 .01472 L
.90807 .01472 L
.9093 .01472 L
.91043 .01472 L
.91149 .01472 L
.91263 .01472 L
.9137 .01472 L
.91468 .01472 L
.91583 .01472 L
.91708 .01472 L
.91826 .01472 L
.91936 .01472 L
.92048 .01472 L
.92153 .01472 L
.92269 .01472 L
.92393 .01472 L
.92516 .01472 L
.92646 .01472 L
.92757 .01472 L
.92879 .01472 L
.93011 .01472 L
.93133 .01472 L
.93196 .01472 L
.93266 .01472 L
.93339 .01472 L
.93408 .01472 L
.93534 .01472 L
.93649 .01472 L
.93712 .01472 L
.93781 .01472 L
.93907 .01472 L
.94031 .01472 L
Mistroke
.94142 .01472 L
.94271 .01472 L
.94392 .01472 L
.94505 .01472 L
.94608 .01472 L
.94722 .01472 L
.94841 .01472 L
.94972 .01472 L
.95091 .01472 L
.95157 .01472 L
.95229 .01472 L
.95359 .01472 L
.95481 .01472 L
.9561 .01472 L
.9572 .01472 L
.95841 .01472 L
.95914 .01472 L
.95984 .01472 L
.96114 .01472 L
.96186 .01472 L
.96254 .01472 L
.96328 .01472 L
.96407 .01472 L
.96476 .01472 L
.9655 .01472 L
.9662 .01472 L
.96685 .01472 L
.96807 .01472 L
.96937 .01472 L
.97026 .01472 L
.97107 .01472 L
.97201 .01472 L
.9729 .01472 L
.97372 .01472 L
.97447 .01472 L
.97531 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[66]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`003_ooool3o`0003Wooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0001aoooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000>?ooool3o`0000kooooo000?ooooo`03
o`000?oooooooooo03Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000006oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000003Sooooo
00?o0000ooooooooool03Oooool000Oooooo1Ol00003ooooo`03o`000?oooooooooo033ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0KOooool01?l0003ooooo
ooooool0000;ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool000oooooo
00?o0000ooooooooool0=oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo06go
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00gooooo000?ooooo`03o`000?oooooooooo03Oooooo00Co0000oooooooooooo00001oooool4o`00
073ooooo00Co0000oooooooooooo00001oooool4o`0003Wooooo00?o0000ooooooooool03Oooool0
00kooooo0_l0000iooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0LOooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo03Wooooo0_l0000?ooooo`003oooool0
0ol0003oooooooooo`0hooooo`;o00002?ooool5o`00073ooooo0_l00008ooooo`Go0000>?ooool0
0ol0003oooooooooo`0=ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003o
ooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003ooooooooo
o`2>ooooo`001oooooooo`0001;o00002?ooool000gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool2o`00
00_ooooo00?o0000ooooooooool02?ooool3o`0000cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`;o00003?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo0ol0000:ooooo`03o`000?oooooooooo
00Wooooo0_l0000<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo03;o
oooo0_l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09oooool2o`0000[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool2o`0003Cooooo00?o0000ooooooooool03?ooool004?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0@_ooool004Cooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0@_ooool004Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0@oooool004Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@oooool004Cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`13ooooo`00
A?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`13ooooo`00AOooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`14ooooo`00AOooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`14ooooo`00AOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`14ooooo`00AOooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`14ooooo`00AOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`14ooooo`00AOooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01_ooool2o`0000Oooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo0015
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo04Cooooo0015ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Gooooo0015ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo04Gooooo0015ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Gooooo0016ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo04Gooooo0016ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Gooooo0016ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0AOooool004Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0AOooool004Kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0AOooool004Kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0AOooool004Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0AOooool004Oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0AOooool004Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0AOooool004Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`15ooooo`00Aooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`15ooooo`00Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`15ooooo`00Aoooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`15ooooo`00Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033o
oooo0ol00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo04Kooooo0017ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Kooooo
0017ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo04Kooooo0017ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`04ooooo`?o00001?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0A_ooool004Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0A_ooool004Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`;o
00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`16ooooo`00Aoooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`16ooooo`00Aooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`16ooooo`00Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`16ooooo`00Aoooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`16ooooo`00Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo04Kooooo0017ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Kooooo
0017ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo04Kooooo0017ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Oooooo0017oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04Oooooo0017ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Oooooo0017ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo04Oooooo0017ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0Aoooool004Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Aoooool0
04Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Aoooool004Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Aoooool004Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0Aoooool004Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool004Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0Aoooool004Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`17ooooo`00B?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`17ooooo`00
B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`17ooooo`00B?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`17ooooo`00B?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`17ooooo`00B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`18ooooo`00B?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`18ooooo`00B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04Sooooo0018ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo0018
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04Sooooo0018ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo0018ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool5o`0000Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0B?ooool004Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0booooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0B?ooool004Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
B?ooool004Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0dooooo`;o00001?oo
ool3o`0000;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04Sooooo0019ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<Oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`18ooooo`00BOooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03;ooooo1?l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo0019ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000>?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo0019oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool00000>?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04Sooooo0019ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo04Sooooo0019ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool004Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0B?ooool004Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000hoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool004Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0B?ooool004Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`04
o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0fooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0fooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool004Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0BOooool004Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0BOooool004Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0fooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool004Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0fooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool004Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`04o`000?oooooooooooooo
o`;o00000_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0BOooool004[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0gooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0BOooool004[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0gooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool004[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0gooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool004[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0gooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0BOooool004[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0gooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0BOooool004[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0gooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0BOooool004[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0gooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0BOooool004[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0gooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0BOooool004[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0gooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0BOooool004[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0gooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0BOooool004[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0cooooo`?o000000?oooooo`000?ooool00_ooool01?l0003o
ooooooooool0000jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0BOooool004[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`04o`000?oooooooooooooo
o`;o00000oooool01?l0003oooooooooool0000jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0BOooool004[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0foooo
o`;o00000oooool4o`0003[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`19oooo
o`00B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo
0000ooooo`02ooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`19ooooo`00B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooool000000_ooool01?l0003oooooooooool0000jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0BOooool004[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0booooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`04o`000?oooooo
ooooo`0003[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`00B_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo0ol00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo04Wooooo001:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`19ooooo`00B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0BOooool004[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool0>Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Wooooo001;ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`00Boooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0BOooool0
04_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0hooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo04Wooooo001;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>?ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`19ooooo`00Boooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0BOooool004_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0hooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Wooooo001;ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo
03Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`00Boooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B_ooool004_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04[ooooo001;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1:ooooo`00Boooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0B_ooool004_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04[ooooo001;ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0>Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1:ooooo`00Boooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo03Wooooo00Ko0000ooooool0003o0000ooooool0000kooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0B_ooool004_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04[ooooo001;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1:ooooo`00Boooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03[ooooo00Go0000ooooool0003oooooo`00000loooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0B_ooool004_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0jooooo`05o`000?oooooo0000ooooool00000??ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo04[ooooo001<ooooo`05o`000?oooooooooooooo
ool00000??ooool01Ol0003oooooo`000?oooooo000003cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1:ooooo`00C?ooool01Ol0003ooooooooooooooooo000003cooooo00Go0000
ooooool0003oooooo`00000looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0B_oo
ool004cooooo00Go0000ooooooooooooooooo`00000looooo`03o`000?oooooo000000;o0000??oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04[ooooo001<ooooo`05o`000?oooooo
ooooooooool00000??ooool01Ol0003oooooo`000?oooooo000003cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1:ooooo`00C?ooool01Ol0003ooooooooooooooooo000003cooooo
00Go0000ooooool0003oooooo`00000looooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0B_ooool004cooooo00Go0000ooooooooooooooooo`00000looooo`05o`000?oooooo0000oooo
ool00000??ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04[ooooo001<ooooo`05
o`000?ooooooooooooooool00000??ooool01Ol0003oooooo`000?oooooo000003cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1:ooooo`00C?ooool01Ol0003ooooooooooooooooo
000003Oooooo0ol00002ooooo`05o`000?oooooo0000ooooool00000??ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04[ooooo001<ooooo`05o`000?ooooooooooooooool00000>?oo
ool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`00000mooooo`05o`000?oooooooooo
ooooool00000C?ooool004cooooo00Go0000ooooooooooooooooo`00000eooooo`Go00000_ooool0
0ol0003oooooo`000002o`0003gooooo00Go0000ooooooooooooooooo`00001<ooooo`00C?ooool0
1Ol0003ooooooooooooooooo000003Gooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
o`000?oooooo000003gooooo00Go0000ooooooooooooooooo`00001<ooooo`00C?ooool01Ol0003o
oooooooooooooooo000003Kooooo00?o0000ooooool000000oooool01Ol0003oooooo`000?oooooo
000003gooooo00Go0000ooooooooooooooooo`00001<ooooo`00C?ooool01Ol0003ooooooooooooo
oooo000003Oooooo0_l00003ooooo`04o`000?oooooo0000o`0003kooooo00Co0000oooooooooooo
0000COooool004cooooo00Go0000ooooooooooooooooo`00000hooooo`06o`000?oooooooooooooo
ool0003ooooo0_l0000nooooo`04o`000?ooooooooooo`0004gooooo001<ooooo`05o`000?oooooo
ooooooooool00000?Oooool3o`0003kooooo00Co0000oooooooooooo0000COooool004cooooo00Go
0000ooooooooooooooooo`00000mooooo`?o0000?_ooool01?l0003oooooooooool0001=ooooo`00
C?ooool01Ol0003ooooooooooooooooo000003gooooo0ol0000nooooo`04o`000?ooooooooooo`00
04gooooo001<ooooo`04o`000?ooooooooooo`0003kooooo0ol0000nooooo`04o`000?oooooooooo
o`0004gooooo001<ooooo`04o`000?ooooooooooo`0003kooooo0ol0000nooooo`04o`000?oooooo
ooooo`0004gooooo001<ooooo`04o`000?ooooooooooo`0003kooooo0ol0000nooooo`04o`000?oo
ooooooooo`0004gooooo001<ooooo`04o`000?ooooooooooo`0003kooooo0ol0000nooooo`04o`00
0?ooooooooooo`0004gooooo001<ooooo`04o`000?ooooooooooo`0003kooooo0ol0000nooooo`04
o`000?ooooooooooo`0004gooooo001<ooooo`04o`000?ooooooooooo`0003oooooo00?o0000oooo
ooooool0?Oooool01?l0003oooooooooool0001=ooooo`00COooool00ol0003oooooo`00000ooooo
o`;o0000?_ooool01?l0003oooooooooool0001=ooooo`00COooool00ol0003oooooo`00000ooooo
o`03o`000?oooooooooo03gooooo00Co0000oooooooooooo0000COooool004gooooo00?o0000oooo
ool00000?oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000004kooooo001=ooooo`03
o`000?oooooo000003oooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`00001>ooooo`00
COooool2o`00043ooooo00?o0000ooooooooool0?_ooool2o`0004kooooo001=ooooo`;o0000@?oo
ool00ol0003oooooooooo`0nooooo`;o0000C_ooool004gooooo0_l00010ooooo`03o`000?oooooo
oooo03kooooo0_l0001>ooooo`00COooool2o`00043ooooo0_l0000oooooo`;o0000C_ooool008oo
oooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o
0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.10503, -0.356233, \
0.00770056, 0.0287092}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot3D[intensity[x,y],{x,-2,2},{y,-.1,.1},PlotRange->All,PlotPoints->100];\
\>", "Input",
  CellLabel->"In[67]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37803e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -11.7989 -9 ]
[.17646 .18758 .20112 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -5.27396 -9 ]
[.50253 .05935 .72604 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 24 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 30 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 24 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01371 .3303 -12 -2.79746 ]
[.01371 .3303 0 6.20254 ]
[.00286 .39831 -12 -2.85523 ]
[.00286 .39831 0 6.14477 ]
[-0.00847 .46933 -12 -2.91582 ]
[-0.00847 .46933 0 6.08418 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-2)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-0.1)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-0.05)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.05)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02599 .32565 m
.03212 .32333 L
s
[(20)] .01371 .3303 1 -0.37834 Mshowa
.01519 .3938 m
.02135 .39155 L
s
[(40)] .00286 .39831 1 -0.36551 Mshowa
.00391 .46497 m
.0101 .46279 L
s
[(60)] -0.00847 .46933 1 -0.35204 Mshowa
.125 Mabswid
.03379 .27641 m
.03746 .27499 L
s
.03122 .29265 m
.03489 .29124 L
s
.02861 .30907 m
.03229 .30766 L
s
.02333 .34242 m
.02701 .34104 L
s
.02064 .35936 m
.02433 .35799 L
s
.01793 .37649 m
.02162 .37513 L
s
.01241 .4113 m
.01611 .40996 L
s
.00961 .429 m
.01331 .42767 L
s
.00677 .44688 m
.01048 .44557 L
s
.00101 .48325 m
.00473 .48196 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.639 .717 .904 r
.40123 .62356 .40432 .62671 .40952 .62517 .40643 .62235 Metetra
.662 .745 .912 r
.40643 .62235 .40952 .62517 .41474 .6233 .41165 .62081 Metetra
.685 .774 .919 r
.41165 .62081 .41474 .6233 .41999 .6211 .41689 .61892 Metetra
.707 .801 .923 r
.41689 .61892 .41999 .6211 .42525 .61861 .42214 .61671 Metetra
.726 .824 .926 r
.42214 .61671 .42525 .61861 .43052 .61587 .42742 .6142 Metetra
.743 .844 .927 r
.42742 .6142 .43052 .61587 .4358 .61292 .43271 .61144 Metetra
.755 .86 .927 r
.43271 .61144 .4358 .61292 .4411 .60982 .43801 .60847 Metetra
.764 .871 .926 r
.43801 .60847 .4411 .60982 .4464 .60661 .44332 .60535 Metetra
.77 .878 .925 r
.44332 .60535 .4464 .60661 .45171 .60335 .44864 .60213 Metetra
.773 .882 .925 r
.44864 .60213 .45171 .60335 .45702 .60008 .45396 .59886 Metetra
.773 .882 .925 r
.45396 .59886 .45702 .60008 .46234 .59687 .45929 .59558 Metetra
.77 .878 .925 r
.45929 .59558 .46234 .59687 .46766 .59374 .46463 .59236 Metetra
.765 .871 .926 r
.46463 .59236 .46766 .59374 .47299 .59072 .46997 .58921 Metetra
.758 .862 .926 r
.46997 .58921 .47299 .59072 .47832 .58784 .47531 .58619 Metetra
.749 .85 .926 r
.47531 .58619 .47832 .58784 .48365 .58511 .48065 .58329 Metetra
.739 .838 .925 r
.48065 .58329 .48365 .58511 .48899 .58253 .486 .58055 Metetra
.729 .825 .924 r
.486 .58055 .48899 .58253 .49434 .58009 .49136 .57796 Metetra
.719 .812 .923 r
.49136 .57796 .49434 .58009 .49969 .57779 .49672 .57552 Metetra
.71 .801 .921 r
.49672 .57552 .49969 .57779 .50505 .57562 .50209 .57321 Metetra
.702 .79 .919 r
.50209 .57321 .50505 .57562 .51042 .57355 .50747 .57102 Metetra
.694 .781 .918 r
.50747 .57102 .51042 .57355 .51579 .57157 .51285 .56895 Metetra
.688 .772 .916 r
.51285 .56895 .51579 .57157 .52118 .56967 .51824 .56696 Metetra
.682 .765 .914 r
.51824 .56696 .52118 .56967 .52657 .56784 .52365 .56506 Metetra
.678 .76 .913 r
.52365 .56506 .52657 .56784 .53198 .56605 .52906 .56321 Metetra
.674 .755 .912 r
.52906 .56321 .53198 .56605 .5374 .56431 .53448 .56142 Metetra
.671 .751 .911 r
.53448 .56142 .5374 .56431 .54282 .5626 .53992 .55967 Metetra
.669 .749 .91 r
.53992 .55967 .54282 .5626 .54826 .5609 .54536 .55794 Metetra
.668 .746 .909 r
.54536 .55794 .54826 .5609 .55371 .55923 .55082 .55624 Metetra
.666 .745 .909 r
.55082 .55624 .55371 .55923 .55916 .55756 .55628 .55456 Metetra
.665 .744 .909 r
.55628 .55456 .55916 .55756 .56463 .5559 .56176 .55288 Metetra
.665 .743 .908 r
.56176 .55288 .56463 .5559 .57011 .55424 .56724 .55121 Metetra
.664 .742 .908 r
.56724 .55121 .57011 .55424 .5756 .55258 .57274 .54954 Metetra
.664 .742 .908 r
.57274 .54954 .5756 .55258 .58111 .55093 .57825 .54788 Metetra
.664 .742 .908 r
.57825 .54788 .58111 .55093 .58662 .54927 .58377 .54621 Metetra
.664 .742 .908 r
.58377 .54621 .58662 .54927 .59214 .54761 .5893 .54454 Metetra
.664 .741 .908 r
.5893 .54454 .59214 .54761 .59768 .54595 .59484 .54288 Metetra
.664 .741 .908 r
.59484 .54288 .59768 .54595 .60322 .54428 .6004 .5412 Metetra
.664 .741 .908 r
.6004 .5412 .60322 .54428 .60878 .54262 .60596 .53953 Metetra
.664 .741 .908 r
.60596 .53953 .60878 .54262 .61435 .54095 .61154 .53785 Metetra
.664 .741 .908 r
.61154 .53785 .61435 .54095 .61993 .53927 .61712 .53617 Metetra
.664 .741 .908 r
.61712 .53617 .61993 .53927 .62552 .53759 .62272 .53449 Metetra
.664 .741 .908 r
.62272 .53449 .62552 .53759 .63112 .53591 .62833 .5328 Metetra
.664 .741 .908 r
.62833 .5328 .63112 .53591 .63673 .53423 .63395 .53111 Metetra
.664 .741 .908 r
.63395 .53111 .63673 .53423 .64235 .53254 .63958 .52942 Metetra
.664 .741 .908 r
.63958 .52942 .64235 .53254 .64799 .53085 .64522 .52772 Metetra
.664 .741 .908 r
.64522 .52772 .64799 .53085 .65364 .52916 .65088 .52602 Metetra
.664 .741 .908 r
.65088 .52602 .65364 .52916 .65929 .52746 .65654 .52432 Metetra
.664 .741 .908 r
.65654 .52432 .65929 .52746 .66496 .52576 .66222 .52261 Metetra
.664 .741 .908 r
.66222 .52261 .66496 .52576 .67064 .52406 .66791 .5209 Metetra
.664 .741 .908 r
.66791 .5209 .67064 .52406 .67633 .52235 .67361 .51919 Metetra
.664 .741 .908 r
.67361 .51919 .67633 .52235 .68204 .52064 .67932 .51747 Metetra
.664 .741 .908 r
.67932 .51747 .68204 .52064 .68775 .51892 .68504 .51575 Metetra
.664 .741 .908 r
.68504 .51575 .68775 .51892 .69348 .51721 .69078 .51403 Metetra
.664 .741 .908 r
.69078 .51403 .69348 .51721 .69922 .51548 .69652 .5123 Metetra
.664 .741 .908 r
.69652 .5123 .69922 .51548 .70497 .51376 .70228 .51057 Metetra
.664 .741 .908 r
.70228 .51057 .70497 .51376 .71073 .51203 .70805 .50883 Metetra
.664 .741 .908 r
.70805 .50883 .71073 .51203 .7165 .5103 .71383 .50709 Metetra
.664 .741 .908 r
.71383 .50709 .7165 .5103 .72229 .50856 .71962 .50535 Metetra
.664 .741 .908 r
.71962 .50535 .72229 .50856 .72808 .50683 .72543 .50361 Metetra
.664 .741 .908 r
.72543 .50361 .72808 .50683 .73389 .50508 .73125 .50186 Metetra
.664 .741 .908 r
.73125 .50186 .73389 .50508 .73971 .50334 .73707 .5001 Metetra
.663 .741 .908 r
.73707 .5001 .73971 .50334 .74554 .50159 .74292 .49835 Metetra
.663 .741 .908 r
.74292 .49835 .74554 .50159 .75139 .49984 .74877 .49659 Metetra
.663 .741 .908 r
.74877 .49659 .75139 .49984 .75724 .49808 .75463 .49483 Metetra
.663 .741 .908 r
.75463 .49483 .75724 .49808 .76311 .49632 .76051 .49307 Metetra
.663 .741 .908 r
.76051 .49307 .76311 .49632 .76899 .49456 .7664 .4913 Metetra
.663 .741 .908 r
.7664 .4913 .76899 .49456 .77489 .4928 .7723 .48954 Metetra
.662 .742 .909 r
.7723 .48954 .77489 .4928 .78079 .49104 .77821 .48778 Metetra
.662 .742 .909 r
.77821 .48778 .78079 .49104 .78671 .48928 .78414 .48602 Metetra
.661 .742 .91 r
.78414 .48602 .78671 .48928 .79264 .48753 .79008 .48427 Metetra
.66 .742 .911 r
.79008 .48427 .79264 .48753 .79858 .48578 .79603 .48253 Metetra
.659 .743 .912 r
.79603 .48253 .79858 .48578 .80454 .48405 .802 .48081 Metetra
.657 .743 .914 r
.802 .48081 .80454 .48405 .81051 .48233 .80799 .47912 Metetra
.654 .744 .916 r
.80799 .47912 .81051 .48233 .8165 .48064 .81398 .47745 Metetra
.651 .745 .919 r
.81398 .47745 .8165 .48064 .8225 .47898 .82 .47583 Metetra
.647 .747 .922 r
.82 .47583 .8225 .47898 .82852 .47736 .82603 .47426 Metetra
.641 .748 .927 r
.82603 .47426 .82852 .47736 .83456 .4758 .83209 .47276 Metetra
.634 .75 .932 r
.83209 .47276 .83456 .4758 .84062 .4743 .83816 .47134 Metetra
.626 .753 .938 r
.83816 .47134 .84062 .4743 .8467 .47289 .84426 .47001 Metetra
.615 .755 .945 r
.84426 .47001 .8467 .47289 .85281 .47157 .85039 .46879 Metetra
.601 .758 .954 r
.85039 .46879 .85281 .47157 .85894 .47035 .85654 .4677 Metetra
.585 .761 .962 r
.85654 .4677 .85894 .47035 .86509 .46926 .86272 .46673 Metetra
.566 .764 .971 r
.86272 .46673 .86509 .46926 .87128 .4683 .86894 .46591 Metetra
.545 .766 .98 r
.86894 .46591 .87128 .4683 .8775 .46748 .87518 .46521 Metetra
.521 .767 .986 r
.87518 .46521 .8775 .46748 .88375 .46679 .88146 .46465 Metetra
.498 .767 .991 r
.88146 .46465 .88375 .46679 .89004 .46623 .88776 .4642 Metetra
.475 .766 .995 r
.88776 .4642 .89004 .46623 .89635 .46578 .8941 .46384 Metetra
.456 .765 .996 r
.8941 .46384 .89635 .46578 .90269 .46542 .90046 .46355 Metetra
.443 .765 .996 r
.90046 .46355 .90269 .46542 .90906 .46513 .90685 .4633 Metetra
.439 .766 .997 r
.90685 .4633 .90906 .46513 .91546 .46488 .91326 .46304 Metetra
.445 .77 .997 r
.91326 .46304 .91546 .46488 .92187 .46461 .91968 .46274 Metetra
.462 .775 .997 r
.91968 .46274 .92187 .46461 .9283 .4643 .92611 .46233 Metetra
.49 .782 .997 r
.92611 .46233 .9283 .4643 .93473 .46389 .93253 .46178 Metetra
.526 .787 .992 r
.93253 .46178 .93473 .46389 .94116 .46333 .93896 .46103 Metetra
.564 .788 .983 r
.93896 .46103 .94116 .46333 .94759 .46258 .94537 .46004 Metetra
.6 .785 .969 r
.94537 .46004 .94759 .46258 .95401 .46159 .95176 .45879 Metetra
.631 .777 .951 r
.95176 .45879 .95401 .46159 .96041 .46034 .95814 .45725 Metetra
.656 .767 .931 r
.95814 .45725 .96041 .46034 .96679 .4588 .96448 .45541 Metetra
.676 .755 .911 r
.96448 .45541 .96679 .4588 .97314 .45697 .97081 .4533 Metetra
.617 .69 .896 r
.39814 .62007 .40123 .62356 .40643 .62235 .40333 .61917 Metetra
.638 .716 .904 r
.40333 .61917 .40643 .62235 .41165 .62081 .40855 .61797 Metetra
.661 .745 .912 r
.40855 .61797 .41165 .62081 .41689 .61892 .41378 .61642 Metetra
.685 .774 .919 r
.41378 .61642 .41689 .61892 .42214 .61671 .41904 .61452 Metetra
.707 .801 .924 r
.41904 .61452 .42214 .61671 .42742 .6142 .42431 .6123 Metetra
.727 .826 .926 r
.42431 .6123 .42742 .6142 .43271 .61144 .42961 .60977 Metetra
.743 .845 .927 r
.42961 .60977 .43271 .61144 .43801 .60847 .43491 .60699 Metetra
.756 .861 .927 r
.43491 .60699 .43801 .60847 .44332 .60535 .44023 .604 Metetra
.765 .872 .926 r
.44023 .604 .44332 .60535 .44864 .60213 .44556 .60085 Metetra
.77 .878 .925 r
.44556 .60085 .44864 .60213 .45396 .59886 .45089 .59762 Metetra
.773 .882 .925 r
.45089 .59762 .45396 .59886 .45929 .59558 .45623 .59434 Metetra
.773 .881 .925 r
.45623 .59434 .45929 .59558 .46463 .59236 .46158 .59106 Metetra
.77 .878 .925 r
.46158 .59106 .46463 .59236 .46997 .58921 .46693 .58782 Metetra
.765 .872 .926 r
.46693 .58782 .46997 .58921 .47531 .58619 .47228 .58467 Metetra
.758 .862 .926 r
.47228 .58467 .47531 .58619 .48065 .58329 .47764 .58163 Metetra
.749 .851 .926 r
.47764 .58163 .48065 .58329 .486 .58055 .483 .57872 Metetra
.739 .838 .925 r
.483 .57872 .486 .58055 .49136 .57796 .48837 .57597 Metetra
.729 .825 .924 r
.48837 .57597 .49136 .57796 .49672 .57552 .49374 .57337 Metetra
.719 .812 .923 r
.49374 .57337 .49672 .57552 .50209 .57321 .49912 .57091 Metetra
.71 .8 .921 r
.49912 .57091 .50209 .57321 .50747 .57102 .5045 .5686 Metetra
.701 .79 .919 r
.5045 .5686 .50747 .57102 .51285 .56895 .5099 .56641 Metetra
.694 .78 .917 r
.5099 .56641 .51285 .56895 .51824 .56696 .5153 .56432 Metetra
.688 .772 .916 r
.5153 .56432 .51824 .56696 .52365 .56506 .52071 .56233 Metetra
.682 .765 .914 r
.52071 .56233 .52365 .56506 .52906 .56321 .52613 .56041 Metetra
.678 .76 .913 r
.52613 .56041 .52906 .56321 .53448 .56142 .53156 .55856 Metetra
.674 .755 .912 r
.53156 .55856 .53448 .56142 .53992 .55967 .537 .55676 Metetra
.671 .751 .911 r
.537 .55676 .53992 .55967 .54536 .55794 .54245 .555 Metetra
.669 .749 .91 r
.54245 .555 .54536 .55794 .55082 .55624 .54791 .55327 Metetra
.668 .746 .909 r
.54791 .55327 .55082 .55624 .55628 .55456 .55339 .55156 Metetra
.666 .745 .909 r
.55339 .55156 .55628 .55456 .56176 .55288 .55887 .54986 Metetra
.665 .744 .909 r
.55887 .54986 .56176 .55288 .56724 .55121 .56436 .54818 Metetra
.665 .743 .908 r
.56436 .54818 .56724 .55121 .57274 .54954 .56987 .5465 Metetra
.664 .742 .908 r
.56987 .5465 .57274 .54954 .57825 .54788 .57539 .54482 Metetra
.664 .742 .908 r
.57539 .54482 .57825 .54788 .58377 .54621 .58091 .54314 Metetra
.664 .742 .908 r
.58091 .54314 .58377 .54621 .5893 .54454 .58645 .54147 Metetra
.664 .742 .908 r
.58645 .54147 .5893 .54454 .59484 .54288 .592 .53979 Metetra
.664 .741 .908 r
.592 .53979 .59484 .54288 .6004 .5412 .59756 .53811 Metetra
.664 .741 .908 r
.59756 .53811 .6004 .5412 .60596 .53953 .60313 .53643 Metetra
.664 .741 .908 r
.60313 .53643 .60596 .53953 .61154 .53785 .60872 .53475 Metetra
.664 .741 .908 r
.60872 .53475 .61154 .53785 .61712 .53617 .61431 .53306 Metetra
.664 .741 .908 r
.61431 .53306 .61712 .53617 .62272 .53449 .61991 .53137 Metetra
.664 .741 .908 r
.61991 .53137 .62272 .53449 .62833 .5328 .62553 .52968 Metetra
.664 .741 .908 r
.62553 .52968 .62833 .5328 .63395 .53111 .63116 .52798 Metetra
.664 .741 .908 r
.63116 .52798 .63395 .53111 .63958 .52942 .6368 .52628 Metetra
.664 .741 .908 r
.6368 .52628 .63958 .52942 .64522 .52772 .64245 .52458 Metetra
.664 .741 .908 r
.64245 .52458 .64522 .52772 .65088 .52602 .64811 .52288 Metetra
.664 .741 .908 r
.64811 .52288 .65088 .52602 .65654 .52432 .65378 .52117 Metetra
.664 .741 .908 r
.65378 .52117 .65654 .52432 .66222 .52261 .65947 .51945 Metetra
.664 .741 .908 r
.65947 .51945 .66222 .52261 .66791 .5209 .66516 .51773 Metetra
.664 .741 .908 r
.66516 .51773 .66791 .5209 .67361 .51919 .67087 .51601 Metetra
.664 .741 .908 r
.67087 .51601 .67361 .51919 .67932 .51747 .67659 .51429 Metetra
.664 .741 .908 r
.67659 .51429 .67932 .51747 .68504 .51575 .68232 .51256 Metetra
.664 .741 .908 r
.68232 .51256 .68504 .51575 .69078 .51403 .68806 .51083 Metetra
.664 .741 .908 r
.68806 .51083 .69078 .51403 .69652 .5123 .69382 .5091 Metetra
.664 .741 .908 r
.69382 .5091 .69652 .5123 .70228 .51057 .69958 .50736 Metetra
.664 .741 .908 r
.69958 .50736 .70228 .51057 .70805 .50883 .70536 .50562 Metetra
.664 .741 .908 r
.70536 .50562 .70805 .50883 .71383 .50709 .71115 .50387 Metetra
.664 .741 .908 r
.71115 .50387 .71383 .50709 .71962 .50535 .71695 .50213 Metetra
.664 .741 .908 r
.71695 .50213 .71962 .50535 .72543 .50361 .72277 .50037 Metetra
.664 .741 .908 r
.72277 .50037 .72543 .50361 .73125 .50186 .72859 .49862 Metetra
.663 .741 .908 r
.72859 .49862 .73125 .50186 .73707 .5001 .73443 .49686 Metetra
.663 .741 .908 r
.73443 .49686 .73707 .5001 .74292 .49835 .74028 .4951 Metetra
.663 .741 .908 r
.74028 .4951 .74292 .49835 .74877 .49659 .74614 .49334 Metetra
.663 .741 .908 r
.74614 .49334 .74877 .49659 .75463 .49483 .75201 .49157 Metetra
.663 .741 .908 r
.75201 .49157 .75463 .49483 .76051 .49307 .7579 .4898 Metetra
.663 .741 .908 r
.7579 .4898 .76051 .49307 .7664 .4913 .76379 .48804 Metetra
.663 .742 .909 r
.76379 .48804 .7664 .4913 .7723 .48954 .7697 .48627 Metetra
.662 .742 .909 r
.7697 .48627 .7723 .48954 .77821 .48778 .77563 .48451 Metetra
.661 .742 .91 r
.77563 .48451 .77821 .48778 .78414 .48602 .78156 .48276 Metetra
.66 .742 .911 r
.78156 .48276 .78414 .48602 .79008 .48427 .78751 .48101 Metetra
.659 .743 .912 r
.78751 .48101 .79008 .48427 .79603 .48253 .79348 .47929 Metetra
.657 .743 .914 r
.79348 .47929 .79603 .48253 .802 .48081 .79946 .47759 Metetra
.654 .744 .916 r
.79946 .47759 .802 .48081 .80799 .47912 .80545 .47592 Metetra
.651 .745 .919 r
.80545 .47592 .80799 .47912 .81398 .47745 .81146 .47429 Metetra
.647 .747 .922 r
.81146 .47429 .81398 .47745 .82 .47583 .81749 .47272 Metetra
.642 .748 .926 r
.81749 .47272 .82 .47583 .82603 .47426 .82354 .47121 Metetra
.635 .75 .932 r
.82354 .47121 .82603 .47426 .83209 .47276 .82961 .46978 Metetra
.626 .753 .938 r
.82961 .46978 .83209 .47276 .83816 .47134 .83571 .46845 Metetra
.615 .755 .945 r
.83571 .46845 .83816 .47134 .84426 .47001 .84183 .46723 Metetra
.601 .758 .954 r
.84183 .46723 .84426 .47001 .85039 .46879 .84798 .46613 Metetra
.585 .761 .963 r
.84798 .46613 .85039 .46879 .85654 .4677 .85415 .46516 Metetra
.566 .764 .971 r
.85415 .46516 .85654 .4677 .86272 .46673 .86036 .46433 Metetra
.545 .766 .98 r
.86036 .46433 .86272 .46673 .86894 .46591 .8666 .46364 Metetra
.522 .767 .986 r
.8666 .46364 .86894 .46591 .87518 .46521 .87287 .46306 Metetra
.498 .767 .991 r
.87287 .46306 .87518 .46521 .88146 .46465 .87916 .46261 Metetra
.476 .766 .994 r
.87916 .46261 .88146 .46465 .88776 .4642 .88549 .46225 Metetra
.456 .765 .996 r
.88549 .46225 .88776 .4642 .8941 .46384 .89185 .46196 Metetra
.442 .764 .996 r
.89185 .46196 .8941 .46384 .90046 .46355 .89823 .46172 Metetra
.436 .765 .996 r
.89823 .46172 .90046 .46355 .90685 .4633 .90463 .46147 Metetra
.441 .769 .997 r
.90463 .46147 .90685 .4633 .91326 .46304 .91104 .46118 Metetra
.459 .775 .998 r
.91104 .46118 .91326 .46304 .91968 .46274 .91747 .46078 Metetra
.488 .782 .997 r
.91747 .46078 .91968 .46274 .92611 .46233 .92389 .46023 Metetra
.525 .787 .993 r
.92389 .46023 .92611 .46233 .93253 .46178 .93031 .45948 Metetra
.564 .788 .983 r
.93031 .45948 .93253 .46178 .93896 .46103 .93671 .45849 Metetra
.6 .785 .969 r
.93671 .45849 .93896 .46103 .94537 .46004 .9431 .45723 Metetra
.631 .777 .951 r
.9431 .45723 .94537 .46004 .95176 .45879 .94947 .45569 Metetra
.656 .766 .931 r
.94947 .45569 .95176 .45879 .95814 .45725 .95582 .45386 Metetra
.675 .755 .911 r
.95582 .45386 .95814 .45725 .96448 .45541 .96214 .45175 Metetra
.69 .744 .892 r
.96214 .45175 .96448 .45541 .97081 .4533 .96844 .44936 Metetra
.599 .668 .888 r
.39506 .61628 .39814 .62007 .40333 .61917 .40024 .61566 Metetra
.617 .69 .895 r
.40024 .61566 .40333 .61917 .40855 .61797 .40545 .61476 Metetra
.638 .715 .903 r
.40545 .61476 .40855 .61797 .41378 .61642 .41068 .61354 Metetra
.661 .744 .912 r
.41068 .61354 .41378 .61642 .41904 .61452 .41593 .61199 Metetra
.684 .773 .919 r
.41593 .61199 .41904 .61452 .42431 .6123 .42121 .6101 Metetra
.707 .801 .924 r
.42121 .6101 .42431 .6123 .42961 .60977 .4265 .60787 Metetra
.727 .826 .926 r
.4265 .60787 .42961 .60977 .43491 .60699 .43181 .60532 Metetra
.744 .847 .927 r
.43181 .60532 .43491 .60699 .44023 .604 .43713 .60251 Metetra
.757 .862 .927 r
.43713 .60251 .44023 .604 .44556 .60085 .44246 .5995 Metetra
.766 .872 .926 r
.44246 .5995 .44556 .60085 .45089 .59762 .4478 .59634 Metetra
.771 .879 .925 r
.4478 .59634 .45089 .59762 .45623 .59434 .45315 .59308 Metetra
.773 .881 .925 r
.45315 .59308 .45623 .59434 .46158 .59106 .45851 .58979 Metetra
.772 .881 .925 r
.45851 .58979 .46158 .59106 .46693 .58782 .46387 .5865 Metetra
.769 .877 .925 r
.46387 .5865 .46693 .58782 .47228 .58467 .46924 .58326 Metetra
.764 .871 .926 r
.46924 .58326 .47228 .58467 .47764 .58163 .47461 .5801 Metetra
.757 .862 .926 r
.47461 .5801 .47764 .58163 .483 .57872 .47998 .57705 Metetra
.749 .851 .926 r
.47998 .57705 .483 .57872 .48837 .57597 .48536 .57413 Metetra
.739 .839 .926 r
.48536 .57413 .48837 .57597 .49374 .57337 .49074 .57136 Metetra
.729 .825 .924 r
.49074 .57136 .49374 .57337 .49912 .57091 .49613 .56875 Metetra
.719 .812 .923 r
.49613 .56875 .49912 .57091 .5045 .5686 .50153 .56629 Metetra
.71 .8 .921 r
.50153 .56629 .5045 .5686 .5099 .56641 .50693 .56396 Metetra
.701 .789 .919 r
.50693 .56396 .5099 .56641 .5153 .56432 .51234 .56176 Metetra
.694 .78 .917 r
.51234 .56176 .5153 .56432 .52071 .56233 .51776 .55967 Metetra
.687 .772 .916 r
.51776 .55967 .52071 .56233 .52613 .56041 .52319 .55767 Metetra
.682 .765 .914 r
.52319 .55767 .52613 .56041 .53156 .55856 .52863 .55575 Metetra
.678 .76 .913 r
.52863 .55575 .53156 .55856 .537 .55676 .53407 .55389 Metetra
.674 .755 .912 r
.53407 .55389 .537 .55676 .54245 .555 .53953 .55208 Metetra
.671 .751 .911 r
.53953 .55208 .54245 .555 .54791 .55327 .545 .5503 Metetra
.669 .749 .91 r
.545 .5503 .54791 .55327 .55339 .55156 .55048 .54856 Metetra
.668 .746 .909 r
.55048 .54856 .55339 .55156 .55887 .54986 .55597 .54684 Metetra
.666 .745 .909 r
.55597 .54684 .55887 .54986 .56436 .54818 .56147 .54514 Metetra
.665 .744 .909 r
.56147 .54514 .56436 .54818 .56987 .5465 .56699 .54344 Metetra
.665 .743 .908 r
.56699 .54344 .56987 .5465 .57539 .54482 .57251 .54176 Metetra
.664 .742 .908 r
.57251 .54176 .57539 .54482 .58091 .54314 .57804 .54007 Metetra
.664 .742 .908 r
.57804 .54007 .58091 .54314 .58645 .54147 .58359 .53839 Metetra
.664 .742 .908 r
.58359 .53839 .58645 .54147 .592 .53979 .58915 .5367 Metetra
.664 .742 .908 r
.58915 .5367 .592 .53979 .59756 .53811 .59471 .53501 Metetra
.664 .742 .908 r
.59471 .53501 .59756 .53811 .60313 .53643 .60029 .53333 Metetra
.664 .741 .908 r
.60029 .53333 .60313 .53643 .60872 .53475 .60588 .53164 Metetra
.664 .741 .908 r
.60588 .53164 .60872 .53475 .61431 .53306 .61148 .52994 Metetra
.664 .741 .908 r
.61148 .52994 .61431 .53306 .61991 .53137 .6171 .52825 Metetra
.664 .741 .908 r
.6171 .52825 .61991 .53137 .62553 .52968 .62272 .52655 Metetra
.664 .741 .908 r
.62272 .52655 .62553 .52968 .63116 .52798 .62836 .52484 Metetra
.664 .741 .908 r
.62836 .52484 .63116 .52798 .6368 .52628 .634 .52314 Metetra
.664 .741 .908 r
.634 .52314 .6368 .52628 .64245 .52458 .63966 .52143 Metetra
.664 .741 .908 r
.63966 .52143 .64245 .52458 .64811 .52288 .64533 .51972 Metetra
.664 .741 .908 r
.64533 .51972 .64811 .52288 .65378 .52117 .65101 .518 Metetra
.664 .741 .908 r
.65101 .518 .65378 .52117 .65947 .51945 .6567 .51628 Metetra
.664 .741 .908 r
.6567 .51628 .65947 .51945 .66516 .51773 .66241 .51456 Metetra
.664 .741 .908 r
.66241 .51456 .66516 .51773 .67087 .51601 .66812 .51283 Metetra
.664 .741 .908 r
.66812 .51283 .67087 .51601 .67659 .51429 .67385 .5111 Metetra
.664 .741 .908 r
.67385 .5111 .67659 .51429 .68232 .51256 .67959 .50937 Metetra
.664 .741 .908 r
.67959 .50937 .68232 .51256 .68806 .51083 .68534 .50763 Metetra
.664 .741 .908 r
.68534 .50763 .68806 .51083 .69382 .5091 .6911 .50589 Metetra
.664 .741 .908 r
.6911 .50589 .69382 .5091 .69958 .50736 .69688 .50414 Metetra
.664 .741 .908 r
.69688 .50414 .69958 .50736 .70536 .50562 .70266 .50239 Metetra
.664 .741 .908 r
.70266 .50239 .70536 .50562 .71115 .50387 .70846 .50064 Metetra
.664 .741 .908 r
.70846 .50064 .71115 .50387 .71695 .50213 .71427 .49889 Metetra
.664 .741 .908 r
.71427 .49889 .71695 .50213 .72277 .50037 .72009 .49713 Metetra
.663 .741 .908 r
.72009 .49713 .72277 .50037 .72859 .49862 .72592 .49537 Metetra
.663 .741 .908 r
.72592 .49537 .72859 .49862 .73443 .49686 .73177 .49361 Metetra
.663 .741 .908 r
.73177 .49361 .73443 .49686 .74028 .4951 .73763 .49184 Metetra
.663 .741 .908 r
.73763 .49184 .74028 .4951 .74614 .49334 .7435 .49007 Metetra
.663 .741 .908 r
.7435 .49007 .74614 .49334 .75201 .49157 .74938 .4883 Metetra
.663 .741 .908 r
.74938 .4883 .75201 .49157 .7579 .4898 .75527 .48653 Metetra
.663 .742 .909 r
.75527 .48653 .7579 .4898 .76379 .48804 .76118 .48476 Metetra
.662 .742 .909 r
.76118 .48476 .76379 .48804 .7697 .48627 .7671 .48299 Metetra
.661 .742 .91 r
.7671 .48299 .7697 .48627 .77563 .48451 .77303 .48124 Metetra
.66 .742 .911 r
.77303 .48124 .77563 .48451 .78156 .48276 .77898 .47949 Metetra
.659 .743 .912 r
.77898 .47949 .78156 .48276 .78751 .48101 .78494 .47776 Metetra
.657 .743 .914 r
.78494 .47776 .78751 .48101 .79348 .47929 .79091 .47606 Metetra
.654 .744 .916 r
.79091 .47606 .79348 .47929 .79946 .47759 .7969 .47439 Metetra
.651 .745 .918 r
.7969 .47439 .79946 .47759 .80545 .47592 .80291 .47276 Metetra
.647 .747 .922 r
.80291 .47276 .80545 .47592 .81146 .47429 .80894 .47118 Metetra
.642 .748 .926 r
.80894 .47118 .81146 .47429 .81749 .47272 .81498 .46966 Metetra
.635 .75 .931 r
.81498 .46966 .81749 .47272 .82354 .47121 .82105 .46823 Metetra
.626 .752 .938 r
.82105 .46823 .82354 .47121 .82961 .46978 .82714 .46689 Metetra
.615 .755 .945 r
.82714 .46689 .82961 .46978 .83571 .46845 .83325 .46566 Metetra
.601 .758 .954 r
.83325 .46566 .83571 .46845 .84183 .46723 .83939 .46456 Metetra
.585 .762 .963 r
.83939 .46456 .84183 .46723 .84798 .46613 .84556 .46359 Metetra
.566 .764 .971 r
.84556 .46359 .84798 .46613 .85415 .46516 .85176 .46276 Metetra
.545 .766 .98 r
.85176 .46276 .85415 .46516 .86036 .46433 .858 .46205 Metetra
.523 .767 .986 r
.858 .46205 .86036 .46433 .8666 .46364 .86426 .46147 Metetra
.499 .767 .991 r
.86426 .46147 .8666 .46364 .87287 .46306 .87055 .46101 Metetra
.476 .766 .994 r
.87055 .46101 .87287 .46306 .87916 .46261 .87687 .46065 Metetra
.455 .764 .996 r
.87687 .46065 .87916 .46261 .88549 .46225 .88322 .46037 Metetra
.439 .763 .996 r
.88322 .46037 .88549 .46225 .89185 .46196 .88959 .46014 Metetra
.432 .765 .996 r
.88959 .46014 .89185 .46196 .89823 .46172 .89599 .4599 Metetra
.438 .769 .997 r
.89599 .4599 .89823 .46172 .90463 .46147 .9024 .45961 Metetra
.456 .775 .998 r
.9024 .45961 .90463 .46147 .91104 .46118 .90881 .45922 Metetra
.487 .783 .997 r
.90881 .45922 .91104 .46118 .91747 .46078 .91523 .45867 Metetra
.525 .788 .993 r
.91523 .45867 .91747 .46078 .92389 .46023 .92164 .45792 Metetra
.564 .788 .983 r
.92164 .45792 .92389 .46023 .93031 .45948 .92804 .45692 Metetra
.6 .784 .968 r
.92804 .45692 .93031 .45948 .93671 .45849 .93442 .45566 Metetra
.631 .776 .95 r
.93442 .45566 .93671 .45849 .9431 .45723 .94079 .45413 Metetra
.655 .766 .931 r
.94079 .45413 .9431 .45723 .94947 .45569 .94713 .45231 Metetra
.675 .755 .912 r
.94713 .45231 .94947 .45569 .95582 .45386 .95345 .4502 Metetra
.69 .745 .893 r
.95345 .4502 .95582 .45386 .96214 .45175 .95975 .44782 Metetra
.701 .734 .876 r
.95975 .44782 .96214 .45175 .96844 .44936 .96602 .44517 Metetra
.584 .651 .882 r
.39197 .61228 .39506 .61628 .40024 .61566 .39715 .61187 Metetra
.6 .669 .888 r
.39715 .61187 .40024 .61566 .40545 .61476 .40235 .61122 Metetra
.618 .69 .895 r
.40235 .61122 .40545 .61476 .41068 .61354 .40758 .61031 Metetra
.638 .715 .903 r
.40758 .61031 .41068 .61354 .41593 .61199 .41283 .60909 Metetra
.66 .742 .911 r
.41283 .60909 .41593 .61199 .42121 .6101 .41809 .60754 Metetra
.684 .772 .918 r
.41809 .60754 .42121 .6101 .4265 .60787 .42338 .60564 Metetra
.706 .801 .924 r
.42338 .60564 .4265 .60787 .43181 .60532 .42869 .60341 Metetra
.727 .827 .927 r
.42869 .60341 .43181 .60532 .43713 .60251 .43402 .60085 Metetra
.744 .848 .928 r
.43402 .60085 .43713 .60251 .44246 .5995 .43935 .59803 Metetra
.758 .864 .927 r
.43935 .59803 .44246 .5995 .4478 .59634 .4447 .59499 Metetra
.767 .874 .926 r
.4447 .59499 .4478 .59634 .45315 .59308 .45006 .5918 Metetra
.772 .88 .925 r
.45006 .5918 .45315 .59308 .45851 .58979 .45543 .58852 Metetra
.773 .881 .924 r
.45543 .58852 .45851 .58979 .46387 .5865 .4608 .58521 Metetra
.772 .88 .925 r
.4608 .58521 .46387 .5865 .46924 .58326 .46618 .58191 Metetra
.769 .876 .925 r
.46618 .58191 .46924 .58326 .47461 .5801 .47156 .57866 Metetra
.764 .87 .926 r
.47156 .57866 .47461 .5801 .47998 .57705 .47695 .5755 Metetra
.757 .862 .926 r
.47695 .5755 .47998 .57705 .48536 .57413 .48234 .57244 Metetra
.749 .851 .926 r
.48234 .57244 .48536 .57413 .49074 .57136 .48773 .56952 Metetra
.739 .839 .926 r
.48773 .56952 .49074 .57136 .49613 .56875 .49313 .56674 Metetra
.729 .826 .925 r
.49313 .56674 .49613 .56875 .50153 .56629 .49854 .56411 Metetra
.719 .813 .923 r
.49854 .56411 .50153 .56629 .50693 .56396 .50395 .56163 Metetra
.71 .8 .921 r
.50395 .56163 .50693 .56396 .51234 .56176 .50937 .5593 Metetra
.701 .789 .919 r
.50937 .5593 .51234 .56176 .51776 .55967 .5148 .55709 Metetra
.694 .78 .917 r
.5148 .55709 .51776 .55967 .52319 .55767 .52024 .55499 Metetra
.687 .772 .916 r
.52024 .55499 .52319 .55767 .52863 .55575 .52568 .55299 Metetra
.682 .765 .914 r
.52568 .55299 .52863 .55575 .53407 .55389 .53114 .55106 Metetra
.678 .76 .913 r
.53114 .55106 .53407 .55389 .53953 .55208 .5366 .54919 Metetra
.674 .755 .912 r
.5366 .54919 .53953 .55208 .545 .5503 .54208 .54737 Metetra
.671 .752 .911 r
.54208 .54737 .545 .5503 .55048 .54856 .54757 .54558 Metetra
.669 .749 .91 r
.54757 .54558 .55048 .54856 .55597 .54684 .55306 .54383 Metetra
.668 .746 .909 r
.55306 .54383 .55597 .54684 .56147 .54514 .55857 .5421 Metetra
.666 .745 .909 r
.55857 .5421 .56147 .54514 .56699 .54344 .56409 .54039 Metetra
.665 .744 .909 r
.56409 .54039 .56699 .54344 .57251 .54176 .56962 .53868 Metetra
.665 .743 .908 r
.56962 .53868 .57251 .54176 .57804 .54007 .57516 .53699 Metetra
.664 .742 .908 r
.57516 .53699 .57804 .54007 .58359 .53839 .58072 .53529 Metetra
.664 .742 .908 r
.58072 .53529 .58359 .53839 .58915 .5367 .58628 .5336 Metetra
.664 .742 .908 r
.58628 .5336 .58915 .5367 .59471 .53501 .59186 .5319 Metetra
.664 .742 .908 r
.59186 .5319 .59471 .53501 .60029 .53333 .59744 .53021 Metetra
.664 .742 .908 r
.59744 .53021 .60029 .53333 .60588 .53164 .60304 .52851 Metetra
.664 .741 .908 r
.60304 .52851 .60588 .53164 .61148 .52994 .60865 .52681 Metetra
.664 .741 .908 r
.60865 .52681 .61148 .52994 .6171 .52825 .61427 .52511 Metetra
.664 .741 .908 r
.61427 .52511 .6171 .52825 .62272 .52655 .6199 .5234 Metetra
.664 .741 .908 r
.6199 .5234 .62272 .52655 .62836 .52484 .62554 .52169 Metetra
.664 .741 .908 r
.62554 .52169 .62836 .52484 .634 .52314 .6312 .51998 Metetra
.664 .741 .908 r
.6312 .51998 .634 .52314 .63966 .52143 .63686 .51826 Metetra
.664 .741 .908 r
.63686 .51826 .63966 .52143 .64533 .51972 .64254 .51654 Metetra
.664 .741 .908 r
.64254 .51654 .64533 .51972 .65101 .518 .64823 .51482 Metetra
.664 .741 .908 r
.64823 .51482 .65101 .518 .6567 .51628 .65393 .5131 Metetra
.664 .741 .908 r
.65393 .5131 .6567 .51628 .66241 .51456 .65964 .51137 Metetra
.664 .741 .908 r
.65964 .51137 .66241 .51456 .66812 .51283 .66537 .50963 Metetra
.664 .741 .908 r
.66537 .50963 .66812 .51283 .67385 .5111 .6711 .5079 Metetra
.664 .741 .908 r
.6711 .5079 .67385 .5111 .67959 .50937 .67685 .50616 Metetra
.664 .741 .908 r
.67685 .50616 .67959 .50937 .68534 .50763 .68261 .50441 Metetra
.664 .741 .908 r
.68261 .50441 .68534 .50763 .6911 .50589 .68838 .50266 Metetra
.664 .741 .908 r
.68838 .50266 .6911 .50589 .69688 .50414 .69416 .50091 Metetra
.664 .741 .908 r
.69416 .50091 .69688 .50414 .70266 .50239 .69995 .49916 Metetra
.664 .741 .908 r
.69995 .49916 .70266 .50239 .70846 .50064 .70576 .4974 Metetra
.664 .741 .908 r
.70576 .4974 .70846 .50064 .71427 .49889 .71158 .49564 Metetra
.663 .741 .908 r
.71158 .49564 .71427 .49889 .72009 .49713 .71741 .49388 Metetra
.663 .741 .908 r
.71741 .49388 .72009 .49713 .72592 .49537 .72325 .49211 Metetra
.663 .741 .908 r
.72325 .49211 .72592 .49537 .73177 .49361 .7291 .49034 Metetra
.663 .741 .908 r
.7291 .49034 .73177 .49361 .73763 .49184 .73497 .48857 Metetra
.663 .741 .908 r
.73497 .48857 .73763 .49184 .7435 .49007 .74085 .48679 Metetra
.663 .741 .908 r
.74085 .48679 .7435 .49007 .74938 .4883 .74674 .48502 Metetra
.663 .742 .909 r
.74674 .48502 .74938 .4883 .75527 .48653 .75264 .48325 Metetra
.662 .742 .909 r
.75264 .48325 .75527 .48653 .76118 .48476 .75855 .48148 Metetra
.661 .742 .91 r
.75855 .48148 .76118 .48476 .7671 .48299 .76448 .47972 Metetra
.66 .742 .911 r
.76448 .47972 .7671 .48299 .77303 .48124 .77043 .47797 Metetra
.659 .743 .912 r
.77043 .47797 .77303 .48124 .77898 .47949 .77638 .47624 Metetra
.657 .743 .914 r
.77638 .47624 .77898 .47949 .78494 .47776 .78235 .47453 Metetra
.655 .744 .916 r
.78235 .47453 .78494 .47776 .79091 .47606 .78834 .47285 Metetra
.652 .745 .918 r
.78834 .47285 .79091 .47606 .7969 .47439 .79434 .47121 Metetra
.647 .746 .922 r
.79434 .47121 .7969 .47439 .80291 .47276 .80036 .46963 Metetra
.642 .748 .926 r
.80036 .46963 .80291 .47276 .80894 .47118 .8064 .46811 Metetra
.635 .75 .931 r
.8064 .46811 .80894 .47118 .81498 .46966 .81247 .46667 Metetra
.626 .752 .938 r
.81247 .46667 .81498 .46966 .82105 .46823 .81855 .46533 Metetra
.615 .755 .945 r
.81855 .46533 .82105 .46823 .82714 .46689 .82466 .4641 Metetra
.601 .759 .954 r
.82466 .4641 .82714 .46689 .83325 .46566 .8308 .463 Metetra
.585 .762 .963 r
.8308 .463 .83325 .46566 .83939 .46456 .83696 .46202 Metetra
.567 .765 .971 r
.83696 .46202 .83939 .46456 .84556 .46359 .84315 .46118 Metetra
.546 .766 .979 r
.84315 .46118 .84556 .46359 .85176 .46276 .84938 .46046 Metetra
.524 .767 .986 r
.84938 .46046 .85176 .46276 .858 .46205 .85563 .45988 Metetra
.5 .766 .991 r
.85563 .45988 .858 .46205 .86426 .46147 .86192 .45941 Metetra
.475 .765 .994 r
.86192 .45941 .86426 .46147 .87055 .46101 .86823 .45906 Metetra
.453 .763 .996 r
.86823 .45906 .87055 .46101 .87687 .46065 .87458 .45878 Metetra
.436 .763 .996 r
.87458 .45878 .87687 .46065 .88322 .46037 .88094 .45856 Metetra
.428 .764 .996 r
.88094 .45856 .88322 .46037 .88959 .46014 .88733 .45833 Metetra
.434 .769 .997 r
.88733 .45833 .88959 .46014 .89599 .4599 .89373 .45805 Metetra
.455 .776 .998 r
.89373 .45805 .89599 .4599 .9024 .45961 .90014 .45766 Metetra
.487 .783 .997 r
.90014 .45766 .9024 .45961 .90881 .45922 .90655 .4571 Metetra
.526 .787 .993 r
.90655 .4571 .90881 .45922 .91523 .45867 .91295 .45634 Metetra
.565 .787 .983 r
.91295 .45634 .91523 .45867 .92164 .45792 .91935 .45534 Metetra
.6 .783 .968 r
.91935 .45534 .92164 .45792 .92804 .45692 .92573 .45409 Metetra
.63 .776 .951 r
.92573 .45409 .92804 .45692 .93442 .45566 .93209 .45257 Metetra
.654 .766 .932 r
.93209 .45257 .93442 .45566 .94079 .45413 .93843 .45076 Metetra
.674 .756 .913 r
.93843 .45076 .94079 .45413 .94713 .45231 .94475 .44866 Metetra
.69 .746 .894 r
.94475 .44866 .94713 .45231 .95345 .4502 .95105 .44628 Metetra
.702 .735 .877 r
.95105 .44628 .95345 .4502 .95975 .44782 .95732 .44362 Metetra
.71 .725 .861 r
.95732 .44362 .95975 .44782 .96602 .44517 .96357 .44071 Metetra
.571 .637 .877 r
.38888 .6081 .39197 .61228 .39715 .61187 .39406 .60787 Metetra
.585 .652 .883 r
.39406 .60787 .39715 .61187 .40235 .61122 .39926 .60744 Metetra
.601 .671 .889 r
.39926 .60744 .40235 .61122 .40758 .61031 .40448 .60677 Metetra
.619 .691 .895 r
.40448 .60677 .40758 .61031 .41283 .60909 .40972 .60583 Metetra
.639 .715 .903 r
.40972 .60583 .41283 .60909 .41809 .60754 .41498 .60459 Metetra
.66 .741 .91 r
.41498 .60459 .41809 .60754 .42338 .60564 .42027 .60304 Metetra
.683 .77 .917 r
.42027 .60304 .42338 .60564 .42869 .60341 .42557 .60114 Metetra
.705 .799 .923 r
.42557 .60114 .42869 .60341 .43402 .60085 .4309 .59891 Metetra
.727 .826 .927 r
.4309 .59891 .43402 .60085 .43935 .59803 .43624 .59636 Metetra
.745 .849 .928 r
.43624 .59636 .43935 .59803 .4447 .59499 .44159 .59352 Metetra
.758 .866 .927 r
.44159 .59352 .4447 .59499 .45006 .5918 .44696 .59046 Metetra
.768 .876 .926 r
.44696 .59046 .45006 .5918 .45543 .58852 .45234 .58724 Metetra
.773 .881 .925 r
.45234 .58724 .45543 .58852 .4608 .58521 .45772 .58393 Metetra
.774 .882 .924 r
.45772 .58393 .4608 .58521 .46618 .58191 .46311 .5806 Metetra
.772 .88 .924 r
.46311 .5806 .46618 .58191 .47156 .57866 .4685 .57729 Metetra
.769 .875 .925 r
.4685 .57729 .47156 .57866 .47695 .5755 .4739 .57403 Metetra
.763 .869 .926 r
.4739 .57403 .47695 .5755 .48234 .57244 .4793 .57087 Metetra
.757 .861 .926 r
.4793 .57087 .48234 .57244 .48773 .56952 .48471 .56781 Metetra
.748 .851 .926 r
.48471 .56781 .48773 .56952 .49313 .56674 .49012 .56488 Metetra
.739 .839 .926 r
.49012 .56488 .49313 .56674 .49854 .56411 .49554 .56209 Metetra
.73 .827 .925 r
.49554 .56209 .49854 .56411 .50395 .56163 .50096 .55945 Metetra
.72 .813 .923 r
.50096 .55945 .50395 .56163 .50937 .5593 .50639 .55696 Metetra
.71 .801 .921 r
.50639 .55696 .50937 .5593 .5148 .55709 .51183 .55461 Metetra
.701 .789 .919 r
.51183 .55461 .5148 .55709 .52024 .55499 .51727 .55239 Metetra
.693 .779 .917 r
.51727 .55239 .52024 .55499 .52568 .55299 .52273 .55028 Metetra
.687 .771 .915 r
.52273 .55028 .52568 .55299 .53114 .55106 .52819 .54827 Metetra
.682 .765 .914 r
.52819 .54827 .53114 .55106 .5366 .54919 .53366 .54634 Metetra
.678 .759 .913 r
.53366 .54634 .5366 .54919 .54208 .54737 .53915 .54446 Metetra
.674 .755 .912 r
.53915 .54446 .54208 .54737 .54757 .54558 .54464 .54263 Metetra
.671 .752 .911 r
.54464 .54263 .54757 .54558 .55306 .54383 .55014 .54084 Metetra
.669 .749 .91 r
.55014 .54084 .55306 .54383 .55857 .5421 .55566 .53908 Metetra
.668 .747 .909 r
.55566 .53908 .55857 .5421 .56409 .54039 .56119 .53734 Metetra
.666 .745 .909 r
.56119 .53734 .56409 .54039 .56962 .53868 .56673 .53561 Metetra
.665 .744 .909 r
.56673 .53561 .56962 .53868 .57516 .53699 .57227 .5339 Metetra
.665 .743 .908 r
.57227 .5339 .57516 .53699 .58072 .53529 .57783 .53219 Metetra
.664 .742 .908 r
.57783 .53219 .58072 .53529 .58628 .5336 .58341 .53049 Metetra
.664 .742 .908 r
.58341 .53049 .58628 .5336 .59186 .5319 .58899 .52878 Metetra
.664 .742 .908 r
.58899 .52878 .59186 .5319 .59744 .53021 .59458 .52708 Metetra
.664 .742 .908 r
.59458 .52708 .59744 .53021 .60304 .52851 .60019 .52537 Metetra
.664 .742 .908 r
.60019 .52537 .60304 .52851 .60865 .52681 .6058 .52367 Metetra
.664 .741 .908 r
.6058 .52367 .60865 .52681 .61427 .52511 .61143 .52196 Metetra
.664 .741 .908 r
.61143 .52196 .61427 .52511 .6199 .5234 .61707 .52024 Metetra
.664 .741 .908 r
.61707 .52024 .6199 .5234 .62554 .52169 .62272 .51853 Metetra
.664 .741 .908 r
.62272 .51853 .62554 .52169 .6312 .51998 .62838 .51681 Metetra
.664 .741 .908 r
.62838 .51681 .6312 .51998 .63686 .51826 .63406 .51509 Metetra
.664 .741 .908 r
.63406 .51509 .63686 .51826 .64254 .51654 .63974 .51336 Metetra
.664 .741 .908 r
.63974 .51336 .64254 .51654 .64823 .51482 .64544 .51163 Metetra
.664 .741 .908 r
.64544 .51163 .64823 .51482 .65393 .5131 .65115 .5099 Metetra
.664 .741 .908 r
.65115 .5099 .65393 .5131 .65964 .51137 .65687 .50816 Metetra
.664 .741 .908 r
.65687 .50816 .65964 .51137 .66537 .50963 .6626 .50642 Metetra
.664 .741 .908 r
.6626 .50642 .66537 .50963 .6711 .5079 .66834 .50468 Metetra
.664 .741 .908 r
.66834 .50468 .6711 .5079 .67685 .50616 .6741 .50293 Metetra
.664 .741 .908 r
.6741 .50293 .67685 .50616 .68261 .50441 .67986 .50118 Metetra
.664 .741 .908 r
.67986 .50118 .68261 .50441 .68838 .50266 .68564 .49943 Metetra
.664 .741 .908 r
.68564 .49943 .68838 .50266 .69416 .50091 .69143 .49767 Metetra
.664 .741 .908 r
.69143 .49767 .69416 .50091 .69995 .49916 .69723 .49591 Metetra
.663 .741 .908 r
.69723 .49591 .69995 .49916 .70576 .4974 .70305 .49415 Metetra
.663 .741 .908 r
.70305 .49415 .70576 .4974 .71158 .49564 .70887 .49238 Metetra
.663 .741 .908 r
.70887 .49238 .71158 .49564 .71741 .49388 .71471 .49061 Metetra
.663 .741 .908 r
.71471 .49061 .71741 .49388 .72325 .49211 .72056 .48884 Metetra
.663 .741 .908 r
.72056 .48884 .72325 .49211 .7291 .49034 .72642 .48706 Metetra
.663 .741 .908 r
.72642 .48706 .7291 .49034 .73497 .48857 .7323 .48528 Metetra
.663 .741 .908 r
.7323 .48528 .73497 .48857 .74085 .48679 .73818 .4835 Metetra
.663 .741 .909 r
.73818 .4835 .74085 .48679 .74674 .48502 .74408 .48173 Metetra
.662 .742 .909 r
.74408 .48173 .74674 .48502 .75264 .48325 .75 .47996 Metetra
.661 .742 .91 r
.75 .47996 .75264 .48325 .75855 .48148 .75592 .4782 Metetra
.66 .742 .911 r
.75592 .4782 .75855 .48148 .76448 .47972 .76186 .47644 Metetra
.659 .743 .912 r
.76186 .47644 .76448 .47972 .77043 .47797 .76781 .47471 Metetra
.657 .743 .914 r
.76781 .47471 .77043 .47797 .77638 .47624 .77378 .473 Metetra
.655 .744 .915 r
.77378 .473 .77638 .47624 .78235 .47453 .77976 .47131 Metetra
.652 .745 .918 r
.77976 .47131 .78235 .47453 .78834 .47285 .78576 .46967 Metetra
.648 .746 .921 r
.78576 .46967 .78834 .47285 .79434 .47121 .79178 .46807 Metetra
.642 .748 .926 r
.79178 .46807 .79434 .47121 .80036 .46963 .79781 .46655 Metetra
.635 .75 .931 r
.79781 .46655 .80036 .46963 .8064 .46811 .80387 .46511 Metetra
.626 .752 .938 r
.80387 .46511 .8064 .46811 .81247 .46667 .80995 .46377 Metetra
.615 .756 .946 r
.80995 .46377 .81247 .46667 .81855 .46533 .81605 .46254 Metetra
.601 .759 .954 r
.81605 .46254 .81855 .46533 .82466 .4641 .82218 .46143 Metetra
.586 .762 .963 r
.82218 .46143 .82466 .4641 .8308 .463 .82834 .46044 Metetra
.568 .765 .971 r
.82834 .46044 .8308 .463 .83696 .46202 .83453 .45959 Metetra
.548 .766 .979 r
.83453 .45959 .83696 .46202 .84315 .46118 .84075 .45886 Metetra
.525 .767 .985 r
.84075 .45886 .84315 .46118 .84938 .46046 .84699 .45827 Metetra
.5 .766 .991 r
.84699 .45827 .84938 .46046 .85563 .45988 .85327 .45781 Metetra
.474 .764 .994 r
.85327 .45781 .85563 .45988 .86192 .45941 .85958 .45746 Metetra
.449 .763 .996 r
.85958 .45746 .86192 .45941 .86823 .45906 .86592 .4572 Metetra
.431 .762 .996 r
.86592 .4572 .86823 .45906 .87458 .45878 .87228 .45699 Metetra
.424 .764 .996 r
.87228 .45699 .87458 .45878 .88094 .45856 .87866 .45677 Metetra
.432 .769 .997 r
.87866 .45677 .88094 .45856 .88733 .45833 .88505 .45649 Metetra
.455 .776 .998 r
.88505 .45649 .88733 .45833 .89373 .45805 .89145 .45609 Metetra
.489 .783 .997 r
.89145 .45609 .89373 .45805 .90014 .45766 .89785 .45552 Metetra
.527 .787 .992 r
.89785 .45552 .90014 .45766 .90655 .4571 .90425 .45475 Metetra
.565 .786 .982 r
.90425 .45475 .90655 .4571 .91295 .45634 .91064 .45376 Metetra
.599 .782 .968 r
.91064 .45376 .91295 .45634 .91935 .45534 .91702 .45252 Metetra
.628 .776 .952 r
.91702 .45252 .91935 .45534 .92573 .45409 .92338 .45101 Metetra
.652 .767 .934 r
.92338 .45101 .92573 .45409 .93209 .45257 .92972 .44922 Metetra
.673 .758 .915 r
.92972 .44922 .93209 .45257 .93843 .45076 .93604 .44713 Metetra
.69 .747 .895 r
.93604 .44713 .93843 .45076 .94475 .44866 .94233 .44475 Metetra
.703 .736 .877 r
.94233 .44475 .94475 .44866 .95105 .44628 .9486 .44207 Metetra
.711 .724 .86 r
.9486 .44207 .95105 .44628 .95732 .44362 .95484 .43913 Metetra
.717 .714 .846 r
.95484 .43913 .95732 .44362 .96357 .44071 .96107 .43598 Metetra
.559 .622 .872 r
.38579 .60372 .38888 .6081 .39406 .60787 .39096 .60368 Metetra
.57 .637 .878 r
.39096 .60368 .39406 .60787 .39926 .60744 .39616 .60346 Metetra
.585 .654 .884 r
.39616 .60346 .39926 .60744 .40448 .60677 .40137 .60301 Metetra
.602 .673 .89 r
.40137 .60301 .40448 .60677 .40972 .60583 .40661 .60231 Metetra
.62 .694 .897 r
.40661 .60231 .40972 .60583 .41498 .60459 .41187 .60134 Metetra
.64 .716 .903 r
.41187 .60134 .41498 .60459 .42027 .60304 .41715 .60007 Metetra
.661 .741 .909 r
.41715 .60007 .42027 .60304 .42557 .60114 .42246 .5985 Metetra
.682 .768 .916 r
.42246 .5985 .42557 .60114 .4309 .59891 .42778 .5966 Metetra
.704 .796 .922 r
.42778 .5966 .4309 .59891 .43624 .59636 .43312 .59438 Metetra
.725 .824 .926 r
.43312 .59438 .43624 .59636 .44159 .59352 .43847 .59183 Metetra
.744 .848 .928 r
.43847 .59183 .44159 .59352 .44696 .59046 .44385 .589 Metetra
.758 .867 .928 r
.44385 .589 .44696 .59046 .45234 .58724 .44923 .58592 Metetra
.768 .878 .926 r
.44923 .58592 .45234 .58724 .45772 .58393 .45462 .58267 Metetra
.774 .884 .925 r
.45462 .58267 .45772 .58393 .46311 .5806 .46002 .57933 Metetra
.775 .884 .924 r
.46002 .57933 .46311 .5806 .4685 .57729 .46543 .57597 Metetra
.773 .88 .924 r
.46543 .57597 .4685 .57729 .4739 .57403 .47084 .57263 Metetra
.769 .875 .925 r
.47084 .57263 .4739 .57403 .4793 .57087 .47625 .56937 Metetra
.763 .868 .925 r
.47625 .56937 .4793 .57087 .48471 .56781 .48167 .5662 Metetra
.756 .859 .926 r
.48167 .5662 .48471 .56781 .49012 .56488 .48709 .56315 Metetra
.748 .85 .926 r
.48709 .56315 .49012 .56488 .49554 .56209 .49252 .56022 Metetra
.739 .839 .926 r
.49252 .56022 .49554 .56209 .50096 .55945 .49795 .55742 Metetra
.73 .827 .925 r
.49795 .55742 .50096 .55945 .50639 .55696 .50339 .55477 Metetra
.72 .814 .923 r
.50339 .55477 .50639 .55696 .51183 .55461 .50884 .55226 Metetra
.71 .801 .921 r
.50884 .55226 .51183 .55461 .51727 .55239 .5143 .5499 Metetra
.701 .789 .919 r
.5143 .5499 .51727 .55239 .52273 .55028 .51976 .54766 Metetra
.693 .779 .917 r
.51976 .54766 .52273 .55028 .52819 .54827 .52523 .54555 Metetra
.687 .771 .915 r
.52523 .54555 .52819 .54827 .53366 .54634 .53071 .54353 Metetra
.681 .764 .914 r
.53071 .54353 .53366 .54634 .53915 .54446 .5362 .54159 Metetra
.677 .759 .913 r
.5362 .54159 .53915 .54446 .54464 .54263 .5417 .5397 Metetra
.674 .755 .912 r
.5417 .5397 .54464 .54263 .55014 .54084 .54722 .53787 Metetra
.671 .752 .911 r
.54722 .53787 .55014 .54084 .55566 .53908 .55274 .53607 Metetra
.669 .749 .91 r
.55274 .53607 .55566 .53908 .56119 .53734 .55827 .53429 Metetra
.668 .747 .909 r
.55827 .53429 .56119 .53734 .56673 .53561 .56382 .53254 Metetra
.666 .745 .909 r
.56382 .53254 .56673 .53561 .57227 .5339 .56937 .53081 Metetra
.665 .744 .909 r
.56937 .53081 .57227 .5339 .57783 .53219 .57494 .52908 Metetra
.665 .743 .908 r
.57494 .52908 .57783 .53219 .58341 .53049 .58052 .52737 Metetra
.664 .742 .908 r
.58052 .52737 .58341 .53049 .58899 .52878 .58611 .52565 Metetra
.664 .742 .908 r
.58611 .52565 .58899 .52878 .59458 .52708 .59171 .52394 Metetra
.664 .742 .908 r
.59171 .52394 .59458 .52708 .60019 .52537 .59732 .52223 Metetra
.664 .742 .908 r
.59732 .52223 .60019 .52537 .6058 .52367 .60295 .52051 Metetra
.664 .742 .908 r
.60295 .52051 .6058 .52367 .61143 .52196 .60858 .5188 Metetra
.664 .741 .908 r
.60858 .5188 .61143 .52196 .61707 .52024 .61423 .51708 Metetra
.664 .741 .908 r
.61423 .51708 .61707 .52024 .62272 .51853 .61989 .51535 Metetra
.664 .741 .908 r
.61989 .51535 .62272 .51853 .62838 .51681 .62556 .51363 Metetra
.664 .741 .908 r
.62556 .51363 .62838 .51681 .63406 .51509 .63124 .5119 Metetra
.664 .741 .908 r
.63124 .5119 .63406 .51509 .63974 .51336 .63693 .51017 Metetra
.664 .741 .908 r
.63693 .51017 .63974 .51336 .64544 .51163 .64264 .50843 Metetra
.664 .741 .908 r
.64264 .50843 .64544 .51163 .65115 .5099 .64835 .50669 Metetra
.664 .741 .908 r
.64835 .50669 .65115 .5099 .65687 .50816 .65408 .50495 Metetra
.664 .741 .908 r
.65408 .50495 .65687 .50816 .6626 .50642 .65982 .5032 Metetra
.664 .741 .908 r
.65982 .5032 .6626 .50642 .66834 .50468 .66557 .50145 Metetra
.664 .741 .908 r
.66557 .50145 .66834 .50468 .6741 .50293 .67133 .4997 Metetra
.664 .741 .908 r
.67133 .4997 .6741 .50293 .67986 .50118 .67711 .49794 Metetra
.664 .741 .908 r
.67711 .49794 .67986 .50118 .68564 .49943 .6829 .49618 Metetra
.664 .741 .908 r
.6829 .49618 .68564 .49943 .69143 .49767 .68869 .49442 Metetra
.663 .741 .908 r
.68869 .49442 .69143 .49767 .69723 .49591 .6945 .49265 Metetra
.663 .741 .908 r
.6945 .49265 .69723 .49591 .70305 .49415 .70033 .49088 Metetra
.663 .741 .908 r
.70033 .49088 .70305 .49415 .70887 .49238 .70616 .48911 Metetra
.663 .741 .908 r
.70616 .48911 .70887 .49238 .71471 .49061 .71201 .48733 Metetra
.663 .741 .908 r
.71201 .48733 .71471 .49061 .72056 .48884 .71786 .48555 Metetra
.663 .741 .908 r
.71786 .48555 .72056 .48884 .72642 .48706 .72374 .48377 Metetra
.663 .741 .908 r
.72374 .48377 .72642 .48706 .7323 .48528 .72962 .48199 Metetra
.663 .741 .909 r
.72962 .48199 .7323 .48528 .73818 .4835 .73551 .48021 Metetra
.662 .742 .909 r
.73551 .48021 .73818 .4835 .74408 .48173 .74142 .47844 Metetra
.661 .742 .91 r
.74142 .47844 .74408 .48173 .75 .47996 .74734 .47667 Metetra
.66 .742 .911 r
.74734 .47667 .75 .47996 .75592 .4782 .75328 .47492 Metetra
.659 .743 .912 r
.75328 .47492 .75592 .4782 .76186 .47644 .75923 .47318 Metetra
.657 .743 .913 r
.75923 .47318 .76186 .47644 .76781 .47471 .76519 .47146 Metetra
.655 .744 .915 r
.76519 .47146 .76781 .47471 .77378 .473 .77117 .46977 Metetra
.652 .745 .918 r
.77117 .46977 .77378 .473 .77976 .47131 .77716 .46811 Metetra
.648 .746 .921 r
.77716 .46811 .77976 .47131 .78576 .46967 .78317 .46652 Metetra
.642 .748 .926 r
.78317 .46652 .78576 .46967 .79178 .46807 .78921 .46499 Metetra
.635 .75 .931 r
.78921 .46499 .79178 .46807 .79781 .46655 .79526 .46355 Metetra
.626 .753 .938 r
.79526 .46355 .79781 .46655 .80387 .46511 .80133 .46221 Metetra
.615 .756 .946 r
.80133 .46221 .80387 .46511 .80995 .46377 .80743 .46098 Metetra
.602 .759 .954 r
.80743 .46098 .80995 .46377 .81605 .46254 .81356 .45986 Metetra
.587 .762 .962 r
.81356 .45986 .81605 .46254 .82218 .46143 .81971 .45886 Metetra
.57 .764 .97 r
.81971 .45886 .82218 .46143 .82834 .46044 .82589 .45799 Metetra
.549 .766 .978 r
.82589 .45799 .82834 .46044 .83453 .45959 .8321 .45726 Metetra
.526 .766 .985 r
.8321 .45726 .83453 .45959 .84075 .45886 .83834 .45666 Metetra
.499 .765 .991 r
.83834 .45666 .84075 .45886 .84699 .45827 .84461 .45621 Metetra
.471 .764 .994 r
.84461 .45621 .84699 .45827 .85327 .45781 .85091 .45588 Metetra
.444 .762 .996 r
.85091 .45588 .85327 .45781 .85958 .45746 .85724 .45563 Metetra
.426 .762 .996 r
.85724 .45563 .85958 .45746 .86592 .4572 .8636 .45543 Metetra
.421 .764 .996 r
.8636 .45543 .86592 .4572 .87228 .45699 .86997 .4552 Metetra
.432 .77 .997 r
.86997 .4552 .87228 .45699 .87866 .45677 .87636 .45491 Metetra
.458 .777 .998 r
.87636 .45491 .87866 .45677 .88505 .45649 .88275 .45449 Metetra
.492 .783 .997 r
.88275 .45449 .88505 .45649 .89145 .45609 .88914 .45392 Metetra
.529 .785 .991 r
.88914 .45392 .89145 .45609 .89785 .45552 .89553 .45315 Metetra
.564 .785 .982 r
.89553 .45315 .89785 .45552 .90425 .45475 .90192 .45217 Metetra
.596 .782 .969 r
.90192 .45217 .90425 .45475 .91064 .45376 .90829 .45096 Metetra
.625 .777 .954 r
.90829 .45096 .91064 .45376 .91702 .45252 .91465 .44948 Metetra
.651 .77 .936 r
.91465 .44948 .91702 .45252 .92338 .45101 .92099 .4477 Metetra
.673 .76 .916 r
.92099 .4477 .92338 .45101 .92972 .44922 .92731 .44561 Metetra
.691 .749 .896 r
.92731 .44561 .92972 .44922 .93604 .44713 .9336 .4432 Metetra
.704 .736 .876 r
.9336 .4432 .93604 .44713 .94233 .44475 .93986 .44049 Metetra
.712 .723 .858 r
.93986 .44049 .94233 .44475 .9486 .44207 .9461 .43753 Metetra
.717 .712 .844 r
.9461 .43753 .9486 .44207 .95484 .43913 .95232 .43435 Metetra
.719 .703 .834 r
.95232 .43435 .95484 .43913 .96107 .43598 .95854 .43104 Metetra
.55 .609 .865 r
.3827 .59913 .38579 .60372 .39096 .60368 .38787 .59924 Metetra
.557 .619 .87 r
.38787 .59924 .39096 .60368 .39616 .60346 .39306 .59923 Metetra
.569 .635 .877 r
.39306 .59923 .39616 .60346 .40137 .60301 .39827 .59902 Metetra
.584 .654 .885 r
.39827 .59902 .40137 .60301 .40661 .60231 .4035 .59858 Metetra
.603 .676 .892 r
.4035 .59858 .40661 .60231 .41187 .60134 .40876 .59785 Metetra
.622 .698 .898 r
.40876 .59785 .41187 .60134 .41715 .60007 .41403 .59684 Metetra
.642 .719 .904 r
.41403 .59684 .41715 .60007 .42246 .5985 .41933 .59553 Metetra
.662 .742 .909 r
.41933 .59553 .42246 .5985 .42778 .5966 .42465 .59392 Metetra
.683 .767 .915 r
.42465 .59392 .42778 .5966 .43312 .59438 .42999 .59201 Metetra
.703 .793 .921 r
.42999 .59201 .43312 .59438 .43847 .59183 .43535 .58979 Metetra
.724 .821 .925 r
.43535 .58979 .43847 .59183 .44385 .589 .44072 .58726 Metetra
.742 .846 .928 r
.44072 .58726 .44385 .589 .44923 .58592 .44611 .58444 Metetra
.758 .866 .928 r
.44611 .58444 .44923 .58592 .45462 .58267 .45151 .58136 Metetra
.769 .88 .927 r
.45151 .58136 .45462 .58267 .46002 .57933 .45692 .5781 Metetra
.775 .887 .926 r
.45692 .5781 .46002 .57933 .46543 .57597 .46234 .57473 Metetra
.777 .887 .924 r
.46234 .57473 .46543 .57597 .47084 .57263 .46776 .57133 Metetra
.774 .882 .924 r
.46776 .57133 .47084 .57263 .47625 .56937 .47319 .56796 Metetra
.769 .875 .924 r
.47319 .56796 .47625 .56937 .48167 .5662 .47862 .56467 Metetra
.763 .866 .925 r
.47862 .56467 .48167 .5662 .48709 .56315 .48405 .5615 Metetra
.755 .857 .926 r
.48405 .5615 .48709 .56315 .49252 .56022 .48949 .55844 Metetra
.747 .848 .926 r
.48949 .55844 .49252 .56022 .49795 .55742 .49494 .55552 Metetra
.738 .838 .926 r
.49494 .55552 .49795 .55742 .50339 .55477 .50039 .55273 Metetra
.729 .827 .925 r
.50039 .55273 .50339 .55477 .50884 .55226 .50584 .55007 Metetra
.72 .815 .924 r
.50584 .55007 .50884 .55226 .5143 .5499 .51131 .54755 Metetra
.711 .802 .922 r
.51131 .54755 .5143 .5499 .51976 .54766 .51678 .54517 Metetra
.702 .79 .919 r
.51678 .54517 .51976 .54766 .52523 .54555 .52226 .54292 Metetra
.694 .78 .917 r
.52226 .54292 .52523 .54555 .53071 .54353 .52775 .54079 Metetra
.687 .771 .915 r
.52775 .54079 .53071 .54353 .5362 .54159 .53325 .53875 Metetra
.681 .764 .914 r
.53325 .53875 .5362 .54159 .5417 .5397 .53876 .5368 Metetra
.677 .758 .912 r
.53876 .5368 .5417 .5397 .54722 .53787 .54427 .53492 Metetra
.674 .754 .912 r
.54427 .53492 .54722 .53787 .55274 .53607 .54981 .53308 Metetra
.671 .751 .911 r
.54981 .53308 .55274 .53607 .55827 .53429 .55535 .53127 Metetra
.669 .749 .91 r
.55535 .53127 .55827 .53429 .56382 .53254 .5609 .52949 Metetra
.668 .747 .91 r
.5609 .52949 .56382 .53254 .56937 .53081 .56646 .52772 Metetra
.667 .745 .909 r
.56646 .52772 .56937 .53081 .57494 .52908 .57204 .52598 Metetra
.666 .744 .909 r
.57204 .52598 .57494 .52908 .58052 .52737 .57762 .52424 Metetra
.665 .743 .908 r
.57762 .52424 .58052 .52737 .58611 .52565 .58322 .52252 Metetra
.664 .742 .908 r
.58322 .52252 .58611 .52565 .59171 .52394 .58883 .52079 Metetra
.664 .742 .908 r
.58883 .52079 .59171 .52394 .59732 .52223 .59445 .51907 Metetra
.664 .742 .908 r
.59445 .51907 .59732 .52223 .60295 .52051 .60008 .51735 Metetra
.664 .742 .908 r
.60008 .51735 .60295 .52051 .60858 .5188 .60572 .51562 Metetra
.664 .742 .908 r
.60572 .51562 .60858 .5188 .61423 .51708 .61138 .5139 Metetra
.664 .741 .908 r
.61138 .5139 .61423 .51708 .61989 .51535 .61705 .51217 Metetra
.664 .741 .908 r
.61705 .51217 .61989 .51535 .62556 .51363 .62272 .51043 Metetra
.664 .741 .908 r
.62272 .51043 .62556 .51363 .63124 .5119 .62841 .5087 Metetra
.664 .741 .908 r
.62841 .5087 .63124 .5119 .63693 .51017 .63411 .50696 Metetra
.664 .741 .908 r
.63411 .50696 .63693 .51017 .64264 .50843 .63982 .50522 Metetra
.664 .741 .908 r
.63982 .50522 .64264 .50843 .64835 .50669 .64555 .50347 Metetra
.664 .741 .908 r
.64555 .50347 .64835 .50669 .65408 .50495 .65128 .50172 Metetra
.664 .741 .908 r
.65128 .50172 .65408 .50495 .65982 .5032 .65703 .49997 Metetra
.664 .741 .908 r
.65703 .49997 .65982 .5032 .66557 .50145 .66279 .49821 Metetra
.664 .741 .908 r
.66279 .49821 .66557 .50145 .67133 .4997 .66856 .49645 Metetra
.664 .741 .908 r
.66856 .49645 .67133 .4997 .67711 .49794 .67434 .49469 Metetra
.664 .741 .908 r
.67434 .49469 .67711 .49794 .6829 .49618 .68014 .49292 Metetra
.663 .741 .908 r
.68014 .49292 .6829 .49618 .68869 .49442 .68595 .49115 Metetra
.663 .741 .908 r
.68595 .49115 .68869 .49442 .6945 .49265 .69176 .48938 Metetra
.663 .741 .908 r
.69176 .48938 .6945 .49265 .70033 .49088 .69759 .4876 Metetra
.663 .741 .908 r
.69759 .4876 .70033 .49088 .70616 .48911 .70344 .48582 Metetra
.663 .741 .908 r
.70344 .48582 .70616 .48911 .71201 .48733 .70929 .48404 Metetra
.663 .741 .908 r
.70929 .48404 .71201 .48733 .71786 .48555 .71516 .48225 Metetra
.663 .741 .908 r
.71516 .48225 .71786 .48555 .72374 .48377 .72104 .48047 Metetra
.662 .742 .909 r
.72104 .48047 .72374 .48377 .72962 .48199 .72693 .47869 Metetra
.662 .742 .909 r
.72693 .47869 .72962 .48199 .73551 .48021 .73283 .47692 Metetra
.661 .742 .91 r
.73283 .47692 .73551 .48021 .74142 .47844 .73875 .47515 Metetra
.66 .742 .911 r
.73875 .47515 .74142 .47844 .74734 .47667 .74468 .47339 Metetra
.659 .743 .912 r
.74468 .47339 .74734 .47667 .75328 .47492 .75063 .47164 Metetra
.658 .743 .913 r
.75063 .47164 .75328 .47492 .75923 .47318 .75659 .46991 Metetra
.655 .744 .915 r
.75659 .46991 .75923 .47318 .76519 .47146 .76256 .46822 Metetra
.652 .745 .917 r
.76256 .46822 .76519 .47146 .77117 .46977 .76855 .46656 Metetra
.648 .746 .921 r
.76855 .46656 .77117 .46977 .77716 .46811 .77456 .46496 Metetra
.642 .748 .926 r
.77456 .46496 .77716 .46811 .78317 .46652 .78059 .46344 Metetra
.634 .75 .932 r
.78059 .46344 .78317 .46652 .78921 .46499 .78663 .462 Metetra
.625 .753 .939 r
.78663 .462 .78921 .46499 .79526 .46355 .7927 .46065 Metetra
.615 .757 .946 r
.7927 .46065 .79526 .46355 .80133 .46221 .7988 .45941 Metetra
.603 .76 .954 r
.7988 .45941 .80133 .46221 .80743 .46098 .80491 .45828 Metetra
.589 .762 .961 r
.80491 .45828 .80743 .46098 .81356 .45986 .81106 .45726 Metetra
.571 .764 .969 r
.81106 .45726 .81356 .45986 .81971 .45886 .81723 .45638 Metetra
.55 .764 .977 r
.81723 .45638 .81971 .45886 .82589 .45799 .82343 .45564 Metetra
.525 .765 .985 r
.82343 .45564 .82589 .45799 .8321 .45726 .82967 .45506 Metetra
.496 .764 .991 r
.82967 .45506 .8321 .45726 .83834 .45666 .83593 .45462 Metetra
.465 .763 .995 r
.83593 .45462 .83834 .45666 .84461 .45621 .84223 .4543 Metetra
.439 .762 .996 r
.84223 .4543 .84461 .45621 .85091 .45588 .84856 .45407 Metetra
.422 .762 .996 r
.84856 .45407 .85091 .45588 .85724 .45563 .8549 .45386 Metetra
.421 .766 .996 r
.8549 .45386 .85724 .45563 .8636 .45543 .86127 .45363 Metetra
.436 .771 .997 r
.86127 .45363 .8636 .45543 .86997 .4552 .86764 .45331 Metetra
.463 .777 .998 r
.86764 .45331 .86997 .4552 .87636 .45491 .87402 .45287 Metetra
.495 .781 .996 r
.87402 .45287 .87636 .45491 .88275 .45449 .88041 .45229 Metetra
.528 .783 .991 r
.88041 .45229 .88275 .45449 .88914 .45392 .8868 .45154 Metetra
.56 .783 .982 r
.8868 .45154 .88914 .45392 .89553 .45315 .89318 .4506 Metetra
.591 .782 .971 r
.89318 .4506 .89553 .45315 .90192 .45217 .89955 .44941 Metetra
.621 .779 .957 r
.89955 .44941 .90192 .45217 .90829 .45096 .90591 .44796 Metetra
.649 .773 .939 r
.90591 .44796 .90829 .45096 .91465 .44948 .91225 .44619 Metetra
.674 .763 .918 r
.91225 .44619 .91465 .44948 .92099 .4477 .91856 .44408 Metetra
.692 .75 .895 r
.91856 .44408 .92099 .4477 .92731 .44561 .92484 .44164 Metetra
.705 .735 .874 r
.92484 .44164 .92731 .44561 .9336 .4432 .9311 .43889 Metetra
.713 .721 .856 r
.9311 .43889 .9336 .4432 .93986 .44049 .93734 .43589 Metetra
.717 .709 .842 r
.93734 .43589 .93986 .44049 .9461 .43753 .94356 .43271 Metetra
.718 .701 .833 r
.94356 .43271 .9461 .43753 .95232 .43435 .94978 .4294 Metetra
.719 .696 .827 r
.94978 .4294 .95232 .43435 .95854 .43104 .95599 .42602 Metetra
.548 .603 .861 r
.3796 .59443 .3827 .59913 .38787 .59924 .38477 .59457 Metetra
.549 .606 .862 r
.38477 .59457 .38787 .59924 .39306 .59923 .38996 .5947 Metetra
.554 .615 .868 r
.38996 .5947 .39306 .59923 .39827 .59902 .39516 .59472 Metetra
.566 .631 .876 r
.39516 .59472 .39827 .59902 .4035 .59858 .40039 .59456 Metetra
.582 .653 .885 r
.40039 .59456 .4035 .59858 .40876 .59785 .40564 .59413 Metetra
.602 .677 .894 r
.40564 .59413 .40876 .59785 .41403 .59684 .41091 .5934 Metetra
.624 .702 .901 r
.41091 .5934 .41403 .59684 .41933 .59553 .41621 .59235 Metetra
.645 .725 .906 r
.41621 .59235 .41933 .59553 .42465 .59392 .42153 .59099 Metetra
.665 .746 .911 r
.42153 .59099 .42465 .59392 .42999 .59201 .42687 .58933 Metetra
.684 .768 .915 r
.42687 .58933 .42999 .59201 .43535 .58979 .43222 .58738 Metetra
.703 .791 .919 r
.43222 .58738 .43535 .58979 .44072 .58726 .4376 .58515 Metetra
.722 .816 .923 r
.4376 .58515 .44072 .58726 .44611 .58444 .44299 .58263 Metetra
.74 .841 .927 r
.44299 .58263 .44611 .58444 .45151 .58136 .44839 .57983 Metetra
.756 .864 .928 r
.44839 .57983 .45151 .58136 .45692 .5781 .4538 .57678 Metetra
.768 .88 .928 r
.4538 .57678 .45692 .5781 .46234 .57473 .45923 .57351 Metetra
.775 .889 .926 r
.45923 .57351 .46234 .57473 .46776 .57133 .46466 .57012 Metetra
.778 .891 .925 r
.46466 .57012 .46776 .57133 .47319 .56796 .4701 .56668 Metetra
.776 .886 .924 r
.4701 .56668 .47319 .56796 .47862 .56467 .47555 .56327 Metetra
.771 .877 .924 r
.47555 .56327 .47862 .56467 .48405 .5615 .48099 .55995 Metetra
.763 .866 .924 r
.48099 .55995 .48405 .5615 .48949 .55844 .48645 .55675 Metetra
.754 .856 .925 r
.48645 .55675 .48949 .55844 .49494 .55552 .4919 .5537 Metetra
.746 .845 .925 r
.4919 .5537 .49494 .55552 .50039 .55273 .49736 .55078 Metetra
.737 .836 .926 r
.49736 .55078 .50039 .55273 .50584 .55007 .50283 .54799 Metetra
.728 .826 .925 r
.50283 .54799 .50584 .55007 .51131 .54755 .5083 .54534 Metetra
.72 .815 .924 r
.5083 .54534 .51131 .54755 .51678 .54517 .51379 .54282 Metetra
.711 .803 .922 r
.51379 .54282 .51678 .54517 .52226 .54292 .51927 .54042 Metetra
.702 .792 .92 r
.51927 .54042 .52226 .54292 .52775 .54079 .52477 .53815 Metetra
.694 .781 .917 r
.52477 .53815 .52775 .54079 .53325 .53875 .53028 .536 Metetra
.687 .771 .915 r
.53028 .536 .53325 .53875 .53876 .5368 .5358 .53395 Metetra
.681 .763 .913 r
.5358 .53395 .53876 .5368 .54427 .53492 .54132 .53199 Metetra
.677 .758 .912 r
.54132 .53199 .54427 .53492 .54981 .53308 .54686 .5301 Metetra
.673 .754 .911 r
.54686 .5301 .54981 .53308 .55535 .53127 .55241 .52825 Metetra
.671 .751 .911 r
.55241 .52825 .55535 .53127 .5609 .52949 .55797 .52644 Metetra
.669 .749 .91 r
.55797 .52644 .5609 .52949 .56646 .52772 .56354 .52465 Metetra
.668 .747 .91 r
.56354 .52465 .56646 .52772 .57204 .52598 .56912 .52288 Metetra
.667 .745 .909 r
.56912 .52288 .57204 .52598 .57762 .52424 .57472 .52112 Metetra
.666 .744 .909 r
.57472 .52112 .57762 .52424 .58322 .52252 .58032 .51938 Metetra
.665 .743 .908 r
.58032 .51938 .58322 .52252 .58883 .52079 .58594 .51764 Metetra
.664 .742 .908 r
.58594 .51764 .58883 .52079 .59445 .51907 .59157 .5159 Metetra
.664 .742 .908 r
.59157 .5159 .59445 .51907 .60008 .51735 .5972 .51417 Metetra
.664 .742 .908 r
.5972 .51417 .60008 .51735 .60572 .51562 .60286 .51244 Metetra
.664 .741 .908 r
.60286 .51244 .60572 .51562 .61138 .5139 .60852 .51071 Metetra
.664 .741 .908 r
.60852 .51071 .61138 .5139 .61705 .51217 .61419 .50897 Metetra
.664 .741 .908 r
.61419 .50897 .61705 .51217 .62272 .51043 .61988 .50723 Metetra
.664 .741 .908 r
.61988 .50723 .62272 .51043 .62841 .5087 .62557 .50549 Metetra
.664 .741 .908 r
.62557 .50549 .62841 .5087 .63411 .50696 .63128 .50374 Metetra
.664 .741 .908 r
.63128 .50374 .63411 .50696 .63982 .50522 .637 .50199 Metetra
.664 .741 .908 r
.637 .50199 .63982 .50522 .64555 .50347 .64273 .50024 Metetra
.664 .741 .908 r
.64273 .50024 .64555 .50347 .65128 .50172 .64848 .49848 Metetra
.664 .741 .908 r
.64848 .49848 .65128 .50172 .65703 .49997 .65423 .49672 Metetra
.664 .741 .908 r
.65423 .49672 .65703 .49997 .66279 .49821 .66 .49496 Metetra
.664 .741 .908 r
.66 .49496 .66279 .49821 .66856 .49645 .66578 .49319 Metetra
.664 .741 .908 r
.66578 .49319 .66856 .49645 .67434 .49469 .67157 .49142 Metetra
.664 .741 .908 r
.67157 .49142 .67434 .49469 .68014 .49292 .67737 .48965 Metetra
.664 .741 .908 r
.67737 .48965 .68014 .49292 .68595 .49115 .68319 .48787 Metetra
.663 .741 .908 r
.68319 .48787 .68595 .49115 .69176 .48938 .68901 .48609 Metetra
.663 .741 .908 r
.68901 .48609 .69176 .48938 .69759 .4876 .69485 .48431 Metetra
.663 .741 .908 r
.69485 .48431 .69759 .4876 .70344 .48582 .7007 .48252 Metetra
.663 .741 .908 r
.7007 .48252 .70344 .48582 .70929 .48404 .70657 .48074 Metetra
.663 .741 .908 r
.70657 .48074 .70929 .48404 .71516 .48225 .71244 .47895 Metetra
.662 .742 .909 r
.71244 .47895 .71516 .48225 .72104 .48047 .71833 .47717 Metetra
.662 .742 .909 r
.71833 .47717 .72104 .48047 .72693 .47869 .72423 .47539 Metetra
.661 .742 .91 r
.72423 .47539 .72693 .47869 .73283 .47692 .73014 .47362 Metetra
.661 .742 .911 r
.73014 .47362 .73283 .47692 .73875 .47515 .73607 .47185 Metetra
.659 .743 .912 r
.73607 .47185 .73875 .47515 .74468 .47339 .74201 .4701 Metetra
.658 .743 .913 r
.74201 .4701 .74468 .47339 .75063 .47164 .74797 .46836 Metetra
.655 .743 .915 r
.74797 .46836 .75063 .47164 .75659 .46991 .75394 .46666 Metetra
.652 .744 .917 r
.75394 .46666 .75659 .46991 .76256 .46822 .75992 .46501 Metetra
.647 .746 .921 r
.75992 .46501 .76256 .46822 .76855 .46656 .76593 .46341 Metetra
.641 .748 .926 r
.76593 .46341 .76855 .46656 .77456 .46496 .77195 .46189 Metetra
.634 .751 .932 r
.77195 .46189 .77456 .46496 .78059 .46344 .77799 .46045 Metetra
.626 .754 .939 r
.77799 .46045 .78059 .46344 .78663 .462 .78406 .45909 Metetra
.616 .757 .946 r
.78406 .45909 .78663 .462 .7927 .46065 .79014 .45783 Metetra
.605 .759 .953 r
.79014 .45783 .7927 .46065 .7988 .45941 .79626 .45668 Metetra
.591 .761 .96 r
.79626 .45668 .7988 .45941 .80491 .45828 .80239 .45565 Metetra
.573 .762 .968 r
.80239 .45565 .80491 .45828 .81106 .45726 .80856 .45476 Metetra
.55 .763 .976 r
.80856 .45476 .81106 .45726 .81723 .45638 .81476 .45403 Metetra
.523 .764 .985 r
.81476 .45403 .81723 .45638 .82343 .45564 .82098 .45346 Metetra
.491 .764 .992 r
.82098 .45346 .82343 .45564 .82967 .45506 .82725 .45304 Metetra
.459 .763 .995 r
.82725 .45304 .82967 .45506 .83593 .45462 .83354 .45274 Metetra
.434 .763 .996 r
.83354 .45274 .83593 .45462 .84223 .4543 .83985 .45251 Metetra
.422 .764 .996 r
.83985 .45251 .84223 .4543 .84856 .45407 .84619 .45228 Metetra
.426 .767 .996 r
.84619 .45228 .84856 .45407 .8549 .45386 .85254 .45202 Metetra
.444 .772 .997 r
.85254 .45202 .8549 .45386 .86127 .45363 .85891 .45168 Metetra
.469 .776 .997 r
.85891 .45168 .86127 .45363 .86764 .45331 .86528 .45123 Metetra
.497 .779 .995 r
.86528 .45123 .86764 .45331 .87402 .45287 .87167 .45067 Metetra
.525 .781 .991 r
.87167 .45067 .87402 .45287 .88041 .45229 .87805 .44995 Metetra
.554 .783 .984 r
.87805 .44995 .88041 .45229 .8868 .45154 .88443 .44905 Metetra
.585 .784 .975 r
.88443 .44905 .8868 .45154 .89318 .4506 .8908 .4479 Metetra
.618 .783 .961 r
.8908 .4479 .89318 .4506 .89955 .44941 .89716 .44646 Metetra
.65 .777 .941 r
.89716 .44646 .89955 .44941 .90591 .44796 .90349 .44468 Metetra
.676 .764 .917 r
.90349 .44468 .90591 .44796 .91225 .44619 .9098 .44253 Metetra
.695 .748 .893 r
.9098 .44253 .91225 .44619 .91856 .44408 .91607 .44004 Metetra
.706 .732 .871 r
.91607 .44004 .91856 .44408 .92484 .44164 .92232 .43726 Metetra
.713 .717 .853 r
.92232 .43726 .92484 .44164 .9311 .43889 .92856 .43424 Metetra
.716 .707 .841 r
.92856 .43424 .9311 .43889 .93734 .43589 .93478 .43106 Metetra
.717 .7 .833 r
.93478 .43106 .93734 .43589 .94356 .43271 .941 .42777 Metetra
.718 .697 .829 r
.941 .42777 .94356 .43271 .94978 .4294 .94722 .42442 Metetra
.719 .696 .827 r
.94722 .42442 .94978 .4294 .95599 .42602 .95344 .42102 Metetra
.553 .61 .864 r
.3765 .5898 .3796 .59443 .38477 .59457 .38167 .58985 Metetra
.549 .604 .86 r
.38167 .58985 .38477 .59457 .38996 .5947 .38686 .58997 Metetra
.549 .603 .86 r
.38686 .58997 .38996 .5947 .39516 .59472 .39206 .5901 Metetra
.553 .61 .865 r
.39206 .5901 .39516 .59472 .40039 .59456 .39728 .59015 Metetra
.563 .626 .872 r
.39728 .59015 .40039 .59456 .40564 .59413 .40252 .59004 Metetra
.579 .649 .883 r
.40252 .59004 .40564 .59413 .41091 .5934 .40779 .58965 Metetra
.6 .676 .894 r
.40779 .58965 .41091 .5934 .41621 .59235 .41308 .58894 Metetra
.624 .705 .903 r
.41308 .58894 .41621 .59235 .42153 .59099 .41839 .58788 Metetra
.648 .731 .91 r
.41839 .58788 .42153 .59099 .42687 .58933 .42373 .58646 Metetra
.669 .753 .913 r
.42373 .58646 .42687 .58933 .43222 .58738 .42909 .58474 Metetra
.688 .772 .916 r
.42909 .58474 .43222 .58738 .4376 .58515 .43446 .58273 Metetra
.705 .792 .918 r
.43446 .58273 .4376 .58515 .44299 .58263 .43986 .58046 Metetra
.722 .813 .922 r
.43986 .58046 .44299 .58263 .44839 .57983 .44526 .57794 Metetra
.738 .836 .925 r
.44526 .57794 .44839 .57983 .4538 .57678 .45068 .57516 Metetra
.753 .858 .927 r
.45068 .57516 .4538 .57678 .45923 .57351 .45611 .57214 Metetra
.766 .878 .928 r
.45611 .57214 .45923 .57351 .46466 .57012 .46155 .5689 Metetra
.775 .89 .927 r
.46155 .5689 .46466 .57012 .4701 .56668 .467 .56551 Metetra
.779 .894 .926 r
.467 .56551 .4701 .56668 .47555 .56327 .47246 .56204 Metetra
.778 .89 .925 r
.47246 .56204 .47555 .56327 .48099 .55995 .47792 .55859 Metetra
.773 .881 .925 r
.47792 .55859 .48099 .55995 .48645 .55675 .48338 .55522 Metetra
.765 .868 .924 r
.48338 .55522 .48645 .55675 .4919 .5537 .48885 .55198 Metetra
.755 .855 .924 r
.48885 .55198 .4919 .5537 .49736 .55078 .49433 .54891 Metetra
.745 .843 .925 r
.49433 .54891 .49736 .55078 .50283 .54799 .4998 .54599 Metetra
.735 .833 .925 r
.4998 .54599 .50283 .54799 .5083 .54534 .50529 .54322 Metetra
.727 .823 .925 r
.50529 .54322 .5083 .54534 .51379 .54282 .51078 .54058 Metetra
.719 .814 .924 r
.51078 .54058 .51379 .54282 .51927 .54042 .51628 .53806 Metetra
.711 .804 .923 r
.51628 .53806 .51927 .54042 .52477 .53815 .52179 .53565 Metetra
.703 .793 .921 r
.52179 .53565 .52477 .53815 .53028 .536 .5273 .53337 Metetra
.695 .782 .918 r
.5273 .53337 .53028 .536 .5358 .53395 .53283 .5312 Metetra
.688 .772 .916 r
.53283 .5312 .5358 .53395 .54132 .53199 .53836 .52913 Metetra
.682 .764 .913 r
.53836 .52913 .54132 .53199 .54686 .5301 .54391 .52715 Metetra
.677 .758 .912 r
.54391 .52715 .54686 .5301 .55241 .52825 .54946 .52525 Metetra
.673 .753 .911 r
.54946 .52525 .55241 .52825 .55797 .52644 .55503 .5234 Metetra
.671 .75 .91 r
.55503 .5234 .55797 .52644 .56354 .52465 .56061 .52158 Metetra
.669 .748 .91 r
.56061 .52158 .56354 .52465 .56912 .52288 .5662 .51979 Metetra
.668 .747 .91 r
.5662 .51979 .56912 .52288 .57472 .52112 .5718 .51801 Metetra
.667 .746 .909 r
.5718 .51801 .57472 .52112 .58032 .51938 .57741 .51624 Metetra
.666 .744 .909 r
.57741 .51624 .58032 .51938 .58594 .51764 .58303 .51448 Metetra
.665 .743 .909 r
.58303 .51448 .58594 .51764 .59157 .5159 .58867 .51273 Metetra
.665 .743 .908 r
.58867 .51273 .59157 .5159 .5972 .51417 .59432 .51099 Metetra
.664 .742 .908 r
.59432 .51099 .5972 .51417 .60286 .51244 .59997 .50924 Metetra
.664 .742 .908 r
.59997 .50924 .60286 .51244 .60852 .51071 .60564 .5075 Metetra
.664 .741 .908 r
.60564 .5075 .60852 .51071 .61419 .50897 .61133 .50576 Metetra
.664 .741 .908 r
.61133 .50576 .61419 .50897 .61988 .50723 .61702 .50401 Metetra
.664 .741 .908 r
.61702 .50401 .61988 .50723 .62557 .50549 .62272 .50226 Metetra
.664 .741 .908 r
.62272 .50226 .62557 .50549 .63128 .50374 .62844 .50051 Metetra
.664 .741 .908 r
.62844 .50051 .63128 .50374 .637 .50199 .63417 .49875 Metetra
.664 .741 .908 r
.63417 .49875 .637 .50199 .64273 .50024 .63991 .49699 Metetra
.664 .741 .908 r
.63991 .49699 .64273 .50024 .64848 .49848 .64566 .49523 Metetra
.664 .741 .908 r
.64566 .49523 .64848 .49848 .65423 .49672 .65142 .49347 Metetra
.664 .741 .908 r
.65142 .49347 .65423 .49672 .66 .49496 .6572 .4917 Metetra
.664 .741 .908 r
.6572 .4917 .66 .49496 .66578 .49319 .66298 .48992 Metetra
.664 .741 .908 r
.66298 .48992 .66578 .49319 .67157 .49142 .66878 .48815 Metetra
.664 .741 .908 r
.66878 .48815 .67157 .49142 .67737 .48965 .67459 .48637 Metetra
.664 .741 .908 r
.67459 .48637 .67737 .48965 .68319 .48787 .68042 .48458 Metetra
.663 .741 .908 r
.68042 .48458 .68319 .48787 .68901 .48609 .68625 .48279 Metetra
.663 .741 .908 r
.68625 .48279 .68901 .48609 .69485 .48431 .6921 .48101 Metetra
.663 .741 .908 r
.6921 .48101 .69485 .48431 .7007 .48252 .69796 .47922 Metetra
.663 .741 .909 r
.69796 .47922 .7007 .48252 .70657 .48074 .70383 .47743 Metetra
.662 .742 .909 r
.70383 .47743 .70657 .48074 .71244 .47895 .70972 .47565 Metetra
.662 .742 .909 r
.70972 .47565 .71244 .47895 .71833 .47717 .71561 .47386 Metetra
.662 .742 .91 r
.71561 .47386 .71833 .47717 .72423 .47539 .72152 .47208 Metetra
.661 .742 .91 r
.72152 .47208 .72423 .47539 .73014 .47362 .72744 .47031 Metetra
.66 .742 .911 r
.72744 .47031 .73014 .47362 .73607 .47185 .73338 .46855 Metetra
.658 .743 .912 r
.73338 .46855 .73607 .47185 .74201 .4701 .73933 .46681 Metetra
.655 .743 .914 r
.73933 .46681 .74201 .4701 .74797 .46836 .7453 .46511 Metetra
.652 .744 .918 r
.7453 .46511 .74797 .46836 .75394 .46666 .75128 .46346 Metetra
.647 .746 .922 r
.75128 .46346 .75394 .46666 .75992 .46501 .75728 .46186 Metetra
.641 .749 .927 r
.75728 .46186 .75992 .46501 .76593 .46341 .7633 .46034 Metetra
.634 .752 .933 r
.7633 .46034 .76593 .46341 .77195 .46189 .76934 .45889 Metetra
.627 .755 .939 r
.76934 .45889 .77195 .46189 .77799 .46045 .7754 .45752 Metetra
.618 .757 .945 r
.7754 .45752 .77799 .46045 .78406 .45909 .78148 .45624 Metetra
.607 .758 .951 r
.78148 .45624 .78406 .45909 .79014 .45783 .78758 .45507 Metetra
.592 .76 .958 r
.78758 .45507 .79014 .45783 .79626 .45668 .79371 .45403 Metetra
.573 .761 .967 r
.79371 .45403 .79626 .45668 .80239 .45565 .79987 .45314 Metetra
.548 .762 .977 r
.79987 .45314 .80239 .45565 .80856 .45476 .80606 .45243 Metetra
.518 .764 .986 r
.80606 .45243 .80856 .45476 .81476 .45403 .81229 .45189 Metetra
.484 .764 .993 r
.81229 .45189 .81476 .45403 .82098 .45346 .81854 .45149 Metetra
.454 .765 .996 r
.81854 .45149 .82098 .45346 .82725 .45304 .82483 .45119 Metetra
.433 .765 .996 r
.82483 .45119 .82725 .45304 .83354 .45274 .83113 .45094 Metetra
.427 .766 .996 r
.83113 .45094 .83354 .45274 .83985 .45251 .83746 .45068 Metetra
.436 .769 .997 r
.83746 .45068 .83985 .45251 .84619 .45228 .8438 .45038 Metetra
.453 .771 .997 r
.8438 .45038 .84619 .45228 .85254 .45202 .85016 .45002 Metetra
.473 .773 .996 r
.85016 .45002 .85254 .45202 .85891 .45168 .85653 .44958 Metetra
.493 .775 .995 r
.85653 .44958 .85891 .45168 .86528 .45123 .8629 .44905 Metetra
.515 .779 .992 r
.8629 .44905 .86528 .45123 .87167 .45067 .86929 .44839 Metetra
.543 .784 .988 r
.86929 .44839 .87167 .45067 .87805 .44995 .87567 .44754 Metetra
.578 .789 .979 r
.87567 .44754 .87805 .44995 .88443 .44905 .88204 .44642 Metetra
.616 .788 .964 r
.88204 .44642 .88443 .44905 .8908 .4479 .88839 .44497 Metetra
.652 .779 .941 r
.88839 .44497 .8908 .4479 .89716 .44646 .89471 .44314 Metetra
.679 .764 .915 r
.89471 .44314 .89716 .44646 .90349 .44468 .90101 .44094 Metetra
.697 .745 .888 r
.90101 .44094 .90349 .44468 .9098 .44253 .90728 .4384 Metetra
.706 .727 .867 r
.90728 .4384 .9098 .44253 .91607 .44004 .91352 .43558 Metetra
.711 .714 .851 r
.91352 .43558 .91607 .44004 .92232 .43726 .91976 .43257 Metetra
.714 .705 .84 r
.91976 .43257 .92232 .43726 .92856 .43424 .92599 .42942 Metetra
.716 .701 .835 r
.92599 .42942 .92856 .43424 .93478 .43106 .93221 .42618 Metetra
.718 .699 .831 r
.93221 .42618 .93478 .43106 .941 .42777 .93843 .42286 Metetra
.72 .699 .83 r
.93843 .42286 .941 .42777 .94722 .42442 .94466 .41947 Metetra
.722 .699 .828 r
.94466 .41947 .94722 .42442 .95344 .42102 .95088 .41601 Metetra
.561 .623 .872 r
.37337 .58538 .3765 .5898 .38167 .58985 .37856 .58529 Metetra
.557 .615 .867 r
.37856 .58529 .38167 .58985 .38686 .58997 .38375 .58528 Metetra
.553 .608 .862 r
.38375 .58528 .38686 .58997 .39206 .5901 .38896 .58534 Metetra
.551 .604 .86 r
.38896 .58534 .39206 .5901 .39728 .59015 .39418 .58544 Metetra
.552 .607 .861 r
.39418 .58544 .39728 .59015 .40252 .59004 .39941 .5855 Metetra
.56 .619 .868 r
.39941 .5855 .40252 .59004 .40779 .58965 .40467 .58544 Metetra
.575 .641 .879 r
.40467 .58544 .40779 .58965 .41308 .58894 .40995 .58512 Metetra
.596 .671 .892 r
.40995 .58512 .41308 .58894 .41839 .58788 .41526 .58446 Metetra
.622 .705 .904 r
.41526 .58446 .41839 .58788 .42373 .58646 .42059 .58341 Metetra
.649 .736 .913 r
.42059 .58341 .42373 .58646 .42909 .58474 .42595 .58197 Metetra
.673 .762 .917 r
.42595 .58197 .42909 .58474 .43446 .58273 .43132 .58017 Metetra
.693 .781 .918 r
.43132 .58017 .43446 .58273 .43986 .58046 .43672 .57808 Metetra
.709 .796 .919 r
.43672 .57808 .43986 .58046 .44526 .57794 .44213 .57574 Metetra
.723 .812 .92 r
.44213 .57574 .44526 .57794 .45068 .57516 .44755 .57318 Metetra
.737 .83 .923 r
.44755 .57318 .45068 .57516 .45611 .57214 .45299 .57041 Metetra
.75 .851 .925 r
.45299 .57041 .45611 .57214 .46155 .5689 .45843 .56743 Metetra
.762 .871 .927 r
.45843 .56743 .46155 .5689 .467 .56551 .46389 .56424 Metetra
.772 .887 .927 r
.46389 .56424 .467 .56551 .47246 .56204 .46936 .56087 Metetra
.778 .896 .927 r
.46936 .56087 .47246 .56204 .47792 .55859 .47483 .5574 Metetra
.779 .895 .926 r
.47483 .5574 .47792 .55859 .48338 .55522 .48031 .55391 Metetra
.775 .887 .925 r
.48031 .55391 .48338 .55522 .48885 .55198 .48579 .55049 Metetra
.767 .873 .925 r
.48579 .55049 .48885 .55198 .49433 .54891 .49127 .5472 Metetra
.756 .857 .924 r
.49127 .5472 .49433 .54891 .4998 .54599 .49677 .54409 Metetra
.745 .842 .924 r
.49677 .54409 .4998 .54599 .50529 .54322 .50226 .54116 Metetra
.734 .829 .924 r
.50226 .54116 .50529 .54322 .51078 .54058 .50776 .53839 Metetra
.725 .819 .923 r
.50776 .53839 .51078 .54058 .51628 .53806 .51327 .53577 Metetra
.717 .811 .923 r
.51327 .53577 .51628 .53806 .52179 .53565 .51879 .53326 Metetra
.71 .803 .923 r
.51879 .53326 .52179 .53565 .5273 .53337 .52431 .53086 Metetra
.703 .794 .921 r
.52431 .53086 .5273 .53337 .53283 .5312 .52984 .52857 Metetra
.696 .784 .919 r
.52984 .52857 .53283 .5312 .53836 .52913 .53539 .52638 Metetra
.689 .774 .916 r
.53539 .52638 .53836 .52913 .54391 .52715 .54094 .52429 Metetra
.682 .765 .914 r
.54094 .52429 .54391 .52715 .54946 .52525 .5465 .52229 Metetra
.677 .758 .912 r
.5465 .52229 .54946 .52525 .55503 .5234 .55208 .52037 Metetra
.673 .753 .911 r
.55208 .52037 .55503 .5234 .56061 .52158 .55766 .51851 Metetra
.67 .749 .91 r
.55766 .51851 .56061 .52158 .5662 .51979 .56326 .51669 Metetra
.668 .747 .91 r
.56326 .51669 .5662 .51979 .5718 .51801 .56887 .51489 Metetra
.667 .746 .909 r
.56887 .51489 .5718 .51801 .57741 .51624 .57449 .51311 Metetra
.666 .745 .909 r
.57449 .51311 .57741 .51624 .58303 .51448 .58012 .51133 Metetra
.666 .745 .909 r
.58012 .51133 .58303 .51448 .58867 .51273 .58576 .50956 Metetra
.665 .744 .909 r
.58576 .50956 .58867 .51273 .59432 .51099 .59142 .5078 Metetra
.665 .743 .908 r
.59142 .5078 .59432 .51099 .59997 .50924 .59708 .50604 Metetra
.664 .742 .908 r
.59708 .50604 .59997 .50924 .60564 .5075 .60276 .50429 Metetra
.664 .742 .908 r
.60276 .50429 .60564 .5075 .61133 .50576 .60845 .50254 Metetra
.664 .741 .908 r
.60845 .50254 .61133 .50576 .61702 .50401 .61415 .50078 Metetra
.664 .741 .908 r
.61415 .50078 .61702 .50401 .62272 .50226 .61986 .49903 Metetra
.664 .741 .908 r
.61986 .49903 .62272 .50226 .62844 .50051 .62559 .49727 Metetra
.664 .741 .908 r
.62559 .49727 .62844 .50051 .63417 .49875 .63132 .49551 Metetra
.664 .741 .908 r
.63132 .49551 .63417 .49875 .63991 .49699 .63707 .49374 Metetra
.664 .741 .908 r
.63707 .49374 .63991 .49699 .64566 .49523 .64283 .49197 Metetra
.664 .741 .908 r
.64283 .49197 .64566 .49523 .65142 .49347 .6486 .4902 Metetra
.664 .741 .908 r
.6486 .4902 .65142 .49347 .6572 .4917 .65439 .48842 Metetra
.664 .741 .908 r
.65439 .48842 .6572 .4917 .66298 .48992 .66018 .48664 Metetra
.664 .741 .908 r
.66018 .48664 .66298 .48992 .66878 .48815 .66599 .48486 Metetra
.664 .741 .908 r
.66599 .48486 .66878 .48815 .67459 .48637 .67181 .48307 Metetra
.663 .741 .908 r
.67181 .48307 .67459 .48637 .68042 .48458 .67764 .48128 Metetra
.663 .741 .908 r
.67764 .48128 .68042 .48458 .68625 .48279 .68348 .47949 Metetra
.663 .741 .908 r
.68348 .47949 .68625 .48279 .6921 .48101 .68934 .4777 Metetra
.663 .742 .909 r
.68934 .4777 .6921 .48101 .69796 .47922 .6952 .47591 Metetra
.662 .742 .909 r
.6952 .47591 .69796 .47922 .70383 .47743 .70109 .47412 Metetra
.662 .742 .909 r
.70109 .47412 .70383 .47743 .70972 .47565 .70698 .47233 Metetra
.662 .742 .91 r
.70698 .47233 .70972 .47565 .71561 .47386 .71288 .47054 Metetra
.661 .742 .91 r
.71288 .47054 .71561 .47386 .72152 .47208 .7188 .46876 Metetra
.66 .742 .911 r
.7188 .46876 .72152 .47208 .72744 .47031 .72473 .467 Metetra
.658 .742 .912 r
.72473 .467 .72744 .47031 .73338 .46855 .73068 .46526 Metetra
.655 .743 .915 r
.73068 .46526 .73338 .46855 .73933 .46681 .73664 .46356 Metetra
.651 .745 .918 r
.73664 .46356 .73933 .46681 .7453 .46511 .74262 .46191 Metetra
.646 .747 .923 r
.74262 .46191 .7453 .46511 .75128 .46346 .74862 .46032 Metetra
.641 .75 .928 r
.74862 .46032 .75128 .46346 .75728 .46186 .75463 .45879 Metetra
.635 .752 .933 r
.75463 .45879 .75728 .46186 .7633 .46034 .76067 .45733 Metetra
.628 .754 .938 r
.76067 .45733 .7633 .46034 .76934 .45889 .76672 .45594 Metetra
.62 .756 .943 r
.76672 .45594 .76934 .45889 .7754 .45752 .77279 .45463 Metetra
.608 .757 .949 r
.77279 .45463 .7754 .45752 .78148 .45624 .77889 .45344 Metetra
.593 .758 .957 r
.77889 .45344 .78148 .45624 .78758 .45507 .78501 .45241 Metetra
.571 .759 .967 r
.78501 .45241 .78758 .45507 .79371 .45403 .79117 .45154 Metetra
.543 .762 .978 r
.79117 .45154 .79371 .45403 .79987 .45314 .79736 .45086 Metetra
.511 .765 .988 r
.79736 .45086 .79987 .45314 .80606 .45243 .80358 .45034 Metetra
.478 .766 .994 r
.80358 .45034 .80606 .45243 .81229 .45189 .80983 .44995 Metetra
.452 .767 .997 r
.80983 .44995 .81229 .45189 .81854 .45149 .8161 .44963 Metetra
.439 .768 .997 r
.8161 .44963 .81854 .45149 .82483 .45119 .8224 .44933 Metetra
.44 .769 .997 r
.8224 .44933 .82483 .45119 .83113 .45094 .82871 .44903 Metetra
.449 .769 .997 r
.82871 .44903 .83113 .45094 .83746 .45068 .83504 .44869 Metetra
.46 .769 .996 r
.83504 .44869 .83746 .45068 .8438 .45038 .84139 .44833 Metetra
.471 .769 .996 r
.84139 .44833 .8438 .45038 .85016 .45002 .84776 .44794 Metetra
.482 .772 .995 r
.84776 .44794 .85016 .45002 .85653 .44958 .85413 .44747 Metetra
.5 .779 .995 r
.85413 .44747 .85653 .44958 .8629 .44905 .86052 .44688 Metetra
.531 .788 .992 r
.86052 .44688 .8629 .44905 .86929 .44839 .8669 .44607 Metetra
.573 .795 .983 r
.8669 .44607 .86929 .44839 .87567 .44754 .87326 .44495 Metetra
.619 .793 .965 r
.87326 .44495 .87567 .44754 .88204 .44642 .8796 .44345 Metetra
.657 .78 .939 r
.8796 .44345 .88204 .44642 .88839 .44497 .88592 .44156 Metetra
.683 .759 .909 r
.88592 .44156 .88839 .44497 .89471 .44314 .8922 .43928 Metetra
.698 .739 .883 r
.8922 .43928 .89471 .44314 .90101 .44094 .89846 .4367 Metetra
.705 .722 .863 r
.89846 .4367 .90101 .44094 .90728 .4384 .90471 .43389 Metetra
.709 .711 .85 r
.90471 .43389 .90728 .4384 .91352 .43558 .91095 .43092 Metetra
.712 .705 .842 r
.91095 .43092 .91352 .43558 .91976 .43257 .91718 .42783 Metetra
.715 .704 .838 r
.91718 .42783 .91976 .43257 .92599 .42942 .92341 .42464 Metetra
.718 .704 .835 r
.92341 .42464 .92599 .42942 .93221 .42618 .92964 .42134 Metetra
.722 .703 .832 r
.92964 .42134 .93221 .42618 .93843 .42286 .93586 .41793 Metetra
.724 .701 .828 r
.93586 .41793 .93843 .42286 .94466 .41947 .94208 .41442 Metetra
.724 .697 .823 r
.94208 .41442 .94466 .41947 .95088 .41601 .9483 .41086 Metetra
.563 .631 .877 r
.37023 .58108 .37337 .58538 .37856 .58529 .37542 .58094 Metetra
.561 .628 .875 r
.37542 .58094 .37856 .58529 .38375 .58528 .38062 .58082 Metetra
.56 .622 .871 r
.38062 .58082 .38375 .58528 .38896 .58534 .38584 .58074 Metetra
.557 .615 .866 r
.38584 .58074 .38896 .58534 .39418 .58544 .39106 .58071 Metetra
.555 .608 .861 r
.39106 .58071 .39418 .58544 .39941 .5855 .39631 .58074 Metetra
.555 .607 .86 r
.39631 .58074 .39941 .5855 .40467 .58544 .40156 .58078 Metetra
.559 .614 .864 r
.40156 .58078 .40467 .58544 .40995 .58512 .40684 .58073 Metetra
.571 .632 .874 r
.40684 .58073 .40995 .58512 .41526 .58446 .41213 .58049 Metetra
.59 .662 .888 r
.41213 .58049 .41526 .58446 .42059 .58341 .41745 .57992 Metetra
.617 .699 .903 r
.41745 .57992 .42059 .58341 .42595 .58197 .4228 .57893 Metetra
.647 .738 .915 r
.4228 .57893 .42595 .58197 .43132 .58017 .42817 .5775 Metetra
.676 .77 .922 r
.42817 .5775 .43132 .58017 .43672 .57808 .43357 .57566 Metetra
.699 .793 .923 r
.43357 .57566 .43672 .57808 .44213 .57574 .43898 .57347 Metetra
.716 .807 .922 r
.43898 .57347 .44213 .57574 .44755 .57318 .44441 .57102 Metetra
.728 .817 .92 r
.44441 .57102 .44755 .57318 .45299 .57041 .44985 .56838 Metetra
.738 .828 .921 r
.44985 .56838 .45299 .57041 .45843 .56743 .45531 .56559 Metetra
.748 .843 .923 r
.45531 .56559 .45843 .56743 .46389 .56424 .46077 .56263 Metetra
.758 .862 .925 r
.46077 .56263 .46389 .56424 .46936 .56087 .46624 .55949 Metetra
.768 .88 .927 r
.46624 .55949 .46936 .56087 .47483 .5574 .47172 .55619 Metetra
.775 .893 .927 r
.47172 .55619 .47483 .5574 .48031 .55391 .47721 .55275 Metetra
.779 .898 .927 r
.47721 .55275 .48031 .55391 .48579 .55049 .48271 .54925 Metetra
.777 .893 .926 r
.48271 .54925 .48579 .55049 .49127 .5472 .48821 .54578 Metetra
.77 .88 .926 r
.48821 .54578 .49127 .5472 .49677 .54409 .49371 .54243 Metetra
.759 .862 .925 r
.49371 .54243 .49677 .54409 .50226 .54116 .49922 .53926 Metetra
.747 .843 .924 r
.49922 .53926 .50226 .54116 .50776 .53839 .50473 .53629 Metetra
.734 .827 .922 r
.50473 .53629 .50776 .53839 .51327 .53577 .51025 .53352 Metetra
.724 .815 .922 r
.51025 .53352 .51327 .53577 .51879 .53326 .51577 .5309 Metetra
.715 .807 .922 r
.51577 .5309 .51879 .53326 .52431 .53086 .52131 .52842 Metetra
.708 .8 .922 r
.52131 .52842 .52431 .53086 .52984 .52857 .52685 .52604 Metetra
.702 .793 .921 r
.52685 .52604 .52984 .52857 .53539 .52638 .5324 .52375 Metetra
.696 .785 .92 r
.5324 .52375 .53539 .52638 .54094 .52429 .53796 .52155 Metetra
.689 .776 .917 r
.53796 .52155 .54094 .52429 .5465 .52229 .54353 .51944 Metetra
.683 .767 .915 r
.54353 .51944 .5465 .52229 .55208 .52037 .54912 .51741 Metetra
.678 .759 .912 r
.54912 .51741 .55208 .52037 .55766 .51851 .55471 .51547 Metetra
.673 .753 .911 r
.55471 .51547 .55766 .51851 .56326 .51669 .56031 .51359 Metetra
.67 .749 .91 r
.56031 .51359 .56326 .51669 .56887 .51489 .56593 .51176 Metetra
.668 .747 .909 r
.56593 .51176 .56887 .51489 .57449 .51311 .57156 .50996 Metetra
.667 .745 .909 r
.57156 .50996 .57449 .51311 .58012 .51133 .5772 .50817 Metetra
.666 .745 .909 r
.5772 .50817 .58012 .51133 .58576 .50956 .58285 .50639 Metetra
.666 .744 .909 r
.58285 .50639 .58576 .50956 .59142 .5078 .58851 .50462 Metetra
.665 .744 .909 r
.58851 .50462 .59142 .5078 .59708 .50604 .59418 .50284 Metetra
.665 .743 .909 r
.59418 .50284 .59708 .50604 .60276 .50429 .59987 .50107 Metetra
.664 .742 .908 r
.59987 .50107 .60276 .50429 .60845 .50254 .60556 .49931 Metetra
.664 .742 .908 r
.60556 .49931 .60845 .50254 .61415 .50078 .61127 .49754 Metetra
.664 .741 .908 r
.61127 .49754 .61415 .50078 .61986 .49903 .61699 .49578 Metetra
.664 .741 .908 r
.61699 .49578 .61986 .49903 .62559 .49727 .62272 .49401 Metetra
.664 .741 .908 r
.62272 .49401 .62559 .49727 .63132 .49551 .62847 .49224 Metetra
.664 .741 .908 r
.62847 .49224 .63132 .49551 .63707 .49374 .63422 .49047 Metetra
.664 .741 .908 r
.63422 .49047 .63707 .49374 .64283 .49197 .63999 .48869 Metetra
.664 .741 .908 r
.63999 .48869 .64283 .49197 .6486 .4902 .64577 .48691 Metetra
.664 .741 .908 r
.64577 .48691 .6486 .4902 .65439 .48842 .65156 .48513 Metetra
.664 .741 .908 r
.65156 .48513 .65439 .48842 .66018 .48664 .65737 .48334 Metetra
.663 .741 .908 r
.65737 .48334 .66018 .48664 .66599 .48486 .66318 .48155 Metetra
.663 .741 .908 r
.66318 .48155 .66599 .48486 .67181 .48307 .66901 .47976 Metetra
.663 .741 .908 r
.66901 .47976 .67181 .48307 .67764 .48128 .67485 .47797 Metetra
.663 .741 .908 r
.67485 .47797 .67764 .48128 .68348 .47949 .6807 .47618 Metetra
.663 .742 .909 r
.6807 .47618 .68348 .47949 .68934 .4777 .68656 .47438 Metetra
.663 .742 .909 r
.68656 .47438 .68934 .4777 .6952 .47591 .69244 .47259 Metetra
.662 .742 .909 r
.69244 .47259 .6952 .47591 .70109 .47412 .69833 .47079 Metetra
.662 .742 .909 r
.69833 .47079 .70109 .47412 .70698 .47233 .70423 .469 Metetra
.661 .742 .91 r
.70423 .469 .70698 .47233 .71288 .47054 .71015 .46721 Metetra
.66 .742 .911 r
.71015 .46721 .71288 .47054 .7188 .46876 .71607 .46544 Metetra
.657 .742 .912 r
.71607 .46544 .7188 .46876 .72473 .467 .72202 .46371 Metetra
.654 .743 .915 r
.72202 .46371 .72473 .467 .73068 .46526 .72798 .46202 Metetra
.65 .745 .919 r
.72798 .46202 .73068 .46526 .73664 .46356 .73395 .46037 Metetra
.646 .748 .923 r
.73395 .46037 .73664 .46356 .74262 .46191 .73994 .45878 Metetra
.642 .751 .928 r
.73994 .45878 .74262 .46191 .74862 .46032 .74595 .45724 Metetra
.637 .752 .932 r
.74595 .45724 .74862 .46032 .75463 .45879 .75198 .45575 Metetra
.631 .753 .936 r
.75198 .45575 .75463 .45879 .76067 .45733 .75802 .45433 Metetra
.622 .754 .941 r
.75802 .45433 .76067 .45733 .76672 .45594 .76409 .453 Metetra
.609 .754 .947 r
.76409 .453 .76672 .45594 .77279 .45463 .77018 .45182 Metetra
.591 .756 .957 r
.77018 .45182 .77279 .45463 .77889 .45344 .7763 .4508 Metetra
.566 .759 .969 r
.7763 .4508 .77889 .45344 .78501 .45241 .78246 .44996 Metetra
.536 .763 .981 r
.78246 .44996 .78501 .45241 .79117 .45154 .78864 .44931 Metetra
.503 .767 .99 r
.78864 .44931 .79117 .45154 .79736 .45086 .79485 .44881 Metetra
.475 .769 .995 r
.79485 .44881 .79736 .45086 .80358 .45034 .80109 .4484 Metetra
.457 .77 .997 r
.80109 .4484 .80358 .45034 .80983 .44995 .80736 .44803 Metetra
.453 .771 .997 r
.80736 .44803 .80983 .44995 .8161 .44963 .81364 .44768 Metetra
.456 .769 .997 r
.81364 .44768 .8161 .44963 .8224 .44933 .81994 .44732 Metetra
.46 .767 .996 r
.81994 .44732 .8224 .44933 .82871 .44903 .82626 .44698 Metetra
.461 .764 .995 r
.82626 .44698 .82871 .44903 .83504 .44869 .83261 .44666 Metetra
.459 .764 .996 r
.83261 .44666 .83504 .44869 .84139 .44833 .83897 .44634 Metetra
.462 .77 .996 r
.83897 .44634 .84139 .44833 .84776 .44794 .84535 .44596 Metetra
.48 .781 .997 r
.84535 .44596 .84776 .44794 .85413 .44747 .85173 .44543 Metetra
.519 .794 .996 r
.85173 .44543 .85413 .44747 .86052 .44688 .85811 .44463 Metetra
.573 .801 .986 r
.85811 .44463 .86052 .44688 .8669 .44607 .86446 .44346 Metetra
.626 .794 .963 r
.86446 .44346 .8669 .44607 .87326 .44495 .87079 .44188 Metetra
.664 .775 .932 r
.87079 .44188 .87326 .44495 .8796 .44345 .87709 .43989 Metetra
.686 .751 .901 r
.87709 .43989 .8796 .44345 .88592 .44156 .88337 .43756 Metetra
.697 .731 .877 r
.88337 .43756 .88592 .44156 .8922 .43928 .88963 .43497 Metetra
.702 .717 .861 r
.88963 .43497 .8922 .43928 .89846 .4367 .89588 .43221 Metetra
.706 .711 .852 r
.89588 .43221 .89846 .4367 .90471 .43389 .90212 .42932 Metetra
.71 .709 .847 r
.90212 .42932 .90471 .43389 .91095 .43092 .90837 .42631 Metetra
.715 .71 .844 r
.90837 .42631 .91095 .43092 .91718 .42783 .9146 .42316 Metetra
.72 .71 .839 r
.9146 .42316 .91718 .42783 .92341 .42464 .92083 .41985 Metetra
.725 .707 .833 r
.92083 .41985 .92341 .42464 .92964 .42134 .92705 .41638 Metetra
.727 .701 .826 r
.92705 .41638 .92964 .42134 .93586 .41793 .93325 .41278 Metetra
.726 .694 .819 r
.93325 .41278 .93586 .41793 .94208 .41442 .93946 .40914 Metetra
.722 .687 .816 r
.93946 .40914 .94208 .41442 .9483 .41086 .94568 .40552 Metetra
.56 .625 .873 r
.36709 .57667 .37023 .58108 .37542 .58094 .37228 .57657 Metetra
.558 .626 .876 r
.37228 .57657 .37542 .58094 .38062 .58082 .37748 .57649 Metetra
.559 .629 .877 r
.37748 .57649 .38062 .58082 .38584 .58074 .3827 .57638 Metetra
.561 .629 .876 r
.3827 .57638 .38584 .58074 .39106 .58071 .38793 .57625 Metetra
.562 .624 .872 r
.38793 .57625 .39106 .58071 .39631 .58074 .39318 .57613 Metetra
.561 .617 .866 r
.39318 .57613 .39631 .58074 .40156 .58078 .39844 .57605 Metetra
.56 .611 .861 r
.39844 .57605 .40156 .58078 .40684 .58073 .40372 .576 Metetra
.561 .612 .861 r
.40372 .576 .40684 .58073 .41213 .58049 .40901 .57593 Metetra
.568 .624 .867 r
.40901 .57593 .41213 .58049 .41745 .57992 .41433 .57574 Metetra
.584 .649 .88 r
.41433 .57574 .41745 .57992 .4228 .57893 .41966 .57527 Metetra
.61 .687 .898 r
.41966 .57527 .4228 .57893 .42817 .5775 .42502 .57439 Metetra
.642 .732 .915 r
.42502 .57439 .42817 .5775 .43357 .57566 .43041 .57303 Metetra
.675 .774 .925 r
.43041 .57303 .43357 .57566 .43898 .57347 .43583 .57119 Metetra
.703 .805 .928 r
.43583 .57119 .43898 .57347 .44441 .57102 .44126 .56893 Metetra
.723 .822 .926 r
.44126 .56893 .44441 .57102 .44985 .56838 .44671 .56636 Metetra
.735 .829 .923 r
.44671 .56636 .44985 .56838 .45531 .56559 .45217 .56359 Metetra
.742 .832 .92 r
.45217 .56359 .45531 .56559 .46077 .56263 .45764 .56071 Metetra
.748 .839 .92 r
.45764 .56071 .46077 .56263 .46624 .55949 .46312 .55773 Metetra
.755 .851 .922 r
.46312 .55773 .46624 .55949 .47172 .55619 .46861 .55464 Metetra
.763 .868 .925 r
.46861 .55464 .47172 .55619 .47721 .55275 .4741 .55141 Metetra
.771 .885 .928 r
.4741 .55141 .47721 .55275 .48271 .54925 .47961 .54804 Metetra
.776 .896 .928 r
.47961 .54804 .48271 .54925 .48821 .54578 .48512 .54458 Metetra
.777 .897 .928 r
.48512 .54458 .48821 .54578 .49371 .54243 .49064 .5411 Metetra
.773 .887 .927 r
.49064 .5411 .49371 .54243 .49922 .53926 .49616 .5377 Metetra
.763 .87 .926 r
.49616 .5377 .49922 .53926 .50473 .53629 .50168 .53445 Metetra
.75 .849 .924 r
.50168 .53445 .50473 .53629 .51025 .53352 .50721 .53141 Metetra
.736 .829 .922 r
.50721 .53141 .51025 .53352 .51577 .5309 .51275 .5286 Metetra
.723 .813 .921 r
.51275 .5286 .51577 .5309 .52131 .52842 .51829 .52598 Metetra
.713 .802 .92 r
.51829 .52598 .52131 .52842 .52685 .52604 .52385 .52351 Metetra
.705 .795 .92 r
.52385 .52351 .52685 .52604 .5324 .52375 .52941 .52116 Metetra
.7 .79 .92 r
.52941 .52116 .5324 .52375 .53796 .52155 .53498 .51889 Metetra
.695 .784 .92 r
.53498 .51889 .53796 .52155 .54353 .51944 .54055 .51669 Metetra
.69 .777 .918 r
.54055 .51669 .54353 .51944 .54912 .51741 .54614 .51457 Metetra
.684 .77 .916 r
.54614 .51457 .54912 .51741 .55471 .51547 .55174 .51252 Metetra
.679 .762 .913 r
.55174 .51252 .55471 .51547 .56031 .51359 .55736 .51055 Metetra
.674 .755 .911 r
.55736 .51055 .56031 .51359 .56593 .51176 .56298 .50865 Metetra
.671 .749 .91 r
.56298 .50865 .56593 .51176 .57156 .50996 .56861 .5068 Metetra
.668 .746 .909 r
.56861 .5068 .57156 .50996 .5772 .50817 .57426 .50499 Metetra
.666 .744 .909 r
.57426 .50499 .5772 .50817 .58285 .50639 .57992 .5032 Metetra
.666 .744 .909 r
.57992 .5032 .58285 .50639 .58851 .50462 .58559 .50142 Metetra
.665 .744 .909 r
.58559 .50142 .58851 .50462 .59418 .50284 .59127 .49964 Metetra
.665 .744 .909 r
.59127 .49964 .59418 .50284 .59987 .50107 .59696 .49786 Metetra
.665 .743 .909 r
.59696 .49786 .59987 .50107 .60556 .49931 .60267 .49608 Metetra
.664 .743 .908 r
.60267 .49608 .60556 .49931 .61127 .49754 .60838 .4943 Metetra
.664 .742 .908 r
.60838 .4943 .61127 .49754 .61699 .49578 .61411 .49252 Metetra
.664 .742 .908 r
.61411 .49252 .61699 .49578 .62272 .49401 .61985 .49074 Metetra
.664 .741 .908 r
.61985 .49074 .62272 .49401 .62847 .49224 .6256 .48897 Metetra
.664 .741 .908 r
.6256 .48897 .62847 .49224 .63422 .49047 .63137 .48719 Metetra
.664 .741 .908 r
.63137 .48719 .63422 .49047 .63999 .48869 .63714 .4854 Metetra
.664 .741 .908 r
.63714 .4854 .63999 .48869 .64577 .48691 .64293 .48362 Metetra
.663 .741 .908 r
.64293 .48362 .64577 .48691 .65156 .48513 .64873 .48183 Metetra
.663 .741 .908 r
.64873 .48183 .65156 .48513 .65737 .48334 .65454 .48004 Metetra
.663 .741 .908 r
.65454 .48004 .65737 .48334 .66318 .48155 .66036 .47824 Metetra
.663 .742 .908 r
.66036 .47824 .66318 .48155 .66901 .47976 .6662 .47645 Metetra
.663 .742 .909 r
.6662 .47645 .66901 .47976 .67485 .47797 .67205 .47465 Metetra
.663 .742 .909 r
.67205 .47465 .67485 .47797 .6807 .47618 .67791 .47285 Metetra
.663 .742 .909 r
.67791 .47285 .6807 .47618 .68656 .47438 .68378 .47105 Metetra
.663 .742 .909 r
.68378 .47105 .68656 .47438 .69244 .47259 .68966 .46925 Metetra
.662 .741 .909 r
.68966 .46925 .69244 .47259 .69833 .47079 .69556 .46745 Metetra
.661 .741 .909 r
.69556 .46745 .69833 .47079 .70423 .469 .70147 .46566 Metetra
.659 .742 .911 r
.70147 .46566 .70423 .469 .71015 .46721 .7074 .4639 Metetra
.657 .743 .913 r
.7074 .4639 .71015 .46721 .71607 .46544 .71334 .46217 Metetra
.653 .744 .916 r
.71334 .46217 .71607 .46544 .72202 .46371 .71929 .46048 Metetra
.65 .747 .92 r
.71929 .46048 .72202 .46371 .72798 .46202 .72526 .45884 Metetra
.647 .749 .924 r
.72526 .45884 .72798 .46202 .73395 .46037 .73125 .45723 Metetra
.643 .751 .927 r
.73125 .45723 .73395 .46037 .73994 .45878 .73725 .45566 Metetra
.639 .751 .93 r
.73725 .45566 .73994 .45878 .74595 .45724 .74327 .45414 Metetra
.633 .751 .933 r
.74327 .45414 .74595 .45724 .75198 .45575 .74931 .4527 Metetra
.623 .751 .938 r
.74931 .4527 .75198 .45575 .75802 .45433 .75537 .45137 Metetra
.608 .752 .947 r
.75537 .45137 .75802 .45433 .76409 .453 .76146 .4502 Metetra
.586 .756 .959 r
.76146 .4502 .76409 .453 .77018 .45182 .76758 .44922 Metetra
.559 .761 .972 r
.76758 .44922 .77018 .45182 .7763 .4508 .77373 .44843 Metetra
.528 .767 .984 r
.77373 .44843 .7763 .4508 .78246 .44996 .77991 .4478 Metetra
.5 .771 .992 r
.77991 .4478 .78246 .44996 .78864 .44931 .78611 .44728 Metetra
.48 .773 .996 r
.78611 .44728 .78864 .44931 .79485 .44881 .79234 .44682 Metetra
.472 .774 .997 r
.79234 .44682 .79485 .44881 .80109 .4484 .79859 .44638 Metetra
.472 .771 .996 r
.79859 .44638 .80109 .4484 .80736 .44803 .80486 .44595 Metetra
.471 .766 .995 r
.80486 .44595 .80736 .44803 .81364 .44768 .81115 .44558 Metetra
.464 .761 .994 r
.81115 .44558 .81364 .44768 .81994 .44732 .81747 .44527 Metetra
.449 .758 .995 r
.81747 .44527 .81994 .44732 .82626 .44698 .82381 .44503 Metetra
.433 .759 .996 r
.82381 .44503 .82626 .44698 .83261 .44666 .83018 .44482 Metetra
.431 .768 .997 r
.83018 .44482 .83261 .44666 .83897 .44634 .83656 .44452 Metetra
.458 .785 .999 r
.83656 .44452 .83897 .44634 .84535 .44596 .84294 .44402 Metetra
.515 .802 .998 r
.84294 .44402 .84535 .44596 .85173 .44543 .8493 .44317 Metetra
.584 .806 .984 r
.8493 .44317 .85173 .44543 .85811 .44463 .85564 .4419 Metetra
.638 .79 .955 r
.85564 .4419 .85811 .44463 .86446 .44346 .86196 .4402 Metetra
.671 .765 .921 r
.86196 .4402 .86446 .44346 .87079 .44188 .86824 .43813 Metetra
.686 .741 .893 r
.86824 .43813 .87079 .44188 .87709 .43989 .87451 .43579 Metetra
.693 .724 .874 r
.87451 .43579 .87709 .43989 .88337 .43756 .88078 .43326 Metetra
.697 .716 .863 r
.88078 .43326 .88337 .43756 .88963 .43497 .88704 .4306 Metetra
.702 .715 .859 r
.88704 .4306 .88963 .43497 .89588 .43221 .8933 .42782 Metetra
.709 .717 .856 r
.8933 .42782 .89588 .43221 .90212 .42932 .89955 .42487 Metetra
.717 .718 .85 r
.89955 .42487 .90212 .42932 .90837 .42631 .90579 .42172 Metetra
.724 .715 .842 r
.90579 .42172 .90837 .42631 .9146 .42316 .912 .41834 Metetra
.728 .707 .831 r
.912 .41834 .9146 .42316 .92083 .41985 .91821 .41477 Metetra
.729 .697 .82 r
.91821 .41477 .92083 .41985 .92705 .41638 .9244 .41106 Metetra
.726 .688 .813 r
.9244 .41106 .92705 .41638 .93325 .41278 .9306 .40734 Metetra
.721 .681 .811 r
.9306 .40734 .93325 .41278 .93946 .40914 .93682 .4037 Metetra
.715 .679 .814 r
.93682 .4037 .93946 .40914 .94568 .40552 .94307 .40022 Metetra
.563 .619 .866 r
.36394 .57211 .36709 .57667 .37228 .57657 .36914 .57198 Metetra
.554 .615 .867 r
.36914 .57198 .37228 .57657 .37748 .57649 .37434 .57197 Metetra
.551 .617 .872 r
.37434 .57197 .37748 .57649 .3827 .57638 .37955 .57199 Metetra
.553 .624 .877 r
.37955 .57199 .3827 .57638 .38793 .57625 .38479 .57195 Metetra
.559 .632 .88 r
.38479 .57195 .38793 .57625 .39318 .57613 .39004 .57183 Metetra
.564 .634 .879 r
.39004 .57183 .39318 .57613 .39844 .57605 .39531 .57164 Metetra
.567 .63 .874 r
.39531 .57164 .39844 .57605 .40372 .576 .40059 .57142 Metetra
.568 .623 .867 r
.40059 .57142 .40372 .576 .40901 .57593 .40589 .57123 Metetra
.567 .617 .862 r
.40589 .57123 .40901 .57593 .41433 .57574 .41121 .57106 Metetra
.57 .62 .863 r
.41121 .57106 .41433 .57574 .41966 .57527 .41654 .57085 Metetra
.58 .637 .872 r
.41654 .57085 .41966 .57527 .42502 .57439 .42189 .57046 Metetra
.601 .67 .889 r
.42189 .57046 .42502 .57439 .43041 .57303 .42726 .56972 Metetra
.632 .718 .909 r
.42726 .56972 .43041 .57303 .43583 .57119 .43266 .5685 Metetra
.668 .77 .926 r
.43266 .5685 .43583 .57119 .44126 .56893 .43809 .56674 Metetra
.703 .813 .933 r
.43809 .56674 .44126 .56893 .44671 .56636 .44354 .56447 Metetra
.729 .839 .932 r
.44354 .56447 .44671 .56636 .45217 .56359 .44901 .56179 Metetra
.744 .847 .927 r
.44901 .56179 .45217 .56359 .45764 .56071 .4545 .55887 Metetra
.751 .845 .922 r
.4545 .55887 .45764 .56071 .46312 .55773 .45999 .55584 Metetra
.753 .842 .919 r
.45999 .55584 .46312 .55773 .46861 .55464 .46548 .55277 Metetra
.754 .844 .919 r
.46548 .55277 .46861 .55464 .4741 .55141 .47099 .54967 Metetra
.758 .855 .922 r
.47099 .54967 .4741 .55141 .47961 .54804 .4765 .5465 Metetra
.764 .871 .926 r
.4765 .5465 .47961 .54804 .48512 .54458 .48202 .54324 Metetra
.77 .887 .928 r
.48202 .54324 .48512 .54458 .49064 .5411 .48755 .53987 Metetra
.774 .895 .929 r
.48755 .53987 .49064 .5411 .49616 .5377 .49308 .53642 Metetra
.773 .893 .929 r
.49308 .53642 .49616 .5377 .50168 .53445 .49862 .53299 Metetra
.766 .88 .928 r
.49862 .53299 .50168 .53445 .50721 .53141 .50416 .52968 Metetra
.755 .859 .926 r
.50416 .52968 .50721 .53141 .51275 .5286 .50971 .52655 Metetra
.74 .835 .923 r
.50971 .52655 .51275 .5286 .51829 .52598 .51527 .52367 Metetra
.725 .814 .92 r
.51527 .52367 .51829 .52598 .52385 .52351 .52083 .52101 Metetra
.712 .798 .918 r
.52083 .52101 .52385 .52351 .52941 .52116 .5264 .51854 Metetra
.703 .789 .918 r
.5264 .51854 .52941 .52116 .53498 .51889 .53197 .51622 Metetra
.697 .784 .918 r
.53197 .51622 .53498 .51889 .54055 .51669 .53756 .51398 Metetra
.693 .781 .919 r
.53756 .51398 .54055 .51669 .54614 .51457 .54316 .51181 Metetra
.689 .777 .918 r
.54316 .51181 .54614 .51457 .55174 .51252 .54877 .50969 Metetra
.685 .771 .917 r
.54877 .50969 .55174 .51252 .55736 .51055 .55439 .50762 Metetra
.68 .764 .915 r
.55439 .50762 .55736 .51055 .56298 .50865 .56002 .50563 Metetra
.676 .757 .912 r
.56002 .50563 .56298 .50865 .56861 .5068 .56566 .50369 Metetra
.672 .751 .91 r
.56566 .50369 .56861 .5068 .57426 .50499 .57131 .50182 Metetra
.668 .747 .909 r
.57131 .50182 .57426 .50499 .57992 .5032 .57698 .49999 Metetra
.666 .744 .908 r
.57698 .49999 .57992 .5032 .58559 .50142 .58266 .4982 Metetra
.665 .743 .908 r
.58266 .4982 .58559 .50142 .59127 .49964 .58835 .49641 Metetra
.665 .743 .908 r
.58835 .49641 .59127 .49964 .59696 .49786 .59405 .49463 Metetra
.665 .743 .909 r
.59405 .49463 .59696 .49786 .60267 .49608 .59976 .49284 Metetra
.665 .743 .909 r
.59976 .49284 .60267 .49608 .60838 .4943 .60548 .49106 Metetra
.664 .743 .909 r
.60548 .49106 .60838 .4943 .61411 .49252 .61122 .48927 Metetra
.664 .743 .909 r
.61122 .48927 .61411 .49252 .61985 .49074 .61697 .48748 Metetra
.664 .742 .908 r
.61697 .48748 .61985 .49074 .6256 .48897 .62273 .48568 Metetra
.664 .742 .908 r
.62273 .48568 .6256 .48897 .63137 .48719 .6285 .48389 Metetra
.664 .741 .908 r
.6285 .48389 .63137 .48719 .63714 .4854 .63428 .4821 Metetra
.663 .741 .908 r
.63428 .4821 .63714 .4854 .64293 .48362 .64008 .48031 Metetra
.663 .741 .908 r
.64008 .48031 .64293 .48362 .64873 .48183 .64588 .47852 Metetra
.663 .742 .908 r
.64588 .47852 .64873 .48183 .65454 .48004 .6517 .47673 Metetra
.663 .742 .909 r
.6517 .47673 .65454 .48004 .66036 .47824 .65754 .47493 Metetra
.663 .742 .909 r
.65754 .47493 .66036 .47824 .6662 .47645 .66338 .47313 Metetra
.663 .742 .909 r
.66338 .47313 .6662 .47645 .67205 .47465 .66924 .47132 Metetra
.663 .742 .908 r
.66924 .47132 .67205 .47465 .67791 .47285 .6751 .46951 Metetra
.663 .741 .908 r
.6751 .46951 .67791 .47285 .68378 .47105 .68098 .4677 Metetra
.662 .741 .908 r
.68098 .4677 .68378 .47105 .68966 .46925 .68688 .46589 Metetra
.661 .741 .909 r
.68688 .46589 .68966 .46925 .69556 .46745 .69279 .46411 Metetra
.658 .742 .911 r
.69279 .46411 .69556 .46745 .70147 .46566 .69871 .46236 Metetra
.656 .743 .914 r
.69871 .46236 .70147 .46566 .7074 .4639 .70464 .46064 Metetra
.653 .746 .918 r
.70464 .46064 .7074 .4639 .71334 .46217 .71059 .45895 Metetra
.651 .748 .921 r
.71059 .45895 .71334 .46217 .71929 .46048 .71656 .45729 Metetra
.649 .749 .923 r
.71656 .45729 .71929 .46048 .72526 .45884 .72254 .45566 Metetra
.646 .75 .925 r
.72254 .45566 .72526 .45884 .73125 .45723 .72854 .45405 Metetra
.642 .749 .927 r
.72854 .45405 .73125 .45723 .73725 .45566 .73455 .45251 Metetra
.634 .748 .93 r
.73455 .45251 .73725 .45566 .74327 .45414 .74058 .45105 Metetra
.621 .748 .937 r
.74058 .45105 .74327 .45414 .74931 .4527 .74664 .44975 Metetra
.603 .751 .948 r
.74664 .44975 .74931 .4527 .75537 .45137 .75273 .44862 Metetra
.579 .757 .963 r
.75273 .44862 .75537 .45137 .76146 .4502 .75884 .44769 Metetra
.551 .765 .977 r
.75884 .44769 .76146 .4502 .76758 .44922 .76499 .44693 Metetra
.524 .771 .988 r
.76499 .44693 .76758 .44922 .77373 .44843 .77116 .44629 Metetra
.504 .776 .993 r
.77116 .44629 .77373 .44843 .77991 .4478 .77735 .44571 Metetra
.495 .777 .995 r
.77735 .44571 .77991 .4478 .78611 .44728 .78357 .44516 Metetra
.494 .774 .994 r
.78357 .44516 .78611 .44728 .79234 .44682 .7898 .44464 Metetra
.491 .767 .993 r
.7898 .44464 .79234 .44682 .79859 .44638 .79606 .44417 Metetra
.478 .76 .992 r
.79606 .44417 .79859 .44638 .80486 .44595 .80235 .44382 Metetra
.453 .753 .994 r
.80235 .44382 .80486 .44595 .81115 .44558 .80867 .44361 Metetra
.42 .751 .994 r
.80867 .44361 .81115 .44558 .81747 .44527 .81501 .4435 Metetra
.393 .754 .993 r
.81501 .4435 .81747 .44527 .82381 .44503 .82138 .4434 Metetra
.396 .767 .993 r
.82138 .4434 .82381 .44503 .83018 .44482 .82776 .44315 Metetra
.446 .791 .998 r
.82776 .44315 .83018 .44482 .83656 .44452 .83413 .4426 Metetra
.528 .81 .998 r
.83413 .4426 .83656 .44452 .84294 .44402 .84047 .44163 Metetra
.604 .804 .977 r
.84047 .44163 .84294 .44402 .8493 .44317 .84679 .44022 Metetra
.651 .779 .942 r
.84679 .44022 .8493 .44317 .85564 .4419 .85309 .4384 Metetra
.673 .751 .909 r
.85309 .4384 .85564 .4419 .86196 .4402 .85937 .4363 Metetra
.682 .73 .887 r
.85937 .4363 .86196 .4402 .86824 .43813 .86565 .43401 Metetra
.686 .721 .876 r
.86565 .43401 .86824 .43813 .87451 .43579 .87192 .43161 Metetra
.691 .721 .872 r
.87192 .43161 .87451 .43579 .88078 .43326 .8782 .4291 Metetra
.699 .725 .87 r
.8782 .4291 .88078 .43326 .88704 .4306 .88447 .42642 Metetra
.71 .729 .865 r
.88447 .42642 .88704 .4306 .8933 .42782 .89072 .4235 Metetra
.721 .727 .854 r
.89072 .4235 .8933 .42782 .89955 .42487 .89695 .42028 Metetra
.729 .717 .839 r
.89695 .42028 .89955 .42487 .90579 .42172 .90315 .41677 Metetra
.731 .703 .824 r
.90315 .41677 .90579 .42172 .912 .41834 .90934 .41305 Metetra
.729 .69 .813 r
.90934 .41305 .912 .41834 .91821 .41477 .91552 .40924 Metetra
.724 .679 .807 r
.91552 .40924 .91821 .41477 .9244 .41106 .92172 .40548 Metetra
.718 .675 .807 r
.92172 .40548 .9244 .41106 .9306 .40734 .92794 .40187 Metetra
.712 .677 .814 r
.92794 .40187 .9306 .40734 .93682 .4037 .9342 .39847 Metetra
.707 .684 .825 r
.9342 .39847 .93682 .4037 .94307 .40022 .94049 .39528 Metetra
.581 .634 .869 r
.36078 .56768 .36394 .57211 .36914 .57198 .36599 .56729 Metetra
.564 .615 .862 r
.36599 .56729 .36914 .57198 .37434 .57197 .3712 .56717 Metetra
.551 .604 .86 r
.3712 .56717 .37434 .57197 .37955 .57199 .37641 .56724 Metetra
.544 .604 .864 r
.37641 .56724 .37955 .57199 .38479 .57195 .38164 .56739 Metetra
.544 .613 .872 r
.38164 .56739 .38479 .57195 .39004 .57183 .38688 .56749 Metetra
.552 .627 .88 r
.38688 .56749 .39004 .57183 .39531 .57164 .39215 .56745 Metetra
.563 .64 .885 r
.39215 .56745 .39531 .57164 .40059 .57142 .39744 .56724 Metetra
.572 .645 .884 r
.39744 .56724 .40059 .57142 .40589 .57123 .40275 .56691 Metetra
.577 .641 .877 r
.40275 .56691 .40589 .57123 .41121 .57106 .40807 .56654 Metetra
.578 .631 .868 r
.40807 .56654 .41121 .57106 .41654 .57085 .41341 .5662 Metetra
.577 .625 .863 r
.41341 .5662 .41654 .57085 .42189 .57046 .41876 .56587 Metetra
.581 .63 .865 r
.41876 .56587 .42189 .57046 .42726 .56972 .42413 .56548 Metetra
.594 .653 .877 r
.42413 .56548 .42726 .56972 .43266 .5685 .42952 .56486 Metetra
.62 .695 .898 r
.42952 .56486 .43266 .5685 .43809 .56674 .43493 .56383 Metetra
.656 .752 .921 r
.43493 .56383 .43809 .56674 .44354 .56447 .44038 .56223 Metetra
.696 .81 .935 r
.44038 .56223 .44354 .56447 .44901 .56179 .44584 .56004 Metetra
.73 .851 .938 r
.44584 .56004 .44901 .56179 .4545 .55887 .45133 .55734 Metetra
.752 .869 .933 r
.45133 .55734 .4545 .55887 .45999 .55584 .45683 .55427 Metetra
.762 .868 .926 r
.45683 .55427 .45999 .55584 .46548 .55277 .46234 .55104 Metetra
.763 .856 .92 r
.46234 .55104 .46548 .55277 .47099 .54967 .46786 .5478 Metetra
.759 .846 .917 r
.46786 .5478 .47099 .54967 .4765 .5465 .47338 .54461 Metetra
.756 .844 .918 r
.47338 .54461 .4765 .5465 .48202 .54324 .47891 .54146 Metetra
.758 .854 .922 r
.47891 .54146 .48202 .54324 .48755 .53987 .48445 .53829 Metetra
.763 .87 .927 r
.48445 .53829 .48755 .53987 .49308 .53642 .48999 .53504 Metetra
.768 .886 .93 r
.48999 .53504 .49308 .53642 .49862 .53299 .49554 .5317 Metetra
.77 .893 .931 r
.49554 .5317 .49862 .53299 .50416 .52968 .5011 .5283 Metetra
.768 .888 .931 r
.5011 .5283 .50416 .52968 .50971 .52655 .50666 .52495 Metetra
.759 .87 .929 r
.50666 .52495 .50971 .52655 .51527 .52367 .51222 .52174 Metetra
.745 .846 .926 r
.51222 .52174 .51527 .52367 .52083 .52101 .5178 .51876 Metetra
.729 .82 .921 r
.5178 .51876 .52083 .52101 .5264 .51854 .52337 .51602 Metetra
.714 .799 .917 r
.52337 .51602 .5264 .51854 .53197 .51622 .52896 .51352 Metetra
.702 .785 .915 r
.52896 .51352 .53197 .51622 .53756 .51398 .53456 .5112 Metetra
.694 .777 .915 r
.53456 .5112 .53756 .51398 .54316 .51181 .54017 .509 Metetra
.689 .775 .916 r
.54017 .509 .54316 .51181 .54877 .50969 .54578 .50686 Metetra
.686 .773 .917 r
.54578 .50686 .54877 .50969 .55439 .50762 .55141 .50476 Metetra
.684 .771 .917 r
.55141 .50476 .55439 .50762 .56002 .50563 .55705 .5027 Metetra
.681 .766 .916 r
.55705 .5027 .56002 .50563 .56566 .50369 .5627 .50069 Metetra
.677 .76 .914 r
.5627 .50069 .56566 .50369 .57131 .50182 .56836 .49873 Metetra
.673 .753 .911 r
.56836 .49873 .57131 .50182 .57698 .49999 .57403 .49682 Metetra
.669 .748 .909 r
.57403 .49682 .57698 .49999 .58266 .4982 .57971 .49497 Metetra
.667 .744 .908 r
.57971 .49497 .58266 .4982 .58835 .49641 .58541 .49315 Metetra
.665 .742 .907 r
.58541 .49315 .58835 .49641 .59405 .49463 .59112 .49136 Metetra
.664 .741 .908 r
.59112 .49136 .59405 .49463 .59976 .49284 .59684 .48957 Metetra
.664 .742 .908 r
.59684 .48957 .59976 .49284 .60548 .49106 .60257 .48779 Metetra
.664 .742 .908 r
.60257 .48779 .60548 .49106 .61122 .48927 .60831 .48599 Metetra
.664 .742 .908 r
.60831 .48599 .61122 .48927 .61697 .48748 .61407 .48419 Metetra
.664 .742 .908 r
.61407 .48419 .61697 .48748 .62273 .48568 .61984 .48239 Metetra
.664 .742 .908 r
.61984 .48239 .62273 .48568 .6285 .48389 .62562 .48059 Metetra
.664 .741 .908 r
.62562 .48059 .6285 .48389 .63428 .4821 .63141 .47879 Metetra
.663 .741 .908 r
.63141 .47879 .63428 .4821 .64008 .48031 .63721 .47699 Metetra
.663 .741 .908 r
.63721 .47699 .64008 .48031 .64588 .47852 .64303 .47519 Metetra
.663 .741 .908 r
.64303 .47519 .64588 .47852 .6517 .47673 .64886 .47339 Metetra
.663 .741 .908 r
.64886 .47339 .6517 .47673 .65754 .47493 .6547 .47158 Metetra
.663 .741 .908 r
.6547 .47158 .65754 .47493 .66338 .47313 .66055 .46977 Metetra
.663 .741 .907 r
.66055 .46977 .66338 .47313 .66924 .47132 .66641 .46795 Metetra
.663 .74 .908 r
.66641 .46795 .66924 .47132 .6751 .46951 .67229 .46614 Metetra
.662 .74 .908 r
.67229 .46614 .6751 .46951 .68098 .4677 .67818 .46434 Metetra
.66 .741 .91 r
.67818 .46434 .68098 .4677 .68688 .46589 .68408 .46257 Metetra
.658 .742 .913 r
.68408 .46257 .68688 .46589 .69279 .46411 .69 .46083 Metetra
.655 .745 .916 r
.69 .46083 .69279 .46411 .69871 .46236 .69593 .45911 Metetra
.654 .747 .918 r
.69593 .45911 .69871 .46236 .70464 .46064 .70188 .45741 Metetra
.652 .748 .92 r
.70188 .45741 .70464 .46064 .71059 .45895 .70784 .45573 Metetra
.651 .748 .921 r
.70784 .45573 .71059 .45895 .71656 .45729 .71381 .45405 Metetra
.648 .747 .922 r
.71381 .45405 .71656 .45729 .72254 .45566 .7198 .45242 Metetra
.643 .745 .924 r
.7198 .45242 .72254 .45566 .72854 .45405 .72581 .45086 Metetra
.633 .745 .929 r
.72581 .45086 .72854 .45405 .73455 .45251 .73184 .44942 Metetra
.617 .748 .939 r
.73184 .44942 .73455 .45251 .74058 .45105 .7379 .44816 Metetra
.596 .754 .953 r
.7379 .44816 .74058 .45105 .74664 .44975 .74398 .4471 Metetra
.571 .762 .969 r
.74398 .4471 .74664 .44975 .75273 .44862 .7501 .44621 Metetra
.545 .771 .982 r
.7501 .44621 .75273 .44862 .75884 .44769 .75623 .44544 Metetra
.527 .777 .989 r
.75623 .44544 .75884 .44769 .76499 .44693 .76239 .44475 Metetra
.519 .779 .991 r
.76239 .44475 .76499 .44693 .77116 .44629 .76857 .44407 Metetra
.519 .776 .99 r
.76857 .44407 .77116 .44629 .77735 .44571 .77477 .44341 Metetra
.516 .769 .988 r
.77477 .44341 .77735 .44571 .78357 .44516 .78099 .44283 Metetra
.501 .759 .988 r
.78099 .44283 .78357 .44516 .7898 .44464 .78725 .44238 Metetra
.469 .751 .991 r
.78725 .44238 .7898 .44464 .79606 .44417 .79353 .44213 Metetra
.421 .745 .993 r
.79353 .44213 .79606 .44417 .80235 .44382 .79986 .44206 Metetra
.369 .742 .989 r
.79986 .44206 .80235 .44382 .80867 .44361 .80621 .4421 Metetra
.341 .747 .982 r
.80621 .4421 .80867 .44361 .81501 .4435 .81258 .44207 Metetra
.371 .77 .985 r
.81258 .44207 .81501 .4435 .82138 .4434 .81894 .44178 Metetra
.459 .803 .998 r
.81894 .44178 .82138 .4434 .82776 .44315 .82529 .4411 Metetra
.559 .813 .993 r
.82529 .4411 .82776 .44315 .83413 .4426 .83161 .43995 Metetra
.626 .791 .961 r
.83161 .43995 .83413 .4426 .84047 .44163 .83791 .43837 Metetra
.658 .76 .925 r
.83791 .43837 .84047 .44163 .84679 .44022 .8442 .4365 Metetra
.669 .736 .9 r
.8442 .4365 .84679 .44022 .85309 .4384 .85048 .43446 Metetra
.673 .725 .888 r
.85048 .43446 .85309 .4384 .85937 .4363 .85677 .43233 Metetra
.677 .726 .886 r
.85677 .43233 .85937 .4363 .86565 .43401 .86307 .43012 Metetra
.685 .734 .887 r
.86307 .43012 .86565 .43401 .87192 .43161 .86936 .42776 Metetra
.699 .742 .884 r
.86936 .42776 .87192 .43161 .8782 .4291 .87563 .42513 Metetra
.716 .742 .872 r
.87563 .42513 .8782 .4291 .88447 .42642 .88187 .42214 Metetra
.728 .731 .853 r
.88187 .42214 .88447 .42642 .89072 .4235 .88809 .41876 Metetra
.734 .713 .831 r
.88809 .41876 .89072 .4235 .89695 .42028 .89427 .41506 Metetra
.732 .694 .814 r
.89427 .41506 .89695 .42028 .90315 .41677 .90044 .41119 Metetra
.727 .679 .804 r
.90044 .41119 .90315 .41677 .90934 .41305 .90662 .40732 Metetra
.72 .671 .802 r
.90662 .40732 .90934 .41305 .91552 .40924 .91282 .40359 Metetra
.713 .671 .807 r
.91282 .40359 .91552 .40924 .92172 .40548 .91906 .40008 Metetra
.708 .678 .819 r
.91906 .40008 .92172 .40548 .92794 .40187 .92533 .39681 Metetra
.706 .69 .833 r
.92533 .39681 .92794 .40187 .9342 .39847 .93164 .39372 Metetra
.705 .703 .846 r
.93164 .39372 .9342 .39847 .94049 .39528 .93797 .39075 Metetra
.606 .67 .885 r
.35759 .56375 .36078 .56768 .36599 .56729 .36282 .56296 Metetra
.589 .643 .872 r
.36282 .56296 .36599 .56729 .3712 .56717 .36804 .56245 Metetra
.569 .616 .86 r
.36804 .56245 .3712 .56717 .37641 .56724 .37327 .56226 Metetra
.551 .597 .853 r
.37327 .56226 .37641 .56724 .38164 .56739 .3785 .56235 Metetra
.538 .589 .853 r
.3785 .56235 .38164 .56739 .38688 .56749 .38374 .56262 Metetra
.534 .595 .861 r
.38374 .56262 .38688 .56749 .39215 .56745 .389 .5629 Metetra
.54 .613 .874 r
.389 .5629 .39215 .56745 .39744 .56724 .39428 .56303 Metetra
.554 .637 .887 r
.39428 .56303 .39744 .56724 .40275 .56691 .39958 .56292 Metetra
.572 .656 .893 r
.39958 .56292 .40275 .56691 .40807 .56654 .40491 .56255 Metetra
.585 .662 .891 r
.40491 .56255 .40807 .56654 .41341 .5662 .41026 .56202 Metetra
.591 .655 .881 r
.41026 .56202 .41341 .5662 .41876 .56587 .41562 .56143 Metetra
.59 .642 .87 r
.41562 .56143 .41876 .56587 .42413 .56548 .421 .56088 Metetra
.589 .634 .864 r
.421 .56088 .42413 .56548 .42952 .56486 .42639 .56037 Metetra
.593 .641 .867 r
.42639 .56037 .42952 .56486 .43493 .56383 .43179 .55978 Metetra
.61 .67 .883 r
.43179 .55978 .43493 .56383 .44038 .56223 .43722 .55892 Metetra
.64 .723 .908 r
.43722 .55892 .44038 .56223 .44584 .56004 .44267 .55756 Metetra
.682 .79 .931 r
.44267 .55756 .44584 .56004 .45133 .55734 .44815 .55557 Metetra
.723 .851 .942 r
.44815 .55557 .45133 .55734 .45683 .55427 .45366 .55295 Metetra
.754 .887 .939 r
.45366 .55295 .45683 .55427 .46234 .55104 .45918 .54983 Metetra
.772 .895 .93 r
.45918 .54983 .46234 .55104 .46786 .5478 .46471 .54641 Metetra
.776 .882 .923 r
.46471 .54641 .46786 .5478 .47338 .54461 .47025 .54293 Metetra
.77 .861 .917 r
.47025 .54293 .47338 .54461 .47891 .54146 .47579 .53955 Metetra
.76 .844 .915 r
.47579 .53955 .47891 .54146 .48445 .53829 .48134 .53631 Metetra
.754 .839 .916 r
.48134 .53631 .48445 .53829 .48999 .53504 .48689 .53317 Metetra
.754 .849 .922 r
.48689 .53317 .48999 .53504 .49554 .5317 .49245 .53005 Metetra
.758 .866 .928 r
.49245 .53005 .49554 .5317 .5011 .5283 .49801 .52686 Metetra
.763 .882 .932 r
.49801 .52686 .5011 .5283 .50666 .52495 .50359 .52357 Metetra
.765 .888 .933 r
.50359 .52357 .50666 .52495 .51222 .52174 .50917 .52026 Metetra
.761 .881 .932 r
.50917 .52026 .51222 .52174 .5178 .51876 .51475 .517 Metetra
.751 .86 .929 r
.51475 .517 .5178 .51876 .52337 .51602 .52034 .51391 Metetra
.735 .832 .925 r
.52034 .51391 .52337 .51602 .52896 .51352 .52594 .51107 Metetra
.718 .805 .919 r
.52594 .51107 .52896 .51352 .53456 .5112 .53154 .50849 Metetra
.703 .785 .915 r
.53154 .50849 .53456 .5112 .54017 .509 .53716 .50613 Metetra
.692 .772 .913 r
.53716 .50613 .54017 .509 .54578 .50686 .54278 .50394 Metetra
.686 .767 .913 r
.54278 .50394 .54578 .50686 .55141 .50476 .54842 .50184 Metetra
.683 .767 .915 r
.54842 .50184 .55141 .50476 .55705 .5027 .55406 .49979 Metetra
.681 .768 .916 r
.55406 .49979 .55705 .5027 .5627 .50069 .55972 .49775 Metetra
.68 .766 .916 r
.55972 .49775 .5627 .50069 .56836 .49873 .56539 .49574 Metetra
.677 .763 .915 r
.56539 .49574 .56836 .49873 .57403 .49682 .57107 .49376 Metetra
.674 .757 .913 r
.57107 .49376 .57403 .49682 .57971 .49497 .57676 .49182 Metetra
.671 .751 .911 r
.57676 .49182 .57971 .49497 .58541 .49315 .58246 .48994 Metetra
.668 .746 .909 r
.58246 .48994 .58541 .49315 .59112 .49136 .58818 .48809 Metetra
.665 .743 .908 r
.58818 .48809 .59112 .49136 .59684 .48957 .59391 .48628 Metetra
.664 .741 .907 r
.59391 .48628 .59684 .48957 .60257 .48779 .59965 .48449 Metetra
.664 .741 .908 r
.59965 .48449 .60257 .48779 .60831 .48599 .6054 .4827 Metetra
.664 .742 .908 r
.6054 .4827 .60831 .48599 .61407 .48419 .61116 .48091 Metetra
.664 .743 .909 r
.61116 .48091 .61407 .48419 .61984 .48239 .61694 .47911 Metetra
.664 .743 .909 r
.61694 .47911 .61984 .48239 .62562 .48059 .62273 .4773 Metetra
.664 .744 .909 r
.62273 .4773 .62562 .48059 .63141 .47879 .62853 .4755 Metetra
.664 .743 .909 r
.62853 .4755 .63141 .47879 .63721 .47699 .63434 .47368 Metetra
.664 .743 .909 r
.63434 .47368 .63721 .47699 .64303 .47519 .64016 .47187 Metetra
.664 .742 .909 r
.64016 .47187 .64303 .47519 .64886 .47339 .646 .47005 Metetra
.664 .742 .908 r
.646 .47005 .64886 .47339 .6547 .47158 .65185 .46823 Metetra
.663 .741 .908 r
.65185 .46823 .6547 .47158 .66055 .46977 .65771 .46641 Metetra
.662 .741 .908 r
.65771 .46641 .66055 .46977 .66641 .46795 .66358 .4646 Metetra
.661 .741 .91 r
.66358 .4646 .66641 .46795 .67229 .46614 .66947 .46282 Metetra
.659 .743 .912 r
.66947 .46282 .67229 .46614 .67818 .46434 .67537 .46105 Metetra
.657 .745 .915 r
.67537 .46105 .67818 .46434 .68408 .46257 .68128 .45931 Metetra
.656 .747 .917 r
.68128 .45931 .68408 .46257 .69 .46083 .68721 .45759 Metetra
.655 .748 .918 r
.68721 .45759 .69 .46083 .69593 .45911 .69315 .45586 Metetra
.655 .748 .918 r
.69315 .45586 .69593 .45911 .70188 .45741 .6991 .45413 Metetra
.654 .746 .918 r
.6991 .45413 .70188 .45741 .70784 .45573 .70507 .45242 Metetra
.65 .744 .918 r
.70507 .45242 .70784 .45573 .71381 .45405 .71106 .45077 Metetra
.642 .742 .922 r
.71106 .45077 .71381 .45405 .7198 .45242 .71706 .44922 Metetra
.629 .744 .93 r
.71706 .44922 .7198 .45242 .72581 .45086 .72309 .44784 Metetra
.61 .75 .944 r
.72309 .44784 .72581 .45086 .73184 .44942 .72914 .44665 Metetra
.588 .759 .96 r
.72914 .44665 .73184 .44942 .7379 .44816 .73523 .44563 Metetra
.564 .769 .975 r
.73523 .44563 .7379 .44816 .74398 .4471 .74133 .44475 Metetra
.548 .778 .984 r
.74133 .44475 .74398 .4471 .7501 .44621 .74746 .44393 Metetra
.542 .781 .987 r
.74746 .44393 .7501 .44621 .75623 .44544 .75361 .44311 Metetra
.543 .778 .985 r
.75361 .44311 .75623 .44544 .76239 .44475 .75977 .44231 Metetra
.542 .769 .982 r
.75977 .44231 .76239 .44475 .76857 .44407 .76596 .44157 Metetra
.528 .758 .981 r
.76596 .44157 .76857 .44407 .77477 .44341 .77217 .44098 Metetra
.494 .749 .985 r
.77217 .44098 .77477 .44341 .78099 .44283 .77842 .44064 Metetra
.437 .742 .992 r
.77842 .44064 .78099 .44283 .78725 .44238 .78472 .44056 Metetra
.363 .734 .988 r
.78472 .44056 .78725 .44238 .79353 .44213 .79104 .44068 Metetra
.3 .727 .971 r
.79104 .44068 .79353 .44213 .79986 .44206 .7974 .44082 Metetra
.297 .741 .963 r
.7974 .44082 .79986 .44206 .80621 .4421 .80375 .44076 Metetra
.38 .783 .984 r
.80375 .44076 .80621 .4421 .81258 .44207 .8101 .44033 Metetra
.503 .814 1 r
.8101 .44033 .81258 .44207 .81894 .44178 .81642 .43942 Metetra
.597 .803 .978 r
.81642 .43942 .81894 .44178 .82529 .4411 .82272 .43806 Metetra
.641 .769 .941 r
.82272 .43806 .82529 .4411 .83161 .43995 .82901 .43639 Metetra
.655 .74 .912 r
.82901 .43639 .83161 .43995 .83791 .43837 .83529 .43457 Metetra
.658 .727 .9 r
.83529 .43457 .83791 .43837 .8442 .4365 .84159 .43271 Metetra
.659 .728 .901 r
.84159 .43271 .8442 .4365 .85048 .43446 .8479 .43083 Metetra
.666 .741 .907 r
.8479 .43083 .85048 .43446 .85677 .43233 .85421 .42883 Metetra
.682 .756 .908 r
.85421 .42883 .85677 .43233 .86307 .43012 .86051 .42656 Metetra
.705 .761 .896 r
.86051 .42656 .86307 .43012 .86936 .42776 .86678 .42387 Metetra
.725 .75 .872 r
.86678 .42387 .86936 .42776 .87563 .42513 .873 .42069 Metetra
.736 .726 .843 r
.873 .42069 .87563 .42513 .88187 .42214 .87919 .41707 Metetra
.735 .701 .818 r
.87919 .41707 .88187 .42214 .88809 .41876 .88535 .41317 Metetra
.729 .68 .802 r
.88535 .41317 .88809 .41876 .89427 .41506 .89151 .4092 Metetra
.721 .668 .797 r
.89151 .4092 .89427 .41506 .90044 .41119 .89769 .40536 Metetra
.714 .665 .801 r
.89769 .40536 .90044 .41119 .90662 .40732 .90391 .40175 Metetra
.708 .672 .812 r
.90391 .40175 .90662 .40732 .91282 .40359 .91017 .39841 Metetra
.706 .686 .828 r
.91017 .39841 .91282 .40359 .91906 .40008 .91646 .39529 Metetra
.706 .702 .843 r
.91646 .39529 .91906 .40008 .92533 .39681 .92277 .39227 Metetra
.708 .715 .854 r
.92277 .39227 .92533 .39681 .93164 .39372 .9291 .38928 Metetra
.71 .72 .857 r
.9291 .38928 .93164 .39372 .93797 .39075 .93544 .38626 Metetra
.621 .703 .904 r
.35436 .56031 .35759 .56375 .36282 .56296 .3596 .55926 Metetra
.614 .686 .894 r
.3596 .55926 .36282 .56296 .36804 .56245 .36485 .55834 Metetra
.599 .659 .88 r
.36485 .55834 .36804 .56245 .37327 .56226 .37011 .55765 Metetra
.578 .627 .864 r
.37011 .55765 .37327 .56226 .3785 .56235 .37536 .5573 Metetra
.556 .598 .85 r
.37536 .5573 .3785 .56235 .38374 .56262 .38061 .55732 Metetra
.537 .579 .844 r
.38061 .55732 .38374 .56262 .389 .5629 .38587 .55764 Metetra
.526 .575 .847 r
.38587 .55764 .389 .5629 .39428 .56303 .39114 .55809 Metetra
.527 .589 .861 r
.39114 .55809 .39428 .56303 .39958 .56292 .39642 .55847 Metetra
.539 .619 .88 r
.39642 .55847 .39958 .56292 .40491 .56255 .40173 .55858 Metetra
.562 .654 .897 r
.40173 .55858 .40491 .56255 .41026 .56202 .40708 .55831 Metetra
.587 .679 .905 r
.40708 .55831 .41026 .56202 .41562 .56143 .41245 .5577 Metetra
.604 .685 .899 r
.41245 .5577 .41562 .56143 .421 .56088 .41784 .55688 Metetra
.609 .672 .885 r
.41784 .55688 .421 .56088 .42639 .56037 .42324 .55602 Metetra
.605 .653 .871 r
.42324 .55602 .42639 .56037 .43179 .55978 .42866 .55524 Metetra
.601 .643 .864 r
.42866 .55524 .43179 .55978 .43722 .55892 .43408 .55453 Metetra
.606 .652 .869 r
.43408 .55453 .43722 .55892 .44267 .55756 .43953 .55373 Metetra
.625 .689 .889 r
.43953 .55373 .44267 .55756 .44815 .55557 .44499 .55261 Metetra
.661 .753 .918 r
.44499 .55261 .44815 .55557 .45366 .55295 .45048 .55092 Metetra
.707 .829 .94 r
.45048 .55092 .45366 .55295 .45918 .54983 .456 .54854 Metetra
.747 .89 .944 r
.456 .54854 .45918 .54983 .46471 .54641 .46154 .54549 Metetra
.775 .918 .934 r
.46154 .54549 .46471 .54641 .47025 .54293 .46709 .54197 Metetra
.788 .915 .926 r
.46709 .54197 .47025 .54293 .47579 .53955 .47265 .53825 Metetra
.786 .891 .92 r
.47265 .53825 .47579 .53955 .48134 .53631 .47821 .53459 Metetra
.773 .86 .915 r
.47821 .53459 .48134 .53631 .48689 .53317 .48378 .53113 Metetra
.758 .837 .912 r
.48378 .53113 .48689 .53317 .49245 .53005 .48935 .52792 Metetra
.748 .83 .914 r
.48935 .52792 .49245 .53005 .49801 .52686 .49492 .52486 Metetra
.747 .84 .921 r
.49492 .52486 .49801 .52686 .50359 .52357 .5005 .52183 Metetra
.752 .86 .929 r
.5005 .52183 .50359 .52357 .50917 .52026 .50609 .51872 Metetra
.757 .877 .934 r
.50609 .51872 .50917 .52026 .51475 .517 .51169 .51553 Metetra
.758 .883 .935 r
.51169 .51553 .51475 .517 .52034 .51391 .51729 .5123 Metetra
.754 .873 .933 r
.51729 .5123 .52034 .51391 .52594 .51107 .5229 .50915 Metetra
.742 .849 .929 r
.5229 .50915 .52594 .51107 .53154 .50849 .52851 .50619 Metetra
.726 .819 .923 r
.52851 .50619 .53154 .50849 .53716 .50613 .53414 .50348 Metetra
.708 .791 .916 r
.53414 .50348 .53716 .50613 .54278 .50394 .53977 .50104 Metetra
.694 .771 .911 r
.53977 .50104 .54278 .50394 .54842 .50184 .54541 .49882 Metetra
.684 .761 .91 r
.54541 .49882 .54842 .50184 .55406 .49979 .55107 .49674 Metetra
.679 .759 .911 r
.55107 .49674 .55406 .49979 .55972 .49775 .55673 .49473 Metetra
.678 .761 .914 r
.55673 .49473 .55972 .49775 .56539 .49574 .56241 .49274 Metetra
.677 .763 .915 r
.56241 .49274 .56539 .49574 .57107 .49376 .5681 .49076 Metetra
.677 .763 .916 r
.5681 .49076 .57107 .49376 .57676 .49182 .5738 .48878 Metetra
.675 .76 .915 r
.5738 .48878 .57676 .49182 .58246 .48994 .57951 .48682 Metetra
.672 .755 .912 r
.57951 .48682 .58246 .48994 .58818 .48809 .58523 .4849 Metetra
.669 .749 .91 r
.58523 .4849 .58818 .48809 .59391 .48628 .59097 .48302 Metetra
.666 .744 .908 r
.59097 .48302 .59391 .48628 .59965 .48449 .59671 .48118 Metetra
.664 .741 .908 r
.59671 .48118 .59965 .48449 .6054 .4827 .60247 .47938 Metetra
.663 .74 .907 r
.60247 .47938 .6054 .4827 .61116 .48091 .60825 .47758 Metetra
.663 .741 .908 r
.60825 .47758 .61116 .48091 .61694 .47911 .61403 .47579 Metetra
.663 .742 .908 r
.61403 .47579 .61694 .47911 .62273 .4773 .61983 .47399 Metetra
.664 .742 .909 r
.61983 .47399 .62273 .4773 .62853 .4755 .62563 .47217 Metetra
.664 .743 .908 r
.62563 .47217 .62853 .4755 .63434 .47368 .63145 .47035 Metetra
.665 .742 .908 r
.63145 .47035 .63434 .47368 .64016 .47187 .63728 .46851 Metetra
.664 .741 .907 r
.63728 .46851 .64016 .47187 .646 .47005 .64313 .46668 Metetra
.663 .741 .907 r
.64313 .46668 .646 .47005 .65185 .46823 .64898 .46486 Metetra
.662 .74 .908 r
.64898 .46486 .65185 .46823 .65771 .46641 .65485 .46306 Metetra
.66 .741 .91 r
.65485 .46306 .65771 .46641 .66358 .4646 .66074 .46128 Metetra
.658 .743 .913 r
.66074 .46128 .66358 .4646 .66947 .46282 .66663 .45952 Metetra
.657 .745 .915 r
.66663 .45952 .66947 .46282 .67537 .46105 .67254 .45778 Metetra
.657 .747 .916 r
.67254 .45778 .67537 .46105 .68128 .45931 .67847 .45602 Metetra
.658 .746 .915 r
.67847 .45602 .68128 .45931 .68721 .45759 .6844 .45426 Metetra
.658 .744 .914 r
.6844 .45426 .68721 .45759 .69315 .45586 .69035 .45249 Metetra
.655 .741 .913 r
.69035 .45249 .69315 .45586 .6991 .45413 .69631 .45076 Metetra
.649 .739 .915 r
.69631 .45076 .6991 .45413 .70507 .45242 .70229 .44912 Metetra
.638 .74 .922 r
.70229 .44912 .70507 .45242 .71106 .45077 .7083 .44762 Metetra
.622 .745 .935 r
.7083 .44762 .71106 .45077 .71706 .44922 .71432 .44632 Metetra
.601 .755 .952 r
.71432 .44632 .71706 .44922 .72309 .44784 .72038 .44519 Metetra
.581 .767 .967 r
.72038 .44519 .72309 .44784 .72914 .44665 .72645 .44419 Metetra
.566 .777 .978 r
.72645 .44419 .72914 .44665 .73523 .44563 .73255 .44326 Metetra
.562 .782 .981 r
.73255 .44326 .73523 .44563 .74133 .44475 .73867 .44231 Metetra
.566 .779 .979 r
.73867 .44231 .74133 .44475 .74746 .44393 .74479 .44135 Metetra
.568 .769 .973 r
.74479 .44135 .74746 .44393 .75361 .44311 .75094 .44043 Metetra
.556 .756 .971 r
.75094 .44043 .75361 .44311 .75977 .44231 .75712 .43967 Metetra
.523 .746 .976 r
.75712 .43967 .75977 .44231 .76596 .44157 .76334 .43919 Metetra
.464 .739 .988 r
.76334 .43919 .76596 .44157 .77217 .44098 .76959 .43905 Metetra
.374 .73 .99 r
.76959 .43905 .77217 .44098 .77842 .44064 .7759 .43919 Metetra
.276 .713 .965 r
.7759 .43919 .77842 .44064 .78472 .44056 .78223 .43945 Metetra
.234 .71 .937 r
.78223 .43945 .78472 .44056 .79104 .44068 .78857 .43959 Metetra
.297 .752 .955 r
.78857 .43959 .79104 .44068 .7974 .44082 .79491 .43937 Metetra
.439 .806 .995 r
.79491 .43937 .7974 .44082 .80375 .44076 .80122 .43866 Metetra
.564 .811 .991 r
.80122 .43866 .80375 .44076 .8101 .44033 .80752 .43749 Metetra
.625 .777 .954 r
.80752 .43749 .8101 .44033 .81642 .43942 .8138 .43598 Metetra
.642 .743 .922 r
.8138 .43598 .81642 .43942 .82272 .43806 .82008 .43435 Metetra
.642 .726 .909 r
.82008 .43435 .82272 .43806 .82901 .43639 .82638 .43274 Metetra
.638 .728 .914 r
.82638 .43274 .82901 .43639 .83529 .43457 .8327 .43119 Metetra
.639 .746 .927 r
.8327 .43119 .83529 .43457 .84159 .43271 .83904 .42959 Metetra
.654 .771 .935 r
.83904 .42959 .84159 .43271 .8479 .43083 .84536 .42774 Metetra
.684 .784 .926 r
.84536 .42774 .8479 .43083 .85421 .42883 .85165 .42542 Metetra
.717 .775 .898 r
.85165 .42542 .85421 .42883 .86051 .42656 .8579 .42251 Metetra
.736 .745 .859 r
.8579 .42251 .86051 .42656 .86678 .42387 .86409 .41902 Metetra
.739 .711 .825 r
.86409 .41902 .86678 .42387 .873 .42069 .87025 .41514 Metetra
.732 .682 .802 r
.87025 .41514 .873 .42069 .87919 .41707 .8764 .41109 Metetra
.723 .665 .792 r
.8764 .41109 .87919 .41707 .88535 .41317 .88256 .40714 Metetra
.714 .659 .794 r
.88256 .40714 .88535 .41317 .89151 .4092 .88876 .40345 Metetra
.707 .665 .806 r
.88876 .40345 .89151 .4092 .89769 .40536 .89501 .40007 Metetra
.705 .681 .824 r
.89501 .40007 .89769 .40536 .90391 .40175 .90129 .39693 Metetra
.706 .7 .843 r
.90129 .39693 .90391 .40175 .91017 .39841 .90759 .39392 Metetra
.71 .717 .855 r
.90759 .39392 .91017 .39841 .91646 .39529 .9139 .3909 Metetra
.715 .724 .858 r
.9139 .3909 .91646 .39529 .92277 .39227 .92022 .3878 Metetra
.717 .722 .853 r
.92022 .3878 .92277 .39227 .9291 .38928 .92653 .38461 Metetra
.715 .712 .846 r
.92653 .38461 .9291 .38928 .93544 .38626 .93286 .38141 Metetra
.614 .701 .906 r
.35111 .55685 .35436 .56031 .3596 .55926 .35636 .55589 Metetra
.617 .707 .909 r
.35636 .55589 .3596 .55926 .36485 .55834 .36162 .55487 Metetra
.618 .702 .905 r
.36162 .55487 .36485 .55834 .37011 .55765 .3669 .55387 Metetra
.61 .681 .893 r
.3669 .55387 .37011 .55765 .37536 .5573 .37218 .55299 Metetra
.592 .647 .874 r
.37218 .55299 .37536 .5573 .38061 .55732 .37746 .5524 Metetra
.568 .61 .854 r
.37746 .5524 .38061 .55732 .38587 .55764 .38274 .55222 Metetra
.544 .578 .839 r
.38274 .55222 .38587 .55764 .39114 .55809 .38801 .55247 Metetra
.525 .561 .834 r
.38801 .55247 .39114 .55809 .39642 .55847 .39329 .55302 Metetra
.516 .563 .842 r
.39329 .55302 .39642 .55847 .40173 .55858 .39859 .55365 Metetra
.521 .588 .863 r
.39859 .55365 .40173 .55858 .40708 .55831 .40391 .55407 Metetra
.543 .633 .89 r
.40391 .55407 .40708 .55831 .41245 .5577 .40926 .55407 Metetra
.576 .681 .912 r
.40926 .55407 .41245 .5577 .41784 .55688 .41464 .55356 Metetra
.608 .712 .918 r
.41464 .55356 .41784 .55688 .42324 .55602 .42006 .55261 Metetra
.627 .713 .908 r
.42006 .55261 .42324 .55602 .42866 .55524 .42549 .55143 Metetra
.629 .691 .889 r
.42549 .55143 .42866 .55524 .43408 .55453 .43093 .55025 Metetra
.62 .664 .871 r
.43093 .55025 .43408 .55453 .43953 .55373 .43639 .54922 Metetra
.613 .651 .863 r
.43639 .54922 .43953 .55373 .44499 .55261 .44185 .54831 Metetra
.618 .662 .871 r
.44185 .54831 .44499 .55261 .45048 .55092 .44733 .54731 Metetra
.641 .708 .895 r
.44733 .54731 .45048 .55092 .456 .54854 .45283 .54594 Metetra
.682 .784 .927 r
.45283 .54594 .456 .54854 .46154 .54549 .45836 .54392 Metetra
.73 .869 .946 r
.45836 .54392 .46154 .54549 .46709 .54197 .46391 .54115 Metetra
.767 .926 .939 r
.46391 .54115 .46709 .54197 .47265 .53825 .46948 .5377 Metetra
.79 .944 .925 r
.46948 .5377 .47265 .53825 .47821 .53459 .47506 .53383 Metetra
.799 .93 .92 r
.47506 .53383 .47821 .53459 .48378 .53113 .48064 .52986 Metetra
.791 .894 .917 r
.48064 .52986 .48378 .53113 .48935 .52792 .48623 .52608 Metetra
.771 .853 .912 r
.48623 .52608 .48935 .52792 .49492 .52486 .49182 .52263 Metetra
.751 .824 .909 r
.49182 .52263 .49492 .52486 .5005 .52183 .49741 .5195 Metetra
.739 .817 .912 r
.49741 .5195 .5005 .52183 .50609 .51872 .50301 .51656 Metetra
.738 .829 .921 r
.50301 .51656 .50609 .51872 .51169 .51553 .50861 .51366 Metetra
.744 .852 .93 r
.50861 .51366 .51169 .51553 .51729 .5123 .51423 .51067 Metetra
.75 .872 .935 r
.51423 .51067 .51729 .5123 .5229 .50915 .51985 .50758 Metetra
.751 .877 .936 r
.51985 .50758 .5229 .50915 .52851 .50619 .52547 .50444 Metetra
.746 .864 .934 r
.52547 .50444 .52851 .50619 .53414 .50348 .53111 .5014 Metetra
.734 .838 .929 r
.53111 .5014 .53414 .50348 .53977 .50104 .53675 .49855 Metetra
.716 .806 .921 r
.53675 .49855 .53977 .50104 .54541 .49882 .5424 .49598 Metetra
.699 .778 .913 r
.5424 .49598 .54541 .49882 .55107 .49674 .54806 .49366 Metetra
.685 .76 .908 r
.54806 .49366 .55107 .49674 .55673 .49473 .55373 .49156 Metetra
.677 .751 .907 r
.55373 .49156 .55673 .49473 .56241 .49274 .55942 .48957 Metetra
.674 .751 .909 r
.55942 .48957 .56241 .49274 .5681 .49076 .56512 .48763 Metetra
.674 .755 .912 r
.56512 .48763 .5681 .49076 .5738 .48878 .57082 .4857 Metetra
.674 .758 .914 r
.57082 .4857 .5738 .48878 .57951 .48682 .57654 .48374 Metetra
.674 .759 .914 r
.57654 .48374 .57951 .48682 .58523 .4849 .58227 .48178 Metetra
.673 .756 .913 r
.58227 .48178 .58523 .4849 .59097 .48302 .58802 .47984 Metetra
.671 .752 .911 r
.58802 .47984 .59097 .48302 .59671 .48118 .59377 .47793 Metetra
.668 .746 .909 r
.59377 .47793 .59671 .48118 .60247 .47938 .59954 .47606 Metetra
.665 .742 .907 r
.59954 .47606 .60247 .47938 .60825 .47758 .60532 .47422 Metetra
.664 .739 .906 r
.60532 .47422 .60825 .47758 .61403 .47579 .61111 .47241 Metetra
.663 .738 .906 r
.61111 .47241 .61403 .47579 .61983 .47399 .61691 .47059 Metetra
.663 .738 .906 r
.61691 .47059 .61983 .47399 .62563 .47217 .62273 .46878 Metetra
.664 .739 .906 r
.62273 .46878 .62563 .47217 .63145 .47035 .62856 .46696 Metetra
.663 .739 .906 r
.62856 .46696 .63145 .47035 .63728 .46851 .6344 .46514 Metetra
.662 .74 .908 r
.6344 .46514 .63728 .46851 .64313 .46668 .64025 .46333 Metetra
.661 .742 .91 r
.64025 .46333 .64313 .46668 .64898 .46486 .64611 .46153 Metetra
.659 .743 .912 r
.64611 .46153 .64898 .46486 .65485 .46306 .65199 .45976 Metetra
.658 .745 .914 r
.65199 .45976 .65485 .46306 .66074 .46128 .65789 .458 Metetra
.659 .747 .915 r
.65789 .458 .66074 .46128 .66663 .45952 .66379 .45622 Metetra
.66 .746 .914 r
.66379 .45622 .66663 .45952 .67254 .45778 .66971 .45443 Metetra
.661 .744 .912 r
.66971 .45443 .67254 .45778 .67847 .45602 .67564 .45262 Metetra
.659 .741 .91 r
.67564 .45262 .67847 .45602 .6844 .45426 .68158 .45083 Metetra
.654 .738 .911 r
.68158 .45083 .6844 .45426 .69035 .45249 .68754 .44911 Metetra
.645 .738 .917 r
.68754 .44911 .69035 .45249 .69631 .45076 .69352 .44753 Metetra
.631 .743 .928 r
.69352 .44753 .69631 .45076 .70229 .44912 .69952 .44612 Metetra
.612 .752 .945 r
.69952 .44612 .70229 .44912 .7083 .44762 .70555 .44489 Metetra
.593 .765 .961 r
.70555 .44489 .7083 .44762 .71432 .44632 .7116 .44379 Metetra
.58 .777 .973 r
.7116 .44379 .71432 .44632 .72038 .44519 .71767 .44274 Metetra
.579 .783 .976 r
.71767 .44274 .72038 .44519 .72645 .44419 .72375 .44167 Metetra
.586 .78 .972 r
.72375 .44167 .72645 .44419 .73255 .44326 .72985 .44055 Metetra
.591 .769 .964 r
.72985 .44055 .73255 .44326 .73867 .44231 .73596 .43945 Metetra
.582 .753 .959 r
.73596 .43945 .73867 .44231 .74479 .44135 .7421 .4385 Metetra
.553 .742 .964 r
.7421 .4385 .74479 .44135 .75094 .44043 .74828 .43784 Metetra
.495 .736 .98 r
.74828 .43784 .75094 .44043 .75712 .43967 .7545 .43758 Metetra
.398 .729 .99 r
.7545 .43758 .75712 .43967 .76334 .43919 .76077 .43769 Metetra
.272 .706 .965 r
.76077 .43769 .76334 .43919 .76959 .43905 .76707 .43802 Metetra
.185 .684 .914 r
.76707 .43802 .76959 .43905 .7759 .43919 .7734 .4383 Metetra
.219 .715 .916 r
.7734 .4383 .7759 .43919 .78223 .43945 .77972 .43827 Metetra
.371 .789 .976 r
.77972 .43827 .78223 .43945 .78857 .43959 .78602 .43773 Metetra
.53 .817 .998 r
.78602 .43773 .78857 .43959 .79491 .43937 .79231 .4367 Metetra
.61 .784 .964 r
.79231 .4367 .79491 .43937 .80122 .43866 .79857 .43531 Metetra
.632 .744 .928 r
.79857 .43531 .80122 .43866 .80752 .43749 .80485 .43382 Metetra
.628 .722 .915 r
.80485 .43382 .80752 .43749 .8138 .43598 .81115 .43242 Metetra
.615 .724 .923 r
.81115 .43242 .8138 .43598 .82008 .43435 .81748 .43119 Metetra
.604 .747 .945 r
.81748 .43119 .82008 .43435 .82638 .43274 .82383 .43001 Metetra
.61 .781 .963 r
.82383 .43001 .82638 .43274 .8327 .43119 .83018 .42862 Metetra
.646 .809 .961 r
.83018 .42862 .8327 .43119 .83904 .42959 .8365 .42674 Metetra
.699 .807 .932 r
.8365 .42674 .83904 .42959 .84536 .42774 .84277 .42417 Metetra
.734 .771 .883 r
.84277 .42417 .84536 .42774 .85165 .42542 .84897 .42089 Metetra
.742 .725 .836 r
.84897 .42089 .85165 .42542 .8579 .42251 .85513 .41705 Metetra
.735 .687 .804 r
.85513 .41705 .8579 .42251 .86409 .41902 .86127 .41295 Metetra
.724 .662 .789 r
.86127 .41295 .86409 .41902 .87025 .41514 .86742 .40891 Metetra
.713 .653 .788 r
.86742 .40891 .87025 .41514 .8764 .41109 .8736 .40514 Metetra
.705 .658 .801 r
.8736 .40514 .8764 .41109 .88256 .40714 .87984 .40174 Metetra
.702 .675 .821 r
.87984 .40174 .88256 .40714 .88876 .40345 .88611 .39864 Metetra
.704 .7 .843 r
.88611 .39864 .88876 .40345 .89501 .40007 .89241 .39566 Metetra
.71 .722 .858 r
.89241 .39566 .89501 .40007 .90129 .39693 .89872 .39266 Metetra
.718 .731 .861 r
.89872 .39266 .90129 .39693 .90759 .39392 .90502 .3895 Metetra
.723 .727 .853 r
.90502 .3895 .90759 .39392 .9139 .3909 .9113 .38619 Metetra
.722 .714 .842 r
.9113 .38619 .9139 .3909 .92022 .3878 .91759 .3828 Metetra
.716 .699 .833 r
.91759 .3828 .92022 .3878 .92653 .38461 .9239 .37945 Metetra
.707 .689 .83 r
.9239 .37945 .92653 .38461 .93286 .38141 .93023 .37627 Metetra
.602 .673 .89 r
.34788 .55296 .35111 .55685 .35636 .55589 .35313 .5522 Metetra
.601 .684 .9 r
.35313 .5522 .35636 .55589 .36162 .55487 .35838 .55141 Metetra
.607 .7 .909 r
.35838 .55141 .36162 .55487 .3669 .55387 .36365 .55053 Metetra
.614 .71 .914 r
.36365 .55053 .3669 .55387 .37218 .55299 .36894 .54954 Metetra
.616 .704 .908 r
.36894 .54954 .37218 .55299 .37746 .5524 .37425 .54854 Metetra
.607 .677 .891 r
.37425 .54854 .37746 .5524 .38274 .55222 .37956 .54769 Metetra
.586 .635 .867 r
.37956 .54769 .38274 .55222 .38801 .55247 .38487 .5472 Metetra
.558 .592 .843 r
.38487 .5472 .38801 .55247 .39329 .55302 .39017 .5472 Metetra
.531 .558 .827 r
.39017 .5472 .39329 .55302 .39859 .55365 .39547 .54768 Metetra
.512 .543 .825 r
.39547 .54768 .39859 .55365 .40391 .55407 .40078 .54847 Metetra
.507 .554 .839 r
.40078 .54847 .40391 .55407 .40926 .55407 .4061 .54924 Metetra
.519 .593 .868 r
.4061 .54924 .40926 .55407 .41464 .55356 .41146 .54966 Metetra
.552 .657 .905 r
.41146 .54966 .41464 .55356 .42006 .55261 .41685 .54946 Metetra
.597 .721 .931 r
.41685 .54946 .42006 .55261 .42549 .55143 .42228 .5486 Metetra
.637 .755 .934 r
.42228 .5486 .42549 .55143 .43093 .55025 .42774 .54721 Metetra
.655 .747 .917 r
.42774 .54721 .43093 .55025 .43639 .54922 .43321 .54561 Metetra
.651 .711 .891 r
.43321 .54561 .43639 .54922 .44185 .54831 .4387 .54408 Metetra
.635 .674 .869 r
.4387 .54408 .44185 .54831 .44733 .54731 .44419 .5428 Metetra
.624 .656 .861 r
.44419 .5428 .44733 .54731 .45283 .54594 .44969 .5417 Metetra
.628 .671 .872 r
.44969 .5417 .45283 .54594 .45836 .54392 .4552 .54052 Metetra
.655 .726 .901 r
.4552 .54052 .45836 .54392 .46391 .54115 .46074 .53892 Metetra
.702 .816 .936 r
.46074 .53892 .46391 .54115 .46948 .5377 .4663 .53659 Metetra
.749 .907 .947 r
.4663 .53659 .46948 .5377 .47506 .53383 .47188 .53345 Metetra
.78 .956 .928 r
.47188 .53345 .47506 .53383 .48064 .52986 .47748 .52963 Metetra
.799 .963 .914 r
.47748 .52963 .48064 .52986 .48623 .52608 .48308 .52545 Metetra
.807 .939 .915 r
.48308 .52545 .48623 .52608 .49182 .52263 .48869 .5213 Metetra
.793 .892 .915 r
.48869 .5213 .49182 .52263 .49741 .5195 .4943 .51747 Metetra
.765 .841 .909 r
.4943 .51747 .49741 .5195 .50301 .51656 .49992 .51409 Metetra
.741 .808 .905 r
.49992 .51409 .50301 .51656 .50861 .51366 .50553 .5111 Metetra
.728 .801 .909 r
.50553 .5111 .50861 .51366 .51423 .51067 .51115 .50833 Metetra
.728 .817 .92 r
.51115 .50833 .51423 .51067 .51985 .50758 .51678 .50558 Metetra
.735 .844 .931 r
.51678 .50558 .51985 .50758 .52547 .50444 .52242 .50272 Metetra
.742 .866 .938 r
.52242 .50272 .52547 .50444 .53111 .5014 .52806 .49973 Metetra
.744 .871 .939 r
.52806 .49973 .53111 .5014 .53675 .49855 .53372 .4967 Metetra
.739 .857 .935 r
.53372 .4967 .53675 .49855 .5424 .49598 .53938 .49376 Metetra
.726 .828 .928 r
.53938 .49376 .5424 .49598 .54806 .49366 .54504 .49103 Metetra
.708 .795 .919 r
.54504 .49103 .54806 .49366 .55373 .49156 .55072 .48857 Metetra
.69 .768 .911 r
.55072 .48857 .55373 .49156 .55942 .48957 .55642 .48637 Metetra
.678 .751 .907 r
.55642 .48637 .55942 .48957 .56512 .48763 .56212 .48437 Metetra
.671 .745 .906 r
.56212 .48437 .56512 .48763 .57082 .4857 .56784 .48247 Metetra
.669 .748 .909 r
.56784 .48247 .57082 .4857 .57654 .48374 .57357 .48059 Metetra
.67 .754 .913 r
.57357 .48059 .57654 .48374 .58227 .48178 .5793 .4787 Metetra
.671 .759 .916 r
.5793 .4787 .58227 .48178 .58802 .47984 .58506 .47678 Metetra
.672 .761 .917 r
.58506 .47678 .58802 .47984 .59377 .47793 .59082 .47484 Metetra
.672 .759 .916 r
.59082 .47484 .59377 .47793 .59954 .47606 .59659 .4729 Metetra
.67 .755 .914 r
.59659 .4729 .59954 .47606 .60532 .47422 .60238 .47098 Metetra
.668 .749 .912 r
.60238 .47098 .60532 .47422 .61111 .47241 .60818 .4691 Metetra
.665 .745 .91 r
.60818 .4691 .61111 .47241 .61691 .47059 .61399 .46725 Metetra
.663 .742 .909 r
.61399 .46725 .61691 .47059 .62273 .46878 .61981 .46543 Metetra
.661 .742 .91 r
.61981 .46543 .62273 .46878 .62856 .46696 .62565 .46364 Metetra
.66 .743 .912 r
.62565 .46364 .62856 .46696 .6344 .46514 .6315 .46186 Metetra
.659 .746 .914 r
.6315 .46186 .6344 .46514 .64025 .46333 .63736 .46009 Metetra
.659 .749 .917 r
.63736 .46009 .64025 .46333 .64611 .46153 .64324 .45831 Metetra
.66 .751 .918 r
.64324 .45831 .64611 .46153 .65199 .45976 .64913 .45652 Metetra
.662 .751 .916 r
.64913 .45652 .65199 .45976 .65789 .458 .65502 .45469 Metetra
.664 .748 .913 r
.65502 .45469 .65789 .458 .66379 .45622 .66093 .45284 Metetra
.663 .743 .91 r
.66093 .45284 .66379 .45622 .66971 .45443 .66686 .45099 Metetra
.659 .739 .909 r
.66686 .45099 .66971 .45443 .67564 .45262 .6728 .4492 Metetra
.651 .737 .913 r
.6728 .4492 .67564 .45262 .68158 .45083 .67875 .44753 Metetra
.638 .741 .923 r
.67875 .44753 .68158 .45083 .68754 .44911 .68473 .44603 Metetra
.621 .75 .938 r
.68473 .44603 .68754 .44911 .69352 .44753 .69073 .4447 Metetra
.604 .763 .955 r
.69073 .4447 .69352 .44753 .69952 .44612 .69676 .44351 Metetra
.593 .776 .967 r
.69676 .44351 .69952 .44612 .70555 .44489 .7028 .44237 Metetra
.594 .783 .971 r
.7028 .44237 .70555 .44489 .7116 .44379 .70885 .44118 Metetra
.604 .78 .965 r
.70885 .44118 .7116 .44379 .71767 .44274 .71492 .43992 Metetra
.611 .767 .954 r
.71492 .43992 .71767 .44274 .72375 .44167 .721 .43863 Metetra
.606 .749 .946 r
.721 .43863 .72375 .44167 .72985 .44055 .7271 .43746 Metetra
.58 .736 .949 r
.7271 .43746 .72985 .44055 .73596 .43945 .73324 .4366 Metetra
.527 .731 .967 r
.73324 .4366 .73596 .43945 .7421 .4385 .73943 .43618 Metetra
.431 .729 .989 r
.73943 .43618 .7421 .4385 .74828 .43784 .74566 .43622 Metetra
.286 .706 .971 r
.74566 .43622 .74828 .43784 .7545 .43758 .75194 .43658 Metetra
.156 .665 .901 r
.75194 .43658 .7545 .43758 .76077 .43769 .75824 .43697 Metetra
.152 .677 .876 r
.75824 .43697 .76077 .43769 .76707 .43802 .76455 .43707 Metetra
.302 .764 .947 r
.76455 .43707 .76707 .43802 .7734 .4383 .77083 .43667 Metetra
.496 .82 1 r
.77083 .43667 .7734 .4383 .77972 .43827 .7771 .43573 Metetra
.6 .79 .972 r
.7771 .43573 .77972 .43827 .78602 .43773 .78335 .43441 Metetra
.626 .743 .932 r
.78335 .43441 .78602 .43773 .79231 .4367 .78961 .433 Metetra
.617 .716 .916 r
.78961 .433 .79231 .4367 .79857 .43531 .7959 .43176 Metetra
.594 .715 .929 r
.7959 .43176 .79857 .43531 .80485 .43382 .80223 .43081 Metetra
.563 .74 .959 r
.80223 .43081 .80485 .43382 .81115 .43242 .8086 .43005 Metetra
.545 .782 .986 r
.8086 .43005 .81115 .43242 .81748 .43119 .81497 .42917 Metetra
.576 .826 .992 r
.81497 .42917 .81748 .43119 .82383 .43001 .82132 .4278 Metetra
.66 .843 .97 r
.82132 .4278 .82383 .43001 .83018 .42862 .82761 .42564 Metetra
.726 .806 .914 r
.82761 .42564 .83018 .42862 .8365 .42674 .83383 .42262 Metetra
.746 .745 .851 r
.83383 .42262 .8365 .42674 .84277 .42417 .83999 .41887 Metetra
.739 .693 .807 r
.83999 .41887 .84277 .42417 .84897 .42089 .84612 .41473 Metetra
.725 .661 .785 r
.84612 .41473 .84897 .42089 .85513 .41705 .85226 .41061 Metetra
.712 .647 .782 r
.85226 .41061 .85513 .41705 .86127 .41295 .85843 .40678 Metetra
.702 .65 .795 r
.85843 .40678 .86127 .41295 .86742 .40891 .86466 .40339 Metetra
.698 .669 .818 r
.86466 .40339 .86742 .40891 .8736 .40514 .87093 .40036 Metetra
.7 .699 .846 r
.87093 .40036 .8736 .40514 .87984 .40174 .87723 .39749 Metetra
.709 .728 .866 r
.87723 .39749 .87984 .40174 .88611 .39864 .88353 .39455 Metetra
.721 .742 .868 r
.88353 .39455 .88611 .39864 .89241 .39566 .88982 .39139 Metetra
.73 .736 .856 r
.88982 .39139 .89241 .39566 .89872 .39266 .89609 .38797 Metetra
.73 .718 .839 r
.89609 .38797 .89872 .39266 .90502 .3895 .90235 .38437 Metetra
.724 .697 .824 r
.90235 .38437 .90502 .3895 .9113 .38619 .90861 .38077 Metetra
.713 .682 .818 r
.90861 .38077 .9113 .38619 .91759 .3828 .91491 .37735 Metetra
.701 .676 .822 r
.91491 .37735 .91759 .3828 .9239 .37945 .92125 .37423 Metetra
.69 .68 .835 r
.92125 .37423 .9239 .37945 .93023 .37627 .92764 .37146 Metetra
.61 .663 .877 r
.34466 .54883 .34788 .55296 .35313 .5522 .3499 .54798 Metetra
.595 .654 .878 r
.3499 .54798 .35313 .5522 .35838 .55141 .35516 .54733 Metetra
.588 .658 .886 r
.35516 .54733 .35838 .55141 .36365 .55053 .36042 .54677 Metetra
.59 .677 .901 r
.36042 .54677 .36365 .55053 .36894 .54954 .3657 .54613 Metetra
.6 .702 .915 r
.3657 .54613 .36894 .54954 .37425 .54854 .371 .5453 Metetra
.612 .718 .92 r
.371 .5453 .37425 .54854 .37956 .54769 .37632 .54431 Metetra
.617 .71 .912 r
.37632 .54431 .37956 .54769 .38487 .5472 .38166 .54326 Metetra
.607 .675 .889 r
.38166 .54326 .38487 .5472 .39017 .5472 .387 .54242 Metetra
.581 .623 .859 r
.387 .54242 .39017 .5472 .39547 .54768 .39233 .54201 Metetra
.549 .573 .831 r
.39233 .54201 .39547 .54768 .40078 .54847 .39766 .5422 Metetra
.52 .538 .815 r
.39766 .5422 .40078 .54847 .4061 .54924 .40299 .54293 Metetra
.501 .527 .815 r
.40299 .54293 .4061 .54924 .41146 .54966 .40832 .54395 Metetra
.499 .547 .837 r
.40832 .54395 .41146 .54966 .41685 .54946 .41368 .54484 Metetra
.521 .605 .878 r
.41368 .54484 .41685 .54946 .42228 .5486 .41908 .54517 Metetra
.567 .693 .926 r
.41908 .54517 .42228 .5486 .42774 .54721 .42452 .54468 Metetra
.626 .775 .952 r
.42452 .54468 .42774 .54721 .43321 .54561 .42999 .54335 Metetra
.672 .807 .948 r
.42999 .54335 .43321 .54561 .4387 .54408 .43549 .54144 Metetra
.687 .783 .924 r
.43549 .54144 .4387 .54408 .44419 .5428 .44101 .53936 Metetra
.673 .729 .892 r
.44101 .53936 .44419 .5428 .44969 .5417 .44654 .53747 Metetra
.648 .68 .866 r
.44654 .53747 .44969 .5417 .4552 .54052 .45206 .53596 Metetra
.632 .658 .857 r
.45206 .53596 .4552 .54052 .46074 .53892 .4576 .53471 Metetra
.636 .677 .871 r
.4576 .53471 .46074 .53892 .4663 .53659 .46314 .53339 Metetra
.667 .743 .907 r
.46314 .53339 .4663 .53659 .47188 .53345 .46871 .53158 Metetra
.719 .848 .943 r
.46871 .53158 .47188 .53345 .47748 .52963 .4743 .52897 Metetra
.762 .94 .941 r
.4743 .52897 .47748 .52963 .48308 .52545 .47991 .52548 Metetra
.785 .978 .91 r
.47991 .52548 .48308 .52545 .48869 .5213 .48554 .52133 Metetra
.805 .977 .901 r
.48554 .52133 .48869 .5213 .4943 .51747 .49117 .5169 Metetra
.811 .944 .912 r
.49117 .5169 .4943 .51747 .49992 .51409 .4968 .51262 Metetra
.79 .884 .913 r
.4968 .51262 .49992 .51409 .50553 .5111 .50243 .50881 Metetra
.756 .824 .905 r
.50243 .50881 .50553 .5111 .51115 .50833 .50806 .50556 Metetra
.727 .787 .9 r
.50806 .50556 .51115 .50833 .51678 .50558 .5137 .50276 Metetra
.714 .782 .905 r
.5137 .50276 .51678 .50558 .52242 .50272 .51935 .50018 Metetra
.716 .803 .918 r
.51935 .50018 .52242 .50272 .52806 .49973 .525 .4976 Metetra
.726 .834 .932 r
.525 .4976 .52806 .49973 .53372 .4967 .53067 .49486 Metetra
.735 .858 .939 r
.53067 .49486 .53372 .4967 .53938 .49376 .53634 .49198 Metetra
.738 .863 .939 r
.53634 .49198 .53938 .49376 .54504 .49103 .54202 .48903 Metetra
.732 .847 .935 r
.54202 .48903 .54504 .49103 .55072 .48857 .54771 .48618 Metetra
.718 .816 .926 r
.54771 .48618 .55072 .48857 .55642 .48637 .5534 .48355 Metetra
.7 .783 .915 r
.5534 .48355 .55642 .48637 .56212 .48437 .55911 .48119 Metetra
.683 .756 .906 r
.55911 .48119 .56212 .48437 .56784 .48247 .56484 .47909 Metetra
.671 .74 .902 r
.56484 .47909 .56784 .48247 .57357 .48059 .57057 .47717 Metetra
.666 .736 .902 r
.57057 .47717 .57357 .48059 .5793 .4787 .57632 .47533 Metetra
.666 .739 .905 r
.57632 .47533 .5793 .4787 .58506 .47678 .58208 .47349 Metetra
.668 .746 .908 r
.58208 .47349 .58506 .47678 .59082 .47484 .58785 .47161 Metetra
.671 .751 .911 r
.58785 .47161 .59082 .47484 .59659 .4729 .59363 .46968 Metetra
.672 .752 .911 r
.59363 .46968 .59659 .4729 .60238 .47098 .59943 .46772 Metetra
.671 .75 .91 r
.59943 .46772 .60238 .47098 .60818 .4691 .60523 .46578 Metetra
.668 .745 .908 r
.60523 .46578 .60818 .4691 .61399 .46725 .61105 .46388 Metetra
.665 .741 .907 r
.61105 .46388 .61399 .46725 .61981 .46543 .61688 .46203 Metetra
.661 .739 .907 r
.61688 .46203 .61981 .46543 .62565 .46364 .62273 .46023 Metetra
.659 .739 .908 r
.62273 .46023 .62565 .46364 .6315 .46186 .62859 .45845 Metetra
.66 .739 .909 r
.62859 .45845 .6315 .46186 .63736 .46009 .63446 .45667 Metetra
.662 .74 .908 r
.63446 .45667 .63736 .46009 .64324 .45831 .64034 .45485 Metetra
.664 .738 .905 r
.64034 .45485 .64324 .45831 .64913 .45652 .64623 .453 Metetra
.665 .735 .902 r
.64623 .453 .64913 .45652 .65502 .45469 .65214 .45112 Metetra
.663 .732 .901 r
.65214 .45112 .65502 .45469 .66093 .45284 .65806 .44928 Metetra
.656 .73 .904 r
.65806 .44928 .66093 .45284 .66686 .45099 .664 .44754 Metetra
.644 .734 .914 r
.664 .44754 .66686 .45099 .6728 .4492 .66995 .44596 Metetra
.629 .743 .929 r
.66995 .44596 .6728 .4492 .67875 .44753 .67593 .44457 Metetra
.614 .756 .946 r
.67593 .44457 .67875 .44753 .68473 .44603 .68193 .4433 Metetra
.604 .771 .96 r
.68193 .4433 .68473 .44603 .69073 .4447 .68795 .44208 Metetra
.606 .78 .964 r
.68795 .44208 .69073 .4447 .69676 .44351 .69398 .4408 Metetra
.618 .778 .957 r
.69398 .4408 .69676 .44351 .7028 .44237 .70002 .43941 Metetra
.628 .764 .944 r
.70002 .43941 .7028 .44237 .70885 .44118 .70607 .43795 Metetra
.625 .744 .932 r
.70607 .43795 .70885 .44118 .71492 .43992 .71214 .43658 Metetra
.604 .729 .933 r
.71214 .43658 .71492 .43992 .721 .43863 .71824 .4355 Metetra
.557 .724 .952 r
.71824 .4355 .721 .43863 .7271 .43746 .72438 .4349 Metetra
.467 .726 .982 r
.72438 .4349 .7271 .43746 .73324 .4366 .73058 .43483 Metetra
.312 .71 .979 r
.73058 .43483 .73324 .4366 .73943 .43618 .73683 .43517 Metetra
.143 .656 .896 r
.73683 .43517 .73943 .43618 .74566 .43622 .7431 .43562 Metetra
.098 .643 .838 r
.7431 .43562 .74566 .43622 .75194 .43658 .74939 .43584 Metetra
.238 .735 .91 r
.74939 .43584 .75194 .43658 .75824 .43697 .75565 .43554 Metetra
.465 .821 .996 r
.75565 .43554 .75824 .43697 .76455 .43707 .7619 .43465 Metetra
.595 .797 .977 r
.7619 .43465 .76455 .43707 .77083 .43667 .76813 .43334 Metetra
.625 .742 .931 r
.76813 .43334 .77083 .43667 .7771 .43573 .77436 .43194 Metetra
.612 .708 .913 r
.77436 .43194 .7771 .43573 .78335 .43441 .78064 .43079 Metetra
.577 .703 .928 r
.78064 .43079 .78335 .43441 .78961 .433 .78697 .43007 Metetra
.52 .727 .968 r
.78697 .43007 .78961 .433 .7959 .43176 .79334 .42971 Metetra
.453 .766 .996 r
.79334 .42971 .7959 .43176 .80223 .43081 .79973 .42936 Metetra
.449 .814 .995 r
.79973 .42936 .80223 .43081 .8086 .43005 .80611 .42855 Metetra
.572 .867 .995 r
.80611 .42855 .8086 .43005 .81497 .42917 .81243 .42688 Metetra
.704 .85 .952 r
.81243 .42688 .81497 .42917 .82132 .4278 .81867 .42417 Metetra
.748 .772 .873 r
.81867 .42417 .82132 .4278 .82761 .42564 .82483 .42056 Metetra
.743 .703 .813 r
.82483 .42056 .82761 .42564 .83383 .42262 .83096 .4164 Metetra
.727 .66 .783 r
.83096 .4164 .83383 .42262 .83999 .41887 .83708 .41219 Metetra
.711 .64 .776 r
.83708 .41219 .83999 .41887 .84612 .41473 .84324 .40832 Metetra
.698 .641 .789 r
.84324 .40832 .84612 .41473 .85226 .41061 .84946 .40496 Metetra
.691 .662 .816 r
.84946 .40496 .85226 .41061 .85843 .40678 .85574 .40205 Metetra
.693 .699 .851 r
.85574 .40205 .85843 .40678 .86466 .40339 .86204 .39935 Metetra
.704 .738 .877 r
.86204 .39935 .86466 .40339 .87093 .40036 .86835 .39656 Metetra
.722 .758 .881 r
.86835 .39656 .87093 .40036 .87723 .39749 .87464 .39345 Metetra
.737 .751 .863 r
.87464 .39345 .87723 .39749 .88353 .39455 .88089 .38994 Metetra
.739 .724 .838 r
.88089 .38994 .88353 .39455 .88982 .39139 .88712 .38614 Metetra
.732 .696 .816 r
.88712 .38614 .88982 .39139 .89609 .38797 .89334 .38227 Metetra
.719 .675 .806 r
.89334 .38227 .89609 .38797 .90235 .38437 .89959 .37856 Metetra
.705 .665 .808 r
.89959 .37856 .90235 .38437 .90861 .38077 .9059 .3752 Metetra
.693 .668 .821 r
.9059 .3752 .90861 .38077 .91491 .37735 .91226 .37227 Metetra
.682 .682 .843 r
.91226 .37227 .91491 .37735 .92125 .37423 .91868 .36973 Metetra
.674 .705 .87 r
.91868 .36973 .92125 .37423 .92764 .37146 .92514 .36744 Metetra
.639 .696 .887 r
.34139 .54512 .34466 .54883 .3499 .54798 .34667 .54382 Metetra
.617 .665 .874 r
.34667 .54382 .3499 .54798 .35516 .54733 .35194 .54285 Metetra
.594 .641 .867 r
.35194 .54285 .35516 .54733 .36042 .54677 .35721 .54223 Metetra
.578 .632 .869 r
.35721 .54223 .36042 .54677 .3657 .54613 .36248 .54185 Metetra
.571 .642 .882 r
.36248 .54185 .3657 .54613 .371 .5453 .36776 .54151 Metetra
.577 .672 .904 r
.36776 .54151 .371 .5453 .37632 .54431 .37306 .54101 Metetra
.594 .709 .923 r
.37306 .54101 .37632 .54431 .38166 .54326 .3784 .54022 Metetra
.614 .732 .93 r
.3784 .54022 .38166 .54326 .387 .54242 .38375 .53916 Metetra
.622 .721 .917 r
.38375 .53916 .387 .54242 .39233 .54201 .38912 .53803 Metetra
.609 .674 .887 r
.38912 .53803 .39233 .54201 .39766 .5422 .3945 .53714 Metetra
.577 .611 .849 r
.3945 .53714 .39766 .5422 .40299 .54293 .39986 .53681 Metetra
.54 .554 .818 r
.39986 .53681 .40299 .54293 .40832 .54395 .40522 .5372 Metetra
.508 .518 .801 r
.40522 .5372 .40832 .54395 .41368 .54484 .41057 .53819 Metetra
.49 .512 .807 r
.41057 .53819 .41368 .54484 .41908 .54517 .41594 .53944 Metetra
.493 .544 .837 r
.41594 .53944 .41908 .54517 .42452 .54468 .42133 .54039 Metetra
.526 .626 .894 r
.42133 .54039 .42452 .54468 .42999 .54335 .42677 .54056 Metetra
.59 .746 .951 r
.42677 .54056 .42999 .54335 .43549 .54144 .43225 .53966 Metetra
.66 .842 .97 r
.43225 .53966 .43549 .54144 .44101 .53936 .43778 .53776 Metetra
.71 .865 .956 r
.43778 .53776 .44101 .53936 .44654 .53747 .44332 .53525 Metetra
.72 .82 .927 r
.44332 .53525 .44654 .53747 .45206 .53596 .44888 .53265 Metetra
.694 .744 .89 r
.44888 .53265 .45206 .53596 .4576 .53471 .45444 .53041 Metetra
.658 .681 .86 r
.45444 .53041 .4576 .53471 .46314 .53339 .46 .5287 Metetra
.637 .656 .852 r
.46 .5287 .46314 .53339 .46871 .53158 .46557 .52736 Metetra
.641 .679 .87 r
.46557 .52736 .46871 .53158 .4743 .52897 .47115 .52594 Metetra
.677 .759 .912 r
.47115 .52594 .4743 .52897 .47991 .52548 .47674 .52397 Metetra
.733 .878 .948 r
.47674 .52397 .47991 .52548 .48554 .52133 .48236 .52111 Metetra
.767 .966 .927 r
.48236 .52111 .48554 .52133 .49117 .5169 .488 .51731 Metetra
.782 .991 .885 r
.488 .51731 .49117 .5169 .4968 .51262 .49365 .51286 Metetra
.806 .986 .888 r
.49365 .51286 .4968 .51262 .50243 .50881 .49931 .50824 Metetra
.813 .945 .91 r
.49931 .50824 .50243 .50881 .50806 .50556 .50496 .5039 Metetra
.785 .872 .912 r
.50496 .5039 .50806 .50556 .5137 .50276 .51061 .50017 Metetra
.743 .804 .9 r
.51061 .50017 .5137 .50276 .51935 .50018 .51627 .49709 Metetra
.712 .766 .895 r
.51627 .49709 .51935 .50018 .525 .4976 .52193 .49451 Metetra
.7 .764 .901 r
.52193 .49451 .525 .4976 .53067 .49486 .52761 .49214 Metetra
.704 .789 .917 r
.52761 .49214 .53067 .49486 .53634 .49198 .53329 .48973 Metetra
.716 .826 .933 r
.53329 .48973 .53634 .49198 .54202 .48903 .53898 .48712 Metetra
.727 .854 .941 r
.53898 .48712 .54202 .48903 .54771 .48618 .54468 .48433 Metetra
.731 .859 .941 r
.54468 .48433 .54771 .48618 .5534 .48355 .55039 .48147 Metetra
.726 .842 .936 r
.55039 .48147 .5534 .48355 .55911 .48119 .5561 .47871 Metetra
.712 .81 .926 r
.5561 .47871 .55911 .48119 .56484 .47909 .56183 .47617 Metetra
.694 .776 .915 r
.56183 .47617 .56484 .47909 .57057 .47717 .56757 .47389 Metetra
.678 .749 .905 r
.56757 .47389 .57057 .47717 .57632 .47533 .57332 .47186 Metetra
.667 .735 .901 r
.57332 .47186 .57632 .47533 .58208 .47349 .57909 .46999 Metetra
.663 .732 .901 r
.57909 .46999 .58208 .47349 .58785 .47161 .58487 .46819 Metetra
.663 .737 .905 r
.58487 .46819 .58785 .47161 .59363 .46968 .59066 .46638 Metetra
.665 .746 .911 r
.59066 .46638 .59363 .46968 .59943 .46772 .59647 .46453 Metetra
.666 .754 .915 r
.59647 .46453 .59943 .46772 .60523 .46578 .60228 .46266 Metetra
.667 .758 .919 r
.60228 .46266 .60523 .46578 .61105 .46388 .60811 .46077 Metetra
.666 .76 .92 r
.60811 .46077 .61105 .46388 .61688 .46203 .61395 .45888 Metetra
.665 .757 .919 r
.61395 .45888 .61688 .46203 .62273 .46023 .6198 .45701 Metetra
.665 .753 .916 r
.6198 .45701 .62273 .46023 .62859 .45845 .62567 .45513 Metetra
.666 .747 .911 r
.62567 .45513 .62859 .45845 .63446 .45667 .63154 .45324 Metetra
.666 .741 .906 r
.63154 .45324 .63446 .45667 .64034 .45485 .63743 .45135 Metetra
.663 .736 .904 r
.63743 .45135 .64034 .45485 .64623 .453 .64333 .4495 Metetra
.657 .735 .907 r
.64333 .4495 .64623 .453 .65214 .45112 .64925 .44773 Metetra
.647 .738 .916 r
.64925 .44773 .65214 .45112 .65806 .44928 .65519 .44611 Metetra
.633 .748 .931 r
.65519 .44611 .65806 .44928 .664 .44754 .66115 .44465 Metetra
.618 .763 .948 r
.66115 .44465 .664 .44754 .66995 .44596 .66712 .44332 Metetra
.609 .778 .962 r
.66712 .44332 .66995 .44596 .67593 .44457 .67312 .44202 Metetra
.612 .788 .965 r
.67312 .44202 .67593 .44457 .68193 .4433 .67912 .44065 Metetra
.628 .785 .957 r
.67912 .44065 .68193 .4433 .68795 .44208 .68514 .43913 Metetra
.642 .769 .94 r
.68514 .43913 .68795 .44208 .69398 .4408 .69116 .4375 Metetra
.642 .746 .924 r
.69116 .4375 .69398 .4408 .70002 .43941 .69719 .43592 Metetra
.624 .726 .921 r
.69719 .43592 .70002 .43941 .70607 .43795 .70326 .43461 Metetra
.582 .719 .938 r
.70326 .43461 .70607 .43795 .71214 .43658 .70937 .43379 Metetra
.5 .724 .973 r
.70937 .43379 .71214 .43658 .71824 .4355 .71553 .43358 Metetra
.345 .716 .985 r
.71553 .43358 .71824 .4355 .72438 .4349 .72174 .43386 Metetra
.143 .654 .898 r
.72174 .43386 .72438 .4349 .73058 .43483 .72799 .43434 Metetra
.056 .615 .805 r
.72799 .43434 .73058 .43483 .73683 .43517 .73425 .43463 Metetra
.18 .704 .868 r
.73425 .43463 .73683 .43517 .7431 .43562 .74049 .43439 Metetra
.438 .822 .989 r
.74049 .43439 .7431 .43562 .74939 .43584 .74671 .43351 Metetra
.596 .805 .98 r
.74671 .43351 .74939 .43584 .75565 .43554 .75291 .43215 Metetra
.63 .74 .927 r
.75291 .43215 .75565 .43554 .7619 .43465 .75912 .43069 Metetra
.613 .698 .905 r
.75912 .43069 .7619 .43465 .76813 .43334 .76538 .42955 Metetra
.567 .688 .922 r
.76538 .42955 .76813 .43334 .77436 .43194 .77169 .429 Metetra
.481 .707 .969 r
.77169 .429 .77436 .43194 .78064 .43079 .77806 .429 Metetra
.34 .727 .984 r
.77806 .429 .78064 .43079 .78697 .43007 .78447 .42918 Metetra
.248 .735 .925 r
.78447 .42918 .78697 .43007 .79334 .42971 .79087 .42897 Metetra
.387 .827 .948 r
.79087 .42897 .79334 .42971 .79973 .42936 .79722 .42785 Metetra
.646 .893 .984 r
.79722 .42785 .79973 .42936 .80611 .42855 .80348 .42552 Metetra
.748 .809 .901 r
.80348 .42552 .80611 .42855 .81243 .42688 .80965 .42208 Metetra
.749 .716 .821 r
.80965 .42208 .81243 .42688 .81867 .42417 .81577 .41792 Metetra
.729 .659 .781 r
.81577 .41792 .81867 .42417 .82483 .42056 .82188 .41363 Metetra
.709 .633 .77 r
.82188 .41363 .82483 .42056 .83096 .4164 .82803 .4097 Metetra
.693 .631 .782 r
.82803 .4097 .83096 .4164 .83708 .41219 .83425 .40639 Metetra
.683 .653 .814 r
.83425 .40639 .83708 .41219 .84324 .40832 .84053 .40366 Metetra
.682 .698 .858 r
.84053 .40366 .84324 .40832 .84946 .40496 .84685 .40122 Metetra
.695 .751 .895 r
.84685 .40122 .84946 .40496 .85574 .40205 .85317 .39866 Metetra
.72 .782 .901 r
.85317 .39866 .85574 .40205 .86204 .39935 .85946 .39567 Metetra
.744 .772 .876 r
.85946 .39567 .86204 .39935 .86835 .39656 .8657 .39213 Metetra
.75 .736 .839 r
.8657 .39213 .86835 .39656 .87464 .39345 .8719 .38812 Metetra
.741 .696 .809 r
.8719 .38812 .87464 .39345 .88089 .38994 .87809 .38394 Metetra
.725 .668 .793 r
.87809 .38394 .88089 .38994 .88712 .38614 .88429 .3799 Metetra
.709 .653 .792 r
.88429 .3799 .88712 .38614 .89334 .38227 .89055 .37626 Metetra
.694 .654 .806 r
.89055 .37626 .89334 .38227 .89959 .37856 .89688 .37314 Metetra
.682 .669 .831 r
.89688 .37314 .89959 .37856 .9059 .3752 .90328 .37052 Metetra
.673 .696 .863 r
.90328 .37052 .9059 .3752 .91226 .37227 .90973 .36824 Metetra
.669 .728 .894 r
.90973 .36824 .91226 .37227 .91868 .36973 .91621 .3661 Metetra
.67 .753 .913 r
.91621 .3661 .91868 .36973 .92514 .36744 .9227 .36394 Metetra
.668 .751 .913 r
.33808 .54218 .34139 .54512 .34667 .54382 .34338 .54044 Metetra
.655 .721 .898 r
.34338 .54044 .34667 .54382 .35194 .54285 .34869 .53889 Metetra
.632 .682 .879 r
.34869 .53889 .35194 .54285 .35721 .54223 .35399 .53769 Metetra
.603 .643 .863 r
.35399 .53769 .35721 .54223 .36248 .54185 .35928 .53694 Metetra
.576 .616 .855 r
.35928 .53694 .36248 .54185 .36776 .54151 .36457 .53661 Metetra
.558 .608 .859 r
.36457 .53661 .36776 .54151 .37306 .54101 .36985 .53654 Metetra
.552 .626 .879 r
.36985 .53654 .37306 .54101 .3784 .54022 .37515 .53645 Metetra
.564 .67 .909 r
.37515 .53645 .3784 .54022 .38375 .53916 .38049 .53608 Metetra
.59 .723 .936 r
.38049 .53608 .38375 .53916 .38912 .53803 .38585 .53527 Metetra
.619 .755 .943 r
.38585 .53527 .38912 .53803 .3945 .53714 .39124 .53407 Metetra
.632 .738 .925 r
.39124 .53407 .3945 .53714 .39986 .53681 .39665 .53279 Metetra
.614 .675 .885 r
.39665 .53279 .39986 .53681 .40522 .5372 .40206 .53182 Metetra
.575 .598 .839 r
.40206 .53182 .40522 .5372 .41057 .53819 .40746 .53155 Metetra
.532 .534 .803 r
.40746 .53155 .41057 .53819 .41594 .53944 .41284 .53215 Metetra
.498 .498 .788 r
.41284 .53215 .41594 .53944 .42133 .54039 .41822 .53342 Metetra
.481 .498 .798 r
.41822 .53342 .42133 .54039 .42677 .54056 .42362 .53488 Metetra
.49 .546 .841 r
.42362 .53488 .42677 .54056 .43225 .53966 .42905 .53585 Metetra
.537 .66 .915 r
.42905 .53585 .43225 .53966 .43778 .53776 .43453 .53576 Metetra
.616 .816 .977 r
.43453 .53576 .43778 .53776 .44332 .53525 .44006 .53434 Metetra
.692 .915 .971 r
.44006 .53434 .44332 .53525 .44888 .53265 .44563 .53177 Metetra
.746 .923 .95 r
.44563 .53177 .44888 .53265 .45444 .53041 .45123 .52859 Metetra
.752 .854 .926 r
.45123 .52859 .45444 .53041 .46 .5287 .45682 .52546 Metetra
.711 .753 .885 r
.45682 .52546 .46 .5287 .46557 .52736 .46242 .5229 Metetra
.664 .677 .853 r
.46242 .5229 .46557 .52736 .47115 .52594 .46801 .52106 Metetra
.637 .649 .845 r
.46801 .52106 .47115 .52594 .47674 .52397 .4736 .51968 Metetra
.643 .678 .868 r
.4736 .51968 .47674 .52397 .48236 .52111 .47921 .51823 Metetra
.684 .772 .918 r
.47921 .51823 .48236 .52111 .488 .51731 .48484 .51614 Metetra
.742 .906 .95 r
.48484 .51614 .488 .51731 .49365 .51286 .49049 .51305 Metetra
.763 .984 .905 r
.49049 .51305 .49365 .51286 .49931 .50824 .49615 .50899 Metetra
.772 .996 .857 r
.49615 .50899 .49931 .50824 .50496 .5039 .50182 .5043 Metetra
.805 .991 .877 r
.50182 .5043 .50496 .5039 .51061 .50017 .5075 .49953 Metetra
.813 .943 .911 r
.5075 .49953 .51061 .50017 .51627 .49709 .51317 .4952 Metetra
.776 .856 .91 r
.51317 .4952 .51627 .49709 .52193 .49451 .51885 .4916 Metetra
.728 .782 .895 r
.51885 .4916 .52193 .49451 .52761 .49214 .52453 .48873 Metetra
.696 .745 .889 r
.52453 .48873 .52761 .49214 .53329 .48973 .53022 .48639 Metetra
.685 .746 .898 r
.53022 .48639 .53329 .48973 .53898 .48712 .53592 .48425 Metetra
.692 .778 .917 r
.53592 .48425 .53898 .48712 .54468 .48433 .54163 .48201 Metetra
.707 .821 .935 r
.54163 .48201 .54468 .48433 .55039 .48147 .54735 .47953 Metetra
.72 .852 .944 r
.54735 .47953 .55039 .48147 .5561 .47871 .55308 .47683 Metetra
.725 .858 .944 r
.55308 .47683 .5561 .47871 .56183 .47617 .55882 .47405 Metetra
.72 .84 .938 r
.55882 .47405 .56183 .47617 .56757 .47389 .56456 .47136 Metetra
.706 .807 .928 r
.56456 .47136 .56757 .47389 .57332 .47186 .57032 .46888 Metetra
.688 .772 .916 r
.57032 .46888 .57332 .47186 .57909 .46999 .57609 .46669 Metetra
.671 .747 .908 r
.57609 .46669 .57909 .46999 .58487 .46819 .58188 .46474 Metetra
.66 .736 .906 r
.58188 .46474 .58487 .46819 .59066 .46638 .58768 .46296 Metetra
.656 .736 .909 r
.58768 .46296 .59066 .46638 .59647 .46453 .5935 .46125 Metetra
.657 .745 .915 r
.5935 .46125 .59647 .46453 .60228 .46266 .59932 .45951 Metetra
.661 .756 .921 r
.59932 .45951 .60228 .46266 .60811 .46077 .60516 .4577 Metetra
.667 .764 .922 r
.60516 .4577 .60811 .46077 .61395 .45888 .61101 .45579 Metetra
.672 .764 .919 r
.61101 .45579 .61395 .45888 .6198 .45701 .61687 .4538 Metetra
.674 .758 .914 r
.61687 .4538 .6198 .45701 .62567 .45513 .62274 .45178 Metetra
.672 .748 .908 r
.62274 .45178 .62567 .45513 .63154 .45324 .62862 .4498 Metetra
.664 .74 .907 r
.62862 .4498 .63154 .45324 .63743 .45135 .63452 .44792 Metetra
.653 .738 .912 r
.63452 .44792 .63743 .45135 .64333 .4495 .64043 .44622 Metetra
.639 .743 .924 r
.64043 .44622 .64333 .4495 .64925 .44773 .64637 .4447 Metetra
.625 .755 .94 r
.64637 .4447 .64925 .44773 .65519 .44611 .65232 .44332 Metetra
.617 .77 .954 r
.65232 .44332 .65519 .44611 .66115 .44465 .6583 .44198 Metetra
.622 .781 .958 r
.6583 .44198 .66115 .44465 .66712 .44332 .66428 .44054 Metetra
.638 .78 .949 r
.66428 .44054 .66712 .44332 .67312 .44202 .67027 .43893 Metetra
.654 .763 .93 r
.67027 .43893 .67312 .44202 .67912 .44065 .67626 .43715 Metetra
.656 .738 .91 r
.67626 .43715 .67912 .44065 .68514 .43913 .68227 .43537 Metetra
.641 .717 .903 r
.68227 .43537 .68514 .43913 .69116 .4375 .68831 .43383 Metetra
.605 .708 .917 r
.68831 .43383 .69116 .4375 .69719 .43592 .69438 .4328 Metetra
.534 .715 .956 r
.69438 .4328 .69719 .43592 .70326 .43461 .70051 .43241 Metetra
.392 .72 .988 r
.70051 .43241 .70326 .43461 .70937 .43379 .70668 .43261 Metetra
.172 .666 .918 r
.70668 .43261 .70937 .43379 .71553 .43358 .7129 .43309 Metetra
.042 .604 .796 r
.7129 .43309 .71553 .43358 .72174 .43386 .71913 .43343 Metetra
.143 .681 .838 r
.71913 .43343 .72174 .43386 .72799 .43434 .72535 .43324 Metetra
.42 .822 .981 r
.72535 .43324 .72799 .43434 .73425 .43463 .73154 .43234 Metetra
.604 .811 .98 r
.73154 .43234 .73425 .43463 .74049 .43439 .73771 .43089 Metetra
.64 .737 .919 r
.73771 .43089 .74049 .43439 .74671 .43351 .74389 .4293 Metetra
.619 .687 .892 r
.74389 .4293 .74671 .43351 .75291 .43215 .75012 .42809 Metetra
.565 .672 .911 r
.75012 .42809 .75291 .43215 .75912 .43069 .75641 .42764 Metetra
.452 .684 .965 r
.75641 .42764 .75912 .43069 .76538 .42955 .76278 .42794 Metetra
.217 .666 .95 r
.76278 .42794 .76538 .42955 .77169 .429 .76919 .42864 Metetra
.001 .574 .76 r
.76919 .42864 .77169 .429 .77806 .429 .77562 .42905 Metetra
.093 .651 .746 r
.77562 .42905 .77806 .429 .78447 .42918 .78199 .42853 Metetra
.499 .89 .956 r
.78199 .42853 .78447 .42918 .79087 .42897 .78827 .42664 Metetra
.74 .856 .934 r
.78827 .42664 .79087 .42897 .79722 .42785 .79445 .42341 Metetra
.755 .733 .832 r
.79445 .42341 .79722 .42785 .80348 .42552 .80056 .41926 Metetra
.731 .66 .779 r
.80056 .41926 .80348 .42552 .80965 .42208 .80666 .41487 Metetra
.707 .625 .764 r
.80666 .41487 .80965 .42208 .81577 .41792 .8128 .41087 Metetra
.687 .619 .775 r
.8128 .41087 .81577 .41792 .82188 .41363 .81901 .40763 Metetra
.672 .642 .811 r
.81901 .40763 .82188 .41363 .82803 .4097 .8253 .40514 Metetra
.667 .696 .868 r
.8253 .40514 .82803 .4097 .83425 .40639 .83164 .40303 Metetra
.676 .767 .92 r
.83164 .40303 .83425 .40639 .84053 .40366 .83798 .40082 Metetra
.71 .814 .93 r
.83798 .40082 .84053 .40366 .84685 .40122 .84428 .39804 Metetra
.749 .804 .897 r
.84428 .39804 .84685 .40122 .85317 .39866 .85052 .39452 Metetra
.762 .753 .845 r
.85052 .39452 .85317 .39866 .85946 .39567 .85669 .39033 Metetra
.751 .7 .803 r
.85669 .39033 .85946 .39567 .8657 .39213 .86284 .38581 Metetra
.732 .661 .781 r
.86284 .38581 .8657 .39213 .8719 .38812 .869 .38139 Metetra
.712 .641 .776 r
.869 .38139 .8719 .38812 .87809 .38394 .87522 .37741 Metetra
.695 .639 .789 r
.87522 .37741 .87809 .38394 .88429 .3799 .88151 .37408 Metetra
.682 .654 .817 r
.88151 .37408 .88429 .3799 .89055 .37626 .88788 .37137 Metetra
.671 .686 .855 r
.88788 .37137 .89055 .37626 .89688 .37314 .89432 .3691 Metetra
.666 .726 .894 r
.89432 .3691 .89688 .37314 .90328 .37052 .90079 .36702 Metetra
.667 .76 .919 r
.90079 .36702 .90328 .37052 .90973 .36824 .90727 .3649 Metetra
.678 .775 .924 r
.90727 .3649 .90973 .36824 .91621 .3661 .91375 .3626 Metetra
.69 .77 .913 r
.91375 .3626 .91621 .3661 .9227 .36394 .92021 .3601 Metetra
.666 .773 .93 r
.33473 .53956 .33808 .54218 .34338 .54044 .34004 .53783 Metetra
.674 .776 .927 r
.34004 .53783 .34338 .54044 .34869 .53889 .34537 .53598 Metetra
.671 .756 .914 r
.34537 .53598 .34869 .53889 .35399 .53769 .35071 .53418 Metetra
.653 .714 .893 r
.35071 .53418 .35399 .53769 .35928 .53694 .35605 .53265 Metetra
.622 .663 .869 r
.35605 .53265 .35928 .53694 .36457 .53661 .36137 .53159 Metetra
.587 .616 .848 r
.36137 .53159 .36457 .53661 .36985 .53654 .36667 .53111 Metetra
.555 .586 .84 r
.36667 .53111 .36985 .53654 .37515 .53645 .37197 .53114 Metetra
.535 .581 .848 r
.37197 .53114 .37515 .53645 .38049 .53608 .37728 .53143 Metetra
.532 .609 .876 r
.37728 .53143 .38049 .53608 .38585 .53527 .3826 .53162 Metetra
.551 .673 .919 r
.3826 .53162 .38585 .53527 .39124 .53407 .38796 .53135 Metetra
.589 .749 .954 r
.38796 .53135 .39124 .53407 .39665 .53279 .39336 .53045 Metetra
.63 .79 .959 r
.39336 .53045 .39665 .53279 .40206 .53182 .3988 .52903 Metetra
.647 .763 .933 r
.3988 .52903 .40206 .53182 .40746 .53155 .40424 .5275 Metetra
.623 .679 .882 r
.40424 .5275 .40746 .53155 .41284 .53215 .40969 .5264 Metetra
.573 .585 .827 r
.40969 .5264 .41284 .53215 .41822 .53342 .41512 .52618 Metetra
.524 .515 .788 r
.41512 .52618 .41822 .53342 .42362 .53488 .42053 .52701 Metetra
.488 .479 .774 r
.42053 .52701 .42362 .53488 .42905 .53585 .42595 .52858 Metetra
.472 .486 .791 r
.42595 .52858 .42905 .53585 .43453 .53576 .43138 .53024 Metetra
.489 .553 .848 r
.43138 .53024 .43453 .53576 .44006 .53434 .43685 .53117 Metetra
.552 .708 .944 r
.43685 .53117 .44006 .53434 .44563 .53177 .44237 .53072 Metetra
.639 .895 .985 r
.44237 .53072 .44563 .53177 .45123 .52859 .44795 .52867 Metetra
.703 .971 .929 r
.44795 .52867 .45123 .52859 .45682 .52546 .45357 .52535 Metetra
.772 .969 .923 r
.45357 .52535 .45682 .52546 .46242 .5229 .4592 .52145 Metetra
.782 .883 .919 r
.4592 .52145 .46242 .5229 .46801 .52106 .46483 .5178 Metetra
.724 .756 .878 r
.46483 .5178 .46801 .52106 .4736 .51968 .47046 .51497 Metetra
.664 .667 .843 r
.47046 .51497 .4736 .51968 .47921 .51823 .47608 .51306 Metetra
.634 .637 .836 r
.47608 .51306 .47921 .51823 .48484 .51614 .4817 .51173 Metetra
.641 .672 .865 r
.4817 .51173 .48484 .51614 .49049 .51305 .48734 .5103 Metetra
.689 .783 .922 r
.48734 .5103 .49049 .51305 .49615 .50899 .49299 .50812 Metetra
.746 .93 .949 r
.49299 .50812 .49615 .50899 .50182 .5043 .49867 .50485 Metetra
.751 .992 .877 r
.49867 .50485 .50182 .5043 .5075 .49953 .50436 .50055 Metetra
.76 .996 .829 r
.50436 .50055 .5075 .49953 .51317 .4952 .51005 .49566 Metetra
.805 .994 .871 r
.51005 .49566 .51317 .4952 .51885 .4916 .51575 .4908 Metetra
.812 .934 .912 r
.51575 .4908 .51885 .4916 .52453 .48873 .52144 .4865 Metetra
.765 .834 .905 r
.52144 .4865 .52453 .48873 .53022 .48639 .52714 .48305 Metetra
.712 .754 .885 r
.52714 .48305 .53022 .48639 .53592 .48425 .53285 .48041 Metetra
.68 .717 .877 r
.53285 .48041 .53592 .48425 .54163 .48201 .53857 .47829 Metetra
.672 .722 .886 r
.53857 .47829 .54163 .48201 .54735 .47953 .5443 .47633 Metetra
.683 .756 .907 r
.5443 .47633 .54735 .47953 .55308 .47683 .55004 .47421 Metetra
.701 .8 .926 r
.55004 .47421 .55308 .47683 .55882 .47405 .55579 .47181 Metetra
.717 .831 .935 r
.55579 .47181 .55882 .47405 .56456 .47136 .56155 .46916 Metetra
.722 .836 .935 r
.56155 .46916 .56456 .47136 .57032 .46888 .56731 .46643 Metetra
.715 .816 .928 r
.56731 .46643 .57032 .46888 .57609 .46669 .57309 .46381 Metetra
.699 .783 .916 r
.57309 .46381 .57609 .46669 .58188 .46474 .57888 .46142 Metetra
.681 .75 .904 r
.57888 .46142 .58188 .46474 .58768 .46296 .58468 .45931 Metetra
.667 .726 .894 r
.58468 .45931 .58768 .46296 .5935 .46125 .5905 .45741 Metetra
.66 .714 .888 r
.5905 .45741 .5935 .46125 .59932 .45951 .59633 .45562 Metetra
.66 .711 .886 r
.59633 .45562 .59932 .45951 .60516 .4577 .60218 .45382 Metetra
.664 .714 .886 r
.60218 .45382 .60516 .4577 .61101 .45579 .60804 .45196 Metetra
.667 .718 .887 r
.60804 .45196 .61101 .45579 .61687 .4538 .6139 .45004 Metetra
.666 .722 .891 r
.6139 .45004 .61687 .4538 .62274 .45178 .61978 .44813 Metetra
.66 .727 .899 r
.61978 .44813 .62274 .45178 .62862 .4498 .62568 .44633 Metetra
.649 .734 .912 r
.62568 .44633 .62862 .4498 .63452 .44792 .63159 .44469 Metetra
.636 .745 .928 r
.63159 .44469 .63452 .44792 .64043 .44622 .63753 .44321 Metetra
.627 .758 .941 r
.63753 .44321 .64043 .44622 .64637 .4447 .64348 .44179 Metetra
.63 .767 .945 r
.64348 .44179 .64637 .4447 .65232 .44332 .64944 .44031 Metetra
.645 .765 .936 r
.64944 .44031 .65232 .44332 .6583 .44198 .65541 .43866 Metetra
.66 .75 .917 r
.65541 .43866 .6583 .44198 .66428 .44054 .66138 .43681 Metetra
.664 .727 .896 r
.66138 .43681 .66428 .44054 .67027 .43893 .66737 .43491 Metetra
.652 .707 .887 r
.66737 .43491 .67027 .43893 .67626 .43715 .67337 .4332 Metetra
.621 .698 .9 r
.67337 .4332 .67626 .43715 .68227 .43537 .67941 .43198 Metetra
.559 .707 .94 r
.67941 .43198 .68227 .43537 .68831 .43383 .68551 .43143 Metetra
.427 .721 .986 r
.68551 .43143 .68831 .43383 .69438 .4328 .69165 .43153 Metetra
.192 .674 .93 r
.69165 .43153 .69438 .4328 .70051 .43241 .69783 .43199 Metetra
.02 .588 .777 r
.69783 .43199 .70051 .43241 .70668 .43261 .70403 .43236 Metetra
.097 .652 .795 r
.70403 .43236 .70668 .43261 .7129 .43309 .71023 .43218 Metetra
.398 .822 .966 r
.71023 .43218 .7129 .43309 .71913 .43343 .71639 .43124 Metetra
.614 .822 .98 r
.71639 .43124 .71913 .43343 .72535 .43324 .72254 .42965 Metetra
.653 .736 .91 r
.72254 .42965 .72535 .43324 .73154 .43234 .72868 .42787 Metetra
.629 .678 .878 r
.72868 .42787 .73154 .43234 .73771 .43089 .73487 .42651 Metetra
.57 .657 .895 r
.73487 .42651 .73771 .43089 .74389 .4293 .74113 .42606 Metetra
.437 .662 .956 r
.74113 .42606 .74389 .4293 .75012 .42809 .74749 .4266 Metetra
.103 .596 .903 r
.74749 .4266 .75012 .42809 .75641 .42764 .75391 .42776 Metetra
.223 0 0 r
.75391 .42776 .75641 .42764 .76278 .42794 .76034 .42881 Metetra
.196 0 0 r
.76034 .42881 .76278 .42794 .76919 .42864 .76673 .42892 Metetra
.216 .738 .761 r
.76673 .42892 .76919 .42864 .77562 .42905 .77303 .42752 Metetra
.71 .909 .965 r
.77303 .42752 .77562 .42905 .78199 .42853 .77922 .42452 Metetra
.762 .756 .847 r
.77922 .42452 .78199 .42853 .78827 .42664 .78533 .42038 Metetra
.735 .662 .778 r
.78533 .42038 .78827 .42664 .79445 .42341 .79141 .41587 Metetra
.705 .618 .756 r
.79141 .41587 .79445 .42341 .80056 .41926 .79754 .41179 Metetra
.68 .607 .766 r
.79754 .41179 .80056 .41926 .80666 .41487 .80374 .40862 Metetra
.66 .628 .807 r
.80374 .40862 .80666 .41487 .8128 .41087 .81005 .40641 Metetra
.644 .69 .879 r
.81005 .40641 .8128 .41087 .81901 .40763 .81641 .40473 Metetra
.64 .786 .951 r
.81641 .40473 .81901 .40763 .8253 .40514 .82278 .40297 Metetra
.678 .856 .967 r
.82278 .40297 .8253 .40514 .83164 .40303 .8291 .40053 Metetra
.749 .851 .926 r
.8291 .40053 .83164 .40303 .83798 .40082 .83534 .3971 Metetra
.776 .78 .856 r
.83534 .3971 .83798 .40082 .84428 .39804 .8415 .39275 Metetra
.762 .706 .799 r
.8415 .39275 .84428 .39804 .85052 .39452 .84761 .38788 Metetra
.738 .656 .768 r
.84761 .38788 .85052 .39452 .85669 .39033 .85372 .38302 Metetra
.715 .629 .76 r
.85372 .38302 .85669 .39033 .86284 .38581 .85989 .37866 Metetra
.696 .623 .772 r
.85989 .37866 .86284 .38581 .869 .38139 .86615 .37508 Metetra
.68 .638 .801 r
.86615 .37508 .869 .38139 .87522 .37741 .8725 .37228 Metetra
.668 .673 .846 r
.8725 .37228 .87522 .37741 .88151 .37408 .87892 .37004 Metetra
.66 .723 .896 r
.87892 .37004 .88151 .37408 .88788 .37137 .88539 .36805 Metetra
.662 .769 .929 r
.88539 .36805 .88788 .37137 .89432 .3691 .89186 .36601 Metetra
.677 .791 .935 r
.89186 .36601 .89432 .3691 .90079 .36702 .89832 .36371 Metetra
.695 .784 .919 r
.89832 .36371 .90079 .36702 .90727 .3649 .90476 .36113 Metetra
.705 .759 .894 r
.90476 .36113 .90727 .3649 .91375 .3626 .91119 .35833 Metetra
.703 .731 .873 r
.91119 .35833 .91375 .3626 .92021 .3601 .91762 .35548 Metetra
.64 .737 .919 r
.3314 .53649 .33473 .53956 .34004 .53783 .33669 .53512 Metetra
.653 .766 .932 r
.33669 .53512 .34004 .53783 .34537 .53598 .34202 .53355 Metetra
.669 .789 .938 r
.34202 .53355 .34537 .53598 .35071 .53418 .34736 .53174 Metetra
.68 .79 .933 r
.34736 .53174 .35071 .53418 .35605 .53265 .35272 .52979 Metetra
.675 .761 .915 r
.35272 .52979 .35605 .53265 .36137 .53159 .35809 .52791 Metetra
.65 .705 .887 r
.35809 .52791 .36137 .53159 .36667 .53111 .36345 .5264 Metetra
.61 .641 .856 r
.36345 .5264 .36667 .53111 .37197 .53114 .3688 .52552 Metetra
.567 .585 .831 r
.3688 .52552 .37197 .53114 .37728 .53143 .37412 .52538 Metetra
.531 .553 .822 r
.37412 .52538 .37728 .53143 .3826 .53162 .37943 .52585 Metetra
.509 .552 .835 r
.37943 .52585 .3826 .53162 .38796 .53135 .38475 .52657 Metetra
.509 .594 .874 r
.38475 .52657 .38796 .53135 .39336 .53045 .3901 .52704 Metetra
.537 .684 .934 r
.3901 .52704 .39336 .53045 .3988 .52903 .39549 .52682 Metetra
.589 .79 .976 r
.39549 .52682 .3988 .52903 .40424 .5275 .40094 .52573 Metetra
.646 .84 .975 r
.40094 .52573 .40424 .5275 .40969 .5264 .40641 .52398 Metetra
.669 .796 .942 r
.40641 .52398 .40969 .5264 .41512 .52618 .41191 .52211 Metetra
.634 .683 .879 r
.41191 .52211 .41512 .52618 .42053 .52701 .41739 .52083 Metetra
.572 .571 .814 r
.41739 .52083 .42053 .52701 .42595 .52858 .42285 .52066 Metetra
.516 .495 .772 r
.42285 .52066 .42595 .52858 .43138 .53024 .4283 .52173 Metetra
.478 .461 .76 r
.4283 .52173 .43138 .53024 .43685 .53117 .43374 .52361 Metetra
.465 .475 .784 r
.43374 .52361 .43685 .53117 .44237 .53072 .4392 .52546 Metetra
.489 .565 .859 r
.4392 .52546 .44237 .53072 .44795 .52867 .44472 .52629 Metetra
.57 .775 .975 r
.44472 .52629 .44795 .52867 .45357 .52535 .45029 .5254 Metetra
.63 .952 .935 r
.45029 .5254 .45357 .52535 .4592 .52145 .45591 .52262 Metetra
.672 .974 .821 r
.45591 .52262 .4592 .52145 .46483 .5178 .46157 .51846 Metetra
.781 .995 .87 r
.46157 .51846 .46483 .5178 .47046 .51497 .46724 .51383 Metetra
.806 .906 .91 r
.46724 .51383 .47046 .51497 .47608 .51306 .47291 .50969 Metetra
.731 .753 .87 r
.47291 .50969 .47608 .51306 .4817 .51173 .47856 .50666 Metetra
.66 .653 .832 r
.47856 .50666 .4817 .51173 .48734 .5103 .48421 .50479 Metetra
.626 .622 .827 r
.48421 .50479 .48734 .5103 .49299 .50812 .48986 .50357 Metetra
.635 .665 .862 r
.48986 .50357 .49299 .50812 .49867 .50485 .49552 .50223 Metetra
.689 .794 .93 r
.49552 .50223 .49867 .50485 .50436 .50055 .50121 .50003 Metetra
.741 .952 .945 r
.50121 .50003 .50436 .50055 .51005 .49566 .50691 .49663 Metetra
.72 .988 .834 r
.50691 .49663 .51005 .49566 .51575 .4908 .51262 .49215 Metetra
.729 .986 .789 r
.51262 .49215 .51575 .4908 .52144 .4865 .51834 .48712 Metetra
.793 .997 .859 r
.51834 .48712 .52144 .4865 .52714 .48305 .52405 .48222 Metetra
.806 .935 .916 r
.52405 .48222 .52714 .48305 .53285 .48041 .52977 .47802 Metetra
.753 .823 .907 r
.52977 .47802 .53285 .48041 .53857 .47829 .5355 .47476 Metetra
.697 .741 .885 r
.5355 .47476 .53857 .47829 .5443 .47633 .54123 .47237 Metetra
.665 .707 .879 r
.54123 .47237 .5443 .47633 .55004 .47421 .54698 .4705 Metetra
.658 .719 .894 r
.54698 .4705 .55004 .47421 .55579 .47181 .55275 .46877 Metetra
.669 .764 .921 r
.55275 .46877 .55579 .47181 .56155 .46916 .55852 .46685 Metetra
.687 .821 .947 r
.55852 .46685 .56155 .46916 .56731 .46643 .5643 .46461 Metetra
.701 .862 .959 r
.5643 .46461 .56731 .46643 .57309 .46381 .57009 .46211 Metetra
.707 .873 .959 r
.57009 .46211 .57309 .46381 .57888 .46142 .57589 .45948 Metetra
.707 .855 .953 r
.57589 .45948 .57888 .46142 .58468 .45931 .58169 .45691 Metetra
.698 .819 .94 r
.58169 .45691 .58468 .45931 .5905 .45741 .58751 .45451 Metetra
.684 .78 .924 r
.58751 .45451 .5905 .45741 .59633 .45562 .59335 .45234 Metetra
.67 .752 .912 r
.59335 .45234 .59633 .45562 .60218 .45382 .5992 .45038 Metetra
.658 .739 .91 r
.5992 .45038 .60218 .45382 .60804 .45196 .60507 .44862 Metetra
.647 .741 .918 r
.60507 .44862 .60804 .45196 .6139 .45004 .61095 .447 Metetra
.635 .758 .937 r
.61095 .447 .6139 .45004 .61978 .44813 .61685 .4455 Metetra
.622 .783 .959 r
.61685 .4455 .61978 .44813 .62568 .44633 .62277 .44406 Metetra
.614 .809 .975 r
.62277 .44406 .62568 .44633 .63159 .44469 .6287 .44259 Metetra
.62 .825 .979 r
.6287 .44259 .63159 .44469 .63753 .44321 .63464 .44098 Metetra
.645 .824 .969 r
.63464 .44098 .63753 .44321 .64348 .44179 .64058 .43915 Metetra
.671 .8 .944 r
.64058 .43915 .64348 .44179 .64944 .44031 .64653 .4371 Metetra
.679 .764 .915 r
.64653 .4371 .64944 .44031 .65541 .43866 .65249 .43497 Metetra
.667 .731 .897 r
.65249 .43497 .65541 .43866 .66138 .43681 .65847 .43302 Metetra
.636 .714 .903 r
.65847 .43302 .66138 .43681 .66737 .43491 .66448 .43156 Metetra
.575 .717 .939 r
.66448 .43156 .66737 .43491 .67337 .4332 .67054 .43081 Metetra
.445 .731 .988 r
.67054 .43081 .67337 .4332 .67941 .43198 .67665 .43077 Metetra
.19 .677 .926 r
.67665 .43077 .67941 .43198 .68551 .43143 .6828 .43117 Metetra
0 .563 .735 r
.6828 .43117 .68551 .43143 .69165 .43153 .68897 .43152 Metetra
.044 .613 .732 r
.68897 .43152 .69165 .43153 .69783 .43199 .69513 .43132 Metetra
.371 .82 .942 r
.69513 .43132 .69783 .43199 .70403 .43236 .70127 .43029 Metetra
.628 .837 .98 r
.70127 .43029 .70403 .43236 .71023 .43218 .70738 .42851 Metetra
.67 .737 .901 r
.70738 .42851 .71023 .43218 .71639 .43124 .71349 .42647 Metetra
.642 .67 .861 r
.71349 .42647 .71639 .43124 .72254 .42965 .71964 .42487 Metetra
.581 .642 .876 r
.71964 .42487 .72254 .42965 .72868 .42787 .72587 .42431 Metetra
.439 .642 .943 r
.72587 .42431 .72868 .42787 .73487 .42651 .7322 .425 Metetra
.02 .535 .864 r
.7322 .425 .73487 .42651 .74113 .42606 .73861 .42659 Metetra
.379 0 0 r
.73861 .42659 .74113 .42606 .74749 .4266 .74506 .42826 Metetra
.384 0 0 r
.74506 .42826 .74749 .4266 .75391 .42776 .75147 .42902 Metetra
.097 0 0 r
.75147 .42902 .75391 .42776 .76034 .42881 .75778 .42814 Metetra
.623 .939 .958 r
.75778 .42814 .76034 .42881 .76673 .42892 .76398 .42542 Metetra
.771 .784 .863 r
.76398 .42542 .76673 .42892 .77303 .42752 .77008 .42128 Metetra
.739 .664 .776 r
.77008 .42128 .77303 .42752 .77922 .42452 .77615 .41663 Metetra
.704 .61 .749 r
.77615 .41663 .77922 .42452 .78533 .42038 .78225 .41242 Metetra
.674 .593 .757 r
.78225 .41242 .78533 .42038 .79141 .41587 .78846 .40931 Metetra
.645 .611 .801 r
.78846 .40931 .79141 .41587 .79754 .41179 .79477 .40741 Metetra
.613 .681 .89 r
.79477 .40741 .79754 .41179 .80374 .40862 .80116 .40626 Metetra
.57 .799 .985 r
.80116 .40626 .80374 .40862 .81005 .40641 .80756 .40508 Metetra
.587 .889 .99 r
.80756 .40508 .81005 .40641 .81641 .40473 .81391 .4031 Metetra
.726 .91 .958 r
.81391 .4031 .81641 .40473 .82278 .40297 .82016 .39987 Metetra
.791 .819 .874 r
.82016 .39987 .82278 .40297 .8291 .40053 .82631 .3954 Metetra
.776 .716 .797 r
.82631 .3954 .8291 .40053 .83534 .3971 .83238 .39015 Metetra
.745 .652 .756 r
.83238 .39015 .83534 .3971 .8415 .39275 .83845 .38481 Metetra
.718 .618 .744 r
.83845 .38481 .8415 .39275 .84761 .38788 .84457 .38 Metetra
.695 .607 .754 r
.84457 .38 .84761 .38788 .85372 .38302 .85079 .37612 Metetra
.677 .62 .784 r
.85079 .37612 .85372 .38302 .85989 .37866 .85711 .37322 Metetra
.663 .659 .836 r
.85711 .37322 .85989 .37866 .86615 .37508 .86353 .37105 Metetra
.652 .721 .899 r
.86353 .37105 .86615 .37508 .8725 .37228 .86999 .36921 Metetra
.651 .782 .944 r
.86999 .36921 .8725 .37228 .87892 .37004 .87646 .36728 Metetra
.672 .814 .951 r
.87646 .36728 .87892 .37004 .88539 .36805 .88291 .36502 Metetra
.701 .804 .929 r
.88291 .36502 .88539 .36805 .89186 .36601 .88933 .36234 Metetra
.715 .769 .895 r
.88933 .36234 .89186 .36601 .89832 .36371 .89572 .35936 Metetra
.713 .731 .865 r
.89572 .35936 .89832 .36371 .90476 .36113 .90211 .35627 Metetra
.702 .704 .848 r
.90211 .35627 .90476 .36113 .91119 .35833 .90852 .3533 Metetra
.689 .69 .846 r
.90852 .3533 .91119 .35833 .91762 .35548 .91498 .35058 Metetra
.625 .694 .894 r
.32809 .53276 .3314 .53649 .33669 .53512 .33338 .53163 Metetra
.624 .707 .906 r
.33338 .53163 .33669 .53512 .34202 .53355 .33868 .5305 Metetra
.633 .738 .924 r
.33868 .5305 .34202 .53355 .34736 .53174 .344 .5292 Metetra
.652 .779 .942 r
.344 .5292 .34736 .53174 .35272 .52979 .34935 .52761 Metetra
.674 .81 .948 r
.34935 .52761 .35272 .52979 .35809 .52791 .35473 .5257 Metetra
.689 .81 .94 r
.35473 .5257 .35809 .52791 .36345 .5264 .36013 .5236 Metetra
.682 .768 .917 r
.36013 .5236 .36345 .5264 .3688 .52552 .36553 .52162 Metetra
.647 .694 .88 r
.36553 .52162 .3688 .52552 .37412 .52538 .37092 .52015 Metetra
.597 .614 .84 r
.37092 .52015 .37412 .52538 .37943 .52585 .37628 .5195 Metetra
.546 .551 .811 r
.37628 .5195 .37943 .52585 .38475 .52657 .38162 .51978 Metetra
.505 .517 .802 r
.38162 .51978 .38475 .52657 .3901 .52704 .38695 .52077 Metetra
.482 .52 .821 r
.38695 .52077 .3901 .52704 .39549 .52682 .39228 .52197 Metetra
.484 .579 .875 r
.39228 .52197 .39549 .52682 .40094 .52573 .39766 .52272 Metetra
.522 .707 .955 r
.39766 .52272 .40094 .52573 .40641 .52398 .40309 .52248 Metetra
.587 .847 .994 r
.40309 .52248 .40641 .52398 .41191 .52211 .40857 .52109 Metetra
.662 .901 .98 r
.40857 .52109 .41191 .52211 .41739 .52083 .4141 .51887 Metetra
.698 .837 .95 r
.4141 .51887 .41739 .52083 .42285 .52066 .41964 .51656 Metetra
.648 .688 .874 r
.41964 .51656 .42285 .52066 .4283 .52173 .42516 .51504 Metetra
.57 .556 .799 r
.42516 .51504 .4283 .52173 .43374 .52361 .43066 .51492 Metetra
.508 .475 .756 r
.43066 .51492 .43374 .52361 .4392 .52546 .43613 .51627 Metetra
.469 .443 .746 r
.43613 .51627 .4392 .52546 .44472 .52629 .4416 .51849 Metetra
.458 .465 .779 r
.4416 .51849 .44472 .52629 .45029 .5254 .4471 .52051 Metetra
.492 .585 .876 r
.4471 .52051 .45029 .5254 .45591 .52262 .45266 .52118 Metetra
.582 .854 .995 r
.45266 .52118 .45591 .52262 .46157 .51846 .45828 .51974 Metetra
.559 .927 .781 r
.45828 .51974 .46157 .51846 .46724 .51383 .46395 .51615 Metetra
.594 .91 .655 r
.46395 .51615 .46724 .51383 .47291 .50969 .46965 .51111 Metetra
.772 .995 .797 r
.46965 .51111 .47291 .50969 .47856 .50666 .47535 .50574 Metetra
.826 .919 .898 r
.47535 .50574 .47856 .50666 .48421 .50479 .48104 .50117 Metetra
.732 .742 .859 r
.48104 .50117 .48421 .50479 .48986 .50357 .48672 .49802 Metetra
.651 .633 .819 r
.48672 .49802 .48986 .50357 .49552 .50223 .4924 .49626 Metetra
.615 .603 .815 r
.4924 .49626 .49552 .50223 .50121 .50003 .49807 .49524 Metetra
.626 .652 .856 r
.49807 .49524 .50121 .50003 .50691 .49663 .50377 .49403 Metetra
.688 .797 .932 r
.50377 .49403 .50691 .49663 .51262 .49215 .50948 .49184 Metetra
.738 .964 .938 r
.50948 .49184 .51262 .49215 .51834 .48712 .51521 .48831 Metetra
.703 .981 .804 r
.51521 .48831 .51834 .48712 .52405 .48222 .52094 .48367 Metetra
.724 .982 .774 r
.52094 .48367 .52405 .48222 .52977 .47802 .52668 .47852 Metetra
.799 .996 .865 r
.52668 .47852 .52977 .47802 .5355 .47476 .53242 .47361 Metetra
.801 .915 .917 r
.53242 .47361 .5355 .47476 .54123 .47237 .53816 .46952 Metetra
.736 .792 .897 r
.53816 .46952 .54123 .47237 .54698 .4705 .54391 .46649 Metetra
.679 .71 .872 r
.54391 .46649 .54698 .4705 .55275 .46877 .54968 .46436 Metetra
.649 .68 .866 r
.54968 .46436 .55275 .46877 .55852 .46685 .55546 .46274 Metetra
.646 .694 .881 r
.55546 .46274 .55852 .46685 .5643 .46461 .56126 .46118 Metetra
.663 .739 .906 r
.56126 .46118 .5643 .46461 .57009 .46211 .56706 .45934 Metetra
.69 .791 .927 r
.56706 .45934 .57009 .46211 .57589 .45948 .57287 .45708 Metetra
.712 .822 .933 r
.57287 .45708 .57589 .45948 .58169 .45691 .57869 .45448 Metetra
.72 .822 .928 r
.57869 .45448 .58169 .45691 .58751 .45451 .58451 .45175 Metetra
.711 .797 .919 r
.58451 .45175 .58751 .45451 .59335 .45234 .59035 .44916 Metetra
.689 .765 .909 r
.59035 .44916 .59335 .45234 .5992 .45038 .5962 .44689 Metetra
.663 .738 .905 r
.5962 .44689 .5992 .45038 .60507 .44862 .60208 .44503 Metetra
.64 .725 .909 r
.60208 .44503 .60507 .44862 .61095 .447 .60797 .44352 Metetra
.628 .727 .918 r
.60797 .44352 .61095 .447 .61685 .4455 .61389 .44216 Metetra
.632 .738 .924 r
.61389 .44216 .61685 .4455 .62277 .44406 .61981 .44072 Metetra
.651 .745 .919 r
.61981 .44072 .62277 .44406 .6287 .44259 .62574 .43902 Metetra
.672 .739 .9 r
.62574 .43902 .6287 .44259 .63464 .44098 .63168 .43699 Metetra
.682 .719 .877 r
.63168 .43699 .63464 .44098 .64058 .43915 .63761 .43475 Metetra
.675 .696 .862 r
.63761 .43475 .64058 .43915 .64653 .4371 .64357 .43259 Metetra
.651 .682 .866 r
.64357 .43259 .64653 .4371 .65249 .43497 .64955 .43087 Metetra
.605 .684 .898 r
.64955 .43087 .65249 .43497 .65847 .43302 .65558 .42988 Metetra
.513 .706 .958 r
.65558 .42988 .65847 .43302 .66448 .43156 .66165 .42969 Metetra
.32 .708 .98 r
.66165 .42969 .66448 .43156 .67054 .43081 .66777 .43003 Metetra
.099 .637 .855 r
.66777 .43003 .67054 .43081 .67665 .43077 .67391 .4304 Metetra
.121 .667 .821 r
.67391 .4304 .67665 .43077 .6828 .43117 .68005 .43025 Metetra
.423 .834 .972 r
.68005 .43025 .6828 .43117 .68897 .43152 .68616 .42919 Metetra
.65 .823 .966 r
.68616 .42919 .68897 .43152 .69513 .43132 .69224 .42726 Metetra
.682 .72 .878 r
.69224 .42726 .69513 .43132 .70127 .43029 .69832 .42498 Metetra
.653 .652 .837 r
.69832 .42498 .70127 .43029 .70738 .42851 .70443 .42311 Metetra
.594 .622 .849 r
.70443 .42311 .70738 .42851 .71349 .42647 .71063 .4224 Metetra
.456 .618 .92 r
.71063 .4224 .71349 .42647 .71964 .42487 .71693 .42317 Metetra
0 .495 .851 r
.71693 .42317 .71964 .42487 .72587 .42431 .72332 .42513 Metetra
.478 0 0 r
.72332 .42513 .72587 .42431 .7322 .425 .72976 .42739 Metetra
.492 0 0 r
.72976 .42739 .7322 .425 .73861 .42659 .73618 .42883 Metetra
.309 0 0 r
.73618 .42883 .73861 .42659 .74506 .42826 .74251 .42851 Metetra
.427 .871 .836 r
.74251 .42851 .74506 .42826 .75147 .42902 .74872 .42608 Metetra
.78 .819 .883 r
.74872 .42608 .75147 .42902 .75778 .42814 .75481 .42195 Metetra
.744 .667 .775 r
.75481 .42195 .75778 .42814 .76398 .42542 .76086 .41711 Metetra
.703 .602 .74 r
.76086 .41711 .76398 .42542 .77008 .42128 .76695 .41273 Metetra
.668 .579 .746 r
.76695 .41273 .77008 .42128 .77615 .41663 .77314 .40966 Metetra
.63 .593 .793 r
.77314 .40966 .77615 .41663 .78225 .41242 .77946 .40809 Metetra
.572 .665 .9 r
.77946 .40809 .78225 .41242 .78846 .40931 .78588 .40754 Metetra
.431 .781 .997 r
.78588 .40754 .78846 .40931 .79477 .40741 .79232 .40708 Metetra
.343 .818 .892 r
.79232 .40708 .79477 .40741 .80116 .40626 .79871 .4057 Metetra
.62 .946 .943 r
.79871 .4057 .80116 .40626 .80756 .40508 .80498 .40278 Metetra
.806 .874 .897 r
.80498 .40278 .80756 .40508 .81391 .4031 .81112 .39826 Metetra
.792 .732 .797 r
.81112 .39826 .81391 .4031 .82016 .39987 .81716 .39263 Metetra
.753 .649 .745 r
.81716 .39263 .82016 .39987 .82631 .3954 .82318 .38674 Metetra
.721 .606 .729 r
.82318 .38674 .82631 .3954 .83238 .39015 .82925 .38141 Metetra
.694 .591 .736 r
.82925 .38141 .83238 .39015 .83845 .38481 .83543 .3772 Metetra
.673 .602 .767 r
.83543 .3772 .83845 .38481 .84457 .38 .84173 .3742 Metetra
.656 .643 .825 r
.84173 .3742 .84457 .38 .85079 .37612 .84814 .37213 Metetra
.64 .717 .904 r
.84814 .37213 .85079 .37612 .85711 .37322 .85461 .37049 Metetra
.631 .799 .963 r
.85461 .37049 .85711 .37322 .86353 .37105 .86108 .36874 Metetra
.658 .843 .971 r
.86108 .36874 .86353 .37105 .86999 .36921 .86752 .36654 Metetra
.705 .833 .943 r
.86752 .36654 .86999 .36921 .87646 .36728 .87391 .36378 Metetra
.728 .783 .896 r
.87391 .36378 .87646 .36728 .88291 .36502 .88027 .36057 Metetra
.724 .731 .856 r
.88027 .36057 .88291 .36502 .88933 .36234 .88662 .3572 Metetra
.71 .695 .834 r
.88662 .3572 .88933 .36234 .89572 .35936 .89299 .35395 Metetra
.693 .678 .83 r
.89299 .35395 .89572 .35936 .90211 .35627 .8994 .35103 Metetra
.678 .677 .842 r
.8994 .35103 .90211 .35627 .90852 .3533 .90588 .34852 Metetra
.664 .691 .866 r
.90588 .34852 .90852 .3533 .91498 .35058 .91242 .34638 Metetra
.642 .699 .888 r
.32476 .52902 .32809 .53276 .33338 .53163 .33007 .52765 Metetra
.624 .681 .883 r
.33007 .52765 .33338 .53163 .33868 .5305 .33538 .52653 Metetra
.612 .677 .888 r
.33538 .52653 .33868 .5305 .344 .5292 .34069 .52558 Metetra
.61 .697 .905 r
.34069 .52558 .344 .5292 .34935 .52761 .34601 .52462 Metetra
.623 .741 .931 r
.34601 .52462 .34935 .52761 .35473 .5257 .35136 .52342 Metetra
.65 .799 .954 r
.35136 .52342 .35473 .5257 .36013 .5236 .35674 .52179 Metetra
.68 .84 .96 r
.35674 .52179 .36013 .5236 .36553 .52162 .36216 .51972 Metetra
.7 .837 .948 r
.36216 .51972 .36553 .52162 .37092 .52015 .36759 .51743 Metetra
.69 .777 .918 r
.36759 .51743 .37092 .52015 .37628 .5195 .37303 .51532 Metetra
.643 .68 .87 r
.37303 .51532 .37628 .5195 .38162 .51978 .37844 .51389 Metetra
.581 .584 .821 r
.37844 .51389 .38162 .51978 .38695 .52077 .38383 .51353 Metetra
.523 .514 .788 r
.38383 .51353 .38695 .52077 .39228 .52197 .38918 .51432 Metetra
.478 .479 .78 r
.38918 .51432 .39228 .52197 .39766 .52272 .39452 .51593 Metetra
.452 .488 .806 r
.39452 .51593 .39766 .52272 .40309 .52248 .39987 .51766 Metetra
.456 .568 .879 r
.39987 .51766 .40309 .52248 .40857 .52109 .40527 .51867 Metetra
.501 .746 .982 r
.40527 .51867 .40857 .52109 .4141 .51887 .41074 .51832 Metetra
.564 .904 .976 r
.41074 .51832 .4141 .51887 .41964 .51656 .41628 .51648 Metetra
.662 .955 .946 r
.41628 .51648 .41964 .51656 .42516 .51504 .42185 .51364 Metetra
.732 .885 .951 r
.42185 .51364 .42516 .51504 .43066 .51492 .42744 .51078 Metetra
.663 .693 .868 r
.42744 .51078 .43066 .51492 .43613 .51627 .433 .50897 Metetra
.569 .54 .784 r
.433 .50897 .43613 .51627 .4416 .51849 .43853 .50891 Metetra
.5 .456 .739 r
.43853 .50891 .4416 .51849 .4471 .52051 .44403 .51058 Metetra
.46 .426 .733 r
.44403 .51058 .4471 .52051 .45266 .52118 .44954 .51317 Metetra
.451 .457 .774 r
.44954 .51317 .45266 .52118 .45828 .51974 .45508 .51536 Metetra
.497 .614 .898 r
.45508 .51536 .45828 .51974 .46395 .51615 .46068 .51581 Metetra
.561 .916 .961 r
.46068 .51581 .46395 .51615 .46965 .51111 .46634 .51374 Metetra
.46634 .51374 .46965 .51111 .47535 .50574 .47205 .50927 Metetra
.47205 .50927 .47535 .50574 .48104 .50117 .47779 .50331 Metetra
.745 .973 .712 r
.47779 .50331 .48104 .50117 .48672 .49802 .48352 .49725 Metetra
.841 .927 .887 r
.48352 .49725 .48672 .49802 .4924 .49626 .48924 .49231 Metetra
.728 .726 .848 r
.48924 .49231 .4924 .49626 .49807 .49524 .49494 .48913 Metetra
.639 .61 .805 r
.49494 .48913 .49807 .49524 .50377 .49403 .50064 .48755 Metetra
.602 .582 .803 r
.50064 .48755 .50377 .49403 .50948 .49184 .50635 .48676 Metetra
.616 .637 .848 r
.50635 .48676 .50948 .49184 .51521 .48831 .51207 .48571 Metetra
.685 .798 .935 r
.51207 .48571 .51521 .48831 .52094 .48367 .51782 .48354 Metetra
.73 .972 .929 r
.51782 .48354 .52094 .48367 .52668 .47852 .52357 .47994 Metetra
.678 .969 .771 r
.52357 .47994 .52668 .47852 .53242 .47361 .52932 .47517 Metetra
.708 .974 .755 r
.52932 .47517 .53242 .47361 .53816 .46952 .53508 .46996 Metetra
.798 .995 .868 r
.53508 .46996 .53816 .46952 .54391 .46649 .54084 .46508 Metetra
.794 .899 .917 r
.54084 .46508 .54391 .46649 .54968 .46436 .54661 .4611 Metetra
.725 .767 .886 r
.54661 .4611 .54968 .46436 .55546 .46274 .55239 .4582 Metetra
.669 .683 .854 r
.55239 .4582 .55546 .46274 .56126 .46118 .55818 .45617 Metetra
.643 .653 .845 r
.55818 .45617 .56126 .46118 .56706 .45934 .564 .45459 Metetra
.643 .664 .856 r
.564 .45459 .56706 .45934 .57287 .45708 .56982 .45304 Metetra
.659 .705 .881 r
.56982 .45304 .57287 .45708 .57869 .45448 .57566 .45124 Metetra
.678 .758 .911 r
.57566 .45124 .57869 .45448 .58451 .45175 .58151 .44915 Metetra
.688 .804 .937 r
.58151 .44915 .58451 .45175 .59035 .44916 .58736 .44689 Metetra
.684 .828 .953 r
.58736 .44689 .59035 .44916 .5962 .44689 .59322 .44464 Metetra
.673 .827 .958 r
.59322 .44464 .5962 .44689 .60208 .44503 .5991 .44251 Metetra
.666 .806 .95 r
.5991 .44251 .60208 .44503 .60797 .44352 .605 .44052 Metetra
.668 .773 .928 r
.605 .44052 .60797 .44352 .61389 .44216 .6109 .43855 Metetra
.673 .736 .898 r
.6109 .43855 .61389 .44216 .61981 .44072 .61682 .43651 Metetra
.674 .704 .87 r
.61682 .43651 .61981 .44072 .62574 .43902 .62274 .43439 Metetra
.666 .682 .855 r
.62274 .43439 .62574 .43902 .63168 .43699 .62868 .43237 Metetra
.647 .675 .863 r
.62868 .43237 .63168 .43699 .63761 .43475 .63465 .43072 Metetra
.606 .688 .901 r
.63465 .43072 .63761 .43475 .64357 .43259 .64065 .4297 Metetra
.509 .723 .969 r
.64065 .4297 .64357 .43259 .64955 .43087 .6467 .42942 Metetra
.266 .71 .961 r
.6467 .42942 .64955 .43087 .65558 .42988 .65278 .42967 Metetra
0 .562 .728 r
.65278 .42967 .65558 .42988 .66165 .42969 .65889 .42997 Metetra
.015 0 0 r
.65889 .42997 .66165 .42969 .66777 .43003 .665 .42974 Metetra
.326 .806 .892 r
.665 .42974 .66777 .43003 .67391 .4304 .67108 .42856 Metetra
.655 .862 .978 r
.67108 .42856 .67391 .4304 .68005 .43025 .67714 .42643 Metetra
.7 .739 .882 r
.67714 .42643 .68005 .43025 .68616 .42919 .68319 .42383 Metetra
.668 .657 .83 r
.68319 .42383 .68616 .42919 .69224 .42726 .68926 .42163 Metetra
.607 .619 .837 r
.68926 .42163 .69224 .42726 .69832 .42498 .69541 .42067 Metetra
.468 .611 .909 r
.69541 .42067 .69832 .42498 .70443 .42311 .70168 .42141 Metetra
0 .452 .819 r
.70168 .42141 .70443 .42311 .71063 .4224 .70805 .42363 Metetra
.553 .003 0 r
.70805 .42363 .71063 .4224 .71693 .42317 .71448 .42642 Metetra
.558 .087 .094 r
.71448 .42642 .71693 .42317 .72332 .42513 .72091 .4285 Metetra
.434 0 .033 r
.72091 .4285 .72332 .42513 .72976 .42739 .72724 .42873 Metetra
.72724 .42873 .72976 .42739 .73618 .42883 .73345 .42658 Metetra
.79 .867 .905 r
.73345 .42658 .73618 .42883 .74251 .42851 .73954 .42243 Metetra
.752 .674 .774 r
.73954 .42243 .74251 .42851 .74872 .42608 .74557 .41736 Metetra
.704 .596 .732 r
.74557 .41736 .74872 .42608 .75481 .42195 .75163 .41274 Metetra
.663 .566 .735 r
.75163 .41274 .75481 .42195 .76086 .41711 .75781 .40964 Metetra
.615 .573 .783 r
.75781 .40964 .76086 .41711 .76695 .41273 .76413 .4084 Metetra
.521 .64 .907 r
.76413 .4084 .76695 .41273 .77314 .40966 .77057 .40853 Metetra
.177 .675 .915 r
.77057 .40853 .77314 .40966 .77946 .40809 .77706 .40891 Metetra
.061 0 0 r
.77706 .40891 .77946 .40809 .78588 .40754 .78349 .4083 Metetra
.3 .783 .705 r
.78349 .4083 .78588 .40754 .79232 .40708 .78979 .40582 Metetra
.803 .946 .917 r
.78979 .40582 .79232 .40708 .79871 .4057 .79593 .4013 Metetra
.811 .755 .8 r
.79593 .4013 .79871 .4057 .80498 .40278 .80194 .39529 Metetra
.762 .647 .735 r
.80194 .39529 .80498 .40278 .81112 .39826 .80791 .3888 Metetra
.723 .596 .714 r
.80791 .3888 .81112 .39826 .81716 .39263 .81393 .38289 Metetra
.693 .576 .719 r
.81393 .38289 .81716 .39263 .82318 .38674 .82007 .37828 Metetra
.669 .583 .75 r
.82007 .37828 .82318 .38674 .82925 .38141 .82635 .37518 Metetra
.646 .624 .813 r
.82635 .37518 .82925 .38141 .83543 .3772 .83276 .37326 Metetra
.621 .713 .911 r
.83276 .37326 .83543 .3772 .84173 .3742 .83923 .3719 Metetra
.592 .818 .986 r
.83923 .3719 .84173 .3742 .84814 .37213 .84571 .37041 Metetra
.621 .877 .989 r
.84571 .37041 .84814 .37213 .85461 .37049 .85215 .36833 Metetra
.705 .871 .96 r
.85215 .36833 .85461 .37049 .86108 .36874 .85852 .36548 Metetra
.744 .803 .9 r
.85852 .36548 .86108 .36874 .86752 .36654 .86484 .36202 Metetra
.737 .732 .846 r
.86484 .36202 .86752 .36654 .87391 .36378 .87114 .35829 Metetra
.718 .685 .818 r
.87114 .35829 .87391 .36378 .88027 .36057 .87746 .3547 Metetra
.697 .663 .812 r
.87746 .3547 .88027 .36057 .88662 .3572 .88384 .35152 Metetra
.679 .661 .825 r
.88384 .35152 .88662 .3572 .89299 .35395 .89028 .34888 Metetra
.663 .677 .854 r
.89028 .34888 .89299 .35395 .8994 .35103 .8968 .34672 Metetra
.649 .708 .891 r
.8968 .34672 .8994 .35103 .90588 .34852 .90337 .34489 Metetra
.639 .744 .925 r
.90337 .34489 .90588 .34852 .91242 .34638 .90998 .34318 Metetra
.674 .751 .908 r
.32139 .526 .32476 .52902 .33007 .52765 .32673 .52414 Metetra
.657 .718 .893 r
.32673 .52414 .33007 .52765 .33538 .52653 .33207 .52252 Metetra
.633 .684 .88 r
.33207 .52252 .33538 .52653 .34069 .52558 .3374 .52126 Metetra
.61 .66 .873 r
.3374 .52126 .34069 .52558 .34601 .52462 .34273 .52035 Metetra
.595 .657 .881 r
.34273 .52035 .34601 .52462 .35136 .52342 .34805 .51966 Metetra
.593 .684 .905 r
.34805 .51966 .35136 .52342 .35674 .52179 .3534 .51891 Metetra
.612 .747 .941 r
.3534 .51891 .35674 .52179 .36216 .51972 .35877 .5178 Metetra
.646 .827 .97 r
.35877 .5178 .36216 .51972 .36759 .51743 .36419 .51611 Metetra
.685 .88 .971 r
.36419 .51611 .36759 .51743 .37303 .51532 .36964 .51383 Metetra
.714 .871 .956 r
.36964 .51383 .37303 .51532 .37844 .51389 .37511 .51128 Metetra
.7 .788 .919 r
.37511 .51128 .37844 .51389 .38383 .51353 .38058 .509 Metetra
.638 .663 .857 r
.38058 .509 .38383 .51353 .38918 .51432 .38603 .50762 Metetra
.563 .551 .799 r
.38603 .50762 .38918 .51432 .39452 .51593 .39143 .50762 Metetra
.498 .477 .764 r
.39143 .50762 .39452 .51593 .39987 .51766 .39679 .50903 Metetra
.45 .441 .757 r
.39679 .50903 .39987 .51766 .40527 .51867 .40214 .51136 Metetra
.422 .456 .791 r
.40214 .51136 .40527 .51867 .41074 .51832 .40752 .51366 Metetra
.424 .562 .888 r
.40752 .51366 .41074 .51832 .41628 .51648 .41295 .51489 Metetra
.462 .797 .999 r
.41295 .51489 .41628 .51648 .42185 .51364 .41847 .51431 Metetra
.478 .897 .846 r
.41847 .51431 .42185 .51364 .42744 .51078 .42405 .51185 Metetra
.619 .957 .831 r
.42405 .51185 .42744 .51078 .433 .50897 .42968 .50823 Metetra
.766 .933 .939 r
.42968 .50823 .433 .50897 .43853 .50891 .43531 .5047 Metetra
.679 .696 .859 r
.43531 .5047 .43853 .50891 .44403 .51058 .44092 .50257 Metetra
.566 .524 .767 r
.44092 .50257 .44403 .51058 .44954 .51317 .44648 .5026 Metetra
.492 .437 .723 r
.44648 .5026 .44954 .51317 .45508 .51536 .45201 .50464 Metetra
.451 .409 .72 r
.45201 .50464 .45508 .51536 .46068 .51581 .45755 .50763 Metetra
.443 .45 .771 r
.45755 .50763 .46068 .51581 .46634 .51374 .46313 .50998 Metetra
.5 .653 .927 r
.46313 .50998 .46634 .51374 .47205 .50927 .46877 .51017 Metetra
.464 .887 .803 r
.46877 .51017 .47205 .50927 .47779 .50331 .47448 .50742 Metetra
.47448 .50742 .47779 .50331 .48352 .49725 .48023 .50203 Metetra
.48023 .50203 .48352 .49725 .48924 .49231 .48599 .49518 Metetra
.698 .931 .617 r
.48599 .49518 .48924 .49231 .49494 .48913 .49175 .48848 Metetra
.851 .935 .88 r
.49175 .48848 .49494 .48913 .50064 .48755 .49749 .48328 Metetra
.72 .71 .841 r
.49749 .48328 .50064 .48755 .50635 .48676 .50322 .4802 Metetra
.622 .59 .797 r
.50322 .4802 .50635 .48676 .51207 .48571 .50895 .47895 Metetra
.583 .565 .799 r
.50895 .47895 .51207 .48571 .51782 .48354 .51468 .47856 Metetra
.597 .633 .858 r
.51468 .47856 .51782 .48354 .52357 .47994 .52044 .47782 Metetra
.664 .83 .963 r
.52044 .47782 .52357 .47994 .52932 .47517 .52621 .47582 Metetra
.632 .963 .861 r
.52621 .47582 .52932 .47517 .53508 .46996 .53199 .47226 Metetra
.507 .858 .602 r
.53199 .47226 .53508 .46996 .54084 .46508 .53777 .46747 Metetra
.556 .879 .605 r
.53777 .46747 .54084 .46508 .54661 .4611 .54355 .46224 Metetra
.72 .985 .803 r
.54355 .46224 .54661 .4611 .55239 .4582 .54933 .45739 Metetra
.779 .943 .932 r
.54933 .45739 .55239 .4582 .55818 .45617 .55512 .45354 Metetra
.715 .806 .922 r
.55512 .45354 .55818 .45617 .564 .45459 .56093 .45088 Metetra
.65 .719 .899 r
.56093 .45088 .564 .45459 .56982 .45304 .56677 .44923 Metetra
.609 .7 .908 r
.56677 .44923 .56982 .45304 .57566 .45124 .57262 .44818 Metetra
.588 .74 .948 r
.57262 .44818 .57566 .45124 .58151 .44915 .5785 .44723 Metetra
.573 .822 .992 r
.5785 .44723 .58151 .44915 .58736 .44689 .58438 .44597 Metetra
.56 .892 .985 r
.58438 .44597 .58736 .44689 .59322 .44464 .59027 .44418 Metetra
.59 .928 .958 r
.59027 .44418 .59322 .44464 .5991 .44251 .59615 .44182 Metetra
.671 .94 .964 r
.59615 .44182 .5991 .44251 .605 .44052 .60204 .43901 Metetra
.725 .896 .957 r
.60204 .43901 .605 .44052 .6109 .43855 .60793 .43604 Metetra
.719 .821 .929 r
.60793 .43604 .6109 .43855 .61682 .43651 .61384 .43328 Metetra
.68 .763 .914 r
.61384 .43328 .61682 .43651 .62274 .43439 .61978 .43113 Metetra
.617 .74 .934 r
.61978 .43113 .62274 .43439 .62868 .43237 .62575 .42985 Metetra
.496 .746 .984 r
.62575 .42985 .62868 .43237 .63465 .43072 .63177 .42949 Metetra
.218 .695 .936 r
.63177 .42949 .63465 .43072 .64065 .4297 .63783 .42976 Metetra
.086 0 0 r
.63783 .42976 .64065 .4297 .6467 .42942 .64391 .43009 Metetra
.092 0 0 r
.64391 .43009 .6467 .42942 .65278 .42967 .64999 .42984 Metetra
.256 .767 .806 r
.64999 .42984 .65278 .42967 .65889 .42997 .65605 .42851 Metetra
.669 .895 .978 r
.65605 .42851 .65889 .42997 .665 .42974 .66207 .42606 Metetra
.723 .754 .877 r
.66207 .42606 .665 .42974 .67108 .42856 .66808 .42302 Metetra
.686 .658 .817 r
.66808 .42302 .67108 .42856 .67714 .42643 .67412 .42031 Metetra
.626 .612 .816 r
.67412 .42031 .67714 .42643 .68319 .42383 .68023 .41894 Metetra
.5 .597 .882 r
.68023 .41894 .68319 .42383 .68926 .42163 .68645 .41952 Metetra
0 .462 .854 r
.68645 .41952 .68926 .42163 .69541 .42067 .69279 .42189 Metetra
.589 .047 0 r
.69279 .42189 .69541 .42067 .70168 .42141 .6992 .42515 Metetra
.596 .145 .152 r
.6992 .42515 .70168 .42141 .70805 .42363 .70562 .42785 Metetra
.498 .058 .132 r
.70562 .42785 .70805 .42363 .71448 .42642 .71196 .42865 Metetra
.096 0 0 r
.71196 .42865 .71448 .42642 .72091 .4285 .71817 .42682 Metetra
.793 .907 .92 r
.71817 .42682 .72091 .4285 .72724 .42873 .72425 .42265 Metetra
.759 .676 .771 r
.72425 .42265 .72724 .42873 .73345 .42658 .73026 .41732 Metetra
.705 .588 .722 r
.73026 .41732 .73345 .42658 .73954 .42243 .73629 .41239 Metetra
.658 .551 .722 r
.73629 .41239 .73954 .42243 .74557 .41736 .74245 .40921 Metetra
.602 .55 .769 r
.74245 .40921 .74557 .41736 .75163 .41274 .74877 .40829 Metetra
.463 .603 .905 r
.74877 .40829 .75163 .41274 .75781 .40964 .75524 .40914 Metetra
.15 0 0 r
.75524 .40914 .75781 .40964 .76413 .4084 .76177 .41049 Metetra
.364 0 0 r
.76177 .41049 .76413 .4084 .77057 .40853 .76825 .41081 Metetra
.108 0 0 r
.76825 .41081 .77057 .40853 .77706 .40891 .77458 .40893 Metetra
.719 .988 .872 r
.77458 .40893 .77706 .40891 .78349 .4083 .78073 .40451 Metetra
.834 .787 .806 r
.78073 .40451 .78349 .4083 .78979 .40582 .78672 .39813 Metetra
.771 .648 .726 r
.78672 .39813 .78979 .40582 .79593 .4013 .79264 .39099 Metetra
.725 .587 .7 r
.79264 .39099 .79593 .4013 .80194 .39529 .79861 .38441 Metetra
.691 .561 .703 r
.79861 .38441 .80194 .39529 .80791 .3888 .8047 .37935 Metetra
.663 .563 .732 r
.8047 .37935 .80791 .3888 .81393 .38289 .81096 .37614 Metetra
.635 .603 .8 r
.81096 .37614 .81393 .38289 .82007 .37828 .81737 .37442 Metetra
.594 .705 .921 r
.81737 .37442 .82007 .37828 .82635 .37518 .82386 .37344 Metetra
.512 .828 1 r
.82386 .37344 .82635 .37518 .83276 .37326 .83036 .37231 Metetra
.526 .891 .974 r
.83036 .37231 .83276 .37326 .83923 .3719 .8368 .37041 Metetra
.689 .917 .971 r
.8368 .37041 .83923 .3719 .84571 .37041 .84316 .36749 Metetra
.762 .83 .905 r
.84316 .36749 .84571 .37041 .85215 .36833 .84944 .36373 Metetra
.752 .734 .835 r
.84944 .36373 .85215 .36833 .85852 .36548 .85568 .35958 Metetra
.726 .674 .8 r
.85568 .35958 .85852 .36548 .86484 .36202 .86195 .35555 Metetra
.701 .646 .792 r
.86195 .35555 .86484 .36202 .87114 .35829 .86828 .35205 Metetra
.68 .643 .806 r
.86828 .35205 .87114 .35829 .87746 .3547 .87469 .34924 Metetra
.661 .661 .839 r
.87469 .34924 .87746 .3547 .88384 .35152 .88119 .34707 Metetra
.643 .698 .886 r
.88119 .34707 .88384 .35152 .89028 .34888 .88775 .34534 Metetra
.629 .745 .931 r
.88775 .34534 .89028 .34888 .8968 .34672 .89435 .34376 Metetra
.624 .785 .958 r
.89435 .34376 .8968 .34672 .90337 .34489 .90096 .34211 Metetra
.637 .804 .963 r
.90096 .34211 .90337 .34489 .90998 .34318 .90755 .34024 Metetra
.687 .798 .934 r
.31796 .52363 .32139 .526 .32673 .52414 .32332 .52157 Metetra
.689 .785 .924 r
.32332 .52157 .32673 .52414 .33207 .52252 .3287 .51949 Metetra
.678 .752 .908 r
.3287 .51949 .33207 .52252 .3374 .52126 .33407 .51756 Metetra
.653 .707 .887 r
.33407 .51756 .3374 .52126 .34273 .52035 .33944 .51599 Metetra
.622 .663 .869 r
.33944 .51599 .34273 .52035 .34805 .51966 .34479 .51489 Metetra
.592 .633 .861 r
.34479 .51489 .34805 .51966 .3534 .51891 .35013 .51426 Metetra
.573 .631 .871 r
.35013 .51426 .3534 .51891 .35877 .5178 .35547 .51388 Metetra
.572 .669 .904 r
.35547 .51388 .35877 .5178 .36419 .51611 .36083 .5134 Metetra
.596 .756 .955 r
.36083 .5134 .36419 .51611 .36964 .51383 .36623 .5124 Metetra
.637 .864 .984 r
.36623 .5124 .36964 .51383 .37511 .51128 .37168 .5106 Metetra
.684 .926 .97 r
.37168 .5106 .37511 .51128 .38058 .509 .37717 .50804 Metetra
.729 .912 .957 r
.37717 .50804 .38058 .509 .38603 .50762 .38269 .50514 Metetra
.713 .8 .919 r
.38269 .50514 .38603 .50762 .39143 .50762 .3882 .50264 Metetra
.632 .642 .842 r
.3882 .50264 .39143 .50762 .39679 .50903 .39367 .50134 Metetra
.544 .517 .776 r
.39367 .50134 .39679 .50903 .40214 .51136 .39909 .50178 Metetra
.474 .439 .738 r
.39909 .50178 .40214 .51136 .40752 .51366 .40446 .50392 Metetra
.423 .404 .734 r
.40446 .50392 .40752 .51366 .41295 .51489 .40982 .50706 Metetra
.39 .424 .776 r
.40982 .50706 .41295 .51489 .41847 .51431 .41522 .50997 Metetra
.386 .561 .903 r
.41522 .50997 .41847 .51431 .42405 .51185 .42069 .51136 Metetra
.369 .82 .939 r
.42069 .51136 .42405 .51185 .42968 .50823 .42626 .51039 Metetra
.42626 .51039 .42968 .50823 .43531 .5047 .4319 .50712 Metetra
.515 .868 .624 r
.4319 .50712 .43531 .5047 .44092 .50257 .43758 .50255 Metetra
.796 .973 .909 r
.43758 .50255 .44092 .50257 .44648 .5026 .44326 .49826 Metetra
.694 .696 .848 r
.44326 .49826 .44648 .5026 .45201 .50464 .4489 .49578 Metetra
.562 .506 .75 r
.4489 .49578 .45201 .50464 .45755 .50763 .4545 .49593 Metetra
.484 .418 .707 r
.4545 .49593 .45755 .50763 .46313 .50998 .46006 .49839 Metetra
.443 .393 .708 r
.46006 .49839 .46313 .50998 .46877 .51017 .46564 .5018 Metetra
.439 .444 .767 r
.46564 .5018 .46877 .51017 .47448 .50742 .47126 .50427 Metetra
.51 .7 .955 r
.47126 .50427 .47448 .50742 .48023 .50203 .47694 .50412 Metetra
.47694 .50412 .48023 .50203 .48599 .49518 .48269 .50062 Metetra
.48269 .50062 .48599 .49518 .49175 .48848 .48847 .49425 Metetra
.48847 .49425 .49175 .48848 .49749 .48328 .49426 .4865 Metetra
.703 .919 .581 r
.49426 .4865 .49749 .48328 .50322 .4802 .50004 .47919 Metetra
.856 .911 .87 r
.50004 .47919 .50322 .4802 .50895 .47895 .5058 .47379 Metetra
.703 .67 .815 r
.5058 .47379 .50895 .47895 .51468 .47856 .51156 .47083 Metetra
.607 .555 .77 r
.51156 .47083 .51468 .47856 .52044 .47782 .51731 .46986 Metetra
.573 .531 .77 r
.51731 .46986 .52044 .47782 .52621 .47582 .52308 .4697 Metetra
.595 .591 .818 r
.52308 .4697 .52621 .47582 .53199 .47226 .52887 .46903 Metetra
.681 .758 .91 r
.52887 .46903 .53199 .47226 .53777 .46747 .53467 .46691 Metetra
.767 .956 .933 r
.53467 .46691 .53777 .46747 .54355 .46224 .54047 .4631 Metetra
.766 .997 .833 r
.54047 .4631 .54355 .46224 .54933 .45739 .54627 .4581 Metetra
.803 .999 .84 r
.54627 .4581 .54933 .45739 .55512 .45354 .55207 .45282 Metetra
.824 .946 .902 r
.55207 .45282 .55512 .45354 .56093 .45088 .55787 .44815 Metetra
.758 .808 .893 r
.55787 .44815 .56093 .45088 .56677 .44923 .56369 .44466 Metetra
.679 .688 .851 r
.56369 .44466 .56677 .44923 .57262 .44818 .56954 .44241 Metetra
.631 .621 .822 r
.56954 .44241 .57262 .44818 .5785 .44723 .57541 .44099 Metetra
.62 .601 .81 r
.57541 .44099 .5785 .44723 .58438 .44597 .58129 .43979 Metetra
.635 .61 .808 r
.58129 .43979 .58438 .44597 .59027 .44418 .58719 .43824 Metetra
.661 .631 .808 r
.58719 .43824 .59027 .44418 .59615 .44182 .59308 .43611 Metetra
.681 .647 .81 r
.59308 .43611 .59615 .44182 .60204 .43901 .59898 .43352 Metetra
.683 .656 .817 r
.59898 .43352 .60204 .43901 .60793 .43604 .60489 .43095 Metetra
.663 .662 .839 r
.60489 .43095 .60793 .43604 .61384 .43328 .61082 .42892 Metetra
.615 .675 .884 r
.61082 .42892 .61384 .43328 .61978 .43113 .61679 .4278 Metetra
.525 .699 .949 r
.61679 .4278 .61978 .43113 .62575 .42985 .62281 .42755 Metetra
.403 .719 .988 r
.62281 .42755 .62575 .42985 .63177 .42949 .62885 .4277 Metetra
.39 .755 .992 r
.62885 .4277 .63177 .42949 .63783 .42976 .63491 .42755 Metetra
.563 .801 .988 r
.63491 .42755 .63783 .42976 .64391 .43009 .64095 .42646 Metetra
.683 .743 .897 r
.64095 .42646 .64391 .43009 .64999 .42984 .64696 .42421 Metetra
.697 .66 .809 r
.64696 .42421 .64999 .42984 .65605 .42851 .65296 .4212 Metetra
.672 .603 .769 r
.65296 .4212 .65605 .42851 .66207 .42606 .65897 .41837 Metetra
.627 .571 .772 r
.65897 .41837 .66207 .42606 .66808 .42302 .66505 .41681 Metetra
.53 .56 .83 r
.66505 .41681 .66808 .42302 .67412 .42031 .67123 .4173 Metetra
.109 .487 .9 r
.67123 .4173 .67412 .42031 .68023 .41894 .67753 .41983 Metetra
.609 .061 0 r
.67753 .41983 .68023 .41894 .68645 .41952 .68392 .42351 Metetra
.624 .185 .186 r
.68392 .42351 .68645 .41952 .69279 .42189 .69033 .42684 Metetra
.541 .122 .195 r
.69033 .42684 .69279 .42189 .6992 .42515 .69667 .42823 Metetra
.247 0 0 r
.69667 .42823 .6992 .42515 .70562 .42785 .70288 .42677 Metetra
.784 .946 .928 r
.70288 .42677 .70562 .42785 .71196 .42865 .70895 .42262 Metetra
.766 .68 .768 r
.70895 .42262 .71196 .42865 .71817 .42682 .71494 .41701 Metetra
.706 .581 .712 r
.71494 .41701 .71817 .42682 .72425 .42265 .72095 .41175 Metetra
.656 .539 .71 r
.72095 .41175 .72425 .42265 .73026 .41732 .72709 .40843 Metetra
.59 .53 .755 r
.72709 .40843 .73026 .41732 .73629 .41239 .7334 .40779 Metetra
.398 .56 .898 r
.7334 .40779 .73629 .41239 .74245 .40921 .73989 .4094 Metetra
.425 0 0 r
.73989 .4094 .74245 .40921 .74877 .40829 .74645 .41182 Metetra
.516 .049 .084 r
.74645 .41182 .74877 .40829 .75524 .40914 .75298 .41321 Metetra
.353 0 .046 r
.75298 .41321 .75524 .40914 .76177 .41049 .75935 .41208 Metetra
.414 .815 .599 r
.75935 .41208 .76177 .41049 .76825 .41081 .76551 .40786 Metetra
.862 .831 .815 r
.76551 .40786 .76825 .41081 .77458 .40893 .77149 .40113 Metetra
.781 .651 .718 r
.77149 .40113 .77458 .40893 .78073 .40451 .77737 .39329 Metetra
.728 .578 .687 r
.77737 .39329 .78073 .40451 .78672 .39813 .78328 .38595 Metetra
.69 .548 .688 r
.78328 .38595 .78672 .39813 .79264 .39099 .78933 .38038 Metetra
.657 .545 .715 r
.78933 .38038 .79264 .39099 .79861 .38441 .79557 .37704 Metetra
.622 .581 .786 r
.79557 .37704 .79861 .38441 .8047 .37935 .80199 .37559 Metetra
.554 .693 .932 r
.80199 .37559 .8047 .37935 .81096 .37614 .8085 .3751 Metetra
.343 .788 .958 r
.8085 .3751 .81096 .37614 .81737 .37442 .81502 .37445 Metetra
.302 .797 .825 r
.81502 .37445 .81737 .37442 .82386 .37344 .82147 .37282 Metetra
.622 .946 .944 r
.82147 .37282 .82386 .37344 .83036 .37231 .82781 .36985 Metetra
.783 .866 .91 r
.82781 .36985 .83036 .37231 .8368 .37041 .83405 .36575 Metetra
.768 .737 .824 r
.83405 .36575 .8368 .37041 .84316 .36749 .84024 .36109 Metetra
.734 .663 .78 r
.84024 .36109 .84316 .36749 .84944 .36373 .84645 .35653 Metetra
.704 .629 .77 r
.84645 .35653 .84944 .36373 .85568 .35958 .85273 .35262 Metetra
.68 .623 .785 r
.85273 .35262 .85568 .35958 .86195 .35555 .8591 .3496 Metetra
.658 .642 .823 r
.8591 .3496 .86195 .35555 .86828 .35205 .86558 .34743 Metetra
.636 .686 .88 r
.86558 .34743 .86828 .35205 .87469 .34924 .87214 .34582 Metetra
.614 .747 .94 r
.87214 .34582 .87469 .34924 .88119 .34707 .87874 .34443 Metetra
.602 .799 .975 r
.87874 .34443 .88119 .34707 .88775 .34534 .88534 .34293 Metetra
.619 .826 .98 r
.88534 .34293 .88775 .34534 .89435 .34376 .89193 .34114 Metetra
.654 .823 .965 r
.89193 .34114 .89435 .34376 .90096 .34211 .89849 .339 Metetra
.68 .798 .938 r
.89849 .339 .90096 .34211 .90755 .34024 .90504 .3366 Metetra
.667 .791 .941 r
.31452 .52119 .31796 .52363 .32332 .52157 .31987 .51939 Metetra
.682 .813 .945 r
.31987 .51939 .32332 .52157 .3287 .51949 .32525 .51737 Metetra
.695 .819 .941 r
.32525 .51737 .3287 .51949 .33407 .51756 .33065 .51516 Metetra
.697 .8 .928 r
.33065 .51516 .33407 .51756 .33944 .51599 .33606 .51294 Metetra
.681 .754 .906 r
.33606 .51294 .33944 .51599 .34479 .51489 .34147 .51094 Metetra
.648 .694 .879 r
.34147 .51094 .34479 .51489 .35013 .51426 .34686 .50943 Metetra
.608 .637 .855 r
.34686 .50943 .35013 .51426 .35547 .51388 .35223 .50856 Metetra
.571 .601 .844 r
.35223 .50856 .35547 .51388 .36083 .5134 .35758 .50828 Metetra
.547 .599 .858 r
.35758 .50828 .36083 .5134 .36623 .5124 .36293 .50832 Metetra
.545 .65 .903 r
.36293 .50832 .36623 .5124 .37168 .5106 .36831 .50816 Metetra
.573 .77 .972 r
.36831 .50816 .37168 .5106 .37717 .50804 .37374 .50726 Metetra
.612 .905 .985 r
.37374 .50726 .37717 .50804 .38269 .50514 .37923 .5053 Metetra
.659 .961 .933 r
.37923 .5053 .38269 .50514 .3882 .50264 .38477 .50235 Metetra
.74 .956 .944 r
.38477 .50235 .3882 .50264 .39367 .50134 .39033 .49901 Metetra
.73 .814 .917 r
.39033 .49901 .39367 .50134 .39909 .50178 .39588 .49623 Metetra
.625 .619 .825 r
.39588 .49623 .39909 .50178 .40446 .50392 .40138 .49503 Metetra
.525 .482 .751 r
.40138 .49503 .40446 .50392 .40982 .50706 .40681 .496 Metetra
.451 .403 .713 r
.40681 .496 .40982 .50706 .41522 .50997 .41219 .499 Metetra
.396 .369 .711 r
.41219 .499 .41522 .50997 .42069 .51136 .41757 .50305 Metetra
.357 .394 .762 r
.41757 .50305 .42069 .51136 .42626 .51039 .42299 .50659 Metetra
.335 .569 .925 r
.42299 .50659 .42626 .51039 .4319 .50712 .42851 .50805 Metetra
.42851 .50805 .4319 .50712 .43758 .50255 .43412 .50653 Metetra
.43412 .50653 .43758 .50255 .44326 .49826 .43982 .50225 Metetra
.43982 .50225 .44326 .49826 .4489 .49578 .44556 .49657 Metetra
.811 .997 .855 r
.44556 .49657 .4489 .49578 .4545 .49593 .45128 .49143 Metetra
.706 .695 .837 r
.45128 .49143 .4545 .49593 .46006 .49839 .45696 .48862 Metetra
.556 .489 .735 r
.45696 .48862 .46006 .49839 .46564 .5018 .46259 .48894 Metetra
.475 .401 .693 r
.46259 .48894 .46564 .5018 .47126 .50427 .46819 .4919 Metetra
.432 .378 .697 r
.46819 .4919 .47126 .50427 .47694 .50412 .4738 .49579 Metetra
.428 .438 .769 r
.4738 .49579 .47694 .50412 .48269 .50062 .47946 .49842 Metetra
.49 .765 .992 r
.47946 .49842 .48269 .50062 .48847 .49425 .48519 .49796 Metetra
.48519 .49796 .48847 .49425 .49426 .4865 .49097 .49375 Metetra
0 0 .001 r
.49097 .49375 .49426 .4865 .50004 .47919 .49678 .48649 Metetra
.49678 .48649 .50004 .47919 .5058 .47379 .50259 .47796 Metetra
.592 .827 .446 r
.50259 .47796 .5058 .47379 .51156 .47083 .50839 .47018 Metetra
.862 .935 .87 r
.50839 .47018 .51156 .47083 .51731 .46986 .51417 .46466 Metetra
.695 .667 .819 r
.51417 .46466 .51731 .46986 .52308 .4697 .51995 .46188 Metetra
.592 .546 .771 r
.51995 .46188 .52308 .4697 .52887 .46903 .52573 .46125 Metetra
.554 .525 .778 r
.52573 .46125 .52887 .46903 .53467 .46691 .53154 .46148 Metetra
.568 .604 .849 r
.53154 .46148 .53467 .46691 .54047 .4631 .53736 .46121 Metetra
.625 .841 .983 r
.53736 .46121 .54047 .4631 .54627 .4581 .54319 .4595 Metetra
.438 .856 .703 r
.54319 .4595 .54627 .4581 .55207 .45282 .54902 .45615 Metetra
.54902 .45615 .55207 .45282 .55787 .44815 .55485 .45159 Metetra
.55485 .45159 .55787 .44815 .56369 .44466 .56068 .44662 Metetra
.531 .883 .647 r
.56068 .44662 .56369 .44466 .56954 .44241 .56651 .44199 Metetra
.754 .967 .931 r
.56651 .44199 .56954 .44241 .57541 .44099 .57236 .43819 Metetra
.723 .801 .912 r
.57236 .43819 .57541 .44099 .58129 .43979 .57823 .43535 Metetra
.665 .691 .864 r
.57823 .43535 .58129 .43979 .58719 .43824 .58412 .43339 Metetra
.625 .656 .86 r
.58412 .43339 .58719 .43824 .59308 .43611 .59004 .43212 Metetra
.583 .682 .909 r
.59004 .43212 .59308 .43611 .59898 .43352 .59599 .43141 Metetra
.449 .758 .995 r
.59599 .43141 .59898 .43352 .60489 .43095 .60196 .43113 Metetra
.028 0 0 r
.60196 .43113 .60489 .43095 .61082 .42892 .60796 .43107 Metetra
.31 0 0 r
.60796 .43107 .61082 .42892 .61679 .4278 .61398 .43086 Metetra
.311 0 0 r
.61398 .43086 .61679 .4278 .62281 .42755 .61999 .43003 Metetra
.105 0 0 r
.61999 .43003 .62281 .42755 .62885 .4277 .62599 .42815 Metetra
.526 .92 .848 r
.62599 .42815 .62885 .4277 .63491 .42755 .63197 .42518 Metetra
.766 .844 .91 r
.63197 .42518 .63491 .42755 .64095 .42646 .63793 .42155 Metetra
.718 .694 .826 r
.63793 .42155 .64095 .42646 .64696 .42421 .64391 .41821 Metetra
.651 .627 .814 r
.64391 .41821 .64696 .42421 .65296 .4212 .64995 .41629 Metetra
.52 .607 .88 r
.64995 .41629 .65296 .4212 .65897 .41837 .6561 .41659 Metetra
0 .391 .776 r
.6561 .41659 .65897 .41837 .66505 .41681 .66237 .41917 Metetra
.651 .166 .087 r
.66237 .41917 .66505 .41681 .67123 .4173 .66872 .42314 Metetra
.634 .24 .278 r
.66872 .42314 .67123 .4173 .67753 .41983 .6751 .42688 Metetra
.567 .193 .291 r
.6751 .42688 .67753 .41983 .68392 .42351 .68143 .42866 Metetra
.383 0 .131 r
.68143 .42866 .68392 .42351 .69033 .42684 .68762 .42734 Metetra
.681 .978 .839 r
.68762 .42734 .69033 .42684 .69667 .42823 .69368 .423 Metetra
.792 .712 .776 r
.69368 .423 .69667 .42823 .70288 .42677 .69964 .41691 Metetra
.716 .586 .708 r
.69964 .41691 .70288 .42677 .70895 .42262 .70562 .4111 Metetra
.658 .534 .702 r
.70562 .4111 .70895 .42262 .71494 .41701 .71172 .40746 Metetra
.584 .515 .744 r
.71172 .40746 .71494 .41701 .72095 .41175 .71802 .40699 Metetra
.332 .514 .886 r
.71802 .40699 .72095 .41175 .72709 .40843 .72452 .40932 Metetra
.586 .03 0 r
.72452 .40932 .72709 .40843 .7334 .40779 .73112 .41287 Metetra
.591 .173 .218 r
.73112 .41287 .7334 .40779 .73989 .4094 .73769 .41547 Metetra
.472 .079 .214 r
.73769 .41547 .73989 .4094 .74645 .41182 .74411 .41523 Metetra
.74411 .41523 .74645 .41182 .75298 .41321 .75029 .41132 Metetra
.891 .89 .822 r
.75029 .41132 .75298 .41321 .75935 .41208 .75625 .40427 Metetra
.793 .656 .711 r
.75625 .40427 .75935 .41208 .76551 .40786 .76209 .39567 Metetra
.73 .571 .675 r
.76209 .39567 .76551 .40786 .77149 .40113 .76795 .38749 Metetra
.688 .535 .674 r
.76795 .38749 .77149 .40113 .77737 .39329 .77396 .38133 Metetra
.651 .527 .699 r
.77396 .38133 .77737 .39329 .78328 .38595 .78017 .37787 Metetra
.608 .557 .772 r
.78017 .37787 .78328 .38595 .78933 .38038 .78659 .37674 Metetra
.495 .672 .943 r
.78659 .37674 .78933 .38038 .79557 .37704 .79314 .37686 Metetra
.044 .612 .757 r
.79314 .37686 .79557 .37704 .80199 .37559 .79969 .37684 Metetra
.035 0 0 r
.79969 .37684 .80199 .37559 .8085 .3751 .80616 .37559 Metetra
.434 .869 .782 r
.80616 .37559 .8085 .3751 .81502 .37445 .81249 .37262 Metetra
.803 .912 .914 r
.81249 .37262 .81502 .37445 .82147 .37282 .81869 .36814 Metetra
.787 .741 .811 r
.81869 .36814 .82147 .37282 .82781 .36985 .82482 .36287 Metetra
.742 .651 .76 r
.82482 .36287 .82781 .36985 .83405 .36575 .83096 .35767 Metetra
.707 .611 .748 r
.83096 .35767 .83405 .36575 .84024 .36109 .83718 .35326 Metetra
.679 .602 .763 r
.83718 .35326 .84024 .36109 .84645 .35653 .84352 .34998 Metetra
.654 .621 .804 r
.84352 .34998 .84645 .35653 .85273 .35262 .84998 .34779 Metetra
.627 .672 .874 r
.84998 .34779 .85273 .35262 .8591 .3496 .85653 .34635 Metetra
.592 .748 .952 r
.85653 .34635 .8591 .3496 .86558 .34743 .86314 .34519 Metetra
.563 .815 .992 r
.86314 .34519 .86558 .34743 .87214 .34582 .86974 .34389 Metetra
.585 .85 .994 r
.86974 .34389 .87214 .34582 .87874 .34443 .87632 .3422 Metetra
.644 .851 .979 r
.87632 .3422 .87874 .34443 .88534 .34293 .88286 .34005 Metetra
.686 .816 .945 r
.88286 .34005 .88534 .34293 .89193 .34114 .88938 .33754 Metetra
.698 .773 .909 r
.88938 .33754 .89193 .34114 .89849 .339 .89589 .33484 Metetra
.694 .739 .886 r
.89589 .33484 .89849 .339 .90504 .3366 .90241 .33216 Metetra
.642 .746 .924 r
.3111 .51818 .31452 .52119 .31987 .51939 .31644 .51674 Metetra
.65 .773 .938 r
.31644 .51674 .31987 .51939 .32525 .51737 .3218 .51515 Metetra
.667 .808 .951 r
.3218 .51515 .32525 .51737 .33065 .51516 .32718 .51331 Metetra
.688 .839 .956 r
.32718 .51331 .33065 .51516 .33606 .51294 .3326 .51115 Metetra
.705 .846 .95 r
.3326 .51115 .33606 .51294 .34147 .51094 .33804 .50876 Metetra
.709 .818 .933 r
.33804 .50876 .34147 .51094 .34686 .50943 .34348 .50636 Metetra
.686 .755 .904 r
.34348 .50636 .34686 .50943 .35223 .50856 .34892 .50427 Metetra
.641 .676 .868 r
.34892 .50427 .35223 .50856 .35758 .50828 .35433 .50285 Metetra
.59 .606 .837 r
.35433 .50285 .35758 .50828 .36293 .50832 .35972 .50227 Metetra
.545 .563 .824 r
.35972 .50227 .36293 .50832 .36831 .50816 .36508 .50247 Metetra
.515 .562 .841 r
.36508 .50247 .36831 .50816 .37374 .50726 .37044 .50301 Metetra
.511 .627 .902 r
.37044 .50301 .37374 .50726 .37923 .5053 .37584 .50323 Metetra
.538 .789 .99 r
.37584 .50323 .37923 .5053 .38477 .50235 .3813 .50244 Metetra
.543 .921 .929 r
.3813 .50244 .38477 .50235 .39033 .49901 .38683 .50023 Metetra
.578 .939 .81 r
.38683 .50023 .39033 .49901 .39588 .49623 .39242 .49677 Metetra
.734 .986 .897 r
.39242 .49677 .39588 .49623 .40138 .49503 .39803 .49287 Metetra
.748 .83 .914 r
.39803 .49287 .40138 .49503 .40681 .496 .40362 .48977 Metetra
.616 .594 .805 r
.40362 .48977 .40681 .496 .41219 .499 .40914 .48868 Metetra
.506 .448 .726 r
.40914 .48868 .41219 .499 .41757 .50305 .41459 .49028 Metetra
.429 .369 .689 r
.41459 .49028 .41757 .50305 .42299 .50659 .41999 .49427 Metetra
.371 .336 .69 r
.41999 .49427 .42299 .50659 .42851 .50805 .42538 .49931 Metetra
.325 .364 .749 r
.42538 .49931 .42851 .50805 .43412 .50653 .43084 .50348 Metetra
.259 .583 .945 r
.43084 .50348 .43412 .50653 .43982 .50225 .43639 .5049 Metetra
.01 0 0 r
.43639 .5049 .43982 .50225 .44556 .49657 .44207 .50264 Metetra
.44207 .50264 .44556 .49657 .45128 .49143 .44783 .49715 Metetra
.44783 .49715 .45128 .49143 .45696 .48862 .45361 .49019 Metetra
.813 .998 .783 r
.45361 .49019 .45696 .48862 .46259 .48894 .45938 .48414 Metetra
.714 .687 .822 r
.45938 .48414 .46259 .48894 .46819 .4919 .46509 .48102 Metetra
.548 .469 .718 r
.46509 .48102 .46819 .4919 .4738 .49579 .47075 .48161 Metetra
.465 .383 .679 r
.47075 .48161 .4738 .49579 .47946 .49842 .47638 .48515 Metetra
.422 .362 .686 r
.47638 .48515 .47946 .49842 .48519 .49796 .48203 .48958 Metetra
.418 .432 .768 r
.48203 .48958 .48519 .49796 .49097 .49375 .48773 .49237 Metetra
.462 .818 .997 r
.48773 .49237 .49097 .49375 .49678 .48649 .4935 .49156 Metetra
.4935 .49156 .49678 .48649 .50259 .47796 .49931 .48657 Metetra
0 0 .072 r
.49931 .48657 .50259 .47796 .50839 .47018 .50515 .47838 Metetra
.50515 .47838 .50839 .47018 .51417 .46466 .51098 .46908 Metetra
.583 .811 .418 r
.51098 .46908 .51417 .46466 .51995 .46188 .51679 .46094 Metetra
.855 .921 .874 r
.51679 .46094 .51995 .46188 .52573 .46125 .52259 .45557 Metetra
.667 .64 .814 r
.52259 .45557 .52573 .46125 .53154 .46148 .52839 .45336 Metetra
.557 .52 .77 r
.52839 .45336 .53154 .46148 .53736 .46121 .53422 .45353 Metetra
.513 .505 .785 r
.53422 .45353 .53736 .46121 .54319 .4595 .54006 .45455 Metetra
.526 .605 .875 r
.54006 .45455 .54319 .4595 .54902 .45615 .54592 .45478 Metetra
.587 .87 .994 r
.54592 .45478 .54902 .45615 .55485 .45159 .55179 .45311 Metetra
.491 .88 .702 r
.55179 .45311 .55485 .45159 .56068 .44662 .55765 .44929 Metetra
.498 .833 .542 r
.55765 .44929 .56068 .44662 .56651 .44199 .5635 .44394 Metetra
.685 .951 .69 r
.5635 .44394 .56651 .44199 .57236 .43819 .56934 .4382 Metetra
.813 .986 .885 r
.56934 .4382 .57236 .43819 .57823 .43535 .57519 .43329 Metetra
.745 .858 .932 r
.57519 .43329 .57823 .43535 .58412 .43339 .58107 .43011 Metetra
.611 .738 .935 r
.58107 .43011 .58412 .43339 .59004 .43212 .587 .4289 Metetra
.45 .673 .959 r
.587 .4289 .59004 .43212 .59599 .43141 .59298 .42924 Metetra
.244 .643 .961 r
.59298 .42924 .59599 .43141 .60196 .43113 .59899 .43018 Metetra
.131 .653 .883 r
.59899 .43018 .60196 .43113 .60796 .43107 .60501 .43055 Metetra
.368 .823 .931 r
.60501 .43055 .60796 .43107 .61398 .43086 .61102 .42943 Metetra
.714 .904 .963 r
.61102 .42943 .61398 .43086 .61999 .43003 .61698 .42651 Metetra
.775 .773 .851 r
.61698 .42651 .61999 .43003 .62599 .42815 .62292 .42227 Metetra
.736 .668 .783 r
.62292 .42227 .62599 .42815 .63197 .42518 .62886 .4179 Metetra
.678 .607 .768 r
.62886 .4179 .63197 .42518 .63793 .42155 .63485 .41488 Metetra
.586 .575 .808 r
.63485 .41488 .63793 .42155 .64391 .41821 .64093 .41435 Metetra
.258 .523 .912 r
.64093 .41435 .64391 .41821 .64995 .41629 .64714 .41657 Metetra
.621 .063 0 r
.64714 .41657 .64995 .41629 .6561 .41659 .65345 .42071 Metetra
.661 .231 .216 r
.65345 .42071 .6561 .41659 .66237 .41917 .65981 .42502 Metetra
.591 .194 .259 r
.65981 .42502 .66237 .41917 .66872 .42314 .66612 .42749 Metetra
.387 0 .08 r
.66612 .42749 .66872 .42314 .6751 .42688 .67232 .42667 Metetra
.75 .984 .906 r
.67232 .42667 .6751 .42688 .68143 .42866 .67837 .42244 Metetra
.779 .68 .754 r
.67837 .42244 .68143 .42866 .68762 .42734 .68432 .41607 Metetra
.71 .567 .691 r
.68432 .41607 .68762 .42734 .69368 .423 .69027 .40978 Metetra
.654 .517 .684 r
.69027 .40978 .69368 .423 .69964 .41691 .69635 .40583 Metetra
.578 .491 .72 r
.69635 .40583 .69964 .41691 .70562 .4111 .70262 .4055 Metetra
.311 .461 .849 r
.70262 .4055 .70562 .4111 .71172 .40746 .70912 .40856 Metetra
.666 .139 0 r
.70912 .40856 .71172 .40746 .71802 .40699 .71574 .41332 Metetra
.635 .244 .286 r
.71574 .41332 .71802 .40699 .72452 .40932 .72236 .41728 Metetra
.535 .173 .3 r
.72236 .41728 .72452 .40932 .73112 .41287 .72882 .41813 Metetra
.224 0 .069 r
.72882 .41813 .73112 .41287 .73769 .41547 .73503 .4147 Metetra
.908 .95 .816 r
.73503 .4147 .73769 .41547 .74411 .41523 .74098 .40741 Metetra
.804 .66 .704 r
.74098 .40741 .74411 .41523 .75029 .41132 .74679 .39805 Metetra
.732 .565 .665 r
.74679 .39805 .75029 .41132 .75625 .40427 .7526 .38898 Metetra
.686 .524 .661 r
.7526 .38898 .75625 .40427 .76209 .39567 .75857 .38216 Metetra
.645 .51 .684 r
.75857 .38216 .76209 .39567 .76795 .38749 .76477 .37856 Metetra
.592 .531 .756 r
.76477 .37856 .76795 .38749 .77396 .38133 .7712 .37783 Metetra
.407 .636 .949 r
.7712 .37783 .77396 .38133 .78017 .37787 .77777 .3787 Metetra
.282 0 0 r
.77777 .3787 .78017 .37787 .78659 .37674 .78436 .37948 Metetra
.3 0 0 r
.78436 .37948 .78659 .37674 .79314 .37686 .79085 .37874 Metetra
.79085 .37874 .79314 .37686 .79969 .37684 .79718 .37582 Metetra
.814 .965 .904 r
.79718 .37582 .79969 .37684 .80616 .37559 .80335 .37094 Metetra
.806 .748 .798 r
.80335 .37094 .80616 .37559 .81249 .37262 .80942 .36495 Metetra
.749 .64 .74 r
.80942 .36495 .81249 .37262 .81869 .36814 .81549 .35898 Metetra
.708 .594 .726 r
.81549 .35898 .81869 .36814 .82482 .36287 .82165 .35395 Metetra
.677 .581 .74 r
.82165 .35395 .82482 .36287 .83096 .35767 .82794 .35036 Metetra
.649 .598 .784 r
.82794 .35036 .83096 .35767 .83718 .35326 .83439 .34816 Metetra
.615 .655 .866 r
.83439 .34816 .83718 .35326 .84352 .34998 .84094 .34693 Metetra
.559 .749 .966 r
.84094 .34693 .84352 .34998 .84998 .34779 .84755 .34607 Metetra
.49 .823 .999 r
.84755 .34607 .84998 .34779 .85653 .34635 .85416 .34504 Metetra
.514 .865 .99 r
.85416 .34504 .85653 .34635 .86314 .34519 .86073 .34348 Metetra
.621 .882 .989 r
.86073 .34348 .86314 .34519 .86974 .34389 .86726 .3413 Metetra
.693 .84 .954 r
.86726 .3413 .86974 .34389 .87632 .3422 .87374 .33865 Metetra
.709 .779 .907 r
.87374 .33865 .87632 .3422 .88286 .34005 .88022 .33575 Metetra
.703 .735 .876 r
.88022 .33575 .88286 .34005 .88938 .33754 .8867 .33287 Metetra
.69 .712 .865 r
.8867 .33287 .88938 .33754 .89589 .33484 .89322 .33018 Metetra
.676 .706 .87 r
.89322 .33018 .89589 .33484 .90241 .33216 .89979 .32777 Metetra
.641 .727 .91 r
.30769 .51485 .3111 .51818 .31644 .51674 .31303 .51344 Metetra
.633 .726 .915 r
.31303 .51344 .31644 .51674 .3218 .51515 .31838 .51212 Metetra
.633 .744 .928 r
.31838 .51212 .3218 .51515 .32718 .51331 .32374 .51077 Metetra
.644 .781 .947 r
.32374 .51077 .32718 .51331 .3326 .51115 .32913 .50923 Metetra
.665 .831 .963 r
.32913 .50923 .3326 .51115 .33804 .50876 .33455 .50732 Metetra
.692 .872 .966 r
.33455 .50732 .33804 .50876 .34348 .50636 .34 .505 Metetra
.717 .881 .957 r
.34 .505 .34348 .50636 .34892 .50427 .34548 .50237 Metetra
.722 .842 .938 r
.34548 .50237 .34892 .50427 .35433 .50285 .35096 .49974 Metetra
.691 .756 .901 r
.35096 .49974 .35433 .50285 .35972 .50227 .35643 .49755 Metetra
.632 .654 .854 r
.35643 .49755 .35972 .50227 .36508 .50247 .36187 .49625 Metetra
.569 .57 .815 r
.36187 .49625 .36508 .50247 .37044 .50301 .36727 .49607 Metetra
.515 .521 .8 r
.36727 .49607 .37044 .50301 .37584 .50323 .37264 .49685 Metetra
.479 .519 .821 r
.37264 .49685 .37584 .50323 .3813 .50244 .37801 .49803 Metetra
.47 .6 .9 r
.37801 .49803 .3813 .50244 .38683 .50023 .38342 .4987 Metetra
.477 .808 1 r
.38342 .4987 .38683 .50023 .39242 .49677 .38891 .49798 Metetra
.39 .84 .745 r
.38891 .49798 .39242 .49677 .39803 .49287 .39449 .49542 Metetra
.424 .813 .579 r
.39449 .49542 .39803 .49287 .40362 .48977 .40013 .4913 Metetra
.694 .978 .796 r
.40013 .4913 .40362 .48977 .40914 .48868 .40579 .48671 Metetra
.77 .845 .908 r
.40579 .48671 .40914 .48868 .41459 .49028 .41142 .48321 Metetra
.606 .568 .785 r
.41142 .48321 .41459 .49028 .41999 .49427 .41697 .48228 Metetra
.487 .417 .703 r
.41697 .48228 .41999 .49427 .42538 .49931 .42244 .48462 Metetra
.409 .339 .667 r
.42244 .48462 .42538 .49931 .43084 .50348 .42785 .48971 Metetra
.349 .307 .669 r
.42785 .48971 .43084 .50348 .43639 .5049 .43326 .49583 Metetra
.292 .337 .737 r
.43326 .49583 .43639 .5049 .44207 .50264 .43875 .50058 Metetra
.134 .586 .925 r
.43875 .50058 .44207 .50264 .44783 .49715 .44436 .50183 Metetra
.129 0 0 r
.44436 .50183 .44783 .49715 .45361 .49019 .45009 .49862 Metetra
.051 0 .094 r
.45009 .49862 .45361 .49019 .45938 .48414 .45591 .49172 Metetra
.45591 .49172 .45938 .48414 .46509 .48102 .46174 .48335 Metetra
.808 .983 .707 r
.46174 .48335 .46509 .48102 .47075 .48161 .46755 .47633 Metetra
.719 .672 .804 r
.46755 .47633 .47075 .48161 .47638 .48515 .47329 .47287 Metetra
.544 .451 .701 r
.47329 .47287 .47638 .48515 .48203 .48958 .47898 .47368 Metetra
.463 .369 .664 r
.47898 .47368 .48203 .48958 .48773 .49237 .48465 .47769 Metetra
.426 .354 .672 r
.48465 .47769 .48773 .49237 .4935 .49156 .49034 .48246 Metetra
.438 .43 .753 r
.49034 .48246 .4935 .49156 .49931 .48657 .49609 .48516 Metetra
.552 .854 .998 r
.49609 .48516 .49931 .48657 .50515 .47838 .50189 .48379 Metetra
.50189 .48379 .50515 .47838 .51098 .46908 .50774 .47794 Metetra
0 0 .055 r
.50774 .47794 .51098 .46908 .51679 .46094 .51359 .4689 Metetra
.51359 .4689 .51679 .46094 .52259 .45557 .51943 .459 Metetra
.753 .925 .566 r
.51943 .459 .52259 .45557 .52839 .45336 .52525 .45059 Metetra
.826 .809 .834 r
.52525 .45059 .52839 .45336 .53422 .45353 .53107 .44515 Metetra
.649 .567 .748 r
.53107 .44515 .53422 .45353 .54006 .45455 .5369 .4428 Metetra
.575 .478 .707 r
.5369 .4428 .54006 .45455 .54592 .45478 .54275 .44255 Metetra
.561 .464 .702 r
.54275 .44255 .54592 .45478 .55179 .45311 .54862 .4428 Metetra
.588 .503 .726 r
.54862 .4428 .55179 .45311 .55765 .44929 .55451 .44215 Metetra
.653 .595 .777 r
.55451 .44215 .55765 .44929 .5635 .44394 .56039 .43995 Metetra
.739 .738 .85 r
.56039 .43995 .5635 .44394 .56934 .4382 .56627 .43645 Metetra
.789 .883 .914 r
.56627 .43645 .56934 .4382 .57519 .43329 .57215 .43248 Metetra
.746 .946 .946 r
.57215 .43248 .57519 .43329 .58107 .43011 .57805 .42896 Metetra
.674 .913 .975 r
.57805 .42896 .58107 .43011 .587 .4289 .58396 .42638 Metetra
.647 .804 .959 r
.58396 .42638 .587 .4289 .59298 .42924 .58991 .42457 Metetra
.645 .675 .864 r
.58991 .42457 .59298 .42924 .59899 .43018 .59587 .42294 Metetra
.649 .592 .777 r
.59587 .42294 .59899 .43018 .60501 .43055 .60183 .42083 Metetra
.651 .549 .726 r
.60183 .42083 .60501 .43055 .61102 .42943 .60778 .41804 Metetra
.645 .526 .704 r
.60778 .41804 .61102 .42943 .61698 .42651 .61375 .41509 Metetra
.625 .513 .707 r
.61375 .41509 .61698 .42651 .62292 .42227 .61974 .41299 Metetra
.573 .511 .747 r
.61974 .41299 .62292 .42227 .62886 .4179 .62581 .41281 Metetra
.353 .508 .873 r
.62581 .41281 .62886 .4179 .63485 .41488 .63198 .41502 Metetra
.611 .048 0 r
.63198 .41502 .63485 .41488 .64093 .41435 .63824 .41907 Metetra
.66 .245 .246 r
.63824 .41907 .64093 .41435 .64714 .41657 .64455 .42344 Metetra
.598 .22 .297 r
.64455 .42344 .64714 .41657 .65345 .42071 .65083 .42613 Metetra
.439 .032 .169 r
.65083 .42613 .65345 .42071 .65981 .42502 .65701 .42558 Metetra
.657 .971 .84 r
.65701 .42558 .65981 .42502 .66612 .42749 .66306 .42145 Metetra
.785 .686 .755 r
.66306 .42145 .66612 .42749 .67232 .42667 .669 .41494 Metetra
.71 .563 .686 r
.669 .41494 .67232 .42667 .67837 .42244 .67494 .40837 Metetra
.653 .51 .676 r
.67494 .40837 .67837 .42244 .68432 .41607 .68099 .40422 Metetra
.572 .479 .71 r
.68099 .40422 .68432 .41607 .69027 .40978 .68725 .40407 Metetra
.244 .415 .834 r
.68725 .40407 .69027 .40978 .69635 .40583 .69374 .40785 Metetra
.722 .242 .106 r
.69374 .40785 .69635 .40583 .70262 .4055 .70038 .41383 Metetra
.659 .297 .347 r
.70038 .41383 .70262 .4055 .70912 .40856 .70703 .41919 Metetra
.573 .239 .365 r
.70703 .41919 .70912 .40856 .71574 .41332 .71352 .42118 Metetra
.369 .022 .24 r
.71352 .42118 .71574 .41332 .72236 .41728 .71975 .41826 Metetra
.857 .992 .736 r
.71975 .41826 .72236 .41728 .72882 .41813 .72571 .41073 Metetra
.821 .674 .7 r
.72571 .41073 .72882 .41813 .73503 .4147 .73149 .40055 Metetra
.737 .562 .656 r
.73149 .40055 .73503 .4147 .74098 .40741 .73726 .39046 Metetra
.686 .515 .65 r
.73726 .39046 .74098 .40741 .74679 .39805 .74318 .38291 Metetra
.64 .496 .67 r
.74318 .38291 .74679 .39805 .7526 .38898 .74935 .37912 Metetra
.575 .507 .741 r
.74935 .37912 .7526 .38898 .75857 .38216 .75579 .37886 Metetra
.276 .574 .939 r
.75579 .37886 .75857 .38216 .76477 .37856 .7624 .38063 Metetra
.49 0 0 r
.7624 .38063 .76477 .37856 .7712 .37783 .76904 .38237 Metetra
.445 .01 .116 r
.76904 .38237 .7712 .37783 .77777 .3787 .77556 .38231 Metetra
.155 0 0 r
.77556 .38231 .77777 .3787 .78436 .37948 .78189 .37952 Metetra
.786 .998 .847 r
.78189 .37952 .78436 .37948 .79085 .37874 .78803 .37419 Metetra
.827 .756 .785 r
.78803 .37419 .79085 .37874 .79718 .37582 .79403 .36738 Metetra
.755 .629 .72 r
.79403 .36738 .79718 .37582 .80335 .37094 .80003 .36049 Metetra
.709 .577 .705 r
.80003 .36049 .80335 .37094 .80942 .36495 .80612 .35473 Metetra
.674 .56 .718 r
.80612 .35473 .80942 .36495 .81549 .35898 .81237 .35075 Metetra
.643 .575 .763 r
.81237 .35075 .81549 .35898 .82165 .35395 .8188 .34854 Metetra
.601 .634 .856 r
.8188 .34854 .82165 .35395 .82794 .35036 .82535 .34758 Metetra
.507 .745 .981 r
.82535 .34758 .82794 .35036 .83439 .34816 .83197 .34711 Metetra
.349 .792 .958 r
.83197 .34711 .83439 .34816 .84094 .34693 .83859 .3464 Metetra
.368 .828 .915 r
.83859 .3464 .84094 .34693 .84755 .34607 .84517 .34501 Metetra
.57 .906 .977 r
.84517 .34501 .84755 .34607 .85416 .34504 .85167 .3428 Metetra
.701 .869 .961 r
.85167 .3428 .85416 .34504 .86073 .34348 .85813 .33996 Metetra
.724 .787 .902 r
.85813 .33996 .86073 .34348 .86726 .3413 .86456 .3368 Metetra
.712 .728 .863 r
.86456 .3368 .86726 .3413 .87374 .33865 .871 .33367 Metetra
.695 .7 .85 r
.871 .33367 .87374 .33865 .88022 .33575 .87749 .3308 Metetra
.678 .694 .858 r
.87749 .3308 .88022 .33575 .8867 .33287 .88403 .32831 Metetra
.663 .706 .88 r
.88403 .32831 .8867 .33287 .89322 .33018 .89063 .32617 Metetra
.649 .73 .908 r
.89063 .32617 .89322 .33018 .89979 .32777 .89726 .32427 Metetra
.662 .755 .919 r
.30424 .51188 .30769 .51485 .31303 .51344 .30961 .51015 Metetra
.648 .733 .911 r
.30961 .51015 .31303 .51344 .31838 .51212 .31497 .50863 Metetra
.633 .716 .907 r
.31497 .50863 .31838 .51212 .32374 .51077 .32034 .50732 Metetra
.622 .716 .913 r
.32034 .50732 .32374 .51077 .32913 .50923 .32571 .50615 Metetra
.621 .739 .931 r
.32571 .50615 .32913 .50923 .33455 .50732 .33109 .50494 Metetra
.634 .792 .958 r
.33109 .50494 .33455 .50732 .34 .505 .33651 .50345 Metetra
.66 .86 .976 r
.33651 .50345 .34 .505 .34548 .50237 .34196 .50148 Metetra
.692 .912 .971 r
.34196 .50148 .34548 .50237 .35096 .49974 .34745 .49894 Metetra
.727 .922 .958 r
.34745 .49894 .35096 .49974 .35643 .49755 .35297 .496 Metetra
.739 .87 .941 r
.35297 .496 .35643 .49755 .36187 .49625 .3585 .49308 Metetra
.697 .755 .896 r
.3585 .49308 .36187 .49625 .36727 .49607 .364 .49078 Metetra
.621 .628 .836 r
.364 .49078 .36727 .49607 .37264 .49685 .36946 .48965 Metetra
.545 .53 .79 r
.36946 .48965 .37264 .49685 .37801 .49803 .37487 .48997 Metetra
.483 .475 .772 r
.37487 .48997 .37801 .49803 .38342 .4987 .38024 .49149 Metetra
.439 .472 .797 r
.38024 .49149 .38342 .4987 .38891 .49798 .38562 .49343 Metetra
.417 .568 .896 r
.38562 .49343 .38891 .49798 .39449 .49542 .39105 .49461 Metetra
.361 .801 .959 r
.39105 .49461 .39449 .49542 .40013 .4913 .39658 .49393 Metetra
.39658 .49393 .40013 .4913 .40579 .48671 .4022 .49089 Metetra
.4022 .49089 .40579 .48671 .41142 .48321 .4079 .48594 Metetra
.609 .909 .634 r
.4079 .48594 .41142 .48321 .41697 .48228 .41362 .48051 Metetra
.793 .86 .9 r
.41362 .48051 .41697 .48228 .42244 .48462 .41929 .47656 Metetra
.596 .541 .763 r
.41929 .47656 .42244 .48462 .42785 .48971 .42487 .47583 Metetra
.47 .387 .681 r
.42487 .47583 .42785 .48971 .43326 .49583 .43035 .47902 Metetra
.39 .312 .647 r
.43035 .47902 .43326 .49583 .43875 .50058 .43578 .48536 Metetra
.326 .279 .651 r
.43578 .48536 .43875 .50058 .44436 .50183 .44122 .49265 Metetra
.248 .308 .728 r
.44122 .49265 .44436 .50183 .45009 .49862 .44674 .49801 Metetra
0 .475 .704 r
.44674 .49801 .45009 .49862 .45591 .49172 .4524 .49899 Metetra
.212 0 .131 r
.4524 .49899 .45591 .49172 .46174 .48335 .45819 .4947 Metetra
.116 0 .198 r
.45819 .4947 .46174 .48335 .46755 .47633 .46406 .48626 Metetra
0 0 .072 r
.46406 .48626 .46755 .47633 .47329 .47287 .46994 .47644 Metetra
.726 .919 .567 r
.46994 .47644 .47329 .47287 .47898 .47368 .47577 .46851 Metetra
.725 .679 .805 r
.47577 .46851 .47898 .47368 .48465 .47769 .48154 .46488 Metetra
.528 .437 .696 r
.48154 .46488 .48465 .47769 .49034 .48246 .48726 .46622 Metetra
.436 .349 .66 r
.48726 .46622 .49034 .48246 .49609 .48516 .49297 .47115 Metetra
.379 .328 .674 r
.49297 .47115 .49609 .48516 .50189 .48379 .49871 .47686 Metetra
.32 .415 .803 r
.49871 .47686 .50189 .48379 .50774 .47794 .5045 .48024 Metetra
.176 0 0 r
.5045 .48024 .50774 .47794 .51359 .4689 .51034 .4791 Metetra
.237 0 .234 r
.51034 .4791 .51359 .4689 .51943 .459 .51621 .47306 Metetra
.19 0 .279 r
.51621 .47306 .51943 .459 .52525 .45059 .52208 .46355 Metetra
.094 0 .226 r
.52208 .46355 .52525 .45059 .53107 .44515 .52793 .45307 Metetra
.52793 .45307 .53107 .44515 .5369 .4428 .53377 .44418 Metetra
.762 .991 .778 r
.53377 .44418 .5369 .4428 .54275 .44255 .53962 .43858 Metetra
.663 .714 .886 r
.53962 .43858 .54275 .44255 .54862 .4428 .54548 .43668 Metetra
.487 .539 .836 r
.54548 .43668 .54862 .4428 .55451 .44215 .55138 .43772 Metetra
.264 .493 .89 r
.55138 .43772 .55451 .44215 .56039 .43995 .55732 .44016 Metetra
.444 0 0 r
.55732 .44016 .56039 .43995 .56627 .43645 .56329 .44232 Metetra
.508 .113 .226 r
.56329 .44232 .56627 .43645 .57215 .43248 .56925 .44285 Metetra
.454 .131 .327 r
.56925 .44285 .57215 .43248 .57805 .42896 .57521 .44101 Metetra
.386 .087 .33 r
.57521 .44101 .57805 .42896 .58396 .42638 .58113 .43678 Metetra
.266 0 .258 r
.58113 .43678 .58396 .42638 .58991 .42457 .58703 .43084 Metetra
.58703 .43084 .58991 .42457 .59587 .42294 .59292 .42433 Metetra
.735 .981 .754 r
.59292 .42433 .59587 .42294 .60183 .42083 .59882 .4187 Metetra
.754 .859 .927 r
.59882 .4187 .60183 .42083 .60778 .41804 .60477 .41532 Metetra
.49 .731 .979 r
.60477 .41532 .60778 .41804 .61375 .41509 .61082 .41506 Metetra
.495 0 0 r
.61082 .41506 .61375 .41509 .61974 .41299 .61697 .41795 Metetra
.677 .271 .268 r
.61697 .41795 .61974 .41299 .62581 .41281 .62322 .42291 Metetra
.645 .306 .383 r
.62322 .42291 .62581 .41281 .63198 .41502 .62951 .42798 Metetra
.592 .277 .404 r
.62951 .42798 .63198 .41502 .63824 .41907 .63576 .43087 Metetra
.496 .182 .363 r
.63576 .43087 .63824 .41907 .64455 .42344 .64191 .42989 Metetra
.135 0 .084 r
.64191 .42989 .64455 .42344 .65083 .42613 .64792 .42476 Metetra
.912 .895 .798 r
.64792 .42476 .65083 .42613 .65701 .42558 .65382 .41686 Metetra
.768 .627 .705 r
.65382 .41686 .65701 .42558 .66306 .42145 .65971 .40884 Metetra
.681 .538 .684 r
.65971 .40884 .66306 .42145 .669 .41494 .6657 .40358 Metetra
.584 .491 .715 r
.6657 .40358 .669 .41494 .67494 .40837 .67191 .40299 Metetra
.17 .384 .83 r
.67191 .40299 .67494 .40837 .68099 .40422 .67837 .40715 Metetra
.746 .301 .194 r
.67837 .40715 .68099 .40422 .68725 .40407 .68501 .41422 Metetra
.674 .33 .384 r
.68501 .41422 .68725 .40407 .69374 .40785 .69168 .42101 Metetra
.597 .28 .402 r
.69168 .42101 .69374 .40785 .70038 .41383 .69821 .42426 Metetra
.442 .12 .324 r
.69821 .42426 .70038 .41383 .70703 .41919 .70446 .42196 Metetra
.65 .877 .516 r
.70446 .42196 .70703 .41919 .71352 .42118 .71042 .41422 Metetra
.839 .688 .695 r
.71042 .41422 .71352 .42118 .71975 .41826 .71618 .40315 Metetra
.741 .559 .647 r
.71618 .40315 .71975 .41826 .72571 .41073 .7219 .39193 Metetra
.685 .507 .64 r
.7219 .39193 .72571 .41073 .73149 .40055 .72777 .38349 Metetra
.636 .483 .658 r
.72777 .38349 .73149 .40055 .73726 .39046 .73393 .37947 Metetra
.56 .482 .724 r
.73393 .37947 .73726 .39046 .74318 .38291 .74037 .37971 Metetra
.107 .474 .895 r
.74037 .37971 .74318 .38291 .74935 .37912 .74702 .38252 Metetra
.594 .124 .109 r
.74702 .38252 .74935 .37912 .75579 .37886 .75371 .38545 Metetra
.522 .134 .247 r
.75371 .38545 .75579 .37886 .7624 .38063 .76027 .38624 Metetra
.315 0 .127 r
.76027 .38624 .7624 .38063 .76904 .38237 .76661 .38368 Metetra
.663 .944 .688 r
.76661 .38368 .76904 .38237 .77556 .38231 .77272 .37791 Metetra
.849 .766 .77 r
.77272 .37791 .77556 .38231 .78189 .37952 .77866 .37018 Metetra
.761 .619 .702 r
.77866 .37018 .78189 .37952 .78803 .37419 .78458 .36222 Metetra
.709 .562 .685 r
.78458 .36222 .78803 .37419 .79403 .36738 .7906 .35558 Metetra
.671 .541 .697 r
.7906 .35558 .79403 .36738 .80003 .36049 .79681 .35114 Metetra
.636 .551 .742 r
.79681 .35114 .80003 .36049 .80612 .35473 .80321 .34893 Metetra
.584 .611 .845 r
.80321 .34893 .80612 .35473 .81237 .35075 .80977 .34831 Metetra
.423 .729 .989 r
.80977 .34831 .81237 .35075 .8188 .34854 .81642 .34832 Metetra
.103 .657 .789 r
.81642 .34832 .8188 .34854 .82535 .34758 .82305 .34803 Metetra
.82305 .34803 .82535 .34758 .83197 .34711 .82962 .34684 Metetra
.457 .884 .898 r
.82962 .34684 .83197 .34711 .83859 .3464 .83611 .3446 Metetra
.708 .903 .965 r
.83611 .3446 .83859 .3464 .84517 .34501 .84253 .34152 Metetra
.741 .794 .895 r
.84253 .34152 .84517 .34501 .85167 .3428 .84892 .33803 Metetra
.722 .719 .847 r
.84892 .33803 .85167 .3428 .85813 .33996 .85531 .33457 Metetra
.699 .685 .833 r
.85531 .33457 .85813 .33996 .86456 .3368 .86176 .33147 Metetra
.679 .678 .842 r
.86176 .33147 .86456 .3368 .871 .33367 .86828 .32888 Metetra
.661 .694 .87 r
.86828 .32888 .871 .33367 .87749 .3308 .87485 .32676 Metetra
.644 .726 .908 r
.87485 .32676 .87749 .3308 .88403 .32831 .88149 .32496 Metetra
.629 .764 .944 r
.88149 .32496 .88403 .32831 .89063 .32617 .88815 .32329 Metetra
.622 .795 .965 r
.88815 .32329 .89063 .32617 .89726 .32427 .89482 .32158 Metetra
.679 .803 .941 r
.30073 .50954 .30424 .51188 .30961 .51015 .30612 .50755 Metetra
.675 .784 .932 r
.30612 .50755 .30961 .51015 .31497 .50863 .31152 .50563 Metetra
.662 .755 .919 r
.31152 .50563 .31497 .50863 .32034 .50732 .31692 .5039 Metetra
.643 .724 .907 r
.31692 .5039 .32034 .50732 .32571 .50615 .32232 .50245 Metetra
.622 .701 .902 r
.32232 .50245 .32571 .50615 .33109 .50494 .3277 .50129 Metetra
.607 .7 .91 r
.3277 .50129 .33109 .50494 .33651 .50345 .33309 .50031 Metetra
.605 .732 .935 r
.33309 .50031 .33651 .50345 .34196 .50148 .3385 .49928 Metetra
.62 .804 .97 r
.3385 .49928 .34196 .50148 .34745 .49894 .34394 .49787 Metetra
.646 .894 .984 r
.34394 .49787 .34745 .49894 .35297 .496 .34942 .4958 Metetra
.677 .951 .955 r
.34942 .4958 .35297 .496 .3585 .49308 .35496 .49299 Metetra
.727 .963 .941 r
.35496 .49299 .3585 .49308 .364 .49078 .36053 .48966 Metetra
.758 .903 .941 r
.36053 .48966 .364 .49078 .36946 .48965 .3661 .48639 Metetra
.703 .752 .89 r
.3661 .48639 .36946 .48965 .37487 .48997 .37164 .48395 Metetra
.606 .597 .816 r
.37164 .48395 .37487 .48997 .38024 .49149 .37712 .48306 Metetra
.519 .488 .762 r
.37712 .48306 .38024 .49149 .38562 .49343 .38253 .48401 Metetra
.45 .429 .743 r
.38253 .48401 .38562 .49343 .39105 .49461 .3879 .48644 Metetra
.398 .423 .77 r
.3879 .48644 .39105 .49461 .39658 .49393 .39329 .48927 Metetra
.353 .529 .89 r
.39329 .48927 .39658 .49393 .4022 .49089 .39874 .49101 Metetra
.163 .703 .788 r
.39874 .49101 .4022 .49089 .4079 .48594 .4043 .49031 Metetra
.005 0 0 r
.4043 .49031 .4079 .48594 .41362 .48051 .40998 .48663 Metetra
.40998 .48663 .41362 .48051 .41929 .47656 .41574 .48065 Metetra
.41574 .48065 .41929 .47656 .42487 .47583 .42152 .47422 Metetra
.815 .871 .888 r
.42152 .47422 .42487 .47583 .43035 .47902 .42723 .46976 Metetra
.585 .513 .741 r
.42723 .46976 .43035 .47902 .43578 .48536 .43284 .46926 Metetra
.456 .362 .66 r
.43284 .46926 .43578 .48536 .44122 .49265 .43833 .4734 Metetra
.377 .29 .629 r
.43833 .4734 .44122 .49265 .44674 .49801 .44378 .48106 Metetra
.314 .259 .635 r
.44378 .48106 .44674 .49801 .4524 .49899 .44925 .48948 Metetra
.232 .291 .718 r
.44925 .48948 .4524 .49899 .45819 .4947 .45482 .49525 Metetra
.207 0 0 r
.45482 .49525 .45819 .4947 .46406 .48626 .46054 .49566 Metetra
.209 0 .196 r
.46054 .49566 .46406 .48626 .46994 .47644 .46639 .48993 Metetra
.108 0 .229 r
.46639 .48993 .46994 .47644 .47577 .46851 .4723 .47969 Metetra
0 0 .09 r
.4723 .47969 .47577 .46851 .48154 .46488 .47822 .46829 Metetra
.811 .95 .603 r
.47822 .46829 .48154 .46488 .48726 .46622 .48408 .45946 Metetra
.705 .627 .768 r
.48408 .45946 .48726 .46622 .49297 .47115 .48987 .45576 Metetra
.521 .412 .671 r
.48987 .45576 .49297 .47115 .49871 .47686 .49563 .4576 Metetra
.444 .338 .64 r
.49563 .4576 .49871 .47686 .5045 .48024 .50138 .46314 Metetra
.414 .33 .652 r
.50138 .46314 .5045 .48024 .51034 .4791 .50716 .46903 Metetra
.449 .421 .736 r
.50716 .46903 .51034 .4791 .51621 .47306 .513 .47181 Metetra
.672 .902 .977 r
.513 .47181 .51621 .47306 .52208 .46355 .51888 .46934 Metetra
.51888 .46934 .52208 .46355 .52793 .45307 .52476 .46164 Metetra
.52476 .46164 .52793 .45307 .53377 .44418 .53064 .45079 Metetra
.53064 .45079 .53377 .44418 .53962 .43858 .53649 .4399 Metetra
.908 .983 .75 r
.53649 .4399 .53962 .43858 .54548 .43668 .54234 .43179 Metetra
.737 .698 .814 r
.54234 .43179 .54548 .43668 .55138 .43772 .54821 .42794 Metetra
.563 .496 .738 r
.54821 .42794 .55138 .43772 .55732 .44016 .55412 .42801 Metetra
.497 .425 .706 r
.55412 .42801 .55732 .44016 .56329 .44232 .56007 .43018 Metetra
.511 .434 .706 r
.56007 .43018 .56329 .44232 .56925 .44285 .56605 .43197 Metetra
.586 .496 .719 r
.56605 .43197 .56925 .44285 .57521 .44101 .57201 .43133 Metetra
.676 .564 .721 r
.57201 .43133 .57521 .44101 .58113 .43678 .57795 .42755 Metetra
.727 .598 .712 r
.57795 .42755 .58113 .43678 .58703 .43084 .58384 .42151 Metetra
.729 .598 .709 r
.58384 .42151 .58703 .43084 .59292 .42433 .58974 .4153 Metetra
.69 .581 .728 r
.58974 .4153 .59292 .42433 .59882 .4187 .59567 .41119 Metetra
.585 .553 .785 r
.59567 .41119 .59882 .4187 .60477 .41532 .6017 .41065 Metetra
.223 .455 .872 r
.6017 .41065 .60477 .41532 .61082 .41506 .60783 .41364 Metetra
.565 0 0 r
.60783 .41364 .61082 .41506 .61697 .41795 .61405 .4185 Metetra
.635 .088 0 r
.61405 .4185 .61697 .41795 .62322 .42291 .62028 .42262 Metetra
.137 0 0 r
.62028 .42262 .62322 .42291 .62951 .42798 .62645 .42355 Metetra
.727 .721 .845 r
.62645 .42355 .62951 .42798 .63576 .43087 .6325 .42016 Metetra
.725 .581 .693 r
.6325 .42016 .63576 .43087 .64191 .42989 .63844 .4133 Metetra
.691 .52 .651 r
.63844 .4133 .64191 .42989 .64792 .42476 .64434 .40554 Metetra
.648 .481 .643 r
.64434 .40554 .64792 .42476 .65382 .41686 .65032 .40007 Metetra
.581 .447 .663 r
.65032 .40007 .65382 .41686 .65971 .40884 .65649 .39933 Metetra
.357 .376 .744 r
.65649 .39933 .65971 .40884 .6657 .40358 .66291 .40386 Metetra
.786 .295 .04 r
.66291 .40386 .6657 .40358 .67191 .40299 .66952 .41198 Metetra
.708 .354 .375 r
.66952 .41198 .67191 .40299 .67837 .40715 .6762 .42033 Metetra
.625 .305 .408 r
.6762 .42033 .67837 .40715 .68501 .41422 .68276 .42518 Metetra
.483 .161 .343 r
.68276 .42518 .68501 .41422 .69168 .42101 .68906 .42398 Metetra
.6 .849 .488 r
.68906 .42398 .69168 .42101 .69821 .42426 .69505 .41652 Metetra
.831 .672 .686 r
.69505 .41652 .69821 .42426 .70446 .42196 .7008 .40495 Metetra
.735 .547 .638 r
.7008 .40495 .70446 .42196 .71042 .41422 .7065 .39284 Metetra
.681 .496 .63 r
.7065 .39284 .71042 .41422 .71618 .40315 .71235 .38367 Metetra
.629 .468 .645 r
.71235 .38367 .71618 .40315 .7219 .39193 .71848 .37949 Metetra
.543 .456 .706 r
.71848 .37949 .7219 .39193 .72777 .38349 .72494 .38035 Metetra
0 .335 .805 r
.72494 .38035 .72777 .38349 .73393 .37947 .73162 .38437 Metetra
.649 .226 .227 r
.73162 .38437 .73393 .37947 .74037 .37971 .73836 .38869 Metetra
.567 .213 .328 r
.73836 .38869 .74037 .37971 .74702 .38252 .74498 .39054 Metetra
.408 .057 .255 r
.74498 .39054 .74702 .38252 .75371 .38545 .75133 .38833 Metetra
.75133 .38833 .75371 .38545 .76027 .38624 .75741 .38212 Metetra
.872 .778 .755 r
.75741 .38212 .76027 .38624 .76661 .38368 .7633 .37336 Metetra
.766 .61 .684 r
.7633 .37336 .76661 .38368 .77272 .37791 .76914 .36417 Metetra
.709 .548 .668 r
.76914 .36417 .77272 .37791 .77866 .37018 .77509 .35652 Metetra
.668 .523 .678 r
.77509 .35652 .77866 .37018 .78458 .36222 .78125 .35154 Metetra
.628 .528 .721 r
.78125 .35154 .78458 .36222 .7906 .35558 .78763 .34934 Metetra
.563 .584 .833 r
.78763 .34934 .7906 .35558 .79681 .35114 .79421 .34914 Metetra
.284 .684 .972 r
.79421 .34914 .79681 .35114 .80321 .34893 .80087 .34974 Metetra
.192 0 0 r
.80087 .34974 .80321 .34893 .80977 .34831 .80753 .34997 Metetra
.151 0 0 r
.80753 .34997 .80977 .34831 .81642 .34832 .8141 .34904 Metetra
.257 .755 .691 r
.8141 .34904 .81642 .34832 .82305 .34803 .82057 .34675 Metetra
.712 .94 .959 r
.82057 .34675 .82305 .34803 .82962 .34684 .82695 .34337 Metetra
.761 .8 .884 r
.82695 .34337 .82962 .34684 .83611 .3446 .83329 .33945 Metetra
.732 .707 .828 r
.83329 .33945 .83611 .3446 .84253 .34152 .83964 .33558 Metetra
.703 .667 .811 r
.83964 .33558 .84253 .34152 .84892 .33803 .84604 .3322 Metetra
.679 .66 .824 r
.84604 .3322 .84892 .33803 .85531 .33457 .85253 .32949 Metetra
.658 .679 .859 r
.85253 .32949 .85531 .33457 .86176 .33147 .85909 .32739 Metetra
.636 .72 .909 r
.85909 .32739 .86176 .33147 .86828 .32888 .86572 .32572 Metetra
.613 .77 .955 r
.86572 .32572 .86828 .32888 .87485 .32676 .87238 .32421 Metetra
.6 .811 .981 r
.87238 .32421 .87485 .32676 .88149 .32496 .87905 .32263 Metetra
.607 .833 .986 r
.87905 .32263 .88149 .32496 .88815 .32329 .88571 .32087 Metetra
.632 .836 .979 r
.88571 .32087 .88815 .32329 .89482 .32158 .89237 .31887 Metetra
.671 .824 .957 r
.29719 .50751 .30073 .50954 .30612 .50755 .30259 .50556 Metetra
.68 .829 .955 r
.30259 .50556 .30612 .50755 .31152 .50563 .308 .5035 Metetra
.684 .82 .948 r
.308 .5035 .31152 .50563 .31692 .5039 .31343 .5014 Metetra
.679 .793 .935 r
.31343 .5014 .31692 .5039 .32232 .50245 .31887 .4994 Metetra
.662 .754 .918 r
.31887 .4994 .32232 .50245 .3277 .50129 .3243 .49766 Metetra
.635 .711 .902 r
.3243 .49766 .3277 .50129 .33309 .50031 .32971 .4963 Metetra
.607 .681 .894 r
.32971 .4963 .33309 .50031 .3385 .49928 .33512 .49535 Metetra
.587 .678 .903 r
.33512 .49535 .3385 .49928 .34394 .49787 .34052 .49464 Metetra
.583 .72 .937 r
.34052 .49464 .34394 .49787 .34942 .4958 .34595 .49384 Metetra
.598 .817 .984 r
.34595 .49384 .34942 .4958 .35496 .49299 .35141 .49253 Metetra
.611 .923 .972 r
.35141 .49253 .35496 .49299 .36053 .48966 .35694 .49034 Metetra
.623 .96 .886 r
.35694 .49034 .36053 .48966 .3661 .48639 .36252 .48718 Metetra
.702 .983 .881 r
.36252 .48718 .3661 .48639 .37164 .48395 .36814 .48336 Metetra
.777 .939 .933 r
.36814 .48336 .37164 .48395 .37712 .48306 .37376 .47966 Metetra
.709 .747 .882 r
.37376 .47966 .37712 .48306 .38253 .48401 .37933 .47707 Metetra
.59 .563 .792 r
.37933 .47707 .38253 .48401 .3879 .48644 .38483 .47649 Metetra
.492 .446 .734 r
.38483 .47649 .3879 .48644 .39329 .48927 .39024 .47822 Metetra
.418 .383 .713 r
.39024 .47822 .39329 .48927 .39874 .49101 .39562 .48173 Metetra
.354 .372 .741 r
.39562 .48173 .39874 .49101 .4043 .49031 .401 .48561 Metetra
.269 .481 .88 r
.401 .48561 .4043 .49031 .40998 .48663 .40648 .48797 Metetra
.081 0 0 r
.40648 .48797 .40998 .48663 .41574 .48065 .41208 .48718 Metetra
.126 0 .048 r
.41208 .48718 .41574 .48065 .42152 .47422 .41782 .48269 Metetra
.003 0 .062 r
.41782 .48269 .42152 .47422 .42723 .46976 .42365 .47548 Metetra
.42365 .47548 .42723 .46976 .43284 .46926 .42948 .4679 Metetra
.839 .885 .874 r
.42948 .4679 .43284 .46926 .43833 .4734 .43524 .46284 Metetra
.574 .49 .721 r
.43524 .46284 .43833 .4734 .44378 .48106 .44087 .46259 Metetra
.443 .34 .643 r
.44087 .46259 .44378 .48106 .44925 .48948 .44639 .46775 Metetra
.365 .271 .614 r
.44639 .46775 .44925 .48948 .45482 .49525 .45186 .4768 Metetra
.298 .239 .621 r
.45186 .4768 .45482 .49525 .46054 .49566 .45737 .48641 Metetra
.18 .263 .714 r
.45737 .48641 .46054 .49566 .46639 .48993 .46299 .49264 Metetra
.362 0 0 r
.46299 .49264 .46639 .48993 .4723 .47969 .46876 .49254 Metetra
.26 0 .283 r
.46876 .49254 .4723 .47969 .47822 .46829 .47466 .48551 Metetra
.165 0 .295 r
.47466 .48551 .47822 .46829 .48408 .45946 .48061 .47361 Metetra
0 0 .186 r
.48061 .47361 .48408 .45946 .48987 .45576 .48655 .46071 Metetra
.696 .856 .443 r
.48655 .46071 .48987 .45576 .49563 .4576 .49244 .45083 Metetra
.72 .635 .762 r
.49244 .45083 .49563 .4576 .50138 .46314 .49826 .44658 Metetra
.529 .411 .663 r
.49826 .44658 .50138 .46314 .50716 .46903 .50405 .44821 Metetra
.455 .34 .633 r
.50405 .44821 .50716 .46903 .513 .47181 .50985 .45369 Metetra
.423 .33 .646 r
.50985 .45369 .513 .47181 .51888 .46934 .51569 .45964 Metetra
.425 .413 .743 r
.51569 .45964 .51888 .46934 .52476 .46164 .52157 .46275 Metetra
.52157 .46275 .52476 .46164 .53064 .45079 .52747 .46108 Metetra
.22 0 .228 r
.52747 .46108 .53064 .45079 .53649 .4399 .53338 .4547 Metetra
.221 0 .3 r
.53338 .4547 .53649 .4399 .54234 .43179 .53927 .44532 Metetra
.151 0 .258 r
.53927 .44532 .54234 .43179 .54821 .42794 .54514 .43536 Metetra
.54514 .43536 .54821 .42794 .55412 .42801 .55101 .42686 Metetra
.871 .91 .854 r
.55101 .42686 .55412 .42801 .56007 .43018 .55689 .42088 Metetra
.67 .565 .728 r
.55689 .42088 .56007 .43018 .56605 .43197 .5628 .41748 Metetra
.596 .469 .678 r
.5628 .41748 .56605 .43197 .57201 .43133 .56874 .41617 Metetra
.561 .442 .674 r
.56874 .41617 .57201 .43133 .57795 .42755 .57473 .41637 Metetra
.518 .45 .72 r
.57473 .41637 .57795 .42755 .58384 .42151 .58075 .41779 Metetra
.189 .495 .904 r
.58075 .41779 .58384 .42151 .58974 .4153 .58682 .42024 Metetra
.615 .201 .234 r
.58682 .42024 .58974 .4153 .59567 .41119 .59294 .42331 Metetra
.59 .269 .393 r
.59294 .42331 .59567 .41119 .6017 .41065 .59907 .42606 Metetra
.553 .255 .415 r
.59907 .42606 .6017 .41065 .60783 .41364 .6052 .42711 Metetra
.477 .176 .375 r
.6052 .42711 .60783 .41364 .61405 .4185 .61127 .42517 Metetra
.121 0 .08 r
.61127 .42517 .61405 .4185 .62028 .42262 .61726 .41985 Metetra
.878 .82 .787 r
.61726 .41985 .62028 .42262 .62645 .42355 .62317 .41213 Metetra
.732 .578 .682 r
.62317 .41213 .62645 .42355 .6325 .42016 .62908 .40437 Metetra
.656 .501 .662 r
.62908 .40437 .6325 .42016 .63844 .4133 .63507 .39944 Metetra
.563 .454 .688 r
.63507 .39944 .63844 .4133 .64434 .40554 .64125 .39955 Metetra
.053 .28 .772 r
.64125 .39955 .64434 .40554 .65032 .40007 .64766 .40516 Metetra
.765 .371 .308 r
.64766 .40516 .65032 .40007 .65649 .39933 .65426 .41449 Metetra
.682 .368 .436 r
.65426 .41449 .65649 .39933 .66291 .40386 .66092 .42402 Metetra
.617 .326 .453 r
.66092 .42402 .66291 .40386 .66952 .41198 .66748 .42972 Metetra
.517 .232 .421 r
.66748 .42972 .66952 .41198 .6762 .42033 .67377 .42875 Metetra
.055 0 .13 r
.67377 .42875 .6762 .42033 .68276 .42518 .67975 .42074 Metetra
.901 .757 .693 r
.67975 .42074 .68276 .42518 .68906 .42398 .68548 .40798 Metetra
.756 .564 .637 r
.68548 .40798 .68906 .42398 .69505 .41652 .69115 .39448 Metetra
.688 .499 .626 r
.69115 .39448 .69505 .41652 .7008 .40495 .69695 .38423 Metetra
.63 .464 .639 r
.69695 .38423 .7008 .40495 .7065 .39284 .70306 .37973 Metetra
.527 .439 .699 r
.70306 .37973 .7065 .39284 .71235 .38367 .70952 .38118 Metetra
0 .117 .593 r
.70952 .38118 .71235 .38367 .71848 .37949 .71623 .38652 Metetra
.677 .294 .314 r
.71623 .38652 .71848 .37949 .72494 .38035 .72303 .39239 Metetra
.593 .266 .384 r
.72303 .39239 .72494 .38035 .73162 .38437 .72969 .39546 Metetra
.465 .146 .339 r
.72969 .39546 .73162 .38437 .73836 .38869 .73606 .39369 Metetra
.73606 .39369 .73836 .38869 .74498 .39054 .74212 .38699 Metetra
.901 .8 .739 r
.74212 .38699 .74498 .39054 .75133 .38833 .74795 .37705 Metetra
.773 .604 .669 r
.74795 .37705 .75133 .38833 .75741 .38212 .75372 .36644 Metetra
.71 .537 .652 r
.75372 .36644 .75741 .38212 .7633 .37336 .75959 .35758 Metetra
.666 .508 .662 r
.75959 .35758 .7633 .37336 .76914 .36417 .76569 .35196 Metetra
.621 .507 .702 r
.76569 .35196 .76914 .36417 .77509 .35652 .77206 .34975 Metetra
.54 .555 .819 r
.77206 .34975 .77509 .35652 .78125 .35154 .77865 .35006 Metetra
.063 .572 .883 r
.77865 .35006 .78125 .35154 .78763 .34934 .78534 .35139 Metetra
.405 0 0 r
.78534 .35139 .78763 .34934 .79421 .34914 .79202 .35226 Metetra
.337 0 0 r
.79202 .35226 .79421 .34914 .80087 .34974 .79861 .35166 Metetra
.79861 .35166 .80087 .34974 .80753 .34997 .80506 .34931 Metetra
.705 .97 .931 r
.80506 .34931 .80753 .34997 .8141 .34904 .8114 .34555 Metetra
.783 .803 .869 r
.8114 .34555 .8141 .34904 .82057 .34675 .81768 .3411 Metetra
.741 .692 .805 r
.81768 .3411 .82057 .34675 .82695 .34337 .82397 .33672 Metetra
.706 .647 .788 r
.82397 .33672 .82695 .34337 .83329 .33945 .83033 .33298 Metetra
.678 .639 .803 r
.83033 .33298 .83329 .33945 .83964 .33558 .83679 .33012 Metetra
.653 .662 .846 r
.83679 .33012 .83964 .33558 .84604 .3322 .84334 .32807 Metetra
.626 .713 .909 r
.84334 .32807 .84604 .3322 .85253 .32949 .84996 .32656 Metetra
.59 .777 .969 r
.84996 .32656 .85253 .32949 .85909 .32739 .85662 .32526 Metetra
.561 .827 .995 r
.85662 .32526 .85909 .32739 .86572 .32572 .86329 .32386 Metetra
.57 .853 .997 r
.86329 .32386 .86572 .32572 .87238 .32421 .86994 .32219 Metetra
.612 .86 .99 r
.86994 .32219 .87238 .32421 .87905 .32263 .87659 .32021 Metetra
.652 .844 .974 r
.87659 .32021 .87905 .32263 .88571 .32087 .88321 .31796 Metetra
.674 .816 .952 r
.88321 .31796 .88571 .32087 .89237 .31887 .88984 .31556 Metetra
.653 .809 .958 r
.29364 .50531 .29719 .50751 .30259 .50556 .29903 .50359 Metetra
.66 .828 .964 r
.29903 .50359 .30259 .50556 .308 .5035 .30444 .50173 Metetra
.672 .846 .966 r
.30444 .50173 .308 .5035 .31343 .5014 .30988 .4997 Metetra
.684 .853 .963 r
.30988 .4997 .31343 .5014 .31887 .4994 .31533 .49752 Metetra
.691 .841 .955 r
.31533 .49752 .31887 .4994 .3243 .49766 .3208 .49528 Metetra
.685 .805 .939 r
.3208 .49528 .3243 .49766 .32971 .4963 .32627 .49318 Metetra
.661 .75 .916 r
.32627 .49318 .32971 .4963 .33512 .49535 .33173 .49143 Metetra
.626 .694 .893 r
.33173 .49143 .33512 .49535 .34052 .49464 .33716 .49021 Metetra
.589 .654 .881 r
.33716 .49021 .34052 .49464 .34595 .49384 .34259 .48952 Metetra
.562 .648 .893 r
.34259 .48952 .34595 .49384 .35141 .49253 .34801 .48916 Metetra
.554 .702 .938 r
.34801 .48916 .35141 .49253 .35694 .49034 .35345 .48867 Metetra
.562 .83 .996 r
.35345 .48867 .35694 .49034 .36252 .48718 .35894 .48749 Metetra
.532 .92 .908 r
.35894 .48749 .36252 .48718 .36814 .48336 .3645 .48514 Metetra
.504 .891 .722 r
.3645 .48514 .36814 .48336 .37376 .47966 .37013 .48153 Metetra
.627 .948 .751 r
.37013 .48153 .37376 .47966 .37933 .47707 .37581 .47711 Metetra
.792 .972 .912 r
.37581 .47711 .37933 .47707 .38483 .47649 .38147 .47289 Metetra
.714 .739 .871 r
.38147 .47289 .38483 .47649 .39024 .47822 .38708 .47014 Metetra
.571 .527 .767 r
.38708 .47014 .39024 .47822 .39562 .48173 .3926 .46995 Metetra
.466 .405 .705 r
.3926 .46995 .39562 .48173 .401 .48561 .39802 .47265 Metetra
.387 .34 .684 r
.39802 .47265 .401 .48561 .40648 .48797 .40339 .47745 Metetra
.312 .323 .711 r
.40339 .47745 .40648 .48797 .41208 .48718 .40878 .48253 Metetra
.164 .422 .86 r
.40878 .48253 .41208 .48718 .41782 .48269 .41428 .48553 Metetra
.247 0 0 r
.41428 .48553 .41782 .48269 .42365 .47548 .41993 .48453 Metetra
.193 0 .172 r
.41993 .48453 .42365 .47548 .42948 .4679 .42573 .479 Metetra
.065 0 .161 r
.42573 .479 .42948 .4679 .43524 .46284 .43163 .47031 Metetra
.43163 .47031 .43524 .46284 .44087 .46259 .43751 .46142 Metetra
.859 .893 .859 r
.43751 .46142 .44087 .46259 .44639 .46775 .44331 .45579 Metetra
.559 .465 .704 r
.44331 .45579 .44639 .46775 .45186 .4768 .44896 .45599 Metetra
.424 .316 .628 r
.44896 .45599 .45186 .4768 .45737 .48641 .4545 .46253 Metetra
.341 .246 .601 r
.4545 .46253 .45737 .48641 .46299 .49264 .46 .47338 Metetra
.256 .206 .607 r
.46 .47338 .46299 .49264 .46876 .49254 .46555 .48452 Metetra
.027 .193 .7 r
.46555 .48452 .46876 .49254 .47466 .48551 .47122 .49136 Metetra
.433 .034 .181 r
.47122 .49136 .47466 .48551 .48061 .47361 .47705 .49067 Metetra
.292 .035 .341 r
.47705 .49067 .48061 .47361 .48655 .46071 .48299 .48202 Metetra
.198 0 .336 r
.48299 .48202 .48655 .46071 .49244 .45083 .48898 .46812 Metetra
.051 0 .249 r
.48898 .46812 .49244 .45083 .49826 .44658 .49495 .45361 Metetra
.49495 .45361 .49826 .44658 .50405 .44821 .50085 .4432 Metetra
.718 .686 .819 r
.50085 .4432 .50405 .44821 .50985 .45369 .5067 .43985 Metetra
.445 .374 .683 r
.5067 .43985 .50985 .45369 .51569 .45964 .51252 .44377 Metetra
.292 .254 .643 r
.51252 .44377 .51569 .45964 .52157 .46275 .51837 .45242 Metetra
.031 .142 .648 r
.51837 .45242 .52157 .46275 .52747 .46108 .52427 .46154 Metetra
.71 .194 0 r
.52427 .46154 .52747 .46108 .53338 .4547 .53022 .46673 Metetra
.476 .163 .356 r
.53022 .46673 .53338 .4547 .53927 .44532 .53618 .4652 Metetra
.352 .1 .386 r
.53618 .4652 .53927 .44532 .54514 .43536 .54212 .45676 Metetra
.245 .019 .36 r
.54212 .45676 .54514 .43536 .55101 .42686 .54801 .44378 Metetra
.106 0 .278 r
.54801 .44378 .55101 .42686 .55689 .42088 .55387 .43018 Metetra
0 0 .056 r
.55387 .43018 .55689 .42088 .5628 .41748 .55974 .41993 Metetra
.55974 .41993 .5628 .41748 .56874 .41617 .56567 .41571 Metetra
.383 0 0 r
.56567 .41571 .56874 .41617 .57473 .41637 .5717 .41806 Metetra
.771 .314 .163 r
.5717 .41806 .57473 .41637 .58075 .41779 .57783 .42529 Metetra
.73 .369 .367 r
.57783 .42529 .58075 .41779 .58682 .42024 .58404 .434 Metetra
.646 .331 .423 r
.58404 .434 .58682 .42024 .59294 .42331 .59025 .44018 Metetra
.543 .251 .422 r
.59025 .44018 .59294 .42331 .59907 .42606 .59638 .4407 Metetra
.355 .079 .348 r
.59638 .4407 .59907 .42606 .6052 .42711 .60238 .43455 Metetra
.60238 .43455 .6052 .42711 .61127 .42517 .60824 .42339 Metetra
.944 .832 .702 r
.60824 .42339 .61127 .42517 .61726 .41985 .61405 .41094 Metetra
.784 .632 .693 r
.61405 .41094 .61726 .41985 .62317 .41213 .61992 .40157 Metetra
.649 .539 .716 r
.61992 .40157 .62317 .41213 .62908 .40437 .62598 .39862 Metetra
.15 .356 .812 r
.62598 .39862 .62908 .40437 .63507 .39944 .63229 .40309 Metetra
.794 .385 .275 r
.63229 .40309 .63507 .39944 .64125 .39955 .63884 .4131 Metetra
.713 .39 .43 r
.63884 .4131 .64125 .39955 .64766 .40516 .6455 .4245 Metetra
.644 .347 .453 r
.6455 .4245 .64766 .40516 .65426 .41449 .65208 .43231 Metetra
.543 .254 .426 r
.65208 .43231 .65426 .41449 .66092 .42402 .65842 .43278 Metetra
.087 0 .149 r
.65842 .43278 .66092 .42402 .66748 .42972 .66442 .42501 Metetra
.902 .748 .682 r
.66442 .42501 .66748 .42972 .67377 .42875 .67015 .41132 Metetra
.758 .56 .629 r
.67015 .41132 .67377 .42875 .67975 .42074 .67579 .39622 Metetra
.69 .494 .618 r
.67579 .39622 .67975 .42074 .68548 .40798 .68155 .38449 Metetra
.63 .456 .628 r
.68155 .38449 .68548 .40798 .69115 .39448 .68761 .37928 Metetra
.523 .419 .678 r
.68761 .37928 .69115 .39448 .69695 .38423 .69405 .3811 Metetra
0 .026 .538 r
.69405 .3811 .69695 .38423 .70306 .37973 .70079 .38778 Metetra
.704 .336 .348 r
.70079 .38778 .70306 .37973 .70952 .38118 .70763 .39546 Metetra
.617 .3 .412 r
.70763 .39546 .70952 .38118 .71623 .38652 .71434 .40011 Metetra
.502 .196 .381 r
.71434 .40011 .71623 .38652 .72303 .39239 .72075 .3991 Metetra
.02 0 .057 r
.72075 .3991 .72303 .39239 .72969 .39546 .72681 .39211 Metetra
.916 .803 .721 r
.72681 .39211 .72969 .39546 .73606 .39369 .73259 .38102 Metetra
.774 .594 .655 r
.73259 .38102 .73606 .39369 .74212 .38699 .73829 .3689 Metetra
.709 .525 .638 r
.73829 .3689 .74212 .38699 .74795 .37705 .74409 .35872 Metetra
.662 .494 .646 r
.74409 .35872 .74795 .37705 .75372 .36644 .75014 .35237 Metetra
.614 .487 .683 r
.75014 .35237 .75372 .36644 .75959 .35758 .75649 .35017 Metetra
.514 .522 .802 r
.75649 .35017 .75959 .35758 .76569 .35196 .76309 .35108 Metetra
0 .372 .678 r
.76309 .35108 .76569 .35196 .77206 .34975 .76982 .35329 Metetra
.521 .047 .07 r
.76982 .35329 .77206 .34975 .77865 .35006 .77654 .35493 Metetra
.441 .012 .127 r
.77654 .35493 .77865 .35006 .78534 .35139 .78313 .35474 Metetra
.165 0 0 r
.78313 .35474 .78534 .35139 .79202 .35226 .78956 .35232 Metetra
.676 .977 .865 r
.78956 .35232 .79202 .35226 .79861 .35166 .79586 .3481 Metetra
.805 .803 .85 r
.79586 .3481 .79861 .35166 .80506 .34931 .80208 .34299 Metetra
.748 .674 .779 r
.80208 .34299 .80506 .34931 .8114 .34555 .80831 .33799 Metetra
.707 .624 .763 r
.80831 .33799 .8114 .34555 .81768 .3411 .81462 .33381 Metetra
.676 .616 .78 r
.81462 .33381 .81768 .3411 .82397 .33672 .82105 .33078 Metetra
.648 .641 .83 r
.82105 .33078 .82397 .33672 .83033 .33298 .82759 .3288 Metetra
.612 .704 .91 r
.82759 .3288 .83033 .33298 .83679 .33012 .83421 .32751 Metetra
.552 .784 .985 r
.83421 .32751 .83679 .33012 .84334 .32807 .84087 .32646 Metetra
.49 .834 .997 r
.84087 .32646 .84334 .32807 .84996 .32656 .84754 .32528 Metetra
.501 .863 .987 r
.84754 .32528 .84996 .32656 .85662 .32526 .85419 .32373 Metetra
.577 .882 .992 r
.85419 .32373 .85662 .32526 .86329 .32386 .86082 .32176 Metetra
.647 .867 .982 r
.86082 .32176 .86329 .32386 .86994 .32219 .86742 .31945 Metetra
.679 .83 .956 r
.86742 .31945 .86994 .32219 .87659 .32021 .87402 .31694 Metetra
.686 .796 .933 r
.87402 .31694 .87659 .32021 .88321 .31796 .88062 .31438 Metetra
.682 .774 .921 r
.88062 .31438 .88321 .31796 .88984 .31556 .88725 .3119 Metetra
.644 .791 .952 r
.29009 .50287 .29364 .50531 .29903 .50359 .29548 .50127 Metetra
.643 .8 .958 r
.29548 .50127 .29903 .50359 .30444 .50173 .30089 .49967 Metetra
.646 .82 .966 r
.30089 .49967 .30444 .50173 .30988 .4997 .30631 .49796 Metetra
.656 .846 .973 r
.30631 .49796 .30988 .4997 .31533 .49752 .31175 .49608 Metetra
.67 .871 .975 r
.31175 .49608 .31533 .49752 .3208 .49528 .31722 .49395 Metetra
.687 .881 .97 r
.31722 .49395 .3208 .49528 .32627 .49318 .32272 .49161 Metetra
.699 .866 .961 r
.32272 .49161 .32627 .49318 .33173 .49143 .32822 .4892 Metetra
.692 .817 .942 r
.32822 .4892 .33173 .49143 .33716 .49021 .33373 .48697 Metetra
.661 .744 .912 r
.33373 .48697 .33716 .49021 .34259 .48952 .33921 .48522 Metetra
.614 .67 .881 r
.33921 .48522 .34259 .48952 .34801 .48916 .34467 .48416 Metetra
.567 .619 .864 r
.34467 .48416 .34801 .48916 .35345 .48867 .35011 .48382 Metetra
.532 .611 .877 r
.35011 .48382 .35345 .48867 .35894 .48749 .35554 .4839 Metetra
.517 .675 .936 r
.35554 .4839 .35894 .48749 .3645 .48514 .361 .4838 Metetra
.505 .836 .999 r
.361 .4838 .3645 .48514 .37013 .48153 .36652 .48278 Metetra
.384 .837 .743 r
.36652 .48278 .37013 .48153 .37581 .47711 .37212 .48023 Metetra
.37212 .48023 .37581 .47711 .38147 .47289 .37781 .47607 Metetra
.497 .835 .55 r
.37781 .47607 .38147 .47289 .38708 .47014 .38354 .47091 Metetra
.797 .995 .869 r
.38354 .47091 .38708 .47014 .3926 .46995 .38926 .46607 Metetra
.718 .727 .858 r
.38926 .46607 .3926 .46995 .39802 .47265 .3949 .46316 Metetra
.552 .491 .741 r
.3949 .46316 .39802 .47265 .40339 .47745 .40043 .46346 Metetra
.443 .368 .678 r
.40043 .46346 .40339 .47745 .40878 .48253 .40585 .46726 Metetra
.362 .303 .656 r
.40585 .46726 .40878 .48253 .41428 .48553 .41122 .4735 Metetra
.28 .28 .681 r
.41122 .4735 .41428 .48553 .41993 .48453 .41662 .47985 Metetra
.068 .361 .831 r
.41662 .47985 .41993 .48453 .42573 .479 .42215 .48344 Metetra
.318 0 .035 r
.42215 .48344 .42573 .479 .43163 .47031 .42786 .48205 Metetra
.223 0 .244 r
.42786 .48205 .43163 .47031 .43751 .46142 .43373 .47525 Metetra
.097 0 .221 r
.43373 .47525 .43751 .46142 .44331 .45579 .43968 .46488 Metetra
.43968 .46488 .44331 .45579 .44896 .45599 .44562 .45455 Metetra
.872 .872 .834 r
.44562 .45455 .44896 .45599 .4545 .46253 .45145 .44823 Metetra
.554 .441 .68 r
.45145 .44823 .4545 .46253 .46 .47338 .45714 .44865 Metetra
.431 .309 .612 r
.45714 .44865 .46 .47338 .46555 .48452 .46272 .45603 Metetra
.367 .253 .59 r
.46272 .45603 .46555 .48452 .47122 .49136 .46826 .46772 Metetra
.326 .237 .6 r
.46826 .46772 .47122 .49136 .47705 .49067 .47388 .47903 Metetra
.304 .305 .696 r
.47388 .47903 .47705 .49067 .48299 .48202 .47962 .48499 Metetra
.024 0 0 r
.47962 .48499 .48299 .48202 .48898 .46812 .48551 .48248 Metetra
.118 0 .244 r
.48551 .48248 .48898 .46812 .49495 .45361 .49149 .47171 Metetra
.032 0 .247 r
.49149 .47171 .49495 .45361 .50085 .4432 .49749 .45611 Metetra
0 0 .06 r
.49749 .45611 .50085 .4432 .5067 .43985 .50345 .4408 Metetra
.958 .932 .722 r
.50345 .4408 .5067 .43985 .51252 .44377 .50935 .43033 Metetra
.643 .506 .681 r
.50935 .43033 .51252 .44377 .51837 .45242 .51522 .42693 Metetra
.52 .372 .62 r
.51522 .42693 .51837 .45242 .52427 .46154 .52108 .42975 Metetra
.49 .338 .602 r
.52108 .42975 .52427 .46154 .53022 .46673 .52698 .43552 Metetra
.506 .351 .605 r
.52698 .43552 .53022 .46673 .53618 .4652 .53291 .44001 Metetra
.562 .403 .624 r
.53291 .44001 .53618 .4652 .54212 .45676 .53886 .44004 Metetra
.656 .496 .656 r
.53886 .44004 .54212 .45676 .54801 .44378 .5448 .43484 Metetra
.772 .625 .697 r
.5448 .43484 .54801 .44378 .55387 .43018 .55072 .4262 Metetra
.862 .759 .748 r
.55072 .4262 .55387 .43018 .55974 .41993 .55661 .41738 Metetra
.847 .829 .829 r
.55661 .41738 .55974 .41993 .56567 .41571 .56253 .41133 Metetra
.666 .7 .872 r
.56253 .41133 .56567 .41571 .5717 .41806 .5685 .40929 Metetra
.519 .489 .763 r
.5685 .40929 .5717 .41806 .57783 .42529 .57453 .41028 Metetra
.528 .422 .677 r
.57453 .41028 .57783 .42529 .58404 .434 .58059 .41177 Metetra
.573 .419 .634 r
.58059 .41177 .58404 .434 .59025 .44018 .58664 .41114 Metetra
.605 .427 .614 r
.58664 .41114 .59025 .44018 .59638 .4407 .59264 .40717 Metetra
.619 .43 .604 r
.59264 .40717 .59638 .4407 .60238 .43455 .59859 .40088 Metetra
.614 .426 .604 r
.59859 .40088 .60238 .43455 .60824 .42339 .60454 .39514 Metetra
.585 .413 .616 r
.60454 .39514 .60824 .42339 .61405 .41094 .6106 .39316 Metetra
.483 .376 .656 r
.6106 .39316 .61405 .41094 .61992 .40157 .61684 .39688 Metetra
0 0 .465 r
.61684 .39688 .61992 .40157 .62598 .39862 .62326 .40575 Metetra
.763 .397 .362 r
.62326 .40575 .62598 .39862 .63229 .40309 .62981 .41666 Metetra
.677 .355 .423 r
.62981 .41666 .63229 .40309 .63884 .4131 .63633 .42507 Metetra
.569 .244 .379 r
.63633 .42507 .63884 .4131 .6455 .4245 .64268 .42699 Metetra
.569 .869 .563 r
.64268 .42699 .6455 .4245 .65208 .43231 .64874 .42086 Metetra
.788 .611 .66 r
.64874 .42086 .65208 .43231 .65842 .43278 .65455 .40844 Metetra
.712 .51 .615 r
.65455 .40844 .65842 .43278 .66442 .42501 .66025 .39407 Metetra
.664 .465 .606 r
.66025 .39407 .66442 .42501 .67015 .41132 .66606 .38274 Metetra
.613 .433 .615 r
.66606 .38274 .67015 .41132 .67579 .39622 .67214 .37806 Metetra
.506 .391 .656 r
.67214 .37806 .67579 .39622 .68155 .38449 .67859 .38092 Metetra
.556 .088 0 r
.67859 .38092 .68155 .38449 .68761 .37928 .68534 .3892 Metetra
.716 .367 .384 r
.68534 .3892 .68761 .37928 .69405 .3811 .69222 .39875 Metetra
.629 .326 .438 r
.69222 .39875 .69405 .3811 .70079 .38778 .69897 .40498 Metetra
.528 .237 .417 r
.69897 .40498 .70079 .38778 .70763 .39546 .70541 .40472 Metetra
.163 0 .198 r
.70541 .40472 .70763 .39546 .71434 .40011 .71147 .39743 Metetra
.938 .821 .703 r
.71147 .39743 .71434 .40011 .72075 .3991 .71721 .38513 Metetra
.777 .587 .643 r
.71721 .38513 .72075 .3991 .72681 .39211 .72285 .37142 Metetra
.707 .515 .627 r
.72285 .37142 .72681 .39211 .73259 .38102 .72858 .35986 Metetra
.659 .481 .633 r
.72858 .35986 .73259 .38102 .73829 .3689 .73459 .35276 Metetra
.606 .468 .667 r
.73459 .35276 .73829 .3689 .74409 .35872 .74093 .35064 Metetra
.484 .488 .786 r
.74093 .35064 .74409 .35872 .75014 .35237 .74755 .35228 Metetra
.473 0 0 r
.74755 .35228 .75014 .35237 .75649 .35017 .75432 .35553 Metetra
.582 .163 .211 r
.75432 .35553 .75649 .35017 .76309 .35108 .76107 .35809 Metetra
.5 .118 .247 r
.76107 .35809 .76309 .35108 .76982 .35329 .76768 .35837 Metetra
.286 0 .076 r
.76768 .35837 .76982 .35329 .77654 .35493 .77409 .35586 Metetra
.609 .939 .742 r
.77409 .35586 .77654 .35493 .78313 .35474 .78034 .35107 Metetra
.827 .801 .827 r
.78034 .35107 .78313 .35474 .78956 .35232 .78649 .34516 Metetra
.753 .655 .753 r
.78649 .34516 .78956 .35232 .79586 .3481 .79266 .33939 Metetra
.706 .602 .738 r
.79266 .33939 .79586 .3481 .80208 .34299 .79892 .33469 Metetra
.672 .591 .757 r
.79892 .33469 .80208 .34299 .80831 .33799 .80531 .33145 Metetra
.64 .618 .812 r
.80531 .33145 .80831 .33799 .81462 .33381 .81184 .32956 Metetra
.593 .691 .911 r
.81184 .32956 .81462 .33381 .82105 .33078 .81847 .32855 Metetra
.489 .785 .997 r
.81847 .32855 .82105 .33078 .82759 .3288 .82514 .32784 Metetra
.359 .805 .952 r
.82514 .32784 .82759 .3288 .83421 .32751 .83181 .32692 Metetra
.373 .83 .92 r
.83181 .32692 .83421 .32751 .84087 .32646 .83846 .32551 Metetra
.514 .89 .968 r
.83846 .32551 .84087 .32646 .84754 .32528 .84507 .32355 Metetra
.639 .891 .985 r
.84507 .32355 .84754 .32528 .85419 .32373 .85165 .32114 Metetra
.688 .844 .958 r
.85165 .32114 .85419 .32373 .86082 .32176 .85821 .31849 Metetra
.695 .798 .929 r
.85821 .31849 .86082 .32176 .86742 .31945 .86479 .31579 Metetra
.688 .772 .915 r
.86479 .31579 .86742 .31945 .87402 .31694 .87139 .3132 Metetra
.678 .763 .915 r
.87139 .3132 .87402 .31694 .88062 .31438 .87802 .31079 Metetra
.666 .768 .926 r
.87802 .31079 .88062 .31438 .88725 .3119 .88469 .30856 Metetra
.651 .799 .954 r
.28652 .50051 .29009 .50287 .29548 .50127 .29193 .49883 Metetra
.643 .791 .953 r
.29193 .49883 .29548 .50127 .30089 .49967 .29734 .49723 Metetra
.637 .791 .956 r
.29734 .49723 .30089 .49967 .30631 .49796 .30276 .4957 Metetra
.634 .803 .964 r
.30276 .4957 .30631 .49796 .31175 .49608 .30819 .49416 Metetra
.637 .83 .975 r
.30819 .49416 .31175 .49608 .31722 .49395 .31364 .49248 Metetra
.648 .866 .982 r
.31364 .49248 .31722 .49395 .32272 .49161 .31911 .49056 Metetra
.665 .899 .979 r
.31911 .49056 .32272 .49161 .32822 .4892 .32462 .48831 Metetra
.688 .914 .972 r
.32462 .48831 .32822 .4892 .33373 .48697 .33015 .48577 Metetra
.708 .895 .964 r
.33015 .48577 .33373 .48697 .33921 .48522 .3357 .48313 Metetra
.702 .832 .944 r
.3357 .48313 .33921 .48522 .34467 .48416 .34124 .48074 Metetra
.66 .735 .905 r
.34124 .48074 .34467 .48416 .35011 .48382 .34676 .47899 Metetra
.599 .641 .863 r
.34676 .47899 .35011 .48382 .35554 .4839 .35224 .47816 Metetra
.541 .578 .841 r
.35224 .47816 .35554 .4839 .361 .4838 .35769 .47828 Metetra
.497 .565 .854 r
.35769 .47828 .361 .4838 .36652 .48278 .36313 .47892 Metetra
.471 .639 .929 r
.36313 .47892 .36652 .48278 .37212 .48023 .3686 .47931 Metetra
.411 .821 .976 r
.3686 .47931 .37212 .48023 .37781 .47607 .37415 .47847 Metetra
.37415 .47847 .37781 .47607 .38354 .47091 .3798 .47567 Metetra
.3798 .47567 .38354 .47091 .38926 .46607 .38554 .47082 Metetra
.38554 .47082 .38926 .46607 .3949 .46316 .39133 .46478 Metetra
.785 .997 .797 r
.39133 .46478 .3949 .46316 .40043 .46346 .3971 .45921 Metetra
.72 .712 .842 r
.3971 .45921 .40043 .46346 .40585 .46726 .40278 .45612 Metetra
.533 .456 .715 r
.40278 .45612 .40585 .46726 .41122 .4735 .40832 .45702 Metetra
.42 .334 .653 r
.40832 .45702 .41122 .4735 .41662 .47985 .41374 .46218 Metetra
.333 .267 .631 r
.41374 .46218 .41662 .47985 .42215 .48344 .41911 .47017 Metetra
.226 .23 .653 r
.41911 .47017 .42215 .48344 .42786 .48205 .42452 .4781 Metetra
0 .218 .728 r
.42452 .4781 .42786 .48205 .43373 .47525 .43008 .4825 Metetra
.399 .029 .216 r
.43008 .4825 .43373 .47525 .43968 .46488 .43584 .48081 Metetra
.278 .013 .32 r
.43584 .48081 .43968 .46488 .44562 .45455 .44177 .47269 Metetra
.163 0 .294 r
.44177 .47269 .44562 .45455 .45145 .44823 .44779 .46047 Metetra
0 0 .106 r
.44779 .46047 .45145 .44823 .45714 .44865 .45378 .44848 Metetra
.907 .933 .818 r
.45378 .44848 .45714 .44865 .46272 .45603 .45965 .44132 Metetra
.546 .433 .676 r
.45965 .44132 .46272 .45603 .46826 .46772 .46537 .44205 Metetra
.406 .288 .605 r
.46537 .44205 .46826 .46772 .47388 .47903 .47098 .45087 Metetra
.313 .215 .581 r
.47098 .45087 .47388 .47903 .47962 .48499 .47656 .46482 Metetra
.174 .144 .582 r
.47656 .46482 .47962 .48499 .48551 .48248 .48222 .47865 Metetra
.67 .196 0 r
.48222 .47865 .48551 .48248 .49149 .47171 .488 .4868 Metetra
.501 .204 .394 r
.488 .4868 .49149 .47171 .49749 .45611 .49392 .48565 Metetra
.386 .151 .43 r
.49392 .48565 .49749 .45611 .50345 .4408 .49993 .47504 Metetra
.314 .1 .421 r
.49993 .47504 .50345 .4408 .50935 .43033 .50596 .45831 Metetra
.221 .015 .374 r
.50596 .45831 .50935 .43033 .51522 .42693 .51194 .44075 Metetra
0 0 .173 r
.51194 .44075 .51522 .42693 .52108 .42975 .51788 .4275 Metetra
.843 .844 .845 r
.51788 .4275 .52108 .42975 .52698 .43552 .52378 .42183 Metetra
.493 .408 .688 r
.52378 .42183 .52698 .43552 .53291 .44001 .52969 .42427 Metetra
.292 .256 .645 r
.52969 .42427 .53291 .44001 .53886 .44004 .53566 .43285 Metetra
0 0 .451 r
.53566 .43285 .53886 .44004 .5448 .43484 .54168 .4439 Metetra
.726 .381 .395 r
.54168 .4439 .5448 .43484 .55072 .4262 .54776 .45333 Metetra
.592 .32 .474 r
.54776 .45333 .55072 .4262 .55661 .41738 .55385 .45778 Metetra
.526 .28 .486 r
.55385 .45778 .55661 .41738 .56253 .41133 .5599 .45547 Metetra
.47 .238 .48 r
.5599 .45547 .56253 .41133 .5685 .40929 .56588 .44659 Metetra
.395 .171 .453 r
.56588 .44659 .5685 .40929 .57453 .41028 .57179 .43313 Metetra
.225 .009 .361 r
.57179 .43313 .57453 .41028 .58059 .41177 .57764 .41839 Metetra
.57764 .41839 .58059 .41177 .58664 .41114 .5835 .40613 Metetra
.803 .72 .773 r
.5835 .40613 .58664 .41114 .59264 .40717 .58946 .39969 Metetra
.49 .503 .798 r
.58946 .39969 .59264 .40717 .59859 .40088 .59558 .40097 Metetra
.81 .334 .08 r
.59558 .40097 .59859 .40088 .60454 .39514 .6019 .40973 Metetra
.727 .41 .442 r
.6019 .40973 .60454 .39514 .6106 .39316 .6084 .4233 Metetra
.662 .384 .488 r
.6084 .4233 .6106 .39316 .61684 .39688 .61498 .437 Metetra
.609 .348 .497 r
.61498 .437 .61684 .39688 .62326 .40575 .62148 .44559 Metetra
.542 .293 .488 r
.62148 .44559 .62326 .40575 .62981 .41666 .62776 .4452 Metetra
.4 .164 .437 r
.62776 .4452 .62981 .41666 .63633 .42507 .63372 .43507 Metetra
.63372 .43507 .63633 .42507 .64268 .42699 .63943 .41807 Metetra
.866 .67 .636 r
.63943 .41807 .64268 .42699 .64874 .42086 .64504 .39961 Metetra
.726 .527 .621 r
.64504 .39961 .64874 .42086 .65455 .40844 .65077 .38547 Metetra
.638 .462 .629 r
.65077 .38547 .65455 .40844 .66025 .39407 .6568 .37968 Metetra
.473 .392 .684 r
.6568 .37968 .66025 .39407 .66606 .38274 .66324 .38307 Metetra
.823 .354 .094 r
.66324 .38307 .66606 .38274 .67214 .37806 .67001 .3931 Metetra
.706 .386 .433 r
.67001 .3931 .67214 .37806 .67859 .38092 .67692 .40485 Metetra
.631 .344 .465 r
.67692 .40485 .67859 .38092 .68534 .3892 .68371 .41284 Metetra
.543 .27 .451 r
.68371 .41284 .68534 .3892 .69222 .39875 .69017 .41321 Metetra
.295 .03 .331 r
.69017 .41321 .69222 .39875 .69897 .40498 .69621 .40516 Metetra
.984 .894 .647 r
.69621 .40516 .69897 .40498 .70541 .40472 .7019 .39102 Metetra
.799 .601 .635 r
.7019 .39102 .70541 .40472 .71147 .39743 .70745 .37502 Metetra
.715 .516 .619 r
.70745 .37502 .71147 .39743 .71721 .38513 .71311 .36149 Metetra
.661 .476 .624 r
.71311 .36149 .71721 .38513 .72285 .37142 .71906 .35328 Metetra
.602 .455 .654 r
.71906 .35328 .72285 .37142 .72858 .35986 .72537 .35109 Metetra
.452 .454 .77 r
.72537 .35109 .72858 .35986 .73459 .35276 .73201 .35354 Metetra
.627 .076 0 r
.73201 .35354 .73459 .35276 .74093 .35064 .73881 .35801 Metetra
.617 .235 .296 r
.73881 .35801 .74093 .35064 .74755 .35228 .7456 .3617 Metetra
.535 .186 .322 r
.7456 .3617 .74755 .35228 .75432 .35553 .75223 .36258 Metetra
.358 0 .199 r
.75223 .36258 .75432 .35553 .76107 .35809 .75864 .35999 Metetra
.514 .852 .577 r
.75864 .35999 .76107 .35809 .76768 .35837 .76483 .35453 Metetra
.846 .794 .801 r
.76483 .35453 .76768 .35837 .77409 .35586 .77092 .34766 Metetra
.756 .636 .728 r
.77092 .34766 .77409 .35586 .78034 .35107 .77702 .34096 Metetra
.704 .58 .713 r
.77702 .34096 .78034 .35107 .78649 .34516 .78322 .33561 Metetra
.667 .568 .733 r
.78322 .33561 .78649 .34516 .79266 .33939 .78958 .33213 Metetra
.631 .594 .793 r
.78958 .33213 .79266 .33939 .79892 .33469 .7961 .33036 Metetra
.569 .676 .912 r
.7961 .33036 .79892 .33469 .80531 .33145 .80273 .3297 Metetra
.382 .766 .99 r
.80273 .3297 .80531 .33145 .81184 .32956 .80942 .3294 Metetra
.143 .687 .797 r
.80942 .3294 .81184 .32956 .81847 .32855 .8161 .32881 Metetra
.169 .706 .741 r
.8161 .32881 .81847 .32855 .82514 .32784 .82274 .32757 Metetra
.407 .857 .889 r
.82274 .32757 .82514 .32784 .83181 .32692 .82934 .3256 Metetra
.626 .914 .98 r
.82934 .3256 .83181 .32692 .83846 .32551 .83589 .32305 Metetra
.7 .857 .957 r
.83589 .32305 .83846 .32551 .84507 .32355 .84242 .32021 Metetra
.706 .798 .921 r
.84242 .32021 .84507 .32355 .85165 .32114 .84896 .31733 Metetra
.695 .765 .905 r
.84896 .31733 .85165 .32114 .85821 .31849 .85554 .31461 Metetra
.681 .756 .908 r
.85554 .31461 .85821 .31849 .86479 .31579 .86215 .31214 Metetra
.666 .764 .924 r
.86215 .31214 .86479 .31579 .87139 .3132 .8688 .30991 Metetra
.652 .783 .944 r
.8688 .30991 .87139 .3132 .87802 .31079 .87549 .30786 Metetra
.639 .804 .962 r
.87549 .30786 .87802 .31079 .88469 .30856 .8822 .30589 Metetra
.658 .827 .965 r
.28291 .49851 .28652 .50051 .29193 .49883 .28834 .49666 Metetra
.655 .815 .96 r
.28834 .49666 .29193 .49883 .29734 .49723 .29377 .49489 Metetra
.647 .801 .956 r
.29377 .49489 .29734 .49723 .30276 .4957 .2992 .49322 Metetra
.637 .789 .955 r
.2992 .49322 .30276 .4957 .30819 .49416 .30464 .49168 Metetra
.628 .788 .959 r
.30464 .49168 .30819 .49416 .31364 .49248 .31008 .49023 Metetra
.623 .804 .969 r
.31008 .49023 .31364 .49248 .31911 .49056 .31554 .48878 Metetra
.625 .839 .982 r
.31554 .48878 .31911 .49056 .32462 .48831 .32101 .48715 Metetra
.634 .887 .987 r
.32101 .48715 .32462 .48831 .33015 .48577 .32652 .48519 Metetra
.651 .926 .974 r
.32652 .48519 .33015 .48577 .3357 .48313 .33207 .48279 Metetra
.681 .945 .961 r
.33207 .48279 .3357 .48313 .34124 .48074 .33765 .48 Metetra
.716 .928 .961 r
.33765 .48 .34124 .48074 .34676 .47899 .34324 .47708 Metetra
.714 .847 .946 r
.34324 .47708 .34676 .47899 .35224 .47816 .34882 .47449 Metetra
.658 .722 .896 r
.34882 .47449 .35224 .47816 .35769 .47828 .35437 .47275 Metetra
.582 .606 .842 r
.35437 .47275 .35769 .47828 .36313 .47892 .35987 .47221 Metetra
.513 .531 .812 r
.35987 .47221 .36313 .47892 .3686 .47931 .36533 .47289 Metetra
.459 .512 .825 r
.36533 .47289 .3686 .47931 .37415 .47847 .37077 .47423 Metetra
.418 .591 .915 r
.37077 .47423 .37415 .47847 .3798 .47567 .37626 .47519 Metetra
.28 .77 .907 r
.37626 .47519 .3798 .47567 .38554 .47082 .38183 .47455 Metetra
.38183 .47455 .38554 .47082 .39133 .46478 .38753 .4714 Metetra
.38753 .4714 .39133 .46478 .3971 .45921 .39333 .46571 Metetra
.39333 .46571 .3971 .45921 .40278 .45612 .39919 .45862 Metetra
.756 .973 .705 r
.39919 .45862 .40278 .45612 .40832 .45702 .40501 .45226 Metetra
.717 .692 .825 r
.40501 .45226 .40832 .45702 .41374 .46218 .41072 .44905 Metetra
.511 .422 .691 r
.41072 .44905 .41374 .46218 .41911 .47017 .41628 .45075 Metetra
.399 .304 .631 r
.41628 .45075 .41911 .47017 .42452 .4781 .4217 .4575 Metetra
.315 .239 .609 r
.4217 .4575 .42452 .4781 .43008 .4825 .42706 .46737 Metetra
.211 .201 .629 r
.42706 .46737 .43008 .4825 .43584 .48081 .4325 .47671 Metetra
0 .192 .71 r
.4325 .47671 .43584 .48081 .44177 .47269 .43811 .48142 Metetra
.368 .024 .243 r
.43811 .48142 .44177 .47269 .44779 .46047 .44393 .47865 Metetra
.244 0 .326 r
.44393 .47865 .44779 .46047 .45378 .44848 .44994 .46842 Metetra
.122 0 .291 r
.44994 .46842 .45378 .44848 .45965 .44132 .45602 .45391 Metetra
0 0 .075 r
.45602 .45391 .45965 .44132 .46537 .44205 .46205 .44045 Metetra
.885 .86 .811 r
.46205 .44045 .46537 .44205 .47098 .45087 .46793 .43335 Metetra
.509 .392 .655 r
.46793 .43335 .47098 .45087 .47656 .46482 .47367 .43573 Metetra
.376 .259 .59 r
.47367 .43573 .47656 .46482 .48222 .47865 .4793 .44715 Metetra
.299 .198 .569 r
.4793 .44715 .48222 .47865 .488 .4868 .48494 .46338 Metetra
.229 .17 .58 r
.48494 .46338 .488 .4868 .49392 .48565 .49067 .47782 Metetra
.088 .243 .729 r
.49067 .47782 .49392 .48565 .49993 .47504 .49654 .484 Metetra
.207 0 .177 r
.49654 .484 .49993 .47504 .50596 .45831 .50253 .47853 Metetra
.1 0 .29 r
.50253 .47853 .50596 .45831 .51194 .44075 .50858 .46274 Metetra
0 0 .251 r
.50858 .46274 .51194 .44075 .51788 .4275 .5146 .44218 Metetra
0 0 .075 r
.5146 .44218 .51788 .4275 .52378 .42183 .52057 .42417 Metetra
.903 .974 .677 r
.52057 .42417 .52378 .42183 .52969 .42427 .52649 .41474 Metetra
.496 .461 .748 r
.52649 .41474 .52969 .42427 .53566 .43285 .53242 .41632 Metetra
.222 .202 .624 r
.53242 .41632 .53566 .43285 .54168 .4439 .53842 .42696 Metetra
.08 .101 .581 r
.53842 .42696 .54168 .4439 .54776 .45333 .5445 .44102 Metetra
.071 .141 .631 r
.5445 .44102 .54776 .45333 .55385 .45778 .55062 .45141 Metetra
.477 .532 .835 r
.55062 .45141 .55385 .45778 .5599 .45547 .55671 .45257 Metetra
.895 .803 .75 r
.55671 .45257 .5599 .45547 .56588 .44659 .5627 .44301 Metetra
.927 .76 .655 r
.5627 .44301 .56588 .44659 .57179 .43313 .56858 .42604 Metetra
.88 .693 .645 r
.56858 .42604 .57179 .43313 .57764 .41839 .5744 .40818 Metetra
.796 .624 .668 r
.5744 .40818 .57764 .41839 .5835 .40613 .58027 .39623 Metetra
.621 .531 .731 r
.58027 .39623 .5835 .40613 .58946 .39969 .58632 .39445 Metetra
0 0 .524 r
.58632 .39445 .58946 .39969 .59558 .40097 .59259 .40296 Metetra
.865 .466 .279 r
.59259 .40296 .59558 .40097 .6019 .40973 .59906 .41765 Metetra
.789 .435 .387 r
.59906 .41765 .6019 .40973 .6084 .4233 .60559 .43171 Metetra
.686 .325 .358 r
.60559 .43171 .6084 .4233 .61498 .437 .612 .43845 Metetra
.521 .895 .707 r
.612 .43845 .61498 .437 .62148 .44559 .61814 .43422 Metetra
.804 .62 .653 r
.61814 .43422 .62148 .44559 .62776 .4452 .62399 .42014 Metetra
.738 .527 .607 r
.62399 .42014 .62776 .4452 .63372 .43507 .62966 .40147 Metetra
.69 .48 .598 r
.62966 .40147 .63372 .43507 .63943 .41807 .63535 .38518 Metetra
.635 .442 .604 r
.63535 .38518 .63943 .41807 .64504 .39961 .6413 .3769 Metetra
.531 .389 .633 r
.6413 .3769 .64504 .39961 .65077 .38547 .64763 .37888 Metetra
0 0 .536 r
.64763 .37888 .65077 .38547 .6568 .37968 .65433 .38925 Metetra
.768 .418 .393 r
.65433 .38925 .6568 .37968 .66324 .38307 .66122 .40292 Metetra
.67 .369 .454 r
.66122 .40292 .66324 .38307 .67001 .3931 .66807 .41358 Metetra
.575 .288 .442 r
.66807 .41358 .67001 .3931 .67692 .40485 .6746 .41627 Metetra
.258 0 .272 r
.6746 .41627 .67692 .40485 .68371 .41284 .68071 .40935 Metetra
.932 .785 .675 r
.68071 .40935 .68371 .41284 .69017 .41321 .68644 .39494 Metetra
.769 .564 .62 r
.68644 .39494 .69017 .41321 .69621 .40516 .69198 .37773 Metetra
.702 .497 .607 r
.69198 .37773 .69621 .40516 .7019 .39102 .6976 .36277 Metetra
.654 .462 .612 r
.6976 .36277 .7019 .39102 .70745 .37502 .70352 .35365 Metetra
.596 .438 .638 r
.70352 .35365 .70745 .37502 .71311 .36149 .70981 .35142 Metetra
.431 .417 .743 r
.70981 .35142 .71311 .36149 .71906 .35328 .71646 .35471 Metetra
.704 .194 .018 r
.71646 .35471 .71906 .35328 .72537 .35109 .7233 .3605 Metetra
.639 .282 .349 r
.7233 .3605 .72537 .35109 .73201 .35354 .73013 .36545 Metetra
.558 .23 .368 r
.73013 .36545 .73201 .35354 .73881 .35801 .73678 .36706 Metetra
.402 .064 .273 r
.73678 .36706 .73881 .35801 .7456 .3617 .74317 .36444 Metetra
.74317 .36444 .7456 .3617 .75223 .36258 .74932 .35828 Metetra
.856 .774 .771 r
.74932 .35828 .75223 .36258 .75864 .35999 .75535 .35036 Metetra
.754 .613 .702 r
.75535 .35036 .75864 .35999 .76483 .35453 .76138 .34262 Metetra
.7 .558 .69 r
.76138 .34262 .76483 .35453 .77092 .34766 .76752 .33655 Metetra
.661 .543 .71 r
.76752 .33655 .77092 .34766 .77702 .34096 .77385 .33281 Metetra
.621 .567 .773 r
.77385 .33281 .77702 .34096 .78322 .33561 .78037 .33121 Metetra
.538 .657 .912 r
.78037 .33121 .78322 .33561 .78958 .33213 .78701 .33098 Metetra
.201 .694 .921 r
.78701 .33098 .78958 .33213 .7961 .33036 .79371 .33117 Metetra
.121 0 0 r
.79371 .33117 .7961 .33036 .80273 .3297 .8004 .33098 Metetra
.064 0 0 r
.8004 .33098 .80273 .3297 .80942 .3294 .80704 .32992 Metetra
.249 .756 .726 r
.80704 .32992 .80942 .3294 .8161 .32881 .81361 .32792 Metetra
.607 .931 .962 r
.81361 .32792 .8161 .32881 .82274 .32757 .82014 .32519 Metetra
.717 .868 .953 r
.82014 .32519 .82274 .32757 .82934 .3256 .82663 .3221 Metetra
.719 .792 .909 r
.82663 .3221 .82934 .3256 .83589 .32305 .83314 .31899 Metetra
.702 .753 .891 r
.83314 .31899 .83589 .32305 .84242 .32021 .83969 .31612 Metetra
.684 .745 .897 r
.83969 .31612 .84242 .32021 .84896 .31733 .84628 .31358 Metetra
.665 .758 .919 r
.84628 .31358 .84896 .31733 .85554 .31461 .85291 .31137 Metetra
.646 .784 .947 r
.85291 .31137 .85554 .31461 .86215 .31214 .85959 .30938 Metetra
.629 .812 .97 r
.85959 .30938 .86215 .31214 .8688 .30991 .8663 .30749 Metetra
.617 .834 .983 r
.8663 .30749 .8688 .30991 .87549 .30786 .87302 .3056 Metetra
.616 .846 .987 r
.87302 .3056 .87549 .30786 .8822 .30589 .87975 .30363 Metetra
.655 .85 .975 r
.27926 .49682 .28291 .49851 .28834 .49666 .2847 .49492 Metetra
.658 .847 .972 r
.2847 .49492 .28834 .49666 .29377 .49489 .29015 .49299 Metetra
.658 .837 .969 r
.29015 .49299 .29377 .49489 .2992 .49322 .29561 .4911 Metetra
.654 .82 .963 r
.29561 .4911 .2992 .49322 .30464 .49168 .30107 .48931 Metetra
.644 .799 .957 r
.30107 .48931 .30464 .49168 .31008 .49023 .30653 .48766 Metetra
.63 .783 .955 r
.30653 .48766 .31008 .49023 .31554 .48878 .31199 .4862 Metetra
.617 .779 .959 r
.31199 .4862 .31554 .48878 .32101 .48715 .31746 .48487 Metetra
.609 .799 .973 r
.31746 .48487 .32101 .48715 .32652 .48519 .32294 .48354 Metetra
.608 .846 .989 r
.32294 .48354 .32652 .48519 .33207 .48279 .32845 .48199 Metetra
.611 .905 .985 r
.32845 .48199 .33207 .48279 .33765 .48 .33399 .47999 Metetra
.62 .944 .946 r
.33399 .47999 .33765 .48 .34324 .47708 .33958 .4774 Metetra
.657 .964 .922 r
.33958 .4774 .34324 .47708 .34882 .47449 .3452 .4743 Metetra
.72 .959 .946 r
.3452 .4743 .34882 .47449 .35437 .47275 .35084 .47103 Metetra
.729 .864 .944 r
.35084 .47103 .35437 .47275 .35987 .47221 .35647 .46819 Metetra
.656 .703 .882 r
.35647 .46819 .35987 .47221 .36533 .47289 .36205 .46645 Metetra
.564 .567 .815 r
.36205 .46645 .36533 .47289 .37077 .47423 .36756 .46627 Metetra
.485 .482 .779 r
.36756 .46627 .37077 .47423 .37626 .47519 .37303 .46763 Metetra
.421 .456 .791 r
.37303 .46763 .37626 .47519 .38183 .47455 .37847 .46981 Metetra
.356 .532 .892 r
.37847 .46981 .38183 .47455 .38753 .4714 .38397 .47148 Metetra
.083 .643 .748 r
.38397 .47148 .38753 .4714 .39333 .46571 .38957 .4711 Metetra
.129 0 0 r
.38957 .4711 .39333 .46571 .39919 .45862 .39532 .4676 Metetra
.08 0 .106 r
.39532 .4676 .39919 .45862 .40501 .45226 .40118 .46098 Metetra
0 0 .007 r
.40118 .46098 .40501 .45226 .41072 .44905 .4071 .45272 Metetra
.691 .913 .576 r
.4071 .45272 .41072 .44905 .41628 .45075 .41298 .4454 Metetra
.718 .672 .804 r
.41298 .4454 .41628 .45075 .4217 .4575 .41873 .4419 Metetra
.503 .398 .667 r
.41873 .4419 .4217 .4575 .42706 .46737 .42431 .44417 Metetra
.398 .288 .612 r
.42431 .44417 .42706 .46737 .4325 .47671 .42974 .45221 Metetra
.322 .23 .593 r
.42974 .45221 .4325 .47671 .43811 .48142 .43513 .46366 Metetra
.228 .194 .61 r
.43513 .46366 .43811 .48142 .44393 .47865 .4406 .47427 Metetra
0 .156 .687 r
.4406 .47427 .44393 .47865 .44994 .46842 .44625 .47943 Metetra
.389 .07 .299 r
.44625 .47943 .44994 .46842 .45602 .45391 .45213 .47617 Metetra
.28 .042 .364 r
.45213 .47617 .45602 .45391 .46205 .44045 .45818 .46469 Metetra
.176 0 .336 r
.45818 .46469 .46205 .44045 .46793 .43335 .4643 .44861 Metetra
0 0 .151 r
.4643 .44861 .46793 .43335 .47367 .43573 .47036 .43354 Metetra
.895 .821 .766 r
.47036 .43354 .47367 .43573 .4793 .44715 .47629 .42476 Metetra
.555 .404 .632 r
.47629 .42476 .4793 .44715 .48494 .46338 .48209 .42514 Metetra
.461 .307 .585 r
.48209 .42514 .48494 .46338 .49067 .47782 .48781 .43396 Metetra
.425 .275 .572 r
.48781 .43396 .49067 .47782 .49654 .484 .49355 .4472 Metetra
.416 .276 .581 r
.49355 .4472 .49654 .484 .50253 .47853 .49936 .45905 Metetra
.446 .34 .641 r
.49936 .45905 .50253 .47853 .50858 .46274 .50527 .46433 Metetra
.467 .869 .702 r
.50527 .46433 .50858 .46274 .5146 .44218 .51126 .46063 Metetra
.219 0 .323 r
.51126 .46063 .5146 .44218 .52057 .42417 .51728 .44917 Metetra
.229 .013 .365 r
.51728 .44917 .52057 .42417 .52649 .41474 .52327 .43382 Metetra
.113 0 .29 r
.52327 .43382 .52649 .41474 .53242 .41632 .52923 .41907 Metetra
.923 .958 .638 r
.52923 .41907 .53242 .41632 .53842 .42696 .53517 .40813 Metetra
.658 .488 .643 r
.53517 .40813 .53842 .42696 .5445 .44102 .54111 .40203 Metetra
.577 .392 .595 r
.54111 .40203 .5445 .44102 .55062 .45141 .54707 .39993 Metetra
.555 .367 .581 r
.54707 .39993 .55062 .45141 .55671 .45257 .55307 .40026 Metetra
.546 .36 .58 r
.55307 .40026 .55671 .45257 .5627 .44301 .55911 .40187 Metetra
.534 .359 .59 r
.55911 .40187 .5627 .44301 .56858 .42604 .56518 .40455 Metetra
.485 .36 .635 r
.56518 .40455 .56858 .42604 .5744 .40818 .57131 .40873 Metetra
.719 .204 0 r
.57131 .40873 .5744 .40818 .58027 .39623 .57749 .4144 Metetra
.626 .327 .444 r
.57749 .4144 .58027 .39623 .58632 .39445 .58373 .42038 Metetra
.585 .31 .467 r
.58373 .42038 .58632 .39445 .59259 .40296 .58997 .42422 Metetra
.518 .242 .436 r
.58997 .42422 .59259 .40296 .59906 .41765 .59613 .42317 Metetra
.59613 .42317 .59906 .41765 .60559 .43171 .60216 .41584 Metetra
.747 .56 .641 r
.60216 .41584 .60559 .43171 .612 .43845 .60806 .40334 Metetra
.671 .465 .598 r
.60806 .40334 .612 .43845 .61814 .43422 .61388 .38937 Metetra
.629 .427 .589 r
.61388 .38937 .61814 .43422 .62399 .42014 .61977 .37884 Metetra
.582 .395 .593 r
.61977 .37884 .62399 .42014 .62966 .40147 .62589 .37584 Metetra
.469 .337 .619 r
.62589 .37584 .62966 .40147 .63535 .38518 .63231 .38182 Metetra
.819 .371 0 r
.63231 .38182 .63535 .38518 .6413 .3769 .63903 .39479 Metetra
.719 .409 .452 r
.63903 .39479 .6413 .3769 .64763 .37888 .64589 .4098 Metetra
.639 .362 .483 r
.64589 .4098 .64763 .37888 .65433 .38925 .65268 .42075 Metetra
.562 .299 .475 r
.65268 .42075 .65433 .38925 .66122 .40292 .65916 .42283 Metetra
.366 .112 .391 r
.65916 .42283 .66122 .40292 .66807 .41358 .66523 .41458 Metetra
.99 .887 .61 r
.66523 .41458 .66807 .41358 .6746 .41627 .67093 .39843 Metetra
.784 .575 .617 r
.67093 .39843 .6746 .41627 .68071 .40935 .67645 .37949 Metetra
.701 .492 .602 r
.67645 .37949 .68071 .40935 .68644 .39494 .68206 .36331 Metetra
.647 .452 .605 r
.68206 .36331 .68644 .39494 .69198 .37773 .68797 .35384 Metetra
.583 .422 .629 r
.68797 .35384 .69198 .37773 .6976 .36277 .69428 .35224 Metetra
.373 .373 .73 r
.69428 .35224 .6976 .36277 .70352 .35365 .70096 .3569 Metetra
.746 .299 .191 r
.70096 .3569 .70352 .35365 .70981 .35142 .70784 .36434 Metetra
.647 .316 .399 r
.70784 .36434 .70981 .35142 .71646 .35471 .7147 .37065 Metetra
.57 .264 .411 r
.7147 .37065 .71646 .35471 .7233 .3605 .72137 .37287 Metetra
.435 .127 .343 r
.72137 .37287 .7233 .3605 .73013 .36545 .72773 .36995 Metetra
.72773 .36995 .73013 .36545 .73678 .36706 .73383 .36274 Metetra
.876 .774 .745 r
.73383 .36274 .73678 .36706 .74317 .36444 .73978 .35341 Metetra
.757 .598 .681 r
.73978 .35341 .74317 .36444 .74932 .35828 .74573 .34436 Metetra
.697 .54 .67 r
.74573 .34436 .74932 .35828 .75535 .35036 .75182 .33743 Metetra
.655 .522 .689 r
.75182 .33743 .75535 .35036 .76138 .34262 .75812 .33341 Metetra
.608 .54 .752 r
.75812 .33341 .76138 .34262 .76752 .33655 .76463 .33204 Metetra
.496 .629 .911 r
.76463 .33204 .76752 .33655 .77385 .33281 .77129 .33237 Metetra
0 .524 .734 r
.77129 .33237 .77385 .33281 .78037 .33121 .77801 .33319 Metetra
.33 0 0 r
.77801 .33319 .78037 .33121 .78701 .33098 .78472 .33346 Metetra
.25 0 0 r
.78472 .33346 .78701 .33098 .79371 .33117 .79135 .33261 Metetra
.79135 .33261 .79371 .33117 .8004 .33098 .79791 .33055 Metetra
.583 .939 .924 r
.79791 .33055 .8004 .33098 .80704 .32992 .80439 .32758 Metetra
.738 .875 .944 r
.80439 .32758 .80704 .32992 .81361 .32792 .81085 .32416 Metetra
.731 .78 .891 r
.81085 .32416 .81361 .32792 .82014 .32519 .81732 .32076 Metetra
.708 .736 .873 r
.81732 .32076 .82014 .32519 .82663 .3221 .82383 .31769 Metetra
.686 .728 .883 r
.82383 .31769 .82663 .3221 .83314 .31899 .8304 .31508 Metetra
.664 .748 .912 r
.8304 .31508 .83314 .31899 .83969 .31612 .83703 .31289 Metetra
.64 .782 .95 r
.83703 .31289 .83969 .31612 .84628 .31358 .8437 .31099 Metetra
.614 .819 .979 r
.8437 .31099 .84628 .31358 .85291 .31137 .85039 .30921 Metetra
.596 .846 .992 r
.85039 .30921 .85291 .31137 .85959 .30938 .85711 .30741 Metetra
.595 .861 .993 r
.85711 .30741 .85959 .30938 .8663 .30749 .86383 .3055 Metetra
.61 .865 .991 r
.86383 .3055 .8663 .30749 .87302 .3056 .87055 .30346 Metetra
.629 .862 .986 r
.87055 .30346 .87302 .3056 .87975 .30363 .87727 .30128 Metetra
.644 .852 .979 r
.27559 .49517 .27926 .49682 .2847 .49492 .28103 .49334 Metetra
.648 .858 .98 r
.28103 .49334 .2847 .49492 .29015 .49299 .28649 .49145 Metetra
.653 .862 .979 r
.28649 .49145 .29015 .49299 .29561 .4911 .29196 .4895 Metetra
.658 .859 .976 r
.29196 .4895 .29561 .4911 .30107 .48931 .29744 .48752 Metetra
.659 .846 .972 r
.29744 .48752 .30107 .48931 .30653 .48766 .30293 .48557 Metetra
.654 .823 .965 r
.30293 .48557 .30653 .48766 .31199 .4862 .30843 .48375 Metetra
.64 .795 .956 r
.30843 .48375 .31199 .4862 .31746 .48487 .31392 .48214 Metetra
.622 .771 .952 r
.31392 .48214 .31746 .48487 .32294 .48354 .31941 .48078 Metetra
.604 .764 .956 r
.31941 .48078 .32294 .48354 .32845 .48199 .3249 .47961 Metetra
.592 .789 .974 r
.3249 .47961 .32845 .48199 .33399 .47999 .3304 .47845 Metetra
.586 .849 .994 r
.3304 .47845 .33399 .47999 .33958 .4774 .33594 .47699 Metetra
.576 .915 .969 r
.33594 .47699 .33958 .4774 .3452 .4743 .34151 .47495 Metetra
.564 .937 .881 r
.34151 .47495 .3452 .4743 .35084 .47103 .34715 .47213 Metetra
.608 .954 .841 r
.34715 .47213 .35084 .47103 .35647 .46819 .35282 .46863 Metetra
.717 .98 .909 r
.35282 .46863 .35647 .46819 .36205 .46645 .35851 .46492 Metetra
.747 .88 .94 r
.35851 .46492 .36205 .46645 .36756 .46627 .36418 .46178 Metetra
.651 .681 .865 r
.36418 .46178 .36756 .46627 .37303 .46763 .36979 .46007 Metetra
.541 .525 .786 r
.36979 .46007 .37303 .46763 .37847 .46981 .37532 .46039 Metetra
.452 .432 .746 r
.37532 .46039 .37847 .46981 .38397 .47148 .38078 .46265 Metetra
.374 .397 .756 r
.38078 .46265 .38397 .47148 .38957 .4711 .38623 .46592 Metetra
.268 .46 .863 r
.38623 .46592 .38957 .4711 .39532 .4676 .39173 .46848 Metetra
.152 0 0 r
.39173 .46848 .39532 .4676 .40118 .46098 .39736 .46839 Metetra
.216 0 .121 r
.39736 .46839 .40118 .46098 .4071 .45272 .40316 .46435 Metetra
.134 0 .194 r
.40316 .46435 .4071 .45272 .41298 .4454 .4091 .45647 Metetra
0 0 .098 r
.4091 .45647 .41298 .4454 .41873 .4419 .41509 .44665 Metetra
.645 .854 .468 r
.41509 .44665 .41873 .4419 .42431 .44417 .42103 .43821 Metetra
.711 .652 .789 r
.42103 .43821 .42431 .44417 .42974 .45221 .4268 .43466 Metetra
.472 .365 .651 r
.4268 .43466 .42974 .45221 .43513 .46366 .43238 .43834 Metetra
.347 .245 .595 r
.43238 .43834 .43513 .46366 .4406 .47427 .4378 .44918 Metetra
.227 .159 .568 r
.4378 .44918 .4406 .47427 .44625 .47943 .44317 .46416 Metetra
0 .021 .546 r
.44317 .46416 .44625 .47943 .45213 .47617 .44864 .47799 Metetra
.768 .325 .199 r
.44864 .47799 .45213 .47617 .45818 .46469 .45433 .48493 Metetra
.461 .189 .413 r
.45433 .48493 .45818 .46469 .4643 .44861 .46027 .48125 Metetra
.34 .115 .42 r
.46027 .48125 .4643 .44861 .47036 .43354 .4664 .46728 Metetra
.24 .037 .39 r
.4664 .46728 .47036 .43354 .47629 .42476 .47258 .44766 Metetra
.079 0 .292 r
.47258 .44766 .47629 .42476 .48209 .42514 .4787 .42964 Metetra
.713 .882 .488 r
.4787 .42964 .48209 .42514 .48781 .43396 .48466 .42029 Metetra
.451 .38 .686 r
.48466 .42029 .48781 .43396 .49355 .4472 .49047 .42381 Metetra
.171 .128 .564 r
.49047 .42381 .49355 .4472 .49936 .45905 .4962 .43991 Metetra
0 0 .388 r
.4962 .43991 .49936 .45905 .50527 .46433 .50196 .46358 Metetra
.926 .562 .314 r
.50196 .46358 .50527 .46433 .51126 .46063 .50783 .48649 Metetra
.673 .389 .483 r
.50783 .48649 .51126 .46063 .51728 .44917 .51383 .49984 Metetra
.532 .291 .495 r
.51383 .49984 .51728 .44917 .52327 .43382 .51992 .49796 Metetra
.438 .221 .485 r
.51992 .49796 .52327 .43382 .52923 .41907 .52603 .48087 Metetra
.354 .153 .463 r
.52603 .48087 .52923 .41907 .53517 .40813 .53207 .45436 Metetra
.26 .07 .423 r
.53207 .45436 .53517 .40813 .54111 .40203 .53803 .42758 Metetra
.167 0 .347 r
.53803 .42758 .54111 .40203 .54707 .39993 .54397 .40948 Metetra
.343 .014 .255 r
.54397 .40948 .54707 .39993 .55307 .40026 .54996 .40577 Metetra
.79 .416 .348 r
.54996 .40577 .55307 .40026 .55911 .40187 .55612 .41731 Metetra
.784 .471 .458 r
.55612 .41731 .55911 .40187 .56518 .40455 .56246 .43976 Metetra
.71 .431 .501 r
.56246 .43976 .56518 .40455 .57131 .40873 .56894 .46478 Metetra
.636 .379 .513 r
.56894 .46478 .57131 .40873 .57749 .4144 .57543 .48263 Metetra
.562 .322 .51 r
.57543 .48263 .57749 .4144 .58373 .42038 .58175 .48581 Metetra
.468 .246 .493 r
.58175 .48581 .58373 .42038 .58997 .42422 .58779 .47226 Metetra
.296 .102 .44 r
.58779 .47226 .58997 .42422 .59613 .42317 .59354 .44632 Metetra
0 0 .171 r
.59354 .44632 .59613 .42317 .60216 .41584 .59913 .41672 Metetra
.993 .822 .57 r
.59913 .41672 .60216 .41584 .60806 .40334 .60477 .39303 Metetra
.786 .619 .674 r
.60477 .39303 .60806 .40334 .61388 .38937 .61069 .38209 Metetra
.299 .397 .795 r
.61069 .38209 .61388 .38937 .61977 .37884 .617 .38599 Metetra
.81 .45 .375 r
.617 .38599 .61977 .37884 .62589 .37584 .62372 .40157 Metetra
.716 .423 .479 r
.62372 .40157 .62589 .37584 .63231 .38182 .63066 .42162 Metetra
.651 .381 .497 r
.63066 .42162 .63231 .38182 .63903 .39479 .63755 .43737 Metetra
.577 .321 .493 r
.63755 .43737 .63903 .39479 .64589 .4098 .64412 .44185 Metetra
.43 .192 .45 r
.64412 .44185 .64589 .4098 .65268 .42075 .6502 .43269 Metetra
.6502 .43269 .65268 .42075 .65916 .42283 .65583 .41282 Metetra
.882 .669 .609 r
.65583 .41282 .65916 .42283 .66523 .41458 .66123 .38881 Metetra
.748 .532 .601 r
.66123 .38881 .66523 .41458 .67093 .39843 .6667 .36788 Metetra
.675 .472 .604 r
.6667 .36788 .67093 .39843 .67645 .37949 .67249 .35519 Metetra
.597 .43 .626 r
.67249 .35519 .67645 .37949 .68206 .36331 .67873 .35245 Metetra
.34 .347 .721 r
.67873 .35245 .68206 .36331 .68797 .35384 .68539 .35785 Metetra
.774 .353 .25 r
.68539 .35785 .68797 .35384 .69428 .35224 .6923 .36717 Metetra
.666 .344 .42 r
.6923 .36717 .69428 .35224 .70096 .3569 .69922 .37552 Metetra
.587 .29 .432 r
.69922 .37552 .70096 .3569 .70784 .36434 .70593 .37907 Metetra
.458 .163 .375 r
.70593 .37907 .70784 .36434 .7147 .37065 .7123 .37631 Metetra
.7123 .37631 .7147 .37065 .72137 .37287 .71836 .36817 Metetra
.886 .76 .717 r
.71836 .36817 .72137 .37287 .72773 .36995 .72424 .35727 Metetra
.759 .585 .662 r
.72424 .35727 .72773 .36995 .73383 .36274 .73011 .34662 Metetra
.697 .527 .653 r
.73011 .34662 .73383 .36274 .73978 .35341 .73613 .33853 Metetra
.652 .505 .671 r
.73613 .33853 .73978 .35341 .74573 .34436 .74239 .33403 Metetra
.599 .517 .733 r
.74239 .33403 .74573 .34436 .75182 .33743 .74889 .33285 Metetra
.445 .599 .909 r
.74889 .33285 .75182 .33743 .75812 .33341 .75556 .33378 Metetra
.314 0 0 r
.75556 .33378 .75812 .33341 .76463 .33204 .76231 .33532 Metetra
.455 0 .002 r
.76231 .33532 .76463 .33204 .77129 .33237 .76903 .33616 Metetra
.366 0 .005 r
.76903 .33616 .77129 .33237 .77801 .33319 .77567 .33558 Metetra
.076 0 0 r
.77567 .33558 .77801 .33319 .78472 .33346 .7822 .33346 Metetra
.564 .937 .876 r
.7822 .33346 .78472 .33346 .79135 .33261 .78866 .33018 Metetra
.762 .873 .928 r
.78866 .33018 .79135 .33261 .79791 .33055 .79507 .32637 Metetra
.742 .76 .867 r
.79507 .32637 .79791 .33055 .80439 .32758 .8015 .32262 Metetra
.712 .712 .849 r
.8015 .32262 .80439 .32758 .81085 .32416 .80798 .31932 Metetra
.686 .708 .864 r
.80798 .31932 .81085 .32416 .81732 .32076 .81453 .31663 Metetra
.661 .734 .903 r
.81453 .31663 .81732 .32076 .82383 .31769 .82114 .31449 Metetra
.63 .78 .953 r
.82114 .31449 .82383 .31769 .8304 .31508 .8278 .3127 Metetra
.593 .826 .988 r
.8278 .3127 .8304 .31508 .83703 .31289 .8345 .31106 Metetra
.564 .856 .997 r
.8345 .31106 .83703 .31289 .8437 .31099 .8412 .30937 Metetra
.564 .872 .995 r
.8412 .30937 .8437 .31099 .85039 .30921 .84791 .30752 Metetra
.589 .879 .993 r
.84791 .30752 .85039 .30921 .85711 .30741 .85462 .30549 Metetra
.62 .875 .989 r
.85462 .30549 .85711 .30741 .86383 .3055 .86132 .3033 Metetra
.643 .862 .982 r
.86132 .3033 .86383 .3055 .87055 .30346 .86803 .301 Metetra
.655 .848 .974 r
.86803 .301 .87055 .30346 .87727 .30128 .87475 .29865 Metetra
.638 .843 .979 r
.27191 .49342 .27559 .49517 .28103 .49334 .27735 .49168 Metetra
.638 .85 .981 r
.27735 .49168 .28103 .49334 .28649 .49145 .28281 .4899 Metetra
.64 .859 .983 r
.28281 .4899 .28649 .49145 .29196 .4895 .28828 .48806 Metetra
.645 .869 .983 r
.28828 .48806 .29196 .4895 .29744 .48752 .29377 .48613 Metetra
.651 .874 .982 r
.29377 .48613 .29744 .48752 .30293 .48557 .29927 .48412 Metetra
.659 .871 .979 r
.29927 .48412 .30293 .48557 .30843 .48375 .3048 .48205 Metetra
.662 .855 .974 r
.3048 .48205 .30843 .48375 .31392 .48214 .31032 .48003 Metetra
.655 .824 .965 r
.31032 .48003 .31392 .48214 .31941 .48078 .31585 .47818 Metetra
.637 .785 .953 r
.31585 .47818 .31941 .48078 .3249 .47961 .32137 .47662 Metetra
.613 .752 .944 r
.32137 .47662 .3249 .47961 .3304 .47845 .32689 .47539 Metetra
.589 .741 .948 r
.32689 .47539 .3304 .47845 .33594 .47699 .3324 .47442 Metetra
.573 .77 .972 r
.3324 .47442 .33594 .47699 .34151 .47495 .33792 .47346 Metetra
.561 .847 .997 r
.33792 .47346 .34151 .47495 .34715 .47213 .34348 .47214 Metetra
.523 .911 .933 r
.34348 .47214 .34715 .47213 .35282 .46863 .3491 .47005 Metetra
.47 .884 .761 r
.3491 .47005 .35282 .46863 .35851 .46492 .35477 .46696 Metetra
.515 .891 .7 r
.35477 .46696 .35851 .46492 .36418 .46178 .3605 .46301 Metetra
.686 .98 .837 r
.3605 .46301 .36418 .46178 .36979 .46007 .36624 .45881 Metetra
.765 .9 .936 r
.36624 .45881 .36979 .46007 .37532 .46039 .37196 .45534 Metetra
.645 .656 .846 r
.37196 .45534 .37532 .46039 .38078 .46265 .3776 .45369 Metetra
.521 .484 .756 r
.3776 .45369 .38078 .46265 .38623 .46592 .38314 .45454 Metetra
.431 .389 .711 r
.38314 .45454 .38623 .46592 .39173 .46848 .38861 .45772 Metetra
.359 .352 .715 r
.38861 .45772 .39173 .46848 .39736 .46839 .39406 .46199 Metetra
.27 .407 .817 r
.39406 .46199 .39736 .46839 .40316 .46435 .39958 .46523 Metetra
.151 0 0 r
.39958 .46523 .40316 .46435 .4091 .45647 .40526 .46515 Metetra
.215 0 .162 r
.40526 .46515 .4091 .45647 .41509 .44665 .41112 .46032 Metetra
.142 0 .23 r
.41112 .46032 .41509 .44665 .42103 .43821 .41712 .45113 Metetra
0 0 .148 r
.41712 .45113 .42103 .43821 .4268 .43466 .42317 .44006 Metetra
.609 .814 .405 r
.42317 .44006 .4268 .43466 .43238 .43834 .42914 .43099 Metetra
.684 .606 .763 r
.42914 .43099 .43238 .43834 .4378 .44918 .43493 .42777 Metetra
.464 .342 .629 r
.43493 .42777 .4378 .44918 .44317 .46416 .44053 .43254 Metetra
.377 .253 .582 r
.44053 .43254 .44317 .46416 .44864 .47799 .44599 .44449 Metetra
.331 .216 .569 r
.44599 .44449 .44864 .47799 .45433 .48493 .45144 .45958 Metetra
.314 .223 .59 r
.45144 .45958 .45433 .48493 .46027 .48125 .45702 .47174 Metetra
.386 .395 .747 r
.45702 .47174 .46027 .48125 .4664 .46728 .46283 .4752 Metetra
.46283 .4752 .4664 .46728 .47258 .44766 .46886 .4673 Metetra
0 0 .235 r
.46886 .4673 .47258 .44766 .4787 .42964 .47503 .45011 Metetra
0 0 .198 r
.47503 .45011 .4787 .42964 .48466 .42029 .4812 .4298 Metetra
.4812 .4298 .48466 .42029 .49047 .42381 .48726 .41396 Metetra
.712 .582 .708 r
.48726 .41396 .49047 .42381 .4962 .43991 .49318 .40839 Metetra
.477 .328 .599 r
.49318 .40839 .4962 .43991 .50196 .46358 .49901 .41461 Metetra
.426 .271 .566 r
.49901 .41461 .50196 .46358 .50783 .48649 .50483 .42912 Metetra
.439 .276 .562 r
.50483 .42912 .50783 .48649 .51383 .49984 .51072 .44467 Metetra
.493 .318 .572 r
.51072 .44467 .51383 .49984 .51992 .49796 .5167 .45324 Metetra
.582 .391 .589 r
.5167 .45324 .51992 .49796 .52603 .48087 .52274 .44992 Metetra
.687 .483 .605 r
.52274 .44992 .52603 .48087 .53207 .45436 .52878 .43536 Metetra
.778 .569 .617 r
.52878 .43536 .53207 .45436 .53803 .42758 .53477 .41547 Metetra
.816 .621 .638 r
.53477 .41547 .53803 .42758 .54397 .40948 .54072 .39837 Metetra
.737 .584 .684 r
.54072 .39837 .54397 .40948 .54996 .40577 .54669 .39045 Metetra
.476 .384 .673 r
.54669 .39045 .54996 .40577 .55612 .41731 .55274 .39369 Metetra
.336 .247 .605 r
.55274 .39369 .55612 .41731 .56246 .43976 .55891 .40484 Metetra
.405 .272 .585 r
.55891 .40484 .56246 .43976 .56894 .46478 .56516 .41701 Metetra
.509 .335 .581 r
.56516 .41701 .56894 .46478 .57543 .48263 .57138 .42287 Metetra
.581 .382 .577 r
.57138 .42287 .57543 .48263 .58175 .48581 .57748 .41835 Metetra
.619 .408 .574 r
.57748 .41835 .58175 .48581 .58779 .47226 .58341 .40475 Metetra
.631 .418 .574 r
.58341 .40475 .58779 .47226 .59354 .44632 .58926 .38801 Metetra
.622 .413 .578 r
.58926 .38801 .59354 .44632 .59913 .41672 .59515 .37562 Metetra
.578 .391 .592 r
.59515 .37562 .59913 .41672 .60477 .39303 .60126 .37307 Metetra
.373 .29 .632 r
.60126 .37307 .60477 .39303 .61069 .38209 .60766 .38145 Metetra
.892 .472 .18 r
.60766 .38145 .61069 .38209 .617 .38599 .61431 .39702 Metetra
.773 .435 .414 r
.61431 .39702 .617 .38599 .62372 .40157 .62105 .41277 Metetra
.693 .353 .395 r
.62105 .41277 .62372 .40157 .63066 .42162 .62765 .42135 Metetra
.596 .942 .932 r
.62765 .42135 .63066 .42162 .63755 .43737 .63391 .41847 Metetra
.737 .542 .629 r
.63391 .41847 .63755 .43737 .64412 .44185 .6398 .40473 Metetra
.697 .482 .591 r
.6398 .40473 .64412 .44185 .6502 .43269 .64544 .38516 Metetra
.667 .452 .583 r
.64544 .38516 .6502 .43269 .65583 .41282 .65107 .36661 Metetra
.634 .428 .586 r
.65107 .36661 .65583 .41282 .66123 .38881 .65692 .35483 Metetra
.581 .401 .603 r
.65692 .35483 .66123 .38881 .6667 .36788 .66316 .35244 Metetra
.399 .336 .67 r
.66316 .35244 .6667 .36788 .67249 .35519 .66979 .35836 Metetra
.799 .372 .233 r
.66979 .35836 .67249 .35519 .67873 .35245 .67668 .36862 Metetra
.673 .357 .43 r
.67668 .36862 .67873 .35245 .68539 .35785 .68359 .37813 Metetra
.597 .304 .441 r
.68359 .37813 .68539 .35785 .6923 .36717 .6903 .38261 Metetra
.469 .175 .383 r
.6903 .38261 .6923 .36717 .69922 .37552 .69668 .38015 Metetra
.69668 .38015 .69922 .37552 .70593 .37907 .70274 .3716 Metetra
.842 .685 .687 r
.70274 .3716 .70593 .37907 .7123 .37631 .70859 .3598 Metetra
.735 .549 .64 r
.70859 .3598 .7123 .37631 .71836 .36817 .71443 .34815 Metetra
.682 .5 .634 r
.71443 .34815 .71836 .36817 .72424 .35727 .72043 .33938 Metetra
.64 .481 .652 r
.72043 .33938 .72424 .35727 .73011 .34662 .72667 .33473 Metetra
.585 .489 .712 r
.72667 .33473 .73011 .34662 .73613 .33853 .73317 .33392 Metetra
.377 .559 .905 r
.73317 .33392 .73613 .33853 .74239 .33403 .73986 .33556 Metetra
.497 0 0 r
.73986 .33556 .74239 .33403 .74889 .33285 .74662 .33786 Metetra
.524 .09 .159 r
.74662 .33786 .74889 .33285 .75556 .33378 .75336 .33926 Metetra
.436 .019 .148 r
.75336 .33926 .75556 .33378 .76231 .33532 .75999 .33887 Metetra
.187 0 0 r
.75999 .33887 .76231 .33532 .76903 .33616 .7665 .33659 Metetra
.55 .928 .817 r
.7665 .33659 .76903 .33616 .77567 .33558 .77291 .33292 Metetra
.785 .86 .905 r
.77291 .33292 .77567 .33558 .7822 .33346 .77928 .32863 Metetra
.747 .731 .837 r
.77928 .32863 .7822 .33346 .78866 .33018 .78567 .32446 Metetra
.711 .682 .82 r
.78567 .32446 .78866 .33018 .79507 .32637 .79212 .32092 Metetra
.683 .68 .841 r
.79212 .32092 .79507 .32637 .8015 .32262 .79865 .31816 Metetra
.656 .714 .891 r
.79865 .31816 .8015 .32262 .80798 .31932 .80525 .3161 Metetra
.618 .774 .955 r
.80525 .3161 .80798 .31932 .81453 .31663 .81191 .31448 Metetra
.562 .831 .996 r
.81191 .31448 .81453 .31663 .82114 .31449 .8186 .31301 Metetra
.515 .86 .993 r
.8186 .31301 .82114 .31449 .8278 .3127 .8253 .31146 Metetra
.518 .876 .984 r
.8253 .31146 .8278 .3127 .8345 .31106 .832 .30969 Metetra
.562 .888 .988 r
.832 .30969 .8345 .31106 .8412 .30937 .83869 .30766 Metetra
.612 .886 .99 r
.83869 .30766 .8412 .30937 .84791 .30752 .84537 .30543 Metetra
.644 .871 .983 r
.84537 .30543 .84791 .30752 .85462 .30549 .85206 .30307 Metetra
.659 .852 .974 r
.85206 .30307 .85462 .30549 .86132 .3033 .85876 .30067 Metetra
.662 .839 .968 r
.85876 .30067 .86132 .3033 .86803 .301 .86547 .29828 Metetra
.659 .832 .966 r
.86547 .29828 .86803 .301 .87475 .29865 .87221 .29594 Metetra
.639 .84 .978 r
.26821 .4916 .27191 .49342 .27735 .49168 .27366 .48987 Metetra
.636 .84 .979 r
.27366 .48987 .27735 .49168 .28281 .4899 .27912 .48815 Metetra
.634 .844 .981 r
.27912 .48815 .28281 .4899 .28828 .48806 .2846 .48642 Metetra
.633 .852 .983 r
.2846 .48642 .28828 .48806 .29377 .48613 .29008 .48465 Metetra
.636 .865 .985 r
.29008 .48465 .29377 .48613 .29927 .48412 .29559 .4828 Metetra
.641 .878 .985 r
.29559 .4828 .29927 .48412 .3048 .48205 .30111 .48083 Metetra
.651 .887 .983 r
.30111 .48083 .3048 .48205 .31032 .48003 .30666 .47873 Metetra
.662 .884 .98 r
.30666 .47873 .31032 .48003 .31585 .47818 .31221 .47657 Metetra
.667 .863 .974 r
.31221 .47657 .31585 .47818 .32137 .47662 .31778 .47445 Metetra
.659 .822 .962 r
.31778 .47445 .32137 .47662 .32689 .47539 .32334 .47255 Metetra
.635 .77 .944 r
.32334 .47255 .32689 .47539 .3324 .47442 .32889 .47103 Metetra
.602 .724 .931 r
.32889 .47103 .3324 .47442 .33792 .47346 .33443 .46998 Metetra
.57 .707 .935 r
.33443 .46998 .33792 .47346 .34348 .47214 .33996 .46928 Metetra
.546 .742 .967 r
.33996 .46928 .34348 .47214 .3491 .47005 .3455 .46863 Metetra
.52 .838 .999 r
.3455 .46863 .3491 .47005 .35477 .46696 .35109 .46751 Metetra
.426 .87 .852 r
.35109 .46751 .35477 .46696 .3605 .46301 .35674 .4654 Metetra
.35674 .4654 .3605 .46301 .36624 .45881 .36246 .462 Metetra
.36246 .462 .36624 .45881 .37196 .45534 .36824 .45748 Metetra
.643 .948 .728 r
.36824 .45748 .37196 .45534 .3776 .45369 .37405 .45259 Metetra
.794 .911 .921 r
.37405 .45259 .3776 .45369 .38314 .45454 .37981 .44859 Metetra
.643 .624 .815 r
.37981 .44859 .38314 .45454 .38861 .45772 .38549 .44685 Metetra
.507 .445 .722 r
.38549 .44685 .38861 .45772 .39406 .46199 .39104 .44824 Metetra
.41 .349 .679 r
.39104 .44824 .39406 .46199 .39958 .46523 .39651 .45261 Metetra
.315 .297 .68 r
.39651 .45261 .39958 .46523 .40526 .46515 .40195 .45846 Metetra
.104 .292 .77 r
.40195 .45846 .40526 .46515 .41112 .46032 .40747 .46324 Metetra
.468 0 .01 r
.40747 .46324 .41112 .46032 .41712 .45113 .41316 .46413 Metetra
.348 .048 .307 r
.41316 .46413 .41712 .45113 .42317 .44006 .41905 .45931 Metetra
.254 .006 .331 r
.41905 .45931 .42317 .44006 .42914 .43099 .42511 .44906 Metetra
.112 0 .265 r
.42511 .44906 .42914 .43099 .43493 .42777 .43124 .43611 Metetra
.43124 .43611 .43493 .42777 .44053 .43254 .43728 .42485 Metetra
.726 .62 .74 r
.43728 .42485 .44053 .43254 .44599 .44449 .44316 .41984 Metetra
.491 .351 .618 r
.44316 .41984 .44599 .44449 .45144 .45958 .44882 .42389 Metetra
.386 .253 .575 r
.44882 .42389 .45144 .45958 .45702 .47174 .45432 .43678 Metetra
.285 .18 .555 r
.45432 .43678 .45702 .47174 .46283 .4752 .45978 .45487 Metetra
.023 .035 .532 r
.45978 .45487 .46283 .4752 .46886 .4673 .46535 .47193 Metetra
.775 .391 .329 r
.46535 .47193 .46886 .4673 .47503 .45011 .47113 .48136 Metetra
.509 .253 .462 r
.47113 .48136 .47503 .45011 .4812 .4298 .47712 .47886 Metetra
.418 .195 .466 r
.47712 .47886 .4812 .4298 .48726 .41396 .48329 .46444 Metetra
.342 .135 .447 r
.48329 .46444 .48726 .41396 .49318 .40839 .4895 .44261 Metetra
.195 .002 .376 r
.4895 .44261 .49318 .40839 .49901 .41461 .49565 .42047 Metetra
.886 .893 .472 r
.49565 .42047 .49901 .41461 .50483 .42912 .50169 .40505 Metetra
.615 .442 .625 r
.50169 .40505 .50483 .42912 .51072 .44467 .50764 .40093 Metetra
.48 .315 .58 r
.50764 .40093 .51072 .44467 .5167 .45324 .51355 .40906 Metetra
.371 .234 .562 r
.51355 .40906 .5167 .45324 .52274 .44992 .51949 .42663 Metetra
0 0 .506 r
.51949 .42663 .52274 .44992 .52878 .43536 .52552 .44801 Metetra
.779 .457 .442 r
.52552 .44801 .52878 .43536 .53477 .41547 .53164 .46639 Metetra
.601 .347 .504 r
.53164 .46639 .53477 .41547 .54072 .39837 .53782 .47576 Metetra
.532 .3 .508 r
.53782 .47576 .54072 .39837 .54669 .39045 .54398 .47277 Metetra
.477 .257 .5 r
.54398 .47277 .54669 .39045 .55274 .39369 .55006 .45779 Metetra
.392 .184 .474 r
.55006 .45779 .55274 .39369 .55891 .40484 .55603 .43473 Metetra
.076 0 .329 r
.55603 .43473 .55891 .40484 .56516 .41701 .56191 .4098 Metetra
.89 .695 .632 r
.56191 .4098 .56516 .41701 .57138 .42287 .56778 .38968 Metetra
.647 .45 .602 r
.56778 .38968 .57138 .42287 .57748 .41835 .57375 .37975 Metetra
.529 .357 .592 r
.57375 .37975 .57748 .41835 .58341 .40475 .57992 .38262 Metetra
.215 .169 .588 r
.57992 .38262 .58341 .40475 .58926 .38801 .58636 .3973 Metetra
.829 .49 .414 r
.58636 .3973 .58926 .38801 .59515 .37562 .59301 .41909 Metetra
.672 .402 .503 r
.59301 .41909 .59515 .37562 .60126 .37307 .59977 .44063 Metetra
.605 .356 .513 r
.59977 .44063 .60126 .37307 .60766 .38145 .60643 .45404 Metetra
.545 .309 .508 r
.60643 .45404 .60766 .38145 .61431 .39702 .61281 .45387 Metetra
.445 .224 .483 r
.61281 .45387 .61431 .39702 .62105 .41277 .61879 .43935 Metetra
.039 0 .312 r
.61879 .43935 .62105 .41277 .62765 .42135 .62442 .41482 Metetra
.926 .712 .594 r
.62442 .41482 .62765 .42135 .63391 .41847 .62991 .38782 Metetra
.731 .513 .595 r
.62991 .38782 .63391 .41847 .6398 .40473 .63549 .36608 Metetra
.643 .441 .594 r
.63549 .36608 .6398 .40473 .64544 .38516 .64139 .35488 Metetra
.55 .384 .61 r
.64139 .35488 .64544 .38516 .65107 .36661 .64773 .35557 Metetra
.068 .163 .655 r
.64773 .35557 .65107 .36661 .65692 .35483 .65448 .36554 Metetra
.759 .413 .399 r
.65448 .36554 .65692 .35483 .66316 .35244 .66145 .3794 Metetra
.652 .365 .472 r
.66145 .3794 .66316 .35244 .66979 .35836 .66839 .39094 Metetra
.581 .314 .476 r
.66839 .39094 .66979 .35836 .67668 .36862 .67508 .39538 Metetra
.478 .22 .445 r
.67508 .39538 .67668 .36862 .68359 .37813 .68137 .391 Metetra
.078 0 .229 r
.68137 .391 .68359 .37813 .6903 .38261 .68731 .37936 Metetra
.943 .794 .666 r
.68731 .37936 .6903 .38261 .69668 .38015 .69303 .36424 Metetra
.766 .57 .634 r
.69303 .36424 .69668 .38015 .70274 .3716 .69876 .34992 Metetra
.69 .5 .626 r
.69876 .34992 .70274 .3716 .70859 .3598 .70468 .33961 Metetra
.635 .468 .64 r
.70468 .33961 .70859 .3598 .71443 .34815 .7109 .33464 Metetra
.565 .461 .695 r
.7109 .33464 .71443 .34815 .72043 .33938 .71742 .3345 Metetra
.269 .481 .88 r
.71742 .3345 .72043 .33938 .72667 .33473 .72414 .33732 Metetra
.605 .103 .032 r
.72414 .33732 .72667 .33473 .73317 .33392 .73095 .34082 Metetra
.568 .174 .256 r
.73095 .34082 .73317 .33392 .73986 .33556 .73771 .34304 Metetra
.481 .103 .245 r
.73771 .34304 .73986 .33556 .74662 .33786 .74433 .34291 Metetra
.268 0 .052 r
.74433 .34291 .74662 .33786 .75336 .33926 .75081 .34036 Metetra
.513 .892 .709 r
.75081 .34036 .75336 .33926 .75999 .33887 .75718 .33608 Metetra
.814 .855 .88 r
.75718 .33608 .75999 .33887 .7665 .33659 .76349 .33109 Metetra
.755 .707 .807 r
.76349 .33109 .7665 .33659 .77291 .33292 .76983 .32634 Metetra
.711 .655 .792 r
.76983 .32634 .77291 .33292 .77928 .32863 .77624 .32245 Metetra
.679 .653 .817 r
.77624 .32245 .77928 .32863 .78567 .32446 .78275 .3196 Metetra
.649 .691 .876 r
.78275 .3196 .78567 .32446 .79212 .32092 .78934 .31766 Metetra
.601 .764 .957 r
.78934 .31766 .79212 .32092 .79865 .31816 .796 .31626 Metetra
.517 .829 1 r
.796 .31626 .79865 .31816 .80525 .3161 .80269 .31502 Metetra
.443 .847 .971 r
.80269 .31502 .80525 .3161 .81191 .31448 .80939 .31364 Metetra
.452 .865 .955 r
.80939 .31364 .81191 .31448 .8186 .31301 .81608 .31196 Metetra
.528 .891 .974 r
.81608 .31196 .8186 .31301 .8253 .31146 .82275 .30994 Metetra
.604 .896 .988 r
.82275 .30994 .8253 .31146 .832 .30969 .82942 .30766 Metetra
.649 .877 .983 r
.82942 .30766 .832 .30969 .83869 .30766 .83608 .30522 Metetra
.666 .853 .971 r
.83608 .30522 .83869 .30766 .84537 .30543 .84276 .30273 Metetra
.668 .836 .964 r
.84276 .30273 .84537 .30543 .85206 .30307 .84945 .30029 Metetra
.663 .828 .963 r
.84945 .30029 .85206 .30307 .85876 .30067 .85617 .29792 Metetra
.656 .828 .966 r
.85617 .29792 .85876 .30067 .86547 .29828 .86291 .29563 Metetra
.648 .833 .972 r
.86291 .29563 .86547 .29828 .87221 .29594 .86968 .29341 Metetra
.642 .843 .977 r
.26449 .48982 .26821 .4916 .27366 .48987 .26996 .48803 Metetra
.64 .839 .977 r
.26996 .48803 .27366 .48987 .27912 .48815 .27543 .48627 Metetra
.637 .836 .977 r
.27543 .48627 .27912 .48815 .2846 .48642 .28091 .48454 Metetra
.634 .836 .978 r
.28091 .48454 .2846 .48642 .29008 .48465 .2864 .48284 Metetra
.631 .84 .981 r
.2864 .48284 .29008 .48465 .29559 .4828 .29191 .48114 Metetra
.63 .852 .984 r
.29191 .48114 .29559 .4828 .30111 .48083 .29742 .47939 Metetra
.633 .869 .986 r
.29742 .47939 .30111 .48083 .30666 .47873 .30296 .47753 Metetra
.64 .886 .986 r
.30296 .47753 .30666 .47873 .31221 .47657 .30852 .4755 Metetra
.652 .899 .982 r
.30852 .4755 .31221 .47657 .31778 .47445 .3141 .4733 Metetra
.666 .897 .979 r
.3141 .4733 .31778 .47445 .32334 .47255 .3197 .47101 Metetra
.674 .871 .973 r
.3197 .47101 .32334 .47255 .32889 .47103 .3253 .46877 Metetra
.663 .818 .958 r
.3253 .46877 .32889 .47103 .33443 .46998 .3309 .46683 Metetra
.63 .75 .934 r
.3309 .46683 .33443 .46998 .33996 .46928 .33648 .4654 Metetra
.587 .691 .914 r
.33648 .4654 .33996 .46928 .3455 .46863 .34204 .46458 Metetra
.548 .667 .915 r
.34204 .46458 .3455 .46863 .35109 .46751 .34758 .46423 Metetra
.521 .705 .954 r
.34758 .46423 .35109 .46751 .35674 .4654 .35315 .46392 Metetra
.494 .825 .999 r
.35315 .46392 .35674 .4654 .36246 .462 .35876 .46297 Metetra
.369 .834 .777 r
.35876 .46297 .36246 .462 .36824 .45748 .36445 .46072 Metetra
.36445 .46072 .36824 .45748 .37405 .45259 .37023 .45681 Metetra
.37023 .45681 .37405 .45259 .37981 .44859 .37608 .4515 Metetra
.615 .911 .634 r
.37608 .4515 .37981 .44859 .38549 .44685 .38194 .44587 Metetra
.808 .919 .912 r
.38194 .44587 .38549 .44685 .39104 .44824 .38774 .44157 Metetra
.618 .591 .801 r
.38774 .44157 .39104 .44824 .39651 .45261 .39343 .4403 Metetra
.461 .398 .701 r
.39343 .4403 .39651 .45261 .40195 .45846 .39898 .44305 Metetra
.35 .294 .654 r
.39898 .44305 .40195 .45846 .40747 .46324 .40442 .44938 Metetra
.241 .234 .65 r
.40442 .44938 .40747 .46324 .41316 .46413 .40985 .45716 Metetra
0 .213 .726 r
.40985 .45716 .41316 .46413 .41905 .45931 .41539 .46295 Metetra
.436 0 .041 r
.41539 .46295 .41905 .45931 .42511 .44906 .42115 .46324 Metetra
.267 0 .288 r
.42115 .46324 .42511 .44906 .43124 .43611 .42715 .45611 Metetra
.148 0 .293 r
.42715 .45611 .43124 .43611 .43728 .42485 .43332 .44265 Metetra
0 0 .202 r
.43332 .44265 .43728 .42485 .44316 .41984 .43952 .42709 Metetra
.43952 .42709 .44316 .41984 .44882 .42389 .44558 .41554 Metetra
.631 .561 .757 r
.44558 .41554 .44882 .42389 .45432 .43678 .4514 .41369 Metetra
.324 .237 .6 r
.4514 .41369 .45432 .43678 .45978 .45487 .45698 .42432 Metetra
.143 .085 .527 r
.45698 .42432 .45978 .45487 .46535 .47193 .4624 .44568 Metetra
0 0 .451 r
.4624 .44568 .46535 .47193 .47113 .48136 .46785 .47121 Metetra
.769 .453 0 r
.46785 .47121 .47113 .48136 .47712 .47886 .4735 .49128 Metetra
.644 .318 .406 r
.4735 .49128 .47712 .47886 .48329 .46444 .47943 .49698 Metetra
.365 .134 .425 r
.47943 .49698 .48329 .46444 .4895 .44261 .48563 .48457 Metetra
.204 .018 .392 r
.48563 .48457 .4895 .44261 .49565 .42047 .49194 .45799 Metetra
.063 0 .334 r
.49194 .45799 .49565 .42047 .50169 .40505 .4982 .42755 Metetra
0 0 .225 r
.4982 .42755 .50169 .40505 .50764 .40093 .50432 .4056 Metetra
.009 0 0 r
.50432 .4056 .50764 .40093 .51355 .40906 .5103 .40151 Metetra
.779 .419 0 r
.5103 .40151 .51355 .40906 .51949 .42663 .51622 .41821 Metetra
.946 .611 .193 r
.51622 .41821 .51949 .42663 .52552 .44801 .52222 .45077 Metetra
.921 .59 .396 r
.52222 .45077 .52552 .44801 .53164 .46639 .52836 .48733 Metetra
.769 .467 .476 r
.52836 .48733 .53164 .46639 .53782 .47576 .53463 .51304 Metetra
.57 .31 .483 r
.53463 .51304 .53782 .47576 .54398 .47277 .54091 .51639 Metetra
.313 .107 .432 r
.54091 .51639 .54398 .47277 .55006 .45779 .54706 .49503 Metetra
0 0 .282 r
.54706 .49503 .55006 .45779 .55603 .43473 .55301 .45718 Metetra
.55301 .45718 .55603 .43473 .56191 .4098 .55881 .41738 Metetra
.966 .843 .428 r
.55881 .41738 .56191 .4098 .56778 .38968 .56464 .38983 Metetra
.884 .98 .826 r
.56464 .38983 .56778 .38968 .57375 .37975 .57068 .3831 Metetra
.847 .459 .312 r
.57068 .3831 .57375 .37975 .57992 .38262 .57706 .39766 Metetra
.816 .499 .453 r
.57706 .39766 .57992 .38262 .58636 .3973 .58377 .42614 Metetra
.752 .459 .488 r
.58377 .42614 .58636 .3973 .59301 .41909 .59064 .45586 Metetra
.668 .392 .494 r
.59064 .45586 .59301 .41909 .59977 .44063 .59738 .47361 Metetra
.513 .258 .465 r
.59738 .47361 .59977 .44063 .60643 .45404 .60373 .47126 Metetra
0 0 .132 r
.60373 .47126 .60643 .45404 .61281 .45387 .60958 .44931 Metetra
.952 .731 .566 r
.60958 .44931 .61281 .45387 .61879 .43935 .61506 .4161 Metetra
.816 .584 .586 r
.61506 .4161 .61879 .43935 .62442 .41482 .62045 .38324 Metetra
.732 .512 .593 r
.62045 .38324 .62442 .41482 .62991 .38782 .62604 .36058 Metetra
.642 .455 .614 r
.62604 .36058 .62991 .38782 .63549 .36608 .63209 .353 Metetra
.328 .309 .686 r
.63209 .353 .63549 .36608 .64139 .35488 .63862 .35956 Metetra
.834 .448 .32 r
.63862 .35956 .64139 .35488 .64773 .35557 .64553 .37464 Metetra
.717 .407 .451 r
.64553 .37464 .64773 .35557 .65448 .36554 .65255 .39036 Metetra
.638 .349 .463 r
.65255 .39036 .65448 .36554 .66145 .3794 .65938 .39962 Metetra
.514 .231 .423 r
.65938 .39962 .66145 .3794 .66839 .39094 .66583 .39863 Metetra
.66583 .39863 .66839 .39094 .67508 .39538 .67185 .38798 Metetra
.879 .697 .652 r
.67185 .38798 .67508 .39538 .68137 .391 .67758 .37167 Metetra
.759 .553 .619 r
.67758 .37167 .68137 .391 .68731 .37936 .68324 .35494 Metetra
.699 .499 .615 r
.68324 .35494 .68731 .37936 .69303 .36424 .68907 .34216 Metetra
.649 .471 .63 r
.68907 .34216 .69303 .36424 .69876 .34992 .6952 .33552 Metetra
.577 .461 .684 r
.6952 .33552 .69876 .34992 .70468 .33961 .70166 .33483 Metetra
.205 .447 .87 r
.70166 .33483 .70468 .33961 .7109 .33464 .70836 .3381 Metetra
.652 .186 .132 r
.70836 .3381 .7109 .33464 .71742 .3345 .71518 .34258 Metetra
.599 .222 .3 r
.71518 .34258 .71742 .3345 .72414 .33732 .72196 .34581 Metetra
.513 .147 .284 r
.72196 .34581 .72414 .33732 .73095 .34082 .72861 .34631 Metetra
.296 0 .088 r
.72861 .34631 .73095 .34082 .73771 .34304 .73508 .34386 Metetra
.615 .947 .771 r
.73508 .34386 .73771 .34304 .74433 .34291 .74142 .33924 Metetra
.816 .803 .839 r
.74142 .33924 .74433 .34291 .75081 .34036 .7477 .33367 Metetra
.75 .669 .771 r
.7477 .33367 .75081 .34036 .75718 .33608 .75399 .32836 Metetra
.707 .624 .762 r
.75399 .32836 .75718 .33608 .76349 .33109 .76037 .32409 Metetra
.675 .626 .792 r
.76037 .32409 .76349 .33109 .76983 .32634 .76685 .32111 Metetra
.643 .672 .863 r
.76685 .32111 .76983 .32634 .77624 .32245 .77344 .31925 Metetra
.581 .759 .963 r
.77344 .31925 .77624 .32245 .78275 .3196 .78009 .31806 Metetra
.449 .821 .993 r
.78009 .31806 .78275 .3196 .78934 .31766 .78678 .31706 Metetra
.334 .807 .912 r
.78678 .31706 .78934 .31766 .796 .31626 .79347 .31587 Metetra
.363 .83 .895 r
.79347 .31587 .796 .31626 .80269 .31502 .80015 .31428 Metetra
.488 .887 .95 r
.80015 .31428 .80269 .31502 .80939 .31364 .80681 .31226 Metetra
.602 .904 .985 r
.80681 .31226 .80939 .31364 .81608 .31196 .81345 .30991 Metetra
.659 .878 .98 r
.81345 .30991 .81608 .31196 .82275 .30994 .82009 .30737 Metetra
.676 .847 .965 r
.82009 .30737 .82275 .30994 .82942 .30766 .82675 .3048 Metetra
.676 .826 .956 r
.82675 .3048 .82942 .30766 .83608 .30522 .83342 .30229 Metetra
.668 .819 .956 r
.83342 .30229 .83608 .30522 .84276 .30273 .84012 .29989 Metetra
.658 .822 .962 r
.84012 .29989 .84276 .30273 .84945 .30029 .84684 .29759 Metetra
.648 .83 .97 r
.84684 .29759 .84945 .30029 .85617 .29792 .85359 .29538 Metetra
.639 .839 .977 r
.85359 .29538 .85617 .29792 .86291 .29563 .86036 .29322 Metetra
.634 .847 .982 r
.86036 .29322 .86291 .29563 .86968 .29341 .86715 .29106 Metetra
.645 .846 .977 r
.26075 .48806 .26449 .48982 .26996 .48803 .26623 .48623 Metetra
.645 .844 .977 r
.26623 .48623 .26996 .48803 .27543 .48627 .27172 .48441 Metetra
.644 .839 .975 r
.27172 .48441 .27543 .48627 .28091 .48454 .27721 .4826 Metetra
.642 .834 .974 r
.27721 .4826 .28091 .48454 .2864 .48284 .28272 .48084 Metetra
.638 .829 .974 r
.28272 .48084 .2864 .48284 .29191 .48114 .28823 .47913 Metetra
.633 .827 .975 r
.28823 .47913 .29191 .48114 .29742 .47939 .29375 .47746 Metetra
.629 .833 .979 r
.29375 .47746 .29742 .47939 .30296 .47753 .29928 .4758 Metetra
.627 .847 .984 r
.29928 .4758 .30296 .47753 .30852 .4755 .30483 .47408 Metetra
.629 .87 .987 r
.30483 .47408 .30852 .4755 .3141 .4733 .3104 .47221 Metetra
.636 .894 .986 r
.3104 .47221 .3141 .4733 .3197 .47101 .316 .47014 Metetra
.65 .912 .98 r
.316 .47014 .3197 .47101 .3253 .46877 .32162 .46783 Metetra
.67 .912 .977 r
.32162 .46783 .3253 .46877 .3309 .46683 .32726 .46539 Metetra
.684 .881 .972 r
.32726 .46539 .3309 .46683 .33648 .4654 .3329 .463 Metetra
.671 .811 .951 r
.3329 .463 .33648 .4654 .34204 .46458 .33853 .46097 Metetra
.63 .722 .914 r
.33853 .46097 .34204 .46458 .34758 .46423 .34414 .45957 Metetra
.58 .648 .882 r
.34414 .45957 .34758 .46423 .35315 .46392 .34973 .45893 Metetra
.537 .614 .877 r
.34973 .45893 .35315 .46392 .35876 .46297 .3553 .45888 Metetra
.509 .65 .921 r
.3553 .45888 .35876 .46297 .36445 .46072 .36088 .45892 Metetra
.476 .796 .999 r
.36088 .45892 .36445 .46072 .37023 .45681 .36651 .45824 Metetra
.36651 .45824 .37023 .45681 .37608 .4515 .37223 .45606 Metetra
.37223 .45606 .37608 .4515 .38194 .44587 .37805 .45194 Metetra
.37805 .45194 .38194 .44587 .38774 .44157 .38395 .44622 Metetra
.38395 .44622 .38774 .44157 .39343 .4403 .38986 .44007 Metetra
.822 .961 .9 r
.38986 .44007 .39343 .4403 .39898 .44305 .39571 .43532 Metetra
.625 .569 .772 r
.39571 .43532 .39898 .44305 .40442 .44938 .40144 .43374 Metetra
.49 .389 .667 r
.40144 .43374 .40442 .44938 .40985 .45716 .40704 .43631 Metetra
.42 .313 .626 r
.40704 .43631 .40985 .45716 .41539 .46295 .41254 .44247 Metetra
.379 .285 .622 r
.41254 .44247 .41539 .46295 .42115 .46324 .41803 .44999 Metetra
.351 .317 .68 r
.41803 .44999 .42115 .46324 .42715 .45611 .42364 .45544 Metetra
.111 .653 .845 r
.42364 .45544 .42715 .45611 .43332 .44265 .42944 .45556 Metetra
.25 0 .263 r
.42944 .45556 .43332 .44265 .43952 .42709 .43545 .44879 Metetra
.226 0 .334 r
.43545 .44879 .43952 .42709 .44558 .41554 .4416 .43631 Metetra
.137 0 .295 r
.4416 .43631 .44558 .41554 .4514 .41369 .44777 .42196 Metetra
.44777 .42196 .4514 .41369 .45698 .42432 .45384 .41073 Metetra
.65 .51 .679 r
.45384 .41073 .45698 .42432 .4624 .44568 .45974 .40681 Metetra
.505 .337 .587 r
.45974 .40681 .4624 .44568 .46785 .47121 .46548 .41165 Metetra
.471 .297 .563 r
.46548 .41165 .46785 .47121 .4735 .49128 .47115 .42323 Metetra
.47 .293 .558 r
.47115 .42323 .4735 .49128 .47943 .49698 .47686 .4366 Metetra
.491 .312 .566 r
.47686 .4366 .47943 .49698 .48563 .48457 .48269 .44579 Metetra
.549 .371 .592 r
.48269 .44579 .48563 .48457 .49194 .45799 .48867 .44646 Metetra
.741 .584 .679 r
.48867 .44646 .49194 .45799 .4982 .42755 .49475 .4379 Metetra
.49475 .4379 .4982 .42755 .50432 .4056 .50087 .42329 Metetra
.015 0 .23 r
.50087 .42329 .50432 .4056 .5103 .40151 .50696 .40791 Metetra
.50696 .40791 .5103 .40151 .51622 .41821 .513 .39652 Metetra
.634 .462 .633 r
.513 .39652 .51622 .41821 .52222 .45077 .51901 .39134 Metetra
.552 .36 .573 r
.51901 .39134 .52222 .45077 .52836 .48733 .52501 .39144 Metetra
.542 .342 .559 r
.52501 .39144 .52836 .48733 .53463 .51304 .53104 .3938 Metetra
.547 .342 .555 r
.53104 .3938 .53463 .51304 .54091 .51639 .5371 .39523 Metetra
.554 .348 .555 r
.5371 .39523 .54091 .51639 .54706 .49503 .54317 .39423 Metetra
.56 .355 .56 r
.54317 .39423 .54706 .49503 .55301 .45718 .54925 .39173 Metetra
.561 .364 .571 r
.54925 .39173 .55301 .45718 .55881 .41738 .55535 .3902 Metetra
.535 .379 .616 r
.55535 .3902 .55881 .41738 .56464 .38983 .5615 .39178 Metetra
.686 .197 .082 r
.5615 .39178 .56464 .38983 .57068 .3831 .56771 .39666 Metetra
.638 .315 .408 r
.56771 .39666 .57068 .3831 .57706 .39766 .57399 .40249 Metetra
.601 .173 .201 r
.57399 .40249 .57706 .39766 .58377 .42614 .58026 .40543 Metetra
.61 .45 .64 r
.58026 .40543 .58377 .42614 .59064 .45586 .58644 .40221 Metetra
.614 .409 .58 r
.58644 .40221 .59064 .45586 .59738 .47361 .59249 .39213 Metetra
.609 .396 .567 r
.59249 .39213 .59738 .47361 .60373 .47126 .59843 .37782 Metetra
.6 .387 .563 r
.59843 .37782 .60373 .47126 .60958 .44931 .60434 .36418 Metetra
.584 .376 .565 r
.60434 .36418 .60958 .44931 .61506 .4161 .61038 .35618 Metetra
.55 .358 .574 r
.61038 .35618 .61506 .4161 .62045 .38324 .61665 .35667 Metetra
.422 .302 .61 r
.61665 .35667 .62045 .38324 .62604 .36058 .6232 .36516 Metetra
.814 .421 .307 r
.6232 .36516 .62604 .36058 .63209 .353 .62994 .37797 Metetra
.66 .368 .467 r
.62994 .37797 .63209 .353 .63862 .35956 .63671 .38968 Metetra
.594 .32 .471 r
.63671 .38968 .63862 .35956 .64553 .37464 .64334 .39528 Metetra
.477 .201 .416 r
.64334 .39528 .64553 .37464 .65255 .39036 .64967 .39224 Metetra
.922 .961 .645 r
.64967 .39224 .65255 .39036 .65938 .39962 .65569 .38141 Metetra
.754 .554 .626 r
.65569 .38141 .65938 .39962 .66583 .39863 .66151 .36635 Metetra
.683 .475 .599 r
.66151 .36635 .66583 .39863 .67185 .38798 .66731 .35167 Metetra
.643 .442 .596 r
.66731 .35167 .67185 .38798 .67758 .37167 .67327 .34114 Metetra
.605 .422 .608 r
.67327 .34114 .67758 .37167 .68324 .35494 .6795 .33657 Metetra
.54 .413 .655 r
.6795 .33657 .68324 .35494 .68907 .34216 .68602 .33755 Metetra
.037 .346 .824 r
.68602 .33755 .68907 .34216 .6952 .33552 .69275 .34198 Metetra
.656 .256 .275 r
.69275 .34198 .6952 .33552 .70166 .33483 .69955 .34704 Metetra
.59 .256 .372 r
.69955 .34704 .70166 .33483 .70836 .3381 .7063 .35026 Metetra
.514 .188 .352 r
.7063 .35026 .70836 .3381 .71518 .34258 .71289 .35028 Metetra
.328 0 .196 r
.71289 .35028 .71518 .34258 .72196 .34581 .71931 .34706 Metetra
.65 .947 .717 r
.71931 .34706 .72196 .34581 .72861 .34631 .72559 .34157 Metetra
.812 .753 .797 r
.72559 .34157 .72861 .34631 .73508 .34386 .73182 .33529 Metetra
.732 .62 .734 r
.73182 .33529 .73508 .34386 .74142 .33924 .73809 .32953 Metetra
.687 .579 .728 r
.73809 .32953 .74142 .33924 .7477 .33367 .74445 .32514 Metetra
.656 .582 .759 r
.74445 .32514 .7477 .33367 .75399 .32836 .75093 .32233 Metetra
.623 .631 .838 r
.75093 .32233 .75399 .32836 .76037 .32409 .75752 .3208 Metetra
.549 .739 .964 r
.75752 .3208 .76037 .32409 .76685 .32111 .76418 .31999 Metetra
.34 .787 .957 r
.76418 .31999 .76685 .32111 .77344 .31925 .77087 .31931 Metetra
.173 .71 .777 r
.77087 .31931 .77344 .31925 .78009 .31806 .77756 .3183 Metetra
.233 .751 .772 r
.77756 .3183 .78009 .31806 .78678 .31706 .78422 .31675 Metetra
.433 .871 .9 r
.78422 .31675 .78678 .31706 .79347 .31587 .79086 .31465 Metetra
.604 .914 .979 r
.79086 .31465 .79347 .31587 .80015 .31428 .79747 .31217 Metetra
.674 .878 .975 r
.79747 .31217 .80015 .31428 .80681 .31226 .80409 .30948 Metetra
.689 .836 .954 r
.80409 .30948 .80681 .31226 .81345 .30991 .81072 .30679 Metetra
.684 .811 .943 r
.81072 .30679 .81345 .30991 .82009 .30737 .81737 .3042 Metetra
.673 .804 .945 r
.81737 .3042 .82009 .30737 .82675 .3048 .82405 .30177 Metetra
.66 .81 .955 r
.82405 .30177 .82675 .3048 .83342 .30229 .83076 .29949 Metetra
.648 .822 .967 r
.83076 .29949 .83342 .30229 .84012 .29989 .83749 .29731 Metetra
.638 .835 .976 r
.83749 .29731 .84012 .29989 .84684 .29759 .84425 .29518 Metetra
.631 .846 .982 r
.84425 .29518 .84684 .29759 .85359 .29538 .85102 .29305 Metetra
.63 .852 .984 r
.85102 .29305 .85359 .29538 .86036 .29322 .85781 .2909 Metetra
.632 .854 .984 r
.85781 .2909 .86036 .29322 .86715 .29106 .86461 .2887 Metetra
.646 .84 .975 r
.25701 .48621 .26075 .48806 .26623 .48623 .26249 .48439 Metetra
.647 .842 .975 r
.26249 .48439 .26623 .48623 .27172 .48441 .26799 .48255 Metetra
.648 .841 .975 r
.26799 .48255 .27172 .48441 .27721 .4826 .2735 .4807 Metetra
.648 .838 .973 r
.2735 .4807 .27721 .4826 .28272 .48084 .27901 .47885 Metetra
.647 .832 .972 r
.27901 .47885 .28272 .48084 .28823 .47913 .28454 .47703 Metetra
.644 .825 .97 r
.28454 .47703 .28823 .47913 .29375 .47746 .29008 .47527 Metetra
.638 .817 .969 r
.29008 .47527 .29375 .47746 .29928 .4758 .29562 .47358 Metetra
.631 .814 .97 r
.29562 .47358 .29928 .4758 .30483 .47408 .30117 .47196 Metetra
.625 .821 .975 r
.30117 .47196 .30483 .47408 .3104 .47221 .30673 .47037 Metetra
.623 .84 .983 r
.30673 .47037 .3104 .47221 .316 .47014 .31231 .4687 Metetra
.627 .87 .988 r
.31231 .4687 .316 .47014 .32162 .46783 .31791 .46684 Metetra
.638 .902 .984 r
.31791 .46684 .32162 .46783 .32726 .46539 .32355 .46468 Metetra
.659 .924 .975 r
.32355 .46468 .32726 .46539 .3329 .463 .32921 .46219 Metetra
.69 .924 .97 r
.32921 .46219 .3329 .463 .33853 .46097 .33489 .45948 Metetra
.706 .882 .962 r
.33489 .45948 .33853 .46097 .34414 .45957 .34058 .45683 Metetra
.682 .792 .933 r
.34058 .45683 .34414 .45957 .34973 .45893 .34626 .45465 Metetra
.623 .686 .888 r
.34626 .45465 .34973 .45893 .3553 .45888 .35189 .45336 Metetra
.554 .6 .854 r
.35189 .45336 .3553 .45888 .36088 .45892 .35749 .45317 Metetra
.486 .558 .854 r
.35749 .45317 .36088 .45892 .36651 .45824 .36306 .45389 Metetra
.416 .592 .916 r
.36306 .45389 .36651 .45824 .37223 .45606 .36864 .45482 Metetra
.247 .718 .943 r
.36864 .45482 .37223 .45606 .37805 .45194 .37428 .45485 Metetra
.057 0 0 r
.37428 .45485 .37805 .45194 .38395 .44622 .38003 .45281 Metetra
.063 0 0 r
.38003 .45281 .38395 .44622 .38986 .44007 .38591 .44799 Metetra
.38591 .44799 .38986 .44007 .39571 .43532 .3919 .44074 Metetra
.3919 .44074 .39571 .43532 .40144 .43374 .39791 .43265 Metetra
.876 .893 .841 r
.39791 .43265 .40144 .43374 .40704 .43631 .40384 .42631 Metetra
.621 .528 .727 r
.40384 .42631 .40704 .43631 .41254 .44247 .40961 .42446 Metetra
.447 .345 .646 r
.40961 .42446 .41254 .44247 .41803 .44999 .41519 .4289 Metetra
.29 .219 .601 r
.41519 .4289 .41803 .44999 .42364 .45544 .4206 .43935 Metetra
0 .035 .549 r
.4206 .43935 .42364 .45544 .42944 .45556 .42598 .45299 Metetra
.879 .443 .097 r
.42598 .45299 .42944 .45556 .43545 .44879 .43147 .46485 Metetra
.612 .307 .428 r
.43147 .46485 .43545 .44879 .4416 .43631 .43722 .46944 Metetra
.459 .211 .45 r
.43722 .46944 .4416 .43631 .44777 .42196 .44328 .46317 Metetra
.347 .128 .433 r
.44328 .46317 .44777 .42196 .45384 .41073 .44957 .44652 Metetra
.204 .007 .376 r
.44957 .44652 .45384 .41073 .45974 .40681 .45593 .42461 Metetra
0 0 .127 r
.45593 .42461 .45974 .40681 .46548 .41165 .46218 .40565 Metetra
.802 .689 .739 r
.46218 .40565 .46548 .41165 .47115 .42323 .46818 .39804 Metetra
.385 .274 .603 r
.46818 .39804 .47115 .42323 .47686 .4366 .4739 .40717 Metetra
0 0 .476 r
.4739 .40717 .47686 .4366 .48269 .44579 .47945 .43312 Metetra
.926 .619 .149 r
.47945 .43312 .48269 .44579 .48867 .44646 .48498 .46969 Metetra
.796 .501 .489 r
.48498 .46969 .48867 .44646 .49475 .4379 .49067 .50541 Metetra
.637 .383 .517 r
.49067 .50541 .49475 .4379 .50087 .42329 .49664 .52714 Metetra
.54 .309 .514 r
.49664 .52714 .50087 .42329 .50696 .40791 .50286 .52563 Metetra
.46 .247 .502 r
.50286 .52563 .50696 .40791 .513 .39652 .50921 .50043 Metetra
.374 .177 .48 r
.50921 .50043 .513 .39652 .51901 .39134 .51553 .46061 Metetra
.254 .076 .435 r
.51553 .46061 .51901 .39134 .52501 .39144 .52171 .42091 Metetra
.035 0 .304 r
.52171 .42091 .52501 .39144 .53104 .3938 .52779 .39564 Metetra
.52779 .39564 .53104 .3938 .5371 .39523 .53385 .39385 Metetra
.929 .556 .274 r
.53385 .39385 .5371 .39523 .54317 .39423 .54005 .41669 Metetra
.815 .514 .481 r
.54005 .41669 .54317 .39423 .54925 .39173 .54646 .45691 Metetra
.705 .438 .518 r
.54646 .45691 .54925 .39173 .55535 .3902 .55308 .50046 Metetra
.626 .379 .525 r
.55308 .50046 .55535 .3902 .5615 .39178 .55975 .5308 Metetra
.557 .326 .521 r
.55975 .5308 .5615 .39178 .56771 .39666 .56625 .53546 Metetra
.482 .267 .51 r
.56625 .53546 .56771 .39666 .57399 .40249 .57238 .51191 Metetra
.374 .18 .484 r
.57238 .51191 .57399 .40249 .58026 .40543 .57812 .46853 Metetra
.134 0 .399 r
.57812 .46853 .58026 .40543 .58644 .40221 .58363 .42019 Metetra
.758 .692 .148 r
.58363 .42019 .58644 .40221 .59249 .39213 .58916 .38159 Metetra
.851 .65 .63 r
.58916 .38159 .59249 .39213 .59843 .37782 .595 .36224 Metetra
.506 .404 .674 r
.595 .36224 .59843 .37782 .60434 .36418 .60129 .36439 Metetra
.904 .507 .246 r
.60129 .36439 .60434 .36418 .61038 .35618 .60805 .38331 Metetra
.742 .445 .48 r
.60805 .38331 .61038 .35618 .61665 .35667 .6151 .40928 Metetra
.655 .389 .505 r
.6151 .40928 .61665 .35667 .6232 .36516 .62215 .43094 Metetra
.583 .335 .507 r
.62215 .43094 .6232 .36516 .62994 .37797 .62889 .43936 Metetra
.495 .264 .492 r
.62889 .43936 .62994 .37797 .63671 .38968 .63512 .43136 Metetra
.312 .109 .435 r
.63512 .43136 .63671 .38968 .64334 .39528 .64087 .41008 Metetra
.64087 .41008 .64334 .39528 .64967 .39224 .64633 .38286 Metetra
.895 .679 .603 r
.64633 .38286 .64967 .39224 .65569 .38141 .6518 .35776 Metetra
.736 .526 .609 r
.6518 .35776 .65569 .38141 .66151 .36635 .65751 .34063 Metetra
.639 .455 .618 r
.65751 .34063 .66151 .36635 .66731 .35167 .66363 .33372 Metetra
.515 .398 .658 r
.66363 .33372 .66731 .35167 .67327 .34114 .67016 .33583 Metetra
0 .103 .656 r
.67016 .33583 .67327 .34114 .6795 .33657 .67698 .34333 Metetra
.726 .336 .311 r
.67698 .34333 .6795 .33657 .68602 .33755 .6839 .35176 Metetra
.627 .302 .4 r
.6839 .35176 .68602 .33755 .69275 .34198 .69073 .35737 Metetra
.538 .229 .392 r
.69073 .35737 .69275 .34198 .69955 .34704 .69735 .35817 Metetra
.371 .056 .294 r
.69735 .35817 .69955 .34704 .7063 .35026 .70373 .35419 Metetra
.70373 .35419 .7063 .35026 .71289 .35028 .70992 .34697 Metetra
.884 .821 .781 r
.70992 .34697 .71289 .35028 .71931 .34706 .71605 .3387 Metetra
.767 .641 .722 r
.71605 .3387 .71931 .34706 .72559 .34157 .72221 .33129 Metetra
.703 .579 .713 r
.72221 .33129 .72559 .34157 .73182 .33529 .72851 .3259 Metetra
.657 .567 .742 r
.72851 .3259 .73182 .33529 .73809 .32953 .73495 .32281 Metetra
.609 .602 .818 r
.73495 .32281 .73809 .32953 .74445 .32514 .74154 .32154 Metetra
.508 .699 .955 r
.74154 .32154 .74445 .32514 .75093 .32233 .74821 .32128 Metetra
.225 .718 .919 r
.74821 .32128 .75093 .32233 .75752 .3208 .75492 .32118 Metetra
.75492 .32118 .75752 .3208 .76418 .31999 .76162 .32059 Metetra
.76162 .32059 .76418 .31999 .77087 .31931 .76828 .31925 Metetra
.389 .849 .861 r
.76828 .31925 .77087 .31931 .77756 .3183 .7749 .31715 Metetra
.616 .922 .975 r
.7749 .31715 .77756 .3183 .78422 .31675 .78149 .31452 Metetra
.694 .875 .966 r
.78149 .31452 .78422 .31675 .79086 .31465 .78807 .31163 Metetra
.703 .823 .939 r
.78807 .31163 .79086 .31465 .79747 .31217 .79467 .30875 Metetra
.693 .794 .928 r
.79467 .30875 .79747 .31217 .80409 .30948 .8013 .30604 Metetra
.678 .788 .932 r
.8013 .30604 .80409 .30948 .81072 .30679 .80796 .30355 Metetra
.663 .796 .946 r
.80796 .30355 .81072 .30679 .81737 .3042 .81465 .30127 Metetra
.648 .812 .962 r
.81465 .30127 .81737 .3042 .82405 .30177 .82137 .29912 Metetra
.636 .829 .975 r
.82137 .29912 .82405 .30177 .83076 .29949 .82812 .29704 Metetra
.629 .842 .981 r
.82812 .29704 .83076 .29949 .83749 .29731 .83488 .29496 Metetra
.629 .849 .984 r
.83488 .29496 .83749 .29731 .84425 .29518 .84165 .29283 Metetra
.633 .851 .983 r
.84165 .29283 .84425 .29518 .85102 .29305 .84844 .29064 Metetra
.639 .85 .98 r
.84844 .29064 .85102 .29305 .85781 .2909 .85523 .2884 Metetra
.645 .847 .977 r
.85523 .2884 .85781 .2909 .86461 .2887 .86204 .28612 Metetra
.647 .827 .969 r
.25325 .48416 .25701 .48621 .26249 .48439 .25874 .48237 Metetra
.648 .83 .97 r
.25874 .48237 .26249 .48439 .26799 .48255 .26425 .48056 Metetra
.649 .832 .971 r
.26425 .48056 .26799 .48255 .2735 .4807 .26976 .47872 Metetra
.651 .834 .971 r
.26976 .47872 .2735 .4807 .27901 .47885 .27529 .47686 Metetra
.652 .834 .97 r
.27529 .47686 .27901 .47885 .28454 .47703 .28083 .47499 Metetra
.652 .831 .969 r
.28083 .47499 .28454 .47703 .29008 .47527 .28639 .47312 Metetra
.651 .823 .966 r
.28639 .47312 .29008 .47527 .29562 .47358 .29195 .47128 Metetra
.646 .812 .963 r
.29195 .47128 .29562 .47358 .30117 .47196 .29752 .46952 Metetra
.639 .801 .96 r
.29752 .46952 .30117 .47196 .30673 .47037 .30309 .46786 Metetra
.632 .795 .961 r
.30309 .46786 .30673 .47037 .31231 .4687 .30867 .46629 Metetra
.627 .801 .966 r
.30867 .46629 .31231 .4687 .31791 .46684 .31426 .46473 Metetra
.629 .824 .975 r
.31426 .46473 .31791 .46684 .32355 .46468 .31987 .46308 Metetra
.637 .862 .984 r
.31987 .46308 .32355 .46468 .32921 .46219 .32551 .46118 Metetra
.65 .905 .982 r
.32551 .46118 .32921 .46219 .33489 .45948 .33118 .4589 Metetra
.667 .934 .969 r
.33118 .4589 .33489 .45948 .34058 .45683 .33688 .45625 Metetra
.69 .938 .964 r
.33688 .45625 .34058 .45683 .34626 .45465 .34261 .45339 Metetra
.703 .899 .967 r
.34261 .45339 .34626 .45465 .35189 .45336 .34833 .45069 Metetra
.671 .796 .941 r
.34833 .45069 .35189 .45336 .35749 .45317 .35403 .44864 Metetra
.6 .665 .885 r
.35403 .44864 .35749 .45317 .36306 .45389 .35968 .44768 Metetra
.528 .563 .834 r
.35968 .44768 .36306 .45389 .36864 .45482 .36529 .44794 Metetra
.481 .515 .816 r
.36529 .44794 .36864 .45482 .37428 .45485 .37089 .449 Metetra
.472 .548 .853 r
.37089 .449 .37428 .45485 .38003 .45281 .37651 .4499 Metetra
.531 .739 .971 r
.37651 .4499 .38003 .45281 .38591 .44799 .38222 .44932 Metetra
.483 .892 .772 r
.38222 .44932 .38591 .44799 .3919 .44074 .38805 .44613 Metetra
.38805 .44613 .3919 .44074 .39791 .43265 .39401 .44 Metetra
.39401 .44 .39791 .43265 .40384 .42631 .40005 .43196 Metetra
.40005 .43196 .40384 .42631 .40961 .42446 .40605 .42432 Metetra
.788 .971 .915 r
.40605 .42432 .40961 .42446 .41519 .4289 .41194 .42 Metetra
.489 .469 .762 r
.41194 .42 .41519 .4289 .4206 .43935 .41764 .42139 Metetra
.338 .27 .631 r
.41764 .42139 .4206 .43935 .42598 .45299 .42317 .42904 Metetra
.292 .209 .588 r
.42317 .42904 .42598 .45299 .43147 .46485 .42862 .44084 Metetra
.307 .221 .592 r
.42862 .44084 .43147 .46485 .43722 .46944 .43415 .45219 Metetra
.414 .329 .65 r
.43415 .45219 .43722 .46944 .44328 .46317 .43989 .45748 Metetra
.751 .683 .785 r
.43989 .45748 .44328 .46317 .44957 .44652 .44592 .45265 Metetra
.882 .901 .486 r
.44592 .45265 .44957 .44652 .45593 .42461 .45218 .43758 Metetra
.45218 .43758 .45593 .42461 .46218 .40565 .45851 .41704 Metetra
.45851 .41704 .46218 .40565 .46818 .39804 .46474 .39907 Metetra
.891 .987 .793 r
.46474 .39907 .46818 .39804 .4739 .40717 .47075 .39178 Metetra
.279 .249 .645 r
.47075 .39178 .4739 .40717 .47945 .43312 .47652 .39986 Metetra
.169 .099 .528 r
.47652 .39986 .47945 .43312 .48498 .46969 .48215 .42214 Metetra
.216 .115 .518 r
.48215 .42214 .48498 .46969 .49067 .50541 .48781 .45113 Metetra
.334 .198 .542 r
.48781 .45113 .49067 .50541 .49664 .52714 .49365 .47508 Metetra
.492 .318 .572 r
.49365 .47508 .49664 .52714 .50286 .52563 .49972 .48281 Metetra
.649 .442 .59 r
.49972 .48281 .50286 .52563 .50921 .50043 .50596 .46944 Metetra
.767 .541 .591 r
.50596 .46944 .50921 .50043 .51553 .46061 .51223 .43953 Metetra
.829 .599 .59 r
.51223 .43953 .51553 .46061 .52171 .42091 .51843 .40513 Metetra
.829 .611 .609 r
.51843 .40513 .52171 .42091 .52779 .39564 .52451 .38002 Metetra
.674 .513 .66 r
.52451 .38002 .52779 .39564 .53385 .39385 .53055 .37391 Metetra
.127 .115 .573 r
.53055 .37391 .53385 .39385 .54005 .41669 .53667 .38884 Metetra
0 0 .439 r
.53667 .38884 .54005 .41669 .54646 .45691 .54295 .41839 Metetra
.078 .03 .495 r
.54295 .41839 .54646 .45691 .55308 .50046 .54937 .44978 Metetra
.381 .238 .558 r
.54937 .44978 .55308 .50046 .55975 .5308 .55583 .46884 Metetra
.565 .369 .573 r
.55583 .46884 .55975 .5308 .56625 .53546 .56213 .46647 Metetra
.653 .433 .572 r
.56213 .46647 .56625 .53546 .57238 .51191 .56817 .44321 Metetra
.691 .461 .57 r
.56817 .44321 .57238 .51191 .57812 .46853 .57397 .40854 Metetra
.7 .471 .572 r
.57397 .40854 .57812 .46853 .58363 .42019 .57969 .37566 Metetra
.681 .463 .584 r
.57969 .37566 .58363 .42019 .58916 .38159 .58554 .35552 Metetra
.59 .42 .619 r
.58554 .35552 .58916 .38159 .595 .36224 .59171 .35292 Metetra
0 0 .508 r
.59171 .35292 .595 .36224 .60129 .36439 .59824 .36569 Metetra
.901 .516 .286 r
.59824 .36569 .60129 .36439 .60805 .38331 .60504 .38616 Metetra
.875 .489 .304 r
.60504 .38616 .60805 .38331 .6151 .40928 .61188 .40438 Metetra
0 .016 .574 r
.61188 .40438 .6151 .40928 .62215 .43094 .61851 .41221 Metetra
.651 .486 .647 r
.61851 .41221 .62215 .43094 .62889 .43936 .62478 .40648 Metetra
.693 .483 .597 r
.62478 .40648 .62889 .43936 .63512 .43136 .63069 .38984 Metetra
.693 .473 .585 r
.63069 .38984 .63512 .43136 .64087 .41008 .6364 .36871 Metetra
.681 .464 .586 r
.6364 .36871 .64087 .41008 .64633 .38286 .64213 .35005 Metetra
.658 .456 .6 r
.64213 .35005 .64633 .38286 .6518 .35776 .6481 .33863 Metetra
.606 .452 .648 r
.6481 .33863 .6518 .35776 .65751 .34063 .6544 .33586 Metetra
.082 .371 .836 r
.6544 .33586 .65751 .34063 .66363 .33372 .66101 .33996 Metetra
.71 .312 .292 r
.66101 .33996 .66363 .33372 .67016 .33583 .6678 .34724 Metetra
.655 .31 .376 r
.6678 .34724 .67016 .33583 .67698 .34333 .6746 .35371 Metetra
.582 .232 .341 r
.6746 .35371 .67698 .34333 .6839 .35176 .68127 .3565 Metetra
.295 0 .029 r
.68127 .3565 .6839 .35176 .69073 .35737 .68774 .35465 Metetra
.836 .855 .859 r
.68774 .35465 .69073 .35737 .69735 .35817 .69403 .349 Metetra
.758 .623 .711 r
.69403 .349 .69735 .35817 .70373 .35419 .70021 .34146 Metetra
.714 .56 .678 r
.70021 .34146 .70373 .35419 .70992 .34697 .70639 .33409 Metetra
.686 .542 .684 r
.70639 .33409 .70992 .34697 .71605 .3387 .71267 .32836 Metetra
.661 .555 .724 r
.71267 .32836 .71605 .3387 .72221 .33129 .71908 .32483 Metetra
.624 .618 .824 r
.71908 .32483 .72221 .33129 .72851 .3259 .72562 .32327 Metetra
.467 .748 .99 r
.72562 .32327 .72851 .3259 .73495 .32281 .73226 .3229 Metetra
.006 0 0 r
.73226 .3229 .73495 .32281 .74154 .32154 .73894 .32283 Metetra
.144 0 0 r
.73894 .32283 .74154 .32154 .74821 .32128 .74562 .32237 Metetra
.74562 .32237 .74821 .32128 .75492 .32118 .75227 .32112 Metetra
.386 .847 .862 r
.75227 .32112 .75492 .32118 .76162 .32059 .75888 .31906 Metetra
.648 .908 .981 r
.75888 .31906 .76162 .32059 .76828 .31925 .76545 .3164 Metetra
.707 .835 .944 r
.76545 .3164 .76828 .31925 .7749 .31715 .77202 .31346 Metetra
.706 .781 .91 r
.77202 .31346 .7749 .31715 .78149 .31452 .7786 .31051 Metetra
.694 .759 .902 r
.7786 .31051 .78149 .31452 .78807 .31163 .78521 .30775 Metetra
.68 .761 .913 r
.78521 .30775 .78807 .31163 .79467 .30875 .79185 .30525 Metetra
.664 .779 .934 r
.79185 .30525 .79467 .30875 .8013 .30604 .79853 .30298 Metetra
.648 .803 .957 r
.79853 .30298 .8013 .30604 .80796 .30355 .80523 .30086 Metetra
.635 .825 .974 r
.80523 .30086 .80796 .30355 .81465 .30127 .81196 .29881 Metetra
.628 .84 .982 r
.81196 .29881 .81465 .30127 .82137 .29912 .81871 .29675 Metetra
.629 .847 .983 r
.81871 .29675 .82137 .29912 .82812 .29704 .82547 .29463 Metetra
.635 .848 .981 r
.82547 .29463 .82812 .29704 .83488 .29496 .83223 .29245 Metetra
.644 .844 .977 r
.83223 .29245 .83488 .29496 .84165 .29283 .83901 .2902 Metetra
.65 .838 .973 r
.83901 .2902 .84165 .29283 .84844 .29064 .8458 .2879 Metetra
.654 .833 .969 r
.8458 .2879 .84844 .29064 .85523 .2884 .8526 .28558 Metetra
.656 .828 .966 r
.8526 .28558 .85523 .2884 .86204 .28612 .85942 .28325 Metetra
.651 .811 .961 r
.2495 .48187 .25325 .48416 .25874 .48237 .255 .48009 Metetra
.65 .813 .961 r
.255 .48009 .25874 .48237 .26425 .48056 .26051 .47831 Metetra
.65 .815 .962 r
.26051 .47831 .26425 .48056 .26976 .47872 .26603 .47651 Metetra
.651 .818 .964 r
.26603 .47651 .26976 .47872 .27529 .47686 .27157 .47469 Metetra
.652 .822 .965 r
.27157 .47469 .27529 .47686 .28083 .47499 .27711 .47285 Metetra
.655 .825 .965 r
.27711 .47285 .28083 .47499 .28639 .47312 .28268 .47096 Metetra
.657 .825 .964 r
.28268 .47096 .28639 .47312 .29195 .47128 .28825 .46905 Metetra
.659 .82 .961 r
.28825 .46905 .29195 .47128 .29752 .46952 .29384 .46713 Metetra
.658 .809 .956 r
.29384 .46713 .29752 .46952 .30309 .46786 .29944 .46524 Metetra
.653 .793 .949 r
.29944 .46524 .30309 .46786 .30867 .46629 .30504 .46344 Metetra
.644 .776 .944 r
.30504 .46344 .30867 .46629 .31426 .46473 .31064 .46178 Metetra
.633 .766 .943 r
.31064 .46178 .31426 .46473 .31987 .46308 .31625 .46025 Metetra
.623 .773 .952 r
.31625 .46025 .31987 .46308 .32551 .46118 .32187 .45882 Metetra
.616 .804 .972 r
.32187 .45882 .32551 .46118 .33118 .4589 .3275 .45733 Metetra
.612 .86 .99 r
.3275 .45733 .33118 .4589 .33688 .45625 .33316 .45561 Metetra
.605 .915 .978 r
.33316 .45561 .33688 .45625 .34261 .45339 .33886 .45344 Metetra
.611 .945 .938 r
.33886 .45344 .34261 .45339 .34833 .45069 .3446 .45074 Metetra
.67 .962 .937 r
.3446 .45074 .34833 .45069 .35403 .44864 .35037 .44761 Metetra
.738 .919 .954 r
.35037 .44761 .35403 .44864 .35968 .44768 .35615 .4444 Metetra
.712 .768 .896 r
.35615 .4444 .35968 .44768 .36529 .44794 .36191 .44168 Metetra
.634 .613 .812 r
.36191 .44168 .36529 .44794 .37089 .449 .36764 .44006 Metetra
.561 .511 .756 r
.36764 .44006 .37089 .449 .37651 .4499 .3733 .43994 Metetra
.502 .457 .74 r
.3733 .43994 .37651 .4499 .38222 .44932 .37892 .44122 Metetra
.441 .46 .783 r
.37892 .44122 .38222 .44932 .38805 .44613 .38454 .44315 Metetra
.241 .594 .949 r
.38454 .44315 .38805 .44613 .39401 .44 .39021 .44442 Metetra
.348 0 .032 r
.39021 .44442 .39401 .44 .40005 .43196 .39598 .44352 Metetra
.342 .025 .275 r
.39598 .44352 .40005 .43196 .40605 .42432 .4019 .4394 Metetra
.269 0 .293 r
.4019 .4394 .40605 .42432 .41194 .42 .40794 .43207 Metetra
.058 0 .157 r
.40794 .43207 .41194 .42 .41764 .42139 .41403 .42294 Metetra
.915 .979 .761 r
.41403 .42294 .41764 .42139 .42317 .42904 .42008 .41461 Metetra
.658 .509 .671 r
.42008 .41461 .42317 .42904 .42862 .44084 .42601 .40999 Metetra
.538 .372 .603 r
.42601 .40999 .42862 .44084 .43415 .45219 .43177 .41126 Metetra
.473 .31 .579 r
.43177 .41126 .43415 .45219 .43989 .45748 .43738 .41881 Metetra
.409 .265 .572 r
.43738 .41881 .43989 .45748 .44592 .45265 .44294 .43069 Metetra
.248 .187 .589 r
.44294 .43069 .44592 .45265 .45218 .43758 .44855 .4429 Metetra
.735 .348 .318 r
.44855 .4429 .45218 .43758 .45851 .41704 .45432 .45052 Metetra
.526 .267 .466 r
.45432 .45052 .45851 .41704 .46474 .39907 .46031 .44963 Metetra
.453 .221 .471 r
.46031 .44963 .46474 .39907 .47075 .39178 .46649 .43907 Metetra
.365 .147 .445 r
.46649 .43907 .47075 .39178 .47652 .39986 .47277 .42126 Metetra
0 0 .22 r
.47277 .42126 .47652 .39986 .48215 .42214 .47902 .40153 Metetra
.738 .537 .622 r
.47902 .40153 .48215 .42214 .48781 .45113 .48518 .38624 Metetra
.582 .379 .571 r
.48518 .38624 .48781 .45113 .49365 .47508 .49119 .3806 Metetra
.523 .326 .555 r
.49119 .3806 .49365 .47508 .49972 .48281 .4971 .38692 Metetra
.476 .29 .548 r
.4971 .38692 .49972 .48281 .50596 .46944 .50298 .40377 Metetra
.394 .236 .546 r
.50298 .40377 .50596 .46944 .51223 .43953 .50892 .42612 Metetra
0 0 .303 r
.50892 .42612 .51223 .43953 .51843 .40513 .51497 .44667 Metetra
.622 .356 .495 r
.51497 .44667 .51843 .40513 .52451 .38002 .52113 .4581 Metetra
.532 .297 .504 r
.52113 .4581 .52451 .38002 .53055 .37391 .52735 .45578 Metetra
.464 .244 .493 r
.52735 .45578 .53055 .37391 .53667 .38884 .53354 .43965 Metetra
.301 .102 .435 r
.53354 .43965 .53667 .38884 .54295 .41839 .53965 .41434 Metetra
.944 .739 .596 r
.53965 .41434 .54295 .41839 .54937 .44978 .54567 .38739 Metetra
.652 .434 .574 r
.54567 .38739 .54937 .44978 .55583 .46884 .55166 .36658 Metetra
.581 .37 .559 r
.55166 .36658 .55583 .46884 .56213 .46647 .55772 .35745 Metetra
.534 .333 .554 r
.55772 .35745 .56213 .46647 .56817 .44321 .56392 .36184 Metetra
.472 .291 .554 r
.56392 .36184 .56817 .44321 .57397 .40854 .57033 .37741 Metetra
.196 .129 .549 r
.57033 .37741 .57397 .40854 .57969 .37566 .5769 .39832 Metetra
.721 .419 .467 r
.5769 .39832 .57969 .37566 .58554 .35552 .58354 .41696 Metetra
.59 .339 .504 r
.58354 .41696 .58554 .35552 .59171 .35292 .59008 .42647 Metetra
.526 .291 .502 r
.59008 .42647 .59171 .35292 .59824 .36569 .59641 .42323 Metetra
.436 .213 .477 r
.59641 .42323 .59824 .36569 .60504 .38616 .60246 .40813 Metetra
0 0 .25 r
.60246 .40813 .60504 .38616 .61188 .40438 .60829 .38598 Metetra
.802 .585 .608 r
.60829 .38598 .61188 .40438 .61851 .41221 .61405 .36335 Metetra
.657 .442 .581 r
.61405 .36335 .61851 .41221 .62478 .40648 .61989 .34615 Metetra
.597 .392 .574 r
.61989 .34615 .62478 .40648 .63069 .38984 .62598 .33778 Metetra
.546 .358 .578 r
.62598 .33778 .63069 .38984 .6364 .36871 .63236 .33856 Metetra
.454 .316 .603 r
.63236 .33856 .6364 .36871 .64213 .35005 .63901 .34598 Metetra
.638 .183 0 r
.63901 .34598 .64213 .35005 .6481 .33863 .64581 .35591 Metetra
.65 .337 .428 r
.64581 .35591 .6481 .33863 .6544 .33586 .6526 .36404 Metetra
.571 .295 .459 r
.6526 .36404 .6544 .33586 .66101 .33996 .65924 .36733 Metetra
.5 .236 .445 r
.65924 .36733 .66101 .33996 .6678 .34724 .66566 .3648 Metetra
.352 .085 .362 r
.66566 .3648 .6678 .34724 .6746 .35371 .67188 .3575 Metetra
.672 .849 .441 r
.67188 .3575 .6746 .35371 .68127 .3565 .67797 .34777 Metetra
.796 .648 .699 r
.67797 .34777 .68127 .3565 .68774 .35465 .68405 .3382 Metetra
.686 .518 .653 r
.68405 .3382 .68774 .35465 .69403 .349 .69023 .33075 Metetra
.634 .476 .651 r
.69023 .33075 .69403 .349 .70021 .34146 .69656 .32629 Metetra
.594 .467 .677 r
.69656 .32629 .70021 .34146 .70639 .33409 .70306 .32465 Metetra
.546 .503 .759 r
.70306 .32465 .70639 .33409 .71267 .32836 .70969 .3249 Metetra
.367 .634 .957 r
.70969 .3249 .71267 .32836 .71908 .32483 .71638 .32583 Metetra
.252 0 0 r
.71638 .32583 .71908 .32483 .72562 .32327 .72308 .32638 Metetra
.323 0 0 r
.72308 .32638 .72562 .32327 .73226 .3229 .72974 .32588 Metetra
.182 0 0 r
.72974 .32588 .73226 .3229 .73894 .32283 .73633 .32417 Metetra
.73633 .32417 .73894 .32283 .74562 .32237 .74288 .32147 Metetra
.666 .95 .955 r
.74288 .32147 .74562 .32237 .75227 .32112 .7494 .3182 Metetra
.735 .837 .928 r
.7494 .3182 .75227 .32112 .75888 .31906 .75592 .31481 Metetra
.714 .752 .882 r
.75592 .31481 .75888 .31906 .76545 .3164 .76247 .31163 Metetra
.69 .717 .87 r
.76247 .31163 .76545 .3164 .77202 .31346 .76906 .30882 Metetra
.671 .717 .883 r
.76906 .30882 .77202 .31346 .7786 .31051 .77569 .30642 Metetra
.656 .74 .911 r
.77569 .30642 .7786 .31051 .78521 .30775 .78236 .3043 Metetra
.642 .774 .944 r
.78236 .3043 .78521 .30775 .79185 .30525 .78907 .30235 Metetra
.63 .808 .968 r
.78907 .30235 .79185 .30525 .79853 .30298 .79579 .30042 Metetra
.625 .831 .98 r
.79579 .30042 .79853 .30298 .80523 .30086 .80252 .29844 Metetra
.629 .843 .982 r
.80252 .29844 .80523 .30086 .81196 .29881 .80926 .29634 Metetra
.639 .845 .979 r
.80926 .29634 .81196 .29881 .81871 .29675 .81601 .29414 Metetra
.65 .839 .973 r
.81601 .29414 .81871 .29675 .82547 .29463 .82277 .29186 Metetra
.657 .83 .966 r
.82277 .29186 .82547 .29463 .83223 .29245 .82954 .28952 Metetra
.661 .821 .961 r
.82954 .28952 .83223 .29245 .83901 .2902 .83632 .28716 Metetra
.662 .815 .957 r
.83632 .28716 .83901 .2902 .8458 .2879 .84312 .28481 Metetra
.661 .811 .955 r
.84312 .28481 .8458 .2879 .8526 .28558 .84993 .28246 Metetra
.66 .81 .955 r
.84993 .28246 .8526 .28558 .85942 .28325 .85676 .28014 Metetra
.654 .796 .95 r
.24576 .47934 .2495 .48187 .255 .48009 .25126 .47755 Metetra
.654 .795 .95 r
.25126 .47755 .255 .48009 .26051 .47831 .25678 .47576 Metetra
.653 .796 .951 r
.25678 .47576 .26051 .47831 .26603 .47651 .26231 .47398 Metetra
.653 .797 .952 r
.26231 .47398 .26603 .47651 .27157 .47469 .26785 .47219 Metetra
.653 .799 .953 r
.26785 .47219 .27157 .47469 .27711 .47285 .2734 .47039 Metetra
.655 .803 .954 r
.2734 .47039 .27711 .47285 .28268 .47096 .27897 .46855 Metetra
.658 .808 .955 r
.27897 .46855 .28268 .47096 .28825 .46905 .28455 .46667 Metetra
.662 .811 .955 r
.28455 .46667 .28825 .46905 .29384 .46713 .29015 .46472 Metetra
.666 .811 .953 r
.29015 .46472 .29384 .46713 .29944 .46524 .29576 .46274 Metetra
.666 .805 .949 r
.29576 .46274 .29944 .46524 .30504 .46344 .30138 .46076 Metetra
.661 .792 .944 r
.30138 .46076 .30504 .46344 .31064 .46178 .30701 .45886 Metetra
.649 .774 .939 r
.30701 .45886 .31064 .46178 .31625 .46025 .31264 .45712 Metetra
.632 .756 .937 r
.31264 .45712 .31625 .46025 .32187 .45882 .31827 .45562 Metetra
.613 .746 .94 r
.31827 .45562 .32187 .45882 .3275 .45733 .3239 .45434 Metetra
.601 .756 .953 r
.3239 .45434 .3275 .45733 .33316 .45561 .32953 .45315 Metetra
.604 .795 .973 r
.32953 .45315 .33316 .45561 .33886 .45344 .33519 .45179 Metetra
.63 .86 .986 r
.33519 .45179 .33886 .45344 .3446 .45074 .34089 .44992 Metetra
.68 .924 .972 r
.34089 .44992 .3446 .45074 .35037 .44761 .34665 .44724 Metetra
.742 .956 .943 r
.34665 .44724 .35037 .44761 .35615 .4444 .35246 .44369 Metetra
.791 .937 .925 r
.35246 .44369 .35615 .4444 .36191 .44168 .35831 .43961 Metetra
.779 .85 .905 r
.35831 .43961 .36191 .44168 .36764 .44006 .36415 .43577 Metetra
.691 .711 .864 r
.36415 .43577 .36764 .44006 .3733 .43994 .36993 .43326 Metetra
.558 .564 .816 r
.36993 .43326 .3733 .43994 .37892 .44122 .37562 .43308 Metetra
.396 .432 .78 r
.37562 .43308 .37892 .44122 .38454 .44315 .3812 .43563 Metetra
.176 .314 .766 r
.3812 .43563 .38454 .44315 .39021 .44442 .38673 .44022 Metetra
0 .176 .696 r
.38673 .44022 .39021 .44442 .39598 .44352 .39229 .44492 Metetra
.518 0 0 r
.39229 .44492 .39598 .44352 .4019 .4394 .39798 .44697 Metetra
.283 0 .147 r
.39798 .44697 .4019 .4394 .40794 .43207 .4039 .4438 Metetra
.018 0 .129 r
.4039 .4438 .40794 .43207 .41403 .42294 .41004 .43444 Metetra
.41004 .43444 .41403 .42294 .42008 .41461 .41632 .42058 Metetra
.869 .908 .499 r
.41632 .42058 .42008 .41461 .42601 .40999 .42257 .40666 Metetra
.861 .78 .77 r
.42257 .40666 .42601 .40999 .43177 .41126 .42861 .39862 Metetra
.445 .386 .698 r
.42861 .39862 .43177 .41126 .43738 .41881 .43433 .40173 Metetra
0 0 .494 r
.43433 .40173 .43738 .41881 .44294 .43069 .43974 .41815 Metetra
.849 .55 .016 r
.43974 .41815 .44294 .43069 .44855 .4429 .44496 .44518 Metetra
.911 .577 .397 r
.44496 .44518 .44855 .4429 .45432 .45052 .45024 .47486 Metetra
.729 .437 .484 r
.45024 .47486 .45432 .45052 .46031 .44963 .45583 .49599 Metetra
.558 .306 .489 r
.45583 .49599 .46031 .44963 .46649 .43907 .46187 .49863 Metetra
.396 .179 .463 r
.46187 .49863 .46649 .43907 .47277 .42126 .46831 .47955 Metetra
.223 .042 .411 r
.46831 .47955 .47277 .42126 .47902 .40153 .47494 .44507 Metetra
.032 0 .326 r
.47494 .44507 .47902 .40153 .48518 .38624 .48148 .40907 Metetra
0 0 .219 r
.48148 .40907 .48518 .38624 .49119 .3806 .48774 .38729 Metetra
.633 .247 .295 r
.48774 .38729 .49119 .3806 .4971 .38692 .49369 .39124 Metetra
.904 .572 .406 r
.49369 .39124 .4971 .38692 .50298 .40377 .49945 .42402 Metetra
.855 .555 .48 r
.49945 .42402 .50298 .40377 .50892 .42612 .50523 .47819 Metetra
.765 .487 .513 r
.50523 .47819 .50892 .42612 .51497 .44667 .51122 .53649 Metetra
.665 .408 .523 r
.51122 .53649 .51497 .44667 .52113 .4581 .51749 .57677 Metetra
.557 .323 .516 r
.51749 .57677 .52113 .4581 .52735 .45578 .52394 .58166 Metetra
.433 .225 .496 r
.52394 .58166 .52735 .45578 .53354 .43965 .53037 .54821 Metetra
.279 .103 .455 r
.53037 .54821 .53354 .43965 .53965 .41434 .53661 .48985 Metetra
.081 0 .381 r
.53661 .48985 .53965 .41434 .54567 .38739 .54264 .42899 Metetra
0 0 .279 r
.54264 .42899 .54567 .38739 .55166 .36658 .54859 .38635 Metetra
.208 0 .323 r
.54859 .38635 .55166 .36658 .55772 .35745 .55467 .37389 Metetra
.753 .437 .449 r
.55467 .37389 .55772 .35745 .56392 .36184 .56108 .39233 Metetra
.781 .486 .489 r
.56108 .39233 .56392 .36184 .57033 .37741 .56786 .43186 Metetra
.724 .449 .509 r
.56786 .43186 .57033 .37741 .5769 .39832 .57487 .47522 Metetra
.646 .389 .515 r
.57487 .47522 .5769 .39832 .58354 .41696 .58182 .50371 Metetra
.547 .31 .508 r
.58182 .50371 .58354 .41696 .59008 .42647 .58839 .50493 Metetra
.398 .191 .478 r
.58839 .50493 .59008 .42647 .59641 .42323 .59439 .47827 Metetra
.106 0 .382 r
.59439 .47827 .59641 .42323 .60246 .40813 .59991 .43407 Metetra
.59991 .43407 .60246 .40813 .60829 .38598 .60522 .38752 Metetra
.995 .787 .511 r
.60522 .38752 .60829 .38598 .61405 .36335 .61066 .35176 Metetra
.834 .635 .633 r
.61066 .35176 .61405 .36335 .61989 .34615 .6165 .33386 Metetra
.553 .464 .709 r
.6165 .33386 .61989 .34615 .62598 .33778 .62284 .33401 Metetra
.794 .348 0 r
.62284 .33401 .62598 .33778 .63236 .33856 .62964 .34693 Metetra
.811 .452 .377 r
.62964 .34693 .63236 .33856 .63901 .34598 .63666 .36438 Metetra
.704 .389 .441 r
.63666 .36438 .63901 .34598 .64581 .35591 .64365 .37822 Metetra
.596 .303 .442 r
.64365 .37822 .64581 .35591 .6526 .36404 .65037 .38317 Metetra
.422 .147 .389 r
.65037 .38317 .6526 .36404 .65924 .36733 .65672 .37811 Metetra
0 0 .101 r
.65672 .37811 .65924 .36733 .66566 .3648 .66275 .36564 Metetra
.987 .897 .62 r
.66275 .36564 .66566 .3648 .67188 .3575 .66863 .35026 Metetra
.867 .698 .671 r
.66863 .35026 .67188 .3575 .67797 .34777 .67453 .33633 Metetra
.761 .598 .676 r
.67453 .33633 .67797 .34777 .68405 .3382 .68061 .32665 Metetra
.675 .548 .703 r
.68061 .32665 .68405 .3382 .69023 .33075 .68693 .32205 Metetra
.57 .531 .772 r
.68693 .32205 .69023 .33075 .69656 .32629 .69349 .32165 Metetra
.327 .537 .904 r
.69349 .32165 .69656 .32629 .70306 .32465 .7002 .32364 Metetra
.238 0 0 r
.7002 .32364 .70306 .32465 .70969 .3249 .70696 .32604 Metetra
.368 0 0 r
.70696 .32604 .70969 .3249 .71638 .32583 .7137 .32737 Metetra
.177 0 0 r
.7137 .32737 .71638 .32583 .72308 .32638 .72036 .32692 Metetra
.302 .792 .756 r
.72036 .32692 .72308 .32638 .72974 .32588 .72692 .3247 Metetra
.702 .944 .959 r
.72692 .3247 .72974 .32588 .73633 .32417 .73342 .32127 Metetra
.764 .845 .912 r
.73342 .32127 .73633 .32417 .74288 .32147 .7399 .31734 Metetra
.744 .768 .872 r
.7399 .31734 .74288 .32147 .7494 .3182 .74639 .31351 Metetra
.716 .731 .863 r
.74639 .31351 .7494 .3182 .75592 .31481 .75293 .31017 Metetra
.688 .724 .877 r
.75293 .31017 .75592 .31481 .76247 .31163 .75952 .30743 Metetra
.663 .737 .905 r
.75952 .30743 .76247 .31163 .76906 .30882 .76616 .3052 Metetra
.64 .762 .937 r
.76616 .3052 .76906 .30882 .77569 .30642 .77285 .30329 Metetra
.624 .79 .961 r
.77285 .30329 .77569 .30642 .78236 .3043 .77956 .3015 Metetra
.62 .811 .974 r
.77956 .3015 .78236 .3043 .78907 .30235 .78629 .29966 Metetra
.627 .823 .976 r
.78629 .29966 .78907 .30235 .79579 .30042 .79302 .29768 Metetra
.641 .825 .971 r
.79302 .29768 .79579 .30042 .80252 .29844 .79976 .29555 Metetra
.654 .821 .963 r
.79976 .29555 .80252 .29844 .80926 .29634 .8065 .29329 Metetra
.662 .813 .955 r
.8065 .29329 .80926 .29634 .81601 .29414 .81325 .29094 Metetra
.666 .805 .949 r
.81325 .29094 .81601 .29414 .82277 .29186 .82001 .28856 Metetra
.667 .799 .945 r
.82001 .28856 .82277 .29186 .82954 .28952 .82679 .28617 Metetra
.666 .796 .944 r
.82679 .28617 .82954 .28952 .83632 .28716 .83358 .28381 Metetra
.664 .795 .945 r
.83358 .28381 .83632 .28716 .84312 .28481 .84039 .28146 Metetra
.662 .795 .946 r
.84039 .28146 .84312 .28481 .84993 .28246 .84723 .27914 Metetra
.66 .797 .948 r
.84723 .27914 .84993 .28246 .85676 .28014 .85407 .27683 Metetra
.657 .78 .939 r
.24202 .47655 .24576 .47934 .25126 .47755 .24753 .47474 Metetra
.657 .779 .939 r
.24753 .47474 .25126 .47755 .25678 .47576 .25306 .47293 Metetra
.657 .778 .938 r
.25306 .47293 .25678 .47576 .26231 .47398 .25859 .47113 Metetra
.657 .777 .938 r
.25859 .47113 .26231 .47398 .26785 .47219 .26414 .46932 Metetra
.656 .776 .937 r
.26414 .46932 .26785 .47219 .2734 .47039 .2697 .46752 Metetra
.656 .777 .938 r
.2697 .46752 .2734 .47039 .27897 .46855 .27527 .46571 Metetra
.657 .779 .939 r
.27527 .46571 .27897 .46855 .28455 .46667 .28086 .46389 Metetra
.658 .784 .941 r
.28086 .46389 .28455 .46667 .29015 .46472 .28646 .46204 Metetra
.66 .791 .945 r
.28646 .46204 .29015 .46472 .29576 .46274 .29207 .46016 Metetra
.662 .799 .948 r
.29207 .46016 .29576 .46274 .30138 .46076 .2977 .45824 Metetra
.663 .804 .95 r
.2977 .45824 .30138 .46076 .30701 .45886 .30334 .45629 Metetra
.662 .801 .949 r
.30334 .45629 .30701 .45886 .31264 .45712 .30899 .45435 Metetra
.658 .787 .943 r
.30899 .45435 .31264 .45712 .31827 .45562 .31465 .45248 Metetra
.651 .762 .93 r
.31465 .45248 .31827 .45562 .3239 .45434 .32031 .45072 Metetra
.643 .731 .913 r
.32031 .45072 .3239 .45434 .32953 .45315 .32598 .4491 Metetra
.636 .705 .896 r
.32598 .4491 .32953 .45315 .33519 .45179 .33165 .44758 Metetra
.637 .697 .889 r
.33165 .44758 .33519 .45179 .34089 .44992 .33734 .44605 Metetra
.648 .72 .9 r
.33734 .44605 .34089 .44992 .34665 .44724 .34305 .44434 Metetra
.672 .784 .934 r
.34305 .44434 .34665 .44724 .35246 .44369 .3488 .44227 Metetra
.686 .889 .972 r
.3488 .44227 .35246 .44369 .35831 .43961 .35458 .43975 Metetra
.621 .951 .929 r
.35458 .43975 .35831 .43961 .36415 .43577 .36038 .43686 Metetra
.486 .898 .805 r
.36038 .43686 .36415 .43577 .36993 .43326 .3662 .43391 Metetra
.478 .897 .854 r
.3662 .43391 .36993 .43326 .37562 .43308 .37201 .43139 Metetra
.595 .851 .993 r
.37201 .43139 .37562 .43308 .3812 .43563 .37779 .42978 Metetra
.569 .599 .844 r
.37779 .42978 .3812 .43563 .38673 .44022 .38353 .42935 Metetra
.537 .467 .724 r
.38353 .42935 .38673 .44022 .39229 .44492 .38925 .42986 Metetra
.538 .426 .674 r
.38925 .42986 .39229 .44492 .39798 .44697 .39498 .43056 Metetra
.563 .434 .663 r
.39498 .43056 .39798 .44697 .4039 .4438 .40077 .4303 Metetra
.616 .49 .685 r
.40077 .4303 .4039 .4438 .41004 .43444 .40665 .428 Metetra
.738 .656 .769 r
.40665 .428 .41004 .43444 .41632 .42058 .41263 .42324 Metetra
.733 .962 .684 r
.41263 .42324 .41632 .42058 .42257 .40666 .41868 .41666 Metetra
.125 0 .143 r
.41868 .41666 .42257 .40666 .42861 .39862 .42472 .40996 Metetra
.313 0 .258 r
.42472 .40996 .42861 .39862 .43433 .40173 .43069 .40536 Metetra
.327 0 0 r
.43069 .40536 .43433 .40173 .43974 .41815 .43657 .40467 Metetra
.432 .37 .688 r
.43657 .40467 .43974 .41815 .44496 .44518 .44235 .40829 Metetra
.477 .318 .585 r
.44235 .40829 .44496 .44518 .45024 .47486 .44809 .41473 Metetra
.508 .323 .565 r
.44809 .41473 .45024 .47486 .45583 .49599 .45389 .42085 Metetra
.537 .341 .562 r
.45389 .42085 .45583 .49599 .46187 .49863 .45981 .42304 Metetra
.569 .365 .565 r
.45981 .42304 .46187 .49863 .46831 .47955 .46587 .41892 Metetra
.607 .4 .574 r
.46587 .41892 .46831 .47955 .47494 .44507 .47204 .4087 Metetra
.662 .456 .596 r
.47204 .4087 .47494 .44507 .48148 .40907 .47823 .39549 Metetra
.756 .577 .655 r
.47823 .39549 .48148 .40907 .48774 .38729 .48438 .38407 Metetra
.811 .799 .84 r
.48438 .38407 .48774 .38729 .49369 .39124 .49043 .37881 Metetra
.453 .396 .704 r
.49043 .37881 .49369 .39124 .49945 .42402 .49641 .38174 Metetra
.452 .294 .575 r
.49641 .38174 .49945 .42402 .50523 .47819 .50238 .39142 Metetra
.492 .303 .552 r
.50238 .39142 .50523 .47819 .51122 .53649 .50839 .40331 Metetra
.523 .321 .547 r
.50839 .40331 .51122 .53649 .51749 .57677 .51449 .41156 Metetra
.547 .337 .547 r
.51449 .41156 .51749 .57677 .52394 .58166 .52064 .41162 Metetra
.567 .352 .549 r
.52064 .41162 .52394 .58166 .53037 .54821 .52681 .40248 Metetra
.585 .368 .552 r
.52681 .40248 .53037 .54821 .53661 .48985 .53296 .38721 Metetra
.601 .384 .559 r
.53296 .38721 .53661 .48985 .54264 .42899 .53906 .37148 Metetra
.611 .403 .575 r
.53906 .37148 .54264 .42899 .54859 .38635 .54516 .36091 Metetra
.585 .417 .62 r
.54516 .36091 .54859 .38635 .55467 .37389 .55131 .35868 Metetra
.381 .323 .668 r
.55131 .35868 .55467 .37389 .56108 .39233 .55755 .36442 Metetra
.389 .273 .598 r
.55755 .36442 .56108 .39233 .56786 .43186 .56389 .37449 Metetra
.485 .309 .567 r
.56389 .37449 .56786 .43186 .57487 .47522 .57028 .38366 Metetra
.533 .334 .557 r
.57028 .38366 .57487 .47522 .58182 .50371 .57664 .38736 Metetra
.559 .351 .554 r
.57664 .38736 .58182 .50371 .58839 .50493 .5829 .38363 Metetra
.576 .363 .554 r
.5829 .38363 .58839 .50493 .59439 .47827 .58904 .37374 Metetra
.589 .375 .558 r
.58904 .37374 .59439 .47827 .59991 .43407 .59512 .36131 Metetra
.599 .389 .567 r
.59512 .36131 .59991 .43407 .60522 .38752 .6012 .35047 Metetra
.608 .415 .595 r
.6012 .35047 .60522 .38752 .61066 .35176 .60738 .34415 Metetra
.596 .568 .793 r
.60738 .34415 .61066 .35176 .6165 .33386 .61371 .34314 Metetra
.59 .228 .323 r
.61371 .34314 .6165 .33386 .62284 .33401 .62018 .34615 Metetra
.614 .277 .375 r
.62018 .34615 .62284 .33401 .62964 .34693 .62673 .35062 Metetra
.602 .136 .119 r
.62673 .35062 .62964 .34693 .63666 .36438 .63328 .35387 Metetra
.546 .485 .738 r
.63328 .35387 .63666 .36438 .64365 .37822 .63975 .35415 Metetra
.597 .43 .626 r
.63975 .35415 .64365 .37822 .65037 .38317 .64613 .35111 Metetra
.609 .422 .604 r
.64613 .35111 .65037 .38317 .65672 .37811 .65242 .34569 Metetra
.615 .426 .603 r
.65242 .34569 .65672 .37811 .66275 .36564 .65868 .33943 Metetra
.622 .442 .618 r
.65868 .33943 .66275 .36564 .66863 .35026 .66497 .33387 Metetra
.633 .485 .663 r
.66497 .33387 .66863 .35026 .67453 .33633 .67133 .32991 Metetra
.65 .632 .819 r
.67133 .32991 .67453 .33633 .68061 .32665 .67778 .32773 Metetra
.041 0 0 r
.67778 .32773 .68061 .32665 .68693 .32205 .68432 .32688 Metetra
.413 0 .085 r
.68432 .32688 .68693 .32205 .69349 .32165 .69091 .32658 Metetra
.404 0 .086 r
.69091 .32658 .69349 .32165 .7002 .32364 .69751 .3261 Metetra
.19 0 0 r
.69751 .3261 .7002 .32364 .70696 .32604 .70409 .32495 Metetra
.533 .889 .979 r
.70409 .32495 .70696 .32604 .7137 .32737 .71065 .323 Metetra
.684 .733 .888 r
.71065 .323 .7137 .32737 .72036 .32692 .71718 .32039 Metetra
.679 .645 .809 r
.71718 .32039 .72036 .32692 .72692 .3247 .72371 .31744 Metetra
.672 .621 .79 r
.72371 .31744 .72692 .3247 .73342 .32127 .73024 .31445 Metetra
.67 .632 .804 r
.73024 .31445 .73342 .32127 .7399 .31734 .7368 .31165 Metetra
.669 .67 .842 r
.7368 .31165 .7399 .31734 .74639 .31351 .74339 .30914 Metetra
.663 .727 .897 r
.74339 .30914 .74639 .31351 .75293 .31017 .75002 .30689 Metetra
.648 .788 .949 r
.75002 .30689 .75293 .31017 .75952 .30743 .75668 .30483 Metetra
.629 .828 .977 r
.75668 .30483 .75952 .30743 .76616 .3052 .76335 .30283 Metetra
.622 .843 .984 r
.76335 .30283 .76616 .3052 .77285 .30329 .77004 .3008 Metetra
.633 .839 .98 r
.77004 .3008 .77285 .30329 .77956 .3015 .77675 .2987 Metetra
.648 .823 .967 r
.77675 .2987 .77956 .3015 .78629 .29966 .78346 .2965 Metetra
.659 .803 .952 r
.78346 .2965 .78629 .29966 .79302 .29768 .79018 .29422 Metetra
.665 .786 .938 r
.79018 .29422 .79302 .29768 .79976 .29555 .79691 .29189 Metetra
.667 .775 .93 r
.79691 .29189 .79976 .29555 .8065 .29329 .80366 .28954 Metetra
.667 .77 .926 r
.80366 .28954 .8065 .29329 .81325 .29094 .81042 .28719 Metetra
.666 .769 .927 r
.81042 .28719 .81325 .29094 .82001 .28856 .8172 .28485 Metetra
.665 .772 .93 r
.8172 .28485 .82001 .28856 .82679 .28617 .82399 .28252 Metetra
.663 .776 .933 r
.82399 .28252 .82679 .28617 .83358 .28381 .83081 .28021 Metetra
.662 .78 .936 r
.83081 .28021 .83358 .28381 .84039 .28146 .83764 .2779 Metetra
.662 .782 .938 r
.83764 .2779 .84039 .28146 .84723 .27914 .84449 .27559 Metetra
.662 .784 .939 r
.84449 .27559 .84723 .27914 .85407 .27683 .85135 .27327 Metetra
.659 .762 .926 r
.23828 .47346 .24202 .47655 .24753 .47474 .2438 .47164 Metetra
.66 .762 .925 r
.2438 .47164 .24753 .47474 .25306 .47293 .24934 .46981 Metetra
.66 .761 .925 r
.24934 .46981 .25306 .47293 .25859 .47113 .25488 .46798 Metetra
.66 .76 .924 r
.25488 .46798 .25859 .47113 .26414 .46932 .26044 .46614 Metetra
.659 .758 .923 r
.26044 .46614 .26414 .46932 .2697 .46752 .26601 .46431 Metetra
.658 .757 .923 r
.26601 .46431 .2697 .46752 .27527 .46571 .27159 .4625 Metetra
.656 .756 .924 r
.27159 .4625 .27527 .46571 .28086 .46389 .27718 .46071 Metetra
.653 .758 .927 r
.27718 .46071 .28086 .46389 .28646 .46204 .28278 .45895 Metetra
.652 .764 .931 r
.28278 .45895 .28646 .46204 .29207 .46016 .28839 .4572 Metetra
.652 .773 .937 r
.28839 .4572 .29207 .46016 .2977 .45824 .29401 .45543 Metetra
.657 .784 .942 r
.29401 .45543 .2977 .45824 .30334 .45629 .29966 .45357 Metetra
.667 .793 .942 r
.29966 .45357 .30334 .45629 .30899 .45435 .30532 .45158 Metetra
.679 .792 .935 r
.30532 .45158 .30899 .45435 .31465 .45248 .311 .44943 Metetra
.688 .777 .919 r
.311 .44943 .31465 .45248 .32031 .45072 .31671 .44715 Metetra
.687 .746 .896 r
.31671 .44715 .32031 .45072 .32598 .4491 .32243 .44484 Metetra
.672 .706 .873 r
.32243 .44484 .32598 .4491 .33165 .44758 .32814 .44271 Metetra
.645 .67 .859 r
.32814 .44271 .33165 .44758 .33734 .44605 .33384 .441 Metetra
.609 .648 .864 r
.33384 .441 .33734 .44605 .34305 .44434 .33953 .4399 Metetra
.56 .658 .902 r
.33953 .4399 .34305 .44434 .3488 .44227 .34519 .43941 Metetra
.474 .722 .978 r
.34519 .43941 .3488 .44227 .35458 .43975 .35085 .43921 Metetra
.242 .745 .893 r
.35085 .43921 .35458 .43975 .36038 .43686 .35655 .43871 Metetra
.35655 .43871 .36038 .43686 .3662 .43391 .36232 .4371 Metetra
.36232 .4371 .3662 .43391 .37201 .43139 .36819 .43371 Metetra
.657 .949 .715 r
.36819 .43371 .37201 .43139 .37779 .42978 .37416 .42842 Metetra
.873 .878 .836 r
.37416 .42842 .37779 .42978 .38353 .42935 .38018 .42195 Metetra
.75 .639 .738 r
.38018 .42195 .38353 .42935 .38925 .42986 .38617 .41597 Metetra
.636 .499 .679 r
.38617 .41597 .38925 .42986 .39498 .43056 .39206 .41263 Metetra
.528 .401 .652 r
.39206 .41263 .39498 .43056 .40077 .4303 .39777 .41385 Metetra
.354 .291 .646 r
.39777 .41385 .40077 .4303 .40665 .428 .40331 .42025 Metetra
0 0 .449 r
.40331 .42025 .40665 .428 .41263 .42324 .40876 .43043 Metetra
.757 .401 .38 r
.40876 .43043 .41263 .42324 .41868 .41666 .41426 .44082 Metetra
.605 .321 .46 r
.41426 .44082 .41868 .41666 .42472 .40996 .41997 .44653 Metetra
.5 .247 .462 r
.41997 .44653 .42472 .40996 .43069 .40536 .42598 .44337 Metetra
.37 .14 .429 r
.42598 .44337 .43069 .40536 .43657 .40467 .4323 .4301 Metetra
.034 0 .27 r
.4323 .4301 .43657 .40467 .44235 .40829 .43876 .40991 Metetra
.986 .844 .616 r
.43876 .40991 .44235 .40829 .44809 .41473 .44517 .38997 Metetra
.683 .488 .617 r
.44517 .38997 .44809 .41473 .45389 .42085 .45133 .37895 Metetra
.503 .331 .581 r
.45133 .37895 .45389 .42085 .45981 .42304 .45712 .38375 Metetra
.227 .129 .53 r
.45712 .38375 .45981 .42304 .46587 .41892 .46261 .40647 Metetra
.93 .621 .157 r
.46261 .40647 .46587 .41892 .47204 .4087 .46798 .44255 Metetra
.764 .478 .501 r
.46798 .44255 .47204 .4087 .47823 .39549 .47346 .48093 Metetra
.632 .381 .519 r
.47346 .48093 .47823 .39549 .48438 .38407 .47927 .50716 Metetra
.548 .316 .515 r
.47927 .50716 .48438 .38407 .49043 .37881 .48548 .50953 Metetra
.468 .251 .501 r
.48548 .50953 .49043 .37881 .49641 .38174 .49199 .4854 Metetra
.353 .157 .47 r
.49199 .4854 .49641 .38174 .50238 .39142 .49857 .44353 Metetra
.036 0 .34 r
.49857 .44353 .50238 .39142 .50839 .40331 .50503 .40015 Metetra
.951 .747 .591 r
.50503 .40015 .50839 .40331 .51449 .41156 .51127 .37187 Metetra
.573 .386 .59 r
.51127 .37187 .51449 .41156 .52064 .41162 .51737 .36946 Metetra
.23 .132 .531 r
.51737 .36946 .52064 .41162 .52681 .40248 .52347 .39453 Metetra
.965 .638 .273 r
.52347 .39453 .52681 .40248 .53296 .38721 .52972 .43884 Metetra
.741 .463 .509 r
.52972 .43884 .53296 .38721 .53906 .37148 .53617 .48615 Metetra
.623 .376 .522 r
.53617 .48615 .53906 .37148 .54516 .36091 .54274 .51759 Metetra
.547 .317 .518 r
.54274 .51759 .54516 .36091 .55131 .35868 .54924 .51973 Metetra
.474 .26 .507 r
.54924 .51973 .55131 .35868 .55755 .36442 .55549 .49121 Metetra
.375 .18 .483 r
.55549 .49121 .55755 .36442 .56389 .37449 .56143 .44302 Metetra
.137 0 .398 r
.56143 .44302 .56389 .37449 .57028 .38366 .56717 .39223 Metetra
.985 .814 .419 r
.56717 .39223 .57028 .38366 .57664 .38736 .57292 .35423 Metetra
.692 .48 .596 r
.57292 .35423 .57664 .38736 .5829 .38363 .57892 .33765 Metetra
.504 .33 .578 r
.57892 .33765 .5829 .38363 .58904 .37374 .58529 .34301 Metetra
.192 .127 .549 r
.58529 .34301 .58904 .37374 .59512 .36131 .59203 .3638 Metetra
.906 .539 .328 r
.59203 .3638 .59512 .36131 .6012 .35047 .59898 .38925 Metetra
.668 .389 .489 r
.59898 .38925 .6012 .35047 .60738 .34415 .60589 .40822 Metetra
.565 .317 .499 r
.60589 .40822 .60738 .34415 .61371 .34314 .61253 .41329 Metetra
.485 .256 .491 r
.61253 .41329 .61371 .34314 .62018 .34615 .61877 .40319 Metetra
.383 .171 .463 r
.61877 .40319 .62018 .34615 .62673 .35062 .62466 .38231 Metetra
.138 0 .358 r
.62466 .38231 .62673 .35062 .63328 .35387 .63037 .35797 Metetra
.973 .873 .49 r
.63037 .35797 .63328 .35387 .63975 .35415 .63613 .33708 Metetra
.746 .553 .634 r
.63613 .33708 .63975 .35415 .64613 .35111 .64211 .32394 Metetra
.607 .429 .615 r
.64211 .32394 .64613 .35111 .65242 .34569 .64841 .31953 Metetra
.517 .369 .619 r
.64841 .31953 .65242 .34569 .65868 .33943 .655 .32205 Metetra
.404 .327 .656 r
.655 .32205 .65868 .33943 .66497 .33387 .66178 .32813 Metetra
0 .237 .752 r
.66178 .32813 .66497 .33387 .67133 .32991 .6686 .33422 Metetra
.608 .154 .15 r
.6686 .33422 .67133 .32991 .67778 .32773 .67536 .33768 Metetra
.488 .138 .298 r
.67536 .33768 .67778 .32773 .68432 .32688 .68196 .33744 Metetra
.367 .04 .273 r
.68196 .33744 .68432 .32688 .69091 .32658 .68842 .33383 Metetra
.129 0 .091 r
.68842 .33383 .69091 .32658 .69751 .3261 .69477 .32815 Metetra
.604 .898 .61 r
.69477 .32815 .69751 .3261 .70409 .32495 .70109 .32192 Metetra
.827 .843 .859 r
.70109 .32192 .70409 .32495 .71065 .323 .70745 .31636 Metetra
.72 .661 .79 r
.70745 .31636 .71065 .323 .71718 .32039 .7139 .31215 Metetra
.657 .591 .769 r
.7139 .31215 .71718 .32039 .72371 .31744 .72043 .30936 Metetra
.62 .575 .782 r
.72043 .30936 .72371 .31744 .73024 .31445 .72705 .30766 Metetra
.6 .599 .822 r
.72705 .30766 .73024 .31445 .7368 .31165 .73373 .30653 Metetra
.593 .66 .884 r
.73373 .30653 .7368 .31165 .74339 .30914 .74043 .30548 Metetra
.596 .742 .946 r
.74043 .30548 .74339 .30914 .75002 .30689 .74714 .30417 Metetra
.607 .812 .978 r
.74714 .30417 .75002 .30689 .75668 .30483 .75383 .30244 Metetra
.632 .846 .982 r
.75383 .30244 .75668 .30483 .76335 .30283 .76052 .30031 Metetra
.66 .848 .972 r
.76052 .30031 .76335 .30283 .77004 .3008 .76719 .29789 Metetra
.678 .827 .955 r
.76719 .29789 .77004 .3008 .77675 .2987 .77387 .29533 Metetra
.682 .798 .936 r
.77387 .29533 .77675 .2987 .78346 .2965 .78056 .29273 Metetra
.679 .772 .921 r
.78056 .29273 .78346 .2965 .79018 .29422 .78728 .2902 Metetra
.673 .756 .913 r
.78728 .2902 .79018 .29422 .79691 .29189 .79401 .28776 Metetra
.667 .748 .91 r
.79401 .28776 .79691 .29189 .80366 .28954 .80077 .28541 Metetra
.663 .746 .912 r
.80077 .28541 .80366 .28954 .81042 .28719 .80755 .28312 Metetra
.661 .749 .916 r
.80755 .28312 .81042 .28719 .8172 .28485 .81435 .28086 Metetra
.66 .755 .92 r
.81435 .28086 .8172 .28485 .82399 .28252 .82116 .2786 Metetra
.661 .76 .923 r
.82116 .2786 .82399 .28252 .83081 .28021 .828 .27634 Metetra
.662 .763 .925 r
.828 .27634 .83081 .28021 .83764 .2779 .83484 .27405 Metetra
.663 .765 .926 r
.83484 .27405 .83764 .2779 .84449 .27559 .8417 .27173 Metetra
.664 .766 .926 r
.8417 .27173 .84449 .27559 .85135 .27327 .84858 .2694 Metetra
.66 .743 .912 r
.23456 .47004 .23828 .47346 .2438 .47164 .24009 .46822 Metetra
.66 .743 .911 r
.24009 .46822 .2438 .47164 .24934 .46981 .24563 .46638 Metetra
.66 .743 .911 r
.24563 .46638 .24934 .46981 .25488 .46798 .25118 .46454 Metetra
.66 .743 .911 r
.25118 .46454 .25488 .46798 .26044 .46614 .25675 .4627 Metetra
.66 .743 .912 r
.25675 .4627 .26044 .46614 .26601 .46431 .26233 .46086 Metetra
.658 .743 .912 r
.26233 .46086 .26601 .46431 .27159 .4625 .26791 .45904 Metetra
.656 .742 .913 r
.26791 .45904 .27159 .4625 .27718 .46071 .27351 .45725 Metetra
.654 .742 .914 r
.27351 .45725 .27718 .46071 .28278 .45895 .27911 .45548 Metetra
.653 .741 .914 r
.27911 .45548 .28278 .45895 .28839 .4572 .28473 .45372 Metetra
.654 .742 .914 r
.28473 .45372 .28839 .4572 .29401 .45543 .29036 .45194 Metetra
.66 .743 .912 r
.29036 .45194 .29401 .45543 .29966 .45357 .29601 .45008 Metetra
.668 .745 .908 r
.29601 .45008 .29966 .45357 .30532 .45158 .30168 .44808 Metetra
.678 .748 .903 r
.30168 .44808 .30532 .45158 .311 .44943 .30737 .44592 Metetra
.686 .75 .9 r
.30737 .44592 .311 .44943 .31671 .44715 .31309 .44363 Metetra
.687 .75 .899 r
.31309 .44363 .31671 .44715 .32243 .44484 .31881 .44131 Metetra
.676 .747 .904 r
.31881 .44131 .32243 .44484 .32814 .44271 .32454 .43918 Metetra
.648 .739 .916 r
.32454 .43918 .32814 .44271 .33384 .441 .33025 .43746 Metetra
.599 .724 .932 r
.33025 .43746 .33384 .441 .33953 .4399 .33593 .43635 Metetra
.541 .703 .945 r
.33593 .43635 .33953 .4399 .34519 .43941 .3416 .43585 Metetra
.507 .689 .95 r
.3416 .43585 .34519 .43941 .35085 .43921 .34727 .43565 Metetra
.542 .703 .945 r
.34727 .43565 .35085 .43921 .35655 .43871 .35298 .43514 Metetra
.639 .738 .92 r
.35298 .43514 .35655 .43871 .36232 .4371 .35876 .43352 Metetra
.739 .762 .871 r
.35876 .43352 .36232 .4371 .36819 .43371 .36464 .43012 Metetra
.802 .769 .822 r
.36464 .43012 .36819 .43371 .37416 .42842 .37061 .42482 Metetra
.828 .769 .796 r
.37061 .42482 .37416 .42842 .38018 .42195 .37664 .41834 Metetra
.818 .769 .806 r
.37664 .41834 .38018 .42195 .38617 .41597 .38265 .41235 Metetra
.736 .76 .872 r
.38265 .41235 .38617 .41597 .39206 .41263 .38854 .40901 Metetra
.317 .593 .943 r
.38854 .40901 .39206 .41263 .39777 .41385 .39426 .41021 Metetra
.587 .091 0 r
.39426 .41021 .39777 .41385 .40331 .42025 .3998 .41661 Metetra
.825 .368 0 r
.3998 .41661 .40331 .42025 .40876 .43043 .40525 .4268 Metetra
.828 .372 0 r
.40525 .4268 .40876 .43043 .41426 .44082 .41074 .43719 Metetra
0 .008 .513 r
.41074 .43719 .41426 .44082 .41997 .44653 .41645 .44291 Metetra
.726 .764 .883 r
.41645 .44291 .41997 .44653 .42598 .44337 .42247 .43973 Metetra
.901 .761 .697 r
.42247 .43973 .42598 .44337 .4323 .4301 .42881 .42644 Metetra
.926 .746 .64 r
.42881 .42644 .4323 .4301 .43876 .40991 .4353 .40623 Metetra
.926 .746 .64 r
.4353 .40623 .43876 .40991 .44517 .38997 .44174 .38627 Metetra
.887 .765 .721 r
.44174 .38627 .44517 .38997 .45133 .37895 .44791 .37523 Metetra
0 .155 .664 r
.44791 .37523 .45133 .37895 .45712 .38375 .45371 .38003 Metetra
.941 .574 .247 r
.45371 .38003 .45712 .38375 .46261 .40647 .45918 .40276 Metetra
.956 .623 .337 r
.45918 .40276 .46261 .40647 .46798 .44255 .46451 .43886 Metetra
.957 .625 .342 r
.46451 .43886 .46798 .44255 .47346 .48093 .46996 .47728 Metetra
.945 .585 .268 r
.46996 .47728 .47346 .48093 .47927 .50716 .47575 .50353 Metetra
.132 .493 .904 r
.47575 .50353 .47927 .50716 .48548 .50953 .48196 .50589 Metetra
.94 .748 .617 r
.48196 .50589 .48548 .50953 .49199 .4854 .48851 .48173 Metetra
.954 .728 .558 r
.48851 .48173 .49199 .4854 .49857 .44353 .49514 .43982 Metetra
.954 .726 .553 r
.49514 .43982 .49857 .44353 .50503 .40015 .50165 .39639 Metetra
.946 .739 .593 r
.50165 .39639 .50503 .40015 .51127 .37187 .50793 .36808 Metetra
.685 .749 .901 r
.50793 .36808 .51127 .37187 .51737 .36946 .51404 .36566 Metetra
.941 .574 .231 r
.51404 .36566 .51737 .36946 .52347 .39453 .52012 .39075 Metetra
.96 .629 .333 r
.52012 .39075 .52347 .39453 .52972 .43884 .52633 .43509 Metetra
.96 .632 .337 r
.52633 .43509 .52972 .43884 .53617 .48615 .53273 .48244 Metetra
.949 .593 .268 r
.53273 .48244 .53617 .48615 .54274 .51759 .53928 .5139 Metetra
.189 .527 .921 r
.53928 .5139 .54274 .51759 .54924 .51973 .54578 .51604 Metetra
.952 .748 .59 r
.54578 .51604 .54924 .51973 .55549 .49121 .55207 .48749 Metetra
.963 .727 .534 r
.55207 .48749 .55549 .49121 .56143 .44302 .55807 .43924 Metetra
.963 .724 .528 r
.55807 .43924 .56143 .44302 .56717 .39223 .56387 .3884 Metetra
.96 .733 .552 r
.56387 .3884 .56717 .39223 .57292 .35423 .56967 .35035 Metetra
.929 .765 .657 r
.56967 .35035 .57292 .35423 .57892 .33765 .57569 .33375 Metetra
0 .167 .685 r
.57569 .33375 .57892 .33765 .58529 .34301 .58206 .33911 Metetra
.912 .518 .12 r
.58206 .33911 .58529 .34301 .59203 .3638 .58878 .35992 Metetra
.931 .554 .179 r
.58878 .35992 .59203 .3638 .59898 .38925 .59572 .38538 Metetra
.894 .487 .072 r
.59572 .38538 .59898 .38925 .60589 .40822 .60262 .40436 Metetra
0 .219 .725 r
.60262 .40436 .60589 .40822 .61253 .41329 .60927 .40943 Metetra
.89 .789 .742 r
.60927 .40943 .61253 .41329 .61877 .40319 .61552 .39931 Metetra
.947 .763 .621 r
.61552 .39931 .61877 .40319 .62466 .38231 .62144 .37841 Metetra
.954 .756 .596 r
.62144 .37841 .62466 .38231 .63037 .35797 .62718 .35404 Metetra
.948 .762 .617 r
.62718 .35404 .63037 .35797 .63613 .33708 .63297 .33312 Metetra
.918 .779 .692 r
.63297 .33312 .63613 .33708 .64211 .32394 .63897 .31996 Metetra
.771 .775 .856 r
.63897 .31996 .64211 .32394 .64841 .31953 .64528 .31554 Metetra
.194 .497 .905 r
.64528 .31554 .64841 .31953 .655 .32205 .65187 .31806 Metetra
0 .14 .666 r
.65187 .31806 .655 .32205 .66178 .32813 .65865 .32414 Metetra
0 .144 .67 r
.65865 .32414 .66178 .32813 .6686 .33422 .66548 .33022 Metetra
.068 .414 .863 r
.66548 .33022 .6686 .33422 .67536 .33768 .67224 .33368 Metetra
.516 .681 .941 r
.67224 .33368 .67536 .33768 .68196 .33744 .67886 .33343 Metetra
.737 .77 .88 r
.67886 .33343 .68196 .33744 .68842 .33383 .68532 .32981 Metetra
.811 .788 .831 r
.68532 .32981 .68842 .33383 .69477 .32815 .69169 .32411 Metetra
.826 .79 .818 r
.69169 .32411 .69477 .32815 .70109 .32192 .69802 .31787 Metetra
.807 .787 .834 r
.69802 .31787 .70109 .32192 .70745 .31636 .7044 .3123 Metetra
.761 .776 .865 r
.7044 .3123 .70745 .31636 .7139 .31215 .71085 .30808 Metetra
.696 .756 .898 r
.71085 .30808 .7139 .31215 .72043 .30936 .7174 .30528 Metetra
.63 .73 .92 r
.7174 .30528 .72043 .30936 .72705 .30766 .72403 .30357 Metetra
.589 .713 .929 r
.72403 .30357 .72705 .30766 .73373 .30653 .73072 .30243 Metetra
.583 .71 .93 r
.73072 .30243 .73373 .30653 .74043 .30548 .73743 .30137 Metetra
.602 .718 .926 r
.73743 .30137 .74043 .30548 .74714 .30417 .74415 .30005 Metetra
.63 .731 .92 r
.74415 .30005 .74714 .30417 .75383 .30244 .75085 .29832 Metetra
.656 .741 .913 r
.75085 .29832 .75383 .30244 .76052 .30031 .75755 .29618 Metetra
.673 .748 .907 r
.75755 .29618 .76052 .30031 .76719 .29789 .76423 .29375 Metetra
.681 .751 .904 r
.76423 .29375 .76719 .29789 .77387 .29533 .77092 .29117 Metetra
.682 .752 .904 r
.77092 .29117 .77387 .29533 .78056 .29273 .77763 .28857 Metetra
.678 .75 .905 r
.77763 .28857 .78056 .29273 .78728 .2902 .78435 .28603 Metetra
.673 .748 .907 r
.78435 .28603 .78728 .2902 .79401 .28776 .7911 .28358 Metetra
.667 .746 .909 r
.7911 .28358 .79401 .28776 .80077 .28541 .79787 .28121 Metetra
.663 .744 .91 r
.79787 .28121 .80077 .28541 .80755 .28312 .80466 .27891 Metetra
.661 .743 .911 r
.80466 .27891 .80755 .28312 .81435 .28086 .81147 .27664 Metetra
.66 .743 .911 r
.81147 .27664 .81435 .28086 .82116 .2786 .8183 .27438 Metetra
.661 .743 .911 r
.8183 .27438 .82116 .2786 .828 .27634 .82514 .2721 Metetra
.662 .744 .911 r
.82514 .2721 .828 .27634 .83484 .27405 .832 .2698 Metetra
.663 .744 .91 r
.832 .2698 .83484 .27405 .8417 .27173 .83887 .26748 Metetra
.664 .744 .91 r
.83887 .26748 .8417 .27173 .84858 .2694 .84576 .26513 Metetra
.659 .725 .898 r
.23086 .4663 .23456 .47004 .24009 .46822 .23639 .46447 Metetra
.659 .725 .898 r
.23639 .46447 .24009 .46822 .24563 .46638 .24194 .46264 Metetra
.659 .726 .899 r
.24194 .46264 .24563 .46638 .25118 .46454 .24749 .46081 Metetra
.658 .727 .9 r
.24749 .46081 .25118 .46454 .25675 .4627 .25306 .45899 Metetra
.658 .728 .901 r
.25306 .45899 .25675 .4627 .26233 .46086 .25864 .45716 Metetra
.658 .729 .902 r
.25864 .45716 .26233 .46086 .26791 .45904 .26424 .45533 Metetra
.659 .729 .902 r
.26424 .45533 .26791 .45904 .27351 .45725 .26984 .45349 Metetra
.66 .727 .899 r
.26984 .45349 .27351 .45725 .27911 .45548 .27546 .45162 Metetra
.662 .723 .894 r
.27546 .45162 .27911 .45548 .28473 .45372 .2811 .44971 Metetra
.664 .716 .887 r
.2811 .44971 .28473 .45372 .29036 .45194 .28675 .44777 Metetra
.664 .708 .88 r
.28675 .44777 .29036 .45194 .29601 .45008 .29241 .4458 Metetra
.662 .703 .877 r
.29241 .4458 .29601 .45008 .30168 .44808 .29808 .44384 Metetra
.659 .704 .88 r
.29808 .44384 .30168 .44808 .30737 .44592 .30376 .44195 Metetra
.652 .716 .895 r
.30376 .44195 .30737 .44592 .31309 .44363 .30945 .44017 Metetra
.642 .742 .922 r
.30945 .44017 .31309 .44363 .31881 .44131 .31514 .43852 Metetra
.627 .782 .956 r
.31514 .43852 .31881 .44131 .32454 .43918 .32083 .43698 Metetra
.612 .819 .98 r
.32083 .43698 .32454 .43918 .33025 .43746 .32654 .43543 Metetra
.625 .835 .981 r
.32654 .43543 .33025 .43746 .33593 .43635 .33228 .4337 Metetra
.67 .802 .946 r
.33228 .4337 .33593 .43635 .3416 .43585 .33804 .4316 Metetra
.693 .716 .867 r
.33804 .4316 .3416 .43585 .34727 .43565 .34385 .42906 Metetra
.681 .628 .789 r
.34385 .42906 .34727 .43565 .35298 .43514 .34968 .42614 Metetra
.66 .567 .739 r
.34968 .42614 .35298 .43514 .35876 .43352 .35553 .42317 Metetra
.638 .535 .721 r
.35553 .42317 .35876 .43352 .36464 .43012 .36136 .42062 Metetra
.615 .534 .74 r
.36136 .42062 .36464 .43012 .37061 .42482 .36716 .41899 Metetra
.567 .602 .847 r
.36716 .41899 .37061 .42482 .37664 .41834 .37292 .41853 Metetra
.154 0 0 r
.37292 .41853 .37664 .41834 .38265 .41235 .37865 .41903 Metetra
.506 .113 .229 r
.37865 .41903 .38265 .41235 .38854 .40901 .3844 .41971 Metetra
.491 .151 .318 r
.3844 .41971 .38854 .40901 .39426 .41021 .39021 .41943 Metetra
.38 .028 .237 r
.39021 .41943 .39426 .41021 .3998 .41661 .39612 .41711 Metetra
.783 .992 .883 r
.39612 .41711 .3998 .41661 .40525 .4268 .40213 .41232 Metetra
.689 .53 .666 r
.40213 .41232 .40525 .4268 .41074 .43719 .40821 .4057 Metetra
.623 .433 .604 r
.40821 .4057 .41074 .43719 .41645 .44291 .41429 .39896 Metetra
.587 .392 .585 r
.41429 .39896 .41645 .44291 .42247 .43973 .4203 .39434 Metetra
.555 .367 .581 r
.4203 .39434 .42247 .43973 .42881 .42644 .4262 .39362 Metetra
.504 .343 .595 r
.4262 .39362 .42881 .42644 .4353 .40623 .43198 .39724 Metetra
.099 .224 .707 r
.43198 .39724 .4353 .40623 .44174 .38627 .43773 .40368 Metetra
.627 .321 .432 r
.43773 .40368 .44174 .38627 .44791 .37523 .44352 .40979 Metetra
.555 .291 .47 r
.44352 .40979 .44791 .37523 .45371 .38003 .44945 .41197 Metetra
.478 .221 .446 r
.44945 .41197 .45371 .38003 .45918 .40276 .45555 .40781 Metetra
.723 .878 .475 r
.45555 .40781 .45918 .40276 .46451 .43886 .46177 .39755 Metetra
.65 .443 .589 r
.46177 .39755 .46451 .43886 .46996 .47728 .46802 .38429 Metetra
.59 .377 .56 r
.46802 .38429 .46996 .47728 .47575 .50353 .47422 .37281 Metetra
.561 .349 .55 r
.47422 .37281 .47575 .50353 .48196 .50589 .48031 .36752 Metetra
.537 .329 .546 r
.48031 .36752 .48196 .50589 .48851 .48173 .48631 .37044 Metetra
.51 .312 .547 r
.48631 .37044 .48851 .48173 .49514 .43982 .49226 .38012 Metetra
.461 .288 .559 r
.49226 .38012 .49514 .43982 .50165 .39639 .49826 .39203 Metetra
.596 .138 0 r
.49826 .39203 .50165 .39639 .50793 .36808 .50434 .40028 Metetra
.532 .267 .459 r
.50434 .40028 .50793 .36808 .51404 .36566 .51052 .40032 Metetra
.419 .176 .437 r
.51052 .40032 .51404 .36566 .52012 .39075 .51674 .39113 Metetra
.979 .871 .658 r
.51674 .39113 .52012 .39075 .52633 .43509 .52295 .37581 Metetra
.634 .419 .573 r
.52295 .37581 .52633 .43509 .53273 .48244 .52913 .36001 Metetra
.577 .362 .553 r
.52913 .36001 .53273 .48244 .53928 .5139 .53528 .34939 Metetra
.55 .338 .546 r
.53528 .34939 .53928 .5139 .54578 .51604 .54145 .34714 Metetra
.531 .323 .543 r
.54145 .34714 .54578 .51604 .55207 .48749 .5477 .35287 Metetra
.515 .314 .545 r
.5477 .35287 .55207 .48749 .55807 .43924 .55403 .36295 Metetra
.498 .31 .556 r
.55403 .36295 .55807 .43924 .56387 .3884 .56041 .37212 Metetra
.457 .369 .667 r
.56041 .37212 .56387 .3884 .56967 .35035 .56678 .37581 Metetra
.47 .203 .426 r
.56678 .37581 .56967 .35035 .57569 .33375 .57308 .37205 Metetra
.426 .188 .448 r
.57308 .37205 .57569 .33375 .58206 .33911 .57927 .36211 Metetra
.266 .031 .359 r
.57927 .36211 .58206 .33911 .58878 .35992 .58541 .34963 Metetra
.789 .624 .677 r
.58541 .34963 .58878 .35992 .59572 .38538 .59154 .33874 Metetra
.595 .396 .582 r
.59154 .33874 .59572 .38538 .60262 .40436 .59777 .33238 Metetra
.552 .352 .564 r
.59777 .33238 .60262 .40436 .60927 .40943 .60412 .33135 Metetra
.532 .336 .56 r
.60412 .33135 .60927 .40943 .61552 .39931 .6106 .33435 Metetra
.521 .332 .565 r
.6106 .33435 .61552 .39931 .62144 .37841 .61716 .33881 Metetra
.518 .347 .588 r
.61716 .33881 .62144 .37841 .62718 .35404 .62373 .34204 Metetra
.547 .466 .716 r
.62373 .34204 .62718 .35404 .63297 .33312 .63023 .3423 Metetra
.357 .01 .232 r
.63023 .3423 .63297 .33312 .63897 .31996 .63664 .33924 Metetra
.408 .133 .382 r
.63664 .33924 .63897 .31996 .64528 .31554 .64297 .33377 Metetra
.378 .105 .367 r
.64297 .33377 .64528 .31554 .65187 .31806 .64926 .32748 Metetra
.23 0 .194 r
.64926 .32748 .65187 .31806 .65865 .32414 .65559 .32188 Metetra
.771 .882 .927 r
.65559 .32188 .65865 .32414 .66548 .33022 .66199 .31789 Metetra
.615 .505 .705 r
.66199 .31789 .66548 .33022 .67224 .33368 .66847 .31569 Metetra
.572 .436 .657 r
.66847 .31569 .67224 .33368 .67886 .33343 .67504 .31481 Metetra
.56 .425 .654 r
.67504 .31481 .67886 .33343 .68532 .32981 .68165 .31449 Metetra
.567 .449 .679 r
.68165 .31449 .68532 .32981 .69169 .32411 .68828 .31398 Metetra
.594 .521 .743 r
.68828 .31398 .69169 .32411 .69802 .31787 .69489 .31281 Metetra
.646 .687 .874 r
.69489 .31281 .69802 .31787 .7044 .3123 .70148 .31083 Metetra
.642 .91 .982 r
.70148 .31083 .7044 .3123 .71085 .30808 .70804 .3082 Metetra
.507 .912 .865 r
.70804 .3082 .71085 .30808 .7174 .30528 .7146 .30521 Metetra
.539 .926 .89 r
.7146 .30521 .7174 .30528 .72403 .30357 .72117 .30219 Metetra
.652 .92 .977 r
.72117 .30219 .72403 .30357 .73072 .30243 .72776 .29936 Metetra
.678 .814 .948 r
.72776 .29936 .73072 .30243 .73743 .30137 .73439 .29682 Metetra
.663 .721 .892 r
.73439 .29682 .73743 .30137 .74415 .30005 .74105 .29455 Metetra
.649 .672 .858 r
.74105 .29455 .74415 .30005 .75085 .29832 .74774 .29245 Metetra
.644 .655 .847 r
.74774 .29245 .75085 .29832 .75755 .29618 .75444 .29042 Metetra
.645 .661 .851 r
.75444 .29042 .75755 .29618 .76423 .29375 .76117 .28837 Metetra
.651 .679 .864 r
.76117 .28837 .76423 .29375 .77092 .29117 .7679 .28624 Metetra
.658 .702 .88 r
.7679 .28624 .77092 .29117 .77763 .28857 .77465 .28401 Metetra
.663 .724 .894 r
.77465 .28401 .77763 .28857 .78435 .28603 .7814 .2817 Metetra
.666 .738 .904 r
.7814 .2817 .78435 .28603 .7911 .28358 .78817 .27934 Metetra
.668 .744 .908 r
.78817 .27934 .7911 .28358 .79787 .28121 .79495 .27696 Metetra
.667 .744 .907 r
.79495 .27696 .79787 .28121 .80466 .27891 .80174 .27458 Metetra
.666 .739 .905 r
.80174 .27458 .80466 .27891 .81147 .27664 .80856 .27221 Metetra
.665 .734 .901 r
.80856 .27221 .81147 .27664 .8183 .27438 .81539 .26985 Metetra
.664 .729 .898 r
.81539 .26985 .8183 .27438 .82514 .2721 .82224 .26751 Metetra
.663 .726 .896 r
.82224 .26751 .82514 .2721 .832 .2698 .8291 .26517 Metetra
.663 .724 .895 r
.8291 .26517 .832 .2698 .83887 .26748 .83598 .26283 Metetra
.663 .724 .894 r
.83598 .26283 .83887 .26748 .84576 .26513 .84288 .26048 Metetra
.658 .71 .886 r
.22716 .46226 .23086 .4663 .23639 .46447 .2327 .46043 Metetra
.657 .71 .886 r
.2327 .46043 .23639 .46447 .24194 .46264 .23825 .45861 Metetra
.657 .71 .887 r
.23825 .45861 .24194 .46264 .24749 .46081 .24381 .45679 Metetra
.657 .711 .888 r
.24381 .45679 .24749 .46081 .25306 .45899 .24939 .45496 Metetra
.658 .712 .888 r
.24939 .45496 .25306 .45899 .25864 .45716 .25497 .45312 Metetra
.659 .712 .887 r
.25497 .45312 .25864 .45716 .26424 .45533 .26058 .45125 Metetra
.662 .711 .884 r
.26058 .45125 .26424 .45533 .26984 .45349 .26619 .44933 Metetra
.665 .708 .88 r
.26619 .44933 .26984 .45349 .27546 .45162 .27183 .44735 Metetra
.666 .704 .875 r
.27183 .44735 .27546 .45162 .2811 .44971 .27748 .44533 Metetra
.665 .698 .871 r
.27748 .44533 .2811 .44971 .28675 .44777 .28314 .44331 Metetra
.66 .694 .87 r
.28314 .44331 .28675 .44777 .29241 .4458 .2888 .44137 Metetra
.651 .692 .876 r
.2888 .44137 .29241 .4458 .29808 .44384 .29447 .4396 Metetra
.636 .697 .889 r
.29447 .4396 .29808 .44384 .30376 .44195 .30013 .43806 Metetra
.619 .711 .911 r
.30013 .43806 .30376 .44195 .30945 .44017 .30579 .43674 Metetra
.607 .735 .936 r
.30579 .43674 .30945 .44017 .31514 .43852 .31146 .43552 Metetra
.616 .765 .951 r
.31146 .43552 .31514 .43852 .32083 .43698 .31715 .43413 Metetra
.658 .786 .943 r
.31715 .43413 .32083 .43698 .32654 .43543 .32289 .43222 Metetra
.711 .776 .903 r
.32289 .43222 .32654 .43543 .33228 .4337 .32869 .4295 Metetra
.738 .73 .844 r
.32869 .4295 .33228 .4337 .33804 .4316 .33455 .4259 Metetra
.732 .673 .793 r
.33455 .4259 .33804 .4316 .34385 .42906 .34045 .42177 Metetra
.703 .621 .762 r
.34045 .42177 .34385 .42906 .34968 .42614 .34634 .41788 Metetra
.653 .576 .756 r
.34634 .41788 .34968 .42614 .35553 .42317 .35217 .41533 Metetra
.559 .536 .786 r
.35217 .41533 .35553 .42317 .36136 .42062 .35788 .41512 Metetra
.267 .456 .86 r
.35788 .41512 .36136 .42062 .36716 .41899 .36348 .41765 Metetra
.632 .07 0 r
.36348 .41765 .36716 .41899 .37292 .41853 .369 .42223 Metetra
.681 .251 .22 r
.369 .42223 .37292 .41853 .37865 .41903 .37456 .42693 Metetra
.567 .194 .295 r
.37456 .42693 .37865 .41903 .3844 .41971 .38027 .42896 Metetra
.326 0 .208 r
.38027 .42896 .3844 .41971 .39021 .41943 .38623 .42574 Metetra
.38623 .42574 .39021 .41943 .39612 .41711 .39246 .4163 Metetra
.949 .831 .694 r
.39246 .4163 .39612 .41711 .40213 .41232 .39885 .40235 Metetra
.815 .636 .661 r
.39885 .40235 .40213 .41232 .40821 .4057 .40521 .38833 Metetra
.69 .515 .646 r
.40521 .38833 .40821 .4057 .41429 .39896 .41133 .38023 Metetra
.48 .365 .644 r
.41133 .38023 .41429 .39896 .4203 .39434 .41706 .38332 Metetra
0 0 .272 r
.41706 .38332 .4203 .39434 .4262 .39362 .4224 .39978 Metetra
.873 .544 .424 r
.4224 .39978 .4262 .39362 .43198 .39724 .4275 .4269 Metetra
.748 .461 .495 r
.4275 .4269 .43198 .39724 .43773 .40368 .43265 .4567 Metetra
.653 .388 .507 r
.43265 .4567 .43773 .40368 .44352 .40979 .43815 .4779 Metetra
.551 .306 .498 r
.43815 .4779 .44352 .40979 .44945 .41197 .44421 .48052 Metetra
.411 .192 .468 r
.44421 .48052 .44945 .41197 .45555 .40781 .45079 .46131 Metetra
.164 0 .381 r
.45079 .46131 .45555 .40781 .46177 .39755 .45764 .42663 Metetra
0 0 .094 r
.45764 .42663 .46177 .39755 .46802 .38429 .46441 .39044 Metetra
.976 .88 .507 r
.46441 .39044 .46802 .38429 .47422 .37281 .47082 .36853 Metetra
0 .316 .804 r
.47082 .36853 .47422 .37281 .48031 .36752 .47678 .37247 Metetra
.9 .568 .409 r
.47678 .37247 .48031 .36752 .48631 .37044 .4824 .40536 Metetra
.802 .513 .499 r
.4824 .40536 .48631 .37044 .49226 .38012 .48792 .45976 Metetra
.716 .448 .52 r
.48792 .45976 .49226 .38012 .49826 .39203 .49363 .51833 Metetra
.634 .385 .523 r
.49363 .51833 .49826 .39203 .50434 .40028 .49973 .55879 Metetra
.551 .318 .516 r
.49973 .55879 .50434 .40028 .51052 .40032 .5062 .56368 Metetra
.457 .244 .501 r
.5062 .56368 .51052 .40032 .51674 .39113 .51284 .53001 Metetra
.342 .153 .473 r
.51284 .53001 .51674 .39113 .52295 .37581 .51943 .47131 Metetra
.195 .034 .422 r
.51943 .47131 .52295 .37581 .52913 .36001 .5258 .41012 Metetra
.024 0 .335 r
.5258 .41012 .52913 .36001 .53528 .34939 .53201 .36726 Metetra
.141 0 .275 r
.53201 .36726 .53528 .34939 .54145 .34714 .53819 .3547 Metetra
.826 .471 .385 r
.53819 .3547 .54145 .34714 .5477 .35287 .54454 .37319 Metetra
.825 .516 .465 r
.54454 .37319 .5477 .35287 .55403 .36295 .55115 .41287 Metetra
.735 .454 .503 r
.55115 .41287 .55403 .36295 .56041 .37212 .55799 .45641 Metetra
.638 .381 .513 r
.55799 .45641 .56041 .37212 .56678 .37581 .56484 .48501 Metetra
.543 .307 .508 r
.56484 .48501 .56678 .37581 .57308 .37205 .57144 .48621 Metetra
.444 .23 .493 r
.57144 .48621 .57308 .37205 .57927 .36211 .57762 .45937 Metetra
.328 .138 .464 r
.57762 .45937 .57927 .36211 .58541 .34963 .58339 .41492 Metetra
.157 0 .403 r
.58339 .41492 .58541 .34963 .59154 .33874 .58897 .36812 Metetra
0 0 .196 r
.58897 .36812 .59154 .33874 .59777 .33238 .59462 .33217 Metetra
.985 .845 .621 r
.59462 .33217 .59777 .33238 .60412 .33135 .60058 .31415 Metetra
.551 .425 .662 r
.60058 .31415 .60412 .33135 .6106 .33435 .60696 .31427 Metetra
.216 .181 .602 r
.60696 .31427 .6106 .33435 .61716 .33881 .61373 .32721 Metetra
0 0 .422 r
.61373 .32721 .61716 .33881 .62373 .34204 .62072 .3447 Metetra
.844 .427 .244 r
.62072 .3447 .62373 .34204 .63023 .3423 .62768 .35857 Metetra
.606 .288 .404 r
.62768 .35857 .63023 .3423 .63664 .33924 .63442 .3635 Metetra
.443 .177 .414 r
.63442 .3635 .63664 .33924 .64297 .33377 .64083 .35838 Metetra
.295 .061 .378 r
.64083 .35838 .64297 .33377 .64926 .32748 .64696 .34582 Metetra
.085 0 .275 r
.64696 .34582 .64926 .32748 .65559 .32188 .65295 .33034 Metetra
.65295 .33034 .65559 .32188 .66199 .31789 .65895 .31631 Metetra
.937 .891 .759 r
.65895 .31631 .66199 .31789 .66847 .31569 .66511 .30655 Metetra
.7 .596 .737 r
.66511 .30655 .66847 .31569 .67504 .31481 .6715 .30189 Metetra
.566 .469 .704 r
.6715 .30189 .67504 .31481 .68165 .31449 .6781 .30146 Metetra
.495 .423 .705 r
.6781 .30146 .68165 .31449 .68828 .31398 .68484 .30342 Metetra
.46 .434 .742 r
.68484 .30342 .68828 .31398 .69489 .31281 .69164 .30579 Metetra
.466 .52 .829 r
.69164 .30579 .69489 .31281 .70148 .31083 .69841 .30709 Metetra
.526 .706 .953 r
.69841 .30709 .70148 .31083 .70804 .3082 .70511 .30659 Metetra
.607 .891 .989 r
.70511 .30659 .70804 .3082 .7146 .30521 .71173 .30434 Metetra
.682 .955 .95 r
.71173 .30434 .7146 .30521 .72117 .30219 .71829 .30085 Metetra
.749 .947 .945 r
.71829 .30085 .72117 .30219 .72776 .29936 .72483 .29686 Metetra
.76 .875 .931 r
.72483 .29686 .72776 .29936 .73439 .29682 .73138 .29298 Metetra
.726 .784 .898 r
.73138 .29298 .73439 .29682 .74105 .29455 .73798 .28959 Metetra
.686 .712 .868 r
.73798 .28959 .74105 .29455 .74774 .29245 .74462 .2868 Metetra
.656 .67 .852 r
.74462 .2868 .74774 .29245 .75444 .29042 .75132 .28452 Metetra
.639 .653 .848 r
.75132 .28452 .75444 .29042 .76117 .28837 .75806 .28257 Metetra
.634 .655 .853 r
.75806 .28257 .76117 .28837 .7679 .28624 .76483 .28072 Metetra
.637 .668 .863 r
.76483 .28072 .7679 .28624 .77465 .28401 .77161 .27884 Metetra
.645 .687 .875 r
.77161 .27884 .77465 .28401 .7814 .2817 .7784 .27681 Metetra
.654 .705 .884 r
.7784 .27681 .7814 .2817 .78817 .27934 .78519 .27463 Metetra
.662 .718 .89 r
.78519 .27463 .78817 .27934 .79495 .27696 .79198 .27232 Metetra
.666 .724 .892 r
.79198 .27232 .79495 .27696 .80174 .27458 .79879 .26993 Metetra
.668 .724 .891 r
.79879 .26993 .80174 .27458 .80856 .27221 .80561 .26749 Metetra
.668 .721 .889 r
.80561 .26749 .80856 .27221 .81539 .26985 .81244 .26506 Metetra
.666 .717 .887 r
.81244 .26506 .81539 .26985 .82224 .26751 .8193 .26264 Metetra
.664 .713 .885 r
.8193 .26264 .82224 .26751 .8291 .26517 .82617 .26024 Metetra
.663 .71 .883 r
.82617 .26024 .8291 .26517 .83598 .26283 .83306 .25787 Metetra
.662 .709 .883 r
.83306 .25787 .83598 .26283 .84288 .26048 .83997 .25551 Metetra
.656 .697 .876 r
.22347 .45795 .22716 .46226 .2327 .46043 .22902 .45612 Metetra
.656 .697 .876 r
.22902 .45612 .2327 .46043 .23825 .45861 .23458 .45428 Metetra
.657 .697 .875 r
.23458 .45428 .23825 .45861 .24381 .45679 .24015 .45244 Metetra
.658 .696 .874 r
.24015 .45244 .24381 .45679 .24939 .45496 .24573 .45057 Metetra
.659 .695 .872 r
.24573 .45057 .24939 .45496 .25497 .45312 .25133 .44867 Metetra
.661 .693 .869 r
.25133 .44867 .25497 .45312 .26058 .45125 .25694 .44674 Metetra
.662 .691 .867 r
.25694 .44674 .26058 .45125 .26619 .44933 .26256 .44477 Metetra
.662 .689 .865 r
.26256 .44477 .26619 .44933 .27183 .44735 .2682 .4428 Metetra
.66 .689 .867 r
.2682 .4428 .27183 .44735 .27748 .44533 .27385 .44086 Metetra
.655 .692 .872 r
.27385 .44086 .27748 .44533 .28314 .44331 .2795 .43901 Metetra
.647 .698 .883 r
.2795 .43901 .28314 .44331 .2888 .44137 .28516 .43729 Metetra
.638 .707 .896 r
.28516 .43729 .2888 .44137 .29447 .4396 .29081 .43572 Metetra
.632 .716 .908 r
.29081 .43572 .29447 .4396 .30013 .43806 .29648 .43423 Metetra
.635 .72 .909 r
.29648 .43423 .30013 .43806 .30579 .43674 .30216 .4327 Metetra
.651 .714 .894 r
.30216 .4327 .30579 .43674 .31146 .43552 .30787 .43092 Metetra
.673 .694 .861 r
.30787 .43092 .31146 .43552 .31715 .43413 .31362 .4287 Metetra
.689 .667 .823 r
.31362 .4287 .31715 .43413 .32289 .43222 .31942 .42594 Metetra
.695 .642 .793 r
.31942 .42594 .32289 .43222 .32869 .4295 .32525 .42275 Metetra
.691 .628 .781 r
.32525 .42275 .32869 .4295 .33455 .4259 .3311 .41948 Metetra
.678 .632 .796 r
.3311 .41948 .33455 .4259 .34045 .42177 .33692 .4167 Metetra
.64 .664 .857 r
.33692 .4167 .34045 .42177 .34634 .41788 .34269 .41502 Metetra
.463 .722 .981 r
.34269 .41502 .34634 .41788 .35217 .41533 .3484 .41486 Metetra
.215 0 0 r
.3484 .41486 .35217 .41533 .35788 .41512 .35405 .4161 Metetra
.48 0 0 r
.35405 .4161 .35788 .41512 .36348 .41765 .35968 .41801 Metetra
.327 0 0 r
.35968 .41801 .36348 .41765 .369 .42223 .36538 .41924 Metetra
.566 .755 .967 r
.36538 .41924 .369 .42223 .37456 .42693 .37121 .4183 Metetra
.695 .594 .738 r
.37121 .4183 .37456 .42693 .38027 .42896 .3772 .4141 Metetra
.698 .533 .661 r
.3772 .4141 .38027 .42896 .38623 .42574 .38333 .40668 Metetra
.693 .511 .637 r
.38333 .40668 .38623 .42574 .39246 .4163 .38954 .39746 Metetra
.685 .506 .639 r
.38954 .39746 .39246 .4163 .39885 .40235 .3957 .38903 Metetra
.665 .522 .68 r
.3957 .38903 .39885 .40235 .40521 .38833 .4017 .38434 Metetra
.34 .583 .933 r
.4017 .38434 .40521 .38833 .41133 .38023 .40749 .38557 Metetra
.733 .345 .316 r
.40749 .38557 .41133 .38023 .41706 .38332 .41309 .39312 Metetra
.748 .408 .408 r
.41309 .39312 .41706 .38332 .4224 .39978 .41859 .40504 Metetra
.8 .43 .356 r
.41859 .40504 .4224 .39978 .4275 .4269 .42415 .41727 Metetra
.022 .159 .669 r
.42415 .41727 .4275 .4269 .43265 .4567 .42991 .4249 Metetra
.561 .386 .602 r
.42991 .4249 .43265 .4567 .43815 .4779 .43595 .42396 Metetra
.615 .407 .577 r
.43595 .42396 .43815 .4779 .44421 .48052 .44225 .41329 Metetra
.634 .417 .57 r
.44225 .41329 .44421 .48052 .45079 .46131 .44871 .39532 Metetra
.643 .424 .571 r
.44871 .39532 .45079 .46131 .45764 .42663 .45517 .37542 Metetra
.644 .43 .579 r
.45517 .37542 .45764 .42663 .46441 .39044 .46148 .35999 Metetra
.614 .427 .605 r
.46148 .35999 .46441 .39044 .47082 .36853 .46758 .35427 Metetra
.322 .29 .667 r
.46758 .35427 .47082 .36853 .47678 .37247 .47349 .36059 Metetra
0 0 .347 r
.47349 .36059 .47678 .37247 .4824 .40536 .47929 .37749 Metetra
.038 .018 .502 r
.47929 .37749 .4824 .40536 .48792 .45976 .48511 .39994 Metetra
.38 .227 .544 r
.48511 .39994 .48792 .45976 .49363 .51833 .49105 .42058 Metetra
.495 .302 .547 r
.49105 .42058 .49363 .51833 .49973 .55879 .49718 .43204 Metetra
.551 .341 .549 r
.49718 .43204 .49973 .55879 .5062 .56368 .50346 .42965 Metetra
.588 .369 .551 r
.50346 .42965 .5062 .56368 .51284 .53001 .50982 .41337 Metetra
.619 .395 .555 r
.50982 .41337 .51284 .53001 .51943 .47131 .51616 .38785 Metetra
.648 .423 .563 r
.51616 .38785 .51943 .47131 .5258 .41012 .52243 .36069 Metetra
.674 .453 .578 r
.52243 .36069 .5258 .41012 .53201 .36726 .52862 .3397 Metetra
.655 .461 .61 r
.52862 .3397 .53201 .36726 .53819 .3547 .53479 .33047 Metetra
.475 .342 .619 r
.53479 .33047 .53819 .3547 .54454 .37319 .54101 .33484 Metetra
.352 .225 .565 r
.54101 .33484 .54454 .37319 .55115 .41287 .54736 .35045 Metetra
.391 .235 .547 r
.54736 .35045 .55115 .41287 .55799 .45641 .55383 .37144 Metetra
.45 .271 .546 r
.55383 .37144 .55799 .45641 .56484 .48501 .56039 .39015 Metetra
.504 .31 .55 r
.56039 .39015 .56484 .48501 .57144 .48621 .56692 .39968 Metetra
.559 .353 .558 r
.56692 .39968 .57144 .48621 .57762 .45937 .57333 .39637 Metetra
.625 .41 .57 r
.57333 .39637 .57762 .45937 .58339 .41492 .57954 .38113 Metetra
.723 .502 .589 r
.57954 .38113 .58339 .41492 .58897 .36812 .58557 .35879 Metetra
.886 .677 .615 r
.58557 .35879 .58897 .36812 .59462 .33217 .59153 .33597 Metetra
.961 .9 .526 r
.59153 .33597 .59462 .33217 .60058 .31415 .59755 .31861 Metetra
.59755 .31861 .60058 .31415 .60696 .31427 .60374 .31015 Metetra
.42 .624 .937 r
.60374 .31015 .60696 .31427 .61373 .32721 .61017 .31087 Metetra
.336 .287 .654 r
.61017 .31087 .61373 .32721 .62072 .3447 .61683 .31829 Metetra
.38 .272 .604 r
.61683 .31829 .62072 .3447 .62768 .35857 .62362 .32823 Metetra
.436 .302 .599 r
.62362 .32823 .62768 .35857 .63442 .3635 .63041 .33636 Metetra
.503 .357 .615 r
.63041 .33636 .63442 .3635 .64083 .35838 .63709 .33962 Metetra
.6 .451 .651 r
.63709 .33962 .64083 .35838 .64696 .34582 .64358 .33702 Metetra
.761 .633 .719 r
.64358 .33702 .64696 .34582 .65295 .33034 .6499 .32963 Metetra
.946 .926 .753 r
.6499 .32963 .65295 .33034 .65895 .31631 .65611 .31979 Metetra
.714 .883 .491 r
.65611 .31979 .65895 .31631 .66511 .30655 .66231 .31011 Metetra
.66231 .31011 .66511 .30655 .6715 .30189 .66859 .30256 Metetra
.641 .963 .811 r
.66859 .30256 .6715 .30189 .6781 .30146 .67501 .29802 Metetra
.623 .767 .949 r
.67501 .29802 .6781 .30146 .68484 .30342 .68158 .29632 Metetra
.531 .554 .823 r
.68158 .29632 .68484 .30342 .69164 .30579 .68826 .29652 Metetra
.513 .49 .768 r
.68826 .29652 .69164 .30579 .69841 .30709 .69501 .2974 Metetra
.531 .493 .759 r
.69501 .2974 .69841 .30709 .70511 .30659 .70177 .2979 Metetra
.572 .537 .777 r
.70177 .2979 .70511 .30659 .71173 .30434 .70849 .29735 Metetra
.626 .609 .814 r
.70849 .29735 .71173 .30434 .71829 .30085 .71516 .29558 Metetra
.683 .697 .857 r
.71516 .29558 .71829 .30085 .72483 .29686 .72178 .29281 Metetra
.722 .77 .891 r
.72178 .29281 .72483 .29686 .73138 .29298 .72838 .28946 Metetra
.732 .805 .909 r
.72838 .28946 .73138 .29298 .73798 .28959 .73499 .28599 Metetra
.72 .797 .912 r
.73499 .28599 .73798 .28959 .74462 .2868 .74161 .28274 Metetra
.697 .763 .903 r
.74161 .28274 .74462 .2868 .75132 .28452 .74828 .27987 Metetra
.672 .723 .888 r
.74828 .27987 .75132 .28452 .75806 .28257 .75499 .27739 Metetra
.653 .691 .872 r
.75499 .27739 .75806 .28257 .76483 .28072 .76174 .27521 Metetra
.644 .672 .862 r
.76174 .27521 .76483 .28072 .77161 .27884 .76852 .27319 Metetra
.641 .666 .858 r
.76852 .27319 .77161 .27884 .7784 .27681 .77532 .2712 Metetra
.644 .669 .859 r
.77532 .2712 .7784 .27681 .78519 .27463 .78213 .26914 Metetra
.65 .677 .863 r
.78213 .26914 .78519 .27463 .79198 .27232 .78895 .26698 Metetra
.656 .687 .867 r
.78895 .26698 .79198 .27232 .79879 .26993 .79578 .26471 Metetra
.661 .695 .871 r
.79578 .26471 .79879 .26993 .80561 .26749 .80261 .26236 Metetra
.664 .7 .874 r
.80261 .26236 .80561 .26749 .81244 .26506 .80946 .25995 Metetra
.665 .703 .875 r
.80946 .25995 .81244 .26506 .8193 .26264 .81632 .25752 Metetra
.664 .703 .875 r
.81632 .25752 .8193 .26264 .82617 .26024 .8232 .2551 Metetra
.663 .701 .875 r
.8232 .2551 .82617 .26024 .83306 .25787 .8301 .25268 Metetra
.662 .699 .874 r
.8301 .25268 .83306 .25787 .83997 .25551 .83702 .25029 Metetra
.656 .686 .866 r
.2198 .4534 .22347 .45795 .22902 .45612 .22535 .45154 Metetra
.657 .685 .865 r
.22535 .45154 .22902 .45612 .23458 .45428 .23091 .44966 Metetra
.658 .684 .863 r
.23091 .44966 .23458 .45428 .24015 .45244 .23649 .44776 Metetra
.659 .682 .861 r
.23649 .44776 .24015 .45244 .24573 .45057 .24209 .44584 Metetra
.659 .68 .859 r
.24209 .44584 .24573 .45057 .25133 .44867 .24769 .4439 Metetra
.658 .678 .858 r
.24769 .4439 .25133 .44867 .25694 .44674 .25331 .44196 Metetra
.656 .678 .859 r
.25331 .44196 .25694 .44674 .26256 .44477 .25893 .44006 Metetra
.652 .68 .863 r
.25893 .44006 .26256 .44477 .2682 .4428 .26456 .43823 Metetra
.647 .685 .872 r
.26456 .43823 .2682 .4428 .27385 .44086 .2702 .43651 Metetra
.642 .694 .883 r
.2702 .43651 .27385 .44086 .2795 .43901 .27584 .43487 Metetra
.641 .705 .893 r
.27584 .43487 .2795 .43901 .28516 .43729 .28149 .43325 Metetra
.647 .712 .895 r
.28149 .43325 .28516 .43729 .29081 .43572 .28717 .43153 Metetra
.662 .71 .883 r
.28717 .43153 .29081 .43572 .29648 .43423 .29287 .42956 Metetra
.679 .692 .856 r
.29287 .42956 .29648 .43423 .30216 .4327 .29861 .42721 Metetra
.687 .664 .822 r
.29861 .42721 .30216 .4327 .30787 .43092 .30439 .42448 Metetra
.684 .633 .792 r
.30439 .42448 .30787 .43092 .31362 .4287 .31019 .42154 Metetra
.67 .609 .778 r
.31019 .42154 .31362 .4287 .31942 .42594 .31599 .41877 Metetra
.646 .597 .785 r
.31599 .41877 .31942 .42594 .32525 .42275 .32176 .41665 Metetra
.601 .608 .831 r
.32176 .41665 .32525 .42275 .3311 .41948 .32747 .41563 Metetra
.466 .656 .943 r
.32747 .41563 .3311 .41948 .33692 .4167 .33313 .41584 Metetra
0 .49 .736 r
.33313 .41584 .33692 .4167 .34269 .41502 .33876 .41685 Metetra
.399 0 0 r
.33876 .41685 .34269 .41502 .3484 .41486 .34442 .41771 Metetra
.265 0 0 r
.34442 .41771 .3484 .41486 .35405 .4161 .35019 .41707 Metetra
.561 .935 .843 r
.35019 .41707 .35405 .4161 .35968 .41801 .3561 .41379 Metetra
.811 .745 .791 r
.3561 .41379 .35968 .41801 .36538 .41924 .36218 .40756 Metetra
.735 .578 .68 r
.36218 .40756 .36538 .41924 .37121 .4183 .36835 .3994 Metetra
.677 .501 .64 r
.36835 .3994 .37121 .4183 .3772 .4141 .37449 .39164 Metetra
.619 .448 .628 r
.37449 .39164 .3772 .4141 .38333 .40668 .38047 .38723 Metetra
.522 .39 .642 r
.38047 .38723 .38333 .40668 .38954 .39746 .38621 .38858 Metetra
0 .111 .648 r
.38621 .38858 .38954 .39746 .3957 .38903 .39171 .39623 Metetra
.773 .419 .385 r
.39171 .39623 .3957 .38903 .4017 .38434 .39709 .40807 Metetra
.662 .371 .467 r
.39709 .40807 .4017 .38434 .40749 .38557 .40255 .41946 Metetra
.584 .313 .473 r
.40255 .41946 .40749 .38557 .41309 .39312 .4083 .42474 Metetra
.462 .204 .437 r
.4083 .42474 .41309 .39312 .41859 .40504 .41443 .41981 Metetra
0 0 .063 r
.41443 .41981 .41859 .40504 .42415 .41727 .4209 .40456 Metetra
.831 .627 .627 r
.4209 .40456 .42415 .41727 .42991 .4249 .42749 .3838 Metetra
.679 .464 .587 r
.42749 .3838 .42991 .4249 .43595 .42396 .43396 .36563 Metetra
.591 .386 .572 r
.43396 .36563 .43595 .42396 .44225 .41329 .4401 .35823 Metetra
.482 .304 .562 r
.4401 .35823 .44225 .41329 .44871 .39532 .44584 .3663 Metetra
.049 .019 .498 r
.44584 .3663 .44871 .39532 .45517 .37542 .45131 .38871 Metetra
.829 .512 .454 r
.45131 .38871 .45517 .37542 .46148 .35999 .45674 .41788 Metetra
.656 .391 .507 r
.45674 .41788 .46148 .35999 .46758 .35427 .4624 .44198 Metetra
.567 .324 .507 r
.4624 .44198 .46758 .35427 .47349 .36059 .46846 .44971 Metetra
.475 .248 .49 r
.46846 .44971 .47349 .36059 .47929 .37749 .47489 .43617 Metetra
.267 .072 .42 r
.47489 .43617 .47929 .37749 .48511 .39994 .48152 .40595 Metetra
1 .821 .5 r
.48152 .40595 .48511 .39994 .49105 .42058 .4881 .3712 Metetra
.693 .469 .578 r
.4881 .3712 .49105 .42058 .49718 .43204 .49449 .34584 Metetra
.571 .362 .558 r
.49449 .34584 .49718 .43204 .50346 .42965 .50065 .33962 Metetra
.472 .285 .545 r
.50065 .33962 .50346 .42965 .50982 .41337 .50669 .35461 Metetra
.28 .153 .523 r
.50669 .35461 .50982 .41337 .51616 .38785 .51275 .38434 Metetra
.95 .597 .28 r
.51275 .38434 .51616 .38785 .52243 .36069 .51894 .41593 Metetra
.638 .373 .5 r
.51894 .41593 .52243 .36069 .52862 .3397 .52529 .43509 Metetra
.527 .292 .502 r
.52529 .43509 .52862 .3397 .53479 .33047 .53168 .43264 Metetra
.441 .225 .488 r
.53168 .43264 .53479 .33047 .54101 .33484 .538 .40912 Metetra
.308 .115 .447 r
.538 .40912 .54101 .33484 .54736 .35045 .54419 .37409 Metetra
0 0 .071 r
.54419 .37409 .54736 .35045 .55383 .37144 .55027 .3409 Metetra
.724 .506 .595 r
.55027 .3409 .55383 .37144 .56039 .39015 .55637 .32054 Metetra
.559 .357 .563 r
.55637 .32054 .56039 .39015 .56692 .39968 .56262 .31785 Metetra
.479 .293 .55 r
.56262 .31785 .56692 .39968 .57333 .39637 .56911 .33065 Metetra
.404 .243 .547 r
.56911 .33065 .57333 .39637 .57954 .38113 .57579 .35122 Metetra
.225 .152 .56 r
.57579 .35122 .57954 .38113 .58557 .35879 .58254 .36954 Metetra
.68 .325 .367 r
.58254 .36954 .58557 .35879 .59153 .33597 .58917 .37736 Metetra
.477 .23 .46 r
.58917 .37736 .59153 .33597 .59755 .31861 .59556 .37152 Metetra
.398 .176 .457 r
.59556 .37152 .59755 .31861 .60374 .31015 .60169 .35468 Metetra
.31 .102 .427 r
.60169 .35468 .60374 .31015 .61017 .31087 .60765 .33332 Metetra
.068 0 .29 r
.60765 .33332 .61017 .31087 .61683 .31829 .61361 .31445 Metetra
.908 .788 .717 r
.61361 .31445 .61683 .31829 .62362 .32823 .61975 .30288 Metetra
.59 .42 .62 r
.61975 .30288 .62362 .32823 .63041 .33636 .62614 .30002 Metetra
.504 .34 .591 r
.62614 .30002 .63041 .33636 .63709 .33962 .63278 .30409 Metetra
.464 .312 .59 r
.63278 .30409 .63709 .33962 .64358 .33702 .63958 .31136 Metetra
.444 .319 .615 r
.63958 .31136 .64358 .33702 .6499 .32963 .64641 .31781 Metetra
.454 .412 .722 r
.64641 .31781 .6499 .32963 .65611 .31979 .65313 .32055 Metetra
.222 .735 .704 r
.65313 .32055 .65611 .31979 .66231 .31011 .65969 .31862 Metetra
.177 0 .142 r
.65969 .31862 .66231 .31011 .66859 .30256 .6661 .31286 Metetra
.146 0 .182 r
.6661 .31286 .66859 .30256 .67501 .29802 .67241 .3052 Metetra
0 0 .012 r
.67241 .3052 .67501 .29802 .68158 .29632 .67873 .29771 Metetra
.669 .953 .712 r
.67873 .29771 .68158 .29632 .68826 .29652 .68512 .29186 Metetra
.727 .739 .861 r
.68512 .29186 .68826 .29652 .69501 .2974 .69164 .28825 Metetra
.611 .549 .761 r
.69164 .28825 .69501 .2974 .70177 .2979 .69827 .2866 Metetra
.566 .489 .728 r
.69827 .2866 .70177 .2979 .70849 .29735 .70499 .28616 Metetra
.556 .485 .731 r
.70499 .28616 .70849 .29735 .71516 .29558 .71176 .28603 Metetra
.571 .52 .759 r
.71176 .28603 .71516 .29558 .72178 .29281 .71852 .28548 Metetra
.605 .59 .809 r
.71852 .28548 .72178 .29281 .72838 .28946 .72526 .28416 Metetra
.651 .683 .867 r
.72526 .28416 .72838 .28946 .73499 .28599 .73196 .28201 Metetra
.69 .766 .91 r
.73196 .28201 .73499 .28599 .74161 .28274 .73863 .27927 Metetra
.708 .803 .924 r
.73863 .27927 .74161 .28274 .74828 .27987 .7453 .27623 Metetra
.707 .793 .918 r
.7453 .27623 .74828 .27987 .75499 .27739 .75199 .27319 Metetra
.694 .757 .9 r
.75199 .27319 .75499 .27739 .76174 .27521 .7587 .27034 Metetra
.676 .716 .879 r
.7587 .27034 .76174 .27521 .76852 .27319 .76544 .26775 Metetra
.66 .684 .862 r
.76544 .26775 .76852 .27319 .77532 .2712 .77222 .26539 Metetra
.65 .665 .851 r
.77222 .26539 .77532 .2712 .78213 .26914 .77903 .26319 Metetra
.646 .658 .847 r
.77903 .26319 .78213 .26914 .78895 .26698 .78586 .26105 Metetra
.646 .659 .848 r
.78586 .26105 .78895 .26698 .79578 .26471 .7927 .2589 Metetra
.65 .666 .852 r
.7927 .2589 .79578 .26471 .80261 .26236 .79956 .2567 Metetra
.654 .674 .857 r
.79956 .2567 .80261 .26236 .80946 .25995 .80643 .25442 Metetra
.657 .682 .862 r
.80643 .25442 .80946 .25995 .81632 .25752 .81331 .25208 Metetra
.66 .687 .865 r
.81331 .25208 .81632 .25752 .8232 .2551 .8202 .24969 Metetra
.661 .69 .866 r
.8202 .24969 .8232 .2551 .8301 .25268 .82711 .24728 Metetra
.661 .69 .866 r
.82711 .24728 .8301 .25268 .83702 .25029 .83404 .24486 Metetra
.657 .675 .856 r
.21613 .44859 .2198 .4534 .22535 .45154 .22169 .44669 Metetra
.657 .674 .855 r
.22169 .44669 .22535 .45154 .23091 .44966 .22726 .44477 Metetra
.657 .673 .853 r
.22726 .44477 .23091 .44966 .23649 .44776 .23285 .44284 Metetra
.657 .672 .852 r
.23285 .44284 .23649 .44776 .24209 .44584 .23845 .44091 Metetra
.655 .671 .853 r
.23845 .44091 .24209 .44584 .24769 .4439 .24405 .43901 Metetra
.652 .672 .856 r
.24405 .43901 .24769 .4439 .25331 .44196 .24966 .43717 Metetra
.648 .675 .862 r
.24966 .43717 .25331 .44196 .25893 .44006 .25528 .4354 Metetra
.645 .68 .869 r
.25528 .4354 .25893 .44006 .26456 .43823 .26091 .43371 Metetra
.644 .686 .875 r
.26091 .43371 .26456 .43823 .2702 .43651 .26654 .43203 Metetra
.648 .691 .876 r
.26654 .43203 .2702 .43651 .27584 .43487 .2722 .43029 Metetra
.659 .69 .868 r
.2722 .43029 .27584 .43487 .28149 .43325 .27788 .42834 Metetra
.672 .68 .85 r
.27788 .42834 .28149 .43325 .28717 .43153 .2836 .4261 Metetra
.682 .664 .826 r
.2836 .4261 .28717 .43153 .29287 .42956 .28935 .42352 Metetra
.683 .644 .805 r
.28935 .42352 .29287 .42956 .29861 .42721 .29513 .42071 Metetra
.676 .628 .794 r
.29513 .42071 .29861 .42721 .30439 .42448 .30091 .41797 Metetra
.658 .62 .8 r
.30091 .41797 .30439 .42448 .31019 .42154 .30667 .41571 Metetra
.62 .626 .835 r
.30667 .41571 .31019 .42154 .31599 .41877 .31238 .41434 Metetra
.533 .652 .911 r
.31238 .41434 .31599 .41877 .32176 .41665 .31804 .41408 Metetra
.288 .658 .97 r
.31804 .41408 .32176 .41665 .32747 .41563 .32365 .41474 Metetra
0 .522 .764 r
.32365 .41474 .32747 .41563 .33313 .41584 .32928 .41562 Metetra
.051 .617 .764 r
.32928 .41562 .33313 .41584 .33876 .41685 .33498 .41558 Metetra
.63 .891 .987 r
.33498 .41558 .33876 .41685 .34442 .41771 .34082 .41345 Metetra
.779 .74 .817 r
.34082 .41345 .34442 .41771 .35019 .41707 .34682 .40852 Metetra
.759 .626 .713 r
.34682 .40852 .35019 .41707 .3561 .41379 .35296 .40113 Metetra
.726 .566 .672 r
.35296 .40113 .3561 .41379 .36218 .40756 .35914 .39289 Metetra
.685 .526 .665 r
.35914 .39289 .36218 .40756 .36835 .3994 .36522 .38642 Metetra
.607 .488 .692 r
.36522 .38642 .36835 .3994 .37449 .39164 .37108 .38449 Metetra
.15 .314 .776 r
.37108 .38449 .37449 .39164 .38047 .38723 .37665 .3889 Metetra
.83 .42 .267 r
.37665 .3889 .38047 .38723 .38621 .38858 .382 .39939 Metetra
.757 .426 .425 r
.382 .39939 .38621 .38858 .39171 .39623 .38726 .41309 Metetra
.698 .388 .448 r
.38726 .41309 .39171 .39623 .39709 .40807 .39267 .425 Metetra
.603 .295 .419 r
.39267 .425 .39709 .40807 .40255 .41946 .39843 .42957 Metetra
.135 0 .133 r
.39843 .42957 .40255 .41946 .4083 .42474 .40463 .42318 Metetra
.947 .799 .665 r
.40463 .42318 .4083 .42474 .41443 .41981 .4112 .40629 Metetra
.831 .623 .622 r
.4112 .40629 .41443 .41981 .4209 .40456 .41791 .38408 Metetra
.766 .557 .615 r
.41791 .38408 .4209 .40456 .42749 .3838 .42446 .36487 Metetra
.676 .5 .639 r
.42446 .36487 .42749 .3838 .43396 .36563 .43061 .35712 Metetra
0 0 .574 r
.43061 .35712 .43396 .36563 .4401 .35823 .4363 .36627 Metetra
.856 .526 .427 r
.4363 .36627 .4401 .35823 .44584 .3663 .44159 .3924 Metetra
.788 .493 .488 r
.44159 .3924 .44584 .3663 .45131 .38871 .44675 .42927 Metetra
.736 .454 .502 r
.44675 .42927 .45131 .38871 .45674 .41788 .45209 .46531 Metetra
.664 .393 .5 r
.45209 .46531 .45674 .41788 .4624 .44198 .45787 .48721 Metetra
.518 .265 .471 r
.45787 .48721 .4624 .44198 .46846 .44971 .46418 .48562 Metetra
.109 0 .33 r
.46418 .48562 .46846 .44971 .47489 .43617 .47091 .46006 Metetra
.47091 .46006 .47489 .43617 .48152 .40595 .47778 .41975 Metetra
.952 .813 .37 r
.47778 .41975 .48152 .40595 .4881 .3712 .48451 .37956 Metetra
.951 .856 .435 r
.48451 .37956 .4881 .3712 .49449 .34584 .49095 .35398 Metetra
.382 .011 .203 r
.49095 .35398 .49449 .34584 .50065 .33962 .49711 .3521 Metetra
.809 .481 .434 r
.49711 .3521 .50065 .33962 .50669 .35461 .50312 .37508 Metetra
.826 .519 .469 r
.50312 .37508 .50669 .35461 .51275 .38434 .50915 .41564 Metetra
.79 .494 .487 r
.50915 .41564 .51275 .38434 .51894 .41593 .51535 .45959 Metetra
.708 .426 .496 r
.51535 .45959 .51894 .41593 .52529 .43509 .52176 .4902 Metetra
.562 .308 .488 r
.52176 .4902 .52529 .43509 .53168 .43264 .52829 .49486 Metetra
.356 .145 .45 r
.52829 .49486 .53168 .43264 .538 .40912 .53478 .47095 Metetra
.138 0 .385 r
.53478 .47095 .538 .40912 .54419 .37409 .54109 .42701 Metetra
0 0 .316 r
.54109 .42701 .54419 .37409 .55027 .3409 .54722 .37809 Metetra
0 0 .251 r
.54722 .37809 .55027 .3409 .55637 .32054 .55326 .33904 Metetra
0 0 .171 r
.55326 .33904 .55637 .32054 .56262 .31785 .55938 .31943 Metetra
.488 0 0 r
.55938 .31943 .56262 .31785 .56911 .33065 .56573 .32152 Metetra
.704 .376 0 r
.56573 .32152 .56911 .33065 .57579 .35122 .57237 .34055 Metetra
.8 .48 0 r
.57237 .34055 .57579 .35122 .58254 .36954 .57923 .3667 Metetra
.919 .524 .165 r
.57923 .3667 .58254 .36954 .58917 .37736 .58613 .3885 Metetra
.686 .333 .371 r
.58613 .3885 .58917 .37736 .59556 .37152 .59287 .39694 Metetra
.386 .13 .399 r
.59287 .39694 .59556 .37152 .60169 .35468 .59928 .38877 Metetra
.21 .011 .377 r
.59928 .38877 .60169 .35468 .60765 .33332 .60534 .36719 Metetra
.086 0 .337 r
.60534 .36719 .60765 .33332 .61361 .31445 .61117 .33962 Metetra
0 0 .256 r
.61117 .33962 .61361 .31445 .61975 .30288 .61698 .31421 Metetra
.61698 .31421 .61975 .30288 .62614 .30002 .62296 .29683 Metetra
.862 .828 .813 r
.62296 .29683 .62614 .30002 .63278 .30409 .62923 .28979 Metetra
.494 .409 .689 r
.62923 .28979 .63278 .30409 .63958 .31136 .63583 .29183 Metetra
.376 .296 .637 r
.63583 .29183 .63958 .31136 .64641 .31781 .64266 .29932 Metetra
.337 .275 .639 r
.64266 .29932 .64641 .31781 .65313 .32055 .64959 .30775 Metetra
.348 .332 .699 r
.64959 .30775 .65313 .32055 .65969 .31862 .65646 .31333 Metetra
.463 .589 .893 r
.65646 .31333 .65969 .31862 .6661 .31286 .66316 .31405 Metetra
.496 .888 .723 r
.66316 .31405 .6661 .31286 .67241 .3052 .66967 .30995 Metetra
.66967 .30995 .67241 .3052 .67873 .29771 .67603 .30259 Metetra
.67603 .30259 .67873 .29771 .68512 .29186 .68232 .29415 Metetra
.693 .923 .599 r
.68232 .29415 .68512 .29186 .69164 .28825 .68865 .28659 Metetra
.839 .932 .89 r
.68865 .28659 .69164 .28825 .69827 .2866 .69509 .28107 Metetra
.699 .693 .841 r
.69509 .28107 .69827 .2866 .70499 .28616 .70166 .27787 Metetra
.603 .564 .783 r
.70166 .27787 .70499 .28616 .71176 .28603 .70835 .27651 Metetra
.563 .516 .761 r
.70835 .27651 .71176 .28603 .71852 .28548 .71513 .27616 Metetra
.557 .516 .766 r
.71513 .27616 .71852 .28548 .72526 .28416 .72193 .27596 Metetra
.575 .552 .791 r
.72193 .27596 .72526 .28416 .73196 .28201 .72874 .27529 Metetra
.611 .612 .828 r
.72874 .27529 .73196 .28201 .73863 .27927 .73551 .27385 Metetra
.653 .681 .864 r
.73551 .27385 .73863 .27927 .7453 .27623 .74225 .27164 Metetra
.685 .734 .887 r
.74225 .27164 .7453 .27623 .75199 .27319 .74896 .2689 Metetra
.7 .755 .894 r
.74896 .2689 .75199 .27319 .7587 .27034 .75567 .2659 Metetra
.699 .747 .889 r
.75567 .2659 .7587 .27034 .76544 .26775 .7624 .26291 Metetra
.687 .724 .878 r
.7624 .26291 .76544 .26775 .77222 .26539 .76915 .26009 Metetra
.672 .697 .865 r
.76915 .26009 .77222 .26539 .77903 .26319 .77594 .25749 Metetra
.659 .675 .854 r
.77594 .25749 .77903 .26319 .78586 .26105 .78275 .2551 Metetra
.651 .661 .847 r
.78275 .2551 .78586 .26105 .7927 .2589 .7896 .25285 Metetra
.647 .656 .845 r
.7896 .25285 .7927 .2589 .79956 .2567 .79647 .25065 Metetra
.647 .657 .846 r
.79647 .25065 .79956 .2567 .80643 .25442 .80335 .24846 Metetra
.649 .662 .848 r
.80335 .24846 .80643 .25442 .81331 .25208 .81025 .24622 Metetra
.653 .668 .852 r
.81025 .24622 .81331 .25208 .8202 .24969 .81716 .24393 Metetra
.656 .673 .855 r
.81716 .24393 .8202 .24969 .82711 .24728 .82409 .24157 Metetra
.658 .677 .857 r
.82409 .24157 .82711 .24728 .83404 .24486 .83102 .23918 Metetra
.656 .667 .849 r
.21247 .44358 .21613 .44859 .22169 .44669 .21804 .44166 Metetra
.655 .666 .849 r
.21804 .44166 .22169 .44669 .22726 .44477 .22361 .43974 Metetra
.654 .666 .849 r
.22361 .43974 .22726 .44477 .23285 .44284 .2292 .43785 Metetra
.652 .667 .852 r
.2292 .43785 .23285 .44284 .23845 .44091 .23479 .43599 Metetra
.65 .67 .856 r
.23479 .43599 .23845 .44091 .24405 .43901 .2404 .43418 Metetra
.648 .673 .861 r
.2404 .43418 .24405 .43901 .24966 .43717 .24601 .43242 Metetra
.647 .677 .864 r
.24601 .43242 .24966 .43717 .25528 .4354 .25163 .43066 Metetra
.651 .679 .864 r
.25163 .43066 .25528 .4354 .26091 .43371 .25727 .42885 Metetra
.658 .677 .857 r
.25727 .42885 .26091 .43371 .26654 .43203 .26293 .42689 Metetra
.666 .668 .843 r
.26293 .42689 .26654 .43203 .2722 .43029 .26862 .42471 Metetra
.673 .655 .824 r
.26862 .42471 .2722 .43029 .27788 .42834 .27434 .4223 Metetra
.674 .64 .809 r
.27434 .4223 .27788 .42834 .2836 .4261 .28009 .41975 Metetra
.668 .629 .801 r
.28009 .41975 .2836 .4261 .28935 .42352 .28583 .41726 Metetra
.654 .626 .809 r
.28583 .41726 .28935 .42352 .29513 .42071 .29157 .41513 Metetra
.628 .638 .841 r
.29157 .41513 .29513 .42071 .30091 .41797 .29727 .41364 Metetra
.573 .673 .907 r
.29727 .41364 .30091 .41797 .30667 .41571 .30293 .41291 Metetra
.449 .721 .983 r
.30293 .41291 .30667 .41571 .31238 .41434 .30856 .41279 Metetra
.298 .733 .968 r
.30856 .41279 .31238 .41434 .31804 .41408 .31421 .41275 Metetra
.421 .81 .988 r
.31421 .41275 .31804 .41408 .32365 .41474 .31993 .41199 Metetra
.682 .803 .939 r
.31993 .41199 .32365 .41474 .32928 .41562 .32575 .4097 Metetra
.732 .669 .789 r
.32575 .4097 .32928 .41562 .33498 .41558 .33171 .40545 Metetra
.714 .582 .706 r
.33171 .40545 .33498 .41558 .34082 .41345 .33776 .39958 Metetra
.688 .533 .671 r
.33776 .39958 .34082 .41345 .34682 .40852 .34383 .39329 Metetra
.656 .504 .665 r
.34383 .39329 .34682 .40852 .35296 .40113 .34983 .3884 Metetra
.601 .486 .695 r
.34983 .3884 .35296 .40113 .35914 .39289 .35566 .38673 Metetra
.304 .45 .842 r
.35566 .38673 .35914 .39289 .36522 .38642 .36129 .38924 Metetra
.733 .298 .217 r
.36129 .38924 .36522 .38642 .37108 .38449 .36677 .3954 Metetra
.681 .343 .396 r
.36677 .3954 .37108 .38449 .37665 .3889 .37222 .40292 Metetra
.628 .306 .406 r
.37222 .40292 .37665 .3889 .382 .39939 .37782 .40836 Metetra
.487 .123 .273 r
.37782 .40836 .382 .39939 .38726 .41309 .3837 .4084 Metetra
.816 .734 .774 r
.3837 .4084 .38726 .41309 .39267 .425 .38989 .40147 Metetra
.702 .505 .618 r
.38989 .40147 .39267 .425 .39843 .42957 .3963 .38876 Metetra
.659 .449 .588 r
.3963 .38876 .39843 .42957 .40463 .42318 .40276 .37416 Metetra
.625 .416 .58 r
.40276 .37416 .40463 .42318 .4112 .40629 .40907 .36272 Metetra
.58 .386 .582 r
.40907 .36272 .4112 .40629 .41791 .38408 .41511 .35867 Metetra
.462 .326 .61 r
.41511 .35867 .41791 .38408 .42446 .36487 .42086 .36348 Metetra
.871 .433 .14 r
.42086 .36348 .42446 .36487 .43061 .35712 .42644 .37512 Metetra
.705 .396 .451 r
.42644 .37512 .43061 .35712 .4363 .36627 .43204 .38856 Metetra
.645 .348 .453 r
.43204 .38856 .4363 .36627 .44159 .3924 .43782 .39777 Metetra
.476 .046 .142 r
.43782 .39777 .44159 .3924 .44675 .42927 .44387 .39836 Metetra
.641 .446 .604 r
.44387 .39836 .44675 .42927 .45209 .46531 .45016 .38962 Metetra
.612 .396 .564 r
.45016 .38962 .45209 .46531 .45787 .48721 .45657 .37476 Metetra
.593 .374 .553 r
.45657 .37476 .45787 .48721 .46418 .48562 .46297 .35911 Metetra
.576 .359 .549 r
.46297 .35911 .46418 .48562 .47091 .46006 .46925 .34751 Metetra
.56 .348 .55 r
.46925 .34751 .47091 .46006 .47778 .41975 .47541 .34218 Metetra
.543 .341 .557 r
.47541 .34218 .47778 .41975 .48451 .37956 .4815 .3422 Metetra
.521 .348 .587 r
.4815 .3422 .48451 .37956 .49095 .35398 .48759 .3445 Metetra
.487 .465 .759 r
.48759 .3445 .49095 .35398 .49711 .3521 .49371 .34585 Metetra
.6 .612 .835 r
.49371 .34585 .49711 .3521 .50312 .37508 .49989 .34475 Metetra
.579 .401 .605 r
.49989 .34475 .50312 .37508 .50915 .41564 .50609 .34214 Metetra
.552 .349 .56 r
.50609 .34214 .50915 .41564 .51535 .45959 .51229 .3405 Metetra
.536 .329 .546 r
.51229 .3405 .51535 .45959 .52176 .4902 .51851 .34201 Metetra
.528 .32 .541 r
.51851 .34201 .52176 .4902 .52829 .49486 .52476 .34686 Metetra
.525 .318 .541 r
.52476 .34686 .52829 .49486 .53478 .47095 .53105 .35266 Metetra
.532 .326 .546 r
.53105 .35266 .53478 .47095 .54109 .42701 .53737 .35555 Metetra
.561 .357 .562 r
.53737 .35555 .54109 .42701 .54722 .37809 .54369 .35221 Metetra
.67 .476 .613 r
.54369 .35221 .54722 .37809 .55326 .33904 .54997 .34192 Metetra
.962 .927 .596 r
.54997 .34192 .55326 .33904 .55938 .31943 .55618 .32736 Metetra
.55618 .32736 .55938 .31943 .56573 .32152 .56237 .31348 Metetra
.785 .653 .718 r
.56237 .31348 .56573 .32152 .57237 .34055 .56861 .3053 Metetra
.542 .367 .594 r
.56861 .3053 .57237 .34055 .57923 .3667 .57497 .30569 Metetra
.487 .306 .561 r
.57497 .30569 .57923 .3667 .58613 .3885 .5815 .31418 Metetra
.471 .289 .552 r
.5815 .31418 .58613 .3885 .59287 .39694 .58818 .32705 Metetra
.473 .293 .555 r
.58818 .32705 .59287 .39694 .59928 .38877 .59491 .3388 Metetra
.5 .323 .572 r
.59491 .3388 .59928 .38877 .60534 .36719 .60157 .34437 Metetra
.598 .434 .63 r
.60157 .34437 .60534 .36719 .61117 .33962 .60804 .3412 Metetra
.936 .962 .67 r
.60804 .3412 .61117 .33962 .61698 .31421 .6143 .33015 Metetra
0 0 .202 r
.6143 .33015 .61698 .31421 .62296 .29683 .62041 .31483 Metetra
.077 0 .261 r
.62041 .31483 .62296 .29683 .62923 .28979 .62649 .29989 Metetra
0 0 .081 r
.62649 .29989 .62923 .28979 .63583 .29183 .63268 .28915 Metetra
.801 .86 .893 r
.63268 .28915 .63583 .29183 .64266 .29932 .63907 .28444 Metetra
.528 .427 .684 r
.63907 .28444 .64266 .29932 .64959 .30775 .64568 .28534 Metetra
.469 .347 .63 r
.64568 .28534 .64959 .30775 .65646 .31333 .65246 .28971 Metetra
.461 .337 .625 r
.65246 .28971 .65646 .31333 .66316 .31405 .65932 .29473 Metetra
.484 .371 .649 r
.65932 .29473 .66316 .31405 .66967 .30995 .66613 .29789 Metetra
.553 .472 .718 r
.66613 .29789 .66967 .30995 .67603 .30259 .67283 .29782 Metetra
.714 .731 .864 r
.67283 .29782 .67603 .30259 .68232 .29415 .6794 .29446 Metetra
.773 .997 .833 r
.6794 .29446 .68232 .29415 .68865 .28659 .68586 .28881 Metetra
.595 .888 .59 r
.68586 .28881 .68865 .28659 .69509 .28107 .69227 .28236 Metetra
.68 .958 .72 r
.69227 .28236 .69509 .28107 .70166 .27787 .69871 .27644 Metetra
.786 .948 .927 r
.69871 .27644 .70166 .27787 .70835 .27651 .70524 .2719 Metetra
.696 .735 .88 r
.70524 .2719 .70835 .27651 .71513 .27616 .71186 .26896 Metetra
.618 .601 .811 r
.71186 .26896 .71513 .27616 .72193 .27596 .71858 .26732 Metetra
.584 .547 .779 r
.71858 .26732 .72193 .27596 .72874 .27529 .72537 .2664 Metetra
.579 .539 .774 r
.72537 .2664 .72874 .27529 .73551 .27385 .73218 .26561 Metetra
.593 .561 .788 r
.73218 .26561 .73551 .27385 .74225 .27164 .739 .26448 Metetra
.619 .604 .814 r
.739 .26448 .74225 .27164 .74896 .2689 .7458 .26281 Metetra
.649 .654 .842 r
.7458 .26281 .74896 .2689 .75567 .2659 .75257 .2606 Metetra
.673 .697 .864 r
.75257 .2606 .75567 .2659 .7624 .26291 .75934 .25798 Metetra
.685 .719 .875 r
.75934 .25798 .7624 .26291 .76915 .26009 .7661 .25516 Metetra
.686 .72 .876 r
.7661 .25516 .76915 .26009 .77594 .25749 .77288 .25234 Metetra
.678 .707 .87 r
.77288 .25234 .77594 .25749 .78275 .2551 .77968 .24962 Metetra
.668 .689 .861 r
.77968 .24962 .78275 .2551 .7896 .25285 .78651 .24706 Metetra
.659 .673 .852 r
.78651 .24706 .7896 .25285 .79647 .25065 .79337 .24465 Metetra
.652 .662 .846 r
.79337 .24465 .79647 .25065 .80335 .24846 .80025 .24234 Metetra
.649 .656 .844 r
.80025 .24234 .80335 .24846 .81025 .24622 .80716 .24008 Metetra
.649 .656 .843 r
.80716 .24008 .81025 .24622 .81716 .24393 .81408 .23783 Metetra
.65 .658 .845 r
.81408 .23783 .81716 .24393 .82409 .24157 .82102 .23554 Metetra
.652 .662 .847 r
.82102 .23554 .82409 .24157 .83102 .23918 .82797 .23321 Metetra
.654 .663 .847 r
.20881 .43848 .21247 .44358 .21804 .44166 .21437 .43658 Metetra
.652 .664 .848 r
.21437 .43658 .21804 .44166 .22361 .43974 .21995 .43471 Metetra
.651 .666 .851 r
.21995 .43471 .22361 .43974 .2292 .43785 .22553 .43288 Metetra
.649 .668 .855 r
.22553 .43288 .2292 .43785 .23479 .43599 .23113 .43107 Metetra
.649 .671 .857 r
.23113 .43107 .23479 .43599 .2404 .43418 .23673 .42926 Metetra
.652 .672 .856 r
.23673 .42926 .2404 .43418 .24601 .43242 .24236 .4274 Metetra
.657 .67 .851 r
.24236 .4274 .24601 .43242 .25163 .43066 .248 .42543 Metetra
.664 .664 .84 r
.248 .42543 .25163 .43066 .25727 .42885 .25367 .42328 Metetra
.669 .654 .826 r
.25367 .42328 .25727 .42885 .26293 .42689 .25937 .42097 Metetra
.669 .643 .814 r
.25937 .42097 .26293 .42689 .26862 .42471 .26508 .41855 Metetra
.664 .633 .809 r
.26508 .41855 .26862 .42471 .27434 .4223 .2708 .4162 Metetra
.652 .63 .815 r
.2708 .4162 .27434 .4223 .28009 .41975 .27651 .41415 Metetra
.63 .638 .84 r
.27651 .41415 .28009 .41975 .28583 .41726 .28219 .41261 Metetra
.591 .664 .889 r
.28219 .41261 .28583 .41726 .29157 .41513 .28784 .41169 Metetra
.525 .708 .955 r
.28784 .41169 .29157 .41513 .29727 .41364 .29347 .41125 Metetra
.463 .757 .993 r
.29347 .41125 .29727 .41364 .30293 .41291 .29911 .41084 Metetra
.537 .808 .996 r
.29911 .41084 .30293 .41291 .30856 .41279 .30482 .40979 Metetra
.689 .788 .926 r
.30482 .40979 .30856 .41279 .31421 .41275 .31063 .40742 Metetra
.736 .689 .806 r
.31063 .40742 .31421 .41275 .31993 .41199 .31656 .40336 Metetra
.724 .608 .727 r
.31656 .40336 .31993 .41199 .32575 .4097 .32259 .3979 Metetra
.697 .555 .689 r
.32259 .3979 .32575 .4097 .33171 .40545 .32863 .3921 Metetra
.66 .519 .681 r
.32863 .3921 .33171 .40545 .33776 .39958 .33459 .38765 Metetra
.595 .491 .706 r
.33459 .38765 .33776 .39958 .34383 .39329 .34038 .38627 Metetra
.325 .429 .814 r
.34038 .38627 .34383 .39329 .34983 .3884 .34596 .38896 Metetra
.762 .283 .101 r
.34596 .38896 .34983 .3884 .35566 .38673 .35137 .39529 Metetra
.704 .351 .374 r
.35137 .39529 .35566 .38673 .36129 .38924 .35675 .40309 Metetra
.635 .312 .407 r
.35675 .40309 .36129 .38924 .36677 .3954 .36228 .40887 Metetra
.511 .187 .355 r
.36228 .40887 .36677 .3954 .37222 .40292 .36812 .40906 Metetra
.36812 .40906 .37222 .40292 .37782 .40836 .37433 .40174 Metetra
.856 .694 .68 r
.37433 .40174 .37782 .40836 .3837 .4084 .38083 .388 Metetra
.744 .542 .621 r
.38083 .388 .3837 .4084 .38989 .40147 .38738 .37214 Metetra
.671 .471 .605 r
.38738 .37214 .38989 .40147 .3963 .38876 .39373 .36035 Metetra
.574 .4 .608 r
.39373 .36035 .3963 .38876 .40276 .37416 .39967 .35837 Metetra
.11 .127 .596 r
.39967 .35837 .40276 .37416 .40907 .36272 .40515 .36905 Metetra
.852 .512 .409 r
.40515 .36905 .40907 .36272 .41511 .35867 .4103 .3906 Metetra
.723 .437 .492 r
.4103 .3906 .41511 .35867 .42086 .36348 .41541 .4164 Metetra
.647 .381 .502 r
.41541 .4164 .42086 .36348 .42644 .37512 .42082 .43666 Metetra
.565 .314 .494 r
.42082 .43666 .42644 .37512 .43204 .38856 .42676 .44235 Metetra
.425 .193 .456 r
.42676 .44235 .43204 .38856 .43782 .39777 .43326 .42966 Metetra
0 0 .258 r
.43326 .42966 .43782 .39777 .44387 .39836 .44011 .4026 Metetra
.998 .822 .541 r
.44011 .4026 .44387 .39836 .45016 .38962 .44698 .37165 Metetra
.801 .587 .612 r
.44698 .37165 .45016 .38962 .45657 .37476 .45355 .34931 Metetra
.607 .431 .618 r
.45355 .34931 .45657 .37476 .46297 .35911 .45969 .34506 Metetra
0 0 .42 r
.45969 .34506 .46297 .35911 .46925 .34751 .46545 .36189 Metetra
.836 .519 .454 r
.46545 .36189 .46925 .34751 .47541 .34218 .47102 .39479 Metetra
.709 .434 .506 r
.47102 .39479 .47541 .34218 .4815 .3422 .47667 .43178 Metetra
.625 .37 .512 r
.47667 .43178 .4815 .3422 .48759 .3445 .48264 .45778 Metetra
.545 .308 .506 r
.48264 .45778 .48759 .3445 .49371 .34585 .48898 .46108 Metetra
.456 .236 .49 r
.48898 .46108 .49371 .34585 .49989 .34475 .49557 .4393 Metetra
.339 .14 .458 r
.49557 .4393 .49989 .34475 .50609 .34214 .50223 .4008 Metetra
.139 0 .379 r
.50223 .4008 .50609 .34214 .51229 .3405 .50876 .36034 Metetra
0 0 .013 r
.50876 .36034 .51229 .3405 .51851 .34201 .51512 .33233 Metetra
.74 .606 .709 r
.51512 .33233 .51851 .34201 .52476 .34686 .52137 .32541 Metetra
.151 .125 .572 r
.52137 .32541 .52476 .34686 .53105 .35266 .52764 .34005 Metetra
.806 .507 0 r
.52764 .34005 .53105 .35266 .53737 .35555 .53402 .36882 Metetra
.835 .507 .433 r
.53402 .36882 .53737 .35555 .54369 .35221 .54055 .39886 Metetra
.644 .371 .49 r
.54055 .39886 .54369 .35221 .54997 .34192 .54714 .41676 Metetra
.521 .28 .491 r
.54714 .41676 .54997 .34192 .55618 .32736 .55364 .41427 Metetra
.425 .208 .478 r
.55364 .41427 .55618 .32736 .56237 .31348 .55995 .3919 Metetra
.332 .133 .454 r
.55995 .3919 .56237 .31348 .56861 .3053 .56603 .35812 Metetra
.201 .022 .4 r
.56603 .35812 .56861 .3053 .57497 .30569 .57201 .32471 Metetra
0 0 .129 r
.57201 .32471 .57497 .30569 .5815 .31418 .57806 .30166 Metetra
.723 .567 .678 r
.57806 .30166 .5815 .31418 .58818 .32705 .58432 .29387 Metetra
.463 .313 .592 r
.58432 .29387 .58818 .32705 .59491 .3388 .59088 .3004 Metetra
.359 .232 .568 r
.59088 .3004 .59491 .3388 .60157 .34437 .59768 .31557 Metetra
.267 .185 .574 r
.59768 .31557 .60157 .34437 .60804 .3412 .6046 .3314 Metetra
0 .136 .658 r
.6046 .3314 .60804 .3412 .6143 .33015 .61142 .34067 Metetra
.451 .103 .282 r
.61142 .34067 .6143 .33015 .62041 .31483 .618 .33956 Metetra
.323 .078 .379 r
.618 .33956 .62041 .31483 .62649 .29989 .62429 .32866 Metetra
.246 .029 .374 r
.62429 .32866 .62649 .29989 .63268 .28915 .63037 .31202 Metetra
.138 0 .316 r
.63037 .31202 .63268 .28915 .63907 .28444 .63639 .29496 Metetra
0 0 .045 r
.63639 .29496 .63907 .28444 .64568 .28534 .64251 .28191 Metetra
.853 .822 .817 r
.64251 .28191 .64568 .28534 .65246 .28971 .64885 .27508 Metetra
.571 .457 .684 r
.64885 .27508 .65246 .28971 .65932 .29473 .65544 .27427 Metetra
.486 .366 .642 r
.65544 .27427 .65932 .29473 .66613 .29789 .66223 .27747 Metetra
.459 .349 .641 r
.66223 .27747 .66613 .29789 .67283 .29782 .66911 .28189 Metetra
.469 .382 .675 r
.66911 .28189 .67283 .29782 .6794 .29446 .67598 .28505 Metetra
.531 .5 .767 r
.67598 .28505 .6794 .29446 .68586 .28881 .68275 .28544 Metetra
.681 .799 .937 r
.68275 .28544 .68586 .28881 .69227 .28236 .68938 .28285 Metetra
.675 .975 .825 r
.68938 .28285 .69227 .28236 .69871 .27644 .69591 .27805 Metetra
.611 .921 .67 r
.69591 .27805 .69871 .27644 .70524 .2719 .70239 .2723 Metetra
.744 .992 .822 r
.70239 .2723 .70524 .2719 .71186 .26896 .70889 .26681 Metetra
.787 .905 .923 r
.70889 .26681 .71186 .26896 .71858 .26732 .71545 .26236 Metetra
.701 .722 .866 r
.71545 .26236 .71858 .26732 .72537 .2664 .7221 .25923 Metetra
.633 .611 .81 r
.7221 .25923 .72537 .2664 .73218 .26561 .72884 .25723 Metetra
.6 .562 .784 r
.72884 .25723 .73218 .26561 .739 .26448 .73565 .25591 Metetra
.592 .554 .781 r
.73565 .25591 .739 .26448 .7458 .26281 .74249 .25479 Metetra
.601 .572 .793 r
.74249 .25479 .7458 .26281 .75257 .2606 .74933 .25346 Metetra
.621 .607 .815 r
.74933 .25346 .75257 .2606 .75934 .25798 .75617 .25173 Metetra
.645 .648 .839 r
.75617 .25173 .75934 .25798 .7661 .25516 .76299 .24956 Metetra
.664 .682 .857 r
.76299 .24956 .7661 .25516 .77288 .25234 .7698 .24706 Metetra
.675 .701 .866 r
.7698 .24706 .77288 .25234 .77968 .24962 .77662 .24438 Metetra
.677 .704 .868 r
.77662 .24438 .77968 .24962 .78651 .24706 .78344 .24165 Metetra
.673 .696 .863 r
.78344 .24165 .78651 .24706 .79337 .24465 .79029 .23899 Metetra
.666 .682 .856 r
.79029 .23899 .79337 .24465 .80025 .24234 .79716 .23643 Metetra
.658 .67 .849 r
.79716 .23643 .80025 .24234 .80716 .24008 .80406 .23399 Metetra
.653 .661 .845 r
.80406 .23399 .80716 .24008 .81408 .23783 .81098 .23163 Metetra
.65 .656 .842 r
.81098 .23163 .81408 .23783 .82102 .23554 .81792 .22932 Metetra
.65 .655 .842 r
.81792 .22932 .82102 .23554 .82797 .23321 .82488 .22701 Metetra
.652 .664 .849 r
.20513 .43339 .20881 .43848 .21437 .43658 .2107 .43153 Metetra
.651 .665 .851 r
.2107 .43153 .21437 .43658 .21995 .43471 .21627 .42969 Metetra
.651 .667 .852 r
.21627 .42969 .21995 .43471 .22553 .43288 .22186 .42784 Metetra
.653 .667 .851 r
.22186 .42784 .22553 .43288 .23113 .43107 .22747 .42595 Metetra
.657 .666 .847 r
.22747 .42595 .23113 .43107 .23673 .42926 .23309 .42397 Metetra
.661 .661 .839 r
.23309 .42397 .23673 .42926 .24236 .4274 .23874 .42187 Metetra
.665 .654 .829 r
.23874 .42187 .24236 .4274 .248 .42543 .24441 .41964 Metetra
.666 .646 .82 r
.24441 .41964 .248 .42543 .25367 .42328 .2501 .41735 Metetra
.662 .639 .817 r
.2501 .41735 .25367 .42328 .25937 .42097 .25579 .4151 Metetra
.653 .638 .823 r
.25579 .4151 .25937 .42097 .26508 .41855 .26148 .41307 Metetra
.636 .645 .842 r
.26148 .41307 .26508 .41855 .2708 .4162 .26714 .41143 Metetra
.609 .665 .879 r
.26714 .41143 .2708 .4162 .27651 .41415 .27279 .41026 Metetra
.573 .699 .927 r
.27279 .41026 .27651 .41415 .28219 .41261 .27842 .40945 Metetra
.551 .737 .962 r
.27842 .40945 .28219 .41261 .28784 .41169 .28406 .40869 Metetra
.596 .763 .959 r
.28406 .40869 .28784 .41169 .29347 .41125 .28975 .40745 Metetra
.678 .739 .897 r
.28975 .40745 .29347 .41125 .29911 .41084 .29554 .40522 Metetra
.715 .672 .807 r
.29554 .40522 .29911 .41084 .30482 .40979 .30142 .40166 Metetra
.713 .61 .741 r
.30142 .40166 .30482 .40979 .31063 .40742 .30739 .39696 Metetra
.695 .568 .707 r
.30739 .39696 .31063 .40742 .31656 .40336 .31338 .3919 Metetra
.668 .54 .7 r
.31338 .3919 .31656 .40336 .32259 .3979 .31932 .38774 Metetra
.617 .526 .729 r
.31932 .38774 .32259 .3979 .32863 .3921 .32512 .38587 Metetra
.428 .518 .848 r
.32512 .38587 .32863 .3921 .33459 .38765 .33074 .38718 Metetra
.655 .103 0 r
.33074 .38718 .33459 .38765 .34038 .38627 .33621 .3915 Metetra
.698 .301 .292 r
.33621 .3915 .34038 .38627 .34596 .38896 .34162 .39734 Metetra
.643 .28 .339 r
.34162 .39734 .34596 .38896 .35137 .39529 .34714 .40209 Metetra
.505 .107 .22 r
.34714 .40209 .35137 .39529 .35675 .40309 .35291 .40289 Metetra
.822 .965 .898 r
.35291 .40289 .35675 .40309 .36228 .40887 .359 .39789 Metetra
.772 .606 .674 r
.359 .39789 .36228 .40887 .36812 .40906 .36536 .38738 Metetra
.716 .519 .622 r
.36536 .38738 .36812 .40906 .37433 .40174 .37184 .37412 Metetra
.675 .477 .609 r
.37184 .37412 .37433 .40174 .38083 .388 .37821 .3626 Metetra
.619 .44 .617 r
.37821 .3626 .38083 .388 .38738 .37214 .38428 .3574 Metetra
.415 .346 .672 r
.38428 .3574 .38738 .37214 .39373 .36035 .38996 .3614 Metetra
.862 .462 .277 r
.38996 .3614 .39373 .36035 .39967 .35837 .39531 .37438 Metetra
.755 .441 .454 r
.39531 .37438 .39967 .35837 .40515 .36905 .40052 .39264 Metetra
.707 .41 .471 r
.40052 .39264 .40515 .36905 .4103 .3906 .40587 .40987 Metetra
.659 .353 .443 r
.40587 .40987 .4103 .3906 .41541 .4164 .41157 .41934 Metetra
.41157 .41934 .41541 .4164 .42082 .43666 .41772 .41669 Metetra
.739 .54 .625 r
.41772 .41669 .42082 .43666 .42676 .44235 .42427 .40193 Metetra
.702 .481 .586 r
.42427 .40193 .42676 .44235 .43326 .42966 .431 .37965 Metetra
.68 .458 .578 r
.431 .37965 .43326 .42966 .44011 .4026 .43768 .35706 Metetra
.655 .441 .582 r
.43768 .35706 .44011 .4026 .44698 .37165 .44412 .3413 Metetra
.597 .414 .604 r
.44412 .3413 .44698 .37165 .45355 .34931 .45025 .33701 Metetra
.14 .191 .655 r
.45025 .33701 .45355 .34931 .45969 .34506 .45612 .34514 Metetra
.9 .512 .276 r
.45612 .34514 .45969 .34506 .46545 .36189 .46185 .36286 Metetra
.906 .537 .322 r
.46185 .36286 .46545 .36189 .47102 .39479 .4676 .38447 Metetra
.699 .39 0 r
.4676 .38447 .47102 .39479 .47667 .43178 .47351 .40303 Metetra
.387 .266 .592 r
.47351 .40303 .47667 .43178 .48264 .45778 .47963 .41244 Metetra
.57 .377 .581 r
.47963 .41244 .48264 .45778 .48898 .46108 .48597 .40929 Metetra
.641 .426 .576 r
.48597 .40929 .48898 .46108 .49557 .4393 .49244 .39395 Metetra
.694 .471 .579 r
.49244 .39395 .49557 .4393 .50223 .4008 .49894 .37042 Metetra
.752 .527 .591 r
.49894 .37042 .50223 .4008 .50876 .36034 .50538 .34498 Metetra
.814 .604 .619 r
.50538 .34498 .50876 .36034 .51512 .33233 .51173 .32445 Metetra
.814 .667 .701 r
.51173 .32445 .51512 .33233 .52137 .32541 .51799 .31426 Metetra
.433 .405 .728 r
.51799 .31426 .52137 .32541 .52764 .34005 .52423 .31705 Metetra
.181 .139 .571 r
.52423 .31705 .52764 .34005 .53402 .36882 .53053 .33183 Metetra
.217 .129 .536 r
.53053 .33183 .53402 .36882 .54055 .39886 .53694 .35384 Metetra
.295 .176 .542 r
.53694 .35384 .54055 .39886 .54714 .41676 .54346 .37559 Metetra
.39 .25 .567 r
.54346 .37559 .54714 .41676 .55364 .41427 .55002 .38911 Metetra
.552 .395 .622 r
.55002 .38911 .55364 .41427 .55995 .3919 .55653 .38881 Metetra
.937 .797 .68 r
.55653 .38881 .55995 .3919 .56603 .35812 .56289 .37395 Metetra
.56289 .37395 .56603 .35812 .57201 .32471 .56907 .34891 Metetra
0 0 .183 r
.56907 .34891 .57201 .32471 .57806 .30166 .57513 .32137 Metetra
0 0 .164 r
.57513 .32137 .57806 .30166 .58432 .29387 .5812 .2992 Metetra
.672 .819 .381 r
.5812 .2992 .58432 .29387 .59088 .3004 .58741 .28771 Metetra
.532 .449 .707 r
.58741 .28771 .59088 .3004 .59768 .31557 .59387 .28829 Metetra
.376 .265 .598 r
.59387 .28829 .59768 .31557 .6046 .3314 .60058 .29829 Metetra
.345 .23 .577 r
.60058 .29829 .6046 .3314 .61142 .34067 .60747 .31222 Metetra
.354 .247 .592 r
.60747 .31222 .61142 .34067 .618 .33956 .61437 .32381 Metetra
.426 .355 .673 r
.61437 .32381 .618 .33956 .62429 .32866 .62112 .32819 Metetra
.757 .981 .912 r
.62112 .32819 .62429 .32866 .63037 .31202 .62763 .32362 Metetra
0 0 .118 r
.62763 .32362 .63037 .31202 .63639 .29496 .63388 .31168 Metetra
.012 0 .224 r
.63388 .31168 .63639 .29496 .64251 .28191 .63998 .29622 Metetra
0 0 .172 r
.63998 .29622 .64251 .28191 .64885 .27508 .64607 .28157 Metetra
.64607 .28157 .64885 .27508 .65544 .27427 .65229 .27098 Metetra
.809 .83 .867 r
.65229 .27098 .65544 .27427 .66223 .27747 .65872 .26582 Metetra
.559 .48 .723 r
.65872 .26582 .66223 .27747 .66911 .28189 .66538 .26554 Metetra
.481 .386 .671 r
.66538 .26554 .66911 .28189 .67598 .28505 .67221 .26827 Metetra
.465 .373 .667 r
.67221 .26827 .67598 .28505 .68275 .28544 .67911 .27169 Metetra
.487 .413 .698 r
.67911 .27169 .68275 .28544 .68938 .28285 .68598 .27381 Metetra
.557 .523 .774 r
.68598 .27381 .68938 .28285 .69591 .27805 .69276 .27355 Metetra
.684 .738 .891 r
.69276 .27355 .69591 .27805 .70239 .2723 .69942 .27084 Metetra
.78 .947 .931 r
.69942 .27084 .70239 .2723 .70889 .26681 .706 .26637 Metetra
.784 .991 .885 r
.706 .26637 .70889 .26681 .71545 .26236 .71254 .26118 Metetra
.8 .964 .913 r
.71254 .26118 .71545 .26236 .7221 .25923 .71909 .25623 Metetra
.766 .85 .914 r
.71909 .25623 .7221 .25923 .72884 .25723 .72571 .25215 Metetra
.694 .715 .865 r
.72571 .25215 .72884 .25723 .73565 .25591 .73241 .24913 Metetra
.639 .627 .822 r
.73241 .24913 .73565 .25591 .74249 .25479 .73919 .24702 Metetra
.611 .584 .799 r
.73919 .24702 .74249 .25479 .74933 .25346 .74602 .24547 Metetra
.603 .575 .795 r
.74602 .24547 .74933 .25346 .75617 .25173 .75289 .24408 Metetra
.61 .588 .803 r
.75289 .24408 .75617 .25173 .76299 .24956 .75976 .24255 Metetra
.626 .614 .819 r
.75976 .24255 .76299 .24956 .7698 .24706 .76663 .24071 Metetra
.644 .645 .836 r
.76663 .24071 .7698 .24706 .77662 .24438 .77349 .23852 Metetra
.66 .672 .85 r
.77349 .23852 .77662 .24438 .78344 .24165 .78035 .23607 Metetra
.669 .687 .858 r
.78035 .23607 .78344 .24165 .79029 .23899 .78721 .23346 Metetra
.671 .691 .86 r
.78721 .23346 .79029 .23899 .79716 .23643 .79408 .2308 Metetra
.668 .686 .857 r
.79408 .2308 .79716 .23643 .80406 .23399 .80098 .22818 Metetra
.663 .677 .853 r
.80098 .22818 .80406 .23399 .81098 .23163 .80789 .22564 Metetra
.658 .668 .848 r
.80789 .22564 .81098 .23163 .81792 .22932 .81483 .22318 Metetra
.654 .661 .844 r
.81483 .22318 .81792 .22932 .82488 .22701 .82179 .22079 Metetra
.652 .665 .85 r
.20144 .42832 .20513 .43339 .2107 .43153 .20701 .42645 Metetra
.654 .666 .849 r
.20701 .42645 .2107 .43153 .21627 .42969 .2126 .42453 Metetra
.657 .664 .845 r
.2126 .42453 .21627 .42969 .22186 .42784 .2182 .42255 Metetra
.66 .66 .84 r
.2182 .42255 .22186 .42784 .22747 .42595 .22383 .42048 Metetra
.663 .655 .832 r
.22383 .42048 .22747 .42595 .23309 .42397 .22947 .41832 Metetra
.663 .649 .826 r
.22947 .41832 .23309 .42397 .23874 .42187 .23513 .41612 Metetra
.66 .644 .824 r
.23513 .41612 .23874 .42187 .24441 .41964 .2408 .41395 Metetra
.652 .644 .829 r
.2408 .41395 .24441 .41964 .2501 .41735 .24646 .41196 Metetra
.64 .651 .845 r
.24646 .41196 .2501 .41735 .25579 .4151 .25211 .41026 Metetra
.621 .667 .873 r
.25211 .41026 .25579 .4151 .26148 .41307 .25775 .4089 Metetra
.6 .693 .908 r
.25775 .4089 .26148 .41307 .26714 .41143 .26338 .4078 Metetra
.593 .722 .934 r
.26338 .4078 .26714 .41143 .27279 .41026 .26902 .40672 Metetra
.624 .738 .928 r
.26902 .40672 .27279 .41026 .27842 .40945 .27471 .40526 Metetra
.676 .717 .88 r
.27471 .40526 .27842 .40945 .28406 .40869 .28047 .40302 Metetra
.704 .667 .81 r
.28047 .40302 .28406 .40869 .28975 .40745 .28631 .39976 Metetra
.704 .615 .754 r
.28631 .39976 .28975 .40745 .29554 .40522 .29223 .39563 Metetra
.69 .576 .722 r
.29223 .39563 .29554 .40522 .30142 .40166 .29817 .39125 Metetra
.664 .55 .716 r
.29817 .39125 .30142 .40166 .30739 .39696 .30406 .38761 Metetra
.618 .54 .744 r
.30406 .38761 .30739 .39696 .31338 .3919 .30984 .38582 Metetra
.473 .549 .853 r
.30984 .38582 .31338 .3919 .31932 .38774 .31546 .38656 Metetra
.48 0 0 r
.31546 .38656 .31932 .38774 .32512 .38587 .32096 .38968 Metetra
.662 .228 .207 r
.32096 .38968 .32512 .38587 .33074 .38718 .32642 .39392 Metetra
.607 .217 .279 r
.32642 .39392 .33074 .38718 .33621 .3915 .33197 .3971 Metetra
.426 0 .124 r
.33197 .3971 .33621 .3915 .34162 .39734 .33775 .3969 Metetra
.829 .951 .898 r
.33775 .3969 .34162 .39734 .34714 .40209 .34383 .39187 Metetra
.768 .611 .685 r
.34383 .39187 .34714 .40209 .35291 .40289 .35015 .3824 Metetra
.706 .516 .628 r
.35015 .3824 .35291 .40289 .359 .39789 .35655 .37102 Metetra
.659 .465 .612 r
.35655 .37102 .359 .39789 .36536 .38738 .36283 .36168 Metetra
.596 .421 .616 r
.36283 .36168 .36536 .38738 .37184 .37412 .36881 .35829 Metetra
.395 .323 .658 r
.36881 .35829 .37184 .37412 .37821 .3626 .37441 .36303 Metetra
.862 .45 .247 r
.37441 .36303 .37821 .3626 .38428 .3574 .37971 .37505 Metetra
.722 .413 .455 r
.37971 .37505 .38428 .3574 .38996 .3614 .38494 .39029 Metetra
.651 .366 .473 r
.38494 .39029 .38996 .3614 .39531 .37438 .39037 .40254 Metetra
.566 .287 .451 r
.39037 .40254 .39531 .37438 .40052 .39264 .39623 .40595 Metetra
.147 0 .196 r
.39623 .40595 .40052 .39264 .40587 .40987 .40255 .39779 Metetra
.821 .626 .639 r
.40255 .39779 .40587 .40987 .41157 .41934 .40921 .38017 Metetra
.698 .479 .587 r
.40921 .38017 .41157 .41934 .41772 .41669 .41593 .35939 Metetra
.637 .421 .572 r
.41593 .35939 .41772 .41669 .42427 .40193 .42245 .34317 Metetra
.579 .375 .568 r
.42245 .34317 .42427 .40193 .431 .37965 .4286 .33738 Metetra
.478 .309 .573 r
.4286 .33738 .431 .37965 .43768 .35706 .43442 .34357 Metetra
0 0 .47 r
.43442 .34357 .43768 .35706 .44412 .3413 .44006 .35821 Metetra
.729 .413 .445 r
.44006 .35821 .44412 .3413 .45025 .33701 .44574 .37389 Metetra
.604 .33 .475 r
.44574 .37389 .45025 .33701 .45612 .34514 .45167 .3825 Metetra
.488 .231 .45 r
.45167 .3825 .45612 .34514 .46185 .36286 .45791 .37899 Metetra
0 0 .139 r
.45791 .37899 .46185 .36286 .4676 .38447 .46438 .36405 Metetra
.775 .562 .611 r
.46438 .36405 .4676 .38447 .47351 .40303 .4709 .3437 Metetra
.64 .421 .57 r
.4709 .3437 .47351 .40303 .47963 .41244 .47732 .32618 Metetra
.576 .364 .556 r
.47732 .32618 .47963 .41244 .48597 .40929 .48358 .31801 Metetra
.526 .324 .549 r
.48358 .31801 .48597 .40929 .49244 .39395 .48969 .32117 Metetra
.473 .289 .549 r
.48969 .32117 .49244 .39395 .49894 .37042 .49577 .33238 Metetra
.389 .25 .568 r
.49577 .33238 .49894 .37042 .50538 .34498 .50191 .34462 Metetra
.697 .158 0 r
.50191 .34462 .50538 .34498 .51173 .32445 .50815 .35045 Metetra
.444 .176 .411 r
.50815 .35045 .51173 .32445 .51799 .31426 .51447 .34573 Metetra
.306 .075 .389 r
.51447 .34573 .51799 .31426 .52423 .31705 .52081 .33176 Metetra
0 0 .065 r
.52081 .33176 .52423 .31705 .53053 .33183 .52711 .31461 Metetra
.741 .55 .635 r
.52711 .31461 .53053 .33183 .53694 .35384 .53338 .3019 Metetra
.562 .365 .572 r
.53338 .3019 .53694 .35384 .54346 .37559 .53967 .29918 Metetra
.495 .304 .551 r
.53967 .29918 .54346 .37559 .55002 .38911 .54605 .30756 Metetra
.456 .274 .544 r
.54605 .30756 .55002 .38911 .55653 .38881 .55255 .32325 Metetra
.433 .263 .549 r
.55255 .32325 .55653 .38881 .56289 .37395 .55914 .33913 Metetra
.435 .29 .585 r
.55914 .33913 .56289 .37395 .56907 .34891 .56572 .34773 Metetra
.676 .93 .97 r
.56572 .34773 .56907 .34891 .57513 .32137 .57219 .34466 Metetra
.21 0 .331 r
.57219 .34466 .57513 .32137 .5812 .2992 .57848 .33055 Metetra
.192 0 .359 r
.57848 .33055 .5812 .2992 .58741 .28771 .58463 .31051 Metetra
.054 0 .277 r
.58463 .31051 .58741 .28771 .59387 .28829 .59074 .29152 Metetra
.886 .938 .567 r
.59074 .29152 .59387 .28829 .60058 .29829 .59695 .27943 Metetra
.597 .447 .649 r
.59695 .27943 .60058 .29829 .60747 .31222 .60338 .27686 Metetra
.475 .319 .589 r
.60338 .27686 .60747 .31222 .61437 .32381 .61005 .28273 Metetra
.435 .282 .575 r
.61005 .28273 .61437 .32381 .62112 .32819 .61691 .29302 Metetra
.426 .285 .585 r
.61691 .29302 .62112 .32819 .62763 .32362 .62381 .30254 Metetra
.459 .345 .637 r
.62381 .30254 .62763 .32362 .63388 .31168 .6306 .30695 Metetra
.68 .722 .881 r
.6306 .30695 .63388 .31168 .63998 .29622 .63718 .30432 Metetra
0 0 .007 r
.63718 .30432 .63998 .29622 .64607 .28157 .64354 .29549 Metetra
.05 0 .204 r
.64354 .29549 .64607 .28157 .65229 .27098 .64975 .28335 Metetra
0 0 .158 r
.64975 .28335 .65229 .27098 .65872 .26582 .65595 .27137 Metetra
.65595 .27137 .65872 .26582 .66538 .26554 .66225 .26232 Metetra
.799 .836 .879 r
.66225 .26232 .66538 .26554 .67221 .26827 .66873 .25745 Metetra
.581 .505 .735 r
.66873 .25745 .67221 .26827 .67911 .27169 .6754 .25649 Metetra
.509 .414 .682 r
.6754 .25649 .67911 .27169 .68598 .27381 .68223 .25801 Metetra
.493 .399 .677 r
.68223 .25801 .68598 .27381 .69276 .27355 .68912 .2602 Metetra
.512 .433 .704 r
.68912 .2602 .69276 .27355 .69942 .27084 .696 .26147 Metetra
.567 .523 .766 r
.696 .26147 .69942 .27084 .706 .26637 .7028 .26093 Metetra
.664 .687 .862 r
.7028 .26093 .706 .26637 .71254 .26118 .70952 .25847 Metetra
.756 .867 .93 r
.70952 .25847 .71254 .26118 .71909 .25623 .71616 .25459 Metetra
.783 .94 .93 r
.71616 .25459 .71909 .25623 .72571 .25215 .72277 .25008 Metetra
.781 .914 .93 r
.72277 .25008 .72571 .25215 .73241 .24913 .72939 .2457 Metetra
.745 .821 .911 r
.72939 .2457 .73241 .24913 .73919 .24702 .73607 .24195 Metetra
.69 .716 .869 r
.73607 .24195 .73919 .24702 .74602 .24547 .74281 .23901 Metetra
.646 .642 .832 r
.74281 .23901 .74602 .24547 .75289 .24408 .74962 .23676 Metetra
.622 .604 .811 r
.74962 .23676 .75289 .24408 .75976 .24255 .75648 .23497 Metetra
.614 .593 .805 r
.75648 .23497 .75976 .24255 .76663 .24071 .76337 .23332 Metetra
.619 .601 .81 r
.76337 .23332 .76663 .24071 .77349 .23852 .77028 .23159 Metetra
.63 .62 .822 r
.77028 .23159 .77349 .23852 .78035 .23607 .77718 .22964 Metetra
.644 .644 .835 r
.77718 .22964 .78035 .23607 .78721 .23346 .78408 .22743 Metetra
.656 .665 .847 r
.78408 .22743 .78721 .23346 .79408 .2308 .79099 .22501 Metetra
.664 .678 .854 r
.79099 .22501 .79408 .2308 .80098 .22818 .79789 .22246 Metetra
.666 .682 .856 r
.79789 .22246 .80098 .22818 .80789 .22564 .80481 .21986 Metetra
.665 .68 .854 r
.80481 .21986 .80789 .22564 .81483 .22318 .81175 .21728 Metetra
.661 .674 .851 r
.81175 .21728 .81483 .22318 .82179 .22079 .81871 .21475 Metetra
.657 .665 .846 r
.19774 .42319 .20144 .42832 .20701 .42645 .20333 .42121 Metetra
.659 .662 .842 r
.20333 .42121 .20701 .42645 .2126 .42453 .20893 .41916 Metetra
.661 .658 .836 r
.20893 .41916 .2126 .42453 .2182 .42255 .21455 .41706 Metetra
.661 .654 .832 r
.21455 .41706 .2182 .42255 .22383 .42048 .22019 .41491 Metetra
.659 .65 .83 r
.22019 .41491 .22383 .42048 .22947 .41832 .22583 .41281 Metetra
.653 .65 .835 r
.22583 .41281 .22947 .41832 .23513 .41612 .23147 .41083 Metetra
.643 .656 .847 r
.23147 .41083 .23513 .41612 .2408 .41395 .23711 .40908 Metetra
.63 .669 .868 r
.23711 .40908 .2408 .41395 .24646 .41196 .24273 .40757 Metetra
.618 .688 .893 r
.24273 .40757 .24646 .41196 .25211 .41026 .24835 .40626 Metetra
.616 .708 .911 r
.24835 .40626 .25211 .41026 .25775 .4089 .25399 .40495 Metetra
.637 .718 .906 r
.25399 .40495 .25775 .4089 .26338 .4078 .25967 .40334 Metetra
.672 .703 .87 r
.25967 .40334 .26338 .4078 .26902 .40672 .2654 .40113 Metetra
.696 .666 .817 r
.2654 .40113 .26902 .40672 .27471 .40526 .27121 .39814 Metetra
.699 .624 .77 r
.27121 .39814 .27471 .40526 .28047 .40302 .27709 .39445 Metetra
.688 .59 .741 r
.27709 .39445 .28047 .40302 .28631 .39976 .28298 .39055 Metetra
.666 .568 .735 r
.28298 .39055 .28631 .39976 .29223 .39563 .28884 .38722 Metetra
.626 .561 .762 r
.28884 .38722 .29223 .39563 .29817 .39125 .2946 .38536 Metetra
.514 .577 .857 r
.2946 .38536 .29817 .39125 .30406 .38761 .30023 .38555 Metetra
0 .383 .756 r
.30023 .38555 .30406 .38761 .30984 .38582 .30575 .38773 Metetra
.617 .117 .041 r
.30575 .38773 .30984 .38582 .31546 .38656 .31122 .39093 Metetra
.582 .142 .171 r
.31122 .39093 .31546 .38656 .32096 .38968 .31677 .39341 Metetra
.363 0 0 r
.31677 .39341 .32096 .38968 .32642 .39392 .32252 .3932 Metetra
.792 .942 .925 r
.32252 .3932 .32642 .39392 .33197 .3971 .32854 .38895 Metetra
.777 .642 .712 r
.32854 .38895 .33197 .3971 .33775 .3969 .33479 .38079 Metetra
.721 .542 .647 r
.33479 .38079 .33775 .3969 .34383 .39187 .34115 .37067 Metetra
.676 .491 .629 r
.34115 .37067 .34383 .39187 .35015 .3824 .34741 .36193 Metetra
.614 .449 .636 r
.34741 .36193 .35015 .3824 .35655 .37102 .35339 .35818 Metetra
.403 .357 .693 r
.35339 .35818 .35655 .37102 .36283 .36168 .359 .36181 Metetra
.854 .43 .218 r
.359 .36181 .36283 .36168 .36881 .35829 .36427 .37271 Metetra
.742 .423 .443 r
.36427 .37271 .36881 .35829 .37441 .36303 .3694 .38785 Metetra
.678 .385 .469 r
.3694 .38785 .37441 .36303 .37971 .37505 .37465 .40182 Metetra
.608 .322 .457 r
.37465 .40182 .37971 .37505 .38494 .39029 .3803 .40876 Metetra
.416 .124 .359 r
.3803 .40876 .38494 .39029 .39037 .40254 .38646 .40488 Metetra
.978 .913 .662 r
.38646 .40488 .39037 .40254 .39623 .40595 .39305 .39051 Metetra
.806 .6 .624 r
.39305 .39051 .39623 .40595 .40255 .39779 .39984 .37037 Metetra
.726 .514 .603 r
.39984 .37037 .40255 .39779 .40921 .38017 .40651 .35188 Metetra
.656 .46 .608 r
.40651 .35188 .40921 .38017 .41593 .35939 .41282 .34222 Metetra
.454 .356 .654 r
.41282 .34222 .41593 .35939 .42245 .34317 .41868 .34567 Metetra
.866 .489 .328 r
.41868 .34567 .42245 .34317 .4286 .33738 .42417 .36193 Metetra
.743 .444 .476 r
.42417 .36193 .4286 .33738 .43442 .34357 .4295 .38593 Metetra
.68 .402 .494 r
.4295 .38593 .43442 .34357 .44006 .35821 .43498 .40915 Metetra
.615 .349 .492 r
.43498 .40915 .44006 .35821 .44574 .37389 .44082 .42264 Metetra
.511 .259 .469 r
.44082 .42264 .44574 .37389 .45167 .3825 .4471 .42059 Metetra
.284 .063 .391 r
.4471 .42059 .45167 .3825 .45791 .37899 .45374 .40301 Metetra
0 0 .109 r
.45374 .40301 .45791 .37899 .46438 .36405 .46053 .37584 Metetra
.88 .819 .342 r
.46053 .37584 .46438 .36405 .4709 .3437 .46724 .34841 Metetra
.974 .9 .548 r
.46724 .34841 .4709 .3437 .47732 .32618 .47372 .32982 Metetra
.47372 .32982 .47732 .32618 .48358 .31801 .47995 .32591 Metetra
.761 .395 .362 r
.47995 .32591 .48358 .31801 .48969 .32117 .48599 .33752 Metetra
.78 .46 .445 r
.48599 .33752 .48969 .32117 .49577 .33238 .49198 .36026 Metetra
.735 .436 .474 r
.49198 .36026 .49577 .33238 .50191 .34462 .49806 .38562 Metetra
.656 .377 .485 r
.49806 .38562 .50191 .34462 .50815 .35045 .50431 .40369 Metetra
.55 .294 .48 r
.50431 .40369 .50815 .35045 .51447 .34573 .51073 .40679 Metetra
.43 .2 .462 r
.51073 .40679 .51447 .34573 .52081 .33176 .51722 .39283 Metetra
.316 .11 .434 r
.51722 .39283 .52081 .33176 .52711 .31461 .52368 .36622 Metetra
.216 .027 .396 r
.52368 .36622 .52711 .31461 .53338 .3019 .53006 .33591 Metetra
.121 0 .336 r
.53006 .33591 .53338 .3019 .53967 .29918 .53636 .31164 Metetra
0 0 .129 r
.53636 .31164 .53967 .29918 .54605 .30756 .54265 .30035 Metetra
.252 .386 .805 r
.54265 .30035 .54605 .30756 .55255 .32325 .54904 .30417 Metetra
.043 .065 .556 r
.54904 .30417 .55255 .32325 .55914 .33913 .55559 .31989 Metetra
0 0 .483 r
.55559 .31989 .55914 .33913 .56572 .34773 .56228 .34017 Metetra
.693 .331 0 r
.56228 .34017 .56572 .34773 .57219 .34466 .56901 .35607 Metetra
.609 .255 .345 r
.56901 .35607 .57219 .34466 .57848 .33055 .57566 .3605 Metetra
.382 .133 .407 r
.57566 .3605 .57848 .33055 .58463 .31051 .58209 .35101 Metetra
.281 .07 .405 r
.58209 .35101 .58463 .31051 .59074 .29152 .58829 .33061 Metetra
.201 .008 .38 r
.58829 .33061 .59074 .29152 .59695 .27943 .59434 .306 Metetra
.075 0 .304 r
.59434 .306 .59695 .27943 .60338 .27686 .60039 .28453 Metetra
.60039 .28453 .60338 .27686 .61005 .28273 .60659 .27147 Metetra
.637 .531 .718 r
.60659 .27147 .61005 .28273 .61691 .29302 .61305 .26853 Metetra
.452 .327 .618 r
.61305 .26853 .61691 .29302 .62381 .30254 .61977 .27387 Metetra
.398 .277 .597 r
.61977 .27387 .62381 .30254 .6306 .30695 .62668 .2832 Metetra
.385 .284 .615 r
.62668 .2832 .6306 .30695 .63718 .30432 .63361 .29154 Metetra
.428 .385 .709 r
.63361 .29154 .63718 .30432 .64354 .29549 .64042 .295 Metetra
.591 .938 .938 r
.64042 .295 .64354 .29549 .64975 .28335 .64703 .29203 Metetra
0 0 .061 r
.64703 .29203 .64975 .28335 .65595 .27137 .65342 .28359 Metetra
.02 0 .165 r
.65342 .28359 .65595 .27137 .66225 .26232 .65967 .27234 Metetra
0 0 .076 r
.65967 .27234 .66225 .26232 .66873 .25745 .66592 .26134 Metetra
.66592 .26134 .66873 .25745 .6754 .25649 .67226 .25295 Metetra
.789 .819 .876 r
.67226 .25295 .6754 .25649 .68223 .25801 .67878 .24822 Metetra
.596 .532 .752 r
.67878 .24822 .68223 .25801 .68912 .2602 .68549 .24685 Metetra
.526 .441 .703 r
.68549 .24685 .68912 .2602 .696 .26147 .69232 .24763 Metetra
.508 .426 .698 r
.69232 .24763 .696 .26147 .7028 .26093 .69923 .24904 Metetra
.525 .459 .724 r
.69923 .24904 .7028 .26093 .70952 .25847 .70612 .24973 Metetra
.575 .542 .78 r
.70612 .24973 .70952 .25847 .71616 .25459 .71296 .24897 Metetra
.656 .678 .859 r
.71296 .24897 .71616 .25459 .72277 .25008 .71972 .24665 Metetra
.731 .818 .918 r
.71972 .24665 .72277 .25008 .72939 .2457 .72642 .24316 Metetra
.763 .882 .931 r
.72642 .24316 .72939 .2457 .73607 .24195 .73309 .23911 Metetra
.76 .863 .925 r
.73309 .23911 .73607 .24195 .74281 .23901 .73978 .23513 Metetra
.729 .793 .903 r
.73978 .23513 .74281 .23901 .74962 .23676 .74651 .23161 Metetra
.686 .713 .868 r
.74651 .23161 .74962 .23676 .75648 .23497 .75329 .2287 Metetra
.651 .653 .839 r
.75329 .2287 .75648 .23497 .76337 .23332 .76014 .22635 Metetra
.631 .62 .821 r
.76014 .22635 .76337 .23332 .77028 .23159 .76703 .22437 Metetra
.623 .609 .815 r
.76703 .22437 .77028 .23159 .77718 .22964 .77395 .22253 Metetra
.626 .614 .818 r
.77395 .22253 .77718 .22964 .78408 .22743 .78088 .22064 Metetra
.634 .628 .827 r
.78088 .22064 .78408 .22743 .79099 .22501 .78782 .21859 Metetra
.645 .647 .837 r
.78782 .21859 .79099 .22501 .79789 .22246 .79477 .21636 Metetra
.654 .663 .846 r
.79477 .21636 .79789 .22246 .80481 .21986 .80171 .21395 Metetra
.66 .674 .852 r
.80171 .21395 .80481 .21986 .81175 .21728 .80867 .21144 Metetra
.663 .678 .854 r
.80867 .21144 .81175 .21728 .81871 .21475 .81563 .20888 Metetra
.66 .662 .841 r
.19404 .41794 .19774 .42319 .20333 .42121 .19964 .41587 Metetra
.66 .659 .838 r
.19964 .41587 .20333 .42121 .20893 .41916 .20525 .41378 Metetra
.658 .657 .837 r
.20525 .41378 .20893 .41916 .21455 .41706 .21087 .41172 Metetra
.654 .657 .841 r
.21087 .41172 .21455 .41706 .22019 .41491 .21649 .40975 Metetra
.646 .662 .851 r
.21649 .40975 .22019 .41491 .22583 .41281 .22211 .40794 Metetra
.637 .672 .866 r
.22211 .40794 .22583 .41281 .23147 .41083 .22773 .40632 Metetra
.63 .686 .884 r
.22773 .40632 .23147 .41083 .23711 .40908 .23334 .40483 Metetra
.63 .7 .896 r
.23334 .40483 .23711 .40908 .24273 .40757 .23897 .40334 Metetra
.645 .705 .891 r
.23897 .40334 .24273 .40757 .24835 .40626 .24463 .40162 Metetra
.669 .694 .864 r
.24463 .40162 .24835 .40626 .25399 .40495 .25035 .39944 Metetra
.688 .666 .823 r
.25035 .39944 .25399 .40495 .25967 .40334 .25612 .39667 Metetra
.693 .633 .784 r
.25612 .39667 .25967 .40334 .2654 .40113 .26195 .39337 Metetra
.685 .604 .759 r
.26195 .39337 .2654 .40113 .27121 .39814 .2678 .38989 Metetra
.667 .586 .755 r
.2678 .38989 .27121 .39814 .27709 .39445 .27363 .38686 Metetra
.633 .583 .78 r
.27363 .38686 .27709 .39445 .28298 .39055 .27937 .38494 Metetra
.549 .606 .863 r
.27937 .38494 .28298 .39055 .28884 .38722 .28501 .38463 Metetra
.149 .578 .93 r
.28501 .38463 .28884 .38722 .2946 .38536 .29055 .38588 Metetra
.477 0 0 r
.29055 .38588 .2946 .38536 .30023 .38555 .29606 .38796 Metetra
.497 0 0 r
.29606 .38796 .30023 .38555 .30575 .38773 .30163 .38953 Metetra
.164 0 0 r
.30163 .38953 .30575 .38773 .31122 .39093 .30736 .38901 Metetra
.769 .869 .922 r
.30736 .38901 .31122 .39093 .31677 .39341 .31333 .38529 Metetra
.757 .633 .723 r
.31333 .38529 .31677 .39341 .32252 .3932 .31951 .3784 Metetra
.713 .544 .658 r
.31951 .3784 .32252 .3932 .32854 .38895 .32578 .36982 Metetra
.673 .496 .638 r
.32578 .36982 .32854 .38895 .33479 .38079 .33199 .36221 Metetra
.619 .461 .646 r
.33199 .36221 .33479 .38079 .34115 .37067 .33796 .3585 Metetra
.461 .404 .707 r
.33796 .3585 .34115 .37067 .34741 .36193 .3436 .36067 Metetra
.814 .333 .044 r
.3436 .36067 .34741 .36193 .35339 .35818 .34895 .36873 Metetra
.737 .4 .41 r
.34895 .36873 .35339 .35818 .359 .36181 .35416 .38028 Metetra
.676 .368 .446 r
.35416 .38028 .359 .36181 .36427 .37271 .35947 .39097 Metetra
.606 .298 .422 r
.35947 .39097 .36427 .37271 .3694 .38785 .36512 .3961 Metetra
.256 0 .127 r
.36512 .3961 .3694 .38785 .37465 .40182 .37123 .39262 Metetra
.808 .644 .679 r
.37123 .39262 .37465 .40182 .3803 .40876 .37772 .38076 Metetra
.711 .502 .604 r
.37772 .38076 .3803 .40876 .38646 .40488 .38441 .3642 Metetra
.664 .452 .586 r
.38441 .3642 .38646 .40488 .39305 .39051 .391 .34867 Metetra
.619 .416 .584 r
.391 .34867 .39305 .39051 .39984 .37037 .3973 .33957 Metetra
.54 .37 .599 r
.3973 .33957 .39984 .37037 .40651 .35188 .40323 .3398 Metetra
.049 .131 .629 r
.40323 .3398 .40651 .35188 .41282 .34222 .40887 .34865 Metetra
.797 .433 .368 r
.40887 .34865 .41282 .34222 .41868 .34567 .4144 .36201 Metetra
.699 .381 .434 r
.4144 .36201 .41868 .34567 .42417 .36193 .42006 .37396 Metetra
.628 .287 .374 r
.42006 .37396 .42417 .36193 .4295 .38593 .42598 .3792 Metetra
.71 .65 .788 r
.42598 .3792 .4295 .38593 .43498 .40915 .43222 .37528 Metetra
.657 .453 .596 r
.43222 .37528 .43498 .40915 .44082 .42264 .43867 .36343 Metetra
.632 .415 .57 r
.43867 .36343 .44082 .42264 .4471 .42059 .44521 .3476 Metetra
.613 .396 .562 r
.44521 .3476 .4471 .42059 .45374 .40301 .45169 .3324 Metetra
.598 .384 .562 r
.45169 .3324 .45374 .40301 .46053 .37584 .45805 .32109 Metetra
.584 .38 .57 r
.45805 .32109 .46053 .37584 .46724 .34841 .46429 .31472 Metetra
.569 .387 .595 r
.46429 .31472 .46724 .34841 .47372 .32982 .47046 .31242 Metetra
.543 .416 .658 r
.47046 .31242 .47372 .32982 .47995 .32591 .4766 .3126 Metetra
.5 .42 .697 r
.4766 .3126 .47995 .32591 .48599 .33752 .48275 .31408 Metetra
.498 .359 .622 r
.48275 .31408 .48599 .33752 .49198 .36026 .48892 .31667 Metetra
.502 .326 .575 r
.48892 .31667 .49198 .36026 .49806 .38562 .4951 .32077 Metetra
.503 .314 .556 r
.4951 .32077 .49806 .38562 .50431 .40369 .50132 .3264 Metetra
.507 .312 .551 r
.50132 .3264 .50431 .40369 .51073 .40679 .50757 .33235 Metetra
.518 .322 .554 r
.50757 .33235 .51073 .40679 .51722 .39283 .51388 .3361 Metetra
.549 .352 .567 r
.51388 .3361 .51722 .39283 .52368 .36622 .52024 .33488 Metetra
.627 .434 .601 r
.52024 .33488 .52368 .36622 .53006 .33591 .52661 .32723 Metetra
.833 .666 .675 r
.52661 .32723 .53006 .33591 .53636 .31164 .53296 .31432 Metetra
.965 .929 .609 r
.53296 .31432 .53636 .31164 .54265 .30035 .53928 .29991 Metetra
.955 .908 .733 r
.53928 .29991 .54265 .30035 .54904 .30417 .54558 .28901 Metetra
.622 .484 .673 r
.54558 .28901 .54904 .30417 .55559 .31989 .55193 .28579 Metetra
.468 .314 .588 r
.55193 .28579 .55559 .31989 .56228 .34017 .55839 .29172 Metetra
.418 .262 .56 r
.55839 .29172 .56228 .34017 .56901 .35607 .56499 .30478 Metetra
.405 .25 .555 r
.56499 .30478 .56901 .35607 .57566 .3605 .5717 .31994 Metetra
.419 .271 .572 r
.5717 .31994 .57566 .3605 .58209 .35101 .57842 .33095 Metetra
.506 .382 .644 r
.57842 .33095 .58209 .35101 .58829 .33061 .58505 .33291 Metetra
.808 .967 .655 r
.58505 .33291 .58829 .33061 .59434 .306 .59148 .32432 Metetra
0 0 .221 r
.59148 .32432 .59434 .306 .60039 .28453 .59771 .30767 Metetra
.049 0 .277 r
.59771 .30767 .60039 .28453 .60659 .27147 .60383 .28818 Metetra
0 0 .187 r
.60383 .28818 .60659 .27147 .61305 .26853 .60997 .27153 Metetra
.799 .935 .572 r
.60997 .27153 .61305 .26853 .61977 .27387 .61626 .2617 Metetra
.601 .5 .711 r
.61626 .2617 .61977 .27387 .62668 .2832 .62279 .2599 Metetra
.462 .338 .624 r
.62279 .2599 .62668 .2832 .63361 .29154 .62956 .26447 Metetra
.424 .3 .606 r
.62956 .26447 .63361 .29154 .64042 .295 .63647 .27189 Metetra
.427 .315 .623 r
.63647 .27189 .64042 .295 .64703 .29203 .6434 .27815 Metetra
.485 .41 .697 r
.6434 .27815 .64703 .29203 .65342 .28359 .65021 .28024 Metetra
.715 .813 .926 r
.65021 .28024 .65342 .28359 .65967 .27234 .65683 .27709 Metetra
.65683 .27709 .65967 .27234 .66592 .26134 .66327 .26957 Metetra
0 0 .001 r
.66327 .26957 .66592 .26134 .67226 .25295 .6696 .25988 Metetra
.6696 .25988 .67226 .25295 .67878 .24822 .67593 .25048 Metetra
.665 .915 .6 r
.67593 .25048 .67878 .24822 .68549 .24685 .68236 .24324 Metetra
.769 .813 .888 r
.68236 .24324 .68549 .24685 .69232 .24763 .68893 .23897 Metetra
.607 .561 .776 r
.68893 .23897 .69232 .24763 .69923 .24904 .69567 .2374 Metetra
.542 .472 .727 r
.69567 .2374 .69923 .24904 .70612 .24973 .70253 .23756 Metetra
.527 .456 .72 r
.70253 .23756 .70612 .24973 .71296 .24897 .70944 .23821 Metetra
.543 .486 .742 r
.70944 .23821 .71296 .24897 .71972 .24665 .71635 .2383 Metetra
.587 .558 .789 r
.71635 .2383 .71972 .24665 .72642 .24316 .72321 .23726 Metetra
.651 .666 .851 r
.72321 .23726 .72642 .24316 .73309 .23911 .73001 .23498 Metetra
.711 .773 .901 r
.73001 .23498 .73309 .23911 .73978 .23513 .73677 .23177 Metetra
.739 .827 .919 r
.73677 .23177 .73978 .23513 .74651 .23161 .7435 .2281 Metetra
.738 .819 .915 r
.7435 .2281 .74651 .23161 .75329 .2287 .75025 .22445 Metetra
.714 .769 .896 r
.75025 .22445 .75329 .2287 .76014 .22635 .75703 .22114 Metetra
.682 .71 .869 r
.75703 .22114 .76014 .22635 .76703 .22437 .76386 .2183 Metetra
.655 .663 .846 r
.76386 .2183 .76703 .22437 .77395 .22253 .77074 .21589 Metetra
.638 .635 .831 r
.77074 .21589 .77395 .22253 .78088 .22064 .77767 .21376 Metetra
.631 .625 .825 r
.77767 .21376 .78088 .22064 .78782 .21859 .78462 .21176 Metetra
.632 .627 .827 r
.78462 .21176 .78782 .21859 .79477 .21636 .79159 .20974 Metetra
.638 .637 .833 r
.79159 .20974 .79477 .21636 .80171 .21395 .79856 .2076 Metetra
.646 .651 .841 r
.79856 .2076 .80171 .21395 .80867 .21144 .80555 .20533 Metetra
.653 .664 .848 r
.80555 .20533 .80867 .21144 .81563 .20888 .81254 .20292 Metetra
.658 .664 .844 r
.19033 .41273 .19404 .41794 .19964 .41587 .19592 .4107 Metetra
.655 .664 .847 r
.19592 .4107 .19964 .41587 .20525 .41378 .20153 .40874 Metetra
.649 .668 .855 r
.20153 .40874 .20525 .41378 .21087 .41172 .20713 .4069 Metetra
.643 .676 .866 r
.20713 .4069 .21087 .41172 .21649 .40975 .21273 .40518 Metetra
.638 .686 .878 r
.21273 .40518 .21649 .40975 .22211 .40794 .21834 .40356 Metetra
.639 .695 .886 r
.21834 .40356 .22211 .40794 .22773 .40632 .22396 .40192 Metetra
.65 .699 .882 r
.22396 .40192 .22773 .40632 .23334 .40483 .22961 .40012 Metetra
.667 .69 .862 r
.22961 .40012 .23334 .40483 .23897 .40334 .2353 .39797 Metetra
.682 .669 .83 r
.2353 .39797 .23897 .40334 .24463 .40162 .24104 .39536 Metetra
.687 .642 .799 r
.24104 .39536 .24463 .40162 .25035 .39944 .24683 .39237 Metetra
.682 .618 .777 r
.24683 .39237 .25035 .39944 .25612 .39667 .25264 .38924 Metetra
.667 .603 .774 r
.25264 .38924 .25612 .39667 .26195 .39337 .25843 .38644 Metetra
.639 .603 .797 r
.25843 .38644 .26195 .39337 .2678 .38989 .26415 .38451 Metetra
.575 .627 .866 r
.26415 .38451 .2678 .38989 .27363 .38686 .2698 .38382 Metetra
.348 .66 .972 r
.2698 .38382 .27363 .38686 .27937 .38494 .27536 .38436 Metetra
.202 0 0 r
.27536 .38436 .27937 .38494 .28501 .38463 .28089 .38558 Metetra
.32 0 0 r
.28089 .38558 .28501 .38463 .29055 .38588 .28647 .38641 Metetra
.106 .658 .71 r
.28647 .38641 .29055 .38588 .29606 .38796 .2922 .3856 Metetra
.749 .84 .92 r
.2922 .3856 .29606 .38796 .30163 .38953 .29812 .38224 Metetra
.752 .646 .743 r
.29812 .38224 .30163 .38953 .30736 .38901 .30424 .37627 Metetra
.714 .558 .676 r
.30424 .37627 .30736 .38901 .31333 .38529 .31044 .36887 Metetra
.676 .51 .653 r
.31044 .36887 .31333 .38529 .31951 .3784 .31659 .36221 Metetra
.624 .476 .661 r
.31659 .36221 .31951 .3784 .32578 .36982 .32253 .35878 Metetra
.478 .43 .725 r
.32253 .35878 .32578 .36982 .33199 .36221 .32817 .36037 Metetra
.761 .247 0 r
.32817 .36037 .33199 .36221 .33796 .3585 .33353 .36711 Metetra
.735 .384 .386 r
.33353 .36711 .33796 .3585 .3436 .36067 .33874 .37704 Metetra
.672 .358 .433 r
.33874 .37704 .3436 .36067 .34895 .36873 .34405 .38645 Metetra
.6 .29 .417 r
.34405 .38645 .34895 .36873 .35416 .38028 .34966 .39111 Metetra
.356 .013 .24 r
.34966 .39111 .35416 .38028 .35947 .39097 .35572 .38812 Metetra
.898 .795 .738 r
.35572 .38812 .35947 .39097 .36512 .3961 .36217 .37749 Metetra
.749 .551 .628 r
.36217 .37749 .36512 .3961 .37123 .39262 .36882 .3625 Metetra
.684 .479 .602 r
.36882 .3625 .37123 .39262 .37772 .38076 .37539 .34858 Metetra
.624 .43 .599 r
.37539 .34858 .37772 .38076 .38441 .3642 .38163 .34117 Metetra
.501 .36 .621 r
.38163 .34117 .38441 .3642 .391 .34867 .38744 .34344 Metetra
.796 .368 0 r
.38744 .34344 .391 .34867 .3973 .33957 .3929 .35495 Metetra
.745 .426 .443 r
.3929 .35495 .3973 .33957 .40323 .3398 .39823 .37139 Metetra
.66 .374 .476 r
.39823 .37139 .40323 .3398 .40887 .34865 .40371 .386 Metetra
.582 .31 .469 r
.40371 .386 .40887 .34865 .4144 .36201 .40957 .39217 Metetra
.434 .172 .416 r
.40957 .39217 .4144 .36201 .42006 .37396 .41588 .38641 Metetra
.41588 .38641 .42006 .37396 .42598 .3792 .42253 .37009 Metetra
.872 .673 .63 r
.42253 .37009 .42598 .3792 .43222 .37528 .42928 .3489 Metetra
.732 .519 .603 r
.42928 .3489 .43222 .37528 .43867 .36343 .43591 .33033 Metetra
.642 .442 .597 r
.43591 .33033 .43867 .36343 .44521 .3476 .44225 .32052 Metetra
.521 .364 .609 r
.44225 .32052 .44521 .3476 .45169 .3324 .4483 .32197 Metetra
0 0 .557 r
.4483 .32197 .45169 .3324 .45805 .32109 .45417 .33267 Metetra
.754 .414 .408 r
.45417 .33267 .45805 .32109 .46429 .31472 .46004 .34689 Metetra
.625 .341 .467 r
.46004 .34689 .46429 .31472 .47046 .31242 .46605 .35735 Metetra
.534 .274 .468 r
.46605 .35735 .47046 .31242 .4766 .3126 .47229 .35836 Metetra
.429 .188 .445 r
.47229 .35836 .4766 .3126 .48275 .31408 .47871 .34841 Metetra
.252 .032 .374 r
.47871 .34841 .48275 .31408 .48892 .31667 .4852 .33089 Metetra
.4852 .33089 .48892 .31667 .4951 .32077 .49167 .31247 Metetra
.832 .669 .681 r
.49167 .31247 .4951 .32077 .50132 .3264 .49803 .30009 Metetra
.573 .404 .614 r
.49803 .30009 .50132 .3264 .50757 .33235 .50429 .2981 Metetra
.427 .283 .581 r
.50429 .2981 .50757 .33235 .51388 .3361 .51052 .30662 Metetra
.271 .181 .566 r
.51052 .30662 .51388 .3361 .52024 .33488 .51679 .32146 Metetra
0 0 .523 r
.51679 .32146 .52024 .33488 .52661 .32723 .52315 .33567 Metetra
.675 .297 .321 r
.52315 .33567 .52661 .32723 .53296 .31432 .52958 .34239 Metetra
.452 .185 .416 r
.52958 .34239 .53296 .31432 .53928 .29991 .53602 .33788 Metetra
.342 .112 .412 r
.53602 .33788 .53928 .29991 .54558 .28901 .54241 .3233 Metetra
.231 .02 .372 r
.54241 .3233 .54558 .28901 .55193 .28579 .54872 .30405 Metetra
0 0 .199 r
.54872 .30405 .55193 .28579 .55839 .29172 .55501 .28723 Metetra
.859 .769 .761 r
.55501 .28723 .55839 .29172 .56499 .30478 .56134 .2786 Metetra
.516 .364 .614 r
.56134 .2786 .56499 .30478 .5717 .31994 .56781 .28044 Metetra
.422 .273 .573 r
.56781 .28044 .5717 .31994 .57842 .33095 .57445 .29085 Metetra
.379 .242 .566 r
.57445 .29085 .57842 .33095 .58505 .33291 .58122 .30464 Metetra
.361 .252 .592 r
.58122 .30464 .58505 .33291 .59148 .32432 .58801 .31536 Metetra
.409 .438 .78 r
.58801 .31536 .59148 .32432 .59771 .30767 .59468 .31792 Metetra
.13 0 .149 r
.59468 .31792 .59771 .30767 .60383 .28818 .60116 .31066 Metetra
.174 0 .315 r
.60116 .31066 .60383 .28818 .60997 .27153 .60742 .29576 Metetra
.129 0 .311 r
.60742 .29576 .60997 .27153 .61626 .2617 .61357 .27799 Metetra
0 0 .198 r
.61357 .27799 .61626 .2617 .62279 .2599 .61974 .26253 Metetra
.811 .948 .601 r
.61974 .26253 .62279 .2599 .62956 .26447 .62606 .25303 Metetra
.622 .521 .719 r
.62606 .25303 .62956 .26447 .63647 .27189 .63261 .25057 Metetra
.484 .36 .636 r
.63261 .25057 .63647 .27189 .6434 .27815 .63939 .25374 Metetra
.443 .321 .619 r
.63939 .25374 .6434 .27815 .65021 .28024 .6463 .25947 Metetra
.445 .337 .637 r
.6463 .25947 .65021 .28024 .65683 .27709 .65323 .26433 Metetra
.5 .432 .712 r
.65323 .26433 .65683 .27709 .66327 .26957 .66007 .26578 Metetra
.696 .783 .918 r
.66007 .26578 .66327 .26957 .6696 .25988 .66673 .26291 Metetra
.66673 .26291 .6696 .25988 .67593 .25048 .67323 .25644 Metetra
.67323 .25644 .67593 .25048 .68236 .24324 .67964 .24815 Metetra
.67964 .24815 .68236 .24324 .68893 .23897 .68605 .24006 Metetra
.738 .979 .742 r
.68605 .24006 .68893 .23897 .69567 .2374 .69255 .23368 Metetra
.755 .806 .894 r
.69255 .23368 .69567 .2374 .70253 .23756 .69918 .22967 Metetra
.62 .587 .795 r
.69918 .22967 .70253 .23756 .70944 .23821 .70594 .22784 Metetra
.561 .503 .748 r
.70594 .22784 .70944 .23821 .71635 .2383 .71282 .22741 Metetra
.546 .486 .74 r
.71282 .22741 .71635 .2383 .72321 .23726 .71974 .22741 Metetra
.56 .512 .759 r
.71974 .22741 .72321 .23726 .73001 .23498 .72667 .22701 Metetra
.596 .574 .799 r
.72667 .22701 .73001 .23498 .73677 .23177 .73356 .22573 Metetra
.648 .661 .849 r
.73356 .22573 .73677 .23177 .7435 .2281 .7404 .22349 Metetra
.694 .744 .889 r
.7404 .22349 .7435 .2281 .75025 .22445 .74721 .22051 Metetra
.718 .789 .907 r
.74721 .22051 .75025 .22445 .75703 .22114 .754 .21715 Metetra
.719 .787 .906 r
.754 .21715 .75703 .22114 .76386 .2183 .76081 .21378 Metetra
.702 .753 .891 r
.76081 .21378 .76386 .2183 .77074 .21589 .76764 .21064 Metetra
.679 .709 .871 r
.76764 .21064 .77074 .21589 .77767 .21376 .77452 .20785 Metetra
.658 .672 .853 r
.77452 .20785 .77767 .21376 .78462 .21176 .78144 .20539 Metetra
.644 .649 .84 r
.78144 .20539 .78462 .21176 .79159 .20974 .7884 .20315 Metetra
.638 .639 .835 r
.7884 .20315 .79159 .20974 .79856 .2076 .79539 .20102 Metetra
.638 .64 .835 r
.79539 .20102 .79856 .2076 .80555 .20533 .80239 .19889 Metetra
.642 .647 .84 r
.80239 .19889 .80555 .20533 .81254 .20292 .80941 .19667 Metetra
.652 .675 .859 r
.18657 .40783 .19033 .41273 .19592 .4107 .19215 .40595 Metetra
.647 .68 .867 r
.19215 .40595 .19592 .4107 .20153 .40874 .19774 .40416 Metetra
.644 .687 .876 r
.19774 .40416 .20153 .40874 .20713 .4069 .20334 .40244 Metetra
.645 .694 .881 r
.20334 .40244 .20713 .4069 .21273 .40518 .20894 .4007 Metetra
.653 .696 .877 r
.20894 .4007 .21273 .40518 .21834 .40356 .21458 .39884 Metetra
.666 .689 .862 r
.21458 .39884 .21834 .40356 .22396 .40192 .22025 .39671 Metetra
.678 .673 .838 r
.22025 .39671 .22396 .40192 .22961 .40012 .22596 .39425 Metetra
.683 .652 .813 r
.22596 .39425 .22961 .40012 .2353 .39797 .23171 .39149 Metetra
.68 .633 .795 r
.23171 .39149 .2353 .39797 .24104 .39536 .23748 .38863 Metetra
.668 .621 .793 r
.23748 .38863 .24104 .39536 .24683 .39237 .24324 .38603 Metetra
.644 .622 .813 r
.24324 .38603 .24683 .39237 .25264 .38924 .24895 .38407 Metetra
.595 .645 .87 r
.24895 .38407 .25264 .38924 .25843 .38644 .25459 .38307 Metetra
.464 .692 .966 r
.25459 .38307 .25843 .38644 .26415 .38451 .26017 .38302 Metetra
.144 .645 .908 r
.26017 .38302 .26415 .38451 .2698 .38382 .26572 .38352 Metetra
0 .571 .735 r
.26572 .38352 .2698 .38382 .27536 .38436 .27132 .38376 Metetra
.368 .818 .941 r
.27132 .38376 .27536 .38436 .28089 .38558 .27703 .38274 Metetra
.727 .808 .914 r
.27703 .38274 .28089 .38558 .28647 .38641 .28292 .37971 Metetra
.743 .655 .763 r
.28292 .37971 .28647 .38641 .2922 .3856 .28896 .37458 Metetra
.714 .573 .695 r
.28896 .37458 .2922 .3856 .29812 .38224 .2951 .36823 Metetra
.68 .527 .671 r
.2951 .36823 .29812 .38224 .30424 .37627 .30119 .36236 Metetra
.633 .497 .679 r
.30119 .36236 .30424 .37627 .31044 .36887 .30712 .35903 Metetra
.509 .469 .748 r
.30712 .35903 .31044 .36887 .31659 .36221 .31278 .35979 Metetra
.615 .067 0 r
.31278 .35979 .31659 .36221 .32253 .35878 .31818 .36491 Metetra
.732 .355 .337 r
.31818 .36491 .32253 .35878 .32817 .36037 .32343 .37293 Metetra
.675 .343 .406 r
.32343 .37293 .32817 .36037 .33353 .36711 .32874 .38089 Metetra
.606 .278 .389 r
.32874 .38089 .33353 .36711 .33874 .37704 .33431 .38523 Metetra
.361 0 .176 r
.33431 .38523 .33874 .37704 .34405 .38645 .34028 .38333 Metetra
.871 .794 .772 r
.34028 .38333 .34405 .38645 .34966 .39111 .34663 .37484 Metetra
.746 .558 .641 r
.34663 .37484 .34966 .39111 .35572 .38812 .35319 .36215 Metetra
.689 .489 .611 r
.35319 .36215 .35572 .38812 .36217 .37749 .35972 .3497 Metetra
.636 .446 .609 r
.35972 .3497 .36217 .37749 .36882 .3625 .36597 .3422 Metetra
.533 .393 .637 r
.36597 .3422 .36882 .3625 .37539 .34858 .37183 .34278 Metetra
0 0 .378 r
.37183 .34278 .37539 .34858 .38163 .34117 .37732 .35164 Metetra
.763 .425 .412 r
.37732 .35164 .38163 .34117 .38744 .34344 .38264 .36575 Metetra
.688 .386 .459 r
.38264 .36575 .38744 .34344 .3929 .35495 .38803 .37975 Metetra
.624 .33 .451 r
.38803 .37975 .3929 .35495 .39823 .37139 .39373 .38794 Metetra
.471 .162 .36 r
.39373 .38794 .39823 .37139 .40371 .386 .39986 .38659 Metetra
.955 .919 .735 r
.39986 .38659 .40371 .386 .40957 .39217 .40637 .37554 Metetra
.781 .58 .627 r
.40637 .37554 .40957 .39217 .41588 .38641 .41307 .35821 Metetra
.721 .508 .601 r
.41307 .35821 .41588 .38641 .42253 .37009 .41976 .34005 Metetra
.683 .477 .601 r
.41976 .34005 .42253 .37009 .42928 .3489 .42627 .32631 Metetra
.636 .458 .626 r
.42627 .32631 .42928 .3489 .43591 .33033 .43251 .32033 Metetra
.431 .423 .749 r
.43251 .32033 .43591 .33033 .44225 .32052 .43853 .32265 Metetra
.787 .346 .201 r
.43853 .32265 .44225 .32052 .4483 .32197 .44441 .33125 Metetra
.741 .385 .376 r
.44441 .33125 .4483 .32197 .45417 .33267 .4503 .34239 Metetra
.715 .357 .37 r
.4503 .34239 .45417 .33267 .46004 .34689 .45628 .35187 Metetra
.643 .213 .211 r
.45628 .35187 .46004 .34689 .46605 .35735 .46243 .35624 Metetra
.629 .916 .98 r
.46243 .35624 .46605 .35735 .47229 .35836 .46873 .35369 Metetra
.859 .755 .747 r
.46873 .35369 .47229 .35836 .47871 .34841 .47516 .34441 Metetra
.912 .768 .69 r
.47516 .34441 .47871 .34841 .4852 .33089 .48164 .33045 Metetra
.97 .855 .669 r
.48164 .33045 .4852 .33089 .49167 .31247 .4881 .31517 Metetra
.951 .947 .638 r
.4881 .31517 .49167 .31247 .49803 .30009 .49449 .30244 Metetra
.723 .959 .682 r
.49449 .30244 .49803 .30009 .50429 .2981 .50082 .29566 Metetra
.181 .609 .942 r
.50082 .29566 .50429 .2981 .51052 .30662 .50709 .29678 Metetra
0 .116 .645 r
.50709 .29678 .51052 .30662 .51679 .32146 .51336 .30556 Metetra
0 .048 .563 r
.51336 .30556 .51679 .32146 .52315 .33567 .51969 .31926 Metetra
.005 .057 .566 r
.51969 .31926 .52315 .33567 .52958 .34239 .52609 .33311 Metetra
0 .12 .654 r
.52609 .33311 .52958 .34239 .53602 .33788 .53257 .34172 Metetra
.323 0 0 r
.53257 .34172 .53602 .33788 .54241 .3233 .53906 .34114 Metetra
.199 0 .28 r
.53906 .34114 .54241 .3233 .54872 .30405 .5455 .33057 Metetra
.156 0 .321 r
.5455 .33057 .54872 .30405 .55501 .28723 .55187 .31296 Metetra
.1 0 .299 r
.55187 .31296 .55501 .28723 .56134 .2786 .55818 .29387 Metetra
0 0 .157 r
.55818 .29387 .56134 .2786 .56781 .28044 .56448 .27921 Metetra
.862 .94 .869 r
.56448 .27921 .56781 .28044 .57445 .29085 .57088 .27309 Metetra
.465 .364 .656 r
.57088 .27309 .57445 .29085 .58122 .30464 .57743 .27636 Metetra
.373 .259 .593 r
.57743 .27636 .58122 .30464 .58801 .31536 .58415 .28643 Metetra
.343 .236 .586 r
.58415 .28643 .58801 .31536 .59468 .31792 .59098 .29826 Metetra
.347 .274 .632 r
.59098 .29826 .59468 .31792 .60116 .31066 .59779 .30624 Metetra
.471 .648 .935 r
.59779 .30624 .60116 .31066 .60742 .29576 .60446 .30643 Metetra
.078 0 .139 r
.60446 .30643 .60742 .29576 .61357 .27799 .61092 .29799 Metetra
.126 0 .282 r
.61092 .29799 .61357 .27799 .61974 .26253 .61719 .28331 Metetra
.085 0 .275 r
.61719 .28331 .61974 .26253 .62606 .25303 .62336 .26674 Metetra
0 0 .146 r
.62336 .26674 .62606 .25303 .63261 .25057 .62956 .2527 Metetra
.803 .964 .645 r
.62956 .2527 .63261 .25057 .63939 .25374 .63593 .24411 Metetra
.632 .555 .75 r
.63593 .24411 .63939 .25374 .6463 .25947 .64253 .24166 Metetra
.492 .384 .659 r
.64253 .24166 .6463 .25947 .65323 .26433 .64933 .24396 Metetra
.453 .344 .64 r
.64933 .24396 .65323 .26433 .66007 .26578 .65626 .24833 Metetra
.459 .365 .661 r
.65626 .24833 .66007 .26578 .66673 .26291 .66319 .25189 Metetra
.52 .468 .739 r
.66319 .25189 .66673 .26291 .67323 .25644 .67004 .25259 Metetra
.694 .78 .917 r
.67004 .25259 .67323 .25644 .67964 .24815 .67673 .24973 Metetra
.622 .929 .684 r
.67673 .24973 .67964 .24815 .68605 .24006 .68329 .24394 Metetra
.68329 .24394 .68605 .24006 .69255 .23368 .68978 .23671 Metetra
.68978 .23671 .69255 .23368 .69918 .22967 .69626 .22965 Metetra
.786 .998 .85 r
.69626 .22965 .69918 .22967 .70594 .22784 .70283 .22397 Metetra
.741 .796 .897 r
.70283 .22397 .70594 .22784 .71282 .22741 .70951 .2202 Metetra
.631 .612 .813 r
.70951 .2202 .71282 .22741 .71974 .22741 .71631 .21818 Metetra
.578 .535 .77 r
.71631 .21818 .71974 .22741 .72667 .22701 .7232 .21729 Metetra
.564 .517 .762 r
.7232 .21729 .72667 .22701 .73356 .22573 .73014 .21676 Metetra
.575 .539 .777 r
.73014 .21676 .73356 .22573 .7404 .22349 .73709 .21595 Metetra
.606 .591 .81 r
.73709 .21595 .7404 .22349 .74721 .22051 .74401 .21446 Metetra
.646 .661 .85 r
.74401 .21446 .74721 .22051 .754 .21715 .75089 .21223 Metetra
.682 .726 .883 r
.75089 .21223 .754 .21715 .76081 .21378 .75775 .20941 Metetra
.702 .762 .899 r
.75775 .20941 .76081 .21378 .76764 .21064 .7646 .20629 Metetra
.704 .764 .899 r
.7646 .20629 .76764 .21064 .77452 .20785 .77146 .20313 Metetra
.693 .741 .888 r
.77146 .20313 .77452 .20785 .78144 .20539 .77835 .20013 Metetra
.676 .709 .873 r
.77835 .20013 .78144 .20539 .7884 .20315 .78528 .19738 Metetra
.66 .681 .859 r
.78528 .19738 .7884 .20315 .79539 .20102 .79224 .19488 Metetra
.649 .661 .849 r
.79224 .19488 .79539 .20102 .80239 .19889 .79924 .19256 Metetra
.643 .652 .844 r
.79924 .19256 .80239 .19889 .80941 .19667 .80626 .19033 Metetra
.649 .691 .875 r
.18275 .40329 .18657 .40783 .19215 .40595 .18834 .40149 Metetra
.65 .695 .879 r
.18834 .40149 .19215 .40595 .19774 .40416 .19393 .39967 Metetra
.656 .696 .876 r
.19393 .39967 .19774 .40416 .20334 .40244 .19955 .39776 Metetra
.665 .691 .864 r
.19955 .39776 .20334 .40244 .20894 .4007 .2052 .39566 Metetra
.674 .678 .846 r
.2052 .39566 .20894 .4007 .21458 .39884 .21089 .3933 Metetra
.679 .662 .826 r
.21089 .3933 .21458 .39884 .22025 .39671 .2166 .39074 Metetra
.677 .647 .812 r
.2166 .39074 .22025 .39671 .22596 .39425 .22234 .38809 Metetra
.667 .637 .811 r
.22234 .38809 .22596 .39425 .23171 .39149 .22806 .38564 Metetra
.648 .64 .828 r
.22806 .38564 .23171 .39149 .23748 .38863 .23375 .38367 Metetra
.611 .661 .874 r
.23375 .38367 .23748 .38863 .24324 .38603 .23939 .38242 Metetra
.532 .705 .95 r
.23939 .38242 .24324 .38603 .24895 .38407 .24499 .38191 Metetra
.376 .737 .99 r
.24499 .38191 .24895 .38407 .25459 .38307 .25056 .38182 Metetra
.297 .751 .956 r
.25056 .38182 .25459 .38307 .26017 .38302 .25617 .38154 Metetra
.515 .842 .998 r
.25617 .38154 .26017 .38302 .26572 .38352 .26187 .38031 Metetra
.711 .783 .908 r
.26187 .38031 .26572 .38352 .27132 .38376 .26771 .37753 Metetra
.733 .663 .781 r
.26771 .37753 .27132 .38376 .27703 .38274 .2737 .37308 Metetra
.712 .588 .715 r
.2737 .37308 .27703 .38274 .28292 .37971 .27976 .36762 Metetra
.682 .544 .69 r
.27976 .36762 .28292 .37971 .28896 .37458 .2858 .36248 Metetra
.639 .517 .698 r
.2858 .36248 .28896 .37458 .2951 .36823 .2917 .35932 Metetra
.536 .503 .766 r
.2917 .35932 .2951 .36823 .30119 .36236 .29738 .35945 Metetra
0 .177 .629 r
.29738 .35945 .30119 .36236 .30712 .35903 .30282 .36317 Metetra
.718 .306 .265 r
.30282 .36317 .30712 .35903 .31278 .35979 .30812 .3694 Metetra
.668 .316 .367 r
.30812 .3694 .31278 .35979 .31818 .36491 .31346 .37574 Metetra
.597 .249 .351 r
.31346 .37574 .31818 .36491 .32343 .37293 .31903 .37924 Metetra
.325 0 .085 r
.31903 .37924 .32343 .37293 .32874 .38089 .32495 .37764 Metetra
.848 .792 .796 r
.32495 .37764 .32874 .38089 .33431 .38523 .33122 .37048 Metetra
.74 .562 .652 r
.33122 .37048 .33431 .38523 .34028 .38333 .3377 .35966 Metetra
.684 .491 .618 r
.3377 .35966 .34028 .38333 .34663 .37484 .34416 .34888 Metetra
.633 .447 .614 r
.34416 .34888 .34663 .37484 .35319 .36215 .35037 .34221 Metetra
.539 .399 .639 r
.35037 .34221 .35319 .36215 .35972 .3497 .35621 .34246 Metetra
0 .034 .604 r
.35621 .34246 .35972 .3497 .36597 .3422 .36171 .34984 Metetra
.767 .41 .378 r
.36171 .34984 .36597 .3422 .37183 .34278 .36703 .36166 Metetra
.68 .371 .443 r
.36703 .36166 .37183 .34278 .37732 .35164 .37244 .37309 Metetra
.606 .306 .433 r
.37244 .37309 .37732 .35164 .38264 .36575 .37817 .37902 Metetra
.4 .076 .296 r
.37817 .37902 .38264 .36575 .38803 .37975 .38432 .37626 Metetra
.894 .779 .727 r
.38432 .37626 .38803 .37975 .39373 .38794 .39084 .36501 Metetra
.733 .527 .614 r
.39084 .36501 .39373 .38794 .39986 .38659 .39753 .34882 Metetra
.673 .46 .588 r
.39753 .34882 .39986 .38659 .40637 .37554 .40418 .33292 Metetra
.629 .422 .582 r
.40418 .33292 .40637 .37554 .41307 .35821 .4106 .322 Metetra
.58 .391 .59 r
.4106 .322 .41307 .35821 .41976 .34005 .41676 .31831 Metetra
.488 .356 .627 r
.41676 .31831 .41976 .34005 .42627 .32631 .42272 .32102 Metetra
0 .137 .679 r
.42272 .32102 .42627 .32631 .43251 .32033 .42862 .32674 Metetra
.638 .235 .264 r
.42862 .32674 .43251 .32033 .43853 .32265 .4346 .33115 Metetra
.463 .084 .234 r
.4346 .33115 .43853 .32265 .44441 .33125 .44074 .33099 Metetra
.835 .974 .883 r
.44074 .33099 .44441 .33125 .4503 .34239 .44703 .32546 Metetra
.704 .527 .646 r
.44703 .32546 .4503 .34239 .45628 .35187 .45341 .31641 Metetra
.631 .43 .592 r
.45341 .31641 .45628 .35187 .46243 .35624 .45978 .30717 Metetra
.588 .385 .574 r
.45978 .30717 .46243 .35624 .46873 .35369 .46608 .30077 Metetra
.555 .358 .568 r
.46608 .30077 .46873 .35369 .47516 .34441 .4723 .29848 Metetra
.532 .345 .573 r
.4723 .29848 .47516 .34441 .48164 .33045 .4785 .2993 Metetra
.524 .357 .598 r
.4785 .2993 .48164 .33045 .4881 .31517 .48472 .30064 Metetra
.569 .454 .683 r
.48472 .30064 .4881 .31517 .49449 .30244 .49098 .29979 Metetra
.783 .851 .902 r
.49098 .29979 .49449 .30244 .50082 .29566 .4973 .29551 Metetra
.875 .974 .844 r
.4973 .29551 .50082 .29566 .50709 .29678 .50364 .28887 Metetra
.749 .642 .743 r
.50364 .28887 .50709 .29678 .51336 .30556 .50998 .28278 Metetra
.581 .419 .627 r
.50998 .28278 .51336 .30556 .51969 .31926 .5163 .28055 Metetra
.501 .33 .581 r
.5163 .28055 .51969 .31926 .52609 .33311 .52263 .28416 Metetra
.458 .288 .562 r
.52263 .28416 .52609 .33311 .53257 .34172 .52901 .29304 Metetra
.436 .273 .56 r
.52901 .29304 .53257 .34172 .53906 .34114 .53546 .30402 Metetra
.437 .286 .578 r
.53546 .30402 .53906 .34114 .5455 .33057 .54196 .31245 Metetra
.504 .389 .656 r
.54196 .31245 .5455 .33057 .55187 .31296 .54847 .31421 Metetra
.784 .994 .775 r
.54847 .31421 .55187 .31296 .55818 .29387 .55494 .30772 Metetra
0 0 .14 r
.55494 .30772 .55818 .29387 .56448 .27921 .56132 .29478 Metetra
0 0 .159 r
.56132 .29478 .56448 .27921 .57088 .27309 .56765 .27983 Metetra
.56765 .27983 .57088 .27309 .57743 .27636 .57399 .26801 Metetra
.718 .622 .75 r
.57399 .26801 .57743 .27636 .58415 .28643 .58043 .26301 Metetra
.495 .359 .624 r
.58043 .26301 .58415 .28643 .59098 .29826 .58703 .26572 Metetra
.426 .287 .588 r
.58703 .26572 .59098 .29826 .59779 .30624 .59379 .274 Metetra
.405 .273 .586 r
.59379 .274 .59779 .30624 .60446 .30643 .60064 .28358 Metetra
.421 .311 .623 r
.60064 .28358 .60446 .30643 .61092 .29799 .60746 .28975 Metetra
.561 .546 .795 r
.60746 .28975 .61092 .29799 .61719 .28331 .61415 .28927 Metetra
.61415 .28927 .61719 .28331 .62336 .26674 .62064 .28157 Metetra
.036 0 .2 r
.62064 .28157 .62336 .26674 .62956 .2527 .62695 .26876 Metetra
.022 0 .212 r
.62695 .26876 .62956 .2527 .63593 .24411 .63319 .25449 Metetra
0 0 .047 r
.63319 .25449 .63593 .24411 .64253 .24166 .63946 .24243 Metetra
.85 .996 .767 r
.63946 .24243 .64253 .24166 .64933 .24396 .6459 .23494 Metetra
.634 .568 .763 r
.6459 .23494 .64933 .24396 .65626 .24833 .65253 .23254 Metetra
.508 .408 .677 r
.65253 .23254 .65626 .24833 .66319 .25189 .65936 .23401 Metetra
.472 .371 .658 r
.65936 .23401 .66319 .25189 .67004 .25259 .66629 .23711 Metetra
.481 .394 .68 r
.66629 .23711 .67004 .25259 .67673 .24973 .67323 .23951 Metetra
.541 .494 .753 r
.67323 .23951 .67673 .24973 .68329 .24394 .68009 .23957 Metetra
.687 .751 .9 r
.68009 .23957 .68329 .24394 .68978 .23671 .68682 .23677 Metetra
.738 .992 .858 r
.68682 .23677 .68978 .23671 .69626 .22965 .69344 .23164 Metetra
.596 .898 .617 r
.69344 .23164 .69626 .22965 .70283 .22397 .7 .22537 Metetra
.667 .948 .699 r
.7 .22537 .70283 .22397 .70951 .2202 .70656 .21923 Metetra
.793 .976 .907 r
.70656 .21923 .70951 .2202 .71631 .21818 .7132 .21419 Metetra
.728 .788 .9 r
.7132 .21419 .71631 .21818 .7232 .21729 .71993 .21065 Metetra
.64 .636 .83 r
.71993 .21065 .7232 .21729 .73014 .21676 .72676 .20848 Metetra
.594 .566 .792 r
.72676 .20848 .73014 .21676 .73709 .21595 .73368 .20721 Metetra
.581 .548 .783 r
.73368 .20721 .73709 .21595 .74401 .21446 .74064 .20625 Metetra
.59 .566 .795 r
.74064 .20625 .74401 .21446 .75089 .21223 .74761 .20508 Metetra
.615 .609 .822 r
.74761 .20508 .75089 .21223 .75775 .20941 .75456 .2034 Metetra
.646 .664 .853 r
.75456 .2034 .75775 .20941 .7646 .20629 .76149 .20116 Metetra
.674 .715 .879 r
.76149 .20116 .7646 .20629 .77146 .20313 .7684 .19846 Metetra
.69 .744 .892 r
.7684 .19846 .77146 .20313 .77835 .20013 .77531 .1955 Metetra
.693 .748 .894 r
.77531 .1955 .77835 .20013 .78528 .19738 .78222 .19251 Metetra
.685 .733 .887 r
.78222 .19251 .78528 .19738 .79224 .19488 .78916 .18962 Metetra
.673 .71 .876 r
.78916 .18962 .79224 .19488 .79924 .19256 .79614 .18691 Metetra
.661 .688 .865 r
.79614 .18691 .79924 .19256 .80626 .19033 .80314 .18438 Metetra
.658 .698 .876 r
.17892 .39883 .18275 .40329 .18834 .40149 .18452 .39688 Metetra
.664 .694 .867 r
.18452 .39688 .18834 .40149 .19393 .39967 .19015 .3948 Metetra
.672 .684 .854 r
.19015 .3948 .19393 .39967 .19955 .39776 .19581 .39253 Metetra
.676 .672 .839 r
.19581 .39253 .19955 .39776 .2052 .39566 .20149 .39011 Metetra
.675 .66 .828 r
.20149 .39011 .2052 .39566 .21089 .3933 .20719 .38763 Metetra
.667 .653 .827 r
.20719 .38763 .21089 .3933 .2166 .39074 .21289 .3853 Metetra
.652 .656 .842 r
.21289 .3853 .2166 .39074 .22234 .38809 .21857 .38332 Metetra
.624 .674 .878 r
.21857 .38332 .22234 .38809 .22806 .38564 .2242 .38188 Metetra
.573 .711 .936 r
.2242 .38188 .22806 .38564 .23375 .38367 .2298 .38099 Metetra
.497 .754 .987 r
.2298 .38099 .23375 .38367 .23939 .38242 .23539 .38044 Metetra
.468 .791 .999 r
.23539 .38044 .23939 .38242 .24499 .38191 .241 .37975 Metetra
.583 .821 .989 r
.241 .37975 .24499 .38191 .25056 .38182 .24669 .37835 Metetra
.699 .766 .903 r
.24669 .37835 .25056 .38182 .25617 .38154 .2525 .37576 Metetra
.723 .672 .8 r
.2525 .37576 .25617 .38154 .26187 .38031 .25843 .37186 Metetra
.71 .605 .737 r
.25843 .37186 .26187 .38031 .26771 .37753 .26443 .36713 Metetra
.684 .563 .712 r
.26443 .36713 .26771 .37753 .2737 .37308 .27042 .36261 Metetra
.646 .54 .72 r
.27042 .36261 .2737 .37308 .27976 .36762 .2763 .3596 Metetra
.559 .536 .786 r
.2763 .3596 .27976 .36762 .2858 .36248 .28198 .35922 Metetra
0 .395 .832 r
.28198 .35922 .2858 .36248 .2917 .35932 .28746 .3618 Metetra
.69 .23 .155 r
.28746 .3618 .2917 .35932 .29738 .35945 .29281 .36655 Metetra
.658 .278 .314 r
.29281 .36655 .29738 .35945 .30282 .36317 .29818 .37158 Metetra
.587 .215 .302 r
.29818 .37158 .30282 .36317 .30812 .3694 .30373 .37447 Metetra
.309 0 .011 r
.30373 .37447 .30812 .3694 .31346 .37574 .3096 .37326 Metetra
.838 .832 .841 r
.3096 .37326 .31346 .37574 .31903 .37924 .31578 .36738 Metetra
.746 .585 .676 r
.31578 .36738 .31903 .37924 .32495 .37764 .32217 .35826 Metetra
.692 .508 .635 r
.32217 .35826 .32495 .37764 .33122 .37048 .32856 .34893 Metetra
.64 .464 .629 r
.32856 .34893 .33122 .37048 .3377 .35966 .33474 .34295 Metetra
.544 .419 .66 r
.33474 .34295 .3377 .35966 .34416 .34888 .34056 .34296 Metetra
0 .035 .599 r
.34056 .34296 .34416 .34888 .35037 .34221 .34604 .34949 Metetra
.761 .399 .37 r
.34604 .34949 .35037 .34221 .35621 .34246 .35132 .36044 Metetra
.683 .371 .44 r
.35132 .36044 .35621 .34246 .36171 .34984 .35665 .3717 Metetra
.616 .316 .438 r
.35665 .3717 .36171 .34984 .36703 .36166 .36227 .37855 Metetra
.481 .172 .364 r
.36227 .37855 .36703 .36166 .37244 .37309 .36831 .37764 Metetra
.738 .919 .559 r
.36831 .37764 .37244 .37309 .37817 .37902 .37476 .36855 Metetra
.817 .637 .658 r
.37476 .36855 .37817 .37902 .38432 .37626 .38143 .35405 Metetra
.729 .526 .617 r
.38143 .35405 .38432 .37626 .39084 .36501 .3881 .33893 Metetra
.675 .478 .611 r
.3881 .33893 .39084 .36501 .39753 .34882 .39457 .32803 Metetra
.608 .445 .635 r
.39457 .32803 .39753 .34882 .40418 .33292 .40072 .32439 Metetra
.279 .362 .77 r
.40072 .32439 .40418 .33292 .4106 .322 .4066 .32822 Metetra
.738 .352 .321 r
.4066 .32822 .4106 .322 .41676 .31831 .41235 .3369 Metetra
.655 .342 .43 r
.41235 .3369 .41676 .31831 .42272 .32102 .41813 .34607 Metetra
.586 .294 .438 r
.41813 .34607 .42272 .32102 .42862 .32674 .42411 .35121 Metetra
.483 .2 .408 r
.42411 .35121 .42862 .32674 .4346 .33115 .43033 .34943 Metetra
.244 0 .289 r
.43033 .34943 .4346 .33115 .44074 .33099 .43676 .34054 Metetra
.43676 .34054 .44074 .33099 .44703 .32546 .4433 .32699 Metetra
.978 .909 .665 r
.4433 .32699 .44703 .32546 .45341 .31641 .44983 .31281 Metetra
.895 .786 .733 r
.44983 .31281 .45341 .31641 .45978 .30717 .45625 .30208 Metetra
.755 .721 .821 r
.45625 .30208 .45978 .30717 .46608 .30077 .46252 .29753 Metetra
.078 .489 .896 r
.46252 .29753 .46608 .30077 .4723 .29848 .46868 .29974 Metetra
.759 .279 .099 r
.46868 .29974 .4723 .29848 .4785 .2993 .47479 .30695 Metetra
.721 .341 .33 r
.47479 .30695 .4785 .2993 .48472 .30064 .48093 .31569 Metetra
.627 .296 .392 r
.48093 .31569 .48472 .30064 .49098 .29979 .48716 .32182 Metetra
.517 .222 .406 r
.48716 .32182 .49098 .29979 .4973 .29551 .4935 .32214 Metetra
.405 .139 .394 r
.4935 .32214 .4973 .29551 .50364 .28887 .49992 .31562 Metetra
.296 .051 .362 r
.49992 .31562 .50364 .28887 .50998 .28278 .50636 .30393 Metetra
.173 0 .292 r
.50636 .30393 .50998 .28278 .5163 .28055 .51279 .29092 Metetra
0 0 .047 r
.51279 .29092 .5163 .28055 .52263 .28416 .51918 .28108 Metetra
.726 .821 .924 r
.51918 .28108 .52263 .28416 .52901 .29304 .52555 .27784 Metetra
.406 .343 .674 r
.52555 .27784 .52901 .29304 .53546 .30402 .53196 .28221 Metetra
.3 .228 .606 r
.53196 .28221 .53546 .30402 .54196 .31245 .53843 .29227 Metetra
.226 .186 .602 r
.53843 .29227 .54196 .31245 .54847 .31421 .54497 .30376 Metetra
.091 .199 .685 r
.54497 .30376 .54847 .31421 .55494 .30772 .55156 .31157 Metetra
.397 0 0 r
.55156 .31157 .55494 .30772 .56132 .29478 .55812 .31184 Metetra
.269 0 .297 r
.55812 .31184 .56132 .29478 .56765 .27983 .56461 .30362 Metetra
.2 0 .323 r
.56461 .30362 .56765 .27983 .57399 .26801 .57099 .28933 Metetra
.105 0 .277 r
.57099 .28933 .57399 .26801 .58043 .26301 .57732 .2736 Metetra
0 0 .018 r
.57732 .2736 .58043 .26301 .58703 .26572 .58366 .26133 Metetra
.8 .773 .829 r
.58366 .26133 .58703 .26572 .59379 .274 .59013 .25576 Metetra
.507 .39 .655 r
.59013 .25576 .59379 .274 .60064 .28358 .59676 .2574 Metetra
.428 .303 .608 r
.59676 .2574 .60064 .28358 .60746 .28975 .60355 .26403 Metetra
.405 .289 .608 r
.60355 .26403 .60746 .28975 .61415 .28927 .61043 .27168 Metetra
.427 .342 .658 r
.61043 .27168 .61415 .28927 .62064 .28157 .61727 .27622 Metetra
.598 .664 .885 r
.61727 .27622 .62064 .28157 .62695 .26876 .62397 .27495 Metetra
.62397 .27495 .62695 .26876 .63319 .25449 .63048 .26755 Metetra
.021 0 .168 r
.63048 .26755 .63319 .25449 .63946 .24243 .63684 .25593 Metetra
0 0 .166 r
.63684 .25593 .63946 .24243 .6459 .23494 .64312 .24325 Metetra
.64312 .24325 .6459 .23494 .65253 .23254 .64946 .23258 Metetra
.851 .996 .823 r
.64946 .23258 .65253 .23254 .65936 .23401 .65595 .22583 Metetra
.643 .592 .782 r
.65595 .22583 .65936 .23401 .66629 .23711 .66263 .22333 Metetra
.525 .437 .699 r
.66263 .22333 .66629 .23711 .67323 .23951 .66947 .22403 Metetra
.491 .4 .68 r
.66947 .22403 .67323 .23951 .68009 .23957 .67641 .22605 Metetra
.501 .425 .703 r
.67641 .22605 .68009 .23957 .68682 .23677 .68336 .22749 Metetra
.559 .523 .772 r
.68336 .22749 .68682 .23677 .69344 .23164 .69023 .22705 Metetra
.681 .739 .895 r
.69023 .22705 .69344 .23164 .7 .22537 .69701 .22432 Metetra
.764 .97 .925 r
.69701 .22432 .7 .22537 .70656 .21923 .70369 .21975 Metetra
.714 .984 .806 r
.70369 .21975 .70656 .21923 .7132 .21419 .71032 .21427 Metetra
.747 .994 .845 r
.71032 .21427 .7132 .21419 .71993 .21065 .71696 .2089 Metetra
.78 .939 .931 r
.71696 .2089 .71993 .21065 .72676 .20848 .72366 .20437 Metetra
.717 .78 .902 r
.72366 .20437 .72676 .20848 .73368 .20721 .73044 .20101 Metetra
.647 .657 .845 r
.73044 .20101 .73368 .20721 .74064 .20625 .73732 .19873 Metetra
.608 .595 .812 r
.73732 .19873 .74064 .20625 .74761 .20508 .74426 .19716 Metetra
.596 .578 .803 r
.74426 .19716 .74761 .20508 .75456 .2034 .75125 .19584 Metetra
.603 .591 .812 r
.75125 .19584 .75456 .2034 .76149 .20116 .75824 .19437 Metetra
.623 .626 .833 r
.75824 .19437 .76149 .20116 .7684 .19846 .76523 .19253 Metetra
.647 .67 .857 r
.76523 .19253 .7684 .19846 .77531 .1955 .7722 .19026 Metetra
.669 .709 .878 r
.7722 .19026 .77531 .1955 .78222 .19251 .77916 .18764 Metetra
.681 .732 .889 r
.77916 .18764 .78222 .19251 .78916 .18962 .78611 .18481 Metetra
.684 .737 .891 r
.78611 .18481 .78916 .18962 .79614 .18691 .79309 .18193 Metetra
.679 .727 .886 r
.79309 .18193 .79614 .18691 .80314 .18438 .80008 .17912 Metetra
.67 .691 .861 r
.17509 .39412 .17892 .39883 .18452 .39688 .18073 .39192 Metetra
.673 .681 .85 r
.18073 .39192 .18452 .39688 .19015 .3948 .18638 .38961 Metetra
.672 .673 .842 r
.18638 .38961 .19015 .3948 .19581 .39253 .19205 .38726 Metetra
.667 .668 .841 r
.19205 .38726 .19581 .39253 .20149 .39011 .19773 .38501 Metetra
.655 .671 .853 r
.19773 .38501 .20149 .39011 .20719 .38763 .20338 .38303 Metetra
.634 .686 .881 r
.20338 .38303 .20719 .38763 .21289 .3853 .20901 .38144 Metetra
.601 .715 .924 r
.20901 .38144 .21289 .3853 .21857 .38332 .21462 .38026 Metetra
.56 .751 .967 r
.21462 .38026 .21857 .38332 .2242 .38188 .22021 .37934 Metetra
.551 .784 .985 r
.22021 .37934 .2242 .38188 .2298 .38099 .22583 .37833 Metetra
.615 .795 .968 r
.22583 .37833 .2298 .38099 .23539 .38044 .23151 .37679 Metetra
.69 .753 .9 r
.23151 .37679 .23539 .38044 .241 .37975 .23729 .37434 Metetra
.714 .681 .817 r
.23729 .37434 .241 .37975 .24669 .37835 .24316 .37088 Metetra
.707 .622 .76 r
.24316 .37088 .24669 .37835 .2525 .37576 .24911 .36676 Metetra
.686 .584 .735 r
.24911 .36676 .2525 .37576 .25843 .37186 .25505 .36275 Metetra
.653 .564 .742 r
.25505 .36275 .25843 .37186 .26443 .36713 .26089 .35989 Metetra
.581 .568 .804 r
.26089 .35989 .26443 .36713 .27042 .36261 .26658 .35909 Metetra
.19 .542 .928 r
.26658 .35909 .27042 .36261 .2763 .3596 .2721 .36067 Metetra
.622 .096 0 r
.2721 .36067 .2763 .3596 .28198 .35922 .2775 .36409 Metetra
.635 .215 .228 r
.2775 .36409 .28198 .35922 .28746 .3618 .28291 .36788 Metetra
.565 .156 .224 r
.28291 .36788 .28746 .3618 .29281 .36655 .28846 .37011 Metetra
.244 0 0 r
.28846 .37011 .29281 .36655 .29818 .37158 .29428 .3691 Metetra
.808 .836 .872 r
.29428 .3691 .29818 .37158 .30373 .37447 .30038 .36427 Metetra
.744 .6 .697 r
.30038 .36427 .30373 .37447 .3096 .37326 .30668 .35664 Metetra
.693 .521 .65 r
.30668 .35664 .3096 .37326 .31578 .36738 .31299 .34863 Metetra
.644 .477 .643 r
.31299 .34863 .31578 .36738 .32217 .35826 .31913 .34322 Metetra
.557 .439 .675 r
.31913 .34322 .32217 .35826 .32856 .34893 .32496 .34276 Metetra
0 .201 .729 r
.32496 .34276 .32856 .34893 .33474 .34295 .33046 .34787 Metetra
.763 .375 .319 r
.33046 .34787 .33474 .34295 .34056 .34296 .33577 .35698 Metetra
.688 .361 .417 r
.33577 .35698 .34056 .34296 .34604 .34949 .34109 .36667 Metetra
.623 .308 .416 r
.34109 .36667 .34604 .34949 .35132 .36044 .34667 .37288 Metetra
.481 .143 .316 r
.34667 .37288 .35132 .36044 .35665 .3717 .35265 .37257 Metetra
.894 .979 .812 r
.35265 .37257 .35665 .3717 .36227 .37855 .35901 .36512 Metetra
.769 .588 .654 r
.35901 .36512 .36227 .37855 .36831 .37764 .36562 .35265 Metetra
.702 .5 .612 r
.36562 .35265 .36831 .37764 .37476 .36855 .37226 .33915 Metetra
.658 .459 .604 r
.37226 .33915 .37476 .36855 .38143 .35405 .37872 .32877 Metetra
.609 .431 .616 r
.37872 .32877 .38143 .35405 .3881 .33893 .38491 .32418 Metetra
.499 .405 .679 r
.38491 .32418 .3881 .33893 .39457 .32803 .39084 .32564 Metetra
.599 .051 0 r
.39084 .32564 .39457 .32803 .40072 .32439 .39664 .33107 Metetra
.677 .285 .295 r
.39664 .33107 .40072 .32439 .4066 .32822 .40246 .33698 Metetra
.583 .207 .295 r
.40246 .33698 .4066 .32822 .41235 .3369 .40844 .33996 Metetra
.073 0 0 r
.40844 .33996 .41235 .3369 .41813 .34607 .41462 .33803 Metetra
.759 .643 .733 r
.41462 .33803 .41813 .34607 .42411 .35121 .42098 .33124 Metetra
.694 .508 .631 r
.42098 .33124 .42411 .35121 .43033 .34943 .42742 .32137 Metetra
.663 .464 .606 r
.42742 .32137 .43033 .34943 .43676 .34054 .43387 .31089 Metetra
.643 .447 .603 r
.43387 .31089 .43676 .34054 .4433 .32699 .44026 .30193 Metetra
.631 .447 .616 r
.44026 .30193 .4433 .32699 .44983 .31281 .44658 .29556 Metetra
.621 .47 .655 r
.44658 .29556 .44983 .31281 .45625 .30208 .45283 .29184 Metetra
.601 .523 .738 r
.45283 .29184 .45625 .30208 .46252 .29753 .45904 .29026 Metetra
.534 .551 .819 r
.45904 .29026 .46252 .29753 .46868 .29974 .46524 .29025 Metetra
.481 .466 .764 r
.46524 .29025 .46868 .29974 .47479 .30695 .47144 .29148 Metetra
.477 .386 .674 r
.47144 .29148 .47479 .30695 .48093 .31569 .47765 .29378 Metetra
.483 .353 .628 r
.47765 .29378 .48093 .31569 .48716 .32182 .48388 .2967 Metetra
.496 .352 .615 r
.48388 .2967 .48716 .32182 .4935 .32214 .49016 .2993 Metetra
.526 .381 .627 r
.49016 .2993 .4935 .32214 .49992 .31562 .49649 .30015 Metetra
.598 .467 .674 r
.49649 .30015 .49992 .31562 .50636 .30393 .50286 .29794 Metetra
.771 .701 .785 r
.50286 .29794 .50636 .30393 .51279 .29092 .50927 .29222 Metetra
.881 .992 .755 r
.50927 .29222 .51279 .29092 .51918 .28108 .51568 .28405 Metetra
.751 .945 .618 r
.51568 .28405 .51918 .28108 .52555 .27784 .52209 .27584 Metetra
.829 .897 .888 r
.52209 .27584 .52555 .27784 .53196 .28221 .52849 .27054 Metetra
.548 .473 .723 r
.52849 .27054 .53196 .28221 .53843 .29227 .53491 .27042 Metetra
.424 .314 .625 r
.53491 .27042 .53843 .29227 .54497 .30376 .54138 .27595 Metetra
.376 .261 .593 r
.54138 .27595 .54497 .30376 .55156 .31157 .54793 .28531 Metetra
.361 .255 .597 r
.54793 .28531 .55156 .31157 .55812 .31184 .55454 .29488 Metetra
.382 .315 .657 r
.55454 .29488 .55812 .31184 .56461 .30362 .56117 .30052 Metetra
.564 .775 .978 r
.56117 .30052 .56461 .30362 .57099 .28933 .56776 .29928 Metetra
.015 0 .084 r
.56776 .29928 .57099 .28933 .57732 .2736 .57426 .29079 Metetra
.074 0 .23 r
.57426 .29079 .57732 .2736 .58366 .26133 .58065 .27742 Metetra
.003 0 .193 r
.58065 .27742 .58366 .26133 .59013 .25576 .587 .26329 Metetra
.587 .26329 .59013 .25576 .59676 .2574 .59339 .25251 Metetra
.769 .747 .833 r
.59339 .25251 .59676 .2574 .60355 .26403 .5999 .24764 Metetra
.512 .406 .67 r
.5999 .24764 .60355 .26403 .61043 .27168 .60658 .24888 Metetra
.439 .323 .624 r
.60658 .24888 .61043 .27168 .61727 .27622 .6134 .25413 Metetra
.424 .316 .627 r
.6134 .25413 .61727 .27622 .62397 .27495 .6203 .25992 Metetra
.459 .383 .684 r
.6203 .25992 .62397 .27495 .63048 .26755 .62714 .26282 Metetra
.645 .716 .9 r
.62714 .26282 .63048 .26755 .63684 .25593 .63385 .26075 Metetra
.63385 .26075 .63684 .25593 .64312 .24325 .64039 .25362 Metetra
0 0 .084 r
.64039 .25362 .64312 .24325 .64946 .23258 .64679 .24314 Metetra
0 0 .081 r
.64679 .24314 .64946 .23258 .65595 .22583 .65314 .23199 Metetra
.65314 .23199 .65595 .22583 .66263 .22333 .65955 .22264 Metetra
.842 .982 .87 r
.65955 .22264 .66263 .22333 .66947 .22403 .6661 .21661 Metetra
.649 .616 .803 r
.6661 .21661 .66947 .22403 .67641 .22605 .67282 .21409 Metetra
.542 .469 .723 r
.67282 .21409 .67641 .22605 .68336 .22749 .67968 .21415 Metetra
.51 .433 .705 r
.67968 .21415 .68336 .22749 .69023 .22705 .68663 .21526 Metetra
.522 .46 .727 r
.68663 .21526 .69023 .22705 .69701 .22432 .69359 .21588 Metetra
.576 .553 .791 r
.69359 .21588 .69701 .22432 .70369 .21975 .70049 .21501 Metetra
.677 .732 .892 r
.70049 .21501 .70369 .21975 .71032 .21427 .7073 .21233 Metetra
.758 .924 .944 r
.7073 .21233 .71032 .21427 .71696 .2089 .71404 .20821 Metetra
.76 .984 .905 r
.71404 .20821 .71696 .2089 .72366 .20437 .72074 .20337 Metetra
.77 .976 .917 r
.72074 .20337 .72366 .20437 .73044 .20101 .72745 .19862 Metetra
.761 .898 .938 r
.72745 .19862 .73044 .20101 .73732 .19873 .73422 .19451 Metetra
.707 .773 .904 r
.73422 .19451 .73732 .19873 .74426 .19716 .74106 .19131 Metetra
.653 .674 .858 r
.74106 .19131 .74426 .19716 .75125 .19584 .74797 .18894 Metetra
.621 .622 .83 r
.74797 .18894 .75125 .19584 .75824 .19437 .75494 .18712 Metetra
.61 .605 .821 r
.75494 .18712 .75824 .19437 .76523 .19253 .76195 .18551 Metetra
.615 .615 .828 r
.76195 .18551 .76523 .19253 .7722 .19026 .76898 .1838 Metetra
.63 .642 .844 r
.76898 .1838 .7722 .19026 .77916 .18764 .776 .18182 Metetra
.649 .676 .863 r
.776 .18182 .77916 .18764 .78611 .18481 .78301 .17951 Metetra
.665 .707 .878 r
.78301 .17951 .78611 .18481 .79309 .18193 .79002 .17693 Metetra
.675 .726 .888 r
.79002 .17693 .79309 .18193 .80008 .17912 .79703 .17419 Metetra
.671 .684 .854 r
.17127 .38922 .17509 .39412 .18073 .39192 .17692 .38697 Metetra
.666 .681 .854 r
.17692 .38697 .18073 .39192 .18638 .38961 .18257 .38479 Metetra
.657 .683 .864 r
.18257 .38479 .18638 .38961 .19205 .38726 .1882 .3828 Metetra
.641 .695 .885 r
.1882 .3828 .19205 .38726 .19773 .38501 .19382 .3811 Metetra
.619 .718 .916 r
.19382 .3811 .19773 .38501 .20338 .38303 .19943 .3797 Metetra
.596 .746 .948 r
.19943 .3797 .20338 .38303 .20901 .38144 .20503 .3785 Metetra
.594 .77 .964 r
.20503 .3785 .20901 .38144 .21462 .38026 .21064 .37723 Metetra
.633 .775 .949 r
.21064 .37723 .21462 .38026 .22021 .37934 .21632 .37557 Metetra
.682 .745 .898 r
.21632 .37557 .22021 .37934 .22583 .37833 .22206 .37323 Metetra
.705 .69 .833 r
.22206 .37323 .22583 .37833 .23151 .37679 .2279 .37012 Metetra
.703 .64 .783 r
.2279 .37012 .23151 .37679 .23729 .37434 .23378 .36648 Metetra
.687 .605 .759 r
.23378 .36648 .23729 .37434 .24316 .37088 .23967 .3629 Metetra
.658 .589 .766 r
.23967 .3629 .24316 .37088 .24911 .36676 .2455 .36018 Metetra
.599 .597 .821 r
.2455 .36018 .24911 .36676 .25505 .36275 .25119 .35905 Metetra
.354 .622 .953 r
.25119 .35905 .25505 .36275 .26089 .35989 .25674 .35982 Metetra
.465 0 0 r
.25674 .35982 .26089 .35989 .26658 .35909 .26219 .36211 Metetra
.588 .112 .092 r
.26219 .36211 .26658 .35909 .2721 .36067 .26763 .36482 Metetra
.522 .063 .105 r
.26763 .36482 .2721 .36067 .2775 .36409 .27319 .36641 Metetra
.138 0 0 r
.27319 .36641 .2775 .36409 .28291 .36788 .27897 .36548 Metetra
.778 .841 .9 r
.27897 .36548 .28291 .36788 .28846 .37011 .285 .36147 Metetra
.742 .62 .723 r
.285 .36147 .28846 .37011 .29428 .3691 .29121 .35508 Metetra
.695 .537 .669 r
.29121 .35508 .29428 .3691 .30038 .36427 .29745 .34824 Metetra
.648 .494 .66 r
.29745 .34824 .30038 .36427 .30668 .35664 .30354 .34342 Metetra
.567 .461 .694 r
.30354 .34342 .30668 .35664 .31299 .34863 .30936 .34268 Metetra
.037 .302 .792 r
.30936 .34268 .31299 .34863 .31913 .34322 .31488 .34674 Metetra
.756 .342 .265 r
.31488 .34674 .31913 .34322 .32496 .34276 .3202 .35442 Metetra
.687 .348 .395 r
.3202 .35442 .32496 .34276 .33046 .34787 .32552 .3629 Metetra
.624 .3 .401 r
.32552 .3629 .33046 .34787 .33577 .35698 .33106 .36864 Metetra
.494 .148 .309 r
.33106 .36864 .33577 .35698 .34109 .36667 .33696 .36884 Metetra
.753 .986 .761 r
.33696 .36884 .34109 .36667 .34667 .37288 .34325 .36271 Metetra
.786 .624 .68 r
.34325 .36271 .34667 .37288 .35265 .37257 .3498 .35191 Metetra
.711 .518 .626 r
.3498 .35191 .35265 .37257 .35901 .36512 .35639 .33993 Metetra
.663 .471 .615 r
.35639 .33993 .35901 .36512 .36562 .35265 .36282 .33059 Metetra
.61 .441 .628 r
.36282 .33059 .36562 .35265 .37226 .33915 .36898 .32655 Metetra
.48 .414 .705 r
.36898 .32655 .37226 .33915 .37872 .32877 .37487 .32823 Metetra
.702 .165 0 r
.37487 .32823 .37872 .32877 .38491 .32418 .38061 .33372 Metetra
.653 .291 .344 r
.38061 .33372 .38491 .32418 .39084 .32564 .38638 .33957 Metetra
.564 .232 .364 r
.38638 .33957 .39084 .32564 .39664 .33107 .39233 .34221 Metetra
.366 .022 .243 r
.39233 .34221 .39664 .33107 .40246 .33698 .39853 .33943 Metetra
.847 .988 .718 r
.39853 .33943 .40246 .33698 .40844 .33996 .40494 .33126 Metetra
.814 .656 .686 r
.40494 .33126 .40844 .33996 .41462 .33803 .41147 .31983 Metetra
.722 .533 .635 r
.41147 .31983 .41462 .33803 .42098 .33124 .41797 .30837 Metetra
.665 .478 .622 r
.41797 .30837 .42098 .33124 .42742 .32137 .42436 .29978 Metetra
.613 .445 .631 r
.42436 .29978 .42742 .32137 .43387 .31089 .4306 .29558 Metetra
.547 .433 .675 r
.4306 .29558 .43387 .31089 .44026 .30193 .43674 .29542 Metetra
.364 .484 .847 r
.43674 .29542 .44026 .30193 .44658 .29556 .44284 .29742 Metetra
.451 0 0 r
.44284 .29742 .44658 .29556 .45283 .29184 .44898 .29902 Metetra
.4 0 .156 r
.44898 .29902 .45283 .29184 .45904 .29026 .45521 .29812 Metetra
.192 0 .08 r
.45521 .29812 .45904 .29026 .46524 .29025 .46152 .29399 Metetra
.509 .82 .501 r
.46152 .29399 .46524 .29025 .47144 .29148 .46788 .28754 Metetra
.832 .784 .806 r
.46788 .28754 .47144 .29148 .47765 .29378 .47424 .28089 Metetra
.66 .527 .691 r
.47424 .28089 .47765 .29378 .48388 .2967 .48057 .27642 Metetra
.558 .412 .639 r
.48057 .27642 .48388 .2967 .49016 .2993 .48686 .27562 Metetra
.488 .351 .62 r
.48686 .27562 .49016 .2993 .49649 .30015 .49313 .27845 Metetra
.438 .323 .626 r
.49313 .27845 .49649 .30015 .50286 .29794 .49942 .28322 Metetra
.41 .35 .679 r
.49942 .28322 .50286 .29794 .50927 .29222 .50576 .28722 Metetra
.436 .596 .911 r
.50576 .28722 .50927 .29222 .51568 .28405 .51215 .28793 Metetra
.51215 .28793 .51568 .28405 .52209 .27584 .51858 .28419 Metetra
0 0 .007 r
.51858 .28419 .52209 .27584 .52849 .27054 .52502 .27687 Metetra
.52502 .27687 .52849 .27054 .53491 .27042 .53145 .26863 Metetra
.851 .909 .874 r
.53145 .26863 .53491 .27042 .54138 .27595 .53788 .26275 Metetra
.573 .471 .7 r
.53788 .26275 .54138 .27595 .54793 .28531 .54434 .26173 Metetra
.457 .331 .62 r
.54434 .26173 .54793 .28531 .55454 .29488 .55087 .26614 Metetra
.406 .28 .594 r
.55087 .26614 .55454 .29488 .56117 .30052 .55748 .27426 Metetra
.387 .274 .601 r
.55748 .27426 .56117 .30052 .56776 .29928 .56415 .28261 Metetra
.408 .335 .663 r
.56415 .28261 .56776 .29928 .57426 .29079 .57083 .28736 Metetra
.594 .768 .962 r
.57083 .28736 .57426 .29079 .58065 .27742 .57745 .28587 Metetra
0 0 .013 r
.57745 .28587 .58065 .27742 .587 .26329 .58397 .27792 Metetra
.036 0 .186 r
.58397 .27792 .587 .26329 .59339 .25251 .59039 .26574 Metetra
0 0 .131 r
.59039 .26574 .59339 .25251 .5999 .24764 .59677 .253 Metetra
.59677 .253 .5999 .24764 .60658 .24888 .6032 .2433 Metetra
.747 .715 .822 r
.6032 .2433 .60658 .24888 .6134 .25413 .60975 .23874 Metetra
.527 .424 .68 r
.60975 .23874 .6134 .25413 .6203 .25992 .61646 .23936 Metetra
.459 .347 .638 r
.61646 .23936 .6203 .25992 .62714 .26282 .62331 .24324 Metetra
.448 .344 .644 r
.62331 .24324 .62714 .26282 .63385 .26075 .63021 .24741 Metetra
.491 .421 .705 r
.63021 .24741 .63385 .26075 .64039 .25362 .63707 .24905 Metetra
.671 .736 .899 r
.63707 .24905 .64039 .25362 .64679 .24314 .64379 .24652 Metetra
.64379 .24652 .64679 .24314 .65314 .23199 .65037 .23985 Metetra
.65037 .23985 .65314 .23199 .65955 .22264 .65682 .23056 Metetra
.65682 .23056 .65955 .22264 .6661 .21661 .66325 .22084 Metetra
.66325 .22084 .6661 .21661 .67282 .21409 .66973 .2127 Metetra
.824 .955 .901 r
.66973 .2127 .67282 .21409 .67968 .21415 .67634 .2073 Metetra
.654 .637 .82 r
.67634 .2073 .67968 .21415 .68663 .21526 .6831 .20476 Metetra
.559 .502 .747 r
.6831 .20476 .68663 .21526 .69359 .21588 .68999 .20428 Metetra
.531 .468 .73 r
.68999 .20428 .69359 .21588 .70049 .21501 .69695 .20462 Metetra
.543 .494 .752 r
.69695 .20462 .70049 .21501 .7073 .21233 .70392 .20458 Metetra
.592 .58 .808 r
.70392 .20458 .7073 .21233 .71404 .20821 .71084 .20335 Metetra
.673 .726 .89 r
.71084 .20335 .71404 .20821 .72074 .20337 .7177 .20071 Metetra
.742 .878 .942 r
.7177 .20071 .72074 .20337 .72745 .19862 .72449 .19695 Metetra
.762 .944 .94 r
.72449 .19695 .72745 .19862 .73422 .19451 .73127 .19264 Metetra
.762 .932 .942 r
.73127 .19264 .73422 .19451 .74106 .19131 .73805 .18838 Metetra
.742 .863 .936 r
.73805 .18838 .74106 .19131 .74797 .18894 .74488 .18462 Metetra
.698 .767 .905 r
.74488 .18462 .74797 .18894 .75494 .18712 .75177 .18154 Metetra
.657 .689 .869 r
.75177 .18154 .75494 .18712 .76195 .18551 .75872 .1791 Metetra
.631 .645 .846 r
.75872 .1791 .76195 .18551 .76898 .1838 .76573 .17709 Metetra
.622 .63 .838 r
.76573 .17709 .76898 .1838 .776 .18182 .77277 .17525 Metetra
.625 .637 .842 r
.77277 .17525 .776 .18182 .78301 .17951 .77983 .17334 Metetra
.636 .658 .854 r
.77983 .17334 .78301 .17951 .79002 .17693 .78688 .17124 Metetra
.651 .684 .868 r
.78688 .17124 .79002 .17693 .79703 .17419 .79394 .16889 Metetra
.658 .694 .872 r
.16741 .38463 .17127 .38922 .17692 .38697 .17303 .38264 Metetra
.647 .704 .888 r
.17303 .38264 .17692 .38697 .18257 .38479 .17864 .38086 Metetra
.632 .72 .911 r
.17864 .38086 .18257 .38479 .1882 .3828 .18424 .37929 Metetra
.618 .741 .934 r
.18424 .37929 .1882 .3828 .19382 .3811 .18983 .37787 Metetra
.618 .759 .946 r
.18983 .37787 .19382 .3811 .19943 .3797 .19545 .3764 Metetra
.643 .761 .935 r
.19545 .3764 .19943 .3797 .20503 .3785 .20111 .37465 Metetra
.677 .739 .897 r
.20111 .37465 .20503 .3785 .21064 .37723 .20683 .37239 Metetra
.698 .698 .847 r
.20683 .37239 .21064 .37723 .21632 .37557 .21262 .36955 Metetra
.699 .657 .805 r
.21262 .36955 .21632 .37557 .22206 .37323 .21846 .3663 Metetra
.687 .626 .783 r
.21846 .3663 .22206 .37323 .2279 .37012 .22431 .36307 Metetra
.663 .613 .788 r
.22431 .36307 .2279 .37012 .23378 .36648 .2301 .36047 Metetra
.615 .624 .836 r
.2301 .36047 .23378 .36648 .23967 .3629 .2358 .35909 Metetra
.457 .664 .951 r
.2358 .35909 .23967 .3629 .2455 .36018 .24138 .35919 Metetra
.175 0 0 r
.24138 .35919 .2455 .36018 .25119 .35905 .24686 .36055 Metetra
.485 0 0 r
.24686 .36055 .25119 .35905 .25674 .35982 .25234 .36233 Metetra
.435 0 0 r
.25234 .36233 .25674 .35982 .26219 .36211 .25791 .36332 Metetra
.25791 .36332 .26219 .36211 .26763 .36482 .26366 .3624 Metetra
.746 .839 .922 r
.26366 .3624 .26763 .36482 .27319 .36641 .26962 .35904 Metetra
.738 .641 .751 r
.26962 .35904 .27319 .36641 .27897 .36548 .27574 .3537 Metetra
.697 .557 .692 r
.27574 .3537 .27897 .36548 .285 .36147 .28191 .34786 Metetra
.654 .514 .68 r
.28191 .34786 .285 .36147 .29121 .35508 .28796 .34355 Metetra
.578 .487 .716 r
.28796 .34355 .29121 .35508 .29745 .34824 .29377 .34257 Metetra
.156 .394 .841 r
.29377 .34257 .29745 .34824 .30354 .34342 .29931 .34564 Metetra
.741 .293 .186 r
.29931 .34564 .30354 .34342 .30936 .34268 .30465 .35196 Metetra
.687 .33 .365 r
.30465 .35196 .30936 .34268 .31488 .34674 .30998 .35927 Metetra
.627 .289 .379 r
.30998 .35927 .31488 .34674 .3202 .35442 .31548 .36458 Metetra
.509 .148 .29 r
.31548 .36458 .3202 .35442 .32552 .3629 .32131 .36536 Metetra
.545 .9 .687 r
.32131 .36536 .32552 .3629 .33106 .36864 .3275 .36069 Metetra
.793 .656 .711 r
.3275 .36069 .33106 .36864 .33696 .36884 .33396 .35173 Metetra
.718 .536 .643 r
.33396 .35173 .33696 .36884 .34325 .36271 .34048 .34135 Metetra
.671 .487 .628 r
.34048 .34135 .34325 .36271 .3498 .35191 .34688 .33292 Metetra
.619 .459 .644 r
.34688 .33292 .3498 .35191 .35639 .33993 .35303 .32894 Metetra
.493 .444 .731 r
.35303 .32894 .35639 .33993 .36282 .33059 .35891 .33008 Metetra
.666 .117 0 r
.35891 .33008 .36282 .33059 .36898 .32655 .36463 .33494 Metetra
.658 .284 .325 r
.36463 .33494 .36898 .32655 .37487 .32823 .37036 .34061 Metetra
.581 .238 .352 r
.37036 .34061 .37487 .32823 .38061 .33372 .37623 .34385 Metetra
.415 .055 .243 r
.37623 .34385 .38061 .33372 .38638 .33957 .38236 .34244 Metetra
.685 .945 .671 r
.38236 .34244 .38638 .33957 .39233 .34221 .38872 .33595 Metetra
.836 .705 .719 r
.38872 .33595 .39233 .34221 .39853 .33943 .39522 .32588 Metetra
.755 .579 .658 r
.39522 .32588 .39853 .33943 .40494 .33126 .40174 .31481 Metetra
.712 .534 .648 r
.40174 .31481 .40494 .33126 .41147 .31983 .40819 .30539 Metetra
.678 .525 .67 r
.40819 .30539 .41147 .31983 .41797 .30837 .4145 .29936 Metetra
.629 .56 .758 r
.4145 .29936 .41797 .30837 .42436 .29978 .42068 .29716 Metetra
.245 .641 .961 r
.42068 .29716 .42436 .29978 .4306 .29558 .42678 .29798 Metetra
.527 .008 0 r
.42678 .29798 .4306 .29558 .43674 .29542 .43286 .30025 Metetra
.537 .087 .13 r
.43286 .30025 .43674 .29542 .44284 .29742 .43899 .30223 Metetra
.428 0 .06 r
.43899 .30223 .44284 .29742 .44898 .29902 .44518 .30253 Metetra
.093 0 0 r
.44518 .30253 .44898 .29902 .45521 .29812 .45146 .30037 Metetra
.496 .87 .655 r
.45146 .30037 .45521 .29812 .46152 .29399 .45781 .29576 Metetra
.762 .987 .755 r
.45781 .29576 .46152 .29399 .46788 .28754 .4642 .28937 Metetra
.797 .99 .746 r
.4642 .28937 .46788 .28754 .47424 .28089 .47059 .2824 Metetra
.757 .989 .776 r
.47059 .2824 .47424 .28089 .48057 .27642 .47697 .27633 Metetra
.68 .971 .92 r
.47697 .27633 .48057 .27642 .48686 .27562 .48331 .27258 Metetra
.488 .741 .984 r
.48331 .27258 .48686 .27562 .49313 .27845 .48963 .27206 Metetra
.291 .448 .845 r
.48963 .27206 .49313 .27845 .49942 .28322 .49593 .27478 Metetra
.197 .317 .761 r
.49593 .27478 .49942 .28322 .50576 .28722 .50226 .27964 Metetra
.136 .305 .772 r
.50226 .27964 .50576 .28722 .51215 .28793 .50863 .28461 Metetra
.005 .436 .863 r
.50863 .28461 .51215 .28793 .51858 .28419 .51505 .28734 Metetra
.191 0 0 r
.51505 .28734 .51858 .28419 .52502 .27687 .52151 .28607 Metetra
.161 0 .114 r
.52151 .28607 .52502 .27687 .53145 .26863 .52799 .2805 Metetra
.098 0 .154 r
.52799 .2805 .53145 .26863 .53788 .26275 .53446 .27208 Metetra
0 0 .031 r
.53446 .27208 .53788 .26275 .54434 .26173 .54092 .26354 Metetra
.649 .946 .712 r
.54092 .26354 .54434 .26173 .55087 .26614 .54739 .25785 Metetra
.578 .553 .79 r
.54739 .25785 .55087 .26614 .55748 .27426 .5539 .25697 Metetra
.434 .346 .658 r
.5539 .25697 .55748 .27426 .56415 .28261 .5605 .261 Metetra
.383 .288 .623 r
.5605 .261 .56415 .28261 .57083 .28736 .56718 .26802 Metetra
.37 .291 .636 r
.56718 .26802 .57083 .28736 .57745 .28587 .5739 .27476 Metetra
.409 .398 .736 r
.5739 .27476 .57745 .28587 .58397 .27792 .58062 .27784 Metetra
.494 .903 .897 r
.58062 .27784 .58397 .27792 .59039 .26574 .58726 .2752 Metetra
.005 0 .067 r
.58726 .2752 .59039 .26574 .59677 .253 .59379 .26693 Metetra
.033 0 .175 r
.59379 .26693 .59677 .253 .6032 .2433 .60023 .25523 Metetra
0 0 .101 r
.60023 .25523 .6032 .2433 .60975 .23874 .60664 .24338 Metetra
.60664 .24338 .60975 .23874 .61646 .23936 .6131 .2344 Metetra
.753 .744 .844 r
.6131 .2344 .61646 .23936 .62331 .24324 .61969 .22998 Metetra
.543 .454 .704 r
.61969 .22998 .62331 .24324 .63021 .24741 .62644 .22994 Metetra
.478 .377 .662 r
.62644 .22994 .63021 .24741 .63707 .24905 .63331 .23256 Metetra
.47 .379 .67 r
.63331 .23256 .63707 .24905 .64379 .24652 .64022 .23529 Metetra
.522 .468 .737 r
.64022 .23529 .64379 .24652 .65037 .23985 .64708 .23583 Metetra
.694 .775 .914 r
.64708 .23583 .65037 .23985 .65682 .23056 .65382 .23291 Metetra
.558 .873 .587 r
.65382 .23291 .65682 .23056 .66325 .22084 .66044 .22667 Metetra
.66044 .22667 .66325 .22084 .66973 .2127 .66695 .21841 Metetra
.66695 .21841 .66973 .2127 .67634 .2073 .67345 .20992 Metetra
.596 .874 .551 r
.67345 .20992 .67634 .2073 .6831 .20476 .68 .20279 Metetra
.802 .926 .918 r
.68 .20279 .6831 .20476 .68999 .20428 .68667 .19793 Metetra
.659 .657 .837 r
.68667 .19793 .68999 .20428 .69695 .20462 .69348 .19536 Metetra
.576 .535 .772 r
.69348 .19536 .69695 .20462 .70392 .20458 .70039 .19443 Metetra
.551 .504 .756 r
.70039 .19443 .70392 .20458 .71084 .20335 .70737 .19414 Metetra
.563 .529 .776 r
.70737 .19414 .71084 .20335 .7177 .20071 .71435 .19354 Metetra
.606 .606 .825 r
.71435 .19354 .7177 .20071 .72449 .19695 .72131 .19202 Metetra
.67 .724 .89 r
.72131 .19202 .72449 .19695 .73127 .19264 .7282 .18941 Metetra
.725 .84 .936 r
.7282 .18941 .73127 .19264 .73805 .18838 .73506 .18594 Metetra
.747 .896 .946 r
.73506 .18594 .73805 .18838 .74488 .18462 .7419 .18204 Metetra
.745 .888 .944 r
.7419 .18204 .74488 .18462 .75177 .18154 .74875 .17818 Metetra
.725 .833 .932 r
.74875 .17818 .75177 .18154 .75872 .1791 .75564 .17469 Metetra
.691 .761 .905 r
.75564 .17469 .75872 .1791 .76573 .17709 .76258 .17172 Metetra
.66 .701 .877 r
.76258 .17172 .76573 .17709 .77277 .17525 .76958 .16923 Metetra
.64 .665 .859 r
.76958 .16923 .77277 .17525 .77983 .17334 .77662 .16706 Metetra
.632 .652 .852 r
.77662 .16706 .77983 .17334 .78688 .17124 .78369 .16503 Metetra
.634 .656 .855 r
.78369 .16503 .78688 .17124 .79394 .16889 .79078 .16296 Metetra
.641 .723 .908 r
.16345 .3807 .16741 .38463 .17303 .38264 .16904 .37901 Metetra
.632 .738 .924 r
.16904 .37901 .17303 .38264 .17864 .38086 .17464 .37742 Metetra
.633 .75 .932 r
.17464 .37742 .17864 .38086 .18424 .37929 .18025 .37581 Metetra
.649 .752 .924 r
.18025 .37581 .18424 .37929 .18983 .37787 .1859 .37398 Metetra
.673 .736 .897 r
.1859 .37398 .18983 .37787 .19545 .3764 .19159 .37179 Metetra
.691 .706 .859 r
.19159 .37179 .19545 .3764 .20111 .37465 .19735 .36916 Metetra
.694 .672 .824 r
.19735 .36916 .20111 .37465 .20683 .37239 .20314 .36621 Metetra
.686 .647 .805 r
.20314 .36621 .20683 .37239 .21262 .36955 .20895 .36325 Metetra
.666 .635 .81 r
.20895 .36325 .21262 .36955 .21846 .3663 .21472 .36076 Metetra
.627 .647 .85 r
.21472 .36076 .21846 .3663 .22431 .36307 .22041 .35919 Metetra
.523 .689 .943 r
.22041 .35919 .22431 .36307 .2301 .36047 .22601 .35876 Metetra
.149 .638 .917 r
.22601 .35876 .2301 .36047 .2358 .35909 .23153 .35935 Metetra
.272 0 0 r
.23153 .35935 .2358 .35909 .24138 .35919 .23704 .36033 Metetra
.266 0 0 r
.23704 .36033 .24138 .35919 .24686 .36055 .24262 .36079 Metetra
.208 .734 .801 r
.24262 .36079 .24686 .36055 .25234 .36233 .24834 .35982 Metetra
.718 .831 .935 r
.24834 .35982 .25234 .36233 .25791 .36332 .25425 .35693 Metetra
.732 .661 .78 r
.25425 .35693 .25791 .36332 .26366 .3624 .26029 .35243 Metetra
.698 .578 .716 r
.26029 .35243 .26366 .3624 .26962 .35904 .26639 .34744 Metetra
.658 .535 .703 r
.26639 .34744 .26962 .35904 .27574 .3537 .27239 .34359 Metetra
.589 .514 .738 r
.27239 .34359 .27574 .3537 .28191 .34786 .27819 .34239 Metetra
.267 .472 .873 r
.27819 .34239 .28191 .34786 .28796 .34355 .28376 .34456 Metetra
.707 .211 .062 r
.28376 .34456 .28796 .34355 .29377 .34257 .28914 .34959 Metetra
.682 .302 .32 r
.28914 .34959 .29377 .34257 .29931 .34564 .29448 .35569 Metetra
.627 .27 .346 r
.29448 .35569 .29931 .34564 .30465 .35196 .29996 .36037 Metetra
.513 .131 .254 r
.29996 .36037 .30465 .35196 .30998 .35927 .30573 .36142 Metetra
.415 .837 .674 r
.30573 .36142 .30998 .35927 .31548 .36458 .31184 .35786 Metetra
.789 .677 .741 r
.31184 .35786 .31548 .36458 .32131 .36536 .3182 .35046 Metetra
.717 .546 .658 r
.3182 .35046 .32131 .36536 .3275 .36069 .32465 .34156 Metetra
.671 .495 .638 r
.32465 .34156 .3275 .36069 .33396 .35173 .33101 .33404 Metetra
.622 .467 .651 r
.33101 .33404 .33396 .35173 .34048 .34135 .33714 .33021 Metetra
.517 .457 .728 r
.33714 .33021 .34048 .34135 .34688 .33292 .34302 .3308 Metetra
.464 0 0 r
.34302 .3308 .34688 .33292 .35303 .32894 .34874 .3347 Metetra
.652 .242 .254 r
.34874 .3347 .35303 .32894 .35891 .33008 .35445 .33939 Metetra
.568 .197 .298 r
.35445 .33939 .35891 .33008 .36463 .33494 .36032 .34194 Metetra
.336 0 .11 r
.36032 .34194 .36463 .33494 .37036 .34061 .36642 .34027 Metetra
.87 .954 .861 r
.36642 .34027 .37036 .34061 .37623 .34385 .37277 .33396 Metetra
.777 .624 .69 r
.37277 .33396 .37623 .34385 .38236 .34244 .37927 .32434 Metetra
.712 .527 .638 r
.37927 .32434 .38236 .34244 .38872 .33595 .38579 .31384 Metetra
.672 .485 .624 r
.38579 .31384 .38872 .33595 .39522 .32588 .39223 .30489 Metetra
.639 .466 .632 r
.39223 .30489 .39522 .32588 .40174 .31481 .39854 .299 Metetra
.606 .468 .667 r
.39854 .299 .40174 .31481 .40819 .30539 .40471 .29632 Metetra
.562 .522 .768 r
.40471 .29632 .40819 .30539 .4145 .29936 .41083 .2958 Metetra
.452 .688 .967 r
.41083 .2958 .4145 .29936 .42068 .29716 .41694 .29579 Metetra
.416 .815 .983 r
.41694 .29579 .42068 .29716 .42678 .29798 .42311 .29486 Metetra
.684 .804 .94 r
.42311 .29486 .42678 .29798 .43286 .30025 .42934 .29233 Metetra
.693 .617 .766 r
.42934 .29233 .43286 .30025 .43899 .30223 .43563 .28844 Metetra
.652 .513 .682 r
.43563 .28844 .43899 .30223 .44518 .30253 .44194 .28407 Metetra
.619 .462 .648 r
.44194 .28407 .44518 .30253 .45146 .30037 .44824 .28017 Metetra
.596 .439 .639 r
.44824 .28017 .45146 .30037 .45781 .29576 .45453 .27723 Metetra
.586 .439 .649 r
.45453 .27723 .45781 .29576 .4642 .28937 .46082 .2751 Metetra
.595 .474 .684 r
.46082 .2751 .4642 .28937 .47059 .2824 .46711 .27314 Metetra
.635 .561 .754 r
.46711 .27314 .47059 .2824 .47697 .27633 .47343 .27069 Metetra
.695 .686 .837 r
.47343 .27069 .47697 .27633 .48331 .27258 .47977 .26754 Metetra
.71 .715 .853 r
.47977 .26754 .48331 .27258 .48963 .27206 .48613 .26421 Metetra
.645 .597 .786 r
.48613 .26421 .48963 .27206 .49593 .27478 .49249 .26177 Metetra
.556 .462 .703 r
.49249 .26177 .49593 .27478 .50226 .27964 .49884 .26131 Metetra
.492 .378 .651 r
.49884 .26131 .50226 .27964 .50863 .28461 .5052 .26332 Metetra
.455 .337 .63 r
.5052 .26332 .50863 .28461 .51505 .28734 .51159 .26724 Metetra
.442 .334 .636 r
.51159 .26724 .51505 .28734 .52151 .28607 .51801 .27147 Metetra
.463 .387 .686 r
.51801 .27147 .52151 .28607 .52799 .2805 .52448 .27397 Metetra
.575 .604 .845 r
.52448 .27397 .52799 .2805 .53446 .27208 .53098 .27313 Metetra
.622 .955 .8 r
.53098 .27313 .53446 .27208 .54092 .26354 .53748 .26858 Metetra
.53748 .26858 .54092 .26354 .54739 .25785 .54398 .26157 Metetra
.522 .816 .478 r
.54398 .26157 .54739 .25785 .5539 .25697 .55047 .25449 Metetra
.793 .877 .908 r
.55047 .25449 .5539 .25697 .5605 .261 .55698 .24992 Metetra
.557 .489 .735 r
.55698 .24992 .5605 .261 .56718 .26802 .56355 .24948 Metetra
.452 .351 .65 r
.56355 .24948 .56718 .26802 .5739 .27476 .5702 .2531 Metetra
.412 .308 .626 r
.5702 .2531 .5739 .27476 .58062 .27784 .57693 .25899 Metetra
.409 .321 .645 r
.57693 .25899 .58062 .27784 .58726 .2752 .5837 .26425 Metetra
.468 .439 .742 r
.5837 .26425 .58726 .2752 .59379 .26693 .59045 .26602 Metetra
.662 .947 .958 r
.59045 .26602 .59379 .26693 .60023 .25523 .59711 .26271 Metetra
.59711 .26271 .60023 .25523 .60664 .24338 .60366 .25463 Metetra
0 0 .094 r
.60366 .25463 .60664 .24338 .6131 .2344 .61013 .24382 Metetra
0 0 .003 r
.61013 .24382 .6131 .2344 .61969 .22998 .61657 .2331 Metetra
.651 .887 .537 r
.61657 .2331 .61969 .22998 .62644 .22994 .62309 .225 Metetra
.744 .744 .851 r
.62309 .225 .62644 .22994 .63331 .23256 .62972 .22079 Metetra
.56 .483 .725 r
.62972 .22079 .63331 .23256 .64022 .23529 .6365 .22022 Metetra
.499 .409 .685 r
.6365 .22022 .64022 .23529 .64708 .23583 .64338 .22175 Metetra
.497 .417 .697 r
.64338 .22175 .64708 .23583 .65382 .23291 .6503 .22325 Metetra
.553 .515 .766 r
.6503 .22325 .65382 .23291 .66044 .22667 .65717 .22288 Metetra
.709 .795 .918 r
.65717 .22288 .66044 .22667 .66695 .21841 .66394 .21969 Metetra
.66 .953 .727 r
.66394 .21969 .66695 .21841 .67345 .20992 .67059 .21389 Metetra
.67059 .21389 .67345 .20992 .68 .20279 .67717 .20656 Metetra
.67717 .20656 .68 .20279 .68667 .19793 .68374 .19914 Metetra
.701 .966 .727 r
.68374 .19914 .68667 .19793 .69348 .19536 .69037 .19289 Metetra
.779 .895 .926 r
.69037 .19289 .69348 .19536 .70039 .19443 .6971 .18847 Metetra
.662 .675 .852 r
.6971 .18847 .70039 .19443 .70737 .19414 .70395 .18588 Metetra
.593 .568 .796 r
.70395 .18588 .70737 .19414 .71435 .19354 .71089 .18458 Metetra
.571 .54 .781 r
.71089 .18458 .71435 .19354 .72131 .19202 .71789 .18378 Metetra
.581 .563 .799 r
.71789 .18378 .72131 .19202 .7282 .18941 .7249 .18273 Metetra
.618 .629 .84 r
.7249 .18273 .7282 .18941 .73506 .18594 .73188 .18098 Metetra
.668 .723 .891 r
.73188 .18098 .73506 .18594 .7419 .18204 .73882 .17839 Metetra
.71 .811 .928 r
.73882 .17839 .7419 .18204 .74875 .17818 .74573 .17514 Metetra
.729 .856 .941 r
.74573 .17514 .74875 .17818 .75564 .17469 .75263 .17156 Metetra
.727 .851 .94 r
.75263 .17156 .75564 .17469 .76258 .17172 .75955 .168 Metetra
.711 .81 .927 r
.75955 .168 .76258 .17172 .76958 .16923 .7665 .16473 Metetra
.685 .757 .906 r
.7665 .16473 .76958 .16923 .77662 .16706 .77349 .16183 Metetra
.662 .711 .884 r
.77349 .16183 .77662 .16706 .78369 .16503 .78054 .1593 Metetra
.646 .682 .87 r
.78054 .1593 .78369 .16503 .79078 .16296 .78762 .15702 Metetra
.643 .745 .923 r
.15944 .37714 .16345 .3807 .16904 .37901 .16504 .37541 Metetra
.654 .746 .917 r
.16504 .37541 .16904 .37901 .17464 .37742 .17067 .37353 Metetra
.671 .734 .898 r
.17067 .37353 .17464 .37742 .18025 .37581 .17635 .37138 Metetra
.685 .712 .869 r
.17635 .37138 .18025 .37581 .1859 .37398 .18207 .3689 Metetra
.689 .686 .842 r
.18207 .3689 .1859 .37398 .19159 .37179 .18782 .36619 Metetra
.684 .665 .826 r
.18782 .36619 .19159 .37179 .19735 .36916 .19359 .36346 Metetra
.668 .656 .829 r
.19359 .36346 .19735 .36916 .20314 .36621 .19934 .36106 Metetra
.637 .666 .861 r
.19934 .36106 .20314 .36621 .20895 .36325 .20502 .35934 Metetra
.566 .703 .934 r
.20502 .35934 .20895 .36325 .21472 .36076 .21064 .3585 Metetra
.366 .729 .989 r
.21064 .3585 .21472 .36076 .22041 .35919 .21619 .35846 Metetra
.043 .603 .805 r
.21619 .35846 .22041 .35919 .22601 .35876 .22172 .35878 Metetra
.22172 .35878 .22601 .35876 .23153 .35935 .22731 .35877 Metetra
.371 .821 .94 r
.22731 .35877 .23153 .35935 .23704 .36033 .23302 .3577 Metetra
.695 .819 .942 r
.23302 .3577 .23704 .36033 .24262 .36079 .23887 .35516 Metetra
.723 .681 .809 r
.23887 .35516 .24262 .36079 .24834 .35982 .24485 .35133 Metetra
.699 .601 .743 r
.24485 .35133 .24834 .35982 .25425 .35693 .25088 .34704 Metetra
.662 .559 .728 r
.25088 .34704 .25425 .35693 .26029 .35243 .25684 .34357 Metetra
.6 .543 .762 r
.25684 .34357 .26029 .35243 .26639 .34744 .26263 .3422 Metetra
.353 .534 .894 r
.26263 .3422 .26639 .34744 .27239 .34359 .26821 .34361 Metetra
.632 .083 0 r
.26821 .34361 .27239 .34359 .27819 .34239 .27363 .34749 Metetra
.671 .26 .257 r
.27363 .34749 .27819 .34239 .28376 .34456 .27899 .35248 Metetra
.622 .243 .304 r
.27899 .35248 .28376 .34456 .28914 .34959 .28446 .35654 Metetra
.514 .11 .213 r
.28446 .35654 .28914 .34959 .29448 .35569 .29018 .35777 Metetra
.29018 .35777 .29448 .35569 .29996 .36037 .2962 .35517 Metetra
.787 .717 .786 r
.2962 .35517 .29996 .36037 .30573 .36142 .30246 .34921 Metetra
.721 .568 .682 r
.30246 .34921 .30573 .36142 .31184 .35786 .30883 .34174 Metetra
.675 .512 .657 r
.30883 .34174 .31184 .35786 .3182 .35046 .31512 .33521 Metetra
.627 .485 .67 r
.31512 .33521 .3182 .35046 .32465 .34156 .32122 .33171 Metetra
.522 .482 .753 r
.32122 .33171 .32465 .34156 .33101 .33404 .32709 .33207 Metetra
.411 0 0 r
.32709 .33207 .33101 .33404 .33714 .33021 .33279 .33548 Metetra
.644 .224 .232 r
.33279 .33548 .33714 .33021 .34302 .3308 .33847 .33981 Metetra
.57 .196 .293 r
.33847 .33981 .34302 .3308 .34874 .3347 .34429 .34245 Metetra
.391 0 .165 r
.34429 .34245 .34874 .3347 .35445 .33939 .35034 .34135 Metetra
.697 .974 .768 r
.35034 .34135 .35445 .33939 .36032 .34194 .35665 .3359 Metetra
.823 .706 .736 r
.35665 .3359 .36032 .34194 .36642 .34027 .36312 .32714 Metetra
.745 .576 .665 r
.36312 .32714 .36642 .34027 .37277 .33396 .36965 .31724 Metetra
.701 .526 .648 r
.36965 .31724 .37277 .33396 .37927 .32434 .37609 .30854 Metetra
.666 .508 .661 r
.37609 .30854 .37927 .32434 .38579 .31384 .3824 .3027 Metetra
.626 .525 .719 r
.3824 .3027 .38579 .31384 .39223 .30489 .38856 .30014 Metetra
.504 .641 .916 r
.38856 .30014 .39223 .30489 .39854 .299 .39464 .30004 Metetra
.293 0 0 r
.39464 .30004 .39854 .299 .40471 .29632 .4007 .30083 Metetra
.391 0 .017 r
.4007 .30083 .40471 .29632 .41083 .2958 .40681 .30079 Metetra
.222 0 0 r
.40681 .30079 .41083 .2958 .41694 .29579 .41302 .29879 Metetra
.41302 .29879 .41694 .29579 .42311 .29486 .41932 .29456 Metetra
.848 .969 .876 r
.41932 .29456 .42311 .29486 .42934 .29233 .42568 .28873 Metetra
.829 .799 .823 r
.42568 .28873 .42934 .29233 .43563 .28844 .43205 .28251 Metetra
.763 .698 .789 r
.43205 .28251 .43563 .28844 .44194 .28407 .43839 .27716 Metetra
.696 .643 .793 r
.43839 .27716 .44194 .28407 .44824 .28017 .44469 .27358 Metetra
.614 .616 .83 r
.44469 .27358 .44824 .28017 .45453 .27723 .45095 .27204 Metetra
.498 .618 .901 r
.45095 .27204 .45453 .27723 .46082 .2751 .4572 .27212 Metetra
.306 .654 .97 r
.4572 .27212 .46082 .2751 .46711 .27314 .46345 .2728 Metetra
.035 .604 .765 r
.46345 .2728 .46711 .27314 .47343 .27069 .46974 .27291 Metetra
.057 0 0 r
.46974 .27291 .47343 .27069 .47977 .26754 .47608 .27147 Metetra
.47608 .27147 .47977 .26754 .48613 .26421 .48246 .26815 Metetra
.48246 .26815 .48613 .26421 .49249 .26177 .48887 .26347 Metetra
.586 .928 .731 r
.48887 .26347 .49249 .26177 .49884 .26131 .49529 .25866 Metetra
.735 .853 .936 r
.49529 .25866 .49884 .26131 .5052 .26332 .5017 .25525 Metetra
.575 .556 .796 r
.5017 .25525 .5052 .26332 .51159 .26724 .5081 .2544 Metetra
.468 .409 .708 r
.5081 .2544 .51159 .26724 .51801 .27147 .51452 .25641 Metetra
.411 .348 .676 r
.51452 .25641 .51801 .27147 .52448 .27397 .52097 .26041 Metetra
.387 .348 .693 r
.52097 .26041 .52448 .27397 .53098 .27313 .52746 .26458 Metetra
.404 .448 .792 r
.52746 .26458 .53098 .27313 .53748 .26858 .53399 .26683 Metetra
.468 .825 .996 r
.53399 .26683 .53748 .26858 .54398 .26157 .54053 .26569 Metetra
.54053 .26569 .54398 .26157 .55047 .25449 .54707 .26101 Metetra
.54707 .26101 .55047 .25449 .55698 .24992 .5536 .25411 Metetra
.5536 .25411 .55698 .24992 .56355 .24948 .56012 .24731 Metetra
.784 .898 .923 r
.56012 .24731 .56355 .24948 .5702 .2531 .56667 .24292 Metetra
.564 .509 .751 r
.56667 .24292 .5702 .2531 .57693 .25899 .57329 .24227 Metetra
.464 .371 .666 r
.57329 .24227 .57693 .25899 .5837 .26425 .57999 .24513 Metetra
.427 .332 .645 r
.57999 .24513 .5837 .26425 .59045 .26602 .58677 .24976 Metetra
.433 .355 .67 r
.58677 .24976 .59045 .26602 .59711 .26271 .59358 .25356 Metetra
.509 .499 .781 r
.59358 .25356 .59711 .26271 .60366 .25463 .60035 .25413 Metetra
.683 .968 .929 r
.60035 .25413 .60366 .25463 .61013 .24382 .60703 .25026 Metetra
.60703 .25026 .61013 .24382 .61657 .2331 .6136 .24241 Metetra
0 0 .016 r
.6136 .24241 .61657 .2331 .62309 .225 .6201 .23241 Metetra
.6201 .23241 .62309 .225 .62972 .22079 .6266 .22271 Metetra
.734 .958 .67 r
.6266 .22271 .62972 .22079 .6365 .22022 .63315 .21535 Metetra
.739 .747 .859 r
.63315 .21535 .6365 .22022 .64338 .22175 .63983 .2113 Metetra
.578 .514 .747 r
.63983 .2113 .64338 .22175 .6503 .22325 .64664 .21024 Metetra
.522 .445 .71 r
.64664 .21024 .6503 .22325 .65717 .22288 .65354 .21082 Metetra
.524 .458 .724 r
.65354 .21082 .65717 .22288 .66394 .21969 .66047 .2113 Metetra
.583 .56 .794 r
.66047 .2113 .66394 .21969 .67059 .21389 .66735 .21022 Metetra
.717 .807 .921 r
.66735 .21022 .67059 .21389 .67717 .20656 .67415 .20688 Metetra
.727 .989 .832 r
.67415 .20688 .67717 .20656 .68374 .19914 .68085 .2015 Metetra
.564 .87 .573 r
.68085 .2015 .68374 .19914 .69037 .19289 .68749 .19499 Metetra
.597 .895 .607 r
.68749 .19499 .69037 .19289 .6971 .18847 .69414 .18849 Metetra
.759 .995 .848 r
.69414 .18849 .6971 .18847 .70395 .18588 .70084 .18297 Metetra
.758 .867 .928 r
.70084 .18297 .70395 .18588 .71089 .18458 .70763 .17893 Metetra
.664 .69 .864 r
.70763 .17893 .71089 .18458 .71789 .18378 .71452 .17633 Metetra
.607 .599 .818 r
.71452 .17633 .71789 .18378 .7249 .18273 .72149 .17473 Metetra
.589 .574 .805 r
.72149 .17473 .7249 .18273 .73188 .18098 .72852 .17351 Metetra
.598 .595 .819 r
.72852 .17351 .73188 .18098 .73882 .17839 .73555 .1721 Metetra
.628 .65 .853 r
.73555 .1721 .73882 .17839 .74573 .17514 .74256 .17015 Metetra
.666 .724 .892 r
.74256 .17015 .74573 .17514 .75263 .17156 .74955 .16757 Metetra
.698 .79 .922 r
.74955 .16757 .75263 .17156 .75955 .168 .75652 .16449 Metetra
.713 .824 .934 r
.75652 .16449 .75955 .168 .7665 .16473 .76348 .16116 Metetra
.712 .822 .933 r
.76348 .16116 .7665 .16473 .77349 .16183 .77046 .15784 Metetra
.699 .792 .922 r
.77046 .15784 .77349 .16183 .78054 .1593 .77746 .15472 Metetra
.68 .753 .906 r
.77746 .15472 .78054 .1593 .78762 .15702 .78451 .15189 Metetra
.669 .734 .899 r
.15544 .37324 .15944 .37714 .16504 .37541 .16109 .37112 Metetra
.68 .718 .878 r
.16109 .37112 .16504 .37541 .17067 .37353 .16678 .36877 Metetra
.684 .698 .856 r
.16678 .36877 .17067 .37353 .17635 .37138 .17251 .36623 Metetra
.681 .681 .843 r
.17251 .36623 .17635 .37138 .18207 .3689 .17824 .36368 Metetra
.669 .674 .846 r
.17824 .36368 .18207 .3689 .18782 .36619 .18396 .36135 Metetra
.645 .683 .871 r
.18396 .36135 .18782 .36619 .19359 .36346 .18964 .35953 Metetra
.596 .713 .926 r
.18964 .35953 .19359 .36346 .19934 .36106 .19526 .35837 Metetra
.486 .753 .989 r
.19526 .35837 .19934 .36106 .20502 .35934 .20083 .35784 Metetra
.311 .747 .968 r
.20083 .35784 .20502 .35934 .21064 .3585 .20639 .35762 Metetra
.266 .751 .925 r
.20639 .35762 .21064 .3585 .21619 .35846 .21199 .3572 Metetra
.482 .843 .992 r
.21199 .3572 .21619 .35846 .22172 .35878 .21768 .35601 Metetra
.678 .807 .944 r
.21768 .35601 .22172 .35878 .22731 .35877 .22349 .35371 Metetra
.713 .698 .834 r
.22349 .35371 .22731 .35877 .23302 .3577 .22941 .35039 Metetra
.697 .624 .771 r
.22941 .35039 .23302 .3577 .23887 .35516 .23538 .34667 Metetra
.666 .584 .754 r
.23538 .34667 .23887 .35516 .24485 .35133 .24129 .34353 Metetra
.611 .572 .786 r
.24129 .34353 .24485 .35133 .25088 .34704 .24708 .34202 Metetra
.423 .582 .906 r
.24708 .34202 .25088 .34704 .25684 .34357 .25268 .34277 Metetra
.482 0 0 r
.25268 .34277 .25684 .34357 .26263 .3422 .25813 .34562 Metetra
.647 .194 .162 r
.25813 .34562 .26263 .3422 .26821 .34361 .26352 .34956 Metetra
.611 .202 .243 r
.26352 .34956 .26821 .34361 .27363 .34749 .26899 .35298 Metetra
.506 .074 .152 r
.26899 .35298 .27363 .34749 .27899 .35248 .27466 .35424 Metetra
.27466 .35424 .27899 .35248 .28446 .35654 .2806 .35239 Metetra
.775 .755 .835 r
.2806 .35239 .28446 .35654 .29018 .35777 .28676 .34768 Metetra
.721 .591 .71 r
.28676 .34768 .29018 .35777 .2962 .35517 .29304 .34151 Metetra
.677 .529 .677 r
.29304 .34151 .2962 .35517 .30246 .34921 .29927 .3359 Metetra
.63 .502 .688 r
.29927 .3359 .30246 .34921 .30883 .34174 .30534 .33271 Metetra
.533 .504 .77 r
.30534 .33271 .30883 .34174 .31512 .33521 .31119 .33278 Metetra
0 .309 .714 r
.31119 .33278 .31512 .33521 .32122 .33171 .31689 .33558 Metetra
.631 .179 .16 r
.31689 .33558 .32122 .33171 .32709 .33207 .32255 .33935 Metetra
.566 .169 .248 r
.32255 .33935 .32709 .33207 .33279 .33548 .32834 .34181 Metetra
.383 0 .105 r
.32834 .34181 .33279 .33548 .33847 .33981 .33434 .34107 Metetra
.692 .981 .836 r
.33434 .34107 .33847 .33981 .34429 .34245 .3406 .33641 Metetra
.809 .703 .748 r
.3406 .33641 .34429 .34245 .35034 .34135 .34704 .32859 Metetra
.739 .575 .671 r
.34704 .32859 .35034 .34135 .35665 .3359 .35354 .31945 Metetra
.698 .526 .65 r
.35354 .31945 .35665 .3359 .36312 .32714 .35998 .31109 Metetra
.667 .507 .659 r
.35998 .31109 .36312 .32714 .36965 .31724 .3663 .30508 Metetra
.636 .519 .703 r
.3663 .30508 .36965 .31724 .37609 .30854 .37248 .30191 Metetra
.583 .598 .834 r
.37248 .30191 .37609 .30854 .3824 .3027 .37857 .30097 Metetra
.29 .727 .966 r
.37857 .30097 .3824 .3027 .38856 .30014 .38463 .30094 Metetra
.008 0 0 r
.38463 .30094 .38856 .30014 .39464 .30004 .39074 .30037 Metetra
.393 .852 .856 r
.39074 .30037 .39464 .30004 .4007 .30083 .39693 .29831 Metetra
.759 .854 .921 r
.39693 .29831 .4007 .30083 .40681 .30079 .4032 .29454 Metetra
.749 .682 .787 r
.4032 .29454 .40681 .30079 .41302 .29879 .40953 .28952 Metetra
.716 .603 .729 r
.40953 .28952 .41302 .29879 .41932 .29456 .41587 .28408 Metetra
.695 .574 .715 r
.41587 .28408 .41932 .29456 .42568 .28873 .4222 .27899 Metetra
.682 .578 .732 r
.4222 .27899 .42568 .28873 .43205 .28251 .42851 .27475 Metetra
.674 .612 .778 r
.42851 .27475 .43205 .28251 .43839 .27716 .4348 .27152 Metetra
.659 .671 .85 r
.4348 .27152 .43839 .27716 .44469 .27358 .44108 .26918 Metetra
.621 .714 .912 r
.44108 .26918 .44469 .27358 .45095 .27204 .44734 .26757 Metetra
.577 .693 .92 r
.44734 .26757 .45095 .27204 .4572 .27212 .45362 .26654 Metetra
.554 .629 .88 r
.45362 .26654 .4572 .27212 .46345 .2728 .4599 .26596 Metetra
.547 .577 .836 r
.4599 .26596 .46345 .2728 .46974 .27291 .4662 .2656 Metetra
.558 .568 .82 r
.4662 .2656 .46974 .27291 .47608 .27147 .47253 .26508 Metetra
.593 .617 .844 r
.47253 .26508 .47608 .27147 .48246 .26815 .47888 .26391 Metetra
.66 .74 .909 r
.47888 .26391 .48246 .26815 .48887 .26347 .48528 .26167 Metetra
.725 .904 .958 r
.48528 .26167 .48887 .26347 .49529 .25866 .49169 .25828 Metetra
.723 .973 .927 r
.49169 .25828 .49529 .25866 .5017 .25525 .49813 .25421 Metetra
.73 .949 .95 r
.49813 .25421 .5017 .25525 .5081 .2544 .50457 .25045 Metetra
.663 .758 .921 r
.50457 .25045 .5081 .2544 .51452 .25641 .51101 .24815 Metetra
.533 .529 .797 r
.51101 .24815 .51452 .25641 .52097 .26041 .51746 .24815 Metetra
.449 .404 .717 r
.51746 .24815 .52097 .26041 .52746 .26458 .52394 .25051 Metetra
.407 .356 .689 r
.52394 .25051 .52746 .26458 .53399 .26683 .53045 .25432 Metetra
.398 .37 .71 r
.53045 .25432 .53399 .26683 .54053 .26569 .53701 .25789 Metetra
.437 .489 .816 r
.53701 .25789 .54053 .26569 .54707 .26101 .54359 .25942 Metetra
.527 .862 .994 r
.54359 .25942 .54707 .26101 .5536 .25411 .55018 .25774 Metetra
.55018 .25774 .5536 .25411 .56012 .24731 .55676 .25292 Metetra
.55676 .25292 .56012 .24731 .56667 .24292 .56331 .24629 Metetra
.56331 .24629 .56667 .24292 .57329 .24227 .56987 .23994 Metetra
.766 .889 .932 r
.56987 .23994 .57329 .24227 .57999 .24513 .57647 .23586 Metetra
.571 .531 .771 r
.57647 .23586 .57999 .24513 .58677 .24976 .58314 .23505 Metetra
.477 .397 .688 r
.58314 .23505 .58677 .24976 .59358 .25356 .58989 .23715 Metetra
.446 .363 .669 r
.58989 .23715 .59358 .25356 .60035 .25413 .5967 .24051 Metetra
.462 .4 .702 r
.5967 .24051 .60035 .25413 .60703 .25026 .60354 .24287 Metetra
.559 .574 .825 r
.60354 .24287 .60703 .25026 .6136 .24241 .61032 .2423 Metetra
.696 .98 .895 r
.61032 .2423 .6136 .24241 .6201 .23241 .61702 .23792 Metetra
.61702 .23792 .6201 .23241 .6266 .22271 .62362 .23028 Metetra
.62362 .23028 .6266 .22271 .63315 .21535 .63016 .22104 Metetra
.63016 .22104 .63315 .21535 .63983 .2113 .6367 .21223 Metetra
.783 .992 .768 r
.6367 .21223 .63983 .2113 .64664 .21024 .64331 .20552 Metetra
.736 .756 .868 r
.64331 .20552 .64664 .21024 .65354 .21082 .65003 .20159 Metetra
.597 .549 .771 r
.65003 .20159 .65354 .21082 .66047 .2113 .65687 .2001 Metetra
.547 .485 .738 r
.65687 .2001 .66047 .2113 .66735 .21022 .66379 .19988 Metetra
.551 .502 .754 r
.66379 .19988 .66735 .21022 .67415 .20688 .67073 .19952 Metetra
.609 .603 .82 r
.67073 .19952 .67415 .20688 .68085 .2015 .67763 .19789 Metetra
.721 .814 .923 r
.67763 .19789 .68085 .2015 .68749 .19499 .68445 .19447 Metetra
.758 .988 .896 r
.68445 .19447 .68749 .19499 .69414 .18849 .69121 .18949 Metetra
.68 .965 .751 r
.69121 .18949 .69414 .18849 .70084 .18297 .69792 .18369 Metetra
.704 .978 .781 r
.69792 .18369 .70084 .18297 .70763 .17893 .70463 .17796 Metetra
.774 .978 .912 r
.70463 .17796 .70763 .17893 .71452 .17633 .7114 .17305 Metetra
.739 .842 .928 r
.7114 .17305 .71452 .17633 .72149 .17473 .71825 .16931 Metetra
.666 .703 .875 r
.71825 .16931 .72149 .17473 .72852 .17351 .72519 .1667 Metetra
.62 .628 .837 r
.72519 .1667 .72852 .17351 .73555 .1721 .7322 .16485 Metetra
.605 .606 .826 r
.7322 .16485 .73555 .1721 .74256 .17015 .73925 .1633 Metetra
.612 .623 .838 r
.73925 .1633 .74256 .17015 .74955 .16757 .74631 .16161 Metetra
.636 .668 .864 r
.74631 .16161 .74955 .16757 .75652 .16449 .75336 .1595 Metetra
.665 .725 .894 r
.75336 .1595 .75652 .16449 .76348 .16116 .7604 .15692 Metetra
.689 .775 .917 r
.7604 .15692 .76348 .16116 .77046 .15784 .76742 .15396 Metetra
.7 .801 .927 r
.76742 .15396 .77046 .15784 .77746 .15472 .77444 .15082 Metetra
.7 .799 .927 r
.77444 .15082 .77746 .15472 .78451 .15189 .78147 .14768 Metetra
.68 .708 .869 r
.1515 .36873 .15544 .37324 .16109 .37112 .15719 .36633 Metetra
.678 .695 .858 r
.15719 .36633 .16109 .37112 .16678 .36877 .16289 .36391 Metetra
.669 .689 .86 r
.16289 .36391 .16678 .36877 .17251 .36623 .16859 .36165 Metetra
.651 .696 .879 r
.16859 .36165 .17251 .36623 .17824 .36368 .17426 .35975 Metetra
.616 .72 .92 r
.17426 .35975 .17824 .36368 .18396 .36135 .17988 .35835 Metetra
.552 .757 .972 r
.17988 .35835 .18396 .36135 .18964 .35953 .18547 .35743 Metetra
.464 .785 .999 r
.18547 .35743 .18964 .35953 .19526 .35837 .19105 .35677 Metetra
.439 .806 .995 r
.19105 .35677 .19526 .35837 .20083 .35784 .19665 .35601 Metetra
.548 .834 .998 r
.19665 .35601 .20083 .35784 .20639 .35762 .20233 .3547 Metetra
.667 .795 .943 r
.20233 .3547 .20639 .35762 .21199 .3572 .20811 .35256 Metetra
.703 .712 .856 r
.20811 .35256 .21199 .3572 .21768 .35601 .21397 .34963 Metetra
.694 .647 .799 r
.21397 .34963 .21768 .35601 .22349 .35371 .21988 .34634 Metetra
.669 .61 .781 r
.21988 .34634 .22349 .35371 .22941 .35039 .22576 .34347 Metetra
.621 .6 .808 r
.22576 .34347 .22941 .35039 .23538 .34667 .23153 .34185 Metetra
.478 .62 .912 r
.23153 .34185 .23538 .34667 .24129 .34353 .23715 .34204 Metetra
0 .351 .669 r
.23715 .34204 .24129 .34353 .24708 .34202 .24264 .34399 Metetra
.596 .089 .016 r
.24264 .34399 .24708 .34202 .25268 .34277 .24806 .34699 Metetra
.587 .138 .153 r
.24806 .34699 .25268 .34277 .25813 .34562 .25353 .34974 Metetra
.485 .016 .066 r
.25353 .34974 .25813 .34562 .26352 .34956 .25917 .35092 Metetra
.25917 .35092 .26352 .34956 .26899 .35298 .26503 .34963 Metetra
.75 .791 .886 r
.26503 .34963 .26899 .35298 .27466 .35424 .2711 .34595 Metetra
.719 .617 .743 r
.2711 .34595 .27466 .35424 .2806 .35239 .27729 .34091 Metetra
.678 .55 .702 r
.27729 .34091 .2806 .35239 .28676 .34768 .28345 .33617 Metetra
.633 .523 .711 r
.28345 .33617 .28676 .34768 .29304 .34151 .28948 .33331 Metetra
.54 .528 .791 r
.28948 .33331 .29304 .34151 .29927 .3359 .29532 .33318 Metetra
0 .417 .82 r
.29532 .33318 .29927 .3359 .30534 .33271 .30101 .33546 Metetra
.608 .122 .074 r
.30101 .33546 .30534 .33271 .31119 .33278 .30666 .33874 Metetra
.559 .138 .2 r
.30666 .33874 .31119 .33278 .31689 .33558 .31241 .34102 Metetra
.382 0 .062 r
.31241 .34102 .31689 .33558 .32255 .33935 .31837 .34059 Metetra
.607 .953 .83 r
.31837 .34059 .32255 .33935 .32834 .34181 .32457 .33665 Metetra
.809 .727 .775 r
.32457 .33665 .32834 .34181 .33434 .34107 .33096 .32973 Metetra
.743 .59 .686 r
.33096 .32973 .33434 .34107 .3406 .33641 .33743 .32137 Metetra
.702 .536 .66 r
.33743 .32137 .3406 .33641 .34704 .32859 .34387 .31349 Metetra
.671 .516 .666 r
.34387 .31349 .34704 .32859 .35354 .31945 .35018 .30757 Metetra
.643 .526 .706 r
.35018 .30757 .35354 .31945 .35998 .31109 .35636 .3042 Metetra
.602 .599 .821 r
.35636 .3042 .35998 .31109 .3663 .30508 .36245 .3029 Metetra
.419 .767 .996 r
.36245 .3029 .3663 .30508 .37248 .30191 .3685 .30244 Metetra
.135 .68 .724 r
.3685 .30244 .37248 .30191 .37857 .30097 .37461 .30145 Metetra
.459 .888 .862 r
.37461 .30145 .37857 .30097 .38463 .30094 .3808 .29894 Metetra
.786 .886 .918 r
.3808 .29894 .38463 .30094 .39074 .30037 .38708 .29469 Metetra
.771 .707 .791 r
.38708 .29469 .39074 .30037 .39693 .29831 .39342 .28919 Metetra
.726 .61 .728 r
.39342 .28919 .39693 .29831 .4032 .29454 .39977 .28339 Metetra
.689 .563 .707 r
.39977 .28339 .4032 .29454 .40953 .28952 .4061 .27824 Metetra
.66 .544 .712 r
.4061 .27824 .40953 .28952 .41587 .28408 .41239 .27431 Metetra
.637 .553 .743 r
.41239 .27431 .41587 .28408 .4222 .27899 .41864 .27167 Metetra
.621 .598 .806 r
.41864 .27167 .4222 .27899 .42851 .27475 .42488 .26989 Metetra
.618 .689 .894 r
.42488 .26989 .42851 .27475 .4348 .27152 .43112 .26834 Metetra
.634 .79 .957 r
.43112 .26834 .4348 .27152 .44108 .26918 .43739 .26642 Metetra
.677 .83 .957 r
.43739 .26642 .44108 .26918 .44734 .26757 .4437 .26389 Metetra
.708 .782 .91 r
.4437 .26389 .44734 .26757 .45362 .26654 .45003 .2609 Metetra
.688 .684 .841 r
.45003 .2609 .45362 .26654 .4599 .26596 .45637 .25792 Metetra
.642 .591 .782 r
.45637 .25792 .4599 .26596 .4662 .2656 .46271 .2555 Metetra
.595 .525 .746 r
.46271 .2555 .4662 .2656 .47253 .26508 .46905 .25402 Metetra
.56 .489 .732 r
.46905 .25402 .47253 .26508 .47888 .26391 .47539 .25344 Metetra
.544 .489 .745 r
.47539 .25344 .47888 .26391 .48528 .26167 .48175 .25328 Metetra
.556 .539 .791 r
.48175 .25328 .48528 .26167 .49169 .25828 .48813 .25281 Metetra
.609 .662 .876 r
.48813 .25281 .49169 .25828 .49813 .25421 .49455 .25136 Metetra
.683 .831 .955 r
.49455 .25136 .49813 .25421 .50457 .25045 .501 .2487 Metetra
.724 .911 .959 r
.501 .2487 .50457 .25045 .51101 .24815 .50746 .24526 Metetra
.723 .84 .937 r
.50746 .24526 .51101 .24815 .51746 .24815 .51394 .24199 Metetra
.633 .647 .846 r
.51394 .24199 .51746 .24815 .52394 .25051 .52042 .24005 Metetra
.53 .483 .748 r
.52042 .24005 .52394 .25051 .53045 .25432 .52692 .24023 Metetra
.464 .393 .692 r
.52692 .24023 .53045 .25432 .53701 .25789 .53346 .24253 Metetra
.43 .359 .676 r
.53346 .24253 .53701 .25789 .54359 .25942 .54003 .24603 Metetra
.427 .378 .701 r
.54003 .24603 .54359 .25942 .55018 .25774 .54664 .24916 Metetra
.473 .49 .795 r
.54664 .24916 .55018 .25774 .55676 .25292 .55328 .25028 Metetra
.602 .826 .985 r
.55328 .25028 .55676 .25292 .56331 .24629 .55991 .24843 Metetra
.448 .838 .622 r
.55991 .24843 .56331 .24629 .56987 .23994 .56652 .24378 Metetra
.56652 .24378 .56987 .23994 .57647 .23586 .57311 .23762 Metetra
.642 .942 .705 r
.57311 .23762 .57647 .23586 .58314 .23505 .57971 .23181 Metetra
.746 .833 .917 r
.57971 .23181 .58314 .23505 .58989 .23715 .58636 .22803 Metetra
.578 .539 .775 r
.58636 .22803 .58989 .23715 .5967 .24051 .59307 .22703 Metetra
.496 .423 .704 r
.59307 .22703 .5967 .24051 .60354 .24287 .59986 .22837 Metetra
.473 .397 .691 r
.59986 .22837 .60354 .24287 .61032 .2423 .60671 .23054 Metetra
.498 .446 .73 r
.60671 .23054 .61032 .2423 .61702 .23792 .61356 .23164 Metetra
.607 .638 .855 r
.61356 .23164 .61702 .23792 .62362 .23028 .62037 .23012 Metetra
.726 .986 .89 r
.62037 .23012 .62362 .23028 .63016 .22104 .62709 .2254 Metetra
.62709 .2254 .63016 .22104 .6367 .21223 .63372 .21806 Metetra
.63372 .21806 .6367 .21223 .64331 .20552 .6403 .20957 Metetra
.6403 .20957 .64331 .20552 .65003 .20159 .64689 .20161 Metetra
.809 .999 .842 r
.64689 .20161 .65003 .20159 .65687 .2001 .65355 .19548 Metetra
.732 .761 .876 r
.65355 .19548 .65687 .2001 .66379 .19988 .66032 .19166 Metetra
.615 .582 .794 r
.66032 .19166 .66379 .19988 .67073 .19952 .66719 .18981 Metetra
.571 .525 .765 r
.66719 .18981 .67073 .19952 .67763 .19789 .67412 .18893 Metetra
.578 .546 .782 r
.67412 .18893 .67763 .19789 .68445 .19447 .68108 .18791 Metetra
.632 .641 .842 r
.68108 .18791 .68445 .19447 .69121 .18949 .688 .18586 Metetra
.721 .815 .923 r
.688 .18586 .69121 .18949 .69792 .18369 .69486 .18242 Metetra
.766 .965 .929 r
.69486 .18242 .69792 .18369 .70463 .17796 .70167 .17781 Metetra
.742 .992 .866 r
.70167 .17781 .70463 .17796 .7114 .17305 .70844 .17261 Metetra
.753 .99 .886 r
.70844 .17261 .7114 .17305 .71825 .16931 .71523 .16753 Metetra
.766 .941 .939 r
.71523 .16753 .71825 .16931 .72519 .1667 .72207 .16311 Metetra
.723 .821 .926 r
.72207 .16311 .72519 .1667 .7322 .16485 .72898 .15961 Metetra
.666 .713 .883 r
.72898 .15961 .7322 .16485 .73925 .1633 .73596 .15699 Metetra
.631 .652 .853 r
.73596 .15699 .73925 .1633 .74631 .16161 .74301 .15495 Metetra
.618 .634 .844 r
.74301 .15495 .74631 .16161 .75336 .1595 .75009 .15313 Metetra
.624 .648 .853 r
.75009 .15313 .75336 .1595 .7604 .15692 .75718 .15121 Metetra
.642 .683 .873 r
.75718 .15121 .7604 .15692 .76742 .15396 .76427 .14897 Metetra
.664 .727 .896 r
.76427 .14897 .76742 .15396 .77444 .15082 .77135 .14639 Metetra
.682 .764 .913 r
.77135 .14639 .77444 .15082 .78147 .14768 .77843 .14352 Metetra
.669 .702 .872 r
.14755 .36416 .1515 .36873 .15719 .36633 .15322 .36195 Metetra
.655 .707 .886 r
.15322 .36195 .15719 .36633 .16289 .36391 .15888 .36 Metetra
.63 .725 .916 r
.15888 .36 .16289 .36391 .16859 .36165 .1645 .35841 Metetra
.591 .754 .956 r
.1645 .35841 .16859 .36165 .17426 .35975 .1701 .35719 Metetra
.544 .784 .987 r
.1701 .35719 .17426 .35975 .17988 .35835 .17569 .35619 Metetra
.531 .807 .996 r
.17569 .35619 .17988 .35835 .18547 .35743 .1813 .35514 Metetra
.587 .816 .987 r
.1813 .35514 .18547 .35743 .19105 .35677 .18697 .35371 Metetra
.66 .785 .94 r
.18697 .35371 .19105 .35677 .19665 .35601 .19271 .35167 Metetra
.692 .723 .873 r
.19271 .35167 .19665 .35601 .20233 .3547 .19853 .34902 Metetra
.69 .668 .823 r
.19853 .34902 .20233 .3547 .20811 .35256 .20439 .34608 Metetra
.67 .635 .806 r
.20439 .34608 .20811 .35256 .21397 .34963 .21024 .34342 Metetra
.629 .627 .829 r
.21024 .34342 .21397 .34963 .21988 .34634 .216 .34171 Metetra
.521 .649 .915 r
.216 .34171 .21988 .34634 .22576 .34347 .22163 .34143 Metetra
.044 .551 .878 r
.22163 .34143 .22576 .34347 .23153 .34185 .22715 .34261 Metetra
.49 0 0 r
.22715 .34261 .23153 .34185 .23715 .34204 .2326 .34475 Metetra
.539 .04 .018 r
.2326 .34475 .23715 .34204 .24264 .34399 .23809 .34687 Metetra
.441 0 0 r
.23809 .34687 .24264 .34399 .24806 .34699 .2437 .34787 Metetra
.2437 .34787 .24806 .34699 .25353 .34974 .2495 .34698 Metetra
.712 .819 .932 r
.2495 .34698 .25353 .34974 .25917 .35092 .25548 .34412 Metetra
.714 .648 .782 r
.25548 .34412 .25917 .35092 .26503 .34963 .26158 .34006 Metetra
.678 .575 .732 r
.26158 .34006 .26503 .34963 .2711 .34595 .26767 .3361 Metetra
.634 .546 .738 r
.26767 .3361 .2711 .34595 .27729 .34091 .27365 .33358 Metetra
.544 .554 .815 r
.27365 .33358 .27729 .34091 .28345 .33617 .27947 .33332 Metetra
.031 .493 .881 r
.27947 .33332 .28345 .33617 .28948 .33331 .28515 .33516 Metetra
.573 .052 0 r
.28515 .33516 .28948 .33331 .29532 .33318 .29079 .33799 Metetra
.55 .104 .144 r
.29079 .33799 .29532 .33318 .30101 .33546 .29651 .34014 Metetra
.387 0 .021 r
.29651 .34014 .30101 .33546 .30666 .33874 .30241 .34004 Metetra
.475 .891 .791 r
.30241 .34004 .30666 .33874 .31241 .34102 .30855 .33688 Metetra
.808 .764 .813 r
.30855 .33688 .31241 .34102 .31837 .34059 .31488 .33096 Metetra
.749 .613 .708 r
.31488 .33096 .31837 .34059 .32457 .33665 .3213 .32351 Metetra
.709 .554 .676 r
.3213 .32351 .32457 .33665 .33096 .32973 .32771 .31623 Metetra
.68 .533 .679 r
.32771 .31623 .33096 .32973 .33743 .32137 .33402 .31051 Metetra
.654 .545 .719 r
.33402 .31051 .33743 .32137 .34387 .31349 .3402 .307 Metetra
.619 .62 .83 r
.3402 .307 .34387 .31349 .35018 .30757 .34628 .30539 Metetra
.461 .787 .999 r
.34628 .30539 .35018 .30757 .35636 .3042 .35233 .30467 Metetra
.166 .704 .748 r
.35233 .30467 .35636 .3042 .36245 .3029 .35841 .30359 Metetra
.406 .858 .824 r
.35841 .30359 .36245 .3029 .3685 .30244 .36458 .30121 Metetra
.768 .929 .938 r
.36458 .30121 .3685 .30244 .37461 .30145 .37085 .29719 Metetra
.791 .763 .828 r
.37085 .29719 .37461 .30145 .3808 .29894 .37718 .29189 Metetra
.754 .663 .761 r
.37718 .29189 .3808 .29894 .38708 .29469 .38354 .28613 Metetra
.723 .619 .741 r
.38354 .28613 .38708 .29469 .39342 .28919 .38988 .28077 Metetra
.699 .61 .753 r
.38988 .28077 .39342 .28919 .39977 .28339 .39617 .27644 Metetra
.678 .635 .799 r
.39617 .27644 .39977 .28339 .4061 .27824 .40243 .27336 Metetra
.647 .699 .884 r
.40243 .27336 .4061 .27824 .41239 .27431 .40865 .27133 Metetra
.585 .786 .975 r
.40865 .27133 .41239 .27431 .41864 .27167 .41487 .26992 Metetra
.509 .837 .999 r
.41487 .26992 .41864 .27167 .42488 .26989 .4211 .2686 Metetra
.514 .867 .989 r
.4211 .2686 .42488 .26989 .43112 .26834 .42737 .26698 Metetra
.595 .894 .989 r
.42737 .26698 .43112 .26834 .43739 .26642 .43366 .26479 Metetra
.674 .901 .977 r
.43366 .26479 .43739 .26642 .4437 .26389 .43999 .26201 Metetra
.719 .895 .96 r
.43999 .26201 .4437 .26389 .45003 .2609 .44634 .25876 Metetra
.733 .882 .949 r
.44634 .25876 .45003 .2609 .45637 .25792 .4527 .25534 Metetra
.721 .854 .945 r
.4527 .25534 .45637 .25792 .46271 .2555 .45907 .25215 Metetra
.681 .797 .937 r
.45907 .25215 .46271 .2555 .46905 .25402 .46544 .24958 Metetra
.621 .716 .914 r
.46544 .24958 .46905 .25402 .47539 .25344 .47181 .24792 Metetra
.56 .637 .884 r
.47181 .24792 .47539 .25344 .48175 .25328 .47818 .24721 Metetra
.518 .593 .869 r
.47818 .24721 .48175 .25328 .48813 .25281 .48456 .24716 Metetra
.506 .606 .886 r
.48456 .24716 .48813 .25281 .49455 .25136 .49097 .24718 Metetra
.53 .694 .944 r
.49097 .24718 .49455 .25136 .501 .2487 .49741 .24658 Metetra
.573 .845 .996 r
.49741 .24658 .501 .2487 .50746 .24526 .50388 .24486 Metetra
.586 .935 .94 r
.50388 .24486 .50746 .24526 .51394 .24199 .51037 .24198 Metetra
.624 .957 .909 r
.51037 .24198 .51394 .24199 .52042 .24005 .51688 .23847 Metetra
.692 .916 .97 r
.51688 .23847 .52042 .24005 .52692 .24023 .52339 .23531 Metetra
.626 .698 .897 r
.52339 .23531 .52692 .24023 .53346 .24253 .52992 .23355 Metetra
.521 .508 .782 r
.52992 .23355 .53346 .24253 .54003 .24603 .53648 .2338 Metetra
.457 .411 .719 r
.53648 .2338 .54003 .24603 .54664 .24916 .54307 .23593 Metetra
.428 .381 .703 r
.54307 .23593 .54664 .24916 .55328 .25028 .54971 .23897 Metetra
.433 .411 .735 r
.54971 .23897 .55328 .25028 .55991 .24843 .55638 .24144 Metetra
.492 .55 .843 r
.55638 .24144 .55991 .24843 .56652 .24378 .56306 .24192 Metetra
.607 .88 .991 r
.56306 .24192 .56652 .24378 .57311 .23762 .56974 .23967 Metetra
.461 .848 .634 r
.56974 .23967 .57311 .23762 .57971 .23181 .57638 .23498 Metetra
.57638 .23498 .57971 .23181 .58636 .22803 .58301 .22907 Metetra
.691 .975 .785 r
.58301 .22907 .58636 .22803 .59307 .22703 .58965 .2236 Metetra
.738 .822 .917 r
.58965 .2236 .59307 .22703 .59986 .22837 .59634 .21994 Metetra
.592 .564 .791 r
.59634 .21994 .59986 .22837 .60671 .23054 .60309 .21862 Metetra
.519 .457 .727 r
.60309 .21862 .60671 .23054 .61356 .23164 .60992 .21915 Metetra
.502 .439 .719 r
.60992 .21915 .61356 .23164 .62037 .23012 .6168 .2202 Metetra
.537 .501 .764 r
.6168 .2202 .62037 .23012 .62709 .2254 .62367 .22016 Metetra
.653 .703 .884 r
.62367 .22016 .62709 .2254 .63372 .21806 .63049 .21784 Metetra
.745 .99 .887 r
.63049 .21784 .63372 .21806 .6403 .20957 .63723 .21289 Metetra
.63723 .21289 .6403 .20957 .64689 .20161 .64389 .20589 Metetra
.64389 .20589 .64689 .20161 .65355 .19548 .65052 .1981 Metetra
.611 .885 .567 r
.65052 .1981 .65355 .19548 .66032 .19166 .65717 .19089 Metetra
.814 .984 .887 r
.65717 .19089 .66032 .19166 .66719 .18981 .66388 .18527 Metetra
.728 .766 .884 r
.66388 .18527 .66719 .18981 .67412 .18893 .67069 .18155 Metetra
.631 .615 .816 r
.67069 .18155 .67412 .18893 .68108 .18791 .67759 .1794 Metetra
.594 .565 .792 r
.67759 .1794 .68108 .18791 .688 .18586 .68455 .178 Metetra
.602 .587 .809 r
.68455 .178 .688 .18586 .69486 .18242 .69152 .17646 Metetra
.649 .673 .86 r
.69152 .17646 .69486 .18242 .70167 .17781 .69847 .1741 Metetra
.718 .812 .924 r
.69847 .1741 .70167 .17781 .70844 .17261 .70537 .17069 Metetra
.76 .932 .943 r
.70537 .17069 .70844 .17261 .71523 .16753 .71223 .1664 Metetra
.761 .972 .924 r
.71223 .1664 .71523 .16753 .72207 .16311 .71908 .16171 Metetra
.762 .962 .932 r
.71908 .16171 .72207 .16311 .72898 .15961 .72593 .15715 Metetra
.75 .901 .945 r
.72593 .15715 .72898 .15961 .73596 .15699 .73284 .15313 Metetra
.71 .804 .923 r
.73284 .15313 .73596 .15699 .74301 .15495 .73981 .14983 Metetra
.667 .721 .889 r
.73981 .14983 .74301 .15495 .75009 .15313 .74684 .14719 Metetra
.639 .673 .866 r
.74684 .14719 .75009 .15313 .75718 .15121 .75392 .145 Metetra
.629 .658 .859 r
.75392 .145 .75718 .15121 .76427 .14897 .76104 .14297 Metetra
.634 .669 .866 r
.76104 .14297 .76427 .14897 .77135 .14639 .76817 .14086 Metetra
.648 .696 .881 r
.76817 .14086 .77135 .14639 .77843 .14352 .7753 .13853 Metetra
.64 .729 .913 r
.1435 .36026 .14755 .36416 .15322 .36195 .14912 .35854 Metetra
.615 .751 .942 r
.14912 .35854 .15322 .36195 .15888 .36 .15473 .3571 Metetra
.589 .775 .969 r
.15473 .3571 .15888 .36 .1645 .35841 .16032 .35583 Metetra
.581 .794 .98 r
.16032 .35583 .1645 .35841 .1701 .35719 .16594 .35454 Metetra
.611 .798 .971 r
.16594 .35454 .1701 .35719 .17569 .35619 .17159 .35299 Metetra
.657 .776 .936 r
.17159 .35299 .17569 .35619 .1813 .35514 .17731 .351 Metetra
.684 .731 .886 r
.17731 .351 .1813 .35514 .18697 .35371 .18309 .34856 Metetra
.686 .687 .845 r
.18309 .34856 .18697 .35371 .19271 .35167 .18891 .34588 Metetra
.67 .657 .829 r
.18891 .34588 .19271 .35167 .19853 .34902 .19472 .34339 Metetra
.636 .65 .847 r
.19472 .34339 .19853 .34902 .20439 .34608 .20047 .3416 Metetra
.554 .672 .916 r
.20047 .3416 .20439 .34608 .21024 .34342 .20611 .34094 Metetra
.263 .663 .967 r
.20611 .34094 .21024 .34342 .216 .34171 .21166 .34147 Metetra
.292 0 0 r
.21166 .34147 .216 .34171 .22163 .34143 .21714 .34286 Metetra
.444 0 0 r
.21714 .34286 .22163 .34143 .22715 .34261 .22264 .34437 Metetra
.359 0 0 r
.22264 .34437 .22715 .34261 .2326 .34475 .22824 .34513 Metetra
.103 .657 .73 r
.22824 .34513 .2326 .34475 .23809 .34687 .23398 .34447 Metetra
.663 .833 .965 r
.23398 .34447 .23809 .34687 .2437 .34787 .23989 .34225 Metetra
.703 .679 .824 r
.23989 .34225 .2437 .34787 .2495 .34698 .2459 .33898 Metetra
.675 .602 .766 r
.2459 .33898 .2495 .34698 .25548 .34412 .25192 .33569 Metetra
.633 .572 .768 r
.25192 .33569 .25548 .34412 .26158 .34006 .25786 .3335 Metetra
.547 .581 .84 r
.25786 .3335 .26158 .34006 .26767 .3361 .26366 .33314 Metetra
.13 .553 .922 r
.26366 .33314 .26767 .3361 .27365 .33358 .26933 .33458 Metetra
.517 0 0 r
.26933 .33458 .27365 .33358 .27947 .33332 .27496 .33698 Metetra
.532 .055 .068 r
.27496 .33698 .27947 .33332 .28515 .33516 .28064 .33896 Metetra
.381 0 0 r
.28064 .33896 .28515 .33516 .29079 .33799 .2865 .33913 Metetra
.372 .835 .773 r
.2865 .33913 .29079 .33799 .29651 .34014 .29256 .33666 Metetra
.795 .793 .851 r
.29256 .33666 .29651 .34014 .30241 .34004 .29882 .33168 Metetra
.75 .633 .73 r
.29882 .33168 .30241 .34004 .30855 .33688 .3052 .32515 Metetra
.712 .569 .691 r
.3052 .32515 .30855 .33688 .31488 .33096 .31157 .3185 Metetra
.684 .545 .69 r
.31157 .3185 .31488 .33096 .3213 .32351 .31787 .31303 Metetra
.66 .554 .723 r
.31787 .31303 .3213 .32351 .32771 .31623 .32405 .30939 Metetra
.634 .616 .815 r
.32405 .30939 .32771 .31623 .33402 .31051 .33013 .30743 Metetra
.563 .768 .975 r
.33013 .30743 .33402 .31051 .3402 .307 .33618 .30629 Metetra
.428 .85 .955 r
.33618 .30629 .3402 .307 .34628 .30539 .34226 .30488 Metetra
.597 .928 .961 r
.34226 .30488 .34628 .30539 .35233 .30467 .34842 .3023 Metetra
.776 .861 .913 r
.34842 .3023 .35233 .30467 .35841 .30359 .35468 .29821 Metetra
.77 .716 .801 r
.35468 .29821 .35841 .30359 .36458 .30121 .36101 .29292 Metetra
.736 .63 .741 r
.36101 .29292 .36458 .30121 .37085 .29719 .36737 .28716 Metetra
.707 .587 .719 r
.36737 .28716 .37085 .29719 .37718 .29189 .37371 .28174 Metetra
.684 .573 .724 r
.37371 .28174 .37718 .29189 .38354 .28613 .38 .27727 Metetra
.667 .585 .754 r
.38 .27727 .38354 .28613 .38988 .28077 .38626 .27392 Metetra
.653 .627 .811 r
.38626 .27392 .38988 .28077 .39617 .27644 .39248 .27147 Metetra
.643 .694 .882 r
.39248 .27147 .39617 .27644 .40243 .27336 .3987 .2695 Metetra
.642 .752 .928 r
.3987 .2695 .40243 .27336 .40865 .27133 .40493 .26755 Metetra
.66 .762 .925 r
.40493 .26755 .40865 .27133 .41487 .26992 .41118 .26534 Metetra
.676 .725 .887 r
.41118 .26534 .41487 .26992 .4211 .2686 .41747 .26282 Metetra
.674 .673 .842 r
.41747 .26282 .4211 .2686 .42737 .26698 .42377 .26013 Metetra
.662 .633 .81 r
.42377 .26013 .42737 .26698 .43366 .26479 .43008 .25745 Metetra
.652 .615 .799 r
.43008 .25745 .43366 .26479 .43999 .26201 .4364 .2549 Metetra
.649 .62 .807 r
.4364 .2549 .43999 .26201 .44634 .25876 .44274 .25248 Metetra
.655 .649 .832 r
.44274 .25248 .44634 .25876 .4527 .25534 .44908 .25009 Metetra
.667 .694 .866 r
.44908 .25009 .4527 .25534 .45907 .25215 .45544 .24762 Metetra
.676 .731 .892 r
.45544 .24762 .45907 .25215 .46544 .24958 .46182 .24507 Metetra
.67 .731 .895 r
.46182 .24507 .46544 .24958 .47181 .24792 .46821 .24262 Metetra
.644 .684 .873 r
.46821 .24262 .47181 .24792 .47818 .24721 .47461 .24055 Metetra
.603 .614 .835 r
.47461 .24055 .47818 .24721 .48456 .24716 .48102 .23915 Metetra
.563 .553 .802 r
.48102 .23915 .48456 .24716 .49097 .24718 .48743 .2385 Metetra
.536 .522 .787 r
.48743 .2385 .49097 .24718 .49741 .24658 .49386 .23841 Metetra
.532 .533 .802 r
.49386 .23841 .49741 .24658 .50388 .24486 .50032 .23837 Metetra
.556 .599 .852 r
.50032 .23837 .50388 .24486 .51037 .24198 .5068 .23778 Metetra
.61 .73 .93 r
.5068 .23778 .51037 .24198 .51688 .23847 .51331 .2362 Metetra
.662 .868 .977 r
.51331 .2362 .51688 .23847 .52339 .23531 .51984 .23362 Metetra
.686 .91 .973 r
.51984 .23362 .52339 .23531 .52992 .23355 .52639 .23056 Metetra
.679 .828 .955 r
.52639 .23056 .52992 .23355 .53648 .2338 .53295 .22791 Metetra
.6 .645 .867 r
.53295 .22791 .53648 .2338 .54307 .23593 .53953 .22655 Metetra
.514 .496 .774 r
.53953 .22655 .54307 .23593 .54971 .23897 .54614 .22697 Metetra
.461 .418 .724 r
.54614 .22697 .54971 .23897 .55638 .24144 .55279 .22892 Metetra
.441 .399 .715 r
.55279 .22892 .55638 .24144 .56306 .24192 .55949 .23146 Metetra
.455 .44 .753 r
.55949 .23146 .56306 .24192 .56974 .23967 .56621 .23326 Metetra
.524 .59 .863 r
.56621 .23326 .56974 .23967 .57638 .23498 .57294 .23313 Metetra
.639 .893 .985 r
.57294 .23313 .57638 .23498 .58301 .22907 .57965 .23053 Metetra
.548 .911 .725 r
.57965 .23053 .58301 .22907 .58965 .2236 .58633 .22583 Metetra
.546 .883 .629 r
.58633 .22583 .58965 .2236 .59634 .21994 .593 .22018 Metetra
.738 .992 .858 r
.593 .22018 .59634 .21994 .60309 .21862 .59968 .21499 Metetra
.732 .812 .914 r
.59968 .21499 .60309 .21862 .60992 .21915 .60641 .21139 Metetra
.609 .591 .808 r
.60641 .21139 .60992 .21915 .6168 .2202 .61321 .20972 Metetra
.545 .496 .752 r
.61321 .20972 .6168 .2202 .62367 .22016 .62007 .20948 Metetra
.535 .487 .749 r
.62007 .20948 .62367 .22016 .63049 .21784 .62696 .20949 Metetra
.578 .56 .798 r
.62696 .20949 .63049 .21784 .63723 .21289 .63385 .20848 Metetra
.691 .76 .905 r
.63385 .20848 .63723 .21289 .64389 .20589 .64069 .20552 Metetra
.761 .99 .89 r
.64069 .20552 .64389 .20589 .65052 .1981 .64745 .20043 Metetra
.598 .893 .601 r
.64745 .20043 .65052 .1981 .65717 .19089 .65415 .19379 Metetra
.562 .851 .526 r
.65415 .19379 .65717 .19089 .66388 .18527 .66083 .18665 Metetra
.707 .964 .715 r
.66083 .18665 .66388 .18527 .67069 .18155 .66753 .18011 Metetra
.806 .958 .912 r
.66753 .18011 .67069 .18155 .67759 .1794 .6743 .17492 Metetra
.723 .77 .89 r
.6743 .17492 .67759 .1794 .68455 .178 .68115 .1713 Metetra
.645 .645 .835 r
.68115 .1713 .68455 .178 .69152 .17646 .68809 .16891 Metetra
.614 .603 .816 r
.68809 .16891 .69152 .17646 .69847 .1741 .69507 .1671 Metetra
.622 .625 .832 r
.69507 .1671 .69847 .1741 .70537 .17069 .70207 .16516 Metetra
.661 .699 .874 r
.70207 .16516 .70537 .17069 .71223 .1664 .70905 .16259 Metetra
.714 .807 .923 r
.70905 .16259 .71223 .1664 .71908 .16171 .71599 .15923 Metetra
.748 .899 .945 r
.71599 .15923 .71908 .16171 .72593 .15715 .72291 .15523 Metetra
.756 .935 .944 r
.72291 .15523 .72593 .15715 .73284 .15313 .72982 .15096 Metetra
.752 .92 .947 r
.72982 .15096 .73284 .15313 .73981 .14983 .73674 .14682 Metetra
.733 .865 .943 r
.73674 .14682 .73981 .14983 .74684 .14719 .74371 .14311 Metetra
.699 .79 .921 r
.74371 .14311 .74684 .14719 .75392 .145 .75074 .13995 Metetra
.667 .727 .894 r
.75074 .13995 .75392 .145 .76104 .14297 .75782 .13731 Metetra
.646 .689 .877 r
.75782 .13731 .76104 .14297 .76817 .14086 .76494 .13499 Metetra
.638 .678 .871 r
.76494 .13499 .76817 .14086 .7753 .13853 .77209 .1328 Metetra
.614 .766 .952 r
.13935 .35711 .1435 .36026 .14912 .35854 .14495 .35563 Metetra
.61 .781 .963 r
.14495 .35563 .14912 .35854 .15473 .3571 .15056 .35415 Metetra
.626 .784 .957 r
.15056 .35415 .15473 .3571 .16032 .35583 .15621 .3525 Metetra
.655 .768 .932 r
.15621 .3525 .16032 .35583 .16594 .35454 .1619 .35054 Metetra
.676 .736 .895 r
.1619 .35054 .16594 .35454 .17159 .35299 .16765 .34824 Metetra
.681 .701 .863 r
.16765 .34824 .17159 .35299 .17731 .351 .17343 .34575 Metetra
.669 .677 .848 r
.17343 .34575 .17731 .351 .18309 .34856 .17921 .34338 Metetra
.642 .671 .863 r
.17921 .34338 .18309 .34856 .18891 .34588 .18494 .34154 Metetra
.58 .69 .916 r
.18494 .34154 .18891 .34588 .19472 .34339 .19059 .34056 Metetra
.403 .712 .986 r
.19059 .34056 .19472 .34339 .20047 .3416 .19616 .34055 Metetra
0 .552 .794 r
.19616 .34055 .20047 .3416 .20611 .34094 .20168 .34128 Metetra
.271 0 0 r
.20168 .34128 .20611 .34094 .21166 .34147 .20719 .34223 Metetra
.222 0 0 r
.20719 .34223 .21166 .34147 .21714 .34286 .21278 .34271 Metetra
.168 .705 .821 r
.21278 .34271 .21714 .34286 .22264 .34437 .21848 .34216 Metetra
.614 .834 .984 r
.21848 .34216 .22264 .34437 .22824 .34513 .22432 .34039 Metetra
.686 .709 .865 r
.22432 .34039 .22824 .34513 .23398 .34447 .23026 .33776 Metetra
.669 .632 .803 r
.23026 .33776 .23398 .34447 .23989 .34225 .23621 .33504 Metetra
.63 .6 .801 r
.23621 .33504 .23989 .34225 .2459 .33898 .24211 .33313 Metetra
.547 .608 .866 r
.24211 .33313 .2459 .33898 .25192 .33569 .24788 .33269 Metetra
.206 .597 .947 r
.24788 .33269 .25192 .33569 .25786 .3335 .25355 .33379 Metetra
.435 0 0 r
.25355 .33379 .25786 .3335 .26366 .33314 .25916 .3358 Metetra
.504 0 0 r
.25916 .3358 .26366 .33314 .26933 .33458 .26482 .33761 Metetra
.372 0 0 r
.26482 .33761 .26933 .33458 .27496 .33698 .27062 .33799 Metetra
.261 .765 .741 r
.27062 .33799 .27496 .33698 .28064 .33896 .27661 .33616 Metetra
.773 .829 .896 r
.27661 .33616 .28064 .33896 .2865 .33913 .2828 .33209 Metetra
.75 .659 .761 r
.2828 .33209 .2865 .33913 .29256 .33666 .2891 .32648 Metetra
.715 .588 .712 r
.2891 .32648 .29256 .33666 .29882 .33168 .29543 .32055 Metetra
.689 .562 .706 r
.29543 .32055 .29882 .33168 .3052 .32515 .3017 .31544 Metetra
.667 .569 .736 r
.3017 .31544 .3052 .32515 .31157 .3185 .30787 .31182 Metetra
.644 .626 .817 r
.30787 .31182 .31157 .3185 .31787 .31303 .31395 .30965 Metetra
.596 .761 .958 r
.31395 .30965 .31787 .31303 .32405 .30939 .32 .30826 Metetra
.509 .868 .986 r
.32 .30826 .32405 .30939 .33013 .30743 .32607 .30666 Metetra
.624 .926 .972 r
.32607 .30666 .33013 .30743 .33618 .30629 .33222 .30404 Metetra
.773 .867 .918 r
.33222 .30404 .33618 .30629 .34226 .30488 .33847 .30003 Metetra
.777 .736 .815 r
.33847 .30003 .34226 .30488 .34842 .3023 .34479 .29484 Metetra
.747 .651 .755 r
.34479 .29484 .34842 .3023 .35468 .29821 .35115 .28912 Metetra
.719 .607 .732 r
.35115 .28912 .35468 .29821 .36101 .29292 .35749 .28365 Metetra
.697 .593 .736 r
.35749 .28365 .36101 .29292 .36737 .28716 .36379 .27905 Metetra
.679 .607 .768 r
.36379 .27905 .36737 .28716 .37371 .28174 .37004 .27554 Metetra
.665 .653 .828 r
.37004 .27554 .37371 .28174 .38 .27727 .37625 .27297 Metetra
.649 .729 .908 r
.37625 .27297 .38 .27727 .38626 .27392 .38245 .27094 Metetra
.636 .804 .963 r
.38245 .27094 .38626 .27392 .39248 .27147 .38866 .26897 Metetra
.653 .839 .972 r
.38866 .26897 .39248 .27147 .3987 .2695 .3949 .2667 Metetra
.691 .83 .95 r
.3949 .2667 .3987 .2695 .40493 .26755 .40117 .264 Metetra
.713 .791 .912 r
.40117 .264 .40493 .26755 .41118 .26534 .40747 .26093 Metetra
.711 .746 .879 r
.40747 .26093 .41118 .26534 .41747 .26282 .41379 .25774 Metetra
.697 .711 .859 r
.41379 .25774 .41747 .26282 .42377 .26013 .42011 .25468 Metetra
.677 .689 .854 r
.42011 .25468 .42377 .26013 .43008 .25745 .42643 .25197 Metetra
.656 .68 .861 r
.42643 .25197 .43008 .25745 .4364 .2549 .43275 .24968 Metetra
.638 .684 .877 r
.43275 .24968 .4364 .2549 .44274 .25248 .43908 .24774 Metetra
.629 .704 .9 r
.43908 .24774 .44274 .25248 .44908 .25009 .44542 .24597 Metetra
.633 .739 .924 r
.44542 .24597 .44908 .25009 .45544 .24762 .45178 .24411 Metetra
.65 .781 .944 r
.45178 .24411 .45544 .24762 .46182 .24507 .45816 .24198 Metetra
.672 .813 .951 r
.45816 .24198 .46182 .24507 .46821 .24262 .46456 .2395 Metetra
.687 .816 .944 r
.46456 .2395 .46821 .24262 .47461 .24055 .47098 .2368 Metetra
.682 .778 .923 r
.47098 .2368 .47461 .24055 .48102 .23915 .47741 .23419 Metetra
.65 .704 .886 r
.47741 .23419 .48102 .23915 .48743 .2385 .48385 .23203 Metetra
.602 .622 .843 r
.48385 .23203 .48743 .2385 .49386 .23841 .4903 .23063 Metetra
.558 .558 .81 r
.4903 .23063 .49386 .23841 .50032 .23837 .49676 .23006 Metetra
.53 .529 .799 r
.49676 .23006 .50032 .23837 .5068 .23778 .50324 .23005 Metetra
.525 .543 .816 r
.50324 .23005 .5068 .23778 .51331 .2362 .50975 .23008 Metetra
.549 .611 .867 r
.50975 .23008 .51331 .2362 .51984 .23362 .51628 .22954 Metetra
.6 .734 .939 r
.51628 .22954 .51984 .23362 .52639 .23056 .52283 .22806 Metetra
.648 .851 .978 r
.52283 .22806 .52639 .23056 .53295 .22791 .52941 .22568 Metetra
.673 .876 .975 r
.52941 .22568 .53295 .22791 .53953 .22655 .536 .22292 Metetra
.658 .784 .941 r
.536 .22292 .53953 .22655 .54614 .22697 .5426 .2206 Metetra
.585 .621 .854 r
.5426 .2206 .54614 .22697 .55279 .22892 .54923 .21948 Metetra
.513 .495 .774 r
.54923 .21948 .55279 .22892 .55949 .23146 .5559 .21991 Metetra
.47 .431 .733 r
.5559 .21991 .55949 .23146 .56621 .23326 .56261 .22157 Metetra
.457 .421 .731 r
.56261 .22157 .56621 .23326 .57294 .23313 .56936 .22355 Metetra
.479 .474 .774 r
.56936 .22355 .57294 .23313 .57965 .23053 .57614 .22467 Metetra
.557 .631 .88 r
.57614 .22467 .57965 .23053 .58633 .22583 .58291 .22395 Metetra
.668 .902 .978 r
.58291 .22395 .58633 .22583 .593 .22018 .58965 .22102 Metetra
.626 .957 .804 r
.58965 .22102 .593 .22018 .59968 .21499 .59637 .21632 Metetra
.641 .951 .746 r
.59637 .21632 .59968 .21499 .60641 .21139 .60308 .21089 Metetra
.767 .985 .902 r
.60308 .21089 .60641 .21139 .61321 .20972 .6098 .20593 Metetra
.73 .804 .91 r
.6098 .20593 .61321 .20972 .62007 .20948 .61657 .20233 Metetra
.627 .62 .824 r
.61657 .20233 .62007 .20948 .62696 .20949 .6234 .20029 Metetra
.574 .539 .778 r
.6234 .20029 .62696 .20949 .63385 .20848 .63029 .19933 Metetra
.57 .538 .78 r
.63029 .19933 .63385 .20848 .64069 .20552 .6372 .19844 Metetra
.618 .619 .83 r
.6372 .19844 .64069 .20552 .64745 .20043 .64411 .19662 Metetra
.72 .804 .917 r
.64411 .19662 .64745 .20043 .65415 .19379 .65096 .19317 Metetra
.774 .986 .899 r
.65096 .19317 .65415 .19379 .66083 .18665 .65775 .18804 Metetra
.681 .957 .715 r
.65775 .18804 .66083 .18665 .66753 .18011 .6645 .18177 Metetra
.668 .943 .679 r
.6645 .18177 .66753 .18011 .6743 .17492 .67123 .17523 Metetra
.764 .996 .822 r
.67123 .17523 .6743 .17492 .68115 .1713 .67799 .16927 Metetra
.792 .929 .924 r
.67799 .16927 .68115 .1713 .68809 .16891 .68481 .16447 Metetra
.719 .773 .895 r
.68481 .16447 .68809 .16891 .69507 .1671 .69171 .16093 Metetra
.656 .671 .852 r
.69171 .16093 .69507 .1671 .70207 .16516 .69868 .15837 Metetra
.632 .637 .838 r
.69868 .15837 .70207 .16516 .70905 .16259 .70569 .15624 Metetra
.639 .657 .851 r
.70569 .15624 .70905 .16259 .71599 .15923 .71272 .15401 Metetra
.67 .718 .885 r
.71272 .15401 .71599 .15923 .72291 .15523 .71973 .1513 Metetra
.708 .801 .922 r
.71973 .1513 .72291 .15523 .72982 .15096 .72672 .148 Metetra
.735 .868 .943 r
.72672 .148 .72982 .15096 .73674 .14682 .7337 .14424 Metetra
.743 .895 .948 r
.7337 .14424 .73674 .14682 .74371 .14311 .74067 .14031 Metetra
.736 .881 .947 r
.74067 .14031 .74371 .14311 .75074 .13995 .74766 .1365 Metetra
.718 .835 .937 r
.74766 .1365 .75074 .13995 .75782 .13731 .75469 .13304 Metetra
.691 .779 .918 r
.75469 .13304 .75782 .13731 .76494 .13499 .76177 .13 Metetra
.666 .731 .898 r
.76177 .13 .76494 .13499 .77209 .1328 .7689 .12733 Metetra
.637 .772 .945 r
.13517 .35394 .13935 .35711 .14495 .35563 .14081 .3522 Metetra
.655 .762 .928 r
.14081 .3522 .14495 .35563 .15056 .35415 .14649 .35025 Metetra
.671 .739 .901 r
.14649 .35025 .15056 .35415 .15621 .3525 .1522 .34804 Metetra
.676 .713 .876 r
.1522 .34804 .15621 .3525 .1619 .35054 .15795 .34569 Metetra
.668 .693 .864 r
.15795 .34569 .1619 .35054 .16765 .34824 .1637 .34341 Metetra
.647 .688 .875 r
.1637 .34341 .16765 .34824 .17343 .34575 .16942 .34152 Metetra
.6 .703 .916 r
.16942 .34152 .17343 .34575 .17921 .34338 .17508 .34029 Metetra
.49 .732 .979 r
.17508 .34029 .17921 .34338 .18494 .34154 .18067 .33983 Metetra
.238 .696 .95 r
.18067 .33983 .18494 .34154 .19059 .34056 .1862 .34001 Metetra
0 .556 .747 r
.1862 .34001 .19059 .34056 .19616 .34055 .19174 .34044 Metetra
.028 0 0 r
.19174 .34044 .19616 .34055 .20168 .34128 .19732 .34062 Metetra
.254 .751 .903 r
.19732 .34062 .20168 .34128 .20719 .34223 .20299 .34007 Metetra
.576 .826 .992 r
.20299 .34007 .20719 .34223 .21278 .34271 .20878 .33862 Metetra
.664 .733 .901 r
.20878 .33862 .21278 .34271 .21848 .34216 .21464 .33646 Metetra
.659 .661 .841 r
.21464 .33646 .21848 .34216 .22432 .34039 .22054 .33419 Metetra
.625 .629 .835 r
.22054 .33419 .22432 .34039 .23026 .33776 .22639 .33251 Metetra
.545 .634 .89 r
.22639 .33251 .23026 .33776 .23621 .33504 .23214 .33202 Metetra
.266 .631 .962 r
.23214 .33202 .23621 .33504 .24211 .33313 .23779 .33281 Metetra
.324 0 0 r
.23779 .33281 .24211 .33313 .24788 .33269 .2434 .33447 Metetra
.461 0 0 r
.2434 .33447 .24788 .33269 .25355 .33379 .24903 .33608 Metetra
.354 0 0 r
.24903 .33608 .25355 .33379 .25916 .3358 .25478 .33663 Metetra
.168 .702 .716 r
.25478 .33663 .25916 .3358 .26482 .33761 .2607 .33536 Metetra
.732 .858 .94 r
.2607 .33536 .26482 .33761 .27062 .33799 .26681 .33212 Metetra
.745 .689 .797 r
.26681 .33212 .27062 .33799 .27661 .33616 .27304 .32742 Metetra
.717 .611 .738 r
.27304 .32742 .27661 .33616 .2828 .33209 .27931 .32224 Metetra
.692 .58 .726 r
.27931 .32224 .2828 .33209 .2891 .32648 .28554 .31756 Metetra
.671 .585 .75 r
.28554 .31756 .2891 .32648 .29543 .32055 .2917 .31405 Metetra
.651 .635 .821 r
.2917 .31405 .29543 .32055 .3017 .31544 .29777 .31175 Metetra
.619 .75 .94 r
.29777 .31175 .3017 .31544 .30787 .31182 .30381 .31014 Metetra
.574 .862 .996 r
.30381 .31014 .30787 .31182 .31395 .30965 .30987 .30839 Metetra
.657 .91 .98 r
.30987 .30839 .31395 .30965 .32 .30826 .31601 .30575 Metetra
.766 .851 .914 r
.31601 .30575 .32 .30826 .32607 .30666 .32225 .30184 Metetra
.773 .736 .819 r
.32225 .30184 .32607 .30666 .33222 .30404 .32856 .2968 Metetra
.748 .656 .76 r
.32856 .2968 .33222 .30404 .33847 .30003 .33491 .29119 Metetra
.722 .613 .735 r
.33491 .29119 .33847 .30003 .34479 .29484 .34125 .28572 Metetra
.702 .598 .738 r
.34125 .28572 .34479 .29484 .35115 .28912 .34755 .28097 Metetra
.686 .609 .764 r
.34755 .28097 .35115 .28912 .35749 .28365 .3538 .27721 Metetra
.674 .649 .817 r
.3538 .27721 .35749 .28365 .36379 .27905 .36002 .27436 Metetra
.664 .715 .886 r
.36002 .27436 .36379 .27905 .37004 .27554 .36621 .27205 Metetra
.657 .778 .938 r
.36621 .27205 .37004 .27554 .37625 .27297 .37241 .26988 Metetra
.669 .806 .948 r
.37241 .26988 .37625 .27297 .38245 .27094 .37864 .26752 Metetra
.692 .792 .927 r
.37864 .26752 .38245 .27094 .38866 .26897 .3849 .26483 Metetra
.704 .756 .892 r
.3849 .26483 .38866 .26897 .3949 .2667 .39118 .26185 Metetra
.702 .722 .865 r
.39118 .26185 .3949 .2667 .40117 .264 .39747 .25874 Metetra
.695 .703 .853 r
.39747 .25874 .40117 .264 .40747 .26093 .40378 .25569 Metetra
.687 .701 .857 r
.40378 .25569 .40747 .26093 .41379 .25774 .41009 .25282 Metetra
.678 .712 .874 r
.41009 .25282 .41379 .25774 .42011 .25468 .41641 .25018 Metetra
.669 .73 .895 r
.41641 .25018 .42011 .25468 .42643 .25197 .42273 .24778 Metetra
.658 .742 .912 r
.42273 .24778 .42643 .25197 .43275 .24968 .42905 .24556 Metetra
.647 .744 .92 r
.42905 .24556 .43275 .24968 .43908 .24774 .43539 .2435 Metetra
.639 .735 .918 r
.43539 .2435 .43908 .24774 .44542 .24597 .44174 .24157 Metetra
.634 .725 .913 r
.44174 .24157 .44542 .24597 .45178 .24411 .44811 .23969 Metetra
.636 .725 .912 r
.44811 .23969 .45178 .24411 .45816 .24198 .4545 .23778 Metetra
.645 .74 .918 r
.4545 .23778 .45816 .24198 .46456 .2395 .4609 .23573 Metetra
.66 .77 .931 r
.4609 .23573 .46456 .2395 .47098 .2368 .46732 .23344 Metetra
.675 .799 .941 r
.46732 .23344 .47098 .2368 .47741 .23419 .47377 .23092 Metetra
.68 .807 .943 r
.47377 .23092 .47741 .23419 .48385 .23203 .48023 .22831 Metetra
.668 .778 .932 r
.48023 .22831 .48385 .23203 .4903 .23063 .4867 .2259 Metetra
.634 .711 .902 r
.4867 .2259 .4903 .23063 .49676 .23006 .49318 .22399 Metetra
.588 .632 .862 r
.49318 .22399 .49676 .23006 .50324 .23005 .49967 .22282 Metetra
.547 .571 .83 r
.49967 .22282 .50324 .23005 .50975 .23008 .50618 .2224 Metetra
.523 .544 .819 r
.50618 .2224 .50975 .23008 .51628 .22954 .51271 .22243 Metetra
.522 .562 .837 r
.51271 .22243 .51628 .22954 .52283 .22806 .51927 .22241 Metetra
.548 .632 .887 r
.51927 .22241 .52283 .22806 .52941 .22568 .52585 .22182 Metetra
.594 .747 .95 r
.52585 .22182 .52941 .22568 .536 .22292 .53245 .22034 Metetra
.636 .844 .98 r
.53245 .22034 .536 .22292 .5426 .2206 .53907 .21809 Metetra
.657 .856 .976 r
.53907 .21809 .5426 .2206 .54923 .21948 .54571 .21556 Metetra
.639 .763 .937 r
.54571 .21556 .54923 .21948 .5559 .21991 .55236 .2135 Metetra
.576 .617 .856 r
.55236 .2135 .5559 .21991 .56261 .22157 .55904 .21252 Metetra
.515 .506 .785 r
.55904 .21252 .56261 .22157 .56936 .22355 .56577 .21284 Metetra
.48 .453 .75 r
.56577 .21284 .56936 .22355 .57614 .22467 .57254 .2141 Metetra
.475 .453 .753 r
.57254 .2141 .57614 .22467 .58291 .22395 .57934 .21545 Metetra
.507 .517 .801 r
.57934 .21545 .58291 .22395 .58965 .22102 .58615 .21585 Metetra
.592 .68 .902 r
.58615 .21585 .58965 .22102 .59637 .21632 .59296 .21452 Metetra
.69 .915 .971 r
.59296 .21452 .59637 .21632 .60308 .21089 .59974 .21127 Metetra
.677 .977 .85 r
.59974 .21127 .60308 .21089 .6098 .20593 .6065 .20654 Metetra
.702 .983 .822 r
.6065 .20654 .6098 .20593 .61657 .20233 .61324 .20126 Metetra
.777 .969 .921 r
.61324 .20126 .61657 .20233 .6234 .20029 .62 .19646 Metetra
.732 .805 .91 r
.62 .19646 .6234 .20029 .63029 .19933 .62681 .1928 Metetra
.647 .652 .84 r
.62681 .1928 .63029 .19933 .6372 .19844 .63368 .19039 Metetra
.603 .584 .804 r
.63368 .19039 .6372 .19844 .64411 .19662 .64059 .18878 Metetra
.605 .591 .81 r
.64059 .18878 .64411 .19662 .65096 .19317 .64753 .18713 Metetra
.654 .674 .857 r
.64753 .18713 .65096 .19317 .65775 .18804 .65444 .18464 Metetra
.74 .836 .924 r
.65444 .18464 .65775 .18804 .6645 .18177 .66132 .18084 Metetra
.782 .979 .909 r
.66132 .18084 .6645 .18177 .67123 .17523 .66815 .17576 Metetra
.739 .99 .804 r
.66815 .17576 .67123 .17523 .67799 .16927 .67494 .16986 Metetra
.739 .989 .796 r
.67494 .16986 .67799 .16927 .68481 .16447 .68172 .16385 Metetra
.787 .99 .886 r
.68172 .16385 .68481 .16447 .69171 .16093 .68854 .15841 Metetra
.776 .9 .929 r
.68854 .15841 .69171 .16093 .69868 .15837 .69542 .15393 Metetra
.714 .774 .9 r
.69542 .15393 .69868 .15837 .70569 .15624 .70236 .15048 Metetra
.665 .693 .866 r
.70236 .15048 .70569 .15624 .71272 .15401 .70937 .14778 Metetra
.645 .666 .855 r
.70937 .14778 .71272 .15401 .71973 .1513 .71642 .14542 Metetra
.651 .683 .867 r
.71642 .14542 .71973 .1513 .72672 .148 .72347 .14297 Metetra
.675 .732 .893 r
.72347 .14297 .72672 .148 .7337 .14424 .73053 .14017 Metetra
.703 .794 .921 r
.73053 .14017 .7337 .14424 .74067 .14031 .73757 .13694 Metetra
.722 .842 .938 r
.73757 .13694 .74067 .14031 .74766 .1365 .7446 .13339 Metetra
.728 .861 .944 r
.7446 .13339 .74766 .1365 .75469 .13304 .75163 .12973 Metetra
.721 .847 .942 r
.75163 .12973 .75469 .13304 .76177 .13 .75869 .12618 Metetra
.705 .812 .932 r
.75869 .12618 .76177 .13 .7689 .12733 .76578 .1229 Metetra
.667 .741 .905 r
.13106 .35009 .13517 .35394 .14081 .3522 .13676 .34795 Metetra
.672 .722 .887 r
.13676 .34795 .14081 .3522 .14649 .35025 .14247 .34569 Metetra
.667 .706 .877 r
.14247 .34569 .14649 .35025 .1522 .34804 .1482 .34348 Metetra
.65 .702 .884 r
.1482 .34348 .1522 .34804 .15795 .34569 .1539 .34155 Metetra
.616 .713 .915 r
.1539 .34155 .15795 .34569 .1637 .34341 .15956 .34012 Metetra
.544 .739 .966 r
.15956 .34012 .1637 .34341 .16942 .34152 .16516 .33929 Metetra
.401 .752 .994 r
.16516 .33929 .16942 .34152 .17508 .34029 .17072 .339 Metetra
.221 .707 .928 r
.17072 .339 .17508 .34029 .18067 .33983 .17627 .33898 Metetra
.178 .697 .883 r
.17627 .33898 .18067 .33983 .1862 .34001 .18185 .33885 Metetra
.343 .784 .962 r
.18185 .33885 .1862 .34001 .19174 .34044 .1875 .33824 Metetra
.555 .816 .994 r
.1875 .33824 .19174 .34044 .19732 .34062 .19324 .33697 Metetra
.641 .751 .929 r
.19324 .33697 .19732 .34062 .20299 .34007 .19905 .33515 Metetra
.647 .688 .875 r
.19905 .33515 .20299 .34007 .20878 .33862 .20489 .33321 Metetra
.617 .657 .866 r
.20489 .33321 .20878 .33862 .21464 .33646 .2107 .33173 Metetra
.544 .659 .911 r
.2107 .33173 .21464 .33646 .22054 .33419 .21643 .33117 Metetra
.316 .659 .972 r
.21643 .33117 .22054 .33419 .22639 .33251 .22207 .3317 Metetra
.191 0 0 r
.22207 .3317 .22639 .33251 .23214 .33202 .22766 .33301 Metetra
.397 0 0 r
.22766 .33301 .23214 .33202 .23779 .33281 .23327 .33442 Metetra
.323 0 0 r
.23327 .33442 .23779 .33281 .2434 .33447 .23898 .33506 Metetra
.099 .653 .704 r
.23898 .33506 .2434 .33447 .24903 .33608 .24484 .33425 Metetra
.669 .875 .976 r
.24484 .33425 .24903 .33608 .25478 .33663 .25086 .33176 Metetra
.734 .722 .84 r
.25086 .33176 .25478 .33663 .2607 .33536 .25701 .32793 Metetra
.715 .636 .768 r
.25701 .32793 .2607 .33536 .26681 .33212 .26321 .32349 Metetra
.693 .601 .749 r
.26321 .32349 .26681 .33212 .27304 .32742 .2694 .31931 Metetra
.674 .602 .768 r
.2694 .31931 .27304 .32742 .27931 .32224 .27553 .31599 Metetra
.655 .645 .828 r
.27553 .31599 .27931 .32224 .28554 .31756 .28159 .31365 Metetra
.631 .741 .927 r
.28159 .31365 .28554 .31756 .2917 .31405 .28762 .31189 Metetra
.61 .844 .988 r
.28762 .31189 .2917 .31405 .29777 .31175 .29368 .31004 Metetra
.673 .887 .976 r
.29368 .31004 .29777 .31175 .30381 .31014 .2998 .30741 Metetra
.759 .837 .911 r
.2998 .30741 .30381 .31014 .30987 .30839 .30602 .30362 Metetra
.769 .737 .824 r
.30602 .30362 .30987 .30839 .31601 .30575 .31231 .29875 Metetra
.748 .662 .766 r
.31231 .29875 .31601 .30575 .32225 .30184 .31866 .29327 Metetra
.725 .619 .739 r
.31866 .29327 .32225 .30184 .32856 .2968 .325 .28781 Metetra
.706 .603 .739 r
.325 .28781 .32856 .2968 .33491 .29119 .3313 .28295 Metetra
.692 .61 .76 r
.3313 .28295 .33491 .29119 .34125 .28572 .33756 .27897 Metetra
.682 .643 .805 r
.33756 .27897 .34125 .28572 .34755 .28097 .34377 .27584 Metetra
.675 .698 .864 r
.34377 .27584 .34755 .28097 .3538 .27721 .34997 .27325 Metetra
.674 .755 .912 r
.34997 .27325 .3538 .27721 .36002 .27436 .35617 .27083 Metetra
.685 .783 .925 r
.35617 .27083 .36002 .27436 .36621 .27205 .36239 .26824 Metetra
.701 .772 .907 r
.36239 .26824 .36621 .27205 .37241 .26988 .36863 .26536 Metetra
.708 .738 .875 r
.36863 .26536 .37241 .26988 .37864 .26752 .37491 .26221 Metetra
.702 .703 .847 r
.37491 .26221 .37864 .26752 .3849 .26483 .38119 .25898 Metetra
.691 .679 .833 r
.38119 .25898 .3849 .26483 .39118 .26185 .38749 .25586 Metetra
.679 .669 .834 r
.38749 .25586 .39118 .26185 .39747 .25874 .39378 .25299 Metetra
.668 .674 .846 r
.39378 .25299 .39747 .25874 .40378 .25569 .40007 .2504 Metetra
.661 .691 .867 r
.40007 .2504 .40378 .25569 .41009 .25282 .40637 .24804 Metetra
.658 .713 .888 r
.40637 .24804 .41009 .25282 .41641 .25018 .41268 .24578 Metetra
.66 .733 .903 r
.41268 .24578 .41641 .25018 .42273 .24778 .41901 .24352 Metetra
.664 .742 .908 r
.41901 .24352 .42273 .24778 .42905 .24556 .42535 .24119 Metetra
.667 .738 .903 r
.42535 .24119 .42905 .24556 .43539 .2435 .4317 .2388 Metetra
.665 .721 .891 r
.4317 .2388 .43539 .2435 .44174 .24157 .43808 .23642 Metetra
.656 .697 .877 r
.43808 .23642 .44174 .24157 .44811 .23969 .44446 .23414 Metetra
.644 .676 .866 r
.44446 .23414 .44811 .23969 .4545 .23778 .45086 .23204 Metetra
.634 .664 .862 r
.45086 .23204 .4545 .23778 .4609 .23573 .45726 .2301 Metetra
.631 .668 .867 r
.45726 .2301 .4609 .23573 .46732 .23344 .46369 .22823 Metetra
.636 .688 .882 r
.46369 .22823 .46732 .23344 .47377 .23092 .47013 .22629 Metetra
.648 .721 .902 r
.47013 .22629 .47377 .23092 .48023 .22831 .47659 .22416 Metetra
.661 .752 .917 r
.47659 .22416 .48023 .22831 .4867 .2259 .48307 .22183 Metetra
.665 .759 .92 r
.48307 .22183 .4867 .2259 .49318 .22399 .48957 .21945 Metetra
.651 .729 .906 r
.48957 .21945 .49318 .22399 .49967 .22282 .49608 .21726 Metetra
.618 .668 .876 r
.49608 .21726 .49967 .22282 .50618 .2224 .5026 .21558 Metetra
.577 .601 .84 r
.5026 .21558 .50618 .2224 .51271 .22243 .50914 .21461 Metetra
.541 .551 .814 r
.50914 .21461 .51271 .22243 .51927 .22241 .51569 .21431 Metetra
.522 .533 .808 r
.51569 .21431 .51927 .22241 .52585 .22182 .52227 .21439 Metetra
.523 .554 .828 r
.52227 .21439 .52585 .22182 .53245 .22034 .52888 .21437 Metetra
.549 .62 .876 r
.52888 .21437 .53245 .22034 .53907 .21809 .53552 .21378 Metetra
.592 .722 .934 r
.53552 .21378 .53907 .21809 .54571 .21556 .54217 .21238 Metetra
.631 .806 .967 r
.54217 .21238 .54571 .21556 .55236 .2135 .54883 .21031 Metetra
.647 .811 .962 r
.54883 .21031 .55236 .2135 .55904 .21252 .55552 .20803 Metetra
.624 .727 .921 r
.55552 .20803 .55904 .21252 .56577 .21284 .56222 .2062 Metetra
.57 .607 .851 r
.56222 .2062 .56577 .21284 .57254 .2141 .56896 .20531 Metetra
.521 .517 .792 r
.56896 .20531 .57254 .2141 .57934 .21545 .57574 .20546 Metetra
.496 .476 .765 r
.57574 .20546 .57934 .21545 .58615 .21585 .58256 .20626 Metetra
.499 .487 .775 r
.58256 .20626 .58615 .21585 .59296 .21452 .58941 .20694 Metetra
.539 .562 .826 r
.58941 .20694 .59296 .21452 .59974 .21127 .59626 .20664 Metetra
.626 .724 .918 r
.59626 .20664 .59974 .21127 .6065 .20654 .6031 .20474 Metetra
.712 .922 .964 r
.6031 .20474 .6065 .20654 .61324 .20126 .60992 .20118 Metetra
.717 .986 .884 r
.60992 .20118 .61324 .20126 .62 .19646 .61671 .19642 Metetra
.743 .992 .873 r
.61671 .19642 .62 .19646 .62681 .1928 .62349 .19127 Metetra
.781 .95 .929 r
.62349 .19127 .62681 .1928 .63368 .19039 .63029 .18657 Metetra
.735 .809 .91 r
.63029 .18657 .63368 .19039 .64059 .18878 .63714 .18282 Metetra
.667 .684 .856 r
.63714 .18282 .64059 .18878 .64753 .18713 .64404 .18007 Metetra
.633 .629 .829 r
.64404 .18007 .64753 .18713 .65444 .18464 .65098 .17788 Metetra
.639 .642 .837 r
.65098 .17788 .65444 .18464 .66132 .18084 .65793 .1756 Metetra
.684 .723 .879 r
.65793 .1756 .66132 .18084 .66815 .17576 .66486 .17261 Metetra
.752 .857 .927 r
.66486 .17261 .66815 .17576 .67494 .16986 .67177 .16858 Metetra
.785 .968 .919 r
.67177 .16858 .67494 .16986 .68172 .16385 .67863 .16359 Metetra
.771 .995 .867 r
.67863 .16359 .68172 .16385 .68854 .15841 .68547 .15805 Metetra
.774 .995 .871 r
.68547 .15805 .68854 .15841 .69542 .15393 .69231 .15253 Metetra
.788 .964 .919 r
.69231 .15253 .69542 .15393 .70236 .15048 .69919 .14753 Metetra
.76 .875 .93 r
.69919 .14753 .70236 .15048 .70937 .14778 .70612 .14333 Metetra
.709 .774 .903 r
.70612 .14333 .70937 .14778 .71642 .14542 .71311 .13995 Metetra
.671 .71 .878 r
.71311 .13995 .71642 .14542 .72347 .14297 .72016 .13717 Metetra
.655 .689 .87 r
.72016 .13717 .72347 .14297 .73053 .14017 .72724 .13463 Metetra
.66 .703 .879 r
.72724 .13463 .73053 .14017 .73757 .13694 .73434 .13204 Metetra
.677 .741 .899 r
.73434 .13204 .73757 .13694 .7446 .13339 .74143 .12918 Metetra
.697 .787 .92 r
.74143 .12918 .7446 .13339 .75163 .12973 .74852 .12602 Metetra
.711 .821 .933 r
.74852 .12602 .75163 .12973 .75869 .12618 .75561 .12264 Metetra
.714 .832 .938 r
.75561 .12264 .75869 .12618 .76578 .1229 .7627 .11919 Metetra
.666 .716 .886 r
.127 .34575 .13106 .35009 .13676 .34795 .1327 .34359 Metetra
.653 .712 .891 r
.1327 .34359 .13676 .34795 .14247 .34569 .13838 .34163 Metetra
.628 .721 .914 r
.13838 .34163 .14247 .34569 .1482 .34348 .14404 .34004 Metetra
.58 .742 .953 r
.14404 .34004 .1482 .34348 .1539 .34155 .14965 .33891 Metetra
.496 .765 .991 r
.14965 .33891 .1539 .34155 .15956 .34012 .15523 .33823 Metetra
.389 .768 .991 r
.15523 .33823 .15956 .34012 .16516 .33929 .16079 .33782 Metetra
.344 .769 .974 r
.16079 .33782 .16516 .33929 .17072 .339 .16638 .33739 Metetra
.422 .8 .992 r
.16638 .33739 .17072 .339 .17627 .33898 .17201 .33667 Metetra
.549 .807 .993 r
.17201 .33667 .17627 .33898 .18185 .33885 .17772 .33548 Metetra
.621 .761 .946 r
.17772 .33548 .18185 .33885 .1875 .33824 .18348 .33388 Metetra
.633 .711 .903 r
.18348 .33388 .1875 .33824 .19324 .33697 .18927 .33219 Metetra
.609 .682 .894 r
.18927 .33219 .19324 .33697 .19905 .33515 .19504 .33083 Metetra
.543 .681 .929 r
.19504 .33083 .19905 .33515 .20489 .33321 .20075 .3302 Metetra
.359 .682 .979 r
.20075 .3302 .20489 .33321 .2107 .33173 .20638 .33049 Metetra
0 .518 .783 r
.20638 .33049 .2107 .33173 .21643 .33117 .21197 .33148 Metetra
.306 0 0 r
.21197 .33148 .21643 .33117 .22207 .3317 .21756 .33267 Metetra
.276 0 0 r
.21756 .33267 .22207 .3317 .22766 .33301 .22322 .33335 Metetra
.056 .621 .707 r
.22322 .33335 .22766 .33301 .23327 .33442 .22902 .3329 Metetra
.585 .872 .994 r
.22902 .3329 .23327 .33442 .23898 .33506 .23496 .33106 Metetra
.712 .755 .886 r
.23496 .33106 .23898 .33506 .24484 .33425 .24102 .32801 Metetra
.709 .665 .805 r
.24102 .32801 .24484 .33425 .25086 .33176 .24716 .3243 Metetra
.692 .625 .777 r
.24716 .3243 .25086 .33176 .25701 .32793 .25329 .32066 Metetra
.674 .622 .79 r
.25329 .32066 .25701 .32793 .26321 .32349 .25938 .3176 Metetra
.656 .658 .84 r
.25938 .3176 .26321 .32349 .2694 .31931 .26543 .31531 Metetra
.636 .737 .922 r
.26543 .31531 .2694 .31931 .27553 .31599 .27144 .3135 Metetra
.624 .826 .978 r
.27144 .3135 .27553 .31599 .28159 .31365 .27748 .31162 Metetra
.676 .868 .972 r
.27748 .31162 .28159 .31365 .28762 .31189 .28358 .30905 Metetra
.749 .829 .913 r
.28358 .30905 .28762 .31189 .29368 .31004 .28977 .30544 Metetra
.765 .743 .833 r
.28977 .30544 .29368 .31004 .2998 .30741 .29605 .3008 Metetra
.75 .672 .775 r
.29605 .3008 .2998 .30741 .30602 .30362 .30238 .29551 Metetra
.729 .63 .748 r
.30238 .29551 .30602 .30362 .31231 .29875 .30872 .29013 Metetra
.712 .612 .744 r
.30872 .29013 .31231 .29875 .31866 .29327 .31502 .28521 Metetra
.699 .618 .762 r
.31502 .28521 .31866 .29327 .325 .28781 .32129 .28105 Metetra
.69 .646 .801 r
.32129 .28105 .325 .28781 .3313 .28295 .3275 .27767 Metetra
.686 .696 .854 r
.3275 .27767 .3313 .28295 .33756 .27897 .3337 .27484 Metetra
.686 .75 .9 r
.3337 .27484 .33756 .27897 .34377 .27584 .33989 .27221 Metetra
.694 .78 .917 r
.33989 .27221 .34377 .27584 .34997 .27325 .3461 .26948 Metetra
.707 .775 .905 r
.3461 .26948 .34997 .27325 .35617 .27083 .35234 .2665 Metetra
.713 .749 .88 r
.35234 .2665 .35617 .27083 .36239 .26824 .3586 .26329 Metetra
.71 .72 .857 r
.3586 .26329 .36239 .26824 .36863 .26536 .36488 .25999 Metetra
.701 .7 .846 r
.36488 .25999 .36863 .26536 .37491 .26221 .37116 .25678 Metetra
.69 .694 .849 r
.37116 .25678 .37491 .26221 .38119 .25898 .37745 .2538 Metetra
.679 .701 .864 r
.37745 .2538 .38119 .25898 .38749 .25586 .38373 .25111 Metetra
.668 .717 .885 r
.38373 .25111 .38749 .25586 .39378 .25299 .39001 .24868 Metetra
.66 .737 .907 r
.39001 .24868 .39378 .25299 .40007 .2504 .3963 .24642 Metetra
.656 .754 .922 r
.3963 .24642 .40007 .2504 .40637 .24804 .4026 .24423 Metetra
.657 .765 .929 r
.4026 .24423 .40637 .24804 .41268 .24578 .40892 .24202 Metetra
.662 .769 .929 r
.40892 .24202 .41268 .24578 .41901 .24352 .41525 .23972 Metetra
.669 .77 .926 r
.41525 .23972 .41901 .24352 .42535 .24119 .42161 .23733 Metetra
.674 .768 .922 r
.42161 .23733 .42535 .24119 .4317 .2388 .42798 .23484 Metetra
.675 .764 .918 r
.42798 .23484 .4317 .2388 .43808 .23642 .43436 .23233 Metetra
.672 .756 .914 r
.43436 .23233 .43808 .23642 .44446 .23414 .44076 .22984 Metetra
.665 .743 .909 r
.44076 .22984 .44446 .23414 .45086 .23204 .44717 .22748 Metetra
.653 .726 .903 r
.44717 .22748 .45086 .23204 .45726 .2301 .45359 .22529 Metetra
.64 .709 .897 r
.45359 .22529 .45726 .2301 .46369 .22823 .46003 .22329 Metetra
.63 .7 .896 r
.46003 .22329 .46369 .22823 .47013 .22629 .46648 .22144 Metetra
.628 .704 .9 r
.46648 .22144 .47013 .22629 .47659 .22416 .47294 .21962 Metetra
.634 .722 .911 r
.47294 .21962 .47659 .22416 .48307 .22183 .47942 .2177 Metetra
.645 .749 .925 r
.47942 .2177 .48307 .22183 .48957 .21945 .48593 .2156 Metetra
.656 .77 .933 r
.48593 .2156 .48957 .21945 .49608 .21726 .49245 .21333 Metetra
.656 .765 .93 r
.49245 .21333 .49608 .21726 .5026 .21558 .49899 .21105 Metetra
.64 .727 .912 r
.49899 .21105 .5026 .21558 .50914 .21461 .50554 .20902 Metetra
.606 .663 .879 r
.50554 .20902 .50914 .21461 .51569 .21431 .51211 .20752 Metetra
.567 .598 .844 r
.51211 .20752 .51569 .21431 .52227 .21439 .51869 .20669 Metetra
.535 .553 .82 r
.51869 .20669 .52227 .21439 .52888 .21437 .5253 .20648 Metetra
.519 .538 .816 r
.5253 .20648 .52888 .21437 .53552 .21378 .53194 .20656 Metetra
.523 .562 .836 r
.53194 .20656 .53552 .21378 .54217 .21238 .5386 .2065 Metetra
.549 .626 .881 r
.5386 .2065 .54217 .21238 .54883 .21031 .54528 .20587 Metetra
.59 .716 .931 r
.54528 .20587 .54883 .21031 .55552 .20803 .55198 .2045 Metetra
.624 .784 .958 r
.55198 .2045 .55552 .20803 .56222 .2062 .5587 .20255 Metetra
.636 .781 .951 r
.5587 .20255 .56222 .2062 .56896 .20531 .56543 .20045 Metetra
.615 .706 .91 r
.56543 .20045 .56896 .20531 .57574 .20546 .57219 .19876 Metetra
.57 .607 .85 r
.57219 .19876 .57574 .20546 .58256 .20626 .57898 .19784 Metetra
.532 .534 .803 r
.57898 .19784 .58256 .20626 .58941 .20694 .58581 .19773 Metetra
.515 .506 .784 r
.58581 .19773 .58941 .20694 .59626 .20664 .59268 .19802 Metetra
.527 .527 .799 r
.59268 .19802 .59626 .20664 .6031 .20474 .59957 .19802 Metetra
.574 .61 .851 r
.59957 .19802 .6031 .20474 .60992 .20118 .60646 .19702 Metetra
.658 .765 .929 r
.60646 .19702 .60992 .20118 .61671 .19642 .61333 .1946 Metetra
.73 .927 .956 r
.61333 .1946 .61671 .19642 .62349 .19127 .62018 .19077 Metetra
.745 .984 .905 r
.62018 .19077 .62349 .19127 .63029 .18657 .627 .18597 Metetra
.767 .986 .901 r
.627 .18597 .63029 .18657 .63714 .18282 .63382 .18092 Metetra
.782 .932 .931 r
.63382 .18092 .63714 .18282 .64404 .18007 .64067 .17628 Metetra
.739 .815 .911 r
.64067 .17628 .64404 .18007 .65098 .17788 .64755 .17243 Metetra
.686 .715 .871 r
.64755 .17243 .65098 .17788 .65793 .1756 .65448 .16937 Metetra
.659 .672 .851 r
.65448 .16937 .65793 .1756 .66486 .17261 .66144 .16671 Metetra
.668 .689 .861 r
.66144 .16671 .66486 .17261 .67177 .16858 .66841 .16393 Metetra
.707 .761 .895 r
.66841 .16393 .67177 .16858 .67863 .16359 .67537 .16056 Metetra
.758 .868 .929 r
.67537 .16056 .67863 .16359 .68547 .15805 .6823 .15641 Metetra
.784 .952 .927 r
.6823 .15641 .68547 .15805 .69231 .15253 .68921 .15156 Metetra
.783 .981 .905 r
.68921 .15156 .69231 .15253 .69919 .14753 .6961 .14637 Metetra
.783 .975 .913 r
.6961 .14637 .69919 .14753 .70612 .14333 .703 .14127 Metetra
.777 .932 .934 r
.703 .14127 .70612 .14333 .71311 .13995 .70994 .13665 Metetra
.745 .852 .929 r
.70994 .13665 .71311 .13995 .72016 .13717 .71692 .13269 Metetra
.704 .773 .906 r
.71692 .13269 .72016 .13717 .72724 .13463 .72397 .12938 Metetra
.674 .724 .887 r
.72397 .12938 .72724 .13463 .73434 .13204 .73106 .12653 Metetra
.662 .707 .881 r
.73106 .12653 .73434 .13204 .74143 .12918 .73818 .12388 Metetra
.665 .718 .888 r
.73818 .12388 .74143 .12918 .74852 .12602 .74531 .12118 Metetra
.678 .747 .903 r
.74531 .12118 .74852 .12602 .75561 .12264 .75245 .1183 Metetra
.692 .78 .918 r
.75245 .1183 .75561 .12264 .7627 .11919 .75959 .1152 Metetra
.637 .726 .913 r
.12287 .34174 .127 .34575 .1327 .34359 .12852 .34003 Metetra
.604 .743 .942 r
.12852 .34003 .1327 .34359 .13838 .34163 .13414 .33867 Metetra
.553 .765 .976 r
.13414 .33867 .13838 .34163 .14404 .34004 .13973 .33768 Metetra
.49 .782 .997 r
.13973 .33768 .14404 .34004 .14965 .33891 .1453 .33693 Metetra
.454 .791 .999 r
.1453 .33693 .14965 .33891 .15523 .33823 .15089 .33622 Metetra
.484 .803 1 r
.15089 .33622 .15523 .33823 .16079 .33782 .15652 .33535 Metetra
.555 .799 .989 r
.15652 .33535 .16079 .33782 .16638 .33739 .16219 .33417 Metetra
.607 .767 .956 r
.16219 .33417 .16638 .33739 .17201 .33667 .16792 .3327 Metetra
.621 .728 .923 r
.16792 .3327 .17201 .33667 .17772 .33548 .17367 .33116 Metetra
.601 .703 .915 r
.17367 .33116 .17772 .33548 .18348 .33388 .1794 .32987 Metetra
.544 .699 .941 r
.1794 .32987 .18348 .33388 .18927 .33219 .18509 .32917 Metetra
.398 .701 .983 r
.18509 .32917 .18927 .33219 .19504 .33083 .19071 .32923 Metetra
.084 .604 .88 r
.19071 .32923 .19504 .33083 .20075 .3302 .19629 .32992 Metetra
.189 0 0 r
.19629 .32992 .20075 .3302 .20638 .33049 .20187 .33088 Metetra
.208 0 0 r
.20187 .33088 .20638 .33049 .21197 .33148 .2075 .33153 Metetra
.039 .609 .728 r
.2075 .33153 .21197 .33148 .21756 .33267 .21324 .33134 Metetra
.49 .848 .992 r
.21324 .33134 .21756 .33267 .22322 .33335 .2191 .33003 Metetra
.676 .785 .932 r
.2191 .33003 .22322 .33335 .22902 .3329 .22508 .32767 Metetra
.696 .696 .846 r
.22508 .32767 .22902 .3329 .23496 .33106 .23114 .32466 Metetra
.686 .652 .811 r
.23114 .32466 .23496 .33106 .24102 .32801 .23721 .32156 Metetra
.67 .645 .816 r
.23721 .32156 .24102 .32801 .24716 .3243 .24326 .31883 Metetra
.653 .673 .857 r
.24326 .31883 .24716 .3243 .25329 .32066 .24928 .31666 Metetra
.634 .737 .923 r
.24928 .31666 .25329 .32066 .25938 .3176 .25527 .31487 Metetra
.627 .812 .971 r
.25527 .31487 .25938 .3176 .26543 .31531 .26128 .31302 Metetra
.671 .85 .968 r
.26128 .31302 .26543 .31531 .27144 .3135 .26736 .31057 Metetra
.737 .822 .917 r
.26736 .31057 .27144 .3135 .27748 .31162 .27353 .30717 Metetra
.759 .748 .843 r
.27353 .30717 .27748 .31162 .28358 .30905 .27978 .3028 Metetra
.749 .682 .786 r
.27978 .3028 .28358 .30905 .28977 .30544 .28609 .29773 Metetra
.732 .64 .756 r
.28609 .29773 .28977 .30544 .29605 .3008 .29242 .29248 Metetra
.716 .62 .749 r
.29242 .29248 .29605 .3008 .30238 .29551 .29873 .28754 Metetra
.705 .622 .762 r
.29873 .28754 .30238 .29551 .30872 .29013 .30499 .28323 Metetra
.697 .645 .794 r
.30499 .28323 .30872 .29013 .31502 .28521 .31122 .27961 Metetra
.694 .687 .838 r
.31122 .27961 .31502 .28521 .32129 .28105 .31741 .27651 Metetra
.695 .732 .879 r
.31741 .27651 .32129 .28105 .3275 .27767 .32361 .27363 Metetra
.702 .759 .896 r
.32361 .27363 .3275 .27767 .3337 .27484 .32982 .2707 Metetra
.712 .757 .888 r
.32982 .2707 .3337 .27484 .33989 .27221 .33605 .26757 Metetra
.715 .734 .866 r
.33605 .26757 .33989 .27221 .3461 .26948 .34231 .26424 Metetra
.71 .708 .846 r
.34231 .26424 .3461 .26948 .35234 .2665 .34858 .26085 Metetra
.701 .689 .835 r
.34858 .26085 .35234 .2665 .3586 .26329 .35485 .25755 Metetra
.69 .682 .837 r
.35485 .25755 .3586 .26329 .36488 .25999 .36112 .25448 Metetra
.68 .688 .851 r
.36112 .25448 .36488 .25999 .37116 .25678 .36739 .25169 Metetra
.671 .703 .871 r
.36739 .25169 .37116 .25678 .37745 .2538 .37366 .24916 Metetra
.665 .722 .891 r
.37366 .24916 .37745 .2538 .38373 .25111 .37993 .24679 Metetra
.662 .738 .906 r
.37993 .24679 .38373 .25111 .39001 .24868 .38622 .24449 Metetra
.663 .745 .911 r
.38622 .24449 .39001 .24868 .3963 .24642 .39252 .24219 Metetra
.665 .744 .909 r
.39252 .24219 .3963 .24642 .4026 .24423 .39883 .23984 Metetra
.666 .737 .903 r
.39883 .23984 .4026 .24423 .40892 .24202 .40517 .23746 Metetra
.666 .729 .897 r
.40517 .23746 .40892 .24202 .41525 .23972 .41151 .23507 Metetra
.665 .724 .893 r
.41151 .23507 .41525 .23972 .42161 .23733 .41787 .23268 Metetra
.664 .725 .894 r
.41787 .23268 .42161 .23733 .42798 .23484 .42425 .2303 Metetra
.665 .731 .899 r
.42425 .2303 .42798 .23484 .43436 .23233 .43064 .22791 Metetra
.666 .738 .904 r
.43064 .22791 .43436 .23233 .44076 .22984 .43705 .22552 Metetra
.666 .743 .908 r
.43705 .22552 .44076 .22984 .44717 .22748 .44347 .22311 Metetra
.663 .741 .908 r
.44347 .22311 .44717 .22748 .45359 .22529 .4499 .22075 Metetra
.657 .73 .903 r
.4499 .22075 .45359 .22529 .46003 .22329 .45635 .21847 Metetra
.647 .713 .896 r
.45635 .21847 .46003 .22329 .46648 .22144 .46281 .21635 Metetra
.635 .696 .889 r
.46281 .21635 .46648 .22144 .47294 .21962 .46929 .21439 Metetra
.627 .687 .887 r
.46929 .21439 .47294 .21962 .47942 .2177 .47578 .21257 Metetra
.625 .691 .891 r
.47578 .21257 .47942 .2177 .48593 .2156 .48228 .21078 Metetra
.63 .708 .903 r
.48228 .21078 .48593 .2156 .49245 .21333 .48881 .20891 Metetra
.639 .733 .917 r
.48881 .20891 .49245 .21333 .49899 .21105 .49536 .20689 Metetra
.646 .751 .925 r
.49536 .20689 .49899 .21105 .50554 .20902 .50192 .20475 Metetra
.643 .744 .922 r
.50192 .20475 .50554 .20902 .51211 .20752 .5085 .20265 Metetra
.624 .706 .904 r
.5085 .20265 .51211 .20752 .51869 .20669 .5151 .20084 Metetra
.592 .648 .874 r
.5151 .20084 .51869 .20669 .5253 .20648 .52171 .19955 Metetra
.557 .59 .842 r
.52171 .19955 .5253 .20648 .53194 .20656 .52835 .19889 Metetra
.53 .552 .822 r
.52835 .19889 .53194 .20656 .5386 .2065 .53501 .19874 Metetra
.518 .543 .821 r
.53501 .19874 .5386 .2065 .54528 .20587 .5417 .19881 Metetra
.525 .57 .843 r
.5417 .19881 .54528 .20587 .55198 .2045 .54841 .19867 Metetra
.552 .632 .884 r
.54841 .19867 .55198 .2045 .5587 .20255 .55515 .19797 Metetra
.589 .711 .928 r
.55515 .19797 .5587 .20255 .56543 .20045 .5619 .1966 Metetra
.62 .765 .949 r
.5619 .1966 .56543 .20045 .57219 .19876 .56867 .19472 Metetra
.629 .759 .94 r
.56867 .19472 .57219 .19876 .57898 .19784 .57545 .19274 Metetra
.61 .695 .903 r
.57545 .19274 .57898 .19784 .58581 .19773 .58226 .19109 Metetra
.575 .614 .853 r
.58226 .19109 .58581 .19773 .59268 .19802 .5891 .19007 Metetra
.547 .557 .816 r
.5891 .19007 .59268 .19802 .59957 .19802 .59598 .18961 Metetra
.539 .54 .804 r
.59598 .18961 .59957 .19802 .60646 .19702 .60289 .18934 Metetra
.557 .571 .823 r
.60289 .18934 .60646 .19702 .61333 .1946 .60982 .18866 Metetra
.609 .659 .874 r
.60982 .18866 .61333 .1946 .62018 .19077 .61674 .18702 Metetra
.687 .801 .936 r
.61674 .18702 .62018 .19077 .627 .18597 .62365 .18412 Metetra
.745 .93 .95 r
.62365 .18412 .627 .18597 .63382 .18092 .63052 .18004 Metetra
.763 .977 .917 r
.63052 .18004 .63382 .18092 .64067 .17628 .63738 .17521 Metetra
.78 .973 .917 r
.63738 .17521 .64067 .17628 .64755 .17243 .64424 .17023 Metetra
.78 .918 .931 r
.64424 .17023 .64755 .17243 .65448 .16937 .65112 .16563 Metetra
.744 .822 .912 r
.65112 .16563 .65448 .16937 .66144 .16671 .65804 .16169 Metetra
.702 .742 .883 r
.65804 .16169 .66144 .16671 .66841 .16393 .665 .15836 Metetra
.682 .71 .87 r
.665 .15836 .66841 .16393 .67537 .16056 .67199 .15532 Metetra
.691 .729 .879 r
.67199 .15532 .67537 .16056 .6823 .15641 .67898 .15216 Metetra
.722 .79 .906 r
.67898 .15216 .6823 .15641 .68921 .15156 .68597 .14854 Metetra
.759 .871 .93 r
.68597 .14854 .68921 .15156 .6961 .14637 .69294 .14434 Metetra
.779 .934 .932 r
.69294 .14434 .6961 .14637 .703 .14127 .69988 .13966 Metetra
.782 .957 .926 r
.69988 .13966 .703 .14127 .70994 .13665 .70683 .13479 Metetra
.778 .945 .932 r
.70683 .13479 .70994 .13665 .71692 .13269 .71379 .13007 Metetra
.762 .899 .938 r
.71379 .13007 .71692 .13269 .72397 .12938 .72079 .12576 Metetra
.732 .833 .927 r
.72079 .12576 .72397 .12938 .73106 .12653 .72783 .12201 Metetra
.699 .772 .908 r
.72783 .12201 .73106 .12653 .73818 .12388 .73492 .11876 Metetra
.676 .733 .893 r
.73492 .11876 .73818 .12388 .74531 .12118 .74206 .11588 Metetra
.667 .721 .889 r
.74206 .11588 .74531 .12118 .75245 .1183 .74922 .11314 Metetra
.669 .729 .895 r
.74922 .11314 .75245 .1183 .75959 .1152 .7564 .11037 Metetra
.588 .761 .961 r
.11862 .33855 .12287 .34174 .12852 .34003 .12422 .3373 Metetra
.549 .778 .984 r
.12422 .3373 .12852 .34003 .13414 .33867 .1298 .33626 Metetra
.523 .791 .994 r
.1298 .33626 .13414 .33867 .13973 .33768 .13539 .33531 Metetra
.531 .797 .994 r
.13539 .33531 .13973 .33768 .1453 .33693 .14101 .33427 Metetra
.568 .791 .983 r
.14101 .33427 .1453 .33693 .15089 .33622 .14667 .33305 Metetra
.601 .768 .96 r
.14667 .33305 .15089 .33622 .15652 .33535 .15236 .33164 Metetra
.612 .739 .936 r
.15236 .33164 .15652 .33535 .16219 .33417 .15808 .33018 Metetra
.596 .719 .93 r
.15808 .33018 .16219 .33417 .16792 .3327 .16378 .32892 Metetra
.548 .715 .95 r
.16378 .32892 .16792 .3327 .17367 .33116 .16945 .32813 Metetra
.434 .717 .984 r
.16945 .32813 .17367 .33116 .1794 .32987 .17507 .32796 Metetra
.201 .666 .941 r
.17507 .32796 .1794 .32987 .18509 .32917 .18064 .32838 Metetra
0 .527 .747 r
.18064 .32838 .18509 .32917 .19071 .32923 .18621 .32908 Metetra
.119 0 0 r
.18621 .32908 .19071 .32923 .19629 .32992 .19181 .32965 Metetra
.048 .615 .764 r
.19181 .32965 .19629 .32992 .20187 .33088 .1975 .32964 Metetra
.404 .813 .978 r
.1975 .32964 .20187 .33088 .2075 .33153 .20329 .32875 Metetra
.623 .804 .969 r
.20329 .32875 .2075 .33153 .21324 .33134 .20919 .32697 Metetra
.673 .728 .891 r
.20919 .32697 .21324 .33134 .2191 .33003 .21517 .32458 Metetra
.674 .681 .849 r
.21517 .32458 .2191 .33003 .22508 .32767 .22118 .32201 Metetra
.662 .668 .846 r
.22118 .32201 .22508 .32767 .23114 .32466 .22718 .31964 Metetra
.645 .689 .877 r
.22718 .31964 .23114 .32466 .23721 .32156 .23315 .31766 Metetra
.627 .741 .929 r
.23315 .31766 .23721 .32156 .24326 .31883 .23912 .31596 Metetra
.621 .802 .969 r
.23912 .31596 .24326 .31883 .24928 .31666 .24511 .31419 Metetra
.661 .837 .967 r
.24511 .31419 .24928 .31666 .25527 .31487 .25115 .3119 Metetra
.723 .817 .924 r
.25115 .3119 .25527 .31487 .26128 .31302 .25729 .30876 Metetra
.751 .755 .856 r
.25729 .30876 .26128 .31302 .26736 .31057 .26351 .30469 Metetra
.748 .693 .799 r
.26351 .30469 .26736 .31057 .27353 .30717 .26979 .29992 Metetra
.734 .651 .766 r
.26979 .29992 .27353 .30717 .27978 .3028 .2761 .29486 Metetra
.72 .63 .756 r
.2761 .29486 .27978 .3028 .28609 .29773 .28241 .28996 Metetra
.71 .629 .765 r
.28241 .28996 .28609 .29773 .29242 .29248 .28867 .28554 Metetra
.703 .647 .79 r
.28867 .28554 .29242 .29248 .29873 .28754 .2949 .28172 Metetra
.701 .681 .827 r
.2949 .28172 .29873 .28754 .30499 .28323 .30111 .27837 Metetra
.703 .72 .862 r
.30111 .27837 .30499 .28323 .31122 .27961 .30731 .27526 Metetra
.709 .745 .88 r
.30731 .27526 .31122 .27961 .31741 .27651 .31351 .27214 Metetra
.716 .747 .876 r
.31351 .27214 .31741 .27651 .32361 .27363 .31974 .26886 Metetra
.719 .729 .859 r
.31974 .26886 .32361 .27363 .32982 .2707 .32599 .26541 Metetra
.714 .707 .842 r
.32599 .26541 .32982 .2707 .33605 .26757 .33226 .26191 Metetra
.705 .69 .833 r
.33226 .26191 .33605 .26757 .34231 .26424 .33852 .2585 Metetra
.695 .684 .835 r
.33852 .2585 .34231 .26424 .34858 .26085 .34479 .25532 Metetra
.685 .689 .848 r
.34479 .25532 .34858 .26085 .35485 .25755 .35105 .25243 Metetra
.676 .703 .868 r
.35105 .25243 .35485 .25755 .36112 .25448 .3573 .24981 Metetra
.669 .722 .889 r
.3573 .24981 .36112 .25448 .36739 .25169 .36356 .24737 Metetra
.666 .739 .905 r
.36356 .24737 .36739 .25169 .37366 .24916 .36983 .24502 Metetra
.666 .749 .912 r
.36983 .24502 .37366 .24916 .37993 .24679 .37611 .24267 Metetra
.669 .751 .912 r
.37611 .24267 .37993 .24679 .38622 .24449 .38241 .24027 Metetra
.671 .747 .908 r
.38241 .24027 .38622 .24449 .39252 .24219 .38872 .23782 Metetra
.672 .74 .902 r
.38872 .23782 .39252 .24219 .39883 .23984 .39505 .23535 Metetra
.67 .734 .898 r
.39505 .23535 .39883 .23984 .40517 .23746 .4014 .23288 Metetra
.667 .729 .896 r
.4014 .23288 .40517 .23746 .41151 .23507 .40776 .23046 Metetra
.664 .727 .896 r
.40776 .23046 .41151 .23507 .41787 .23268 .41412 .22809 Metetra
.66 .727 .899 r
.41412 .22809 .41787 .23268 .42425 .2303 .42051 .22577 Metetra
.659 .73 .902 r
.42051 .22577 .42425 .2303 .43064 .22791 .4269 .22347 Metetra
.659 .736 .906 r
.4269 .22347 .43064 .22791 .43705 .22552 .43332 .22117 Metetra
.662 .742 .909 r
.43332 .22117 .43705 .22552 .44347 .22311 .43975 .21882 Metetra
.664 .746 .911 r
.43975 .21882 .44347 .22311 .4499 .22075 .44619 .21644 Metetra
.665 .746 .91 r
.44619 .21644 .4499 .22075 .45635 .21847 .45265 .21403 Metetra
.662 .738 .906 r
.45265 .21403 .45635 .21847 .46281 .21635 .45913 .21165 Metetra
.655 .724 .9 r
.45913 .21165 .46281 .21635 .46929 .21439 .46562 .20939 Metetra
.643 .705 .891 r
.46562 .20939 .46929 .21439 .47578 .21257 .47212 .20729 Metetra
.631 .688 .885 r
.47212 .20729 .47578 .21257 .48228 .21078 .47864 .20538 Metetra
.622 .679 .883 r
.47864 .20538 .48228 .21078 .48881 .20891 .48517 .20361 Metetra
.62 .683 .888 r
.48517 .20361 .48881 .20891 .49536 .20689 .49172 .20188 Metetra
.623 .699 .899 r
.49172 .20188 .49536 .20689 .50192 .20475 .49829 .20009 Metetra
.63 .719 .911 r
.49829 .20009 .50192 .20475 .5085 .20265 .50487 .19818 Metetra
.635 .731 .918 r
.50487 .19818 .5085 .20265 .5151 .20084 .51148 .1962 Metetra
.629 .72 .913 r
.51148 .1962 .5151 .20084 .52171 .19955 .51811 .1943 Metetra
.609 .683 .894 r
.51811 .1943 .52171 .19955 .52835 .19889 .52475 .19271 Metetra
.579 .63 .866 r
.52475 .19271 .52835 .19889 .53501 .19874 .53141 .19162 Metetra
.548 .58 .839 r
.53141 .19162 .53501 .19874 .5417 .19881 .5381 .19109 Metetra
.526 .55 .823 r
.5381 .19109 .5417 .19881 .54841 .19867 .54482 .19099 Metetra
.519 .548 .825 r
.54482 .19099 .54841 .19867 .55515 .19797 .55156 .19101 Metetra
.529 .577 .847 r
.55156 .19101 .55515 .19797 .5619 .1966 .55833 .19077 Metetra
.556 .636 .885 r
.55833 .19077 .5619 .1966 .56867 .19472 .56512 .18999 Metetra
.591 .705 .922 r
.56512 .18999 .56867 .19472 .57545 .19274 .57192 .18859 Metetra
.619 .75 .94 r
.57192 .18859 .57545 .19274 .58226 .19109 .57874 .18674 Metetra
.627 .742 .93 r
.57874 .18674 .58226 .19109 .5891 .19007 .58557 .1848 Metetra
.611 .689 .898 r
.58557 .1848 .5891 .19007 .59598 .18961 .59243 .18312 Metetra
.585 .626 .858 r
.59243 .18312 .59598 .18961 .60289 .18934 .59933 .1819 Metetra
.566 .583 .83 r
.59933 .1819 .60289 .18934 .60982 .18866 .60625 .18104 Metetra
.565 .578 .825 r
.60625 .18104 .60982 .18866 .61674 .18702 .6132 .18019 Metetra
.59 .617 .847 r
.6132 .18019 .61674 .18702 .62365 .18412 .62016 .17886 Metetra
.643 .707 .893 r
.62016 .17886 .62365 .18412 .63052 .18004 .62711 .17662 Metetra
.711 .831 .939 r
.62711 .17662 .63052 .18004 .63738 .17521 .63404 .17329 Metetra
.758 .931 .944 r
.63404 .17329 .63738 .17521 .64424 .17023 .64095 .16901 Metetra
.775 .967 .923 r
.64095 .16901 .64424 .17023 .65112 .16563 .64785 .16415 Metetra
.785 .958 .924 r
.64785 .16415 .65112 .16563 .65804 .16169 .65474 .15924 Metetra
.779 .906 .929 r
.65474 .15924 .65804 .16169 .665 .15836 .66166 .15467 Metetra
.747 .828 .914 r
.66166 .15467 .665 .15836 .67199 .15532 .66862 .15065 Metetra
.715 .766 .893 r
.66862 .15065 .67199 .15532 .67898 .15216 .67561 .1471 Metetra
.7 .743 .884 r
.67561 .1471 .67898 .15216 .68597 .14854 .68262 .14377 Metetra
.708 .76 .893 r
.68262 .14377 .68597 .14854 .69294 .14434 .68965 .14034 Metetra
.731 .809 .913 r
.68965 .14034 .69294 .14434 .69988 .13966 .69666 .13657 Metetra
.757 .87 .93 r
.69666 .13657 .69988 .13966 .70683 .13479 .70367 .13239 Metetra
.771 .914 .936 r
.70367 .13239 .70683 .13479 .71379 .13007 .71067 .12789 Metetra
.773 .928 .936 r
.71067 .12789 .71379 .13007 .72079 .12576 .71766 .12332 Metetra
.765 .912 .939 r
.71766 .12332 .72079 .12576 .72783 .12201 .72468 .11891 Metetra
.747 .87 .937 r
.72468 .11891 .72783 .12201 .73492 .11876 .73174 .11488 Metetra
.72 .816 .925 r
.73174 .11488 .73492 .11876 .74206 .11588 .73884 .11129 Metetra
.695 .769 .909 r
.73884 .11129 .74206 .11588 .74922 .11314 .74598 .10811 Metetra
.677 .74 .898 r
.74598 .10811 .74922 .11314 .7564 .11037 .75316 .1052 Metetra
.566 .783 .98 r
.11429 .33579 .11862 .33855 .12422 .3373 .11989 .33462 Metetra
.566 .788 .983 r
.11989 .33462 .12422 .3373 .1298 .33626 .1255 .33343 Metetra
.582 .784 .975 r
.1255 .33343 .1298 .33626 .13539 .33531 .13114 .33213 Metetra
.602 .768 .959 r
.13114 .33213 .13539 .33531 .14101 .33427 .13681 .33071 Metetra
.608 .747 .943 r
.13681 .33071 .14101 .33427 .14667 .33305 .1425 .32928 Metetra
.595 .731 .939 r
.1425 .32928 .14667 .33305 .15236 .33164 .14818 .32801 Metetra
.555 .727 .955 r
.14818 .32801 .15236 .33164 .15808 .33018 .15383 .32712 Metetra
.467 .73 .983 r
.15383 .32712 .15808 .33018 .16378 .32892 .15944 .32675 Metetra
.298 .707 .975 r
.15944 .32675 .16378 .32892 .16945 .32813 .16501 .32688 Metetra
.086 .62 .862 r
.16501 .32688 .16945 .32813 .17507 .32796 .17057 .32734 Metetra
0 .562 .758 r
.17057 .32734 .17507 .32796 .18064 .32838 .17615 .32778 Metetra
.081 .635 .813 r
.17615 .32778 .18064 .32838 .18621 .32908 .18179 .32784 Metetra
.34 .78 .963 r
.18179 .32784 .18621 .32908 .19181 .32965 .18753 .32726 Metetra
.559 .81 .992 r
.18753 .32726 .19181 .32965 .1975 .32964 .19335 .32596 Metetra
.639 .755 .932 r
.19335 .32596 .1975 .32964 .20329 .32875 .19925 .32411 Metetra
.654 .709 .888 r
.19925 .32411 .20329 .32875 .20919 .32697 .20519 .32203 Metetra
.647 .693 .879 r
.20519 .32203 .20919 .32697 .21517 .32458 .21114 .32003 Metetra
.632 .707 .9 r
.21114 .32003 .21517 .32458 .22118 .32201 .21707 .31828 Metetra
.614 .746 .94 r
.21707 .31828 .22118 .32201 .22718 .31964 .223 .31673 Metetra
.609 .795 .971 r
.223 .31673 .22718 .31964 .23315 .31766 .22895 .3151 Metetra
.645 .827 .97 r
.22895 .3151 .23315 .31766 .23912 .31596 .23496 .31301 Metetra
.706 .815 .933 r
.23496 .31301 .23912 .31596 .24511 .31419 .24106 .31015 Metetra
.741 .763 .871 r
.24106 .31015 .24511 .31419 .25115 .3119 .24724 .30643 Metetra
.744 .705 .815 r
.24724 .30643 .25115 .3119 .25729 .30876 .25349 .30199 Metetra
.735 .663 .779 r
.25349 .30199 .25729 .30876 .26351 .30469 .25978 .29718 Metetra
.723 .64 .765 r
.25978 .29718 .26351 .30469 .26979 .29992 .26607 .29239 Metetra
.714 .636 .769 r
.26607 .29239 .26979 .29992 .2761 .29486 .27234 .28794 Metetra
.708 .649 .789 r
.27234 .28794 .2761 .29486 .28241 .28996 .27857 .28396 Metetra
.707 .677 .819 r
.27857 .28396 .28241 .28996 .28867 .28554 .28478 .2804 Metetra
.709 .71 .848 r
.28478 .2804 .28867 .28554 .2949 .28172 .29098 .27707 Metetra
.715 .733 .865 r
.29098 .27707 .2949 .28172 .30111 .27837 .29719 .27376 Metetra
.72 .736 .864 r
.29719 .27376 .30111 .27837 .30731 .27526 .30342 .27033 Metetra
.721 .723 .851 r
.30342 .27033 .30731 .27526 .31351 .27214 .30967 .26676 Metetra
.717 .704 .837 r
.30967 .26676 .31351 .27214 .31974 .26886 .31593 .26314 Metetra
.709 .69 .83 r
.31593 .26314 .31974 .26886 .32599 .26541 .32219 .25962 Metetra
.699 .684 .832 r
.32219 .25962 .32599 .26541 .33226 .26191 .32845 .25632 Metetra
.689 .688 .844 r
.32845 .25632 .33226 .26191 .33852 .2585 .3347 .25331 Metetra
.681 .702 .863 r
.3347 .25331 .33852 .2585 .34479 .25532 .34094 .25057 Metetra
.674 .72 .883 r
.34094 .25057 .34479 .25532 .35105 .25243 .34719 .24804 Metetra
.67 .736 .9 r
.34719 .24804 .35105 .25243 .3573 .24981 .35344 .24561 Metetra
.669 .746 .908 r
.35344 .24561 .3573 .24981 .36356 .24737 .3597 .24321 Metetra
.67 .749 .91 r
.3597 .24321 .36356 .24737 .36983 .24502 .36598 .24078 Metetra
.672 .746 .907 r
.36598 .24078 .36983 .24502 .37611 .24267 .37228 .23833 Metetra
.672 .742 .903 r
.37228 .23833 .37611 .24267 .38241 .24027 .37859 .23585 Metetra
.671 .738 .9 r
.37859 .23585 .38241 .24027 .38872 .23782 .38492 .23338 Metetra
.669 .736 .9 r
.38492 .23338 .38872 .23782 .39505 .23535 .39125 .23092 Metetra
.667 .737 .902 r
.39125 .23092 .39505 .23535 .4014 .23288 .39761 .2285 Metetra
.665 .74 .905 r
.39761 .2285 .4014 .23288 .40776 .23046 .40397 .22612 Metetra
.663 .741 .908 r
.40397 .22612 .40776 .23046 .41412 .22809 .41035 .22376 Metetra
.662 .742 .91 r
.41035 .22376 .41412 .22809 .42051 .22577 .41674 .22143 Metetra
.66 .741 .91 r
.41674 .22143 .42051 .22577 .4269 .22347 .42315 .21911 Metetra
.659 .741 .91 r
.42315 .21911 .4269 .22347 .43332 .22117 .42957 .2168 Metetra
.659 .741 .91 r
.42957 .2168 .43332 .22117 .43975 .21882 .43601 .21448 Metetra
.661 .743 .911 r
.43601 .21448 .43975 .21882 .44619 .21644 .44246 .21215 Metetra
.663 .747 .913 r
.44246 .21215 .44619 .21644 .45265 .21403 .44893 .20977 Metetra
.664 .75 .914 r
.44893 .20977 .45265 .21403 .45913 .21165 .45542 .20737 Metetra
.664 .749 .914 r
.45542 .20737 .45913 .21165 .46562 .20939 .46192 .20497 Metetra
.659 .741 .91 r
.46192 .20497 .46562 .20939 .47212 .20729 .46844 .20262 Metetra
.651 .725 .904 r
.46844 .20262 .47212 .20729 .47864 .20538 .47496 .20041 Metetra
.639 .706 .896 r
.47496 .20041 .47864 .20538 .48517 .20361 .48151 .19837 Metetra
.627 .69 .889 r
.48151 .19837 .48517 .20361 .49172 .20188 .48807 .19651 Metetra
.618 .681 .887 r
.48807 .19651 .49172 .20188 .49829 .20009 .49464 .1948 Metetra
.615 .683 .891 r
.49464 .1948 .49829 .20009 .50487 .19818 .50124 .19313 Metetra
.617 .696 .901 r
.50124 .19313 .50487 .19818 .51148 .1962 .50785 .19141 Metetra
.622 .712 .91 r
.50785 .19141 .51148 .1962 .51811 .1943 .51448 .18962 Metetra
.623 .718 .914 r
.51448 .18962 .51811 .1943 .52475 .19271 .52114 .18779 Metetra
.615 .703 .907 r
.52114 .18779 .52475 .19271 .53141 .19162 .52781 .18609 Metetra
.595 .666 .888 r
.52781 .18609 .53141 .19162 .5381 .19109 .5345 .18471 Metetra
.568 .618 .862 r
.5345 .18471 .5381 .19109 .54482 .19099 .54122 .18379 Metetra
.542 .576 .838 r
.54122 .18379 .54482 .19099 .55156 .19101 .54796 .18336 Metetra
.525 .553 .826 r
.54796 .18336 .55156 .19101 .55833 .19077 .55473 .18326 Metetra
.522 .556 .831 r
.55473 .18326 .55833 .19077 .56512 .18999 .56153 .18319 Metetra
.535 .588 .854 r
.56153 .18319 .56512 .18999 .57192 .18859 .56835 .18281 Metetra
.563 .643 .888 r
.56835 .18281 .57192 .18859 .57874 .18674 .57519 .18191 Metetra
.596 .704 .919 r
.57519 .18191 .57874 .18674 .58557 .1848 .58205 .18043 Metetra
.621 .74 .932 r
.58205 .18043 .58557 .1848 .59243 .18312 .58891 .17856 Metetra
.628 .733 .923 r
.58891 .17856 .59243 .18312 .59933 .1819 .5958 .17658 Metetra
.617 .692 .897 r
.5958 .17658 .59933 .1819 .60625 .18104 .60271 .17478 Metetra
.599 .643 .866 r
.60271 .17478 .60625 .18104 .6132 .18019 .60965 .17329 Metetra
.588 .614 .846 r
.60965 .17329 .6132 .18019 .62016 .17886 .61661 .17199 Metetra
.594 .619 .846 r
.61661 .17199 .62016 .17886 .62711 .17662 .6236 .17056 Metetra
.623 .664 .869 r
.6236 .17056 .62711 .17662 .63404 .17329 .63059 .16862 Metetra
.674 .75 .908 r
.63059 .16862 .63404 .17329 .64095 .16901 .63757 .16585 Metetra
.731 .854 .939 r
.63757 .16585 .64095 .16901 .64785 .16415 .64453 .16216 Metetra
.767 .93 .939 r
.64453 .16216 .64785 .16415 .65474 .15924 .65146 .1577 Metetra
.781 .956 .927 r
.65146 .1577 .65474 .15924 .66166 .15467 .65839 .15285 Metetra
.787 .943 .927 r
.65839 .15285 .66166 .15467 .66862 .15065 .66533 .14799 Metetra
.776 .896 .928 r
.66533 .14799 .66862 .15065 .67561 .1471 .67229 .14345 Metetra
.75 .833 .916 r
.67229 .14345 .67561 .1471 .68262 .14377 .67928 .13937 Metetra
.724 .785 .901 r
.67928 .13937 .68262 .14377 .68965 .14034 .6863 .13566 Metetra
.713 .768 .896 r
.6863 .13566 .68965 .14034 .69666 .13657 .69335 .13213 Metetra
.719 .783 .903 r
.69335 .13213 .69666 .13657 .70367 .13239 .7004 .12852 Metetra
.735 .82 .917 r
.7004 .12852 .70367 .13239 .71067 .12789 .70746 .12467 Metetra
.752 .863 .93 r
.70746 .12467 .71067 .12789 .71766 .12332 .71451 .12055 Metetra
.761 .893 .937 r
.71451 .12055 .71766 .12332 .72468 .11891 .72155 .11624 Metetra
.76 .9 .939 r
.72155 .11624 .72468 .11891 .73174 .11488 .72861 .11193 Metetra
.751 .882 .939 r
.72861 .11193 .73174 .11488 .73884 .11129 .73569 .10781 Metetra
.733 .845 .933 r
.73569 .10781 .73884 .11129 .74598 .10811 .7428 .104 Metetra
.71 .803 .922 r
.7428 .104 .74598 .10811 .75316 .1052 .74996 .10055 Metetra
.597 .777 .966 r
.10997 .33278 .11429 .33579 .11989 .33462 .1156 .33139 Metetra
.606 .766 .956 r
.1156 .33139 .11989 .33462 .1255 .33343 .12125 .32994 Metetra
.609 .752 .946 r
.12125 .32994 .1255 .33343 .13114 .33213 .12692 .32849 Metetra
.597 .74 .944 r
.12692 .32849 .13114 .33213 .13681 .33071 .13258 .32718 Metetra
.565 .736 .956 r
.13258 .32718 .13681 .33071 .1425 .32928 .13822 .32618 Metetra
.498 .739 .981 r
.13822 .32618 .1425 .32928 .14818 .32801 .14383 .3256 Metetra
.376 .732 .99 r
.14383 .3256 .14818 .32801 .15383 .32712 .1494 .32547 Metetra
.211 .686 .937 r
.1494 .32547 .15383 .32712 .15944 .32675 .15495 .32567 Metetra
.101 .638 .859 r
.15495 .32567 .15944 .32675 .16501 .32688 .16051 .32595 Metetra
.134 .665 .866 r
.16051 .32595 .16501 .32688 .17057 .32734 .16612 .32602 Metetra
.305 .758 .956 r
.16612 .32602 .17057 .32734 .17615 .32778 .1718 .32563 Metetra
.494 .802 .999 r
.1718 .32563 .17615 .32778 .18179 .32784 .17756 .32469 Metetra
.593 .773 .966 r
.17756 .32469 .18179 .32784 .18753 .32726 .18339 .32329 Metetra
.624 .735 .926 r
.18339 .32329 .18753 .32726 .19335 .32596 .18926 .32165 Metetra
.625 .717 .913 r
.18926 .32165 .19335 .32596 .19925 .32411 .19514 .32001 Metetra
.612 .724 .925 r
.19514 .32001 .19925 .32411 .20519 .32203 .20103 .31851 Metetra
.595 .753 .954 r
.20103 .31851 .20519 .32203 .21114 .32003 .20691 .31715 Metetra
.59 .791 .976 r
.20691 .31715 .21114 .32003 .21707 .31828 .21283 .31569 Metetra
.623 .82 .976 r
.21283 .31569 .21707 .31828 .223 .31673 .2188 .31383 Metetra
.684 .815 .945 r
.2188 .31383 .223 .31673 .22895 .3151 .22484 .3113 Metetra
.727 .772 .889 r
.22484 .3113 .22895 .3151 .23496 .31301 .23098 .30795 Metetra
.738 .719 .833 r
.23098 .30795 .23496 .31301 .24106 .31015 .23719 .30389 Metetra
.734 .677 .795 r
.23719 .30389 .24106 .31015 .24724 .30643 .24345 .29938 Metetra
.725 .652 .776 r
.24345 .29938 .24724 .30643 .25349 .30199 .24972 .29476 Metetra
.717 .645 .776 r
.24972 .29476 .25349 .30199 .25978 .29718 .25598 .29035 Metetra
.712 .653 .789 r
.25598 .29035 .25978 .29718 .26607 .29239 .26222 .28628 Metetra
.711 .675 .813 r
.26222 .28628 .26607 .29239 .27234 .28794 .26843 .28255 Metetra
.714 .701 .837 r
.26843 .28255 .27234 .28794 .27857 .28396 .27464 .27903 Metetra
.718 .721 .852 r
.27464 .27903 .27857 .28396 .28478 .2804 .28085 .27554 Metetra
.723 .726 .852 r
.28085 .27554 .28478 .2804 .29098 .27707 .28708 .27195 Metetra
.724 .716 .842 r
.28708 .27195 .29098 .27707 .29719 .27376 .29332 .26826 Metetra
.72 .7 .831 r
.29332 .26826 .29719 .27376 .30342 .27033 .29958 .26452 Metetra
.712 .687 .825 r
.29958 .26452 .30342 .27033 .30967 .26676 .30584 .26087 Metetra
.703 .682 .827 r
.30584 .26087 .30967 .26676 .31593 .26314 .31209 .25744 Metetra
.694 .685 .837 r
.31209 .25744 .31593 .26314 .32219 .25962 .31834 .25428 Metetra
.686 .697 .855 r
.31834 .25428 .32219 .25962 .32845 .25632 .32458 .25141 Metetra
.679 .714 .874 r
.32458 .25141 .32845 .25632 .3347 .25331 .33081 .24875 Metetra
.675 .729 .891 r
.33081 .24875 .3347 .25331 .34094 .25057 .33705 .24622 Metetra
.673 .74 .9 r
.33705 .24622 .34094 .25057 .34719 .24804 .3433 .24374 Metetra
.673 .743 .903 r
.3433 .24374 .34719 .24804 .35344 .24561 .34957 .24125 Metetra
.674 .741 .901 r
.34957 .24125 .35344 .24561 .3597 .24321 .35585 .23875 Metetra
.673 .736 .897 r
.35585 .23875 .3597 .24321 .36598 .24078 .36214 .23623 Metetra
.672 .731 .895 r
.36214 .23623 .36598 .24078 .37228 .23833 .36845 .23374 Metetra
.669 .729 .894 r
.36845 .23374 .37228 .23833 .37859 .23585 .37476 .23127 Metetra
.667 .73 .897 r
.37476 .23127 .37859 .23585 .38492 .23338 .3811 .22885 Metetra
.665 .732 .9 r
.3811 .22885 .38492 .23338 .39125 .23092 .38744 .22647 Metetra
.664 .735 .903 r
.38744 .22647 .39125 .23092 .39761 .2285 .3938 .2241 Metetra
.663 .739 .906 r
.3938 .2241 .39761 .2285 .40397 .22612 .40017 .22174 Metetra
.663 .74 .907 r
.40017 .22174 .40397 .22612 .41035 .22376 .40656 .21937 Metetra
.664 .74 .907 r
.40656 .21937 .41035 .22376 .41674 .22143 .41296 .21699 Metetra
.663 .738 .906 r
.41296 .21699 .41674 .22143 .42315 .21911 .41938 .21461 Metetra
.662 .735 .904 r
.41938 .21461 .42315 .21911 .42957 .2168 .42581 .21224 Metetra
.66 .732 .903 r
.42581 .21224 .42957 .2168 .43601 .21448 .43226 .20989 Metetra
.659 .73 .902 r
.43226 .20989 .43601 .21448 .44246 .21215 .43872 .20755 Metetra
.658 .731 .903 r
.43872 .20755 .44246 .21215 .44893 .20977 .4452 .20522 Metetra
.659 .734 .905 r
.4452 .20522 .44893 .20977 .45542 .20737 .45169 .20289 Metetra
.66 .738 .908 r
.45169 .20289 .45542 .20737 .46192 .20497 .4582 .20053 Metetra
.661 .741 .91 r
.4582 .20053 .46192 .20497 .46844 .20262 .46473 .19815 Metetra
.659 .74 .909 r
.46473 .19815 .46844 .20262 .47496 .20041 .47127 .19579 Metetra
.654 .731 .906 r
.47127 .19579 .47496 .20041 .48151 .19837 .47783 .1935 Metetra
.645 .716 .899 r
.47783 .1935 .48151 .19837 .48807 .19651 .4844 .19135 Metetra
.632 .697 .892 r
.4844 .19135 .48807 .19651 .49464 .1948 .49099 .18939 Metetra
.62 .681 .886 r
.49099 .18939 .49464 .1948 .50124 .19313 .49759 .18761 Metetra
.612 .673 .884 r
.49759 .18761 .50124 .19313 .50785 .19141 .50421 .18597 Metetra
.608 .676 .889 r
.50421 .18597 .50785 .19141 .51448 .18962 .51085 .18439 Metetra
.609 .686 .897 r
.51085 .18439 .51448 .18962 .52114 .18779 .51751 .18277 Metetra
.612 .698 .905 r
.51751 .18277 .52114 .18779 .52781 .18609 .52419 .18111 Metetra
.611 .7 .907 r
.52419 .18111 .52781 .18609 .5345 .18471 .53089 .17946 Metetra
.601 .683 .899 r
.53089 .17946 .5345 .18471 .54122 .18379 .53761 .17796 Metetra
.582 .649 .881 r
.53761 .17796 .54122 .18379 .54796 .18336 .54435 .17677 Metetra
.558 .607 .858 r
.54435 .17677 .54796 .18336 .55473 .18326 .55112 .176 Metetra
.537 .573 .839 r
.55112 .176 .55473 .18326 .56153 .18319 .55792 .17563 Metetra
.526 .558 .831 r
.55792 .17563 .56153 .18319 .56835 .18281 .56475 .17548 Metetra
.527 .566 .838 r
.56475 .17548 .56835 .18281 .57519 .18191 .5716 .17527 Metetra
.544 .6 .86 r
.5716 .17527 .57519 .18191 .58205 .18043 .57848 .17473 Metetra
.572 .653 .891 r
.57848 .17473 .58205 .18043 .58891 .17856 .58537 .17367 Metetra
.603 .707 .917 r
.58537 .17367 .58891 .17856 .5958 .17658 .59228 .17207 Metetra
.626 .737 .927 r
.59228 .17207 .5958 .17658 .60271 .17478 .59919 .1701 Metetra
.634 .732 .919 r
.59919 .1701 .60271 .17478 .60965 .17329 .60612 .16801 Metetra
.627 .7 .897 r
.60612 .16801 .60965 .17329 .61661 .17199 .61308 .16602 Metetra
.616 .665 .875 r
.61308 .16602 .61661 .17199 .6236 .17056 .62006 .16421 Metetra
.612 .648 .862 r
.62006 .16421 .6236 .17056 .63059 .16862 .62706 .16245 Metetra
.624 .661 .866 r
.62706 .16245 .63059 .16862 .63757 .16585 .63408 .16047 Metetra
.655 .709 .887 r
.63408 .16047 .63757 .16585 .64453 .16216 .6411 .15797 Metetra
.701 .787 .918 r
.6411 .15797 .64453 .16216 .65146 .1577 .6481 .15473 Metetra
.747 .871 .937 r
.6481 .15473 .65146 .1577 .65839 .15285 .65509 .15074 Metetra
.774 .927 .936 r
.65509 .15074 .65839 .15285 .66533 .14799 .66206 .14617 Metetra
.784 .945 .928 r
.66206 .14617 .66533 .14799 .67229 .14345 .66903 .14132 Metetra
.785 .929 .929 r
.66903 .14132 .67229 .14345 .67928 .13937 .676 .13653 Metetra
.773 .887 .927 r
.676 .13653 .67928 .13937 .6863 .13566 .683 .13203 Metetra
.75 .837 .917 r
.683 .13203 .6863 .13566 .69335 .13213 .69003 .12791 Metetra
.73 .8 .907 r
.69003 .12791 .69335 .13213 .7004 .12852 .69709 .1241 Metetra
.721 .786 .904 r
.69709 .1241 .7004 .12852 .70746 .12467 .70417 .12043 Metetra
.724 .798 .91 r
.70417 .12043 .70746 .12467 .71451 .12055 .71126 .11672 Metetra
.735 .825 .92 r
.71126 .11672 .71451 .12055 .72155 .11624 .71835 .11286 Metetra
.745 .854 .93 r
.71835 .11286 .72155 .11624 .72861 .11193 .72545 .10882 Metetra
.75 .873 .936 r
.72545 .10882 .72861 .11193 .73569 .10781 .73255 .1047 Metetra
.747 .873 .938 r
.73255 .1047 .73569 .10781 .7428 .104 .73966 .10063 Metetra
.737 .855 .936 r
.73966 .10063 .7428 .104 .74996 .10055 .7468 .09673 Metetra
.613 .754 .945 r
.1057 .32931 .10997 .33278 .1156 .33139 .11134 .32782 Metetra
.602 .745 .945 r
.11134 .32782 .1156 .33139 .12125 .32994 .11699 .32645 Metetra
.576 .742 .955 r
.11699 .32645 .12125 .32994 .12692 .32849 .12262 .32533 Metetra
.525 .746 .976 r
.12262 .32533 .12692 .32849 .13258 .32718 .12822 .32456 Metetra
.437 .747 .993 r
.12822 .32456 .13258 .32718 .13822 .32618 .13379 .32419 Metetra
.315 .728 .977 r
.13379 .32419 .13822 .32618 .14383 .3256 .13934 .32413 Metetra
.212 .696 .93 r
.13934 .32413 .14383 .3256 .1494 .32547 .14489 .32422 Metetra
.201 .698 .916 r
.14489 .32422 .1494 .32547 .15495 .32567 .15047 .32422 Metetra
.299 .748 .96 r
.15047 .32422 .15495 .32567 .16051 .32595 .15611 .32393 Metetra
.441 .788 .998 r
.15611 .32393 .16051 .32595 .16612 .32602 .16181 .32325 Metetra
.542 .781 .986 r
.16181 .32325 .16612 .32602 .1718 .32563 .16757 .3222 Metetra
.586 .754 .958 r
.16757 .3222 .1718 .32563 .17756 .32469 .17337 .32092 Metetra
.594 .737 .943 r
.17337 .32092 .17756 .32469 .18339 .32329 .1792 .31961 Metetra
.585 .739 .949 r
.1792 .31961 .18339 .32329 .18926 .32165 .18503 .31837 Metetra
.569 .759 .968 r
.18503 .31837 .18926 .32165 .19514 .32001 .19087 .31721 Metetra
.565 .788 .983 r
.19087 .31721 .19514 .32001 .20103 .31851 .19674 .31595 Metetra
.596 .814 .983 r
.19674 .31595 .20103 .31851 .20691 .31715 .20266 .31435 Metetra
.658 .815 .959 r
.20266 .31435 .20691 .31715 .21283 .31569 .20866 .31214 Metetra
.709 .782 .909 r
.20866 .31214 .21283 .31569 .2188 .31383 .21474 .3092 Metetra
.729 .734 .854 r
.21474 .3092 .2188 .31383 .22484 .3113 .2209 .30555 Metetra
.731 .692 .813 r
.2209 .30555 .22484 .3113 .23098 .30795 .22712 .30139 Metetra
.725 .665 .791 r
.22712 .30139 .23098 .30795 .23719 .30389 .23337 .29702 Metetra
.719 .655 .785 r
.23337 .29702 .23719 .30389 .24345 .29938 .23961 .29271 Metetra
.715 .659 .793 r
.23961 .29271 .24345 .29938 .24972 .29476 .24584 .28862 Metetra
.714 .675 .81 r
.24584 .28862 .24972 .29476 .25598 .29035 .25206 .28479 Metetra
.717 .696 .829 r
.25206 .28479 .25598 .29035 .26222 .28628 .25827 .28111 Metetra
.721 .712 .841 r
.25827 .28111 .26222 .28628 .26843 .28255 .26449 .27747 Metetra
.725 .717 .843 r
.26449 .27747 .26843 .28255 .27464 .27903 .27072 .27375 Metetra
.726 .71 .835 r
.27072 .27375 .27464 .27903 .28085 .27554 .27696 .26993 Metetra
.723 .697 .826 r
.27696 .26993 .28085 .27554 .28708 .27195 .28322 .26608 Metetra
.716 .686 .82 r
.28322 .26608 .28708 .27195 .29332 .26826 .28948 .2623 Metetra
.708 .681 .822 r
.28948 .2623 .29332 .26826 .29958 .26452 .29573 .25872 Metetra
.699 .684 .832 r
.29573 .25872 .29958 .26452 .30584 .26087 .30197 .25542 Metetra
.691 .694 .848 r
.30197 .25542 .30584 .26087 .31209 .25744 .3082 .25239 Metetra
.685 .71 .867 r
.3082 .25239 .31209 .25744 .31834 .25428 .31443 .2496 Metetra
.68 .725 .883 r
.31443 .2496 .31834 .25428 .32458 .25141 .32066 .24695 Metetra
.678 .736 .894 r
.32066 .24695 .32458 .25141 .33081 .24875 .3269 .24438 Metetra
.677 .74 .899 r
.3269 .24438 .33081 .24875 .33705 .24622 .33315 .24183 Metetra
.677 .74 .898 r
.33315 .24183 .33705 .24622 .3433 .24374 .33941 .23928 Metetra
.676 .737 .896 r
.33941 .23928 .3433 .24374 .34957 .24125 .34569 .23673 Metetra
.674 .733 .895 r
.34569 .23673 .34957 .24125 .35585 .23875 .35198 .2342 Metetra
.671 .732 .896 r
.35198 .2342 .35585 .23875 .36214 .23623 .35828 .23171 Metetra
.668 .733 .898 r
.35828 .23171 .36214 .23623 .36845 .23374 .36459 .22927 Metetra
.666 .735 .902 r
.36459 .22927 .36845 .23374 .37476 .23127 .37091 .22687 Metetra
.664 .738 .905 r
.37091 .22687 .37476 .23127 .3811 .22885 .37725 .2245 Metetra
.663 .741 .908 r
.37725 .2245 .3811 .22885 .38744 .22647 .3836 .22214 Metetra
.663 .743 .909 r
.3836 .22214 .38744 .22647 .3938 .2241 .38997 .21978 Metetra
.663 .744 .91 r
.38997 .21978 .3938 .2241 .40017 .22174 .39635 .2174 Metetra
.664 .744 .91 r
.39635 .2174 .40017 .22174 .40656 .21937 .40275 .21502 Metetra
.665 .744 .909 r
.40275 .21502 .40656 .21937 .41296 .21699 .40916 .21261 Metetra
.665 .743 .909 r
.40916 .21261 .41296 .21699 .41938 .21461 .41559 .2102 Metetra
.664 .742 .908 r
.41559 .2102 .41938 .21461 .42581 .21224 .42203 .20779 Metetra
.663 .74 .907 r
.42203 .20779 .42581 .21224 .43226 .20989 .42849 .20539 Metetra
.662 .738 .906 r
.42849 .20539 .43226 .20989 .43872 .20755 .43497 .20301 Metetra
.66 .735 .905 r
.43497 .20301 .43872 .20755 .4452 .20522 .44145 .20065 Metetra
.658 .733 .905 r
.44145 .20065 .4452 .20522 .45169 .20289 .44796 .19831 Metetra
.657 .734 .906 r
.44796 .19831 .45169 .20289 .4582 .20053 .45448 .19598 Metetra
.657 .736 .908 r
.45448 .19598 .4582 .20053 .46473 .19815 .46101 .19365 Metetra
.658 .739 .909 r
.46101 .19365 .46473 .19815 .47127 .19579 .46756 .19129 Metetra
.658 .74 .91 r
.46756 .19129 .47127 .19579 .47783 .1935 .47413 .18894 Metetra
.655 .736 .909 r
.47413 .18894 .47783 .1935 .4844 .19135 .48071 .18662 Metetra
.649 .725 .904 r
.48071 .18662 .4844 .19135 .49099 .18939 .48731 .18439 Metetra
.638 .709 .898 r
.48731 .18439 .49099 .18939 .49759 .18761 .49393 .18232 Metetra
.626 .69 .89 r
.49393 .18232 .49759 .18761 .50421 .18597 .50056 .18044 Metetra
.614 .675 .884 r
.50056 .18044 .50421 .18597 .51085 .18439 .5072 .17875 Metetra
.605 .667 .883 r
.5072 .17875 .51085 .18439 .51751 .18277 .51387 .1772 Metetra
.601 .668 .887 r
.51387 .1772 .51751 .18277 .52419 .18111 .52056 .1757 Metetra
.601 .676 .894 r
.52056 .1757 .52419 .18111 .53089 .17946 .52726 .1742 Metetra
.601 .684 .9 r
.52726 .1742 .53089 .17946 .53761 .17796 .53399 .17268 Metetra
.598 .682 .9 r
.53399 .17268 .53761 .17796 .54435 .17677 .54074 .1712 Metetra
.588 .665 .892 r
.54074 .1712 .54435 .17677 .55112 .176 .54752 .16989 Metetra
.571 .634 .875 r
.54752 .16989 .55112 .176 .55792 .17563 .55431 .16887 Metetra
.551 .599 .855 r
.55431 .16887 .55792 .17563 .56475 .17548 .56114 .16821 Metetra
.536 .573 .84 r
.56114 .16821 .56475 .17548 .5716 .17527 .56799 .16784 Metetra
.529 .565 .836 r
.56799 .16784 .5716 .17527 .57848 .17473 .57488 .1676 Metetra
.535 .579 .845 r
.57488 .1676 .57848 .17473 .58537 .17367 .58179 .16722 Metetra
.554 .615 .867 r
.58179 .16722 .58537 .17367 .59228 .17207 .58871 .16646 Metetra
.583 .665 .895 r
.58871 .16646 .59228 .17207 .59919 .1701 .59566 .1652 Metetra
.613 .713 .916 r
.59566 .1652 .59919 .1701 .60612 .16801 .60261 .16343 Metetra
.635 .739 .924 r
.60261 .16343 .60612 .16801 .61308 .16602 .60957 .16131 Metetra
.643 .736 .916 r
.60957 .16131 .61308 .16602 .62006 .16421 .61655 .15905 Metetra
.641 .714 .9 r
.61655 .15905 .62006 .16421 .62706 .16245 .62355 .15682 Metetra
.636 .691 .884 r
.62355 .15682 .62706 .16245 .63408 .16047 .63057 .15465 Metetra
.638 .684 .877 r
.63057 .15465 .63408 .16047 .6411 .15797 .6376 .15242 Metetra
.653 .703 .883 r
.6376 .15242 .6411 .15797 .6481 .15473 .64465 .14992 Metetra
.684 .751 .902 r
.64465 .14992 .6481 .15473 .65509 .15074 .65169 .14693 Metetra
.723 .818 .924 r
.65169 .14693 .65509 .15074 .66206 .14617 .65872 .14331 Metetra
.758 .883 .935 r
.65872 .14331 .66206 .14617 .66903 .14132 .66574 .13908 Metetra
.778 .923 .933 r
.66574 .13908 .66903 .14132 .676 .13653 .67274 .13443 Metetra
.785 .933 .929 r
.67274 .13443 .676 .13653 .683 .13203 .67975 .12961 Metetra
.782 .916 .929 r
.67975 .12961 .683 .13203 .69003 .12791 .68677 .12489 Metetra
.769 .879 .927 r
.68677 .12489 .69003 .12791 .69709 .1241 .69381 .12044 Metetra
.749 .838 .919 r
.69381 .12044 .69709 .1241 .70417 .12043 .70088 .11632 Metetra
.733 .809 .911 r
.70088 .11632 .70417 .12043 .71126 .11672 .70797 .11245 Metetra
.725 .799 .91 r
.70797 .11245 .71126 .11672 .71835 .11286 .71509 .10871 Metetra
.726 .806 .914 r
.71509 .10871 .71835 .11286 .72545 .10882 .72222 .10496 Metetra
.732 .825 .922 r
.72222 .10496 .72545 .10882 .73255 .1047 .72936 .10112 Metetra
.738 .844 .93 r
.72936 .10112 .73255 .1047 .73966 .10063 .7365 .0972 Metetra
.739 .854 .934 r
.7365 .0972 .73966 .10063 .7468 .09673 .74366 .09325 Metetra
.588 .747 .953 r
.1014 .32583 .1057 .32931 .11134 .32782 .10702 .32459 Metetra
.55 .75 .97 r
.10702 .32459 .11134 .32782 .11699 .32645 .11261 .32364 Metetra
.486 .755 .989 r
.11261 .32364 .11699 .32645 .12262 .32533 .11818 .32303 Metetra
.397 .75 .993 r
.11818 .32303 .12262 .32533 .12822 .32456 .12373 .32273 Metetra
.31 .734 .973 r
.12373 .32273 .12822 .32456 .13379 .32419 .12928 .32261 Metetra
.274 .728 .956 r
.12928 .32261 .13379 .32419 .13934 .32413 .13484 .3225 Metetra
.317 .749 .97 r
.13484 .3225 .13934 .32413 .14489 .32422 .14044 .32223 Metetra
.41 .776 .994 r
.14044 .32223 .14489 .32422 .15047 .32422 .14609 .3217 Metetra
.495 .779 .995 r
.14609 .3217 .15047 .32422 .15611 .32393 .1518 .3209 Metetra
.543 .764 .979 r
.1518 .3209 .15611 .32393 .16181 .32325 .15754 .31992 Metetra
.558 .751 .968 r
.15754 .31992 .16181 .32325 .16757 .3222 .16331 .31888 Metetra
.552 .75 .969 r
.16331 .31888 .16757 .3222 .17337 .32092 .16909 .31788 Metetra
.539 .763 .98 r
.16909 .31788 .17337 .32092 .1792 .31961 .17488 .31692 Metetra
.535 .785 .99 r
.17488 .31692 .1792 .31961 .18503 .31837 .1807 .31587 Metetra
.564 .808 .99 r
.1807 .31587 .18503 .31837 .19087 .31721 .18657 .31453 Metetra
.626 .815 .973 r
.18657 .31453 .19087 .31721 .19674 .31595 .19251 .31266 Metetra
.685 .792 .931 r
.19251 .31266 .19674 .31595 .20266 .31435 .19853 .31013 Metetra
.716 .749 .878 r
.19853 .31013 .20266 .31435 .20866 .31214 .20464 .30691 Metetra
.725 .708 .835 r
.20464 .30691 .20866 .31214 .21474 .3092 .21081 .30316 Metetra
.723 .68 .808 r
.21081 .30316 .21474 .3092 .2209 .30555 .21702 .29909 Metetra
.72 .667 .797 r
.21702 .29909 .2209 .30555 .22712 .30139 .22324 .29496 Metetra
.717 .667 .799 r
.22324 .29496 .22712 .30139 .23337 .29702 .22946 .29093 Metetra
.717 .677 .811 r
.22946 .29093 .23337 .29702 .23961 .29271 .23567 .28705 Metetra
.719 .693 .824 r
.23567 .28705 .23961 .29271 .24584 .28862 .24188 .28328 Metetra
.723 .706 .834 r
.24188 .28328 .24584 .28862 .25206 .28479 .2481 .27953 Metetra
.727 .711 .835 r
.2481 .27953 .25206 .28479 .25827 .28111 .25433 .27569 Metetra
.728 .705 .829 r
.25433 .27569 .25827 .28111 .26449 .27747 .26058 .27177 Metetra
.725 .695 .821 r
.26058 .27177 .26449 .27747 .27072 .27375 .26683 .2678 Metetra
.719 .685 .816 r
.26683 .2678 .27072 .27375 .27696 .26993 .27309 .2639 Metetra
.712 .68 .817 r
.27309 .2639 .27696 .26993 .28322 .26608 .27935 .26017 Metetra
.704 .682 .826 r
.27935 .26017 .28322 .26608 .28948 .2623 .28559 .2567 Metetra
.697 .691 .84 r
.28559 .2567 .28948 .2623 .29573 .25872 .29182 .25351 Metetra
.691 .704 .858 r
.29182 .25351 .29573 .25872 .30197 .25542 .29804 .25056 Metetra
.686 .719 .874 r
.29804 .25056 .30197 .25542 .3082 .25239 .30426 .24778 Metetra
.683 .73 .886 r
.30426 .24778 .3082 .25239 .31443 .2496 .31049 .2451 Metetra
.681 .735 .892 r
.31049 .2451 .31443 .2496 .32066 .24695 .31673 .24246 Metetra
.68 .736 .893 r
.31673 .24246 .32066 .24695 .3269 .24438 .32298 .23985 Metetra
.678 .733 .892 r
.32298 .23985 .3269 .24438 .33315 .24183 .32924 .23725 Metetra
.676 .731 .892 r
.32924 .23725 .33315 .24183 .33941 .23928 .33551 .23468 Metetra
.673 .73 .893 r
.33551 .23468 .33941 .23928 .34569 .23673 .34179 .23216 Metetra
.67 .731 .896 r
.34179 .23216 .34569 .23673 .35198 .2342 .34809 .2297 Metetra
.667 .734 .9 r
.34809 .2297 .35198 .2342 .35828 .23171 .35439 .22727 Metetra
.665 .737 .903 r
.35439 .22727 .35828 .23171 .36459 .22927 .36071 .22488 Metetra
.664 .74 .906 r
.36071 .22488 .36459 .22927 .37091 .22687 .36704 .22251 Metetra
.664 .741 .908 r
.36704 .22251 .37091 .22687 .37725 .2245 .37339 .22014 Metetra
.664 .742 .908 r
.37339 .22014 .37725 .2245 .3836 .22214 .37975 .21776 Metetra
.664 .742 .908 r
.37975 .21776 .3836 .22214 .38997 .21978 .38612 .21538 Metetra
.664 .741 .907 r
.38612 .21538 .38997 .21978 .39635 .2174 .39252 .21298 Metetra
.664 .74 .907 r
.39252 .21298 .39635 .2174 .40275 .21502 .39892 .21059 Metetra
.664 .74 .907 r
.39892 .21059 .40275 .21502 .40916 .21261 .40535 .20818 Metetra
.664 .741 .907 r
.40535 .20818 .40916 .21261 .41559 .2102 .41178 .20577 Metetra
.664 .742 .908 r
.41178 .20577 .41559 .2102 .42203 .20779 .41824 .20336 Metetra
.664 .742 .908 r
.41824 .20336 .42203 .20779 .42849 .20539 .42471 .20094 Metetra
.663 .741 .908 r
.42471 .20094 .42849 .20539 .43497 .20301 .43119 .19852 Metetra
.662 .74 .908 r
.43119 .19852 .43497 .20301 .44145 .20065 .43769 .19611 Metetra
.661 .737 .907 r
.43769 .19611 .44145 .20065 .44796 .19831 .4442 .19372 Metetra
.659 .734 .906 r
.4442 .19372 .44796 .19831 .45448 .19598 .45073 .19136 Metetra
.657 .733 .905 r
.45073 .19136 .45448 .19598 .46101 .19365 .45728 .18902 Metetra
.656 .733 .906 r
.45728 .18902 .46101 .19365 .46756 .19129 .46384 .18669 Metetra
.656 .734 .907 r
.46384 .18669 .46756 .19129 .47413 .18894 .47041 .18436 Metetra
.655 .736 .909 r
.47041 .18436 .47413 .18894 .48071 .18662 .47701 .18202 Metetra
.654 .735 .909 r
.47701 .18202 .48071 .18662 .48731 .18439 .48362 .17971 Metetra
.65 .73 .907 r
.48362 .17971 .48731 .18439 .49393 .18232 .49024 .17744 Metetra
.642 .718 .903 r
.49024 .17744 .49393 .18232 .50056 .18044 .49688 .1753 Metetra
.631 .701 .896 r
.49688 .1753 .50056 .18044 .5072 .17875 .50354 .17332 Metetra
.618 .683 .889 r
.50354 .17332 .5072 .17875 .51387 .1772 .51022 .17154 Metetra
.606 .668 .883 r
.51022 .17154 .51387 .1772 .52056 .1757 .51691 .16995 Metetra
.598 .66 .882 r
.51691 .16995 .52056 .1757 .52726 .1742 .52363 .16849 Metetra
.593 .661 .885 r
.52363 .16849 .52726 .1742 .53399 .17268 .53036 .1671 Metetra
.592 .666 .891 r
.53036 .1671 .53399 .17268 .54074 .1712 .53712 .16572 Metetra
.591 .671 .895 r
.53712 .16572 .54074 .1712 .54752 .16989 .5439 .16434 Metetra
.587 .666 .894 r
.5439 .16434 .54752 .16989 .55431 .16887 .5507 .16303 Metetra
.577 .649 .885 r
.5507 .16303 .55431 .16887 .56114 .16821 .55753 .16188 Metetra
.563 .623 .87 r
.55753 .16188 .56114 .16821 .56799 .16784 .56438 .16098 Metetra
.547 .595 .854 r
.56438 .16098 .56799 .16784 .57488 .1676 .57126 .16037 Metetra
.537 .577 .843 r
.57126 .16037 .57488 .1676 .58179 .16722 .57817 .15995 Metetra
.536 .576 .842 r
.57817 .15995 .58179 .16722 .58871 .16646 .58511 .15956 Metetra
.546 .594 .854 r
.58511 .15956 .58871 .16646 .59566 .1652 .59207 .15896 Metetra
.568 .632 .875 r
.59207 .15896 .59566 .1652 .60261 .16343 .59905 .15796 Metetra
.597 .679 .899 r
.59905 .15796 .60261 .16343 .60957 .16131 .60604 .15645 Metetra
.625 .722 .916 r
.60604 .15645 .60957 .16131 .61655 .15905 .61304 .15446 Metetra
.646 .746 .922 r
.61304 .15446 .61655 .15905 .62355 .15682 .62005 .15215 Metetra
.656 .746 .916 r
.62005 .15215 .62355 .15682 .63057 .15465 .62707 .14967 Metetra
.657 .731 .904 r
.62707 .14967 .63057 .15465 .6376 .15242 .63411 .14715 Metetra
.657 .718 .893 r
.63411 .14715 .6376 .15242 .64465 .14992 .64116 .1446 Metetra
.663 .719 .89 r
.64116 .1446 .64465 .14992 .65169 .14693 .64823 .14193 Metetra
.68 .742 .897 r
.64823 .14193 .65169 .14693 .65872 .14331 .6553 .13897 Metetra
.708 .786 .912 r
.6553 .13897 .65872 .14331 .66574 .13908 .66237 .13555 Metetra
.74 .841 .927 r
.66237 .13555 .66574 .13908 .67274 .13443 .66943 .13162 Metetra
.765 .89 .933 r
.66943 .13162 .67274 .13443 .67975 .12961 .67648 .12723 Metetra
.779 .918 .931 r
.67648 .12723 .67975 .12961 .68677 .12489 .68352 .12254 Metetra
.783 .921 .93 r
.68352 .12254 .68677 .12489 .69381 .12044 .69056 .11777 Metetra
.777 .903 .929 r
.69056 .11777 .69381 .12044 .70088 .11632 .69762 .11313 Metetra
.764 .871 .926 r
.69762 .11313 .70088 .11632 .70797 .11245 .7047 .10875 Metetra
.747 .838 .92 r
.7047 .10875 .70797 .11245 .71509 .10871 .71181 .10464 Metetra
.733 .814 .915 r
.71181 .10464 .71509 .10871 .72222 .10496 .71895 .10076 Metetra
.726 .805 .914 r
.71895 .10076 .72222 .10496 .72936 .10112 .72611 .09699 Metetra
.725 .809 .917 r
.72611 .09699 .72936 .10112 .7365 .0972 .73329 .09325 Metetra
.727 .821 .923 r
.73329 .09325 .7365 .0972 .74366 .09325 .74047 .08947 Metetra
.525 .758 .982 r
.09701 .32286 .1014 .32583 .10702 .32459 .10258 .32203 Metetra
.46 .761 .995 r
.10258 .32203 .10702 .32459 .11261 .32364 .10813 .32149 Metetra
.39 .756 .992 r
.10813 .32149 .11261 .32364 .11818 .32303 .11367 .32115 Metetra
.345 .75 .982 r
.11367 .32115 .11818 .32303 .12373 .32273 .11922 .32089 Metetra
.351 .756 .983 r
.11922 .32089 .12373 .32273 .12928 .32261 .1248 .32057 Metetra
.401 .769 .993 r
.1248 .32057 .12928 .32261 .13484 .3225 .13041 .32011 Metetra
.461 .774 .997 r
.13041 .32011 .13484 .3225 .14044 .32223 .13606 .31947 Metetra
.503 .767 .991 r
.13606 .31947 .14044 .32223 .14609 .3217 .14175 .3187 Metetra
.52 .759 .983 r
.14175 .3187 .14609 .3217 .1518 .3209 .14746 .31788 Metetra
.517 .757 .983 r
.14746 .31788 .1518 .3209 .15754 .31992 .15319 .31708 Metetra
.505 .764 .989 r
.15319 .31708 .15754 .31992 .16331 .31888 .15894 .31631 Metetra
.501 .78 .995 r
.15894 .31631 .16331 .31888 .16909 .31788 .1647 .31547 Metetra
.527 .8 .996 r
.1647 .31547 .16909 .31788 .17488 .31692 .17052 .31438 Metetra
.588 .813 .985 r
.17052 .31438 .17488 .31692 .1807 .31587 .1764 .31284 Metetra
.654 .8 .953 r
.1764 .31284 .1807 .31587 .18657 .31453 .18236 .31071 Metetra
.697 .765 .905 r
.18236 .31071 .18657 .31453 .19251 .31266 .18841 .30794 Metetra
.715 .726 .859 r
.18841 .30794 .19251 .31266 .19853 .31013 .19452 .30461 Metetra
.719 .697 .828 r
.19452 .30461 .19853 .31013 .20464 .30691 .20069 .30091 Metetra
.718 .68 .812 r
.20069 .30091 .20464 .30691 .21081 .30316 .20688 .29703 Metetra
.717 .676 .809 r
.20688 .29703 .21081 .30316 .21702 .29909 .21307 .29313 Metetra
.717 .682 .815 r
.21307 .29313 .21702 .29909 .22324 .29496 .21927 .28929 Metetra
.72 .693 .823 r
.21927 .28929 .22324 .29496 .22946 .29093 .22548 .28549 Metetra
.724 .703 .83 r
.22548 .28549 .22946 .29093 .23567 .28705 .23169 .28166 Metetra
.728 .706 .83 r
.23169 .28166 .23567 .28705 .24188 .28328 .23792 .27775 Metetra
.729 .702 .824 r
.23792 .27775 .24188 .28328 .2481 .27953 .24417 .27374 Metetra
.727 .693 .817 r
.24417 .27374 .2481 .27953 .25433 .27569 .25043 .26968 Metetra
.722 .684 .812 r
.25043 .26968 .25433 .27569 .26058 .27177 .25669 .26566 Metetra
.716 .679 .813 r
.25669 .26566 .26058 .27177 .26683 .2678 .26294 .26179 Metetra
.709 .68 .82 r
.26294 .26179 .26683 .2678 .27309 .2639 .26919 .25815 Metetra
.702 .687 .833 r
.26919 .25815 .27309 .2639 .27935 .26017 .27542 .25479 Metetra
.696 .699 .849 r
.27542 .25479 .27935 .26017 .28559 .2567 .28164 .25166 Metetra
.691 .712 .865 r
.28164 .25166 .28559 .2567 .29182 .25351 .28786 .24873 Metetra
.688 .723 .877 r
.28786 .24873 .29182 .25351 .29804 .25056 .29408 .24592 Metetra
.685 .73 .884 r
.29408 .24592 .29804 .25056 .30426 .24778 .3003 .24318 Metetra
.683 .731 .887 r
.3003 .24318 .30426 .24778 .31049 .2451 .30654 .24048 Metetra
.681 .73 .888 r
.30654 .24048 .31049 .2451 .31673 .24246 .31279 .23782 Metetra
.678 .729 .888 r
.31279 .23782 .31673 .24246 .32298 .23985 .31904 .23521 Metetra
.675 .728 .89 r
.31904 .23521 .32298 .23985 .32924 .23725 .32531 .23265 Metetra
.671 .73 .894 r
.32531 .23265 .32924 .23725 .33551 .23468 .33159 .23015 Metetra
.668 .732 .898 r
.33159 .23015 .33551 .23468 .34179 .23216 .33787 .2277 Metetra
.666 .736 .902 r
.33787 .2277 .34179 .23216 .34809 .2297 .34417 .22529 Metetra
.665 .739 .905 r
.34417 .22529 .34809 .2297 .35439 .22727 .35048 .2229 Metetra
.664 .741 .907 r
.35048 .2229 .35439 .22727 .36071 .22488 .35681 .22052 Metetra
.664 .742 .908 r
.35681 .22052 .36071 .22488 .36704 .22251 .36315 .21813 Metetra
.664 .742 .908 r
.36315 .21813 .36704 .22251 .37339 .22014 .36951 .21574 Metetra
.664 .741 .907 r
.36951 .21574 .37339 .22014 .37975 .21776 .37588 .21334 Metetra
.664 .74 .907 r
.37588 .21334 .37975 .21776 .38612 .21538 .38226 .21093 Metetra
.664 .74 .906 r
.38226 .21093 .38612 .21538 .39252 .21298 .38867 .20853 Metetra
.664 .739 .906 r
.38867 .20853 .39252 .21298 .39892 .21059 .39508 .20612 Metetra
.663 .739 .907 r
.39508 .20612 .39892 .21059 .40535 .20818 .40151 .20371 Metetra
.663 .74 .907 r
.40151 .20371 .40535 .20818 .41178 .20577 .40796 .2013 Metetra
.663 .74 .907 r
.40796 .2013 .41178 .20577 .41824 .20336 .41442 .19889 Metetra
.663 .741 .908 r
.41442 .19889 .41824 .20336 .42471 .20094 .4209 .19646 Metetra
.663 .741 .908 r
.4209 .19646 .42471 .20094 .43119 .19852 .4274 .19403 Metetra
.663 .741 .908 r
.4274 .19403 .43119 .19852 .43769 .19611 .4339 .1916 Metetra
.663 .74 .907 r
.4339 .1916 .43769 .19611 .4442 .19372 .44043 .18916 Metetra
.661 .738 .907 r
.44043 .18916 .4442 .19372 .45073 .19136 .44697 .18674 Metetra
.66 .735 .905 r
.44697 .18674 .45073 .19136 .45728 .18902 .45353 .18435 Metetra
.657 .732 .905 r
.45353 .18435 .45728 .18902 .46384 .18669 .4601 .18198 Metetra
.655 .73 .904 r
.4601 .18198 .46384 .18669 .47041 .18436 .46668 .17964 Metetra
.654 .73 .905 r
.46668 .17964 .47041 .18436 .47701 .18202 .47329 .17732 Metetra
.653 .73 .906 r
.47329 .17732 .47701 .18202 .48362 .17971 .4799 .17501 Metetra
.652 .731 .907 r
.4799 .17501 .48362 .17971 .49024 .17744 .48654 .17271 Metetra
.649 .729 .907 r
.48654 .17271 .49024 .17744 .49688 .1753 .49319 .17045 Metetra
.644 .721 .905 r
.49319 .17045 .49688 .1753 .50354 .17332 .49986 .16827 Metetra
.635 .708 .9 r
.49986 .16827 .50354 .17332 .51022 .17154 .50655 .16622 Metetra
.623 .691 .893 r
.50655 .16622 .51022 .17154 .51691 .16995 .51325 .16435 Metetra
.61 .674 .886 r
.51325 .16435 .51691 .16995 .52363 .16849 .51997 .16268 Metetra
.598 .66 .881 r
.51997 .16268 .52363 .16849 .53036 .1671 .52672 .1612 Metetra
.59 .652 .88 r
.52672 .1612 .53036 .1671 .53712 .16572 .53348 .15985 Metetra
.585 .652 .882 r
.53348 .15985 .53712 .16572 .5439 .16434 .54027 .15857 Metetra
.583 .656 .887 r
.54027 .15857 .5439 .16434 .5507 .16303 .54708 .1573 Metetra
.582 .658 .889 r
.54708 .1573 .5507 .16303 .55753 .16188 .55391 .15606 Metetra
.577 .652 .887 r
.55391 .15606 .55753 .16188 .56438 .16098 .56076 .15489 Metetra
.569 .637 .879 r
.56076 .15489 .56438 .16098 .57126 .16037 .56765 .15387 Metetra
.557 .615 .866 r
.56765 .15387 .57126 .16037 .57817 .15995 .57456 .15305 Metetra
.547 .595 .854 r
.57456 .15305 .57817 .15995 .58511 .15956 .58149 .15243 Metetra
.541 .585 .847 r
.58149 .15243 .58511 .15956 .59207 .15896 .58846 .15191 Metetra
.545 .59 .85 r
.58846 .15191 .59207 .15896 .59905 .15796 .59545 .15131 Metetra
.559 .613 .863 r
.59545 .15131 .59905 .15796 .60604 .15645 .60247 .15045 Metetra
.583 .651 .883 r
.60247 .15045 .60604 .15645 .61304 .15446 .60949 .14916 Metetra
.612 .696 .904 r
.60949 .14916 .61304 .15446 .62005 .15215 .61653 .14737 Metetra
.64 .735 .918 r
.61653 .14737 .62005 .15215 .62707 .14967 .62357 .14514 Metetra
.659 .756 .922 r
.62357 .14514 .62707 .14967 .63411 .14715 .63062 .14258 Metetra
.67 .759 .917 r
.63062 .14258 .63411 .14715 .64116 .1446 .63768 .13984 Metetra
.674 .751 .909 r
.63768 .13984 .64116 .1446 .64823 .14193 .64475 .13701 Metetra
.678 .745 .902 r
.64475 .13701 .64823 .14193 .6553 .13897 .65184 .13409 Metetra
.687 .752 .901 r
.65184 .13409 .6553 .13897 .66237 .13555 .65894 .13101 Metetra
.704 .776 .908 r
.65894 .13101 .66237 .13555 .66943 .13162 .66604 .12764 Metetra
.728 .814 .918 r
.66604 .12764 .66943 .13162 .67648 .12723 .67313 .12388 Metetra
.752 .858 .928 r
.67313 .12388 .67648 .12723 .68352 .12254 .68022 .11972 Metetra
.77 .893 .931 r
.68022 .11972 .68352 .12254 .69056 .11777 .6873 .11522 Metetra
.778 .911 .93 r
.6873 .11522 .69056 .11777 .69762 .11313 .69438 .11053 Metetra
.779 .909 .93 r
.69438 .11053 .69762 .11313 .7047 .10875 .70146 .10583 Metetra
.771 .891 .929 r
.70146 .10583 .7047 .10875 .71181 .10464 .70857 .10129 Metetra
.758 .863 .926 r
.70857 .10129 .71181 .10464 .71895 .10076 .7157 .09698 Metetra
.743 .835 .921 r
.7157 .09698 .71895 .10076 .72611 .09699 .72285 .09291 Metetra
.731 .816 .917 r
.72285 .09291 .72611 .09699 .73329 .09325 .73004 .08905 Metetra
.724 .807 .917 r
.73004 .08905 .73329 .09325 .74047 .08947 .73724 .0853 Metetra
.454 .766 .996 r
.09252 .32042 .09701 .32286 .10258 .32203 .09806 .31986 Metetra
.409 .764 .995 r
.09806 .31986 .10258 .32203 .10813 .32149 .10361 .31942 Metetra
.394 .764 .993 r
.10361 .31942 .10813 .32149 .11367 .32115 .10916 .31901 Metetra
.411 .768 .995 r
.10916 .31901 .11367 .32115 .11922 .32089 .11475 .31854 Metetra
.444 .77 .997 r
.11475 .31854 .11922 .32089 .1248 .32057 .12036 .31798 Metetra
.473 .767 .995 r
.12036 .31798 .1248 .32057 .13041 .32011 .126 .31734 Metetra
.486 .761 .991 r
.126 .31734 .13041 .32011 .13606 .31947 .13167 .31668 Metetra
.483 .759 .991 r
.13167 .31668 .13606 .31947 .14175 .3187 .13735 .31604 Metetra
.471 .763 .994 r
.13735 .31604 .14175 .3187 .14746 .31788 .14304 .31543 Metetra
.466 .774 .997 r
.14304 .31543 .14746 .31788 .15319 .31708 .14876 .31476 Metetra
.487 .791 .998 r
.14876 .31476 .15319 .31708 .15894 .31631 .15452 .3139 Metetra
.545 .807 .994 r
.15452 .3139 .15894 .31631 .1647 .31547 .16034 .31267 Metetra
.616 .805 .972 r
.16034 .31267 .1647 .31547 .17052 .31438 .16624 .31093 Metetra
.67 .78 .932 r
.16624 .31093 .17052 .31438 .1764 .31284 .17222 .3086 Metetra
.699 .745 .887 r
.17222 .3086 .1764 .31284 .18236 .31071 .17827 .30572 Metetra
.71 .715 .852 r
.17827 .30572 .18236 .31071 .18841 .30794 .18438 .30242 Metetra
.714 .695 .831 r
.18438 .30242 .18841 .30794 .19452 .30461 .19052 .29885 Metetra
.715 .687 .822 r
.19052 .29885 .19452 .30461 .20069 .30091 .19669 .29516 Metetra
.716 .688 .822 r
.19669 .29516 .20069 .30091 .20688 .29703 .20287 .29143 Metetra
.719 .695 .826 r
.20287 .29143 .20688 .29703 .21307 .29313 .20906 .28766 Metetra
.724 .702 .829 r
.20906 .28766 .21307 .29313 .21927 .28929 .21527 .28383 Metetra
.728 .703 .827 r
.21527 .28383 .21927 .28929 .22548 .28549 .2215 .27989 Metetra
.73 .699 .821 r
.2215 .27989 .22548 .28549 .23169 .28166 .22774 .27583 Metetra
.729 .691 .814 r
.22774 .27583 .23169 .28166 .23792 .27775 .234 .27169 Metetra
.725 .683 .809 r
.234 .27169 .23792 .27775 .24417 .27374 .24026 .26757 Metetra
.719 .678 .809 r
.24026 .26757 .24417 .27374 .25043 .26968 .24652 .26357 Metetra
.713 .678 .814 r
.24652 .26357 .25043 .26968 .25669 .26566 .25277 .25978 Metetra
.707 .684 .825 r
.25277 .25978 .25669 .26566 .26294 .26179 .259 .25623 Metetra
.702 .694 .84 r
.259 .25623 .26294 .26179 .26919 .25815 .26522 .25293 Metetra
.697 .706 .855 r
.26522 .25293 .26919 .25815 .27542 .25479 .27144 .24983 Metetra
.693 .717 .867 r
.27144 .24983 .27542 .25479 .28164 .25166 .27765 .24687 Metetra
.69 .724 .875 r
.27765 .24687 .28164 .25166 .28786 .24873 .28387 .24401 Metetra
.687 .727 .88 r
.28387 .24401 .28786 .24873 .29408 .24592 .2901 .24121 Metetra
.684 .727 .882 r
.2901 .24121 .29408 .24592 .3003 .24318 .29634 .23848 Metetra
.681 .726 .884 r
.29634 .23848 .3003 .24318 .30654 .24048 .30258 .2358 Metetra
.677 .727 .887 r
.30258 .2358 .30654 .24048 .31279 .23782 .30883 .23318 Metetra
.674 .728 .891 r
.30883 .23318 .31279 .23782 .31904 .23521 .31509 .23064 Metetra
.67 .731 .896 r
.31509 .23064 .31904 .23521 .32531 .23265 .32136 .22816 Metetra
.668 .735 .9 r
.32136 .22816 .32531 .23265 .33159 .23015 .32764 .22572 Metetra
.666 .738 .904 r
.32764 .22572 .33159 .23015 .33787 .2277 .33393 .22331 Metetra
.665 .74 .906 r
.33393 .22331 .33787 .2277 .34417 .22529 .34024 .22092 Metetra
.665 .742 .907 r
.34024 .22092 .34417 .22529 .35048 .2229 .34656 .21852 Metetra
.665 .742 .908 r
.34656 .21852 .35048 .2229 .35681 .22052 .35289 .21613 Metetra
.665 .741 .907 r
.35289 .21613 .35681 .22052 .36315 .21813 .35925 .21372 Metetra
.664 .741 .907 r
.35925 .21372 .36315 .21813 .36951 .21574 .36561 .21132 Metetra
.664 .741 .907 r
.36561 .21132 .36951 .21574 .37588 .21334 .37199 .20891 Metetra
.664 .741 .907 r
.37199 .20891 .37588 .21334 .38226 .21093 .37839 .20649 Metetra
.664 .741 .908 r
.37839 .20649 .38226 .21093 .38867 .20853 .3848 .20408 Metetra
.664 .741 .908 r
.3848 .20408 .38867 .20853 .39508 .20612 .39122 .20167 Metetra
.663 .741 .908 r
.39122 .20167 .39508 .20612 .40151 .20371 .39767 .19925 Metetra
.663 .741 .908 r
.39767 .19925 .40151 .20371 .40796 .2013 .40412 .19683 Metetra
.663 .741 .908 r
.40412 .19683 .40796 .2013 .41442 .19889 .41059 .1944 Metetra
.663 .741 .908 r
.41059 .1944 .41442 .19889 .4209 .19646 .41708 .19197 Metetra
.663 .741 .908 r
.41708 .19197 .4209 .19646 .4274 .19403 .42358 .18954 Metetra
.663 .742 .908 r
.42358 .18954 .4274 .19403 .4339 .1916 .4301 .18709 Metetra
.663 .742 .909 r
.4301 .18709 .4339 .1916 .44043 .18916 .43664 .18464 Metetra
.663 .741 .908 r
.43664 .18464 .44043 .18916 .44697 .18674 .44319 .18219 Metetra
.662 .74 .908 r
.44319 .18219 .44697 .18674 .45353 .18435 .44976 .17974 Metetra
.661 .737 .907 r
.44976 .17974 .45353 .18435 .4601 .18198 .45634 .17732 Metetra
.658 .734 .906 r
.45634 .17732 .4601 .18198 .46668 .17964 .46294 .17492 Metetra
.656 .731 .905 r
.46294 .17492 .46668 .17964 .47329 .17732 .46955 .17256 Metetra
.653 .728 .904 r
.46955 .17256 .47329 .17732 .4799 .17501 .47618 .17023 Metetra
.651 .727 .905 r
.47618 .17023 .4799 .17501 .48654 .17271 .48282 .16793 Metetra
.649 .727 .906 r
.48282 .16793 .48654 .17271 .49319 .17045 .48948 .16565 Metetra
.647 .726 .906 r
.48948 .16565 .49319 .17045 .49986 .16827 .49616 .1634 Metetra
.643 .722 .905 r
.49616 .1634 .49986 .16827 .50655 .16622 .50286 .16121 Metetra
.636 .713 .902 r
.50286 .16121 .50655 .16622 .51325 .16435 .50957 .15912 Metetra
.626 .698 .897 r
.50957 .15912 .51325 .16435 .51997 .16268 .5163 .15718 Metetra
.614 .681 .89 r
.5163 .15718 .51997 .16268 .52672 .1612 .52306 .15543 Metetra
.601 .664 .883 r
.52306 .15543 .52672 .1612 .53348 .15985 .52983 .15388 Metetra
.59 .651 .878 r
.52983 .15388 .53348 .15985 .54027 .15857 .53662 .15252 Metetra
.582 .644 .877 r
.53662 .15252 .54027 .15857 .54708 .1573 .54344 .15128 Metetra
.578 .644 .879 r
.54344 .15128 .54708 .1573 .55391 .15606 .55027 .1501 Metetra
.575 .646 .883 r
.55027 .1501 .55391 .15606 .56076 .15489 .55714 .14895 Metetra
.573 .646 .884 r
.55714 .14895 .56076 .15489 .56765 .15387 .56402 .14783 Metetra
.569 .641 .882 r
.56402 .14783 .56765 .15387 .57456 .15305 .57094 .14677 Metetra
.563 .628 .874 r
.57094 .14677 .57456 .15305 .58149 .15243 .57788 .14582 Metetra
.555 .612 .864 r
.57788 .14582 .58149 .15243 .58846 .15191 .58484 .14502 Metetra
.549 .599 .856 r
.58484 .14502 .58846 .15191 .59545 .15131 .59184 .14433 Metetra
.549 .596 .853 r
.59184 .14433 .59545 .15131 .60247 .15045 .59886 .14364 Metetra
.558 .607 .858 r
.59886 .14364 .60247 .15045 .60949 .14916 .6059 .1428 Metetra
.575 .634 .872 r
.6059 .1428 .60949 .14916 .61653 .14737 .61296 .14163 Metetra
.601 .673 .891 r
.61296 .14163 .61653 .14737 .62357 .14514 .62003 .14001 Metetra
.63 .715 .908 r
.62003 .14001 .62357 .14514 .63062 .14258 .62711 .13792 Metetra
.656 .75 .92 r
.62711 .13792 .63062 .14258 .63768 .13984 .63419 .13541 Metetra
.674 .77 .922 r
.63419 .13541 .63768 .13984 .64475 .13701 .64128 .13258 Metetra
.685 .775 .919 r
.64128 .13258 .64475 .13701 .65184 .13409 .64838 .12956 Metetra
.691 .772 .913 r
.64838 .12956 .65184 .13409 .65894 .13101 .65549 .12642 Metetra
.697 .772 .909 r
.65549 .12642 .65894 .13101 .66604 .12764 .66261 .12315 Metetra
.707 .782 .91 r
.66261 .12315 .66604 .12764 .67313 .12388 .66973 .11971 Metetra
.723 .804 .915 r
.66973 .11971 .67313 .12388 .68022 .11972 .67686 .116 Metetra
.742 .836 .922 r
.67686 .116 .68022 .11972 .6873 .11522 .68398 .11198 Metetra
.76 .869 .928 r
.68398 .11198 .6873 .11522 .69438 .11053 .6911 .10765 Metetra
.771 .893 .93 r
.6911 .10765 .69438 .11053 .70146 .10583 .69822 .10309 Metetra
.776 .902 .93 r
.69822 .10309 .70146 .10583 .70857 .10129 .70534 .09844 Metetra
.773 .897 .93 r
.70534 .09844 .70857 .10129 .7157 .09698 .71247 .09383 Metetra
.764 .878 .929 r
.71247 .09383 .7157 .09698 .72285 .09291 .71962 .08939 Metetra
.752 .854 .926 r
.71962 .08939 .72285 .09291 .73004 .08905 .72679 .08517 Metetra
.738 .831 .922 r
.72679 .08517 .73004 .08905 .73724 .0853 .734 .08117 Metetra
.438 .77 .997 r
.08799 .31812 .09252 .32042 .09806 .31986 .09354 .31758 Metetra
.434 .769 .997 r
.09354 .31758 .09806 .31986 .10361 .31942 .0991 .31705 Metetra
.445 .768 .997 r
.0991 .31705 .10361 .31942 .10916 .31901 .10468 .31649 Metetra
.458 .765 .996 r
.10468 .31649 .10916 .31901 .11475 .31854 .11029 .31591 Metetra
.463 .761 .994 r
.11029 .31591 .11475 .31854 .12036 .31798 .11591 .31534 Metetra
.457 .758 .994 r
.11591 .31534 .12036 .31798 .126 .31734 .12154 .31481 Metetra
.443 .759 .995 r
.12154 .31481 .126 .31734 .13167 .31668 .12719 .31431 Metetra
.434 .766 .997 r
.12719 .31431 .13167 .31668 .13735 .31604 .13286 .31379 Metetra
.449 .78 .998 r
.13286 .31379 .13735 .31604 .14304 .31543 .13857 .31313 Metetra
.499 .798 .999 r
.13857 .31313 .14304 .31543 .14876 .31476 .14433 .31218 Metetra
.571 .805 .988 r
.14433 .31218 .14876 .31476 .15452 .3139 .15016 .31079 Metetra
.636 .791 .957 r
.15016 .31079 .15452 .3139 .16034 .31267 .15607 .30888 Metetra
.676 .763 .916 r
.15607 .30888 .16034 .31267 .16624 .31093 .16205 .30645 Metetra
.697 .734 .879 r
.16205 .30645 .16624 .31093 .17222 .3086 .1681 .30358 Metetra
.706 .712 .853 r
.1681 .30358 .17222 .3086 .17827 .30572 .1742 .30037 Metetra
.71 .701 .839 r
.1742 .30037 .17827 .30572 .18438 .30242 .18032 .29695 Metetra
.713 .698 .834 r
.18032 .29695 .18438 .30242 .19052 .29885 .18648 .2934 Metetra
.718 .7 .832 r
.18648 .2934 .19052 .29885 .19669 .29516 .19265 .28975 Metetra
.723 .703 .831 r
.19265 .28975 .19669 .29516 .20287 .29143 .19884 .28597 Metetra
.727 .703 .828 r
.19884 .28597 .20287 .29143 .20906 .28766 .20505 .28205 Metetra
.73 .699 .821 r
.20505 .28205 .20906 .28766 .21527 .28383 .21129 .27799 Metetra
.73 .691 .813 r
.21129 .27799 .21527 .28383 .2215 .27989 .21754 .27382 Metetra
.727 .683 .808 r
.21754 .27382 .2215 .27989 .22774 .27583 .22381 .26962 Metetra
.723 .678 .806 r
.22381 .26962 .22774 .27583 .234 .27169 .23007 .26551 Metetra
.717 .677 .81 r
.23007 .26551 .234 .27169 .24026 .26757 .23632 .26156 Metetra
.712 .681 .819 r
.23632 .26156 .24026 .26757 .24652 .26357 .24256 .25784 Metetra
.707 .69 .831 r
.24256 .25784 .24652 .26357 .25277 .25978 .24879 .25435 Metetra
.703 .7 .845 r
.24879 .25435 .25277 .25978 .259 .25623 .25501 .25107 Metetra
.699 .71 .857 r
.25501 .25107 .259 .25623 .26522 .25293 .26122 .24796 Metetra
.695 .717 .866 r
.26122 .24796 .26522 .25293 .27144 .24983 .26744 .24496 Metetra
.692 .721 .872 r
.26744 .24496 .27144 .24983 .27765 .24687 .27365 .24205 Metetra
.688 .723 .876 r
.27365 .24205 .27765 .24687 .28387 .24401 .27988 .23921 Metetra
.684 .723 .879 r
.27988 .23921 .28387 .24401 .2901 .24121 .28611 .23645 Metetra
.68 .724 .883 r
.28611 .23645 .2901 .24121 .29634 .23848 .29235 .23377 Metetra
.676 .726 .887 r
.29235 .23377 .29634 .23848 .30258 .2358 .29859 .23117 Metetra
.673 .729 .892 r
.29859 .23117 .30258 .2358 .30883 .23318 .30485 .22865 Metetra
.67 .733 .897 r
.30485 .22865 .30883 .23318 .31509 .23064 .31111 .22617 Metetra
.667 .736 .902 r
.31111 .22617 .31509 .23064 .32136 .22816 .31738 .22374 Metetra
.666 .739 .904 r
.31738 .22374 .32136 .22816 .32764 .22572 .32367 .22132 Metetra
.666 .74 .906 r
.32367 .22132 .32764 .22572 .33393 .22331 .32997 .21892 Metetra
.665 .741 .906 r
.32997 .21892 .33393 .22331 .34024 .22092 .33629 .21651 Metetra
.665 .741 .906 r
.33629 .21651 .34024 .22092 .34656 .21852 .34262 .2141 Metetra
.665 .74 .906 r
.34262 .2141 .34656 .21852 .35289 .21613 .34896 .21169 Metetra
.664 .74 .906 r
.34896 .21169 .35289 .21613 .35925 .21372 .35532 .20928 Metetra
.664 .74 .907 r
.35532 .20928 .35925 .21372 .36561 .21132 .3617 .20687 Metetra
.664 .74 .907 r
.3617 .20687 .36561 .21132 .37199 .20891 .36809 .20445 Metetra
.664 .741 .907 r
.36809 .20445 .37199 .20891 .37839 .20649 .37449 .20204 Metetra
.664 .741 .908 r
.37449 .20204 .37839 .20649 .3848 .20408 .38091 .19962 Metetra
.664 .741 .908 r
.38091 .19962 .3848 .20408 .39122 .20167 .38735 .19719 Metetra
.664 .741 .908 r
.38735 .19719 .39122 .20167 .39767 .19925 .3938 .19476 Metetra
.663 .741 .908 r
.3938 .19476 .39767 .19925 .40412 .19683 .40027 .19233 Metetra
.663 .741 .908 r
.40027 .19233 .40412 .19683 .41059 .1944 .40675 .18989 Metetra
.663 .741 .908 r
.40675 .18989 .41059 .1944 .41708 .19197 .41324 .18744 Metetra
.663 .74 .907 r
.41324 .18744 .41708 .19197 .42358 .18954 .41976 .185 Metetra
.663 .74 .908 r
.41976 .185 .42358 .18954 .4301 .18709 .42629 .18255 Metetra
.663 .741 .908 r
.42629 .18255 .4301 .18709 .43664 .18464 .43283 .18009 Metetra
.663 .741 .908 r
.43283 .18009 .43664 .18464 .44319 .18219 .43939 .17763 Metetra
.663 .741 .908 r
.43939 .17763 .44319 .18219 .44976 .17974 .44597 .17516 Metetra
.662 .74 .908 r
.44597 .17516 .44976 .17974 .45634 .17732 .45256 .1727 Metetra
.661 .739 .907 r
.45256 .1727 .45634 .17732 .46294 .17492 .45917 .17025 Metetra
.659 .736 .906 r
.45917 .17025 .46294 .17492 .46955 .17256 .46579 .16782 Metetra
.656 .732 .905 r
.46579 .16782 .46955 .17256 .47618 .17023 .47243 .16543 Metetra
.653 .728 .904 r
.47243 .16543 .47618 .17023 .48282 .16793 .47909 .16308 Metetra
.65 .726 .904 r
.47909 .16308 .48282 .16793 .48948 .16565 .48576 .16077 Metetra
.648 .724 .904 r
.48576 .16077 .48948 .16565 .49616 .1634 .49245 .1585 Metetra
.645 .722 .904 r
.49245 .1585 .49616 .1634 .50286 .16121 .49916 .15627 Metetra
.641 .719 .904 r
.49916 .15627 .50286 .16121 .50957 .15912 .50588 .15408 Metetra
.636 .713 .903 r
.50588 .15408 .50957 .15912 .5163 .15718 .51262 .15198 Metetra
.628 .702 .899 r
.51262 .15198 .5163 .15718 .52306 .15543 .51938 .15 Metetra
.617 .688 .893 r
.51938 .15 .52306 .15543 .52983 .15388 .52616 .14819 Metetra
.605 .67 .886 r
.52616 .14819 .52983 .15388 .53662 .15252 .53296 .14657 Metetra
.592 .654 .88 r
.53296 .14657 .53662 .15252 .54344 .15128 .53978 .14515 Metetra
.582 .642 .876 r
.53978 .14515 .54344 .15128 .55027 .1501 .54663 .1439 Metetra
.574 .636 .875 r
.54663 .1439 .55027 .1501 .55714 .14895 .5535 .14277 Metetra
.57 .635 .877 r
.5535 .14277 .55714 .14895 .56402 .14783 .56039 .14169 Metetra
.569 .637 .879 r
.56039 .14169 .56402 .14783 .57094 .14677 .56731 .14064 Metetra
.567 .637 .88 r
.56731 .14064 .57094 .14677 .57788 .14582 .57425 .1396 Metetra
.564 .633 .878 r
.57425 .1396 .57788 .14582 .58484 .14502 .58122 .13861 Metetra
.56 .623 .872 r
.58122 .13861 .58484 .14502 .59184 .14433 .58822 .13768 Metetra
.557 .613 .865 r
.58822 .13768 .59184 .14433 .59886 .14364 .59524 .13684 Metetra
.556 .607 .86 r
.59524 .13684 .59886 .14364 .6059 .1428 .60229 .13601 Metetra
.561 .611 .86 r
.60229 .13601 .6059 .1428 .61296 .14163 .60936 .1351 Metetra
.573 .627 .868 r
.60936 .1351 .61296 .14163 .62003 .14001 .61646 .13396 Metetra
.594 .657 .882 r
.61646 .13396 .62003 .14001 .62711 .13792 .62356 .13245 Metetra
.62 .696 .898 r
.62356 .13245 .62711 .13792 .63419 .13541 .63067 .13049 Metetra
.648 .736 .913 r
.63067 .13049 .63419 .13541 .64128 .13258 .63779 .12808 Metetra
.672 .767 .922 r
.63779 .12808 .64128 .13258 .64838 .12956 .64491 .12526 Metetra
.69 .785 .924 r
.64491 .12526 .64838 .12956 .65549 .12642 .65204 .12216 Metetra
.701 .792 .921 r
.65204 .12216 .65549 .12642 .66261 .12315 .65917 .11885 Metetra
.708 .793 .917 r
.65917 .11885 .66261 .12315 .66973 .11971 .66631 .11541 Metetra
.715 .796 .915 r
.66631 .11541 .66973 .11971 .67686 .116 .67346 .11183 Metetra
.725 .807 .915 r
.67346 .11183 .67686 .116 .68398 .11198 .68062 .10807 Metetra
.738 .826 .919 r
.68062 .10807 .68398 .11198 .6911 .10765 .68777 .1041 Metetra
.752 .851 .924 r
.68777 .1041 .6911 .10765 .69822 .10309 .69492 .09988 Metetra
.764 .874 .928 r
.69492 .09988 .69822 .10309 .70534 .09844 .70208 .09545 Metetra
.77 .889 .929 r
.70208 .09545 .70534 .09844 .71247 .09383 .70923 .09089 Metetra
.771 .893 .93 r
.70923 .09089 .71247 .09383 .71962 .08939 .71639 .0863 Metetra
.766 .884 .93 r
.71639 .0863 .71962 .08939 .72679 .08517 .72357 .08179 Metetra
.757 .866 .929 r
.72357 .08179 .72679 .08517 .734 .08117 .73077 .07746 Metetra
.459 .769 .997 r
.08346 .31566 .08799 .31812 .09354 .31758 .08902 .31506 Metetra
.458 .765 .996 r
.08902 .31506 .09354 .31758 .0991 .31705 .09459 .31448 Metetra
.454 .761 .995 r
.09459 .31448 .0991 .31705 .10468 .31649 .10018 .31394 Metetra
.442 .757 .995 r
.10018 .31394 .10468 .31649 .11029 .31591 .10578 .31346 Metetra
.424 .756 .995 r
.10578 .31346 .11029 .31591 .11591 .31534 .11139 .31303 Metetra
.411 .759 .995 r
.11139 .31303 .11591 .31534 .12154 .31481 .11701 .31262 Metetra
.416 .769 .996 r
.11701 .31262 .12154 .31481 .12719 .31431 .12267 .31211 Metetra
.455 .786 .999 r
.12267 .31211 .12719 .31431 .13286 .31379 .12837 .31139 Metetra
.522 .8 .996 r
.12837 .31139 .13286 .31379 .13857 .31313 .13414 .31032 Metetra
.593 .798 .978 r
.13414 .31032 .13857 .31313 .14433 .31218 .13998 .3088 Metetra
.646 .778 .944 r
.13998 .3088 .14433 .31218 .15016 .31079 .14589 .3068 Metetra
.677 .752 .908 r
.14589 .3068 .15016 .31079 .15607 .30888 .15187 .30435 Metetra
.693 .73 .879 r
.15187 .30435 .15607 .30888 .16205 .30645 .1579 .30154 Metetra
.702 .716 .86 r
.1579 .30154 .16205 .30645 .1681 .30358 .16398 .29844 Metetra
.708 .709 .849 r
.16398 .29844 .1681 .30358 .1742 .30037 .17009 .29514 Metetra
.714 .707 .843 r
.17009 .29514 .1742 .30037 .18032 .29695 .17623 .29167 Metetra
.72 .707 .838 r
.17623 .29167 .18032 .29695 .18648 .2934 .1824 .28802 Metetra
.725 .705 .831 r
.1824 .28802 .18648 .2934 .19265 .28975 .1886 .28419 Metetra
.729 .7 .823 r
.1886 .28419 .19265 .28975 .19884 .28597 .19483 .28017 Metetra
.73 .692 .814 r
.19483 .28017 .19884 .28597 .20505 .28205 .20107 .27601 Metetra
.728 .684 .808 r
.20107 .27601 .20505 .28205 .21129 .27799 .20733 .27178 Metetra
.725 .678 .804 r
.20733 .27178 .21129 .27799 .21754 .27382 .21359 .26758 Metetra
.721 .676 .806 r
.21359 .26758 .21754 .27382 .22381 .26962 .21985 .26351 Metetra
.716 .679 .813 r
.21985 .26351 .22381 .26962 .23007 .26551 .2261 .25962 Metetra
.712 .686 .823 r
.2261 .25962 .23007 .26551 .23632 .26156 .23233 .25596 Metetra
.708 .695 .835 r
.23233 .25596 .23632 .26156 .24256 .25784 .23855 .25249 Metetra
.704 .704 .847 r
.23855 .25249 .24256 .25784 .24879 .25435 .24477 .2492 Metetra
.7 .711 .857 r
.24477 .2492 .24879 .25435 .25501 .25107 .25098 .24605 Metetra
.696 .716 .864 r
.25098 .24605 .25501 .25107 .26122 .24796 .2572 .243 Metetra
.693 .718 .869 r
.2572 .243 .26122 .24796 .26744 .24496 .26342 .24005 Metetra
.688 .719 .873 r
.26342 .24005 .26744 .24496 .27365 .24205 .26964 .2372 Metetra
.684 .721 .878 r
.26964 .2372 .27365 .24205 .27988 .23921 .27587 .23444 Metetra
.679 .724 .883 r
.27587 .23444 .27988 .23921 .28611 .23645 .2821 .23177 Metetra
.675 .727 .889 r
.2821 .23177 .28611 .23645 .29235 .23377 .28834 .22918 Metetra
.672 .731 .894 r
.28834 .22918 .29235 .23377 .29859 .23117 .29458 .22666 Metetra
.669 .735 .899 r
.29458 .22666 .29859 .23117 .30485 .22865 .30084 .22419 Metetra
.668 .738 .902 r
.30084 .22419 .30485 .22865 .31111 .22617 .30711 .22175 Metetra
.667 .739 .904 r
.30711 .22175 .31111 .22617 .31738 .22374 .31339 .21933 Metetra
.666 .74 .905 r
.31339 .21933 .31738 .22374 .32367 .22132 .31969 .21691 Metetra
.666 .74 .906 r
.31969 .21691 .32367 .22132 .32997 .21892 .326 .21449 Metetra
.665 .74 .906 r
.326 .21449 .32997 .21892 .33629 .21651 .33232 .21207 Metetra
.665 .74 .906 r
.33232 .21207 .33629 .21651 .34262 .2141 .33866 .20966 Metetra
.664 .74 .907 r
.33866 .20966 .34262 .2141 .34896 .21169 .34501 .20724 Metetra
.664 .74 .907 r
.34501 .20724 .34896 .21169 .35532 .20928 .35138 .20483 Metetra
.664 .741 .907 r
.35138 .20483 .35532 .20928 .3617 .20687 .35777 .20241 Metetra
.664 .741 .908 r
.35777 .20241 .3617 .20687 .36809 .20445 .36417 .19999 Metetra
.664 .741 .908 r
.36417 .19999 .36809 .20445 .37449 .20204 .37058 .19757 Metetra
.664 .741 .908 r
.37058 .19757 .37449 .20204 .38091 .19962 .37701 .19514 Metetra
.664 .741 .908 r
.37701 .19514 .38091 .19962 .38735 .19719 .38345 .1927 Metetra
.664 .741 .908 r
.38345 .1927 .38735 .19719 .3938 .19476 .38992 .19026 Metetra
.664 .741 .908 r
.38992 .19026 .3938 .19476 .40027 .19233 .39639 .18781 Metetra
.664 .741 .908 r
.39639 .18781 .40027 .19233 .40675 .18989 .40288 .18536 Metetra
.663 .741 .908 r
.40288 .18536 .40675 .18989 .41324 .18744 .40939 .1829 Metetra
.663 .741 .908 r
.40939 .1829 .41324 .18744 .41976 .185 .41591 .18044 Metetra
.663 .741 .908 r
.41591 .18044 .41976 .185 .42629 .18255 .42245 .17797 Metetra
.663 .74 .908 r
.42245 .17797 .42629 .18255 .43283 .18009 .42901 .17551 Metetra
.663 .74 .908 r
.42901 .17551 .43283 .18009 .43939 .17763 .43558 .17304 Metetra
.663 .74 .908 r
.43558 .17304 .43939 .17763 .44597 .17516 .44217 .17056 Metetra
.662 .74 .908 r
.44217 .17056 .44597 .17516 .45256 .1727 .44877 .16808 Metetra
.662 .74 .908 r
.44877 .16808 .45256 .1727 .45917 .17025 .45539 .16561 Metetra
.661 .739 .908 r
.45539 .16561 .45917 .17025 .46579 .16782 .46202 .16314 Metetra
.66 .737 .907 r
.46202 .16314 .46579 .16782 .47243 .16543 .46867 .16068 Metetra
.657 .733 .906 r
.46867 .16068 .47243 .16543 .47909 .16308 .47534 .15826 Metetra
.654 .729 .905 r
.47534 .15826 .47909 .16308 .48576 .16077 .48202 .15589 Metetra
.651 .725 .904 r
.48202 .15589 .48576 .16077 .49245 .1585 .48872 .15356 Metetra
.647 .722 .903 r
.48872 .15356 .49245 .1585 .49916 .15627 .49544 .15128 Metetra
.643 .719 .903 r
.49544 .15128 .49916 .15627 .50588 .15408 .50217 .14905 Metetra
.64 .716 .903 r
.50217 .14905 .50588 .15408 .51262 .15198 .50892 .14689 Metetra
.635 .711 .902 r
.50892 .14689 .51262 .15198 .51938 .15 .51569 .14479 Metetra
.628 .703 .9 r
.51569 .14479 .51938 .15 .52616 .14819 .52248 .14279 Metetra
.619 .691 .895 r
.52248 .14279 .52616 .14819 .53296 .14657 .52929 .14093 Metetra
.607 .676 .89 r
.52929 .14093 .53296 .14657 .53978 .14515 .53611 .13925 Metetra
.595 .659 .883 r
.53611 .13925 .53978 .14515 .54663 .1439 .54296 .13777 Metetra
.583 .645 .877 r
.54296 .13777 .54663 .1439 .5535 .14277 .54984 .13648 Metetra
.574 .634 .873 r
.54984 .13648 .5535 .14277 .56039 .14169 .55674 .13534 Metetra
.567 .629 .872 r
.55674 .13534 .56039 .14169 .56731 .14064 .56366 .13431 Metetra
.564 .629 .874 r
.56366 .13431 .56731 .14064 .57425 .1396 .57061 .13331 Metetra
.563 .63 .876 r
.57061 .13331 .57425 .1396 .58122 .13861 .57759 .13232 Metetra
.563 .631 .877 r
.57759 .13232 .58122 .13861 .58822 .13768 .58459 .13134 Metetra
.563 .628 .875 r
.58459 .13134 .58822 .13768 .59524 .13684 .59162 .13036 Metetra
.562 .623 .871 r
.59162 .13036 .59524 .13684 .60229 .13601 .59867 .1294 Metetra
.562 .619 .867 r
.59867 .1294 .60229 .13601 .60936 .1351 .60575 .12844 Metetra
.566 .619 .865 r
.60575 .12844 .60936 .1351 .61646 .13396 .61285 .12742 Metetra
.575 .629 .868 r
.61285 .12742 .61646 .13396 .62356 .13245 .61997 .12623 Metetra
.591 .651 .877 r
.61997 .12623 .62356 .13245 .63067 .13049 .62711 .12475 Metetra
.614 .682 .891 r
.62711 .12475 .63067 .13049 .63779 .12808 .63426 .12288 Metetra
.641 .72 .906 r
.63426 .12288 .63779 .12808 .64491 .12526 .64141 .12057 Metetra
.667 .757 .917 r
.64141 .12057 .64491 .12526 .65204 .12216 .64857 .11782 Metetra
.689 .785 .924 r
.64857 .11782 .65204 .12216 .65917 .11885 .65572 .1147 Metetra
.705 .801 .925 r
.65572 .1147 .65917 .11885 .66631 .11541 .66288 .11131 Metetra
.715 .808 .923 r
.66288 .11131 .66631 .11541 .67346 .11183 .67005 .10773 Metetra
.723 .812 .92 r
.67005 .10773 .67346 .11183 .68062 .10807 .67722 .10401 Metetra
.73 .816 .919 r
.67722 .10401 .68062 .10807 .68777 .1041 .6844 .10016 Metetra
.738 .826 .919 r
.6844 .10016 .68777 .1041 .69492 .09988 .69158 .09616 Metetra
.748 .842 .922 r
.69158 .09616 .69492 .09988 .70208 .09545 .69877 .09199 Metetra
.757 .86 .925 r
.69877 .09199 .70208 .09545 .70923 .09089 .70596 .08765 Metetra
.764 .875 .928 r
.70596 .08765 .70923 .09089 .71639 .0863 .71315 .08317 Metetra
.767 .883 .929 r
.71315 .08317 .71639 .0863 .72357 .08179 .72034 .07864 Metetra
.765 .882 .93 r
.72034 .07864 .72357 .08179 .73077 .07746 .72755 .07414 Metetra
.457 .762 .995 r
.07892 .31309 .08346 .31566 .08902 .31506 .08448 .31253 Metetra
.439 .758 .995 r
.08448 .31253 .08902 .31506 .09459 .31448 .09004 .31205 Metetra
.417 .755 .995 r
.09004 .31205 .09459 .31448 .10018 .31394 .09562 .31165 Metetra
.397 .754 .993 r
.09562 .31165 .10018 .31394 .10578 .31346 .1012 .31129 Metetra
.393 .76 .993 r
.1012 .31129 .10578 .31346 .11139 .31303 .10682 .31089 Metetra
.418 .773 .996 r
.10682 .31089 .11139 .31303 .11701 .31262 .11247 .31035 Metetra
.474 .79 .999 r
.11247 .31035 .11701 .31262 .12267 .31211 .11817 .30954 Metetra
.544 .797 .992 r
.11817 .30954 .12267 .31211 .12837 .31139 .12394 .30836 Metetra
.606 .789 .969 r
.12394 .30836 .12837 .31139 .13414 .31032 .12978 .30676 Metetra
.648 .769 .937 r
.12978 .30676 .13414 .31032 .13998 .3088 .13569 .30473 Metetra
.674 .748 .907 r
.13569 .30473 .13998 .3088 .14589 .3068 .14165 .30232 Metetra
.689 .732 .884 r
.14165 .30232 .14589 .3068 .15187 .30435 .14767 .2996 Metetra
.699 .722 .868 r
.14767 .2996 .15187 .30435 .1579 .30154 .15374 .2966 Metetra
.707 .717 .857 r
.15374 .2966 .1579 .30154 .16398 .29844 .15984 .29337 Metetra
.715 .714 .848 r
.15984 .29337 .16398 .29844 .17009 .29514 .16597 .28991 Metetra
.722 .71 .838 r
.16597 .28991 .17009 .29514 .17623 .29167 .17215 .28622 Metetra
.727 .704 .828 r
.17215 .28622 .17623 .29167 .1824 .28802 .17835 .28231 Metetra
.729 .695 .818 r
.17835 .28231 .1824 .28802 .1886 .28419 .18458 .27821 Metetra
.729 .687 .809 r
.18458 .27821 .1886 .28419 .19483 .28017 .19084 .27399 Metetra
.727 .68 .805 r
.19084 .27399 .19483 .28017 .20107 .27601 .1971 .26975 Metetra
.724 .677 .804 r
.1971 .26975 .20107 .27601 .20733 .27178 .20336 .26559 Metetra
.72 .678 .809 r
.20336 .26559 .20733 .27178 .21359 .26758 .20961 .26156 Metetra
.716 .683 .817 r
.20961 .26156 .21359 .26758 .21985 .26351 .21585 .25773 Metetra
.712 .69 .827 r
.21585 .25773 .21985 .26351 .2261 .25962 .22208 .25408 Metetra
.709 .698 .838 r
.22208 .25408 .2261 .25962 .23233 .25596 .2283 .25061 Metetra
.705 .705 .847 r
.2283 .25061 .23233 .25596 .23855 .25249 .23452 .24729 Metetra
.701 .71 .855 r
.23452 .24729 .23855 .25249 .24477 .2492 .24073 .2441 Metetra
.697 .713 .861 r
.24073 .2441 .24477 .2492 .25098 .24605 .24694 .24102 Metetra
.693 .715 .866 r
.24694 .24102 .25098 .24605 .2572 .243 .25316 .23805 Metetra
.688 .718 .872 r
.25316 .23805 .2572 .243 .26342 .24005 .25938 .23519 Metetra
.683 .721 .878 r
.25938 .23519 .26342 .24005 .26964 .2372 .2656 .23243 Metetra
.679 .724 .884 r
.2656 .23243 .26964 .2372 .27587 .23444 .27182 .22978 Metetra
.675 .729 .89 r
.27182 .22978 .27587 .23444 .2821 .23177 .27806 .2272 Metetra
.672 .733 .896 r
.27806 .2272 .2821 .23177 .28834 .22918 .2843 .22468 Metetra
.67 .736 .9 r
.2843 .22468 .28834 .22918 .29458 .22666 .29055 .22221 Metetra
.668 .738 .902 r
.29055 .22221 .29458 .22666 .30084 .22419 .29681 .21975 Metetra
.667 .739 .904 r
.29681 .21975 .30084 .22419 .30711 .22175 .30309 .21732 Metetra
.666 .74 .905 r
.30309 .21732 .30711 .22175 .31339 .21933 .30938 .21489 Metetra
.666 .74 .905 r
.30938 .21489 .31339 .21933 .31969 .21691 .31568 .21246 Metetra
.665 .74 .906 r
.31568 .21246 .31969 .21691 .326 .21449 .322 .21004 Metetra
.665 .74 .906 r
.322 .21004 .326 .21449 .33232 .21207 .32834 .20762 Metetra
.664 .74 .907 r
.32834 .20762 .33232 .21207 .33866 .20966 .33468 .2052 Metetra
.664 .741 .907 r
.33468 .2052 .33866 .20966 .34501 .20724 .34105 .20279 Metetra
.664 .741 .908 r
.34105 .20279 .34501 .20724 .35138 .20483 .34742 .20037 Metetra
.664 .741 .908 r
.34742 .20037 .35138 .20483 .35777 .20241 .35382 .19794 Metetra
.664 .741 .908 r
.35382 .19794 .35777 .20241 .36417 .19999 .36023 .19551 Metetra
.664 .741 .908 r
.36023 .19551 .36417 .19999 .37058 .19757 .36665 .19308 Metetra
.664 .741 .908 r
.36665 .19308 .37058 .19757 .37701 .19514 .37309 .19064 Metetra
.664 .741 .908 r
.37309 .19064 .37701 .19514 .38345 .1927 .37954 .18819 Metetra
.664 .741 .908 r
.37954 .18819 .38345 .1927 .38992 .19026 .38601 .18574 Metetra
.664 .741 .908 r
.38601 .18574 .38992 .19026 .39639 .18781 .3925 .18328 Metetra
.664 .741 .908 r
.3925 .18328 .39639 .18781 .40288 .18536 .399 .18082 Metetra
.664 .741 .908 r
.399 .18082 .40288 .18536 .40939 .1829 .40552 .17834 Metetra
.664 .741 .908 r
.40552 .17834 .40939 .1829 .41591 .18044 .41205 .17587 Metetra
.663 .741 .908 r
.41205 .17587 .41591 .18044 .42245 .17797 .4186 .17339 Metetra
.663 .741 .908 r
.4186 .17339 .42245 .17797 .42901 .17551 .42517 .17091 Metetra
.663 .741 .908 r
.42517 .17091 .42901 .17551 .43558 .17304 .43175 .16842 Metetra
.663 .74 .908 r
.43175 .16842 .43558 .17304 .44217 .17056 .43834 .16593 Metetra
.662 .74 .908 r
.43834 .16593 .44217 .17056 .44877 .16808 .44496 .16344 Metetra
.662 .74 .908 r
.44496 .16344 .44877 .16808 .45539 .16561 .45159 .16095 Metetra
.662 .74 .908 r
.45159 .16095 .45539 .16561 .46202 .16314 .45823 .15846 Metetra
.661 .739 .908 r
.45823 .15846 .46202 .16314 .46867 .16068 .46489 .15598 Metetra
.66 .737 .907 r
.46489 .15598 .46867 .16068 .47534 .15826 .47157 .15351 Metetra
.658 .735 .906 r
.47157 .15351 .47534 .15826 .48202 .15589 .47826 .15106 Metetra
.655 .731 .905 r
.47826 .15106 .48202 .15589 .48872 .15356 .48497 .14866 Metetra
.651 .726 .904 r
.48497 .14866 .48872 .15356 .49544 .15128 .4917 .1463 Metetra
.647 .721 .903 r
.4917 .1463 .49544 .15128 .50217 .14905 .49844 .14401 Metetra
.643 .717 .902 r
.49844 .14401 .50217 .14905 .50892 .14689 .50521 .14178 Metetra
.638 .713 .901 r
.50521 .14178 .50892 .14689 .51569 .14479 .51198 .13961 Metetra
.633 .708 .901 r
.51198 .13961 .51569 .14479 .52248 .14279 .51878 .13752 Metetra
.627 .702 .899 r
.51878 .13752 .52248 .14279 .52929 .14093 .5256 .13553 Metetra
.619 .692 .896 r
.5256 .13553 .52929 .14093 .53611 .13925 .53243 .13365 Metetra
.609 .679 .892 r
.53243 .13365 .53611 .13925 .54296 .13777 .53929 .13193 Metetra
.597 .664 .886 r
.53929 .13193 .54296 .13777 .54984 .13648 .54617 .13039 Metetra
.585 .649 .879 r
.54617 .13039 .54984 .13648 .55674 .13534 .55308 .12904 Metetra
.575 .635 .874 r
.55308 .12904 .55674 .13534 .56366 .13431 .56001 .12787 Metetra
.567 .626 .871 r
.56001 .12787 .56366 .13431 .57061 .13331 .56696 .12683 Metetra
.562 .623 .87 r
.56696 .12683 .57061 .13331 .57759 .13232 .57394 .12587 Metetra
.56 .623 .872 r
.57394 .12587 .57759 .13232 .58459 .13134 .58095 .12493 Metetra
.561 .626 .874 r
.58095 .12493 .58459 .13134 .59162 .13036 .58798 .12397 Metetra
.562 .628 .875 r
.58798 .12397 .59162 .13036 .59867 .1294 .59504 .12298 Metetra
.564 .629 .874 r
.59504 .12298 .59867 .1294 .60575 .12844 .60212 .12196 Metetra
.566 .628 .872 r
.60212 .12196 .60575 .12844 .61285 .12742 .60923 .1209 Metetra
.571 .629 .871 r
.60923 .1209 .61285 .12742 .61997 .12623 .61636 .11977 Metetra
.579 .636 .872 r
.61636 .11977 .61997 .12623 .62711 .12475 .62352 .11849 Metetra
.592 .651 .877 r
.62352 .11849 .62711 .12475 .63426 .12288 .63069 .11698 Metetra
.611 .676 .887 r
.63069 .11698 .63426 .12288 .64141 .12057 .63787 .11514 Metetra
.635 .709 .9 r
.63787 .11514 .64141 .12057 .64857 .11782 .64505 .1129 Metetra
.661 .745 .912 r
.64505 .1129 .64857 .11782 .65572 .1147 .65224 .11022 Metetra
.685 .778 .921 r
.65224 .11022 .65572 .1147 .66288 .11131 .65943 .10714 Metetra
.705 .802 .925 r
.65943 .10714 .66288 .11131 .67005 .10773 .66662 .10373 Metetra
.719 .817 .926 r
.66662 .10373 .67005 .10773 .67722 .10401 .67381 .10008 Metetra
.729 .824 .924 r
.67381 .10008 .67722 .10401 .6844 .10016 .68101 .09625 Metetra
.735 .828 .922 r
.68101 .09625 .6844 .10016 .69158 .09616 .68822 .09229 Metetra
.741 .833 .921 r
.68822 .09229 .69158 .09616 .69877 .09199 .69543 .08822 Metetra
.747 .841 .922 r
.69543 .08822 .69877 .09199 .70596 .08765 .70264 .08403 Metetra
.754 .853 .924 r
.70264 .08403 .70596 .08765 .71315 .08317 .70986 .07973 Metetra
.76 .864 .926 r
.70986 .07973 .71315 .08317 .72034 .07864 .71709 .07532 Metetra
.763 .873 .928 r
.71709 .07532 .72034 .07864 .72755 .07414 .72432 .07085 Metetra
.422 .756 .995 r
.07433 .31064 .07892 .31309 .08448 .31253 .07988 .31022 Metetra
.396 .753 .993 r
.07988 .31022 .08448 .31253 .09004 .31205 .08543 .30987 Metetra
.382 .754 .991 r
.08543 .30987 .09004 .31205 .09562 .31165 .091 .30953 Metetra
.392 .763 .992 r
.091 .30953 .09562 .31165 .1012 .31129 .09661 .30911 Metetra
.432 .778 .997 r
.09661 .30911 .1012 .31129 .10682 .31089 .10225 .30851 Metetra
.494 .791 .998 r
.10225 .30851 .10682 .31089 .11247 .31035 .10796 .30761 Metetra
.559 .792 .986 r
.10796 .30761 .11247 .31035 .11817 .30954 .11372 .30636 Metetra
.611 .781 .963 r
.11372 .30636 .11817 .30954 .12394 .30836 .11956 .30473 Metetra
.647 .765 .935 r
.11956 .30473 .12394 .30836 .12978 .30676 .12546 .30272 Metetra
.67 .749 .91 r
.12546 .30272 .12978 .30676 .13569 .30473 .13141 .30037 Metetra
.685 .737 .89 r
.13141 .30037 .13569 .30473 .14165 .30232 .13742 .29772 Metetra
.698 .729 .875 r
.13742 .29772 .14165 .30232 .14767 .2996 .14347 .29479 Metetra
.708 .723 .862 r
.14347 .29479 .14767 .2996 .15374 .2966 .14956 .29158 Metetra
.717 .717 .849 r
.14956 .29158 .15374 .2966 .15984 .29337 .1557 .2881 Metetra
.723 .709 .836 r
.1557 .2881 .15984 .29337 .16597 .28991 .16188 .28435 Metetra
.727 .7 .824 r
.16188 .28435 .16597 .28991 .17215 .28622 .16809 .28037 Metetra
.729 .691 .814 r
.16809 .28037 .17215 .28622 .17835 .28231 .17433 .27622 Metetra
.728 .683 .807 r
.17433 .27622 .17835 .28231 .18458 .27821 .18058 .27199 Metetra
.726 .679 .804 r
.18058 .27199 .18458 .27821 .19084 .27399 .18684 .26777 Metetra
.723 .678 .806 r
.18684 .26777 .19084 .27399 .1971 .26975 .1931 .26364 Metetra
.719 .681 .812 r
.1931 .26364 .1971 .26975 .20336 .26559 .19934 .25966 Metetra
.716 .686 .82 r
.19934 .25966 .20336 .26559 .20961 .26156 .20558 .25584 Metetra
.713 .693 .829 r
.20558 .25584 .20961 .26156 .21585 .25773 .21181 .2522 Metetra
.71 .699 .838 r
.21181 .2522 .21585 .25773 .22208 .25408 .21803 .2487 Metetra
.706 .704 .846 r
.21803 .2487 .22208 .25408 .2283 .25061 .22424 .24535 Metetra
.702 .708 .852 r
.22424 .24535 .2283 .25061 .23452 .24729 .23046 .24212 Metetra
.697 .711 .859 r
.23046 .24212 .23452 .24729 .24073 .2441 .23667 .23902 Metetra
.692 .713 .865 r
.23667 .23902 .24073 .2441 .24694 .24102 .24288 .23604 Metetra
.687 .717 .872 r
.24288 .23604 .24694 .24102 .25316 .23805 .2491 .23319 Metetra
.683 .721 .879 r
.2491 .23319 .25316 .23805 .25938 .23519 .25531 .23044 Metetra
.678 .725 .885 r
.25531 .23044 .25938 .23519 .2656 .23243 .26153 .22779 Metetra
.675 .73 .891 r
.26153 .22779 .2656 .23243 .27182 .22978 .26776 .22522 Metetra
.672 .733 .896 r
.26776 .22522 .27182 .22978 .27806 .2272 .27399 .2227 Metetra
.67 .736 .9 r
.27399 .2227 .27806 .2272 .2843 .22468 .28024 .22021 Metetra
.668 .738 .902 r
.28024 .22021 .2843 .22468 .29055 .22221 .2865 .21775 Metetra
.667 .739 .903 r
.2865 .21775 .29055 .22221 .29681 .21975 .29277 .2153 Metetra
.666 .739 .904 r
.29277 .2153 .29681 .21975 .30309 .21732 .29905 .21286 Metetra
.666 .739 .905 r
.29905 .21286 .30309 .21732 .30938 .21489 .30535 .21043 Metetra
.665 .74 .906 r
.30535 .21043 .30938 .21489 .31568 .21246 .31166 .20801 Metetra
.664 .74 .906 r
.31166 .20801 .31568 .21246 .322 .21004 .31799 .20558 Metetra
.664 .74 .907 r
.31799 .20558 .322 .21004 .32834 .20762 .32433 .20316 Metetra
.664 .741 .907 r
.32433 .20316 .32834 .20762 .33468 .2052 .33069 .20074 Metetra
.664 .741 .908 r
.33069 .20074 .33468 .2052 .34105 .20279 .33706 .19832 Metetra
.664 .741 .908 r
.33706 .19832 .34105 .20279 .34742 .20037 .34345 .19589 Metetra
.664 .741 .908 r
.34345 .19589 .34742 .20037 .35382 .19794 .34985 .19345 Metetra
.664 .741 .908 r
.34985 .19345 .35382 .19794 .36023 .19551 .35627 .19101 Metetra
.664 .741 .908 r
.35627 .19101 .36023 .19551 .36665 .19308 .3627 .18857 Metetra
.664 .741 .908 r
.3627 .18857 .36665 .19308 .37309 .19064 .36915 .18611 Metetra
.664 .741 .908 r
.36915 .18611 .37309 .19064 .37954 .18819 .37562 .18366 Metetra
.664 .741 .908 r
.37562 .18366 .37954 .18819 .38601 .18574 .3821 .18119 Metetra
.664 .741 .908 r
.3821 .18119 .38601 .18574 .3925 .18328 .38859 .17872 Metetra
.664 .741 .908 r
.38859 .17872 .3925 .18328 .399 .18082 .3951 .17625 Metetra
.664 .741 .908 r
.3951 .17625 .399 .18082 .40552 .17834 .40163 .17377 Metetra
.664 .741 .908 r
.40163 .17377 .40552 .17834 .41205 .17587 .40817 .17128 Metetra
.664 .741 .908 r
.40817 .17128 .41205 .17587 .4186 .17339 .41473 .16879 Metetra
.663 .741 .908 r
.41473 .16879 .4186 .17339 .42517 .17091 .42131 .16629 Metetra
.663 .741 .908 r
.42131 .16629 .42517 .17091 .43175 .16842 .4279 .16379 Metetra
.663 .741 .908 r
.4279 .16379 .43175 .16842 .43834 .16593 .43451 .16128 Metetra
.663 .74 .908 r
.43451 .16128 .43834 .16593 .44496 .16344 .44113 .15878 Metetra
.662 .74 .908 r
.44113 .15878 .44496 .16344 .45159 .16095 .44777 .15627 Metetra
.662 .74 .908 r
.44777 .15627 .45159 .16095 .45823 .15846 .45442 .15377 Metetra
.661 .739 .908 r
.45442 .15377 .45823 .15846 .46489 .15598 .4611 .15127 Metetra
.661 .739 .908 r
.4611 .15127 .46489 .15598 .47157 .15351 .46778 .14877 Metetra
.66 .737 .907 r
.46778 .14877 .47157 .15351 .47826 .15106 .47449 .14628 Metetra
.658 .735 .907 r
.47449 .14628 .47826 .15106 .48497 .14866 .48121 .14381 Metetra
.655 .732 .906 r
.48121 .14381 .48497 .14866 .4917 .1463 .48795 .14138 Metetra
.652 .727 .904 r
.48795 .14138 .4917 .1463 .49844 .14401 .4947 .139 Metetra
.647 .722 .903 r
.4947 .139 .49844 .14401 .50521 .14178 .50147 .13669 Metetra
.642 .716 .902 r
.50147 .13669 .50521 .14178 .51198 .13961 .50826 .13444 Metetra
.637 .711 .9 r
.50826 .13444 .51198 .13961 .51878 .13752 .51507 .13227 Metetra
.632 .706 .899 r
.51507 .13227 .51878 .13752 .5256 .13553 .52189 .13019 Metetra
.625 .699 .898 r
.52189 .13019 .5256 .13553 .53243 .13365 .52874 .12819 Metetra
.618 .691 .896 r
.52874 .12819 .53243 .13365 .53929 .13193 .53561 .12631 Metetra
.609 .681 .892 r
.53561 .12631 .53929 .13193 .54617 .13039 .54249 .12457 Metetra
.599 .667 .887 r
.54249 .12457 .54617 .13039 .55308 .12904 .5494 .12299 Metetra
.587 .652 .881 r
.5494 .12299 .55308 .12904 .56001 .12787 .55634 .12159 Metetra
.576 .638 .876 r
.55634 .12159 .56001 .12787 .56696 .12683 .56329 .12037 Metetra
.567 .627 .871 r
.56329 .12037 .56696 .12683 .57394 .12587 .57028 .1193 Metetra
.561 .62 .869 r
.57028 .1193 .57394 .12587 .58095 .12493 .57729 .11834 Metetra
.558 .619 .869 r
.57729 .11834 .58095 .12493 .58798 .12397 .58433 .11742 Metetra
.558 .621 .871 r
.58433 .11742 .58798 .12397 .59504 .12298 .5914 .1165 Metetra
.56 .625 .873 r
.5914 .1165 .59504 .12298 .60212 .12196 .59849 .11552 Metetra
.564 .629 .875 r
.59849 .11552 .60212 .12196 .60923 .1209 .60561 .11448 Metetra
.569 .633 .875 r
.60561 .11448 .60923 .1209 .61636 .11977 .61274 .11336 Metetra
.575 .637 .875 r
.61274 .11336 .61636 .11977 .62352 .11849 .61991 .11213 Metetra
.583 .644 .876 r
.61991 .11213 .62352 .11849 .63069 .11698 .62709 .11077 Metetra
.595 .656 .88 r
.62709 .11077 .63069 .11698 .63787 .11514 .63429 .10919 Metetra
.611 .675 .887 r
.63429 .10919 .63787 .11514 .64505 .1129 .6415 .10733 Metetra
.632 .703 .897 r
.6415 .10733 .64505 .1129 .65224 .11022 .64872 .10511 Metetra
.656 .735 .908 r
.64872 .10511 .65224 .11022 .65943 .10714 .65594 .10249 Metetra
.681 .769 .917 r
.65594 .10249 .65943 .10714 .66662 .10373 .66316 .09946 Metetra
.703 .797 .924 r
.66316 .09946 .66662 .10373 .67381 .10008 .67039 .09607 Metetra
.72 .818 .926 r
.67039 .09607 .67381 .10008 .68101 .09625 .67761 .09238 Metetra
.732 .831 .926 r
.67761 .09238 .68101 .09625 .68822 .09229 .68483 .08848 Metetra
.739 .837 .925 r
.68483 .08848 .68822 .09229 .69543 .08822 .69207 .08444 Metetra
.745 .841 .923 r
.69207 .08444 .69543 .08822 .70264 .08403 .6993 .08029 Metetra
.749 .845 .923 r
.6993 .08029 .70264 .08403 .70986 .07973 .70654 .07605 Metetra
.753 .851 .923 r
.70654 .07605 .70986 .07973 .71709 .07532 .71379 .07174 Metetra
.757 .858 .925 r
.71379 .07174 .71709 .07532 .72432 .07085 .72105 .06736 Metetra
.384 .752 .992 r
.06969 .30841 .07433 .31064 .07988 .31022 .07523 .30808 Metetra
.379 .756 .99 r
.07523 .30808 .07988 .31022 .08543 .30987 .08079 .30773 Metetra
.401 .766 .994 r
.08079 .30773 .08543 .30987 .091 .30953 .08638 .30727 Metetra
.449 .78 .998 r
.08638 .30727 .091 .30953 .09661 .30911 .09203 .3066 Metetra
.509 .789 .996 r
.09203 .3066 .09661 .30911 .10225 .30851 .09773 .30564 Metetra
.566 .788 .982 r
.09773 .30564 .10225 .30851 .10796 .30761 .10349 .30436 Metetra
.611 .778 .96 r
.10349 .30436 .10796 .30761 .11372 .30636 .10932 .30273 Metetra
.643 .764 .937 r
.10932 .30273 .11372 .30636 .11956 .30473 .1152 .30077 Metetra
.666 .752 .915 r
.1152 .30077 .11956 .30473 .12546 .30272 .12114 .29848 Metetra
.683 .743 .896 r
.12114 .29848 .12546 .30272 .13141 .30037 .12713 .29588 Metetra
.697 .734 .88 r
.12713 .29588 .13141 .30037 .13742 .29772 .13318 .29297 Metetra
.709 .726 .864 r
.13318 .29297 .13742 .29772 .14347 .29479 .13927 .28975 Metetra
.718 .717 .848 r
.13927 .28975 .14347 .29479 .14956 .29158 .14541 .28622 Metetra
.724 .706 .833 r
.14541 .28622 .14956 .29158 .1557 .2881 .15159 .28242 Metetra
.727 .696 .821 r
.15159 .28242 .1557 .2881 .16188 .28435 .15781 .2784 Metetra
.728 .687 .811 r
.15781 .2784 .16188 .28435 .16809 .28037 .16405 .27423 Metetra
.727 .681 .806 r
.16405 .27423 .16809 .28037 .17433 .27622 .1703 .27001 Metetra
.725 .679 .805 r
.1703 .27001 .17433 .27622 .18058 .27199 .17656 .26582 Metetra
.722 .68 .808 r
.17656 .26582 .18058 .27199 .18684 .26777 .18281 .26173 Metetra
.72 .683 .814 r
.18281 .26173 .18684 .26777 .1931 .26364 .18905 .25777 Metetra
.717 .688 .822 r
.18905 .25777 .1931 .26364 .19934 .25966 .19529 .25395 Metetra
.714 .694 .829 r
.19529 .25395 .19934 .25966 .20558 .25584 .20151 .25029 Metetra
.71 .698 .837 r
.20151 .25029 .20558 .25584 .21181 .2522 .20774 .24677 Metetra
.706 .702 .844 r
.20774 .24677 .21181 .2522 .21803 .2487 .21395 .24338 Metetra
.702 .706 .85 r
.21395 .24338 .21803 .2487 .22424 .24535 .22017 .24013 Metetra
.697 .709 .857 r
.22017 .24013 .22424 .24535 .23046 .24212 .22638 .23702 Metetra
.692 .713 .865 r
.22638 .23702 .23046 .24212 .23667 .23902 .23258 .23405 Metetra
.687 .717 .872 r
.23258 .23405 .23667 .23902 .24288 .23604 .23879 .2312 Metetra
.682 .722 .88 r
.23879 .2312 .24288 .23604 .2491 .23319 .245 .22846 Metetra
.678 .727 .886 r
.245 .22846 .2491 .23319 .25531 .23044 .25121 .22581 Metetra
.675 .731 .892 r
.25121 .22581 .25531 .23044 .26153 .22779 .25744 .22323 Metetra
.672 .734 .896 r
.25744 .22323 .26153 .22779 .26776 .22522 .26367 .2207 Metetra
.67 .736 .899 r
.26367 .2207 .26776 .22522 .27399 .2227 .26991 .2182 Metetra
.669 .737 .901 r
.26991 .2182 .27399 .2227 .28024 .22021 .27616 .21573 Metetra
.667 .738 .903 r
.27616 .21573 .28024 .22021 .2865 .21775 .28243 .21327 Metetra
.666 .739 .904 r
.28243 .21327 .2865 .21775 .29277 .2153 .28871 .21083 Metetra
.665 .739 .905 r
.28871 .21083 .29277 .2153 .29905 .21286 .295 .2084 Metetra
.665 .74 .906 r
.295 .2084 .29905 .21286 .30535 .21043 .3013 .20597 Metetra
.664 .74 .907 r
.3013 .20597 .30535 .21043 .31166 .20801 .30763 .20355 Metetra
.664 .741 .907 r
.30763 .20355 .31166 .20801 .31799 .20558 .31396 .20112 Metetra
.664 .741 .907 r
.31396 .20112 .31799 .20558 .32433 .20316 .32031 .1987 Metetra
.664 .741 .908 r
.32031 .1987 .32433 .20316 .33069 .20074 .32668 .19627 Metetra
.664 .741 .908 r
.32668 .19627 .33069 .20074 .33706 .19832 .33306 .19383 Metetra
.664 .741 .908 r
.33306 .19383 .33706 .19832 .34345 .19589 .33946 .19139 Metetra
.664 .741 .908 r
.33946 .19139 .34345 .19589 .34985 .19345 .34587 .18894 Metetra
.664 .741 .908 r
.34587 .18894 .34985 .19345 .35627 .19101 .35229 .18649 Metetra
.664 .741 .908 r
.35229 .18649 .35627 .19101 .3627 .18857 .35874 .18404 Metetra
.664 .741 .908 r
.35874 .18404 .3627 .18857 .36915 .18611 .3652 .18157 Metetra
.664 .741 .908 r
.3652 .18157 .36915 .18611 .37562 .18366 .37167 .1791 Metetra
.664 .741 .908 r
.37167 .1791 .37562 .18366 .3821 .18119 .37816 .17663 Metetra
.664 .741 .908 r
.37816 .17663 .3821 .18119 .38859 .17872 .38467 .17415 Metetra
.664 .741 .908 r
.38467 .17415 .38859 .17872 .3951 .17625 .39119 .17166 Metetra
.664 .741 .908 r
.39119 .17166 .3951 .17625 .40163 .17377 .39772 .16917 Metetra
.664 .741 .908 r
.39772 .16917 .40163 .17377 .40817 .17128 .40428 .16667 Metetra
.664 .741 .908 r
.40428 .16667 .40817 .17128 .41473 .16879 .41085 .16417 Metetra
.664 .741 .908 r
.41085 .16417 .41473 .16879 .42131 .16629 .41743 .16166 Metetra
.663 .741 .908 r
.41743 .16166 .42131 .16629 .4279 .16379 .42403 .15914 Metetra
.663 .741 .908 r
.42403 .15914 .4279 .16379 .43451 .16128 .43065 .15662 Metetra
.663 .741 .908 r
.43065 .15662 .43451 .16128 .44113 .15878 .43728 .1541 Metetra
.663 .74 .908 r
.43728 .1541 .44113 .15878 .44777 .15627 .44393 .15158 Metetra
.662 .74 .908 r
.44393 .15158 .44777 .15627 .45442 .15377 .4506 .14905 Metetra
.662 .739 .907 r
.4506 .14905 .45442 .15377 .4611 .15127 .45728 .14653 Metetra
.661 .739 .907 r
.45728 .14653 .4611 .15127 .46778 .14877 .46398 .14401 Metetra
.661 .738 .907 r
.46398 .14401 .46778 .14877 .47449 .14628 .4707 .1415 Metetra
.659 .737 .907 r
.4707 .1415 .47449 .14628 .48121 .14381 .47743 .139 Metetra
.658 .735 .907 r
.47743 .139 .48121 .14381 .48795 .14138 .48418 .13652 Metetra
.655 .732 .906 r
.48418 .13652 .48795 .14138 .4947 .139 .49094 .13407 Metetra
.652 .728 .905 r
.49094 .13407 .4947 .139 .50147 .13669 .49772 .13166 Metetra
.648 .723 .903 r
.49772 .13166 .50147 .13669 .50826 .13444 .50452 .12932 Metetra
.643 .717 .902 r
.50452 .12932 .50826 .13444 .51507 .13227 .51134 .12705 Metetra
.637 .71 .9 r
.51134 .12705 .51507 .13227 .52189 .13019 .51818 .12487 Metetra
.631 .704 .898 r
.51818 .12487 .52189 .13019 .52874 .12819 .52503 .12278 Metetra
.624 .697 .897 r
.52503 .12278 .52874 .12819 .53561 .12631 .5319 .12079 Metetra
.617 .689 .895 r
.5319 .12079 .53561 .12631 .54249 .12457 .5388 .11891 Metetra
.609 .68 .892 r
.5388 .11891 .54249 .12457 .5494 .12299 .54572 .11715 Metetra
.599 .669 .888 r
.54572 .11715 .5494 .12299 .55634 .12159 .55265 .11555 Metetra
.589 .655 .883 r
.55265 .11555 .55634 .12159 .56329 .12037 .55962 .11411 Metetra
.578 .642 .877 r
.55962 .11411 .56329 .12037 .57028 .1193 .56661 .11285 Metetra
.569 .629 .872 r
.56661 .11285 .57028 .1193 .57729 .11834 .57363 .11174 Metetra
.561 .621 .869 r
.57363 .11174 .57729 .11834 .58433 .11742 .58067 .11075 Metetra
.557 .616 .867 r
.58067 .11075 .58433 .11742 .5914 .1165 .58774 .10983 Metetra
.556 .617 .868 r
.58774 .10983 .5914 .1165 .59849 .11552 .59484 .10893 Metetra
.558 .621 .871 r
.59484 .10893 .59849 .11552 .60561 .11448 .60196 .10797 Metetra
.563 .627 .874 r
.60196 .10797 .60561 .11448 .61274 .11336 .60911 .10693 Metetra
.569 .634 .876 r
.60911 .10693 .61274 .11336 .61991 .11213 .61628 .10578 Metetra
.577 .642 .878 r
.61628 .10578 .61991 .11213 .62709 .11077 .62347 .10449 Metetra
.586 .65 .88 r
.62347 .10449 .62709 .11077 .63429 .10919 .63069 .10304 Metetra
.598 .662 .883 r
.63069 .10304 .63429 .10919 .6415 .10733 .63792 .10139 Metetra
.613 .678 .888 r
.63792 .10139 .6415 .10733 .64872 .10511 .64516 .09948 Metetra
.632 .701 .896 r
.64516 .09948 .64872 .10511 .65594 .10249 .65241 .09724 Metetra
.654 .73 .905 r
.65241 .09724 .65594 .10249 .66316 .09946 .65967 .09464 Metetra
.677 .761 .914 r
.65967 .09464 .66316 .09946 .67039 .09607 .66692 .09165 Metetra
.699 .791 .921 r
.66692 .09165 .67039 .09607 .67761 .09238 .67418 .08829 Metetra
.718 .816 .926 r
.67418 .08829 .67761 .09238 .68483 .08848 .68143 .08461 Metetra
.732 .833 .927 r
.68143 .08461 .68483 .08848 .69207 .08444 .68869 .08068 Metetra
.742 .843 .926 r
.68869 .08068 .69207 .08444 .6993 .08029 .69595 .07657 Metetra
.748 .848 .925 r
.69595 .07657 .6993 .08029 .70654 .07605 .70321 .07235 Metetra
.751 .85 .924 r
.70321 .07235 .70654 .07605 .71379 .07174 .71048 .06806 Metetra
.754 .853 .924 r
.71048 .06806 .71379 .07174 .72105 .06736 .71776 .06371 Metetra
.385 .758 .991 r
.065 .30627 .06969 .30841 .07523 .30808 .07056 .30589 Metetra
.414 .769 .995 r
.07056 .30589 .07523 .30808 .08079 .30773 .07615 .30537 Metetra
.463 .781 .998 r
.07615 .30537 .08079 .30773 .08638 .30727 .08179 .30465 Metetra
.518 .787 .994 r
.08179 .30465 .08638 .30727 .09203 .3066 .08748 .30367 Metetra
.568 .784 .98 r
.08748 .30367 .09203 .3066 .09773 .30564 .09323 .30238 Metetra
.608 .776 .961 r
.09323 .30238 .09773 .30564 .10349 .30436 .09905 .30078 Metetra
.639 .767 .94 r
.09905 .30078 .10349 .30436 .10932 .30273 .10492 .29886 Metetra
.663 .757 .92 r
.10492 .29886 .10932 .30273 .1152 .30077 .11085 .29661 Metetra
.682 .747 .9 r
.11085 .29661 .1152 .30077 .12114 .29848 .11683 .29403 Metetra
.698 .737 .882 r
.11683 .29403 .12114 .29848 .12713 .29588 .12287 .29112 Metetra
.71 .727 .863 r
.12287 .29112 .12713 .29588 .13318 .29297 .12896 .28787 Metetra
.719 .715 .846 r
.12896 .28787 .13318 .29297 .13927 .28975 .13511 .2843 Metetra
.724 .703 .83 r
.13511 .2843 .13927 .28975 .14541 .28622 .14129 .28046 Metetra
.727 .693 .818 r
.14129 .28046 .14541 .28622 .15159 .28242 .14751 .27642 Metetra
.727 .686 .81 r
.14751 .27642 .15159 .28242 .15781 .2784 .15375 .27226 Metetra
.726 .682 .807 r
.15375 .27226 .15781 .2784 .16405 .27423 .16 .26806 Metetra
.724 .68 .807 r
.16 .26806 .16405 .27423 .1703 .27001 .16625 .2639 Metetra
.722 .682 .81 r
.16625 .2639 .1703 .27001 .17656 .26582 .1725 .25983 Metetra
.72 .685 .816 r
.1725 .25983 .17656 .26582 .18281 .26173 .17874 .25587 Metetra
.718 .689 .822 r
.17874 .25587 .18281 .26173 .18905 .25777 .18498 .25204 Metetra
.714 .694 .829 r
.18498 .25204 .18905 .25777 .19529 .25395 .1912 .24835 Metetra
.711 .697 .835 r
.1912 .24835 .19529 .25395 .20151 .25029 .19743 .24481 Metetra
.706 .701 .842 r
.19743 .24481 .20151 .25029 .20774 .24677 .20364 .2414 Metetra
.702 .704 .849 r
.20364 .2414 .20774 .24677 .21395 .24338 .20985 .23814 Metetra
.697 .708 .857 r
.20985 .23814 .21395 .24338 .22017 .24013 .21606 .23503 Metetra
.692 .713 .865 r
.21606 .23503 .22017 .24013 .22638 .23702 .22226 .23206 Metetra
.687 .718 .873 r
.22226 .23206 .22638 .23702 .23258 .23405 .22846 .22922 Metetra
.682 .723 .881 r
.22846 .22922 .23258 .23405 .23879 .2312 .23467 .22648 Metetra
.678 .727 .887 r
.23467 .22648 .23879 .2312 .245 .22846 .24088 .22382 Metetra
.675 .731 .892 r
.24088 .22382 .245 .22846 .25121 .22581 .24709 .22123 Metetra
.672 .734 .896 r
.24709 .22123 .25121 .22581 .25744 .22323 .25332 .21869 Metetra
.67 .736 .899 r
.25332 .21869 .25744 .22323 .26367 .2207 .25956 .21619 Metetra
.669 .737 .901 r
.25956 .21619 .26367 .2207 .26991 .2182 .2658 .21371 Metetra
.667 .738 .903 r
.2658 .21371 .26991 .2182 .27616 .21573 .27206 .21125 Metetra
.666 .738 .904 r
.27206 .21125 .27616 .21573 .28243 .21327 .27834 .2088 Metetra
.665 .739 .905 r
.27834 .2088 .28243 .21327 .28871 .21083 .28462 .20636 Metetra
.665 .74 .906 r
.28462 .20636 .28871 .21083 .295 .2084 .29092 .20393 Metetra
.664 .74 .907 r
.29092 .20393 .295 .2084 .3013 .20597 .29724 .2015 Metetra
.664 .741 .907 r
.29724 .2015 .3013 .20597 .30763 .20355 .30357 .19907 Metetra
.664 .741 .908 r
.30357 .19907 .30763 .20355 .31396 .20112 .30991 .19664 Metetra
.664 .741 .908 r
.30991 .19664 .31396 .20112 .32031 .1987 .31627 .19421 Metetra
.664 .741 .908 r
.31627 .19421 .32031 .1987 .32668 .19627 .32265 .19177 Metetra
.664 .741 .908 r
.32265 .19177 .32668 .19627 .33306 .19383 .32904 .18932 Metetra
.664 .741 .908 r
.32904 .18932 .33306 .19383 .33946 .19139 .33544 .18687 Metetra
.664 .741 .908 r
.33544 .18687 .33946 .19139 .34587 .18894 .34187 .18441 Metetra
.664 .741 .908 r
.34187 .18441 .34587 .18894 .35229 .18649 .3483 .18195 Metetra
.664 .741 .908 r
.3483 .18195 .35229 .18649 .35874 .18404 .35475 .17948 Metetra
.664 .741 .908 r
.35475 .17948 .35874 .18404 .3652 .18157 .36122 .17701 Metetra
.664 .741 .908 r
.36122 .17701 .3652 .18157 .37167 .1791 .36771 .17453 Metetra
.664 .741 .908 r
.36771 .17453 .37167 .1791 .37816 .17663 .37421 .17205 Metetra
.664 .741 .908 r
.37421 .17205 .37816 .17663 .38467 .17415 .38072 .16955 Metetra
.664 .741 .908 r
.38072 .16955 .38467 .17415 .39119 .17166 .38725 .16706 Metetra
.664 .741 .908 r
.38725 .16706 .39119 .17166 .39772 .16917 .3938 .16455 Metetra
.664 .741 .908 r
.3938 .16455 .39772 .16917 .40428 .16667 .40036 .16204 Metetra
.663 .741 .908 r
.40036 .16204 .40428 .16667 .41085 .16417 .40694 .15953 Metetra
.663 .741 .908 r
.40694 .15953 .41085 .16417 .41743 .16166 .41354 .15701 Metetra
.663 .741 .908 r
.41354 .15701 .41743 .16166 .42403 .15914 .42015 .15448 Metetra
.663 .741 .908 r
.42015 .15448 .42403 .15914 .43065 .15662 .42678 .15195 Metetra
.663 .741 .908 r
.42678 .15195 .43065 .15662 .43728 .1541 .43342 .14941 Metetra
.663 .741 .908 r
.43342 .14941 .43728 .1541 .44393 .15158 .44008 .14687 Metetra
.663 .74 .908 r
.44008 .14687 .44393 .15158 .4506 .14905 .44676 .14433 Metetra
.662 .74 .908 r
.44676 .14433 .4506 .14905 .45728 .14653 .45345 .14178 Metetra
.662 .739 .907 r
.45345 .14178 .45728 .14653 .46398 .14401 .46016 .13924 Metetra
.661 .739 .907 r
.46016 .13924 .46398 .14401 .4707 .1415 .46689 .13671 Metetra
.66 .738 .907 r
.46689 .13671 .4707 .1415 .47743 .139 .47363 .13418 Metetra
.659 .737 .907 r
.47363 .13418 .47743 .139 .48418 .13652 .48039 .13167 Metetra
.658 .735 .907 r
.48039 .13167 .48418 .13652 .49094 .13407 .48716 .12917 Metetra
.655 .732 .906 r
.48716 .12917 .49094 .13407 .49772 .13166 .49396 .1267 Metetra
.652 .729 .905 r
.49396 .1267 .49772 .13166 .50452 .12932 .50077 .12428 Metetra
.648 .724 .904 r
.50077 .12428 .50452 .12932 .51134 .12705 .50759 .12191 Metetra
.643 .717 .902 r
.50759 .12191 .51134 .12705 .51818 .12487 .51444 .11962 Metetra
.637 .71 .9 r
.51444 .11962 .51818 .12487 .52503 .12278 .5213 .11742 Metetra
.63 .703 .898 r
.5213 .11742 .52503 .12278 .5319 .12079 .52819 .11532 Metetra
.623 .695 .896 r
.52819 .11532 .5319 .12079 .5388 .11891 .53509 .11332 Metetra
.616 .687 .894 r
.53509 .11332 .5388 .11891 .54572 .11715 .54202 .11144 Metetra
.608 .679 .892 r
.54202 .11144 .54572 .11715 .55265 .11555 .54896 .10968 Metetra
.599 .668 .888 r
.54896 .10968 .55265 .11555 .55962 .11411 .55593 .10806 Metetra
.589 .657 .884 r
.55593 .10806 .55962 .11411 .56661 .11285 .56293 .1066 Metetra
.579 .644 .879 r
.56293 .1066 .56661 .11285 .57363 .11174 .56995 .10529 Metetra
.57 .632 .874 r
.56995 .10529 .57363 .11174 .58067 .11075 .57699 .10414 Metetra
.562 .622 .869 r
.57699 .10414 .58067 .11075 .58774 .10983 .58407 .10312 Metetra
.557 .616 .867 r
.58407 .10312 .58774 .10983 .59484 .10893 .59117 .10218 Metetra
.555 .615 .867 r
.59117 .10218 .59484 .10893 .60196 .10797 .5983 .10127 Metetra
.557 .618 .869 r
.5983 .10127 .60196 .10797 .60911 .10693 .60546 .10032 Metetra
.562 .624 .872 r
.60546 .10032 .60911 .10693 .61628 .10578 .61264 .09929 Metetra
.569 .633 .875 r
.61264 .09929 .61628 .10578 .62347 .10449 .61985 .09813 Metetra
.578 .643 .879 r
.61985 .09813 .62347 .10449 .63069 .10304 .62707 .09681 Metetra
.589 .654 .882 r
.62707 .09681 .63069 .10304 .63792 .10139 .63431 .0953 Metetra
.601 .667 .886 r
.63431 .0953 .63792 .10139 .64516 .09948 .64157 .09358 Metetra
.616 .683 .89 r
.64157 .09358 .64516 .09948 .65241 .09724 .64885 .0916 Metetra
.633 .703 .896 r
.64885 .0916 .65241 .09724 .65967 .09464 .65613 .08933 Metetra
.653 .728 .904 r
.65613 .08933 .65967 .09464 .66692 .09165 .66342 .08672 Metetra
.675 .756 .912 r
.66342 .08672 .66692 .09165 .67418 .08829 .67071 .08375 Metetra
.696 .785 .919 r
.67071 .08375 .67418 .08829 .68143 .08461 .67799 .08041 Metetra
.716 .811 .924 r
.67799 .08041 .68143 .08461 .68869 .08068 .68528 .07675 Metetra
.731 .831 .927 r
.68528 .07675 .68869 .08068 .69595 .07657 .69257 .07281 Metetra
.742 .845 .927 r
.69257 .07281 .69595 .07657 .70321 .07235 .69985 .06867 Metetra
.75 .852 .926 r
.69985 .06867 .70321 .07235 .71048 .06806 .70715 .0644 Metetra
.753 .855 .925 r
.70715 .0644 .71048 .06806 .71776 .06371 .71444 .06005 Metetra
.426 .771 .996 r
.06031 .304 .065 .30627 .07056 .30589 .06589 .30345 Metetra
.472 .78 .998 r
.06589 .30345 .07056 .30589 .07615 .30537 .07153 .3027 Metetra
.521 .785 .992 r
.07153 .3027 .07615 .30537 .08179 .30465 .07721 .3017 Metetra
.567 .783 .98 r
.07721 .3017 .08179 .30465 .08748 .30367 .08295 .30043 Metetra
.605 .777 .963 r
.08295 .30043 .08748 .30367 .09323 .30238 .08875 .29886 Metetra
.636 .769 .944 r
.08875 .29886 .09323 .30238 .09905 .30078 .09461 .29697 Metetra
.661 .76 .923 r
.09461 .29697 .09905 .30078 .10492 .29886 .10053 .29474 Metetra
.682 .75 .902 r
.10053 .29474 .10492 .29886 .11085 .29661 .10651 .29217 Metetra
.699 .738 .881 r
.10651 .29217 .11085 .29661 .11683 .29403 .11255 .28924 Metetra
.711 .725 .861 r
.11255 .28924 .11683 .29403 .12287 .29112 .11864 .28595 Metetra
.719 .713 .843 r
.11864 .28595 .12287 .29112 .12896 .28787 .12479 .28236 Metetra
.724 .701 .828 r
.12479 .28236 .12896 .28787 .13511 .2843 .13097 .2785 Metetra
.726 .692 .818 r
.13097 .2785 .13511 .2843 .14129 .28046 .13719 .27446 Metetra
.726 .686 .811 r
.13719 .27446 .14129 .28046 .14751 .27642 .14343 .27031 Metetra
.726 .683 .808 r
.14343 .27031 .14751 .27642 .15375 .27226 .14967 .26613 Metetra
.724 .682 .809 r
.14967 .26613 .15375 .27226 .16 .26806 .15592 .26199 Metetra
.723 .684 .812 r
.15592 .26199 .16 .26806 .16625 .2639 .16217 .25792 Metetra
.721 .686 .816 r
.16217 .25792 .16625 .2639 .1725 .25983 .16841 .25396 Metetra
.718 .689 .822 r
.16841 .25396 .1725 .25983 .17874 .25587 .17465 .25011 Metetra
.715 .693 .828 r
.17465 .25011 .17874 .25587 .18498 .25204 .18088 .2464 Metetra
.711 .696 .834 r
.18088 .2464 .18498 .25204 .1912 .24835 .1871 .24283 Metetra
.706 .7 .841 r
.1871 .24283 .1912 .24835 .19743 .24481 .19331 .23942 Metetra
.701 .704 .849 r
.19331 .23942 .19743 .24481 .20364 .2414 .19952 .23616 Metetra
.696 .708 .857 r
.19952 .23616 .20364 .2414 .20985 .23814 .20572 .23305 Metetra
.691 .713 .866 r
.20572 .23305 .20985 .23814 .21606 .23503 .21192 .23008 Metetra
.687 .719 .874 r
.21192 .23008 .21606 .23503 .22226 .23206 .21812 .22723 Metetra
.682 .724 .881 r
.21812 .22723 .22226 .23206 .22846 .22922 .22432 .22449 Metetra
.678 .728 .887 r
.22432 .22449 .22846 .22922 .23467 .22648 .23052 .22183 Metetra
.675 .731 .892 r
.23052 .22183 .23467 .22648 .24088 .22382 .23673 .21923 Metetra
.673 .733 .896 r
.23673 .21923 .24088 .22382 .24709 .22123 .24295 .21668 Metetra
.671 .735 .899 r
.24295 .21668 .24709 .22123 .25332 .21869 .24918 .21417 Metetra
.669 .736 .901 r
.24918 .21417 .25332 .21869 .25956 .21619 .25543 .21168 Metetra
.667 .738 .903 r
.25543 .21168 .25956 .21619 .2658 .21371 .26168 .20921 Metetra
.666 .738 .904 r
.26168 .20921 .2658 .21371 .27206 .21125 .26795 .20676 Metetra
.665 .739 .905 r
.26795 .20676 .27206 .21125 .27834 .2088 .27423 .20432 Metetra
.665 .74 .906 r
.27423 .20432 .27834 .2088 .28462 .20636 .28052 .20189 Metetra
.664 .74 .907 r
.28052 .20189 .28462 .20636 .29092 .20393 .28683 .19946 Metetra
.664 .741 .907 r
.28683 .19946 .29092 .20393 .29724 .2015 .29315 .19702 Metetra
.664 .741 .907 r
.29315 .19702 .29724 .2015 .30357 .19907 .29949 .19459 Metetra
.664 .741 .908 r
.29949 .19459 .30357 .19907 .30991 .19664 .30585 .19215 Metetra
.664 .741 .908 r
.30585 .19215 .30991 .19664 .31627 .19421 .31222 .1897 Metetra
.664 .741 .908 r
.31222 .1897 .31627 .19421 .32265 .19177 .3186 .18725 Metetra
.664 .741 .908 r
.3186 .18725 .32265 .19177 .32904 .18932 .325 .18479 Metetra
.664 .741 .908 r
.325 .18479 .32904 .18932 .33544 .18687 .33142 .18233 Metetra
.664 .741 .908 r
.33142 .18233 .33544 .18687 .34187 .18441 .33785 .17986 Metetra
.664 .741 .908 r
.33785 .17986 .34187 .18441 .3483 .18195 .34429 .17739 Metetra
.664 .741 .908 r
.34429 .17739 .3483 .18195 .35475 .17948 .35075 .17491 Metetra
.664 .741 .908 r
.35075 .17491 .35475 .17948 .36122 .17701 .35723 .17243 Metetra
.664 .741 .908 r
.35723 .17243 .36122 .17701 .36771 .17453 .36373 .16994 Metetra
.664 .741 .908 r
.36373 .16994 .36771 .17453 .37421 .17205 .37023 .16744 Metetra
.664 .741 .908 r
.37023 .16744 .37421 .17205 .38072 .16955 .37676 .16494 Metetra
.664 .741 .908 r
.37676 .16494 .38072 .16955 .38725 .16706 .3833 .16243 Metetra
.664 .741 .908 r
.3833 .16243 .38725 .16706 .3938 .16455 .38986 .15991 Metetra
.664 .741 .908 r
.38986 .15991 .3938 .16455 .40036 .16204 .39643 .15739 Metetra
.664 .741 .908 r
.39643 .15739 .40036 .16204 .40694 .15953 .40302 .15487 Metetra
.663 .741 .908 r
.40302 .15487 .40694 .15953 .41354 .15701 .40963 .15233 Metetra
.663 .741 .908 r
.40963 .15233 .41354 .15701 .42015 .15448 .41625 .14979 Metetra
.663 .741 .908 r
.41625 .14979 .42015 .15448 .42678 .15195 .42289 .14725 Metetra
.663 .741 .908 r
.42289 .14725 .42678 .15195 .43342 .14941 .42954 .1447 Metetra
.663 .741 .908 r
.42954 .1447 .43342 .14941 .44008 .14687 .43621 .14214 Metetra
.663 .741 .908 r
.43621 .14214 .44008 .14687 .44676 .14433 .4429 .13958 Metetra
.663 .741 .908 r
.4429 .13958 .44676 .14433 .45345 .14178 .4496 .13702 Metetra
.662 .74 .908 r
.4496 .13702 .45345 .14178 .46016 .13924 .45632 .13446 Metetra
.662 .739 .907 r
.45632 .13446 .46016 .13924 .46689 .13671 .46306 .1319 Metetra
.661 .739 .907 r
.46306 .1319 .46689 .13671 .47363 .13418 .46981 .12935 Metetra
.66 .737 .907 r
.46981 .12935 .47363 .13418 .48039 .13167 .47658 .12681 Metetra
.659 .736 .907 r
.47658 .12681 .48039 .13167 .48716 .12917 .48337 .12428 Metetra
.657 .735 .907 r
.48337 .12428 .48716 .12917 .49396 .1267 .49017 .12177 Metetra
.655 .732 .906 r
.49017 .12177 .49396 .1267 .50077 .12428 .49699 .11928 Metetra
.652 .729 .905 r
.49699 .11928 .50077 .12428 .50759 .12191 .50383 .11684 Metetra
.648 .724 .904 r
.50383 .11684 .50759 .12191 .51444 .11962 .51069 .11445 Metetra
.643 .718 .902 r
.51069 .11445 .51444 .11962 .5213 .11742 .51756 .11214 Metetra
.637 .711 .9 r
.51756 .11214 .5213 .11742 .52819 .11532 .52446 .10992 Metetra
.63 .703 .898 r
.52446 .10992 .52819 .11532 .53509 .11332 .53137 .1078 Metetra
.623 .695 .896 r
.53137 .1078 .53509 .11332 .54202 .11144 .5383 .10579 Metetra
.615 .686 .893 r
.5383 .10579 .54202 .11144 .54896 .10968 .54525 .1039 Metetra
.607 .677 .891 r
.54525 .1039 .54896 .10968 .55593 .10806 .55223 .10214 Metetra
.598 .667 .888 r
.55223 .10214 .55593 .10806 .56293 .1066 .55923 .10051 Metetra
.589 .657 .884 r
.55923 .10051 .56293 .1066 .56995 .10529 .56626 .09903 Metetra
.58 .645 .88 r
.56626 .09903 .56995 .10529 .57699 .10414 .57331 .0977 Metetra
.571 .634 .875 r
.57331 .0977 .57699 .10414 .58407 .10312 .58039 .09651 Metetra
.563 .624 .871 r
.58039 .09651 .58407 .10312 .59117 .10218 .58749 .09545 Metetra
.558 .617 .868 r
.58749 .09545 .59117 .10218 .5983 .10127 .59463 .09448 Metetra
.555 .614 .866 r
.59463 .09448 .5983 .10127 .60546 .10032 .60179 .09355 Metetra
.556 .616 .867 r
.60179 .09355 .60546 .10032 .61264 .09929 .60898 .0926 Metetra
.561 .622 .87 r
.60898 .0926 .61264 .09929 .61985 .09813 .6162 .09157 Metetra
.568 .631 .874 r
.6162 .09157 .61985 .09813 .62707 .09681 .62344 .0904 Metetra
.578 .643 .879 r
.62344 .0904 .62707 .09681 .63431 .0953 .63069 .08906 Metetra
.59 .656 .883 r
.63069 .08906 .63431 .0953 .64157 .09358 .63797 .08752 Metetra
.603 .671 .888 r
.63797 .08752 .64157 .09358 .64885 .0916 .64526 .08574 Metetra
.618 .687 .893 r
.64526 .08574 .64885 .0916 .65613 .08933 .65256 .08371 Metetra
.635 .706 .898 r
.65256 .08371 .65613 .08933 .66342 .08672 .65988 .08138 Metetra
.654 .728 .904 r
.65988 .08138 .66342 .08672 .67071 .08375 .66719 .07874 Metetra
.674 .754 .911 r
.66719 .07874 .67071 .08375 .67799 .08041 .67452 .07576 Metetra
.694 .78 .917 r
.67452 .07576 .67799 .08041 .68528 .07675 .68184 .07244 Metetra
.713 .806 .922 r
.68184 .07244 .68528 .07675 .69257 .07281 .68916 .06879 Metetra
.73 .828 .926 r
.68916 .06879 .69257 .07281 .69985 .06867 .69648 .06486 Metetra
.742 .844 .927 r
.69648 .06486 .69985 .06867 .70715 .0644 .70379 .06071 Metetra
.75 .854 .927 r
.70379 .06071 .70715 .0644 .71444 .06005 .71111 .05641 Metetra
.477 .779 .997 r
.05562 .30152 .06031 .304 .06589 .30345 .06125 .30075 Metetra
.521 .783 .992 r
.06125 .30075 .06589 .30345 .07153 .3027 .06692 .29976 Metetra
.564 .783 .981 r
.06692 .29976 .07153 .3027 .07721 .3017 .07265 .2985 Metetra
.601 .779 .965 r
.07265 .2985 .07721 .3017 .08295 .30043 .07843 .29695 Metetra
.634 .772 .947 r
.07843 .29695 .08295 .30043 .08875 .29886 .08428 .29508 Metetra
.661 .762 .925 r
.08428 .29508 .08875 .29886 .09461 .29697 .09019 .29286 Metetra
.683 .751 .903 r
.09019 .29286 .09461 .29697 .10053 .29474 .09617 .29028 Metetra
.7 .737 .88 r
.09617 .29028 .10053 .29474 .10651 .29217 .1022 .28732 Metetra
.711 .724 .86 r
.1022 .28732 .10651 .29217 .11255 .28924 .1083 .28401 Metetra
.719 .711 .842 r
.1083 .28401 .11255 .28924 .11864 .28595 .11444 .2804 Metetra
.723 .7 .828 r
.11444 .2804 .11864 .28595 .12479 .28236 .12063 .27654 Metetra
.725 .692 .818 r
.12063 .27654 .12479 .28236 .13097 .2785 .12684 .27251 Metetra
.726 .686 .812 r
.12684 .27251 .13097 .2785 .13719 .27446 .13308 .26838 Metetra
.726 .684 .81 r
.13308 .26838 .13719 .27446 .14343 .27031 .13932 .26422 Metetra
.725 .683 .81 r
.13932 .26422 .14343 .27031 .14967 .26613 .14557 .26008 Metetra
.723 .685 .812 r
.14557 .26008 .14967 .26613 .15592 .26199 .15182 .25601 Metetra
.721 .687 .816 r
.15182 .25601 .15592 .26199 .16217 .25792 .15806 .25203 Metetra
.718 .689 .821 r
.15806 .25203 .16217 .25792 .16841 .25396 .1643 .24816 Metetra
.715 .692 .827 r
.1643 .24816 .16841 .25396 .17465 .25011 .17053 .24443 Metetra
.711 .695 .833 r
.17053 .24443 .17465 .25011 .18088 .2464 .17675 .24085 Metetra
.706 .699 .841 r
.17675 .24085 .18088 .2464 .1871 .24283 .18296 .23743 Metetra
.701 .704 .849 r
.18296 .23743 .1871 .24283 .19331 .23942 .18916 .23417 Metetra
.696 .709 .858 r
.18916 .23417 .19331 .23942 .19952 .23616 .19536 .23106 Metetra
.691 .714 .866 r
.19536 .23106 .19952 .23616 .20572 .23305 .20156 .2281 Metetra
.687 .719 .874 r
.20156 .2281 .20572 .23305 .21192 .23008 .20775 .22525 Metetra
.682 .724 .881 r
.20775 .22525 .21192 .23008 .21812 .22723 .21394 .2225 Metetra
.679 .728 .887 r
.21394 .2225 .21812 .22723 .22432 .22449 .22014 .21983 Metetra
.675 .731 .892 r
.22014 .21983 .22432 .22449 .23052 .22183 .22635 .21722 Metetra
.673 .733 .895 r
.22635 .21722 .23052 .22183 .23673 .21923 .23256 .21466 Metetra
.671 .735 .898 r
.23256 .21466 .23673 .21923 .24295 .21668 .23879 .21214 Metetra
.669 .736 .901 r
.23879 .21214 .24295 .21668 .24918 .21417 .24503 .20965 Metetra
.667 .738 .903 r
.24503 .20965 .24918 .21417 .25543 .21168 .25127 .20718 Metetra
.666 .739 .904 r
.25127 .20718 .25543 .21168 .26168 .20921 .25754 .20473 Metetra
.665 .739 .905 r
.25754 .20473 .26168 .20921 .26795 .20676 .26381 .20228 Metetra
.665 .74 .906 r
.26381 .20228 .26795 .20676 .27423 .20432 .2701 .19984 Metetra
.664 .741 .907 r
.2701 .19984 .27423 .20432 .28052 .20189 .2764 .19741 Metetra
.664 .741 .907 r
.2764 .19741 .28052 .20189 .28683 .19946 .28272 .19497 Metetra
.664 .741 .907 r
.28272 .19497 .28683 .19946 .29315 .19702 .28905 .19252 Metetra
.664 .741 .908 r
.28905 .19252 .29315 .19702 .29949 .19459 .2954 .19008 Metetra
.664 .741 .908 r
.2954 .19008 .29949 .19459 .30585 .19215 .30176 .18763 Metetra
.664 .741 .908 r
.30176 .18763 .30585 .19215 .31222 .1897 .30814 .18517 Metetra
.664 .741 .908 r
.30814 .18517 .31222 .1897 .3186 .18725 .31453 .18271 Metetra
.664 .741 .908 r
.31453 .18271 .3186 .18725 .325 .18479 .32094 .18024 Metetra
.664 .741 .908 r
.32094 .18024 .325 .18479 .33142 .18233 .32737 .17777 Metetra
.664 .741 .908 r
.32737 .17777 .33142 .18233 .33785 .17986 .33381 .17529 Metetra
.664 .741 .908 r
.33381 .17529 .33785 .17986 .34429 .17739 .34026 .17281 Metetra
.664 .741 .908 r
.34026 .17281 .34429 .17739 .35075 .17491 .34674 .17032 Metetra
.664 .741 .908 r
.34674 .17032 .35075 .17491 .35723 .17243 .35322 .16783 Metetra
.664 .741 .908 r
.35322 .16783 .35723 .17243 .36373 .16994 .35973 .16532 Metetra
.664 .741 .908 r
.35973 .16532 .36373 .16994 .37023 .16744 .36625 .16281 Metetra
.664 .741 .908 r
.36625 .16281 .37023 .16744 .37676 .16494 .37278 .1603 Metetra
.664 .741 .908 r
.37278 .1603 .37676 .16494 .3833 .16243 .37933 .15778 Metetra
.664 .741 .908 r
.37933 .15778 .3833 .16243 .38986 .15991 .3859 .15525 Metetra
.664 .741 .908 r
.3859 .15525 .38986 .15991 .39643 .15739 .39248 .15272 Metetra
.664 .741 .908 r
.39248 .15272 .39643 .15739 .40302 .15487 .39908 .15018 Metetra
.664 .741 .908 r
.39908 .15018 .40302 .15487 .40963 .15233 .4057 .14764 Metetra
.663 .741 .908 r
.4057 .14764 .40963 .15233 .41625 .14979 .41233 .14509 Metetra
.663 .741 .908 r
.41233 .14509 .41625 .14979 .42289 .14725 .41898 .14253 Metetra
.663 .741 .908 r
.41898 .14253 .42289 .14725 .42954 .1447 .42564 .13997 Metetra
.663 .741 .908 r
.42564 .13997 .42954 .1447 .43621 .14214 .43232 .1374 Metetra
.663 .741 .908 r
.43232 .1374 .43621 .14214 .4429 .13958 .43902 .13483 Metetra
.663 .741 .908 r
.43902 .13483 .4429 .13958 .4496 .13702 .44574 .13225 Metetra
.663 .741 .908 r
.44574 .13225 .4496 .13702 .45632 .13446 .45247 .12967 Metetra
.663 .74 .908 r
.45247 .12967 .45632 .13446 .46306 .1319 .45921 .12709 Metetra
.662 .739 .907 r
.45921 .12709 .46306 .1319 .46981 .12935 .46598 .12451 Metetra
.661 .739 .907 r
.46598 .12451 .46981 .12935 .47658 .12681 .47276 .12194 Metetra
.66 .737 .907 r
.47276 .12194 .47658 .12681 .48337 .12428 .47956 .11938 Metetra
.659 .736 .907 r
.47956 .11938 .48337 .12428 .49017 .12177 .48637 .11683 Metetra
.657 .734 .906 r
.48637 .11683 .49017 .12177 .49699 .11928 .4932 .11431 Metetra
.655 .732 .906 r
.4932 .11431 .49699 .11928 .50383 .11684 .50005 .11181 Metetra
.652 .729 .905 r
.50005 .11181 .50383 .11684 .51069 .11445 .50692 .10935 Metetra
.648 .724 .904 r
.50692 .10935 .51069 .11445 .51756 .11214 .5138 .10695 Metetra
.643 .718 .903 r
.5138 .10695 .51756 .11214 .52446 .10992 .52071 .10461 Metetra
.637 .711 .901 r
.52071 .10461 .52446 .10992 .53137 .1078 .52763 .10237 Metetra
.63 .703 .898 r
.52763 .10237 .53137 .1078 .5383 .10579 .53457 .10023 Metetra
.623 .694 .896 r
.53457 .10023 .5383 .10579 .54525 .1039 .54153 .0982 Metetra
.615 .685 .893 r
.54153 .0982 .54525 .1039 .55223 .10214 .54852 .0963 Metetra
.606 .676 .89 r
.54852 .0963 .55223 .10214 .55923 .10051 .55553 .09454 Metetra
.598 .666 .887 r
.55553 .09454 .55923 .10051 .56626 .09903 .56256 .0929 Metetra
.589 .656 .884 r
.56256 .0929 .56626 .09903 .57331 .0977 .56961 .09141 Metetra
.58 .646 .88 r
.56961 .09141 .57331 .0977 .58039 .09651 .5767 .09006 Metetra
.572 .636 .876 r
.5767 .09006 .58039 .09651 .58749 .09545 .58381 .08884 Metetra
.564 .626 .872 r
.58381 .08884 .58749 .09545 .59463 .09448 .59095 .08774 Metetra
.559 .619 .869 r
.59095 .08774 .59463 .09448 .60179 .09355 .59811 .08673 Metetra
.556 .615 .867 r
.59811 .08673 .60179 .09355 .60898 .0926 .60531 .08577 Metetra
.556 .616 .867 r
.60531 .08577 .60898 .0926 .6162 .09157 .61253 .08481 Metetra
.56 .62 .869 r
.61253 .08481 .6162 .09157 .62344 .0904 .61978 .08377 Metetra
.567 .63 .873 r
.61978 .08377 .62344 .0904 .63069 .08906 .62705 .08259 Metetra
.578 .642 .878 r
.62705 .08259 .63069 .08906 .63797 .08752 .63434 .08124 Metetra
.59 .657 .883 r
.63434 .08124 .63797 .08752 .64526 .08574 .64165 .07967 Metetra
.604 .673 .889 r
.64165 .07967 .64526 .08574 .65256 .08371 .64897 .07786 Metetra
.62 .691 .894 r
.64897 .07786 .65256 .08371 .65988 .08138 .65631 .07577 Metetra
.637 .71 .899 r
.65631 .07577 .65988 .08138 .66719 .07874 .66365 .0734 Metetra
.655 .731 .905 r
.66365 .0734 .66719 .07874 .67452 .07576 .671 .07072 Metetra
.674 .754 .911 r
.671 .07072 .67452 .07576 .68184 .07244 .67835 .06772 Metetra
.693 .778 .917 r
.67835 .06772 .68184 .07244 .68916 .06879 .68571 .06439 Metetra
.712 .802 .921 r
.68571 .06439 .68916 .06879 .69648 .06486 .69306 .06075 Metetra
.728 .824 .925 r
.69306 .06075 .69648 .06486 .70379 .06071 .70041 .05683 Metetra
.741 .841 .926 r
.70041 .05683 .70379 .06071 .71111 .05641 .70776 .05268 Metetra
.519 .783 .992 r
.05094 .29881 .05562 .30152 .06125 .30075 .0566 .29783 Metetra
.56 .784 .982 r
.0566 .29783 .06125 .30075 .06692 .29976 .06232 .29659 Metetra
.599 .781 .967 r
.06232 .29659 .06692 .29976 .07265 .2985 .0681 .29505 Metetra
.633 .774 .948 r
.0681 .29505 .07265 .2985 .07843 .29695 .07393 .29319 Metetra
.661 .763 .926 r
.07393 .29319 .07843 .29695 .08428 .29508 .07984 .29096 Metetra
.683 .75 .902 r
.07984 .29096 .08428 .29508 .09019 .29286 .08581 .28836 Metetra
.7 .736 .879 r
.08581 .28836 .09019 .29286 .09617 .29028 .09185 .28538 Metetra
.711 .722 .858 r
.09185 .28538 .09617 .29028 .1022 .28732 .09794 .28206 Metetra
.718 .71 .841 r
.09794 .28206 .1022 .28732 .1083 .28401 .10408 .27844 Metetra
.723 .699 .828 r
.10408 .27844 .1083 .28401 .11444 .2804 .11026 .27459 Metetra
.725 .692 .818 r
.11026 .27459 .11444 .2804 .12063 .27654 .11648 .27057 Metetra
.726 .687 .813 r
.11648 .27057 .12063 .27654 .12684 .27251 .12271 .26645 Metetra
.726 .685 .811 r
.12271 .26645 .12684 .27251 .13308 .26838 .12895 .2623 Metetra
.725 .684 .811 r
.12895 .2623 .13308 .26838 .13932 .26422 .1352 .25816 Metetra
.723 .685 .813 r
.1352 .25816 .13932 .26422 .14557 .26008 .14145 .25408 Metetra
.721 .686 .816 r
.14145 .25408 .14557 .26008 .15182 .25601 .14769 .25008 Metetra
.718 .688 .82 r
.14769 .25008 .15182 .25601 .15806 .25203 .15393 .2462 Metetra
.715 .691 .826 r
.15393 .2462 .15806 .25203 .1643 .24816 .16016 .24246 Metetra
.711 .695 .833 r
.16016 .24246 .1643 .24816 .17053 .24443 .16638 .23888 Metetra
.706 .699 .841 r
.16638 .23888 .17053 .24443 .17675 .24085 .17259 .23545 Metetra
.701 .704 .849 r
.17259 .23545 .17675 .24085 .18296 .23743 .17879 .23219 Metetra
.696 .709 .858 r
.17879 .23219 .18296 .23743 .18916 .23417 .18498 .22908 Metetra
.691 .715 .867 r
.18498 .22908 .18916 .23417 .19536 .23106 .19117 .22611 Metetra
.687 .72 .874 r
.19117 .22611 .19536 .23106 .20156 .2281 .19736 .22325 Metetra
.683 .724 .881 r
.19736 .22325 .20156 .2281 .20775 .22525 .20355 .2205 Metetra
.679 .728 .887 r
.20355 .2205 .20775 .22525 .21394 .2225 .20975 .21782 Metetra
.676 .73 .891 r
.20975 .21782 .21394 .2225 .22014 .21983 .21595 .2152 Metetra
.673 .733 .895 r
.21595 .2152 .22014 .21983 .22635 .21722 .22216 .21264 Metetra
.671 .735 .898 r
.22216 .21264 .22635 .21722 .23256 .21466 .22838 .21011 Metetra
.669 .736 .901 r
.22838 .21011 .23256 .21466 .23879 .21214 .23461 .20762 Metetra
.667 .738 .903 r
.23461 .20762 .23879 .21214 .24503 .20965 .24085 .20514 Metetra
.666 .739 .904 r
.24085 .20514 .24503 .20965 .25127 .20718 .2471 .20269 Metetra
.665 .74 .905 r
.2471 .20269 .25127 .20718 .25754 .20473 .25337 .20024 Metetra
.665 .74 .906 r
.25337 .20024 .25754 .20473 .26381 .20228 .25965 .19779 Metetra
.664 .741 .907 r
.25965 .19779 .26381 .20228 .2701 .19984 .26595 .19535 Metetra
.664 .741 .907 r
.26595 .19535 .2701 .19984 .2764 .19741 .27226 .19291 Metetra
.664 .741 .907 r
.27226 .19291 .2764 .19741 .28272 .19497 .27859 .19046 Metetra
.664 .741 .908 r
.27859 .19046 .28272 .19497 .28905 .19252 .28493 .18801 Metetra
.664 .741 .908 r
.28493 .18801 .28905 .19252 .2954 .19008 .29129 .18555 Metetra
.664 .741 .908 r
.29129 .18555 .2954 .19008 .30176 .18763 .29766 .18309 Metetra
.664 .741 .908 r
.29766 .18309 .30176 .18763 .30814 .18517 .30405 .18062 Metetra
.664 .741 .908 r
.30405 .18062 .30814 .18517 .31453 .18271 .31045 .17815 Metetra
.664 .741 .908 r
.31045 .17815 .31453 .18271 .32094 .18024 .31687 .17568 Metetra
.664 .741 .908 r
.31687 .17568 .32094 .18024 .32737 .17777 .3233 .17319 Metetra
.664 .741 .908 r
.3233 .17319 .32737 .17777 .33381 .17529 .32975 .1707 Metetra
.664 .741 .908 r
.32975 .1707 .33381 .17529 .34026 .17281 .33622 .16821 Metetra
.664 .741 .908 r
.33622 .16821 .34026 .17281 .34674 .17032 .3427 .16571 Metetra
.664 .741 .908 r
.3427 .16571 .34674 .17032 .35322 .16783 .3492 .1632 Metetra
.664 .741 .908 r
.3492 .1632 .35322 .16783 .35973 .16532 .35571 .16069 Metetra
.664 .741 .908 r
.35571 .16069 .35973 .16532 .36625 .16281 .36224 .15817 Metetra
.664 .741 .908 r
.36224 .15817 .36625 .16281 .37278 .1603 .36878 .15564 Metetra
.664 .741 .908 r
.36878 .15564 .37278 .1603 .37933 .15778 .37534 .15311 Metetra
.664 .741 .908 r
.37534 .15311 .37933 .15778 .3859 .15525 .38192 .15057 Metetra
.664 .741 .908 r
.38192 .15057 .3859 .15525 .39248 .15272 .38851 .14803 Metetra
.664 .741 .908 r
.38851 .14803 .39248 .15272 .39908 .15018 .39512 .14548 Metetra
.664 .741 .908 r
.39512 .14548 .39908 .15018 .4057 .14764 .40175 .14292 Metetra
.664 .741 .908 r
.40175 .14292 .4057 .14764 .41233 .14509 .40839 .14036 Metetra
.663 .741 .908 r
.40839 .14036 .41233 .14509 .41898 .14253 .41505 .13779 Metetra
.663 .741 .908 r
.41505 .13779 .41898 .14253 .42564 .13997 .42173 .13522 Metetra
.663 .741 .908 r
.42173 .13522 .42564 .13997 .43232 .1374 .42842 .13264 Metetra
.663 .741 .908 r
.42842 .13264 .43232 .1374 .43902 .13483 .43513 .13005 Metetra
.663 .741 .908 r
.43513 .13005 .43902 .13483 .44574 .13225 .44185 .12746 Metetra
.663 .741 .908 r
.44185 .12746 .44574 .13225 .45247 .12967 .44859 .12486 Metetra
.663 .741 .908 r
.44859 .12486 .45247 .12967 .45921 .12709 .45535 .12227 Metetra
.663 .74 .908 r
.45535 .12227 .45921 .12709 .46598 .12451 .46213 .11967 Metetra
.662 .74 .908 r
.46213 .11967 .46598 .12451 .47276 .12194 .46892 .11707 Metetra
.661 .739 .907 r
.46892 .11707 .47276 .12194 .47956 .11938 .47573 .11448 Metetra
.66 .737 .907 r
.47573 .11448 .47956 .11938 .48637 .11683 .48255 .1119 Metetra
.659 .736 .907 r
.48255 .1119 .48637 .11683 .4932 .11431 .4894 .10934 Metetra
.657 .734 .906 r
.4894 .10934 .4932 .11431 .50005 .11181 .49626 .10679 Metetra
.655 .731 .906 r
.49626 .10679 .50005 .11181 .50692 .10935 .50313 .10428 Metetra
.652 .728 .905 r
.50313 .10428 .50692 .10935 .5138 .10695 .51003 .10181 Metetra
.648 .724 .904 r
.51003 .10181 .5138 .10695 .52071 .10461 .51694 .09939 Metetra
.643 .719 .903 r
.51694 .09939 .52071 .10461 .52763 .10237 .52387 .09704 Metetra
.637 .712 .901 r
.52387 .09704 .52763 .10237 .53457 .10023 .53083 .09477 Metetra
.631 .704 .898 r
.53083 .09477 .53457 .10023 .54153 .0982 .5378 .09261 Metetra
.623 .695 .896 r
.5378 .09261 .54153 .0982 .54852 .0963 .54479 .09057 Metetra
.614 .685 .893 r
.54479 .09057 .54852 .0963 .55553 .09454 .5518 .08865 Metetra
.606 .675 .89 r
.5518 .08865 .55553 .09454 .56256 .0929 .55884 .08687 Metetra
.597 .665 .887 r
.55884 .08687 .56256 .0929 .56961 .09141 .5659 .08523 Metetra
.588 .655 .883 r
.5659 .08523 .56961 .09141 .5767 .09006 .57299 .08372 Metetra
.58 .646 .88 r
.57299 .08372 .5767 .09006 .58381 .08884 .58011 .08236 Metetra
.572 .636 .876 r
.58011 .08236 .58381 .08884 .59095 .08774 .58725 .08111 Metetra
.565 .627 .873 r
.58725 .08111 .59095 .08774 .59811 .08673 .59442 .07999 Metetra
.56 .621 .869 r
.59442 .07999 .59811 .08673 .60531 .08577 .60162 .07894 Metetra
.557 .617 .868 r
.60162 .07894 .60531 .08577 .61253 .08481 .60885 .07795 Metetra
.557 .616 .867 r
.60885 .07795 .61253 .08481 .61978 .08377 .6161 .07695 Metetra
.56 .62 .869 r
.6161 .07695 .61978 .08377 .62705 .08259 .62339 .0759 Metetra
.567 .629 .872 r
.62339 .0759 .62705 .08259 .63434 .08124 .63069 .07471 Metetra
.577 .641 .877 r
.63069 .07471 .63434 .08124 .64165 .07967 .63802 .07335 Metetra
.59 .656 .883 r
.63802 .07335 .64165 .07967 .64897 .07786 .64536 .07176 Metetra
.605 .674 .889 r
.64536 .07176 .64897 .07786 .65631 .07577 .65271 .06992 Metetra
.621 .692 .895 r
.65271 .06992 .65631 .07577 .66365 .0734 .66008 .0678 Metetra
.638 .712 .901 r
.66008 .0678 .66365 .0734 .671 .07072 .66746 .06538 Metetra
.656 .733 .906 r
.66746 .06538 .671 .07072 .67835 .06772 .67484 .06266 Metetra
.675 .755 .911 r
.67484 .06266 .67835 .06772 .68571 .06439 .68222 .05963 Metetra
.693 .778 .916 r
.68222 .05963 .68571 .06439 .69306 .06075 .68961 .05628 Metetra
.71 .8 .921 r
.68961 .05628 .69306 .06075 .70041 .05683 .69699 .05263 Metetra
.726 .821 .924 r
.69699 .05263 .70041 .05683 .70776 .05268 .70437 .04871 Metetra
.558 .785 .984 r
.04627 .29591 .05094 .29881 .0566 .29783 .05197 .29468 Metetra
.597 .782 .969 r
.05197 .29468 .0566 .29783 .06232 .29659 .05774 .29315 Metetra
.632 .775 .949 r
.05774 .29315 .06232 .29659 .0681 .29505 .06357 .29128 Metetra
.662 .763 .925 r
.06357 .29128 .0681 .29505 .07393 .29319 .06947 .28904 Metetra
.684 .75 .901 r
.06947 .28904 .07393 .29319 .07984 .29096 .07544 .28642 Metetra
.7 .735 .878 r
.07544 .28642 .07984 .29096 .08581 .28836 .08147 .28343 Metetra
.711 .721 .857 r
.08147 .28343 .08581 .28836 .09185 .28538 .08756 .2801 Metetra
.718 .709 .841 r
.08756 .2801 .09185 .28538 .09794 .28206 .0937 .27649 Metetra
.722 .7 .828 r
.0937 .27649 .09794 .28206 .10408 .27844 .09988 .27264 Metetra
.725 .693 .819 r
.09988 .27264 .10408 .27844 .11026 .27459 .10609 .26864 Metetra
.726 .688 .814 r
.10609 .26864 .11026 .27459 .11648 .27057 .11232 .26453 Metetra
.726 .686 .811 r
.11232 .26453 .11648 .27057 .12271 .26645 .11856 .26038 Metetra
.725 .685 .811 r
.11856 .26038 .12271 .26645 .12895 .2623 .12481 .25623 Metetra
.724 .685 .812 r
.12481 .25623 .12895 .2623 .1352 .25816 .13106 .25214 Metetra
.721 .686 .815 r
.13106 .25214 .1352 .25816 .14145 .25408 .1373 .24813 Metetra
.718 .688 .82 r
.1373 .24813 .14145 .25408 .14769 .25008 .14354 .24424 Metetra
.715 .691 .826 r
.14354 .24424 .14769 .25008 .15393 .2462 .14977 .24049 Metetra
.71 .694 .833 r
.14977 .24049 .15393 .2462 .16016 .24246 .15599 .2369 Metetra
.706 .699 .841 r
.15599 .2369 .16016 .24246 .16638 .23888 .16219 .23348 Metetra
.701 .704 .85 r
.16219 .23348 .16638 .23888 .17259 .23545 .16839 .23021 Metetra
.696 .71 .858 r
.16839 .23021 .17259 .23545 .17879 .23219 .17458 .2271 Metetra
.691 .715 .867 r
.17458 .2271 .17879 .23219 .18498 .22908 .18076 .22412 Metetra
.687 .72 .874 r
.18076 .22412 .18498 .22908 .19117 .22611 .18695 .22126 Metetra
.683 .724 .881 r
.18695 .22126 .19117 .22611 .19736 .22325 .19314 .21849 Metetra
.679 .727 .886 r
.19314 .21849 .19736 .22325 .20355 .2205 .19933 .2158 Metetra
.676 .73 .891 r
.19933 .2158 .20355 .2205 .20975 .21782 .20552 .21318 Metetra
.673 .733 .895 r
.20552 .21318 .20975 .21782 .21595 .2152 .21173 .21061 Metetra
.67 .735 .898 r
.21173 .21061 .21595 .2152 .22216 .21264 .21794 .20808 Metetra
.669 .736 .901 r
.21794 .20808 .22216 .21264 .22838 .21011 .22416 .20558 Metetra
.667 .738 .903 r
.22416 .20558 .22838 .21011 .23461 .20762 .2304 .20311 Metetra
.666 .739 .904 r
.2304 .20311 .23461 .20762 .24085 .20514 .23665 .20064 Metetra
.665 .74 .905 r
.23665 .20064 .24085 .20514 .2471 .20269 .24291 .19819 Metetra
.665 .74 .906 r
.24291 .19819 .2471 .20269 .25337 .20024 .24919 .19574 Metetra
.664 .741 .907 r
.24919 .19574 .25337 .20024 .25965 .19779 .25548 .19329 Metetra
.664 .741 .907 r
.25548 .19329 .25965 .19779 .26595 .19535 .26178 .19084 Metetra
.664 .741 .907 r
.26178 .19084 .26595 .19535 .27226 .19291 .2681 .18839 Metetra
.664 .741 .908 r
.2681 .18839 .27226 .19291 .27859 .19046 .27444 .18593 Metetra
.664 .741 .908 r
.27444 .18593 .27859 .19046 .28493 .18801 .28079 .18347 Metetra
.664 .741 .908 r
.28079 .18347 .28493 .18801 .29129 .18555 .28716 .18101 Metetra
.664 .741 .908 r
.28716 .18101 .29129 .18555 .29766 .18309 .29354 .17853 Metetra
.664 .741 .908 r
.29354 .17853 .29766 .18309 .30405 .18062 .29993 .17606 Metetra
.664 .741 .908 r
.29993 .17606 .30405 .18062 .31045 .17815 .30635 .17358 Metetra
.664 .741 .908 r
.30635 .17358 .31045 .17815 .31687 .17568 .31278 .17109 Metetra
.664 .741 .908 r
.31278 .17109 .31687 .17568 .3233 .17319 .31922 .16859 Metetra
.664 .741 .908 r
.31922 .16859 .3233 .17319 .32975 .1707 .32568 .16609 Metetra
.664 .741 .908 r
.32568 .16609 .32975 .1707 .33622 .16821 .33215 .16359 Metetra
.664 .741 .908 r
.33215 .16359 .33622 .16821 .3427 .16571 .33864 .16107 Metetra
.664 .741 .908 r
.33864 .16107 .3427 .16571 .3492 .1632 .34515 .15856 Metetra
.664 .741 .908 r
.34515 .15856 .3492 .1632 .35571 .16069 .35167 .15603 Metetra
.664 .741 .908 r
.35167 .15603 .35571 .16069 .36224 .15817 .35821 .1535 Metetra
.664 .741 .908 r
.35821 .1535 .36224 .15817 .36878 .15564 .36477 .15096 Metetra
.664 .741 .908 r
.36477 .15096 .36878 .15564 .37534 .15311 .37134 .14842 Metetra
.664 .741 .908 r
.37134 .14842 .37534 .15311 .38192 .15057 .37793 .14587 Metetra
.664 .741 .908 r
.37793 .14587 .38192 .15057 .38851 .14803 .38453 .14332 Metetra
.664 .741 .908 r
.38453 .14332 .38851 .14803 .39512 .14548 .39115 .14075 Metetra
.664 .741 .908 r
.39115 .14075 .39512 .14548 .40175 .14292 .39778 .13818 Metetra
.664 .741 .908 r
.39778 .13818 .40175 .14292 .40839 .14036 .40444 .13561 Metetra
.664 .741 .908 r
.40444 .13561 .40839 .14036 .41505 .13779 .41111 .13303 Metetra
.664 .741 .908 r
.41111 .13303 .41505 .13779 .42173 .13522 .41779 .13044 Metetra
.663 .741 .908 r
.41779 .13044 .42173 .13522 .42842 .13264 .42449 .12785 Metetra
.663 .741 .908 r
.42449 .12785 .42842 .13264 .43513 .13005 .43121 .12525 Metetra
.663 .741 .908 r
.43121 .12525 .43513 .13005 .44185 .12746 .43795 .12265 Metetra
.663 .741 .908 r
.43795 .12265 .44185 .12746 .44859 .12486 .4447 .12004 Metetra
.663 .741 .908 r
.4447 .12004 .44859 .12486 .45535 .12227 .45147 .11742 Metetra
.663 .741 .908 r
.45147 .11742 .45535 .12227 .46213 .11967 .45826 .11481 Metetra
.663 .74 .908 r
.45826 .11481 .46213 .11967 .46892 .11707 .46506 .11219 Metetra
.662 .74 .908 r
.46506 .11219 .46892 .11707 .47573 .11448 .47188 .10958 Metetra
.661 .739 .907 r
.47188 .10958 .47573 .11448 .48255 .1119 .47872 .10697 Metetra
.66 .737 .907 r
.47872 .10697 .48255 .1119 .4894 .10934 .48557 .10437 Metetra
.659 .736 .907 r
.48557 .10437 .4894 .10934 .49626 .10679 .49244 .10179 Metetra
.657 .734 .906 r
.49244 .10179 .49626 .10679 .50313 .10428 .49933 .09923 Metetra
.654 .731 .906 r
.49933 .09923 .50313 .10428 .51003 .10181 .50624 .0967 Metetra
.652 .728 .905 r
.50624 .0967 .51003 .10181 .51694 .09939 .51316 .09421 Metetra
.648 .724 .904 r
.51316 .09421 .51694 .09939 .52387 .09704 .5201 .09177 Metetra
.643 .718 .903 r
.5201 .09177 .52387 .09704 .53083 .09477 .52706 .0894 Metetra
.637 .712 .901 r
.52706 .0894 .53083 .09477 .5378 .09261 .53405 .08712 Metetra
.631 .704 .899 r
.53405 .08712 .5378 .09261 .54479 .09057 .54105 .08494 Metetra
.623 .695 .896 r
.54105 .08494 .54479 .09057 .5518 .08865 .54807 .08288 Metetra
.614 .685 .893 r
.54807 .08288 .5518 .08865 .55884 .08687 .55511 .08094 Metetra
.606 .675 .89 r
.55511 .08094 .55884 .08687 .5659 .08523 .56218 .07915 Metetra
.597 .665 .886 r
.56218 .07915 .5659 .08523 .57299 .08372 .56928 .07749 Metetra
.588 .655 .883 r
.56928 .07749 .57299 .08372 .58011 .08236 .5764 .07598 Metetra
.58 .645 .88 r
.5764 .07598 .58011 .08236 .58725 .08111 .58354 .07459 Metetra
.572 .636 .876 r
.58354 .07459 .58725 .08111 .59442 .07999 .59072 .07333 Metetra
.566 .628 .873 r
.59072 .07333 .59442 .07999 .60162 .07894 .59792 .07218 Metetra
.561 .622 .87 r
.59792 .07218 .60162 .07894 .60885 .07795 .60516 .07111 Metetra
.558 .618 .868 r
.60516 .07111 .60885 .07795 .6161 .07695 .61242 .07008 Metetra
.558 .617 .868 r
.61242 .07008 .6161 .07695 .62339 .0759 .61971 .06905 Metetra
.561 .621 .869 r
.61971 .06905 .62339 .0759 .63069 .07471 .62702 .06797 Metetra
.567 .628 .872 r
.62702 .06797 .63069 .07471 .63802 .07335 .63436 .06676 Metetra
.577 .64 .877 r
.63436 .06676 .63802 .07335 .64536 .07176 .64172 .06538 Metetra
.59 .655 .883 r
.64172 .06538 .64536 .07176 .65271 .06992 .64909 .06378 Metetra
.605 .673 .889 r
.64909 .06378 .65271 .06992 .66008 .0678 .65648 .06192 Metetra
.621 .693 .895 r
.65648 .06192 .66008 .0678 .66746 .06538 .66388 .05977 Metetra
.639 .714 .902 r
.66388 .05977 .66746 .06538 .67484 .06266 .67129 .05731 Metetra
.657 .735 .907 r
.67129 .05731 .67484 .06266 .68222 .05963 .6787 .05455 Metetra
.675 .757 .912 r
.6787 .05455 .68222 .05963 .68961 .05628 .68612 .05148 Metetra
.693 .778 .917 r
.68612 .05148 .68961 .05628 .69699 .05263 .69353 .04811 Metetra
.71 .799 .92 r
.69353 .04811 .69699 .05263 .70437 .04871 .70095 .04445 Metetra
.597 .783 .969 r
.0416 .29277 .04627 .29591 .05197 .29468 .04736 .29123 Metetra
.633 .775 .949 r
.04736 .29123 .05197 .29468 .05774 .29315 .05318 .28935 Metetra
.662 .763 .925 r
.05318 .28935 .05774 .29315 .06357 .29128 .05908 .2871 Metetra
.684 .749 .9 r
.05908 .2871 .06357 .29128 .06947 .28904 .06504 .28447 Metetra
.7 .734 .877 r
.06504 .28447 .06947 .28904 .07544 .28642 .07107 .28148 Metetra
.711 .72 .857 r
.07107 .28148 .07544 .28642 .08147 .28343 .07716 .27815 Metetra
.718 .709 .841 r
.07716 .27815 .08147 .28343 .08756 .2801 .08329 .27454 Metetra
.722 .7 .829 r
.08329 .27454 .08756 .2801 .0937 .27649 .08947 .27071 Metetra
.725 .694 .82 r
.08947 .27071 .0937 .27649 .09988 .27264 .09568 .26671 Metetra
.726 .689 .815 r
.09568 .26671 .09988 .27264 .10609 .26864 .10191 .2626 Metetra
.726 .686 .812 r
.10191 .2626 .10609 .26864 .11232 .26453 .10815 .25845 Metetra
.725 .685 .811 r
.10815 .25845 .11232 .26453 .11856 .26038 .1144 .25429 Metetra
.724 .685 .812 r
.1144 .25429 .11856 .26038 .12481 .25623 .12065 .25019 Metetra
.721 .685 .815 r
.12065 .25019 .12481 .25623 .13106 .25214 .12689 .24617 Metetra
.718 .687 .819 r
.12689 .24617 .13106 .25214 .1373 .24813 .13313 .24227 Metetra
.715 .69 .826 r
.13313 .24227 .1373 .24813 .14354 .24424 .13936 .23852 Metetra
.71 .694 .833 r
.13936 .23852 .14354 .24424 .14977 .24049 .14557 .23493 Metetra
.706 .699 .841 r
.14557 .23493 .14977 .24049 .15599 .2369 .15178 .2315 Metetra
.701 .704 .85 r
.15178 .2315 .15599 .2369 .16219 .23348 .15797 .22823 Metetra
.696 .71 .859 r
.15797 .22823 .16219 .23348 .16839 .23021 .16416 .22511 Metetra
.692 .715 .867 r
.16416 .22511 .16839 .23021 .17458 .2271 .17034 .22212 Metetra
.687 .72 .874 r
.17034 .22212 .17458 .2271 .18076 .22412 .17652 .21925 Metetra
.683 .724 .881 r
.17652 .21925 .18076 .22412 .18695 .22126 .1827 .21648 Metetra
.679 .727 .886 r
.1827 .21648 .18695 .22126 .19314 .21849 .18889 .21378 Metetra
.676 .73 .891 r
.18889 .21378 .19314 .21849 .19933 .2158 .19508 .21116 Metetra
.673 .733 .895 r
.19508 .21116 .19933 .2158 .20552 .21318 .20128 .20858 Metetra
.67 .735 .898 r
.20128 .20858 .20552 .21318 .21173 .21061 .20748 .20605 Metetra
.669 .736 .901 r
.20748 .20605 .21173 .21061 .21794 .20808 .2137 .20354 Metetra
.667 .738 .903 r
.2137 .20354 .21794 .20808 .22416 .20558 .21993 .20106 Metetra
.666 .739 .904 r
.21993 .20106 .22416 .20558 .2304 .20311 .22617 .19859 Metetra
.665 .74 .905 r
.22617 .19859 .2304 .20311 .23665 .20064 .23243 .19613 Metetra
.665 .74 .906 r
.23243 .19613 .23665 .20064 .24291 .19819 .2387 .19368 Metetra
.664 .74 .907 r
.2387 .19368 .24291 .19819 .24919 .19574 .24499 .19123 Metetra
.664 .741 .907 r
.24499 .19123 .24919 .19574 .25548 .19329 .25129 .18877 Metetra
.664 .741 .907 r
.25129 .18877 .25548 .19329 .26178 .19084 .2576 .18631 Metetra
.664 .741 .908 r
.2576 .18631 .26178 .19084 .2681 .18839 .26393 .18385 Metetra
.664 .741 .908 r
.26393 .18385 .2681 .18839 .27444 .18593 .27027 .18139 Metetra
.664 .741 .908 r
.27027 .18139 .27444 .18593 .28079 .18347 .27663 .17892 Metetra
.664 .741 .908 r
.27663 .17892 .28079 .18347 .28716 .18101 .28301 .17644 Metetra
.664 .741 .908 r
.28301 .17644 .28716 .18101 .29354 .17853 .2894 .17396 Metetra
.664 .741 .908 r
.2894 .17396 .29354 .17853 .29993 .17606 .2958 .17147 Metetra
.664 .741 .908 r
.2958 .17147 .29993 .17606 .30635 .17358 .30223 .16898 Metetra
.664 .741 .908 r
.30223 .16898 .30635 .17358 .31278 .17109 .30866 .16648 Metetra
.664 .741 .908 r
.30866 .16648 .31278 .17109 .31922 .16859 .31512 .16397 Metetra
.664 .741 .908 r
.31512 .16397 .31922 .16859 .32568 .16609 .32159 .16146 Metetra
.664 .741 .908 r
.32159 .16146 .32568 .16609 .33215 .16359 .32807 .15894 Metetra
.664 .741 .908 r
.32807 .15894 .33215 .16359 .33864 .16107 .33457 .15642 Metetra
.664 .741 .908 r
.33457 .15642 .33864 .16107 .34515 .15856 .34109 .15389 Metetra
.664 .741 .908 r
.34109 .15389 .34515 .15856 .35167 .15603 .34762 .15135 Metetra
.664 .741 .908 r
.34762 .15135 .35167 .15603 .35821 .1535 .35417 .14881 Metetra
.664 .741 .908 r
.35417 .14881 .35821 .1535 .36477 .15096 .36073 .14626 Metetra
.664 .741 .908 r
.36073 .14626 .36477 .15096 .37134 .14842 .36731 .14371 Metetra
.664 .741 .908 r
.36731 .14371 .37134 .14842 .37793 .14587 .37391 .14115 Metetra
.664 .741 .908 r
.37391 .14115 .37793 .14587 .38453 .14332 .38052 .13858 Metetra
.664 .741 .908 r
.38052 .13858 .38453 .14332 .39115 .14075 .38715 .13601 Metetra
.664 .741 .908 r
.38715 .13601 .39115 .14075 .39778 .13818 .3938 .13343 Metetra
.664 .741 .908 r
.3938 .13343 .39778 .13818 .40444 .13561 .40046 .13084 Metetra
.664 .741 .908 r
.40046 .13084 .40444 .13561 .41111 .13303 .40714 .12825 Metetra
.664 .741 .908 r
.40714 .12825 .41111 .13303 .41779 .13044 .41384 .12565 Metetra
.664 .741 .908 r
.41384 .12565 .41779 .13044 .42449 .12785 .42055 .12304 Metetra
.663 .741 .908 r
.42055 .12304 .42449 .12785 .43121 .12525 .42728 .12043 Metetra
.663 .741 .908 r
.42728 .12043 .43121 .12525 .43795 .12265 .43403 .11781 Metetra
.663 .741 .908 r
.43403 .11781 .43795 .12265 .4447 .12004 .44079 .11519 Metetra
.663 .741 .908 r
.44079 .11519 .4447 .12004 .45147 .11742 .44757 .11256 Metetra
.663 .741 .908 r
.44757 .11256 .45147 .11742 .45826 .11481 .45437 .10993 Metetra
.663 .741 .908 r
.45437 .10993 .45826 .11481 .46506 .11219 .46118 .1073 Metetra
.662 .74 .908 r
.46118 .1073 .46506 .11219 .47188 .10958 .46801 .10466 Metetra
.662 .74 .908 r
.46801 .10466 .47188 .10958 .47872 .10697 .47486 .10203 Metetra
.661 .739 .907 r
.47486 .10203 .47872 .10697 .48557 .10437 .48173 .0994 Metetra
.66 .737 .907 r
.48173 .0994 .48557 .10437 .49244 .10179 .48861 .09678 Metetra
.659 .736 .907 r
.48861 .09678 .49244 .10179 .49933 .09923 .49551 .09418 Metetra
.657 .734 .906 r
.49551 .09418 .49933 .09923 .50624 .0967 .50243 .0916 Metetra
.654 .731 .906 r
.50243 .0916 .50624 .0967 .51316 .09421 .50936 .08906 Metetra
.651 .728 .905 r
.50936 .08906 .51316 .09421 .5201 .09177 .51631 .08655 Metetra
.648 .723 .904 r
.51631 .08655 .5201 .09177 .52706 .0894 .52329 .0841 Metetra
.643 .718 .903 r
.52329 .0841 .52706 .0894 .53405 .08712 .53028 .08172 Metetra
.637 .712 .901 r
.53028 .08172 .53405 .08712 .54105 .08494 .53729 .07942 Metetra
.631 .704 .899 r
.53729 .07942 .54105 .08494 .54807 .08288 .54432 .07722 Metetra
.623 .695 .896 r
.54432 .07722 .54807 .08288 .55511 .08094 .55137 .07513 Metetra
.614 .685 .893 r
.55137 .07513 .55511 .08094 .56218 .07915 .55845 .07318 Metetra
.606 .675 .89 r
.55845 .07318 .56218 .07915 .56928 .07749 .56555 .07137 Metetra
.596 .664 .886 r
.56555 .07137 .56928 .07749 .5764 .07598 .57267 .0697 Metetra
.588 .654 .883 r
.57267 .0697 .5764 .07598 .58354 .07459 .57983 .06817 Metetra
.579 .644 .879 r
.57983 .06817 .58354 .07459 .59072 .07333 .58701 .06677 Metetra
.572 .636 .876 r
.58701 .06677 .59072 .07333 .59792 .07218 .59421 .06549 Metetra
.566 .628 .873 r
.59421 .06549 .59792 .07218 .60516 .07111 .60145 .06432 Metetra
.561 .623 .871 r
.60145 .06432 .60516 .07111 .61242 .07008 .60872 .06322 Metetra
.559 .619 .869 r
.60872 .06322 .61242 .07008 .61971 .06905 .61601 .06216 Metetra
.559 .619 .868 r
.61601 .06216 .61971 .06905 .62702 .06797 .62333 .0611 Metetra
.561 .622 .869 r
.62333 .0611 .62702 .06797 .63436 .06676 .63068 .05998 Metetra
.568 .629 .872 r
.63068 .05998 .63436 .06676 .64172 .06538 .63805 .05875 Metetra
.577 .64 .876 r
.63805 .05875 .64172 .06538 .64909 .06378 .64544 .05735 Metetra
.59 .655 .882 r
.64544 .05735 .64909 .06378 .65648 .06192 .65285 .05573 Metetra
.605 .673 .889 r
.65285 .05573 .65648 .06192 .66388 .05977 .66028 .05385 Metetra
.622 .693 .895 r
.66028 .05385 .66388 .05977 .67129 .05731 .66771 .05167 Metetra
.64 .715 .902 r
.66771 .05167 .67129 .05731 .6787 .05455 .67515 .04919 Metetra
.658 .737 .908 r
.67515 .04919 .6787 .05455 .68612 .05148 .6826 .0464 Metetra
.676 .758 .913 r
.6826 .0464 .68612 .05148 .69353 .04811 .69004 .04329 Metetra
.694 .779 .917 r
.69004 .04329 .69353 .04811 .70095 .04445 .69749 .03989 Metetra
.634 .774 .948 r
.03696 .28931 .0416 .29277 .04736 .29123 .04278 .28742 Metetra
.663 .762 .924 r
.04278 .28742 .04736 .29123 .05318 .28935 .04867 .28515 Metetra
.684 .748 .899 r
.04867 .28515 .05318 .28935 .05908 .2871 .05463 .28252 Metetra
.7 .733 .877 r
.05463 .28252 .05908 .2871 .06504 .28447 .06065 .27952 Metetra
.71 .72 .857 r
.06065 .27952 .06504 .28447 .07107 .28148 .06673 .2762 Metetra
.717 .709 .842 r
.06673 .2762 .07107 .28148 .07716 .27815 .07287 .2726 Metetra
.722 .701 .83 r
.07287 .2726 .07716 .27815 .08329 .27454 .07904 .26877 Metetra
.725 .694 .821 r
.07904 .26877 .08329 .27454 .08947 .27071 .08525 .26478 Metetra
.726 .69 .815 r
.08525 .26478 .08947 .27071 .09568 .26671 .09147 .26067 Metetra
.726 .686 .812 r
.09147 .26067 .09568 .26671 .10191 .2626 .09772 .25651 Metetra
.725 .685 .811 r
.09772 .25651 .10191 .2626 .10815 .25845 .10397 .25234 Metetra
.724 .684 .812 r
.10397 .25234 .10815 .25845 .1144 .25429 .11022 .24823 Metetra
.721 .685 .815 r
.11022 .24823 .1144 .25429 .12065 .25019 .11646 .2442 Metetra
.718 .687 .819 r
.11646 .2442 .12065 .25019 .12689 .24617 .1227 .2403 Metetra
.714 .69 .826 r
.1227 .2403 .12689 .24617 .13313 .24227 .12892 .23654 Metetra
.71 .695 .833 r
.12892 .23654 .13313 .24227 .13936 .23852 .13514 .23295 Metetra
.706 .699 .841 r
.13514 .23295 .13936 .23852 .14557 .23493 .14134 .22952 Metetra
.701 .705 .85 r
.14134 .22952 .14557 .23493 .15178 .2315 .14753 .22625 Metetra
.696 .71 .859 r
.14753 .22625 .15178 .2315 .15797 .22823 .15371 .22312 Metetra
.692 .715 .867 r
.15371 .22312 .15797 .22823 .16416 .22511 .15989 .22012 Metetra
.687 .719 .874 r
.15989 .22012 .16416 .22511 .17034 .22212 .16607 .21724 Metetra
.683 .723 .88 r
.16607 .21724 .17034 .22212 .17652 .21925 .17224 .21446 Metetra
.679 .727 .886 r
.17224 .21446 .17652 .21925 .1827 .21648 .17842 .21176 Metetra
.676 .73 .891 r
.17842 .21176 .1827 .21648 .18889 .21378 .18461 .20913 Metetra
.673 .733 .895 r
.18461 .20913 .18889 .21378 .19508 .21116 .1908 .20655 Metetra
.67 .735 .898 r
.1908 .20655 .19508 .21116 .20128 .20858 .19701 .20401 Metetra
.669 .736 .901 r
.19701 .20401 .20128 .20858 .20748 .20605 .20322 .2015 Metetra
.667 .738 .903 r
.20322 .2015 .20748 .20605 .2137 .20354 .20944 .19901 Metetra
.666 .739 .904 r
.20944 .19901 .2137 .20354 .21993 .20106 .21568 .19654 Metetra
.665 .74 .905 r
.21568 .19654 .21993 .20106 .22617 .19859 .22193 .19408 Metetra
.665 .74 .906 r
.22193 .19408 .22617 .19859 .23243 .19613 .22819 .19162 Metetra
.664 .74 .907 r
.22819 .19162 .23243 .19613 .2387 .19368 .23447 .18916 Metetra
.664 .741 .907 r
.23447 .18916 .2387 .19368 .24499 .19123 .24076 .1867 Metetra
.664 .741 .907 r
.24076 .1867 .24499 .19123 .25129 .18877 .24707 .18423 Metetra
.664 .741 .908 r
.24707 .18423 .25129 .18877 .2576 .18631 .2534 .18177 Metetra
.664 .741 .908 r
.2534 .18177 .2576 .18631 .26393 .18385 .25973 .1793 Metetra
.664 .741 .908 r
.25973 .1793 .26393 .18385 .27027 .18139 .26609 .17682 Metetra
.664 .741 .908 r
.26609 .17682 .27027 .18139 .27663 .17892 .27246 .17434 Metetra
.664 .741 .908 r
.27246 .17434 .27663 .17892 .28301 .17644 .27884 .17185 Metetra
.664 .741 .908 r
.27884 .17185 .28301 .17644 .2894 .17396 .28524 .16936 Metetra
.664 .741 .908 r
.28524 .16936 .2894 .17396 .2958 .17147 .29166 .16686 Metetra
.664 .741 .908 r
.29166 .16686 .2958 .17147 .30223 .16898 .29809 .16436 Metetra
.664 .741 .908 r
.29809 .16436 .30223 .16898 .30866 .16648 .30453 .16185 Metetra
.664 .741 .908 r
.30453 .16185 .30866 .16648 .31512 .16397 .311 .15933 Metetra
.664 .741 .908 r
.311 .15933 .31512 .16397 .32159 .16146 .31747 .15681 Metetra
.664 .741 .908 r
.31747 .15681 .32159 .16146 .32807 .15894 .32397 .15428 Metetra
.664 .741 .908 r
.32397 .15428 .32807 .15894 .33457 .15642 .33048 .15175 Metetra
.664 .741 .908 r
.33048 .15175 .33457 .15642 .34109 .15389 .33701 .1492 Metetra
.664 .741 .908 r
.33701 .1492 .34109 .15389 .34762 .15135 .34355 .14666 Metetra
.664 .741 .908 r
.34355 .14666 .34762 .15135 .35417 .14881 .35011 .1441 Metetra
.664 .741 .908 r
.35011 .1441 .35417 .14881 .36073 .14626 .35668 .14154 Metetra
.664 .741 .908 r
.35668 .14154 .36073 .14626 .36731 .14371 .36327 .13898 Metetra
.664 .741 .908 r
.36327 .13898 .36731 .14371 .37391 .14115 .36988 .1364 Metetra
.664 .741 .908 r
.36988 .1364 .37391 .14115 .38052 .13858 .3765 .13382 Metetra
.664 .741 .908 r
.3765 .13382 .38052 .13858 .38715 .13601 .38314 .13124 Metetra
.664 .741 .908 r
.38314 .13124 .38715 .13601 .3938 .13343 .3898 .12865 Metetra
.664 .741 .908 r
.3898 .12865 .3938 .13343 .40046 .13084 .39647 .12605 Metetra
.664 .741 .908 r
.39647 .12605 .40046 .13084 .40714 .12825 .40316 .12344 Metetra
.664 .741 .908 r
.40316 .12344 .40714 .12825 .41384 .12565 .40987 .12083 Metetra
.664 .741 .908 r
.40987 .12083 .41384 .12565 .42055 .12304 .41659 .11821 Metetra
.664 .741 .908 r
.41659 .11821 .42055 .12304 .42728 .12043 .42333 .11559 Metetra
.663 .741 .908 r
.42333 .11559 .42728 .12043 .43403 .11781 .43009 .11296 Metetra
.663 .741 .908 r
.43009 .11296 .43403 .11781 .44079 .11519 .43686 .11032 Metetra
.663 .741 .908 r
.43686 .11032 .44079 .11519 .44757 .11256 .44365 .10768 Metetra
.663 .741 .908 r
.44365 .10768 .44757 .11256 .45437 .10993 .45046 .10504 Metetra
.663 .741 .908 r
.45046 .10504 .45437 .10993 .46118 .1073 .45729 .10239 Metetra
.663 .741 .908 r
.45729 .10239 .46118 .1073 .46801 .10466 .46413 .09973 Metetra
.662 .74 .908 r
.46413 .09973 .46801 .10466 .47486 .10203 .47099 .09708 Metetra
.662 .74 .908 r
.47099 .09708 .47486 .10203 .48173 .0994 .47786 .09443 Metetra
.661 .739 .907 r
.47786 .09443 .48173 .0994 .48861 .09678 .48476 .09178 Metetra
.66 .737 .907 r
.48476 .09178 .48861 .09678 .49551 .09418 .49167 .08914 Metetra
.659 .736 .907 r
.49167 .08914 .49551 .09418 .50243 .0916 .4986 .08652 Metetra
.657 .734 .906 r
.4986 .08652 .50243 .0916 .50936 .08906 .50554 .08393 Metetra
.654 .731 .906 r
.50554 .08393 .50936 .08906 .51631 .08655 .51251 .08136 Metetra
.651 .727 .905 r
.51251 .08136 .51631 .08655 .52329 .0841 .51949 .07884 Metetra
.647 .723 .904 r
.51949 .07884 .52329 .0841 .53028 .08172 .52649 .07637 Metetra
.643 .718 .902 r
.52649 .07637 .53028 .08172 .53729 .07942 .53351 .07397 Metetra
.637 .711 .901 r
.53351 .07397 .53729 .07942 .54432 .07722 .54056 .07166 Metetra
.63 .704 .899 r
.54056 .07166 .54432 .07722 .55137 .07513 .54762 .06944 Metetra
.623 .695 .896 r
.54762 .06944 .55137 .07513 .55845 .07318 .5547 .06734 Metetra
.614 .685 .893 r
.5547 .06734 .55845 .07318 .56555 .07137 .56181 .06537 Metetra
.606 .675 .89 r
.56181 .06537 .56555 .07137 .57267 .0697 .56894 .06353 Metetra
.596 .664 .886 r
.56894 .06353 .57267 .0697 .57983 .06817 .5761 .06184 Metetra
.587 .654 .882 r
.5761 .06184 .57983 .06817 .58701 .06677 .58328 .0603 Metetra
.579 .644 .879 r
.58328 .0603 .58701 .06677 .59421 .06549 .59049 .05889 Metetra
.572 .636 .876 r
.59049 .05889 .59421 .06549 .60145 .06432 .59773 .05759 Metetra
.566 .628 .873 r
.59773 .05759 .60145 .06432 .60872 .06322 .605 .0564 Metetra
.561 .623 .871 r
.605 .0564 .60872 .06322 .61601 .06216 .6123 .05527 Metetra
.559 .62 .869 r
.6123 .05527 .61601 .06216 .62333 .0611 .61963 .05418 Metetra
.559 .62 .869 r
.61963 .05418 .62333 .0611 .63068 .05998 .62699 .05309 Metetra
.562 .623 .87 r
.62699 .05309 .63068 .05998 .63805 .05875 .63437 .05194 Metetra
.568 .629 .872 r
.63437 .05194 .63805 .05875 .64544 .05735 .64177 .05068 Metetra
.578 .64 .876 r
.64177 .05068 .64544 .05735 .65285 .05573 .6492 .04925 Metetra
.59 .655 .882 r
.6492 .04925 .65285 .05573 .66028 .05385 .65664 .04761 Metetra
.605 .673 .888 r
.65664 .04761 .66028 .05385 .66771 .05167 .6641 .04571 Metetra
.622 .693 .895 r
.6641 .04571 .66771 .05167 .67515 .04919 .67157 .04351 Metetra
.64 .715 .902 r
.67157 .04351 .67515 .04919 .6826 .0464 .67904 .041 Metetra
.659 .737 .908 r
.67904 .041 .6826 .0464 .69004 .04329 .68652 .03818 Metetra
.677 .759 .913 r
.68652 .03818 .69004 .04329 .69749 .03989 .694 .03505 Metetra
.663 .761 .923 r
.03235 .28547 .03696 .28931 .04278 .28742 .03824 .2832 Metetra
.684 .747 .899 r
.03824 .2832 .04278 .28742 .04867 .28515 .04419 .28056 Metetra
.699 .733 .877 r
.04419 .28056 .04867 .28515 .05463 .28252 .05021 .27756 Metetra
.71 .721 .858 r
.05021 .27756 .05463 .28252 .06065 .27952 .05629 .27425 Metetra
.717 .71 .842 r
.05629 .27425 .06065 .27952 .06673 .2762 .06242 .27065 Metetra
.722 .701 .83 r
.06242 .27065 .06673 .2762 .07287 .2726 .06859 .26683 Metetra
.725 .695 .821 r
.06859 .26683 .07287 .2726 .07904 .26877 .07479 .26284 Metetra
.726 .69 .815 r
.07479 .26284 .07904 .26877 .08525 .26478 .08102 .25873 Metetra
.726 .686 .812 r
.08102 .25873 .08525 .26478 .09147 .26067 .08727 .25456 Metetra
.725 .685 .811 r
.08727 .25456 .09147 .26067 .09772 .25651 .09352 .25039 Metetra
.724 .684 .812 r
.09352 .25039 .09772 .25651 .10397 .25234 .09977 .24627 Metetra
.721 .685 .815 r
.09977 .24627 .10397 .25234 .11022 .24823 .10601 .24224 Metetra
.718 .687 .819 r
.10601 .24224 .11022 .24823 .11646 .2442 .11225 .23833 Metetra
.714 .691 .826 r
.11225 .23833 .11646 .2442 .1227 .2403 .11847 .23457 Metetra
.71 .695 .833 r
.11847 .23457 .1227 .2403 .12892 .23654 .12468 .23097 Metetra
.706 .7 .842 r
.12468 .23097 .12892 .23654 .13514 .23295 .13088 .22753 Metetra
.701 .705 .85 r
.13088 .22753 .13514 .23295 .14134 .22952 .13707 .22425 Metetra
.697 .71 .858 r
.13707 .22425 .14134 .22952 .14753 .22625 .14325 .22112 Metetra
.692 .715 .866 r
.14325 .22112 .14753 .22625 .15371 .22312 .14942 .21812 Metetra
.687 .719 .874 r
.14942 .21812 .15371 .22312 .15989 .22012 .15559 .21523 Metetra
.683 .723 .88 r
.15559 .21523 .15989 .22012 .16607 .21724 .16177 .21244 Metetra
.679 .727 .886 r
.16177 .21244 .16607 .21724 .17224 .21446 .16794 .20973 Metetra
.676 .73 .891 r
.16794 .20973 .17224 .21446 .17842 .21176 .17412 .2071 Metetra
.673 .733 .895 r
.17412 .2071 .17842 .21176 .18461 .20913 .18031 .20451 Metetra
.67 .735 .898 r
.18031 .20451 .18461 .20913 .1908 .20655 .18651 .20197 Metetra
.669 .736 .901 r
.18651 .20197 .1908 .20655 .19701 .20401 .19271 .19945 Metetra
.667 .738 .903 r
.19271 .19945 .19701 .20401 .20322 .2015 .19893 .19696 Metetra
.666 .739 .904 r
.19893 .19696 .20322 .2015 .20944 .19901 .20516 .19448 Metetra
.665 .74 .905 r
.20516 .19448 .20944 .19901 .21568 .19654 .21141 .19201 Metetra
.665 .74 .906 r
.21141 .19201 .21568 .19654 .22193 .19408 .21766 .18955 Metetra
.664 .74 .907 r
.21766 .18955 .22193 .19408 .22819 .19162 .22394 .18708 Metetra
.664 .741 .907 r
.22394 .18708 .22819 .19162 .23447 .18916 .23022 .18462 Metetra
.664 .741 .907 r
.23022 .18462 .23447 .18916 .24076 .1867 .23652 .18215 Metetra
.664 .741 .908 r
.23652 .18215 .24076 .1867 .24707 .18423 .24284 .17968 Metetra
.664 .741 .908 r
.24284 .17968 .24707 .18423 .2534 .18177 .24917 .1772 Metetra
.664 .741 .908 r
.24917 .1772 .2534 .18177 .25973 .1793 .25552 .17472 Metetra
.664 .741 .908 r
.25552 .17472 .25973 .1793 .26609 .17682 .26188 .17224 Metetra
.664 .741 .908 r
.26188 .17224 .26609 .17682 .27246 .17434 .26826 .16975 Metetra
.664 .741 .908 r
.26826 .16975 .27246 .17434 .27884 .17185 .27465 .16725 Metetra
.664 .741 .908 r
.27465 .16725 .27884 .17185 .28524 .16936 .28106 .16474 Metetra
.664 .741 .908 r
.28106 .16474 .28524 .16936 .29166 .16686 .28749 .16224 Metetra
.664 .741 .908 r
.28749 .16224 .29166 .16686 .29809 .16436 .29393 .15972 Metetra
.664 .741 .908 r
.29393 .15972 .29809 .16436 .30453 .16185 .30038 .1572 Metetra
.664 .741 .908 r
.30038 .1572 .30453 .16185 .311 .15933 .30686 .15467 Metetra
.664 .741 .908 r
.30686 .15467 .311 .15933 .31747 .15681 .31334 .15214 Metetra
.664 .741 .908 r
.31334 .15214 .31747 .15681 .32397 .15428 .31985 .1496 Metetra
.664 .741 .908 r
.31985 .1496 .32397 .15428 .33048 .15175 .32637 .14705 Metetra
.664 .741 .908 r
.32637 .14705 .33048 .15175 .33701 .1492 .3329 .1445 Metetra
.664 .741 .908 r
.3329 .1445 .33701 .1492 .34355 .14666 .33946 .14194 Metetra
.664 .741 .908 r
.33946 .14194 .34355 .14666 .35011 .1441 .34603 .13937 Metetra
.664 .741 .908 r
.34603 .13937 .35011 .1441 .35668 .14154 .35261 .1368 Metetra
.664 .741 .908 r
.35261 .1368 .35668 .14154 .36327 .13898 .35921 .13422 Metetra
.664 .741 .908 r
.35921 .13422 .36327 .13898 .36988 .1364 .36583 .13164 Metetra
.664 .741 .908 r
.36583 .13164 .36988 .1364 .3765 .13382 .37246 .12904 Metetra
.664 .741 .908 r
.37246 .12904 .3765 .13382 .38314 .13124 .37911 .12645 Metetra
.664 .741 .908 r
.37911 .12645 .38314 .13124 .3898 .12865 .38578 .12384 Metetra
.664 .741 .908 r
.38578 .12384 .3898 .12865 .39647 .12605 .39246 .12123 Metetra
.664 .741 .908 r
.39246 .12123 .39647 .12605 .40316 .12344 .39916 .11862 Metetra
.664 .741 .908 r
.39916 .11862 .40316 .12344 .40987 .12083 .40588 .11599 Metetra
.664 .741 .908 r
.40588 .11599 .40987 .12083 .41659 .11821 .41261 .11336 Metetra
.664 .741 .908 r
.41261 .11336 .41659 .11821 .42333 .11559 .41936 .11073 Metetra
.664 .741 .908 r
.41936 .11073 .42333 .11559 .43009 .11296 .42613 .10808 Metetra
.663 .741 .908 r
.42613 .10808 .43009 .11296 .43686 .11032 .43292 .10543 Metetra
.663 .741 .908 r
.43292 .10543 .43686 .11032 .44365 .10768 .43972 .10278 Metetra
.663 .741 .908 r
.43972 .10278 .44365 .10768 .45046 .10504 .44654 .10012 Metetra
.663 .741 .908 r
.44654 .10012 .45046 .10504 .45729 .10239 .45337 .09745 Metetra
.663 .741 .908 r
.45337 .09745 .45729 .10239 .46413 .09973 .46023 .09478 Metetra
.663 .74 .908 r
.46023 .09478 .46413 .09973 .47099 .09708 .4671 .09211 Metetra
.662 .74 .908 r
.4671 .09211 .47099 .09708 .47786 .09443 .47398 .08944 Metetra
.662 .739 .908 r
.47398 .08944 .47786 .09443 .48476 .09178 .48089 .08677 Metetra
.661 .739 .907 r
.48089 .08677 .48476 .09178 .49167 .08914 .48781 .0841 Metetra
.66 .737 .907 r
.48781 .0841 .49167 .08914 .4986 .08652 .49475 .08145 Metetra
.659 .736 .907 r
.49475 .08145 .4986 .08652 .50554 .08393 .50171 .07881 Metetra
.657 .734 .906 r
.50171 .07881 .50554 .08393 .51251 .08136 .50868 .07619 Metetra
.654 .731 .906 r
.50868 .07619 .51251 .08136 .51949 .07884 .51568 .07361 Metetra
.651 .727 .905 r
.51568 .07361 .51949 .07884 .52649 .07637 .52269 .07107 Metetra
.647 .723 .904 r
.52269 .07107 .52649 .07637 .53351 .07397 .52972 .06859 Metetra
.642 .718 .902 r
.52972 .06859 .53351 .07397 .54056 .07166 .53677 .06617 Metetra
.637 .711 .901 r
.53677 .06617 .54056 .07166 .54762 .06944 .54385 .06384 Metetra
.63 .704 .899 r
.54385 .06384 .54762 .06944 .5547 .06734 .55094 .0616 Metetra
.623 .695 .896 r
.55094 .0616 .5547 .06734 .56181 .06537 .55805 .05949 Metetra
.614 .685 .893 r
.55805 .05949 .56181 .06537 .56894 .06353 .56519 .05749 Metetra
.606 .675 .89 r
.56519 .05749 .56894 .06353 .5761 .06184 .57236 .05564 Metetra
.596 .664 .886 r
.57236 .05564 .5761 .06184 .58328 .0603 .57954 .05393 Metetra
.587 .654 .882 r
.57954 .05393 .58328 .0603 .59049 .05889 .58676 .05237 Metetra
.579 .644 .879 r
.58676 .05237 .59049 .05889 .59773 .05759 .59401 .05094 Metetra
.572 .635 .876 r
.59401 .05094 .59773 .05759 .605 .0564 .60128 .04963 Metetra
.566 .628 .873 r
.60128 .04963 .605 .0564 .6123 .05527 .60858 .04841 Metetra
.562 .623 .871 r
.60858 .04841 .6123 .05527 .61963 .05418 .61592 .04727 Metetra
.56 .621 .87 r
.61592 .04727 .61963 .05418 .62699 .05309 .62328 .04615 Metetra
.56 .621 .869 r
.62328 .04615 .62699 .05309 .63437 .05194 .63067 .04503 Metetra
.563 .624 .87 r
.63067 .04503 .63437 .05194 .64177 .05068 .63808 .04384 Metetra
.569 .63 .873 r
.63808 .04384 .64177 .05068 .6492 .04925 .64552 .04255 Metetra
.578 .641 .877 r
.64552 .04255 .6492 .04925 .65664 .04761 .65298 .0411 Metetra
.59 .655 .882 r
.65298 .0411 .65664 .04761 .6641 .04571 .66046 .03943 Metetra
.605 .673 .888 r
.66046 .03943 .6641 .04571 .67157 .04351 .66795 .0375 Metetra
.622 .693 .895 r
.66795 .0375 .67157 .04351 .67904 .041 .67545 .03528 Metetra
.64 .715 .902 r
.67545 .03528 .67904 .041 .68652 .03818 .68296 .03275 Metetra
.659 .738 .908 r
.68296 .03275 .68652 .03818 .694 .03505 .69047 .0299 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-2)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[67]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00^_ooool5o`00067ooooo002kooooo`04o`000?ooooooooooo`00067ooooo002looooo`03
o`000?oooooooooo067ooooo002mooooo`03o`000?oooooooooo063ooooo002jooooo`05o`000?oo
ooooooooooooool00000HOooool00;[ooooo00Go0000ooooooooooooooooo`00000=ooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`?o0000A_ooool00;_ooooo0ol0000=ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool0AOooool00<Cooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool0AOooool00<_ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`15ooooo`00boooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo04Gooooo003;ooooo`04o`000?ooooooooooo`0000Sooooo0_l00017ooooo`00_ooo
ool2o`0000_ooooo0_l0000:ooooo`03o`000?oooooooooo04Gooooo002looooo`Ko0000G_ooool0
0;[ooooo0_l00004ooooo`;o0000G_ooool00;Oooooo0ol00006ooooo`03o`000?oooooo000005go
oooo002dooooo`Go00001oooool00ol0003oooooo`00001Mooooo`00/_ooool2o`0000cooooo00Co
0000oooooooooooo0000G?ooool00:oooooo0ol0000>ooooo`05o`000?ooooooooooooooool00000
Foooool008cooooo0ol0000Nooooo`;o00004Oooool01?l0003oooooooooooooool2o`0005[ooooo
002=ooooo`03o`000?oooooooooo01[ooooo0ol000000ooooooo0000ooooo`0>ooooo`Co00000ooo
ool00ol0003oooooooooo`1Hooooo`00SOooool00ol0003oooooooooo`0Hooooo`;o00004_ooool2
o`000003oj>gi_l0003oZ;cX00;o00000oooool00ol0003oooooooooo`1Gooooo`00SOooool00ol0
003oooooooooo`0Eooooo`?o00004?ooool4o`000003oinaiOl0003oXkOV00Go00000_ooool00ol0
003oooooooooo`1Gooooo`00SOooool00ol0003oooooooooo`0Cooooo`;o00003Oooool6o`000003
oiNWhOl0003oVZcS00Co000000CoZ;cXo`000?l0003o/LOZ0_l00002ooooo`03o`000?oooooooooo
05Kooooo002<ooooo`;o00004_ooool3o`0000;ooooo00?o0000ooooooooool00oooool7o`000005
oi2Og_l0003oTJ7Oo`000?nCY>001?l000000onO/NGo0000oj>giP02o`000005ojg2jOl0003o0000
okG<jol000000oooool00ol0003oooooooooo`1Eooooo`00SOooool00ol0003oooooooooo`0=oooo
o`?o00001Oooool6o`000003oi2Pgol0003oSioN00;o000000?oSikNo`000?l000001?l000000onG
Yn7o0000oiZ/h`04o`000003ojRlj?l0003o000000;o000000?o]Lc[o`000?ooool00_ooool2o`00
05Kooooo002Kooooo`;o00001?ooool4o`000007oiJWhOl0003oU:CQo`000?nBX^3o0000oi2Pg`05
o`000005ohnOg_l0003oTJ7Oo`000?nCXn001?l000000onO/NGo0000oj>giP02o`000003ojc1jOl0
003o000000Co00000_ooool2o`0005Kooooo002Hooooo`?o000000?oooooo`000?ooool00ol00000
1OnK[>?o0000oiRYh_l0003oUZOQ00Ko000000CoSioNo`000?l0003oSikN1_l000000onGYn7o0000
oiZ/h`04o`000003ojRlj?l0003o000000;o000000?o]Lc[o`000?nmend00ol00002ooooo`03o`00
0?oooooooooo05?ooooo002Fooooo`;o00000_ooool4o`000003oinaiOl0003o000000Go000000Go
U:CQo`000?nBX^3o0000oi2Pg`05o`000005ohnOg_l0003oTJ7Oo`000?nCXn001?l000000onN/NGo
0000oj>fiP02o`000003ojc1jOl0003o/LOZ00Co000000Ko_m[]o`000?o0f^co0000ooooool0001E
ooooo`00Toooool3o`0000;ooooo0_l000000onS]^Ko0000oj6diP03o`000005oi^/hol0003oV:WR
o`000?nFYn401_l000000on?Wmko0000ohnNgP02o`000003ohnOg_l0003o000000;o000000?oUjOR
o`000?nJ[><01?l000000onW^nOo0000o`000004o`000009okgHkOl0003o0000ol3Jk?l0003o`M[/
o`000?oooooo000005Cooooo002Aooooo`;o00000_ooool3o`000003ojBgi_l0003o000000;o0000
00?oWk7Uo`000?nM[n@01Ol000001OnDY>7o0000oi:Rh?l0003oT:3O00Oo000000GoTJ3Oo`000?nC
Xn3o0000oiNWhP02o`000003oijaiOl0003oXkKV00;o000000?o[<7Yo`000?naanX01?l000001?no
f^go0000o`000?o1f^`3o`000003ooooool0003ooooo05;ooooo002>ooooo`?o00000_ooool3o`00
0006ojFiiol0003o0000oj>fi_l0003oXKCV1Ol000000onHZN;o0000oiJWhP06o`000005ohnOg_l0
003oSYkNo`000?n>WMh01ol000000onJ[>?o0000oijai@02o`000003ojNkiol0003o[<7Y00;o0000
00?o]/k/o`000?nmf>d00_l000002?o0fNco0000o`000?l0003o`mo]o`000?oooooo0000Doooool0
08cooooo0_l000000ooooooo0000o`000002o`000007ojNkiol0003o0000o`000?nT]nKo0000oj>f
iP02o`000003oinaiOl0003oWJoT00Go000000GoU:GQo`000?nBX^3o0000oi2Pg`07o`000005oi6Q
gol0003oTjCPo`000?nGYn801?l000000onS]NKo0000o`000002o`000003ok77j_l0003o000000;o
000000Co_mW/o`000?l0003o`=W/1Ol000000ooooooo0000ooooo`1Aooooo`00ROooool3o`000006
ooooool0003o0000ojRlj?l0003oZ;_W0_l000000onV^^Oo0000o`000003o`000003oj6di_l0003o
000000;o000000CoVjcSo`000?l0003oUZOR1_l000001on?W]ko0000ohjMg_l0003oSYgMo`000?n?
W]h01Ol000000onJ[>?o0000oij`i002o`000003ojNjiol0003o[<7Y00;o000000?o]lo/o`000?l0
00000_l000001onof>co0000o`000?l0003oa>;]o`000?o1gNd00ol0001Booooo`00Q_ooool3o`00
0005ooooool0003o0000o`000?nX_>P01?l000001onW^nOo0000o`000?l0003oY;OWo`000?nS]^H0
0_l000000onO/NGo0000oif_i005o`000005oiBUhOl0003oTZ;Po`000?n@X=l02Ol000000onCY>3o
0000oiNXhP04o`000003oj:diOl0003o000000;o000000?o//S[o`000?l000000_l000001?nnenco
0000o`000?o1f^`5o`000004okcDk?l0003o0000o`00057ooooo0024ooooo`;o00000_ooool3o`00
0006ojVmj?l0003o0000ojRlj?l0003oZ;_W0_l000000onV^^Oo0000ojFii`03o`000003oj6di_l0
003o000000;o000000GoVjcSo`000?nHZ^?o0000oiJWhP05o`000007ohnNg_l0003oSYgMo`000?n>
WMgo0000ohnNgP05o`000003oiZ[hol0003oWZoT00;o000000?oYk[Wo`000?n/`NT00_l000000ong
d>go0000okgFk002o`000007okoGk?l0003o0000o`000?o5i>ko0000ol3Jk@02o`000004okW>j_l0
003o0000o`00053ooooo001Qooooo`;o00007_ooool7o`000005ojVmj?l0003o0000o`000?nX_>P0
1?l000000onW^nOo0000o`000002o`000007ojBgiol0003o0000o`000?nO/NGo0000oif_i007o`00
0003oi:Rh?l0003oT:3O00Wo000000?oTjCQo`000?nGYn801?l000000onR/nGo0000o`000002o`00
0003ok;:jol0003o000000Go000000?o`Mc/o`000?l000000ol000001?nkd>[o0000o`000?njd^`2
o`00053ooooo001Pooooo`04o`000?ooooooooooo`0001_ooooo0_l00002ooooo`04o`000?nY_NSo
0000ojVmj0;o000000OoZKgXo`000?nY_NSo0000ojRlj?l0003oZ;_W00;o000000?oY[[Wo`000?nU
^NL00ol000000onQ]>Go0000o`000002o`000005oi^]hol0003oVJ[So`000?nFYn801Ol000001on>
WMko0000ohjMgOl0003oSYgMo`000?n?Wmh01Ol000000onIZ^;o0000oif^h`02o`000003ojNjiol0
003o[L;Y00;o000000?o^=7]o`000?nldn`01_l000000oo5iNko0000okkEj`02o`000004okW?j_l0
003o0000okgJk`;o0000Coooool0063ooooo00Co0000oooooooooooo00006?ooool3o`0000;ooooo
0_l000001OnY_NSo0000o`000?l0003oZKgX00Co000000GoZ;cXo`000?l0003o0000ojNki`04o`00
0007ojBhiol0003o0000o`000?nO/NGo0000oif_i007o`000003oi:Rgol0003oT9oN00So000000Co
TJ;Oo`000?l0003oUZOQ1?l000000onQ/nGo0000o`000002o`000003ok?<k?l0003o000000;o0000
00Co_=?[o`000?l0003o`mo]1Ol000001?nic^Wo0000o`000?nlf>h6o`0004gooooo001Pooooo`04
o`000?ooooooooooo`0001Kooooo0_l000000ooooooo0000o`000002o`000005ojVmj?l0003o0000
o`000?nY_NP00_l000000onY_NSo0000ojVmj003o`000006ojRkiol0003o0000ojJjiol0003oYKWW
0_l000000onS]^Ko0000oj6ci@03o`000005oi^]i?l0003oVJ[So`000?nFZ>801Ol000001on>WMgo
0000ohjMgOl0003oSYkNo`000?n?Wml01Ol000000onIZN;o0000oib]h`02o`000003ojNlj?l0003o
[/CZ00;o000000?o^=7]o`000?njd>/00_l000001oo0fNco0000o`000?l0003oaNC]o`000?nkd>X0
0_l000001_nkdnco0000o`000?nogo3o0000okG=k0;o00003oooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol0000[ooooo`00H?ooool01?l0003oooooooooool0000Coooo
o`?o00000_ooool01?l0003oZKgXo`000?nY_NP2o`000005ojVmj?l0003o0000o`000?nY_NP01?l0
00001OnX_>So0000o`000?l0003oYk_W00Co000000?oY;OWo`000?l000000ol000000onM[nCo0000
o`000004o`000004oiBThOl0003o0000ohnOgPSo000000CoTJ;Po`000?l0003oUZKQ1?l000000onQ
/nGo0000o`000002o`000003okC=k?l0003o000000;o000000?o_=?[o`000?l000001_l000001?ni
c^Wo0000o`000?nognl4o`000003ojfmiOl0003o000000gooooo00Co0000oooooooooooo00002?oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0:?ooool0063ooooo
00Co0000oooooooooooo00004?ooool3o`000003ooooool0003o000000;o000000GoZKgXo`000?l0
003o0000ojVmj002o`000007ojVmj?l0003oZKgXo`000?nY_NSo0000ojVmj002o`000007ojRlj?l0
003oZ;_Wo`000?nV^^Oo0000ojFii`02o`000003oj>fi_l0003oXK?U00?o000000GoVjgTo`000?nI
Zn?o0000oiJXhP05o`000007ohjMgOl0003oSYgNo`000?n>W]ko0000oi2Pg`05o`000003oiRWhOl0
003oW:cS00;o000000?oZKkYo`000?n_an/00_l000000ongc^co0000okW>jP02o`000007ol;NkOl0
003o0000o`000?o3g^go0000okW<j002o`000006okkJk_l0003o0000ol3Ql?l0003o/LCX1Ol00005
ooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool0:?ooool0067ooooo0_l0000?ooooo`;o00000_ooool2o`000003ojVmj?l0
003oZKgX00;o000000GoZKgXo`000?l0003o0000ojVmj004o`000005ojVmj?l0003o0000o`000?nX
_>P01?l000001OnW^nOo0000o`000?l0003oY;OV00Co000000?oWk7Uo`000?nM[n@01Ol000001OnC
Y>3o0000oi6Qgol0003oSikN00Oo000000GoTJ;Oo`000?nCXmoo0000oiFTh003o`000003oj:ei_l0
003o000000;o000000?o]<g/o`000?l000000_l000000onme^co0000o`000006o`000004okcCjol0
003o0000ol;Vl0Co000000?oZ[SSo`000?n[^^D00_l0000<ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Xooooo`00Koooool3o`000005
ooooool0003o0000o`000?nY_NP01?l000001OnY_NSo0000o`000?l0003oZKgX00;o000000?oZKgX
o`000?nY_NP00ol000001?nY_NSo0000o`000?nX_>P5o`000006ojFiiol0003o0000oj>ei_l0003o
XK?U1Ol000000onIZn?o0000o`000007o`000005ohjNg_l0003oSioOo`000?n@XMl01ol000001_nL
[N?o0000o`000?nZ`N[o0000ok38k0;o000000?o]L_Zo`000?nicNX00_l000001oo5i>ko0000o`00
0?l0003o_mK[o`000?nic>P00_l000001_o2i>oo0000o`000?nog^oo0000ojfki0Co000000?o/LO[
o`000?l000002oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool0
1?l0000[ooooo`00KOooool6o`000007ojVmj?l0003oZKgXo`000?nY_NSo0000ojVmj002o`000005
ojVmj?l0003o0000o`000?nY_NP01?l000001OnY_NSo0000o`000?l0003oZ;cX00;o000000?oZ;cX
o`000?nW^nL00ol000000onT]nKo0000o`000002o`000003oinbiOl0003oWK3U00?o000000OoUZKQ
o`000?nCXn3o0000oi6Pg_l0003oSikN00Oo000000GoT:3Oo`000?nBXMko0000oiBRg`03o`000003
ojBhiol0003o000000;o000000Ko/l[[o`000?l0003o]<SXo`000?o0fnd3o`000003olCQkOl0003o
000000;o000000Co`=c^o`000?l0003o`nW`1?l000000onZ]n?o0000ojfoi`02o`000004okKDl?l0
003o0000o`0000Wooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0002kooooo001Zooooo`?o000000Goooooo`000?l0003o0000ojVmj004o`000005ojVmj?l0003o
0000o`000?nY_NP00_l000001onY_NSo0000ojVmj?l0003oZKgXo`000?nY_NP00_l000001OnY_NSo
0000o`000?l0003oZ;cX00Co000000OoY[[Wo`000?l0003o0000oj>ei_l0003oXKCU00Go000000?o
VJ[So`000?l000001ol000000on?X=oo0000ohnPg`09o`000006oif^i?l0003o0000ojc4k?l0003o
/<S/0_l000000onbaNSo0000o`000002o`000003olO[k_l0003o000000?o000000Co_=7Zo`000?l0
003oaNg_1?l000000onY]>7o0000o`000002o`000003okKBk_l0003o000000;o00002oooool2o`00
00[ooooo0_l00002ooooo`Go0000:_ooool006Sooooo0_l00002ooooo`?o000000KoZKgXo`000?l0
003oZKgXo`000?nY_NP2o`000005ojVmj?l0003o0000o`000?nY_NP01?l000001OnY_NSo0000o`00
0?l0003oZKgX00;o000000OoZKgXo`000?nX_>So0000ojRlj?l0003oYk_W00;o000000?oYKWWo`00
0?nT]nH00ol000000onO/^Go0000oij`i@03o`000005oiFVhOl0003oTj;Oo`000?nAX=h01ol00000
1on?Wmko0000ohnNgOl0003oT9kMo`000?nCXMh00ol000000onU_>Wo0000o`000002o`000006ok35
jOl0003o0000okC6j?l0003o`n?^0ol000000onoe^[o0000o`000002o`000005olGYkol0003o0000
o`000?ndaNL00ol000000on]_NKo0000ok;9j`04o`000003ojZkiOl0003o000004Wooooo001Uoooo
o`Oo000000GoZKgXo`000?l0003o0000ojVmj004o`000005ojVmj?l0003o0000o`000?nY_NP00_l0
00000onY_NSo0000ojVmj002o`000005ojVmj?l0003o0000o`000?nY_NP01?l000001OnX_>So0000
o`000?l0003oY[[W00Go000000?oXKCVo`000?l000000_l000000onK[NCo0000oiRYhP05o`000003
oi2Qgol0003oT:7P00;o000000?oT:3Oo`000?l000001_l000001OnHZ>7o0000o`000?l0003o[<G/
00Co000000?o[l3Vo`000?l000000ol000001_o5hngo0000o`000?nfa>Go0000ol7NkP?o000000Go
_][]o`000?l0003o0000ojRch@05o`000005okOEkol0003o0000o`000?nS[Mh00_l00018ooooo`00
Hoooool2o`0000;ooooo0ol000002?nY_NSo0000o`000?nY_NSo0000ojVmj?l0003oZKgX1?l00000
1OnY_NSo0000o`000?l0003oZKgX00Co000000GoZKgXo`000?l0003o0000ojVmj002o`000003ojVm
j?l0003oZ;cX00?o000000KoYk_Wo`000?l0003oYKSWo`000?nT]nH3o`000003oj2ci_l0003o0000
00Go000000?oTZ;Oo`000?nAXMl01ol000001on>W=go0000ohjKg?l0003oSicLo`000?nBX=h00ol0
00001_nW_n_o0000o`000?n/`>So0000ojfniP;o000000?o]LWYo`000?o7k>h00ol000000onib>Ko
0000o`000002o`000005olSdkOl0003o0000o`000?n[]N000ol000001?ncbn_o0000o`000?nlhO83
o`000003ojF`h?l0003o000000;o0000B?ooool0063ooooo1ol000001OnY_NSo0000o`000?l0003o
ZKgX00Co000000GoZKgXo`000?l0003o0000ojVmj002o`000005ojVmj?l0003oZKgXo`000?nY_NP0
1?l000001OnY_NSo0000o`000?l0003oZKgX00Co000000GoZ;cXo`000?l0003o0000ojJji`04o`00
0009oj>fi_l0003o0000o`000?nN/>Go0000oi^]hol0003oV:SR00Go000000GoTJ?Qo`000?nAXn7o
0000oi2Rh009o`000005oiV/i?l0003oXKOXo`000?n[`^X01?l000001?n^_NGo0000o`000?o2h^l2
o`000004okoEj_l0003o0000okG2i0Go000000Go]LKWo`000?n[]N3o0000ojbki002o`000004okkU
l_l0003o0000ok;:j`?o000000?oXZ_Mo`000?nU/^400_l00017ooooo`00GOooool3o`0000;ooooo
00Co0000ojVmj?l0003oZKgX0_l000001OnY_NSo0000ojVmj?l0003oZKgX00Co000000GoZKgXo`00
0?l0003o0000ojVmj004o`000005ojVmj?l0003oZKgXo`000?nY_NP00_l000001onY_NSo0000ojVm
j?l0003oZKgXo`000?nY_>P00_l000001onX_>So0000o`000?l0003oYKSWo`000?nT]nH00_l00000
0onR]^Ko0000o`000005o`000004oiBTh?l0003o0000oi6Rh0Oo000000OoS9WKo`000?n<V=[o0000
ohjKfol0003oTj;O00Ko000000?oZ;OTo`000?nY^><00_l000001?nidNco0000o`000?o6iNd2o`00
0004ok>nh_l0003o0000ol;NkP;o000000?o`]o^o`000?l000001?l000001?nlg_7o0000o`000?nk
gO43o`000003oj6Xfol0003oXZ_M00;o000000?o[/?Yo`000?l00000A_ooool005_ooooo0_l00000
0ooooooo0000o`000002o`000005ojVmj?l0003o0000o`000?nY_NP01?l000001OnY_NSo0000ojVm
j?l0003oZKgX00;o000000GoZKgXo`000?nY_NSo0000ojVmj004o`000005ojVmj?l0003o0000o`00
0?nY_NP01?l000001OnY_NSo0000o`000?l0003oZ;cX00;o000000?oYk_Wo`000?nV^NL00ol00000
1onS]nOo0000o`000?l0003oWK3To`000?nJZn801ol000001OnBYN;o0000oi6ThOl0003oT:3O00Wo
000000GoW;;Wo`000?l0003o0000ojRki`04o`000004ojo0i_l0003o0000olK]k`;o000000Co]lCT
o`000?l0003o^<[W1Ol000001OnZ/Mgo0000ojFZf_l0003o]Lg/00;o000000Co`>_bo`000?l0003o
Z[SS1Ol000000onY^^Go0000o`000003o`0004Gooooo001Hooooo`?o00000_ooool01?l0003oZKgX
o`000?nY_NP2o`000005ojVmj?l0003o0000o`000?nY_NP01?l000001OnY_NSo0000o`000?l0003o
ZKgX00Co000000GoZKgXo`000?nY_NSo0000ojVmj003o`000004ojVmj?l0003o0000ojVmj0Co0000
00GoZKgXo`000?l0003o0000ojRli`08o`000003oj:fiol0003oX;?V00?o000000GoUjKPo`000?nD
Y>3o0000oi>Th@07o`000006ohbHf_l0003o0000oh^GfOl0003oSicL1?l000001onU_^co0000ojNn
j_l0003oXjoPo`000?nW/n800_l000001?nog^oo0000o`000?nodnT2o`0000;o/;[Q00Go0000olSc
kOl0003o0000okK6iP06o`000004ol7_lOl0003o0000okG=k0?o000000?oWjGJo`000?nT[]l00_l0
00000onccNgo0000ojk0i`02o`0004Gooooo000gooooo`?o00007?ooool2o`000003ooooool0003o
000000;o000000GoZKgXo`000?l0003o0000ojVmj002o`000007ojVmj?l0003oZKgXo`000?nY_NSo
0000ojVmj002o`000005ojVmj?l0003o0000o`000?nY_NP01?l000001OnY_NSo0000o`000?l0003o
ZKgX00?o000000KoZKgXo`000?l0003oZKgXo`000?nY_NP3o`00000:ojRlj?l0003o0000ojNjiol0
003oY[WWo`000?nU^>Oo0000ojBhi`Go000000?oVJWRo`000?l000001Ol000001OnCY^?o0000oi6S
hOl0003oSYgM00Oo000000?oV:gVo`000?nO^>X01Ol000001?nS[n3o0000o`000?ncbN/5o`000003
ojjeg_l0003o/;[Q00?o000000Soa^K]o`000?l0003oXJ?Fo`000?nSZ=Wo0000okoVl@Go000000?o
XJKJo`000?l000000ol000000on`a^[o0000o`000005o`0004Cooooo000hooooo`03o`000?oooooo
oooo01Sooooo1_l000000onY_NSo0000ojVmj002o`000005ojVmj?l0003o0000o`000?nY_NP01?l0
00001OnY_NSo0000o`000?l0003oZKgX00?o000000KoZKgXo`000?l0003oZKgXo`000?nY_NP2o`00
0005ojVmj?l0003o0000o`000?nY_NP00ol000000onY_NSo0000o`000002o`000005ojVmj?l0003o
0000o`000?nX^nL01?l000001onU^NOo0000o`000?l0003oX[KVo`000?nP/^D00ol000001OnGY^7o
0000oiFVhOl0003oUJOS00Oo000000?oRI?Go`000?n9TmL00_l000000onAXMoo0000o`000002o`00
0003ojBlj_l0003oY;KV00?o000000OoYkGSo`000?l0003o0000olSek?l0003o/kgR00So000000?o
Yj_Jo`000?nQXmH00_l000001_nfc^co0000o`000?nid^go0000ojZfhP?o000000?oXZ_Mo`000?nZ
^N@00_l000001Onfd^ko0000ojVfh_l0003oYJkN00;o0000A?ooool0033ooooo1Ol00003ooooo`03
o`000?oooooooooo01Kooooo0_l000000ooooooo0000o`000002o`000005ojVmj?l0003o0000o`00
0?nY_NP00_l000001onY_NSo0000ojVmj?l0003oZKgXo`000?nY_NP00_l000001OnY_NSo0000o`00
0?l0003oZKgX00?o000000?oZKgXo`000?l000000_l000001OnY_NSo0000o`000?l0003oZKgX00;o
000000OoZKgXo`000?nY_NSo0000ojVmj?l0003oZKgX00;o000000GoZKgXo`000?l0003o0000ojNj
i`05o`000003ojBhiol0003o000000;o000000?oW:cRo`000?nIZ>401Ol000001?nFZ^Co0000o`00
0?n@Wmh9o`000003oibfj_l0003o000000Go000000CoWjWMo`000?l0003o^m[`0ol000001Onnd^Wo
0000oj^`g?l0003o]<;U00?o000000?o^<GUo`000?l000000_l000001?nY/]oo0000o`000?o4l?04
o`000003oiZKdol0003o000000[o000000?oXZOJo`000?l00000@oooool003Sooooo00?o0000oooo
ooooool04oooool3o`0000;ooooo00?o0000ojVmj?l000000ol000001OnY_NSo0000o`000?l0003o
ZKgX00Co000000GoZKgXo`000?l0003o0000ojVmj003o`000006ojVmj?l0003o0000ojVmj?l0003o
ZKgX0_l000001OnY_NSo0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l000000_l000001OnY
_NSo0000o`000?l0003oZKgX00;o000000OoZ;cWo`000?nW^nOo0000ojJjiol0003oY[[W00?o0000
00?oX[GVo`000?l000001Ol000000onGZ^Co0000o`000005o`000005ohVBeol0003oQi3Fo`000?n8
U=P00_l000002?nEZ^Go0000o`000?nR^n_o0000oj2ciOl0003oWJ[O0ol000001On/_nSo0000o`00
0?l0003oan_^00?o000000?oZk3Lo`000?l000001?l000000onMV]3o0000o`000002o`00000:ol;^
lOl0003o0000ojZcgol0003oWZ3Fo`000?nJVm?o0000ojZii0;o000000Oo^]W`o`000?l0003o0000
oj>Zfol0003oXJKJ00Ko0000@Oooool003Sooooo00?o0000ooooooooool04?ooool8o`000005ojVm
j?l0003oZKgXo`000?nY_NP00_l000001OnY_NSo0000ojVmj?l0003oZKgX00Co000000GoZKgXo`00
0?l0003o0000ojVmj003o`000003ojVmj?l0003o000000;o000000GoZKgXo`000?l0003o0000ojVm
j002o`000005ojVmj?l0003oZKgXo`000?nY_NP01?l000001OnY_NSo0000o`000?l0003oZKgX00Co
000000GoYk[Wo`000?l0003o0000ojJjj003o`000003oij^hol0003oVj_R00Go000000GoVJkVo`00
0?nFZ^Co0000oi:Rg`0:o`000003oj2lkOl0003o000000Co000000?oV9kHo`000?l000000_l00000
1?o7nN[o0000o`000?n_]mh3o`000007ol3KkOl0003o0000o`000?nUYMGo0000oifJd002o`000004
okO?k?l0003o0000okgGk@So000000Co^]_`o`000?l0003o/<;W1Ol000000onRZ=[o0000ojJ_gP02
o`0004;ooooo000gooooo`;o00004?ooool2o`0000?ooooo00?o0000ojVmj?l000000ol000001OnY
_NSo0000o`000?l0003oZKgX00Co000000GoZKgXo`000?nY_NSo0000ojVmj003o`000004ojVmj?l0
003o0000ojVmj0?o000000?oZKgXo`000?l000000_l000001OnY_NSo0000o`000?l0003oZKgX00Co
000000GoZKgXo`000?nY_NSo0000ojVmj003o`000006ojVmj?l0003o0000ojRkiol0003oYk_W0ol0
00001_nV^nSo0000o`000?nT]nOo0000oj6ci@?o000000?oVJ_So`000?nI[N@02?l000001on6S]Co
0000ohJ@e_l0003oRiWLo`000?nBYn@00ol000001OnM/NGo0000oiVTgOl0003oUYgH00?o000000Go
]]C`o`000?l0003o0000okg@j@03o`000003ojnihOl0003o000000Ko000000?oYZcLo`000?l00000
0ol000001onKVM7o0000oiJBc_l0003oVISAo`000?necnd00_l000001onieNko0000o`000?l0003o
Wj7Fo`000?nOXmL01?l000000on/^N?o0000o`000011ooooo`00>?ooool00ol0003oooooooooo`0;
ooooo`?o000000?oooooo`000?l000000_l000001OnY_NSo0000o`000?l0003oZKgX00;o000000Go
ZKgXo`000?nY_NSo0000ojVmj004o`000005ojVmj?l0003o0000o`000?nY_NP00ol000002_nY_NSo
0000o`000?nY_NSo0000ojVmj?l0003oZKgXo`000?nY_NP2o`000005ojVmj?l0003o0000o`000?nY
_NP01?l000001OnY_NSo0000o`000?l0003oZKgX00?o000000?oZKcXo`000?l000000_l000001OnW
^^Oo0000o`000?l0003oY[[X00Go000000?oVZ[Ro`000?l000000ol000000onI[^Ko0000oiBVh@0;
o`000003oijmk_l0003o000000Go000000?oUigHo`000?nT]>@01Ol000000onRXMCo0000oj>TeP04
o`000004oj6Md?l0003o0000oiZFc`Go000000?oZK3Mo`000?nKVM401_l000001?nnho7o0000o`00
0?nX/=h2o`000006oinQe_l0003o0000ojJ]g?l0003oZ[CP0ol000000ooooooo0000ooooo`0ooooo
o`00A?ooool7o`000005ojVmj?l0003o0000o`000?nY_NP00ol000000onY_NSo0000o`000002o`00
0005ojVmj?l0003oZKgXo`000?nY_NP00_l000001OnY_NSo0000o`000?l0003oZKgX00?o000000?o
ZKgXo`000?l000000_l000001OnY_NSo0000o`000?l0003oZKgX00;o000000OoZKgXo`000?nY_NSo
0000ojVmj?l0003oZKgX00;o000000GoZKgXo`000?l0003o0000ojVmj003o`000003ojRkiol0003o
000000;o000000OoYkcXo`000?l0003o0000oj>eiOl0003oX;3S00?o000000?oVjoUo`000?nL/^L0
1Ol000000on:TmKo0000ohJ=d`02o`000003ohRFf_l0003oT:CS00Go000000GoUJ3Ko`000?n@UMCo
0000oi2Cd`05o`000003okc?j?l0003oZZoK00Ko000000?o^/CRo`000?nQWM000ol000000onhd>co
0000o`000005o`000005oiB@c?l0003oWZ7Go`000?noiO800_l000000onba>Oo0000o`000003o`00
0003oj6Tf?l0003oYZgL00Oo0000@?ooool0047ooooo0ol00002ooooo`?o000000GoZKgXo`000?l0
003o0000ojVmj002o`000005ojVmj?l0003o0000o`000?nY_NP01?l000001OnY_NSo0000o`000?l0
003oZKgX00?o000000SoZKgXo`000?l0003oZKgXo`000?nY_NSo0000ojVmj0Co000000GoZKgXo`00
0?l0003o0000ojVmj004o`000005ojVmj?l0003o0000o`000?nY_NP00ol000002_nY_NSo0000o`00
0?nY_>So0000ojRliol0003oYk_Wo`000?nW^nP3o`000003ojJiiol0003o000000;o000000?oW:cR
o`000?l000000ol000000onM/nSo0000oiRZh`0:o`000003oijol?l0003o000000Oo000000?oVjSO
o`000?l000001Ol000001OnJUloo0000ojN/fol0003od?_S00Go000000?oXJCGo`000?l000000ol0
00001OnGTL_o0000oi::aol0003oU93<00Co000000Co_Mc_o`000?l0003oWYoD0_l000000onMWM?o
0000o`000002o`000005ojjkhol0003o[;GPo`000?nY/=d00ol0000oooooo`00?oooool2o`000003
ooooool0003o000000;o000000GoZ[gWo`000?l0003o0000ojVmj003o`000008ojVmj?l0003o0000
ojVmj?l0003oZKgXo`000?nY_NP4o`000005ojVmj?l0003o0000o`000?nY_NP00ol000000onY_NSo
0000o`000002o`000005ojVmj?l0003o0000o`000?nY_NP00_l000001OnY_NSo0000ojVmj?l0003o
ZKgX00Co000000GoZKgXo`000?l0003o0000ojVmj003o`000003ojVmj?l0003o000000;o000000Go
Z;_Wo`000?l0003o0000ojRmj003o`000003oj6bi?l0003o000000?o000000?oWkKXo`000?l00000
1Ol000001on6S=;o0000ohB<dol0003oQi?Ho`000?n>X^800ol000000onL/NOo0000oi>MfP02o`00
0003ohV:cOl0003oSY;B00;o000000So^^gdo`000?l0003oYJKGo`000?nJULgo0000oiZGc`Co0000
00GoWIC;o`000?nBQ/?o0000oi>;b003o`000003olOUkOl0003o000000Go000000?oZkWSo`000?l0
00000_l000000onW[=_o0000oijOe003o`000003ojF[fol0003oZkGP00Ko000000CoY:KHo`000?oo
oooo0000?_ooool003cooooo0ol00002ooooo`04o`000?nZ_NOo0000ojZmi`;o000000GoZ[gWo`00
0?l0003o0000ojZmi`03o`000003ojVmj?l0003o000000;o000000GoZKgXo`000?nY_NSo0000ojVm
j003o`000004ojVmj?l0003o0000ojVmj0Co000000GoZKgXo`000?l0003o0000ojVmj003o`000003
ojVmj?l0003o000000;o000000GoZKgXo`000?nY_NSo0000ojVmj003o`000004ojVmj?l0003o0000
ojVmj0?o000000?oZKcXo`000?l000000_l000001OnX_>So0000o`000?l0003oYk_W00?o000000?o
WZkSo`000?nM[^@00ol000001OnQ^>Wo0000oi^^i?l0003oU:7M01Co000000?oZ<?]o`000?l00000
0_l000000onUY]Oo0000o`000002o`000004okS=j_l0003o^l;Po`0000;oWIC;2?l000001On=PL7o
0000oi27a_l0003oVi_C00;o000000?o`^G`o`000?l000001Ol000000onOX=Go0000o`000002o`00
0007ok6oi?l0003oZ:kKo`000?nVZMWo0000ojBVf003o`0003kooooo000jooooo`;o000000?ooooo
o`000?l000000_l000001OnZ_>Oo0000o`000?l0003oZ[gW00?o000000CoZ[gWo`000?l0003oZ[gW
1?l000001OnZ_NOo0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l000000_l000001OnY_NSo
0000ojVmj?l0003oZKgX00?o000000CoZKgXo`000?l0003oZKgX0ol000000onY_NSo0000o`000002
o`000005ojVmj?l0003o0000o`000?nY_NP00ol000002_nY_NSo0000o`000?nY_NSo0000ojVmj?l0
003oZ;_Wo`000?nX^nL2o`000007ojVmj?l0003o0000o`000?nS]>Go0000oj2`h`03o`000003oj6h
jOl0003o000000Go000000KoQhgBo`000?l0003oQY7Go`000?n=XN83o`000005oifdj?l0003oTI_I
o`000?n8R<d00_l000000on6Q/co0000oi:Lf@07o`000003oi69aol0003oWYkD00So000000GoVi[A
o`000?l0003o0000ojRXeP03o`000005ohf1`Ol0003o0000o`000?nmh?400_l000002onUZ=So0000
oi^Hcol0003oV9?=o`000?nJUloo0000ojbghOl0003o/;kT00?o000000?oZ:kKo`000?l000000_l0
00001?nTYMOo0000ooooool0000mooooo`00=oooool3o`0000;ooooo0_l000001On[_>Go0000o`00
0?l0003oZkcV00?o000000?oZ[cWo`000?l000000_l000001OnZ_NOo0000ojZmiol0003oZ[gW00?o
000000CoZ[gWo`000?l0003oZ[gW0ol000000onY_NSo0000o`000002o`000005ojVmj?l0003o0000
o`000?nY_NP00ol000002?nY_NSo0000o`000?nY_NSo0000ojVmj?l0003oZKgX1?l000001OnY_NSo
0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l000000_l000001OnX_>Oo0000o`000?l0003o
Z;cX00?o000000?oY[WWo`000?l000000ol000001?nO/^Ko0000o`000?nT_^`2o`000003oiNUgol0
003o000000Oo000000?oWlSeo`000?l000003?l000001_njcNSo0000o`000?nBRLOo0000oi69a`Co
000000OoV8c5o`000?n<O;co0000ohf0`Ol0003oVi[A00Wo000000Ko[;WSo`000?l0003o]lOVo`00
0?nUZ=P:o`000007ok6mhol0003o0000o`000?nSXmGo0000oj>Se@04o`000003ooooool0003ooooo
03_ooooo000dooooo`?o00000_ooool3o`000005ojbkiOl0003o0000o`000?n[_>D00_l000001On[
_>Go0000oj^li_l0003oZkcV00Co000000GoZ[cWo`000?l0003o0000ojZmi`03o`00000:ojZmiol0
003o0000ojZmiol0003oZ[gWo`000?nZ_NOo0000ojVmj0;o000000GoZKgWo`000?l0003o0000ojVm
j003o`000003ojVmj?l0003o000000;o000000GoZKgXo`000?nY_NSo0000ojVmj003o`000004ojVm
j?l0003o0000ojVmj0?o000000?oZKgXo`000?l000000_l000001OnX^nOo0000o`000?l0003oZKoY
00?o000000?oXK3Ro`000?nO[N800ol000000onU`>co0000o`000003o`000003ohR=dOl0003oQ8W@
00;o000000?oS:3Qo`000?l000000_l000002?nO^^_o0000o`000?n5Q<[o0000ogii`ol0003oOgc6
0_l000000onP^N_o0000o`000007o`000003ok32iol0003o000000;o000000?oV8c5o`000?l00000
0ol000001OnWXm7o0000ohn0_ol0003oQgNj00;o000000GoUiC>o`000?l0003o0000olO`kP03o`00
0009oiB<b?l0003oUi3;o`000?nMVm;o0000ok?3i_l0003o]<?V00?o000000?oY:KGo`000?l00000
0_l000001_nUY]Oo0000ojNYfOl0003oooooo`0003cooooo000booooo`;o00000oooool3o`000004
ojfji?l0003o0000ojfji0?o000000?o[;_Uo`000?l000000_l000001On[_>Go0000oj^liOl0003o
ZkcV00;o000000GoZkcVo`000?l0003o0000ojZli`03o`000003ojZliol0003o000000;o000000Go
Z[gWo`000?l0003o0000ojZmi`03o`000004ojZmiol0003o0000ojZmi`?o000000?oZKgWo`000?l0
00000_l000001OnY_NSo0000o`000?l0003oZKgW00?o000000[oZKgXo`000?l0003oZ[kXo`000?nY
_NSo0000ojRkiol0003oZ;[V1_l000000onW^NKo0000o`000003o`000007oj6eiol0003o0000o`00
0?nS^^Wo0000oi^Yh@02o`0000;oR8gA1?l000000onQc_Oo0000o`000007o`000004ogii`ol0003o
0000ohV?d`?o000000?oViO>o`000?n;O/000_l000001OnCSlco0000o`000?l0003oTh>o00Co0000
0_nESl/5o`000003ohn0_ol0003o000000;o000000?o`^cao`000?l000000_l000001?nHT<[o0000
oiB<b?nDS<P7o`000007ojfeg_l0003o0000o`000?nQX=?o0000oj>Se@05o`0000;ooooo00?o0000
ooooooooool0>Oooool000oooooo1Ol0000Kooooo`?o00000_ooool3o`000003ojjihOl0003o0000
00;o000000Go[K[Ro`000?n]^^;o0000ojfji002o`000005ojfji?l0003o0000o`000?n/^nD00ol0
00001On[_>Go0000o`000?l0003oZkcV00;o000000GoZkcVo`000?nZ_>Oo0000ojZli`04o`000005
ojZmiol0003o0000o`000?nZ_NL00ol000002_nZ_NOo0000o`000?nZ_NOo0000ojZmiol0003oZ[gX
o`000?nY_NP2o`000005ojVmj?l0003o0000o`000?nY_NP00ol000000onZ_^So0000o`000002o`00
0009ojVliol0003o0000o`000?nY_^Wo0000ojZnj?l0003oZKcW00?o000000?oX:oSo`000?l00000
0_l000000onWaNko0000o`000008o`000009ohbNh?l0003o0000o`000?nS`noo0000oi>Mfol0003o
Ph7800;o000000?oNG?0o`000?l000001?l000001_nkcnWo0000oi^Gc_nKUlko0000oh]n`0?o0000
00?o_KoKo`000?nCPkl00_l000000on6MKWo0000oiF?b`02o`000003ohYh^Ol0003oPVjd00Co0000
00Go[K_To`000?l0003o0000ok[9iP07o`000005ojFYfOl0003o^<WWo`000?nc`>@00_l000001?nS
X]Co0000o`000?nQX=<2o`000003ojNYf?l0003oZ:cJ00?o000000?oooooo`000?l000002?ooool2
o`00033ooooo000@ooooo`04o`000?ooooooooooo`0001Wooooo0_l00003ooooo`;o000000Oo/KOM
o`000?n_^=oo0000ojnhgol0003o[[WQ00;o000000Go[[WQo`000?l0003o0000ojfjhP03o`000004
ojfji?l0003o0000ojbki0?o000000?o[;_Uo`000?l000000_l000002On[_>Ko0000o`000?l0003o
ZkcVo`000?n[_>Ko0000ojZmi`02o`000005ojZmiol0003o0000o`000?nZ_NL00ol000000onZ_NOo
0000o`000002o`000005ojZmj?l0003o0000o`000?nY_NP00ol000001?nY_NSo0000o`000?nY_^P3
o`000003ojVmj?l0003o000000Ko000000GoZKkYo`000?l0003o0000ojFfi@03o`000003oj:hjOl0
003o000000?o000000GoWZ_Po`000?nCVMOo0000ohZ=d005o`000003oj;Hn_l0003o000000Ko0000
00CoNW>oo`000?l0003oPHC=4Ol000000on5LKGo0000o`000003o`000007ohYh^Ol0003oPVjdo`00
0?n5MK[o0000oi>=bP06o`000005oi24`ol0003oThW6o`000?nKUll01_l000000onWZMSo0000oj>R
e003o`000003ojFUe_l0003oYjWH00?o000000GoZJcIo`000?l0003oooooo`000007ooooo`04o`00
0?ooooooooooo`0002oooooo0009ooooo`Go00000oooool00ol0003oooooooooo`0Fooooo`?o0000
0_ooool01_l0003oooooo`000?nb]M_o0000ok6gg@;o000000Go/KOMo`000?l0003o0000ojnhg`03
o`000004ojjihOl0003o0000ojjih@?o000000So[K[So`000?l0003o[K[So`000?n/^nCo0000ojbk
i0Co000000Go[;_Uo`000?l0003o0000oj^liP03o`000005oj^li_l0003o0000o`000?nZ_NL00_l0
00001OnZ_NOo0000o`000?l0003oZ[gW00Co000000GoZKgXo`000?l0003o0000ojVmj003o`000008
ojVnj?l0003o0000ojVmiol0003oZKgXo`000?nY_NP3o`000003ojRliol0003o000000;o000000_o
ZKgXo`000?l0003o0000oj6ciOl0003oX;CVo`000?nY`>[o0000oj[2j`08o`000003ohbQhol0003o
000000;o000000KoZ<S`o`000?l0003oPgk6o`000?mhK[/6o`00000:oj_Vn_l0003o0000oiN@b_l0
003oQ7Bjo`000?n0L;So0000ohV0``;o000000?oSg^io`000?moJ:l01?l000000onebn_o0000o`00
0002o`000003ohYh^Ol0003oPVjd00Co000000Go_L_Uo`000?nQW=3o0000oi>8a@05o`000005ok6n
hol0003o]/CUo`000?n^]Mh01Ol000000onRX=?o0000o`000002o`000006ojZ^fol0003o0000o`00
0?nWZMSo00000_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002oooooo000B
ooooo`03o`000?oooooooooo01?ooooo0_l00005ooooo`;o000000Go/kCIo`000?l0003o0000ok:e
f`03o`000004ok6ggOl0003o0000ok2gg@?o000000So[kSOo`000?l0003o[kSOo`000?n^^N7o0000
ojjih@Co000000Go[K[So`000?n]^^;o0000ojbki003o`000004ojbkiOl0003o0000ojbki@?o0000
00GoZkcVo`000?l0003o0000ojZliP02o`000007oj^li_l0003oZ[cWo`000?nZ_>Ko0000ojZmi`02
o`000005ojZliol0003o0000o`000?nY_>L00ol000000onY_>Oo0000o`000002o`000009ojVmj?l0
003oZ;[Vo`000?nX^^Ko0000ojZliol0003oZ[kX00?o000000?oXkGUo`000?l000000_l000001OnU
^>Ko0000o`000?l0003oX[KV00;o000000?oS9;Do`000?n5Rm400ol000000onUfO[o0000o`000007
o`000005ogQ^^ol0003oNWW6o`000?n>XN401ol000000on4M;[o0000oh1`^002o`000004okjnfOl0
003o0000ogmX[`;o000000?oSH?4o`000?l000000_l000000ommIZko0000o`000003o`000003ojjm
iOl0003o000000Ko000000?oV9;<o`000?nUZMT01_l000000onQW];o0000oinKd003o`000003ojNZ
f?l0003oZJgJ00?o000000?oZ:_Io`000?l000000_l000000ooooooo0000ooooo`05ooooo`04o`00
0?ooooooooooo`0002oooooo000?ooooo`05o`000?ooooooooooooooool000004Oooool3o`0000Go
oooo0_l000001Ond/mOo0000o`000?l0003o/kCI00;o000000Go/kCIo`000?l0003o0000ok:ef`02
o`000005ok:efol0003o/;OMo`000?n`]]d01?l000001On_^=oo0000ojnggol0003o[[WQ00;o0000
00Go[[SQo`000?l0003o0000ojfihP03o`000008ojbjhol0003o0000ojbjhol0003o[;_To`000?n/
^^@3o`000003oj^kiOl0003o000000;o000000GoZk_Uo`000?l0003o0000ojZkiP03o`000004ojZl
i_l0003o0000ojZji@?o000000?oZ[cVo`000?l000001_l000001OnZ^nKo0000o`000?l0003oZ[kX
00?o000000?oXJ_Mo`000?l000000_l000000on^c_7o0000o`000006o`000007ohbLgOl0003oVK_`
o`000?n]doCo0000oiVUg@02o`000003ogI[^Ol0003oL6Jg00Ko000000?o_]GZo`000?nCRLH00_l0
00000omiIK3o0000o`000008o`000004ogmX[ol0003o0000o`0000;oY9O800Ko0000ogeV[_l0003o
P6bco`000?n?QLD5o`000006ohn0_ol0003o0000ohn3`_l0003oV9;<0_l000001Onmdn_o0000ojnf
g_l0003oYZOF00Go000000?oY:CEo`000?l000000_l000001on[[m_o0000o`000?l0003oYZOGo`00
0?nVYmL00_l000000ooooooo0000ooooo`04ooooo`04o`000?ooooooooooo`0002oooooo000?oooo
o`05o`000?ooooooooooooooool000003oooool2o`0000;ooooo00?o0000ooooooooool00_ooool2
o`000005okFaeOl0003o]K7Eo`000?nd/]L00_l000001Ond/]Oo0000okBbeol0003o/kCI00?o0000
00So/[GKo`000?l0003o/[GKo`000?nb]M_o0000ok2fg@;o000000Go/KKMo`000?l0003o0000ojng
g`03o`000004ojjhhOl0003o0000ojjhh0?o000000?o[KWRo`000?l000000_l000001On]^N?o0000
ojfjhol0003o[;[T00;o000000Go[;[So`000?l0003o0000ojbji003o`000005oj^kiOl0003o0000
o`000?n[^^@00_l000002On[_>Ko0000oj^li_l0003oZk_Uo`000?nZ^^Go0000ojZii004o`000009
ojc3jol0003o0000o`000?nT[Mgo0000oj:Yg?l0003oZ<G^00Go000000?oVYoGo`000?n>S/l00_l0
00000on6Rm3o0000o`00000:o`000005og1V]ol0003oM730o`000?n6Um`01ol000001OmiIK3o0000
ogmb^_l0003oVj?J00;o000000?oNV2Yo`000?mhHJ/01?l000000on2J:go0000o`000002o`000003
ogeV[_l0003o000000;o00000_o1c^@01?l0003oWYK;o`000?n?P;l4o`000003okK5i_l0003o0000
00Co000000?oWIO>o`000?nNVLl00ol000000on[[m_o0000oj^`g003o`000003ojNYf?l0003oYZOG
00;o000000GoYZWHo`000?ooooooooooo`000004ooooo`04o`000?ooooooooooo`0002oooooo000@
ooooo`?o00003Oooool3o`0000Oooooo0_l000001Onf/=?o0000o`000?l0003o]K7E00;o000000Go
]K7Eo`000?l0003o0000okBbe`02o`000005okBbeol0003o0000o`000?nc]=T00_l000001Onc]=Wo
0000ok:efol0003o/[GK00;o000000Go/[GKo`000?na]]go0000ok6fg@03o`000008ok2ggol0003o
0000ok2hgol0003o[kSPo`000?n_^N44o`000005ojjih_l0003o0000o`000?n]^^<00ol000001On]
^nCo0000o`000?l0003o[;_U00;o000000Go[;cUo`000?l0003o0000ojbmi`04o`000007ojbmi_l0
003o0000o`000?nZ^^Go0000oj_5k@05o`000003ojNbh?l0003o000000;o000000?oYKg[o`000?n_
d?402_l000000onL^^ko0000o`000003o`000003ohF2b?l0003oM6Vh00Co000000?oL6Jgo`000?l0
00000_l000001OnBQlGo0000ogYU/?l0003oLUb[00;o000000?oNFF`o`000?l000000ol000001Omj
H:Wo0000ogQQZol0003oQGNl00;o000000?oPVR]o`000?mhGZP01?l000000on_`>Ko0000o`000008
o`00000:ojJZfOl0003o0000ol;Lk?l0003oYJCDo`000?nOV/oo0000oifGcP?o000000?oZ:cIo`00
0?n[[m/00_l000000onZ[]_o0000o`000003o`000005ojJXf?l0003oYZWHo`000?ooool00ol00004
ooooo`;o0000<?ooool001gooooo0ol00009ooooo`09o`000?ng[m7o0000o`000?ng[m7o0000okJ`
dol0003o]k3C00;o000000Go]k3Co`000?ne/MGo0000okJae@02o`000005okJaeOl0003o];;Go`00
0?nd/mL01?l000001Onc]=Wo0000ok>dfOl0003o/[GK00;o000000Oo/[KKo`000?nb]]co0000ok6g
gOl0003o/KON00Co000000Go/;WPo`000?n_^^7o0000ojnjh@03o`000004ojjjhol0003o0000ojjl
i0?o000000Go[KgUo`000?l0003o0000ojbmiP02o`000005oj^oj?l0003o0000o`000?n[`>T01?l0
00002OnZ_^So0000o`000?l0003oZLC]o`000?nY_NSo0000ojZli`03o`000003oj:ijOl0003o0000
00Co000000?oY:oOo`000?nJWMD00_l000000on9QLWo0000ohR8c@04o`000004oj:Uf?l0003o0000
ogIT/@Go000000?oKVVlo`000?l000001_l000000omjIK3o0000og9LZ`09o`000003ogYPZOl0003o
N66[00Go000000?oN5jXo`000?l000000_n:O/02o`000007oi^?a_l0003oRWRjo`000?n6M;So0000
oh]l_@03o`000005ol?Qk_l0003o0000o`000?nUY=@01?l000000onPWM7o0000o`000003o`000007
ojbbg?l0003o0000o`000?nVYmSo0000ojJWe`06o`0000;ooooo00?o0000ooooooooool0=?ooool0
01_ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo0_l000001Onh[m3o0000okR_d?l0003o
]joA00;o000000Go]joAo`000?ng/=7o0000okN`d`02o`000005okN`dol0003o]k7Co`000?nf/MD0
0_l000001Onf/]Go0000okJbeOl0003o];?G00;o000000Go];?Ho`000?l0003o0000ok>efP03o`00
0008ok:fg?l0003o0000ok:ggOl0003o/KOMo`000?na^=l2o`000005ok2igol0003o0000o`000?n_
^^800ol000001?n^_>Co0000o`000?n]_>@3o`000005ojbmi_l0003o0000o`000?n[_^P00_l00000
1OnZ_NOo0000ojZojOl0003oZKcW00Co000000GoYl7/o`000?l0003o0000ojRki`03o`000005ojFn
jol0003o0000o`000?nR_N`00_l000000on]^nCo0000o`00000?o`000003ogIT/Ol0003oKU^]00Wo
000000GoMUjZo`000?l0003o0000ogYU/003o`000003ohnBdol0003oQVb^00;o000000?oLURTo`00
0?l000001?l000001OmcF:?o0000o`000?l0003oN5jX00[o000000CoQWBho`000?l0003o^m7[0_l0
00003Onnd^Wo0000o`000?l0003oVY?;o`000?nLU/go0000oj2MdOl0003o[;?Mo`000?n]]=h00_l0
00000onX[=[o0000o`000003o`000006ojN[f_l0003oYjcJo`000?nY/=go00000oooool00ol0003o
ooooooooo`0cooooo`006?ooool3o`0000[ooooo0_l000001Oni[loo0000o`000?l0003o^:o@00;o
000000Go^:o@o`000?l0003o0000okN`d@02o`000005okN`dOl0003o0000o`000?ng/M<00_l00000
1Ong/M?o0000o`000?l0003o][;E00;o000000Go]K;Fo`000?l0003o0000okBdf002o`000005okBd
f?l0003o0000o`000?nc]]/00_l000001Onb]M_o0000ok6ggOl0003o/KOM00?o000000Co/;WPo`00
0?l0003o[kSO0ol000002?n^^N;o0000o`000?n]]]oo0000ojbji?l0003o[;SR0ol000000on[^>?o
0000o`000002o`000005ojZhi?l0003oZkORo`000?nX_>P00ol000001?nX]^?o0000o`000?n[^^D3
o`000005oj>_h?l0003o0000o`000?nZ/Md00ol000000onN]nWo0000ohnShP02o`000004oh6Kh_l0
003o0000ojkDm0?o000000?oR8O<o`000?mbIkL00ol000000om^Fjgo0000ofeP/`02o`000003oi[C
o?l0003o000000;o000000?oMUjZo`000?m]E:D02?l000001on6K:ko0000og9HY?l0003oOF^do`00
0?n[_>H00_l000000omcF:?o0000ogEMZ@05o`000003oiR8`?l0003o000000Ko000000?oYjgKo`00
0?l000000_l000001?nSX=;o0000o`000?nJTl/8o`000007oj^`g?l0003oZ:cJo`000?nUZ=So0000
ojJYf@08o`0000;ooooo00?o0000ooooooooool0<oooool001Oooooo0_l0000;ooooo`09o`000?ni
[loo^Jo?o`000?ni[loo0000okV_col0003o^Jo?00;o000000Go^Jo?o`000?nh[m3o0000okR_d002
o`000005okR_d?l0003o]k3Bo`000?ng/=800_l000001Ong/=;o0000okJae?l0003o][7D00;o0000
00Go][7Do`000?ne/]Ko0000okFbeP02o`000005okFaeOl0003o];CHo`000?nc/mP01?l000001onb
]=[o0000ok:bfOl0003o/;KMo`000?n`]=/00_l000001On`/MWo0000ojnegOl0003o[k;J00Co0000
00Wo[[?Lo`000?n_/=Wo0000ojfcg_l0003o[[3Io`000?n[/mh00_l000001On]/mgo0000o`000?l0
003oZjcH00?o000000Go[KKOo`000?l0003o0000ojN^g002o`000005ojJNc_l0003oYjKDo`000?nh
f_402?l000000onKZN3o0000o`00000:o`000003ofiK[Ol0003o000000;o000000?oSWflo`000?mc
FJH00ol000000om]E:Go0000ofiJZ`04o`000003og1BWol0003o000000?o00000_mmJk@2o`000006
ogeRZ?l0003o0000ogEMZOl0003oQGNm1?l000001onHR<3o0000oh9]/_l0003oQWFio`000?nCR/L0
0_l000000oo4fNWo0000ok6gg@05o`000007oijKd?l0003oYJGFo`000?n_^>3o0000ojfdgP05o`00
000:ojFXf?l0003o0000ojR^g?l0003oZ:oMo`000?nY/moo0000ojVbg`;o00000_ooool00ol0003o
ooooooooo`0booooo`005oooool3o`0000Sooooo0ol000001?ni[loo0000o`000?ni[ll2o`000005
okV_col0003o^Jo?o`000?ni[ll00_l000001Oni[m3o0000okV_col0003o^:o@00;o000000Go^:o@
o`000?nh[m3o0000okN`dP02o`000005okN`d_l0003o]joAo`000?nf/M@00_l000001Onf/=?o0000
okJ_d_l0003o]K7E00;o000000Go];3Do`000?nd[m?o0000ok>ae`02o`000009ok>_eOl0003o0000
o`000?nb/=Oo0000ok:_e?l0003o/;7I00;o000000Go/JoFo`000?nb[mCo0000ok2`f003o`000004
ojn`fOl0003o0000ok2^eP?o000000Go/;7Io`000?l0003o0000ojf[e@03o`000004ojncfol0003o
0000ok:ff`?o000000?oYYg<o`000?nVW/h01?l000002?nTUlSo0000o`000?n?OK_o0000oh]m__l0
003oSXW:0_l000000onlf^oo0000oi>>b`02o`000005ofUI[Ol0003o0000o`000?mUG[D02?l00000
0omcFJKo0000o`000003o`000003ofiJZol0003oPWo700;o000000?oL5:Oo`000?m/D:000_l00000
0ombF:Co0000o`000004o`000003og=HXol0003o000000?o000000?oPVV^o`000?l000000_l00000
1On2KK;o0000o`000?l0003o`Mg^00Co000000KoVHo8o`000?l0003oVI;;o`000?nNVm02o`000007
ojnhgol0003o0000o`000?nX[=[o0000ojJYf003o`000003ojN/fol0003o000000Ko000000CoZKGR
o`000?oooooooooo0_l0000cooooo`004?ooool2o`0000Gooooo00Co0000oooooooooooo00001Ooo
ool2o`000003okV`d?l0003o^Jo?00;o000000Go^Jo?o`000?ni[loo0000okV_c`02o`00000:okV_
col0003o^Jo?okV_col0003o^Jk?o`000?ni[loo0000okV_c`;o000000Go^:k?o`000?nh[m3o0000
okR^d003o`000004okN_dOl0003o0000okN^d@?o000000Co]ZoBo`000?l0003o]ZkA0ol000001?nd
[m?o0000o`000?ne[]43o`000005okB^dol0003o0000o`000?nb[m@00_l000001Onc[]?o0000o`00
0?l0003o/ZoD00;o000000Go];3Eo`000?l0003o0000ok>`e@03o`000008ok>cf?l0003o0000ok>c
f?l0003o/:gEo`000?nc^=d3o`000004okJnhOl0003o0000ojb/e`;o000000?oYYg<o`000?l00000
0_l000001?n`[mOo0000ojBGb?nTUlP=o`000003ofUI[Ol0003o000000?o000000GoKgg@o`000?l0
003o0000ofmHZ005o`000003ofQBYOl0003o000000Co000000CoPfN[o`000?l0003oK52P1ol00000
0omaEZ?o0000o`000003o`000005oiB1_?l0003oPVV^o`000?mnIZd01?l000002?nY[mco0000o`00
0?nc^=go0000oj:Lcol0003oVHo81Ol000001On//]go0000o`000?l0003o[;;M00Go000000[oYZ[J
o`000?l0003oZK?Oo`000?nZ/moo0000ojVfh_l0003oZKGR0ol00003ooooo`03o`000?oooooooooo
037ooooo000?ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ni/M;o0000okV`d0;o000000Go^K3@o`000?l0003o0000okV_c`02o`000005okV_
col0003o0000o`000?ni[ll00_l000002?ni[/oo0000o`000?ni[/oo0000okV^c_l0003o^:k?0_l0
00001Onh[/ko0000okV]c_l0003o^:k?00;o000000Oo^:g?o`000?nh[Lko0000okN]d?l0003o]jg?
00;o000000Go^:g?o`000?nf[M3o0000okN]d002o`000009okR_d?l0003o]ZkAo`000?ng[m7o0000
okF^d_l0003o]ZoC00;o000000Go]kCFo`000?ne/=Co0000okJde`02o`000009okNkgOl0003o]KGH
o`000?nf_n7o0000okFhfol0003o]KcO00Co000000?o]<7To`000?n`e?<00ol000000on]^N?o0000
ojb/e`04o`000003ojgDm?l0003o000000Ko000000?oUigHo`000?l000000_l000000on>M[?o0000
ogePYP05o`000003of=I/Ol0003o000000?o000000_oM5BNo`000?m_F:So0000of99Wol0003oLeVV
o`000?mXDZGo0000ogM`_@07o`000003ofa@X?l0003oMF:_00Oo000000?oOfjfo`000?l000000_l0
00001?nDPKco0000o`000?mnIZd2o`000003oi65a?l0003o000000So000000?oWY[@o`000?nVYmL0
0_l000001onb_n?o0000o`000?l0003oYZ[Io`000?nUZ=P00ol000000onY/Mko0000o`000006o`00
0004ojViiOl0003o0000o`0000?ooooo00?o0000ooooooooool0<?ooool000oooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`03ooooo`?o000000Go^;?Do`000?ni/M;o0000okVa
dP02o`000005okVadOl0003o^K3@o`000?ni/=000_l000001Oni[m3o0000okV_col0003o^Jo?00;o
000000Go^Jk>o`000?ni[/oo0000okV^cP02o`0000;o^Jg>0_l000000oni[Lko0000o`000002okV]
c@;o000000So^:g>o`000?l0003o^Jg>o`000?ni[/oo0000okR]c`;o000000Go^:o?o`000?ni/M;o
0000okR_d002o`000009okVbdol0003o0000o`000?nh/mCo0000okRifOl0003o]kCF00;o000000Go
^;[Ko`000?nf`N?o0000okNkg@02o`000003okC6iol0003o000000?o000000?oZlkbo`000?l00000
1?l000000onT`>go0000o`000008o`000008oijfjOl0003o0000ohfQhOl0003oS9?Fo`000?n>TM42
o`000003okFgf_l0003o000000;o000000CoOF2Vo`000?l0003oLEFR1_l000000onBN;?o0000ogAD
WP03o`000003of99Wol0003o000000;o000000?oJ5:Uo`000?l000000ol000001OmWBI_o0000og1B
Wol0003oK52P00Co000000CoNebRo`000?maEZ?o00000_moK[H00ol0003oNf:[o`000007o`00000:
olObk_l0003o0000oijIcol0003oUHc7o`000?nDRLKo0000oiN?b@?o000000Go/l7To`000?l0003o
0000ojR_g005o`00000:ojN_gOl0003o0000oj^ii?l0003oZkSSo`000?nY^^Go0000ojVii@Ko0000
0oooool00ol0003oooooooooo`0_ooooo`003oooool01?l0003oooooooooool00003ooooo`;o0000
1?ooool01?l0003o]kGGo`000?nh/m@2o`000005okRce?l0003o^;?Do`000?ni/M400_l000001Oni
/M7o0000okVadOl0003o^Jo@00;o000000Go^Jo?o`000?ni[loo0000okV^cP02o`000005okV^c_l0
003o^Zk>o`000?ni[Lh00_l000001Oni[Lgo0000okZ^c_l0003o^Jg=00;o000000Co^Jg=o`000?nj
[/ko^Zk>0_l000001?ni[/oo0000o`000?nj/M43o`000004okVad_l0003o0000okVee@?o000000Co
^KOGo`000?l0003o^;cM0ol000001?ng_n3o0000o`000?nc`^D6o`000003ojc1jOl0003oZKOR00?o
000000SoY[[Xo`000?l0003oYj3?o`000?nT/N7o0000ojFbhP?o000000CoWYW>o`000?l0003o[9c7
0ol000000onMWMCo0000o`00000>o`000003og5EX_l0003oMV>_00Ko000000CoM5BNo`000?l0003o
KeRX0_l000000omNBZ;o0000o`000002o`000005ofe9U_l0003oPF>Wo`000?mWBI/01_l000000om/
C9_o0000o`000002o`000009og5FXol0003o0000o`000?mkHZ_o0000ogMOZ_l0003oO6Vb00;o0000
00?o[kcTo`000?l000000_l00002oijIc`Ko000000Co[k_So`000?l0003o/L7V0ol000000onTZ]_o
0000ojB[f`03o`000003ojZii?l0003o000000Ko000000?oZKkYo`000?nY`nd01?l00002ooooo`03
o`000?oooooooooo02oooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooooooo0_l000001One^=_o0000o`000?l0003o]kGG00?o000000Co^;?Do`000?l0003o^;?C0ol0
00001?ni/M7o0000o`000?ni/M43o`000004okV_col0003o0000okZ_c`?o000000Co^Zk>o`000?l0
003o^Zk>0ol000001?nj[/ko0000o`000?nj[lh3o`000006okZ^c_l0003o0000okZ`d?l0003o^[?B
0_l000001Onj]]Go0000okZde?l0003o^KOG00;o000000Go]kSJo`000?ni^M[o0000okNkg@02o`00
0005ok>hg?l0003o0000o`000?na^n400_l000001On_/][o0000ojjTc_l0003o[;;M00;o000000Wo
[:KAo`000?n]VlCo0000ojZWdol0003oZYG1o`000?nWX<l01?l000002onXRkKo0000oj>=__l0003o
[Y>ko`000?n/W<Oo0000ok:Tbol0003oWIgD00?o000000?oV7V_o`000?nRSl400_l000001on>JJ?o
0000ogaIW_l0003o<U72o`000?mmH:H00ol000000omfHjoo0000oi>Jf003o`000003oi9h/ol0003o
000000?o000000?oHTVOo`000?l000000ol000000om]BIKo0000o`000008o`000003ofa<Vol0003o
KE2O00Co000000WoO5fTo`000?l0003o0000ogMOZ_l0003oO6Vbo`000?n>QLH02_l000001OnLW=?o
0000o`000?l0003o]<_[00?o000000?oY:cLo`000?l000001_l000001OnZ_^So0000o`000?l0003o
Z;kY00Ko000000CoZLS`o`000?l0003o00000oooool2o`0002oooooo000?ooooo`04o`000?oooooo
ooooo`0000?ooooo1?l000002?nb^n3o0000o`000?nc^n3o0000okFhfol0003o][SK1?l000001ong
]MOo0000okNeeol0003o^K;Co`000?ni/m<00_l000001Oni/m?o0000okVadOl0003o^[7A00;o0000
00Go^[;Bo`000?nj[loo0000okZ`d002o`000005okZadOl0003o^Zo?o`000?nj/M000_l000001Onj
/];o0000okZ`d?l0003o^[;B00;o000000Go^[CDo`000?ni]=Go0000okZfe@02o`000005okRfeol0
003o][?Fo`000?ng^=X00_l000001?ne]MWo0000ok>^donc[]<2o`000003ok6_e_l0003o000000;o
/:G=0_l000001?n^Y<ko0000o`000?n_Vl<3o`000005ojfKa?l0003o0000o`000?nZUL400_l00000
1?nbW<3o0000ok2@]?l00002ojR;]P;o00000_n^Tk/2o`000004ok:Tbol0003o0000oiQ`X`;o0000
0_nHNJl3o`000003ohiYXol0003oO5VN00Ko000000?oLEFRo`000?l000001_l000000omdE9ko0000
of=6V@03o`000005oei:X_l0003o0000o`000?m]BIH01?l000000omWBI_o0000ofeGZ002o`000004
ogIFWol0003o0000ofe@W`Co000000?oO5fTo`000?l000000_l000000omgGj[o0000o`000002o`00
0003ok:aeol0003oVY3800;o000000?oSXC4o`000?l000001_l000002On/^N?o0000o`000?l0003o
Xj_Lo`000?nU[moo0000ojZli`08o`000005ojS1jol0003o0000o`000?nYanl01ol000000ooooooo
0000o`00000_ooooo`004?ooool2o`0000Cooooo00?o0000ojW2k?l000000ol000002On__nKo0000
o`000?l0003o/k_Po`000?nc_>3o0000okJhf`02o`000005okJhfol0003o0000o`000?nh]]L00ol0
00002?ni/m?o0000o`000?ni/mCo0000okVdeOl0003o^[;B0_l000001Onj/m;o0000okZddol0003o
^[7A00;o000000Go^[?Bo`000?nj/m?o0000okZbdP02o`000003okZcdol0003o^K?D00?o000000Co
^KCEo`000?l0003o]k;D0ol000001?nf/mKo0000o`000?nd[M43o`000008ok>^dol0003o0000ok:U
bol0003o/Yk3o`000?n`YLd2o`000006ok6L`_l0003o/iVlo`000?n_Vl?o00000_nbUk`02Ol0003o
]9Jho`000?n_T[Wo0000okVN_Ol0003o/Yc0o`000002ok2@]0?o000000_o/I:go`000?l0003o0000
ol>bbOl0003oWWJUo`000?nHL:?o0000oiI`YP05o`000003ohiYXol0003oO5VN00;o000000?oJ5V]
o`000?l000001?l000002omWEjco0000o`000?l0003oH4:Go`000?mdE9ko0000of=6VOl0003oJ5FY
00Oo000000CoIdFFo`000?l0003oIdVK1?l000000omfEYoo0000ofa<V`02o`000003ogaX/_l0003o
TWB_00?o000000GoN66/o`000?l0003o0000ojk<k`0<o`000003okS<jOl0003o000000?o000000?o
XZOJo`000?l000001?l000001On/_nSo0000ojZnj?l0003oZKkY00[o000000GoZLodo`000?l0003o
Ym?go`000002ooooo`03o`000?oooooooooo02gooooo000Fooooo`;o000000?oX/Kbo`000?l00000
0_l000001OnY`nco0000o`000?l0003o[koV00?o000000Go/kcQo`000?l0003o0000okJig002o`00
0005okJig?l0003o0000o`000?nh]mP00_l000001Ong]mWo0000okVdeOl0003o^KGF00?o000000Co
^[CCo`000?l0003o^KCD0ol000001?nj/m?o0000o`000?ni/m@2o`000005okRad_l0003o]jg?o`00
0?nh/M800_l000001onf[<oo0000okJWbOl0003o]Zc@o`000?neY/T00_l000001?neXL?o0000ok>U
b_l00002okBO``;o000000?o/Yk3o`000?l000000_ndV[d2o`000005ok>I_?l0003o0000o`000?nb
Uk`00_l00002okBF^0;o000000Co^Ijmo`000?l0003o^Ibj0ol000001OngV[[o0000ok6B]ol0003o
e<cB00?o000000GoWWJUo`000?nHL:?o0000oiI`YP02o`0000;oe<S>0_l000001on>JJ?o0000o`00
0?l0003oJ5V]o`000?m_V>T02?l000000omP@YOo0000o`000003o`0000;oJ5FY0ol000001?mnFioo
0000o`000?mWAIH5o`000007og=CW_l0003o0000o`000?m/C9_o0000ofe@W`04o`000005ogaMY?l0
003oN66/o`000?n7Ol@00ol000000onLS<;o0000oi1m^P02o`000003oi:5`_l0003oVYO?00Co0000
00?o[kKNo`000?nWZmX00ol000001OnV[Mgo0000o`000?l0003o[KoW00Ko000000GoZ/G]o`000?l0
003o0000oj[<l@02o`000003ojWBm_l0003o000000Oo000000?oooooo`000?ooool0;Oooool001Ko
oooo00Go0000ooooool0003o0000oiS8n003o`000005oj76l_l0003o0000o`000?nY`nd00ol00000
1On^`>Oo0000o`000?l0003o/[cQ00;o000000Go/[cQo`000?ne^]co0000okFig@04o`000003okNg
fOl0003o]kKI00?o000000Co^;CFo`000?l0003o]k?D0ol000000onh/M?o0000o`000002okN^d0;o
000000?o]jg?o`000?l000000_ngZ</2o`000008okJWbOl0003o0000okJRa?l0003o^:71o`000?ne
XL<3o`000008okBO`ol0003o0000okJL__l0003o^Ijmo`000?ndV[d2o`000006okRL_?l0003o_jK1
o`000?nhVk_o00000_nlXKd3o`000009ol6Y`_l0003oaKC:o`000?niW;[o0000okn^bOl0003o]iZj
00Co000000?o/Ig4o`000?l000000_nNMZD4o`000003og]g`ol0003o000000;o000000?oSVVSo`00
0?mlFIh01ol000001OmeBHoo0000o`000?l0003oK52O00;o000000?oG46Ho`000?l000001?l00000
1OmgGJOo0000o`000?l0003oKDVF00?o000000KoSh_;o`000?l0003oLe>No`000?mRB9d6o`000003
ogIFWol0003o000000Go000000Ko^[gLo`000?nLS<;oW8c2o`000?n@OKX4o`000003okS5i?l0003o
000000Go000000SoYJWIo`000?l0003o[/3Wo`000?n^`>Oo0000ojg5j`?o000000CoZ/K^o`000?l0
003oZM3d3Ol000001OnRf?_o0000oooooooooooo000002gooooo000Eooooo`03o`000?oooooooooo
00;ooooo1Ol000001OnIaoOo0000o`000?l0003oX/Gb00?o000000?oZL;/o`000?l000000_l00000
2On^_nKo0000o`000?l0003o/[_Qo`000?nb^]oo0000okFig002o`000005okBgfol0003o]KGIo`00
0?nf]=L00_l000002Onf/]Go0000okN_d_l0003o]k3Bo`000?ng[Loo0000okN^d002o`000005okNZ
c?l0003o^:O8o`000?ngZ</01?l000001OniXl?o0000okJRa?l0003o^:7100;o000000Co^j?1o`00
0?ngW[oo00000_njXKl2o`000003okVN_Ol0003o000000;o_jO20_l000001OnoY/7o0000o`000?l0
003o_:6m00;o000000Gob/?Co`000?l0003o0000olFdbP03o`000003okn^bOl0003o000000Co0000
0_naWL@2o`000003oiifYOl0003o000000Co000000?oNV:/o`000?l000000_l000001?mlFIko0000
o`000?o5/lP4o`000005ogE9Sol0003oIeN/o`000?m/D9l01Ol000000omSAYWo0000o`000003o`00
0005oeLlU_l0003oKDVFo`000?mWAIH00_l000000om_B9?o0000o`000003o`0000;oKF:e00Ko0000
ogQHXOl0003oMUJOo`000?mkGZH2o`000003okJkgOl0003o000000So000000Co[[;Ko`000?l0003o
`]o^0ol000001OnV[=_o0000o`000?l0003o[;oX00Ko000000?oZ<gco`000?l000001_l000000onQ
f?_o0000o`000002o`000003oj?EnOl0003o000000So0000;Oooool001Gooooo00?o0000oooooooo
ool01?ooool8o`000003oi[6m_l0003o000000;o000000GoXlC`o`000?l0003o0000oj[0jP03o`00
0005ojnlhol0003o0000o`000?nb^=h00ol000001?ne]MWo0000o`000?ne/mH3o`000005okN_d_l0
003o0000o`000?ng[Ll00_l000001OnhZ/co0000o`000?l0003o^:O800;o000000Go^JK6o`000?nl
ZLOo0000okVS``02o`000005ok^Va?l0003o_jk9o`000?nkXl400ol000002?njXKoo0000o`000?no
ZLCo0000olFldOl0003o_jO20_l000001Oo6_=3o0000olKLjOl0003oaKO=00co000000CoShG4o`00
0?nQSl;oXHo22Ol00002ol6hdP;o000000CoNV:/o`000?l0003oOUZM1?l000000oo5/lSo0000o`00
0002o`000003ogE9Sol0003o000000Wo000000GoK4FBo`000?l0003o0000oeLlUP03o`000006ofM5
U_l0003o0000ofm8Tol0003oKDRE0_l000001?mRB9go0000o`000?n7KJl2o`000005ogIFWol0003o
NejVo`000?n=N;L01?l000001On3OLCo0000ohMn`_l0003oTXW600[o000000?oXK_[o`000?l00000
2_l000000onOe?[o0000o`00000;o`000003ojWCm_l0003o000000;o000000CoYmWio`000?l0003o
0000;?ooool001Gooooo00?o0000ooooooooool01Oooool=o`000003oic7mOl0003o000000;o0000
00SoZkoXo`000?l0003o[;oXo`000?n`^n;o0000ok6jh@?o000000co];KJo`000?l0003o]KOJo`00
0?nf/MCo0000okRbdol0003o]jk?o`000?ni[/h2o`000005ok^ad?l0003o^J[:o`000?nk[L/00ol0
00002?nlZLOo0000o`000?no/Lco0000ok^Va?l0003o_jk90_l000001Oo3_]Go0000o`000?l0003o
a;cB00;o000000?oa=WYo`000?l000002?l000001?nJVM;o0000o`000?nEVMD2o`000004oj26^?l0
003oXgNQo`0000;oVgNZ0_l000001?nQSl;o0000o`000?l00002oha^[006o`000?nQLYgo0000oiih
Yol0003o`KSB1_l000001OmnFYgo0000ohIQX?l0003oVGN/00?o000000?oU6^Po`000?meBHl01Ol0
00000omP@YOo0000oea1V002o`000004ohAMWOl0003o0000of4mT0?o000000GoF4JQo`000?l0003o
0000ogUAUP02o`000003ofe8UOl0003o000000Go000000?oN5RQo`000?mfEYl00ol000000on@N;Co
0000o`00000Co`000003oj7Cn_l0003o000000[o000000KoZL_bo`000?l0003o[<gao`000?n]do@?
o`0002_ooooo000Eooooo`;o00002OoooolEo`000009ojg0j?l0003o[L?Zo`000?nb^n7o0000ok:n
hol0003o]KOJ00;o000000Wo]kWKo`000?l0003o0000okVeeOl0003o^[_Jo`000?nk/M000_l00000
1Onl^=Go0000okg3g_l0003o_[C@00;o000000Oo`<7Ko`000?l0003o0000ol:oeol0003o_mCY00ko
000000GoWYkDo`000?l0003o0000oiZIdP02o`000004oj:4/ol0003oZX:YojZ2Z@;o00000_nSMj40
2?l0003oVgNZo`000?n]QZ_o0000ojYjWol0003oW76Q0ol000001_nQLYgo0000o`000?oUbK_o0000
oiIRTPGo000000GoOUZMo`000?n6HJ3o0000oiUg[007o`000003ofm5Sol0003o000000?o000000Co
G46Ho`000?l0003oQ5fM0_l000001?mQ?I3o0000o`000?mG?9H4o`000004ogUAU_l0003o0000ofe8
U@;o000000Co[[SQo`000?l0003oETJS0ol000001OmfEYoo0000o`000?l0003oT7Rd00;o000000Go
MFnmo`000?mgQMCo0000ohJdl`02o`000007ok;1iOl0003o0000o`000?nIVM;o0000oiNXhP06o`00
0003ojVliol0003oZkOR00?o000000Co[/;Yo`000?l0003o/L_]5?l000000onScOKo0000o`00000[
ooooo`005Oooool00ol0003oooooooooo`09oooooago000000Co//?Wo`000?l0003o[l[^0ol00000
1Oneb>So0000o`000?l0003o^/GS00;o000000Go]=3^o`000?l0003o0000okWAk002o`000003oj_I
mol0003o000000Ko000000WoW[o`o`000?l0003oY:3Ao`000?nXSKWo0000oj:Md?l000000_nWRkP0
1Ol0003oZhBZo`000?nTQ[Co000000;oZX6X0_l00002ojZ2Z@;o00000_nSMj43o`000004ojf6Zol0
003oZWZOojYjW`;o000000GoY7:Jo`000?nQLYgo0000onG9^`02o`000003oiIRT_l0003o000000;o
000000?oNeZPo`000?mnFYd02_l000000om_AHoo0000o`000008o`000005ofa5T_l0003o0000o`00
0?mG?9H01?l000000omiDIKo0000ofm8T`02o`000003ogEHXol0003oMTnG00?o000000?oFEBbo`00
0?l000000_l000000oncV;co0000oi1h]006o`000004ol;6gOl0003o0000ojRGa0Go000000GoZj_G
o`000?l0003o0000ok2ih004o`000005okC7j?l0003o0000o`000?ncd_004?l000000onUb?;o0000
oj[3k007o`0002[ooooo000Eooooo`03o`000?oooooooooo00_ooooo7ol000000onHd?_o0000o`00
0008o`000003oik=n?l0003o000000Co000000CoX[c/o`000?nWYM?oYjGC0_l000001onVX];o0000
o`000?nZTKco0000ojBPdOl000000_nXSKT00ol0003o[XR]o`000002o`000004oj^4Z_l0003o0000
o`0000;oZX6X0_l00002ojZ2Z@06o`000?n/O9oo0000oj=gXOl0003o]XRU0ol00002ojYjW`;o0000
0_nTLYX3o`000003oj5^Uol0003oUV:B00;o000000GoR5RBo`000?l0003o0000ogiJW@0:o`000003
ofm5Sol0003o000000;oPF>W1_l000000om/AI;o0000o`000004o`000007of13VOl0003oNE6Fo`00
0?m_B9?o0000ofe8U@02o`000003ogI?Uol0003o000000?o000000?oMYKTo`000?l000001Ol00002
oiR5_P0:o`000?o>bMGo0000okRYb_l0003oZ9O4o`000?n/W/[o0000oj^Qc@Ko000000?o]/3Qo`00
0?ndeO404?l000000onY_nWo0000o`000006o`000003ok35j_l0003o000000Go00002?ooool2o`00
00Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000=ooooo`005Oooool00ol0003o
ooooooooo`0>oooooa?o000000?oSKoho`000?l000002_l000001OnQ]>Ko0000o`000?l0003oYK3P
00?o000000GoYjcKo`000?n/Wl[o0000ojNXe`03o`000008ojNUdol0003o0000oj^E_ol0003o/8nd
o`000?nZTK`2o`00000<ojn;/?l0003o0000o`000?n^R:go0000ok>9Z?l0003oZhBZo`000?nbQZKo
00000_nZPJP00ol0003o/hJUo`000002o`000008ojalWol0003o0000o`000?nfR:Go0000okR8X_l0
0002ojYjW`;o00000_nTLYX3o`000003oj5^Uol0003oUV:B00;o00000_n8F984o`000005omB[[_l0
003o0000o`000?m5;Y000ol000001OmeBHoo0000o`000?l0003oPF>W00?o000000WoMe2Fo`000?mW
?hko0000ofa5T_l0003oHCf@o`000?mXL<L00_l000001omP@iWo0000o`000?l0003oKdRCo`000?m]
B9D00_l000001?mfCiOo0000o`000?mdJKP3o`000007oif1]?l0003oTVnXo`000?n?K:Oo0000oi5b
[@02o`000004om?:dOl0003o0000okRYbP?o000000Ko[9k:o`000?l0003o`mSYo`000?nZlo@7o`00
000:oiC2m_l0003o0000ojJ`h?l0003o[ZkGo`000?nW]^Co0000ojneg@;o000000Oo]KcOo`000?l0
003o0000ok?0i?l0003o]<c[00So000000?oY]Sio`000?l000000ol00006ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00[o
oooo000Dooooo`?o00004?oooolGo`000007oinlkOl0003o0000o`000?nW]N?o0000ojFah@03o`00
0005ojV[f?l0003o0000o`000?n[YM000ol000001on/Wl[o0000o`000?naVKoo0000ojbJa?l00000
0_naU;T2o`0000;o/8nd00Go0000okJA/?l0003o[h^`o`000002okF=[@;o00000_ncRJP2o`0000;o
/XJV0ol000002_ncQZGo0000okJ6Xol0003o[7bOo`000?o1U:So0000okJ8YOl00002okR8XP04o`00
0?nZNYoo0000o`0000;oY7:J0ol000001OnQKYOo0000oiIRT_l0003oSU^A00Wo000000?oKDRDo`00
0?l000000_l000000omeBHoo0000ofm5S`05o`000007ogM@U_l0003oIcn>o`000?m/AI;o0000of4m
T006o`000003oeXoUol0003o000000?o000000CoPENGo`000?l0003oLE6M1?l000001?nMPKCo0000
oi9_Z?l00002ohm/Y`;o000000?odl[Ao`000?l000000_l000000on_^n?o0000ojfUc`0:o`000005
ojbPb_l0003o0000o`000?n]Ym400ol000000on^[]Oo0000o`000002o`000003ok_7i?l0003o0000
017o000000?oWl_go`000?l000001_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool02_ooool000Gooooo1Ol00003ooooo`;o00001Oooool0
0ol0003oooooooooo`0Booooo`Co000000?oTkgdo`000?l000005Ol000003on/^^Co0000ojb^fOl0
003o/[;Ho`000?n_Y/oo0000okFZc_l0003o/Io6o`000?ngX/Co0000ok6I_`03o`000004ok6D^Ol0
003o0000okNF]P?o000000Co]Y6`o`000?l0003o00000_neSJd2o`0000;o/hVX0_l00002ok:6YP05
o`000?nnTj[o0000ok>6YOl000000_nfQZ<2o`0000;o`IBX0_l00002okR8XP?o000000?oZGJKo`00
0?nTLYX00ol000000onQKYOo0000o`000003o`000003ohQHT_l0003o000000;o000000CoP52>o`00
0?l0003oKDRD1?l000000omeBHoo0000ofm5S`07o`000005ofLoS_l0003o0000o`000?mQ?I002?l0
00001om]FZco0000o`000?l0003oPENGo`000?mfCiL00_l000001oobkL3o0000o`000?l0003oWH6d
o`000?nBKjP00ol000000oo?bMCo0000o`000008o`00000;ojRA_Ol0003o[iBjo`000?nWU<;o0000
okBO`ol0003o[:3:o`000?nfYlX00_l000001ono^mKo0000o`000?l0003o_L;Mo`000?nlgo406Ol0
0005ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`0:ooooo`001_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool04oooool8o`000003oi^olOl0003o000000?o000000?oV;S^o`00
0?l000000_l000000on;/_3o0000o`00000=o`000005okFZc_l0003o0000o`000?ngX/@00_l00000
2?nn/<co0000o`000?l0003o_jS2o`000?ngU[Ko00000_noX[X2o`0000;o_ibe0ol000001OnnUjoo
0000o`000?l0003o_I>[00?o000000Co_Y>Zo`000?l0003o00000_nfQZ<2o`0000;o`IBX00[o0000
om2W[ol0003o^8RRo`000?naPZ7o0000ojUfVol0003oY7:J1Ol000001OnFHY;o0000ohiKTOl0003o
R5RB00Co000000?oP52>o`000?l000000_l000001_m5;Y3o0000o`000?meBHoo0000ofm5S`;o0000
00?oM4J;o`000?l000001?l000001om[AI;o0000o`000?l0003oMU2Go`000?mK>i401?l00002ofeJ
[0;o000000?oPENGo`000?mfCiL00ol000000on4GYko0000o`000004o`000004okc5hOl0003o0000
o`0000;oV7N]0ol000001?nYS[Wo0000ok>D]_ncU;H2o`0000;o[iBj0_l000001_ndWl?o0000o`00
0?o1]<ko0000olSLi`Wo000000CoUk3Yo`000?l0003oYJCD0ol000001onWZMSo0000ojfXd_l0003o
Z:gKo`000?n][ML00ol000001On]/M_o0000o`000?l0003o[KCN00;o00001Oooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l0000=ooooo`001oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05?oooolCo`00
0007oj:fiol0003o0000o`000?nU/=oo0000oifXg@04o`000003oh^Rhol0003o000000Ko000000?o
^m_`o`000?nn/<`00ol000001OnoZ<;o0000o`000?l0003o_j:j00?o000000Co_ibeo`000?l0003o
ck[60ol00002olnc_`;o00000_oB];`2o`0000;oaYn`00Co0000okJ6Xol0003oe[Bh0ol000001oo@
Yjoo0000o`000?l0003o/H:Qo`000?nYMY/01_l000001_nQKYOo0000o`000?n>Fi7o0000ohQHTPCo
000000CoP52>o`000?l0003oQ5:=1?l000000omeBHoo0000ofm5S`02o`000003ogA6Rol0003o0000
00Co000000?oJdFBo`000?n1HJ@00ol000001OmK>i7o0000o`000?l0003oFSnG00So000000?o`Z:h
o`000?n4GYh01?l000000on4[_3o0000o`000003o`0000;oV7N]00?o0000ojn:[on_RZl00_l00002
ok>D]P03o`000?nkW[_o000000;o000000?o_j_5o`000?o@f^401_l000001OnZTK_o0000o`000?l0
003o[9O100?o000000Go[Ig7o`000?l0003o0000ojfSc@03o`000003ojfXd_l0003o000000;o0000
00Go][[Lo`000?l0003o0000ok>lh003o`000003ok6mh_l0003o000000Cooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`00013ooooo0008ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`02ooooo`;o00005_ooool2o`000003oiK2m_l0
003o000001Go000000OoZ:WGo`000?l0003o0000oj^QcOl0003oXIW=00?o000000?oXY;4o`000?l0
00000_l000000onRRkco0000o`00000;o`000005olnja_l0003o0000o`000?o?/kl00ol000001?oB
];co0000o`000?l00002olJO/0?o000000?oe[Bho`000?l000000ol000000oo2Y;_o0000ok62X@03
o`000003ojAaV?l0003o000000;o000000CoXFjGo`000?l0003oSU^A1_l000001_n0D8ko0000o`00
0?n4DXgo0000ohaJT@Oo000000?oM4J;o`000?m^@h`01?l000001Om[AI;o0000oh5QY?l0003oND^>
00[o000000OoP5^Mo`000?nILjKo0000ol:R^?l0003oQ5jN00;o00000_nRO:T01_l0003o`YV]o`00
0?n_Q:Oo0000oj9iYP?o00000_n_RZl00ol0003oa:Bho`000004o`000003om3=e_l0003o000000Co
000000[oZH^eo`000?ndU;Ko0000ojZA^ol0003o]9Zlo`000?n/Ul7o00000_ndWl<00ol0003o_K7>
o`000002o`000007ok^ddol0003o0000o`000?nh^=So0000okW9iP03o`000003okG7j?l0003o0000
00Oo00001?ooool2o`0000[ooooo0_l00002ooooo`Go00003?ooool000Gooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05oooool0
0ol0003oXkWYo`000002o`000005oj2hjOl0003o0000o`000?nM]^X00ol000001OnI/n[o0000o`00
0?l0003oU;3Z00go000000Oo/jgBo`000?l0003o0000okJUb?l0003o[I>k00?o000000?o[Hbco`00
0?l000000_l00002oj60/0;o00000_nPO:/3o`000005oimgY_l0003o0000o`000?nNMJ@00_l00000
0onYN9go0000o`000004o`000003ojajW?l0003o000000;o000000?oXFbDo`000?l000000ol00000
0onYMY_o0000ojAaV004o`000006oj5^Uol0003o0000ohiKTOl0003ojLB`1?l000002?n0D8ko0000
o`000?n4DXgo0000ohaJTOl0003oX6nI0ol000001On?GI;o0000ogA6Rol0003oKT><00?o000000?o
Icn>o`000?m[AI800_l000001omiBhko0000ogmBT_l0003oVFnQo`000?n5E9001?l000001?n0Figo
0000oiUcY_nILjH5o`000003oj9lZOl0003ogK:[00;o00000_n_Q:L2o`0000;o]Xn]1Ol000000oo?
`<co0000o`000002o`000004ok::Zol0003oYhF`o`0000;o/hj`0_l00002okBD]P;o000000Go]9Zl
o`000?l0003o0000okBO``02o`000003okfac_l0003o`/cR00ko000000?oW]?jo`000?l000001?l0
000Uooooo`001Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Hooooo`03o`000?nZ]n;o000000;o000000GoZ[CPo`000?l0003o
0000oj^ag@03o`000005oj^]fOl0003o0000o`000?n[Z=@01?l000001OnQX=Co0000o`000?l0003o
WYW>00Go000000?o]]7^o`000?nfYLP00ol00002okRM_P;o000000?o^9Neo`000?n]Qjd00ol00000
1On/PjSo0000o`000?l0003oZgjS00?o000000CoZgbPo`000?l0003o00000_nYN9d2o`0000;oZ7FJ
0_l00002ojajW003o`000?n/MIKo000000So000000?oY76Ho`000?nLIHl00_l000001?nQKYOo0000
o`000?n>Fi46o`000008oh1@S_l0003o0000ohABSOl0003oS5ZAo`000?nPKiT3o`000005ohmMT_l0
003oM4J;o`000?m^@h`00ol000001OmW?hko0000of]5T_l0003oN4V=00;o000000GoOe:Bo`000?nI
Kj7o0000ohEDT002o`000004of55V_l0003oP5^Mo`0000;oVG>V0_l000000onMKI[o0000oimaWP02
o`000003omfbZol0003o000000;o[hBW0_l00002okJ?[@03o`000?oRd/Oo000000?o000000Co/XJW
o`000?nVPJ_o00000_nbRZ/2o`0000;o/hj`1Ol000001Oo0Yl3o0000olk=fOl0003o_jc700go0000
00GoUkoco`000?l0003o0000oifol005o`000003ojJei?l0003o000000;o00009?ooool000Kooooo
0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`0Jooooo`03o`000?nZ_NOo000000;o0000
00GoZkgVo`000?l0003o0000ojfli@04o`000005ojn_f?l0003o0000o`000?n`Zm800ol000002Ona
YLco0000oj^Laol0003o/Yo5o`000?nZUL7o0000ok:I_P06o`000004okRM__l0003o0000o`0000;o
^9Ne0_l000003_nhTJko0000ojb3Z?l0003o]h^Xo`000?n[OZ?o0000okN9Y?l0003oZgbPo`000?nf
Q:3o00000_nYN9d2o`0000;oZ7FJ0_l00002ojajW0?o000000?oXFbDo`000?l000000ol00002ok^4
VP;o000000?oW6F?o`000?l000001?l000001?oK`Koo0000o`000?n6DX`2o`00000<oh1@S_l0003o
0000ohABSOl0003oS5ZAo`000?nPKiWo0000ocLQROl0003oSefB0ol000002Om^@hco0000ofm:UOl0
003oIcn>o`000?m[AI;o0000ogQ9S@02o`000007ogmBT_l0003oVFnQo`000?n5E93o0000ohAHUP03
o`000003oh1KWOl0003oVG>V00;o000000CoWFfJo`000?nOLIko00000_oM/Z/00ol0003objFbo`00
0002o`000003ol:O]_l0003o000000;o00000_n^Oj82o`0000;o/XJW0_l00002ok::Z`03o`000?o1
W;?o000000Co000000?odlgCo`000?l000001ol000001OnIX]_o0000o`000?l0003oWJOM00co0000
00Go[JWCo`000?l0003o0000ojf]e`04o`0002?ooooo000Cooooo`03o`000?oooooooooo01_ooooo
00?o0000oj?5lOl000000_l000001OnPb?Co0000o`000?l0003oW<ch00So000000?oZ/_ao`000?nc
]]/01?l000001?nbWlGo0000o`000?l00002ok:I_P;o00000_nbTkL2o`000003ok:>/Ol0003o0000
00Co00000_nhTJh2o`0000;o]h^X0_l00002okN9Y0;o00000_nfQ:001?l0003oZGRMo`000?l00002
ojQeVPGo000000?o[7FFo`000?nQK9@01Ol00002ok^4VP;o000000?oW6F?o`000?nIHXl00ol00000
1ooK`Koo0000o`000?l0003oQU:<o`000?n0Di<00ol000001?n4DXgo0000ohaJTOn<FY44o`000007
ohmMT_l0003o0000o`000?m^@hco0000ofm:U@04o`000005oga>Sol0003o0000o`000?moDY800ol0
00000on5E93o0000ohAHUP03o`000005oh1KWOl0003o0000oi]/V_l000000_nMKIX2o`000003omfb
Zol0003o000000;o00000_oFf]/2o`000003ok1oX?l0003o000000;o[WnR0_l00002ok:6Y`03o`00
0?o1VJko000000;o000000?o`Ibco`000?oHbld01?l000001?nPQkSo0000o`000?nRSKd2o`000005
ojb?]ol0003o0000o`000?n]U;d00ol000003on]V/?o0000okBQaOl0003o[Yo8o`000?ncYL[o0000
ojjTc_l0003o/ZW?o`000?n]ZM?o0000ok6]e003o`000003ok2`f?l0003o000002?ooooo000Coooo
o`;o00007OoooolKo`000005okV^col0003o0000o`000?nkZLL01?l00002ok:>/@;o00000_naRJ/5
o`0000;o]h^X0_l00002okN9Y0;o00000_nfQ:03o`000005ok=oW?l0003o0000o`000?njQYd00ol0
00001On/MIKo0000oj5/U?l0003o^8:I00?o00000_nkQ9X2o`000003oiaUSol0003oVF:?00Co0000
00KoXf^Ao`000?l0003oQU:<o`000?n0Di<3o`000006ohABSOl0003oS5ZAohaJTOl0003oQU6:0_l0
00001_n?GI;o0000o`000?mdAX_o0000ofi3S0;o000000CoIcj<o`000?l0003oO4j?0ol00002ogmB
TP;o000000?oQEB@o`000?n4F9H01_l000001?nKK9[o0000oie]V_nMKIX4o`000003oiY/Vol0003o
/WnM00?o00000_n`Oj001_l0003o_8bSo`000?n^Oj;o0000ol:EZ@?o000000?o`IV^o`000?oKa/D0
1_l000004on[QJgo0000o`000?l0003oZhZbo`000?neTkCo0000ojb?]ol0003o]IRio`000?n]U;go
0000okBL_ol0003o[I[3o`000?ndXLD00ol000000oncYL[o0000o`000006o`000005okJkgOl0003o
0000o`000?nc^ml00_l0000Rooooo`004oooool00ol0003oooooooooo`0Nooooo`;o000000GoYkCR
o`000?l0003o0000ojJbh@03o`000005ojF^g_l0003o0000o`000?nSZ]`00ol000001OnPYMWo0000
o`000?l0003oWIoF00?o000000?oVISBo`000?l000000_l000000onne^co0000okbT`004o`0000;o
/HV[0_l000000onaQJKo0000olV]_@03o`000003ol^W]_l0003o]hVT00;o00000_nfQ:07o`000009
okZ6WOl0003o0000o`000?n/MIKo0000oj5/U?l0003o^8:I00;o000000?ogjbQo`000?nkQ9X00_l0
00000onLIHoo0000oiURS`02o`000003olJ?W?l0003oXf^A00;o000000?oQU:<o`000?n0Di<00ol0
00001_n4DXgo0000ohaJTOn<FY7o0000ohIARPGo000000?oM4J;o`000?m^@h`00_l000001?mW?Xco
0000o`000?mlCXl3o`0000;oOe:B0_l00002ohEDT0Oo000000CoVfbJo`000?nMKI[oWFfJ0_l00000
1?nTLISo0000oiY/Vol00002ok9oW@06o`000?o4TJ;o0000ok1oX?l0003o_8bS0ol000000oo2UJWo
0000on36_P06o`000005ojZ2ZOl0003o]Hb[o`000?n[QJd00_l000000oneSjoo0000o`000002okFC
]0;o000000Go]IRio`000?l0003o0000okBL_`04o`00000;ol2keOl0003o0000o`000?nl^mSo0000
ok[8iOl0003o^K_Ko`000?nga>D00ol000000ond`^Co0000o`000002o`0002;ooooo000Cooooo`03
o`000?oooooooooo01kooooo00?o0000oj^cgol000000_l000006On[/=co0000ojj^eol0003oZjcH
o`000?n_Z]?o0000oj^We?l0003o[jG>o`000?nZX/oo0000ojnPb?l0003oZIc9o`000?n_V/;o0000
ojRFa?l0003o[iFlo`000?nWT;d01ol000001onmW[Wo0000o`000?l0003o_YVbo`000?naQJH00_l0
00000onaPZ;o0000o`000003o`000007olVO[_l0003o0000o`000?o4UZOo0000ok=oW003o`000005
okZ6WOl0003o^hJMo`000?n/MIH00ol000001_nhPYWo0000omn/XOoO[:7o0000ok^4VP;o000000?o
W6F?o`000?nIHXl00_l000001Oo6Sico0000oj=[TOl0003oTef>00;o000000CoP5>Co`000?l0003o
00000_n4DXd01?l0003oS5ZAo`000?n6DHX5o`000003ogA6Rol0003oKT><00Go000000KoO4j?o`00
0?l0003oND^>o`000?moDY82o`0000;oQEB@0ol000001?n;Fi?o0000o`000?l00002oi]/VP04o`00
0?nMKI[o0000o`0000;oY76H0_l00002ok9oW@03o`000?o4TJ;o000000;o000000Co_8bSo`000?oR
`[Ooh/:g1Ol000001_nYOZGo0000okF9Y_l0003oZX:Yo`0000;o]Hb[0ol000000oneSjoo0000ol6Q
^003o`000009oknS_Ol0003obKg?o`000?nmY/;o0000olBld_l0003o`mCW00?o000000?o_/gVo`00
0?l000001_l000000on]b^oo0000o`000003o`000003oj_0jOl0003o0000027ooooo000Cooooo`03
o`000?oooooooooo01oooooo00?o0000ojjeg_l000000_l000001On_/]_o0000o`000?l0003o/:oG
00Co000000Go[jG>o`000?l0003o0000ojnPb003o`000005ojnJ`_l0003o0000o`000?n_UK`00ol0
0002ojn@]P;o00000_n^Rk08o`000003okjE[Ol0003o/H:R00So000000_oa9JWo`000?ncOico0000
om6SZ?l0003o^XJMo`000?nkQYgo0000ojaeUP03o`000004okR2VOl0003ogjbQomn/X@Co000000?o
W6F?o`000?nIHXl00_l000001Oo6Sico0000oj=[TOl0003oTef>00Co000000SoP52>o`000?l0003o
Q5:=o`000?n<FY7o0000ohIARPGo000000?oM4J;o`000?m^@h`00ol000000omW?Xco0000oga>S`02
o`00000;ogU;S_l0003oOe:Bo`000?n8EXoo0000ohEDT?l0003om<6Ho`000?n;Fi<01?l000000onK
K9[o0000oie]VP02o`0000;oY76H00?o0000ol:=W_l000000_l000001?o4TJ;o0000omN_[ooG[jl2
o`000005on;2]ol0003o0000ojQkX_l000000_neQZ<2o`0000;o]HVV0_l00002okF<Z`03o`000?o2
W[?o000000;o000000Oo`J6ho`000?o>_lco0000oknS_Ol0003obKg?00co000000?oY/Sao`000?l0
00001_l000001On//]co0000o`000?l0003o[;CN00;o00008?ooool001;ooooo0_l0000Rooooo`03
o`000?n[^nKo000000;o000000?oZk_Uo`000?l000000_l000001On`]=_o0000o`000?l0003o/[;H
00?o000000_o];3Eo`000?ncXlSo0000okJ^dOl0003o]9o2o`000?ni[<co0000okFJ_003o`000003
okJF]ol0003o000000;o00000_n^QZ/4o`000003okjE[Ol0003o000000?o000000Co[gfNo`000?l0
003o/7fL1Ol000002?oAXjSo0000o`000?l0003o^hJMo`000?n/MIKo00000_o7U:02o`000004omn/
XOl0003o0000ojQcV0;o000000?oW6F?o`000?nIHXl00_l00002olJ?W0;o000000?oTef>o`000?l0
00000_l000002?n0D8ko0000o`000?n4DXgo0000ohaJTOl0003oQU6:0_l000001_m;;H[o0000o`00
0?mdAX_o0000ofi3S0?o000000?oIcj<o`000?l000000_l000001omiBhko0000o`000?l0003oR5J?
o`000?n5E9000ol000000on;Fi?o0000o`000002o`000003oi]/V_l0003o000000;o[WVI00Co0000
ojAaV?l0003o`XfN0ol000001oo4TJ;o0000omN_[ooG[joo0000ojUiWol000000_ndPj02o`0000;o
]HJS0_l00002okF9YP03o`000?o4W:oo000000;o000000?o`Yjco`000?oC`LP03Ol000001OnWY=?o
0000o`000?l0003oZJSF00?o000000OoZjcHo`000?n^Ym7o0000oj^_f_l0003o[Z_D00?o000000?o
[ZkGo`000?l000000ol0000Oooooo`004_ooool00ol0003oooooooooo`0Rooooo`03o`000?nT_^co
000000;o000000?oX[o^o`000?l000001_l000000onRa_;o0000o`000003o`000003ok30i_l0003o
000000;o00000_ni[<`2o`000007ok^Yaol0003o]YJgo`000?nnYl?o0000okJB/@04o`000007ojf2
Yol0003o0000o`000?oIb/_o0000okf?YP03o`000003okj>Y?l0003o/7fL00;o00000_n_NYX4o`00
0004ok^6WOl0003o[7FFo`0000;oaiBP0ol000000oneY/Wo0000ojQcV002o`000003oiaUSol0003o
VF:?00?o000000CoaXnLo`000?l0003oTef>1?l000001?n0D8ko0000o`000?n4DXd3o`000003ohIA
R_l0003o=b6900?o000000?oM4J;o`000?m^@h`00ol000000omW?Xco0000o`000002o`000007ogU;
S_l0003o0000o`000?n8EXoo0000ohEDT005o`000003ojifU_l0003o000000?o00000_n^NIT3o`00
0003ol:=W_l0003olL^Z00So00000_ndPj02o`0000;o]HJS00?o0000olFJZol000000_l000000oo4
W:oo0000omW4a@06o`000004oinDbOl0003o0000oj:Jc0?o000000OoYIo@o`000?n/V/Co0000ojNT
dol0003o[Ik800?o000000Co[Z?=o`000?l0003o/J?90ol000000onaYlko0000okBZcP03o`000003
ok>]d_l0003o000000;o00007oooool001;ooooo00?o0000ooooooooool08oooool00ol0003oY;WX
o`000002o`000005oj6hjOl0003o0000o`000?nN]nX05_l00002okjW``;o000000?o`:Fno`000?l0
00000ol000000onfRjSo0000o`000002o`000009omk;aOl0003o_XjTo`000?n`OIco0000okn=X?l0
003o[gZJ00?o000000?oi<Njo`000?l000000_l00002olNDX006o`000?nSJi;o0000okFVbOl0003o
Z7>H0_l000000onLIHoo0000oiURS`03o`000004olJ?W?l0003o0000oi=MSPCo000000CoP52>o`00
0?l0003oQ5:=0ol000000on6DH[o0000o`000003o`000003ogA6Rol0003o000000?o000000GoIcj<
o`000?l0003o0000ogQ9S@04o`000003ohQFSol0003oQEB@00Go000000Co[WJFo`000?l0003oiJfJ
0_l00002ojiiV@;o000000?ohK:Vo`000?l000000_l000000oncOi_o0000o`000002okN4WP;o0000
0_ndPj000ol0003oaYRWo`000002o`000003olFJZol0003oglO100Go000000?oVhk5o`000?l00000
1?l000000onYT;_o0000ok6C^004o`00000>ojbJa?l0003o0000ok6K`Ol0003o]j72o`000?nbWlGo
0000okJTa_l0003o/J?9o`000?neYlX3o`000003okBZc_l0003o]ZkA00?o000000Co];3Do`000?l0
003o00007_ooool001;ooooo00?o0000ooooooooool09?ooool00ol0003oZ;7Oo`000002o`000005
ojR^gOl0003o0000o`000?nWZmX01?l000001OnO[>3o0000o`000?l0003oW:WO00?o000000GoV:GN
o`000?l0003o0000oi>Pg@0<o`000003ol6R^Ol0003o]X^X00?o000000Co^8ZUo`000?l0003o_XjT
0ol000001OnoSJ3o0000ojmjV_l0003o]X2J00Go000000Gom>^lo`000?o7U:3o0000oj=[TP03o`00
0003ojQcV?l0003oXFZA00?o000000CoUen=o`000?l0003oaXnL0_l000000onCGHko0000o`000002
o`000004oh1@S_l0003o0000ohABS@?o000000?oQU6:o`000?l000000ol000000omdAX_o0000o`00
0003o`000005ofLnS?l0003o^H2Fo`000?mhBHd01?l000001?n8EXoo0000o`000?ob`ih4o`000008
ojifU_l0003oiJfJonF]V_l0003o`HfPo`000?n^NIT2o`000004on6bY_l0003o0000o`0000;o/gnK
0_l00002okN4WP07o`000?o6UZCo0000okB3X?l0003oaYRWo`000002onK<_@?o000000OoYH:_o`00
0?n`R:co0000ojJ6/_l0003o/8b`00Oo000000_o/I>ho`000?nhVk[o0000ok6G_?l0003o]ijno`00
0?naVl7o0000okNQ`P03o`000003okJTa_l0003o000000;o000000Oo^k;@o`000?l0003o0000okVb
d_l0003o^;KG00?o000000?o]kKHo`000?l000007_ooool001;ooooo00?o0000ooooooooool09Ooo
ool02?l0003oZjoJo`000?nZ[][o0000ojb/eol0003oZZ_G0_l000001OnZYm?o0000o`000?l0003o
ZZ??00?o000000_oZik;o`000?nTWm3o0000ojZJa_l0003oXi[<o`000?nZU/7o0000oj:Ea`09o`00
0007ol6R^Ol0003o0000o`000?o6Y;Ko0000okR:Y@06o`000009okn=X?l0003o0000o`000?nfP9[o
0000ojUcU_l0003ocYVO00Go000000OoXf^Bo`000?l0003o0000ojQcV?l0003oXFZA00?o000000Co
Uen=o`000?l0003oaXnL0_l000001_nCGHko0000o`000?naN9Co0000oh1@SP;o000000GoQ5:=o`00
0?n7DH[o0000ohIARP08o`000003ohmKT?l0003o000000;o000000?o^H2Fo`000?mhBHd01?l00000
0on8EXoo0000o`000003o`000003ok5iUOl0003o[WJF00Co000000Go`HfPo`000?n^NIWo0000on6b
YP04o`0000;o/gnK00Ko0000olbIX_l0003o]hBNo`000?o6UZ@2o`000003on[=^?l0003o000000?o
000000Go[hJYo`000?nUPZoo0000ok28[003o`000006ok2</?l0003o^IJco`000?n`Sk?o00000_ni
V;H2o`0000;o^9^j0_l000000ongW[ko0000o`000002o`000007ol2ccOl0003o0000o`000?nm//oo
0000okfieP03o`000003okZge_l0003o000000?o000000?o]kSJo`000?l000000ol0000Mooooo`00
4_ooool2o`0002Oooooo0ol000000on/[]Wo0000o`000002o`000009ojbXdol0003o[JWCo`000?n]
YLoo0000ojjVd?l0003o[Z;;00Co000000GoZY[6o`000?l0003o0000ojZF`@03o`0000;oZY6l0_l0
00000onYS;Oo0000o`000005o`000007olJT]_l0003o0000o`000?o4W:oo0000okB4X004o`000007
oljT[Ol0003o]X2Jo`000?nYLiKo0000oljIW`03o`000003ok9jU_l0003oXf^B00Go000000GoXFZA
o`000?l0003o0000oiMOS@05o`000003oi=MS_l0003o000000;o/GRD0ol000001on4DXgo0000ohMA
R_l0003oQU6:o`000?n8Dh/00ol00002oheUW`03o`000?n?Fi3o000000?o000000?o^H2Fo`000?l0
00000ol000000on=FY3o0000o`000004o`0000;o/GVE1?l000000oo/mZGo0000o`000003o`0000;o
/gfJ00Ko0000olB@W_l0003o/gnKo`000?o<VJ82o`000004oo3B/ol0003o0000on[=^0;o000000Go
[h>Vo`000?l0003o0000ojn6Z@03o`000004ok28[?l0003o^Y>_okZC[`;o00000_niU[<5o`000003
ol2V__l0003o000000?o000000Oo`kC<o`000?o3`=So0000ol2ccOl0003o_kcF00Co000000Oo^;gN
o`000?l0003o0000okNkg?l0003o]KOJ00?o000000?o]KOJo`000?nd/mP00ol0000Looooo`001?oo
ool3o`0000?ooooo0_l00006ooooo`03o`000?oooooooooo02Oooooo1?l000001On/[m[o0000o`00
0?l0003o[:gH00Co000000Wo[ZK@o`000?l0003o0000ojnTc?l0003o[Yk6o`000?naX/P00ol00000
0onbWlGo0000ok2G_@03o`000008ok2C^?l0003o0000ok6A]?l0003oZhZco`000?nbS[05o`000003
olBL[ol0003o000000Co000000?ocZB]o`000?nfP9X00ol000002Oo>VIoo0000om:PXol0003o/WZF
o`000?nSJi;o0000ok=kUP03o`000005oj5ZTOl0003o0000o`000?nGGhd01Ol000000onCGHko0000
o`000002ok5hU0?o000000[oQ5:=o`000?n7DH[o0000ohIAR_l0003oR5>;o`000?m;;H[o00000_n=
IIl4o`000003oimXTOl0003o^H2F00Go000000CoSEZ@o`000?l0003ol/>N0ol00002ok5iU@;o0000
0_nZLiD3o`000007okn8VOl0003ob9>Mo`000?ncOI[o0000olB@WP03o`000003olbIX_l0003ol=:c
00;o000000[o[h6So`000?l0003o0000ojn3Y_l0003o^i2Zo`000?n_QZWo00000_njTZ`2o`0000;o
^Y>_00?o0000olFU^Ol000000_l000002Oo3YKco0000olZkc?l0003o`:Jno`000?o6]lco0000olK7
f`08o`000003okS2hOl0003o]K[M00?o000000?o]KSKo`000?l000000_l000000ond[m?o0000o`00
0003o`000003okB_dol0003o000001cooooo0005ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo00?o0000ojRbh?l000000_l0
00000onW/^3o0000o`000002o`000007ojZ`g?l0003o0000o`000?nZ/=co0000ojj[e008o`000005
ok:OaOl0003o0000o`000?ndWL401?l00002ok6A]0;o00000_nbS[02o`000003ok28Zol0003o0000
00?o000000?oaI^/o`000?ngQ9l00_l000000onfP9[o0000o`000003o`000007om:PXol0003o/WZF
o`000?nSJi;o0000ok=kUP03o`000005oj5ZTOl0003o0000o`000?nGGhd01Ol000000onCGHko0000
o`000002ok5hU0Go000000WoQe6:o`000?n6DH[o0000ohQCRol0003oBbf:o`000?n=IIl00_l00000
0on1Chco0000o`000002oimXT@?o000000CoUUn>o`000?l0003oSEZ@0ol000000onXLICo0000o`00
0002ok5iU@;o00000_nZLiD2o`0000;o_hRI00?o0000olRCWOl000000_l000001?o4T9ko0000o`00
0?oki:D5o`0000;o[h6S00Co0000okb?Yol0003o00000_nkT:X2o`0000;o^Y:/00?o0000olNV]ol0
00000_l000000oo5YKWo0000olo1c00:o`000003okG@k_l0003o/L3U00?o000000?o];cPo`000?l0
00000_l000004_nc[=;o0000o`000?l0003o]:kBo`000?ne[<oo0000okB_dol0003o]JgAo`000?nf
[M3o0000okB_dol0003oooooo`0001_ooooo0002ooooo`Go00000_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo02Wooooo00?o0000ojJ`gol000000_l000000onT[n3o0000o`00
0002o`000003oj>ah_l0003o000000So000000?o[;?No`000?l000000_l000001ondZ/oo0000okBM
`Ol0003o]jc>o`000?nfW;d00ol000000oniVk[o0000o`000002o`0000;o/8R[0_l000000oniT:co
0000o`000007o`000005ok>1W_l0003oZ7:Fo`000?oBX:<00_l000000onSJi;o0000ok=kUP03o`00
0007oj5ZTOl0003o0000o`000?nGGhgo0000oi=KS003o`000003oi=MS_l0003o000000;o/GRD1Ol0
00001On7DH[o0000ohIAR_l0003oR5>;00Ko000000?oPDn<o`000?l000000_nOJ943o`000003oiIO
S_l0003o000000Co000000GoZ76Do`000?naNiSo0000ok5iU@02o`0000;oZW>E00?o0000on6[Vol0
00000_l000001?o8Tigo0000o`000?o^b:`6o`000003ojinXOl0003o_HnU00?o000000?o_8nWo`00
0?l000000_nkT:X00ol0003objNfo`000002o`000003olNV]ol0003oeLW>00_o000000OoZ[;No`00
0?l0003o0000ojjbfol0003o/:W@00?o000000Oo/Z_Ao`000?ndZ<go0000ok>/d_l0003o]:[>00?o
000000?o]Jc?o`000?l000000ol000000onf[M3o0000o`000002o`000003ooooool0003ooooo01Wo
oooo0002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001?ooool2o`00
02_ooooo00?o0000ojJ/fol000000ol000001OnT[Mgo0000o`000?l0003oXjcM00Go000000?oW[3T
o`000?l000000_l000000onG^>oo0000o`000005o`00000;okN/c_l0003o0000o`000?nl/<ko0000
okVK^_l0003o^j_9o`000?nfU;@00ol000000oo2X;Ko0000o`000002o`0000;o[H2S0_l000001oo@
^lKo0000ok>1W_l0003oZ7:Fo`000?oBX:<01?l000001OncNiKo0000o`000?l0003oXFZA00?o0000
00?oUen=o`000?nCFh`01_l00002ok5hU003o`000?mhB8_o000000;o000000GoQe6:o`000?n6DH[o
0000ohQCR`06o`000003oh5?S?l0003o000000;oWfRA00Co0000oi=LSOl0003oUUn>1?l000001ooS
bKgo0000o`000?l0003o/G^Ho`000?naNID00_l00002ojYcU@05o`000?oQZi_o0000o`000?omhi`0
0_l00002onk8[0;o000000?o/7nPo`000?nlS:<00ol000001onmSjGo0000om://ol0003o_8nWo`00
0?o=Z;@00ol000000oo;YkKo0000omcDd007o`000007oib^hol0003oZ:3>o`000?nT/>7o0000ojbT
c`03o`000004ojjWd?l0003o0000ok:Tb@;o000000Go/jK;o`000?l0003o0000okBXc@04o`00000@
okR[c?l0003o0000o`000?nhZlgo0000okV]c_l0003o]jc>o`000?nh[/oo0000okR_d?l0003ooooo
o`0000Wooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`000oooool00ol0
003oooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:oooool0
1?l0003oZ:WHo`000?nWZMP2o`000003ojNXeol0003o000000?o000000?oY:OHo`000?l000000_l0
00001OnNZ]oo0000o`000?l0003oVj[Q00ko00000_nkZlT2o`000007olNmdOl0003o`Z2fo`000?o?
_/[o0000okbC[P06o`000005ok>1W_l0003oZ7:Fo`000?oBX:<01?l000001OncNiKo0000o`000?l0
003oXFZA00?o000000?oUen=o`000?nCFh`00ol000001?nAH9Co0000o`000?naN9@2o`000009ogQ8
Rol0003o0000o`000?n7DH[o0000ohIAR_l0003oR5>;00Co000000?oLdF;o`000?n1Ch`00_l00002
oimXT@04o`000?nCG8go0000oiIOSP;o000000ooVF>@o`000?l0003o0000ojIlYOl0003o/G^Ho`00
0?naNIGo0000ok9kUol0003oZW>Eo`000?oQZi/02ol000000onlS:?o0000omJ`/@03o`000005om:/
/ol0003o0000o`000?o=Z;@01ol000001OnQUl_o0000o`000?l0003oYIc=00?o000000?oZ:3>o`00
0?l000000_l000001OneX/Go0000o`000?l0003o]Z?600?o000000go]ZG8o`000?niZLWo0000okJW
bOl0003o^J[:o`000?nj[/go0000okR[c?l0003o^Zg=00?o000000?o^Jg>o`000?l000000_l00000
0oni/M7o0000o`000003o`0000Oooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`02ooooo`001?ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0/ooooo`So000000?oZ:KDo`000?l000000_l000001OnVY=Co0000o`000?l0003oYj?B00Co0000
00GoXJ?Go`000?l0003o0000oj2Se`03o`000003oijPeOl0003oR:KY00ko000000Go/IRlo`000?nb
R:Wo0000om2kaP02o`000003ojQbU_l0003o000000;o000000?o_HZOo`000?ncNiH00ol000001onQ
JY7o0000o`000?l0003oUen=o`000?nCFh`00ol000001?nAH9Co0000o`000?naN9@2o`000009ogQ8
Rol0003o0000o`000?n7DH[o0000ohIAR_l0003oR5>;00Ko000000WoPDn<o`000?n?FXko0000oimX
TOl0003oTeb=o`000?nFGhh00_l000004OnIHi3o0000o`000?l0003oYWbUo`000?naNiSo0000ok5i
UOl0003o/W^Go`000?nZLiGo0000on6[Vol0003oZGNK00Go000000Co`I2So`000?oD[:ooe:b_0_l0
00000ooF/;7o0000o`000006o`000009okBH^ol0003oZI2lo`000?ncV[go0000oj^D__l0003o]9bo
00?o000000Oo]9k1o`000?l0003o0000okBO`ol0003o^ZS700?o000000Go^ZS8o`000?nfXlKo0000
okVYb003o`000003okVYbOl0003o000000?o000000?o^Zk=o`000?l000000_l000001onk/m;o0000
o`000?l0003o^[;Ao`000?nj/m<00ol000001Oni/];o0000oooooooooooo000000Kooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`001Oooool00ol0003oooooooooo`02
ooooo`;o00001Oooool00ol0003oooooooooo`0/ooooo`Ko000000GoZJODo`000?l0003o0000ojVV
d`03o`000003ojZUdOl0003oZJ?A00;o000000_oZJ;?o`000?l0003o0000oj^QcOl0003oYj3?o`00
0?n]X<_o0000ojRNc004o`000006oiVKe?l0003o0000ojfQbol0003o/ik30_l000000on?RLWo0000
o`000002o`000003ok6H_?l0003o/XRY00Co000000?oZ7:Fo`000?obc:X00_l000000onmRYoo0000
ok=kUP07o`000003oiMOSOl0003oTe^<00?o000000?oTF2Do`000?nTKI<01_l000001on9E8_o0000
o`000?n6DH[o0000ohQCRol000000_n7DX/3o`000009oh5?S?l0003oSeZ>o`000?nOJ97o0000oi=L
SOl0003oUUn>00;o000000_oVF>@o`000?l0003o0000ojIlYOl0003o/G^Ho`000?naNIGo0000ok9k
U`07o`000004ol:?XOl0003oi/6aonK1/@;o000000?oe:b_o`000?l000000_l00002okBD]P;o0000
0_ndU[P2o`000005okBH^ol0003o0000o`000?ncV[d00ol000001ondW;oo0000okbYaol0003o]9k1
o`000?nkZ<L00ol000001OnjZ<Oo0000o`000?l0003o^ZS800Co000000Oo_KWFo`000?l0003o0000
okffdol0003o_;WG00?o000000?o^kKDo`000?nj]mH00ol000000onj]=Co0000o`000002o`000003
okRce?l0003o000000?o000000?oooooo`000?ooool01Oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00;ooooo000Aooooo`03o`000?oooooooooo02[ooooo1Ol000001OnXZMOo
0000o`000?l0003oZ:SG00?o000000?oZJWFo`000?nZYm@01?l000001On[Y=3o0000ojbWd_l0003o
[:??00Co000000Go[J3;o`000?l0003o0000oj^Ka`03o`000005ok2Paol0003o0000o`000?ncW/<0
1?l00002oif8_@_o000000GoWfjJo`000?nmRYoo0000ok=kUP03o`000007oj9ZTOl0003o0000o`00
0?nGGhgo0000oi=KS003o`000003oi5PU?l0003oY6fC00Ko000000?oREB;o`000?n7DHX00_l00000
1?n8Dh_o0000ohMBRon7DX/3o`000009oh5?S?l0003oSeZ>o`000?nOJ97o0000oi=LSOl0003oUUn>
00;o000000?oVF>@o`000?l000000_l000000onVO:Go0000ok5kV002o`000004ok9kUol0003o0000
olVLZ0;o00000_oV_jh:o`000005olB^a?l0003o0000o`000?o2[LD01Ol000001Oo7dN;o0000o`00
0?l0003oaLSL00Co000000[o_:W7o`000?l0003o`K_Do`000?nocnKo0000okngd_l0003o_lGO0ol0
00000onn_]Wo0000ok_5hP03o`000003okbnfol0003o000000;o000000Oo]kgOo`000?l0003o0000
okRjf_l0003o]kOI00?o000000?o^;GFo`000?ng]=D00ol000000onh/]Co0000okRbd`02o`000003
ooooool0003ooooo00Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02oooo
o`004?ooool2o`0002Wooooo0ol00004ooooo`;o000000OoYj[Io`000?l0003o0000ojNZfOl0003o
Z:[H00Co000000?oZJWGo`000?l000000_l000001On/Ym;o0000o`000?l0003o[ZWC00?o000000Go
[jWBo`000?n_X/[o0000ok2ZdP03o`000003okbjf?l0003o000000;o000000?oZ96mo`000?nSR;P0
3Ol000001OnOKY[o0000o`000?l0003o/g^F00?o000000OoXVZAo`000?l0003o0000oiMOSOl0003o
Te^<00?o000000?oTF2Do`000?nTKI<00ol000001_nFGXgo0000o`000?n9E8_o0000ohMARP;o0000
00CoR5>;o`000?n7DX_oQe:;0ol000001_n1Chco0000ohmJS_l0003oWfRAo`0000;oTeb=0ol00000
2_nIHi3o0000o`000?o@UIKo0000ojIlYOl0003o/G^Ho`000?nlRZ43o`000003olVLZ?l0003o0000
02oo000000Oo[lS]o`000?l0003o0000okC2iOl0003o/[gR00?o000000?o]K[Mo`000?l000000ol0
00000ong]MSo0000o`000002o`000007okNceOl0003o0000o`000?ng/]Co0000okRbd`04o`0000Co
oooo00Co0000oooooooooooo00002?ooool2o`0000Cooooo000@ooooo`03o`000?oooooooooo02Go
oooo0ol00008ooooo`;o000000?oYZ[Io`000?nVZ]X01?l000001OnV[=_o0000o`000?l0003oYZgM
00Co000000OoZ;3No`000?l0003o0000ojVeh_l0003o[K7K00Co000000?o/:[Bo`000?nfa^L00ol0
00000ona]mgo0000ojjPb@09o`000003ohUg^Ol0003o000000Co000000GoWfjJo`000?l0003o0000
ok=kUP03o`000004oj9ZTOl0003o0000oiaUT0;o000000OoTe^<o`000?l0003o0000oi5PU?l0003o
Y6fC00?o000000KoUUj=o`000?l0003oREB;o`000?n7DHX2o`000004ohQCRol0003oQe:;ohMBR`?o
000000KoPDn<o`000?n?FXko0000oimXTOl00002oi=LS@?o000000?oVF>@o`000?l000000_l00000
1OnVO:Go0000ok5kV?l0003o_8ZQ01Wo000000?oXkc[o`000?l000002?l000000onC/ngo0000o`00
0007o`000003oiZolOl0003o000000_o000000Oo/;SOo`000?l0003o0000ok>gfol0003o];KJ00?o
000000Oo][CGo`000?nf]=Oo0000okNceOl0003o]k?E00?o000000?o^;;Co`000?ooool00_l00005
ooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`004?ooool00ol0003oooooooooo`0Roooo
o`?o00002oooool00ol0003oYZWIo`000003o`000005ojJ[f_l0003o0000o`000?nU[=`01?l00000
1OnT[moo0000o`000?l0003oY;CT00Go000000?oX[SXo`000?l000002ol000001?nS_>_o0000o`00
0?n`]]d2o`000003ofE^aol0003o000000;o000000GoT6nYo`000?nMOJoo0000oim^VP04o`000004
ohmRV_l0003o0000oj9ZT@;o000000CoW6F@o`000?l0003oTe^<0ol000000onAH9Co0000ojA]T`03
o`000006oiINSOl0003o0000ohUDRol0003oQe6:0_l000001?n8Dh_o0000o`000?n7DX/3o`000006
oh5?S?l0003oSeZ>o`000?nOJ97o00000_nCG8d3o`000005oiUST?l0003olk^@o`000?o=WZL01?l0
00001OnlRZ7o0000o`000?l0003oZ[_U00?o000000?oY[CSo`000?l000001_l000000onD^?3o0000
o`00000Fo`000003oj6nkOl0003o000000Ko000000GoZ;[Vo`000?l0003o0000ojbih`03o`000003
ojnhh?l0003o000000Oo000000?o]KKIo`000?l000001_l000000ong]MOo0000o`000003o`000003
ooooool0003ooooo01Gooooo000@ooooo`03o`000?oooooooooo01oooooo0ol0000?ooooo`;o0000
00GoYZWIo`000?l0003o0000ojJZfP04o`000005ojF/g?l0003o0000o`000?nU[ml00ol000000onU
/^;o0000o`000003o`000003oijfjOl0003o000000?o000000?oYKgZo`000?l000001_l000000oo7
fNOo0000o`000006o`0000;oT6nY1ol000001?n?HY[o0000o`000?nRJY42o`000004oiaUT?l0003o
0000oi=KS0;o000000?oHdBGo`000?nAH9@01?l000001_nFGXgo0000o`000?n9E8_o0000ohMARP;o
000000CoR5>;o`000?l0003oQe:;0_l000001?mcAH_o0000o`000?n?FXh3o`0000;oTeb=0ol00000
1?nIHi3o0000oo>kT?l00002olfNY`So000000?oZ;oZo`000?l000001?l000000onTa?3o0000o`00
0007o`000003oi^ol_l0003o000001oo000000Oo[<3Xo`000?l0003o0000ojnmi?l0003o[l3V00?o
000000_o/[gRo`000?l0003o0000okBjgOl0003o];_No`000?nf]m[o0000okJhf`03o`000003okNf
f?l0003o]kKH00?o00005_ooool0013ooooo00?o0000ooooooooool07?ooool3o`0001?ooooo0_l0
00001onWZ]Wo0000o`000?l0003oZ:cJo`000?nWZmX00_l000001OnW[M_o0000o`000?l0003oZ;3M
00?o000000?oZ;7No`000?nV/N001Ol000000on__nKo0000o`000002o`000003oi^UgOl0003o0000
00Ko000000?oSh;1o`000?l000001ol000001?m[D:3o0000o`000?ni`n85o`000004oj9ZTOl0003o
0000oiaUT0;o000000?oTe^<o`000?l000000_l000000onAH9Co0000o`000002o`000006oiINSOl0
003o0000ohUDRol0003oQe6:1Ol000001?n7DX_o0000o`000?mcAH/2o`000004ohmJS_l0003o0000
o`0000;oTeb=0ol000000onIHi3o0000oo>kT015o`000005ojS7l?l0003o0000o`000?n]`nX02Ol0
00000ond_>3o0000o`000003o`000003okFig?l0003o000001Kooooo000?ooooo`;o00006oooool3
o`0001Oooooo0_l000000onX[=[o0000ojR/fP06o`000007ojV`gOl0003o0000o`000?nZ]=oo0000
ojZbgP03o`000004ojVch?l0003o0000ojnoiP;o000000?o[kkUo`000?l000000_l000000onU^>Ko
0000o`00000?o`000003of]@X?l0003o000000Ko000000CoXVZAo`000?l0003oW6F@0_l000000onC
Fhco0000o`000002o`000003oi5PU?l0003o000000;o000000KoUUj=o`000?l0003oREB;o`000?n7
DHX5o`00000<ohMBRol0003o0000og=5Rol0003oPDn<o`000?n?FXko0000ohmISOl0003oTeb=0ol0
00000onIHi3o0000oo>kT003o`000005ojJkjOl0003o0000o`000?nS_^`0AOl000000on/`n_o0000
o`000007o`000006ok>lh?l0003o0000o`000?oooooo00005Oooool0013ooooo00?o0000oooooooo
ool05_ooool3o`0001[ooooo00?o0000ojR/fol000000_l000001?nX[mco0000o`000?nX/Ml3o`00
0003ojVfh_l0003oZ[GQ00?o000000?oZKOSo`000?l000001ol000000onT^nWo0000o`000004o`00
0005oj_;l?l0003o0000o`000?mkPm000ol000001_nTWm3o0000o`000?mXFJgo0000oeU;Y`Wo0000
00GoWFRCo`000?nRJY7o0000oiaUT002o`000003oi=KS?l0003o000000;o000000?oTF2Do`000?l0
00000_l000001_nFGXgo0000o`000?n9E8_o0000ohMARPGo000000coQe:;o`000?l0003oLdF;o`00
0?n1Chco0000ohmJS_l0003oSeV=o`000?nCG8d3o`000004oiUST?l0003o0000ojZhi0?o000000?o
ZKgXo`000?l000000ol000000onY^nKo0000o`000008o`000005ojJmj_l0003o0000o`000?nT_N`0
=_l000001OnVa>oo0000o`000?l0003o[<7Y00?o000000?o/;kTo`000?l000000_l0000Eooooo`00
3oooool00ol0003oooooooooo`0Eooooo`;o00007_ooool00ol0003oYjoMo`000002o`000006ojRb
gol0003o0000ojRfhol0003oZ;KS0ol000001OnX^^Ko0000o`000?l0003oYkgY00Go000000GoZ<Wa
o`000?l0003o0000oiW1l`07o`000003ogb>f_l0003o000000Ko000000?oJ5V]o`000?l000001?l0
00000omIDJko0000odXeUP02o`000005oieXTol0003oXVZAo`000?nLII000_l000002?nCFhco0000
o`000?n?FHco0000oi5PU?l0003oOTf<0_l000001_nFGXgo0000o`000?n9E8_o0000ohMARPGo0000
00coQe:;o`000?l0003oLdF;o`000?n1Chco0000ohmJS_l0003oSeV=o`000?nCG8d=o`000003ojVl
iol0003o000000Co000000GoZKkYo`000?l0003o0000ojRnj@03o`000005ojNnjol0003o0000o`00
0?nU_n`02_l000000onO`O3o0000o`00000eo`0001Gooooo000?ooooo`03o`000?oooooooooo01;o
oooo0ol0000Qooooo`03o`000?nW/^3o000001_o000000?o]>7fo`000?l000002Ol000000om^HkKo
0000o`000005o`000003of58Wol0003o000000?o000000GoWFRCo`000?nRJY7o0000oiaUT002o`00
0004oi=KS?l0003o0000ohmIS0?o000000CoOTf<o`000?l0003oUUj=0_l000000on9E8_o0000ohMA
RP05o`00000<ohMBRol0003o0000og=5Rol0003oPDn<o`000?n?FXko0000ohmISOl0003oTeb=1_l0
00001OnZ`N_o0000o`000?l0003oZ;gX00Ko000000GoZ;oZo`000?l0003o0000ojRojP1=o`0001Go
oooo000?ooooo`;o00004?ooool3o`0002Gooooo00Go0000ojReh_l0003o0000ojRiiP03o`000005
ojRnjOl0003o0000o`000?nW`N`01Ol000000onZc_;o0000o`00000?o`000004ojJ^gOl0003o0000
og=^_Poo000000GoWFRCo`000?nRJY7o0000oiaUT002o`000004oi=KS?l0003o0000ohmIS0?o0000
00CoOTf<o`000?l0003oUUj=0_l000000on9E8_o0000ohMARP02o`000004oi=LSOl0003o0000ohMB
R`;o000000WoLdF;o`000?n1Chco0000ohmJS_l0003oSeV=o`000?nCG8d01ol000000onY_NSo0000
o`000004o`000003ojRnjOl0003o000000Oo000000GoZ;gYo`000?l0003o0000ojNnj@03o`000003
ojNnj_l0003o000000Co000000GoYKo/o`000?l0003o0000ojBok@03o`000003oj;0k_l0003o0000
02co00001?ooool00ol0003oooooooooo`0Cooooo`0000Coooooo`000?l0003o00001?ooool2o`00
00Gooooo00?o0000ooooooooool03?ooool3o`0002Wooooo00Go0000ojRiiOl0003o0000ojRnj@03
o`000003ojS2k?l0003o000000Co000000?oZLodo`000?l000000ol000000onPcOOo0000o`000005
o`000003ohbZj_l0003o000001;o000000WoD3fKo`000?l0003o0000oieXTol0003oXVZAo`000?nL
II000_l000001?nCFhco0000o`000?n?FH`3o`000004ogi=S?l0003o0000oiINS@;o000000?oREB;
o`000?n7DHX00_l000001?nCG8go0000o`000?n7DX/4o`000007oh5?S?l0003oSeZ>o`000?n?FHgo
0000oi=LS@04o`000003oj^nj?l0003o000000[o000000GoZKgXo`000?l0003o0000ojVmj003o`00
0003ojVmj?l0003o000003So00003_ooool00ol0003oooooooooo`0Cooooo`0000Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02Oooool3
o`0002gooooo00Go0000ojRnjOl0003o0000ojS2k006o`000003ojO=m?l0003o0000017o000000Go
^]gao`000?l0003o0000ogaka`0<o`000003ofI=XOl0003o000000;o000000GoWFRCo`000?l0003o
0000oiaUT005o`000004ohmIS?l0003o0000of4jR`?o000000?oUUj=o`000?nNIHh00_l000001?n7
DH[o0000o`000?nCG8d2o`000003ohMBRol0003o000000;o000000OoPDn<o`000?l0003o0000ohmI
SOl0003oTeb=00ko000000GoZKgXo`000?l0003o0000ojVmj003o`000003ojVmj?l0003o000000[o
000000GoZ;gYo`000?l0003o0000ojRnj@03o`000003ojNnj_l0003o000000So000000GoY;o]o`00
0?l0003o0000oj:okP03o`000003oj30l?l0003o000000Ko00006oooool00ol0003oooooooooo`0C
ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01_ooool3o`00037ooooo00?o0000ojS3kOl000001?l000000onWc??o0000o`00
000Fo`000003oh>7col0003o000000Co000000?oTXK4o`000?l000002_l000000onMJ9?o0000o`00
0007o`000004ohmIS?l0003o0000of4jR`?o00000_nFGXd3o`000004ohMAR_l0003o0000oi=LS@;o
000000?oQe:;o`000?l000000_l000001on1Chco0000o`000?l0003oSeV=o`000?nCG8d01?l00000
0onY_NOo0000o`000004o`000005ojVnj?l0003o0000o`000?nY_NP00ol000000onY_NSo0000o`00
000:o`000005ojVmj?l0003o0000o`000?nY_NT00ol000000onX_^Wo0000o`00000Go`0000Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`001?l00003ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00oooool3o`0003Gooooo;?l000000om7Ajko0000
o`00000>o`000003ohmIS?l0003o000000Co00000_nFGXd3o`000004ohMAR_l0003o0000oi=LS@;o
000000?oQe:;o`000?l000000_l000001?n1Chco0000o`000?n8EHh2o`000003oi=LSOl0003oZkkX
00Ko000000GoZKkXo`000?l0003o0000ojVmj009o`000003ojVmj?l0003o000000Co000000GoZKgX
o`000?l0003o0000ojVmj003o`000003ojVmj?l0003o000000[o000000GoZ;kYo`000?l0003o0000
ojNnjP03o`000004ojJnjol0003o0000o`0000[ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Booooo`0000?o0000ooooooooool01?ooool01?l0003oooooooooool00003ooooo`;o
00000_ooool3o`0003Wooooo00?o0000ojK?m_l000005_l000000onX_>Oo0000o`00000=o`000003
odmB]_l0003o000000Ko000000?oH4ZQo`000?l000001ol000000on?FHco0000o`000004o`0000;o
UUj=0ol000001?n7DH[o0000o`000?nCG8d2o`000006ohMBRol0003o0000oi1NT_l0003oPDn<0_l0
00001?n8EHko0000o`000?nCG8d5o`000003ojVnj?l0003o000000Oo000000GoZKgXo`000?l0003o
0000ojVmj006o`000005ojVmj?l0003o0000o`000?nY_NP04?l000001OnX_NWo0000o`000?l0003o
Z;kY00Oo00003Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo00000ooo
oooo0000ooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo1?l0000moooooaWo000000?oTIkM
o`000?l000001?l000000onKV=3o0000o`000003o`000003oeYO_Ol0003o000000Ko000000?oHdnU
o`000?l000002Ol000000on?FHco0000o`000004o`0000;oUUj=0ol000001?n7DH[o0000o`000?nC
G8d2o`000004ohMBRol0003o0000oi1NTPOo000000?oTeb=o`000?l000001_l000001OnY_NSo0000
o`000?l0003oZKgX00?o000000?oZKgXo`000?l000003_l000000onY_NSo0000o`000004o`000005
ojVmj?l0003o0000o`000?nY_NP02_l0000Booooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool04_ooool000;ooooo0_l00004ooooo`;o00001?ooool2o`00047ooooo8_l000000omUK<Go
0000o`000006o`000003ofQFZ_l0003o000000Ko000000?oREN?o`000?l000000_l000000on?FHco
0000o`000004o`0000;oUUj=1_l000001?nCG8go0000o`000?n7DX/2o`000003oi1NT_l0003oYfjB
00_o000000GoZKkXo`000?l0003o0000ojVmj003o`000003ojVmj?l0003o000000Ko000000GoZKgX
o`000?l0003o0000ojVmj003o`000003ojVmj?l0003o000000Co000000?oZKgXo`000?l000001ol0
00001?nY_NSo0000o`000?l0000Gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
4_ooool0013ooooo00?o0000ooooooooool0@Oooool8o`000003oj?9m?l0003o000000Co000000?o
ZKoZo`000?l000001ol000001OnNX=Ko0000o`000?l0003oL7S<00Go000000CoWIS>o`000?l0003o
KEj`2?l000000olkB[Oo0000ohUGS`04o`000003ohmIS?l0003o000000Co00000_nFGXd3o`000003
oi5JS?l0003oUEj=00?o000000KoQe:;o`000?l0003oT5jBo`000?nWKY88o`000005ojZnj?l0003o
0000o`000?nY_NP03?l000001OnY_NSo0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l00000
2_l000001OnY_NSo0000o`000?l0003oZKgX00?o00006oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01;ooooo000Aooooo`03o`000?oooooooooo04;ooooo3_l000000onK[^Co0000
o`00000>o`000003oinNdol0003o000000Wo000000?o?djjo`000?l000001?l000001Om^H;;o0000
ohmIS?l0003ol;nM00?o000000?oSEN<o`000?nFGXd00ol000000onAFXco0000oiENS@04o`000005
oo>oUol0003oT5jBo`000?nWKY803ol000000onY_NSo0000o`000004o`000005ojVmj?l0003o0000
o`000?nY_NP04?l000001OnY_NSo0000o`000?l0003oZKgX00?o00007_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo01;ooooo000Booooo`03o`000?oooooooooo04?ooooo2?l00000
0on]bnoo0000o`000002o`000003oiZkkol0003o0000013o000000?oLfNfo`000?l000001?l00000
1Om:E[co0000o`000?l0003oSh6o00;o000000GoLFBeo`000?l0003o0000ohmIS005o`000003oheG
S?l0003oUUj=00;o000000CoS5J<o`000?l0003oUEj=1_l000000on@GY;o0000ojM^TP08o`000005
ojVmj?l0003o0000o`000?nY_NP00ol000001?nY_NSo0000o`000?nY_NP9o`000005ojVmj?l0003o
0000o`000?nY_NP01_l000001OnY_NSo0000o`000?l0003oZKgX00?o00008_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo017ooooo000Cooooo`;o0000AOooool7o`000003ojBij?l0
003o000000Go000000OoY:gNo`000?l0003o0000oh>?eol0003oPZ3V00?o000000CoXJCGo`000?l0
003oNG2l2_l000001On@Q/Co0000o`000?l0003oNf^d00[o000000?oSEN<o`000?nFGXd00_l00000
1?n<EXco0000o`000?nEGXd5o`000003of4lS_l0003oT5jB00Ko000000GoZ[kXo`000?l0003o0000
ojVmj003o`000003ojVmj?l0003o000000Ko000000GoZKgXo`000?l0003o0000ojVmj003o`000003
ojVmj?l0003o000000co00009_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017o
oooo000Eooooo`03o`000?oooooooooo04?ooooo=Ol000000on=Ehco0000oiINS@02o`000005ohaF
S?l0003o0000o`000?n<Ehh01?l000000omQ?8ko0000oi1NTP03o`000003ojZnj?l0003o000000_o
000000CoZKgXo`000?l0003oZKgX0ol000001OnY_NSo0000o`000?l0003oZKgX00So000000CoZKgX
o`000?l0003o0000;?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo000F
ooooo`03o`000?oooooooooo04Cooooo1?l000000onR_^go0000o`000003o`000003ojFahOl0003o
000000[o000000?oOg[3o`000?l000002Ol000000omoM;go0000o`000002o`000003og5caOl0003o
000000Co000000OoY:cMo`000?l0003o0000oheGS?l0003oUUj=00;o000000?oS5J<o`000?l00000
1?l000001Ooc_iOo0000o`000?l0003oT5jB00Ko000000GoZ[kXo`000?l0003o0000ojVmj003o`00
0003ojVmj?l0003o0000017o000000CoZKgXo`000?l0003o0000;oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo017ooooo000Gooooo`03o`000?oooooooooo04Cooooo2_l000000onG
X]co0000o`000007o`000003ohF3bOl0003o000000ko000000?oLgC6o`000?l000000ol000000onY
Z]Oo0000o`000004o`000003oheGS?l0003oUUj=00;o000000GoS5J<o`000?l0003o0000ok;8j`06
o`000003oi1NT_l0003o000000Go000000GoZKgXo`000?l0003o0000ojVmj008o`000005ojVmj?l0
003o0000o`000?nY_NP01_l000001?nY_NSo0000o`000?l0000cooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04Oooool001Sooooo0_l00015oooooaKo000000?oLgc>o`000?l00000
1_l000001?n2NL7o0000o`000?meMlL4o`000003olSRjol0003o000000Oo000000?oSEN<o`000?nF
GXd00_l000000on<EXco0000o`000008o`000003oi1NT_l0003o000000co000000CoZKgXo`000?l0
003oZKgX0ol000001OnY_NSo0000o`000?l0003oZKgX00Ko0000=oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo000Jooooo`03o`000?oooooooooo04?ooooo0ol000000onX
]nCo0000oj:_h@0>o`000003og^Dgol0003o000000Go000000?oQ7k5o`000?l000002?l000000onY
[M[o0000o`000006o`000003oheGS?l0003oUUj=00;o000000?oS5J<o`000?l000000ol000000on^
`nWo0000o`000002o`000003oi1NT_l0003o000000Go000000GoZKgXo`000?l0003o0000ojVmj00@
o`0003_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`006oooool00ol0
003oooooooooo`14ooooo`Co000000?oW:gSo`000?l000001Ol000001?nAUMCo0000o`000?n2SMD8
o`000003ohJ3bOl0003o000000;o000000?oMgW8o`000?l000000_l000000oo0f^go0000o`000004
o`000003ol[Tj_l0003o000000;o000000?oSEN<o`000?nFGXd00_l000000on<EXco0000o`000008
o`000003oi1NT_l0003o000000;o000000?oZKgXo`000?l000002_l000001OnY_NSo0000o`000?l0
003oZKgX00?o0000?oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo000L
ooooo`03o`000?oooooooooo04Cooooo1_l000000on^b^ko0000o`00000Ao`000003ogQlb_l0003o
000000[o000000Coc>k[o`000?l0003o`MW/0_l000000on=Ehco0000oiINS@02o`000003ohaFS?l0
003o000000?o000000?o[L;Yo`000?l000002_l000001OnY_NSo0000o`000?l0003oZKgX00Ko0000
00CoZKgXo`000?l0003o0000@oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo000Mooooo`;o0000AOooool?o`000003oik1lOl0003o000000;o000000CoR8S=o`000?l0003o
Ngo<2Ol000000onR[Mko0000o`000008o`000003oheGS?l0003oUUj=00;o000000CoS5J<o`000?l0
003o[lGZ2Ol000001?nZ_^So0000o`000?nY_NP3o`000003ojVmj?l0003o000000So0000Aoooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo
04?ooooo1?l000001?nQ[^7o0000o`000?nCWMX9o`000003ohZ=dOl0003o000000So000000?o[;[T
o`000?l000000ol000000oo4kO3o0000o`000004o`000003olGSkOl0003oSEN<00;o000000?oQE:<
o`000?n<EX`01Ol000001On/`NWo0000o`000?l0003oZkoX00co000000CoZKgXo`000?l0003o0000
Boooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo000Pooooo`03o`000?oo
oooooooo04;ooooo2?l000000onBY>7o0000o`00000Co`000003oj2[gol0003o000000[o000000Ko
SEN<o`000?l0003oQE:<o`000?n<EX`2o`000003ojk3jOl0003o000000Oo000000CoZ[kXo`000?l0
003oZKgX0ol000001?nY_NSo0000o`000?l0001?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool04?ooool0027ooooo00?o0000ooooooooool0@ooooolGo`000003ojNoj_l0003o0000
00Co000000Co_n?ao`000?l0003o`]SZ1ol000001_n=Ehco0000o`000?n5DXco0000ohaFS0Go0000
00GoZl3Yo`000?l0003o0000ojZnj00:o`0005?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`13ooooo`go000000GoPh_Co`000?l0003o
0000ohfXi`06o`000003oibVg?l0003o000000go000000?oSEN<o`000?l000000_l000000on<EXco
0000o`00000=o`0005Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`00
8oooool2o`0004Cooooo1_l000001OnGYMoo0000o`000?l0003oQXoE00go000000?oWk3So`000?ni
fO400_l000001?o0en_o0000o`000?o6i>d6o`000003oheGS?l0003o000000;o000000?oS5J<o`00
0?l000000ol000001On[_nSo0000o`000?l0003oZ[kX00?o0000Foooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo013ooooo000Uooooo`03o`000?oooooooooo04;ooooo4?l000000onJ
[nKo0000o`00000Ho`000003ohaFS?l0003o000000So0000Goooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00oooooo000Vooooo`03o`000?oooooooooo047ooooo4_l000000onFX]go
0000o`000005o`000004okgDjol0003o0000olGSk@go000000?oS5J<o`000?l000001?l0001Toooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool002Oooooo00?o0000oooooooo
ool0@OoooolBo`000004oiRWh?l0003o0000ok?@kPSo000000Coa=o/o`000?l0003o_mW]2?l00000
1?n<EXco0000o`000?l0001Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03ooo
ool002Sooooo0_l00012oooooaKo000000?o^]7[o`000?l000002Ol000000onjdnco0000okG<j`04
o`000003ohaFS?l0003ooooo06Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?
ooooo`00:_ooool00ol0003oooooooooo`0oooooo`;o000000?oSIgMo`000?l000005_l000001?o5
hNco0000o`000?o1g>d8o`000004ooooool0003oS5J<o`0006_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0?ooooo`00:oooool00ol0003oooooooooo`0oooooo`;o000000GoSZ3P
o`000?l0003o0000ohnOg`03o`000003ohnLg?l0003oTIoM00Ko000000?o]L_[o`000?l000000ol0
00000oo6h^co0000o`000003o`000004okgFk?l0003o0000o`0000Cooooo0ol0001/ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03oooool002cooooo00?o0000ooooooooool0?ooo
ool?o`000003ojc3j_l0003o000000So000000?o`mk]o`000?l000000ol00008ooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`00;Oooool2
o`00043ooooo5Ol000000oo5hNco0000o`000005o`0007Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0>ooooo`00;oooool00ol0003oooooooooo`0mooooo`_o000000CoWkCWo`00
0?l0003o[lCZ2?l000000oo5h>co0000o`00001looooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03_ooool0033ooooo00?o0000ooooooooool0?Oooool?o`000004okWBkOl0003o0000
olCOk@Go0000O_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo000aoooo
o`03o`000?oooooooooo03gooooo2Ol000000onT^>Oo0000o`00000:o`0007oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0>ooooo`00<_ooool2o`0003gooooo0_l000000on>W]ko
0000o`00000:o`000003ol7LkOl0003o000000;o0000P_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00kooooo000dooooo`03o`000?oooooooooo03_ooooo0_l000000onAXn3o0000
o`000003o`000003ojRmj?l0003o000000Ko0000QOooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00kooooo000eooooo`03o`000?oooooooooo03_ooooo0ol000000onIZn?o0000o`00
0005o`000003okkHkOl0003o000008Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0>ooooo`00=_ooool00ol0003oooooooooo`0jooooo`go0000ROooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00gooooo000gooooo`;o0000>oooool6o`000004ojo6jol0003o0000
o`0008cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`00>Oooool00ol0
003oooooooooo`0iooooo`Oo0000Soooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00gooooo000jooooo`03o`000?oooooooooo03Wooooo00Co0000oj>giol0003o0000T_ooool01Ol0
003ooooooooooooooooo000000oooooo000kooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool0T_ooool01Ol0003ooooooooooooooooo000000oooooo000looooo`;o0000>Oooool00ol0
003oooooooooo`2Cooooo`04o`000?ooooooooooo`0000oooooo000nooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool0U?ooool00ol0003oooooo`00000?ooooo`00?oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo09Cooooo00Co0000oooooooooooo00003_ooool0043o
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooo000000ko
oooo0011ooooo`;o0000=?ooool00ol0003oooooooooo`2Fooooo`;o00003_ooool004?ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`2Eooooo`?o00003_ooool004Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`2Booooo`Co00004Oooool004Gooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`2>ooooo`Co00005Oooool004Kooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`2;ooooo`?o00006Oooool004Oooooo0_l0000]ooooo`03o`00
0?oooooooooo08Oooooo1?l0000Looooo`00BOooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo08?ooooo1?l0000Pooooo`00B_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo07oooooo1?l0000Tooooo`00Boooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
07_ooooo1?l0000Xooooo`00C?ooool2o`0002Sooooo00?o0000ooooooooool0N?ooool3o`0002co
oooo001>ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4o`0002oooooo
001?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L?ooool4o`0003?ooooo001@
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0K?ooool4o`0003Oooooo001Aoooo
o`;o00008oooool00ol0003oooooooooo`1Xooooo`Co0000>oooool005?ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`1Uooooo`?o0000?oooool005Cooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`1Qooooo`Co0000@_ooool005Gooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`1Mooooo`Co0000A_ooool005Kooooo0_l0000Nooooo`03o`000?oooooo
oooo05Wooooo1?l0001:ooooo`00F?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
05Gooooo1?l0001>ooooo`00FOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;o
oooo0ol0001Booooo`00F_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo
1?l0001Eooooo`00Foooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0005Wooooo001M
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`0005gooooo001Noooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool4o`00067ooooo001Oooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool3o`0006Gooooo001Pooooo`;o0000
5?ooool00ol0003oooooooooo`0kooooo`Co0000J?ooool006;ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0gooooo`Co0000K?ooool006?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0cooooo`Co0000L?ooool006Cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0_ooooo`Co0000M?ooool006Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0]ooooo`?o0000N?ooool006Kooooo0_l0000=ooooo`03o`000?oooooooooo02Wooooo
1?l0001kooooo`00J?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0
001oooooo`00JOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l00023
ooooo`00J_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l00027oooo
o`00Joooool2o`0000Sooooo00?o0000ooooooooool06_ooool3o`0008_ooooo001]ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`0008kooooo001^ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04_ooool4o`0009;ooooo001_ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03_ooool4o`0009Kooooo001`ooooo`;o00000oooool00ol0
003oooooooooo`0:ooooo`Co0000V_ooool007;ooooo00Co0000oooooooooooo00002Oooool3o`00
09kooooo001cooooo`03o`000?oooooo000000Gooooo1?l0002Qooooo`00M?ooool2o`000003oooo
ool0003o000000;o0000YOooool007Gooooo0_l0002Yooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0521246, 0.00246641, \
0.00367095, 0.00367095}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wavelet analysis of an Imaging System", "Subsubsection",
  CellTags->{"AOG0.", "6.4.8", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell["\<\
In this section, we calculate the wavefront propagation for a plane wave \
traveling through a lens. Here is an overall schematic of the system.\
\>", "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[{
\tMove[LineOfWavelets[10,NumberOfRays->1],-50],
\tPlanoConvexLens[100,50,10],
\tMove[Screen[50],103]},PlotType->TopView,ShowGaussian->True];\
\>", "Input",
  CellLabel->"In[68]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3468 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.335045 0.00622471 0.182923 0.00622471 [
[.36617 .00826 -3 -4.5 ]
[.36617 .00826 3 4.5 ]
[.97619 .00826 -3 -4.5 ]
[.97619 .00826 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .3468 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-6. 0 lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 g
.37502 .0273 m
.39729 .0273 L
.39729 .07918 L
.35217 .07918 L
.37502 .0273 L
F
.35217 .07918 m
.39729 .07918 L
.39729 .13105 L
.33924 .13105 L
.35217 .07918 L
F
.33924 .13105 m
.39729 .13105 L
.39729 .18292 L
.33505 .18292 L
.33924 .13105 L
F
.33505 .18292 m
.39729 .18292 L
.39729 .2348 L
.33924 .2348 L
.33505 .18292 L
F
.33924 .2348 m
.39729 .2348 L
.39729 .28667 L
.35217 .28667 L
.33924 .2348 L
F
.35217 .28667 m
.39729 .28667 L
.39729 .33854 L
.37502 .33854 L
.35217 .28667 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.37502 .0273 m
.35217 .07918 L
.33924 .13105 L
.33505 .18292 L
.33924 .2348 L
.35217 .28667 L
.37502 .33854 L
.39729 .33854 L
.39729 .28667 L
.39729 .2348 L
.39729 .18292 L
.39729 .13105 L
.39729 .07918 L
.39729 .0273 L
.37502 .0273 L
s
.5 g
.37502 .18292 m
.39729 .18292 L
.39729 .18292 L
.35217 .18292 L
.37502 .18292 L
F
.35217 .18292 m
.39729 .18292 L
.39729 .18292 L
.33924 .18292 L
.35217 .18292 L
F
.33924 .18292 m
.39729 .18292 L
.39729 .18292 L
.33505 .18292 L
.33924 .18292 L
F
.33505 .18292 m
.39729 .18292 L
.39729 .18292 L
.33924 .18292 L
.33505 .18292 L
F
.33924 .18292 m
.39729 .18292 L
.39729 .18292 L
.35217 .18292 L
.33924 .18292 L
F
.35217 .18292 m
.39729 .18292 L
.39729 .18292 L
.37502 .18292 L
.35217 .18292 L
F
0 g
.37502 .18292 m
.35217 .18292 L
.33924 .18292 L
.33505 .18292 L
.33924 .18292 L
.35217 .18292 L
.37502 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.39729 .18292 L
.37502 .18292 L
s
.37502 .33854 m
.39729 .33854 L
.39729 .33324 L
.37502 .33324 L
.37502 .33854 L
s
.37502 .33324 m
.39729 .33324 L
.39729 .31769 L
.37502 .31769 L
.37502 .33324 L
s
.37502 .31769 m
.39729 .31769 L
.39729 .29296 L
.37502 .29296 L
.37502 .31769 L
s
.37502 .29296 m
.39729 .29296 L
.39729 .26073 L
.37502 .26073 L
.37502 .29296 L
s
.37502 .26073 m
.39729 .26073 L
.39729 .2232 L
.37502 .2232 L
.37502 .26073 L
s
.37502 .2232 m
.39729 .2232 L
.39729 .18292 L
.37502 .18292 L
.37502 .2232 L
s
.37502 .18292 m
.39729 .18292 L
.39729 .14265 L
.37502 .14265 L
.37502 .18292 L
s
.37502 .14265 m
.39729 .14265 L
.39729 .10511 L
.37502 .10511 L
.37502 .14265 L
s
.37502 .10511 m
.39729 .10511 L
.39729 .07288 L
.37502 .07288 L
.37502 .10511 L
s
.37502 .07288 m
.39729 .07288 L
.39729 .04815 L
.37502 .04815 L
.37502 .07288 L
s
.37502 .04815 m
.39729 .04815 L
.39729 .03261 L
.37502 .03261 L
.37502 .04815 L
s
.37502 .03261 m
.39729 .03261 L
.39729 .0273 L
.37502 .0273 L
.37502 .03261 L
s
.37502 .0273 m
.39729 .0273 L
.39729 .03261 L
.37502 .03261 L
.37502 .0273 L
s
.37502 .03261 m
.39729 .03261 L
.39729 .04815 L
.37502 .04815 L
.37502 .03261 L
s
.37502 .04815 m
.39729 .04815 L
.39729 .07288 L
.37502 .07288 L
.37502 .04815 L
s
.37502 .07288 m
.39729 .07288 L
.39729 .10511 L
.37502 .10511 L
.37502 .07288 L
s
.37502 .10511 m
.39729 .10511 L
.39729 .14265 L
.37502 .14265 L
.37502 .10511 L
s
.37502 .14265 m
.39729 .14265 L
.39729 .18292 L
.37502 .18292 L
.37502 .14265 L
s
.37502 .18292 m
.39729 .18292 L
.39729 .2232 L
.37502 .2232 L
.37502 .18292 L
s
.37502 .2232 m
.39729 .2232 L
.39729 .26073 L
.37502 .26073 L
.37502 .2232 L
s
.37502 .26073 m
.39729 .26073 L
.39729 .29296 L
.37502 .29296 L
.37502 .26073 L
s
.37502 .29296 m
.39729 .29296 L
.39729 .31769 L
.37502 .31769 L
.37502 .29296 L
s
.37502 .31769 m
.39729 .31769 L
.39729 .33324 L
.37502 .33324 L
.37502 .31769 L
s
.37502 .33324 m
.39729 .33324 L
.39729 .33854 L
.37502 .33854 L
.37502 .33324 L
s
.97619 .0273 m
.97619 .07918 L
.97619 .13105 L
.97619 .18292 L
.97619 .2348 L
.97619 .28667 L
.97619 .33854 L
.97619 .33854 L
.97619 .28667 L
.97619 .2348 L
.97619 .18292 L
.97619 .13105 L
.97619 .07918 L
.97619 .0273 L
.97619 .0273 L
s
.97619 .18292 m
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
.97619 .18292 L
s
.97619 .33854 m
.97619 .33324 L
.97619 .31769 L
.97619 .29296 L
.97619 .26073 L
.97619 .2232 L
.97619 .18292 L
.97619 .14265 L
.97619 .10511 L
.97619 .07288 L
.97619 .04815 L
.97619 .03261 L
.97619 .0273 L
.97619 .03261 L
.97619 .04815 L
.97619 .07288 L
.97619 .10511 L
.97619 .14265 L
.97619 .18292 L
.97619 .2232 L
.97619 .26073 L
.97619 .29296 L
.97619 .31769 L
.97619 .33324 L
.97619 .33854 L
s
0 0 0 r
[(L)] .36617 .00826 0 0 Mshowa
[(S)] .97619 .00826 0 0 Mshowa
.039 .916 .04 r
1 Mabswid
.02381 .24517 m
.03968 .24517 L
.05556 .24517 L
.07143 .24517 L
.0873 .24517 L
.10317 .24517 L
.11905 .24517 L
.13492 .24517 L
.15079 .24517 L
.16667 .24517 L
.18254 .24517 L
.19841 .24517 L
.21429 .24517 L
.23016 .24517 L
.24603 .24517 L
.2619 .24517 L
.27778 .24517 L
.29365 .24517 L
.30952 .24517 L
.3254 .24517 L
.34127 .24476 L
.35714 .24371 L
.37302 .24267 L
.38889 .24162 L
.40476 .24032 L
.42063 .23873 L
.43651 .23714 L
.45238 .23555 L
.46825 .23396 L
.48413 .23237 L
.5 .23078 L
.51587 .22919 L
.53175 .2276 L
.54762 .22601 L
.56349 .22442 L
.57937 .22283 L
.59524 .22124 L
.61111 .21965 L
.62698 .21806 L
.64286 .21647 L
.65873 .21489 L
.6746 .2133 L
.69048 .21171 L
.70635 .21012 L
.72222 .20853 L
.7381 .20694 L
.75397 .20535 L
.76984 .20376 L
.78571 .20217 L
.80159 .20058 L
Mistroke
.81746 .19899 L
.83333 .1974 L
.84921 .19581 L
.86508 .19422 L
.88095 .19263 L
.89683 .19104 L
.9127 .18945 L
.92857 .18786 L
.94444 .18627 L
.96032 .18468 L
.97619 .18309 L
Mfstroke
.02381 .12068 m
.03968 .12068 L
.05556 .12068 L
.07143 .12068 L
.0873 .12068 L
.10317 .12068 L
.11905 .12068 L
.13492 .12068 L
.15079 .12068 L
.16667 .12068 L
.18254 .12068 L
.19841 .12068 L
.21429 .12068 L
.23016 .12068 L
.24603 .12068 L
.2619 .12068 L
.27778 .12068 L
.29365 .12068 L
.30952 .12068 L
.3254 .12068 L
.34127 .12109 L
.35714 .12213 L
.37302 .12318 L
.38889 .12422 L
.40476 .12553 L
.42063 .12712 L
.43651 .12871 L
.45238 .13029 L
.46825 .13188 L
.48413 .13347 L
.5 .13506 L
.51587 .13665 L
.53175 .13824 L
.54762 .13983 L
.56349 .14142 L
.57937 .14301 L
.59524 .1446 L
.61111 .14619 L
.62698 .14778 L
.64286 .14937 L
.65873 .15096 L
.6746 .15255 L
.69048 .15414 L
.70635 .15573 L
.72222 .15732 L
.7381 .15891 L
.75397 .1605 L
.76984 .16209 L
.78571 .16368 L
.80159 .16527 L
Mistroke
.81746 .16686 L
.83333 .16845 L
.84921 .17003 L
.86508 .17162 L
.88095 .17321 L
.89683 .1748 L
.9127 .17639 L
.92857 .17798 L
.94444 .17957 L
.96032 .18116 L
.97619 .18275 L
Mfstroke
0 0 0 r
.02381 .18292 m
.33505 .18292 L
s
% Start of user PostScript
-50. 0 0 0 MAarrowhead1
% End of user PostScript
.33505 .18292 m
.39729 .18292 L
s
% Start of user PostScript
0 0 10. 0 MAarrowhead1
% End of user PostScript
.39729 .18292 m
.97619 .18292 L
s
% Start of user PostScript
10. 0 103. 0 MAarrowhead1
% End of user PostScript
.97619 .18292 m
.97619 .18292 L
s
% Start of user PostScript
103. 0 MAarrowzero1
% End of user PostScript
.039 .916 .04 r
.02381 .1269 m
.02381 .13063 L
.02381 .13437 L
.02381 .1381 L
.02381 .14184 L
.02381 .14557 L
.02381 .14931 L
.02381 .15304 L
.02381 .15678 L
.02381 .16051 L
.02381 .16425 L
.02381 .16798 L
.02381 .17172 L
.02381 .17545 L
.02381 .17919 L
.02381 .18292 L
.02381 .18666 L
.02381 .19039 L
.02381 .19413 L
.02381 .19786 L
.02381 .2016 L
.02381 .20533 L
.02381 .20907 L
.02381 .2128 L
.02381 .21654 L
.02381 .22027 L
.02381 .22401 L
.02381 .22774 L
.02381 .23148 L
.02381 .23521 L
.02381 .23894 L
s
.04762 .1269 m
.04762 .13063 L
.04762 .13437 L
.04762 .1381 L
.04762 .14184 L
.04762 .14557 L
.04762 .14931 L
.04762 .15304 L
.04762 .15678 L
.04762 .16051 L
.04762 .16425 L
.04762 .16798 L
.04762 .17172 L
.04762 .17545 L
.04762 .17919 L
.04762 .18292 L
.04762 .18666 L
.04762 .19039 L
.04762 .19413 L
.04762 .19786 L
.04762 .2016 L
.04762 .20533 L
.04762 .20907 L
.04762 .2128 L
.04762 .21654 L
.04762 .22027 L
.04762 .22401 L
.04762 .22774 L
.04762 .23148 L
.04762 .23521 L
.04762 .23894 L
s
.07143 .1269 m
.07143 .13063 L
.07143 .13437 L
.07143 .1381 L
.07143 .14184 L
.07143 .14557 L
.07143 .14931 L
.07143 .15304 L
.07143 .15678 L
.07143 .16051 L
.07143 .16425 L
.07143 .16798 L
.07143 .17172 L
.07143 .17545 L
.07143 .17919 L
.07143 .18292 L
.07143 .18666 L
.07143 .19039 L
.07143 .19413 L
.07143 .19786 L
.07143 .2016 L
.07143 .20533 L
.07143 .20907 L
.07143 .2128 L
.07143 .21654 L
.07143 .22027 L
.07143 .22401 L
.07143 .22774 L
.07143 .23148 L
.07143 .23521 L
.07143 .23894 L
s
.09524 .1269 m
.09524 .13063 L
.09524 .13437 L
.09524 .1381 L
.09524 .14184 L
.09524 .14557 L
.09524 .14931 L
.09524 .15304 L
.09524 .15678 L
.09524 .16051 L
.09524 .16425 L
.09524 .16798 L
.09524 .17172 L
.09524 .17545 L
.09524 .17919 L
.09524 .18292 L
.09524 .18666 L
.09524 .19039 L
.09524 .19413 L
.09524 .19786 L
.09524 .2016 L
.09524 .20533 L
.09524 .20907 L
.09524 .2128 L
.09524 .21654 L
.09524 .22027 L
.09524 .22401 L
.09524 .22774 L
.09524 .23148 L
.09524 .23521 L
.09524 .23894 L
s
.11905 .1269 m
.11905 .13063 L
.11905 .13437 L
.11905 .1381 L
.11905 .14184 L
.11905 .14557 L
.11905 .14931 L
.11905 .15304 L
.11905 .15678 L
.11905 .16051 L
.11905 .16425 L
.11905 .16798 L
.11905 .17172 L
.11905 .17545 L
.11905 .17919 L
.11905 .18292 L
.11905 .18666 L
.11905 .19039 L
.11905 .19413 L
.11905 .19786 L
.11905 .2016 L
.11905 .20533 L
.11905 .20907 L
.11905 .2128 L
.11905 .21654 L
.11905 .22027 L
.11905 .22401 L
.11905 .22774 L
.11905 .23148 L
.11905 .23521 L
.11905 .23894 L
s
.14286 .1269 m
.14286 .13063 L
.14286 .13437 L
.14286 .1381 L
.14286 .14184 L
.14286 .14557 L
.14286 .14931 L
.14286 .15304 L
.14286 .15678 L
.14286 .16051 L
.14286 .16425 L
.14286 .16798 L
.14286 .17172 L
.14286 .17545 L
.14286 .17919 L
.14286 .18292 L
.14286 .18666 L
.14286 .19039 L
.14286 .19413 L
.14286 .19786 L
.14286 .2016 L
.14286 .20533 L
.14286 .20907 L
.14286 .2128 L
.14286 .21654 L
.14286 .22027 L
.14286 .22401 L
.14286 .22774 L
.14286 .23148 L
.14286 .23521 L
.14286 .23894 L
s
.16667 .1269 m
.16667 .13063 L
.16667 .13437 L
.16667 .1381 L
.16667 .14184 L
.16667 .14557 L
.16667 .14931 L
.16667 .15304 L
.16667 .15678 L
.16667 .16051 L
.16667 .16425 L
.16667 .16798 L
.16667 .17172 L
.16667 .17545 L
.16667 .17919 L
.16667 .18292 L
.16667 .18666 L
.16667 .19039 L
.16667 .19413 L
.16667 .19786 L
.16667 .2016 L
.16667 .20533 L
.16667 .20907 L
.16667 .2128 L
.16667 .21654 L
.16667 .22027 L
.16667 .22401 L
.16667 .22774 L
.16667 .23148 L
.16667 .23521 L
.16667 .23894 L
s
.19048 .1269 m
.19048 .13063 L
.19048 .13437 L
.19048 .1381 L
.19048 .14184 L
.19048 .14557 L
.19048 .14931 L
.19048 .15304 L
.19048 .15678 L
.19048 .16051 L
.19048 .16425 L
.19048 .16798 L
.19048 .17172 L
.19048 .17545 L
.19048 .17919 L
.19048 .18292 L
.19048 .18666 L
.19048 .19039 L
.19048 .19413 L
.19048 .19786 L
.19048 .2016 L
.19048 .20533 L
.19048 .20907 L
.19048 .2128 L
.19048 .21654 L
.19048 .22027 L
.19048 .22401 L
.19048 .22774 L
.19048 .23148 L
.19048 .23521 L
.19048 .23894 L
s
.21429 .1269 m
.21429 .13063 L
.21429 .13437 L
.21429 .1381 L
.21429 .14184 L
.21429 .14557 L
.21429 .14931 L
.21429 .15304 L
.21429 .15678 L
.21429 .16051 L
.21429 .16425 L
.21429 .16798 L
.21429 .17172 L
.21429 .17545 L
.21429 .17919 L
.21429 .18292 L
.21429 .18666 L
.21429 .19039 L
.21429 .19413 L
.21429 .19786 L
.21429 .2016 L
.21429 .20533 L
.21429 .20907 L
.21429 .2128 L
.21429 .21654 L
.21429 .22027 L
.21429 .22401 L
.21429 .22774 L
.21429 .23148 L
.21429 .23521 L
.21429 .23894 L
s
.2381 .1269 m
.2381 .13063 L
.2381 .13437 L
.2381 .1381 L
.2381 .14184 L
.2381 .14557 L
.2381 .14931 L
.2381 .15304 L
.2381 .15678 L
.2381 .16051 L
.2381 .16425 L
.2381 .16798 L
.2381 .17172 L
.2381 .17545 L
.2381 .17919 L
.2381 .18292 L
.2381 .18666 L
.2381 .19039 L
.2381 .19413 L
.2381 .19786 L
.2381 .2016 L
.2381 .20533 L
.2381 .20907 L
.2381 .2128 L
.2381 .21654 L
.2381 .22027 L
.2381 .22401 L
.2381 .22774 L
.2381 .23148 L
.2381 .23521 L
.2381 .23894 L
s
.2619 .1269 m
.2619 .13063 L
.2619 .13437 L
.2619 .1381 L
.2619 .14184 L
.2619 .14557 L
.2619 .14931 L
.2619 .15304 L
.2619 .15678 L
.2619 .16051 L
.2619 .16425 L
.2619 .16798 L
.2619 .17172 L
.2619 .17545 L
.2619 .17919 L
.2619 .18292 L
.2619 .18666 L
.2619 .19039 L
.2619 .19413 L
.2619 .19786 L
.2619 .2016 L
.2619 .20533 L
.2619 .20907 L
.2619 .2128 L
.2619 .21654 L
.2619 .22027 L
.2619 .22401 L
.2619 .22774 L
.2619 .23148 L
.2619 .23521 L
.2619 .23894 L
s
.28571 .1269 m
.28571 .13063 L
.28571 .13437 L
.28571 .1381 L
.28571 .14184 L
.28571 .14557 L
.28571 .14931 L
.28571 .15304 L
.28571 .15678 L
.28571 .16051 L
.28571 .16425 L
.28571 .16798 L
.28571 .17172 L
.28571 .17545 L
.28571 .17919 L
.28571 .18292 L
.28571 .18666 L
.28571 .19039 L
.28571 .19413 L
.28571 .19786 L
.28571 .2016 L
.28571 .20533 L
.28571 .20907 L
.28571 .2128 L
.28571 .21654 L
.28571 .22027 L
.28571 .22401 L
.28571 .22774 L
.28571 .23148 L
.28571 .23521 L
.28571 .23894 L
s
.30952 .1269 m
.30952 .13063 L
.30952 .13437 L
.30952 .1381 L
.30952 .14184 L
.30952 .14557 L
.30952 .14931 L
.30952 .15304 L
.30952 .15678 L
.30952 .16051 L
.30952 .16425 L
.30952 .16798 L
.30952 .17172 L
.30952 .17545 L
.30952 .17919 L
.30952 .18292 L
.30952 .18666 L
.30952 .19039 L
.30952 .19413 L
.30952 .19786 L
.30952 .2016 L
.30952 .20533 L
.30952 .20907 L
.30952 .2128 L
.30952 .21654 L
.30952 .22027 L
.30952 .22401 L
.30952 .22774 L
.30952 .23148 L
.30952 .23521 L
.30952 .23894 L
s
.33333 .1269 m
.33333 .13063 L
.33333 .13437 L
.33333 .1381 L
.33333 .14184 L
.33333 .14557 L
.33333 .14931 L
.33333 .15304 L
.33333 .15678 L
.33333 .16051 L
.33333 .16425 L
.33333 .16798 L
.33333 .17172 L
.33333 .17545 L
.33333 .17919 L
.33333 .18292 L
.33333 .18666 L
.33333 .19039 L
.33333 .19413 L
.33333 .19786 L
.33333 .2016 L
.33333 .20533 L
.33333 .20907 L
.33333 .2128 L
.33333 .21654 L
.33333 .22027 L
.33333 .22401 L
.33333 .22774 L
.33333 .23148 L
.33333 .23521 L
.33333 .23894 L
s
.35915 .12821 m
.35889 .13186 L
.35865 .13551 L
.35843 .13915 L
.35822 .1428 L
.35804 .14645 L
.35787 .1501 L
.35771 .15374 L
.35758 .15739 L
.35746 .16104 L
.35737 .16469 L
.35729 .16833 L
.35722 .17198 L
.35718 .17563 L
.35715 .17928 L
.35714 .18292 L
.35715 .18657 L
.35718 .19022 L
.35722 .19386 L
.35729 .19751 L
.35737 .20116 L
.35746 .20481 L
.35758 .20845 L
.35771 .2121 L
.35787 .21575 L
.35804 .2194 L
.35822 .22304 L
.35843 .22669 L
.35865 .23034 L
.35889 .23399 L
.35915 .23763 L
s
.38291 .12962 m
.38266 .13318 L
.38242 .13673 L
.3822 .14028 L
.382 .14384 L
.38182 .14739 L
.38166 .15094 L
.38151 .1545 L
.38138 .15805 L
.38127 .1616 L
.38117 .16516 L
.38109 .16871 L
.38103 .17226 L
.38099 .17582 L
.38096 .17937 L
.38095 .18292 L
.38096 .18648 L
.38099 .19003 L
.38103 .19358 L
.38109 .19714 L
.38117 .20069 L
.38127 .20424 L
.38138 .2078 L
.38151 .21135 L
.38166 .2149 L
.38182 .21846 L
.382 .22201 L
.3822 .22556 L
.38242 .22912 L
.38266 .23267 L
.38291 .23622 L
s
.40914 .13127 m
.40857 .13471 L
.40805 .13815 L
.40756 .1416 L
.40712 .14504 L
.40671 .14848 L
.40634 .15193 L
.40601 .15537 L
.40571 .15882 L
.40546 .16226 L
.40525 .1657 L
.40507 .16915 L
.40494 .17259 L
.40484 .17603 L
.40478 .17948 L
.40476 .18292 L
.40478 .18637 L
.40484 .18981 L
.40494 .19325 L
.40507 .1967 L
.40525 .20014 L
.40546 .20359 L
.40571 .20703 L
.40601 .21047 L
.40634 .21392 L
.40671 .21736 L
.40712 .2208 L
.40756 .22425 L
.40805 .22769 L
.40857 .23114 L
.40914 .23458 L
s
.43277 .13341 m
.43222 .13671 L
.43172 .14001 L
.43126 .14331 L
.43083 .14661 L
.43044 .14992 L
.43008 .15322 L
.42976 .15652 L
.42948 .15982 L
.42924 .16312 L
.42904 .16642 L
.42887 .16972 L
.42874 .17302 L
.42865 .17632 L
.42859 .17962 L
.42857 .18292 L
.42859 .18622 L
.42865 .18952 L
.42874 .19282 L
.42887 .19613 L
.42904 .19943 L
.42924 .20273 L
.42948 .20603 L
.42976 .20933 L
.43008 .21263 L
.43044 .21593 L
.43083 .21923 L
.43126 .22253 L
.43172 .22583 L
.43222 .22913 L
.43277 .23243 L
s
.45639 .13556 m
.45588 .13872 L
.45539 .14187 L
.45495 .14503 L
.45454 .14819 L
.45416 .15135 L
.45383 .1545 L
.45352 .15766 L
.45325 .16082 L
.45302 .16398 L
.45283 .16713 L
.45267 .17029 L
.45254 .17345 L
.45245 .17661 L
.4524 .17976 L
.45238 .18292 L
.4524 .18608 L
.45245 .18924 L
.45254 .1924 L
.45267 .19555 L
.45283 .19871 L
.45302 .20187 L
.45325 .20503 L
.45352 .20818 L
.45383 .21134 L
.45416 .2145 L
.45454 .21766 L
.45495 .22081 L
.45539 .22397 L
.45588 .22713 L
.45639 .23029 L
s
.48002 .1377 m
.47953 .14072 L
.47907 .14373 L
.47864 .14675 L
.47825 .14976 L
.47789 .15278 L
.47757 .15579 L
.47728 .15881 L
.47702 .16182 L
.4768 .16483 L
.47662 .16785 L
.47646 .17086 L
.47634 .17388 L
.47626 .17689 L
.47621 .17991 L
.47619 .18292 L
.47621 .18594 L
.47626 .18895 L
.47634 .19197 L
.47646 .19498 L
.47662 .198 L
.4768 .20101 L
.47702 .20402 L
.47728 .20704 L
.47757 .21005 L
.47789 .21307 L
.47825 .21608 L
.47864 .2191 L
.47907 .22211 L
.47953 .22513 L
.48002 .22814 L
s
.50365 .13985 m
.50318 .14272 L
.50274 .14559 L
.50234 .14846 L
.50196 .15134 L
.50162 .15421 L
.50131 .15708 L
.50104 .15995 L
.50079 .16282 L
.50058 .16569 L
.50041 .16856 L
.50026 .17144 L
.50015 .17431 L
.50006 .17718 L
.50002 .18005 L
.5 .18292 L
.50002 .18579 L
.50006 .18867 L
.50015 .19154 L
.50026 .19441 L
.50041 .19728 L
.50058 .20015 L
.50079 .20302 L
.50104 .20589 L
.50131 .20877 L
.50162 .21164 L
.50196 .21451 L
.50234 .21738 L
.50274 .22025 L
.50318 .22312 L
.50365 .226 L
s
.52728 .142 m
.52683 .14472 L
.52641 .14745 L
.52603 .15018 L
.52567 .15291 L
.52535 .15564 L
.52506 .15837 L
.5248 .16109 L
.52456 .16382 L
.52436 .16655 L
.52419 .16928 L
.52406 .17201 L
.52395 .17474 L
.52387 .17747 L
.52382 .18019 L
.52381 .18292 L
.52382 .18565 L
.52387 .18838 L
.52395 .19111 L
.52406 .19384 L
.52419 .19656 L
.52436 .19929 L
.52456 .20202 L
.5248 .20475 L
.52506 .20748 L
.52535 .21021 L
.52567 .21294 L
.52603 .21566 L
.52641 .21839 L
.52683 .22112 L
.52728 .22385 L
s
.5509 .14414 m
.55048 .14673 L
.55009 .14931 L
.54972 .1519 L
.54939 .15448 L
.54908 .15707 L
.5488 .15965 L
.54855 .16224 L
.54833 .16482 L
.54814 .16741 L
.54798 .17 L
.54785 .17258 L
.54775 .17517 L
.54768 .17775 L
.54763 .18034 L
.54762 .18292 L
.54763 .18551 L
.54768 .18809 L
.54775 .19068 L
.54785 .19326 L
.54798 .19585 L
.54814 .19843 L
.54833 .20102 L
.54855 .20361 L
.5488 .20619 L
.54908 .20878 L
.54939 .21136 L
.54972 .21395 L
.55009 .21653 L
.55048 .21912 L
.5509 .2217 L
s
.57453 .14629 m
.57413 .14873 L
.57376 .15117 L
.57341 .15361 L
.5731 .15606 L
.57281 .1585 L
.57255 .16094 L
.57231 .16338 L
.5721 .16583 L
.57193 .16827 L
.57177 .17071 L
.57165 .17315 L
.57155 .1756 L
.57148 .17804 L
.57144 .18048 L
.57143 .18292 L
.57144 .18536 L
.57148 .18781 L
.57155 .19025 L
.57165 .19269 L
.57177 .19513 L
.57193 .19758 L
.5721 .20002 L
.57231 .20246 L
.57255 .2049 L
.57281 .20735 L
.5731 .20979 L
.57341 .21223 L
.57376 .21467 L
.57413 .21712 L
.57453 .21956 L
s
.59816 .14843 m
.59778 .15073 L
.59743 .15303 L
.59711 .15533 L
.59681 .15763 L
.59654 .15993 L
.59629 .16223 L
.59607 .16453 L
.59587 .16683 L
.59571 .16913 L
.59556 .17143 L
.59545 .17373 L
.59535 .17602 L
.59529 .17832 L
.59525 .18062 L
.59524 .18292 L
.59525 .18522 L
.59529 .18752 L
.59535 .18982 L
.59545 .19212 L
.59556 .19442 L
.59571 .19672 L
.59587 .19902 L
.59607 .20132 L
.59629 .20362 L
.59654 .20592 L
.59681 .20821 L
.59711 .21051 L
.59743 .21281 L
.59778 .21511 L
.59816 .21741 L
s
.62179 .15058 m
.62143 .15274 L
.62111 .15489 L
.6208 .15705 L
.62052 .1592 L
.62027 .16136 L
.62003 .16352 L
.61983 .16567 L
.61964 .16783 L
.61949 .16999 L
.61935 .17214 L
.61924 .1743 L
.61916 .17645 L
.6191 .17861 L
.61906 .18077 L
.61905 .18292 L
.61906 .18508 L
.6191 .18723 L
.61916 .18939 L
.61924 .19155 L
.61935 .1937 L
.61949 .19586 L
.61964 .19802 L
.61983 .20017 L
.62003 .20233 L
.62027 .20448 L
.62052 .20664 L
.6208 .2088 L
.62111 .21095 L
.62143 .21311 L
.62179 .21527 L
s
.64542 .15273 m
.64509 .15474 L
.64478 .15675 L
.64449 .15876 L
.64423 .16078 L
.64399 .16279 L
.64378 .1648 L
.64358 .16682 L
.64341 .16883 L
.64327 .17084 L
.64314 .17286 L
.64304 .17487 L
.64296 .17688 L
.6429 .1789 L
.64287 .18091 L
.64286 .18292 L
.64287 .18494 L
.6429 .18695 L
.64296 .18896 L
.64304 .19098 L
.64314 .19299 L
.64327 .195 L
.64341 .19701 L
.64358 .19903 L
.64378 .20104 L
.64399 .20305 L
.64423 .20507 L
.64449 .20708 L
.64478 .20909 L
.64509 .21111 L
.64542 .21312 L
s
.66904 .15487 m
.66874 .15674 L
.66845 .15861 L
.66819 .16048 L
.66794 .16235 L
.66772 .16422 L
.66752 .16609 L
.66734 .16796 L
.66718 .16983 L
.66705 .1717 L
.66693 .17357 L
.66684 .17544 L
.66676 .17731 L
.66671 .17918 L
.66668 .18105 L
.66667 .18292 L
.66668 .18479 L
.66671 .18666 L
.66676 .18853 L
.66684 .1904 L
.66693 .19227 L
.66705 .19414 L
.66718 .19601 L
.66734 .19788 L
.66752 .19975 L
.66772 .20162 L
.66794 .20349 L
.66819 .20536 L
.66845 .20723 L
.66874 .2091 L
.66904 .21097 L
s
.69267 .15702 m
.69239 .15874 L
.69212 .16047 L
.69188 .1622 L
.69166 .16393 L
.69145 .16565 L
.69127 .16738 L
.6911 .16911 L
.69095 .17083 L
.69083 .17256 L
.69072 .17429 L
.69063 .17601 L
.69056 .17774 L
.69052 .17947 L
.69049 .1812 L
.69048 .18292 L
.69049 .18465 L
.69052 .18638 L
.69056 .1881 L
.69063 .18983 L
.69072 .19156 L
.69083 .19328 L
.69095 .19501 L
.6911 .19674 L
.69127 .19847 L
.69145 .20019 L
.69166 .20192 L
.69188 .20365 L
.69212 .20537 L
.69239 .2071 L
.69267 .20883 L
s
.7163 .15916 m
.71604 .16075 L
.7158 .16233 L
.71557 .16392 L
.71537 .1655 L
.71518 .16708 L
.71501 .16867 L
.71486 .17025 L
.71472 .17183 L
.71461 .17342 L
.71451 .175 L
.71443 .17659 L
.71437 .17817 L
.71432 .17975 L
.71429 .18134 L
.71429 .18292 L
.71429 .18451 L
.71432 .18609 L
.71437 .18767 L
.71443 .18926 L
.71451 .19084 L
.71461 .19243 L
.71472 .19401 L
.71486 .19559 L
.71501 .19718 L
.71518 .19876 L
.71537 .20035 L
.71557 .20193 L
.7158 .20351 L
.71604 .2051 L
.7163 .20668 L
s
.73993 .16131 m
.73969 .16275 L
.73947 .16419 L
.73927 .16563 L
.73908 .16707 L
.73891 .16851 L
.73875 .16995 L
.73862 .1714 L
.73849 .17284 L
.73839 .17428 L
.7383 .17572 L
.73823 .17716 L
.73817 .1786 L
.73813 .18004 L
.7381 .18148 L
.7381 .18292 L
.7381 .18436 L
.73813 .1858 L
.73817 .18725 L
.73823 .18869 L
.7383 .19013 L
.73839 .19157 L
.73849 .19301 L
.73862 .19445 L
.73875 .19589 L
.73891 .19733 L
.73908 .19877 L
.73927 .20021 L
.73947 .20165 L
.73969 .20309 L
.73993 .20454 L
s
.76355 .16346 m
.76334 .16475 L
.76314 .16605 L
.76296 .16735 L
.76279 .16865 L
.76264 .16994 L
.7625 .17124 L
.76237 .17254 L
.76226 .17384 L
.76217 .17514 L
.76209 .17643 L
.76202 .17773 L
.76197 .17903 L
.76193 .18033 L
.76191 .18162 L
.7619 .18292 L
.76191 .18422 L
.76193 .18552 L
.76197 .18682 L
.76202 .18811 L
.76209 .18941 L
.76217 .19071 L
.76226 .19201 L
.76237 .19331 L
.7625 .1946 L
.76264 .1959 L
.76279 .1972 L
.76296 .1985 L
.76314 .19979 L
.76334 .20109 L
.76355 .20239 L
s
.78718 .1656 m
.78699 .16676 L
.78682 .16791 L
.78665 .16907 L
.7865 .17022 L
.78637 .17137 L
.78624 .17253 L
.78613 .17368 L
.78603 .17484 L
.78595 .17599 L
.78588 .17715 L
.78582 .1783 L
.78577 .17946 L
.78574 .18061 L
.78572 .18177 L
.78571 .18292 L
.78572 .18408 L
.78574 .18523 L
.78577 .18639 L
.78582 .18754 L
.78588 .1887 L
.78595 .18985 L
.78603 .19101 L
.78613 .19216 L
.78624 .19332 L
.78637 .19447 L
.7865 .19562 L
.78665 .19678 L
.78682 .19793 L
.78699 .19909 L
.78718 .20024 L
s
.81081 .16775 m
.81064 .16876 L
.81049 .16977 L
.81035 .17078 L
.81022 .17179 L
.8101 .17281 L
.80999 .17382 L
.80989 .17483 L
.8098 .17584 L
.80973 .17685 L
.80967 .17786 L
.80962 .17888 L
.80958 .17989 L
.80955 .1809 L
.80953 .18191 L
.80952 .18292 L
.80953 .18393 L
.80955 .18495 L
.80958 .18596 L
.80962 .18697 L
.80967 .18798 L
.80973 .18899 L
.8098 .19 L
.80989 .19102 L
.80999 .19203 L
.8101 .19304 L
.81022 .19405 L
.81035 .19506 L
.81049 .19607 L
.81064 .19709 L
.81081 .1981 L
s
.83444 .16989 m
.83429 .17076 L
.83416 .17163 L
.83404 .1725 L
.83393 .17337 L
.83382 .17424 L
.83373 .1751 L
.83365 .17597 L
.83357 .17684 L
.83351 .17771 L
.83346 .17858 L
.83341 .17945 L
.83338 .18032 L
.83335 .18119 L
.83334 .18205 L
.83333 .18292 L
.83334 .18379 L
.83335 .18466 L
.83338 .18553 L
.83341 .1864 L
.83346 .18727 L
.83351 .18813 L
.83357 .189 L
.83365 .18987 L
.83373 .19074 L
.83382 .19161 L
.83393 .19248 L
.83404 .19335 L
.83416 .19421 L
.83429 .19508 L
.83444 .19595 L
s
.85806 .17204 m
.85795 .17276 L
.85784 .17349 L
.85773 .17422 L
.85764 .17494 L
.85755 .17567 L
.85747 .17639 L
.85741 .17712 L
.85734 .17784 L
.85729 .17857 L
.85725 .17929 L
.85721 .18002 L
.85718 .18075 L
.85716 .18147 L
.85715 .1822 L
.85714 .18292 L
.85715 .18365 L
.85716 .18437 L
.85718 .1851 L
.85721 .18582 L
.85725 .18655 L
.85729 .18728 L
.85734 .188 L
.85741 .18873 L
.85747 .18945 L
.85755 .19018 L
.85764 .1909 L
.85773 .19163 L
.85784 .19235 L
.85795 .19308 L
.85806 .19381 L
s
.88169 .17418 m
.8816 .17477 L
.88151 .17535 L
.88143 .17593 L
.88135 .17651 L
.88128 .1771 L
.88122 .17768 L
.88116 .17826 L
.88111 .17884 L
.88107 .17943 L
.88103 .18001 L
.88101 .18059 L
.88098 .18117 L
.88097 .18176 L
.88096 .18234 L
.88095 .18292 L
.88096 .18351 L
.88097 .18409 L
.88098 .18467 L
.88101 .18525 L
.88103 .18584 L
.88107 .18642 L
.88111 .187 L
.88116 .18758 L
.88122 .18817 L
.88128 .18875 L
.88135 .18933 L
.88143 .18991 L
.88151 .1905 L
.8816 .19108 L
.88169 .19166 L
s
.90532 .17633 m
.90525 .17677 L
.90518 .17721 L
.90512 .17765 L
.90506 .17809 L
.90501 .17853 L
.90496 .17897 L
.90492 .17941 L
.90488 .17985 L
.90485 .18029 L
.90482 .18073 L
.9048 .18116 L
.90478 .1816 L
.90477 .18204 L
.90476 .18248 L
.90476 .18292 L
.90476 .18336 L
.90477 .1838 L
.90478 .18424 L
.9048 .18468 L
.90482 .18512 L
.90485 .18556 L
.90488 .186 L
.90492 .18644 L
.90496 .18688 L
.90501 .18732 L
.90506 .18776 L
.90512 .1882 L
.90518 .18864 L
.90525 .18907 L
.90532 .18951 L
s
.92895 .17848 m
.9289 .17877 L
.92885 .17907 L
.92881 .17937 L
.92877 .17966 L
.92874 .17996 L
.92871 .18026 L
.92868 .18055 L
.92865 .18085 L
.92863 .18114 L
.92861 .18144 L
.9286 .18174 L
.92859 .18203 L
.92858 .18233 L
.92857 .18263 L
.92857 .18292 L
.92857 .18322 L
.92858 .18352 L
.92859 .18381 L
.9286 .18411 L
.92861 .1844 L
.92863 .1847 L
.92865 .185 L
.92868 .18529 L
.92871 .18559 L
.92874 .18589 L
.92877 .18618 L
.92881 .18648 L
.92885 .18678 L
.9289 .18707 L
.92895 .18737 L
s
.95258 .18062 m
.95255 .18078 L
.95253 .18093 L
.95251 .18108 L
.95249 .18124 L
.95247 .18139 L
.95245 .18154 L
.95244 .1817 L
.95242 .18185 L
.95241 .182 L
.9524 .18216 L
.95239 .18231 L
.95239 .18246 L
.95238 .18262 L
.95238 .18277 L
.95238 .18292 L
.95238 .18308 L
.95238 .18323 L
.95239 .18338 L
.95239 .18354 L
.9524 .18369 L
.95241 .18384 L
.95242 .184 L
.95244 .18415 L
.95245 .1843 L
.95247 .18446 L
.95249 .18461 L
.95251 .18476 L
.95253 .18492 L
.95255 .18507 L
.95258 .18522 L
s
0 0 m
1 0 L
1 .3468 L
0 .3468 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 99.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Hb000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00I`3oool500000:D0oooo00@000000?ooo`00000000002`3oool006P0
oooo00@000000?ooo`3oool00000Y@3oool200000080oooo00<000000?ooo`3oool0203oool006P0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`02000000X0oooo001X0?ooo`030000
003oool0oooo0:L0oooo0`00000;0?ooo`00J03oool00`000000oooo0?ooo`2V0?ooo`8000000P3o
ool00`000000oooo0?ooo`080?ooo`00J03oool00`000000oooo0?ooo`2V0?ooo`030000003oool0
oooo008000002P3oool006L0oooo0`00002X0?ooo`80000000<0oooo0000003oool02@3oool006`0
oooo1`00002Q0?ooo`030000003oool0oooo00T0oooo001/0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00J`3oool800000:40oooo00<0
00000?ooo`3oool02@3oool006/0oooo0P00000507moO`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool02@3oool006/0oooo0P00000507moO`030000003oool0oooo09l0oooo00<000000?oo
o`3oool02@3oool006X0oooo00<0000007moO`0000001@1oOgl00`000000oooo0?ooo`2O0?ooo`03
0000003oool0oooo00T0oooo001Z0?ooo`030000001oOgl0000000H00000X@3oool00`000000oooo
0?ooo`090?ooo`00J@3oool010000000Ogmo07moO`00000507moO`030000003oool0oooo09l0oooo
00<000000?ooo`3oool02@3oool006T0oooo00@0000007moO`1oOgl000001@1oOgl00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo00T0oooo001Y0?ooo`040000001oOgl0Ogmo000000D0Ogmo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00J03oool01@000000Ogmo07mo
O`1oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00J03o
ool01@000000Ogmo07moO`1oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`090?ooo`00I`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I`3oool00`000000Ogmo07moO`02
07moO`L00000X@3oool00`000000oooo0?ooo`090?ooo`00I`3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?oo
o`00IP3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`090?ooo`00IP3oool00`000000Ogmo07moO`0307moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00IP3o
ool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`090?ooo`00I@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I@3oool00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`090?ooo`00I@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I03oool00`000000Ogmo
07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`090?ooo`00I03oool00`000000Ogmo07moO`0507moO`L00000X@3oool00`000000oooo0?oo
o`090?ooo`00I03oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I03oool00`000000Ogmo07moO`0507mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?oo
o`00H`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`090?ooo`002P3ooomH00WZ2P030?ooo`000000Ogmo00L0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00T0oooo
001R0?oooa402NX:X@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P000000Ogmo00P0Ogmo00<0000007moO`1oOgl00`1oOgl00`0000002NX:00WZ2P07
00WZ2YP0oooo00<000000?ooo`3oool02@3oool000X0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09
jPX0000007moO`0407moO`0700WZ2P1oOgl0Ogmo07moO`000000Ogmo00WZ2P0307moO`050000003o
ool0oooo0?ooo`09jPX01@3oool900WZ2Xl0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0000007moO`0407moO`0700WZ2P1oOgl0Ogmo07moO`000000
Ogmo00WZ2P0307moO`050000003oool0oooo0?ooo`09jPX01@3oool00`09jPX0oooo0?ooo`060?oo
o`d02NX:PP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P000000Ogmo00@0Ogmo00L02NX:07moO`1oOgl0Ogmo0000001oOgl02NX:00<0Ogmo00@00000
0?ooo`3oool02NX:1P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<0
2NX:0?ooo`3oool01P3oool900WZ2WT0oooo00<000000?ooo`3oool02@3oool000X0oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0000007moO`0407moO`0700WZ2P1oOgl0Ogmo07moO`000000Ogmo
00WZ2P0307moO`040000003oool0oooo00WZ2PH0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool01009jPX0
oooo0?ooo`3oool900WZ2W00oooo00<000000?ooo`3oool02@3oool000X0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0000007moO`0307moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P0000000`09jPX0
00000000000200000080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool900WZ2VL0oooo00<000000?ooo`3o
ool02@3oool000X0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0000007moO`0307moO`0300WZ
2P1oOgl0Ogmo0080Ogmo00<0000007moO`09jPX00`1oOgl010000000oooo0?ooo`09jPX60?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool03@09jPYJ0?ooo`030000003oool0oooo00T0
oooo000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0000001oOgl00`1oOgl00`09jPX0Ogmo
07moO`0207moO`030000001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1P3oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo00WZ2P0800WZ2U40oooo00<000000?ooo`3oool02@3oool000X0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0000007moO`0307moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`09jPX0
0`1oOgl010000000oooo0?ooo`09jPX50?ooo`802NX:1@3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`020?ooo`T0
2NX:B03oool00`000000oooo0?ooo`090?ooo`002P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl00P1oOgl00`000000Ogmo00WZ2P0307moO`040000
003oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo2P09jPXo0?ooo`030000003oool0oooo00T0oooo000:0?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`0207moO`030000
001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1@3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00<0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool00`3oool200WZ2PD0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0=00WZ2S80
oooo00<000000?ooo`3oool02@3oool000X0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0Ogmo
07moO`0307moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`09jPX00`1oOgl010000000oooo
0?ooo`09jPX50?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0
oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00T02NX::@3oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
0`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl00`000000Ogmo00WZ2P0307moO`040000003oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`020?ooo`T02NX:803oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
0`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl0
0P1oOgl00`000000Ogmo00WZ2P0307moO`040000003oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3o
ool00`3oool200WZ2PD0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool:00WZ2QL0oooo00<000000?ooo`3o
ool02@3oool000X0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo00<0oooo00<0000000WZ2P0000001@3oool00`09jPX0Ogmo07moO`0307moO`0300WZ
2P1oOgl0Ogmo00<0000000<0Ogmo00WZ2P1oOgl00P1oOgl00`000000oooo00WZ2P060?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
0`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
0`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
0`3oool01009jPX0oooo0?ooo`3oool=00WZ2P80oooo0`0000050?ooo`030000003oool0oooo00T0
oooo000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P000000000000<0000000<0oooo00WZ2P1oOgl0101oOgl01009jPX0Ogmo
07moO`1oOgl30000000700WZ2P000000000007moO`000000oooo00WZ2P060?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`802NX:0P3oool4
00WZ2PD0000000<0oooo0000003oool02P3oool000X0oooo00<02NX:000000000000100000000`09
jPX00000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09
jPX00000000000030000000300WZ2P000000000000@0000000<02NX:000000000000100000000`09
jPX00000000000030000000300WZ2P000000000000@0000000<02NX:000000000000100000000`09
jPX00000000000030000000300WZ2P000000000000@0000000<02NX:000000000000100000000`09
jPX00000000000030000000300WZ2P000000000000@0000000<02NX:0000000000000`0000000`09
jPX00000000000040000000300WZ2P000000000000@0000000<02NX:0000000000000`0000000`09
jPX00000000000040000000300WZ2P000000000000@0000000<02NX:0000000000000`0000000`09
jPX00000000000040000000300WZ2P000000000000@0000000<02NX:0000000000000`0000000`09
jPX00000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09
jPX00000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09
jPX00000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09
jPX00000000000040000000300WZ2P000000000000<0000000<02NX:000000000000100000000`09
jPX0000000000003000000802NX:1@0000000`09jPX0000000000005000000/0oooo000:0?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`03
00WZ2P0000000000008000000P3oool00`09jPX0Ogmo07moO`0307moO`0400WZ2P1oOgl0Ogmo07mo
O`<0000000L02NX:0000001oOgl0Ogmo0000003oool02NX:00H0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool0oooo0?ooo`T02NX:1@0000020?ooo`030000
003oool0oooo00T0oooo000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`030?ooo`0300000009jPX0oooo00D0oooo00<02NX:07moO`1oOgl00`1o
Ogl00`09jPX0Ogmo07moO`030000000307moO`09jPX0Ogmo0080Ogmo00<000000?ooo`09jPX01P3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00P02NX:203oool2000000H0oooo00<0
00000?ooo`3oool02@3oool000X0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0Ogmo07moO`03
07moO`0300WZ2P1oOgl0Ogmo0080Ogmo00<0000007moO`09jPX00`1oOgl010000000oooo0?ooo`09
jPX50?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPX50?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool00`3oool200WZ2PD0oooo00<02NX:0?ooo`09jPX03@09jPXH0?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:07moO`1oOgl00`1oOgl0
0`09jPX0Ogmo07moO`0207moO`030000001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1@3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`T02NX:9P3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P1oOgl0Ogmo00<0Ogmo00<02NX:07moO`1oOgl00P1oOgl0
0`000000Ogmo00WZ2P0307moO`040000003oool0oooo00WZ2PD0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0080oooo2009jPX_0?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:07moO`1oOgl00`1oOgl0
0`09jPX0Ogmo07moO`0207moO`030000001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1@3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPX50?ooo`0300WZ2P3o
ool0oooo00@0oooo00<02NX:0?ooo`09jPX02009jPXg0?ooo`030000003oool0oooo00T0oooo000:
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`03
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:07moO`1oOgl00`1oOgl00`09jPX0Ogmo07moO`02
07moO`030000001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1@3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`09jPX03009jPY00?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0000001oOgl00`1oOgl0
0`09jPX0Ogmo07moO`0207moO`030000001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1P3o
ool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3o
ool200WZ2PD0oooo2@09jPY=0?ooo`030000003oool0oooo00T0oooo000:0?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0000001oOgl00`1oOgl00`09jPX0Ogmo07moO`0207moO`030000001oOgl0
2NX:00<0Ogmo00@000000?ooo`3oool02NX:1P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3o
ool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3o
ool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3o
ool0oooo00@0oooo00@02NX:0?ooo`3oool0oooo2@09jPYF0?ooo`030000003oool0oooo00T0oooo
000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?oo
o`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0000001oOgl00`1oOgl00`09jPX0Ogmo07mo
O`0207moO`030000001oOgl02NX:00<0Ogmo00@000000?ooo`3oool02NX:1P3oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool01009jPX0oooo
0?ooo`3oool=00WZ2Ul0oooo00<000000?ooo`3oool02@3oool000X0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
103oool00`09jPX0000007moO`0307moO`0300WZ2P1oOgl0Ogmo0080Ogmo0P0000000`09jPX00000
0000000200000080oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`09jPX02009jPY/0?ooo`030000003oool0oooo00T0oooo
000:0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?oo
o`030?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0000001oOgl0101oOgl01`09jPX0Ogmo07mo
O`1oOgl0000007moO`09jPX00`1oOgl010000000oooo0?ooo`09jPX60?ooo`0300WZ2P3oool0oooo
00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo
00<0oooo2@09jPYe0?ooo`030000003oool0oooo00T0oooo000:0?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0000001oOgl0101oOgl01`09jPX0Ogmo07moO`1oOgl0000007moO`09jPX00`1oOgl0
1@000000oooo0?ooo`3oool02NX:00D0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?oo
o`070?ooo`T02NX:OP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P000000Ogmo00@0Ogmo00L02NX:07moO`1oOgl0Ogmo0000001oOgl02NX:00<0Ogmo
00D000000?ooo`3oool0oooo00WZ2P050?ooo`0400WZ2P3oool0oooo0?ooo`d02NX:Q`3oool00`00
0000oooo0?ooo`090?ooo`002P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00@0
oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00<0
oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P000000Ogmo00@0
Ogmo00L02NX:07moO`1oOgl0Ogmo0000001oOgl02NX:00<0Ogmo00<000000?ooo`3oool00P3oool9
00WZ2Y@0oooo00<000000?ooo`3oool02@3oool00680oooo00<0000007moO`1oOgl01@1oOgl=00WZ
2Yd0oooo00<000000?ooo`3oool02@3oool000X0ooooH009jPX207moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00H`3oool00`000000Ogmo
07moO`0607moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`090?ooo`00H`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00H`3oool00`000000Ogmo07moO`06
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`09
0?ooo`00I03oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo00<0Ogmo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I03oool00`000000Ogmo07moO`0507moO`L0
0000X@3oool00`000000oooo0?ooo`090?ooo`00I03oool00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I@3o
ool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`090?ooo`00I@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00I@3oool00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`090?ooo`00I@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00IP3oool00`000000Ogmo
07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`090?ooo`00IP3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00<0Ogmo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00IP3oool00`000000Ogmo07moO`03
07moO`L00000X@3oool00`000000oooo0?ooo`090?ooo`00I`3oool00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?oo
o`00I`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`090?ooo`00J03oool01@000000Ogmo07moO`1oOgl0000000D0
Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00J03oool01@000000Ogmo
07moO`1oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`090?ooo`00
J03oool01@000000Ogmo07moO`1oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3oool00`000000
oooo0?ooo`090?ooo`00J@3oool010000000Ogmo07moO`00000507moO`030000003oool0oooo09l0
oooo00<000000?ooo`3oool02@3oool006T0oooo00<0000007moO`1oOgl01`00002Q0?ooo`030000
003oool0oooo00T0oooo001Z0?ooo`030000001oOgl0000000D0Ogmo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`090?ooo`00JP3oool00`000000Ogmo0000000507moO`030000003oool0
oooo09l0oooo00<000000?ooo`3oool02@3oool006/0oooo0P00000507moO`030000003oool0oooo
09l0oooo00<000000?ooo`3oool02@3oool006/0oooo0P00000507moO`030000003oool0oooo09l0
oooo00<000000?ooo`3oool02@3oool006/0oooo2000002Q0?ooo`030000003oool0oooo00T0oooo
001/0?ooo`L00000X@3oool00`000000oooo0?ooo`090?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {98.875, 0}} -> {-56.197, -30.6532, 0.576286, \
0.576286}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell["\<\
Next, we define the system using 21 Gaussian wavelets to approximate a \
collimated beam of light. Because each Gaussian wavelet follows the \
symbolically calculated solution for the system, relatively few numbers of \
wavelets are required to accurately model the system's behavior.\
\>", "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell["\<\
waveletSystem = {
\tMove[LineOfWavelets[10,NumberOfRays->21],-50],
\tPlanoConvexLens[100,50,10],
\tMove[Screen[50],103]};\
\>", "Input",
  CellLabel->"In[69]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[TextData[{
  "Finally, we use ",
  StyleBox["FindField", "Input"],
  " to construct a symbolic solution of the field intensity. This calculation \
will take about 10 minutes on many computers."
}], "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
Timing[intensity = FindField[waveletSystem]][[1]]/60/Second*\"Minutes\"
ByteCount[intensity]\
\>", "Input",
  CellLabel->"In[70]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[BoxData[
    \(17.815555555555555`\ "Minutes"\)], "Output",
  CellLabel->"Out[70]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[BoxData[
    \(291720\)], "Output",
  CellLabel->"Out[71]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell["\<\
Here is plot of the intensity near the plane of focus. The vertical axis is \
intensity. The horizontal axis is measured in millimeters.\
\>", "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
Plot[intensity[0,y],{y,-.022,.022},PlotRange->All,PlotPoints->100];\
\>", "Input",
  CellLabel->"In[72]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 21.645 0.0147148 0.00504223 [
[.0671 .00221 -15 -9 ]
[.0671 .00221 15 0 ]
[.28355 .00221 -15 -9 ]
[.28355 .00221 15 0 ]
[.71645 .00221 -12 -9 ]
[.71645 .00221 12 0 ]
[.9329 .00221 -12 -9 ]
[.9329 .00221 12 0 ]
[.4875 .11556 -12 -4.5 ]
[.4875 .11556 0 4.5 ]
[.4875 .2164 -12 -4.5 ]
[.4875 .2164 0 4.5 ]
[.4875 .31725 -12 -4.5 ]
[.4875 .31725 0 4.5 ]
[.4875 .41809 -12 -4.5 ]
[.4875 .41809 0 4.5 ]
[.4875 .51894 -18 -4.5 ]
[.4875 .51894 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0671 .01471 m
.0671 .02096 L
s
[(-0.02)] .0671 .00221 0 1 Mshowa
.28355 .01471 m
.28355 .02096 L
s
[(-0.01)] .28355 .00221 0 1 Mshowa
.71645 .01471 m
.71645 .02096 L
s
[(0.01)] .71645 .00221 0 1 Mshowa
.9329 .01471 m
.9329 .02096 L
s
[(0.02)] .9329 .00221 0 1 Mshowa
.125 Mabswid
.11039 .01471 m
.11039 .01846 L
s
.15368 .01471 m
.15368 .01846 L
s
.19697 .01471 m
.19697 .01846 L
s
.24026 .01471 m
.24026 .01846 L
s
.32684 .01471 m
.32684 .01846 L
s
.37013 .01471 m
.37013 .01846 L
s
.41342 .01471 m
.41342 .01846 L
s
.45671 .01471 m
.45671 .01846 L
s
.54329 .01471 m
.54329 .01846 L
s
.58658 .01471 m
.58658 .01846 L
s
.62987 .01471 m
.62987 .01846 L
s
.67316 .01471 m
.67316 .01846 L
s
.75974 .01471 m
.75974 .01846 L
s
.80303 .01471 m
.80303 .01846 L
s
.84632 .01471 m
.84632 .01846 L
s
.88961 .01471 m
.88961 .01846 L
s
.02381 .01471 m
.02381 .01846 L
s
.97619 .01471 m
.97619 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
.5 .11556 m
.50625 .11556 L
s
[(20)] .4875 .11556 1 0 Mshowa
.5 .2164 m
.50625 .2164 L
s
[(40)] .4875 .2164 1 0 Mshowa
.5 .31725 m
.50625 .31725 L
s
[(60)] .4875 .31725 1 0 Mshowa
.5 .41809 m
.50625 .41809 L
s
[(80)] .4875 .41809 1 0 Mshowa
.5 .51894 m
.50625 .51894 L
s
[(100)] .4875 .51894 1 0 Mshowa
.125 Mabswid
.5 .03993 m
.50375 .03993 L
s
.5 .06514 m
.50375 .06514 L
s
.5 .09035 m
.50375 .09035 L
s
.5 .14077 m
.50375 .14077 L
s
.5 .16598 m
.50375 .16598 L
s
.5 .19119 m
.50375 .19119 L
s
.5 .24162 m
.50375 .24162 L
s
.5 .26683 m
.50375 .26683 L
s
.5 .29204 m
.50375 .29204 L
s
.5 .34246 m
.50375 .34246 L
s
.5 .36767 m
.50375 .36767 L
s
.5 .39288 m
.50375 .39288 L
s
.5 .4433 m
.50375 .4433 L
s
.5 .46852 m
.50375 .46852 L
s
.5 .49373 m
.50375 .49373 L
s
.5 .54415 m
.50375 .54415 L
s
.5 .56936 m
.50375 .56936 L
s
.5 .59457 m
.50375 .59457 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .01672 m
.03318 .0162 L
.04339 .0155 L
.04836 .01518 L
.05078 .01505 L
.05298 .01495 L
.05512 .01487 L
.05744 .0148 L
.05806 .01479 L
.05872 .01478 L
.05932 .01477 L
.05989 .01476 L
.06042 .01476 L
.06072 .01475 L
.06099 .01475 L
.06129 .01475 L
.06146 .01475 L
.06162 .01475 L
.0619 .01475 L
.06221 .01475 L
.06251 .01475 L
.06268 .01475 L
.06284 .01475 L
.06316 .01475 L
.06351 .01476 L
.06413 .01476 L
.0647 .01477 L
.06609 .0148 L
.0674 .01483 L
.06974 .01492 L
.07229 .01505 L
.07708 .0154 L
.08218 .01588 L
.09133 .01697 L
.10107 .01815 L
.10555 .01861 L
.10809 .01882 L
.11045 .01898 L
.1128 .0191 L
.11412 .01915 L
.11531 .01919 L
.11597 .0192 L
.11657 .01921 L
.11689 .01921 L
.11724 .01922 L
.11741 .01922 L
.1176 .01922 L
.11778 .01922 L
.11794 .01922 L
.11826 .01922 L
Mistroke
.11855 .01922 L
.11872 .01922 L
.11887 .01922 L
.11922 .01921 L
.11952 .01921 L
.11984 .01921 L
.12043 .0192 L
.121 .01918 L
.12162 .01917 L
.12274 .01913 L
.12406 .01907 L
.12527 .019 L
.12789 .01882 L
.13038 .01859 L
.13968 .01741 L
.14958 .01593 L
.15195 .01561 L
.1545 .0153 L
.15671 .01508 L
.15795 .01497 L
.15911 .01489 L
.16034 .01482 L
.16145 .01477 L
.16206 .01475 L
.16263 .01473 L
.16295 .01473 L
.16324 .01472 L
.16356 .01472 L
.16372 .01472 L
.1639 .01472 L
.16419 .01472 L
.16447 .01472 L
.16472 .01472 L
.16499 .01472 L
.16529 .01472 L
.1656 .01473 L
.16616 .01475 L
.16668 .01476 L
.16717 .01478 L
.16828 .01485 L
.16941 .01493 L
.17066 .01505 L
.17317 .01537 L
.17549 .01577 L
.17765 .01623 L
.1826 .01761 L
.18711 .01925 L
.19679 .02374 L
.20611 .02869 L
.21083 .03112 L
Mistroke
.21602 .03353 L
.22101 .0354 L
.22319 .03605 L
.22557 .03663 L
.22682 .03688 L
.22798 .03707 L
.22916 .03723 L
.23027 .03734 L
.23089 .03739 L
.23122 .03741 L
.23156 .03742 L
.23185 .03744 L
.23217 .03745 L
.23246 .03746 L
.23273 .03746 L
.23289 .03746 L
.23306 .03746 L
.23323 .03746 L
.23339 .03746 L
.23368 .03746 L
.23399 .03746 L
.23415 .03745 L
.23432 .03745 L
.23463 .03744 L
.23534 .0374 L
.23592 .03736 L
.23654 .03731 L
.23766 .03719 L
.23899 .037 L
.2402 .03679 L
.24283 .03621 L
.24532 .03551 L
.25465 .03204 L
.25937 .03013 L
.26188 .02919 L
.26457 .02832 L
.26589 .02795 L
.26715 .02765 L
.26838 .02741 L
.26951 .02724 L
.27006 .02718 L
.27058 .02713 L
.27087 .0271 L
.27118 .02708 L
.27146 .02707 L
.27172 .02706 L
.27201 .02705 L
.27228 .02705 L
.27257 .02705 L
.27289 .02706 L
Mistroke
.27305 .02706 L
.27322 .02707 L
.27354 .02708 L
.27384 .0271 L
.27413 .02713 L
.27472 .02719 L
.27526 .02727 L
.27647 .0275 L
.27759 .02779 L
.27866 .02815 L
.28105 .02923 L
.28366 .0309 L
.28616 .03299 L
.28843 .03535 L
.29351 .04231 L
.29818 .05081 L
.30322 .06229 L
.31316 .09132 L
.32273 .1253 L
.33193 .16015 L
.34173 .19499 L
.35116 .22188 L
.35362 .22737 L
.35631 .2325 L
.35862 .2362 L
.36118 .23947 L
.36237 .2407 L
.36365 .24181 L
.36476 .24259 L
.36598 .24327 L
.3666 .24354 L
.36727 .24377 L
.36764 .24388 L
.36797 .24396 L
.36832 .24402 L
.36863 .24407 L
.36892 .2441 L
.36923 .24413 L
.36954 .24414 L
.36972 .24414 L
.36988 .24414 L
.37018 .24413 L
.37045 .24411 L
.37077 .24407 L
.37107 .24403 L
.3717 .2439 L
.37229 .24373 L
.3734 .24331 L
.37459 .24271 L
.37588 .24188 L
Mistroke
.3782 .23997 L
.38034 .23777 L
.38992 .22422 L
.39913 .20978 L
.40387 .20384 L
.40523 .20249 L
.40652 .2014 L
.40767 .20058 L
.40894 .19987 L
.40953 .19962 L
.41015 .1994 L
.41044 .19931 L
.41075 .19924 L
.41103 .19918 L
.41129 .19914 L
.41159 .1991 L
.4119 .19908 L
.4122 .19907 L
.41248 .19907 L
.41263 .19908 L
.4128 .19909 L
.4131 .19913 L
.41327 .19915 L
.41342 .19918 L
.41378 .19926 L
.41435 .19942 L
.4149 .19964 L
.41593 .20017 L
.41704 .20096 L
.41824 .20207 L
.42052 .20491 L
.42303 .20922 L
.42565 .21509 L
.42812 .22192 L
.433 .23921 L
.43749 .25941 L
.44708 .31507 L
.45631 .38023 L
.46613 .45385 L
.47559 .51929 L
.48041 .54753 L
.48564 .57257 L
.48808 .58195 L
.49067 .59012 L
.49288 .5956 L
.49405 .59791 L
.49532 .59996 L
.49597 .60083 L
.49658 .60153 L
.49721 .60212 L
Mistroke
.49778 .60256 L
.49834 .60289 L
.49887 .60312 L
.49916 .60321 L
.49942 .60327 L
.49972 .60331 L
.50003 .60332 L
.50034 .6033 L
.50063 .60326 L
.50079 .60322 L
.50096 .60318 L
.50127 .60307 L
.50188 .60278 L
.50244 .60241 L
.50305 .60189 L
.50372 .60119 L
.50509 .59936 L
.50628 .5973 L
.50754 .59467 L
.50978 .58884 L
.51484 .57057 L
.51962 .54737 L
.52408 .5214 L
.53354 .45624 L
.5436 .38086 L
.5533 .31257 L
.56263 .25884 L
.56745 .2374 L
.56991 .2283 L
.57255 .21994 L
.57503 .21342 L
.57729 .20859 L
.57957 .20477 L
.58173 .20209 L
.58296 .20096 L
.58407 .20018 L
.58468 .19983 L
.58534 .19953 L
.58597 .19932 L
.58625 .19925 L
.58655 .19918 L
.58683 .19914 L
.58708 .1991 L
.58734 .19908 L
.58758 .19907 L
.58787 .19907 L
.58813 .19908 L
.58841 .1991 L
.58872 .19914 L
.58899 .19918 L
Mistroke
.58928 .19924 L
.58981 .19939 L
.59043 .1996 L
.59101 .19985 L
.59216 .20048 L
.59339 .20133 L
.59561 .2033 L
.60063 .20944 L
.6107 .22521 L
.61576 .23283 L
.61797 .23576 L
.62041 .23858 L
.6226 .24069 L
.62495 .24243 L
.62625 .24315 L
.62743 .24364 L
.628 .24382 L
.6283 .2439 L
.62862 .24397 L
.6289 .24402 L
.62921 .24407 L
.62949 .2441 L
.62975 .24412 L
.63003 .24414 L
.63034 .24414 L
.63063 .24414 L
.63089 .24412 L
.63119 .24409 L
.63137 .24407 L
.63153 .24405 L
.63213 .24393 L
.63271 .24378 L
.63335 .24356 L
.63464 .24295 L
.63575 .24225 L
.63695 .24131 L
.63912 .23913 L
.64158 .23591 L
.64425 .23151 L
.64912 .22121 L
.65898 .19264 L
.66848 .15861 L
.67856 .12048 L
.68828 .08663 L
.69763 .06017 L
.70247 .0495 L
.70758 .04061 L
.70988 .0374 L
.71235 .03449 L
.71466 .03225 L
Mistroke
.71679 .03057 L
.71926 .02907 L
.72057 .02846 L
.72195 .02794 L
.72315 .02759 L
.72427 .02735 L
.72491 .02724 L
.7255 .02717 L
.72615 .0271 L
.72647 .02708 L
.72664 .02707 L
.72683 .02707 L
.72715 .02705 L
.72744 .02705 L
.72776 .02705 L
.72794 .02705 L
.72811 .02705 L
.72842 .02706 L
.72869 .02708 L
.72902 .0271 L
.72932 .02712 L
.73041 .02723 L
.73102 .02731 L
.73159 .02741 L
.73405 .02794 L
.73667 .0287 L
.74677 .03262 L
.75184 .03457 L
.75406 .03532 L
.7565 .03603 L
.7587 .03657 L
.76106 .03701 L
.76236 .03719 L
.76355 .03732 L
.76412 .03737 L
.76474 .03741 L
.76502 .03742 L
.76532 .03744 L
.7656 .03745 L
.76586 .03745 L
.76616 .03746 L
.76647 .03746 L
.76676 .03746 L
.76706 .03746 L
.76735 .03746 L
.76763 .03745 L
.76788 .03745 L
.76815 .03744 L
.76877 .03741 L
.76942 .03736 L
Mistroke
.7706 .03725 L
.77169 .03712 L
.77271 .03696 L
.77504 .0365 L
.77757 .03584 L
.77997 .03507 L
.78447 .03332 L
.79376 .02876 L
.80364 .02352 L
.80855 .02112 L
.81316 .01914 L
.81762 .01754 L
.82231 .01624 L
.82465 .01574 L
.8272 .01532 L
.82833 .01516 L
.82953 .01503 L
.83058 .01493 L
.83169 .01485 L
.8323 .01481 L
.83298 .01478 L
.8336 .01475 L
.83417 .01474 L
.83452 .01473 L
.83485 .01472 L
.83515 .01472 L
.83531 .01472 L
.83547 .01472 L
.83565 .01472 L
.83582 .01472 L
.83598 .01472 L
.83614 .01472 L
.83633 .01472 L
.83652 .01472 L
.83668 .01472 L
.83686 .01472 L
.83719 .01473 L
.8375 .01473 L
.83808 .01475 L
.83871 .01477 L
.83939 .0148 L
.84175 .01495 L
.84403 .01515 L
.84655 .01542 L
.85165 .0161 L
.8614 .01757 L
.86589 .01817 L
.86843 .01847 L
.87079 .0187 L
.87335 .01891 L
Mistroke
.87566 .01905 L
.87694 .01912 L
.87814 .01916 L
.87875 .01918 L
.87941 .01919 L
.87975 .0192 L
.88012 .01921 L
.88046 .01921 L
.88078 .01921 L
.88107 .01922 L
.88139 .01922 L
.8817 .01922 L
.88188 .01922 L
.88205 .01922 L
.88235 .01922 L
.88262 .01922 L
.88293 .01921 L
.88325 .01921 L
.88381 .0192 L
.88432 .01919 L
.8855 .01916 L
.88678 .01912 L
.88795 .01907 L
.89057 .01892 L
.89521 .01854 L
.90025 .018 L
.91016 .01678 L
.91509 .01618 L
.91971 .01569 L
.92441 .01528 L
.92888 .01499 L
.93123 .01488 L
.93256 .01483 L
.93379 .0148 L
.93438 .01479 L
.93493 .01478 L
.93544 .01477 L
.93597 .01476 L
.93625 .01476 L
.93655 .01476 L
.93683 .01475 L
.93708 .01475 L
.93738 .01475 L
.93755 .01475 L
.9377 .01475 L
.93798 .01475 L
.93829 .01475 L
.93858 .01475 L
.93885 .01475 L
.93915 .01475 L
Mistroke
.93946 .01476 L
.93999 .01476 L
.94057 .01477 L
.94187 .01479 L
.94308 .01482 L
.94555 .01489 L
.94818 .015 L
.95335 .01529 L
.95824 .01561 L
.96757 .01625 L
.97619 .01672 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`004_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol0000Voooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0005oooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00009oooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000;ooooo1Ol0000@ooooo`004Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00009Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0GOooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool09Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00004?ooool000[ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`0Nooooo`Go00000_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0GOooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool09Oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool04?ooool0
017ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo02Cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo05gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00oooooo000Aooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo02?ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo05gooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo02Go
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool03_ooool0017ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool08oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo0_l0001Oooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool2o`0002Oooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool03_ooool001;ooooo0_l0000:oooo
o`;o00000oooool3o`0002Oooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`1Noooo
o`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool09_ooool2o`0000[ooooo0_l00003oooo
o`?o00004Oooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0
S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool0
00Ooooooool0000Bo`0000Sooooo000=ooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`ko
00000oooool00ol0003oooooooooo`04ooooo`Go00002oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooo000000;o00001_ooool00ol0003oooooooooo`02ooooo`ko00001Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00cooooo000Iooooo`03o`000?oooooooooo023ooooo
0_l0000Fooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Dooooo`?o00008Oooool00ol0003oooooooooo`0Hooooo`00?_ooool00ol0003ooooooooo
o`0?ooooo`?o0000??ooool00ol0003oooooooooo`0jooooo`?o00004Oooool00ol0003ooooooooo
o`0mooooo`00?oooool3o`0000_ooooo0ol00002ooooo`?o0000>_ooool00ol0003oooooooooo`0h
ooooo`?o00000_ooool3o`0000cooooo0_l00010ooooo`00@_ooool00ol0003oooooooooo`06oooo
o`;o00002?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo0_l00007oooo
o`?o00001oooool2o`0004;ooooo0013ooooo`So00002_ooool2o`0003Sooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`09ooooo`So0000A?ooool005Oooooo00?o0000ooooooooool0
=Oooool2o`0003Oooooo00?o0000ooooooooool0EOooool005Oooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo05Kooooo001Hooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1Gooooo`00F?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0Eoooool005So
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo05So
oooo001Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`1Hooooo`00FOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0F?ooool005Wooooo00?o0000ooooooooool0<oooool2o`0003?ooooo00?o0000
ooooooooool0FOooool005[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo05Wooooo001Jooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`1Iooooo`00F_ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0F_ooool005_ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo05[ooooo001Kooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Jooooo`00Foooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Foooool005co
oooo00?o0000ooooooooool0<?ooool2o`00037ooooo00?o0000ooooooooool0Foooool005cooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05_ooooo
001Mooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`1Looooo`00GOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0G?ooool005gooooo00?o0000ooooooooool08?ooool5o`0000?ooooo0_l00005oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0G?ooool005kooooo00?o0000oooooooo
ool08?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`1Looooo`00G_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool3o`0002oooooo00?o0000
ooooooooool0G?ooool005kooooo00?o0000ooooooooool08_ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo05gooooo001Oooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`1Mooooo`00Goooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
GOooool005oooooo00?o0000ooooooooool07oooool3o`0000Cooooo0_l00005ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0GOooool005oooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05kooooo001Pooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Nooooo`00H?ooool00ol0003o
ooooooooo`0/ooooo`;o0000;_ooool00ol0003oooooooooo`1Nooooo`00H?ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Goooool0063ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05oooooo001P
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1O
ooooo`00HOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0H?ooool0067ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo063ooooo001Qooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`1Pooooo`00HOooool00ol0003oooooooooo`0[ooooo`;o0000:ooo
ool00ol0003oooooooooo`1Qooooo`00H_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0HOooool006;ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo067ooooo001Rooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Rooooo`00Hoooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0H_ooool006?ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06;ooooo001S
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1S
ooooo`00I?ooool00ol0003oooooooooo`0Xooooo`;o0000:Oooool00ol0003oooooooooo`1Soooo
o`00I?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0Hoooool006Cooooo00?o0000ooooooooool03oooool3o`0001Kooooo00?o0000ooooooooool0
5?ooool3o`00017ooooo00?o0000ooooooooool0Hoooool006Cooooo00?o0000ooooooooool03_oo
ool2o`000003ooooool0003o000001Gooooo00?o0000ooooooooool04oooool2o`000003ooooool0
003o000000oooooo00?o0000ooooooooool0I?ooool006Gooooo00?o0000ooooooooool03?ooool2
o`0000?ooooo00?o0000ooooooooool01_ooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooo
oooo01?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo06Cooooo001U
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo06Cooooo001Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`Go00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo06Cooooo001Vooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
1?ooool3o`00017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo06Gooooo001Vooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Uooooo`00I_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1Uooooo`00Ioooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o00001Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Vooooo`00J?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`00J?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Wooooo`00JOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Xooooo`00JOooool5o`0000oooooo
00?o0000ooooooooool03oooool2o`00013ooooo00?o0000ooooooooool03?ooool5o`0006_ooooo
001[ooooo`;o00004?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool2o`0006cooooo001mooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1looooo`00O_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0OOooool007kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07gooooo001nooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1mooooo`00O_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0OOoo
ool007kooooo00?o0000ooooooooool03_ooool2o`0000oooooo00?o0000ooooooooool0OOooool0
07oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
07gooooo001oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1nooooo`00Ooooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0O_ooool007oooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo07kooooo001oooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1nooooo`00P?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0O_ooool0083ooooo00?o0000oooooooo
ool03?ooool2o`0000kooooo00?o0000ooooooooool0O_ooool0083ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07kooooo0020ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1oooooo`00P?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Ooooool0
087ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
07oooooo0020ooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1oooooo`00P?ooool2o`0000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`?o00003?ooool00ol0
003oooooooooo`1oooooo`00P?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo07oooooo0020ooooo`;o00001Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Ooooool0087o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0P?ooool0087ooooo0ol00004ooooo`;o00001Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo083ooooo0022ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`20ooooo`00P_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0P?ooool008;ooooo00?o0000
ooooooooool02_ooool2o`0000cooooo00?o0000ooooooooool0P?ooool008;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo083ooooo0022ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`21ooooo`00
P_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
POooool008;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo087ooooo0022ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`21ooooo`00P_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0POooool008?ooooo00?o0000ooooooooool02Oooool2o`0000_o
oooo00?o0000ooooooooool0POooool008?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo087ooooo0023ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`22ooooo`00Poooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0P_ooool008?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08;ooooo0023ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`22ooooo`00
Poooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
P_ooool008?ooooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool0P_oo
ool008Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo08?ooooo0024ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`23ooooo`00Q?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0Poooool0087ooooo1?l00003ooooo`;o00001Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo08?ooooo0020ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Poooool0083ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`23ooooo`00POooool4o`0000;o
oooo00Co0000oooooooooooo00001?ooool3o`0000Sooooo00?o0000ooooooooool0Poooool0083o
oooo00Co0000oooooooooooooooo0_l000001Ooooooo0000oooooooooooo000000Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`24ooooo`00P?ooool01?l0003oooooooooooooool2
o`000005ooooool0003oooooooooool000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo08Cooooo0021ooooo`?o000000Coooooo`000?oooooooooo0_l00005ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Q?ooool008Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Cooooo0025ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`24ooooo`00QOooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Q?ooool008Gooooo
00?o0000ooooooooool01oooool2o`0000Sooooo00?o0000ooooooooool0Q?ooool008Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Gooooo0026
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`25
ooooo`00Q_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0QOooool008Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo08Gooooo0026ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`25ooooo`00Q_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0QOooool008Kooooo00?o0000ooooooooool01_ooool2
o`0000Oooooo00?o0000ooooooooool0QOooool008Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo08Kooooo0027ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`26ooooo`00Qoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q_ooool008Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Kooooo0027
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`26
ooooo`00Qoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Q_ooool008Oooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool0Q_ooool008Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo08Kooooo0027ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`26ooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Qoooool007_ooooo0ol00004ooooo`;o00001?ooool2o`00
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27ooooo`00O?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000ooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Qoooool007cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?ooool00oooool3o`00
00Cooooo00?o0000ooooooooool0Qoooool007cooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo08Oooooo001looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`27ooooo`00Noooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool2o`00
0003ooooool0003ooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27oooo
o`00O?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`28ooooo`00ROooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0R?ooool008Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo002:ooooo`03o`000?oooooo
oooo00;ooooo0_l00003ooooo`03o`000?oooooooooo08Wooooo002:ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`29ooooo`00R_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ROooool008[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Wooooo
002:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`29ooooo`00Roooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0R_oo
ool008_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo08[ooooo002;
ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`2:ooooo`00Roooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0R_ooool008_ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo08[ooooo002<ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool0R_ooool008cooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`2;ooooo`00S?ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo08_ooooo002<ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0Rooo
ool008gooooo00?o0000ooooool000000_l0002>ooooo`00SOooool00ol0003oooooo`000002o`00
08kooooo002>ooooo`?o0000Soooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o
0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000oooo
ooooool0S_ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0243111, -9.02594, \
0.000169415, 0.727257}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell[TextData[{
  "The vertical axis is normalized to have a unity area. We can check this \
result with ",
  StyleBox["NIntegrate", "Input"],
  ". In fact, you could also use the ",
  StyleBox["Integrate", "Input"],
  " to do this symbolically, but the calculation time would be prohibitive."
}], "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["NIntegrate[intensity[0,y],{y,-.1,.1}]", "Input",
  CellLabel->"In[73]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[BoxData[
    \(0.9999999972334601`\)], "Output",
  CellLabel->"Out[73]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell["\<\
We now compare this plot with the point spread function that is calculated \
numerically for the same surface location. Although not identical, the two \
results are consistent with each other.\
\>", "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
psf = PointSpreadFunction/.PSF[{
\tMove[LineOfRays[10],-50],
\tPlanoConvexLens[100,50,10],
\tMove[Screen[50],103]},NumberOfPoints->256,PaddingFactor->10];\
\>", "Input",
  CellLabel->"In[74]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952018 0.603319 1.77778 [
[.11919 -0.0125 -6 -9 ]
[.11919 -0.0125 6 0 ]
[.3096 -0.0125 -6 -9 ]
[.3096 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.6904 -0.0125 -3 -9 ]
[.6904 -0.0125 3 0 ]
[.88081 -0.0125 -3 -9 ]
[.88081 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06999 -24 -4.5 ]
[-0.0125 .06999 0 4.5 ]
[-0.0125 .15887 -30 -4.5 ]
[-0.0125 .15887 0 4.5 ]
[-0.0125 .24776 -24 -4.5 ]
[-0.0125 .24776 0 4.5 ]
[-0.0125 .33665 -30 -4.5 ]
[-0.0125 .33665 0 4.5 ]
[-0.0125 .42554 -24 -4.5 ]
[-0.0125 .42554 0 4.5 ]
[-0.0125 .51443 -30 -4.5 ]
[-0.0125 .51443 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11919 0 m
.11919 .00625 L
s
[(-4)] .11919 -0.0125 0 1 Mshowa
.3096 0 m
.3096 .00625 L
s
[(-2)] .3096 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.6904 0 m
.6904 .00625 L
s
[(2)] .6904 -0.0125 0 1 Mshowa
.88081 0 m
.88081 .00625 L
s
[(4)] .88081 -0.0125 0 1 Mshowa
.125 Mabswid
.16679 0 m
.16679 .00375 L
s
.21439 0 m
.21439 .00375 L
s
.262 0 m
.262 .00375 L
s
.3572 0 m
.3572 .00375 L
s
.4048 0 m
.4048 .00375 L
s
.4524 0 m
.4524 .00375 L
s
.5476 0 m
.5476 .00375 L
s
.5952 0 m
.5952 .00375 L
s
.6428 0 m
.6428 .00375 L
s
.738 0 m
.738 .00375 L
s
.78561 0 m
.78561 .00375 L
s
.83321 0 m
.83321 .00375 L
s
.07159 0 m
.07159 .00375 L
s
.02399 0 m
.02399 .00375 L
s
.92841 0 m
.92841 .00375 L
s
.97601 0 m
.97601 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06999 m
.00625 .06999 L
s
[(-0.3)] -0.0125 .06999 1 0 Mshowa
0 .15887 m
.00625 .15887 L
s
[(-0.25)] -0.0125 .15887 1 0 Mshowa
0 .24776 m
.00625 .24776 L
s
[(-0.2)] -0.0125 .24776 1 0 Mshowa
0 .33665 m
.00625 .33665 L
s
[(-0.15)] -0.0125 .33665 1 0 Mshowa
0 .42554 m
.00625 .42554 L
s
[(-0.1)] -0.0125 .42554 1 0 Mshowa
0 .51443 m
.00625 .51443 L
s
[(-0.05)] -0.0125 .51443 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .08776 m
.00375 .08776 L
s
0 .10554 m
.00375 .10554 L
s
0 .12332 m
.00375 .12332 L
s
0 .1411 m
.00375 .1411 L
s
0 .17665 m
.00375 .17665 L
s
0 .19443 m
.00375 .19443 L
s
0 .21221 m
.00375 .21221 L
s
0 .22999 m
.00375 .22999 L
s
0 .26554 m
.00375 .26554 L
s
0 .28332 m
.00375 .28332 L
s
0 .3011 m
.00375 .3011 L
s
0 .31887 m
.00375 .31887 L
s
0 .35443 m
.00375 .35443 L
s
0 .37221 m
.00375 .37221 L
s
0 .38999 m
.00375 .38999 L
s
0 .40776 m
.00375 .40776 L
s
0 .44332 m
.00375 .44332 L
s
0 .4611 m
.00375 .4611 L
s
0 .47887 m
.00375 .47887 L
s
0 .49665 m
.00375 .49665 L
s
0 .53221 m
.00375 .53221 L
s
0 .54999 m
.00375 .54999 L
s
0 .56776 m
.00375 .56776 L
s
0 .58554 m
.00375 .58554 L
s
0 .05221 m
.00375 .05221 L
s
0 .03443 m
.00375 .03443 L
s
0 .01665 m
.00375 .01665 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11919 .61178 m
.11919 .61803 L
s
.3096 .61178 m
.3096 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.6904 .61178 m
.6904 .61803 L
s
.88081 .61178 m
.88081 .61803 L
s
.125 Mabswid
.16679 .61428 m
.16679 .61803 L
s
.21439 .61428 m
.21439 .61803 L
s
.262 .61428 m
.262 .61803 L
s
.3572 .61428 m
.3572 .61803 L
s
.4048 .61428 m
.4048 .61803 L
s
.4524 .61428 m
.4524 .61803 L
s
.5476 .61428 m
.5476 .61803 L
s
.5952 .61428 m
.5952 .61803 L
s
.6428 .61428 m
.6428 .61803 L
s
.738 .61428 m
.738 .61803 L
s
.78561 .61428 m
.78561 .61803 L
s
.83321 .61428 m
.83321 .61803 L
s
.07159 .61428 m
.07159 .61803 L
s
.02399 .61428 m
.02399 .61803 L
s
.92841 .61428 m
.92841 .61803 L
s
.97601 .61428 m
.97601 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06999 m
1 .06999 L
s
.99375 .15887 m
1 .15887 L
s
.99375 .24776 m
1 .24776 L
s
.99375 .33665 m
1 .33665 L
s
.99375 .42554 m
1 .42554 L
s
.99375 .51443 m
1 .51443 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .08776 m
1 .08776 L
s
.99625 .10554 m
1 .10554 L
s
.99625 .12332 m
1 .12332 L
s
.99625 .1411 m
1 .1411 L
s
.99625 .17665 m
1 .17665 L
s
.99625 .19443 m
1 .19443 L
s
.99625 .21221 m
1 .21221 L
s
.99625 .22999 m
1 .22999 L
s
.99625 .26554 m
1 .26554 L
s
.99625 .28332 m
1 .28332 L
s
.99625 .3011 m
1 .3011 L
s
.99625 .31887 m
1 .31887 L
s
.99625 .35443 m
1 .35443 L
s
.99625 .37221 m
1 .37221 L
s
.99625 .38999 m
1 .38999 L
s
.99625 .40776 m
1 .40776 L
s
.99625 .44332 m
1 .44332 L
s
.99625 .4611 m
1 .4611 L
s
.99625 .47887 m
1 .47887 L
s
.99625 .49665 m
1 .49665 L
s
.99625 .53221 m
1 .53221 L
s
.99625 .54999 m
1 .54999 L
s
.99625 .56776 m
1 .56776 L
s
.99625 .58554 m
1 .58554 L
s
.99625 .05221 m
1 .05221 L
s
.99625 .03443 m
1 .03443 L
s
.99625 .01665 m
1 .01665 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .01472 Mdot
.05455 .02675 Mdot
.08529 .05391 Mdot
.11603 .09288 Mdot
.14676 .14057 Mdot
.17749 .19417 Mdot
.20821 .25108 Mdot
.23893 .30895 Mdot
.26965 .36567 Mdot
.30037 .41939 Mdot
.33109 .46845 Mdot
.3618 .51147 Mdot
.39251 .54728 Mdot
.42322 .57495 Mdot
.45393 .59379 Mdot
.48464 .60332 Mdot
.51536 .60332 Mdot
.54607 .59379 Mdot
.57678 .57495 Mdot
.60749 .54728 Mdot
.6382 .51147 Mdot
.66891 .46845 Mdot
.69963 .41939 Mdot
.73035 .36567 Mdot
.76107 .30895 Mdot
.79179 .25108 Mdot
.82251 .19417 Mdot
.85324 .14057 Mdot
.88397 .09288 Mdot
.91471 .05391 Mdot
.94545 .02675 Mdot
.97619 .01472 Mdot
.5 Mabswid
.02381 .01472 m
.03853 .02048 L
.04619 .02347 L
.05024 .02506 L
.05247 .02593 L
.05357 .02636 L
.05405 .02655 L
.0543 .02665 L
.05458 .02677 L
.05507 .02721 L
.05553 .02761 L
.05654 .0285 L
.05867 .03038 L
.06238 .03367 L
.06965 .04009 L
.07716 .04673 L
.08113 .05023 L
.08331 .05216 L
.08536 .05399 L
.08947 .05921 L
.0932 .06394 L
.10049 .07317 L
.11517 .09179 L
.13079 .11579 L
.14583 .13914 L
.1603 .16419 L
.1757 .19105 L
.19052 .21831 L
.20628 .2475 L
.22146 .27603 L
.23606 .30354 L
.2516 .33233 L
.26655 .35995 L
.28094 .3854 L
.29625 .41219 L
.31099 .43635 L
.32666 .46139 L
.34176 .4834 L
.35627 .50373 L
.37173 .52305 L
.3866 .54039 L
.40241 .5562 L
.41764 .56992 L
.43229 .58051 L
.44788 .59007 L
.46289 .59657 L
.47733 .60105 L
.48113 .60223 L
.483 .60281 L
.48391 .60309 L
Mistroke
.48431 .60321 L
.48473 .60332 L
.48523 .60332 L
.4857 .60332 L
.48672 .60332 L
.48889 .60332 L
.49269 .60332 L
.50015 .60332 L
.5041 .60332 L
.50833 .60332 L
.51043 .60332 L
.51241 .60332 L
.51419 .60332 L
.51468 .60332 L
.51495 .60332 L
.5152 .60332 L
.51564 .60323 L
.51613 .60308 L
.5234 .60082 L
.53815 .59624 L
.54212 .59501 L
.54405 .59441 L
.54489 .59415 L
.54534 .59401 L
.5458 .59387 L
.5463 .59364 L
.54676 .59336 L
.54766 .59281 L
.54965 .59159 L
.55385 .58901 L
.5683 .58015 L
.58369 .56873 L
.5985 .55538 L
.61424 .53941 L
.62941 .52172 L
.644 .50335 L
.65952 .48161 L
.67447 .45958 L
.68884 .43663 L
.70414 .4115 L
.71887 .38575 L
.73453 .35796 L
.74961 .33011 L
.76411 .30321 L
.77955 .27413 L
.79442 .24621 L
.81021 .21696 L
.82543 .18908 L
.84007 .16354 L
.85565 .13684 L
Mistroke
.87065 .11356 L
.88507 .09149 L
.90042 .07202 L
.9152 .05348 L
.92326 .04636 L
.93091 .03959 L
.93855 .03284 L
.94187 .02991 L
.94362 .02836 L
.94458 .02752 L
.94504 .0271 L
.94547 .02674 L
.94593 .02656 L
.94643 .02636 L
.94748 .02595 L
.94933 .02523 L
.95297 .0238 L
.96096 .02068 L
.97615 .01473 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[74]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00@oooool3o`0002[ooooo1Ol0000Yooooo`;o0000;?ooool5o`0002cooooo0ol0000Poooo
o`00A?ooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`0002Sooooo00Co0000oooo
oooooooo0000;?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo01oooooo000k
ooooo`Go000000?oooooo`000?l000000ol0000Tooooo`Go00000oooool00ol0003oooooooooo`0X
ooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0:_ooool5o`00023ooooo0011
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool09oooool01?l0003ooooooooo
ool0000^ooooo`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo00008Oooool004;ooooo
00?o0000ooooool00000:oooool01Ol0003ooooooooooooooooo000002Sooooo00Co0000oooooooo
oooo0000:oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooool000008Oooool0
04?ooooo0_l0000[ooooo`05o`000?ooooooooooooooool00000:?ooool01?l0003oooooooooool0
000[ooooo`05o`000?ooooooooooooooool00000;?ooool2o`00027ooooo0014ooooo`03o`000?oo
oooooooo02[ooooo0ol0000Zooooo`;o0000;Oooool3o`0002kooooo00?o0000ooooooooool07ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool002Cooooon?l0
0004ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo000Toooo
o`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`02oooo
o`009?ooool00ol0003oooooooooo`02ooooo`?o0000Loooool00ol0003oooooooooo`1booooo`;o
00001Oooool00ol0003oooooooooo`02ooooo`009?ooool2o`0000?ooooo0_l000000ooooooo0000
ooooo`1aooooo`03o`000?oooooooooo073ooooo1?l00004ooooo`;o00001?ooool002Cooooo00?o
0000ooooooooool01_ooool3o`0006oooooo00?o0000ooooooooool0K_ooool2o`0000Wooooo00?o
0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool02Oooool3o`0006cooooo00?o0000
ooooooooool0Joooool3o`0000_ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooo
ooooool02_ooool2o`0006cooooo00?o0000ooooooooool0Joooool2o`0000cooooo00?o0000oooo
ooooool00_ooool002Cooooo0_l0000=ooooo`03o`000?oooooooooo06Wooooo00?o0000oooooooo
ool0JOooool2o`0000gooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo06Sooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo00kooooo0_l0001Xooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`009?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00_ooool002Cooooo0_l0000Booooo`;o0000IOooool00ol0003o
ooooooooo`1Sooooo`;o00004oooool2o`0000Cooooo000Aooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`?o0000I?ooool00ol0003ooooo
ooooo`1Sooooo`;o00005?ooool00ol0003oooooooooo`02ooooo`004?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00;ooooo0009ooooo`Go00000_ooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`00
4?ooool01?l0003oooooooooool00009ooooo`;o00001Oooool2o`0001Kooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Gooooo0_l00004ooooo`00
4?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`02ooooo`004?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00;ooooo000Aooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`02ooooo`009?ooool2o`0001Wooooo00?o0000ooooooooool0GOooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo01Oooooo0_l00004ooooo`009?ooool00ol0003ooooooooo
o`0Iooooo`;o0000GOooool00ol0003oooooooooo`1Looooo`;o00006oooool00ol0003ooooooooo
o`02ooooo`009?ooool00ol0003oooooooooo`0Iooooo`;o0000GOooool00ol0003oooooooooo`1L
ooooo`;o00006oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool00_ooool002Cooooo0_l0000Looooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`0Jooooo`;o00001?ooool002Cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo05Sooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00;ooooo000Tooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool002Co
oooo0_l0000Oooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`0Mooooo`;o00001?ooool002Cooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool0E_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo000T
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooo
ooooool08?ooool2o`0005Kooooo00?o0000ooooooooool0E?ooool2o`0002?ooooo00?o0000oooo
ooooool00_ooool002Cooooo0_l0000Qooooo`;o0000E_ooool00ol0003oooooooooo`1Dooooo`;o
00008_ooool2o`0000Cooooo000;ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000;o
oooo0ol00005ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool000[ooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool0Doooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo0003oooo
o`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool0Doooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo000:oooo
o`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`;o00009Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool08_ooool2o`0000Cooooo000:ooooo`04o`000?ooooooooooo`0000Oooooo00Ko0000
ooooooooooooooooo`000?ooool4o`0000Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`02ooooo`002_ooool01?l0003oooooooooool00007ooooo`07o`000?ooooooooooooooool0
003oooooo`000008ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool000_o
oooo0_l00009ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02ooooo`009?ooool2o`0002Oooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo02Gooooo0_l00004ooooo`009?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool00_ooool002Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02oooo
o`009?ooool00ol0003oooooooooo`0Xooooo`;o0000C_ooool00ol0003oooooooooo`1=ooooo`;o
0000:_ooool00ol0003oooooooooo`02ooooo`009?ooool2o`0002Wooooo0_l0001>ooooo`03o`00
0?oooooooooo04gooooo0_l0000Yooooo`;o00001?ooool002Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo00;ooooo000Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool002Co
oooo0_l0000/ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`0Zooooo`;o00001?ooool002Cooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo000T
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00_ooool002Cooooo0_l0000^oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0/oooo
o`;o00001?ooool002Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`00
4Oooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool00_ooool0013ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00_ooool000Wo
oooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo000@ooooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool00oooool2o`00037ooooo0_l00016ooooo`03o`000?oooooooooo
04Gooooo0_l0000aooooo`;o00001?ooool0013ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0<?ooool2o`0004Kooooo00?o0000
ooooooooool0AOooool2o`0003;ooooo00?o0000ooooooooool00_ooool0013ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`02ooooo`004Oooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool00_ooool002Cooooo0_l0000cooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0aooooo`;o00001?ooool002Co
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`02
ooooo`009?ooool2o`0003Kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo03?ooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
0_ooool002Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`009?ooool2
o`0003Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo03Gooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
00;ooooo000Tooooo`03o`000?oooooooooo03Oooooo0_l0000oooooo`03o`000?oooooooooo03go
oooo0ol0000iooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo03Oooooo
0_l0000oooooo`03o`000?oooooooooo03gooooo0_l0000jooooo`03o`000?oooooooooo00;ooooo
000Tooooo`;o0000>Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0>?ooool2o`0000Cooooo000Tooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool00_ooool000_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00003oooo
o`?o00001Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo000:ooooo`04
o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`000oooool5o`00
00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`002_ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2
o`0003cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo03_ooooo0_l00004ooooo`002_ooool01?l0003oooooooooool00009ooooo`04o`000?oooooo
ooooooooo`Co00001Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00;ooooo000:
ooooo`04o`000?ooooooooooo`0000Sooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`02ooooo`002oooool2o`0000[ooooo00Co0000
oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00_oo
ool002Cooooo0_l0000oooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0mooooo`;o00001?ooool002Cooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00;o
oooo000Tooooo`03o`000?oooooooooo03oooooo0_l0000gooooo`03o`000?oooooooooo03Kooooo
0_l00011ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo03oooooo0_l0
000gooooo`03o`000?oooooooooo03Kooooo0_l00011ooooo`03o`000?oooooooooo00;ooooo000T
ooooo`;o0000@Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0@?ooool2o`0000Cooooo000Tooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool00_ooool002Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`00
9?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00;ooooo000Tooooo`;o0000@ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@Ooo
ool2o`0000Cooooo000Tooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool00_ooool0
02Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo00;ooooo000Tooooo`;o0000A_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0A?ooool2o`0000Cooooo
000Tooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool00_ooool0017ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool00_ooool0013ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo04Kooooo0_l0000`ooooo`03o`000?oooooooooo02kooooo0_l00019
ooooo`03o`000?oooooooooo00;ooooo0009ooooo`Go00000_ooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0A_ooool2o`00033ooooo00?o0000
ooooooooool0;_ooool2o`0004Wooooo00?o0000ooooooooool00_ooool0013ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000BOooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Aoooool2o`0000Cooooo000@oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo00;ooooo000@ooooo`04o`000?ooooooooooo`0000Sooooo0_l00006
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool00_ooool0017ooooo0_l0000:oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`02oooo
o`009?ooool2o`0004_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo04Wooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool00_oo
ool002Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo00;ooooo000Tooooo`;o0000Coooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0C?ooool2o`0000Co
oooo000Tooooo`03o`000?oooooooooo04kooooo0_l0000Xooooo`03o`000?oooooooooo02Oooooo
0_l0001@ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo04kooooo0_l0
000Xooooo`03o`000?oooooooooo02Oooooo0_l0001@ooooo`03o`000?oooooooooo00;ooooo000T
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool00_ooool002Cooooo0_l0001Aoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1?oooo
o`;o00001?ooool002Cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`02ooooo`00
9?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool00_ooool002Cooooo0_l0001Dooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Booooo`;o00001?ooool0
02Cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`02ooooo`002oooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool00_ooool000[ooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo00;ooooo0003ooooo`Go00000_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Fooooo`;o00008?ooool00ol0003oooooooooo`0Oooooo`;o0000F?ooool00ol0003ooooooooo
o`02ooooo`002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool00_ooool2o`0005Oooooo0_l0000Pooooo`03o`000?oooooooooo01oooooo
0_l0001Gooooo`;o00001?ooool000[ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
ooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00;o
oooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00008
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool00_ooool000_ooooo0_l0000:oooo
o`;o00000_ooool5o`0000Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`02oooo
o`009?ooool2o`0005_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo05Wooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool00_oo
ool002Cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`02ooooo`009?ooool00ol0
003oooooooooo`1Mooooo`;o00006Oooool00ol0003oooooooooo`0Gooooo`;o0000H?ooool00ol0
003oooooooooo`02ooooo`009?ooool2o`0005kooooo0ol0000Hooooo`03o`000?oooooooooo01Oo
oooo0_l0001Oooooo`;o00001?ooool002Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Gooooo0_l0001Rooooo`03o`000?oooooooooo00;ooooo
000Tooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`009?ooool2o`0006Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`;o0000IOooool2o`0000Cooooo000Tooooo`03
o`000?oooooooooo06Cooooo0ol0000Aooooo`03o`000?oooooooooo013ooooo0_l0001Wooooo`03
o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo06Gooooo0ol0000@ooooo`03o`00
0?oooooooooo00oooooo0ol0001Wooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oo
oooooooo06Sooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo0_l0001Zooooo`03o`000?oo
oooooooo00;ooooo000Tooooo`;o0000Joooool2o`0000cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1Yooooo`;o00001?ooool002Cooooo00?o0000ooooooooool0K?ooool2o`00
00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo
00;ooooo000Mooooo`;o00001Oooool00ol0003oooooooooo`1/ooooo`?o00002Oooool00ol0003o
ooooooooo`08ooooo`?o0000K_ooool00ol0003oooooooooo`02ooooo`007?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo06cooooo0_l000001?oooooo0000o`000?l00006oooo
o`03o`000?oooooooooo00Gooooo1Ol0001_ooooo`03o`000?oooooooooo00;ooooo000Looooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0L_ooool4o`0000;ooooo00Co0000oooo
oooooooooooo1?l0001dooooo`03o`000?oooooooooo00;ooooo000Looooo`04o`000?oooooooooo
o`0000Cooooo0_l0001eooooo`[o0000MOooool2o`0000Cooooo000Looooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
oooo00;ooooo000Looooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`007Oooool2o`0000Gooooon?l00004ooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00=_ooool3o`0008[ooooo00?o0000ooooooooool0:oooool3
o`0001Gooooo00?o0000ooooooooool05?ooool003Oooooo00?o0000ooooooooool0R?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool0037o
oooo0ol00003ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o00000oooool4o`000003
ooooool0003o000000?o00001oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6o`0000Ko
oooo1?l00002ooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`0000;o
oooo0ol00002ooooo`?o00001?ooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`00
00?ooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool4o`00
00?ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`00
0004ooooool0003o0000ooooo`Co00000oooool2o`0000;ooooo2_l00005ooooo`03o`000?oooooo
oooo01;ooooo000`ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo000`ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooooooool5o`0000;ooooo00?o0000ooooooooool0
0_ooool5o`0000;ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`Go00002?ooool00ol0
003oooooooooo`02ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000?ooooo00?o0000
ooooool000000_ooool5o`0000?ooooo00Co0000oooooooooooooooo1Ol00002ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo01;ooooo000`ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001Oooool01_l0003ooooo
ooooool0003oooooo`0000Sooooo00?o0000ooooooooool04_ooool0033ooooo00Ko0000oooooooo
ooooooooo`000?ooool4o`0000;ooooo1?l00002ooooo`?o00001?ooool3o`0000?ooooo0_l00005
ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l0
0003ooooo`?o00002Oooool01Ol0003oooooooooool0003ooooo00?o00001?ooool4o`0000;ooooo
1?l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`Co0000
0oooool3o`0000?ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo1_l000000ooooooo0000
o`000003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Cooooo00?o0000ooooooooool0
0_ooool3o`0000;ooooo1?l00003ooooo`Wo00000oooool3o`0000?ooooo1?l00004ooooo`03o`00
0?oooooooooo01;ooooo000`ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Cooooo`00<Oooool3o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0=ooooo`?o00002Oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`0000[o
oooo1?l00004ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o0000;_ooool00ol0003o
ooooooooo`0Hooooo`?o00005_ooool00ol0003oooooooooo`02ooooo`;o00002oooool00ol0003o
ooooooooo`0Dooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.79886, -0.366882, \
0.0424976, 0.00227578}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 21.644 0.0144024 0.00620464 [
[.06712 .0019 -15 -9 ]
[.06712 .0019 15 0 ]
[.28356 .0019 -15 -9 ]
[.28356 .0019 15 0 ]
[.5 .0019 -3 -9 ]
[.5 .0019 3 0 ]
[.71644 .0019 -12 -9 ]
[.71644 .0019 12 0 ]
[.93288 .0019 -12 -9 ]
[.93288 .0019 12 0 ]
[.01131 .1385 -12 -4.5 ]
[.01131 .1385 0 4.5 ]
[.01131 .26259 -12 -4.5 ]
[.01131 .26259 0 4.5 ]
[.01131 .38668 -12 -4.5 ]
[.01131 .38668 0 4.5 ]
[.01131 .51077 -12 -4.5 ]
[.01131 .51077 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06712 .0144 m
.06712 .02065 L
s
[(-0.02)] .06712 .0019 0 1 Mshowa
.28356 .0144 m
.28356 .02065 L
s
[(-0.01)] .28356 .0019 0 1 Mshowa
.5 .0144 m
.5 .02065 L
s
[(0)] .5 .0019 0 1 Mshowa
.71644 .0144 m
.71644 .02065 L
s
[(0.01)] .71644 .0019 0 1 Mshowa
.93288 .0144 m
.93288 .02065 L
s
[(0.02)] .93288 .0019 0 1 Mshowa
.125 Mabswid
.11041 .0144 m
.11041 .01815 L
s
.1537 .0144 m
.1537 .01815 L
s
.19698 .0144 m
.19698 .01815 L
s
.24027 .0144 m
.24027 .01815 L
s
.32685 .0144 m
.32685 .01815 L
s
.37014 .0144 m
.37014 .01815 L
s
.41342 .0144 m
.41342 .01815 L
s
.45671 .0144 m
.45671 .01815 L
s
.54329 .0144 m
.54329 .01815 L
s
.58658 .0144 m
.58658 .01815 L
s
.62986 .0144 m
.62986 .01815 L
s
.67315 .0144 m
.67315 .01815 L
s
.75973 .0144 m
.75973 .01815 L
s
.80302 .0144 m
.80302 .01815 L
s
.8463 .0144 m
.8463 .01815 L
s
.88959 .0144 m
.88959 .01815 L
s
.02383 .0144 m
.02383 .01815 L
s
.97617 .0144 m
.97617 .01815 L
s
.25 Mabswid
0 .0144 m
1 .0144 L
s
.02381 .1385 m
.03006 .1385 L
s
[(20)] .01131 .1385 1 0 Mshowa
.02381 .26259 m
.03006 .26259 L
s
[(40)] .01131 .26259 1 0 Mshowa
.02381 .38668 m
.03006 .38668 L
s
[(60)] .01131 .38668 1 0 Mshowa
.02381 .51077 m
.03006 .51077 L
s
[(80)] .01131 .51077 1 0 Mshowa
.125 Mabswid
.02381 .04543 m
.02756 .04543 L
s
.02381 .07645 m
.02756 .07645 L
s
.02381 .10747 m
.02756 .10747 L
s
.02381 .16952 m
.02756 .16952 L
s
.02381 .20054 m
.02756 .20054 L
s
.02381 .23156 m
.02756 .23156 L
s
.02381 .29361 m
.02756 .29361 L
s
.02381 .32463 m
.02756 .32463 L
s
.02381 .35566 m
.02756 .35566 L
s
.02381 .4177 m
.02756 .4177 L
s
.02381 .44873 m
.02756 .44873 L
s
.02381 .47975 m
.02756 .47975 L
s
.02381 .5418 m
.02756 .5418 L
s
.02381 .57282 m
.02756 .57282 L
s
.02381 .60384 m
.02756 .60384 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .02087 m
.03571 .02217 L
.04762 .02223 L
.05952 .02095 L
.07143 .01871 L
.08333 .01629 L
.09524 .01472 L
.10714 .01492 L
.11905 .01747 L
.13095 .02227 L
.14286 .02854 L
.15476 .03493 L
.16667 .03986 L
.17857 .04204 L
.19048 .0409 L
.20238 .037 L
.21429 .03208 L
.22619 .02885 L
.2381 .03039 L
.25 .03946 L
.2619 .05764 L
.27381 .08475 L
.28571 .11863 L
.29762 .15534 L
.30952 .18988 L
.32143 .2173 L
.33333 .23385 L
.34524 .23808 L
.35714 .23142 L
.36905 .21819 L
.38095 .20491 L
.39286 .199 L
.40476 .2072 L
.41667 .23396 L
.42857 .2802 L
.44048 .34277 L
.45238 .41475 L
.46429 .48658 L
.47619 .54776 L
.4881 .58885 L
.5 .60332 L
.5119 .58885 L
.52381 .54776 L
.53571 .48658 L
.54762 .41475 L
.55952 .34277 L
.57143 .2802 L
.58333 .23396 L
.59524 .2072 L
.60714 .199 L
Mistroke
.61905 .20491 L
.63095 .21819 L
.64286 .23142 L
.65476 .23808 L
.66667 .23385 L
.67857 .2173 L
.69048 .18988 L
.70238 .15534 L
.71429 .11863 L
.72619 .08475 L
.7381 .05764 L
.75 .03946 L
.7619 .03039 L
.77381 .02885 L
.78571 .03208 L
.79762 .037 L
.80952 .0409 L
.82143 .04204 L
.83333 .03986 L
.84524 .03493 L
.85714 .02854 L
.86905 .02227 L
.88095 .01747 L
.89286 .01492 L
.90476 .01472 L
.91667 .01629 L
.92857 .01871 L
.94048 .02095 L
.95238 .02223 L
.96429 .02217 L
.97619 .02087 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[74]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`007oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol0000Roooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0002Wooooo0_l0000[oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0002?ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00005?ooool001kooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00027ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo02Oo
oooo00Co0000oooooooooooo0000:Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005?ooool001Oooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0J
ooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool09oooool01?l0003oooooooooool0000Yooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Qooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Dooooo`007_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool08?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool09oooool01?l0003oooooooooool0000Yooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Cooooo`007_ooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`0Oooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0Wooooo`04o`000?ooooooooooo`0002Wooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool04_ooool0
01kooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool07oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo0_l0000Yooooo`04o`000?ooooooooooo`0002Wooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00002ooooo`;o00008oooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Booooo`007oooool2o`00
00[ooooo0_l00003ooooo`?o00008oooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo
02Sooooo0_l0000[ooooo`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool08_ooool2o`00
00[ooooo0_l00003ooooo`?o00005Oooool001_ooooo00?o0000ooooooooool0ooooool3ooooo`00
6oooool00ol0003oooooooooo`3oooooo`?ooooo000Kooooo`03o`000?oooooooooo0?oooooo0ooo
ool001_ooooo00?o0000ooooooooool0ooooool3ooooo`005Oooooono`0000gooooo000Kooooo`?o
00001Oooool6o`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00005
ooooo`;o00004oooool001_ooooo00?o0000ooooooooool01Ol0000Cooooo`?o0000]oooool2o`00
01Cooooo1Ol0000Eooooo`006oooool00ol0003oooooooooo`0Kooooo`;o00004_ooool4o`0008Oo
oooo1?l0000Aooooo`?o0000<?ooool001_ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0<ooooo`?o00001?ooool2o`0008;ooooo0ol00004ooooo`?o00003Oooool00ol0003ooooo
ooooo`0aooooo`006oooool00ol0003oooooooooo`0Nooooo`?o00002?ooool3o`0000Wooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`08ooooo`?o00002?ooool2o`0003Cooooo000K
ooooo`03o`000?oooooooooo027ooooo0ol00002ooooo`?o00003Oooool00ol0003oooooooooo`1l
ooooo`03o`000?oooooooooo00cooooo0ol00002ooooo`?o0000=_ooool001_ooooo00?o0000oooo
ooooool09?ooool2o`00013ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0?oooo
o`;o0000>Oooool001_ooooo0_l0000hooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo
ool0Boooool001_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo04cooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`1<ooooo`006oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo07Kooooo00?o0000ooooooooool0COooool001_ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`1fooooo`03o`000?oooooooooo04gooooo000Kooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`1>ooooo`006oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0C_ooool001_ooooo0_l0
000looooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Coooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo04oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1?oooo
o`006oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool0D?ooool001_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1`ooooo`03o`00
0?oooooooooo053ooooo000Kooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`1Aooooo`006oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0DOooool001_ooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo057ooooo000Kooooo`;o0000?oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo05;ooooo000Kooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1Booooo`006oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0D_ooool001_ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo05?ooooo000Koooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1Coooo
o`006oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo06Sooooo00?o0000oooooooo
ool0E?ooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo06Sooooo00?o0000ooooooooool0E?ooool000gooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`1Dooooo`003_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Cooooo0ol00011ooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool0EOooool000oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo05Go
oooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Eoooo
o`003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0E_ooool0
00gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool0E_ooool001_ooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo05Kooooo000Kooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Gooooo`006oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Eoooool001_ooooo0_l00014
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Eoooool001_ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo05Sooooo000Kooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Hooooo`00
6oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
F?ooool001_ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo05Wooooo000Kooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`1Iooooo`006oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool0FOooool001_ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0@ooooo`?o0000=?ooool3o`0001;ooooo00?o0000ooooooooool0F_ooool001_ooooo
0_l00017ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000booooo`05
o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`1Jooooo`006oooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Kooooo`006oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Kooooo`006oooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Kooooo`006oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1Looooo`006oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Loooo
o`006oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Mooooo`006oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Nooooo`006ooo
ool2o`0004cooooo0ol00002ooooo`;o00003oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00cooooo0ol00002ooooo`;o0000HOooool001_ooooo00?o0000ooooooooool0C_ooool2
o`00017ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`;o0000Hoooool0
01_ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
07Cooooo000Kooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1eooooo`006oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0MOooool000kooooo0ol00003ooooo`;o00001Oooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0MOooool000oooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Gooooo000<ooooo`Go00000_ooool0
1?l0003oooooooooool00004ooooo`?o0000Hoooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo07Kooooo000<ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
M_ooool000gooooo00?o0000ooooool000000oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1fooooo`003_oo
ool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0M_ooool000oooooo00?o0000ooooooooool00_oo
ool2o`0000Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo07Oooooo000Kooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1gooooo`006oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0Moooool001_ooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo07Oooooo000Kooooo`;o0000IOooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo07Oooooo000Kooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`1hooooo`006oooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0N?ooool001_ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Sooooo000Kooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1hooooo`00
6oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
N?ooool001_ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo07Wooooo000Kooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1iooooo`006oooool2o`0006Oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`1iooooo`006oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0NOooool001_ooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo07Wooooo000Kooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`1jooooo`006oooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0N_ooool001_ooooo00?o0000oooo
ooooool0Ioooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07[ooooo000Kooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1jooooo`00
6oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
N_ooool001_ooooo0_l0001Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0N_oo
ool001_ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo07_ooooo000Kooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1kooooo`006oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0Noooool001_ooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo07_ooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07_ooooo000<
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo06Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1kooooo`003?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0O?ooool000cooooo
1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo0ol0001Yooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0O?ooool000cooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1looooo`003Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07co
oooo000>ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0JOooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo07cooooo000Kooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`1looooo`006oooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0OOooool001_ooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07gooooo000Kooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1mooooo`00
6oooool2o`0006_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1mooooo`006ooo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0OOoo
ool001_ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo07gooooo000Kooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`1nooooo`006oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0O_ooool001_ooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo07kooooo000Kooooo`03o`000?oooooooooo06_ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`1nooooo`006oooool00ol0003oooooooooo`1[
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0O_ooool001_ooooo0_l0001/oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0O_ooool001_ooooo00?o0000oooooooo
ool0K?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo07oooooo000Kooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1oooooo`006ooo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Oooo
ool001_ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo07oooooo000Kooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1oooooo`006oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0Ooooool001_ooooo0_l0001^ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0P?ooool001_ooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo083ooooo000Kooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`20ooooo`006oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0P?ooool001_ooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo083ooooo000Kooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`20ooooo`003Ooo
ool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`21ooooo`003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0POooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Cooooo0ol0001^ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0POooool000gooooo0ol00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo087ooooo000<ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`21ooooo`003?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0P_ooool000gooooo0ol00004oooo
o`;o00001Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0P_ooool001_ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo08;ooooo000Kooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`22ooooo`006oooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0P_ooool001_ooooo0_l0001aooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0Poooool001_ooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo08?ooooo000Kooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`23ooooo`006oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Poooool001_ooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08?ooooo000K
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`24
ooooo`006oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Q?ooool001_ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo08Cooooo000Kooooo`;o0000Loooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo08Gooooo000Kooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`25ooooo`006oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0QOooool001_ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo08Kooooo000Kooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`26ooooo`006oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Q_ooool001_ooooo00?o
0000ooooooooool0M?ooool01Ol0003ooooooooooooooooo000008Wooooo000Kooooo`03o`000?oo
oooooooo07Gooooo00?o0000ooooool00000R_ooool001_ooooo0_l0001gooooo`03o`000?oooooo
oooo08Wooooo000Kooooo`03o`000?oooooooooo0?oooooo0oooool001_ooooo00?o0000oooooooo
ool0ooooool3ooooo`006oooool00ol0003oooooooooo`3oooooo`?ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo001Qooooo`?o0000DOooool3o`0006Sooooo001Rooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool0Ioooool003Oooooo0ol00004ooooo`?o00000_oo
ool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00002Oooool3o`0000?ooooo
0ol00002ooooo`?o00001?ooool3o`0000?ooooo1?l00002ooooo`Co00001oooool5o`000005oooo
ool0003o0000o`000?ooool00_l00002ooooo`;o00000oooool3o`0000;ooooo0ol000000ooooooo
0000o`000004o`0000;ooooo1Ol00003ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`?o
00001Oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0ol00004oooo
o`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l00000;oooool003So
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`06o`000?oo
ooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooooooo
ooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000<?ooool003Sooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00cooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`Go00000_ooool3o`0000;ooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool3o`00
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
ooooo`000?oooooo00001_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02kooooo000hooooo`?o
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`?o00000oooool01?l0003o
ooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003ooooooooo
ool00006ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo02kooooo000hooooo`04o`000?ooooooooooo`0000;ooooo0ol00002oooo
o`?o00000oooool4o`0000;ooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo1?l00002oooo
o`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo0_l00004ooooo`?o00002_ooool01?l0
003oooooooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000?ooooo1?l00000
1?oooooo0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000Sooooo00?o
0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool3o`0000;ooooo
1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l0000aooooo`00>?ooool01?l0003ooooooooo
ool0000Dooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00007?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0@oooool003Oo
oooo1?l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool3o`0001_o
oooo0_l00008ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03_ooool5o`0001Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0looooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0270585, -7.7527, \
0.000182741, 0.637465}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["NIntegrate", "Input"],
  " is used again to check its area."
}], "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["NIntegrate[psf[y],{y,-.1,.1}]", "Input",
  CellLabel->"In[75]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[BoxData[
    \(InterpolatingFunction::"dmval" \(\(:\)\(\ \)\) 
      "Input value \!\({0.09840853600948425`}\) lies outside the range of \
data in the interpolating function. Extrapolation will be used."\)], "Message",\

  CellLabel->"From In[75]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[BoxData[
    \(InterpolatingFunction::"dmval" \(\(:\)\(\ \)\) 
      "Input value \!\({\(-0.09840853600948425`\)}\) lies outside the range \
of data in the interpolating function. Extrapolation will be used."\)], \
"Message",
  CellLabel->"From In[75]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[BoxData[
    \(InterpolatingFunction::"dmval" \(\(:\)\(\ \)\) 
      "Input value \!\({0.0906179845938664`}\) lies outside the range of data \
in the interpolating function. Extrapolation will be used."\)], "Message",
  CellLabel->"From In[75]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(InterpolatingFunction :: \"dmval\"\) will be \
suppressed during this calculation."\)], "Message",
  CellLabel->"From In[75]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[BoxData[
    \(NIntegrate::"ncvb" \(\(:\)\(\ \)\) 
      "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(y\) near \!\(y\) = \!\(-0.00859375`\)."\)], \
"Message",
  CellLabel->"From In[75]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[BoxData[
    \(0.9835645226274282`\)], "Output",
  CellLabel->"Out[75]=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell["\<\
Here is an symbolic intensity plot at a different plane near the focus.\
\>", "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
Plot[intensity[-1,y],{y,-.1,.1},PlotRange->All,PlotPoints->100];\
\>", "Input",
  CellLabel->"In[76]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.7619 0.0146369 0.0413309 [
[.02381 .00214 -12 -9 ]
[.02381 .00214 12 0 ]
[.2619 .00214 -15 -9 ]
[.2619 .00214 15 0 ]
[.7381 .00214 -12 -9 ]
[.7381 .00214 12 0 ]
[.97619 .00214 -9 -9 ]
[.97619 .00214 9 0 ]
[.4875 .0973 -6 -4.5 ]
[.4875 .0973 0 4.5 ]
[.4875 .17996 -6 -4.5 ]
[.4875 .17996 0 4.5 ]
[.4875 .26262 -6 -4.5 ]
[.4875 .26262 0 4.5 ]
[.4875 .34528 -6 -4.5 ]
[.4875 .34528 0 4.5 ]
[.4875 .42795 -12 -4.5 ]
[.4875 .42795 0 4.5 ]
[.4875 .51061 -12 -4.5 ]
[.4875 .51061 0 4.5 ]
[.4875 .59327 -12 -4.5 ]
[.4875 .59327 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01464 m
.02381 .02089 L
s
[(-0.1)] .02381 .00214 0 1 Mshowa
.2619 .01464 m
.2619 .02089 L
s
[(-0.05)] .2619 .00214 0 1 Mshowa
.7381 .01464 m
.7381 .02089 L
s
[(0.05)] .7381 .00214 0 1 Mshowa
.97619 .01464 m
.97619 .02089 L
s
[(0.1)] .97619 .00214 0 1 Mshowa
.125 Mabswid
.07143 .01464 m
.07143 .01839 L
s
.11905 .01464 m
.11905 .01839 L
s
.16667 .01464 m
.16667 .01839 L
s
.21429 .01464 m
.21429 .01839 L
s
.30952 .01464 m
.30952 .01839 L
s
.35714 .01464 m
.35714 .01839 L
s
.40476 .01464 m
.40476 .01839 L
s
.45238 .01464 m
.45238 .01839 L
s
.54762 .01464 m
.54762 .01839 L
s
.59524 .01464 m
.59524 .01839 L
s
.64286 .01464 m
.64286 .01839 L
s
.69048 .01464 m
.69048 .01839 L
s
.78571 .01464 m
.78571 .01839 L
s
.83333 .01464 m
.83333 .01839 L
s
.88095 .01464 m
.88095 .01839 L
s
.92857 .01464 m
.92857 .01839 L
s
.25 Mabswid
0 .01464 m
1 .01464 L
s
.5 .0973 m
.50625 .0973 L
s
[(2)] .4875 .0973 1 0 Mshowa
.5 .17996 m
.50625 .17996 L
s
[(4)] .4875 .17996 1 0 Mshowa
.5 .26262 m
.50625 .26262 L
s
[(6)] .4875 .26262 1 0 Mshowa
.5 .34528 m
.50625 .34528 L
s
[(8)] .4875 .34528 1 0 Mshowa
.5 .42795 m
.50625 .42795 L
s
[(10)] .4875 .42795 1 0 Mshowa
.5 .51061 m
.50625 .51061 L
s
[(12)] .4875 .51061 1 0 Mshowa
.5 .59327 m
.50625 .59327 L
s
[(14)] .4875 .59327 1 0 Mshowa
.125 Mabswid
.5 .0353 m
.50375 .0353 L
s
.5 .05597 m
.50375 .05597 L
s
.5 .07663 m
.50375 .07663 L
s
.5 .11796 m
.50375 .11796 L
s
.5 .13863 m
.50375 .13863 L
s
.5 .1593 m
.50375 .1593 L
s
.5 .20063 m
.50375 .20063 L
s
.5 .22129 m
.50375 .22129 L
s
.5 .24196 m
.50375 .24196 L
s
.5 .28329 m
.50375 .28329 L
s
.5 .30395 m
.50375 .30395 L
s
.5 .32462 m
.50375 .32462 L
s
.5 .36595 m
.50375 .36595 L
s
.5 .38662 m
.50375 .38662 L
s
.5 .40728 m
.50375 .40728 L
s
.5 .44861 m
.50375 .44861 L
s
.5 .46928 m
.50375 .46928 L
s
.5 .48994 m
.50375 .48994 L
s
.5 .53127 m
.50375 .53127 L
s
.5 .55194 m
.50375 .55194 L
s
.5 .5726 m
.50375 .5726 L
s
.5 .61394 m
.50375 .61394 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02837 .01473 L
.03318 .01475 L
.03846 .01477 L
.04339 .0148 L
.05262 .01486 L
.06207 .01495 L
.07212 .01508 L
.0818 .01526 L
.09111 .01549 L
.10102 .01582 L
.11056 .01624 L
.11973 .0168 L
.12949 .0176 L
.13889 .01864 L
.14889 .02014 L
.15851 .02214 L
.16777 .02478 L
.17763 .02863 L
.18711 .03383 L
.19719 .04159 L
.20691 .05211 L
.21625 .06621 L
.22619 .08696 L
.23576 .11421 L
.24497 .14898 L
.25477 .19669 L
.2642 .25373 L
.27423 .32569 L
.28389 .40214 L
.29318 .47599 L
.29788 .5108 L
.30307 .54502 L
.30803 .57178 L
.31021 .58121 L
.31259 .58975 L
.31487 .59608 L
.31612 .59872 L
.31728 .60065 L
.31793 .60152 L
.31856 .60219 L
.31911 .60265 L
.31943 .60286 L
.31972 .60302 L
.32003 .60316 L
.3202 .60321 L
.32038 .60326 L
.32057 .60329 L
.32075 .60331 L
.3209 .60332 L
Mistroke
.32108 .60331 L
.32139 .60328 L
.32157 .60324 L
.32173 .60319 L
.32204 .60307 L
.32233 .60292 L
.32292 .60252 L
.32346 .60202 L
.3247 .60042 L
.32591 .59825 L
.32721 .59525 L
.32955 .58807 L
.33169 .57959 L
.33633 .55527 L
.34136 .52112 L
.35126 .44164 L
.35618 .40256 L
.36079 .36989 L
.36521 .34431 L
.36767 .33305 L
.36996 .32475 L
.37228 .31856 L
.37351 .31623 L
.3742 .31522 L
.37483 .31446 L
.37549 .31384 L
.37584 .31359 L
.37621 .31339 L
.37636 .31332 L
.37653 .31325 L
.37683 .31317 L
.37701 .31313 L
.37718 .31311 L
.37734 .3131 L
.37751 .31311 L
.3778 .31314 L
.37797 .31317 L
.37812 .31322 L
.37843 .31333 L
.37877 .3135 L
.37938 .31391 L
.37994 .31442 L
.38109 .31581 L
.38232 .31782 L
.38453 .32266 L
.38954 .33812 L
.39436 .35583 L
.3969 .36495 L
.39959 .37364 L
.40199 .38009 L
Mistroke
.40326 .3829 L
.40463 .38539 L
.40588 .38716 L
.40703 .38834 L
.40758 .38876 L
.40787 .38894 L
.40818 .3891 L
.40848 .38923 L
.40875 .38932 L
.40902 .38938 L
.40928 .38942 L
.40956 .38945 L
.40986 .38944 L
.41015 .38941 L
.41041 .38936 L
.41071 .38927 L
.41104 .38914 L
.41165 .38882 L
.41228 .38837 L
.41295 .38777 L
.41415 .38638 L
.41628 .38301 L
.41863 .37814 L
.42838 .35136 L
.43286 .33941 L
.4354 .33371 L
.43776 .32938 L
.44011 .32612 L
.44143 .32479 L
.44263 .32389 L
.44328 .32352 L
.44389 .32327 L
.44421 .32316 L
.44455 .32307 L
.44473 .32303 L
.44492 .323 L
.4451 .32298 L
.44526 .32296 L
.44557 .32295 L
.44587 .32295 L
.44604 .32296 L
.44619 .32297 L
.44637 .32299 L
.44653 .32302 L
.44684 .32308 L
.44711 .32315 L
.44774 .32336 L
.44834 .32363 L
.44889 .32393 L
.45011 .32478 L
Mistroke
.45232 .3269 L
.45733 .33373 L
.46236 .34167 L
.46457 .3449 L
.46701 .34791 L
.46813 .34904 L
.46934 .35005 L
.46993 .35045 L
.47048 .35077 L
.47103 .35103 L
.47153 .35122 L
.4718 .35131 L
.4721 .35139 L
.47242 .35145 L
.47271 .35149 L
.47299 .35151 L
.47329 .35152 L
.47354 .35151 L
.47382 .35149 L
.47399 .35147 L
.47414 .35144 L
.47444 .35138 L
.47476 .35129 L
.47511 .35118 L
.47574 .35091 L
.47632 .35059 L
.47744 .34979 L
.47865 .34868 L
.48084 .34605 L
.48583 .33807 L
.4906 .32997 L
.49311 .32639 L
.4945 .32479 L
.4958 .32356 L
.49705 .32268 L
.49776 .32231 L
.4981 .32217 L
.49841 .32206 L
.4987 .32197 L
.49896 .32191 L
.49925 .32186 L
.49956 .32182 L
.49986 .3218 L
.50003 .3218 L
.50019 .3218 L
.50047 .32182 L
.50078 .32186 L
.50109 .32192 L
.50138 .32199 L
.50203 .32222 L
Mistroke
.5026 .32249 L
.50321 .32284 L
.50426 .32361 L
.50541 .32469 L
.50789 .32772 L
.51014 .33115 L
.51522 .33989 L
.51747 .34358 L
.51985 .34696 L
.5211 .34841 L
.52247 .34972 L
.52307 .35018 L
.52372 .35061 L
.52433 .35094 L
.52489 .35118 L
.52547 .35136 L
.52579 .35143 L
.52609 .35148 L
.52637 .3515 L
.52663 .35152 L
.52691 .35152 L
.52721 .3515 L
.52751 .35146 L
.52768 .35143 L
.52784 .3514 L
.52842 .35124 L
.52875 .35112 L
.5291 .35097 L
.52975 .35064 L
.53104 .34976 L
.53241 .34852 L
.53487 .34564 L
.54401 .3317 L
.54629 .32856 L
.54869 .32584 L
.54995 .32473 L
.55062 .32424 L
.55133 .3238 L
.55198 .32347 L
.55258 .32324 L
.55287 .32315 L
.55318 .32307 L
.55347 .32302 L
.55375 .32298 L
.55405 .32295 L
.55434 .32294 L
.55459 .32295 L
.55488 .32297 L
.55518 .32302 L
.55535 .32305 L
Mistroke
.55551 .32308 L
.55609 .32326 L
.55663 .32348 L
.55722 .3238 L
.55829 .32455 L
.55955 .32575 L
.56089 .32738 L
.56329 .33118 L
.56805 .34167 L
.57249 .35386 L
.57701 .36688 L
.58193 .37939 L
.58323 .38207 L
.5846 .38454 L
.58588 .38642 L
.58708 .3878 L
.58762 .38829 L
.58819 .38872 L
.58849 .38891 L
.58882 .38908 L
.58912 .38921 L
.5894 .3893 L
.58956 .38935 L
.58973 .38939 L
.59004 .38943 L
.59021 .38944 L
.5904 .38945 L
.59055 .38944 L
.59072 .38942 L
.59103 .38937 L
.5912 .38933 L
.59136 .38928 L
.59196 .38903 L
.59227 .38886 L
.59257 .38866 L
.59312 .38822 L
.59435 .38687 L
.59542 .38531 L
.59657 .38323 L
.59919 .37709 L
.6016 .36995 L
.60656 .35241 L
.61119 .33559 L
.61347 .3282 L
.61564 .32225 L
.61683 .3195 L
.61813 .31702 L
.61931 .31527 L
.62041 .31409 L
.62099 .31364 L
Mistroke
.62127 .31347 L
.62153 .31334 L
.62183 .31323 L
.62199 .31319 L
.62215 .31315 L
.62246 .31311 L
.62275 .31311 L
.62303 .31314 L
.62329 .31319 L
.62357 .31329 L
.62388 .31343 L
.62438 .31374 L
.62494 .31422 L
.62559 .31494 L
.62619 .31576 L
.62752 .31816 L
.62876 .32106 L
.62994 .32442 L
.63228 .33282 L
.63476 .34414 L
.63922 .37001 L
.64837 .43863 L
.65811 .51718 L
.66259 .54849 L
.66512 .56369 L
.66748 .57583 L
.67003 .58654 L
.67234 .59404 L
.67361 .59722 L
.67481 .59962 L
.67608 .6015 L
.67679 .60227 L
.67713 .60256 L
.67745 .60279 L
.67773 .60296 L
.67804 .60311 L
.67832 .60321 L
.67858 .60327 L
.67889 .60331 L
.67917 .60332 L
.67933 .60331 L
.67949 .60328 L
.6798 .60321 L
.68006 .60312 L
.68035 .60298 L
.68094 .60261 L
.68149 .60214 L
.682 .6016 L
.68326 .59983 L
.68441 .59767 L
Mistroke
.687 .59104 L
.6894 .58274 L
.69163 .57335 L
.69666 .54665 L
.70619 .48082 L
.71535 .40831 L
.7251 .33085 L
.73449 .26254 L
.74447 .20091 L
.75408 .15312 L
.76332 .11725 L
.77316 .08855 L
.78264 .06821 L
.7927 .05261 L
.8024 .04196 L
.81173 .03459 L
.82166 .02896 L
.83122 .02512 L
.84041 .02241 L
.8502 .0203 L
.85961 .01883 L
.86963 .01768 L
.87927 .01687 L
.88855 .01629 L
.89842 .01584 L
.90793 .01551 L
.91803 .01526 L
.92776 .01508 L
.93713 .01496 L
.94709 .01486 L
.95668 .0148 L
.9659 .01475 L
.97572 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[76]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`002oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00033ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o0000J_ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol0000`ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`?o00001oooool000[ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0^oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo06Kooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool0;?ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Kooooo0003ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo02Oooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01_ooool000[ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`0^ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`1Vooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_oo
ool000[ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0^ooooo`04o`000?oo
ooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0006Wooooo00Co0000oooooooo
oooo00002?ooool01Ol0003oooooooooool0003ooooo00Co0000;oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Kooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo0_l0
000`ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0001/oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0000booooo`04o`00
0?ooooooooooo`0000Sooooo0_l00008ooooo`002oooool2o`0000[ooooo00?o0000ooooooooool0
;oooool2o`0000[ooooo0_l00002ooooo`Go0000JOooool2o`0000[ooooo0_l00002ooooo`Go0000
;oooool2o`0000[ooooo00?o0000ooooooooool01_ooool0097ooooo00?o0000ooooooooool0S?oo
ool0097ooooo00?o0000ooooooooool0S?ooool0097ooooo00?o0000ooooooooool0S?ooool0097o
oooo00?o0000ooooooooool0S?ooool000Soooooool0000Co`0000Kooooo000?ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool:o`0000?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo1ol0000<ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool000oooooo00?o0000ooooooooool08Oooool3
o`0001[ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo01Sooooo1_l0000Pooooo`03o`000?oooooooooo00_ooooo000fooooo`?o0000F?ooool00ol0
003oooooooooo`1Fooooo`;o0000=?ooool003Wooooo0_l0001Fooooo`03o`000?oooooooooo05?o
oooo0ol0000fooooo`00>oooool2o`0005Cooooo00?o0000ooooooooool0DOooool2o`0003Wooooo
000mooooo`03o`000?oooooooooo057ooooo0_l0001Aooooo`03o`000?oooooooooo03Wooooo000n
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0j
ooooo`00?oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool0>oooool0043ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo03cooooo0011ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`0mooooo`00@Oooool00ol0003oooooooooo`1=ooooo`;o0000COoo
ool00ol0003oooooooooo`0mooooo`00@_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool0?_ooool004;ooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo03kooooo0013ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0nooooo`00@oooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0?oooool004Cooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03oooooo0014
ooooo`03o`000?oooooooooo04[ooooo0_l0001:ooooo`03o`000?oooooooooo043ooooo0015oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`11oooo
o`00AOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0@Oooool004Kooooo00?o0000ooooooooool0?_ooool5o`0000Gooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`12ooooo`00A_ooool00ol0003oooooooooo`0oooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`12ooooo`00A_oo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`13ooooo`00Aoooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00Cooooo0_l00017ooooo`03o`000?oooooooooo04?ooooo0017ooooo`03o`000?oooooooooo
03gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0@oooool004Oooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`14ooooo`00B?ooool00ol0
003oooooooooo`0mooooo`?o00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
04Cooooo0018ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`14ooooo`00B?ooool00ol0003oooooooooo`16ooooo`;o0000AOooool00ol0003ooooo
ooooo`15ooooo`00B?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0AOooool004Wooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo04Gooooo0019ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`16ooooo`00BOooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0A_ooool004[ooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo04Kooooo001:ooooo`03o`000?oo
oooooooo04Cooooo0_l00014ooooo`03o`000?oooooooooo04Kooooo001:ooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`16ooooo`00Boooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0Aoooool004_o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04Oo
oooo001;ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`17ooooo`00Boooool00ol0003oooooooooo`13ooooo`;o0000@oooool00ol0003ooooooooo
o`17ooooo`00C?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0Aoooool004cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo04Sooooo001<ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`18ooooo`00C?ooool00ol0003oooooooooo`0jooooo`?o0000
1Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04Sooooo001=ooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo04Sooooo001=ooooo`03o`000?oooooooooo03Oooooo1Ol00005ooooo`;o0000@Oooool0
0ol0003oooooooooo`19ooooo`00COooool00ol0003oooooooooo`0gooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`19ooooo`00COooool00ol0
003oooooooooo`0hooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`19ooooo`00COooool00ol0003oooooooooo`0iooooo`;o00001_ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo04Wooooo001>ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04Wooooo
001>ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`1:ooooo`00C_ooool00ol0003oooooooooo`10ooooo`;o0000@?ooool00ol0003oooooooooo`1:
ooooo`00C_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0B_ooool004kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo04[ooooo001>ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`1:ooooo`00Coooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0Boooool004oooooo00?o0000ooooooooool0?oooool2
o`0003oooooo00?o0000ooooooooool0Boooool004oooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo04_ooooo001?ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1;ooooo`00Coooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Boooool004oooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo04cooooo001?
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1<
ooooo`00D?ooool00ol0003oooooooooo`0nooooo`;o0000?_ooool00ol0003oooooooooo`1<oooo
o`00D?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool0C?ooool0053ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo04cooooo001@ooooo`03o`000?oooooooooo03Gooooo0ol00006ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool0C?ooool0053ooooo00?o0000ooooooooool0=?ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`1=ooooo`00D?ooool00ol0003oooooooooo`0dooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo04gooooo001@ooooo`03o`000?oooooo
oooo03Cooooo1?l00006ooooo`;o0000?Oooool00ol0003oooooooooo`1=ooooo`00DOooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`1=ooooo`00DOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1=ooooo`00DOooool00ol0003ooooo
ooooo`0eooooo`;o00001_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo04gooooo
001Aooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`1=ooooo`00DOooool00ol0003oooooooooo`0mooooo`;o0000??ooool00ol0003oooooooooo`1>
ooooo`00DOooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0C_ooool0057ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo04kooooo001Booooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`1>ooooo`00D_ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0C_ooool005;ooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo04kooooo001Booooo`03o`000?oooooooooo
03cooooo0_l0000looooo`03o`000?oooooooooo04kooooo001Booooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1>ooooo`00D_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool2o`0001cooooo
00?o0000ooooooooool0C_ooool005;ooooo00?o0000ooooooooool06Oooool3o`00023ooooo00?o
0000ooooooooool07Oooool3o`0001[ooooo00?o0000ooooooooool0Coooool005?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo01cooooo00Co0000
oooooooooooo00006_ooool00ol0003oooooooooo`1?ooooo`00Doooool00ol0003oooooooooo`0H
ooooo`04o`000?ooooooooooo`0000oooooo0ol0000;ooooo`Co00002oooool3o`0000oooooo00Go
0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo04oooooo001Cooooo`03o`000?oo
oooooooo01Oooooo00Go0000ooooooooooooooooo`00000>ooooo`;o000000?oooooo`000?l00000
2_ooool00ol0003oooooo`000002o`0000[ooooo00Co0000oooooooooooo00003Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Coooool005?ooooo
00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo000000kooooo00Go0000oooooooo
ooooooooo`000009ooooo`06o`000?ooooooooooo`000?oooooo00002Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04oooooo001Cooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01_ooool01_l0003oooooooooool0003oooooo`0000Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`1?ooooo`00Doooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04oooooo001Dooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo0_l00003ooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`1?ooooo`00E?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`06ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo053ooooo001Dooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo1?l00005ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000oooo
o`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo053ooooo001Dooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo1Ol00005
ooooo`03o`000?oooooooooo00?ooooo0ol0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo053ooooo001Doooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0D?ooool005Cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool3o`00
00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1@ooooo`00E?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0D?ooool005Gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool04oooool2o`0001?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0D?ooool005Gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo057ooooo001E
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1A
ooooo`00EOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0DOooool005Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`05
o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`0Cooooo`05o`000?oooooooooo
ooooool000002_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo057ooooo001Eoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000G
ooooo`;o00005Oooool01?l0003oooooo`000?l0000;ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0DOooool005Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:
ooooo`?o00005oooool00ol0003oooooooooo`0Dooooo`?o00003?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo057ooooo001Fooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0DOooool005Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Booooo`00
E_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05;ooooo001Fooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0D_ooool005Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Uooooo`;o00009Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo05;ooooo001Fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D_ooool005Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Booooo`00E_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Kooooo0ol00004ooooo`;o00001_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D_ooool005Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0D_ooool005Oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D_ooool005Oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001Oooool2o`0002Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1Cooooo`00Eoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Cooooo`00Eoooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01Oooooo0_l00004ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo
001Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`03ooooo`;o00001_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0Doooool005Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1C
ooooo`00Eoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Kooooo0_l0000Voooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Doooool005Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Cooooo`00Eoooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo05?ooooo001Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Dooo
ool005Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Cooooo`00F?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001Hooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool09oooool2o`0002Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1Dooooo`00F?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo
001Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0E?ooool005Sooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Dooooo`00F?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo05Cooooo001Hooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0E?ooool005Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`;o0000
:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Cooooo001Iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0EOooool005Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Eooooo`00FOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Wooooo0ol00002ooooo`Go00001Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0EOooool005Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0EOooool005Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool2o`0002Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Eooooo`00FOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`00FOooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo05Kooooo001Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_oo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`00F_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Kooooo001J
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E_ooool005[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Yooooo`;o0000:Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05Kooooo001Jooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0E_ooool005_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`00Fooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo001Kooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Eoooool005_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Zooooo`;o0000:_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
05Oooooo001Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool005_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`00G?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo05Sooooo001Looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0F?ooool005cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Hoooo
o`00G?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02_ooooo0_l0000[ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0F?ooool005cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Hooooo`00GOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05Wooooo001Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool3
o`0000Cooooo0ol00005ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Iooooo`00GOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Iooooo`00GOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooooooo1Ol00005oooo
o`03o`000?oooooooooo02_ooooo00Go0000ooooooooooooooooo`00001Looooo`00GOooool01Ol0
003ooooooooooooooooo0000027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Cooooo0_l0000/ooooo`05o`000?ooooooooooooooool00000G?ooool005kooooo00Co
0000oooooooooooo00008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooooooool0;?ooool01?l0003oooooooooool0001Looooo`00Goooool3o`00023ooooo
0_l00005ooooo`;o00001_ooool00ol0003oooooooooo`0]ooooo`;o0000GOooool008?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08cooooo002A
ooooo`03o`000?oooooooooo08cooooo002Aooooo`;o0000SOooool0097ooooo00?o0000oooooooo
ool0S?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.111673, -1.10103, \
0.000770157, 0.088733}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell["\<\
Again, the numeric point spread function is consistent in form. Note that the \
numeric PSF shows eveidence of high frequency ringing that is absent from the \
symbolic solution. This is due the hard edge of the pupil function in the \
numeric PSF.\
\>", "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
psf = PointSpreadFunction/.PSF[{
\tMove[LineOfRays[10],-50],
\tPlanoConvexLens[100,50,10],
\tMove[Screen[50],102]},NumberOfPoints->512,PaddingFactor->10];\
\>", "Input",
  CellLabel->"In[77]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952031 0.603319 0.215971 [
[.11919 -0.0125 -6 -9 ]
[.11919 -0.0125 6 0 ]
[.30959 -0.0125 -6 -9 ]
[.30959 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69041 -0.0125 -3 -9 ]
[.69041 -0.0125 3 0 ]
[.88081 -0.0125 -3 -9 ]
[.88081 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06339 -24 -4.5 ]
[-0.0125 .06339 0 4.5 ]
[-0.0125 .17138 -12 -4.5 ]
[-0.0125 .17138 0 4.5 ]
[-0.0125 .27936 -24 -4.5 ]
[-0.0125 .27936 0 4.5 ]
[-0.0125 .38735 -12 -4.5 ]
[-0.0125 .38735 0 4.5 ]
[-0.0125 .49533 -24 -4.5 ]
[-0.0125 .49533 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11919 0 m
.11919 .00625 L
s
[(-4)] .11919 -0.0125 0 1 Mshowa
.30959 0 m
.30959 .00625 L
s
[(-2)] .30959 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69041 0 m
.69041 .00625 L
s
[(2)] .69041 -0.0125 0 1 Mshowa
.88081 0 m
.88081 .00625 L
s
[(4)] .88081 -0.0125 0 1 Mshowa
.125 Mabswid
.16679 0 m
.16679 .00375 L
s
.21439 0 m
.21439 .00375 L
s
.26199 0 m
.26199 .00375 L
s
.3572 0 m
.3572 .00375 L
s
.4048 0 m
.4048 .00375 L
s
.4524 0 m
.4524 .00375 L
s
.5476 0 m
.5476 .00375 L
s
.5952 0 m
.5952 .00375 L
s
.6428 0 m
.6428 .00375 L
s
.73801 0 m
.73801 .00375 L
s
.78561 0 m
.78561 .00375 L
s
.83321 0 m
.83321 .00375 L
s
.07159 0 m
.07159 .00375 L
s
.02398 0 m
.02398 .00375 L
s
.92841 0 m
.92841 .00375 L
s
.97602 0 m
.97602 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06339 m
.00625 .06339 L
s
[(-2.5)] -0.0125 .06339 1 0 Mshowa
0 .17138 m
.00625 .17138 L
s
[(-2)] -0.0125 .17138 1 0 Mshowa
0 .27936 m
.00625 .27936 L
s
[(-1.5)] -0.0125 .27936 1 0 Mshowa
0 .38735 m
.00625 .38735 L
s
[(-1)] -0.0125 .38735 1 0 Mshowa
0 .49533 m
.00625 .49533 L
s
[(-0.5)] -0.0125 .49533 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .08499 m
.00375 .08499 L
s
0 .10659 m
.00375 .10659 L
s
0 .12818 m
.00375 .12818 L
s
0 .14978 m
.00375 .14978 L
s
0 .19297 m
.00375 .19297 L
s
0 .21457 m
.00375 .21457 L
s
0 .23617 m
.00375 .23617 L
s
0 .25777 m
.00375 .25777 L
s
0 .30096 m
.00375 .30096 L
s
0 .32256 m
.00375 .32256 L
s
0 .34415 m
.00375 .34415 L
s
0 .36575 m
.00375 .36575 L
s
0 .40894 m
.00375 .40894 L
s
0 .43054 m
.00375 .43054 L
s
0 .45214 m
.00375 .45214 L
s
0 .47374 m
.00375 .47374 L
s
0 .51693 m
.00375 .51693 L
s
0 .53853 m
.00375 .53853 L
s
0 .56012 m
.00375 .56012 L
s
0 .58172 m
.00375 .58172 L
s
0 .04179 m
.00375 .04179 L
s
0 .0202 m
.00375 .0202 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11919 .61178 m
.11919 .61803 L
s
.30959 .61178 m
.30959 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69041 .61178 m
.69041 .61803 L
s
.88081 .61178 m
.88081 .61803 L
s
.125 Mabswid
.16679 .61428 m
.16679 .61803 L
s
.21439 .61428 m
.21439 .61803 L
s
.26199 .61428 m
.26199 .61803 L
s
.3572 .61428 m
.3572 .61803 L
s
.4048 .61428 m
.4048 .61803 L
s
.4524 .61428 m
.4524 .61803 L
s
.5476 .61428 m
.5476 .61803 L
s
.5952 .61428 m
.5952 .61803 L
s
.6428 .61428 m
.6428 .61803 L
s
.73801 .61428 m
.73801 .61803 L
s
.78561 .61428 m
.78561 .61803 L
s
.83321 .61428 m
.83321 .61803 L
s
.07159 .61428 m
.07159 .61803 L
s
.02398 .61428 m
.02398 .61803 L
s
.92841 .61428 m
.92841 .61803 L
s
.97602 .61428 m
.97602 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06339 m
1 .06339 L
s
.99375 .17138 m
1 .17138 L
s
.99375 .27936 m
1 .27936 L
s
.99375 .38735 m
1 .38735 L
s
.99375 .49533 m
1 .49533 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .08499 m
1 .08499 L
s
.99625 .10659 m
1 .10659 L
s
.99625 .12818 m
1 .12818 L
s
.99625 .14978 m
1 .14978 L
s
.99625 .19297 m
1 .19297 L
s
.99625 .21457 m
1 .21457 L
s
.99625 .23617 m
1 .23617 L
s
.99625 .25777 m
1 .25777 L
s
.99625 .30096 m
1 .30096 L
s
.99625 .32256 m
1 .32256 L
s
.99625 .34415 m
1 .34415 L
s
.99625 .36575 m
1 .36575 L
s
.99625 .40894 m
1 .40894 L
s
.99625 .43054 m
1 .43054 L
s
.99625 .45214 m
1 .45214 L
s
.99625 .47374 m
1 .47374 L
s
.99625 .51693 m
1 .51693 L
s
.99625 .53853 m
1 .53853 L
s
.99625 .56012 m
1 .56012 L
s
.99625 .58172 m
1 .58172 L
s
.99625 .04179 m
1 .04179 L
s
.99625 .0202 m
1 .0202 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .01472 Mdot
.05455 .08089 Mdot
.08529 .14457 Mdot
.11603 .20536 Mdot
.14676 .26288 Mdot
.17748 .31679 Mdot
.20821 .36678 Mdot
.23893 .41258 Mdot
.26965 .45392 Mdot
.30037 .49059 Mdot
.33108 .52238 Mdot
.3618 .54912 Mdot
.39251 .57069 Mdot
.42322 .58696 Mdot
.45393 .59786 Mdot
.48464 .60332 Mdot
.51536 .60332 Mdot
.54607 .59786 Mdot
.57678 .58696 Mdot
.60749 .57069 Mdot
.6382 .54912 Mdot
.66892 .52238 Mdot
.69963 .49059 Mdot
.73035 .45392 Mdot
.76107 .41258 Mdot
.79179 .36678 Mdot
.82252 .31679 Mdot
.85324 .26288 Mdot
.88397 .20536 Mdot
.91471 .14457 Mdot
.94545 .08089 Mdot
.97619 .01472 Mdot
.5 Mabswid
.02381 .01472 m
.03853 .0464 L
.05458 .08095 L
.06965 .11218 L
.08415 .14221 L
.09958 .17284 L
.11444 .20222 L
.13023 .23194 L
.14544 .26041 L
.16007 .28624 L
.17564 .31355 L
.19063 .33818 L
.20504 .36164 L
.22039 .38494 L
.23516 .40696 L
.25087 .42864 L
.26599 .449 L
.28054 .46692 L
.29603 .48541 L
.31093 .50152 L
.32678 .51792 L
.34204 .53192 L
.35672 .54471 L
.37234 .55653 L
.38739 .56709 L
.40185 .57564 L
.41725 .5838 L
.43208 .5901 L
.43962 .59278 L
.44783 .59569 L
.45165 .59705 L
.45266 .59741 L
.45319 .59759 L
.45348 .5977 L
.45375 .59779 L
.45424 .59791 L
.45478 .59801 L
.45572 .59817 L
.45918 .59879 L
.46301 .59947 L
.47789 .60212 L
.48179 .60281 L
.48286 .603 L
.48344 .6031 L
.48399 .6032 L
.48445 .60328 L
.48495 .60332 L
.48524 .60332 L
.48551 .60332 L
.48602 .60332 L
Mistroke
.49369 .60332 L
.50134 .60332 L
.50826 .60332 L
.51012 .60332 L
.51213 .60332 L
.51306 .60332 L
.51403 .60332 L
.51486 .60332 L
.51533 .60332 L
.51577 .60324 L
.52377 .60182 L
.53861 .59918 L
.5425 .59849 L
.54454 .59813 L
.54508 .59803 L
.54566 .59793 L
.54593 .59788 L
.54621 .59781 L
.54672 .59763 L
.54861 .59695 L
.5507 .59621 L
.55439 .59491 L
.56892 .58975 L
.5844 .58293 L
.59929 .57504 L
.61512 .56533 L
.63037 .55462 L
.64504 .54317 L
.66065 .52957 L
.67568 .51537 L
.69013 .50042 L
.70552 .48356 L
.72033 .46588 L
.73608 .44621 L
.75124 .4258 L
.76583 .40548 L
.78136 .38234 L
.7963 .35944 L
.81067 .33606 L
.82597 .31072 L
.8407 .28488 L
.85636 .25704 L
.87144 .22881 L
.88595 .20146 L
.90139 .17092 L
.91625 .14138 L
.93205 .10866 L
.94727 .07698 L
.96191 .04546 L
.97619 .01472 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00@?ooool3o`0002[ooooo1Ol0000Yooooo`;o0000;?ooool5o`0002cooooo0ol0000Soooo
o`00@Oooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`0002Sooooo00Co0000oooo
oooooooo0000;?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02;ooooo000h
ooooo`Go000000?oooooo`000?l000000ol0000Tooooo`Go00000oooool00ol0003oooooooooo`0X
ooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0:_ooool5o`0002?ooooo000n
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool09oooool01?l0003ooooooooo
ool0000^ooooo`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo00009?ooool003oooooo
00?o0000ooooool00000:oooool01Ol0003ooooooooooooooooo000002Sooooo00Co0000oooooooo
oooo0000:oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooool000009?ooool0
043ooooo0_l0000[ooooo`05o`000?ooooooooooooooool00000:?ooool01?l0003oooooooooool0
000[ooooo`05o`000?ooooooooooooooool00000;?ooool2o`0002Cooooo0011ooooo`03o`000?oo
oooooooo02[ooooo0ol0000Zooooo`;o0000;Oooool3o`0002kooooo00?o0000ooooooooool08_oo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0027ooooon?l0
0007ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`02ooooo`;o0000M?ooool00ol0003oooooooooo`1booooo`;o
00001Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`02ooooo`;o0000
M?ooool00ol0003oooooooooo`1booooo`;o00001Oooool00ol0003oooooooooo`05ooooo`008Ooo
ool2o`0000Gooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo00?ooooo0_l00007ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00001_ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01?ooool2o`0000Oooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`003?ooool5o`0000?ooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`00
3Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0Koooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0006ooooo`Go00000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`;o00001oooool000oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01Oooool000cooooo00Go0000ooooooooooooooooo`000007ooooo`Co0000
1Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000<ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01Oooool000gooooo0ol00008ooooo`Go00001?ooool00ol0003ooooooooo
o`09ooooo`?o0000K?ooool00ol0003oooooooooo`1[ooooo`;o00003?ooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`0:ooooo`;o0000K?ooool00ol0003oooooooooo`1[
ooooo`;o00003?ooool00ol0003oooooooooo`05ooooo`008Oooool2o`0000_ooooo00?o0000oooo
ooooool0Joooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00[ooooo0_l00007oooo
o`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`;o00003_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool03?ooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`05ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000Aoooo
o`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0?oooo
o`;o00001oooool0027ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo06Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`00
8Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool04Oooool2
o`0006Gooooo00?o0000ooooooooool0Hoooool2o`0001Cooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool04Oooool2o`0006Gooooo00?o0000ooooooooool0Hoooool2o`00
01Cooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000Dooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Booooo`;o00001oooool0027ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Gooooo000Hooooo`Go00001?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Gooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`05ooooo`004_ooool5o`0000?ooooo00?o0000oooo
ooooool01?ooool2o`0001Oooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo01Cooooo0_l00007ooooo`006oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool001Sooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool001Sooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01Oooool001Wooooo0ol00005ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1Oooool0027ooooo0_l0000Iooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0Gooooo`;o00001oooool0027ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo01Wooooo0_l0001Mooooo`03o`000?oooooooooo05co
oooo0_l0000Kooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01Wooooo
0_l0001Mooooo`03o`000?oooooooooo05cooooo0_l0000Kooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool0027ooooo0_l0000K
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0J
ooooo`;o00001oooool0027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Joooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`05ooooo`008Oooool2o`0001kooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01gooooo0_l00007ooooo`008Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`05ooooo`008Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool0Eoooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo000Q
ooooo`;o00008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool07oooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo023ooooo0_l0001Foooo
o`03o`000?oooooooooo05Cooooo0ol0000Rooooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo023ooooo0_l0001Fooooo`03o`000?oooooooooo05Cooooo0_l0000Sooooo`03
o`000?oooooooooo00Gooooo000=ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
EOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool01Oooool000Kooooo1Ol00003ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05;ooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo000>
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool2o`0002Cooooo00?o0000
ooooooooool0D_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02;ooooo0_l00007
ooooo`003_ooool00ol0003oooooooooo`07ooooo`Co00001Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Gooooo000=ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool0
1oooool5o`0000Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o00009oooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool2
o`0000Oooooo000Qooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool0027o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo02Sooooo0_l0
001>ooooo`03o`000?oooooooooo04gooooo0_l0000Zooooo`03o`000?oooooooooo00Gooooo000Q
ooooo`;o0000:Oooool2o`0004kooooo00?o0000ooooooooool0COooool2o`0002Wooooo0_l00007
ooooo`008Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1;ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool01Oooool0
027ooooo0_l0000^ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`0/ooooo`;o00001oooool0027ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo
000Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`05ooooo`008Oooool2o`00037ooooo0_l00016oooo
o`03o`000?oooooooooo04Gooooo0_l0000aooooo`;o00001oooool0027ooooo00?o0000oooooooo
ool0<?ooool2o`0004Kooooo00?o0000ooooooooool0AOooool2o`0003;ooooo00?o0000oooooooo
ool01Oooool0027ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`05ooooo`006Ooo
ool3o`0000Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`05ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool0
01;ooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo0_l0000dooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0booooo`;o00001oooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Go
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`05ooooo`006Oooool2o`0000Kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`05ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool01Oooool0027ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`05oooo
o`008Oooool2o`0003Sooooo0_l0000oooooo`03o`000?oooooooooo03gooooo0ol0000hooooo`;o
00001oooool0027ooooo00?o0000ooooooooool0=oooool2o`0003oooooo00?o0000ooooooooool0
?Oooool2o`0003[ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00Gooooo000Qooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01Oooool0027o
oooo0_l0000looooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0iooooo`;o00001oooool0027ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`05ooooo`008Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Gooooo000Q
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`05ooooo`008Oooool2o`00043ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03gooooo0_l00007ooooo`00
8Oooool00ol0003oooooooooo`0oooooo`;o0000=oooool00ol0003oooooooooo`0fooooo`;o0000
@Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0oooooo`;o0000=ooo
ool00ol0003oooooooooo`0fooooo`;o0000@Oooool00ol0003oooooooooo`05ooooo`008Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`05ooooo`008Oooool2o`0004Cooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo04?ooooo0_l00007ooooo`008Oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool01Oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0A_ooool2
o`00033ooooo00?o0000ooooooooool0;_ooool2o`0004Wooooo00?o0000ooooooooool01Oooool0
00Kooooo1Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2
o`0004Oooooo0ol0000_ooooo`03o`000?oooooooooo02gooooo0ol00018ooooo`;o00001oooool0
00gooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool01Oooool000gooooo00Co0000oooooooooooo00001oooool4
o`0000Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`05ooooo`003Oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`05ooooo`003_ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool01Oooool0027ooooo0_l0001>ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1<ooooo`;o00001oooool0027ooooo
00?o0000ooooooooool0C_ooool2o`0002Sooooo00?o0000ooooooooool09oooool2o`00053ooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0C_ooool2o`0002Sooooo00?o
0000ooooooooool09oooool2o`00053ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1Aoooo
o`;o00009Oooool00ol0003oooooooooo`0Tooooo`;o0000Doooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Gooooo000Qooooo`;o0000
EOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
Doooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo05Gooooo0_l0000Qooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`05ooooo`008Oooool0
0ol0003oooooooooo`1Fooooo`;o00008?ooool00ol0003oooooooooo`0Oooooo`;o0000F?ooool0
0ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1Fooooo`?o00007oooool00ol0
003oooooooooo`0Oooooo`;o0000F?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003o
ooooooooo`1Iooooo`;o00007Oooool00ol0003oooooooooo`0Mooooo`;o0000F_ooool00ol0003o
ooooooooo`05ooooo`008Oooool2o`0005cooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Kooooo`;o0000Foooool2o`0000Oooooo000Qooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`;o0000G_ooool00ol0003ooooooooo
o`05ooooo`008Oooool00ol0003oooooooooo`1Mooooo`;o00006Oooool00ol0003oooooooooo`0G
ooooo`;o0000H?ooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`1Moooo
o`?o00006?ooool00ol0003oooooooooo`0Gooooo`;o0000H?ooool00ol0003oooooooooo`05oooo
o`008Oooool00ol0003oooooooooo`1Pooooo`;o00005_ooool00ol0003oooooooooo`0Eooooo`;o
0000H_ooool00ol0003oooooooooo`05ooooo`008Oooool2o`0006?ooooo0_l0000Dooooo`03o`00
0?oooooooooo01?ooooo0_l0001Sooooo`;o00001oooool0027ooooo00?o0000ooooooooool0I?oo
ool3o`00017ooooo00?o0000ooooooooool04?ooool3o`0006Kooooo00?o0000ooooooooool01Ooo
ool0027ooooo00?o0000ooooooooool0IOooool3o`00013ooooo00?o0000ooooooooool03_ooool4
o`0006Oooooo00?o0000ooooooooool01Oooool001[ooooo0_l00005ooooo`03o`000?oooooooooo
06Sooooo1?l0000<ooooo`03o`000?oooooooooo00cooooo0_l0001[ooooo`03o`000?oooooooooo
00Gooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0K?ooool3o`00
00Wooooo00?o0000ooooooooool02?ooool4o`0006gooooo00?o0000ooooooooool01Oooool001Wo
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1/ooooo`[o00000_ooool01?l0
003oooooooooooooool9o`0006oooooo00?o0000ooooooooool01Oooool001Wooooo00Co0000oooo
oooooooo00001?ooool2o`0007Gooooo2_l0001eooooo`;o00001oooool001Wooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool01Oooool001Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo000Jooooo`;o00001Ooooooho`0000Oooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo000cooooo`?o0000R_ooool00ol0003oooooooooo`0[
ooooo`?o00005Oooool00ol0003oooooooooo`0Gooooo`00=?ooool00ol0003oooooooooo`28oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Foooo
o`00;_ooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003ooooo`Co
000000?oooooo`000?l000000ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko
00001_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o
00000_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3o`000004ooooool0003o0000oooo
o`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003oooo
o`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol00002oooo
o`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_ooool:o`0000Gooooo00?o0000
ooooooooool05Oooool002gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool002gooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00000_ooool00ol0003ooooo
ooooo`02ooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`0000Gooooo1Ol00008oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o00000oooool0
0ol0003oooooo`000002ooooo`Go00000oooool01?l0003oooooooooooooool5o`0000;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00000_ooool3o`0000Gooooo00?o0000ooooooooool05Oooool002gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00005ooooo`06o`00
0?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`0Eooooo`00;Oooool01_l0003o
oooooooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000oooool2
o`0000Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00002ooooo`;o00000ooo
ool4o`0000?ooooo0ol00009ooooo`05o`000?ooooooooooo`000?ooool00ol00004ooooo`Co0000
0_ooool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo
1?l00003ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00_ooool6o`000003oooo
ool0003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o00000oooool4o`0000Cooooo
00?o0000ooooooooool05Oooool002gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Kooooo000^ooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00gooooo0ol00009ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o
00002_ooool4o`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0000^ooooo`03
o`000?oooooooooo01Sooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000;ooooo`03
o`000?oooooooooo01Oooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.67127, -3.02001, \
0.042497, 0.0187333}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 4.79371 0.0120499 0.0442353 [
[.02063 -0.00045 -12 -9 ]
[.02063 -0.00045 12 0 ]
[.26031 -0.00045 -15 -9 ]
[.26031 -0.00045 15 0 ]
[.5 -0.00045 -3 -9 ]
[.5 -0.00045 3 0 ]
[.73969 -0.00045 -12 -9 ]
[.73969 -0.00045 12 0 ]
[.97937 -0.00045 -9 -9 ]
[.97937 -0.00045 9 0 ]
[.01131 .10052 -6 -4.5 ]
[.01131 .10052 0 4.5 ]
[.01131 .18899 -6 -4.5 ]
[.01131 .18899 0 4.5 ]
[.01131 .27746 -6 -4.5 ]
[.01131 .27746 0 4.5 ]
[.01131 .36593 -6 -4.5 ]
[.01131 .36593 0 4.5 ]
[.01131 .4544 -12 -4.5 ]
[.01131 .4544 0 4.5 ]
[.01131 .54287 -12 -4.5 ]
[.01131 .54287 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02063 .01205 m
.02063 .0183 L
s
[(-0.1)] .02063 -0.00045 0 1 Mshowa
.26031 .01205 m
.26031 .0183 L
s
[(-0.05)] .26031 -0.00045 0 1 Mshowa
.5 .01205 m
.5 .0183 L
s
[(0)] .5 -0.00045 0 1 Mshowa
.73969 .01205 m
.73969 .0183 L
s
[(0.05)] .73969 -0.00045 0 1 Mshowa
.97937 .01205 m
.97937 .0183 L
s
[(0.1)] .97937 -0.00045 0 1 Mshowa
.125 Mabswid
.06857 .01205 m
.06857 .0158 L
s
.1165 .01205 m
.1165 .0158 L
s
.16444 .01205 m
.16444 .0158 L
s
.21238 .01205 m
.21238 .0158 L
s
.30825 .01205 m
.30825 .0158 L
s
.35619 .01205 m
.35619 .0158 L
s
.40413 .01205 m
.40413 .0158 L
s
.45206 .01205 m
.45206 .0158 L
s
.54794 .01205 m
.54794 .0158 L
s
.59587 .01205 m
.59587 .0158 L
s
.64381 .01205 m
.64381 .0158 L
s
.69175 .01205 m
.69175 .0158 L
s
.78762 .01205 m
.78762 .0158 L
s
.83556 .01205 m
.83556 .0158 L
s
.8835 .01205 m
.8835 .0158 L
s
.93143 .01205 m
.93143 .0158 L
s
.25 Mabswid
0 .01205 m
1 .01205 L
s
.02381 .10052 m
.03006 .10052 L
s
[(2)] .01131 .10052 1 0 Mshowa
.02381 .18899 m
.03006 .18899 L
s
[(4)] .01131 .18899 1 0 Mshowa
.02381 .27746 m
.03006 .27746 L
s
[(6)] .01131 .27746 1 0 Mshowa
.02381 .36593 m
.03006 .36593 L
s
[(8)] .01131 .36593 1 0 Mshowa
.02381 .4544 m
.03006 .4544 L
s
[(10)] .01131 .4544 1 0 Mshowa
.02381 .54287 m
.03006 .54287 L
s
[(12)] .01131 .54287 1 0 Mshowa
.125 Mabswid
.02381 .03417 m
.02756 .03417 L
s
.02381 .05629 m
.02756 .05629 L
s
.02381 .0784 m
.02756 .0784 L
s
.02381 .12264 m
.02756 .12264 L
s
.02381 .14476 m
.02756 .14476 L
s
.02381 .16687 m
.02756 .16687 L
s
.02381 .21111 m
.02756 .21111 L
s
.02381 .23323 m
.02756 .23323 L
s
.02381 .25534 m
.02756 .25534 L
s
.02381 .29958 m
.02756 .29958 L
s
.02381 .3217 m
.02756 .3217 L
s
.02381 .34381 m
.02756 .34381 L
s
.02381 .38805 m
.02756 .38805 L
s
.02381 .41017 m
.02756 .41017 L
s
.02381 .43229 m
.02756 .43229 L
s
.02381 .47652 m
.02756 .47652 L
s
.02381 .49864 m
.02756 .49864 L
s
.02381 .52076 m
.02756 .52076 L
s
.02381 .56499 m
.02756 .56499 L
s
.02381 .58711 m
.02756 .58711 L
s
.02381 .60923 m
.02756 .60923 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01828 m
.02643 .01847 L
.02904 .018 L
.03166 .01704 L
.03428 .01592 L
.03689 .01503 L
.03951 .01472 L
.04212 .01513 L
.04474 .01622 L
.04736 .01771 L
.04997 .01917 L
.05259 .0202 L
.05521 .02049 L
.05782 .01999 L
.06044 .01887 L
.06306 .01754 L
.06567 .01649 L
.06829 .01612 L
.07091 .01666 L
.07352 .01805 L
.07614 .01996 L
.07875 .02187 L
.08137 .02326 L
.08399 .02376 L
.0866 .02325 L
.08922 .02197 L
.09184 .02039 L
.09445 .01912 L
.09707 .01871 L
.09969 .01945 L
.1023 .02131 L
.10492 .02388 L
.10754 .02653 L
.11015 .02858 L
.11277 .02951 L
.11538 .02914 L
.118 .02773 L
.12062 .02587 L
.12323 .02436 L
.12585 .02392 L
.12847 .02501 L
.13108 .02765 L
.1337 .03136 L
.13632 .03533 L
.13893 .03866 L
.14155 .04058 L
.14417 .04079 L
.14678 .03951 L
.1494 .03747 L
.15201 .03574 L
Mistroke
.15463 .03537 L
.15725 .03708 L
.15986 .04106 L
.16248 .0468 L
.1651 .05329 L
.16771 .05926 L
.17033 .06355 L
.17295 .06553 L
.17556 .06528 L
.17818 .06365 L
.1808 .06202 L
.18341 .06194 L
.18603 .0647 L
.18864 .07084 L
.19126 .08006 L
.19388 .09116 L
.19649 .1024 L
.19911 .11199 L
.20173 .11862 L
.20434 .12189 L
.20696 .12249 L
.20958 .12206 L
.21219 .12281 L
.21481 .12687 L
.21743 .1357 L
.22004 .14959 L
.22266 .16757 L
.22527 .18756 L
.22789 .20692 L
.23051 .2232 L
.23312 .23481 L
.23574 .24157 L
.23836 .24479 L
.24097 .247 L
.24359 .25131 L
.24621 .26059 L
.24882 .27658 L
.25144 .29945 L
.25406 .32758 L
.25667 .35796 L
.25929 .3869 L
.2619 .41099 L
.26452 .42798 L
.26714 .43744 L
.26975 .44088 L
.27237 .44138 L
.27499 .44284 L
.2776 .44893 L
.28022 .46209 L
.28284 .48288 L
Mistroke
.28545 .50973 L
.28807 .53926 L
.29069 .56711 L
.2933 .58894 L
.29592 .60148 L
.29853 .60332 L
.30115 .5952 L
.30377 .5798 L
.30638 .56105 L
.309 .54316 L
.31162 .52959 L
.31423 .52229 L
.31685 .52126 L
.31947 .52463 L
.32208 .52924 L
.3247 .53136 L
.32732 .52763 L
.32993 .51584 L
.33255 .4953 L
.33516 .46699 L
.33778 .43323 L
.3404 .39715 L
.34301 .36202 L
.34563 .33067 L
.34825 .30509 L
.35086 .28623 L
.35348 .27408 L
.3561 .26792 L
.35871 .26657 L
.36133 .26873 L
.36395 .27312 L
.36656 .27867 L
.36918 .28445 L
.37179 .28977 L
.37441 .2941 L
.37703 .29717 L
.37964 .29902 L
.38226 .30008 L
.38488 .30119 L
.38749 .30353 L
.39011 .30842 L
.39273 .31703 L
.39534 .33004 L
.39796 .34739 L
.40058 .3681 L
.40319 .3903 L
.40581 .41144 L
.40842 .42876 L
.41104 .43968 L
.41366 .44236 L
Mistroke
.41627 .43595 L
.41889 .42081 L
.42151 .39838 L
.42412 .37092 L
.42674 .34112 L
.42936 .31168 L
.43197 .28495 L
.43459 .26271 L
.43721 .24613 L
.43982 .23582 L
.44244 .23194 L
.44505 .23435 L
.44767 .24272 L
.45029 .25646 L
.4529 .27477 L
.45552 .29644 L
.45814 .3199 L
.46075 .34323 L
.46337 .36431 L
.46599 .38108 L
.4686 .39185 L
.47122 .39558 L
.47384 .39206 L
.47645 .38194 L
.47907 .36663 L
.48168 .34803 L
.4843 .32819 L
.48692 .30902 L
.48953 .29204 L
.49215 .27826 L
.49477 .26826 L
.49738 .26223 L
.5 .26022 L
.50262 .26223 L
.50523 .26826 L
.50785 .27826 L
.51047 .29204 L
.51308 .30902 L
.5157 .32819 L
.51832 .34803 L
.52093 .36663 L
.52355 .38194 L
.52616 .39206 L
.52878 .39558 L
.5314 .39185 L
.53401 .38108 L
.53663 .36431 L
.53925 .34323 L
.54186 .3199 L
.54448 .29644 L
Mistroke
.5471 .27477 L
.54971 .25646 L
.55233 .24272 L
.55495 .23435 L
.55756 .23194 L
.56018 .23582 L
.56279 .24613 L
.56541 .26271 L
.56803 .28495 L
.57064 .31168 L
.57326 .34112 L
.57588 .37092 L
.57849 .39838 L
.58111 .42081 L
.58373 .43595 L
.58634 .44236 L
.58896 .43968 L
.59158 .42876 L
.59419 .41144 L
.59681 .3903 L
.59942 .3681 L
.60204 .34739 L
.60466 .33004 L
.60727 .31703 L
.60989 .30842 L
.61251 .30353 L
.61512 .30119 L
.61774 .30008 L
.62036 .29902 L
.62297 .29717 L
.62559 .2941 L
.62821 .28977 L
.63082 .28445 L
.63344 .27867 L
.63605 .27312 L
.63867 .26873 L
.64129 .26657 L
.6439 .26792 L
.64652 .27408 L
.64914 .28623 L
.65175 .30509 L
.65437 .33067 L
.65699 .36202 L
.6596 .39715 L
.66222 .43323 L
.66484 .46699 L
.66745 .4953 L
.67007 .51584 L
.67268 .52763 L
.6753 .53136 L
Mistroke
.67792 .52924 L
.68053 .52463 L
.68315 .52126 L
.68577 .52229 L
.68838 .52959 L
.691 .54316 L
.69362 .56105 L
.69623 .5798 L
.69885 .5952 L
.70147 .60332 L
.70408 .60148 L
.7067 .58894 L
.70931 .56711 L
.71193 .53926 L
.71455 .50973 L
.71716 .48288 L
.71978 .46209 L
.7224 .44893 L
.72501 .44284 L
.72763 .44138 L
.73025 .44088 L
.73286 .43744 L
.73548 .42798 L
.7381 .41099 L
.74071 .3869 L
.74333 .35796 L
.74594 .32758 L
.74856 .29945 L
.75118 .27658 L
.75379 .26059 L
.75641 .25131 L
.75903 .247 L
.76164 .24479 L
.76426 .24157 L
.76688 .23481 L
.76949 .2232 L
.77211 .20692 L
.77473 .18756 L
.77734 .16757 L
.77996 .14959 L
.78257 .1357 L
.78519 .12687 L
.78781 .12281 L
.79042 .12206 L
.79304 .12249 L
.79566 .12189 L
.79827 .11862 L
.80089 .11199 L
.80351 .1024 L
.80612 .09116 L
Mistroke
.80874 .08006 L
.81136 .07084 L
.81397 .0647 L
.81659 .06194 L
.8192 .06202 L
.82182 .06365 L
.82444 .06528 L
.82705 .06553 L
.82967 .06355 L
.83229 .05926 L
.8349 .05329 L
.83752 .0468 L
.84014 .04106 L
.84275 .03708 L
.84537 .03537 L
.84799 .03574 L
.8506 .03747 L
.85322 .03951 L
.85583 .04079 L
.85845 .04058 L
.86107 .03866 L
.86368 .03533 L
.8663 .03136 L
.86892 .02765 L
.87153 .02501 L
.87415 .02392 L
.87677 .02436 L
.87938 .02587 L
.882 .02773 L
.88462 .02914 L
.88723 .02951 L
.88985 .02858 L
.89246 .02653 L
.89508 .02388 L
.8977 .02131 L
.90031 .01945 L
.90293 .01871 L
.90555 .01912 L
.90816 .02039 L
.91078 .02197 L
.9134 .02325 L
.91601 .02376 L
.91863 .02326 L
.92125 .02187 L
.92386 .01996 L
.92648 .01805 L
.92909 .01666 L
.93171 .01612 L
.93433 .01649 L
.93694 .01754 L
Mistroke
.93956 .01887 L
.94218 .01999 L
.94479 .02049 L
.94741 .0202 L
.95003 .01917 L
.95264 .01771 L
.95526 .01622 L
.95788 .01513 L
.96049 .01472 L
.96311 .01503 L
.96572 .01592 L
.96834 .01704 L
.97096 .018 L
.97357 .01847 L
.97619 .01828 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[77]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0002_ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o0000;oooool2o`00037ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o0000:oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000oooooo000Dooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool0:Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0002oooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool09ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00kooooo000=ooooo`Go00000_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo02;ooooo1Ol00002ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0[oooo
o`04o`000?ooooooooooo`0002oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`0>ooooo`005?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo02Wo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo02_ooooo00Co0000oooooooooooo0000;oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool09oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00kooooo000Dooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool0:Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l0
000^ooooo`04o`000?ooooooooooo`0002oooooo00Co0000oooooooooooo00002?ooool01Ol0003o
ooooooooool0003ooooo00Co0000:_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00kooooo000Dooooo`04o`000?ooooooooooo`0000Sooooo0_l0000[ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0000aooooo`04o`000?ooooooooooo`00
02oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0002gooooo
00Co0000oooooooooooo00002?ooool2o`00013ooooo000Eooooo`;o00002_ooool00ol0003ooooo
ooooo`0Zooooo`;o00002_ooool2o`0000;ooooo1Ol0000^ooooo`;o0000<Oooool2o`0000[ooooo
0_l00002ooooo`Go0000:_ooool2o`0000[ooooo00?o0000ooooooooool03_ooool00?oooooo8Ooo
ool001[ooooo00?o0000ooooooooool0ooooool4ooooo`006_ooool00ol0003oooooooooo`3ooooo
o`Cooooo000Jooooo`03o`000?oooooooooo0?oooooo1?ooool001CooooooOl0000?ooooo`006Ooo
ool4o`0000;ooooo0_l00002ooooo`Co00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00_ooool2o`0000Cooooo1?l00003ooooo`03o`000?oo
oooooooo00Co00005Oooool001[ooooo00?o0000ooooooooool00oooool3o`0000Cooooo0_l00000
1?oooooo0000o`000?ooool2o`000<Oooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo0ol0
000Looooo`006_ooool00ol0003oooooooooo`0;ooooo`?o00000oooool2o`0000;ooooo0ol0002j
ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`;o00009?ooool001[ooooo00?o0000oooo
ooooool04_ooool3o`0000?ooooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`03o`00
02_ooooo000Jooooo`;o00006Oooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo02oo
oooo000Jooooo`03o`000?oooooooooo01Wooooo0_l000001?oooooo0000o`000?l0002/ooooo`?o
00000_ooool00ol0003oooooooooo`0`ooooo`006_ooool00ol0003oooooooooo`0Jooooo`?o0000
0_ooool00ol0003oooooooooo`2Xooooo`04o`000?ooooooooooooooo`;o0000<oooool001[ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo03Kooooo
000Jooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Yoooool00ol0003ooooooooo
o`0fooooo`006_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:Kooooo00?o0000
ooooooooool0=oooool001[ooooo0_l0000Qooooo`03o`000?oooooooooo0:Kooooo00?o0000oooo
ooooool0=oooool001[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02o`0009ko
oooo0_l00002ooooo`03o`000?oooooooooo03Sooooo000Jooooo`03o`000?oooooooooo02;ooooo
0ol000000ooooooo0000ooooo`2Looooo`03o`000?oooooo000000;o0000>_ooool001[ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo03cooooo000J
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0m
ooooo`006_ooool2o`0002Oooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0moooo
o`006_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo09Sooooo00?o0000oooooooo
ool0?_ooool001[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Hooooo`03o`00
0?oooooooooo03kooooo000Aooooo`Go00001?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo09Oooooo00?o0000ooooooooool0?_ooool001;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0?_oo
ool001?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo09Oooooo00?o0000ooooooooool0?_ooool001Cooooo00?o0000ooooooooool00oooool2o`00
02Wooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0oooooo`004Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2Foooo
o`03o`000?oooooooooo03oooooo000Aooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0@?ooool001;o
oooo0ol00005ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0U?ooool00ol0003o
ooooooooo`10ooooo`006_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09Cooooo
00?o0000ooooooooool0@?ooool001[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooo`00
002Aooooo`?o0000@_ooool001[ooooo0_l0000/ooooo`;o0000T?ooool2o`0004Cooooo000Joooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`13oooo
o`006_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo08gooooo00?o0000oooooooo
ool0@oooool001[ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2<ooooo`03o`00
0?oooooooooo04Cooooo000Jooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0S?oo
ool00ol0003oooooooooo`14ooooo`006_ooool2o`0002oooooo00?o0000ooooooooool0R_ooool0
0ol0003oooooooooo`15ooooo`006_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
08[ooooo00?o0000ooooooooool0AOooool001[ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`2:ooooo`03o`000?oooooooooo04Gooooo000Jooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0R_ooool00ol0003oooooooooo`15ooooo`006_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0AOooool001[ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo04Gooooo000Joooo
o`;o0000<?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo04Gooooo000Jooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`15ooooo`00
6_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0
AOooool001?ooooo0ol00004ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0R?oo
ool00ol0003oooooooooo`16ooooo`005?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`16ooooo`004Oooool5o`00
00Cooooo0_l0000`ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0A_ooool0017o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
08Sooooo00?o0000ooooooooool0A_ooool001;ooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0A_ooool001?ooooo
0_l00005ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`17ooooo`005?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0Q_ooool00ol0003oooooooooo`17ooooo`006_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Aoooool001[ooooo0_l0000aoooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Aoooool001[ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo04Oooooo000Jooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`17ooooo`006_oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0Aooo
ool001[ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo04Oooooo000Jooooo`;o0000<_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`18ooooo`006_ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo03;ooooo0_l0000Kooooo`;o0000<oooool00ol0003o
ooooooooo`18ooooo`006_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03;ooooo
0_l0000Kooooo`;o0000<oooool00ol0003oooooooooo`18ooooo`006_ooool00ol0003ooooooooo
o`0booooo`;o0000<Oooool00ol0003oooooo`00000Jooooo`03o`000?oooooo000003;ooooo00?o
0000ooooooooool0BOooool001[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooo000001[ooooo00?o0000ooooool00000<Oooool00ol0003oooooooooo`1:
ooooo`006_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02kooooo00Co0000oooo
oooooooo00006?ooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo04_ooooo000J
ooooo`;o0000=Oooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0001Sooooo00Co
0000oooooooooooo0000<?ooool00ol0003oooooooooo`1;ooooo`006_ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02cooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo04_o
oooo000Jooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;?ooool01Ol0003ooooo
oooooooooooo000000_ooooo0_l0000;ooooo`05o`000?ooooooooooooooool00000;oooool00ol0
003oooooooooo`1;ooooo`004_ooool3o`0000Gooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0Hooooo`?o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooo00002_ooool01Ol0003ooooooooooooooooo000001;ooooo0_l0000K
ooooo`03o`000?oooooooooo04_ooooo000Aooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool000004Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00002_oo
ool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooool000006_ooool00ol0003ooooo
ooooo`1<ooooo`004Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00006Oooool00ol0
003oooooooooo`1<ooooo`004Oooool4o`0000Gooooo0_l0000fooooo`03o`000?oooooooooo01So
oooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03Oooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool0C?oo
ool0017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000
6Oooool00ol0003oooooooooo`1<ooooo`004_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00gooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo04cooooo
000Cooooo`;o00001Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1=ooooo`006_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1=
ooooo`006_ooool2o`0003Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`05oooo
o`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool3o`0000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1=oooo
o`006_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`08ooooo`;o00002?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04gooooo000Jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04gooooo000Jooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo04gooooo000Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04gooooo000Jooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04gooooo000Jooooo`;o0000>?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0COooool001[ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0COooool001[ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0COooool001[ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0COooool001[ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0COooool001[ooooo0_l0000hooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1=ooooo`006_ooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1>ooooo`006_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`1>ooooo`004_ooool3o`0000Gooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0C_ooool0
017ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01_ooool01Ol0003ooooooooooooooooo000000[ooooo00Go0000oooooooooooooooo
o`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo04kooooo000Aooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
ooooo`00000:ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1>oooo
o`004_ooool3o`0000Gooooo0_l0000hooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`00000:ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1>
ooooo`004Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000002_ooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0C_ooool0017ooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool01?l0003ooooo
ooooool0000:ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Coooool001;o
oooo0ol00005ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooool0000;ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Coooool001[o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`00
00_ooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`006_ooool2o`0003Wo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo0000
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0Coooool001[ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`09ooooo`;o00003?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oo
oooo000Jooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool001[ooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo000J
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>
ooooo`05o`000?ooooooooooooooool000009_ooool01Ol0003ooooooooooooooooo0000013ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1?ooooo`006_ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooo
oooooooo000002Kooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0Coooool001[ooooo0_l0000jooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000002Kooooo00Go0000oooooooo
ooooooooo`00000@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Coooool001[o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00ko
oooo00Co0000oooooooooooo0000:?ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0Coooool001[ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo0000:?ooool0
1?l0003oooooooooool0000Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Cooo
ool001[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooool00000:?ooool01?l0003oooooooooool0000Aooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0D?ooool001[ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool00000:?ooool0
1?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0D?oo
ool001[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooool00000:Oooool00ol0003oooooo`00000Aooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0D?ooool001[ooooo0_l0000kooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03oooool00ol0003oooooo`00000Yooooo`03o`000?oooooo0000
017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Aooooo`006_ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003o
ooooo`00000Yooooo`;o00004_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057o
oooo000Jooooo`03o`000?oooooooooo03_ooooo0_l0000?ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo
0ol0001Cooooo`003?ooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Doooool000gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Doooool000gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00004ooooo`;o0000?_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`1Cooooo`003Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Dooooo`003Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Dooooo`003?ooool2o`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05Cooooo000=ooooo`03o`000?oooooooooo00?ooooo0_l00005
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E?ooool001[ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Eooooo`006_ooool2o`0003oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0EOooool001[ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`006_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo000Jooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0EOooool001[ooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1Eooooo`006_ooool2o`00043ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0EOooool001[ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`006_ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo05Gooooo000Jooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0EOooool001[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Eoooo
o`006_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Gooooo000Jooooo`;o0000
@?ooool00ol0003oooooooooo`04ooooo`;o00000_ooool00ol0003oooooooooo`1Cooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0EOooool001[ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?ooool0EOooool01?l0003ooooo
o`000?l00007ooooo`03o`000?oooooooooo05Gooooo000Jooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02o`0005Kooooo0_l00002ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool000cooooo0ol00002ooooo`Go00001?oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`00001Gooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0E_ooool000gooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0E_ooool000gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`;o0000@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Fooooo`003Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Fooooo`003Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0GOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Kooooo000<ooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Fooooo`003Oooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`10
ooooo`05o`000?ooooooooooooooool00000H?ooool01Ol0003ooooooooooooooooo000005Wooooo
000Jooooo`03o`000?oooooooooo043ooooo00Go0000ooooooooooooooooo`00001Pooooo`05o`00
0?ooooooooooooooool00000FOooool001[ooooo0_l00011ooooo`05o`000?ooooooooooooooool0
0000H?ooool01Ol0003ooooooooooooooooo000005Wooooo000Jooooo`03o`000?oooooooooo043o
oooo00Go0000ooooooooooooooooo`00001Pooooo`05o`000?ooooooooooooooool00000FOooool0
01[ooooo00?o0000ooooooooool0@?ooool01?l0003oooooooooool0001Rooooo`04o`000?oooooo
ooooo`0005Wooooo000Jooooo`03o`000?oooooooooo043ooooo00Co0000oooooooooooo0000H_oo
ool01?l0003oooooooooool0001Iooooo`006_ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooo000006;ooooo00Co0000oooooooooooo0000FOooool001[ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooo`00001Rooooo`04o`000?ooooooooooo`0005Wooooo000Jooooo`;o0000@_oo
ool00ol0003oooooo`00001Rooooo`04o`000?ooooooooooo`0005Wooooo000Jooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooool00000Hoooool00ol0003oooooo`00001Iooooo`006_ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooo000006?ooooo0_l0001Jooooo`006_ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooo000006?ooooo0_l0001Jooooo`006_ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0FOooool001[ooooo
0_l0003oooooo`Gooooo000Jooooo`03o`000?oooooooooo0?oooooo1?ooool001[ooooo00?o0000
ooooooooool0ooooool4ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00Gooo
ool3o`00057ooooo0ol0001Zooooo`00H?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo06Wooooo000eooooo`?o00001?ooool3o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000Wooooo0ol00003ooooo`?o00000_ooool3o`0000Cooooo0ol00003
ooooo`Co00000_ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_oo
ool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000001?l00002ooooo`Go00000ooo
ool2o`0000Cooooo00?o0000ooooooooool01oooool3o`0000Gooooo0_l000000ooooooo0000o`00
0002o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`?o0000
0_ooool3o`000003ooooool0003o0000037ooooo000fooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00Co
0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0003;ooooo000fooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool5o`0000;ooooo0ol00002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0`ooooo`00=_ooool3o`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0:ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`;o00000oooool01ol0
003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooooooo
o`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000002Oooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0`ooooo`00=_oo
ool01?l0003oooooooooool00002ooooo`?o00000_ooool3o`0000?ooooo1?l00002ooooo`Co0000
2Oooool00ol0003oooooooooo`02ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo
0ol00003ooooo`;o00001?ooool3o`0000[ooooo00Co0000oooooooooooooooo1?l00002ooooo`Co
00000oooool3o`0000;ooooo1?l00003ooooo`Co000000Coooooo`000?l0003o00000oooool4o`00
00;ooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oooooooooo00;ooooo0_l000001?oo
oooo0000o`000?ooool4o`0000?ooooo0ol00002ooooo`Co00000_ooool3o`0000Cooooo0ol00002
ooooo`Co0000<oooool003Kooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`09
ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
ool0000Dooooo`03o`000?oooooooooo04Gooooo000eooooo`Co00002_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo0ol0000Kooooo`;o00002?ooool5o`0000Sooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo1Ol0
000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.121057, -1.09038, \
0.000828174, 0.089748}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Again we try a symbolic intensity plot but, this time we move further away \
from the plane of focus.\
\>", "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
Plot[intensity[-10,y],{y,-1,1},PlotRange->All,PlotPoints->100];\
\>", "Input",
  CellLabel->"In[78]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0147151 0.575452 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -12 -9 ]
[.2619 .00222 12 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .12981 -18 -4.5 ]
[.4875 .12981 0 4.5 ]
[.4875 .2449 -18 -4.5 ]
[.4875 .2449 0 4.5 ]
[.4875 .35999 -18 -4.5 ]
[.4875 .35999 0 4.5 ]
[.4875 .47508 -18 -4.5 ]
[.4875 .47508 0 4.5 ]
[.4875 .59017 -6 -4.5 ]
[.4875 .59017 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-0.5)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(0.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .12981 m
.50625 .12981 L
s
[(0.2)] .4875 .12981 1 0 Mshowa
.5 .2449 m
.50625 .2449 L
s
[(0.4)] .4875 .2449 1 0 Mshowa
.5 .35999 m
.50625 .35999 L
s
[(0.6)] .4875 .35999 1 0 Mshowa
.5 .47508 m
.50625 .47508 L
s
[(0.8)] .4875 .47508 1 0 Mshowa
.5 .59017 m
.50625 .59017 L
s
[(1)] .4875 .59017 1 0 Mshowa
.125 Mabswid
.5 .04349 m
.50375 .04349 L
s
.5 .07226 m
.50375 .07226 L
s
.5 .10103 m
.50375 .10103 L
s
.5 .15858 m
.50375 .15858 L
s
.5 .18735 m
.50375 .18735 L
s
.5 .21612 m
.50375 .21612 L
s
.5 .27367 m
.50375 .27367 L
s
.5 .30244 m
.50375 .30244 L
s
.5 .33121 m
.50375 .33121 L
s
.5 .38876 m
.50375 .38876 L
s
.5 .41753 m
.50375 .41753 L
s
.5 .4463 m
.50375 .4463 L
s
.5 .50385 m
.50375 .50385 L
s
.5 .53262 m
.50375 .53262 L
s
.5 .56139 m
.50375 .56139 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02409 .01472 L
.02435 .01472 L
.02465 .01472 L
.02494 .01472 L
.0252 .01472 L
.02544 .01472 L
.0257 .01472 L
.02599 .01472 L
.02627 .01472 L
.02657 .01472 L
.02686 .01472 L
.02712 .01472 L
.02743 .01472 L
.0276 .01472 L
.02776 .01472 L
.02805 .01472 L
.02837 .01472 L
.02853 .01472 L
.02869 .01472 L
.02899 .01472 L
.02916 .01472 L
.02931 .01472 L
.0295 .01472 L
.02967 .01472 L
.02998 .01472 L
.03026 .01472 L
.03056 .01472 L
.03073 .01472 L
.03089 .01472 L
.03116 .01472 L
.03142 .01472 L
.0317 .01472 L
.032 .01472 L
.0323 .01472 L
.03261 .01472 L
.03288 .01472 L
.03318 .01472 L
.03335 .01472 L
.03351 .01472 L
.03368 .01472 L
.03387 .01472 L
.03418 .01472 L
.03435 .01472 L
.03452 .01472 L
.03482 .01472 L
.0351 .01472 L
.03526 .01472 L
.03543 .01472 L
.03573 .01472 L
Mistroke
.03592 .01472 L
.03609 .01472 L
.03642 .01472 L
.0366 .01472 L
.03677 .01472 L
.03697 .01472 L
.03715 .01472 L
.03746 .01472 L
.03762 .01472 L
.03779 .01472 L
.03797 .01472 L
.03815 .01472 L
.03831 .01472 L
.03847 .01472 L
.03875 .01472 L
.03906 .01472 L
.03937 .01472 L
.03954 .01472 L
.03969 .01472 L
.03996 .01472 L
.04025 .01472 L
.04055 .01472 L
.04083 .01472 L
.04099 .01472 L
.04116 .01472 L
.04148 .01472 L
.04178 .01472 L
.04207 .01472 L
.04237 .01472 L
.04255 .01472 L
.04271 .01472 L
.04304 .01472 L
.04322 .01472 L
.04339 .01472 L
.04368 .01472 L
.04394 .01472 L
.04424 .01472 L
.04455 .01472 L
.04487 .01472 L
.04502 .01472 L
.0452 .01472 L
.0455 .01472 L
.04579 .01472 L
.04608 .01472 L
.04635 .01472 L
.0466 .01472 L
.04686 .01472 L
.04715 .01472 L
.04746 .01472 L
.04772 .01472 L
Mistroke
.04801 .01472 L
.04817 .01472 L
.04835 .01472 L
.04867 .01472 L
.04898 .01472 L
.04926 .01472 L
.04944 .01472 L
.0496 .01472 L
.04991 .01472 L
.05009 .01472 L
.05025 .01472 L
.05042 .01472 L
.05061 .01472 L
.0509 .01472 L
.05117 .01472 L
.0515 .01472 L
.05179 .01472 L
.0521 .01472 L
.05227 .01472 L
.05243 .01472 L
.05273 .01472 L
.05304 .01472 L
.05332 .01472 L
.05362 .01472 L
.05394 .01472 L
.05423 .01472 L
.0545 .01472 L
.05475 .01472 L
.05504 .01472 L
.05532 .01472 L
.05561 .01472 L
.05593 .01472 L
.0562 .01472 L
.05649 .01472 L
.05681 .01472 L
.05699 .01472 L
.05715 .01472 L
.05747 .01472 L
.05777 .01472 L
.05805 .01472 L
.0583 .01472 L
.05859 .01472 L
.05887 .01472 L
.05912 .01472 L
.05936 .01472 L
.05962 .01472 L
.05989 .01472 L
.06016 .01472 L
.06046 .01472 L
.06074 .01472 L
Mistroke
.06099 .01472 L
.06129 .01472 L
.06161 .01472 L
.06192 .01472 L
.0622 .01472 L
.0625 .01472 L
.06279 .01472 L
.06305 .01472 L
.06333 .01472 L
.06363 .01472 L
.06396 .01472 L
.06426 .01472 L
.06454 .01472 L
.06482 .01472 L
.06508 .01472 L
.06537 .01472 L
.06567 .01472 L
.06593 .01472 L
.06618 .01472 L
.06645 .01472 L
.06674 .01472 L
.06707 .01472 L
.06738 .01472 L
.06772 .01472 L
.06789 .01472 L
.06808 .01472 L
.06839 .01472 L
.06873 .01472 L
.06906 .01472 L
.06935 .01472 L
.06964 .01472 L
.0699 .01472 L
.0702 .01472 L
.07051 .01472 L
.07084 .01472 L
.07115 .01472 L
.07143 .01472 L
.07173 .01472 L
.07203 .01472 L
.07231 .01472 L
.07262 .01472 L
.07292 .01472 L
.07319 .01472 L
.07345 .01472 L
.07373 .01472 L
.07403 .01472 L
.07436 .01472 L
.07471 .01472 L
.07504 .01472 L
.07535 .01472 L
Mistroke
.07563 .01472 L
.07594 .01472 L
.07625 .01472 L
.07655 .01472 L
.07687 .01472 L
.07721 .01472 L
.07754 .01472 L
.07784 .01472 L
.07811 .01472 L
.07841 .01472 L
.07872 .01472 L
.07901 .01472 L
.07934 .01472 L
.07968 .01472 L
.07997 .01472 L
.08028 .01472 L
.08063 .01472 L
.08099 .01472 L
.08134 .01472 L
.08165 .01472 L
.08194 .01472 L
.08221 .01472 L
.08251 .01472 L
.08283 .01472 L
.08316 .01472 L
.08348 .01472 L
.08377 .01472 L
.08408 .01472 L
.08434 .01472 L
.08464 .01472 L
.08495 .01472 L
.08524 .01472 L
.08551 .01472 L
.08575 .01472 L
.08602 .01472 L
.08631 .01472 L
.08663 .01472 L
.08691 .01472 L
.08724 .01472 L
.08756 .01472 L
.08785 .01472 L
.08811 .01472 L
.08841 .01472 L
.08872 .01472 L
.08903 .01472 L
.08937 .01472 L
.08968 .01472 L
.08997 .01472 L
.09031 .01472 L
.09068 .01472 L
Mistroke
.09103 .01472 L
.09135 .01472 L
.09167 .01472 L
.092 .01472 L
.09228 .01472 L
.09259 .01472 L
.09292 .01472 L
.09327 .01472 L
.09361 .01472 L
.09392 .01472 L
.09423 .01472 L
.09451 .01472 L
.09482 .01472 L
.09516 .01472 L
.09544 .01472 L
.09571 .01472 L
.09601 .01472 L
.09633 .01472 L
.09661 .01472 L
.09688 .01472 L
.09717 .01472 L
.09748 .01472 L
.0978 .01472 L
.09811 .01472 L
.09839 .01472 L
.09868 .01472 L
.09894 .01472 L
.09923 .01472 L
.09953 .01472 L
.09981 .01472 L
.10031 .01472 L
.10059 .01472 L
.10084 .01472 L
.10116 .01472 L
.10145 .01472 L
.10172 .01472 L
.102 .01472 L
.10231 .01472 L
.10264 .01472 L
.10293 .01472 L
.10324 .01472 L
.10353 .01472 L
.10379 .01472 L
.1041 .01472 L
.10438 .01472 L
.1049 .01472 L
.10519 .01472 L
.10545 .01472 L
.10574 .01472 L
.10605 .01472 L
Mistroke
.10635 .01472 L
.10662 .01472 L
.10693 .01472 L
.10727 .01472 L
.10759 .01472 L
.10789 .01472 L
.10823 .01472 L
.10855 .01472 L
.10884 .01472 L
.10915 .01472 L
.10948 .01472 L
.10984 .01472 L
.11015 .01472 L
.11048 .01472 L
.1108 .01472 L
.11109 .01472 L
.11141 .01472 L
.11175 .01472 L
.11205 .01472 L
.11232 .01472 L
.11263 .01472 L
.11295 .01472 L
.11323 .01472 L
.11353 .01472 L
.11384 .01472 L
.11413 .01472 L
.11465 .01472 L
.11494 .01472 L
.11521 .01472 L
.11552 .01472 L
.11586 .01472 L
.11614 .01472 L
.11646 .01472 L
.1168 .01472 L
.11716 .01472 L
.1175 .01472 L
.11781 .01472 L
.11842 .01472 L
.11876 .01472 L
.11908 .01472 L
.11966 .01472 L
.11998 .01472 L
.12028 .01472 L
.12084 .01472 L
.12116 .01472 L
.12146 .01472 L
.12206 .01472 L
.1224 .01472 L
.12271 .01472 L
.12326 .01472 L
Mistroke
.12357 .01472 L
.12386 .01472 L
.12439 .01472 L
.12465 .01472 L
.12495 .01472 L
.12527 .01472 L
.1256 .01472 L
.1262 .01472 L
.12654 .01472 L
.12685 .01472 L
.12719 .01472 L
.12755 .01472 L
.12787 .01472 L
.12821 .01472 L
.12851 .01472 L
.12883 .01472 L
.12912 .01472 L
.12944 .01472 L
.13 .01472 L
.13031 .01472 L
.1306 .01472 L
.13095 .01472 L
.13126 .01472 L
.13184 .01472 L
.13216 .01472 L
.13246 .01472 L
.13274 .01472 L
.13303 .01472 L
.13355 .01472 L
.13384 .01472 L
.1341 .01472 L
.13472 .01472 L
.13503 .01472 L
.13537 .01472 L
.13568 .01472 L
.136 .01472 L
.13629 .01472 L
.1366 .01472 L
.13716 .01472 L
.1375 .01472 L
.13781 .01472 L
.13815 .01472 L
.13852 .01472 L
.13885 .01472 L
.13916 .01472 L
.13978 .01472 L
.14009 .01472 L
.14042 .01472 L
.14101 .01472 L
.14134 .01472 L
Mistroke
.14165 .01472 L
.142 .01472 L
.14234 .01472 L
.14264 .01472 L
.14295 .01472 L
.14351 .01472 L
.14382 .01472 L
.14416 .01472 L
.14476 .01472 L
.14529 .01472 L
.14586 .01472 L
.1464 .01472 L
.1469 .01472 L
.14745 .01472 L
.14805 .01472 L
.14836 .01472 L
.14868 .01472 L
.14927 .01472 L
.14957 .01472 L
.14989 .01472 L
.15021 .01472 L
.15056 .01472 L
.15117 .01472 L
.15175 .01472 L
.15209 .01472 L
.15247 .01472 L
.1528 .01472 L
.15316 .01472 L
.15351 .01472 L
.15382 .01472 L
.15444 .01472 L
.15507 .01472 L
.15565 .01472 L
.15629 .01472 L
.15661 .01472 L
.15696 .01472 L
.15755 .01472 L
.15818 .01472 L
.15878 .01472 L
.15933 .01472 L
.15988 .01472 L
.16049 .01472 L
.16113 .01472 L
.16173 .01472 L
.16229 .01472 L
.16281 .01472 L
.16337 .01472 L
.16396 .01472 L
.16456 .01472 L
.16521 .01472 L
Mistroke
.16582 .01472 L
.16637 .01472 L
.16702 .01472 L
.16772 .01472 L
.16839 .01472 L
.169 .01472 L
.16959 .01472 L
.17013 .01472 L
.17076 .01472 L
.17135 .01472 L
.1719 .01472 L
.17241 .01472 L
.17296 .01472 L
.17355 .01472 L
.17414 .01472 L
.17478 .01472 L
.17538 .01472 L
.17593 .01472 L
.17654 .01472 L
.17721 .01472 L
.17791 .01472 L
.17856 .01472 L
.1792 .01472 L
.17978 .01472 L
.18043 .01472 L
.18111 .01472 L
.1817 .01472 L
.18225 .01472 L
.18286 .01472 L
.18351 .01472 L
.18409 .01472 L
.18472 .01472 L
.18527 .01472 L
.18587 .01472 L
.18645 .01472 L
.18698 .01472 L
.18802 .01472 L
.18858 .01472 L
.1892 .01472 L
.1898 .01472 L
.19045 .01472 L
.19105 .01472 L
.19161 .01472 L
.19269 .01472 L
.19333 .01472 L
.19393 .01472 L
.19457 .01472 L
.19528 .01472 L
.19647 .01472 L
.19712 .01472 L
Mistroke
.19773 .01472 L
.19887 .01472 L
.19952 .01472 L
.20012 .01473 L
.20133 .01473 L
.20201 .01473 L
.20263 .01474 L
.20374 .01475 L
.20494 .01476 L
.20607 .01478 L
.20712 .0148 L
.20825 .01483 L
.20947 .01487 L
.21062 .01493 L
.21167 .015 L
.2129 .0151 L
.21424 .01525 L
.2155 .01544 L
.21667 .01567 L
.21791 .01598 L
.21924 .01641 L
.2205 .01694 L
.22166 .01755 L
.22386 .01912 L
.22496 .02016 L
.22617 .02155 L
.22866 .02537 L
.23092 .03028 L
.23352 .03814 L
.23599 .04826 L
.23834 .06083 L
.24083 .07776 L
.2453 .11866 L
.25003 .17739 L
.25447 .24519 L
.26386 .40618 L
.26864 .48002 L
.27116 .51299 L
.27385 .54244 L
.27647 .56504 L
.27884 .58044 L
.27999 .58624 L
.28123 .5914 L
.28231 .59502 L
.28347 .59806 L
.2841 .59936 L
.28466 .60036 L
.28524 .6012 L
.28578 .60184 L
.2864 .60243 L
Mistroke
.28672 .60267 L
.28707 .60289 L
.28736 .60303 L
.28767 .60315 L
.28784 .6032 L
.288 .60324 L
.2883 .60329 L
.2886 .60332 L
.28892 .60332 L
.28922 .60329 L
.28949 .60325 L
.28981 .60317 L
.29016 .60307 L
.29079 .60282 L
.29215 .60205 L
.29341 .60115 L
.29834 .59701 L
.30296 .59367 L
.30738 .59132 L
.31214 .58943 L
.31727 .58786 L
.32214 .58671 L
.33141 .58476 L
.34127 .58237 L
.35077 .58063 L
.36085 .57864 L
.37058 .57693 L
.37993 .5756 L
.38468 .57477 L
.38988 .57393 L
.39484 .57334 L
.39946 .57288 L
.4089 .57165 L
.41894 .57055 L
.4286 .5698 L
.43303 .56932 L
.43554 .56905 L
.43791 .56883 L
.44022 .56866 L
.44271 .56853 L
.44514 .56844 L
.4478 .56834 L
.45032 .56822 L
.45266 .56808 L
.45778 .56767 L
.46034 .56748 L
.46159 .5674 L
.46275 .56733 L
.46378 .56729 L
.46491 .56725 L
Mistroke
.46605 .56722 L
.46667 .56721 L
.46726 .5672 L
.46944 .56718 L
.47064 .56717 L
.47177 .56717 L
.47235 .56716 L
.47298 .56715 L
.47363 .56714 L
.47431 .56713 L
.47555 .5671 L
.47668 .56706 L
.47913 .56695 L
.48182 .56681 L
.48313 .56675 L
.48437 .56669 L
.48558 .56664 L
.48611 .56663 L
.48669 .56661 L
.48722 .5666 L
.4878 .56659 L
.48811 .56659 L
.4884 .56658 L
.48869 .56658 L
.48897 .56658 L
.48926 .56658 L
.48958 .56658 L
.48988 .56658 L
.49015 .56658 L
.49047 .56658 L
.49081 .56659 L
.49144 .56659 L
.49272 .56662 L
.49408 .56665 L
.49535 .56668 L
.49651 .5667 L
.49708 .56671 L
.49769 .56672 L
.49827 .56673 L
.49881 .56673 L
.4991 .56674 L
.49938 .56674 L
.49968 .56674 L
.49985 .56674 L
.5 .56674 L
.5003 .56674 L
.50047 .56674 L
.50062 .56674 L
.50094 .56674 L
.50127 .56673 L
Mistroke
.50185 .56673 L
.50247 .56672 L
.5036 .5667 L
.50572 .56665 L
.50682 .56663 L
.50801 .5666 L
.50869 .56659 L
.50932 .56659 L
.50962 .56658 L
.50977 .56658 L
.50994 .56658 L
.51025 .56658 L
.51054 .56658 L
.51071 .56658 L
.51088 .56658 L
.5112 .56658 L
.51138 .56658 L
.51154 .56658 L
.51192 .56659 L
.51224 .56659 L
.51254 .5666 L
.51321 .56661 L
.51446 .56664 L
.51564 .56669 L
.52007 .56691 L
.52258 .56703 L
.52382 .56708 L
.52494 .56711 L
.52607 .56714 L
.52664 .56715 L
.52726 .56716 L
.52788 .56716 L
.52855 .56717 L
.52975 .56718 L
.53041 .56718 L
.53112 .56719 L
.53175 .56719 L
.53242 .5672 L
.53302 .5672 L
.53368 .56722 L
.53484 .56724 L
.53545 .56726 L
.53611 .56728 L
.53731 .56734 L
.53957 .56747 L
.54464 .56787 L
.55452 .56842 L
.55688 .56851 L
.55942 .56864 L
.56182 .5688 L
Mistroke
.56403 .569 L
.57317 .56998 L
.57776 .57033 L
.58038 .5705 L
.58277 .57068 L
.58752 .57117 L
.5926 .57187 L
.60228 .57305 L
.60672 .5735 L
.6116 .57415 L
.61641 .57497 L
.62151 .57584 L
.63129 .5772 L
.64069 .57897 L
.65069 .58088 L
.66032 .58273 L
.66959 .58499 L
.67945 .58706 L
.68401 .58821 L
.68894 .58982 L
.69413 .59205 L
.69902 .59499 L
.70377 .59879 L
.70628 .6009 L
.70766 .60192 L
.70834 .60236 L
.70897 .6027 L
.70957 .60297 L
.70988 .60308 L
.71021 .60318 L
.71038 .60322 L
.71054 .60325 L
.71085 .6033 L
.71102 .60331 L
.7112 .60332 L
.71139 .60332 L
.71156 .60331 L
.71187 .60326 L
.71216 .6032 L
.71242 .60311 L
.7127 .603 L
.71334 .60263 L
.71392 .60215 L
.71448 .60156 L
.71499 .60088 L
.71617 .59883 L
.71732 .59609 L
.71855 .59222 L
.72101 .58128 L
.7224 .573 L
Mistroke
.72368 .56389 L
.72856 .51635 L
.73355 .44781 L
.73806 .37353 L
.74779 .2093 L
.75226 .14697 L
.7548 .11763 L
.75716 .09444 L
.7597 .07386 L
.76201 .05879 L
.76447 .04613 L
.76712 .03596 L
.76953 .02918 L
.77176 .02463 L
.7742 .02109 L
.77543 .01976 L
.77679 .01859 L
.77805 .01772 L
.77925 .01706 L
.7815 .01616 L
.78275 .0158 L
.78392 .01554 L
.7852 .01533 L
.78656 .01515 L
.78786 .01503 L
.78905 .01495 L
.79036 .01488 L
.79175 .01483 L
.79295 .0148 L
.79408 .01477 L
.79531 .01476 L
.79601 .01475 L
.79664 .01474 L
.7978 .01473 L
.79904 .01473 L
.8001 .01472 L
.80126 .01472 L
.80191 .01472 L
.80251 .01472 L
.80315 .01472 L
.80386 .01472 L
.80504 .01472 L
.80569 .01472 L
.80629 .01472 L
.80752 .01472 L
.80821 .01472 L
.80884 .01472 L
.81001 .01472 L
.8106 .01472 L
.81125 .01472 L
Mistroke
.81237 .01472 L
.813 .01472 L
.81358 .01472 L
.81411 .01472 L
.8147 .01472 L
.81576 .01472 L
.81638 .01472 L
.81705 .01472 L
.81768 .01472 L
.81826 .01472 L
.81937 .01472 L
.81992 .01472 L
.82053 .01472 L
.8212 .01472 L
.82181 .01472 L
.8225 .01472 L
.82317 .01472 L
.82378 .01472 L
.82434 .01472 L
.82496 .01472 L
.82562 .01472 L
.8262 .01472 L
.82681 .01472 L
.82733 .01472 L
.8279 .01472 L
.82851 .01472 L
.82917 .01472 L
.82979 .01472 L
.83035 .01472 L
.83092 .01472 L
.83144 .01472 L
.83202 .01472 L
.83263 .01472 L
.83316 .01472 L
.83366 .01472 L
.8342 .01472 L
.83478 .01472 L
.8354 .01472 L
.83606 .01472 L
.83662 .01472 L
.83724 .01472 L
.83791 .01472 L
.83826 .01472 L
.83863 .01472 L
.8393 .01472 L
.83992 .01472 L
.84051 .01472 L
.84113 .01472 L
.84172 .01472 L
.84225 .01472 L
Mistroke
.84288 .01472 L
.84321 .01472 L
.84356 .01472 L
.84421 .01472 L
.8448 .01472 L
.84541 .01472 L
.84599 .01472 L
.84651 .01472 L
.84708 .01472 L
.8477 .01472 L
.84804 .01472 L
.84836 .01472 L
.84896 .01472 L
.84954 .01472 L
.85008 .01472 L
.85065 .01472 L
.85113 .01472 L
.85167 .01472 L
.85224 .01472 L
.85256 .01472 L
.85286 .01472 L
.85344 .01472 L
.85397 .01472 L
.85455 .01472 L
.85509 .01472 L
.85568 .01472 L
.85601 .01472 L
.85632 .01472 L
.85689 .01472 L
.85722 .01472 L
.85753 .01472 L
.85814 .01472 L
.85849 .01472 L
.8588 .01472 L
.85938 .01472 L
.85991 .01472 L
.86049 .01472 L
.86078 .01472 L
.8611 .01472 L
.86164 .01472 L
.86194 .01472 L
.86222 .01472 L
.86276 .01472 L
.86327 .01472 L
.86357 .01472 L
.8639 .01472 L
.86419 .01472 L
.86449 .01472 L
.86477 .01472 L
.86507 .01472 L
Mistroke
.8656 .01472 L
.86593 .01472 L
.86622 .01472 L
.86654 .01472 L
.86688 .01472 L
.8672 .01472 L
.8675 .01472 L
.86778 .01472 L
.86808 .01472 L
.86861 .01472 L
.86911 .01472 L
.86942 .01472 L
.8697 .01472 L
.87025 .01472 L
.87052 .01472 L
.87082 .01472 L
.87134 .01472 L
.87167 .01472 L
.87197 .01472 L
.87254 .01472 L
.87282 .01472 L
.87313 .01472 L
.87367 .01472 L
.874 .01472 L
.87432 .01472 L
.87491 .01472 L
.87521 .01472 L
.87553 .01472 L
.8761 .01472 L
.87642 .01472 L
.87672 .01472 L
.87705 .01472 L
.87741 .01472 L
.87795 .01472 L
.87825 .01472 L
.87853 .01472 L
.87903 .01472 L
.87931 .01472 L
.87956 .01472 L
.88013 .01472 L
.88046 .01472 L
.88076 .01472 L
.8813 .01472 L
.88158 .01472 L
.88188 .01472 L
.88218 .01472 L
.88249 .01472 L
.88283 .01472 L
.88315 .01472 L
.88347 .01472 L
Mistroke
.88377 .01472 L
.88405 .01472 L
.88434 .01472 L
.88461 .01472 L
.88491 .01472 L
.88543 .01472 L
.88572 .01472 L
.88603 .01472 L
.8863 .01472 L
.88659 .01472 L
.88693 .01472 L
.88725 .01472 L
.88758 .01472 L
.88796 .01472 L
.88828 .01472 L
.88862 .01472 L
.88895 .01472 L
.88924 .01472 L
.88981 .01472 L
.89012 .01472 L
.89042 .01472 L
.89073 .01472 L
.89102 .01472 L
.89135 .01472 L
.89166 .01472 L
.89194 .01472 L
.89224 .01472 L
.8925 .01472 L
.89278 .01472 L
.89311 .01472 L
.89343 .01472 L
.89373 .01472 L
.89402 .01472 L
.89435 .01472 L
.89465 .01472 L
.89493 .01472 L
.89523 .01472 L
.89555 .01472 L
.8959 .01472 L
.89619 .01472 L
.89651 .01472 L
.89682 .01472 L
.8971 .01472 L
.89763 .01472 L
.89793 .01472 L
.89821 .01472 L
.89851 .01472 L
.89883 .01472 L
.89909 .01472 L
.89936 .01472 L
Mistroke
.89986 .01472 L
.90016 .01472 L
.90045 .01472 L
.90073 .01472 L
.90099 .01472 L
.90129 .01472 L
.90162 .01472 L
.90191 .01472 L
.90221 .01472 L
.90246 .01472 L
.90274 .01472 L
.90303 .01472 L
.90331 .01472 L
.90363 .01472 L
.90398 .01472 L
.90431 .01472 L
.90461 .01472 L
.90488 .01472 L
.90518 .01472 L
.9055 .01472 L
.90579 .01472 L
.90605 .01472 L
.90634 .01472 L
.90663 .01472 L
.90691 .01472 L
.90741 .01472 L
.90768 .01472 L
.90794 .01472 L
.90823 .01472 L
.90851 .01472 L
.90881 .01472 L
.90913 .01472 L
.9094 .01472 L
.90966 .01472 L
.90994 .01472 L
.91025 .01472 L
.91057 .01472 L
.91087 .01472 L
.9112 .01472 L
.91152 .01472 L
.91182 .01472 L
.91209 .01472 L
.91239 .01472 L
.9127 .01472 L
.91302 .01472 L
.91337 .01472 L
.91369 .01472 L
.91398 .01472 L
.91433 .01472 L
.9147 .01472 L
Mistroke
.91505 .01472 L
.91538 .01472 L
.91566 .01472 L
.91596 .01472 L
.91625 .01472 L
.91651 .01472 L
.91679 .01472 L
.91711 .01472 L
.91744 .01472 L
.91775 .01472 L
.91807 .01472 L
.91838 .01472 L
.91866 .01472 L
.91896 .01472 L
.91929 .01472 L
.91963 .01472 L
.91993 .01472 L
.92025 .01472 L
.92057 .01472 L
.92086 .01472 L
.92118 .01472 L
.92152 .01472 L
.92182 .01472 L
.92209 .01472 L
.9224 .01472 L
.92272 .01472 L
.923 .01472 L
.9233 .01472 L
.92361 .01472 L
.9239 .01472 L
.92417 .01472 L
.92442 .01472 L
.92471 .01472 L
.92498 .01472 L
.92527 .01472 L
.92559 .01472 L
.92593 .01472 L
.92624 .01472 L
.92654 .01472 L
.9268 .01472 L
.92711 .01472 L
.92741 .01472 L
.92773 .01472 L
.92806 .01472 L
.92838 .01472 L
.92867 .01472 L
.92901 .01472 L
.9292 .01472 L
.92938 .01472 L
.9297 .01472 L
Mistroke
.93005 .01472 L
.93034 .01472 L
.93066 .01472 L
.93097 .01472 L
.93125 .01472 L
.9315 .01472 L
.93178 .01472 L
.93207 .01472 L
.93235 .01472 L
.93265 .01472 L
.93296 .01472 L
.93324 .01472 L
.93353 .01472 L
.93385 .01472 L
.93419 .01472 L
.93452 .01472 L
.93481 .01472 L
.93509 .01472 L
.93538 .01472 L
.93563 .01472 L
.93591 .01472 L
.9362 .01472 L
.93652 .01472 L
.93682 .01472 L
.9371 .01472 L
.93737 .01472 L
.93763 .01472 L
.93791 .01472 L
.9382 .01472 L
.93849 .01472 L
.93876 .01472 L
.939 .01472 L
.93926 .01472 L
.93956 .01472 L
.93983 .01472 L
.94015 .01472 L
.94045 .01472 L
.94073 .01472 L
.94099 .01472 L
.94127 .01472 L
.94157 .01472 L
.94187 .01472 L
.94219 .01472 L
.9425 .01472 L
.94277 .01472 L
.9431 .01472 L
.94328 .01472 L
.94345 .01472 L
.94377 .01472 L
.9441 .01472 L
Mistroke
.94427 .01472 L
.94445 .01472 L
.94476 .01472 L
.94494 .01472 L
.94511 .01472 L
.9453 .01472 L
.94548 .01472 L
.94581 .01472 L
.94611 .01472 L
.94643 .01472 L
.94661 .01472 L
.94678 .01472 L
.94707 .01472 L
.94734 .01472 L
.94764 .01472 L
.94796 .01472 L
.94828 .01472 L
.94844 .01472 L
.94861 .01472 L
.94892 .01472 L
.94921 .01472 L
.94952 .01472 L
.94985 .01472 L
.95013 .01472 L
.95044 .01472 L
.95061 .01472 L
.95077 .01472 L
.95094 .01472 L
.95112 .01472 L
.95129 .01472 L
.95145 .01472 L
.95176 .01472 L
.95208 .01472 L
.95237 .01472 L
.95264 .01472 L
.95293 .01472 L
.95324 .01472 L
.9534 .01472 L
.95358 .01472 L
.95388 .01472 L
.95417 .01472 L
.95445 .01472 L
.95475 .01472 L
.95504 .01472 L
.95531 .01472 L
.95555 .01472 L
.95581 .01472 L
.95609 .01472 L
.95635 .01472 L
.95663 .01472 L
Mistroke
.95693 .01472 L
.95719 .01472 L
.95747 .01472 L
.95777 .01472 L
.95794 .01472 L
.95809 .01472 L
.95839 .01472 L
.95868 .01472 L
.95896 .01472 L
.95926 .01472 L
.95954 .01472 L
.9598 .01472 L
.9601 .01472 L
.96028 .01472 L
.96043 .01472 L
.96073 .01472 L
.96104 .01472 L
.96133 .01472 L
.96165 .01472 L
.96195 .01472 L
.96222 .01472 L
.96253 .01472 L
.9627 .01472 L
.96286 .01472 L
.96319 .01472 L
.96337 .01472 L
.96353 .01472 L
.96381 .01472 L
.96411 .01472 L
.96436 .01472 L
.96464 .01472 L
.96494 .01472 L
.96526 .01472 L
.96556 .01472 L
.96583 .01472 L
.96611 .01472 L
.96637 .01472 L
.96665 .01472 L
.96695 .01472 L
.96724 .01472 L
.96751 .01472 L
.96775 .01472 L
.96801 .01472 L
.96826 .01472 L
.96848 .01472 L
.96874 .01472 L
.96899 .01472 L
.96922 .01472 L
.96943 .01472 L
.96966 .01472 L
Mistroke
.96991 .01472 L
.97015 .01472 L
.97042 .01472 L
.97067 .01472 L
.9709 .01472 L
.97115 .01472 L
.97143 .01472 L
.97172 .01472 L
.97199 .01472 L
.97225 .01472 L
.97254 .01472 L
.9728 .01472 L
.97305 .01472 L
.97328 .01472 L
.97352 .01472 L
.97378 .01472 L
.97402 .01472 L
.9743 .01472 L
.97457 .01472 L
.97481 .01472 L
.97507 .01472 L
.97535 .01472 L
.97565 .01472 L
.97593 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`003P3oool3o`0003T0oooo0_l000040?ooo`03o`00003oool0oooo0080oooo0ol0001a0?oo
o`;o0000103oool00ol00000oooo0?ooo`020?ooo`?o0000>03oool3o`0000h0oooo000?0?ooo`03
o`00003oool0oooo03L0oooo00Co00000?ooo`3ooooo00001`3oool01Ol00000oooo0?ooo`3ooooo
000006l0oooo00Co00000?ooo`3ooooo00001`3oool01Ol00000oooo0?ooo`3ooooo000003P0oooo
00?o00000?ooo`3oool03@3oool000L0oooo1Ol000030?ooo`03o`00003oool0oooo0300oooo1Ol0
00020?ooo`04o`00003oool0ooooo`0000/0oooo00?o00000?ooo`3oool0K@3oool01?l00000oooo
0?ooool0000;0?ooo`03o`00003oool0oooo03H0oooo00?o00000?ooo`3oool03@3oool000l0oooo
00?o00000?ooo`3oool0=`3oool01?l00000oooo0?ooool0000;0?ooo`03o`00003oool0oooo06d0
oooo00Co00000?ooo`3ooooo00002`3oool00ol00000oooo0?ooo`0f0?ooo`03o`00003oool0oooo
00d0oooo000?0?ooo`03o`00003oool0oooo03L0oooo00Co00000?ooo`3ooooo00001`3oool4o`00
0700oooo00Co00000?ooo`3ooooo00001`3oool4o`0003T0oooo00?o00000?ooo`3oool03@3oool0
00h0oooo0_l0000i0?ooo`04o`00003oool0ooooo`0000L0oooo00?o00000?ooo`3oool0L@3oool0
1?l00000oooo0?ooool000070?ooo`03o`00003oool0oooo03T0oooo0_l0000?0?ooo`003`3oool0
0ol00000oooo0?ooo`0h0?ooo`;o0000203oool5o`000700oooo0_l000080?ooo`Go0000>03oool0
0ol00000oooo0?ooo`0=0?ooo`00S`3oool00ol00000oooo0?ooo`2>0?ooo`00S`3oool00ol00000
oooo0?ooo`2>0?ooo`00S`3oool00ol00000oooo0?ooo`2>0?ooo`00S`3oool00ol00000oooo0?oo
o`2>0?ooo`001`3oooooo`0001;o0000203oool000d0oooo00?o00000?ooo`3oool02P3oool00ol0
0000oooo0?ooo`0:0?ooo`03o`00003oool0oooo00X0oooo00?o00000?ooo`3oool02P3oool01?l0
0000ooooo`000?l000090?ooo`03o`00003oool0oooo00X0oooo00?o00000?ooo`3oool02P3oool0
0ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo00X0oooo00?o00000?ooo`3oool02P3oool0
0ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo00X0oooo00?o00000?ooo`3oool02P3oool0
0ol00000oooo0?ooo`0:0?ooo`03o`00003oool0oooo00X0oooo00?o00000?ooo`3oool01`3oool2
o`0000030?ooool00000oooo00/0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0:
0?ooo`03o`00003oool0oooo00X0oooo00?o00000?ooo`3oool0303oool000d0oooo00?o00000?oo
o`3oool0=03oool00ol00000oooo0?ooo`070?ooo`03o`00003oool0oooo03h0oooo00?o00000?oo
o`3oool0?P3oool00ol00000oooo0?ooo`070?ooo`03o`00003oool0oooo03@0oooo00?o00000?oo
o`3oool0303oool004D0oooo00?o00000?ooo`3oool0A`3oool00ol00000oooo0?ooo`170?ooo`03
o`00003oool0oooo04@0oooo00160?ooo`03o`00003oool0oooo04H0oooo00?o00000?ooo`3oool0
A`3oool00ol00000oooo0?ooo`140?ooo`00AP3oool00ol00000oooo0?ooo`160?ooo`03o`00003o
ool0oooo04L0oooo00?o00000?ooo`3oool0A03oool004H0oooo00?o00000?ooo`3oool0AP3oool0
0ol00000oooo0?ooo`160?ooo`03o`00003oool0oooo04D0oooo00160?ooo`03o`00003oool0oooo
04H0oooo00?o00000?ooo`3oool0AP3oool00ol00000oooo0?ooo`150?ooo`00A`3oool00ol00000
oooo0?ooo`150?ooo`;o0000AP3oool00ol00000oooo0?ooo`160?ooo`00A`3oool00ol00000oooo
0?ooo`150?ooo`03o`00003oool0oooo04D0oooo00?o00000?ooo`3oool0AP3oool004L0oooo00?o
00000?ooo`3oool0A@3oool00ol00000oooo0?ooo`150?ooo`03o`00003oool0oooo04H0oooo0017
0?ooo`03o`00003oool0oooo04D0oooo00?o00000?ooo`3oool0A03oool00ol00000oooo0?ooo`17
0?ooo`00B03oool00ol00000oooo0?ooo`140?ooo`03o`00003oool0oooo04@0oooo00?o00000?oo
o`3oool0A`3oool004P0oooo00?o00000?ooo`3oool0A03oool00ol00000oooo0?ooo`140?ooo`03
o`00003oool0oooo04L0oooo00180?ooo`03o`00003oool0oooo04@0oooo00?o00000?ooo`3oool0
A03oool00ol00000oooo0?ooo`170?ooo`00B03oool00ol00000oooo0?ooo`140?ooo`03o`00003o
ool0oooo04@0oooo00?o00000?ooo`3oool0A`3oool004P0oooo00?o00000?ooo`3oool0A03oool2
o`0004D0oooo00?o00000?ooo`3oool0A`3oool004P0oooo00?o00000?ooo`3oool0A03oool00ol0
0000oooo0?ooo`140?ooo`03o`00003oool0oooo04L0oooo00180?ooo`03o`00003oool0oooo04@0
oooo00?o00000?ooo`3oool0A03oool00ol00000oooo0?ooo`170?ooo`00B03oool00ol00000oooo
0?ooo`140?ooo`03o`00003oool0oooo04@0oooo00?o00000?ooo`3oool0A`3oool004P0oooo00?o
00000?ooo`3oool0A03oool00ol00000oooo0?ooo`130?ooo`03o`00003oool0oooo04P0oooo0019
0?ooo`03o`00003oool0oooo04<0oooo00?o00000?ooo`3oool0@`3oool00ol00000oooo0?ooo`18
0?ooo`00B@3oool00ol00000oooo0?ooo`130?ooo`03o`00003oool0oooo04<0oooo00?o00000?oo
o`3oool0B03oool004T0oooo00?o00000?ooo`3oool0@`3oool00ol00000oooo0?ooo`130?ooo`03
o`00003oool0oooo04P0oooo00190?ooo`03o`00003oool0oooo04<0oooo0_l000140?ooo`03o`00
003oool0oooo04P0oooo00190?ooo`03o`00003oool0oooo04<0oooo00?o00000?ooo`3oool0@`3o
ool00ol00000oooo0?ooo`180?ooo`00BP3oool00ol00000oooo0?ooo`120?ooo`03o`00003oool0
oooo0480oooo00?o00000?ooo`3oool0B@3oool004X0oooo00?o00000?ooo`3oool0@P3oool00ol0
0000oooo0?ooo`120?ooo`03o`00003oool0oooo04T0oooo001:0?ooo`03o`00003oool0oooo0480
oooo00?o00000?ooo`3oool0@P3oool00ol00000oooo0?ooo`190?ooo`00BP3oool00ol00000oooo
0?ooo`0_0?ooo`;o0000103oool01?l00000oooo0?ooo`3oool5o`0000@0oooo00?o00000?ooo`3o
ool0@P3oool00ol00000oooo0?ooo`190?ooo`00BP3oool00ol00000oooo0?ooo`0^0?ooo`04o`00
003oool0ooooo`0000P0oooo00Co00000?ooo`3ooooo0000103oool00ol00000oooo0?ooo`120?oo
o`03o`00003oool0oooo04T0oooo001:0?ooo`03o`00003oool0oooo02h0oooo00Co00000?ooo`3o
oooo00002@3oool00ol00000oooo0?ooo`040?ooo`?o0000@P3oool00ol00000oooo0?ooo`190?oo
o`00BP3oool00ol00000oooo0?ooo`0^0?ooo`04o`00003oool0ooooo`0000X0oooo00?o00000?oo
o`3oool00`3oool00ol00000oooo0?ooo`120?ooo`03o`00003oool0oooo04T0oooo001:0?ooo`03
o`00003oool0oooo02h0oooo00Co00000?ooo`3ooooo00001`3oool01Ol00000oooo0?ooo`3ooooo
000000@0oooo00?o00000?ooo`3oool0@P3oool00ol00000oooo0?ooo`190?ooo`00BP3oool00ol0
0000oooo0?ooo`0^0?ooo`04o`00003oool0ooooo`0000L0oooo00Go00000?ooo`3oool0ooooo`00
00040?ooo`03o`00003oool0oooo0480oooo00?o00000?ooo`3oool0B@3oool004X0oooo00?o0000
0?ooo`3oool0;`3oool2o`0000T0oooo0ol000050?ooo`03o`00003oool0oooo0480oooo00?o0000
0?ooo`3oool0B@3oool004X0oooo00?o00000?ooo`3oool0@P3oool00ol00000oooo0?ooo`120?oo
o`03o`00003oool0oooo04T0oooo001;0?ooo`03o`00003oool0oooo0440oooo00?o00000?ooo`3o
ool0@P3oool00ol00000oooo0?ooo`190?ooo`00B`3oool00ol00000oooo0?ooo`110?ooo`03o`00
003oool0oooo0480oooo00?o00000?ooo`3oool0B@3oool004/0oooo00?o00000?ooo`3oool0@@3o
ool2o`0004<0oooo00?o00000?ooo`3oool0B@3oool004/0oooo00?o00000?ooo`3oool0@@3oool0
0ol00000oooo0?ooo`120?ooo`03o`00003oool0oooo04T0oooo001;0?ooo`03o`00003oool0oooo
0440oooo00?o00000?ooo`3oool0@P3oool00ol00000oooo0?ooo`190?ooo`00B`3oool00ol00000
oooo0?ooo`110?ooo`03o`00003oool0oooo0480oooo00?o00000?ooo`3oool0B@3oool004/0oooo
00?o00000?ooo`3oool0@@3oool00ol00000oooo0?ooo`120?ooo`03o`00003oool0oooo04T0oooo
001;0?ooo`03o`00003oool0oooo0440oooo00?o00000?ooo`3oool0@P3oool00ol00000oooo0?oo
o`190?ooo`00B`3oool00ol00000oooo0?ooo`110?ooo`03o`00003oool0oooo0440oooo00?o0000
0?ooo`3oool0BP3oool004/0oooo00?o00000?ooo`3oool0@@3oool00ol00000oooo0?ooo`110?oo
o`03o`00003oool0oooo04X0oooo001;0?ooo`03o`00003oool0oooo0440oooo0_l000120?ooo`03
o`00003oool0oooo04X0oooo001;0?ooo`03o`00003oool0oooo0440oooo00?o00000?ooo`3oool0
@@3oool00ol00000oooo0?ooo`1:0?ooo`00B`3oool00ol00000oooo0?ooo`110?ooo`03o`00003o
ool0oooo0440oooo00?o00000?ooo`3oool0BP3oool004/0oooo00?o00000?ooo`3oool0@@3oool0
0ol00000oooo0?ooo`110?ooo`03o`00003oool0oooo04X0oooo001;0?ooo`03o`00003oool0oooo
0440oooo00?o00000?ooo`3oool0@@3oool00ol00000oooo0?ooo`1:0?ooo`00B`3oool00ol00000
oooo0?ooo`110?ooo`03o`00003oool0oooo0440oooo00?o00000?ooo`3oool0BP3oool004/0oooo
00?o00000?ooo`3oool0@@3oool00ol00000oooo0?ooo`110?ooo`03o`00003oool0oooo04X0oooo
001<0?ooo`03o`00003oool0oooo0400oooo00?o00000?ooo`3oool0@@3oool00ol00000oooo0?oo
o`1:0?ooo`00C03oool00ol00000oooo0?ooo`100?ooo`;o0000@P3oool00ol00000oooo0?ooo`1:
0?ooo`00C03oool00ol00000oooo0?ooo`100?ooo`03o`00003oool0oooo0440oooo00?o00000?oo
o`3oool0BP3oool004`0oooo00?o00000?ooo`3oool0@03oool00ol00000oooo0?ooo`110?ooo`03
o`00003oool0oooo04X0oooo001<0?ooo`03o`00003oool0oooo0400oooo00?o00000?ooo`3oool0
@@3oool00ol00000oooo0?ooo`1:0?ooo`00C03oool00ol00000oooo0?ooo`100?ooo`03o`00003o
ool0oooo0440oooo00?o00000?ooo`3oool0BP3oool004`0oooo00?o00000?ooo`3oool0;@3oool2
o`0000@0oooo00?o00000?ooo`3oool00`3oool3o`0000@0oooo00?o00000?ooo`3oool0@@3oool0
0ol00000oooo0?ooo`1:0?ooo`00C03oool00ol00000oooo0?ooo`0/0?ooo`04o`00003oool0oooo
o`0000X0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`100?ooo`03o`00003oool0
oooo04/0oooo001<0?ooo`03o`00003oool0oooo02`0oooo00Co00000?ooo`3ooooo00001`3oool5
o`0000@0oooo00?o00000?ooo`3oool0@03oool00ol00000oooo0?ooo`1;0?ooo`00C03oool00ol0
0000oooo0?ooo`0/0?ooo`04o`00003oool0ooooo`0000L0oooo00Co00000?ooo`3ooooo00001@3o
ool3o`000400oooo00?o00000?ooo`3oool0B`3oool004`0oooo00?o00000?ooo`3oool0;03oool0
1?l00000oooo0?ooool000080?ooo`03o`00003ooooo000000D0oooo00?o00000?ooo`3oool0@03o
ool00ol00000oooo0?ooo`1;0?ooo`00C03oool00ol00000oooo0?ooo`0/0?ooo`04o`00003oool0
ooooo`0000T0oooo0_l000050?ooo`03o`00003oool0oooo0400oooo00?o00000?ooo`3oool0B`3o
ool004`0oooo00?o00000?ooo`3oool0;@3oool2o`0000/0oooo00?o00000?ooo`3oool00`3oool0
0ol00000oooo0?ooo`100?ooo`03o`00003oool0oooo04/0oooo001<0?ooo`03o`00003oool0oooo
0400oooo00?o00000?ooo`3oool0@03oool00ol00000oooo0?ooo`1;0?ooo`00C03oool00ol00000
oooo0?ooo`100?ooo`03o`00003oool0oooo0400oooo00?o00000?ooo`3oool0B`3oool004`0oooo
00?o00000?ooo`3oool0@03oool00ol00000oooo0?ooo`100?ooo`03o`00003oool0oooo04/0oooo
001<0?ooo`03o`00003oool0oooo0400oooo00?o00000?ooo`3oool0@03oool00ol00000oooo0?oo
o`1;0?ooo`00C@3oool00ol00000oooo0?ooo`0o0?ooo`;o0000@@3oool00ol00000oooo0?ooo`1;
0?ooo`00C@3oool00ol00000oooo0?ooo`0o0?ooo`03o`00003oool0oooo0400oooo00?o00000?oo
o`3oool0B`3oool004d0oooo00?o00000?ooo`3oool0?`3oool00ol00000oooo0?ooo`100?ooo`03
o`00003oool0oooo04/0oooo001=0?ooo`03o`00003oool0oooo03l0oooo00?o00000?ooo`3oool0
@03oool00ol00000oooo0?ooo`1;0?ooo`00C@3oool00ol00000oooo0?ooo`0o0?ooo`03o`00003o
ool0oooo0400oooo00?o00000?ooo`3oool0B`3oool004d0oooo00?o00000?ooo`3oool0?`3oool0
0ol00000oooo0?ooo`0o0?ooo`03o`00003oool0oooo04`0oooo001=0?ooo`03o`00003oool0oooo
03l0oooo00?o00000?ooo`3oool0?`3oool00ol00000oooo0?ooo`1<0?ooo`00C@3oool00ol00000
oooo0?ooo`0o0?ooo`;o0000@03oool00ol00000oooo0?ooo`1<0?ooo`00C@3oool00ol00000oooo
0?ooo`0o0?ooo`03o`00003oool0oooo03l0oooo00?o00000?ooo`3oool0C03oool004d0oooo00?o
00000?ooo`3oool0?`3oool00ol00000oooo0?ooo`0o0?ooo`03o`00003oool0oooo04`0oooo001=
0?ooo`03o`00003oool0oooo03l0oooo00?o00000?ooo`3oool0?`3oool00ol00000oooo0?ooo`1<
0?ooo`00C@3oool00ol00000oooo0?ooo`0o0?ooo`03o`00003oool0oooo03l0oooo00?o00000?oo
o`3oool0C03oool004d0oooo00?o00000?ooo`3oool0?`3oool00ol00000oooo0?ooo`0o0?ooo`03
o`00003oool0oooo04`0oooo001=0?ooo`03o`00003oool0oooo03l0oooo00?o00000?ooo`3oool0
?`3oool00ol00000oooo0?ooo`1<0?ooo`00C@3oool00ol00000oooo0?ooo`0o0?ooo`03o`00003o
ool0oooo03l0oooo00?o00000?ooo`3oool0C03oool004h0oooo00?o00000?ooo`3oool0?P3oool2
o`000400oooo00?o00000?ooo`3oool0C03oool004h0oooo00?o00000?ooo`3oool0?P3oool00ol0
0000oooo0?ooo`0o0?ooo`03o`00003oool0oooo04`0oooo001>0?ooo`03o`00003oool0oooo03h0
oooo00?o00000?ooo`3oool0?`3oool00ol00000oooo0?ooo`1<0?ooo`00CP3oool00ol00000oooo
0?ooo`0n0?ooo`03o`00003oool0oooo03l0oooo00?o00000?ooo`3oool0C03oool004h0oooo00?o
00000?ooo`3oool0?P3oool00ol00000oooo0?ooo`0o0?ooo`03o`00003oool0oooo04`0oooo001>
0?ooo`03o`00003oool0oooo03h0oooo00?o00000?ooo`3oool0?P3oool00ol00000oooo0?ooo`1=
0?ooo`00CP3oool00ol00000oooo0?ooo`0[0?ooo`;o0000103oool00ol00000oooo0?ooo`020?oo
o`?o00001@3oool00ol00000oooo0?ooo`0n0?ooo`03o`00003oool0oooo04d0oooo001>0?ooo`03
o`00003oool0oooo02X0oooo00Co00000?ooo`3ooooo00001`3oool01Ol00000oooo0?ooo`3ooooo
000000@0oooo00?o00000?ooo`3oool0?P3oool00ol00000oooo0?ooo`1=0?ooo`00CP3oool00ol0
0000oooo0?ooo`0Z0?ooo`04o`00003oool0ooooo`0000L0oooo00Go00000?ooo`3oool0ooooo`00
00040?ooo`?o0000?P3oool00ol00000oooo0?ooo`1=0?ooo`00CP3oool00ol00000oooo0?ooo`0Z
0?ooo`04o`00003oool0ooooo`0000L0oooo1?l000050?ooo`03o`00003oool0oooo03h0oooo00?o
00000?ooo`3oool0C@3oool004h0oooo00?o00000?ooo`3oool0:P3oool01?l00000oooo0?ooool0
00070?ooo`03o`00003oool0oooo00H0oooo00?o00000?ooo`3oool0?P3oool00ol00000oooo0?oo
o`1=0?ooo`00CP3oool00ol00000oooo0?ooo`0Z0?ooo`04o`00003oool0ooooo`0000P0oooo00?o
00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0n0?ooo`03o`00003oool0oooo04d0oooo001>
0?ooo`03o`00003oool0oooo02/0oooo0_l0000:0?ooo`;o00001@3oool00ol00000oooo0?ooo`0n
0?ooo`03o`00003oool0oooo04d0oooo001>0?ooo`03o`00003oool0oooo03h0oooo00?o00000?oo
o`3oool0?P3oool00ol00000oooo0?ooo`1=0?ooo`00CP3oool00ol00000oooo0?ooo`0n0?ooo`03
o`00003oool0oooo03h0oooo00?o00000?ooo`3oool0C@3oool004l0oooo00?o00000?ooo`3oool0
?@3oool00ol00000oooo0?ooo`0n0?ooo`03o`00003oool0oooo04d0oooo001?0?ooo`03o`00003o
ool0oooo03d0oooo0_l0000o0?ooo`03o`00003oool0oooo04d0oooo001?0?ooo`03o`00003oool0
oooo03d0oooo00?o00000?ooo`3oool0?P3oool00ol00000oooo0?ooo`1=0?ooo`00C`3oool00ol0
0000oooo0?ooo`0m0?ooo`03o`00003oool0oooo03h0oooo00?o00000?ooo`3oool0C@3oool004l0
oooo00?o00000?ooo`3oool0?@3oool00ol00000oooo0?ooo`0n0?ooo`03o`00003oool0oooo04d0
oooo001?0?ooo`03o`00003oool0oooo03d0oooo00?o00000?ooo`3oool0?P3oool00ol00000oooo
0?ooo`1=0?ooo`00C`3oool00ol00000oooo0?ooo`0m0?ooo`03o`00003oool0oooo03h0oooo00?o
00000?ooo`3oool0C@3oool004l0oooo00?o00000?ooo`3oool0?@3oool00ol00000oooo0?ooo`0n
0?ooo`03o`00003oool0oooo04d0oooo001?0?ooo`03o`00003oool0oooo03d0oooo00?o00000?oo
o`3oool0?@3oool00ol00000oooo0?ooo`1>0?ooo`00C`3oool00ol00000oooo0?ooo`0m0?ooo`;o
0000?P3oool00ol00000oooo0?ooo`1>0?ooo`00C`3oool00ol00000oooo0?ooo`0m0?ooo`03o`00
003oool0oooo03d0oooo00?o00000?ooo`3oool0CP3oool004l0oooo00?o00000?ooo`3oool0?@3o
ool00ol00000oooo0?ooo`0m0?ooo`03o`00003oool0oooo04h0oooo001?0?ooo`03o`00003oool0
oooo03d0oooo00?o00000?ooo`3oool0?@3oool00ol00000oooo0?ooo`1>0?ooo`00C`3oool00ol0
0000oooo0?ooo`0m0?ooo`03o`00003oool0oooo03d0oooo00?o00000?ooo`3oool0CP3oool004l0
oooo00?o00000?ooo`3oool0?@3oool00ol00000oooo0?ooo`0m0?ooo`03o`00003oool0oooo04h0
oooo001?0?ooo`03o`00003oool0oooo03d0oooo00?o00000?ooo`3oool0?@3oool00ol00000oooo
0?ooo`1>0?ooo`00C`3oool00ol00000oooo0?ooo`0m0?ooo`03o`00003oool0oooo03d0oooo00?o
00000?ooo`3oool0CP3oool00500oooo00?o00000?ooo`3oool0?03oool2o`0003h0oooo00?o0000
0?ooo`3oool0CP3oool00500oooo00?o00000?ooo`3oool0?03oool00ol00000oooo0?ooo`0m0?oo
o`03o`00003oool0oooo04h0oooo001@0?ooo`03o`00003oool0oooo03`0oooo00?o00000?ooo`3o
ool0?@3oool00ol00000oooo0?ooo`1>0?ooo`00D03oool00ol00000oooo0?ooo`0l0?ooo`03o`00
003oool0oooo03d0oooo00?o00000?ooo`3oool0CP3oool00500oooo00?o00000?ooo`3oool0?03o
ool00ol00000oooo0?ooo`0m0?ooo`03o`00003oool0oooo04h0oooo001@0?ooo`03o`00003oool0
oooo02T0oooo0_l000040?ooo`03o`00003oool0oooo0080oooo0ol000050?ooo`03o`00003oool0
oooo03d0oooo00?o00000?ooo`3oool0CP3oool00500oooo00?o00000?ooo`3oool0:03oool01?l0
0000oooo0?ooool000070?ooo`05o`00003oool0oooo0?ooool00000103oool00ol00000oooo0?oo
o`0l0?ooo`03o`00003oool0oooo04l0oooo001@0?ooo`03o`00003oool0oooo02P0oooo00Co0000
0?ooo`3ooooo00001`3oool01Ol00000oooo0?ooo`3ooooo000000@0oooo00?o00000?ooo`3oool0
?03oool00ol00000oooo0?ooo`1?0?ooo`00D03oool00ol00000oooo0?ooo`0X0?ooo`04o`00003o
ool0ooooo`0000P0oooo0ol000050?ooo`?o0000?03oool00ol00000oooo0?ooo`1?0?ooo`00D03o
ool00ol00000oooo0?ooo`0X0?ooo`04o`00003oool0ooooo`0000L0oooo00Go00000?ooo`3oool0
ooooo`0000040?ooo`03o`00003oool0oooo03`0oooo00?o00000?ooo`3oool0C`3oool00500oooo
00?o00000?ooo`3oool0:03oool01?l00000oooo0?ooool000070?ooo`05o`00003oool0oooo0?oo
ool00000103oool00ol00000oooo0?ooo`0l0?ooo`03o`00003oool0oooo04l0oooo001@0?ooo`03
o`00003oool0oooo02T0oooo0_l000090?ooo`?o00001@3oool00ol00000oooo0?ooo`0l0?ooo`03
o`00003oool0oooo04l0oooo001@0?ooo`03o`00003oool0oooo03`0oooo00?o00000?ooo`3oool0
?03oool00ol00000oooo0?ooo`1?0?ooo`00D03oool00ol00000oooo0?ooo`0l0?ooo`03o`00003o
ool0oooo03`0oooo00?o00000?ooo`3oool0C`3oool00540oooo00?o00000?ooo`3oool0>`3oool0
0ol00000oooo0?ooo`0l0?ooo`03o`00003oool0oooo04l0oooo001A0?ooo`03o`00003oool0oooo
03/0oooo0_l0000l0?ooo`03o`00003oool0oooo0500oooo001A0?ooo`03o`00003oool0oooo03/0
oooo00?o00000?ooo`3oool0>`3oool00ol00000oooo0?ooo`1@0?ooo`00D@3oool00ol00000oooo
0?ooo`0k0?ooo`03o`00003oool0oooo03/0oooo00?o00000?ooo`3oool0D03oool00540oooo00?o
00000?ooo`3oool0>`3oool00ol00000oooo0?ooo`0k0?ooo`03o`00003oool0oooo0500oooo001A
0?ooo`03o`00003oool0oooo03/0oooo00?o00000?ooo`3oool0>`3oool00ol00000oooo0?ooo`1@
0?ooo`00D@3oool00ol00000oooo0?ooo`0k0?ooo`03o`00003oool0oooo03/0oooo00?o00000?oo
o`3oool0D03oool00540oooo00?o00000?ooo`3oool0>`3oool00ol00000oooo0?ooo`0k0?ooo`03
o`00003oool0oooo0500oooo001A0?ooo`03o`00003oool0oooo03/0oooo00?o00000?ooo`3oool0
>`3oool00ol00000oooo0?ooo`1@0?ooo`00D@3oool00ol00000oooo0?ooo`0k0?ooo`;o0000?03o
ool00ol00000oooo0?ooo`1@0?ooo`00D@3oool00ol00000oooo0?ooo`0k0?ooo`03o`00003oool0
oooo03/0oooo00?o00000?ooo`3oool0D03oool00540oooo00?o00000?ooo`3oool0>`3oool00ol0
0000oooo0?ooo`0k0?ooo`03o`00003oool0oooo0500oooo001A0?ooo`03o`00003oool0oooo03/0
oooo00?o00000?ooo`3oool0>P3oool00ol00000oooo0?ooo`1A0?ooo`00D@3oool00ol00000oooo
0?ooo`0k0?ooo`03o`00003oool0oooo03X0oooo00?o00000?ooo`3oool0D@3oool00540oooo00?o
00000?ooo`3oool0>`3oool00ol00000oooo0?ooo`0j0?ooo`03o`00003oool0oooo0540oooo001A
0?ooo`03o`00003oool0oooo03/0oooo00?o00000?ooo`3oool0>P3oool00ol00000oooo0?ooo`1A
0?ooo`00DP3oool00ol00000oooo0?ooo`0j0?ooo`03o`00003oool0oooo03X0oooo00?o00000?oo
o`3oool0D@3oool00580oooo00?o00000?ooo`3oool0>P3oool2o`0003/0oooo00?o00000?ooo`3o
ool0D@3oool00580oooo00?o00000?ooo`3oool0=P3oool9o`0003P0oooo00?o00000?ooo`3oool0
D@3oool00580oooo00?o00000?ooo`3oool09P3oool@o`0000<0oooo0ol000030?oooa7o00009`3o
ool00ol00000oooo0?ooo`1A0?ooo`00DP3oool00ol00000oooo0?ooo`0L0?ooo`[o0000503oool0
0ol00000oooo0?ooo`0C0?ooo`So00007`3oool00ol00000oooo0?ooo`1A0?ooo`00D`3oool00ol0
0000oooo0?ooo`0E0?ooo`Ko00007P3oool00ol00000oooo0?ooo`0K0?ooo`So00005`3oool00ol0
0000oooo0?ooo`1A0?ooo`00D`3oool00ol00000oooo0?ooo`0?0?ooo`Ko0000703oool3o`0000D0
oooo00?o00000?ooo`3oool08`3oool6o`000100oooo00?o00000?ooo`3oool0DP3oool005<0oooo
00?o00000?ooo`3oool02P3oool5o`0002<0oooo00?o00000?ooo`3oool0103oool00ol00000oooo
0?ooo`0Y0?ooo`Go00002`3oool00ol00000oooo0?ooo`1B0?ooo`00D`3oool00ol00000oooo0?oo
o`070?ooo`?o0000:03oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo02h0oooo0ol0
00080?ooo`03o`00003oool0oooo0580oooo001C0?ooo`03o`00003oool0oooo00@0oooo0ol0000[
0?ooo`03o`00003oool0oooo00@0oooo0ol0000a0?ooo`;o00001P3oool00ol00000oooo0?ooo`1B
0?ooo`00E03oool00ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo02`0oooo00?o00000?oo
o`3oool0103oool00ol00000oooo0?ooo`0c0?ooo`;o0000103oool00ol00000oooo0?ooo`1B0?oo
o`00E03oool01Ol00000oooo0?ooo`3ooooo000002h0oooo0_l000060?ooo`03o`00003oool0oooo
03D0oooo00Co00000?ooo`3ooooo0000E@3oool005@0oooo1?l0000`0?ooo`03o`00003oool0oooo
00@0oooo00?o00000?ooo`3oool0=@3oool4o`0005D0oooo002?0?ooo`03o`00003oool0oooo08h0
oooo002?0?ooo`03o`00003oool0oooo08h0oooo002?0?ooo`03o`00003oool0oooo08h0oooo002?
0?ooo`03o`00003oool0oooo08h0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.10503, -0.0790693, \
0.00770057, 0.00637227}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell["\<\
The numeric PSF is again consistent, but with a great deal of high frequency \
ringing present.\
\>", "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
psf = PointSpreadFunction/.PSF[{
\tMove[LineOfRays[10],-50],
\tPlanoConvexLens[100,50,10],
\tMove[Screen[50],93]},NumberOfPoints->4096,PaddingFactor->10];\
\>", "Input",
  CellLabel->"In[79]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952153 0.603319 0.0220632 [
[.11914 -0.0125 -6 -9 ]
[.11914 -0.0125 6 0 ]
[.30957 -0.0125 -6 -9 ]
[.30957 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69043 -0.0125 -3 -9 ]
[.69043 -0.0125 3 0 ]
[.88086 -0.0125 -3 -9 ]
[.88086 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05174 -18 -4.5 ]
[-0.0125 .05174 0 4.5 ]
[-0.0125 .16205 -18 -4.5 ]
[-0.0125 .16205 0 4.5 ]
[-0.0125 .27237 -18 -4.5 ]
[-0.0125 .27237 0 4.5 ]
[-0.0125 .38269 -18 -4.5 ]
[-0.0125 .38269 0 4.5 ]
[-0.0125 .493 -12 -4.5 ]
[-0.0125 .493 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11914 0 m
.11914 .00625 L
s
[(-4)] .11914 -0.0125 0 1 Mshowa
.30957 0 m
.30957 .00625 L
s
[(-2)] .30957 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69043 0 m
.69043 .00625 L
s
[(2)] .69043 -0.0125 0 1 Mshowa
.88086 0 m
.88086 .00625 L
s
[(4)] .88086 -0.0125 0 1 Mshowa
.125 Mabswid
.16675 0 m
.16675 .00375 L
s
.21435 0 m
.21435 .00375 L
s
.26196 0 m
.26196 .00375 L
s
.35718 0 m
.35718 .00375 L
s
.40478 0 m
.40478 .00375 L
s
.45239 0 m
.45239 .00375 L
s
.54761 0 m
.54761 .00375 L
s
.59522 0 m
.59522 .00375 L
s
.64282 0 m
.64282 .00375 L
s
.73804 0 m
.73804 .00375 L
s
.78565 0 m
.78565 .00375 L
s
.83325 0 m
.83325 .00375 L
s
.07153 0 m
.07153 .00375 L
s
.02392 0 m
.02392 .00375 L
s
.92847 0 m
.92847 .00375 L
s
.97608 0 m
.97608 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05174 m
.00625 .05174 L
s
[(-25)] -0.0125 .05174 1 0 Mshowa
0 .16205 m
.00625 .16205 L
s
[(-20)] -0.0125 .16205 1 0 Mshowa
0 .27237 m
.00625 .27237 L
s
[(-15)] -0.0125 .27237 1 0 Mshowa
0 .38269 m
.00625 .38269 L
s
[(-10)] -0.0125 .38269 1 0 Mshowa
0 .493 m
.00625 .493 L
s
[(-5)] -0.0125 .493 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .0738 m
.00375 .0738 L
s
0 .09586 m
.00375 .09586 L
s
0 .11793 m
.00375 .11793 L
s
0 .13999 m
.00375 .13999 L
s
0 .18412 m
.00375 .18412 L
s
0 .20618 m
.00375 .20618 L
s
0 .22824 m
.00375 .22824 L
s
0 .25031 m
.00375 .25031 L
s
0 .29443 m
.00375 .29443 L
s
0 .3165 m
.00375 .3165 L
s
0 .33856 m
.00375 .33856 L
s
0 .36062 m
.00375 .36062 L
s
0 .40475 m
.00375 .40475 L
s
0 .42681 m
.00375 .42681 L
s
0 .44888 m
.00375 .44888 L
s
0 .47094 m
.00375 .47094 L
s
0 .51507 m
.00375 .51507 L
s
0 .53713 m
.00375 .53713 L
s
0 .55919 m
.00375 .55919 L
s
0 .58126 m
.00375 .58126 L
s
0 .02967 m
.00375 .02967 L
s
0 .00761 m
.00375 .00761 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11914 .61178 m
.11914 .61803 L
s
.30957 .61178 m
.30957 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69043 .61178 m
.69043 .61803 L
s
.88086 .61178 m
.88086 .61803 L
s
.125 Mabswid
.16675 .61428 m
.16675 .61803 L
s
.21435 .61428 m
.21435 .61803 L
s
.26196 .61428 m
.26196 .61803 L
s
.35718 .61428 m
.35718 .61803 L
s
.40478 .61428 m
.40478 .61803 L
s
.45239 .61428 m
.45239 .61803 L
s
.54761 .61428 m
.54761 .61803 L
s
.59522 .61428 m
.59522 .61803 L
s
.64282 .61428 m
.64282 .61803 L
s
.73804 .61428 m
.73804 .61803 L
s
.78565 .61428 m
.78565 .61803 L
s
.83325 .61428 m
.83325 .61803 L
s
.07153 .61428 m
.07153 .61803 L
s
.02392 .61428 m
.02392 .61803 L
s
.92847 .61428 m
.92847 .61803 L
s
.97608 .61428 m
.97608 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05174 m
1 .05174 L
s
.99375 .16205 m
1 .16205 L
s
.99375 .27237 m
1 .27237 L
s
.99375 .38269 m
1 .38269 L
s
.99375 .493 m
1 .493 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .0738 m
1 .0738 L
s
.99625 .09586 m
1 .09586 L
s
.99625 .11793 m
1 .11793 L
s
.99625 .13999 m
1 .13999 L
s
.99625 .18412 m
1 .18412 L
s
.99625 .20618 m
1 .20618 L
s
.99625 .22824 m
1 .22824 L
s
.99625 .25031 m
1 .25031 L
s
.99625 .29443 m
1 .29443 L
s
.99625 .3165 m
1 .3165 L
s
.99625 .33856 m
1 .33856 L
s
.99625 .36062 m
1 .36062 L
s
.99625 .40475 m
1 .40475 L
s
.99625 .42681 m
1 .42681 L
s
.99625 .44888 m
1 .44888 L
s
.99625 .47094 m
1 .47094 L
s
.99625 .51507 m
1 .51507 L
s
.99625 .53713 m
1 .53713 L
s
.99625 .55919 m
1 .55919 L
s
.99625 .58126 m
1 .58126 L
s
.99625 .02967 m
1 .02967 L
s
.99625 .00761 m
1 .00761 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .01472 Mdot
.05454 .08761 Mdot
.08528 .15582 Mdot
.11601 .21932 Mdot
.14674 .27805 Mdot
.17746 .332 Mdot
.20819 .38114 Mdot
.23891 .42544 Mdot
.26963 .46487 Mdot
.30035 .49942 Mdot
.33106 .52907 Mdot
.36178 .5538 Mdot
.3925 .5736 Mdot
.42321 .58845 Mdot
.45393 .59836 Mdot
.48464 .60332 Mdot
.51536 .60332 Mdot
.54607 .59836 Mdot
.57679 .58845 Mdot
.6075 .5736 Mdot
.63822 .5538 Mdot
.66894 .52907 Mdot
.69965 .49942 Mdot
.73037 .46487 Mdot
.76109 .42544 Mdot
.79181 .38114 Mdot
.82254 .332 Mdot
.85326 .27805 Mdot
.88399 .21932 Mdot
.91472 .15582 Mdot
.94546 .08761 Mdot
.97619 .01472 Mdot
.5 Mabswid
.02381 .01472 m
.03853 .04962 L
.05458 .08769 L
.06965 .12115 L
.08415 .15333 L
.09958 .18538 L
.11444 .21607 L
.13023 .2465 L
.14544 .27557 L
.16007 .30147 L
.17564 .32881 L
.19063 .35307 L
.20504 .37612 L
.22039 .39874 L
.23516 .42004 L
.25087 .44079 L
.26599 .46021 L
.28054 .47715 L
.29603 .49456 L
.31093 .50964 L
.32678 .52493 L
.34204 .5379 L
.35672 .54973 L
.37234 .56061 L
.38739 .5703 L
.40185 .57812 L
.41725 .58557 L
.43208 .59131 L
.43962 .59375 L
.44783 .5964 L
.45165 .59763 L
.45266 .59795 L
.45319 .59813 L
.45348 .59822 L
.45375 .59831 L
.45424 .59841 L
.45478 .5985 L
.45572 .59865 L
.45918 .59921 L
.46301 .59983 L
.47789 .60223 L
.48179 .60286 L
.48286 .60303 L
.48344 .60312 L
.48399 .60321 L
.48445 .60329 L
.48495 .60332 L
.48524 .60332 L
.48551 .60332 L
.48602 .60332 L
Mistroke
.49369 .60332 L
.50134 .60332 L
.50826 .60332 L
.51012 .60332 L
.51213 .60332 L
.51306 .60332 L
.51403 .60332 L
.51486 .60332 L
.51533 .60332 L
.51577 .60325 L
.52377 .60196 L
.53861 .59957 L
.5425 .59894 L
.54454 .59861 L
.54508 .59852 L
.54566 .59843 L
.54593 .59839 L
.54621 .59832 L
.54672 .59815 L
.54861 .59754 L
.5507 .59687 L
.55439 .59568 L
.56892 .59099 L
.5844 .58477 L
.59929 .57757 L
.61512 .56869 L
.63037 .55886 L
.64504 .5483 L
.66065 .53574 L
.67568 .52256 L
.69013 .50861 L
.70552 .49282 L
.72033 .47616 L
.73608 .45755 L
.75124 .43808 L
.76583 .4186 L
.78136 .39622 L
.7963 .37396 L
.81067 .35098 L
.82597 .32597 L
.8407 .30011 L
.85636 .27213 L
.87144 .2433 L
.88595 .21527 L
.90139 .18337 L
.91625 .15243 L
.93205 .11737 L
.94727 .08332 L
.96191 .04859 L
.97619 .01472 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[79]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?Oooool3o`0002[ooooo1Ol0000Yooooo`;o0000;?ooool5o`0002cooooo0ol0000Voooo
o`00?_ooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`0002Sooooo00Co0000oooo
oooooooo0000;?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02Gooooo000e
ooooo`Go000000?oooooo`000?l000000ol0000Tooooo`Go00000oooool00ol0003oooooooooo`0X
ooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0:_ooool5o`0002Kooooo000k
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool09oooool01?l0003ooooooooo
ool0000^ooooo`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo00009oooool003cooooo
00?o0000ooooool00000:oooool01Ol0003ooooooooooooooooo000002Sooooo00Co0000oooooooo
oooo0000:oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooool000009oooool0
03gooooo0_l0000[ooooo`05o`000?ooooooooooooooool00000:?ooool01?l0003oooooooooool0
000[ooooo`05o`000?ooooooooooooooool00000;?ooool2o`0002Oooooo000nooooo`03o`000?oo
oooooooo02[ooooo0ol0000Zooooo`;o0000;Oooool3o`0002kooooo00?o0000ooooooooool09Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool001kooooon?l0
000:ooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Noooo
o`;o0000NOooool00ol0003oooooooooo`1hooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool00_ooool2o`0007Cooooo00?o0000ooooooooool0L_ooool2o`0000Gooooo00?o0000oooooooo
ool02?ooool001kooooo00?o0000ooooooooool00_ooool2o`0007Cooooo00?o0000ooooooooool0
L_ooool2o`0000Gooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o00001Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool00oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`003oooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02?ooool0013ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool5o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o00001ooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01Ooo
ool2o`0000[ooooo000Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000?ooooo`06o`000?oooooooooo
ooooool0003ooooo1?l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool000oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`004?ooool3o`0000;ooooo1Ol00004ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`007_ooool2o`0000Wooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool02_ooool2o`0006cooooo00?o
0000ooooooooool0Joooool2o`0000cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool02_ooool2o`0006cooooo00?o0000ooooooooool0Joooool2o`0000cooooo00?o0000
ooooooooool02?ooool001kooooo0_l0000<ooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool0Joooool00ol0003oooooooooo`0:ooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06[ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo06Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0JOoo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?oo
ool001kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo06Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00003_ooool00ol0003o
ooooooooo`1Xooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool03Oooool2o`0000[o
oooo000Nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool001kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool02?ooool001kooooo0_l0000Aooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool0I_ooool00ol0003oooooooooo`0?ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Sooooo000?ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool04Oooool2o`0006Gooooo00?o0000ooooooooool0Hooo
ool2o`0001Cooooo00?o0000ooooooooool02?ooool000Wooooo1Ol00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Aooooo`;o0000IOoo
ool00ol0003oooooooooo`1Sooooo`;o00005?ooool00ol0003oooooooooo`08ooooo`004_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool2o`0001Cooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01;ooooo0_l0
000:ooooo`003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo000?ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool02?ooool0013ooooo0ol00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool02?ooool001kooooo0_l0000Gooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`0Dooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00006Oooool00ol0
003oooooooooo`1Mooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool05oooool2o`00
00[ooooo000Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0GOooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooooooo
o`0Iooooo`;o0000GOooool00ol0003oooooooooo`1Looooo`;o00006oooool00ol0003ooooooooo
o`08ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000GOooool00ol0003oooooooooo`1L
ooooo`;o00006oooool00ol0003oooooooooo`08ooooo`007_ooool2o`0001_ooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01Wooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Jooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool001ko
oooo0_l0000Nooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`0Mooooo`;o00002_ooool001kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`08ooooo`004?ooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0Eoooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool02?ooool0017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Fooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`002Oooool5
o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool02?ooool0017ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`;o00008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool07oooool2o`0000[ooooo000Aooooo`04o`000?oooooooooooooo
o`Co00001Oooool00ol0003oooooooooo`0Pooooo`;o0000E_ooool00ol0003oooooooooo`1Doooo
o`?o00008_ooool00ol0003oooooooooo`08ooooo`004?ooool2o`0000?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Pooooo`;o0000E_ooool00ol0003oooooooooo`1Dooooo`;o
00008oooool00ol0003oooooooooo`08ooooo`004Oooool01?l0003oooooooooooooool5o`0000Co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o00009?ooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool08_ooool2o`0000[ooooo000N
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1C
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`007_ooool2
o`0002Oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1@ooooo`03o`000?oooooo
oooo02Gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00Sooooo000Nooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02?ooool001kooooo
00?o0000ooooooooool0:?ooool2o`0004kooooo00?o0000ooooooooool0COooool2o`0002[ooooo
00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0:?ooool2o`0004kooooo00?o
0000ooooooooool0COooool2o`0002[ooooo00?o0000ooooooooool02?ooool001kooooo0_l0000Z
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Y
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo04cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`08oooo
o`007_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`;o0000;_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0;?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`08ooooo`004?ooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool02?ooool0017ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02?ooool000Wooooo1Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool2o`00037ooooo0_l0
0016ooooo`03o`000?oooooooooo04Gooooo0_l0000aooooo`;o00002_ooool0017ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo033ooooo0_l0
0016ooooo`03o`000?oooooooooo04Gooooo0_l0000booooo`03o`000?oooooooooo00Sooooo000A
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Sooooo000@ooooo`;o00001?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02?ooool0017ooooo00?o0000
ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`08
ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Sooooo000Nooooo`;o
0000=Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0<oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
2?ooool001kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`007_ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo
03Oooooo0_l0000oooooo`03o`000?oooooooooo03gooooo0ol0000iooooo`03o`000?oooooooooo
00Sooooo000Nooooo`;o0000>?ooool2o`0003oooooo00?o0000ooooooooool0?Oooool2o`0003Wo
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Sooooo
000Nooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?ooool001kooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool02?ooool001kooooo0_l0000nooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0kooooo`;o00002_ooool001kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000gooooo`03o`000?oooooooooo
03Kooooo0_l00011ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo03oo
oooo0_l0000gooooo`03o`000?oooooooooo03Kooooo0_l00011ooooo`03o`000?oooooooooo00So
oooo000Nooooo`;o0000@_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0@?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`08
ooooo`005_ooool3o`0000Gooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`08oooo
o`005Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`08ooooo`003oooool5o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo00Sooooo000Iooooo`03o`000?oooooooooo00;ooooo
0_l00017ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`16ooooo`;o00002_ooool001Gooooo1?l00005ooooo`03o`000?oooooooooo04Kooooo0_l0
000`ooooo`03o`000?oooooooooo02kooooo0_l00019ooooo`03o`000?oooooooooo00Sooooo000E
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A_ooool3o`0002oooooo00?o0000
ooooooooool0;Oooool3o`0004Wooooo00?o0000ooooooooool02?ooool001Gooooo1Ol00004oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooooooo
ool0B_ooool2o`0002cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo00Sooooo000Nooooo`;o0000COooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0B_ooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo0_l0001?ooooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000Xooooo`03o`000?oooooooooo
02Oooooo0_l0001@ooooo`03o`000?oooooooooo00Sooooo000Nooooo`03o`000?oooooooooo04ko
oooo0_l0000Xooooo`03o`000?oooooooooo02Kooooo0ol0001@ooooo`03o`000?oooooooooo00So
oooo000Nooooo`;o0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo
0_l0001Booooo`;o00002_ooool001kooooo00?o0000ooooooooool0DOooool2o`0002Gooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Sooooo000N
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02?ooool001kooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1Eooooo`?o
00008?ooool00ol0003oooooooooo`0Oooooo`;o0000F?ooool00ol0003oooooooooo`08ooooo`00
7_ooool00ol0003oooooooooo`1Fooooo`?o00007oooool00ol0003oooooooooo`0Oooooo`;o0000
F?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`0005[ooooo0_l0000Mooooo`03o`000?oo
oooooooo01gooooo0_l0001Iooooo`;o00002_ooool001kooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo0_l0001Looooo`03o`000?oooooo
oooo00Sooooo000Nooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`;o0000G_ooool00ol0003oooooooooo`08ooooo`007_ooool00ol0003o
ooooooooo`1Mooooo`;o00006Oooool00ol0003oooooooooo`0Gooooo`;o0000H?ooool00ol0003o
ooooooooo`08ooooo`007_ooool00ol0003oooooooooo`1Mooooo`?o00006?ooool00ol0003ooooo
ooooo`0Eooooo`Co0000H?ooool00ol0003oooooooooo`08ooooo`007_ooool2o`00067ooooo0ol0
000Eooooo`03o`000?oooooooooo01?ooooo0_l0001Sooooo`;o00002_ooool001kooooo00?o0000
ooooooooool0Hoooool3o`0001;ooooo00?o0000ooooooooool04Oooool2o`0006Kooooo00?o0000
ooooooooool02?ooool001kooooo00?o0000ooooooooool0IOooool3o`00013ooooo00?o0000oooo
ooooool04?ooool2o`0006Oooooo00?o0000ooooooooool02?ooool001Oooooo0_l00005ooooo`03
o`000?oooooooooo06Gooooo0_l000000ooooooo0000o`000002o`0000cooooo00?o0000oooooooo
ool03Oooool5o`0006Oooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`1/ooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`Go
0000K?ooool00ol0003oooooooooo`08ooooo`005_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo06cooooo1_l00002ooooo`;o00000_ooool01?l0003oooooooooooooool9o`00
06oooooo00?o0000ooooooooool02?ooool001Kooooo00Co0000oooooooooooo00001?ooool2o`00
07?ooooo3?l0001eooooo`;o00002_ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02?ooool001Ko
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo000Gooooo`;o00001Ooooooho`0000[ooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo000`ooooo`?o0000R_ooool00ol0003oooooooooo`0[ooooo`?o00005Oooool00ol0
003oooooooooo`0Jooooo`00<Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Iooooo`00:oooool3o`0000?ooooo
0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l00000
0ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001_ooool4o`0000;ooooo
1Ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo
0ol00004ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`?o00000oooool3o`0000Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`Co00000oooool00ol0003o
ooooooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0
003ooooo1?l00003ooooo`;o00000_ooool:o`0000Gooooo00?o0000ooooooooool06?ooool002[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool00000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooo`00000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool01?l0
003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool06?ooool002[ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`Go00000_oo
ool01_l0003oooooooooool0003oooooo`0000Gooooo1Ol00008ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooool0003oooooo`000002ooooo`?o00000oooool00ol0003oooooo`000002oooo
o`Go00000oooool01?l0003oooooooooooooool5o`0000;ooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00000_ooool3o`00
00Gooooo00?o0000ooooooooool06?ooool002[ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Sooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool0
1ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooool000000oooool01?l0003oooooooooool00005ooooo`06o`000?ooooooooooo`000?oooooo
00002?ooool00ol0003oooooooooo`0Hooooo`00:_ooool01_l0003ooooooooooooooooo0000oooo
o`Co00000_ooool4o`0000;ooooo0ol00004ooooo`?o00000oooool2o`0000Gooooo00?o0000oooo
ooooool02?ooool01?l0003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00009
ooooo`05o`000?ooooooooooo`000?ooool00ol00004ooooo`Co00000_ooool4o`0000;ooooo0ol0
0002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l00003ooooo`?o00000ooo
ool3o`0000Wooooo00?o0000ooooooooool00_ooool6o`000003ooooool0003o000000?ooooo0_l0
00000ooooooo0000o`000002ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00000_oo
ool4o`0000?ooooo2Ol00003ooooo`?o00000oooool4o`0000Cooooo00?o0000ooooooooool06?oo
ool002[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wo
oooo000[ooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo
0ol00009ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool4o`0000Cooooo
00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0000^ooooo`03o`000?oooooooooo01Sooooo
0ol0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000;ooooo`03o`000?oooooooooo01[ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.54294, -29.5621, \
0.0424915, 0.183375}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.682323 0.00873659 0.495475 [
[.09061 -0.00376 -12 -9 ]
[.09061 -0.00376 12 0 ]
[.22707 -0.00376 -12 -9 ]
[.22707 -0.00376 12 0 ]
[.36354 -0.00376 -12 -9 ]
[.36354 -0.00376 12 0 ]
[.5 -0.00376 -3 -9 ]
[.5 -0.00376 3 0 ]
[.63646 -0.00376 -9 -9 ]
[.63646 -0.00376 9 0 ]
[.77293 -0.00376 -9 -9 ]
[.77293 -0.00376 9 0 ]
[.90939 -0.00376 -9 -9 ]
[.90939 -0.00376 9 0 ]
[.01131 .10783 -18 -4.5 ]
[.01131 .10783 0 4.5 ]
[.01131 .20693 -18 -4.5 ]
[.01131 .20693 0 4.5 ]
[.01131 .30602 -18 -4.5 ]
[.01131 .30602 0 4.5 ]
[.01131 .40512 -18 -4.5 ]
[.01131 .40512 0 4.5 ]
[.01131 .50421 -6 -4.5 ]
[.01131 .50421 0 4.5 ]
[.01131 .60331 -18 -4.5 ]
[.01131 .60331 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09061 .00874 m
.09061 .01499 L
s
[(-0.6)] .09061 -0.00376 0 1 Mshowa
.22707 .00874 m
.22707 .01499 L
s
[(-0.4)] .22707 -0.00376 0 1 Mshowa
.36354 .00874 m
.36354 .01499 L
s
[(-0.2)] .36354 -0.00376 0 1 Mshowa
.5 .00874 m
.5 .01499 L
s
[(0)] .5 -0.00376 0 1 Mshowa
.63646 .00874 m
.63646 .01499 L
s
[(0.2)] .63646 -0.00376 0 1 Mshowa
.77293 .00874 m
.77293 .01499 L
s
[(0.4)] .77293 -0.00376 0 1 Mshowa
.90939 .00874 m
.90939 .01499 L
s
[(0.6)] .90939 -0.00376 0 1 Mshowa
.125 Mabswid
.12472 .00874 m
.12472 .01249 L
s
.15884 .00874 m
.15884 .01249 L
s
.19295 .00874 m
.19295 .01249 L
s
.26119 .00874 m
.26119 .01249 L
s
.2953 .00874 m
.2953 .01249 L
s
.32942 .00874 m
.32942 .01249 L
s
.39765 .00874 m
.39765 .01249 L
s
.43177 .00874 m
.43177 .01249 L
s
.46588 .00874 m
.46588 .01249 L
s
.53412 .00874 m
.53412 .01249 L
s
.56823 .00874 m
.56823 .01249 L
s
.60235 .00874 m
.60235 .01249 L
s
.67058 .00874 m
.67058 .01249 L
s
.7047 .00874 m
.7047 .01249 L
s
.73881 .00874 m
.73881 .01249 L
s
.80705 .00874 m
.80705 .01249 L
s
.84116 .00874 m
.84116 .01249 L
s
.87528 .00874 m
.87528 .01249 L
s
.05649 .00874 m
.05649 .01249 L
s
.02237 .00874 m
.02237 .01249 L
s
.94351 .00874 m
.94351 .01249 L
s
.97763 .00874 m
.97763 .01249 L
s
.25 Mabswid
0 .00874 m
1 .00874 L
s
.02381 .10783 m
.03006 .10783 L
s
[(0.2)] .01131 .10783 1 0 Mshowa
.02381 .20693 m
.03006 .20693 L
s
[(0.4)] .01131 .20693 1 0 Mshowa
.02381 .30602 m
.03006 .30602 L
s
[(0.6)] .01131 .30602 1 0 Mshowa
.02381 .40512 m
.03006 .40512 L
s
[(0.8)] .01131 .40512 1 0 Mshowa
.02381 .50421 m
.03006 .50421 L
s
[(1)] .01131 .50421 1 0 Mshowa
.02381 .60331 m
.03006 .60331 L
s
[(1.2)] .01131 .60331 1 0 Mshowa
.125 Mabswid
.02381 .03351 m
.02756 .03351 L
s
.02381 .05828 m
.02756 .05828 L
s
.02381 .08306 m
.02756 .08306 L
s
.02381 .13261 m
.02756 .13261 L
s
.02381 .15738 m
.02756 .15738 L
s
.02381 .18215 m
.02756 .18215 L
s
.02381 .2317 m
.02756 .2317 L
s
.02381 .25647 m
.02756 .25647 L
s
.02381 .28125 m
.02756 .28125 L
s
.02381 .3308 m
.02756 .3308 L
s
.02381 .35557 m
.02756 .35557 L
s
.02381 .38034 m
.02756 .38034 L
s
.02381 .42989 m
.02756 .42989 L
s
.02381 .45466 m
.02756 .45466 L
s
.02381 .47944 m
.02756 .47944 L
s
.02381 .52898 m
.02756 .52898 L
s
.02381 .55376 m
.02756 .55376 L
s
.02381 .57853 m
.02756 .57853 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02416 .01553 L
.0245 .01623 L
.02485 .01667 L
.0252 .01681 L
.02554 .0167 L
.02589 .01645 L
.02624 .01624 L
.02658 .01623 L
.02693 .0165 L
.02728 .01705 L
.02762 .01776 L
.02797 .01846 L
.02832 .01896 L
.02867 .01912 L
.02901 .01889 L
.02936 .01835 L
.02971 .01766 L
.03005 .01704 L
.0304 .01669 L
.03075 .01673 L
.03109 .01717 L
.03144 .01791 L
.03179 .01872 L
.03213 .01939 L
.03248 .01973 L
.03283 .01965 L
.03317 .0192 L
.03352 .01855 L
.03387 .01794 L
.03421 .01757 L
.03456 .01762 L
.03491 .01812 L
.03525 .01895 L
.0356 .01991 L
.03595 .02075 L
.0363 .02128 L
.03664 .02138 L
.03699 .02111 L
.03734 .02063 L
.03768 .0202 L
.03803 .02007 L
.03838 .02042 L
.03872 .02127 L
.03907 .02252 L
.03942 .02392 L
.03976 .02516 L
.04011 .02597 L
.04046 .02619 L
.0408 .02583 L
Mistroke
.04115 .02505 L
.0415 .02412 L
.04184 .02336 L
.04219 .02299 L
.04254 .02315 L
.04288 .02377 L
.04323 .02467 L
.04358 .02556 L
.04393 .02617 L
.04427 .02631 L
.04462 .02595 L
.04497 .0252 L
.04531 .02431 L
.04566 .02357 L
.04601 .02321 L
.04635 .02334 L
.0467 .02394 L
.04705 .0248 L
.04739 .02565 L
.04774 .02621 L
.04809 .02629 L
.04843 .02582 L
.04878 .02494 L
.04913 .02386 L
.04947 .02289 L
.04982 .02226 L
.05017 .02211 L
.05052 .02239 L
.05086 .02294 L
.05121 .02349 L
.05156 .02375 L
.0519 .02354 L
.05225 .02284 L
.0526 .02176 L
.05294 .02058 L
.05329 .0196 L
.05364 .01909 L
.05398 .01919 L
.05433 .01987 L
.05468 .02093 L
.05502 .02207 L
.05537 .02297 L
.05572 .02341 L
.05606 .0233 L
.05641 .02276 L
.05676 .02201 L
.0571 .02135 L
.05745 .02108 L
.0578 .02133 L
.05815 .02208 L
Mistroke
.05849 .02316 L
.05884 .02427 L
.05919 .02512 L
.05953 .02547 L
.05988 .02527 L
.06023 .02462 L
.06057 .02378 L
.06092 .02306 L
.06127 .02275 L
.06161 .02297 L
.06196 .02372 L
.06231 .02477 L
.06265 .02583 L
.063 .02658 L
.06335 .02679 L
.06369 .02641 L
.06404 .02558 L
.06439 .02459 L
.06473 .02381 L
.06508 .02355 L
.06543 .02401 L
.06578 .02515 L
.06612 .02677 L
.06647 .02854 L
.06682 .03011 L
.06716 .0312 L
.06751 .03174 L
.06786 .03183 L
.0682 .03175 L
.06855 .03185 L
.0689 .03244 L
.06924 .03366 L
.06959 .03547 L
.06994 .03762 L
.07028 .03975 L
.07063 .04148 L
.07098 .04255 L
.07132 .04293 L
.07167 .04278 L
.07202 .04248 L
.07236 .04245 L
.07271 .04306 L
.07306 .04451 L
.07341 .04673 L
.07375 .04943 L
.0741 .05215 L
.07445 .05441 L
.07479 .05588 L
.07514 .05644 L
.07549 .05628 L
Mistroke
.07583 .0558 L
.07618 .05549 L
.07653 .05581 L
.07687 .05701 L
.07722 .05907 L
.07757 .06165 L
.07791 .06423 L
.07826 .06622 L
.07861 .06719 L
.07895 .06695 L
.0793 .06564 L
.07965 .06371 L
.08 .06178 L
.08034 .06047 L
.08069 .06021 L
.08104 .06113 L
.08138 .063 L
.08173 .06534 L
.08208 .06755 L
.08242 .06909 L
.08277 .06965 L
.08312 .06924 L
.08346 .06821 L
.08381 .0671 L
.08416 .06649 L
.0845 .06683 L
.08485 .06826 L
.0852 .07059 L
.08554 .07336 L
.08589 .07594 L
.08624 .07777 L
.08658 .07851 L
.08693 .07817 L
.08728 .07708 L
.08763 .07582 L
.08797 .07501 L
.08832 .07515 L
.08867 .07643 L
.08901 .07866 L
.08936 .08136 L
.08971 .08386 L
.09005 .08551 L
.0904 .08592 L
.09075 .08502 L
.09109 .08316 L
.09144 .08096 L
.09179 .07916 L
.09213 .07838 L
.09248 .07897 L
.09283 .08087 L
Mistroke
.09317 .08369 L
.09352 .0868 L
.09387 .08954 L
.09421 .09147 L
.09456 .09245 L
.09491 .09273 L
.09526 .09283 L
.0956 .09343 L
.09595 .09506 L
.0963 .098 L
.09664 .10212 L
.09699 .10697 L
.09734 .11184 L
.09768 .11606 L
.09803 .11914 L
.09838 .12102 L
.09872 .12202 L
.09907 .12281 L
.09942 .12419 L
.09976 .12683 L
.10011 .13109 L
.10046 .13686 L
.1008 .14359 L
.10115 .15046 L
.1015 .15663 L
.10185 .16146 L
.10219 .16476 L
.10254 .16683 L
.10289 .16837 L
.10323 .17028 L
.10358 .17336 L
.10393 .17806 L
.10427 .18428 L
.10462 .19144 L
.10497 .19855 L
.10531 .20454 L
.10566 .20859 L
.10601 .21035 L
.10635 .2101 L
.1067 .20865 L
.10705 .20719 L
.10739 .20687 L
.10774 .20855 L
.10809 .21249 L
.10843 .21832 L
.10878 .22512 L
.10913 .23174 L
.10948 .23708 L
.10982 .24048 L
.11017 .24188 L
Mistroke
.11052 .24187 L
.11086 .24148 L
.11121 .24188 L
.11156 .24401 L
.1119 .24832 L
.11225 .25455 L
.1126 .2619 L
.11294 .26917 L
.11329 .27518 L
.11364 .27911 L
.11398 .28075 L
.11433 .28057 L
.11468 .27958 L
.11502 .27904 L
.11537 .28003 L
.11572 .28315 L
.11606 .28831 L
.11641 .29474 L
.11676 .3012 L
.11711 .30638 L
.11745 .30927 L
.1178 .30951 L
.11815 .30752 L
.11849 .30441 L
.11884 .30166 L
.11919 .30075 L
.11953 .30271 L
.11988 .30784 L
.12023 .31561 L
.12057 .32487 L
.12092 .33412 L
.12127 .34202 L
.12161 .34772 L
.12196 .35117 L
.12231 .35306 L
.12265 .35464 L
.123 .35732 L
.12335 .36225 L
.1237 .36992 L
.12404 .38008 L
.12439 .39175 L
.12474 .40351 L
.12508 .41399 L
.12543 .42221 L
.12578 .42794 L
.12612 .43175 L
.12647 .43483 L
.12682 .43867 L
.12716 .44459 L
.12751 .45332 L
Mistroke
.12786 .46479 L
.1282 .47813 L
.12855 .49188 L
.1289 .50444 L
.12924 .51451 L
.12959 .52145 L
.12994 .52547 L
.13028 .52752 L
.13063 .52901 L
.13098 .53138 L
.13133 .5356 L
.13167 .54194 L
.13202 .54983 L
.13237 .55806 L
.13271 .56515 L
.13306 .56981 L
.13341 .57137 L
.13375 .57 L
.1341 .56671 L
.13445 .5631 L
.13479 .56086 L
.13514 .56135 L
.13549 .56516 L
.13583 .57191 L
.13618 .5804 L
.13653 .58887 L
.13687 .59556 L
.13722 .59916 L
.13757 .59921 L
.13791 .59619 L
.13826 .59143 L
.13861 .58665 L
.13896 .58353 L
.1393 .58317 L
.13965 .58578 L
.14 .59067 L
.14034 .59636 L
.14069 .6011 L
.14104 .60332 L
.14138 .60207 L
.14173 .59734 L
.14208 .58998 L
.14242 .58152 L
.14277 .57366 L
.14312 .56784 L
.14346 .56481 L
.14381 .56444 L
.14416 .56581 L
.1445 .56752 L
.14485 .56812 L
Mistroke
.1452 .56656 L
.14555 .56257 L
.14589 .55671 L
.14624 .55021 L
.14659 .54468 L
.14693 .54153 L
.14728 .54165 L
.14763 .54503 L
.14797 .55079 L
.14832 .55741 L
.14867 .56308 L
.14901 .56628 L
.14936 .56612 L
.14971 .56264 L
.15005 .55675 L
.1504 .55003 L
.15075 .5442 L
.15109 .54072 L
.15144 .54033 L
.15179 .54287 L
.15213 .54734 L
.15248 .55213 L
.15283 .55554 L
.15318 .55619 L
.15352 .55342 L
.15387 .54746 L
.15422 .53933 L
.15456 .53057 L
.15491 .52279 L
.15526 .5172 L
.1556 .51429 L
.15595 .5137 L
.1563 .5143 L
.15664 .51451 L
.15699 .51272 L
.15734 .50774 L
.15768 .49912 L
.15803 .48726 L
.15838 .47333 L
.15872 .45895 L
.15907 .4458 L
.15942 .4352 L
.15976 .42779 L
.16011 .42341 L
.16046 .4212 L
.16081 .4198 L
.16115 .41781 L
.1615 .41407 L
.16185 .40803 L
.16219 .39982 L
Mistroke
.16254 .39022 L
.16289 .3804 L
.16323 .37163 L
.16358 .36492 L
.16393 .36075 L
.16427 .35899 L
.16462 .3589 L
.16497 .35938 L
.16531 .35922 L
.16566 .35747 L
.16601 .35361 L
.16635 .34777 L
.1667 .3406 L
.16705 .33315 L
.16739 .3266 L
.16774 .32191 L
.16809 .31962 L
.16844 .3197 L
.16878 .32156 L
.16913 .3242 L
.16948 .32648 L
.16982 .32741 L
.17017 .32644 L
.17052 .32357 L
.17086 .31943 L
.17121 .31508 L
.17156 .31182 L
.1719 .31084 L
.17225 .31292 L
.1726 .31827 L
.17294 .32644 L
.17329 .3364 L
.17364 .34684 L
.17398 .35642 L
.17433 .36414 L
.17468 .36957 L
.17503 .37293 L
.17537 .37507 L
.17572 .37723 L
.17607 .3807 L
.17641 .38652 L
.17676 .39518 L
.17711 .40649 L
.17745 .41958 L
.1778 .43318 L
.17815 .44586 L
.17849 .45644 L
.17884 .46427 L
.17919 .46944 L
.17953 .47271 L
Mistroke
.17988 .47533 L
.18023 .47876 L
.18057 .48419 L
.18092 .49229 L
.18127 .50296 L
.18161 .51535 L
.18196 .52805 L
.18231 .53938 L
.18266 .54787 L
.183 .55257 L
.18335 .55329 L
.1837 .55067 L
.18404 .54598 L
.18439 .54085 L
.18474 .53678 L
.18508 .53485 L
.18543 .53541 L
.18578 .53806 L
.18612 .54173 L
.18647 .54504 L
.18682 .54662 L
.18716 .54555 L
.18751 .54154 L
.18786 .53503 L
.1882 .52708 L
.18855 .51905 L
.1889 .51226 L
.18924 .50764 L
.18959 .50544 L
.18994 .50524 L
.19029 .50597 L
.19063 .50625 L
.19098 .50473 L
.19133 .50042 L
.19167 .49299 L
.19202 .48278 L
.19237 .4708 L
.19271 .45838 L
.19306 .44691 L
.19341 .43748 L
.19375 .43059 L
.1941 .42607 L
.19445 .42314 L
.19479 .42063 L
.19514 .41726 L
.19549 .412 L
.19583 .40431 L
.19618 .3943 L
.19653 .38269 L
.19688 .37068 L
Mistroke
.19722 .35962 L
.19757 .35077 L
.19792 .34497 L
.19826 .34249 L
.19861 .34298 L
.19896 .34557 L
.1993 .34907 L
.19965 .35228 L
.2 .35422 L
.20034 .35434 L
.20069 .35267 L
.20104 .34976 L
.20138 .34654 L
.20173 .34412 L
.20208 .3435 L
.20242 .34536 L
.20277 .34992 L
.20312 .35685 L
.20346 .36537 L
.20381 .37444 L
.20416 .38296 L
.20451 .39006 L
.20485 .39527 L
.2052 .39866 L
.20555 .40078 L
.20589 .40262 L
.20624 .40529 L
.20659 .40981 L
.20693 .41685 L
.20728 .42654 L
.20763 .43843 L
.20797 .45152 L
.20832 .46451 L
.20867 .47604 L
.20901 .48501 L
.20936 .4908 L
.20971 .49343 L
.21005 .49356 L
.2104 .49229 L
.21075 .49094 L
.21109 .49072 L
.21144 .49248 L
.21179 .49644 L
.21214 .50223 L
.21248 .50891 L
.21283 .51526 L
.21318 .52008 L
.21352 .52246 L
.21387 .52203 L
.21422 .51903 L
Mistroke
.21456 .51426 L
.21491 .50889 L
.21526 .50411 L
.2156 .50087 L
.21595 .49964 L
.2163 .50023 L
.21664 .50192 L
.21699 .50355 L
.21734 .50385 L
.21768 .50176 L
.21803 .49662 L
.21838 .48843 L
.21873 .47777 L
.21907 .46569 L
.21942 .45347 L
.21977 .44231 L
.22011 .43306 L
.22046 .42605 L
.22081 .42101 L
.22115 .41721 L
.2215 .4136 L
.22185 .40911 L
.22219 .40292 L
.22254 .39464 L
.22289 .38443 L
.22323 .37298 L
.22358 .36132 L
.22393 .35066 L
.22427 .3421 L
.22462 .33644 L
.22497 .33398 L
.22531 .33453 L
.22566 .33742 L
.22601 .34166 L
.22636 .34617 L
.2267 .34998 L
.22705 .35243 L
.2274 .3533 L
.22774 .35283 L
.22809 .35167 L
.22844 .35076 L
.22878 .35109 L
.22913 .35355 L
.22948 .35868 L
.22982 .3666 L
.23017 .37695 L
.23052 .38894 L
.23086 .40155 L
.23121 .41367 L
.23156 .4244 L
Mistroke
.2319 .43316 L
.23225 .4399 L
.2326 .44502 L
.23294 .44939 L
.23329 .45404 L
.23364 .46001 L
.23399 .46802 L
.23433 .47831 L
.23468 .49054 L
.23503 .50382 L
.23537 .51684 L
.23572 .52817 L
.23607 .53653 L
.23641 .54109 L
.23676 .54164 L
.23711 .53863 L
.23745 .53311 L
.2378 .52649 L
.23815 .52023 L
.23849 .51554 L
.23884 .51309 L
.23919 .51294 L
.23953 .51447 L
.23988 .51659 L
.24023 .51798 L
.24058 .51741 L
.24092 .51398 L
.24127 .50738 L
.24162 .49787 L
.24196 .48626 L
.24231 .47372 L
.24266 .46147 L
.243 .45055 L
.24335 .4416 L
.2437 .43474 L
.24404 .4296 L
.24439 .42539 L
.24474 .42114 L
.24508 .41593 L
.24543 .40907 L
.24578 .40028 L
.24612 .38972 L
.24647 .37797 L
.24682 .3659 L
.24716 .35449 L
.24751 .34465 L
.24786 .33705 L
.24821 .33202 L
.24855 .32949 L
.2489 .32906 L
Mistroke
.24925 .33008 L
.24959 .33178 L
.24994 .33349 L
.25029 .3347 L
.25063 .33521 L
.25098 .33519 L
.25133 .33509 L
.25167 .33563 L
.25202 .3376 L
.25237 .34172 L
.25271 .34848 L
.25306 .358 L
.25341 .37001 L
.25375 .38381 L
.2541 .39844 L
.25445 .41279 L
.25479 .42582 L
.25514 .43678 L
.25549 .44533 L
.25584 .4516 L
.25618 .45619 L
.25653 .46003 L
.25688 .46413 L
.25722 .46943 L
.25757 .47651 L
.25792 .48547 L
.25826 .49591 L
.25861 .50694 L
.25896 .5174 L
.2593 .52609 L
.25965 .53198 L
.26 .53446 L
.26034 .53343 L
.26069 .52932 L
.26104 .523 L
.26138 .51557 L
.26173 .50813 L
.26208 .50155 L
.26242 .4963 L
.26277 .49239 L
.26312 .48938 L
.26347 .48653 L
.26381 .48294 L
.26416 .47783 L
.26451 .47069 L
.26485 .46142 L
.2652 .45035 L
.26555 .43822 L
.26589 .42603 L
.26624 .41484 L
Mistroke
.26659 .40561 L
.26693 .39902 L
.26728 .39536 L
.26763 .39444 L
.26797 .39573 L
.26832 .39836 L
.26867 .40134 L
.26901 .40373 L
.26936 .4048 L
.26971 .40415 L
.27006 .40179 L
.2704 .39812 L
.27075 .39388 L
.2711 .38995 L
.27144 .38723 L
.27179 .38644 L
.27214 .38797 L
.27248 .39175 L
.27283 .39732 L
.27318 .40382 L
.27352 .4102 L
.27387 .41537 L
.27422 .41844 L
.27456 .41888 L
.27491 .41663 L
.27526 .41214 L
.2756 .40626 L
.27595 .4001 L
.2763 .39479 L
.27664 .39131 L
.27699 .39026 L
.27734 .39174 L
.27769 .39539 L
.27803 .40042 L
.27838 .40578 L
.27873 .41041 L
.27907 .41339 L
.27942 .41416 L
.27977 .41259 L
.28011 .40901 L
.28046 .40415 L
.28081 .39895 L
.28115 .39443 L
.2815 .39148 L
.28185 .3907 L
.28219 .39233 L
.28254 .39621 L
.28289 .40182 L
.28323 .40842 L
.28358 .41514 L
Mistroke
.28393 .4212 L
.28427 .42603 L
.28462 .42935 L
.28497 .43127 L
.28532 .43222 L
.28566 .43293 L
.28601 .43424 L
.28636 .43699 L
.2867 .44182 L
.28705 .44904 L
.2874 .45854 L
.28774 .46978 L
.28809 .48184 L
.28844 .49353 L
.28878 .50365 L
.28913 .51113 L
.28948 .51526 L
.28982 .51582 L
.29017 .5131 L
.29052 .50789 L
.29086 .50129 L
.29121 .49456 L
.29156 .48879 L
.29191 .4848 L
.29225 .48288 L
.2926 .48282 L
.29295 .4839 L
.29329 .48509 L
.29364 .48523 L
.29399 .48326 L
.29433 .47847 L
.29468 .47058 L
.29503 .45984 L
.29537 .44692 L
.29572 .43285 L
.29607 .41877 L
.29641 .40578 L
.29676 .3947 L
.29711 .38603 L
.29745 .37982 L
.2978 .37577 L
.29815 .37327 L
.29849 .37154 L
.29884 .36982 L
.29919 .36744 L
.29954 .36399 L
.29988 .35935 L
.30023 .35372 L
.30058 .3476 L
.30092 .34166 L
Mistroke
.30127 .33672 L
.30162 .33355 L
.30196 .33279 L
.30231 .33483 L
.30266 .33974 L
.303 .34726 L
.30335 .3568 L
.3037 .36754 L
.30404 .37854 L
.30439 .38891 L
.30474 .39792 L
.30508 .40515 L
.30543 .41055 L
.30578 .41443 L
.30612 .41737 L
.30647 .42015 L
.30682 .42352 L
.30717 .42805 L
.30751 .43403 L
.30786 .44135 L
.30821 .44954 L
.30855 .45781 L
.3089 .46526 L
.30925 .47096 L
.30959 .47422 L
.30994 .47465 L
.31029 .4723 L
.31063 .46761 L
.31098 .46136 L
.31133 .45456 L
.31167 .44825 L
.31202 .44337 L
.31237 .44059 L
.31271 .44023 L
.31306 .44223 L
.31341 .44618 L
.31376 .45136 L
.3141 .45691 L
.31445 .46193 L
.3148 .46565 L
.31514 .46752 L
.31549 .46732 L
.31584 .46518 L
.31618 .46157 L
.31653 .45722 L
.31688 .453 L
.31722 .44982 L
.31757 .4484 L
.31792 .44919 L
.31826 .45227 L
Mistroke
.31861 .45727 L
.31896 .4635 L
.3193 .46995 L
.31965 .47553 L
.32 .47921 L
.32034 .4802 L
.32069 .47809 L
.32104 .4729 L
.32139 .46507 L
.32173 .4554 L
.32208 .44485 L
.32243 .43442 L
.32277 .42494 L
.32312 .41696 L
.32347 .41064 L
.32381 .40581 L
.32416 .40199 L
.32451 .39853 L
.32485 .39473 L
.3252 .38999 L
.32555 .38392 L
.32589 .37642 L
.32624 .36767 L
.32659 .35814 L
.32693 .3485 L
.32728 .33952 L
.32763 .33199 L
.32797 .3266 L
.32832 .3239 L
.32867 .32417 L
.32902 .32744 L
.32936 .33347 L
.32971 .34174 L
.33006 .35156 L
.3304 .36215 L
.33075 .37271 L
.3311 .38256 L
.33144 .39122 L
.33179 .39849 L
.33214 .40444 L
.33248 .40945 L
.33283 .41404 L
.33318 .41882 L
.33352 .42433 L
.33387 .43092 L
.33422 .43864 L
.33456 .44724 L
.33491 .45616 L
.33526 .46465 L
.33561 .47186 L
Mistroke
.33595 .47702 L
.3363 .47959 L
.33665 .47932 L
.33699 .47633 L
.33734 .47112 L
.33769 .46443 L
.33803 .45721 L
.33838 .45042 L
.33873 .44492 L
.33907 .44138 L
.33942 .44016 L
.33977 .4413 L
.34011 .44454 L
.34046 .44933 L
.34081 .45496 L
.34115 .46066 L
.3415 .46565 L
.34185 .4693 L
.34219 .47121 L
.34254 .47125 L
.34289 .46958 L
.34324 .46664 L
.34358 .46309 L
.34393 .45968 L
.34428 .45714 L
.34462 .45606 L
.34497 .45674 L
.34532 .45914 L
.34566 .46286 L
.34601 .46717 L
.34636 .47116 L
.3467 .47381 L
.34705 .47423 L
.3474 .47177 L
.34774 .46612 L
.34809 .4574 L
.34844 .44609 L
.34878 .433 L
.34913 .41908 L
.34948 .40536 L
.34982 .39272 L
.35017 .38186 L
.35052 .37315 L
.35087 .3667 L
.35121 .36233 L
.35156 .35966 L
.35191 .35817 L
.35225 .35732 L
.3526 .35661 L
.35295 .35564 L
Mistroke
.35329 .35419 L
.35364 .35221 L
.35399 .34985 L
.35433 .34744 L
.35468 .34545 L
.35503 .34446 L
.35537 .34502 L
.35572 .34764 L
.35607 .35265 L
.35641 .36014 L
.35676 .36991 L
.35711 .38144 L
.35745 .39397 L
.3578 .40657 L
.35815 .41824 L
.3585 .42807 L
.35884 .43537 L
.35919 .43977 L
.35954 .44126 L
.35988 .44018 L
.36023 .43718 L
.36058 .43308 L
.36092 .42875 L
.36127 .42502 L
.36162 .42251 L
.36196 .4216 L
.36231 .4224 L
.36266 .42478 L
.363 .42838 L
.36335 .43274 L
.3637 .43737 L
.36404 .44181 L
.36439 .44569 L
.36474 .44882 L
.36509 .45117 L
.36543 .45289 L
.36578 .45428 L
.36613 .45574 L
.36647 .45774 L
.36682 .4607 L
.36717 .46495 L
.36751 .47062 L
.36786 .4776 L
.36821 .48554 L
.36855 .4938 L
.3689 .50159 L
.36925 .50802 L
.36959 .51222 L
.36994 .5135 L
.37029 .51141 L
Mistroke
.37063 .50587 L
.37098 .49714 L
.37133 .48583 L
.37167 .47277 L
.37202 .45894 L
.37237 .44528 L
.37272 .43263 L
.37306 .4216 L
.37341 .41251 L
.37376 .40544 L
.3741 .40018 L
.37445 .39638 L
.3748 .39359 L
.37514 .39131 L
.37549 .38913 L
.37584 .38671 L
.37618 .38387 L
.37653 .38056 L
.37688 .37691 L
.37722 .37315 L
.37757 .36963 L
.37792 .36673 L
.37826 .36486 L
.37861 .36435 L
.37896 .36543 L
.3793 .36813 L
.37965 .3723 L
.38 .37754 L
.38035 .38332 L
.38069 .38896 L
.38104 .39376 L
.38139 .39707 L
.38173 .39844 L
.38208 .39763 L
.38243 .39471 L
.38277 .38999 L
.38312 .38407 L
.38347 .37765 L
.38381 .37156 L
.38416 .36655 L
.38451 .36327 L
.38485 .36218 L
.3852 .3635 L
.38555 .36725 L
.38589 .3732 L
.38624 .38095 L
.38659 .38998 L
.38694 .39967 L
.38728 .40941 L
.38763 .41866 L
Mistroke
.38798 .42698 L
.38832 .43408 L
.38867 .4399 L
.38902 .44456 L
.38936 .44839 L
.38971 .45182 L
.39006 .45538 L
.3904 .45954 L
.39075 .46466 L
.3911 .4709 L
.39144 .47812 L
.39179 .48597 L
.39214 .49382 L
.39248 .50091 L
.39283 .50644 L
.39318 .50969 L
.39352 .5101 L
.39387 .50742 L
.39422 .50167 L
.39457 .49323 L
.39491 .48272 L
.39526 .47098 L
.39561 .45893 L
.39595 .44752 L
.3963 .43758 L
.39665 .42979 L
.39699 .4246 L
.39734 .42219 L
.39769 .42246 L
.39803 .42505 L
.39838 .42939 L
.39873 .43471 L
.39907 .44017 L
.39942 .4449 L
.39977 .44815 L
.40011 .44933 L
.40046 .4481 L
.40081 .4444 L
.40115 .43845 L
.4015 .43072 L
.40185 .42184 L
.4022 .41251 L
.40254 .40341 L
.40289 .3951 L
.40324 .38796 L
.40358 .38214 L
.40393 .37762 L
.40428 .3742 L
.40462 .37156 L
.40497 .36936 L
Mistroke
.40532 .36727 L
.40566 .36504 L
.40601 .3625 L
.40636 .3596 L
.4067 .35644 L
.40705 .35319 L
.4074 .35014 L
.40774 .34766 L
.40809 .34616 L
.40844 .34606 L
.40879 .34778 L
.40913 .35159 L
.40948 .35766 L
.40983 .36592 L
.41017 .37609 L
.41052 .38762 L
.41087 .39977 L
.41121 .41167 L
.41156 .42239 L
.41191 .43112 L
.41225 .4372 L
.4126 .44027 L
.41295 .44028 L
.41329 .43752 L
.41364 .43257 L
.41399 .42624 L
.41433 .41943 L
.41468 .41309 L
.41503 .40809 L
.41537 .40515 L
.41572 .40477 L
.41607 .40724 L
.41642 .41259 L
.41676 .42061 L
.41711 .43089 L
.41746 .44282 L
.4178 .45565 L
.41815 .46855 L
.4185 .48067 L
.41884 .49124 L
.41919 .49961 L
.41954 .50537 L
.41988 .50833 L
.42023 .5086 L
.42058 .5065 L
.42092 .50255 L
.42127 .49737 L
.42162 .49158 L
.42196 .48569 L
.42231 .48008 L
Mistroke
.42266 .47492 L
.423 .47021 L
.42335 .46577 L
.4237 .46134 L
.42405 .45662 L
.42439 .45136 L
.42474 .4454 L
.42509 .43868 L
.42543 .43129 L
.42578 .42345 L
.42613 .41545 L
.42647 .40766 L
.42682 .40048 L
.42717 .39432 L
.42751 .38954 L
.42786 .3864 L
.42821 .38508 L
.42855 .3856 L
.4289 .38778 L
.42925 .39129 L
.42959 .39563 L
.42994 .40014 L
.43029 .40413 L
.43064 .4069 L
.43098 .40784 L
.43133 .40653 L
.43168 .40277 L
.43202 .39664 L
.43237 .38845 L
.43272 .37876 L
.43306 .36827 L
.43341 .35778 L
.43376 .34811 L
.4341 .34001 L
.43445 .33411 L
.4348 .33091 L
.43514 .33071 L
.43549 .33363 L
.43584 .33959 L
.43618 .34827 L
.43653 .35919 L
.43688 .37169 L
.43722 .38498 L
.43757 .39818 L
.43792 .41045 L
.43827 .421 L
.43861 .42926 L
.43896 .43486 L
.43931 .43772 L
.43965 .43803 L
Mistroke
.44 .43624 L
.44035 .43298 L
.44069 .42898 L
.44104 .42497 L
.44139 .42163 L
.44173 .41952 L
.44208 .41901 L
.44243 .4203 L
.44277 .42345 L
.44312 .42834 L
.44347 .43473 L
.44381 .44229 L
.44416 .45063 L
.44451 .45929 L
.44485 .46779 L
.4452 .47568 L
.44555 .48254 L
.4459 .48804 L
.44624 .49199 L
.44659 .49431 L
.44694 .49511 L
.44728 .49457 L
.44763 .493 L
.44798 .49071 L
.44832 .48798 L
.44867 .48501 L
.44902 .48188 L
.44936 .47856 L
.44971 .4749 L
.45006 .4707 L
.4504 .46576 L
.45075 .45994 L
.4511 .45318 L
.45144 .44553 L
.45179 .43716 L
.45214 .42836 L
.45248 .41946 L
.45283 .41083 L
.45318 .40287 L
.45353 .39591 L
.45387 .39025 L
.45422 .38612 L
.45457 .38366 L
.45491 .38291 L
.45526 .38377 L
.45561 .38602 L
.45595 .38931 L
.4563 .39315 L
.45665 .39698 L
.45699 .4002 L
Mistroke
.45734 .40221 L
.45769 .40255 L
.45803 .40089 L
.45838 .39711 L
.45873 .3913 L
.45907 .38381 L
.45942 .37511 L
.45977 .36584 L
.46012 .35669 L
.46046 .34835 L
.46081 .34147 L
.46116 .33662 L
.4615 .33422 L
.46185 .33458 L
.4622 .33783 L
.46254 .34394 L
.46289 .35268 L
.46324 .36366 L
.46358 .37627 L
.46393 .38976 L
.46428 .40328 L
.46462 .41591 L
.46497 .42683 L
.46532 .4353 L
.46566 .44085 L
.46601 .44325 L
.46636 .44261 L
.4667 .4393 L
.46705 .43395 L
.4674 .42737 L
.46775 .42044 L
.46809 .41408 L
.46844 .4091 L
.46879 .40621 L
.46913 .40594 L
.46948 .40862 L
.46983 .41437 L
.47017 .42307 L
.47052 .4344 L
.47087 .4478 L
.47121 .46252 L
.47156 .47765 L
.47191 .49219 L
.47225 .50512 L
.4726 .51549 L
.47295 .52254 L
.47329 .52575 L
.47364 .52493 L
.47399 .52019 L
.47433 .512 L
Mistroke
.47468 .50106 L
.47503 .48825 L
.47538 .47453 L
.47572 .46085 L
.47607 .44805 L
.47642 .43683 L
.47676 .42768 L
.47711 .42091 L
.47746 .41663 L
.4778 .41474 L
.47815 .415 L
.4785 .41702 L
.47884 .42028 L
.47919 .42417 L
.47954 .42805 L
.47988 .43124 L
.48023 .43317 L
.48058 .43336 L
.48092 .43149 L
.48127 .42746 L
.48162 .42136 L
.48197 .4135 L
.48231 .40433 L
.48266 .3944 L
.48301 .38431 L
.48335 .37462 L
.4837 .36587 L
.48405 .35848 L
.48439 .35275 L
.48474 .3489 L
.48509 .34702 L
.48543 .34709 L
.48578 .34899 L
.48613 .35249 L
.48647 .35729 L
.48682 .36295 L
.48717 .36903 L
.48751 .37502 L
.48786 .38045 L
.48821 .38494 L
.48855 .38822 L
.4889 .39017 L
.48925 .39084 L
.4896 .39041 L
.48994 .38919 L
.49029 .38756 L
.49064 .38592 L
.49098 .38462 L
.49133 .38399 L
.49168 .38426 L
Mistroke
.49202 .3856 L
.49237 .38811 L
.49272 .39184 L
.49306 .39679 L
.49341 .40288 L
.49376 .41 L
.4941 .41796 L
.49445 .42649 L
.4948 .43525 L
.49514 .44387 L
.49549 .45197 L
.49584 .45918 L
.49618 .46523 L
.49653 .46995 L
.49688 .47328 L
.49723 .47531 L
.49757 .47622 L
.49792 .47625 L
.49827 .47569 L
.49861 .47482 L
.49896 .47389 L
.49931 .47308 L
.49965 .47255 L
.5 .47236 L
.50035 .47255 L
.50069 .47308 L
.50104 .47389 L
.50139 .47482 L
.50173 .47569 L
.50208 .47625 L
.50243 .47622 L
.50277 .47531 L
.50312 .47328 L
.50347 .46995 L
.50382 .46523 L
.50416 .45918 L
.50451 .45197 L
.50486 .44387 L
.5052 .43525 L
.50555 .42649 L
.5059 .41796 L
.50624 .41 L
.50659 .40288 L
.50694 .39679 L
.50728 .39184 L
.50763 .38811 L
.50798 .3856 L
.50832 .38426 L
.50867 .38399 L
.50902 .38462 L
Mistroke
.50936 .38592 L
.50971 .38756 L
.51006 .38919 L
.5104 .39041 L
.51075 .39084 L
.5111 .39017 L
.51145 .38822 L
.51179 .38494 L
.51214 .38045 L
.51249 .37502 L
.51283 .36903 L
.51318 .36295 L
.51353 .35729 L
.51387 .35249 L
.51422 .34899 L
.51457 .34709 L
.51491 .34702 L
.51526 .3489 L
.51561 .35275 L
.51595 .35848 L
.5163 .36587 L
.51665 .37462 L
.51699 .38431 L
.51734 .3944 L
.51769 .40433 L
.51803 .4135 L
.51838 .42136 L
.51873 .42746 L
.51908 .43149 L
.51942 .43336 L
.51977 .43317 L
.52012 .43124 L
.52046 .42805 L
.52081 .42417 L
.52116 .42028 L
.5215 .41702 L
.52185 .415 L
.5222 .41474 L
.52254 .41663 L
.52289 .42091 L
.52324 .42768 L
.52358 .43683 L
.52393 .44805 L
.52428 .46085 L
.52462 .47453 L
.52497 .48825 L
.52532 .50106 L
.52567 .512 L
.52601 .52019 L
.52636 .52493 L
Mistroke
.52671 .52575 L
.52705 .52254 L
.5274 .51549 L
.52775 .50512 L
.52809 .49219 L
.52844 .47765 L
.52879 .46252 L
.52913 .4478 L
.52948 .4344 L
.52983 .42307 L
.53017 .41437 L
.53052 .40862 L
.53087 .40594 L
.53121 .40621 L
.53156 .4091 L
.53191 .41408 L
.53225 .42044 L
.5326 .42737 L
.53295 .43395 L
.5333 .4393 L
.53364 .44261 L
.53399 .44325 L
.53434 .44085 L
.53468 .4353 L
.53503 .42683 L
.53538 .41591 L
.53572 .40328 L
.53607 .38976 L
.53642 .37627 L
.53676 .36366 L
.53711 .35268 L
.53746 .34394 L
.5378 .33783 L
.53815 .33458 L
.5385 .33422 L
.53884 .33662 L
.53919 .34147 L
.53954 .34835 L
.53988 .35669 L
.54023 .36584 L
.54058 .37511 L
.54093 .38381 L
.54127 .3913 L
.54162 .39711 L
.54197 .40089 L
.54231 .40255 L
.54266 .40221 L
.54301 .4002 L
.54335 .39698 L
.5437 .39315 L
Mistroke
.54405 .38931 L
.54439 .38602 L
.54474 .38377 L
.54509 .38291 L
.54543 .38366 L
.54578 .38612 L
.54613 .39025 L
.54647 .39591 L
.54682 .40287 L
.54717 .41083 L
.54752 .41946 L
.54786 .42836 L
.54821 .43716 L
.54856 .44553 L
.5489 .45318 L
.54925 .45994 L
.5496 .46576 L
.54994 .4707 L
.55029 .4749 L
.55064 .47856 L
.55098 .48188 L
.55133 .48501 L
.55168 .48798 L
.55202 .49071 L
.55237 .493 L
.55272 .49457 L
.55306 .49511 L
.55341 .49431 L
.55376 .49199 L
.5541 .48804 L
.55445 .48254 L
.5548 .47568 L
.55515 .46779 L
.55549 .45929 L
.55584 .45063 L
.55619 .44229 L
.55653 .43473 L
.55688 .42834 L
.55723 .42345 L
.55757 .4203 L
.55792 .41901 L
.55827 .41952 L
.55861 .42163 L
.55896 .42497 L
.55931 .42898 L
.55965 .43298 L
.56 .43624 L
.56035 .43803 L
.56069 .43772 L
.56104 .43486 L
Mistroke
.56139 .42926 L
.56173 .421 L
.56208 .41045 L
.56243 .39818 L
.56278 .38498 L
.56312 .37169 L
.56347 .35919 L
.56382 .34827 L
.56416 .33959 L
.56451 .33363 L
.56486 .33071 L
.5652 .33091 L
.56555 .33411 L
.5659 .34001 L
.56624 .34811 L
.56659 .35778 L
.56694 .36827 L
.56728 .37876 L
.56763 .38845 L
.56798 .39664 L
.56832 .40277 L
.56867 .40653 L
.56902 .40784 L
.56936 .4069 L
.56971 .40413 L
.57006 .40014 L
.57041 .39563 L
.57075 .39129 L
.5711 .38778 L
.57145 .3856 L
.57179 .38508 L
.57214 .3864 L
.57249 .38954 L
.57283 .39432 L
.57318 .40048 L
.57353 .40766 L
.57387 .41545 L
.57422 .42345 L
.57457 .43129 L
.57491 .43868 L
.57526 .4454 L
.57561 .45136 L
.57595 .45662 L
.5763 .46134 L
.57665 .46577 L
.577 .47021 L
.57734 .47492 L
.57769 .48008 L
.57804 .48569 L
.57838 .49158 L
Mistroke
.57873 .49737 L
.57908 .50255 L
.57942 .5065 L
.57977 .5086 L
.58012 .50833 L
.58046 .50537 L
.58081 .49961 L
.58116 .49124 L
.5815 .48067 L
.58185 .46855 L
.5822 .45565 L
.58254 .44282 L
.58289 .43089 L
.58324 .42061 L
.58358 .41259 L
.58393 .40724 L
.58428 .40477 L
.58463 .40515 L
.58497 .40809 L
.58532 .41309 L
.58567 .41943 L
.58601 .42624 L
.58636 .43257 L
.58671 .43752 L
.58705 .44028 L
.5874 .44027 L
.58775 .4372 L
.58809 .43112 L
.58844 .42239 L
.58879 .41167 L
.58913 .39977 L
.58948 .38762 L
.58983 .37609 L
.59017 .36592 L
.59052 .35766 L
.59087 .35159 L
.59121 .34778 L
.59156 .34606 L
.59191 .34616 L
.59226 .34766 L
.5926 .35014 L
.59295 .35319 L
.5933 .35644 L
.59364 .3596 L
.59399 .3625 L
.59434 .36504 L
.59468 .36727 L
.59503 .36936 L
.59538 .37156 L
.59572 .3742 L
Mistroke
.59607 .37762 L
.59642 .38214 L
.59676 .38796 L
.59711 .3951 L
.59746 .40341 L
.5978 .41251 L
.59815 .42184 L
.5985 .43072 L
.59885 .43845 L
.59919 .4444 L
.59954 .4481 L
.59989 .44933 L
.60023 .44815 L
.60058 .4449 L
.60093 .44017 L
.60127 .43471 L
.60162 .42939 L
.60197 .42505 L
.60231 .42246 L
.60266 .42219 L
.60301 .4246 L
.60335 .42979 L
.6037 .43758 L
.60405 .44752 L
.60439 .45893 L
.60474 .47098 L
.60509 .48272 L
.60543 .49323 L
.60578 .50167 L
.60613 .50742 L
.60648 .5101 L
.60682 .50969 L
.60717 .50644 L
.60752 .50091 L
.60786 .49382 L
.60821 .48597 L
.60856 .47812 L
.6089 .4709 L
.60925 .46466 L
.6096 .45954 L
.60994 .45538 L
.61029 .45182 L
.61064 .44839 L
.61098 .44456 L
.61133 .4399 L
.61168 .43408 L
.61202 .42698 L
.61237 .41866 L
.61272 .40941 L
.61306 .39967 L
Mistroke
.61341 .38998 L
.61376 .38095 L
.61411 .3732 L
.61445 .36725 L
.6148 .3635 L
.61515 .36218 L
.61549 .36327 L
.61584 .36655 L
.61619 .37156 L
.61653 .37765 L
.61688 .38407 L
.61723 .38999 L
.61757 .39471 L
.61792 .39763 L
.61827 .39844 L
.61861 .39707 L
.61896 .39376 L
.61931 .38896 L
.61965 .38332 L
.62 .37754 L
.62035 .3723 L
.6207 .36813 L
.62104 .36543 L
.62139 .36435 L
.62174 .36486 L
.62208 .36673 L
.62243 .36963 L
.62278 .37315 L
.62312 .37691 L
.62347 .38056 L
.62382 .38387 L
.62416 .38671 L
.62451 .38913 L
.62486 .39131 L
.6252 .39359 L
.62555 .39638 L
.6259 .40018 L
.62624 .40544 L
.62659 .41251 L
.62694 .4216 L
.62728 .43263 L
.62763 .44528 L
.62798 .45894 L
.62833 .47277 L
.62867 .48583 L
.62902 .49714 L
.62937 .50587 L
.62971 .51141 L
.63006 .5135 L
.63041 .51222 L
Mistroke
.63075 .50802 L
.6311 .50159 L
.63145 .4938 L
.63179 .48554 L
.63214 .4776 L
.63249 .47062 L
.63283 .46495 L
.63318 .4607 L
.63353 .45774 L
.63387 .45574 L
.63422 .45428 L
.63457 .45289 L
.63491 .45117 L
.63526 .44882 L
.63561 .44569 L
.63596 .44181 L
.6363 .43737 L
.63665 .43274 L
.637 .42838 L
.63734 .42478 L
.63769 .4224 L
.63804 .4216 L
.63838 .42251 L
.63873 .42502 L
.63908 .42875 L
.63942 .43308 L
.63977 .43718 L
.64012 .44018 L
.64046 .44126 L
.64081 .43977 L
.64116 .43537 L
.6415 .42807 L
.64185 .41824 L
.6422 .40657 L
.64255 .39397 L
.64289 .38144 L
.64324 .36991 L
.64359 .36014 L
.64393 .35265 L
.64428 .34764 L
.64463 .34502 L
.64497 .34446 L
.64532 .34545 L
.64567 .34744 L
.64601 .34985 L
.64636 .35221 L
.64671 .35419 L
.64705 .35564 L
.6474 .35661 L
.64775 .35732 L
Mistroke
.64809 .35817 L
.64844 .35966 L
.64879 .36233 L
.64913 .3667 L
.64948 .37315 L
.64983 .38186 L
.65018 .39272 L
.65052 .40536 L
.65087 .41908 L
.65122 .433 L
.65156 .44609 L
.65191 .4574 L
.65226 .46612 L
.6526 .47177 L
.65295 .47423 L
.6533 .47381 L
.65364 .47116 L
.65399 .46717 L
.65434 .46286 L
.65468 .45914 L
.65503 .45674 L
.65538 .45606 L
.65572 .45714 L
.65607 .45968 L
.65642 .46309 L
.65676 .46664 L
.65711 .46958 L
.65746 .47125 L
.65781 .47121 L
.65815 .4693 L
.6585 .46565 L
.65885 .46066 L
.65919 .45496 L
.65954 .44933 L
.65989 .44454 L
.66023 .4413 L
.66058 .44016 L
.66093 .44138 L
.66127 .44492 L
.66162 .45042 L
.66197 .45721 L
.66231 .46443 L
.66266 .47112 L
.66301 .47633 L
.66335 .47932 L
.6637 .47959 L
.66405 .47702 L
.66439 .47186 L
.66474 .46465 L
.66509 .45616 L
Mistroke
.66544 .44724 L
.66578 .43864 L
.66613 .43092 L
.66648 .42433 L
.66682 .41882 L
.66717 .41404 L
.66752 .40945 L
.66786 .40444 L
.66821 .39849 L
.66856 .39122 L
.6689 .38256 L
.66925 .37271 L
.6696 .36215 L
.66994 .35156 L
.67029 .34174 L
.67064 .33347 L
.67098 .32744 L
.67133 .32417 L
.67168 .3239 L
.67203 .3266 L
.67237 .33199 L
.67272 .33952 L
.67307 .3485 L
.67341 .35814 L
.67376 .36767 L
.67411 .37642 L
.67445 .38392 L
.6748 .38999 L
.67515 .39473 L
.67549 .39853 L
.67584 .40199 L
.67619 .40581 L
.67653 .41064 L
.67688 .41696 L
.67723 .42494 L
.67757 .43442 L
.67792 .44485 L
.67827 .4554 L
.67861 .46507 L
.67896 .4729 L
.67931 .47809 L
.67966 .4802 L
.68 .47921 L
.68035 .47553 L
.6807 .46995 L
.68104 .4635 L
.68139 .45727 L
.68174 .45227 L
.68208 .44919 L
.68243 .4484 L
Mistroke
.68278 .44982 L
.68312 .453 L
.68347 .45722 L
.68382 .46157 L
.68416 .46518 L
.68451 .46732 L
.68486 .46752 L
.6852 .46565 L
.68555 .46193 L
.6859 .45691 L
.68624 .45136 L
.68659 .44618 L
.68694 .44223 L
.68729 .44023 L
.68763 .44059 L
.68798 .44337 L
.68833 .44825 L
.68867 .45456 L
.68902 .46136 L
.68937 .46761 L
.68971 .4723 L
.69006 .47465 L
.69041 .47422 L
.69075 .47096 L
.6911 .46526 L
.69145 .45781 L
.69179 .44954 L
.69214 .44135 L
.69249 .43403 L
.69283 .42805 L
.69318 .42352 L
.69353 .42015 L
.69388 .41737 L
.69422 .41443 L
.69457 .41055 L
.69492 .40515 L
.69526 .39792 L
.69561 .38891 L
.69596 .37854 L
.6963 .36754 L
.69665 .3568 L
.697 .34726 L
.69734 .33974 L
.69769 .33483 L
.69804 .33279 L
.69838 .33355 L
.69873 .33672 L
.69908 .34166 L
.69942 .3476 L
.69977 .35372 L
Mistroke
.70012 .35935 L
.70046 .36399 L
.70081 .36744 L
.70116 .36982 L
.70151 .37154 L
.70185 .37327 L
.7022 .37577 L
.70255 .37982 L
.70289 .38603 L
.70324 .3947 L
.70359 .40578 L
.70393 .41877 L
.70428 .43285 L
.70463 .44692 L
.70497 .45984 L
.70532 .47058 L
.70567 .47847 L
.70601 .48326 L
.70636 .48523 L
.70671 .48509 L
.70705 .4839 L
.7074 .48282 L
.70775 .48288 L
.70809 .4848 L
.70844 .48879 L
.70879 .49456 L
.70914 .50129 L
.70948 .50789 L
.70983 .5131 L
.71018 .51582 L
.71052 .51526 L
.71087 .51113 L
.71122 .50365 L
.71156 .49353 L
.71191 .48184 L
.71226 .46978 L
.7126 .45854 L
.71295 .44904 L
.7133 .44182 L
.71364 .43699 L
.71399 .43424 L
.71434 .43293 L
.71468 .43222 L
.71503 .43127 L
.71538 .42935 L
.71573 .42603 L
.71607 .4212 L
.71642 .41514 L
.71677 .40842 L
.71711 .40182 L
Mistroke
.71746 .39621 L
.71781 .39233 L
.71815 .3907 L
.7185 .39148 L
.71885 .39443 L
.71919 .39895 L
.71954 .40415 L
.71989 .40901 L
.72023 .41259 L
.72058 .41416 L
.72093 .41339 L
.72127 .41041 L
.72162 .40578 L
.72197 .40042 L
.72231 .39539 L
.72266 .39174 L
.72301 .39026 L
.72336 .39131 L
.7237 .39479 L
.72405 .4001 L
.7244 .40626 L
.72474 .41214 L
.72509 .41663 L
.72544 .41888 L
.72578 .41844 L
.72613 .41537 L
.72648 .4102 L
.72682 .40382 L
.72717 .39732 L
.72752 .39175 L
.72786 .38797 L
.72821 .38644 L
.72856 .38723 L
.7289 .38995 L
.72925 .39388 L
.7296 .39812 L
.72994 .40179 L
.73029 .40415 L
.73064 .4048 L
.73099 .40373 L
.73133 .40134 L
.73168 .39836 L
.73203 .39573 L
.73237 .39444 L
.73272 .39536 L
.73307 .39902 L
.73341 .40561 L
.73376 .41484 L
.73411 .42603 L
.73445 .43822 L
Mistroke
.7348 .45035 L
.73515 .46142 L
.73549 .47069 L
.73584 .47783 L
.73619 .48294 L
.73653 .48653 L
.73688 .48938 L
.73723 .49239 L
.73758 .4963 L
.73792 .50155 L
.73827 .50813 L
.73862 .51557 L
.73896 .523 L
.73931 .52932 L
.73966 .53343 L
.74 .53446 L
.74035 .53198 L
.7407 .52609 L
.74104 .5174 L
.74139 .50694 L
.74174 .49591 L
.74208 .48547 L
.74243 .47651 L
.74278 .46943 L
.74312 .46413 L
.74347 .46003 L
.74382 .45619 L
.74416 .4516 L
.74451 .44533 L
.74486 .43678 L
.74521 .42582 L
.74555 .41279 L
.7459 .39844 L
.74625 .38381 L
.74659 .37001 L
.74694 .358 L
.74729 .34848 L
.74763 .34172 L
.74798 .3376 L
.74833 .33563 L
.74867 .33509 L
.74902 .33519 L
.74937 .33521 L
.74971 .3347 L
.75006 .33349 L
.75041 .33178 L
.75075 .33008 L
.7511 .32906 L
.75145 .32949 L
.75179 .33202 L
Mistroke
.75214 .33705 L
.75249 .34465 L
.75284 .35449 L
.75318 .3659 L
.75353 .37797 L
.75388 .38972 L
.75422 .40028 L
.75457 .40907 L
.75492 .41593 L
.75526 .42114 L
.75561 .42539 L
.75596 .4296 L
.7563 .43474 L
.75665 .4416 L
.757 .45055 L
.75734 .46147 L
.75769 .47372 L
.75804 .48626 L
.75838 .49787 L
.75873 .50738 L
.75908 .51398 L
.75942 .51741 L
.75977 .51798 L
.76012 .51659 L
.76047 .51447 L
.76081 .51294 L
.76116 .51309 L
.76151 .51554 L
.76185 .52023 L
.7622 .52649 L
.76255 .53311 L
.76289 .53863 L
.76324 .54164 L
.76359 .54109 L
.76393 .53653 L
.76428 .52817 L
.76463 .51684 L
.76497 .50382 L
.76532 .49054 L
.76567 .47831 L
.76601 .46802 L
.76636 .46001 L
.76671 .45404 L
.76706 .44939 L
.7674 .44502 L
.76775 .4399 L
.7681 .43316 L
.76844 .4244 L
.76879 .41367 L
.76914 .40155 L
Mistroke
.76948 .38894 L
.76983 .37695 L
.77018 .3666 L
.77052 .35868 L
.77087 .35355 L
.77122 .35109 L
.77156 .35076 L
.77191 .35167 L
.77226 .35283 L
.7726 .3533 L
.77295 .35243 L
.7733 .34998 L
.77364 .34617 L
.77399 .34166 L
.77434 .33742 L
.77469 .33453 L
.77503 .33398 L
.77538 .33644 L
.77573 .3421 L
.77607 .35066 L
.77642 .36132 L
.77677 .37298 L
.77711 .38443 L
.77746 .39464 L
.77781 .40292 L
.77815 .40911 L
.7785 .4136 L
.77885 .41721 L
.77919 .42101 L
.77954 .42605 L
.77989 .43306 L
.78023 .44231 L
.78058 .45347 L
.78093 .46569 L
.78127 .47777 L
.78162 .48843 L
.78197 .49662 L
.78232 .50176 L
.78266 .50385 L
.78301 .50355 L
.78336 .50192 L
.7837 .50023 L
.78405 .49964 L
.7844 .50087 L
.78474 .50411 L
.78509 .50889 L
.78544 .51426 L
.78578 .51903 L
.78613 .52203 L
.78648 .52246 L
Mistroke
.78682 .52008 L
.78717 .51526 L
.78752 .50891 L
.78786 .50223 L
.78821 .49644 L
.78856 .49248 L
.78891 .49072 L
.78925 .49094 L
.7896 .49229 L
.78995 .49356 L
.79029 .49343 L
.79064 .4908 L
.79099 .48501 L
.79133 .47604 L
.79168 .46451 L
.79203 .45152 L
.79237 .43843 L
.79272 .42654 L
.79307 .41685 L
.79341 .40981 L
.79376 .40529 L
.79411 .40262 L
.79445 .40078 L
.7948 .39866 L
.79515 .39527 L
.79549 .39006 L
.79584 .38296 L
.79619 .37444 L
.79654 .36537 L
.79688 .35685 L
.79723 .34992 L
.79758 .34536 L
.79792 .3435 L
.79827 .34412 L
.79862 .34654 L
.79896 .34976 L
.79931 .35267 L
.79966 .35434 L
.8 .35422 L
.80035 .35228 L
.8007 .34907 L
.80104 .34557 L
.80139 .34298 L
.80174 .34249 L
.80208 .34497 L
.80243 .35077 L
.80278 .35962 L
.80312 .37068 L
.80347 .38269 L
.80382 .3943 L
Mistroke
.80417 .40431 L
.80451 .412 L
.80486 .41726 L
.80521 .42063 L
.80555 .42314 L
.8059 .42607 L
.80625 .43059 L
.80659 .43748 L
.80694 .44691 L
.80729 .45838 L
.80763 .4708 L
.80798 .48278 L
.80833 .49299 L
.80867 .50042 L
.80902 .50473 L
.80937 .50625 L
.80971 .50597 L
.81006 .50524 L
.81041 .50544 L
.81076 .50764 L
.8111 .51226 L
.81145 .51905 L
.8118 .52708 L
.81214 .53503 L
.81249 .54154 L
.81284 .54555 L
.81318 .54662 L
.81353 .54504 L
.81388 .54173 L
.81422 .53806 L
.81457 .53541 L
.81492 .53485 L
.81526 .53678 L
.81561 .54085 L
.81596 .54598 L
.8163 .55067 L
.81665 .55329 L
.817 .55257 L
.81734 .54787 L
.81769 .53938 L
.81804 .52805 L
.81839 .51535 L
.81873 .50296 L
.81908 .49229 L
.81943 .48419 L
.81977 .47876 L
.82012 .47533 L
.82047 .47271 L
.82081 .46944 L
.82116 .46427 L
Mistroke
.82151 .45644 L
.82185 .44586 L
.8222 .43318 L
.82255 .41958 L
.82289 .40649 L
.82324 .39518 L
.82359 .38652 L
.82393 .3807 L
.82428 .37723 L
.82463 .37507 L
.82497 .37293 L
.82532 .36957 L
.82567 .36414 L
.82602 .35642 L
.82636 .34684 L
.82671 .3364 L
.82706 .32644 L
.8274 .31827 L
.82775 .31292 L
.8281 .31084 L
.82844 .31182 L
.82879 .31508 L
.82914 .31943 L
.82948 .32357 L
.82983 .32644 L
.83018 .32741 L
.83052 .32648 L
.83087 .3242 L
.83122 .32156 L
.83156 .3197 L
.83191 .31962 L
.83226 .32191 L
.83261 .3266 L
.83295 .33315 L
.8333 .3406 L
.83365 .34777 L
.83399 .35361 L
.83434 .35747 L
.83469 .35922 L
.83503 .35938 L
.83538 .3589 L
.83573 .35899 L
.83607 .36075 L
.83642 .36492 L
.83677 .37163 L
.83711 .3804 L
.83746 .39022 L
.83781 .39982 L
.83815 .40803 L
.8385 .41407 L
Mistroke
.83885 .41781 L
.83919 .4198 L
.83954 .4212 L
.83989 .42341 L
.84024 .42779 L
.84058 .4352 L
.84093 .4458 L
.84128 .45895 L
.84162 .47333 L
.84197 .48726 L
.84232 .49912 L
.84266 .50774 L
.84301 .51272 L
.84336 .51451 L
.8437 .5143 L
.84405 .5137 L
.8444 .51429 L
.84474 .5172 L
.84509 .52279 L
.84544 .53057 L
.84578 .53933 L
.84613 .54746 L
.84648 .55342 L
.84682 .55619 L
.84717 .55554 L
.84752 .55213 L
.84787 .54734 L
.84821 .54287 L
.84856 .54033 L
.84891 .54072 L
.84925 .5442 L
.8496 .55003 L
.84995 .55675 L
.85029 .56264 L
.85064 .56612 L
.85099 .56628 L
.85133 .56308 L
.85168 .55741 L
.85203 .55079 L
.85237 .54503 L
.85272 .54165 L
.85307 .54153 L
.85341 .54468 L
.85376 .55021 L
.85411 .55671 L
.85445 .56257 L
.8548 .56656 L
.85515 .56812 L
.8555 .56752 L
.85584 .56581 L
Mistroke
.85619 .56444 L
.85654 .56481 L
.85688 .56784 L
.85723 .57366 L
.85758 .58152 L
.85792 .58998 L
.85827 .59734 L
.85862 .60207 L
.85896 .60332 L
.85931 .6011 L
.85966 .59636 L
.86 .59067 L
.86035 .58578 L
.8607 .58317 L
.86104 .58353 L
.86139 .58665 L
.86174 .59143 L
.86209 .59619 L
.86243 .59921 L
.86278 .59916 L
.86313 .59556 L
.86347 .58887 L
.86382 .5804 L
.86417 .57191 L
.86451 .56516 L
.86486 .56135 L
.86521 .56086 L
.86555 .5631 L
.8659 .56671 L
.86625 .57 L
.86659 .57137 L
.86694 .56981 L
.86729 .56515 L
.86763 .55806 L
.86798 .54983 L
.86833 .54194 L
.86867 .5356 L
.86902 .53138 L
.86937 .52901 L
.86972 .52752 L
.87006 .52547 L
.87041 .52145 L
.87076 .51451 L
.8711 .50444 L
.87145 .49188 L
.8718 .47813 L
.87214 .46479 L
.87249 .45332 L
.87284 .44459 L
.87318 .43867 L
Mistroke
.87353 .43483 L
.87388 .43175 L
.87422 .42794 L
.87457 .42221 L
.87492 .41399 L
.87526 .40351 L
.87561 .39175 L
.87596 .38008 L
.8763 .36992 L
.87665 .36225 L
.877 .35732 L
.87735 .35464 L
.87769 .35306 L
.87804 .35117 L
.87839 .34772 L
.87873 .34202 L
.87908 .33412 L
.87943 .32487 L
.87977 .31561 L
.88012 .30784 L
.88047 .30271 L
.88081 .30075 L
.88116 .30166 L
.88151 .30441 L
.88185 .30752 L
.8822 .30951 L
.88255 .30927 L
.88289 .30638 L
.88324 .3012 L
.88359 .29474 L
.88394 .28831 L
.88428 .28315 L
.88463 .28003 L
.88498 .27904 L
.88532 .27958 L
.88567 .28057 L
.88602 .28075 L
.88636 .27911 L
.88671 .27518 L
.88706 .26917 L
.8874 .2619 L
.88775 .25455 L
.8881 .24832 L
.88844 .24401 L
.88879 .24188 L
.88914 .24148 L
.88948 .24187 L
.88983 .24188 L
.89018 .24048 L
.89052 .23708 L
Mistroke
.89087 .23174 L
.89122 .22512 L
.89157 .21832 L
.89191 .21249 L
.89226 .20855 L
.89261 .20687 L
.89295 .20719 L
.8933 .20865 L
.89365 .2101 L
.89399 .21035 L
.89434 .20859 L
.89469 .20454 L
.89503 .19855 L
.89538 .19144 L
.89573 .18428 L
.89607 .17806 L
.89642 .17336 L
.89677 .17028 L
.89711 .16837 L
.89746 .16683 L
.89781 .16476 L
.89815 .16146 L
.8985 .15663 L
.89885 .15046 L
.8992 .14359 L
.89954 .13686 L
.89989 .13109 L
.90024 .12683 L
.90058 .12419 L
.90093 .12281 L
.90128 .12202 L
.90162 .12102 L
.90197 .11914 L
.90232 .11606 L
.90266 .11184 L
.90301 .10697 L
.90336 .10212 L
.9037 .098 L
.90405 .09506 L
.9044 .09343 L
.90474 .09283 L
.90509 .09273 L
.90544 .09245 L
.90579 .09147 L
.90613 .08954 L
.90648 .0868 L
.90683 .08369 L
.90717 .08087 L
.90752 .07897 L
.90787 .07838 L
Mistroke
.90821 .07916 L
.90856 .08096 L
.90891 .08316 L
.90925 .08502 L
.9096 .08592 L
.90995 .08551 L
.91029 .08386 L
.91064 .08136 L
.91099 .07866 L
.91133 .07643 L
.91168 .07515 L
.91203 .07501 L
.91237 .07582 L
.91272 .07708 L
.91307 .07817 L
.91342 .07851 L
.91376 .07777 L
.91411 .07594 L
.91446 .07336 L
.9148 .07059 L
.91515 .06826 L
.9155 .06683 L
.91584 .06649 L
.91619 .0671 L
.91654 .06821 L
.91688 .06924 L
.91723 .06965 L
.91758 .06909 L
.91792 .06755 L
.91827 .06534 L
.91862 .063 L
.91896 .06113 L
.91931 .06021 L
.91966 .06047 L
.92 .06178 L
.92035 .06371 L
.9207 .06564 L
.92105 .06695 L
.92139 .06719 L
.92174 .06622 L
.92209 .06423 L
.92243 .06165 L
.92278 .05907 L
.92313 .05701 L
.92347 .05581 L
.92382 .05549 L
.92417 .0558 L
.92451 .05628 L
.92486 .05644 L
.92521 .05588 L
Mistroke
.92555 .05441 L
.9259 .05215 L
.92625 .04943 L
.92659 .04673 L
.92694 .04451 L
.92729 .04306 L
.92764 .04245 L
.92798 .04248 L
.92833 .04278 L
.92868 .04293 L
.92902 .04255 L
.92937 .04148 L
.92972 .03975 L
.93006 .03762 L
.93041 .03547 L
.93076 .03366 L
.9311 .03244 L
.93145 .03185 L
.9318 .03175 L
.93214 .03183 L
.93249 .03174 L
.93284 .0312 L
.93318 .03011 L
.93353 .02854 L
.93388 .02677 L
.93422 .02515 L
.93457 .02401 L
.93492 .02355 L
.93527 .02381 L
.93561 .02459 L
.93596 .02558 L
.93631 .02641 L
.93665 .02679 L
.937 .02658 L
.93735 .02583 L
.93769 .02477 L
.93804 .02372 L
.93839 .02297 L
.93873 .02275 L
.93908 .02306 L
.93943 .02378 L
.93977 .02462 L
.94012 .02527 L
.94047 .02547 L
.94081 .02512 L
.94116 .02427 L
.94151 .02316 L
.94185 .02208 L
.9422 .02133 L
.94255 .02108 L
Mistroke
.9429 .02135 L
.94324 .02201 L
.94359 .02276 L
.94394 .0233 L
.94428 .02341 L
.94463 .02297 L
.94498 .02207 L
.94532 .02093 L
.94567 .01987 L
.94602 .01919 L
.94636 .01909 L
.94671 .0196 L
.94706 .02058 L
.9474 .02176 L
.94775 .02284 L
.9481 .02354 L
.94844 .02375 L
.94879 .02349 L
.94914 .02294 L
.94948 .02239 L
.94983 .02211 L
.95018 .02226 L
.95053 .02289 L
.95087 .02386 L
.95122 .02494 L
.95157 .02582 L
.95191 .02629 L
.95226 .02621 L
.95261 .02565 L
.95295 .0248 L
.9533 .02394 L
.95365 .02334 L
.95399 .02321 L
.95434 .02357 L
.95469 .02431 L
.95503 .0252 L
.95538 .02595 L
.95573 .02631 L
.95607 .02617 L
.95642 .02556 L
.95677 .02467 L
.95712 .02377 L
.95746 .02315 L
.95781 .02299 L
.95816 .02336 L
.9585 .02412 L
.95885 .02505 L
.9592 .02583 L
.95954 .02619 L
.95989 .02597 L
Mistroke
.96024 .02516 L
.96058 .02392 L
.96093 .02252 L
.96128 .02127 L
.96162 .02042 L
.96197 .02007 L
.96232 .0202 L
.96266 .02063 L
.96301 .02111 L
.96336 .02138 L
.9637 .02128 L
.96405 .02075 L
.9644 .01991 L
.96475 .01895 L
.96509 .01812 L
.96544 .01762 L
.96579 .01757 L
.96613 .01794 L
.96648 .01855 L
.96683 .0192 L
.96717 .01965 L
.96752 .01973 L
.96787 .01939 L
.96821 .01872 L
.96856 .01791 L
.96891 .01717 L
.96925 .01673 L
.9696 .01669 L
.96995 .01704 L
.97029 .01766 L
.97064 .01835 L
.97099 .01889 L
.97133 .01912 L
.97168 .01896 L
.97203 .01846 L
.97238 .01776 L
.97272 .01705 L
.97307 .0165 L
.97342 .01623 L
.97376 .01624 L
.97411 .01645 L
.97446 .0167 L
.9748 .01681 L
.97515 .01667 L
.9755 .01623 L
.97584 .01553 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[79]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001Cooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0ol0000Cooooo`;o00001?ooool01?l0003oooooooooooooool5
o`0001Oooooo0_l0000Jooooo`;o00001?ooool01?l0003oooooooooooooool5o`0001?ooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0ol0000Cooooo`;o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00007?ooool002_ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000001;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Aooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00005_ooool01?l0003oooooooooool0
000Hooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00004_ooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000001_ooooo000Tooooo`Go00000_ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000002oooool5o`0000;ooooo00Co0000oooooooooooo
00001oooool5o`0000_ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool05_ooool01?l0003oooooooooool0000Hooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool04_ooool01?l0003oooooooooool00007ooooo`Go00004_ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000006oooool002_ooooo00Co0000oooooooo
oooo00001oooool4o`0001?ooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
000Cooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool05Oooool01?l0003ooooo
ooooool0000Hooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool04Oooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo0000
1oooool4o`0001cooooo000[ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
5?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000001?ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000001Kooooo00Co0000oooooooooooo00006?oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000004_ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000001?ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0Mooooo`00:oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo01?ooooo00Co0000oooooooooooo00002Oooool2o`0001?ooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000001Kooooo00Co0000oooooooooooo00006?ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000004_ooool01?l0003ooooooooo
ool00009ooooo`;o00004oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo01co
oooo000/ooooo`;o00002_ooool2o`0001Cooooo0_l0000;ooooo`03o`000?oooooooooo01;ooooo
0_l00009ooooo`?o00006?ooool2o`0001[ooooo0_l00009ooooo`?o00005?ooool2o`0000_ooooo
00?o0000ooooooooool04_ooool2o`0000[ooooo0_l0000Looooo`00oooooolQooooo`00oooooolQ
ooooo`007oooool00ol0003oooooooooo`3nooooo`007oooool00ol0003oooooooooo`3nooooo`00
6Oooooolo`0000_ooooo000Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03ooo
ool001oooooo1?l00004ooooo`03o`000?oooooooooo0=cooooo0_l00003ooooo`Co00004Oooool0
01oooooo00?o0000ooooooooool02Ol0003Iooooo`So00005?ooool001oooooo00Co0000oooooooo
oooooooo1?l000001?oooooo0000o`000?l0003Hooooo`?o00000_ooool3o`0001Gooooo000Ooooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`0Joooo
o`007oooool2o`0000[ooooo00?o0000ooooooooool0e?ooool2o`0001cooooo000Oooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0e?ooool00ol0003oooooooooo`0Kooooo`007ooo
ool00ol0003oooooooooo`09ooooo`;o0000eOooool00ol0003oooooooooo`0Kooooo`007oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0=;ooooo0_l0000Mooooo`007oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo0=;ooooo00?o0000ooooooooool07?ooool001oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Booooo`03o`000?oooooooooo01co
oooo000Oooooo`;o00002oooool2o`000=?ooooo00?o0000ooooooooool07?ooool001oooooo00?o
0000ooooooooool02oooool2o`000=3ooooo0_l0000Oooooo`007oooool00ol0003oooooooooo`0;
ooooo`;o0000d?ooool2o`0001oooooo000Oooooo`03o`000?oooooooooo00cooooo0_l0003?oooo
o`03o`000?oooooooooo01kooooo000Oooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0Oooooo`007oooool00ol0003oooooooooo`0=ooooo`;o0000
c?ooool2o`00027ooooo000Oooooo`;o00003oooool2o`000<_ooooo00?o0000ooooooooool08?oo
ool001oooooo00?o0000ooooooooool03_ooool2o`000<[ooooo0_l0000Rooooo`007oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool08Oooool001oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo027o
oooo000<ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo027ooooo000;ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool08Oooool000_ooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0aoooool00ol0003oooooooooo`0Qooooo`002oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00?ooooo0ol0000@ooooo`03o`000?oooooooooo0<Oooooo00?o0000oooo
ooooool08Oooool000_ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`36ooooo`03o`000?oooooo
oooo02;ooooo000;ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0a_ooool00ol0003ooooooooo
o`0Rooooo`003?ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0a_ooool00ol0003oooooooooo`0Rooooo`007oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool08_ooool001oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo02;ooooo000Oooooo`;o0000
4Oooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo02;ooooo000Oooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`0Rooooo`007oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool08_ooool0
01oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`35ooooo`03o`000?oooooooooo
02;ooooo000Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0aOooool00ol0003o
ooooooooo`0Rooooo`007oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<Gooooo
00?o0000ooooooooool08_ooool001oooooo0_l0000Booooo`03o`000?oooooooooo0<Cooooo00?o
0000ooooooooool08oooool001oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`34
ooooo`03o`000?oooooooooo02?ooooo000Oooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0a?ooool00ol0003oooooooooo`0Sooooo`007oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo0<Cooooo00?o0000ooooooooool08oooool001oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo02?ooooo000Oooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0a?ooool00ol0003oooooooooo`0Sooooo`007oooool2
o`0001;ooooo00?o0000ooooooooool0a?ooool00ol0003oooooooooo`0Sooooo`007oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo0<Cooooo00?o0000ooooooooool08oooool001oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo02?o
oooo000Oooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0`oooool00ol0003ooooo
ooooo`0Sooooo`003?ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo02?ooooo000;
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool08oooool000_ooooo00Co0000
oooooooooooo00001oooool5o`0000Cooooo0ol0000Booooo`03o`000?oooooooooo0<;ooooo00?o
0000ooooooooool09?ooool000_ooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0`_ooool00ol0003ooooo
ooooo`0Tooooo`002oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`32ooooo`03o`000?oooooooooo02Cooooo
000;ooooo`04o`000?ooooooooooo`0000Wooooo0_l00005ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0`_ooool00ol0003oooooooooo`0Tooooo`003?ooool2o`0000_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0<;ooooo00?o
0000ooooooooool09?ooool001oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`31
ooooo`03o`000?oooooooooo02Cooooo000Oooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0`Oooool00ol0003oooooooooo`0Tooooo`007oooool2o`0001Cooooo00?o0000oooooooo
ool0`Oooool00ol0003oooooooooo`0Tooooo`007oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo0<3ooooo00?o0000ooooooooool09Oooool001oooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo02Gooooo000Oooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0`?ooool00ol0003oooooooooo`0Uooooo`007oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool09Oooool001oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo02Go
oooo000Oooooo`;o00005?ooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo02Gooooo
000Oooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0_oooool00ol0003ooooooooo
o`0Uooooo`007oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0;oooooo00?o0000
ooooooooool09Oooool001oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2ooooo
o`03o`000?oooooooooo02Gooooo000Oooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0__ooool00ol0003oooooooooo`0Vooooo`007oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo0;kooooo00?o0000ooooooooool09_ooool001oooooo0_l0000Eooooo`03o`000?oo
oooooooo0;kooooo00?o0000ooooooooool09_ooool001oooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`2nooooo`03o`000?oooooooooo02Kooooo000Oooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0__ooool00ol0003oooooooooo`0Vooooo`007oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool09_ooool000cooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0__ooool00ol0003oooooooooo`0Vooooo`002oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0;cooooo0_l0000Xooooo`002oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001?ooool3o`0001Gooooo00?o0000ooooooooool0_?ooool2o`00
02Sooooo000;ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool09oooool000_ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`2Rooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09oooool000_o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool02_ooool2o`000:?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Wooooo`003?ooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02Oooool3o`000:?ooooo0_l0000;ooooo`03o`000?oooooooooo02Oo
oooo000Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool3o`0002Gooooo
0_l0001Eooooo`03o`000?oooooooooo02Cooooo0_l0000;ooooo`03o`000?oooooooooo02Oooooo
000Oooooo`;o00005oooool00ol0003oooooooooo`08ooooo`?o00004_ooool00ol0003ooooooooo
o`0@ooooo`;o00006Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo0_l0
000Booooo`;o00004_ooool2o`0000_ooooo00?o0000ooooooooool09oooool001oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000cooooo00?o0000
ooooooooool00_ooool2o`0000cooooo00?o0000ooooooooool00oooool2o`0001Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool05oooool2o`0000Gooooo00?o0000ooooooooool02_ooool2o`0000Cooooo0_l0000;
ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool09oooool001oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000cooooo00?o0000oooo
ooooool00_ooool2o`0000cooooo00?o0000ooooooooool00oooool2o`0001Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05oooool2o`0000Gooooo00?o0000ooooooooool02_ooool2o`0000Cooooo0_l0000;oooo
o`03o`000?oooooo000000_ooooo00?o0000ooooooooool09oooool001oooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool00oooool2o`0000Cooooo00?o0000ooooool000002oooool00ol0003oooooooooo`03ooooo`;o
00006Oooool2o`0000Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01Oooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo0_l00004ooooo`;o
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000[ooooo00?o0000oooooooo
ool0:?ooool001oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooo000000Gooooo0_l00004ooooo`;o00001?ooool00ol0003oooooo`00000;ooooo`03o`00
0?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0oooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool0
2_ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooo`00000:ooooo`03o`00
0?oooooooooo02Sooooo000Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooo`000005ooooo`;o00001?ooool3o`0000?ooooo00?o0000ooooool000002ooo
ool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`0:ooooo`;o00001Ooo
ool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`;o00003?oo
ool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0000_ooooo0_l00004ooooo`;o00001?oo
ool2o`0000Gooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`0Xooooo`007oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000001Oooool2
o`0000Cooooo0ol00003ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool00oooool2
o`0000Gooooo0_l0000;ooooo`;o00001Oooool2o`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`;o00003?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool2
o`0000_ooooo0_l00003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooool000002_ooool0
0ol0003oooooooooo`0Xooooo`007oooool2o`0001Oooooo00?o0000ooooooooool01oooool2o`00
0003ooooool0003ooooo00Cooooo0_l00004ooooo`03o`000?oooooo000000?ooooo00?o0000oooo
ool000002oooool00ol0003oooooooooo`03ooooo`;o00001?ooool3o`0000_ooooo0_l00005oooo
o`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00004oooo
o`;o00001?ooool2o`0000Gooooo0_l0000<ooooo`;o00001?ooool2o`0000Gooooo0_l0000:oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooool000001?ooool2o`0000Gooooo00Co0000oooo
ool0003o00002Oooool00ol0003oooooooooo`0Xooooo`007oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000ooooo`04ooooo`;o00001?ooool00ol0
003oooooo`000003ooooo`03o`000?oooooo000000[ooooo0_l00005ooooo`;o00001?ooool00ol0
003oooooo`000006ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`;o00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o00001?ooool2o`00
00Gooooo0_l00004ooooo`03o`000?oooooooooo00Gooooo0_l00004ooooo`;o00001Oooool2o`00
00[ooooo00?o0000ooooool000000oooool00ol0003oooooo`000004ooooo`;o00001Oooool01?l0
003oooooo`000?l00009ooooo`03o`000?oooooooooo02Sooooo000Oooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00005ooooo`;o00001?ooool0
0ol0003oooooo`000003ooooo`03o`000?oooooo000000[ooooo0_l00005ooooo`;o00001?ooool0
0ol0003oooooo`000004ooooo`03o`000?oooooo000000Cooooo0_l00005ooooo`;o00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o00001?ooool2
o`0000Gooooo0_l00004ooooo`?o00001Oooool2o`0000Cooooo0_l00005ooooo`;o00002_ooool0
0ol0003oooooo`000003ooooo`03o`000?oooooo000000Cooooo0_l00005ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool0:?ooool001oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Gooooo0_l00004ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooool000002_ooool2o`0000Gooooo0_l00004ooooo`03o`000?oo
oooo000000Cooooo00?o0000ooooool000001?ooool2o`0000Gooooo0_l00005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l00004ooooo`;o00001Ooo
ool2o`0000Cooooo0ol00004ooooo`03o`000?oooooo000000Cooooo0_l00005ooooo`;o00002_oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooo000000Cooooo00?o0000ooooool000001?oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo02Sooooo000Oooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00005ooooo`;o0000
1?ooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000[ooooo0_l00005ooooo`;o0000
1?ooool00ol0003oooooo`000004ooooo`?o00001?ooool2o`0000Gooooo0_l00004ooooo`;o0000
1?ooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0ol00003ooooo`?o0000
1?ooool00ol0003oooooo`000004ooooo`;o00001Oooool2o`0000[ooooo00?o0000ooooool00000
0oooool00ol0003oooooo`000004ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`0Xooooo`007oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Oooooo00Co0000oooooooooooo00001Oooool2o`0000Cooooo00?o0000ooooool0
00000oooool00ol0003oooooo`00000:ooooo`;o00001Oooool2o`0000Cooooo00?o0000ooooool0
00001?ooool3o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`;o
00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo000000?ooooo0ol00004ooooo`03
o`000?oooooo000000Cooooo0_l00005ooooo`;o00002_ooool00ol0003oooooo`000003ooooo`03
o`000?oooooo000000Cooooo00?o0000ooooool000001?ooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo02Sooooo000Oooooo`;o00005oooool00ol0003oooooooooo`07ooooo`04
o`000?ooooooooooo`0000Gooooo0_l00004ooooo`03o`000?oooooo000000?ooooo00?o0000oooo
ool000002_ooool2o`0000Gooooo0_l00004ooooo`03o`000?oooooo000000Cooooo0ol00003oooo
o`03o`000?oooooo000000Gooooo0_l00003ooooo`?o00001?ooool00ol0003oooooo`000005oooo
o`;o00001?ooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooo000000?ooooo1?l00003oooo
o`03o`000?oooooo000000Cooooo0_l00005ooooo`;o00002_ooool00ol0003oooooo`000003oooo
o`03o`000?oooooo000000Cooooo00?o0000ooooool000001?ooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo02Sooooo000Oooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00004ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
000000Cooooo0_l00004ooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`03o`000?oooooo
000000Cooooo0ol00003ooooo`;o000000?oooooo`000?ooool00_ooool01?l0003oooooo`000?l0
0003ooooo`?o00001?ooool3o`0000?ooooo00Co0000ooooool0003o00000oooool00ol0003ooooo
o`000003ooooo`Co00000oooool00ol0003oooooo`000004ooooo`;o00001Oooool2o`0000Kooooo
00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000001?ooool00ol0
003oooooo`000004ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0:?ooool0
01oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooool000000oooool01?l0003oooooo`000?l00003ooooo`03o`000?oooooo000000Cooooo
0_l00004ooooo`03o`000?oooooo000000?ooooo00Co0000ooooool0003o00000oooool00ol0003o
ooooo`000003ooooo`Co00000oooool2o`000003ooooool0003ooooo00;ooooo00Co0000ooooool0
003o00000_ooool2o`000003ooooool0003ooooo00?ooooo0ol00003ooooo`04o`000?oooooo0000
o`0000?ooooo00?o0000ooooool000000oooool2o`000003ooooool0003ooooo00;ooooo00?o0000
ooooool000001?ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?ooool00_ooool0
0ol0003oooooo`000003ooooo`03o`000?oooooo000000Cooooo00?o0000ooooool000001?ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo02Sooooo000Oooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo
1Ol00003ooooo`03o`000?oooooo000000Cooooo0_l00004ooooo`03o`000?oooooo000000?ooooo
00Co0000ooooool0003o00000oooool00ol0003oooooo`000003ooooo`Co00000oooool2o`000003
ooooool0003ooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`?o00000oooool01?l0003oooooo`000?l00003ooooo`03o`000?oooooo000000?ooooo0_l0
00000ooooooo0000ooooo`02ooooo`03o`000?oooooo000000Cooooo0_l00005ooooo`03o`000?oo
oooo000000;ooooo1Ol00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000001?oo
ool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
:?ooool000cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000;o
oooo1Ol00003ooooo`03o`000?oooooo000000Cooooo0_l00004ooooo`03o`000?oooooo000000?o
oooo00Co0000ooooool0003o00000oooool00ol0003oooooo`000003ooooo`Co00000oooool2o`00
0003ooooool0003ooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`?o00000oooool01?l0003oooooo`000?l00003ooooo`03o`000?oooooo000000?ooooo
0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooo000000Cooooo00?o0000ooooool00000
1?ooool00ol0003oooooo`000002ooooo`Go00000_ooool00ol0003oooooo`000003ooooo`03o`00
0?oooooo000000?ooooo0_l000000ooooooo0000ooooo`03ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool0:?ooool000_ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooool000000_ooool5o`0000?ooooo00?o0000ooooool000001?oo
ool2o`0000Cooooo00?o0000ooooool000000oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooo000000?ooooo0_l000000ooooooo0000ooooo`02ooooo`;o000000?oooooo`000?ooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo0ol00003oooo
o`04o`000?oooooo0000o`0000?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooo000000Cooooo00?o0000ooooool000001?ooool00ol0003oooooo`00
0002ooooo`Go00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00Co
0000oooooooooooo00001?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo02So
oooo000;ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`?o00005oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000_oo
ool5o`0000?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooo`000?l00002oooo
o`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000ooooool00000
0oooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?ooool00_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooo000000Cooooo00?o0000ooooool000000oooool01?l0
003oooooooooool00002ooooo`Go00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Wooooo
00?o0000ooooooooool0:?ooool000_ooooo00Co0000oooooooooooo00002?ooool3o`0000Gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000oooo
ool000000_ooool00ol0003oooooo`000002o`0000?ooooo00?o0000ooooool000000oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooo`000002o`000005ooooool0003o0000ooooool000000oooool00ol0003ooooo
ooooo`02o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`05o`000?oooooo0000ooooool000000oooool01?l0003oooooo`000?l00002ooooo`;o000000?o
ooooo`000?ooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000Cooooo
00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`?o000000Ooooooo`000?oo
ooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`0Xooooo`002ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000;o00000_ooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooo000000;o000000Goooooo`000?ooooooooooo`000003ooooo`03o`000?oooooooooo
00;o000000?oooooo`000?l000000_ooool01?l0003oooooooooool00002ooooo`;o000000?ooooo
o`000?l000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_l0
00000ooooooo0000ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool00000
0oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo0ol000001ooo
oooo0000oooooooooooo0000ooooool000000oooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo02So
oooo000;ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oo
oooo000000;ooooo00Go0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooool000000_l000001?oooooo0000ooooooooool2o`0000;ooooo00?o
0000ooooooooool00_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003ooooo
ooooo`02o`000003ooooool0003ooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool0
1Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooool000000oooool00ol0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000009ooooo`03
o`000?oooooooooo02Sooooo000<ooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ool00003ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooo00000_ooool2o`00
0006ooooool0003o0000o`000?oooooo00000_ooool2o`0000;ooooo00?o0000ooooooooool00_l0
00000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooo`000002o`000003oooo
ool0003o000000;ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0003ooooo00;o
oooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0:Oooool001oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002oooo
o`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool01_l0003ooooooooooooooooo0000ooooo`;o00000_ooool01_l0003ooooooooooooooooo
0000ooooo`;o000000Koooooo`000?l0003o0000ooooool00002ooooo`;o00000_ooool00ol0003o
ooooooooo`02o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo00000_ooool2o`00
0003ooooool0003o000000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooo0000
00;o000000?oooooo`000?l000000_ooool01?l0003oooooooooool00002ooooo`;o000000?ooooo
o`000?ooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`007oooool2o`0001Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_oo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000;ooooo00Ko0000oooooooooooo
ooooo`000?ooool2o`0000;ooooo0_l000001?oooooo0000ooooooooool2o`0000;ooooo00?o0000
ooooooooool00_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`0000;ooooo0_l0
00000ooooooo0000o`000003ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000ooooool00000
0_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`0000;ooooo0_l000000ooooooo
0000ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo000Oooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01_l0003ooooooooooooooooo0000ooooo`;o00000_ooool01_l0003ooooooooooooo
oooo0000ooooo`;o00000_ooool2o`000004ooooool0003oooooooooo`;o00000_ooool00ol0003o
ooooooooo`02o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo00000_ooool2o`00
0003ooooool0003o000000?ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000002
o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0
003ooooo00;ooooo00Co0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`00
00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0:Oooool001oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`00
0?ooooooooooooooool0003ooooo0_l00002ooooo`06o`000?ooooooooooooooool0003ooooo0_l0
0002ooooo`;o000000Coooooo`000?oooooooooo0_l00002ooooo`03o`000?oooooooooo00;o0000
00?oooooo`000?ooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooo0000o`00
00?ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000002o`000006ooooool0003o
0000o`000?oooooo00000_ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00;ooooo
00Co0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000Cooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0:Oooool001oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooo000000;ooooo00Go0000ooooool0003oooooo`000002ooooo`;o00000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000oooool01?l0003oooooo`000?l00002ooooo`;o000000?o
ooooo`000?ooool00oooool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?ooool00_oo
ool01?l0003oooooooooool00003ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000ooooool0
00000oooool01?l0003oooooo`000?l00002ooooo`Co00001?ooool01?l0003oooooo`000?l00002
ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000ooooool000000_l00002ooooo`03o`000?oo
oooo000000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0:Oooool001oooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooo000000;ooooo0ol000001?oooooo0000ooooooooool3o`000003
ooooool0003ooooo00;ooooo00?o0000ooooool000000oooool01?l0003oooooo`000?l00003oooo
o`03o`000?oooooo000000Cooooo0_l00003ooooo`;o000000?oooooo`000?ooool00_ooool01?l0
003oooooooooool00004ooooo`?o00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo
000000?ooooo1?l00004ooooo`03o`000?oooooo000000?ooooo00Co0000ooooool0003o00000_oo
ool00ol0003oooooo`000002o`0000;ooooo00?o0000ooooool000001?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Y
ooooo`007oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool00000
0oooool4o`0000;ooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooo000000?ooooo
00Co0000ooooool0003o00000oooool00ol0003oooooo`000004ooooo`;o00001?ooool00ol0003o
ooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo0_l00004ooooo`03o`000?oooooo0000
00?ooooo00?o0000ooooool000001?ooool3o`0000Cooooo0_l00004ooooo`04o`000?oooooo0000
o`0000;ooooo1Ol00002ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool001oo
oooo0_l0000Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000000oooool4o`0000;ooooo0ol0
00000ooooooo0000ooooo`02ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000001?oo
ool00ol0003oooooo`000004ooooo`;o00001?ooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000Cooooo0_l00004ooooo`03o`000?oooooo000000Cooooo0_l00005ooooo`;o0000
1?ooool2o`0000Cooooo00Co0000ooooool0003o00000_ooool5o`0000;ooooo00?o0000ooooool0
00001?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0:Oooool001oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooo000000?ooooo1?l00002ooooo`Go00000oooool00ol0003oooooo`000003ooooo`;o
00001Oooool00ol0003oooooo`000004ooooo`;o00001?ooool00ol0003oooooo`000003ooooo`04
o`000?ooooooooooo`0000Cooooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l00004oooo
o`;o00001?ooool4o`0000;ooooo1Ol00002ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ool000000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo000O
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooool000001?ooool00ol0003oooooo`000003ooooo`Co0000
0_ooool5o`0000?ooooo00?o0000ooooool000000oooool2o`0000Gooooo0_l00005ooooo`;o0000
1?ooool00ol0003oooooo`000004ooooo`03o`000?oooooo000000Cooooo0_l00004ooooo`;o0000
1Oooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool4o`0000;ooooo1Ol00002ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooool000000_ooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02Wooooo000Oooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000001?ooool0
0ol0003oooooo`000003ooooo`Co00000_ooool4o`0000Cooooo00?o0000ooooool000000oooool2
o`0000Gooooo0_l00005ooooo`;o00001?ooool00ol0003oooooo`000004ooooo`03o`000?oooooo
000000Cooooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool4
o`0000;ooooo1?l00003ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000000_ooool0
0ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo000Oooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooool000001?ooool00ol0003oooooo`000003ooooo`Co00000_ooool4o`0000Co
oooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000Go
oooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool4o`0000;o
oooo1?l00003ooooo`03o`000?oooooo000000Gooooo0_l00003ooooo`03o`000?oooooo000000?o
oooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0:Oooool001oooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000oooool00ol0003oooooo`000004
ooooo`03o`000?oooooo000000?ooooo00Co0000ooooool0003o00000_ooool4o`0000Cooooo0_l0
0004ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l0
0004ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool4o`0000;ooooo0_l0
00000ooooooo0000ooooo`02ooooo`03o`000?oooooo000000Gooooo0_l00003ooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool001oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo0_l00005ooooo`03
o`000?oooooo000000Gooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l00005ooooo`;o
00001Oooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`;o
00001Oooool2o`0000Cooooo0_l00006ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Gooooo0_l00003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0:Oooool001oooooo0_l0000Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooool000000oooool2o`0000Gooooo00?o0000ooooool000001Oooool2o`0000?ooooo00?o0000
ooooooooool01?ooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l0000<
ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0000Oooooo00Go0000
ooooooooooooooooo`000005ooooo`?o00001Oooool2o`0000?ooooo00?o0000ooooool000000ooo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Yooooo`007oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000004ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooool000000oooool2o`0000Gooooo0ol0000Booooo`03o`00
0?oooooooooo00;ooooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l0000<ooooo`;o0000
1?ooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`00017ooooo0ol00005ooooo`;o0000
0oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo000Oooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000Cooooo00?o0000ooooool000000oooool00ol0003oooooo`000003ooooo`;o0000
1_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`;o0000
1Oooool2o`0000Gooooo00?o0000ooooooooool02_ooool2o`0000Gooooo00?o0000ooooooooool0
0oooool2o`0000Gooooo0_l00004ooooo`;o00004_ooool2o`0000Gooooo0_l00003ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooool000001?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool001Oooooo0ol00005ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000Cooooo00?o0000ooooool000000oooool00ol0003oooooo`000003ooooo`;o0000
1_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`;o0000
1Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0000Cooooo0_l0000Booooo`;o0000
1Oooool2o`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooo`000004ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`00
6?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Cooooo00?o0000ooooool00000
0oooool00ol0003oooooo`000003ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0:ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`;o0000
1Oooool2o`0000Cooooo0_l0000Booooo`;o00001Oooool2o`0000?ooooo00?o0000ooooool00000
0oooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Yooooo`006?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000Cooooo0ol00003ooooo`03o`000?oooooo000000?ooooo0_l00006ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o0000
3?ooool00ol0003oooooooooo`0:ooooo`;o00002oooool2o`0000Gooooo0_l00004ooooo`03o`00
0?oooooooooo017ooooo0_l00005ooooo`;o00000oooool00ol0003oooooo`000003ooooo`?o0000
1?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
:Oooool001Sooooo00?o0000ooooooooool01?ooool3o`0001Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Cooooo0ol00003ooooo`03o`000?oo
oooo000000?ooooo0_l00006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`;o00002ooo
ool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`;o00001Ooo
ool2o`0000?ooooo00?o0000ooooool000000oooool3o`0000Cooooo00?o0000ooooool000001Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo000Hooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000?ooooo0_l00006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool2
o`0000cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo0_l00005ooooo`;o00000oooool00ol0003oooooo`000004ooooo`;o00001?ooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool0
01Oooooo0_l00006ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool2o`00
00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`?o00000oooool2o`00
00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0:_ooool001Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`;o00001_ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`04ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o00001_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02[ooooo000Oooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool00_ooool2o`0000Cooooo0_l0000dooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0<_ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo
0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool001oooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooool000002_ooool2o`0000Cooooo0_l0000dooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0<_ooool2o`0000Cooooo0_l0000;ooooo`;o00001_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02[ooooo000Oooooo`;o00006Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo0_l0000;ooooo`;o00001?ooool2o`0007Oooooo00?o0000
ooooooooool00_ooool2o`0000_ooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0:_ooool001oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo0_l0000;ooooo`;o00001?ooool2o`0007Oooooo00?o0000oooo
ooooool00_ooool2o`0000_ooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0:_ooool001oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo0_l0000;ooooo`;o0000P_ooool2o`0000_ooooo0_l00006ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool001oooooo00?o0000ooooooooool0
6?ooool01?l0003oooooooooooooool3o`0000Kooooo0_l0000<ooooo`03o`000?oooooooooo087o
oooo00?o0000ooooooooool02Oooool2o`0000Kooooo0ol00003ooooo`03o`000?oooooooooo02[o
oooo000Oooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooooooo0ol00006ooooo`;o
0000W?ooool2o`0000Kooooo0ol00003ooooo`03o`000?oooooooooo02[ooooo000Oooooo`03o`00
0?oooooooooo01Sooooo00Co0000oooooooooooooooo0ol00006ooooo`03o`000?oooooooooo09co
oooo00?o0000ooooooooool01?ooool3o`0000?ooooo00?o0000ooooooooool0:_ooool001oooooo
0_l0000Iooooo`04o`000?ooooooooooooooo`?o00001_ooool00ol0003oooooooooo`2Looooo`03
o`000?oooooooooo00Cooooo0ol00003ooooo`03o`000?oooooooooo02[ooooo000Oooooo`03o`00
0?oooooooooo01Sooooo00Co0000oooooooooooooooo0ol0002/ooooo`?o00000oooool00ol0003o
ooooooooo`0Zooooo`007oooool00ol0003oooooooooo`0Hooooo`;o00000_ooool2o`000:kooooo
0_l00002ooooo`;o0000;?ooool001oooooo00?o0000ooooooooool06Oooool00ol0003oooooo`00
0002o`000:kooooo0ol000000ooooooo0000o`00000/ooooo`007oooool00ol0003oooooooooo`0I
ooooo`04o`000?oooooo0000o`000;7ooooo00Co0000ooooool0003o0000;?ooool001oooooo00?o
0000ooooooooool06Oooool00ol0003oooooo`00002booooo`03o`000?oooooo000002gooooo000O
ooooo`;o00006_ooool00ol0003oooooo`00002booooo`03o`000?oooooo000002gooooo000Ooooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooool00000/_ooool00ol0003oooooo`00000]oooo
o`007oooool00ol0003oooooooooo`0Iooooo`?o0000/_ooool3o`0002gooooo000Oooooo`03o`00
0?oooooooooo01[ooooo0_l0002booooo`?o0000;Oooool000_ooooo0ol00004ooooo`04o`000?oo
ooooooooooooo`Go00001?ooool00ol0003oooooooooo`0Jooooo`;o0000/_ooool3o`0002gooooo
000<ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0Jooooo`;o0000/_ooool3o`0002gooooo000<ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`;o0000/_ooool2o`0002kooooo000<
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool3o`0001_ooooo00?o0000
ooooooooool0/Oooool00ol0003oooooooooo`0/ooooo`003?ooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`3nooooo`002oooool2o`00
00Wooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0?kooooo000<oooo
o`03o`000?oooooooooo00Sooooo0ol00005ooooo`03o`000?oooooooooo0?kooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo001Tooooo`?o0000DOooool3o`0006Gooooo001Uoooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool0I?ooool003[ooooo0ol00004ooooo`?o
00000_ooool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00002Oooool3o`00
00?ooooo0ol00002ooooo`?o00001?ooool3o`0000?ooooo1?l00002ooooo`Co00001oooool5o`00
0005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00000oooool3o`0000;ooooo0ol00000
0ooooooo0000o`000004o`0000;ooooo1Ol00003ooooo`;o00001?ooool00ol0003oooooooooo`07
ooooo`?o00001Oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0ol0
0004ooooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l00000;?oo
ool003_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`06
o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`000?oo
ooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000;Oooool0
03_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00cooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`Go00000_ooool3o`0000;o
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooooooo00000_oo
ool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02_ooooo000k
ooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo0_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`?o00000oooool0
1?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003o
ooooooooool00006ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo02_ooooo000kooooo`04o`000?ooooooooooo`0000;ooooo0ol0
0002ooooo`?o00000oooool4o`0000;ooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo1?l0
0002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo0_l00004ooooo`?o00002_oo
ool01?l0003oooooooooooooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000?ooooo
1?l000001?oooooo0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000So
oooo00?o0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool3o`00
00;ooooo1?l00002ooooo`?o00001?ooool3o`0000;ooooo1?l0000^ooooo`00>oooool01?l0003o
ooooooooool0000Dooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00007?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0@?oo
ool003[ooooo1?l0000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool3
o`0001_ooooo0_l00008ooooo`Go00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03_ooool5o`0001Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0iooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.883673, -0.0977193, \
0.00584892, 0.0080546}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]]
}, Open  ]],

Cell["\<\
We can find the plane of peak intensity by making a symbolic plot along the \
optical axis of the system.\
\>", "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["Plot[intensity[x,0],{x,-10,10},PlotRange->All];", "Input",
  CellLabel->"In[80]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.0118245 0.00301327 [
[.02381 -0.00068 -9 -9 ]
[.02381 -0.00068 9 0 ]
[.2619 -0.00068 -6 -9 ]
[.2619 -0.00068 6 0 ]
[.7381 -0.00068 -3 -9 ]
[.7381 -0.00068 3 0 ]
[.97619 -0.00068 -6 -9 ]
[.97619 -0.00068 6 0 ]
[.4875 .16249 -12 -4.5 ]
[.4875 .16249 0 4.5 ]
[.4875 .31315 -18 -4.5 ]
[.4875 .31315 0 4.5 ]
[.4875 .46381 -18 -4.5 ]
[.4875 .46381 0 4.5 ]
[.4875 .61448 -18 -4.5 ]
[.4875 .61448 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01182 m
.02381 .01807 L
s
[(-10)] .02381 -0.00068 0 1 Mshowa
.2619 .01182 m
.2619 .01807 L
s
[(-5)] .2619 -0.00068 0 1 Mshowa
.7381 .01182 m
.7381 .01807 L
s
[(5)] .7381 -0.00068 0 1 Mshowa
.97619 .01182 m
.97619 .01807 L
s
[(10)] .97619 -0.00068 0 1 Mshowa
.125 Mabswid
.07143 .01182 m
.07143 .01557 L
s
.11905 .01182 m
.11905 .01557 L
s
.16667 .01182 m
.16667 .01557 L
s
.21429 .01182 m
.21429 .01557 L
s
.30952 .01182 m
.30952 .01557 L
s
.35714 .01182 m
.35714 .01557 L
s
.40476 .01182 m
.40476 .01557 L
s
.45238 .01182 m
.45238 .01557 L
s
.54762 .01182 m
.54762 .01557 L
s
.59524 .01182 m
.59524 .01557 L
s
.64286 .01182 m
.64286 .01557 L
s
.69048 .01182 m
.69048 .01557 L
s
.78571 .01182 m
.78571 .01557 L
s
.83333 .01182 m
.83333 .01557 L
s
.88095 .01182 m
.88095 .01557 L
s
.92857 .01182 m
.92857 .01557 L
s
.25 Mabswid
0 .01182 m
1 .01182 L
s
.5 .16249 m
.50625 .16249 L
s
[(50)] .4875 .16249 1 0 Mshowa
.5 .31315 m
.50625 .31315 L
s
[(100)] .4875 .31315 1 0 Mshowa
.5 .46381 m
.50625 .46381 L
s
[(150)] .4875 .46381 1 0 Mshowa
.5 .61448 m
.50625 .61448 L
s
[(200)] .4875 .61448 1 0 Mshowa
.125 Mabswid
.5 .04196 m
.50375 .04196 L
s
.5 .07209 m
.50375 .07209 L
s
.5 .10222 m
.50375 .10222 L
s
.5 .13236 m
.50375 .13236 L
s
.5 .19262 m
.50375 .19262 L
s
.5 .22275 m
.50375 .22275 L
s
.5 .25289 m
.50375 .25289 L
s
.5 .28302 m
.50375 .28302 L
s
.5 .34328 m
.50375 .34328 L
s
.5 .37342 m
.50375 .37342 L
s
.5 .40355 m
.50375 .40355 L
s
.5 .43368 m
.50375 .43368 L
s
.5 .49395 m
.50375 .49395 L
s
.5 .52408 m
.50375 .52408 L
s
.5 .55421 m
.50375 .55421 L
s
.5 .58434 m
.50375 .58434 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .01472 m
.06244 .01496 L
.10458 .01529 L
.14415 .01566 L
.18221 .0161 L
.22272 .0167 L
.26171 .01745 L
.28158 .01794 L
.30316 .01856 L
.34309 .02015 L
.36292 .02125 L
.38395 .02279 L
.40349 .02475 L
.42179 .02735 L
.42675 .02828 L
.43217 .02928 L
.43464 .02977 L
.43728 .03041 L
.44203 .03202 L
.44446 .03291 L
.44565 .03327 L
.44673 .03354 L
.44787 .03376 L
.44909 .03391 L
.44973 .03396 L
.45042 .03401 L
.45168 .03412 L
.45274 .03428 L
.45392 .0346 L
.45514 .03516 L
.45629 .03596 L
.45736 .03694 L
.45835 .03803 L
.46056 .04083 L
.46172 .04223 L
.46295 .04342 L
.46366 .04388 L
.46431 .04412 L
.46557 .04405 L
.46687 .04324 L
.46761 .04251 L
.46828 .04172 L
.46952 .04025 L
.4702 .03956 L
.47084 .03909 L
.47154 .03887 L
.47217 .03903 L
.47342 .04054 L
.47412 .0422 L
.47477 .0443 L
Mistroke
.47625 .05092 L
.47767 .05912 L
.4792 .06851 L
.4799 .07242 L
.48064 .07593 L
.48128 .07821 L
.48197 .07976 L
.48325 .07955 L
.48397 .07753 L
.48462 .0745 L
.48589 .06577 L
.4871 .05519 L
.48818 .04542 L
.48932 .03693 L
.49058 .03281 L
.49174 .0367 L
.49297 .05155 L
.49366 .06549 L
.49429 .08201 L
.49546 .12196 L
.49669 .17635 L
.49949 .3334 L
.50087 .41459 L
.50214 .48303 L
.50329 .53489 L
.50455 .57662 L
.50582 .59947 L
.50651 .60332 L
.50716 .6014 L
.50831 .58549 L
.50935 .55842 L
.51056 .51515 L
.51171 .46571 L
.51428 .34424 L
.51569 .28189 L
.51701 .23125 L
.51823 .19325 L
.51935 .16598 L
.52058 .14378 L
.52124 .13515 L
.52192 .128 L
.52297 .12024 L
.5241 .1151 L
.52516 .11211 L
.52612 .11013 L
.53072 .09744 L
.53528 .07631 L
.53653 .07111 L
.53787 .06641 L
.53914 .0629 L
Mistroke
.5403 .06044 L
.54149 .05855 L
.54278 .05703 L
.54514 .05501 L
.55027 .05048 L
.55509 .04542 L
.55946 .04187 L
.56215 .04029 L
.56468 .03903 L
.57025 .03653 L
.58025 .03278 L
.59002 .03015 L
.60034 .02798 L
.61882 .02517 L
.62831 .02407 L
.63847 .02308 L
.65681 .02165 L
.67807 .02038 L
.69819 .01945 L
.73654 .01815 L
.75633 .01763 L
.77735 .01717 L
.81512 .0165 L
.85534 .01595 L
.89405 .01553 L
.93521 .01517 L
.97485 .01489 L
.97619 .01488 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[80]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`004?ooool3o`0000Cooooo0_l0000iooooo`?o0000NOooool3o`0003Wooooo0ol00004oooo
o`;o00003Oooool0017ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000goooo
o`05o`000?ooooooooooooooool00000Moooool01Ol0003ooooooooooooooooo000003Wooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000<ooooo`002Oooool5o`0000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000aooooo`Go00001Oooool00ol0003ooooo
ooooo`1iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000<ooooo`004Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003_o
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00003?ooool0017ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000gooooo`Co0000N?ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000<ooooo`004?ooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000cooooo000Aooooo`03o`000?oooooooooo00?ooooo0_l0000hooooo`Go0000Moooool5
o`0003Wooooo00?o0000ooooooooool00oooool2o`0000gooooo003oooooob7ooooo002@ooooo`03
o`000?oooooooooo08gooooo002@ooooo`03o`000?oooooooooo08gooooo002@ooooo`03o`000?oo
oooooooo08gooooo000;oooooooo00003?l0000:ooooo`004_oooom3o`0000Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ool00000?Ol0000@ooooo`004_ooool00ol0003oooooooooo`0looooo`04o`000?oooooooooooooo
oa_o00008?ooool00ol0003oooooooooo`0Uoooooa[o0000?Oooool00ol0003oooooooooo`0>oooo
o`00L?ooool;o`0001Gooooo00?o0000ooooooooool06oooool:o`0006Sooooo001kooooo`?o0000
4_ooool00ol0003oooooooooo`0Gooooo`Co0000L_ooool007kooooo1Ol0000;ooooo`03o`000?oo
oooo000001Cooooo1Ol0001fooooo`00P_ooool4o`0000Sooooo00?o0000ooooool000004_ooool2
o`0007_ooooo0025ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003oooooo`00000@oooo
o`;o0000OOooool008Kooooo1?l00004ooooo`04o`000?oooooo0000o`0000kooooo00?o0000oooo
ooooool0OOooool008[ooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`0=ooooo`03
o`000?oooooooooo07kooooo002:ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool0
2oooool2o`00087ooooo002:ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool02_oo
ool00ol0003oooooooooo`21ooooo`00R_ooool00ol0003oooooooooo`02o`000003ooooool0003o
oooo00Wooooo0_l00023ooooo`00R_ooool01Ol0003oooooooooool0003ooooo00;o00002_ooool0
0ol0003oooooooooo`22ooooo`00Roooool01?l0003oooooo`000?ooool2o`0000Wooooo00?o0000
ooooooooool0Poooool008_ooooo00Co0000ooooool0003ooooo0_l00009ooooo`03o`000?oooooo
oooo08?ooooo002;ooooo`;o00000_ooool3o`0000Sooooo00?o0000ooooooooool0Poooool008_o
oooo0_l00002ooooo`;o00002Oooool00ol0003oooooooooo`23ooooo`00Roooool2o`0000;ooooo
0_l00009ooooo`03o`000?oooooooooo08?ooooo002?ooooo`;o00002Oooool00ol0003ooooooooo
o`23ooooo`00Soooool2o`0000Wooooo00?o0000ooooooooool0Poooool008oooooo0_l00008oooo
o`03o`000?oooooooooo08Cooooo002?ooooo`;o00002?ooool00ol0003oooooooooo`24ooooo`00
Soooool2o`0000Sooooo00?o0000ooooooooool0Q?ooool008oooooo0ol00007ooooo`03o`000?oo
oooooooo08Cooooo002?ooooo`;o00001oooool00ol0003oooooooooo`25ooooo`00Soooool2o`00
00Kooooo00?o0000ooooooooool0Q_ooool008oooooo0_l00006ooooo`03o`000?oooooooooo08Ko
oooo002?ooooo`;o00001_ooool00ol0003oooooooooo`26ooooo`00Soooool2o`0000Gooooo00?o
0000ooooooooool0Qoooool008oooooo0_l00005ooooo`03o`000?oooooooooo08Oooooo002?oooo
o`;o00001Oooool00ol0003oooooooooo`27ooooo`00Soooool3o`0000Cooooo00?o0000oooooooo
ool0Qoooool008oooooo0_l00005ooooo`03o`000?oooooooooo08Oooooo002?ooooo`;o00001Ooo
ool00ol0003oooooooooo`27ooooo`00Soooool2o`0000Gooooo00?o0000ooooooooool0Qoooool0
08oooooo0_l00005ooooo`03o`000?oooooooooo08Oooooo0022ooooo`?o00001?ooool2o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo08Oooooo0021ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00003ooooo`;o00001Oooool00ol0003oooooooooo`27oooo
o`00QOooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`;o00001?ooool0
0ol0003oooooooooo`28ooooo`00QOooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooooooo`Co00000_ooool00ol0003oooooooooo`28ooooo`00POooool4o`0000?ooooo00Co0000
oooooooooooo00000oooool2o`0000Cooooo00?o0000ooooooooool0R?ooool0087ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00003ooooo`;o00001?ooool00ol0003ooooooooo
o`28ooooo`00POooool5o`0000?ooooo0_l00004ooooo`;o00001?ooool00ol0003oooooooooo`28
ooooo`00Soooool2o`0000Cooooo00?o0000ooooooooool0R?ooool008oooooo0_l00004ooooo`03
o`000?oooooooooo08Sooooo002?ooooo`;o00001?ooool00ol0003oooooooooo`28ooooo`00Sooo
ool2o`0000Cooooo00?o0000ooooooooool0R?ooool008oooooo0ol00003ooooo`03o`000?oooooo
oooo08Sooooo002?ooooo`;o00001?ooool00ol0003oooooooooo`28ooooo`00Soooool2o`0000Co
oooo00?o0000ooooooooool0R?ooool008oooooo0_l00004ooooo`03o`000?oooooooooo08Sooooo
002?ooooo`;o00001?ooool00ol0003oooooooooo`28ooooo`00Soooool2o`0000Cooooo00?o0000
ooooooooool0R?ooool008oooooo0_l00004ooooo`03o`000?oooooooooo08Sooooo002?ooooo`;o
00001?ooool00ol0003oooooooooo`28ooooo`00Soooool3o`0000?ooooo00?o0000ooooooooool0
R?ooool008oooooo0_l00004ooooo`03o`000?oooooooooo08Sooooo002?ooooo`;o00001?ooool0
0ol0003oooooooooo`28ooooo`00Soooool2o`0000Cooooo00?o0000ooooooooool0R?ooool008oo
oooo0_l00004ooooo`03o`000?oooooooooo08Sooooo002?ooooo`;o00001?ooool00ol0003ooooo
ooooo`28ooooo`00Soooool2o`0000Cooooo00?o0000ooooooooool0R?ooool008oooooo0_l00004
ooooo`03o`000?oooooooooo08Sooooo002?ooooo`?o00000oooool00ol0003oooooooooo`28oooo
o`00T?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Sooooo002@ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0R?ooool0093ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`28ooooo`00T?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo08Sooooo002@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0R?ooool0093o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`28ooooo`00T?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo08Sooooo002@ooooo`;o00000oooool00ol0003ooooooooo
o`28ooooo`00T?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Sooooo002@oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0R?ooool0093ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`28ooooo`00T?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo08Sooooo001looooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0R?ooool007gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`28ooooo`00OOooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo08Sooooo001mooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`?o00000_ooool00ol0003oooooooooo`28oooo
o`00OOooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000008_ooooo001looooo`;o00001?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`00002;ooooo`00OOooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo
00Go0000ooooooooooooooooo`00002;ooooo`00T?ooool01Ol0003ooooooooooooooooo000008_o
oooo002@ooooo`05o`000?ooooooooooooooool00000Roooool0093ooooo00Go0000oooooooooooo
ooooo`00002;ooooo`00T?ooool01Ol0003ooooooooooooooooo000008_ooooo002@ooooo`;o0000
0_ooool00ol0003oooooooooo`29ooooo`00T?ooool01Ol0003ooooooooooooooooo000008_ooooo
002@ooooo`05o`000?ooooooooooooooool00000Roooool0093ooooo00Go0000oooooooooooooooo
o`00002;ooooo`00T?ooool01Ol0003ooooooooooooooooo000008_ooooo002@ooooo`05o`000?oo
ooooooooooooool00000Roooool0093ooooo00Go0000ooooooooooooooooo`00002;ooooo`00T?oo
ool01Ol0003ooooooooooooooooo000008_ooooo002@ooooo`;o00000_ooool00ol0003ooooooooo
o`29ooooo`00T?ooool2o`0000;ooooo00?o0000ooooooooool0ROooool0093ooooo0_l00002oooo
o`03o`000?oooooooooo08Wooooo002@ooooo`;o00000_ooool00ol0003oooooooooo`29ooooo`00
T?ooool2o`0000;ooooo00?o0000ooooooooool0ROooool0093ooooo0_l00002ooooo`03o`000?oo
oooooooo08Wooooo002@ooooo`;o00000_ooool00ol0003oooooooooo`29ooooo`00T?ooool2o`00
00;ooooo00?o0000ooooooooool0ROooool0093ooooo0_l00002ooooo`03o`000?oooooooooo08Wo
oooo002@ooooo`;o000000?oooooo`000?ooool0Roooool0093ooooo0_l000000ooooooo0000oooo
o`2;ooooo`00T?ooool2o`000003ooooool0003ooooo08_ooooo002@ooooo`;o000000?oooooo`00
0?ooool0Roooool0093ooooo0_l000000ooooooo0000ooooo`2;ooooo`00T?ooool2o`000003oooo
ool0003ooooo08_ooooo002@ooooo`;o000000?oooooo`000?ooool0Roooool0093ooooo0_l00000
0ooooooo0000ooooo`2;ooooo`00T?ooool2o`000003ooooool0003ooooo08_ooooo002@ooooo`;o
000000?oooooo`000?ooool0Roooool0093ooooo0_l000000ooooooo0000ooooo`2;ooooo`00T?oo
ool2o`000003ooooool0003ooooo08_ooooo001looooo`?o00000oooool3o`0000Cooooo0_l00005
ooooo`;o000000?oooooo`000?ooool0Roooool007gooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0
003ooooo08_ooooo001mooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool0Roooool007gooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1?l0
002<ooooo`00OOooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo0000
1?ooool2o`000003ooooool0003ooooo08_ooooo001looooo`;o00000oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000Cooooo0_l000000ooooooo0000ooooo`2;ooooo`00OOoo
ool01?l0003oooooooooooooool5o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?ooool0
Roooool0093ooooo0_l000000ooooooo0000ooooo`2;ooooo`00T?ooool2o`000003ooooool0003o
oooo08_ooooo002@ooooo`;o000000?oooooo`000?ooool0Roooool0093ooooo0_l000000ooooooo
0000ooooo`2;ooooo`00T?ooool2o`000003ooooool0003ooooo08_ooooo002@ooooo`;o000000?o
ooooo`000?ooool0Roooool0093ooooo0_l000000ooooooo0000ooooo`2;ooooo`00T?ooool2o`00
0003ooooool0003ooooo08_ooooo002@ooooo`;o000000?oooooo`000?ooool0Roooool0093ooooo
0_l000000ooooooo0000ooooo`2;ooooo`00T?ooool2o`000003ooooool0003ooooo08_ooooo002@
ooooo`;o000000?oooooo`000?ooool0Roooool0093ooooo0_l000000ooooooo0000ooooo`2;oooo
o`00T?ooool2o`000003ooooool0003ooooo08_ooooo002@ooooo`;o000000?oooooo`000?ooool0
Roooool0093ooooo0_l000000ooooooo0000ooooo`2;ooooo`00T?ooool2o`000003ooooool0003o
oooo08_ooooo002@ooooo`;o000000?oooooo`000?ooool0Roooool0093ooooo0_l000000ooooooo
0000ooooo`2;ooooo`00T?ooool2o`000003ooooool0003ooooo08_ooooo002@ooooo`;o000000?o
ooooo`000?ooool0Roooool0093ooooo00Co0000ooooool0003o0000S?ooool0093ooooo00Co0000
ooooool0003o0000S?ooool0093ooooo00Co0000ooooool0003o0000S?ooool0093ooooo00Co0000
ooooool0003o0000S?ooool0093ooooo00Co0000ooooool0003o0000S?ooool0093ooooo00Co0000
ooooool0003o0000S?ooool0093ooooo00Co0000ooooool0003o0000S?ooool0093ooooo1?l0002<
ooooo`00T?ooool01?l0003oooooo`000?l0002<ooooo`00T?ooool01?l0003oooooo`000?l0002<
ooooo`00T?ooool00ol0003oooooo`00002=ooooo`00T?ooool00ol0003oooooo`00002=ooooo`00
Noooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooo`00002=ooooo`00O?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`2=ooooo`00OOooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2=
ooooo`00O_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`?o0000SOooool007_ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`2=ooooo`00Noooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0002Dooooo`00O?ooool3o`0000Cooooo0_l00004oooo
o`;o0000UOooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.4483, -15.3929, \
0.0790423, 1.24912}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell["\<\
We can now compare plots of the symbolic and numeric intensity profiles at \
the plane of peak intensity. Again, the overall shapes are in agreement with \
each other.\
\>", "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
Plot[intensity[.133,y],{y,-.022,.022},PlotRange->All,PlotPoints->100];\
\>", "Input",
  CellLabel->"In[81]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 21.645 0.013963 0.00300442 [
[.0671 .00146 -15 -9 ]
[.0671 .00146 15 0 ]
[.28355 .00146 -15 -9 ]
[.28355 .00146 15 0 ]
[.71645 .00146 -12 -9 ]
[.71645 .00146 12 0 ]
[.9329 .00146 -12 -9 ]
[.9329 .00146 12 0 ]
[.4875 .16418 -12 -4.5 ]
[.4875 .16418 0 4.5 ]
[.4875 .31441 -18 -4.5 ]
[.4875 .31441 0 4.5 ]
[.4875 .46463 -18 -4.5 ]
[.4875 .46463 0 4.5 ]
[.4875 .61485 -18 -4.5 ]
[.4875 .61485 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0671 .01396 m
.0671 .02021 L
s
[(-0.02)] .0671 .00146 0 1 Mshowa
.28355 .01396 m
.28355 .02021 L
s
[(-0.01)] .28355 .00146 0 1 Mshowa
.71645 .01396 m
.71645 .02021 L
s
[(0.01)] .71645 .00146 0 1 Mshowa
.9329 .01396 m
.9329 .02021 L
s
[(0.02)] .9329 .00146 0 1 Mshowa
.125 Mabswid
.11039 .01396 m
.11039 .01771 L
s
.15368 .01396 m
.15368 .01771 L
s
.19697 .01396 m
.19697 .01771 L
s
.24026 .01396 m
.24026 .01771 L
s
.32684 .01396 m
.32684 .01771 L
s
.37013 .01396 m
.37013 .01771 L
s
.41342 .01396 m
.41342 .01771 L
s
.45671 .01396 m
.45671 .01771 L
s
.54329 .01396 m
.54329 .01771 L
s
.58658 .01396 m
.58658 .01771 L
s
.62987 .01396 m
.62987 .01771 L
s
.67316 .01396 m
.67316 .01771 L
s
.75974 .01396 m
.75974 .01771 L
s
.80303 .01396 m
.80303 .01771 L
s
.84632 .01396 m
.84632 .01771 L
s
.88961 .01396 m
.88961 .01771 L
s
.02381 .01396 m
.02381 .01771 L
s
.97619 .01396 m
.97619 .01771 L
s
.25 Mabswid
0 .01396 m
1 .01396 L
s
.5 .16418 m
.50625 .16418 L
s
[(50)] .4875 .16418 1 0 Mshowa
.5 .31441 m
.50625 .31441 L
s
[(100)] .4875 .31441 1 0 Mshowa
.5 .46463 m
.50625 .46463 L
s
[(150)] .4875 .46463 1 0 Mshowa
.5 .61485 m
.50625 .61485 L
s
[(200)] .4875 .61485 1 0 Mshowa
.125 Mabswid
.5 .04401 m
.50375 .04401 L
s
.5 .07405 m
.50375 .07405 L
s
.5 .1041 m
.50375 .1041 L
s
.5 .13414 m
.50375 .13414 L
s
.5 .19423 m
.50375 .19423 L
s
.5 .22427 m
.50375 .22427 L
s
.5 .25432 m
.50375 .25432 L
s
.5 .28436 m
.50375 .28436 L
s
.5 .34445 m
.50375 .34445 L
s
.5 .37449 m
.50375 .37449 L
s
.5 .40454 m
.50375 .40454 L
s
.5 .43458 m
.50375 .43458 L
s
.5 .49467 m
.50375 .49467 L
s
.5 .52471 m
.50375 .52471 L
s
.5 .55476 m
.50375 .55476 L
s
.5 .5848 m
.50375 .5848 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .0158 m
.03318 .01555 L
.04339 .01518 L
.04836 .015 L
.05298 .01486 L
.05527 .01481 L
.05744 .01477 L
.05864 .01475 L
.05994 .01473 L
.06051 .01473 L
.06112 .01472 L
.06164 .01472 L
.06191 .01472 L
.06221 .01472 L
.06252 .01472 L
.06281 .01472 L
.06299 .01472 L
.06316 .01472 L
.06347 .01472 L
.06377 .01472 L
.06404 .01472 L
.06435 .01472 L
.06467 .01472 L
.06522 .01472 L
.06574 .01472 L
.06691 .01474 L
.06819 .01475 L
.06936 .01477 L
.07198 .01484 L
.07438 .01492 L
.0766 .01501 L
.08164 .01527 L
.09115 .01596 L
.10031 .01673 L
.10539 .01714 L
.11005 .01748 L
.11491 .01777 L
.11728 .01789 L
.11943 .01797 L
.12165 .01804 L
.12287 .01806 L
.12402 .01808 L
.12463 .01809 L
.12527 .0181 L
.12582 .0181 L
.12613 .0181 L
.12643 .0181 L
.12659 .0181 L
.12676 .0181 L
.12708 .0181 L
Mistroke
.1274 .0181 L
.12769 .0181 L
.12786 .0181 L
.12803 .0181 L
.12834 .0181 L
.12867 .0181 L
.12904 .01809 L
.12961 .01809 L
.13023 .01808 L
.13135 .01806 L
.13267 .01803 L
.13388 .018 L
.13651 .01791 L
.13899 .0178 L
.14829 .01722 L
.15819 .01653 L
.16311 .01623 L
.16552 .01612 L
.16773 .01603 L
.16988 .01597 L
.17096 .01595 L
.17157 .01594 L
.17214 .01593 L
.17244 .01593 L
.17276 .01593 L
.17306 .01593 L
.17334 .01593 L
.1736 .01593 L
.17388 .01592 L
.17417 .01593 L
.17444 .01593 L
.17475 .01593 L
.17506 .01593 L
.17533 .01593 L
.17562 .01593 L
.17628 .01594 L
.17689 .01595 L
.17801 .01597 L
.17922 .01601 L
.18141 .0161 L
.18401 .01624 L
.1864 .01641 L
.19098 .01682 L
.196 .0174 L
.20582 .01877 L
.21528 .02009 L
.2201 .02064 L
.22264 .02088 L
.22533 .02109 L
.22773 .02124 L
Mistroke
.22909 .0213 L
.23037 .02134 L
.23097 .02136 L
.23154 .02137 L
.23205 .02138 L
.23261 .02138 L
.23293 .02139 L
.23322 .02139 L
.23337 .02139 L
.23355 .02139 L
.23386 .02139 L
.23415 .02139 L
.23446 .02139 L
.23473 .02139 L
.23502 .02139 L
.23534 .02139 L
.23563 .02138 L
.23629 .02137 L
.23688 .02136 L
.2375 .02134 L
.23857 .02131 L
.23975 .02126 L
.24237 .02112 L
.24482 .02095 L
.25421 .02008 L
.25897 .01962 L
.26149 .01941 L
.26288 .01931 L
.26419 .01923 L
.26544 .01916 L
.2661 .01913 L
.2668 .01911 L
.26738 .01909 L
.26769 .01908 L
.26803 .01908 L
.26834 .01907 L
.26862 .01907 L
.2689 .01907 L
.26917 .01906 L
.26946 .01906 L
.26972 .01906 L
.27003 .01906 L
.27032 .01907 L
.27058 .01907 L
.27083 .01907 L
.27138 .01909 L
.27194 .0191 L
.27256 .01912 L
.2738 .01919 L
.27507 .01928 L
Mistroke
.27628 .01939 L
.27854 .01967 L
.28097 .02008 L
.28361 .02066 L
.28842 .02209 L
.29352 .02414 L
.30269 .02909 L
.31245 .03553 L
.32185 .04173 L
.32662 .04441 L
.32915 .04561 L
.33184 .04668 L
.33318 .04713 L
.33445 .04749 L
.33569 .04779 L
.33683 .048 L
.33791 .04816 L
.33845 .04823 L
.33905 .04828 L
.33936 .0483 L
.33965 .04832 L
.33981 .04832 L
.33999 .04833 L
.3403 .04834 L
.34059 .04834 L
.3409 .04835 L
.34117 .04834 L
.34146 .04834 L
.34176 .04833 L
.34203 .04831 L
.34265 .04827 L
.34326 .04821 L
.34391 .04813 L
.34508 .04793 L
.34615 .0477 L
.34875 .04691 L
.3512 .04588 L
.35605 .04307 L
.36053 .03967 L
.37008 .03067 L
.37926 .02199 L
.38167 .02011 L
.38397 .01861 L
.38524 .01793 L
.38662 .01731 L
.38787 .01687 L
.38844 .01672 L
.38903 .01659 L
.38934 .01653 L
.38968 .01648 L
Mistroke
.38999 .01644 L
.39027 .01642 L
.39044 .01641 L
.3906 .0164 L
.39077 .01639 L
.39096 .01639 L
.39112 .01639 L
.39129 .01639 L
.3916 .01641 L
.39189 .01643 L
.39219 .01646 L
.39248 .0165 L
.39275 .01654 L
.39337 .01668 L
.39402 .01687 L
.39513 .01731 L
.39617 .01785 L
.39853 .01961 L
.39976 .02083 L
.40109 .0224 L
.4035 .02594 L
.408 .03511 L
.41283 .04893 L
.41793 .06835 L
.42713 .11613 L
.43692 .18402 L
.44634 .26232 L
.45635 .35275 L
.466 .43836 L
.47528 .51077 L
.47998 .54115 L
.48516 .56849 L
.48752 .5785 L
.49006 .58749 L
.49246 .59418 L
.49467 .59873 L
.49581 .60049 L
.49644 .60128 L
.49704 .6019 L
.49759 .60239 L
.4982 .6028 L
.49846 .60294 L
.49874 .60307 L
.499 .60316 L
.49925 .60323 L
.49956 .60329 L
.49984 .60332 L
.50015 .60332 L
.50032 .60331 L
.50048 .60328 L
Mistroke
.50077 .60323 L
.50104 .60315 L
.50135 .60303 L
.50164 .60289 L
.50229 .60247 L
.5029 .60196 L
.50426 .60038 L
.5054 .59861 L
.50662 .59624 L
.50883 .5908 L
.51145 .58238 L
.51384 .57293 L
.5235 .51911 L
.53279 .44847 L
.54268 .36151 L
.5522 .27522 L
.56136 .19757 L
.5711 .12716 L
.58049 .0754 L
.58534 .0553 L
.59046 .03905 L
.59278 .03328 L
.59525 .02815 L
.59756 .02427 L
.5997 .02144 L
.60218 .019 L
.60349 .01806 L
.60488 .0173 L
.60546 .01706 L
.60608 .01684 L
.60662 .01668 L
.6072 .01655 L
.60756 .01649 L
.60789 .01645 L
.60821 .01642 L
.60838 .01641 L
.60854 .0164 L
.60884 .01639 L
.60901 .01639 L
.60917 .01639 L
.60946 .0164 L
.60976 .01642 L
.61006 .01645 L
.61038 .01649 L
.61097 .01659 L
.61154 .01671 L
.61207 .01685 L
.61326 .01726 L
.61453 .01781 L
.61665 .01899 L
Mistroke
.61898 .0206 L
.62874 .02949 L
.63814 .03852 L
.64291 .04235 L
.64543 .04404 L
.64812 .04555 L
.65074 .04672 L
.65311 .04751 L
.65426 .04779 L
.6555 .04804 L
.65607 .04813 L
.65667 .0482 L
.65718 .04825 L
.65774 .0483 L
.65806 .04832 L
.65835 .04833 L
.65867 .04834 L
.65883 .04834 L
.65901 .04834 L
.65931 .04835 L
.65948 .04834 L
.65963 .04834 L
.65992 .04833 L
.66022 .04832 L
.66048 .04831 L
.66077 .04829 L
.66129 .04825 L
.66191 .04819 L
.66247 .04811 L
.66372 .04791 L
.66508 .04761 L
.66754 .0469 L
.67235 .04492 L
.67745 .04215 L
.68663 .03616 L
.6964 .02965 L
.70581 .02445 L
.71094 .02232 L
.7133 .02152 L
.71581 .02081 L
.71833 .02022 L
.72062 .0198 L
.72291 .01948 L
.72508 .01927 L
.72621 .01919 L
.72745 .01912 L
.72807 .0191 L
.72842 .01909 L
.72874 .01908 L
.72904 .01908 L
Mistroke
.72937 .01907 L
.72967 .01907 L
.72995 .01906 L
.73021 .01906 L
.73048 .01906 L
.73074 .01906 L
.73098 .01906 L
.73125 .01907 L
.73154 .01907 L
.73184 .01908 L
.73212 .01908 L
.73324 .01911 L
.73386 .01913 L
.73443 .01916 L
.73685 .01929 L
.73908 .01946 L
.74413 .01992 L
.74907 .02041 L
.75369 .02084 L
.75596 .02101 L
.75812 .02115 L
.75931 .02122 L
.76061 .02128 L
.7617 .02132 L
.76288 .02135 L
.76355 .02137 L
.76417 .02138 L
.76476 .02139 L
.76506 .02139 L
.76523 .02139 L
.76539 .02139 L
.76569 .02139 L
.76596 .02139 L
.76625 .02139 L
.76657 .02139 L
.76684 .02139 L
.76714 .02139 L
.76739 .02138 L
.76766 .02138 L
.76832 .02137 L
.76893 .02136 L
.77029 .02132 L
.77155 .02127 L
.77275 .02121 L
.77507 .02106 L
.77755 .02087 L
.78201 .02041 L
.79209 .01907 L
.8018 .01769 L
.80625 .01713 L
Mistroke
.81114 .01661 L
.81348 .01641 L
.81598 .01624 L
.81736 .01616 L
.81862 .01609 L
.81981 .01604 L
.82108 .016 L
.82223 .01597 L
.82283 .01596 L
.82349 .01594 L
.82408 .01594 L
.82435 .01593 L
.82463 .01593 L
.82489 .01593 L
.82516 .01593 L
.82544 .01593 L
.82571 .01593 L
.82587 .01592 L
.82605 .01592 L
.82636 .01593 L
.82653 .01593 L
.8267 .01593 L
.82687 .01593 L
.82707 .01593 L
.82741 .01593 L
.82773 .01593 L
.82835 .01594 L
.82894 .01595 L
.82949 .01596 L
.83074 .01599 L
.83331 .01607 L
.83573 .01617 L
.84024 .01642 L
.8496 .01707 L
.85434 .01741 L
.85955 .01772 L
.86194 .01784 L
.86451 .01795 L
.86575 .01799 L
.86693 .01802 L
.86807 .01805 L
.86913 .01807 L
.87025 .01809 L
.87084 .01809 L
.87115 .0181 L
.87148 .0181 L
.87181 .0181 L
.87211 .0181 L
.87228 .0181 L
.87243 .0181 L
Mistroke
.87261 .0181 L
.87278 .0181 L
.87308 .0181 L
.87335 .0181 L
.87365 .0181 L
.87397 .0181 L
.87425 .0181 L
.8745 .0181 L
.87507 .01809 L
.8756 .01809 L
.8761 .01808 L
.87722 .01806 L
.87844 .01803 L
.88071 .01797 L
.88322 .01786 L
.88831 .01759 L
.89805 .01686 L
.90742 .01607 L
.91218 .0157 L
.91738 .01533 L
.92235 .01506 L
.92457 .01496 L
.92698 .01487 L
.92831 .01483 L
.92953 .0148 L
.93067 .01477 L
.93193 .01475 L
.93306 .01474 L
.93412 .01473 L
.9347 .01472 L
.93524 .01472 L
.93553 .01472 L
.93569 .01472 L
.93585 .01472 L
.93616 .01472 L
.93644 .01472 L
.93674 .01472 L
.93691 .01472 L
.93707 .01472 L
.93724 .01472 L
.93739 .01472 L
.93774 .01472 L
.93803 .01472 L
.93835 .01472 L
.93893 .01472 L
.93961 .01473 L
.94034 .01473 L
.94163 .01475 L
.94396 .01479 L
.94652 .01485 L
Mistroke
.95122 .01499 L
.95627 .01517 L
.96625 .01553 L
.97123 .01569 L
.97586 .01579 L
.97619 .0158 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol0000Toooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0005gooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00009Oooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000;ooooo1Ol0000Cooooo`005?ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Foooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool08oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00004oooool000gooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`0Looooo`Go00000_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Foooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool08oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool04oooool0
01Cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo02;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo05_ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo01;ooooo000Dooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo027ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo05_ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo02?o
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool04Oooool001Cooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo0_l0001Mooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool2o`0002Gooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool04Oooool001Gooooo0_l0000:oooo
o`;o00000oooool3o`0002Gooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`1Loooo
o`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool09?ooool2o`0000[ooooo0_l00003oooo
o`?o00005?ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0
S_ooool008oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool0S_ooool0
00[oooooool0000<o`0000_ooooo000@ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01_ooool@o`0000Kooooo2?l00007ooooo`03o`000?oooooooooo00;ooooo1ol0000;ooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooooooo1Ol00003ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooooooo1Ol00003ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool8o`0000?ooooo00?o0000ooooooooool01Oooool8o`0000Kooooo4Ol00007
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool001cooooo00?o0000oooo
ooooool09?ooool<o`0000Kooooo0ol0000Fooooo`;o00001?ooool2o`0001Wooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo0ol00007oooo
o`_o00009_ooool00ol0003oooooooooo`0Kooooo`00F?ooool2o`0001?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`;o0000FOooool005[ooooo0_l0000@ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Kooooo0_l0000@ooooo`;o0000Foooool005cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Fooo
ool005gooooo0ol0000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2
o`0005kooooo001Pooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`06ooooo`;o0000H?ooool0067ooooo00?o0000ooooooooool00oooool3o`0000go
oooo00?o0000ooooooooool05Oooool2o`0001Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo063ooooo001Rooooo`Ko00004?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03Oooool6o`0006?ooooo
001hooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1gooooo`00N?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0Moooool007Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo07Oooooo001iooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1hooooo`00NOooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0N?ooool007Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo07Sooooo001iooooo`03o`000?oooooo
oooo01?ooooo0_l0000Cooooo`03o`000?oooooooooo07Wooooo001jooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1iooooo`00N_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0NOooool007[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07Wooooo
001jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1jooooo`00Noooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0N_ooool007_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo07[ooooo001kooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`1jooooo`00Noooool00ol0003oooooooooo`0Aooooo`;o0000
4_ooool00ol0003oooooooooo`1jooooo`00Noooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0N_ooool007cooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo07[ooooo001looooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1kooooo`00O?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Noooool007cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07_ooooo
001looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`1kooooo`00O?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Noooool007gooooo00?o0000ooooooooool03oooool2o`00017ooooo00?o0000oooo
ooooool0Noooool007gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo07_ooooo001mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1looooo`00OOooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0O?ooool007gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07cooooo001mooooo`04o`000?oooooooooo
ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1l
ooooo`00OOooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07cooooo001m
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0O?ooool007gooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0ol0
000>ooooo`03o`000?oooooooooo07gooooo001nooooo`03o`000?oooooo000000?o00000oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0OOoo
ool007kooooo00?o0000ooooool000001_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0OOooool007kooooo00?o0000ooooool000001?l00003
ooooo`;o00001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07gooooo001noooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1moooo
o`00O_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0OOooool007kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo07gooooo001nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1nooooo`00O_ooool00ol0003oooooooooo`0>ooooo`;o00003_ooool0
0ol0003oooooooooo`1nooooo`00Ooooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0O_ooool007oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo07kooooo001oooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1nooooo`00Ooooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0O_ooool007oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07kooooo001ooooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1noooo
o`00Ooooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0Ooooool0083ooooo00?o0000ooooooooool03?ooool2o`0000gooooo00?o0000ooooooooool0
Ooooool0083ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo07oooooo0020ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1oooooo`00P?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0Ooooool0083ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo07oooooo0020ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1oooooo`00P?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Ooooool0087ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07oooooo0021oooo
o`03o`000?oooooooooo00_ooooo0_l0000=ooooo`03o`000?oooooooooo07oooooo0021ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1oooooo`00
POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
P?ooool0087ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo083ooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`20ooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0P?ooool0087ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo083ooooo0021ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`20ooooo`00POooool00ol0003ooooooooo
o`0;ooooo`;o00003?ooool00ol0003oooooooooo`20ooooo`00P_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0P?ooool008;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo083ooooo0022ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`21ooooo`00
P_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
POooool007_ooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`21ooooo`00O?ooool00ol0003oooooooooo`02ooooo`;o000000Gooooo
o`000?ooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`21ooooo`00O?ooool00ol0003oooooooooo`02ooooo`;o000000Gooooo
o`000?ooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`21ooooo`00O?ooool00ol0003oooooooooo`02ooooo`;o000000Gooooo
o`000?ooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo0ol0000:ooooo`03o`000?oo
oooooooo087ooooo001looooo`03o`000?oooooooooo00;ooooo0_l000001Ooooooo0000oooooooo
oooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo087ooooo001kooooo`;o00001?ooool2o`000005ooooool0003oooooooooool000000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0P_oo
ool007cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0P_ooool008;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo08;ooooo0023ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`22ooooo`00Poooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0P_ooool008?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08;ooooo0023
ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`03o`000?oooooooooo08;ooooo0023oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`23oooo
o`00Poooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Poooool008?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo08?ooooo0023ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`23ooooo`00Poooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Poooool008?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo08?ooooo0024ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`23ooooo`00Q?ooool00ol0003ooooo
ooooo`08ooooo`;o00002Oooool00ol0003oooooooooo`23ooooo`00Q?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Poooool008Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08?ooooo0024oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`24oooo
o`00Q?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Q?ooool008Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo08Cooooo0025ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`24ooooo`00QOooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0Q?ooool008Gooooo00?o0000ooooooooool01oooool2o`00
00Sooooo00?o0000ooooooooool0Q?ooool008Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo08Cooooo0025ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`24ooooo`00QOooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Q?ooool008Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Cooooo0025oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`24oooo
o`00Q_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Q?ooool008Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo08Gooooo0026ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`03o`000?oo
oooooooo08Gooooo0026ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`25ooooo`00Q_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0QOooool008Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo08Gooooo0026ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`25ooooo`00Noooool3o`0000?ooooo0ol0
0002ooooo`04o`000?oooooo0000o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`25ooooo`00O?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000ooooool0003o
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0QOooool007cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`25ooooo`00
O?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool0Q_ooool007cooooo00Co0000oooooooooooo
oooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`26ooooo`00Noooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q_ooool007co
oooo00Co0000oooooooooooooooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo08Kooooo0027ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`26ooooo`00Qoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Q_ooool008Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo0027ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27ooooo`00R?ooool00ol0
003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`27ooooo`00R?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Qoooool008Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo
0028ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`27ooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0R?ooool008Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo08Sooooo0028ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`28ooooo`00ROooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0R?ooool008Wooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo00?o0000ooooooooool0R?ooool008Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo0029ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`28ooooo`00R_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ROooool008[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Wooooo
002:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`29ooooo`00R_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0ROooool008[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo08Wooooo002:ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`03
o`000?oooooooooo08Wooooo002;ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`29ooooo`00Roooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool0R_ooool008_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo08[o
oooo002;ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`2:ooooo`00
Roooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0R_ooool008cooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`2:ooooo`00S?ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo08_ooooo002<ooooo`03o`000?oooooooooo00;o0000
00?oooooo`000?ooool0S?ooool008cooooo00Ko0000oooooooooooo0000ooooool0002>ooooo`00
SOooool01Ol0003oooooo`000?oooooo000008kooooo002=ooooo`05o`000?oooooo0000ooooool0
0000S_ooool008kooooo0ol0002?ooooo`00N_ooool5o`0000?ooooo0_l00004ooooo`;o00001?oo
ool3o`0008oooooo001kooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo08kooooo001looooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo08kooooo001mooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0ol0002>ooooo`00N_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo08kooooo001jooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0009Gooooo001kooooo`?o
00001?ooool2o`0000Cooooo0_l0002Fooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0248819, -15.4053, \
0.000173393, 1.24919}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
psf = PointSpreadFunction/.PSF[{
\tMove[LineOfRays[10],-50],
\tPlanoConvexLens[100,50,10],
\tMove[Screen[50],103.133]},NumberOfPoints->1024,PaddingFactor->10];\
\>", "Input",
  CellLabel->"In[82]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952017 0.603319 6.74624 [
[.11919 -0.0125 -6 -9 ]
[.11919 -0.0125 6 0 ]
[.3096 -0.0125 -6 -9 ]
[.3096 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.6904 -0.0125 -3 -9 ]
[.6904 -0.0125 3 0 ]
[.88081 -0.0125 -3 -9 ]
[.88081 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06362 -30 -4.5 ]
[-0.0125 .06362 0 4.5 ]
[-0.0125 .19854 -30 -4.5 ]
[-0.0125 .19854 0 4.5 ]
[-0.0125 .33347 -30 -4.5 ]
[-0.0125 .33347 0 4.5 ]
[-0.0125 .46839 -30 -4.5 ]
[-0.0125 .46839 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11919 0 m
.11919 .00625 L
s
[(-4)] .11919 -0.0125 0 1 Mshowa
.3096 0 m
.3096 .00625 L
s
[(-2)] .3096 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.6904 0 m
.6904 .00625 L
s
[(2)] .6904 -0.0125 0 1 Mshowa
.88081 0 m
.88081 .00625 L
s
[(4)] .88081 -0.0125 0 1 Mshowa
.125 Mabswid
.16679 0 m
.16679 .00375 L
s
.21439 0 m
.21439 .00375 L
s
.262 0 m
.262 .00375 L
s
.3572 0 m
.3572 .00375 L
s
.4048 0 m
.4048 .00375 L
s
.4524 0 m
.4524 .00375 L
s
.5476 0 m
.5476 .00375 L
s
.5952 0 m
.5952 .00375 L
s
.6428 0 m
.6428 .00375 L
s
.738 0 m
.738 .00375 L
s
.78561 0 m
.78561 .00375 L
s
.83321 0 m
.83321 .00375 L
s
.07159 0 m
.07159 .00375 L
s
.02399 0 m
.02399 .00375 L
s
.92841 0 m
.92841 .00375 L
s
.97601 0 m
.97601 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06362 m
.00625 .06362 L
s
[(-0.08)] -0.0125 .06362 1 0 Mshowa
0 .19854 m
.00625 .19854 L
s
[(-0.06)] -0.0125 .19854 1 0 Mshowa
0 .33347 m
.00625 .33347 L
s
[(-0.04)] -0.0125 .33347 1 0 Mshowa
0 .46839 m
.00625 .46839 L
s
[(-0.02)] -0.0125 .46839 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .09735 m
.00375 .09735 L
s
0 .13108 m
.00375 .13108 L
s
0 .16481 m
.00375 .16481 L
s
0 .23228 m
.00375 .23228 L
s
0 .26601 m
.00375 .26601 L
s
0 .29974 m
.00375 .29974 L
s
0 .3672 m
.00375 .3672 L
s
0 .40093 m
.00375 .40093 L
s
0 .43466 m
.00375 .43466 L
s
0 .50213 m
.00375 .50213 L
s
0 .53586 m
.00375 .53586 L
s
0 .56959 m
.00375 .56959 L
s
0 .02989 m
.00375 .02989 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11919 .61178 m
.11919 .61803 L
s
.3096 .61178 m
.3096 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.6904 .61178 m
.6904 .61803 L
s
.88081 .61178 m
.88081 .61803 L
s
.125 Mabswid
.16679 .61428 m
.16679 .61803 L
s
.21439 .61428 m
.21439 .61803 L
s
.262 .61428 m
.262 .61803 L
s
.3572 .61428 m
.3572 .61803 L
s
.4048 .61428 m
.4048 .61803 L
s
.4524 .61428 m
.4524 .61803 L
s
.5476 .61428 m
.5476 .61803 L
s
.5952 .61428 m
.5952 .61803 L
s
.6428 .61428 m
.6428 .61803 L
s
.738 .61428 m
.738 .61803 L
s
.78561 .61428 m
.78561 .61803 L
s
.83321 .61428 m
.83321 .61803 L
s
.07159 .61428 m
.07159 .61803 L
s
.02399 .61428 m
.02399 .61803 L
s
.92841 .61428 m
.92841 .61803 L
s
.97601 .61428 m
.97601 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06362 m
1 .06362 L
s
.99375 .19854 m
1 .19854 L
s
.99375 .33347 m
1 .33347 L
s
.99375 .46839 m
1 .46839 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .09735 m
1 .09735 L
s
.99625 .13108 m
1 .13108 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .23228 m
1 .23228 L
s
.99625 .26601 m
1 .26601 L
s
.99625 .29974 m
1 .29974 L
s
.99625 .3672 m
1 .3672 L
s
.99625 .40093 m
1 .40093 L
s
.99625 .43466 m
1 .43466 L
s
.99625 .50213 m
1 .50213 L
s
.99625 .53586 m
1 .53586 L
s
.99625 .56959 m
1 .56959 L
s
.99625 .02989 m
1 .02989 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.02381 .49359 Mdot
.05455 .27345 Mdot
.08529 .12851 Mdot
.11603 .04616 Mdot
.14676 .01472 Mdot
.17749 .02341 Mdot
.20821 .06241 Mdot
.23893 .1228 Mdot
.26965 .19656 Mdot
.30037 .2766 Mdot
.33109 .3567 Mdot
.3618 .43155 Mdot
.39251 .49673 Mdot
.42322 .5487 Mdot
.45393 .58482 Mdot
.48464 .60332 Mdot
.51536 .60332 Mdot
.54607 .58482 Mdot
.57678 .5487 Mdot
.60749 .49673 Mdot
.6382 .43155 Mdot
.66891 .3567 Mdot
.69963 .2766 Mdot
.73035 .19656 Mdot
.76107 .1228 Mdot
.79179 .06241 Mdot
.82251 .02341 Mdot
.85324 .01472 Mdot
.88397 .04616 Mdot
.91471 .12851 Mdot
.94545 .27345 Mdot
.97619 .49359 Mdot
.5 Mabswid
.02381 .49359 m
.03853 .3882 L
.04619 .33335 L
.05024 .30432 L
.05247 .28835 L
.05357 .28051 L
.05405 .27706 L
.0543 .27523 L
.05458 .27333 L
.05507 .27101 L
.05553 .26884 L
.05654 .26409 L
.05867 .25406 L
.06238 .23653 L
.06965 .20225 L
.07716 .16684 L
.08113 .14814 L
.08331 .13787 L
.08438 .13283 L
.08484 .13062 L
.08509 .12945 L
.08536 .12834 L
.08586 .127 L
.08632 .12576 L
.08734 .12304 L
.08947 .11731 L
.0932 .10732 L
.10049 .0878 L
.10803 .06758 L
.11201 .05692 L
.11419 .05107 L
.11526 .04821 L
.11573 .04696 L
.11598 .0463 L
.11624 .04594 L
.1167 .04548 L
.11712 .04505 L
.11805 .0441 L
.11999 .04211 L
.12413 .03788 L
.13142 .03041 L
.13901 .02265 L
.143 .01856 L
.14519 .01632 L
.14573 .01576 L
.14625 .01523 L
.14672 .01475 L
.14699 .01478 L
.14723 .01485 L
.14905 .01536 L
Mistroke
.151 .01592 L
.15515 .01709 L
.16246 .01916 L
.16964 .02119 L
.17341 .02225 L
.17547 .02284 L
.17647 .02312 L
.17691 .02324 L
.17739 .02338 L
.17765 .02362 L
.17789 .02392 L
.17837 .02453 L
.17942 .02586 L
.18165 .02869 L
.18556 .03366 L
.19325 .04342 L
.20098 .05323 L
.20476 .05803 L
.20642 .06013 L
.20729 .06124 L
.20777 .06185 L
.20823 .06244 L
.20867 .06331 L
.20915 .06424 L
.20998 .06588 L
.21161 .06908 L
.21516 .07607 L
.22263 .09075 L
.23824 .12143 L
.25327 .15721 L
.26772 .19192 L
.28311 .23162 L
.29792 .27021 L
.31366 .31126 L
.32883 .35081 L
.34342 .38675 L
.35894 .42458 L
.37389 .4572 L
.38826 .4877 L
.40356 .51542 L
.41829 .54034 L
.43395 .56131 L
.44176 .5705 L
.44903 .57905 L
.45076 .58108 L
.45263 .58329 L
.45349 .5843 L
.45396 .58484 L
.4544 .5851 L
.45518 .58557 L
Mistroke
.45604 .58609 L
.45996 .58845 L
.46353 .5906 L
.47831 .5995 L
.48216 .60182 L
.48322 .60246 L
.4838 .60281 L
.48408 .60298 L
.48435 .60314 L
.48459 .60329 L
.48486 .60332 L
.48512 .60332 L
.48541 .60332 L
.48637 .60332 L
.49402 .60332 L
.50208 .60332 L
.50943 .60332 L
.51308 .60332 L
.51408 .60332 L
.51463 .60332 L
.5149 .60332 L
.51514 .60332 L
.51558 .60318 L
.51605 .6029 L
.51705 .6023 L
.52426 .59795 L
.53209 .59324 L
.53936 .58886 L
.54298 .58668 L
.54475 .58561 L
.54553 .58514 L
.54594 .58489 L
.54639 .58444 L
.54686 .58388 L
.5473 .58336 L
.54827 .58222 L
.55032 .57982 L
.55389 .57562 L
.56962 .55712 L
.58478 .53516 L
.59935 .51049 L
.61486 .48107 L
.6298 .44938 L
.64567 .41335 L
.66096 .37609 L
.67567 .33908 L
.69132 .29827 L
.70639 .25899 L
.72088 .22122 L
.73631 .18225 L
Mistroke
.75116 .14659 L
.76694 .11125 L
.78215 .08136 L
.79678 .05607 L
.81234 .03632 L
.81607 .03159 L
.82008 .0265 L
.82101 .02532 L
.8215 .0247 L
.82202 .02404 L
.82252 .02341 L
.82298 .02328 L
.82386 .02303 L
.82733 .02205 L
.84174 .01797 L
.84907 .0159 L
.85107 .01533 L
.85217 .01502 L
.85271 .01487 L
.85319 .01473 L
.85364 .01513 L
.85407 .01556 L
.85501 .01652 L
.857 .01856 L
.87159 .03349 L
.87897 .04105 L
.881 .04312 L
.88206 .04421 L
.88318 .04535 L
.88365 .04584 L
.88392 .04611 L
.88416 .04667 L
.88472 .04816 L
.88524 .04955 L
.88712 .05461 L
.90208 .09467 L
.91 .1159 L
.9173 .14076 L
.93195 .20983 L
.9397 .24637 L
.94696 .28428 L
.96139 .3876 L
.97617 .49347 L
.97619 .49359 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[82]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00@oooool3o`0002[ooooo1Ol0000Yooooo`;o0000;?ooool5o`0002cooooo0ol0000Poooo
o`00A?ooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`0002Sooooo00Co0000oooo
oooooooo0000;?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo01oooooo000k
ooooo`Go000000?oooooo`000?l000000ol0000Tooooo`Go00000oooool00ol0003oooooooooo`0X
ooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0:_ooool5o`00023ooooo0011
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool09oooool01?l0003ooooooooo
ool0000^ooooo`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo00008Oooool004;ooooo
00?o0000ooooool00000:oooool01Ol0003ooooooooooooooooo000002Sooooo00Co0000oooooooo
oooo0000:oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooool000008Oooool0
04?ooooo0_l0000[ooooo`05o`000?ooooooooooooooool00000:?ooool01?l0003oooooooooool0
000[ooooo`05o`000?ooooooooooooooool00000;?ooool2o`00027ooooo0014ooooo`03o`000?oo
oooooooo02[ooooo0ol0000Zooooo`;o0000;Oooool3o`0002kooooo00?o0000ooooooooool07ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool002Cooooon?l0
0004ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo000Toooo
o`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`02oooo
o`009?ooool00ol0003oooooooooo`0Pooooo`?o0000EOooool00ol0003oooooooooo`1Dooooo`;o
00008oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Pooooo`Oo0000
DOooool00ol0003oooooooooo`1@ooooo`Oo00008_ooool00ol0003oooooooooo`02ooooo`009?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo0ol0001>ooooo`03o`000?oo
oooooooo04gooooo0ol00006ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_oo
ool002Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`;o0000C_ooool0
0ol0003oooooooooo`1=ooooo`;o00002?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00;ooooo000Tooooo`;o00007_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01gooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00gooooo0_l0
000Looooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo01Wooooo0_l0000B
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0?
ooooo`;o00006oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Ioooo
o`;o00004oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool04?ooool2o`0001_ooooo00?o0000ooooooooool00_ooool000_ooooo0_l00004ooooo`03
o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`00
2_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo0003ooooo`Go00000_ooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`0Dooooo`;o0000A_ooool00ol0003ooooo
ooooo`15ooooo`?o00005_ooool00ol0003oooooooooo`0Gooooo`;o00001?ooool000[ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o00001Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Gooooo0_l00016ooooo`03o`000?oooooooooo04Go
oooo0_l0000Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool000[ooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`02ooooo`002_ooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00;ooooo000;ooooo`;o00002_ooool2o`0000?ooooo0ol00005ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00;ooooo000Tooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00;ooooo000Tooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo
000Tooooo`;o00005_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Cooooo0_l0
0004ooooo`009?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02oooo
o`009?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`009?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02;ooooo0_l0000oooooo`03o`000?oooooooooo03gooooo0_l0000Uooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool04Oooool2o`00
02Cooooo0_l0000oooooo`03o`000?oooooooooo03gooooo0_l0000Tooooo`;o00005?ooool00ol0
003oooooooooo`02ooooo`009?ooool2o`0001;ooooo0_l0000Vooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`;o00004oooool2o`0000Co
oooo000Tooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo000T
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo000Tooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00;ooooo000Tooooo`;o00004Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00oooooo0_l00004ooooo`009?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`02ooooo`009?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`02ooooo`002oooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000:ooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool000?ooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0]ooooo`;o0000=oooool00ol0003o
ooooooooo`0fooooo`;o0000;oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`00
00Gooooo0_l0000?ooooo`03o`000?oooooooooo02kooooo0_l0000gooooo`03o`000?oooooooooo
03Kooooo0_l0000_ooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`002_ooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`02ooooo`002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`002oooool2o`0000[ooooo0_l0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02
ooooo`009?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00
9?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`02ooooo`009?ooool2o`0000gooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0<ooooo`;o00001?ooool002Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool0
02Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool002Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00_ooool002Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool002Cooooo0_l0000<ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool2o`0000Cooooo000Tooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00;ooooo000Tooooo`03o`000?oooooooooo00[ooooo0_l0000kooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0iooooo`;o00003?oo
ool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o0000>_ooool2
o`00033ooooo00?o0000ooooooooool0;_ooool2o`0003_ooooo0_l0000<ooooo`03o`000?oooooo
oooo00;ooooo000Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool3o`00
02oooooo00?o0000ooooooooool0;_ooool2o`0003cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`009?ooool2o`0000[ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`08oooo
o`;o00001?ooool002Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool002Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool0
02Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_ooool000_ooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`002_ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`02ooooo`000oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01Ol0
003oooooooooool0003ooooo00Go00001?ooool2o`0000Wooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`07ooooo`;o00001?ooool000[ooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`02ooooo`002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooool000001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`002_ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo0_l00005ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00;ooooo000;ooooo`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`009?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04Cooooo0_l0000Xooooo`03o`000?oooooooooo02Oooooo0_l0
0016ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`14ooooo`;o0000:?ooool00ol0003oooooooooo`0W
ooooo`;o0000A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo000Toooo
o`;o00002?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Kooooo0_l00004oooo
o`009?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`009?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`009?ooool2o`0000Oooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`05ooooo`;o00001?ooool002Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool002Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool002Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
02Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1>ooooo`;o00008?ooool00ol0003oooooooooo`0Oooooo`;o0000D?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo000Tooooo`;o00001_ooool00ol0003ooooo
ooooo`1>ooooo`;o00008?ooool00ol0003oooooooooo`0Oooooo`;o0000D?ooool00ol0003ooooo
ooooo`04ooooo`;o00001?ooool002Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool002Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool002Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool000_ooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0_l00002ooooo`Go00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`002_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05;ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`000oooool5o`0000;ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo0_l00005oooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool00oooool2o`0000Cooooo000:ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo000:ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool000[ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`002oooool2o`0000[o
oooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`009?ooool00ol0003oooooooooo`02ooooo`;o0000FOooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0E_ooool2o`0000Gooooo00?o
0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool00_ooool2o`0005Wooooo0_l0000I
ooooo`03o`000?oooooooooo01Oooooo0ol0001Hooooo`;o00001Oooool00ol0003oooooooooo`02
ooooo`009?ooool00ol0003oooooooooo`1Mooooo`;o00006Oooool00ol0003oooooooooo`0Goooo
o`;o0000H?ooool00ol0003oooooooooo`02ooooo`009?ooool2o`00063ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05kooooo0_l00004ooooo`00
9?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00;ooooo000Tooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00;ooooo000Tooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool00_ooool002Cooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo00;ooooo000Tooooo`;o0000I?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Hoooool2o`0000Cooooo000Toooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`1Uooooo`;o0000
4Oooool00ol0003oooooooooo`0@ooooo`;o0000Ioooool00ol0003oooooooooo`02ooooo`009?oo
ool00ol0003oooooooooo`1Uooooo`;o00004Oooool00ol0003oooooooooo`0@ooooo`;o0000Iooo
ool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo00;ooooo000Tooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool00_ooool002Co
oooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`02ooooo`009?ooool2o`0006[ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06Sooooo
0_l00004ooooo`009?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00;ooooo000T
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool00_ooool002Cooooo00?o0000oooo
ooooool0K?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0K?ooool00ol0003oooooooooo`02ooooo`009?ooool00ol0003oooooooooo`1/ooooo`;o
00002_ooool00ol0003oooooooooo`08ooooo`;o0000Koooool00ol0003oooooooooo`02ooooo`00
9?ooool00ol0003oooooooooo`1/ooooo`Co00002?ooool00ol0003oooooooooo`06ooooo`Co0000
Koooool00ol0003oooooooooo`02ooooo`007Oooool2o`0000Gooooo00?o0000ooooooooool0Kooo
ool2o`0000Oooooo00?o0000ooooooooool01?ooool2o`0007?ooooo00?o0000ooooooooool00_oo
ool001cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1aooooo`;o00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00_oo
ool001cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1cooooo`?o00000_oo
ool01?l0003oooooooooooooool3o`0007Gooooo00?o0000ooooooooool00_ooool001cooooo00Co
0000oooooooooooo00001?ooool2o`0007Gooooo2_l0001eooooo`;o00001?ooool001cooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Wooooo
00?o0000ooooooooool00_ooool001cooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo000Mooooo`;o00001Ooooooho`0000Cooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo000fooooo`?o0000R_ooool00ol0003ooooo
ooooo`0[ooooo`?o00005Oooool00ol0003oooooooooo`0Dooooo`00=oooool00ol0003ooooooooo
o`28ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`00<Oooool3o`0000?ooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0ol00003
ooooo`Co000000?oooooo`000?l000000ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002
ooooo`Ko00001_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o
000000?o00000_ooool3o`0000;ooooo0ol00004ooooo`?o00000_ooool3o`000004ooooool0003o
0000ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0003ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000;ooooo0ol0
0002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_ooool:o`0000Gooooo
00?o0000ooooooooool04_ooool0033ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000000_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool0033o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00000_ooool00ol0
003oooooooooo`02ooooo`Go00000_ooool01_l0003oooooooooool0003oooooo`0000Gooooo1Ol0
0008ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o0000
0oooool00ol0003oooooo`000002ooooo`Go00000oooool01?l0003oooooooooooooool5o`0000;o
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00000_ooool3o`0000Gooooo00?o0000ooooooooool04_ooool0033ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0ol00002ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00005oooo
o`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`0Booooo`00<?ooool0
1_l0003ooooooooooooooooo0000ooooo`Co00000_ooool4o`0000;ooooo0ol00004ooooo`?o0000
0oooool2o`0000Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00002ooooo`;o
00000oooool4o`0000?ooooo0ol00009ooooo`05o`000?ooooooooooo`000?ooool00ol00004oooo
o`Co00000_ooool4o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00;ooooo1?l00003ooooo`?o00000oooool3o`0000Wooooo00?o0000ooooooooool00_ooool6o`00
0003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool00ol0
003oooooooooo`02ooooo`?o00000_ooool4o`0000?ooooo2Ol00003ooooo`?o00000oooool4o`00
00Cooooo00?o0000ooooooooool04_ooool0033ooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01?ooooo000aooooo`?o00002Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00gooooo0ol00009ooooo`Co00002Oooool00ol0003oooooooooo`02
ooooo`;o00002_ooool4o`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0000^
ooooo`03o`000?oooooooooo01Sooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000;
ooooo`03o`000?oooooooooo01Cooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.79886, -0.0966812, \
0.0424976, 0.000599718}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 29.8233 0.0123456 0.00370703 [
[.05265 -0.00015 -18 -9 ]
[.05265 -0.00015 18 0 ]
[.20177 -0.00015 -15 -9 ]
[.20177 -0.00015 15 0 ]
[.35088 -0.00015 -18 -9 ]
[.35088 -0.00015 18 0 ]
[.5 -0.00015 -3 -9 ]
[.5 -0.00015 3 0 ]
[.64912 -0.00015 -15 -9 ]
[.64912 -0.00015 15 0 ]
[.79823 -0.00015 -12 -9 ]
[.79823 -0.00015 12 0 ]
[.94735 -0.00015 -15 -9 ]
[.94735 -0.00015 15 0 ]
[.01131 .10502 -12 -4.5 ]
[.01131 .10502 0 4.5 ]
[.01131 .1977 -12 -4.5 ]
[.01131 .1977 0 4.5 ]
[.01131 .29037 -12 -4.5 ]
[.01131 .29037 0 4.5 ]
[.01131 .38305 -18 -4.5 ]
[.01131 .38305 0 4.5 ]
[.01131 .47572 -18 -4.5 ]
[.01131 .47572 0 4.5 ]
[.01131 .5684 -18 -4.5 ]
[.01131 .5684 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05265 .01235 m
.05265 .0186 L
s
[(-0.015)] .05265 -0.00015 0 1 Mshowa
.20177 .01235 m
.20177 .0186 L
s
[(-0.01)] .20177 -0.00015 0 1 Mshowa
.35088 .01235 m
.35088 .0186 L
s
[(-0.005)] .35088 -0.00015 0 1 Mshowa
.5 .01235 m
.5 .0186 L
s
[(0)] .5 -0.00015 0 1 Mshowa
.64912 .01235 m
.64912 .0186 L
s
[(0.005)] .64912 -0.00015 0 1 Mshowa
.79823 .01235 m
.79823 .0186 L
s
[(0.01)] .79823 -0.00015 0 1 Mshowa
.94735 .01235 m
.94735 .0186 L
s
[(0.015)] .94735 -0.00015 0 1 Mshowa
.125 Mabswid
.08247 .01235 m
.08247 .0161 L
s
.1123 .01235 m
.1123 .0161 L
s
.14212 .01235 m
.14212 .0161 L
s
.17194 .01235 m
.17194 .0161 L
s
.23159 .01235 m
.23159 .0161 L
s
.26141 .01235 m
.26141 .0161 L
s
.29124 .01235 m
.29124 .0161 L
s
.32106 .01235 m
.32106 .0161 L
s
.38071 .01235 m
.38071 .0161 L
s
.41053 .01235 m
.41053 .0161 L
s
.44035 .01235 m
.44035 .0161 L
s
.47018 .01235 m
.47018 .0161 L
s
.52982 .01235 m
.52982 .0161 L
s
.55965 .01235 m
.55965 .0161 L
s
.58947 .01235 m
.58947 .0161 L
s
.61929 .01235 m
.61929 .0161 L
s
.67894 .01235 m
.67894 .0161 L
s
.70876 .01235 m
.70876 .0161 L
s
.73859 .01235 m
.73859 .0161 L
s
.76841 .01235 m
.76841 .0161 L
s
.82806 .01235 m
.82806 .0161 L
s
.85788 .01235 m
.85788 .0161 L
s
.8877 .01235 m
.8877 .0161 L
s
.91753 .01235 m
.91753 .0161 L
s
.02283 .01235 m
.02283 .0161 L
s
.97717 .01235 m
.97717 .0161 L
s
.25 Mabswid
0 .01235 m
1 .01235 L
s
.02381 .10502 m
.03006 .10502 L
s
[(25)] .01131 .10502 1 0 Mshowa
.02381 .1977 m
.03006 .1977 L
s
[(50)] .01131 .1977 1 0 Mshowa
.02381 .29037 m
.03006 .29037 L
s
[(75)] .01131 .29037 1 0 Mshowa
.02381 .38305 m
.03006 .38305 L
s
[(100)] .01131 .38305 1 0 Mshowa
.02381 .47572 m
.03006 .47572 L
s
[(125)] .01131 .47572 1 0 Mshowa
.02381 .5684 m
.03006 .5684 L
s
[(150)] .01131 .5684 1 0 Mshowa
.125 Mabswid
.02381 .03088 m
.02756 .03088 L
s
.02381 .04942 m
.02756 .04942 L
s
.02381 .06795 m
.02756 .06795 L
s
.02381 .08649 m
.02756 .08649 L
s
.02381 .12356 m
.02756 .12356 L
s
.02381 .14209 m
.02756 .14209 L
s
.02381 .16063 m
.02756 .16063 L
s
.02381 .17916 m
.02756 .17916 L
s
.02381 .21623 m
.02756 .21623 L
s
.02381 .23477 m
.02756 .23477 L
s
.02381 .2533 m
.02756 .2533 L
s
.02381 .27184 m
.02756 .27184 L
s
.02381 .30891 m
.02756 .30891 L
s
.02381 .32744 m
.02756 .32744 L
s
.02381 .34598 m
.02756 .34598 L
s
.02381 .36451 m
.02756 .36451 L
s
.02381 .40158 m
.02756 .40158 L
s
.02381 .42012 m
.02756 .42012 L
s
.02381 .43865 m
.02756 .43865 L
s
.02381 .45719 m
.02756 .45719 L
s
.02381 .49426 m
.02756 .49426 L
s
.02381 .5128 m
.02756 .5128 L
s
.02381 .53133 m
.02756 .53133 L
s
.02381 .54987 m
.02756 .54987 L
s
.02381 .58694 m
.02756 .58694 L
s
.02381 .60547 m
.02756 .60547 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Point Spread Intensity Function)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01899 m
.04023 .02062 L
.05665 .02115 L
.07307 .02038 L
.08949 .01851 L
.10591 .01627 L
.12233 .01472 L
.13875 .01494 L
.15517 .01778 L
.17159 .0234 L
.18801 .03117 L
.20443 .03963 L
.22085 .04681 L
.23727 .05067 L
.25369 .04977 L
.27011 .0439 L
.28654 .03447 L
.30296 .02467 L
.31938 .01914 L
.3358 .02322 L
.35222 .04199 L
.36864 .07907 L
.38506 .13563 L
.40148 .20968 L
.4179 .29601 L
.43432 .38662 L
.45074 .4718 L
.46716 .54158 L
.48358 .58737 L
.5 .60332 L
.51642 .58737 L
.53284 .54158 L
.54926 .4718 L
.56568 .38662 L
.5821 .29601 L
.59852 .20968 L
.61494 .13563 L
.63136 .07907 L
.64778 .04199 L
.6642 .02322 L
.68062 .01914 L
.69704 .02467 L
.71346 .03447 L
.72989 .0439 L
.74631 .04977 L
.76273 .05067 L
.77915 .04681 L
.79557 .03963 L
.81199 .03117 L
.82841 .0234 L
Mistroke
.84483 .01778 L
.86125 .01494 L
.87767 .01472 L
.89409 .01627 L
.91051 .01851 L
.92693 .02038 L
.94335 .02115 L
.95977 .02062 L
.97619 .01899 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[82]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00003oooo
o`?o00003oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000>oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000?ooooo0ol0000Eoooo
o`;o00005oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00003oooo
o`?o00003oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000>oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000?ooooo0ol0000=oooo
o`006_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
2_ooool001?ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05
ooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`00
01Gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0:ooooo`006_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0<ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo017ooooo00Co0000oooooooooooo00005Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`0;ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0<ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo000Jooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooooooool4o`0000kooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`05o`000?oo
ooooooooo`000?ooool01?l0000Dooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooo`000?ooool01?l0
000>ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0<ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooooooool4o`0000gooooo000Jooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool2o`0000?ooooo00?o0000ooooooooool03oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0_l0000>ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0001Oo
oooo00Co0000oooooooooooo00005Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0000Aooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool2o`0000kooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00002ooooo`;o00000oooool00ol0003oooooooooo`0>ooooo`006ooo
ool2o`0000[ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00003_ooool2o`0000[ooooo
0_l00004ooooo`03o`000?oooooooooo00gooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo
1Ol0000Dooooo`;o00005oooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool5o`0000kooooo
0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`0=ooooo`;o00002_ooool2o`0000Cooooo
00Co0000oooooooooooooooo1Ol0000<ooooo`00oooooolQooooo`007_ooool00ol0003ooooooooo
o`3oooooo`007_ooool00ol0003oooooooooo`3oooooo`007_ooool00ol0003oooooooooo`3ooooo
o`006?ooooomo`0000_ooooo000Mooooo`Co00001?ooool00ol0003oooooooooo`04ooooo`Wo0000
1oooool00ol0003oooooo`000003o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool4o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`Co0000
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co000000?oooooo`000?ooool0
1Oooool9o`0000Kooooo00?o0000ooooooooool00oooool3o`00017ooooo000Nooooo`03o`000?oo
oooooooo00_o00005_ooool3o`00023ooooo0_l00004ooooo`;o0000D_ooool2o`0000Cooooo0_l0
000Pooooo`Co00005Oooool<o`0001Cooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000L
ooooo`;o00001oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Gooooo0_l0000L
ooooo`;o0000>Oooool001kooooo0_l0000Wooooo`;o00006?ooool2o`0000[ooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`08ooooo`?o00005oooool2o`0003_ooooo000Nooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool04oooool2o`0000gooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0<ooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`00
7_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0looooo`007_ooool00ol0003oooooooooo`0Zooooo`?o00003ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0<ooooo`?o0000?oooool001kooooo00?o0000ooooooooool0;Oooool5
o`0000Oooooo0ol0000Cooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool04_ooool3
o`0000Oooooo1?l00012ooooo`007_ooool2o`0003?ooooo1ol0000Gooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool05_ooool7o`0004Kooooo000Nooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Sooooo`007_ooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0Hoooool001kooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo06Cooooo000N
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1T
ooooo`007_ooool2o`0005?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1Uoooo
o`007_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool0IOooool001kooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo06Gooooo000Nooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`1Vooooo`007_ooool2o`0005Gooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`1Vooooo`007_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0I_ooool001kooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo06Oooooo000?ooooo`Go00000_ooool3o`0000Gooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo06Oooooo
000@ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1Wooooo`00
4Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0001Gooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0J?ooool001;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`1Xooooo`003oooool01_l0003ooooooooooooooooo0000ooooo`Co0000
1Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
J?ooool000oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o0000oooooooo
ool0E_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo06Sooooo000@ooooo`?o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo06Wooooo000Nooooo`;o0000F?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo06Wooooo000Nooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`1Yooooo`007_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0J_ooool001kooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo06[ooooo000Nooooo`;o0000FOooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo06[ooooo000Nooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`1Zooooo`007_ooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Joooool001kooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo06_ooooo000Nooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1[ooooo`00
7_ooool2o`0005[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1[ooooo`007_oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Jooo
ool001kooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo06cooooo000Nooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`1/ooooo`007_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0K?ooool001kooooo0_l0001Kooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0K?ooool001kooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo06gooooo000@ooooo`?o00001?ooool2o`0000Gooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo06gooooo000?oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1]ooooo`004oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0001Looooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0KOooool001?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`1]ooooo`003oooool4o`0000?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0K_oo
ool000oooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1^ooooo`003oooool5
o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`1^ooooo`007_ooool2o`0005gooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`1^ooooo`007_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0Koooool001kooooo00?o0000ooooooooool0GOooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo06oooooo000Nooooo`03o`000?oooooooooo05gooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`1_ooooo`007_ooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Koooool001kooooo0_l0001Noooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Koooool001kooooo00?o0000oooooooo
ool0GOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo073ooooo000Nooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1`ooooo`007_oo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0L?oo
ool001kooooo0_l0001Oooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0L?ooool0
01kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
077ooooo000Nooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`1aooooo`007_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0LOooool001kooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo077ooooo000Nooooo`;o0000H?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo07;ooooo000Nooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`1booooo`004Oooool00ol0003oooooooooo`02ooooo`?o
00001Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0L_ooool0017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07;o
oooo000Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0L_ooool001;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000HOooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo07?ooooo000Cooooo`03o`000?oooooo000000?o00001Oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Loooool0
00oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07?ooooo000?ooooo`Go000000?ooooo
o`000?l000000ol00004ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1cooooo`007_ooool2o`00067ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`1cooooo`007_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0M?ooool001kooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo07Cooooo000Nooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1dooooo`007_ooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0M?ooool001kooooo0_l0001Roooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0M?ooool001kooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo07Cooooo000Nooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1eooooo`007_oo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0MOoo
ool001kooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo07Gooooo000Nooooo`;o0000Hoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Gooooo000Nooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`1eooooo`007_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0M_ooool001kooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo07Kooooo000Nooooo`;o0000I?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo07Kooooo000Nooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`1fooooo`007_ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0M_ooool000[ooooo0ol00004ooooo`;o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo07Kooooo000;ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`1gooooo`002oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`0006Gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1gooooo`002oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Moooool000_ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Oooooo000:
ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Oooooo
000;ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Moooool001kooooo0_l0001V
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0N?ooool001kooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo07Sooooo000Nooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1hooooo`00
7_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
N?ooool001kooooo0_l0001Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0N?oo
ool001kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo07Wooooo000Nooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1iooooo`007_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0NOooool001kooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo07Wooooo000Nooooo`;o0000Ioooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo07Wooooo000Nooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1jooooo`007_ooool00ol0003oooooooooo`1Woooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0N_ooool001kooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo07[ooooo000Nooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1jooooo`007_oo
ool2o`0006Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1jooooo`007_ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Noooool0
00[ooooo0ol00002ooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo07_ooooo000;ooooo`03o`000?oooooooooo00;o
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo07_ooooo000;oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`;o0000JOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo07_ooooo000;ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1kooooo`00
2oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000ol00005ooooo`03
o`000?oooooooooo06Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1looooo`00
2_ooool2o`0000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o0000oooo
ooooool0JOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07cooooo000;ooooo`03
o`000?oooooooooo00;ooooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0O?ooool001kooooo0_l0001Zooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0O?ooool001kooooo00?o0000ooooooooool0JOoo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07cooooo000Nooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1mooooo`007_ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0OOooool001ko
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07go
oooo000Nooooo`;o0000Joooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07gooooo
000Nooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`1nooooo`007_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0O_ooool001kooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo07kooooo000Nooooo`;o0000K?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo07kooooo000Nooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1nooooo`007_ooool00ol0003oooooooooo`1/ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0Ooooool001kooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07oooooo000Nooooo`03o`000?oooooooooo
06cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1oooooo`007_ooool2o`0006ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`20ooooo`007_ooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0P?ooool000[ooooo0ol0
0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo083ooooo000;ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo087ooooo000;ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`21ooooo`002ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool2o`00073ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`21ooooo`002ooo
ool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0P_ooool000[ooooo
0_l00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0P_ooool000_ooooo
00Co0000oooooooooooooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0P_ooool001kooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08?ooooo000Nooooo`;o0000L_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08?ooooo000Nooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`24ooooo`007_ooool00ol0
003oooooooooo`1cooooo`05o`000?ooooooooooooooool00000Qoooool001kooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooo`000028ooooo`007_ooool2o`0007Kooooo00?o0000oooooooo
ool0Qoooool001kooooo00?o0000ooooooooool0ooooool001kooooo00?o0000ooooooooool0oooo
ool001kooooo00?o0000ooooooooool0ooooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool006?ooooo0ol0001Aooooo`?o0000I_ooool006Cooooo00?o0000ooooooooool0DOooool0
0ol0003oooooooooo`1Uooooo`00>Oooool3o`0000Cooooo0ol00002ooooo`Go000000Goooooo`00
0?l0003o0000ooooo`02o`0000;ooooo0_l00009ooooo`?o00000oooool3o`0000;ooooo0ol00004
ooooo`?o00000oooool4o`0000;ooooo1?l00007ooooo`Go000000Goooooo`000?l0003o0000oooo
o`02o`0000;ooooo0_l00003ooooo`?o00000_ooool3o`000003ooooool0003o000000Co00000_oo
ool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo00Oooooo0ol00005ooooo`;o000000?o
ooooo`000?l000000_l000001?oooooo0000o`000?ooool3o`0000Cooooo0_l00002ooooo`Go0000
0_ooool3o`0000;ooooo0ol000000ooooooo0000o`00000]ooooo`00>_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0006ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool0000^ooooo`00>_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo1Ol00002ooooo`?o00000_ooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000002Oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool0;?ooool003[ooooo0ol00002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool02_ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`00
00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01_l0
003oooooooooool0003oooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Wooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
;?ooool003[ooooo00Co0000oooooooooooo00000_ooool3o`0000;ooooo0ol00003ooooo`Co0000
0_ooool4o`0000Wooooo00?o0000ooooooooool00_ooool4o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`?o00000oooool2o`0000Cooooo0ol0000:ooooo`04o`000?ooooooooooooooo`Co
00000_ooool4o`0000?ooooo0ol00002ooooo`Co00000oooool4o`000004ooooool0003o0000o`00
00?ooooo1?l00002ooooo`;o000000?oooooo`000?l000002?ooool00ol0003oooooooooo`02oooo
o`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`?o00000_ooool4o`0000;ooooo0ol00004
ooooo`?o00000_ooool4o`0002oooooo000jooooo`04o`000?ooooooooooo`0001Cooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooo00005?ooool00ol0003oooooooooo`11ooooo`00>Oooool4o`0000[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`?o00006oooool2o`0000Sooooo1Ol0
0008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0>ooooo`Go00005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0199861, -13.0056, \
0.000133055, 1.07044}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Finally, we make a three-dimensional plot of symbolic intensity between the \
optical and transverse axes. The peak indicates the paraxial focus of the \
system.\
\>", "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
Plot3D[intensity[x,y],{x,-2,2},{y,-.1,.1},PlotRange->All,PlotPoints->100];\
\>", "Input",
  CellLabel->"In[83]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -11.7989 -9 ]
[.17646 .18758 .20112 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -5.27396 -9 ]
[.50253 .05935 .72604 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 24 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 30 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 24 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01428 .32673 -12 -2.79444 ]
[.01428 .32673 0 6.20556 ]
[.00405 .39088 -18 -2.8489 ]
[.00405 .39088 0 6.1511 ]
[-0.00661 .4577 -18 -2.90588 ]
[-0.00661 .4577 0 6.09412 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-2)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-0.1)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-0.05)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.05)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02655 .32208 m
.03269 .31976 L
s
[(50)] .01428 .32673 1 -0.37901 Mshowa
.01637 .38636 m
.02253 .3841 L
s
[(100)] .00405 .39088 1 -0.36691 Mshowa
.00575 .45331 m
.01194 .45112 L
s
[(150)] -0.00661 .4577 1 -0.35425 Mshowa
.125 Mabswid
.03441 .27249 m
.03808 .27106 L
s
.03247 .28474 m
.03614 .28332 L
s
.03051 .29709 m
.03419 .29568 L
s
.02854 .30954 m
.03222 .30813 L
s
.02455 .33473 m
.02823 .33334 L
s
.02253 .34748 m
.02621 .3461 L
s
.02049 .36034 m
.02418 .35896 L
s
.01844 .37329 m
.02213 .37193 L
s
.01428 .39953 m
.01798 .39818 L
s
.01217 .41281 m
.01588 .41147 L
s
.01005 .4262 m
.01376 .42487 L
s
.00791 .4397 m
.01162 .43838 L
s
.00358 .46704 m
.00729 .46574 L
s
.00139 .48089 m
.0051 .47959 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.697 .787 .92 r
.40192 .6042 .40502 .60651 .41021 .60451 .40712 .60215 Metetra
.695 .783 .919 r
.40712 .60215 .41021 .60451 .41541 .60255 .41233 .60013 Metetra
.692 .779 .918 r
.41233 .60013 .41541 .60255 .42061 .60064 .41754 .59815 Metetra
.689 .774 .916 r
.41754 .59815 .42061 .60064 .42582 .59877 .42276 .59622 Metetra
.685 .769 .915 r
.42276 .59622 .42582 .59877 .43104 .59694 .42798 .59433 Metetra
.682 .765 .914 r
.42798 .59433 .43104 .59694 .43626 .59516 .43322 .59249 Metetra
.679 .76 .913 r
.43322 .59249 .43626 .59516 .4415 .59342 .43846 .59069 Metetra
.676 .757 .912 r
.43846 .59069 .4415 .59342 .44674 .5917 .44371 .58894 Metetra
.673 .754 .911 r
.44371 .58894 .44674 .5917 .45199 .59001 .44897 .58721 Metetra
.671 .751 .91 r
.44897 .58721 .45199 .59001 .45726 .58835 .45424 .58551 Metetra
.67 .749 .91 r
.45424 .58551 .45726 .58835 .46253 .5867 .45952 .58384 Metetra
.668 .747 .909 r
.45952 .58384 .46253 .5867 .46781 .58506 .46481 .58218 Metetra
.667 .746 .909 r
.46481 .58218 .46781 .58506 .4731 .58343 .47011 .58054 Metetra
.666 .745 .909 r
.47011 .58054 .4731 .58343 .4784 .58181 .47541 .5789 Metetra
.666 .744 .909 r
.47541 .5789 .4784 .58181 .48371 .5802 .48073 .57727 Metetra
.665 .743 .908 r
.48073 .57727 .48371 .5802 .48903 .57859 .48606 .57565 Metetra
.665 .743 .908 r
.48606 .57565 .48903 .57859 .49436 .57697 .4914 .57402 Metetra
.664 .742 .908 r
.4914 .57402 .49436 .57697 .49971 .57536 .49675 .5724 Metetra
.664 .742 .908 r
.49675 .5724 .49971 .57536 .50506 .57375 .50211 .57078 Metetra
.664 .742 .908 r
.50211 .57078 .50506 .57375 .51042 .57213 .50748 .56916 Metetra
.664 .742 .908 r
.50748 .56916 .51042 .57213 .5158 .57052 .51286 .56754 Metetra
.664 .742 .908 r
.51286 .56754 .5158 .57052 .52118 .5689 .51825 .56591 Metetra
.664 .741 .908 r
.51825 .56591 .52118 .5689 .52657 .56728 .52365 .56429 Metetra
.664 .741 .908 r
.52365 .56429 .52657 .56728 .53198 .56566 .52906 .56266 Metetra
.664 .741 .908 r
.52906 .56266 .53198 .56566 .53739 .56403 .53448 .56103 Metetra
.664 .741 .908 r
.53448 .56103 .53739 .56403 .54282 .5624 .53992 .55939 Metetra
.664 .741 .908 r
.53992 .55939 .54282 .5624 .54826 .56077 .54536 .55775 Metetra
.664 .741 .908 r
.54536 .55775 .54826 .56077 .55371 .55914 .55081 .55611 Metetra
.664 .741 .908 r
.55081 .55611 .55371 .55914 .55916 .5575 .55628 .55447 Metetra
.664 .741 .908 r
.55628 .55447 .55916 .5575 .56463 .55586 .56176 .55282 Metetra
.664 .741 .908 r
.56176 .55282 .56463 .55586 .57011 .55422 .56724 .55117 Metetra
.664 .741 .908 r
.56724 .55117 .57011 .55422 .5756 .55257 .57274 .54952 Metetra
.664 .741 .908 r
.57274 .54952 .5756 .55257 .58111 .55092 .57825 .54786 Metetra
.664 .741 .908 r
.57825 .54786 .58111 .55092 .58662 .54926 .58377 .5462 Metetra
.664 .741 .908 r
.58377 .5462 .58662 .54926 .59214 .54761 .5893 .54454 Metetra
.664 .741 .908 r
.5893 .54454 .59214 .54761 .59768 .54595 .59484 .54287 Metetra
.664 .741 .908 r
.59484 .54287 .59768 .54595 .60322 .54428 .6004 .5412 Metetra
.664 .741 .908 r
.6004 .5412 .60322 .54428 .60878 .54262 .60596 .53953 Metetra
.664 .741 .908 r
.60596 .53953 .60878 .54262 .61435 .54095 .61154 .53785 Metetra
.664 .741 .908 r
.61154 .53785 .61435 .54095 .61993 .53927 .61712 .53617 Metetra
.664 .741 .908 r
.61712 .53617 .61993 .53927 .62552 .53759 .62272 .53449 Metetra
.664 .741 .908 r
.62272 .53449 .62552 .53759 .63112 .53591 .62833 .5328 Metetra
.664 .741 .908 r
.62833 .5328 .63112 .53591 .63673 .53423 .63395 .53111 Metetra
.664 .741 .908 r
.63395 .53111 .63673 .53423 .64235 .53254 .63958 .52942 Metetra
.664 .741 .908 r
.63958 .52942 .64235 .53254 .64799 .53085 .64522 .52772 Metetra
.664 .741 .908 r
.64522 .52772 .64799 .53085 .65364 .52916 .65088 .52602 Metetra
.664 .741 .908 r
.65088 .52602 .65364 .52916 .65929 .52746 .65654 .52432 Metetra
.664 .741 .908 r
.65654 .52432 .65929 .52746 .66496 .52576 .66222 .52261 Metetra
.664 .741 .908 r
.66222 .52261 .66496 .52576 .67064 .52406 .66791 .5209 Metetra
.664 .741 .908 r
.66791 .5209 .67064 .52406 .67633 .52235 .67361 .51919 Metetra
.664 .741 .908 r
.67361 .51919 .67633 .52235 .68204 .52064 .67932 .51747 Metetra
.664 .741 .908 r
.67932 .51747 .68204 .52064 .68775 .51892 .68504 .51575 Metetra
.664 .741 .908 r
.68504 .51575 .68775 .51892 .69348 .51721 .69078 .51403 Metetra
.664 .741 .908 r
.69078 .51403 .69348 .51721 .69922 .51548 .69652 .5123 Metetra
.664 .741 .908 r
.69652 .5123 .69922 .51548 .70497 .51376 .70228 .51057 Metetra
.664 .741 .908 r
.70228 .51057 .70497 .51376 .71073 .51203 .70805 .50883 Metetra
.664 .741 .908 r
.70805 .50883 .71073 .51203 .7165 .5103 .71383 .50709 Metetra
.664 .741 .908 r
.71383 .50709 .7165 .5103 .72229 .50856 .71962 .50535 Metetra
.664 .741 .908 r
.71962 .50535 .72229 .50856 .72808 .50682 .72543 .50361 Metetra
.664 .741 .908 r
.72543 .50361 .72808 .50682 .73389 .50508 .73125 .50186 Metetra
.664 .741 .908 r
.73125 .50186 .73389 .50508 .73971 .50334 .73707 .5001 Metetra
.664 .741 .908 r
.73707 .5001 .73971 .50334 .74554 .50159 .74292 .49835 Metetra
.664 .741 .908 r
.74292 .49835 .74554 .50159 .75139 .49983 .74877 .49659 Metetra
.664 .741 .908 r
.74877 .49659 .75139 .49983 .75724 .49808 .75463 .49482 Metetra
.664 .741 .908 r
.75463 .49482 .75724 .49808 .76311 .49632 .76051 .49306 Metetra
.664 .741 .908 r
.76051 .49306 .76311 .49632 .76899 .49455 .7664 .49129 Metetra
.664 .741 .908 r
.7664 .49129 .76899 .49455 .77488 .49278 .7723 .48951 Metetra
.664 .741 .908 r
.7723 .48951 .77488 .49278 .78079 .49101 .77821 .48773 Metetra
.664 .741 .908 r
.77821 .48773 .78079 .49101 .78671 .48924 .78414 .48595 Metetra
.664 .741 .908 r
.78414 .48595 .78671 .48924 .79263 .48746 .79007 .48417 Metetra
.664 .741 .908 r
.79007 .48417 .79263 .48746 .79857 .48568 .79602 .48238 Metetra
.664 .741 .908 r
.79602 .48238 .79857 .48568 .80453 .48389 .80198 .48059 Metetra
.663 .741 .908 r
.80198 .48059 .80453 .48389 .81049 .4821 .80796 .47879 Metetra
.663 .741 .908 r
.80796 .47879 .81049 .4821 .81647 .48031 .81394 .47699 Metetra
.663 .741 .908 r
.81394 .47699 .81647 .48031 .82246 .47852 .81994 .47519 Metetra
.663 .741 .908 r
.81994 .47519 .82246 .47852 .82846 .47672 .82595 .47339 Metetra
.663 .741 .908 r
.82595 .47339 .82846 .47672 .83448 .47492 .83198 .47158 Metetra
.663 .741 .908 r
.83198 .47158 .83448 .47492 .84051 .47311 .83802 .46977 Metetra
.663 .741 .908 r
.83802 .46977 .84051 .47311 .84655 .4713 .84407 .46796 Metetra
.663 .741 .908 r
.84407 .46796 .84655 .4713 .8526 .4695 .85013 .46614 Metetra
.663 .742 .909 r
.85013 .46614 .8526 .4695 .85867 .46769 .8562 .46433 Metetra
.663 .742 .909 r
.8562 .46433 .85867 .46769 .86474 .46587 .86229 .46251 Metetra
.662 .742 .909 r
.86229 .46251 .86474 .46587 .87084 .46406 .86839 .4607 Metetra
.662 .742 .909 r
.86839 .4607 .87084 .46406 .87694 .46225 .87451 .45889 Metetra
.661 .742 .91 r
.87451 .45889 .87694 .46225 .88306 .46044 .88064 .45708 Metetra
.661 .742 .91 r
.88064 .45708 .88306 .46044 .88919 .45864 .88678 .45527 Metetra
.66 .743 .911 r
.88678 .45527 .88919 .45864 .89534 .45683 .89294 .45347 Metetra
.66 .743 .912 r
.89294 .45347 .89534 .45683 .9015 .45504 .89911 .45168 Metetra
.659 .743 .912 r
.89911 .45168 .9015 .45504 .90767 .45325 .90529 .4499 Metetra
.658 .744 .913 r
.90529 .4499 .90767 .45325 .91386 .45147 .91149 .44813 Metetra
.656 .744 .915 r
.91149 .44813 .91386 .45147 .92007 .4497 .91771 .44637 Metetra
.655 .745 .916 r
.91771 .44637 .92007 .4497 .92629 .44795 .92394 .44464 Metetra
.653 .746 .918 r
.92394 .44464 .92629 .44795 .93253 .44622 .93019 .44292 Metetra
.652 .747 .919 r
.93019 .44292 .93253 .44622 .93878 .4445 .93646 .44122 Metetra
.65 .748 .921 r
.93646 .44122 .93878 .4445 .94505 .4428 .94274 .43954 Metetra
.648 .749 .923 r
.94274 .43954 .94505 .4428 .95134 .44112 .94904 .43788 Metetra
.646 .75 .925 r
.94904 .43788 .95134 .44112 .95764 .43946 .95536 .43624 Metetra
.644 .751 .927 r
.95536 .43624 .95764 .43946 .96396 .43782 .9617 .43462 Metetra
.643 .752 .928 r
.9617 .43462 .96396 .43782 .9703 .4362 .96805 .43302 Metetra
.7 .791 .922 r
.39881 .60193 .40192 .6042 .40712 .60215 .40402 .59984 Metetra
.698 .789 .921 r
.40402 .59984 .40712 .60215 .41233 .60013 .40923 .59777 Metetra
.696 .785 .919 r
.40923 .59777 .41233 .60013 .41754 .59815 .41445 .59572 Metetra
.693 .78 .918 r
.41445 .59572 .41754 .59815 .42276 .59622 .41968 .59372 Metetra
.689 .775 .917 r
.41968 .59372 .42276 .59622 .42798 .59433 .42492 .59177 Metetra
.686 .77 .915 r
.42492 .59177 .42798 .59433 .43322 .59249 .43016 .58987 Metetra
.682 .765 .914 r
.43016 .58987 .43322 .59249 .43846 .59069 .43541 .58801 Metetra
.679 .761 .913 r
.43541 .58801 .43846 .59069 .44371 .58894 .44067 .5862 Metetra
.676 .757 .912 r
.44067 .5862 .44371 .58894 .44897 .58721 .44594 .58443 Metetra
.673 .754 .911 r
.44594 .58443 .44897 .58721 .45424 .58551 .45121 .5827 Metetra
.671 .751 .91 r
.45121 .5827 .45424 .58551 .45952 .58384 .4565 .58099 Metetra
.67 .749 .91 r
.4565 .58099 .45952 .58384 .46481 .58218 .46179 .57931 Metetra
.668 .747 .909 r
.46179 .57931 .46481 .58218 .47011 .58054 .4671 .57764 Metetra
.667 .746 .909 r
.4671 .57764 .47011 .58054 .47541 .5789 .47241 .57598 Metetra
.666 .745 .909 r
.47241 .57598 .47541 .5789 .48073 .57727 .47774 .57434 Metetra
.666 .744 .909 r
.47774 .57434 .48073 .57727 .48606 .57565 .48307 .5727 Metetra
.665 .743 .908 r
.48307 .5727 .48606 .57565 .4914 .57402 .48842 .57107 Metetra
.665 .743 .908 r
.48842 .57107 .4914 .57402 .49675 .5724 .49378 .56944 Metetra
.664 .742 .908 r
.49378 .56944 .49675 .5724 .50211 .57078 .49914 .56781 Metetra
.664 .742 .908 r
.49914 .56781 .50211 .57078 .50748 .56916 .50452 .56618 Metetra
.664 .742 .908 r
.50452 .56618 .50748 .56916 .51286 .56754 .5099 .56455 Metetra
.664 .742 .908 r
.5099 .56455 .51286 .56754 .51825 .56591 .5153 .56292 Metetra
.664 .742 .908 r
.5153 .56292 .51825 .56591 .52365 .56429 .52071 .56128 Metetra
.664 .741 .908 r
.52071 .56128 .52365 .56429 .52906 .56266 .52613 .55965 Metetra
.664 .741 .908 r
.52613 .55965 .52906 .56266 .53448 .56103 .53156 .55801 Metetra
.664 .741 .908 r
.53156 .55801 .53448 .56103 .53992 .55939 .537 .55637 Metetra
.664 .741 .908 r
.537 .55637 .53992 .55939 .54536 .55775 .54245 .55472 Metetra
.664 .741 .908 r
.54245 .55472 .54536 .55775 .55081 .55611 .54791 .55308 Metetra
.664 .741 .908 r
.54791 .55308 .55081 .55611 .55628 .55447 .55339 .55143 Metetra
.664 .741 .908 r
.55339 .55143 .55628 .55447 .56176 .55282 .55887 .54977 Metetra
.664 .741 .908 r
.55887 .54977 .56176 .55282 .56724 .55117 .56436 .54812 Metetra
.664 .741 .908 r
.56436 .54812 .56724 .55117 .57274 .54952 .56987 .54646 Metetra
.664 .741 .908 r
.56987 .54646 .57274 .54952 .57825 .54786 .57539 .5448 Metetra
.664 .741 .908 r
.57539 .5448 .57825 .54786 .58377 .5462 .58091 .54313 Metetra
.664 .741 .908 r
.58091 .54313 .58377 .5462 .5893 .54454 .58645 .54146 Metetra
.664 .741 .908 r
.58645 .54146 .5893 .54454 .59484 .54287 .592 .53979 Metetra
.664 .741 .908 r
.592 .53979 .59484 .54287 .6004 .5412 .59756 .53811 Metetra
.664 .741 .908 r
.59756 .53811 .6004 .5412 .60596 .53953 .60313 .53643 Metetra
.664 .741 .908 r
.60313 .53643 .60596 .53953 .61154 .53785 .60872 .53475 Metetra
.664 .741 .908 r
.60872 .53475 .61154 .53785 .61712 .53617 .61431 .53306 Metetra
.664 .741 .908 r
.61431 .53306 .61712 .53617 .62272 .53449 .61991 .53137 Metetra
.664 .741 .908 r
.61991 .53137 .62272 .53449 .62833 .5328 .62553 .52968 Metetra
.664 .741 .908 r
.62553 .52968 .62833 .5328 .63395 .53111 .63116 .52798 Metetra
.664 .741 .908 r
.63116 .52798 .63395 .53111 .63958 .52942 .6368 .52628 Metetra
.664 .741 .908 r
.6368 .52628 .63958 .52942 .64522 .52772 .64245 .52458 Metetra
.664 .741 .908 r
.64245 .52458 .64522 .52772 .65088 .52602 .64811 .52288 Metetra
.664 .741 .908 r
.64811 .52288 .65088 .52602 .65654 .52432 .65378 .52117 Metetra
.664 .741 .908 r
.65378 .52117 .65654 .52432 .66222 .52261 .65947 .51945 Metetra
.664 .741 .908 r
.65947 .51945 .66222 .52261 .66791 .5209 .66516 .51773 Metetra
.664 .741 .908 r
.66516 .51773 .66791 .5209 .67361 .51919 .67087 .51601 Metetra
.664 .741 .908 r
.67087 .51601 .67361 .51919 .67932 .51747 .67659 .51429 Metetra
.664 .741 .908 r
.67659 .51429 .67932 .51747 .68504 .51575 .68232 .51256 Metetra
.664 .741 .908 r
.68232 .51256 .68504 .51575 .69078 .51403 .68806 .51083 Metetra
.664 .741 .908 r
.68806 .51083 .69078 .51403 .69652 .5123 .69382 .5091 Metetra
.664 .741 .908 r
.69382 .5091 .69652 .5123 .70228 .51057 .69958 .50736 Metetra
.664 .741 .908 r
.69958 .50736 .70228 .51057 .70805 .50883 .70536 .50562 Metetra
.664 .741 .908 r
.70536 .50562 .70805 .50883 .71383 .50709 .71115 .50387 Metetra
.664 .741 .908 r
.71115 .50387 .71383 .50709 .71962 .50535 .71695 .50213 Metetra
.664 .741 .908 r
.71695 .50213 .71962 .50535 .72543 .50361 .72276 .50037 Metetra
.664 .741 .908 r
.72276 .50037 .72543 .50361 .73125 .50186 .72859 .49862 Metetra
.664 .741 .908 r
.72859 .49862 .73125 .50186 .73707 .5001 .73443 .49686 Metetra
.664 .741 .908 r
.73443 .49686 .73707 .5001 .74292 .49835 .74028 .4951 Metetra
.664 .741 .908 r
.74028 .4951 .74292 .49835 .74877 .49659 .74614 .49333 Metetra
.664 .741 .908 r
.74614 .49333 .74877 .49659 .75463 .49482 .75201 .49156 Metetra
.664 .741 .908 r
.75201 .49156 .75463 .49482 .76051 .49306 .75789 .48979 Metetra
.664 .741 .908 r
.75789 .48979 .76051 .49306 .7664 .49129 .76379 .48801 Metetra
.664 .741 .908 r
.76379 .48801 .7664 .49129 .7723 .48951 .7697 .48623 Metetra
.664 .741 .908 r
.7697 .48623 .7723 .48951 .77821 .48773 .77562 .48444 Metetra
.664 .741 .908 r
.77562 .48444 .77821 .48773 .78414 .48595 .78156 .48265 Metetra
.664 .741 .908 r
.78156 .48265 .78414 .48595 .79007 .48417 .7875 .48086 Metetra
.664 .741 .908 r
.7875 .48086 .79007 .48417 .79602 .48238 .79346 .47907 Metetra
.663 .741 .908 r
.79346 .47907 .79602 .48238 .80198 .48059 .79943 .47727 Metetra
.663 .741 .908 r
.79943 .47727 .80198 .48059 .80796 .47879 .80541 .47547 Metetra
.663 .741 .908 r
.80541 .47547 .80796 .47879 .81394 .47699 .81141 .47366 Metetra
.663 .741 .908 r
.81141 .47366 .81394 .47699 .81994 .47519 .81742 .47185 Metetra
.663 .741 .908 r
.81742 .47185 .81994 .47519 .82595 .47339 .82344 .47004 Metetra
.663 .741 .908 r
.82344 .47004 .82595 .47339 .83198 .47158 .82947 .46823 Metetra
.663 .741 .908 r
.82947 .46823 .83198 .47158 .83802 .46977 .83552 .46641 Metetra
.663 .741 .908 r
.83552 .46641 .83802 .46977 .84407 .46796 .84157 .4646 Metetra
.663 .742 .909 r
.84157 .4646 .84407 .46796 .85013 .46614 .84765 .46278 Metetra
.663 .742 .909 r
.84765 .46278 .85013 .46614 .8562 .46433 .85373 .46096 Metetra
.662 .742 .909 r
.85373 .46096 .8562 .46433 .86229 .46251 .85983 .45914 Metetra
.662 .742 .909 r
.85983 .45914 .86229 .46251 .86839 .4607 .86594 .45733 Metetra
.661 .742 .91 r
.86594 .45733 .86839 .4607 .87451 .45889 .87207 .45551 Metetra
.661 .742 .91 r
.87207 .45551 .87451 .45889 .88064 .45708 .8782 .4537 Metetra
.66 .743 .911 r
.8782 .4537 .88064 .45708 .88678 .45527 .88436 .4519 Metetra
.66 .743 .912 r
.88436 .4519 .88678 .45527 .89294 .45347 .89052 .45011 Metetra
.659 .743 .912 r
.89052 .45011 .89294 .45347 .89911 .45168 .89671 .44832 Metetra
.657 .744 .914 r
.89671 .44832 .89911 .45168 .90529 .4499 .9029 .44655 Metetra
.656 .744 .915 r
.9029 .44655 .90529 .4499 .91149 .44813 .90912 .44479 Metetra
.655 .745 .916 r
.90912 .44479 .91149 .44813 .91771 .44637 .91535 .44305 Metetra
.653 .746 .918 r
.91535 .44305 .91771 .44637 .92394 .44464 .92159 .44133 Metetra
.651 .747 .919 r
.92159 .44133 .92394 .44464 .93019 .44292 .92785 .43963 Metetra
.649 .748 .921 r
.92785 .43963 .93019 .44292 .93646 .44122 .93413 .43795 Metetra
.648 .749 .923 r
.93413 .43795 .93646 .44122 .94274 .43954 .94043 .4363 Metetra
.646 .75 .925 r
.94043 .4363 .94274 .43954 .94904 .43788 .94675 .43466 Metetra
.644 .751 .927 r
.94675 .43466 .94904 .43788 .95536 .43624 .95308 .43304 Metetra
.642 .752 .929 r
.95308 .43304 .95536 .43624 .9617 .43462 .95943 .43144 Metetra
.641 .754 .931 r
.95943 .43144 .9617 .43462 .96805 .43302 .96579 .42985 Metetra
.701 .794 .923 r
.39568 .59969 .39881 .60193 .40402 .59984 .4009 .59758 Metetra
.701 .793 .922 r
.4009 .59758 .40402 .59984 .40923 .59777 .40612 .59546 Metetra
.699 .79 .921 r
.40612 .59546 .40923 .59777 .41445 .59572 .41135 .59336 Metetra
.697 .786 .92 r
.41135 .59336 .41445 .59572 .41968 .59372 .41659 .5913 Metetra
.694 .781 .918 r
.41659 .5913 .41968 .59372 .42492 .59177 .42183 .58927 Metetra
.69 .776 .917 r
.42183 .58927 .42492 .59177 .43016 .58987 .42709 .5873 Metetra
.686 .771 .916 r
.42709 .5873 .43016 .58987 .43541 .58801 .43235 .58538 Metetra
.683 .766 .914 r
.43235 .58538 .43541 .58801 .44067 .5862 .43761 .58351 Metetra
.679 .761 .913 r
.43761 .58351 .44067 .5862 .44594 .58443 .44289 .58169 Metetra
.676 .757 .912 r
.44289 .58169 .44594 .58443 .45121 .5827 .44817 .5799 Metetra
.674 .754 .911 r
.44817 .5799 .45121 .5827 .4565 .58099 .45347 .57816 Metetra
.671 .751 .91 r
.45347 .57816 .4565 .58099 .46179 .57931 .45877 .57644 Metetra
.67 .749 .91 r
.45877 .57644 .46179 .57931 .4671 .57764 .46408 .57475 Metetra
.668 .747 .909 r
.46408 .57475 .4671 .57764 .47241 .57598 .4694 .57307 Metetra
.667 .746 .909 r
.4694 .57307 .47241 .57598 .47774 .57434 .47474 .57141 Metetra
.666 .745 .909 r
.47474 .57141 .47774 .57434 .48307 .5727 .48008 .56975 Metetra
.666 .744 .909 r
.48008 .56975 .48307 .5727 .48842 .57107 .48543 .56811 Metetra
.665 .743 .908 r
.48543 .56811 .48842 .57107 .49378 .56944 .49079 .56646 Metetra
.665 .743 .908 r
.49079 .56646 .49378 .56944 .49914 .56781 .49617 .56483 Metetra
.664 .742 .908 r
.49617 .56483 .49914 .56781 .50452 .56618 .50155 .56319 Metetra
.664 .742 .908 r
.50155 .56319 .50452 .56618 .5099 .56455 .50694 .56155 Metetra
.664 .742 .908 r
.50694 .56155 .5099 .56455 .5153 .56292 .51235 .55991 Metetra
.664 .742 .908 r
.51235 .55991 .5153 .56292 .52071 .56128 .51776 .55827 Metetra
.664 .742 .908 r
.51776 .55827 .52071 .56128 .52613 .55965 .52319 .55663 Metetra
.664 .741 .908 r
.52319 .55663 .52613 .55965 .53156 .55801 .52863 .55498 Metetra
.664 .741 .908 r
.52863 .55498 .53156 .55801 .537 .55637 .53407 .55333 Metetra
.664 .741 .908 r
.53407 .55333 .537 .55637 .54245 .55472 .53953 .55168 Metetra
.664 .741 .908 r
.53953 .55168 .54245 .55472 .54791 .55308 .545 .55003 Metetra
.664 .741 .908 r
.545 .55003 .54791 .55308 .55339 .55143 .55048 .54837 Metetra
.664 .741 .908 r
.55048 .54837 .55339 .55143 .55887 .54977 .55597 .54671 Metetra
.664 .741 .908 r
.55597 .54671 .55887 .54977 .56436 .54812 .56147 .54505 Metetra
.664 .741 .908 r
.56147 .54505 .56436 .54812 .56987 .54646 .56699 .54339 Metetra
.664 .741 .908 r
.56699 .54339 .56987 .54646 .57539 .5448 .57251 .54172 Metetra
.664 .741 .908 r
.57251 .54172 .57539 .5448 .58091 .54313 .57804 .54004 Metetra
.664 .741 .908 r
.57804 .54004 .58091 .54313 .58645 .54146 .58359 .53837 Metetra
.664 .741 .908 r
.58359 .53837 .58645 .54146 .592 .53979 .58915 .53669 Metetra
.664 .741 .908 r
.58915 .53669 .592 .53979 .59756 .53811 .59471 .53501 Metetra
.664 .741 .908 r
.59471 .53501 .59756 .53811 .60313 .53643 .60029 .53332 Metetra
.664 .741 .908 r
.60029 .53332 .60313 .53643 .60872 .53475 .60588 .53163 Metetra
.664 .741 .908 r
.60588 .53163 .60872 .53475 .61431 .53306 .61148 .52994 Metetra
.664 .741 .908 r
.61148 .52994 .61431 .53306 .61991 .53137 .6171 .52825 Metetra
.664 .741 .908 r
.6171 .52825 .61991 .53137 .62553 .52968 .62272 .52655 Metetra
.664 .741 .908 r
.62272 .52655 .62553 .52968 .63116 .52798 .62836 .52484 Metetra
.664 .741 .908 r
.62836 .52484 .63116 .52798 .6368 .52628 .634 .52314 Metetra
.664 .741 .908 r
.634 .52314 .6368 .52628 .64245 .52458 .63966 .52143 Metetra
.664 .741 .908 r
.63966 .52143 .64245 .52458 .64811 .52288 .64533 .51972 Metetra
.664 .741 .908 r
.64533 .51972 .64811 .52288 .65378 .52117 .65101 .518 Metetra
.664 .741 .908 r
.65101 .518 .65378 .52117 .65947 .51945 .6567 .51628 Metetra
.664 .741 .908 r
.6567 .51628 .65947 .51945 .66516 .51773 .66241 .51456 Metetra
.664 .741 .908 r
.66241 .51456 .66516 .51773 .67087 .51601 .66812 .51283 Metetra
.664 .741 .908 r
.66812 .51283 .67087 .51601 .67659 .51429 .67385 .5111 Metetra
.664 .741 .908 r
.67385 .5111 .67659 .51429 .68232 .51256 .67959 .50937 Metetra
.664 .741 .908 r
.67959 .50937 .68232 .51256 .68806 .51083 .68534 .50763 Metetra
.664 .741 .908 r
.68534 .50763 .68806 .51083 .69382 .5091 .6911 .50589 Metetra
.664 .741 .908 r
.6911 .50589 .69382 .5091 .69958 .50736 .69688 .50414 Metetra
.664 .741 .908 r
.69688 .50414 .69958 .50736 .70536 .50562 .70266 .50239 Metetra
.664 .741 .908 r
.70266 .50239 .70536 .50562 .71115 .50387 .70846 .50064 Metetra
.664 .741 .908 r
.70846 .50064 .71115 .50387 .71695 .50213 .71427 .49889 Metetra
.664 .741 .908 r
.71427 .49889 .71695 .50213 .72276 .50037 .72009 .49713 Metetra
.664 .741 .908 r
.72009 .49713 .72276 .50037 .72859 .49862 .72592 .49537 Metetra
.664 .741 .908 r
.72592 .49537 .72859 .49862 .73443 .49686 .73177 .4936 Metetra
.664 .741 .908 r
.73177 .4936 .73443 .49686 .74028 .4951 .73763 .49183 Metetra
.664 .741 .908 r
.73763 .49183 .74028 .4951 .74614 .49333 .7435 .49006 Metetra
.664 .741 .908 r
.7435 .49006 .74614 .49333 .75201 .49156 .74938 .48828 Metetra
.664 .741 .908 r
.74938 .48828 .75201 .49156 .75789 .48979 .75527 .4865 Metetra
.664 .741 .908 r
.75527 .4865 .75789 .48979 .76379 .48801 .76118 .48472 Metetra
.664 .741 .908 r
.76118 .48472 .76379 .48801 .7697 .48623 .76709 .48293 Metetra
.664 .741 .908 r
.76709 .48293 .7697 .48623 .77562 .48444 .77302 .48114 Metetra
.664 .741 .908 r
.77302 .48114 .77562 .48444 .78156 .48265 .77897 .47934 Metetra
.664 .741 .908 r
.77897 .47934 .78156 .48265 .7875 .48086 .78492 .47754 Metetra
.663 .741 .908 r
.78492 .47754 .7875 .48086 .79346 .47907 .79089 .47574 Metetra
.663 .741 .908 r
.79089 .47574 .79346 .47907 .79943 .47727 .79687 .47394 Metetra
.663 .741 .908 r
.79687 .47394 .79943 .47727 .80541 .47547 .80286 .47213 Metetra
.663 .741 .908 r
.80286 .47213 .80541 .47547 .81141 .47366 .80886 .47032 Metetra
.663 .741 .908 r
.80886 .47032 .81141 .47366 .81742 .47185 .81488 .4685 Metetra
.663 .741 .908 r
.81488 .4685 .81742 .47185 .82344 .47004 .82091 .46669 Metetra
.663 .741 .908 r
.82091 .46669 .82344 .47004 .82947 .46823 .82695 .46487 Metetra
.663 .741 .908 r
.82695 .46487 .82947 .46823 .83552 .46641 .83301 .46305 Metetra
.663 .742 .909 r
.83301 .46305 .83552 .46641 .84157 .4646 .83907 .46123 Metetra
.663 .742 .909 r
.83907 .46123 .84157 .4646 .84765 .46278 .84516 .4594 Metetra
.662 .742 .909 r
.84516 .4594 .84765 .46278 .85373 .46096 .85125 .45758 Metetra
.662 .742 .909 r
.85125 .45758 .85373 .46096 .85983 .45914 .85736 .45576 Metetra
.662 .742 .91 r
.85736 .45576 .85983 .45914 .86594 .45733 .86348 .45395 Metetra
.661 .742 .91 r
.86348 .45395 .86594 .45733 .87207 .45551 .86961 .45213 Metetra
.66 .743 .911 r
.86961 .45213 .87207 .45551 .8782 .4537 .87576 .45033 Metetra
.66 .743 .912 r
.87576 .45033 .8782 .4537 .88436 .4519 .88193 .44853 Metetra
.659 .743 .912 r
.88193 .44853 .88436 .4519 .89052 .45011 .88811 .44674 Metetra
.657 .744 .914 r
.88811 .44674 .89052 .45011 .89671 .44832 .8943 .44497 Metetra
.656 .744 .915 r
.8943 .44497 .89671 .44832 .9029 .44655 .90051 .44321 Metetra
.655 .745 .916 r
.90051 .44321 .9029 .44655 .90912 .44479 .90673 .44147 Metetra
.653 .746 .918 r
.90673 .44147 .90912 .44479 .91535 .44305 .91298 .43974 Metetra
.651 .747 .92 r
.91298 .43974 .91535 .44305 .92159 .44133 .91924 .43804 Metetra
.649 .748 .921 r
.91924 .43804 .92159 .44133 .92785 .43963 .92551 .43636 Metetra
.647 .749 .923 r
.92551 .43636 .92785 .43963 .93413 .43795 .9318 .43471 Metetra
.645 .75 .925 r
.9318 .43471 .93413 .43795 .94043 .4363 .93812 .43308 Metetra
.643 .751 .928 r
.93812 .43308 .94043 .4363 .94675 .43466 .94444 .43146 Metetra
.641 .753 .929 r
.94444 .43146 .94675 .43466 .95308 .43304 .95079 .42987 Metetra
.64 .754 .931 r
.95079 .42987 .95308 .43304 .95943 .43144 .95715 .42828 Metetra
.639 .755 .932 r
.95715 .42828 .95943 .43144 .96579 .42985 .96353 .4267 Metetra
.7 .795 .924 r
.39254 .59745 .39568 .59969 .4009 .59758 .39777 .59535 Metetra
.702 .796 .923 r
.39777 .59535 .4009 .59758 .40612 .59546 .403 .59321 Metetra
.702 .795 .923 r
.403 .59321 .40612 .59546 .41135 .59336 .40824 .59107 Metetra
.701 .792 .921 r
.40824 .59107 .41135 .59336 .41659 .5913 .41348 .58894 Metetra
.698 .788 .92 r
.41348 .58894 .41659 .5913 .42183 .58927 .41874 .58685 Metetra
.695 .783 .919 r
.41874 .58685 .42183 .58927 .42709 .5873 .424 .5848 Metetra
.691 .777 .917 r
.424 .5848 .42709 .5873 .43235 .58538 .42927 .5828 Metetra
.687 .771 .916 r
.42927 .5828 .43235 .58538 .43761 .58351 .43455 .58087 Metetra
.683 .766 .914 r
.43455 .58087 .43761 .58351 .44289 .58169 .43983 .57898 Metetra
.679 .762 .913 r
.43983 .57898 .44289 .58169 .44817 .5799 .44512 .57714 Metetra
.676 .757 .912 r
.44512 .57714 .44817 .5799 .45347 .57816 .45042 .57535 Metetra
.674 .754 .911 r
.45042 .57535 .45347 .57816 .45877 .57644 .45573 .57359 Metetra
.671 .751 .91 r
.45573 .57359 .45877 .57644 .46408 .57475 .46105 .57187 Metetra
.67 .749 .91 r
.46105 .57187 .46408 .57475 .4694 .57307 .46638 .57016 Metetra
.668 .747 .909 r
.46638 .57016 .4694 .57307 .47474 .57141 .47172 .56848 Metetra
.667 .746 .909 r
.47172 .56848 .47474 .57141 .48008 .56975 .47707 .56681 Metetra
.666 .745 .909 r
.47707 .56681 .48008 .56975 .48543 .56811 .48243 .56514 Metetra
.666 .744 .909 r
.48243 .56514 .48543 .56811 .49079 .56646 .4878 .56349 Metetra
.665 .743 .908 r
.4878 .56349 .49079 .56646 .49617 .56483 .49318 .56184 Metetra
.665 .743 .908 r
.49318 .56184 .49617 .56483 .50155 .56319 .49857 .56019 Metetra
.664 .742 .908 r
.49857 .56019 .50155 .56319 .50694 .56155 .50397 .55854 Metetra
.664 .742 .908 r
.50397 .55854 .50694 .56155 .51235 .55991 .50938 .55689 Metetra
.664 .742 .908 r
.50938 .55689 .51235 .55991 .51776 .55827 .5148 .55524 Metetra
.664 .742 .908 r
.5148 .55524 .51776 .55827 .52319 .55663 .52024 .55359 Metetra
.664 .742 .908 r
.52024 .55359 .52319 .55663 .52863 .55498 .52568 .55194 Metetra
.664 .741 .908 r
.52568 .55194 .52863 .55498 .53407 .55333 .53114 .55029 Metetra
.664 .741 .908 r
.53114 .55029 .53407 .55333 .53953 .55168 .5366 .54863 Metetra
.664 .741 .908 r
.5366 .54863 .53953 .55168 .545 .55003 .54208 .54697 Metetra
.664 .741 .908 r
.54208 .54697 .545 .55003 .55048 .54837 .54756 .54531 Metetra
.664 .741 .908 r
.54756 .54531 .55048 .54837 .55597 .54671 .55306 .54364 Metetra
.664 .741 .908 r
.55306 .54364 .55597 .54671 .56147 .54505 .55857 .54197 Metetra
.664 .741 .908 r
.55857 .54197 .56147 .54505 .56699 .54339 .56409 .5403 Metetra
.664 .741 .908 r
.56409 .5403 .56699 .54339 .57251 .54172 .56962 .53863 Metetra
.664 .741 .908 r
.56962 .53863 .57251 .54172 .57804 .54004 .57516 .53695 Metetra
.664 .741 .908 r
.57516 .53695 .57804 .54004 .58359 .53837 .58072 .53527 Metetra
.664 .741 .908 r
.58072 .53527 .58359 .53837 .58915 .53669 .58628 .53358 Metetra
.664 .741 .908 r
.58628 .53358 .58915 .53669 .59471 .53501 .59186 .53189 Metetra
.664 .741 .908 r
.59186 .53189 .59471 .53501 .60029 .53332 .59744 .5302 Metetra
.664 .741 .908 r
.59744 .5302 .60029 .53332 .60588 .53163 .60304 .52851 Metetra
.664 .741 .908 r
.60304 .52851 .60588 .53163 .61148 .52994 .60865 .52681 Metetra
.664 .741 .908 r
.60865 .52681 .61148 .52994 .6171 .52825 .61427 .52511 Metetra
.664 .741 .908 r
.61427 .52511 .6171 .52825 .62272 .52655 .6199 .5234 Metetra
.664 .741 .908 r
.6199 .5234 .62272 .52655 .62836 .52484 .62554 .52169 Metetra
.664 .741 .908 r
.62554 .52169 .62836 .52484 .634 .52314 .6312 .51998 Metetra
.664 .741 .908 r
.6312 .51998 .634 .52314 .63966 .52143 .63686 .51826 Metetra
.664 .741 .908 r
.63686 .51826 .63966 .52143 .64533 .51972 .64254 .51654 Metetra
.664 .741 .908 r
.64254 .51654 .64533 .51972 .65101 .518 .64823 .51482 Metetra
.664 .741 .908 r
.64823 .51482 .65101 .518 .6567 .51628 .65393 .5131 Metetra
.664 .741 .908 r
.65393 .5131 .6567 .51628 .66241 .51456 .65964 .51137 Metetra
.664 .741 .908 r
.65964 .51137 .66241 .51456 .66812 .51283 .66537 .50963 Metetra
.664 .741 .908 r
.66537 .50963 .66812 .51283 .67385 .5111 .6711 .5079 Metetra
.664 .741 .908 r
.6711 .5079 .67385 .5111 .67959 .50937 .67685 .50615 Metetra
.664 .741 .908 r
.67685 .50615 .67959 .50937 .68534 .50763 .68261 .50441 Metetra
.664 .741 .908 r
.68261 .50441 .68534 .50763 .6911 .50589 .68838 .50266 Metetra
.664 .741 .908 r
.68838 .50266 .6911 .50589 .69688 .50414 .69416 .50091 Metetra
.664 .741 .908 r
.69416 .50091 .69688 .50414 .70266 .50239 .69995 .49916 Metetra
.664 .741 .908 r
.69995 .49916 .70266 .50239 .70846 .50064 .70576 .4974 Metetra
.664 .741 .908 r
.70576 .4974 .70846 .50064 .71427 .49889 .71158 .49564 Metetra
.664 .741 .908 r
.71158 .49564 .71427 .49889 .72009 .49713 .71741 .49387 Metetra
.664 .741 .908 r
.71741 .49387 .72009 .49713 .72592 .49537 .72325 .4921 Metetra
.664 .741 .908 r
.72325 .4921 .72592 .49537 .73177 .4936 .7291 .49033 Metetra
.664 .741 .908 r
.7291 .49033 .73177 .4936 .73763 .49183 .73497 .48855 Metetra
.664 .741 .908 r
.73497 .48855 .73763 .49183 .7435 .49006 .74084 .48677 Metetra
.664 .741 .908 r
.74084 .48677 .7435 .49006 .74938 .48828 .74673 .48499 Metetra
.664 .741 .908 r
.74673 .48499 .74938 .48828 .75527 .4865 .75264 .4832 Metetra
.664 .741 .908 r
.75264 .4832 .75527 .4865 .76118 .48472 .75855 .48141 Metetra
.664 .741 .908 r
.75855 .48141 .76118 .48472 .76709 .48293 .76448 .47962 Metetra
.664 .741 .908 r
.76448 .47962 .76709 .48293 .77302 .48114 .77041 .47782 Metetra
.664 .741 .908 r
.77041 .47782 .77302 .48114 .77897 .47934 .77637 .47602 Metetra
.663 .741 .908 r
.77637 .47602 .77897 .47934 .78492 .47754 .78233 .47421 Metetra
.663 .741 .908 r
.78233 .47421 .78492 .47754 .79089 .47574 .7883 .47241 Metetra
.663 .741 .908 r
.7883 .47241 .79089 .47574 .79687 .47394 .79429 .47059 Metetra
.663 .741 .908 r
.79429 .47059 .79687 .47394 .80286 .47213 .80029 .46878 Metetra
.663 .741 .908 r
.80029 .46878 .80286 .47213 .80886 .47032 .80631 .46696 Metetra
.663 .741 .908 r
.80631 .46696 .80886 .47032 .81488 .4685 .81233 .46514 Metetra
.663 .741 .908 r
.81233 .46514 .81488 .4685 .82091 .46669 .81837 .46332 Metetra
.663 .741 .908 r
.81837 .46332 .82091 .46669 .82695 .46487 .82442 .4615 Metetra
.663 .742 .909 r
.82442 .4615 .82695 .46487 .83301 .46305 .83049 .45967 Metetra
.663 .742 .909 r
.83049 .45967 .83301 .46305 .83907 .46123 .83656 .45785 Metetra
.662 .742 .909 r
.83656 .45785 .83907 .46123 .84516 .4594 .84266 .45602 Metetra
.662 .742 .909 r
.84266 .45602 .84516 .4594 .85125 .45758 .84876 .4542 Metetra
.662 .742 .91 r
.84876 .4542 .85125 .45758 .85736 .45576 .85488 .45238 Metetra
.661 .742 .91 r
.85488 .45238 .85736 .45576 .86348 .45395 .86101 .45056 Metetra
.66 .742 .911 r
.86101 .45056 .86348 .45395 .86961 .45213 .86715 .44875 Metetra
.659 .743 .912 r
.86715 .44875 .86961 .45213 .87576 .45033 .87331 .44695 Metetra
.659 .743 .913 r
.87331 .44695 .87576 .45033 .88193 .44853 .87949 .44516 Metetra
.657 .744 .914 r
.87949 .44516 .88193 .44853 .88811 .44674 .88568 .44338 Metetra
.656 .744 .915 r
.88568 .44338 .88811 .44674 .8943 .44497 .89188 .44162 Metetra
.655 .745 .916 r
.89188 .44162 .8943 .44497 .90051 .44321 .89811 .43988 Metetra
.653 .746 .918 r
.89811 .43988 .90051 .44321 .90673 .44147 .90434 .43815 Metetra
.651 .747 .92 r
.90434 .43815 .90673 .44147 .91298 .43974 .9106 .43645 Metetra
.649 .748 .922 r
.9106 .43645 .91298 .43974 .91924 .43804 .91687 .43477 Metetra
.647 .749 .924 r
.91687 .43477 .91924 .43804 .92551 .43636 .92316 .43312 Metetra
.645 .75 .926 r
.92316 .43312 .92551 .43636 .9318 .43471 .92947 .43149 Metetra
.643 .751 .928 r
.92947 .43149 .9318 .43471 .93812 .43308 .93579 .42988 Metetra
.641 .753 .93 r
.93579 .42988 .93812 .43308 .94444 .43146 .94214 .42829 Metetra
.639 .754 .932 r
.94214 .42829 .94444 .43146 .95079 .42987 .9485 .42671 Metetra
.638 .756 .933 r
.9485 .42671 .95079 .42987 .95715 .42828 .95487 .42513 Metetra
.638 .757 .934 r
.95487 .42513 .95715 .42828 .96353 .4267 .96126 .42356 Metetra
.697 .793 .925 r
.38939 .59519 .39254 .59745 .39777 .59535 .39462 .59312 Metetra
.701 .797 .925 r
.39462 .59312 .39777 .59535 .403 .59321 .39986 .59099 Metetra
.703 .798 .924 r
.39986 .59099 .403 .59321 .40824 .59107 .40511 .58882 Metetra
.703 .797 .923 r
.40511 .58882 .40824 .59107 .41348 .58894 .41036 .58665 Metetra
.702 .794 .922 r
.41036 .58665 .41348 .58894 .41874 .58685 .41563 .58449 Metetra
.699 .789 .92 r
.41563 .58449 .41874 .58685 .424 .5848 .4209 .58237 Metetra
.696 .784 .919 r
.4209 .58237 .424 .5848 .42927 .5828 .42618 .5803 Metetra
.692 .778 .917 r
.42618 .5803 .42927 .5828 .43455 .58087 .43146 .57829 Metetra
.687 .772 .916 r
.43146 .57829 .43455 .58087 .43983 .57898 .43676 .57633 Metetra
.683 .767 .915 r
.43676 .57633 .43983 .57898 .44512 .57714 .44206 .57443 Metetra
.68 .762 .913 r
.44206 .57443 .44512 .57714 .45042 .57535 .44737 .57258 Metetra
.677 .758 .912 r
.44737 .57258 .45042 .57535 .45573 .57359 .45269 .57077 Metetra
.674 .754 .911 r
.45269 .57077 .45573 .57359 .46105 .57187 .45801 .569 Metetra
.672 .751 .91 r
.45801 .569 .46105 .57187 .46638 .57016 .46335 .56727 Metetra
.67 .749 .91 r
.46335 .56727 .46638 .57016 .47172 .56848 .4687 .56555 Metetra
.668 .747 .909 r
.4687 .56555 .47172 .56848 .47707 .56681 .47405 .56386 Metetra
.667 .746 .909 r
.47405 .56386 .47707 .56681 .48243 .56514 .47942 .56218 Metetra
.666 .745 .909 r
.47942 .56218 .48243 .56514 .4878 .56349 .4848 .56051 Metetra
.666 .744 .909 r
.4848 .56051 .4878 .56349 .49318 .56184 .49018 .55884 Metetra
.665 .743 .908 r
.49018 .55884 .49318 .56184 .49857 .56019 .49558 .55718 Metetra
.665 .743 .908 r
.49558 .55718 .49857 .56019 .50397 .55854 .50099 .55552 Metetra
.664 .742 .908 r
.50099 .55552 .50397 .55854 .50938 .55689 .50641 .55387 Metetra
.664 .742 .908 r
.50641 .55387 .50938 .55689 .5148 .55524 .51184 .55221 Metetra
.664 .742 .908 r
.51184 .55221 .5148 .55524 .52024 .55359 .51728 .55055 Metetra
.664 .742 .908 r
.51728 .55055 .52024 .55359 .52568 .55194 .52273 .54889 Metetra
.664 .742 .908 r
.52273 .54889 .52568 .55194 .53114 .55029 .52819 .54723 Metetra
.664 .741 .908 r
.52819 .54723 .53114 .55029 .5366 .54863 .53366 .54557 Metetra
.664 .741 .908 r
.53366 .54557 .5366 .54863 .54208 .54697 .53914 .5439 Metetra
.664 .741 .908 r
.53914 .5439 .54208 .54697 .54756 .54531 .54464 .54223 Metetra
.664 .741 .908 r
.54464 .54223 .54756 .54531 .55306 .54364 .55014 .54056 Metetra
.664 .741 .908 r
.55014 .54056 .55306 .54364 .55857 .54197 .55566 .53889 Metetra
.664 .741 .908 r
.55566 .53889 .55857 .54197 .56409 .5403 .56119 .53721 Metetra
.664 .741 .908 r
.56119 .53721 .56409 .5403 .56962 .53863 .56672 .53553 Metetra
.664 .741 .908 r
.56672 .53553 .56962 .53863 .57516 .53695 .57227 .53384 Metetra
.664 .741 .908 r
.57227 .53384 .57516 .53695 .58072 .53527 .57783 .53215 Metetra
.664 .741 .908 r
.57783 .53215 .58072 .53527 .58628 .53358 .58341 .53046 Metetra
.664 .741 .908 r
.58341 .53046 .58628 .53358 .59186 .53189 .58899 .52877 Metetra
.664 .741 .908 r
.58899 .52877 .59186 .53189 .59744 .5302 .59458 .52707 Metetra
.664 .741 .908 r
.59458 .52707 .59744 .5302 .60304 .52851 .60019 .52537 Metetra
.664 .741 .908 r
.60019 .52537 .60304 .52851 .60865 .52681 .6058 .52366 Metetra
.664 .741 .908 r
.6058 .52366 .60865 .52681 .61427 .52511 .61143 .52195 Metetra
.664 .741 .908 r
.61143 .52195 .61427 .52511 .6199 .5234 .61707 .52024 Metetra
.664 .741 .908 r
.61707 .52024 .6199 .5234 .62554 .52169 .62272 .51853 Metetra
.664 .741 .908 r
.62272 .51853 .62554 .52169 .6312 .51998 .62838 .51681 Metetra
.664 .741 .908 r
.62838 .51681 .6312 .51998 .63686 .51826 .63406 .51509 Metetra
.664 .741 .908 r
.63406 .51509 .63686 .51826 .64254 .51654 .63974 .51336 Metetra
.664 .741 .908 r
.63974 .51336 .64254 .51654 .64823 .51482 .64544 .51163 Metetra
.664 .741 .908 r
.64544 .51163 .64823 .51482 .65393 .5131 .65115 .5099 Metetra
.664 .741 .908 r
.65115 .5099 .65393 .5131 .65964 .51137 .65687 .50816 Metetra
.664 .741 .908 r
.65687 .50816 .65964 .51137 .66537 .50963 .6626 .50642 Metetra
.664 .741 .908 r
.6626 .50642 .66537 .50963 .6711 .5079 .66834 .50468 Metetra
.664 .741 .908 r
.66834 .50468 .6711 .5079 .67685 .50615 .6741 .50293 Metetra
.664 .741 .908 r
.6741 .50293 .67685 .50615 .68261 .50441 .67986 .50118 Metetra
.664 .741 .908 r
.67986 .50118 .68261 .50441 .68838 .50266 .68564 .49943 Metetra
.664 .741 .908 r
.68564 .49943 .68838 .50266 .69416 .50091 .69143 .49767 Metetra
.664 .741 .908 r
.69143 .49767 .69416 .50091 .69995 .49916 .69723 .49591 Metetra
.664 .741 .908 r
.69723 .49591 .69995 .49916 .70576 .4974 .70305 .49414 Metetra
.664 .741 .908 r
.70305 .49414 .70576 .4974 .71158 .49564 .70887 .49238 Metetra
.664 .741 .908 r
.70887 .49238 .71158 .49564 .71741 .49387 .71471 .4906 Metetra
.664 .741 .908 r
.71471 .4906 .71741 .49387 .72325 .4921 .72056 .48883 Metetra
.664 .741 .908 r
.72056 .48883 .72325 .4921 .7291 .49033 .72642 .48705 Metetra
.664 .741 .908 r
.72642 .48705 .7291 .49033 .73497 .48855 .7323 .48527 Metetra
.664 .741 .908 r
.7323 .48527 .73497 .48855 .74084 .48677 .73818 .48348 Metetra
.664 .741 .908 r
.73818 .48348 .74084 .48677 .74673 .48499 .74408 .48169 Metetra
.664 .741 .908 r
.74408 .48169 .74673 .48499 .75264 .4832 .74999 .4799 Metetra
.664 .741 .908 r
.74999 .4799 .75264 .4832 .75855 .48141 .75591 .4781 Metetra
.664 .741 .908 r
.75591 .4781 .75855 .48141 .76448 .47962 .76185 .4763 Metetra
.664 .741 .908 r
.76185 .4763 .76448 .47962 .77041 .47782 .7678 .47449 Metetra
.663 .741 .908 r
.7678 .47449 .77041 .47782 .77637 .47602 .77376 .47268 Metetra
.663 .741 .908 r
.77376 .47268 .77637 .47602 .78233 .47421 .77973 .47087 Metetra
.663 .741 .908 r
.77973 .47087 .78233 .47421 .7883 .47241 .78571 .46906 Metetra
.663 .741 .908 r
.78571 .46906 .7883 .47241 .79429 .47059 .79171 .46724 Metetra
.663 .741 .908 r
.79171 .46724 .79429 .47059 .80029 .46878 .79772 .46542 Metetra
.663 .741 .908 r
.79772 .46542 .80029 .46878 .80631 .46696 .80374 .4636 Metetra
.663 .741 .908 r
.80374 .4636 .80631 .46696 .81233 .46514 .80978 .46177 Metetra
.663 .741 .908 r
.80978 .46177 .81233 .46514 .81837 .46332 .81582 .45994 Metetra
.663 .742 .909 r
.81582 .45994 .81837 .46332 .82442 .4615 .82188 .45811 Metetra
.663 .742 .909 r
.82188 .45811 .82442 .4615 .83049 .45967 .82796 .45629 Metetra
.662 .742 .909 r
.82796 .45629 .83049 .45967 .83656 .45785 .83405 .45446 Metetra
.662 .742 .909 r
.83405 .45446 .83656 .45785 .84266 .45602 .84015 .45263 Metetra
.662 .742 .91 r
.84015 .45263 .84266 .45602 .84876 .4542 .84626 .45081 Metetra
.661 .742 .91 r
.84626 .45081 .84876 .4542 .85488 .45238 .85239 .44899 Metetra
.66 .742 .911 r
.85239 .44899 .85488 .45238 .86101 .45056 .85853 .44718 Metetra
.659 .743 .912 r
.85853 .44718 .86101 .45056 .86715 .44875 .86469 .44537 Metetra
.659 .743 .913 r
.86469 .44537 .86715 .44875 .87331 .44695 .87086 .44358 Metetra
.657 .744 .914 r
.87086 .44358 .87331 .44695 .87949 .44516 .87704 .4418 Metetra
.656 .744 .915 r
.87704 .4418 .87949 .44516 .88568 .44338 .88325 .44003 Metetra
.654 .745 .916 r
.88325 .44003 .88568 .44338 .89188 .44162 .88946 .43829 Metetra
.653 .746 .918 r
.88946 .43829 .89188 .44162 .89811 .43988 .8957 .43656 Metetra
.651 .747 .92 r
.8957 .43656 .89811 .43988 .90434 .43815 .90195 .43486 Metetra
.649 .748 .922 r
.90195 .43486 .90434 .43815 .9106 .43645 .90822 .43318 Metetra
.647 .749 .924 r
.90822 .43318 .9106 .43645 .91687 .43477 .9145 .43153 Metetra
.644 .75 .926 r
.9145 .43153 .91687 .43477 .92316 .43312 .92081 .4299 Metetra
.642 .752 .928 r
.92081 .4299 .92316 .43312 .92947 .43149 .92713 .42829 Metetra
.64 .753 .931 r
.92713 .42829 .92947 .43149 .93579 .42988 .93347 .42671 Metetra
.639 .755 .932 r
.93347 .42671 .93579 .42988 .94214 .42829 .93983 .42513 Metetra
.638 .756 .934 r
.93983 .42513 .94214 .42829 .9485 .42671 .9462 .42357 Metetra
.637 .757 .935 r
.9462 .42357 .9485 .42671 .95487 .42513 .95259 .422 Metetra
.638 .758 .935 r
.95259 .422 .95487 .42513 .96126 .42356 .95899 .42041 Metetra
.691 .788 .925 r
.38623 .59286 .38939 .59519 .39462 .59312 .39146 .59086 Metetra
.698 .795 .925 r
.39146 .59086 .39462 .59312 .39986 .59099 .39671 .58877 Metetra
.702 .799 .925 r
.39671 .58877 .39986 .59099 .40511 .58882 .40196 .58662 Metetra
.705 .801 .925 r
.40196 .58662 .40511 .58882 .41036 .58665 .40723 .58442 Metetra
.705 .799 .924 r
.40723 .58442 .41036 .58665 .41563 .58449 .4125 .58221 Metetra
.703 .796 .922 r
.4125 .58221 .41563 .58449 .4209 .58237 .41778 .58003 Metetra
.7 .791 .921 r
.41778 .58003 .4209 .58237 .42618 .5803 .42307 .57788 Metetra
.697 .785 .919 r
.42307 .57788 .42618 .5803 .43146 .57829 .42837 .57578 Metetra
.692 .779 .918 r
.42837 .57578 .43146 .57829 .43676 .57633 .43367 .57375 Metetra
.688 .773 .916 r
.43367 .57375 .43676 .57633 .44206 .57443 .43898 .57177 Metetra
.684 .767 .915 r
.43898 .57177 .44206 .57443 .44737 .57258 .4443 .56985 Metetra
.68 .762 .913 r
.4443 .56985 .44737 .57258 .45269 .57077 .44963 .56799 Metetra
.677 .758 .912 r
.44963 .56799 .45269 .57077 .45801 .569 .45496 .56617 Metetra
.674 .754 .911 r
.45496 .56617 .45801 .569 .46335 .56727 .46031 .56439 Metetra
.672 .751 .91 r
.46031 .56439 .46335 .56727 .4687 .56555 .46566 .56264 Metetra
.67 .749 .91 r
.46566 .56264 .4687 .56555 .47405 .56386 .47102 .56092 Metetra
.668 .747 .909 r
.47102 .56092 .47405 .56386 .47942 .56218 .4764 .55921 Metetra
.667 .746 .909 r
.4764 .55921 .47942 .56218 .4848 .56051 .48178 .55752 Metetra
.666 .745 .909 r
.48178 .55752 .4848 .56051 .49018 .55884 .48717 .55584 Metetra
.666 .744 .909 r
.48717 .55584 .49018 .55884 .49558 .55718 .49258 .55417 Metetra
.665 .743 .908 r
.49258 .55417 .49558 .55718 .50099 .55552 .49799 .5525 Metetra
.665 .743 .908 r
.49799 .5525 .50099 .55552 .50641 .55387 .50342 .55083 Metetra
.664 .742 .908 r
.50342 .55083 .50641 .55387 .51184 .55221 .50886 .54917 Metetra
.664 .742 .908 r
.50886 .54917 .51184 .55221 .51728 .55055 .5143 .5475 Metetra
.664 .742 .908 r
.5143 .5475 .51728 .55055 .52273 .54889 .51976 .54583 Metetra
.664 .742 .908 r
.51976 .54583 .52273 .54889 .52819 .54723 .52523 .54417 Metetra
.664 .742 .908 r
.52523 .54417 .52819 .54723 .53366 .54557 .53071 .54249 Metetra
.664 .741 .908 r
.53071 .54249 .53366 .54557 .53914 .5439 .5362 .54082 Metetra
.664 .741 .908 r
.5362 .54082 .53914 .5439 .54464 .54223 .5417 .53915 Metetra
.664 .741 .908 r
.5417 .53915 .54464 .54223 .55014 .54056 .54721 .53747 Metetra
.664 .741 .908 r
.54721 .53747 .55014 .54056 .55566 .53889 .55274 .53579 Metetra
.664 .741 .908 r
.55274 .53579 .55566 .53889 .56119 .53721 .55827 .5341 Metetra
.664 .741 .908 r
.55827 .5341 .56119 .53721 .56672 .53553 .56382 .53241 Metetra
.664 .741 .908 r
.56382 .53241 .56672 .53553 .57227 .53384 .56937 .53072 Metetra
.664 .741 .908 r
.56937 .53072 .57227 .53384 .57783 .53215 .57494 .52903 Metetra
.664 .741 .908 r
.57494 .52903 .57783 .53215 .58341 .53046 .58052 .52733 Metetra
.664 .741 .908 r
.58052 .52733 .58341 .53046 .58899 .52877 .58611 .52563 Metetra
.664 .741 .908 r
.58611 .52563 .58899 .52877 .59458 .52707 .59171 .52393 Metetra
.664 .741 .908 r
.59171 .52393 .59458 .52707 .60019 .52537 .59732 .52222 Metetra
.664 .741 .908 r
.59732 .52222 .60019 .52537 .6058 .52366 .60295 .52051 Metetra
.664 .741 .908 r
.60295 .52051 .6058 .52366 .61143 .52195 .60858 .51879 Metetra
.664 .741 .908 r
.60858 .51879 .61143 .52195 .61707 .52024 .61423 .51707 Metetra
.664 .741 .908 r
.61423 .51707 .61707 .52024 .62272 .51853 .61989 .51535 Metetra
.664 .741 .908 r
.61989 .51535 .62272 .51853 .62838 .51681 .62556 .51363 Metetra
.664 .741 .908 r
.62556 .51363 .62838 .51681 .63406 .51509 .63124 .5119 Metetra
.664 .741 .908 r
.63124 .5119 .63406 .51509 .63974 .51336 .63693 .51017 Metetra
.664 .741 .908 r
.63693 .51017 .63974 .51336 .64544 .51163 .64264 .50843 Metetra
.664 .741 .908 r
.64264 .50843 .64544 .51163 .65115 .5099 .64835 .50669 Metetra
.664 .741 .908 r
.64835 .50669 .65115 .5099 .65687 .50816 .65408 .50495 Metetra
.664 .741 .908 r
.65408 .50495 .65687 .50816 .6626 .50642 .65982 .5032 Metetra
.664 .741 .908 r
.65982 .5032 .6626 .50642 .66834 .50468 .66557 .50145 Metetra
.664 .741 .908 r
.66557 .50145 .66834 .50468 .6741 .50293 .67133 .4997 Metetra
.664 .741 .908 r
.67133 .4997 .6741 .50293 .67986 .50118 .67711 .49794 Metetra
.664 .741 .908 r
.67711 .49794 .67986 .50118 .68564 .49943 .6829 .49618 Metetra
.664 .741 .908 r
.6829 .49618 .68564 .49943 .69143 .49767 .68869 .49442 Metetra
.664 .741 .908 r
.68869 .49442 .69143 .49767 .69723 .49591 .6945 .49265 Metetra
.664 .741 .908 r
.6945 .49265 .69723 .49591 .70305 .49414 .70033 .49088 Metetra
.664 .741 .908 r
.70033 .49088 .70305 .49414 .70887 .49238 .70616 .4891 Metetra
.664 .741 .908 r
.70616 .4891 .70887 .49238 .71471 .4906 .71201 .48732 Metetra
.664 .741 .908 r
.71201 .48732 .71471 .4906 .72056 .48883 .71786 .48554 Metetra
.664 .741 .908 r
.71786 .48554 .72056 .48883 .72642 .48705 .72373 .48375 Metetra
.664 .741 .908 r
.72373 .48375 .72642 .48705 .7323 .48527 .72962 .48196 Metetra
.664 .741 .908 r
.72962 .48196 .7323 .48527 .73818 .48348 .73551 .48017 Metetra
.664 .741 .908 r
.73551 .48017 .73818 .48348 .74408 .48169 .74142 .47837 Metetra
.664 .741 .908 r
.74142 .47837 .74408 .48169 .74999 .4799 .74734 .47657 Metetra
.664 .741 .908 r
.74734 .47657 .74999 .4799 .75591 .4781 .75327 .47477 Metetra
.664 .741 .908 r
.75327 .47477 .75591 .4781 .76185 .4763 .75921 .47296 Metetra
.663 .741 .908 r
.75921 .47296 .76185 .4763 .7678 .47449 .76517 .47115 Metetra
.663 .741 .908 r
.76517 .47115 .7678 .47449 .77376 .47268 .77114 .46934 Metetra
.663 .741 .908 r
.77114 .46934 .77376 .47268 .77973 .47087 .77712 .46752 Metetra
.663 .741 .908 r
.77712 .46752 .77973 .47087 .78571 .46906 .78311 .4657 Metetra
.663 .741 .908 r
.78311 .4657 .78571 .46906 .79171 .46724 .78912 .46387 Metetra
.663 .741 .908 r
.78912 .46387 .79171 .46724 .79772 .46542 .79513 .46205 Metetra
.663 .741 .908 r
.79513 .46205 .79772 .46542 .80374 .4636 .80117 .46022 Metetra
.663 .741 .908 r
.80117 .46022 .80374 .4636 .80978 .46177 .80721 .45839 Metetra
.663 .742 .909 r
.80721 .45839 .80978 .46177 .81582 .45994 .81327 .45655 Metetra
.663 .742 .909 r
.81327 .45655 .81582 .45994 .82188 .45811 .81934 .45472 Metetra
.662 .742 .909 r
.81934 .45472 .82188 .45811 .82796 .45629 .82542 .45289 Metetra
.662 .742 .909 r
.82542 .45289 .82796 .45629 .83405 .45446 .83152 .45106 Metetra
.662 .742 .91 r
.83152 .45106 .83405 .45446 .84015 .45263 .83763 .44923 Metetra
.661 .742 .91 r
.83763 .44923 .84015 .45263 .84626 .45081 .84375 .44741 Metetra
.66 .742 .911 r
.84375 .44741 .84626 .45081 .85239 .44899 .84989 .4456 Metetra
.659 .743 .912 r
.84989 .4456 .85239 .44899 .85853 .44718 .85604 .44379 Metetra
.659 .743 .913 r
.85604 .44379 .85853 .44718 .86469 .44537 .86221 .44199 Metetra
.657 .744 .914 r
.86221 .44199 .86469 .44537 .87086 .44358 .86839 .44021 Metetra
.656 .744 .915 r
.86839 .44021 .87086 .44358 .87704 .4418 .87459 .43844 Metetra
.654 .745 .916 r
.87459 .43844 .87704 .4418 .88325 .44003 .8808 .43669 Metetra
.653 .746 .918 r
.8808 .43669 .88325 .44003 .88946 .43829 .88703 .43497 Metetra
.651 .747 .92 r
.88703 .43497 .88946 .43829 .8957 .43656 .89328 .43326 Metetra
.648 .748 .922 r
.89328 .43326 .8957 .43656 .90195 .43486 .89955 .43159 Metetra
.646 .749 .924 r
.89955 .43159 .90195 .43486 .90822 .43318 .90583 .42993 Metetra
.644 .751 .927 r
.90583 .42993 .90822 .43318 .9145 .43153 .91213 .42831 Metetra
.642 .752 .929 r
.91213 .42831 .9145 .43153 .92081 .4299 .91845 .42671 Metetra
.639 .753 .931 r
.91845 .42671 .92081 .4299 .92713 .42829 .92479 .42513 Metetra
.638 .755 .933 r
.92479 .42513 .92713 .42829 .93347 .42671 .93114 .42356 Metetra
.637 .756 .935 r
.93114 .42356 .93347 .42671 .93983 .42513 .93751 .422 Metetra
.636 .758 .936 r
.93751 .422 .93983 .42513 .9462 .42357 .94389 .42043 Metetra
.637 .759 .936 r
.94389 .42043 .9462 .42357 .95259 .422 .95029 .41886 Metetra
.639 .759 .936 r
.95029 .41886 .95259 .422 .95899 .42041 .9567 .41725 Metetra
.683 .779 .924 r
.38306 .59041 .38623 .59286 .39146 .59086 .3883 .58853 Metetra
.692 .789 .925 r
.3883 .58853 .39146 .59086 .39671 .58877 .39354 .58653 Metetra
.699 .797 .926 r
.39354 .58653 .39671 .58877 .40196 .58662 .39881 .58441 Metetra
.704 .801 .926 r
.39881 .58441 .40196 .58662 .40723 .58442 .40408 .58222 Metetra
.706 .803 .925 r
.40408 .58222 .40723 .58442 .4125 .58221 .40936 .57999 Metetra
.706 .802 .924 r
.40936 .57999 .4125 .58221 .41778 .58003 .41465 .57776 Metetra
.705 .798 .923 r
.41465 .57776 .41778 .58003 .42307 .57788 .41995 .57554 Metetra
.702 .793 .921 r
.41995 .57554 .42307 .57788 .42837 .57578 .42526 .57336 Metetra
.698 .787 .92 r
.42526 .57336 .42837 .57578 .43367 .57375 .43057 .57124 Metetra
.693 .78 .918 r
.43057 .57124 .43367 .57375 .43898 .57177 .43589 .56918 Metetra
.689 .774 .916 r
.43589 .56918 .43898 .57177 .4443 .56985 .44122 .56718 Metetra
.684 .768 .915 r
.44122 .56718 .4443 .56985 .44963 .56799 .44655 .56525 Metetra
.68 .763 .913 r
.44655 .56525 .44963 .56799 .45496 .56617 .4519 .56337 Metetra
.677 .758 .912 r
.4519 .56337 .45496 .56617 .46031 .56439 .45725 .56154 Metetra
.674 .755 .911 r
.45725 .56154 .46031 .56439 .46566 .56264 .46261 .55975 Metetra
.672 .751 .911 r
.46261 .55975 .46566 .56264 .47102 .56092 .46798 .55799 Metetra
.67 .749 .91 r
.46798 .55799 .47102 .56092 .4764 .55921 .47336 .55626 Metetra
.668 .747 .909 r
.47336 .55626 .4764 .55921 .48178 .55752 .47875 .55454 Metetra
.667 .746 .909 r
.47875 .55454 .48178 .55752 .48717 .55584 .48416 .55284 Metetra
.666 .745 .909 r
.48416 .55284 .48717 .55584 .49258 .55417 .48957 .55115 Metetra
.665 .744 .909 r
.48957 .55115 .49258 .55417 .49799 .5525 .49499 .54947 Metetra
.665 .743 .908 r
.49499 .54947 .49799 .5525 .50342 .55083 .50042 .54779 Metetra
.665 .743 .908 r
.50042 .54779 .50342 .55083 .50886 .54917 .50586 .54612 Metetra
.664 .742 .908 r
.50586 .54612 .50886 .54917 .5143 .5475 .51132 .54444 Metetra
.664 .742 .908 r
.51132 .54444 .5143 .5475 .51976 .54583 .51678 .54277 Metetra
.664 .742 .908 r
.51678 .54277 .51976 .54583 .52523 .54417 .52226 .54109 Metetra
.664 .742 .908 r
.52226 .54109 .52523 .54417 .53071 .54249 .52775 .53941 Metetra
.664 .742 .908 r
.52775 .53941 .53071 .54249 .5362 .54082 .53324 .53773 Metetra
.664 .741 .908 r
.53324 .53773 .5362 .54082 .5417 .53915 .53875 .53605 Metetra
.664 .741 .908 r
.53875 .53605 .5417 .53915 .54721 .53747 .54427 .53436 Metetra
.664 .741 .908 r
.54427 .53436 .54721 .53747 .55274 .53579 .5498 .53268 Metetra
.664 .741 .908 r
.5498 .53268 .55274 .53579 .55827 .5341 .55534 .53098 Metetra
.664 .741 .908 r
.55534 .53098 .55827 .5341 .56382 .53241 .5609 .52929 Metetra
.664 .741 .908 r
.5609 .52929 .56382 .53241 .56937 .53072 .56646 .52759 Metetra
.664 .741 .908 r
.56646 .52759 .56937 .53072 .57494 .52903 .57204 .52589 Metetra
.664 .741 .908 r
.57204 .52589 .57494 .52903 .58052 .52733 .57762 .52419 Metetra
.664 .741 .908 r
.57762 .52419 .58052 .52733 .58611 .52563 .58322 .52248 Metetra
.664 .741 .908 r
.58322 .52248 .58611 .52563 .59171 .52393 .58883 .52077 Metetra
.664 .741 .908 r
.58883 .52077 .59171 .52393 .59732 .52222 .59445 .51906 Metetra
.664 .741 .908 r
.59445 .51906 .59732 .52222 .60295 .52051 .60008 .51734 Metetra
.664 .741 .908 r
.60008 .51734 .60295 .52051 .60858 .51879 .60572 .51562 Metetra
.664 .741 .908 r
.60572 .51562 .60858 .51879 .61423 .51707 .61138 .51389 Metetra
.664 .741 .908 r
.61138 .51389 .61423 .51707 .61989 .51535 .61705 .51216 Metetra
.664 .741 .908 r
.61705 .51216 .61989 .51535 .62556 .51363 .62272 .51043 Metetra
.664 .741 .908 r
.62272 .51043 .62556 .51363 .63124 .5119 .62841 .5087 Metetra
.664 .741 .908 r
.62841 .5087 .63124 .5119 .63693 .51017 .63411 .50696 Metetra
.664 .741 .908 r
.63411 .50696 .63693 .51017 .64264 .50843 .63982 .50522 Metetra
.664 .741 .908 r
.63982 .50522 .64264 .50843 .64835 .50669 .64555 .50347 Metetra
.664 .741 .908 r
.64555 .50347 .64835 .50669 .65408 .50495 .65128 .50172 Metetra
.664 .741 .908 r
.65128 .50172 .65408 .50495 .65982 .5032 .65703 .49997 Metetra
.664 .741 .908 r
.65703 .49997 .65982 .5032 .66557 .50145 .66279 .49821 Metetra
.664 .741 .908 r
.66279 .49821 .66557 .50145 .67133 .4997 .66856 .49645 Metetra
.664 .741 .908 r
.66856 .49645 .67133 .4997 .67711 .49794 .67434 .49469 Metetra
.664 .741 .908 r
.67434 .49469 .67711 .49794 .6829 .49618 .68014 .49292 Metetra
.664 .741 .908 r
.68014 .49292 .6829 .49618 .68869 .49442 .68595 .49115 Metetra
.664 .741 .908 r
.68595 .49115 .68869 .49442 .6945 .49265 .69176 .48938 Metetra
.664 .741 .908 r
.69176 .48938 .6945 .49265 .70033 .49088 .69759 .4876 Metetra
.664 .741 .908 r
.69759 .4876 .70033 .49088 .70616 .4891 .70344 .48581 Metetra
.664 .741 .908 r
.70344 .48581 .70616 .4891 .71201 .48732 .70929 .48403 Metetra
.664 .741 .908 r
.70929 .48403 .71201 .48732 .71786 .48554 .71516 .48224 Metetra
.664 .741 .908 r
.71516 .48224 .71786 .48554 .72373 .48375 .72104 .48045 Metetra
.664 .741 .908 r
.72104 .48045 .72373 .48375 .72962 .48196 .72693 .47865 Metetra
.664 .741 .908 r
.72693 .47865 .72962 .48196 .73551 .48017 .73283 .47685 Metetra
.664 .741 .908 r
.73283 .47685 .73551 .48017 .74142 .47837 .73875 .47505 Metetra
.664 .741 .908 r
.73875 .47505 .74142 .47837 .74734 .47657 .74467 .47324 Metetra
.664 .741 .908 r
.74467 .47324 .74734 .47657 .75327 .47477 .75061 .47143 Metetra
.663 .741 .908 r
.75061 .47143 .75327 .47477 .75921 .47296 .75656 .46961 Metetra
.663 .741 .908 r
.75656 .46961 .75921 .47296 .76517 .47115 .76253 .4678 Metetra
.663 .741 .908 r
.76253 .4678 .76517 .47115 .77114 .46934 .76851 .46597 Metetra
.663 .741 .908 r
.76851 .46597 .77114 .46934 .77712 .46752 .7745 .46415 Metetra
.663 .741 .908 r
.7745 .46415 .77712 .46752 .78311 .4657 .7805 .46232 Metetra
.663 .741 .908 r
.7805 .46232 .78311 .4657 .78912 .46387 .78651 .46049 Metetra
.663 .741 .908 r
.78651 .46049 .78912 .46387 .79513 .46205 .79254 .45866 Metetra
.663 .741 .908 r
.79254 .45866 .79513 .46205 .80117 .46022 .79858 .45683 Metetra
.663 .742 .909 r
.79858 .45683 .80117 .46022 .80721 .45839 .80463 .45499 Metetra
.663 .742 .909 r
.80463 .45499 .80721 .45839 .81327 .45655 .8107 .45316 Metetra
.662 .742 .909 r
.8107 .45316 .81327 .45655 .81934 .45472 .81678 .45132 Metetra
.662 .742 .909 r
.81678 .45132 .81934 .45472 .82542 .45289 .82287 .44949 Metetra
.662 .742 .91 r
.82287 .44949 .82542 .45289 .83152 .45106 .82898 .44766 Metetra
.661 .742 .91 r
.82898 .44766 .83152 .45106 .83763 .44923 .8351 .44583 Metetra
.66 .742 .911 r
.8351 .44583 .83763 .44923 .84375 .44741 .84123 .44401 Metetra
.659 .743 .912 r
.84123 .44401 .84375 .44741 .84989 .4456 .84738 .4422 Metetra
.658 .743 .913 r
.84738 .4422 .84989 .4456 .85604 .44379 .85355 .4404 Metetra
.657 .744 .914 r
.85355 .4404 .85604 .44379 .86221 .44199 .85973 .43862 Metetra
.656 .744 .915 r
.85973 .43862 .86221 .44199 .86839 .44021 .86592 .43685 Metetra
.654 .745 .916 r
.86592 .43685 .86839 .44021 .87459 .43844 .87213 .4351 Metetra
.652 .746 .918 r
.87213 .4351 .87459 .43844 .8808 .43669 .87836 .43337 Metetra
.65 .747 .92 r
.87836 .43337 .8808 .43669 .88703 .43497 .8846 .43166 Metetra
.648 .748 .922 r
.8846 .43166 .88703 .43497 .89328 .43326 .89086 .42999 Metetra
.646 .749 .925 r
.89086 .42999 .89328 .43326 .89955 .43159 .89714 .42834 Metetra
.643 .751 .927 r
.89714 .42834 .89955 .43159 .90583 .42993 .90344 .42672 Metetra
.641 .752 .929 r
.90344 .42672 .90583 .42993 .91213 .42831 .90975 .42512 Metetra
.639 .754 .932 r
.90975 .42512 .91213 .42831 .91845 .42671 .91609 .42354 Metetra
.637 .755 .934 r
.91609 .42354 .91845 .42671 .92479 .42513 .92244 .42198 Metetra
.636 .757 .935 r
.92244 .42198 .92479 .42513 .93114 .42356 .9288 .42043 Metetra
.635 .758 .936 r
.9288 .42043 .93114 .42356 .93751 .422 .93518 .41887 Metetra
.636 .759 .937 r
.93518 .41887 .93751 .422 .94389 .42043 .94158 .4173 Metetra
.638 .76 .936 r
.94158 .4173 .94389 .42043 .95029 .41886 .94799 .4157 Metetra
.64 .76 .935 r
.94799 .4157 .95029 .41886 .9567 .41725 .9544 .41407 Metetra
.672 .767 .922 r
.37988 .58781 .38306 .59041 .3883 .58853 .38512 .58608 Metetra
.683 .78 .924 r
.38512 .58608 .3883 .58853 .39354 .58653 .39037 .5842 Metetra
.692 .791 .926 r
.39037 .5842 .39354 .58653 .39881 .58441 .39564 .58217 Metetra
.7 .799 .927 r
.39564 .58217 .39881 .58441 .40408 .58222 .40092 .58003 Metetra
.705 .804 .926 r
.40092 .58003 .40408 .58222 .40936 .57999 .40621 .57781 Metetra
.708 .805 .926 r
.40621 .57781 .40936 .57999 .41465 .57776 .41151 .57555 Metetra
.708 .804 .925 r
.41151 .57555 .41465 .57776 .41995 .57554 .41682 .57328 Metetra
.706 .8 .923 r
.41682 .57328 .41995 .57554 .42526 .57336 .42213 .57103 Metetra
.703 .795 .922 r
.42213 .57103 .42526 .57336 .43057 .57124 .42746 .56882 Metetra
.699 .789 .92 r
.42746 .56882 .43057 .57124 .43589 .56918 .43279 .56667 Metetra
.694 .782 .918 r
.43279 .56667 .43589 .56918 .44122 .56718 .43812 .56459 Metetra
.69 .775 .917 r
.43812 .56459 .44122 .56718 .44655 .56525 .44347 .56257 Metetra
.685 .769 .915 r
.44347 .56257 .44655 .56525 .4519 .56337 .44882 .56062 Metetra
.681 .763 .914 r
.44882 .56062 .4519 .56337 .45725 .56154 .45418 .55873 Metetra
.677 .759 .912 r
.45418 .55873 .45725 .56154 .46261 .55975 .45955 .55688 Metetra
.674 .755 .911 r
.45955 .55688 .46261 .55975 .46798 .55799 .46493 .55508 Metetra
.672 .752 .911 r
.46493 .55508 .46798 .55799 .47336 .55626 .47032 .55331 Metetra
.67 .749 .91 r
.47032 .55331 .47336 .55626 .47875 .55454 .47572 .55157 Metetra
.668 .747 .909 r
.47572 .55157 .47875 .55454 .48416 .55284 .48112 .54984 Metetra
.667 .746 .909 r
.48112 .54984 .48416 .55284 .48957 .55115 .48654 .54814 Metetra
.666 .744 .909 r
.48654 .54814 .48957 .55115 .49499 .54947 .49197 .54644 Metetra
.665 .744 .909 r
.49197 .54644 .49499 .54947 .50042 .54779 .49741 .54474 Metetra
.665 .743 .908 r
.49741 .54474 .50042 .54779 .50586 .54612 .50286 .54306 Metetra
.665 .743 .908 r
.50286 .54306 .50586 .54612 .51132 .54444 .50832 .54137 Metetra
.664 .742 .908 r
.50832 .54137 .51132 .54444 .51678 .54277 .5138 .53969 Metetra
.664 .742 .908 r
.5138 .53969 .51678 .54277 .52226 .54109 .51928 .538 Metetra
.664 .742 .908 r
.51928 .538 .52226 .54109 .52775 .53941 .52477 .53632 Metetra
.664 .742 .908 r
.52477 .53632 .52775 .53941 .53324 .53773 .53028 .53463 Metetra
.664 .742 .908 r
.53028 .53463 .53324 .53773 .53875 .53605 .53579 .53294 Metetra
.664 .741 .908 r
.53579 .53294 .53875 .53605 .54427 .53436 .54132 .53125 Metetra
.664 .741 .908 r
.54132 .53125 .54427 .53436 .5498 .53268 .54686 .52955 Metetra
.664 .741 .908 r
.54686 .52955 .5498 .53268 .55534 .53098 .55241 .52786 Metetra
.664 .741 .908 r
.55241 .52786 .55534 .53098 .5609 .52929 .55797 .52616 Metetra
.664 .741 .908 r
.55797 .52616 .5609 .52929 .56646 .52759 .56354 .52445 Metetra
.664 .741 .908 r
.56354 .52445 .56646 .52759 .57204 .52589 .56912 .52274 Metetra
.664 .741 .908 r
.56912 .52274 .57204 .52589 .57762 .52419 .57472 .52103 Metetra
.664 .741 .908 r
.57472 .52103 .57762 .52419 .58322 .52248 .58032 .51932 Metetra
.664 .741 .908 r
.58032 .51932 .58322 .52248 .58883 .52077 .58594 .5176 Metetra
.664 .741 .908 r
.58594 .5176 .58883 .52077 .59445 .51906 .59156 .51588 Metetra
.664 .741 .908 r
.59156 .51588 .59445 .51906 .60008 .51734 .5972 .51416 Metetra
.664 .741 .908 r
.5972 .51416 .60008 .51734 .60572 .51562 .60285 .51243 Metetra
.664 .741 .908 r
.60285 .51243 .60572 .51562 .61138 .51389 .60852 .5107 Metetra
.664 .741 .908 r
.60852 .5107 .61138 .51389 .61705 .51216 .61419 .50896 Metetra
.664 .741 .908 r
.61419 .50896 .61705 .51216 .62272 .51043 .61988 .50723 Metetra
.664 .741 .908 r
.61988 .50723 .62272 .51043 .62841 .5087 .62557 .50548 Metetra
.664 .741 .908 r
.62557 .50548 .62841 .5087 .63411 .50696 .63128 .50374 Metetra
.664 .741 .908 r
.63128 .50374 .63411 .50696 .63982 .50522 .637 .50199 Metetra
.664 .741 .908 r
.637 .50199 .63982 .50522 .64555 .50347 .64273 .50024 Metetra
.664 .741 .908 r
.64273 .50024 .64555 .50347 .65128 .50172 .64848 .49848 Metetra
.664 .741 .908 r
.64848 .49848 .65128 .50172 .65703 .49997 .65423 .49672 Metetra
.664 .741 .908 r
.65423 .49672 .65703 .49997 .66279 .49821 .66 .49496 Metetra
.664 .741 .908 r
.66 .49496 .66279 .49821 .66856 .49645 .66578 .49319 Metetra
.664 .741 .908 r
.66578 .49319 .66856 .49645 .67434 .49469 .67157 .49142 Metetra
.664 .741 .908 r
.67157 .49142 .67434 .49469 .68014 .49292 .67737 .48965 Metetra
.664 .741 .908 r
.67737 .48965 .68014 .49292 .68595 .49115 .68319 .48787 Metetra
.664 .741 .908 r
.68319 .48787 .68595 .49115 .69176 .48938 .68901 .48609 Metetra
.664 .741 .908 r
.68901 .48609 .69176 .48938 .69759 .4876 .69485 .4843 Metetra
.664 .741 .908 r
.69485 .4843 .69759 .4876 .70344 .48581 .7007 .48252 Metetra
.664 .741 .908 r
.7007 .48252 .70344 .48581 .70929 .48403 .70657 .48072 Metetra
.664 .741 .908 r
.70657 .48072 .70929 .48403 .71516 .48224 .71244 .47893 Metetra
.664 .741 .908 r
.71244 .47893 .71516 .48224 .72104 .48045 .71833 .47713 Metetra
.664 .741 .908 r
.71833 .47713 .72104 .48045 .72693 .47865 .72423 .47532 Metetra
.664 .741 .908 r
.72423 .47532 .72693 .47865 .73283 .47685 .73014 .47352 Metetra
.664 .741 .908 r
.73014 .47352 .73283 .47685 .73875 .47505 .73606 .47171 Metetra
.664 .741 .908 r
.73606 .47171 .73875 .47505 .74467 .47324 .742 .46989 Metetra
.663 .741 .908 r
.742 .46989 .74467 .47324 .75061 .47143 .74795 .46807 Metetra
.663 .741 .908 r
.74795 .46807 .75061 .47143 .75656 .46961 .75391 .46625 Metetra
.663 .741 .908 r
.75391 .46625 .75656 .46961 .76253 .4678 .75988 .46443 Metetra
.663 .741 .908 r
.75988 .46443 .76253 .4678 .76851 .46597 .76587 .4626 Metetra
.663 .741 .908 r
.76587 .4626 .76851 .46597 .7745 .46415 .77187 .46077 Metetra
.663 .741 .908 r
.77187 .46077 .7745 .46415 .7805 .46232 .77788 .45894 Metetra
.663 .741 .908 r
.77788 .45894 .7805 .46232 .78651 .46049 .7839 .4571 Metetra
.663 .741 .908 r
.7839 .4571 .78651 .46049 .79254 .45866 .78994 .45526 Metetra
.663 .742 .909 r
.78994 .45526 .79254 .45866 .79858 .45683 .79599 .45343 Metetra
.663 .742 .909 r
.79599 .45343 .79858 .45683 .80463 .45499 .80205 .45159 Metetra
.662 .742 .909 r
.80205 .45159 .80463 .45499 .8107 .45316 .80812 .44975 Metetra
.662 .742 .909 r
.80812 .44975 .8107 .45316 .81678 .45132 .81421 .44791 Metetra
.662 .742 .91 r
.81421 .44791 .81678 .45132 .82287 .44949 .82032 .44608 Metetra
.661 .742 .91 r
.82032 .44608 .82287 .44949 .82898 .44766 .82643 .44425 Metetra
.66 .742 .911 r
.82643 .44425 .82898 .44766 .8351 .44583 .83256 .44243 Metetra
.659 .743 .912 r
.83256 .44243 .8351 .44583 .84123 .44401 .83871 .44061 Metetra
.658 .743 .913 r
.83871 .44061 .84123 .44401 .84738 .4422 .84487 .43881 Metetra
.657 .744 .914 r
.84487 .43881 .84738 .4422 .85355 .4404 .85104 .43702 Metetra
.656 .744 .915 r
.85104 .43702 .85355 .4404 .85973 .43862 .85723 .43525 Metetra
.654 .745 .917 r
.85723 .43525 .85973 .43862 .86592 .43685 .86344 .4335 Metetra
.652 .746 .918 r
.86344 .4335 .86592 .43685 .87213 .4351 .86966 .43177 Metetra
.65 .747 .92 r
.86966 .43177 .87213 .4351 .87836 .43337 .8759 .43006 Metetra
.648 .748 .923 r
.8759 .43006 .87836 .43337 .8846 .43166 .88216 .42839 Metetra
.645 .749 .925 r
.88216 .42839 .8846 .43166 .89086 .42999 .88844 .42674 Metetra
.643 .751 .927 r
.88844 .42674 .89086 .42999 .89714 .42834 .89473 .42512 Metetra
.64 .752 .93 r
.89473 .42512 .89714 .42834 .90344 .42672 .90104 .42353 Metetra
.638 .754 .932 r
.90104 .42353 .90344 .42672 .90975 .42512 .90737 .42196 Metetra
.636 .756 .934 r
.90737 .42196 .90975 .42512 .91609 .42354 .91372 .4204 Metetra
.635 .757 .936 r
.91372 .4204 .91609 .42354 .92244 .42198 .92008 .41886 Metetra
.634 .758 .937 r
.92008 .41886 .92244 .42198 .9288 .42043 .92646 .41731 Metetra
.635 .76 .938 r
.92646 .41731 .9288 .42043 .93518 .41887 .93285 .41575 Metetra
.637 .76 .937 r
.93285 .41575 .93518 .41887 .94158 .4173 .93926 .41416 Metetra
.639 .761 .936 r
.93926 .41416 .94158 .4173 .94799 .4157 .94567 .41253 Metetra
.643 .761 .934 r
.94567 .41253 .94799 .4157 .9544 .41407 .9521 .41085 Metetra
.66 .752 .918 r
.3767 .58503 .37988 .58781 .38512 .58608 .38194 .58347 Metetra
.671 .767 .922 r
.38194 .58347 .38512 .58608 .39037 .5842 .38719 .58174 Metetra
.683 .78 .925 r
.38719 .58174 .39037 .5842 .39564 .58217 .39246 .57985 Metetra
.693 .792 .926 r
.39246 .57985 .39564 .58217 .40092 .58003 .39774 .5778 Metetra
.701 .801 .927 r
.39774 .5778 .40092 .58003 .40621 .57781 .40304 .57564 Metetra
.706 .806 .927 r
.40304 .57564 .40621 .57781 .41151 .57555 .40835 .57339 Metetra
.709 .808 .926 r
.40835 .57339 .41151 .57555 .41682 .57328 .41366 .57109 Metetra
.71 .807 .925 r
.41366 .57109 .41682 .57328 .42213 .57103 .41899 .56879 Metetra
.708 .803 .924 r
.41899 .56879 .42213 .57103 .42746 .56882 .42432 .5665 Metetra
.705 .797 .922 r
.42432 .5665 .42746 .56882 .43279 .56667 .42967 .56426 Metetra
.7 .79 .92 r
.42967 .56426 .43279 .56667 .43812 .56459 .43501 .56208 Metetra
.695 .783 .919 r
.43501 .56208 .43812 .56459 .44347 .56257 .44037 .55997 Metetra
.69 .776 .917 r
.44037 .55997 .44347 .56257 .44882 .56062 .44573 .55794 Metetra
.686 .77 .915 r
.44573 .55794 .44882 .56062 .45418 .55873 .4511 .55597 Metetra
.681 .764 .914 r
.4511 .55597 .45418 .55873 .45955 .55688 .45648 .55406 Metetra
.677 .759 .912 r
.45648 .55406 .45955 .55688 .46493 .55508 .46187 .5522 Metetra
.674 .755 .911 r
.46187 .5522 .46493 .55508 .47032 .55331 .46726 .55039 Metetra
.672 .752 .911 r
.46726 .55039 .47032 .55331 .47572 .55157 .47267 .54861 Metetra
.67 .749 .91 r
.47267 .54861 .47572 .55157 .48112 .54984 .47808 .54685 Metetra
.668 .747 .909 r
.47808 .54685 .48112 .54984 .48654 .54814 .48351 .54512 Metetra
.667 .746 .909 r
.48351 .54512 .48654 .54814 .49197 .54644 .48894 .5434 Metetra
.666 .744 .909 r
.48894 .5434 .49197 .54644 .49741 .54474 .49439 .54169 Metetra
.665 .744 .909 r
.49439 .54169 .49741 .54474 .50286 .54306 .49985 .53999 Metetra
.665 .743 .908 r
.49985 .53999 .50286 .54306 .50832 .54137 .50532 .5383 Metetra
.665 .743 .908 r
.50532 .5383 .50832 .54137 .5138 .53969 .5108 .5366 Metetra
.664 .742 .908 r
.5108 .5366 .5138 .53969 .51928 .538 .51629 .53491 Metetra
.664 .742 .908 r
.51629 .53491 .51928 .538 .52477 .53632 .52179 .53321 Metetra
.664 .742 .908 r
.52179 .53321 .52477 .53632 .53028 .53463 .5273 .53152 Metetra
.664 .742 .908 r
.5273 .53152 .53028 .53463 .53579 .53294 .53282 .52982 Metetra
.664 .742 .908 r
.53282 .52982 .53579 .53294 .54132 .53125 .53836 .52812 Metetra
.664 .741 .908 r
.53836 .52812 .54132 .53125 .54686 .52955 .5439 .52642 Metetra
.664 .741 .908 r
.5439 .52642 .54686 .52955 .55241 .52786 .54946 .52472 Metetra
.664 .741 .908 r
.54946 .52472 .55241 .52786 .55797 .52616 .55503 .52301 Metetra
.664 .741 .908 r
.55503 .52301 .55797 .52616 .56354 .52445 .56061 .5213 Metetra
.664 .741 .908 r
.56061 .5213 .56354 .52445 .56912 .52274 .5662 .51958 Metetra
.664 .741 .908 r
.5662 .51958 .56912 .52274 .57472 .52103 .5718 .51787 Metetra
.664 .741 .908 r
.5718 .51787 .57472 .52103 .58032 .51932 .57741 .51615 Metetra
.664 .741 .908 r
.57741 .51615 .58032 .51932 .58594 .5176 .58303 .51442 Metetra
.664 .741 .908 r
.58303 .51442 .58594 .5176 .59156 .51588 .58867 .5127 Metetra
.664 .741 .908 r
.58867 .5127 .59156 .51588 .5972 .51416 .59432 .51097 Metetra
.664 .741 .908 r
.59432 .51097 .5972 .51416 .60285 .51243 .59997 .50923 Metetra
.664 .741 .908 r
.59997 .50923 .60285 .51243 .60852 .5107 .60564 .50749 Metetra
.664 .741 .908 r
.60564 .50749 .60852 .5107 .61419 .50896 .61133 .50575 Metetra
.664 .741 .908 r
.61133 .50575 .61419 .50896 .61988 .50723 .61702 .50401 Metetra
.664 .741 .908 r
.61702 .50401 .61988 .50723 .62557 .50548 .62272 .50226 Metetra
.664 .741 .908 r
.62272 .50226 .62557 .50548 .63128 .50374 .62844 .50051 Metetra
.664 .741 .908 r
.62844 .50051 .63128 .50374 .637 .50199 .63417 .49875 Metetra
.664 .741 .908 r
.63417 .49875 .637 .50199 .64273 .50024 .63991 .49699 Metetra
.664 .741 .908 r
.63991 .49699 .64273 .50024 .64848 .49848 .64566 .49523 Metetra
.664 .741 .908 r
.64566 .49523 .64848 .49848 .65423 .49672 .65142 .49346 Metetra
.664 .741 .908 r
.65142 .49346 .65423 .49672 .66 .49496 .6572 .49169 Metetra
.664 .741 .908 r
.6572 .49169 .66 .49496 .66578 .49319 .66298 .48992 Metetra
.664 .741 .908 r
.66298 .48992 .66578 .49319 .67157 .49142 .66878 .48814 Metetra
.664 .741 .908 r
.66878 .48814 .67157 .49142 .67737 .48965 .67459 .48636 Metetra
.664 .741 .908 r
.67459 .48636 .67737 .48965 .68319 .48787 .68042 .48458 Metetra
.664 .741 .908 r
.68042 .48458 .68319 .48787 .68901 .48609 .68625 .48279 Metetra
.664 .741 .908 r
.68625 .48279 .68901 .48609 .69485 .4843 .6921 .481 Metetra
.664 .741 .908 r
.6921 .481 .69485 .4843 .7007 .48252 .69796 .4792 Metetra
.664 .741 .908 r
.69796 .4792 .7007 .48252 .70657 .48072 .70383 .4774 Metetra
.664 .741 .908 r
.70383 .4774 .70657 .48072 .71244 .47893 .70971 .4756 Metetra
.664 .741 .908 r
.70971 .4756 .71244 .47893 .71833 .47713 .71561 .4738 Metetra
.664 .741 .908 r
.71561 .4738 .71833 .47713 .72423 .47532 .72152 .47198 Metetra
.664 .741 .908 r
.72152 .47198 .72423 .47532 .73014 .47352 .72744 .47017 Metetra
.664 .741 .908 r
.72744 .47017 .73014 .47352 .73606 .47171 .73337 .46835 Metetra
.663 .741 .908 r
.73337 .46835 .73606 .47171 .742 .46989 .73931 .46653 Metetra
.663 .741 .908 r
.73931 .46653 .742 .46989 .74795 .46807 .74527 .46471 Metetra
.663 .741 .908 r
.74527 .46471 .74795 .46807 .75391 .46625 .75124 .46288 Metetra
.663 .741 .908 r
.75124 .46288 .75391 .46625 .75988 .46443 .75722 .46105 Metetra
.663 .741 .908 r
.75722 .46105 .75988 .46443 .76587 .4626 .76322 .45922 Metetra
.663 .741 .908 r
.76322 .45922 .76587 .4626 .77187 .46077 .76922 .45738 Metetra
.663 .741 .908 r
.76922 .45738 .77187 .46077 .77788 .45894 .77524 .45554 Metetra
.663 .741 .908 r
.77524 .45554 .77788 .45894 .7839 .4571 .78128 .4537 Metetra
.663 .742 .909 r
.78128 .4537 .7839 .4571 .78994 .45526 .78732 .45186 Metetra
.663 .742 .909 r
.78732 .45186 .78994 .45526 .79599 .45343 .79338 .45002 Metetra
.662 .742 .909 r
.79338 .45002 .79599 .45343 .80205 .45159 .79945 .44817 Metetra
.662 .742 .909 r
.79945 .44817 .80205 .45159 .80812 .44975 .80554 .44633 Metetra
.662 .742 .91 r
.80554 .44633 .80812 .44975 .81421 .44791 .81164 .4445 Metetra
.661 .742 .91 r
.81164 .4445 .81421 .44791 .82032 .44608 .81775 .44266 Metetra
.66 .742 .911 r
.81775 .44266 .82032 .44608 .82643 .44425 .82388 .44084 Metetra
.659 .743 .912 r
.82388 .44084 .82643 .44425 .83256 .44243 .83002 .43902 Metetra
.658 .743 .913 r
.83002 .43902 .83256 .44243 .83871 .44061 .83617 .43721 Metetra
.657 .744 .914 r
.83617 .43721 .83871 .44061 .84487 .43881 .84235 .43542 Metetra
.656 .744 .915 r
.84235 .43542 .84487 .43881 .85104 .43702 .84853 .43365 Metetra
.654 .745 .917 r
.84853 .43365 .85104 .43702 .85723 .43525 .85473 .43189 Metetra
.652 .746 .918 r
.85473 .43189 .85723 .43525 .86344 .4335 .86095 .43016 Metetra
.65 .747 .921 r
.86095 .43016 .86344 .4335 .86966 .43177 .86719 .42846 Metetra
.648 .748 .923 r
.86719 .42846 .86966 .43177 .8759 .43006 .87344 .42678 Metetra
.645 .75 .925 r
.87344 .42678 .8759 .43006 .88216 .42839 .87971 .42514 Metetra
.642 .751 .928 r
.87971 .42514 .88216 .42839 .88844 .42674 .886 .42352 Metetra
.64 .753 .93 r
.886 .42352 .88844 .42674 .89473 .42512 .89231 .42193 Metetra
.637 .754 .933 r
.89231 .42193 .89473 .42512 .90104 .42353 .89864 .42037 Metetra
.635 .756 .935 r
.89864 .42037 .90104 .42353 .90737 .42196 .90498 .41882 Metetra
.634 .758 .937 r
.90498 .41882 .90737 .42196 .91372 .4204 .91134 .41729 Metetra
.633 .759 .938 r
.91134 .41729 .91372 .4204 .92008 .41886 .91772 .41575 Metetra
.634 .76 .939 r
.91772 .41575 .92008 .41886 .92646 .41731 .92411 .41419 Metetra
.636 .761 .938 r
.92411 .41419 .92646 .41731 .93285 .41575 .93051 .41261 Metetra
.639 .761 .937 r
.93051 .41261 .93285 .41575 .93926 .41416 .93692 .41099 Metetra
.642 .761 .935 r
.93692 .41099 .93926 .41416 .94567 .41253 .94334 .40931 Metetra
.647 .76 .932 r
.94334 .40931 .94567 .41253 .9521 .41085 .94977 .40757 Metetra
.647 .736 .914 r
.37352 .58205 .3767 .58503 .38194 .58347 .37875 .58066 Metetra
.658 .751 .918 r
.37875 .58066 .38194 .58347 .38719 .58174 .384 .57911 Metetra
.67 .766 .922 r
.384 .57911 .38719 .58174 .39246 .57985 .38927 .57738 Metetra
.682 .781 .925 r
.38927 .57738 .39246 .57985 .39774 .5778 .39456 .57548 Metetra
.693 .794 .927 r
.39456 .57548 .39774 .5778 .40304 .57564 .39986 .57342 Metetra
.702 .803 .928 r
.39986 .57342 .40304 .57564 .40835 .57339 .40517 .57123 Metetra
.708 .809 .928 r
.40517 .57123 .40835 .57339 .41366 .57109 .4105 .56895 Metetra
.711 .811 .927 r
.4105 .56895 .41366 .57109 .41899 .56879 .41583 .56662 Metetra
.711 .809 .926 r
.41583 .56662 .41899 .56879 .42432 .5665 .42118 .56427 Metetra
.71 .805 .924 r
.42118 .56427 .42432 .5665 .42967 .56426 .42653 .56195 Metetra
.706 .799 .923 r
.42653 .56195 .42967 .56426 .43501 .56208 .43189 .55968 Metetra
.702 .792 .921 r
.43189 .55968 .43501 .56208 .44037 .55997 .43725 .55747 Metetra
.696 .785 .919 r
.43725 .55747 .44037 .55997 .44573 .55794 .44263 .55534 Metetra
.691 .777 .917 r
.44263 .55534 .44573 .55794 .4511 .55597 .448 .55328 Metetra
.686 .77 .915 r
.448 .55328 .4511 .55597 .45648 .55406 .45339 .55129 Metetra
.682 .764 .914 r
.45339 .55129 .45648 .55406 .46187 .5522 .45879 .54936 Metetra
.678 .759 .912 r
.45879 .54936 .46187 .5522 .46726 .55039 .46419 .54749 Metetra
.675 .755 .911 r
.46419 .54749 .46726 .55039 .47267 .54861 .46961 .54567 Metetra
.672 .752 .911 r
.46961 .54567 .47267 .54861 .47808 .54685 .47503 .54388 Metetra
.67 .749 .91 r
.47503 .54388 .47808 .54685 .48351 .54512 .48046 .54211 Metetra
.668 .747 .909 r
.48046 .54211 .48351 .54512 .48894 .5434 .48591 .54037 Metetra
.667 .746 .909 r
.48591 .54037 .48894 .5434 .49439 .54169 .49136 .53864 Metetra
.666 .744 .909 r
.49136 .53864 .49439 .54169 .49985 .53999 .49682 .53692 Metetra
.665 .744 .909 r
.49682 .53692 .49985 .53999 .50532 .5383 .5023 .53521 Metetra
.665 .743 .908 r
.5023 .53521 .50532 .5383 .5108 .5366 .50779 .53351 Metetra
.665 .743 .908 r
.50779 .53351 .5108 .5366 .51629 .53491 .51328 .5318 Metetra
.664 .742 .908 r
.51328 .5318 .51629 .53491 .52179 .53321 .51879 .5301 Metetra
.664 .742 .908 r
.51879 .5301 .52179 .53321 .5273 .53152 .52431 .5284 Metetra
.664 .742 .908 r
.52431 .5284 .5273 .53152 .53282 .52982 .52984 .52669 Metetra
.664 .742 .908 r
.52984 .52669 .53282 .52982 .53836 .52812 .53538 .52499 Metetra
.664 .742 .908 r
.53538 .52499 .53836 .52812 .5439 .52642 .54094 .52328 Metetra
.664 .741 .908 r
.54094 .52328 .5439 .52642 .54946 .52472 .5465 .52157 Metetra
.664 .741 .908 r
.5465 .52157 .54946 .52472 .55503 .52301 .55207 .51985 Metetra
.664 .741 .908 r
.55207 .51985 .55503 .52301 .56061 .5213 .55766 .51813 Metetra
.664 .741 .908 r
.55766 .51813 .56061 .5213 .5662 .51958 .56326 .51641 Metetra
.664 .741 .908 r
.56326 .51641 .5662 .51958 .5718 .51787 .56887 .51469 Metetra
.664 .741 .908 r
.56887 .51469 .5718 .51787 .57741 .51615 .57449 .51296 Metetra
.664 .741 .908 r
.57449 .51296 .57741 .51615 .58303 .51442 .58012 .51123 Metetra
.664 .741 .908 r
.58012 .51123 .58303 .51442 .58867 .5127 .58576 .5095 Metetra
.664 .741 .908 r
.58576 .5095 .58867 .5127 .59432 .51097 .59142 .50776 Metetra
.664 .741 .908 r
.59142 .50776 .59432 .51097 .59997 .50923 .59708 .50602 Metetra
.664 .741 .908 r
.59708 .50602 .59997 .50923 .60564 .50749 .60276 .50428 Metetra
.664 .741 .908 r
.60276 .50428 .60564 .50749 .61133 .50575 .60845 .50253 Metetra
.664 .741 .908 r
.60845 .50253 .61133 .50575 .61702 .50401 .61415 .50078 Metetra
.664 .741 .908 r
.61415 .50078 .61702 .50401 .62272 .50226 .61986 .49902 Metetra
.664 .741 .908 r
.61986 .49902 .62272 .50226 .62844 .50051 .62559 .49726 Metetra
.664 .741 .908 r
.62559 .49726 .62844 .50051 .63417 .49875 .63132 .4955 Metetra
.664 .741 .908 r
.63132 .4955 .63417 .49875 .63991 .49699 .63707 .49374 Metetra
.664 .741 .908 r
.63707 .49374 .63991 .49699 .64566 .49523 .64283 .49197 Metetra
.664 .741 .908 r
.64283 .49197 .64566 .49523 .65142 .49346 .6486 .49019 Metetra
.664 .741 .908 r
.6486 .49019 .65142 .49346 .6572 .49169 .65439 .48842 Metetra
.664 .741 .908 r
.65439 .48842 .6572 .49169 .66298 .48992 .66018 .48664 Metetra
.664 .741 .908 r
.66018 .48664 .66298 .48992 .66878 .48814 .66599 .48485 Metetra
.664 .741 .908 r
.66599 .48485 .66878 .48814 .67459 .48636 .67181 .48307 Metetra
.664 .741 .908 r
.67181 .48307 .67459 .48636 .68042 .48458 .67764 .48127 Metetra
.664 .741 .908 r
.67764 .48127 .68042 .48458 .68625 .48279 .68348 .47948 Metetra
.664 .741 .908 r
.68348 .47948 .68625 .48279 .6921 .481 .68934 .47768 Metetra
.664 .741 .908 r
.68934 .47768 .6921 .481 .69796 .4792 .6952 .47588 Metetra
.664 .741 .908 r
.6952 .47588 .69796 .4792 .70383 .4774 .70108 .47407 Metetra
.664 .741 .908 r
.70108 .47407 .70383 .4774 .70971 .4756 .70697 .47226 Metetra
.664 .741 .908 r
.70697 .47226 .70971 .4756 .71561 .4738 .71288 .47045 Metetra
.664 .741 .908 r
.71288 .47045 .71561 .4738 .72152 .47198 .71879 .46863 Metetra
.664 .741 .908 r
.71879 .46863 .72152 .47198 .72744 .47017 .72472 .46681 Metetra
.663 .741 .908 r
.72472 .46681 .72744 .47017 .73337 .46835 .73066 .46499 Metetra
.663 .741 .908 r
.73066 .46499 .73337 .46835 .73931 .46653 .73662 .46316 Metetra
.663 .741 .908 r
.73662 .46316 .73931 .46653 .74527 .46471 .74258 .46133 Metetra
.663 .741 .908 r
.74258 .46133 .74527 .46471 .75124 .46288 .74856 .4595 Metetra
.663 .741 .908 r
.74856 .4595 .75124 .46288 .75722 .46105 .75455 .45766 Metetra
.663 .741 .908 r
.75455 .45766 .75722 .46105 .76322 .45922 .76056 .45582 Metetra
.663 .741 .908 r
.76056 .45582 .76322 .45922 .76922 .45738 .76657 .45398 Metetra
.663 .741 .908 r
.76657 .45398 .76922 .45738 .77524 .45554 .7726 .45213 Metetra
.663 .742 .908 r
.7726 .45213 .77524 .45554 .78128 .4537 .77864 .45029 Metetra
.663 .742 .909 r
.77864 .45029 .78128 .4537 .78732 .45186 .7847 .44844 Metetra
.662 .742 .909 r
.7847 .44844 .78732 .45186 .79338 .45002 .79077 .44659 Metetra
.662 .742 .909 r
.79077 .44659 .79338 .45002 .79945 .44817 .79685 .44475 Metetra
.662 .742 .91 r
.79685 .44475 .79945 .44817 .80554 .44633 .80294 .44291 Metetra
.661 .742 .91 r
.80294 .44291 .80554 .44633 .81164 .4445 .80905 .44107 Metetra
.66 .742 .911 r
.80905 .44107 .81164 .4445 .81775 .44266 .81518 .43924 Metetra
.659 .743 .912 r
.81518 .43924 .81775 .44266 .82388 .44084 .82131 .43742 Metetra
.658 .743 .913 r
.82131 .43742 .82388 .44084 .83002 .43902 .82746 .43561 Metetra
.657 .744 .914 r
.82746 .43561 .83002 .43902 .83617 .43721 .83363 .43382 Metetra
.656 .744 .915 r
.83363 .43382 .83617 .43721 .84235 .43542 .83981 .43204 Metetra
.654 .745 .917 r
.83981 .43204 .84235 .43542 .84853 .43365 .84601 .43029 Metetra
.652 .746 .919 r
.84601 .43029 .84853 .43365 .85473 .43189 .85223 .42856 Metetra
.65 .747 .921 r
.85223 .42856 .85473 .43189 .86095 .43016 .85846 .42685 Metetra
.647 .748 .923 r
.85846 .42685 .86095 .43016 .86719 .42846 .86471 .42518 Metetra
.645 .75 .926 r
.86471 .42518 .86719 .42846 .87344 .42678 .87098 .42353 Metetra
.642 .751 .928 r
.87098 .42353 .87344 .42678 .87971 .42514 .87726 .42192 Metetra
.639 .753 .931 r
.87726 .42192 .87971 .42514 .886 .42352 .88357 .42034 Metetra
.636 .755 .934 r
.88357 .42034 .886 .42352 .89231 .42193 .88989 .41878 Metetra
.634 .756 .936 r
.88989 .41878 .89231 .42193 .89864 .42037 .89623 .41724 Metetra
.633 .758 .938 r
.89623 .41724 .89864 .42037 .90498 .41882 .90259 .41571 Metetra
.632 .76 .939 r
.90259 .41571 .90498 .41882 .91134 .41729 .90896 .41418 Metetra
.633 .761 .94 r
.90896 .41418 .91134 .41729 .91772 .41575 .91535 .41264 Metetra
.635 .762 .939 r
.91535 .41264 .91772 .41575 .92411 .41419 .92175 .41107 Metetra
.638 .762 .938 r
.92175 .41107 .92411 .41419 .93051 .41261 .92816 .40945 Metetra
.642 .762 .936 r
.92816 .40945 .93051 .41261 .93692 .41099 .93457 .40778 Metetra
.647 .761 .932 r
.93457 .40778 .93692 .41099 .94334 .40931 .941 .40604 Metetra
.652 .759 .928 r
.941 .40604 .94334 .40931 .94977 .40757 .94743 .40423 Metetra
.636 .721 .909 r
.37033 .57887 .37352 .58205 .37875 .58066 .37557 .57764 Metetra
.645 .734 .914 r
.37557 .57764 .37875 .58066 .384 .57911 .38081 .57627 Metetra
.657 .75 .918 r
.38081 .57627 .384 .57911 .38927 .57738 .38608 .57473 Metetra
.669 .766 .923 r
.38608 .57473 .38927 .57738 .39456 .57548 .39137 .57301 Metetra
.682 .782 .926 r
.39137 .57301 .39456 .57548 .39986 .57342 .39667 .5711 Metetra
.694 .795 .928 r
.39667 .5711 .39986 .57342 .40517 .57123 .40199 .56902 Metetra
.703 .805 .929 r
.40199 .56902 .40517 .57123 .4105 .56895 .40732 .56681 Metetra
.709 .812 .929 r
.40732 .56681 .4105 .56895 .41583 .56662 .41266 .56449 Metetra
.713 .814 .928 r
.41266 .56449 .41583 .56662 .42118 .56427 .41801 .56212 Metetra
.713 .812 .927 r
.41801 .56212 .42118 .56427 .42653 .56195 .42338 .55974 Metetra
.712 .808 .925 r
.42338 .55974 .42653 .56195 .43189 .55968 .42875 .55738 Metetra
.708 .802 .923 r
.42875 .55738 .43189 .55968 .43725 .55747 .43412 .55507 Metetra
.703 .794 .921 r
.43412 .55507 .43725 .55747 .44263 .55534 .43951 .55283 Metetra
.698 .786 .919 r
.43951 .55283 .44263 .55534 .448 .55328 .44489 .55067 Metetra
.692 .778 .917 r
.44489 .55067 .448 .55328 .45339 .55129 .45029 .54859 Metetra
.687 .771 .916 r
.45029 .54859 .45339 .55129 .45879 .54936 .4557 .54658 Metetra
.682 .765 .914 r
.4557 .54658 .45879 .54936 .46419 .54749 .46111 .54464 Metetra
.678 .76 .913 r
.46111 .54464 .46419 .54749 .46961 .54567 .46653 .54276 Metetra
.675 .755 .911 r
.46653 .54276 .46961 .54567 .47503 .54388 .47196 .54092 Metetra
.672 .752 .911 r
.47196 .54092 .47503 .54388 .48046 .54211 .4774 .53912 Metetra
.67 .749 .91 r
.4774 .53912 .48046 .54211 .48591 .54037 .48286 .53734 Metetra
.668 .747 .909 r
.48286 .53734 .48591 .54037 .49136 .53864 .48832 .53559 Metetra
.667 .746 .909 r
.48832 .53559 .49136 .53864 .49682 .53692 .49379 .53385 Metetra
.666 .744 .909 r
.49379 .53385 .49682 .53692 .5023 .53521 .49927 .53213 Metetra
.665 .744 .908 r
.49927 .53213 .5023 .53521 .50779 .53351 .50477 .53041 Metetra
.665 .743 .908 r
.50477 .53041 .50779 .53351 .51328 .5318 .51027 .52869 Metetra
.665 .743 .908 r
.51027 .52869 .51328 .5318 .51879 .5301 .51579 .52698 Metetra
.664 .742 .908 r
.51579 .52698 .51879 .5301 .52431 .5284 .52131 .52527 Metetra
.664 .742 .908 r
.52131 .52527 .52431 .5284 .52984 .52669 .52685 .52355 Metetra
.664 .742 .908 r
.52685 .52355 .52984 .52669 .53538 .52499 .5324 .52184 Metetra
.664 .742 .908 r
.5324 .52184 .53538 .52499 .54094 .52328 .53796 .52012 Metetra
.664 .742 .908 r
.53796 .52012 .54094 .52328 .5465 .52157 .54353 .5184 Metetra
.664 .741 .908 r
.54353 .5184 .5465 .52157 .55207 .51985 .54911 .51668 Metetra
.664 .741 .908 r
.54911 .51668 .55207 .51985 .55766 .51813 .55471 .51496 Metetra
.664 .741 .908 r
.55471 .51496 .55766 .51813 .56326 .51641 .56031 .51323 Metetra
.664 .741 .908 r
.56031 .51323 .56326 .51641 .56887 .51469 .56593 .5115 Metetra
.664 .741 .908 r
.56593 .5115 .56887 .51469 .57449 .51296 .57155 .50977 Metetra
.664 .741 .908 r
.57155 .50977 .57449 .51296 .58012 .51123 .57719 .50803 Metetra
.664 .741 .908 r
.57719 .50803 .58012 .51123 .58576 .5095 .58284 .50629 Metetra
.664 .741 .908 r
.58284 .50629 .58576 .5095 .59142 .50776 .58851 .50455 Metetra
.664 .741 .908 r
.58851 .50455 .59142 .50776 .59708 .50602 .59418 .5028 Metetra
.664 .741 .908 r
.59418 .5028 .59708 .50602 .60276 .50428 .59987 .50105 Metetra
.664 .741 .908 r
.59987 .50105 .60276 .50428 .60845 .50253 .60556 .49929 Metetra
.664 .741 .908 r
.60556 .49929 .60845 .50253 .61415 .50078 .61127 .49754 Metetra
.664 .741 .908 r
.61127 .49754 .61415 .50078 .61986 .49902 .61699 .49577 Metetra
.664 .741 .908 r
.61699 .49577 .61986 .49902 .62559 .49726 .62272 .49401 Metetra
.664 .741 .908 r
.62272 .49401 .62559 .49726 .63132 .4955 .62847 .49224 Metetra
.664 .741 .908 r
.62847 .49224 .63132 .4955 .63707 .49374 .63422 .49047 Metetra
.664 .741 .908 r
.63422 .49047 .63707 .49374 .64283 .49197 .63999 .48869 Metetra
.664 .741 .908 r
.63999 .48869 .64283 .49197 .6486 .49019 .64577 .48691 Metetra
.664 .741 .908 r
.64577 .48691 .6486 .49019 .65439 .48842 .65156 .48513 Metetra
.664 .741 .908 r
.65156 .48513 .65439 .48842 .66018 .48664 .65737 .48334 Metetra
.664 .741 .908 r
.65737 .48334 .66018 .48664 .66599 .48485 .66318 .48155 Metetra
.664 .741 .908 r
.66318 .48155 .66599 .48485 .67181 .48307 .66901 .47976 Metetra
.664 .741 .908 r
.66901 .47976 .67181 .48307 .67764 .48127 .67485 .47796 Metetra
.664 .741 .908 r
.67485 .47796 .67764 .48127 .68348 .47948 .6807 .47616 Metetra
.664 .741 .908 r
.6807 .47616 .68348 .47948 .68934 .47768 .68656 .47435 Metetra
.664 .741 .908 r
.68656 .47435 .68934 .47768 .6952 .47588 .69244 .47254 Metetra
.664 .741 .908 r
.69244 .47254 .6952 .47588 .70108 .47407 .69833 .47073 Metetra
.664 .741 .908 r
.69833 .47073 .70108 .47407 .70697 .47226 .70423 .46891 Metetra
.664 .741 .908 r
.70423 .46891 .70697 .47226 .71288 .47045 .71014 .46709 Metetra
.664 .741 .908 r
.71014 .46709 .71288 .47045 .71879 .46863 .71606 .46527 Metetra
.663 .741 .908 r
.71606 .46527 .71879 .46863 .72472 .46681 .722 .46344 Metetra
.663 .741 .908 r
.722 .46344 .72472 .46681 .73066 .46499 .72795 .46161 Metetra
.663 .741 .908 r
.72795 .46161 .73066 .46499 .73662 .46316 .73391 .45978 Metetra
.663 .741 .908 r
.73391 .45978 .73662 .46316 .74258 .46133 .73989 .45794 Metetra
.663 .741 .908 r
.73989 .45794 .74258 .46133 .74856 .4595 .74587 .4561 Metetra
.663 .741 .908 r
.74587 .4561 .74856 .4595 .75455 .45766 .75187 .45425 Metetra
.663 .741 .908 r
.75187 .45425 .75455 .45766 .76056 .45582 .75789 .45241 Metetra
.663 .741 .908 r
.75789 .45241 .76056 .45582 .76657 .45398 .76391 .45056 Metetra
.663 .742 .908 r
.76391 .45056 .76657 .45398 .7726 .45213 .76995 .44871 Metetra
.663 .742 .909 r
.76995 .44871 .7726 .45213 .77864 .45029 .776 .44686 Metetra
.662 .742 .909 r
.776 .44686 .77864 .45029 .7847 .44844 .78207 .44501 Metetra
.662 .742 .909 r
.78207 .44501 .7847 .44844 .79077 .44659 .78814 .44317 Metetra
.662 .742 .91 r
.78814 .44317 .79077 .44659 .79685 .44475 .79423 .44132 Metetra
.661 .742 .91 r
.79423 .44132 .79685 .44475 .80294 .44291 .80034 .43948 Metetra
.66 .742 .911 r
.80034 .43948 .80294 .44291 .80905 .44107 .80646 .43765 Metetra
.659 .743 .912 r
.80646 .43765 .80905 .44107 .81518 .43924 .81259 .43583 Metetra
.658 .743 .913 r
.81259 .43583 .81518 .43924 .82131 .43742 .81874 .43401 Metetra
.657 .744 .914 r
.81874 .43401 .82131 .43742 .82746 .43561 .8249 .43222 Metetra
.656 .744 .915 r
.8249 .43222 .82746 .43561 .83363 .43382 .83108 .43044 Metetra
.654 .745 .917 r
.83108 .43044 .83363 .43382 .83981 .43204 .83728 .42868 Metetra
.652 .746 .919 r
.83728 .42868 .83981 .43204 .84601 .43029 .84349 .42695 Metetra
.649 .747 .921 r
.84349 .42695 .84601 .43029 .85223 .42856 .84972 .42524 Metetra
.647 .748 .923 r
.84972 .42524 .85223 .42856 .85846 .42685 .85596 .42357 Metetra
.644 .75 .926 r
.85596 .42357 .85846 .42685 .86471 .42518 .86223 .42193 Metetra
.641 .751 .929 r
.86223 .42193 .86471 .42518 .87098 .42353 .86851 .42032 Metetra
.638 .753 .932 r
.86851 .42032 .87098 .42353 .87726 .42192 .87481 .41874 Metetra
.635 .755 .934 r
.87481 .41874 .87726 .42192 .88357 .42034 .88113 .41719 Metetra
.633 .757 .937 r
.88113 .41719 .88357 .42034 .88989 .41878 .88746 .41566 Metetra
.632 .759 .939 r
.88746 .41566 .88989 .41878 .89623 .41724 .89382 .41414 Metetra
.631 .76 .94 r
.89382 .41414 .89623 .41724 .90259 .41571 .90019 .41262 Metetra
.632 .762 .941 r
.90019 .41262 .90259 .41571 .90896 .41418 .90657 .41109 Metetra
.633 .763 .941 r
.90657 .41109 .90896 .41418 .91535 .41264 .91297 .40952 Metetra
.637 .763 .939 r
.91297 .40952 .91535 .41264 .92175 .41107 .91937 .40791 Metetra
.641 .763 .937 r
.91937 .40791 .92175 .41107 .92816 .40945 .92579 .40625 Metetra
.646 .762 .933 r
.92579 .40625 .92816 .40945 .93457 .40778 .93221 .40451 Metetra
.652 .76 .929 r
.93221 .40451 .93457 .40778 .941 .40604 .93864 .40269 Metetra
.657 .758 .924 r
.93864 .40269 .941 .40604 .94743 .40423 .94507 .4008 Metetra
.628 .71 .905 r
.36714 .57554 .37033 .57887 .37557 .57764 .37237 .57442 Metetra
.634 .719 .908 r
.37237 .57442 .37557 .57764 .38081 .57627 .37762 .57321 Metetra
.643 .732 .913 r
.37762 .57321 .38081 .57627 .38608 .57473 .38289 .57186 Metetra
.655 .748 .918 r
.38289 .57186 .38608 .57473 .39137 .57301 .38817 .57034 Metetra
.668 .765 .923 r
.38817 .57034 .39137 .57301 .39667 .5711 .39347 .56863 Metetra
.682 .782 .926 r
.39347 .56863 .39667 .5711 .40199 .56902 .39879 .56671 Metetra
.694 .797 .929 r
.39879 .56671 .40199 .56902 .40732 .56681 .40413 .56462 Metetra
.704 .808 .929 r
.40413 .56462 .40732 .56681 .41266 .56449 .40948 .56237 Metetra
.711 .814 .929 r
.40948 .56237 .41266 .56449 .41801 .56212 .41484 .56002 Metetra
.715 .817 .929 r
.41484 .56002 .41801 .56212 .42338 .55974 .42021 .55762 Metetra
.715 .815 .927 r
.42021 .55762 .42338 .55974 .42875 .55738 .42559 .55519 Metetra
.714 .811 .926 r
.42559 .55519 .42875 .55738 .43412 .55507 .43098 .55279 Metetra
.71 .804 .924 r
.43098 .55279 .43412 .55507 .43951 .55283 .43637 .55045 Metetra
.705 .796 .922 r
.43637 .55045 .43951 .55283 .44489 .55067 .44177 .54818 Metetra
.699 .788 .92 r
.44177 .54818 .44489 .55067 .45029 .54859 .44718 .54599 Metetra
.693 .78 .918 r
.44718 .54599 .45029 .54859 .4557 .54658 .45259 .54388 Metetra
.687 .772 .916 r
.45259 .54388 .4557 .54658 .46111 .54464 .45802 .54185 Metetra
.683 .765 .914 r
.45802 .54185 .46111 .54464 .46653 .54276 .46345 .53989 Metetra
.678 .76 .913 r
.46345 .53989 .46653 .54276 .47196 .54092 .46889 .53799 Metetra
.675 .755 .912 r
.46889 .53799 .47196 .54092 .4774 .53912 .47433 .53614 Metetra
.672 .752 .911 r
.47433 .53614 .4774 .53912 .48286 .53734 .47979 .53433 Metetra
.67 .749 .91 r
.47979 .53433 .48286 .53734 .48832 .53559 .48526 .53255 Metetra
.668 .747 .909 r
.48526 .53255 .48832 .53559 .49379 .53385 .49074 .53079 Metetra
.667 .746 .909 r
.49074 .53079 .49379 .53385 .49927 .53213 .49623 .52904 Metetra
.666 .744 .909 r
.49623 .52904 .49927 .53213 .50477 .53041 .50173 .5273 Metetra
.665 .744 .908 r
.50173 .5273 .50477 .53041 .51027 .52869 .50724 .52557 Metetra
.665 .743 .908 r
.50724 .52557 .51027 .52869 .51579 .52698 .51277 .52385 Metetra
.665 .743 .908 r
.51277 .52385 .51579 .52698 .52131 .52527 .5183 .52213 Metetra
.664 .742 .908 r
.5183 .52213 .52131 .52527 .52685 .52355 .52385 .5204 Metetra
.664 .742 .908 r
.52385 .5204 .52685 .52355 .5324 .52184 .5294 .51868 Metetra
.664 .742 .908 r
.5294 .51868 .5324 .52184 .53796 .52012 .53497 .51696 Metetra
.664 .742 .908 r
.53497 .51696 .53796 .52012 .54353 .5184 .54055 .51523 Metetra
.664 .742 .908 r
.54055 .51523 .54353 .5184 .54911 .51668 .54614 .5135 Metetra
.664 .741 .908 r
.54614 .5135 .54911 .51668 .55471 .51496 .55174 .51177 Metetra
.664 .741 .908 r
.55174 .51177 .55471 .51496 .56031 .51323 .55735 .51004 Metetra
.664 .741 .908 r
.55735 .51004 .56031 .51323 .56593 .5115 .56298 .5083 Metetra
.664 .741 .908 r
.56298 .5083 .56593 .5115 .57155 .50977 .56861 .50656 Metetra
.664 .741 .908 r
.56861 .50656 .57155 .50977 .57719 .50803 .57426 .50481 Metetra
.664 .741 .908 r
.57426 .50481 .57719 .50803 .58284 .50629 .57992 .50307 Metetra
.664 .741 .908 r
.57992 .50307 .58284 .50629 .58851 .50455 .58559 .50132 Metetra
.664 .741 .908 r
.58559 .50132 .58851 .50455 .59418 .5028 .59127 .49956 Metetra
.664 .741 .908 r
.59127 .49956 .59418 .5028 .59987 .50105 .59696 .49781 Metetra
.664 .741 .908 r
.59696 .49781 .59987 .50105 .60556 .49929 .60267 .49605 Metetra
.664 .741 .908 r
.60267 .49605 .60556 .49929 .61127 .49754 .60838 .49428 Metetra
.664 .741 .908 r
.60838 .49428 .61127 .49754 .61699 .49577 .61411 .49251 Metetra
.664 .741 .908 r
.61411 .49251 .61699 .49577 .62272 .49401 .61985 .49074 Metetra
.664 .741 .908 r
.61985 .49074 .62272 .49401 .62847 .49224 .6256 .48896 Metetra
.664 .741 .908 r
.6256 .48896 .62847 .49224 .63422 .49047 .63137 .48719 Metetra
.664 .741 .908 r
.63137 .48719 .63422 .49047 .63999 .48869 .63714 .4854 Metetra
.664 .741 .908 r
.63714 .4854 .63999 .48869 .64577 .48691 .64293 .48362 Metetra
.664 .741 .908 r
.64293 .48362 .64577 .48691 .65156 .48513 .64873 .48183 Metetra
.664 .741 .908 r
.64873 .48183 .65156 .48513 .65737 .48334 .65454 .48003 Metetra
.664 .741 .908 r
.65454 .48003 .65737 .48334 .66318 .48155 .66036 .47824 Metetra
.664 .741 .908 r
.66036 .47824 .66318 .48155 .66901 .47976 .6662 .47643 Metetra
.664 .741 .908 r
.6662 .47643 .66901 .47976 .67485 .47796 .67205 .47463 Metetra
.664 .741 .908 r
.67205 .47463 .67485 .47796 .6807 .47616 .67791 .47282 Metetra
.664 .741 .908 r
.67791 .47282 .6807 .47616 .68656 .47435 .68378 .47101 Metetra
.664 .741 .908 r
.68378 .47101 .68656 .47435 .69244 .47254 .68966 .46919 Metetra
.664 .741 .908 r
.68966 .46919 .69244 .47254 .69833 .47073 .69556 .46737 Metetra
.664 .741 .908 r
.69556 .46737 .69833 .47073 .70423 .46891 .70147 .46555 Metetra
.664 .741 .908 r
.70147 .46555 .70423 .46891 .71014 .46709 .70739 .46372 Metetra
.663 .741 .908 r
.70739 .46372 .71014 .46709 .71606 .46527 .71332 .46189 Metetra
.663 .741 .908 r
.71332 .46189 .71606 .46527 .722 .46344 .71927 .46006 Metetra
.663 .741 .908 r
.71927 .46006 .722 .46344 .72795 .46161 .72523 .45822 Metetra
.663 .741 .908 r
.72523 .45822 .72795 .46161 .73391 .45978 .7312 .45638 Metetra
.663 .741 .908 r
.7312 .45638 .73391 .45978 .73989 .45794 .73718 .45453 Metetra
.663 .741 .908 r
.73718 .45453 .73989 .45794 .74587 .4561 .74318 .45269 Metetra
.663 .741 .908 r
.74318 .45269 .74587 .4561 .75187 .45425 .74918 .45084 Metetra
.663 .741 .908 r
.74918 .45084 .75187 .45425 .75789 .45241 .75521 .44899 Metetra
.663 .742 .908 r
.75521 .44899 .75789 .45241 .76391 .45056 .76124 .44714 Metetra
.663 .742 .909 r
.76124 .44714 .76391 .45056 .76995 .44871 .76729 .44528 Metetra
.662 .742 .909 r
.76729 .44528 .76995 .44871 .776 .44686 .77335 .44343 Metetra
.662 .742 .909 r
.77335 .44343 .776 .44686 .78207 .44501 .77942 .44158 Metetra
.662 .742 .91 r
.77942 .44158 .78207 .44501 .78814 .44317 .78551 .43973 Metetra
.661 .742 .91 r
.78551 .43973 .78814 .44317 .79423 .44132 .79161 .43789 Metetra
.66 .742 .911 r
.79161 .43789 .79423 .44132 .80034 .43948 .79773 .43605 Metetra
.659 .743 .912 r
.79773 .43605 .80034 .43948 .80646 .43765 .80385 .43422 Metetra
.658 .743 .913 r
.80385 .43422 .80646 .43765 .81259 .43583 .81 .43241 Metetra
.657 .744 .914 r
.81 .43241 .81259 .43583 .81874 .43401 .81616 .43061 Metetra
.656 .744 .915 r
.81616 .43061 .81874 .43401 .8249 .43222 .82233 .42883 Metetra
.654 .745 .917 r
.82233 .42883 .8249 .43222 .83108 .43044 .82852 .42707 Metetra
.652 .746 .919 r
.82852 .42707 .83108 .43044 .83728 .42868 .83473 .42533 Metetra
.649 .747 .921 r
.83473 .42533 .83728 .42868 .84349 .42695 .84095 .42363 Metetra
.647 .748 .924 r
.84095 .42363 .84349 .42695 .84972 .42524 .8472 .42196 Metetra
.644 .75 .926 r
.8472 .42196 .84972 .42524 .85596 .42357 .85346 .42032 Metetra
.64 .752 .929 r
.85346 .42032 .85596 .42357 .86223 .42193 .85974 .41872 Metetra
.637 .753 .932 r
.85974 .41872 .86223 .42193 .86851 .42032 .86603 .41715 Metetra
.635 .755 .935 r
.86603 .41715 .86851 .42032 .87481 .41874 .87235 .4156 Metetra
.632 .757 .938 r
.87235 .4156 .87481 .41874 .88113 .41719 .87868 .41408 Metetra
.63 .759 .94 r
.87868 .41408 .88113 .41719 .88746 .41566 .88503 .41257 Metetra
.63 .761 .941 r
.88503 .41257 .88746 .41566 .89382 .41414 .8914 .41106 Metetra
.63 .762 .942 r
.8914 .41106 .89382 .41414 .90019 .41262 .89778 .40954 Metetra
.632 .763 .942 r
.89778 .40954 .90019 .41262 .90657 .41109 .90417 .40798 Metetra
.636 .764 .94 r
.90417 .40798 .90657 .41109 .91297 .40952 .91058 .40638 Metetra
.64 .763 .938 r
.91058 .40638 .91297 .40952 .91937 .40791 .91699 .40472 Metetra
.646 .762 .934 r
.91699 .40472 .91937 .40791 .92579 .40625 .9234 .40298 Metetra
.652 .761 .929 r
.9234 .40298 .92579 .40625 .93221 .40451 .92983 .40117 Metetra
.657 .758 .924 r
.92983 .40117 .93221 .40451 .93864 .40269 .93626 .39926 Metetra
.663 .755 .919 r
.93626 .39926 .93864 .40269 .94507 .4008 .94269 .39728 Metetra
.625 .703 .902 r
.36394 .57211 .36714 .57554 .37237 .57442 .36918 .57104 Metetra
.626 .707 .904 r
.36918 .57104 .37237 .57442 .37762 .57321 .37443 .56994 Metetra
.631 .716 .908 r
.37443 .56994 .37762 .57321 .38289 .57186 .37969 .56876 Metetra
.641 .729 .913 r
.37969 .56876 .38289 .57186 .38817 .57034 .38497 .56744 Metetra
.653 .746 .918 r
.38497 .56744 .38817 .57034 .39347 .56863 .39027 .56594 Metetra
.667 .765 .923 r
.39027 .56594 .39347 .56863 .39879 .56671 .39559 .56423 Metetra
.681 .783 .927 r
.39559 .56423 .39879 .56671 .40413 .56462 .40093 .56231 Metetra
.695 .798 .929 r
.40093 .56231 .40413 .56462 .40948 .56237 .40628 .5602 Metetra
.705 .81 .93 r
.40628 .5602 .40948 .56237 .41484 .56002 .41165 .55793 Metetra
.713 .818 .93 r
.41165 .55793 .41484 .56002 .42021 .55762 .41702 .55554 Metetra
.717 .82 .929 r
.41702 .55554 .42021 .55762 .42559 .55519 .42241 .55309 Metetra
.718 .819 .928 r
.42241 .55309 .42559 .55519 .43098 .55279 .42781 .55063 Metetra
.716 .814 .926 r
.42781 .55063 .43098 .55279 .43637 .55045 .43322 .54818 Metetra
.712 .807 .924 r
.43322 .54818 .43637 .55045 .44177 .54818 .43863 .5458 Metetra
.706 .798 .922 r
.43863 .5458 .44177 .54818 .44718 .54599 .44405 .54349 Metetra
.7 .79 .92 r
.44405 .54349 .44718 .54599 .45259 .54388 .44947 .54127 Metetra
.694 .781 .918 r
.44947 .54127 .45259 .54388 .45802 .54185 .45491 .53914 Metetra
.688 .773 .916 r
.45491 .53914 .45802 .54185 .46345 .53989 .46035 .53709 Metetra
.683 .766 .914 r
.46035 .53709 .46345 .53989 .46889 .53799 .46579 .53512 Metetra
.679 .76 .913 r
.46579 .53512 .46889 .53799 .47433 .53614 .47125 .53321 Metetra
.675 .756 .912 r
.47125 .53321 .47433 .53614 .47979 .53433 .47672 .53134 Metetra
.672 .752 .911 r
.47672 .53134 .47979 .53433 .48526 .53255 .4822 .52952 Metetra
.67 .749 .91 r
.4822 .52952 .48526 .53255 .49074 .53079 .48768 .52772 Metetra
.668 .747 .909 r
.48768 .52772 .49074 .53079 .49623 .52904 .49318 .52595 Metetra
.667 .746 .909 r
.49318 .52595 .49623 .52904 .50173 .5273 .49869 .5242 Metetra
.666 .744 .909 r
.49869 .5242 .50173 .5273 .50724 .52557 .50421 .52245 Metetra
.665 .744 .908 r
.50421 .52245 .50724 .52557 .51277 .52385 .50974 .52071 Metetra
.665 .743 .908 r
.50974 .52071 .51277 .52385 .5183 .52213 .51528 .51898 Metetra
.665 .742 .908 r
.51528 .51898 .5183 .52213 .52385 .5204 .52083 .51724 Metetra
.664 .742 .908 r
.52083 .51724 .52385 .5204 .5294 .51868 .52639 .51551 Metetra
.664 .742 .908 r
.52639 .51551 .5294 .51868 .53497 .51696 .53197 .51378 Metetra
.664 .742 .908 r
.53197 .51378 .53497 .51696 .54055 .51523 .53756 .51204 Metetra
.664 .742 .908 r
.53756 .51204 .54055 .51523 .54614 .5135 .54315 .51031 Metetra
.664 .742 .908 r
.54315 .51031 .54614 .5135 .55174 .51177 .54876 .50857 Metetra
.664 .741 .908 r
.54876 .50857 .55174 .51177 .55735 .51004 .55438 .50683 Metetra
.664 .741 .908 r
.55438 .50683 .55735 .51004 .56298 .5083 .56001 .50509 Metetra
.664 .741 .908 r
.56001 .50509 .56298 .5083 .56861 .50656 .56566 .50334 Metetra
.664 .741 .908 r
.56566 .50334 .56861 .50656 .57426 .50481 .57131 .50159 Metetra
.664 .741 .908 r
.57131 .50159 .57426 .50481 .57992 .50307 .57698 .49983 Metetra
.664 .741 .908 r
.57698 .49983 .57992 .50307 .58559 .50132 .58265 .49808 Metetra
.664 .741 .908 r
.58265 .49808 .58559 .50132 .59127 .49956 .58834 .49632 Metetra
.664 .741 .908 r
.58834 .49632 .59127 .49956 .59696 .49781 .59404 .49455 Metetra
.664 .741 .908 r
.59404 .49455 .59696 .49781 .60267 .49605 .59976 .49278 Metetra
.664 .741 .908 r
.59976 .49278 .60267 .49605 .60838 .49428 .60548 .49101 Metetra
.664 .741 .908 r
.60548 .49101 .60838 .49428 .61411 .49251 .61122 .48924 Metetra
.664 .741 .908 r
.61122 .48924 .61411 .49251 .61985 .49074 .61697 .48746 Metetra
.664 .741 .908 r
.61697 .48746 .61985 .49074 .6256 .48896 .62273 .48568 Metetra
.664 .741 .908 r
.62273 .48568 .6256 .48896 .63137 .48719 .6285 .48389 Metetra
.664 .741 .908 r
.6285 .48389 .63137 .48719 .63714 .4854 .63428 .4821 Metetra
.664 .741 .908 r
.63428 .4821 .63714 .4854 .64293 .48362 .64008 .48031 Metetra
.664 .741 .908 r
.64008 .48031 .64293 .48362 .64873 .48183 .64588 .47851 Metetra
.664 .741 .908 r
.64588 .47851 .64873 .48183 .65454 .48003 .6517 .47671 Metetra
.664 .741 .908 r
.6517 .47671 .65454 .48003 .66036 .47824 .65753 .47491 Metetra
.664 .741 .908 r
.65753 .47491 .66036 .47824 .6662 .47643 .66338 .4731 Metetra
.664 .741 .908 r
.66338 .4731 .6662 .47643 .67205 .47463 .66923 .47129 Metetra
.664 .741 .908 r
.66923 .47129 .67205 .47463 .67791 .47282 .6751 .46947 Metetra
.664 .741 .908 r
.6751 .46947 .67791 .47282 .68378 .47101 .68098 .46765 Metetra
.664 .741 .908 r
.68098 .46765 .68378 .47101 .68966 .46919 .68688 .46583 Metetra
.664 .741 .908 r
.68688 .46583 .68966 .46919 .69556 .46737 .69278 .464 Metetra
.664 .741 .908 r
.69278 .464 .69556 .46737 .70147 .46555 .6987 .46217 Metetra
.663 .741 .908 r
.6987 .46217 .70147 .46555 .70739 .46372 .70463 .46034 Metetra
.663 .741 .908 r
.70463 .46034 .70739 .46372 .71332 .46189 .71057 .4585 Metetra
.663 .741 .908 r
.71057 .4585 .71332 .46189 .71927 .46006 .71652 .45666 Metetra
.663 .741 .908 r
.71652 .45666 .71927 .46006 .72523 .45822 .72249 .45482 Metetra
.663 .741 .908 r
.72249 .45482 .72523 .45822 .7312 .45638 .72847 .45297 Metetra
.663 .741 .908 r
.72847 .45297 .7312 .45638 .73718 .45453 .73446 .45112 Metetra
.663 .741 .908 r
.73446 .45112 .73718 .45453 .74318 .45269 .74047 .44927 Metetra
.663 .741 .908 r
.74047 .44927 .74318 .45269 .74918 .45084 .74648 .44741 Metetra
.663 .742 .908 r
.74648 .44741 .74918 .45084 .75521 .44899 .75251 .44556 Metetra
.663 .742 .909 r
.75251 .44556 .75521 .44899 .76124 .44714 .75856 .4437 Metetra
.662 .742 .909 r
.75856 .4437 .76124 .44714 .76729 .44528 .76462 .44184 Metetra
.662 .742 .909 r
.76462 .44184 .76729 .44528 .77335 .44343 .77069 .43999 Metetra
.662 .742 .91 r
.77069 .43999 .77335 .44343 .77942 .44158 .77677 .43814 Metetra
.661 .742 .91 r
.77677 .43814 .77942 .44158 .78551 .43973 .78287 .43629 Metetra
.66 .742 .911 r
.78287 .43629 .78551 .43973 .79161 .43789 .78898 .43445 Metetra
.659 .743 .912 r
.78898 .43445 .79161 .43789 .79773 .43605 .7951 .43262 Metetra
.658 .743 .913 r
.7951 .43262 .79773 .43605 .80385 .43422 .80124 .4308 Metetra
.657 .744 .914 r
.80124 .4308 .80385 .43422 .81 .43241 .8074 .429 Metetra
.656 .744 .915 r
.8074 .429 .81 .43241 .81616 .43061 .81357 .42721 Metetra
.654 .745 .917 r
.81357 .42721 .81616 .43061 .82233 .42883 .81975 .42545 Metetra
.651 .746 .919 r
.81975 .42545 .82233 .42883 .82852 .42707 .82596 .42372 Metetra
.649 .747 .921 r
.82596 .42372 .82852 .42707 .83473 .42533 .83218 .42202 Metetra
.646 .749 .924 r
.83218 .42202 .83473 .42533 .84095 .42363 .83842 .42035 Metetra
.643 .75 .927 r
.83842 .42035 .84095 .42363 .8472 .42196 .84467 .41871 Metetra
.64 .752 .93 r
.84467 .41871 .8472 .42196 .85346 .42032 .85095 .41711 Metetra
.637 .754 .933 r
.85095 .41711 .85346 .42032 .85974 .41872 .85724 .41555 Metetra
.634 .756 .936 r
.85724 .41555 .85974 .41872 .86603 .41715 .86355 .41401 Metetra
.631 .758 .939 r
.86355 .41401 .86603 .41715 .87235 .4156 .86988 .4125 Metetra
.629 .76 .941 r
.86988 .4125 .87235 .4156 .87868 .41408 .87623 .411 Metetra
.628 .761 .942 r
.87623 .411 .87868 .41408 .88503 .41257 .88259 .4095 Metetra
.629 .763 .943 r
.88259 .4095 .88503 .41257 .8914 .41106 .88897 .40799 Metetra
.631 .764 .943 r
.88897 .40799 .8914 .41106 .89778 .40954 .89536 .40645 Metetra
.634 .765 .941 r
.89536 .40645 .89778 .40954 .90417 .40798 .90176 .40485 Metetra
.639 .764 .939 r
.90176 .40485 .90417 .40798 .91058 .40638 .90817 .40319 Metetra
.645 .763 .935 r
.90817 .40319 .91058 .40638 .91699 .40472 .91458 .40146 Metetra
.651 .761 .93 r
.91458 .40146 .91699 .40472 .9234 .40298 .921 .39964 Metetra
.658 .759 .925 r
.921 .39964 .9234 .40298 .92983 .40117 .92743 .39773 Metetra
.663 .756 .919 r
.92743 .39773 .92983 .40117 .93626 .39926 .93385 .39574 Metetra
.668 .752 .914 r
.93385 .39574 .93626 .39926 .94269 .39728 .94029 .39367 Metetra
.626 .702 .9 r
.36074 .56864 .36394 .57211 .36918 .57104 .36598 .56755 Metetra
.623 .701 .901 r
.36598 .56755 .36918 .57104 .37443 .56994 .37123 .5665 Metetra
.624 .704 .903 r
.37123 .5665 .37443 .56994 .37969 .56876 .37649 .56543 Metetra
.629 .713 .907 r
.37649 .56543 .37969 .56876 .38497 .56744 .38177 .56428 Metetra
.638 .727 .912 r
.38177 .56428 .38497 .56744 .39027 .56594 .38707 .56299 Metetra
.651 .744 .918 r
.38707 .56299 .39027 .56594 .39559 .56423 .39238 .56151 Metetra
.666 .764 .923 r
.39238 .56151 .39559 .56423 .40093 .56231 .39772 .55982 Metetra
.681 .783 .928 r
.39772 .55982 .40093 .56231 .40628 .5602 .40307 .5579 Metetra
.695 .8 .93 r
.40307 .5579 .40628 .5602 .41165 .55793 .40844 .55577 Metetra
.706 .813 .931 r
.40844 .55577 .41165 .55793 .41702 .55554 .41383 .55347 Metetra
.714 .821 .931 r
.41383 .55347 .41702 .55554 .42241 .55309 .41922 .55105 Metetra
.719 .824 .93 r
.41922 .55105 .42241 .55309 .42781 .55063 .42463 .54856 Metetra
.72 .823 .929 r
.42463 .54856 .42781 .55063 .43322 .54818 .43005 .54604 Metetra
.718 .817 .927 r
.43005 .54604 .43322 .54818 .43863 .5458 .43547 .54356 Metetra
.714 .81 .925 r
.43547 .54356 .43863 .5458 .44405 .54349 .4409 .54113 Metetra
.708 .801 .923 r
.4409 .54113 .44405 .54349 .44947 .54127 .44634 .53879 Metetra
.702 .791 .92 r
.44634 .53879 .44947 .54127 .45491 .53914 .45178 .53654 Metetra
.695 .782 .918 r
.45178 .53654 .45491 .53914 .46035 .53709 .45723 .53438 Metetra
.689 .774 .916 r
.45723 .53438 .46035 .53709 .46579 .53512 .46269 .53231 Metetra
.683 .767 .914 r
.46269 .53231 .46579 .53512 .47125 .53321 .46816 .53032 Metetra
.679 .761 .913 r
.46816 .53032 .47125 .53321 .47672 .53134 .47363 .52839 Metetra
.675 .756 .912 r
.47363 .52839 .47672 .53134 .4822 .52952 .47912 .52651 Metetra
.672 .752 .911 r
.47912 .52651 .4822 .52952 .48768 .52772 .48461 .52468 Metetra
.67 .749 .91 r
.48461 .52468 .48768 .52772 .49318 .52595 .49012 .52287 Metetra
.668 .747 .909 r
.49012 .52287 .49318 .52595 .49869 .5242 .49563 .52109 Metetra
.667 .746 .909 r
.49563 .52109 .49869 .5242 .50421 .52245 .50116 .51933 Metetra
.666 .744 .909 r
.50116 .51933 .50421 .52245 .50974 .52071 .5067 .51757 Metetra
.665 .744 .908 r
.5067 .51757 .50974 .52071 .51528 .51898 .51225 .51582 Metetra
.665 .743 .908 r
.51225 .51582 .51528 .51898 .52083 .51724 .51781 .51408 Metetra
.665 .742 .908 r
.51781 .51408 .52083 .51724 .52639 .51551 .52338 .51233 Metetra
.664 .742 .908 r
.52338 .51233 .52639 .51551 .53197 .51378 .52896 .51059 Metetra
.664 .742 .908 r
.52896 .51059 .53197 .51378 .53756 .51204 .53455 .50885 Metetra
.664 .742 .908 r
.53455 .50885 .53756 .51204 .54315 .51031 .54016 .50711 Metetra
.664 .742 .908 r
.54016 .50711 .54315 .51031 .54876 .50857 .54577 .50536 Metetra
.664 .742 .908 r
.54577 .50536 .54876 .50857 .55438 .50683 .5514 .50361 Metetra
.664 .741 .908 r
.5514 .50361 .55438 .50683 .56001 .50509 .55704 .50186 Metetra
.664 .741 .908 r
.55704 .50186 .56001 .50509 .56566 .50334 .56269 .50011 Metetra
.664 .741 .908 r
.56269 .50011 .56566 .50334 .57131 .50159 .56835 .49835 Metetra
.664 .741 .908 r
.56835 .49835 .57131 .50159 .57698 .49983 .57403 .49659 Metetra
.664 .741 .908 r
.57403 .49659 .57698 .49983 .58265 .49808 .57971 .49482 Metetra
.664 .741 .908 r
.57971 .49482 .58265 .49808 .58834 .49632 .58541 .49306 Metetra
.664 .741 .908 r
.58541 .49306 .58834 .49632 .59404 .49455 .59112 .49129 Metetra
.664 .741 .908 r
.59112 .49129 .59404 .49455 .59976 .49278 .59684 .48951 Metetra
.664 .741 .908 r
.59684 .48951 .59976 .49278 .60548 .49101 .60257 .48773 Metetra
.664 .741 .908 r
.60257 .48773 .60548 .49101 .61122 .48924 .60831 .48595 Metetra
.664 .741 .908 r
.60831 .48595 .61122 .48924 .61697 .48746 .61407 .48417 Metetra
.664 .741 .908 r
.61407 .48417 .61697 .48746 .62273 .48568 .61984 .48238 Metetra
.664 .741 .908 r
.61984 .48238 .62273 .48568 .6285 .48389 .62562 .48059 Metetra
.664 .741 .908 r
.62562 .48059 .6285 .48389 .63428 .4821 .63141 .47879 Metetra
.664 .741 .908 r
.63141 .47879 .63428 .4821 .64008 .48031 .63721 .47699 Metetra
.664 .741 .908 r
.63721 .47699 .64008 .48031 .64588 .47851 .64303 .47518 Metetra
.664 .741 .908 r
.64303 .47518 .64588 .47851 .6517 .47671 .64886 .47338 Metetra
.664 .741 .908 r
.64886 .47338 .6517 .47671 .65753 .47491 .6547 .47157 Metetra
.664 .741 .908 r
.6547 .47157 .65753 .47491 .66338 .4731 .66055 .46975 Metetra
.664 .741 .908 r
.66055 .46975 .66338 .4731 .66923 .47129 .66641 .46793 Metetra
.664 .741 .908 r
.66641 .46793 .66923 .47129 .6751 .46947 .67229 .46611 Metetra
.664 .741 .908 r
.67229 .46611 .6751 .46947 .68098 .46765 .67818 .46428 Metetra
.664 .741 .908 r
.67818 .46428 .68098 .46765 .68688 .46583 .68408 .46245 Metetra
.664 .741 .908 r
.68408 .46245 .68688 .46583 .69278 .464 .68999 .46062 Metetra
.663 .741 .908 r
.68999 .46062 .69278 .464 .6987 .46217 .69592 .45878 Metetra
.663 .741 .908 r
.69592 .45878 .6987 .46217 .70463 .46034 .70185 .45694 Metetra
.663 .741 .908 r
.70185 .45694 .70463 .46034 .71057 .4585 .70781 .4551 Metetra
.663 .741 .908 r
.70781 .4551 .71057 .4585 .71652 .45666 .71377 .45325 Metetra
.663 .741 .908 r
.71377 .45325 .71652 .45666 .72249 .45482 .71974 .4514 Metetra
.663 .741 .908 r
.71974 .4514 .72249 .45482 .72847 .45297 .72573 .44955 Metetra
.663 .741 .908 r
.72573 .44955 .72847 .45297 .73446 .45112 .73173 .44769 Metetra
.663 .741 .908 r
.73173 .44769 .73446 .45112 .74047 .44927 .73775 .44583 Metetra
.663 .741 .908 r
.73775 .44583 .74047 .44927 .74648 .44741 .74377 .44397 Metetra
.663 .742 .909 r
.74377 .44397 .74648 .44741 .75251 .44556 .74981 .44211 Metetra
.662 .742 .909 r
.74981 .44211 .75251 .44556 .75856 .4437 .75587 .44025 Metetra
.662 .742 .909 r
.75587 .44025 .75856 .4437 .76462 .44184 .76193 .4384 Metetra
.662 .742 .91 r
.76193 .4384 .76462 .44184 .77069 .43999 .76801 .43654 Metetra
.661 .742 .91 r
.76801 .43654 .77069 .43999 .77677 .43814 .77411 .43469 Metetra
.66 .742 .911 r
.77411 .43469 .77677 .43814 .78287 .43629 .78021 .43285 Metetra
.659 .743 .912 r
.78021 .43285 .78287 .43629 .78898 .43445 .78633 .43101 Metetra
.658 .743 .913 r
.78633 .43101 .78898 .43445 .7951 .43262 .79247 .42919 Metetra
.657 .744 .914 r
.79247 .42919 .7951 .43262 .80124 .4308 .79862 .42739 Metetra
.655 .744 .915 r
.79862 .42739 .80124 .4308 .8074 .429 .80479 .4256 Metetra
.654 .745 .917 r
.80479 .4256 .8074 .429 .81357 .42721 .81097 .42384 Metetra
.651 .746 .919 r
.81097 .42384 .81357 .42721 .81975 .42545 .81717 .4221 Metetra
.649 .747 .922 r
.81717 .4221 .81975 .42545 .82596 .42372 .82339 .4204 Metetra
.646 .749 .924 r
.82339 .4204 .82596 .42372 .83218 .42202 .82962 .41873 Metetra
.643 .75 .927 r
.82962 .41873 .83218 .42202 .83842 .42035 .83587 .4171 Metetra
.639 .752 .93 r
.83587 .4171 .83842 .42035 .84467 .41871 .84214 .4155 Metetra
.636 .754 .934 r
.84214 .4155 .84467 .41871 .85095 .41711 .84843 .41395 Metetra
.632 .756 .937 r
.84843 .41395 .85095 .41711 .85724 .41555 .85474 .41242 Metetra
.63 .758 .94 r
.85474 .41242 .85724 .41555 .86355 .41401 .86107 .41092 Metetra
.628 .76 .942 r
.86107 .41092 .86355 .41401 .86988 .4125 .86741 .40943 Metetra
.627 .762 .944 r
.86741 .40943 .86988 .4125 .87623 .411 .87377 .40795 Metetra
.627 .764 .944 r
.87377 .40795 .87623 .411 .88259 .4095 .88015 .40645 Metetra
.63 .765 .944 r
.88015 .40645 .88259 .4095 .88897 .40799 .88653 .40491 Metetra
.633 .765 .943 r
.88653 .40491 .88897 .40799 .89536 .40645 .89293 .40333 Metetra
.638 .765 .94 r
.89293 .40333 .89536 .40645 .90176 .40485 .89934 .40167 Metetra
.645 .764 .936 r
.89934 .40167 .90176 .40485 .90817 .40319 .90575 .39994 Metetra
.651 .762 .931 r
.90575 .39994 .90817 .40319 .91458 .40146 .91216 .39812 Metetra
.658 .759 .925 r
.91216 .39812 .91458 .40146 .921 .39964 .91858 .3962 Metetra
.664 .756 .919 r
.91858 .3962 .921 .39964 .92743 .39773 .92501 .3942 Metetra
.668 .752 .913 r
.92501 .3942 .92743 .39773 .93385 .39574 .93143 .39212 Metetra
.672 .749 .908 r
.93143 .39212 .93385 .39574 .94029 .39367 .93787 .38997 Metetra
.631 .707 .901 r
.35751 .56522 .36074 .56864 .36598 .56755 .36276 .56405 Metetra
.625 .701 .9 r
.36276 .56405 .36598 .56755 .37123 .5665 .36802 .56297 Metetra
.621 .698 .9 r
.36802 .56297 .37123 .5665 .37649 .56543 .37329 .56194 Metetra
.621 .701 .902 r
.37329 .56194 .37649 .56543 .38177 .56428 .37857 .5609 Metetra
.626 .709 .906 r
.37857 .5609 .38177 .56428 .38707 .56299 .38386 .55978 Metetra
.635 .723 .911 r
.38386 .55978 .38707 .56299 .39238 .56151 .38918 .55853 Metetra
.648 .742 .918 r
.38918 .55853 .39238 .56151 .39772 .55982 .39451 .55707 Metetra
.664 .763 .924 r
.39451 .55707 .39772 .55982 .40307 .5579 .39986 .55539 Metetra
.68 .783 .928 r
.39986 .55539 .40307 .5579 .40844 .55577 .40523 .55347 Metetra
.695 .802 .931 r
.40523 .55347 .40844 .55577 .41383 .55347 .41062 .55133 Metetra
.707 .816 .932 r
.41062 .55133 .41383 .55347 .41922 .55105 .41602 .54901 Metetra
.716 .824 .932 r
.41602 .54901 .41922 .55105 .42463 .54856 .42144 .54655 Metetra
.721 .828 .931 r
.42144 .54655 .42463 .54856 .43005 .54604 .42686 .54401 Metetra
.722 .826 .93 r
.42686 .54401 .43005 .54604 .43547 .54356 .4323 .54145 Metetra
.72 .821 .928 r
.4323 .54145 .43547 .54356 .4409 .54113 .43774 .53891 Metetra
.716 .813 .926 r
.43774 .53891 .4409 .54113 .44634 .53879 .44319 .53644 Metetra
.71 .804 .923 r
.44319 .53644 .44634 .53879 .45178 .53654 .44864 .53406 Metetra
.703 .794 .921 r
.44864 .53406 .45178 .53654 .45723 .53438 .4541 .53178 Metetra
.696 .784 .919 r
.4541 .53178 .45723 .53438 .46269 .53231 .45957 .52959 Metetra
.69 .775 .916 r
.45957 .52959 .46269 .53231 .46816 .53032 .46505 .5275 Metetra
.684 .767 .915 r
.46505 .5275 .46816 .53032 .47363 .52839 .47053 .52549 Metetra
.679 .761 .913 r
.47053 .52549 .47363 .52839 .47912 .52651 .47603 .52354 Metetra
.675 .756 .912 r
.47603 .52354 .47912 .52651 .48461 .52468 .48153 .52166 Metetra
.672 .752 .911 r
.48153 .52166 .48461 .52468 .49012 .52287 .48704 .51981 Metetra
.67 .749 .91 r
.48704 .51981 .49012 .52287 .49563 .52109 .49257 .518 Metetra
.668 .747 .909 r
.49257 .518 .49563 .52109 .50116 .51933 .4981 .5162 Metetra
.667 .746 .909 r
.4981 .5162 .50116 .51933 .5067 .51757 .50365 .51443 Metetra
.666 .744 .909 r
.50365 .51443 .5067 .51757 .51225 .51582 .5092 .51266 Metetra
.665 .744 .908 r
.5092 .51266 .51225 .51582 .51781 .51408 .51477 .5109 Metetra
.665 .743 .908 r
.51477 .5109 .51781 .51408 .52338 .51233 .52035 .50915 Metetra
.665 .742 .908 r
.52035 .50915 .52338 .51233 .52896 .51059 .52594 .5074 Metetra
.664 .742 .908 r
.52594 .5074 .52896 .51059 .53455 .50885 .53154 .50565 Metetra
.664 .742 .908 r
.53154 .50565 .53455 .50885 .54016 .50711 .53715 .50389 Metetra
.664 .742 .908 r
.53715 .50389 .54016 .50711 .54577 .50536 .54277 .50214 Metetra
.664 .742 .908 r
.54277 .50214 .54577 .50536 .5514 .50361 .54841 .50038 Metetra
.664 .742 .908 r
.54841 .50038 .5514 .50361 .55704 .50186 .55405 .49862 Metetra
.664 .741 .908 r
.55405 .49862 .55704 .50186 .56269 .50011 .55971 .49686 Metetra
.664 .741 .908 r
.55971 .49686 .56269 .50011 .56835 .49835 .56538 .4951 Metetra
.664 .741 .908 r
.56538 .4951 .56835 .49835 .57403 .49659 .57106 .49333 Metetra
.664 .741 .908 r
.57106 .49333 .57403 .49659 .57971 .49482 .57676 .49156 Metetra
.664 .741 .908 r
.57676 .49156 .57971 .49482 .58541 .49306 .58246 .48979 Metetra
.664 .741 .908 r
.58246 .48979 .58541 .49306 .59112 .49129 .58818 .48801 Metetra
.664 .741 .908 r
.58818 .48801 .59112 .49129 .59684 .48951 .59391 .48623 Metetra
.664 .741 .908 r
.59391 .48623 .59684 .48951 .60257 .48773 .59965 .48444 Metetra
.664 .741 .908 r
.59965 .48444 .60257 .48773 .60831 .48595 .6054 .48265 Metetra
.664 .741 .908 r
.6054 .48265 .60831 .48595 .61407 .48417 .61116 .48086 Metetra
.664 .741 .908 r
.61116 .48086 .61407 .48417 .61984 .48238 .61694 .47907 Metetra
.664 .741 .908 r
.61694 .47907 .61984 .48238 .62562 .48059 .62273 .47727 Metetra
.664 .741 .908 r
.62273 .47727 .62562 .48059 .63141 .47879 .62853 .47546 Metetra
.664 .741 .908 r
.62853 .47546 .63141 .47879 .63721 .47699 .63434 .47366 Metetra
.664 .741 .908 r
.63434 .47366 .63721 .47699 .64303 .47518 .64016 .47184 Metetra
.664 .741 .908 r
.64016 .47184 .64303 .47518 .64886 .47338 .646 .47003 Metetra
.664 .741 .908 r
.646 .47003 .64886 .47338 .6547 .47157 .65185 .46821 Metetra
.664 .741 .908 r
.65185 .46821 .6547 .47157 .66055 .46975 .65771 .46639 Metetra
.664 .741 .908 r
.65771 .46639 .66055 .46975 .66641 .46793 .66358 .46456 Metetra
.664 .741 .908 r
.66358 .46456 .66641 .46793 .67229 .46611 .66946 .46273 Metetra
.664 .741 .908 r
.66946 .46273 .67229 .46611 .67818 .46428 .67536 .4609 Metetra
.664 .741 .908 r
.67536 .4609 .67818 .46428 .68408 .46245 .68127 .45906 Metetra
.663 .741 .908 r
.68127 .45906 .68408 .46245 .68999 .46062 .68719 .45722 Metetra
.663 .741 .908 r
.68719 .45722 .68999 .46062 .69592 .45878 .69313 .45538 Metetra
.663 .741 .908 r
.69313 .45538 .69592 .45878 .70185 .45694 .69907 .45353 Metetra
.663 .741 .908 r
.69907 .45353 .70185 .45694 .70781 .4551 .70503 .45168 Metetra
.663 .741 .908 r
.70503 .45168 .70781 .4551 .71377 .45325 .711 .44983 Metetra
.663 .741 .908 r
.711 .44983 .71377 .45325 .71974 .4514 .71699 .44797 Metetra
.663 .741 .908 r
.71699 .44797 .71974 .4514 .72573 .44955 .72298 .44611 Metetra
.663 .741 .908 r
.72298 .44611 .72573 .44955 .73173 .44769 .72899 .44425 Metetra
.663 .742 .908 r
.72899 .44425 .73173 .44769 .73775 .44583 .73502 .44239 Metetra
.663 .742 .909 r
.73502 .44239 .73775 .44583 .74377 .44397 .74105 .44053 Metetra
.662 .742 .909 r
.74105 .44053 .74377 .44397 .74981 .44211 .7471 .43866 Metetra
.662 .742 .909 r
.7471 .43866 .74981 .44211 .75587 .44025 .75316 .4368 Metetra
.662 .742 .91 r
.75316 .4368 .75587 .44025 .76193 .4384 .75924 .43494 Metetra
.661 .742 .91 r
.75924 .43494 .76193 .4384 .76801 .43654 .76533 .43309 Metetra
.66 .742 .911 r
.76533 .43309 .76801 .43654 .77411 .43469 .77143 .43124 Metetra
.659 .743 .912 r
.77143 .43124 .77411 .43469 .78021 .43285 .77755 .4294 Metetra
.658 .743 .913 r
.77755 .4294 .78021 .43285 .78633 .43101 .78368 .42758 Metetra
.657 .744 .914 r
.78368 .42758 .78633 .43101 .79247 .42919 .78983 .42577 Metetra
.655 .744 .915 r
.78983 .42577 .79247 .42919 .79862 .42739 .79599 .42398 Metetra
.653 .745 .917 r
.79599 .42398 .79862 .42739 .80479 .4256 .80217 .42222 Metetra
.651 .746 .919 r
.80217 .42222 .80479 .4256 .81097 .42384 .80836 .42048 Metetra
.648 .747 .922 r
.80836 .42048 .81097 .42384 .81717 .4221 .81458 .41878 Metetra
.645 .749 .924 r
.81458 .41878 .81717 .4221 .82339 .4204 .82081 .41711 Metetra
.642 .75 .928 r
.82081 .41711 .82339 .4204 .82962 .41873 .82706 .41548 Metetra
.638 .752 .931 r
.82706 .41548 .82962 .41873 .83587 .4171 .83332 .41389 Metetra
.635 .754 .934 r
.83332 .41389 .83587 .4171 .84214 .4155 .83961 .41234 Metetra
.631 .756 .938 r
.83961 .41234 .84214 .4155 .84843 .41395 .84591 .41083 Metetra
.628 .759 .941 r
.84591 .41083 .84843 .41395 .85474 .41242 .85224 .40934 Metetra
.626 .761 .943 r
.85224 .40934 .85474 .41242 .86107 .41092 .85858 .40786 Metetra
.625 .763 .945 r
.85858 .40786 .86107 .41092 .86741 .40943 .86494 .40639 Metetra
.626 .765 .946 r
.86494 .40639 .86741 .40943 .87377 .40795 .87131 .4049 Metetra
.628 .766 .945 r
.87131 .4049 .87377 .40795 .88015 .40645 .87769 .40338 Metetra
.632 .766 .944 r
.87769 .40338 .88015 .40645 .88653 .40491 .88409 .4018 Metetra
.638 .766 .941 r
.88409 .4018 .88653 .40491 .89293 .40333 .89049 .40016 Metetra
.644 .765 .937 r
.89049 .40016 .89293 .40333 .89934 .40167 .89689 .39843 Metetra
.651 .763 .931 r
.89689 .39843 .89934 .40167 .90575 .39994 .90331 .3966 Metetra
.658 .76 .925 r
.90331 .3966 .90575 .39994 .91216 .39812 .90972 .39468 Metetra
.664 .756 .919 r
.90972 .39468 .91216 .39812 .91858 .3962 .91614 .39266 Metetra
.669 .753 .913 r
.91614 .39266 .91858 .3962 .92501 .3942 .92256 .39057 Metetra
.673 .749 .908 r
.92256 .39057 .92501 .3942 .93143 .39212 .92899 .38841 Metetra
.675 .745 .903 r
.92899 .38841 .93143 .39212 .93787 .38997 .93543 .3862 Metetra
.64 .717 .904 r
.35428 .56191 .35751 .56522 .36276 .56405 .35954 .56061 Metetra
.631 .707 .901 r
.35954 .56061 .36276 .56405 .36802 .56297 .3648 .55943 Metetra
.624 .699 .899 r
.3648 .55943 .36802 .56297 .37329 .56194 .37008 .55836 Metetra
.619 .695 .899 r
.37008 .55836 .37329 .56194 .37857 .5609 .37536 .55735 Metetra
.618 .697 .901 r
.37536 .55735 .37857 .5609 .38386 .55978 .38066 .55634 Metetra
.623 .706 .905 r
.38066 .55634 .38386 .55978 .38918 .55853 .38597 .55526 Metetra
.632 .72 .911 r
.38597 .55526 .38918 .55853 .39451 .55707 .3913 .55404 Metetra
.645 .739 .917 r
.3913 .55404 .39451 .55707 .39986 .55539 .39664 .55262 Metetra
.662 .761 .924 r
.39664 .55262 .39986 .55539 .40523 .55347 .40201 .55095 Metetra
.679 .783 .929 r
.40201 .55095 .40523 .55347 .41062 .55133 .4074 .54904 Metetra
.695 .803 .932 r
.4074 .54904 .41062 .55133 .41602 .54901 .41281 .54689 Metetra
.709 .818 .933 r
.41281 .54689 .41602 .54901 .42144 .54655 .41823 .54453 Metetra
.718 .828 .933 r
.41823 .54453 .42144 .54655 .42686 .54401 .42366 .54203 Metetra
.723 .832 .932 r
.42366 .54203 .42686 .54401 .4323 .54145 .42911 .53945 Metetra
.725 .831 .93 r
.42911 .53945 .4323 .54145 .43774 .53891 .43456 .53683 Metetra
.723 .825 .928 r
.43456 .53683 .43774 .53891 .44319 .53644 .44002 .53425 Metetra
.718 .817 .926 r
.44002 .53425 .44319 .53644 .44864 .53406 .44549 .53173 Metetra
.712 .807 .924 r
.44549 .53173 .44864 .53406 .4541 .53178 .45096 .52931 Metetra
.705 .796 .921 r
.45096 .52931 .4541 .53178 .45957 .52959 .45644 .52699 Metetra
.697 .786 .919 r
.45644 .52699 .45957 .52959 .46505 .5275 .46193 .52478 Metetra
.691 .776 .917 r
.46193 .52478 .46505 .5275 .47053 .52549 .46742 .52266 Metetra
.685 .768 .915 r
.46742 .52266 .47053 .52549 .47603 .52354 .47292 .52063 Metetra
.68 .762 .913 r
.47292 .52063 .47603 .52354 .48153 .52166 .47843 .51867 Metetra
.676 .756 .912 r
.47843 .51867 .48153 .52166 .48704 .51981 .48396 .51677 Metetra
.672 .752 .911 r
.48396 .51677 .48704 .51981 .49257 .518 .48949 .51491 Metetra
.67 .749 .91 r
.48949 .51491 .49257 .518 .4981 .5162 .49503 .51309 Metetra
.668 .747 .909 r
.49503 .51309 .4981 .5162 .50365 .51443 .50058 .51129 Metetra
.667 .745 .909 r
.50058 .51129 .50365 .51443 .5092 .51266 .50614 .5095 Metetra
.666 .744 .909 r
.50614 .5095 .5092 .51266 .51477 .5109 .51172 .50773 Metetra
.665 .743 .908 r
.51172 .50773 .51477 .5109 .52035 .50915 .5173 .50596 Metetra
.665 .743 .908 r
.5173 .50596 .52035 .50915 .52594 .5074 .5229 .50419 Metetra
.664 .742 .908 r
.5229 .50419 .52594 .5074 .53154 .50565 .52851 .50243 Metetra
.664 .742 .908 r
.52851 .50243 .53154 .50565 .53715 .50389 .53413 .50067 Metetra
.664 .742 .908 r
.53413 .50067 .53715 .50389 .54277 .50214 .53976 .49891 Metetra
.664 .742 .908 r
.53976 .49891 .54277 .50214 .54841 .50038 .5454 .49714 Metetra
.664 .742 .908 r
.5454 .49714 .54841 .50038 .55405 .49862 .55106 .49538 Metetra
.664 .742 .908 r
.55106 .49538 .55405 .49862 .55971 .49686 .55672 .49361 Metetra
.664 .741 .908 r
.55672 .49361 .55971 .49686 .56538 .4951 .5624 .49184 Metetra
.664 .741 .908 r
.5624 .49184 .56538 .4951 .57106 .49333 .56809 .49006 Metetra
.664 .741 .908 r
.56809 .49006 .57106 .49333 .57676 .49156 .57379 .48828 Metetra
.664 .741 .908 r
.57379 .48828 .57676 .49156 .58246 .48979 .5795 .4865 Metetra
.664 .741 .908 r
.5795 .4865 .58246 .48979 .58818 .48801 .58523 .48472 Metetra
.664 .741 .908 r
.58523 .48472 .58818 .48801 .59391 .48623 .59096 .48293 Metetra
.664 .741 .908 r
.59096 .48293 .59391 .48623 .59965 .48444 .59671 .48114 Metetra
.664 .741 .908 r
.59671 .48114 .59965 .48444 .6054 .48265 .60247 .47934 Metetra
.664 .741 .908 r
.60247 .47934 .6054 .48265 .61116 .48086 .60824 .47754 Metetra
.664 .741 .908 r
.60824 .47754 .61116 .48086 .61694 .47907 .61403 .47574 Metetra
.664 .741 .908 r
.61403 .47574 .61694 .47907 .62273 .47727 .61982 .47393 Metetra
.664 .741 .908 r
.61982 .47393 .62273 .47727 .62853 .47546 .62563 .47212 Metetra
.664 .741 .908 r
.62563 .47212 .62853 .47546 .63434 .47366 .63145 .47031 Metetra
.664 .741 .908 r
.63145 .47031 .63434 .47366 .64016 .47184 .63728 .46849 Metetra
.664 .741 .908 r
.63728 .46849 .64016 .47184 .646 .47003 .64313 .46667 Metetra
.664 .741 .908 r
.64313 .46667 .646 .47003 .65185 .46821 .64898 .46485 Metetra
.664 .741 .908 r
.64898 .46485 .65185 .46821 .65771 .46639 .65485 .46302 Metetra
.664 .741 .908 r
.65485 .46302 .65771 .46639 .66358 .46456 .66073 .46118 Metetra
.664 .741 .908 r
.66073 .46118 .66358 .46456 .66946 .46273 .66663 .45935 Metetra
.664 .741 .908 r
.66663 .45935 .66946 .46273 .67536 .4609 .67253 .45751 Metetra
.664 .741 .908 r
.67253 .45751 .67536 .4609 .68127 .45906 .67845 .45566 Metetra
.663 .741 .908 r
.67845 .45566 .68127 .45906 .68719 .45722 .68438 .45382 Metetra
.663 .741 .908 r
.68438 .45382 .68719 .45722 .69313 .45538 .69032 .45197 Metetra
.663 .741 .908 r
.69032 .45197 .69313 .45538 .69907 .45353 .69628 .45011 Metetra
.663 .741 .908 r
.69628 .45011 .69907 .45353 .70503 .45168 .70225 .44825 Metetra
.663 .741 .908 r
.70225 .44825 .70503 .45168 .711 .44983 .70823 .44639 Metetra
.663 .741 .908 r
.70823 .44639 .711 .44983 .71699 .44797 .71422 .44453 Metetra
.663 .741 .908 r
.71422 .44453 .71699 .44797 .72298 .44611 .72023 .44267 Metetra
.663 .741 .908 r
.72023 .44267 .72298 .44611 .72899 .44425 .72625 .4408 Metetra
.663 .742 .909 r
.72625 .4408 .72899 .44425 .73502 .44239 .73228 .43893 Metetra
.662 .742 .909 r
.73228 .43893 .73502 .44239 .74105 .44053 .73832 .43707 Metetra
.662 .742 .909 r
.73832 .43707 .74105 .44053 .7471 .43866 .74438 .4352 Metetra
.662 .742 .91 r
.74438 .4352 .7471 .43866 .75316 .4368 .75045 .43334 Metetra
.661 .742 .91 r
.75045 .43334 .75316 .4368 .75924 .43494 .75654 .43148 Metetra
.66 .742 .911 r
.75654 .43148 .75924 .43494 .76533 .43309 .76264 .42963 Metetra
.659 .743 .912 r
.76264 .42963 .76533 .43309 .77143 .43124 .76875 .42779 Metetra
.658 .743 .913 r
.76875 .42779 .77143 .43124 .77755 .4294 .77488 .42596 Metetra
.657 .744 .914 r
.77488 .42596 .77755 .4294 .78368 .42758 .78102 .42415 Metetra
.655 .744 .915 r
.78102 .42415 .78368 .42758 .78983 .42577 .78718 .42236 Metetra
.653 .745 .917 r
.78718 .42236 .78983 .42577 .79599 .42398 .79335 .42059 Metetra
.651 .746 .919 r
.79335 .42059 .79599 .42398 .80217 .42222 .79954 .41886 Metetra
.648 .747 .922 r
.79954 .41886 .80217 .42222 .80836 .42048 .80575 .41715 Metetra
.645 .749 .925 r
.80575 .41715 .80836 .42048 .81458 .41878 .81198 .41549 Metetra
.641 .751 .928 r
.81198 .41549 .81458 .41878 .82081 .41711 .81822 .41386 Metetra
.638 .752 .931 r
.81822 .41386 .82081 .41711 .82706 .41548 .82449 .41228 Metetra
.634 .755 .935 r
.82449 .41228 .82706 .41548 .83332 .41389 .83077 .41074 Metetra
.63 .757 .938 r
.83077 .41074 .83332 .41389 .83961 .41234 .83707 .40923 Metetra
.627 .759 .942 r
.83707 .40923 .83961 .41234 .84591 .41083 .84339 .40776 Metetra
.624 .761 .944 r
.84339 .40776 .84591 .41083 .85224 .40934 .84973 .4063 Metetra
.623 .764 .946 r
.84973 .4063 .85224 .40934 .85858 .40786 .85608 .40484 Metetra
.624 .765 .947 r
.85608 .40484 .85858 .40786 .86494 .40639 .86245 .40336 Metetra
.626 .767 .947 r
.86245 .40336 .86494 .40639 .87131 .4049 .86883 .40185 Metetra
.631 .767 .945 r
.86883 .40185 .87131 .4049 .87769 .40338 .87522 .40029 Metetra
.637 .767 .942 r
.87522 .40029 .87769 .40338 .88409 .4018 .88162 .39865 Metetra
.644 .766 .937 r
.88162 .39865 .88409 .4018 .89049 .40016 .88802 .39692 Metetra
.651 .764 .932 r
.88802 .39692 .89049 .40016 .89689 .39843 .89443 .39509 Metetra
.658 .761 .925 r
.89443 .39509 .89689 .39843 .90331 .3966 .90084 .39316 Metetra
.665 .757 .919 r
.90084 .39316 .90331 .3966 .90972 .39468 .90726 .39113 Metetra
.67 .753 .913 r
.90726 .39113 .90972 .39468 .91614 .39266 .91368 .38902 Metetra
.674 .749 .907 r
.91368 .38902 .91614 .39266 .92256 .39057 .9201 .38684 Metetra
.676 .745 .903 r
.9201 .38684 .92256 .39057 .92899 .38841 .92653 .38461 Metetra
.677 .742 .9 r
.92653 .38461 .92899 .38841 .93543 .3862 .93298 .38237 Metetra
.649 .729 .907 r
.35102 .55874 .35428 .56191 .35954 .56061 .35629 .55729 Metetra
.64 .718 .904 r
.35629 .55729 .35954 .56061 .3648 .55943 .36157 .55597 Metetra
.631 .707 .901 r
.36157 .55597 .3648 .55943 .37008 .55836 .36685 .55478 Metetra
.622 .698 .899 r
.36685 .55478 .37008 .55836 .37536 .55735 .37215 .55372 Metetra
.617 .693 .898 r
.37215 .55372 .37536 .55735 .38066 .55634 .37744 .55273 Metetra
.615 .694 .9 r
.37744 .55273 .38066 .55634 .38597 .55526 .38276 .55175 Metetra
.619 .702 .904 r
.38276 .55175 .38597 .55526 .3913 .55404 .38808 .55071 Metetra
.628 .716 .91 r
.38808 .55071 .3913 .55404 .39664 .55262 .39343 .54953 Metetra
.642 .736 .917 r
.39343 .54953 .39664 .55262 .40201 .55095 .39879 .54814 Metetra
.66 .759 .924 r
.39879 .54814 .40201 .55095 .4074 .54904 .40418 .54651 Metetra
.678 .783 .929 r
.40418 .54651 .4074 .54904 .41281 .54689 .40958 .5446 Metetra
.695 .805 .933 r
.40958 .5446 .41281 .54689 .41823 .54453 .41501 .54243 Metetra
.71 .821 .934 r
.41501 .54243 .41823 .54453 .42366 .54203 .42045 .54005 Metetra
.72 .832 .934 r
.42045 .54005 .42366 .54203 .42911 .53945 .4259 .53751 Metetra
.726 .836 .933 r
.4259 .53751 .42911 .53945 .43456 .53683 .43136 .53487 Metetra
.728 .835 .931 r
.43136 .53487 .43456 .53683 .44002 .53425 .43683 .53221 Metetra
.726 .829 .929 r
.43683 .53221 .44002 .53425 .44549 .53173 .44231 .52957 Metetra
.721 .82 .927 r
.44231 .52957 .44549 .53173 .45096 .52931 .4478 .52701 Metetra
.714 .81 .924 r
.4478 .52701 .45096 .52931 .45644 .52699 .45329 .52454 Metetra
.706 .798 .922 r
.45329 .52454 .45644 .52699 .46193 .52478 .45879 .52218 Metetra
.699 .787 .919 r
.45879 .52218 .46193 .52478 .46742 .52266 .46429 .51994 Metetra
.692 .777 .917 r
.46429 .51994 .46742 .52266 .47292 .52063 .46981 .5178 Metetra
.685 .769 .915 r
.46981 .5178 .47292 .52063 .47843 .51867 .47533 .51575 Metetra
.68 .762 .913 r
.47533 .51575 .47843 .51867 .48396 .51677 .48086 .51377 Metetra
.676 .757 .912 r
.48086 .51377 .48396 .51677 .48949 .51491 .4864 .51186 Metetra
.673 .752 .911 r
.4864 .51186 .48949 .51491 .49503 .51309 .49195 .50999 Metetra
.67 .749 .91 r
.49195 .50999 .49503 .51309 .50058 .51129 .49751 .50815 Metetra
.668 .747 .909 r
.49751 .50815 .50058 .51129 .50614 .5095 .50308 .50634 Metetra
.667 .745 .909 r
.50308 .50634 .50614 .5095 .51172 .50773 .50866 .50455 Metetra
.666 .744 .909 r
.50866 .50455 .51172 .50773 .5173 .50596 .51425 .50276 Metetra
.665 .743 .908 r
.51425 .50276 .5173 .50596 .5229 .50419 .51986 .50098 Metetra
.665 .743 .908 r
.51986 .50098 .5229 .50419 .52851 .50243 .52547 .49921 Metetra
.664 .742 .908 r
.52547 .49921 .52851 .50243 .53413 .50067 .5311 .49744 Metetra
.664 .742 .908 r
.5311 .49744 .53413 .50067 .53976 .49891 .53674 .49566 Metetra
.664 .742 .908 r
.53674 .49566 .53976 .49891 .5454 .49714 .54239 .49389 Metetra
.664 .742 .908 r
.54239 .49389 .5454 .49714 .55106 .49538 .54805 .49212 Metetra
.664 .742 .908 r
.54805 .49212 .55106 .49538 .55672 .49361 .55372 .49034 Metetra
.664 .742 .908 r
.55372 .49034 .55672 .49361 .5624 .49184 .55941 .48856 Metetra
.664 .741 .908 r
.55941 .48856 .5624 .49184 .56809 .49006 .56511 .48678 Metetra
.664 .741 .908 r
.56511 .48678 .56809 .49006 .57379 .48828 .57081 .48499 Metetra
.664 .741 .908 r
.57081 .48499 .57379 .48828 .5795 .4865 .57654 .48321 Metetra
.664 .741 .908 r
.57654 .48321 .5795 .4865 .58523 .48472 .58227 .48141 Metetra
.664 .741 .908 r
.58227 .48141 .58523 .48472 .59096 .48293 .58801 .47962 Metetra
.664 .741 .908 r
.58801 .47962 .59096 .48293 .59671 .48114 .59377 .47782 Metetra
.664 .741 .908 r
.59377 .47782 .59671 .48114 .60247 .47934 .59954 .47602 Metetra
.664 .741 .908 r
.59954 .47602 .60247 .47934 .60824 .47754 .60532 .47421 Metetra
.664 .741 .908 r
.60532 .47421 .60824 .47754 .61403 .47574 .61111 .4724 Metetra
.664 .741 .908 r
.61111 .4724 .61403 .47574 .61982 .47393 .61691 .47059 Metetra
.664 .741 .908 r
.61691 .47059 .61982 .47393 .62563 .47212 .62273 .46877 Metetra
.664 .741 .908 r
.62273 .46877 .62563 .47212 .63145 .47031 .62855 .46695 Metetra
.664 .741 .908 r
.62855 .46695 .63145 .47031 .63728 .46849 .6344 .46513 Metetra
.664 .741 .908 r
.6344 .46513 .63728 .46849 .64313 .46667 .64025 .4633 Metetra
.664 .741 .908 r
.64025 .4633 .64313 .46667 .64898 .46485 .64611 .46147 Metetra
.664 .741 .908 r
.64611 .46147 .64898 .46485 .65485 .46302 .65199 .45963 Metetra
.664 .741 .908 r
.65199 .45963 .65485 .46302 .66073 .46118 .65788 .45779 Metetra
.664 .741 .908 r
.65788 .45779 .66073 .46118 .66663 .45935 .66378 .45595 Metetra
.664 .741 .908 r
.66378 .45595 .66663 .45935 .67253 .45751 .66969 .4541 Metetra
.663 .741 .908 r
.66969 .4541 .67253 .45751 .67845 .45566 .67562 .45225 Metetra
.663 .741 .908 r
.67562 .45225 .67845 .45566 .68438 .45382 .68156 .45039 Metetra
.663 .741 .908 r
.68156 .45039 .68438 .45382 .69032 .45197 .68751 .44854 Metetra
.663 .741 .908 r
.68751 .44854 .69032 .45197 .69628 .45011 .69347 .44668 Metetra
.663 .741 .908 r
.69347 .44668 .69628 .45011 .70225 .44825 .69945 .44481 Metetra
.663 .741 .908 r
.69945 .44481 .70225 .44825 .70823 .44639 .70544 .44295 Metetra
.663 .741 .908 r
.70544 .44295 .70823 .44639 .71422 .44453 .71144 .44108 Metetra
.663 .741 .908 r
.71144 .44108 .71422 .44453 .72023 .44267 .71746 .43921 Metetra
.663 .742 .909 r
.71746 .43921 .72023 .44267 .72625 .4408 .72349 .43734 Metetra
.662 .742 .909 r
.72349 .43734 .72625 .4408 .73228 .43893 .72953 .43547 Metetra
.662 .742 .909 r
.72953 .43547 .73228 .43893 .73832 .43707 .73558 .4336 Metetra
.662 .742 .91 r
.73558 .4336 .73832 .43707 .74438 .4352 .74165 .43173 Metetra
.661 .742 .91 r
.74165 .43173 .74438 .4352 .75045 .43334 .74773 .42987 Metetra
.66 .742 .911 r
.74773 .42987 .75045 .43334 .75654 .43148 .75382 .42802 Metetra
.659 .743 .912 r
.75382 .42802 .75654 .43148 .76264 .42963 .75993 .42617 Metetra
.658 .743 .913 r
.75993 .42617 .76264 .42963 .76875 .42779 .76606 .42434 Metetra
.657 .744 .914 r
.76606 .42434 .76875 .42779 .77488 .42596 .7722 .42253 Metetra
.655 .744 .915 r
.7722 .42253 .77488 .42596 .78102 .42415 .77835 .42074 Metetra
.653 .745 .917 r
.77835 .42074 .78102 .42415 .78718 .42236 .78452 .41897 Metetra
.651 .746 .92 r
.78452 .41897 .78718 .42236 .79335 .42059 .79071 .41723 Metetra
.648 .748 .922 r
.79071 .41723 .79335 .42059 .79954 .41886 .79691 .41553 Metetra
.645 .749 .925 r
.79691 .41553 .79954 .41886 .80575 .41715 .80313 .41387 Metetra
.641 .751 .928 r
.80313 .41387 .80575 .41715 .81198 .41549 .80938 .41225 Metetra
.637 .753 .932 r
.80938 .41225 .81198 .41549 .81822 .41386 .81563 .41067 Metetra
.633 .755 .936 r
.81563 .41067 .81822 .41386 .82449 .41228 .82191 .40914 Metetra
.629 .757 .939 r
.82191 .40914 .82449 .41228 .83077 .41074 .82821 .40764 Metetra
.625 .76 .943 r
.82821 .40764 .83077 .41074 .83707 .40923 .83453 .40618 Metetra
.623 .762 .946 r
.83453 .40618 .83707 .40923 .84339 .40776 .84086 .40473 Metetra
.622 .764 .948 r
.84086 .40473 .84339 .40776 .84973 .4063 .84721 .40329 Metetra
.622 .766 .949 r
.84721 .40329 .84973 .4063 .85608 .40484 .85358 .40183 Metetra
.625 .768 .948 r
.85358 .40183 .85608 .40484 .86245 .40336 .85996 .40033 Metetra
.629 .769 .947 r
.85996 .40033 .86245 .40336 .86883 .40185 .86634 .39877 Metetra
.636 .768 .943 r
.86634 .39877 .86883 .40185 .87522 .40029 .87274 .39714 Metetra
.643 .767 .938 r
.87274 .39714 .87522 .40029 .88162 .39865 .87914 .39541 Metetra
.651 .765 .932 r
.87914 .39541 .88162 .39865 .88802 .39692 .88554 .39358 Metetra
.659 .761 .926 r
.88554 .39358 .88802 .39692 .89443 .39509 .89195 .39164 Metetra
.665 .757 .919 r
.89195 .39164 .89443 .39509 .90084 .39316 .89836 .3896 Metetra
.671 .753 .912 r
.89836 .3896 .90084 .39316 .90726 .39113 .90477 .38747 Metetra
.674 .749 .907 r
.90477 .38747 .90726 .39113 .91368 .38902 .91119 .38528 Metetra
.677 .745 .902 r
.91119 .38528 .91368 .38902 .9201 .38684 .91762 .38303 Metetra
.678 .742 .899 r
.91762 .38303 .9201 .38684 .92653 .38461 .92406 .38077 Metetra
.677 .74 .898 r
.92406 .38077 .92653 .38461 .93298 .38237 .93051 .3785 Metetra
.658 .74 .911 r
.34774 .55569 .35102 .55874 .35629 .55729 .35303 .55411 Metetra
.651 .731 .908 r
.35303 .55411 .35629 .55729 .36157 .55597 .35832 .55264 Metetra
.641 .719 .904 r
.35832 .55264 .36157 .55597 .36685 .55478 .36362 .5513 Metetra
.631 .707 .901 r
.36362 .5513 .36685 .55478 .37215 .55372 .36892 .5501 Metetra
.622 .696 .898 r
.36892 .5501 .37215 .55372 .37744 .55273 .37423 .54904 Metetra
.615 .69 .897 r
.37423 .54904 .37744 .55273 .38276 .55175 .37954 .54808 Metetra
.613 .69 .898 r
.37954 .54808 .38276 .55175 .38808 .55071 .38487 .54713 Metetra
.616 .697 .902 r
.38487 .54713 .38808 .55071 .39343 .54953 .39021 .54614 Metetra
.625 .712 .909 r
.39021 .54614 .39343 .54953 .39879 .54814 .39557 .54501 Metetra
.639 .733 .916 r
.39557 .54501 .39879 .54814 .40418 .54651 .40095 .54366 Metetra
.657 .757 .924 r
.40095 .54366 .40418 .54651 .40958 .5446 .40635 .54205 Metetra
.676 .783 .93 r
.40635 .54205 .40958 .5446 .41501 .54243 .41178 .54015 Metetra
.695 .806 .934 r
.41178 .54015 .41501 .54243 .42045 .54005 .41722 .53797 Metetra
.711 .824 .935 r
.41722 .53797 .42045 .54005 .4259 .53751 .42268 .53557 Metetra
.722 .836 .935 r
.42268 .53557 .4259 .53751 .43136 .53487 .42815 .53298 Metetra
.729 .841 .934 r
.42815 .53298 .43136 .53487 .43683 .53221 .43363 .53029 Metetra
.731 .84 .932 r
.43363 .53029 .43683 .53221 .44231 .52957 .43912 .52757 Metetra
.729 .834 .93 r
.43912 .52757 .44231 .52957 .4478 .52701 .44462 .52488 Metetra
.724 .824 .928 r
.44462 .52488 .4478 .52701 .45329 .52454 .45012 .52226 Metetra
.716 .813 .925 r
.45012 .52226 .45329 .52454 .45879 .52218 .45563 .51974 Metetra
.708 .801 .922 r
.45563 .51974 .45879 .52218 .46429 .51994 .46115 .51735 Metetra
.7 .789 .92 r
.46115 .51735 .46429 .51994 .46981 .5178 .46667 .51507 Metetra
.693 .779 .917 r
.46667 .51507 .46981 .5178 .47533 .51575 .4722 .51291 Metetra
.686 .77 .915 r
.4722 .51291 .47533 .51575 .48086 .51377 .47774 .51084 Metetra
.68 .763 .913 r
.47774 .51084 .48086 .51377 .4864 .51186 .48329 .50885 Metetra
.676 .757 .912 r
.48329 .50885 .4864 .51186 .49195 .50999 .48885 .50692 Metetra
.673 .753 .911 r
.48885 .50692 .49195 .50999 .49751 .50815 .49442 .50504 Metetra
.67 .749 .91 r
.49442 .50504 .49751 .50815 .50308 .50634 .5 .50319 Metetra
.668 .747 .909 r
.5 .50319 .50308 .50634 .50866 .50455 .50559 .50137 Metetra
.667 .745 .909 r
.50559 .50137 .50866 .50455 .51425 .50276 .51119 .49956 Metetra
.666 .744 .909 r
.51119 .49956 .51425 .50276 .51986 .50098 .5168 .49777 Metetra
.665 .743 .908 r
.5168 .49777 .51986 .50098 .52547 .49921 .52242 .49598 Metetra
.665 .743 .908 r
.52242 .49598 .52547 .49921 .5311 .49744 .52806 .49419 Metetra
.664 .742 .908 r
.52806 .49419 .5311 .49744 .53674 .49566 .5337 .49241 Metetra
.664 .742 .908 r
.5337 .49241 .53674 .49566 .54239 .49389 .53936 .49063 Metetra
.664 .742 .908 r
.53936 .49063 .54239 .49389 .54805 .49212 .54503 .48885 Metetra
.664 .742 .908 r
.54503 .48885 .54805 .49212 .55372 .49034 .55071 .48706 Metetra
.664 .742 .908 r
.55071 .48706 .55372 .49034 .55941 .48856 .55641 .48527 Metetra
.664 .742 .908 r
.55641 .48527 .55941 .48856 .56511 .48678 .56211 .48349 Metetra
.664 .741 .908 r
.56211 .48349 .56511 .48678 .57081 .48499 .56783 .48169 Metetra
.664 .741 .908 r
.56783 .48169 .57081 .48499 .57654 .48321 .57355 .4799 Metetra
.664 .741 .908 r
.57355 .4799 .57654 .48321 .58227 .48141 .5793 .4781 Metetra
.664 .741 .908 r
.5793 .4781 .58227 .48141 .58801 .47962 .58505 .4763 Metetra
.664 .741 .908 r
.58505 .4763 .58801 .47962 .59377 .47782 .59081 .47449 Metetra
.664 .741 .908 r
.59081 .47449 .59377 .47782 .59954 .47602 .59659 .47268 Metetra
.664 .741 .908 r
.59659 .47268 .59954 .47602 .60532 .47421 .60237 .47087 Metetra
.664 .741 .908 r
.60237 .47087 .60532 .47421 .61111 .4724 .60817 .46905 Metetra
.664 .741 .908 r
.60817 .46905 .61111 .4724 .61691 .47059 .61399 .46723 Metetra
.664 .741 .908 r
.61399 .46723 .61691 .47059 .62273 .46877 .61981 .46541 Metetra
.664 .741 .908 r
.61981 .46541 .62273 .46877 .62855 .46695 .62565 .46358 Metetra
.664 .741 .908 r
.62565 .46358 .62855 .46695 .6344 .46513 .6315 .46175 Metetra
.664 .741 .908 r
.6315 .46175 .6344 .46513 .64025 .4633 .63736 .45991 Metetra
.664 .741 .908 r
.63736 .45991 .64025 .4633 .64611 .46147 .64323 .45807 Metetra
.664 .741 .908 r
.64323 .45807 .64611 .46147 .65199 .45963 .64911 .45623 Metetra
.664 .741 .908 r
.64911 .45623 .65199 .45963 .65788 .45779 .65501 .45438 Metetra
.664 .741 .908 r
.65501 .45438 .65788 .45779 .66378 .45595 .66092 .45253 Metetra
.663 .741 .908 r
.66092 .45253 .66378 .45595 .66969 .4541 .66684 .45068 Metetra
.663 .741 .908 r
.66684 .45068 .66969 .4541 .67562 .45225 .67278 .44882 Metetra
.663 .741 .908 r
.67278 .44882 .67562 .45225 .68156 .45039 .67873 .44696 Metetra
.663 .741 .908 r
.67873 .44696 .68156 .45039 .68751 .44854 .68469 .4451 Metetra
.663 .741 .908 r
.68469 .4451 .68751 .44854 .69347 .44668 .69066 .44323 Metetra
.663 .741 .908 r
.69066 .44323 .69347 .44668 .69945 .44481 .69664 .44136 Metetra
.663 .741 .908 r
.69664 .44136 .69945 .44481 .70544 .44295 .70264 .43949 Metetra
.663 .742 .908 r
.70264 .43949 .70544 .44295 .71144 .44108 .70865 .43762 Metetra
.663 .742 .909 r
.70865 .43762 .71144 .44108 .71746 .43921 .71468 .43574 Metetra
.662 .742 .909 r
.71468 .43574 .71746 .43921 .72349 .43734 .72071 .43387 Metetra
.662 .742 .909 r
.72071 .43387 .72349 .43734 .72953 .43547 .72676 .432 Metetra
.662 .742 .91 r
.72676 .432 .72953 .43547 .73558 .4336 .73283 .43013 Metetra
.661 .742 .91 r
.73283 .43013 .73558 .4336 .74165 .43173 .73891 .42826 Metetra
.66 .742 .911 r
.73891 .42826 .74165 .43173 .74773 .42987 .745 .4264 Metetra
.659 .743 .912 r
.745 .4264 .74773 .42987 .75382 .42802 .7511 .42456 Metetra
.658 .743 .913 r
.7511 .42456 .75382 .42802 .75993 .42617 .75722 .42272 Metetra
.657 .744 .914 r
.75722 .42272 .75993 .42617 .76606 .42434 .76336 .4209 Metetra
.655 .744 .915 r
.76336 .4209 .76606 .42434 .7722 .42253 .76951 .41911 Metetra
.653 .745 .917 r
.76951 .41911 .7722 .42253 .77835 .42074 .77567 .41734 Metetra
.651 .746 .92 r
.77567 .41734 .77835 .42074 .78452 .41897 .78186 .4156 Metetra
.648 .748 .922 r
.78186 .4156 .78452 .41897 .79071 .41723 .78806 .4139 Metetra
.644 .749 .925 r
.78806 .4139 .79071 .41723 .79691 .41553 .79427 .41224 Metetra
.64 .751 .929 r
.79427 .41224 .79691 .41553 .80313 .41387 .80051 .41062 Metetra
.636 .753 .933 r
.80051 .41062 .80313 .41387 .80938 .41225 .80677 .40905 Metetra
.632 .755 .937 r
.80677 .40905 .80938 .41225 .81563 .41067 .81304 .40753 Metetra
.627 .758 .94 r
.81304 .40753 .81563 .41067 .82191 .40914 .81934 .40605 Metetra
.624 .76 .944 r
.81934 .40605 .82191 .40914 .82821 .40764 .82565 .4046 Metetra
.621 .763 .947 r
.82565 .4046 .82821 .40764 .83453 .40618 .83198 .40317 Metetra
.62 .765 .949 r
.83198 .40317 .83453 .40618 .84086 .40473 .83833 .40174 Metetra
.62 .767 .95 r
.83833 .40174 .84086 .40473 .84721 .40329 .84469 .4003 Metetra
.623 .769 .95 r
.84469 .4003 .84721 .40329 .85358 .40183 .85106 .39881 Metetra
.628 .77 .948 r
.85106 .39881 .85358 .40183 .85996 .40033 .85745 .39727 Metetra
.634 .77 .945 r
.85745 .39727 .85996 .40033 .86634 .39877 .86384 .39564 Metetra
.642 .768 .939 r
.86384 .39564 .86634 .39877 .87274 .39714 .87024 .39391 Metetra
.651 .766 .933 r
.87024 .39391 .87274 .39714 .87914 .39541 .87664 .39208 Metetra
.659 .762 .926 r
.87664 .39208 .87914 .39541 .88554 .39358 .88304 .39013 Metetra
.666 .758 .919 r
.88304 .39013 .88554 .39358 .89195 .39164 .88945 .38808 Metetra
.671 .753 .912 r
.88945 .38808 .89195 .39164 .89836 .3896 .89586 .38593 Metetra
.675 .749 .906 r
.89586 .38593 .89836 .3896 .90477 .38747 .90227 .38372 Metetra
.678 .745 .902 r
.90227 .38372 .90477 .38747 .91119 .38528 .90869 .38145 Metetra
.678 .742 .899 r
.90869 .38145 .91119 .38528 .91762 .38303 .91513 .37917 Metetra
.678 .74 .897 r
.91513 .37917 .91762 .38303 .92406 .38077 .92158 .37689 Metetra
.676 .739 .898 r
.92158 .37689 .92406 .38077 .93051 .3785 .92804 .37464 Metetra
.663 .748 .913 r
.34445 .55274 .34774 .55569 .35303 .55411 .34974 .55108 Metetra
.659 .742 .911 r
.34974 .55108 .35303 .55411 .35832 .55264 .35505 .54947 Metetra
.652 .732 .908 r
.35505 .54947 .35832 .55264 .36362 .5513 .36036 .54797 Metetra
.642 .72 .905 r
.36036 .54797 .36362 .5513 .36892 .5501 .36567 .5466 Metetra
.631 .707 .901 r
.36567 .5466 .36892 .5501 .37423 .54904 .37099 .5454 Metetra
.621 .695 .897 r
.37099 .5454 .37423 .54904 .37954 .54808 .37632 .54434 Metetra
.613 .688 .896 r
.37632 .54434 .37954 .54808 .38487 .54713 .38165 .54339 Metetra
.61 .686 .897 r
.38165 .54339 .38487 .54713 .39021 .54614 .38699 .54249 Metetra
.612 .693 .901 r
.38699 .54249 .39021 .54614 .39557 .54501 .39235 .54154 Metetra
.62 .707 .907 r
.39235 .54154 .39557 .54501 .40095 .54366 .39773 .54046 Metetra
.635 .729 .916 r
.39773 .54046 .40095 .54366 .40635 .54205 .40313 .53916 Metetra
.654 .755 .924 r
.40313 .53916 .40635 .54205 .41178 .54015 .40854 .53758 Metetra
.675 .782 .931 r
.40854 .53758 .41178 .54015 .41722 .53797 .41398 .53569 Metetra
.695 .807 .935 r
.41398 .53569 .41722 .53797 .42268 .53557 .41944 .53351 Metetra
.712 .827 .937 r
.41944 .53351 .42268 .53557 .42815 .53298 .42492 .53108 Metetra
.724 .84 .936 r
.42492 .53108 .42815 .53298 .43363 .53029 .43041 .52845 Metetra
.731 .846 .935 r
.43041 .52845 .43363 .53029 .43912 .52757 .43591 .52571 Metetra
.734 .845 .933 r
.43591 .52571 .43912 .52757 .44462 .52488 .44142 .52292 Metetra
.732 .839 .931 r
.44142 .52292 .44462 .52488 .45012 .52226 .44694 .52017 Metetra
.727 .829 .928 r
.44694 .52017 .45012 .52226 .45563 .51974 .45246 .51749 Metetra
.719 .817 .926 r
.45246 .51749 .45563 .51974 .46115 .51735 .45799 .51493 Metetra
.71 .804 .923 r
.45799 .51493 .46115 .51735 .46667 .51507 .46353 .51249 Metetra
.702 .791 .92 r
.46353 .51249 .46667 .51507 .4722 .51291 .46907 .51018 Metetra
.694 .78 .918 r
.46907 .51018 .4722 .51291 .47774 .51084 .47462 .50799 Metetra
.687 .771 .915 r
.47462 .50799 .47774 .51084 .48329 .50885 .48018 .5059 Metetra
.681 .763 .913 r
.48018 .5059 .48329 .50885 .48885 .50692 .48574 .50389 Metetra
.676 .757 .912 r
.48574 .50389 .48885 .50692 .49442 .50504 .49132 .50195 Metetra
.673 .753 .911 r
.49132 .50195 .49442 .50504 .5 .50319 .49691 .50005 Metetra
.67 .749 .91 r
.49691 .50005 .5 .50319 .50559 .50137 .5025 .4982 Metetra
.668 .747 .909 r
.5025 .4982 .50559 .50137 .51119 .49956 .50811 .49636 Metetra
.667 .745 .909 r
.50811 .49636 .51119 .49956 .5168 .49777 .51373 .49455 Metetra
.666 .744 .909 r
.51373 .49455 .5168 .49777 .52242 .49598 .51936 .49274 Metetra
.665 .743 .908 r
.51936 .49274 .52242 .49598 .52806 .49419 .525 .49094 Metetra
.665 .743 .908 r
.525 .49094 .52806 .49419 .5337 .49241 .53066 .48915 Metetra
.664 .742 .908 r
.53066 .48915 .5337 .49241 .53936 .49063 .53632 .48736 Metetra
.664 .742 .908 r
.53632 .48736 .53936 .49063 .54503 .48885 .542 .48557 Metetra
.664 .742 .908 r
.542 .48557 .54503 .48885 .55071 .48706 .54769 .48377 Metetra
.664 .742 .908 r
.54769 .48377 .55071 .48706 .55641 .48527 .55339 .48198 Metetra
.664 .742 .908 r
.55339 .48198 .55641 .48527 .56211 .48349 .5591 .48018 Metetra
.664 .741 .908 r
.5591 .48018 .56211 .48349 .56783 .48169 .56483 .47838 Metetra
.664 .741 .908 r
.56483 .47838 .56783 .48169 .57355 .4799 .57056 .47658 Metetra
.664 .741 .908 r
.57056 .47658 .57355 .4799 .5793 .4781 .57631 .47477 Metetra
.664 .741 .908 r
.57631 .47477 .5793 .4781 .58505 .4763 .58207 .47296 Metetra
.664 .741 .908 r
.58207 .47296 .58505 .4763 .59081 .47449 .58784 .47115 Metetra
.664 .741 .908 r
.58784 .47115 .59081 .47449 .59659 .47268 .59363 .46933 Metetra
.664 .741 .908 r
.59363 .46933 .59659 .47268 .60237 .47087 .59942 .46751 Metetra
.664 .741 .908 r
.59942 .46751 .60237 .47087 .60817 .46905 .60523 .46569 Metetra
.664 .741 .908 r
.60523 .46569 .60817 .46905 .61399 .46723 .61105 .46386 Metetra
.664 .741 .908 r
.61105 .46386 .61399 .46723 .61981 .46541 .61688 .46203 Metetra
.664 .741 .908 r
.61688 .46203 .61981 .46541 .62565 .46358 .62273 .46019 Metetra
.664 .741 .908 r
.62273 .46019 .62565 .46358 .6315 .46175 .62858 .45836 Metetra
.664 .741 .908 r
.62858 .45836 .6315 .46175 .63736 .45991 .63445 .45651 Metetra
.664 .741 .908 r
.63445 .45651 .63736 .45991 .64323 .45807 .64033 .45467 Metetra
.664 .741 .908 r
.64033 .45467 .64323 .45807 .64911 .45623 .64623 .45282 Metetra
.664 .741 .908 r
.64623 .45282 .64911 .45623 .65501 .45438 .65213 .45096 Metetra
.663 .741 .908 r
.65213 .45096 .65501 .45438 .66092 .45253 .65805 .44911 Metetra
.663 .741 .908 r
.65805 .44911 .66092 .45253 .66684 .45068 .66398 .44725 Metetra
.663 .741 .908 r
.66398 .44725 .66684 .45068 .67278 .44882 .66993 .44538 Metetra
.663 .741 .908 r
.66993 .44538 .67278 .44882 .67873 .44696 .67588 .44351 Metetra
.663 .741 .908 r
.67588 .44351 .67873 .44696 .68469 .4451 .68185 .44164 Metetra
.663 .741 .908 r
.68185 .44164 .68469 .4451 .69066 .44323 .68783 .43977 Metetra
.663 .741 .908 r
.68783 .43977 .69066 .44323 .69664 .44136 .69383 .4379 Metetra
.663 .741 .908 r
.69383 .4379 .69664 .44136 .70264 .43949 .69983 .43602 Metetra
.663 .742 .909 r
.69983 .43602 .70264 .43949 .70865 .43762 .70585 .43414 Metetra
.662 .742 .909 r
.70585 .43414 .70865 .43762 .71468 .43574 .71189 .43226 Metetra
.662 .742 .909 r
.71189 .43226 .71468 .43574 .72071 .43387 .71793 .43039 Metetra
.662 .742 .91 r
.71793 .43039 .72071 .43387 .72676 .432 .72399 .42852 Metetra
.661 .742 .91 r
.72399 .42852 .72676 .432 .73283 .43013 .73007 .42665 Metetra
.66 .742 .911 r
.73007 .42665 .73283 .43013 .73891 .42826 .73615 .42479 Metetra
.659 .743 .912 r
.73615 .42479 .73891 .42826 .745 .4264 .74225 .42293 Metetra
.658 .743 .913 r
.74225 .42293 .745 .4264 .7511 .42456 .74837 .4211 Metetra
.657 .744 .914 r
.74837 .4211 .7511 .42456 .75722 .42272 .7545 .41928 Metetra
.655 .744 .916 r
.7545 .41928 .75722 .42272 .76336 .4209 .76065 .41748 Metetra
.653 .745 .917 r
.76065 .41748 .76336 .4209 .76951 .41911 .76681 .41571 Metetra
.65 .746 .92 r
.76681 .41571 .76951 .41911 .77567 .41734 .77299 .41397 Metetra
.647 .748 .923 r
.77299 .41397 .77567 .41734 .78186 .4156 .77918 .41227 Metetra
.644 .749 .926 r
.77918 .41227 .78186 .4156 .78806 .4139 .7854 .41061 Metetra
.64 .751 .929 r
.7854 .41061 .78806 .4139 .79427 .41224 .79163 .409 Metetra
.635 .753 .933 r
.79163 .409 .79427 .41224 .80051 .41062 .79788 .40744 Metetra
.631 .755 .937 r
.79788 .40744 .80051 .41062 .80677 .40905 .80415 .40592 Metetra
.626 .758 .941 r
.80415 .40592 .80677 .40905 .81304 .40753 .81044 .40445 Metetra
.622 .761 .945 r
.81044 .40445 .81304 .40753 .81934 .40605 .81675 .40302 Metetra
.619 .763 .949 r
.81675 .40302 .81934 .40605 .82565 .4046 .82308 .4016 Metetra
.617 .766 .951 r
.82308 .4016 .82565 .4046 .83198 .40317 .82943 .4002 Metetra
.618 .768 .952 r
.82943 .4002 .83198 .40317 .83833 .40174 .83578 .39877 Metetra
.621 .77 .952 r
.83578 .39877 .83833 .40174 .84469 .4003 .84216 .3973 Metetra
.626 .771 .95 r
.84216 .3973 .84469 .4003 .85106 .39881 .84854 .39577 Metetra
.633 .771 .946 r
.84854 .39577 .85106 .39881 .85745 .39727 .85493 .39415 Metetra
.642 .769 .941 r
.85493 .39415 .85745 .39727 .86384 .39564 .86132 .39243 Metetra
.651 .767 .934 r
.86132 .39243 .86384 .39564 .87024 .39391 .86772 .39058 Metetra
.659 .763 .926 r
.86772 .39058 .87024 .39391 .87664 .39208 .87411 .38863 Metetra
.667 .758 .919 r
.87411 .38863 .87664 .39208 .88304 .39013 .88051 .38656 Metetra
.672 .753 .912 r
.88051 .38656 .88304 .39013 .88945 .38808 .88692 .38439 Metetra
.676 .749 .905 r
.88692 .38439 .88945 .38808 .89586 .38593 .89333 .38216 Metetra
.678 .745 .901 r
.89333 .38216 .89586 .38593 .90227 .38372 .89975 .37987 Metetra
.679 .741 .898 r
.89975 .37987 .90227 .38372 .90869 .38145 .90618 .37758 Metetra
.678 .739 .897 r
.90618 .37758 .90869 .38145 .91513 .37917 .91262 .37528 Metetra
.677 .739 .897 r
.91262 .37528 .91513 .37917 .92158 .37689 .91908 .37302 Metetra
.674 .739 .899 r
.91908 .37302 .92158 .37689 .92804 .37464 .92556 .37079 Metetra
.664 .751 .915 r
.34114 .54981 .34445 .55274 .34974 .55108 .34644 .54813 Metetra
.664 .75 .914 r
.34644 .54813 .34974 .55108 .35505 .54947 .35176 .54645 Metetra
.66 .744 .912 r
.35176 .54645 .35505 .54947 .36036 .54797 .35708 .54481 Metetra
.653 .735 .909 r
.35708 .54481 .36036 .54797 .36567 .5466 .36241 .54328 Metetra
.644 .722 .905 r
.36241 .54328 .36567 .5466 .37099 .5454 .36774 .54188 Metetra
.632 .707 .901 r
.36774 .54188 .37099 .5454 .37632 .54434 .37308 .54066 Metetra
.62 .694 .897 r
.37308 .54066 .37632 .54434 .38165 .54339 .37842 .5396 Metetra
.611 .685 .895 r
.37842 .5396 .38165 .54339 .38699 .54249 .38377 .53867 Metetra
.606 .682 .896 r
.38377 .53867 .38699 .54249 .39235 .54154 .38913 .53781 Metetra
.608 .688 .899 r
.38913 .53781 .39235 .54154 .39773 .54046 .39451 .53691 Metetra
.616 .702 .906 r
.39451 .53691 .39773 .54046 .40313 .53916 .3999 .53588 Metetra
.631 .724 .915 r
.3999 .53588 .40313 .53916 .40854 .53758 .40531 .53463 Metetra
.65 .751 .924 r
.40531 .53463 .40854 .53758 .41398 .53569 .41075 .5331 Metetra
.672 .781 .931 r
.41075 .5331 .41398 .53569 .41944 .53351 .4162 .53123 Metetra
.694 .809 .936 r
.4162 .53123 .41944 .53351 .42492 .53108 .42168 .52905 Metetra
.712 .831 .938 r
.42168 .52905 .42492 .53108 .43041 .52845 .42718 .52659 Metetra
.726 .845 .937 r
.42718 .52659 .43041 .52845 .43591 .52571 .43269 .52392 Metetra
.734 .852 .936 r
.43269 .52392 .43591 .52571 .44142 .52292 .43821 .52112 Metetra
.737 .851 .934 r
.43821 .52112 .44142 .52292 .44694 .52017 .44374 .51827 Metetra
.735 .845 .932 r
.44374 .51827 .44694 .52017 .45246 .51749 .44927 .51545 Metetra
.73 .834 .929 r
.44927 .51545 .45246 .51749 .45799 .51493 .45482 .51271 Metetra
.722 .821 .926 r
.45482 .51271 .45799 .51493 .46353 .51249 .46036 .51009 Metetra
.713 .807 .924 r
.46036 .51009 .46353 .51249 .46907 .51018 .46592 .50761 Metetra
.703 .794 .921 r
.46592 .50761 .46907 .51018 .47462 .50799 .47148 .50526 Metetra
.695 .782 .918 r
.47148 .50526 .47462 .50799 .48018 .5059 .47704 .50304 Metetra
.687 .772 .916 r
.47704 .50304 .48018 .5059 .48574 .50389 .48262 .50093 Metetra
.681 .764 .914 r
.48262 .50093 .48574 .50389 .49132 .50195 .48821 .4989 Metetra
.676 .757 .912 r
.48821 .4989 .49132 .50195 .49691 .50005 .4938 .49695 Metetra
.673 .753 .911 r
.4938 .49695 .49691 .50005 .5025 .4982 .49941 .49504 Metetra
.67 .75 .91 r
.49941 .49504 .5025 .4982 .50811 .49636 .50502 .49317 Metetra
.668 .747 .909 r
.50502 .49317 .50811 .49636 .51373 .49455 .51065 .49133 Metetra
.667 .745 .909 r
.51065 .49133 .51373 .49455 .51936 .49274 .51629 .4895 Metetra
.666 .744 .909 r
.51629 .4895 .51936 .49274 .525 .49094 .52194 .48769 Metetra
.665 .743 .908 r
.52194 .48769 .525 .49094 .53066 .48915 .5276 .48588 Metetra
.665 .743 .908 r
.5276 .48588 .53066 .48915 .53632 .48736 .53327 .48408 Metetra
.664 .742 .908 r
.53327 .48408 .53632 .48736 .542 .48557 .53896 .48227 Metetra
.664 .742 .908 r
.53896 .48227 .542 .48557 .54769 .48377 .54466 .48047 Metetra
.664 .742 .908 r
.54466 .48047 .54769 .48377 .55339 .48198 .55036 .47867 Metetra
.664 .742 .908 r
.55036 .47867 .55339 .48198 .5591 .48018 .55608 .47686 Metetra
.664 .742 .908 r
.55608 .47686 .5591 .48018 .56483 .47838 .56182 .47505 Metetra
.664 .741 .908 r
.56182 .47505 .56483 .47838 .57056 .47658 .56756 .47324 Metetra
.664 .741 .908 r
.56756 .47324 .57056 .47658 .57631 .47477 .57332 .47143 Metetra
.664 .741 .908 r
.57332 .47143 .57631 .47477 .58207 .47296 .57908 .46961 Metetra
.664 .741 .908 r
.57908 .46961 .58207 .47296 .58784 .47115 .58486 .46779 Metetra
.664 .741 .908 r
.58486 .46779 .58784 .47115 .59363 .46933 .59066 .46597 Metetra
.664 .741 .908 r
.59066 .46597 .59363 .46933 .59942 .46751 .59646 .46414 Metetra
.664 .741 .908 r
.59646 .46414 .59942 .46751 .60523 .46569 .60228 .46231 Metetra
.664 .741 .908 r
.60228 .46231 .60523 .46569 .61105 .46386 .6081 .46048 Metetra
.664 .741 .908 r
.6081 .46048 .61105 .46386 .61688 .46203 .61394 .45864 Metetra
.664 .741 .908 r
.61394 .45864 .61688 .46203 .62273 .46019 .6198 .4568 Metetra
.664 .741 .908 r
.6198 .4568 .62273 .46019 .62858 .45836 .62566 .45495 Metetra
.664 .741 .908 r
.62566 .45495 .62858 .45836 .63445 .45651 .63154 .4531 Metetra
.664 .741 .908 r
.63154 .4531 .63445 .45651 .64033 .45467 .63743 .45125 Metetra
.664 .741 .908 r
.63743 .45125 .64033 .45467 .64623 .45282 .64333 .44939 Metetra
.663 .741 .908 r
.64333 .44939 .64623 .45282 .65213 .45096 .64925 .44753 Metetra
.663 .741 .908 r
.64925 .44753 .65213 .45096 .65805 .44911 .65517 .44567 Metetra
.663 .741 .908 r
.65517 .44567 .65805 .44911 .66398 .44725 .66111 .4438 Metetra
.663 .741 .908 r
.66111 .4438 .66398 .44725 .66993 .44538 .66706 .44193 Metetra
.663 .741 .908 r
.66706 .44193 .66993 .44538 .67588 .44351 .67303 .44005 Metetra
.663 .741 .908 r
.67303 .44005 .67588 .44351 .68185 .44164 .67901 .43818 Metetra
.663 .741 .908 r
.67901 .43818 .68185 .44164 .68783 .43977 .685 .4363 Metetra
.663 .741 .908 r
.685 .4363 .68783 .43977 .69383 .4379 .691 .43442 Metetra
.663 .742 .909 r
.691 .43442 .69383 .4379 .69983 .43602 .69702 .43254 Metetra
.662 .742 .909 r
.69702 .43254 .69983 .43602 .70585 .43414 .70304 .43066 Metetra
.662 .742 .909 r
.70304 .43066 .70585 .43414 .71189 .43226 .70909 .42878 Metetra
.662 .742 .91 r
.70909 .42878 .71189 .43226 .71793 .43039 .71514 .4269 Metetra
.661 .742 .91 r
.71514 .4269 .71793 .43039 .72399 .42852 .72121 .42503 Metetra
.66 .742 .911 r
.72121 .42503 .72399 .42852 .73007 .42665 .72729 .42316 Metetra
.659 .743 .912 r
.72729 .42316 .73007 .42665 .73615 .42479 .73339 .42131 Metetra
.658 .743 .913 r
.73339 .42131 .73615 .42479 .74225 .42293 .7395 .41947 Metetra
.657 .744 .914 r
.7395 .41947 .74225 .42293 .74837 .4211 .74563 .41765 Metetra
.655 .744 .916 r
.74563 .41765 .74837 .4211 .7545 .41928 .75177 .41585 Metetra
.653 .745 .918 r
.75177 .41585 .7545 .41928 .76065 .41748 .75793 .41407 Metetra
.65 .746 .92 r
.75793 .41407 .76065 .41748 .76681 .41571 .7641 .41233 Metetra
.647 .748 .923 r
.7641 .41233 .76681 .41571 .77299 .41397 .77029 .41063 Metetra
.643 .749 .926 r
.77029 .41063 .77299 .41397 .77918 .41227 .7765 .40898 Metetra
.639 .751 .93 r
.7765 .40898 .77918 .41227 .7854 .41061 .78273 .40737 Metetra
.634 .753 .934 r
.78273 .40737 .7854 .41061 .79163 .409 .78898 .40582 Metetra
.629 .756 .938 r
.78898 .40582 .79163 .409 .79788 .40744 .79525 .40432 Metetra
.624 .759 .943 r
.79525 .40432 .79788 .40744 .80415 .40592 .80153 .40286 Metetra
.62 .761 .947 r
.80153 .40286 .80415 .40592 .81044 .40445 .80784 .40144 Metetra
.617 .764 .95 r
.80784 .40144 .81044 .40445 .81675 .40302 .81417 .40005 Metetra
.615 .767 .953 r
.81417 .40005 .81675 .40302 .82308 .4016 .82051 .39866 Metetra
.615 .769 .954 r
.82051 .39866 .82308 .4016 .82943 .4002 .82686 .39725 Metetra
.618 .771 .954 r
.82686 .39725 .82943 .4002 .83578 .39877 .83323 .3958 Metetra
.624 .772 .951 r
.83323 .3958 .83578 .39877 .84216 .3973 .83961 .39428 Metetra
.632 .772 .948 r
.83961 .39428 .84216 .3973 .84854 .39577 .84599 .39267 Metetra
.641 .771 .942 r
.84599 .39267 .84854 .39577 .85493 .39415 .85238 .39094 Metetra
.651 .768 .935 r
.85238 .39094 .85493 .39415 .86132 .39243 .85878 .3891 Metetra
.66 .764 .927 r
.85878 .3891 .86132 .39243 .86772 .39058 .86517 .38713 Metetra
.667 .759 .919 r
.86517 .38713 .86772 .39058 .87411 .38863 .87157 .38504 Metetra
.673 .753 .911 r
.87157 .38504 .87411 .38863 .88051 .38656 .87797 .38286 Metetra
.677 .748 .905 r
.87797 .38286 .88051 .38656 .88692 .38439 .88437 .3806 Metetra
.679 .744 .9 r
.88437 .3806 .88692 .38439 .89333 .38216 .89079 .3783 Metetra
.68 .741 .897 r
.89079 .3783 .89333 .38216 .89975 .37987 .89721 .37598 Metetra
.679 .739 .896 r
.89721 .37598 .89975 .37987 .90618 .37758 .90365 .37368 Metetra
.677 .738 .897 r
.90365 .37368 .90618 .37758 .91262 .37528 .91011 .3714 Metetra
.674 .739 .899 r
.91011 .3714 .91262 .37528 .91908 .37302 .91659 .36917 Metetra
.671 .74 .902 r
.91659 .36917 .91908 .37302 .92556 .37079 .92308 .36699 Metetra
.662 .749 .915 r
.33782 .54684 .34114 .54981 .34644 .54813 .34313 .54519 Metetra
.664 .752 .915 r
.34313 .54519 .34644 .54813 .35176 .54645 .34845 .5435 Metetra
.665 .751 .915 r
.34845 .5435 .35176 .54645 .35708 .54481 .35378 .5418 Metetra
.662 .746 .913 r
.35378 .5418 .35708 .54481 .36241 .54328 .35912 .54013 Metetra
.655 .737 .91 r
.35912 .54013 .36241 .54328 .36774 .54188 .36447 .53857 Metetra
.645 .724 .906 r
.36447 .53857 .36774 .54188 .37308 .54066 .36982 .53714 Metetra
.633 .708 .901 r
.36982 .53714 .37308 .54066 .37842 .5396 .37518 .5359 Metetra
.62 .694 .897 r
.37518 .5359 .37842 .5396 .38377 .53867 .38054 .53483 Metetra
.61 .683 .894 r
.38054 .53483 .38377 .53867 .38913 .53781 .38591 .53392 Metetra
.603 .678 .894 r
.38591 .53392 .38913 .53781 .39451 .53691 .39128 .53309 Metetra
.604 .683 .897 r
.39128 .53309 .39451 .53691 .3999 .53588 .39667 .53225 Metetra
.611 .696 .904 r
.39667 .53225 .3999 .53588 .40531 .53463 .40208 .53128 Metetra
.626 .719 .913 r
.40208 .53128 .40531 .53463 .41075 .5331 .40751 .5301 Metetra
.646 .748 .923 r
.40751 .5301 .41075 .5331 .4162 .53123 .41296 .5286 Metetra
.67 .779 .932 r
.41296 .5286 .4162 .53123 .42168 .52905 .41844 .52677 Metetra
.693 .809 .937 r
.41844 .52677 .42168 .52905 .42718 .52659 .42393 .52459 Metetra
.713 .834 .939 r
.42393 .52459 .42718 .52659 .43269 .52392 .42945 .5221 Metetra
.728 .85 .939 r
.42945 .5221 .43269 .52392 .43821 .52112 .43497 .51939 Metetra
.737 .857 .937 r
.43497 .51939 .43821 .52112 .44374 .51827 .44051 .51653 Metetra
.741 .857 .935 r
.44051 .51653 .44374 .51827 .44927 .51545 .44606 .51361 Metetra
.739 .85 .932 r
.44606 .51361 .44927 .51545 .45482 .51271 .45162 .51072 Metetra
.733 .839 .93 r
.45162 .51072 .45482 .51271 .46036 .51009 .45718 .50791 Metetra
.725 .825 .927 r
.45718 .50791 .46036 .51009 .46592 .50761 .46275 .50524 Metetra
.715 .81 .924 r
.46275 .50524 .46592 .50761 .47148 .50526 .46832 .50271 Metetra
.705 .796 .921 r
.46832 .50271 .47148 .50526 .47704 .50304 .4739 .50032 Metetra
.696 .783 .918 r
.4739 .50032 .47704 .50304 .48262 .50093 .47949 .49807 Metetra
.688 .773 .916 r
.47949 .49807 .48262 .50093 .48821 .4989 .48508 .49593 Metetra
.682 .764 .914 r
.48508 .49593 .48821 .4989 .4938 .49695 .49068 .49389 Metetra
.677 .758 .912 r
.49068 .49389 .4938 .49695 .49941 .49504 .4963 .49192 Metetra
.673 .753 .911 r
.4963 .49192 .49941 .49504 .50502 .49317 .50192 .49 Metetra
.67 .75 .91 r
.50192 .49 .50502 .49317 .51065 .49133 .50756 .48812 Metetra
.668 .747 .909 r
.50756 .48812 .51065 .49133 .51629 .4895 .51321 .48627 Metetra
.667 .745 .909 r
.51321 .48627 .51629 .4895 .52194 .48769 .51886 .48443 Metetra
.666 .744 .909 r
.51886 .48443 .52194 .48769 .5276 .48588 .52453 .48261 Metetra
.665 .743 .908 r
.52453 .48261 .5276 .48588 .53327 .48408 .53021 .48079 Metetra
.665 .743 .908 r
.53021 .48079 .53327 .48408 .53896 .48227 .53591 .47897 Metetra
.664 .742 .908 r
.53591 .47897 .53896 .48227 .54466 .48047 .54161 .47716 Metetra
.664 .742 .908 r
.54161 .47716 .54466 .48047 .55036 .47867 .54733 .47535 Metetra
.664 .742 .908 r
.54733 .47535 .55036 .47867 .55608 .47686 .55305 .47353 Metetra
.664 .742 .908 r
.55305 .47353 .55608 .47686 .56182 .47505 .55879 .47172 Metetra
.664 .742 .908 r
.55879 .47172 .56182 .47505 .56756 .47324 .56455 .4699 Metetra
.664 .742 .908 r
.56455 .4699 .56756 .47324 .57332 .47143 .57031 .46808 Metetra
.664 .741 .908 r
.57031 .46808 .57332 .47143 .57908 .46961 .57609 .46625 Metetra
.664 .741 .908 r
.57609 .46625 .57908 .46961 .58486 .46779 .58187 .46443 Metetra
.664 .741 .908 r
.58187 .46443 .58486 .46779 .59066 .46597 .58767 .4626 Metetra
.664 .741 .908 r
.58767 .4626 .59066 .46597 .59646 .46414 .59349 .46076 Metetra
.664 .741 .908 r
.59349 .46076 .59646 .46414 .60228 .46231 .59931 .45892 Metetra
.664 .741 .908 r
.59931 .45892 .60228 .46231 .6081 .46048 .60515 .45708 Metetra
.664 .741 .908 r
.60515 .45708 .6081 .46048 .61394 .45864 .61099 .45524 Metetra
.664 .741 .908 r
.61099 .45524 .61394 .45864 .6198 .4568 .61686 .45339 Metetra
.664 .741 .908 r
.61686 .45339 .6198 .4568 .62566 .45495 .62273 .45153 Metetra
.664 .741 .908 r
.62273 .45153 .62566 .45495 .63154 .4531 .62861 .44968 Metetra
.664 .741 .908 r
.62861 .44968 .63154 .4531 .63743 .45125 .63451 .44782 Metetra
.663 .741 .908 r
.63451 .44782 .63743 .45125 .64333 .44939 .64042 .44595 Metetra
.663 .741 .908 r
.64042 .44595 .64333 .44939 .64925 .44753 .64635 .44409 Metetra
.663 .741 .908 r
.64635 .44409 .64925 .44753 .65517 .44567 .65228 .44221 Metetra
.663 .741 .908 r
.65228 .44221 .65517 .44567 .66111 .4438 .65823 .44034 Metetra
.663 .741 .908 r
.65823 .44034 .66111 .4438 .66706 .44193 .66419 .43846 Metetra
.663 .741 .908 r
.66419 .43846 .66706 .44193 .67303 .44005 .67016 .43658 Metetra
.663 .741 .908 r
.67016 .43658 .67303 .44005 .67901 .43818 .67615 .4347 Metetra
.663 .741 .908 r
.67615 .4347 .67901 .43818 .685 .4363 .68215 .43282 Metetra
.663 .742 .909 r
.68215 .43282 .685 .4363 .691 .43442 .68816 .43093 Metetra
.663 .742 .909 r
.68816 .43093 .691 .43442 .69702 .43254 .69418 .42905 Metetra
.662 .742 .909 r
.69418 .42905 .69702 .43254 .70304 .43066 .70022 .42717 Metetra
.662 .742 .91 r
.70022 .42717 .70304 .43066 .70909 .42878 .70627 .42528 Metetra
.661 .742 .91 r
.70627 .42528 .70909 .42878 .71514 .4269 .71234 .42341 Metetra
.66 .742 .911 r
.71234 .42341 .71514 .4269 .72121 .42503 .71842 .42154 Metetra
.659 .743 .912 r
.71842 .42154 .72121 .42503 .72729 .42316 .72451 .41968 Metetra
.658 .743 .913 r
.72451 .41968 .72729 .42316 .73339 .42131 .73062 .41784 Metetra
.657 .744 .914 r
.73062 .41784 .73339 .42131 .7395 .41947 .73674 .41601 Metetra
.655 .744 .916 r
.73674 .41601 .7395 .41947 .74563 .41765 .74288 .41421 Metetra
.653 .745 .918 r
.74288 .41421 .74563 .41765 .75177 .41585 .74903 .41243 Metetra
.65 .746 .92 r
.74903 .41243 .75177 .41585 .75793 .41407 .7552 .4107 Metetra
.647 .748 .923 r
.7552 .4107 .75793 .41407 .7641 .41233 .76139 .409 Metetra
.643 .75 .927 r
.76139 .409 .7641 .41233 .77029 .41063 .76759 .40735 Metetra
.638 .751 .93 r
.76759 .40735 .77029 .41063 .7765 .40898 .77382 .40575 Metetra
.633 .754 .935 r
.77382 .40575 .7765 .40898 .78273 .40737 .78006 .4042 Metetra
.628 .756 .939 r
.78006 .4042 .78273 .40737 .78898 .40582 .78633 .40271 Metetra
.623 .759 .944 r
.78633 .40271 .78898 .40582 .79525 .40432 .79261 .40127 Metetra
.618 .762 .948 r
.79261 .40127 .79525 .40432 .80153 .40286 .79891 .39986 Metetra
.614 .765 .952 r
.79891 .39986 .80153 .40286 .80784 .40144 .80523 .39849 Metetra
.612 .768 .954 r
.80523 .39849 .80784 .40144 .81417 .40005 .81157 .39712 Metetra
.613 .77 .956 r
.81157 .39712 .81417 .40005 .82051 .39866 .81792 .39573 Metetra
.616 .773 .955 r
.81792 .39573 .82051 .39866 .82686 .39725 .82429 .3943 Metetra
.622 .774 .953 r
.82429 .3943 .82686 .39725 .83323 .3958 .83067 .3928 Metetra
.63 .774 .949 r
.83067 .3928 .83323 .3958 .83961 .39428 .83705 .39119 Metetra
.64 .772 .943 r
.83705 .39119 .83961 .39428 .84599 .39267 .84343 .38947 Metetra
.651 .769 .935 r
.84343 .38947 .84599 .39267 .85238 .39094 .84982 .38762 Metetra
.66 .764 .927 r
.84982 .38762 .85238 .39094 .85878 .3891 .85621 .38564 Metetra
.668 .759 .918 r
.85621 .38564 .85878 .3891 .86517 .38713 .8626 .38353 Metetra
.674 .754 .91 r
.8626 .38353 .86517 .38713 .87157 .38504 .869 .38133 Metetra
.678 .748 .904 r
.869 .38133 .87157 .38504 .87797 .38286 .8754 .37904 Metetra
.68 .744 .899 r
.8754 .37904 .87797 .38286 .88437 .3806 .88181 .37672 Metetra
.681 .741 .896 r
.88181 .37672 .88437 .3806 .89079 .3783 .88823 .37439 Metetra
.679 .739 .896 r
.88823 .37439 .89079 .3783 .89721 .37598 .89466 .37207 Metetra
.677 .738 .897 r
.89466 .37207 .89721 .37598 .90365 .37368 .90112 .36979 Metetra
.674 .739 .899 r
.90112 .36979 .90365 .37368 .91011 .3714 .90759 .36755 Metetra
.671 .74 .902 r
.90759 .36755 .91011 .3714 .91659 .36917 .91409 .36537 Metetra
.668 .742 .906 r
.91409 .36537 .91659 .36917 .92308 .36699 .9206 .36323 Metetra
.657 .743 .913 r
.33449 .5438 .33782 .54684 .34313 .54519 .3398 .54221 Metetra
.661 .748 .915 r
.3398 .54221 .34313 .54519 .34845 .5435 .34513 .54055 Metetra
.664 .752 .916 r
.34513 .54055 .34845 .5435 .35378 .5418 .35047 .53885 Metetra
.665 .753 .915 r
.35047 .53885 .35378 .5418 .35912 .54013 .35582 .53713 Metetra
.663 .749 .914 r
.35582 .53713 .35912 .54013 .36447 .53857 .36118 .53544 Metetra
.657 .74 .911 r
.36118 .53544 .36447 .53857 .36982 .53714 .36655 .53384 Metetra
.647 .726 .906 r
.36655 .53384 .36982 .53714 .37518 .5359 .37192 .53238 Metetra
.634 .71 .901 r
.37192 .53238 .37518 .5359 .38054 .53483 .37729 .5311 Metetra
.62 .693 .896 r
.37729 .5311 .38054 .53483 .38591 .53392 .38267 .53003 Metetra
.608 .681 .893 r
.38267 .53003 .38591 .53392 .39128 .53309 .38805 .52913 Metetra
.6 .674 .892 r
.38805 .52913 .39128 .53309 .39667 .53225 .39344 .52834 Metetra
.599 .677 .895 r
.39344 .52834 .39667 .53225 .40208 .53128 .39885 .52756 Metetra
.606 .69 .902 r
.39885 .52756 .40208 .53128 .40751 .5301 .40427 .52666 Metetra
.62 .713 .912 r
.40427 .52666 .40751 .5301 .41296 .5286 .40972 .52554 Metetra
.642 .743 .923 r
.40972 .52554 .41296 .5286 .41844 .52677 .41519 .5241 Metetra
.666 .777 .932 r
.41519 .5241 .41844 .52677 .42393 .52459 .42068 .5223 Metetra
.692 .81 .938 r
.42068 .5223 .42393 .52459 .42945 .5221 .42619 .52013 Metetra
.714 .837 .941 r
.42619 .52013 .42945 .5221 .43497 .51939 .43173 .51762 Metetra
.73 .855 .94 r
.43173 .51762 .43497 .51939 .44051 .51653 .43728 .51486 Metetra
.74 .864 .938 r
.43728 .51486 .44051 .51653 .44606 .51361 .44284 .51193 Metetra
.744 .864 .935 r
.44284 .51193 .44606 .51361 .45162 .51072 .4484 .50894 Metetra
.743 .857 .933 r
.4484 .50894 .45162 .51072 .45718 .50791 .45398 .50598 Metetra
.737 .845 .931 r
.45398 .50598 .45718 .50791 .46275 .50524 .45956 .5031 Metetra
.728 .83 .928 r
.45956 .5031 .46275 .50524 .46832 .50271 .46515 .50036 Metetra
.718 .814 .925 r
.46515 .50036 .46832 .50271 .4739 .50032 .47074 .49778 Metetra
.707 .799 .922 r
.47074 .49778 .4739 .50032 .47949 .49807 .47634 .49535 Metetra
.697 .785 .919 r
.47634 .49535 .47949 .49807 .48508 .49593 .48194 .49307 Metetra
.689 .774 .916 r
.48194 .49307 .48508 .49593 .49068 .49389 .48756 .49091 Metetra
.682 .765 .914 r
.48756 .49091 .49068 .49389 .4963 .49192 .49318 .48885 Metetra
.677 .758 .912 r
.49318 .48885 .4963 .49192 .50192 .49 .49881 .48686 Metetra
.673 .753 .911 r
.49881 .48686 .50192 .49 .50756 .48812 .50445 .48493 Metetra
.67 .75 .91 r
.50445 .48493 .50756 .48812 .51321 .48627 .51011 .48304 Metetra
.668 .747 .909 r
.51011 .48304 .51321 .48627 .51886 .48443 .51577 .48118 Metetra
.667 .745 .909 r
.51577 .48118 .51886 .48443 .52453 .48261 .52145 .47933 Metetra
.666 .744 .909 r
.52145 .47933 .52453 .48261 .53021 .48079 .52714 .47749 Metetra
.665 .743 .908 r
.52714 .47749 .53021 .48079 .53591 .47897 .53284 .47567 Metetra
.665 .743 .908 r
.53284 .47567 .53591 .47897 .54161 .47716 .53855 .47384 Metetra
.664 .742 .908 r
.53855 .47384 .54161 .47716 .54733 .47535 .54428 .47202 Metetra
.664 .742 .908 r
.54428 .47202 .54733 .47535 .55305 .47353 .55001 .47019 Metetra
.664 .742 .908 r
.55001 .47019 .55305 .47353 .55879 .47172 .55576 .46837 Metetra
.664 .742 .908 r
.55576 .46837 .55879 .47172 .56455 .4699 .56152 .46654 Metetra
.664 .741 .908 r
.56152 .46654 .56455 .4699 .57031 .46808 .56729 .46471 Metetra
.664 .741 .908 r
.56729 .46471 .57031 .46808 .57609 .46625 .57308 .46288 Metetra
.664 .741 .908 r
.57308 .46288 .57609 .46625 .58187 .46443 .57887 .46104 Metetra
.664 .741 .908 r
.57887 .46104 .58187 .46443 .58767 .4626 .58468 .45921 Metetra
.664 .741 .908 r
.58468 .45921 .58767 .4626 .59349 .46076 .5905 .45736 Metetra
.664 .741 .908 r
.5905 .45736 .59349 .46076 .59931 .45892 .59633 .45552 Metetra
.664 .741 .908 r
.59633 .45552 .59931 .45892 .60515 .45708 .60218 .45367 Metetra
.664 .741 .908 r
.60218 .45367 .60515 .45708 .61099 .45524 .60803 .45182 Metetra
.664 .741 .908 r
.60803 .45182 .61099 .45524 .61686 .45339 .6139 .44996 Metetra
.664 .741 .908 r
.6139 .44996 .61686 .45339 .62273 .45153 .61978 .4481 Metetra
.664 .741 .908 r
.61978 .4481 .62273 .45153 .62861 .44968 .62568 .44624 Metetra
.663 .741 .908 r
.62568 .44624 .62861 .44968 .63451 .44782 .63158 .44437 Metetra
.663 .741 .908 r
.63158 .44437 .63451 .44782 .64042 .44595 .6375 .4425 Metetra
.663 .741 .908 r
.6375 .4425 .64042 .44595 .64635 .44409 .64343 .44063 Metetra
.663 .741 .908 r
.64343 .44063 .64635 .44409 .65228 .44221 .64938 .43875 Metetra
.663 .741 .908 r
.64938 .43875 .65228 .44221 .65823 .44034 .65533 .43687 Metetra
.663 .741 .908 r
.65533 .43687 .65823 .44034 .66419 .43846 .6613 .43498 Metetra
.663 .741 .908 r
.6613 .43498 .66419 .43846 .67016 .43658 .66729 .4331 Metetra
.663 .741 .908 r
.66729 .4331 .67016 .43658 .67615 .4347 .67328 .43121 Metetra
.663 .741 .909 r
.67328 .43121 .67615 .4347 .68215 .43282 .67929 .42932 Metetra
.663 .742 .909 r
.67929 .42932 .68215 .43282 .68816 .43093 .68531 .42744 Metetra
.662 .742 .909 r
.68531 .42744 .68816 .43093 .69418 .42905 .69134 .42555 Metetra
.662 .742 .909 r
.69134 .42555 .69418 .42905 .70022 .42717 .69739 .42366 Metetra
.661 .742 .91 r
.69739 .42366 .70022 .42717 .70627 .42528 .70345 .42179 Metetra
.66 .742 .911 r
.70345 .42179 .70627 .42528 .71234 .42341 .70953 .41991 Metetra
.659 .743 .912 r
.70953 .41991 .71234 .42341 .71842 .42154 .71562 .41805 Metetra
.658 .743 .913 r
.71562 .41805 .71842 .42154 .72451 .41968 .72172 .4162 Metetra
.657 .744 .914 r
.72172 .4162 .72451 .41968 .73062 .41784 .72784 .41438 Metetra
.655 .744 .916 r
.72784 .41438 .73062 .41784 .73674 .41601 .73397 .41257 Metetra
.653 .745 .918 r
.73397 .41257 .73674 .41601 .74288 .41421 .74012 .41079 Metetra
.65 .746 .92 r
.74012 .41079 .74288 .41421 .74903 .41243 .74628 .40905 Metetra
.646 .748 .923 r
.74628 .40905 .74903 .41243 .7552 .4107 .75247 .40736 Metetra
.642 .75 .927 r
.75247 .40736 .7552 .4107 .76139 .409 .75867 .40571 Metetra
.637 .752 .931 r
.75867 .40571 .76139 .409 .76759 .40735 .76489 .40411 Metetra
.632 .754 .935 r
.76489 .40411 .76759 .40735 .77382 .40575 .77113 .40258 Metetra
.627 .757 .94 r
.77113 .40258 .77382 .40575 .78006 .4042 .77739 .4011 Metetra
.621 .76 .945 r
.77739 .4011 .78006 .4042 .78633 .40271 .78367 .39967 Metetra
.616 .763 .95 r
.78367 .39967 .78633 .40271 .79261 .40127 .78997 .39829 Metetra
.612 .766 .953 r
.78997 .39829 .79261 .40127 .79891 .39986 .79628 .39694 Metetra
.609 .769 .956 r
.79628 .39694 .79891 .39986 .80523 .39849 .80262 .39559 Metetra
.61 .772 .958 r
.80262 .39559 .80523 .39849 .81157 .39712 .80897 .39423 Metetra
.613 .774 .958 r
.80897 .39423 .81157 .39712 .81792 .39573 .81533 .39281 Metetra
.62 .775 .955 r
.81533 .39281 .81792 .39573 .82429 .3943 .8217 .39132 Metetra
.629 .775 .951 r
.8217 .39132 .82429 .3943 .83067 .3928 .82808 .38973 Metetra
.64 .774 .944 r
.82808 .38973 .83067 .3928 .83705 .39119 .83446 .38801 Metetra
.651 .77 .936 r
.83446 .38801 .83705 .39119 .84343 .38947 .84085 .38615 Metetra
.661 .765 .927 r
.84085 .38615 .84343 .38947 .84982 .38762 .84723 .38415 Metetra
.669 .76 .918 r
.84723 .38415 .84982 .38762 .85621 .38564 .85362 .38203 Metetra
.676 .754 .91 r
.85362 .38203 .85621 .38564 .8626 .38353 .86001 .3798 Metetra
.68 .748 .903 r
.86001 .3798 .8626 .38353 .869 .38133 .86641 .3775 Metetra
.681 .744 .898 r
.86641 .3775 .869 .38133 .8754 .37904 .87281 .37515 Metetra
.681 .74 .896 r
.87281 .37515 .8754 .37904 .88181 .37672 .87923 .3728 Metetra
.68 .738 .895 r
.87923 .3728 .88181 .37672 .88823 .37439 .88566 .37046 Metetra
.677 .738 .896 r
.88566 .37046 .88823 .37439 .89466 .37207 .89211 .36817 Metetra
.674 .739 .899 r
.89211 .36817 .89466 .37207 .90112 .36979 .89858 .36594 Metetra
.671 .741 .903 r
.89858 .36594 .90112 .36979 .90759 .36755 .90507 .36375 Metetra
.668 .743 .906 r
.90507 .36375 .90759 .36755 .91409 .36537 .91158 .36161 Metetra
.666 .745 .91 r
.91158 .36161 .91409 .36537 .9206 .36323 .91812 .35951 Metetra
.653 .737 .911 r
.33115 .54066 .33449 .5438 .3398 .54221 .33647 .53913 Metetra
.656 .742 .913 r
.33647 .53913 .3398 .54221 .34513 .54055 .3418 .53754 Metetra
.66 .747 .915 r
.3418 .53754 .34513 .54055 .35047 .53885 .34714 .5359 Metetra
.664 .752 .916 r
.34714 .5359 .35047 .53885 .35582 .53713 .3525 .53419 Metetra
.666 .754 .916 r
.3525 .53419 .35582 .53713 .36118 .53544 .35787 .53245 Metetra
.665 .751 .915 r
.35787 .53245 .36118 .53544 .36655 .53384 .36325 .53073 Metetra
.659 .743 .912 r
.36325 .53073 .36655 .53384 .37192 .53238 .36863 .52909 Metetra
.649 .729 .907 r
.36863 .52909 .37192 .53238 .37729 .5311 .37402 .52759 Metetra
.635 .712 .902 r
.37402 .52759 .37729 .5311 .38267 .53003 .37941 .52629 Metetra
.62 .694 .896 r
.37941 .52629 .38267 .53003 .38805 .52913 .38481 .5252 Metetra
.607 .679 .892 r
.38481 .5252 .38805 .52913 .39344 .52834 .39021 .52431 Metetra
.597 .67 .891 r
.39021 .52431 .39344 .52834 .39885 .52756 .39562 .52356 Metetra
.595 .671 .893 r
.39562 .52356 .39885 .52756 .40427 .52666 .40104 .52283 Metetra
.6 .683 .9 r
.40104 .52283 .40427 .52666 .40972 .52554 .40648 .52201 Metetra
.614 .706 .91 r
.40648 .52201 .40972 .52554 .41519 .5241 .41194 .52097 Metetra
.636 .738 .922 r
.41194 .52097 .41519 .5241 .42068 .5223 .41743 .51959 Metetra
.663 .775 .933 r
.41743 .51959 .42068 .5223 .42619 .52013 .42294 .51784 Metetra
.69 .811 .94 r
.42294 .51784 .42619 .52013 .43173 .51762 .42847 .51568 Metetra
.714 .84 .942 r
.42847 .51568 .43173 .51762 .43728 .51486 .43402 .51315 Metetra
.732 .861 .941 r
.43402 .51315 .43728 .51486 .44284 .51193 .43959 .51034 Metetra
.744 .871 .939 r
.43959 .51034 .44284 .51193 .4484 .50894 .44517 .50735 Metetra
.748 .871 .936 r
.44517 .50735 .4484 .50894 .45398 .50598 .45076 .50428 Metetra
.747 .864 .934 r
.45076 .50428 .45398 .50598 .45956 .5031 .45635 .50123 Metetra
.741 .851 .931 r
.45635 .50123 .45956 .5031 .46515 .50036 .46195 .49828 Metetra
.732 .835 .929 r
.46195 .49828 .46515 .50036 .47074 .49778 .46756 .49547 Metetra
.721 .818 .926 r
.46756 .49547 .47074 .49778 .47634 .49535 .47317 .49283 Metetra
.709 .802 .922 r
.47317 .49283 .47634 .49535 .48194 .49307 .47879 .49036 Metetra
.699 .787 .919 r
.47879 .49036 .48194 .49307 .48756 .49091 .48441 .48804 Metetra
.69 .775 .916 r
.48441 .48804 .48756 .49091 .49318 .48885 .49004 .48585 Metetra
.683 .766 .914 r
.49004 .48585 .49318 .48885 .49881 .48686 .49569 .48377 Metetra
.677 .759 .912 r
.49569 .48377 .49881 .48686 .50445 .48493 .50134 .48177 Metetra
.673 .753 .911 r
.50134 .48177 .50445 .48493 .51011 .48304 .507 .47983 Metetra
.67 .75 .91 r
.507 .47983 .51011 .48304 .51577 .48118 .51267 .47793 Metetra
.668 .747 .909 r
.51267 .47793 .51577 .48118 .52145 .47933 .51836 .47605 Metetra
.667 .745 .909 r
.51836 .47605 .52145 .47933 .52714 .47749 .52406 .4742 Metetra
.666 .744 .909 r
.52406 .4742 .52714 .47749 .53284 .47567 .52976 .47235 Metetra
.665 .743 .908 r
.52976 .47235 .53284 .47567 .53855 .47384 .53548 .47051 Metetra
.665 .743 .908 r
.53548 .47051 .53855 .47384 .54428 .47202 .54121 .46868 Metetra
.664 .742 .908 r
.54121 .46868 .54428 .47202 .55001 .47019 .54696 .46684 Metetra
.664 .742 .908 r
.54696 .46684 .55001 .47019 .55576 .46837 .55271 .46501 Metetra
.664 .742 .908 r
.55271 .46501 .55576 .46837 .56152 .46654 .55848 .46317 Metetra
.664 .742 .908 r
.55848 .46317 .56152 .46654 .56729 .46471 .56426 .46134 Metetra
.664 .742 .908 r
.56426 .46134 .56729 .46471 .57308 .46288 .57005 .4595 Metetra
.664 .742 .908 r
.57005 .4595 .57308 .46288 .57887 .46104 .57586 .45765 Metetra
.664 .742 .908 r
.57586 .45765 .57887 .46104 .58468 .45921 .58167 .45581 Metetra
.664 .742 .908 r
.58167 .45581 .58468 .45921 .5905 .45736 .5875 .45396 Metetra
.664 .742 .908 r
.5875 .45396 .5905 .45736 .59633 .45552 .59334 .45211 Metetra
.664 .741 .908 r
.59334 .45211 .59633 .45552 .60218 .45367 .59919 .45025 Metetra
.664 .741 .908 r
.59919 .45025 .60218 .45367 .60803 .45182 .60506 .44839 Metetra
.664 .741 .908 r
.60506 .44839 .60803 .45182 .6139 .44996 .61094 .44653 Metetra
.664 .741 .908 r
.61094 .44653 .6139 .44996 .61978 .4481 .61683 .44466 Metetra
.663 .741 .908 r
.61683 .44466 .61978 .4481 .62568 .44624 .62273 .44279 Metetra
.663 .741 .908 r
.62273 .44279 .62568 .44624 .63158 .44437 .62864 .44091 Metetra
.663 .741 .908 r
.62864 .44091 .63158 .44437 .6375 .4425 .63457 .43904 Metetra
.663 .741 .908 r
.63457 .43904 .6375 .4425 .64343 .44063 .64051 .43716 Metetra
.663 .742 .908 r
.64051 .43716 .64343 .44063 .64938 .43875 .64646 .43527 Metetra
.663 .742 .908 r
.64646 .43527 .64938 .43875 .65533 .43687 .65243 .43339 Metetra
.663 .742 .908 r
.65243 .43339 .65533 .43687 .6613 .43498 .65841 .4315 Metetra
.663 .742 .908 r
.65841 .4315 .6613 .43498 .66729 .4331 .6644 .42961 Metetra
.663 .742 .909 r
.6644 .42961 .66729 .4331 .67328 .43121 .6704 .42771 Metetra
.663 .742 .909 r
.6704 .42771 .67328 .43121 .67929 .42932 .67642 .42582 Metetra
.662 .742 .909 r
.67642 .42582 .67929 .42932 .68531 .42744 .68245 .42393 Metetra
.662 .742 .91 r
.68245 .42393 .68531 .42744 .69134 .42555 .68849 .42204 Metetra
.661 .742 .91 r
.68849 .42204 .69134 .42555 .69739 .42366 .69455 .42016 Metetra
.66 .742 .911 r
.69455 .42016 .69739 .42366 .70345 .42179 .70062 .41828 Metetra
.659 .743 .912 r
.70062 .41828 .70345 .42179 .70953 .41991 .7067 .41642 Metetra
.658 .743 .913 r
.7067 .41642 .70953 .41991 .71562 .41805 .7128 .41457 Metetra
.657 .744 .914 r
.7128 .41457 .71562 .41805 .72172 .4162 .71892 .41274 Metetra
.655 .745 .916 r
.71892 .41274 .72172 .4162 .72784 .41438 .72504 .41093 Metetra
.652 .745 .918 r
.72504 .41093 .72784 .41438 .73397 .41257 .73119 .40915 Metetra
.649 .747 .921 r
.73119 .40915 .73397 .41257 .74012 .41079 .73735 .40741 Metetra
.646 .748 .924 r
.73735 .40741 .74012 .41079 .74628 .40905 .74353 .40572 Metetra
.642 .75 .927 r
.74353 .40572 .74628 .40905 .75247 .40736 .74973 .40407 Metetra
.637 .752 .932 r
.74973 .40407 .75247 .40736 .75867 .40571 .75594 .40248 Metetra
.631 .754 .936 r
.75594 .40248 .75867 .40571 .76489 .40411 .76218 .40096 Metetra
.625 .757 .941 r
.76218 .40096 .76489 .40411 .77113 .40258 .76843 .39949 Metetra
.619 .76 .946 r
.76843 .39949 .77113 .40258 .77739 .4011 .77471 .39808 Metetra
.613 .763 .951 r
.77471 .39808 .77739 .4011 .78367 .39967 .78101 .39672 Metetra
.609 .767 .955 r
.78101 .39672 .78367 .39967 .78997 .39829 .78732 .39539 Metetra
.606 .77 .958 r
.78732 .39539 .78997 .39829 .79628 .39694 .79365 .39407 Metetra
.606 .773 .96 r
.79365 .39407 .79628 .39694 .80262 .39559 .8 .39273 Metetra
.61 .776 .96 r
.8 .39273 .80262 .39559 .80897 .39423 .80636 .39134 Metetra
.617 .777 .957 r
.80636 .39134 .80897 .39423 .81533 .39281 .81273 .38986 Metetra
.627 .777 .953 r
.81273 .38986 .81533 .39281 .8217 .39132 .8191 .38828 Metetra
.639 .775 .946 r
.8191 .38828 .8217 .39132 .82808 .38973 .82548 .38656 Metetra
.651 .772 .937 r
.82548 .38656 .82808 .38973 .83446 .38801 .83186 .38469 Metetra
.662 .766 .928 r
.83186 .38469 .83446 .38801 .84085 .38615 .83824 .38268 Metetra
.671 .76 .918 r
.83824 .38268 .84085 .38615 .84723 .38415 .84462 .38054 Metetra
.677 .754 .909 r
.84462 .38054 .84723 .38415 .85362 .38203 .85101 .37828 Metetra
.681 .748 .902 r
.85101 .37828 .85362 .38203 .86001 .3798 .8574 .37595 Metetra
.682 .743 .897 r
.8574 .37595 .86001 .3798 .86641 .3775 .8638 .37358 Metetra
.682 .74 .895 r
.8638 .37358 .86641 .3775 .87281 .37515 .87021 .37121 Metetra
.68 .738 .894 r
.87021 .37121 .87281 .37515 .87923 .3728 .87664 .36886 Metetra
.677 .738 .896 r
.87664 .36886 .87923 .3728 .88566 .37046 .88309 .36656 Metetra
.674 .739 .899 r
.88309 .36656 .88566 .37046 .89211 .36817 .88955 .36433 Metetra
.671 .741 .903 r
.88955 .36433 .89211 .36817 .89858 .36594 .89604 .36214 Metetra
.668 .744 .907 r
.89604 .36214 .89858 .36594 .90507 .36375 .90255 .36001 Metetra
.665 .746 .91 r
.90255 .36001 .90507 .36375 .91158 .36161 .90908 .35791 Metetra
.664 .748 .913 r
.90908 .35791 .91158 .36161 .91812 .35951 .91562 .35582 Metetra
.65 .732 .909 r
.32781 .53745 .33115 .54066 .33647 .53913 .33313 .53595 Metetra
.651 .735 .91 r
.33313 .53595 .33647 .53913 .3418 .53754 .33846 .53442 Metetra
.654 .74 .912 r
.33846 .53442 .3418 .53754 .34714 .5359 .34381 .53285 Metetra
.659 .746 .915 r
.34381 .53285 .34714 .5359 .3525 .53419 .34917 .53121 Metetra
.663 .752 .916 r
.34917 .53121 .3525 .53419 .35787 .53245 .35454 .52951 Metetra
.666 .755 .917 r
.35454 .52951 .35787 .53245 .36325 .53073 .35993 .52776 Metetra
.666 .754 .916 r
.35993 .52776 .36325 .53073 .36863 .52909 .36532 .52601 Metetra
.661 .746 .913 r
.36532 .52601 .36863 .52909 .37402 .52759 .37073 .52432 Metetra
.651 .732 .908 r
.37073 .52432 .37402 .52759 .37941 .52629 .37614 .52278 Metetra
.637 .714 .903 r
.37614 .52278 .37941 .52629 .38481 .5252 .38155 .52144 Metetra
.621 .694 .896 r
.38155 .52144 .38481 .5252 .39021 .52431 .38696 .52033 Metetra
.606 .677 .891 r
.38696 .52033 .39021 .52431 .39562 .52356 .39238 .51945 Metetra
.595 .666 .889 r
.39238 .51945 .39562 .52356 .40104 .52283 .39781 .51873 Metetra
.59 .665 .891 r
.39781 .51873 .40104 .52283 .40648 .52201 .40325 .51807 Metetra
.594 .676 .897 r
.40325 .51807 .40648 .52201 .41194 .52097 .4087 .51733 Metetra
.608 .699 .908 r
.4087 .51733 .41194 .52097 .41743 .51959 .41418 .51637 Metetra
.63 .732 .921 r
.41418 .51637 .41743 .51959 .42294 .51784 .41968 .51507 Metetra
.658 .771 .933 r
.41968 .51507 .42294 .51784 .42847 .51568 .42521 .51337 Metetra
.687 .81 .941 r
.42521 .51337 .42847 .51568 .43402 .51315 .43076 .51123 Metetra
.714 .843 .944 r
.43076 .51123 .43402 .51315 .43959 .51034 .43633 .50869 Metetra
.734 .866 .943 r
.43633 .50869 .43959 .51034 .44517 .50735 .44192 .50584 Metetra
.747 .878 .94 r
.44192 .50584 .44517 .50735 .45076 .50428 .44752 .50277 Metetra
.753 .879 .937 r
.44752 .50277 .45076 .50428 .45635 .50123 .45313 .49962 Metetra
.752 .872 .934 r
.45313 .49962 .45635 .50123 .46195 .49828 .45874 .49648 Metetra
.746 .859 .932 r
.45874 .49648 .46195 .49828 .46756 .49547 .46436 .49344 Metetra
.736 .841 .93 r
.46436 .49344 .46756 .49547 .47317 .49283 .46999 .49056 Metetra
.724 .823 .926 r
.46999 .49056 .47317 .49283 .47879 .49036 .47562 .48786 Metetra
.712 .805 .923 r
.47562 .48786 .47879 .49036 .48441 .48804 .48125 .48534 Metetra
.701 .789 .92 r
.48125 .48534 .48441 .48804 .49004 .48585 .4869 .48298 Metetra
.691 .776 .917 r
.4869 .48298 .49004 .48585 .49569 .48377 .49255 .48077 Metetra
.683 .766 .914 r
.49255 .48077 .49569 .48377 .50134 .48177 .49821 .47867 Metetra
.678 .759 .912 r
.49821 .47867 .50134 .48177 .507 .47983 .50388 .47665 Metetra
.673 .753 .911 r
.50388 .47665 .507 .47983 .51267 .47793 .50956 .4747 Metetra
.67 .75 .91 r
.50956 .4747 .51267 .47793 .51836 .47605 .51525 .47279 Metetra
.668 .747 .909 r
.51525 .47279 .51836 .47605 .52406 .4742 .52096 .4709 Metetra
.667 .745 .909 r
.52096 .4709 .52406 .4742 .52976 .47235 .52667 .46903 Metetra
.666 .744 .909 r
.52667 .46903 .52976 .47235 .53548 .47051 .5324 .46718 Metetra
.665 .743 .908 r
.5324 .46718 .53548 .47051 .54121 .46868 .53814 .46533 Metetra
.665 .743 .908 r
.53814 .46533 .54121 .46868 .54696 .46684 .54389 .46348 Metetra
.664 .742 .908 r
.54389 .46348 .54696 .46684 .55271 .46501 .54966 .46164 Metetra
.664 .742 .908 r
.54966 .46164 .55271 .46501 .55848 .46317 .55543 .45979 Metetra
.664 .742 .908 r
.55543 .45979 .55848 .46317 .56426 .46134 .56122 .45795 Metetra
.664 .742 .908 r
.56122 .45795 .56426 .46134 .57005 .4595 .56702 .4561 Metetra
.664 .741 .908 r
.56702 .4561 .57005 .4595 .57586 .45765 .57283 .45425 Metetra
.664 .741 .908 r
.57283 .45425 .57586 .45765 .58167 .45581 .57866 .45239 Metetra
.664 .741 .908 r
.57866 .45239 .58167 .45581 .5875 .45396 .58449 .45054 Metetra
.664 .741 .908 r
.58449 .45054 .5875 .45396 .59334 .45211 .59034 .44868 Metetra
.664 .741 .908 r
.59034 .44868 .59334 .45211 .59919 .45025 .5962 .44681 Metetra
.664 .741 .908 r
.5962 .44681 .59919 .45025 .60506 .44839 .60208 .44495 Metetra
.664 .741 .908 r
.60208 .44495 .60506 .44839 .61094 .44653 .60796 .44307 Metetra
.664 .741 .908 r
.60796 .44307 .61094 .44653 .61683 .44466 .61386 .4412 Metetra
.663 .741 .908 r
.61386 .4412 .61683 .44466 .62273 .44279 .61977 .43932 Metetra
.663 .741 .908 r
.61977 .43932 .62273 .44279 .62864 .44091 .62569 .43744 Metetra
.663 .741 .908 r
.62569 .43744 .62864 .44091 .63457 .43904 .63163 .43556 Metetra
.663 .741 .908 r
.63163 .43556 .63457 .43904 .64051 .43716 .63758 .43367 Metetra
.663 .741 .908 r
.63758 .43367 .64051 .43716 .64646 .43527 .64354 .43178 Metetra
.663 .741 .908 r
.64354 .43178 .64646 .43527 .65243 .43339 .64951 .42989 Metetra
.663 .741 .908 r
.64951 .42989 .65243 .43339 .65841 .4315 .6555 .42799 Metetra
.663 .741 .908 r
.6555 .42799 .65841 .4315 .6644 .42961 .6615 .4261 Metetra
.663 .741 .909 r
.6615 .4261 .6644 .42961 .6704 .42771 .66751 .4242 Metetra
.662 .742 .909 r
.66751 .4242 .6704 .42771 .67642 .42582 .67354 .42231 Metetra
.662 .742 .909 r
.67354 .42231 .67642 .42582 .68245 .42393 .67958 .42042 Metetra
.661 .742 .91 r
.67958 .42042 .68245 .42393 .68849 .42204 .68563 .41853 Metetra
.66 .742 .911 r
.68563 .41853 .68849 .42204 .69455 .42016 .6917 .41665 Metetra
.659 .743 .911 r
.6917 .41665 .69455 .42016 .70062 .41828 .69778 .41478 Metetra
.658 .743 .913 r
.69778 .41478 .70062 .41828 .7067 .41642 .70387 .41293 Metetra
.657 .744 .914 r
.70387 .41293 .7067 .41642 .7128 .41457 .70998 .41109 Metetra
.655 .744 .916 r
.70998 .41109 .7128 .41457 .71892 .41274 .7161 .40928 Metetra
.652 .745 .918 r
.7161 .40928 .71892 .41274 .72504 .41093 .72224 .4075 Metetra
.649 .747 .921 r
.72224 .4075 .72504 .41093 .73119 .40915 .7284 .40576 Metetra
.645 .748 .924 r
.7284 .40576 .73119 .40915 .73735 .40741 .73458 .40407 Metetra
.641 .75 .928 r
.73458 .40407 .73735 .40741 .74353 .40572 .74077 .40243 Metetra
.636 .752 .932 r
.74077 .40243 .74353 .40572 .74973 .40407 .74698 .40085 Metetra
.63 .755 .937 r
.74698 .40085 .74973 .40407 .75594 .40248 .75321 .39933 Metetra
.623 .757 .942 r
.75321 .39933 .75594 .40248 .76218 .40096 .75946 .39788 Metetra
.617 .761 .948 r
.75946 .39788 .76218 .40096 .76843 .39949 .76573 .39649 Metetra
.61 .764 .953 r
.76573 .39649 .76843 .39949 .77471 .39808 .77203 .39515 Metetra
.605 .768 .957 r
.77203 .39515 .77471 .39808 .78101 .39672 .77834 .39385 Metetra
.603 .771 .961 r
.77834 .39385 .78101 .39672 .78732 .39539 .78467 .39255 Metetra
.603 .774 .962 r
.78467 .39255 .78732 .39539 .79365 .39407 .79101 .39124 Metetra
.607 .777 .962 r
.79101 .39124 .79365 .39407 .8 .39273 .79737 .38987 Metetra
.615 .779 .96 r
.79737 .38987 .8 .39273 .80636 .39134 .80373 .38841 Metetra
.626 .779 .955 r
.80373 .38841 .80636 .39134 .81273 .38986 .8101 .38684 Metetra
.638 .777 .947 r
.8101 .38684 .81273 .38986 .8191 .38828 .81648 .38512 Metetra
.651 .773 .938 r
.81648 .38512 .8191 .38828 .82548 .38656 .82285 .38325 Metetra
.663 .767 .928 r
.82285 .38325 .82548 .38656 .83186 .38469 .82923 .38122 Metetra
.672 .761 .917 r
.82923 .38122 .83186 .38469 .83824 .38268 .83561 .37905 Metetra
.678 .754 .908 r
.83561 .37905 .83824 .38268 .84462 .38054 .84199 .37677 Metetra
.682 .748 .901 r
.84199 .37677 .84462 .38054 .85101 .37828 .84837 .37441 Metetra
.683 .743 .896 r
.84837 .37441 .85101 .37828 .8574 .37595 .85477 .37201 Metetra
.683 .739 .894 r
.85477 .37201 .8574 .37595 .8638 .37358 .86117 .36962 Metetra
.681 .738 .894 r
.86117 .36962 .8638 .37358 .87021 .37121 .8676 .36726 Metetra
.678 .738 .896 r
.8676 .36726 .87021 .37121 .87664 .36886 .87404 .36496 Metetra
.674 .739 .9 r
.87404 .36496 .87664 .36886 .88309 .36656 .88051 .36272 Metetra
.67 .741 .904 r
.88051 .36272 .88309 .36656 .88955 .36433 .887 .36054 Metetra
.667 .744 .908 r
.887 .36054 .88955 .36433 .89604 .36214 .8935 .35841 Metetra
.665 .747 .911 r
.8935 .35841 .89604 .36214 .90255 .36001 .90003 .35631 Metetra
.664 .749 .914 r
.90003 .35631 .90255 .36001 .90908 .35791 .90657 .35422 Metetra
.664 .751 .915 r
.90657 .35422 .90908 .35791 .91562 .35582 .91312 .35213 Metetra
.65 .731 .908 r
.32446 .5342 .32781 .53745 .33313 .53595 .32978 .5327 Metetra
.649 .731 .909 r
.32978 .5327 .33313 .53595 .33846 .53442 .33512 .5312 Metetra
.65 .733 .91 r
.33512 .5312 .33846 .53442 .34381 .53285 .34046 .52969 Metetra
.653 .738 .912 r
.34046 .52969 .34381 .53285 .34917 .53121 .34583 .52813 Metetra
.657 .744 .914 r
.34583 .52813 .34917 .53121 .35454 .52951 .3512 .52651 Metetra
.662 .751 .916 r
.3512 .52651 .35454 .52951 .35993 .52776 .35659 .52481 Metetra
.666 .756 .917 r
.35659 .52481 .35993 .52776 .36532 .52601 .362 .52305 Metetra
.667 .756 .917 r
.362 .52305 .36532 .52601 .37073 .52432 .36741 .52127 Metetra
.663 .749 .914 r
.36741 .52127 .37073 .52432 .37614 .52278 .37284 .51955 Metetra
.654 .736 .91 r
.37284 .51955 .37614 .52278 .38155 .52144 .37827 .51795 Metetra
.64 .717 .904 r
.37827 .51795 .38155 .52144 .38696 .52033 .3837 .51657 Metetra
.623 .695 .897 r
.3837 .51657 .38696 .52033 .39238 .51945 .38913 .51543 Metetra
.605 .676 .89 r
.38913 .51543 .39238 .51945 .39781 .51873 .39457 .51455 Metetra
.592 .662 .887 r
.39457 .51455 .39781 .51873 .40325 .51807 .40001 .51386 Metetra
.585 .659 .888 r
.40001 .51386 .40325 .51807 .4087 .51733 .40547 .51327 Metetra
.588 .668 .894 r
.40547 .51327 .4087 .51733 .41418 .51637 .41094 .51261 Metetra
.601 .69 .905 r
.41094 .51261 .41418 .51637 .41968 .51507 .41643 .51175 Metetra
.623 .724 .919 r
.41643 .51175 .41968 .51507 .42521 .51337 .42195 .51054 Metetra
.653 .766 .933 r
.42195 .51054 .42521 .51337 .43076 .51123 .42749 .5089 Metetra
.684 .809 .942 r
.42749 .5089 .43076 .51123 .43633 .50869 .43306 .50679 Metetra
.713 .846 .945 r
.43306 .50679 .43633 .50869 .44192 .50584 .43865 .50424 Metetra
.736 .872 .944 r
.43865 .50424 .44192 .50584 .44752 .50277 .44426 .50135 Metetra
.75 .885 .941 r
.44426 .50135 .44752 .50277 .45313 .49962 .44988 .49821 Metetra
.757 .888 .937 r
.44988 .49821 .45313 .49962 .45874 .49648 .45551 .49497 Metetra
.757 .88 .935 r
.45551 .49497 .45874 .49648 .46436 .49344 .46114 .49173 Metetra
.75 .866 .933 r
.46114 .49173 .46436 .49344 .46999 .49056 .46678 .4886 Metetra
.74 .848 .93 r
.46678 .4886 .46999 .49056 .47562 .48786 .47243 .48564 Metetra
.727 .828 .927 r
.47243 .48564 .47562 .48786 .48125 .48534 .47808 .48287 Metetra
.714 .809 .924 r
.47808 .48287 .48125 .48534 .4869 .48298 .48373 .48029 Metetra
.702 .792 .92 r
.48373 .48029 .4869 .48298 .49255 .48077 .48939 .4779 Metetra
.692 .778 .917 r
.48939 .4779 .49255 .48077 .49821 .47867 .49507 .47566 Metetra
.684 .767 .914 r
.49507 .47566 .49821 .47867 .50388 .47665 .50075 .47354 Metetra
.678 .759 .912 r
.50075 .47354 .50388 .47665 .50956 .4747 .50644 .4715 Metetra
.673 .753 .911 r
.50644 .4715 .50956 .4747 .51525 .47279 .51214 .46954 Metetra
.67 .75 .91 r
.51214 .46954 .51525 .47279 .52096 .4709 .51785 .46761 Metetra
.668 .747 .909 r
.51785 .46761 .52096 .4709 .52667 .46903 .52357 .46572 Metetra
.667 .745 .909 r
.52357 .46572 .52667 .46903 .5324 .46718 .52931 .46384 Metetra
.666 .744 .909 r
.52931 .46384 .5324 .46718 .53814 .46533 .53506 .46197 Metetra
.665 .743 .908 r
.53506 .46197 .53814 .46533 .54389 .46348 .54082 .46011 Metetra
.665 .743 .908 r
.54082 .46011 .54389 .46348 .54966 .46164 .54659 .45826 Metetra
.664 .742 .908 r
.54659 .45826 .54966 .46164 .55543 .45979 .55237 .4564 Metetra
.664 .742 .908 r
.55237 .4564 .55543 .45979 .56122 .45795 .55817 .45454 Metetra
.664 .742 .908 r
.55817 .45454 .56122 .45795 .56702 .4561 .56397 .45269 Metetra
.664 .742 .908 r
.56397 .45269 .56702 .4561 .57283 .45425 .56979 .45083 Metetra
.664 .741 .908 r
.56979 .45083 .57283 .45425 .57866 .45239 .57563 .44897 Metetra
.664 .741 .908 r
.57563 .44897 .57866 .45239 .58449 .45054 .58147 .4471 Metetra
.664 .741 .908 r
.58147 .4471 .58449 .45054 .59034 .44868 .58733 .44523 Metetra
.664 .741 .908 r
.58733 .44523 .59034 .44868 .5962 .44681 .5932 .44336 Metetra
.664 .741 .908 r
.5932 .44336 .5962 .44681 .60208 .44495 .59908 .44149 Metetra
.664 .741 .908 r
.59908 .44149 .60208 .44495 .60796 .44307 .60497 .43961 Metetra
.663 .741 .908 r
.60497 .43961 .60796 .44307 .61386 .4412 .61088 .43773 Metetra
.663 .741 .908 r
.61088 .43773 .61386 .4412 .61977 .43932 .6168 .43584 Metetra
.663 .741 .908 r
.6168 .43584 .61977 .43932 .62569 .43744 .62273 .43396 Metetra
.663 .741 .908 r
.62273 .43396 .62569 .43744 .63163 .43556 .62867 .43207 Metetra
.663 .741 .908 r
.62867 .43207 .63163 .43556 .63758 .43367 .63463 .43017 Metetra
.663 .741 .908 r
.63463 .43017 .63758 .43367 .64354 .43178 .6406 .42828 Metetra
.663 .741 .908 r
.6406 .42828 .64354 .43178 .64951 .42989 .64658 .42638 Metetra
.663 .742 .909 r
.64658 .42638 .64951 .42989 .6555 .42799 .65258 .42448 Metetra
.663 .742 .909 r
.65258 .42448 .6555 .42799 .6615 .4261 .65859 .42258 Metetra
.662 .742 .909 r
.65859 .42258 .6615 .4261 .66751 .4242 .66461 .42068 Metetra
.662 .742 .91 r
.66461 .42068 .66751 .4242 .67354 .42231 .67064 .41879 Metetra
.661 .742 .91 r
.67064 .41879 .67354 .42231 .67958 .42042 .67669 .4169 Metetra
.66 .742 .911 r
.67669 .4169 .67958 .42042 .68563 .41853 .68276 .41502 Metetra
.659 .743 .912 r
.68276 .41502 .68563 .41853 .6917 .41665 .68883 .41314 Metetra
.658 .743 .913 r
.68883 .41314 .6917 .41665 .69778 .41478 .69492 .41129 Metetra
.657 .744 .914 r
.69492 .41129 .69778 .41478 .70387 .41293 .70103 .40945 Metetra
.655 .745 .916 r
.70103 .40945 .70387 .41293 .70998 .41109 .70715 .40763 Metetra
.652 .745 .918 r
.70715 .40763 .70998 .41109 .7161 .40928 .71328 .40585 Metetra
.649 .747 .921 r
.71328 .40585 .7161 .40928 .72224 .4075 .71944 .40411 Metetra
.645 .748 .924 r
.71944 .40411 .72224 .4075 .7284 .40576 .72561 .40242 Metetra
.64 .75 .928 r
.72561 .40242 .7284 .40576 .73458 .40407 .73179 .40079 Metetra
.635 .752 .933 r
.73179 .40079 .73458 .40407 .74077 .40243 .738 .39921 Metetra
.628 .755 .938 r
.738 .39921 .74077 .40243 .74698 .40085 .74423 .39771 Metetra
.622 .758 .944 r
.74423 .39771 .74698 .40085 .75321 .39933 .75048 .39627 Metetra
.614 .761 .949 r
.75048 .39627 .75321 .39933 .75946 .39788 .75674 .3949 Metetra
.607 .765 .955 r
.75674 .3949 .75946 .39788 .76573 .39649 .76303 .39359 Metetra
.602 .769 .96 r
.76303 .39359 .76573 .39649 .77203 .39515 .76934 .39231 Metetra
.599 .772 .963 r
.76934 .39231 .77203 .39515 .77834 .39385 .77567 .39105 Metetra
.599 .776 .965 r
.77567 .39105 .77834 .39385 .78467 .39255 .78201 .38976 Metetra
.603 .779 .965 r
.78201 .38976 .78467 .39255 .79101 .39124 .78836 .38842 Metetra
.612 .781 .962 r
.78836 .38842 .79101 .39124 .79737 .38987 .79472 .38698 Metetra
.624 .781 .957 r
.79472 .38698 .79737 .38987 .80373 .38841 .80109 .38541 Metetra
.637 .779 .949 r
.80109 .38541 .80373 .38841 .8101 .38684 .80746 .3837 Metetra
.651 .775 .939 r
.80746 .3837 .8101 .38684 .81648 .38512 .81383 .38181 Metetra
.664 .768 .928 r
.81383 .38181 .81648 .38512 .82285 .38325 .8202 .37976 Metetra
.673 .761 .917 r
.8202 .37976 .82285 .38325 .82923 .38122 .82657 .37757 Metetra
.68 .754 .907 r
.82657 .37757 .82923 .38122 .83561 .37905 .83295 .37526 Metetra
.684 .748 .9 r
.83295 .37526 .83561 .37905 .84199 .37677 .83933 .37287 Metetra
.685 .742 .895 r
.83933 .37287 .84199 .37677 .84837 .37441 .84572 .37045 Metetra
.684 .739 .893 r
.84572 .37045 .84837 .37441 .85477 .37201 .85212 .36804 Metetra
.681 .737 .893 r
.85212 .36804 .85477 .37201 .86117 .36962 .85854 .36567 Metetra
.678 .738 .896 r
.85854 .36567 .86117 .36962 .8676 .36726 .86499 .36336 Metetra
.674 .739 .9 r
.86499 .36336 .8676 .36726 .87404 .36496 .87145 .36112 Metetra
.67 .742 .904 r
.87145 .36112 .87404 .36496 .88051 .36272 .87793 .35894 Metetra
.667 .745 .909 r
.87793 .35894 .88051 .36272 .887 .36054 .88444 .35682 Metetra
.665 .748 .912 r
.88444 .35682 .887 .36054 .8935 .35841 .89096 .35472 Metetra
.664 .75 .915 r
.89096 .35472 .8935 .35841 .90003 .35631 .8975 .35263 Metetra
.664 .751 .915 r
.8975 .35263 .90003 .35631 .90657 .35422 .90405 .35053 Metetra
.665 .752 .915 r
.90405 .35053 .90657 .35422 .91312 .35213 .91061 .34841 Metetra
.652 .733 .909 r
.32109 .53097 .32446 .5342 .32978 .5327 .32642 .52943 Metetra
.65 .73 .908 r
.32642 .52943 .32978 .5327 .33512 .5312 .33176 .52792 Metetra
.648 .729 .908 r
.33176 .52792 .33512 .5312 .34046 .52969 .33711 .52643 Metetra
.648 .731 .909 r
.33711 .52643 .34046 .52969 .34583 .52813 .34248 .52492 Metetra
.651 .736 .911 r
.34248 .52492 .34583 .52813 .3512 .52651 .34786 .52338 Metetra
.655 .742 .914 r
.34786 .52338 .3512 .52651 .35659 .52481 .35325 .52178 Metetra
.661 .75 .916 r
.35325 .52178 .35659 .52481 .362 .52305 .35866 .52009 Metetra
.666 .756 .918 r
.35866 .52009 .362 .52305 .36741 .52127 .36408 .51832 Metetra
.668 .758 .918 r
.36408 .51832 .36741 .52127 .37284 .51955 .36951 .51652 Metetra
.665 .753 .916 r
.36951 .51652 .37284 .51955 .37827 .51795 .37496 .51476 Metetra
.657 .74 .911 r
.37496 .51476 .37827 .51795 .3837 .51657 .38041 .51311 Metetra
.642 .721 .905 r
.38041 .51311 .3837 .51657 .38913 .51543 .38586 .51168 Metetra
.624 .697 .897 r
.38586 .51168 .38913 .51543 .39457 .51455 .39131 .51051 Metetra
.605 .675 .89 r
.39131 .51051 .39457 .51455 .40001 .51386 .39677 .50961 Metetra
.59 .659 .885 r
.39677 .50961 .40001 .51386 .40547 .51327 .40223 .50896 Metetra
.581 .652 .885 r
.40223 .50896 .40547 .51327 .41094 .51261 .4077 .50842 Metetra
.581 .659 .891 r
.4077 .50842 .41094 .51261 .41643 .51175 .41319 .50786 Metetra
.593 .681 .902 r
.41319 .50786 .41643 .51175 .42195 .51054 .4187 .5071 Metetra
.615 .716 .917 r
.4187 .5071 .42195 .51054 .42749 .5089 .42423 .506 Metetra
.646 .761 .932 r
.42423 .506 .42749 .5089 .43306 .50679 .42979 .50444 Metetra
.68 .808 .943 r
.42979 .50444 .43306 .50679 .43865 .50424 .43538 .50237 Metetra
.712 .849 .948 r
.43538 .50237 .43865 .50424 .44426 .50135 .44098 .49982 Metetra
.737 .878 .946 r
.44098 .49982 .44426 .50135 .44988 .49821 .44661 .49688 Metetra
.753 .894 .941 r
.44661 .49688 .44988 .49821 .45551 .49497 .45225 .49367 Metetra
.761 .897 .938 r
.45225 .49367 .45551 .49497 .46114 .49173 .4579 .49033 Metetra
.762 .89 .935 r
.4579 .49033 .46114 .49173 .46678 .4886 .46356 .48699 Metetra
.756 .875 .933 r
.46356 .48699 .46678 .4886 .47243 .48564 .46922 .48376 Metetra
.745 .856 .931 r
.46922 .48376 .47243 .48564 .47808 .48287 .47488 .4807 Metetra
.731 .834 .928 r
.47488 .4807 .47808 .48287 .48373 .48029 .48055 .47786 Metetra
.717 .813 .925 r
.48055 .47786 .48373 .48029 .48939 .4779 .48623 .47523 Metetra
.705 .795 .921 r
.48623 .47523 .48939 .4779 .49507 .47566 .49191 .47279 Metetra
.694 .78 .917 r
.49191 .47279 .49507 .47566 .50075 .47354 .4976 .47052 Metetra
.685 .768 .915 r
.4976 .47052 .50075 .47354 .50644 .4715 .5033 .46838 Metetra
.678 .76 .913 r
.5033 .46838 .50644 .4715 .51214 .46954 .50901 .46633 Metetra
.674 .754 .911 r
.50901 .46633 .51214 .46954 .51785 .46761 .51473 .46435 Metetra
.67 .75 .91 r
.51473 .46435 .51785 .46761 .52357 .46572 .52046 .46241 Metetra
.668 .747 .91 r
.52046 .46241 .52357 .46572 .52931 .46384 .5262 .46051 Metetra
.667 .745 .909 r
.5262 .46051 .52931 .46384 .53506 .46197 .53196 .45862 Metetra
.666 .744 .909 r
.53196 .45862 .53506 .46197 .54082 .46011 .53773 .45674 Metetra
.665 .743 .909 r
.53773 .45674 .54082 .46011 .54659 .45826 .54351 .45487 Metetra
.665 .743 .908 r
.54351 .45487 .54659 .45826 .55237 .4564 .5493 .45301 Metetra
.664 .743 .908 r
.5493 .45301 .55237 .4564 .55817 .45454 .5551 .45114 Metetra
.664 .742 .908 r
.5551 .45114 .55817 .45454 .56397 .45269 .56092 .44927 Metetra
.664 .742 .908 r
.56092 .44927 .56397 .45269 .56979 .45083 .56675 .4474 Metetra
.664 .742 .908 r
.56675 .4474 .56979 .45083 .57563 .44897 .57259 .44553 Metetra
.664 .742 .908 r
.57259 .44553 .57563 .44897 .58147 .4471 .57844 .44366 Metetra
.664 .742 .908 r
.57844 .44366 .58147 .4471 .58733 .44523 .5843 .44179 Metetra
.664 .742 .908 r
.5843 .44179 .58733 .44523 .5932 .44336 .59018 .43991 Metetra
.664 .742 .908 r
.59018 .43991 .5932 .44336 .59908 .44149 .59607 .43803 Metetra
.664 .742 .908 r
.59607 .43803 .59908 .44149 .60497 .43961 .60197 .43614 Metetra
.663 .742 .908 r
.60197 .43614 .60497 .43961 .61088 .43773 .60789 .43425 Metetra
.663 .742 .908 r
.60789 .43425 .61088 .43773 .6168 .43584 .61382 .43236 Metetra
.663 .742 .908 r
.61382 .43236 .6168 .43584 .62273 .43396 .61976 .43047 Metetra
.663 .742 .908 r
.61976 .43047 .62273 .43396 .62867 .43207 .62571 .42857 Metetra
.663 .742 .908 r
.62571 .42857 .62867 .43207 .63463 .43017 .63167 .42667 Metetra
.663 .742 .909 r
.63167 .42667 .63463 .43017 .6406 .42828 .63765 .42477 Metetra
.663 .742 .909 r
.63765 .42477 .6406 .42828 .64658 .42638 .64364 .42286 Metetra
.663 .742 .909 r
.64364 .42286 .64658 .42638 .65258 .42448 .64965 .42096 Metetra
.662 .742 .909 r
.64965 .42096 .65258 .42448 .65859 .42258 .65567 .41906 Metetra
.662 .742 .91 r
.65567 .41906 .65859 .42258 .66461 .42068 .6617 .41716 Metetra
.661 .742 .91 r
.6617 .41716 .66461 .42068 .67064 .41879 .66774 .41527 Metetra
.66 .742 .911 r
.66774 .41527 .67064 .41879 .67669 .4169 .6738 .41338 Metetra
.66 .743 .912 r
.6738 .41338 .67669 .4169 .68276 .41502 .67987 .4115 Metetra
.658 .743 .913 r
.67987 .4115 .68276 .41502 .68883 .41314 .68596 .40964 Metetra
.657 .744 .914 r
.68596 .40964 .68883 .41314 .69492 .41129 .69206 .4078 Metetra
.655 .745 .916 r
.69206 .4078 .69492 .41129 .70103 .40945 .69817 .40598 Metetra
.652 .746 .918 r
.69817 .40598 .70103 .40945 .70715 .40763 .7043 .4042 Metetra
.649 .747 .921 r
.7043 .4042 .70715 .40763 .71328 .40585 .71045 .40246 Metetra
.645 .748 .925 r
.71045 .40246 .71328 .40585 .71944 .40411 .71662 .40077 Metetra
.64 .75 .929 r
.71662 .40077 .71944 .40411 .72561 .40242 .7228 .39914 Metetra
.634 .753 .934 r
.7228 .39914 .72561 .40242 .73179 .40079 .729 .39758 Metetra
.627 .755 .939 r
.729 .39758 .73179 .40079 .738 .39921 .73523 .39608 Metetra
.62 .758 .945 r
.73523 .39608 .738 .39921 .74423 .39771 .74147 .39467 Metetra
.612 .762 .951 r
.74147 .39467 .74423 .39771 .75048 .39627 .74774 .39332 Metetra
.604 .766 .957 r
.74774 .39332 .75048 .39627 .75674 .3949 .75402 .39203 Metetra
.598 .77 .962 r
.75402 .39203 .75674 .3949 .76303 .39359 .76033 .39078 Metetra
.594 .774 .966 r
.76033 .39078 .76303 .39359 .76934 .39231 .76665 .38955 Metetra
.594 .778 .968 r
.76665 .38955 .76934 .39231 .77567 .39105 .77299 .38829 Metetra
.599 .781 .967 r
.77299 .38829 .77567 .39105 .78201 .38976 .77934 .38698 Metetra
.608 .783 .965 r
.77934 .38698 .78201 .38976 .78836 .38842 .7857 .38556 Metetra
.621 .783 .959 r
.7857 .38556 .78836 .38842 .79472 .38698 .79206 .38401 Metetra
.637 .781 .951 r
.79206 .38401 .79472 .38698 .80109 .38541 .79843 .38229 Metetra
.652 .776 .94 r
.79843 .38229 .80109 .38541 .80746 .3837 .80479 .3804 Metetra
.665 .77 .928 r
.80479 .3804 .80746 .3837 .81383 .38181 .81116 .37833 Metetra
.675 .762 .917 r
.81116 .37833 .81383 .38181 .8202 .37976 .81753 .3761 Metetra
.681 .754 .906 r
.81753 .3761 .8202 .37976 .82657 .37757 .82389 .37376 Metetra
.685 .747 .899 r
.82389 .37376 .82657 .37757 .83295 .37526 .83027 .37134 Metetra
.686 .742 .894 r
.83027 .37134 .83295 .37526 .83933 .37287 .83665 .36889 Metetra
.684 .739 .892 r
.83665 .36889 .83933 .37287 .84572 .37045 .84305 .36646 Metetra
.682 .737 .893 r
.84305 .36646 .84572 .37045 .85212 .36804 .84947 .36408 Metetra
.678 .738 .896 r
.84947 .36408 .85212 .36804 .85854 .36567 .85591 .36177 Metetra
.673 .74 .9 r
.85591 .36177 .85854 .36567 .86499 .36336 .86237 .35953 Metetra
.669 .743 .905 r
.86237 .35953 .86499 .36336 .87145 .36112 .86885 .35736 Metetra
.666 .746 .91 r
.86885 .35736 .87145 .36112 .87793 .35894 .87535 .35523 Metetra
.664 .749 .913 r
.87535 .35523 .87793 .35894 .88444 .35682 .88187 .35314 Metetra
.664 .751 .916 r
.88187 .35314 .88444 .35682 .89096 .35472 .88841 .35105 Metetra
.664 .753 .916 r
.88841 .35105 .89096 .35472 .8975 .35263 .89496 .34894 Metetra
.665 .753 .915 r
.89496 .34894 .8975 .35263 .90405 .35053 .90152 .34682 Metetra
.667 .752 .914 r
.90152 .34682 .90405 .35053 .91061 .34841 .90809 .34466 Metetra
.655 .737 .91 r
.3177 .52778 .32109 .53097 .32642 .52943 .32304 .52619 Metetra
.652 .733 .909 r
.32304 .52619 .32642 .52943 .33176 .52792 .32839 .52463 Metetra
.65 .73 .908 r
.32839 .52463 .33176 .52792 .33711 .52643 .33375 .52311 Metetra
.648 .728 .908 r
.33375 .52311 .33711 .52643 .34248 .52492 .33912 .52162 Metetra
.647 .729 .909 r
.33912 .52162 .34248 .52492 .34786 .52338 .3445 .52013 Metetra
.649 .733 .911 r
.3445 .52013 .34786 .52338 .35325 .52178 .3499 .51861 Metetra
.653 .74 .913 r
.3499 .51861 .35325 .52178 .35866 .52009 .35531 .51702 Metetra
.659 .749 .916 r
.35531 .51702 .35866 .52009 .36408 .51832 .36073 .51535 Metetra
.665 .756 .918 r
.36073 .51535 .36408 .51832 .36951 .51652 .36617 .51358 Metetra
.668 .76 .919 r
.36617 .51358 .36951 .51652 .37496 .51476 .37163 .51176 Metetra
.667 .757 .917 r
.37163 .51176 .37496 .51476 .38041 .51311 .37709 .50996 Metetra
.66 .745 .913 r
.37709 .50996 .38041 .51311 .38586 .51168 .38256 .50826 Metetra
.646 .725 .906 r
.38256 .50826 .38586 .51168 .39131 .51051 .38803 .50676 Metetra
.627 .7 .898 r
.38803 .50676 .39131 .51051 .39677 .50961 .3935 .50555 Metetra
.606 .675 .89 r
.3935 .50555 .39677 .50961 .40223 .50896 .39898 .50464 Metetra
.588 .656 .884 r
.39898 .50464 .40223 .50896 .4077 .50842 .40446 .504 Metetra
.576 .646 .882 r
.40446 .504 .4077 .50842 .41319 .50786 .40995 .50353 Metetra
.574 .65 .887 r
.40995 .50353 .41319 .50786 .4187 .5071 .41545 .50307 Metetra
.584 .67 .898 r
.41545 .50307 .4187 .5071 .42423 .506 .42097 .50243 Metetra
.607 .706 .915 r
.42097 .50243 .42423 .506 .42979 .50444 .42652 .50144 Metetra
.639 .754 .932 r
.42652 .50144 .42979 .50444 .43538 .50237 .4321 .49997 Metetra
.675 .805 .945 r
.4321 .49997 .43538 .50237 .44098 .49982 .4377 .49796 Metetra
.71 .851 .949 r
.4377 .49796 .44098 .49982 .44661 .49688 .44333 .49542 Metetra
.738 .884 .947 r
.44333 .49542 .44661 .49688 .45225 .49367 .44898 .49244 Metetra
.756 .903 .942 r
.44898 .49244 .45225 .49367 .4579 .49033 .45464 .48915 Metetra
.766 .907 .937 r
.45464 .48915 .4579 .49033 .46356 .48699 .46031 .48571 Metetra
.767 .9 .935 r
.46031 .48571 .46356 .48699 .46922 .48376 .46599 .48225 Metetra
.761 .884 .933 r
.46599 .48225 .46922 .48376 .47488 .4807 .47167 .47891 Metetra
.75 .863 .931 r
.47167 .47891 .47488 .4807 .48055 .47786 .47735 .47575 Metetra
.736 .84 .929 r
.47735 .47575 .48055 .47786 .48623 .47523 .48304 .47283 Metetra
.721 .817 .925 r
.48304 .47283 .48623 .47523 .49191 .47279 .48874 .47013 Metetra
.707 .797 .921 r
.48874 .47013 .49191 .47279 .4976 .47052 .49444 .46765 Metetra
.695 .781 .917 r
.49444 .46765 .4976 .47052 .5033 .46838 .50015 .46534 Metetra
.686 .769 .915 r
.50015 .46534 .5033 .46838 .50901 .46633 .50587 .46318 Metetra
.679 .76 .912 r
.50587 .46318 .50901 .46633 .51473 .46435 .5116 .46111 Metetra
.674 .753 .911 r
.5116 .46111 .51473 .46435 .52046 .46241 .51734 .45912 Metetra
.67 .749 .91 r
.51734 .45912 .52046 .46241 .5262 .46051 .52309 .45717 Metetra
.668 .746 .909 r
.52309 .45717 .5262 .46051 .53196 .45862 .52885 .45525 Metetra
.667 .745 .908 r
.52885 .45525 .53196 .45862 .53773 .45674 .53463 .45335 Metetra
.666 .743 .908 r
.53463 .45335 .53773 .45674 .54351 .45487 .54041 .45147 Metetra
.665 .743 .908 r
.54041 .45147 .54351 .45487 .5493 .45301 .54621 .44959 Metetra
.665 .742 .908 r
.54621 .44959 .5493 .45301 .5551 .45114 .55202 .44771 Metetra
.664 .742 .908 r
.55202 .44771 .5551 .45114 .56092 .44927 .55785 .44583 Metetra
.664 .741 .908 r
.55785 .44583 .56092 .44927 .56675 .4474 .56368 .44395 Metetra
.664 .741 .908 r
.56368 .44395 .56675 .4474 .57259 .44553 .56953 .44207 Metetra
.664 .741 .907 r
.56953 .44207 .57259 .44553 .57844 .44366 .57539 .44019 Metetra
.664 .741 .907 r
.57539 .44019 .57844 .44366 .5843 .44179 .58127 .43831 Metetra
.664 .741 .907 r
.58127 .43831 .5843 .44179 .59018 .43991 .58715 .43642 Metetra
.664 .741 .907 r
.58715 .43642 .59018 .43991 .59607 .43803 .59305 .43453 Metetra
.664 .741 .907 r
.59305 .43453 .59607 .43803 .60197 .43614 .59896 .43264 Metetra
.663 .741 .907 r
.59896 .43264 .60197 .43614 .60789 .43425 .60489 .43074 Metetra
.663 .741 .908 r
.60489 .43074 .60789 .43425 .61382 .43236 .61082 .42885 Metetra
.663 .741 .908 r
.61082 .42885 .61382 .43236 .61976 .43047 .61677 .42694 Metetra
.663 .741 .908 r
.61677 .42694 .61976 .43047 .62571 .42857 .62273 .42504 Metetra
.663 .741 .908 r
.62273 .42504 .62571 .42857 .63167 .42667 .62871 .42314 Metetra
.663 .741 .908 r
.62871 .42314 .63167 .42667 .63765 .42477 .63469 .42123 Metetra
.663 .741 .908 r
.63469 .42123 .63765 .42477 .64364 .42286 .64069 .41932 Metetra
.662 .741 .909 r
.64069 .41932 .64364 .42286 .64965 .42096 .64671 .41742 Metetra
.662 .741 .909 r
.64671 .41742 .64965 .42096 .65567 .41906 .65273 .41552 Metetra
.661 .742 .91 r
.65273 .41552 .65567 .41906 .6617 .41716 .65877 .41362 Metetra
.66 .742 .91 r
.65877 .41362 .6617 .41716 .66774 .41527 .66483 .41173 Metetra
.659 .742 .911 r
.66483 .41173 .66774 .41527 .6738 .41338 .67089 .40985 Metetra
.658 .743 .912 r
.67089 .40985 .6738 .41338 .67987 .4115 .67698 .40799 Metetra
.657 .743 .914 r
.67698 .40799 .67987 .4115 .68596 .40964 .68307 .40614 Metetra
.654 .744 .916 r
.68307 .40614 .68596 .40964 .69206 .4078 .68918 .40433 Metetra
.652 .745 .918 r
.68918 .40433 .69206 .4078 .69817 .40598 .69531 .40254 Metetra
.648 .747 .921 r
.69531 .40254 .69817 .40598 .7043 .4042 .70145 .4008 Metetra
.644 .748 .925 r
.70145 .4008 .7043 .4042 .71045 .40246 .70761 .39912 Metetra
.639 .75 .929 r
.70761 .39912 .71045 .40246 .71662 .40077 .71379 .39749 Metetra
.633 .753 .934 r
.71379 .39749 .71662 .40077 .7228 .39914 .71999 .39594 Metetra
.626 .755 .94 r
.71999 .39594 .7228 .39914 .729 .39758 .72621 .39446 Metetra
.617 .759 .946 r
.72621 .39446 .729 .39758 .73523 .39608 .73245 .39306 Metetra
.609 .762 .953 r
.73245 .39306 .73523 .39608 .74147 .39467 .73871 .39173 Metetra
.601 .766 .959 r
.73871 .39173 .74147 .39467 .74774 .39332 .74499 .39048 Metetra
.594 .771 .964 r
.74499 .39048 .74774 .39332 .75402 .39203 .75129 .38926 Metetra
.589 .775 .968 r
.75129 .38926 .75402 .39203 .76033 .39078 .75761 .38806 Metetra
.589 .779 .97 r
.75761 .38806 .76033 .39078 .76665 .38955 .76395 .38684 Metetra
.594 .783 .97 r
.76395 .38684 .76665 .38955 .77299 .38829 .7703 .38556 Metetra
.605 .785 .967 r
.7703 .38556 .77299 .38829 .77934 .38698 .77665 .38416 Metetra
.619 .785 .961 r
.77665 .38416 .77934 .38698 .7857 .38556 .78301 .38262 Metetra
.636 .783 .952 r
.78301 .38262 .7857 .38556 .79206 .38401 .78938 .3809 Metetra
.652 .778 .941 r
.78938 .3809 .79206 .38401 .79843 .38229 .79574 .37899 Metetra
.666 .771 .928 r
.79574 .37899 .79843 .38229 .80479 .3804 .8021 .3769 Metetra
.676 .763 .916 r
.8021 .3769 .80479 .3804 .81116 .37833 .80846 .37465 Metetra
.683 .754 .905 r
.80846 .37465 .81116 .37833 .81753 .3761 .81482 .37227 Metetra
.687 .747 .897 r
.81482 .37227 .81753 .3761 .82389 .37376 .82119 .36982 Metetra
.687 .741 .892 r
.82119 .36982 .82389 .37376 .83027 .37134 .82757 .36734 Metetra
.685 .738 .891 r
.82757 .36734 .83027 .37134 .83665 .36889 .83397 .36489 Metetra
.682 .737 .892 r
.83397 .36489 .83665 .36889 .84305 .36646 .84038 .3625 Metetra
.678 .738 .896 r
.84038 .3625 .84305 .36646 .84947 .36408 .84682 .36018 Metetra
.673 .74 .901 r
.84682 .36018 .84947 .36408 .85591 .36177 .85328 .35795 Metetra
.669 .744 .906 r
.85328 .35795 .85591 .36177 .86237 .35953 .85975 .35578 Metetra
.666 .747 .911 r
.85975 .35578 .86237 .35953 .86885 .35736 .86625 .35367 Metetra
.664 .75 .915 r
.86625 .35367 .86885 .35736 .87535 .35523 .87277 .35157 Metetra
.663 .753 .916 r
.87277 .35157 .87535 .35523 .88187 .35314 .8793 .34948 Metetra
.664 .754 .917 r
.8793 .34948 .88187 .35314 .88841 .35105 .88585 .34736 Metetra
.666 .753 .916 r
.88585 .34736 .88841 .35105 .89496 .34894 .8924 .34522 Metetra
.668 .752 .914 r
.8924 .34522 .89496 .34894 .90152 .34682 .89897 .34305 Metetra
.669 .751 .912 r
.89897 .34305 .90152 .34682 .90809 .34466 .90555 .34085 Metetra
.657 .74 .911 r
.3143 .52462 .3177 .52778 .32304 .52619 .31965 .52299 Metetra
.655 .738 .91 r
.31965 .52299 .32304 .52619 .32839 .52463 .32501 .52138 Metetra
.653 .734 .909 r
.32501 .52138 .32839 .52463 .33375 .52311 .33038 .51981 Metetra
.65 .73 .908 r
.33038 .51981 .33375 .52311 .33912 .52162 .33576 .51828 Metetra
.647 .728 .908 r
.33576 .51828 .33912 .52162 .3445 .52013 .34115 .51678 Metetra
.646 .727 .908 r
.34115 .51678 .3445 .52013 .3499 .51861 .34654 .5153 Metetra
.647 .731 .91 r
.34654 .5153 .3499 .51861 .35531 .51702 .35195 .5138 Metetra
.651 .737 .913 r
.35195 .5138 .35531 .51702 .36073 .51535 .35738 .51224 Metetra
.657 .746 .916 r
.35738 .51224 .36073 .51535 .36617 .51358 .36282 .51058 Metetra
.663 .756 .919 r
.36282 .51058 .36617 .51358 .37163 .51176 .36828 .50883 Metetra
.668 .761 .92 r
.36828 .50883 .37163 .51176 .37709 .50996 .37375 .50699 Metetra
.669 .76 .919 r
.37375 .50699 .37709 .50996 .38256 .50826 .37923 .50515 Metetra
.663 .75 .915 r
.37923 .50515 .38256 .50826 .38803 .50676 .38472 .50339 Metetra
.65 .73 .908 r
.38472 .50339 .38803 .50676 .3935 .50555 .39022 .50183 Metetra
.63 .704 .899 r
.39022 .50183 .3935 .50555 .39898 .50464 .39571 .50056 Metetra
.608 .676 .89 r
.39571 .50056 .39898 .50464 .40446 .504 .4012 .49962 Metetra
.587 .653 .882 r
.4012 .49962 .40446 .504 .40995 .50353 .4067 .499 Metetra
.572 .64 .879 r
.4067 .499 .40995 .50353 .41545 .50307 .41221 .49859 Metetra
.567 .641 .883 r
.41221 .49859 .41545 .50307 .42097 .50243 .41773 .49823 Metetra
.575 .659 .894 r
.41773 .49823 .42097 .50243 .42652 .50144 .42327 .49772 Metetra
.597 .694 .911 r
.42327 .49772 .42652 .50144 .4321 .49997 .42883 .49687 Metetra
.63 .745 .93 r
.42883 .49687 .4321 .49997 .4377 .49796 .43442 .49551 Metetra
.669 .801 .945 r
.43442 .49551 .4377 .49796 .44333 .49542 .44005 .49357 Metetra
.708 .853 .952 r
.44005 .49357 .44333 .49542 .44898 .49244 .44569 .49105 Metetra
.738 .891 .949 r
.44569 .49105 .44898 .49244 .45464 .48915 .45136 .48804 Metetra
.759 .912 .942 r
.45136 .48804 .45464 .48915 .46031 .48571 .45704 .48467 Metetra
.77 .918 .937 r
.45704 .48467 .46031 .48571 .46599 .48225 .46273 .48111 Metetra
.773 .911 .934 r
.46273 .48111 .46599 .48225 .47167 .47891 .46843 .47754 Metetra
.767 .895 .933 r
.46843 .47754 .47167 .47891 .47735 .47575 .47413 .47407 Metetra
.756 .873 .932 r
.47413 .47407 .47735 .47575 .48304 .47283 .47984 .47081 Metetra
.741 .848 .93 r
.47984 .47081 .48304 .47283 .48874 .47013 .48555 .46779 Metetra
.724 .823 .926 r
.48555 .46779 .48874 .47013 .49444 .46765 .49126 .46503 Metetra
.709 .802 .922 r
.49126 .46503 .49444 .46765 .50015 .46534 .49698 .46249 Metetra
.696 .784 .918 r
.49698 .46249 .50015 .46534 .50587 .46318 .50271 .46015 Metetra
.686 .771 .915 r
.50271 .46015 .50587 .46318 .5116 .46111 .50845 .45796 Metetra
.679 .761 .913 r
.50845 .45796 .5116 .46111 .51734 .45912 .5142 .45588 Metetra
.674 .755 .911 r
.5142 .45588 .51734 .45912 .52309 .45717 .51996 .45387 Metetra
.67 .75 .91 r
.51996 .45387 .52309 .45717 .52885 .45525 .52573 .45191 Metetra
.668 .747 .91 r
.52573 .45191 .52885 .45525 .53463 .45335 .53151 .44999 Metetra
.667 .746 .909 r
.53151 .44999 .53463 .45335 .54041 .45147 .53731 .44808 Metetra
.666 .745 .909 r
.53731 .44808 .54041 .45147 .54621 .44959 .54312 .44618 Metetra
.665 .744 .909 r
.54312 .44618 .54621 .44959 .55202 .44771 .54894 .44429 Metetra
.665 .743 .909 r
.54894 .44429 .55202 .44771 .55785 .44583 .55477 .4424 Metetra
.664 .743 .909 r
.55477 .4424 .55785 .44583 .56368 .44395 .56061 .44051 Metetra
.664 .743 .909 r
.56061 .44051 .56368 .44395 .56953 .44207 .56647 .43862 Metetra
.664 .743 .909 r
.56647 .43862 .56953 .44207 .57539 .44019 .57234 .43674 Metetra
.664 .743 .909 r
.57234 .43674 .57539 .44019 .58127 .43831 .57822 .43484 Metetra
.664 .742 .909 r
.57822 .43484 .58127 .43831 .58715 .43642 .58411 .43295 Metetra
.664 .742 .909 r
.58411 .43295 .58715 .43642 .59305 .43453 .59002 .43105 Metetra
.663 .742 .909 r
.59002 .43105 .59305 .43453 .59896 .43264 .59594 .42915 Metetra
.663 .742 .909 r
.59594 .42915 .59896 .43264 .60489 .43074 .60187 .42725 Metetra
.663 .742 .909 r
.60187 .42725 .60489 .43074 .61082 .42885 .60782 .42535 Metetra
.663 .742 .909 r
.60782 .42535 .61082 .42885 .61677 .42694 .61377 .42344 Metetra
.663 .742 .909 r
.61377 .42344 .61677 .42694 .62273 .42504 .61974 .42153 Metetra
.663 .742 .909 r
.61974 .42153 .62273 .42504 .62871 .42314 .62573 .41962 Metetra
.663 .743 .909 r
.62573 .41962 .62871 .42314 .63469 .42123 .63172 .41771 Metetra
.662 .743 .91 r
.63172 .41771 .63469 .42123 .64069 .41932 .63773 .4158 Metetra
.662 .743 .91 r
.63773 .4158 .64069 .41932 .64671 .41742 .64375 .41389 Metetra
.661 .743 .911 r
.64375 .41389 .64671 .41742 .65273 .41552 .64979 .41199 Metetra
.661 .743 .911 r
.64979 .41199 .65273 .41552 .65877 .41362 .65584 .4101 Metetra
.66 .743 .912 r
.65584 .4101 .65877 .41362 .66483 .41173 .6619 .40821 Metetra
.658 .744 .913 r
.6619 .40821 .66483 .41173 .67089 .40985 .66798 .40634 Metetra
.657 .744 .915 r
.66798 .40634 .67089 .40985 .67698 .40799 .67407 .4045 Metetra
.654 .745 .916 r
.67407 .4045 .67698 .40799 .68307 .40614 .68018 .40268 Metetra
.652 .746 .919 r
.68018 .40268 .68307 .40614 .68918 .40433 .6863 .40089 Metetra
.648 .747 .922 r
.6863 .40089 .68918 .40433 .69531 .40254 .69244 .39915 Metetra
.644 .749 .925 r
.69244 .39915 .69531 .40254 .70145 .4008 .69859 .39747 Metetra
.638 .751 .93 r
.69859 .39747 .70145 .4008 .70761 .39912 .70477 .39585 Metetra
.632 .753 .935 r
.70477 .39585 .70761 .39912 .71379 .39749 .71096 .3943 Metetra
.624 .756 .941 r
.71096 .3943 .71379 .39749 .71999 .39594 .71718 .39284 Metetra
.615 .76 .948 r
.71718 .39284 .71999 .39594 .72621 .39446 .72341 .39146 Metetra
.606 .763 .955 r
.72341 .39146 .72621 .39446 .73245 .39306 .72967 .39016 Metetra
.596 .768 .961 r
.72967 .39016 .73245 .39306 .73871 .39173 .73595 .38893 Metetra
.588 .772 .967 r
.73595 .38893 .73871 .39173 .74499 .39048 .74225 .38775 Metetra
.583 .776 .971 r
.74225 .38775 .74499 .39048 .75129 .38926 .74856 .38659 Metetra
.583 .781 .974 r
.74856 .38659 .75129 .38926 .75761 .38806 .75489 .38541 Metetra
.589 .785 .973 r
.75489 .38541 .75761 .38806 .76395 .38684 .76124 .38415 Metetra
.6 .788 .97 r
.76124 .38415 .76395 .38684 .7703 .38556 .76759 .38278 Metetra
.616 .788 .964 r
.76759 .38278 .7703 .38556 .77665 .38416 .77395 .38125 Metetra
.635 .786 .954 r
.77395 .38125 .77665 .38416 .78301 .38262 .78031 .37953 Metetra
.652 .78 .942 r
.78031 .37953 .78301 .38262 .78938 .3809 .78667 .37761 Metetra
.667 .772 .928 r
.78667 .37761 .78938 .3809 .79574 .37899 .79302 .37549 Metetra
.678 .763 .915 r
.79302 .37549 .79574 .37899 .8021 .3769 .79938 .3732 Metetra
.685 .754 .904 r
.79938 .3732 .8021 .3769 .80846 .37465 .80573 .37079 Metetra
.688 .746 .896 r
.80573 .37079 .80846 .37465 .81482 .37227 .8121 .3683 Metetra
.688 .741 .891 r
.8121 .3683 .81482 .37227 .82119 .36982 .81847 .3658 Metetra
.686 .737 .89 r
.81847 .3658 .82119 .36982 .82757 .36734 .82487 .36333 Metetra
.682 .737 .892 r
.82487 .36333 .82757 .36734 .83397 .36489 .83128 .36092 Metetra
.677 .738 .896 r
.83128 .36092 .83397 .36489 .84038 .3625 .83771 .35861 Metetra
.672 .741 .902 r
.83771 .35861 .84038 .3625 .84682 .36018 .84416 .35638 Metetra
.668 .745 .908 r
.84416 .35638 .84682 .36018 .85328 .35795 .85064 .35422 Metetra
.665 .749 .913 r
.85064 .35422 .85328 .35795 .85975 .35578 .85714 .35211 Metetra
.663 .752 .916 r
.85714 .35211 .85975 .35578 .86625 .35367 .86365 .35001 Metetra
.663 .754 .917 r
.86365 .35001 .86625 .35367 .87277 .35157 .87018 .34791 Metetra
.665 .755 .917 r
.87018 .34791 .87277 .35157 .8793 .34948 .87672 .34579 Metetra
.666 .754 .916 r
.87672 .34579 .8793 .34948 .88585 .34736 .88327 .34364 Metetra
.668 .753 .913 r
.88327 .34364 .88585 .34736 .8924 .34522 .88983 .34144 Metetra
.67 .751 .911 r
.88983 .34144 .8924 .34522 .89897 .34305 .89641 .33923 Metetra
.671 .749 .909 r
.89641 .33923 .89897 .34305 .90555 .34085 .90299 .33699 Metetra
.658 .741 .912 r
.31089 .52147 .3143 .52462 .31965 .52299 .31624 .51982 Metetra
.657 .741 .911 r
.31624 .51982 .31965 .52299 .32501 .52138 .32161 .51818 Metetra
.656 .739 .911 r
.32161 .51818 .32501 .52138 .33038 .51981 .32699 .51655 Metetra
.653 .735 .909 r
.32699 .51655 .33038 .51981 .33576 .51828 .33238 .51496 Metetra
.65 .731 .908 r
.33238 .51496 .33576 .51828 .34115 .51678 .33777 .51341 Metetra
.647 .727 .907 r
.33777 .51341 .34115 .51678 .34654 .5153 .34318 .51191 Metetra
.645 .726 .907 r
.34318 .51191 .34654 .5153 .35195 .5138 .34859 .51044 Metetra
.645 .728 .909 r
.34859 .51044 .35195 .5138 .35738 .51224 .35402 .50895 Metetra
.648 .734 .912 r
.35402 .50895 .35738 .51224 .36282 .51058 .35946 .50742 Metetra
.654 .743 .915 r
.35946 .50742 .36282 .51058 .36828 .50883 .36492 .50579 Metetra
.662 .754 .919 r
.36492 .50579 .36828 .50883 .37375 .50699 .3704 .50405 Metetra
.668 .762 .921 r
.3704 .50405 .37375 .50699 .37923 .50515 .37589 .50221 Metetra
.671 .763 .92 r
.37589 .50221 .37923 .50515 .38472 .50339 .38139 .50034 Metetra
.666 .755 .917 r
.38139 .50034 .38472 .50339 .39022 .50183 .3869 .49852 Metetra
.654 .736 .91 r
.3869 .49852 .39022 .50183 .39571 .50056 .39241 .49689 Metetra
.634 .709 .901 r
.39241 .49689 .39571 .50056 .4012 .49962 .39793 .49555 Metetra
.61 .679 .89 r
.39793 .49555 .4012 .49962 .4067 .499 .40344 .49457 Metetra
.586 .651 .881 r
.40344 .49457 .4067 .499 .41221 .49859 .40896 .49395 Metetra
.568 .634 .876 r
.40896 .49395 .41221 .49859 .41773 .49823 .41448 .49359 Metetra
.56 .631 .879 r
.41448 .49359 .41773 .49823 .42327 .49772 .42002 .49334 Metetra
.565 .646 .889 r
.42002 .49334 .42327 .49772 .42883 .49687 .42557 .49298 Metetra
.585 .681 .907 r
.42557 .49298 .42883 .49687 .43442 .49551 .43115 .49227 Metetra
.619 .734 .929 r
.43115 .49227 .43442 .49551 .44005 .49357 .43676 .49105 Metetra
.661 .796 .947 r
.43676 .49105 .44005 .49357 .44569 .49105 .4424 .48921 Metetra
.704 .854 .954 r
.4424 .48921 .44569 .49105 .45136 .48804 .44807 .48672 Metetra
.738 .897 .951 r
.44807 .48672 .45136 .48804 .45704 .48467 .45375 .48368 Metetra
.761 .922 .942 r
.45375 .48368 .45704 .48467 .46273 .48111 .45946 .48024 Metetra
.774 .929 .935 r
.45946 .48024 .46273 .48111 .46843 .47754 .46517 .47656 Metetra
.778 .924 .933 r
.46517 .47656 .46843 .47754 .47413 .47407 .47089 .47285 Metetra
.774 .907 .933 r
.47089 .47285 .47413 .47407 .47984 .47081 .47661 .46925 Metetra
.762 .883 .932 r
.47661 .46925 .47984 .47081 .48555 .46779 .48234 .46586 Metetra
.746 .856 .93 r
.48234 .46586 .48555 .46779 .49126 .46503 .48807 .46274 Metetra
.729 .829 .927 r
.48807 .46274 .49126 .46503 .49698 .46249 .4938 .45989 Metetra
.712 .805 .923 r
.4938 .45989 .49698 .46249 .50271 .46015 .49954 .4573 Metetra
.698 .786 .919 r
.49954 .4573 .50271 .46015 .50845 .45796 .50529 .45492 Metetra
.687 .771 .915 r
.50529 .45492 .50845 .45796 .5142 .45588 .51105 .4527 Metetra
.68 .761 .913 r
.51105 .4527 .5142 .45588 .51996 .45387 .51682 .4506 Metetra
.674 .754 .911 r
.51682 .4506 .51996 .45387 .52573 .45191 .5226 .44858 Metetra
.67 .749 .91 r
.5226 .44858 .52573 .45191 .53151 .44999 .52839 .44661 Metetra
.668 .746 .909 r
.52839 .44661 .53151 .44999 .53731 .44808 .53419 .44467 Metetra
.667 .745 .908 r
.53419 .44467 .53731 .44808 .54312 .44618 .54001 .44275 Metetra
.666 .743 .908 r
.54001 .44275 .54312 .44618 .54894 .44429 .54583 .44084 Metetra
.665 .743 .908 r
.54583 .44084 .54894 .44429 .55477 .4424 .55167 .43894 Metetra
.665 .742 .908 r
.55167 .43894 .55477 .4424 .56061 .44051 .55753 .43704 Metetra
.664 .742 .908 r
.55753 .43704 .56061 .44051 .56647 .43862 .56339 .43514 Metetra
.664 .741 .908 r
.56339 .43514 .56647 .43862 .57234 .43674 .56927 .43324 Metetra
.664 .741 .908 r
.56927 .43324 .57234 .43674 .57822 .43484 .57516 .43134 Metetra
.664 .741 .908 r
.57516 .43134 .57822 .43484 .58411 .43295 .58106 .42944 Metetra
.664 .741 .908 r
.58106 .42944 .58411 .43295 .59002 .43105 .58698 .42753 Metetra
.664 .741 .908 r
.58698 .42753 .59002 .43105 .59594 .42915 .5929 .42563 Metetra
.663 .741 .908 r
.5929 .42563 .59594 .42915 .60187 .42725 .59884 .42372 Metetra
.663 .741 .908 r
.59884 .42372 .60187 .42725 .60782 .42535 .6048 .42181 Metetra
.663 .741 .908 r
.6048 .42181 .60782 .42535 .61377 .42344 .61076 .41989 Metetra
.663 .741 .908 r
.61076 .41989 .61377 .42344 .61974 .42153 .61674 .41798 Metetra
.663 .741 .908 r
.61674 .41798 .61974 .42153 .62573 .41962 .62273 .41606 Metetra
.662 .741 .908 r
.62273 .41606 .62573 .41962 .63172 .41771 .62874 .41415 Metetra
.662 .741 .909 r
.62874 .41415 .63172 .41771 .63773 .4158 .63476 .41224 Metetra
.661 .741 .909 r
.63476 .41224 .63773 .4158 .64375 .41389 .64079 .41034 Metetra
.661 .742 .91 r
.64079 .41034 .64375 .41389 .64979 .41199 .64683 .40844 Metetra
.66 .742 .911 r
.64683 .40844 .64979 .41199 .65584 .4101 .65289 .40655 Metetra
.658 .742 .912 r
.65289 .40655 .65584 .4101 .6619 .40821 .65896 .40468 Metetra
.657 .743 .914 r
.65896 .40468 .6619 .40821 .66798 .40634 .66505 .40283 Metetra
.654 .744 .916 r
.66505 .40283 .66798 .40634 .67407 .4045 .67115 .40101 Metetra
.651 .745 .918 r
.67115 .40101 .67407 .4045 .68018 .40268 .67727 .39922 Metetra
.648 .746 .921 r
.67727 .39922 .68018 .40268 .6863 .40089 .68341 .39748 Metetra
.643 .748 .925 r
.68341 .39748 .6863 .40089 .69244 .39915 .68956 .3958 Metetra
.638 .75 .93 r
.68956 .3958 .69244 .39915 .69859 .39747 .69573 .39419 Metetra
.631 .753 .936 r
.69573 .39419 .69859 .39747 .70477 .39585 .70192 .39265 Metetra
.622 .756 .942 r
.70192 .39265 .70477 .39585 .71096 .3943 .70813 .39121 Metetra
.613 .76 .949 r
.70813 .39121 .71096 .3943 .71718 .39284 .71436 .38985 Metetra
.602 .764 .956 r
.71436 .38985 .71718 .39284 .72341 .39146 .72061 .38858 Metetra
.592 .768 .963 r
.72061 .38858 .72341 .39146 .72967 .39016 .72689 .38739 Metetra
.583 .773 .97 r
.72689 .38739 .72967 .39016 .73595 .38893 .73318 .38625 Metetra
.577 .778 .974 r
.73318 .38625 .73595 .38893 .74225 .38775 .73949 .38513 Metetra
.576 .783 .977 r
.73949 .38513 .74225 .38775 .74856 .38659 .74582 .38399 Metetra
.583 .787 .977 r
.74582 .38399 .74856 .38659 .75489 .38541 .75216 .38277 Metetra
.595 .79 .973 r
.75216 .38277 .75489 .38541 .76124 .38415 .75851 .38143 Metetra
.613 .791 .967 r
.75851 .38143 .76124 .38415 .76759 .38278 .76487 .37991 Metetra
.634 .789 .956 r
.76487 .37991 .76759 .38278 .77395 .38125 .77122 .37819 Metetra
.653 .783 .943 r
.77122 .37819 .77395 .38125 .78031 .37953 .77758 .37625 Metetra
.669 .774 .928 r
.77758 .37625 .78031 .37953 .78667 .37761 .78393 .3741 Metetra
.68 .764 .914 r
.78393 .3741 .78667 .37761 .79302 .37549 .79028 .37178 Metetra
.687 .754 .903 r
.79028 .37178 .79302 .37549 .79938 .3732 .79663 .36932 Metetra
.69 .746 .894 r
.79663 .36932 .79938 .3732 .80573 .37079 .80299 .36679 Metetra
.69 .74 .89 r
.80299 .36679 .80573 .37079 .8121 .3683 .80936 .36426 Metetra
.687 .737 .889 r
.80936 .36426 .8121 .3683 .81847 .3658 .81575 .36177 Metetra
.682 .737 .892 r
.81575 .36177 .81847 .3658 .82487 .36333 .82215 .35936 Metetra
.677 .738 .897 r
.82215 .35936 .82487 .36333 .83128 .36092 .82858 .35705 Metetra
.672 .742 .903 r
.82858 .35705 .83128 .36092 .83771 .35861 .83504 .35482 Metetra
.667 .746 .909 r
.83504 .35482 .83771 .35861 .84416 .35638 .84151 .35267 Metetra
.664 .75 .914 r
.84151 .35267 .84416 .35638 .85064 .35422 .848 .35056 Metetra
.663 .753 .917 r
.848 .35056 .85064 .35422 .85714 .35211 .85451 .34847 Metetra
.664 .755 .918 r
.85451 .34847 .85714 .35211 .86365 .35001 .86104 .34636 Metetra
.665 .756 .918 r
.86104 .34636 .86365 .35001 .87018 .34791 .86757 .34423 Metetra
.667 .755 .916 r
.86757 .34423 .87018 .34791 .87672 .34579 .87412 .34205 Metetra
.669 .753 .913 r
.87412 .34205 .87672 .34579 .88327 .34364 .88068 .33984 Metetra
.671 .751 .911 r
.88068 .33984 .88327 .34364 .88983 .34144 .88725 .33761 Metetra
.671 .749 .909 r
.88725 .33761 .88983 .34144 .89641 .33923 .89383 .33535 Metetra
.671 .747 .907 r
.89383 .33535 .89641 .33923 .90299 .33699 .90042 .33309 Metetra
.657 .741 .912 r
.30746 .51829 .31089 .52147 .31624 .51982 .31282 .51665 Metetra
.658 .742 .912 r
.31282 .51665 .31624 .51982 .32161 .51818 .3182 .515 Metetra
.658 .741 .912 r
.3182 .515 .32161 .51818 .32699 .51655 .32359 .51335 Metetra
.657 .74 .911 r
.32359 .51335 .32699 .51655 .33238 .51496 .32898 .5117 Metetra
.654 .736 .91 r
.32898 .5117 .33238 .51496 .33777 .51341 .33439 .51009 Metetra
.651 .732 .908 r
.33439 .51009 .33777 .51341 .34318 .51191 .3398 .50852 Metetra
.647 .727 .907 r
.3398 .50852 .34318 .51191 .34859 .51044 .34523 .50701 Metetra
.644 .724 .907 r
.34523 .50701 .34859 .51044 .35402 .50895 .35066 .50554 Metetra
.643 .725 .908 r
.35066 .50554 .35402 .50895 .35946 .50742 .3561 .50407 Metetra
.645 .73 .911 r
.3561 .50407 .35946 .50742 .36492 .50579 .36156 .50256 Metetra
.651 .74 .914 r
.36156 .50256 .36492 .50579 .3704 .50405 .36703 .50097 Metetra
.659 .752 .918 r
.36703 .50097 .3704 .50405 .37589 .50221 .37253 .49926 Metetra
.667 .762 .921 r
.37253 .49926 .37589 .50221 .38139 .50034 .37803 .49742 Metetra
.672 .766 .922 r
.37803 .49742 .38139 .50034 .3869 .49852 .38356 .49552 Metetra
.669 .761 .919 r
.38356 .49552 .3869 .49852 .39241 .49689 .38909 .49365 Metetra
.658 .743 .913 r
.38909 .49365 .39241 .49689 .39793 .49555 .39462 .49194 Metetra
.638 .715 .903 r
.39462 .49194 .39793 .49555 .40344 .49457 .40016 .49052 Metetra
.613 .682 .891 r
.40016 .49052 .40344 .49457 .40896 .49395 .40569 .48948 Metetra
.586 .651 .88 r
.40569 .48948 .40896 .49395 .41448 .49359 .41123 .48885 Metetra
.565 .628 .874 r
.41123 .48885 .41448 .49359 .42002 .49334 .41677 .48854 Metetra
.553 .621 .874 r
.41677 .48854 .42002 .49334 .42557 .49298 .42232 .4884 Metetra
.555 .633 .883 r
.42232 .4884 .42557 .49298 .43115 .49227 .42789 .48818 Metetra
.573 .667 .902 r
.42789 .48818 .43115 .49227 .43676 .49105 .43349 .48765 Metetra
.607 .721 .925 r
.43349 .48765 .43676 .49105 .4424 .48921 .43911 .48659 Metetra
.652 .788 .946 r
.43911 .48659 .4424 .48921 .44807 .48672 .44477 .48486 Metetra
.699 .853 .956 r
.44477 .48486 .44807 .48672 .45375 .48368 .45046 .48243 Metetra
.737 .902 .952 r
.45046 .48243 .45375 .48368 .45946 .48024 .45616 .47937 Metetra
.763 .931 .941 r
.45616 .47937 .45946 .48024 .46517 .47656 .46189 .47584 Metetra
.778 .94 .933 r
.46189 .47584 .46517 .47656 .47089 .47285 .46762 .47204 Metetra
.784 .935 .93 r
.46762 .47204 .47089 .47285 .47661 .46925 .47336 .46818 Metetra
.781 .919 .931 r
.47336 .46818 .47661 .46925 .48234 .46586 .47911 .46442 Metetra
.769 .894 .932 r
.47911 .46442 .48234 .46586 .48807 .46274 .48485 .46089 Metetra
.752 .864 .93 r
.48485 .46089 .48807 .46274 .4938 .45989 .4906 .45766 Metetra
.733 .835 .927 r
.4906 .45766 .4938 .45989 .49954 .4573 .49635 .45472 Metetra
.715 .809 .923 r
.49635 .45472 .49954 .4573 .50529 .45492 .50212 .45207 Metetra
.7 .788 .919 r
.50212 .45207 .50529 .45492 .51105 .4527 .50788 .44965 Metetra
.688 .772 .915 r
.50788 .44965 .51105 .4527 .51682 .4506 .51366 .4474 Metetra
.68 .761 .913 r
.51366 .4474 .51682 .4506 .5226 .44858 .51945 .44529 Metetra
.674 .754 .911 r
.51945 .44529 .5226 .44858 .52839 .44661 .52525 .44325 Metetra
.67 .749 .91 r
.52525 .44325 .52839 .44661 .53419 .44467 .53106 .44127 Metetra
.668 .746 .909 r
.53106 .44127 .53419 .44467 .54001 .44275 .53689 .43932 Metetra
.667 .744 .908 r
.53689 .43932 .54001 .44275 .54583 .44084 .54272 .43739 Metetra
.666 .743 .908 r
.54272 .43739 .54583 .44084 .55167 .43894 .54857 .43548 Metetra
.665 .743 .908 r
.54857 .43548 .55167 .43894 .55753 .43704 .55443 .43356 Metetra
.665 .742 .908 r
.55443 .43356 .55753 .43704 .56339 .43514 .5603 .43165 Metetra
.664 .742 .908 r
.5603 .43165 .56339 .43514 .56927 .43324 .56619 .42974 Metetra
.664 .742 .908 r
.56619 .42974 .56927 .43324 .57516 .43134 .57209 .42783 Metetra
.664 .741 .908 r
.57209 .42783 .57516 .43134 .58106 .42944 .578 .42592 Metetra
.664 .741 .908 r
.578 .42592 .58106 .42944 .58698 .42753 .58392 .42401 Metetra
.663 .741 .908 r
.58392 .42401 .58698 .42753 .5929 .42563 .58986 .4221 Metetra
.663 .741 .908 r
.58986 .4221 .5929 .42563 .59884 .42372 .59581 .42018 Metetra
.663 .741 .908 r
.59581 .42018 .59884 .42372 .6048 .42181 .60177 .41826 Metetra
.663 .741 .908 r
.60177 .41826 .6048 .42181 .61076 .41989 .60774 .41635 Metetra
.663 .742 .909 r
.60774 .41635 .61076 .41989 .61674 .41798 .61373 .41443 Metetra
.662 .742 .909 r
.61373 .41443 .61674 .41798 .62273 .41606 .61973 .41251 Metetra
.662 .742 .909 r
.61973 .41251 .62273 .41606 .62874 .41415 .62574 .4106 Metetra
.661 .742 .91 r
.62574 .4106 .62874 .41415 .63476 .41224 .63177 .40869 Metetra
.661 .742 .911 r
.63177 .40869 .63476 .41224 .64079 .41034 .63781 .40679 Metetra
.66 .743 .912 r
.63781 .40679 .64079 .41034 .64683 .40844 .64387 .4049 Metetra
.658 .743 .913 r
.64387 .4049 .64683 .40844 .65289 .40655 .64993 .40302 Metetra
.656 .744 .914 r
.64993 .40302 .65289 .40655 .65896 .40468 .65602 .40117 Metetra
.654 .745 .916 r
.65602 .40117 .65896 .40468 .66505 .40283 .66211 .39935 Metetra
.651 .746 .919 r
.66211 .39935 .66505 .40283 .67115 .40101 .66823 .39756 Metetra
.648 .747 .922 r
.66823 .39756 .67115 .40101 .67727 .39922 .67436 .39582 Metetra
.643 .749 .926 r
.67436 .39582 .67727 .39922 .68341 .39748 .6805 .39414 Metetra
.637 .751 .931 r
.6805 .39414 .68341 .39748 .68956 .3958 .68667 .39253 Metetra
.629 .753 .937 r
.68667 .39253 .68956 .3958 .69573 .39419 .69285 .39101 Metetra
.62 .757 .943 r
.69285 .39101 .69573 .39419 .70192 .39265 .69906 .38958 Metetra
.61 .76 .951 r
.69906 .38958 .70192 .39265 .70813 .39121 .70529 .38825 Metetra
.598 .765 .959 r
.70529 .38825 .70813 .39121 .71436 .38985 .71154 .38701 Metetra
.587 .769 .966 r
.71154 .38701 .71436 .38985 .72061 .38858 .71781 .38585 Metetra
.577 .774 .973 r
.71781 .38585 .72061 .38858 .72689 .38739 .7241 .38476 Metetra
.57 .779 .977 r
.7241 .38476 .72689 .38739 .73318 .38625 .73041 .38369 Metetra
.569 .784 .98 r
.73041 .38369 .73318 .38625 .73949 .38513 .73673 .38259 Metetra
.575 .789 .98 r
.73673 .38259 .73949 .38513 .74582 .38399 .74307 .38141 Metetra
.59 .793 .977 r
.74307 .38141 .74582 .38399 .75216 .38277 .74942 .3801 Metetra
.61 .794 .969 r
.74942 .3801 .75216 .38277 .75851 .38143 .75577 .3786 Metetra
.633 .791 .958 r
.75577 .3786 .75851 .38143 .76487 .37991 .76212 .37687 Metetra
.654 .785 .944 r
.76212 .37687 .76487 .37991 .77122 .37819 .76847 .37491 Metetra
.671 .775 .928 r
.76847 .37491 .77122 .37819 .77758 .37625 .77481 .37273 Metetra
.683 .764 .913 r
.77481 .37273 .77758 .37625 .78393 .3741 .78116 .37036 Metetra
.689 .754 .901 r
.78116 .37036 .78393 .3741 .79028 .37178 .7875 .36786 Metetra
.692 .745 .893 r
.7875 .36786 .79028 .37178 .79663 .36932 .79386 .3653 Metetra
.691 .739 .888 r
.79386 .3653 .79663 .36932 .80299 .36679 .80022 .36273 Metetra
.687 .737 .888 r
.80022 .36273 .80299 .36679 .80936 .36426 .80661 .36023 Metetra
.682 .737 .892 r
.80661 .36023 .80936 .36426 .81575 .36177 .81301 .35781 Metetra
.677 .739 .897 r
.81301 .35781 .81575 .36177 .82215 .35936 .81944 .3555 Metetra
.671 .743 .904 r
.81944 .3555 .82215 .35936 .82858 .35705 .82589 .35328 Metetra
.667 .748 .911 r
.82589 .35328 .82858 .35705 .83504 .35482 .83236 .35114 Metetra
.664 .752 .916 r
.83236 .35114 .83504 .35482 .84151 .35267 .83886 .34904 Metetra
.663 .755 .919 r
.83886 .34904 .84151 .35267 .848 .35056 .84536 .34694 Metetra
.664 .757 .919 r
.84536 .34694 .848 .35056 .85451 .34847 .85188 .34483 Metetra
.666 .757 .918 r
.85188 .34483 .85451 .34847 .86104 .34636 .85841 .34268 Metetra
.668 .755 .916 r
.85841 .34268 .86104 .34636 .86757 .34423 .86495 .34048 Metetra
.67 .753 .913 r
.86495 .34048 .86757 .34423 .87412 .34205 .87151 .33825 Metetra
.672 .751 .91 r
.87151 .33825 .87412 .34205 .88068 .33984 .87807 .33599 Metetra
.672 .749 .908 r
.87807 .33599 .88068 .33984 .88725 .33761 .88465 .33372 Metetra
.672 .747 .907 r
.88465 .33372 .88725 .33761 .89383 .33535 .89124 .33145 Metetra
.671 .746 .907 r
.89124 .33145 .89383 .33535 .90042 .33309 .89785 .32918 Metetra
.656 .739 .911 r
.30402 .51509 .30746 .51829 .31282 .51665 .30939 .51346 Metetra
.657 .74 .912 r
.30939 .51346 .31282 .51665 .3182 .515 .31477 .51182 Metetra
.657 .742 .912 r
.31477 .51182 .3182 .515 .32359 .51335 .32016 .51016 Metetra
.658 .742 .912 r
.32016 .51016 .32359 .51335 .32898 .5117 .32557 .50849 Metetra
.657 .741 .912 r
.32557 .50849 .32898 .5117 .33439 .51009 .33098 .50683 Metetra
.655 .738 .91 r
.33098 .50683 .33439 .51009 .3398 .50852 .33641 .5052 Metetra
.652 .733 .909 r
.33641 .5052 .3398 .50852 .34523 .50701 .34184 .50361 Metetra
.647 .728 .907 r
.34184 .50361 .34523 .50701 .35066 .50554 .34728 .50208 Metetra
.644 .724 .907 r
.34728 .50208 .35066 .50554 .3561 .50407 .35273 .5006 Metetra
.642 .723 .907 r
.35273 .5006 .3561 .50407 .36156 .50256 .35819 .49915 Metetra
.643 .727 .909 r
.35819 .49915 .36156 .50256 .36703 .50097 .36367 .49767 Metetra
.648 .736 .913 r
.36367 .49767 .36703 .50097 .37253 .49926 .36916 .49612 Metetra
.656 .749 .918 r
.36916 .49612 .37253 .49926 .37803 .49742 .37467 .49444 Metetra
.665 .761 .922 r
.37467 .49444 .37803 .49742 .38356 .49552 .38019 .49262 Metetra
.672 .769 .923 r
.38019 .49262 .38356 .49552 .38909 .49365 .38573 .4907 Metetra
.672 .766 .921 r
.38573 .4907 .38909 .49365 .39462 .49194 .39129 .48878 Metetra
.663 .751 .915 r
.39129 .48878 .39462 .49194 .40016 .49052 .39684 .48699 Metetra
.644 .723 .905 r
.39684 .48699 .40016 .49052 .40569 .48948 .4024 .48547 Metetra
.617 .687 .893 r
.4024 .48547 .40569 .48948 .41123 .48885 .40796 .48436 Metetra
.588 .651 .88 r
.40796 .48436 .41123 .48885 .41677 .48854 .41352 .4837 Metetra
.563 .624 .871 r
.41352 .4837 .41677 .48854 .42232 .4884 .41907 .48342 Metetra
.547 .611 .869 r
.41907 .48342 .42232 .4884 .42789 .48818 .42464 .48338 Metetra
.545 .618 .876 r
.42464 .48338 .42789 .48818 .43349 .48765 .43023 .48333 Metetra
.56 .65 .895 r
.43023 .48333 .43349 .48765 .43911 .48659 .43584 .483 Metetra
.593 .705 .921 r
.43584 .483 .43911 .48659 .44477 .48486 .44148 .48212 Metetra
.64 .777 .946 r
.44148 .48212 .44477 .48486 .45046 .48243 .44715 .48054 Metetra
.691 .851 .959 r
.44715 .48054 .45046 .48243 .45616 .47937 .45286 .47819 Metetra
.733 .909 .955 r
.45286 .47819 .45616 .47937 .46189 .47584 .45858 .47514 Metetra
.762 .942 .94 r
.45858 .47514 .46189 .47584 .46762 .47204 .46433 .47154 Metetra
.779 .954 .929 r
.46433 .47154 .46762 .47204 .47336 .46818 .47009 .46761 Metetra
.787 .951 .925 r
.47009 .46761 .47336 .46818 .47911 .46442 .47585 .46359 Metetra
.786 .935 .928 r
.47585 .46359 .47911 .46442 .48485 .46089 .48161 .45967 Metetra
.776 .91 .932 r
.48161 .45967 .48485 .46089 .4906 .45766 .48738 .45598 Metetra
.759 .878 .932 r
.48738 .45598 .4906 .45766 .49635 .45472 .49315 .45262 Metetra
.739 .846 .93 r
.49315 .45262 .49635 .45472 .50212 .45207 .49892 .44959 Metetra
.719 .817 .926 r
.49892 .44959 .50212 .45207 .50788 .44965 .5047 .44686 Metetra
.703 .794 .921 r
.5047 .44686 .50788 .44965 .51366 .4474 .51049 .44439 Metetra
.69 .776 .917 r
.51049 .44439 .51366 .4474 .51945 .44529 .51629 .44212 Metetra
.681 .764 .914 r
.51629 .44212 .51945 .44529 .52525 .44325 .5221 .43998 Metetra
.674 .756 .913 r
.5221 .43998 .52525 .44325 .53106 .44127 .52792 .43793 Metetra
.67 .751 .911 r
.52792 .43793 .53106 .44127 .53689 .43932 .53375 .43594 Metetra
.668 .748 .911 r
.53375 .43594 .53689 .43932 .54272 .43739 .5396 .43398 Metetra
.666 .747 .91 r
.5396 .43398 .54272 .43739 .54857 .43548 .54545 .43204 Metetra
.665 .746 .91 r
.54545 .43204 .54857 .43548 .55443 .43356 .55132 .43011 Metetra
.665 .745 .91 r
.55132 .43011 .55443 .43356 .5603 .43165 .5572 .42819 Metetra
.664 .744 .91 r
.5572 .42819 .5603 .43165 .56619 .42974 .5631 .42627 Metetra
.664 .744 .91 r
.5631 .42627 .56619 .42974 .57209 .42783 .569 .42435 Metetra
.664 .744 .91 r
.569 .42435 .57209 .42783 .578 .42592 .57492 .42243 Metetra
.664 .744 .91 r
.57492 .42243 .578 .42592 .58392 .42401 .58085 .42051 Metetra
.663 .744 .91 r
.58085 .42051 .58392 .42401 .58986 .4221 .5868 .41859 Metetra
.663 .744 .91 r
.5868 .41859 .58986 .4221 .59581 .42018 .59276 .41667 Metetra
.663 .744 .91 r
.59276 .41667 .59581 .42018 .60177 .41826 .59873 .41474 Metetra
.663 .743 .91 r
.59873 .41474 .60177 .41826 .60774 .41635 .60471 .41282 Metetra
.662 .743 .91 r
.60471 .41282 .60774 .41635 .61373 .41443 .61071 .4109 Metetra
.662 .744 .911 r
.61071 .4109 .61373 .41443 .61973 .41251 .61671 .40898 Metetra
.661 .744 .911 r
.61671 .40898 .61973 .41251 .62574 .4106 .62274 .40706 Metetra
.661 .744 .912 r
.62274 .40706 .62574 .4106 .63177 .40869 .62877 .40516 Metetra
.66 .744 .912 r
.62877 .40516 .63177 .40869 .63781 .40679 .63482 .40326 Metetra
.658 .744 .913 r
.63482 .40326 .63781 .40679 .64387 .4049 .64089 .40138 Metetra
.656 .745 .915 r
.64089 .40138 .64387 .4049 .64993 .40302 .64697 .39952 Metetra
.654 .746 .917 r
.64697 .39952 .64993 .40302 .65602 .40117 .65306 .39769 Metetra
.651 .746 .919 r
.65306 .39769 .65602 .40117 .66211 .39935 .65917 .39591 Metetra
.647 .748 .923 r
.65917 .39591 .66211 .39935 .66823 .39756 .66529 .39417 Metetra
.642 .749 .927 r
.66529 .39417 .66823 .39756 .67436 .39582 .67144 .39249 Metetra
.636 .752 .932 r
.67144 .39249 .67436 .39582 .6805 .39414 .6776 .39089 Metetra
.628 .754 .938 r
.6776 .39089 .6805 .39414 .68667 .39253 .68378 .38938 Metetra
.618 .758 .945 r
.68378 .38938 .68667 .39253 .69285 .39101 .68998 .38796 Metetra
.607 .762 .953 r
.68998 .38796 .69285 .39101 .69906 .38958 .6962 .38666 Metetra
.594 .766 .961 r
.6962 .38666 .69906 .38958 .70529 .38825 .70244 .38545 Metetra
.581 .771 .969 r
.70244 .38545 .70529 .38825 .71154 .38701 .70871 .38434 Metetra
.569 .776 .976 r
.70871 .38434 .71154 .38701 .71781 .38585 .715 .38329 Metetra
.561 .781 .981 r
.715 .38329 .71781 .38585 .7241 .38476 .72131 .38227 Metetra
.559 .787 .984 r
.72131 .38227 .7241 .38476 .73041 .38369 .72763 .38123 Metetra
.567 .792 .984 r
.72763 .38123 .73041 .38369 .73673 .38259 .73397 .38009 Metetra
.583 .797 .981 r
.73397 .38009 .73673 .38259 .74307 .38141 .74031 .37881 Metetra
.606 .798 .973 r
.74031 .37881 .74307 .38141 .74942 .3801 .74666 .37732 Metetra
.632 .795 .961 r
.74666 .37732 .74942 .3801 .75577 .3786 .753 .37559 Metetra
.655 .788 .945 r
.753 .37559 .75577 .3786 .76212 .37687 .75935 .37361 Metetra
.673 .777 .928 r
.75935 .37361 .76212 .37687 .76847 .37491 .76569 .37139 Metetra
.685 .765 .912 r
.76569 .37139 .76847 .37491 .77481 .37273 .77202 .36897 Metetra
.692 .754 .899 r
.77202 .36897 .77481 .37273 .78116 .37036 .77836 .36642 Metetra
.694 .745 .891 r
.77836 .36642 .78116 .37036 .7875 .36786 .78471 .36381 Metetra
.692 .739 .887 r
.78471 .36381 .7875 .36786 .79386 .3653 .79107 .36122 Metetra
.688 .736 .888 r
.79107 .36122 .79386 .3653 .80022 .36273 .79745 .35869 Metetra
.682 .737 .892 r
.79745 .35869 .80022 .36273 .80661 .36023 .80386 .35627 Metetra
.676 .74 .898 r
.80386 .35627 .80661 .36023 .81301 .35781 .81028 .35397 Metetra
.67 .744 .906 r
.81028 .35397 .81301 .35781 .81944 .3555 .81673 .35176 Metetra
.666 .749 .913 r
.81673 .35176 .81944 .3555 .82589 .35328 .8232 .34963 Metetra
.663 .754 .918 r
.8232 .34963 .82589 .35328 .83236 .35114 .82969 .34753 Metetra
.663 .757 .92 r
.82969 .34753 .83236 .35114 .83886 .34904 .83619 .34543 Metetra
.664 .758 .92 r
.83619 .34543 .83886 .34904 .84536 .34694 .84271 .3433 Metetra
.667 .758 .918 r
.84271 .3433 .84536 .34694 .85188 .34483 .84923 .34113 Metetra
.669 .756 .915 r
.84923 .34113 .85188 .34483 .85841 .34268 .85577 .33892 Metetra
.671 .753 .912 r
.85577 .33892 .85841 .34268 .86495 .34048 .86232 .33666 Metetra
.673 .751 .909 r
.86232 .33666 .86495 .34048 .87151 .33825 .86888 .33439 Metetra
.673 .749 .908 r
.86888 .33439 .87151 .33825 .87807 .33599 .87545 .3321 Metetra
.672 .747 .907 r
.87545 .3321 .87807 .33599 .88465 .33372 .88203 .32981 Metetra
.672 .746 .907 r
.88203 .32981 .88465 .33372 .89124 .33145 .88864 .32753 Metetra
.671 .746 .907 r
.88864 .32753 .89124 .33145 .89785 .32918 .89526 .32526 Metetra
.655 .738 .91 r
.30057 .51185 .30402 .51509 .30939 .51346 .30595 .51023 Metetra
.655 .738 .911 r
.30595 .51023 .30939 .51346 .31477 .51182 .31133 .5086 Metetra
.656 .74 .912 r
.31133 .5086 .31477 .51182 .32016 .51016 .31673 .50696 Metetra
.657 .741 .912 r
.31673 .50696 .32016 .51016 .32557 .50849 .32214 .5053 Metetra
.658 .742 .912 r
.32214 .5053 .32557 .50849 .33098 .50683 .32756 .50362 Metetra
.657 .742 .912 r
.32756 .50362 .33098 .50683 .33641 .5052 .333 .50195 Metetra
.656 .739 .911 r
.333 .50195 .33641 .5052 .34184 .50361 .33844 .50029 Metetra
.653 .735 .91 r
.33844 .50029 .34184 .50361 .34728 .50208 .34389 .49867 Metetra
.648 .729 .908 r
.34389 .49867 .34728 .50208 .35273 .5006 .34935 .49712 Metetra
.644 .723 .906 r
.34935 .49712 .35273 .5006 .35819 .49915 .35482 .49564 Metetra
.64 .721 .906 r
.35482 .49564 .35819 .49915 .36367 .49767 .3603 .49419 Metetra
.64 .723 .908 r
.3603 .49419 .36367 .49767 .36916 .49612 .36579 .49274 Metetra
.644 .731 .912 r
.36579 .49274 .36916 .49612 .37467 .49444 .3713 .49123 Metetra
.652 .744 .917 r
.3713 .49123 .37467 .49444 .38019 .49262 .37682 .4896 Metetra
.663 .759 .922 r
.37682 .4896 .38019 .49262 .38573 .4907 .38237 .48781 Metetra
.672 .77 .924 r
.38237 .48781 .38573 .4907 .39129 .48878 .38793 .48588 Metetra
.675 .771 .923 r
.38793 .48588 .39129 .48878 .39684 .48699 .3935 .48391 Metetra
.668 .758 .918 r
.3935 .48391 .39684 .48699 .4024 .48547 .39908 .48203 Metetra
.65 .731 .908 r
.39908 .48203 .4024 .48547 .40796 .48436 .40466 .48042 Metetra
.623 .694 .895 r
.40466 .48042 .40796 .48436 .41352 .4837 .41024 .47921 Metetra
.591 .654 .88 r
.41024 .47921 .41352 .4837 .41907 .48342 .41582 .4785 Metetra
.561 .62 .868 r
.41582 .4785 .41907 .48342 .42464 .48338 .42139 .47825 Metetra
.54 .602 .864 r
.42139 .47825 .42464 .48338 .43023 .48333 .42698 .47831 Metetra
.534 .604 .87 r
.42698 .47831 .43023 .48333 .43584 .483 .43258 .47843 Metetra
.545 .632 .888 r
.43258 .47843 .43584 .483 .44148 .48212 .43821 .47831 Metetra
.577 .687 .916 r
.43821 .47831 .44148 .48212 .44715 .48054 .44386 .47766 Metetra
.626 .764 .945 r
.44386 .47766 .44715 .48054 .45286 .47819 .44955 .47626 Metetra
.682 .847 .962 r
.44955 .47626 .45286 .47819 .45858 .47514 .45527 .47401 Metetra
.729 .913 .957 r
.45527 .47401 .45858 .47514 .46433 .47154 .46102 .47097 Metetra
.762 .951 .938 r
.46102 .47097 .46433 .47154 .47009 .46761 .46679 .4673 Metetra
.782 .965 .922 r
.46679 .4673 .47009 .46761 .47585 .46359 .47256 .46323 Metetra
.793 .962 .918 r
.47256 .46323 .47585 .46359 .48161 .45967 .47835 .45901 Metetra
.794 .947 .922 r
.47835 .45901 .48161 .45967 .48738 .45598 .48414 .45489 Metetra
.785 .92 .928 r
.48414 .45489 .48738 .45598 .49315 .45262 .48993 .45102 Metetra
.768 .885 .93 r
.48993 .45102 .49315 .45262 .49892 .44959 .49572 .4475 Metetra
.745 .849 .927 r
.49572 .4475 .49892 .44959 .5047 .44686 .50151 .44435 Metetra
.724 .817 .923 r
.50151 .44435 .5047 .44686 .51049 .44439 .50731 .44154 Metetra
.705 .791 .918 r
.50731 .44154 .51049 .44439 .51629 .44212 .51312 .43902 Metetra
.691 .772 .914 r
.51312 .43902 .51629 .44212 .5221 .43998 .51894 .43671 Metetra
.681 .759 .911 r
.51894 .43671 .5221 .43998 .52792 .43793 .52477 .43455 Metetra
.674 .751 .908 r
.52477 .43455 .52792 .43793 .53375 .43594 .53061 .43249 Metetra
.67 .746 .907 r
.53061 .43249 .53375 .43594 .5396 .43398 .53646 .43048 Metetra
.668 .743 .906 r
.53646 .43048 .5396 .43398 .54545 .43204 .54232 .42852 Metetra
.666 .741 .906 r
.54232 .42852 .54545 .43204 .55132 .43011 .5482 .42657 Metetra
.665 .74 .906 r
.5482 .42657 .55132 .43011 .5572 .42819 .55409 .42463 Metetra
.665 .739 .906 r
.55409 .42463 .5572 .42819 .5631 .42627 .55999 .42269 Metetra
.664 .739 .905 r
.55999 .42269 .5631 .42627 .569 .42435 .56591 .42076 Metetra
.664 .738 .905 r
.56591 .42076 .569 .42435 .57492 .42243 .57183 .41883 Metetra
.664 .738 .905 r
.57183 .41883 .57492 .42243 .58085 .42051 .57777 .4169 Metetra
.663 .738 .905 r
.57777 .4169 .58085 .42051 .5868 .41859 .58373 .41498 Metetra
.663 .738 .906 r
.58373 .41498 .5868 .41859 .59276 .41667 .58969 .41305 Metetra
.663 .738 .906 r
.58969 .41305 .59276 .41667 .59873 .41474 .59567 .41112 Metetra
.662 .738 .906 r
.59567 .41112 .59873 .41474 .60471 .41282 .60166 .4092 Metetra
.662 .738 .907 r
.60166 .4092 .60471 .41282 .61071 .4109 .60767 .40727 Metetra
.661 .739 .907 r
.60767 .40727 .61071 .4109 .61671 .40898 .61369 .40536 Metetra
.661 .739 .908 r
.61369 .40536 .61671 .40898 .62274 .40706 .61972 .40345 Metetra
.66 .739 .909 r
.61972 .40345 .62274 .40706 .62877 .40516 .62576 .40155 Metetra
.658 .74 .91 r
.62576 .40155 .62877 .40516 .63482 .40326 .63182 .39967 Metetra
.656 .741 .912 r
.63182 .39967 .63482 .40326 .64089 .40138 .6379 .39781 Metetra
.654 .742 .914 r
.6379 .39781 .64089 .40138 .64697 .39952 .64398 .39598 Metetra
.651 .743 .917 r
.64398 .39598 .64697 .39952 .65306 .39769 .65009 .3942 Metetra
.647 .744 .92 r
.65009 .3942 .65306 .39769 .65917 .39591 .65621 .39246 Metetra
.642 .746 .925 r
.65621 .39246 .65917 .39591 .66529 .39417 .66235 .39079 Metetra
.635 .749 .93 r
.66235 .39079 .66529 .39417 .67144 .39249 .6685 .3892 Metetra
.627 .752 .937 r
.6685 .3892 .67144 .39249 .6776 .39089 .67468 .3877 Metetra
.616 .755 .945 r
.67468 .3877 .6776 .39089 .68378 .38938 .68087 .38631 Metetra
.604 .76 .953 r
.68087 .38631 .68378 .38938 .68998 .38796 .68709 .38504 Metetra
.59 .764 .962 r
.68709 .38504 .68998 .38796 .6962 .38666 .69333 .38388 Metetra
.575 .77 .971 r
.69333 .38388 .6962 .38666 .70244 .38545 .6996 .38281 Metetra
.561 .775 .979 r
.6996 .38281 .70244 .38545 .70871 .38434 .70588 .38182 Metetra
.551 .781 .984 r
.70588 .38182 .70871 .38434 .715 .38329 .71219 .38086 Metetra
.549 .787 .987 r
.71219 .38086 .715 .38329 .72131 .38227 .71851 .37987 Metetra
.557 .794 .987 r
.71851 .37987 .72131 .38227 .72763 .38123 .72484 .37879 Metetra
.576 .799 .984 r
.72484 .37879 .72763 .38123 .73397 .38009 .73118 .37754 Metetra
.602 .801 .976 r
.73118 .37754 .73397 .38009 .74031 .37881 .73753 .37607 Metetra
.631 .799 .963 r
.73753 .37607 .74031 .37881 .74666 .37732 .74387 .37434 Metetra
.656 .791 .946 r
.74387 .37434 .74666 .37732 .753 .37559 .75021 .37233 Metetra
.676 .779 .928 r
.75021 .37233 .753 .37559 .75935 .37361 .75654 .37007 Metetra
.688 .766 .911 r
.75654 .37007 .75935 .37361 .76569 .37139 .76287 .3676 Metetra
.694 .754 .897 r
.76287 .3676 .76569 .37139 .77202 .36897 .76921 .36499 Metetra
.696 .744 .889 r
.76921 .36499 .77202 .36897 .77836 .36642 .77555 .36234 Metetra
.693 .738 .886 r
.77555 .36234 .77836 .36642 .78471 .36381 .78191 .35972 Metetra
.689 .736 .887 r
.78191 .35972 .78471 .36381 .79107 .36122 .78828 .35717 Metetra
.682 .737 .892 r
.78828 .35717 .79107 .36122 .79745 .35869 .79468 .35475 Metetra
.676 .741 .9 r
.79468 .35475 .79745 .35869 .80386 .35627 .80111 .35246 Metetra
.669 .746 .908 r
.80111 .35246 .80386 .35627 .81028 .35397 .80755 .35027 Metetra
.665 .751 .915 r
.80755 .35027 .81028 .35397 .81673 .35176 .81402 .34814 Metetra
.663 .756 .92 r
.81402 .34814 .81673 .35176 .8232 .34963 .82051 .34605 Metetra
.663 .759 .921 r
.82051 .34605 .8232 .34963 .82969 .34753 .82701 .34394 Metetra
.665 .76 .921 r
.82701 .34394 .82969 .34753 .83619 .34543 .83352 .34179 Metetra
.668 .759 .918 r
.83352 .34179 .83619 .34543 .84271 .3433 .84004 .3396 Metetra
.671 .756 .915 r
.84004 .3396 .84271 .3433 .84923 .34113 .84657 .33736 Metetra
.673 .753 .911 r
.84657 .33736 .84923 .34113 .85577 .33892 .85311 .33508 Metetra
.674 .75 .909 r
.85311 .33508 .85577 .33892 .86232 .33666 .85966 .33278 Metetra
.674 .748 .907 r
.85966 .33278 .86232 .33666 .86888 .33439 .86623 .33048 Metetra
.673 .747 .906 r
.86623 .33048 .86888 .33439 .87545 .3321 .87281 .32818 Metetra
.672 .746 .906 r
.87281 .32818 .87545 .3321 .88203 .32981 .87941 .32589 Metetra
.671 .746 .907 r
.87941 .32589 .88203 .32981 .88864 .32753 .88603 .32361 Metetra
.67 .747 .908 r
.88603 .32361 .88864 .32753 .89526 .32526 .89266 .32134 Metetra
.655 .737 .91 r
.29711 .50859 .30057 .51185 .30595 .51023 .30249 .50696 Metetra
.654 .737 .91 r
.30249 .50696 .30595 .51023 .31133 .5086 .30788 .50534 Metetra
.654 .738 .911 r
.30788 .50534 .31133 .5086 .31673 .50696 .31329 .50371 Metetra
.655 .739 .911 r
.31329 .50371 .31673 .50696 .32214 .5053 .3187 .50207 Metetra
.656 .741 .912 r
.3187 .50207 .32214 .5053 .32756 .50362 .32413 .50041 Metetra
.657 .742 .913 r
.32413 .50041 .32756 .50362 .333 .50195 .32957 .49873 Metetra
.658 .743 .913 r
.32957 .49873 .333 .50195 .33844 .50029 .33502 .49704 Metetra
.657 .741 .912 r
.33502 .49704 .33844 .50029 .34389 .49867 .34048 .49536 Metetra
.654 .737 .91 r
.34048 .49536 .34389 .49867 .34935 .49712 .34595 .49372 Metetra
.649 .73 .908 r
.34595 .49372 .34935 .49712 .35482 .49564 .35143 .49214 Metetra
.644 .724 .906 r
.35143 .49214 .35482 .49564 .3603 .49419 .35692 .49063 Metetra
.64 .719 .905 r
.35692 .49063 .3603 .49419 .36579 .49274 .36242 .48919 Metetra
.638 .719 .907 r
.36242 .48919 .36579 .49274 .3713 .49123 .36793 .48777 Metetra
.64 .726 .91 r
.36793 .48777 .3713 .49123 .37682 .4896 .37345 .4863 Metetra
.648 .739 .916 r
.37345 .4863 .37682 .4896 .38237 .48781 .37899 .48472 Metetra
.659 .755 .921 r
.37899 .48472 .38237 .48781 .38793 .48588 .38455 .48297 Metetra
.67 .77 .925 r
.38455 .48297 .38793 .48588 .3935 .48391 .39013 .48106 Metetra
.676 .776 .925 r
.39013 .48106 .3935 .48391 .39908 .48203 .39572 .47906 Metetra
.673 .767 .921 r
.39572 .47906 .39908 .48203 .40466 .48042 .40132 .4771 Metetra
.657 .742 .912 r
.40132 .4771 .40466 .48042 .41024 .47921 .40693 .47537 Metetra
.63 .703 .898 r
.40693 .47537 .41024 .47921 .41582 .4785 .41253 .47405 Metetra
.595 .658 .882 r
.41253 .47405 .41582 .4785 .42139 .47825 .41813 .47326 Metetra
.561 .619 .867 r
.41813 .47326 .42139 .47825 .42698 .47831 .42373 .473 Metetra
.536 .593 .859 r
.42373 .473 .42698 .47831 .43258 .47843 .42933 .47315 Metetra
.524 .589 .861 r
.42933 .47315 .43258 .47843 .43821 .47831 .43495 .47344 Metetra
.531 .611 .878 r
.43495 .47344 .43821 .47831 .44386 .47766 .44059 .47355 Metetra
.56 .664 .907 r
.44059 .47355 .44386 .47766 .44955 .47626 .44626 .47314 Metetra
.61 .744 .941 r
.44626 .47314 .44955 .47626 .45527 .47401 .45197 .47196 Metetra
.671 .837 .963 r
.45197 .47196 .45527 .47401 .46102 .47097 .4577 .46986 Metetra
.724 .914 .959 r
.4577 .46986 .46102 .47097 .46679 .4673 .46347 .46686 Metetra
.759 .958 .936 r
.46347 .46686 .46679 .4673 .47256 .46323 .46926 .46314 Metetra
.78 .976 .914 r
.46926 .46314 .47256 .46323 .47835 .45901 .47506 .45893 Metetra
.793 .976 .907 r
.47506 .45893 .47835 .45901 .48414 .45489 .48087 .45454 Metetra
.798 .964 .914 r
.48087 .45454 .48414 .45489 .48993 .45102 .48667 .45022 Metetra
.791 .94 .925 r
.48667 .45022 .48993 .45102 .49572 .4475 .49248 .44616 Metetra
.775 .905 .932 r
.49248 .44616 .49572 .4475 .50151 .44435 .4983 .44248 Metetra
.752 .867 .932 r
.4983 .44248 .50151 .44435 .50731 .44154 .50411 .43921 Metetra
.728 .832 .929 r
.50411 .43921 .50731 .44154 .51312 .43902 .50993 .43632 Metetra
.708 .804 .924 r
.50993 .43632 .51312 .43902 .51894 .43671 .51576 .43374 Metetra
.693 .783 .92 r
.51576 .43374 .51894 .43671 .52477 .43455 .5216 .4314 Metetra
.682 .768 .917 r
.5216 .4314 .52477 .43455 .53061 .43249 .52745 .42922 Metetra
.675 .759 .915 r
.52745 .42922 .53061 .43249 .53646 .43048 .53331 .42714 Metetra
.67 .754 .913 r
.53331 .42714 .53646 .43048 .54232 .42852 .53918 .42513 Metetra
.668 .751 .913 r
.53918 .42513 .54232 .42852 .5482 .42657 .54507 .42315 Metetra
.666 .749 .912 r
.54507 .42315 .5482 .42657 .55409 .42463 .55096 .4212 Metetra
.665 .748 .912 r
.55096 .4212 .55409 .42463 .55999 .42269 .55687 .41925 Metetra
.665 .748 .912 r
.55687 .41925 .55999 .42269 .56591 .42076 .5628 .41731 Metetra
.664 .747 .912 r
.5628 .41731 .56591 .42076 .57183 .41883 .56873 .41537 Metetra
.664 .747 .912 r
.56873 .41537 .57183 .41883 .57777 .4169 .57468 .41343 Metetra
.663 .747 .912 r
.57468 .41343 .57777 .4169 .58373 .41498 .58064 .4115 Metetra
.663 .747 .913 r
.58064 .4115 .58373 .41498 .58969 .41305 .58662 .40956 Metetra
.663 .747 .913 r
.58662 .40956 .58969 .41305 .59567 .41112 .59261 .40763 Metetra
.662 .747 .913 r
.59261 .40763 .59567 .41112 .60166 .4092 .59861 .4057 Metetra
.661 .747 .914 r
.59861 .4057 .60166 .4092 .60767 .40727 .60462 .40378 Metetra
.661 .747 .914 r
.60462 .40378 .60767 .40727 .61369 .40536 .61065 .40186 Metetra
.66 .747 .915 r
.61065 .40186 .61369 .40536 .61972 .40345 .61669 .39996 Metetra
.658 .748 .916 r
.61669 .39996 .61972 .40345 .62576 .40155 .62274 .39807 Metetra
.656 .748 .917 r
.62274 .39807 .62576 .40155 .63182 .39967 .62881 .39621 Metetra
.654 .749 .919 r
.62881 .39621 .63182 .39967 .6379 .39781 .6349 .39437 Metetra
.651 .749 .922 r
.6349 .39437 .6379 .39781 .64398 .39598 .641 .39258 Metetra
.646 .751 .925 r
.641 .39258 .64398 .39598 .65009 .3942 .64711 .39084 Metetra
.641 .752 .93 r
.64711 .39084 .65009 .3942 .65621 .39246 .65325 .38917 Metetra
.634 .754 .935 r
.65325 .38917 .65621 .39246 .66235 .39079 .6594 .38758 Metetra
.624 .757 .942 r
.6594 .38758 .66235 .39079 .6685 .3892 .66557 .3861 Metetra
.613 .76 .95 r
.66557 .3861 .6685 .3892 .67468 .3877 .67176 .38472 Metetra
.599 .764 .958 r
.67176 .38472 .67468 .3877 .68087 .38631 .67797 .38348 Metetra
.583 .769 .967 r
.67797 .38348 .68087 .38631 .68709 .38504 .68421 .38235 Metetra
.566 .773 .976 r
.68421 .38235 .68709 .38504 .69333 .38388 .69047 .38133 Metetra
.55 .778 .983 r
.69047 .38133 .69333 .38388 .6996 .38281 .69675 .3804 Metetra
.538 .784 .989 r
.69675 .3804 .6996 .38281 .70588 .38182 .70305 .3795 Metetra
.536 .79 .991 r
.70305 .3795 .70588 .38182 .71219 .38086 .70937 .37857 Metetra
.545 .797 .992 r
.70937 .37857 .71219 .38086 .71851 .37987 .7157 .37754 Metetra
.567 .804 .988 r
.7157 .37754 .71851 .37987 .72484 .37879 .72204 .37633 Metetra
.597 .806 .98 r
.72204 .37633 .72484 .37879 .73118 .37754 .72838 .37487 Metetra
.63 .803 .966 r
.72838 .37487 .73118 .37754 .73753 .37607 .73471 .37313 Metetra
.658 .794 .947 r
.73471 .37313 .73753 .37607 .74387 .37434 .74105 .37109 Metetra
.679 .781 .927 r
.74105 .37109 .74387 .37434 .75021 .37233 .74738 .36877 Metetra
.691 .766 .909 r
.74738 .36877 .75021 .37233 .75654 .37007 .7537 .36624 Metetra
.697 .753 .895 r
.7537 .36624 .75654 .37007 .76287 .3676 .76003 .36359 Metetra
.698 .743 .887 r
.76003 .36359 .76287 .3676 .76921 .36499 .76637 .36089 Metetra
.694 .737 .884 r
.76637 .36089 .76921 .36499 .77555 .36234 .77272 .35823 Metetra
.689 .736 .886 r
.77272 .35823 .77555 .36234 .78191 .35972 .7791 .35568 Metetra
.682 .737 .893 r
.7791 .35568 .78191 .35972 .78828 .35717 .78549 .35326 Metetra
.675 .742 .901 r
.78549 .35326 .78828 .35717 .79468 .35475 .79192 .35098 Metetra
.668 .748 .91 r
.79192 .35098 .79468 .35475 .80111 .35246 .79836 .3488 Metetra
.664 .754 .917 r
.79836 .3488 .80111 .35246 .80755 .35027 .80483 .34668 Metetra
.662 .759 .922 r
.80483 .34668 .80755 .35027 .81402 .34814 .81131 .34459 Metetra
.663 .761 .923 r
.81131 .34459 .81402 .34814 .82051 .34605 .8178 .34247 Metetra
.666 .762 .921 r
.8178 .34247 .82051 .34605 .82701 .34394 .82431 .3403 Metetra
.669 .76 .918 r
.82431 .3403 .82701 .34394 .83352 .34179 .83082 .33808 Metetra
.672 .757 .914 r
.83082 .33808 .83352 .34179 .84004 .3396 .83735 .33581 Metetra
.674 .753 .91 r
.83735 .33581 .84004 .3396 .84657 .33736 .84388 .3335 Metetra
.675 .75 .908 r
.84388 .3335 .84657 .33736 .85311 .33508 .85043 .33118 Metetra
.674 .748 .906 r
.85043 .33118 .85311 .33508 .85966 .33278 .857 .32886 Metetra
.673 .747 .906 r
.857 .32886 .85966 .33278 .86623 .33048 .86358 .32655 Metetra
.672 .747 .906 r
.86358 .32655 .86623 .33048 .87281 .32818 .87017 .32425 Metetra
.671 .747 .907 r
.87017 .32425 .87281 .32818 .87941 .32589 .87678 .32197 Metetra
.67 .747 .908 r
.87678 .32197 .87941 .32589 .88603 .32361 .88341 .3197 Metetra
.67 .748 .909 r
.88341 .3197 .88603 .32361 .89266 .32134 .89005 .31743 Metetra
.656 .738 .91 r
.29364 .50533 .29711 .50859 .30249 .50696 .29902 .50369 Metetra
.655 .737 .91 r
.29902 .50369 .30249 .50696 .30788 .50534 .30442 .50205 Metetra
.654 .737 .91 r
.30442 .50205 .30788 .50534 .31329 .50371 .30983 .50042 Metetra
.654 .737 .911 r
.30983 .50042 .31329 .50371 .3187 .50207 .31525 .49879 Metetra
.654 .738 .911 r
.31525 .49879 .3187 .50207 .32413 .50041 .32068 .49715 Metetra
.655 .74 .912 r
.32068 .49715 .32413 .50041 .32957 .49873 .32613 .49549 Metetra
.657 .742 .913 r
.32613 .49549 .32957 .49873 .33502 .49704 .33159 .49381 Metetra
.658 .743 .913 r
.33159 .49381 .33502 .49704 .34048 .49536 .33706 .49211 Metetra
.657 .742 .913 r
.33706 .49211 .34048 .49536 .34595 .49372 .34254 .49042 Metetra
.655 .739 .911 r
.34254 .49042 .34595 .49372 .35143 .49214 .34803 .48875 Metetra
.651 .733 .909 r
.34803 .48875 .35143 .49214 .35692 .49063 .35353 .48713 Metetra
.645 .725 .907 r
.35353 .48713 .35692 .49063 .36242 .48919 .35904 .4856 Metetra
.639 .718 .905 r
.35904 .4856 .36242 .48919 .36793 .48777 .36455 .48415 Metetra
.636 .716 .905 r
.36455 .48415 .36793 .48777 .37345 .4863 .37008 .48275 Metetra
.637 .72 .908 r
.37008 .48275 .37345 .4863 .37899 .48472 .37562 .48133 Metetra
.643 .733 .914 r
.37562 .48133 .37899 .48472 .38455 .48297 .38117 .47981 Metetra
.654 .75 .92 r
.38117 .47981 .38455 .48297 .39013 .48106 .38675 .47812 Metetra
.667 .768 .926 r
.38675 .47812 .39013 .48106 .39572 .47906 .39234 .47624 Metetra
.677 .779 .928 r
.39234 .47624 .39572 .47906 .40132 .4771 .39796 .47421 Metetra
.677 .775 .924 r
.39796 .47421 .40132 .4771 .40693 .47537 .40358 .47218 Metetra
.665 .753 .916 r
.40358 .47218 .40693 .47537 .41253 .47405 .40921 .47032 Metetra
.638 .713 .902 r
.40921 .47032 .41253 .47405 .41813 .47326 .41483 .46887 Metetra
.602 .665 .883 r
.41483 .46887 .41813 .47326 .42373 .473 .42046 .46797 Metetra
.563 .619 .865 r
.42046 .46797 .42373 .473 .42933 .47315 .42607 .46768 Metetra
.532 .585 .854 r
.42607 .46768 .42933 .47315 .43495 .47344 .4317 .46789 Metetra
.513 .573 .853 r
.4317 .46789 .43495 .47344 .44059 .47355 .43733 .46836 Metetra
.514 .589 .868 r
.43733 .46836 .44059 .47355 .44626 .47314 .44298 .46874 Metetra
.538 .639 .898 r
.44298 .46874 .44626 .47314 .45197 .47196 .44867 .46864 Metetra
.587 .724 .939 r
.44867 .46864 .45197 .47196 .4577 .46986 .45439 .46775 Metetra
.651 .83 .969 r
.45439 .46775 .4577 .46986 .46347 .46686 .46015 .46586 Metetra
.709 .921 .965 r
.46015 .46586 .46347 .46686 .46926 .46314 .46593 .46296 Metetra
.746 .971 .929 r
.46593 .46296 .46926 .46314 .47506 .45893 .47174 .4592 Metetra
.768 .988 .896 r
.47174 .4592 .47506 .45893 .48087 .45454 .47757 .45486 Metetra
.786 .99 .887 r
.47757 .45486 .48087 .45454 .48667 .45022 .4834 .45024 Metetra
.799 .981 .899 r
.4834 .45024 .48667 .45022 .49248 .44616 .48923 .44566 Metetra
.799 .958 .916 r
.48923 .44566 .49248 .44616 .4983 .44248 .49506 .44135 Metetra
.785 .92 .928 r
.49506 .44135 .4983 .44248 .50411 .43921 .50089 .43745 Metetra
.762 .876 .93 r
.50089 .43745 .50411 .43921 .50993 .43632 .50673 .434 Metetra
.735 .835 .926 r
.50673 .434 .50993 .43632 .51576 .43374 .51257 .43098 Metetra
.712 .801 .92 r
.51257 .43098 .51576 .43374 .5216 .4314 .51842 .42832 Metetra
.695 .777 .915 r
.51842 .42832 .5216 .4314 .52745 .42922 .52428 .42593 Metetra
.682 .761 .911 r
.52428 .42593 .52745 .42922 .53331 .42714 .53015 .42372 Metetra
.675 .751 .908 r
.53015 .42372 .53331 .42714 .53918 .42513 .53603 .42163 Metetra
.67 .746 .907 r
.53603 .42163 .53918 .42513 .54507 .42315 .54192 .41961 Metetra
.667 .743 .907 r
.54192 .41961 .54507 .42315 .55096 .4212 .54783 .41763 Metetra
.666 .741 .906 r
.54783 .41763 .55096 .4212 .55687 .41925 .55374 .41566 Metetra
.665 .74 .906 r
.55374 .41566 .55687 .41925 .5628 .41731 .55968 .41371 Metetra
.664 .74 .906 r
.55968 .41371 .5628 .41731 .56873 .41537 .56562 .41176 Metetra
.664 .739 .906 r
.56562 .41176 .56873 .41537 .57468 .41343 .57158 .40981 Metetra
.663 .739 .906 r
.57158 .40981 .57468 .41343 .58064 .4115 .57755 .40787 Metetra
.663 .739 .906 r
.57755 .40787 .58064 .4115 .58662 .40956 .58353 .40593 Metetra
.662 .739 .907 r
.58353 .40593 .58662 .40956 .59261 .40763 .58953 .40399 Metetra
.662 .739 .907 r
.58953 .40399 .59261 .40763 .59861 .4057 .59554 .40206 Metetra
.661 .739 .908 r
.59554 .40206 .59861 .4057 .60462 .40378 .60156 .40014 Metetra
.66 .739 .909 r
.60156 .40014 .60462 .40378 .61065 .40186 .6076 .39824 Metetra
.658 .74 .91 r
.6076 .39824 .61065 .40186 .61669 .39996 .61365 .39635 Metetra
.657 .74 .911 r
.61365 .39635 .61669 .39996 .62274 .39807 .61971 .39448 Metetra
.654 .741 .914 r
.61971 .39448 .62274 .39807 .62881 .39621 .62579 .39265 Metetra
.651 .742 .917 r
.62579 .39265 .62881 .39621 .6349 .39437 .63188 .39085 Metetra
.646 .744 .92 r
.63188 .39085 .6349 .39437 .641 .39258 .638 .38912 Metetra
.641 .746 .925 r
.638 .38912 .641 .39258 .64711 .39084 .64412 .38746 Metetra
.633 .749 .931 r
.64412 .38746 .64711 .39084 .65325 .38917 .65027 .38589 Metetra
.623 .752 .939 r
.65027 .38589 .65325 .38917 .6594 .38758 .65644 .38442 Metetra
.611 .756 .948 r
.65644 .38442 .6594 .38758 .66557 .3861 .66262 .38308 Metetra
.596 .761 .958 r
.66262 .38308 .66557 .3861 .67176 .38472 .66883 .38187 Metetra
.578 .766 .968 r
.66883 .38187 .67176 .38472 .67797 .38348 .67506 .3808 Metetra
.558 .772 .978 r
.67506 .3808 .67797 .38348 .68421 .38235 .68132 .37985 Metetra
.539 .777 .986 r
.68132 .37985 .68421 .38235 .69047 .38133 .6876 .37899 Metetra
.524 .784 .992 r
.6876 .37899 .69047 .38133 .69675 .3804 .6939 .37817 Metetra
.52 .791 .995 r
.6939 .37817 .69675 .3804 .70305 .3795 .70021 .37731 Metetra
.53 .8 .995 r
.70021 .37731 .70305 .3795 .70937 .37857 .70654 .37634 Metetra
.555 .808 .992 r
.70654 .37634 .70937 .37857 .7157 .37754 .71288 .37517 Metetra
.591 .812 .984 r
.71288 .37517 .7157 .37754 .72204 .37633 .71921 .37373 Metetra
.628 .809 .969 r
.71921 .37373 .72204 .37633 .72838 .37487 .72555 .37198 Metetra
.66 .799 .949 r
.72555 .37198 .72838 .37487 .73471 .37313 .73187 .3699 Metetra
.682 .784 .927 r
.73187 .3699 .73471 .37313 .74105 .37109 .73819 .36752 Metetra
.695 .768 .908 r
.73819 .36752 .74105 .37109 .74738 .36877 .74451 .36493 Metetra
.7 .753 .893 r
.74451 .36493 .74738 .36877 .7537 .36624 .75084 .3622 Metetra
.7 .743 .885 r
.75084 .3622 .7537 .36624 .76003 .36359 .75717 .35945 Metetra
.696 .737 .883 r
.75717 .35945 .76003 .36359 .76637 .36089 .76352 .35676 Metetra
.689 .736 .886 r
.76352 .35676 .76637 .36089 .77272 .35823 .76989 .3542 Metetra
.681 .738 .894 r
.76989 .3542 .77272 .35823 .7791 .35568 .77629 .35179 Metetra
.674 .744 .903 r
.77629 .35179 .7791 .35568 .78549 .35326 .78271 .34952 Metetra
.667 .75 .913 r
.78271 .34952 .78549 .35326 .79192 .35098 .78915 .34736 Metetra
.663 .757 .92 r
.78915 .34736 .79192 .35098 .79836 .3488 .79561 .34525 Metetra
.662 .762 .924 r
.79561 .34525 .79836 .3488 .80483 .34668 .80209 .34315 Metetra
.664 .764 .924 r
.80209 .34315 .80483 .34668 .81131 .34459 .80858 .34102 Metetra
.668 .763 .922 r
.80858 .34102 .81131 .34459 .8178 .34247 .81508 .33883 Metetra
.671 .761 .918 r
.81508 .33883 .8178 .34247 .82431 .3403 .82159 .33657 Metetra
.674 .757 .913 r
.82159 .33657 .82431 .3403 .83082 .33808 .82811 .33427 Metetra
.675 .753 .909 r
.82811 .33427 .83082 .33808 .83735 .33581 .83464 .33194 Metetra
.676 .75 .907 r
.83464 .33194 .83735 .33581 .84388 .3335 .84119 .32959 Metetra
.675 .748 .906 r
.84119 .32959 .84388 .3335 .85043 .33118 .84774 .32725 Metetra
.674 .747 .906 r
.84774 .32725 .85043 .33118 .857 .32886 .85432 .32493 Metetra
.672 .747 .907 r
.85432 .32493 .857 .32886 .86358 .32655 .86091 .32263 Metetra
.671 .747 .908 r
.86091 .32263 .86358 .32655 .87017 .32425 .86752 .32034 Metetra
.67 .748 .909 r
.86752 .32034 .87017 .32425 .87678 .32197 .87414 .31806 Metetra
.67 .749 .909 r
.87414 .31806 .87678 .32197 .88341 .3197 .88078 .31578 Metetra
.67 .749 .91 r
.88078 .31578 .88341 .3197 .89005 .31743 .88744 .3135 Metetra
.657 .739 .911 r
.29015 .50208 .29364 .50533 .29902 .50369 .29554 .50041 Metetra
.656 .738 .91 r
.29554 .50041 .29902 .50369 .30442 .50205 .30095 .49876 Metetra
.655 .737 .91 r
.30095 .49876 .30442 .50205 .30983 .50042 .30636 .49711 Metetra
.654 .736 .91 r
.30636 .49711 .30983 .50042 .31525 .49879 .31179 .49547 Metetra
.653 .736 .91 r
.31179 .49547 .31525 .49879 .32068 .49715 .31723 .49384 Metetra
.653 .737 .911 r
.31723 .49384 .32068 .49715 .32613 .49549 .32268 .4922 Metetra
.654 .739 .912 r
.32268 .4922 .32613 .49549 .33159 .49381 .32814 .49055 Metetra
.656 .741 .913 r
.32814 .49055 .33159 .49381 .33706 .49211 .33362 .48887 Metetra
.657 .743 .914 r
.33362 .48887 .33706 .49211 .34254 .49042 .3391 .48717 Metetra
.658 .744 .914 r
.3391 .48717 .34254 .49042 .34803 .48875 .3446 .48546 Metetra
.656 .741 .912 r
.3446 .48546 .34803 .48875 .35353 .48713 .35011 .48376 Metetra
.653 .735 .91 r
.35011 .48376 .35353 .48713 .35904 .4856 .35563 .48211 Metetra
.647 .727 .907 r
.35563 .48211 .35904 .4856 .36455 .48415 .36116 .48055 Metetra
.64 .719 .905 r
.36116 .48055 .36455 .48415 .37008 .48275 .3667 .47908 Metetra
.635 .714 .904 r
.3667 .47908 .37008 .48275 .37562 .48133 .37224 .47769 Metetra
.633 .715 .906 r
.37224 .47769 .37562 .48133 .38117 .47981 .3778 .47631 Metetra
.638 .725 .911 r
.3778 .47631 .38117 .47981 .38675 .47812 .38337 .47485 Metetra
.649 .743 .919 r
.38337 .47485 .38675 .47812 .39234 .47624 .38896 .47323 Metetra
.663 .765 .925 r
.38896 .47323 .39234 .47624 .39796 .47421 .39457 .4714 Metetra
.676 .781 .929 r
.39457 .4714 .39796 .47421 .40358 .47218 .4002 .46937 Metetra
.681 .783 .928 r
.4002 .46937 .40358 .47218 .40921 .47032 .40585 .46727 Metetra
.672 .765 .92 r
.40585 .46727 .40921 .47032 .41483 .46887 .4115 .4653 Metetra
.647 .727 .907 r
.4115 .4653 .41483 .46887 .42046 .46797 .41715 .4637 Metetra
.609 .675 .887 r
.41715 .4637 .42046 .46797 .42607 .46768 .4228 .46266 Metetra
.567 .622 .867 r
.4228 .46266 .42607 .46768 .4317 .46789 .42844 .46231 Metetra
.529 .58 .851 r
.42844 .46231 .4317 .46789 .43733 .46836 .43408 .46257 Metetra
.504 .56 .846 r
.43408 .46257 .43733 .46836 .44298 .46874 .43973 .46321 Metetra
.499 .568 .857 r
.43973 .46321 .44298 .46874 .44867 .46864 .4454 .46386 Metetra
.518 .611 .885 r
.4454 .46386 .44867 .46864 .45439 .46775 .4511 .46407 Metetra
.566 .695 .928 r
.4511 .46407 .45439 .46775 .46015 .46586 .45683 .46348 Metetra
.636 .807 .965 r
.45683 .46348 .46015 .46586 .46593 .46296 .46261 .4618 Metetra
.705 .911 .967 r
.46261 .4618 .46593 .46296 .47174 .4592 .46841 .459 Metetra
.75 .97 .929 r
.46841 .459 .47174 .4592 .47757 .45486 .47424 .4552 Metetra
.775 .99 .889 r
.47424 .4552 .47757 .45486 .4834 .45024 .48009 .45069 Metetra
.795 .993 .875 r
.48009 .45069 .4834 .45024 .48923 .44566 .48594 .44583 Metetra
.809 .986 .886 r
.48594 .44583 .48923 .44566 .49506 .44135 .4918 .44098 Metetra
.81 .964 .907 r
.4918 .44098 .49506 .44135 .50089 .43745 .49765 .43641 Metetra
.795 .927 .922 r
.49765 .43641 .50089 .43745 .50673 .434 .50351 .4323 Metetra
.769 .883 .928 r
.50351 .4323 .50673 .434 .51257 .43098 .50936 .42871 Metetra
.74 .84 .926 r
.50936 .42871 .51257 .43098 .51842 .42832 .51522 .42559 Metetra
.715 .806 .921 r
.51522 .42559 .51842 .42832 .52428 .42593 .52109 .42288 Metetra
.696 .78 .916 r
.52109 .42288 .52428 .42593 .53015 .42372 .52697 .42046 Metetra
.683 .764 .913 r
.52697 .42046 .53015 .42372 .53603 .42163 .53286 .41824 Metetra
.675 .754 .911 r
.53286 .41824 .53603 .42163 .54192 .41961 .53876 .41614 Metetra
.67 .748 .909 r
.53876 .41614 .54192 .41961 .54783 .41763 .54468 .41411 Metetra
.667 .745 .909 r
.54468 .41411 .54783 .41763 .55374 .41566 .5506 .41211 Metetra
.666 .743 .908 r
.5506 .41211 .55374 .41566 .55968 .41371 .55654 .41014 Metetra
.665 .742 .908 r
.55654 .41014 .55968 .41371 .56562 .41176 .5625 .40818 Metetra
.664 .742 .908 r
.5625 .40818 .56562 .41176 .57158 .40981 .56846 .40622 Metetra
.663 .742 .908 r
.56846 .40622 .57158 .40981 .57755 .40787 .57444 .40428 Metetra
.663 .742 .909 r
.57444 .40428 .57755 .40787 .58353 .40593 .58043 .40233 Metetra
.662 .742 .909 r
.58043 .40233 .58353 .40593 .58953 .40399 .58644 .4004 Metetra
.661 .742 .91 r
.58644 .4004 .58953 .40399 .59554 .40206 .59245 .39847 Metetra
.66 .742 .911 r
.59245 .39847 .59554 .40206 .60156 .40014 .59849 .39656 Metetra
.658 .743 .912 r
.59849 .39656 .60156 .40014 .6076 .39824 .60453 .39466 Metetra
.656 .743 .914 r
.60453 .39466 .6076 .39824 .61365 .39635 .61059 .39279 Metetra
.654 .744 .916 r
.61059 .39279 .61365 .39635 .61971 .39448 .61667 .39096 Metetra
.651 .745 .919 r
.61667 .39096 .61971 .39448 .62579 .39265 .62276 .38916 Metetra
.646 .746 .922 r
.62276 .38916 .62579 .39265 .63188 .39085 .62886 .38742 Metetra
.64 .748 .927 r
.62886 .38742 .63188 .39085 .638 .38912 .63499 .38576 Metetra
.632 .75 .933 r
.63499 .38576 .638 .38912 .64412 .38746 .64113 .3842 Metetra
.622 .753 .941 r
.64113 .3842 .64412 .38746 .65027 .38589 .64729 .38275 Metetra
.608 .757 .95 r
.64729 .38275 .65027 .38589 .65644 .38442 .65347 .38143 Metetra
.591 .761 .96 r
.65347 .38143 .65644 .38442 .66262 .38308 .65967 .38025 Metetra
.571 .766 .97 r
.65967 .38025 .66262 .38308 .66883 .38187 .6659 .37923 Metetra
.549 .771 .98 r
.6659 .37923 .66883 .38187 .67506 .3808 .67215 .37834 Metetra
.527 .776 .989 r
.67215 .37834 .67506 .3808 .68132 .37985 .67843 .37756 Metetra
.509 .782 .994 r
.67843 .37756 .68132 .37985 .6876 .37899 .68472 .37682 Metetra
.504 .789 .997 r
.68472 .37682 .6876 .37899 .6939 .37817 .69104 .37605 Metetra
.515 .799 .997 r
.69104 .37605 .6939 .37817 .70021 .37731 .69736 .37515 Metetra
.544 .809 .995 r
.69736 .37515 .70021 .37731 .70654 .37634 .7037 .37403 Metetra
.585 .814 .987 r
.7037 .37403 .70654 .37634 .71288 .37517 .71003 .37262 Metetra
.628 .812 .971 r
.71003 .37262 .71288 .37517 .71921 .37373 .71636 .37086 Metetra
.662 .801 .949 r
.71636 .37086 .71921 .37373 .72555 .37198 .72268 .36874 Metetra
.686 .785 .926 r
.72268 .36874 .72555 .37198 .73187 .3699 .729 .3663 Metetra
.699 .767 .905 r
.729 .3663 .73187 .3699 .73819 .36752 .73531 .36364 Metetra
.703 .752 .89 r
.73531 .36364 .73819 .36752 .74451 .36493 .74163 .36085 Metetra
.702 .742 .882 r
.74163 .36085 .74451 .36493 .75084 .3622 .74796 .35805 Metetra
.697 .736 .881 r
.74796 .35805 .75084 .3622 .75717 .35945 .7543 .35533 Metetra
.689 .736 .886 r
.7543 .35533 .75717 .35945 .76352 .35676 .76067 .35276 Metetra
.681 .74 .895 r
.76067 .35276 .76352 .35676 .76989 .3542 .76706 .35036 Metetra
.672 .746 .906 r
.76706 .35036 .76989 .3542 .77629 .35179 .77348 .34811 Metetra
.666 .754 .916 r
.77348 .34811 .77629 .35179 .78271 .34952 .77993 .34596 Metetra
.662 .761 .923 r
.77993 .34596 .78271 .34952 .78915 .34736 .78639 .34386 Metetra
.662 .765 .926 r
.78639 .34386 .78915 .34736 .79561 .34525 .79286 .34175 Metetra
.665 .766 .925 r
.79286 .34175 .79561 .34525 .80209 .34315 .79935 .33959 Metetra
.669 .765 .922 r
.79935 .33959 .80209 .34315 .80858 .34102 .80584 .33737 Metetra
.673 .761 .917 r
.80584 .33737 .80858 .34102 .81508 .33883 .81234 .33508 Metetra
.676 .757 .912 r
.81234 .33508 .81508 .33883 .82159 .33657 .81886 .33274 Metetra
.677 .753 .908 r
.81886 .33274 .82159 .33657 .82811 .33427 .82538 .33038 Metetra
.677 .75 .906 r
.82538 .33038 .82811 .33427 .83464 .33194 .83192 .32801 Metetra
.676 .748 .905 r
.83192 .32801 .83464 .33194 .84119 .32959 .83848 .32566 Metetra
.674 .747 .906 r
.83848 .32566 .84119 .32959 .84774 .32725 .84505 .32333 Metetra
.673 .748 .907 r
.84505 .32333 .84774 .32725 .85432 .32493 .85163 .32101 Metetra
.671 .748 .908 r
.85163 .32101 .85432 .32493 .86091 .32263 .85824 .31872 Metetra
.671 .749 .909 r
.85824 .31872 .86091 .32263 .86752 .32034 .86486 .31643 Metetra
.67 .749 .91 r
.86486 .31643 .86752 .32034 .87414 .31806 .87149 .31414 Metetra
.67 .749 .91 r
.87149 .31414 .87414 .31806 .88078 .31578 .87814 .31184 Metetra
.671 .749 .909 r
.87814 .31184 .88078 .31578 .88744 .3135 .88481 .30954 Metetra
.657 .74 .911 r
.28664 .49882 .29015 .50208 .29554 .50041 .29205 .49714 Metetra
.657 .739 .911 r
.29205 .49714 .29554 .50041 .30095 .49876 .29746 .49547 Metetra
.656 .739 .911 r
.29746 .49547 .30095 .49876 .30636 .49711 .30288 .4938 Metetra
.655 .737 .91 r
.30288 .4938 .30636 .49711 .31179 .49547 .30832 .49214 Metetra
.654 .736 .91 r
.30832 .49214 .31179 .49547 .31723 .49384 .31376 .49049 Metetra
.653 .736 .91 r
.31376 .49049 .31723 .49384 .32268 .4922 .31922 .48886 Metetra
.652 .736 .911 r
.31922 .48886 .32268 .4922 .32814 .49055 .32469 .48722 Metetra
.653 .738 .912 r
.32469 .48722 .32814 .49055 .33362 .48887 .33016 .48558 Metetra
.654 .74 .913 r
.33016 .48558 .33362 .48887 .3391 .48717 .33566 .48391 Metetra
.656 .743 .914 r
.33566 .48391 .3391 .48717 .3446 .48546 .34116 .48221 Metetra
.658 .745 .914 r
.34116 .48221 .3446 .48546 .35011 .48376 .34668 .48049 Metetra
.657 .744 .914 r
.34668 .48049 .35011 .48376 .35563 .48211 .35221 .47876 Metetra
.654 .739 .911 r
.35221 .47876 .35563 .48211 .36116 .48055 .35775 .47708 Metetra
.649 .73 .908 r
.35775 .47708 .36116 .48055 .3667 .47908 .3633 .47547 Metetra
.641 .72 .905 r
.3633 .47547 .3667 .47908 .37224 .47769 .36885 .47397 Metetra
.634 .712 .903 r
.36885 .47397 .37224 .47769 .3778 .47631 .37442 .47257 Metetra
.63 .71 .904 r
.37442 .47257 .3778 .47631 .38337 .47485 .37999 .47123 Metetra
.633 .718 .908 r
.37999 .47123 .38337 .47485 .38896 .47323 .38558 .46984 Metetra
.642 .735 .916 r
.38558 .46984 .38896 .47323 .39457 .4714 .39119 .46831 Metetra
.657 .759 .925 r
.39119 .46831 .39457 .4714 .4002 .46937 .39682 .46655 Metetra
.673 .781 .931 r
.39682 .46655 .4002 .46937 .40585 .46727 .40246 .46456 Metetra
.682 .79 .931 r
.40246 .46456 .40585 .46727 .4115 .4653 .40813 .46242 Metetra
.679 .779 .926 r
.40813 .46242 .4115 .4653 .41715 .4637 .41381 .46033 Metetra
.658 .743 .913 r
.41381 .46033 .41715 .4637 .4228 .46266 .41948 .45855 Metetra
.621 .688 .892 r
.41948 .45855 .4228 .46266 .42844 .46231 .42515 .45733 Metetra
.575 .628 .867 r
.42515 .45733 .42844 .46231 .43408 .46257 .43082 .45685 Metetra
.531 .577 .846 r
.43082 .45685 .43408 .46257 .43973 .46321 .43648 .45709 Metetra
.499 .546 .835 r
.43648 .45709 .43973 .46321 .4454 .46386 .44214 .45786 Metetra
.486 .544 .841 r
.44214 .45786 .4454 .46386 .4511 .46407 .44783 .45878 Metetra
.497 .578 .867 r
.44783 .45878 .4511 .46407 .45683 .46348 .45354 .45937 Metetra
.537 .658 .914 r
.45354 .45937 .45683 .46348 .46261 .4618 .45929 .45918 Metetra
.606 .782 .965 r
.45929 .45918 .46261 .4618 .46841 .459 .46508 .45788 Metetra
.677 .91 .975 r
.46508 .45788 .46841 .459 .47424 .4552 .47091 .45533 Metetra
.712 .977 .916 r
.47091 .45533 .47424 .4552 .48009 .45069 .47676 .45163 Metetra
.721 .989 .841 r
.47676 .45163 .48009 .45069 .48594 .44583 .48262 .44707 Metetra
.736 .989 .808 r
.48262 .44707 .48594 .44583 .4918 .44098 .4885 .44204 Metetra
.762 .996 .825 r
.4885 .44204 .4918 .44098 .49765 .43641 .49438 .43692 Metetra
.786 .995 .869 r
.49438 .43692 .49765 .43641 .50351 .4323 .50026 .43206 Metetra
.793 .973 .911 r
.50026 .43206 .50351 .4323 .50936 .42871 .50613 .42766 Metetra
.778 .929 .933 r
.50613 .42766 .50936 .42871 .51522 .42559 .51201 .42382 Metetra
.751 .878 .938 r
.51201 .42382 .51522 .42559 .52109 .42288 .51789 .42051 Metetra
.723 .833 .933 r
.51789 .42051 .52109 .42288 .52697 .42046 .52378 .41766 Metetra
.701 .8 .927 r
.52378 .41766 .52697 .42046 .53286 .41824 .52968 .41516 Metetra
.685 .778 .921 r
.52968 .41516 .53286 .41824 .53876 .41614 .53559 .41289 Metetra
.675 .765 .918 r
.53559 .41289 .53876 .41614 .54468 .41411 .54151 .41077 Metetra
.67 .758 .917 r
.54151 .41077 .54468 .41411 .5506 .41211 .54745 .40873 Metetra
.666 .755 .916 r
.54745 .40873 .5506 .41211 .55654 .41014 .5534 .40674 Metetra
.665 .753 .916 r
.5534 .40674 .55654 .41014 .5625 .40818 .55936 .40476 Metetra
.664 .753 .916 r
.55936 .40476 .5625 .40818 .56846 .40622 .56533 .4028 Metetra
.663 .752 .917 r
.56533 .4028 .56846 .40622 .57444 .40428 .57132 .40084 Metetra
.662 .752 .917 r
.57132 .40084 .57444 .40428 .58043 .40233 .57732 .3989 Metetra
.661 .752 .917 r
.57732 .3989 .58043 .40233 .58644 .4004 .58334 .39696 Metetra
.66 .752 .918 r
.58334 .39696 .58644 .4004 .59245 .39847 .58936 .39504 Metetra
.658 .752 .919 r
.58936 .39504 .59245 .39847 .59849 .39656 .59541 .39313 Metetra
.656 .753 .921 r
.59541 .39313 .59849 .39656 .60453 .39466 .60146 .39126 Metetra
.654 .753 .923 r
.60146 .39126 .60453 .39466 .61059 .39279 .60753 .38941 Metetra
.65 .754 .926 r
.60753 .38941 .61059 .39279 .61667 .39096 .61362 .38761 Metetra
.645 .755 .929 r
.61362 .38761 .61667 .39096 .62276 .38916 .61972 .38588 Metetra
.638 .757 .934 r
.61972 .38588 .62276 .38916 .62886 .38742 .62584 .38422 Metetra
.629 .76 .941 r
.62584 .38422 .62886 .38742 .63499 .38576 .63197 .38266 Metetra
.617 .763 .949 r
.63197 .38266 .63499 .38576 .64113 .3842 .63813 .38123 Metetra
.602 .767 .959 r
.63813 .38123 .64113 .3842 .64729 .38275 .6443 .37994 Metetra
.582 .771 .969 r
.6443 .37994 .64729 .38275 .65347 .38143 .6505 .3788 Metetra
.557 .776 .98 r
.6505 .3788 .65347 .38143 .65967 .38025 .65673 .37783 Metetra
.528 .78 .989 r
.65673 .37783 .65967 .38025 .6659 .37923 .66298 .37701 Metetra
.5 .783 .996 r
.66298 .37701 .6659 .37923 .67215 .37834 .66925 .3763 Metetra
.477 .787 .999 r
.66925 .3763 .67215 .37834 .67843 .37756 .67554 .37565 Metetra
.47 .794 .999 r
.67554 .37565 .67843 .37756 .68472 .37682 .68185 .37495 Metetra
.485 .805 1 r
.68185 .37495 .68472 .37682 .69104 .37605 .68817 .37412 Metetra
.522 .818 .999 r
.68817 .37412 .69104 .37605 .69736 .37515 .6945 .37304 Metetra
.574 .826 .993 r
.6945 .37304 .69736 .37515 .7037 .37403 .70083 .37163 Metetra
.626 .823 .976 r
.70083 .37163 .7037 .37403 .71003 .37262 .70716 .36983 Metetra
.666 .809 .952 r
.70716 .36983 .71003 .37262 .71636 .37086 .71347 .36765 Metetra
.691 .789 .925 r
.71347 .36765 .71636 .37086 .72268 .36874 .71978 .36513 Metetra
.703 .769 .903 r
.71978 .36513 .72268 .36874 .729 .3663 .72609 .36238 Metetra
.707 .752 .887 r
.72609 .36238 .729 .3663 .73531 .36364 .7324 .35951 Metetra
.704 .741 .88 r
.7324 .35951 .73531 .36364 .74163 .36085 .73872 .35666 Metetra
.698 .735 .88 r
.73872 .35666 .74163 .36085 .74796 .35805 .74507 .35392 Metetra
.689 .736 .887 r
.74507 .35392 .74796 .35805 .7543 .35533 .75143 .35135 Metetra
.68 .741 .897 r
.75143 .35135 .7543 .35533 .76067 .35276 .75783 .34897 Metetra
.671 .749 .909 r
.75783 .34897 .76067 .35276 .76706 .35036 .76424 .34674 Metetra
.664 .758 .919 r
.76424 .34674 .76706 .35036 .77348 .34811 .77068 .34461 Metetra
.662 .765 .926 r
.77068 .34461 .77348 .34811 .77993 .34596 .77714 .34251 Metetra
.663 .769 .928 r
.77714 .34251 .77993 .34596 .78639 .34386 .78361 .34038 Metetra
.667 .769 .926 r
.78361 .34038 .78639 .34386 .79286 .34175 .79009 .33819 Metetra
.672 .766 .922 r
.79009 .33819 .79286 .34175 .79935 .33959 .79658 .33593 Metetra
.676 .762 .916 r
.79658 .33593 .79935 .33959 .80584 .33737 .80308 .3336 Metetra
.678 .757 .911 r
.80308 .3336 .80584 .33737 .81234 .33508 .80958 .33122 Metetra
.678 .752 .907 r
.80958 .33122 .81234 .33508 .81886 .33274 .8161 .32883 Metetra
.678 .749 .905 r
.8161 .32883 .81886 .33274 .82538 .33038 .82264 .32644 Metetra
.676 .748 .905 r
.82264 .32644 .82538 .33038 .83192 .32801 .82919 .32407 Metetra
.674 .748 .906 r
.82919 .32407 .83192 .32801 .83848 .32566 .83576 .32173 Metetra
.673 .748 .907 r
.83576 .32173 .83848 .32566 .84505 .32333 .84234 .31941 Metetra
.672 .749 .909 r
.84234 .31941 .84505 .32333 .85163 .32101 .84894 .31711 Metetra
.671 .75 .91 r
.84894 .31711 .85163 .32101 .85824 .31872 .85556 .31481 Metetra
.671 .75 .91 r
.85556 .31481 .85824 .31872 .86486 .31643 .86219 .31251 Metetra
.671 .75 .91 r
.86219 .31251 .86486 .31643 .87149 .31414 .86883 .3102 Metetra
.671 .749 .909 r
.86883 .3102 .87149 .31414 .87814 .31184 .87549 .30788 Metetra
.671 .749 .909 r
.87549 .30788 .87814 .31184 .88481 .30954 .88217 .30556 Metetra
.657 .74 .911 r
.28313 .49555 .28664 .49882 .29205 .49714 .28854 .49387 Metetra
.657 .74 .911 r
.28854 .49387 .29205 .49714 .29746 .49547 .29396 .49218 Metetra
.656 .74 .911 r
.29396 .49218 .29746 .49547 .30288 .4938 .29939 .4905 Metetra
.656 .739 .911 r
.29939 .4905 .30288 .4938 .30832 .49214 .30483 .48882 Metetra
.655 .738 .911 r
.30483 .48882 .30832 .49214 .31376 .49049 .31028 .48715 Metetra
.654 .736 .91 r
.31028 .48715 .31376 .49049 .31922 .48886 .31574 .48549 Metetra
.653 .735 .91 r
.31574 .48549 .31922 .48886 .32469 .48722 .32122 .48385 Metetra
.652 .735 .91 r
.32122 .48385 .32469 .48722 .33016 .48558 .3267 .48221 Metetra
.652 .736 .911 r
.3267 .48221 .33016 .48558 .33566 .48391 .3322 .48058 Metetra
.653 .739 .912 r
.3322 .48058 .33566 .48391 .34116 .48221 .33771 .47892 Metetra
.655 .742 .914 r
.33771 .47892 .34116 .48221 .34668 .48049 .34323 .47722 Metetra
.657 .745 .915 r
.34323 .47722 .34668 .48049 .35221 .47876 .34877 .4755 Metetra
.658 .745 .915 r
.34877 .4755 .35221 .47876 .35775 .47708 .35432 .47375 Metetra
.656 .742 .913 r
.35432 .47375 .35775 .47708 .3633 .47547 .35988 .47203 Metetra
.651 .734 .91 r
.35988 .47203 .3633 .47547 .36885 .47397 .36545 .47038 Metetra
.644 .723 .906 r
.36545 .47038 .36885 .47397 .37442 .47257 .37103 .46884 Metetra
.635 .712 .903 r
.37103 .46884 .37442 .47257 .37999 .47123 .37661 .46742 Metetra
.628 .707 .902 r
.37661 .46742 .37999 .47123 .38558 .46984 .3822 .4661 Metetra
.628 .71 .906 r
.3822 .4661 .38558 .46984 .39119 .46831 .3878 .46478 Metetra
.635 .725 .913 r
.3878 .46478 .39119 .46831 .39682 .46655 .39343 .46334 Metetra
.649 .75 .923 r
.39343 .46334 .39682 .46655 .40246 .46456 .39907 .46168 Metetra
.668 .777 .931 r
.39907 .46168 .40246 .46456 .40813 .46242 .40474 .45974 Metetra
.683 .794 .934 r
.40474 .45974 .40813 .46242 .41381 .46033 .41042 .45758 Metetra
.686 .791 .929 r
.41042 .45758 .41381 .46033 .41948 .45855 .41612 .45537 Metetra
.67 .76 .918 r
.41612 .45537 .41948 .45855 .42515 .45733 .42182 .4534 Metetra
.634 .704 .897 r
.42182 .4534 .42515 .45733 .43082 .45685 .42752 .45198 Metetra
.584 .638 .871 r
.42752 .45198 .43082 .45685 .43648 .45709 .43321 .45135 Metetra
.532 .578 .846 r
.43321 .45135 .43648 .45709 .44214 .45786 .43889 .45157 Metetra
.49 .536 .831 r
.43889 .45157 .44214 .45786 .44783 .45878 .44458 .45249 Metetra
.466 .523 .833 r
.44458 .45249 .44783 .45878 .45354 .45937 .45028 .45373 Metetra
.466 .549 .857 r
.45028 .45373 .45354 .45937 .45929 .45918 .456 .45478 Metetra
.498 .625 .906 r
.456 .45478 .45929 .45918 .46508 .45788 .46177 .45508 Metetra
.569 .757 .967 r
.46177 .45508 .46508 .45788 .47091 .45533 .46757 .45417 Metetra
.652 .903 .982 r
.46757 .45417 .47091 .45533 .47676 .45163 .47341 .45185 Metetra
.702 .978 .91 r
.47341 .45185 .47676 .45163 .48262 .44707 .47929 .44816 Metetra
.727 .989 .826 r
.47929 .44816 .48262 .44707 .4885 .44204 .48518 .44338 Metetra
.76 .993 .797 r
.48518 .44338 .4885 .44204 .49438 .43692 .49108 .43796 Metetra
.801 1 .822 r
.49108 .43796 .49438 .43692 .50026 .43206 .49698 .43238 Metetra
.827 .99 .867 r
.49698 .43238 .50026 .43206 .50613 .42766 .50288 .42706 Metetra
.824 .953 .901 r
.50288 .42706 .50613 .42766 .51201 .42382 .50878 .42228 Metetra
.796 .897 .915 r
.50878 .42228 .51201 .42382 .51789 .42051 .51468 .41817 Metetra
.758 .841 .914 r
.51468 .41817 .51789 .42051 .52378 .41766 .52058 .41471 Metetra
.724 .796 .908 r
.52058 .41471 .52378 .41766 .52968 .41516 .52649 .41179 Metetra
.699 .765 .903 r
.52649 .41179 .52968 .41516 .53559 .41289 .53241 .40928 Metetra
.682 .746 .899 r
.53241 .40928 .53559 .41289 .54151 .41077 .53834 .40702 Metetra
.673 .736 .897 r
.53834 .40702 .54151 .41077 .54745 .40873 .54428 .40492 Metetra
.668 .731 .897 r
.54428 .40492 .54745 .40873 .5534 .40674 .55024 .40289 Metetra
.665 .728 .897 r
.55024 .40289 .5534 .40674 .55936 .40476 .55621 .4009 Metetra
.664 .727 .897 r
.55621 .4009 .55936 .40476 .56533 .4028 .56219 .39892 Metetra
.663 .727 .897 r
.56219 .39892 .56533 .4028 .57132 .40084 .56819 .39696 Metetra
.662 .726 .897 r
.56819 .39696 .57132 .40084 .57732 .3989 .57419 .39502 Metetra
.66 .726 .898 r
.57419 .39502 .57732 .3989 .58334 .39696 .58022 .39309 Metetra
.659 .727 .899 r
.58022 .39309 .58334 .39696 .58936 .39504 .58625 .39118 Metetra
.657 .727 .901 r
.58625 .39118 .58936 .39504 .59541 .39313 .5923 .3893 Metetra
.654 .728 .903 r
.5923 .3893 .59541 .39313 .60146 .39126 .59837 .38745 Metetra
.651 .729 .907 r
.59837 .38745 .60146 .39126 .60753 .38941 .60445 .38566 Metetra
.646 .731 .911 r
.60445 .38566 .60753 .38941 .61362 .38761 .61054 .38393 Metetra
.64 .733 .916 r
.61054 .38393 .61362 .38761 .61972 .38588 .61666 .38228 Metetra
.631 .736 .923 r
.61666 .38228 .61972 .38588 .62584 .38422 .62279 .38075 Metetra
.62 .74 .932 r
.62279 .38075 .62584 .38422 .63197 .38266 .62894 .37934 Metetra
.604 .744 .943 r
.62894 .37934 .63197 .38266 .63813 .38123 .63511 .3781 Metetra
.584 .75 .956 r
.63511 .3781 .63813 .38123 .6443 .37994 .64131 .37703 Metetra
.559 .756 .97 r
.64131 .37703 .6443 .37994 .6505 .3788 .64752 .37615 Metetra
.528 .762 .983 r
.64752 .37615 .6505 .3788 .65673 .37783 .65377 .37544 Metetra
.495 .768 .992 r
.65377 .37544 .65673 .37783 .66298 .37701 .66004 .37486 Metetra
.467 .774 .997 r
.66004 .37486 .66298 .37701 .66925 .3763 .66633 .37434 Metetra
.454 .783 .998 r
.66633 .37434 .66925 .3763 .67554 .37565 .67264 .37378 Metetra
.466 .797 .999 r
.67264 .37378 .67554 .37565 .68185 .37495 .67896 .37307 Metetra
.506 .814 1 r
.67896 .37307 .68185 .37495 .68817 .37412 .68529 .37207 Metetra
.565 .828 .995 r
.68529 .37207 .68817 .37412 .6945 .37304 .69162 .3707 Metetra
.624 .828 .979 r
.69162 .3707 .6945 .37304 .70083 .37163 .69794 .36889 Metetra
.669 .814 .953 r
.69794 .36889 .70083 .37163 .70716 .36983 .70425 .36666 Metetra
.696 .793 .925 r
.70425 .36666 .70716 .36983 .71347 .36765 .71055 .36405 Metetra
.708 .771 .901 r
.71055 .36405 .71347 .36765 .71978 .36513 .71685 .3612 Metetra
.711 .753 .885 r
.71685 .3612 .71978 .36513 .72609 .36238 .72316 .35825 Metetra
.707 .742 .879 r
.72316 .35825 .72609 .36238 .7324 .35951 .72947 .35533 Metetra
.699 .737 .88 r
.72947 .35533 .7324 .35951 .73872 .35666 .73581 .35256 Metetra
.689 .738 .888 r
.73581 .35256 .73872 .35666 .74507 .35392 .74218 .34999 Metetra
.679 .744 .9 r
.74218 .34999 .74507 .35392 .75143 .35135 .74857 .34762 Metetra
.669 .753 .913 r
.74857 .34762 .75143 .35135 .75783 .34897 .75499 .34542 Metetra
.663 .762 .924 r
.75499 .34542 .75783 .34897 .76424 .34674 .76143 .3433 Metetra
.661 .769 .929 r
.76143 .3433 .76424 .34674 .77068 .34461 .76788 .3412 Metetra
.664 .772 .93 r
.76788 .3412 .77068 .34461 .77714 .34251 .77435 .33905 Metetra
.669 .772 .927 r
.77435 .33905 .77714 .34251 .78361 .34038 .78082 .33682 Metetra
.674 .768 .921 r
.78082 .33682 .78361 .34038 .79009 .33819 .7873 .33451 Metetra
.678 .762 .914 r
.7873 .33451 .79009 .33819 .79658 .33593 .79379 .33213 Metetra
.68 .756 .909 r
.79379 .33213 .79658 .33593 .80308 .3336 .80029 .32971 Metetra
.68 .752 .906 r
.80029 .32971 .80308 .3336 .80958 .33122 .80681 .32729 Metetra
.678 .749 .904 r
.80681 .32729 .80958 .33122 .8161 .32883 .81334 .32488 Metetra
.677 .748 .905 r
.81334 .32488 .8161 .32883 .82264 .32644 .81988 .3225 Metetra
.675 .748 .906 r
.81988 .3225 .82264 .32644 .82919 .32407 .82645 .32015 Metetra
.673 .749 .908 r
.82645 .32015 .82919 .32407 .83576 .32173 .83303 .31783 Metetra
.672 .75 .909 r
.83303 .31783 .83576 .32173 .84234 .31941 .83962 .31551 Metetra
.672 .751 .91 r
.83962 .31551 .84234 .31941 .84894 .31711 .84624 .3132 Metetra
.672 .751 .91 r
.84624 .3132 .84894 .31711 .85556 .31481 .85286 .31088 Metetra
.672 .75 .91 r
.85286 .31088 .85556 .31481 .86219 .31251 .8595 .30856 Metetra
.672 .75 .909 r
.8595 .30856 .86219 .31251 .86883 .3102 .86616 .30623 Metetra
.672 .749 .908 r
.86616 .30623 .86883 .3102 .87549 .30788 .87283 .30389 Metetra
.672 .748 .908 r
.87283 .30389 .87549 .30788 .88217 .30556 .87951 .30155 Metetra
.656 .739 .911 r
.2796 .49226 .28313 .49555 .28854 .49387 .28501 .49058 Metetra
.656 .74 .911 r
.28501 .49058 .28854 .49387 .29396 .49218 .29044 .48889 Metetra
.656 .74 .911 r
.29044 .48889 .29396 .49218 .29939 .4905 .29588 .4872 Metetra
.656 .74 .911 r
.29588 .4872 .29939 .4905 .30483 .48882 .30132 .48551 Metetra
.656 .74 .911 r
.30132 .48551 .30483 .48882 .31028 .48715 .30678 .48382 Metetra
.655 .738 .911 r
.30678 .48382 .31028 .48715 .31574 .48549 .31226 .48213 Metetra
.654 .737 .91 r
.31226 .48213 .31574 .48549 .32122 .48385 .31774 .48046 Metetra
.653 .735 .91 r
.31774 .48046 .32122 .48385 .3267 .48221 .32323 .47881 Metetra
.651 .734 .91 r
.32323 .47881 .3267 .48221 .3322 .48058 .32873 .47717 Metetra
.651 .735 .911 r
.32873 .47717 .3322 .48058 .33771 .47892 .33425 .47554 Metetra
.651 .737 .912 r
.33425 .47554 .33771 .47892 .34323 .47722 .33978 .47389 Metetra
.653 .74 .914 r
.33978 .47389 .34323 .47722 .34877 .4755 .34532 .47221 Metetra
.656 .744 .915 r
.34532 .47221 .34877 .4755 .35432 .47375 .35087 .47049 Metetra
.658 .747 .916 r
.35087 .47049 .35432 .47375 .35988 .47203 .35644 .46874 Metetra
.657 .745 .915 r
.35644 .46874 .35988 .47203 .36545 .47038 .36202 .46699 Metetra
.654 .739 .912 r
.36202 .46699 .36545 .47038 .37103 .46884 .36761 .46529 Metetra
.646 .727 .908 r
.36761 .46529 .37103 .46884 .37661 .46742 .37321 .46369 Metetra
.637 .714 .903 r
.37321 .46369 .37661 .46742 .3822 .4661 .37881 .46224 Metetra
.628 .704 .901 r
.37881 .46224 .3822 .4661 .3878 .46478 .38442 .46091 Metetra
.624 .703 .902 r
.38442 .46091 .3878 .46478 .39343 .46334 .39004 .45963 Metetra
.628 .714 .909 r
.39004 .45963 .39343 .46334 .39907 .46168 .39568 .45829 Metetra
.641 .738 .919 r
.39568 .45829 .39907 .46168 .40474 .45974 .40134 .45675 Metetra
.661 .769 .93 r
.40134 .45675 .40474 .45974 .41042 .45758 .40702 .4549 Metetra
.68 .795 .936 r
.40702 .4549 .41042 .45758 .41612 .45537 .41273 .45277 Metetra
.689 .803 .935 r
.41273 .45277 .41612 .45537 .42182 .4534 .41845 .4505 Metetra
.68 .781 .927 r
.41845 .4505 .42182 .4534 .42752 .45198 .42418 .44837 Metetra
.647 .728 .908 r
.42418 .44837 .42752 .45198 .43321 .45135 .4299 .44673 Metetra
.596 .656 .879 r
.4299 .44673 .43321 .45135 .43889 .45157 .43562 .44588 Metetra
.54 .584 .848 r
.43562 .44588 .43889 .45157 .44458 .45249 .44132 .44596 Metetra
.493 .53 .824 r
.44132 .44596 .44458 .45249 .45028 .45373 .44703 .44689 Metetra
.463 .504 .815 r
.44703 .44689 .45028 .45373 .456 .45478 .45274 .44833 Metetra
.458 .514 .828 r
.45274 .44833 .456 .45478 .46177 .45508 .45849 .44971 Metetra
.485 .572 .868 r
.45849 .44971 .46177 .45508 .46757 .45417 .46426 .45044 Metetra
.551 .689 .931 r
.46426 .45044 .46757 .45417 .47341 .45185 .47008 .44997 Metetra
.645 .851 .979 r
.47008 .44997 .47341 .45185 .47929 .44816 .47594 .448 Metetra
.708 .968 .934 r
.47594 .448 .47929 .44816 .48518 .44338 .48184 .44453 Metetra
.708 .984 .817 r
.48184 .44453 .48518 .44338 .49108 .43796 .48775 .43981 Metetra
.699 .967 .733 r
.48775 .43981 .49108 .43796 .49698 .43238 .49367 .43432 Metetra
.713 .968 .724 r
.49367 .43432 .49698 .43238 .50288 .42706 .4996 .42856 Metetra
.746 .987 .774 r
.4996 .42856 .50288 .42706 .50878 .42228 .50552 .42302 Metetra
.775 .997 .849 r
.50552 .42302 .50878 .42228 .51468 .41817 .51144 .418 Metetra
.781 .978 .911 r
.51144 .418 .51468 .41817 .52058 .41471 .51736 .41366 Metetra
.763 .931 .941 r
.51736 .41366 .52058 .41471 .52649 .41179 .52328 .40999 Metetra
.734 .878 .947 r
.52328 .40999 .52649 .41179 .53241 .40928 .52921 .40691 Metetra
.707 .834 .943 r
.52921 .40691 .53241 .40928 .53834 .40702 .53515 .40427 Metetra
.688 .803 .936 r
.53515 .40427 .53834 .40702 .54428 .40492 .54111 .40193 Metetra
.676 .784 .931 r
.54111 .40193 .54428 .40492 .55024 .40289 .54707 .39977 Metetra
.668 .774 .929 r
.54707 .39977 .55024 .40289 .55621 .4009 .55305 .39772 Metetra
.664 .769 .928 r
.55305 .39772 .55621 .4009 .56219 .39892 .55904 .39572 Metetra
.662 .768 .928 r
.55904 .39572 .56219 .39892 .56819 .39696 .56505 .39375 Metetra
.66 .767 .929 r
.56505 .39375 .56819 .39696 .57419 .39502 .57106 .39181 Metetra
.658 .767 .93 r
.57106 .39181 .57419 .39502 .58022 .39309 .5771 .38989 Metetra
.656 .768 .932 r
.5771 .38989 .58022 .39309 .58625 .39118 .58314 .38799 Metetra
.653 .768 .934 r
.58314 .38799 .58625 .39118 .5923 .3893 .5892 .38613 Metetra
.649 .768 .936 r
.5892 .38613 .5923 .3893 .59837 .38745 .59528 .38432 Metetra
.643 .769 .94 r
.59528 .38432 .59837 .38745 .60445 .38566 .60137 .38257 Metetra
.635 .77 .945 r
.60137 .38257 .60445 .38566 .61054 .38393 .60748 .38091 Metetra
.625 .772 .951 r
.60748 .38091 .61054 .38393 .61666 .38228 .6136 .37937 Metetra
.61 .774 .959 r
.6136 .37937 .61666 .38228 .62279 .38075 .61975 .37796 Metetra
.591 .777 .969 r
.61975 .37796 .62279 .38075 .62894 .37934 .62591 .37672 Metetra
.565 .779 .979 r
.62591 .37672 .62894 .37934 .63511 .3781 .6321 .37567 Metetra
.532 .781 .989 r
.6321 .37567 .63511 .3781 .64131 .37703 .63832 .37482 Metetra
.492 .781 .996 r
.63832 .37482 .64131 .37703 .64752 .37615 .64456 .37416 Metetra
.45 .779 .998 r
.64456 .37416 .64752 .37615 .65377 .37544 .65082 .37365 Metetra
.416 .777 .995 r
.65082 .37365 .65377 .37544 .66004 .37486 .65711 .37321 Metetra
.403 .782 .992 r
.65711 .37321 .66004 .37486 .66633 .37434 .66341 .37274 Metetra
.424 .796 .994 r
.66341 .37274 .66633 .37434 .67264 .37378 .66973 .3721 Metetra
.48 .818 .999 r
.66973 .3721 .67264 .37378 .67896 .37307 .67606 .37116 Metetra
.554 .834 .997 r
.67606 .37116 .67896 .37307 .68529 .37207 .68238 .36979 Metetra
.624 .833 .98 r
.68238 .36979 .68529 .37207 .69162 .3707 .68869 .36796 Metetra
.674 .815 .951 r
.68869 .36796 .69162 .3707 .69794 .36889 .695 .36565 Metetra
.701 .79 .92 r
.695 .36565 .69794 .36889 .70425 .36666 .7013 .36296 Metetra
.712 .767 .895 r
.7013 .36296 .70425 .36666 .71055 .36405 .70759 .36002 Metetra
.713 .749 .88 r
.70759 .36002 .71055 .36405 .71685 .3612 .71389 .35699 Metetra
.708 .738 .875 r
.71389 .35699 .71685 .3612 .72316 .35825 .72021 .35403 Metetra
.699 .735 .879 r
.72021 .35403 .72316 .35825 .72947 .35533 .72655 .35125 Metetra
.688 .739 .89 r
.72655 .35125 .72947 .35533 .73581 .35256 .73291 .3487 Metetra
.677 .748 .904 r
.73291 .3487 .73581 .35256 .74218 .34999 .7393 .34636 Metetra
.668 .759 .918 r
.7393 .34636 .74218 .34999 .74857 .34762 .74572 .34418 Metetra
.662 .769 .929 r
.74572 .34418 .74857 .34762 .75499 .34542 .75215 .34207 Metetra
.662 .775 .933 r
.75215 .34207 .75499 .34542 .76143 .3433 .7586 .33995 Metetra
.666 .777 .932 r
.7586 .33995 .76143 .3433 .76788 .3412 .76506 .33776 Metetra
.672 .774 .927 r
.76506 .33776 .76788 .3412 .77435 .33905 .77153 .33548 Metetra
.678 .768 .919 r
.77153 .33548 .77435 .33905 .78082 .33682 .778 .33311 Metetra
.681 .762 .912 r
.778 .33311 .78082 .33682 .7873 .33451 .78449 .33068 Metetra
.682 .755 .907 r
.78449 .33068 .7873 .33451 .79379 .33213 .79098 .32822 Metetra
.681 .751 .904 r
.79098 .32822 .79379 .33213 .80029 .32971 .79749 .32577 Metetra
.679 .749 .904 r
.79749 .32577 .80029 .32971 .80681 .32729 .80402 .32334 Metetra
.677 .748 .905 r
.80402 .32334 .80681 .32729 .81334 .32488 .81056 .32096 Metetra
.675 .749 .907 r
.81056 .32096 .81334 .32488 .81988 .3225 .81712 .3186 Metetra
.673 .75 .909 r
.81712 .3186 .81988 .3225 .82645 .32015 .8237 .31626 Metetra
.673 .751 .91 r
.8237 .31626 .82645 .32015 .83303 .31783 .83029 .31393 Metetra
.672 .752 .91 r
.83029 .31393 .83303 .31783 .83962 .31551 .8369 .31161 Metetra
.672 .752 .91 r
.8369 .31161 .83962 .31551 .84624 .3132 .84352 .30927 Metetra
.673 .751 .909 r
.84352 .30927 .84624 .3132 .85286 .31088 .85016 .30693 Metetra
.673 .75 .909 r
.85016 .30693 .85286 .31088 .8595 .30856 .85681 .30458 Metetra
.673 .749 .908 r
.85681 .30458 .8595 .30856 .86616 .30623 .86347 .30222 Metetra
.672 .748 .908 r
.86347 .30222 .86616 .30623 .87283 .30389 .87015 .29987 Metetra
.672 .747 .907 r
.87015 .29987 .87283 .30389 .87951 .30155 .87685 .29752 Metetra
.656 .739 .911 r
.27606 .48895 .2796 .49226 .28501 .49058 .28148 .48727 Metetra
.656 .739 .911 r
.28148 .48727 .28501 .49058 .29044 .48889 .28691 .48558 Metetra
.656 .739 .911 r
.28691 .48558 .29044 .48889 .29588 .4872 .29235 .48389 Metetra
.656 .74 .911 r
.29235 .48389 .29588 .4872 .30132 .48551 .29781 .48219 Metetra
.656 .74 .912 r
.29781 .48219 .30132 .48551 .30678 .48382 .30327 .48049 Metetra
.656 .74 .912 r
.30327 .48049 .30678 .48382 .31226 .48213 .30875 .47879 Metetra
.655 .739 .911 r
.30875 .47879 .31226 .48213 .31774 .48046 .31424 .47709 Metetra
.654 .737 .911 r
.31424 .47709 .31774 .48046 .32323 .47881 .31974 .47541 Metetra
.653 .736 .91 r
.31974 .47541 .32323 .47881 .32873 .47717 .32525 .47374 Metetra
.651 .734 .91 r
.32525 .47374 .32873 .47717 .33425 .47554 .33078 .4721 Metetra
.65 .733 .91 r
.33078 .4721 .33425 .47554 .33978 .47389 .33631 .47046 Metetra
.65 .735 .911 r
.33631 .47046 .33978 .47389 .34532 .47221 .34185 .46883 Metetra
.651 .738 .913 r
.34185 .46883 .34532 .47221 .35087 .47049 .34741 .46717 Metetra
.654 .743 .915 r
.34741 .46717 .35087 .47049 .35644 .46874 .35299 .46546 Metetra
.657 .747 .916 r
.35299 .46546 .35644 .46874 .36202 .46699 .35857 .46371 Metetra
.658 .748 .916 r
.35857 .46371 .36202 .46699 .36761 .46529 .36417 .46194 Metetra
.656 .743 .914 r
.36417 .46194 .36761 .46529 .37321 .46369 .36978 .46019 Metetra
.65 .732 .909 r
.36978 .46019 .37321 .46369 .37881 .46224 .3754 .45852 Metetra
.64 .718 .904 r
.3754 .45852 .37881 .46224 .38442 .46091 .38103 .45701 Metetra
.629 .704 .9 r
.38103 .45701 .38442 .46091 .39004 .45963 .38666 .45566 Metetra
.621 .697 .899 r
.38666 .45566 .39004 .45963 .39568 .45829 .3923 .45442 Metetra
.62 .703 .905 r
.3923 .45442 .39568 .45829 .40134 .45675 .39795 .45319 Metetra
.63 .725 .916 r
.39795 .45319 .40134 .45675 .40702 .4549 .40363 .45179 Metetra
.65 .759 .93 r
.40363 .45179 .40702 .4549 .41273 .45277 .40932 .45009 Metetra
.673 .795 .939 r
.40932 .45009 .41273 .45277 .41845 .4505 .41505 .44803 Metetra
.691 .814 .941 r
.41505 .44803 .41845 .4505 .42418 .44837 .42079 .44571 Metetra
.692 .801 .933 r
.42079 .44571 .42418 .44837 .4299 .44673 .42654 .44339 Metetra
.667 .752 .914 r
.42654 .44339 .4299 .44673 .43562 .44588 .43229 .44144 Metetra
.617 .675 .882 r
.43229 .44144 .43562 .44588 .44132 .44596 .43804 .44025 Metetra
.555 .592 .846 r
.43804 .44025 .44132 .44596 .44703 .44689 .44377 .44011 Metetra
.497 .525 .816 r
.44377 .44011 .44703 .44689 .45274 .44833 .4495 .44103 Metetra
.451 .484 .802 r
.4495 .44103 .45274 .44833 .45849 .44971 .45523 .44275 Metetra
.424 .479 .813 r
.45523 .44275 .45849 .44971 .46426 .45044 .46098 .44474 Metetra
.422 .525 .857 r
.46098 .44474 .46426 .45044 .47008 .44997 .46677 .44627 Metetra
.456 .65 .943 r
.46677 .44627 .47008 .44997 .47594 .448 .4726 .44667 Metetra
.514 .848 .997 r
.4726 .44667 .47594 .448 .48184 .44453 .47847 .44543 Metetra
.498 .904 .81 r
.47847 .44543 .48184 .44453 .48775 .43981 .48438 .44239 Metetra
.454 .824 .571 r
.48438 .44239 .48775 .43981 .49367 .43432 .49032 .4377 Metetra
.49032 .4377 .49367 .43432 .4996 .42856 .49627 .43185 Metetra
.569 .856 .531 r
.49627 .43185 .4996 .42856 .50552 .42302 .50222 .42545 Metetra
.698 .946 .662 r
.50222 .42545 .50552 .42302 .51144 .418 .50817 .41911 Metetra
.803 .999 .808 r
.50817 .41911 .51144 .418 .51736 .41366 .51412 .41331 Metetra
.827 .968 .893 r
.51412 .41331 .51736 .41366 .52328 .40999 .52006 .40833 Metetra
.793 .891 .915 r
.52006 .40833 .52328 .40999 .52921 .40691 .526 .40423 Metetra
.746 .819 .909 r
.526 .40423 .52921 .40691 .53515 .40427 .53195 .40092 Metetra
.708 .77 .901 r
.53195 .40092 .53515 .40427 .54111 .40193 .53791 .39821 Metetra
.684 .743 .896 r
.53791 .39821 .54111 .40193 .54707 .39977 .54388 .3959 Metetra
.67 .73 .895 r
.54388 .3959 .54707 .39977 .55305 .39772 .54987 .39382 Metetra
.663 .727 .897 r
.54987 .39382 .55305 .39772 .55904 .39572 .55587 .39184 Metetra
.661 .727 .899 r
.55587 .39184 .55904 .39572 .56505 .39375 .56188 .38989 Metetra
.659 .728 .901 r
.56188 .38989 .56505 .39375 .57106 .39181 .56791 .38797 Metetra
.657 .73 .903 r
.56791 .38797 .57106 .39181 .5771 .38989 .57395 .38607 Metetra
.655 .73 .905 r
.57395 .38607 .5771 .38989 .58314 .38799 .58001 .38421 Metetra
.651 .732 .908 r
.58001 .38421 .58314 .38799 .5892 .38613 .58608 .38241 Metetra
.645 .733 .913 r
.58608 .38241 .5892 .38613 .59528 .38432 .59216 .38068 Metetra
.638 .736 .92 r
.59216 .38068 .59528 .38432 .60137 .38257 .59827 .37906 Metetra
.627 .74 .929 r
.59827 .37906 .60137 .38257 .60748 .38091 .60439 .37756 Metetra
.613 .745 .94 r
.60439 .37756 .60748 .38091 .6136 .37937 .61053 .37621 Metetra
.592 .752 .954 r
.61053 .37621 .6136 .37937 .61975 .37796 .61669 .37506 Metetra
.564 .759 .97 r
.61669 .37506 .61975 .37796 .62591 .37672 .62288 .37412 Metetra
.524 .765 .985 r
.62288 .37412 .62591 .37672 .6321 .37567 .62909 .37341 Metetra
.472 .768 .995 r
.62909 .37341 .6321 .37567 .63832 .37482 .63532 .37291 Metetra
.412 .766 .995 r
.63532 .37291 .63832 .37482 .64456 .37416 .64159 .37259 Metetra
.355 .761 .983 r
.64159 .37259 .64456 .37416 .65082 .37365 .64788 .37234 Metetra
.324 .761 .967 r
.64788 .37234 .65082 .37365 .65711 .37321 .65418 .37204 Metetra
.341 .779 .965 r
.65418 .37204 .65711 .37321 .66341 .37274 .6605 .37152 Metetra
.411 .816 .981 r
.6605 .37152 .66341 .37274 .66973 .3721 .66682 .37064 Metetra
.516 .851 .996 r
.66682 .37064 .66973 .3721 .67606 .37116 .67314 .36927 Metetra
.615 .86 .99 r
.67314 .36927 .67606 .37116 .68238 .36979 .67945 .36735 Metetra
.68 .839 .96 r
.67945 .36735 .68238 .36979 .68869 .36796 .68575 .36491 Metetra
.711 .807 .924 r
.68575 .36491 .68869 .36796 .695 .36565 .69203 .36206 Metetra
.721 .776 .896 r
.69203 .36206 .695 .36565 .7013 .36296 .69832 .35896 Metetra
.719 .753 .879 r
.69832 .35896 .7013 .36296 .70759 .36002 .70461 .35581 Metetra
.711 .74 .874 r
.70461 .35581 .70759 .36002 .71389 .35699 .71092 .35278 Metetra
.7 .736 .879 r
.71092 .35278 .71389 .35699 .72021 .35403 .71726 .34998 Metetra
.687 .741 .892 r
.71726 .34998 .72021 .35403 .72655 .35125 .72362 .34745 Metetra
.675 .751 .908 r
.72362 .34745 .72655 .35125 .73291 .3487 .73002 .34515 Metetra
.665 .763 .923 r
.73002 .34515 .73291 .3487 .7393 .34636 .73643 .343 Metetra
.661 .774 .933 r
.73643 .343 .7393 .34636 .74572 .34418 .74286 .3409 Metetra
.663 .781 .936 r
.74286 .3409 .74572 .34418 .75215 .34207 .74931 .33876 Metetra
.669 .781 .933 r
.74931 .33876 .75215 .34207 .7586 .33995 .75576 .33652 Metetra
.676 .777 .926 r
.75576 .33652 .7586 .33995 .76506 .33776 .76222 .33417 Metetra
.682 .769 .917 r
.76222 .33417 .76506 .33776 .77153 .33548 .76869 .33174 Metetra
.684 .761 .91 r
.76869 .33174 .77153 .33548 .778 .33311 .77517 .32924 Metetra
.684 .755 .905 r
.77517 .32924 .778 .33311 .78449 .33068 .78166 .32674 Metetra
.682 .751 .903 r
.78166 .32674 .78449 .33068 .79098 .32822 .78816 .32426 Metetra
.68 .749 .903 r
.78816 .32426 .79098 .32822 .79749 .32577 .79468 .32182 Metetra
.677 .749 .905 r
.79468 .32182 .79749 .32577 .80402 .32334 .80122 .31943 Metetra
.675 .75 .908 r
.80122 .31943 .80402 .32334 .81056 .32096 .80778 .31706 Metetra
.674 .752 .909 r
.80778 .31706 .81056 .32096 .81712 .3186 .81435 .31471 Metetra
.673 .753 .91 r
.81435 .31471 .81712 .3186 .8237 .31626 .82094 .31237 Metetra
.673 .753 .911 r
.82094 .31237 .8237 .31626 .83029 .31393 .82754 .31002 Metetra
.673 .752 .91 r
.82754 .31002 .83029 .31393 .8369 .31161 .83416 .30767 Metetra
.674 .751 .909 r
.83416 .30767 .8369 .31161 .84352 .30927 .84079 .3053 Metetra
.674 .75 .908 r
.84079 .3053 .84352 .30927 .85016 .30693 .84744 .30293 Metetra
.673 .749 .908 r
.84744 .30293 .85016 .30693 .85681 .30458 .8541 .30056 Metetra
.673 .748 .907 r
.8541 .30056 .85681 .30458 .86347 .30222 .86077 .29819 Metetra
.672 .748 .907 r
.86077 .29819 .86347 .30222 .87015 .29987 .86746 .29583 Metetra
.672 .747 .907 r
.86746 .29583 .87015 .29987 .87685 .29752 .87417 .29347 Metetra
.656 .739 .911 r
.2725 .48564 .27606 .48895 .28148 .48727 .27793 .48394 Metetra
.656 .739 .911 r
.27793 .48394 .28148 .48727 .28691 .48558 .28337 .48224 Metetra
.656 .739 .911 r
.28337 .48224 .28691 .48558 .29235 .48389 .28882 .48055 Metetra
.656 .739 .911 r
.28882 .48055 .29235 .48389 .29781 .48219 .29428 .47885 Metetra
.656 .739 .911 r
.29428 .47885 .29781 .48219 .30327 .48049 .29975 .47715 Metetra
.656 .74 .912 r
.29975 .47715 .30327 .48049 .30875 .47879 .30524 .47545 Metetra
.656 .74 .912 r
.30524 .47545 .30875 .47879 .31424 .47709 .31073 .47374 Metetra
.655 .74 .912 r
.31073 .47374 .31424 .47709 .31974 .47541 .31624 .47203 Metetra
.655 .738 .911 r
.31624 .47203 .31974 .47541 .32525 .47374 .32176 .47033 Metetra
.653 .736 .911 r
.32176 .47033 .32525 .47374 .33078 .4721 .32729 .46865 Metetra
.651 .734 .91 r
.32729 .46865 .33078 .4721 .33631 .47046 .33283 .46699 Metetra
.649 .733 .91 r
.33283 .46699 .33631 .47046 .34185 .46883 .33838 .46536 Metetra
.649 .733 .911 r
.33838 .46536 .34185 .46883 .34741 .46717 .34395 .46373 Metetra
.649 .735 .912 r
.34395 .46373 .34741 .46717 .35299 .46546 .34952 .46209 Metetra
.652 .74 .914 r
.34952 .46209 .35299 .46546 .35857 .46371 .35511 .46041 Metetra
.655 .746 .916 r
.35511 .46041 .35857 .46371 .36417 .46194 .36072 .45867 Metetra
.658 .749 .917 r
.36072 .45867 .36417 .46194 .36978 .46019 .36634 .45688 Metetra
.658 .748 .916 r
.36634 .45688 .36978 .46019 .3754 .45852 .37197 .45509 Metetra
.654 .739 .912 r
.37197 .45509 .3754 .45852 .38103 .45701 .37761 .45337 Metetra
.644 .724 .907 r
.37761 .45337 .38103 .45701 .38666 .45566 .38326 .45179 Metetra
.631 .707 .901 r
.38326 .45179 .38666 .45566 .3923 .45442 .38891 .45039 Metetra
.62 .695 .898 r
.38891 .45039 .3923 .45442 .39795 .45319 .39457 .44917 Metetra
.615 .694 .9 r
.39457 .44917 .39795 .45319 .40363 .45179 .40024 .448 Metetra
.621 .71 .909 r
.40024 .448 .40363 .45179 .40932 .45009 .40593 .44673 Metetra
.639 .742 .923 r
.40593 .44673 .40932 .45009 .41505 .44803 .41164 .44518 Metetra
.666 .782 .936 r
.41164 .44518 .41505 .44803 .42079 .44571 .41738 .44322 Metetra
.69 .813 .941 r
.41738 .44322 .42079 .44571 .42654 .44339 .42314 .4409 Metetra
.699 .815 .937 r
.42314 .4409 .42654 .44339 .43229 .44144 .42892 .43845 Metetra
.681 .778 .924 r
.42892 .43845 .43229 .44144 .43804 .44025 .4347 .43627 Metetra
.633 .705 .898 r
.4347 .43627 .43804 .44025 .44377 .44011 .44047 .43483 Metetra
.563 .614 .861 r
.44047 .43483 .44377 .44011 .4495 .44103 .44623 .43449 Metetra
.493 .531 .825 r
.44623 .43449 .4495 .44103 .45523 .44275 .45198 .4354 Metetra
.437 .475 .801 r
.45198 .4354 .45523 .44275 .46098 .44474 .45773 .43732 Metetra
.406 .456 .799 r
.45773 .43732 .46098 .44474 .46677 .44627 .4635 .43969 Metetra
.409 .484 .826 r
.4635 .43969 .46677 .44627 .4726 .44667 .4693 .4417 Metetra
.461 .581 .888 r
.4693 .4417 .4726 .44667 .47847 .44543 .47515 .44253 Metetra
.574 .757 .964 r
.47515 .44253 .47847 .44543 .48438 .44239 .48104 .44156 Metetra
.7 .936 .963 r
.48104 .44156 .48438 .44239 .49032 .4377 .48697 .43854 Metetra
.754 .995 .846 r
.48697 .43854 .49032 .4377 .49627 .43185 .49293 .43366 Metetra
.768 .986 .745 r
.49293 .43366 .49627 .43185 .50222 .42545 .49891 .42748 Metetra
.791 .984 .721 r
.49891 .42748 .50222 .42545 .50817 .41911 .50488 .4207 Metetra
.821 .995 .761 r
.50488 .4207 .50817 .41911 .51412 .41331 .51085 .41406 Metetra
.839 .998 .829 r
.51085 .41406 .51412 .41331 .52006 .40833 .51681 .40807 Metetra
.828 .973 .89 r
.51681 .40807 .52006 .40833 .526 .40423 .52278 .40301 Metetra
.792 .923 .924 r
.52278 .40301 .526 .40423 .53195 .40092 .52874 .3989 Metetra
.748 .867 .934 r
.52874 .3989 .53195 .40092 .53791 .39821 .53471 .39559 Metetra
.712 .82 .932 r
.53471 .39559 .53791 .39821 .54388 .3959 .54069 .39285 Metetra
.688 .786 .925 r
.54069 .39285 .54388 .3959 .54987 .39382 .54669 .39049 Metetra
.674 .765 .919 r
.54669 .39049 .54987 .39382 .55587 .39184 .55269 .38833 Metetra
.666 .752 .914 r
.55269 .38833 .55587 .39184 .56188 .38989 .55871 .38629 Metetra
.661 .745 .912 r
.55871 .38629 .56188 .38989 .56791 .38797 .56475 .38433 Metetra
.657 .742 .912 r
.56475 .38433 .56791 .38797 .57395 .38607 .5708 .38243 Metetra
.652 .74 .914 r
.5708 .38243 .57395 .38607 .58001 .38421 .57686 .3806 Metetra
.647 .741 .918 r
.57686 .3806 .58001 .38421 .58608 .38241 .58294 .37884 Metetra
.639 .741 .922 r
.58294 .37884 .58608 .38241 .59216 .38068 .58904 .37718 Metetra
.629 .742 .929 r
.58904 .37718 .59216 .38068 .59827 .37906 .59515 .37564 Metetra
.615 .743 .937 r
.59515 .37564 .59827 .37906 .60439 .37756 .60129 .37427 Metetra
.596 .745 .948 r
.60129 .37427 .60439 .37756 .61053 .37621 .60744 .37311 Metetra
.568 .747 .961 r
.60744 .37311 .61053 .37621 .61669 .37506 .61362 .37219 Metetra
.531 .748 .975 r
.61362 .37219 .61669 .37506 .62288 .37412 .61982 .37153 Metetra
.483 .749 .988 r
.61982 .37153 .62288 .37412 .62909 .37341 .62606 .37113 Metetra
.427 .746 .993 r
.62606 .37113 .62909 .37341 .63532 .37291 .63232 .37095 Metetra
.374 .743 .99 r
.63232 .37095 .63532 .37291 .64159 .37259 .6386 .37089 Metetra
.343 .746 .982 r
.6386 .37089 .64159 .37259 .64788 .37234 .6449 .3708 Metetra
.357 .765 .982 r
.6449 .3708 .64788 .37234 .65418 .37204 .65122 .3705 Metetra
.424 .801 .992 r
.65122 .3705 .65418 .37204 .6605 .37152 .65755 .3698 Metetra
.525 .836 .999 r
.65755 .3698 .6605 .37152 .66682 .37064 .66387 .36854 Metetra
.621 .845 .985 r
.66387 .36854 .66682 .37064 .67314 .36927 .67017 .36666 Metetra
.685 .828 .952 r
.67017 .36666 .67314 .36927 .67945 .36735 .67647 .36418 Metetra
.716 .8 .917 r
.67647 .36418 .67945 .36735 .68575 .36491 .68275 .36124 Metetra
.725 .772 .89 r
.68275 .36124 .68575 .36491 .69203 .36206 .68903 .35803 Metetra
.723 .753 .876 r
.68903 .35803 .69203 .36206 .69832 .35896 .69532 .35479 Metetra
.714 .743 .874 r
.69532 .35479 .69832 .35896 .70461 .35581 .70163 .3517 Metetra
.702 .742 .883 r
.70163 .3517 .70461 .35581 .71092 .35278 .70796 .34888 Metetra
.687 .749 .899 r
.70796 .34888 .71092 .35278 .71726 .34998 .71432 .34635 Metetra
.674 .761 .916 r
.71432 .34635 .71726 .34998 .72362 .34745 .72072 .34407 Metetra
.664 .774 .931 r
.72072 .34407 .72362 .34745 .73002 .34515 .72713 .34192 Metetra
.661 .783 .939 r
.72713 .34192 .73002 .34515 .73643 .343 .73356 .3398 Metetra
.665 .787 .939 r
.73356 .3398 .73643 .343 .74286 .3409 .74 .33762 Metetra
.673 .785 .933 r
.74 .33762 .74286 .3409 .74931 .33876 .74645 .33531 Metetra
.681 .778 .924 r
.74645 .33531 .74931 .33876 .75576 .33652 .7529 .33289 Metetra
.686 .768 .914 r
.7529 .33289 .75576 .33652 .76222 .33417 .75936 .33038 Metetra
.687 .76 .907 r
.75936 .33038 .76222 .33417 .76869 .33174 .76583 .32783 Metetra
.686 .754 .903 r
.76583 .32783 .76869 .33174 .77517 .32924 .77231 .32529 Metetra
.683 .75 .902 r
.77231 .32529 .77517 .32924 .78166 .32674 .77881 .32279 Metetra
.68 .75 .903 r
.77881 .32279 .78166 .32674 .78816 .32426 .78533 .32033 Metetra
.678 .751 .906 r
.78533 .32033 .78816 .32426 .79468 .32182 .79187 .31793 Metetra
.676 .752 .909 r
.79187 .31793 .79468 .32182 .80122 .31943 .79842 .31555 Metetra
.675 .754 .91 r
.79842 .31555 .80122 .31943 .80778 .31706 .80499 .31319 Metetra
.674 .754 .911 r
.80499 .31319 .80778 .31706 .81435 .31471 .81157 .31082 Metetra
.674 .754 .911 r
.81157 .31082 .81435 .31471 .82094 .31237 .81817 .30845 Metetra
.675 .753 .91 r
.81817 .30845 .82094 .31237 .82754 .31002 .82478 .30607 Metetra
.675 .751 .909 r
.82478 .30607 .82754 .31002 .83416 .30767 .83141 .30369 Metetra
.674 .75 .908 r
.83141 .30369 .83416 .30767 .84079 .3053 .83805 .3013 Metetra
.674 .749 .907 r
.83805 .3013 .84079 .3053 .84744 .30293 .8447 .29891 Metetra
.673 .748 .907 r
.8447 .29891 .84744 .30293 .8541 .30056 .85137 .29653 Metetra
.673 .748 .907 r
.85137 .29653 .8541 .30056 .86077 .29819 .85806 .29415 Metetra
.672 .748 .907 r
.85806 .29415 .86077 .29819 .86746 .29583 .86476 .29178 Metetra
.672 .748 .907 r
.86476 .29178 .86746 .29583 .87417 .29347 .87148 .28941 Metetra
.657 .739 .911 r
.26893 .48231 .2725 .48564 .27793 .48394 .27436 .4806 Metetra
.656 .739 .911 r
.27436 .4806 .27793 .48394 .28337 .48224 .27981 .4789 Metetra
.656 .739 .911 r
.27981 .4789 .28337 .48224 .28882 .48055 .28527 .47719 Metetra
.655 .739 .911 r
.28527 .47719 .28882 .48055 .29428 .47885 .29073 .47549 Metetra
.655 .739 .911 r
.29073 .47549 .29428 .47885 .29975 .47715 .29621 .47379 Metetra
.655 .739 .911 r
.29621 .47379 .29975 .47715 .30524 .47545 .3017 .47209 Metetra
.655 .74 .912 r
.3017 .47209 .30524 .47545 .31073 .47374 .30721 .47038 Metetra
.655 .74 .912 r
.30721 .47038 .31073 .47374 .31624 .47203 .31272 .46867 Metetra
.655 .74 .912 r
.31272 .46867 .31624 .47203 .32176 .47033 .31825 .46695 Metetra
.655 .739 .912 r
.31825 .46695 .32176 .47033 .32729 .46865 .32379 .46524 Metetra
.654 .738 .911 r
.32379 .46524 .32729 .46865 .33283 .46699 .32934 .46354 Metetra
.652 .735 .91 r
.32934 .46354 .33283 .46699 .33838 .46536 .3349 .46186 Metetra
.649 .732 .91 r
.3349 .46186 .33838 .46536 .34395 .46373 .34047 .46022 Metetra
.648 .731 .91 r
.34047 .46022 .34395 .46373 .34952 .46209 .34605 .45859 Metetra
.647 .732 .911 r
.34605 .45859 .34952 .46209 .35511 .46041 .35164 .45697 Metetra
.649 .737 .914 r
.35164 .45697 .35511 .46041 .36072 .45867 .35725 .45532 Metetra
.652 .744 .917 r
.35725 .45532 .36072 .45867 .36634 .45688 .36288 .45361 Metetra
.656 .75 .919 r
.36288 .45361 .36634 .45688 .37197 .45509 .36851 .45184 Metetra
.659 .752 .919 r
.36851 .45184 .37197 .45509 .37761 .45337 .37417 .45003 Metetra
.657 .747 .916 r
.37417 .45003 .37761 .45337 .38326 .45179 .37983 .44824 Metetra
.649 .733 .91 r
.37983 .44824 .38326 .45179 .38891 .45039 .3855 .44656 Metetra
.637 .713 .902 r
.3855 .44656 .38891 .45039 .39457 .44917 .39117 .44507 Metetra
.623 .694 .895 r
.39117 .44507 .39457 .44917 .40024 .448 .39685 .44379 Metetra
.613 .684 .894 r
.39685 .44379 .40024 .448 .40593 .44673 .40254 .44266 Metetra
.612 .692 .9 r
.40254 .44266 .40593 .44673 .41164 .44518 .40825 .44153 Metetra
.624 .721 .916 r
.40825 .44153 .41164 .44518 .41738 .44322 .41397 .44019 Metetra
.648 .768 .936 r
.41397 .44019 .41738 .44322 .42314 .4409 .41972 .43847 Metetra
.677 .816 .95 r
.41972 .43847 .42314 .4409 .42892 .43845 .4255 .4363 Metetra
.697 .841 .952 r
.4255 .4363 .42892 .43845 .4347 .43627 .4313 .43384 Metetra
.695 .821 .942 r
.4313 .43384 .4347 .43627 .44047 .43483 .43711 .43142 Metetra
.661 .749 .915 r
.43711 .43142 .44047 .43483 .44623 .43449 .44291 .42953 Metetra
.597 .644 .868 r
.44291 .42953 .44623 .43449 .45198 .4354 .44871 .42865 Metetra
.527 .544 .816 r
.44871 .42865 .45198 .4354 .45773 .43732 .45449 .42907 Metetra
.468 .47 .777 r
.45449 .42907 .45773 .43732 .4635 .43969 .46026 .43077 Metetra
.427 .431 .761 r
.46026 .43077 .4635 .43969 .4693 .4417 .46605 .43334 Metetra
.406 .431 .774 r
.46605 .43334 .4693 .4417 .47515 .44253 .47186 .43606 Metetra
.407 .489 .831 r
.47186 .43606 .47515 .44253 .48104 .44156 .47772 .43804 Metetra
.438 .656 .952 r
.47772 .43804 .48104 .44156 .48697 .43854 .48361 .43848 Metetra
.393 .848 .897 r
.48361 .43848 .48697 .43854 .49293 .43366 .48956 .43685 Metetra
.48956 .43685 .49293 .43366 .49891 .42748 .49553 .43308 Metetra
.49553 .43308 .49891 .42748 .50488 .4207 .50153 .42747 Metetra
.50153 .42747 .50488 .4207 .51085 .41406 .50753 .42067 Metetra
.50753 .42067 .51085 .41406 .51681 .40807 .51353 .41343 Metetra
.51353 .41343 .51681 .40807 .52278 .40301 .51952 .40646 Metetra
.51952 .40646 .52278 .40301 .52874 .3989 .52551 .40026 Metetra
.707 .978 .778 r
.52551 .40026 .52874 .3989 .53471 .39559 .5315 .3951 Metetra
.77 .967 .926 r
.5315 .3951 .53471 .39559 .54069 .39285 .53749 .391 Metetra
.737 .88 .946 r
.53749 .391 .54069 .39285 .54669 .39049 .54349 .38782 Metetra
.696 .815 .939 r
.54349 .38782 .54669 .39049 .55269 .38833 .54951 .38531 Metetra
.667 .784 .936 r
.54951 .38531 .55269 .38833 .55871 .38629 .55554 .38323 Metetra
.65 .777 .941 r
.55554 .38323 .55871 .38629 .56475 .38433 .56158 .38138 Metetra
.64 .782 .949 r
.56158 .38138 .56475 .38433 .5708 .38243 .56765 .37964 Metetra
.632 .79 .958 r
.56765 .37964 .5708 .38243 .57686 .3806 .57372 .37795 Metetra
.622 .798 .967 r
.57372 .37795 .57686 .3806 .58294 .37884 .57982 .37633 Metetra
.606 .804 .976 r
.57982 .37633 .58294 .37884 .58904 .37718 .58593 .37484 Metetra
.581 .807 .985 r
.58593 .37484 .58904 .37718 .59515 .37564 .59206 .37351 Metetra
.543 .809 .995 r
.59206 .37351 .59515 .37564 .60129 .37427 .59821 .37241 Metetra
.485 .805 1 r
.59821 .37241 .60129 .37427 .60744 .37311 .60438 .37158 Metetra
.402 .789 .99 r
.60438 .37158 .60744 .37311 .61362 .37219 .61058 .37103 Metetra
.294 .752 .952 r
.61058 .37103 .61362 .37219 .61982 .37153 .61681 .37075 Metetra
.178 .696 .885 r
.61681 .37075 .61982 .37153 .62606 .37113 .62307 .37068 Metetra
.086 .64 .81 r
.62307 .37068 .62606 .37113 .63232 .37095 .62935 .37072 Metetra
.053 .618 .767 r
.62935 .37072 .63232 .37095 .6386 .37089 .63565 .3707 Metetra
.1 .655 .786 r
.63565 .3707 .6386 .37089 .6449 .3708 .64196 .37041 Metetra
.241 .751 .87 r
.64196 .37041 .6449 .3708 .65122 .3705 .64828 .36965 Metetra
.441 .852 .964 r
.64828 .36965 .65122 .3705 .65755 .3698 .65459 .36827 Metetra
.61 .884 .99 r
.65459 .36827 .65755 .3698 .66387 .36854 .66088 .36619 Metetra
.697 .851 .956 r
.66088 .36619 .66387 .36854 .67017 .36666 .66717 .3635 Metetra
.727 .804 .912 r
.66717 .3635 .67017 .36666 .67647 .36418 .67344 .36035 Metetra
.731 .766 .881 r
.67344 .36035 .67647 .36418 .68275 .36124 .67972 .35699 Metetra
.724 .743 .867 r
.67972 .35699 .68275 .36124 .68903 .35803 .686 .35368 Metetra
.712 .734 .868 r
.686 .35368 .68903 .35803 .69532 .35479 .69231 .35059 Metetra
.698 .737 .881 r
.69231 .35059 .69532 .35479 .70163 .3517 .69865 .34782 Metetra
.683 .75 .902 r
.69865 .34782 .70163 .3517 .70796 .34888 .70501 .34537 Metetra
.67 .767 .923 r
.70501 .34537 .70796 .34888 .71432 .34635 .7114 .34314 Metetra
.662 .784 .939 r
.7114 .34314 .71432 .34635 .72072 .34407 .71782 .34101 Metetra
.662 .795 .946 r
.71782 .34101 .72072 .34407 .72713 .34192 .72424 .33885 Metetra
.669 .797 .943 r
.72424 .33885 .72713 .34192 .73356 .3398 .73067 .33658 Metetra
.679 .791 .934 r
.73067 .33658 .73356 .3398 .74 .33762 .73711 .33417 Metetra
.687 .78 .922 r
.73711 .33417 .74 .33762 .74645 .33531 .74355 .33164 Metetra
.69 .768 .911 r
.74355 .33164 .74645 .33531 .7529 .33289 .75 .32904 Metetra
.69 .758 .904 r
.75 .32904 .7529 .33289 .75936 .33038 .75647 .32643 Metetra
.688 .752 .901 r
.75647 .32643 .75936 .33038 .76583 .32783 .76295 .32386 Metetra
.684 .75 .901 r
.76295 .32386 .76583 .32783 .77231 .32529 .76944 .32134 Metetra
.681 .75 .904 r
.76944 .32134 .77231 .32529 .77881 .32279 .77596 .31888 Metetra
.678 .752 .907 r
.77596 .31888 .77881 .32279 .78533 .32033 .78249 .31646 Metetra
.676 .754 .91 r
.78249 .31646 .78533 .32033 .79187 .31793 .78904 .31407 Metetra
.676 .755 .911 r
.78904 .31407 .79187 .31793 .79842 .31555 .79561 .31169 Metetra
.676 .756 .911 r
.79561 .31169 .79842 .31555 .80499 .31319 .80219 .3093 Metetra
.676 .755 .91 r
.80219 .3093 .80499 .31319 .81157 .31082 .80878 .3069 Metetra
.676 .753 .909 r
.80878 .3069 .81157 .31082 .81817 .30845 .81538 .30449 Metetra
.676 .751 .908 r
.81538 .30449 .81817 .30845 .82478 .30607 .822 .30208 Metetra
.675 .75 .907 r
.822 .30208 .82478 .30607 .83141 .30369 .82864 .29967 Metetra
.675 .749 .907 r
.82864 .29967 .83141 .30369 .83805 .3013 .83529 .29726 Metetra
.674 .748 .907 r
.83529 .29726 .83805 .3013 .8447 .29891 .84196 .29486 Metetra
.673 .748 .907 r
.84196 .29486 .8447 .29891 .85137 .29653 .84864 .29247 Metetra
.673 .748 .907 r
.84864 .29247 .85137 .29653 .85806 .29415 .85534 .29009 Metetra
.672 .748 .907 r
.85534 .29009 .85806 .29415 .86476 .29178 .86205 .28771 Metetra
.672 .748 .908 r
.86205 .28771 .86476 .29178 .87148 .28941 .86878 .28533 Metetra
.657 .74 .911 r
.26534 .47897 .26893 .48231 .27436 .4806 .27079 .47726 Metetra
.657 .74 .911 r
.27079 .47726 .27436 .4806 .27981 .4789 .27624 .47554 Metetra
.656 .739 .911 r
.27624 .47554 .27981 .4789 .28527 .47719 .2817 .47383 Metetra
.656 .739 .911 r
.2817 .47383 .28527 .47719 .29073 .47549 .28718 .47212 Metetra
.655 .739 .911 r
.28718 .47212 .29073 .47549 .29621 .47379 .29266 .47041 Metetra
.655 .738 .911 r
.29266 .47041 .29621 .47379 .3017 .47209 .29816 .46871 Metetra
.655 .739 .911 r
.29816 .46871 .3017 .47209 .30721 .47038 .30367 .467 Metetra
.655 .739 .912 r
.30367 .467 .30721 .47038 .31272 .46867 .30919 .46529 Metetra
.655 .74 .912 r
.30919 .46529 .31272 .46867 .31825 .46695 .31473 .46357 Metetra
.655 .74 .912 r
.31473 .46357 .31825 .46695 .32379 .46524 .32027 .46185 Metetra
.655 .74 .912 r
.32027 .46185 .32379 .46524 .32934 .46354 .32583 .46012 Metetra
.654 .739 .912 r
.32583 .46012 .32934 .46354 .3349 .46186 .3314 .4584 Metetra
.652 .736 .911 r
.3314 .4584 .3349 .46186 .34047 .46022 .33698 .45671 Metetra
.65 .733 .91 r
.33698 .45671 .34047 .46022 .34605 .45859 .34257 .45505 Metetra
.647 .73 .91 r
.34257 .45505 .34605 .45859 .35164 .45697 .34817 .45342 Metetra
.645 .73 .911 r
.34817 .45342 .35164 .45697 .35725 .45532 .35378 .45182 Metetra
.646 .733 .913 r
.35378 .45182 .35725 .45532 .36288 .45361 .35941 .4502 Metetra
.649 .74 .916 r
.35941 .4502 .36288 .45361 .36851 .45184 .36505 .44852 Metetra
.654 .748 .919 r
.36505 .44852 .36851 .45184 .37417 .45003 .3707 .44677 Metetra
.659 .753 .92 r
.3707 .44677 .37417 .45003 .37983 .44824 .37637 .44495 Metetra
.66 .752 .918 r
.37637 .44495 .37983 .44824 .3855 .44656 .38206 .4431 Metetra
.655 .74 .912 r
.38206 .4431 .3855 .44656 .39117 .44507 .38775 .44133 Metetra
.643 .721 .905 r
.38775 .44133 .39117 .44507 .39685 .44379 .39345 .43974 Metetra
.625 .698 .897 r
.39345 .43974 .39685 .44379 .40254 .44266 .39915 .43841 Metetra
.609 .682 .894 r
.39915 .43841 .40254 .44266 .40825 .44153 .40486 .43733 Metetra
.6 .682 .899 r
.40486 .43733 .40825 .44153 .41397 .44019 .41058 .43635 Metetra
.607 .704 .913 r
.41058 .43635 .41397 .44019 .41972 .43847 .41632 .43524 Metetra
.631 .751 .934 r
.41632 .43524 .41972 .43847 .4255 .4363 .42208 .43375 Metetra
.669 .807 .949 r
.42208 .43375 .4255 .4363 .4313 .43384 .42788 .43169 Metetra
.704 .843 .949 r
.42788 .43169 .4313 .43384 .43711 .43142 .4337 .42911 Metetra
.718 .834 .937 r
.4337 .42911 .43711 .43142 .44291 .42953 .43954 .42635 Metetra
.692 .772 .913 r
.43954 .42635 .44291 .42953 .44871 .42865 .44538 .42397 Metetra
.624 .67 .873 r
.44538 .42397 .44871 .42865 .45449 .42907 .4512 .42263 Metetra
.533 .558 .826 r
.4512 .42263 .45449 .42907 .46026 .43077 .45701 .42289 Metetra
.441 .464 .788 r
.45701 .42289 .46026 .43077 .46605 .43334 .4628 .4249 Metetra
.357 .4 .769 r
.4628 .4249 .46605 .43334 .47186 .43606 .46859 .42831 Metetra
.285 .374 .779 r
.46859 .42831 .47186 .43606 .47772 .43804 .47441 .43227 Metetra
.23 .414 .837 r
.47441 .43227 .47772 .43804 .48361 .43848 .48027 .43558 Metetra
.217 .583 .944 r
.48027 .43558 .48361 .43848 .48956 .43685 .48619 .43702 Metetra
.27 .776 .825 r
.48619 .43702 .48956 .43685 .49553 .43308 .49216 .43574 Metetra
.49216 .43574 .49553 .43308 .50153 .42747 .49817 .43147 Metetra
.49817 .43147 .50153 .42747 .50753 .42067 .5042 .42465 Metetra
.676 .881 .506 r
.5042 .42465 .50753 .42067 .51353 .41343 .51023 .41624 Metetra
.84 .967 .646 r
.51023 .41624 .51353 .41343 .51952 .40646 .51625 .40741 Metetra
.915 .977 .769 r
.51625 .40741 .51952 .40646 .52551 .40026 .52226 .39925 Metetra
.891 .914 .833 r
.52226 .39925 .52551 .40026 .5315 .3951 .52826 .39246 Metetra
.822 .83 .855 r
.52826 .39246 .5315 .3951 .53749 .391 .53426 .38727 Metetra
.752 .763 .862 r
.53426 .38727 .53749 .391 .54349 .38782 .54027 .38351 Metetra
.699 .72 .866 r
.54027 .38351 .54349 .38782 .54951 .38531 .54629 .3808 Metetra
.667 .699 .871 r
.54629 .3808 .54951 .38531 .55554 .38323 .55233 .37869 Metetra
.652 .693 .875 r
.55233 .37869 .55554 .38323 .56158 .38138 .55839 .37683 Metetra
.647 .691 .877 r
.55839 .37683 .56158 .38138 .56765 .37964 .56445 .37507 Metetra
.642 .688 .878 r
.56445 .37507 .56765 .37964 .57372 .37795 .57054 .37337 Metetra
.634 .685 .881 r
.57054 .37337 .57372 .37795 .57982 .37633 .57664 .37182 Metetra
.619 .683 .888 r
.57664 .37182 .57982 .37633 .58593 .37484 .58276 .3705 Metetra
.597 .683 .902 r
.58276 .3705 .58593 .37484 .59206 .37351 .5889 .36949 Metetra
.566 .688 .922 r
.5889 .36949 .59206 .37351 .59821 .37241 .59507 .36883 Metetra
.52 .695 .948 r
.59507 .36883 .59821 .37241 .60438 .37158 .60127 .36853 Metetra
.452 .701 .973 r
.60127 .36853 .60438 .37158 .61058 .37103 .60749 .3686 Metetra
.354 .697 .983 r
.60749 .3686 .61058 .37103 .61681 .37075 .61375 .36898 Metetra
.231 .675 .955 r
.61375 .36898 .61681 .37075 .62307 .37068 .62004 .36953 Metetra
.126 .643 .889 r
.62004 .36953 .62307 .37068 .62935 .37072 .62635 .37005 Metetra
.096 .641 .837 r
.62635 .37005 .62935 .37072 .63565 .3707 .63267 .37025 Metetra
.177 .706 .851 r
.63267 .37025 .63565 .3707 .64196 .37041 .63899 .36985 Metetra
.364 .822 .926 r
.63899 .36985 .64196 .37041 .64828 .36965 .64531 .36863 Metetra
.572 .902 .981 r
.64531 .36863 .64828 .36965 .65459 .36827 .6516 .36652 Metetra
.7 .895 .967 r
.6516 .36652 .65459 .36827 .66088 .36619 .65788 .36362 Metetra
.746 .847 .925 r
.65788 .36362 .66088 .36619 .66717 .3635 .66414 .36016 Metetra
.751 .8 .892 r
.66414 .36016 .66717 .3635 .67344 .36035 .6704 .3565 Metetra
.74 .768 .876 r
.6704 .3565 .67344 .36035 .67972 .35699 .67668 .35293 Metetra
.722 .752 .876 r
.67668 .35293 .67972 .35699 .686 .35368 .68298 .3497 Metetra
.702 .751 .889 r
.68298 .3497 .686 .35368 .69231 .35059 .68931 .34689 Metetra
.683 .76 .91 r
.68931 .34689 .69231 .35059 .69865 .34782 .69568 .34445 Metetra
.667 .776 .931 r
.69568 .34445 .69865 .34782 .70501 .34537 .70207 .34226 Metetra
.66 .791 .945 r
.70207 .34226 .70501 .34537 .7114 .34314 .70848 .34014 Metetra
.663 .8 .948 r
.70848 .34014 .7114 .34314 .71782 .34101 .7149 .33794 Metetra
.674 .8 .942 r
.7149 .33794 .71782 .34101 .72424 .33885 .72133 .3356 Metetra
.686 .792 .931 r
.72133 .3356 .72424 .33885 .73067 .33658 .72776 .33309 Metetra
.693 .78 .918 r
.72776 .33309 .73067 .33658 .73711 .33417 .73419 .33045 Metetra
.695 .767 .907 r
.73419 .33045 .73711 .33417 .74355 .33164 .74063 .32776 Metetra
.694 .758 .901 r
.74063 .32776 .74355 .33164 .75 .32904 .74709 .32508 Metetra
.69 .753 .9 r
.74709 .32508 .75 .32904 .75647 .32643 .75357 .32247 Metetra
.685 .751 .902 r
.75357 .32247 .75647 .32643 .76295 .32386 .76006 .31993 Metetra
.681 .752 .905 r
.76006 .31993 .76295 .32386 .76944 .32134 .76657 .31745 Metetra
.678 .754 .908 r
.76657 .31745 .76944 .32134 .77596 .31888 .7731 .31502 Metetra
.677 .756 .911 r
.7731 .31502 .77596 .31888 .78249 .31646 .77965 .31261 Metetra
.677 .757 .911 r
.77965 .31261 .78249 .31646 .78904 .31407 .78621 .31021 Metetra
.677 .757 .911 r
.78621 .31021 .78904 .31407 .79561 .31169 .79278 .30779 Metetra
.677 .755 .91 r
.79278 .30779 .79561 .31169 .80219 .3093 .79937 .30535 Metetra
.677 .753 .908 r
.79937 .30535 .80219 .3093 .80878 .3069 .80597 .30292 Metetra
.677 .751 .907 r
.80597 .30292 .80878 .3069 .81538 .30449 .81258 .30048 Metetra
.676 .75 .906 r
.81258 .30048 .81538 .30449 .822 .30208 .81921 .29805 Metetra
.676 .749 .906 r
.81921 .29805 .822 .30208 .82864 .29967 .82586 .29562 Metetra
.675 .749 .906 r
.82586 .29562 .82864 .29967 .83529 .29726 .83252 .29321 Metetra
.674 .748 .907 r
.83252 .29321 .83529 .29726 .84196 .29486 .8392 .29081 Metetra
.673 .748 .907 r
.8392 .29081 .84196 .29486 .84864 .29247 .8459 .28841 Metetra
.673 .748 .907 r
.8459 .28841 .84864 .29247 .85534 .29009 .8526 .28601 Metetra
.672 .748 .907 r
.8526 .28601 .85534 .29009 .86205 .28771 .85933 .28362 Metetra
.672 .748 .907 r
.85933 .28362 .86205 .28771 .86878 .28533 .86607 .28123 Metetra
.657 .74 .911 r
.26175 .47563 .26534 .47897 .27079 .47726 .26719 .47391 Metetra
.657 .74 .911 r
.26719 .47391 .27079 .47726 .27624 .47554 .27265 .47218 Metetra
.656 .74 .911 r
.27265 .47218 .27624 .47554 .2817 .47383 .27812 .47046 Metetra
.656 .739 .911 r
.27812 .47046 .2817 .47383 .28718 .47212 .28361 .46874 Metetra
.656 .739 .911 r
.28361 .46874 .28718 .47212 .29266 .47041 .2891 .46702 Metetra
.655 .739 .911 r
.2891 .46702 .29266 .47041 .29816 .46871 .2946 .4653 Metetra
.655 .738 .911 r
.2946 .4653 .29816 .46871 .30367 .467 .30012 .46359 Metetra
.654 .738 .911 r
.30012 .46359 .30367 .467 .30919 .46529 .30565 .46188 Metetra
.654 .738 .912 r
.30565 .46188 .30919 .46529 .31473 .46357 .31119 .46016 Metetra
.654 .739 .912 r
.31119 .46016 .31473 .46357 .32027 .46185 .31674 .45845 Metetra
.654 .74 .913 r
.31674 .45845 .32027 .46185 .32583 .46012 .3223 .45672 Metetra
.655 .741 .913 r
.3223 .45672 .32583 .46012 .3314 .4584 .32788 .45499 Metetra
.654 .74 .913 r
.32788 .45499 .3314 .4584 .33698 .45671 .33347 .45326 Metetra
.653 .738 .912 r
.33347 .45326 .33698 .45671 .34257 .45505 .33907 .45154 Metetra
.65 .735 .911 r
.33907 .45154 .34257 .45505 .34817 .45342 .34468 .44986 Metetra
.647 .731 .91 r
.34468 .44986 .34817 .45342 .35378 .45182 .3503 .44822 Metetra
.645 .728 .909 r
.3503 .44822 .35378 .45182 .35941 .4502 .35593 .44661 Metetra
.644 .729 .91 r
.35593 .44661 .35941 .4502 .36505 .44852 .36157 .445 Metetra
.646 .734 .913 r
.36157 .445 .36505 .44852 .3707 .44677 .36723 .44337 Metetra
.65 .743 .917 r
.36723 .44337 .3707 .44677 .37637 .44495 .3729 .44166 Metetra
.656 .752 .921 r
.3729 .44166 .37637 .44495 .38206 .4431 .37859 .43987 Metetra
.659 .757 .922 r
.37859 .43987 .38206 .4431 .38775 .44133 .3843 .43803 Metetra
.657 .752 .92 r
.3843 .43803 .38775 .44133 .39345 .43974 .39002 .43621 Metetra
.648 .736 .913 r
.39002 .43621 .39345 .43974 .39915 .43841 .39574 .43452 Metetra
.632 .711 .903 r
.39574 .43452 .39915 .43841 .40486 .43733 .40146 .43307 Metetra
.614 .685 .893 r
.40146 .43307 .40486 .43733 .41058 .43635 .4072 .43189 Metetra
.602 .671 .888 r
.4072 .43189 .41058 .43635 .41632 .43524 .41293 .4309 Metetra
.603 .677 .893 r
.41293 .4309 .41632 .43524 .42208 .43375 .41869 .42988 Metetra
.62 .71 .91 r
.41869 .42988 .42208 .43375 .42788 .43169 .42447 .42858 Metetra
.652 .767 .933 r
.42447 .42858 .42788 .43169 .4337 .42911 .43028 .42679 Metetra
.687 .828 .951 r
.43028 .42679 .4337 .42911 .43954 .42635 .43611 .42445 Metetra
.705 .863 .957 r
.43611 .42445 .43954 .42635 .44538 .42397 .44197 .4218 Metetra
.695 .842 .954 r
.44197 .4218 .44538 .42397 .4512 .42263 .44783 .41933 Metetra
.642 .753 .929 r
.44783 .41933 .4512 .42263 .45701 .42289 .45368 .41767 Metetra
.557 .617 .868 r
.45368 .41767 .45701 .42289 .4628 .4249 .45952 .41737 Metetra
.477 .495 .798 r
.45952 .41737 .4628 .4249 .46859 .42831 .46535 .41872 Metetra
.425 .418 .748 r
.46535 .41872 .46859 .42831 .47441 .43227 .47118 .4215 Metetra
.405 .386 .725 r
.47118 .4215 .47441 .43227 .48027 .43558 .47703 .42506 Metetra
.414 .396 .73 r
.47703 .42506 .48027 .43558 .48619 .43702 .48291 .42837 Metetra
.456 .457 .771 r
.48291 .42837 .48619 .43702 .49216 .43574 .48884 .43036 Metetra
.549 .61 .866 r
.48884 .43036 .49216 .43574 .49817 .43147 .49482 .43018 Metetra
.683 .908 .974 r
.49482 .43018 .49817 .43147 .5042 .42465 .50084 .42749 Metetra
.50084 .42749 .5042 .42465 .51023 .41624 .50688 .42246 Metetra
.50688 .42246 .51023 .41624 .51625 .40741 .51293 .41573 Metetra
0 0 .05 r
.51293 .41573 .51625 .40741 .52226 .39925 .51897 .40813 Metetra
.029 0 .091 r
.51897 .40813 .52226 .39925 .52826 .39246 .52501 .4005 Metetra
.02 0 .06 r
.52501 .4005 .52826 .39246 .53426 .38727 .53104 .39346 Metetra
.53104 .39346 .53426 .38727 .54027 .38351 .53707 .38737 Metetra
.53707 .38737 .54027 .38351 .54629 .3808 .54311 .38236 Metetra
.496 .883 .704 r
.54311 .38236 .54629 .3808 .55233 .37869 .54915 .37839 Metetra
.646 .954 .941 r
.54915 .37839 .55233 .37869 .55839 .37683 .55521 .37534 Metetra
.647 .89 .984 r
.55521 .37534 .55839 .37683 .56445 .37507 .56128 .37304 Metetra
.61 .841 .987 r
.56128 .37304 .56445 .37507 .57054 .37337 .56738 .37132 Metetra
.56 .822 .995 r
.56738 .37132 .57054 .37337 .57664 .37182 .57349 .37004 Metetra
.494 .815 1 r
.57349 .37004 .57664 .37182 .58276 .3705 .57963 .36909 Metetra
.406 .799 .987 r
.57963 .36909 .58276 .3705 .5889 .36949 .5858 .36842 Metetra
.299 .76 .948 r
.5858 .36842 .5889 .36949 .59507 .36883 .59198 .36803 Metetra
.18 .697 .886 r
.59198 .36803 .59507 .36883 .60127 .36853 .5982 .36796 Metetra
.064 .621 .811 r
.5982 .36796 .60127 .36853 .60749 .3686 .60444 .36821 Metetra
0 .554 .742 r
.60444 .36821 .60749 .3686 .61375 .36898 .61072 .3687 Metetra
0 .53 .71 r
.61072 .3687 .61375 .36898 .62004 .36953 .61702 .36923 Metetra
.003 .578 .747 r
.61702 .36923 .62004 .36953 .62635 .37005 .62333 .36951 Metetra
.177 .704 .861 r
.62333 .36951 .62635 .37005 .63267 .37025 .62965 .3692 Metetra
.429 .835 .974 r
.62965 .3692 .63267 .37025 .63899 .36985 .63596 .36806 Metetra
.625 .87 .988 r
.63596 .36806 .63899 .36985 .64531 .36863 .64226 .36599 Metetra
.713 .834 .94 r
.64226 .36599 .64531 .36863 .6516 .36652 .64853 .36309 Metetra
.74 .791 .894 r
.64853 .36309 .6516 .36652 .65788 .36362 .6548 .35963 Metetra
.742 .762 .869 r
.6548 .35963 .65788 .36362 .66414 .36016 .66107 .35597 Metetra
.734 .749 .864 r
.66107 .35597 .66414 .36016 .6704 .3565 .66735 .35243 Metetra
.72 .752 .877 r
.66735 .35243 .6704 .3565 .67668 .35293 .67365 .34922 Metetra
.703 .766 .901 r
.67365 .34922 .67668 .35293 .68298 .3497 .67998 .34643 Metetra
.683 .788 .929 r
.67998 .34643 .68298 .3497 .68931 .34689 .68635 .34399 Metetra
.667 .808 .95 r
.68635 .34399 .68931 .34689 .69568 .34445 .69273 .34173 Metetra
.663 .82 .959 r
.69273 .34173 .69568 .34445 .70207 .34226 .69914 .3395 Metetra
.671 .82 .955 r
.69914 .3395 .70207 .34226 .70848 .34014 .70555 .33715 Metetra
.685 .809 .942 r
.70555 .33715 .70848 .34014 .7149 .33794 .71196 .33465 Metetra
.695 .793 .925 r
.71196 .33465 .7149 .33794 .72133 .3356 .71838 .33199 Metetra
.699 .775 .91 r
.71838 .33199 .72133 .3356 .72776 .33309 .72481 .32924 Metetra
.698 .762 .901 r
.72481 .32924 .72776 .33309 .73419 .33045 .73124 .32648 Metetra
.695 .754 .897 r
.73124 .32648 .73419 .33045 .74063 .32776 .7377 .32377 Metetra
.69 .751 .898 r
.7377 .32377 .74063 .32776 .74709 .32508 .74417 .32113 Metetra
.686 .752 .902 r
.74417 .32113 .74709 .32508 .75357 .32247 .75066 .31858 Metetra
.682 .755 .907 r
.75066 .31858 .75357 .32247 .76006 .31993 .75717 .31609 Metetra
.68 .758 .91 r
.75717 .31609 .76006 .31993 .76657 .31745 .76369 .31364 Metetra
.679 .76 .912 r
.76369 .31364 .76657 .31745 .7731 .31502 .77023 .3112 Metetra
.679 .759 .912 r
.77023 .3112 .7731 .31502 .77965 .31261 .77679 .30875 Metetra
.679 .758 .91 r
.77679 .30875 .77965 .31261 .78621 .31021 .78336 .30629 Metetra
.679 .755 .909 r
.78336 .30629 .78621 .31021 .79278 .30779 .78994 .30382 Metetra
.679 .753 .907 r
.78994 .30382 .79278 .30779 .79937 .30535 .79653 .30135 Metetra
.678 .751 .906 r
.79653 .30135 .79937 .30535 .80597 .30292 .80314 .29889 Metetra
.677 .75 .906 r
.80314 .29889 .80597 .30292 .81258 .30048 .80977 .29644 Metetra
.676 .749 .906 r
.80977 .29644 .81258 .30048 .81921 .29805 .81641 .294 Metetra
.675 .749 .906 r
.81641 .294 .81921 .29805 .82586 .29562 .82307 .29157 Metetra
.675 .749 .907 r
.82307 .29157 .82586 .29562 .83252 .29321 .82974 .28915 Metetra
.674 .749 .907 r
.82974 .28915 .83252 .29321 .8392 .29081 .83643 .28674 Metetra
.673 .749 .907 r
.83643 .28674 .8392 .29081 .8459 .28841 .84314 .28433 Metetra
.673 .748 .907 r
.84314 .28433 .8459 .28841 .8526 .28601 .84986 .28192 Metetra
.673 .748 .907 r
.84986 .28192 .8526 .28601 .85933 .28362 .85659 .27951 Metetra
.672 .747 .907 r
.85659 .27951 .85933 .28362 .86607 .28123 .86335 .2771 Metetra
.657 .74 .911 r
.25813 .47227 .26175 .47563 .26719 .47391 .26359 .47054 Metetra
.657 .74 .911 r
.26359 .47054 .26719 .47391 .27265 .47218 .26905 .46881 Metetra
.656 .74 .911 r
.26905 .46881 .27265 .47218 .27812 .47046 .27453 .46708 Metetra
.656 .74 .911 r
.27453 .46708 .27812 .47046 .28361 .46874 .28002 .46535 Metetra
.656 .74 .911 r
.28002 .46535 .28361 .46874 .2891 .46702 .28552 .46362 Metetra
.656 .739 .911 r
.28552 .46362 .2891 .46702 .2946 .4653 .29103 .46189 Metetra
.655 .739 .911 r
.29103 .46189 .2946 .4653 .30012 .46359 .29656 .46016 Metetra
.654 .738 .911 r
.29656 .46016 .30012 .46359 .30565 .46188 .30209 .45844 Metetra
.654 .738 .911 r
.30209 .45844 .30565 .46188 .31119 .46016 .30764 .45673 Metetra
.653 .738 .912 r
.30764 .45673 .31119 .46016 .31674 .45845 .3132 .45502 Metetra
.653 .739 .912 r
.3132 .45502 .31674 .45845 .3223 .45672 .31877 .4533 Metetra
.653 .74 .913 r
.31877 .4533 .3223 .45672 .32788 .45499 .32435 .45158 Metetra
.654 .741 .914 r
.32435 .45158 .32788 .45499 .33347 .45326 .32994 .44984 Metetra
.654 .741 .914 r
.32994 .44984 .33347 .45326 .33907 .45154 .33555 .4481 Metetra
.654 .74 .913 r
.33555 .4481 .33907 .45154 .34468 .44986 .34117 .44636 Metetra
.652 .736 .911 r
.34117 .44636 .34468 .44986 .3503 .44822 .3468 .44464 Metetra
.649 .731 .91 r
.3468 .44464 .3503 .44822 .35593 .44661 .35244 .44297 Metetra
.645 .727 .909 r
.35244 .44297 .35593 .44661 .36157 .445 .35809 .44135 Metetra
.642 .726 .909 r
.35809 .44135 .36157 .445 .36723 .44337 .36375 .43977 Metetra
.641 .729 .913 r
.36375 .43977 .36723 .44337 .3729 .44166 .36943 .4382 Metetra
.644 .738 .918 r
.36943 .4382 .3729 .44166 .37859 .43987 .37512 .43658 Metetra
.65 .751 .923 r
.37512 .43658 .37859 .43987 .3843 .43803 .38083 .43485 Metetra
.658 .761 .926 r
.38083 .43485 .3843 .43803 .39002 .43621 .38655 .43301 Metetra
.663 .762 .924 r
.38655 .43301 .39002 .43621 .39574 .43452 .39229 .4311 Metetra
.66 .747 .915 r
.39229 .4311 .39574 .43452 .40146 .43307 .39804 .42924 Metetra
.646 .719 .902 r
.39804 .42924 .40146 .43307 .4072 .43189 .40379 .42757 Metetra
.625 .686 .888 r
.40379 .42757 .4072 .43189 .41293 .4309 .40955 .42623 Metetra
.601 .661 .88 r
.40955 .42623 .41293 .4309 .41869 .42988 .41531 .42525 Metetra
.585 .656 .886 r
.41531 .42525 .41869 .42988 .42447 .42858 .42108 .4245 Metetra
.583 .684 .911 r
.42108 .4245 .42447 .42858 .43028 .42679 .42686 .4237 Metetra
.602 .754 .95 r
.42686 .4237 .43028 .42679 .43611 .42445 .43268 .42249 Metetra
.642 .846 .978 r
.43268 .42249 .43611 .42445 .44197 .4218 .43852 .42056 Metetra
.689 .907 .972 r
.43852 .42056 .44197 .4218 .44783 .41933 .4444 .41788 Metetra
.732 .899 .954 r
.4444 .41788 .44783 .41933 .45368 .41767 .4503 .41476 Metetra
.719 .799 .914 r
.4503 .41476 .45368 .41767 .45952 .41737 .4562 .41192 Metetra
.639 .645 .841 r
.4562 .41192 .45952 .41737 .46535 .41872 .46209 .41027 Metetra
.538 .509 .771 r
.46209 .41027 .46535 .41872 .47118 .4215 .46796 .41065 Metetra
.441 .408 .725 r
.46796 .41065 .47118 .4215 .47703 .42506 .4738 .41349 Metetra
.34 .332 .705 r
.4738 .41349 .47703 .42506 .48291 .42837 .47965 .41854 Metetra
.197 .268 .711 r
.47965 .41854 .48291 .42837 .48884 .43036 .48552 .42479 Metetra
0 .176 .712 r
.48552 .42479 .48884 .43036 .49482 .43018 .49144 .43064 Metetra
.608 .055 0 r
.49144 .43064 .49482 .43018 .50084 .42749 .49742 .4343 Metetra
.477 .089 .223 r
.49742 .4343 .50084 .42749 .50688 .42246 .50346 .4343 Metetra
.352 .041 .291 r
.50346 .4343 .50688 .42246 .51293 .41573 .50954 .42997 Metetra
.23 0 .278 r
.50954 .42997 .51293 .41573 .51897 .40813 .51564 .42168 Metetra
.067 0 .204 r
.51564 .42168 .51897 .40813 .52501 .4005 .52172 .41071 Metetra
0 0 .016 r
.52172 .41071 .52501 .4005 .53104 .39346 .52779 .39885 Metetra
.683 .831 .398 r
.52779 .39885 .53104 .39346 .53707 .38737 .53384 .38788 Metetra
.934 .958 .765 r
.53384 .38788 .53707 .38737 .54311 .38236 .53987 .3791 Metetra
.832 .8 .82 r
.53987 .3791 .54311 .38236 .54915 .37839 .54591 .37307 Metetra
.716 .686 .82 r
.54591 .37307 .54915 .37839 .55521 .37534 .55197 .36961 Metetra
.63 .636 .837 r
.55197 .36961 .55521 .37534 .56128 .37304 .55806 .36807 Metetra
.563 .637 .882 r
.55806 .36807 .56128 .37304 .56738 .37132 .56418 .36761 Metetra
.499 .677 .945 r
.56418 .36761 .56738 .37132 .57349 .37004 .57032 .36756 Metetra
.41 .723 .989 r
.57032 .36756 .57349 .37004 .57963 .36909 .57649 .36759 Metetra
.267 .716 .958 r
.57649 .36759 .57963 .36909 .5858 .36842 .58268 .36772 Metetra
.055 .61 .819 r
.58268 .36772 .5858 .36842 .59198 .36803 .58889 .36813 Metetra
.184 0 0 r
.58889 .36813 .59198 .36803 .5982 .36796 .59514 .36895 Metetra
.359 0 0 r
.59514 .36895 .5982 .36796 .60444 .36821 .60143 .37013 Metetra
.431 0 0 r
.60143 .37013 .60444 .36821 .61072 .3687 .60774 .37133 Metetra
.421 0 0 r
.60774 .37133 .61072 .3687 .61702 .36923 .61406 .37206 Metetra
.333 0 0 r
.61406 .37206 .61702 .36923 .62333 .36951 .62038 .37182 Metetra
.116 0 0 r
.62038 .37182 .62333 .36951 .62965 .3692 .62668 .3703 Metetra
.331 .798 .696 r
.62668 .3703 .62965 .3692 .63596 .36806 .63296 .36752 Metetra
.715 .968 .935 r
.63296 .36752 .63596 .36806 .64226 .36599 .63921 .36378 Metetra
.787 .877 .913 r
.63921 .36378 .64226 .36599 .64853 .36309 .64545 .35957 Metetra
.77 .793 .872 r
.64545 .35957 .64853 .36309 .6548 .35963 .6517 .35539 Metetra
.741 .749 .858 r
.6517 .35539 .6548 .35963 .66107 .35597 .65797 .35165 Metetra
.715 .737 .869 r
.65797 .35165 .66107 .35597 .66735 .35243 .66428 .34849 Metetra
.691 .75 .897 r
.66428 .34849 .66735 .35243 .67365 .34922 .67062 .34588 Metetra
.671 .779 .931 r
.67062 .34588 .67365 .34922 .67998 .34643 .677 .34362 Metetra
.66 .811 .956 r
.677 .34362 .67998 .34643 .68635 .34399 .68339 .34145 Metetra
.663 .833 .965 r
.68339 .34145 .68635 .34399 .69273 .34173 .68978 .33916 Metetra
.68 .837 .958 r
.68978 .33916 .69273 .34173 .69914 .3395 .69619 .33666 Metetra
.699 .824 .942 r
.69619 .33666 .69914 .3395 .70555 .33715 .70259 .33393 Metetra
.708 .802 .923 r
.70259 .33393 .70555 .33715 .71196 .33465 .70899 .33104 Metetra
.709 .779 .907 r
.70899 .33104 .71196 .33465 .71838 .33199 .71541 .32812 Metetra
.704 .762 .897 r
.71541 .32812 .71838 .33199 .72481 .32924 .72184 .32524 Metetra
.697 .753 .895 r
.72184 .32524 .72481 .32924 .73124 .32648 .72828 .32247 Metetra
.691 .751 .897 r
.72828 .32247 .73124 .32648 .7377 .32377 .73475 .31982 Metetra
.685 .753 .903 r
.73475 .31982 .7377 .32377 .74417 .32113 .74124 .31726 Metetra
.682 .757 .908 r
.74124 .31726 .74417 .32113 .75066 .31858 .74775 .31477 Metetra
.681 .76 .911 r
.74775 .31477 .75066 .31858 .75717 .31609 .75427 .31229 Metetra
.681 .762 .912 r
.75427 .31229 .75717 .31609 .76369 .31364 .7608 .30981 Metetra
.681 .761 .911 r
.7608 .30981 .76369 .31364 .77023 .3112 .76735 .30732 Metetra
.682 .759 .909 r
.76735 .30732 .77023 .3112 .77679 .30875 .77391 .30481 Metetra
.682 .756 .907 r
.77391 .30481 .77679 .30875 .78336 .30629 .78049 .3023 Metetra
.681 .753 .906 r
.78049 .3023 .78336 .30629 .78994 .30382 .78708 .2998 Metetra
.679 .751 .905 r
.78708 .2998 .78994 .30382 .79653 .30135 .79368 .29731 Metetra
.678 .75 .905 r
.79368 .29731 .79653 .30135 .80314 .29889 .80031 .29484 Metetra
.677 .749 .906 r
.80031 .29484 .80314 .29889 .80977 .29644 .80694 .29238 Metetra
.676 .749 .906 r
.80694 .29238 .80977 .29644 .81641 .294 .8136 .28994 Metetra
.675 .749 .907 r
.8136 .28994 .81641 .294 .82307 .29157 .82027 .28751 Metetra
.675 .749 .907 r
.82027 .28751 .82307 .29157 .82974 .28915 .82695 .28507 Metetra
.674 .749 .907 r
.82695 .28507 .82974 .28915 .83643 .28674 .83365 .28265 Metetra
.674 .749 .907 r
.83365 .28265 .83643 .28674 .84314 .28433 .84037 .28022 Metetra
.673 .748 .907 r
.84037 .28022 .84314 .28433 .84986 .28192 .8471 .2778 Metetra
.673 .748 .907 r
.8471 .2778 .84986 .28192 .85659 .27951 .85385 .27537 Metetra
.672 .747 .907 r
.85385 .27537 .85659 .27951 .86335 .2771 .86061 .27295 Metetra
.657 .74 .911 r
.25451 .4689 .25813 .47227 .26359 .47054 .25997 .46716 Metetra
.657 .74 .911 r
.25997 .46716 .26359 .47054 .26905 .46881 .26544 .46543 Metetra
.656 .74 .911 r
.26544 .46543 .26905 .46881 .27453 .46708 .27093 .46369 Metetra
.656 .74 .911 r
.27093 .46369 .27453 .46708 .28002 .46535 .27642 .46195 Metetra
.656 .74 .911 r
.27642 .46195 .28002 .46535 .28552 .46362 .28193 .46021 Metetra
.656 .74 .912 r
.28193 .46021 .28552 .46362 .29103 .46189 .28745 .45847 Metetra
.655 .739 .912 r
.28745 .45847 .29103 .46189 .29656 .46016 .29298 .45673 Metetra
.655 .739 .912 r
.29298 .45673 .29656 .46016 .30209 .45844 .29852 .455 Metetra
.654 .738 .912 r
.29852 .455 .30209 .45844 .30764 .45673 .30407 .45327 Metetra
.653 .738 .912 r
.30407 .45327 .30764 .45673 .3132 .45502 .30964 .45155 Metetra
.653 .738 .912 r
.30964 .45155 .3132 .45502 .31877 .4533 .31521 .44984 Metetra
.652 .738 .912 r
.31521 .44984 .31877 .4533 .32435 .45158 .3208 .44812 Metetra
.653 .739 .913 r
.3208 .44812 .32435 .45158 .32994 .44984 .3264 .4464 Metetra
.653 .74 .913 r
.3264 .4464 .32994 .44984 .33555 .4481 .33202 .44466 Metetra
.654 .741 .914 r
.33202 .44466 .33555 .4481 .34117 .44636 .33765 .44291 Metetra
.654 .741 .914 r
.33765 .44291 .34117 .44636 .3468 .44464 .34329 .44116 Metetra
.652 .739 .913 r
.34329 .44116 .3468 .44464 .35244 .44297 .34894 .43943 Metetra
.649 .735 .912 r
.34894 .43943 .35244 .44297 .35809 .44135 .3546 .43774 Metetra
.645 .73 .911 r
.3546 .43774 .35809 .44135 .36375 .43977 .36027 .43611 Metetra
.641 .726 .91 r
.36027 .43611 .36375 .43977 .36943 .4382 .36595 .43453 Metetra
.639 .726 .911 r
.36595 .43453 .36943 .4382 .37512 .43658 .37164 .43298 Metetra
.641 .731 .914 r
.37164 .43298 .37512 .43658 .38083 .43485 .37735 .43139 Metetra
.648 .741 .918 r
.37735 .43139 .38083 .43485 .38655 .43301 .38307 .4297 Metetra
.657 .753 .921 r
.38307 .4297 .38655 .43301 .39229 .4311 .38882 .42787 Metetra
.663 .761 .922 r
.38882 .42787 .39229 .4311 .39804 .42924 .39458 .42593 Metetra
.662 .757 .92 r
.39458 .42593 .39804 .42924 .40379 .42757 .40035 .42401 Metetra
.649 .738 .914 r
.40035 .42401 .40379 .42757 .40955 .42623 .40613 .42229 Metetra
.625 .708 .906 r
.40613 .42229 .40955 .42623 .41531 .42525 .41191 .42091 Metetra
.597 .677 .897 r
.41191 .42091 .41531 .42525 .42108 .4245 .41769 .41996 Metetra
.576 .658 .893 r
.41769 .41996 .42108 .4245 .42686 .4237 .42347 .4193 Metetra
.576 .666 .899 r
.42347 .4193 .42686 .4237 .43268 .42249 .42927 .41862 Metetra
.605 .707 .916 r
.42927 .41862 .43268 .42249 .43852 .42056 .43511 .41749 Metetra
.66 .774 .934 r
.43511 .41749 .43852 .42056 .4444 .41788 .44098 .41556 Metetra
.717 .838 .939 r
.44098 .41556 .4444 .41788 .4503 .41476 .44688 .41276 Metetra
.747 .863 .933 r
.44688 .41276 .4503 .41476 .4562 .41192 .4528 .40947 Metetra
.726 .831 .93 r
.4528 .40947 .4562 .41192 .46209 .41027 .45873 .40653 Metetra
.636 .727 .914 r
.45873 .40653 .46209 .41027 .46796 .41065 .46463 .40496 Metetra
.487 .565 .86 r
.46463 .40496 .46796 .41065 .4738 .41349 .47052 .40566 Metetra
.34 .408 .786 r
.47052 .40566 .4738 .41349 .47965 .41854 .47638 .40896 Metetra
.249 .307 .728 r
.47638 .40896 .47965 .41854 .48552 .42479 .48226 .41436 Metetra
.231 .28 .707 r
.48226 .41436 .48552 .42479 .49144 .43064 .48816 .42052 Metetra
.296 .329 .726 r
.48816 .42052 .49144 .43064 .49742 .4343 .49412 .42559 Metetra
.443 .45 .772 r
.49412 .42559 .49742 .4343 .50346 .4343 .50014 .42779 Metetra
.638 .615 .81 r
.50014 .42779 .50346 .4343 .50954 .42997 .50621 .42598 Metetra
.81 .763 .809 r
.50621 .42598 .50954 .42997 .51564 .42168 .51231 .42013 Metetra
.915 .865 .776 r
.51231 .42013 .51564 .42168 .52172 .41071 .51841 .41123 Metetra
.953 .933 .735 r
.51841 .41123 .52172 .41071 .52779 .39885 .52451 .40099 Metetra
.916 .972 .684 r
.52451 .40099 .52779 .39885 .53384 .38788 .53058 .39113 Metetra
.736 .926 .578 r
.53058 .39113 .53384 .38788 .53987 .3791 .53665 .38291 Metetra
.53665 .38291 .53987 .3791 .54591 .37307 .54272 .37681 Metetra
.54272 .37681 .54591 .37307 .55197 .36961 .5488 .37258 Metetra
.5488 .37258 .55197 .36961 .55806 .36807 .55489 .36962 Metetra
.55489 .36962 .55806 .36807 .56418 .36761 .56101 .36734 Metetra
.452 .877 .923 r
.56101 .36734 .56418 .36761 .57032 .36756 .56714 .36546 Metetra
.565 .822 .994 r
.56714 .36546 .57032 .36756 .57649 .36759 .5733 .36414 Metetra
.527 .709 .954 r
.5733 .36414 .57649 .36759 .58268 .36772 .57948 .36371 Metetra
.425 .623 .935 r
.57948 .36371 .58268 .36772 .58889 .36813 .58571 .36445 Metetra
.255 .551 .929 r
.58571 .36445 .58889 .36813 .59514 .36895 .59199 .36629 Metetra
.01 .462 .87 r
.59199 .36629 .59514 .36895 .60143 .37013 .59831 .36875 Metetra
0 .383 .721 r
.59831 .36875 .60143 .37013 .60774 .37133 .60466 .37102 Metetra
.183 0 0 r
.60466 .37102 .60774 .37133 .61406 .37206 .61101 .37223 Metetra
.054 .62 .713 r
.61101 .37223 .61406 .37206 .62038 .37182 .61734 .37181 Metetra
.449 .881 .888 r
.61734 .37181 .62038 .37182 .62668 .3703 .62364 .36959 Metetra
.723 .961 .943 r
.62364 .36959 .62668 .3703 .63296 .36752 .6299 .36589 Metetra
.804 .916 .914 r
.6299 .36589 .63296 .36752 .63921 .36378 .63614 .36134 Metetra
.806 .864 .891 r
.63614 .36134 .63921 .36378 .64545 .35957 .64238 .35666 Metetra
.783 .833 .891 r
.64238 .35666 .64545 .35957 .6517 .35539 .64864 .35239 Metetra
.75 .822 .908 r
.64864 .35239 .6517 .35539 .65797 .35165 .65493 .3488 Metetra
.712 .824 .934 r
.65493 .3488 .65797 .35165 .66428 .34849 .66126 .34589 Metetra
.68 .833 .957 r
.66126 .34589 .66428 .34849 .67062 .34588 .66762 .34342 Metetra
.665 .839 .967 r
.66762 .34342 .67062 .34588 .677 .34362 .67401 .3411 Metetra
.673 .838 .963 r
.67401 .3411 .677 .34362 .68339 .34145 .6804 .33869 Metetra
.692 .827 .948 r
.6804 .33869 .68339 .34145 .68978 .33916 .68679 .33604 Metetra
.708 .808 .927 r
.68679 .33604 .68978 .33916 .69619 .33666 .69319 .33317 Metetra
.715 .787 .909 r
.69319 .33317 .69619 .33666 .70259 .33393 .69958 .33016 Metetra
.714 .771 .897 r
.69958 .33016 .70259 .33393 .70899 .33104 .70599 .32712 Metetra
.708 .761 .893 r
.70599 .32712 .70899 .33104 .71541 .32812 .71241 .32415 Metetra
.701 .757 .895 r
.71241 .32415 .71541 .32812 .72184 .32524 .71886 .32132 Metetra
.694 .758 .901 r
.71886 .32132 .72184 .32524 .72828 .32247 .72532 .31862 Metetra
.688 .76 .907 r
.72532 .31862 .72828 .32247 .73475 .31982 .73181 .31602 Metetra
.685 .763 .911 r
.73181 .31602 .73475 .31982 .74124 .31726 .73831 .31349 Metetra
.683 .764 .912 r
.73831 .31349 .74124 .31726 .74775 .31477 .74482 .31096 Metetra
.684 .763 .912 r
.74482 .31096 .74775 .31477 .75427 .31229 .75135 .30844 Metetra
.684 .76 .909 r
.75135 .30844 .75427 .31229 .7608 .30981 .7579 .30589 Metetra
.684 .757 .907 r
.7579 .30589 .7608 .30981 .76735 .30732 .76445 .30334 Metetra
.683 .754 .905 r
.76445 .30334 .76735 .30732 .77391 .30481 .77102 .30079 Metetra
.682 .752 .904 r
.77102 .30079 .77391 .30481 .78049 .3023 .77761 .29826 Metetra
.681 .751 .904 r
.77761 .29826 .78049 .3023 .78708 .2998 .78421 .29575 Metetra
.679 .75 .905 r
.78421 .29575 .78708 .2998 .79368 .29731 .79083 .29326 Metetra
.678 .75 .906 r
.79083 .29326 .79368 .29731 .80031 .29484 .79746 .29078 Metetra
.677 .75 .906 r
.79746 .29078 .80031 .29484 .80694 .29238 .80411 .28832 Metetra
.676 .75 .907 r
.80411 .28832 .80694 .29238 .8136 .28994 .81077 .28587 Metetra
.675 .75 .907 r
.81077 .28587 .8136 .28994 .82027 .28751 .81745 .28342 Metetra
.675 .749 .907 r
.81745 .28342 .82027 .28751 .82695 .28507 .82415 .28097 Metetra
.674 .749 .907 r
.82415 .28097 .82695 .28507 .83365 .28265 .83086 .27853 Metetra
.674 .748 .906 r
.83086 .27853 .83365 .28265 .84037 .28022 .83759 .27609 Metetra
.674 .748 .906 r
.83759 .27609 .84037 .28022 .8471 .2778 .84433 .27365 Metetra
.673 .747 .906 r
.84433 .27365 .8471 .2778 .85385 .27537 .85109 .27121 Metetra
.673 .747 .907 r
.85109 .27121 .85385 .27537 .86061 .27295 .85786 .26878 Metetra
.657 .74 .911 r
.25087 .46551 .25451 .4689 .25997 .46716 .25634 .46377 Metetra
.657 .74 .911 r
.25634 .46377 .25997 .46716 .26544 .46543 .26182 .46203 Metetra
.656 .74 .911 r
.26182 .46203 .26544 .46543 .27093 .46369 .26731 .46028 Metetra
.656 .74 .911 r
.26731 .46028 .27093 .46369 .27642 .46195 .27281 .45854 Metetra
.656 .74 .911 r
.27281 .45854 .27642 .46195 .28193 .46021 .27832 .4568 Metetra
.656 .74 .912 r
.27832 .4568 .28193 .46021 .28745 .45847 .28385 .45505 Metetra
.655 .74 .912 r
.28385 .45505 .28745 .45847 .29298 .45673 .28938 .45331 Metetra
.655 .74 .912 r
.28938 .45331 .29298 .45673 .29852 .455 .29493 .45156 Metetra
.655 .739 .912 r
.29493 .45156 .29852 .455 .30407 .45327 .30049 .44982 Metetra
.654 .739 .912 r
.30049 .44982 .30407 .45327 .30964 .45155 .30607 .44808 Metetra
.653 .738 .911 r
.30607 .44808 .30964 .45155 .31521 .44984 .31165 .44634 Metetra
.653 .737 .911 r
.31165 .44634 .31521 .44984 .3208 .44812 .31725 .44462 Metetra
.652 .737 .912 r
.31725 .44462 .3208 .44812 .3264 .4464 .32285 .4429 Metetra
.651 .737 .912 r
.32285 .4429 .3264 .4464 .33202 .44466 .32847 .44119 Metetra
.651 .739 .914 r
.32847 .44119 .33202 .44466 .33765 .44291 .33411 .43947 Metetra
.652 .741 .915 r
.33411 .43947 .33765 .44291 .34329 .44116 .33975 .43773 Metetra
.653 .743 .916 r
.33975 .43773 .34329 .44116 .34894 .43943 .34541 .43598 Metetra
.653 .743 .916 r
.34541 .43598 .34894 .43943 .3546 .43774 .35108 .43423 Metetra
.651 .739 .914 r
.35108 .43423 .3546 .43774 .36027 .43611 .35676 .4325 Metetra
.648 .732 .91 r
.35676 .4325 .36027 .43611 .36595 .43453 .36246 .4308 Metetra
.644 .725 .907 r
.36246 .4308 .36595 .43453 .37164 .43298 .36816 .42917 Metetra
.64 .719 .905 r
.36816 .42917 .37164 .43298 .37735 .43139 .37387 .4276 Metetra
.637 .72 .907 r
.37387 .4276 .37735 .43139 .38307 .4297 .3796 .42606 Metetra
.638 .729 .914 r
.3796 .42606 .38307 .4297 .38882 .42787 .38534 .42449 Metetra
.642 .747 .925 r
.38534 .42449 .38882 .42787 .39458 .42593 .3911 .42285 Metetra
.65 .768 .935 r
.3911 .42285 .39458 .42593 .40035 .42401 .39687 .42108 Metetra
.656 .78 .94 r
.39687 .42108 .40035 .42401 .40613 .42229 .40266 .41921 Metetra
.658 .771 .933 r
.40266 .41921 .40613 .42229 .41191 .42091 .40847 .41732 Metetra
.649 .738 .914 r
.40847 .41732 .41191 .42091 .41769 .41996 .41428 .41558 Metetra
.63 .688 .886 r
.41428 .41558 .41769 .41996 .42347 .4193 .42009 .41413 Metetra
.607 .643 .86 r
.42009 .41413 .42347 .4193 .42927 .41862 .42591 .41306 Metetra
.587 .619 .85 r
.42591 .41306 .42927 .41862 .43511 .41749 .43174 .41231 Metetra
.58 .631 .867 r
.43174 .41231 .43511 .41749 .44098 .41556 .43758 .41165 Metetra
.587 .7 .92 r
.43758 .41165 .44098 .41556 .44688 .41276 .44344 .41073 Metetra
.596 .831 .989 r
.44344 .41073 .44688 .41276 .4528 .40947 .44933 .40921 Metetra
.551 .918 .946 r
.44933 .40921 .4528 .40947 .45873 .40653 .45526 .40693 Metetra
.548 .93 .883 r
.45526 .40693 .45873 .40653 .46463 .40496 .46121 .40408 Metetra
.681 .931 .969 r
.46121 .40408 .46463 .40496 .47052 .40566 .46717 .40124 Metetra
.659 .701 .878 r
.46717 .40124 .47052 .40566 .47638 .40896 .47312 .39929 Metetra
.561 .501 .745 r
.47312 .39929 .47638 .40896 .48226 .41436 .47906 .39917 Metetra
.491 .395 .674 r
.47906 .39917 .48226 .41436 .48816 .42052 .48499 .40159 Metetra
.436 .335 .642 r
.48499 .40159 .48816 .42052 .49412 .42559 .49092 .40671 Metetra
.374 .292 .635 r
.49092 .40671 .49412 .42559 .50014 .42779 .49687 .41394 Metetra
.243 .242 .658 r
.49687 .41394 .50014 .42779 .50621 .42598 .50286 .42197 Metetra
0 0 .481 r
.50286 .42197 .50621 .42598 .51231 .42013 .50891 .42896 Metetra
.624 .264 .339 r
.50891 .42896 .51231 .42013 .51841 .41123 .51502 .43303 Metetra
.523 .242 .43 r
.51502 .43303 .51841 .41123 .52451 .40099 .52116 .4327 Metetra
.469 .217 .449 r
.52116 .4327 .52451 .40099 .53058 .39113 .52733 .42738 Metetra
.424 .186 .447 r
.52733 .42738 .53058 .39113 .53665 .38291 .53348 .41757 Metetra
.373 .143 .431 r
.53348 .41757 .53665 .38291 .54272 .37681 .5396 .40477 Metetra
.303 .075 .393 r
.5396 .40477 .54272 .37681 .5488 .37258 .54569 .3911 Metetra
.184 0 .306 r
.54569 .3911 .5488 .37258 .55489 .36962 .55176 .37877 Metetra
0 0 .058 r
.55176 .37877 .55489 .36962 .56101 .36734 .55784 .36957 Metetra
.531 .874 .62 r
.55784 .36957 .56101 .36734 .56714 .36546 .56396 .36446 Metetra
.412 .828 .971 r
.56396 .36446 .56714 .36546 .5733 .36414 .57013 .36341 Metetra
.291 0 0 r
.57013 .36341 .5733 .36414 .57948 .36371 .57637 .36555 Metetra
.631 .12 .013 r
.57637 .36555 .57948 .36371 .58571 .36445 .58267 .3694 Metetra
.634 .21 .22 r
.58267 .3694 .58571 .36445 .59199 .36629 .58902 .37332 Metetra
.583 .194 .27 r
.58902 .37332 .59199 .36629 .59831 .36875 .59537 .37591 Metetra
.499 .112 .238 r
.59537 .37591 .59831 .36875 .60466 .37102 .6017 .37637 Metetra
.321 0 .076 r
.6017 .37637 .60466 .37102 .61101 .37223 .608 .37457 Metetra
.608 .37457 .61101 .37223 .61734 .37181 .61426 .37095 Metetra
.798 .961 .916 r
.61426 .37095 .61734 .37181 .62364 .36959 .6205 .36632 Metetra
.799 .812 .862 r
.6205 .36632 .62364 .36959 .6299 .36589 .62674 .36147 Metetra
.765 .747 .837 r
.62674 .36147 .6299 .36589 .63614 .36134 .63299 .357 Metetra
.742 .745 .854 r
.63299 .357 .63614 .36134 .64238 .35666 .63927 .35318 Metetra
.725 .787 .902 r
.63927 .35318 .64238 .35666 .64864 .35239 .64558 .35 Metetra
.7 .853 .956 r
.64558 .35 .64864 .35239 .65493 .3488 .65192 .34722 Metetra
.668 .901 .978 r
.65192 .34722 .65493 .3488 .66126 .34589 .65828 .34455 Metetra
.665 .917 .976 r
.65828 .34455 .66126 .34589 .66762 .34342 .66465 .34177 Metetra
.697 .906 .969 r
.66465 .34177 .66762 .34342 .67401 .3411 .67101 .33878 Metetra
.725 .867 .948 r
.67101 .33878 .67401 .3411 .6804 .33869 .67738 .3356 Metetra
.731 .817 .918 r
.67738 .3356 .6804 .33869 .68679 .33604 .68375 .33233 Metetra
.724 .777 .894 r
.68375 .33233 .68679 .33604 .69319 .33317 .69014 .32908 Metetra
.714 .754 .884 r
.69014 .32908 .69319 .33317 .69958 .33016 .69654 .32597 Metetra
.705 .746 .884 r
.69654 .32597 .69958 .33016 .70599 .32712 .70297 .32302 Metetra
.698 .749 .891 r
.70297 .32302 .70599 .32712 .71241 .32415 .70941 .32022 Metetra
.692 .757 .901 r
.70941 .32022 .71241 .32415 .71886 .32132 .71588 .31754 Metetra
.689 .765 .909 r
.71588 .31754 .71886 .32132 .72532 .31862 .72236 .31492 Metetra
.688 .77 .914 r
.72236 .31492 .72532 .31862 .73181 .31602 .72885 .31232 Metetra
.688 .77 .914 r
.72885 .31232 .73181 .31602 .73831 .31349 .73536 .30972 Metetra
.689 .767 .911 r
.73536 .30972 .73831 .31349 .74482 .31096 .74188 .3071 Metetra
.688 .762 .908 r
.74188 .3071 .74482 .31096 .75135 .30844 .74842 .30448 Metetra
.687 .757 .905 r
.74842 .30448 .75135 .30844 .7579 .30589 .75497 .30187 Metetra
.685 .753 .903 r
.75497 .30187 .7579 .30589 .76445 .30334 .76153 .29929 Metetra
.683 .751 .903 r
.76153 .29929 .76445 .30334 .77102 .30079 .76811 .29673 Metetra
.681 .75 .903 r
.76811 .29673 .77102 .30079 .77761 .29826 .77471 .2942 Metetra
.68 .75 .904 r
.77471 .2942 .77761 .29826 .78421 .29575 .78133 .29169 Metetra
.679 .751 .905 r
.78133 .29169 .78421 .29575 .79083 .29326 .78795 .2892 Metetra
.678 .751 .906 r
.78795 .2892 .79083 .29326 .79746 .29078 .7946 .28672 Metetra
.677 .751 .906 r
.7946 .28672 .79746 .29078 .80411 .28832 .80126 .28424 Metetra
.676 .75 .906 r
.80126 .28424 .80411 .28832 .81077 .28587 .80793 .28177 Metetra
.676 .749 .906 r
.80793 .28177 .81077 .28587 .81745 .28342 .81463 .2793 Metetra
.675 .749 .906 r
.81463 .2793 .81745 .28342 .82415 .28097 .82133 .27684 Metetra
.675 .748 .906 r
.82133 .27684 .82415 .28097 .83086 .27853 .82805 .27438 Metetra
.674 .748 .906 r
.82805 .27438 .83086 .27853 .83759 .27609 .83479 .27193 Metetra
.674 .747 .906 r
.83479 .27193 .83759 .27609 .84433 .27365 .84155 .26948 Metetra
.673 .747 .906 r
.84155 .26948 .84433 .27365 .85109 .27121 .84832 .26704 Metetra
.673 .747 .906 r
.84832 .26704 .85109 .27121 .85786 .26878 .8551 .26459 Metetra
.657 .74 .911 r
.24721 .46212 .25087 .46551 .25634 .46377 .25269 .46036 Metetra
.657 .74 .911 r
.25269 .46036 .25634 .46377 .26182 .46203 .25817 .45861 Metetra
.656 .74 .911 r
.25817 .45861 .26182 .46203 .26731 .46028 .26367 .45686 Metetra
.656 .74 .911 r
.26367 .45686 .26731 .46028 .27281 .45854 .26918 .45511 Metetra
.656 .74 .912 r
.26918 .45511 .27281 .45854 .27832 .4568 .2747 .45336 Metetra
.655 .74 .912 r
.2747 .45336 .27832 .4568 .28385 .45505 .28023 .45162 Metetra
.655 .74 .912 r
.28023 .45162 .28385 .45505 .28938 .45331 .28578 .44986 Metetra
.655 .74 .912 r
.28578 .44986 .28938 .45331 .29493 .45156 .29133 .44811 Metetra
.655 .74 .912 r
.29133 .44811 .29493 .45156 .30049 .44982 .2969 .44636 Metetra
.655 .74 .912 r
.2969 .44636 .30049 .44982 .30607 .44808 .30248 .4446 Metetra
.654 .739 .912 r
.30248 .4446 .30607 .44808 .31165 .44634 .30807 .44285 Metetra
.653 .738 .912 r
.30807 .44285 .31165 .44634 .31725 .44462 .31368 .44111 Metetra
.652 .737 .912 r
.31368 .44111 .31725 .44462 .32285 .4429 .31929 .43938 Metetra
.651 .737 .912 r
.31929 .43938 .32285 .4429 .32847 .44119 .32492 .43767 Metetra
.65 .737 .913 r
.32492 .43767 .32847 .44119 .33411 .43947 .33056 .43597 Metetra
.65 .738 .914 r
.33056 .43597 .33411 .43947 .33975 .43773 .33621 .43426 Metetra
.651 .741 .915 r
.33621 .43426 .33975 .43773 .34541 .43598 .34187 .43253 Metetra
.653 .742 .915 r
.34187 .43253 .34541 .43598 .35108 .43423 .34755 .43077 Metetra
.654 .743 .915 r
.34755 .43077 .35108 .43423 .35676 .4325 .35324 .42898 Metetra
.654 .74 .913 r
.35324 .42898 .35676 .4325 .36246 .4308 .35895 .4272 Metetra
.651 .734 .911 r
.35895 .4272 .36246 .4308 .36816 .42917 .36466 .42546 Metetra
.644 .727 .909 r
.36466 .42546 .36816 .42917 .37387 .4276 .37038 .42381 Metetra
.635 .72 .909 r
.37038 .42381 .37387 .4276 .3796 .42606 .37612 .42229 Metetra
.628 .719 .912 r
.37612 .42229 .3796 .42606 .38534 .42449 .38186 .42086 Metetra
.626 .727 .919 r
.38186 .42086 .38534 .42449 .3911 .42285 .38761 .41944 Metetra
.633 .744 .928 r
.38761 .41944 .3911 .42285 .39687 .42108 .39338 .41791 Metetra
.65 .763 .932 r
.39338 .41791 .39687 .42108 .40266 .41921 .39918 .41613 Metetra
.669 .775 .929 r
.39918 .41613 .40266 .41921 .40847 .41732 .405 .41409 Metetra
.68 .768 .918 r
.405 .41409 .40847 .41732 .41428 .41558 .41083 .41188 Metetra
.671 .739 .902 r
.41083 .41188 .41428 .41558 .42009 .41413 .41668 .40979 Metetra
.64 .696 .886 r
.41668 .40979 .42009 .41413 .42591 .41306 .42252 .40817 Metetra
.592 .65 .877 r
.42252 .40817 .42591 .41306 .43174 .41231 .42835 .4073 Metetra
.536 .62 .883 r
.42835 .4073 .43174 .41231 .43758 .41165 .43418 .40721 Metetra
.487 .626 .913 r
.43418 .40721 .43758 .41165 .44344 .41073 .44002 .40752 Metetra
.471 .697 .966 r
.44002 .40752 .44344 .41073 .44933 .40921 .44588 .4075 Metetra
.53 .831 .999 r
.44588 .4075 .44933 .40921 .45526 .40693 .45179 .40632 Metetra
.669 .942 .963 r
.45179 .40632 .45526 .40693 .46121 .40408 .45776 .40343 Metetra
.801 .953 .917 r
.45776 .40343 .46121 .40408 .46717 .40124 .46376 .39899 Metetra
.818 .851 .874 r
.46376 .39899 .46717 .40124 .47312 .39929 .46977 .3941 Metetra
.719 .69 .821 r
.46977 .3941 .47312 .39929 .47906 .39917 .47577 .39061 Metetra
.554 .518 .769 r
.47577 .39061 .47906 .39917 .48499 .40159 .48172 .3906 Metetra
.325 .332 .713 r
.48172 .3906 .48499 .40159 .49092 .40671 .48764 .39558 Metetra
0 .086 .613 r
.48764 .39558 .49092 .40671 .49687 .41394 .49355 .4057 Metetra
0 0 .33 r
.49355 .4057 .49687 .41394 .50286 .42197 .49949 .41928 Metetra
.883 .452 .089 r
.49949 .41928 .50286 .42197 .50891 .42896 .5055 .43299 Metetra
.782 .38 .292 r
.5055 .43299 .50891 .42896 .51502 .43303 .5116 .44262 Metetra
.561 .207 .325 r
.5116 .44262 .51502 .43303 .52116 .4327 .51778 .44449 Metetra
.179 0 .215 r
.51778 .44449 .52116 .4327 .52733 .42738 .52398 .43687 Metetra
.52398 .43687 .52733 .42738 .53348 .41757 .53017 .42078 Metetra
.995 .869 .562 r
.53017 .42078 .53348 .41757 .5396 .40477 .5363 .39979 Metetra
.922 .732 .628 r
.5363 .39979 .5396 .40477 .54569 .3911 .54236 .37881 Metetra
.812 .618 .64 r
.54236 .37881 .54569 .3911 .55176 .37877 .54841 .36251 Metetra
.702 .529 .65 r
.54841 .36251 .55176 .37877 .55784 .36957 .55448 .35396 Metetra
.558 .438 .672 r
.55448 .35396 .55784 .36957 .56396 .36446 .56064 .35392 Metetra
.201 .26 .701 r
.56064 .35392 .56396 .36446 .57013 .36341 .56692 .36083 Metetra
.809 .335 0 r
.56692 .36083 .57013 .36341 .57637 .36555 .5733 .3715 Metetra
.771 .387 .328 r
.5733 .3715 .57637 .36555 .58267 .3694 .57974 .38211 Metetra
.663 .33 .399 r
.57974 .38211 .58267 .3694 .58902 .37332 .58618 .38943 Metetra
.565 .256 .404 r
.58618 .38943 .58902 .37332 .59537 .37591 .59257 .39167 Metetra
.449 .153 .369 r
.59257 .39167 .59537 .37591 .6017 .37637 .59887 .38878 Metetra
.268 0 .27 r
.59887 .38878 .6017 .37637 .608 .37457 .60509 .38213 Metetra
.60509 .38213 .608 .37457 .61426 .37095 .61126 .37376 Metetra
.732 .927 .583 r
.61126 .37376 .61426 .37095 .6205 .36632 .61742 .36557 Metetra
.889 .952 .841 r
.61742 .36557 .6205 .36632 .62674 .36147 .62361 .35878 Metetra
.813 .849 .876 r
.62361 .35878 .62674 .36147 .63299 .357 .62987 .35381 Metetra
.741 .809 .906 r
.62987 .35381 .63299 .357 .63927 .35318 .63617 .35036 Metetra
.69 .82 .945 r
.63617 .35036 .63927 .35318 .64558 .35 .64252 .34777 Metetra
.668 .856 .972 r
.64252 .34777 .64558 .35 .65192 .34722 .64889 .34535 Metetra
.683 .887 .973 r
.64889 .34535 .65192 .34722 .65828 .34455 .65526 .34262 Metetra
.722 .892 .957 r
.65526 .34262 .65828 .34455 .66465 .34177 .66162 .33941 Metetra
.751 .869 .934 r
.66162 .33941 .66465 .34177 .67101 .33878 .66797 .33582 Metetra
.756 .83 .909 r
.66797 .33582 .67101 .33878 .67738 .3356 .67433 .33208 Metetra
.746 .795 .892 r
.67433 .33208 .67738 .3356 .68375 .33233 .6807 .32843 Metetra
.73 .769 .885 r
.6807 .32843 .68375 .33233 .69014 .32908 .68709 .32503 Metetra
.713 .757 .886 r
.68709 .32503 .69014 .32908 .69654 .32597 .6935 .32194 Metetra
.701 .754 .893 r
.6935 .32194 .69654 .32597 .70297 .32302 .69994 .31909 Metetra
.693 .758 .902 r
.69994 .31909 .70297 .32302 .70941 .32022 .70641 .31641 Metetra
.689 .763 .908 r
.70641 .31641 .70941 .32022 .71588 .31754 .71289 .31379 Metetra
.69 .767 .911 r
.71289 .31379 .71588 .31754 .72236 .31492 .71938 .31116 Metetra
.691 .768 .91 r
.71938 .31116 .72236 .31492 .72885 .31232 .72588 .3085 Metetra
.692 .765 .908 r
.72588 .3085 .72885 .31232 .73536 .30972 .7324 .30581 Metetra
.692 .761 .905 r
.7324 .30581 .73536 .30972 .74188 .3071 .73893 .30312 Metetra
.69 .757 .903 r
.73893 .30312 .74188 .3071 .74842 .30448 .74547 .30045 Metetra
.688 .754 .902 r
.74547 .30045 .74842 .30448 .75497 .30187 .75203 .29781 Metetra
.685 .752 .902 r
.75203 .29781 .75497 .30187 .76153 .29929 .7586 .29522 Metetra
.682 .751 .903 r
.7586 .29522 .76153 .29929 .76811 .29673 .7652 .29266 Metetra
.681 .751 .904 r
.7652 .29266 .76811 .29673 .77471 .2942 .77181 .29013 Metetra
.679 .751 .905 r
.77181 .29013 .77471 .2942 .78133 .29169 .77843 .28762 Metetra
.679 .751 .906 r
.77843 .28762 .78133 .29169 .78795 .2892 .78507 .28512 Metetra
.678 .751 .906 r
.78507 .28512 .78795 .2892 .7946 .28672 .79173 .28262 Metetra
.677 .75 .906 r
.79173 .28262 .7946 .28672 .80126 .28424 .7984 .28013 Metetra
.677 .749 .906 r
.7984 .28013 .80126 .28424 .80793 .28177 .80508 .27764 Metetra
.676 .749 .906 r
.80508 .27764 .80793 .28177 .81463 .2793 .81178 .27516 Metetra
.675 .748 .906 r
.81178 .27516 .81463 .2793 .82133 .27684 .8185 .27268 Metetra
.675 .748 .906 r
.8185 .27268 .82133 .27684 .82805 .27438 .82524 .27021 Metetra
.674 .747 .906 r
.82524 .27021 .82805 .27438 .83479 .27193 .83198 .26775 Metetra
.674 .747 .906 r
.83198 .26775 .83479 .27193 .84155 .26948 .83875 .26529 Metetra
.673 .747 .906 r
.83875 .26529 .84155 .26948 .84832 .26704 .84553 .26284 Metetra
.673 .747 .906 r
.84553 .26284 .84832 .26704 .8551 .26459 .85233 .26038 Metetra
.657 .74 .911 r
.24355 .45871 .24721 .46212 .25269 .46036 .24903 .45695 Metetra
.657 .74 .911 r
.24903 .45695 .25269 .46036 .25817 .45861 .25452 .45519 Metetra
.656 .74 .911 r
.25452 .45519 .25817 .45861 .26367 .45686 .26002 .45343 Metetra
.656 .74 .911 r
.26002 .45343 .26367 .45686 .26918 .45511 .26554 .45167 Metetra
.656 .74 .912 r
.26554 .45167 .26918 .45511 .2747 .45336 .27107 .44992 Metetra
.655 .739 .912 r
.27107 .44992 .2747 .45336 .28023 .45162 .27661 .44816 Metetra
.655 .739 .912 r
.27661 .44816 .28023 .45162 .28578 .44986 .28216 .4464 Metetra
.655 .739 .912 r
.28216 .4464 .28578 .44986 .29133 .44811 .28772 .44465 Metetra
.655 .739 .912 r
.28772 .44465 .29133 .44811 .2969 .44636 .29329 .44289 Metetra
.654 .74 .912 r
.29329 .44289 .2969 .44636 .30248 .4446 .29888 .44113 Metetra
.654 .74 .913 r
.29888 .44113 .30248 .4446 .30807 .44285 .30448 .43937 Metetra
.654 .74 .913 r
.30448 .43937 .30807 .44285 .31368 .44111 .31009 .43762 Metetra
.653 .739 .913 r
.31009 .43762 .31368 .44111 .31929 .43938 .31571 .43587 Metetra
.652 .738 .913 r
.31571 .43587 .31929 .43938 .32492 .43767 .32135 .43414 Metetra
.651 .737 .912 r
.32135 .43414 .32492 .43767 .33056 .43597 .32699 .43241 Metetra
.65 .736 .912 r
.32699 .43241 .33056 .43597 .33621 .43426 .33265 .43069 Metetra
.65 .735 .912 r
.33265 .43069 .33621 .43426 .34187 .43253 .33832 .42897 Metetra
.65 .736 .912 r
.33832 .42897 .34187 .43253 .34755 .43077 .34401 .42724 Metetra
.651 .739 .914 r
.34401 .42724 .34755 .43077 .35324 .42898 .3497 .4255 Metetra
.651 .742 .916 r
.3497 .4255 .35324 .42898 .35895 .4272 .35541 .42375 Metetra
.65 .745 .919 r
.35541 .42375 .35895 .4272 .36466 .42546 .36113 .42201 Metetra
.648 .744 .92 r
.36113 .42201 .36466 .42546 .37038 .42381 .36687 .42029 Metetra
.644 .739 .918 r
.36687 .42029 .37038 .42381 .37612 .42229 .37261 .41863 Metetra
.639 .73 .914 r
.37261 .41863 .37612 .42229 .38186 .42086 .37837 .41703 Metetra
.636 .719 .908 r
.37837 .41703 .38186 .42086 .38761 .41944 .38413 .41549 Metetra
.635 .713 .903 r
.38413 .41549 .38761 .41944 .39338 .41791 .38991 .41395 Metetra
.639 .714 .902 r
.38991 .41395 .39338 .41791 .39918 .41613 .39571 .41236 Metetra
.646 .727 .908 r
.39571 .41236 .39918 .41613 .405 .41409 .40152 .41066 Metetra
.652 .75 .921 r
.40152 .41066 .405 .41409 .41083 .41188 .40735 .40885 Metetra
.653 .776 .939 r
.40735 .40885 .41083 .41188 .41668 .40979 .41319 .407 Metetra
.642 .789 .953 r
.41319 .407 .41668 .40979 .42252 .40817 .41905 .40525 Metetra
.62 .775 .955 r
.41905 .40525 .42252 .40817 .42835 .4073 .42491 .40376 Metetra
.598 .727 .935 r
.42491 .40376 .42835 .4073 .43418 .40721 .43077 .40264 Metetra
.583 .663 .894 r
.43077 .40264 .43418 .40721 .44002 .40752 .43664 .40186 Metetra
.58 .614 .851 r
.43664 .40186 .44002 .40752 .44588 .4075 .44253 .4012 Metetra
.593 .598 .826 r
.44253 .4012 .44588 .4075 .45179 .40632 .44843 .40034 Metetra
.622 .622 .83 r
.44843 .40034 .45179 .40632 .45776 .40343 .45437 .39893 Metetra
.665 .701 .873 r
.45437 .39893 .45776 .40343 .46376 .39899 .46033 .39683 Metetra
.698 .851 .956 r
.46033 .39683 .46376 .39899 .46977 .3941 .46632 .39423 Metetra
.529 .919 .906 r
.46632 .39423 .46977 .3941 .47577 .39061 .47232 .3917 Metetra
.47232 .3917 .47577 .39061 .48172 .3906 .47831 .39003 Metetra
.12 .663 .838 r
.47831 .39003 .48172 .3906 .48764 .39558 .4843 .39001 Metetra
.354 .502 .867 r
.4843 .39001 .48764 .39558 .49355 .4057 .49029 .39205 Metetra
.425 .365 .687 r
.49029 .39205 .49355 .4057 .49949 .41928 .49629 .396 Metetra
.46 .335 .622 r
.49629 .396 .49949 .41928 .5055 .43299 .50231 .40108 Metetra
.487 .334 .598 r
.50231 .40108 .5055 .43299 .5116 .44262 .50838 .40617 Metetra
.509 .343 .592 r
.50838 .40617 .5116 .44262 .51778 .44449 .51449 .41012 Metetra
.528 .36 .597 r
.51449 .41012 .51778 .44449 .52398 .43687 .52064 .41225 Metetra
.55 .395 .624 r
.52064 .41225 .52398 .43687 .53017 .42078 .52682 .41256 Metetra
.589 .549 .778 r
.52682 .41256 .53017 .42078 .5363 .39979 .53302 .41172 Metetra
.478 .15 .333 r
.53302 .41172 .5363 .39979 .54236 .37881 .53924 .41075 Metetra
.531 .268 .461 r
.53924 .41075 .54236 .37881 .54841 .36251 .54548 .41055 Metetra
.545 .294 .487 r
.54548 .41055 .54841 .36251 .55448 .35396 .55175 .41149 Metetra
.55 .303 .495 r
.55175 .41149 .55448 .35396 .56064 .35392 .55805 .41324 Metetra
.549 .303 .496 r
.55805 .41324 .56064 .35392 .56692 .36083 .56438 .41486 Metetra
.54 .294 .491 r
.56438 .41486 .56692 .36083 .5733 .3715 .57072 .41516 Metetra
.52 .271 .477 r
.57072 .41516 .5733 .3715 .57974 .38211 .57705 .41313 Metetra
.474 .219 .446 r
.57705 .41313 .57974 .38211 .58618 .38943 .58335 .40835 Metetra
.358 .091 .365 r
.58335 .40835 .58618 .38943 .59257 .39167 .58959 .40107 Metetra
0 0 .092 r
.58959 .40107 .59257 .39167 .59887 .38878 .5958 .39216 Metetra
.761 .917 .544 r
.5958 .39216 .59887 .38878 .60509 .38213 .60198 .3827 Metetra
.928 .97 .753 r
.60198 .3827 .60509 .38213 .61126 .37376 .60815 .37373 Metetra
.91 .969 .8 r
.60815 .37373 .61126 .37376 .61742 .36557 .61435 .36593 Metetra
.846 .997 .825 r
.61435 .36593 .61742 .36557 .62361 .35878 .62058 .35952 Metetra
.725 .988 .818 r
.62058 .35952 .62361 .35878 .62987 .35381 .62685 .35437 Metetra
.652 .969 .84 r
.62685 .35437 .62987 .35381 .63617 .35036 .63315 .3501 Metetra
.692 .973 .919 r
.63315 .3501 .63617 .35036 .64252 .34777 .63947 .34628 Metetra
.746 .925 .95 r
.63947 .34628 .64252 .34777 .64889 .34535 .64581 .34261 Metetra
.756 .844 .918 r
.64581 .34261 .64889 .34535 .65526 .34262 .65215 .33892 Metetra
.748 .784 .883 r
.65215 .33892 .65526 .34262 .66162 .33941 .6585 .33519 Metetra
.739 .755 .865 r
.6585 .33519 .66162 .33941 .66797 .33582 .66486 .33149 Metetra
.732 .748 .865 r
.66486 .33149 .66797 .33582 .67433 .33208 .67123 .32792 Metetra
.725 .755 .876 r
.67123 .32792 .67433 .33208 .6807 .32843 .67763 .32454 Metetra
.718 .768 .891 r
.67763 .32454 .6807 .32843 .68709 .32503 .68404 .32137 Metetra
.711 .779 .905 r
.68404 .32137 .68709 .32503 .6935 .32194 .69047 .31837 Metetra
.705 .783 .913 r
.69047 .31837 .6935 .32194 .69994 .31909 .69693 .3155 Metetra
.7 .781 .914 r
.69693 .3155 .69994 .31909 .70641 .31641 .70339 .3127 Metetra
.698 .773 .91 r
.70339 .3127 .70641 .31641 .71289 .31379 .70988 .30993 Metetra
.696 .765 .905 r
.70988 .30993 .71289 .31379 .71938 .31116 .71637 .30718 Metetra
.694 .758 .901 r
.71637 .30718 .71938 .31116 .72588 .3085 .72288 .30444 Metetra
.692 .753 .898 r
.72288 .30444 .72588 .3085 .7324 .30581 .72941 .30172 Metetra
.69 .751 .898 r
.72941 .30172 .7324 .30581 .73893 .30312 .73595 .29903 Metetra
.688 .751 .9 r
.73595 .29903 .73893 .30312 .74547 .30045 .7425 .29638 Metetra
.686 .752 .902 r
.7425 .29638 .74547 .30045 .75203 .29781 .74908 .29376 Metetra
.684 .753 .903 r
.74908 .29376 .75203 .29781 .7586 .29522 .75566 .29117 Metetra
.682 .753 .905 r
.75566 .29117 .7586 .29522 .7652 .29266 .76227 .28861 Metetra
.681 .753 .905 r
.76227 .28861 .7652 .29266 .77181 .29013 .76889 .28606 Metetra
.68 .752 .905 r
.76889 .28606 .77181 .29013 .77843 .28762 .77552 .28353 Metetra
.679 .751 .905 r
.77552 .28353 .77843 .28762 .78507 .28512 .78217 .281 Metetra
.678 .75 .905 r
.78217 .281 .78507 .28512 .79173 .28262 .78884 .27849 Metetra
.678 .749 .905 r
.78884 .27849 .79173 .28262 .7984 .28013 .79552 .27598 Metetra
.677 .748 .905 r
.79552 .27598 .7984 .28013 .80508 .27764 .80222 .27348 Metetra
.676 .748 .905 r
.80222 .27348 .80508 .27764 .81178 .27516 .80893 .27099 Metetra
.675 .748 .905 r
.80893 .27099 .81178 .27516 .8185 .27268 .81566 .2685 Metetra
.675 .747 .906 r
.81566 .2685 .8185 .27268 .82524 .27021 .8224 .26602 Metetra
.674 .747 .906 r
.8224 .26602 .82524 .27021 .83198 .26775 .82917 .26355 Metetra
.674 .747 .906 r
.82917 .26355 .83198 .26775 .83875 .26529 .83594 .26108 Metetra
.673 .747 .906 r
.83594 .26108 .83875 .26529 .84553 .26284 .84273 .25862 Metetra
.673 .746 .906 r
.84273 .25862 .84553 .26284 .85233 .26038 .84954 .25615 Metetra
.657 .74 .911 r
.23986 .45529 .24355 .45871 .24903 .45695 .24535 .45353 Metetra
.657 .74 .911 r
.24535 .45353 .24903 .45695 .25452 .45519 .25085 .45176 Metetra
.656 .74 .911 r
.25085 .45176 .25452 .45519 .26002 .45343 .25636 .44999 Metetra
.656 .74 .912 r
.25636 .44999 .26002 .45343 .26554 .45167 .26188 .44823 Metetra
.656 .74 .912 r
.26188 .44823 .26554 .45167 .27107 .44992 .26742 .44646 Metetra
.656 .74 .912 r
.26742 .44646 .27107 .44992 .27661 .44816 .27296 .44469 Metetra
.655 .739 .912 r
.27296 .44469 .27661 .44816 .28216 .4464 .27852 .44293 Metetra
.655 .739 .912 r
.27852 .44293 .28216 .4464 .28772 .44465 .28409 .44116 Metetra
.654 .739 .912 r
.28409 .44116 .28772 .44465 .29329 .44289 .28967 .43941 Metetra
.654 .739 .913 r
.28967 .43941 .29329 .44289 .29888 .44113 .29527 .43765 Metetra
.654 .74 .913 r
.29527 .43765 .29888 .44113 .30448 .43937 .30087 .43589 Metetra
.653 .74 .913 r
.30087 .43589 .30448 .43937 .31009 .43762 .30649 .43413 Metetra
.654 .74 .913 r
.30649 .43413 .31009 .43762 .31571 .43587 .31212 .43237 Metetra
.653 .74 .913 r
.31212 .43237 .31571 .43587 .32135 .43414 .31776 .4306 Metetra
.653 .738 .912 r
.31776 .4306 .32135 .43414 .32699 .43241 .32342 .42884 Metetra
.652 .736 .911 r
.32342 .42884 .32699 .43241 .33265 .43069 .32908 .42708 Metetra
.65 .734 .911 r
.32908 .42708 .33265 .43069 .33832 .42897 .33476 .42536 Metetra
.647 .734 .912 r
.33476 .42536 .33832 .42897 .34401 .42724 .34045 .42366 Metetra
.645 .735 .915 r
.34045 .42366 .34401 .42724 .3497 .4255 .34615 .42199 Metetra
.644 .74 .918 r
.34615 .42199 .3497 .4255 .35541 .42375 .35186 .42032 Metetra
.646 .745 .922 r
.35186 .42032 .35541 .42375 .36113 .42201 .35759 .41863 Metetra
.649 .75 .923 r
.35759 .41863 .36113 .42201 .36687 .42029 .36333 .41688 Metetra
.654 .75 .92 r
.36333 .41688 .36687 .42029 .37261 .41863 .36909 .41507 Metetra
.656 .742 .913 r
.36909 .41507 .37261 .41863 .37837 .41703 .37486 .41322 Metetra
.653 .727 .903 r
.37486 .41322 .37837 .41703 .38413 .41549 .38065 .41141 Metetra
.644 .71 .895 r
.38065 .41141 .38413 .41549 .38991 .41395 .38644 .40974 Metetra
.63 .698 .895 r
.38644 .40974 .38991 .41395 .39571 .41236 .39223 .40828 Metetra
.613 .7 .906 r
.39223 .40828 .39571 .41236 .40152 .41066 .39804 .40705 Metetra
.6 .723 .931 r
.39804 .40705 .40152 .41066 .40735 .40885 .40385 .40593 Metetra
.596 .767 .961 r
.40385 .40593 .40735 .40885 .41319 .407 .40968 .4047 Metetra
.613 .816 .978 r
.40968 .4047 .41319 .407 .41905 .40525 .41554 .40312 Metetra
.657 .841 .971 r
.41554 .40312 .41905 .40525 .42491 .40376 .42143 .40104 Metetra
.697 .809 .934 r
.42143 .40104 .42491 .40376 .43077 .40264 .42734 .39853 Metetra
.693 .727 .876 r
.42734 .39853 .43077 .40264 .43664 .40186 .43327 .39597 Metetra
.651 .638 .824 r
.43327 .39597 .43664 .40186 .44253 .4012 .43919 .39397 Metetra
.591 .569 .798 r
.43919 .39397 .44253 .4012 .44843 .40034 .4451 .39312 Metetra
.514 .529 .809 r
.4451 .39312 .44843 .40034 .45437 .39893 .45099 .39371 Metetra
.371 .528 .882 r
.45099 .39371 .45437 .39893 .46033 .39683 .45688 .39539 Metetra
0 .44 .763 r
.45688 .39539 .46033 .39683 .46632 .39423 .46279 .39715 Metetra
.403 0 0 r
.46279 .39715 .46632 .39423 .47232 .3917 .46876 .39753 Metetra
.286 0 .074 r
.46876 .39753 .47232 .3917 .47831 .39003 .47479 .39524 Metetra
.47479 .39524 .47831 .39003 .4843 .39001 .48087 .38989 Metetra
.905 .951 .82 r
.48087 .38989 .4843 .39001 .49029 .39205 .48698 .38259 Metetra
.735 .603 .71 r
.48698 .38259 .49029 .39205 .49629 .396 .49308 .37603 Metetra
.592 .438 .642 r
.49308 .37603 .49629 .396 .50231 .40108 .49913 .37395 Metetra
.454 .319 .607 r
.49913 .37395 .50231 .40108 .50838 .40617 .50515 .3801 Metetra
.188 .132 .558 r
.50515 .3801 .50838 .40617 .51449 .41012 .51117 .39701 Metetra
.788 .499 0 r
.51117 .39701 .51449 .41012 .52064 .41225 .51724 .4249 Metetra
.856 .538 .448 r
.51724 .4249 .52064 .41225 .52682 .41256 .52344 .4611 Metetra
.725 .448 .507 r
.52344 .4611 .52682 .41256 .53302 .41172 .52981 .50014 Metetra
.652 .395 .519 r
.52981 .50014 .53302 .41172 .53924 .41075 .53633 .5348 Metetra
.6 .357 .521 r
.53633 .5348 .53924 .41075 .54548 .41055 .54295 .55794 Metetra
.558 .325 .518 r
.54295 .55794 .54548 .41055 .55175 .41149 .54957 .56474 Metetra
.517 .293 .513 r
.54957 .56474 .55175 .41149 .55805 .41324 .55607 .55428 Metetra
.475 .259 .505 r
.55607 .55428 .55805 .41324 .56438 .41486 .5624 .52965 Metetra
.422 .215 .491 r
.5624 .52965 .56438 .41486 .57072 .41516 .56854 .49665 Metetra
.346 .15 .465 r
.56854 .49665 .57072 .41516 .57705 .41313 .57455 .46172 Metetra
.205 .026 .403 r
.57455 .46172 .57705 .41313 .58335 .40835 .5805 .43014 Metetra
0 0 .184 r
.5805 .43014 .58335 .40835 .58959 .40107 .58647 .40503 Metetra
.963 .899 .527 r
.58647 .40503 .58959 .40107 .5958 .39216 .59252 .38727 Metetra
.881 .749 .713 r
.59252 .38727 .5958 .39216 .60198 .3827 .59867 .37589 Metetra
.782 .677 .747 r
.59867 .37589 .60198 .3827 .60815 .37373 .60491 .36893 Metetra
.764 .734 .824 r
.60491 .36893 .60815 .37373 .61435 .36593 .6112 .36425 Metetra
.78 .914 .93 r
.6112 .36425 .61435 .36593 .62058 .35952 .61752 .36011 Metetra
.681 .978 .838 r
.61752 .36011 .62058 .35952 .62685 .35437 .62383 .35556 Metetra
.668 .964 .763 r
.62383 .35556 .62685 .35437 .63315 .3501 .63012 .35036 Metetra
.796 .998 .849 r
.63012 .35036 .63315 .3501 .63947 .34628 .6364 .34481 Metetra
.841 .929 .888 r
.6364 .34481 .63947 .34628 .64581 .34261 .64269 .33938 Metetra
.802 .821 .866 r
.64269 .33938 .64581 .34261 .65215 .33892 .649 .33446 Metetra
.755 .748 .846 r
.649 .33446 .65215 .33892 .6585 .33519 .65534 .33023 Metetra
.723 .716 .843 r
.65534 .33023 .6585 .33519 .66486 .33149 .66171 .32664 Metetra
.706 .715 .856 r
.66171 .32664 .66486 .33149 .67123 .32792 .66812 .32352 Metetra
.7 .735 .878 r
.66812 .32352 .67123 .32792 .67763 .32454 .67454 .32063 Metetra
.701 .761 .899 r
.67454 .32063 .67763 .32454 .68404 .32137 .68099 .31778 Metetra
.706 .782 .911 r
.68099 .31778 .68404 .32137 .69047 .31837 .68744 .31488 Metetra
.71 .79 .914 r
.68744 .31488 .69047 .31837 .69693 .3155 .6939 .31192 Metetra
.71 .785 .91 r
.6939 .31192 .69693 .3155 .70339 .3127 .70037 .30893 Metetra
.708 .774 .904 r
.70037 .30893 .70339 .3127 .70988 .30993 .70685 .30596 Metetra
.702 .762 .898 r
.70685 .30596 .70988 .30993 .71637 .30718 .71335 .30307 Metetra
.696 .752 .895 r
.71335 .30307 .71637 .30718 .72288 .30444 .71987 .30027 Metetra
.691 .748 .895 r
.71987 .30027 .72288 .30444 .72941 .30172 .7264 .29755 Metetra
.687 .747 .897 r
.7264 .29755 .72941 .30172 .73595 .29903 .73296 .2949 Metetra
.685 .749 .899 r
.73296 .2949 .73595 .29903 .7425 .29638 .73953 .29228 Metetra
.684 .751 .902 r
.73953 .29228 .7425 .29638 .74908 .29376 .74611 .28969 Metetra
.683 .753 .904 r
.74611 .28969 .74908 .29376 .75566 .29117 .75271 .28711 Metetra
.683 .753 .905 r
.75271 .28711 .75566 .29117 .76227 .28861 .75933 .28453 Metetra
.682 .753 .905 r
.75933 .28453 .76227 .28861 .76889 .28606 .76596 .28196 Metetra
.681 .751 .904 r
.76596 .28196 .76889 .28606 .77552 .28353 .7726 .2794 Metetra
.68 .75 .904 r
.7726 .2794 .77552 .28353 .78217 .281 .77926 .27685 Metetra
.679 .749 .904 r
.77926 .27685 .78217 .281 .78884 .27849 .78594 .27432 Metetra
.678 .748 .904 r
.78594 .27432 .78884 .27849 .79552 .27598 .79263 .2718 Metetra
.677 .748 .904 r
.79263 .2718 .79552 .27598 .80222 .27348 .79934 .26929 Metetra
.676 .747 .905 r
.79934 .26929 .80222 .27348 .80893 .27099 .80606 .26679 Metetra
.675 .747 .905 r
.80606 .26679 .80893 .27099 .81566 .2685 .8128 .2643 Metetra
.675 .747 .905 r
.8128 .2643 .81566 .2685 .8224 .26602 .81956 .26181 Metetra
.674 .747 .906 r
.81956 .26181 .8224 .26602 .82917 .26355 .82633 .25933 Metetra
.674 .747 .906 r
.82633 .25933 .82917 .26355 .83594 .26108 .83312 .25685 Metetra
.673 .747 .906 r
.83312 .25685 .83594 .26108 .84273 .25862 .83993 .25437 Metetra
.673 .746 .906 r
.83993 .25437 .84273 .25862 .84954 .25615 .84675 .2519 Metetra
.657 .74 .911 r
.23617 .45186 .23986 .45529 .24535 .45353 .24166 .45009 Metetra
.657 .74 .911 r
.24166 .45009 .24535 .45353 .25085 .45176 .24717 .44831 Metetra
.656 .74 .911 r
.24717 .44831 .25085 .45176 .25636 .44999 .25268 .44654 Metetra
.656 .74 .912 r
.25268 .44654 .25636 .44999 .26188 .44823 .25821 .44476 Metetra
.656 .74 .912 r
.25821 .44476 .26188 .44823 .26742 .44646 .26375 .44299 Metetra
.656 .74 .912 r
.26375 .44299 .26742 .44646 .27296 .44469 .26931 .44122 Metetra
.655 .74 .912 r
.26931 .44122 .27296 .44469 .27852 .44293 .27487 .43944 Metetra
.655 .74 .912 r
.27487 .43944 .27852 .44293 .28409 .44116 .28045 .43767 Metetra
.654 .74 .912 r
.28045 .43767 .28409 .44116 .28967 .43941 .28604 .43591 Metetra
.654 .739 .913 r
.28604 .43591 .28967 .43941 .29527 .43765 .29164 .43415 Metetra
.654 .739 .913 r
.29164 .43415 .29527 .43765 .30087 .43589 .29725 .43238 Metetra
.653 .739 .913 r
.29725 .43238 .30087 .43589 .30649 .43413 .30287 .43061 Metetra
.654 .739 .913 r
.30287 .43061 .30649 .43413 .31212 .43237 .30851 .42884 Metetra
.654 .739 .913 r
.30851 .42884 .31212 .43237 .31776 .4306 .31416 .42707 Metetra
.653 .739 .913 r
.31416 .42707 .31776 .4306 .32342 .42884 .31982 .42529 Metetra
.652 .739 .913 r
.31982 .42529 .32342 .42884 .32908 .42708 .3255 .42353 Metetra
.65 .738 .914 r
.3255 .42353 .32908 .42708 .33476 .42536 .33118 .4218 Metetra
.647 .738 .915 r
.33118 .4218 .33476 .42536 .34045 .42366 .33688 .4201 Metetra
.645 .737 .916 r
.33688 .4201 .34045 .42366 .34615 .42199 .34258 .41842 Metetra
.645 .737 .916 r
.34258 .41842 .34615 .42199 .35186 .42032 .3483 .41674 Metetra
.646 .737 .915 r
.3483 .41674 .35186 .42032 .35759 .41863 .35404 .41504 Metetra
.65 .738 .914 r
.35404 .41504 .35759 .41863 .36333 .41688 .35979 .41329 Metetra
.654 .74 .912 r
.35979 .41329 .36333 .41688 .36909 .41507 .36555 .41147 Metetra
.656 .74 .912 r
.36555 .41147 .36909 .41507 .37486 .41322 .37134 .40961 Metetra
.653 .739 .913 r
.37134 .40961 .37486 .41322 .38065 .41141 .37713 .4078 Metetra
.643 .736 .916 r
.37713 .4078 .38065 .41141 .38644 .40974 .38293 .40612 Metetra
.627 .731 .922 r
.38293 .40612 .38644 .40974 .39223 .40828 .38873 .40465 Metetra
.609 .725 .927 r
.38873 .40465 .39223 .40828 .39804 .40705 .39454 .40341 Metetra
.6 .722 .93 r
.39454 .40341 .39804 .40705 .40385 .40593 .40036 .40228 Metetra
.608 .725 .928 r
.40036 .40228 .40385 .40593 .40968 .4047 .40619 .40105 Metetra
.635 .734 .919 r
.40619 .40105 .40968 .4047 .41554 .40312 .41206 .39946 Metetra
.669 .744 .907 r
.41206 .39946 .41554 .40312 .42143 .40104 .41796 .39737 Metetra
.694 .751 .896 r
.41796 .39737 .42143 .40104 .42734 .39853 .42388 .39485 Metetra
.697 .752 .894 r
.42388 .39485 .42734 .39853 .43327 .39597 .42982 .39229 Metetra
.663 .742 .909 r
.42982 .39229 .43327 .39597 .43919 .39397 .43575 .39028 Metetra
.574 .712 .936 r
.43575 .39028 .43919 .39397 .4451 .39312 .44166 .38942 Metetra
.417 .641 .949 r
.44166 .38942 .4451 .39312 .45099 .39371 .44756 .39 Metetra
.255 .553 .93 r
.44756 .39 .45099 .39371 .45688 .39539 .45345 .39168 Metetra
.243 .547 .928 r
.45345 .39168 .45688 .39539 .46279 .39715 .45937 .39343 Metetra
.443 .654 .95 r
.45937 .39343 .46279 .39715 .46876 .39753 .46534 .39381 Metetra
.679 .749 .904 r
.46534 .39381 .46876 .39753 .47479 .39524 .47138 .39151 Metetra
.803 .774 .826 r
.47138 .39151 .47479 .39524 .48087 .38989 .47748 .38615 Metetra
.845 .775 .784 r
.47748 .38615 .48087 .38989 .48698 .38259 .4836 .37883 Metetra
.832 .776 .799 r
.4836 .37883 .48698 .38259 .49308 .37603 .48971 .37226 Metetra
.665 .743 .908 r
.48971 .37226 .49308 .37603 .49913 .37395 .49577 .37017 Metetra
0 .019 .539 r
.49577 .37017 .49913 .37395 .50515 .3801 .50179 .37633 Metetra
.904 .499 .11 r
.50179 .37633 .50515 .3801 .51117 .39701 .5078 .39324 Metetra
.947 .588 .26 r
.5078 .39324 .51117 .39701 .51724 .4249 .51385 .42115 Metetra
.955 .614 .306 r
.51385 .42115 .51724 .4249 .52344 .4611 .52002 .45737 Metetra
.957 .618 .314 r
.52002 .45737 .52344 .4611 .52981 .50014 .52635 .49645 Metetra
.953 .605 .29 r
.52635 .49645 .52981 .50014 .53633 .5348 .53285 .53114 Metetra
.93 .547 .192 r
.53285 .53114 .53633 .5348 .54295 .55794 .53945 .5543 Metetra
0 0 .498 r
.53945 .5543 .54295 .55794 .54957 .56474 .54607 .5611 Metetra
.892 .792 .744 r
.54607 .5611 .54957 .56474 .55607 .55428 .55259 .55062 Metetra
.949 .756 .609 r
.55259 .55062 .55607 .55428 .5624 .52965 .55895 .52596 Metetra
.958 .743 .571 r
.55895 .52596 .5624 .52965 .56854 .49665 .56513 .49292 Metetra
.959 .74 .563 r
.56513 .49292 .56854 .49665 .57455 .46172 .57119 .45794 Metetra
.957 .743 .572 r
.57119 .45794 .57455 .46172 .5805 .43014 .57718 .42632 Metetra
.951 .752 .599 r
.57718 .42632 .5805 .43014 .58647 .40503 .58318 .40119 Metetra
.935 .766 .648 r
.58318 .40119 .58647 .40503 .59252 .38727 .58926 .3834 Metetra
.901 .781 .72 r
.58926 .3834 .59252 .38727 .59867 .37589 .59542 .37201 Metetra
.841 .786 .798 r
.59542 .37201 .59867 .37589 .60491 .36893 .60168 .36504 Metetra
.781 .779 .851 r
.60168 .36504 .60491 .36893 .6112 .36425 .60798 .36034 Metetra
.761 .775 .864 r
.60798 .36034 .6112 .36425 .61752 .36011 .61431 .35619 Metetra
.777 .778 .854 r
.61431 .35619 .61752 .36011 .62383 .35556 .62063 .35163 Metetra
.797 .782 .839 r
.62063 .35163 .62383 .35556 .63012 .35036 .62694 .34642 Metetra
.808 .784 .83 r
.62694 .34642 .63012 .35036 .6364 .34481 .63323 .34086 Metetra
.804 .783 .833 r
.63323 .34086 .6364 .34481 .64269 .33938 .63953 .33541 Metetra
.789 .78 .845 r
.63953 .33541 .64269 .33938 .649 .33446 .64585 .33048 Metetra
.764 .775 .862 r
.64585 .33048 .649 .33446 .65534 .33023 .6522 .32624 Metetra
.737 .768 .878 r
.6522 .32624 .65534 .33023 .66171 .32664 .65859 .32264 Metetra
.715 .761 .889 r
.65859 .32264 .66171 .32664 .66812 .32352 .66501 .31951 Metetra
.703 .757 .894 r
.66501 .31951 .66812 .32352 .67454 .32063 .67144 .31661 Metetra
.7 .756 .895 r
.67144 .31661 .67454 .32063 .68099 .31778 .6779 .31375 Metetra
.703 .757 .894 r
.6779 .31375 .68099 .31778 .68744 .31488 .68436 .31085 Metetra
.706 .758 .893 r
.68436 .31085 .68744 .31488 .6939 .31192 .69083 .30787 Metetra
.707 .759 .892 r
.69083 .30787 .6939 .31192 .70037 .30893 .69731 .30487 Metetra
.706 .758 .893 r
.69731 .30487 .70037 .30893 .70685 .30596 .7038 .3019 Metetra
.702 .757 .895 r
.7038 .3019 .70685 .30596 .71335 .30307 .71031 .29899 Metetra
.697 .755 .897 r
.71031 .29899 .71335 .30307 .71987 .30027 .71684 .29618 Metetra
.692 .753 .899 r
.71684 .29618 .71987 .30027 .7264 .29755 .72339 .29345 Metetra
.688 .752 .9 r
.72339 .29345 .7264 .29755 .73296 .2949 .72995 .29079 Metetra
.685 .751 .901 r
.72995 .29079 .73296 .2949 .73953 .29228 .73653 .28817 Metetra
.684 .75 .902 r
.73653 .28817 .73953 .29228 .74611 .28969 .74313 .28556 Metetra
.683 .75 .902 r
.74313 .28556 .74611 .28969 .75271 .28711 .74974 .28297 Metetra
.683 .75 .902 r
.74974 .28297 .75271 .28711 .75933 .28453 .75637 .28038 Metetra
.682 .75 .903 r
.75637 .28038 .75933 .28453 .76596 .28196 .76301 .2778 Metetra
.681 .749 .903 r
.76301 .2778 .76596 .28196 .7726 .2794 .76966 .27523 Metetra
.68 .749 .903 r
.76966 .27523 .7726 .2794 .77926 .27685 .77634 .27267 Metetra
.679 .748 .904 r
.77634 .27267 .77926 .27685 .78594 .27432 .78302 .27013 Metetra
.678 .748 .904 r
.78302 .27013 .78594 .27432 .79263 .2718 .78973 .2676 Metetra
.677 .748 .904 r
.78973 .2676 .79263 .2718 .79934 .26929 .79645 .26509 Metetra
.676 .747 .905 r
.79645 .26509 .79934 .26929 .80606 .26679 .80318 .26258 Metetra
.675 .747 .905 r
.80318 .26258 .80606 .26679 .8128 .2643 .80994 .26008 Metetra
.675 .747 .905 r
.80994 .26008 .8128 .2643 .81956 .26181 .8167 .25758 Metetra
.674 .747 .905 r
.8167 .25758 .81956 .26181 .82633 .25933 .82349 .25508 Metetra
.674 .746 .905 r
.82349 .25508 .82633 .25933 .83312 .25685 .83029 .25259 Metetra
.673 .746 .906 r
.83029 .25259 .83312 .25685 .83993 .25437 .8371 .25011 Metetra
.673 .746 .906 r
.8371 .25011 .83993 .25437 .84675 .2519 .84394 .24762 Metetra
.657 .74 .911 r
.23245 .44841 .23617 .45186 .24166 .45009 .23796 .44663 Metetra
.657 .74 .911 r
.23796 .44663 .24166 .45009 .24717 .44831 .24347 .44485 Metetra
.656 .74 .911 r
.24347 .44485 .24717 .44831 .25268 .44654 .24899 .44307 Metetra
.656 .74 .912 r
.24899 .44307 .25268 .44654 .25821 .44476 .25453 .44129 Metetra
.656 .74 .912 r
.25453 .44129 .25821 .44476 .26375 .44299 .26008 .43951 Metetra
.655 .74 .912 r
.26008 .43951 .26375 .44299 .26931 .44122 .26564 .43773 Metetra
.655 .74 .912 r
.26564 .43773 .26931 .44122 .27487 .43944 .27121 .43596 Metetra
.655 .74 .912 r
.27121 .43596 .27487 .43944 .28045 .43767 .27679 .43418 Metetra
.655 .74 .912 r
.27679 .43418 .28045 .43767 .28604 .43591 .28239 .4324 Metetra
.654 .74 .912 r
.28239 .4324 .28604 .43591 .29164 .43415 .28799 .43062 Metetra
.654 .739 .912 r
.28799 .43062 .29164 .43415 .29725 .43238 .29361 .42884 Metetra
.654 .738 .912 r
.29361 .42884 .29725 .43238 .30287 .43061 .29925 .42706 Metetra
.653 .738 .912 r
.29925 .42706 .30287 .43061 .30851 .42884 .30489 .4253 Metetra
.652 .738 .913 r
.30489 .4253 .30851 .42884 .31416 .42707 .31055 .42353 Metetra
.651 .74 .914 r
.31055 .42353 .31416 .42707 .31982 .42529 .31621 .42178 Metetra
.65 .741 .916 r
.31621 .42178 .31982 .42529 .3255 .42353 .32189 .42004 Metetra
.65 .742 .917 r
.32189 .42004 .3255 .42353 .33118 .4218 .32758 .4183 Metetra
.65 .742 .917 r
.32758 .4183 .33118 .4218 .33688 .4201 .33329 .41655 Metetra
.651 .74 .915 r
.33329 .41655 .33688 .4201 .34258 .41842 .33901 .41478 Metetra
.651 .736 .911 r
.33901 .41478 .34258 .41842 .3483 .41674 .34474 .41301 Metetra
.651 .731 .908 r
.34474 .41301 .3483 .41674 .35404 .41504 .35048 .41125 Metetra
.648 .727 .906 r
.35048 .41125 .35404 .41504 .35979 .41329 .35624 .40951 Metetra
.644 .727 .908 r
.35624 .40951 .35979 .41329 .36555 .41147 .36201 .40782 Metetra
.639 .733 .917 r
.36201 .40782 .36555 .41147 .37134 .40961 .36778 .4062 Metetra
.634 .746 .929 r
.36778 .4062 .37134 .40961 .37713 .4078 .37357 .40464 Metetra
.63 .761 .942 r
.37357 .40464 .37713 .4078 .38293 .40612 .37937 .40308 Metetra
.633 .771 .946 r
.37937 .40308 .38293 .40612 .38873 .40465 .38519 .40146 Metetra
.643 .764 .937 r
.38519 .40146 .38873 .40465 .39454 .40341 .39103 .39974 Metetra
.653 .738 .912 r
.39103 .39974 .39454 .40341 .40036 .40228 .39688 .39791 Metetra
.654 .702 .882 r
.39688 .39791 .40036 .40228 .40619 .40105 .40275 .39604 Metetra
.645 .669 .859 r
.40275 .39604 .40619 .40105 .41206 .39946 .40863 .39426 Metetra
.63 .656 .857 r
.40863 .39426 .41206 .39946 .41796 .39737 .41451 .39275 Metetra
.607 .673 .887 r
.41451 .39275 .41796 .39737 .42388 .39485 .42039 .39161 Metetra
.558 .735 .958 r
.42039 .39161 .42388 .39485 .42982 .39229 .42628 .39081 Metetra
.419 .8 .991 r
.42628 .39081 .42982 .39229 .43575 .39028 .43219 .39013 Metetra
.243 .756 .852 r
.43219 .39013 .43575 .39028 .44166 .38942 .43812 .38924 Metetra
.371 .833 .902 r
.43812 .38924 .44166 .38942 .44756 .39 .44407 .38781 Metetra
.657 .841 .971 r
.44407 .38781 .44756 .39 .45345 .39168 .45006 .38569 Metetra
.676 .648 .815 r
.45006 .38569 .45345 .39168 .45937 .39343 .45608 .38306 Metetra
.637 .536 .724 r
.45608 .38306 .45937 .39343 .46534 .39381 .4621 .3805 Metetra
.6 .482 .691 r
.4621 .3805 .46534 .39381 .47138 .39151 .46812 .37882 Metetra
.556 .46 .701 r
.46812 .37882 .47138 .39151 .47748 .38615 .47413 .37878 Metetra
.417 .472 .809 r
.47413 .37878 .47748 .38615 .4836 .37883 .48013 .3808 Metetra
.645 .146 .05 r
.48013 .3808 .4836 .37883 .48971 .37226 .48613 .38473 Metetra
.628 .296 .389 r
.48613 .38473 .48971 .37226 .49577 .37017 .49216 .38981 Metetra
.604 .305 .435 r
.49216 .38981 .49577 .37017 .50179 .37633 .49823 .39489 Metetra
.59 .288 .425 r
.49823 .39489 .50179 .37633 .5078 .39324 .50435 .39884 Metetra
.562 .144 .206 r
.50435 .39884 .5078 .39324 .51385 .42115 .51052 .40095 Metetra
.548 .408 .643 r
.51052 .40095 .51385 .42115 .52002 .45737 .51672 .40125 Metetra
.554 .36 .573 r
.51672 .40125 .52002 .45737 .52635 .49645 .52294 .40038 Metetra
.55 .345 .556 r
.52294 .40038 .52635 .49645 .53285 .53114 .52918 .39939 Metetra
.546 .337 .549 r
.52918 .39939 .53285 .53114 .53945 .5543 .53544 .39917 Metetra
.542 .333 .546 r
.53544 .39917 .53945 .5543 .54607 .5611 .54173 .40009 Metetra
.541 .331 .545 r
.54173 .40009 .54607 .5611 .55259 .55062 .54805 .40183 Metetra
.541 .332 .546 r
.54805 .40183 .55259 .55062 .55895 .52596 .5544 .40343 Metetra
.544 .337 .55 r
.5544 .40343 .55895 .52596 .56513 .49292 .56076 .40371 Metetra
.555 .35 .558 r
.56076 .40371 .56513 .49292 .57119 .45794 .56712 .40165 Metetra
.578 .379 .574 r
.56712 .40165 .57119 .45794 .57718 .42632 .57345 .39684 Metetra
.632 .442 .609 r
.57345 .39684 .57718 .42632 .58318 .40119 .57974 .38952 Metetra
.748 .59 .68 r
.57974 .38952 .58318 .40119 .58926 .3834 .586 .38056 Metetra
.904 .826 .76 r
.586 .38056 .58926 .3834 .59542 .37201 .59223 .37106 Metetra
.931 .914 .778 r
.59223 .37106 .59542 .37201 .60168 .36504 .59845 .36204 Metetra
.878 .828 .794 r
.59845 .36204 .60168 .36504 .60798 .36034 .60469 .3542 Metetra
.785 .696 .766 r
.60469 .3542 .60798 .36034 .61431 .35619 .61097 .34775 Metetra
.721 .617 .741 r
.61097 .34775 .61431 .35619 .62063 .35163 .61727 .34257 Metetra
.692 .592 .739 r
.61727 .34257 .62063 .35163 .62694 .34642 .62361 .33826 Metetra
.69 .607 .759 r
.62361 .33826 .62694 .34642 .63323 .34086 .62996 .33442 Metetra
.707 .658 .799 r
.62996 .33442 .63323 .34086 .63953 .33541 .63633 .33072 Metetra
.732 .732 .85 r
.63633 .33072 .63953 .33541 .64585 .33048 .64271 .32699 Metetra
.751 .799 .892 r
.64271 .32699 .64585 .33048 .6522 .32624 .6491 .32323 Metetra
.754 .83 .91 r
.6491 .32323 .6522 .32624 .65859 .32264 .65549 .3195 Metetra
.746 .82 .91 r
.65549 .3195 .65859 .32264 .66501 .31951 .6619 .3159 Metetra
.732 .789 .898 r
.6619 .3159 .66501 .31951 .67144 .31661 .66833 .31249 Metetra
.717 .757 .884 r
.66833 .31249 .67144 .31661 .6779 .31375 .67477 .30928 Metetra
.704 .736 .876 r
.67477 .30928 .6779 .31375 .68436 .31085 .68124 .30626 Metetra
.697 .728 .874 r
.68124 .30626 .68436 .31085 .69083 .30787 .68772 .30336 Metetra
.694 .731 .879 r
.68772 .30336 .69083 .30787 .69731 .30487 .69422 .30053 Metetra
.694 .74 .887 r
.69422 .30053 .69731 .30487 .7038 .3019 .70074 .29773 Metetra
.694 .75 .894 r
.70074 .29773 .7038 .3019 .71031 .29899 .70727 .29495 Metetra
.694 .757 .9 r
.70727 .29495 .71031 .29899 .71684 .29618 .71381 .29218 Metetra
.693 .759 .903 r
.71381 .29218 .71684 .29618 .72339 .29345 .72037 .28943 Metetra
.691 .758 .903 r
.72037 .28943 .72339 .29345 .72995 .29079 .72694 .28671 Metetra
.688 .754 .902 r
.72694 .28671 .72995 .29079 .73653 .28817 .73353 .28403 Metetra
.686 .751 .901 r
.73353 .28403 .73653 .28817 .74313 .28556 .74013 .28138 Metetra
.684 .748 .9 r
.74013 .28138 .74313 .28556 .74974 .28297 .74676 .27876 Metetra
.682 .747 .9 r
.74676 .27876 .74974 .28297 .75637 .28038 .75339 .27617 Metetra
.681 .746 .901 r
.75339 .27617 .75637 .28038 .76301 .2778 .76005 .27359 Metetra
.68 .747 .902 r
.76005 .27359 .76301 .2778 .76966 .27523 .76671 .27103 Metetra
.679 .748 .903 r
.76671 .27103 .76966 .27523 .77634 .27267 .7734 .26847 Metetra
.678 .748 .904 r
.7734 .26847 .77634 .27267 .78302 .27013 .7801 .26593 Metetra
.678 .748 .904 r
.7801 .26593 .78302 .27013 .78973 .2676 .78681 .26339 Metetra
.677 .748 .904 r
.78681 .26339 .78973 .2676 .79645 .26509 .79355 .26086 Metetra
.676 .747 .905 r
.79355 .26086 .79645 .26509 .80318 .26258 .80029 .25834 Metetra
.675 .747 .905 r
.80029 .25834 .80318 .26258 .80994 .26008 .80706 .25582 Metetra
.675 .746 .905 r
.80706 .25582 .80994 .26008 .8167 .25758 .81383 .25332 Metetra
.674 .746 .905 r
.81383 .25332 .8167 .25758 .82349 .25508 .82063 .25081 Metetra
.674 .746 .905 r
.82063 .25081 .82349 .25508 .83029 .25259 .82744 .24831 Metetra
.673 .746 .905 r
.82744 .24831 .83029 .25259 .8371 .25011 .83427 .24582 Metetra
.673 .746 .906 r
.83427 .24582 .8371 .25011 .84394 .24762 .84111 .24332 Metetra
.657 .74 .911 r
.22873 .44496 .23245 .44841 .23796 .44663 .23424 .44317 Metetra
.657 .74 .911 r
.23424 .44317 .23796 .44663 .24347 .44485 .23975 .44138 Metetra
.656 .74 .912 r
.23975 .44138 .24347 .44485 .24899 .44307 .24529 .43959 Metetra
.656 .74 .912 r
.24529 .43959 .24899 .44307 .25453 .44129 .25083 .43781 Metetra
.656 .74 .912 r
.25083 .43781 .25453 .44129 .26008 .43951 .25638 .43602 Metetra
.655 .74 .912 r
.25638 .43602 .26008 .43951 .26564 .43773 .26195 .43424 Metetra
.655 .74 .912 r
.26195 .43424 .26564 .43773 .27121 .43596 .26753 .43245 Metetra
.655 .74 .912 r
.26753 .43245 .27121 .43596 .27679 .43418 .27312 .43066 Metetra
.655 .74 .912 r
.27312 .43066 .27679 .43418 .28239 .4324 .27872 .42887 Metetra
.655 .74 .912 r
.27872 .42887 .28239 .4324 .28799 .43062 .28434 .42708 Metetra
.654 .739 .912 r
.28434 .42708 .28799 .43062 .29361 .42884 .28996 .42529 Metetra
.653 .739 .912 r
.28996 .42529 .29361 .42884 .29925 .42706 .2956 .42351 Metetra
.652 .739 .913 r
.2956 .42351 .29925 .42706 .30489 .4253 .30125 .42175 Metetra
.651 .739 .914 r
.30125 .42175 .30489 .4253 .31055 .42353 .30691 .42 Metetra
.65 .74 .915 r
.30691 .42 .31055 .42353 .31621 .42178 .31259 .41826 Metetra
.65 .741 .916 r
.31259 .41826 .31621 .42178 .32189 .42004 .31827 .41651 Metetra
.651 .742 .916 r
.31827 .41651 .32189 .42004 .32758 .4183 .32397 .41474 Metetra
.653 .741 .914 r
.32397 .41474 .32758 .4183 .33329 .41655 .32969 .41295 Metetra
.654 .739 .912 r
.32969 .41295 .33329 .41655 .33901 .41478 .33542 .41112 Metetra
.654 .736 .91 r
.33542 .41112 .33901 .41478 .34474 .41301 .34116 .4093 Metetra
.651 .733 .909 r
.34116 .4093 .34474 .41301 .35048 .41125 .34691 .40753 Metetra
.644 .73 .912 r
.34691 .40753 .35048 .41125 .35624 .40951 .35267 .40584 Metetra
.635 .731 .918 r
.35267 .40584 .35624 .40951 .36201 .40782 .35844 .40428 Metetra
.626 .736 .926 r
.35844 .40428 .36201 .40782 .36778 .4062 .36421 .40282 Metetra
.624 .746 .934 r
.36421 .40282 .36778 .4062 .37357 .40464 .37 .40136 Metetra
.632 .756 .937 r
.37 .40136 .37357 .40464 .37937 .40308 .37581 .39979 Metetra
.65 .761 .93 r
.37581 .39979 .37937 .40308 .38519 .40146 .38165 .39798 Metetra
.669 .754 .914 r
.38165 .39798 .38519 .40146 .39103 .39974 .38751 .39589 Metetra
.678 .736 .895 r
.38751 .39589 .39103 .39974 .39688 .39791 .39338 .39364 Metetra
.669 .712 .881 r
.39338 .39364 .39688 .39791 .40275 .39604 .39927 .39151 Metetra
.64 .69 .881 r
.39927 .39151 .40275 .39604 .40863 .39426 .40515 .38985 Metetra
.587 .676 .902 r
.40515 .38985 .40863 .39426 .41451 .39275 .41102 .38895 Metetra
.504 .677 .943 r
.41102 .38895 .41451 .39275 .42039 .39161 .41687 .38883 Metetra
.389 .694 .981 r
.41687 .38883 .42039 .39161 .42628 .39081 .42274 .3891 Metetra
.325 .738 .978 r
.42274 .3891 .42628 .39081 .43219 .39013 .42863 .38905 Metetra
.465 .847 .984 r
.42863 .38905 .43219 .39013 .43812 .38924 .43458 .38784 Metetra
.708 .905 .965 r
.43458 .38784 .43812 .38924 .44407 .38781 .44059 .3849 Metetra
.792 .815 .871 r
.44059 .3849 .44407 .38781 .45006 .38569 .44665 .38041 Metetra
.762 .704 .796 r
.44665 .38041 .45006 .38569 .45608 .38306 .45272 .37546 Metetra
.689 .612 .765 r
.45272 .37546 .45608 .38306 .4621 .3805 .45877 .37193 Metetra
.552 .518 .772 r
.45877 .37193 .4621 .3805 .46812 .37882 .46476 .37189 Metetra
.104 .293 .77 r
.46476 .37189 .46812 .37882 .47413 .37878 .47068 .37686 Metetra
.837 .368 .022 r
.47068 .37686 .47413 .37878 .48013 .3808 .47656 .38699 Metetra
.802 .437 .365 r
.47656 .38699 .48013 .3808 .48613 .38473 .48246 .4006 Metetra
.72 .402 .441 r
.48246 .4006 .48613 .38473 .49216 .38981 .48843 .41434 Metetra
.642 .351 .461 r
.48843 .41434 .49216 .38981 .49823 .39489 .49452 .42398 Metetra
.551 .278 .454 r
.49452 .42398 .49823 .39489 .50435 .39884 .50072 .42583 Metetra
.403 .148 .41 r
.50072 .42583 .50435 .39884 .51052 .40095 .507 .41814 Metetra
0 0 .181 r
.507 .41814 .51052 .40095 .51672 .40125 .5133 .40193 Metetra
.987 .832 .603 r
.5133 .40193 .51672 .40125 .52294 .40038 .51958 .38082 Metetra
.785 .571 .611 r
.51958 .38082 .52294 .40038 .52918 .39939 .52579 .35971 Metetra
.672 .459 .588 r
.52579 .35971 .52918 .39939 .53544 .39917 .53195 .34331 Metetra
.6 .395 .574 r
.53195 .34331 .53544 .39917 .54173 .40009 .53811 .33469 Metetra
.547 .35 .565 r
.53811 .33469 .54173 .40009 .54805 .40183 .5443 .33461 Metetra
.505 .318 .561 r
.5443 .33461 .54805 .40183 .5544 .40343 .55057 .34152 Metetra
.475 .298 .56 r
.55057 .34152 .5544 .40343 .56076 .40371 .55694 .3522 Metetra
.46 .293 .567 r
.55694 .3522 .56076 .40371 .56712 .40165 .56336 .36283 Metetra
.47 .312 .584 r
.56336 .36283 .56712 .40165 .57345 .39684 .5698 .37015 Metetra
.519 .368 .616 r
.5698 .37015 .57345 .39684 .57974 .38952 .57622 .37236 Metetra
.612 .467 .66 r
.57622 .37236 .57974 .38952 .586 .38056 .58257 .36942 Metetra
.719 .579 .697 r
.58257 .36942 .586 .38056 .59223 .37106 .58886 .36271 Metetra
.784 .648 .713 r
.58886 .36271 .59223 .37106 .59845 .36204 .59511 .35427 Metetra
.79 .661 .721 r
.59511 .35427 .59845 .36204 .60469 .3542 .60135 .346 Metetra
.759 .64 .729 r
.60135 .346 .60469 .3542 .61097 .34775 .60761 .33915 Metetra
.715 .611 .74 r
.60761 .33915 .61097 .34775 .61727 .34257 .61393 .33412 Metetra
.677 .595 .757 r
.61393 .33412 .61727 .34257 .62361 .33826 .62029 .33062 Metetra
.657 .603 .782 r
.62029 .33062 .62361 .33826 .62996 .33442 .62669 .32798 Metetra
.661 .638 .816 r
.62669 .32798 .62996 .33442 .63633 .33072 .63311 .32551 Metetra
.686 .694 .852 r
.63311 .32551 .63633 .33072 .64271 .32699 .63953 .32274 Metetra
.718 .75 .877 r
.63953 .32274 .64271 .32699 .6491 .32323 .64595 .31948 Metetra
.742 .784 .887 r
.64595 .31948 .6491 .32323 .65549 .3195 .65236 .31583 Metetra
.75 .791 .887 r
.65236 .31583 .65549 .3195 .6619 .3159 .65877 .31204 Metetra
.743 .779 .883 r
.65877 .31204 .6619 .3159 .66833 .31249 .66519 .30834 Metetra
.728 .76 .879 r
.66519 .30834 .66833 .31249 .67477 .30928 .67164 .30489 Metetra
.711 .743 .877 r
.67164 .30489 .67477 .30928 .68124 .30626 .67811 .30174 Metetra
.697 .732 .878 r
.67811 .30174 .68124 .30626 .68772 .30336 .68461 .29885 Metetra
.689 .73 .882 r
.68461 .29885 .68772 .30336 .69422 .30053 .69112 .29612 Metetra
.686 .735 .887 r
.69112 .29612 .69422 .30053 .70074 .29773 .69766 .29345 Metetra
.687 .742 .893 r
.69766 .29345 .70074 .29773 .70727 .29495 .7042 .29077 Metetra
.69 .749 .897 r
.7042 .29077 .70727 .29495 .71381 .29218 .71076 .28806 Metetra
.691 .754 .899 r
.71076 .28806 .71381 .29218 .72037 .28943 .71733 .28533 Metetra
.691 .755 .9 r
.71733 .28533 .72037 .28943 .72694 .28671 .72391 .28258 Metetra
.69 .754 .9 r
.72391 .28258 .72694 .28671 .73353 .28403 .73051 .27986 Metetra
.687 .751 .9 r
.73051 .27986 .73353 .28403 .74013 .28138 .73713 .27718 Metetra
.685 .749 .9 r
.73713 .27718 .74013 .28138 .74676 .27876 .74376 .27453 Metetra
.682 .747 .9 r
.74376 .27453 .74676 .27876 .75339 .27617 .75041 .27193 Metetra
.68 .746 .901 r
.75041 .27193 .75339 .27617 .76005 .27359 .75707 .26935 Metetra
.679 .746 .901 r
.75707 .26935 .76005 .27359 .76671 .27103 .76375 .26679 Metetra
.678 .746 .902 r
.76375 .26679 .76671 .27103 .7734 .26847 .77045 .26424 Metetra
.678 .747 .903 r
.77045 .26424 .7734 .26847 .7801 .26593 .77716 .26169 Metetra
.677 .747 .904 r
.77716 .26169 .7801 .26593 .78681 .26339 .78389 .25915 Metetra
.677 .747 .904 r
.78389 .25915 .78681 .26339 .79355 .26086 .79063 .25661 Metetra
.676 .747 .904 r
.79063 .25661 .79355 .26086 .80029 .25834 .79739 .25408 Metetra
.675 .747 .904 r
.79739 .25408 .80029 .25834 .80706 .25582 .80416 .25155 Metetra
.675 .746 .905 r
.80416 .25155 .80706 .25582 .81383 .25332 .81095 .24903 Metetra
.674 .746 .905 r
.81095 .24903 .81383 .25332 .82063 .25081 .81776 .24652 Metetra
.673 .746 .905 r
.81776 .24652 .82063 .25081 .82744 .24831 .82458 .24401 Metetra
.673 .746 .905 r
.82458 .24401 .82744 .24831 .83427 .24582 .83142 .2415 Metetra
.673 .745 .905 r
.83142 .2415 .83427 .24582 .84111 .24332 .83828 .239 Metetra
.657 .74 .911 r
.22499 .44149 .22873 .44496 .23424 .44317 .2305 .43969 Metetra
.657 .74 .912 r
.2305 .43969 .23424 .44317 .23975 .44138 .23603 .4379 Metetra
.656 .74 .912 r
.23603 .4379 .23975 .44138 .24529 .43959 .24157 .43611 Metetra
.656 .74 .912 r
.24157 .43611 .24529 .43959 .25083 .43781 .24711 .43431 Metetra
.656 .74 .912 r
.24711 .43431 .25083 .43781 .25638 .43602 .25268 .43252 Metetra
.656 .74 .912 r
.25268 .43252 .25638 .43602 .26195 .43424 .25825 .43072 Metetra
.655 .74 .912 r
.25825 .43072 .26195 .43424 .26753 .43245 .26384 .42893 Metetra
.655 .74 .912 r
.26384 .42893 .26753 .43245 .27312 .43066 .26943 .42713 Metetra
.655 .74 .912 r
.26943 .42713 .27312 .43066 .27872 .42887 .27504 .42533 Metetra
.654 .74 .912 r
.27504 .42533 .27872 .42887 .28434 .42708 .28066 .42354 Metetra
.653 .74 .913 r
.28066 .42354 .28434 .42708 .28996 .42529 .2863 .42176 Metetra
.652 .74 .914 r
.2863 .42176 .28996 .42529 .2956 .42351 .29194 .41998 Metetra
.652 .741 .915 r
.29194 .41998 .2956 .42351 .30125 .42175 .2976 .41822 Metetra
.651 .741 .915 r
.2976 .41822 .30125 .42175 .30691 .42 .30327 .41645 Metetra
.651 .74 .914 r
.30327 .41645 .30691 .42 .31259 .41826 .30895 .41468 Metetra
.652 .739 .913 r
.30895 .41468 .31259 .41826 .31827 .41651 .31465 .41289 Metetra
.653 .737 .912 r
.31465 .41289 .31827 .41651 .32397 .41474 .32036 .41109 Metetra
.653 .736 .91 r
.32036 .41109 .32397 .41474 .32969 .41295 .32608 .40929 Metetra
.651 .736 .911 r
.32608 .40929 .32969 .41295 .33542 .41112 .33181 .4075 Metetra
.648 .737 .914 r
.33181 .4075 .33542 .41112 .34116 .4093 .33756 .40575 Metetra
.643 .741 .92 r
.33756 .40575 .34116 .4093 .34691 .40753 .34331 .40406 Metetra
.638 .745 .926 r
.34331 .40406 .34691 .40753 .35267 .40584 .34907 .40244 Metetra
.635 .748 .93 r
.34907 .40244 .35267 .40584 .35844 .40428 .35485 .40085 Metetra
.636 .747 .928 r
.35485 .40085 .35844 .40428 .36421 .40282 .36064 .39923 Metetra
.643 .74 .92 r
.36064 .39923 .36421 .40282 .37 .40136 .36645 .39753 Metetra
.652 .729 .906 r
.36645 .39753 .37 .40136 .37581 .39979 .37228 .39571 Metetra
.658 .718 .893 r
.37228 .39571 .37581 .39979 .38165 .39798 .37812 .39378 Metetra
.658 .713 .888 r
.37812 .39378 .38165 .39798 .38751 .39589 .38398 .39184 Metetra
.649 .718 .898 r
.38398 .39184 .38751 .39589 .39338 .39364 .38985 .39004 Metetra
.627 .736 .926 r
.38985 .39004 .39338 .39364 .39927 .39151 .39572 .38854 Metetra
.582 .762 .964 r
.39572 .38854 .39927 .39151 .40515 .38985 .40158 .38742 Metetra
.521 .778 .991 r
.40158 .38742 .40515 .38985 .41102 .38895 .40746 .38663 Metetra
.501 .779 .994 r
.40746 .38663 .41102 .38895 .41687 .38883 .41334 .38592 Metetra
.562 .761 .971 r
.41334 .38592 .41687 .38883 .42274 .3891 .41925 .38495 Metetra
.633 .71 .902 r
.41925 .38495 .42274 .3891 .42863 .38905 .4252 .38338 Metetra
.666 .655 .83 r
.4252 .38338 .42863 .38905 .43458 .38784 .43119 .38104 Metetra
.678 .626 .79 r
.43119 .38104 .43458 .38784 .44059 .3849 .4372 .37813 Metetra
.677 .626 .791 r
.4372 .37813 .44059 .3849 .44665 .38041 .44322 .37522 Metetra
.654 .67 .853 r
.44322 .37522 .44665 .38041 .45272 .37546 .44924 .37321 Metetra
.408 .744 .993 r
.44924 .37321 .45272 .37546 .45877 .37193 .45522 .37305 Metetra
.52 0 0 r
.45522 .37305 .45877 .37193 .46476 .37189 .46117 .37544 Metetra
.688 .246 .197 r
.46117 .37544 .46476 .37189 .47068 .37686 .46711 .38055 Metetra
.743 .321 .247 r
.46711 .38055 .47068 .37686 .47656 .38699 .47305 .38778 Metetra
.792 .324 .126 r
.47305 .38778 .47656 .38699 .48246 .4006 .47903 .3958 Metetra
0 .001 .551 r
.47903 .3958 .48246 .4006 .48843 .41434 .48507 .4028 Metetra
.381 .365 .717 r
.48507 .4028 .48843 .41434 .49452 .42398 .4912 .40685 Metetra
.561 .432 .662 r
.4912 .40685 .49452 .42398 .50072 .42583 .49739 .40647 Metetra
.643 .477 .643 r
.49739 .40647 .50072 .42583 .507 .41814 .50365 .40107 Metetra
.713 .533 .645 r
.50365 .40107 .507 .41814 .5133 .40193 .50992 .39115 Metetra
.802 .626 .663 r
.50992 .39115 .5133 .40193 .51958 .38082 .51619 .37821 Metetra
.934 .802 .691 r
.51619 .37821 .51958 .38082 .52579 .35971 .52243 .36441 Metetra
.835 .908 .502 r
.52243 .36441 .52579 .35971 .53195 .34331 .52863 .35197 Metetra
.52863 .35197 .53195 .34331 .53811 .33469 .53483 .34267 Metetra
.159 0 .105 r
.53483 .34267 .53811 .33469 .5443 .33461 .54103 .33747 Metetra
.215 0 0 r
.54103 .33747 .5443 .33461 .55057 .34152 .54726 .33637 Metetra
.321 .509 .885 r
.54726 .33637 .55057 .34152 .55694 .3522 .55353 .33848 Metetra
.428 .37 .69 r
.55353 .33848 .55694 .3522 .56336 .36283 .55986 .3423 Metetra
.472 .355 .638 r
.55986 .3423 .56336 .36283 .5698 .37015 .56623 .34619 Metetra
.509 .368 .624 r
.56623 .34619 .5698 .37015 .57622 .37236 .57261 .34875 Metetra
.545 .394 .627 r
.57261 .34875 .57622 .37236 .58257 .36942 .57899 .34916 Metetra
.585 .434 .642 r
.57899 .34916 .58257 .36942 .58886 .36271 .58535 .3473 Metetra
.632 .49 .671 r
.58535 .3473 .58886 .36271 .59511 .35427 .59169 .34362 Metetra
.685 .565 .714 r
.59169 .34362 .59511 .35427 .60135 .346 .59802 .3389 Metetra
.733 .652 .769 r
.59802 .3389 .60135 .346 .60761 .33915 .60434 .33397 Metetra
.754 .719 .82 r
.60434 .33397 .60761 .33915 .61393 .33412 .61068 .32942 Metetra
.739 .734 .847 r
.61068 .32942 .61393 .33412 .62029 .33062 .61704 .32554 Metetra
.708 .707 .847 r
.61704 .32554 .62029 .33062 .62669 .32798 .62343 .32229 Metetra
.684 .674 .834 r
.62343 .32229 .62669 .32798 .63311 .32551 .62984 .31944 Metetra
.675 .657 .825 r
.62984 .31944 .63311 .32551 .63953 .32274 .63627 .3167 Metetra
.68 .661 .825 r
.63627 .3167 .63953 .32274 .64595 .31948 .64271 .31386 Metetra
.693 .682 .835 r
.64271 .31386 .64595 .31948 .65236 .31583 .64915 .3108 Metetra
.708 .711 .851 r
.64915 .3108 .65236 .31583 .65877 .31204 .6556 .30754 Metetra
.719 .74 .869 r
.6556 .30754 .65877 .31204 .66519 .30834 .66205 .3042 Metetra
.721 .759 .883 r
.66205 .3042 .66519 .30834 .67164 .30489 .66852 .30089 Metetra
.716 .766 .891 r
.66852 .30089 .67164 .30489 .67811 .30174 .675 .2977 Metetra
.707 .761 .894 r
.675 .2977 .67811 .30174 .68461 .29885 .6815 .29468 Metetra
.698 .751 .893 r
.6815 .29468 .68461 .29885 .69112 .29612 .68802 .29182 Metetra
.691 .743 .891 r
.68802 .29182 .69112 .29612 .69766 .29345 .69456 .28907 Metetra
.687 .738 .89 r
.69456 .28907 .69766 .29345 .7042 .29077 .70111 .28638 Metetra
.686 .737 .89 r
.70111 .28638 .7042 .29077 .71076 .28806 .70769 .28371 Metetra
.686 .74 .892 r
.70769 .28371 .71076 .28806 .71733 .28533 .71427 .28104 Metetra
.687 .744 .895 r
.71427 .28104 .71733 .28533 .72391 .28258 .72087 .27835 Metetra
.687 .747 .897 r
.72087 .27835 .72391 .28258 .73051 .27986 .72748 .27566 Metetra
.686 .75 .9 r
.72748 .27566 .73051 .27986 .73713 .27718 .73411 .27298 Metetra
.685 .75 .901 r
.73411 .27298 .73713 .27718 .74376 .27453 .74075 .27033 Metetra
.683 .749 .902 r
.74075 .27033 .74376 .27453 .75041 .27193 .74741 .2677 Metetra
.681 .748 .902 r
.74741 .2677 .75041 .27193 .75707 .26935 .75408 .2651 Metetra
.679 .747 .902 r
.75408 .2651 .75707 .26935 .76375 .26679 .76077 .26253 Metetra
.678 .746 .902 r
.76077 .26253 .76375 .26679 .77045 .26424 .76748 .25997 Metetra
.677 .746 .902 r
.76748 .25997 .77045 .26424 .77716 .26169 .7742 .25741 Metetra
.677 .746 .903 r
.7742 .25741 .77716 .26169 .78389 .25915 .78094 .25487 Metetra
.676 .746 .903 r
.78094 .25487 .78389 .25915 .79063 .25661 .7877 .25233 Metetra
.676 .746 .904 r
.7877 .25233 .79063 .25661 .79739 .25408 .79447 .24979 Metetra
.675 .746 .904 r
.79447 .24979 .79739 .25408 .80416 .25155 .80125 .24726 Metetra
.675 .746 .904 r
.80125 .24726 .80416 .25155 .81095 .24903 .80806 .24473 Metetra
.674 .746 .905 r
.80806 .24473 .81095 .24903 .81776 .24652 .81488 .2422 Metetra
.673 .746 .905 r
.81488 .2422 .81776 .24652 .82458 .24401 .82171 .23968 Metetra
.673 .745 .905 r
.82171 .23968 .82458 .24401 .83142 .2415 .82856 .23717 Metetra
.672 .745 .905 r
.82856 .23717 .83142 .2415 .83828 .239 .83543 .23466 Metetra
.657 .741 .912 r
.22123 .43801 .22499 .44149 .2305 .43969 .22675 .43621 Metetra
.657 .741 .912 r
.22675 .43621 .2305 .43969 .23603 .4379 .23228 .43441 Metetra
.656 .741 .912 r
.23228 .43441 .23603 .4379 .24157 .43611 .23783 .43261 Metetra
.656 .74 .912 r
.23783 .43261 .24157 .43611 .24711 .43431 .24339 .4308 Metetra
.656 .74 .912 r
.24339 .4308 .24711 .43431 .25268 .43252 .24895 .429 Metetra
.656 .74 .912 r
.24895 .429 .25268 .43252 .25825 .43072 .25454 .42719 Metetra
.655 .74 .912 r
.25454 .42719 .25825 .43072 .26384 .42893 .26013 .42539 Metetra
.655 .74 .912 r
.26013 .42539 .26384 .42893 .26943 .42713 .26573 .42359 Metetra
.654 .74 .913 r
.26573 .42359 .26943 .42713 .27504 .42533 .27135 .4218 Metetra
.653 .74 .913 r
.27135 .4218 .27504 .42533 .28066 .42354 .27698 .42001 Metetra
.653 .741 .914 r
.27698 .42001 .28066 .42354 .2863 .42176 .28262 .41823 Metetra
.652 .741 .915 r
.28262 .41823 .2863 .42176 .29194 .41998 .28827 .41645 Metetra
.653 .741 .915 r
.28827 .41645 .29194 .41998 .2976 .41822 .29393 .41466 Metetra
.653 .741 .914 r
.29393 .41466 .2976 .41822 .30327 .41645 .29961 .41285 Metetra
.654 .739 .912 r
.29961 .41285 .30327 .41645 .30895 .41468 .3053 .41104 Metetra
.654 .737 .911 r
.3053 .41104 .30895 .41468 .31465 .41289 .31101 .40922 Metetra
.652 .735 .91 r
.31101 .40922 .31465 .41289 .32036 .41109 .31672 .40742 Metetra
.649 .735 .912 r
.31672 .40742 .32036 .41109 .32608 .40929 .32245 .40566 Metetra
.644 .736 .916 r
.32245 .40566 .32608 .40929 .33181 .4075 .32818 .40396 Metetra
.64 .741 .922 r
.32818 .40396 .33181 .4075 .33756 .40575 .33393 .40232 Metetra
.637 .747 .928 r
.33393 .40232 .33756 .40575 .34331 .40406 .33969 .4007 Metetra
.639 .752 .93 r
.33969 .4007 .34331 .40406 .34907 .40244 .34546 .39905 Metetra
.647 .753 .926 r
.34546 .39905 .34907 .40244 .35485 .40085 .35125 .39728 Metetra
.657 .746 .916 r
.35125 .39728 .35485 .40085 .36064 .39923 .35706 .39538 Metetra
.663 .732 .901 r
.35706 .39538 .36064 .39923 .36645 .39753 .3629 .39338 Metetra
.661 .716 .889 r
.3629 .39338 .36645 .39753 .37228 .39571 .36874 .39139 Metetra
.649 .703 .887 r
.36874 .39139 .37228 .39571 .37812 .39378 .37458 .38959 Metetra
.625 .702 .901 r
.37458 .38959 .37812 .39378 .38398 .39184 .38043 .38815 Metetra
.588 .718 .934 r
.38043 .38815 .38398 .39184 .38985 .39004 .38627 .38714 Metetra
.535 .75 .975 r
.38627 .38714 .38985 .39004 .39572 .38854 .39211 .38642 Metetra
.492 .79 .998 r
.39211 .38642 .39572 .38854 .40158 .38742 .39797 .38568 Metetra
.529 .831 .999 r
.39797 .38568 .40158 .38742 .40746 .38663 .40387 .38448 Metetra
.645 .841 .975 r
.40387 .38448 .40746 .38663 .41334 .38592 .40981 .38247 Metetra
.714 .772 .898 r
.40981 .38247 .41334 .38592 .41925 .38495 .4158 .37959 Metetra
.712 .684 .822 r
.4158 .37959 .41925 .38495 .4252 .38338 .42181 .37623 Metetra
.678 .617 .78 r
.42181 .37623 .4252 .38338 .43119 .38104 .42782 .3732 Metetra
.621 .573 .778 r
.42782 .3732 .43119 .38104 .4372 .37813 .43379 .37156 Metetra
.496 .543 .835 r
.43379 .37156 .4372 .37813 .44322 .37522 .43973 .37221 Metetra
0 .323 .774 r
.43973 .37221 .44322 .37522 .44924 .37321 .44562 .37548 Metetra
.708 .24 .139 r
.44562 .37548 .44924 .37321 .45522 .37305 .45149 .38086 Metetra
.677 .306 .336 r
.45149 .38086 .45522 .37305 .46117 .37544 .45739 .38701 Metetra
.63 .291 .377 r
.45739 .38701 .46117 .37544 .46711 .38055 .46336 .39207 Metetra
.564 .224 .351 r
.46336 .39207 .46711 .38055 .47305 .38778 .46942 .39422 Metetra
.336 0 .118 r
.46942 .39422 .47305 .38778 .47903 .3958 .47556 .39235 Metetra
.824 .795 .824 r
.47556 .39235 .47903 .3958 .48507 .4028 .48178 .38638 Metetra
.707 .532 .649 r
.48178 .38638 .48507 .4028 .4912 .40685 .48803 .37736 Metetra
.659 .462 .606 r
.48803 .37736 .4912 .40685 .49739 .40647 .49428 .36697 Metetra
.631 .428 .59 r
.49428 .36697 .49739 .40647 .50365 .40107 .50052 .35697 Metetra
.612 .41 .584 r
.50052 .35697 .50365 .40107 .50992 .39115 .50672 .34863 Metetra
.598 .401 .585 r
.50672 .34863 .50992 .39115 .51619 .37821 .51291 .34242 Metetra
.591 .402 .595 r
.51291 .34242 .51619 .37821 .52243 .36441 .51909 .3381 Metetra
.591 .418 .616 r
.51909 .3381 .52243 .36441 .52863 .35197 .52527 .33506 Metetra
.602 .459 .66 r
.52527 .33506 .52863 .35197 .53483 .34267 .53147 .33269 Metetra
.619 .535 .737 r
.53147 .33269 .53483 .34267 .54103 .33747 .53768 .33074 Metetra
.614 .603 .816 r
.53768 .33074 .54103 .33747 .54726 .33637 .54392 .32934 Metetra
.569 .571 .816 r
.54392 .32934 .54726 .33637 .55353 .33848 .55017 .32885 Metetra
.522 .484 .755 r
.55017 .32885 .55353 .33848 .55986 .3423 .55646 .32953 Metetra
.494 .423 .705 r
.55646 .32953 .55986 .3423 .56623 .34619 .56278 .33133 Metetra
.485 .397 .681 r
.56278 .33133 .56623 .34619 .57261 .34875 .56915 .33374 Metetra
.492 .401 .68 r
.56915 .33374 .57261 .34875 .57899 .34916 .57554 .33596 Metetra
.517 .434 .701 r
.57554 .33596 .57899 .34916 .58535 .3473 .58195 .33713 Metetra
.569 .505 .743 r
.58195 .33713 .58535 .3473 .59169 .34362 .58836 .33663 Metetra
.65 .617 .803 r
.58836 .33663 .59169 .34362 .59802 .3389 .59474 .33433 Metetra
.737 .739 .853 r
.59474 .33433 .59802 .3389 .60434 .33397 .6011 .33054 Metetra
.788 .809 .869 r
.6011 .33054 .60434 .33397 .61068 .32942 .60745 .3259 Metetra
.791 .805 .863 r
.60745 .3259 .61068 .32942 .61704 .32554 .6138 .32111 Metetra
.761 .754 .846 r
.6138 .32111 .61704 .32554 .62343 .32229 .62017 .31674 Metetra
.718 .694 .826 r
.62017 .31674 .62343 .32229 .62984 .31944 .62656 .31306 Metetra
.682 .651 .813 r
.62656 .31306 .62984 .31944 .63627 .3167 .63299 .31006 Metetra
.662 .634 .811 r
.63299 .31006 .63627 .3167 .64271 .31386 .63944 .30751 Metetra
.658 .642 .822 r
.63944 .30751 .64271 .31386 .64915 .3108 .64592 .30511 Metetra
.668 .67 .842 r
.64592 .30511 .64915 .3108 .6556 .30754 .6524 .30261 Metetra
.685 .708 .866 r
.6524 .30261 .6556 .30754 .66205 .3042 .65889 .29988 Metetra
.702 .745 .885 r
.65889 .29988 .66205 .3042 .66852 .30089 .66538 .29692 Metetra
.712 .767 .896 r
.66538 .29692 .66852 .30089 .675 .2977 .67188 .29381 Metetra
.714 .773 .899 r
.67188 .29381 .675 .2977 .6815 .29468 .67838 .29068 Metetra
.709 .766 .897 r
.67838 .29068 .6815 .29468 .68802 .29182 .68491 .28763 Metetra
.7 .753 .893 r
.68491 .28763 .68802 .29182 .69456 .28907 .69145 .2847 Metetra
.692 .741 .889 r
.69145 .2847 .69456 .28907 .70111 .28638 .69801 .28192 Metetra
.685 .734 .888 r
.69801 .28192 .70111 .28638 .70769 .28371 .70459 .27923 Metetra
.682 .733 .889 r
.70459 .27923 .70769 .28371 .71427 .28104 .71119 .27661 Metetra
.681 .736 .892 r
.71119 .27661 .71427 .28104 .72087 .27835 .7178 .274 Metetra
.682 .74 .895 r
.7178 .274 .72087 .27835 .72748 .27566 .72443 .27138 Metetra
.683 .745 .898 r
.72443 .27138 .72748 .27566 .73411 .27298 .73107 .26875 Metetra
.683 .748 .901 r
.73107 .26875 .73411 .27298 .74075 .27033 .73773 .26611 Metetra
.683 .749 .902 r
.73773 .26611 .74075 .27033 .74741 .2677 .7444 .26347 Metetra
.682 .749 .902 r
.7444 .26347 .74741 .2677 .75408 .2651 .75108 .26085 Metetra
.68 .748 .902 r
.75108 .26085 .75408 .2651 .76077 .26253 .75778 .25825 Metetra
.679 .746 .902 r
.75778 .25825 .76077 .26253 .76748 .25997 .7645 .25567 Metetra
.677 .745 .902 r
.7645 .25567 .76748 .25997 .7742 .25741 .77124 .2531 Metetra
.676 .745 .902 r
.77124 .2531 .7742 .25741 .78094 .25487 .77799 .25055 Metetra
.676 .745 .903 r
.77799 .25055 .78094 .25487 .7877 .25233 .78475 .24801 Metetra
.675 .745 .903 r
.78475 .24801 .7877 .25233 .79447 .24979 .79154 .24547 Metetra
.675 .745 .904 r
.79154 .24547 .79447 .24979 .80125 .24726 .79833 .24293 Metetra
.674 .746 .904 r
.79833 .24293 .80125 .24726 .80806 .24473 .80515 .2404 Metetra
.674 .746 .905 r
.80515 .2404 .80806 .24473 .81488 .2422 .81198 .23787 Metetra
.673 .745 .905 r
.81198 .23787 .81488 .2422 .82171 .23968 .81883 .23534 Metetra
.673 .745 .905 r
.81883 .23534 .82171 .23968 .82856 .23717 .82569 .23281 Metetra
.672 .745 .905 r
.82569 .23281 .82856 .23717 .83543 .23466 .83257 .23029 Metetra
.657 .741 .912 r
.21746 .43452 .22123 .43801 .22675 .43621 .22299 .43271 Metetra
.657 .741 .912 r
.22299 .43271 .22675 .43621 .23228 .43441 .22853 .4309 Metetra
.656 .74 .912 r
.22853 .4309 .23228 .43441 .23783 .43261 .23408 .42909 Metetra
.656 .74 .912 r
.23408 .42909 .23783 .43261 .24339 .4308 .23964 .42728 Metetra
.656 .74 .912 r
.23964 .42728 .24339 .4308 .24895 .429 .24522 .42547 Metetra
.656 .74 .912 r
.24522 .42547 .24895 .429 .25454 .42719 .25081 .42365 Metetra
.655 .74 .912 r
.25081 .42365 .25454 .42719 .26013 .42539 .2564 .42185 Metetra
.654 .74 .913 r
.2564 .42185 .26013 .42539 .26573 .42359 .26202 .42005 Metetra
.654 .74 .913 r
.26202 .42005 .26573 .42359 .27135 .4218 .26764 .41825 Metetra
.653 .741 .914 r
.26764 .41825 .27135 .4218 .27698 .42001 .27327 .41646 Metetra
.653 .741 .914 r
.27327 .41646 .27698 .42001 .28262 .41823 .27892 .41467 Metetra
.653 .741 .914 r
.27892 .41467 .28262 .41823 .28827 .41645 .28458 .41286 Metetra
.654 .74 .913 r
.28458 .41286 .28827 .41645 .29393 .41466 .29025 .41104 Metetra
.654 .739 .912 r
.29025 .41104 .29393 .41466 .29961 .41285 .29594 .40922 Metetra
.654 .738 .911 r
.29594 .40922 .29961 .41285 .3053 .41104 .30164 .4074 Metetra
.652 .737 .912 r
.30164 .4074 .3053 .41104 .31101 .40922 .30735 .4056 Metetra
.648 .738 .915 r
.30735 .4056 .31101 .40922 .31672 .40742 .31307 .40385 Metetra
.644 .74 .919 r
.31307 .40385 .31672 .40742 .32245 .40566 .3188 .40215 Metetra
.641 .743 .923 r
.3188 .40215 .32245 .40566 .32818 .40396 .32454 .40049 Metetra
.64 .745 .925 r
.32454 .40049 .32818 .40396 .33393 .40232 .33029 .39883 Metetra
.643 .746 .924 r
.33029 .39883 .33393 .40232 .33969 .4007 .33606 .39713 Metetra
.651 .743 .917 r
.33606 .39713 .33969 .4007 .34546 .39905 .34185 .39532 Metetra
.659 .737 .908 r
.34185 .39532 .34546 .39905 .35125 .39728 .34766 .39339 Metetra
.662 .73 .9 r
.34766 .39339 .35125 .39728 .35706 .39538 .35348 .3914 Metetra
.659 .724 .897 r
.35348 .3914 .35706 .39538 .3629 .39338 .35932 .38944 Metetra
.646 .723 .905 r
.35932 .38944 .3629 .39338 .36874 .39139 .36515 .38769 Metetra
.621 .729 .924 r
.36515 .38769 .36874 .39139 .37458 .38959 .37099 .38627 Metetra
.584 .74 .95 r
.37099 .38627 .37458 .38959 .38043 .38815 .37682 .38521 Metetra
.548 .753 .972 r
.37682 .38521 .38043 .38815 .38627 .38714 .38266 .38439 Metetra
.545 .766 .98 r
.38266 .38439 .38627 .38714 .39211 .38642 .38852 .38352 Metetra
.596 .774 .965 r
.38852 .38352 .39211 .38642 .39797 .38568 .39441 .38222 Metetra
.662 .759 .922 r
.39441 .38222 .39797 .38568 .40387 .38448 .40035 .38021 Metetra
.701 .726 .87 r
.40035 .38021 .40387 .38448 .40981 .38247 .40633 .37743 Metetra
.71 .695 .834 r
.40633 .37743 .40981 .38247 .4158 .37959 .41233 .37421 Metetra
.695 .678 .83 r
.41233 .37421 .4158 .37959 .42181 .37623 .41833 .37128 Metetra
.641 .675 .867 r
.41833 .37128 .42181 .37623 .42782 .3732 .42431 .36954 Metetra
.44 .661 .954 r
.42431 .36954 .42782 .3732 .43379 .37156 .43024 .36985 Metetra
0 .276 .642 r
.43024 .36985 .43379 .37156 .43973 .37221 .43612 .37265 Metetra
.694 .17 0 r
.43612 .37265 .43973 .37221 .44562 .37548 .44197 .37767 Metetra
.735 .276 .161 r
.44197 .37767 .44562 .37548 .45149 .38086 .44784 .38391 Metetra
.714 .268 .19 r
.44784 .38391 .45149 .38086 .45739 .38701 .45376 .38975 Metetra
.628 .147 .093 r
.45376 .38975 .45739 .38701 .46336 .39207 .45977 .39337 Metetra
.195 0 0 r
.45977 .39337 .46336 .39207 .46942 .39422 .46588 .3933 Metetra
.794 .945 .923 r
.46588 .3933 .46942 .39422 .47556 .39235 .47208 .38886 Metetra
.869 .79 .771 r
.47208 .38886 .47556 .39235 .48178 .38638 .47835 .38042 Metetra
.852 .712 .707 r
.47835 .38042 .48178 .38638 .48803 .37736 .48464 .36927 Metetra
.828 .667 .684 r
.48464 .36927 .48803 .37736 .49428 .36697 .49092 .35722 Metetra
.796 .633 .679 r
.49092 .35722 .49428 .36697 .50052 .35697 .49717 .34607 Metetra
.755 .599 .683 r
.49717 .34607 .50052 .35697 .50672 .34863 .50338 .33713 Metetra
.706 .565 .693 r
.50338 .33713 .50672 .34863 .51291 .34242 .50956 .33097 Metetra
.653 .535 .707 r
.50956 .33097 .51291 .34242 .51909 .3381 .51574 .3274 Metetra
.606 .516 .727 r
.51574 .3274 .51909 .3381 .52527 .33506 .52192 .32577 Metetra
.572 .519 .757 r
.52192 .32577 .52527 .33506 .53147 .33269 .52812 .32523 Metetra
.55 .548 .805 r
.52812 .32523 .53147 .33269 .53768 .33074 .53434 .3251 Metetra
.531 .601 .869 r
.53434 .3251 .53768 .33074 .54392 .32934 .54058 .32506 Metetra
.494 .652 .929 r
.54058 .32506 .54392 .32934 .55017 .32885 .54685 .32512 Metetra
.441 .66 .954 r
.54685 .32512 .55017 .32885 .55646 .32953 .55314 .32545 Metetra
.41 .622 .939 r
.55314 .32545 .55646 .32953 .56278 .33133 .55946 .3262 Metetra
.421 .57 .896 r
.55946 .3262 .56278 .33133 .56915 .33374 .56581 .32732 Metetra
.459 .534 .847 r
.56581 .32732 .56915 .33374 .57554 .33596 .57219 .32845 Metetra
.507 .526 .811 r
.57219 .32845 .57554 .33596 .58195 .33713 .57859 .32911 Metetra
.561 .543 .792 r
.57859 .32911 .58195 .33713 .58836 .33663 .58499 .32879 Metetra
.617 .578 .787 r
.58499 .32879 .58836 .33663 .59474 .33433 .59139 .32718 Metetra
.67 .622 .793 r
.59139 .32718 .59474 .33433 .6011 .33054 .59778 .32429 Metetra
.714 .669 .804 r
.59778 .32429 .6011 .33054 .60745 .3259 .60416 .32044 Metetra
.742 .706 .818 r
.60416 .32044 .60745 .3259 .6138 .32111 .61053 .31611 Metetra
.748 .726 .831 r
.61053 .31611 .6138 .32111 .62017 .31674 .61691 .31182 Metetra
.734 .725 .843 r
.61691 .31182 .62017 .31674 .62656 .31306 .62331 .30795 Metetra
.707 .708 .848 r
.62331 .30795 .62656 .31306 .63299 .31006 .62973 .30469 Metetra
.681 .687 .85 r
.62973 .30469 .63299 .31006 .63944 .30751 .63619 .30197 Metetra
.663 .674 .85 r
.63619 .30197 .63944 .30751 .64592 .30511 .64267 .29961 Metetra
.659 .674 .853 r
.64267 .29961 .64592 .30511 .6524 .30261 .64918 .29733 Metetra
.665 .687 .86 r
.64918 .29733 .6524 .30261 .65889 .29988 .65569 .29495 Metetra
.679 .708 .869 r
.65569 .29495 .65889 .29988 .66538 .29692 .6622 .29234 Metetra
.693 .73 .879 r
.6622 .29234 .66538 .29692 .67188 .29381 .66872 .2895 Metetra
.703 .748 .886 r
.66872 .2895 .67188 .29381 .67838 .29068 .67525 .28651 Metetra
.706 .756 .891 r
.67525 .28651 .67838 .29068 .68491 .28763 .68178 .28347 Metetra
.704 .757 .893 r
.68178 .28347 .68491 .28763 .69145 .2847 .68833 .28048 Metetra
.697 .752 .894 r
.68833 .28048 .69145 .2847 .69801 .28192 .6949 .2776 Metetra
.69 .745 .893 r
.6949 .2776 .69801 .28192 .70459 .27923 .70149 .27485 Metetra
.684 .739 .893 r
.70149 .27485 .70459 .27923 .71119 .27661 .7081 .27218 Metetra
.681 .736 .893 r
.7081 .27218 .71119 .27661 .7178 .274 .71472 .26958 Metetra
.679 .737 .894 r
.71472 .26958 .7178 .274 .72443 .27138 .72136 .267 Metetra
.679 .739 .896 r
.72136 .267 .72443 .27138 .73107 .26875 .72802 .26441 Metetra
.68 .743 .898 r
.72802 .26441 .73107 .26875 .73773 .26611 .73469 .26181 Metetra
.681 .745 .9 r
.73469 .26181 .73773 .26611 .7444 .26347 .74137 .25919 Metetra
.681 .747 .901 r
.74137 .25919 .7444 .26347 .75108 .26085 .74807 .25658 Metetra
.68 .747 .902 r
.74807 .25658 .75108 .26085 .75778 .25825 .75478 .25396 Metetra
.679 .747 .902 r
.75478 .25396 .75778 .25825 .7645 .25567 .76151 .25136 Metetra
.678 .746 .902 r
.76151 .25136 .7645 .25567 .77124 .2531 .76826 .24878 Metetra
.677 .745 .903 r
.76826 .24878 .77124 .2531 .77799 .25055 .77502 .24622 Metetra
.676 .745 .903 r
.77502 .24622 .77799 .25055 .78475 .24801 .7818 .24367 Metetra
.675 .744 .903 r
.7818 .24367 .78475 .24801 .79154 .24547 .78859 .24112 Metetra
.674 .745 .903 r
.78859 .24112 .79154 .24547 .79833 .24293 .7954 .23858 Metetra
.674 .745 .904 r
.7954 .23858 .79833 .24293 .80515 .2404 .80223 .23604 Metetra
.674 .745 .904 r
.80223 .23604 .80515 .2404 .81198 .23787 .80907 .23351 Metetra
.673 .745 .905 r
.80907 .23351 .81198 .23787 .81883 .23534 .81593 .23097 Metetra
.673 .745 .905 r
.81593 .23097 .81883 .23534 .82569 .23281 .8228 .22843 Metetra
.672 .745 .905 r
.8228 .22843 .82569 .23281 .83257 .23029 .82969 .2259 Metetra
.657 .741 .912 r
.21367 .43101 .21746 .43452 .22299 .43271 .21921 .42919 Metetra
.657 .74 .912 r
.21921 .42919 .22299 .43271 .22853 .4309 .22476 .42737 Metetra
.656 .74 .912 r
.22476 .42737 .22853 .4309 .23408 .42909 .23031 .42556 Metetra
.656 .74 .912 r
.23031 .42556 .23408 .42909 .23964 .42728 .23588 .42374 Metetra
.656 .74 .912 r
.23588 .42374 .23964 .42728 .24522 .42547 .24147 .42193 Metetra
.655 .74 .913 r
.24147 .42193 .24522 .42547 .25081 .42365 .24706 .42012 Metetra
.654 .741 .913 r
.24706 .42012 .25081 .42365 .2564 .42185 .25267 .41831 Metetra
.654 .741 .914 r
.25267 .41831 .2564 .42185 .26202 .42005 .25828 .4165 Metetra
.654 .741 .914 r
.25828 .4165 .26202 .42005 .26764 .41825 .26391 .4147 Metetra
.654 .741 .913 r
.26391 .4147 .26764 .41825 .27327 .41646 .26956 .41288 Metetra
.654 .74 .913 r
.26956 .41288 .27327 .41646 .27892 .41467 .27521 .41106 Metetra
.655 .739 .912 r
.27521 .41106 .27892 .41467 .28458 .41286 .28088 .40923 Metetra
.654 .738 .911 r
.28088 .40923 .28458 .41286 .29025 .41104 .28656 .40741 Metetra
.653 .737 .912 r
.28656 .40741 .29025 .41104 .29594 .40922 .29225 .40559 Metetra
.65 .738 .914 r
.29225 .40559 .29594 .40922 .30164 .4074 .29796 .40382 Metetra
.647 .74 .917 r
.29796 .40382 .30164 .4074 .30735 .4056 .30367 .40208 Metetra
.644 .743 .921 r
.30367 .40208 .30735 .4056 .31307 .40385 .30939 .40037 Metetra
.643 .746 .924 r
.30939 .40037 .31307 .40385 .3188 .40215 .31513 .39867 Metetra
.645 .747 .923 r
.31513 .39867 .3188 .40215 .32454 .40049 .32088 .39694 Metetra
.65 .745 .919 r
.32088 .39694 .32454 .40049 .33029 .39883 .32665 .39514 Metetra
.656 .738 .91 r
.32665 .39514 .33029 .39883 .33606 .39713 .33244 .39325 Metetra
.659 .729 .901 r
.33244 .39325 .33606 .39713 .34185 .39532 .33824 .3913 Metetra
.657 .722 .896 r
.33824 .3913 .34185 .39532 .34766 .39339 .34405 .38938 Metetra
.648 .72 .9 r
.34405 .38938 .34766 .39339 .35348 .3914 .34987 .38759 Metetra
.631 .726 .916 r
.34987 .38759 .35348 .3914 .35932 .38944 .35569 .38605 Metetra
.605 .743 .942 r
.35569 .38605 .35932 .38944 .36515 .38769 .36152 .38478 Metetra
.576 .765 .968 r
.36152 .38478 .36515 .38769 .37099 .38627 .36734 .38369 Metetra
.566 .785 .982 r
.36734 .38369 .37099 .38627 .37682 .38521 .37319 .38258 Metetra
.598 .793 .974 r
.37319 .38258 .37682 .38521 .38266 .38439 .37906 .38119 Metetra
.652 .771 .936 r
.37906 .38119 .38266 .38439 .38852 .38352 .38497 .37929 Metetra
.684 .723 .879 r
.38497 .37929 .38852 .38352 .39441 .38222 .39092 .37684 Metetra
.687 .675 .832 r
.39092 .37684 .39441 .38222 .40035 .38021 .39689 .37408 Metetra
.672 .643 .813 r
.39689 .37408 .40035 .38021 .40633 .37743 .40286 .3715 Metetra
.637 .635 .832 r
.40286 .3715 .40633 .37743 .41233 .37421 .40882 .36973 Metetra
.541 .658 .911 r
.40882 .36973 .41233 .37421 .41833 .37128 .41474 .36935 Metetra
.061 .56 .888 r
.41474 .36935 .41833 .37128 .42431 .36954 .42063 .37063 Metetra
.552 .003 0 r
.42063 .37063 .42431 .36954 .43024 .36985 .4265 .37337 Metetra
.626 .169 .147 r
.4265 .37337 .43024 .36985 .43612 .37265 .43237 .37688 Metetra
.613 .171 .176 r
.43237 .37688 .43612 .37265 .44197 .37767 .43829 .38015 Metetra
.518 .007 0 r
.43829 .38015 .44197 .37767 .44784 .38391 .44428 .38207 Metetra
.372 .758 .989 r
.44428 .38207 .44784 .38391 .45376 .38975 .45034 .38181 Metetra
.662 .595 .77 r
.45034 .38181 .45376 .38975 .45977 .39337 .45648 .379 Metetra
.665 .517 .673 r
.45648 .379 .45977 .39337 .46588 .3933 .46268 .37383 Metetra
.662 .489 .639 r
.46268 .37383 .46588 .3933 .47208 .38886 .46891 .36693 Metetra
.661 .48 .628 r
.46891 .36693 .47208 .38886 .47835 .38042 .47515 .35916 Metetra
.665 .484 .63 r
.47515 .35916 .47835 .38042 .48464 .36927 .48138 .35136 Metetra
.674 .503 .646 r
.48138 .35136 .48464 .36927 .49092 .35722 .48759 .34415 Metetra
.693 .544 .679 r
.48759 .34415 .49092 .35722 .49717 .34607 .49379 .3379 Metetra
.723 .621 .743 r
.49379 .3379 .49717 .34607 .50338 .33713 .49998 .33275 Metetra
.752 .744 .845 r
.49998 .33275 .50338 .33713 .50956 .33097 .50617 .32865 Metetra
.73 .858 .942 r
.50617 .32865 .50956 .33097 .51574 .3274 .51235 .32547 Metetra
.664 .872 .977 r
.51235 .32547 .51574 .3274 .52192 .32577 .51855 .32306 Metetra
.63 .808 .968 r
.51855 .32306 .52192 .32577 .52812 .32523 .52476 .32123 Metetra
.611 .72 .922 r
.52476 .32123 .52812 .32523 .53434 .3251 .53098 .31985 Metetra
.595 .649 .874 r
.53098 .31985 .53434 .3251 .54058 .32506 .53723 .3188 Metetra
.581 .603 .84 r
.53723 .3188 .54058 .32506 .54685 .32512 .54349 .31803 Metetra
.567 .57 .816 r
.54349 .31803 .54685 .32512 .55314 .32545 .54977 .31755 Metetra
.553 .54 .795 r
.54977 .31755 .55314 .32545 .55946 .3262 .55608 .31739 Metetra
.54 .512 .773 r
.55608 .31739 .55946 .3262 .56581 .32732 .56242 .31755 Metetra
.533 .49 .754 r
.56242 .31755 .56581 .32732 .57219 .32845 .56878 .31795 Metetra
.533 .478 .74 r
.56878 .31795 .57219 .32845 .57859 .32911 .57517 .3184 Metetra
.544 .481 .736 r
.57517 .3184 .57859 .32911 .58499 .32879 .58158 .31858 Metetra
.565 .502 .744 r
.58158 .31858 .58499 .32879 .59139 .32718 .588 .31818 Metetra
.598 .543 .764 r
.588 .31818 .59139 .32718 .59778 .32429 .59443 .31693 Metetra
.642 .604 .796 r
.59443 .31693 .59778 .32429 .60416 .32044 .60085 .31475 Metetra
.691 .679 .834 r
.60085 .31475 .60416 .32044 .61053 .31611 .60727 .31172 Metetra
.731 .749 .867 r
.60727 .31172 .61053 .31611 .61691 .31182 .61368 .30813 Metetra
.749 .791 .887 r
.61368 .30813 .61691 .31182 .62331 .30795 .62009 .30434 Metetra
.744 .794 .893 r
.62009 .30434 .62331 .30795 .62973 .30469 .62651 .30066 Metetra
.723 .766 .887 r
.62651 .30066 .62973 .30469 .63619 .30197 .63296 .29733 Metetra
.697 .727 .873 r
.63296 .29733 .63619 .30197 .64267 .29961 .63943 .29441 Metetra
.675 .694 .86 r
.63943 .29441 .64267 .29961 .64918 .29733 .64593 .29184 Metetra
.663 .677 .853 r
.64593 .29184 .64918 .29733 .65569 .29495 .65245 .28946 Metetra
.662 .677 .854 r
.65245 .28946 .65569 .29495 .6622 .29234 .65899 .28711 Metetra
.669 .691 .862 r
.65899 .28711 .6622 .29234 .66872 .2895 .66553 .28464 Metetra
.68 .713 .873 r
.66553 .28464 .66872 .2895 .67525 .28651 .67209 .28201 Metetra
.69 .735 .885 r
.67209 .28201 .67525 .28651 .68178 .28347 .67864 .27923 Metetra
.697 .751 .893 r
.67864 .27923 .68178 .28347 .68833 .28048 .68521 .27635 Metetra
.698 .758 .898 r
.68521 .27635 .68833 .28048 .6949 .2776 .69179 .27346 Metetra
.695 .757 .899 r
.69179 .27346 .6949 .2776 .70149 .27485 .69839 .27062 Metetra
.69 .751 .898 r
.69839 .27062 .70149 .27485 .7081 .27218 .705 .26785 Metetra
.685 .744 .896 r
.705 .26785 .7081 .27218 .71472 .26958 .71163 .26517 Metetra
.681 .739 .895 r
.71163 .26517 .71472 .26958 .72136 .267 .71828 .26256 Metetra
.678 .737 .895 r
.71828 .26256 .72136 .267 .72802 .26441 .72495 .25998 Metetra
.678 .737 .896 r
.72495 .25998 .72802 .26441 .73469 .26181 .73163 .25741 Metetra
.678 .74 .897 r
.73163 .25741 .73469 .26181 .74137 .25919 .73833 .25483 Metetra
.678 .743 .899 r
.73833 .25483 .74137 .25919 .74807 .25658 .74504 .25224 Metetra
.679 .745 .901 r
.74504 .25224 .74807 .25658 .75478 .25396 .75177 .24965 Metetra
.679 .746 .902 r
.75177 .24965 .75478 .25396 .76151 .25136 .75851 .24705 Metetra
.678 .747 .903 r
.75851 .24705 .76151 .25136 .76826 .24878 .76526 .24446 Metetra
.677 .746 .903 r
.76526 .24446 .76826 .24878 .77502 .24622 .77204 .24188 Metetra
.676 .745 .903 r
.77204 .24188 .77502 .24622 .7818 .24367 .77883 .23931 Metetra
.675 .745 .903 r
.77883 .23931 .7818 .24367 .78859 .24112 .78563 .23675 Metetra
.674 .744 .903 r
.78563 .23675 .78859 .24112 .7954 .23858 .79245 .2342 Metetra
.674 .744 .904 r
.79245 .2342 .7954 .23858 .80223 .23604 .79929 .23166 Metetra
.673 .744 .904 r
.79929 .23166 .80223 .23604 .80907 .23351 .80615 .22911 Metetra
.673 .744 .904 r
.80615 .22911 .80907 .23351 .81593 .23097 .81302 .22657 Metetra
.673 .744 .905 r
.81302 .22657 .81593 .23097 .8228 .22843 .8199 .22403 Metetra
.672 .745 .905 r
.8199 .22403 .8228 .22843 .82969 .2259 .82681 .22149 Metetra
.657 .741 .911 r
.20987 .42749 .21367 .43101 .21921 .42919 .21542 .42566 Metetra
.657 .74 .912 r
.21542 .42566 .21921 .42919 .22476 .42737 .22097 .42384 Metetra
.656 .74 .912 r
.22097 .42384 .22476 .42737 .23031 .42556 .22653 .42202 Metetra
.656 .74 .912 r
.22653 .42202 .23031 .42556 .23588 .42374 .23211 .4202 Metetra
.655 .741 .913 r
.23211 .4202 .23588 .42374 .24147 .42193 .2377 .41838 Metetra
.655 .741 .913 r
.2377 .41838 .24147 .42193 .24706 .42012 .2433 .41657 Metetra
.655 .741 .913 r
.2433 .41657 .24706 .42012 .25267 .41831 .24891 .41475 Metetra
.655 .741 .913 r
.24891 .41475 .25267 .41831 .25828 .4165 .25454 .41293 Metetra
.655 .741 .913 r
.25454 .41293 .25828 .4165 .26391 .4147 .26017 .4111 Metetra
.655 .74 .912 r
.26017 .4111 .26391 .4147 .26956 .41288 .26583 .40927 Metetra
.655 .739 .912 r
.26583 .40927 .26956 .41288 .27521 .41106 .27149 .40743 Metetra
.654 .738 .912 r
.27149 .40743 .27521 .41106 .28088 .40923 .27716 .4056 Metetra
.652 .738 .913 r
.27716 .4056 .28088 .40923 .28656 .40741 .28285 .4038 Metetra
.649 .739 .915 r
.28285 .4038 .28656 .40741 .29225 .40559 .28855 .40203 Metetra
.647 .741 .918 r
.28855 .40203 .29225 .40559 .29796 .40382 .29425 .40029 Metetra
.645 .744 .921 r
.29425 .40029 .29796 .40382 .30367 .40208 .29997 .39857 Metetra
.645 .746 .922 r
.29997 .39857 .30367 .40208 .30939 .40037 .3057 .39684 Metetra
.649 .746 .92 r
.3057 .39684 .30939 .40037 .31513 .39867 .31145 .39506 Metetra
.655 .743 .915 r
.31145 .39506 .31513 .39867 .32088 .39694 .31722 .39319 Metetra
.659 .737 .907 r
.31722 .39319 .32088 .39694 .32665 .39514 .323 .39125 Metetra
.66 .73 .901 r
.323 .39125 .32665 .39514 .33244 .39325 .3288 .38929 Metetra
.655 .725 .901 r
.3288 .38929 .33244 .39325 .33824 .3913 .33461 .38741 Metetra
.642 .725 .908 r
.33461 .38741 .33824 .3913 .34405 .38938 .34042 .38571 Metetra
.622 .731 .925 r
.34042 .38571 .34405 .38938 .34987 .38759 .34622 .38427 Metetra
.596 .745 .948 r
.34622 .38427 .34987 .38759 .35569 .38605 .35203 .38307 Metetra
.577 .762 .966 r
.35203 .38307 .35569 .38605 .36152 .38478 .35785 .38199 Metetra
.584 .778 .972 r
.35785 .38199 .36152 .38478 .36734 .38369 .36369 .38078 Metetra
.625 .783 .957 r
.36369 .38078 .36734 .38369 .37319 .38258 .36957 .37917 Metetra
.673 .764 .919 r
.36957 .37917 .37319 .38258 .37906 .38119 .37549 .37699 Metetra
.698 .729 .874 r
.37549 .37699 .37906 .38119 .38497 .37929 .38144 .37429 Metetra
.697 .693 .842 r
.38144 .37429 .38497 .37929 .39092 .37684 .38741 .37139 Metetra
.676 .668 .835 r
.38741 .37139 .39092 .37684 .39689 .37408 .39338 .36888 Metetra
.623 .658 .863 r
.39338 .36888 .39689 .37408 .40286 .3715 .39932 .36744 Metetra
.475 .652 .937 r
.39932 .36744 .40286 .3715 .40882 .36973 .40521 .3676 Metetra
0 .462 .831 r
.40521 .3676 .40882 .36973 .41474 .36935 .41106 .36954 Metetra
.575 .008 0 r
.41106 .36954 .41474 .36935 .42063 .37063 .41688 .37291 Metetra
.646 .158 .08 r
.41688 .37291 .42063 .37063 .4265 .37337 .42273 .37682 Metetra
.613 .15 .131 r
.42273 .37682 .4265 .37337 .43237 .37688 .42863 .38008 Metetra
.49 0 .017 r
.42863 .38008 .43237 .37688 .43829 .38015 .43462 .38144 Metetra
.43462 .38144 .43829 .38015 .44428 .38207 .4407 .38004 Metetra
.798 .876 .904 r
.4407 .38004 .44428 .38207 .45034 .38181 .44688 .37562 Metetra
.792 .691 .753 r
.44688 .37562 .45034 .38181 .45648 .379 .45312 .36861 Metetra
.757 .606 .69 r
.45312 .36861 .45648 .379 .46268 .37383 .45939 .35999 Metetra
.727 .559 .663 r
.45939 .35999 .46268 .37383 .46891 .36693 .46565 .35095 Metetra
.702 .53 .653 r
.46565 .35095 .46891 .36693 .47515 .35916 .47189 .34258 Metetra
.679 .512 .653 r
.47189 .34258 .47515 .35916 .48138 .35136 .4781 .3356 Metetra
.66 .504 .662 r
.4781 .3356 .48138 .35136 .48759 .34415 .48428 .33024 Metetra
.644 .506 .68 r
.48428 .33024 .48759 .34415 .49379 .3379 .49045 .32634 Metetra
.635 .523 .709 r
.49045 .32634 .49379 .3379 .49998 .33275 .49662 .32349 Metetra
.632 .554 .748 r
.49662 .32349 .49998 .33275 .50617 .32865 .50279 .32125 Metetra
.635 .595 .791 r
.50279 .32125 .50617 .32865 .51235 .32547 .50897 .31926 Metetra
.639 .632 .827 r
.50897 .31926 .51235 .32547 .51855 .32306 .51517 .31737 Metetra
.638 .651 .846 r
.51517 .31737 .51855 .32306 .52476 .32123 .52138 .31556 Metetra
.63 .648 .849 r
.52138 .31556 .52476 .32123 .53098 .31985 .52761 .31388 Metetra
.617 .631 .843 r
.52761 .31388 .53098 .31985 .53723 .3188 .53386 .31244 Metetra
.6 .61 .833 r
.53386 .31244 .53723 .3188 .54349 .31803 .54013 .31131 Metetra
.581 .589 .825 r
.54013 .31131 .54349 .31803 .54977 .31755 .54641 .31054 Metetra
.562 .57 .82 r
.54641 .31054 .54977 .31755 .55608 .31739 .55272 .31014 Metetra
.543 .553 .815 r
.55272 .31014 .55608 .31739 .56242 .31755 .55905 .3101 Metetra
.527 .539 .811 r
.55905 .3101 .56242 .31755 .56878 .31795 .56542 .31037 Metetra
.518 .531 .809 r
.56542 .31037 .56878 .31795 .57517 .3184 .5718 .31083 Metetra
.519 .532 .809 r
.5718 .31083 .57517 .3184 .58158 .31858 .57822 .31125 Metetra
.535 .548 .815 r
.57822 .31125 .58158 .31858 .588 .31818 .58465 .31134 Metetra
.566 .58 .827 r
.58465 .31134 .588 .31818 .59443 .31693 .5911 .31083 Metetra
.609 .628 .844 r
.5911 .31083 .59443 .31693 .60085 .31475 .59754 .30949 Metetra
.659 .684 .862 r
.59754 .30949 .60085 .31475 .60727 .31172 .60399 .30724 Metetra
.705 .737 .876 r
.60399 .30724 .60727 .31172 .61368 .30813 .61042 .30419 Metetra
.737 .774 .883 r
.61042 .30419 .61368 .30813 .62009 .30434 .61685 .30059 Metetra
.749 .789 .885 r
.61685 .30059 .62009 .30434 .62651 .30066 .62329 .29676 Metetra
.742 .78 .883 r
.62329 .29676 .62651 .30066 .63296 .29733 .62973 .29304 Metetra
.722 .754 .878 r
.62973 .29304 .63296 .29733 .63943 .29441 .6362 .28966 Metetra
.697 .723 .87 r
.6362 .28966 .63943 .29441 .64593 .29184 .64269 .2867 Metetra
.675 .698 .863 r
.64269 .2867 .64593 .29184 .65245 .28946 .64921 .28412 Metetra
.662 .684 .861 r
.64921 .28412 .65245 .28946 .65899 .28711 .65576 .28179 Metetra
.658 .684 .863 r
.65576 .28179 .65899 .28711 .66553 .28464 .66232 .27953 Metetra
.663 .695 .87 r
.66232 .27953 .66553 .28464 .67209 .28201 .6689 .2772 Metetra
.672 .713 .879 r
.6689 .2772 .67209 .28201 .67864 .27923 .67548 .27471 Metetra
.683 .732 .888 r
.67548 .27471 .67864 .27923 .68521 .27635 .68207 .27205 Metetra
.691 .747 .895 r
.68207 .27205 .68521 .27635 .69179 .27346 .68866 .26927 Metetra
.694 .755 .898 r
.68866 .26927 .69179 .27346 .69839 .27062 .69527 .26643 Metetra
.693 .755 .899 r
.69527 .26643 .69839 .27062 .705 .26785 .70189 .26361 Metetra
.689 .751 .899 r
.70189 .26361 .705 .26785 .71163 .26517 .70853 .26084 Metetra
.685 .745 .897 r
.70853 .26084 .71163 .26517 .71828 .26256 .71519 .25815 Metetra
.68 .74 .896 r
.71519 .25815 .71828 .26256 .72495 .25998 .72187 .25553 Metetra
.677 .738 .896 r
.72187 .25553 .72495 .25998 .73163 .25741 .72856 .25296 Metetra
.676 .737 .897 r
.72856 .25296 .73163 .25741 .73833 .25483 .73527 .2504 Metetra
.676 .739 .898 r
.73527 .2504 .73833 .25483 .74504 .25224 .74199 .24784 Metetra
.676 .741 .9 r
.74199 .24784 .74504 .25224 .75177 .24965 .74873 .24528 Metetra
.677 .743 .901 r
.74873 .24528 .75177 .24965 .75851 .24705 .75549 .2427 Metetra
.677 .745 .902 r
.75549 .2427 .75851 .24705 .76526 .24446 .76226 .24011 Metetra
.677 .746 .903 r
.76226 .24011 .76526 .24446 .77204 .24188 .76904 .23752 Metetra
.676 .746 .903 r
.76904 .23752 .77204 .24188 .77883 .23931 .77584 .23494 Metetra
.675 .745 .903 r
.77584 .23494 .77883 .23931 .78563 .23675 .78266 .23237 Metetra
.674 .745 .903 r
.78266 .23237 .78563 .23675 .79245 .2342 .78949 .2298 Metetra
.674 .744 .904 r
.78949 .2298 .79245 .2342 .79929 .23166 .79634 .22725 Metetra
.673 .744 .904 r
.79634 .22725 .79929 .23166 .80615 .22911 .80321 .2247 Metetra
.673 .744 .904 r
.80321 .2247 .80615 .22911 .81302 .22657 .81009 .22215 Metetra
.672 .744 .904 r
.81009 .22215 .81302 .22657 .8199 .22403 .81699 .21961 Metetra
.672 .744 .905 r
.81699 .21961 .8199 .22403 .82681 .22149 .82391 .21706 Metetra
.657 .741 .912 r
.20606 .42395 .20987 .42749 .21542 .42566 .21161 .42212 Metetra
.656 .741 .912 r
.21161 .42212 .21542 .42566 .22097 .42384 .21717 .42029 Metetra
.656 .741 .912 r
.21717 .42029 .22097 .42384 .22653 .42202 .22274 .41847 Metetra
.655 .741 .913 r
.22274 .41847 .22653 .42202 .23211 .4202 .22832 .41665 Metetra
.655 .741 .913 r
.22832 .41665 .23211 .4202 .2377 .41838 .23392 .41482 Metetra
.655 .741 .913 r
.23392 .41482 .2377 .41838 .2433 .41657 .23952 .413 Metetra
.655 .741 .913 r
.23952 .413 .2433 .41657 .24891 .41475 .24514 .41116 Metetra
.655 .74 .912 r
.24514 .41116 .24891 .41475 .25454 .41293 .25078 .40933 Metetra
.655 .74 .912 r
.25078 .40933 .25454 .41293 .26017 .4111 .25642 .40748 Metetra
.655 .739 .912 r
.25642 .40748 .26017 .4111 .26583 .40927 .26208 .40565 Metetra
.654 .739 .912 r
.26208 .40565 .26583 .40927 .27149 .40743 .26775 .40382 Metetra
.651 .74 .914 r
.26775 .40382 .27149 .40743 .27716 .4056 .27343 .40202 Metetra
.649 .741 .917 r
.27343 .40202 .27716 .4056 .28285 .4038 .27912 .40025 Metetra
.647 .743 .919 r
.27912 .40025 .28285 .4038 .28855 .40203 .28482 .3985 Metetra
.647 .745 .921 r
.28482 .3985 .28855 .40203 .29425 .40029 .29053 .39675 Metetra
.649 .745 .92 r
.29053 .39675 .29425 .40029 .29997 .39857 .29626 .39497 Metetra
.652 .743 .916 r
.29626 .39497 .29997 .39857 .3057 .39684 .30201 .39314 Metetra
.657 .738 .91 r
.30201 .39314 .3057 .39684 .31145 .39506 .30777 .39124 Metetra
.659 .733 .904 r
.30777 .39124 .31145 .39506 .31722 .39319 .31355 .3893 Metetra
.657 .729 .902 r
.31355 .3893 .31722 .39319 .323 .39125 .31934 .38738 Metetra
.649 .728 .907 r
.31934 .38738 .323 .39125 .3288 .38929 .32514 .38558 Metetra
.635 .733 .919 r
.32514 .38558 .3288 .38929 .33461 .38741 .33093 .38396 Metetra
.616 .744 .937 r
.33093 .38396 .33461 .38741 .34042 .38571 .33673 .38256 Metetra
.598 .757 .955 r
.33673 .38256 .34042 .38571 .34622 .38427 .34254 .38131 Metetra
.593 .769 .963 r
.34254 .38131 .34622 .38427 .35203 .38307 .34836 .38005 Metetra
.614 .772 .956 r
.34836 .38005 .35203 .38307 .35785 .38199 .3542 .37859 Metetra
.65 .758 .929 r
.3542 .37859 .35785 .38199 .36369 .38078 .36009 .37673 Metetra
.678 .731 .89 r
.36009 .37673 .36369 .38078 .36957 .37917 .366 .37443 Metetra
.688 .701 .857 r
.366 .37443 .36957 .37917 .37549 .37699 .37195 .37182 Metetra
.681 .681 .844 r
.37195 .37182 .37549 .37699 .38144 .37429 .3779 .36926 Metetra
.656 .678 .859 r
.3779 .36926 .38144 .37429 .38741 .37139 .38384 .36724 Metetra
.588 .696 .917 r
.38384 .36724 .38741 .37139 .39338 .36888 .38975 .36623 Metetra
.358 .692 .982 r
.38975 .36623 .39338 .36888 .39932 .36744 .39563 .36655 Metetra
.211 0 0 r
.39563 .36655 .39932 .36744 .40521 .3676 .40147 .36817 Metetra
.507 0 0 r
.40147 .36817 .40521 .3676 .41106 .36954 .40731 .37067 Metetra
.545 0 0 r
.40731 .37067 .41106 .36954 .41688 .37291 .41318 .37332 Metetra
.418 0 0 r
.41318 .37332 .41688 .37291 .42273 .37682 .4191 .37522 Metetra
.215 .684 .942 r
.4191 .37522 .42273 .37682 .42863 .38008 .42509 .37556 Metetra
.64 .7 .89 r
.42509 .37556 .42863 .38008 .43462 .38144 .43118 .3738 Metetra
.699 .62 .764 r
.43118 .3738 .43462 .38144 .4407 .38004 .43733 .36986 Metetra
.713 .584 .71 r
.43733 .36986 .4407 .38004 .44688 .37562 .44354 .36406 Metetra
.72 .573 .689 r
.44354 .36406 .44688 .37562 .45312 .36861 .44978 .35704 Metetra
.727 .577 .686 r
.44978 .35704 .45312 .36861 .45939 .35999 .45602 .34958 Metetra
.735 .594 .699 r
.45602 .34958 .45939 .35999 .46565 .35095 .46226 .34239 Metetra
.744 .624 .726 r
.46226 .34239 .46565 .35095 .47189 .34258 .46847 .33599 Metetra
.751 .667 .768 r
.46847 .33599 .47189 .34258 .4781 .3356 .47466 .33064 Metetra
.748 .719 .824 r
.47466 .33064 .4781 .3356 .48428 .33024 .48084 .32637 Metetra
.729 .764 .88 r
.48084 .32637 .48428 .33024 .49045 .32634 .48701 .32302 Metetra
.697 .788 .921 r
.48701 .32302 .49045 .32634 .49662 .32349 .49318 .32036 Metetra
.668 .792 .941 r
.49318 .32036 .49662 .32349 .50279 .32125 .49937 .31814 Metetra
.649 .788 .948 r
.49937 .31814 .50279 .32125 .50897 .31926 .50556 .31615 Metetra
.641 .786 .951 r
.50556 .31615 .50897 .31926 .51517 .31737 .51177 .31426 Metetra
.635 .785 .953 r
.51177 .31426 .51517 .31737 .52138 .31556 .518 .31243 Metetra
.629 .782 .955 r
.518 .31243 .52138 .31556 .52761 .31388 .52424 .31068 Metetra
.62 .774 .955 r
.52424 .31068 .52761 .31388 .53386 .31244 .53049 .30904 Metetra
.608 .758 .95 r
.53049 .30904 .53386 .31244 .54013 .31131 .53676 .30758 Metetra
.594 .732 .94 r
.53676 .30758 .54013 .31131 .54641 .31054 .54306 .30634 Metetra
.578 .699 .924 r
.54306 .30634 .54641 .31054 .55272 .31014 .54937 .30538 Metetra
.563 .662 .904 r
.54937 .30538 .55272 .31014 .55905 .3101 .5557 .3047 Metetra
.55 .626 .88 r
.5557 .3047 .55905 .3101 .56542 .31037 .56206 .30429 Metetra
.542 .594 .855 r
.56206 .30429 .56542 .31037 .5718 .31083 .56844 .30411 Metetra
.541 .57 .834 r
.56844 .30411 .5718 .31083 .57822 .31125 .57485 .30402 Metetra
.547 .558 .818 r
.57485 .30402 .57822 .31125 .58465 .31134 .58128 .30388 Metetra
.562 .56 .809 r
.58128 .30388 .58465 .31134 .5911 .31083 .58773 .30347 Metetra
.585 .576 .809 r
.58773 .30347 .5911 .31083 .59754 .30949 .59419 .30258 Metetra
.616 .605 .817 r
.59419 .30258 .59754 .30949 .60399 .30724 .60065 .30105 Metetra
.651 .645 .831 r
.60065 .30105 .60399 .30724 .61042 .30419 .60712 .29882 Metetra
.686 .692 .849 r
.60712 .29882 .61042 .30419 .61685 .30059 .61358 .29596 Metetra
.715 .735 .867 r
.61358 .29596 .61685 .30059 .62329 .29676 .62004 .29265 Metetra
.731 .766 .881 r
.62004 .29265 .62329 .29676 .62973 .29304 .6265 .28912 Metetra
.731 .776 .889 r
.6265 .28912 .62973 .29304 .6362 .28966 .63298 .28563 Metetra
.719 .768 .891 r
.63298 .28563 .6362 .28966 .64269 .2867 .63947 .28237 Metetra
.699 .746 .888 r
.63947 .28237 .64269 .2867 .64921 .28412 .64599 .27943 Metetra
.68 .722 .881 r
.64599 .27943 .64921 .28412 .65576 .28179 .65253 .27682 Metetra
.666 .703 .875 r
.65253 .27682 .65576 .28179 .66232 .27953 .6591 .27443 Metetra
.66 .696 .872 r
.6591 .27443 .66232 .27953 .6689 .2772 .66568 .27214 Metetra
.662 .699 .874 r
.66568 .27214 .6689 .2772 .67548 .27471 .67228 .26982 Metetra
.668 .71 .879 r
.67228 .26982 .67548 .27471 .68207 .27205 .67889 .26739 Metetra
.677 .725 .886 r
.67889 .26739 .68207 .27205 .68866 .26927 .68551 .26482 Metetra
.684 .739 .892 r
.68551 .26482 .68866 .26927 .69527 .26643 .69214 .26213 Metetra
.689 .748 .897 r
.69214 .26213 .69527 .26643 .70189 .26361 .69878 .25936 Metetra
.69 .752 .899 r
.69878 .25936 .70189 .26361 .70853 .26084 .70543 .25658 Metetra
.688 .751 .9 r
.70543 .25658 .70853 .26084 .71519 .25815 .71209 .25384 Metetra
.684 .748 .9 r
.71209 .25384 .71519 .25815 .72187 .25553 .71877 .25115 Metetra
.68 .743 .899 r
.71877 .25115 .72187 .25553 .72856 .25296 .72548 .24852 Metetra
.677 .74 .898 r
.72548 .24852 .72856 .25296 .73527 .2504 .7322 .24594 Metetra
.675 .738 .898 r
.7322 .24594 .73527 .2504 .74199 .24784 .73893 .24339 Metetra
.675 .739 .899 r
.73893 .24339 .74199 .24784 .74873 .24528 .74569 .24083 Metetra
.675 .74 .9 r
.74569 .24083 .74873 .24528 .75549 .2427 .75245 .23828 Metetra
.675 .742 .901 r
.75245 .23828 .75549 .2427 .76226 .24011 .75924 .23571 Metetra
.676 .744 .902 r
.75924 .23571 .76226 .24011 .76904 .23752 .76603 .23313 Metetra
.676 .745 .903 r
.76603 .23313 .76904 .23752 .77584 .23494 .77285 .23055 Metetra
.675 .745 .903 r
.77285 .23055 .77584 .23494 .78266 .23237 .77967 .22797 Metetra
.675 .745 .904 r
.77967 .22797 .78266 .23237 .78949 .2298 .78652 .22539 Metetra
.674 .745 .904 r
.78652 .22539 .78949 .2298 .79634 .22725 .79338 .22282 Metetra
.673 .744 .904 r
.79338 .22282 .79634 .22725 .80321 .2247 .80026 .22026 Metetra
.673 .744 .904 r
.80026 .22026 .80321 .2247 .81009 .22215 .80715 .21771 Metetra
.672 .744 .904 r
.80715 .21771 .81009 .22215 .81699 .21961 .81406 .21515 Metetra
.672 .744 .905 r
.81406 .21515 .81699 .21961 .82391 .21706 .82099 .2126 Metetra
.656 .741 .912 r
.20223 .42041 .20606 .42395 .21161 .42212 .20778 .41858 Metetra
.656 .741 .912 r
.20778 .41858 .21161 .42212 .21717 .42029 .21335 .41674 Metetra
.656 .741 .913 r
.21335 .41674 .21717 .42029 .22274 .41847 .21893 .41491 Metetra
.656 .741 .913 r
.21893 .41491 .22274 .41847 .22832 .41665 .22452 .41308 Metetra
.656 .741 .913 r
.22452 .41308 .22832 .41665 .23392 .41482 .23012 .41124 Metetra
.656 .741 .912 r
.23012 .41124 .23392 .41482 .23952 .413 .23573 .4094 Metetra
.656 .74 .912 r
.23573 .4094 .23952 .413 .24514 .41116 .24136 .40755 Metetra
.655 .739 .912 r
.24136 .40755 .24514 .41116 .25078 .40933 .247 .4057 Metetra
.655 .739 .912 r
.247 .4057 .25078 .40933 .25642 .40748 .25265 .40386 Metetra
.653 .739 .913 r
.25265 .40386 .25642 .40748 .26208 .40565 .25832 .40204 Metetra
.651 .74 .915 r
.25832 .40204 .26208 .40565 .26775 .40382 .26399 .40025 Metetra
.649 .742 .917 r
.26399 .40025 .26775 .40382 .27343 .40202 .26967 .39848 Metetra
.648 .744 .919 r
.26967 .39848 .27343 .40202 .27912 .40025 .27537 .39671 Metetra
.649 .745 .919 r
.27537 .39671 .27912 .40025 .28482 .3985 .28108 .39493 Metetra
.652 .744 .917 r
.28108 .39493 .28482 .3985 .29053 .39675 .28681 .3931 Metetra
.656 .741 .913 r
.28681 .3931 .29053 .39675 .29626 .39497 .29255 .39122 Metetra
.658 .736 .907 r
.29255 .39122 .29626 .39497 .30201 .39314 .29831 .38929 Metetra
.658 .732 .904 r
.29831 .38929 .30201 .39314 .30777 .39124 .30408 .38736 Metetra
.653 .729 .905 r
.30408 .38736 .30777 .39124 .31355 .3893 .30986 .38549 Metetra
.643 .73 .912 r
.30986 .38549 .31355 .3893 .31934 .38738 .31565 .38377 Metetra
.628 .737 .926 r
.31565 .38377 .31934 .38738 .32514 .38558 .32143 .38223 Metetra
.611 .749 .943 r
.32143 .38223 .32514 .38558 .33093 .38396 .32722 .38087 Metetra
.601 .762 .956 r
.32722 .38087 .33093 .38396 .33673 .38256 .33302 .37957 Metetra
.608 .772 .959 r
.33302 .37957 .33673 .38256 .34254 .38131 .33884 .37816 Metetra
.636 .771 .944 r
.33884 .37816 .34254 .38131 .34836 .38005 .3447 .37646 Metetra
.668 .753 .914 r
.3447 .37646 .34836 .38005 .3542 .37859 .35059 .37435 Metetra
.686 .724 .879 r
.35059 .37435 .3542 .37859 .36009 .37673 .35651 .37188 Metetra
.686 .696 .853 r
.35651 .37188 .36009 .37673 .366 .37443 .36245 .36927 Metetra
.67 .678 .848 r
.36245 .36927 .366 .37443 .37195 .37182 .36838 .36693 Metetra
.631 .675 .874 r
.36838 .36693 .37195 .37182 .3779 .36926 .3743 .36535 Metetra
.534 .688 .938 r
.3743 .36535 .3779 .36926 .38384 .36724 .38017 .36489 Metetra
.226 .641 .957 r
.38017 .36489 .38384 .36724 .38975 .36623 .38601 .36569 Metetra
.31 0 0 r
.38601 .36569 .38975 .36623 .39563 .36655 .39184 .36753 Metetra
.505 0 0 r
.39184 .36753 .39563 .36655 .40147 .36817 .39767 .36981 Metetra
.495 0 0 r
.39767 .36981 .40147 .36817 .40731 .37067 .40354 .37174 Metetra
.301 0 0 r
.40354 .37174 .40731 .37067 .41318 .37332 .40949 .37246 Metetra
.404 .83 .962 r
.40949 .37246 .41318 .37332 .4191 .37522 .41552 .37135 Metetra
.722 .759 .881 r
.41552 .37135 .4191 .37522 .42509 .37556 .42164 .36816 Metetra
.732 .64 .756 r
.42164 .36816 .42509 .37556 .43118 .3738 .42782 .36307 Metetra
.718 .581 .7 r
.42782 .36307 .43118 .3738 .43733 .36986 .43405 .35666 Metetra
.704 .55 .675 r
.43405 .35666 .43733 .36986 .44354 .36406 .44028 .34965 Metetra
.693 .534 .667 r
.44028 .34965 .44354 .36406 .44978 .35704 .44651 .34277 Metetra
.683 .528 .67 r
.44651 .34277 .44978 .35704 .45602 .34958 .45272 .33656 Metetra
.676 .534 .683 r
.45272 .33656 .45602 .34958 .46226 .34239 .45891 .33129 Metetra
.673 .55 .708 r
.45891 .33129 .46226 .34239 .46847 .33599 .46508 .32698 Metetra
.671 .579 .744 r
.46508 .32698 .46847 .33599 .47466 .33064 .47125 .32348 Metetra
.672 .619 .788 r
.47125 .32348 .47466 .33064 .48084 .32637 .47741 .32058 Metetra
.671 .661 .831 r
.47741 .32058 .48084 .32637 .48701 .32302 .48358 .31805 Metetra
.668 .692 .864 r
.48358 .31805 .48701 .32302 .49318 .32036 .48975 .31573 Metetra
.664 .707 .879 r
.48975 .31573 .49318 .32036 .49937 .31814 .49594 .31353 Metetra
.659 .707 .882 r
.49594 .31353 .49937 .31814 .50556 .31615 .50215 .3114 Metetra
.655 .699 .879 r
.50215 .3114 .50556 .31615 .51177 .31426 .50837 .30934 Metetra
.65 .69 .874 r
.50837 .30934 .51177 .31426 .518 .31243 .5146 .30735 Metetra
.645 .681 .869 r
.5146 .30735 .518 .31243 .52424 .31068 .52084 .30543 Metetra
.639 .671 .865 r
.52084 .30543 .52424 .31068 .53049 .30904 .52711 .30361 Metetra
.631 .661 .861 r
.52711 .30361 .53049 .30904 .53676 .30758 .53338 .30192 Metetra
.621 .648 .855 r
.53338 .30192 .53676 .30758 .54306 .30634 .53968 .3004 Metetra
.609 .631 .848 r
.53968 .3004 .54306 .30634 .54937 .30538 .54599 .29908 Metetra
.595 .612 .839 r
.54599 .29908 .54937 .30538 .5557 .3047 .55233 .29801 Metetra
.581 .592 .829 r
.55233 .29801 .5557 .3047 .56206 .30429 .55868 .2972 Metetra
.567 .573 .819 r
.55868 .2972 .56206 .30429 .56844 .30411 .56506 .29667 Metetra
.557 .557 .81 r
.56506 .29667 .56844 .30411 .57485 .30402 .57147 .29635 Metetra
.551 .548 .804 r
.57147 .29635 .57485 .30402 .58128 .30388 .5779 .29615 Metetra
.553 .548 .803 r
.5779 .29615 .58128 .30388 .58773 .30347 .58435 .29592 Metetra
.563 .559 .807 r
.58435 .29592 .58773 .30347 .59419 .30258 .59082 .29548 Metetra
.582 .583 .818 r
.59082 .29548 .59419 .30258 .60065 .30105 .5973 .29463 Metetra
.611 .619 .835 r
.5973 .29463 .60065 .30105 .60712 .29882 .60379 .29322 Metetra
.646 .666 .855 r
.60379 .29322 .60712 .29882 .61358 .29596 .61028 .29116 Metetra
.682 .716 .875 r
.61028 .29116 .61358 .29596 .62004 .29265 .61677 .28851 Metetra
.711 .759 .89 r
.61677 .28851 .62004 .29265 .6265 .28912 .62326 .28537 Metetra
.728 .787 .899 r
.62326 .28537 .6265 .28912 .63298 .28563 .62975 .28198 Metetra
.731 .793 .902 r
.62975 .28198 .63298 .28563 .63947 .28237 .63625 .27854 Metetra
.721 .781 .9 r
.63625 .27854 .63947 .28237 .64599 .27943 .64277 .27526 Metetra
.704 .757 .894 r
.64277 .27526 .64599 .27943 .65253 .27682 .64931 .27225 Metetra
.685 .731 .885 r
.64931 .27225 .65253 .27682 .6591 .27443 .65587 .26955 Metetra
.67 .71 .878 r
.65587 .26955 .6591 .27443 .66568 .27214 .66246 .26708 Metetra
.661 .699 .875 r
.66246 .26708 .66568 .27214 .67228 .26982 .66907 .26476 Metetra
.66 .699 .875 r
.66907 .26476 .67228 .26982 .67889 .26739 .67569 .26246 Metetra
.664 .707 .88 r
.67569 .26246 .67889 .26739 .68551 .26482 .68233 .26009 Metetra
.671 .72 .886 r
.68233 .26009 .68551 .26482 .69214 .26213 .68898 .25761 Metetra
.679 .734 .892 r
.68898 .25761 .69214 .26213 .69878 .25936 .69564 .255 Metetra
.684 .745 .897 r
.69564 .255 .69878 .25936 .70543 .25658 .7023 .25231 Metetra
.686 .751 .9 r
.7023 .25231 .70543 .25658 .71209 .25384 .70898 .24957 Metetra
.686 .752 .901 r
.70898 .24957 .71209 .25384 .71877 .25115 .71568 .24684 Metetra
.683 .749 .901 r
.71568 .24684 .71877 .25115 .72548 .24852 .72239 .24415 Metetra
.68 .745 .9 r
.72239 .24415 .72548 .24852 .7322 .24594 .72911 .24151 Metetra
.677 .741 .899 r
.72911 .24151 .7322 .24594 .73893 .24339 .73586 .23892 Metetra
.675 .739 .899 r
.73586 .23892 .73893 .24339 .74569 .24083 .74262 .23635 Metetra
.674 .739 .899 r
.74262 .23635 .74569 .24083 .75245 .23828 .7494 .2338 Metetra
.674 .739 .9 r
.7494 .2338 .75245 .23828 .75924 .23571 .7562 .23125 Metetra
.674 .741 .901 r
.7562 .23125 .75924 .23571 .76603 .23313 .76301 .22869 Metetra
.674 .743 .902 r
.76301 .22869 .76603 .23313 .77285 .23055 .76984 .22612 Metetra
.674 .744 .903 r
.76984 .22612 .77285 .23055 .77967 .22797 .77668 .22355 Metetra
.674 .745 .904 r
.77668 .22355 .77967 .22797 .78652 .22539 .78353 .22097 Metetra
.674 .745 .904 r
.78353 .22097 .78652 .22539 .79338 .22282 .79041 .21839 Metetra
.673 .745 .904 r
.79041 .21839 .79338 .22282 .80026 .22026 .7973 .21581 Metetra
.673 .744 .904 r
.7973 .21581 .80026 .22026 .80715 .21771 .8042 .21324 Metetra
.672 .744 .904 r
.8042 .21324 .80715 .21771 .81406 .21515 .81113 .21068 Metetra
.672 .744 .904 r
.81113 .21068 .81406 .21515 .82099 .2126 .81807 .20811 Metetra
.656 .741 .912 r
.19838 .41685 .20223 .42041 .20778 .41858 .20394 .41502 Metetra
.656 .741 .912 r
.20394 .41502 .20778 .41858 .21335 .41674 .20951 .41318 Metetra
.656 .741 .912 r
.20951 .41318 .21335 .41674 .21893 .41491 .2151 .41134 Metetra
.656 .741 .912 r
.2151 .41134 .21893 .41491 .22452 .41308 .2207 .40949 Metetra
.656 .74 .912 r
.2207 .40949 .22452 .41308 .23012 .41124 .22631 .40763 Metetra
.656 .74 .912 r
.22631 .40763 .23012 .41124 .23573 .4094 .23193 .40578 Metetra
.655 .74 .912 r
.23193 .40578 .23573 .4094 .24136 .40755 .23756 .40393 Metetra
.654 .74 .912 r
.23756 .40393 .24136 .40755 .247 .4057 .24321 .40209 Metetra
.653 .74 .914 r
.24321 .40209 .247 .4057 .25265 .40386 .24887 .40027 Metetra
.651 .741 .916 r
.24887 .40027 .25265 .40386 .25832 .40204 .25453 .39847 Metetra
.65 .743 .918 r
.25453 .39847 .25832 .40204 .26399 .40025 .26021 .39669 Metetra
.65 .744 .918 r
.26021 .39669 .26399 .40025 .26967 .39848 .26591 .3949 Metetra
.651 .744 .917 r
.26591 .3949 .26967 .39848 .27537 .39671 .27161 .39308 Metetra
.654 .742 .914 r
.27161 .39308 .27537 .39671 .28108 .39493 .27734 .39122 Metetra
.657 .739 .91 r
.27734 .39122 .28108 .39493 .28681 .3931 .28307 .38932 Metetra
.658 .735 .906 r
.28307 .38932 .28681 .3931 .29255 .39122 .28883 .38738 Metetra
.656 .732 .905 r
.28883 .38738 .29255 .39122 .29831 .38929 .29459 .38547 Metetra
.65 .732 .909 r
.29459 .38547 .29831 .38929 .30408 .38736 .30036 .38365 Metetra
.639 .735 .918 r
.30036 .38365 .30408 .38736 .30986 .38549 .30614 .38198 Metetra
.625 .743 .932 r
.30614 .38198 .30986 .38549 .31565 .38377 .31191 .38048 Metetra
.612 .753 .945 r
.31191 .38048 .31565 .38377 .32143 .38223 .3177 .37909 Metetra
.609 .762 .952 r
.3177 .37909 .32143 .38223 .32722 .38087 .3235 .37771 Metetra
.624 .766 .947 r
.3235 .37771 .32722 .38087 .33302 .37957 .32932 .37615 Metetra
.65 .758 .928 r
.32932 .37615 .33302 .37957 .33884 .37816 .33517 .37429 Metetra
.674 .739 .899 r
.33517 .37429 .33884 .37816 .3447 .37646 .34106 .37207 Metetra
.685 .716 .873 r
.34106 .37207 .3447 .37646 .35059 .37435 .34698 .36958 Metetra
.682 .698 .859 r
.34698 .36958 .35059 .37435 .35651 .37188 .35291 .36708 Metetra
.662 .691 .867 r
.35291 .36708 .35651 .37188 .36245 .36927 .35883 .36496 Metetra
.614 .698 .904 r
.35883 .36496 .36245 .36927 .36838 .36693 .36472 .36362 Metetra
.492 .71 .968 r
.36472 .36362 .36838 .36693 .3743 .36535 .37058 .36334 Metetra
.171 .631 .935 r
.37058 .36334 .3743 .36535 .38017 .36489 .37641 .36415 Metetra
.24 0 0 r
.37641 .36415 .38017 .36489 .38601 .36569 .38222 .36577 Metetra
.391 0 0 r
.38222 .36577 .38601 .36569 .39184 .36753 .38805 .36766 Metetra
.32 0 0 r
.38805 .36766 .39184 .36753 .39767 .36981 .39393 .36909 Metetra
.07 .623 .823 r
.39393 .36909 .39767 .36981 .40354 .37174 .39988 .36936 Metetra
.58 .812 .987 r
.39988 .36936 .40354 .37174 .40949 .37246 .40591 .36797 Metetra
.717 .727 .858 r
.40591 .36797 .40949 .37246 .41552 .37135 .41203 .36473 Metetra
.739 .661 .773 r
.41203 .36473 .41552 .37135 .42164 .36816 .4182 .35982 Metetra
.741 .626 .731 r
.4182 .35982 .42164 .36816 .42782 .36307 .42442 .35373 Metetra
.738 .609 .714 r
.42442 .35373 .42782 .36307 .43405 .35666 .43066 .34707 Metetra
.734 .604 .711 r
.43066 .34707 .43405 .35666 .44028 .34965 .43689 .34048 Metetra
.729 .607 .721 r
.43689 .34048 .44028 .34965 .44651 .34277 .4431 .33443 Metetra
.723 .617 .74 r
.4431 .33443 .44651 .34277 .45272 .33656 .44929 .32922 Metetra
.713 .634 .767 r
.44929 .32922 .45272 .33656 .45891 .33129 .45546 .3249 Metetra
.702 .654 .799 r
.45546 .3249 .45891 .33129 .46508 .32698 .46163 .32139 Metetra
.688 .675 .832 r
.46163 .32139 .46508 .32698 .47125 .32348 .46778 .31849 Metetra
.676 .695 .86 r
.46778 .31849 .47125 .32348 .47741 .32058 .47395 .316 Metetra
.667 .711 .88 r
.47395 .316 .47741 .32058 .48358 .31805 .48012 .31374 Metetra
.663 .723 .894 r
.48012 .31374 .48358 .31805 .48975 .31573 .4863 .31158 Metetra
.66 .731 .902 r
.4863 .31158 .48975 .31573 .49594 .31353 .4925 .30946 Metetra
.659 .736 .906 r
.4925 .30946 .49594 .31353 .50215 .3114 .49872 .30736 Metetra
.657 .737 .908 r
.49872 .30736 .50215 .3114 .50837 .30934 .50494 .30528 Metetra
.655 .736 .909 r
.50494 .30528 .50837 .30934 .5146 .30735 .51118 .30325 Metetra
.651 .732 .909 r
.51118 .30325 .5146 .30735 .52084 .30543 .51744 .30127 Metetra
.645 .727 .908 r
.51744 .30127 .52084 .30543 .52711 .30361 .52371 .29936 Metetra
.639 .721 .907 r
.52371 .29936 .52711 .30361 .53338 .30192 .53 .29756 Metetra
.63 .712 .906 r
.53 .29756 .53338 .30192 .53968 .3004 .5363 .29589 Metetra
.62 .701 .903 r
.5363 .29589 .53968 .3004 .54599 .29908 .54262 .29437 Metetra
.607 .686 .898 r
.54262 .29437 .54599 .29908 .55233 .29801 .54896 .29305 Metetra
.593 .668 .891 r
.54896 .29305 .55233 .29801 .55868 .2972 .55532 .29194 Metetra
.579 .648 .882 r
.55532 .29194 .55868 .2972 .56506 .29667 .5617 .29107 Metetra
.567 .628 .872 r
.5617 .29107 .56506 .29667 .57147 .29635 .5681 .29042 Metetra
.558 .61 .861 r
.5681 .29042 .57147 .29635 .5779 .29615 .57453 .28994 Metetra
.555 .598 .851 r
.57453 .28994 .5779 .29615 .58435 .29592 .58098 .28953 Metetra
.559 .594 .845 r
.58098 .28953 .58435 .29592 .59082 .29548 .58746 .28907 Metetra
.571 .6 .843 r
.58746 .28907 .59082 .29548 .5973 .29463 .59395 .2884 Metetra
.592 .617 .846 r
.59395 .2884 .5973 .29463 .60379 .29322 .60045 .28735 Metetra
.619 .644 .853 r
.60045 .28735 .60379 .29322 .61028 .29116 .60696 .2858 Metetra
.65 .679 .864 r
.60696 .2858 .61028 .29116 .61677 .28851 .61348 .2837 Metetra
.68 .716 .876 r
.61348 .2837 .61677 .28851 .62326 .28537 .61999 .28106 Metetra
.705 .75 .886 r
.61999 .28106 .62326 .28537 .62975 .28198 .6265 .27799 Metetra
.721 .773 .894 r
.6265 .27799 .62975 .28198 .63625 .27854 .63302 .27469 Metetra
.724 .781 .898 r
.63302 .27469 .63625 .27854 .64277 .27526 .63955 .27132 Metetra
.717 .776 .898 r
.63955 .27132 .64277 .27526 .64931 .27225 .64609 .26808 Metetra
.703 .759 .895 r
.64609 .26808 .64931 .27225 .65587 .26955 .65265 .26508 Metetra
.687 .738 .89 r
.65265 .26508 .65587 .26955 .66246 .26708 .65924 .26235 Metetra
.672 .72 .885 r
.65924 .26235 .66246 .26708 .66907 .26476 .66585 .25985 Metetra
.663 .708 .881 r
.66585 .25985 .66907 .26476 .67569 .26246 .67248 .2575 Metetra
.66 .705 .88 r
.67248 .2575 .67569 .26246 .68233 .26009 .67913 .2552 Metetra
.662 .71 .883 r
.67913 .2552 .68233 .26009 .68898 .25761 .6858 .25286 Metetra
.668 .719 .887 r
.6858 .25286 .68898 .25761 .69564 .255 .69248 .25042 Metetra
.675 .731 .893 r
.69248 .25042 .69564 .255 .7023 .25231 .69916 .24787 Metetra
.68 .741 .897 r
.69916 .24787 .7023 .25231 .70898 .24957 .70586 .24523 Metetra
.683 .748 .9 r
.70586 .24523 .70898 .24957 .71568 .24684 .71256 .24253 Metetra
.684 .75 .902 r
.71256 .24253 .71568 .24684 .72239 .24415 .71929 .23982 Metetra
.682 .749 .902 r
.71929 .23982 .72239 .24415 .72911 .24151 .72602 .23714 Metetra
.68 .746 .901 r
.72602 .23714 .72911 .24151 .73586 .23892 .73278 .23449 Metetra
.677 .743 .901 r
.73278 .23449 .73586 .23892 .74262 .23635 .73955 .23188 Metetra
.674 .74 .9 r
.73955 .23188 .74262 .23635 .7494 .2338 .74634 .22931 Metetra
.673 .739 .9 r
.74634 .22931 .7494 .2338 .7562 .23125 .75315 .22676 Metetra
.673 .739 .901 r
.75315 .22676 .7562 .23125 .76301 .22869 .75997 .22421 Metetra
.673 .74 .901 r
.75997 .22421 .76301 .22869 .76984 .22612 .76681 .22165 Metetra
.673 .742 .902 r
.76681 .22165 .76984 .22612 .77668 .22355 .77366 .21908 Metetra
.673 .743 .903 r
.77366 .21908 .77668 .22355 .78353 .22097 .78053 .21651 Metetra
.673 .744 .904 r
.78053 .21651 .78353 .22097 .79041 .21839 .78742 .21393 Metetra
.673 .744 .904 r
.78742 .21393 .79041 .21839 .7973 .21581 .79432 .21134 Metetra
.673 .744 .904 r
.79432 .21134 .7973 .21581 .8042 .21324 .80124 .20876 Metetra
.672 .744 .904 r
.80124 .20876 .8042 .21324 .81113 .21068 .80817 .20618 Metetra
.672 .744 .905 r
.80817 .20618 .81113 .21068 .81807 .20811 .81513 .20361 Metetra
.656 .741 .912 r
.19452 .41329 .19838 .41685 .20394 .41502 .20008 .41144 Metetra
.656 .741 .912 r
.20008 .41144 .20394 .41502 .20951 .41318 .20567 .40959 Metetra
.656 .741 .912 r
.20567 .40959 .20951 .41318 .2151 .41134 .21126 .40773 Metetra
.656 .74 .912 r
.21126 .40773 .2151 .41134 .2207 .40949 .21686 .40587 Metetra
.656 .74 .912 r
.21686 .40587 .2207 .40949 .22631 .40763 .22248 .40402 Metetra
.655 .74 .912 r
.22248 .40402 .22631 .40763 .23193 .40578 .22811 .40216 Metetra
.654 .74 .913 r
.22811 .40216 .23193 .40578 .23756 .40393 .23375 .40033 Metetra
.652 .741 .915 r
.23375 .40033 .23756 .40393 .24321 .40209 .2394 .39851 Metetra
.651 .742 .916 r
.2394 .39851 .24321 .40209 .24887 .40027 .24506 .3967 Metetra
.651 .743 .917 r
.24506 .3967 .24887 .40027 .25453 .39847 .25074 .3949 Metetra
.651 .744 .917 r
.25074 .3949 .25453 .39847 .26021 .39669 .25642 .39308 Metetra
.653 .743 .915 r
.25642 .39308 .26021 .39669 .26591 .3949 .26213 .39123 Metetra
.656 .741 .912 r
.26213 .39123 .26591 .3949 .27161 .39308 .26785 .38934 Metetra
.658 .737 .908 r
.26785 .38934 .27161 .39308 .27734 .39122 .27358 .38742 Metetra
.657 .734 .906 r
.27358 .38742 .27734 .39122 .28307 .38932 .27933 .38549 Metetra
.654 .733 .907 r
.27933 .38549 .28307 .38932 .28883 .38738 .28508 .38362 Metetra
.646 .734 .913 r
.28508 .38362 .28883 .38738 .29459 .38547 .29085 .38186 Metetra
.635 .74 .924 r
.29085 .38186 .29459 .38547 .30036 .38365 .29661 .38023 Metetra
.623 .748 .937 r
.29661 .38023 .30036 .38365 .30614 .38198 .30238 .37874 Metetra
.616 .758 .946 r
.30238 .37874 .30614 .38198 .31191 .38048 .30816 .3773 Metetra
.62 .764 .948 r
.30816 .3773 .31191 .38048 .3177 .37909 .31396 .37579 Metetra
.639 .762 .937 r
.31396 .37579 .3177 .37909 .3235 .37771 .31978 .37407 Metetra
.662 .749 .915 r
.31978 .37407 .3235 .37771 .32932 .37615 .32564 .37205 Metetra
.678 .728 .888 r
.32564 .37205 .32932 .37615 .33517 .37429 .33153 .36973 Metetra
.682 .708 .867 r
.33153 .36973 .33517 .37429 .34106 .37207 .33744 .36727 Metetra
.672 .694 .862 r
.33744 .36727 .34106 .37207 .34698 .36958 .34336 .36496 Metetra
.646 .694 .88 r
.34336 .36496 .34698 .36958 .35291 .36708 .34925 .36314 Metetra
.585 .708 .928 r
.34925 .36314 .35291 .36708 .35883 .36496 .35512 .36213 Metetra
.431 .717 .984 r
.35512 .36213 .35883 .36496 .36472 .36362 .36096 .36207 Metetra
.091 .604 .887 r
.36096 .36207 .36472 .36362 .37058 .36334 .36677 .36288 Metetra
.221 0 0 r
.36677 .36288 .37058 .36334 .37641 .36415 .37259 .36419 Metetra
.282 0 0 r
.37259 .36419 .37641 .36415 .38222 .36577 .37843 .36547 Metetra
.084 0 0 r
.37843 .36547 .38222 .36577 .38805 .36766 .38432 .36606 Metetra
.407 .792 .99 r
.38432 .36606 .38805 .36766 .39393 .36909 .3903 .36543 Metetra
.666 .756 .917 r
.3903 .36543 .39393 .36909 .39988 .36936 .39635 .36328 Metetra
.712 .666 .803 r
.39635 .36328 .39988 .36936 .40591 .36797 .40247 .35958 Metetra
.716 .613 .741 r
.40247 .35958 .40591 .36797 .41203 .36473 .40865 .35462 Metetra
.713 .585 .711 r
.40865 .35462 .41203 .36473 .4182 .35982 .41486 .34887 Metetra
.709 .573 .7 r
.41486 .34887 .4182 .35982 .42442 .35373 .42108 .34285 Metetra
.706 .572 .702 r
.42108 .34285 .42442 .35373 .43066 .34707 .42728 .33704 Metetra
.704 .581 .715 r
.42728 .33704 .43066 .34707 .43689 .34048 .43348 .33177 Metetra
.703 .601 .74 r
.43348 .33177 .43689 .34048 .4431 .33443 .43965 .32719 Metetra
.702 .631 .774 r
.43965 .32719 .4431 .33443 .44929 .32922 .44582 .3233 Metetra
.7 .668 .815 r
.44582 .3233 .44929 .32922 .45546 .3249 .45197 .32 Metetra
.694 .705 .856 r
.45197 .32 .45546 .3249 .46163 .32139 .45813 .31716 Metetra
.685 .734 .888 r
.45813 .31716 .46163 .32139 .46778 .31849 .46429 .31461 Metetra
.676 .75 .907 r
.46429 .31461 .46778 .31849 .47395 .316 .47046 .31226 Metetra
.669 .756 .916 r
.47046 .31226 .47395 .316 .48012 .31374 .47664 .31001 Metetra
.665 .756 .918 r
.47664 .31001 .48012 .31374 .4863 .31158 .48284 .30782 Metetra
.663 .754 .918 r
.48284 .30782 .4863 .31158 .4925 .30946 .48904 .30565 Metetra
.661 .752 .917 r
.48904 .30565 .4925 .30946 .49872 .30736 .49527 .30352 Metetra
.66 .75 .917 r
.49527 .30352 .49872 .30736 .50494 .30528 .5015 .3014 Metetra
.658 .747 .916 r
.5015 .3014 .50494 .30528 .51118 .30325 .50775 .2993 Metetra
.655 .744 .915 r
.50775 .2993 .51118 .30325 .51744 .30127 .51402 .29725 Metetra
.651 .739 .913 r
.51402 .29725 .51744 .30127 .52371 .29936 .5203 .29524 Metetra
.647 .732 .911 r
.5203 .29524 .52371 .29936 .53 .29756 .52659 .2933 Metetra
.641 .723 .907 r
.52659 .2933 .53 .29756 .5363 .29589 .5329 .29145 Metetra
.633 .711 .903 r
.5329 .29145 .5363 .29589 .54262 .29437 .53923 .28971 Metetra
.624 .696 .896 r
.53923 .28971 .54262 .29437 .54896 .29305 .54558 .28811 Metetra
.614 .679 .888 r
.54558 .28811 .54896 .29305 .55532 .29194 .55194 .28669 Metetra
.602 .659 .878 r
.55194 .28669 .55532 .29194 .5617 .29107 .55832 .28545 Metetra
.59 .638 .867 r
.55832 .28545 .5617 .29107 .5681 .29042 .56473 .28442 Metetra
.579 .618 .855 r
.56473 .28442 .5681 .29042 .57453 .28994 .57116 .28358 Metetra
.571 .602 .845 r
.57116 .28358 .57453 .28994 .58098 .28953 .57761 .2829 Metetra
.568 .591 .836 r
.57761 .2829 .58098 .28953 .58746 .28907 .58408 .28229 Metetra
.57 .587 .831 r
.58408 .28229 .58746 .28907 .59395 .2884 .59058 .28164 Metetra
.579 .593 .831 r
.59058 .28164 .59395 .2884 .60045 .28735 .59709 .28082 Metetra
.595 .609 .836 r
.59709 .28082 .60045 .28735 .60696 .2858 .60361 .27969 Metetra
.618 .635 .846 r
.60361 .27969 .60696 .2858 .61348 .2837 .61015 .27813 Metetra
.645 .669 .859 r
.61015 .27813 .61348 .2837 .61999 .28106 .61669 .27609 Metetra
.672 .707 .874 r
.61669 .27609 .61999 .28106 .6265 .27799 .62323 .27357 Metetra
.697 .743 .887 r
.62323 .27357 .6265 .27799 .63302 .27469 .62977 .27065 Metetra
.713 .769 .897 r
.62977 .27065 .63302 .27469 .63955 .27132 .63631 .26749 Metetra
.719 .782 .902 r
.63631 .26749 .63955 .27132 .64609 .26808 .64287 .26423 Metetra
.715 .781 .904 r
.64287 .26423 .64609 .26808 .65265 .26508 .64944 .26104 Metetra
.704 .768 .902 r
.64944 .26104 .65265 .26508 .65924 .26235 .65602 .25803 Metetra
.689 .748 .897 r
.65602 .25803 .65924 .26235 .66585 .25985 .66263 .25525 Metetra
.675 .729 .891 r
.66263 .25525 .66585 .25985 .67248 .2575 .66927 .2527 Metetra
.665 .716 .886 r
.66927 .2527 .67248 .2575 .67913 .2552 .67592 .2503 Metetra
.661 .709 .884 r
.67592 .2503 .67913 .2552 .6858 .25286 .6826 .24797 Metetra
.661 .711 .885 r
.6826 .24797 .6858 .25286 .69248 .25042 .68929 .24563 Metetra
.665 .718 .888 r
.68929 .24563 .69248 .25042 .69916 .24787 .696 .24323 Metetra
.671 .728 .892 r
.696 .24323 .69916 .24787 .70586 .24523 .70271 .24072 Metetra
.676 .737 .897 r
.70271 .24072 .70586 .24523 .71256 .24253 .70944 .23813 Metetra
.68 .745 .9 r
.70944 .23813 .71256 .24253 .71929 .23982 .71617 .23547 Metetra
.682 .749 .902 r
.71617 .23547 .71929 .23982 .72602 .23714 .72292 .23278 Metetra
.681 .749 .903 r
.72292 .23278 .72602 .23714 .73278 .23449 .72968 .2301 Metetra
.679 .747 .902 r
.72968 .2301 .73278 .23449 .73955 .23188 .73647 .22745 Metetra
.677 .744 .902 r
.73647 .22745 .73955 .23188 .74634 .22931 .74327 .22484 Metetra
.674 .742 .901 r
.74327 .22484 .74634 .22931 .75315 .22676 .75008 .22225 Metetra
.673 .74 .901 r
.75008 .22225 .75315 .22676 .75997 .22421 .75692 .21969 Metetra
.672 .74 .901 r
.75692 .21969 .75997 .22421 .76681 .22165 .76377 .21713 Metetra
.672 .74 .902 r
.76377 .21713 .76681 .22165 .77366 .21908 .77064 .21457 Metetra
.672 .741 .902 r
.77064 .21457 .77366 .21908 .78053 .21651 .77752 .21201 Metetra
.672 .742 .903 r
.77752 .21201 .78053 .21651 .78742 .21393 .78442 .20943 Metetra
.672 .743 .904 r
.78442 .20943 .78742 .21393 .79432 .21134 .79133 .20685 Metetra
.672 .744 .904 r
.79133 .20685 .79432 .21134 .80124 .20876 .79826 .20426 Metetra
.672 .744 .905 r
.79826 .20426 .80124 .20876 .80817 .20618 .80521 .20168 Metetra
.672 .744 .905 r
.80521 .20168 .80817 .20618 .81513 .20361 .81217 .19909 Metetra
.657 .741 .912 r
.19064 .4097 .19452 .41329 .20008 .41144 .19621 .40784 Metetra
.657 .741 .912 r
.19621 .40784 .20008 .41144 .20567 .40959 .2018 .40598 Metetra
.656 .74 .912 r
.2018 .40598 .20567 .40959 .21126 .40773 .2074 .40411 Metetra
.656 .74 .912 r
.2074 .40411 .21126 .40773 .21686 .40587 .21301 .40225 Metetra
.655 .74 .912 r
.21301 .40225 .21686 .40587 .22248 .40402 .21864 .4004 Metetra
.654 .741 .914 r
.21864 .4004 .22248 .40402 .22811 .40216 .22427 .39856 Metetra
.652 .742 .915 r
.22427 .39856 .22811 .40216 .23375 .40033 .22992 .39674 Metetra
.652 .743 .916 r
.22992 .39674 .23375 .40033 .2394 .39851 .23557 .39492 Metetra
.652 .743 .917 r
.23557 .39492 .2394 .39851 .24506 .3967 .24124 .3931 Metetra
.653 .743 .916 r
.24124 .3931 .24506 .3967 .25074 .3949 .24693 .39126 Metetra
.655 .742 .914 r
.24693 .39126 .25074 .3949 .25642 .39308 .25263 .38938 Metetra
.657 .739 .91 r
.25263 .38938 .25642 .39308 .26213 .39123 .25834 .38747 Metetra
.658 .736 .908 r
.25834 .38747 .26213 .39123 .26785 .38934 .26407 .38554 Metetra
.656 .734 .907 r
.26407 .38554 .26785 .38934 .27358 .38742 .26981 .38363 Metetra
.651 .734 .91 r
.26981 .38363 .27358 .38742 .27933 .38549 .27556 .38179 Metetra
.643 .737 .917 r
.27556 .38179 .27933 .38549 .28508 .38362 .28131 .38007 Metetra
.632 .743 .928 r
.28131 .38007 .28508 .38362 .29085 .38186 .28706 .37847 Metetra
.623 .751 .938 r
.28706 .37847 .29085 .38186 .29661 .38023 .29283 .37697 Metetra
.621 .758 .944 r
.29283 .37697 .29661 .38023 .30238 .37874 .2986 .37546 Metetra
.631 .761 .941 r
.2986 .37546 .30238 .37874 .30816 .3773 .3044 .37385 Metetra
.65 .756 .927 r
.3044 .37385 .30816 .3773 .31396 .37579 .31023 .37199 Metetra
.669 .742 .905 r
.31023 .37199 .31396 .37579 .31978 .37407 .31609 .36986 Metetra
.68 .723 .883 r
.31609 .36986 .31978 .37407 .32564 .37205 .32198 .36749 Metetra
.679 .707 .869 r
.32198 .36749 .32564 .37205 .33153 .36973 .32788 .36509 Metetra
.665 .699 .872 r
.32788 .36509 .33153 .36973 .33744 .36727 .33378 .36292 Metetra
.632 .703 .896 r
.33378 .36292 .33744 .36727 .34336 .36496 .33966 .36131 Metetra
.56 .717 .946 r
.33966 .36131 .34336 .36496 .34925 .36314 .34551 .36051 Metetra
.393 .714 .987 r
.34551 .36051 .34925 .36314 .35512 .36213 .35133 .36057 Metetra
.093 .607 .888 r
.35133 .36057 .35512 .36213 .36096 .36207 .35713 .36136 Metetra
.139 0 0 r
.35713 .36136 .36096 .36207 .36677 .36288 .36294 .36248 Metetra
.143 0 0 r
.36294 .36248 .36677 .36288 .37259 .36419 .36878 .36339 Metetra
.114 .653 .852 r
.36878 .36339 .37259 .36419 .37843 .36547 .37468 .36354 Metetra
.514 .818 1 r
.37468 .36354 .37843 .36547 .38432 .36606 .38066 .36245 Metetra
.69 .765 .909 r
.38066 .36245 .38432 .36606 .3903 .36543 .38672 .35992 Metetra
.728 .69 .814 r
.38672 .35992 .3903 .36543 .39635 .36328 .39286 .35598 Metetra
.733 .643 .759 r
.39286 .35598 .39635 .36328 .40247 .35958 .39904 .35093 Metetra
.729 .615 .731 r
.39904 .35093 .40247 .35958 .40865 .35462 .40525 .34523 Metetra
.723 .601 .719 r
.40525 .34523 .40865 .35462 .41486 .34887 .41146 .33937 Metetra
.716 .596 .72 r
.41146 .33937 .41486 .34887 .42108 .34285 .41767 .33377 Metetra
.709 .598 .73 r
.41767 .33377 .42108 .34285 .42728 .33704 .42385 .32873 Metetra
.702 .608 .748 r
.42385 .32873 .42728 .33704 .43348 .33177 .43002 .32436 Metetra
.695 .624 .773 r
.43002 .32436 .43348 .33177 .43965 .32719 .43618 .32066 Metetra
.687 .644 .801 r
.43618 .32066 .43965 .32719 .44582 .3233 .44233 .31751 Metetra
.679 .665 .829 r
.44233 .31751 .44582 .3233 .45197 .32 .44848 .31478 Metetra
.673 .684 .853 r
.44848 .31478 .45197 .32 .45813 .31716 .45463 .31231 Metetra
.668 .699 .87 r
.45463 .31231 .45813 .31716 .46429 .31461 .4608 .30999 Metetra
.665 .709 .88 r
.4608 .30999 .46429 .31461 .47046 .31226 .46697 .30775 Metetra
.664 .715 .886 r
.46697 .30775 .47046 .31226 .47664 .31001 .47316 .30554 Metetra
.663 .717 .889 r
.47316 .30554 .47664 .31001 .48284 .30782 .47936 .30336 Metetra
.662 .717 .89 r
.47936 .30336 .48284 .30782 .48904 .30565 .48558 .30119 Metetra
.66 .717 .89 r
.48558 .30119 .48904 .30565 .49527 .30352 .49181 .29903 Metetra
.659 .716 .89 r
.49181 .29903 .49527 .30352 .5015 .3014 .49805 .29688 Metetra
.658 .715 .89 r
.49805 .29688 .5015 .3014 .50775 .2993 .50431 .29476 Metetra
.656 .713 .89 r
.50431 .29476 .50775 .2993 .51402 .29725 .51059 .29267 Metetra
.653 .71 .89 r
.51059 .29267 .51402 .29725 .5203 .29524 .51687 .29061 Metetra
.65 .707 .889 r
.51687 .29061 .5203 .29524 .52659 .2933 .52318 .2886 Metetra
.645 .703 .888 r
.52318 .2886 .52659 .2933 .5329 .29145 .5295 .28666 Metetra
.64 .697 .887 r
.5295 .28666 .5329 .29145 .53923 .28971 .53583 .28481 Metetra
.633 .689 .884 r
.53583 .28481 .53923 .28971 .54558 .28811 .54218 .28306 Metetra
.624 .679 .881 r
.54218 .28306 .54558 .28811 .55194 .28669 .54855 .28145 Metetra
.614 .666 .877 r
.54855 .28145 .55194 .28669 .55832 .28545 .55494 .28 Metetra
.603 .653 .871 r
.55494 .28 .55832 .28545 .56473 .28442 .56135 .27873 Metetra
.592 .638 .865 r
.56135 .27873 .56473 .28442 .57116 .28358 .56778 .27765 Metetra
.582 .624 .858 r
.56778 .27765 .57116 .28358 .57761 .2829 .57423 .27675 Metetra
.575 .612 .852 r
.57423 .27675 .57761 .2829 .58408 .28229 .5807 .27597 Metetra
.572 .605 .847 r
.5807 .27597 .58408 .28229 .59058 .28164 .5872 .27526 Metetra
.574 .604 .845 r
.5872 .27526 .59058 .28164 .59709 .28082 .59372 .27451 Metetra
.583 .611 .846 r
.59372 .27451 .59709 .28082 .60361 .27969 .60026 .2736 Metetra
.598 .627 .852 r
.60026 .2736 .60361 .27969 .61015 .27813 .60681 .2724 Metetra
.619 .652 .86 r
.60681 .2724 .61015 .27813 .61669 .27609 .61336 .27081 Metetra
.645 .683 .871 r
.61336 .27081 .61669 .27609 .62323 .27357 .61993 .26878 Metetra
.671 .716 .883 r
.61993 .26878 .62323 .27357 .62977 .27065 .62649 .26631 Metetra
.693 .747 .893 r
.62649 .26631 .62977 .27065 .63631 .26749 .63306 .26347 Metetra
.709 .77 .9 r
.63306 .26347 .63631 .26749 .64287 .26423 .63963 .26037 Metetra
.715 .782 .904 r
.63963 .26037 .64287 .26423 .64944 .26104 .64621 .25716 Metetra
.713 .781 .905 r
.64621 .25716 .64944 .26104 .65602 .25803 .65281 .254 Metetra
.704 .77 .903 r
.65281 .254 .65602 .25803 .66263 .25525 .65942 .25098 Metetra
.691 .753 .899 r
.65942 .25098 .66263 .25525 .66927 .2527 .66605 .24816 Metetra
.678 .735 .894 r
.66605 .24816 .66927 .2527 .67592 .2503 .67271 .24556 Metetra
.667 .721 .889 r
.67271 .24556 .67592 .2503 .6826 .24797 .67939 .24312 Metetra
.662 .714 .887 r
.67939 .24312 .6826 .24797 .68929 .24563 .68609 .24076 Metetra
.661 .713 .887 r
.68609 .24076 .68929 .24563 .696 .24323 .69281 .23842 Metetra
.663 .718 .889 r
.69281 .23842 .696 .24323 .70271 .24072 .69954 .23604 Metetra
.668 .726 .893 r
.69954 .23604 .70271 .24072 .70944 .23813 .70628 .23357 Metetra
.673 .735 .897 r
.70628 .23357 .70944 .23813 .71617 .23547 .71304 .23101 Metetra
.677 .742 .9 r
.71304 .23101 .71617 .23547 .72292 .23278 .7198 .22838 Metetra
.679 .747 .902 r
.7198 .22838 .72292 .23278 .72968 .2301 .72658 .22572 Metetra
.68 .748 .903 r
.72658 .22572 .72968 .2301 .73647 .22745 .73337 .22305 Metetra
.678 .747 .903 r
.73337 .22305 .73647 .22745 .74327 .22484 .74018 .22039 Metetra
.676 .745 .903 r
.74018 .22039 .74327 .22484 .75008 .22225 .74701 .21777 Metetra
.674 .743 .902 r
.74701 .21777 .75008 .22225 .75692 .21969 .75385 .21517 Metetra
.673 .741 .902 r
.75385 .21517 .75692 .21969 .76377 .21713 .76071 .21259 Metetra
.672 .74 .902 r
.76071 .21259 .76377 .21713 .77064 .21457 .76759 .21003 Metetra
.671 .74 .902 r
.76759 .21003 .77064 .21457 .77752 .21201 .77449 .20747 Metetra
.671 .741 .903 r
.77449 .20747 .77752 .21201 .78442 .20943 .7814 .2049 Metetra
.671 .742 .903 r
.7814 .2049 .78442 .20943 .79133 .20685 .78833 .20232 Metetra
.672 .743 .904 r
.78833 .20232 .79133 .20685 .79826 .20426 .79527 .19974 Metetra
.672 .743 .904 r
.79527 .19974 .79826 .20426 .80521 .20168 .80223 .19715 Metetra
.671 .744 .905 r
.80223 .19715 .80521 .20168 .81217 .19909 .80921 .19455 Metetra
.657 .741 .912 r
.18675 .4061 .19064 .4097 .19621 .40784 .19233 .40423 Metetra
.657 .74 .912 r
.19233 .40423 .19621 .40784 .2018 .40598 .19792 .40236 Metetra
.656 .74 .912 r
.19792 .40236 .2018 .40598 .2074 .40411 .20353 .40049 Metetra
.655 .741 .913 r
.20353 .40049 .2074 .40411 .21301 .40225 .20915 .39864 Metetra
.654 .741 .914 r
.20915 .39864 .21301 .40225 .21864 .4004 .21477 .3968 Metetra
.653 .742 .915 r
.21477 .3968 .21864 .4004 .22427 .39856 .22041 .39497 Metetra
.652 .743 .916 r
.22041 .39497 .22427 .39856 .22992 .39674 .22607 .39314 Metetra
.653 .743 .916 r
.22607 .39314 .22992 .39674 .23557 .39492 .23173 .3913 Metetra
.654 .742 .914 r
.23173 .3913 .23557 .39492 .24124 .3931 .23741 .38943 Metetra
.656 .741 .912 r
.23741 .38943 .24124 .3931 .24693 .39126 .24311 .38753 Metetra
.658 .738 .909 r
.24311 .38753 .24693 .39126 .25263 .38938 .24882 .38561 Metetra
.657 .736 .908 r
.24882 .38561 .25263 .38938 .25834 .38747 .25454 .38368 Metetra
.654 .735 .909 r
.25454 .38368 .25834 .38747 .26407 .38554 .26027 .3818 Metetra
.649 .736 .913 r
.26027 .3818 .26407 .38554 .26981 .38363 .26601 .37999 Metetra
.64 .74 .921 r
.26601 .37999 .26981 .38363 .27556 .38179 .27175 .3783 Metetra
.631 .747 .931 r
.27175 .3783 .27556 .38179 .28131 .38007 .2775 .3767 Metetra
.625 .753 .939 r
.2775 .3767 .28131 .38007 .28706 .37847 .28326 .37516 Metetra
.628 .758 .94 r
.28326 .37516 .28706 .37847 .29283 .37697 .28904 .37358 Metetra
.64 .757 .933 r
.28904 .37358 .29283 .37697 .2986 .37546 .29484 .37185 Metetra
.658 .749 .917 r
.29484 .37185 .2986 .37546 .3044 .37385 .30067 .36988 Metetra
.672 .734 .897 r
.30067 .36988 .3044 .37385 .31023 .37199 .30653 .36767 Metetra
.678 .718 .879 r
.30653 .36767 .31023 .37199 .31609 .36986 .31241 .36532 Metetra
.674 .707 .872 r
.31241 .36532 .31609 .36986 .32198 .36749 .3183 .36301 Metetra
.656 .704 .882 r
.3183 .36301 .32198 .36749 .32788 .36509 .32418 .36102 Metetra
.617 .713 .914 r
.32418 .36102 .32788 .36509 .33378 .36292 .33004 .35961 Metetra
.534 .729 .964 r
.33004 .35961 .33378 .36292 .33966 .36131 .33587 .35895 Metetra
.362 .718 .987 r
.33587 .35895 .33966 .36131 .34551 .36051 .34168 .35903 Metetra
.118 .628 .896 r
.34168 .35903 .34551 .36051 .35133 .36057 .34747 .35965 Metetra
0 .549 .787 r
.34747 .35965 .35133 .36057 .35713 .36136 .35329 .36042 Metetra
.066 .613 .837 r
.35329 .36042 .35713 .36136 .36294 .36248 .35914 .36086 Metetra
.359 .767 .982 r
.35914 .36086 .36294 .36248 .36878 .36339 .36505 .36049 Metetra
.608 .786 .966 r
.36505 .36049 .36878 .36339 .37468 .36354 .37104 .35899 Metetra
.695 .719 .867 r
.37104 .35899 .37468 .36354 .38066 .36245 .37711 .35621 Metetra
.718 .663 .795 r
.37711 .35621 .38066 .36245 .38672 .35992 .38324 .35225 Metetra
.723 .63 .754 r
.38324 .35225 .38672 .35992 .39286 .35598 .38941 .3474 Metetra
.722 .613 .735 r
.38941 .3474 .39286 .35598 .39904 .35093 .39561 .34207 Metetra
.72 .607 .73 r
.39561 .34207 .39904 .35093 .40525 .34523 .40181 .33666 Metetra
.718 .611 .737 r
.40181 .33666 .40525 .34523 .41146 .33937 .408 .33151 Metetra
.716 .624 .753 r
.408 .33151 .41146 .33937 .41767 .33377 .41418 .32683 Metetra
.713 .643 .778 r
.41418 .32683 .41767 .33377 .42385 .32873 .42034 .32271 Metetra
.708 .668 .809 r
.42034 .32271 .42385 .32873 .43002 .32436 .42649 .31915 Metetra
.701 .695 .841 r
.42649 .31915 .43002 .32436 .43618 .32066 .43264 .31606 Metetra
.692 .718 .87 r
.43264 .31606 .43618 .32066 .44233 .31751 .43878 .31332 Metetra
.682 .736 .891 r
.43878 .31332 .44233 .31751 .44848 .31478 .44494 .31082 Metetra
.675 .746 .905 r
.44494 .31082 .44848 .31478 .45463 .31231 .4511 .30847 Metetra
.67 .752 .912 r
.4511 .30847 .45463 .31231 .4608 .30999 .45727 .3062 Metetra
.667 .754 .916 r
.45727 .3062 .4608 .30999 .46697 .30775 .46345 .30398 Metetra
.665 .755 .917 r
.46345 .30398 .46697 .30775 .47316 .30554 .46965 .30177 Metetra
.664 .756 .918 r
.46965 .30177 .47316 .30554 .47936 .30336 .47586 .29958 Metetra
.663 .756 .919 r
.47586 .29958 .47936 .30336 .48558 .30119 .48209 .2974 Metetra
.663 .755 .919 r
.48209 .2974 .48558 .30119 .49181 .29903 .48833 .29522 Metetra
.662 .754 .919 r
.48833 .29522 .49181 .29903 .49805 .29688 .49458 .29305 Metetra
.66 .753 .919 r
.49458 .29305 .49805 .29688 .50431 .29476 .50085 .2909 Metetra
.659 .751 .918 r
.50085 .2909 .50431 .29476 .51059 .29267 .50714 .28877 Metetra
.657 .749 .918 r
.50714 .28877 .51059 .29267 .51687 .29061 .51343 .28666 Metetra
.654 .746 .917 r
.51343 .28666 .51687 .29061 .52318 .2886 .51975 .28458 Metetra
.651 .741 .916 r
.51975 .28458 .52318 .2886 .5295 .28666 .52607 .28255 Metetra
.647 .735 .914 r
.52607 .28255 .5295 .28666 .53583 .28481 .53242 .28059 Metetra
.641 .728 .911 r
.53242 .28059 .53583 .28481 .54218 .28306 .53878 .2787 Metetra
.634 .718 .908 r
.53878 .2787 .54218 .28306 .54855 .28145 .54515 .27692 Metetra
.626 .706 .903 r
.54515 .27692 .54855 .28145 .55494 .28 .55155 .27526 Metetra
.617 .692 .897 r
.55155 .27526 .55494 .28 .56135 .27873 .55796 .27374 Metetra
.607 .676 .89 r
.55796 .27374 .56135 .27873 .56778 .27765 .56439 .27239 Metetra
.597 .66 .882 r
.56439 .27239 .56778 .27765 .57423 .27675 .57085 .2712 Metetra
.588 .643 .873 r
.57085 .2712 .57423 .27675 .5807 .27597 .57732 .27017 Metetra
.582 .63 .865 r
.57732 .27017 .5807 .27597 .5872 .27526 .58382 .26924 Metetra
.579 .621 .858 r
.58382 .26924 .5872 .27526 .59372 .27451 .59034 .26837 Metetra
.581 .618 .853 r
.59034 .26837 .59372 .27451 .60026 .2736 .59689 .26747 Metetra
.589 .622 .853 r
.59689 .26747 .60026 .2736 .60681 .2724 .60344 .26641 Metetra
.603 .635 .856 r
.60344 .26641 .60681 .2724 .61336 .27081 .61002 .26511 Metetra
.622 .656 .862 r
.61002 .26511 .61336 .27081 .61993 .26878 .6166 .26347 Metetra
.644 .682 .871 r
.6166 .26347 .61993 .26878 .62649 .26631 .62319 .26143 Metetra
.667 .712 .881 r
.62319 .26143 .62649 .26631 .63306 .26347 .62978 .259 Metetra
.688 .74 .891 r
.62978 .259 .63306 .26347 .63963 .26037 .63637 .25622 Metetra
.703 .763 .899 r
.63637 .25622 .63963 .26037 .64621 .25716 .64297 .2532 Metetra
.71 .776 .904 r
.64297 .2532 .64621 .25716 .65281 .254 .64958 .25007 Metetra
.71 .778 .906 r
.64958 .25007 .65281 .254 .65942 .25098 .6562 .24694 Metetra
.702 .771 .905 r
.6562 .24694 .65942 .25098 .66605 .24816 .66284 .24393 Metetra
.691 .757 .902 r
.66284 .24393 .66605 .24816 .67271 .24556 .6695 .2411 Metetra
.679 .741 .897 r
.6695 .2411 .67271 .24556 .67939 .24312 .67618 .23846 Metetra
.669 .727 .893 r
.67618 .23846 .67939 .24312 .68609 .24076 .68288 .23597 Metetra
.663 .719 .89 r
.68288 .23597 .68609 .24076 .69281 .23842 .68961 .23359 Metetra
.661 .716 .889 r
.68961 .23359 .69281 .23842 .69954 .23604 .69635 .23123 Metetra
.662 .719 .891 r
.69635 .23123 .69954 .23604 .70628 .23357 .70311 .22885 Metetra
.666 .725 .893 r
.70311 .22885 .70628 .23357 .71304 .23101 .70988 .2264 Metetra
.671 .733 .897 r
.70988 .2264 .71304 .23101 .7198 .22838 .71667 .22387 Metetra
.675 .74 .9 r
.71667 .22387 .7198 .22838 .72658 .22572 .72346 .22127 Metetra
.677 .745 .902 r
.72346 .22127 .72658 .22572 .73337 .22305 .73027 .21863 Metetra
.678 .747 .903 r
.73027 .21863 .73337 .22305 .74018 .22039 .73709 .21596 Metetra
.677 .747 .904 r
.73709 .21596 .74018 .22039 .74701 .21777 .74392 .21331 Metetra
.676 .746 .903 r
.74392 .21331 .74701 .21777 .75385 .21517 .75078 .21067 Metetra
.674 .744 .903 r
.75078 .21067 .75385 .21517 .76071 .21259 .75765 .20806 Metetra
.672 .742 .903 r
.75765 .20806 .76071 .21259 .76759 .21003 .76454 .20547 Metetra
.671 .741 .902 r
.76454 .20547 .76759 .21003 .77449 .20747 .77145 .2029 Metetra
.671 .74 .902 r
.77145 .2029 .77449 .20747 .7814 .2049 .77837 .20033 Metetra
.671 .741 .903 r
.77837 .20033 .7814 .2049 .78833 .20232 .78531 .19775 Metetra
.671 .741 .903 r
.78531 .19775 .78833 .20232 .79527 .19974 .79227 .19517 Metetra
.671 .742 .904 r
.79227 .19517 .79527 .19974 .80223 .19715 .79924 .19258 Metetra
.671 .743 .904 r
.79924 .19258 .80223 .19715 .80921 .19455 .80623 .18999 Metetra
.656 .741 .912 r
.18284 .40248 .18675 .4061 .19233 .40423 .18843 .4006 Metetra
.656 .741 .912 r
.18843 .4006 .19233 .40423 .19792 .40236 .19403 .39874 Metetra
.655 .741 .913 r
.19403 .39874 .19792 .40236 .20353 .40049 .19964 .39688 Metetra
.654 .742 .914 r
.19964 .39688 .20353 .40049 .20915 .39864 .20526 .39504 Metetra
.653 .742 .915 r
.20526 .39504 .20915 .39864 .21477 .3968 .2109 .39319 Metetra
.653 .743 .915 r
.2109 .39319 .21477 .3968 .22041 .39497 .21654 .39135 Metetra
.654 .743 .915 r
.21654 .39135 .22041 .39497 .22607 .39314 .2222 .38948 Metetra
.656 .741 .913 r
.2222 .38948 .22607 .39314 .23173 .3913 .22788 .38759 Metetra
.657 .74 .911 r
.22788 .38759 .23173 .3913 .23741 .38943 .23357 .38568 Metetra
.658 .738 .909 r
.23357 .38568 .23741 .38943 .24311 .38753 .23928 .38375 Metetra
.656 .736 .908 r
.23928 .38375 .24311 .38753 .24882 .38561 .24499 .38184 Metetra
.652 .736 .911 r
.24499 .38184 .24882 .38561 .25454 .38368 .25072 .37998 Metetra
.646 .738 .916 r
.25072 .37998 .25454 .38368 .26027 .3818 .25645 .3782 Metetra
.638 .743 .924 r
.25645 .3782 .26027 .3818 .26601 .37999 .26218 .37652 Metetra
.631 .749 .932 r
.26218 .37652 .26601 .37999 .27175 .3783 .26792 .37492 Metetra
.629 .754 .937 r
.26792 .37492 .27175 .3783 .2775 .3767 .27368 .37333 Metetra
.635 .757 .936 r
.27368 .37333 .2775 .3767 .28326 .37516 .27945 .37167 Metetra
.648 .753 .926 r
.27945 .37167 .28326 .37516 .28904 .37358 .28525 .36983 Metetra
.664 .743 .91 r
.28525 .36983 .28904 .37358 .29484 .37185 .29108 .36777 Metetra
.674 .729 .891 r
.29108 .36777 .29484 .37185 .30067 .36988 .29694 .36552 Metetra
.676 .716 .879 r
.29694 .36552 .30067 .36988 .30653 .36767 .30282 .36319 Metetra
.668 .708 .877 r
.30282 .36319 .30653 .36767 .31241 .36532 .30869 .36098 Metetra
.646 .709 .893 r
.30869 .36098 .31241 .36532 .3183 .36301 .31456 .35916 Metetra
.602 .72 .928 r
.31456 .35916 .3183 .36301 .32418 .36102 .3204 .35792 Metetra
.511 .735 .975 r
.3204 .35792 .32418 .36102 .33004 .35961 .32621 .35738 Metetra
.345 .719 .985 r
.32621 .35738 .33004 .35961 .33587 .35895 .33201 .35747 Metetra
.152 .651 .911 r
.33201 .35747 .33587 .35895 .34168 .35903 .3378 .35794 Metetra
.081 .619 .855 r
.3378 .35794 .34168 .35903 .34747 .35965 .34361 .35842 Metetra
.211 .702 .923 r
.34361 .35842 .34747 .35965 .35329 .36042 .34948 .35847 Metetra
.471 .799 .999 r
.34948 .35847 .35329 .36042 .35914 .36086 .3554 .35767 Metetra
.646 .778 .944 r
.3554 .35767 .35914 .36086 .36505 .36049 .3614 .35577 Metetra
.706 .714 .855 r
.3614 .35577 .36505 .36049 .37104 .35899 .36748 .35271 Metetra
.722 .664 .793 r
.36748 .35271 .37104 .35899 .37711 .35621 .37361 .34862 Metetra
.723 .632 .757 r
.37361 .34862 .37711 .35621 .38324 .35225 .37978 .34381 Metetra
.72 .615 .739 r
.37978 .34381 .38324 .35225 .38941 .3474 .38597 .33864 Metetra
.716 .607 .734 r
.38597 .33864 .38941 .3474 .39561 .34207 .39216 .33348 Metetra
.711 .608 .739 r
.39216 .33348 .39561 .34207 .40181 .33666 .39834 .32861 Metetra
.706 .616 .753 r
.39834 .32861 .40181 .33666 .408 .33151 .40451 .3242 Metetra
.701 .63 .774 r
.40451 .3242 .408 .33151 .41418 .32683 .41067 .32033 Metetra
.696 .649 .799 r
.41067 .32033 .41418 .32683 .42034 .32271 .41681 .31694 Metetra
.689 .67 .826 r
.41681 .31694 .42034 .32271 .42649 .31915 .42295 .31397 Metetra
.683 .69 .851 r
.42295 .31397 .42649 .31915 .43264 .31606 .42909 .3113 Metetra
.676 .707 .87 r
.42909 .3113 .43264 .31606 .43878 .31332 .43523 .30883 Metetra
.672 .718 .884 r
.43523 .30883 .43878 .31332 .44494 .31082 .44139 .30648 Metetra
.668 .725 .892 r
.44139 .30648 .44494 .31082 .4511 .30847 .44756 .30421 Metetra
.666 .729 .896 r
.44756 .30421 .4511 .30847 .45727 .3062 .45374 .30197 Metetra
.665 .731 .899 r
.45374 .30197 .45727 .3062 .46345 .30398 .45993 .29975 Metetra
.664 .731 .9 r
.45993 .29975 .46345 .30398 .46965 .30177 .46614 .29754 Metetra
.663 .731 .9 r
.46614 .29754 .46965 .30177 .47586 .29958 .47236 .29534 Metetra
.663 .731 .9 r
.47236 .29534 .47586 .29958 .48209 .2974 .47859 .29315 Metetra
.662 .731 .9 r
.47859 .29315 .48209 .2974 .48833 .29522 .48484 .29096 Metetra
.661 .73 .901 r
.48484 .29096 .48833 .29522 .49458 .29305 .4911 .28878 Metetra
.66 .73 .901 r
.4911 .28878 .49458 .29305 .50085 .2909 .49738 .2866 Metetra
.659 .729 .901 r
.49738 .2866 .50085 .2909 .50714 .28877 .50367 .28444 Metetra
.658 .727 .9 r
.50367 .28444 .50714 .28877 .51343 .28666 .50998 .2823 Metetra
.656 .725 .9 r
.50998 .2823 .51343 .28666 .51975 .28458 .5163 .28018 Metetra
.654 .722 .899 r
.5163 .28018 .51975 .28458 .52607 .28255 .52264 .27809 Metetra
.651 .719 .898 r
.52264 .27809 .52607 .28255 .53242 .28059 .52899 .27605 Metetra
.647 .714 .897 r
.52899 .27605 .53242 .28059 .53878 .2787 .53536 .27406 Metetra
.642 .707 .895 r
.53536 .27406 .53878 .2787 .54515 .27692 .54174 .27216 Metetra
.635 .699 .892 r
.54174 .27216 .54515 .27692 .55155 .27526 .54814 .27034 Metetra
.628 .689 .888 r
.54814 .27034 .55155 .27526 .55796 .27374 .55456 .26865 Metetra
.619 .678 .884 r
.55456 .26865 .55796 .27374 .56439 .27239 .561 .26709 Metetra
.61 .665 .878 r
.561 .26709 .56439 .27239 .57085 .2712 .56746 .26568 Metetra
.601 .651 .872 r
.56746 .26568 .57085 .2712 .57732 .27017 .57394 .26442 Metetra
.593 .639 .866 r
.57394 .26442 .57732 .27017 .58382 .26924 .58044 .2633 Metetra
.587 .628 .86 r
.58044 .2633 .58382 .26924 .59034 .26837 .58696 .26228 Metetra
.584 .622 .855 r
.58696 .26228 .59034 .26837 .59689 .26747 .5935 .26131 Metetra
.586 .621 .853 r
.5935 .26131 .59689 .26747 .60344 .26641 .60007 .26031 Metetra
.593 .626 .854 r
.60007 .26031 .60344 .26641 .61002 .26511 .60665 .25917 Metetra
.605 .639 .858 r
.60665 .25917 .61002 .26511 .6166 .26347 .61325 .25782 Metetra
.622 .659 .865 r
.61325 .25782 .6166 .26347 .62319 .26143 .61986 .25615 Metetra
.643 .684 .874 r
.61986 .25615 .62319 .26143 .62978 .259 .62647 .25413 Metetra
.664 .713 .884 r
.62647 .25413 .62978 .259 .63637 .25622 .63309 .25174 Metetra
.684 .74 .893 r
.63309 .25174 .63637 .25622 .64297 .2532 .63971 .24903 Metetra
.698 .761 .901 r
.63971 .24903 .64297 .2532 .64958 .25007 .64634 .24608 Metetra
.706 .775 .905 r
.64634 .24608 .64958 .25007 .6562 .24694 .65297 .243 Metetra
.707 .778 .907 r
.65297 .243 .6562 .24694 .66284 .24393 .65962 .23991 Metetra
.702 .772 .907 r
.65962 .23991 .66284 .24393 .6695 .2411 .66628 .2369 Metetra
.692 .76 .904 r
.66628 .2369 .6695 .2411 .67618 .23846 .67296 .23405 Metetra
.681 .746 .9 r
.67296 .23405 .67618 .23846 .68288 .23597 .67967 .23137 Metetra
.671 .732 .896 r
.67967 .23137 .68288 .23597 .68961 .23359 .6864 .22884 Metetra
.665 .723 .893 r
.6864 .22884 .68961 .23359 .69635 .23123 .69315 .22641 Metetra
.662 .719 .891 r
.69315 .22641 .69635 .23123 .70311 .22885 .69992 .22404 Metetra
.662 .72 .892 r
.69992 .22404 .70311 .22885 .70988 .2264 .70671 .22165 Metetra
.665 .725 .894 r
.70671 .22165 .70988 .2264 .71667 .22387 .71351 .21921 Metetra
.669 .731 .897 r
.71351 .21921 .71667 .22387 .72346 .22127 .72032 .2167 Metetra
.672 .738 .9 r
.72032 .2167 .72346 .22127 .73027 .21863 .72714 .21413 Metetra
.675 .743 .902 r
.72714 .21413 .73027 .21863 .73709 .21596 .73398 .2115 Metetra
.677 .746 .903 r
.73398 .2115 .73709 .21596 .74392 .21331 .74083 .20885 Metetra
.677 .747 .904 r
.74083 .20885 .74392 .21331 .75078 .21067 .74769 .20619 Metetra
.675 .746 .904 r
.74769 .20619 .75078 .21067 .75765 .20806 .75457 .20355 Metetra
.674 .744 .904 r
.75457 .20355 .75765 .20806 .76454 .20547 .76147 .20093 Metetra
.672 .743 .903 r
.76147 .20093 .76454 .20547 .77145 .2029 .76839 .19833 Metetra
.671 .741 .903 r
.76839 .19833 .77145 .2029 .77837 .20033 .77533 .19574 Metetra
.67 .741 .903 r
.77533 .19574 .77837 .20033 .78531 .19775 .78228 .19316 Metetra
.67 .741 .903 r
.78228 .19316 .78531 .19775 .79227 .19517 .78925 .19057 Metetra
.67 .741 .904 r
.78925 .19057 .79227 .19517 .79924 .19258 .79623 .18799 Metetra
.67 .742 .904 r
.79623 .18799 .79924 .19258 .80623 .18999 .80324 .18539 Metetra
.656 .741 .913 r
.17891 .39885 .18284 .40248 .18843 .4006 .18451 .39698 Metetra
.655 .741 .913 r
.18451 .39698 .18843 .4006 .19403 .39874 .19011 .39512 Metetra
.654 .742 .914 r
.19011 .39512 .19403 .39874 .19964 .39688 .19573 .39327 Metetra
.654 .742 .915 r
.19573 .39327 .19964 .39688 .20526 .39504 .20136 .39142 Metetra
.654 .743 .915 r
.20136 .39142 .20526 .39504 .2109 .39319 .207 .38955 Metetra
.655 .742 .914 r
.207 .38955 .2109 .39319 .21654 .39135 .21266 .38767 Metetra
.657 .741 .912 r
.21266 .38767 .21654 .39135 .2222 .38948 .21833 .38576 Metetra
.658 .739 .91 r
.21833 .38576 .2222 .38948 .22788 .38759 .22402 .38384 Metetra
.657 .737 .909 r
.22402 .38384 .22788 .38759 .23357 .38568 .22972 .38191 Metetra
.655 .737 .91 r
.22972 .38191 .23357 .38568 .23928 .38375 .23543 .38001 Metetra
.651 .737 .913 r
.23543 .38001 .23928 .38375 .24499 .38184 .24114 .37817 Metetra
.644 .74 .919 r
.24114 .37817 .24499 .38184 .25072 .37998 .24686 .37642 Metetra
.637 .745 .926 r
.24686 .37642 .25072 .37998 .25645 .3782 .25259 .37474 Metetra
.633 .75 .933 r
.25259 .37474 .25645 .3782 .26218 .37652 .25833 .37312 Metetra
.634 .754 .935 r
.25833 .37312 .26218 .37652 .26792 .37492 .26408 .37147 Metetra
.642 .754 .931 r
.26408 .37147 .26792 .37492 .27368 .37333 .26985 .36972 Metetra
.655 .749 .919 r
.26985 .36972 .27368 .37333 .27945 .37167 .27566 .3678 Metetra
.667 .738 .903 r
.27566 .3678 .27945 .37167 .28525 .36983 .28149 .36568 Metetra
.674 .726 .888 r
.28149 .36568 .28525 .36983 .29108 .36777 .28734 .36341 Metetra
.673 .715 .88 r
.28734 .36341 .29108 .36777 .29694 .36552 .2932 .36113 Metetra
.662 .711 .884 r
.2932 .36113 .29694 .36552 .30282 .36319 .29907 .35903 Metetra
.637 .716 .904 r
.29907 .35903 .30282 .36319 .30869 .36098 .30492 .35735 Metetra
.588 .729 .941 r
.30492 .35735 .30869 .36098 .31456 .35916 .31074 .35623 Metetra
.495 .741 .982 r
.31074 .35623 .31456 .35916 .3204 .35792 .31654 .35574 Metetra
.349 .725 .986 r
.31654 .35574 .3204 .35792 .32621 .35738 .32233 .35577 Metetra
.214 .684 .94 r
.32233 .35577 .32621 .35738 .33201 .35747 .32812 .35606 Metetra
.203 .688 .928 r
.32812 .35606 .33201 .35747 .3378 .35794 .33394 .35626 Metetra
.351 .759 .982 r
.33394 .35626 .3378 .35794 .34361 .35842 .3398 .35597 Metetra
.549 .796 .99 r
.3398 .35597 .34361 .35842 .34948 .35847 .34574 .35485 Metetra
.665 .758 .92 r
.34574 .35485 .34948 .35847 .3554 .35767 .35174 .35271 Metetra
.708 .705 .845 r
.35174 .35271 .3554 .35767 .3614 .35577 .35782 .34954 Metetra
.721 .665 .794 r
.35782 .34954 .3614 .35577 .36748 .35271 .36395 .34548 Metetra
.724 .641 .765 r
.36395 .34548 .36748 .35271 .37361 .34862 .37011 .34082 Metetra
.723 .628 .751 r
.37011 .34082 .37361 .34862 .37978 .34381 .37629 .33587 Metetra
.721 .624 .75 r
.37629 .33587 .37978 .34381 .38597 .33864 .38248 .33097 Metetra
.717 .628 .757 r
.38248 .33097 .38597 .33864 .39216 .33348 .38865 .32634 Metetra
.713 .639 .773 r
.38865 .32634 .39216 .33348 .39834 .32861 .39481 .32213 Metetra
.708 .654 .794 r
.39481 .32213 .39834 .32861 .40451 .3242 .40096 .31838 Metetra
.701 .673 .819 r
.40096 .31838 .40451 .3242 .41067 .32033 .4071 .31508 Metetra
.694 .691 .844 r
.4071 .31508 .41067 .32033 .41681 .31694 .41323 .31214 Metetra
.686 .708 .865 r
.41323 .31214 .41681 .31694 .42295 .31397 .41937 .30948 Metetra
.678 .721 .881 r
.41937 .30948 .42295 .31397 .42909 .3113 .42551 .30701 Metetra
.673 .729 .892 r
.42551 .30701 .42909 .3113 .43523 .30883 .43166 .30466 Metetra
.669 .735 .899 r
.43166 .30466 .43523 .30883 .44139 .30648 .43782 .30238 Metetra
.667 .738 .903 r
.43782 .30238 .44139 .30648 .44756 .30421 .444 .30013 Metetra
.666 .74 .905 r
.444 .30013 .44756 .30421 .45374 .30197 .45019 .29791 Metetra
.665 .74 .906 r
.45019 .29791 .45374 .30197 .45993 .29975 .45639 .29569 Metetra
.664 .741 .907 r
.45639 .29569 .45993 .29975 .46614 .29754 .4626 .29348 Metetra
.664 .741 .907 r
.4626 .29348 .46614 .29754 .47236 .29534 .46883 .29127 Metetra
.663 .741 .908 r
.46883 .29127 .47236 .29534 .47859 .29315 .47508 .28906 Metetra
.663 .74 .908 r
.47508 .28906 .47859 .29315 .48484 .29096 .48134 .28686 Metetra
.662 .74 .908 r
.48134 .28686 .48484 .29096 .4911 .28878 .48761 .28466 Metetra
.662 .739 .908 r
.48761 .28466 .4911 .28878 .49738 .2866 .4939 .28246 Metetra
.661 .738 .907 r
.4939 .28246 .49738 .2866 .50367 .28444 .5002 .28028 Metetra
.66 .737 .907 r
.5002 .28028 .50367 .28444 .50998 .2823 .50651 .2781 Metetra
.658 .736 .907 r
.50651 .2781 .50998 .2823 .5163 .28018 .51284 .27595 Metetra
.656 .733 .906 r
.51284 .27595 .5163 .28018 .52264 .27809 .51919 .27381 Metetra
.654 .731 .906 r
.51919 .27381 .52264 .27809 .52899 .27605 .52555 .27171 Metetra
.651 .727 .905 r
.52555 .27171 .52899 .27605 .53536 .27406 .53193 .26965 Metetra
.647 .722 .903 r
.53193 .26965 .53536 .27406 .54174 .27216 .53832 .26765 Metetra
.642 .716 .901 r
.53832 .26765 .54174 .27216 .54814 .27034 .54473 .26573 Metetra
.636 .708 .899 r
.54473 .26573 .54814 .27034 .55456 .26865 .55115 .26389 Metetra
.629 .699 .895 r
.55115 .26389 .55456 .26865 .561 .26709 .5576 .26216 Metetra
.621 .688 .891 r
.5576 .26216 .561 .26709 .56746 .26568 .56406 .26056 Metetra
.612 .675 .886 r
.56406 .26056 .56746 .26568 .57394 .26442 .57054 .2591 Metetra
.604 .663 .88 r
.57054 .2591 .57394 .26442 .58044 .2633 .57705 .25777 Metetra
.596 .651 .874 r
.57705 .25777 .58044 .2633 .58696 .26228 .58357 .25657 Metetra
.591 .641 .869 r
.58357 .25657 .58696 .26228 .5935 .26131 .59012 .25546 Metetra
.589 .634 .864 r
.59012 .25546 .5935 .26131 .60007 .26031 .59669 .25439 Metetra
.591 .633 .862 r
.59669 .25439 .60007 .26031 .60665 .25917 .60328 .25328 Metetra
.597 .638 .862 r
.60328 .25328 .60665 .25917 .61325 .25782 .60989 .25205 Metetra
.609 .649 .865 r
.60989 .25205 .61325 .25782 .61986 .25615 .61651 .25062 Metetra
.624 .666 .87 r
.61651 .25062 .61986 .25615 .62647 .25413 .62314 .24891 Metetra
.643 .689 .878 r
.62314 .24891 .62647 .25413 .63309 .25174 .62978 .24688 Metetra
.663 .714 .886 r
.62978 .24688 .63309 .25174 .63971 .24903 .63642 .24451 Metetra
.681 .738 .894 r
.63642 .24451 .63971 .24903 .64634 .24608 .64307 .24184 Metetra
.694 .758 .901 r
.64307 .24184 .64634 .24608 .65297 .243 .64972 .23894 Metetra
.703 .771 .905 r
.64972 .23894 .65297 .243 .65962 .23991 .65639 .23591 Metetra
.704 .776 .908 r
.65639 .23591 .65962 .23991 .66628 .2369 .66306 .23285 Metetra
.7 .772 .908 r
.66306 .23285 .66628 .2369 .67296 .23405 .66975 .22985 Metetra
.692 .762 .905 r
.66975 .22985 .67296 .23405 .67967 .23137 .67646 .22699 Metetra
.682 .749 .902 r
.67646 .22699 .67967 .23137 .6864 .22884 .68319 .22427 Metetra
.673 .737 .898 r
.68319 .22427 .6864 .22884 .69315 .22641 .68994 .2217 Metetra
.666 .727 .895 r
.68994 .2217 .69315 .22641 .69992 .22404 .69672 .21924 Metetra
.662 .722 .893 r
.69672 .21924 .69992 .22404 .70671 .22165 .70352 .21684 Metetra
.662 .721 .893 r
.70352 .21684 .70671 .22165 .71351 .21921 .71033 .21444 Metetra
.664 .725 .895 r
.71033 .21444 .71351 .21921 .72032 .2167 .71716 .21201 Metetra
.667 .73 .897 r
.71716 .21201 .72032 .2167 .72714 .21413 .724 .20951 Metetra
.67 .736 .9 r
.724 .20951 .72714 .21413 .73398 .2115 .73085 .20695 Metetra
.673 .742 .902 r
.73085 .20695 .73398 .2115 .74083 .20885 .73771 .20434 Metetra
.675 .745 .903 r
.73771 .20434 .74083 .20885 .74769 .20619 .74459 .2017 Metetra
.676 .746 .904 r
.74459 .2017 .74769 .20619 .75457 .20355 .75149 .19905 Metetra
.675 .746 .904 r
.75149 .19905 .75457 .20355 .76147 .20093 .7584 .1964 Metetra
.674 .745 .904 r
.7584 .1964 .76147 .20093 .76839 .19833 .76532 .19376 Metetra
.672 .743 .904 r
.76532 .19376 .76839 .19833 .77533 .19574 .77227 .19115 Metetra
.671 .742 .903 r
.77227 .19115 .77533 .19574 .78228 .19316 .77923 .18854 Metetra
.67 .741 .903 r
.77923 .18854 .78228 .19316 .78925 .19057 .78621 .18595 Metetra
.67 .741 .903 r
.78621 .18595 .78925 .19057 .79623 .18799 .79321 .18336 Metetra
.67 .741 .904 r
.79321 .18336 .79623 .18799 .80324 .18539 .80023 .18076 Metetra
.655 .742 .913 r
.17497 .39523 .17891 .39885 .18451 .39698 .18057 .39336 Metetra
.654 .742 .914 r
.18057 .39336 .18451 .39698 .19011 .39512 .18618 .3915 Metetra
.654 .742 .914 r
.18618 .3915 .19011 .39512 .19573 .39327 .19181 .38963 Metetra
.655 .742 .914 r
.19181 .38963 .19573 .39327 .20136 .39142 .19745 .38775 Metetra
.656 .741 .913 r
.19745 .38775 .20136 .39142 .207 .38955 .2031 .38586 Metetra
.657 .74 .911 r
.2031 .38586 .207 .38955 .21266 .38767 .20877 .38394 Metetra
.658 .739 .91 r
.20877 .38394 .21266 .38767 .21833 .38576 .21445 .382 Metetra
.657 .738 .909 r
.21445 .382 .21833 .38576 .22402 .38384 .22014 .38008 Metetra
.654 .737 .911 r
.22014 .38008 .22402 .38384 .22972 .38191 .22584 .3782 Metetra
.649 .739 .915 r
.22584 .3782 .22972 .38191 .23543 .38001 .23155 .37638 Metetra
.643 .742 .921 r
.23155 .37638 .23543 .38001 .24114 .37817 .23726 .37464 Metetra
.638 .747 .928 r
.23726 .37464 .24114 .37817 .24686 .37642 .24298 .37295 Metetra
.635 .751 .932 r
.24298 .37295 .24686 .37642 .25259 .37474 .24871 .3713 Metetra
.638 .753 .932 r
.24871 .3713 .25259 .37474 .25833 .37312 .25447 .36959 Metetra
.648 .752 .925 r
.25447 .36959 .25833 .37312 .26408 .37147 .26024 .36776 Metetra
.659 .745 .913 r
.26024 .36776 .26408 .37147 .26985 .36972 .26604 .36577 Metetra
.669 .734 .899 r
.26604 .36577 .26985 .36972 .27566 .3678 .27187 .3636 Metetra
.674 .723 .887 r
.27187 .3636 .27566 .3678 .28149 .36568 .27772 .36133 Metetra
.67 .716 .883 r
.27772 .36133 .28149 .36568 .28734 .36341 .28357 .35912 Metetra
.656 .714 .891 r
.28357 .35912 .28734 .36341 .2932 .36113 .28942 .35714 Metetra
.627 .722 .915 r
.28942 .35714 .2932 .36113 .29907 .35903 .29526 .35558 Metetra
.574 .736 .952 r
.29526 .35558 .29907 .35903 .30492 .35735 .30106 .35456 Metetra
.483 .746 .987 r
.30106 .35456 .30492 .35735 .31074 .35623 .30685 .35409 Metetra
.359 .733 .988 r
.30685 .35409 .31074 .35623 .31654 .35574 .31263 .35404 Metetra
.271 .713 .962 r
.31263 .35404 .31654 .35574 .32233 .35577 .31842 .35413 Metetra
.302 .735 .969 r
.31842 .35413 .32233 .35577 .32812 .35606 .32425 .35404 Metetra
.448 .785 .998 r
.32425 .35404 .32812 .35606 .33394 .35626 .33012 .35342 Metetra
.598 .787 .971 r
.33012 .35342 .33394 .35626 .3398 .35597 .33606 .35199 Metetra
.678 .742 .899 r
.33606 .35199 .3398 .35597 .34574 .35485 .34208 .34962 Metetra
.709 .695 .835 r
.34208 .34962 .34574 .35485 .35174 .35271 .34815 .34633 Metetra
.719 .66 .791 r
.34815 .34633 .35174 .35271 .35782 .34954 .35428 .34228 Metetra
.72 .639 .766 r
.35428 .34228 .35782 .34954 .36395 .34548 .36044 .33774 Metetra
.719 .628 .755 r
.36044 .33774 .36395 .34548 .37011 .34082 .36661 .33301 Metetra
.716 .625 .755 r
.36661 .33301 .37011 .34082 .37629 .33587 .37278 .32835 Metetra
.713 .63 .763 r
.37278 .32835 .37629 .33587 .38248 .33097 .37894 .32396 Metetra
.709 .641 .779 r
.37894 .32396 .38248 .33097 .38865 .32634 .38509 .31997 Metetra
.704 .656 .8 r
.38509 .31997 .38865 .32634 .39481 .32213 .39123 .31639 Metetra
.698 .675 .824 r
.39123 .31639 .39481 .32213 .40096 .31838 .39737 .3132 Metetra
.691 .693 .847 r
.39737 .3132 .40096 .31838 .4071 .31508 .4035 .31033 Metetra
.684 .71 .868 r
.4035 .31033 .4071 .31508 .41323 .31214 .40963 .3077 Metetra
.678 .723 .883 r
.40963 .3077 .41323 .31214 .41937 .30948 .41576 .30524 Metetra
.673 .732 .894 r
.41576 .30524 .41937 .30948 .42551 .30701 .42191 .30288 Metetra
.67 .737 .901 r
.42191 .30288 .42551 .30701 .43166 .30466 .42807 .30059 Metetra
.667 .74 .905 r
.42807 .30059 .43166 .30466 .43782 .30238 .43424 .29834 Metetra
.666 .742 .907 r
.43424 .29834 .43782 .30238 .444 .30013 .44042 .29611 Metetra
.665 .743 .908 r
.44042 .29611 .444 .30013 .45019 .29791 .44662 .29388 Metetra
.665 .743 .909 r
.44662 .29388 .45019 .29791 .45639 .29569 .45283 .29166 Metetra
.664 .743 .909 r
.45283 .29166 .45639 .29569 .4626 .29348 .45905 .28944 Metetra
.664 .744 .909 r
.45905 .28944 .4626 .29348 .46883 .29127 .46529 .28723 Metetra
.663 .744 .91 r
.46529 .28723 .46883 .29127 .47508 .28906 .47155 .28501 Metetra
.663 .743 .91 r
.47155 .28501 .47508 .28906 .48134 .28686 .47781 .2828 Metetra
.663 .743 .91 r
.47781 .2828 .48134 .28686 .48761 .28466 .4841 .28058 Metetra
.662 .743 .91 r
.4841 .28058 .48761 .28466 .4939 .28246 .49039 .27837 Metetra
.662 .742 .91 r
.49039 .27837 .4939 .28246 .5002 .28028 .4967 .27616 Metetra
.661 .741 .91 r
.4967 .27616 .5002 .28028 .50651 .2781 .50303 .27396 Metetra
.66 .74 .909 r
.50303 .27396 .50651 .2781 .51284 .27595 .50937 .27177 Metetra
.658 .738 .909 r
.50937 .27177 .51284 .27595 .51919 .27381 .51572 .2696 Metetra
.657 .736 .908 r
.51572 .2696 .51919 .27381 .52555 .27171 .5221 .26745 Metetra
.654 .733 .907 r
.5221 .26745 .52555 .27171 .53193 .26965 .52848 .26533 Metetra
.651 .729 .906 r
.52848 .26533 .53193 .26965 .53832 .26765 .53488 .26325 Metetra
.648 .724 .905 r
.53488 .26325 .53832 .26765 .54473 .26573 .5413 .26123 Metetra
.643 .718 .902 r
.5413 .26123 .54473 .26573 .55115 .26389 .54773 .25927 Metetra
.637 .71 .9 r
.54773 .25927 .55115 .26389 .5576 .26216 .55418 .25741 Metetra
.63 .701 .896 r
.55418 .25741 .5576 .26216 .56406 .26056 .56065 .25564 Metetra
.623 .69 .892 r
.56065 .25564 .56406 .26056 .57054 .2591 .56714 .25399 Metetra
.615 .678 .887 r
.56714 .25399 .57054 .2591 .57705 .25777 .57365 .25246 Metetra
.607 .666 .881 r
.57365 .25246 .57705 .25777 .58357 .25657 .58018 .25107 Metetra
.6 .655 .875 r
.58018 .25107 .58357 .25657 .59012 .25546 .58673 .24978 Metetra
.596 .646 .87 r
.58673 .24978 .59012 .25546 .59669 .25439 .5933 .24857 Metetra
.594 .64 .866 r
.5933 .24857 .59669 .25439 .60328 .25328 .59989 .2474 Metetra
.595 .638 .864 r
.59989 .2474 .60328 .25328 .60989 .25205 .60651 .2462 Metetra
.601 .643 .864 r
.60651 .2462 .60989 .25205 .61651 .25062 .61314 .2449 Metetra
.611 .653 .866 r
.61314 .2449 .61651 .25062 .62314 .24891 .61978 .2434 Metetra
.626 .669 .872 r
.61978 .2434 .62314 .24891 .62978 .24688 .62644 .24166 Metetra
.643 .69 .879 r
.62644 .24166 .62978 .24688 .63642 .24451 .63311 .23962 Metetra
.66 .713 .887 r
.63311 .23962 .63642 .24451 .64307 .24184 .63978 .23727 Metetra
.677 .736 .895 r
.63978 .23727 .64307 .24184 .64972 .23894 .64645 .23464 Metetra
.691 .755 .901 r
.64645 .23464 .64972 .23894 .65639 .23591 .65313 .23179 Metetra
.699 .768 .906 r
.65313 .23179 .65639 .23591 .66306 .23285 .65982 .22881 Metetra
.701 .774 .908 r
.65982 .22881 .66306 .23285 .66975 .22985 .66652 .22578 Metetra
.699 .772 .908 r
.66652 .22578 .66975 .22985 .67646 .22699 .67324 .22279 Metetra
.692 .764 .907 r
.67324 .22279 .67646 .22699 .68319 .22427 .67998 .21991 Metetra
.683 .752 .904 r
.67998 .21991 .68319 .22427 .68994 .2217 .68673 .21717 Metetra
.674 .74 .9 r
.68673 .21717 .68994 .2217 .69672 .21924 .69351 .21457 Metetra
.667 .731 .897 r
.69351 .21457 .69672 .21924 .70352 .21684 .70032 .21207 Metetra
.663 .725 .895 r
.70032 .21207 .70352 .21684 .71033 .21444 .70714 .20964 Metetra
.662 .723 .895 r
.70714 .20964 .71033 .21444 .71716 .21201 .71398 .20722 Metetra
.663 .725 .895 r
.71398 .20722 .71716 .21201 .724 .20951 .72083 .20478 Metetra
.666 .73 .897 r
.72083 .20478 .724 .20951 .73085 .20695 .7277 .20229 Metetra
.669 .735 .9 r
.7277 .20229 .73085 .20695 .73771 .20434 .73458 .19975 Metetra
.672 .74 .902 r
.73458 .19975 .73771 .20434 .74459 .2017 .74148 .19715 Metetra
.674 .744 .903 r
.74148 .19715 .74459 .2017 .75149 .19905 .74838 .19452 Metetra
.674 .746 .904 r
.74838 .19452 .75149 .19905 .7584 .1964 .75531 .19186 Metetra
.674 .746 .905 r
.75531 .19186 .7584 .1964 .76532 .19376 .76225 .18921 Metetra
.673 .745 .905 r
.76225 .18921 .76532 .19376 .77227 .19115 .7692 .18656 Metetra
.672 .744 .904 r
.7692 .18656 .77227 .19115 .77923 .18854 .77618 .18393 Metetra
.671 .742 .904 r
.77618 .18393 .77923 .18854 .78621 .18595 .78317 .18132 Metetra
.67 .741 .904 r
.78317 .18132 .78621 .18595 .79321 .18336 .79018 .17871 Metetra
.669 .741 .904 r
.79018 .17871 .79321 .18336 .80023 .18076 .79721 .17611 Metetra
.655 .742 .914 r
.17101 .3916 .17497 .39523 .18057 .39336 .17662 .38973 Metetra
.655 .742 .914 r
.17662 .38973 .18057 .39336 .18618 .3915 .18224 .38785 Metetra
.656 .742 .913 r
.18224 .38785 .18618 .3915 .19181 .38963 .18787 .38595 Metetra
.657 .741 .912 r
.18787 .38595 .19181 .38963 .19745 .38775 .19352 .38404 Metetra
.658 .74 .91 r
.19352 .38404 .19745 .38775 .2031 .38586 .19918 .38211 Metetra
.657 .738 .91 r
.19918 .38211 .2031 .38586 .20877 .38394 .20486 .38018 Metetra
.656 .738 .91 r
.20486 .38018 .20877 .38394 .21445 .382 .21054 .37827 Metetra
.653 .738 .912 r
.21054 .37827 .21445 .382 .22014 .38008 .21624 .3764 Metetra
.648 .74 .917 r
.21624 .3764 .22014 .38008 .22584 .3782 .22194 .37459 Metetra
.642 .744 .923 r
.22194 .37459 .22584 .3782 .23155 .37638 .22764 .37285 Metetra
.638 .748 .928 r
.22764 .37285 .23155 .37638 .23726 .37464 .23336 .37115 Metetra
.638 .751 .93 r
.23336 .37115 .23726 .37464 .24298 .37295 .23909 .36946 Metetra
.643 .752 .928 r
.23909 .36946 .24298 .37295 .24871 .3713 .24484 .36769 Metetra
.652 .749 .92 r
.24484 .36769 .24871 .3713 .25447 .36959 .25061 .36579 Metetra
.663 .741 .908 r
.25061 .36579 .25447 .36959 .26024 .36776 .25641 .36374 Metetra
.671 .731 .896 r
.25641 .36374 .26024 .36776 .26604 .36577 .26223 .36154 Metetra
.672 .722 .887 r
.26223 .36154 .26604 .36577 .27187 .3636 .26808 .3593 Metetra
.666 .717 .887 r
.26808 .3593 .27187 .3636 .27772 .36133 .27392 .35715 Metetra
.65 .718 .899 r
.27392 .35715 .27772 .36133 .28357 .35912 .27976 .35527 Metetra
.618 .727 .924 r
.27976 .35527 .28357 .35912 .28942 .35714 .28557 .35381 Metetra
.564 .741 .96 r
.28557 .35381 .28942 .35714 .29526 .35558 .29137 .35286 Metetra
.478 .749 .989 r
.29137 .35286 .29526 .35558 .30106 .35456 .29715 .35239 Metetra
.379 .742 .991 r
.29715 .35239 .30106 .35456 .30685 .35409 .30292 .35224 Metetra
.33 .737 .98 r
.30292 .35224 .30685 .35409 .31263 .35404 .30871 .35215 Metetra
.383 .763 .991 r
.30871 .35215 .31263 .35404 .31842 .35413 .31454 .35181 Metetra
.512 .791 .996 r
.31454 .35181 .31842 .35413 .32425 .35404 .32042 .35092 Metetra
.625 .777 .954 r
.32042 .35092 .32425 .35404 .33012 .35342 .32637 .34925 Metetra
.686 .735 .888 r
.32637 .34925 .33012 .35342 .33606 .35199 .33239 .34672 Metetra
.711 .694 .832 r
.33239 .34672 .33606 .35199 .34208 .34962 .33846 .34336 Metetra
.72 .664 .795 r
.33846 .34336 .34208 .34962 .34815 .34633 .34459 .33935 Metetra
.721 .646 .773 r
.34459 .33935 .34815 .34633 .35428 .34228 .35074 .33493 Metetra
.72 .637 .764 r
.35074 .33493 .35428 .34228 .36044 .33774 .3569 .33036 Metetra
.717 .635 .765 r
.3569 .33036 .36044 .33774 .36661 .33301 .36306 .32588 Metetra
.713 .639 .773 r
.36306 .32588 .36661 .33301 .37278 .32835 .36922 .32167 Metetra
.709 .649 .788 r
.36922 .32167 .37278 .32835 .37894 .32396 .37536 .31781 Metetra
.703 .663 .807 r
.37536 .31781 .37894 .32396 .38509 .31997 .3815 .31434 Metetra
.697 .678 .828 r
.3815 .31434 .38509 .31997 .39123 .31639 .38762 .31122 Metetra
.69 .694 .849 r
.38762 .31122 .39123 .31639 .39737 .3132 .39375 .30839 Metetra
.683 .707 .866 r
.39375 .30839 .39737 .3132 .4035 .31033 .39987 .30578 Metetra
.677 .718 .88 r
.39987 .30578 .4035 .31033 .40963 .3077 .406 .30332 Metetra
.672 .725 .889 r
.406 .30332 .40963 .3077 .41576 .30524 .41215 .30097 Metetra
.669 .73 .895 r
.41215 .30097 .41576 .30524 .42191 .30288 .4183 .29867 Metetra
.667 .733 .899 r
.4183 .29867 .42191 .30288 .42807 .30059 .42446 .29641 Metetra
.666 .735 .901 r
.42446 .29641 .42807 .30059 .43424 .29834 .43064 .29417 Metetra
.665 .735 .902 r
.43064 .29417 .43424 .29834 .44042 .29611 .43683 .29193 Metetra
.664 .736 .903 r
.43683 .29193 .44042 .29611 .44662 .29388 .44304 .28971 Metetra
.664 .736 .903 r
.44304 .28971 .44662 .29388 .45283 .29166 .44926 .28748 Metetra
.664 .736 .904 r
.44926 .28748 .45283 .29166 .45905 .28944 .45549 .28525 Metetra
.663 .736 .904 r
.45549 .28525 .45905 .28944 .46529 .28723 .46174 .28303 Metetra
.663 .736 .904 r
.46174 .28303 .46529 .28723 .47155 .28501 .468 .2808 Metetra
.663 .736 .904 r
.468 .2808 .47155 .28501 .47781 .2828 .47428 .27857 Metetra
.663 .736 .904 r
.47428 .27857 .47781 .2828 .4841 .28058 .48057 .27635 Metetra
.662 .735 .904 r
.48057 .27635 .4841 .28058 .49039 .27837 .48688 .27412 Metetra
.662 .735 .904 r
.48688 .27412 .49039 .27837 .4967 .27616 .4932 .2719 Metetra
.661 .734 .904 r
.4932 .2719 .4967 .27616 .50303 .27396 .49953 .26968 Metetra
.66 .734 .904 r
.49953 .26968 .50303 .27396 .50937 .27177 .50588 .26747 Metetra
.659 .732 .904 r
.50588 .26747 .50937 .27177 .51572 .2696 .51225 .26527 Metetra
.658 .731 .903 r
.51225 .26527 .51572 .2696 .5221 .26745 .51863 .26308 Metetra
.656 .729 .903 r
.51863 .26308 .5221 .26745 .52848 .26533 .52502 .26092 Metetra
.654 .727 .902 r
.52502 .26092 .52848 .26533 .53488 .26325 .53143 .25879 Metetra
.651 .723 .902 r
.53143 .25879 .53488 .26325 .5413 .26123 .53786 .2567 Metetra
.647 .719 .9 r
.53786 .2567 .5413 .26123 .54773 .25927 .5443 .25466 Metetra
.643 .713 .899 r
.5443 .25466 .54773 .25927 .55418 .25741 .55076 .25269 Metetra
.638 .707 .897 r
.55076 .25269 .55418 .25741 .56065 .25564 .55723 .2508 Metetra
.631 .698 .894 r
.55723 .2508 .56065 .25564 .56714 .25399 .56373 .249 Metetra
.624 .689 .89 r
.56373 .249 .56714 .25399 .57365 .25246 .57024 .24732 Metetra
.617 .679 .886 r
.57024 .24732 .57365 .25246 .58018 .25107 .57678 .24575 Metetra
.61 .668 .881 r
.57678 .24575 .58018 .25107 .58673 .24978 .58333 .24429 Metetra
.604 .658 .877 r
.58333 .24429 .58673 .24978 .5933 .24857 .58991 .24294 Metetra
.599 .65 .872 r
.58991 .24294 .5933 .24857 .59989 .2474 .5965 .24166 Metetra
.597 .645 .869 r
.5965 .24166 .59989 .2474 .60651 .2462 .60312 .24041 Metetra
.599 .645 .867 r
.60312 .24041 .60651 .2462 .61314 .2449 .60976 .23913 Metetra
.604 .649 .867 r
.60976 .23913 .61314 .2449 .61978 .2434 .61642 .23775 Metetra
.614 .658 .87 r
.61642 .23775 .61978 .2434 .62644 .24166 .62309 .2362 Metetra
.627 .673 .875 r
.62309 .2362 .62644 .24166 .63311 .23962 .62977 .23443 Metetra
.642 .692 .881 r
.62977 .23443 .63311 .23962 .63978 .23727 .63646 .23238 Metetra
.659 .714 .889 r
.63646 .23238 .63978 .23727 .64645 .23464 .64316 .23004 Metetra
.675 .735 .896 r
.64316 .23004 .64645 .23464 .65313 .23179 .64986 .22744 Metetra
.688 .753 .902 r
.64986 .22744 .65313 .23179 .65982 .22881 .65657 .22463 Metetra
.696 .766 .906 r
.65657 .22463 .65982 .22881 .66652 .22578 .66329 .22168 Metetra
.699 .772 .908 r
.66329 .22168 .66652 .22578 .67324 .22279 .67001 .21868 Metetra
.697 .771 .909 r
.67001 .21868 .67324 .22279 .67998 .21991 .67676 .21571 Metetra
.691 .765 .908 r
.67676 .21571 .67998 .21991 .68673 .21717 .68352 .21282 Metetra
.684 .754 .905 r
.68352 .21282 .68673 .21717 .69351 .21457 .6903 .21005 Metetra
.676 .743 .902 r
.6903 .21005 .69351 .21457 .70032 .21207 .69711 .20742 Metetra
.669 .734 .899 r
.69711 .20742 .70032 .21207 .70714 .20964 .70394 .20488 Metetra
.664 .728 .897 r
.70394 .20488 .70714 .20964 .71398 .20722 .71078 .20242 Metetra
.662 .725 .896 r
.71078 .20242 .71398 .20722 .72083 .20478 .71765 .19999 Metetra
.663 .726 .896 r
.71765 .19999 .72083 .20478 .7277 .20229 .72453 .19754 Metetra
.665 .729 .898 r
.72453 .19754 .7277 .20229 .73458 .19975 .73143 .19505 Metetra
.667 .734 .9 r
.73143 .19505 .73458 .19975 .74148 .19715 .73834 .19251 Metetra
.67 .739 .902 r
.73834 .19251 .74148 .19715 .74838 .19452 .74526 .18992 Metetra
.672 .743 .903 r
.74526 .18992 .74838 .19452 .75531 .19186 .7522 .18729 Metetra
.673 .745 .904 r
.7522 .18729 .75531 .19186 .76225 .18921 .75915 .18464 Metetra
.673 .746 .905 r
.75915 .18464 .76225 .18921 .7692 .18656 .76612 .18198 Metetra
.673 .745 .905 r
.76612 .18198 .7692 .18656 .77618 .18393 .77311 .17933 Metetra
.672 .744 .905 r
.77311 .17933 .77618 .18393 .78317 .18132 .78011 .17669 Metetra
.671 .743 .905 r
.78011 .17669 .78317 .18132 .79018 .17871 .78713 .17406 Metetra
.67 .742 .904 r
.78713 .17406 .79018 .17871 .79721 .17611 .79417 .17143 Metetra
.656 .742 .913 r
.16704 .38795 .17101 .3916 .17662 .38973 .17265 .38606 Metetra
.657 .741 .912 r
.17265 .38606 .17662 .38973 .18224 .38785 .17828 .38415 Metetra
.657 .741 .911 r
.17828 .38415 .18224 .38785 .18787 .38595 .18393 .38222 Metetra
.658 .739 .91 r
.18393 .38222 .18787 .38595 .19352 .38404 .18958 .38029 Metetra
.657 .738 .91 r
.18958 .38029 .19352 .38404 .19918 .38211 .19525 .37836 Metetra
.655 .738 .911 r
.19525 .37836 .19918 .38211 .20486 .38018 .20093 .37646 Metetra
.651 .739 .914 r
.20093 .37646 .20486 .38018 .21054 .37827 .20661 .3746 Metetra
.647 .742 .919 r
.20661 .3746 .21054 .37827 .21624 .3764 .21231 .3728 Metetra
.642 .745 .924 r
.21231 .3728 .21624 .3764 .22194 .37459 .21801 .37106 Metetra
.64 .749 .927 r
.21801 .37106 .22194 .37459 .22764 .37285 .22372 .36934 Metetra
.641 .751 .928 r
.22372 .36934 .22764 .37285 .23336 .37115 .22944 .3676 Metetra
.647 .75 .924 r
.22944 .3676 .23336 .37115 .23909 .36946 .23519 .36577 Metetra
.656 .746 .916 r
.23519 .36577 .23909 .36946 .24484 .36769 .24096 .36381 Metetra
.665 .738 .904 r
.24096 .36381 .24484 .36769 .25061 .36579 .24676 .36172 Metetra
.671 .729 .894 r
.24676 .36172 .25061 .36579 .25641 .36374 .25258 .35951 Metetra
.67 .722 .888 r
.25258 .35951 .25641 .36374 .26223 .36154 .25841 .3573 Metetra
.662 .719 .891 r
.25841 .3573 .26223 .36154 .26808 .3593 .26425 .35522 Metetra
.643 .723 .906 r
.26425 .35522 .26808 .3593 .27392 .35715 .27007 .35344 Metetra
.61 .733 .933 r
.27007 .35344 .27392 .35715 .27976 .35527 .27587 .35206 Metetra
.556 .746 .966 r
.27587 .35206 .27976 .35527 .28557 .35381 .28166 .35115 Metetra
.479 .754 .99 r
.28166 .35115 .28557 .35381 .29137 .35286 .28743 .35064 Metetra
.404 .751 .994 r
.28743 .35064 .29137 .35286 .29715 .35239 .2932 .35037 Metetra
.385 .756 .992 r
.2932 .35037 .29715 .35239 .30292 .35224 .29899 .35009 Metetra
.45 .778 .998 r
.29899 .35009 .30292 .35224 .30871 .35215 .30482 .34952 Metetra
.558 .788 .985 r
.30482 .34952 .30871 .35215 .31454 .35181 .31071 .34838 Metetra
.644 .764 .936 r
.31071 .34838 .31454 .35181 .32042 .35092 .31666 .34652 Metetra
.69 .725 .876 r
.31666 .34652 .32042 .35092 .32637 .34925 .32268 .34386 Metetra
.71 .69 .828 r
.32268 .34386 .32637 .34925 .33239 .34672 .32876 .34047 Metetra
.718 .664 .796 r
.32876 .34047 .33239 .34672 .33846 .34336 .33487 .33652 Metetra
.719 .649 .778 r
.33487 .33652 .33846 .34336 .34459 .33935 .34102 .33223 Metetra
.718 .642 .771 r
.34102 .33223 .34459 .33935 .35074 .33493 .34717 .32784 Metetra
.716 .642 .773 r
.34717 .32784 .35074 .33493 .3569 .33036 .35332 .32355 Metetra
.713 .647 .783 r
.35332 .32355 .3569 .33036 .36306 .32588 .35947 .31951 Metetra
.708 .658 .798 r
.35947 .31951 .36306 .32588 .36922 .32167 .36561 .3158 Metetra
.703 .672 .817 r
.36561 .3158 .36922 .32167 .37536 .31781 .37173 .31243 Metetra
.697 .688 .838 r
.37173 .31243 .37536 .31781 .3815 .31434 .37785 .30937 Metetra
.69 .703 .857 r
.37785 .30937 .3815 .31434 .38762 .31122 .38397 .30658 Metetra
.683 .716 .874 r
.38397 .30658 .38762 .31122 .39375 .30839 .39009 .30399 Metetra
.678 .726 .886 r
.39009 .30399 .39375 .30839 .39987 .30578 .39622 .30154 Metetra
.673 .733 .895 r
.39622 .30154 .39987 .30578 .406 .30332 .40236 .29918 Metetra
.67 .738 .901 r
.40236 .29918 .406 .30332 .41215 .30097 .40851 .29688 Metetra
.668 .74 .904 r
.40851 .29688 .41215 .30097 .4183 .29867 .41467 .29461 Metetra
.666 .742 .907 r
.41467 .29461 .4183 .29867 .42446 .29641 .42084 .29237 Metetra
.665 .743 .908 r
.42084 .29237 .42446 .29641 .43064 .29417 .42703 .29013 Metetra
.665 .743 .909 r
.42703 .29013 .43064 .29417 .43683 .29193 .43323 .28789 Metetra
.665 .744 .909 r
.43323 .28789 .43683 .29193 .44304 .28971 .43944 .28566 Metetra
.664 .744 .91 r
.43944 .28566 .44304 .28971 .44926 .28748 .44567 .28343 Metetra
.664 .744 .91 r
.44567 .28343 .44926 .28748 .45549 .28525 .45191 .2812 Metetra
.664 .744 .91 r
.45191 .2812 .45549 .28525 .46174 .28303 .45817 .27896 Metetra
.664 .744 .91 r
.45817 .27896 .46174 .28303 .468 .2808 .46444 .27673 Metetra
.663 .744 .91 r
.46444 .27673 .468 .2808 .47428 .27857 .47073 .27449 Metetra
.663 .744 .91 r
.47073 .27449 .47428 .27857 .48057 .27635 .47703 .27225 Metetra
.663 .744 .91 r
.47703 .27225 .48057 .27635 .48688 .27412 .48334 .27001 Metetra
.663 .743 .91 r
.48334 .27001 .48688 .27412 .4932 .2719 .48967 .26777 Metetra
.662 .743 .91 r
.48967 .26777 .4932 .2719 .49953 .26968 .49602 .26553 Metetra
.661 .742 .91 r
.49602 .26553 .49953 .26968 .50588 .26747 .50238 .26329 Metetra
.661 .741 .909 r
.50238 .26329 .50588 .26747 .51225 .26527 .50875 .26106 Metetra
.66 .739 .909 r
.50875 .26106 .51225 .26527 .51863 .26308 .51514 .25885 Metetra
.658 .738 .908 r
.51514 .25885 .51863 .26308 .52502 .26092 .52155 .25664 Metetra
.657 .735 .908 r
.52155 .25664 .52502 .26092 .53143 .25879 .52796 .25446 Metetra
.654 .733 .907 r
.52796 .25446 .53143 .25879 .53786 .2567 .5344 .25231 Metetra
.652 .729 .906 r
.5344 .25231 .53786 .2567 .5443 .25466 .54085 .2502 Metetra
.648 .724 .904 r
.54085 .2502 .5443 .25466 .55076 .25269 .54732 .24814 Metetra
.644 .719 .902 r
.54732 .24814 .55076 .25269 .55723 .2508 .5538 .24614 Metetra
.639 .712 .9 r
.5538 .24614 .55723 .2508 .56373 .249 .5603 .24422 Metetra
.633 .703 .897 r
.5603 .24422 .56373 .249 .57024 .24732 .56682 .24239 Metetra
.626 .694 .893 r
.56682 .24239 .57024 .24732 .57678 .24575 .57336 .24067 Metetra
.619 .684 .889 r
.57336 .24067 .57678 .24575 .58333 .24429 .57992 .23905 Metetra
.612 .674 .885 r
.57992 .23905 .58333 .24429 .58991 .24294 .5865 .23753 Metetra
.607 .665 .88 r
.5865 .23753 .58991 .24294 .5965 .24166 .5931 .23611 Metetra
.603 .657 .876 r
.5931 .23611 .5965 .24166 .60312 .24041 .59973 .23475 Metetra
.601 .652 .873 r
.59973 .23475 .60312 .24041 .60976 .23913 .60637 .23342 Metetra
.602 .651 .871 r
.60637 .23342 .60976 .23913 .61642 .23775 .61303 .23206 Metetra
.607 .655 .871 r
.61303 .23206 .61642 .23775 .62309 .2362 .61971 .23061 Metetra
.616 .663 .873 r
.61971 .23061 .62309 .2362 .62977 .23443 .62641 .22901 Metetra
.628 .677 .877 r
.62641 .22901 .62977 .23443 .63646 .23238 .63312 .22719 Metetra
.642 .694 .883 r
.63312 .22719 .63646 .23238 .64316 .23004 .63983 .22513 Metetra
.658 .714 .889 r
.63983 .22513 .64316 .23004 .64986 .22744 .64656 .2228 Metetra
.672 .733 .896 r
.64656 .2228 .64986 .22744 .65657 .22463 .65329 .22023 Metetra
.685 .751 .902 r
.65329 .22023 .65657 .22463 .66329 .22168 .66003 .21745 Metetra
.693 .763 .906 r
.66003 .21745 .66329 .22168 .67001 .21868 .66677 .21453 Metetra
.696 .77 .908 r
.66677 .21453 .67001 .21868 .67676 .21571 .67353 .21156 Metetra
.695 .77 .909 r
.67353 .21156 .67676 .21571 .68352 .21282 .6803 .20859 Metetra
.691 .765 .908 r
.6803 .20859 .68352 .21282 .6903 .21005 .68709 .2057 Metetra
.684 .756 .906 r
.68709 .2057 .6903 .21005 .69711 .20742 .6939 .20292 Metetra
.676 .746 .903 r
.6939 .20292 .69711 .20742 .70394 .20488 .70073 .20025 Metetra
.67 .737 .9 r
.70073 .20025 .70394 .20488 .71078 .20242 .70758 .19768 Metetra
.665 .73 .898 r
.70758 .19768 .71078 .20242 .71765 .19999 .71446 .19519 Metetra
.663 .727 .897 r
.71446 .19519 .71765 .19999 .72453 .19754 .72135 .19273 Metetra
.662 .727 .897 r
.72135 .19273 .72453 .19754 .73143 .19505 .72826 .19027 Metetra
.664 .729 .898 r
.72826 .19027 .73143 .19505 .73834 .19251 .73519 .18778 Metetra
.666 .733 .9 r
.73519 .18778 .73834 .19251 .74526 .18992 .74213 .18524 Metetra
.669 .738 .902 r
.74213 .18524 .74526 .18992 .7522 .18729 .74908 .18266 Metetra
.671 .741 .903 r
.74908 .18266 .7522 .18729 .75915 .18464 .75605 .18003 Metetra
.672 .744 .904 r
.75605 .18003 .75915 .18464 .76612 .18198 .76303 .17738 Metetra
.673 .745 .905 r
.76303 .17738 .76612 .18198 .77311 .17933 .77003 .17472 Metetra
.672 .745 .905 r
.77003 .17472 .77311 .17933 .78011 .17669 .77704 .17205 Metetra
.672 .744 .905 r
.77704 .17205 .78011 .17669 .78713 .17406 .78407 .1694 Metetra
.671 .743 .905 r
.78407 .1694 .78713 .17406 .79417 .17143 .79112 .16675 Metetra
.657 .741 .912 r
.16305 .38427 .16704 .38795 .17265 .38606 .16867 .38235 Metetra
.658 .74 .911 r
.16867 .38235 .17265 .38606 .17828 .38415 .17431 .38041 Metetra
.658 .739 .91 r
.17431 .38041 .17828 .38415 .18393 .38222 .17996 .37847 Metetra
.657 .739 .91 r
.17996 .37847 .18393 .38222 .18958 .38029 .18562 .37655 Metetra
.654 .739 .912 r
.18562 .37655 .18958 .38029 .19525 .37836 .19129 .37465 Metetra
.65 .741 .915 r
.19129 .37465 .19525 .37836 .20093 .37646 .19697 .37281 Metetra
.646 .743 .92 r
.19697 .37281 .20093 .37646 .20661 .3746 .20266 .37101 Metetra
.643 .746 .924 r
.20266 .37101 .20661 .3746 .21231 .3728 .20835 .36926 Metetra
.642 .749 .927 r
.20835 .36926 .21231 .3728 .21801 .37106 .21406 .36751 Metetra
.645 .75 .926 r
.21406 .36751 .21801 .37106 .22372 .36934 .21978 .36572 Metetra
.651 .748 .921 r
.21978 .36572 .22372 .36934 .22944 .3676 .22553 .36384 Metetra
.66 .743 .912 r
.22553 .36384 .22944 .3676 .23519 .36577 .2313 .36183 Metetra
.667 .736 .901 r
.2313 .36183 .23519 .36577 .24096 .36381 .2371 .3597 Metetra
.67 .728 .893 r
.2371 .3597 .24096 .36381 .24676 .36172 .24291 .3575 Metetra
.668 .722 .89 r
.24291 .3575 .24676 .36172 .25258 .35951 .24873 .35533 Metetra
.657 .721 .896 r
.24873 .35533 .25258 .35951 .25841 .3573 .25455 .35333 Metetra
.637 .727 .913 r
.25455 .35333 .25841 .3573 .26425 .35522 .26036 .35162 Metetra
.603 .738 .94 r
.26036 .35162 .26425 .35522 .27007 .35344 .26615 .35031 Metetra
.55 .75 .97 r
.26615 .35031 .27007 .35344 .27587 .35206 .27193 .34942 Metetra
.483 .758 .991 r
.27193 .34942 .27587 .35206 .28166 .35115 .27769 .34886 Metetra
.43 .759 .996 r
.27769 .34886 .28166 .35115 .28743 .35064 .28346 .34848 Metetra
.432 .768 .997 r
.28346 .34848 .28743 .35064 .2932 .35037 .28925 .34801 Metetra
.498 .784 .996 r
.28925 .34801 .2932 .35037 .29899 .35009 .29509 .34722 Metetra
.589 .783 .972 r
.29509 .34722 .29899 .35009 .30482 .34952 .30098 .34588 Metetra
.657 .756 .923 r
.30098 .34588 .30482 .34952 .31071 .34838 .30694 .34385 Metetra
.694 .72 .869 r
.30694 .34385 .31071 .34838 .31666 .34652 .31296 .34109 Metetra
.711 .689 .827 r
.31296 .34109 .31666 .34652 .32268 .34386 .31903 .33768 Metetra
.717 .666 .799 r
.31903 .33768 .32268 .34386 .32876 .34047 .32514 .33378 Metetra
.718 .653 .783 r
.32514 .33378 .32876 .34047 .33487 .33652 .33128 .3296 Metetra
.717 .646 .778 r
.33128 .3296 .33487 .33652 .34102 .33223 .33742 .32535 Metetra
.714 .647 .78 r
.33742 .32535 .34102 .33223 .34717 .32784 .34357 .32122 Metetra
.711 .652 .789 r
.34357 .32122 .34717 .32784 .35332 .32355 .34971 .31732 Metetra
.706 .662 .804 r
.34971 .31732 .35332 .32355 .35947 .31951 .35583 .31372 Metetra
.701 .675 .821 r
.35583 .31372 .35947 .31951 .36561 .3158 .36195 .31044 Metetra
.695 .688 .84 r
.36195 .31044 .36561 .3158 .37173 .31243 .36807 .30744 Metetra
.688 .702 .857 r
.36807 .30744 .37173 .31243 .37785 .30937 .37418 .30468 Metetra
.682 .713 .872 r
.37418 .30468 .37785 .30937 .38397 .30658 .3803 .30211 Metetra
.677 .722 .884 r
.3803 .30211 .38397 .30658 .39009 .30399 .38642 .29966 Metetra
.672 .729 .892 r
.38642 .29966 .39009 .30399 .39622 .30154 .39255 .2973 Metetra
.669 .733 .897 r
.39255 .2973 .39622 .30154 .40236 .29918 .3987 .29499 Metetra
.667 .735 .901 r
.3987 .29499 .40236 .29918 .40851 .29688 .40485 .29272 Metetra
.666 .737 .903 r
.40485 .29272 .40851 .29688 .41467 .29461 .41102 .29047 Metetra
.665 .738 .904 r
.41102 .29047 .41467 .29461 .42084 .29237 .4172 .28822 Metetra
.665 .738 .905 r
.4172 .28822 .42084 .29237 .42703 .29013 .4234 .28598 Metetra
.664 .739 .905 r
.4234 .28598 .42703 .29013 .43323 .28789 .42961 .28375 Metetra
.664 .739 .906 r
.42961 .28375 .43323 .28789 .43944 .28566 .43583 .28151 Metetra
.664 .739 .906 r
.43583 .28151 .43944 .28566 .44567 .28343 .44207 .27927 Metetra
.664 .739 .906 r
.44207 .27927 .44567 .28343 .45191 .2812 .44832 .27703 Metetra
.663 .739 .906 r
.44832 .27703 .45191 .2812 .45817 .27896 .45459 .27479 Metetra
.663 .739 .906 r
.45459 .27479 .45817 .27896 .46444 .27673 .46087 .27254 Metetra
.663 .739 .906 r
.46087 .27254 .46444 .27673 .47073 .27449 .46716 .27029 Metetra
.663 .739 .906 r
.46716 .27029 .47073 .27449 .47703 .27225 .47347 .26804 Metetra
.663 .739 .906 r
.47347 .26804 .47703 .27225 .48334 .27001 .4798 .26579 Metetra
.663 .739 .906 r
.4798 .26579 .48334 .27001 .48967 .26777 .48614 .26354 Metetra
.662 .738 .906 r
.48614 .26354 .48967 .26777 .49602 .26553 .49249 .26128 Metetra
.662 .738 .906 r
.49249 .26128 .49602 .26553 .50238 .26329 .49886 .25903 Metetra
.661 .737 .906 r
.49886 .25903 .50238 .26329 .50875 .26106 .50524 .25678 Metetra
.66 .737 .906 r
.50524 .25678 .50875 .26106 .51514 .25885 .51164 .25454 Metetra
.659 .735 .906 r
.51164 .25454 .51514 .25885 .52155 .25664 .51806 .25231 Metetra
.658 .734 .906 r
.51806 .25231 .52155 .25664 .52796 .25446 .52448 .2501 Metetra
.656 .732 .905 r
.52448 .2501 .52796 .25446 .5344 .25231 .53093 .2479 Metetra
.654 .73 .905 r
.53093 .2479 .5344 .25231 .54085 .2502 .53739 .24574 Metetra
.652 .726 .904 r
.53739 .24574 .54085 .2502 .54732 .24814 .54387 .24361 Metetra
.648 .722 .902 r
.54387 .24361 .54732 .24814 .5538 .24614 .55036 .24153 Metetra
.644 .717 .901 r
.55036 .24153 .5538 .24614 .5603 .24422 .55687 .23951 Metetra
.639 .71 .899 r
.55687 .23951 .5603 .24422 .56682 .24239 .5634 .23756 Metetra
.634 .703 .896 r
.5634 .23756 .56682 .24239 .57336 .24067 .56994 .2357 Metetra
.627 .694 .893 r
.56994 .2357 .57336 .24067 .57992 .23905 .57651 .23394 Metetra
.621 .685 .889 r
.57651 .23394 .57992 .23905 .5865 .23753 .58309 .23227 Metetra
.615 .676 .885 r
.58309 .23227 .5865 .23753 .5931 .23611 .5897 .2307 Metetra
.609 .667 .881 r
.5897 .2307 .5931 .23611 .59973 .23475 .59632 .22922 Metetra
.606 .661 .877 r
.59632 .22922 .59973 .23475 .60637 .23342 .60297 .2278 Metetra
.604 .656 .874 r
.60297 .2278 .60637 .23342 .61303 .23206 .60964 .2264 Metetra
.606 .656 .873 r
.60964 .2264 .61303 .23206 .61971 .23061 .61633 .22497 Metetra
.61 .659 .873 r
.61633 .22497 .61971 .23061 .62641 .22901 .62304 .22346 Metetra
.618 .667 .875 r
.62304 .22346 .62641 .22901 .63312 .22719 .62976 .2218 Metetra
.629 .68 .879 r
.62976 .2218 .63312 .22719 .63983 .22513 .63649 .21995 Metetra
.642 .696 .884 r
.63649 .21995 .63983 .22513 .64656 .2228 .64323 .21787 Metetra
.657 .714 .89 r
.64323 .21787 .64656 .2228 .65329 .22023 .64999 .21555 Metetra
.67 .732 .896 r
.64999 .21555 .65329 .22023 .66003 .21745 .65674 .21299 Metetra
.682 .749 .902 r
.65674 .21299 .66003 .21745 .66677 .21453 .66351 .21025 Metetra
.69 .761 .906 r
.66351 .21025 .66677 .21453 .67353 .21156 .67028 .20736 Metetra
.694 .768 .908 r
.67028 .20736 .67353 .21156 .6803 .20859 .67707 .20441 Metetra
.694 .769 .909 r
.67707 .20441 .6803 .20859 .68709 .2057 .68386 .20145 Metetra
.69 .765 .909 r
.68386 .20145 .68709 .2057 .6939 .20292 .69068 .19856 Metetra
.684 .757 .907 r
.69068 .19856 .6939 .20292 .70073 .20025 .69752 .19575 Metetra
.677 .748 .905 r
.69752 .19575 .70073 .20025 .70758 .19768 .70438 .19306 Metetra
.671 .74 .902 r
.70438 .19306 .70758 .19768 .71446 .19519 .71126 .19046 Metetra
.666 .733 .9 r
.71126 .19046 .71446 .19519 .72135 .19273 .71816 .18794 Metetra
.663 .729 .898 r
.71816 .18794 .72135 .19273 .72826 .19027 .72508 .18545 Metetra
.663 .728 .898 r
.72508 .18545 .72826 .19027 .73519 .18778 .73202 .18297 Metetra
.663 .73 .899 r
.73202 .18297 .73519 .18778 .74213 .18524 .73897 .18047 Metetra
.665 .733 .9 r
.73897 .18047 .74213 .18524 .74908 .18266 .74594 .17793 Metetra
.668 .737 .902 r
.74594 .17793 .74908 .18266 .75605 .18003 .75292 .17535 Metetra
.67 .74 .903 r
.75292 .17535 .75605 .18003 .76303 .17738 .75992 .17273 Metetra
.671 .743 .904 r
.75992 .17273 .76303 .17738 .77003 .17472 .76693 .17008 Metetra
.672 .745 .905 r
.76693 .17008 .77003 .17472 .77704 .17205 .77396 .16741 Metetra
.672 .745 .905 r
.77396 .16741 .77704 .17205 .78407 .1694 .781 .16474 Metetra
.671 .744 .905 r
.781 .16474 .78407 .1694 .79112 .16675 .78806 .16207 Metetra
.658 .74 .91 r
.15905 .38054 .16305 .38427 .16867 .38235 .16468 .3786 Metetra
.657 .739 .91 r
.16468 .3786 .16867 .38235 .17431 .38041 .17032 .37666 Metetra
.656 .739 .911 r
.17032 .37666 .17431 .38041 .17996 .37847 .17598 .37474 Metetra
.653 .74 .913 r
.17598 .37474 .17996 .37847 .18562 .37655 .18164 .37286 Metetra
.65 .742 .917 r
.18164 .37286 .18562 .37655 .19129 .37465 .18731 .37101 Metetra
.646 .744 .921 r
.18731 .37101 .19129 .37465 .19697 .37281 .19299 .36922 Metetra
.644 .747 .924 r
.19299 .36922 .19697 .37281 .20266 .37101 .19868 .36745 Metetra
.644 .749 .925 r
.19868 .36745 .20266 .37101 .20835 .36926 .20439 .36567 Metetra
.648 .749 .923 r
.20439 .36567 .20835 .36926 .21406 .36751 .21011 .36384 Metetra
.654 .746 .917 r
.21011 .36384 .21406 .36751 .21978 .36572 .21585 .36191 Metetra
.662 .741 .908 r
.21585 .36191 .21978 .36572 .22553 .36384 .22162 .35986 Metetra
.668 .734 .899 r
.22162 .35986 .22553 .36384 .2313 .36183 .22741 .35771 Metetra
.669 .727 .893 r
.22741 .35771 .2313 .36183 .2371 .3597 .23322 .35552 Metetra
.665 .723 .893 r
.23322 .35552 .2371 .3597 .24291 .3575 .23903 .35339 Metetra
.653 .724 .901 r
.23903 .35339 .24291 .3575 .24873 .35533 .24484 .35145 Metetra
.632 .731 .919 r
.24484 .35145 .24873 .35533 .25455 .35333 .25064 .34982 Metetra
.597 .742 .945 r
.25064 .34982 .25455 .35333 .26036 .35162 .25641 .34855 Metetra
.548 .754 .973 r
.25641 .34855 .26036 .35162 .26615 .35031 .26218 .34766 Metetra
.492 .761 .99 r
.26218 .34766 .26615 .35031 .27193 .34942 .26794 .34704 Metetra
.457 .766 .996 r
.26794 .34704 .27193 .34942 .27769 .34886 .2737 .34653 Metetra
.472 .775 .997 r
.2737 .34653 .27769 .34886 .28346 .34848 .2795 .3459 Metetra
.536 .784 .989 r
.2795 .3459 .28346 .34848 .28925 .34801 .28534 .34492 Metetra
.611 .775 .959 r
.28534 .34492 .28925 .34801 .29509 .34722 .29124 .3434 Metetra
.666 .748 .912 r
.29124 .3434 .29509 .34722 .30098 .34588 .2972 .34123 Metetra
.696 .716 .864 r
.2972 .34123 .30098 .34588 .30694 .34385 .30322 .3384 Metetra
.71 .688 .827 r
.30322 .3384 .30694 .34385 .31296 .34109 .30929 .33499 Metetra
.716 .669 .802 r
.30929 .33499 .31296 .34109 .31903 .33768 .31539 .33116 Metetra
.717 .657 .789 r
.31539 .33116 .31903 .33768 .32514 .33378 .32152 .3271 Metetra
.716 .652 .785 r
.32152 .3271 .32514 .33378 .33128 .3296 .32766 .32299 Metetra
.714 .654 .788 r
.32766 .32299 .33128 .3296 .33742 .32535 .33379 .31899 Metetra
.71 .66 .798 r
.33379 .31899 .33742 .32535 .34357 .32122 .33992 .31522 Metetra
.706 .669 .812 r
.33992 .31522 .34357 .32122 .34971 .31732 .34604 .31172 Metetra
.7 .681 .828 r
.34604 .31172 .34971 .31732 .35583 .31372 .35216 .30851 Metetra
.694 .694 .846 r
.35216 .30851 .35583 .31372 .36195 .31044 .35826 .30556 Metetra
.688 .707 .862 r
.35826 .30556 .36195 .31044 .36807 .30744 .36437 .30283 Metetra
.682 .717 .876 r
.36437 .30283 .36807 .30744 .37418 .30468 .37049 .30026 Metetra
.677 .725 .886 r
.37049 .30026 .37418 .30468 .3803 .30211 .3766 .29782 Metetra
.673 .731 .894 r
.3766 .29782 .3803 .30211 .38642 .29966 .38273 .29545 Metetra
.67 .735 .899 r
.38273 .29545 .38642 .29966 .39255 .2973 .38887 .29314 Metetra
.668 .737 .902 r
.38887 .29314 .39255 .2973 .3987 .29499 .39502 .29087 Metetra
.666 .739 .904 r
.39502 .29087 .3987 .29499 .40485 .29272 .40118 .28861 Metetra
.666 .74 .906 r
.40118 .28861 .40485 .29272 .41102 .29047 .40736 .28636 Metetra
.665 .74 .906 r
.40736 .28636 .41102 .29047 .4172 .28822 .41355 .28411 Metetra
.665 .741 .907 r
.41355 .28411 .4172 .28822 .4234 .28598 .41975 .28187 Metetra
.664 .741 .907 r
.41975 .28187 .4234 .28598 .42961 .28375 .42597 .27963 Metetra
.664 .741 .907 r
.42597 .27963 .42961 .28375 .43583 .28151 .4322 .27738 Metetra
.664 .741 .908 r
.4322 .27738 .43583 .28151 .44207 .27927 .43845 .27514 Metetra
.664 .741 .908 r
.43845 .27514 .44207 .27927 .44832 .27703 .44471 .27289 Metetra
.664 .741 .908 r
.44471 .27289 .44832 .27703 .45459 .27479 .45099 .27063 Metetra
.664 .741 .908 r
.45099 .27063 .45459 .27479 .46087 .27254 .45728 .26838 Metetra
.663 .741 .908 r
.45728 .26838 .46087 .27254 .46716 .27029 .46358 .26612 Metetra
.663 .741 .908 r
.46358 .26612 .46716 .27029 .47347 .26804 .4699 .26385 Metetra
.663 .741 .908 r
.4699 .26385 .47347 .26804 .4798 .26579 .47624 .26159 Metetra
.663 .741 .908 r
.47624 .26159 .4798 .26579 .48614 .26354 .48258 .25932 Metetra
.663 .74 .908 r
.48258 .25932 .48614 .26354 .49249 .26128 .48895 .25705 Metetra
.662 .74 .908 r
.48895 .25705 .49249 .26128 .49886 .25903 .49533 .25478 Metetra
.662 .739 .907 r
.49533 .25478 .49886 .25903 .50524 .25678 .50172 .25251 Metetra
.661 .739 .907 r
.50172 .25251 .50524 .25678 .51164 .25454 .50813 .25025 Metetra
.66 .738 .907 r
.50813 .25025 .51164 .25454 .51806 .25231 .51455 .24799 Metetra
.659 .736 .907 r
.51455 .24799 .51806 .25231 .52448 .2501 .52099 .24575 Metetra
.658 .735 .906 r
.52099 .24575 .52448 .2501 .53093 .2479 .52744 .24352 Metetra
.656 .733 .906 r
.52744 .24352 .53093 .2479 .53739 .24574 .53391 .24131 Metetra
.654 .73 .905 r
.53391 .24131 .53739 .24574 .54387 .24361 .5404 .23913 Metetra
.652 .727 .904 r
.5404 .23913 .54387 .24361 .55036 .24153 .5469 .23698 Metetra
.648 .723 .903 r
.5469 .23698 .55036 .24153 .55687 .23951 .55342 .23488 Metetra
.644 .718 .901 r
.55342 .23488 .55687 .23951 .5634 .23756 .55995 .23284 Metetra
.64 .712 .899 r
.55995 .23284 .5634 .23756 .56994 .2357 .56651 .23087 Metetra
.634 .705 .897 r
.56651 .23087 .56994 .2357 .57651 .23394 .57308 .22898 Metetra
.629 .697 .894 r
.57308 .22898 .57651 .23394 .58309 .23227 .57967 .22718 Metetra
.623 .688 .89 r
.57967 .22718 .58309 .23227 .5897 .2307 .58628 .22547 Metetra
.617 .679 .887 r
.58628 .22547 .5897 .2307 .59632 .22922 .59291 .22385 Metetra
.612 .672 .883 r
.59291 .22385 .59632 .22922 .60297 .2278 .59957 .22231 Metetra
.609 .665 .879 r
.59957 .22231 .60297 .2278 .60964 .2264 .60624 .22082 Metetra
.607 .661 .877 r
.60624 .22082 .60964 .2264 .61633 .22497 .61294 .21936 Metetra
.608 .661 .875 r
.61294 .21936 .61633 .22497 .62304 .22346 .61965 .21786 Metetra
.613 .664 .876 r
.61965 .21786 .62304 .22346 .62976 .2218 .62638 .21629 Metetra
.62 .671 .878 r
.62638 .21629 .62976 .2218 .63649 .21995 .63313 .21459 Metetra
.63 .683 .881 r
.63313 .21459 .63649 .21995 .64323 .21787 .63989 .2127 Metetra
.643 .698 .886 r
.63989 .2127 .64323 .21787 .64999 .21555 .64666 .21061 Metetra
.656 .715 .891 r
.64666 .21061 .64999 .21555 .65674 .21299 .65344 .20828 Metetra
.669 .732 .897 r
.65344 .20828 .65674 .21299 .66351 .21025 .66022 .20574 Metetra
.68 .747 .902 r
.66022 .20574 .66351 .21025 .67028 .20736 .66701 .20302 Metetra
.688 .759 .906 r
.66701 .20302 .67028 .20736 .67707 .20441 .67382 .20015 Metetra
.692 .766 .908 r
.67382 .20015 .67707 .20441 .68386 .20145 .68063 .19722 Metetra
.692 .768 .91 r
.68063 .19722 .68386 .20145 .69068 .19856 .68746 .19428 Metetra
.689 .765 .909 r
.68746 .19428 .69068 .19856 .69752 .19575 .6943 .19138 Metetra
.684 .758 .908 r
.6943 .19138 .69752 .19575 .70438 .19306 .70116 .18856 Metetra
.678 .75 .905 r
.70116 .18856 .70438 .19306 .71126 .19046 .70805 .18584 Metetra
.672 .742 .903 r
.70805 .18584 .71126 .19046 .71816 .18794 .71496 .18321 Metetra
.667 .735 .901 r
.71496 .18321 .71816 .18794 .72508 .18545 .72188 .18066 Metetra
.664 .731 .899 r
.72188 .18066 .72508 .18545 .73202 .18297 .72883 .17815 Metetra
.663 .729 .899 r
.72883 .17815 .73202 .18297 .73897 .18047 .7358 .17565 Metetra
.663 .73 .899 r
.7358 .17565 .73897 .18047 .74594 .17793 .74278 .17314 Metetra
.665 .733 .9 r
.74278 .17314 .74594 .17793 .75292 .17535 .74978 .17059 Metetra
.667 .736 .902 r
.74978 .17059 .75292 .17535 .75992 .17273 .75679 .16801 Metetra
.669 .74 .903 r
.75679 .16801 .75992 .17273 .76693 .17008 .76382 .16539 Metetra
.67 .742 .904 r
.76382 .16539 .76693 .17008 .77396 .16741 .77086 .16273 Metetra
.671 .744 .905 r
.77086 .16273 .77396 .16741 .781 .16474 .77792 .16006 Metetra
.671 .745 .906 r
.77792 .16006 .781 .16474 .78806 .16207 .78499 .15738 Metetra
.657 .739 .91 r
.15503 .3768 .15905 .38054 .16468 .3786 .16067 .37486 Metetra
.655 .74 .912 r
.16067 .37486 .16468 .3786 .17032 .37666 .16632 .37294 Metetra
.653 .74 .914 r
.16632 .37294 .17032 .37666 .17598 .37474 .17197 .37106 Metetra
.649 .742 .917 r
.17197 .37106 .17598 .37474 .18164 .37286 .17764 .36922 Metetra
.646 .745 .921 r
.17764 .36922 .18164 .37286 .18731 .37101 .18331 .36742 Metetra
.645 .747 .923 r
.18331 .36742 .18731 .37101 .19299 .36922 .189 .36563 Metetra
.646 .748 .924 r
.189 .36563 .19299 .36922 .19868 .36745 .1947 .36382 Metetra
.651 .747 .92 r
.1947 .36382 .19868 .36745 .20439 .36567 .20042 .36194 Metetra
.657 .744 .914 r
.20042 .36194 .20439 .36567 .21011 .36384 .20616 .35997 Metetra
.664 .739 .906 r
.20616 .35997 .21011 .36384 .21585 .36191 .21192 .35789 Metetra
.668 .732 .898 r
.21192 .35789 .21585 .36191 .22162 .35986 .21771 .35573 Metetra
.668 .727 .894 r
.21771 .35573 .22162 .35986 .22741 .35771 .22351 .35356 Metetra
.662 .725 .896 r
.22351 .35356 .22741 .35771 .23322 .35552 .22931 .35148 Metetra
.649 .727 .906 r
.22931 .35148 .23322 .35552 .23903 .35339 .23511 .3496 Metetra
.627 .735 .925 r
.23511 .3496 .23903 .35339 .24484 .35145 .24089 .34802 Metetra
.592 .746 .95 r
.24089 .34802 .24484 .35145 .25064 .34982 .24666 .34679 Metetra
.547 .757 .974 r
.24666 .34679 .25064 .34982 .25641 .34855 .25241 .34588 Metetra
.502 .764 .99 r
.25241 .34588 .25641 .34855 .26218 .34766 .25817 .34519 Metetra
.482 .77 .995 r
.25817 .34519 .26218 .34766 .26794 .34704 .26393 .34456 Metetra
.505 .779 .994 r
.26393 .34456 .26794 .34704 .2737 .34653 .26973 .34377 Metetra
.564 .782 .981 r
.26973 .34377 .2737 .34653 .2795 .3459 .27558 .34261 Metetra
.627 .768 .947 r
.27558 .34261 .2795 .3459 .28534 .34492 .28148 .34094 Metetra
.672 .741 .903 r
.28148 .34094 .28534 .34492 .29124 .3434 .28744 .33866 Metetra
.697 .712 .86 r
.28744 .33866 .29124 .3434 .2972 .34123 .29346 .33577 Metetra
.71 .688 .827 r
.29346 .33577 .2972 .34123 .30322 .3384 .29952 .33237 Metetra
.715 .671 .805 r
.29952 .33237 .30322 .3384 .30929 .33499 .30562 .32861 Metetra
.716 .66 .794 r
.30562 .32861 .30929 .33499 .31539 .33116 .31174 .32465 Metetra
.715 .657 .791 r
.31174 .32465 .31539 .33116 .32152 .3271 .31787 .32066 Metetra
.712 .658 .794 r
.31787 .32066 .32152 .3271 .32766 .32299 .324 .31679 Metetra
.709 .664 .804 r
.324 .31679 .32766 .32299 .33379 .31899 .33012 .31313 Metetra
.704 .674 .817 r
.33012 .31313 .33379 .31899 .33992 .31522 .33623 .30972 Metetra
.699 .685 .833 r
.33623 .30972 .33992 .31522 .34604 .31172 .34234 .30657 Metetra
.693 .697 .849 r
.34234 .30657 .34604 .31172 .35216 .30851 .34844 .30367 Metetra
.687 .708 .864 r
.34844 .30367 .35216 .30851 .35826 .30556 .35455 .30096 Metetra
.681 .718 .877 r
.35455 .30096 .35826 .30556 .36437 .30283 .36065 .29841 Metetra
.676 .726 .887 r
.36065 .29841 .36437 .30283 .37049 .30026 .36677 .29597 Metetra
.672 .731 .894 r
.36677 .29597 .37049 .30026 .3766 .29782 .37289 .2936 Metetra
.67 .735 .899 r
.37289 .2936 .3766 .29782 .38273 .29545 .37902 .29129 Metetra
.668 .737 .902 r
.37902 .29129 .38273 .29545 .38887 .29314 .38517 .28901 Metetra
.666 .739 .904 r
.38517 .28901 .38887 .29314 .39502 .29087 .39132 .28674 Metetra
.666 .74 .905 r
.39132 .28674 .39502 .29087 .40118 .28861 .3975 .28449 Metetra
.665 .74 .906 r
.3975 .28449 .40118 .28861 .40736 .28636 .40368 .28224 Metetra
.665 .741 .907 r
.40368 .28224 .40736 .28636 .41355 .28411 .40988 .27999 Metetra
.664 .741 .907 r
.40988 .27999 .41355 .28411 .41975 .28187 .41609 .27774 Metetra
.664 .741 .908 r
.41609 .27774 .41975 .28187 .42597 .27963 .42232 .27549 Metetra
.664 .741 .908 r
.42232 .27549 .42597 .27963 .4322 .27738 .42856 .27324 Metetra
.664 .742 .908 r
.42856 .27324 .4322 .27738 .43845 .27514 .43482 .27099 Metetra
.664 .742 .908 r
.43482 .27099 .43845 .27514 .44471 .27289 .44109 .26873 Metetra
.664 .742 .908 r
.44109 .26873 .44471 .27289 .45099 .27063 .44737 .26647 Metetra
.664 .742 .908 r
.44737 .26647 .45099 .27063 .45728 .26838 .45367 .2642 Metetra
.663 .742 .908 r
.45367 .2642 .45728 .26838 .46358 .26612 .45999 .26193 Metetra
.663 .742 .908 r
.45999 .26193 .46358 .26612 .4699 .26385 .46631 .25966 Metetra
.663 .742 .908 r
.46631 .25966 .4699 .26385 .47624 .26159 .47266 .25738 Metetra
.663 .741 .908 r
.47266 .25738 .47624 .26159 .48258 .25932 .47902 .2551 Metetra
.663 .741 .908 r
.47902 .2551 .48258 .25932 .48895 .25705 .48539 .25282 Metetra
.663 .741 .908 r
.48539 .25282 .48895 .25705 .49533 .25478 .49178 .25053 Metetra
.662 .741 .908 r
.49178 .25053 .49533 .25478 .50172 .25251 .49818 .24825 Metetra
.662 .74 .908 r
.49818 .24825 .50172 .25251 .50813 .25025 .5046 .24597 Metetra
.661 .739 .908 r
.5046 .24597 .50813 .25025 .51455 .24799 .51103 .24369 Metetra
.66 .738 .908 r
.51103 .24369 .51455 .24799 .52099 .24575 .51748 .24142 Metetra
.659 .737 .907 r
.51748 .24142 .52099 .24575 .52744 .24352 .52394 .23916 Metetra
.658 .736 .907 r
.52394 .23916 .52744 .24352 .53391 .24131 .53042 .23691 Metetra
.657 .734 .906 r
.53042 .23691 .53391 .24131 .5404 .23913 .53692 .23468 Metetra
.655 .731 .906 r
.53692 .23468 .5404 .23913 .5469 .23698 .54343 .23248 Metetra
.652 .728 .905 r
.54343 .23248 .5469 .23698 .55342 .23488 .54996 .23032 Metetra
.649 .724 .903 r
.54996 .23032 .55342 .23488 .55995 .23284 .5565 .2282 Metetra
.645 .719 .902 r
.5565 .2282 .55995 .23284 .56651 .23087 .56306 .22614 Metetra
.64 .713 .9 r
.56306 .22614 .56651 .23087 .57308 .22898 .56964 .22414 Metetra
.635 .706 .897 r
.56964 .22414 .57308 .22898 .57967 .22718 .57624 .22222 Metetra
.63 .698 .894 r
.57624 .22222 .57967 .22718 .58628 .22547 .58286 .22038 Metetra
.624 .69 .891 r
.58286 .22038 .58628 .22547 .59291 .22385 .58949 .21863 Metetra
.619 .682 .888 r
.58949 .21863 .59291 .22385 .59957 .22231 .59615 .21696 Metetra
.614 .675 .884 r
.59615 .21696 .59957 .22231 .60624 .22082 .60283 .21537 Metetra
.611 .669 .881 r
.60283 .21537 .60624 .22082 .61294 .21936 .60953 .21382 Metetra
.61 .665 .879 r
.60953 .21382 .61294 .21936 .61965 .21786 .61625 .21229 Metetra
.611 .665 .877 r
.61625 .21229 .61965 .21786 .62638 .21629 .62299 .21073 Metetra
.615 .668 .878 r
.62299 .21073 .62638 .21629 .63313 .21459 .62975 .2091 Metetra
.622 .675 .879 r
.62975 .2091 .63313 .21459 .63989 .2127 .63652 .20735 Metetra
.631 .685 .882 r
.63652 .20735 .63989 .2127 .64666 .21061 .64331 .20544 Metetra
.643 .699 .887 r
.64331 .20544 .64666 .21061 .65344 .20828 .6501 .20332 Metetra
.655 .715 .892 r
.6501 .20332 .65344 .20828 .66022 .20574 .65691 .201 Metetra
.667 .731 .897 r
.65691 .201 .66022 .20574 .66701 .20302 .66372 .19846 Metetra
.678 .745 .902 r
.66372 .19846 .66701 .20302 .67382 .20015 .67054 .19576 Metetra
.686 .757 .906 r
.67054 .19576 .67382 .20015 .68063 .19722 .67737 .19292 Metetra
.69 .764 .908 r
.67737 .19292 .68063 .19722 .68746 .19428 .68422 .19 Metetra
.691 .766 .91 r
.68422 .19 .68746 .19428 .6943 .19138 .69107 .18707 Metetra
.688 .764 .909 r
.69107 .18707 .6943 .19138 .70116 .18856 .69794 .18416 Metetra
.684 .759 .908 r
.69794 .18416 .70116 .18856 .70805 .18584 .70483 .18133 Metetra
.678 .751 .906 r
.70483 .18133 .70805 .18584 .71496 .18321 .71175 .17859 Metetra
.672 .744 .904 r
.71175 .17859 .71496 .18321 .72188 .18066 .71868 .17593 Metetra
.668 .737 .902 r
.71868 .17593 .72188 .18066 .72883 .17815 .72564 .17335 Metetra
.664 .733 .9 r
.72564 .17335 .72883 .17815 .7358 .17565 .73261 .17081 Metetra
.663 .731 .9 r
.73261 .17081 .7358 .17565 .74278 .17314 .73961 .16829 Metetra
.663 .731 .9 r
.73961 .16829 .74278 .17314 .74978 .17059 .74662 .16577 Metetra
.664 .733 .901 r
.74662 .16577 .74978 .17059 .75679 .16801 .75365 .16322 Metetra
.666 .736 .902 r
.75365 .16322 .75679 .16801 .76382 .16539 .76069 .16063 Metetra
.668 .739 .903 r
.76069 .16063 .76382 .16539 .77086 .16273 .76775 .158 Metetra
.669 .742 .904 r
.76775 .158 .77086 .16273 .77792 .16006 .77482 .15535 Metetra
.67 .743 .905 r
.77482 .15535 .77792 .16006 .78499 .15738 .7819 .15267 Metetra
.655 .74 .912 r
.15099 .37305 .15503 .3768 .16067 .37486 .15663 .37114 Metetra
.652 .741 .915 r
.15663 .37114 .16067 .37486 .16632 .37294 .16228 .36927 Metetra
.649 .743 .918 r
.16228 .36927 .16632 .37294 .17197 .37106 .16794 .36742 Metetra
.647 .745 .921 r
.16794 .36742 .17197 .37106 .17764 .36922 .17361 .36561 Metetra
.646 .747 .923 r
.17361 .36561 .17764 .36922 .18331 .36742 .17929 .3638 Metetra
.648 .747 .922 r
.17929 .3638 .18331 .36742 .189 .36563 .18499 .36195 Metetra
.653 .746 .918 r
.18499 .36195 .189 .36563 .1947 .36382 .19071 .36004 Metetra
.659 .742 .911 r
.19071 .36004 .1947 .36382 .20042 .36194 .19645 .35803 Metetra
.665 .737 .904 r
.19645 .35803 .20042 .36194 .20616 .35997 .20221 .35593 Metetra
.668 .731 .897 r
.20221 .35593 .20616 .35997 .21192 .35789 .20799 .35377 Metetra
.666 .727 .895 r
.20799 .35377 .21192 .35789 .21771 .35573 .21378 .35162 Metetra
.659 .726 .899 r
.21378 .35162 .21771 .35573 .22351 .35356 .21957 .34959 Metetra
.645 .73 .911 r
.21957 .34959 .22351 .35356 .22931 .35148 .22536 .34776 Metetra
.622 .738 .93 r
.22536 .34776 .22931 .35148 .23511 .3496 .23113 .34623 Metetra
.589 .749 .953 r
.23113 .34623 .23511 .3496 .24089 .34802 .23688 .34501 Metetra
.549 .759 .975 r
.23688 .34501 .24089 .34802 .24666 .34679 .24263 .34408 Metetra
.514 .766 .988 r
.24263 .34408 .24666 .34679 .25241 .34588 .24838 .34332 Metetra
.504 .773 .992 r
.24838 .34332 .25241 .34588 .25817 .34519 .25415 .34256 Metetra
.532 .78 .989 r
.25415 .34256 .25817 .34519 .26393 .34456 .25995 .34162 Metetra
.586 .778 .971 r
.25995 .34162 .26393 .34456 .26973 .34377 .2658 .34032 Metetra
.639 .762 .937 r
.2658 .34032 .26973 .34377 .27558 .34261 .2717 .33851 Metetra
.677 .737 .896 r
.2717 .33851 .27558 .34261 .28148 .34094 .27766 .33614 Metetra
.698 .71 .857 r
.27766 .33614 .28148 .34094 .28744 .33866 .28368 .33322 Metetra
.709 .689 .828 r
.28368 .33322 .28744 .33866 .29346 .33577 .28974 .32984 Metetra
.714 .673 .809 r
.28974 .32984 .29346 .33577 .29952 .33237 .29583 .32613 Metetra
.715 .665 .799 r
.29583 .32613 .29952 .33237 .30562 .32861 .30194 .32227 Metetra
.714 .662 .797 r
.30194 .32227 .30562 .32861 .31174 .32465 .30806 .31839 Metetra
.711 .663 .801 r
.30806 .31839 .31174 .32465 .31787 .32066 .31418 .31463 Metetra
.708 .669 .81 r
.31418 .31463 .31787 .32066 .324 .31679 .3203 .31106 Metetra
.703 .678 .823 r
.3203 .31106 .324 .31679 .33012 .31313 .3264 .30773 Metetra
.698 .689 .838 r
.3264 .30773 .33012 .31313 .33623 .30972 .3325 .30464 Metetra
.692 .7 .853 r
.3325 .30464 .33623 .30972 .34234 .30657 .3386 .30177 Metetra
.686 .71 .866 r
.3386 .30177 .34234 .30657 .34844 .30367 .3447 .29908 Metetra
.681 .719 .878 r
.3447 .29908 .34844 .30367 .35455 .30096 .3508 .29654 Metetra
.676 .726 .887 r
.3508 .29654 .35455 .30096 .36065 .29841 .35691 .2941 Metetra
.672 .731 .894 r
.35691 .2941 .36065 .29841 .36677 .29597 .36303 .29173 Metetra
.67 .734 .898 r
.36303 .29173 .36677 .29597 .37289 .2936 .36915 .28941 Metetra
.668 .736 .901 r
.36915 .28941 .37289 .2936 .37902 .29129 .37529 .28712 Metetra
.666 .738 .903 r
.37529 .28712 .37902 .29129 .38517 .28901 .38145 .28485 Metetra
.666 .739 .905 r
.38145 .28485 .38517 .28901 .39132 .28674 .38761 .28259 Metetra
.665 .739 .906 r
.38761 .28259 .39132 .28674 .3975 .28449 .39379 .28034 Metetra
.665 .74 .906 r
.39379 .28034 .3975 .28449 .40368 .28224 .39999 .27809 Metetra
.664 .74 .906 r
.39999 .27809 .40368 .28224 .40988 .27999 .40619 .27583 Metetra
.664 .74 .907 r
.40619 .27583 .40988 .27999 .41609 .27774 .41242 .27358 Metetra
.664 .74 .907 r
.41242 .27358 .41609 .27774 .42232 .27549 .41865 .27132 Metetra
.664 .74 .907 r
.41865 .27132 .42232 .27549 .42856 .27324 .4249 .26906 Metetra
.664 .74 .907 r
.4249 .26906 .42856 .27324 .43482 .27099 .43117 .2668 Metetra
.664 .74 .907 r
.43117 .2668 .43482 .27099 .44109 .26873 .43745 .26453 Metetra
.664 .74 .907 r
.43745 .26453 .44109 .26873 .44737 .26647 .44374 .26226 Metetra
.663 .74 .907 r
.44374 .26226 .44737 .26647 .45367 .2642 .45005 .25998 Metetra
.663 .74 .907 r
.45005 .25998 .45367 .2642 .45999 .26193 .45637 .2577 Metetra
.663 .74 .907 r
.45637 .2577 .45999 .26193 .46631 .25966 .46271 .25542 Metetra
.663 .74 .907 r
.46271 .25542 .46631 .25966 .47266 .25738 .46906 .25313 Metetra
.663 .74 .907 r
.46906 .25313 .47266 .25738 .47902 .2551 .47543 .25084 Metetra
.663 .74 .907 r
.47543 .25084 .47902 .2551 .48539 .25282 .48181 .24854 Metetra
.663 .74 .907 r
.48181 .24854 .48539 .25282 .49178 .25053 .48821 .24625 Metetra
.662 .739 .907 r
.48821 .24625 .49178 .25053 .49818 .24825 .49463 .24395 Metetra
.662 .739 .907 r
.49463 .24395 .49818 .24825 .5046 .24597 .50105 .24165 Metetra
.662 .739 .907 r
.50105 .24165 .5046 .24597 .51103 .24369 .5075 .23935 Metetra
.661 .738 .907 r
.5075 .23935 .51103 .24369 .51748 .24142 .51395 .23706 Metetra
.66 .737 .907 r
.51395 .23706 .51748 .24142 .52394 .23916 .52043 .23478 Metetra
.659 .736 .906 r
.52043 .23478 .52394 .23916 .53042 .23691 .52692 .2325 Metetra
.658 .735 .906 r
.52692 .2325 .53042 .23691 .53692 .23468 .53342 .23024 Metetra
.657 .733 .906 r
.53342 .23024 .53692 .23468 .54343 .23248 .53994 .228 Metetra
.655 .73 .905 r
.53994 .228 .54343 .23248 .54996 .23032 .54648 .22578 Metetra
.652 .727 .904 r
.54648 .22578 .54996 .23032 .5565 .2282 .55303 .2236 Metetra
.649 .723 .903 r
.55303 .2236 .5565 .2282 .56306 .22614 .5596 .22146 Metetra
.645 .719 .901 r
.5596 .22146 .56306 .22614 .56964 .22414 .56619 .21938 Metetra
.641 .713 .9 r
.56619 .21938 .56964 .22414 .57624 .22222 .57279 .21735 Metetra
.636 .707 .897 r
.57279 .21735 .57624 .22222 .58286 .22038 .57942 .2154 Metetra
.631 .699 .895 r
.57942 .2154 .58286 .22038 .58949 .21863 .58606 .21353 Metetra
.626 .692 .892 r
.58606 .21353 .58949 .21863 .59615 .21696 .59273 .21174 Metetra
.621 .685 .889 r
.59273 .21174 .59615 .21696 .60283 .21537 .59941 .21003 Metetra
.617 .678 .885 r
.59941 .21003 .60283 .21537 .60953 .21382 .60612 .20838 Metetra
.614 .672 .883 r
.60612 .20838 .60953 .21382 .61625 .21229 .61284 .20678 Metetra
.612 .669 .88 r
.61284 .20678 .61625 .21229 .62299 .21073 .61959 .20519 Metetra
.614 .669 .879 r
.61959 .20519 .62299 .21073 .62975 .2091 .62636 .20358 Metetra
.617 .672 .88 r
.62636 .20358 .62975 .2091 .63652 .20735 .63314 .2019 Metetra
.624 .678 .881 r
.63314 .2019 .63652 .20735 .64331 .20544 .63994 .2001 Metetra
.632 .688 .884 r
.63994 .2001 .64331 .20544 .6501 .20332 .64675 .19815 Metetra
.643 .701 .888 r
.64675 .19815 .6501 .20332 .65691 .201 .65358 .19602 Metetra
.655 .715 .893 r
.65358 .19602 .65691 .201 .66372 .19846 .66041 .19369 Metetra
.666 .73 .898 r
.66041 .19369 .66372 .19846 .67054 .19576 .66725 .19116 Metetra
.676 .744 .902 r
.66725 .19116 .67054 .19576 .67737 .19292 .6741 .18847 Metetra
.683 .755 .906 r
.6741 .18847 .67737 .19292 .68422 .19 .68096 .18564 Metetra
.688 .762 .908 r
.68096 .18564 .68422 .19 .69107 .18707 .68783 .18274 Metetra
.689 .765 .91 r
.68783 .18274 .69107 .18707 .69794 .18416 .69471 .17982 Metetra
.688 .764 .91 r
.69471 .17982 .69794 .18416 .70483 .18133 .70161 .17691 Metetra
.684 .759 .909 r
.70161 .17691 .70483 .18133 .71175 .17859 .70853 .17407 Metetra
.678 .753 .907 r
.70853 .17407 .71175 .17859 .71868 .17593 .71547 .17131 Metetra
.673 .745 .905 r
.71547 .17131 .71868 .17593 .72564 .17335 .72243 .16862 Metetra
.668 .739 .903 r
.72243 .16862 .72564 .17335 .73261 .17081 .72942 .16601 Metetra
.665 .734 .901 r
.72942 .16601 .73261 .17081 .73961 .16829 .73642 .16345 Metetra
.663 .732 .901 r
.73642 .16345 .73961 .16829 .74662 .16577 .74344 .16091 Metetra
.663 .731 .9 r
.74344 .16091 .74662 .16577 .75365 .16322 .75048 .15836 Metetra
.664 .733 .901 r
.75048 .15836 .75365 .16322 .76069 .16063 .75754 .1558 Metetra
.665 .735 .902 r
.75754 .1558 .76069 .16063 .76775 .158 .76461 .15321 Metetra
.667 .738 .903 r
.76461 .15321 .76775 .158 .77482 .15535 .7717 .15058 Metetra
.669 .741 .904 r
.7717 .15058 .77482 .15535 .7819 .15267 .7788 .14792 Metetra
.652 .742 .916 r
.14694 .36935 .15099 .37305 .15663 .37114 .15258 .36747 Metetra
.649 .744 .918 r
.15258 .36747 .15663 .37114 .16228 .36927 .15823 .36562 Metetra
.648 .746 .921 r
.15823 .36562 .16228 .36927 .16794 .36742 .16389 .3638 Metetra
.648 .747 .922 r
.16389 .3638 .16794 .36742 .17361 .36561 .16957 .36196 Metetra
.651 .747 .92 r
.16957 .36196 .17361 .36561 .17929 .3638 .17526 .36008 Metetra
.655 .745 .915 r
.17526 .36008 .17929 .3638 .18499 .36195 .18098 .35813 Metetra
.661 .741 .909 r
.18098 .35813 .18499 .36195 .19071 .36004 .18672 .35609 Metetra
.665 .736 .902 r
.18672 .35609 .19071 .36004 .19645 .35803 .19247 .35398 Metetra
.667 .731 .897 r
.19247 .35398 .19645 .35803 .20221 .35593 .19825 .35182 Metetra
.664 .728 .897 r
.19825 .35182 .20221 .35593 .20799 .35377 .20403 .3497 Metetra
.656 .728 .902 r
.20403 .3497 .20799 .35377 .21378 .35162 .20981 .34771 Metetra
.641 .733 .915 r
.20981 .34771 .21378 .35162 .21957 .34959 .21558 .34593 Metetra
.618 .741 .934 r
.21558 .34593 .21957 .34959 .22536 .34776 .22134 .34443 Metetra
.587 .751 .956 r
.22134 .34443 .22536 .34776 .23113 .34623 .22709 .34322 Metetra
.552 .761 .975 r
.22709 .34322 .23113 .34623 .23688 .34501 .23283 .34225 Metetra
.526 .768 .986 r
.23283 .34225 .23688 .34501 .24263 .34408 .23858 .34141 Metetra
.525 .774 .988 r
.23858 .34141 .24263 .34408 .24838 .34332 .24435 .34054 Metetra
.555 .778 .982 r
.24435 .34054 .24838 .34332 .25415 .34256 .25015 .33946 Metetra
.603 .773 .962 r
.25015 .33946 .25415 .34256 .25995 .34162 .256 .33802 Metetra
.648 .757 .928 r
.256 .33802 .25995 .34162 .2658 .34032 .26191 .33611 Metetra
.68 .732 .89 r
.26191 .33611 .2658 .34032 .2717 .33851 .26787 .33366 Metetra
.699 .709 .855 r
.26787 .33366 .2717 .33851 .27766 .33614 .27388 .33072 Metetra
.709 .689 .829 r
.27388 .33072 .27766 .33614 .28368 .33322 .27994 .32736 Metetra
.713 .676 .812 r
.27994 .32736 .28368 .33322 .28974 .32984 .28602 .32372 Metetra
.714 .668 .804 r
.28602 .32372 .28974 .32984 .29583 .32613 .29213 .31994 Metetra
.713 .666 .802 r
.29213 .31994 .29583 .32613 .30194 .32227 .29824 .31617 Metetra
.71 .668 .807 r
.29824 .31617 .30194 .32227 .30806 .31839 .30435 .3125 Metetra
.707 .674 .816 r
.30435 .3125 .30806 .31839 .31418 .31463 .31045 .30902 Metetra
.702 .683 .828 r
.31045 .30902 .31418 .31463 .3203 .31106 .31655 .30576 Metetra
.697 .693 .842 r
.31655 .30576 .3203 .31106 .3264 .30773 .32265 .30272 Metetra
.691 .703 .856 r
.32265 .30272 .3264 .30773 .3325 .30464 .32874 .29988 Metetra
.685 .712 .869 r
.32874 .29988 .3325 .30464 .3386 .30177 .33483 .29722 Metetra
.68 .721 .88 r
.33483 .29722 .3386 .30177 .3447 .29908 .34093 .29468 Metetra
.676 .727 .888 r
.34093 .29468 .3447 .29908 .3508 .29654 .34703 .29224 Metetra
.672 .732 .895 r
.34703 .29224 .3508 .29654 .35691 .2941 .35315 .28987 Metetra
.67 .735 .899 r
.35315 .28987 .35691 .2941 .36303 .29173 .35927 .28755 Metetra
.668 .737 .902 r
.35927 .28755 .36303 .29173 .36915 .28941 .3654 .28526 Metetra
.666 .739 .904 r
.3654 .28526 .36915 .28941 .37529 .28712 .37155 .28298 Metetra
.666 .74 .905 r
.37155 .28298 .37529 .28712 .38145 .28485 .37771 .28072 Metetra
.665 .74 .906 r
.37771 .28072 .38145 .28485 .38761 .28259 .38389 .27846 Metetra
.665 .741 .907 r
.38389 .27846 .38761 .28259 .39379 .28034 .39007 .2762 Metetra
.664 .741 .907 r
.39007 .2762 .39379 .28034 .39999 .27809 .39628 .27395 Metetra
.664 .741 .908 r
.39628 .27395 .39999 .27809 .40619 .27583 .40249 .27169 Metetra
.664 .742 .908 r
.40249 .27169 .40619 .27583 .41242 .27358 .40872 .26943 Metetra
.664 .742 .908 r
.40872 .26943 .41242 .27358 .41865 .27132 .41497 .26716 Metetra
.664 .742 .908 r
.41497 .26716 .41865 .27132 .4249 .26906 .42123 .26489 Metetra
.664 .742 .908 r
.42123 .26489 .4249 .26906 .43117 .2668 .4275 .26262 Metetra
.664 .742 .908 r
.4275 .26262 .43117 .2668 .43745 .26453 .43379 .26034 Metetra
.664 .742 .908 r
.43379 .26034 .43745 .26453 .44374 .26226 .4401 .25806 Metetra
.664 .742 .908 r
.4401 .25806 .44374 .26226 .45005 .25998 .44641 .25578 Metetra
.664 .742 .908 r
.44641 .25578 .45005 .25998 .45637 .2577 .45275 .25349 Metetra
.663 .742 .908 r
.45275 .25349 .45637 .2577 .46271 .25542 .45909 .25119 Metetra
.663 .742 .908 r
.45909 .25119 .46271 .25542 .46906 .25313 .46546 .24889 Metetra
.663 .742 .908 r
.46546 .24889 .46906 .25313 .47543 .25084 .47183 .24659 Metetra
.663 .741 .908 r
.47183 .24659 .47543 .25084 .48181 .24854 .47823 .24428 Metetra
.663 .741 .908 r
.47823 .24428 .48181 .24854 .48821 .24625 .48463 .24197 Metetra
.663 .741 .908 r
.48463 .24197 .48821 .24625 .49463 .24395 .49105 .23966 Metetra
.663 .741 .908 r
.49105 .23966 .49463 .24395 .50105 .24165 .49749 .23734 Metetra
.662 .74 .908 r
.49749 .23734 .50105 .24165 .5075 .23935 .50395 .23503 Metetra
.662 .74 .908 r
.50395 .23503 .5075 .23935 .51395 .23706 .51041 .23272 Metetra
.661 .739 .908 r
.51041 .23272 .51395 .23706 .52043 .23478 .5169 .23041 Metetra
.66 .738 .907 r
.5169 .23041 .52043 .23478 .52692 .2325 .5234 .2281 Metetra
.659 .737 .907 r
.5234 .2281 .52692 .2325 .53342 .23024 .52991 .22581 Metetra
.658 .735 .907 r
.52991 .22581 .53342 .23024 .53994 .228 .53644 .22353 Metetra
.657 .733 .906 r
.53644 .22353 .53994 .228 .54648 .22578 .54299 .22128 Metetra
.655 .731 .905 r
.54299 .22128 .54648 .22578 .55303 .2236 .54955 .21904 Metetra
.652 .728 .905 r
.54955 .21904 .55303 .2236 .5596 .22146 .55613 .21684 Metetra
.649 .724 .903 r
.55613 .21684 .5596 .22146 .56619 .21938 .56272 .21469 Metetra
.646 .72 .902 r
.56272 .21469 .56619 .21938 .57279 .21735 .56934 .21258 Metetra
.642 .714 .9 r
.56934 .21258 .57279 .21735 .57942 .2154 .57597 .21053 Metetra
.637 .708 .898 r
.57597 .21053 .57942 .2154 .58606 .21353 .58262 .20855 Metetra
.632 .701 .895 r
.58262 .20855 .58606 .21353 .59273 .21174 .58929 .20665 Metetra
.627 .694 .893 r
.58929 .20665 .59273 .21174 .59941 .21003 .59598 .20482 Metetra
.622 .687 .89 r
.59598 .20482 .59941 .21003 .60612 .20838 .60269 .20306 Metetra
.619 .681 .887 r
.60269 .20306 .60612 .20838 .61284 .20678 .60943 .20136 Metetra
.616 .676 .884 r
.60943 .20136 .61284 .20678 .61959 .20519 .61618 .19971 Metetra
.615 .673 .882 r
.61618 .19971 .61959 .20519 .62636 .20358 .62295 .19806 Metetra
.616 .672 .881 r
.62295 .19806 .62636 .20358 .63314 .2019 .62974 .1964 Metetra
.619 .675 .881 r
.62974 .1964 .63314 .2019 .63994 .2001 .63655 .19466 Metetra
.625 .681 .883 r
.63655 .19466 .63994 .2001 .64675 .19815 .64338 .19283 Metetra
.633 .69 .885 r
.64338 .19283 .64675 .19815 .65358 .19602 .65022 .19084 Metetra
.643 .702 .889 r
.65022 .19084 .65358 .19602 .66041 .19369 .65707 .18869 Metetra
.654 .716 .893 r
.65707 .18869 .66041 .19369 .66725 .19116 .66393 .18635 Metetra
.665 .73 .898 r
.66393 .18635 .66725 .19116 .6741 .18847 .6708 .18383 Metetra
.674 .743 .902 r
.6708 .18383 .6741 .18847 .68096 .18564 .67768 .18115 Metetra
.682 .753 .906 r
.67768 .18115 .68096 .18564 .68783 .18274 .68457 .17834 Metetra
.686 .761 .908 r
.68457 .17834 .68783 .18274 .69471 .17982 .69147 .17545 Metetra
.688 .764 .91 r
.69147 .17545 .69471 .17982 .70161 .17691 .69838 .17253 Metetra
.687 .763 .91 r
.69838 .17253 .70161 .17691 .70853 .17407 .70531 .16963 Metetra
.683 .759 .909 r
.70531 .16963 .70853 .17407 .71547 .17131 .71226 .16677 Metetra
.679 .753 .908 r
.71226 .16677 .71547 .17131 .72243 .16862 .71922 .16399 Metetra
.674 .747 .906 r
.71922 .16399 .72243 .16862 .72942 .16601 .72621 .16128 Metetra
.669 .74 .904 r
.72621 .16128 .72942 .16601 .73642 .16345 .73322 .15864 Metetra
.666 .736 .902 r
.73322 .15864 .73642 .16345 .74344 .16091 .74026 .15605 Metetra
.664 .733 .901 r
.74026 .15605 .74344 .16091 .75048 .15836 .74731 .15348 Metetra
.663 .732 .901 r
.74731 .15348 .75048 .15836 .75754 .1558 .75438 .15092 Metetra
.664 .733 .901 r
.75438 .15092 .75754 .1558 .76461 .15321 .76146 .14834 Metetra
.665 .735 .902 r
.76146 .14834 .76461 .15321 .7717 .15058 .76857 .14574 Metetra
.667 .738 .903 r
.76857 .14574 .7717 .15058 .7788 .14792 .77568 .14311 Metetra
.649 .744 .919 r
.14285 .36567 .14694 .36935 .15258 .36747 .1485 .36382 Metetra
.649 .746 .92 r
.1485 .36382 .15258 .36747 .15823 .36562 .15416 .36198 Metetra
.649 .746 .92 r
.15416 .36198 .15823 .36562 .16389 .3638 .15983 .36011 Metetra
.653 .746 .918 r
.15983 .36011 .16389 .3638 .16957 .36196 .16552 .3582 Metetra
.657 .743 .913 r
.16552 .3582 .16957 .36196 .17526 .36008 .17123 .35622 Metetra
.662 .739 .907 r
.17123 .35622 .17526 .36008 .18098 .35813 .17697 .35416 Metetra
.666 .735 .901 r
.17697 .35416 .18098 .35813 .18672 .35609 .18272 .35203 Metetra
.666 .731 .898 r
.18272 .35203 .18672 .35609 .19247 .35398 .18849 .34989 Metetra
.662 .729 .899 r
.18849 .34989 .19247 .35398 .19825 .35182 .19426 .3478 Metetra
.653 .73 .905 r
.19426 .3478 .19825 .35182 .20403 .3497 .20003 .34585 Metetra
.638 .735 .919 r
.20003 .34585 .20403 .3497 .20981 .34771 .20579 .34411 Metetra
.616 .744 .937 r
.20579 .34411 .20981 .34771 .21558 .34593 .21154 .34263 Metetra
.587 .753 .957 r
.21154 .34263 .21558 .34593 .22134 .34443 .21728 .34142 Metetra
.557 .762 .974 r
.21728 .34142 .22134 .34443 .22709 .34322 .22302 .3404 Metetra
.538 .769 .983 r
.22302 .3404 .22709 .34322 .23283 .34225 .22876 .33948 Metetra
.543 .775 .984 r
.22876 .33948 .23283 .34225 .23858 .34141 .23453 .3385 Metetra
.573 .776 .975 r
.23453 .3385 .23858 .34141 .24435 .34054 .24034 .3373 Metetra
.616 .769 .953 r
.24034 .3373 .24435 .34054 .25015 .33946 .24619 .33574 Metetra
.655 .752 .921 r
.24619 .33574 .25015 .33946 .256 .33802 .25209 .33373 Metetra
.683 .729 .886 r
.25209 .33373 .256 .33802 .26191 .33611 .25805 .33122 Metetra
.699 .708 .854 r
.25805 .33122 .26191 .33611 .26787 .33366 .26406 .32826 Metetra
.708 .69 .831 r
.26406 .32826 .26787 .33366 .27388 .33072 .27012 .32493 Metetra
.712 .678 .816 r
.27012 .32493 .27388 .33072 .27994 .32736 .27619 .32135 Metetra
.713 .672 .808 r
.27619 .32135 .27994 .32736 .28602 .32372 .28229 .31766 Metetra
.711 .67 .807 r
.28229 .31766 .28602 .32372 .29213 .31994 .28839 .31398 Metetra
.709 .672 .812 r
.28839 .31398 .29213 .31994 .29824 .31617 .29449 .3104 Metetra
.705 .678 .821 r
.29449 .3104 .29824 .31617 .30435 .3125 .30059 .307 Metetra
.701 .686 .832 r
.30059 .307 .30435 .3125 .31045 .30902 .30669 .3038 Metetra
.696 .695 .845 r
.30669 .3038 .31045 .30902 .31655 .30576 .31277 .3008 Metetra
.69 .705 .859 r
.31277 .3008 .31655 .30576 .32265 .30272 .31886 .29799 Metetra
.685 .714 .871 r
.31886 .29799 .32265 .30272 .32874 .29988 .32495 .29534 Metetra
.68 .721 .881 r
.32495 .29534 .32874 .29988 .33483 .29722 .33104 .29281 Metetra
.675 .727 .889 r
.33104 .29281 .33483 .29722 .34093 .29468 .33714 .29037 Metetra
.672 .732 .895 r
.33714 .29037 .34093 .29468 .34703 .29224 .34325 .288 Metetra
.67 .735 .899 r
.34325 .288 .34703 .29224 .35315 .28987 .34936 .28567 Metetra
.668 .737 .902 r
.34936 .28567 .35315 .28987 .35927 .28755 .35549 .28337 Metetra
.667 .738 .904 r
.35549 .28337 .35927 .28755 .3654 .28526 .36164 .28109 Metetra
.666 .739 .905 r
.36164 .28109 .3654 .28526 .37155 .28298 .36779 .27883 Metetra
.665 .74 .906 r
.36779 .27883 .37155 .28298 .37771 .28072 .37396 .27656 Metetra
.665 .74 .906 r
.37396 .27656 .37771 .28072 .38389 .27846 .38014 .2743 Metetra
.664 .74 .907 r
.38014 .2743 .38389 .27846 .39007 .2762 .38634 .27204 Metetra
.664 .741 .907 r
.38634 .27204 .39007 .2762 .39628 .27395 .39255 .26977 Metetra
.664 .741 .907 r
.39255 .26977 .39628 .27395 .40249 .27169 .39878 .26751 Metetra
.664 .741 .907 r
.39878 .26751 .40249 .27169 .40872 .26943 .40502 .26524 Metetra
.664 .741 .907 r
.40502 .26524 .40872 .26943 .41497 .26716 .41127 .26297 Metetra
.664 .741 .907 r
.41127 .26297 .41497 .26716 .42123 .26489 .41754 .26069 Metetra
.664 .741 .908 r
.41754 .26069 .42123 .26489 .4275 .26262 .42382 .25841 Metetra
.664 .741 .908 r
.42382 .25841 .4275 .26262 .43379 .26034 .43012 .25612 Metetra
.664 .741 .908 r
.43012 .25612 .43379 .26034 .4401 .25806 .43643 .25383 Metetra
.664 .741 .908 r
.43643 .25383 .4401 .25806 .44641 .25578 .44276 .25153 Metetra
.663 .741 .908 r
.44276 .25153 .44641 .25578 .45275 .25349 .4491 .24923 Metetra
.663 .741 .908 r
.4491 .24923 .45275 .25349 .45909 .25119 .45546 .24693 Metetra
.663 .741 .908 r
.45546 .24693 .45909 .25119 .46546 .24889 .46183 .24462 Metetra
.663 .741 .908 r
.46183 .24462 .46546 .24889 .47183 .24659 .46822 .2423 Metetra
.663 .741 .908 r
.46822 .2423 .47183 .24659 .47823 .24428 .47462 .23998 Metetra
.663 .741 .908 r
.47462 .23998 .47823 .24428 .48463 .24197 .48104 .23766 Metetra
.663 .74 .908 r
.48104 .23766 .48463 .24197 .49105 .23966 .48747 .23534 Metetra
.663 .74 .908 r
.48747 .23534 .49105 .23966 .49749 .23734 .49392 .23301 Metetra
.663 .74 .908 r
.49392 .23301 .49749 .23734 .50395 .23503 .50038 .23068 Metetra
.662 .74 .907 r
.50038 .23068 .50395 .23503 .51041 .23272 .50686 .22835 Metetra
.662 .739 .907 r
.50686 .22835 .51041 .23272 .5169 .23041 .51335 .22602 Metetra
.661 .738 .907 r
.51335 .22602 .5169 .23041 .5234 .2281 .51986 .2237 Metetra
.66 .738 .907 r
.51986 .2237 .5234 .2281 .52991 .22581 .52638 .22138 Metetra
.659 .736 .907 r
.52638 .22138 .52991 .22581 .53644 .22353 .53292 .21907 Metetra
.658 .735 .906 r
.53292 .21907 .53644 .22353 .54299 .22128 .53948 .21678 Metetra
.657 .733 .906 r
.53948 .21678 .54299 .22128 .54955 .21904 .54605 .2145 Metetra
.655 .731 .905 r
.54605 .2145 .54955 .21904 .55613 .21684 .55264 .21225 Metetra
.652 .728 .904 r
.55264 .21225 .55613 .21684 .56272 .21469 .55925 .21004 Metetra
.649 .724 .903 r
.55925 .21004 .56272 .21469 .56934 .21258 .56587 .20786 Metetra
.646 .72 .902 r
.56587 .20786 .56934 .21258 .57597 .21053 .57251 .20573 Metetra
.642 .715 .9 r
.57251 .20573 .57597 .21053 .58262 .20855 .57917 .20366 Metetra
.638 .709 .898 r
.57917 .20366 .58262 .20855 .58929 .20665 .58585 .20165 Metetra
.633 .702 .896 r
.58585 .20165 .58929 .20665 .59598 .20482 .59254 .19971 Metetra
.628 .696 .893 r
.59254 .19971 .59598 .20482 .60269 .20306 .59926 .19785 Metetra
.624 .689 .89 r
.59926 .19785 .60269 .20306 .60943 .20136 .606 .19605 Metetra
.62 .683 .888 r
.606 .19605 .60943 .20136 .61618 .19971 .61276 .1943 Metetra
.618 .679 .885 r
.61276 .1943 .61618 .19971 .62295 .19806 .61954 .1926 Metetra
.617 .676 .884 r
.61954 .1926 .62295 .19806 .62974 .1964 .62634 .1909 Metetra
.618 .676 .883 r
.62634 .1909 .62974 .1964 .63655 .19466 .63316 .18918 Metetra
.621 .678 .883 r
.63316 .18918 .63655 .19466 .64338 .19283 .63999 .1874 Metetra
.627 .684 .884 r
.63999 .1874 .64338 .19283 .65022 .19084 .64685 .18552 Metetra
.634 .692 .887 r
.64685 .18552 .65022 .19084 .65707 .18869 .65371 .18351 Metetra
.644 .703 .89 r
.65371 .18351 .65707 .18869 .66393 .18635 .66059 .18133 Metetra
.654 .716 .894 r
.66059 .18133 .66393 .18635 .6708 .18383 .66748 .17898 Metetra
.664 .729 .898 r
.66748 .17898 .6708 .18383 .67768 .18115 .67438 .17646 Metetra
.673 .742 .902 r
.67438 .17646 .67768 .18115 .68457 .17834 .68128 .17379 Metetra
.68 .752 .906 r
.68128 .17379 .68457 .17834 .69147 .17545 .6882 .17099 Metetra
.685 .759 .908 r
.6882 .17099 .69147 .17545 .69838 .17253 .69513 .16811 Metetra
.686 .763 .909 r
.69513 .16811 .69838 .17253 .70531 .16963 .70207 .1652 Metetra
.686 .762 .91 r
.70207 .1652 .70531 .16963 .71226 .16677 .70903 .16229 Metetra
.683 .759 .909 r
.70903 .16229 .71226 .16677 .71922 .16399 .71601 .15943 Metetra
.679 .754 .908 r
.71601 .15943 .71922 .16399 .72621 .16128 .723 .15663 Metetra
.674 .748 .906 r
.723 .15663 .72621 .16128 .73322 .15864 .73002 .15389 Metetra
.67 .742 .904 r
.73002 .15389 .73322 .15864 .74026 .15605 .73706 .15123 Metetra
.666 .737 .903 r
.73706 .15123 .74026 .15605 .74731 .15348 .74412 .14861 Metetra
.664 .734 .902 r
.74412 .14861 .74731 .15348 .75438 .15092 .7512 .14602 Metetra
.663 .733 .902 r
.7512 .14602 .75438 .15092 .76146 .14834 .7583 .14344 Metetra
.664 .734 .902 r
.7583 .14344 .76146 .14834 .76857 .14574 .76541 .14085 Metetra
.665 .735 .902 r
.76541 .14085 .76857 .14574 .77568 .14311 .77255 .13823 Metetra
.65 .746 .92 r
.13875 .36201 .14285 .36567 .1485 .36382 .14441 .36015 Metetra
.651 .746 .919 r
.14441 .36015 .1485 .36382 .15416 .36198 .15008 .35826 Metetra
.654 .745 .916 r
.15008 .35826 .15416 .36198 .15983 .36011 .15576 .35632 Metetra
.659 .742 .911 r
.15576 .35632 .15983 .36011 .16552 .3582 .16147 .35431 Metetra
.663 .738 .906 r
.16147 .35431 .16552 .3582 .17123 .35622 .1672 .35223 Metetra
.666 .734 .901 r
.1672 .35223 .17123 .35622 .17697 .35416 .17295 .3501 Metetra
.665 .731 .899 r
.17295 .3501 .17697 .35416 .18272 .35203 .17871 .34797 Metetra
.66 .73 .901 r
.17871 .34797 .18272 .35203 .18849 .34989 .18447 .34591 Metetra
.651 .732 .909 r
.18447 .34591 .18849 .34989 .19426 .3478 .19023 .34399 Metetra
.635 .738 .922 r
.19023 .34399 .19426 .3478 .20003 .34585 .19598 .34229 Metetra
.613 .746 .94 r
.19598 .34229 .20003 .34585 .20579 .34411 .20172 .34083 Metetra
.587 .755 .958 r
.20172 .34083 .20579 .34411 .21154 .34263 .20746 .3396 Metetra
.562 .763 .973 r
.20746 .3396 .21154 .34263 .21728 .34142 .21319 .33854 Metetra
.549 .77 .98 r
.21319 .33854 .21728 .34142 .22302 .3404 .21893 .33754 Metetra
.558 .774 .979 r
.21893 .33754 .22302 .3404 .22876 .33948 .2247 .33646 Metetra
.588 .774 .968 r
.2247 .33646 .22876 .33948 .23453 .3385 .2305 .33514 Metetra
.626 .765 .946 r
.2305 .33514 .23453 .3385 .24034 .3373 .23636 .33348 Metetra
.66 .748 .915 r
.23636 .33348 .24034 .3373 .24619 .33574 .24226 .33138 Metetra
.684 .727 .882 r
.24226 .33138 .24619 .33574 .25209 .33373 .24822 .32883 Metetra
.699 .707 .854 r
.24822 .32883 .25209 .33373 .25805 .33122 .25423 .32586 Metetra
.707 .692 .833 r
.25423 .32586 .25805 .33122 .26406 .32826 .26027 .32256 Metetra
.711 .681 .819 r
.26027 .32256 .26406 .32826 .27012 .32493 .26635 .31904 Metetra
.711 .675 .813 r
.26635 .31904 .27012 .32493 .27619 .32135 .27243 .31542 Metetra
.71 .674 .812 r
.27243 .31542 .27619 .32135 .28229 .31766 .27853 .31182 Metetra
.708 .676 .817 r
.27853 .31182 .28229 .31766 .28839 .31398 .28462 .30833 Metetra
.704 .682 .826 r
.28462 .30833 .28839 .31398 .29449 .3104 .29071 .30499 Metetra
.7 .689 .837 r
.29071 .30499 .29449 .3104 .30059 .307 .2968 .30184 Metetra
.695 .698 .849 r
.2968 .30184 .30059 .307 .30669 .3038 .30288 .29888 Metetra
.689 .707 .861 r
.30288 .29888 .30669 .3038 .31277 .3008 .30896 .2961 Metetra
.684 .715 .872 r
.30896 .2961 .31277 .3008 .31886 .29799 .31504 .29346 Metetra
.679 .722 .882 r
.31504 .29346 .31886 .29799 .32495 .29534 .32113 .29094 Metetra
.675 .728 .889 r
.32113 .29094 .32495 .29534 .33104 .29281 .32722 .2885 Metetra
.672 .732 .895 r
.32722 .2885 .33104 .29281 .33714 .29037 .33333 .28613 Metetra
.67 .735 .899 r
.33333 .28613 .33714 .29037 .34325 .288 .33944 .2838 Metetra
.668 .737 .902 r
.33944 .2838 .34325 .288 .34936 .28567 .34556 .28149 Metetra
.667 .738 .904 r
.34556 .28149 .34936 .28567 .35549 .28337 .3517 .27921 Metetra
.666 .739 .905 r
.3517 .27921 .35549 .28337 .36164 .28109 .35785 .27693 Metetra
.665 .74 .906 r
.35785 .27693 .36164 .28109 .36779 .27883 .36401 .27467 Metetra
.665 .74 .907 r
.36401 .27467 .36779 .27883 .37396 .27656 .37019 .2724 Metetra
.664 .741 .907 r
.37019 .2724 .37396 .27656 .38014 .2743 .37638 .27013 Metetra
.664 .741 .907 r
.37638 .27013 .38014 .2743 .38634 .27204 .38259 .26787 Metetra
.664 .741 .907 r
.38259 .26787 .38634 .27204 .39255 .26977 .38881 .26559 Metetra
.664 .741 .908 r
.38881 .26559 .39255 .26977 .39878 .26751 .39504 .26332 Metetra
.664 .741 .908 r
.39504 .26332 .39878 .26751 .40502 .26524 .40129 .26104 Metetra
.664 .741 .908 r
.40129 .26104 .40502 .26524 .41127 .26297 .40756 .25876 Metetra
.664 .741 .908 r
.40756 .25876 .41127 .26297 .41754 .26069 .41383 .25647 Metetra
.664 .741 .908 r
.41383 .25647 .41754 .26069 .42382 .25841 .42013 .25418 Metetra
.664 .741 .908 r
.42013 .25418 .42382 .25841 .43012 .25612 .42643 .25189 Metetra
.664 .741 .908 r
.42643 .25189 .43012 .25612 .43643 .25383 .43276 .24959 Metetra
.664 .741 .908 r
.43276 .24959 .43643 .25383 .44276 .25153 .43909 .24728 Metetra
.664 .741 .908 r
.43909 .24728 .44276 .25153 .4491 .24923 .44544 .24497 Metetra
.663 .741 .908 r
.44544 .24497 .4491 .24923 .45546 .24693 .45181 .24265 Metetra
.663 .741 .908 r
.45181 .24265 .45546 .24693 .46183 .24462 .45819 .24033 Metetra
.663 .741 .908 r
.45819 .24033 .46183 .24462 .46822 .2423 .46459 .23801 Metetra
.663 .741 .908 r
.46459 .23801 .46822 .2423 .47462 .23998 .471 .23568 Metetra
.663 .741 .908 r
.471 .23568 .47462 .23998 .48104 .23766 .47743 .23334 Metetra
.663 .741 .908 r
.47743 .23334 .48104 .23766 .48747 .23534 .48387 .231 Metetra
.663 .741 .908 r
.48387 .231 .48747 .23534 .49392 .23301 .49033 .22866 Metetra
.663 .74 .908 r
.49033 .22866 .49392 .23301 .50038 .23068 .4968 .22632 Metetra
.663 .74 .908 r
.4968 .22632 .50038 .23068 .50686 .22835 .50329 .22397 Metetra
.662 .74 .908 r
.50329 .22397 .50686 .22835 .51335 .22602 .50979 .22163 Metetra
.662 .739 .907 r
.50979 .22163 .51335 .22602 .51986 .2237 .51631 .21929 Metetra
.661 .738 .907 r
.51631 .21929 .51986 .2237 .52638 .22138 .52284 .21695 Metetra
.66 .738 .907 r
.52284 .21695 .52638 .22138 .53292 .21907 .52939 .21461 Metetra
.659 .736 .907 r
.52939 .21461 .53292 .21907 .53948 .21678 .53596 .21229 Metetra
.658 .735 .906 r
.53596 .21229 .53948 .21678 .54605 .2145 .54254 .20998 Metetra
.657 .733 .906 r
.54254 .20998 .54605 .2145 .55264 .21225 .54914 .20769 Metetra
.655 .731 .905 r
.54914 .20769 .55264 .21225 .55925 .21004 .55575 .20542 Metetra
.652 .728 .904 r
.55575 .20542 .55925 .21004 .56587 .20786 .56239 .20318 Metetra
.65 .724 .903 r
.56239 .20318 .56587 .20786 .57251 .20573 .56903 .20099 Metetra
.646 .72 .902 r
.56903 .20099 .57251 .20573 .57917 .20366 .5757 .19884 Metetra
.643 .715 .9 r
.5757 .19884 .57917 .20366 .58585 .20165 .58239 .19674 Metetra
.638 .71 .899 r
.58239 .19674 .58585 .20165 .59254 .19971 .58909 .19471 Metetra
.634 .704 .896 r
.58909 .19471 .59254 .19971 .59926 .19785 .59582 .19274 Metetra
.63 .697 .894 r
.59582 .19274 .59926 .19785 .606 .19605 .60256 .19083 Metetra
.626 .691 .891 r
.60256 .19083 .606 .19605 .61276 .1943 .60932 .18899 Metetra
.622 .686 .889 r
.60932 .18899 .61276 .1943 .61954 .1926 .61611 .1872 Metetra
.62 .682 .887 r
.61611 .1872 .61954 .1926 .62634 .1909 .62292 .18545 Metetra
.619 .679 .885 r
.62292 .18545 .62634 .1909 .63316 .18918 .62974 .1837 Metetra
.62 .679 .884 r
.62974 .1837 .63316 .18918 .63999 .1874 .63659 .18193 Metetra
.623 .681 .884 r
.63659 .18193 .63999 .1874 .64685 .18552 .64345 .18011 Metetra
.628 .686 .885 r
.64345 .18011 .64685 .18552 .65371 .18351 .65033 .17819 Metetra
.635 .694 .888 r
.65033 .17819 .65371 .18351 .66059 .18133 .65723 .17614 Metetra
.644 .705 .891 r
.65723 .17614 .66059 .18133 .66748 .17898 .66414 .17395 Metetra
.653 .717 .895 r
.66414 .17395 .66748 .17898 .67438 .17646 .67105 .17159 Metetra
.663 .729 .899 r
.67105 .17159 .67438 .17646 .68128 .17379 .67798 .16907 Metetra
.671 .741 .902 r
.67798 .16907 .68128 .17379 .6882 .17099 .68491 .1664 Metetra
.678 .751 .906 r
.68491 .1664 .6882 .17099 .69513 .16811 .69186 .16361 Metetra
.683 .758 .908 r
.69186 .16361 .69513 .16811 .70207 .1652 .69882 .16074 Metetra
.685 .761 .909 r
.69882 .16074 .70207 .1652 .70903 .16229 .70579 .15783 Metetra
.685 .762 .91 r
.70579 .15783 .70903 .16229 .71601 .15943 .71278 .15492 Metetra
.682 .759 .909 r
.71278 .15492 .71601 .15943 .723 .15663 .71978 .15205 Metetra
.679 .754 .908 r
.71978 .15205 .723 .15663 .73002 .15389 .72681 .14923 Metetra
.674 .749 .907 r
.72681 .14923 .73002 .15389 .73706 .15123 .73385 .14647 Metetra
.67 .743 .905 r
.73385 .14647 .73706 .15123 .74412 .14861 .74092 .14378 Metetra
.667 .739 .904 r
.74092 .14378 .74412 .14861 .7512 .14602 .74801 .14114 Metetra
.665 .735 .903 r
.74801 .14114 .7512 .14602 .7583 .14344 .75512 .13852 Metetra
.664 .734 .902 r
.75512 .13852 .7583 .14344 .76541 .14085 .76225 .13592 Metetra
.663 .734 .902 r
.76225 .13592 .76541 .14085 .77255 .13823 .76939 .13331 Metetra
.653 .745 .918 r
.13464 .35831 .13875 .36201 .14441 .36015 .1403 .3564 Metetra
.656 .744 .914 r
.1403 .3564 .14441 .36015 .15008 .35826 .14599 .35443 Metetra
.66 .741 .91 r
.14599 .35443 .15008 .35826 .15576 .35632 .15169 .3524 Metetra
.664 .737 .905 r
.15169 .3524 .15576 .35632 .16147 .35431 .15742 .35031 Metetra
.665 .734 .901 r
.15742 .35031 .16147 .35431 .1672 .35223 .16316 .34818 Metetra
.664 .731 .9 r
.16316 .34818 .1672 .35223 .17295 .3501 .16891 .34606 Metetra
.659 .731 .903 r
.16891 .34606 .17295 .3501 .17871 .34797 .17466 .34403 Metetra
.648 .734 .912 r
.17466 .34403 .17871 .34797 .18447 .34591 .18041 .34214 Metetra
.633 .74 .925 r
.18041 .34214 .18447 .34591 .19023 .34399 .18616 .34046 Metetra
.612 .748 .942 r
.18616 .34046 .19023 .34399 .19598 .34229 .19189 .33901 Metetra
.588 .757 .959 r
.19189 .33901 .19598 .34229 .20172 .34083 .19761 .33777 Metetra
.568 .764 .971 r
.19761 .33777 .20172 .34083 .20746 .3396 .20334 .33666 Metetra
.56 .77 .976 r
.20334 .33666 .20746 .3396 .21319 .33854 .20908 .33558 Metetra
.572 .773 .974 r
.20908 .33558 .21319 .33854 .21893 .33754 .21485 .3344 Metetra
.6 .771 .961 r
.21485 .3344 .21893 .33754 .2247 .33646 .22065 .33298 Metetra
.635 .761 .939 r
.22065 .33298 .2247 .33646 .2305 .33514 .22651 .33122 Metetra
.664 .744 .909 r
.22651 .33122 .2305 .33514 .23636 .33348 .23241 .32906 Metetra
.686 .725 .88 r
.23241 .32906 .23636 .33348 .24226 .33138 .23837 .32647 Metetra
.699 .707 .854 r
.23837 .32647 .24226 .33138 .24822 .32883 .24437 .3235 Metetra
.706 .693 .835 r
.24437 .3235 .24822 .32883 .25423 .32586 .25041 .32023 Metetra
.71 .683 .823 r
.25041 .32023 .25423 .32586 .26027 .32256 .25648 .31676 Metetra
.71 .678 .817 r
.25648 .31676 .26027 .32256 .26635 .31904 .26256 .31322 Metetra
.709 .677 .817 r
.26256 .31322 .26635 .31904 .27243 .31542 .26864 .30969 Metetra
.707 .68 .822 r
.26864 .30969 .27243 .31542 .27853 .31182 .27473 .30627 Metetra
.703 .685 .83 r
.27473 .30627 .27853 .31182 .28462 .30833 .28081 .30299 Metetra
.699 .692 .84 r
.28081 .30299 .28462 .30833 .29071 .30499 .28689 .29989 Metetra
.694 .701 .852 r
.28689 .29989 .29071 .30499 .2968 .30184 .29297 .29697 Metetra
.689 .709 .864 r
.29297 .29697 .2968 .30184 .30288 .29888 .29904 .29421 Metetra
.684 .717 .874 r
.29904 .29421 .30288 .29888 .30896 .2961 .30512 .29158 Metetra
.679 .723 .883 r
.30512 .29158 .30896 .2961 .31504 .29346 .3112 .28906 Metetra
.675 .728 .89 r
.3112 .28906 .31504 .29346 .32113 .29094 .31729 .28663 Metetra
.672 .732 .895 r
.31729 .28663 .32113 .29094 .32722 .2885 .32339 .28425 Metetra
.67 .735 .899 r
.32339 .28425 .32722 .2885 .33333 .28613 .32949 .28192 Metetra
.668 .737 .902 r
.32949 .28192 .33333 .28613 .33944 .2838 .33561 .27961 Metetra
.667 .738 .904 r
.33561 .27961 .33944 .2838 .34556 .28149 .34175 .27732 Metetra
.666 .739 .905 r
.34175 .27732 .34556 .28149 .3517 .27921 .34789 .27504 Metetra
.665 .74 .906 r
.34789 .27504 .3517 .27921 .35785 .27693 .35405 .27277 Metetra
.665 .74 .906 r
.35405 .27277 .35785 .27693 .36401 .27467 .36022 .2705 Metetra
.664 .741 .907 r
.36022 .2705 .36401 .27467 .37019 .2724 .36641 .26822 Metetra
.664 .741 .907 r
.36641 .26822 .37019 .2724 .37638 .27013 .37261 .26595 Metetra
.664 .741 .907 r
.37261 .26595 .37638 .27013 .38259 .26787 .37882 .26368 Metetra
.664 .741 .908 r
.37882 .26368 .38259 .26787 .38881 .26559 .38505 .2614 Metetra
.664 .741 .908 r
.38505 .2614 .38881 .26559 .39504 .26332 .39129 .25912 Metetra
.664 .741 .908 r
.39129 .25912 .39504 .26332 .40129 .26104 .39755 .25683 Metetra
.664 .741 .908 r
.39755 .25683 .40129 .26104 .40756 .25876 .40383 .25454 Metetra
.664 .741 .908 r
.40383 .25454 .40756 .25876 .41383 .25647 .41011 .25224 Metetra
.664 .741 .908 r
.41011 .25224 .41383 .25647 .42013 .25418 .41641 .24994 Metetra
.664 .741 .908 r
.41641 .24994 .42013 .25418 .42643 .25189 .42273 .24764 Metetra
.664 .741 .908 r
.42273 .24764 .42643 .25189 .43276 .24959 .42906 .24532 Metetra
.664 .741 .908 r
.42906 .24532 .43276 .24959 .43909 .24728 .43541 .24301 Metetra
.664 .741 .908 r
.43541 .24301 .43909 .24728 .44544 .24497 .44177 .24069 Metetra
.664 .741 .908 r
.44177 .24069 .44544 .24497 .45181 .24265 .44814 .23836 Metetra
.663 .741 .908 r
.44814 .23836 .45181 .24265 .45819 .24033 .45454 .23603 Metetra
.663 .741 .908 r
.45454 .23603 .45819 .24033 .46459 .23801 .46094 .23369 Metetra
.663 .741 .908 r
.46094 .23369 .46459 .23801 .471 .23568 .46736 .23135 Metetra
.663 .741 .908 r
.46736 .23135 .471 .23568 .47743 .23334 .4738 .22901 Metetra
.663 .741 .908 r
.4738 .22901 .47743 .23334 .48387 .231 .48025 .22666 Metetra
.663 .741 .908 r
.48025 .22666 .48387 .231 .49033 .22866 .48672 .2243 Metetra
.663 .741 .908 r
.48672 .2243 .49033 .22866 .4968 .22632 .4932 .22195 Metetra
.663 .741 .908 r
.4932 .22195 .4968 .22632 .50329 .22397 .4997 .21959 Metetra
.663 .74 .908 r
.4997 .21959 .50329 .22397 .50979 .22163 .50621 .21723 Metetra
.662 .74 .908 r
.50621 .21723 .50979 .22163 .51631 .21929 .51274 .21487 Metetra
.662 .739 .908 r
.51274 .21487 .51631 .21929 .52284 .21695 .51928 .21251 Metetra
.661 .739 .907 r
.51928 .21251 .52284 .21695 .52939 .21461 .52584 .21015 Metetra
.66 .738 .907 r
.52584 .21015 .52939 .21461 .53596 .21229 .53242 .2078 Metetra
.659 .737 .907 r
.53242 .2078 .53596 .21229 .54254 .20998 .53901 .20546 Metetra
.658 .735 .906 r
.53901 .20546 .54254 .20998 .54914 .20769 .54562 .20313 Metetra
.657 .733 .906 r
.54562 .20313 .54914 .20769 .55575 .20542 .55225 .20082 Metetra
.655 .731 .905 r
.55225 .20082 .55575 .20542 .56239 .20318 .55889 .19854 Metetra
.653 .728 .905 r
.55889 .19854 .56239 .20318 .56903 .20099 .56555 .19629 Metetra
.65 .725 .904 r
.56555 .19629 .56903 .20099 .5757 .19884 .57222 .19407 Metetra
.647 .721 .902 r
.57222 .19407 .5757 .19884 .58239 .19674 .57892 .1919 Metetra
.643 .716 .901 r
.57892 .1919 .58239 .19674 .58909 .19471 .58563 .18978 Metetra
.639 .711 .899 r
.58563 .18978 .58909 .19471 .59582 .19274 .59236 .18771 Metetra
.635 .705 .897 r
.59236 .18771 .59582 .19274 .60256 .19083 .59911 .18571 Metetra
.631 .699 .894 r
.59911 .18571 .60256 .19083 .60932 .18899 .60588 .18378 Metetra
.627 .693 .892 r
.60588 .18378 .60932 .18899 .61611 .1872 .61268 .1819 Metetra
.624 .688 .89 r
.61268 .1819 .61611 .1872 .62292 .18545 .61949 .18006 Metetra
.622 .684 .888 r
.61949 .18006 .62292 .18545 .62974 .1837 .62632 .17826 Metetra
.621 .682 .886 r
.62632 .17826 .62974 .1837 .63659 .18193 .63318 .17647 Metetra
.622 .682 .885 r
.63318 .17647 .63659 .18193 .64345 .18011 .64005 .17465 Metetra
.625 .684 .886 r
.64005 .17465 .64345 .18011 .65033 .17819 .64694 .17278 Metetra
.629 .689 .887 r
.64694 .17278 .65033 .17819 .65723 .17614 .65385 .17082 Metetra
.636 .696 .889 r
.65385 .17082 .65723 .17614 .66414 .17395 .66077 .16875 Metetra
.644 .706 .892 r
.66077 .16875 .66414 .17395 .67105 .17159 .6677 .16653 Metetra
.653 .717 .895 r
.6677 .16653 .67105 .17159 .67798 .16907 .67465 .16416 Metetra
.662 .729 .899 r
.67465 .16416 .67798 .16907 .68491 .1664 .68161 .16163 Metetra
.67 .74 .902 r
.68161 .16163 .68491 .1664 .69186 .16361 .68857 .15897 Metetra
.677 .749 .905 r
.68857 .15897 .69186 .16361 .69882 .16074 .69555 .15618 Metetra
.682 .756 .908 r
.69555 .15618 .69882 .16074 .70579 .15783 .70253 .15332 Metetra
.684 .76 .909 r
.70253 .15332 .70579 .15783 .71278 .15492 .70953 .15041 Metetra
.684 .761 .91 r
.70953 .15041 .71278 .15492 .71978 .15205 .71655 .1475 Metetra
.682 .759 .91 r
.71655 .1475 .71978 .15205 .72681 .14923 .72358 .14462 Metetra
.678 .755 .909 r
.72358 .14462 .72681 .14923 .73385 .14647 .73064 .14179 Metetra
.675 .75 .907 r
.73064 .14179 .73385 .14647 .74092 .14378 .73771 .13901 Metetra
.671 .744 .906 r
.73771 .13901 .74092 .14378 .74801 .14114 .74481 .13629 Metetra
.667 .74 .904 r
.74481 .13629 .74801 .14114 .75512 .13852 .75193 .13362 Metetra
.665 .737 .903 r
.75193 .13362 .75512 .13852 .76225 .13592 .75907 .13098 Metetra
.664 .735 .903 r
.75907 .13098 .76225 .13592 .76939 .13331 .76622 .12836 Metetra
.657 .743 .913 r
.13051 .35454 .13464 .35831 .1403 .3564 .13619 .35255 Metetra
.661 .74 .908 r
.13619 .35255 .1403 .3564 .14599 .35443 .14189 .35049 Metetra
.664 .737 .904 r
.14189 .35049 .14599 .35443 .15169 .3524 .14761 .34839 Metetra
.665 .733 .901 r
.14761 .34839 .15169 .3524 .15742 .35031 .15335 .34626 Metetra
.663 .732 .901 r
.15335 .34626 .15742 .35031 .16316 .34818 .15909 .34416 Metetra
.657 .732 .905 r
.15909 .34416 .16316 .34818 .16891 .34606 .16484 .34216 Metetra
.646 .736 .914 r
.16484 .34216 .16891 .34606 .17466 .34403 .17058 .3403 Metetra
.631 .742 .928 r
.17058 .3403 .17466 .34403 .18041 .34214 .17631 .33864 Metetra
.611 .749 .943 r
.17631 .33864 .18041 .34214 .18616 .34046 .18203 .33719 Metetra
.59 .758 .958 r
.18203 .33719 .18616 .34046 .19189 .33901 .18775 .33592 Metetra
.574 .764 .969 r
.18775 .33592 .19189 .33901 .19761 .33777 .19347 .33476 Metetra
.57 .769 .973 r
.19347 .33476 .19761 .33777 .20334 .33666 .19921 .3336 Metetra
.584 .771 .968 r
.19921 .3336 .20334 .33666 .20908 .33558 .20498 .33233 Metetra
.611 .768 .955 r
.20498 .33233 .20908 .33558 .21485 .3344 .21079 .33082 Metetra
.641 .757 .933 r
.21079 .33082 .21485 .3344 .22065 .33298 .21664 .32898 Metetra
.668 .741 .905 r
.21664 .32898 .22065 .33298 .22651 .33122 .22255 .32676 Metetra
.687 .723 .877 r
.22255 .32676 .22651 .33122 .23241 .32906 .2285 .32414 Metetra
.699 .707 .854 r
.2285 .32414 .23241 .32906 .23837 .32647 .2345 .32117 Metetra
.705 .694 .837 r
.2345 .32117 .23837 .32647 .24437 .3235 .24053 .31793 Metetra
.708 .685 .826 r
.24053 .31793 .24437 .3235 .25041 .32023 .24659 .31452 Metetra
.709 .681 .821 r
.24659 .31452 .25041 .32023 .25648 .31676 .25266 .31104 Metetra
.708 .68 .821 r
.25266 .31104 .25648 .31676 .26256 .31322 .25874 .30759 Metetra
.705 .683 .826 r
.25874 .30759 .26256 .31322 .26864 .30969 .26482 .30422 Metetra
.702 .688 .834 r
.26482 .30422 .26864 .30969 .27473 .30627 .27089 .301 Metetra
.698 .695 .844 r
.27089 .301 .27473 .30627 .28081 .30299 .27697 .29795 Metetra
.693 .703 .855 r
.27697 .29795 .28081 .30299 .28689 .29989 .28304 .29505 Metetra
.688 .711 .866 r
.28304 .29505 .28689 .29989 .29297 .29697 .28911 .29231 Metetra
.683 .718 .875 r
.28911 .29231 .29297 .29697 .29904 .29421 .29518 .28969 Metetra
.679 .724 .884 r
.29518 .28969 .29904 .29421 .30512 .29158 .30125 .28718 Metetra
.675 .729 .89 r
.30125 .28718 .30512 .29158 .3112 .28906 .30734 .28475 Metetra
.672 .732 .895 r
.30734 .28475 .3112 .28906 .31729 .28663 .31343 .28237 Metetra
.67 .735 .899 r
.31343 .28237 .31729 .28663 .32339 .28425 .31953 .28003 Metetra
.668 .737 .902 r
.31953 .28003 .32339 .28425 .32949 .28192 .32565 .27772 Metetra
.667 .738 .904 r
.32565 .27772 .32949 .28192 .33561 .27961 .33177 .27542 Metetra
.666 .739 .905 r
.33177 .27542 .33561 .27961 .34175 .27732 .33791 .27314 Metetra
.665 .74 .906 r
.33791 .27314 .34175 .27732 .34789 .27504 .34407 .27086 Metetra
.665 .74 .906 r
.34407 .27086 .34789 .27504 .35405 .27277 .35023 .26858 Metetra
.664 .741 .907 r
.35023 .26858 .35405 .27277 .36022 .2705 .35641 .26631 Metetra
.664 .741 .907 r
.35641 .26631 .36022 .2705 .36641 .26822 .36261 .26403 Metetra
.664 .741 .907 r
.36261 .26403 .36641 .26822 .37261 .26595 .36882 .26175 Metetra
.664 .741 .907 r
.36882 .26175 .37261 .26595 .37882 .26368 .37504 .25947 Metetra
.664 .741 .908 r
.37504 .25947 .37882 .26368 .38505 .2614 .38128 .25718 Metetra
.664 .741 .908 r
.38128 .25718 .38505 .2614 .39129 .25912 .38753 .25489 Metetra
.664 .741 .908 r
.38753 .25489 .39129 .25912 .39755 .25683 .3938 .25259 Metetra
.664 .741 .908 r
.3938 .25259 .39755 .25683 .40383 .25454 .40008 .25029 Metetra
.664 .741 .908 r
.40008 .25029 .40383 .25454 .41011 .25224 .40637 .24799 Metetra
.664 .741 .908 r
.40637 .24799 .41011 .25224 .41641 .24994 .41269 .24568 Metetra
.664 .741 .908 r
.41269 .24568 .41641 .24994 .42273 .24764 .41901 .24336 Metetra
.664 .741 .908 r
.41901 .24336 .42273 .24764 .42906 .24532 .42535 .24104 Metetra
.664 .741 .908 r
.42535 .24104 .42906 .24532 .43541 .24301 .43171 .23872 Metetra
.664 .741 .908 r
.43171 .23872 .43541 .24301 .44177 .24069 .43808 .23638 Metetra
.664 .741 .908 r
.43808 .23638 .44177 .24069 .44814 .23836 .44446 .23405 Metetra
.663 .741 .908 r
.44446 .23405 .44814 .23836 .45454 .23603 .45086 .23171 Metetra
.663 .741 .908 r
.45086 .23171 .45454 .23603 .46094 .23369 .45728 .22936 Metetra
.663 .741 .908 r
.45728 .22936 .46094 .23369 .46736 .23135 .46371 .22701 Metetra
.663 .741 .908 r
.46371 .22701 .46736 .23135 .4738 .22901 .47016 .22465 Metetra
.663 .741 .908 r
.47016 .22465 .4738 .22901 .48025 .22666 .47662 .22229 Metetra
.663 .741 .908 r
.47662 .22229 .48025 .22666 .48672 .2243 .4831 .21992 Metetra
.663 .741 .908 r
.4831 .21992 .48672 .2243 .4932 .22195 .48959 .21755 Metetra
.663 .741 .908 r
.48959 .21755 .4932 .22195 .4997 .21959 .49609 .21518 Metetra
.663 .74 .908 r
.49609 .21518 .4997 .21959 .50621 .21723 .50262 .2128 Metetra
.662 .74 .908 r
.50262 .2128 .50621 .21723 .51274 .21487 .50916 .21043 Metetra
.662 .74 .907 r
.50916 .21043 .51274 .21487 .51928 .21251 .51571 .20805 Metetra
.662 .739 .907 r
.51571 .20805 .51928 .21251 .52584 .21015 .52228 .20568 Metetra
.661 .738 .907 r
.52228 .20568 .52584 .21015 .53242 .2078 .52887 .2033 Metetra
.66 .738 .907 r
.52887 .2033 .53242 .2078 .53901 .20546 .53547 .20094 Metetra
.659 .736 .907 r
.53547 .20094 .53901 .20546 .54562 .20313 .54209 .19858 Metetra
.658 .735 .906 r
.54209 .19858 .54562 .20313 .55225 .20082 .54872 .19624 Metetra
.657 .733 .906 r
.54872 .19624 .55225 .20082 .55889 .19854 .55537 .19391 Metetra
.655 .731 .905 r
.55537 .19391 .55889 .19854 .56555 .19629 .56204 .19161 Metetra
.653 .728 .905 r
.56204 .19161 .56555 .19629 .57222 .19407 .56873 .18934 Metetra
.65 .725 .904 r
.56873 .18934 .57222 .19407 .57892 .1919 .57543 .1871 Metetra
.647 .721 .902 r
.57543 .1871 .57892 .1919 .58563 .18978 .58215 .18491 Metetra
.644 .717 .901 r
.58215 .18491 .58563 .18978 .59236 .18771 .58889 .18276 Metetra
.64 .711 .899 r
.58889 .18276 .59236 .18771 .59911 .18571 .59565 .18067 Metetra
.636 .706 .897 r
.59565 .18067 .59911 .18571 .60588 .18378 .60243 .17864 Metetra
.632 .7 .895 r
.60243 .17864 .60588 .18378 .61268 .1819 .60923 .17667 Metetra
.628 .695 .893 r
.60923 .17667 .61268 .1819 .61949 .18006 .61605 .17475 Metetra
.625 .69 .891 r
.61605 .17475 .61949 .18006 .62632 .17826 .62289 .17288 Metetra
.623 .687 .889 r
.62289 .17288 .62632 .17826 .63318 .17647 .62975 .17103 Metetra
.623 .684 .887 r
.62975 .17103 .63318 .17647 .64005 .17465 .63663 .16919 Metetra
.623 .684 .887 r
.63663 .16919 .64005 .17465 .64694 .17278 .64353 .16733 Metetra
.626 .686 .887 r
.64353 .16733 .64694 .17278 .65385 .17082 .65045 .16542 Metetra
.631 .691 .888 r
.65045 .16542 .65385 .17082 .66077 .16875 .65739 .16342 Metetra
.637 .698 .89 r
.65739 .16342 .66077 .16875 .6677 .16653 .66434 .16132 Metetra
.645 .707 .892 r
.66434 .16132 .6677 .16653 .67465 .16416 .6713 .15908 Metetra
.653 .717 .896 r
.6713 .15908 .67465 .16416 .68161 .16163 .67827 .15669 Metetra
.661 .728 .899 r
.67827 .15669 .68161 .16163 .68857 .15897 .68526 .15416 Metetra
.669 .739 .902 r
.68526 .15416 .68857 .15897 .69555 .15618 .69225 .15149 Metetra
.676 .748 .905 r
.69225 .15149 .69555 .15618 .70253 .15332 .69926 .14872 Metetra
.68 .755 .908 r
.69926 .14872 .70253 .15332 .70953 .15041 .70627 .14586 Metetra
.683 .759 .909 r
.70627 .14586 .70953 .15041 .71655 .1475 .7133 .14295 Metetra
.683 .76 .91 r
.7133 .14295 .71655 .1475 .72358 .14462 .72035 .14004 Metetra
.681 .758 .91 r
.72035 .14004 .72358 .14462 .73064 .14179 .72741 .13715 Metetra
.678 .755 .909 r
.72741 .13715 .73064 .14179 .73771 .13901 .7345 .1343 Metetra
.675 .75 .908 r
.7345 .1343 .73771 .13901 .74481 .13629 .7416 .1315 Metetra
.671 .745 .906 r
.7416 .1315 .74481 .13629 .75193 .13362 .74873 .12876 Metetra
.668 .741 .905 r
.74873 .12876 .75193 .13362 .75907 .13098 .75588 .12607 Metetra
.665 .737 .904 r
.75588 .12607 .75907 .13098 .76622 .12836 .76304 .1234 Metetra
.662 .739 .907 r
.12638 .35065 .13051 .35454 .13619 .35255 .13208 .34859 Metetra
.664 .736 .903 r
.13208 .34859 .13619 .35255 .14189 .35049 .13779 .34648 Metetra
.664 .734 .901 r
.13779 .34648 .14189 .35049 .14761 .34839 .14352 .34436 Metetra
.661 .732 .902 r
.14352 .34436 .14761 .34839 .15335 .34626 .14925 .34227 Metetra
.655 .734 .907 r
.14925 .34227 .15335 .34626 .15909 .34416 .15499 .34029 Metetra
.644 .737 .917 r
.15499 .34029 .15909 .34416 .16484 .34216 .16072 .33846 Metetra
.629 .743 .93 r
.16072 .33846 .16484 .34216 .17058 .3403 .16644 .33681 Metetra
.611 .751 .945 r
.16644 .33681 .17058 .3403 .17631 .33864 .17216 .33536 Metetra
.592 .758 .958 r
.17216 .33536 .17631 .33864 .18203 .33719 .17787 .33406 Metetra
.58 .765 .967 r
.17787 .33406 .18203 .33719 .18775 .33592 .18359 .33285 Metetra
.579 .769 .969 r
.18359 .33285 .18775 .33592 .19347 .33476 .18933 .33162 Metetra
.594 .769 .963 r
.18933 .33162 .19347 .33476 .19921 .3336 .1951 .33026 Metetra
.619 .765 .949 r
.1951 .33026 .19921 .3336 .20498 .33233 .2009 .32867 Metetra
.647 .754 .927 r
.2009 .32867 .20498 .33233 .21079 .33082 .20676 .32676 Metetra
.67 .739 .901 r
.20676 .32676 .21079 .33082 .21664 .32898 .21266 .32448 Metetra
.687 .722 .876 r
.21266 .32448 .21664 .32898 .22255 .32676 .21861 .32184 Metetra
.698 .707 .855 r
.21861 .32184 .22255 .32676 .2285 .32414 .2246 .31888 Metetra
.705 .696 .839 r
.2246 .31888 .2285 .32414 .2345 .32117 .23063 .31567 Metetra
.707 .688 .829 r
.23063 .31567 .2345 .32117 .24053 .31793 .23668 .31231 Metetra
.708 .684 .825 r
.23668 .31231 .24053 .31793 .24659 .31452 .24274 .30889 Metetra
.707 .684 .825 r
.24274 .30889 .24659 .31452 .25266 .31104 .24882 .3055 Metetra
.704 .686 .83 r
.24882 .3055 .25266 .31104 .25874 .30759 .25489 .3022 Metetra
.701 .691 .838 r
.25489 .3022 .25874 .30759 .26482 .30422 .26096 .29903 Metetra
.697 .698 .847 r
.26096 .29903 .26482 .30422 .27089 .301 .26702 .29601 Metetra
.692 .705 .857 r
.26702 .29601 .27089 .301 .27697 .29795 .27309 .29314 Metetra
.687 .712 .868 r
.27309 .29314 .27697 .29795 .28304 .29505 .27915 .29042 Metetra
.683 .719 .877 r
.27915 .29042 .28304 .29505 .28911 .29231 .28522 .28781 Metetra
.678 .725 .885 r
.28522 .28781 .28911 .29231 .29518 .28969 .29129 .2853 Metetra
.675 .729 .891 r
.29129 .2853 .29518 .28969 .30125 .28718 .29736 .28286 Metetra
.672 .733 .896 r
.29736 .28286 .30125 .28718 .30734 .28475 .30345 .28048 Metetra
.67 .735 .899 r
.30345 .28048 .30734 .28475 .31343 .28237 .30955 .27814 Metetra
.668 .737 .902 r
.30955 .27814 .31343 .28237 .31953 .28003 .31566 .27582 Metetra
.667 .738 .904 r
.31566 .27582 .31953 .28003 .32565 .27772 .32178 .27353 Metetra
.666 .739 .905 r
.32178 .27353 .32565 .27772 .33177 .27542 .32791 .27124 Metetra
.665 .74 .906 r
.32791 .27124 .33177 .27542 .33791 .27314 .33406 .26895 Metetra
.665 .74 .906 r
.33406 .26895 .33791 .27314 .34407 .27086 .34022 .26667 Metetra
.664 .741 .907 r
.34022 .26667 .34407 .27086 .35023 .26858 .3464 .26439 Metetra
.664 .741 .907 r
.3464 .26439 .35023 .26858 .35641 .26631 .35259 .26211 Metetra
.664 .741 .907 r
.35259 .26211 .35641 .26631 .36261 .26403 .35879 .25983 Metetra
.664 .741 .908 r
.35879 .25983 .36261 .26403 .36882 .26175 .36501 .25754 Metetra
.664 .741 .908 r
.36501 .25754 .36882 .26175 .37504 .25947 .37124 .25525 Metetra
.664 .741 .908 r
.37124 .25525 .37504 .25947 .38128 .25718 .37749 .25295 Metetra
.664 .741 .908 r
.37749 .25295 .38128 .25718 .38753 .25489 .38375 .25065 Metetra
.664 .741 .908 r
.38375 .25065 .38753 .25489 .3938 .25259 .39002 .24835 Metetra
.664 .741 .908 r
.39002 .24835 .3938 .25259 .40008 .25029 .39632 .24604 Metetra
.664 .741 .908 r
.39632 .24604 .40008 .25029 .40637 .24799 .40262 .24372 Metetra
.664 .741 .908 r
.40262 .24372 .40637 .24799 .41269 .24568 .40894 .2414 Metetra
.664 .741 .908 r
.40894 .2414 .41269 .24568 .41901 .24336 .41528 .23907 Metetra
.664 .741 .908 r
.41528 .23907 .41901 .24336 .42535 .24104 .42163 .23674 Metetra
.664 .741 .908 r
.42163 .23674 .42535 .24104 .43171 .23872 .42799 .23441 Metetra
.664 .741 .908 r
.42799 .23441 .43171 .23872 .43808 .23638 .43437 .23207 Metetra
.664 .741 .908 r
.43437 .23207 .43808 .23638 .44446 .23405 .44077 .22972 Metetra
.664 .741 .908 r
.44077 .22972 .44446 .23405 .45086 .23171 .44718 .22737 Metetra
.663 .741 .908 r
.44718 .22737 .45086 .23171 .45728 .22936 .4536 .22501 Metetra
.663 .741 .908 r
.4536 .22501 .45728 .22936 .46371 .22701 .46004 .22265 Metetra
.663 .741 .908 r
.46004 .22265 .46371 .22701 .47016 .22465 .4665 .22028 Metetra
.663 .741 .908 r
.4665 .22028 .47016 .22465 .47662 .22229 .47297 .2179 Metetra
.663 .741 .908 r
.47297 .2179 .47662 .22229 .4831 .21992 .47946 .21553 Metetra
.663 .741 .908 r
.47946 .21553 .4831 .21992 .48959 .21755 .48596 .21315 Metetra
.663 .741 .908 r
.48596 .21315 .48959 .21755 .49609 .21518 .49248 .21076 Metetra
.663 .741 .908 r
.49248 .21076 .49609 .21518 .50262 .2128 .49901 .20837 Metetra
.663 .74 .908 r
.49901 .20837 .50262 .2128 .50916 .21043 .50556 .20598 Metetra
.662 .74 .908 r
.50556 .20598 .50916 .21043 .51571 .20805 .51212 .20359 Metetra
.662 .74 .908 r
.51212 .20359 .51571 .20805 .52228 .20568 .5187 .20119 Metetra
.662 .739 .907 r
.5187 .20119 .52228 .20568 .52887 .2033 .5253 .1988 Metetra
.661 .739 .907 r
.5253 .1988 .52887 .2033 .53547 .20094 .53191 .19641 Metetra
.66 .738 .907 r
.53191 .19641 .53547 .20094 .54209 .19858 .53854 .19403 Metetra
.659 .737 .907 r
.53854 .19403 .54209 .19858 .54872 .19624 .54519 .19166 Metetra
.658 .735 .906 r
.54519 .19166 .54872 .19624 .55537 .19391 .55185 .1893 Metetra
.657 .733 .906 r
.55185 .1893 .55537 .19391 .56204 .19161 .55852 .18696 Metetra
.655 .731 .905 r
.55852 .18696 .56204 .19161 .56873 .18934 .56522 .18464 Metetra
.653 .728 .905 r
.56522 .18464 .56873 .18934 .57543 .1871 .57193 .18234 Metetra
.65 .725 .904 r
.57193 .18234 .57543 .1871 .58215 .18491 .57866 .18009 Metetra
.647 .721 .902 r
.57866 .18009 .58215 .18491 .58889 .18276 .58541 .17787 Metetra
.644 .717 .901 r
.58541 .17787 .58889 .18276 .59565 .18067 .59218 .1757 Metetra
.64 .712 .899 r
.59218 .1757 .59565 .18067 .60243 .17864 .59896 .17359 Metetra
.637 .707 .898 r
.59896 .17359 .60243 .17864 .60923 .17667 .60577 .17153 Metetra
.633 .702 .896 r
.60577 .17153 .60923 .17667 .61605 .17475 .6126 .16952 Metetra
.63 .697 .893 r
.6126 .16952 .61605 .17475 .62289 .17288 .61945 .16757 Metetra
.627 .692 .891 r
.61945 .16757 .62289 .17288 .62975 .17103 .62631 .16565 Metetra
.625 .689 .89 r
.62631 .16565 .62975 .17103 .63663 .16919 .6332 .16376 Metetra
.624 .687 .888 r
.6332 .16376 .63663 .16919 .64353 .16733 .64011 .16188 Metetra
.625 .687 .888 r
.64011 .16188 .64353 .16733 .65045 .16542 .64704 .15998 Metetra
.628 .689 .888 r
.64704 .15998 .65045 .16542 .65739 .16342 .65399 .15802 Metetra
.632 .693 .889 r
.65399 .15802 .65739 .16342 .66434 .16132 .66095 .15599 Metetra
.638 .7 .891 r
.66095 .15599 .66434 .16132 .6713 .15908 .66793 .15385 Metetra
.645 .708 .893 r
.66793 .15385 .6713 .15908 .67827 .15669 .67492 .15159 Metetra
.653 .718 .896 r
.67492 .15159 .67827 .15669 .68526 .15416 .68192 .14919 Metetra
.661 .728 .899 r
.68192 .14919 .68526 .15416 .69225 .15149 .68894 .14665 Metetra
.668 .738 .903 r
.68894 .14665 .69225 .15149 .69926 .14872 .69596 .14398 Metetra
.674 .747 .905 r
.69596 .14398 .69926 .14872 .70627 .14586 .70299 .14121 Metetra
.679 .754 .908 r
.70299 .14121 .70627 .14586 .7133 .14295 .71004 .13835 Metetra
.681 .758 .909 r
.71004 .13835 .7133 .14295 .72035 .14004 .7171 .13545 Metetra
.682 .759 .91 r
.7171 .13545 .72035 .14004 .72741 .13715 .72418 .13253 Metetra
.681 .758 .91 r
.72418 .13253 .72741 .13715 .7345 .1343 .73127 .12963 Metetra
.678 .755 .909 r
.73127 .12963 .7345 .1343 .7416 .1315 .73839 .12677 Metetra
.675 .751 .908 r
.73839 .12677 .7416 .1315 .74873 .12876 .74552 .12395 Metetra
.671 .746 .907 r
.74552 .12395 .74873 .12876 .75588 .12607 .75267 .12119 Metetra
.668 .742 .905 r
.75267 .12119 .75588 .12607 .76304 .1234 .75985 .11846 Metetra
.664 .736 .903 r
.12224 .34668 .12638 .35065 .13208 .34859 .12795 .34457 Metetra
.664 .734 .902 r
.12795 .34457 .13208 .34859 .13779 .34648 .13367 .34246 Metetra
.66 .733 .904 r
.13367 .34246 .13779 .34648 .14352 .34436 .1394 .34039 Metetra
.653 .735 .909 r
.1394 .34039 .14352 .34436 .14925 .34227 .14512 .33843 Metetra
.642 .739 .919 r
.14512 .33843 .14925 .34227 .15499 .34029 .15084 .33662 Metetra
.628 .745 .932 r
.15084 .33662 .15499 .34029 .16072 .33846 .15656 .33498 Metetra
.611 .752 .945 r
.15656 .33498 .16072 .33846 .16644 .33681 .16227 .33352 Metetra
.595 .759 .957 r
.16227 .33352 .16644 .33681 .17216 .33536 .16798 .33219 Metetra
.585 .764 .964 r
.16798 .33219 .17216 .33536 .17787 .33406 .17369 .33093 Metetra
.588 .768 .965 r
.17369 .33093 .17787 .33406 .18359 .33285 .17943 .32963 Metetra
.603 .767 .958 r
.17943 .32963 .18359 .33285 .18933 .33162 .18519 .32819 Metetra
.626 .762 .944 r
.18519 .32819 .18933 .33162 .1951 .33026 .191 .32653 Metetra
.651 .751 .923 r
.191 .32653 .1951 .33026 .2009 .32867 .19685 .32455 Metetra
.672 .737 .898 r
.19685 .32455 .2009 .32867 .20676 .32676 .20276 .32223 Metetra
.688 .721 .875 r
.20276 .32223 .20676 .32676 .21266 .32448 .2087 .31957 Metetra
.698 .708 .855 r
.2087 .31957 .21266 .32448 .21861 .32184 .21469 .31662 Metetra
.704 .697 .841 r
.21469 .31662 .21861 .32184 .2246 .31888 .22071 .31344 Metetra
.706 .69 .832 r
.22071 .31344 .2246 .31888 .23063 .31567 .22675 .31013 Metetra
.707 .687 .828 r
.22675 .31013 .23063 .31567 .23668 .31231 .23281 .30677 Metetra
.706 .687 .829 r
.23281 .30677 .23668 .31231 .24274 .30889 .23887 .30343 Metetra
.703 .689 .834 r
.23887 .30343 .24274 .30889 .24882 .3055 .24494 .30018 Metetra
.7 .694 .841 r
.24494 .30018 .24882 .3055 .25489 .3022 .251 .29705 Metetra
.696 .7 .85 r
.251 .29705 .25489 .3022 .26096 .29903 .25706 .29407 Metetra
.691 .707 .86 r
.25706 .29407 .26096 .29903 .26702 .29601 .26312 .29123 Metetra
.687 .714 .869 r
.26312 .29123 .26702 .29601 .27309 .29314 .26917 .28852 Metetra
.682 .72 .878 r
.26917 .28852 .27309 .29314 .27915 .29042 .27523 .28592 Metetra
.678 .725 .885 r
.27523 .28592 .27915 .29042 .28522 .28781 .2813 .28341 Metetra
.675 .729 .891 r
.2813 .28341 .28522 .28781 .29129 .2853 .28737 .28098 Metetra
.672 .733 .896 r
.28737 .28098 .29129 .2853 .29736 .28286 .29345 .27859 Metetra
.669 .735 .899 r
.29345 .27859 .29736 .28286 .30345 .28048 .29955 .27625 Metetra
.668 .737 .902 r
.29955 .27625 .30345 .28048 .30955 .27814 .30565 .27393 Metetra
.667 .738 .904 r
.30565 .27393 .30955 .27814 .31566 .27582 .31177 .27162 Metetra
.666 .739 .905 r
.31177 .27162 .31566 .27582 .32178 .27353 .31789 .26933 Metetra
.665 .74 .906 r
.31789 .26933 .32178 .27353 .32791 .27124 .32404 .26704 Metetra
.665 .74 .906 r
.32404 .26704 .32791 .27124 .33406 .26895 .33019 .26476 Metetra
.664 .741 .907 r
.33019 .26476 .33406 .26895 .34022 .26667 .33636 .26247 Metetra
.664 .741 .907 r
.33636 .26247 .34022 .26667 .3464 .26439 .34255 .26018 Metetra
.664 .741 .907 r
.34255 .26018 .3464 .26439 .35259 .26211 .34874 .25789 Metetra
.664 .741 .907 r
.34874 .25789 .35259 .26211 .35879 .25983 .35496 .2556 Metetra
.664 .741 .908 r
.35496 .2556 .35879 .25983 .36501 .25754 .36118 .25331 Metetra
.664 .741 .908 r
.36118 .25331 .36501 .25754 .37124 .25525 .36742 .25101 Metetra
.664 .741 .908 r
.36742 .25101 .37124 .25525 .37749 .25295 .37368 .2487 Metetra
.664 .741 .908 r
.37368 .2487 .37749 .25295 .38375 .25065 .37995 .24639 Metetra
.664 .741 .908 r
.37995 .24639 .38375 .25065 .39002 .24835 .38624 .24408 Metetra
.664 .741 .908 r
.38624 .24408 .39002 .24835 .39632 .24604 .39254 .24176 Metetra
.664 .741 .908 r
.39254 .24176 .39632 .24604 .40262 .24372 .39885 .23943 Metetra
.664 .741 .908 r
.39885 .23943 .40262 .24372 .40894 .2414 .40518 .2371 Metetra
.664 .741 .908 r
.40518 .2371 .40894 .2414 .41528 .23907 .41152 .23477 Metetra
.664 .741 .908 r
.41152 .23477 .41528 .23907 .42163 .23674 .41788 .23242 Metetra
.664 .741 .908 r
.41788 .23242 .42163 .23674 .42799 .23441 .42426 .23008 Metetra
.664 .741 .908 r
.42426 .23008 .42799 .23441 .43437 .23207 .43065 .22773 Metetra
.664 .741 .908 r
.43065 .22773 .43437 .23207 .44077 .22972 .43705 .22537 Metetra
.664 .741 .908 r
.43705 .22537 .44077 .22972 .44718 .22737 .44347 .22301 Metetra
.664 .741 .908 r
.44347 .22301 .44718 .22737 .4536 .22501 .44991 .22064 Metetra
.663 .741 .908 r
.44991 .22064 .4536 .22501 .46004 .22265 .45636 .21826 Metetra
.663 .741 .908 r
.45636 .21826 .46004 .22265 .4665 .22028 .46282 .21589 Metetra
.663 .741 .908 r
.46282 .21589 .4665 .22028 .47297 .2179 .4693 .2135 Metetra
.663 .741 .908 r
.4693 .2135 .47297 .2179 .47946 .21553 .4758 .21111 Metetra
.663 .741 .908 r
.4758 .21111 .47946 .21553 .48596 .21315 .48231 .20872 Metetra
.663 .741 .908 r
.48231 .20872 .48596 .21315 .49248 .21076 .48884 .20632 Metetra
.663 .741 .908 r
.48884 .20632 .49248 .21076 .49901 .20837 .49538 .20392 Metetra
.663 .741 .908 r
.49538 .20392 .49901 .20837 .50556 .20598 .50194 .20151 Metetra
.663 .74 .908 r
.50194 .20151 .50556 .20598 .51212 .20359 .50852 .19911 Metetra
.662 .74 .908 r
.50852 .19911 .51212 .20359 .5187 .20119 .51511 .1967 Metetra
.662 .74 .908 r
.51511 .1967 .5187 .20119 .5253 .1988 .52172 .19429 Metetra
.662 .739 .907 r
.52172 .19429 .5253 .1988 .53191 .19641 .52834 .19188 Metetra
.661 .738 .907 r
.52834 .19188 .53191 .19641 .53854 .19403 .53498 .18948 Metetra
.66 .738 .907 r
.53498 .18948 .53854 .19403 .54519 .19166 .54163 .18708 Metetra
.659 .736 .907 r
.54163 .18708 .54519 .19166 .55185 .1893 .5483 .18469 Metetra
.658 .735 .906 r
.5483 .18469 .55185 .1893 .55852 .18696 .55499 .18231 Metetra
.657 .733 .906 r
.55499 .18231 .55852 .18696 .56522 .18464 .5617 .17995 Metetra
.655 .731 .905 r
.5617 .17995 .56522 .18464 .57193 .18234 .56842 .17761 Metetra
.653 .729 .905 r
.56842 .17761 .57193 .18234 .57866 .18009 .57516 .1753 Metetra
.65 .725 .904 r
.57516 .1753 .57866 .18009 .58541 .17787 .58192 .17303 Metetra
.648 .722 .903 r
.58192 .17303 .58541 .17787 .59218 .1757 .58869 .17079 Metetra
.644 .718 .901 r
.58869 .17079 .59218 .1757 .59896 .17359 .59549 .1686 Metetra
.641 .713 .9 r
.59549 .1686 .59896 .17359 .60577 .17153 .6023 .16645 Metetra
.637 .708 .898 r
.6023 .16645 .60577 .17153 .6126 .16952 .60914 .16436 Metetra
.634 .703 .896 r
.60914 .16436 .6126 .16952 .61945 .16757 .61599 .16233 Metetra
.631 .698 .894 r
.61599 .16233 .61945 .16757 .62631 .16565 .62287 .16034 Metetra
.628 .694 .892 r
.62287 .16034 .62631 .16565 .6332 .16376 .62976 .15838 Metetra
.626 .691 .891 r
.62976 .15838 .6332 .16376 .64011 .16188 .63668 .15645 Metetra
.626 .689 .889 r
.63668 .15645 .64011 .16188 .64704 .15998 .64362 .15453 Metetra
.627 .689 .889 r
.64362 .15453 .64704 .15998 .65399 .15802 .65057 .15258 Metetra
.629 .691 .889 r
.65057 .15258 .65399 .15802 .66095 .15599 .65755 .15059 Metetra
.633 .695 .89 r
.65755 .15059 .66095 .15599 .66793 .15385 .66454 .14852 Metetra
.639 .701 .891 r
.66454 .14852 .66793 .15385 .67492 .15159 .67155 .14635 Metetra
.645 .709 .894 r
.67155 .14635 .67492 .15159 .68192 .14919 .67857 .14407 Metetra
.653 .719 .897 r
.67857 .14407 .68192 .14919 .68894 .14665 .6856 .14165 Metetra
.66 .728 .9 r
.6856 .14165 .68894 .14665 .69596 .14398 .69264 .1391 Metetra
.667 .738 .903 r
.69264 .1391 .69596 .14398 .70299 .14121 .69969 .13643 Metetra
.673 .746 .905 r
.69969 .13643 .70299 .14121 .71004 .13835 .70676 .13365 Metetra
.678 .753 .907 r
.70676 .13365 .71004 .13835 .7171 .13545 .71384 .1308 Metetra
.68 .757 .909 r
.71384 .1308 .7171 .13545 .72418 .13253 .72093 .1279 Metetra
.681 .758 .91 r
.72093 .1279 .72418 .13253 .73127 .12963 .72803 .12498 Metetra
.68 .758 .91 r
.72803 .12498 .73127 .12963 .73839 .12677 .73516 .12207 Metetra
.678 .755 .909 r
.73516 .12207 .73839 .12677 .74552 .12395 .7423 .11919 Metetra
.675 .751 .908 r
.7423 .11919 .74552 .12395 .75267 .12119 .74946 .11635 Metetra
.672 .747 .907 r
.74946 .11635 .75267 .12119 .75985 .11846 .75665 .11356 Metetra
.663 .734 .903 r
.11809 .34267 .12224 .34668 .12795 .34457 .1238 .34057 Metetra
.659 .734 .905 r
.1238 .34057 .12795 .34457 .13367 .34246 .12952 .33852 Metetra
.652 .736 .911 r
.12952 .33852 .13367 .34246 .1394 .34039 .13524 .33658 Metetra
.641 .74 .921 r
.13524 .33658 .1394 .34039 .14512 .33843 .14095 .33478 Metetra
.627 .746 .933 r
.14095 .33478 .14512 .33843 .15084 .33662 .14666 .33315 Metetra
.611 .753 .945 r
.14666 .33315 .15084 .33662 .15656 .33498 .15236 .33167 Metetra
.598 .759 .956 r
.15236 .33167 .15656 .33498 .16227 .33352 .15806 .33031 Metetra
.591 .764 .962 r
.15806 .33031 .16227 .33352 .16798 .33219 .16377 .32899 Metetra
.595 .766 .961 r
.16377 .32899 .16798 .33219 .17369 .33093 .16951 .32763 Metetra
.61 .765 .954 r
.16951 .32763 .17369 .33093 .17943 .32963 .17527 .32612 Metetra
.632 .759 .939 r
.17527 .32612 .17943 .32963 .18519 .32819 .18108 .32439 Metetra
.655 .749 .919 r
.18108 .32439 .18519 .32819 .191 .32653 .18693 .32235 Metetra
.674 .735 .896 r
.18693 .32235 .191 .32653 .19685 .32455 .19283 .32 Metetra
.688 .721 .874 r
.19283 .32 .19685 .32455 .20276 .32223 .19878 .31733 Metetra
.697 .708 .856 r
.19878 .31733 .20276 .32223 .2087 .31957 .20476 .31438 Metetra
.703 .698 .843 r
.20476 .31438 .2087 .31957 .21469 .31662 .21077 .31124 Metetra
.705 .692 .835 r
.21077 .31124 .21469 .31662 .22071 .31344 .21681 .30797 Metetra
.706 .689 .832 r
.21681 .30797 .22071 .31344 .22675 .31013 .22285 .30466 Metetra
.704 .689 .833 r
.22285 .30466 .22675 .31013 .23281 .30677 .22891 .30137 Metetra
.702 .692 .837 r
.22891 .30137 .23281 .30677 .23887 .30343 .23497 .29817 Metetra
.699 .696 .844 r
.23497 .29817 .23887 .30343 .24494 .30018 .24102 .29509 Metetra
.695 .702 .853 r
.24102 .29509 .24494 .30018 .251 .29705 .24707 .29213 Metetra
.69 .708 .862 r
.24707 .29213 .251 .29705 .25706 .29407 .25313 .28931 Metetra
.686 .715 .871 r
.25313 .28931 .25706 .29407 .26312 .29123 .25918 .28662 Metetra
.682 .721 .879 r
.25918 .28662 .26312 .29123 .26917 .28852 .26523 .28403 Metetra
.678 .726 .886 r
.26523 .28403 .26917 .28852 .27523 .28592 .27129 .28152 Metetra
.674 .73 .892 r
.27129 .28152 .27523 .28592 .2813 .28341 .27736 .27909 Metetra
.672 .733 .896 r
.27736 .27909 .2813 .28341 .28737 .28098 .28344 .2767 Metetra
.669 .735 .899 r
.28344 .2767 .28737 .28098 .29345 .27859 .28952 .27435 Metetra
.668 .737 .902 r
.28952 .27435 .29345 .27859 .29955 .27625 .29562 .27203 Metetra
.667 .738 .904 r
.29562 .27203 .29955 .27625 .30565 .27393 .30173 .26972 Metetra
.666 .739 .905 r
.30173 .26972 .30565 .27393 .31177 .27162 .30786 .26742 Metetra
.665 .74 .906 r
.30786 .26742 .31177 .27162 .31789 .26933 .31399 .26513 Metetra
.665 .74 .906 r
.31399 .26513 .31789 .26933 .32404 .26704 .32014 .26284 Metetra
.664 .741 .907 r
.32014 .26284 .32404 .26704 .33019 .26476 .32631 .26055 Metetra
.664 .741 .907 r
.32631 .26055 .33019 .26476 .33636 .26247 .33249 .25825 Metetra
.664 .741 .907 r
.33249 .25825 .33636 .26247 .34255 .26018 .33868 .25596 Metetra
.664 .741 .907 r
.33868 .25596 .34255 .26018 .34874 .25789 .34489 .25366 Metetra
.664 .741 .908 r
.34489 .25366 .34874 .25789 .35496 .2556 .35111 .25136 Metetra
.664 .741 .908 r
.35111 .25136 .35496 .2556 .36118 .25331 .35734 .24906 Metetra
.664 .741 .908 r
.35734 .24906 .36118 .25331 .36742 .25101 .36359 .24675 Metetra
.664 .741 .908 r
.36359 .24675 .36742 .25101 .37368 .2487 .36986 .24443 Metetra
.664 .741 .908 r
.36986 .24443 .37368 .2487 .37995 .24639 .37614 .24212 Metetra
.664 .741 .908 r
.37614 .24212 .37995 .24639 .38624 .24408 .38243 .23979 Metetra
.664 .741 .908 r
.38243 .23979 .38624 .24408 .39254 .24176 .38874 .23746 Metetra
.664 .741 .908 r
.38874 .23746 .39254 .24176 .39885 .23943 .39506 .23513 Metetra
.664 .741 .908 r
.39506 .23513 .39885 .23943 .40518 .2371 .4014 .23279 Metetra
.664 .741 .908 r
.4014 .23279 .40518 .2371 .41152 .23477 .40776 .23044 Metetra
.664 .741 .908 r
.40776 .23044 .41152 .23477 .41788 .23242 .41412 .22809 Metetra
.664 .741 .908 r
.41412 .22809 .41788 .23242 .42426 .23008 .42051 .22573 Metetra
.664 .741 .908 r
.42051 .22573 .42426 .23008 .43065 .22773 .42691 .22337 Metetra
.664 .741 .908 r
.42691 .22337 .43065 .22773 .43705 .22537 .43332 .221 Metetra
.664 .741 .908 r
.43332 .221 .43705 .22537 .44347 .22301 .43975 .21863 Metetra
.664 .741 .908 r
.43975 .21863 .44347 .22301 .44991 .22064 .4462 .21625 Metetra
.664 .741 .908 r
.4462 .21625 .44991 .22064 .45636 .21826 .45266 .21386 Metetra
.663 .741 .908 r
.45266 .21386 .45636 .21826 .46282 .21589 .45913 .21147 Metetra
.663 .741 .908 r
.45913 .21147 .46282 .21589 .4693 .2135 .46562 .20908 Metetra
.663 .741 .908 r
.46562 .20908 .4693 .2135 .4758 .21111 .47213 .20668 Metetra
.663 .741 .908 r
.47213 .20668 .4758 .21111 .48231 .20872 .47865 .20427 Metetra
.663 .741 .908 r
.47865 .20427 .48231 .20872 .48884 .20632 .48519 .20186 Metetra
.663 .741 .908 r
.48519 .20186 .48884 .20632 .49538 .20392 .49174 .19945 Metetra
.663 .741 .908 r
.49174 .19945 .49538 .20392 .50194 .20151 .49831 .19703 Metetra
.663 .741 .908 r
.49831 .19703 .50194 .20151 .50852 .19911 .5049 .19461 Metetra
.663 .74 .908 r
.5049 .19461 .50852 .19911 .51511 .1967 .5115 .19219 Metetra
.662 .74 .908 r
.5115 .19219 .51511 .1967 .52172 .19429 .51812 .18976 Metetra
.662 .74 .908 r
.51812 .18976 .52172 .19429 .52834 .19188 .52475 .18734 Metetra
.662 .739 .907 r
.52475 .18734 .52834 .19188 .53498 .18948 .5314 .18491 Metetra
.661 .738 .907 r
.5314 .18491 .53498 .18948 .54163 .18708 .53806 .18249 Metetra
.66 .738 .907 r
.53806 .18249 .54163 .18708 .5483 .18469 .54474 .18007 Metetra
.659 .736 .907 r
.54474 .18007 .5483 .18469 .55499 .18231 .55144 .17767 Metetra
.658 .735 .906 r
.55144 .17767 .55499 .18231 .5617 .17995 .55816 .17527 Metetra
.657 .733 .906 r
.55816 .17527 .5617 .17995 .56842 .17761 .56489 .1729 Metetra
.655 .731 .905 r
.56489 .1729 .56842 .17761 .57516 .1753 .57164 .17054 Metetra
.653 .729 .905 r
.57164 .17054 .57516 .1753 .58192 .17303 .57841 .16821 Metetra
.651 .726 .904 r
.57841 .16821 .58192 .17303 .58869 .17079 .58519 .16591 Metetra
.648 .722 .903 r
.58519 .16591 .58869 .17079 .59549 .1686 .592 .16365 Metetra
.645 .718 .901 r
.592 .16365 .59549 .1686 .6023 .16645 .59882 .16144 Metetra
.642 .714 .9 r
.59882 .16144 .6023 .16645 .60914 .16436 .60566 .15927 Metetra
.638 .709 .898 r
.60566 .15927 .60914 .16436 .61599 .16233 .61252 .15715 Metetra
.635 .704 .896 r
.61252 .15715 .61599 .16233 .62287 .16034 .61941 .15508 Metetra
.632 .7 .895 r
.61941 .15508 .62287 .16034 .62976 .15838 .62631 .15306 Metetra
.629 .696 .893 r
.62631 .15306 .62976 .15838 .63668 .15645 .63323 .15106 Metetra
.628 .693 .891 r
.63323 .15106 .63668 .15645 .64362 .15453 .64018 .14909 Metetra
.627 .691 .89 r
.64018 .14909 .64362 .15453 .65057 .15258 .64715 .14713 Metetra
.628 .691 .89 r
.64715 .14713 .65057 .15258 .65755 .15059 .65413 .14514 Metetra
.63 .693 .89 r
.65413 .14514 .65755 .15059 .66454 .14852 .66113 .14311 Metetra
.634 .697 .891 r
.66113 .14311 .66454 .14852 .67155 .14635 .66815 .14101 Metetra
.639 .703 .892 r
.66815 .14101 .67155 .14635 .67857 .14407 .67519 .13881 Metetra
.646 .71 .894 r
.67519 .13881 .67857 .14407 .6856 .14165 .68224 .1365 Metetra
.653 .719 .897 r
.68224 .1365 .6856 .14165 .69264 .1391 .6893 .13407 Metetra
.66 .728 .9 r
.6893 .13407 .69264 .1391 .69969 .13643 .69637 .13151 Metetra
.667 .737 .903 r
.69637 .13151 .69969 .13643 .70676 .13365 .70345 .12883 Metetra
.672 .745 .905 r
.70345 .12883 .70676 .13365 .71384 .1308 .71055 .12606 Metetra
.677 .751 .907 r
.71055 .12606 .71384 .1308 .72093 .1279 .71766 .1232 Metetra
.679 .756 .909 r
.71766 .1232 .72093 .1279 .72803 .12498 .72478 .1203 Metetra
.68 .757 .91 r
.72478 .1203 .72803 .12498 .73516 .12207 .73192 .11737 Metetra
.679 .757 .91 r
.73192 .11737 .73516 .12207 .7423 .11919 .73907 .11445 Metetra
.678 .755 .909 r
.73907 .11445 .7423 .11919 .74946 .11635 .74624 .11156 Metetra
.675 .751 .908 r
.74624 .11156 .74946 .11635 .75665 .11356 .75344 .10871 Metetra
.658 .735 .907 r
.11392 .33868 .11809 .34267 .1238 .34057 .11963 .33665 Metetra
.65 .737 .913 r
.11963 .33665 .1238 .34057 .12952 .33852 .12533 .33472 Metetra
.64 .742 .923 r
.12533 .33472 .12952 .33852 .13524 .33658 .13104 .33294 Metetra
.626 .747 .934 r
.13104 .33294 .13524 .33658 .14095 .33478 .13674 .33131 Metetra
.612 .754 .945 r
.13674 .33131 .14095 .33478 .14666 .33315 .14243 .32981 Metetra
.601 .759 .954 r
.14243 .32981 .14666 .33315 .15236 .33167 .14813 .32842 Metetra
.597 .763 .959 r
.14813 .32842 .15236 .33167 .15806 .33031 .15384 .32705 Metetra
.602 .765 .957 r
.15384 .32705 .15806 .33031 .16377 .32899 .15957 .32563 Metetra
.617 .763 .949 r
.15957 .32563 .16377 .32899 .16951 .32763 .16534 .32405 Metetra
.637 .757 .935 r
.16534 .32405 .16951 .32763 .17527 .32612 .17114 .32225 Metetra
.658 .746 .915 r
.17114 .32225 .17527 .32612 .18108 .32439 .17699 .32017 Metetra
.676 .733 .894 r
.17699 .32017 .18108 .32439 .18693 .32235 .18289 .31778 Metetra
.688 .72 .874 r
.18289 .31778 .18693 .32235 .19283 .32 .18883 .3151 Metetra
.697 .709 .857 r
.18883 .3151 .19283 .32 .19878 .31733 .19481 .31217 Metetra
.702 .7 .845 r
.19481 .31217 .19878 .31733 .20476 .31438 .20081 .30906 Metetra
.704 .694 .838 r
.20081 .30906 .20476 .31438 .21077 .31124 .20684 .30583 Metetra
.704 .692 .835 r
.20684 .30583 .21077 .31124 .21681 .30797 .21288 .30256 Metetra
.703 .692 .836 r
.21288 .30256 .21681 .30797 .22285 .30466 .21893 .29933 Metetra
.701 .694 .84 r
.21893 .29933 .22285 .30466 .22891 .30137 .22498 .29617 Metetra
.698 .699 .847 r
.22498 .29617 .22891 .30137 .23497 .29817 .23102 .29312 Metetra
.694 .704 .855 r
.23102 .29312 .23497 .29817 .24102 .29509 .23707 .2902 Metetra
.69 .71 .864 r
.23707 .2902 .24102 .29509 .24707 .29213 .24312 .2874 Metetra
.685 .716 .872 r
.24312 .2874 .24707 .29213 .25313 .28931 .24916 .28472 Metetra
.681 .722 .88 r
.24916 .28472 .25313 .28931 .25918 .28662 .25521 .28213 Metetra
.677 .726 .887 r
.25521 .28213 .25918 .28662 .26523 .28403 .26127 .27963 Metetra
.674 .73 .892 r
.26127 .27963 .26523 .28403 .27129 .28152 .26733 .27719 Metetra
.672 .733 .896 r
.26733 .27719 .27129 .28152 .27736 .27909 .2734 .2748 Metetra
.669 .736 .9 r
.2734 .2748 .27736 .27909 .28344 .2767 .27948 .27245 Metetra
.668 .737 .902 r
.27948 .27245 .28344 .2767 .28952 .27435 .28558 .27012 Metetra
.667 .738 .904 r
.28558 .27012 .28952 .27435 .29562 .27203 .29168 .26781 Metetra
.666 .739 .905 r
.29168 .26781 .29562 .27203 .30173 .26972 .2978 .2655 Metetra
.665 .74 .906 r
.2978 .2655 .30173 .26972 .30786 .26742 .30393 .26321 Metetra
.665 .74 .906 r
.30393 .26321 .30786 .26742 .31399 .26513 .31007 .26091 Metetra
.664 .741 .907 r
.31007 .26091 .31399 .26513 .32014 .26284 .31623 .25862 Metetra
.664 .741 .907 r
.31623 .25862 .32014 .26284 .32631 .26055 .32241 .25632 Metetra
.664 .741 .907 r
.32241 .25632 .32631 .26055 .33249 .25825 .32859 .25402 Metetra
.664 .741 .907 r
.32859 .25402 .33249 .25825 .33868 .25596 .33479 .25172 Metetra
.664 .741 .908 r
.33479 .25172 .33868 .25596 .34489 .25366 .34101 .24942 Metetra
.664 .741 .908 r
.34101 .24942 .34489 .25366 .35111 .25136 .34724 .24711 Metetra
.664 .741 .908 r
.34724 .24711 .35111 .25136 .35734 .24906 .35348 .24479 Metetra
.664 .741 .908 r
.35348 .24479 .35734 .24906 .36359 .24675 .35974 .24247 Metetra
.664 .741 .908 r
.35974 .24247 .36359 .24675 .36986 .24443 .36602 .24015 Metetra
.664 .741 .908 r
.36602 .24015 .36986 .24443 .37614 .24212 .37231 .23782 Metetra
.664 .741 .908 r
.37231 .23782 .37614 .24212 .38243 .23979 .37861 .23549 Metetra
.664 .741 .908 r
.37861 .23549 .38243 .23979 .38874 .23746 .38493 .23315 Metetra
.664 .741 .908 r
.38493 .23315 .38874 .23746 .39506 .23513 .39126 .2308 Metetra
.664 .741 .908 r
.39126 .2308 .39506 .23513 .4014 .23279 .39761 .22845 Metetra
.664 .741 .908 r
.39761 .22845 .4014 .23279 .40776 .23044 .40397 .22609 Metetra
.664 .741 .908 r
.40397 .22609 .40776 .23044 .41412 .22809 .41035 .22373 Metetra
.664 .741 .908 r
.41035 .22373 .41412 .22809 .42051 .22573 .41674 .22137 Metetra
.664 .741 .908 r
.41674 .22137 .42051 .22573 .42691 .22337 .42315 .21899 Metetra
.664 .741 .908 r
.42315 .21899 .42691 .22337 .43332 .221 .42958 .21661 Metetra
.664 .741 .908 r
.42958 .21661 .43332 .221 .43975 .21863 .43602 .21423 Metetra
.664 .741 .908 r
.43602 .21423 .43975 .21863 .4462 .21625 .44247 .21184 Metetra
.664 .741 .908 r
.44247 .21184 .4462 .21625 .45266 .21386 .44894 .20945 Metetra
.664 .741 .908 r
.44894 .20945 .45266 .21386 .45913 .21147 .45543 .20704 Metetra
.663 .741 .908 r
.45543 .20704 .45913 .21147 .46562 .20908 .46193 .20464 Metetra
.663 .741 .908 r
.46193 .20464 .46562 .20908 .47213 .20668 .46844 .20223 Metetra
.663 .741 .908 r
.46844 .20223 .47213 .20668 .47865 .20427 .47497 .19981 Metetra
.663 .741 .908 r
.47497 .19981 .47865 .20427 .48519 .20186 .48152 .19739 Metetra
.663 .741 .908 r
.48152 .19739 .48519 .20186 .49174 .19945 .48809 .19496 Metetra
.663 .741 .908 r
.48809 .19496 .49174 .19945 .49831 .19703 .49467 .19253 Metetra
.663 .741 .908 r
.49467 .19253 .49831 .19703 .5049 .19461 .50126 .1901 Metetra
.663 .741 .908 r
.50126 .1901 .5049 .19461 .5115 .19219 .50787 .18766 Metetra
.663 .74 .908 r
.50787 .18766 .5115 .19219 .51812 .18976 .5145 .18522 Metetra
.662 .74 .908 r
.5145 .18522 .51812 .18976 .52475 .18734 .52114 .18278 Metetra
.662 .74 .908 r
.52114 .18278 .52475 .18734 .5314 .18491 .5278 .18033 Metetra
.662 .739 .907 r
.5278 .18033 .5314 .18491 .53806 .18249 .53448 .17789 Metetra
.661 .738 .907 r
.53448 .17789 .53806 .18249 .54474 .18007 .54117 .17546 Metetra
.66 .738 .907 r
.54117 .17546 .54474 .18007 .55144 .17767 .54788 .17302 Metetra
.659 .736 .907 r
.54788 .17302 .55144 .17767 .55816 .17527 .5546 .1706 Metetra
.658 .735 .906 r
.5546 .1706 .55816 .17527 .56489 .1729 .56135 .16819 Metetra
.657 .733 .906 r
.56135 .16819 .56489 .1729 .57164 .17054 .56811 .16579 Metetra
.655 .731 .905 r
.56811 .16579 .57164 .17054 .57841 .16821 .57488 .16342 Metetra
.653 .729 .905 r
.57488 .16342 .57841 .16821 .58519 .16591 .58168 .16107 Metetra
.651 .726 .904 r
.58168 .16107 .58519 .16591 .592 .16365 .58849 .15875 Metetra
.648 .723 .903 r
.58849 .15875 .592 .16365 .59882 .16144 .59532 .15647 Metetra
.645 .719 .902 r
.59532 .15647 .59882 .16144 .60566 .15927 .60217 .15423 Metetra
.642 .714 .9 r
.60217 .15423 .60566 .15927 .61252 .15715 .60904 .15204 Metetra
.639 .71 .899 r
.60904 .15204 .61252 .15715 .61941 .15508 .61594 .14989 Metetra
.636 .706 .897 r
.61594 .14989 .61941 .15508 .62631 .15306 .62285 .14779 Metetra
.633 .701 .895 r
.62285 .14779 .62631 .15306 .63323 .15106 .62978 .14573 Metetra
.63 .698 .893 r
.62978 .14573 .63323 .15106 .64018 .14909 .63673 .1437 Metetra
.629 .695 .892 r
.63673 .1437 .64018 .14909 .64715 .14713 .64371 .14169 Metetra
.628 .693 .891 r
.64371 .14169 .64715 .14713 .65413 .14514 .6507 .13968 Metetra
.629 .693 .89 r
.6507 .13968 .65413 .14514 .66113 .14311 .65771 .13766 Metetra
.631 .695 .891 r
.65771 .13766 .66113 .14311 .66815 .14101 .66474 .13559 Metetra
.635 .699 .891 r
.66474 .13559 .66815 .14101 .67519 .13881 .67179 .13345 Metetra
.64 .704 .893 r
.67179 .13345 .67519 .13881 .68224 .1365 .67886 .13123 Metetra
.646 .711 .895 r
.67886 .13123 .68224 .1365 .6893 .13407 .68593 .12889 Metetra
.653 .719 .897 r
.68593 .12889 .6893 .13407 .69637 .13151 .69303 .12644 Metetra
.659 .728 .9 r
.69303 .12644 .69637 .13151 .70345 .12883 .70013 .12387 Metetra
.666 .737 .903 r
.70013 .12387 .70345 .12883 .71055 .12606 .70724 .12119 Metetra
.671 .744 .905 r
.70724 .12119 .71055 .12606 .71766 .1232 .71437 .11841 Metetra
.676 .75 .907 r
.71437 .11841 .71766 .1232 .72478 .1203 .72151 .11555 Metetra
.678 .755 .909 r
.72151 .11555 .72478 .1203 .73192 .11737 .72866 .11265 Metetra
.679 .757 .909 r
.72866 .11265 .73192 .11737 .73907 .11445 .73583 .10972 Metetra
.679 .756 .91 r
.73583 .10972 .73907 .11445 .74624 .11156 .74301 .10679 Metetra
.677 .755 .909 r
.74301 .10679 .74624 .11156 .75344 .10871 .75022 .10389 Metetra
.649 .738 .915 r
.10971 .33478 .11392 .33868 .11963 .33665 .11541 .33287 Metetra
.639 .743 .924 r
.11541 .33287 .11963 .33665 .12533 .33472 .12111 .33109 Metetra
.626 .748 .935 r
.12111 .33109 .12533 .33472 .13104 .33294 .1268 .32946 Metetra
.614 .754 .945 r
.1268 .32946 .13104 .33294 .13674 .33131 .13249 .32795 Metetra
.604 .759 .953 r
.13249 .32795 .13674 .33131 .14243 .32981 .13818 .32652 Metetra
.602 .763 .956 r
.13818 .32652 .14243 .32981 .14813 .32842 .14389 .3251 Metetra
.608 .764 .954 r
.14389 .3251 .14813 .32842 .15384 .32705 .14962 .32362 Metetra
.623 .761 .945 r
.14962 .32362 .15384 .32705 .15957 .32563 .15538 .32198 Metetra
.642 .755 .931 r
.15538 .32198 .15957 .32563 .16534 .32405 .16119 .32012 Metetra
.661 .744 .912 r
.16119 .32012 .16534 .32405 .17114 .32225 .16703 .318 Metetra
.677 .732 .892 r
.16703 .318 .17114 .32225 .17699 .32017 .17293 .31558 Metetra
.688 .72 .873 r
.17293 .31558 .17699 .32017 .18289 .31778 .17886 .3129 Metetra
.696 .709 .858 r
.17886 .3129 .18289 .31778 .18883 .3151 .18483 .30998 Metetra
.701 .701 .847 r
.18483 .30998 .18883 .3151 .19481 .31217 .19083 .3069 Metetra
.703 .696 .84 r
.19083 .3069 .19481 .31217 .20081 .30906 .19685 .30371 Metetra
.703 .694 .838 r
.19685 .30371 .20081 .30906 .20684 .30583 .20289 .30049 Metetra
.702 .694 .839 r
.20289 .30049 .20684 .30583 .21288 .30256 .20893 .2973 Metetra
.7 .697 .843 r
.20893 .2973 .21288 .30256 .21893 .29933 .21497 .29418 Metetra
.697 .701 .85 r
.21497 .29418 .21893 .29933 .22498 .29617 .22101 .29116 Metetra
.693 .706 .857 r
.22101 .29116 .22498 .29617 .23102 .29312 .22705 .28826 Metetra
.689 .712 .866 r
.22705 .28826 .23102 .29312 .23707 .2902 .23309 .28548 Metetra
.685 .717 .874 r
.23309 .28548 .23707 .2902 .24312 .2874 .23913 .28281 Metetra
.681 .722 .881 r
.23913 .28281 .24312 .2874 .24916 .28472 .24517 .28023 Metetra
.677 .727 .887 r
.24517 .28023 .24916 .28472 .25521 .28213 .25122 .27773 Metetra
.674 .73 .892 r
.25122 .27773 .25521 .28213 .26127 .27963 .25728 .2753 Metetra
.671 .733 .896 r
.25728 .2753 .26127 .27963 .26733 .27719 .26335 .2729 Metetra
.669 .736 .9 r
.26335 .2729 .26733 .27719 .2734 .2748 .26942 .27055 Metetra
.668 .737 .902 r
.26942 .27055 .2734 .2748 .27948 .27245 .27551 .26821 Metetra
.667 .738 .904 r
.27551 .26821 .27948 .27245 .28558 .27012 .28161 .26589 Metetra
.666 .739 .905 r
.28161 .26589 .28558 .27012 .29168 .26781 .28772 .26359 Metetra
.665 .74 .906 r
.28772 .26359 .29168 .26781 .2978 .2655 .29385 .26128 Metetra
.665 .74 .906 r
.29385 .26128 .2978 .2655 .30393 .26321 .29999 .25898 Metetra
.664 .741 .907 r
.29999 .25898 .30393 .26321 .31007 .26091 .30614 .25668 Metetra
.664 .741 .907 r
.30614 .25668 .31007 .26091 .31623 .25862 .31231 .25438 Metetra
.664 .741 .907 r
.31231 .25438 .31623 .25862 .32241 .25632 .31849 .25208 Metetra
.664 .741 .907 r
.31849 .25208 .32241 .25632 .32859 .25402 .32468 .24977 Metetra
.664 .741 .908 r
.32468 .24977 .32859 .25402 .33479 .25172 .33089 .24746 Metetra
.664 .741 .908 r
.33089 .24746 .33479 .25172 .34101 .24942 .33712 .24515 Metetra
.664 .741 .908 r
.33712 .24515 .34101 .24942 .34724 .24711 .34336 .24283 Metetra
.664 .741 .908 r
.34336 .24283 .34724 .24711 .35348 .24479 .34961 .24051 Metetra
.664 .741 .908 r
.34961 .24051 .35348 .24479 .35974 .24247 .35588 .23818 Metetra
.664 .741 .908 r
.35588 .23818 .35974 .24247 .36602 .24015 .36216 .23585 Metetra
.664 .741 .908 r
.36216 .23585 .36602 .24015 .37231 .23782 .36846 .23351 Metetra
.664 .741 .908 r
.36846 .23351 .37231 .23782 .37861 .23549 .37477 .23116 Metetra
.664 .741 .908 r
.37477 .23116 .37861 .23549 .38493 .23315 .3811 .22881 Metetra
.664 .741 .908 r
.3811 .22881 .38493 .23315 .39126 .2308 .38744 .22646 Metetra
.664 .741 .908 r
.38744 .22646 .39126 .2308 .39761 .22845 .3938 .2241 Metetra
.664 .741 .908 r
.3938 .2241 .39761 .22845 .40397 .22609 .40017 .22173 Metetra
.664 .741 .908 r
.40017 .22173 .40397 .22609 .41035 .22373 .40656 .21936 Metetra
.664 .741 .908 r
.40656 .21936 .41035 .22373 .41674 .22137 .41296 .21698 Metetra
.664 .741 .908 r
.41296 .21698 .41674 .22137 .42315 .21899 .41938 .2146 Metetra
.664 .741 .908 r
.41938 .2146 .42315 .21899 .42958 .21661 .42581 .21221 Metetra
.664 .741 .908 r
.42581 .21221 .42958 .21661 .43602 .21423 .43226 .20981 Metetra
.664 .741 .908 r
.43226 .20981 .43602 .21423 .44247 .21184 .43873 .20741 Metetra
.664 .741 .908 r
.43873 .20741 .44247 .21184 .44894 .20945 .44521 .20501 Metetra
.664 .741 .908 r
.44521 .20501 .44894 .20945 .45543 .20704 .4517 .2026 Metetra
.663 .741 .908 r
.4517 .2026 .45543 .20704 .46193 .20464 .45821 .20018 Metetra
.663 .741 .908 r
.45821 .20018 .46193 .20464 .46844 .20223 .46474 .19776 Metetra
.663 .741 .908 r
.46474 .19776 .46844 .20223 .47497 .19981 .47128 .19533 Metetra
.663 .741 .908 r
.47128 .19533 .47497 .19981 .48152 .19739 .47784 .1929 Metetra
.663 .741 .908 r
.47784 .1929 .48152 .19739 .48809 .19496 .48441 .19046 Metetra
.663 .741 .908 r
.48441 .19046 .48809 .19496 .49467 .19253 .491 .18801 Metetra
.663 .741 .908 r
.491 .18801 .49467 .19253 .50126 .1901 .49761 .18557 Metetra
.663 .741 .908 r
.49761 .18557 .50126 .1901 .50787 .18766 .50423 .18312 Metetra
.663 .741 .908 r
.50423 .18312 .50787 .18766 .5145 .18522 .51087 .18066 Metetra
.663 .74 .908 r
.51087 .18066 .5145 .18522 .52114 .18278 .51752 .1782 Metetra
.662 .74 .908 r
.51752 .1782 .52114 .18278 .5278 .18033 .52419 .17574 Metetra
.662 .74 .908 r
.52419 .17574 .5278 .18033 .53448 .17789 .53088 .17328 Metetra
.662 .739 .907 r
.53088 .17328 .53448 .17789 .54117 .17546 .53758 .17083 Metetra
.661 .738 .907 r
.53758 .17083 .54117 .17546 .54788 .17302 .5443 .16837 Metetra
.66 .738 .907 r
.5443 .16837 .54788 .17302 .5546 .1706 .55104 .16592 Metetra
.659 .736 .907 r
.55104 .16592 .5546 .1706 .56135 .16819 .55779 .16348 Metetra
.658 .735 .906 r
.55779 .16348 .56135 .16819 .56811 .16579 .56456 .16105 Metetra
.657 .733 .906 r
.56456 .16105 .56811 .16579 .57488 .16342 .57135 .15864 Metetra
.655 .731 .905 r
.57135 .15864 .57488 .16342 .58168 .16107 .57815 .15625 Metetra
.653 .729 .905 r
.57815 .15625 .58168 .16107 .58849 .15875 .58497 .15388 Metetra
.651 .726 .904 r
.58497 .15388 .58849 .15875 .59532 .15647 .59181 .15154 Metetra
.648 .723 .903 r
.59181 .15154 .59532 .15647 .60217 .15423 .59867 .14924 Metetra
.646 .719 .902 r
.59867 .14924 .60217 .15423 .60904 .15204 .60555 .14698 Metetra
.643 .715 .9 r
.60555 .14698 .60904 .15204 .61594 .14989 .61245 .14476 Metetra
.64 .711 .899 r
.61245 .14476 .61594 .14989 .62285 .14779 .61937 .14258 Metetra
.636 .707 .897 r
.61937 .14258 .62285 .14779 .62978 .14573 .62631 .14045 Metetra
.634 .703 .896 r
.62631 .14045 .62978 .14573 .63673 .1437 .63327 .13835 Metetra
.632 .699 .894 r
.63327 .13835 .63673 .1437 .64371 .14169 .64025 .13629 Metetra
.63 .696 .893 r
.64025 .13629 .64371 .14169 .6507 .13968 .64726 .13424 Metetra
.63 .695 .892 r
.64726 .13424 .6507 .13968 .65771 .13766 .65428 .1322 Metetra
.63 .695 .891 r
.65428 .1322 .65771 .13766 .66474 .13559 .66132 .13013 Metetra
.633 .697 .891 r
.66132 .13013 .66474 .13559 .67179 .13345 .66838 .12803 Metetra
.636 .7 .892 r
.66838 .12803 .67179 .13345 .67886 .13123 .67546 .12586 Metetra
.641 .705 .894 r
.67546 .12586 .67886 .13123 .68593 .12889 .68255 .1236 Metetra
.646 .712 .896 r
.68255 .1236 .68593 .12889 .69303 .12644 .68966 .12124 Metetra
.653 .72 .898 r
.68966 .12124 .69303 .12644 .70013 .12387 .69678 .11878 Metetra
.659 .728 .9 r
.69678 .11878 .70013 .12387 .70724 .12119 .70391 .11619 Metetra
.665 .736 .903 r
.70391 .11619 .70724 .12119 .71437 .11841 .71106 .1135 Metetra
.671 .744 .905 r
.71106 .1135 .71437 .11841 .72151 .11555 .71821 .11072 Metetra
.675 .749 .907 r
.71821 .11072 .72151 .11555 .72866 .11265 .72538 .10786 Metetra
.677 .754 .909 r
.72538 .10786 .72866 .11265 .73583 .10972 .73257 .10495 Metetra
.679 .756 .909 r
.73257 .10495 .73583 .10972 .74301 .10679 .73976 .10201 Metetra
.678 .756 .91 r
.73976 .10201 .74301 .10679 .75022 .10389 .74698 .09908 Metetra
.638 .744 .925 r
.10547 .33102 .10971 .33478 .11541 .33287 .11116 .32925 Metetra
.626 .749 .935 r
.11116 .32925 .11541 .33287 .12111 .33109 .11684 .32761 Metetra
.615 .754 .945 r
.11684 .32761 .12111 .33109 .1268 .32946 .12252 .32608 Metetra
.608 .759 .951 r
.12252 .32608 .1268 .32946 .13249 .32795 .12821 .32461 Metetra
.606 .762 .953 r
.12821 .32461 .13249 .32795 .13818 .32652 .13392 .32315 Metetra
.614 .762 .95 r
.13392 .32315 .13818 .32652 .14389 .3251 .13965 .3216 Metetra
.628 .759 .941 r
.13965 .3216 .14389 .3251 .14962 .32362 .14541 .31991 Metetra
.645 .753 .927 r
.14541 .31991 .14962 .32362 .15538 .32198 .15121 .318 Metetra
.663 .743 .909 r
.15121 .318 .15538 .32198 .16119 .32012 .15706 .31584 Metetra
.677 .731 .891 r
.15706 .31584 .16119 .32012 .16703 .318 .16295 .3134 Metetra
.688 .72 .873 r
.16295 .3134 .16703 .318 .17293 .31558 .16888 .31072 Metetra
.696 .71 .859 r
.16888 .31072 .17293 .31558 .17886 .3129 .17484 .30781 Metetra
.7 .703 .849 r
.17484 .30781 .17886 .3129 .18483 .30998 .18083 .30475 Metetra
.702 .698 .843 r
.18083 .30475 .18483 .30998 .19083 .3069 .18685 .3016 Metetra
.702 .696 .841 r
.18685 .3016 .19083 .3069 .19685 .30371 .19287 .29842 Metetra
.701 .696 .842 r
.19287 .29842 .19685 .30371 .20289 .30049 .1989 .29527 Metetra
.699 .699 .846 r
.1989 .29527 .20289 .30049 .20893 .2973 .20494 .29219 Metetra
.696 .703 .852 r
.20494 .29219 .20893 .2973 .21497 .29418 .21097 .28921 Metetra
.692 .708 .859 r
.21097 .28921 .21497 .29418 .22101 .29116 .21701 .28633 Metetra
.688 .713 .867 r
.21701 .28633 .22101 .29116 .22705 .28826 .22304 .28357 Metetra
.684 .718 .875 r
.22304 .28357 .22705 .28826 .23309 .28548 .22908 .2809 Metetra
.68 .723 .882 r
.22908 .2809 .23309 .28548 .23913 .28281 .23511 .27833 Metetra
.677 .727 .888 r
.23511 .27833 .23913 .28281 .24517 .28023 .24116 .27583 Metetra
.674 .731 .893 r
.24116 .27583 .24517 .28023 .25122 .27773 .24721 .27339 Metetra
.671 .734 .897 r
.24721 .27339 .25122 .27773 .25728 .2753 .25327 .271 Metetra
.669 .736 .9 r
.25327 .271 .25728 .2753 .26335 .2729 .25934 .26864 Metetra
.668 .737 .902 r
.25934 .26864 .26335 .2729 .26942 .27055 .26542 .2663 Metetra
.667 .738 .904 r
.26542 .2663 .26942 .27055 .27551 .26821 .27152 .26398 Metetra
.666 .739 .905 r
.27152 .26398 .27551 .26821 .28161 .26589 .27762 .26166 Metetra
.665 .74 .906 r
.27762 .26166 .28161 .26589 .28772 .26359 .28374 .25936 Metetra
.665 .74 .906 r
.28374 .25936 .28772 .26359 .29385 .26128 .28988 .25705 Metetra
.664 .741 .907 r
.28988 .25705 .29385 .26128 .29999 .25898 .29602 .25475 Metetra
.664 .741 .907 r
.29602 .25475 .29999 .25898 .30614 .25668 .30219 .25244 Metetra
.664 .741 .907 r
.30219 .25244 .30614 .25668 .31231 .25438 .30836 .25013 Metetra
.664 .741 .907 r
.30836 .25013 .31231 .25438 .31849 .25208 .31455 .24782 Metetra
.664 .741 .908 r
.31455 .24782 .31849 .25208 .32468 .24977 .32076 .24551 Metetra
.664 .741 .908 r
.32076 .24551 .32468 .24977 .33089 .24746 .32697 .24319 Metetra
.664 .741 .908 r
.32697 .24319 .33089 .24746 .33712 .24515 .33321 .24087 Metetra
.664 .741 .908 r
.33321 .24087 .33712 .24515 .34336 .24283 .33945 .23854 Metetra
.664 .741 .908 r
.33945 .23854 .34336 .24283 .34961 .24051 .34572 .23621 Metetra
.664 .741 .908 r
.34572 .23621 .34961 .24051 .35588 .23818 .35199 .23387 Metetra
.664 .741 .908 r
.35199 .23387 .35588 .23818 .36216 .23585 .35829 .23152 Metetra
.664 .741 .908 r
.35829 .23152 .36216 .23585 .36846 .23351 .36459 .22917 Metetra
.664 .741 .908 r
.36459 .22917 .36846 .23351 .37477 .23116 .37092 .22682 Metetra
.664 .741 .908 r
.37092 .22682 .37477 .23116 .3811 .22881 .37725 .22446 Metetra
.664 .741 .908 r
.37725 .22446 .3811 .22881 .38744 .22646 .3836 .22209 Metetra
.664 .741 .908 r
.3836 .22209 .38744 .22646 .3938 .2241 .38997 .21972 Metetra
.664 .741 .908 r
.38997 .21972 .3938 .2241 .40017 .22173 .39635 .21735 Metetra
.664 .741 .908 r
.39635 .21735 .40017 .22173 .40656 .21936 .40275 .21496 Metetra
.664 .741 .908 r
.40275 .21496 .40656 .21936 .41296 .21698 .40916 .21258 Metetra
.664 .741 .908 r
.40916 .21258 .41296 .21698 .41938 .2146 .41559 .21018 Metetra
.664 .741 .908 r
.41559 .21018 .41938 .2146 .42581 .21221 .42203 .20778 Metetra
.664 .741 .908 r
.42203 .20778 .42581 .21221 .43226 .20981 .42849 .20538 Metetra
.664 .741 .908 r
.42849 .20538 .43226 .20981 .43873 .20741 .43497 .20297 Metetra
.664 .741 .908 r
.43497 .20297 .43873 .20741 .44521 .20501 .44146 .20055 Metetra
.664 .741 .908 r
.44146 .20055 .44521 .20501 .4517 .2026 .44796 .19813 Metetra
.664 .741 .908 r
.44796 .19813 .4517 .2026 .45821 .20018 .45448 .1957 Metetra
.663 .741 .908 r
.45448 .1957 .45821 .20018 .46474 .19776 .46102 .19327 Metetra
.663 .741 .908 r
.46102 .19327 .46474 .19776 .47128 .19533 .46757 .19083 Metetra
.663 .741 .908 r
.46757 .19083 .47128 .19533 .47784 .1929 .47414 .18838 Metetra
.663 .741 .908 r
.47414 .18838 .47784 .1929 .48441 .19046 .48072 .18593 Metetra
.663 .741 .908 r
.48072 .18593 .48441 .19046 .491 .18801 .48732 .18348 Metetra
.663 .741 .908 r
.48732 .18348 .491 .18801 .49761 .18557 .49394 .18102 Metetra
.663 .741 .908 r
.49394 .18102 .49761 .18557 .50423 .18312 .50057 .17855 Metetra
.663 .741 .908 r
.50057 .17855 .50423 .18312 .51087 .18066 .50722 .17608 Metetra
.663 .741 .908 r
.50722 .17608 .51087 .18066 .51752 .1782 .51388 .17361 Metetra
.663 .74 .908 r
.51388 .17361 .51752 .1782 .52419 .17574 .52056 .17114 Metetra
.662 .74 .908 r
.52056 .17114 .52419 .17574 .53088 .17328 .52726 .16866 Metetra
.662 .74 .908 r
.52726 .16866 .53088 .17328 .53758 .17083 .53397 .16619 Metetra
.662 .739 .907 r
.53397 .16619 .53758 .17083 .5443 .16837 .5407 .16371 Metetra
.661 .738 .907 r
.5407 .16371 .5443 .16837 .55104 .16592 .54745 .16124 Metetra
.66 .738 .907 r
.54745 .16124 .55104 .16592 .55779 .16348 .55421 .15877 Metetra
.659 .736 .907 r
.55421 .15877 .55779 .16348 .56456 .16105 .56099 .15631 Metetra
.658 .735 .906 r
.56099 .15631 .56456 .16105 .57135 .15864 .56779 .15387 Metetra
.657 .734 .906 r
.56779 .15387 .57135 .15864 .57815 .15625 .57461 .15144 Metetra
.655 .732 .905 r
.57461 .15144 .57815 .15625 .58497 .15388 .58144 .14902 Metetra
.653 .729 .905 r
.58144 .14902 .58497 .15388 .59181 .15154 .58829 .14664 Metetra
.651 .726 .904 r
.58829 .14664 .59181 .15154 .59867 .14924 .59516 .14428 Metetra
.649 .723 .903 r
.59516 .14428 .59867 .14924 .60555 .14698 .60205 .14196 Metetra
.646 .72 .902 r
.60205 .14196 .60555 .14698 .61245 .14476 .60896 .13967 Metetra
.643 .716 .9 r
.60896 .13967 .61245 .14476 .61937 .14258 .61588 .13742 Metetra
.64 .712 .899 r
.61588 .13742 .61937 .14258 .62631 .14045 .62283 .13522 Metetra
.637 .708 .898 r
.62283 .13522 .62631 .14045 .63327 .13835 .6298 .13306 Metetra
.635 .704 .896 r
.6298 .13306 .63327 .13835 .64025 .13629 .63679 .13093 Metetra
.633 .7 .895 r
.63679 .13093 .64025 .13629 .64726 .13424 .6438 .12883 Metetra
.631 .698 .893 r
.6438 .12883 .64726 .13424 .65428 .1322 .65083 .12675 Metetra
.631 .697 .892 r
.65083 .12675 .65428 .1322 .66132 .13013 .65788 .12467 Metetra
.632 .697 .892 r
.65788 .12467 .66132 .13013 .66838 .12803 .66495 .12256 Metetra
.634 .698 .892 r
.66495 .12256 .66838 .12803 .67546 .12586 .67204 .12042 Metetra
.637 .702 .893 r
.67204 .12042 .67546 .12586 .68255 .1236 .67915 .11822 Metetra
.641 .707 .894 r
.67915 .11822 .68255 .1236 .68966 .12124 .68627 .11593 Metetra
.647 .713 .896 r
.68627 .11593 .68966 .12124 .69678 .11878 .69341 .11355 Metetra
.653 .72 .898 r
.69341 .11355 .69678 .11878 .70391 .11619 .70056 .11107 Metetra
.659 .728 .901 r
.70056 .11107 .70391 .11619 .71106 .1135 .70772 .10847 Metetra
.665 .736 .903 r
.70772 .10847 .71106 .1135 .71821 .11072 .7149 .10577 Metetra
.67 .743 .905 r
.7149 .10577 .71821 .11072 .72538 .10786 .72209 .10298 Metetra
.674 .749 .907 r
.72209 .10298 .72538 .10786 .73257 .10495 .72929 .10012 Metetra
.677 .753 .908 r
.72929 .10012 .73257 .10495 .73976 .10201 .7365 .0972 Metetra
.678 .755 .909 r
.7365 .0972 .73976 .10201 .74698 .09908 .74373 .09426 Metetra
.627 .75 .936 r
.10119 .3274 .10547 .33102 .11116 .32925 .10686 .32575 Metetra
.617 .755 .944 r
.10686 .32575 .11116 .32925 .11684 .32761 .11254 .3242 Metetra
.611 .759 .95 r
.11254 .3242 .11684 .32761 .12252 .32608 .11823 .3227 Metetra
.611 .761 .951 r
.11823 .3227 .12252 .32608 .12821 .32461 .12393 .32118 Metetra
.618 .761 .947 r
.12393 .32118 .12821 .32461 .13392 .32315 .12966 .31959 Metetra
.632 .758 .938 r
.12966 .31959 .13392 .32315 .13965 .3216 .13542 .31785 Metetra
.649 .751 .924 r
.13542 .31785 .13965 .3216 .14541 .31991 .14122 .31589 Metetra
.665 .741 .907 r
.14122 .31589 .14541 .31991 .15121 .318 .14706 .31369 Metetra
.678 .73 .89 r
.14706 .31369 .15121 .318 .15706 .31584 .15294 .31124 Metetra
.688 .72 .874 r
.15294 .31124 .15706 .31584 .16295 .3134 .15887 .30855 Metetra
.695 .711 .86 r
.15887 .30855 .16295 .3134 .16888 .31072 .16483 .30566 Metetra
.699 .704 .851 r
.16483 .30566 .16888 .31072 .17484 .30781 .17082 .30263 Metetra
.701 .7 .845 r
.17082 .30263 .17484 .30781 .18083 .30475 .17682 .29951 Metetra
.701 .698 .844 r
.17682 .29951 .18083 .30475 .18685 .3016 .18284 .29637 Metetra
.7 .698 .845 r
.18284 .29637 .18685 .3016 .19287 .29842 .18886 .29326 Metetra
.698 .701 .849 r
.18886 .29326 .19287 .29842 .1989 .29527 .19489 .29021 Metetra
.695 .704 .855 r
.19489 .29021 .1989 .29527 .20494 .29219 .20092 .28725 Metetra
.692 .709 .861 r
.20092 .28725 .20494 .29219 .21097 .28921 .20694 .2844 Metetra
.688 .714 .869 r
.20694 .2844 .21097 .28921 .21701 .28633 .21297 .28165 Metetra
.684 .719 .876 r
.21297 .28165 .21701 .28633 .22304 .28357 .219 .27899 Metetra
.68 .724 .883 r
.219 .27899 .22304 .28357 .22908 .2809 .22504 .27643 Metetra
.677 .728 .888 r
.22504 .27643 .22908 .2809 .23511 .27833 .23107 .27393 Metetra
.674 .731 .893 r
.23107 .27393 .23511 .27833 .24116 .27583 .23712 .27149 Metetra
.671 .734 .897 r
.23712 .27149 .24116 .27583 .24721 .27339 .24318 .26909 Metetra
.669 .736 .9 r
.24318 .26909 .24721 .27339 .25327 .271 .24924 .26673 Metetra
.668 .737 .902 r
.24924 .26673 .25327 .271 .25934 .26864 .25532 .26438 Metetra
.667 .738 .904 r
.25532 .26438 .25934 .26864 .26542 .2663 .26141 .26206 Metetra
.666 .739 .905 r
.26141 .26206 .26542 .2663 .27152 .26398 .26751 .25974 Metetra
.665 .74 .906 r
.26751 .25974 .27152 .26398 .27762 .26166 .27362 .25743 Metetra
.665 .74 .906 r
.27362 .25743 .27762 .26166 .28374 .25936 .27975 .25512 Metetra
.664 .741 .907 r
.27975 .25512 .28374 .25936 .28988 .25705 .28589 .25281 Metetra
.664 .741 .907 r
.28589 .25281 .28988 .25705 .29602 .25475 .29205 .2505 Metetra
.664 .741 .907 r
.29205 .2505 .29602 .25475 .30219 .25244 .29822 .24819 Metetra
.664 .741 .907 r
.29822 .24819 .30219 .25244 .30836 .25013 .3044 .24587 Metetra
.664 .741 .908 r
.3044 .24587 .30836 .25013 .31455 .24782 .3106 .24355 Metetra
.664 .741 .908 r
.3106 .24355 .31455 .24782 .32076 .24551 .31681 .24123 Metetra
.664 .741 .908 r
.31681 .24123 .32076 .24551 .32697 .24319 .32304 .2389 Metetra
.664 .741 .908 r
.32304 .2389 .32697 .24319 .33321 .24087 .32928 .23657 Metetra
.664 .741 .908 r
.32928 .23657 .33321 .24087 .33945 .23854 .33554 .23423 Metetra
.664 .741 .908 r
.33554 .23423 .33945 .23854 .34572 .23621 .34181 .23189 Metetra
.664 .741 .908 r
.34181 .23189 .34572 .23621 .35199 .23387 .34809 .22954 Metetra
.664 .741 .908 r
.34809 .22954 .35199 .23387 .35829 .23152 .3544 .22718 Metetra
.664 .741 .908 r
.3544 .22718 .35829 .23152 .36459 .22917 .36071 .22482 Metetra
.664 .741 .908 r
.36071 .22482 .36459 .22917 .37092 .22682 .36704 .22246 Metetra
.664 .741 .908 r
.36704 .22246 .37092 .22682 .37725 .22446 .37339 .22009 Metetra
.664 .741 .908 r
.37339 .22009 .37725 .22446 .3836 .22209 .37975 .21771 Metetra
.664 .741 .908 r
.37975 .21771 .3836 .22209 .38997 .21972 .38613 .21533 Metetra
.664 .741 .908 r
.38613 .21533 .38997 .21972 .39635 .21735 .39252 .21294 Metetra
.664 .741 .908 r
.39252 .21294 .39635 .21735 .40275 .21496 .39892 .21055 Metetra
.664 .741 .908 r
.39892 .21055 .40275 .21496 .40916 .21258 .40535 .20815 Metetra
.664 .741 .908 r
.40535 .20815 .40916 .21258 .41559 .21018 .41178 .20575 Metetra
.664 .741 .908 r
.41178 .20575 .41559 .21018 .42203 .20778 .41824 .20334 Metetra
.664 .741 .908 r
.41824 .20334 .42203 .20778 .42849 .20538 .42471 .20092 Metetra
.664 .741 .908 r
.42471 .20092 .42849 .20538 .43497 .20297 .43119 .1985 Metetra
.664 .741 .908 r
.43119 .1985 .43497 .20297 .44146 .20055 .43769 .19607 Metetra
.664 .741 .908 r
.43769 .19607 .44146 .20055 .44796 .19813 .4442 .19364 Metetra
.664 .741 .908 r
.4442 .19364 .44796 .19813 .45448 .1957 .45074 .1912 Metetra
.664 .741 .908 r
.45074 .1912 .45448 .1957 .46102 .19327 .45728 .18876 Metetra
.663 .741 .908 r
.45728 .18876 .46102 .19327 .46757 .19083 .46384 .1863 Metetra
.663 .741 .908 r
.46384 .1863 .46757 .19083 .47414 .18838 .47042 .18385 Metetra
.663 .741 .908 r
.47042 .18385 .47414 .18838 .48072 .18593 .47702 .18139 Metetra
.663 .741 .908 r
.47702 .18139 .48072 .18593 .48732 .18348 .48363 .17892 Metetra
.663 .741 .908 r
.48363 .17892 .48732 .18348 .49394 .18102 .49025 .17645 Metetra
.663 .741 .908 r
.49025 .17645 .49394 .18102 .50057 .17855 .4969 .17397 Metetra
.663 .741 .908 r
.4969 .17397 .50057 .17855 .50722 .17608 .50355 .17149 Metetra
.663 .741 .908 r
.50355 .17149 .50722 .17608 .51388 .17361 .51023 .16901 Metetra
.663 .741 .908 r
.51023 .16901 .51388 .17361 .52056 .17114 .51692 .16652 Metetra
.663 .74 .908 r
.51692 .16652 .52056 .17114 .52726 .16866 .52363 .16403 Metetra
.662 .74 .908 r
.52363 .16403 .52726 .16866 .53397 .16619 .53035 .16153 Metetra
.662 .74 .908 r
.53035 .16153 .53397 .16619 .5407 .16371 .53709 .15904 Metetra
.662 .739 .907 r
.53709 .15904 .5407 .16371 .54745 .16124 .54385 .15655 Metetra
.661 .738 .907 r
.54385 .15655 .54745 .16124 .55421 .15877 .55062 .15406 Metetra
.66 .738 .907 r
.55062 .15406 .55421 .15877 .56099 .15631 .55741 .15157 Metetra
.659 .736 .907 r
.55741 .15157 .56099 .15631 .56779 .15387 .56422 .1491 Metetra
.658 .735 .906 r
.56422 .1491 .56779 .15387 .57461 .15144 .57105 .14663 Metetra
.657 .734 .906 r
.57105 .14663 .57461 .15144 .58144 .14902 .57789 .14418 Metetra
.655 .732 .905 r
.57789 .14418 .58144 .14902 .58829 .14664 .58475 .14175 Metetra
.654 .729 .905 r
.58475 .14175 .58829 .14664 .59516 .14428 .59163 .13935 Metetra
.651 .727 .904 r
.59163 .13935 .59516 .14428 .60205 .14196 .59853 .13697 Metetra
.649 .724 .903 r
.59853 .13697 .60205 .14196 .60896 .13967 .60545 .13462 Metetra
.646 .72 .902 r
.60545 .13462 .60896 .13967 .61588 .13742 .61238 .13231 Metetra
.644 .716 .901 r
.61238 .13231 .61588 .13742 .62283 .13522 .61934 .13004 Metetra
.641 .712 .899 r
.61934 .13004 .62283 .13522 .6298 .13306 .62632 .12781 Metetra
.638 .709 .898 r
.62632 .12781 .6298 .13306 .63679 .13093 .63331 .12561 Metetra
.636 .705 .896 r
.63331 .12561 .63679 .13093 .6438 .12883 .64033 .12346 Metetra
.634 .702 .895 r
.64033 .12346 .6438 .12883 .65083 .12675 .64737 .12132 Metetra
.632 .7 .894 r
.64737 .12132 .65083 .12675 .65788 .12467 .65443 .1192 Metetra
.632 .698 .893 r
.65443 .1192 .65788 .12467 .66495 .12256 .66151 .11708 Metetra
.633 .698 .893 r
.66151 .11708 .66495 .12256 .67204 .12042 .66861 .11495 Metetra
.635 .7 .893 r
.66861 .11495 .67204 .12042 .67915 .11822 .67573 .11277 Metetra
.638 .703 .894 r
.67573 .11277 .67915 .11822 .68627 .11593 .68287 .11053 Metetra
.642 .708 .895 r
.68287 .11053 .68627 .11593 .69341 .11355 .69002 .10822 Metetra
.647 .714 .896 r
.69002 .10822 .69341 .11355 .70056 .11107 .69719 .10582 Metetra
.653 .721 .899 r
.69719 .10582 .70056 .11107 .70772 .10847 .70437 .10331 Metetra
.658 .728 .901 r
.70437 .10331 .70772 .10847 .7149 .10577 .71156 .1007 Metetra
.664 .736 .903 r
.71156 .1007 .7149 .10577 .72209 .10298 .71877 .09799 Metetra
.669 .742 .905 r
.71877 .09799 .72209 .10298 .72929 .10012 .72599 .09519 Metetra
.673 .748 .907 r
.72599 .09519 .72929 .10012 .7365 .0972 .73322 .09232 Metetra
.676 .752 .908 r
.73322 .09232 .7365 .0972 .74373 .09426 .74047 .0894 Metetra
.618 .755 .943 r
.09687 .32388 .10119 .3274 .10686 .32575 .10254 .32231 Metetra
.614 .758 .948 r
.10254 .32231 .10686 .32575 .11254 .3242 .10822 .32077 Metetra
.615 .76 .948 r
.10822 .32077 .11254 .3242 .11823 .3227 .11392 .31922 Metetra
.623 .76 .944 r
.11392 .31922 .11823 .3227 .12393 .32118 .11965 .31758 Metetra
.636 .756 .935 r
.11965 .31758 .12393 .32118 .12966 .31959 .1254 .31578 Metetra
.651 .749 .921 r
.1254 .31578 .12966 .31959 .13542 .31785 .1312 .31379 Metetra
.666 .74 .905 r
.1312 .31379 .13542 .31785 .14122 .31589 .13704 .31156 Metetra
.679 .73 .889 r
.13704 .31156 .14122 .31589 .14706 .31369 .14292 .30909 Metetra
.688 .72 .874 r
.14292 .30909 .14706 .31369 .15294 .31124 .14884 .3064 Metetra
.694 .712 .862 r
.14884 .3064 .15294 .31124 .15887 .30855 .1548 .30352 Metetra
.698 .705 .853 r
.1548 .30352 .15887 .30855 .16483 .30566 .16078 .30052 Metetra
.7 .701 .848 r
.16078 .30052 .16483 .30566 .17082 .30263 .16677 .29743 Metetra
.7 .7 .846 r
.16677 .29743 .17082 .30263 .17682 .29951 .17278 .29432 Metetra
.699 .7 .847 r
.17278 .29432 .17682 .29951 .18284 .29637 .1788 .29124 Metetra
.697 .702 .851 r
.1788 .29124 .18284 .29637 .18886 .29326 .18482 .28823 Metetra
.694 .706 .857 r
.18482 .28823 .18886 .29326 .19489 .29021 .19084 .2853 Metetra
.691 .71 .863 r
.19084 .2853 .19489 .29021 .20092 .28725 .19686 .28246 Metetra
.687 .715 .87 r
.19686 .28246 .20092 .28725 .20694 .2844 .20289 .27973 Metetra
.683 .72 .877 r
.20289 .27973 .20694 .2844 .21297 .28165 .20891 .27708 Metetra
.68 .724 .883 r
.20891 .27708 .21297 .28165 .219 .27899 .21494 .27452 Metetra
.676 .728 .889 r
.21494 .27452 .219 .27899 .22504 .27643 .22097 .27202 Metetra
.674 .731 .893 r
.22097 .27202 .22504 .27643 .23107 .27393 .22701 .26958 Metetra
.671 .734 .897 r
.22701 .26958 .23107 .27393 .23712 .27149 .23306 .26718 Metetra
.669 .736 .9 r
.23306 .26718 .23712 .27149 .24318 .26909 .23912 .26481 Metetra
.668 .737 .902 r
.23912 .26481 .24318 .26909 .24924 .26673 .24519 .26246 Metetra
.667 .738 .904 r
.24519 .26246 .24924 .26673 .25532 .26438 .25127 .26013 Metetra
.666 .739 .905 r
.25127 .26013 .25532 .26438 .26141 .26206 .25737 .25781 Metetra
.665 .74 .906 r
.25737 .25781 .26141 .26206 .26751 .25974 .26348 .25549 Metetra
.665 .74 .906 r
.26348 .25549 .26751 .25974 .27362 .25743 .2696 .25318 Metetra
.664 .74 .907 r
.2696 .25318 .27362 .25743 .27975 .25512 .27574 .25086 Metetra
.664 .741 .907 r
.27574 .25086 .27975 .25512 .28589 .25281 .28189 .24855 Metetra
.664 .741 .907 r
.28189 .24855 .28589 .25281 .29205 .2505 .28805 .24623 Metetra
.664 .741 .907 r
.28805 .24623 .29205 .2505 .29822 .24819 .29423 .24391 Metetra
.664 .741 .908 r
.29423 .24391 .29822 .24819 .3044 .24587 .30042 .24159 Metetra
.664 .741 .908 r
.30042 .24159 .3044 .24587 .3106 .24355 .30663 .23926 Metetra
.664 .741 .908 r
.30663 .23926 .3106 .24355 .31681 .24123 .31285 .23693 Metetra
.664 .741 .908 r
.31285 .23693 .31681 .24123 .32304 .2389 .31909 .23459 Metetra
.664 .741 .908 r
.31909 .23459 .32304 .2389 .32928 .23657 .32534 .23225 Metetra
.664 .741 .908 r
.32534 .23225 .32928 .23657 .33554 .23423 .3316 .2299 Metetra
.664 .741 .908 r
.3316 .2299 .33554 .23423 .34181 .23189 .33788 .22755 Metetra
.664 .741 .908 r
.33788 .22755 .34181 .23189 .34809 .22954 .34418 .22519 Metetra
.664 .741 .908 r
.34418 .22519 .34809 .22954 .3544 .22718 .35049 .22282 Metetra
.664 .741 .908 r
.35049 .22282 .3544 .22718 .36071 .22482 .35681 .22045 Metetra
.664 .741 .908 r
.35681 .22045 .36071 .22482 .36704 .22246 .36315 .21808 Metetra
.664 .741 .908 r
.36315 .21808 .36704 .22246 .37339 .22009 .36951 .2157 Metetra
.664 .741 .908 r
.36951 .2157 .37339 .22009 .37975 .21771 .37588 .21331 Metetra
.664 .741 .908 r
.37588 .21331 .37975 .21771 .38613 .21533 .38227 .21092 Metetra
.664 .741 .908 r
.38227 .21092 .38613 .21533 .39252 .21294 .38867 .20852 Metetra
.664 .741 .908 r
.38867 .20852 .39252 .21294 .39892 .21055 .39508 .20612 Metetra
.664 .741 .908 r
.39508 .20612 .39892 .21055 .40535 .20815 .40151 .20371 Metetra
.664 .741 .908 r
.40151 .20371 .40535 .20815 .41178 .20575 .40796 .20129 Metetra
.664 .741 .908 r
.40796 .20129 .41178 .20575 .41824 .20334 .41442 .19887 Metetra
.664 .741 .908 r
.41442 .19887 .41824 .20334 .42471 .20092 .4209 .19645 Metetra
.664 .741 .908 r
.4209 .19645 .42471 .20092 .43119 .1985 .4274 .19401 Metetra
.664 .741 .908 r
.4274 .19401 .43119 .1985 .43769 .19607 .43391 .19157 Metetra
.664 .741 .908 r
.43391 .19157 .43769 .19607 .4442 .19364 .44043 .18913 Metetra
.664 .741 .908 r
.44043 .18913 .4442 .19364 .45074 .1912 .44697 .18668 Metetra
.664 .741 .908 r
.44697 .18668 .45074 .1912 .45728 .18876 .45353 .18423 Metetra
.664 .741 .908 r
.45353 .18423 .45728 .18876 .46384 .1863 .4601 .18176 Metetra
.663 .741 .908 r
.4601 .18176 .46384 .1863 .47042 .18385 .46669 .1793 Metetra
.663 .741 .908 r
.46669 .1793 .47042 .18385 .47702 .18139 .47329 .17682 Metetra
.663 .741 .908 r
.47329 .17682 .47702 .18139 .48363 .17892 .47991 .17434 Metetra
.663 .741 .908 r
.47991 .17434 .48363 .17892 .49025 .17645 .48655 .17186 Metetra
.663 .741 .908 r
.48655 .17186 .49025 .17645 .4969 .17397 .4932 .16937 Metetra
.663 .741 .908 r
.4932 .16937 .4969 .17397 .50355 .17149 .49987 .16688 Metetra
.663 .741 .908 r
.49987 .16688 .50355 .17149 .51023 .16901 .50656 .16438 Metetra
.663 .741 .908 r
.50656 .16438 .51023 .16901 .51692 .16652 .51326 .16188 Metetra
.663 .741 .908 r
.51326 .16188 .51692 .16652 .52363 .16403 .51998 .15937 Metetra
.663 .74 .908 r
.51998 .15937 .52363 .16403 .53035 .16153 .52671 .15686 Metetra
.662 .74 .908 r
.52671 .15686 .53035 .16153 .53709 .15904 .53346 .15435 Metetra
.662 .74 .908 r
.53346 .15435 .53709 .15904 .54385 .15655 .54023 .15184 Metetra
.662 .739 .907 r
.54023 .15184 .54385 .15655 .55062 .15406 .54702 .14933 Metetra
.661 .738 .907 r
.54702 .14933 .55062 .15406 .55741 .15157 .55382 .14682 Metetra
.66 .738 .907 r
.55382 .14682 .55741 .15157 .56422 .1491 .56064 .14432 Metetra
.659 .736 .907 r
.56064 .14432 .56422 .1491 .57105 .14663 .56747 .14183 Metetra
.658 .735 .906 r
.56747 .14183 .57105 .14663 .57789 .14418 .57433 .13935 Metetra
.657 .734 .906 r
.57433 .13935 .57789 .14418 .58475 .14175 .5812 .13688 Metetra
.655 .732 .905 r
.5812 .13688 .58475 .14175 .59163 .13935 .58809 .13443 Metetra
.654 .729 .905 r
.58809 .13443 .59163 .13935 .59853 .13697 .595 .132 Metetra
.652 .727 .904 r
.595 .132 .59853 .13697 .60545 .13462 .60192 .1296 Metetra
.649 .724 .903 r
.60192 .1296 .60545 .13462 .61238 .13231 .60887 .12723 Metetra
.647 .721 .902 r
.60887 .12723 .61238 .13231 .61934 .13004 .61583 .1249 Metetra
.644 .717 .901 r
.61583 .1249 .61934 .13004 .62632 .12781 .62282 .1226 Metetra
.641 .713 .9 r
.62282 .1226 .62632 .12781 .63331 .12561 .62982 .12035 Metetra
.639 .71 .898 r
.62982 .12035 .63331 .12561 .64033 .12346 .63685 .11812 Metetra
.636 .706 .897 r
.63685 .11812 .64033 .12346 .64737 .12132 .6439 .11593 Metetra
.635 .703 .896 r
.6439 .11593 .64737 .12132 .65443 .1192 .65097 .11376 Metetra
.633 .701 .895 r
.65097 .11376 .65443 .1192 .66151 .11708 .65806 .11161 Metetra
.633 .7 .894 r
.65806 .11161 .66151 .11708 .66861 .11495 .66517 .10945 Metetra
.634 .7 .893 r
.66517 .10945 .66861 .11495 .67573 .11277 .6723 .10728 Metetra
.636 .701 .893 r
.6723 .10728 .67573 .11277 .68287 .11053 .67945 .10507 Metetra
.639 .704 .894 r
.67945 .10507 .68287 .11053 .69002 .10822 .68661 .1028 Metetra
.642 .709 .895 r
.68661 .1028 .69002 .10822 .69719 .10582 .6938 .10046 Metetra
.647 .715 .897 r
.6938 .10046 .69719 .10582 .70437 .10331 .70099 .09803 Metetra
.653 .721 .899 r
.70099 .09803 .70437 .10331 .71156 .1007 .70821 .09551 Metetra
.658 .728 .901 r
.70821 .09551 .71156 .1007 .71877 .09799 .71543 .09288 Metetra
.664 .735 .903 r
.71543 .09288 .71877 .09799 .72599 .09519 .72267 .09016 Metetra
.668 .742 .905 r
.72267 .09016 .72599 .09519 .73322 .09232 .72992 .08735 Metetra
.672 .747 .907 r
.72992 .08735 .73322 .09232 .74047 .0894 .73718 .08448 Metetra
.617 .758 .946 r
.09252 .32042 .09687 .32388 .10254 .32231 .0982 .31885 Metetra
.619 .759 .946 r
.0982 .31885 .10254 .32231 .10822 .32077 .1039 .31725 Metetra
.627 .758 .941 r
.1039 .31725 .10822 .32077 .11392 .31922 .10962 .31556 Metetra
.639 .754 .932 r
.10962 .31556 .11392 .31922 .11965 .31758 .11538 .31372 Metetra
.654 .748 .919 r
.11538 .31372 .11965 .31758 .1254 .31578 .12117 .31169 Metetra
.667 .739 .904 r
.12117 .31169 .1254 .31578 .1312 .31379 .12701 .30943 Metetra
.679 .729 .888 r
.12701 .30943 .1312 .31379 .13704 .31156 .13288 .30695 Metetra
.688 .72 .874 r
.13288 .30695 .13704 .31156 .14292 .30909 .1388 .30426 Metetra
.694 .712 .863 r
.1388 .30426 .14292 .30909 .14884 .3064 .14475 .3014 Metetra
.697 .707 .855 r
.14475 .3014 .14884 .3064 .1548 .30352 .15072 .29842 Metetra
.699 .703 .85 r
.15072 .29842 .1548 .30352 .16078 .30052 .15671 .29536 Metetra
.699 .701 .849 r
.15671 .29536 .16078 .30052 .16677 .29743 .16271 .29229 Metetra
.698 .702 .85 r
.16271 .29229 .16677 .29743 .17278 .29432 .16872 .28924 Metetra
.696 .704 .854 r
.16872 .28924 .17278 .29432 .1788 .29124 .17473 .28625 Metetra
.693 .708 .859 r
.17473 .28625 .1788 .29124 .18482 .28823 .18075 .28334 Metetra
.69 .712 .865 r
.18075 .28334 .18482 .28823 .19084 .2853 .18676 .28053 Metetra
.686 .716 .872 r
.18676 .28053 .19084 .2853 .19686 .28246 .19278 .2778 Metetra
.683 .721 .878 r
.19278 .2778 .19686 .28246 .20289 .27973 .1988 .27517 Metetra
.679 .725 .884 r
.1988 .27517 .20289 .27973 .20891 .27708 .20482 .27261 Metetra
.676 .728 .889 r
.20482 .27261 .20891 .27708 .21494 .27452 .21085 .27011 Metetra
.673 .731 .894 r
.21085 .27011 .21494 .27452 .22097 .27202 .21688 .26767 Metetra
.671 .734 .897 r
.21688 .26767 .22097 .27202 .22701 .26958 .22293 .26526 Metetra
.669 .736 .9 r
.22293 .26526 .22701 .26958 .23306 .26718 .22898 .26289 Metetra
.668 .737 .902 r
.22898 .26289 .23306 .26718 .23912 .26481 .23505 .26054 Metetra
.667 .738 .904 r
.23505 .26054 .23912 .26481 .24519 .26246 .24112 .2582 Metetra
.666 .739 .905 r
.24112 .2582 .24519 .26246 .25127 .26013 .24721 .25587 Metetra
.665 .74 .906 r
.24721 .25587 .25127 .26013 .25737 .25781 .25332 .25355 Metetra
.665 .74 .906 r
.25332 .25355 .25737 .25781 .26348 .25549 .25943 .25123 Metetra
.664 .741 .907 r
.25943 .25123 .26348 .25549 .2696 .25318 .26556 .24892 Metetra
.664 .741 .907 r
.26556 .24892 .2696 .25318 .27574 .25086 .27171 .2466 Metetra
.664 .741 .907 r
.27171 .2466 .27574 .25086 .28189 .24855 .27786 .24427 Metetra
.664 .741 .907 r
.27786 .24427 .28189 .24855 .28805 .24623 .28404 .24195 Metetra
.664 .741 .908 r
.28404 .24195 .28805 .24623 .29423 .24391 .29022 .23962 Metetra
.664 .741 .908 r
.29022 .23962 .29423 .24391 .30042 .24159 .29642 .23729 Metetra
.664 .741 .908 r
.29642 .23729 .30042 .24159 .30663 .23926 .30264 .23495 Metetra
.664 .741 .908 r
.30264 .23495 .30663 .23926 .31285 .23693 .30887 .23261 Metetra
.664 .741 .908 r
.30887 .23261 .31285 .23693 .31909 .23459 .31512 .23026 Metetra
.664 .741 .908 r
.31512 .23026 .31909 .23459 .32534 .23225 .32138 .22791 Metetra
.664 .741 .908 r
.32138 .22791 .32534 .23225 .3316 .2299 .32765 .22555 Metetra
.664 .741 .908 r
.32765 .22555 .3316 .2299 .33788 .22755 .33394 .22319 Metetra
.664 .741 .908 r
.33394 .22319 .33788 .22755 .34418 .22519 .34024 .22082 Metetra
.664 .741 .908 r
.34024 .22082 .34418 .22519 .35049 .22282 .34656 .21844 Metetra
.664 .741 .908 r
.34656 .21844 .35049 .22282 .35681 .22045 .3529 .21606 Metetra
.664 .741 .908 r
.3529 .21606 .35681 .22045 .36315 .21808 .35925 .21368 Metetra
.664 .741 .908 r
.35925 .21368 .36315 .21808 .36951 .2157 .36561 .21129 Metetra
.664 .741 .908 r
.36561 .21129 .36951 .2157 .37588 .21331 .37199 .20889 Metetra
.664 .741 .908 r
.37199 .20889 .37588 .21331 .38227 .21092 .37839 .20649 Metetra
.664 .741 .908 r
.37839 .20649 .38227 .21092 .38867 .20852 .3848 .20408 Metetra
.664 .741 .908 r
.3848 .20408 .38867 .20852 .39508 .20612 .39122 .20167 Metetra
.664 .741 .908 r
.39122 .20167 .39508 .20612 .40151 .20371 .39767 .19925 Metetra
.664 .741 .908 r
.39767 .19925 .40151 .20371 .40796 .20129 .40412 .19682 Metetra
.664 .741 .908 r
.40412 .19682 .40796 .20129 .41442 .19887 .41059 .19439 Metetra
.664 .741 .908 r
.41059 .19439 .41442 .19887 .4209 .19645 .41708 .19195 Metetra
.664 .741 .908 r
.41708 .19195 .4209 .19645 .4274 .19401 .42359 .18951 Metetra
.664 .741 .908 r
.42359 .18951 .4274 .19401 .43391 .19157 .43011 .18706 Metetra
.664 .741 .908 r
.43011 .18706 .43391 .19157 .44043 .18913 .43664 .1846 Metetra
.664 .741 .908 r
.43664 .1846 .44043 .18913 .44697 .18668 .44319 .18214 Metetra
.664 .741 .908 r
.44319 .18214 .44697 .18668 .45353 .18423 .44976 .17967 Metetra
.664 .741 .908 r
.44976 .17967 .45353 .18423 .4601 .18176 .45634 .1772 Metetra
.664 .741 .908 r
.45634 .1772 .4601 .18176 .46669 .1793 .46294 .17472 Metetra
.663 .741 .908 r
.46294 .17472 .46669 .1793 .47329 .17682 .46955 .17224 Metetra
.663 .741 .908 r
.46955 .17224 .47329 .17682 .47991 .17434 .47618 .16975 Metetra
.663 .741 .908 r
.47618 .16975 .47991 .17434 .48655 .17186 .48283 .16725 Metetra
.663 .741 .908 r
.48283 .16725 .48655 .17186 .4932 .16937 .4895 .16475 Metetra
.663 .741 .908 r
.4895 .16475 .4932 .16937 .49987 .16688 .49617 .16225 Metetra
.663 .741 .908 r
.49617 .16225 .49987 .16688 .50656 .16438 .50287 .15973 Metetra
.663 .741 .908 r
.50287 .15973 .50656 .16438 .51326 .16188 .50958 .15722 Metetra
.663 .741 .908 r
.50958 .15722 .51326 .16188 .51998 .15937 .51631 .1547 Metetra
.663 .741 .908 r
.51631 .1547 .51998 .15937 .52671 .15686 .52306 .15218 Metetra
.663 .74 .908 r
.52306 .15218 .52671 .15686 .53346 .15435 .52982 .14965 Metetra
.662 .74 .908 r
.52982 .14965 .53346 .15435 .54023 .15184 .5366 .14712 Metetra
.662 .74 .908 r
.5366 .14712 .54023 .15184 .54702 .14933 .54339 .14459 Metetra
.662 .739 .907 r
.54339 .14459 .54702 .14933 .55382 .14682 .55021 .14207 Metetra
.661 .738 .907 r
.55021 .14207 .55382 .14682 .56064 .14432 .55704 .13954 Metetra
.66 .738 .907 r
.55704 .13954 .56064 .14432 .56747 .14183 .56388 .13702 Metetra
.659 .736 .907 r
.56388 .13702 .56747 .14183 .57433 .13935 .57075 .13451 Metetra
.658 .735 .906 r
.57075 .13451 .57433 .13935 .5812 .13688 .57763 .13201 Metetra
.657 .734 .906 r
.57763 .13201 .5812 .13688 .58809 .13443 .58453 .12952 Metetra
.656 .732 .906 r
.58453 .12952 .58809 .13443 .595 .132 .59145 .12705 Metetra
.654 .73 .905 r
.59145 .12705 .595 .132 .60192 .1296 .59838 .12461 Metetra
.652 .727 .904 r
.59838 .12461 .60192 .1296 .60887 .12723 .60534 .12219 Metetra
.649 .724 .903 r
.60534 .12219 .60887 .12723 .61583 .1249 .61231 .1198 Metetra
.647 .721 .902 r
.61231 .1198 .61583 .1249 .62282 .1226 .61931 .11744 Metetra
.644 .717 .901 r
.61931 .11744 .62282 .1226 .62982 .12035 .62632 .11512 Metetra
.642 .714 .9 r
.62632 .11512 .62982 .12035 .63685 .11812 .63336 .11283 Metetra
.639 .71 .899 r
.63336 .11283 .63685 .11812 .6439 .11593 .64042 .11058 Metetra
.637 .707 .897 r
.64042 .11058 .6439 .11593 .65097 .11376 .64749 .10836 Metetra
.635 .704 .896 r
.64749 .10836 .65097 .11376 .65806 .11161 .65459 .10616 Metetra
.634 .702 .895 r
.65459 .10616 .65806 .11161 .66517 .10945 .66171 .10397 Metetra
.634 .701 .894 r
.66171 .10397 .66517 .10945 .6723 .10728 .66885 .10178 Metetra
.635 .701 .894 r
.66885 .10178 .6723 .10728 .67945 .10507 .67601 .09957 Metetra
.637 .703 .894 r
.67601 .09957 .67945 .10507 .68661 .1028 .68319 .09732 Metetra
.639 .706 .895 r
.68319 .09732 .68661 .1028 .6938 .10046 .69039 .09502 Metetra
.643 .71 .896 r
.69039 .09502 .6938 .10046 .70099 .09803 .6976 .09265 Metetra
.648 .715 .897 r
.6976 .09265 .70099 .09803 .70821 .09551 .70483 .0902 Metetra
.653 .722 .899 r
.70483 .0902 .70821 .09551 .71543 .09288 .71207 .08765 Metetra
.658 .728 .901 r
.71207 .08765 .71543 .09288 .72267 .09016 .71933 .08501 Metetra
.663 .735 .903 r
.71933 .08501 .72267 .09016 .72992 .08735 .72659 .08228 Metetra
.668 .741 .905 r
.72659 .08228 .72992 .08735 .73718 .08448 .73388 .07946 Metetra
.622 .758 .943 r
.08816 .31691 .09252 .32042 .0982 .31885 .09385 .31527 Metetra
.63 .757 .938 r
.09385 .31527 .0982 .31885 .1039 .31725 .09957 .31354 Metetra
.642 .753 .929 r
.09957 .31354 .1039 .31725 .10962 .31556 .10533 .31166 Metetra
.656 .746 .916 r
.10533 .31166 .10962 .31556 .11538 .31372 .11112 .3096 Metetra
.669 .738 .902 r
.11112 .3096 .11538 .31372 .12117 .31169 .11695 .30732 Metetra
.679 .729 .887 r
.11695 .30732 .12117 .31169 .12701 .30943 .12283 .30482 Metetra
.688 .72 .874 r
.12283 .30482 .12701 .30943 .13288 .30695 .12874 .30214 Metetra
.693 .713 .864 r
.12874 .30214 .13288 .30695 .1388 .30426 .13468 .29929 Metetra
.697 .708 .856 r
.13468 .29929 .1388 .30426 .14475 .3014 .14064 .29633 Metetra
.698 .704 .852 r
.14064 .29633 .14475 .3014 .15072 .29842 .14662 .2933 Metetra
.698 .703 .851 r
.14662 .2933 .15072 .29842 .15671 .29536 .15262 .29026 Metetra
.697 .704 .852 r
.15262 .29026 .15671 .29536 .16271 .29229 .15862 .28724 Metetra
.695 .706 .856 r
.15862 .28724 .16271 .29229 .16872 .28924 .16463 .28428 Metetra
.693 .709 .861 r
.16463 .28428 .16872 .28924 .17473 .28625 .17063 .28139 Metetra
.689 .713 .867 r
.17063 .28139 .17473 .28625 .18075 .28334 .17664 .27859 Metetra
.686 .717 .873 r
.17664 .27859 .18075 .28334 .18676 .28053 .18265 .27588 Metetra
.682 .721 .879 r
.18265 .27588 .18676 .28053 .19278 .2778 .18866 .27325 Metetra
.679 .725 .885 r
.18866 .27325 .19278 .2778 .1988 .27517 .19468 .27069 Metetra
.676 .729 .89 r
.19468 .27069 .1988 .27517 .20482 .27261 .2007 .2682 Metetra
.673 .732 .894 r
.2007 .2682 .20482 .27261 .21085 .27011 .20673 .26575 Metetra
.671 .734 .897 r
.20673 .26575 .21085 .27011 .21688 .26767 .21277 .26334 Metetra
.669 .736 .9 r
.21277 .26334 .21688 .26767 .22293 .26526 .21882 .26097 Metetra
.668 .737 .902 r
.21882 .26097 .22293 .26526 .22898 .26289 .22488 .25861 Metetra
.667 .738 .904 r
.22488 .25861 .22898 .26289 .23505 .26054 .23095 .25627 Metetra
.666 .739 .905 r
.23095 .25627 .23505 .26054 .24112 .2582 .23703 .25394 Metetra
.665 .74 .906 r
.23703 .25394 .24112 .2582 .24721 .25587 .24313 .25161 Metetra
.665 .74 .906 r
.24313 .25161 .24721 .25587 .25332 .25355 .24924 .24929 Metetra
.664 .74 .907 r
.24924 .24929 .25332 .25355 .25943 .25123 .25537 .24696 Metetra
.664 .741 .907 r
.25537 .24696 .25943 .25123 .26556 .24892 .26151 .24464 Metetra
.664 .741 .907 r
.26151 .24464 .26556 .24892 .27171 .2466 .26766 .24231 Metetra
.664 .741 .907 r
.26766 .24231 .27171 .2466 .27786 .24427 .27382 .23998 Metetra
.664 .741 .908 r
.27382 .23998 .27786 .24427 .28404 .24195 .28 .23765 Metetra
.664 .741 .908 r
.28 .23765 .28404 .24195 .29022 .23962 .2862 .23531 Metetra
.664 .741 .908 r
.2862 .23531 .29022 .23962 .29642 .23729 .29241 .23297 Metetra
.664 .741 .908 r
.29241 .23297 .29642 .23729 .30264 .23495 .29863 .23062 Metetra
.664 .741 .908 r
.29863 .23062 .30264 .23495 .30887 .23261 .30487 .22827 Metetra
.664 .741 .908 r
.30487 .22827 .30887 .23261 .31512 .23026 .31113 .22591 Metetra
.664 .741 .908 r
.31113 .22591 .31512 .23026 .32138 .22791 .3174 .22355 Metetra
.664 .741 .908 r
.3174 .22355 .32138 .22791 .32765 .22555 .32368 .22118 Metetra
.664 .741 .908 r
.32368 .22118 .32765 .22555 .33394 .22319 .32998 .21881 Metetra
.664 .741 .908 r
.32998 .21881 .33394 .22319 .34024 .22082 .33629 .21643 Metetra
.664 .741 .908 r
.33629 .21643 .34024 .22082 .34656 .21844 .34262 .21405 Metetra
.664 .741 .908 r
.34262 .21405 .34656 .21844 .3529 .21606 .34897 .21166 Metetra
.664 .741 .908 r
.34897 .21166 .3529 .21606 .35925 .21368 .35532 .20926 Metetra
.664 .741 .908 r
.35532 .20926 .35925 .21368 .36561 .21129 .3617 .20686 Metetra
.664 .741 .908 r
.3617 .20686 .36561 .21129 .37199 .20889 .36809 .20445 Metetra
.664 .741 .908 r
.36809 .20445 .37199 .20889 .37839 .20649 .37449 .20204 Metetra
.664 .741 .908 r
.37449 .20204 .37839 .20649 .3848 .20408 .38091 .19962 Metetra
.664 .741 .908 r
.38091 .19962 .3848 .20408 .39122 .20167 .38735 .19719 Metetra
.664 .741 .908 r
.38735 .19719 .39122 .20167 .39767 .19925 .3938 .19476 Metetra
.664 .741 .908 r
.3938 .19476 .39767 .19925 .40412 .19682 .40027 .19233 Metetra
.664 .741 .908 r
.40027 .19233 .40412 .19682 .41059 .19439 .40675 .18988 Metetra
.664 .741 .908 r
.40675 .18988 .41059 .19439 .41708 .19195 .41325 .18743 Metetra
.664 .741 .908 r
.41325 .18743 .41708 .19195 .42359 .18951 .41976 .18498 Metetra
.664 .741 .908 r
.41976 .18498 .42359 .18951 .43011 .18706 .42629 .18252 Metetra
.664 .741 .908 r
.42629 .18252 .43011 .18706 .43664 .1846 .43283 .18005 Metetra
.664 .741 .908 r
.43283 .18005 .43664 .1846 .44319 .18214 .43939 .17758 Metetra
.664 .741 .908 r
.43939 .17758 .44319 .18214 .44976 .17967 .44597 .1751 Metetra
.664 .741 .908 r
.44597 .1751 .44976 .17967 .45634 .1772 .45256 .17262 Metetra
.664 .741 .908 r
.45256 .17262 .45634 .1772 .46294 .17472 .45917 .17013 Metetra
.664 .741 .908 r
.45917 .17013 .46294 .17472 .46955 .17224 .4658 .16763 Metetra
.663 .741 .908 r
.4658 .16763 .46955 .17224 .47618 .16975 .47244 .16513 Metetra
.663 .741 .908 r
.47244 .16513 .47618 .16975 .48283 .16725 .4791 .16263 Metetra
.663 .741 .908 r
.4791 .16263 .48283 .16725 .4895 .16475 .48577 .16011 Metetra
.663 .741 .908 r
.48577 .16011 .4895 .16475 .49617 .16225 .49246 .15759 Metetra
.663 .741 .908 r
.49246 .15759 .49617 .16225 .50287 .15973 .49917 .15507 Metetra
.663 .741 .908 r
.49917 .15507 .50287 .15973 .50958 .15722 .50589 .15254 Metetra
.663 .741 .908 r
.50589 .15254 .50958 .15722 .51631 .1547 .51263 .15001 Metetra
.663 .741 .908 r
.51263 .15001 .51631 .1547 .52306 .15218 .51939 .14747 Metetra
.663 .741 .908 r
.51939 .14747 .52306 .15218 .52982 .14965 .52616 .14493 Metetra
.663 .74 .908 r
.52616 .14493 .52982 .14965 .5366 .14712 .53295 .14239 Metetra
.662 .74 .908 r
.53295 .14239 .5366 .14712 .54339 .14459 .53975 .13984 Metetra
.662 .74 .908 r
.53975 .13984 .54339 .14459 .55021 .14207 .54658 .13729 Metetra
.662 .739 .907 r
.54658 .13729 .55021 .14207 .55704 .13954 .55342 .13475 Metetra
.661 .738 .907 r
.55342 .13475 .55704 .13954 .56388 .13702 .56028 .13221 Metetra
.66 .738 .907 r
.56028 .13221 .56388 .13702 .57075 .13451 .56715 .12967 Metetra
.659 .736 .907 r
.56715 .12967 .57075 .13451 .57763 .13201 .57404 .12714 Metetra
.658 .735 .906 r
.57404 .12714 .57763 .13201 .58453 .12952 .58095 .12462 Metetra
.657 .734 .906 r
.58095 .12462 .58453 .12952 .59145 .12705 .58788 .12211 Metetra
.656 .732 .906 r
.58788 .12211 .59145 .12705 .59838 .12461 .59483 .11962 Metetra
.654 .73 .905 r
.59483 .11962 .59838 .12461 .60534 .12219 .6018 .11716 Metetra
.652 .727 .904 r
.6018 .11716 .60534 .12219 .61231 .1198 .60878 .11472 Metetra
.65 .724 .903 r
.60878 .11472 .61231 .1198 .61931 .11744 .61578 .1123 Metetra
.647 .721 .902 r
.61578 .1123 .61931 .11744 .62632 .11512 .62281 .10992 Metetra
.645 .718 .901 r
.62281 .10992 .62632 .11512 .63336 .11283 .62985 .10758 Metetra
.642 .715 .9 r
.62985 .10758 .63336 .11283 .64042 .11058 .63692 .10526 Metetra
.64 .711 .899 r
.63692 .10526 .64042 .11058 .64749 .10836 .644 .10298 Metetra
.638 .708 .898 r
.644 .10298 .64749 .10836 .65459 .10616 .65111 .10073 Metetra
.636 .706 .896 r
.65111 .10073 .65459 .10616 .66171 .10397 .65824 .0985 Metetra
.635 .704 .896 r
.65824 .0985 .66171 .10397 .66885 .10178 .66539 .09627 Metetra
.635 .703 .895 r
.66539 .09627 .66885 .10178 .67601 .09957 .67256 .09405 Metetra
.636 .703 .895 r
.67256 .09405 .67601 .09957 .68319 .09732 .67975 .0918 Metetra
.637 .704 .895 r
.67975 .0918 .68319 .09732 .69039 .09502 .68696 .08953 Metetra
.64 .707 .895 r
.68696 .08953 .69039 .09502 .6976 .09265 .69419 .08719 Metetra
.644 .711 .896 r
.69419 .08719 .6976 .09265 .70483 .0902 .70143 .0848 Metetra
.648 .716 .898 r
.70143 .0848 .70483 .0902 .71207 .08765 .70869 .08232 Metetra
.653 .722 .899 r
.70869 .08232 .71207 .08765 .71933 .08501 .71596 .07975 Metetra
.658 .728 .901 r
.71596 .07975 .71933 .08501 .72659 .08228 .72325 .0771 Metetra
.663 .735 .903 r
.72325 .0771 .72659 .08228 .73388 .07946 .73055 .07435 Metetra
.634 .756 .936 r
.08379 .3133 .08816 .31691 .09385 .31527 .08951 .31152 Metetra
.645 .751 .927 r
.08951 .31152 .09385 .31527 .09957 .31354 .09526 .30961 Metetra
.658 .745 .915 r
.09526 .30961 .09957 .31354 .10533 .31166 .10105 .30751 Metetra
.669 .737 .901 r
.10105 .30751 .10533 .31166 .11112 .3096 .10688 .30521 Metetra
.68 .729 .887 r
.10688 .30521 .11112 .3096 .11695 .30732 .11275 .30271 Metetra
.687 .721 .875 r
.11275 .30271 .11695 .30732 .12283 .30482 .11865 .30002 Metetra
.693 .714 .865 r
.11865 .30002 .12283 .30482 .12874 .30214 .12458 .29719 Metetra
.696 .709 .858 r
.12458 .29719 .12874 .30214 .13468 .29929 .13054 .29425 Metetra
.697 .706 .854 r
.13054 .29425 .13468 .29929 .14064 .29633 .13652 .29125 Metetra
.697 .705 .853 r
.13652 .29125 .14064 .29633 .14662 .2933 .14251 .28824 Metetra
.696 .705 .854 r
.14251 .28824 .14662 .2933 .15262 .29026 .1485 .28524 Metetra
.694 .707 .858 r
.1485 .28524 .15262 .29026 .15862 .28724 .1545 .28231 Metetra
.692 .71 .862 r
.1545 .28231 .15862 .28724 .16463 .28428 .1605 .27944 Metetra
.689 .714 .868 r
.1605 .27944 .16463 .28428 .17063 .28139 .1665 .27665 Metetra
.685 .718 .874 r
.1665 .27665 .17063 .28139 .17664 .27859 .17251 .27395 Metetra
.682 .722 .88 r
.17251 .27395 .17664 .27859 .18265 .27588 .17851 .27133 Metetra
.679 .726 .885 r
.17851 .27133 .18265 .27588 .18866 .27325 .18452 .26877 Metetra
.676 .729 .89 r
.18452 .26877 .18866 .27325 .19468 .27069 .19054 .26628 Metetra
.673 .732 .894 r
.19054 .26628 .19468 .27069 .2007 .2682 .19656 .26383 Metetra
.671 .734 .897 r
.19656 .26383 .2007 .2682 .20673 .26575 .2026 .26142 Metetra
.669 .736 .9 r
.2026 .26142 .20673 .26575 .21277 .26334 .20864 .25904 Metetra
.668 .737 .902 r
.20864 .25904 .21277 .26334 .21882 .26097 .21469 .25668 Metetra
.667 .738 .904 r
.21469 .25668 .21882 .26097 .22488 .25861 .22076 .25433 Metetra
.666 .739 .905 r
.22076 .25433 .22488 .25861 .23095 .25627 .22684 .252 Metetra
.665 .74 .906 r
.22684 .252 .23095 .25627 .23703 .25394 .23293 .24966 Metetra
.665 .74 .906 r
.23293 .24966 .23703 .25394 .24313 .25161 .23903 .24734 Metetra
.664 .74 .907 r
.23903 .24734 .24313 .25161 .24924 .24929 .24515 .24501 Metetra
.664 .741 .907 r
.24515 .24501 .24924 .24929 .25537 .24696 .25128 .24268 Metetra
.664 .741 .907 r
.25128 .24268 .25537 .24696 .26151 .24464 .25743 .24035 Metetra
.664 .741 .907 r
.25743 .24035 .26151 .24464 .26766 .24231 .26359 .23801 Metetra
.664 .741 .908 r
.26359 .23801 .26766 .24231 .27382 .23998 .26977 .23568 Metetra
.664 .741 .908 r
.26977 .23568 .27382 .23998 .28 .23765 .27596 .23333 Metetra
.664 .741 .908 r
.27596 .23333 .28 .23765 .2862 .23531 .28216 .23099 Metetra
.664 .741 .908 r
.28216 .23099 .2862 .23531 .29241 .23297 .28838 .22863 Metetra
.664 .741 .908 r
.28838 .22863 .29241 .23297 .29863 .23062 .29461 .22628 Metetra
.664 .741 .908 r
.29461 .22628 .29863 .23062 .30487 .22827 .30086 .22392 Metetra
.664 .741 .908 r
.30086 .22392 .30487 .22827 .31113 .22591 .30712 .22155 Metetra
.664 .741 .908 r
.30712 .22155 .31113 .22591 .3174 .22355 .3134 .21918 Metetra
.664 .741 .908 r
.3134 .21918 .3174 .22355 .32368 .22118 .31969 .2168 Metetra
.664 .741 .908 r
.31969 .2168 .32368 .22118 .32998 .21881 .326 .21441 Metetra
.664 .741 .908 r
.326 .21441 .32998 .21881 .33629 .21643 .33232 .21202 Metetra
.664 .741 .908 r
.33232 .21202 .33629 .21643 .34262 .21405 .33866 .20963 Metetra
.664 .741 .908 r
.33866 .20963 .34262 .21405 .34897 .21166 .34502 .20723 Metetra
.664 .741 .908 r
.34502 .20723 .34897 .21166 .35532 .20926 .35138 .20482 Metetra
.664 .741 .908 r
.35138 .20482 .35532 .20926 .3617 .20686 .35777 .20241 Metetra
.664 .741 .908 r
.35777 .20241 .3617 .20686 .36809 .20445 .36417 .19999 Metetra
.664 .741 .908 r
.36417 .19999 .36809 .20445 .37449 .20204 .37058 .19757 Metetra
.664 .741 .908 r
.37058 .19757 .37449 .20204 .38091 .19962 .37701 .19514 Metetra
.664 .741 .908 r
.37701 .19514 .38091 .19962 .38735 .19719 .38345 .1927 Metetra
.664 .741 .908 r
.38345 .1927 .38735 .19719 .3938 .19476 .38992 .19026 Metetra
.664 .741 .908 r
.38992 .19026 .3938 .19476 .40027 .19233 .39639 .18781 Metetra
.664 .741 .908 r
.39639 .18781 .40027 .19233 .40675 .18988 .40288 .18536 Metetra
.664 .741 .908 r
.40288 .18536 .40675 .18988 .41325 .18743 .40939 .1829 Metetra
.664 .741 .908 r
.40939 .1829 .41325 .18743 .41976 .18498 .41591 .18043 Metetra
.664 .741 .908 r
.41591 .18043 .41976 .18498 .42629 .18252 .42245 .17796 Metetra
.664 .741 .908 r
.42245 .17796 .42629 .18252 .43283 .18005 .42901 .17549 Metetra
.664 .741 .908 r
.42901 .17549 .43283 .18005 .43939 .17758 .43558 .173 Metetra
.664 .741 .908 r
.43558 .173 .43939 .17758 .44597 .1751 .44217 .17051 Metetra
.664 .741 .908 r
.44217 .17051 .44597 .1751 .45256 .17262 .44877 .16802 Metetra
.664 .741 .908 r
.44877 .16802 .45256 .17262 .45917 .17013 .45539 .16552 Metetra
.664 .741 .908 r
.45539 .16552 .45917 .17013 .4658 .16763 .46202 .16301 Metetra
.664 .741 .908 r
.46202 .16301 .4658 .16763 .47244 .16513 .46868 .1605 Metetra
.663 .741 .908 r
.46868 .1605 .47244 .16513 .4791 .16263 .47534 .15798 Metetra
.663 .741 .908 r
.47534 .15798 .4791 .16263 .48577 .16011 .48203 .15545 Metetra
.663 .741 .908 r
.48203 .15545 .48577 .16011 .49246 .15759 .48873 .15292 Metetra
.663 .741 .908 r
.48873 .15292 .49246 .15759 .49917 .15507 .49545 .15039 Metetra
.663 .741 .908 r
.49545 .15039 .49917 .15507 .50589 .15254 .50218 .14784 Metetra
.663 .741 .908 r
.50218 .14784 .50589 .15254 .51263 .15001 .50893 .1453 Metetra
.663 .741 .908 r
.50893 .1453 .51263 .15001 .51939 .14747 .5157 .14275 Metetra
.663 .741 .908 r
.5157 .14275 .51939 .14747 .52616 .14493 .52248 .14019 Metetra
.663 .741 .908 r
.52248 .14019 .52616 .14493 .53295 .14239 .52928 .13763 Metetra
.663 .74 .908 r
.52928 .13763 .53295 .14239 .53975 .13984 .5361 .13507 Metetra
.662 .74 .908 r
.5361 .13507 .53975 .13984 .54658 .13729 .54293 .13251 Metetra
.662 .74 .908 r
.54293 .13251 .54658 .13729 .55342 .13475 .54978 .12994 Metetra
.662 .739 .907 r
.54978 .12994 .55342 .13475 .56028 .13221 .55665 .12738 Metetra
.661 .738 .907 r
.55665 .12738 .56028 .13221 .56715 .12967 .56354 .12482 Metetra
.66 .737 .907 r
.56354 .12482 .56715 .12967 .57404 .12714 .57044 .12226 Metetra
.659 .736 .907 r
.57044 .12226 .57404 .12714 .58095 .12462 .57736 .11971 Metetra
.658 .735 .906 r
.57736 .11971 .58095 .12462 .58788 .12211 .5843 .11718 Metetra
.657 .734 .906 r
.5843 .11718 .58788 .12211 .59483 .11962 .59126 .11465 Metetra
.656 .732 .906 r
.59126 .11465 .59483 .11962 .6018 .11716 .59824 .11214 Metetra
.654 .73 .905 r
.59824 .11214 .6018 .11716 .60878 .11472 .60523 .10966 Metetra
.652 .727 .904 r
.60523 .10966 .60878 .11472 .61578 .1123 .61225 .10719 Metetra
.65 .725 .903 r
.61225 .10719 .61578 .1123 .62281 .10992 .61928 .10476 Metetra
.648 .722 .902 r
.61928 .10476 .62281 .10992 .62985 .10758 .62633 .10236 Metetra
.645 .719 .901 r
.62633 .10236 .62985 .10758 .63692 .10526 .63341 .09998 Metetra
.643 .715 .9 r
.63341 .09998 .63692 .10526 .644 .10298 .6405 .09764 Metetra
.641 .712 .899 r
.6405 .09764 .644 .10298 .65111 .10073 .64762 .09533 Metetra
.639 .709 .898 r
.64762 .09533 .65111 .10073 .65824 .0985 .65476 .09305 Metetra
.637 .707 .897 r
.65476 .09305 .65824 .0985 .66539 .09627 .66192 .09078 Metetra
.636 .705 .896 r
.66192 .09078 .66539 .09627 .67256 .09405 .6691 .08853 Metetra
.636 .704 .895 r
.6691 .08853 .67256 .09405 .67975 .0918 .6763 .08627 Metetra
.637 .704 .895 r
.6763 .08627 .67975 .0918 .68696 .08953 .68352 .08399 Metetra
.638 .705 .895 r
.68352 .08399 .68696 .08953 .69419 .08719 .69076 .08168 Metetra
.641 .708 .896 r
.69076 .08168 .69419 .08719 .70143 .0848 .69801 .07932 Metetra
.644 .712 .897 r
.69801 .07932 .70143 .0848 .70869 .08232 .70529 .07689 Metetra
.648 .717 .898 r
.70529 .07689 .70869 .08232 .71596 .07975 .71258 .07439 Metetra
.653 .722 .9 r
.71258 .07439 .71596 .07975 .72325 .0771 .71988 .0718 Metetra
.658 .729 .902 r
.71988 .0718 .72325 .0771 .73055 .07435 .7272 .06913 Metetra
.647 .75 .924 r
.07943 .30951 .08379 .3133 .08951 .31152 .08517 .30755 Metetra
.659 .744 .913 r
.08517 .30755 .08951 .31152 .09526 .30961 .09096 .30543 Metetra
.67 .736 .9 r
.09096 .30543 .09526 .30961 .10105 .30751 .09679 .30311 Metetra
.68 .728 .887 r
.09679 .30311 .10105 .30751 .10688 .30521 .10265 .3006 Metetra
.687 .721 .875 r
.10265 .3006 .10688 .30521 .11275 .30271 .10855 .29792 Metetra
.692 .715 .866 r
.10855 .29792 .11275 .30271 .11865 .30002 .11447 .2951 Metetra
.695 .71 .86 r
.11447 .2951 .11865 .30002 .12458 .29719 .12042 .29218 Metetra
.696 .707 .856 r
.12042 .29218 .12458 .29719 .13054 .29425 .12639 .28921 Metetra
.697 .706 .855 r
.12639 .28921 .13054 .29425 .13652 .29125 .13237 .28622 Metetra
.696 .707 .856 r
.13237 .28622 .13652 .29125 .14251 .28824 .13836 .28325 Metetra
.694 .709 .86 r
.13836 .28325 .14251 .28824 .1485 .28524 .14435 .28033 Metetra
.691 .712 .864 r
.14435 .28033 .1485 .28524 .1545 .28231 .15035 .27749 Metetra
.688 .715 .869 r
.15035 .27749 .1545 .28231 .1605 .27944 .15634 .27471 Metetra
.685 .719 .875 r
.15634 .27471 .1605 .27944 .1665 .27665 .16234 .27202 Metetra
.682 .723 .881 r
.16234 .27202 .1665 .27665 .17251 .27395 .16834 .2694 Metetra
.678 .726 .886 r
.16834 .2694 .17251 .27395 .17851 .27133 .17434 .26685 Metetra
.676 .729 .891 r
.17434 .26685 .17851 .27133 .18452 .26877 .18036 .26435 Metetra
.673 .732 .894 r
.18036 .26435 .18452 .26877 .19054 .26628 .18637 .26191 Metetra
.671 .734 .898 r
.18637 .26191 .19054 .26628 .19656 .26383 .1924 .25949 Metetra
.669 .736 .9 r
.1924 .25949 .19656 .26383 .2026 .26142 .19844 .25711 Metetra
.668 .737 .902 r
.19844 .25711 .2026 .26142 .20864 .25904 .20449 .25474 Metetra
.667 .738 .904 r
.20449 .25474 .20864 .25904 .21469 .25668 .21055 .25239 Metetra
.666 .739 .905 r
.21055 .25239 .21469 .25668 .22076 .25433 .21662 .25005 Metetra
.665 .74 .906 r
.21662 .25005 .22076 .25433 .22684 .252 .22271 .24771 Metetra
.665 .74 .906 r
.22271 .24771 .22684 .252 .23293 .24966 .2288 .24538 Metetra
.664 .74 .907 r
.2288 .24538 .23293 .24966 .23903 .24734 .23492 .24305 Metetra
.664 .741 .907 r
.23492 .24305 .23903 .24734 .24515 .24501 .24104 .24071 Metetra
.664 .741 .907 r
.24104 .24071 .24515 .24501 .25128 .24268 .24718 .23838 Metetra
.664 .741 .907 r
.24718 .23838 .25128 .24268 .25743 .24035 .25334 .23604 Metetra
.664 .741 .908 r
.25334 .23604 .25743 .24035 .26359 .23801 .25951 .2337 Metetra
.664 .741 .908 r
.25951 .2337 .26359 .23801 .26977 .23568 .26569 .23135 Metetra
.664 .741 .908 r
.26569 .23135 .26977 .23568 .27596 .23333 .27189 .229 Metetra
.664 .741 .908 r
.27189 .229 .27596 .23333 .28216 .23099 .2781 .22664 Metetra
.664 .741 .908 r
.2781 .22664 .28216 .23099 .28838 .22863 .28433 .22428 Metetra
.664 .741 .908 r
.28433 .22428 .28838 .22863 .29461 .22628 .29057 .22191 Metetra
.664 .741 .908 r
.29057 .22191 .29461 .22628 .30086 .22392 .29683 .21954 Metetra
.664 .741 .908 r
.29683 .21954 .30086 .22392 .30712 .22155 .3031 .21716 Metetra
.664 .741 .908 r
.3031 .21716 .30712 .22155 .3134 .21918 .30939 .21478 Metetra
.664 .741 .908 r
.30939 .21478 .3134 .21918 .31969 .2168 .31569 .21239 Metetra
.664 .741 .908 r
.31569 .21239 .31969 .2168 .326 .21441 .32201 .21 Metetra
.664 .741 .908 r
.32201 .21 .326 .21441 .33232 .21202 .32834 .2076 Metetra
.664 .741 .908 r
.32834 .2076 .33232 .21202 .33866 .20963 .33469 .20519 Metetra
.664 .741 .908 r
.33469 .20519 .33866 .20963 .34502 .20723 .34105 .20278 Metetra
.664 .741 .908 r
.34105 .20278 .34502 .20723 .35138 .20482 .34743 .20036 Metetra
.664 .741 .908 r
.34743 .20036 .35138 .20482 .35777 .20241 .35382 .19794 Metetra
.664 .741 .908 r
.35382 .19794 .35777 .20241 .36417 .19999 .36023 .19551 Metetra
.664 .741 .908 r
.36023 .19551 .36417 .19999 .37058 .19757 .36665 .19308 Metetra
.664 .741 .908 r
.36665 .19308 .37058 .19757 .37701 .19514 .37309 .19064 Metetra
.664 .741 .908 r
.37309 .19064 .37701 .19514 .38345 .1927 .37954 .18819 Metetra
.664 .741 .908 r
.37954 .18819 .38345 .1927 .38992 .19026 .38601 .18574 Metetra
.664 .741 .908 r
.38601 .18574 .38992 .19026 .39639 .18781 .3925 .18328 Metetra
.664 .741 .908 r
.3925 .18328 .39639 .18781 .40288 .18536 .399 .18081 Metetra
.664 .741 .908 r
.399 .18081 .40288 .18536 .40939 .1829 .40552 .17834 Metetra
.664 .741 .908 r
.40552 .17834 .40939 .1829 .41591 .18043 .41205 .17587 Metetra
.664 .741 .908 r
.41205 .17587 .41591 .18043 .42245 .17796 .4186 .17338 Metetra
.664 .741 .908 r
.4186 .17338 .42245 .17796 .42901 .17549 .42517 .1709 Metetra
.664 .741 .908 r
.42517 .1709 .42901 .17549 .43558 .173 .43175 .1684 Metetra
.664 .741 .908 r
.43175 .1684 .43558 .173 .44217 .17051 .43835 .1659 Metetra
.664 .741 .908 r
.43835 .1659 .44217 .17051 .44877 .16802 .44496 .16339 Metetra
.664 .741 .908 r
.44496 .16339 .44877 .16802 .45539 .16552 .45159 .16088 Metetra
.664 .741 .908 r
.45159 .16088 .45539 .16552 .46202 .16301 .45823 .15836 Metetra
.664 .741 .908 r
.45823 .15836 .46202 .16301 .46868 .1605 .4649 .15584 Metetra
.664 .741 .908 r
.4649 .15584 .46868 .1605 .47534 .15798 .47157 .15331 Metetra
.663 .741 .908 r
.47157 .15331 .47534 .15798 .48203 .15545 .47827 .15077 Metetra
.663 .741 .908 r
.47827 .15077 .48203 .15545 .48873 .15292 .48498 .14823 Metetra
.663 .741 .908 r
.48498 .14823 .48873 .15292 .49545 .15039 .49171 .14568 Metetra
.663 .741 .908 r
.49171 .14568 .49545 .15039 .50218 .14784 .49845 .14313 Metetra
.663 .741 .908 r
.49845 .14313 .50218 .14784 .50893 .1453 .50521 .14057 Metetra
.663 .741 .908 r
.50521 .14057 .50893 .1453 .5157 .14275 .51199 .138 Metetra
.663 .741 .908 r
.51199 .138 .5157 .14275 .52248 .14019 .51879 .13543 Metetra
.663 .741 .908 r
.51879 .13543 .52248 .14019 .52928 .13763 .5256 .13286 Metetra
.663 .741 .908 r
.5256 .13286 .52928 .13763 .5361 .13507 .53243 .13028 Metetra
.663 .74 .908 r
.53243 .13028 .5361 .13507 .54293 .13251 .53927 .1277 Metetra
.662 .74 .908 r
.53927 .1277 .54293 .13251 .54978 .12994 .54613 .12512 Metetra
.662 .74 .908 r
.54613 .12512 .54978 .12994 .55665 .12738 .55301 .12254 Metetra
.662 .739 .907 r
.55301 .12254 .55665 .12738 .56354 .12482 .55991 .11996 Metetra
.661 .738 .907 r
.55991 .11996 .56354 .12482 .57044 .12226 .56683 .11738 Metetra
.66 .737 .907 r
.56683 .11738 .57044 .12226 .57736 .11971 .57376 .1148 Metetra
.659 .736 .907 r
.57376 .1148 .57736 .11971 .5843 .11718 .58071 .11224 Metetra
.658 .735 .906 r
.58071 .11224 .5843 .11718 .59126 .11465 .58768 .10968 Metetra
.657 .734 .906 r
.58768 .10968 .59126 .11465 .59824 .11214 .59466 .10714 Metetra
.656 .732 .906 r
.59466 .10714 .59824 .11214 .60523 .10966 .60167 .10461 Metetra
.654 .73 .905 r
.60167 .10461 .60523 .10966 .61225 .10719 .60869 .1021 Metetra
.652 .728 .904 r
.60869 .1021 .61225 .10719 .61928 .10476 .61574 .09962 Metetra
.65 .725 .904 r
.61574 .09962 .61928 .10476 .62633 .10236 .6228 .09716 Metetra
.648 .722 .903 r
.6228 .09716 .62633 .10236 .63341 .09998 .62988 .09473 Metetra
.646 .719 .902 r
.62988 .09473 .63341 .09998 .6405 .09764 .63699 .09234 Metetra
.643 .716 .9 r
.63699 .09234 .6405 .09764 .64762 .09533 .64411 .08997 Metetra
.641 .713 .899 r
.64411 .08997 .64762 .09533 .65476 .09305 .65126 .08763 Metetra
.639 .71 .898 r
.65126 .08763 .65476 .09305 .66192 .09078 .65843 .08532 Metetra
.638 .708 .897 r
.65843 .08532 .66192 .09078 .6691 .08853 .66562 .08302 Metetra
.637 .706 .896 r
.66562 .08302 .6691 .08853 .6763 .08627 .67283 .08073 Metetra
.637 .705 .896 r
.67283 .08073 .6763 .08627 .68352 .08399 .68006 .07844 Metetra
.637 .705 .896 r
.68006 .07844 .68352 .08399 .69076 .08168 .68731 .07613 Metetra
.639 .707 .896 r
.68731 .07613 .69076 .08168 .69801 .07932 .69458 .07378 Metetra
.641 .709 .896 r
.69458 .07378 .69801 .07932 .70529 .07689 .70187 .07139 Metetra
.645 .713 .897 r
.70187 .07139 .70529 .07689 .71258 .07439 .70917 .06894 Metetra
.649 .717 .898 r
.70917 .06894 .71258 .07439 .71988 .0718 .7165 .06641 Metetra
.653 .723 .9 r
.7165 .06641 .71988 .0718 .7272 .06913 .72383 .0638 Metetra
.66 .743 .911 r
.07507 .30551 .07943 .30951 .08517 .30755 .08085 .30335 Metetra
.671 .736 .899 r
.08085 .30335 .08517 .30755 .09096 .30543 .08667 .30102 Metetra
.68 .728 .887 r
.08667 .30102 .09096 .30543 .09679 .30311 .09253 .29851 Metetra
.687 .721 .876 r
.09253 .29851 .09679 .30311 .10265 .3006 .09842 .29583 Metetra
.691 .715 .867 r
.09842 .29583 .10265 .3006 .10855 .29792 .10434 .29302 Metetra
.694 .711 .861 r
.10434 .29302 .10855 .29792 .11447 .2951 .11029 .29012 Metetra
.696 .709 .858 r
.11029 .29012 .11447 .2951 .12042 .29218 .11625 .28717 Metetra
.696 .708 .857 r
.11625 .28717 .12042 .29218 .12639 .28921 .12222 .2842 Metetra
.695 .708 .858 r
.12222 .2842 .12639 .28921 .13237 .28622 .1282 .28126 Metetra
.693 .71 .861 r
.1282 .28126 .13237 .28622 .13836 .28325 .13418 .27836 Metetra
.69 .713 .866 r
.13418 .27836 .13836 .28325 .14435 .28033 .14017 .27553 Metetra
.687 .716 .871 r
.14017 .27553 .14435 .28033 .15035 .27749 .14616 .27277 Metetra
.684 .72 .876 r
.14616 .27277 .15035 .27749 .15634 .27471 .15215 .27009 Metetra
.681 .723 .882 r
.15215 .27009 .15634 .27471 .16234 .27202 .15815 .26748 Metetra
.678 .727 .887 r
.15815 .26748 .16234 .27202 .16834 .2694 .16415 .26493 Metetra
.675 .73 .891 r
.16415 .26493 .16834 .2694 .17434 .26685 .17015 .26243 Metetra
.673 .732 .895 r
.17015 .26243 .17434 .26685 .18036 .26435 .17616 .25998 Metetra
.671 .734 .898 r
.17616 .25998 .18036 .26435 .18637 .26191 .18219 .25756 Metetra
.669 .736 .9 r
.18219 .25756 .18637 .26191 .1924 .25949 .18822 .25517 Metetra
.668 .737 .902 r
.18822 .25517 .1924 .25949 .19844 .25711 .19426 .2528 Metetra
.667 .738 .904 r
.19426 .2528 .19844 .25711 .20449 .25474 .20031 .25045 Metetra
.666 .739 .905 r
.20031 .25045 .20449 .25474 .21055 .25239 .20638 .2481 Metetra
.665 .74 .906 r
.20638 .2481 .21055 .25239 .21662 .25005 .21246 .24576 Metetra
.665 .74 .906 r
.21246 .24576 .21662 .25005 .22271 .24771 .21855 .24342 Metetra
.665 .74 .907 r
.21855 .24342 .22271 .24771 .2288 .24538 .22466 .24108 Metetra
.664 .741 .907 r
.22466 .24108 .2288 .24538 .23492 .24305 .23078 .23875 Metetra
.664 .741 .907 r
.23078 .23875 .23492 .24305 .24104 .24071 .23692 .23641 Metetra
.664 .741 .907 r
.23692 .23641 .24104 .24071 .24718 .23838 .24307 .23406 Metetra
.664 .741 .908 r
.24307 .23406 .24718 .23838 .25334 .23604 .24923 .23171 Metetra
.664 .741 .908 r
.24923 .23171 .25334 .23604 .25951 .2337 .25541 .22936 Metetra
.664 .741 .908 r
.25541 .22936 .25951 .2337 .26569 .23135 .2616 .22701 Metetra
.664 .741 .908 r
.2616 .22701 .26569 .23135 .27189 .229 .26781 .22465 Metetra
.664 .741 .908 r
.26781 .22465 .27189 .229 .2781 .22664 .27403 .22228 Metetra
.664 .741 .908 r
.27403 .22228 .2781 .22664 .28433 .22428 .28026 .21991 Metetra
.664 .741 .908 r
.28026 .21991 .28433 .22428 .29057 .22191 .28651 .21753 Metetra
.664 .741 .908 r
.28651 .21753 .29057 .22191 .29683 .21954 .29278 .21515 Metetra
.664 .741 .908 r
.29278 .21515 .29683 .21954 .3031 .21716 .29906 .21276 Metetra
.664 .741 .908 r
.29906 .21276 .3031 .21716 .30939 .21478 .30536 .21037 Metetra
.664 .741 .908 r
.30536 .21037 .30939 .21478 .31569 .21239 .31167 .20797 Metetra
.664 .741 .908 r
.31167 .20797 .31569 .21239 .32201 .21 .31799 .20556 Metetra
.664 .741 .908 r
.31799 .20556 .32201 .21 .32834 .2076 .32433 .20315 Metetra
.664 .741 .908 r
.32433 .20315 .32834 .2076 .33469 .20519 .33069 .20073 Metetra
.664 .741 .908 r
.33069 .20073 .33469 .20519 .34105 .20278 .33706 .19831 Metetra
.664 .741 .908 r
.33706 .19831 .34105 .20278 .34743 .20036 .34345 .19588 Metetra
.664 .741 .908 r
.34345 .19588 .34743 .20036 .35382 .19794 .34985 .19345 Metetra
.664 .741 .908 r
.34985 .19345 .35382 .19794 .36023 .19551 .35627 .19101 Metetra
.664 .741 .908 r
.35627 .19101 .36023 .19551 .36665 .19308 .3627 .18857 Metetra
.664 .741 .908 r
.3627 .18857 .36665 .19308 .37309 .19064 .36915 .18611 Metetra
.664 .741 .908 r
.36915 .18611 .37309 .19064 .37954 .18819 .37562 .18366 Metetra
.664 .741 .908 r
.37562 .18366 .37954 .18819 .38601 .18574 .3821 .18119 Metetra
.664 .741 .908 r
.3821 .18119 .38601 .18574 .3925 .18328 .38859 .17872 Metetra
.664 .741 .908 r
.38859 .17872 .3925 .18328 .399 .18081 .3951 .17625 Metetra
.664 .741 .908 r
.3951 .17625 .399 .18081 .40552 .17834 .40163 .17377 Metetra
.664 .741 .908 r
.40163 .17377 .40552 .17834 .41205 .17587 .40817 .17128 Metetra
.664 .741 .908 r
.40817 .17128 .41205 .17587 .4186 .17338 .41473 .16879 Metetra
.664 .741 .908 r
.41473 .16879 .4186 .17338 .42517 .1709 .42131 .16629 Metetra
.664 .741 .908 r
.42131 .16629 .42517 .1709 .43175 .1684 .4279 .16378 Metetra
.664 .741 .908 r
.4279 .16378 .43175 .1684 .43835 .1659 .43451 .16127 Metetra
.664 .741 .908 r
.43451 .16127 .43835 .1659 .44496 .16339 .44113 .15875 Metetra
.664 .741 .908 r
.44113 .15875 .44496 .16339 .45159 .16088 .44777 .15623 Metetra
.664 .741 .908 r
.44777 .15623 .45159 .16088 .45823 .15836 .45443 .1537 Metetra
.664 .741 .908 r
.45443 .1537 .45823 .15836 .4649 .15584 .4611 .15116 Metetra
.664 .741 .908 r
.4611 .15116 .4649 .15584 .47157 .15331 .46779 .14862 Metetra
.664 .741 .908 r
.46779 .14862 .47157 .15331 .47827 .15077 .47449 .14607 Metetra
.663 .741 .908 r
.47449 .14607 .47827 .15077 .48498 .14823 .48121 .14351 Metetra
.663 .741 .908 r
.48121 .14351 .48498 .14823 .49171 .14568 .48795 .14095 Metetra
.663 .741 .908 r
.48795 .14095 .49171 .14568 .49845 .14313 .49471 .13839 Metetra
.663 .741 .908 r
.49471 .13839 .49845 .14313 .50521 .14057 .50148 .13582 Metetra
.663 .741 .908 r
.50148 .13582 .50521 .14057 .51199 .138 .50827 .13324 Metetra
.663 .741 .908 r
.50827 .13324 .51199 .138 .51879 .13543 .51507 .13066 Metetra
.663 .741 .908 r
.51507 .13066 .51879 .13543 .5256 .13286 .5219 .12807 Metetra
.663 .741 .908 r
.5219 .12807 .5256 .13286 .53243 .13028 .52874 .12548 Metetra
.663 .741 .908 r
.52874 .12548 .53243 .13028 .53927 .1277 .53559 .12288 Metetra
.663 .74 .908 r
.53559 .12288 .53927 .1277 .54613 .12512 .54247 .12028 Metetra
.662 .74 .908 r
.54247 .12028 .54613 .12512 .55301 .12254 .54936 .11768 Metetra
.662 .74 .908 r
.54936 .11768 .55301 .12254 .55991 .11996 .55627 .11508 Metetra
.662 .739 .907 r
.55627 .11508 .55991 .11996 .56683 .11738 .56319 .11248 Metetra
.661 .738 .907 r
.56319 .11248 .56683 .11738 .57376 .1148 .57014 .10989 Metetra
.66 .737 .907 r
.57014 .10989 .57376 .1148 .58071 .11224 .5771 .10729 Metetra
.659 .736 .907 r
.5771 .10729 .58071 .11224 .58768 .10968 .58408 .10471 Metetra
.658 .735 .906 r
.58408 .10471 .58768 .10968 .59466 .10714 .59107 .10213 Metetra
.657 .734 .906 r
.59107 .10213 .59466 .10714 .60167 .10461 .59809 .09957 Metetra
.656 .732 .906 r
.59809 .09957 .60167 .10461 .60869 .1021 .60513 .09702 Metetra
.654 .73 .905 r
.60513 .09702 .60869 .1021 .61574 .09962 .61218 .09449 Metetra
.652 .728 .904 r
.61218 .09449 .61574 .09962 .6228 .09716 .61925 .09199 Metetra
.65 .725 .904 r
.61925 .09199 .6228 .09716 .62988 .09473 .62635 .08951 Metetra
.648 .722 .903 r
.62635 .08951 .62988 .09473 .63699 .09234 .63346 .08706 Metetra
.646 .72 .902 r
.63346 .08706 .63699 .09234 .64411 .08997 .6406 .08463 Metetra
.644 .717 .901 r
.6406 .08463 .64411 .08997 .65126 .08763 .64775 .08224 Metetra
.642 .714 .9 r
.64775 .08224 .65126 .08763 .65843 .08532 .65493 .07987 Metetra
.64 .711 .899 r
.65493 .07987 .65843 .08532 .66562 .08302 .66213 .07753 Metetra
.639 .709 .898 r
.66213 .07753 .66562 .08302 .67283 .08073 .66935 .0752 Metetra
.638 .707 .897 r
.66935 .0752 .67283 .08073 .68006 .07844 .67659 .07288 Metetra
.638 .706 .896 r
.67659 .07288 .68006 .07844 .68731 .07613 .68385 .07055 Metetra
.638 .706 .896 r
.68385 .07055 .68731 .07613 .69458 .07378 .69113 .06821 Metetra
.64 .708 .896 r
.69113 .06821 .69458 .07378 .70187 .07139 .69843 .06583 Metetra
.642 .71 .897 r
.69843 .06583 .70187 .07139 .70917 .06894 .70575 .06341 Metetra
.645 .714 .898 r
.70575 .06341 .70917 .06894 .7165 .06641 .71309 .06093 Metetra
.649 .718 .899 r
.71309 .06093 .7165 .06641 .72383 .0638 .72044 .05838 Metetra
.671 .735 .898 r
.07072 .30128 .07507 .30551 .08085 .30335 .07654 .29894 Metetra
.68 .728 .887 r
.07654 .29894 .08085 .30335 .08667 .30102 .08239 .29642 Metetra
.686 .722 .877 r
.08239 .29642 .08667 .30102 .09253 .29851 .08828 .29375 Metetra
.691 .716 .868 r
.08828 .29375 .09253 .29851 .09842 .29583 .09419 .29095 Metetra
.694 .712 .863 r
.09419 .29095 .09842 .29583 .10434 .29302 .10013 .28807 Metetra
.695 .71 .86 r
.10013 .28807 .10434 .29302 .11029 .29012 .10608 .28514 Metetra
.695 .709 .859 r
.10608 .28514 .11029 .29012 .11625 .28717 .11205 .28219 Metetra
.694 .709 .86 r
.11205 .28219 .11625 .28717 .12222 .2842 .11802 .27927 Metetra
.692 .711 .863 r
.11802 .27927 .12222 .2842 .1282 .28126 .124 .27639 Metetra
.69 .714 .867 r
.124 .27639 .1282 .28126 .13418 .27836 .12998 .27358 Metetra
.687 .717 .872 r
.12998 .27358 .13418 .27836 .14017 .27553 .13596 .27083 Metetra
.684 .721 .877 r
.13596 .27083 .14017 .27553 .14616 .27277 .14195 .26815 Metetra
.681 .724 .882 r
.14195 .26815 .14616 .27277 .15215 .27009 .14794 .26555 Metetra
.678 .727 .887 r
.14794 .26555 .15215 .27009 .15815 .26748 .15393 .263 Metetra
.675 .73 .891 r
.15393 .263 .15815 .26748 .16415 .26493 .15993 .2605 Metetra
.673 .733 .895 r
.15993 .2605 .16415 .26493 .17015 .26243 .16594 .25805 Metetra
.671 .735 .898 r
.16594 .25805 .17015 .26243 .17616 .25998 .17195 .25563 Metetra
.669 .736 .9 r
.17195 .25563 .17616 .25998 .18219 .25756 .17798 .25323 Metetra
.668 .737 .902 r
.17798 .25323 .18219 .25756 .18822 .25517 .18401 .25086 Metetra
.667 .738 .904 r
.18401 .25086 .18822 .25517 .19426 .2528 .19006 .2485 Metetra
.666 .739 .905 r
.19006 .2485 .19426 .2528 .20031 .25045 .19612 .24615 Metetra
.665 .74 .906 r
.19612 .24615 .20031 .25045 .20638 .2481 .2022 .2438 Metetra
.665 .74 .906 r
.2022 .2438 .20638 .2481 .21246 .24576 .20828 .24146 Metetra
.665 .74 .907 r
.20828 .24146 .21246 .24576 .21855 .24342 .21439 .23912 Metetra
.664 .741 .907 r
.21439 .23912 .21855 .24342 .22466 .24108 .2205 .23677 Metetra
.664 .741 .907 r
.2205 .23677 .22466 .24108 .23078 .23875 .22663 .23443 Metetra
.664 .741 .907 r
.22663 .23443 .23078 .23875 .23692 .23641 .23277 .23208 Metetra
.664 .741 .908 r
.23277 .23208 .23692 .23641 .24307 .23406 .23893 .22973 Metetra
.664 .741 .908 r
.23893 .22973 .24307 .23406 .24923 .23171 .2451 .22737 Metetra
.664 .741 .908 r
.2451 .22737 .24923 .23171 .25541 .22936 .25129 .22501 Metetra
.664 .741 .908 r
.25129 .22501 .25541 .22936 .2616 .22701 .25749 .22264 Metetra
.664 .741 .908 r
.25749 .22264 .2616 .22701 .26781 .22465 .2637 .22027 Metetra
.664 .741 .908 r
.2637 .22027 .26781 .22465 .27403 .22228 .26993 .2179 Metetra
.664 .741 .908 r
.26993 .2179 .27403 .22228 .28026 .21991 .27618 .21552 Metetra
.664 .741 .908 r
.27618 .21552 .28026 .21991 .28651 .21753 .28244 .21313 Metetra
.664 .741 .908 r
.28244 .21313 .28651 .21753 .29278 .21515 .28871 .21074 Metetra
.664 .741 .908 r
.28871 .21074 .29278 .21515 .29906 .21276 .295 .20834 Metetra
.664 .741 .908 r
.295 .20834 .29906 .21276 .30536 .21037 .30131 .20593 Metetra
.664 .741 .908 r
.30131 .20593 .30536 .21037 .31167 .20797 .30763 .20352 Metetra
.664 .741 .908 r
.30763 .20352 .31167 .20797 .31799 .20556 .31396 .20111 Metetra
.664 .741 .908 r
.31396 .20111 .31799 .20556 .32433 .20315 .32031 .19869 Metetra
.664 .741 .908 r
.32031 .19869 .32433 .20315 .33069 .20073 .32668 .19626 Metetra
.664 .741 .908 r
.32668 .19626 .33069 .20073 .33706 .19831 .33306 .19383 Metetra
.664 .741 .908 r
.33306 .19383 .33706 .19831 .34345 .19588 .33946 .19139 Metetra
.664 .741 .908 r
.33946 .19139 .34345 .19588 .34985 .19345 .34587 .18894 Metetra
.664 .741 .908 r
.34587 .18894 .34985 .19345 .35627 .19101 .35229 .18649 Metetra
.664 .741 .908 r
.35229 .18649 .35627 .19101 .3627 .18857 .35874 .18403 Metetra
.664 .741 .908 r
.35874 .18403 .3627 .18857 .36915 .18611 .3652 .18157 Metetra
.664 .741 .908 r
.3652 .18157 .36915 .18611 .37562 .18366 .37167 .1791 Metetra
.664 .741 .908 r
.37167 .1791 .37562 .18366 .3821 .18119 .37816 .17663 Metetra
.664 .741 .908 r
.37816 .17663 .3821 .18119 .38859 .17872 .38467 .17415 Metetra
.664 .741 .908 r
.38467 .17415 .38859 .17872 .3951 .17625 .39119 .17166 Metetra
.664 .741 .908 r
.39119 .17166 .3951 .17625 .40163 .17377 .39772 .16917 Metetra
.664 .741 .908 r
.39772 .16917 .40163 .17377 .40817 .17128 .40428 .16667 Metetra
.664 .741 .908 r
.40428 .16667 .40817 .17128 .41473 .16879 .41085 .16417 Metetra
.664 .741 .908 r
.41085 .16417 .41473 .16879 .42131 .16629 .41743 .16166 Metetra
.664 .741 .908 r
.41743 .16166 .42131 .16629 .4279 .16378 .42403 .15914 Metetra
.664 .741 .908 r
.42403 .15914 .4279 .16378 .43451 .16127 .43065 .15662 Metetra
.664 .741 .908 r
.43065 .15662 .43451 .16127 .44113 .15875 .43728 .15409 Metetra
.664 .741 .908 r
.43728 .15409 .44113 .15875 .44777 .15623 .44393 .15155 Metetra
.664 .741 .908 r
.44393 .15155 .44777 .15623 .45443 .1537 .4506 .14901 Metetra
.664 .741 .908 r
.4506 .14901 .45443 .1537 .4611 .15116 .45728 .14646 Metetra
.664 .741 .908 r
.45728 .14646 .4611 .15116 .46779 .14862 .46398 .14391 Metetra
.664 .741 .908 r
.46398 .14391 .46779 .14862 .47449 .14607 .4707 .14135 Metetra
.664 .741 .908 r
.4707 .14135 .47449 .14607 .48121 .14351 .47743 .13878 Metetra
.663 .741 .908 r
.47743 .13878 .48121 .14351 .48795 .14095 .48418 .13621 Metetra
.663 .741 .908 r
.48418 .13621 .48795 .14095 .49471 .13839 .49095 .13363 Metetra
.663 .741 .908 r
.49095 .13363 .49471 .13839 .50148 .13582 .49773 .13104 Metetra
.663 .741 .908 r
.49773 .13104 .50148 .13582 .50827 .13324 .50453 .12845 Metetra
.663 .741 .908 r
.50453 .12845 .50827 .13324 .51507 .13066 .51135 .12586 Metetra
.663 .741 .908 r
.51135 .12586 .51507 .13066 .5219 .12807 .51818 .12326 Metetra
.663 .741 .908 r
.51818 .12326 .5219 .12807 .52874 .12548 .52503 .12065 Metetra
.663 .741 .908 r
.52503 .12065 .52874 .12548 .53559 .12288 .5319 .11804 Metetra
.663 .74 .908 r
.5319 .11804 .53559 .12288 .54247 .12028 .53878 .11543 Metetra
.663 .74 .908 r
.53878 .11543 .54247 .12028 .54936 .11768 .54568 .11281 Metetra
.662 .74 .908 r
.54568 .11281 .54936 .11768 .55627 .11508 .5526 .11019 Metetra
.662 .739 .907 r
.5526 .11019 .55627 .11508 .56319 .11248 .55954 .10757 Metetra
.661 .739 .907 r
.55954 .10757 .56319 .11248 .57014 .10989 .5665 .10496 Metetra
.661 .738 .907 r
.5665 .10496 .57014 .10989 .5771 .10729 .57347 .10234 Metetra
.66 .737 .907 r
.57347 .10234 .5771 .10729 .58408 .10471 .58046 .09973 Metetra
.659 .736 .907 r
.58046 .09973 .58408 .10471 .59107 .10213 .58747 .09712 Metetra
.658 .735 .906 r
.58747 .09712 .59107 .10213 .59809 .09957 .5945 .09453 Metetra
.657 .734 .906 r
.5945 .09453 .59809 .09957 .60513 .09702 .60154 .09194 Metetra
.656 .732 .906 r
.60154 .09194 .60513 .09702 .61218 .09449 .60861 .08938 Metetra
.654 .73 .905 r
.60861 .08938 .61218 .09449 .61925 .09199 .61569 .08683 Metetra
.652 .728 .904 r
.61569 .08683 .61925 .09199 .62635 .08951 .62279 .0843 Metetra
.651 .725 .904 r
.62279 .0843 .62635 .08951 .63346 .08706 .62992 .0818 Metetra
.648 .723 .903 r
.62992 .0818 .63346 .08706 .6406 .08463 .63706 .07932 Metetra
.646 .72 .902 r
.63706 .07932 .6406 .08463 .64775 .08224 .64423 .07688 Metetra
.644 .717 .901 r
.64423 .07688 .64775 .08224 .65493 .07987 .65141 .07446 Metetra
.642 .714 .9 r
.65141 .07446 .65493 .07987 .66213 .07753 .65862 .07206 Metetra
.641 .712 .899 r
.65862 .07206 .66213 .07753 .66935 .0752 .66585 .06969 Metetra
.639 .71 .898 r
.66585 .06969 .66935 .0752 .67659 .07288 .6731 .06733 Metetra
.638 .708 .897 r
.6731 .06733 .67659 .07288 .68385 .07055 .68038 .06497 Metetra
.638 .707 .897 r
.68038 .06497 .68385 .07055 .69113 .06821 .68767 .06262 Metetra
.639 .708 .896 r
.68767 .06262 .69113 .06821 .69843 .06583 .69498 .06024 Metetra
.64 .709 .897 r
.69498 .06024 .69843 .06583 .70575 .06341 .70231 .05783 Metetra
.643 .711 .897 r
.70231 .05783 .70575 .06341 .71309 .06093 .70966 .05538 Metetra
.646 .714 .898 r
.70966 .05538 .71309 .06093 .72044 .05838 .71703 .05287 Metetra
.68 .728 .887 r
.06639 .29686 .07072 .30128 .07654 .29894 .07223 .29433 Metetra
.686 .722 .877 r
.07223 .29433 .07654 .29894 .08239 .29642 .07811 .29167 Metetra
.69 .717 .87 r
.07811 .29167 .08239 .29642 .08828 .29375 .08402 .28888 Metetra
.693 .713 .864 r
.08402 .28888 .08828 .29375 .09419 .29095 .08995 .28602 Metetra
.694 .711 .861 r
.08995 .28602 .09419 .29095 .10013 .28807 .0959 .28311 Metetra
.694 .71 .861 r
.0959 .28311 .10013 .28807 .10608 .28514 .10185 .28019 Metetra
.693 .711 .862 r
.10185 .28019 .10608 .28514 .11205 .28219 .10782 .27728 Metetra
.691 .712 .865 r
.10782 .27728 .11205 .28219 .11802 .27927 .11379 .27443 Metetra
.689 .715 .869 r
.11379 .27443 .11802 .27927 .124 .27639 .11976 .27162 Metetra
.686 .718 .873 r
.11976 .27162 .124 .27639 .12998 .27358 .12574 .26889 Metetra
.683 .721 .878 r
.12574 .26889 .12998 .27358 .13596 .27083 .13172 .26622 Metetra
.68 .725 .883 r
.13172 .26622 .13596 .27083 .14195 .26815 .1377 .26361 Metetra
.678 .728 .888 r
.1377 .26361 .14195 .26815 .14794 .26555 .14369 .26106 Metetra
.675 .73 .892 r
.14369 .26106 .14794 .26555 .15393 .263 .14968 .25857 Metetra
.673 .733 .895 r
.14968 .25857 .15393 .263 .15993 .2605 .15569 .25611 Metetra
.671 .735 .898 r
.15569 .25611 .15993 .2605 .16594 .25805 .1617 .25369 Metetra
.669 .736 .9 r
.1617 .25369 .16594 .25805 .17195 .25563 .16772 .25129 Metetra
.668 .737 .902 r
.16772 .25129 .17195 .25563 .17798 .25323 .17375 .24891 Metetra
.667 .738 .904 r
.17375 .24891 .17798 .25323 .18401 .25086 .17979 .24655 Metetra
.666 .739 .905 r
.17979 .24655 .18401 .25086 .19006 .2485 .18584 .24419 Metetra
.665 .74 .906 r
.18584 .24419 .19006 .2485 .19612 .24615 .19191 .24184 Metetra
.665 .74 .906 r
.19191 .24184 .19612 .24615 .2022 .2438 .19799 .23949 Metetra
.665 .74 .907 r
.19799 .23949 .2022 .2438 .20828 .24146 .20409 .23715 Metetra
.664 .741 .907 r
.20409 .23715 .20828 .24146 .21439 .23912 .2102 .2348 Metetra
.664 .741 .907 r
.2102 .2348 .21439 .23912 .2205 .23677 .21632 .23245 Metetra
.664 .741 .907 r
.21632 .23245 .2205 .23677 .22663 .23443 .22246 .23009 Metetra
.664 .741 .908 r
.22246 .23009 .22663 .23443 .23277 .23208 .22861 .22774 Metetra
.664 .741 .908 r
.22861 .22774 .23277 .23208 .23893 .22973 .23477 .22538 Metetra
.664 .741 .908 r
.23477 .22538 .23893 .22973 .2451 .22737 .24095 .22301 Metetra
.664 .741 .908 r
.24095 .22301 .2451 .22737 .25129 .22501 .24715 .22064 Metetra
.664 .741 .908 r
.24715 .22064 .25129 .22501 .25749 .22264 .25336 .21826 Metetra
.664 .741 .908 r
.25336 .21826 .25749 .22264 .2637 .22027 .25958 .21588 Metetra
.664 .741 .908 r
.25958 .21588 .2637 .22027 .26993 .2179 .26582 .2135 Metetra
.664 .741 .908 r
.26582 .2135 .26993 .2179 .27618 .21552 .27208 .2111 Metetra
.664 .741 .908 r
.27208 .2111 .27618 .21552 .28244 .21313 .27834 .20871 Metetra
.664 .741 .908 r
.27834 .20871 .28244 .21313 .28871 .21074 .28463 .2063 Metetra
.664 .741 .908 r
.28463 .2063 .28871 .21074 .295 .20834 .29093 .20389 Metetra
.664 .741 .908 r
.29093 .20389 .295 .20834 .30131 .20593 .29724 .20148 Metetra
.664 .741 .908 r
.29724 .20148 .30131 .20593 .30763 .20352 .30357 .19906 Metetra
.664 .741 .908 r
.30357 .19906 .30763 .20352 .31396 .20111 .30991 .19663 Metetra
.664 .741 .908 r
.30991 .19663 .31396 .20111 .32031 .19869 .31627 .1942 Metetra
.664 .741 .908 r
.31627 .1942 .32031 .19869 .32668 .19626 .32265 .19176 Metetra
.664 .741 .908 r
.32265 .19176 .32668 .19626 .33306 .19383 .32904 .18932 Metetra
.664 .741 .908 r
.32904 .18932 .33306 .19383 .33946 .19139 .33544 .18687 Metetra
.664 .741 .908 r
.33544 .18687 .33946 .19139 .34587 .18894 .34187 .18441 Metetra
.664 .741 .908 r
.34187 .18441 .34587 .18894 .35229 .18649 .3483 .18195 Metetra
.664 .741 .908 r
.3483 .18195 .35229 .18649 .35874 .18403 .35475 .17948 Metetra
.664 .741 .908 r
.35475 .17948 .35874 .18403 .3652 .18157 .36122 .17701 Metetra
.664 .741 .908 r
.36122 .17701 .3652 .18157 .37167 .1791 .36771 .17453 Metetra
.664 .741 .908 r
.36771 .17453 .37167 .1791 .37816 .17663 .37421 .17205 Metetra
.664 .741 .908 r
.37421 .17205 .37816 .17663 .38467 .17415 .38072 .16955 Metetra
.664 .741 .908 r
.38072 .16955 .38467 .17415 .39119 .17166 .38725 .16706 Metetra
.664 .741 .908 r
.38725 .16706 .39119 .17166 .39772 .16917 .3938 .16455 Metetra
.664 .741 .908 r
.3938 .16455 .39772 .16917 .40428 .16667 .40036 .16204 Metetra
.664 .741 .908 r
.40036 .16204 .40428 .16667 .41085 .16417 .40694 .15953 Metetra
.664 .741 .908 r
.40694 .15953 .41085 .16417 .41743 .16166 .41354 .157 Metetra
.664 .741 .908 r
.41354 .157 .41743 .16166 .42403 .15914 .42015 .15448 Metetra
.664 .741 .908 r
.42015 .15448 .42403 .15914 .43065 .15662 .42678 .15194 Metetra
.664 .741 .908 r
.42678 .15194 .43065 .15662 .43728 .15409 .43342 .1494 Metetra
.664 .741 .908 r
.43342 .1494 .43728 .15409 .44393 .15155 .44008 .14685 Metetra
.664 .741 .908 r
.44008 .14685 .44393 .15155 .4506 .14901 .44676 .1443 Metetra
.664 .741 .908 r
.44676 .1443 .4506 .14901 .45728 .14646 .45345 .14174 Metetra
.664 .741 .908 r
.45345 .14174 .45728 .14646 .46398 .14391 .46016 .13917 Metetra
.664 .741 .908 r
.46016 .13917 .46398 .14391 .4707 .14135 .46689 .1366 Metetra
.664 .741 .908 r
.46689 .1366 .4707 .14135 .47743 .13878 .47363 .13402 Metetra
.664 .741 .908 r
.47363 .13402 .47743 .13878 .48418 .13621 .48039 .13144 Metetra
.663 .741 .908 r
.48039 .13144 .48418 .13621 .49095 .13363 .48717 .12885 Metetra
.663 .741 .908 r
.48717 .12885 .49095 .13363 .49773 .13104 .49396 .12625 Metetra
.663 .741 .908 r
.49396 .12625 .49773 .13104 .50453 .12845 .50077 .12365 Metetra
.663 .741 .908 r
.50077 .12365 .50453 .12845 .51135 .12586 .5076 .12104 Metetra
.663 .741 .908 r
.5076 .12104 .51135 .12586 .51818 .12326 .51444 .11843 Metetra
.663 .741 .908 r
.51444 .11843 .51818 .12326 .52503 .12065 .52131 .11581 Metetra
.663 .741 .908 r
.52131 .11581 .52503 .12065 .5319 .11804 .52819 .11318 Metetra
.663 .741 .908 r
.52819 .11318 .5319 .11804 .53878 .11543 .53508 .11055 Metetra
.663 .74 .908 r
.53508 .11055 .53878 .11543 .54568 .11281 .54199 .10792 Metetra
.663 .74 .908 r
.54199 .10792 .54568 .11281 .5526 .11019 .54893 .10529 Metetra
.662 .74 .908 r
.54893 .10529 .5526 .11019 .55954 .10757 .55587 .10265 Metetra
.662 .739 .907 r
.55587 .10265 .55954 .10757 .5665 .10496 .56284 .10001 Metetra
.661 .739 .907 r
.56284 .10001 .5665 .10496 .57347 .10234 .56982 .09737 Metetra
.661 .738 .907 r
.56982 .09737 .57347 .10234 .58046 .09973 .57683 .09474 Metetra
.66 .737 .907 r
.57683 .09474 .58046 .09973 .58747 .09712 .58385 .09211 Metetra
.659 .736 .907 r
.58385 .09211 .58747 .09712 .5945 .09453 .59089 .08948 Metetra
.658 .735 .906 r
.59089 .08948 .5945 .09453 .60154 .09194 .59794 .08687 Metetra
.657 .734 .906 r
.59794 .08687 .60154 .09194 .60861 .08938 .60502 .08427 Metetra
.656 .732 .906 r
.60502 .08427 .60861 .08938 .61569 .08683 .61211 .08168 Metetra
.654 .73 .905 r
.61211 .08168 .61569 .08683 .62279 .0843 .61923 .07911 Metetra
.653 .728 .904 r
.61923 .07911 .62279 .0843 .62992 .0818 .62636 .07656 Metetra
.651 .726 .904 r
.62636 .07656 .62992 .0818 .63706 .07932 .63352 .07403 Metetra
.649 .723 .903 r
.63352 .07403 .63706 .07932 .64423 .07688 .64069 .07154 Metetra
.647 .72 .902 r
.64069 .07154 .64423 .07688 .65141 .07446 .64789 .06906 Metetra
.645 .718 .901 r
.64789 .06906 .65141 .07446 .65862 .07206 .6551 .06662 Metetra
.643 .715 .9 r
.6551 .06662 .65862 .07206 .66585 .06969 .66234 .06419 Metetra
.641 .713 .899 r
.66234 .06419 .66585 .06969 .6731 .06733 .6696 .06179 Metetra
.64 .711 .898 r
.6696 .06179 .6731 .06733 .68038 .06497 .67689 .0594 Metetra
.639 .709 .898 r
.67689 .0594 .68038 .06497 .68767 .06262 .68419 .05701 Metetra
.639 .709 .897 r
.68419 .05701 .68767 .06262 .69498 .06024 .69151 .05462 Metetra
.64 .709 .897 r
.69151 .05462 .69498 .06024 .70231 .05783 .69886 .05221 Metetra
.641 .71 .897 r
.69886 .05221 .70231 .05783 .70966 .05538 .70622 .04978 Metetra
.643 .712 .897 r
.70622 .04978 .70966 .05538 .71703 .05287 .71361 .04729 Metetra
.685 .722 .878 r
.06206 .29226 .06639 .29686 .07223 .29433 .06793 .2896 Metetra
.69 .718 .871 r
.06793 .2896 .07223 .29433 .07811 .29167 .07383 .28682 Metetra
.692 .714 .866 r
.07383 .28682 .07811 .29167 .08402 .28888 .07975 .28397 Metetra
.693 .712 .863 r
.07975 .28397 .08402 .28888 .08995 .28602 .08569 .28108 Metetra
.693 .711 .862 r
.08569 .28108 .08995 .28602 .0959 .28311 .09164 .27818 Metetra
.692 .712 .863 r
.09164 .27818 .0959 .28311 .10185 .28019 .0976 .2753 Metetra
.691 .714 .866 r
.0976 .2753 .10185 .28019 .10782 .27728 .10356 .27246 Metetra
.688 .716 .87 r
.10356 .27246 .10782 .27728 .11379 .27443 .10953 .26967 Metetra
.686 .719 .874 r
.10953 .26967 .11379 .27443 .11976 .27162 .1155 .26694 Metetra
.683 .722 .879 r
.1155 .26694 .11976 .27162 .12574 .26889 .12147 .26428 Metetra
.68 .725 .884 r
.12147 .26428 .12574 .26889 .13172 .26622 .12745 .26167 Metetra
.677 .728 .888 r
.12745 .26167 .13172 .26622 .1377 .26361 .13343 .25913 Metetra
.675 .731 .892 r
.13343 .25913 .1377 .26361 .14369 .26106 .13942 .25663 Metetra
.673 .733 .895 r
.13942 .25663 .14369 .26106 .14968 .25857 .14542 .25417 Metetra
.671 .735 .898 r
.14542 .25417 .14968 .25857 .15569 .25611 .15142 .25175 Metetra
.669 .736 .9 r
.15142 .25175 .15569 .25611 .1617 .25369 .15743 .24934 Metetra
.668 .738 .902 r
.15743 .24934 .1617 .25369 .16772 .25129 .16346 .24696 Metetra
.667 .738 .904 r
.16346 .24696 .16772 .25129 .17375 .24891 .1695 .24459 Metetra
.666 .739 .905 r
.1695 .24459 .17375 .24891 .17979 .24655 .17555 .24223 Metetra
.665 .74 .906 r
.17555 .24223 .17979 .24655 .18584 .24419 .18161 .23988 Metetra
.665 .74 .906 r
.18161 .23988 .18584 .24419 .19191 .24184 .18768 .23752 Metetra
.665 .74 .907 r
.18768 .23752 .19191 .24184 .19799 .23949 .19377 .23517 Metetra
.664 .741 .907 r
.19377 .23517 .19799 .23949 .20409 .23715 .19987 .23282 Metetra
.664 .741 .907 r
.19987 .23282 .20409 .23715 .2102 .2348 .20599 .23046 Metetra
.664 .741 .907 r
.20599 .23046 .2102 .2348 .21632 .23245 .21212 .2281 Metetra
.664 .741 .908 r
.21212 .2281 .21632 .23245 .22246 .23009 .21827 .22574 Metetra
.664 .741 .908 r
.21827 .22574 .22246 .23009 .22861 .22774 .22443 .22338 Metetra
.664 .741 .908 r
.22443 .22338 .22861 .22774 .23477 .22538 .2306 .22101 Metetra
.664 .741 .908 r
.2306 .22101 .23477 .22538 .24095 .22301 .23679 .21863 Metetra
.664 .741 .908 r
.23679 .21863 .24095 .22301 .24715 .22064 .24299 .21625 Metetra
.664 .741 .908 r
.24299 .21625 .24715 .22064 .25336 .21826 .24921 .21386 Metetra
.664 .741 .908 r
.24921 .21386 .25336 .21826 .25958 .21588 .25544 .21147 Metetra
.664 .741 .908 r
.25544 .21147 .25958 .21588 .26582 .2135 .26169 .20908 Metetra
.664 .741 .908 r
.26169 .20908 .26582 .2135 .27208 .2111 .26795 .20667 Metetra
.664 .741 .908 r
.26795 .20667 .27208 .2111 .27834 .20871 .27423 .20426 Metetra
.664 .741 .908 r
.27423 .20426 .27834 .20871 .28463 .2063 .28052 .20185 Metetra
.664 .741 .908 r
.28052 .20185 .28463 .2063 .29093 .20389 .28683 .19943 Metetra
.664 .741 .908 r
.28683 .19943 .29093 .20389 .29724 .20148 .29316 .19701 Metetra
.664 .741 .908 r
.29316 .19701 .29724 .20148 .30357 .19906 .29949 .19457 Metetra
.664 .741 .908 r
.29949 .19457 .30357 .19906 .30991 .19663 .30585 .19214 Metetra
.664 .741 .908 r
.30585 .19214 .30991 .19663 .31627 .1942 .31222 .18969 Metetra
.664 .741 .908 r
.31222 .18969 .31627 .1942 .32265 .19176 .3186 .18725 Metetra
.664 .741 .908 r
.3186 .18725 .32265 .19176 .32904 .18932 .325 .18479 Metetra
.664 .741 .908 r
.325 .18479 .32904 .18932 .33544 .18687 .33142 .18233 Metetra
.664 .741 .908 r
.33142 .18233 .33544 .18687 .34187 .18441 .33785 .17986 Metetra
.664 .741 .908 r
.33785 .17986 .34187 .18441 .3483 .18195 .34429 .17739 Metetra
.664 .741 .908 r
.34429 .17739 .3483 .18195 .35475 .17948 .35075 .17491 Metetra
.664 .741 .908 r
.35075 .17491 .35475 .17948 .36122 .17701 .35723 .17243 Metetra
.664 .741 .908 r
.35723 .17243 .36122 .17701 .36771 .17453 .36373 .16994 Metetra
.664 .741 .908 r
.36373 .16994 .36771 .17453 .37421 .17205 .37023 .16744 Metetra
.664 .741 .908 r
.37023 .16744 .37421 .17205 .38072 .16955 .37676 .16494 Metetra
.664 .741 .908 r
.37676 .16494 .38072 .16955 .38725 .16706 .3833 .16243 Metetra
.664 .741 .908 r
.3833 .16243 .38725 .16706 .3938 .16455 .38986 .15991 Metetra
.664 .741 .908 r
.38986 .15991 .3938 .16455 .40036 .16204 .39643 .15739 Metetra
.664 .741 .908 r
.39643 .15739 .40036 .16204 .40694 .15953 .40302 .15486 Metetra
.664 .741 .908 r
.40302 .15486 .40694 .15953 .41354 .157 .40963 .15233 Metetra
.664 .741 .908 r
.40963 .15233 .41354 .157 .42015 .15448 .41625 .14979 Metetra
.664 .741 .908 r
.41625 .14979 .42015 .15448 .42678 .15194 .42289 .14724 Metetra
.664 .741 .908 r
.42289 .14724 .42678 .15194 .43342 .1494 .42954 .14469 Metetra
.664 .741 .908 r
.42954 .14469 .43342 .1494 .44008 .14685 .43621 .14213 Metetra
.664 .741 .908 r
.43621 .14213 .44008 .14685 .44676 .1443 .4429 .13957 Metetra
.664 .741 .908 r
.4429 .13957 .44676 .1443 .45345 .14174 .4496 .137 Metetra
.664 .741 .908 r
.4496 .137 .45345 .14174 .46016 .13917 .45632 .13442 Metetra
.664 .741 .908 r
.45632 .13442 .46016 .13917 .46689 .1366 .46306 .13184 Metetra
.664 .741 .908 r
.46306 .13184 .46689 .1366 .47363 .13402 .46981 .12924 Metetra
.664 .741 .908 r
.46981 .12924 .47363 .13402 .48039 .13144 .47658 .12665 Metetra
.664 .741 .908 r
.47658 .12665 .48039 .13144 .48717 .12885 .48337 .12405 Metetra
.663 .741 .908 r
.48337 .12405 .48717 .12885 .49396 .12625 .49018 .12144 Metetra
.663 .741 .908 r
.49018 .12144 .49396 .12625 .50077 .12365 .497 .11882 Metetra
.663 .741 .908 r
.497 .11882 .50077 .12365 .5076 .12104 .50384 .1162 Metetra
.663 .741 .908 r
.50384 .1162 .5076 .12104 .51444 .11843 .51069 .11357 Metetra
.663 .741 .908 r
.51069 .11357 .51444 .11843 .52131 .11581 .51757 .11094 Metetra
.663 .741 .908 r
.51757 .11094 .52131 .11581 .52819 .11318 .52446 .1083 Metetra
.663 .741 .908 r
.52446 .1083 .52819 .11318 .53508 .11055 .53136 .10566 Metetra
.663 .741 .908 r
.53136 .10566 .53508 .11055 .54199 .10792 .53829 .10301 Metetra
.663 .74 .908 r
.53829 .10301 .54199 .10792 .54893 .10529 .54523 .10036 Metetra
.663 .74 .908 r
.54523 .10036 .54893 .10529 .55587 .10265 .55219 .09771 Metetra
.662 .74 .908 r
.55219 .09771 .55587 .10265 .56284 .10001 .55917 .09505 Metetra
.662 .739 .907 r
.55917 .09505 .56284 .10001 .56982 .09737 .56616 .09239 Metetra
.661 .739 .907 r
.56616 .09239 .56982 .09737 .57683 .09474 .57318 .08974 Metetra
.661 .738 .907 r
.57318 .08974 .57683 .09474 .58385 .09211 .58021 .08708 Metetra
.66 .737 .907 r
.58021 .08708 .58385 .09211 .59089 .08948 .58726 .08443 Metetra
.659 .736 .907 r
.58726 .08443 .59089 .08948 .59794 .08687 .59433 .08179 Metetra
.658 .735 .906 r
.59433 .08179 .59794 .08687 .60502 .08427 .60141 .07916 Metetra
.657 .734 .906 r
.60141 .07916 .60502 .08427 .61211 .08168 .60852 .07653 Metetra
.656 .732 .906 r
.60852 .07653 .61211 .08168 .61923 .07911 .61565 .07392 Metetra
.654 .73 .905 r
.61565 .07392 .61923 .07911 .62636 .07656 .62279 .07133 Metetra
.653 .728 .905 r
.62279 .07133 .62636 .07656 .63352 .07403 .62995 .06876 Metetra
.651 .726 .904 r
.62995 .06876 .63352 .07403 .64069 .07154 .63714 .06621 Metetra
.649 .723 .903 r
.63714 .06621 .64069 .07154 .64789 .06906 .64435 .06369 Metetra
.647 .721 .902 r
.64435 .06369 .64789 .06906 .6551 .06662 .65157 .06119 Metetra
.645 .718 .901 r
.65157 .06119 .6551 .06662 .66234 .06419 .65882 .05872 Metetra
.643 .716 .9 r
.65882 .05872 .66234 .06419 .6696 .06179 .66609 .05627 Metetra
.642 .713 .899 r
.66609 .05627 .6696 .06179 .67689 .0594 .67338 .05384 Metetra
.641 .711 .899 r
.67338 .05384 .67689 .0594 .68419 .05701 .6807 .05141 Metetra
.64 .71 .898 r
.6807 .05141 .68419 .05701 .69151 .05462 .68803 .049 Metetra
.64 .709 .897 r
.68803 .049 .69151 .05462 .69886 .05221 .69539 .04658 Metetra
.64 .71 .897 r
.69539 .04658 .69886 .05221 .70622 .04978 .70277 .04414 Metetra
.642 .711 .897 r
.70277 .04414 .70622 .04978 .71361 .04729 .71016 .04167 Metetra
.689 .718 .872 r
.05772 .28753 .06206 .29226 .06793 .2896 .06362 .28477 Metetra
.691 .715 .867 r
.06362 .28477 .06793 .2896 .07383 .28682 .06953 .28194 Metetra
.692 .713 .864 r
.06953 .28194 .07383 .28682 .07975 .28397 .07546 .27906 Metetra
.693 .712 .864 r
.07546 .27906 .07975 .28397 .08569 .28108 .08141 .27618 Metetra
.692 .713 .865 r
.08141 .27618 .08569 .28108 .09164 .27818 .08736 .27331 Metetra
.69 .715 .868 r
.08736 .27331 .09164 .27818 .0976 .2753 .09332 .27049 Metetra
.688 .717 .871 r
.09332 .27049 .0976 .2753 .10356 .27246 .09928 .26771 Metetra
.685 .72 .875 r
.09928 .26771 .10356 .27246 .10953 .26967 .10524 .26499 Metetra
.683 .723 .88 r
.10524 .26499 .10953 .26967 .1155 .26694 .11121 .26233 Metetra
.68 .725 .884 r
.11121 .26233 .1155 .26694 .12147 .26428 .11718 .25973 Metetra
.677 .728 .888 r
.11718 .25973 .12147 .26428 .12745 .26167 .12315 .25719 Metetra
.675 .731 .892 r
.12315 .25719 .12745 .26167 .13343 .25913 .12914 .25469 Metetra
.672 .733 .896 r
.12914 .25469 .13343 .25913 .13942 .25663 .13513 .25223 Metetra
.671 .735 .898 r
.13513 .25223 .13942 .25663 .14542 .25417 .14112 .2498 Metetra
.669 .736 .9 r
.14112 .2498 .14542 .25417 .15142 .25175 .14713 .24739 Metetra
.668 .738 .902 r
.14713 .24739 .15142 .25175 .15743 .24934 .15315 .24501 Metetra
.667 .738 .904 r
.15315 .24501 .15743 .24934 .16346 .24696 .15918 .24263 Metetra
.666 .739 .905 r
.15918 .24263 .16346 .24696 .1695 .24459 .16523 .24027 Metetra
.665 .74 .906 r
.16523 .24027 .1695 .24459 .17555 .24223 .17128 .23791 Metetra
.665 .74 .906 r
.17128 .23791 .17555 .24223 .18161 .23988 .17735 .23555 Metetra
.665 .74 .907 r
.17735 .23555 .18161 .23988 .18768 .23752 .18343 .23319 Metetra
.664 .741 .907 r
.18343 .23319 .18768 .23752 .19377 .23517 .18953 .23083 Metetra
.664 .741 .907 r
.18953 .23083 .19377 .23517 .19987 .23282 .19564 .22847 Metetra
.664 .741 .907 r
.19564 .22847 .19987 .23282 .20599 .23046 .20177 .22611 Metetra
.664 .741 .908 r
.20177 .22611 .20599 .23046 .21212 .2281 .2079 .22374 Metetra
.664 .741 .908 r
.2079 .22374 .21212 .2281 .21827 .22574 .21406 .22137 Metetra
.664 .741 .908 r
.21406 .22137 .21827 .22574 .22443 .22338 .22023 .219 Metetra
.664 .741 .908 r
.22023 .219 .22443 .22338 .2306 .22101 .22641 .21662 Metetra
.664 .741 .908 r
.22641 .21662 .2306 .22101 .23679 .21863 .23261 .21423 Metetra
.664 .741 .908 r
.23261 .21423 .23679 .21863 .24299 .21625 .23882 .21184 Metetra
.664 .741 .908 r
.23882 .21184 .24299 .21625 .24921 .21386 .24505 .20945 Metetra
.664 .741 .908 r
.24505 .20945 .24921 .21386 .25544 .21147 .25129 .20704 Metetra
.664 .741 .908 r
.25129 .20704 .25544 .21147 .26169 .20908 .25754 .20464 Metetra
.664 .741 .908 r
.25754 .20464 .26169 .20908 .26795 .20667 .26381 .20222 Metetra
.664 .741 .908 r
.26381 .20222 .26795 .20667 .27423 .20426 .2701 .1998 Metetra
.664 .741 .908 r
.2701 .1998 .27423 .20426 .28052 .20185 .2764 .19738 Metetra
.664 .741 .908 r
.2764 .19738 .28052 .20185 .28683 .19943 .28272 .19495 Metetra
.664 .741 .908 r
.28272 .19495 .28683 .19943 .29316 .19701 .28905 .19251 Metetra
.664 .741 .908 r
.28905 .19251 .29316 .19701 .29949 .19457 .2954 .19007 Metetra
.664 .741 .908 r
.2954 .19007 .29949 .19457 .30585 .19214 .30176 .18762 Metetra
.664 .741 .908 r
.30176 .18762 .30585 .19214 .31222 .18969 .30814 .18517 Metetra
.664 .741 .908 r
.30814 .18517 .31222 .18969 .3186 .18725 .31453 .18271 Metetra
.664 .741 .908 r
.31453 .18271 .3186 .18725 .325 .18479 .32094 .18024 Metetra
.664 .741 .908 r
.32094 .18024 .325 .18479 .33142 .18233 .32737 .17777 Metetra
.664 .741 .908 r
.32737 .17777 .33142 .18233 .33785 .17986 .33381 .17529 Metetra
.664 .741 .908 r
.33381 .17529 .33785 .17986 .34429 .17739 .34026 .17281 Metetra
.664 .741 .908 r
.34026 .17281 .34429 .17739 .35075 .17491 .34674 .17032 Metetra
.664 .741 .908 r
.34674 .17032 .35075 .17491 .35723 .17243 .35322 .16782 Metetra
.664 .741 .908 r
.35322 .16782 .35723 .17243 .36373 .16994 .35973 .16532 Metetra
.664 .741 .908 r
.35973 .16532 .36373 .16994 .37023 .16744 .36625 .16281 Metetra
.664 .741 .908 r
.36625 .16281 .37023 .16744 .37676 .16494 .37278 .1603 Metetra
.664 .741 .908 r
.37278 .1603 .37676 .16494 .3833 .16243 .37933 .15778 Metetra
.664 .741 .908 r
.37933 .15778 .3833 .16243 .38986 .15991 .3859 .15525 Metetra
.664 .741 .908 r
.3859 .15525 .38986 .15991 .39643 .15739 .39248 .15272 Metetra
.664 .741 .908 r
.39248 .15272 .39643 .15739 .40302 .15486 .39908 .15018 Metetra
.664 .741 .908 r
.39908 .15018 .40302 .15486 .40963 .15233 .4057 .14764 Metetra
.664 .741 .908 r
.4057 .14764 .40963 .15233 .41625 .14979 .41233 .14509 Metetra
.664 .741 .908 r
.41233 .14509 .41625 .14979 .42289 .14724 .41898 .14253 Metetra
.664 .741 .908 r
.41898 .14253 .42289 .14724 .42954 .14469 .42564 .13996 Metetra
.664 .741 .908 r
.42564 .13996 .42954 .14469 .43621 .14213 .43232 .13739 Metetra
.664 .741 .908 r
.43232 .13739 .43621 .14213 .4429 .13957 .43902 .13482 Metetra
.664 .741 .908 r
.43902 .13482 .4429 .13957 .4496 .137 .44574 .13223 Metetra
.664 .741 .908 r
.44574 .13223 .4496 .137 .45632 .13442 .45247 .12964 Metetra
.664 .741 .908 r
.45247 .12964 .45632 .13442 .46306 .13184 .45921 .12705 Metetra
.664 .741 .908 r
.45921 .12705 .46306 .13184 .46981 .12924 .46598 .12444 Metetra
.664 .741 .908 r
.46598 .12444 .46981 .12924 .47658 .12665 .47276 .12184 Metetra
.664 .741 .908 r
.47276 .12184 .47658 .12665 .48337 .12405 .47956 .11922 Metetra
.664 .741 .908 r
.47956 .11922 .48337 .12405 .49018 .12144 .48637 .1166 Metetra
.663 .741 .908 r
.48637 .1166 .49018 .12144 .497 .11882 .49321 .11397 Metetra
.663 .741 .908 r
.49321 .11397 .497 .11882 .50384 .1162 .50006 .11134 Metetra
.663 .741 .908 r
.50006 .11134 .50384 .1162 .51069 .11357 .50692 .1087 Metetra
.663 .741 .908 r
.50692 .1087 .51069 .11357 .51757 .11094 .51381 .10605 Metetra
.663 .741 .908 r
.51381 .10605 .51757 .11094 .52446 .1083 .52071 .1034 Metetra
.663 .741 .908 r
.52071 .1034 .52446 .1083 .53136 .10566 .52763 .10074 Metetra
.663 .741 .908 r
.52763 .10074 .53136 .10566 .53829 .10301 .53456 .09808 Metetra
.663 .741 .908 r
.53456 .09808 .53829 .10301 .54523 .10036 .54152 .09542 Metetra
.663 .74 .908 r
.54152 .09542 .54523 .10036 .55219 .09771 .54849 .09275 Metetra
.663 .74 .908 r
.54849 .09275 .55219 .09771 .55917 .09505 .55548 .09007 Metetra
.662 .74 .908 r
.55548 .09007 .55917 .09505 .56616 .09239 .56249 .0874 Metetra
.662 .739 .907 r
.56249 .0874 .56616 .09239 .57318 .08974 .56951 .08472 Metetra
.661 .739 .907 r
.56951 .08472 .57318 .08974 .58021 .08708 .57655 .08205 Metetra
.661 .738 .907 r
.57655 .08205 .58021 .08708 .58726 .08443 .58361 .07937 Metetra
.66 .737 .907 r
.58361 .07937 .58726 .08443 .59433 .08179 .59069 .0767 Metetra
.659 .736 .907 r
.59069 .0767 .59433 .08179 .60141 .07916 .59779 .07404 Metetra
.658 .735 .906 r
.59779 .07404 .60141 .07916 .60852 .07653 .60491 .07139 Metetra
.657 .734 .906 r
.60491 .07139 .60852 .07653 .61565 .07392 .61205 .06874 Metetra
.656 .732 .906 r
.61205 .06874 .61565 .07392 .62279 .07133 .6192 .06611 Metetra
.655 .731 .905 r
.6192 .06611 .62279 .07133 .62995 .06876 .62638 .0635 Metetra
.653 .728 .905 r
.62638 .0635 .62995 .06876 .63714 .06621 .63357 .06091 Metetra
.651 .726 .904 r
.63357 .06091 .63714 .06621 .64435 .06369 .64079 .05834 Metetra
.649 .724 .903 r
.64079 .05834 .64435 .06369 .65157 .06119 .64803 .05579 Metetra
.647 .721 .902 r
.64803 .05579 .65157 .06119 .65882 .05872 .65529 .05327 Metetra
.646 .719 .901 r
.65529 .05327 .65882 .05872 .66609 .05627 .66257 .05077 Metetra
.644 .716 .9 r
.66257 .05077 .66609 .05627 .67338 .05384 .66987 .04829 Metetra
.642 .714 .9 r
.66987 .04829 .67338 .05384 .6807 .05141 .67719 .04582 Metetra
.641 .712 .899 r
.67719 .04582 .6807 .05141 .68803 .049 .68454 .04337 Metetra
.641 .711 .898 r
.68454 .04337 .68803 .049 .69539 .04658 .6919 .04093 Metetra
.64 .71 .898 r
.6919 .04093 .69539 .04658 .70277 .04414 .69929 .03847 Metetra
.641 .711 .898 r
.69929 .03847 .70277 .04414 .71016 .04167 .7067 .036 Metetra
.691 .716 .868 r
.05339 .28272 .05772 .28753 .06362 .28477 .05929 .2799 Metetra
.692 .714 .866 r
.05929 .2799 .06362 .28477 .06953 .28194 .06522 .27704 Metetra
.692 .714 .865 r
.06522 .27704 .06953 .28194 .07546 .27906 .07115 .27418 Metetra
.691 .714 .866 r
.07115 .27418 .07546 .27906 .08141 .27618 .0771 .27133 Metetra
.689 .716 .869 r
.0771 .27133 .08141 .27618 .08736 .27331 .08305 .26851 Metetra
.687 .718 .872 r
.08305 .26851 .08736 .27331 .09332 .27049 .089 .26575 Metetra
.685 .72 .876 r
.089 .26575 .09332 .27049 .09928 .26771 .09496 .26304 Metetra
.682 .723 .881 r
.09496 .26304 .09928 .26771 .10524 .26499 .10092 .26039 Metetra
.68 .726 .885 r
.10092 .26039 .10524 .26499 .11121 .26233 .10688 .25779 Metetra
.677 .729 .889 r
.10688 .25779 .11121 .26233 .11718 .25973 .11285 .25525 Metetra
.675 .731 .893 r
.11285 .25525 .11718 .25973 .12315 .25719 .11883 .25274 Metetra
.672 .733 .896 r
.11883 .25274 .12315 .25719 .12914 .25469 .12481 .25028 Metetra
.671 .735 .898 r
.12481 .25028 .12914 .25469 .13513 .25223 .13081 .24785 Metetra
.669 .736 .901 r
.13081 .24785 .13513 .25223 .14112 .2498 .13681 .24544 Metetra
.668 .738 .902 r
.13681 .24544 .14112 .2498 .14713 .24739 .14282 .24305 Metetra
.667 .738 .904 r
.14282 .24305 .14713 .24739 .15315 .24501 .14885 .24067 Metetra
.666 .739 .905 r
.14885 .24067 .15315 .24501 .15918 .24263 .15489 .2383 Metetra
.665 .74 .905 r
.15489 .2383 .15918 .24263 .16523 .24027 .16094 .23593 Metetra
.665 .74 .906 r
.16094 .23593 .16523 .24027 .17128 .23791 .167 .23357 Metetra
.665 .74 .907 r
.167 .23357 .17128 .23791 .17735 .23555 .17308 .23121 Metetra
.664 .741 .907 r
.17308 .23121 .17735 .23555 .18343 .23319 .17917 .22885 Metetra
.664 .741 .907 r
.17917 .22885 .18343 .23319 .18953 .23083 .18527 .22648 Metetra
.664 .741 .907 r
.18527 .22648 .18953 .23083 .19564 .22847 .19139 .22411 Metetra
.664 .741 .908 r
.19139 .22411 .19564 .22847 .20177 .22611 .19752 .22174 Metetra
.664 .741 .908 r
.19752 .22174 .20177 .22611 .2079 .22374 .20367 .21937 Metetra
.664 .741 .908 r
.20367 .21937 .2079 .22374 .21406 .22137 .20983 .21699 Metetra
.664 .741 .908 r
.20983 .21699 .21406 .22137 .22023 .219 .21601 .2146 Metetra
.664 .741 .908 r
.21601 .2146 .22023 .219 .22641 .21662 .2222 .21221 Metetra
.664 .741 .908 r
.2222 .21221 .22641 .21662 .23261 .21423 .2284 .20981 Metetra
.664 .741 .908 r
.2284 .20981 .23261 .21423 .23882 .21184 .23463 .20741 Metetra
.664 .741 .908 r
.23463 .20741 .23882 .21184 .24505 .20945 .24086 .20501 Metetra
.664 .741 .908 r
.24086 .20501 .24505 .20945 .25129 .20704 .24711 .20259 Metetra
.664 .741 .908 r
.24711 .20259 .25129 .20704 .25754 .20464 .25338 .20018 Metetra
.664 .741 .908 r
.25338 .20018 .25754 .20464 .26381 .20222 .25966 .19775 Metetra
.664 .741 .908 r
.25966 .19775 .26381 .20222 .2701 .1998 .26595 .19532 Metetra
.664 .741 .908 r
.26595 .19532 .2701 .1998 .2764 .19738 .27226 .19289 Metetra
.664 .741 .908 r
.27226 .19289 .2764 .19738 .28272 .19495 .27859 .19045 Metetra
.664 .741 .908 r
.27859 .19045 .28272 .19495 .28905 .19251 .28493 .188 Metetra
.664 .741 .908 r
.28493 .188 .28905 .19251 .2954 .19007 .29129 .18555 Metetra
.664 .741 .908 r
.29129 .18555 .2954 .19007 .30176 .18762 .29766 .18309 Metetra
.664 .741 .908 r
.29766 .18309 .30176 .18762 .30814 .18517 .30405 .18062 Metetra
.664 .741 .908 r
.30405 .18062 .30814 .18517 .31453 .18271 .31045 .17815 Metetra
.664 .741 .908 r
.31045 .17815 .31453 .18271 .32094 .18024 .31687 .17568 Metetra
.664 .741 .908 r
.31687 .17568 .32094 .18024 .32737 .17777 .3233 .17319 Metetra
.664 .741 .908 r
.3233 .17319 .32737 .17777 .33381 .17529 .32975 .1707 Metetra
.664 .741 .908 r
.32975 .1707 .33381 .17529 .34026 .17281 .33622 .16821 Metetra
.664 .741 .908 r
.33622 .16821 .34026 .17281 .34674 .17032 .3427 .16571 Metetra
.664 .741 .908 r
.3427 .16571 .34674 .17032 .35322 .16782 .3492 .1632 Metetra
.664 .741 .908 r
.3492 .1632 .35322 .16782 .35973 .16532 .35571 .16069 Metetra
.664 .741 .908 r
.35571 .16069 .35973 .16532 .36625 .16281 .36224 .15817 Metetra
.664 .741 .908 r
.36224 .15817 .36625 .16281 .37278 .1603 .36878 .15564 Metetra
.664 .741 .908 r
.36878 .15564 .37278 .1603 .37933 .15778 .37534 .15311 Metetra
.664 .741 .908 r
.37534 .15311 .37933 .15778 .3859 .15525 .38192 .15057 Metetra
.664 .741 .908 r
.38192 .15057 .3859 .15525 .39248 .15272 .38851 .14803 Metetra
.664 .741 .908 r
.38851 .14803 .39248 .15272 .39908 .15018 .39512 .14548 Metetra
.664 .741 .908 r
.39512 .14548 .39908 .15018 .4057 .14764 .40175 .14292 Metetra
.664 .741 .908 r
.40175 .14292 .4057 .14764 .41233 .14509 .40839 .14036 Metetra
.664 .741 .908 r
.40839 .14036 .41233 .14509 .41898 .14253 .41505 .13779 Metetra
.664 .741 .908 r
.41505 .13779 .41898 .14253 .42564 .13996 .42173 .13521 Metetra
.664 .741 .908 r
.42173 .13521 .42564 .13996 .43232 .13739 .42842 .13263 Metetra
.664 .741 .908 r
.42842 .13263 .43232 .13739 .43902 .13482 .43513 .13004 Metetra
.664 .741 .908 r
.43513 .13004 .43902 .13482 .44574 .13223 .44185 .12745 Metetra
.664 .741 .908 r
.44185 .12745 .44574 .13223 .45247 .12964 .44859 .12485 Metetra
.664 .741 .908 r
.44859 .12485 .45247 .12964 .45921 .12705 .45535 .12224 Metetra
.664 .741 .908 r
.45535 .12224 .45921 .12705 .46598 .12444 .46213 .11962 Metetra
.664 .741 .908 r
.46213 .11962 .46598 .12444 .47276 .12184 .46892 .117 Metetra
.664 .741 .908 r
.46892 .117 .47276 .12184 .47956 .11922 .47573 .11437 Metetra
.664 .741 .908 r
.47573 .11437 .47956 .11922 .48637 .1166 .48255 .11174 Metetra
.664 .741 .908 r
.48255 .11174 .48637 .1166 .49321 .11397 .4894 .1091 Metetra
.663 .741 .908 r
.4894 .1091 .49321 .11397 .50006 .11134 .49626 .10645 Metetra
.663 .741 .908 r
.49626 .10645 .50006 .11134 .50692 .1087 .50314 .1038 Metetra
.663 .741 .908 r
.50314 .1038 .50692 .1087 .51381 .10605 .51003 .10114 Metetra
.663 .741 .908 r
.51003 .10114 .51381 .10605 .52071 .1034 .51694 .09848 Metetra
.663 .741 .908 r
.51694 .09848 .52071 .1034 .52763 .10074 .52387 .09581 Metetra
.663 .741 .908 r
.52387 .09581 .52763 .10074 .53456 .09808 .53082 .09313 Metetra
.663 .741 .908 r
.53082 .09313 .53456 .09808 .54152 .09542 .53779 .09045 Metetra
.663 .741 .908 r
.53779 .09045 .54152 .09542 .54849 .09275 .54477 .08777 Metetra
.663 .74 .908 r
.54477 .08777 .54849 .09275 .55548 .09007 .55177 .08508 Metetra
.663 .74 .908 r
.55177 .08508 .55548 .09007 .56249 .0874 .55879 .08238 Metetra
.662 .74 .908 r
.55879 .08238 .56249 .0874 .56951 .08472 .56583 .07969 Metetra
.662 .739 .907 r
.56583 .07969 .56951 .08472 .57655 .08205 .57288 .07699 Metetra
.661 .739 .907 r
.57288 .07699 .57655 .08205 .58361 .07937 .57995 .0743 Metetra
.661 .738 .907 r
.57995 .0743 .58361 .07937 .59069 .0767 .58705 .07161 Metetra
.66 .737 .907 r
.58705 .07161 .59069 .0767 .59779 .07404 .59416 .06892 Metetra
.659 .736 .907 r
.59416 .06892 .59779 .07404 .60491 .07139 .60128 .06623 Metetra
.658 .735 .906 r
.60128 .06623 .60491 .07139 .61205 .06874 .60843 .06356 Metetra
.657 .734 .906 r
.60843 .06356 .61205 .06874 .6192 .06611 .6156 .06089 Metetra
.656 .732 .906 r
.6156 .06089 .6192 .06611 .62638 .0635 .62279 .05824 Metetra
.655 .731 .905 r
.62279 .05824 .62638 .0635 .63357 .06091 .62999 .05561 Metetra
.653 .729 .905 r
.62999 .05561 .63357 .06091 .64079 .05834 .63722 .053 Metetra
.651 .726 .904 r
.63722 .053 .64079 .05834 .64803 .05579 .64447 .0504 Metetra
.65 .724 .903 r
.64447 .0504 .64803 .05579 .65529 .05327 .65174 .04783 Metetra
.648 .722 .902 r
.65174 .04783 .65529 .05327 .66257 .05077 .65903 .04528 Metetra
.646 .719 .902 r
.65903 .04528 .66257 .05077 .66987 .04829 .66634 .04275 Metetra
.644 .717 .901 r
.66634 .04275 .66987 .04829 .67719 .04582 .67367 .04025 Metetra
.643 .715 .9 r
.67367 .04025 .67719 .04582 .68454 .04337 .68103 .03776 Metetra
.642 .713 .899 r
.68103 .03776 .68454 .04337 .6919 .04093 .6884 .03527 Metetra
.641 .712 .899 r
.6884 .03527 .6919 .04093 .69929 .03847 .6958 .0328 Metetra
.641 .711 .898 r
.6958 .0328 .69929 .03847 .7067 .036 .70322 .03031 Metetra
.691 .715 .867 r
.04904 .27787 .05339 .28272 .05929 .2799 .05495 .27503 Metetra
.691 .715 .867 r
.05495 .27503 .05929 .2799 .06522 .27704 .06088 .27218 Metetra
.69 .715 .868 r
.06088 .27218 .06522 .27704 .07115 .27418 .06682 .26934 Metetra
.689 .716 .87 r
.06682 .26934 .07115 .27418 .0771 .27133 .07276 .26654 Metetra
.687 .718 .873 r
.07276 .26654 .0771 .27133 .08305 .26851 .07871 .26379 Metetra
.684 .721 .877 r
.07871 .26379 .08305 .26851 .089 .26575 .08466 .26108 Metetra
.682 .724 .881 r
.08466 .26108 .089 .26575 .09496 .26304 .09061 .25844 Metetra
.679 .726 .885 r
.09061 .25844 .09496 .26304 .10092 .26039 .09657 .25584 Metetra
.677 .729 .889 r
.09657 .25584 .10092 .26039 .10688 .25779 .10253 .2533 Metetra
.674 .731 .893 r
.10253 .2533 .10688 .25779 .11285 .25525 .10851 .2508 Metetra
.672 .733 .896 r
.10851 .2508 .11285 .25525 .11883 .25274 .11448 .24833 Metetra
.671 .735 .898 r
.11448 .24833 .11883 .25274 .12481 .25028 .12047 .24589 Metetra
.669 .736 .901 r
.12047 .24589 .12481 .25028 .13081 .24785 .12647 .24348 Metetra
.668 .738 .902 r
.12647 .24348 .13081 .24785 .13681 .24544 .13247 .24108 Metetra
.667 .738 .904 r
.13247 .24108 .13681 .24544 .14282 .24305 .13849 .2387 Metetra
.666 .739 .905 r
.13849 .2387 .14282 .24305 .14885 .24067 .14452 .23633 Metetra
.665 .74 .905 r
.14452 .23633 .14885 .24067 .15489 .2383 .15057 .23396 Metetra
.665 .74 .906 r
.15057 .23396 .15489 .2383 .16094 .23593 .15663 .23159 Metetra
.665 .74 .907 r
.15663 .23159 .16094 .23593 .167 .23357 .1627 .22922 Metetra
.664 .741 .907 r
.1627 .22922 .167 .23357 .17308 .23121 .16878 .22685 Metetra
.664 .741 .907 r
.16878 .22685 .17308 .23121 .17917 .22885 .17488 .22448 Metetra
.664 .741 .907 r
.17488 .22448 .17917 .22885 .18527 .22648 .18099 .22211 Metetra
.664 .741 .908 r
.18099 .22211 .18527 .22648 .19139 .22411 .18712 .21974 Metetra
.664 .741 .908 r
.18712 .21974 .19139 .22411 .19752 .22174 .19326 .21735 Metetra
.664 .741 .908 r
.19326 .21735 .19752 .22174 .20367 .21937 .19942 .21497 Metetra
.664 .741 .908 r
.19942 .21497 .20367 .21937 .20983 .21699 .20559 .21258 Metetra
.664 .741 .908 r
.20559 .21258 .20983 .21699 .21601 .2146 .21177 .21018 Metetra
.664 .741 .908 r
.21177 .21018 .21601 .2146 .2222 .21221 .21797 .20778 Metetra
.664 .741 .908 r
.21797 .20778 .2222 .21221 .2284 .20981 .22418 .20538 Metetra
.664 .741 .908 r
.22418 .20538 .2284 .20981 .23463 .20741 .23041 .20297 Metetra
.664 .741 .908 r
.23041 .20297 .23463 .20741 .24086 .20501 .23666 .20055 Metetra
.664 .741 .908 r
.23666 .20055 .24086 .20501 .24711 .20259 .24292 .19813 Metetra
.664 .741 .908 r
.24292 .19813 .24711 .20259 .25338 .20018 .24919 .1957 Metetra
.664 .741 .908 r
.24919 .1957 .25338 .20018 .25966 .19775 .25548 .19326 Metetra
.664 .741 .908 r
.25548 .19326 .25966 .19775 .26595 .19532 .26179 .19082 Metetra
.664 .741 .908 r
.26179 .19082 .26595 .19532 .27226 .19289 .26811 .18838 Metetra
.664 .741 .908 r
.26811 .18838 .27226 .19289 .27859 .19045 .27444 .18592 Metetra
.664 .741 .908 r
.27444 .18592 .27859 .19045 .28493 .188 .28079 .18347 Metetra
.664 .741 .908 r
.28079 .18347 .28493 .188 .29129 .18555 .28716 .181 Metetra
.664 .741 .908 r
.28716 .181 .29129 .18555 .29766 .18309 .29354 .17853 Metetra
.664 .741 .908 r
.29354 .17853 .29766 .18309 .30405 .18062 .29993 .17606 Metetra
.664 .741 .908 r
.29993 .17606 .30405 .18062 .31045 .17815 .30635 .17358 Metetra
.664 .741 .908 r
.30635 .17358 .31045 .17815 .31687 .17568 .31278 .17109 Metetra
.664 .741 .908 r
.31278 .17109 .31687 .17568 .3233 .17319 .31922 .16859 Metetra
.664 .741 .908 r
.31922 .16859 .3233 .17319 .32975 .1707 .32568 .16609 Metetra
.664 .741 .908 r
.32568 .16609 .32975 .1707 .33622 .16821 .33215 .16359 Metetra
.664 .741 .908 r
.33215 .16359 .33622 .16821 .3427 .16571 .33864 .16107 Metetra
.664 .741 .908 r
.33864 .16107 .3427 .16571 .3492 .1632 .34515 .15856 Metetra
.664 .741 .908 r
.34515 .15856 .3492 .1632 .35571 .16069 .35167 .15603 Metetra
.664 .741 .908 r
.35167 .15603 .35571 .16069 .36224 .15817 .35821 .1535 Metetra
.664 .741 .908 r
.35821 .1535 .36224 .15817 .36878 .15564 .36477 .15096 Metetra
.664 .741 .908 r
.36477 .15096 .36878 .15564 .37534 .15311 .37134 .14842 Metetra
.664 .741 .908 r
.37134 .14842 .37534 .15311 .38192 .15057 .37793 .14587 Metetra
.664 .741 .908 r
.37793 .14587 .38192 .15057 .38851 .14803 .38453 .14332 Metetra
.664 .741 .908 r
.38453 .14332 .38851 .14803 .39512 .14548 .39115 .14075 Metetra
.664 .741 .908 r
.39115 .14075 .39512 .14548 .40175 .14292 .39778 .13818 Metetra
.664 .741 .908 r
.39778 .13818 .40175 .14292 .40839 .14036 .40444 .13561 Metetra
.664 .741 .908 r
.40444 .13561 .40839 .14036 .41505 .13779 .41111 .13303 Metetra
.664 .741 .908 r
.41111 .13303 .41505 .13779 .42173 .13521 .41779 .13044 Metetra
.664 .741 .908 r
.41779 .13044 .42173 .13521 .42842 .13263 .42449 .12785 Metetra
.664 .741 .908 r
.42449 .12785 .42842 .13263 .43513 .13004 .43121 .12525 Metetra
.664 .741 .908 r
.43121 .12525 .43513 .13004 .44185 .12745 .43795 .12264 Metetra
.664 .741 .908 r
.43795 .12264 .44185 .12745 .44859 .12485 .4447 .12003 Metetra
.664 .741 .908 r
.4447 .12003 .44859 .12485 .45535 .12224 .45147 .11741 Metetra
.664 .741 .908 r
.45147 .11741 .45535 .12224 .46213 .11962 .45826 .11478 Metetra
.664 .741 .908 r
.45826 .11478 .46213 .11962 .46892 .117 .46506 .11215 Metetra
.664 .741 .908 r
.46506 .11215 .46892 .117 .47573 .11437 .47188 .10951 Metetra
.664 .741 .908 r
.47188 .10951 .47573 .11437 .48255 .11174 .47872 .10686 Metetra
.664 .741 .908 r
.47872 .10686 .48255 .11174 .4894 .1091 .48557 .10421 Metetra
.664 .741 .908 r
.48557 .10421 .4894 .1091 .49626 .10645 .49244 .10155 Metetra
.663 .741 .908 r
.49244 .10155 .49626 .10645 .50314 .1038 .49933 .09888 Metetra
.663 .741 .908 r
.49933 .09888 .50314 .1038 .51003 .10114 .50624 .09621 Metetra
.663 .741 .908 r
.50624 .09621 .51003 .10114 .51694 .09848 .51316 .09353 Metetra
.663 .741 .908 r
.51316 .09353 .51694 .09848 .52387 .09581 .5201 .09085 Metetra
.663 .741 .908 r
.5201 .09085 .52387 .09581 .53082 .09313 .52706 .08816 Metetra
.663 .741 .908 r
.52706 .08816 .53082 .09313 .53779 .09045 .53404 .08546 Metetra
.663 .741 .908 r
.53404 .08546 .53779 .09045 .54477 .08777 .54103 .08276 Metetra
.663 .741 .908 r
.54103 .08276 .54477 .08777 .55177 .08508 .54805 .08006 Metetra
.663 .74 .908 r
.54805 .08006 .55177 .08508 .55879 .08238 .55508 .07735 Metetra
.663 .74 .908 r
.55508 .07735 .55879 .08238 .56583 .07969 .56213 .07464 Metetra
.662 .74 .908 r
.56213 .07464 .56583 .07969 .57288 .07699 .56919 .07192 Metetra
.662 .739 .907 r
.56919 .07192 .57288 .07699 .57995 .0743 .57628 .06921 Metetra
.661 .739 .907 r
.57628 .06921 .57995 .0743 .58705 .07161 .58338 .06649 Metetra
.661 .738 .907 r
.58338 .06649 .58705 .07161 .59416 .06892 .5905 .06378 Metetra
.66 .737 .907 r
.5905 .06378 .59416 .06892 .60128 .06623 .59764 .06107 Metetra
.659 .736 .907 r
.59764 .06107 .60128 .06623 .60843 .06356 .6048 .05837 Metetra
.658 .735 .906 r
.6048 .05837 .60843 .06356 .6156 .06089 .61198 .05567 Metetra
.657 .734 .906 r
.61198 .05567 .6156 .06089 .62279 .05824 .61918 .05299 Metetra
.656 .732 .906 r
.61918 .05299 .62279 .05824 .62999 .05561 .6264 .05032 Metetra
.655 .731 .905 r
.6264 .05032 .62999 .05561 .63722 .053 .63363 .04766 Metetra
.653 .729 .905 r
.63363 .04766 .63722 .053 .64447 .0504 .64089 .04503 Metetra
.651 .727 .904 r
.64089 .04503 .64447 .0504 .65174 .04783 .64817 .04241 Metetra
.65 .724 .903 r
.64817 .04241 .65174 .04783 .65903 .04528 .65547 .03981 Metetra
.648 .722 .903 r
.65547 .03981 .65903 .04528 .66634 .04275 .66279 .03724 Metetra
.646 .72 .902 r
.66279 .03724 .66634 .04275 .67367 .04025 .67014 .03468 Metetra
.645 .717 .901 r
.67014 .03468 .67367 .04025 .68103 .03776 .6775 .03215 Metetra
.643 .715 .9 r
.6775 .03215 .68103 .03776 .6884 .03527 .68489 .02963 Metetra
.642 .714 .899 r
.68489 .02963 .6884 .03527 .6958 .0328 .6923 .02712 Metetra
.642 .713 .899 r
.6923 .02712 .6958 .0328 .70322 .03031 .69973 .02461 Metetra
.69 .715 .868 r
.04467 .27302 .04904 .27787 .05495 .27503 .05059 .27018 Metetra
.69 .716 .869 r
.05059 .27018 .05495 .27503 .06088 .27218 .05652 .26736 Metetra
.688 .717 .871 r
.05652 .26736 .06088 .27218 .06682 .26934 .06245 .26457 Metetra
.686 .719 .874 r
.06245 .26457 .06682 .26934 .07276 .26654 .06839 .26182 Metetra
.684 .722 .878 r
.06839 .26182 .07276 .26654 .07871 .26379 .07434 .25913 Metetra
.681 .724 .882 r
.07434 .25913 .07871 .26379 .08466 .26108 .08028 .25648 Metetra
.679 .727 .886 r
.08028 .25648 .08466 .26108 .09061 .25844 .08624 .25389 Metetra
.676 .729 .89 r
.08624 .25389 .09061 .25844 .09657 .25584 .0922 .25135 Metetra
.674 .732 .893 r
.0922 .25135 .09657 .25584 .10253 .2533 .09816 .24885 Metetra
.672 .733 .896 r
.09816 .24885 .10253 .2533 .10851 .2508 .10413 .24638 Metetra
.67 .735 .899 r
.10413 .24638 .10851 .2508 .11448 .24833 .11011 .24394 Metetra
.669 .736 .901 r
.11011 .24394 .11448 .24833 .12047 .24589 .1161 .24152 Metetra
.668 .738 .902 r
.1161 .24152 .12047 .24589 .12647 .24348 .1221 .23912 Metetra
.667 .738 .904 r
.1221 .23912 .12647 .24348 .13247 .24108 .12812 .23673 Metetra
.666 .739 .905 r
.12812 .23673 .13247 .24108 .13849 .2387 .13414 .23435 Metetra
.665 .74 .905 r
.13414 .23435 .13849 .2387 .14452 .23633 .14018 .23197 Metetra
.665 .74 .906 r
.14018 .23197 .14452 .23633 .15057 .23396 .14623 .2296 Metetra
.665 .74 .907 r
.14623 .2296 .15057 .23396 .15663 .23159 .1523 .22723 Metetra
.664 .741 .907 r
.1523 .22723 .15663 .23159 .1627 .22922 .15837 .22486 Metetra
.664 .741 .907 r
.15837 .22486 .1627 .22922 .16878 .22685 .16447 .22248 Metetra
.664 .741 .907 r
.16447 .22248 .16878 .22685 .17488 .22448 .17057 .22011 Metetra
.664 .741 .908 r
.17057 .22011 .17488 .22448 .18099 .22211 .17669 .21772 Metetra
.664 .741 .908 r
.17669 .21772 .18099 .22211 .18712 .21974 .18283 .21534 Metetra
.664 .741 .908 r
.18283 .21534 .18712 .21974 .19326 .21735 .18898 .21295 Metetra
.664 .741 .908 r
.18898 .21295 .19326 .21735 .19942 .21497 .19514 .21055 Metetra
.664 .741 .908 r
.19514 .21055 .19942 .21497 .20559 .21258 .20132 .20815 Metetra
.664 .741 .908 r
.20132 .20815 .20559 .21258 .21177 .21018 .20751 .20575 Metetra
.664 .741 .908 r
.20751 .20575 .21177 .21018 .21797 .20778 .21372 .20334 Metetra
.664 .741 .908 r
.21372 .20334 .21797 .20778 .22418 .20538 .21995 .20092 Metetra
.664 .741 .908 r
.21995 .20092 .22418 .20538 .23041 .20297 .22618 .1985 Metetra
.664 .741 .908 r
.22618 .1985 .23041 .20297 .23666 .20055 .23244 .19607 Metetra
.664 .741 .908 r
.23244 .19607 .23666 .20055 .24292 .19813 .23871 .19364 Metetra
.664 .741 .908 r
.23871 .19364 .24292 .19813 .24919 .1957 .24499 .1912 Metetra
.664 .741 .908 r
.24499 .1912 .24919 .1957 .25548 .19326 .25129 .18875 Metetra
.664 .741 .908 r
.25129 .18875 .25548 .19326 .26179 .19082 .2576 .1863 Metetra
.664 .741 .908 r
.2576 .1863 .26179 .19082 .26811 .18838 .26393 .18385 Metetra
.664 .741 .908 r
.26393 .18385 .26811 .18838 .27444 .18592 .27027 .18138 Metetra
.664 .741 .908 r
.27027 .18138 .27444 .18592 .28079 .18347 .27663 .17891 Metetra
.664 .741 .908 r
.27663 .17891 .28079 .18347 .28716 .181 .28301 .17644 Metetra
.664 .741 .908 r
.28301 .17644 .28716 .181 .29354 .17853 .2894 .17396 Metetra
.664 .741 .908 r
.2894 .17396 .29354 .17853 .29993 .17606 .2958 .17147 Metetra
.664 .741 .908 r
.2958 .17147 .29993 .17606 .30635 .17358 .30223 .16898 Metetra
.664 .741 .908 r
.30223 .16898 .30635 .17358 .31278 .17109 .30866 .16648 Metetra
.664 .741 .908 r
.30866 .16648 .31278 .17109 .31922 .16859 .31512 .16397 Metetra
.664 .741 .908 r
.31512 .16397 .31922 .16859 .32568 .16609 .32159 .16146 Metetra
.664 .741 .908 r
.32159 .16146 .32568 .16609 .33215 .16359 .32807 .15894 Metetra
.664 .741 .908 r
.32807 .15894 .33215 .16359 .33864 .16107 .33457 .15642 Metetra
.664 .741 .908 r
.33457 .15642 .33864 .16107 .34515 .15856 .34109 .15389 Metetra
.664 .741 .908 r
.34109 .15389 .34515 .15856 .35167 .15603 .34762 .15135 Metetra
.664 .741 .908 r
.34762 .15135 .35167 .15603 .35821 .1535 .35417 .14881 Metetra
.664 .741 .908 r
.35417 .14881 .35821 .1535 .36477 .15096 .36073 .14626 Metetra
.664 .741 .908 r
.36073 .14626 .36477 .15096 .37134 .14842 .36731 .14371 Metetra
.664 .741 .908 r
.36731 .14371 .37134 .14842 .37793 .14587 .37391 .14115 Metetra
.664 .741 .908 r
.37391 .14115 .37793 .14587 .38453 .14332 .38052 .13858 Metetra
.664 .741 .908 r
.38052 .13858 .38453 .14332 .39115 .14075 .38715 .13601 Metetra
.664 .741 .908 r
.38715 .13601 .39115 .14075 .39778 .13818 .3938 .13343 Metetra
.664 .741 .908 r
.3938 .13343 .39778 .13818 .40444 .13561 .40046 .13084 Metetra
.664 .741 .908 r
.40046 .13084 .40444 .13561 .41111 .13303 .40714 .12825 Metetra
.664 .741 .908 r
.40714 .12825 .41111 .13303 .41779 .13044 .41384 .12565 Metetra
.664 .741 .908 r
.41384 .12565 .41779 .13044 .42449 .12785 .42055 .12304 Metetra
.664 .741 .908 r
.42055 .12304 .42449 .12785 .43121 .12525 .42728 .12043 Metetra
.664 .741 .908 r
.42728 .12043 .43121 .12525 .43795 .12264 .43403 .11781 Metetra
.664 .741 .908 r
.43403 .11781 .43795 .12264 .4447 .12003 .44079 .11518 Metetra
.664 .741 .908 r
.44079 .11518 .4447 .12003 .45147 .11741 .44757 .11255 Metetra
.664 .741 .908 r
.44757 .11255 .45147 .11741 .45826 .11478 .45437 .10991 Metetra
.664 .741 .908 r
.45437 .10991 .45826 .11478 .46506 .11215 .46118 .10727 Metetra
.664 .741 .908 r
.46118 .10727 .46506 .11215 .47188 .10951 .46801 .10462 Metetra
.664 .741 .908 r
.46801 .10462 .47188 .10951 .47872 .10686 .47486 .10196 Metetra
.664 .741 .908 r
.47486 .10196 .47872 .10686 .48557 .10421 .48173 .09929 Metetra
.664 .741 .908 r
.48173 .09929 .48557 .10421 .49244 .10155 .48861 .09662 Metetra
.663 .741 .908 r
.48861 .09662 .49244 .10155 .49933 .09888 .49551 .09394 Metetra
.663 .741 .908 r
.49551 .09394 .49933 .09888 .50624 .09621 .50243 .09126 Metetra
.663 .741 .908 r
.50243 .09126 .50624 .09621 .51316 .09353 .50936 .08857 Metetra
.663 .741 .908 r
.50936 .08857 .51316 .09353 .5201 .09085 .51632 .08587 Metetra
.663 .741 .908 r
.51632 .08587 .5201 .09085 .52706 .08816 .52329 .08317 Metetra
.663 .741 .908 r
.52329 .08317 .52706 .08816 .53404 .08546 .53028 .08046 Metetra
.663 .741 .908 r
.53028 .08046 .53404 .08546 .54103 .08276 .53728 .07774 Metetra
.663 .741 .908 r
.53728 .07774 .54103 .08276 .54805 .08006 .54431 .07502 Metetra
.663 .741 .908 r
.54431 .07502 .54805 .08006 .55508 .07735 .55135 .0723 Metetra
.663 .74 .908 r
.55135 .0723 .55508 .07735 .56213 .07464 .55841 .06957 Metetra
.663 .74 .908 r
.55841 .06957 .56213 .07464 .56919 .07192 .56549 .06684 Metetra
.662 .74 .908 r
.56549 .06684 .56919 .07192 .57628 .06921 .57258 .0641 Metetra
.662 .739 .907 r
.57258 .0641 .57628 .06921 .58338 .06649 .5797 .06137 Metetra
.661 .739 .907 r
.5797 .06137 .58338 .06649 .5905 .06378 .58683 .05863 Metetra
.661 .738 .907 r
.58683 .05863 .5905 .06378 .59764 .06107 .59398 .0559 Metetra
.66 .737 .907 r
.59398 .0559 .59764 .06107 .6048 .05837 .60115 .05317 Metetra
.659 .737 .907 r
.60115 .05317 .6048 .05837 .61198 .05567 .60834 .05045 Metetra
.658 .735 .906 r
.60834 .05045 .61198 .05567 .61918 .05299 .61555 .04773 Metetra
.657 .734 .906 r
.61555 .04773 .61918 .05299 .6264 .05032 .62278 .04503 Metetra
.656 .733 .906 r
.62278 .04503 .6264 .05032 .63363 .04766 .63003 .04233 Metetra
.655 .731 .905 r
.63003 .04233 .63363 .04766 .64089 .04503 .6373 .03966 Metetra
.653 .729 .905 r
.6373 .03966 .64089 .04503 .64817 .04241 .64459 .037 Metetra
.652 .727 .904 r
.64459 .037 .64817 .04241 .65547 .03981 .6519 .03436 Metetra
.65 .725 .903 r
.6519 .03436 .65547 .03981 .66279 .03724 .65924 .03174 Metetra
.648 .722 .903 r
.65924 .03174 .66279 .03724 .67014 .03468 .66659 .02914 Metetra
.647 .72 .902 r
.66659 .02914 .67014 .03468 .6775 .03215 .67397 .02655 Metetra
.645 .718 .901 r
.67397 .02655 .6775 .03215 .68489 .02963 .68136 .02399 Metetra
.644 .716 .9 r
.68136 .02399 .68489 .02963 .6923 .02712 .68878 .02144 Metetra
.643 .715 .9 r
.68878 .02144 .6923 .02712 .69973 .02461 .69623 .0189 Metetra
.689 .717 .87 r
.04027 .26818 .04467 .27302 .05059 .27018 .04619 .26537 Metetra
.688 .718 .872 r
.04619 .26537 .05059 .27018 .05652 .26736 .05212 .26259 Metetra
.686 .72 .875 r
.05212 .26259 .05652 .26736 .06245 .26457 .05806 .25986 Metetra
.683 .722 .879 r
.05806 .25986 .06245 .26457 .06839 .26182 .06399 .25717 Metetra
.681 .725 .883 r
.06399 .25717 .06839 .26182 .07434 .25913 .06994 .25453 Metetra
.679 .727 .887 r
.06994 .25453 .07434 .25913 .08028 .25648 .07588 .25194 Metetra
.676 .73 .89 r
.07588 .25194 .08028 .25648 .08624 .25389 .08183 .24939 Metetra
.674 .732 .893 r
.08183 .24939 .08624 .25389 .0922 .25135 .08779 .24689 Metetra
.672 .734 .896 r
.08779 .24689 .0922 .25135 .09816 .24885 .09376 .24442 Metetra
.67 .735 .899 r
.09376 .24442 .09816 .24885 .10413 .24638 .09973 .24197 Metetra
.669 .737 .901 r
.09973 .24197 .10413 .24638 .11011 .24394 .10572 .23955 Metetra
.668 .738 .902 r
.10572 .23955 .11011 .24394 .1161 .24152 .11171 .23715 Metetra
.667 .738 .904 r
.11171 .23715 .1161 .24152 .1221 .23912 .11772 .23475 Metetra
.666 .739 .905 r
.11772 .23475 .1221 .23912 .12812 .23673 .12374 .23237 Metetra
.665 .74 .905 r
.12374 .23237 .12812 .23673 .13414 .23435 .12977 .22999 Metetra
.665 .74 .906 r
.12977 .22999 .13414 .23435 .14018 .23197 .13582 .22761 Metetra
.665 .74 .907 r
.13582 .22761 .14018 .23197 .14623 .2296 .14188 .22524 Metetra
.664 .741 .907 r
.14188 .22524 .14623 .2296 .1523 .22723 .14795 .22286 Metetra
.664 .741 .907 r
.14795 .22286 .1523 .22723 .15837 .22486 .15403 .22048 Metetra
.664 .741 .907 r
.15403 .22048 .15837 .22486 .16447 .22248 .16013 .2181 Metetra
.664 .741 .908 r
.16013 .2181 .16447 .22248 .17057 .22011 .16625 .21571 Metetra
.664 .741 .908 r
.16625 .21571 .17057 .22011 .17669 .21772 .17238 .21332 Metetra
.664 .741 .908 r
.17238 .21332 .17669 .21772 .18283 .21534 .17852 .21093 Metetra
.664 .741 .908 r
.17852 .21093 .18283 .21534 .18898 .21295 .18468 .20853 Metetra
.664 .741 .908 r
.18468 .20853 .18898 .21295 .19514 .21055 .19085 .20612 Metetra
.664 .741 .908 r
.19085 .20612 .19514 .21055 .20132 .20815 .19704 .20371 Metetra
.664 .741 .908 r
.19704 .20371 .20132 .20815 .20751 .20575 .20324 .20129 Metetra
.664 .741 .908 r
.20324 .20129 .20751 .20575 .21372 .20334 .20946 .19887 Metetra
.664 .741 .908 r
.20946 .19887 .21372 .20334 .21995 .20092 .21569 .19645 Metetra
.664 .741 .908 r
.21569 .19645 .21995 .20092 .22618 .1985 .22194 .19401 Metetra
.664 .741 .908 r
.22194 .19401 .22618 .1985 .23244 .19607 .2282 .19157 Metetra
.664 .741 .908 r
.2282 .19157 .23244 .19607 .23871 .19364 .23447 .18913 Metetra
.664 .741 .908 r
.23447 .18913 .23871 .19364 .24499 .1912 .24077 .18668 Metetra
.664 .741 .908 r
.24077 .18668 .24499 .1912 .25129 .18875 .24707 .18422 Metetra
.664 .741 .908 r
.24707 .18422 .25129 .18875 .2576 .1863 .2534 .18176 Metetra
.664 .741 .908 r
.2534 .18176 .2576 .1863 .26393 .18385 .25973 .17929 Metetra
.664 .741 .908 r
.25973 .17929 .26393 .18385 .27027 .18138 .26609 .17682 Metetra
.664 .741 .908 r
.26609 .17682 .27027 .18138 .27663 .17891 .27246 .17434 Metetra
.664 .741 .908 r
.27246 .17434 .27663 .17891 .28301 .17644 .27884 .17185 Metetra
.664 .741 .908 r
.27884 .17185 .28301 .17644 .2894 .17396 .28524 .16936 Metetra
.664 .741 .908 r
.28524 .16936 .2894 .17396 .2958 .17147 .29166 .16686 Metetra
.664 .741 .908 r
.29166 .16686 .2958 .17147 .30223 .16898 .29809 .16436 Metetra
.664 .741 .908 r
.29809 .16436 .30223 .16898 .30866 .16648 .30453 .16185 Metetra
.664 .741 .908 r
.30453 .16185 .30866 .16648 .31512 .16397 .311 .15933 Metetra
.664 .741 .908 r
.311 .15933 .31512 .16397 .32159 .16146 .31747 .15681 Metetra
.664 .741 .908 r
.31747 .15681 .32159 .16146 .32807 .15894 .32397 .15428 Metetra
.664 .741 .908 r
.32397 .15428 .32807 .15894 .33457 .15642 .33048 .15175 Metetra
.664 .741 .908 r
.33048 .15175 .33457 .15642 .34109 .15389 .33701 .1492 Metetra
.664 .741 .908 r
.33701 .1492 .34109 .15389 .34762 .15135 .34355 .14666 Metetra
.664 .741 .908 r
.34355 .14666 .34762 .15135 .35417 .14881 .35011 .1441 Metetra
.664 .741 .908 r
.35011 .1441 .35417 .14881 .36073 .14626 .35668 .14154 Metetra
.664 .741 .908 r
.35668 .14154 .36073 .14626 .36731 .14371 .36327 .13898 Metetra
.664 .741 .908 r
.36327 .13898 .36731 .14371 .37391 .14115 .36988 .1364 Metetra
.664 .741 .908 r
.36988 .1364 .37391 .14115 .38052 .13858 .3765 .13382 Metetra
.664 .741 .908 r
.3765 .13382 .38052 .13858 .38715 .13601 .38314 .13124 Metetra
.664 .741 .908 r
.38314 .13124 .38715 .13601 .3938 .13343 .3898 .12865 Metetra
.664 .741 .908 r
.3898 .12865 .3938 .13343 .40046 .13084 .39647 .12605 Metetra
.664 .741 .908 r
.39647 .12605 .40046 .13084 .40714 .12825 .40316 .12344 Metetra
.664 .741 .908 r
.40316 .12344 .40714 .12825 .41384 .12565 .40987 .12083 Metetra
.664 .741 .908 r
.40987 .12083 .41384 .12565 .42055 .12304 .41659 .11821 Metetra
.664 .741 .908 r
.41659 .11821 .42055 .12304 .42728 .12043 .42333 .11559 Metetra
.664 .741 .908 r
.42333 .11559 .42728 .12043 .43403 .11781 .43009 .11296 Metetra
.664 .741 .908 r
.43009 .11296 .43403 .11781 .44079 .11518 .43686 .11032 Metetra
.664 .741 .908 r
.43686 .11032 .44079 .11518 .44757 .11255 .44365 .10767 Metetra
.664 .741 .908 r
.44365 .10767 .44757 .11255 .45437 .10991 .45046 .10502 Metetra
.664 .741 .908 r
.45046 .10502 .45437 .10991 .46118 .10727 .45729 .10237 Metetra
.664 .741 .908 r
.45729 .10237 .46118 .10727 .46801 .10462 .46413 .0997 Metetra
.664 .741 .908 r
.46413 .0997 .46801 .10462 .47486 .10196 .47099 .09703 Metetra
.664 .741 .908 r
.47099 .09703 .47486 .10196 .48173 .09929 .47786 .09435 Metetra
.664 .741 .908 r
.47786 .09435 .48173 .09929 .48861 .09662 .48476 .09167 Metetra
.664 .741 .908 r
.48476 .09167 .48861 .09662 .49551 .09394 .49167 .08898 Metetra
.663 .741 .908 r
.49167 .08898 .49551 .09394 .50243 .09126 .4986 .08628 Metetra
.663 .741 .908 r
.4986 .08628 .50243 .09126 .50936 .08857 .50555 .08358 Metetra
.663 .741 .908 r
.50555 .08358 .50936 .08857 .51632 .08587 .51251 .08087 Metetra
.663 .741 .908 r
.51251 .08087 .51632 .08587 .52329 .08317 .51949 .07815 Metetra
.663 .741 .908 r
.51949 .07815 .52329 .08317 .53028 .08046 .52649 .07543 Metetra
.663 .741 .908 r
.52649 .07543 .53028 .08046 .53728 .07774 .53351 .0727 Metetra
.663 .741 .908 r
.53351 .0727 .53728 .07774 .54431 .07502 .54055 .06996 Metetra
.663 .741 .908 r
.54055 .06996 .54431 .07502 .55135 .0723 .5476 .06722 Metetra
.663 .741 .908 r
.5476 .06722 .55135 .0723 .55841 .06957 .55467 .06448 Metetra
.663 .74 .908 r
.55467 .06448 .55841 .06957 .56549 .06684 .56176 .06173 Metetra
.663 .74 .908 r
.56176 .06173 .56549 .06684 .57258 .0641 .56887 .05898 Metetra
.662 .74 .908 r
.56887 .05898 .57258 .0641 .5797 .06137 .576 .05622 Metetra
.662 .739 .907 r
.576 .05622 .5797 .06137 .58683 .05863 .58314 .05347 Metetra
.661 .739 .907 r
.58314 .05347 .58683 .05863 .59398 .0559 .59031 .05072 Metetra
.661 .738 .907 r
.59031 .05072 .59398 .0559 .60115 .05317 .59749 .04796 Metetra
.66 .737 .907 r
.59749 .04796 .60115 .05317 .60834 .05045 .60469 .04521 Metetra
.659 .737 .907 r
.60469 .04521 .60834 .05045 .61555 .04773 .61191 .04247 Metetra
.659 .735 .906 r
.61191 .04247 .61555 .04773 .62278 .04503 .61915 .03973 Metetra
.657 .734 .906 r
.61915 .03973 .62278 .04503 .63003 .04233 .62642 .037 Metetra
.656 .733 .906 r
.62642 .037 .63003 .04233 .6373 .03966 .6337 .03429 Metetra
.655 .731 .905 r
.6337 .03429 .6373 .03966 .64459 .037 .641 .03159 Metetra
.653 .729 .905 r
.641 .03159 .64459 .037 .6519 .03436 .64832 .02891 Metetra
.652 .727 .904 r
.64832 .02891 .6519 .03436 .65924 .03174 .65566 .02624 Metetra
.65 .725 .903 r
.65566 .02624 .65924 .03174 .66659 .02914 .66303 .0236 Metetra
.649 .723 .903 r
.66303 .0236 .66659 .02914 .67397 .02655 .67041 .02097 Metetra
.647 .721 .902 r
.67041 .02097 .67397 .02655 .68136 .02399 .67782 .01837 Metetra
.645 .719 .901 r
.67782 .01837 .68136 .02399 .68878 .02144 .68525 .01578 Metetra
.644 .717 .901 r
.68525 .01578 .68878 .02144 .69623 .0189 .69271 .0132 Metetra
.687 .719 .874 r
.03585 .26339 .04027 .26818 .04619 .26537 .04177 .26062 Metetra
.685 .721 .876 r
.04177 .26062 .04619 .26537 .05212 .26259 .0477 .25789 Metetra
.683 .723 .88 r
.0477 .25789 .05212 .26259 .05806 .25986 .05363 .25521 Metetra
.681 .725 .883 r
.05363 .25521 .05806 .25986 .06399 .25717 .05957 .25257 Metetra
.678 .728 .887 r
.05957 .25257 .06399 .25717 .06994 .25453 .06551 .24998 Metetra
.676 .73 .891 r
.06551 .24998 .06994 .25453 .07588 .25194 .07145 .24744 Metetra
.674 .732 .894 r
.07145 .24744 .07588 .25194 .08183 .24939 .07741 .24493 Metetra
.672 .734 .896 r
.07741 .24493 .08183 .24939 .08779 .24689 .08337 .24246 Metetra
.67 .735 .899 r
.08337 .24246 .08779 .24689 .09376 .24442 .08934 .24001 Metetra
.669 .737 .901 r
.08934 .24001 .09376 .24442 .09973 .24197 .09531 .23758 Metetra
.668 .738 .902 r
.09531 .23758 .09973 .24197 .10572 .23955 .1013 .23517 Metetra
.667 .738 .904 r
.1013 .23517 .10572 .23955 .11171 .23715 .1073 .23277 Metetra
.666 .739 .905 r
.1073 .23277 .11171 .23715 .11772 .23475 .11332 .23038 Metetra
.665 .74 .905 r
.11332 .23038 .11772 .23475 .12374 .23237 .11934 .228 Metetra
.665 .74 .906 r
.11934 .228 .12374 .23237 .12977 .22999 .12538 .22562 Metetra
.665 .74 .907 r
.12538 .22562 .12977 .22999 .13582 .22761 .13143 .22324 Metetra
.664 .741 .907 r
.13143 .22324 .13582 .22761 .14188 .22524 .1375 .22085 Metetra
.664 .741 .907 r
.1375 .22085 .14188 .22524 .14795 .22286 .14358 .21847 Metetra
.664 .741 .907 r
.14358 .21847 .14795 .22286 .15403 .22048 .14967 .21608 Metetra
.664 .741 .907 r
.14967 .21608 .15403 .22048 .16013 .2181 .15578 .21369 Metetra
.664 .741 .908 r
.15578 .21369 .16013 .2181 .16625 .21571 .1619 .2113 Metetra
.664 .741 .908 r
.1619 .2113 .16625 .21571 .17238 .21332 .16804 .2089 Metetra
.664 .741 .908 r
.16804 .2089 .17238 .21332 .17852 .21093 .17419 .20649 Metetra
.664 .741 .908 r
.17419 .20649 .17852 .21093 .18468 .20853 .18036 .20408 Metetra
.664 .741 .908 r
.18036 .20408 .18468 .20853 .19085 .20612 .18654 .20167 Metetra
.664 .741 .908 r
.18654 .20167 .19085 .20612 .19704 .20371 .19274 .19925 Metetra
.664 .741 .908 r
.19274 .19925 .19704 .20371 .20324 .20129 .19895 .19682 Metetra
.664 .741 .908 r
.19895 .19682 .20324 .20129 .20946 .19887 .20517 .19439 Metetra
.664 .741 .908 r
.20517 .19439 .20946 .19887 .21569 .19645 .21141 .19195 Metetra
.664 .741 .908 r
.21141 .19195 .21569 .19645 .22194 .19401 .21767 .18951 Metetra
.664 .741 .908 r
.21767 .18951 .22194 .19401 .2282 .19157 .22394 .18706 Metetra
.664 .741 .908 r
.22394 .18706 .2282 .19157 .23447 .18913 .23022 .1846 Metetra
.664 .741 .908 r
.23022 .1846 .23447 .18913 .24077 .18668 .23652 .18214 Metetra
.664 .741 .908 r
.23652 .18214 .24077 .18668 .24707 .18422 .24284 .17967 Metetra
.664 .741 .908 r
.24284 .17967 .24707 .18422 .2534 .18176 .24917 .1772 Metetra
.664 .741 .908 r
.24917 .1772 .2534 .18176 .25973 .17929 .25552 .17472 Metetra
.664 .741 .908 r
.25552 .17472 .25973 .17929 .26609 .17682 .26188 .17224 Metetra
.664 .741 .908 r
.26188 .17224 .26609 .17682 .27246 .17434 .26826 .16975 Metetra
.664 .741 .908 r
.26826 .16975 .27246 .17434 .27884 .17185 .27465 .16725 Metetra
.664 .741 .908 r
.27465 .16725 .27884 .17185 .28524 .16936 .28106 .16474 Metetra
.664 .741 .908 r
.28106 .16474 .28524 .16936 .29166 .16686 .28749 .16224 Metetra
.664 .741 .908 r
.28749 .16224 .29166 .16686 .29809 .16436 .29393 .15972 Metetra
.664 .741 .908 r
.29393 .15972 .29809 .16436 .30453 .16185 .30038 .1572 Metetra
.664 .741 .908 r
.30038 .1572 .30453 .16185 .311 .15933 .30686 .15467 Metetra
.664 .741 .908 r
.30686 .15467 .311 .15933 .31747 .15681 .31334 .15214 Metetra
.664 .741 .908 r
.31334 .15214 .31747 .15681 .32397 .15428 .31985 .1496 Metetra
.664 .741 .908 r
.31985 .1496 .32397 .15428 .33048 .15175 .32637 .14705 Metetra
.664 .741 .908 r
.32637 .14705 .33048 .15175 .33701 .1492 .3329 .1445 Metetra
.664 .741 .908 r
.3329 .1445 .33701 .1492 .34355 .14666 .33946 .14194 Metetra
.664 .741 .908 r
.33946 .14194 .34355 .14666 .35011 .1441 .34603 .13937 Metetra
.664 .741 .908 r
.34603 .13937 .35011 .1441 .35668 .14154 .35261 .1368 Metetra
.664 .741 .908 r
.35261 .1368 .35668 .14154 .36327 .13898 .35921 .13422 Metetra
.664 .741 .908 r
.35921 .13422 .36327 .13898 .36988 .1364 .36583 .13164 Metetra
.664 .741 .908 r
.36583 .13164 .36988 .1364 .3765 .13382 .37246 .12904 Metetra
.664 .741 .908 r
.37246 .12904 .3765 .13382 .38314 .13124 .37911 .12645 Metetra
.664 .741 .908 r
.37911 .12645 .38314 .13124 .3898 .12865 .38578 .12384 Metetra
.664 .741 .908 r
.38578 .12384 .3898 .12865 .39647 .12605 .39246 .12123 Metetra
.664 .741 .908 r
.39246 .12123 .39647 .12605 .40316 .12344 .39916 .11862 Metetra
.664 .741 .908 r
.39916 .11862 .40316 .12344 .40987 .12083 .40588 .11599 Metetra
.664 .741 .908 r
.40588 .11599 .40987 .12083 .41659 .11821 .41261 .11336 Metetra
.664 .741 .908 r
.41261 .11336 .41659 .11821 .42333 .11559 .41936 .11072 Metetra
.664 .741 .908 r
.41936 .11072 .42333 .11559 .43009 .11296 .42613 .10808 Metetra
.664 .741 .908 r
.42613 .10808 .43009 .11296 .43686 .11032 .43292 .10543 Metetra
.664 .741 .908 r
.43292 .10543 .43686 .11032 .44365 .10767 .43972 .10277 Metetra
.664 .741 .908 r
.43972 .10277 .44365 .10767 .45046 .10502 .44654 .10011 Metetra
.664 .741 .908 r
.44654 .10011 .45046 .10502 .45729 .10237 .45337 .09744 Metetra
.664 .741 .908 r
.45337 .09744 .45729 .10237 .46413 .0997 .46023 .09476 Metetra
.664 .741 .908 r
.46023 .09476 .46413 .0997 .47099 .09703 .4671 .09208 Metetra
.664 .741 .908 r
.4671 .09208 .47099 .09703 .47786 .09435 .47398 .08939 Metetra
.664 .741 .908 r
.47398 .08939 .47786 .09435 .48476 .09167 .48089 .08669 Metetra
.664 .741 .908 r
.48089 .08669 .48476 .09167 .49167 .08898 .48781 .08399 Metetra
.664 .741 .908 r
.48781 .08399 .49167 .08898 .4986 .08628 .49475 .08128 Metetra
.663 .741 .908 r
.49475 .08128 .4986 .08628 .50555 .08358 .50171 .07856 Metetra
.663 .741 .908 r
.50171 .07856 .50555 .08358 .51251 .08087 .50869 .07584 Metetra
.663 .741 .908 r
.50869 .07584 .51251 .08087 .51949 .07815 .51568 .07311 Metetra
.663 .741 .908 r
.51568 .07311 .51949 .07815 .52649 .07543 .52269 .07037 Metetra
.663 .741 .908 r
.52269 .07037 .52649 .07543 .53351 .0727 .52972 .06763 Metetra
.663 .741 .908 r
.52972 .06763 .53351 .0727 .54055 .06996 .53677 .06488 Metetra
.663 .741 .908 r
.53677 .06488 .54055 .06996 .5476 .06722 .54383 .06213 Metetra
.663 .741 .908 r
.54383 .06213 .5476 .06722 .55467 .06448 .55092 .05937 Metetra
.663 .741 .908 r
.55092 .05937 .55467 .06448 .56176 .06173 .55802 .0566 Metetra
.663 .74 .908 r
.55802 .0566 .56176 .06173 .56887 .05898 .56514 .05383 Metetra
.663 .74 .908 r
.56514 .05383 .56887 .05898 .576 .05622 .57228 .05106 Metetra
.662 .74 .908 r
.57228 .05106 .576 .05622 .58314 .05347 .57944 .04829 Metetra
.662 .739 .907 r
.57944 .04829 .58314 .05347 .59031 .05072 .58661 .04551 Metetra
.661 .739 .907 r
.58661 .04551 .59031 .05072 .59749 .04796 .59381 .04274 Metetra
.661 .738 .907 r
.59381 .04274 .59749 .04796 .60469 .04521 .60102 .03996 Metetra
.66 .737 .907 r
.60102 .03996 .60469 .04521 .61191 .04247 .60826 .03719 Metetra
.659 .737 .907 r
.60826 .03719 .61191 .04247 .61915 .03973 .61551 .03443 Metetra
.659 .735 .906 r
.61551 .03443 .61915 .03973 .62642 .037 .62278 .03167 Metetra
.657 .734 .906 r
.62278 .03167 .62642 .037 .6337 .03429 .63007 .02892 Metetra
.656 .733 .906 r
.63007 .02892 .6337 .03429 .641 .03159 .63739 .02619 Metetra
.655 .731 .905 r
.63739 .02619 .641 .03159 .64832 .02891 .64472 .02346 Metetra
.654 .729 .905 r
.64472 .02346 .64832 .02891 .65566 .02624 .65207 .02076 Metetra
.652 .727 .904 r
.65207 .02076 .65566 .02624 .66303 .0236 .65945 .01807 Metetra
.65 .725 .904 r
.65945 .01807 .66303 .0236 .67041 .02097 .66685 .0154 Metetra
.649 .723 .903 r
.66685 .0154 .67041 .02097 .67782 .01837 .67427 .01275 Metetra
.647 .721 .902 r
.67427 .01275 .67782 .01837 .68525 .01578 .68171 .01012 Metetra
.646 .719 .901 r
.68171 .01012 .68525 .01578 .69271 .0132 .68917 .0075 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-2)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[83]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00^oooool5o`00063ooooo002looooo`04o`000?oo
ooooooooo`00063ooooo002mooooo`03o`000?oooooooooo063ooooo002nooooo`03o`000?oooooo
oooo05oooooo002kooooo`05o`000?ooooooooooooooool00000H?ooool00;_ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000AOooool0
0;cooooo0ol0000=ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0A?ooool0
0<Gooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0A?ooool0
0<cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`14ooooo`00c?ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo04Cooooo003<ooooo`04o`000?oooooooooo
o`0000Sooooo0_l00016ooooo`00`Oooool2o`0000[ooooo0_l0000:ooooo`03o`000?oooooooooo
04Cooooo002nooooo`Go0000GOooool00;cooooo0_l00003ooooo`?o0000G?ooool00;Wooooo0ol0
0002ooooo`?o000000CoYKSVo`000?l0003o0000Foooool00;Oooooo0ol00002ooooo`?o000000?o
YKSVo`000?l000000ol0001Kooooo`00]?ooool3o`000003ooooool0003o000000;o000000GoY[WW
o`000?l0003o0000ojFhiP05o`0005[ooooo002aooooo`?o00000_ooool2o`000003ojNjiol0003o
Y[[W00?o000000?oYKSVo`000?l000000_l000001?nT]nKo0000o`000?l0001Iooooo`00S_ooool3
o`0001kooooo0_l000000ooooooo0000o`000002o`000003ojNkiol0003o000000;o000000OoY[WW
o`000?l0003o0000ojFgi_l0003oY;OV00;o000000?oY;KVo`000?l00000FOooool008oooooo00?o
0000ooooooooool06_ooool3o`000006ooooool0003o0000ojRkiol0003oYk_W0_l000000onW^^Oo
0000ojJji`03o`000003ojFhi_l0003o000000So0000F?ooool008oooooo00?o0000ooooooooool0
6?ooool2o`0000?ooooo00Co0000ojRliol0003oZ;_W0_l000000onW^nOo0000ojNji`02o`000007
ojJiiol0003o0000o`000?nU]nKo0000ojBgiP04o`000004ojBfiOl0003o0000o`0005Oooooo002?
ooooo`03o`000?oooooooooo01Gooooo0ol000000ooooooo0000o`000002o`000005ojRlj?l0003o
0000o`000?nW^nL01?l000001OnV^^Oo0000o`000?l0003oYKSV00Co000000?oY;KVo`000?l00000
0_l000000onT]^Go0000o`00001Gooooo`00Soooool00ol0003oooooooooo`0Cooooo`?o000000Ko
ooooo`000?l0003oZKcXo`000?nX_>P3o`000006ojRkiol0003o0000ojNkiol0003oYk[W0_l00000
1onV^NOo0000ojFhiol0003oY;OVo`000?nT]nH01?l000000onS]NGo0000o`000003o`0005Kooooo
002>ooooo`;o00004_ooool7o`000003ojVmj?l0003o000000;o000000GoZ;cXo`000?l0003o0000
ojNki`04o`000003ojJjiol0003o000000Ko000000?oY;KVo`000?nT]^D00_l000000onS]NGo0000
o`000002o`0005Kooooo002?ooooo`03o`000?oooooooooo00kooooo0_l00002ooooo`04o`000?nY
_NSo0000ojVmj0;o000000?oZKcXo`000?nX_>P00ol000001_nX^nOo0000o`000?nW^nOo0000ojNj
i`;o000000OoY[WWo`000?nU^>Ko0000ojBgi_l0003oY;KV00So000000?oY;KUo`000?ooool00_l0
001Dooooo`00WOooool3o`0000;ooooo0_l000001OnY_NSo0000o`000?l0003oZKgX00Co000000Go
Z;cXo`000?l0003o0000ojNki`04o`000003ojJiiol0003o000000Ko000000?oY;KVo`000?nS]ND0
0_l000000onS]NGo0000ojBei@05o`0005Cooooo002Kooooo`;o000000?oooooo`000?l000000_l0
00001OnY_NSo0000o`000?l0003oZKgX00;o000000?oZKcXo`000?nX_>P00_l000001onX_>Oo0000
o`000?l0003oYk_Wo`000?nW^^L00_l000001onV^NOo0000ojFhi_l0003oY;OVo`000?nT]^H01?l0
00000onS]NGo0000o`000003o`000004ojFfiOl0003o0000o`0005Cooooo002Hooooo`?o000000Ko
ooooo`000?l0003oZKgXo`000?nY_NP2o`000005ojVmj?l0003o0000o`000?nY_NP01?l000001OnX
_>So0000o`000?l0003oYk_W00Co000000?oY[WWo`000?l000000_l000001onU]nKo0000o`000?l0
003oXkKUo`000?nS]ND01?l000001OnS]NGo0000o`000?l0003oY[OV00?o0000Doooool009Kooooo
0_l000001Ooooooo0000o`000?l0003oZKgX00Co000000[oZKgXo`000?l0003oZKgXo`000?nY_NSo
0000ojVlj?l0003oZ;cX0_l000001onX_>Oo0000ojRkiol0003oYk_Wo`000?nW^^L00_l000000onV
^NOo0000ojFhiP03o`000003ojBfi_l0003o000000;o000000?oXkCUo`000?l000000ol000001onU
]^Go0000o`000?nW^NKo0000ooooool00000D_ooool009?ooooo0ol000002?oooooo0000o`000?nY
_NSo0000ojVmj?l0003oZKgX1?l000000onY_NSo0000o`000006o`000003ojRlj?l0003o000000;o
000000GoYk_Wo`000?l0003o0000ojJii`04o`000007ojFgi_l0003o0000o`000?nS]NGo0000oj>e
i@02o`000003oj>diOl0003oXkGU00?o000000?oY[OUo`000?l000000ol0001Booooo`00T?ooool3
o`000005ooooool0003o0000o`000?nY_NP01?l000001OnY_NSo0000ojVmj?l0003oZKgX00;o0000
00OoZKgXo`000?nY_NSo0000ojVlj?l0003oZ;cX00;o000000?oZ;cWo`000?nX^nL00ol000001_nW
^^Oo0000o`000?nV^NOo0000ojFhiP?o000000?oY;KVo`000?l000000_l000000onS]>Go0000o`00
0003o`000006ojFfiOl0003o0000ojNhi_l0003oZ;[V0ol0001Aooooo`00S_ooool2o`0000;ooooo
0ol000001_nY_NSo0000o`000?nY_NSo0000ojVmj0;o000000GoZKgXo`000?l0003o0000ojVmj004
o`000005ojVmj?l0003o0000o`000?nX_>P01?l000001OnW^nOo0000o`000?l0003oY[WW00Co0000
00OoY;OVo`000?l0003o0000oj>eiOl0003oXkCU00;o000000?oXkCUo`000?l000000ol000000onU
]nGo0000o`000002o`000004ojVliol0003o0000o`00053ooooo002;ooooo`Oo000000GoZKgXo`00
0?l0003o0000ojVmj004o`000005ojVmj?l0003o0000o`000?nY_NP00_l000000onY_NSo0000ojVm
j003o`000006ojRlj?l0003o0000ojRliol0003oZ;_W0ol000001_nW^^Oo0000o`000?nU^NOo0000
ojFhiP?o000000?oXkKVo`000?l000000_l000000onS]>Go0000o`000003o`000006ojBfiOl0003o
0000ojNhi_l0003oZ;[V0_l000000on[_NOo0000o`00001@ooooo`00ROooool2o`0000;ooooo00Co
0000ojVmj?l0003oZKgX0_l000001onY_NSo0000ojVmj?l0003oZKgXo`000?nY_NP00_l000001OnY
_NSo0000o`000?l0003oZKgX00Co000000GoZKgXo`000?l0003o0000ojRlj004o`000005ojNkiol0
003o0000o`000?nV^NL01?l000001onT]nKo0000o`000?l0003oXkGUo`000?nS]>D00_l000000onS
]>Go0000oj>di@03o`000003ojFgiOl0003o000000;o000000KoZKcWo`000?l0003o0000ooooool0
001?ooooo`00Q_ooool3o`0000;ooooo0_l000001OnY_NSo0000o`000?l0003oZKgX00So000000Co
ZKgXo`000?l0003oZKgX0ol000000onY_NSo0000ojVmj002o`000005ojVlj?l0003o0000o`000?nX
_>L01?l000001onW^^Oo0000o`000?l0003oYKSWo`000?nU^>H00_l000000onT]^Ko0000o`000003
o`000003oj:diOl0003o000000?o000000KoY;KUo`000?l0003oYkSVo`000?nX^^H2o`000006oj^m
iol0003o0000o`000?oooooo0000C_ooool006Cooooo0_l0000Nooooo`;o000000?oooooo`000?l0
00000_l000001OnY_NSo0000o`000?l0003oZKgX00;o000000GoZKgXo`000?nY_NSo0000ojVmj004
o`000005ojVmj?l0003o0000o`000?nY_NP01?l000001OnY_NSo0000o`000?l0003oZ;cX00;o0000
00?oZ;_Wo`000?nW^nL00ol000000onV^NOo0000o`000002o`000007ojBgi_l0003o0000o`000?nS
]>Go0000oj:di@02o`000003oj:ciOl0003oXkCU00?o000000?oYKOUo`000?l000000_l000001OnY
_>Oo0000o`000?l0003o[L3X00?o0000C_ooool006?ooooo00Co0000oooooooooooo00006_ooool4
o`000003ooooool0003oZKgX00Co000000GoZKgXo`000?l0003o0000ojVmj004o`000005ojVmj?l0
003oZKgXo`000?nY_NP00_l000001onY_NSo0000ojVmj?l0003oZKgXo`000?nY_NP00_l000001OnY
_>So0000o`000?l0003oZ;cW00Co000000OoYk[Wo`000?l0003o0000ojFhiol0003oYKSV00;o0000
00?oY;KVo`000?nS]ND00ol000000onR/nGo0000o`000003o`000006ojBeiOl0003o0000ojNhi_l0
003oZ;[V0_l000001On[_NOo0000o`000?l0003o[L7X00?o0000COooool006?ooooo00Co0000oooo
oooooooo00006?ooool2o`000003ooooool0003o000000;o000000GoZKgXo`000?nY_NSo0000ojVm
j003o`000004ojVmj?l0003o0000ojVmj0Co000000GoZKgXo`000?l0003o0000ojVmj004o`000005
ojVmj?l0003o0000o`000?nY_NP00_l000001onX_>So0000o`000?l0003oZ;_Wo`000?nW^nL00_l0
00000onV^^Oo0000o`000003o`000003ojBgi_l0003o000000?o000000KoX[CUo`000?l0003oX[?T
o`000?nS/n@8o`000005ojVliol0003o0000o`000?n]`>P00_l000001?n]`NSo0000o`000?l0000>
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0002[ooooo001Soooo
o`04o`000?ooooooooooo`0001Gooooo0ol000001?oooooo0000o`000?nY_NP4o`000005ojVmj?l0
003o0000o`000?nY_NP00ol000001_nY_NSo0000o`000?nY_NSo0000ojVmj0?o000000KoZKgXo`00
0?l0003oZKgXo`000?nY_NP6o`000005ojVlj?l0003o0000o`000?nX_>L01?l000001OnW^^Oo0000
o`000?l0003oYKSV00Co000000?oXkKVo`000?nS]ND00ol000000onR/nCo0000o`000002o`000007
oj>di?l0003o0000o`000?nW^>Ko0000ojRjiP02o`000005oj^niol0003o0000o`000?n]`NP01Ol0
000=ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo02Oooooo001Sooooo`04o`000?ooooooooooo`0001?ooooo0_l000001Ooo
oooo0000o`000?l0003oZKgX00;o000000?oZKgXo`000?nY_NP00ol000002?nY_NSo0000o`000?nY
_NSo0000ojVmj?l0003oZKgX1?l000001OnY_NSo0000o`000?l0003oZKgX00Co000000GoZKgXo`00
0?nY_NSo0000ojVmj002o`000007ojRlj?l0003oZ;cXo`000?nX^nOo0000ojNki`02o`000007ojJj
iol0003oY[WWo`000?nU]nKo0000ojBgiP08o`000003oj:ci?l0003oX[?T00?o000000?oYKKUo`00
0?l000000_l000001OnZ_>Oo0000o`000?l0003o[L7X00;o000000Ko[L7Xo`000?l0003o0000oooo
ool00005ooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool09oooool006?ooooo00Co0000oooooooooooo00004?ooool3o`00
0004ooooool0003o0000ojVmj0?o000000?oZKgXo`000?l000000_l000001OnY_NSo0000o`000?l0
003oZKgX00Co000000GoZKgXo`000?nY_NSo0000ojVmj002o`000005ojVmj?l0003oZKgXo`000?nY
_NP01?l000001OnY_NSo0000o`000?l0003oZKcX00Co000000GoZ;cWo`000?l0003o0000ojNji`08
o`000007oj>ei_l0003oXkCUo`000?nR/nGo0000oj:ci004o`000003oj>ci?l0003o000000?o0000
00CoZ;[Vo`000?l0003oZkkW0ol000001?n]`NSo0000o`000?n]`NP3o`000003ooooool0003ooooo
00[ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo02Oooooo001Tooooo`;o00003oooool2o`000005ooooool0003o0000o`000?nY_NP00_l0
00001onY_NSo0000ojVmj?l0003oZKgXo`000?nY_NP00_l000001OnY_NSo0000ojVmj?l0003oZKgX
00Co000000GoZKgXo`000?l0003o0000ojVmj006o`000003ojVmj?l0003oZKgX00?o000000KoZKgX
o`000?l0003oZ;cXo`000?nX_>P3o`00000:ojNkiol0003o0000ojJjiol0003oY[WWo`000?nT]nKo
0000ojBfiPCo000000OoX[?Uo`000?l0003o0000oj:bi?l0003oX[?T00?o000000?oYKKUo`000?l0
00000_l000001OnZ_>Oo0000o`000?l0003o[L7X00;o000000Go[L7Xo`000?l0003o0000ojboj003
o`0000_ooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co0000
:_ooool007;ooooo0ol000001?oooooo0000o`000?nY_NP3o`000003ojVmj?l0003o000000;o0000
00GoZKgXo`000?l0003o0000ojVmj006o`000003ojVmj?l0003oZKgX00?o000000CoZKgXo`000?l0
003oZKgX0ol000000onY_NSo0000o`000002o`000005ojVmj?l0003o0000o`000?nY_>P01?l00000
1OnX_>Oo0000o`000?l0003oYk[W00Co000000GoYKSVo`000?l0003o0000oj>ei@05o`000003oj6b
i?l0003o000000;o000000OoXk?To`000?l0003o0000ojNhiOl0003oZ;[V00;o000000GoZkkWo`00
0?l0003o0000ojk1j002o`000005ojg1j?l0003o0000o`000?n[_NL00ol0000:ooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0000]ooooo`00Koooool3o`000005
ooooool0003o0000o`000?nY_NP00_l000001onY_NSo0000ojVmj?l0003oZKgXo`000?nY_NP00_l0
00001OnY_NSo0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l000000_l000001OnY_NSo0000
o`000?l0003oZKgX00;o000000OoZKgXo`000?nY_NSo0000ojVmj?l0003oZKgX00;o000000GoZKgX
o`000?l0003o0000ojRlj004o`000005ojRkiol0003o0000o`000?nV^^L01Ol000001_nT]^Ko0000
o`000?nR]>Go0000oj:ci@?o000000?oXK;To`000?nR/^@00ol000000onU]^Go0000o`000002o`00
0005ojZliol0003o0000o`000?n]`NP00_l000001On^`^So0000o`000?l0003oZkkX00;o000000Co
Z[cWo`000?l0003o00002_ooool2o`0000[ooooo0_l00002ooooo`Go0000:Oooool006gooooo0_l0
0002ooooo`;o000000GoZKgXo`000?l0003o0000ojVmj004o`000005ojVmj?l0003o0000o`000?nY
_NP00ol000002_nY_NSo0000o`000?nY_NSo0000ojVmj?l0003oZKgXo`000?nY_NP2o`000005ojVm
j?l0003o0000o`000?nY_NP01?l000001OnY_NSo0000o`000?l0003oZKgX00;o000000OoZKgXo`00
0?l0003o0000ojRlj?l0003oZ;cW00?o000000KoYk[Wo`000?l0003oY[WWo`000?nU^>H3o`000003
oj>eiOl0003o000000?o000000?oXK;To`000?l000000_l000001OnR/nCo0000o`000?l0003oYkSU
00Co000000Go[;kWo`000?l0003o0000ojk2j002o`000005ojg1j?l0003o0000o`000?n[_NL01Ol0
0018ooooo`00J_ooool3o`000005ooooool0003o0000o`000?nY_NP00ol000001_nY_NSo0000o`00
0?nY_NSo0000ojVmj0;o000000GoZKgXo`000?l0003o0000ojVmj003o`000003ojVmj?l0003o0000
00;o000000GoZKgXo`000?l0003o0000ojVmj002o`000007ojVmj?l0003oZKgXo`000?nY_NSo0000
ojVmj002o`000005ojVmj?l0003o0000o`000?nY_NP00ol000000onX_>So0000o`000002o`000005
ojRkiol0003o0000o`000?nV^^L01?l000001onT]nKo0000o`000?l0003oX[CUo`000?nR/nD00ol0
00000onQ/NCo0000oj:bi002o`000003oj>di?l0003o000000?o000000GoZ[cWo`000?l0003o0000
ojk1j002o`000005ojk2j?l0003o0000o`000?n[_^L00_l000000onZ_>Oo0000ojVli`03o`0004Oo
oooo001Xooooo`?o000000Coooooo`000?l0003oZKgX0ol000001OnY_NSo0000o`000?l0003oZKgX
00Co000000GoZKgXo`000?l0003o0000ojVmj002o`000005ojVmj?l0003oZKgXo`000?nY_NP01?l0
00001OnY_NSo0000o`000?l0003oZKgX00So000000GoZKgXo`000?l0003o0000ojVmj002o`000007
ojVmj?l0003oZKcXo`000?nX_>So0000ojRli`02o`000007ojNkiol0003o0000o`000?nV^NOo0000
ojFhiP03o`000003oj>eiOl0003o000000;o000000?oXK;To`000?l000000ol000001OnR/^Co0000
o`000?l0003oYkSU00Co000000Go[;kWo`000?l0003o0000ojk2j002o`000005ojg1j?l0003o0000
o`000?nZ_NL01?l000000onY^nKo0000o`000017ooooo`00IOooool3o`000005ooooool0003o0000
o`000?nY_NP00ol000001_nY_NSo0000o`000?nY_NSo0000ojVmj0;o000000GoZKgXo`000?l0003o
0000ojVmj003o`000003ojVmj?l0003o000000;o000000GoZKgXo`000?nY_NSo0000ojVmj003o`00
0004ojVmj?l0003o0000ojVmj0?o000000?oZKgXo`000?l000000_l000001OnY_NSo0000o`000?l0
003oZKgX00Co000000GoZ;cXo`000?l0003o0000ojRki`03o`000003ojJjiol0003o000000;o0000
00OoY;OVo`000?l0003o0000oj:ciOl0003oXK;T00?o000000?oXK7So`000?l000000_l000001OnS
/nCo0000o`000?l0003oZ;[V00Co000000Go[L7Xo`000?l0003o0000ojk2j003o`000006oj^niol0
003o0000ojZliol0003oZK_V1Ol00016ooooo`00Hoooool6o`000005ojVmj?l0003o0000o`000?nY
_NP00ol000000onY_NSo0000o`000002o`000005ojVmj?l0003o0000o`000?nY_NP00_l000001OnY
_NSo0000ojVmj?l0003oZKgX00Co000000GoZKgXo`000?l0003o0000ojVmj003o`00000:ojVmj?l0
003o0000ojVmj?l0003oZKgXo`000?nY_NSo0000ojVmj0;o000000GoZKgXo`000?l0003o0000ojVm
j008o`000005ojNkiol0003o0000o`000?nV^NL01Ol000000onR]>Go0000o`000002o`000007oj6a
i?l0003o0000o`000?nQ/N?o0000oj:bi003o`000003ojNhiOl0003o000000;o000000Go[;oWo`00
0?l0003o0000ojk2j002o`000005ojg1j?l0003o0000o`000?nZ_NL01?l000001_nY^nKo0000ojZl
iol0003oooooo`0004Gooooo001Pooooo`Go000000?oZKgXo`000?nY_NP00ol000001?nY_NSo0000
o`000?nY_NP3o`000003ojVmj?l0003o000000;o000000GoZKgXo`000?l0003o0000ojVmj004o`00
0005ojVmj?l0003oZKgXo`000?nY_NP00ol000001?nY_NSo0000o`000?nY_NP3o`000003ojVmj?l0
003o000000;o000000GoZKgXo`000?l0003o0000ojVmj003o`00000:ojVmj?l0003o0000ojVlj?l0
003oZ;cXo`000?nX_>Oo0000ojRki`;o000000OoYk[Wo`000?l0003o0000ojFhi_l0003oY;OV00?o
000000?oX[?Uo`000?l000000_l000000onP/>?o0000o`000003o`000007oj>ci?l0003oYKGTo`00
0?nY^^Ko0000oj^li`02o`000005ojk1j?l0003o0000o`000?n^`^P00_l000001On/_nSo0000o`00
0?l0003oZK_V00[o0000A?ooool005kooooo1_l000001OnY_NSo0000o`000?l0003oZKgX00?o0000
00[oZKgXo`000?l0003oZKgXo`000?nY_NSo0000ojVmj?l0003oZKgX0_l000001OnY_NSo0000o`00
0?l0003oZKgX00Co000000GoZKgXo`000?l0003o0000ojVmj003o`00000:ojVmj?l0003o0000ojVm
j?l0003oZKgXo`000?nY_NSo0000ojVmj0;o000000GoZKgXo`000?l0003o0000ojVmj003o`000003
ojVmj?l0003o000000;o000000GoZ;cXo`000?l0003o0000ojNki`03o`000003ojFiiol0003o0000
00;o000000OoXkGVo`000?l0003o0000oj6bi?l0003oX;7T00?o000000?oXK3So`000?nR/N<03ol0
00001On]`NSo0000o`000?l0003oZ[cW00;o000000OoZK_Vo`000?nY^nKo0000ojZliol0003oZkgW
00?o0000A?ooool003_ooooo0ol0000Mooooo`?o000000Goooooo`000?l0003o0000ojVmj002o`00
0005ojVmj?l0003o0000o`000?nY_NP01?l000001OnY_NSo0000o`000?l0003oZKgX00?o000000[o
ZKgXo`000?l0003oZKgXo`000?nY_NSo0000ojVmj?l0003oZKgX0_l000001OnY_NSo0000o`000?l0
003oZKgX00?o000000?oZKgXo`000?l000000_l000001OnY_NSo0000o`000?l0003oZKgX00?o0000
00SoZKgXo`000?l0003oZKgXo`000?nY_NSo0000ojVlj0Co000000GoZ;cWo`000?l0003o0000ojNj
i`03o`000003ojFhi_l0003oY;KV00?o000000?oXK?Uo`000?l000000_l000000onP/>?o0000o`00
0003o`000005oj>ci?l0003oYKGTo`000?nY^^H01_l000000on_`nSo0000ojk2j002o`000005ojbo
iol0003o0000o`000?nY^nH02?l000001?n[_^Oo0000o`000?l00013ooooo`00??ooool00ol0003o
ooooooooo`0Jooooo`;o000000Goooooo`000?l0003o0000ojVmj003o`00000:ojVmj?l0003o0000
ojVmj?l0003oZKgXo`000?nY_NSo0000ojVmj0;o000000GoZKgXo`000?l0003o0000ojVmj003o`00
0003ojVmj?l0003o000000;o000000GoZKgXo`000?l0003o0000ojVmj003o`000004ojVmj?l0003o
0000ojVmj0?o000000?oZKgXo`000?l000001_l000001OnY_NSo0000o`000?l0003oZKgX00Ko0000
00?oZ;cXo`000?nX_>P00ol000001?nW^nOo0000o`000?nV^NL5o`000007oj>eiOl0003o0000o`00
0?nP/NCo0000oj2`i003o`000003oj2`hol0003oXK7S00Ko000000?oZkgVo`000?n]_nL01_l00000
1On]`NSo0000o`000?l0003oZ[cV00;o000000GoZK_Vo`000?nY^nKo0000oj^mi`07o`0004?ooooo
000dooooo`Go00000oooool00ol0003oooooooooo`0Gooooo`?o000000Coooooo`000?l0003oZKgX
0ol000001OnY_NSo0000o`000?l0003oZKgX00Co000000GoZKgXo`000?l0003o0000ojVmj003o`00
0008ojVmj?l0003o0000ojVmj?l0003oZKgXo`000?nY_NP8o`000005ojVmj?l0003o0000o`000?nY
_NP00ol000002_nY_NSo0000o`000?nY_NSo0000ojVmj?l0003oZKgXo`000?nY_NP2o`000005ojVm
j?l0003o0000o`000?nY_NP00ol000000onY_>So0000o`000002o`000005ojRliol0003o0000o`00
0?nW^^L00ol000000onU]nKo0000o`000002o`000003oj:ciOl0003o000000?o000000?oWjoSo`00
0?nO[n<00ol000001OnS/^?o0000o`000?l0003oZK[V00Co000000?o[/;Xo`000?n_`nP01?l00000
1On/_nOo0000o`000?l0003oZK_V00Ko000000GoZkgWo`000?n[_^Oo0000oj^ni`03o`0004;ooooo
000looooo`03o`000?oooooooooo01Gooooo0_l000001Ooooooo0000o`000?l0003oZKgX00?o0000
00SoZKgXo`000?l0003oZKgXo`000?nY_NSo0000ojVmj0Co000000GoZKgXo`000?l0003o0000ojVm
j003o`000003ojVmj?l0003o000000;o000000WoZKgXo`000?nY_NSo0000ojVmj?l0003oZKgXo`00
0?nY_NP00_l000001OnY_NSo0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l000000_l00000
1OnY_NSo0000o`000?l0003oZKgX00?o000000SoZKgXo`000?l0003oZKgXo`000?nY_NSo0000ojRl
j0Co000000GoZ;_Wo`000?l0003o0000ojJii`03o`000003ojBfi_l0003oXkGU00?o000000?oX;7T
o`000?nO/><01Ol000002_nQ/>?o0000o`000?nT]>Co0000ojNgiOl0003oZkgVo`000?n]`>L4o`00
0003ojk2j?l0003o[L3X00?o000000CoZ[_Vo`000?l0003oZK_V0ol000000on[_NOo0000o`000004
o`000004oj^niol0003oooooo`00047ooooo000looooo`03o`000?oooooooooo01;ooooo1_l00000
1OnY_NSo0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l000000_l000001OnY_NSo0000ojVm
j?l0003oZKgX00?o000000CoZKgXo`000?l0003oZKgX0ol000000onY_NSo0000o`000002o`000005
ojVmj?l0003o0000o`000?nY_NP00ol000001OnY_NSo0000o`000?l0003oZKgX00;o000000GoZKgX
o`000?l0003o0000ojVmj004o`000005ojVmj?l0003o0000o`000?nY_NP00ol000000onY_NSo0000
o`000002o`000005ojVlj?l0003oZ;cXo`000?nX_>L00ol000001_nW^^Oo0000o`000?nU^>Oo0000
ojBgiP?o000000?oX[?Uo`000?nQ/^@00ol000000onO[n?o0000o`000003o`000003oj:bhol0003o
000000Ko000000?o[l;Xo`000?l000001?l000001On/_^Oo0000o`000?l0003oZK_V00;o000000Go
Z[_Vo`000?l0003o0000oj^ni`03o`000003ojbniol0003o000000Co0000@?ooool003_ooooo0_l0
000Aooooo`?o000000Goooooo`000?l0003o0000ojVmj003o`000004ojVmj?l0003o0000ojVmj0?o
000000?oZKgXo`000?l000000_l000001OnY_NSo0000o`000?l0003oZKgX00?o000000[oZKgXo`00
0?l0003oZKgXo`000?nY_NSo0000ojVmj?l0003oZKgX1_l000001OnY_NSo0000o`000?l0003oZKgX
00?o000000[oZKgXo`000?l0003oZKgXo`000?nY_NSo0000ojVmj?l0003oZKgX0_l000001OnY_NSo
0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l000001_l000001OnX^nOo0000o`000?l0003o
Y[WW00ko000000?oWjkRo`000?nO[n800ol000001OnT]>Co0000ojNgiOl0003o[;gV00Co000000?o
/<?Xo`000?n_`^P02?l000001OnY^^Ko0000o`000?l0003oZkgW00;o000000Oo[;kWo`000?l0003o
0000oj^niol0003oZkgW00?o0000@?ooool003cooooo00?o0000ooooooooool03Oooool2o`000005
ooooool0003o0000o`000?nY_NP00ol000001OnY_NSo0000o`000?l0003oZKgX00;o000000OoZKgX
o`000?nY_NSo0000ojVmj?l0003oZKgX00;o000000GoZKgXo`000?l0003o0000ojVmj003o`000003
ojVmj?l0003o000000;o000000WoZKgXo`000?l0003o0000ojVmj?l0003oZKgXo`000?nY_NP00_l0
00001OnY_NSo0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l000000_l000001OnY_NSo0000
o`000?l0003oZKgX00?o000000SoZKgXo`000?l0003oZKgXo`000?nY_NSo0000ojVmj0?o000000?o
Z;cXo`000?l000000_l000002onW^nOo0000o`000?l0003oYKSVo`000?nT]nKo0000oj:diOl0003o
XK?U00?o000000?oWjoSo`000?nN[^801Ol000000onR/N?o0000o`000002o`000005ojVjiOl0003o
[/3Wo`000?n_`^P01?l000001on]`>Oo0000ojbniol0003oZK_Vo`000?nY^^H00_l000001OnZ^nKo
0000o`000?l0003o[;kW00?o000000?o[;kWo`000?l000000_l000001?n[_NOo0000ooooool0000o
ooooo`00BOooool3o`000005ooooool0003o0000o`000?nY_NP00_l000001OnY_NSo0000o`000?l0
003oZKgX00Co000000GoZKgXo`000?l0003o0000ojVmj003o`000005ojVmj?l0003o0000o`000?nY
_NP00_l000001OnY_NSo0000o`000?l0003oZKgX00Co000000GoZKgXo`000?l0003o0000ojVmj003
o`000005ojVmj?l0003o0000o`000?nY_NP00_l000001OnY_NSo0000ojVmj?l0003oZKgX00Co0000
00GoZKgXo`000?l0003o0000ojVmj003o`000003ojVmj?l0003o000000Co000000OoZKcXo`000?nX
_>So0000ojRliol0003oZ;_W00?o000000?oY[WWo`000?l000000_l000001onS]^Ko0000o`000?l0
003oX;7To`000?nO/><00ol000000onN[N;o0000oin^hP03o`000003ojBchol0003o000000Ko0000
00?o/<?Xo`000?l000001?l000001OnZ_>Ko0000o`000?l0003oZK[V00?o000000CoZkgWo`000?l0
003o[;kW0ol000000on[_NOo0000o`000005o`0003oooooo0017ooooo`;o000000Goooooo`000?l0
003o0000ojVmj003o`000008ojVmj?l0003o0000ojVmj?l0003oZKgXo`000?nY_NP4o`000005ojVm
j?l0003o0000o`000?nY_NP00ol000001OnY_NSo0000o`000?l0003oZKgX00;o000000OoZKgXo`00
0?nY_NSo0000ojVmj?l0003oZKgX00;o000000GoZKgXo`000?l0003o0000ojVmj003o`000005ojVm
j?l0003o0000o`000?nY_NP01?l000001OnY_NSo0000ojVmj?l0003oZKgX00;o000000GoZKgXo`00
0?l0003o0000ojVmj003o`000005ojVmj?l0003o0000o`000?nY_NP01?l000001OnX_>So0000o`00
0?l0003oYk_W00?o000000?oYKSVo`000?l000000ol000000onQ/^Co0000o`000003o`000003oij]
h_l0003o000000?o000000SoX[7So`000?l0003oYkOTo`000?nZ^^Go0000ojk1i`Ko000000?o[KoW
o`000?l000001_l000001OnZ^nKo0000o`000?l0003o[;kW00?o000000So[;kWo`000?l0003oZkgW
o`000?n[_NOo0000oj^mi`?o0000?_ooool004Cooooo1_l000001OnY_NSo0000o`000?l0003oZKgX
00?o000000?oZKgXo`000?l000000_l000001OnY_NSo0000ojVmj?l0003oZKgX00?o000000CoZKgX
o`000?l0003oZKgX0ol000001OnY_NSo0000o`000?l0003oZKgX00Co000000GoZKgXo`000?l0003o
0000ojVmj003o`000004ojVmj?l0003o0000ojVmj0?o000000GoZKgXo`000?l0003o0000ojVmj004
o`000005ojVmj?l0003o0000o`000?nY_NP00ol000001OnY_NSo0000o`000?l0003oZKgX00;o0000
00GoZKgXo`000?l0003o0000ojVlj004o`000005ojRliol0003o0000o`000?nW^^L00ol000000onT
]nKo0000oj>fiP03o`000003oj2`i?l0003o000000?o000000?oWZgRo`000?nN[N800ol000000onT
/n?o0000o`000004o`000005ok33j?l0003o0000o`000?n_`^P00_l000001on[_NKo0000ojZki_l0
003oZK[Uo`000?nY^^D00ol000001?n/_^Oo0000o`000?n/_^L3o`000003oj^miol0003o000000Co
000000CoZkkWo`000?oooooo0000?Oooool004;ooooo0_l000001Ooooooo0000o`000?l0003oZKgX
00;o000000GoZKgXo`000?nY_NSo0000ojVmj004o`000005ojVmj?l0003o0000o`000?nY_NP00ol0
00001OnY_NSo0000o`000?l0003oZKgX00;o000000GoZKgXo`000?nY_NSo0000ojVmj003o`000003
ojVmj?l0003o000000;o000000GoZKgXo`000?l0003o0000ojVmj003o`000005ojVmj?l0003o0000
o`000?nY_NP00_l000001OnY_NSo0000ojVmj?l0003oZKgX00Co000000GoZKgXo`000?l0003o0000
ojVmj003o`000005ojVmj?l0003o0000o`000?nY_NP00_l000001onY_NSo0000ojVmj?l0003oZ;cX
o`000?nX_>P00ol000001OnW^nOo0000o`000?l0003oYKSV00Co000000OoX[CUo`000?l0003o0000
oij^hol0003oWZgR00Go000000WoWjkRo`000?l0003o0000ojNgi?l0003oZ[[Uo`000?n_`NL00_l0
00000onaa>So0000ok33j00:o`000005ojZki_l0003o0000o`000?n/_^L00_l000001On/_^Oo0000
o`000?l0003oZkgW00?o000000?oZkgWo`000?l000000ol0000mooooo`00?oooool6o`000005ojVm
j?l0003o0000o`000?nY_NP01?l000001OnY_NSo0000ojVmj?l0003oZKgX00;o000000GoZKgXo`00
0?l0003o0000ojVmj003o`000005ojVmj?l0003o0000o`000?nY_NP01?l000002OnY_NSo0000ojVm
j?l0003oZKgXo`000?nY_NSo0000ojVmj002o`000005ojVmj?l0003o0000o`000?nY_NP00ol00000
1OnY_NSo0000o`000?l0003oZKgX00Co000000GoZKgXo`000?nY_NSo0000ojVmj006o`000005ojVm
j?l0003o0000o`000?nY_NP00ol000000onY_NSo0000o`000006o`000005ojRliol0003o0000o`00
0?nW^^L00ol000000onT]nKo0000o`000003o`000003oin`hol0003o000000?o000000?oWJcQo`00
0?l000000ol000000onT/n?o0000o`000002o`000003ojfni_l0003o/LCX00Ko000000GoZkcVo`00
0?nZ^^Go0000ojVii@08o`000005ojbniol0003o0000o`000?n[_NL00_l000001On[_NOo0000o`00
0?l0003o[;kW00?o000000?oooooo`000?ooool0>oooool003gooooo0_l000001?oooooo0000o`00
0?nY_NP3o`000003ojVmj?l0003o000000;o000000GoZKgXo`000?l0003o0000ojVmj003o`000005
ojVmj?l0003o0000o`000?nY_NP00ol000001?nY_NSo0000o`000?nY_NP3o`000003ojVmj?l0003o
000000;o000000GoZKgXo`000?l0003o0000ojVmj003o`000005ojVmj?l0003o0000o`000?nY_NP0
0_l000001OnY_NSo0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l000000_l000002OnY_NSo
0000o`000?l0003oZKgXo`000?nY_NSo0000ojVmj003o`000004ojVmj?l0003o0000ojVmj0?o0000
00GoZKgXo`000?l0003o0000ojRlj004o`000005ojRkiol0003o0000o`000?nV^NL00ol000000onS
]NGo0000oj:ci@03o`000003oij^hol0003oWJgR00?o000000?oWJcQo`000?nO[N400ol000000onW
]nCo0000o`000004o`000005ok74j?l0003o0000o`000?n]_^L01_l000001OnZ^^Go0000oj^li_l0
003o[;kW00Co000000Go[;kWo`000?l0003o0000oj^miP03o`000004ojbniol0003o0000ojbni`?o
000000?oooooo`000?ooool0>_ooool003[ooooo1ol000001onY_NSo0000ojVmj?l0003oZKgXo`00
0?nY_NP01?l000001OnY_NSo0000o`000?l0003oZKgX00?o000000GoZKgXo`000?l0003o0000ojVm
j003o`000008ojVmj?l0003o0000ojVmj?l0003oZKgXo`000?nY_NP4o`000005ojVmj?l0003o0000
o`000?nY_NP00ol000001OnY_NSo0000o`000?l0003oZKgX00?o000000CoZKgXo`000?l0003oZKgX
0ol000000onY_NSo0000o`000002o`000005ojVmj?l0003o0000o`000?nY_NP00ol000001OnY_NSo
0000o`000?l0003oZKgX00;o000000GoZKgXo`000?l0003o0000ojVmj003o`000003ojRlj?l0003o
000000;o000000GoYk_Wo`000?l0003o0000ojFhiP05o`000003oj2ai?l0003o000000?o000000?o
W:_Qo`000?l000000ol000002OnQ[n7o0000o`000?l0003oZk_Uo`000?n^_nKo0000ok74j002o`00
0003ok33j?l0003o000000Go000000?oZKWUo`000?l000000_l000001On/_NKo0000ojfoiol0003o
[;kW00Ko000000GoZkgWo`000?l0003o0000ojbni`03o`000004ojbniol0003o0000o`0003_ooooo
000hooooo`Go000000?oZKgXo`000?l000000_l000002OnY_NSo0000o`000?l0003oZKgXo`000?nY
_NSo0000ojVmj003o`000004ojVmj?l0003o0000ojVmj0?o000000GoZKgXo`000?l0003o0000ojVm
j004o`000009ojVmj?l0003o0000o`000?nY_NSo0000ojVmj?l0003oZKgX00;o000000GoZKgXo`00
0?l0003o0000ojVmj003o`000005ojVmj?l0003o0000o`000?nY_NP00ol000002_nY_NSo0000o`00
0?nY_NSo0000ojVmj?l0003oZKgXo`000?nY_NP6o`000005ojVmj?l0003o0000o`000?nY_NP00ol0
00001OnY_NSo0000o`000?l0003oZKgX00;o000000OoZKgXo`000?nX_>So0000ojRliol0003oZ;_W
00?o000000GoY[WWo`000?l0003o0000oj>ei@05o`000003oif]h_l0003o000000?o000000?oWJ_P
o`000?nO[>400ol000000onW]nCo0000o`000004o`000005ok75j?l0003o0000o`000?n]_^H00_l0
00001onY^NGo0000ojViiOl0003oZ[[Uo`000?n[_>H01_l000001On/_^Oo0000ojbmi_l0003oZkgV
00Ko000000Go[;kWo`000?l0003o0000ojbni`03o`0003[ooooo000Dooooo`Go00007?ooool3o`00
0007ooooool0003oZKgXo`000?nY_NSo0000ojVmj004o`000005ojVmj?l0003o0000o`000?nY_NP0
0ol000001OnY_NSo0000o`000?l0003oZKgX00;o000000GoZKgXo`000?nY_NSo0000ojVmj003o`00
0003ojVmj?l0003o000000;o000000GoZKgXo`000?l0003o0000ojVmj003o`000005ojVmj?l0003o
0000o`000?nY_NP00ol000001?nY_NSo0000o`000?nY_NP3o`000005ojVmj?l0003o0000o`000?nY
_NP01?l000002OnY_NSo0000o`000?l0003oZKgXo`000?nY_NSo0000ojVmj002o`000005ojVmj?l0
003o0000o`000?nY_NP00ol000001OnY_NSo0000o`000?l0003oZKgX00So000000GoYk_Wo`000?l0
003o0000ojFhiP03o`000003oj6biOl0003oX;7T00?o000000?oW:_Qo`000?nLZ^401Ol000001OnQ
[^7o0000o`000?l0003oZk_U00?o000000Co//GXo`000?l0003o/<?X0ol000000onZ^nGo0000o`00
0006o`000003ojbni_l0003o[KoW00So000000Go[;gVo`000?n/_^Oo0000ojbni`06o`000004ojbn
iol0003o0000o`0000Sooooo0_l0000_ooooo`005Oooool01?l0003oooooooooool0000Jooooo`;o
000000Goooooo`000?l0003o0000ojVmj003o`000005ojVmj?l0003o0000o`000?nY_NP00_l00000
1OnY_NSo0000o`000?l0003oZKgX00?o000000GoZKgXo`000?l0003o0000ojVmj004o`000007ojVm
j?l0003oZKgXo`000?nY_NSo0000ojVmj004o`000005ojVmj?l0003o0000o`000?nY_NP00ol00000
1OnY_NSo0000o`000?l0003oZKgX00?o000000SoZKgXo`000?l0003oZKgXo`000?nY_NSo0000ojVm
j0?o000000?oZKgXo`000?l000000_l000001OnY_NSo0000o`000?l0003oZKgX00?o000000GoZKgX
o`000?l0003o0000ojVmj002o`000005ojVmj?l0003o0000o`000?nY_NP00ol000001OnY_>So0000
o`000?l0003oZ;cW00Co000000GoY[[Wo`000?l0003o0000ojBfiP05o`000003oij^hol0003o0000
00?o000000?oVjWOo`000?l000000ol000001OnT/^;o0000o`000?l0003o[l3V00?o000000Co//GX
o`000?l0003o[/3W0ol000001OnY^>Co0000o`000?l0003oZk_U00Ko000000Go[KkWo`000?n/_^Ko
0000ojbmiP08o`000005ojbniol0003o[;kWo`000?n/_^L01Ol00007ooooo`04o`000?oooooooooo
o`0002kooooo000>ooooo`Go00000oooool00ol0003oooooooooo`0Gooooo`Ko000000GoZKgXo`00
0?l0003o0000ojVmj003o`000005ojVmj?l0003o0000o`000?nY_NP00ol000001?nY_NSo0000o`00
0?nY_NP3o`000005ojVmj?l0003o0000o`000?nY_NP01?l000002OnY_NSo0000o`000?l0003oZKgX
o`000?nY_NSo0000ojVmj002o`000005ojVmj?l0003o0000o`000?nY_NP00ol000001OnY_NSo0000
o`000?l0003oZKgX00?o000000?oZKgXo`000?l000000_l000001onY_NSo0000ojVmj?l0003oZKgX
o`000?nY_NP01?l000001OnY_NSo0000o`000?l0003oZKgX00?o000000GoZKgXo`000?l0003o0000
ojVmj003o`000008ojVmj?l0003o0000ojVmj?l0003oZKgXo`000?nX_>P3o`000003ojRkiol0003o
000000?o000000GoYKSVo`000?l0003o0000oj6bi005o`000003oi^ZhOl0003oVjWP00?o000000?o
WZ[Oo`000?nQ[^400ol000001?n/^nGo0000o`000?nba>L3o`000005ok73j?l0003o0000o`000?nZ
^^D01_l000001On/_NKo0000o`000?l0003o[KoW00Ko000000Go[;gVo`000?n/_NKo0000ojbni`08
o`000003ojbniol0003o[;kW00?o00001_ooool01?l0003oooooooooool0000^ooooo`005oooool0
0ol0003oooooooooo`0Cooooo`?o000000Goooooo`000?l0003o0000ojZmj002o`000005ojZmj?l0
003o0000o`000?nY_NP00ol000001OnY_NSo0000o`000?l0003oZKgX00?o000000SoZKgXo`000?l0
003oZKgXo`000?nY_NSo0000ojVmj0?o000000?oZKgXo`000?l000000_l000001OnY_NSo0000o`00
0?l0003oZKgX00?o000000GoZKgXo`000?l0003o0000ojVmj003o`000004ojVmj?l0003o0000ojVm
j0?o000000GoZKgXo`000?l0003o0000ojVmj004o`000009ojVmj?l0003o0000o`000?nY_NSo0000
ojVmj?l0003oZKgX00Ko000000GoZKgXo`000?l0003o0000ojVmj003o`000005ojVmj?l0003o0000
o`000?nY_NP01_l000001onX_>So0000ojRlj?l0003oYk[Wo`000?nV^^L00ol000001onS]^Ko0000
o`000?l0003oWk3So`000?nM[N<01Ol000000onKYmoo0000oibXg`03o`000005ojBah_l0003o0000
o`000?n``>H00_l000001Onca^So0000o`000?l0003o[[oV00?o000000GoZKSTo`000?l0003o0000
oj^ki@02o`000005ojfoi_l0003o0000o`000?n]_^H00ol000000on/_NKo0000o`000004o`000005
ojbniol0003o0000o`000?n/_^L01_l000000on/_^Oo0000o`000006ooooo`04o`000?oooooooooo
o`0002kooooo000Dooooo`05o`000?ooooooooooooooool000004_ooool2o`000005ooooool0003o
0000o`000?nZ_NL00ol000001OnZ_NOo0000o`000?l0003oZ[gX00;o000000GoZ[gXo`000?l0003o
0000ojVmj003o`000003ojVmj?l0003o000000;o000000WoZKgXo`000?l0003o0000ojVmj?l0003o
ZKgXo`000?nY_NP00_l000001OnY_NSo0000o`000?l0003oZKgX00?o000000GoZKgXo`000?l0003o
0000ojVmj003o`000005ojVmj?l0003o0000o`000?nY_NP00_l000001OnY_NSo0000ojVmj?l0003o
ZKgX00?o000000?oZKgXo`000?l000001_l000002OnY_NSo0000o`000?l0003oZKgXo`000?nY_NSo
0000ojVmj002o`000005ojVmj?l0003o0000o`000?nY_NP00ol000001OnY_NSo0000o`000?l0003o
ZKgX00?o000000?oZ;cXo`000?l000000_l000001OnX^nOo0000o`000?l0003oY[WW00?o000000?o
X[CUo`000?nQ/^@00ol000000onKZ^7o0000o`000006o`000005oj2]h?l0003o0000o`000?n/_>D0
0_l000001Onba>Oo0000o`000?l0003o/L?W00;o000000GoZk_Uo`000?l0003o0000ojVhi003o`00
0005ojfmi_l0003o0000o`000?n]_nH00_l000001On/_NKo0000o`000?l0003o[;gV00?o000000Co
[;kWo`000?l0003o[;kW0ol000001On/_^Oo0000o`000?l0003o[;kW00Go00001Oooool01?l0003o
ooooooooool0000^ooooo`005?ooool01Ol0003ooooooooooooooooo000000oooooo1_l000001OnZ
_>Oo0000o`000?l0003oZ[gW00?o000000?oZ[gWo`000?l000000_l000001onZ_NOo0000ojZmiol0
003oZ[gXo`000?nZ_NP00ol000000onY_NSo0000o`000002o`000005ojVmj?l0003o0000o`000?nY
_NP00ol000001OnY_NSo0000o`000?l0003oZKgX00;o000000GoZKgXo`000?l0003o0000ojVmj003
o`000005ojVmj?l0003o0000o`000?nY_NP00ol000000onY_NSo0000o`000002o`000007ojVmj?l0
003oZKgXo`000?nY_NSo0000ojVmj003o`000003ojVmj?l0003o000000;o000000GoZKgXo`000?l0
003o0000ojVmj003o`000005ojVmj?l0003o0000o`000?nY_NP00_l000001OnY_NSo0000o`000?l0
003oZKgX00?o000000GoZKgXo`000?l0003o0000ojRli`08o`000003ojBgi_l0003o000000So0000
00?oVJKOo`000?nJY]h01Ol000001OnT/N7o0000o`000?l0003o/<7V00;o000000Go]<KXo`000?l0
003o0000ojjniP03o`000003ojVghol0003o000000Co000000Go[[oVo`000?l0003o0000ojfniP03
o`000004ojbmi_l0003o0000ojfniP?o000000Go[;kWo`000?l0003o0000ojbni`02o`000005ojbn
iol0003o0000o`000?n/_^L00ol000000ooooooo0000o`000003ooooo`04o`000?ooooooooooo`00
02kooooo000Eooooo`?o00003_ooool2o`000008ooooool0003o0000oj^li_l0003oZkcVo`000?n[
_>H3o`000005ojZliol0003o0000o`000?nZ_NL01?l000002OnZ_NOo0000o`000?l0003oZ[gWo`00
0?nZ_NOo0000ojZmj002o`000005ojZmj?l0003o0000o`000?nY_NP00ol000001OnY_NSo0000o`00
0?l0003oZKgX00?o000000GoZKgXo`000?l0003o0000ojVmj002o`000005ojVmj?l0003o0000o`00
0?nY_NP00ol000001OnY_NSo0000o`000?l0003oZKgX00Co000000_oZKgXo`000?l0003o0000ojVm
j?l0003oZKgXo`000?nY_NSo0000ojVmj004o`000005ojVmj?l0003o0000o`000?nY_NP00ol00000
1OnY_NSo0000o`000?l0003oZKgX00?o000000CoZKgXo`000?l0003oZKgX0ol000001OnY_>So0000
o`000?l0003oZ;cX00?o000000?oY[[Wo`000?l000000ol000001onR/nGo0000o`000?l0003oW:cR
o`000?nKZ^401Ol000000onJY]go0000oifXgP03o`000005ojRfhol0003o0000o`000?ncaNL01_l0
00001On[^^Co0000o`000?l0003oZKOS00?o000000Co[[kVo`000?l0003o[[oV0ol000001On/_NKo
0000o`000?l0003o[;gV00?o000000Co[KkWo`000?l0003o[;kW0ol000001On/_^Oo0000o`000?l0
003o[;kW00;o000000?o[;kWo`000?l000000_l00005ooooo`;o0000;oooool002?ooooo1_l00000
0on[_>Ko0000o`000002o`000007oj^li_l0003oZkcVo`000?n[_>Ko0000oj^liP04o`000005ojZl
iol0003o0000o`000?nZ_NL00ol000001OnZ_NOo0000o`000?l0003oZ[gW00?o000000CoZ[gXo`00
0?l0003oZ[gX0ol000001OnY_NSo0000o`000?l0003oZKgX00?o000000GoZKgXo`000?l0003o0000
ojVmj003o`000004ojVmj?l0003o0000ojVmj0?o000000GoZKgXo`000?l0003o0000ojVmj004o`00
0005ojVmj?l0003o0000o`000?nY_NP00ol000001OnY_NSo0000ojVmj?l0003oZKgX00;o000000Go
ZKgXo`000?l0003o0000ojVmj003o`000005ojVmj?l0003o0000o`000?nY_NP00ol000001OnY_NSo
0000o`000?l0003oZKgX00;o000000_oZ;cXo`000?l0003o0000ojNkiol0003oYk[Wo`000?nU^>Ko
0000ojBgiP03o`000003oj2ai?l0003oWZoS00?o000000CoVJKOo`000?l0003oVJGM1Ol000001OnT
/>7o0000o`000?l0003o/L;V00;o000000?o]<OXo`000?n``NH01Ol000000onY]^?o0000o`000004
o`000005ojnoi_l0003o0000o`000?n]_NH00_l000001On/_NKo0000o`000?l0003o[KkV00?o0000
00?o[KkWo`000?l000001?l000001On/_^Oo0000o`000?l0003o[;kW00?o000000Co[;kWo`000?l0
003o0000=Oooool0027ooooo0_l00002ooooo`03o`000?n/^nCo000000?o000000Go[;_Uo`000?l0
003o0000oj^liP03o`000005oj^li_l0003oZkcVo`000?n[_>H00_l000001On[_>Ko0000o`000?l0
003oZ[cW00?o000000GoZ[gWo`000?l0003o0000ojZmi`03o`000005ojZmiol0003o0000o`000?nY
_NP00_l000001OnY_NSo0000o`000?l0003oZKgX00?o000000GoZKgXo`000?l0003o0000ojVmj003
o`000008ojVmj?l0003o0000ojVmj?l0003oZKgXo`000?nY_NP3o`000003ojVmj?l0003o000000Ko
000000GoZKgXo`000?l0003o0000ojVmj003o`000005ojVmj?l0003o0000o`000?nY_NP00_l00000
1OnY_NSo0000o`000?l0003oZKgX00?o000000GoZKgXo`000?l0003o0000ojVmj003o`000005ojVm
j?l0003o0000o`000?nX_>L01?l000001OnV^NOo0000o`000?l0003oXkKV00Ko000000?oVZSPo`00
0?l000000ol000000onIY=go0000oibWg@03o`000005ojVfh_l0003o0000o`000?nda^L00_l00000
1OncaNOo0000ojfli?l0003oZ[SS00Oo000000Co[[oVo`000?l0003o[[oV0ol000001On/_>Go0000
o`000?l0003o[KkV00;o000000Wo[KoWo`000?l0003o0000ojfniol0003o[;kWo`000?n/_^L01_l0
00002?n/_^Oo0000o`000?l0003o[;kWo`000?oooooo0000=?ooool001kooooo0ol000001Ooooooo
0000o`000?l0003o[K[T00?o000000Co[;_To`000?l0003o[;_T0ol000001On/^nGo0000o`000?l0
003oZkcU00?o000000GoZkcVo`000?l0003o0000oj^liP02o`000005oj^li_l0003o0000o`000?nZ
_>L00ol000001OnZ_NOo0000o`000?l0003oZ[gW00?o000000SoZ[gWo`000?l0003oZ[gWo`000?nY
_NSo0000ojVmj0?o000000GoZKgXo`000?l0003o0000ojVmj003o`000003ojVmj?l0003o000000;o
000000OoZKgXo`000?nY_NSo0000ojVmj?l0003oZKgX00?o000000?oZKgXo`000?l000000_l00000
1OnY_NSo0000o`000?l0003oZKgX00?o000000GoZKgXo`000?l0003o0000ojVmj002o`000005ojVm
j?l0003o0000o`000?nY_NP00ol000001OnY_NSo0000o`000?l0003oZKgX00?o000000GoZ;cXo`00
0?l0003o0000ojNki`09o`000003oin`hol0003o000000?o000000?oV:GNo`000?nHXmd01_l00000
1?nT/>3o0000o`000?n__N@3o`000003okG7iol0003o000000So000000Go[;_To`000?l0003o0000
ojo0iP06o`000005ojfmiOl0003o0000o`000?n]_^H02_l000000on/_^Oo0000ojbni`0;o`0003Co
oooo000Mooooo`;o000000Coooooo`000?l0003o[[WR0ol000001On]^^?o0000o`000?l0003o[K[S
00?o000000Co[;_To`000?l0003o[;_T0ol000001On/^nGo0000o`000?l0003oZkcU00?o000000Go
ZkcVo`000?l0003o0000oj^liP02o`000005oj^li_l0003o0000o`000?nZ_>L00ol000001OnZ_NOo
0000o`000?l0003oZ[gW00Co000000?oZ[gWo`000?nZ_NL00ol000001OnY_NSo0000o`000?l0003o
ZKgX00?o000000?oZKgXo`000?l000000_l000002onY_NSo0000o`000?l0003oZKgXo`000?nY_NSo
0000ojVmj?l0003oZKgX00Co000000GoZKgXo`000?l0003o0000ojVmj003o`000005ojVmj?l0003o
0000o`000?nY_NP00ol000001?nY_NSo0000o`000?nY_NP3o`000005ojVmj?l0003o0000o`000?nY
_NP00ol000001OnX_>Oo0000o`000?l0003oYk_X00?o000000?oY;KVo`000?l000000ol000000onM
[N?o0000oi^Zh@06o`000003oiRSg?l0003oVjKM00?o000000CoZKKRo`000?l0003o/l?V0ol00000
0ondaNOo0000o`000005o`000004oj^hhol0003o0000ojnni@?o000000?o[koVo`000?n]_>D02?l0
00000on]_nKo0000ojfniP03o`000003ojfniol0003o000000Co000000Go[;kWo`000?n/_^Oo0000
ojbni`03o`000004ojbniol0003o0000o`0003?ooooo000Looooo`Co000000So[[WQo`000?l0003o
[[SQo`000?n^^N;o0000ojjih@?o000000Go[KWRo`000?l0003o0000ojfjh`02o`000005ojfjhol0
003o[;_To`000?n/^n@00ol000001On/^nGo0000o`000?l0003oZkcU00Co000000OoZkcVo`000?n[
_>Ko0000oj^li_l0003oZkcV00?o000000GoZ[cWo`000?l0003o0000ojZmi`04o`000007ojZmiol0
003oZ[gWo`000?nZ_NOo0000ojZmi`03o`000005ojVmj?l0003o0000o`000?nY_NP01?l000001OnY
_NSo0000o`000?l0003oZKgX00?o000000GoZKgXo`000?nY_NSo0000ojVmj006o`000005ojVmj?l0
003o0000o`000?nY_NP00ol000001OnY_NSo0000o`000?l0003oZKgX00?o000000CoZKgXo`000?l0
003oZKgX0ol000001OnY_>Oo0000o`000?l0003oZ;cX00?o000000OoY[WVo`000?l0003o0000oj>e
i_l0003oXK?U00Ko000000?oUjCNo`000?l000001Ol000001OnOZ=go0000o`000?l0003o/;gT00[o
000000GoZ;CQo`000?l0003o0000ojfki006o`000007ojjmiOl0003o[KcUo`000?n]_NGo0000ojjo
iP06o`000005ojfni_l0003o[KkWo`000?n]_nL00ol000000on/_nOo0000o`000004o`000005ojbo
iol0003o0000o`000?n/_^L00ol0000booooo`005Oooool2o`0000Gooooo0ol000001?n_^>3o0000
o`000?n_^=l3o`000007ojnhh?l0003o[kSPo`000?n^^N7o0000ojjih@04o`00000;ojjih_l0003o
0000o`000?n]^^?o0000ojfjhol0003o[;[To`000?n/^^@00ol000000on/^nGo0000o`000002o`00
0007oj^kiOl0003o0000o`000?n[_>Ko0000oj^liP03o`000005oj^li_l0003o0000o`000?nZ_>L0
1?l000002onZ_NOo0000o`000?l0003oZ[gWo`000?nZ_NOo0000ojZmiol0003oZ[gW00?o000000?o
ZKgXo`000?l000000_l000001OnY_NSo0000o`000?l0003oZKgX00?o000000OoZKgXo`000?l0003o
0000ojVmj?l0003oZKgX00Co000000GoZKgXo`000?l0003o0000ojVmj003o`000005ojVmj?l0003o
0000o`000?nY_NP00ol000001OnY_NSo0000o`000?l0003oZKcW00;o000000?oZKgXo`000?l00000
0_l000001?nW^^Ko0000o`000?nU^NL6o`000003oib/h_l0003o000000?o000000?oUIoJo`000?nF
W]X01_l000001?nZ]^7o0000o`000?neaNH:o`000007ojVdhOl0003o0000o`000?n`_nGo0000ok30
iP08o`000003ojjni_l0003o[[oV00?o000000?o[KkVo`000?l000001?l000001On]_nOo0000o`00
0?l0003o[;oW00?o000000?o[;oWo`000?l000001?l000000on/_nOo0000o`00000booooo`005?oo
ool01?l0003oooooooooool00005ooooo`?o000000Go/;OOo`000?l0003o0000ojnhg`02o`000009
ojnggol0003o0000o`000?n_^>3o0000ojnhgol0003o[[WQ00;o000000Go[[SQo`000?l0003o0000
ojjihP03o`000005ojfjhol0003o[K[So`000?n/^^@00_l000001On]^^Co0000o`000?l0003o[;_T
00?o000000OoZk_Uo`000?n[^nGo0000oj^li_l0003oZkcV00?o000000?oZkcVo`000?l000000_l0
00001OnZ_>Oo0000o`000?l0003oZ[gW00?o000000OoZ[gWo`000?nZ_NOo0000ojZmiol0003oZ[gW
00Co000000GoZKgXo`000?l0003o0000ojVmj003o`000009ojVmj?l0003o0000o`000?nY_NSo0000
ojVmj?l0003oZKgX00Ko000000GoZKgXo`000?l0003o0000ojVmj003o`000005ojVmj?l0003o0000
o`000?nY_NL00ol000001OnY_NSo0000o`000?l0003oZ;_W00?o000000GoY[[Wo`000?l0003o0000
oj:eiP05o`000003oiVVgol0003oUj?M00Ko000000?oVZ;Ko`000?nOYm`01_l000002Onhb>Ko0000
ok?2iOl0003o[kcSo`000?nY/]oo0000ojRbg`03o`00000:ojnmi?l0003o0000ok71i_l0003o[kkU
o`000?n^_NGo0000ojfmi@Ko000000Go[[oVo`000?l0003o0000ojfniP03o`000005ojfoiol0003o
0000o`000?n]_nL00_l000002On/_nOo0000o`000?l0003o[;oWo`000?n/_nOo0000ojboi`05o`00
037ooooo000Dooooo`04o`000?ooooooooooo`0000Cooooo0_l000001?oooooo0000o`000?n`]mh3
o`000005ok2gg_l0003o0000o`000?n_]ml00_l000001On`]mko0000o`000?l0003o[kSO00?o0000
00Co[[SPo`000?l0003o[kSP0ol000001On^^N7o0000o`000?l0003o[KWR00?o000000Co[K[So`00
0?l0003o[K[S0ol000002On/^nCo0000o`000?l0003oZk_Uo`000?n[^nGo0000oj^liP02o`000005
oj^li_l0003o0000o`000?n[_>H00ol000001OnZ_>Oo0000o`000?l0003oZ[gW00?o000000?oZ[gW
o`000?nZ_NL01?l000001OnZ_NOo0000o`000?l0003oZKgX00?o000000GoZKgXo`000?l0003o0000
ojVmj003o`000005ojVmj?l0003oZKgXo`000?nY_NP00_l000001OnY_NSo0000o`000?l0003oZKgX
00?o000000GoZKgWo`000?l0003o0000ojVnj003o`000005ojRkiol0003o0000o`000?nX_>P00ol0
00001onU^>Oo0000o`000?l0003oX;3So`000?nN[N801_l000001OnDW]_o0000oiBNf_l0003oUYoJ
00Oo000000?o]/CUo`000?l000001?l000001On[]N3o0000o`000?l0003oZkGQ00?o000000?o/L7U
o`000?l000001_l000001On^_^Go0000o`000?l0003o[[oV00?o000000Co[KkVo`000?l0003o[KoW
0ol000001On]_nOo0000o`000?l0003o[KoW00[o000000?o[;oWo`000?n/_nP00ol0000`ooooo`00
5?ooool01?l0003oooooooooool00004ooooo`07o`000?ooooooooooo`000?n`]mko0000ok2gg@03
o`000005ok2fgOl0003o0000o`000?n`]mh00_l000001On`]]go0000ok2gg_l0003o/;ON00?o0000
00Go[kOOo`000?l0003o0000ojnhh002o`000005ojnhgol0003o0000o`000?n^^>400ol000001?n]
^N;o0000o`000?n]^N83o`000005ojfjhol0003o0000o`000?n/^n@00ol000001On[^nGo0000o`00
0?l0003oZkcV00;o000000GoZkcVo`000?l0003o0000oj^liP03o`000009ojZliol0003o0000o`00
0?nZ_NOo0000ojZmiol0003oZ[gW00Ko000000GoZ[gXo`000?l0003o0000ojVmj003o`000005ojVm
j?l0003o0000o`000?nY_NP00ol000000onY_NSo0000o`000004o`000005ojVmiol0003o0000o`00
0?nY_^P00ol000001OnY_>Oo0000o`000?l0003oZ;gX00?o000000GoYk_Wo`000?l0003o0000ojBd
i@06o`000003oiRXhOl0003o000000co000000Ko/[kSo`000?l0003o^LOUo`000?nd`N@5o`000003
ojVbgol0003o000000Co000000?o/L7Vo`000?n__N@00ol000001?n^_NGo0000o`000?n__nH3o`00
0005ojjoi_l0003o0000o`000?n^_nH02_l000000on]_nOo0000ojboi`03o`000003ojboiol0003o
000000Co000000?o[;oXo`000?l00000<?ooool001Cooooo00Co0000oooooooooooo00001?ooool0
3_l0003ooooooooooooooooo0000ok2ggOl0003o/KKMo`000?na]]go0000ok6fgOl0003o/KKM0_l0
00002ona]]co0000o`000?l0003o/;KMo`000?na]]co0000ok2fgOl0003o/;KM00?o000000So/;ON
o`000?l0003o/;KNo`000?n_]moo0000ojngg`?o000000Go[[SPo`000?l0003o0000ojjihP02o`00
0005ojjih_l0003o0000o`000?n]^^<00ol000001On/^^Co0000o`000?l0003o[;_U00;o000000Go
[;_Uo`000?l0003o0000oj^liP03o`000005oj^li_l0003o0000o`000?nZ_>L00ol000001OnZ_NOo
0000ojZmiol0003oZ[gW00;o000000GoZ[gWo`000?l0003o0000ojZmj003o`000005ojVmiol0003o
0000o`000?nY_NP00ol000001OnY_NSo0000ojVmiol0003oZKgW00Ko000000GoZKcWo`000?l0003o
0000ojVmj003o`000005ojRlj?l0003o0000o`000?nV^>D00ol000000onR]nSo0000o`000004o`00
0003oiBOfol0003oTicJ00;o000000?oTY[Ho`000?l000000ol000001OnUZm_o0000o`000?l0003o
^<GT00;o000000Go^<OVo`000?n^^>7o0000ojZcg`03o`000003ojbfhOl0003o//3T00Ko000000Go
[[_So`000?l0003o0000ojnoi@03o`000004ojnoi_l0003o0000ojjoiP?o000000?o[[oWo`000?n^
_nL00ol000000on]_nOo0000o`000004o`000005ojboiol0003o0000o`000?n/_nL00ol000000on/
_nSo0000o`000003o`0002oooooo000Dooooo`04o`000?ooooooooooo`0000?ooooo0_l00004oooo
o`03o`000?n`]mko000000;o000000Go/KKMo`000?l0003o0000ok6fg003o`000004ok6fg?l0003o
0000ok6eg0?o000000Oo/KGLo`000?na]Mco0000ok2fgOl0003o/KGL00Co000000Oo/;KMo`000?n`
]]go0000ojnggol0003o[kON00?o000000Go[kSPo`000?l0003o0000ojjih@02o`000005ojjhhOl0
003o0000o`000?n]^N<00ol000001On/^^Co0000o`000?l0003o[;_U00;o000000Go[;_Uo`000?l0
003o0000oj^liP03o`000005oj^li_l0003o0000o`000?nZ_>L00ol000000onZ_NOo0000o`000004
o`000005ojZmiol0003o0000o`000?nZ_NP00ol000001OnY_NSo0000o`000?l0003oZKgW00?o0000
00?oZKkXo`000?nY_>L03?l000001OnW^NKo0000o`000?l0003oYKcY00Co000000?oWJ[Po`000?nJ
Ymh02ol000001?nNX]So0000o`000?n^]n03o`000003ok_;i_l0003o000000Co000000OoZ:oLo`00
0?l0003o0000ok2lh_l0003o]<7T00?o000000Co[k_So`000?l0003o[kgT0ol000001On``NKo0000
o`000?l0003o[koV00So000000Go[L3Wo`000?n]_nOo0000ojfoi`03o`000005ojfoiol0003o0000
o`000?n/_nP00_l000001On/_nSo0000o`000?l0003o[;oX00?o000000?oooooo`000?ooool0;Ooo
ool001Gooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo0_l000001?n`]mgo0000o`000?na
]]d3o`000005ok6fg?l0003o0000o`000?na]M/00ol000001?na]M_o0000o`000?nb]=/3o`000005
ok6dfol0003o/KCKo`000?na]M`00_l000002ona]M_o0000o`000?l0003o/;GLo`000?na]Mco0000
ok2fg_l0003o/;KM00?o000000Go[kOOo`000?l0003o0000ojjhh@02o`000005ojjhhOl0003o0000
o`000?n]^N800ol000001On/^^Co0000o`000?l0003o[;_U00;o000000Go[;_Uo`000?l0003o0000
oj^liP03o`000009oj^li_l0003o0000o`000?nZ_NOo0000ojZliol0003oZ[gW00Ko000000GoZ[gW
o`000?l0003o0000ojVmi`03o`00000;ojVnj?l0003o0000o`000?nY_>Oo0000ojVnj?l0003oZKkX
o`000?nY_NP00ol000000onX^^Ko0000o`000007o`000003oj:`h_l0003o000000?o000000?oUj?M
o`000?l000000ol000000onAU]Co0000o`000003o`000005ojJ]gOl0003o0000o`000?njbNH00_l0
00001Onha>Co0000ojbbg?l0003oZJoL00?o000000?o[[KOo`000?l000000_l000001Onc`>Co0000
ok6mhol0003o[kcS00?o000000Co/<7Vo`000?l0003o/<7V0ol000000on^_nKo0000ojk0i`03o`00
0003ojk0iol0003o000000Co000000Go[L3Wo`000?l0003o0000ojboj003o`000003ojboj?l0003o
000000Wo0000;_ooool001cooooo00?o0000ooooooooool01?ooool3o`00000;ok2gg_l0003o/;ON
o`000?na]]go0000ok6fg?l0003o/KGLo`000?nb]M/00ol000001Onb]=[o0000o`000?l0003o/[CJ
00;o000000Go/[CJo`000?l0003o0000ok:dfP03o`000004ok6dfol0003o0000ok6dfP?o000000Oo
/KGKo`000?na]=_o0000ok2fgOl0003o/;GM00?o000000So[kONo`000?l0003o[kKNo`000?n^^>3o
0000ojjhh0?o000000Go[KWRo`000?l0003o0000ojbjh`02o`000005ojbjhol0003o0000o`000?n/
^nD00ol000001On[_>Ko0000o`000?l0003oZkcV00?o000000?oZ[gWo`000?nZ_NL02?l000001OnZ
_^So0000o`000?l0003oZKcW00?o000000_oZKkXo`000?l0003o0000ojVmj?l0003oZK[Vo`000?nX
^^Ko0000ojS0j`03o`000003ojJdhol0003oYK?S00?o000000?oWk;Uo`000?nM[N<02Ol000000onB
VMOo0000oiNMf003o`000005ojjggol0003o0000o`000?nka^<00_l000001Onb^Mko0000o`000?l0
003oZJgJ00?o000000?o/koRo`000?nea>D01_l000001On`_nGo0000o`000?l0003o/<;W00So0000
00Go[/3Wo`000?l0003o0000ojg0i`03o`000003ojg0iol0003o000000So000000?o[;oXo`000?n/
_nP00ol000001_n/_nSo0000o`000?l0003oooooo`0002gooooo000Kooooo`;o00001_ooool01Ol0
003o[kSPo`000?l0003o[kSP00?o000000_o/;ONo`000?l0003o0000ok6fg?l0003o/KGLo`000?nb
]=_o0000ok:dfP03o`000008ok:cfOl0003o0000ok:cfOl0003o/[?Io`000?nb/mP3o`000005ok:c
fOl0003o0000o`000?nb/mX00_l000002onb/mWo0000o`000?l0003o/KCJo`000?na/m[o0000ok2e
g?l0003o/;CL00Co000000Oo[kKNo`000?n`]]go0000ojjggol0003o[kOO00?o000000Go[KSQo`00
0?l0003o0000ojbjh`02o`000005ojfjhol0003o0000o`000?n/^n@00ol000002on[_>Ko0000o`00
0?l0003oZkcVo`000?nZ_>Ko0000ojZliol0003oZ[gX00co000000GoZKgXo`000?l0003o0000ojVk
iP03o`000005ojS0jol0003oYkKSo`000?nW]N<00ol000000onT^NSo0000o`00000@o`000004ojFZ
f_l0003o0000okNlg@?o000000Go^<7Po`000?l0003o0000ojV]fP03o`000006ok6jhOl0003o0000
okK5i_l0003o//3T0ol000001?n__NCo0000o`000?na`NH3o`000003ok30i_l0003o[koV00?o0000
00Co[l3Wo`000?l0003o[/3W0ol000001on^_nOo0000o`000?l0003o[KoWo`000?n]_nL00ol00000
0on/_nOo0000o`000004o`000005ojboj?l0003o0000o`000?n/_nP00ol000000ooooooo0000oooo
o`0[ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`000?n^^^?o000000;o000000Co[kSP
o`000?l0003o[kSP0ol000002ona]mgo0000o`000?l0003o/[GKo`000?nb]M_o0000ok:df_l0003o
/[?I00Co000000Oo/k?Ho`000?nc/]So0000ok>bf?l0003o/k;G00?o000000Go/k;Go`000?l0003o
0000ok:bf002o`000009ok:bf?l0003o0000o`000?nb/mWo0000ok:bf?l0003o/KCK00Ko000000Oo
/;GMo`000?n`]=co0000ojnggol0003o[kKN00?o000000Go[[SQo`000?l0003o0000ojfih`02o`00
0005ojfihol0003o0000o`000?n/^n@00ol000001on[^nGo0000o`000?l0003oZkgWo`000?nZ^nH0
0ol000001OnZ_NSo0000o`000?l0003oZ[gW00co000000GoZ;OSo`000?l0003o0000ojJmj@03o`00
0003oj6fiol0003o000000Co000000KoTI;Ao`000?l0003oSHc=o`000?n=S<d2o`000005oiBEdOl0
003oW9kEo`000?n_/MT00_l000001OnobN;o0000o`000?l0003o/[[O00?o000000GoZZoLo`000?l0
003o0000okK4i@04o`000005ok2jhOl0003o0000o`000?na_n@02?l000001On``>Ko0000o`000?l0
003o[l3V00?o000000?o[[oWo`000?l000001_l000001On]_nOo0000o`000?l0003o[KoW00?o0000
00?o[;oXo`000?l000002_l0000[ooooo`006oooool00ol0003oooooooooo`07ooooo`03o`000?n[
_>Go000000;o000000Go[[[So`000?l0003o0000ojnhg`03o`000004ok6fgOl0003o0000ok6fg@?o
000000Go/[CJo`000?l0003o0000ok>cf@03o`00000:ok>bf?l0003o0000ok>beol0003o/k7Fo`00
0?nc/MKo0000ok>aeP?o000000Go/k7Fo`000?l0003o0000ok>ae`02o`000009ok>`e_l0003o0000
o`000?nb/MSo0000ok:aeol0003o/K?J00;o000000Oo/K;Io`000?l0003o0000ok2dfol0003o/;?K
00?o000000Go[kGMo`000?l0003o0000ojjgh002o`000005ojjgh?l0003o0000o`000?n]^>800ol0
00001on/^nGo0000o`000?l0003oZk[Uo`000?n[_>H00ol000001OnZ_>Oo0000o`000?l0003oZ[_V
00?o000000GoZL7[o`000?l0003o0000ojRgh`0=o`000003oi^QfOl0003oV9cF00go000000?oYZGD
o`000?nla^801ol000001?nX[=[o0000o`000?n_]Md3o`000003okO4i?l0003o/[_P00?o000000Ko
/KgSo`000?l0003o/l7Uo`000?nb`>D3o`000003ok30iOl0003o000000Co000000Oo[l3Wo`000?l0
003o0000ojk0iol0003o[/3W00?o000000Co[L3Wo`000?l0003o[L3X0ol000001on/_nSo0000o`00
0?l0003o[;oXo`000?n/_nP00ol000000on/_nSo0000o`000003o`0002_ooooo000Kooooo`03o`00
0?oooooooooo00Sooooo00?o0000ojRnjOl000000_l000001On[_>Ko0000o`000?l0003o[[[S00?o
000000Go/;SOo`000?l0003o0000ok6fg002o`000005ok6fg?l0003o0000o`000?nb]=T00ol00000
1Onc/]Oo0000o`000?l0003o/k7F00;o000000_o];7Eo`000?nd/=Co0000okB`eOl0003o]:oDo`00
0?nc/=Go0000okB_e003o`000004ok>`eOl0003o0000ok>_e0?o000000Go/k3Fo`000?l0003o0000
ok:af002o`000007ok:aeol0003o/[3Fo`000?na/m[o0000ok6bf@03o`000005ok2dg?l0003o0000
o`000?n^]]l00_l000001On^]moo0000o`000?l0003o[KOQ00?o000000Oo[;_To`000?n/^^Co0000
oj^li_l0003oZkWT00?o000000GoZ/7Zo`000?l0003o0000ojVgh`03o`000005ojW0j_l0003o0000
o`000?nW_>P01Ol000000onQZMco0000o`000004o`000003ohbPhOl0003oRYSJ00;o000000KoS8kA
o`000?l0003oUI??o`000?nMV]44o`000005oko:hol0003o];GIo`000?n^[mT00ol000000on[ZmOo
0000o`000004o`000003okJnh?l0003o/[[O00?o000000?o]<;To`000?l000000_l000001Ona`^Ko
0000o`000?l0003o/L;W00co000000Go[L7Xo`000?l0003o0000ojg0j00<o`000005ojboj?l0003o
0000o`000?n/_nP01?l0000[ooooo`006_ooool2o`0000_ooooo00?o0000ojFok?l000000_l00000
1OnX_^[o0000o`000?l0003oZkcV00?o000000?o[K[So`000?l000000_l000002on`^=oo0000ok2h
gol0003o/KKLo`000?nb]M_o0000ok>cfOl0003o/k?H00?o000000Go];7Fo`000?l0003o0000okB`
e002o`00000;okB_dol0003o0000o`000?nd[m?o0000okF^d_l0003o]:kCo`000?nd[]800ol00000
1?nd[]?o0000o`000?nd[M83o`000005ok>^dol0003o0000o`000?nb/=H01?l000001Onc[]?o0000
ok6af?l0003o/K3G00?o000000Go/;?Ko`000?l0003o0000ojjdg@02o`000005ojneg_l0003o0000
o`000?n]^>400ol000000on/]n;o0000ojbni`03o`000005ojZehOl0003o0000o`000?nZ`N/00ol0
00000onX_>Oo0000o`00000Ho`000003ojR_g?l0003o^koM00?o000000Co];GIo`000?l0003oZJ;?
0ol000000one]]Wo0000okk7hP06o`000007okC2i?l0003o0000o`000?nea^Oo0000ok;3i`02o`00
0007ok34j?l0003o0000o`000?n`a>Wo0000ojo3j@03o`000005ojk2jOl0003o0000o`000?n]`^P0
0_l000001on]`NWo0000o`000?l0003o[L7Xo`000?n/`NT00ol000001On/`>So0000o`000?l0003o
[<3X00_o0000:_ooool001_ooooo00?o0000ooooooooool02_ooool2o`000005oj;1kol0003o0000
o`000?nT`>d00ol000001OnW_n_o0000o`000?l0003oZ[gW00?o000000Go[K[So`000?l0003o0000
ok2hg`03o`00000;ok:efol0003o/[GKo`000?nc/mSo0000ok>beol0003o];7Eo`000?nd/=@00ol0
00001One[m?o0000o`000?l0003o]JkB00;o000000Oo]JgAo`000?ne[<oo0000okF]dOl0003o]Jc?
00?o000000Co]:c@o`000?l0003o]J_?0ol000001Ond[=7o0000okB[col0003o/jkC00Co000000Go
/jcAo`000?l0003o0000ok:]d`03o`000005ok2af?l0003o0000o`000?n_]Md02?l000001On/[m[o
0000oj^bg_l0003o[KoX00?o000000?oZKWTo`000?l000001Ol000001OnRb??o0000o`000?l0003o
WJ7G00;o000000?oU9KCo`000?n?TM400_l000001_n6RLoo0000o`000?n4R<oo0000ohR<d0;o0000
00koVj3Ho`000?l0003o/:gEo`000?no^MCo0000ok^ieol0003o[ZK@o`000?nYX/oo0000ok6^e@;o
000000Oo_l[So`000?nkbNGo0000okO1h_l0003o/l7T00;o000000?o]L[Yo`000?l000000ol00000
0on`a>Wo0000o`000006o`000005ojk2jOl0003o0000o`000?n]`^T03?l000001On/`>So0000o`00
0?l0003o[<3X00?o000000?o[<3Xo`000?n[_nP00ol000000on[_nSo0000o`000003o`0002Wooooo
000Jooooo`;o00003_ooool5o`000005oj32l?l0003o0000o`000?nR`Nl00ol000001OnV`>co0000
o`000?l0003oZKkX00?o000000Go[K_To`000?l0003o0000ok2hg`03o`00000;ok:efol0003o0000
o`000?nd/]Oo0000okBbe_l0003o];3Do`000?ne[m<00ol000001One[M7o0000o`000?l0003o]Jc?
00;o000000_o]Z_>o`000?nfZ/go0000okF[c_l0003o]ZW=o`000?neZloo0000okFYc@03o`00000:
okB[col0003o0000okBYcOl0003o]JS<o`000?nc[=7o0000ok>YcP;o000000Go]:O<o`000?l0003o
0000ok>/d@03o`000007ok2[dol0003o/k7Go`000?na]mko0000ojfZe006o`000003ojfag?l0003o
000000Go000000GoY/Wbo`000?l0003o0000oj>Vf00Co`000005ojBJbol0003o0000o`000?no^M@0
1_l000000on^ZM?o0000okg8h`08o`000003okC8jOl0003o000000;o000000Oo/L;Vo`000?l0003o
0000ok33j?l0003o/<;X00?o000000?o[/7Xo`000?l000001?l000000on]`NSo0000ojg0j003o`00
0005ojg0j?l0003o0000o`000?n/`>P03?l000001On[_nSo0000o`000?l0003oZkoX00Go00001ooo
ool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000=ooooo`006_ooool0
0ol0003oooooooooo`0?ooooo`So000000GoW/;bo`000?l0003o0000oj32l003o`000005ojC1k_l0
003o0000o`000?nX_^X01?l000001On`^=oo0000o`000?l0003o/[GJ00;o000000oo/[CJo`000?l0
003o0000okBae_l0003o];7Eo`000?ne[];o0000okJ^dOl0003o]Zc@o`000?nf[<h00ol000001Onf
Z/go0000o`000?l0003o]ZW=00;o000000Oo]ZS;o`000?nfYlWo0000okFXc?l0003o]ZK900?o0000
00Wo]JS<o`000?l0003o]JK9o`000?neY<Oo0000okBWc?l000000_neYl/2o`000004ok:Vc?l0003o
0000okF[c`?o000000Oo[jC=o`000?ncZm3o0000ok6dfol0003o/:cD00Ko000000?o//W[o`000?l0
00000_l000001onSXM?o0000o`000?l0003oW;S/o`000?nHY]l00_l000001_nATM3o0000o`000?n:
PlGo0000ohQm`@;o000000CoRg^lo`000?l0003oVH_30_l000002OnfZlgo0000o`000?l0003o`/7H
o`000?n_[=Go0000ojbXd`04o`000003ol7Dj?l0003o]l;S00?o000000Ko/l;Vo`000?l0003o]/OW
o`000?nc`N@8o`000005ok30iOl0003o0000o`000?n_`>H02?l000001On^_nOo0000o`000?l0003o
[KoW00?o000000?o[;oXo`000?n/_nL00ol000001On/_nSo0000o`000?l0003oZkoX00_o00001_oo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`0:ooooo`003?ooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo013o
oooo0_l000000onM`O7o0000o`000007o`000005oi_3m?l0003o0000o`000?nM`o800ol000000onQ
`_3o0000o`000002o`000005ojbliOl0003o0000o`000?n_^>000ol000001Onb]=[o0000o`000?l0
003o];7E00;o000000oo];7Eo`000?l0003o0000okJ]d?l0003o]Zg?o`000?nfZlgo0000okNZc?l0
003o]ZW<o`000?ngZ<X00ol000003_nfYlWo0000o`000?nfYLOo0000okNTaOl0003o]ZG8o`000?nf
XlGo0000okFVbOl0003o]JC70ol000002_neYl_o0000o`000?ncXLKo0000okJTaol0003o]J_?o`00
0?naWlD3o`000003ok>[d?l0003o000000Co000000?o[9k9o`000?nj`n400ol000000onQSKoo0000
oj:HbP0@o`000003ohQj_Ol0003oRg^l00;o000000GoZio;o`000?nfZlgo0000ol[>g002o`000007
okFdf?l0003o0000o`000?n_/M[o0000ol3<i002o`000003okc4h?l0003o];OK00?o000000?o]lCT
o`000?l000000_l000000ond_^;o0000okG2i003o`000004ok;0iOl0003o0000ok71i@?o000000?o
/<3Vo`000?n``>H00ol000000on^_nKo0000o`00000:o`000005ojfoiol0003o0000o`000?n/_nL0
0ol000000on/_nSo0000ojboi`03o`000006oj^nj?l0003o0000o`000?oooooo00001Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool02_oo
ool000_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool04Oooool2o`000005oj2okol0003o0000o`000?nM`O403Ol000000onJa?Go
0000o`000002o`000005ojG1kOl0003o0000o`000?n[_NL00ol000001On_^N7o0000o`000?l0003o
/[CJ00?o000000Go]K3Do`000?l0003o0000okJ]c`03o`000009okNZc?l0003o0000okNXbol0003o
]jS9o`000?ngY/So000000;o]jG70_l000001OngY<Go0000o`000?l0003o]Z?500;o000000Ko]Z73
o`000?ngX<7o0000okJSaOl00002okBM`0;o000000So]ZC7o`000?l0003o/i^oo`000?ncVKgo0000
ok>QaPGo000000SoZiBno`000?l0003o_kSBo`000?nTPJko0000oj:5]@Go000000CoVhBjo`000?l0
003oS8c>3ol000001_n[Wl_o0000o`000?o9cmko0000okfkf0?o000000KoZJ?@o`000?l0003o^k_I
o`000?o3a]`4o`000007ok^ogOl0003o0000o`000?nja>;o0000okK1hP02o`000003okK5iOl0003o
]LOX00?o000000?o//?Vo`000?l000001_l000001on_`^So0000o`000?l0003o[l7Wo`000?n^`NP0
0ol000001On^`>Oo0000o`000?l0003o[KoW00co000000Go[;oWo`000?l0003o0000ojbnj004o`00
00Gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo00[ooooo000?ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo
0_l0000Dooooo`?o000000GoXkk/o`000?l0003o0000oj2ok`02o`000005oic0lOl0003o0000o`00
0?nH`_@03_l000001OnR`_3o0000o`000?l0003oZ;oZ00?o000000Go[[[Ro`000?l0003o0000ok:e
fP03o`000005okF`dol0003o0000o`000?ngZlh00ol000001OngZ<Wo0000o`000?l0003o]jG700;o
000000Ko]jC5o`000?nhXl?o0000okNR`ol00002okNO`@;o000000Go]j31o`000?l0003o0000okBM
`002o`000005okNO`?l0003o]IVjo`000?ncVkl01Ol000001OnfX/Co0000o`000?n/S;Go000000;o
`:[40_l00002ojB1[P;o000000Co`;kHo`000?l0003oYhRd1?l000001?nNR;co0000o`000?nAT]02
o`000003ogi/]?l0003oO6F^00?o000000GoSh_:o`000?nMTlWo0000okbmfP04o`000004ojfH`Ol0
003oZ9[8o`0000;o]:S<0ol000000oo1_mSo0000okg1g@02o`000003ol7Dj?l0003o000000?o0000
00?o]lWXo`000?l000000_l000001onabnco0000o`000?l0003o/LO[o`000?n_an`00ol000000on_
a>Wo0000o`000006o`000005ojg3jOl0003o0000o`000?n]`NT00ol000000on]`>So0000ojc0j003
o`000005ojboj?l0003o0000o`000?n/_nP02ol00004ooooo`04o`000?ooooooooooo`0000Sooooo
00Go0000oooooooooooo0000ooooo`04o`0000gooooo000?ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`?o000000GoY[cYo`000?l0
003o0000ojBmj`03o`000004oj2nk_l0003o0000oic0l@?o000000?oUl;eo`000?l000003?l00000
6OnMa??o0000o`000?l0003oYL7]o`000?n^^n?o0000ojfliOl0003o/[GKo`000?nb]]co0000okF`
dol0003o]K3Co`000?ngZlgo0000okNZc?l0003o]jO8o`000?nhY/L00ol000001OnhXl?o0000o`00
0?l0003o]io100;o000000Ko^9noo`000?ngVk_o0000okJK_Ol00002okNL_0;o000000?o]IVjo`00
0?l000001?l000001?niWKgo0000ojf8[_n]R:h2o`000004ol2Za?l0003o0000o`0000;oY86^00Co
0000okVN__l0003o]92a0ol000001?nGJigo0000o`000?nNR;`7o`000004ogaU[_l0003o0000ohA_
/`Go000000Go^jK4o`000?ngW;go0000ojfH`@03o`000004okBXc?l0003o0000olgBg@;o000000?o
_lSRo`000?o0g^l01?l000000onado;o0000o`00000<o`000003ojc8k_l0003o000000?o000000Go
[<K]o`000?l0003o0000ojc4j`0<o`000005ojc1jOl0003o0000o`000?n/`>T00ol000000on/`>So
0000ojc0j003o`000006oj^oj?l0003o0000o`000?oooooo00000oooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00004?ooool000_ooooo1?l00003ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool05Oooool3o`000005ojRkiol0003o0000o`00
0?nW_>P00ol000000onT_>[o0000o`000008o`000003oiK1mOl0003o000001;o000000Go[;gWo`00
0?l0003o0000ok:gg@03o`00000>okJ`dol0003o0000o`000?ngZL_o0000okRYbol0003o^:G5o`00
0?nhXlCo0000okRP`Ol00002okVP`0;o000000Go]i^ko`000?l0003o0000okNL_004o`000004okBB
/ol0003o]9Bgo`0000;o^Y^h0_l00002ojf8[P06o`000?nnWkWo0000ojf3Yol0003oZ86Y1Ol00000
1ondT;7o0000oiMVV?l0003oUf^Mo`000?nJMJP00ol000000on1DHoo0000o`000005o`000009ohA_
/ol0003oTH6no`000?n_T;Ko0000ok^Va?l0003o]ibm00;o000000Go/INmo`000?l0003o0000olg8
e@02o`000003ol7Hjol0003o000000Wo000000?oZM7eo`000?nXb_401_l000001onYb?3o0000o`00
0?l0003oZLO_o`000?nYa^h00ol000000onYaNko0000o`000003o`000005oj[4k?l0003o0000o`00
0?n[`n`01_l000000on[`^_o0000o`000007o`000005oj_0jOl0003o0000o`000?n[`>T01?l00004
ooooo`;o00002_ooool2o`0000;ooooo1Ol0000<ooooo`002oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000?ooooo0_l0000Gooooo`?o000000GoZK_Vo`000?l0003o0000ojVk
iP03o`000003ojRkiol0003oZ;_W00?o000000?oY[_Xo`000?l000007?l000001Ona^=ko0000o`00
0?l0003o]K3C00?o000000Go^:W;o`000?l0003o0000okRSa003o`000006okVP`?l0003o0000okRM
_Ol0003o^9bl1?l000000oniVKSo0000o`000002okBB/`;o000000Co^Y^ho`000?l0003o[XN[1Ol0
00001_n]PjOo0000o`000?l0003o/H^]o`0000;o`IV^0_l000001OnGIYSo0000oiM[WOl0003oVWFX
00?o000000GoPE6?o`000?l0003o0000ogQJX`07o`0000;o[i2f00So0000ol:S^_l0003o^9fmo`00
0?naUkgo0000olk8e0So000000?o[]Gdo`000?n[anh00_l000000on^bNgo0000o`000003o`000003
oj_4k?l0003o000000[o000000?oZL?/o`000?l000000ol000001OnY`^co0000o`000?l0003oZL?/
00?o000000?oZL;/o`000?l000001ol000000onZ`N_o0000o`00000=o`0002Cooooo000;ooooo`Go
00000oooool2o`0000Cooooo00?o0000ooooooooool05oooool3o`000005ojVliol0003o0000o`00
0?nZ^nH00ol000001onY^nKo0000ojZki_l0003oZ;[Vo`000?nY^^H00ol000001OnW^^Ko0000o`00
0?l0003oYK[Y00?o000000?oX;c/o`000?l000005?l000001On__>?o0000okJae?l0003o]K7E00?o
000000Go^:[;o`000?l0003o0000okVQ`@07o`000004okVI^?l0003o0000okFB/`?o0000013o^iZf
o`000?naR:[o0000ojj7Zol0003o_9Rbo`000?ncQjOo0000ojf3Yol0003o[82Uo`000?naRjgo0000
0_o1VJh2o`000003oiMVV?l0003oUf^M00;o000000CoVFFBo`000?l0003oPE6?0ol000000omhFZ?o
0000oh9NW`02o`000003oiE_Y?l0003oXGf[00?o000000Ko`Z>jo`000?nhWKgo^9fmo`000?o<b=H3
o`000003ok3AlOl0003o/m[d00Co000000?o/;oUo`000?nca>H01?l000001onb_>7o0000o`000?l0
003o[koVo`000?n__N@00ol000000on]_nOo0000o`00000:o`000005ojZojOl0003o0000o`000?nY
`NX01Ol000001OnY`N_o0000o`000?l0003oZL7[00?o000000?oZL7[o`000?nY`NX00ol000001OnY
`N[o0000o`000?l0003oZ/3Z00?o000000?oooooo`000?ooool08_ooool001Wooooo00?o0000oooo
ooooool06?ooool3o`000005ojVmj?l0003o0000o`000?nY_>L00ol000002onZ^nKo0000o`000?l0
003oZ[_Uo`000?nZ^nGo0000ojVjiOl0003oZ[[U00?o000000GoZKWUo`000?l0003o0000ojNiiP03
o`000003oj>jjOl0003o000001Go000000Oo]KCHo`000?l0003o0000okRYbol0003o^J7100So0000
00Go]YFfo`000?l0003o0000okbK]P03o`000006ok68Z_l0003o0000o`000?nlV;;o00000_ncQjL2
o`0000;o[82U00?o0000ol^R[Ol000000ol00002oiMVV0?o000000KoVFFBo`000?l0003oPE6?o`00
0?miC8l3o`000007oh9NWol0003o0000oiE_Y?l0003oXGf[o`000002olZY^005o`000?o8//Co0000
o`000?o6amX00_l000000onmcnOo0000o`000004o`000003okNlg_l0003o000000;o000000?o^<3P
o`000?nf^mh02?l000001onb_>7o0000o`000?l0003o/;cSo`000?n`_><00ol000000on^_NGo0000
o`00000:o`000005oj^niol0003o0000o`000?nZ_nT00ol000000onY_nWo0000o`000003o`000005
ojVoj_l0003o0000o`000?nY`>X00ol000000onY`>[o0000o`000002o`0002?ooooo000Iooooo`03
o`000?oooooooooo01Wooooo0ol000001OnW_^Wo0000o`000?l0003oZ;gY00?o000000GoZKgXo`00
0?l0003o0000ojZliP03o`000004oj^kiOl0003o0000oj^ji0;o000000GoZk[To`000?l0003o0000
oj^hh`03o`000005ojVhi?l0003o0000o`000?nV]nH00ol000000onP^>[o0000o`00000=o`000003
ojG7lOl0003o];KJ00Co0000017o^J71o`000?l0003o^jC2o`000?ngW;go0000okJE]_l0003o_J2k
o`000?nlVkKo0000okB<[?l0003o/HRZo`000002okZC[`;o00000_ncQjL2o`0000;o[82U00Co0000
ol^R[Ol0003oW6RE0_l00002oiMVV0?o000000KoVFFBo`000?l0003oPE6?o`000?miC8l3o`000003
oh9NWol0003o000000;oUFnT0_l000001_o:ZKSo0000o`000?o8//Co0000olK7fPCo000000Co_KkJ
o`000?l0003oaL_O0ol000000onk_mgo0000okg4h002o`000009okVngOl0003o^L3Po`000?nh`>7o
0000okJmgol0003o]KcO00;o000000?o];gQo`000?l000000ol000001onb_>7o0000o`000?l0003o
/;cRo`000?n`_>800ol000001On^_>Co0000o`000?l0003o[KgU00co000000?oZkkWo`000?l00000
2ol000000onY_nWo0000o`00000Rooooo`006?ooool2o`0001cooooo0ol000001OnV_^_o0000o`00
0?l0003oYkk[00?o000000GoYkkZo`000?l0003o0000ojRmj@03o`000004ojVmiol0003o0000oj^k
iP?o000000CoZk[To`000?l0003oZk[T0ol000001On/^>?o0000o`000?l0003oZkOR00?o000000Go
ZKKRo`000?l0003o0000ojFei002o`000003oiffjOl0003o000000go000000Co^[3@o`000?l0003o
00000_ngW;d2o`0000;o_J2k0_l00002okB<[0;o00000_njTjl00ol0003o^XnYo`000002o`00000;
ojYkXOl0003o[82Uo`000?o;XZgo0000oiaXUOl0003oVFJEo`000?nGIYP00ol000001_nIII;o0000
o`000?n1DHoo0000ogU<S`;o000000[oN5ZSo`000?l0003oRfBPo`000?nEKjCo0000olRU]_l0003o
h=?;1_l000001?o3_mKo0000o`000?o9h>T2o`000003okg:i?l0003o000000?o000000?o^lCQo`00
0?l000000_l000001onha^Go0000o`000?l0003o][oQo`000?nf`>801Ol000001?nc_N7o0000o`00
0?nc_^85o`000005ok6lh_l0003o0000o`000?n`_><00ol000000on^_>Co0000ojjli003o`000005
ojfliOl0003o0000o`000?n/_NH01Ol000001On[_NOo0000o`000?l0003oZ[kX00Wo00008Oooool0
01Sooooo00?o0000ooooooooool07?oooolNo`000005oj^kiOl0003o0000o`000?n/^N<00ol00000
1?n/]n7o0000o`000?n]]n46o`000003ojZbgol0003o000000Go000000?oWK;Wo`000?l000001Ol0
00000onZ`N[o0000okJZc@03o`000005okfYaOl0003o0000o`000?ngU;<00ol000002OnhT[3o0000
o`000?l0003o^XnYo`000?nYNZ3o0000ojYkX@02o`000008om>Z[ol0003o0000oiaXUOl0003oVFJE
o`000?nGIYP3o`000006oiUUT_l0003o0000oh5ASol0003oNDb?1Ol000001On;I:3o0000o`000?l0
003ob:Ff00;o000000?oalOIo`000?l000000_l000001_o<cmco0000o`000?ngmnoo0000okKEl0Co
000000?o/]Wdo`000?l000000ol000000onfc^co0000o`000006o`000003ok?4iol0003o//CW00?o
000000?o/l3To`000?l000000ol000001Onb_^?o0000o`000?l0003o/KgS00So000000Go[kcSo`00
0?l0003o0000ojjli003o`000003ojfliOl0003o[KcU00?o000000Oo[;gVo`000?l0003o0000oj^m
iol0003oZkgW00?o000000?oZkgWo`000?l000008Oooool001Sooooo00?o0000ooooooooool07Ooo
ool2o`000004ojJmj_l0003o0000ojJnj`?o000000GoYKk[o`000?l0003o0000ojBok003o`000005
ojBokOl0003o0000o`000?nT`>d00ol000000onT`>go0000o`000006o`000005ojZliol0003o0000
o`000?n/^^@00ol000001On]]n7o0000ojjih_l0003o[KCN00Go000000Wo[[;Ko`000?nY/=go0000
oj^]fOl0003oXJcOo`000?nW[M/01_l000001?ng^]_o0000o`000?l00002ok^S`@;o000000Co]YFe
o`000?nhT[3o00000_o1Vk02o`000004ojUjX?l0003oZW^Qo`0000;odjZ_0_l000001OnLJ9Go0000
oiUVUOl0003oUfJH00?o00000_nIII83o`000004ogU<Sol0003o0000ogQ?U@Co00000_nhU;82o`00
0005omO9c?l0003o`k_Bo`000?o<m^X07Ol000001on^b>go0000o`000?l0003o/<CXo`000?n`a>T0
0ol000001ona`NKo0000o`000?l0003o/KkTo`000?n`_^@00ol000000on`_NCo0000o`00000:o`00
0003ojjli?l0003o000000Oo000000Go[;gVo`000?l0003o0000oj^miP02o`00023ooooo000Hoooo
o`;o00008?ooool01Ol0003oYkgYo`000?l0003oYkgY00?o000000GoY[gZo`000?l0003o0000ojFn
j`03o`000005ojBnk?l0003o0000o`000?nS_nd00ol000001OnR`>ko0000o`000?l0003oX/7_00co
000000?oZkgWo`000?l000001Ol000001On_]moo0000o`000?l0003o[k;J00?o000000?o[ZkHo`00
0?nb/ML03Ol00002okJE]@;o000000Co`I^`o`000?l0003o00000_nYNZ02o`000004om>Z[ol0003o
0000o`0000;oW6RE1Ol000000on/MIKo0000oiUUTP03o`000004ogU<Sol0003o0000ogQ?U@;o0000
00SoW7NXo`000?nhU;;o^9Bbo`000?oGbLco0000olR]_bOo000000Go[<K]o`000?l0003o0000ojk3
j@05o`000007ojo1iol0003o0000o`000?n__nGo0000ojnoiP03o`000005ojnmiOl0003o0000o`00
0?n^_N@01Ol000001On^_>Go0000o`000?l0003o[KcU00Wo00007oooool001Sooooo00?o0000oooo
ooooool08?ooool01Ol0003oZ;gXo`000?l0003oYkgY00?o000000GoYkgYo`000?l0003o0000ojJm
j@03o`000005ojFmj_l0003o0000o`000?nT_N/00ol000001OnS_^go0000o`000?l0003oXKo^00?o
000000?oWl3`o`000?l000002_l000001OnV`^go0000o`000?l0003oZl3Y00?o000000?o[K_So`00
0?l000001?l000001on_[=Co0000ojbTd?l0003o]K7Eo`000?na[M@00_l000000onS/n?o0000ok:N
``03o`000003olZ``?l0003oZXB/00;o00000_nYNZ001?l0003of[Jdo`000?nXMY/2o`0000;oW6RE
0ol000001Oo8TYco0000ojaeU_l0003oVFFB00;o000000GoPE6?o`000?l0003o0000ogQ?U@02o`00
00;oW7NX1?l000000oo8[Koo0000o`00000]o`000005oj[5kOl0003o0000o`000?n]`nX01Ol00000
1On^`NSo0000o`000?l0003o[[oV00?o000000?o[[kUo`000?n^_^D00ol000001on^_NGo0000o`00
0?l0003o[KgUo`000?n]_ND00ol000000on]_NGo0000o`00000Oooooo`006?ooool00ol0003ooooo
ooooo`0Qooooo`05o`000?nX_NSo0000o`000?nX_NP00ol000001OnX_>So0000o`000?l0003oYkcX
00?o000000GoYkcYo`000?l0003o0000ojJlj@03o`000005ojFlj_l0003o0000o`000?nS_N/00ol0
00001?nQ_^go0000o`000?nO_nl3o`000003oic0lOl0003o000000ko000000?oY/G_o`000?n_^N40
0ol000001Onc^Mko0000o`000?l0003o]ZoB00Wo000000goZXB/o`000?nYOJ?o0000ojUjX?l0003o
f[Jdo`000?nXMY_o0000oj5]Uol0003oW6RE00?o00000_o8TY`2o`000008oiUUT_l0003o0000oh5A
Sol0003oNDb?o`000?mhCiD2o`0000;oW7NX0_l000001OoVakSo0000o`000?l0003oWlGc00?o0000
00?oW[g^o`000?l00000A_l000000on]_NKo0000o`000004o`0001kooooo000Gooooo`?o00008ooo
ool01Ol0003oZ;gYo`000?l0003oZ;gY00?o000000GoZ;gXo`000?l0003o0000ojRmj003o`000005
ojRlj?l0003o0000o`000?nW_>P00ol000001OnW_>So0000o`000?l0003oY[_X01;o000000?oV;kb
o`000?l000004Ol000001OnZYmCo0000ojfPb_l0003ob]3N00?o000000?oZXB/o`000?nYOJ<00_l0
00002ooNb/Go0000o`000?nXMY_o0000oj5]Uol0003oW6REo`000?o=X:Wo000000;ob9:L0_l00000
1_nIII;o0000o`000?n1DHoo0000ogU<S`;o000000GoN4nEo`000?l0003o0000oknG[P02o`000005
on6o]_l0003o0000o`000?nS^nX00ol000001OnQ`_3o0000o`000?l0003oWl3`00?o000000?oW<7b
o`000?l000009Ol000001OnVaO3o0000o`000?l0003oZLC]00?o000000?oZl;[o`000?l000000ol0
00001On/`>Wo0000o`000?l0003o[KoW00?o000000?o[KkVo`000?l000000ol000001?n]_NKo0000
o`000?l0000Mooooo`000oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`0Tooooo`05o`000?nW_NWo0000o`000?nW_NT00ol000001OnW_NWo0000o`000?l0003oZ;gY
01Go000000GoZ;_Wo`000?l0003o0000ojRjiP03o`000003ojNii_l0003o000000;o000000GoXKWZ
o`000?l0003o0000oijjk003o`000003oiJgkol0003o000001Co000000cog/[5o`000?l0003o0000
ojQfVol0003oXFfGo`000?nLJ9Go0000olfPZOl00002olRBW0;o000000KoVFFBo`000?l0003oPE6?
o`000?miC8l2o`000006ogQ?UOl0003o0000oknG[_l0003oklBU8Ol000000onGa?Ko0000o`00000P
o`000005ojS3kOl0003o0000o`000?nZ`^/00ol000000on[`>Wo0000o`000003o`000005ojboj?l0
003o0000o`000?n/_^L00_l0000Mooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Uooooo`oo
000000CoYkkZo`000?l0003oYkkZ0ol000000onW_^[o0000o`000005o`000005ojNmjOl0003o0000
o`000?nX_>P00ol000000onX_>So0000o`000002o`000005ojRhiOl0003o0000o`000?nX^ND00ol0
00001OnV/n?o0000o`000?l0003oY[OU00[o000000?oZKgXo`000?l000002Ol000000ooBbm;o0000
okB8YP02o`000003oj5]Uol0003oW6RE00;o000000?oo=BJo`000?o8TY`00_l000001_nIII;o0000
o`000?n1DHoo0000ogU<S`;o000000CoN4nEo`000?l0003o_iN^0ol000001OnW`>_o0000o`000?l0
003oYkkZ00?o000000GoY[gZo`000?l0003o0000ojG0k003o`000003ojBnk?l0003o000000So0000
00?oWl7ao`000?l000004_l000001OnJa_Ko0000o`000?l0003oW<Ke00?o000000GoW/Kdo`000?l0
003o0000oj76lP03o`000005ojC5lOl0003o0000o`000?nVa>l02Ol000000onZ`N_o0000o`000008
o`0001cooooo0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`;o0000:?ooool2o`000005ojNmjOl0003o0000o`000?nW_NT0
0ol000001OnW_N[o0000o`000?l0003oY[kZ00;o000000?oY[kZo`000?l000001Ol000001OnV_^_o
0000o`000?l0003oY[k[00?o000000GoY[k[o`000?l0003o0000ojJnj`08o`000005ojVki_l0003o
0000o`000?nX]n@01_l000001OnUZm_o0000oj6Wfol0003o/L3U00?o000000CoYZ?Bo`000?l0003o
PhO?1Ol000001Onh/=;o0000o`000?l0003o]8RV00;o000000SoXFfGo`000?l0003o]XRUo`000?ol
e9[o0000olRBW0Go000000?oPE6?o`000?miC8l01?l000000onQLI_o0000o`000003o`000005ojRn
jOl0003o0000o`000?nX_NT00ol000000onW_n_o0000o`000016o`000005ojW1jol0003o0000o`00
0?n[`>T00_l0000Looooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Xooooo`;o000000GoYkgY
o`000?l0003o0000ojNmj@03o`000005ojNmjOl0003o0000o`000?nV_NX01_l000001OnV_N[o0000
o`000?l0003oYKk[00?o000000GoYKk[o`000?l0003o0000ojBnk003o`000004oj>nk?l0003o0000
oj?0kPco000000?oYkcYo`000?l000001Ol000000onbcnoo0000o`000004o`000003oinOe?l0003o
000000?o000000?oSh2no`000?l000001Ol00002okJ8Y@Ko000000?oRUF;o`000?l000000_l00000
2?miC8oo0000o`000?nCHI;o0000oj5aVol0003oklBU1?l000001OnX_NSo0000o`000?l0003oZ;oZ
013o000000GoYKo/o`000?l0003o0000ojBok003o`000005oj>okOl0003o0000o`000?nR`>h08ol0
00001OnSa?7o0000o`000?l0003oY<?_00?o000000?oY/?^o`000?l000002?l0000Kooooo`001?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0Yooooo`;o000000GoZ;gYo`000?l0003o0000ojNmj@03o`00
0003ojNmjOl0003o000000Co000000GoYkgYo`000?l0003o0000ojJmj@03o`000005ojJmj_l0003o
0000o`000?nU_NX00ol000000onT_N_o0000o`000004o`000005oj>nkOl0003o0000o`000?nP_>d0
0ol000000onQ`_7o0000o`00000:o`000004oiVjkol0003o0000oiBMf@So000000CoSh2no`000?l0
003oHEfg0_l000002?nTNZCo0000okJ8YOnfR:Go0000oheLT_l0003oS5R>0_l000001?n:EH_o0000
o`000?n:E8/4o`000003oi=QT_l0003oXG6K00?o000000?oZKgXo`000?l000003_l000001OnX_^Wo
0000o`000?l0003oYkkZ00?o000000GoY[k[o`000?l0003o0000ojJoj`03o`000003ojFok?l0003o
000000So000000GoXL7_o`000?l0003o0000oj31l003o`000005oio2lOl0003o0000o`000?nO`_40
6_l000000onU`noo0000o`000006o`0001[ooooo0003ooooo`;o00001?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0:oooool2o`000005
ojRmjOl0003o0000o`000?nW_NT00ol000001?nW_NWo0000o`000?nW_NT3o`000005ojNmjOl0003o
0000o`000?nW_>T02ol000001?nV_>Wo0000o`000?nU_>T3o`000005ojBjjOl0003o0000o`000?nS
^nX00ol000001OnT_>[o0000o`000?l0003oW;?W00ko000000?o^MC^o`000?l000002?l000000onT
NZCo0000okJ8Y@02o`000003oheLT_l0003oS5R>00;o000000KoRUF;o`000?l0003oRUB;o`000?n;
EX`2o`000003oi=QT_l0003oXG6K00[o000000?oZKkYo`000?l000001?l000001OnX_NWo0000o`00
0?l0003oZ;kY00?o000000GoZ;kYo`000?l0003o0000ojNnjP0ao`000003oj73lOl0003o000000go
00002Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0004ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0002gooooo0_l000000onW_NWo0000
o`00000Bo`000005ojNmjOl0003o0000o`000?nW_NT03?l000001OnU^^Oo0000o`000?l0003oYkgY
00?o000000GoY;GUo`000?l0003o0000ojFjj002o`000003oj^mi_l0003o000000Co000000?oU[?[
o`000?l000000_l000000onSYMOo0000o`000002o`000003ocm>^_l0003o000000;o00000_nTNZ@3
o`000003oheLT_l0003oS5R>00;o000000KoRUF;o`000?l0003oRUB;o`000?n;EX`2o`0000;oTf6B
3ol000001OnY_NSo0000o`000?l0003oZKkY00?o000000GoZ;gYo`000?l0003o0000ojRnj@0@o`00
0005ojJnjol0003o0000o`000?nU_n`00ol000001OnT_ngo0000o`000?l0003oXl3]00[o000000Go
XL7`o`000?l0003o0000oj72l003o`000003oj72l?l0003o000000co000000GoXl;_o`000?l0003o
0000ojC2k`02o`0000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02oooo
o`005_ooool00ol0003oooooooooo`0]ooooo`Co000000GoYkgYo`000?l0003o0000ojNmj@03o`00
0005ojNmjOl0003o0000o`000?nW_NT00ol000001?nW_NWo0000o`000?nW_NX3o`000005ojJmjOl0
003o0000o`000?nV_NX00ol000000onV_N[o0000o`00000:o`000003oj:fiol0003o000000Co0000
00?oXK3Ro`000?nKY=`01Ol000000onki_Co0000o`000004o`000005oeMD]?l0003o0000o`000?mQ
GKL00_l000001onTNZCo0000oh9GUol0003oSEbBo`000?n<F8h00_l000001_n:EH_o0000o`000?n:
E8_o0000oh]FS0;o00000_nCHI800ol0003oll2Io`000005o`000005ojVmj?l0003o0000o`000?nY
_NP00ol000001OnY_^So0000o`000?l0003oZKgX00Wo000000?oZ;kYo`000?l000001?l000001OnX
_^Wo0000o`000?l0003oYkkZ00?o000000GoYkk[o`000?l0003o0000ojJnj`0`o`0000Kooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`005_ooool00ol0003ooooooooo
o`0Zooooo`?o000000?oooooo`000?nW_NT00_l000001OnW_NWo0000o`000?l0003oYkgY00?o0000
00GoYkgYo`000?l0003o0000ojNmj@06o`000005ojJmj_l0003o0000o`000?nV_NX00ol000001OnV
_N[o0000o`000?l0003oYKcZ00Ko000000?oY;g[o`000?l000003?l000000onCZ^Ko0000o`000004
o`000004ohjMg_l0003o0000ofa[_`[o000000GoPUNGo`000?n=G9;o0000ohaHSP02o`000006ohYE
Rol0003o0000ohYDRol0003oReJ<0_l00002oi=QTPGo000000GoZKgXo`000?l0003o0000ojVmj003
o`000005ojVnj?l0003o0000o`000?nY_NP01Ol000000onY_NSo0000o`000008o`000005ojRnjOl0
003o0000o`000?nX_^T00ol000000onX_^Wo0000o`00000>o`000005ojFok?l0003o0000o`000?nU
_n`00ol000001OnT_ngo0000o`000?l0003oXl3]00[o000000GoX/7_o`000?l0003o0000oj;1k`03
o`000003oj;2kol0003o000000Go00001_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00;ooooo000Fooooo`;o0000:?ooool3o`0000Gooooo1?l000001OnW_NWo0000o`000?l0
003oYkgY00?o000000GoYkgYo`000?l0003o0000ojNmj@02o`000005ojNmjOl0003o0000o`000?nV
_NT00ol000001OnV_NWo0000o`000?l0003oY[cY00?o000000CoYKcZo`000?l0003oY[k[0ol00000
1OnR^>So0000o`000?l0003oY;o/00?o000000?oY[cYo`000?l000002?l000000onOZmoo0000o`00
0008o`00000:od]D^Ol0003o0000ogEEWol0003oPUNGo`000?n=G9;o0000ohaHSP;o000000KoRUF;
o`000?l0003oRUB;o`000?n;EX`2o`0000;oTf6B0_l000001OnY_NSo0000o`000?l0003oZKgX00?o
000000?oZKgXo`000?l000001ol000000onY_NSo0000o`000004o`000005ojVmj?l0003o0000o`00
0?nY_NP00ol000000onX_NWo0000o`000007o`000003ojRnjOl0003o000000Co000000GoYkkZo`00
0?l0003o0000ojNnjP03o`000005ojJnjol0003o0000o`000?nV_n/08_l00005ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00_ooool001Kooooo00?o0000ooooooooool09?oo
ool3o`0000Sooooo00?o0000ojRmjOl000000_l000001OnW_NWo0000o`000?l0003oYkgY01go0000
00GoY[_Yo`000?l0003o0000oj>hj003o`000003ojW2k?l0003o000000;o000000OoVJWQo`000?l0
003o0000ojK4k_l0003o]mG_00Go000000?oL7K9o`000?l000000_l000000omYIK[o0000o`000007
o`000003oheLT_l0003oS5R>00;o000000KoRUF;o`000?l0003oRUB;o`000?n;EX`2o`0000;oTf6B
0ol000001OnY_NSo0000o`000?l0003oZKgX00Go000000GoZKgXo`000?l0003o0000ojVmj006o`00
0005ojVmj?l0003o0000o`000?nY_NP02Ol000000onY_NSo0000o`000008o`000005ojRnjOl0003o
0000o`000?nX_^T00ol000000onW_^[o0000o`00000>o`000005ojFok?l0003o0000o`000?nU_n`0
0ol000000onT`>go0000o`000008o`000005oj?1k_l0003o0000o`000?nS`Nh00_l00004ooooo`04
o`000?ooooooooooo`0000Sooooo0_l00004ooooo`005Oooool00ol0003oooooooooo`0Rooooo`?o
00003?ooool;o`000005ojNmjOl0003o0000o`000?nW_NT00ol000001OnW_NWo0000o`000?l0003o
YkgY00;o000000GoYkgYo`000?l0003o0000ojJlj@0<o`000003ojFmjol0003o000000Ko000000?o
VZgTo`000?l000000ol000001?nY_n[o0000o`000?n6Rm04o`000003odQOaol0003o000000;o0000
00?oS9cMo`000?l000001_l000001?n<F8ko0000o`000?n:EH/2o`000007ohYDRol0003oReJ<o`00
0?n>FHko0000oi=QTP0:o`000005ojVmj?l0003o0000o`000?nY_NP01_l000001OnY_NSo0000o`00
0?l0003oZKgX00Go000000GoZKgXo`000?l0003o0000ojVmj006o`000005ojVmj?l0003o0000o`00
0?nX_NT00ol000000onX_^Wo0000o`000007o`000003ojRnjOl0003o000000Co000000GoYkkZo`00
0?l0003o0000ojJnj`03o`000003ojJojol0003o000000So000000GoY;o]o`000?l0003o0000ojC0
k@09o`0000Gooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo000Eooooo`;o00008?ooool3
o`00017ooooo0ol000000onX_NWo0000o`000004o`000005ojNmjOl0003o0000o`000?nW_NT00ol0
00000onW_NWo0000o`000004o`000005ojJljOl0003o0000o`000?nV_>T00ol000001OnW_^[o0000
o`000?l0003oY;WX00Ko000000?oYKcYo`000?l000002ol000001OmnQm?o0000o`000?l0003oKFk2
00Wo000000?o`n3^o`000?l000000ol000001?n<F8ko0000o`000?n:EH/2o`000005ohYDRol0003o
ReJ<o`000?n>FHh00_l000001?od_Y;o0000o`000?nY_NP3o`000005ojVmj?l0003o0000o`000?nY
_NP01_l000000onY_NSo0000o`000007o`000005ojVmj?l0003o0000o`000?nY_NP01_l000001OnY
_NSo0000o`000?l0003oZKgX00Wo000000?oZ;gYo`000?l000002?l000001OnX_^Wo0000o`000?l0
003oYkkZ01So000000?oYKo/o`000?l000001Ol0000Eooooo`005Oooool00ol0003oooooooooo`0L
ooooo`?o00005Oooool3o`000004ojRmjOl0003o0000ojNmj@?o000000GoYkgYo`000?l0003o0000
ojNmj@03o`000004ojNmjOl0003o0000ojNmj@?o000000GoY[cYo`000?l0003o0000ojJmjP03o`00
0003ojJljOl0003o000000Co000000GoZ<7/o`000?l0003o0000oinbi@04o`000003ojG4kol0003o
000000So000000?oIgC<o`000?l000002ol000001?n2EiOo0000o`000?n<F8h2o`000008ohYERol0
003o0000ohYDRol0003oReJ<o`000?n>FHh6o`000005ojVmj?l0003o0000o`000?nY_NP03?l00000
1OnY_NSo0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l000001?l000000onY_NSo0000o`00
0007o`000005ojVmj?l0003o0000o`000?nY_NP01_l000001OnX_NWo0000o`000?l0003oZ;kY013o
000000GoYkkZo`000?l0003o0000ojNnj`03o`000003ojJojol0003o000000So00000_ooool00ol0
003oooooooooo`0Dooooo`005Oooool00ol0003oooooooooo`0Iooooo`?o00006Oooool3o`000004
ojRmjOl0003o0000ojNmjA[o000000CoYK[Xo`000?l0003oY[kZ0ol000000onW_NWo0000o`000002
o`000003oibai_l0003o000000?o000000?oZ/3Yo`000?l000000ol000000omcNlgo0000o`000002
o`000003ogJDhol0003o000000?o000000?oa^O^o`000?l000001Ol000001?n<F8ko0000o`000?n:
EH/2o`000005ohYDRol0003oReJ<o`000?n>FHh00ol000001OnY_NSo0000o`000?l0003oZKgX00co
000000GoZKgXo`000?l0003o0000ojVmj003o`000003ojVmj?l0003o000000[o000000GoZKgXo`00
0?l0003o0000ojVmj00:o`000003ojVmj?l0003o000000Oo000000?oZ;gYo`000?l000002?l00000
1OnX_^Wo0000o`000?l0003oYkkZ00ko00001Oooool00ol0003oooooooooo`0Dooooo`005Oooool0
0ol0003oooooooooo`0Fooooo`?o00007Oooool9o`000004ojNmjOl0003o0000ojNmj@?o000000Go
YkgYo`000?l0003o0000ojNlj@03o`000004ojNmjOl0003o0000ojNmjAOo000000CoV:OQo`000?l0
003oOXOB1?l000000om/Q]_o0000o`000004o`000003ol[`k?l0003o000000Ko000000CoS5R>o`00
0?l0003oRUF;0_l000001On:E8_o0000oh]FS?l0003oSUV>00Co000000?oZKgXo`000?l000002_l0
00001OnY_NSo0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l000001_l000001OnY_NSo0000
o`000?l0003oZKgX00?o000000?oZKgXo`000?l000001?l000000onY_NSo0000o`000007o`000005
ojVmj?l0003o0000o`000?nY_NP01_l000001OnX_NWo0000o`000?l0003oZ;kY013o00002oooool0
0ol0003oooooooooo`0Cooooo`005Oooool2o`0001Gooooo0_l0000Qooooo`03o`000?nX_NWo0000
00;o000000GoYkgYo`000?l0003o0000ojNmj@02o`000005ojNmjOl0003o0000o`000?nW_NT00ol0
00000onW_>Wo0000o`000004o`000005ojJljOl0003o0000o`000?nU^nT00ol000001_nX`>_o0000
o`000?nQ]>Ko0000oijai@?o000000?oY/;^o`000?l000002Ol000000omePm?o0000o`000007o`00
0003okgHk_l0003o000000Co000000GoSEbBo`000?l0003o0000ohYER`02o`000004ohYDRol0003o
ReJ<oh]FS0;o000000?om;jBo`000?l000000ol000000onY_NSo0000o`000004o`000005ojVmj?l0
003o0000o`000?nY_NP03?l000001OnY_NSo0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l0
00002_l000001OnY_NSo0000o`000?l0003oZKgX00[o000000?oZKgXo`000?l000001ol000000onX
_^Wo0000o`000004o`000004ojRnjOl0003o0000o`0000kooooo00?o0000ooooooooool04oooool0
0004ooooool0003o0000o`0000?ooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`0B
ooooo`?o00009?ooool00ol0003oZ;gYo`000002o`000003ojNmjOl0003o000000Co000000GoYkgY
o`000?l0003o0000ojNlj@03o`000004ojNmjOl0003o0000ojNmj@?o000000GoYK[Xo`000?l0003o
0000ojJnjP03o`000003ojNmjOl0003o000000So000000?oZl;[o`000?l000001?l000000omgQMGo
0000o`00000@o`000005oheLT_l0003o0000o`000?n:EH/00_l000001?n:E8_o0000oh]FS?n;EX`5
o`000003ojVmj?l0003o000000Co000000GoZKgXo`000?l0003o0000ojVmj00<o`000005ojVmj?l0
003o0000o`000?nY_NP00ol000000onY_NSo0000o`00000:o`000005ojVmj?l0003o0000o`000?nY
_NP01_l000000onY_NSo0000o`000007o`000005ojVmj?l0003o0000o`000?nY_NP01_l000001?nX
_^Wo0000o`000?l0000Aooooo`03o`000?oooooooooo01?ooooo0002ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
4Oooool3o`0002Sooooo9_l000001OnP]^So0000o`000?l0003o[/__00Co000000GoTj3Mo`000?l0
003o0000ogb;e`0:o`000003ol3Mk_l0003o000000;o000000Go[lGZo`000?l0003o0000oheLTP03
o`000005ohYERol0003o0000ohYDRol000000_n;EX`9o`000003ojVmj?l0003o000000Oo000000?o
ZKgXo`000?l000001?l000001OnY_NSo0000o`000?l0003oZKgX00Wo000000?oZKgXo`000?l00000
1?l000001OnY_NSo0000o`000?l0003oZKgX00co000000GoZKgXo`000?l0003o0000ojVmj00:o`00
0004ojVmj?l0003o0000o`0001Cooooo00?o0000ooooooooool04oooool000;ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`;o00003Ooo
ool3o`0002gooooo0_l000001OnX_NWo0000o`000?l0003oYkgY00?o000000CoYkgYo`000?l0003o
YkcY0ol000001OnW_NWo0000o`000?l0003oY[cX00Ko000000GoZ;oZo`000?l0003o0000oj>fi`04
o`000003ojJok?l0003o000001go000000GoSEbBo`000?l0003o0000ohYER`02o`000004ohYDRol0
003oReJ<oh]FS0co000000GoZKgXo`000?l0003o0000ojVmj006o`000003ojVmj?l0003o000000Oo
000000?oZKgXo`000?l000002?l000001OnY_NSo0000o`000?l0003oZKgX00co000000GoZKgXo`00
0?l0003o0000ojVmj00>o`0001Oooooo00?o0000ooooooooool04oooool000;ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000002ooo
ool3o`00037ooooo0_l000001OnX_NWo0000o`000?l0003oYkgY00Ko000000GoYkgYo`000?l0003o
0000ojNmj@03o`000004ojJkj?l0003o0000ojNnjP?o000000GoYkgYo`000?l0003o0000oj2diP06
o`000003ojc3jol0003o000000oo000000?o`n;^o`000?nid^d00_l000000onaan[o0000o`000007
o`000003ohYERol0003o000000;oRUB;00?o0000oh]FS?l000002?l000001OnY_NSo0000o`000?l0
003oZKgX00?o000000?oZKgXo`000?l000001_l000001OnY_NSo0000o`000?l0003oZKgX00Ko0000
00GoZKgXo`000?l0003o0000ojVmj00@o`000005ojVmj?l0003o0000o`000?nY_NP03?l000000ooo
oooo0000ooooo`0Iooooo`03o`000?oooooooooo01?ooooo0002ooooo`04o`000?oooooooooooooo
o`Co00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Kooooo0ol0000e
ooooob3o000000CoX[OXo`000?l0003o[LO]4ol000000oo6j>ko0000o`000006o`000003ojc0jOl0
003o000000Co000000?oRUF;o`000?l000000_n:E8/00ol0003oReJ<o`000002o`000004ojVmj?l0
003o0000ojVmj0?o000000?oZKgXo`000?l000002_l000001OnY_NSo0000o`000?l0003oZKgX00?o
000000CoZKgXo`000?l0003oZKgX2Ol000000onY_NSo0000o`000004o`000005ojVmj?l0003o0000
o`000?nY_NP03?l000001?nY_NSo0000o`000?l00004ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool04oooool00003ooooool0003o000000?ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo0ol0000iooooo`05o`000?nX
_NWo0000o`000?nW_NT00ol000001OnW_NWo0000o`000?l0003oYkgY00;o000000GoYkcXo`000?l0
003o0000ojJlj@03o`000004ojRnj_l0003o0000ojBhi`go000000CoSikMo`000?l0003oQYKL1?l0
00000on^f?Ko0000o`000009o`000003ojo4jOl0003o000000Oo000000?oRUF;o`000?l000000_n:
E8/01?l0003oReJ<o`000?oe_I0;o`000005ojVmj?l0003o0000o`000?nY_NP00_l000001OnY_NSo
0000o`000?l0003oZKgX00co000000GoZKgXo`000?l0003o0000ojVmj006o`000003ojVmj?l0003o
000000Oo000000?oZKgXo`000?l000001?l000001?nY_NSo0000o`000?l00008ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool04_ooool000;ooooo00Co0000oooooooooooooooo1Ol0
0003ooooo`;o00000oooool2o`0000;ooooo0ol0000mooooo`Co000000GoYkgYo`000?l0003o0000
ojNmj@06o`000005ojJkj?l0003o0000o`000?nW_NT01_l000000onR]^Oo0000o`000005o`000003
ojc4jol0003o000000Oo000000?oTjoZo`000?l000001?l000001_o5jNoo0000o`000?nkeNgo0000
ok?:j`Go000000?oZkoXo`000?l000000ol000002?n;EXco0000o`000?n:E8_o0000ohYDRol0003o
ReJ<1_l000001OnY_NSo0000o`000?l0003oZKgX00?o000000?oZKgXo`000?l000002_l000000onY
_NSo0000o`000004o`000005ojVmj?l0003o0000o`000?nY_NP03?l000001OnY_NSo0000o`000?l0
003oZKgX00Ko000000CoZKgXo`000?l0003o00003?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01;ooooo000Cooooo`Co0000@?oooolKo`000005oj>hj?l0003o0000o`000?n[aN`0
6ol000000on]`^Wo0000o`000006o`000003oh]FS?l0003oRUF;00;o000000?oRUB;o`000?n;EX`0
1ol000001OnY_NSo0000o`000?l0003oZKgX00So000000GoZKgXo`000?l0003o0000ojVmj006o`00
0003ojVmj?l0003o000000ko000000GoZKgXo`000?l0003o0000ojVmj00:o`00013ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Booooo`004oooool2o`0004Cooooo0ol000001?nW
_NWo0000o`000?nW_NT3o`000005ojNlj?l0003o0000o`000?nW_>T00_l000001OnX_^Wo0000o`00
0?l0003oYKWX00[o000000?oY;WWo`000?l000003ol000001OnmfNko0000okK>k?l0003o/<KZ00?o
000000?o[<3Yo`000?l000001Ol000000on;EXco0000ohYER`02o`000003ohYDRol0003oReJ<00ko
000000CoZKgXo`000?l0003oZKgX0ol000001OnY_NSo0000o`000?l0003oZKgX00So000000GoZKgX
o`000?l0003o0000ojVmj006o`000003ojVmj?l0003o000000[o00005Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01;ooooo000Eooooo`03o`000?oooooooooo04;ooooo1_l00000
1OnW_NWo0000o`000?l0003oYkcX00[o000000CoXkSWo`000?l0003oY[kZ2?l000000onFY^7o0000
o`00000Bo`000003ojk3jOl0003o000000?o000000?oZ[kXo`000?l000000_l000000on;EXco0000
ohYER`02o`000003ohYDRol0003oReJ<00Oo000000GoZKgXo`000?l0003o0000ojVmj00Co`000005
ojVmj?l0003o0000o`000?nY_NP03?l000000onY_NSo0000o`000004o`0001Wooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Booooo`005_ooool00ol0003oooooooooo`12ooooob;o
000000?oSj7Qo`000?n@YN<00_l000000on[cO7o0000o`000006o`000003okSAkOl0003o//S[00Go
000000?oZkoXo`000?l000001Ol000000on;EXco0000ohYER`02o`000003ohYDRol0003oReJ<00Co
000000GoZKgXo`000?l0003o0000ojVmj008o`000005ojVmj?l0003o0000o`000?nY_NP01_l00000
0onY_NSo0000o`00000>o`000003ojVmj?l0003o000000Co00007Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01;ooooo000Gooooo`03o`000?oooooooooo04;ooooo00?o0000ojRm
jOl000001Ol000001OnW_>Wo0000o`000?l0003oZ;kY00;o000000GoYK[Xo`000?l0003o0000ojBj
j003o`000004oj[3jol0003o0000ojNlj1Wo000000?o[L7Yo`000?l000002?l000000on;EXco0000
ohYER`02o`000003ohYDRol0003oReJ<00_o000000?oZKgXo`000?l000001?l000001OnY_NSo0000
o`000?l0003oZKgX00So000000GoZKgXo`000?l0003o0000ojVmj006o`000003ojVmj?l0003o0000
00Co00008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo000Hooooo`;o
0000@ooooolCo`000003ojJmjOl0003o000000co000000?oVkCZo`000?l000002ol000000on_aN[o
0000o`000003o`000005oj^oj?l0003o0000o`000?nZ_^P00ol000000on;EXco0000ohYER`02o`00
0004ohYDRol0003o0000ooFnTP?o000000GoZKgXo`000?l0003o0000ojVmj00Co`000005ojVmj?l0
003o0000o`000?nY_NP03?l0000Uooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
4Oooool001[ooooo00?o0000ooooooooool0@_ooool2o`000003ojNlj?l0003o000000Co000000Go
YkcXo`000?l0003o0000ojBij006o`000003oj_2jol0003o000000;o000000?oVjcSo`000?l00000
3Ol000000onidngo0000ok?;j`05o`000003ojc0jOl0003o000000So000000?oReJ<o`000?n:EH/0
0_l000000on:E8_o0000o`00000Bo`000005ojVmj?l0003o0000o`000?nY_NP00_l000000onY_NSo
0000o`00000:o`000004ojVmj?l0003o0000o`0002Wooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Aooooo`006oooool00ol0003oooooooooo`12ooooo`;o000000?oYkcYo`000?l0
00002?l000001?nU^^So0000o`000?nY`N/8o`000003oiNXh_l0003o0000017o000000?o[/?Yo`00
0?l000000ol000001OnZ_^So0000o`000?l0003oZ[kX00?o000000?oReJ<o`000?n:EH/00_l00000
0on:E8_o0000o`000004o`000005ojVmj?l0003o0000o`000?nY_NP01_l000000onY_NSo0000o`00
000:o`000005ojVmj?l0003o0000o`000?nY_NP00_l000001?nY_NSo0000o`000?l0000]ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool001cooooo00?o0000ooooooooool0
@Oooool5o`000003ojRmjOl0003o000000_o000000?oZ;gYo`000?l000001?l000000onEZ>?o0000
o`000002o`000003ojS5k_l0003o]]Oa00Co000000?o^]G]o`000?l000001ol000001On[_nSo0000
o`000?l0003oZ[kX00Ko000000?oReJ<o`000?n:EH/00_l000000on:E8_o0000o`000005o`000003
ojVmj?l0003o000000[o000000?oZKgXo`000?l000001?l000001OnY_NSo0000o`000?l0003oZKgX
00Ko0000<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo000Mooooo`03
o`000?oooooooooo047ooooo00?o0000ojRmjOl000000_l000001?nW_NWo0000o`000?nU^^P3o`00
0003ojNmjOl0003o000000Co000000?oXkOWo`000?l000004Ol000000onecNco0000o`00000<o`00
0007ojZmj?l0003o0000o`000?n;EXco0000ohYER`02o`000003ohYDRol0003o000000So000000?o
ZKgXo`000?l000001?l000001OnY_NSo0000o`000?l0003oZKgX00co0000=Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo017ooooo000Nooooo`;o0000@_ooool>o`000003oj[1j_l0
003o000000So000000?oWKCXo`000?l000001?l000000onkf^oo0000o`000006o`000003ojo4j_l0
003o000000Ko000000GoZ[kXo`000?l0003o0000ojVmj002o`000003oh]FS?l0003oRUF;00;o0000
00?oRUB;o`000?oe_Y801Ol000001OnY_NSo0000o`000?l0003oZKgX00oo000000CoZKgXo`000?l0
003o0000>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000Pooooo`03
o`000?oooooooooo047ooooo0_l000001OnV^nSo0000o`000?l0003oYK_X00;o000000?oZL3Zo`00
0?l000005_l000000onfcnco0000ok;9j`05o`000003ojc0jOl0003o000000[o000000?oReJ<o`00
0?n:EH/00_l000000on:E8_o0000o`00000?o`000005ojVmj?l0003o0000o`000?nY_NP01_l0000m
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool0027ooooo00?o0000oooo
ooooool0@Oooool;o`000003ojRnjOl0003o000000;o000000?oVjkTo`000?l000001_l000000ona
cnoo0000o`00000:o`000003ojg2jOl0003o000000?o000000CoZ[kXo`000?l0003oZ[kX0ol00000
1_nY_NSo0000o`000?n;EXco0000ohYER`;o000000?oRUB;o`000?l000001Ol000001OnY_NSo0000
o`000?l0003oZKgX00co0000@Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo000Rooooo`03o`000?oooooooooo047ooooo1?l000001OnW_NWo0000o`000?l0003oZ/7Z00;o
000000?oYKWWo`000?l000000_l000000onJ[NCo0000o`000002o`000003ojK0k?l0003o000000[o
000000?o/<KZo`000?l000000ol000000on[_nSo0000o`00000:o`000003oh]FS?l0003oRUF;00?o
000000?ol/6Ko`000?l000003_l000001?nY_NSo0000o`000?l00015ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04?ooool002?ooooo0_l00011oooooa7o000000?oVk3Vo`000?l0
00001ol000000onie>ko0000okO@k@0=o`000004ojZnj?l0003o0000ojZnj0?o000000?oZKgXo`00
0?l000000_l000000on:EH_o0000o`000005o`000004ojVmj?l0003o0000ojVmj0?o000000?oZKgX
o`000?l000001?l00019ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool0
02Gooooo00?o0000ooooooooool0@?ooool2o`000003ojVoj_l0003o000000_o000000?oW[CXo`00
0?l000004ol000000on[_nSo0000o`00000<o`000003ohYERol0003o000000;o000000?oZKgXo`00
0?l000002_l0001=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool002Ko
oooo00?o0000ooooooooool0@?ooool4o`000003ojRnjOl0003o000000;o000000?oW[7Uo`000?l0
00001_l000000on]b>go0000okGAkP0:o`000003ojk3jOl0003o000000Ko000000?oZ[kXo`000?l0
00001?l000000onY_NSo0000o`000002o`000004ohYERol0003o0000oo;1V`Co000000CoZKgXo`00
0?l0003oZKgX0ol0001Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool0
02Oooooo00?o0000ooooooooool0@?oooolIo`000003okC;k?l0003o/LOZ00Go000000Co[<3Yo`00
0?l0003oZ[kX3?l000000onY_NSo0000ohYER`0;o`0005Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0@ooooo`00:?ooool2o`00047ooooo0ol000000onV^nSo0000o`00000?o`00
0003okK?kOl0003o000000Go000000?o[L;Yo`000?l000001_l000001OnZ_^So0000o`000?l0003o
ZKgX00Oo000000GoRUF;o`000?l0003o0000ojVmj003o`0005[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0@ooooo`00:_ooool00ol0003oooooooooo`0oooooo`Oo000000?oW[;V
o`000?l000005Ol000000on[_nSo0000o`00000=o`000005ojVmj?l0003o0000o`000?oTb[h00_l0
001Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool002_ooooo00?o0000
ooooooooool0?oooool00ol0003oXkOWo`00000Eo`000003ojo4j_l0003o000000Ko000000CoZ[kX
o`000?l0003oZ[kX3_l0001Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03ooo
ool002cooooo00?o0000ooooooooool0?oooool00ol0003oXKCVo`000003o`000006oj6fj?l0003o
0000oj[3k?l0003o/Lc]1?l000001Onfcngo0000okC<k?l0003o/LS[017o000000GoZKgXo`000?l0
003o0000ojVmj002o`0000Cooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00oooooo000]ooooo`03o`000?oooooooooo03oooooo5_l000000on^`nWo
0000o`000006o`000003ojZnj?l0003o000000So0000J?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00oooooo000^ooooo`;o0000@?oooolQo`000003ojVmj?l0003o000006kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`00<?ooool00ol0003ooooooooo
o`0noooooa7o000000?o[lGZo`000?l000000_l000001On[`>So0000o`000?l0003oZ[kX00Ko0000
LOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo000aooooo`03o`000?oo
oooooooo03kooooo2Ol000001OndcNco0000ok?;k?l0003o//S[00ko0000M_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00oooooo000booooo`03o`000?oooooooooo03kooooo0ol0
00000on^anco0000o`00000Bo`0007Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0>ooooo`00<oooool2o`0003oooooo3Ol000000on^`nWo0000o`000004o`0007gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0>ooooo`00=Oooool00ol0003oooooooooo`0moooo
o`[o000000?o/<KZo`000?l000000_l00022ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03_ooool003Kooooo00?o0000ooooooooool0?_ooool5o`000003ok;8jol0003o000000?o
0000QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo000gooooo`03o`00
0?oooooooooo03kooooo00?o0000ok?:k?l000001?l00028ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03_ooool003Sooooo0_l0000oooooo`?o0000S?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00kooooo000jooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool0S?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo000koooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00gooooo000looooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0SOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo000mooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00gooooo000nooooo`;o0000>_ooool00ol0003oooooooooo`2?ooooo`05o`000?oo
ooooooooooooool000003oooool0043ooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`2?ooooo`05o`000?ooooooooooooooool000003oooool0047ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`2@ooooo`04o`000?ooooooooooo`0000oooooo0012ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0TOooool00ol0003oooooo`00000?ooooo`00@oooool2
o`0003Gooooo00?o0000ooooooooool0TOooool01?l0003oooooooooool0000>ooooo`00AOooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo09;ooooo00?o0000ooooool000003_ooool0
04Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Cooooo`;o00003_ooool004Oo
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Cooooo`?o00003_ooool004Sooooo
0_l0000_ooooo`03o`000?oooooooooo08oooooo1?l0000Aooooo`00B_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo08_ooooo1?l0000Eooooo`00Boooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo08Sooooo0ol0000Iooooo`00C?ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo08Cooooo1?l0000Looooo`00COooool2o`0002[ooooo00?o0000oooooooo
ool0P?ooool4o`00023ooooo001?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
O?ooool4o`0002Cooooo001@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?oo
ool4o`0002Sooooo001Aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4
o`0002cooooo001Booooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool3o`00
033ooooo001Cooooo`;o00009?ooool00ol0003oooooooooo`1]ooooo`Co0000<oooool005Gooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Yooooo`Co0000=oooool005Kooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`1Uooooo`Co0000>oooool005Oooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1Qooooo`Co0000?oooool005Sooooo0_l0000Ooooo
o`03o`000?oooooooooo05kooooo0ol00013ooooo`00F_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo05[ooooo1?l00016ooooo`00Foooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo05Kooooo1?l0001:ooooo`00G?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo05;ooooo1?l0001>ooooo`00GOooool2o`0001[ooooo00?o0000ooooooooool0C_ooool4
o`0005;ooooo001Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B_ooool4o`00
05Kooooo001Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool3o`0005[o
oooo001Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool4o`0005gooooo
001Rooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4o`00067ooooo001S
ooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`Co0000IOooool006Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0gooooo`Co0000JOooool006Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0cooooo`Co0000KOooool006Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0`ooooo`?o0000LOooool006Sooooo0_l0000>ooooo`03o`000?oo
oooooooo02gooooo1?l0001dooooo`00J_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02Wooooo1?l0001hooooo`00Joooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Gooooo1?l0001looooo`00K?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027o
oooo1?l00020ooooo`00KOooool2o`0000Wooooo00?o0000ooooooooool07_ooool3o`0008Cooooo
001_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool4o`0008Oooooo001`
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`0008_ooooo001aoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`0008oooooo001booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`0009?ooooo001cooooo`;o0000
0oooool00ol0003oooooooooo`0:ooooo`Co0000Uoooool007Gooooo00Co0000oooooooooooo0000
2Oooool3o`0009_ooooo001fooooo`03o`000?oooooo000000Gooooo1?l0002Nooooo`00Moooool2
o`000003ooooool0003o000000;o0000X_ooool007Sooooo0_l0002Vooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.073831, -0.00727976, \
0.00375165, 0.00375165}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell[TextData[{
  "Here is a similar intensity plot using the ",
  StyleBox["ContourPlot", "Input"],
  " function. The horizontal dimension is measured along the optical axis of \
the system. The plot has been a thresholded in order to observe the \
low-intensity details."
}], "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
ContourPlot[intensity[x,y], {x,-1, 1}, {y,-.05,.05}, PlotPoints->100, \
PlotRange->{0,50}, Contours->30, ContourLines->False, \
ColorFunction->Function[Hue[.65-#*(.65),1,#*.9+.1]]];\
\>", "Input",
  CellLabel->"In[84]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 9.61538 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.25962 -0.0125 -12 -9 ]
[.25962 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -9 -9 ]
[.74038 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11538 -30 -4.5 ]
[-0.0125 .11538 0 4.5 ]
[-0.0125 .30769 -30 -4.5 ]
[-0.0125 .30769 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .69231 -24 -4.5 ]
[-0.0125 .69231 0 4.5 ]
[-0.0125 .88462 -24 -4.5 ]
[-0.0125 .88462 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-0.5)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(0.5)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11538 m
.00625 .11538 L
s
[(-0.04)] -0.0125 .11538 1 0 Mshowa
0 .30769 m
.00625 .30769 L
s
[(-0.02)] -0.0125 .30769 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .69231 m
.00625 .69231 L
s
[(0.02)] -0.0125 .69231 1 0 Mshowa
0 .88462 m
.00625 .88462 L
s
[(0.04)] -0.0125 .88462 1 0 Mshowa
.125 Mabswid
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .25962 m
.00375 .25962 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .74038 m
.00375 .74038 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .06731 m
.00375 .06731 L
s
0 .01923 m
.00375 .01923 L
s
0 .93269 m
.00375 .93269 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .06731 m
1 .06731 L
s
.99625 .01923 m
1 .01923 L
s
.99625 .93269 m
1 .93269 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .093 .19 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 .136 .22 r
.01923 .03198 m
.02769 .03866 L
.02894 .03965 L
.03866 .04733 L
.03997 .04837 L
.04837 .05503 L
.05221 .05808 L
.05808 .06275 L
.06443 .06779 L
.06779 .07047 L
.07667 .07751 L
.07751 .07817 L
.08722 .08584 L
.08897 .08722 L
.09693 .09351 L
.10126 .09693 L
.10664 .10121 L
.11345 .10664 L
.11636 .10897 L
.12559 .11636 L
.12607 .11673 L
.13578 .12444 L
.13785 .12607 L
.14549 .13206 L
.15028 .13578 L
.15521 .13963 L
.16267 .14549 L
.16492 .14729 L
.17463 .1551 L
.17476 .15521 L
.18434 .163 L
.18672 .16492 L
.19406 .17074 L
.19908 .17463 L
.20377 .17821 L
.21195 .18434 L
.21348 .1855 L
.22319 .19298 L
.22456 .19406 L
.23291 .20092 L
.23627 .20377 L
.24262 .20916 L
.24779 .21348 L
.25233 .21709 L
.26059 .22319 L
.26204 .22423 L
.27176 .23097 L
.2746 .23291 L
.28147 .2379 L
.28747 .24262 L
.29118 .24587 L
.29801 .25233 L
.30089 .25505 L
.3087 .26204 L
.31061 .26359 L
.32032 .2703 L
.32289 .27176 L
.33003 .27602 L
.33939 .28147 L
.33974 .2817 L
.34946 .2889 L
.35191 .29118 L
.35917 .30011 L
.35974 .30089 L
.36888 .31023 L
.36942 .31061 L
.37859 .3169 L
.38754 .32032 L
.38831 .32067 L
.39802 .32493 L
.40773 .32967 L
.40833 .33003 L
.41744 .33842 L
.41813 .33974 L
.4212 .34946 L
.42716 .3569 L
.43052 .35917 L
.43687 .36347 L
.44658 .36729 L
.45629 .36872 L
.45951 .36888 L
.46601 .37043 L
.47572 .37221 L
.4851 .37859 L
.48543 .37896 L
.48706 .38831 L
.48543 .39117 L
.48294 .39802 L
.48543 .40372 L
.49284 .40773 L
.49514 .40834 L
.50486 .41024 L
.51457 .4115 L
.52428 .41241 L
.53399 .41551 L
.54371 .41571 L
.55342 .41589 L
.56313 .41615 L
.57284 .41656 L
.58256 .41711 L
.59227 .41744 L
.60198 .41704 L
.61169 .41458 L
.6202 .40773 L
.61737 .39802 L
.6172 .38831 L
.62141 .38472 L
.63112 .37982 L
.6342 .37859 L
.64083 .37638 L
.65054 .37322 L
.66026 .36927 L
.66105 .36888 L
.66997 .36399 L
.67588 .35917 L
.67968 .35254 L
.68084 .34946 L
.68662 .33974 L
.68939 .33703 L
.69911 .33099 L
.701 .33003 L
.70882 .32607 L
.71853 .32069 L
.71913 .32032 L
.72824 .31429 L
.73236 .31061 L
.73796 .30447 L
.74116 .30089 L
.74767 .29401 L
.7507 .29118 L
.75738 .28601 L
.76399 .28147 L
.76709 .27946 L
.77681 .27307 L
.77871 .27176 L
.78652 .26605 L
.79151 .26204 L
.79623 .25792 L
.80252 .25233 L
.80594 .2493 L
.81386 .24262 L
.81566 .2412 L
.82537 .23385 L
.82665 .23291 L
.83508 .2268 L
.84 .22319 L
.84479 .2196 L
.85273 .21348 L
.85451 .21207 L
.86422 .20427 L
.86484 .20377 L
.87393 .19652 L
.87707 .19406 L
.88364 .18902 L
.88983 .18434 L
.89336 .18171 L
.90283 .17463 L
.90307 .17445 L
.91278 .16713 L
.91569 .16492 L
.92249 .15971 L
.92839 .15521 L
.93221 .15229 L
.94117 .14549 L
.94192 .14493 L
.95163 .13767 L
.95417 .13578 L
.96134 .13047 L
.96731 .12607 L
.97106 .12331 L
.98048 .11636 L
.98077 .11614 L
.98077 .98077 L
.01923 .98077 L
F
0 .188 .25 r
.01923 .04991 m
.02894 .05722 L
.03009 .05808 L
.03866 .06455 L
.04295 .06779 L
.04837 .07189 L
.0558 .07751 L
.05808 .07923 L
.06779 .08655 L
.06868 .08722 L
.07751 .09388 L
.08155 .09693 L
.08722 .10124 L
.09432 .10664 L
.09693 .10864 L
.10664 .11608 L
.107 .11636 L
.11636 .12349 L
.11975 .12607 L
.12607 .13084 L
.13265 .13578 L
.13578 .13814 L
.14549 .14546 L
.14554 .14549 L
.15521 .15291 L
.15816 .15521 L
.16492 .16047 L
.17062 .16492 L
.17463 .16801 L
.18337 .17463 L
.18434 .17536 L
.19406 .18251 L
.19658 .18434 L
.20377 .18963 L
.20968 .19406 L
.21348 .197 L
.22199 .20377 L
.22319 .20475 L
.23291 .21263 L
.23397 .21348 L
.24262 .22008 L
.24695 .22319 L
.25233 .22695 L
.26116 .23291 L
.26204 .23351 L
.27176 .24044 L
.27463 .24262 L
.28147 .24833 L
.28595 .25233 L
.29118 .25702 L
.297 .26204 L
.30089 .26508 L
.31061 .27152 L
.31101 .27176 L
.32032 .27731 L
.32756 .28147 L
.33003 .28301 L
.33974 .29003 L
.34108 .29118 L
.34946 .3003 L
.34994 .30089 L
.35917 .31017 L
.3597 .31061 L
.36888 .31695 L
.37692 .32032 L
.37859 .32111 L
.38831 .32546 L
.3979 .33003 L
.39802 .33009 L
.40773 .33742 L
.40945 .33974 L
.41372 .34946 L
.41744 .35499 L
.4225 .35917 L
.42716 .36267 L
.43687 .36712 L
.44658 .36875 L
.44895 .36888 L
.45629 .37088 L
.46601 .37346 L
.47572 .37839 L
.47591 .37859 L
.48055 .38831 L
.47773 .39802 L
.48543 .40748 L
.48599 .40773 L
.49514 .41019 L
.50486 .41187 L
.51457 .41308 L
.52428 .41407 L
.53399 .41672 L
.54371 .41689 L
.55342 .41722 L
.55717 .41744 L
.56313 .41831 L
.57284 .42023 L
.58256 .42328 L
.5888 .42716 L
.58256 .43049 L
.57284 .43484 L
.56788 .43687 L
.56313 .43892 L
.55342 .44365 L
.54897 .44658 L
.54461 .45629 L
.55342 .45874 L
.56313 .45946 L
.57284 .45928 L
.58256 .45837 L
.59227 .45657 L
.5934 .45629 L
.60198 .45265 L
.60771 .44658 L
.60667 .43687 L
.6038 .42716 L
.61169 .42269 L
.62141 .42101 L
.62744 .41744 L
.63112 .41489 L
.6361 .40773 L
.63323 .39802 L
.63491 .38831 L
.64083 .38427 L
.65054 .37981 L
.65362 .37859 L
.66026 .37635 L
.66997 .37282 L
.67826 .36888 L
.67968 .36812 L
.68939 .36214 L
.69173 .35917 L
.6977 .34946 L
.69911 .34742 L
.70574 .33974 L
.70882 .33734 L
.71853 .33153 L
.7214 .33003 L
.72824 .32654 L
.73796 .32105 L
.73911 .32032 L
.74767 .31441 L
.75214 .31061 L
.75738 .30539 L
.7619 .30089 L
.76709 .29609 L
.773 .29118 L
.77681 .28843 L
.78652 .28201 L
.78738 .28147 L
.79623 .27588 L
.80247 .27176 L
.80594 .26934 L
.81566 .26211 L
.81574 .26204 L
.82537 .25426 L
.82777 .25233 L
.83508 .24662 L
.84043 .24262 L
.84479 .23952 L
.8544 .23291 L
.85451 .23284 L
.86422 .22627 L
.86871 .22319 L
.87393 .21955 L
.88247 .21348 L
.88364 .21263 L
.89336 .20559 L
.89588 .20377 L
.90307 .19865 L
.90964 .19406 L
.91278 .19191 L
.92249 .18535 L
.92399 .18434 L
.93221 .17889 L
.93863 .17463 L
.94192 .17245 L
.95163 .16602 L
.95329 .16492 L
.96134 .15961 L
.96808 .15521 L
.97106 .15328 L
.98077 .14709 L
.98077 .98077 L
.01923 .98077 L
F
0 .246 .28 r
.01923 .06674 m
.02072 .06779 L
.02894 .07359 L
.03448 .07751 L
.03866 .08046 L
.04819 .08722 L
.04837 .08735 L
.05808 .09425 L
.06184 .09693 L
.06779 .1012 L
.07536 .10664 L
.07751 .1082 L
.08722 .11525 L
.08875 .11636 L
.09693 .1223 L
.10213 .12607 L
.10664 .12933 L
.11562 .13578 L
.11636 .13631 L
.12607 .1433 L
.1291 .14549 L
.13578 .15037 L
.14234 .15521 L
.14549 .15756 L
.15521 .16481 L
.15535 .16492 L
.16492 .17199 L
.16855 .17463 L
.17463 .179 L
.18219 .18434 L
.18434 .18587 L
.19406 .1928 L
.19579 .19406 L
.20377 .2 L
.20869 .20377 L
.21348 .2075 L
.22115 .21348 L
.22319 .21504 L
.23291 .22215 L
.23439 .22319 L
.24262 .2288 L
.24885 .23291 L
.25233 .23524 L
.26204 .242 L
.26288 .24262 L
.27176 .24967 L
.2749 .25233 L
.28147 .25797 L
.28633 .26204 L
.29118 .26574 L
.30027 .27176 L
.30089 .27215 L
.31061 .27789 L
.31693 .28147 L
.32032 .28352 L
.33003 .29018 L
.33129 .29118 L
.33974 .29947 L
.34105 .30089 L
.34946 .3093 L
.35094 .31061 L
.35917 .31645 L
.3675 .32032 L
.36888 .32099 L
.37859 .32541 L
.38831 .32986 L
.38864 .33003 L
.39802 .33597 L
.40164 .33974 L
.40695 .34946 L
.40773 .35081 L
.41537 .35917 L
.41744 .36092 L
.42716 .36647 L
.43687 .36865 L
.43988 .36888 L
.44658 .37083 L
.45629 .37359 L
.46601 .37737 L
.46789 .37859 L
.47476 .38831 L
.473 .39802 L
.47572 .40471 L
.48008 .40773 L
.48543 .40957 L
.49514 .41179 L
.50486 .41333 L
.51457 .41455 L
.52428 .41562 L
.53399 .4173 L
.54016 .41744 L
.54371 .41789 L
.55342 .4194 L
.56313 .42169 L
.57283 .42716 L
.56313 .43645 L
.56247 .43687 L
.55342 .44151 L
.54592 .44658 L
.54371 .44845 L
.54123 .45629 L
.54371 .45758 L
.55342 .45969 L
.56313 .46024 L
.57284 .46003 L
.58256 .45917 L
.59227 .45754 L
.59733 .45629 L
.60198 .45446 L
.61134 .44658 L
.61169 .44596 L
.61336 .43687 L
.62091 .42716 L
.62141 .42693 L
.63112 .42401 L
.6404 .41744 L
.64083 .41715 L
.64832 .40773 L
.64693 .39802 L
.65054 .38862 L
.65085 .38831 L
.66026 .38139 L
.66997 .37877 L
.67056 .37859 L
.67968 .37539 L
.68939 .37119 L
.69359 .36888 L
.69911 .36607 L
.70627 .35917 L
.70882 .35588 L
.7132 .34946 L
.71853 .34371 L
.72322 .33974 L
.72824 .33646 L
.73796 .33116 L
.74016 .33003 L
.74767 .32621 L
.75738 .32065 L
.7579 .32032 L
.76709 .31386 L
.7711 .31061 L
.77681 .30546 L
.78196 .30089 L
.78652 .29718 L
.79472 .29118 L
.79623 .29018 L
.80594 .28416 L
.81048 .28147 L
.81566 .27841 L
.82537 .27247 L
.82649 .27176 L
.83508 .26602 L
.84076 .26204 L
.84479 .25914 L
.85434 .25233 L
.85451 .25221 L
.86422 .24569 L
.86901 .24262 L
.87393 .23959 L
.88364 .23379 L
.88514 .23291 L
.89336 .22809 L
.9017 .22319 L
.90307 .22239 L
.91278 .21663 L
.9181 .21348 L
.92249 .21092 L
.93221 .20535 L
.93501 .20377 L
.94192 .20005 L
.95163 .19508 L
.95365 .19406 L
.96134 .19045 L
.97106 .1862 L
.97582 .18434 L
.98077 .18241 L
.98077 .98077 L
.01923 .98077 L
F
0 .31 .307 r
.01923 .08377 m
.02465 .08722 L
.02894 .08994 L
.03866 .09619 L
.0398 .09693 L
.04837 .10252 L
.05462 .10664 L
.05808 .10895 L
.06779 .11545 L
.06914 .11636 L
.07751 .12201 L
.08351 .12607 L
.08722 .12858 L
.09693 .13514 L
.09788 .13578 L
.10664 .14171 L
.1122 .14549 L
.11636 .14834 L
.12607 .15509 L
.12624 .15521 L
.13578 .16194 L
.13998 .16492 L
.14549 .16882 L
.15378 .17463 L
.15521 .17562 L
.16492 .18228 L
.16796 .18434 L
.17463 .18888 L
.18218 .19406 L
.18434 .19557 L
.19406 .20254 L
.19573 .20377 L
.20377 .20977 L
.20873 .21348 L
.21348 .21696 L
.22231 .22319 L
.22319 .2238 L
.23291 .23022 L
.23709 .23291 L
.24262 .2365 L
.2517 .24262 L
.25233 .24307 L
.26204 .25043 L
.2644 .25233 L
.27176 .2584 L
.27623 .26204 L
.28147 .26596 L
.29019 .27176 L
.29118 .27237 L
.30089 .27807 L
.307 .28147 L
.31061 .28358 L
.32032 .28985 L
.32214 .29118 L
.33003 .2982 L
.33272 .30089 L
.33974 .30782 L
.34279 .31061 L
.34946 .31551 L
.35884 .32032 L
.35917 .32048 L
.36888 .32501 L
.37859 .32931 L
.38012 .33003 L
.38831 .33456 L
.39442 .33974 L
.39802 .34496 L
.40064 .34946 L
.40773 .35838 L
.40884 .35917 L
.41744 .36523 L
.42716 .36835 L
.43177 .36888 L
.43687 .37045 L
.44658 .37327 L
.45629 .3765 L
.46061 .37859 L
.46601 .38252 L
.46942 .38831 L
.46861 .39802 L
.47487 .40773 L
.47572 .40812 L
.48543 .41126 L
.49514 .41323 L
.50486 .41469 L
.51457 .41593 L
.52428 .4171 L
.52702 .41744 L
.53399 .41784 L
.54371 .41981 L
.55342 .42198 L
.56313 .42638 L
.56385 .42716 L
.56313 .43114 L
.55751 .43687 L
.55342 .43934 L
.54371 .44613 L
.54319 .44658 L
.53804 .45629 L
.54371 .45894 L
.55342 .46052 L
.56313 .46095 L
.57284 .46071 L
.58256 .4599 L
.59227 .45841 L
.60079 .45629 L
.60198 .45585 L
.61169 .45026 L
.61485 .44658 L
.61928 .43687 L
.62141 .43406 L
.63094 .42716 L
.63112 .42713 L
.64083 .42249 L
.65054 .41752 L
.65067 .41744 L
.65865 .40773 L
.65893 .39802 L
.66026 .39412 L
.66518 .38831 L
.66997 .38482 L
.67968 .38079 L
.68588 .37859 L
.68939 .37737 L
.69911 .37356 L
.70793 .36888 L
.70882 .36844 L
.71853 .36093 L
.72021 .35917 L
.7282 .34946 L
.72824 .34941 L
.73796 .34124 L
.74022 .33974 L
.74767 .33553 L
.75738 .33068 L
.7587 .33003 L
.76709 .32587 L
.77681 .32041 L
.77696 .32032 L
.78652 .31382 L
.79078 .31061 L
.79623 .30626 L
.80316 .30089 L
.80594 .29894 L
.81566 .29271 L
.81826 .29118 L
.82537 .28728 L
.83508 .28222 L
.83654 .28147 L
.84479 .27718 L
.85451 .272 L
.85495 .27176 L
.86422 .26654 L
.8721 .26204 L
.87393 .26102 L
.88364 .2557 L
.89016 .25233 L
.89336 .25082 L
.90307 .24651 L
.91278 .24282 L
.91313 .24262 L
.92249 .23976 L
.93221 .23755 L
.94192 .23665 L
.95163 .2384 L
.95699 .24262 L
.96 .25233 L
.95912 .26204 L
.95638 .27176 L
.95292 .28147 L
.95163 .28514 L
.94958 .29118 L
.94661 .30089 L
.94373 .31061 L
.94192 .31622 L
.94056 .32032 L
.93723 .33003 L
.93505 .33974 L
.93712 .34946 L
.94192 .35528 L
.95163 .35781 L
.96134 .35892 L
.96545 .35917 L
.97106 .35938 L
.98077 .35955 L
.98077 .98077 L
.01923 .98077 L
F
0 .34 .292 r
.01923 .10329 m
.02577 .10664 L
.02894 .10821 L
.03866 .11344 L
.04397 .11636 L
.04837 .11888 L
.05808 .12451 L
.06077 .12607 L
.06779 .13023 L
.07705 .13578 L
.07751 .13606 L
.08722 .14194 L
.093 .14549 L
.09693 .14794 L
.10664 .15408 L
.1084 .15521 L
.11636 .16037 L
.1233 .16492 L
.12607 .16675 L
.13578 .17316 L
.13803 .17463 L
.14549 .17948 L
.15304 .18434 L
.15521 .18574 L
.16492 .19199 L
.16809 .19406 L
.17463 .19841 L
.18247 .20377 L
.18434 .20509 L
.19406 .21199 L
.19614 .21348 L
.20377 .21883 L
.21019 .22319 L
.21348 .22536 L
.22319 .23153 L
.2254 .23291 L
.23291 .23761 L
.24066 .24262 L
.24262 .24396 L
.25233 .25098 L
.25409 .25233 L
.26204 .25862 L
.26638 .26204 L
.27176 .266 L
.28043 .27176 L
.28147 .2724 L
.29118 .27804 L
.29744 .28147 L
.30089 .28341 L
.31061 .28931 L
.31334 .29118 L
.32032 .29683 L
.32473 .30089 L
.33003 .306 L
.33502 .31061 L
.33974 .3142 L
.34946 .31978 L
.35067 .32032 L
.35917 .32437 L
.36888 .32859 L
.3721 .33003 L
.37859 .33327 L
.38759 .33974 L
.38831 .34055 L
.39468 .34946 L
.39802 .35404 L
.40271 .35917 L
.40773 .36322 L
.41744 .36768 L
.42433 .36888 L
.42716 .3698 L
.43687 .37272 L
.44658 .37567 L
.45385 .37859 L
.45629 .3799 L
.46444 .38831 L
.46448 .39802 L
.46601 .40377 L
.47005 .40773 L
.47572 .41015 L
.48543 .41276 L
.49514 .41454 L
.50486 .41596 L
.51457 .41724 L
.51617 .41744 L
.52428 .4183 L
.53399 .41858 L
.54371 .4218 L
.55342 .42501 L
.55676 .42716 L
.55349 .43687 L
.55342 .43692 L
.54371 .44381 L
.5405 .44658 L
.5352 .45629 L
.54371 .46003 L
.55342 .46128 L
.56313 .4616 L
.57284 .46135 L
.58256 .46057 L
.59227 .4592 L
.60198 .45694 L
.60406 .45629 L
.61169 .45258 L
.6182 .44658 L
.62141 .44192 L
.6246 .43687 L
.63112 .43162 L
.63938 .42716 L
.64083 .42649 L
.65054 .42216 L
.6597 .41744 L
.66026 .41705 L
.66795 .40773 L
.66982 .39802 L
.66997 .39768 L
.6784 .38831 L
.67968 .38745 L
.68939 .38276 L
.69911 .37908 L
.7004 .37859 L
.70882 .37553 L
.71853 .37095 L
.72202 .36888 L
.72824 .36456 L
.73422 .35917 L
.73796 .35511 L
.7435 .34946 L
.74767 .34613 L
.75738 .34004 L
.75794 .33974 L
.76709 .33526 L
.77681 .33091 L
.77878 .33003 L
.78652 .32651 L
.79623 .32161 L
.79856 .32032 L
.80594 .31586 L
.81406 .31061 L
.81566 .30957 L
.82537 .30343 L
.82969 .30089 L
.83508 .29813 L
.84479 .29374 L
.8513 .29118 L
.85451 .29005 L
.86422 .28689 L
.87393 .28433 L
.88364 .2826 L
.89336 .28222 L
.90307 .28464 L
.90926 .29118 L
.91168 .30089 L
.91075 .31061 L
.90762 .32032 L
.90357 .33003 L
.90307 .331 L
.90031 .33974 L
.89878 .34946 L
.89889 .35917 L
.90071 .36888 L
.90307 .37439 L
.90694 .37859 L
.91278 .38176 L
.92249 .38405 L
.93221 .38504 L
.94192 .38569 L
.95163 .38648 L
.96134 .38787 L
.9635 .38831 L
.97106 .39029 L
.98077 .39607 L
.98077 .98077 L
.01923 .98077 L
F
0 .31 .307 r
.01923 .89671 m
.02577 .89336 L
.02894 .89179 L
.03866 .88656 L
.04397 .88364 L
.04837 .88112 L
.05808 .87549 L
.06077 .87393 L
.06779 .86977 L
.07705 .86422 L
.07751 .86394 L
.08722 .85806 L
.093 .85451 L
.09693 .85206 L
.10664 .84592 L
.1084 .84479 L
.11636 .83963 L
.1233 .83508 L
.12607 .83325 L
.13578 .82684 L
.13803 .82537 L
.14549 .82052 L
.15304 .81566 L
.15521 .81426 L
.16492 .80801 L
.16809 .80594 L
.17463 .80159 L
.18247 .79623 L
.18434 .79491 L
.19406 .78801 L
.19614 .78652 L
.20377 .78117 L
.21019 .77681 L
.21348 .77464 L
.22319 .76847 L
.2254 .76709 L
.23291 .76239 L
.24066 .75738 L
.24262 .75604 L
.25233 .74902 L
.25409 .74767 L
.26204 .74138 L
.26638 .73796 L
.27176 .734 L
.28043 .72824 L
.28147 .7276 L
.29118 .72196 L
.29744 .71853 L
.30089 .71659 L
.31061 .71069 L
.31334 .70882 L
.32032 .70317 L
.32473 .69911 L
.33003 .694 L
.33502 .68939 L
.33974 .6858 L
.34946 .68022 L
.35067 .67968 L
.35917 .67563 L
.36888 .67141 L
.3721 .66997 L
.37859 .66673 L
.38759 .66026 L
.38831 .65945 L
.39468 .65054 L
.39802 .64596 L
.40271 .64083 L
.40773 .63678 L
.41744 .63232 L
.42433 .63112 L
.42716 .6302 L
.43687 .62728 L
.44658 .62433 L
.45385 .62141 L
.45629 .6201 L
.46444 .61169 L
.46448 .60198 L
.46601 .59623 L
.47005 .59227 L
.47572 .58985 L
.48543 .58724 L
.49514 .58546 L
.50486 .58404 L
.51457 .58276 L
.51617 .58256 L
.52428 .5817 L
.53399 .58142 L
.54371 .5782 L
.55342 .57499 L
.55676 .57284 L
.55349 .56313 L
.55342 .56308 L
.54371 .55619 L
.5405 .55342 L
.5352 .54371 L
.54371 .53997 L
.55342 .53872 L
.56313 .5384 L
.57284 .53865 L
.58256 .53943 L
.59227 .5408 L
.60198 .54306 L
.60406 .54371 L
.61169 .54742 L
.6182 .55342 L
.62141 .55808 L
.6246 .56313 L
.63112 .56838 L
.63938 .57284 L
.64083 .57351 L
.65054 .57784 L
.6597 .58256 L
.66026 .58295 L
.66795 .59227 L
.66982 .60198 L
.66997 .60232 L
.6784 .61169 L
.67968 .61255 L
.68939 .61724 L
.69911 .62092 L
.7004 .62141 L
.70882 .62447 L
.71853 .62905 L
.72202 .63112 L
.72824 .63544 L
.73422 .64083 L
.73796 .64489 L
.7435 .65054 L
.74767 .65387 L
.75738 .65996 L
.75794 .66026 L
.76709 .66474 L
.77681 .66909 L
.77878 .66997 L
.78652 .67349 L
.79623 .67839 L
.79856 .67968 L
.80594 .68414 L
.81406 .68939 L
.81566 .69043 L
.82537 .69657 L
.82969 .69911 L
.83508 .70187 L
.84479 .70626 L
.8513 .70882 L
.85451 .70995 L
.86422 .71311 L
.87393 .71567 L
.88364 .7174 L
.89336 .71778 L
.90307 .71536 L
.90926 .70882 L
.91168 .69911 L
.91075 .68939 L
.90762 .67968 L
.90357 .66997 L
.90307 .669 L
.90031 .66026 L
.89878 .65054 L
.89889 .64083 L
.90071 .63112 L
.90307 .62561 L
.90694 .62141 L
.91278 .61824 L
.92249 .61595 L
.93221 .61496 L
.94192 .61431 L
.95163 .61352 L
.96134 .61213 L
.9635 .61169 L
.97106 .60971 L
.98077 .60393 L
.98077 .98077 L
.01923 .98077 L
F
0 .246 .28 r
.01923 .91623 m
.02465 .91278 L
.02894 .91006 L
.03866 .90381 L
.0398 .90307 L
.04837 .89748 L
.05462 .89336 L
.05808 .89105 L
.06779 .88455 L
.06914 .88364 L
.07751 .87799 L
.08351 .87393 L
.08722 .87142 L
.09693 .86486 L
.09788 .86422 L
.10664 .85829 L
.1122 .85451 L
.11636 .85166 L
.12607 .84491 L
.12624 .84479 L
.13578 .83806 L
.13998 .83508 L
.14549 .83118 L
.15378 .82537 L
.15521 .82438 L
.16492 .81772 L
.16796 .81566 L
.17463 .81112 L
.18218 .80594 L
.18434 .80443 L
.19406 .79746 L
.19573 .79623 L
.20377 .79023 L
.20873 .78652 L
.21348 .78304 L
.22231 .77681 L
.22319 .7762 L
.23291 .76978 L
.23709 .76709 L
.24262 .7635 L
.2517 .75738 L
.25233 .75693 L
.26204 .74957 L
.2644 .74767 L
.27176 .7416 L
.27623 .73796 L
.28147 .73404 L
.29019 .72824 L
.29118 .72763 L
.30089 .72193 L
.307 .71853 L
.31061 .71642 L
.32032 .71015 L
.32214 .70882 L
.33003 .7018 L
.33272 .69911 L
.33974 .69218 L
.34279 .68939 L
.34946 .68449 L
.35884 .67968 L
.35917 .67952 L
.36888 .67499 L
.37859 .67069 L
.38012 .66997 L
.38831 .66544 L
.39442 .66026 L
.39802 .65504 L
.40064 .65054 L
.40773 .64162 L
.40884 .64083 L
.41744 .63477 L
.42716 .63165 L
.43177 .63112 L
.43687 .62955 L
.44658 .62673 L
.45629 .6235 L
.46061 .62141 L
.46601 .61748 L
.46942 .61169 L
.46861 .60198 L
.47487 .59227 L
.47572 .59188 L
.48543 .58874 L
.49514 .58677 L
.50486 .58531 L
.51457 .58407 L
.52428 .5829 L
.52702 .58256 L
.53399 .58216 L
.54371 .58019 L
.55342 .57802 L
.56313 .57362 L
.56385 .57284 L
.56313 .56886 L
.55751 .56313 L
.55342 .56066 L
.54371 .55387 L
.54319 .55342 L
.53804 .54371 L
.54371 .54106 L
.55342 .53948 L
.56313 .53905 L
.57284 .53929 L
.58256 .5401 L
.59227 .54159 L
.60079 .54371 L
.60198 .54415 L
.61169 .54974 L
.61485 .55342 L
.61928 .56313 L
.62141 .56594 L
.63094 .57284 L
.63112 .57287 L
.64083 .57751 L
.65054 .58248 L
.65067 .58256 L
.65865 .59227 L
.65893 .60198 L
.66026 .60588 L
.66518 .61169 L
.66997 .61518 L
.67968 .61921 L
.68588 .62141 L
.68939 .62263 L
.69911 .62644 L
.70793 .63112 L
.70882 .63156 L
.71853 .63907 L
.72021 .64083 L
.7282 .65054 L
.72824 .65059 L
.73796 .65876 L
.74022 .66026 L
.74767 .66447 L
.75738 .66932 L
.7587 .66997 L
.76709 .67413 L
.77681 .67959 L
.77696 .67968 L
.78652 .68618 L
.79078 .68939 L
.79623 .69374 L
.80316 .69911 L
.80594 .70106 L
.81566 .70729 L
.81826 .70882 L
.82537 .71272 L
.83508 .71778 L
.83654 .71853 L
.84479 .72282 L
.85451 .728 L
.85495 .72824 L
.86422 .73346 L
.8721 .73796 L
.87393 .73898 L
.88364 .7443 L
.89016 .74767 L
.89336 .74918 L
.90307 .75349 L
.91278 .75718 L
.91313 .75738 L
.92249 .76024 L
.93221 .76245 L
.94192 .76335 L
.95163 .7616 L
.95699 .75738 L
.96 .74767 L
.95912 .73796 L
.95638 .72824 L
.95292 .71853 L
.95163 .71486 L
.94958 .70882 L
.94661 .69911 L
.94373 .68939 L
.94192 .68378 L
.94056 .67968 L
.93723 .66997 L
.93505 .66026 L
.93712 .65054 L
.94192 .64472 L
.95163 .64219 L
.96134 .64108 L
.96545 .64083 L
.97106 .64062 L
.98077 .64045 L
.98077 .98077 L
.01923 .98077 L
F
0 .188 .25 r
.01923 .93326 m
.02072 .93221 L
.02894 .92641 L
.03448 .92249 L
.03866 .91954 L
.04819 .91278 L
.04837 .91265 L
.05808 .90575 L
.06184 .90307 L
.06779 .8988 L
.07536 .89336 L
.07751 .8918 L
.08722 .88475 L
.08875 .88364 L
.09693 .8777 L
.10213 .87393 L
.10664 .87067 L
.11562 .86422 L
.11636 .86369 L
.12607 .8567 L
.1291 .85451 L
.13578 .84963 L
.14234 .84479 L
.14549 .84244 L
.15521 .83519 L
.15535 .83508 L
.16492 .82801 L
.16855 .82537 L
.17463 .821 L
.18219 .81566 L
.18434 .81413 L
.19406 .8072 L
.19579 .80594 L
.20377 .8 L
.20869 .79623 L
.21348 .7925 L
.22115 .78652 L
.22319 .78496 L
.23291 .77785 L
.23439 .77681 L
.24262 .7712 L
.24885 .76709 L
.25233 .76476 L
.26204 .758 L
.26288 .75738 L
.27176 .75033 L
.2749 .74767 L
.28147 .74203 L
.28633 .73796 L
.29118 .73426 L
.30027 .72824 L
.30089 .72785 L
.31061 .72211 L
.31693 .71853 L
.32032 .71648 L
.33003 .70982 L
.33129 .70882 L
.33974 .70053 L
.34105 .69911 L
.34946 .6907 L
.35094 .68939 L
.35917 .68355 L
.3675 .67968 L
.36888 .67901 L
.37859 .67459 L
.38831 .67014 L
.38864 .66997 L
.39802 .66403 L
.40164 .66026 L
.40695 .65054 L
.40773 .64919 L
.41537 .64083 L
.41744 .63908 L
.42716 .63353 L
.43687 .63135 L
.43988 .63112 L
.44658 .62917 L
.45629 .62641 L
.46601 .62263 L
.46789 .62141 L
.47476 .61169 L
.473 .60198 L
.47572 .59529 L
.48008 .59227 L
.48543 .59043 L
.49514 .58821 L
.50486 .58667 L
.51457 .58545 L
.52428 .58438 L
.53399 .5827 L
.54016 .58256 L
.54371 .58211 L
.55342 .5806 L
.56313 .57831 L
.57283 .57284 L
.56313 .56355 L
.56247 .56313 L
.55342 .55849 L
.54592 .55342 L
.54371 .55155 L
.54123 .54371 L
.54371 .54242 L
.55342 .54031 L
.56313 .53976 L
.57284 .53997 L
.58256 .54083 L
.59227 .54246 L
.59733 .54371 L
.60198 .54554 L
.61134 .55342 L
.61169 .55404 L
.61336 .56313 L
.62091 .57284 L
.62141 .57307 L
.63112 .57599 L
.6404 .58256 L
.64083 .58285 L
.64832 .59227 L
.64693 .60198 L
.65054 .61138 L
.65085 .61169 L
.66026 .61861 L
.66997 .62123 L
.67056 .62141 L
.67968 .62461 L
.68939 .62881 L
.69359 .63112 L
.69911 .63393 L
.70627 .64083 L
.70882 .64412 L
.7132 .65054 L
.71853 .65629 L
.72322 .66026 L
.72824 .66354 L
.73796 .66884 L
.74016 .66997 L
.74767 .67379 L
.75738 .67935 L
.7579 .67968 L
.76709 .68614 L
.7711 .68939 L
.77681 .69454 L
.78196 .69911 L
.78652 .70282 L
.79472 .70882 L
.79623 .70982 L
.80594 .71584 L
.81048 .71853 L
.81566 .72159 L
.82537 .72753 L
.82649 .72824 L
.83508 .73398 L
.84076 .73796 L
.84479 .74086 L
.85434 .74767 L
.85451 .74779 L
.86422 .75431 L
.86901 .75738 L
.87393 .76041 L
.88364 .76621 L
.88514 .76709 L
.89336 .77191 L
.9017 .77681 L
.90307 .77761 L
.91278 .78337 L
.9181 .78652 L
.92249 .78908 L
.93221 .79465 L
.93501 .79623 L
.94192 .79995 L
.95163 .80492 L
.95365 .80594 L
.96134 .80955 L
.97106 .8138 L
.97582 .81566 L
.98077 .81759 L
.98077 .98077 L
.01923 .98077 L
F
0 .136 .22 r
.01923 .95009 m
.02894 .94278 L
.03009 .94192 L
.03866 .93545 L
.04295 .93221 L
.04837 .92811 L
.0558 .92249 L
.05808 .92077 L
.06779 .91345 L
.06868 .91278 L
.07751 .90612 L
.08155 .90307 L
.08722 .89876 L
.09432 .89336 L
.09693 .89136 L
.10664 .88392 L
.107 .88364 L
.11636 .87651 L
.11975 .87393 L
.12607 .86916 L
.13265 .86422 L
.13578 .86186 L
.14549 .85454 L
.14554 .85451 L
.15521 .84709 L
.15816 .84479 L
.16492 .83953 L
.17062 .83508 L
.17463 .83199 L
.18337 .82537 L
.18434 .82464 L
.19406 .81749 L
.19658 .81566 L
.20377 .81037 L
.20968 .80594 L
.21348 .803 L
.22199 .79623 L
.22319 .79525 L
.23291 .78737 L
.23397 .78652 L
.24262 .77992 L
.24695 .77681 L
.25233 .77305 L
.26116 .76709 L
.26204 .76649 L
.27176 .75956 L
.27463 .75738 L
.28147 .75167 L
.28595 .74767 L
.29118 .74298 L
.297 .73796 L
.30089 .73492 L
.31061 .72848 L
.31101 .72824 L
.32032 .72269 L
.32756 .71853 L
.33003 .71699 L
.33974 .70997 L
.34108 .70882 L
.34946 .6997 L
.34994 .69911 L
.35917 .68983 L
.3597 .68939 L
.36888 .68305 L
.37692 .67968 L
.37859 .67889 L
.38831 .67454 L
.3979 .66997 L
.39802 .66991 L
.40773 .66258 L
.40945 .66026 L
.41372 .65054 L
.41744 .64501 L
.4225 .64083 L
.42716 .63733 L
.43687 .63288 L
.44658 .63125 L
.44895 .63112 L
.45629 .62912 L
.46601 .62654 L
.47572 .62161 L
.47591 .62141 L
.48055 .61169 L
.47773 .60198 L
.48543 .59252 L
.48599 .59227 L
.49514 .58981 L
.50486 .58813 L
.51457 .58692 L
.52428 .58593 L
.53399 .58328 L
.54371 .58311 L
.55342 .58278 L
.55717 .58256 L
.56313 .58169 L
.57284 .57977 L
.58256 .57672 L
.5888 .57284 L
.58256 .56951 L
.57284 .56516 L
.56788 .56313 L
.56313 .56108 L
.55342 .55635 L
.54897 .55342 L
.54461 .54371 L
.55342 .54126 L
.56313 .54054 L
.57284 .54072 L
.58256 .54163 L
.59227 .54343 L
.5934 .54371 L
.60198 .54735 L
.60771 .55342 L
.60667 .56313 L
.6038 .57284 L
.61169 .57731 L
.62141 .57899 L
.62744 .58256 L
.63112 .58511 L
.6361 .59227 L
.63323 .60198 L
.63491 .61169 L
.64083 .61573 L
.65054 .62019 L
.65362 .62141 L
.66026 .62365 L
.66997 .62718 L
.67826 .63112 L
.67968 .63188 L
.68939 .63786 L
.69173 .64083 L
.6977 .65054 L
.69911 .65258 L
.70574 .66026 L
.70882 .66266 L
.71853 .66847 L
.7214 .66997 L
.72824 .67346 L
.73796 .67895 L
.73911 .67968 L
.74767 .68559 L
.75214 .68939 L
.75738 .69461 L
.7619 .69911 L
.76709 .70391 L
.773 .70882 L
.77681 .71157 L
.78652 .71799 L
.78738 .71853 L
.79623 .72412 L
.80247 .72824 L
.80594 .73066 L
.81566 .73789 L
.81574 .73796 L
.82537 .74574 L
.82777 .74767 L
.83508 .75338 L
.84043 .75738 L
.84479 .76048 L
.8544 .76709 L
.85451 .76716 L
.86422 .77373 L
.86871 .77681 L
.87393 .78045 L
.88247 .78652 L
.88364 .78737 L
.89336 .79441 L
.89588 .79623 L
.90307 .80135 L
.90964 .80594 L
.91278 .80809 L
.92249 .81465 L
.92399 .81566 L
.93221 .82111 L
.93863 .82537 L
.94192 .82755 L
.95163 .83398 L
.95329 .83508 L
.96134 .84039 L
.96808 .84479 L
.97106 .84672 L
.98077 .85291 L
.98077 .98077 L
.01923 .98077 L
F
0 .093 .19 r
.01923 .96802 m
.02769 .96134 L
.02894 .96035 L
.03866 .95267 L
.03997 .95163 L
.04837 .94497 L
.05221 .94192 L
.05808 .93725 L
.06443 .93221 L
.06779 .92953 L
.07667 .92249 L
.07751 .92183 L
.08722 .91416 L
.08897 .91278 L
.09693 .90649 L
.10126 .90307 L
.10664 .89879 L
.11345 .89336 L
.11636 .89103 L
.12559 .88364 L
.12607 .88327 L
.13578 .87556 L
.13785 .87393 L
.14549 .86794 L
.15028 .86422 L
.15521 .86037 L
.16267 .85451 L
.16492 .85271 L
.17463 .8449 L
.17476 .84479 L
.18434 .837 L
.18672 .83508 L
.19406 .82926 L
.19908 .82537 L
.20377 .82179 L
.21195 .81566 L
.21348 .8145 L
.22319 .80702 L
.22456 .80594 L
.23291 .79908 L
.23627 .79623 L
.24262 .79084 L
.24779 .78652 L
.25233 .78291 L
.26059 .77681 L
.26204 .77577 L
.27176 .76903 L
.2746 .76709 L
.28147 .7621 L
.28747 .75738 L
.29118 .75413 L
.29801 .74767 L
.30089 .74495 L
.3087 .73796 L
.31061 .73641 L
.32032 .7297 L
.32289 .72824 L
.33003 .72398 L
.33939 .71853 L
.33974 .7183 L
.34946 .7111 L
.35191 .70882 L
.35917 .69989 L
.35974 .69911 L
.36888 .68977 L
.36942 .68939 L
.37859 .6831 L
.38754 .67968 L
.38831 .67933 L
.39802 .67507 L
.40773 .67033 L
.40833 .66997 L
.41744 .66158 L
.41813 .66026 L
.4212 .65054 L
.42716 .6431 L
.43052 .64083 L
.43687 .63653 L
.44658 .63271 L
.45629 .63128 L
.45951 .63112 L
.46601 .62957 L
.47572 .62779 L
.4851 .62141 L
.48543 .62104 L
.48706 .61169 L
.48543 .60883 L
.48294 .60198 L
.48543 .59628 L
.49284 .59227 L
.49514 .59166 L
.50486 .58976 L
.51457 .5885 L
.52428 .58759 L
.53399 .58449 L
.54371 .58429 L
.55342 .58411 L
.56313 .58385 L
.57284 .58344 L
.58256 .58289 L
.59227 .58256 L
.60198 .58296 L
.61169 .58542 L
.6202 .59227 L
.61737 .60198 L
.6172 .61169 L
.62141 .61528 L
.63112 .62018 L
.6342 .62141 L
.64083 .62362 L
.65054 .62678 L
.66026 .63073 L
.66105 .63112 L
.66997 .63601 L
.67588 .64083 L
.67968 .64746 L
.68084 .65054 L
.68662 .66026 L
.68939 .66297 L
.69911 .66901 L
.701 .66997 L
.70882 .67393 L
.71853 .67931 L
.71913 .67968 L
.72824 .68571 L
.73236 .68939 L
.73796 .69553 L
.74116 .69911 L
.74767 .70599 L
.7507 .70882 L
.75738 .71399 L
.76399 .71853 L
.76709 .72054 L
.77681 .72693 L
.77871 .72824 L
.78652 .73395 L
.79151 .73796 L
.79623 .74208 L
.80252 .74767 L
.80594 .7507 L
.81386 .75738 L
.81566 .7588 L
.82537 .76615 L
.82665 .76709 L
.83508 .7732 L
.84 .77681 L
.84479 .7804 L
.85273 .78652 L
.85451 .78793 L
.86422 .79573 L
.86484 .79623 L
.87393 .80348 L
.87707 .80594 L
.88364 .81098 L
.88983 .81566 L
.89336 .81829 L
.90283 .82537 L
.90307 .82555 L
.91278 .83287 L
.91569 .83508 L
.92249 .84029 L
.92839 .84479 L
.93221 .84771 L
.94117 .85451 L
.94192 .85507 L
.95163 .86233 L
.95417 .86422 L
.96134 .86953 L
.96731 .87393 L
.97106 .87669 L
.98048 .88364 L
.98077 .88386 L
.98077 .98077 L
.01923 .98077 L
F
0 .31 .307 r
.01923 .82804 m
.02171 .82537 L
.02894 .8173 L
.03048 .81566 L
.03866 .80678 L
.03945 .80594 L
.04837 .79637 L
.0485 .79623 L
.05776 .78652 L
.05808 .78618 L
.06738 .77681 L
.06779 .77639 L
.07733 .76709 L
.07751 .76693 L
.08722 .7575 L
.08734 .75738 L
.09693 .74791 L
.09717 .74767 L
.10664 .73834 L
.10704 .73796 L
.11636 .72922 L
.11744 .72824 L
.12607 .72064 L
.12852 .71853 L
.13578 .71224 L
.13965 .70882 L
.14549 .70346 L
.15007 .69911 L
.15521 .69411 L
.16008 .68939 L
.16492 .68491 L
.17093 .67968 L
.17463 .6767 L
.18346 .66997 L
.18434 .66933 L
.19406 .66211 L
.19641 .66026 L
.20377 .65405 L
.20744 .65054 L
.21348 .64435 L
.21683 .64083 L
.22319 .63462 L
.22726 .63112 L
.23291 .62699 L
.24177 .62141 L
.24262 .62097 L
.25233 .61564 L
.25861 .61169 L
.26204 .60984 L
.27053 .60198 L
.27176 .60111 L
.27813 .59227 L
.28147 .58784 L
.28563 .58256 L
.29118 .57807 L
.30077 .57284 L
.30089 .57281 L
.31061 .56999 L
.32032 .56667 L
.32874 .56313 L
.33003 .56243 L
.33974 .55584 L
.34194 .55342 L
.34632 .54371 L
.34471 .53399 L
.33974 .52979 L
.33003 .52863 L
.32032 .52852 L
.31061 .52889 L
.30089 .52977 L
.29118 .53157 L
.28481 .53399 L
.28147 .53618 L
.27614 .54371 L
.27176 .55214 L
.27081 .55342 L
.26204 .56164 L
.25729 .56313 L
.25233 .56471 L
.24262 .5669 L
.23291 .56831 L
.22319 .56916 L
.21348 .56935 L
.20377 .56804 L
.19824 .56313 L
.19632 .55342 L
.20011 .54371 L
.20377 .53763 L
.21246 .53399 L
.21348 .5335 L
.22319 .52985 L
.23291 .52726 L
.24262 .52489 L
.24482 .52428 L
.25233 .52142 L
.25787 .51457 L
.25969 .50486 L
.25969 .49514 L
.25787 .48543 L
.25233 .47858 L
.24482 .47572 L
.24262 .47511 L
.23291 .47274 L
.22319 .47015 L
.21348 .4665 L
.21246 .46601 L
.20377 .46237 L
.20011 .45629 L
.19632 .44658 L
.19824 .43687 L
.20377 .43196 L
.21348 .43065 L
.22319 .43084 L
.23291 .43169 L
.24262 .4331 L
.25233 .43529 L
.25729 .43687 L
.26204 .43836 L
.27081 .44658 L
.27176 .44786 L
.27614 .45629 L
.28147 .46382 L
.28481 .46601 L
.29118 .46843 L
.30089 .47023 L
.31061 .47111 L
.32032 .47148 L
.33003 .47137 L
.33974 .47021 L
.34471 .46601 L
.34632 .45629 L
.34194 .44658 L
.33974 .44416 L
.33003 .43757 L
.32874 .43687 L
.32032 .43333 L
.31061 .43001 L
.30089 .42719 L
.30077 .42716 L
.29118 .42193 L
.28563 .41744 L
.28147 .41216 L
.27813 .40773 L
.27176 .39889 L
.27053 .39802 L
.26204 .39016 L
.25861 .38831 L
.25233 .38436 L
.24262 .37903 L
.24177 .37859 L
.23291 .37301 L
.22726 .36888 L
.22319 .36538 L
.21683 .35917 L
.21348 .35565 L
.20744 .34946 L
.20377 .34595 L
.19641 .33974 L
.19406 .33789 L
.18434 .33067 L
.18346 .33003 L
.17463 .3233 L
.17093 .32032 L
.16492 .31509 L
.16008 .31061 L
.15521 .30589 L
.15007 .30089 L
.14549 .29654 L
.13965 .29118 L
.13578 .28776 L
.12852 .28147 L
.12607 .27936 L
.11744 .27176 L
.11636 .27078 L
.10704 .26204 L
.10664 .26166 L
.09717 .25233 L
.09693 .25209 L
.08734 .24262 L
.08722 .2425 L
.07751 .23307 L
.07733 .23291 L
.06779 .22361 L
.06738 .22319 L
.05808 .21382 L
.05776 .21348 L
.0485 .20377 L
.04837 .20363 L
.03945 .19406 L
.03866 .19322 L
.03048 .18434 L
.02894 .1827 L
.02171 .17463 L
.01923 .17196 L
F
0 .246 .28 r
.01923 .81006 m
.02337 .80594 L
.02894 .80038 L
.03312 .79623 L
.03866 .79075 L
.04296 .78652 L
.04837 .78127 L
.05305 .77681 L
.05808 .77208 L
.06345 .76709 L
.06779 .76308 L
.07395 .75738 L
.07751 .75407 L
.0843 .74767 L
.08722 .7449 L
.09454 .73796 L
.09693 .73573 L
.10514 .72824 L
.10664 .72692 L
.11636 .71857 L
.1164 .71853 L
.12607 .71042 L
.12794 .70882 L
.13578 .70197 L
.1389 .69911 L
.14549 .69291 L
.14918 .68939 L
.15521 .68382 L
.1599 .67968 L
.16492 .6756 L
.17228 .66997 L
.17463 .66835 L
.18434 .66129 L
.18571 .66026 L
.19406 .65381 L
.19761 .65054 L
.20377 .64459 L
.2072 .64083 L
.21348 .63431 L
.21679 .63112 L
.22319 .62607 L
.23022 .62141 L
.23291 .62014 L
.24262 .61492 L
.24829 .61169 L
.25233 .6107 L
.26199 .60198 L
.26204 .60192 L
.26984 .59227 L
.27176 .58839 L
.27457 .58256 L
.27824 .57284 L
.27176 .57076 L
.26204 .57194 L
.25552 .57284 L
.25233 .57304 L
.24262 .5743 L
.23291 .57593 L
.22319 .57796 L
.21348 .5807 L
.20864 .58256 L
.20377 .58486 L
.19406 .59193 L
.1937 .59227 L
.18434 .60042 L
.18149 .60198 L
.17463 .6059 L
.16492 .61009 L
.15521 .61123 L
.1523 .61169 L
.14549 .61245 L
.13634 .61169 L
.13578 .61154 L
.12921 .60198 L
.13447 .59227 L
.13578 .58991 L
.14549 .5834 L
.1468 .58256 L
.15521 .5774 L
.16405 .57284 L
.16492 .57227 L
.17436 .56313 L
.17463 .56272 L
.17929 .55342 L
.18353 .54371 L
.18434 .54213 L
.19065 .53399 L
.19406 .5313 L
.20377 .52658 L
.21145 .52428 L
.21348 .52381 L
.22319 .52164 L
.23291 .51894 L
.24161 .51457 L
.24262 .51381 L
.24882 .50486 L
.24882 .49514 L
.24262 .48619 L
.24161 .48543 L
.23291 .48106 L
.22319 .47836 L
.21348 .47619 L
.21145 .47572 L
.20377 .47342 L
.19406 .4687 L
.19065 .46601 L
.18434 .45787 L
.18353 .45629 L
.17929 .44658 L
.17463 .43728 L
.17436 .43687 L
.16492 .42773 L
.16405 .42716 L
.15521 .4226 L
.1468 .41744 L
.14549 .4166 L
.13578 .41009 L
.13447 .40773 L
.12921 .39802 L
.13578 .38846 L
.13634 .38831 L
.14549 .38755 L
.1523 .38831 L
.15521 .38877 L
.16492 .38991 L
.17463 .3941 L
.18149 .39802 L
.18434 .39958 L
.1937 .40773 L
.19406 .40807 L
.20377 .41514 L
.20864 .41744 L
.21348 .4193 L
.22319 .42204 L
.23291 .42407 L
.24262 .4257 L
.25233 .42696 L
.25552 .42716 L
.26204 .42806 L
.27176 .42924 L
.281 .43687 L
.28147 .43829 L
.28422 .44658 L
.28922 .45629 L
.29118 .45914 L
.30089 .46387 L
.31061 .46593 L
.31125 .46601 L
.32032 .46656 L
.32732 .46601 L
.33003 .46552 L
.33965 .45629 L
.33592 .44658 L
.33003 .44231 L
.32032 .43796 L
.31684 .43687 L
.31061 .43496 L
.30089 .4324 L
.29118 .43178 L
.28147 .43029 L
.27824 .42716 L
.27457 .41744 L
.27176 .41161 L
.26984 .40773 L
.26204 .39808 L
.26199 .39802 L
.25233 .3893 L
.24829 .38831 L
.24262 .38508 L
.23291 .37986 L
.23022 .37859 L
.22319 .37393 L
.21679 .36888 L
.21348 .36569 L
.2072 .35917 L
.20377 .35541 L
.19761 .34946 L
.19406 .34619 L
.18571 .33974 L
.18434 .33871 L
.17463 .33165 L
.17228 .33003 L
.16492 .3244 L
.1599 .32032 L
.15521 .31618 L
.14918 .31061 L
.14549 .30709 L
.1389 .30089 L
.13578 .29803 L
.12794 .29118 L
.12607 .28958 L
.1164 .28147 L
.11636 .28143 L
.10664 .27308 L
.10514 .27176 L
.09693 .26427 L
.09454 .26204 L
.08722 .2551 L
.0843 .25233 L
.07751 .24593 L
.07395 .24262 L
.06779 .23692 L
.06345 .23291 L
.05808 .22792 L
.05305 .22319 L
.04837 .21873 L
.04296 .21348 L
.03866 .20925 L
.03312 .20377 L
.02894 .19962 L
.02337 .19406 L
.01923 .18994 L
F
0 .188 .25 r
.01923 .79357 m
.02664 .78652 L
.02894 .78437 L
.03704 .77681 L
.03866 .77533 L
.0477 .76709 L
.04837 .7665 L
.05808 .75779 L
.05853 .75738 L
.06779 .74902 L
.06926 .74767 L
.07751 .74007 L
.07977 .73796 L
.08722 .73114 L
.09042 .72824 L
.09693 .72261 L
.1017 .71853 L
.10664 .71455 L
.11351 .70882 L
.11636 .70663 L
.12491 .69911 L
.12607 .69821 L
.13534 .68939 L
.13578 .68904 L
.14549 .67974 L
.14555 .67968 L
.15521 .67163 L
.15732 .66997 L
.16492 .66489 L
.17125 .66026 L
.17463 .65911 L
.18413 .65054 L
.18434 .65032 L
.19384 .64083 L
.19406 .6405 L
.20163 .63112 L
.20377 .62758 L
.2096 .62141 L
.21348 .61866 L
.22319 .61537 L
.22948 .61169 L
.23291 .61033 L
.24262 .60588 L
.25043 .60198 L
.25233 .59907 L
.25788 .59227 L
.25233 .58489 L
.24262 .58432 L
.23291 .58616 L
.22319 .5889 L
.21926 .59227 L
.21348 .59734 L
.20916 .60198 L
.20377 .60828 L
.19921 .61169 L
.19406 .61495 L
.18434 .61824 L
.17463 .62133 L
.17436 .62141 L
.16492 .62378 L
.15521 .62696 L
.14549 .6306 L
.14425 .63112 L
.13578 .63486 L
.12607 .64016 L
.12494 .64083 L
.11636 .64583 L
.10745 .65054 L
.10664 .65093 L
.09693 .65537 L
.08722 .65896 L
.08072 .66026 L
.07751 .66106 L
.06779 .66295 L
.05808 .66146 L
.05539 .66026 L
.05516 .65054 L
.05808 .64498 L
.06091 .64083 L
.06779 .6335 L
.07029 .63112 L
.07751 .62434 L
.0816 .62141 L
.08722 .61613 L
.09164 .61169 L
.09693 .60526 L
.09944 .60198 L
.10664 .59238 L
.10674 .59227 L
.11624 .58256 L
.11636 .58246 L
.12607 .57574 L
.1313 .57284 L
.13578 .57066 L
.14549 .56537 L
.14895 .56313 L
.15521 .55937 L
.1594 .55342 L
.16388 .54371 L
.16443 .53399 L
.15521 .52456 L
.15114 .52428 L
.14549 .52329 L
.13578 .52194 L
.12607 .52033 L
.11636 .51749 L
.11108 .51457 L
.10664 .51049 L
.10367 .50486 L
.10367 .49514 L
.10664 .48951 L
.11108 .48543 L
.11636 .48251 L
.12607 .47967 L
.13578 .47806 L
.14549 .47671 L
.15114 .47572 L
.15521 .47544 L
.16443 .46601 L
.16388 .45629 L
.1594 .44658 L
.15521 .44063 L
.14895 .43687 L
.14549 .43463 L
.13578 .42934 L
.1313 .42716 L
.12607 .42426 L
.11636 .41754 L
.11624 .41744 L
.10674 .40773 L
.10664 .40762 L
.09944 .39802 L
.09693 .39474 L
.09164 .38831 L
.08722 .38387 L
.0816 .37859 L
.07751 .37566 L
.07029 .36888 L
.06779 .3665 L
.06091 .35917 L
.05808 .35502 L
.05516 .34946 L
.05539 .33974 L
.05808 .33854 L
.06779 .33705 L
.07751 .33894 L
.08072 .33974 L
.08722 .34104 L
.09693 .34463 L
.10664 .34907 L
.10745 .34946 L
.11636 .35417 L
.12494 .35917 L
.12607 .35984 L
.13578 .36514 L
.14425 .36888 L
.14549 .3694 L
.15521 .37304 L
.16492 .37622 L
.17436 .37859 L
.17463 .37867 L
.18434 .38176 L
.19406 .38505 L
.19921 .38831 L
.20377 .39172 L
.20916 .39802 L
.21348 .40266 L
.21926 .40773 L
.22319 .4111 L
.23291 .41384 L
.24262 .41568 L
.25233 .41511 L
.25788 .40773 L
.25233 .40093 L
.25043 .39802 L
.24262 .39412 L
.23291 .38967 L
.22948 .38831 L
.22319 .38463 L
.21348 .38134 L
.2096 .37859 L
.20377 .37242 L
.20163 .36888 L
.19406 .3595 L
.19384 .35917 L
.18434 .34968 L
.18413 .34946 L
.17463 .34089 L
.17125 .33974 L
.16492 .33511 L
.15732 .33003 L
.15521 .32837 L
.14555 .32032 L
.14549 .32026 L
.13578 .31096 L
.13534 .31061 L
.12607 .30179 L
.12491 .30089 L
.11636 .29337 L
.11351 .29118 L
.10664 .28545 L
.1017 .28147 L
.09693 .27739 L
.09042 .27176 L
.08722 .26886 L
.07977 .26204 L
.07751 .25993 L
.06926 .25233 L
.06779 .25098 L
.05853 .24262 L
.05808 .24221 L
.04837 .2335 L
.0477 .23291 L
.03866 .22467 L
.03704 .22319 L
.02894 .21563 L
.02664 .21348 L
.01923 .20643 L
F
0 .136 .22 r
.01923 .77382 m
.02627 .76709 L
.02894 .76501 L
.03714 .75738 L
.03866 .75635 L
.04782 .74767 L
.04837 .74749 L
.05805 .73796 L
.05808 .73793 L
.06779 .7284 L
.06793 .72824 L
.07751 .71912 L
.07806 .71853 L
.08722 .71098 L
.08918 .70882 L
.09693 .70195 L
.10075 .69911 L
.10664 .6924 L
.10999 .68939 L
.10664 .68029 L
.09693 .68218 L
.08722 .68363 L
.07872 .68939 L
.07751 .68998 L
.06779 .69436 L
.0595 .69911 L
.05808 .69967 L
.04837 .70462 L
.03963 .70882 L
.03866 .70923 L
.02894 .71347 L
.01923 .71759 L
F
.01923 .28241 m
.02894 .28653 L
.03866 .29077 L
.03963 .29118 L
.04837 .29538 L
.05808 .30033 L
.0595 .30089 L
.06779 .30564 L
.07751 .31002 L
.07872 .31061 L
.08722 .31637 L
.09693 .31782 L
.10664 .31971 L
.10999 .31061 L
.10664 .3076 L
.10075 .30089 L
.09693 .29805 L
.08918 .29118 L
.08722 .28902 L
.07806 .28147 L
.07751 .28088 L
.06793 .27176 L
.06779 .2716 L
.05808 .26207 L
.05805 .26204 L
.04837 .25251 L
.04782 .25233 L
.03866 .24365 L
.03714 .24262 L
.02894 .23499 L
.02627 .23291 L
.01923 .22618 L
F
.01923 .43186 m
.02894 .42831 L
.03675 .42716 L
.03866 .42693 L
.04837 .42616 L
.05808 .42592 L
.06779 .42238 L
.0727 .41744 L
.07116 .40773 L
.06779 .40246 L
.06417 .39802 L
.05808 .39083 L
.05302 .38831 L
.04837 .38448 L
.04053 .37859 L
.03866 .37701 L
.02968 .36888 L
.02894 .36815 L
.02044 .35917 L
.01923 .35782 L
F
.01923 .64218 m
.02044 .64083 L
.02894 .63185 L
.02968 .63112 L
.03866 .62299 L
.04053 .62141 L
.04837 .61552 L
.05302 .61169 L
.05808 .60917 L
.06417 .60198 L
.06779 .59754 L
.07116 .59227 L
.0727 .58256 L
.06779 .57762 L
.05808 .57408 L
.04837 .57384 L
.03866 .57307 L
.03675 .57284 L
.02894 .57169 L
.01923 .56814 L
F
.01923 .541 m
.02567 .53399 L
.02894 .5311 L
.03866 .5248 L
.0396 .52428 L
.04837 .5192 L
.0539 .51457 L
.05808 .50936 L
.0601 .50486 L
.0601 .49514 L
.05808 .49064 L
.0539 .48543 L
.04837 .4808 L
.0396 .47572 L
.03866 .4752 L
.02894 .4689 L
.02567 .46601 L
.01923 .459 L
F
0 .37 .27 r
.02894 .14206 m
.03866 .13845 L
.04837 .13993 L
.05808 .14341 L
.06414 .14549 L
.06779 .14735 L
.07751 .15186 L
.08435 .15521 L
.08722 .15676 L
.09693 .16197 L
.10229 .16492 L
.10664 .16741 L
.11636 .17302 L
.11915 .17463 L
.12607 .17866 L
.13578 .18433 L
.13581 .18434 L
.14549 .18999 L
.15234 .19406 L
.15521 .19579 L
.16492 .20181 L
.16799 .20377 L
.17463 .20813 L
.18265 .21348 L
.18434 .21462 L
.19406 .22104 L
.19741 .22319 L
.20377 .22717 L
.21326 .23291 L
.21348 .23303 L
.22319 .23884 L
.22933 .24262 L
.23291 .24492 L
.24262 .25161 L
.24362 .25233 L
.25233 .25891 L
.25646 .26204 L
.26204 .26606 L
.2707 .27176 L
.27176 .2724 L
.28147 .27797 L
.28799 .28147 L
.29118 .2832 L
.30089 .28877 L
.30468 .29118 L
.31061 .29555 L
.3169 .30089 L
.32032 .30407 L
.32744 .31061 L
.33003 .31263 L
.33974 .31882 L
.34278 .32032 L
.34946 .32357 L
.35917 .3278 L
.36437 .33003 L
.36888 .3321 L
.37859 .3378 L
.38101 .33974 L
.38831 .34856 L
.38894 .34946 L
.39687 .35917 L
.39802 .36024 L
.40773 .36646 L
.41735 .36888 L
.41744 .36891 L
.42716 .37201 L
.43687 .37486 L
.44658 .37822 L
.44744 .37859 L
.45629 .38403 L
.4597 .38831 L
.46052 .39802 L
.46557 .40773 L
.46601 .40799 L
.47572 .41184 L
.48543 .41411 L
.49514 .41577 L
.50486 .41717 L
.50686 .41744 L
.51457 .41841 L
.52428 .4194 L
.53399 .41957 L
.54371 .42393 L
.55065 .42716 L
.54969 .43687 L
.54371 .44157 L
.53799 .44658 L
.53399 .4507 L
.53251 .45629 L
.53399 .45773 L
.54371 .46095 L
.55342 .46196 L
.56313 .46221 L
.57284 .46194 L
.58256 .46121 L
.59227 .45992 L
.60198 .45787 L
.6072 .45629 L
.61169 .45429 L
.62141 .44662 L
.62144 .44658 L
.62961 .43687 L
.63112 .43569 L
.64083 .43006 L
.64707 .42716 L
.65054 .42569 L
.66026 .42151 L
.66809 .41744 L
.66997 .41607 L
.67668 .40773 L
.67968 .39901 L
.68011 .39802 L
.68939 .38916 L
.69112 .38831 L
.69911 .38453 L
.70882 .38085 L
.71492 .37859 L
.71853 .37736 L
.72824 .37345 L
.73671 .36888 L
.73796 .36808 L
.74767 .36054 L
.74923 .35917 L
.75738 .35185 L
.76036 .34946 L
.76709 .34524 L
.77681 .34053 L
.77867 .33974 L
.78652 .33665 L
.79623 .33316 L
.80536 .33003 L
.80594 .32984 L
.81566 .32648 L
.82537 .32313 L
.83361 .32032 L
.83508 .31991 L
.84479 .31721 L
.85451 .31594 L
.86422 .31825 L
.867 .32032 L
.8707 .33003 L
.8723 .33974 L
.87328 .34946 L
.87316 .35917 L
.87132 .36888 L
.8678 .37859 L
.86476 .38831 L
.86653 .39802 L
.87393 .4043 L
.88325 .40773 L
.88364 .40783 L
.89336 .40961 L
.90307 .4106 L
.91278 .41142 L
.92249 .41262 L
.93221 .41505 L
.93733 .41744 L
.94192 .42102 L
.94601 .42716 L
.94891 .43687 L
.95015 .44658 L
.95068 .45629 L
.95074 .46601 L
.95037 .47572 L
.94959 .48543 L
.94875 .49514 L
.94875 .50486 L
.94959 .51457 L
.95037 .52428 L
.95074 .53399 L
.95068 .54371 L
.95015 .55342 L
.94891 .56313 L
.94601 .57284 L
.94192 .57898 L
.93733 .58256 L
.93221 .58495 L
.92249 .58738 L
.91278 .58858 L
.90307 .5894 L
.89336 .59039 L
.88364 .59217 L
.88325 .59227 L
.87393 .5957 L
.86653 .60198 L
.86476 .61169 L
.8678 .62141 L
.87132 .63112 L
.87316 .64083 L
.87328 .65054 L
.8723 .66026 L
.8707 .66997 L
.867 .67968 L
.86422 .68175 L
.85451 .68406 L
.84479 .68279 L
.83508 .68009 L
.83361 .67968 L
.82537 .67687 L
.81566 .67352 L
.80594 .67016 L
.80536 .66997 L
.79623 .66684 L
.78652 .66335 L
.77867 .66026 L
.77681 .65947 L
.76709 .65476 L
.76036 .65054 L
.75738 .64815 L
.74923 .64083 L
.74767 .63946 L
.73796 .63192 L
.73671 .63112 L
.72824 .62655 L
.71853 .62264 L
.71492 .62141 L
.70882 .61915 L
.69911 .61547 L
.69112 .61169 L
.68939 .61084 L
.68011 .60198 L
.67968 .60099 L
.67668 .59227 L
.66997 .58393 L
.66809 .58256 L
.66026 .57849 L
.65054 .57431 L
.64707 .57284 L
.64083 .56994 L
.63112 .56431 L
.62961 .56313 L
.62144 .55342 L
.62141 .55338 L
.61169 .54571 L
.6072 .54371 L
.60198 .54213 L
.59227 .54008 L
.58256 .53879 L
.57284 .53806 L
.56313 .53779 L
.55342 .53804 L
.54371 .53905 L
.53399 .54227 L
.53251 .54371 L
.53399 .5493 L
.53799 .55342 L
.54371 .55843 L
.54969 .56313 L
.55065 .57284 L
.54371 .57607 L
.53399 .58043 L
.52428 .5806 L
.51457 .58159 L
.50686 .58256 L
.50486 .58283 L
.49514 .58423 L
.48543 .58589 L
.47572 .58816 L
.46601 .59201 L
.46557 .59227 L
.46052 .60198 L
.4597 .61169 L
.45629 .61597 L
.44744 .62141 L
.44658 .62178 L
.43687 .62514 L
.42716 .62799 L
.41744 .63109 L
.41735 .63112 L
.40773 .63354 L
.39802 .63976 L
.39687 .64083 L
.38894 .65054 L
.38831 .65144 L
.38101 .66026 L
.37859 .6622 L
.36888 .6679 L
.36437 .66997 L
.35917 .6722 L
.34946 .67643 L
.34278 .67968 L
.33974 .68118 L
.33003 .68737 L
.32744 .68939 L
.32032 .69593 L
.3169 .69911 L
.31061 .70445 L
.30468 .70882 L
.30089 .71123 L
.29118 .7168 L
.28799 .71853 L
.28147 .72203 L
.27176 .7276 L
.2707 .72824 L
.26204 .73394 L
.25646 .73796 L
.25233 .74109 L
.24362 .74767 L
.24262 .74839 L
.23291 .75508 L
.22933 .75738 L
.22319 .76116 L
.21348 .76697 L
.21326 .76709 L
.20377 .77283 L
.19741 .77681 L
.19406 .77896 L
.18434 .78538 L
.18265 .78652 L
.17463 .79187 L
.16799 .79623 L
.16492 .79819 L
.15521 .80421 L
.15234 .80594 L
.14549 .81001 L
.13581 .81566 L
.13578 .81567 L
.12607 .82134 L
.11915 .82537 L
.11636 .82698 L
.10664 .83259 L
.10229 .83508 L
.09693 .83803 L
.08722 .84324 L
.08435 .84479 L
.07751 .84814 L
.06779 .85265 L
.06414 .85451 L
.05808 .85659 L
.04837 .86007 L
.03866 .86155 L
.02894 .85794 L
.02811 .85451 L
.02894 .84889 L
.03025 .84479 L
.03532 .83508 L
.03866 .82832 L
.04169 .82537 L
.04837 .81609 L
.04886 .81566 L
.05641 .80594 L
.05808 .80378 L
.06428 .79623 L
.06779 .79196 L
.07261 .78652 L
.07751 .78102 L
.08151 .77681 L
.08722 .77076 L
.09081 .76709 L
.09693 .76068 L
.10011 .75738 L
.10664 .75043 L
.10927 .74767 L
.11636 .74025 L
.11865 .73796 L
.12607 .73071 L
.12874 .72824 L
.13578 .72184 L
.13951 .71853 L
.14549 .71312 L
.15012 .70882 L
.15521 .70387 L
.15996 .69911 L
.16492 .69408 L
.16966 .68939 L
.17463 .68476 L
.18054 .67968 L
.18434 .67662 L
.19305 .66997 L
.19406 .66922 L
.20377 .66165 L
.20542 .66026 L
.21348 .65281 L
.2157 .65054 L
.22319 .64259 L
.22489 .64083 L
.23291 .63345 L
.23586 .63112 L
.24262 .62646 L
.25091 .62141 L
.25233 .62064 L
.26204 .6149 L
.26668 .61169 L
.27176 .60784 L
.27733 .60198 L
.28147 .59677 L
.28481 .59227 L
.29118 .58495 L
.29386 .58256 L
.30089 .57794 L
.31061 .57338 L
.31196 .57284 L
.32032 .57018 L
.33003 .56635 L
.33619 .56313 L
.33974 .5608 L
.34706 .55342 L
.34946 .54874 L
.35129 .54371 L
.35322 .53399 L
.34946 .52769 L
.33974 .52481 L
.33003 .52501 L
.32032 .52502 L
.31061 .52504 L
.30089 .52501 L
.29118 .52474 L
.28534 .52428 L
.28147 .52361 L
.27176 .51655 L
.27089 .51457 L
.26881 .50486 L
.26881 .49514 L
.27089 .48543 L
.27176 .48345 L
.28147 .47639 L
.28534 .47572 L
.29118 .47526 L
.30089 .47499 L
.31061 .47496 L
.32032 .47498 L
.33003 .47499 L
.33974 .47519 L
.34946 .47231 L
.35322 .46601 L
.35129 .45629 L
.34946 .45126 L
.34706 .44658 L
.33974 .4392 L
.33619 .43687 L
.33003 .43365 L
.32032 .42982 L
.31196 .42716 L
.31061 .42662 L
.30089 .42206 L
.29386 .41744 L
.29118 .41505 L
.28481 .40773 L
.28147 .40323 L
.27733 .39802 L
.27176 .39216 L
.26668 .38831 L
.26204 .3851 L
.25233 .37936 L
.25091 .37859 L
.24262 .37354 L
.23586 .36888 L
.23291 .36655 L
.22489 .35917 L
.22319 .35741 L
.2157 .34946 L
.21348 .34719 L
.20542 .33974 L
.20377 .33835 L
.19406 .33078 L
.19305 .33003 L
.18434 .32338 L
.18054 .32032 L
.17463 .31524 L
.16966 .31061 L
.16492 .30592 L
.15996 .30089 L
.15521 .29613 L
.15012 .29118 L
.14549 .28688 L
.13951 .28147 L
.13578 .27816 L
.12874 .27176 L
.12607 .26929 L
.11865 .26204 L
.11636 .25975 L
.10927 .25233 L
.10664 .24957 L
.10011 .24262 L
.09693 .23932 L
.09081 .23291 L
.08722 .22924 L
.08151 .22319 L
.07751 .21898 L
.07261 .21348 L
.06779 .20804 L
.06428 .20377 L
.05808 .19622 L
.05641 .19406 L
.04886 .18434 L
.04837 .18391 L
.04169 .17463 L
.03866 .17168 L
.03532 .16492 L
.03025 .15521 L
.02894 .15111 L
.02811 .14549 L
F
0 .058 .16 r
.98077 .91692 m
.97564 .91278 L
.97106 .90907 L
.96366 .90307 L
.96134 .90118 L
.95176 .89336 L
.95163 .89325 L
.94192 .88532 L
.93987 .88364 L
.93221 .87742 L
.9279 .87393 L
.92249 .86956 L
.91591 .86422 L
.91278 .86167 L
.90405 .85451 L
.90307 .85369 L
.89336 .84559 L
.8924 .84479 L
.88364 .8375 L
.88072 .83508 L
.87393 .82955 L
.86874 .82537 L
.86422 .82175 L
.85659 .81566 L
.85451 .81397 L
.84481 .80594 L
.84479 .80593 L
.83508 .7975 L
.83364 .79623 L
.82537 .78904 L
.82241 .78652 L
.81566 .78102 L
.81024 .77681 L
.80594 .77353 L
.7974 .76709 L
.79623 .76618 L
.78652 .75823 L
.78555 .75738 L
.77681 .74902 L
.77546 .74767 L
.76709 .7396 L
.76531 .73796 L
.75738 .73157 L
.7526 .72824 L
.74767 .72492 L
.73796 .7186 L
.73785 .71853 L
.72824 .71125 L
.72562 .70882 L
.71853 .69994 L
.71793 .69911 L
.7101 .68939 L
.70882 .68809 L
.69911 .68094 L
.69615 .67968 L
.68939 .67608 L
.67968 .67139 L
.67692 .66997 L
.66997 .66723 L
.66414 .66026 L
.66145 .65054 L
.66026 .64531 L
.65764 .64083 L
.65054 .63576 L
.64083 .6312 L
.64062 .63112 L
.63112 .62767 L
.62141 .62476 L
.61169 .6215 L
.61147 .62141 L
.60198 .61617 L
.59821 .61169 L
.59973 .60198 L
.59689 .59227 L
.59227 .59068 L
.58256 .58697 L
.57284 .58671 L
.56313 .58654 L
.55342 .58645 L
.54371 .58645 L
.53399 .58665 L
.52428 .5894 L
.51457 .59027 L
.50486 .59163 L
.50148 .59227 L
.49514 .59445 L
.48882 .60198 L
.49473 .61169 L
.49514 .61249 L
.49627 .62141 L
.49514 .62244 L
.48543 .62731 L
.47572 .63065 L
.47258 .63112 L
.46601 .63152 L
.45629 .6331 L
.44658 .63674 L
.43996 .64083 L
.43687 .64262 L
.42978 .65054 L
.42821 .66026 L
.42716 .66269 L
.42066 .66997 L
.41744 .67205 L
.40773 .67651 L
.40016 .67968 L
.39802 .68015 L
.38831 .68403 L
.3807 .68939 L
.37859 .69053 L
.37101 .69911 L
.36888 .70227 L
.36446 .70882 L
.35917 .71404 L
.35322 .71853 L
.34946 .72083 L
.33974 .72646 L
.33675 .72824 L
.33003 .73206 L
.32217 .73796 L
.32032 .73952 L
.31185 .74767 L
.31061 .74901 L
.30226 .75738 L
.30089 .75859 L
.29118 .76631 L
.29012 .76709 L
.28147 .77309 L
.27626 .77681 L
.27176 .78003 L
.26356 .78652 L
.26204 .78781 L
.25252 .79623 L
.25233 .7964 L
.24262 .80499 L
.24149 .80594 L
.23291 .8129 L
.2294 .81566 L
.22319 .82041 L
.21684 .82537 L
.21348 .82801 L
.20481 .83508 L
.20377 .83595 L
.19406 .84418 L
.19334 .84479 L
.18434 .85238 L
.1818 .85451 L
.17463 .86037 L
.16989 .86422 L
.16492 .86822 L
.15787 .87393 L
.15521 .87611 L
.14606 .88364 L
.14549 .88412 L
.13578 .89222 L
.13443 .89336 L
.12607 .90032 L
.12275 .90307 L
.11636 .90834 L
.11096 .91278 L
.10664 .91633 L
.09916 .92249 L
.09693 .92433 L
.08742 .93221 L
.08722 .93238 L
.07751 .94045 L
.07574 .94192 L
.06779 .94852 L
.06405 .95163 L
.05808 .95657 L
.05232 .96134 L
.04837 .96461 L
.04058 .97106 L
.03866 .97265 L
.02894 .98071 L
.02887 .98077 L
.98077 .98077 L
F
.98077 .08308 m
.97564 .08722 L
.97106 .09093 L
.96366 .09693 L
.96134 .09882 L
.95176 .10664 L
.95163 .10675 L
.94192 .11468 L
.93987 .11636 L
.93221 .12258 L
.9279 .12607 L
.92249 .13044 L
.91591 .13578 L
.91278 .13833 L
.90405 .14549 L
.90307 .14631 L
.89336 .15441 L
.8924 .15521 L
.88364 .1625 L
.88072 .16492 L
.87393 .17045 L
.86874 .17463 L
.86422 .17825 L
.85659 .18434 L
.85451 .18603 L
.84481 .19406 L
.84479 .19407 L
.83508 .2025 L
.83364 .20377 L
.82537 .21096 L
.82241 .21348 L
.81566 .21898 L
.81024 .22319 L
.80594 .22647 L
.7974 .23291 L
.79623 .23382 L
.78652 .24177 L
.78555 .24262 L
.77681 .25098 L
.77546 .25233 L
.76709 .2604 L
.76531 .26204 L
.75738 .26843 L
.7526 .27176 L
.74767 .27508 L
.73796 .2814 L
.73785 .28147 L
.72824 .28875 L
.72562 .29118 L
.71853 .30006 L
.71793 .30089 L
.7101 .31061 L
.70882 .31191 L
.69911 .31906 L
.69615 .32032 L
.68939 .32392 L
.67968 .32861 L
.67692 .33003 L
.66997 .33277 L
.66414 .33974 L
.66145 .34946 L
.66026 .35469 L
.65764 .35917 L
.65054 .36424 L
.64083 .3688 L
.64062 .36888 L
.63112 .37233 L
.62141 .37524 L
.61169 .3785 L
.61147 .37859 L
.60198 .38383 L
.59821 .38831 L
.59973 .39802 L
.59689 .40773 L
.59227 .40932 L
.58256 .41303 L
.57284 .41329 L
.56313 .41346 L
.55342 .41355 L
.54371 .41355 L
.53399 .41335 L
.52428 .4106 L
.51457 .40973 L
.50486 .40837 L
.50148 .40773 L
.49514 .40555 L
.48882 .39802 L
.49473 .38831 L
.49514 .38751 L
.49627 .37859 L
.49514 .37756 L
.48543 .37269 L
.47572 .36935 L
.47258 .36888 L
.46601 .36848 L
.45629 .3669 L
.44658 .36326 L
.43996 .35917 L
.43687 .35738 L
.42978 .34946 L
.42821 .33974 L
.42716 .33731 L
.42066 .33003 L
.41744 .32795 L
.40773 .32349 L
.40016 .32032 L
.39802 .31985 L
.38831 .31597 L
.3807 .31061 L
.37859 .30947 L
.37101 .30089 L
.36888 .29773 L
.36446 .29118 L
.35917 .28596 L
.35322 .28147 L
.34946 .27917 L
.33974 .27354 L
.33675 .27176 L
.33003 .26794 L
.32217 .26204 L
.32032 .26048 L
.31185 .25233 L
.31061 .25099 L
.30226 .24262 L
.30089 .24141 L
.29118 .23369 L
.29012 .23291 L
.28147 .22691 L
.27626 .22319 L
.27176 .21997 L
.26356 .21348 L
.26204 .21219 L
.25252 .20377 L
.25233 .2036 L
.24262 .19501 L
.24149 .19406 L
.23291 .1871 L
.2294 .18434 L
.22319 .17959 L
.21684 .17463 L
.21348 .17199 L
.20481 .16492 L
.20377 .16405 L
.19406 .15582 L
.19334 .15521 L
.18434 .14762 L
.1818 .14549 L
.17463 .13963 L
.16989 .13578 L
.16492 .13178 L
.15787 .12607 L
.15521 .12389 L
.14606 .11636 L
.14549 .11588 L
.13578 .10778 L
.13443 .10664 L
.12607 .09968 L
.12275 .09693 L
.11636 .09166 L
.11096 .08722 L
.10664 .08367 L
.09916 .07751 L
.09693 .07567 L
.08742 .06779 L
.08722 .06762 L
.07751 .05955 L
.07574 .05808 L
.06779 .05148 L
.06405 .04837 L
.05808 .04343 L
.05232 .03866 L
.04837 .03539 L
.04058 .02894 L
.03866 .02735 L
.02894 .01929 L
.02887 .01923 L
.98077 .01923 L
F
0 .03 .13 r
.98077 .9574 m
.97415 .95163 L
.97106 .94893 L
.96303 .94192 L
.96134 .94045 L
.9519 .93221 L
.95163 .93197 L
.94192 .92353 L
.94072 .92249 L
.93221 .91509 L
.92955 .91278 L
.92249 .90661 L
.91847 .90307 L
.91278 .89806 L
.90745 .89336 L
.90307 .8895 L
.89638 .88364 L
.89336 .88101 L
.88516 .87393 L
.88364 .87262 L
.87393 .86423 L
.87391 .86422 L
.86422 .85568 L
.86291 .85451 L
.85451 .84693 L
.85215 .84479 L
.84479 .83822 L
.84124 .83508 L
.83508 .8298 L
.82981 .82537 L
.82537 .82166 L
.81821 .81566 L
.81566 .81344 L
.8073 .80594 L
.80594 .80467 L
.79721 .79623 L
.79623 .7953 L
.78675 .78652 L
.78652 .78632 L
.77681 .77836 L
.77477 .77681 L
.76709 .77095 L
.76209 .76709 L
.75738 .76312 L
.75125 .75738 L
.74767 .75345 L
.74279 .74767 L
.73796 .74237 L
.73353 .73796 L
.72824 .73349 L
.72028 .72824 L
.71853 .72712 L
.70882 .72114 L
.7048 .71853 L
.69911 .71433 L
.69401 .70882 L
.68939 .69966 L
.68913 .69911 L
.68245 .68939 L
.67968 .68631 L
.66997 .68021 L
.66654 .67968 L
.66026 .67692 L
.65054 .673 L
.64454 .66997 L
.64083 .66767 L
.63444 .66026 L
.63708 .65054 L
.63497 .64083 L
.63112 .63818 L
.62141 .63366 L
.61425 .63112 L
.61169 .6303 L
.60198 .62764 L
.59227 .62524 L
.58381 .62141 L
.58256 .62061 L
.57815 .61169 L
.5816 .60198 L
.57284 .59419 L
.56439 .59227 L
.56313 .59202 L
.55342 .59069 L
.54371 .5901 L
.53399 .59008 L
.52428 .59147 L
.51514 .59227 L
.51457 .59235 L
.50486 .5944 L
.49591 .60198 L
.50451 .61169 L
.50486 .61203 L
.51203 .62141 L
.50486 .62663 L
.49514 .62995 L
.49068 .63112 L
.48543 .63144 L
.47572 .63241 L
.46601 .63453 L
.45629 .63842 L
.45202 .64083 L
.44658 .64361 L
.44022 .65054 L
.44082 .66026 L
.43687 .66981 L
.4367 .66997 L
.42716 .67587 L
.41744 .67936 L
.41659 .67968 L
.40773 .6817 L
.39802 .68695 L
.39482 .68939 L
.38831 .69474 L
.38491 .69911 L
.38023 .70882 L
.37859 .71112 L
.37092 .71853 L
.36888 .71991 L
.35917 .72553 L
.35437 .72824 L
.34946 .73054 L
.33974 .73731 L
.33898 .73796 L
.33003 .74653 L
.32903 .74767 L
.3208 .75738 L
.32032 .75788 L
.31061 .7664 L
.30971 .76709 L
.30089 .77327 L
.2959 .77681 L
.29118 .78008 L
.28315 .78652 L
.28147 .78799 L
.27266 .79623 L
.27176 .79713 L
.26255 .80594 L
.26204 .8064 L
.25233 .81467 L
.25112 .81566 L
.24262 .82234 L
.23883 .82537 L
.23291 .83015 L
.22709 .83508 L
.22319 .83851 L
.21618 .84479 L
.21348 .84723 L
.20531 .85451 L
.20377 .85584 L
.19406 .86413 L
.19395 .86422 L
.18434 .87224 L
.18234 .87393 L
.17463 .88048 L
.17096 .88364 L
.16492 .88892 L
.15986 .89336 L
.15521 .89744 L
.14876 .90307 L
.14549 .90589 L
.13749 .91278 L
.13578 .91424 L
.12617 .92249 L
.12607 .92258 L
.11636 .93096 L
.11493 .93221 L
.10664 .93942 L
.10378 .94192 L
.09693 .94788 L
.09263 .95163 L
.08722 .95632 L
.08143 .96134 L
.07751 .96473 L
.07021 .97106 L
.06779 .97316 L
.05903 .98077 L
.98077 .98077 L
F
.98077 .0426 m
.97415 .04837 L
.97106 .05107 L
.96303 .05808 L
.96134 .05955 L
.9519 .06779 L
.95163 .06803 L
.94192 .07647 L
.94072 .07751 L
.93221 .08491 L
.92955 .08722 L
.92249 .09339 L
.91847 .09693 L
.91278 .10194 L
.90745 .10664 L
.90307 .1105 L
.89638 .11636 L
.89336 .11899 L
.88516 .12607 L
.88364 .12738 L
.87393 .13577 L
.87391 .13578 L
.86422 .14432 L
.86291 .14549 L
.85451 .15307 L
.85215 .15521 L
.84479 .16178 L
.84124 .16492 L
.83508 .1702 L
.82981 .17463 L
.82537 .17834 L
.81821 .18434 L
.81566 .18656 L
.8073 .19406 L
.80594 .19533 L
.79721 .20377 L
.79623 .2047 L
.78675 .21348 L
.78652 .21368 L
.77681 .22164 L
.77477 .22319 L
.76709 .22905 L
.76209 .23291 L
.75738 .23688 L
.75125 .24262 L
.74767 .24655 L
.74279 .25233 L
.73796 .25763 L
.73353 .26204 L
.72824 .26651 L
.72028 .27176 L
.71853 .27288 L
.70882 .27886 L
.7048 .28147 L
.69911 .28567 L
.69401 .29118 L
.68939 .30034 L
.68913 .30089 L
.68245 .31061 L
.67968 .31369 L
.66997 .31979 L
.66654 .32032 L
.66026 .32308 L
.65054 .327 L
.64454 .33003 L
.64083 .33233 L
.63444 .33974 L
.63708 .34946 L
.63497 .35917 L
.63112 .36182 L
.62141 .36634 L
.61425 .36888 L
.61169 .3697 L
.60198 .37236 L
.59227 .37476 L
.58381 .37859 L
.58256 .37939 L
.57815 .38831 L
.5816 .39802 L
.57284 .40581 L
.56439 .40773 L
.56313 .40798 L
.55342 .40931 L
.54371 .4099 L
.53399 .40992 L
.52428 .40853 L
.51514 .40773 L
.51457 .40765 L
.50486 .4056 L
.49591 .39802 L
.50451 .38831 L
.50486 .38797 L
.51203 .37859 L
.50486 .37337 L
.49514 .37005 L
.49068 .36888 L
.48543 .36856 L
.47572 .36759 L
.46601 .36547 L
.45629 .36158 L
.45202 .35917 L
.44658 .35639 L
.44022 .34946 L
.44082 .33974 L
.43687 .33019 L
.4367 .33003 L
.42716 .32413 L
.41744 .32064 L
.41659 .32032 L
.40773 .3183 L
.39802 .31305 L
.39482 .31061 L
.38831 .30526 L
.38491 .30089 L
.38023 .29118 L
.37859 .28888 L
.37092 .28147 L
.36888 .28009 L
.35917 .27447 L
.35437 .27176 L
.34946 .26946 L
.33974 .26269 L
.33898 .26204 L
.33003 .25347 L
.32903 .25233 L
.3208 .24262 L
.32032 .24212 L
.31061 .2336 L
.30971 .23291 L
.30089 .22673 L
.2959 .22319 L
.29118 .21992 L
.28315 .21348 L
.28147 .21201 L
.27266 .20377 L
.27176 .20287 L
.26255 .19406 L
.26204 .1936 L
.25233 .18533 L
.25112 .18434 L
.24262 .17766 L
.23883 .17463 L
.23291 .16985 L
.22709 .16492 L
.22319 .16149 L
.21618 .15521 L
.21348 .15277 L
.20531 .14549 L
.20377 .14416 L
.19406 .13587 L
.19395 .13578 L
.18434 .12776 L
.18234 .12607 L
.17463 .11952 L
.17096 .11636 L
.16492 .11108 L
.15986 .10664 L
.15521 .10256 L
.14876 .09693 L
.14549 .09411 L
.13749 .08722 L
.13578 .08576 L
.12617 .07751 L
.12607 .07742 L
.11636 .06904 L
.11493 .06779 L
.10664 .06058 L
.10378 .05808 L
.09693 .05212 L
.09263 .04837 L
.08722 .04368 L
.08143 .03866 L
.07751 .03527 L
.07021 .02894 L
.06779 .02684 L
.05903 .01923 L
.98077 .01923 L
F
0 .4 .24 r
.07751 .18126 m
.08722 .17701 L
.09693 .18003 L
.10664 .18346 L
.10934 .18434 L
.11636 .18726 L
.12607 .19162 L
.13135 .19406 L
.13578 .19626 L
.14549 .20129 L
.15009 .20377 L
.15521 .20668 L
.16492 .2124 L
.16673 .21348 L
.17463 .21827 L
.18285 .22319 L
.18434 .22408 L
.19406 .22966 L
.19985 .23291 L
.20377 .23507 L
.21348 .24052 L
.21712 .24262 L
.22319 .24627 L
.23253 .25233 L
.23291 .2526 L
.24262 .25954 L
.24609 .26204 L
.25233 .2664 L
.26065 .27176 L
.26204 .27259 L
.27176 .27802 L
.27835 .28147 L
.28147 .28309 L
.29118 .28835 L
.29594 .29118 L
.30089 .29451 L
.30904 .30089 L
.31061 .30228 L
.3199 .31061 L
.32032 .31094 L
.33003 .31766 L
.335 .32032 L
.33974 .32268 L
.34946 .32698 L
.35678 .33003 L
.35917 .33106 L
.36888 .33588 L
.37456 .33974 L
.37859 .34368 L
.38334 .34946 L
.38831 .35628 L
.39121 .35917 L
.39802 .36448 L
.40773 .36833 L
.41068 .36888 L
.41744 .37115 L
.42716 .37403 L
.43687 .37699 L
.44127 .37859 L
.44658 .38109 L
.45515 .38831 L
.45629 .39341 L
.45673 .39802 L
.46131 .40773 L
.46601 .41022 L
.47572 .41332 L
.48543 .41535 L
.49514 .41693 L
.49864 .41744 L
.50486 .4183 L
.51457 .41951 L
.52428 .42052 L
.53399 .42104 L
.54371 .42639 L
.5451 .42716 L
.54624 .43687 L
.54371 .43916 L
.53562 .44658 L
.53399 .44813 L
.52991 .45629 L
.53399 .45942 L
.54371 .46177 L
.55342 .4626 L
.56313 .46278 L
.57284 .46251 L
.58256 .4618 L
.59227 .4606 L
.60198 .45872 L
.6102 .45629 L
.61169 .45567 L
.62141 .4497 L
.62464 .44658 L
.63112 .43954 L
.63446 .43687 L
.64083 .4332 L
.65054 .42879 L
.65443 .42716 L
.66026 .42487 L
.66997 .42219 L
.67623 .41744 L
.67968 .41478 L
.6852 .40773 L
.68939 .39929 L
.6902 .39802 L
.69911 .39063 L
.70399 .38831 L
.70882 .38624 L
.71853 .38272 L
.72824 .37941 L
.73058 .37859 L
.73796 .3761 L
.74767 .372 L
.75353 .36888 L
.75738 .36638 L
.76709 .35926 L
.76722 .35917 L
.77681 .35258 L
.78233 .34946 L
.78652 .34762 L
.79623 .34419 L
.80594 .34184 L
.81566 .34045 L
.82537 .34014 L
.83508 .34133 L
.84479 .3469 L
.84639 .34946 L
.84938 .35917 L
.84741 .36888 L
.84479 .37601 L
.84317 .37859 L
.84047 .38831 L
.84144 .39802 L
.84479 .40544 L
.84632 .40773 L
.85451 .41543 L
.85871 .41744 L
.86422 .41964 L
.87393 .42228 L
.88364 .4242 L
.89336 .42609 L
.89799 .42716 L
.90307 .4285 L
.91278 .43242 L
.91875 .43687 L
.92249 .44136 L
.92505 .44658 L
.92636 .45629 L
.92426 .46601 L
.92249 .47068 L
.91903 .47572 L
.91278 .48449 L
.91221 .48543 L
.90758 .49514 L
.90758 .50486 L
.91221 .51457 L
.91278 .51551 L
.91903 .52428 L
.92249 .52932 L
.92426 .53399 L
.92636 .54371 L
.92505 .55342 L
.92249 .55864 L
.91875 .56313 L
.91278 .56758 L
.90307 .5715 L
.89799 .57284 L
.89336 .57391 L
.88364 .5758 L
.87393 .57772 L
.86422 .58036 L
.85871 .58256 L
.85451 .58457 L
.84632 .59227 L
.84479 .59456 L
.84144 .60198 L
.84047 .61169 L
.84317 .62141 L
.84479 .62399 L
.84741 .63112 L
.84938 .64083 L
.84639 .65054 L
.84479 .6531 L
.83508 .65867 L
.82537 .65986 L
.81566 .65955 L
.80594 .65816 L
.79623 .65581 L
.78652 .65238 L
.78233 .65054 L
.77681 .64742 L
.76722 .64083 L
.76709 .64074 L
.75738 .63362 L
.75353 .63112 L
.74767 .628 L
.73796 .6239 L
.73058 .62141 L
.72824 .62059 L
.71853 .61728 L
.70882 .61376 L
.70399 .61169 L
.69911 .60937 L
.6902 .60198 L
.68939 .60071 L
.6852 .59227 L
.67968 .58522 L
.67623 .58256 L
.66997 .57781 L
.66026 .57513 L
.65443 .57284 L
.65054 .57121 L
.64083 .5668 L
.63446 .56313 L
.63112 .56046 L
.62464 .55342 L
.62141 .5503 L
.61169 .54433 L
.6102 .54371 L
.60198 .54128 L
.59227 .5394 L
.58256 .5382 L
.57284 .53749 L
.56313 .53722 L
.55342 .5374 L
.54371 .53823 L
.53399 .54058 L
.52991 .54371 L
.53399 .55187 L
.53562 .55342 L
.54371 .56084 L
.54624 .56313 L
.5451 .57284 L
.54371 .57361 L
.53399 .57896 L
.52428 .57948 L
.51457 .58049 L
.50486 .5817 L
.49864 .58256 L
.49514 .58307 L
.48543 .58465 L
.47572 .58668 L
.46601 .58978 L
.46131 .59227 L
.45673 .60198 L
.45629 .60659 L
.45515 .61169 L
.44658 .61891 L
.44127 .62141 L
.43687 .62301 L
.42716 .62597 L
.41744 .62885 L
.41068 .63112 L
.40773 .63167 L
.39802 .63552 L
.39121 .64083 L
.38831 .64372 L
.38334 .65054 L
.37859 .65632 L
.37456 .66026 L
.36888 .66412 L
.35917 .66894 L
.35678 .66997 L
.34946 .67302 L
.33974 .67732 L
.335 .67968 L
.33003 .68234 L
.32032 .68906 L
.3199 .68939 L
.31061 .69772 L
.30904 .69911 L
.30089 .70549 L
.29594 .70882 L
.29118 .71165 L
.28147 .71691 L
.27835 .71853 L
.27176 .72198 L
.26204 .72741 L
.26065 .72824 L
.25233 .7336 L
.24609 .73796 L
.24262 .74046 L
.23291 .7474 L
.23253 .74767 L
.22319 .75373 L
.21712 .75738 L
.21348 .75948 L
.20377 .76493 L
.19985 .76709 L
.19406 .77034 L
.18434 .77592 L
.18285 .77681 L
.17463 .78173 L
.16673 .78652 L
.16492 .7876 L
.15521 .79332 L
.15009 .79623 L
.14549 .79871 L
.13578 .80374 L
.13135 .80594 L
.12607 .80838 L
.11636 .81274 L
.10934 .81566 L
.10664 .81654 L
.09693 .81997 L
.08722 .82299 L
.07751 .81874 L
.07633 .81566 L
.07751 .80836 L
.07825 .80594 L
.08303 .79623 L
.08722 .78972 L
.08942 .78652 L
.09693 .77683 L
.09698 .77681 L
.10509 .76709 L
.10664 .7652 L
.11326 .75738 L
.11636 .75361 L
.12144 .74767 L
.12607 .7423 L
.13015 .73796 L
.13578 .73209 L
.13982 .72824 L
.14549 .72283 L
.15014 .71853 L
.15521 .71365 L
.16007 .70882 L
.16492 .70373 L
.16924 .69911 L
.17463 .69337 L
.17858 .68939 L
.18434 .68398 L
.18943 .67968 L
.19406 .67596 L
.20183 .66997 L
.20377 .66846 L
.21348 .66032 L
.21355 .66026 L
.2231 .65054 L
.22319 .65044 L
.23211 .64083 L
.23291 .64004 L
.24262 .63174 L
.24348 .63112 L
.25233 .62529 L
.25882 .62141 L
.26204 .61956 L
.27176 .61312 L
.27357 .61169 L
.28147 .60405 L
.28319 .60198 L
.29061 .59227 L
.29118 .59158 L
.30079 .58256 L
.30089 .58249 L
.31061 .57702 L
.32032 .57289 L
.32045 .57284 L
.33003 .56948 L
.33974 .56467 L
.34207 .56313 L
.34946 .55663 L
.35132 .55342 L
.35573 .54371 L
.35917 .53622 L
.35982 .53399 L
.36888 .52528 L
.37146 .52428 L
.37859 .52362 L
.38831 .52252 L
.39802 .52155 L
.40773 .52035 L
.41744 .51838 L
.42623 .51457 L
.42716 .51389 L
.4335 .50486 L
.4335 .49514 L
.42716 .48611 L
.42623 .48543 L
.41744 .48162 L
.40773 .47965 L
.39802 .47845 L
.38831 .47748 L
.37859 .47638 L
.37146 .47572 L
.36888 .47472 L
.35982 .46601 L
.35917 .46378 L
.35573 .45629 L
.35132 .44658 L
.34946 .44337 L
.34207 .43687 L
.33974 .43533 L
.33003 .43052 L
.32045 .42716 L
.32032 .42711 L
.31061 .42298 L
.30089 .41751 L
.30079 .41744 L
.29118 .40842 L
.29061 .40773 L
.28319 .39802 L
.28147 .39595 L
.27357 .38831 L
.27176 .38688 L
.26204 .38044 L
.25882 .37859 L
.25233 .37471 L
.24348 .36888 L
.24262 .36826 L
.23291 .35996 L
.23211 .35917 L
.22319 .34956 L
.2231 .34946 L
.21355 .33974 L
.21348 .33968 L
.20377 .33154 L
.20183 .33003 L
.19406 .32404 L
.18943 .32032 L
.18434 .31602 L
.17858 .31061 L
.17463 .30663 L
.16924 .30089 L
.16492 .29627 L
.16007 .29118 L
.15521 .28635 L
.15014 .28147 L
.14549 .27717 L
.13982 .27176 L
.13578 .26791 L
.13015 .26204 L
.12607 .2577 L
.12144 .25233 L
.11636 .24639 L
.11326 .24262 L
.10664 .2348 L
.10509 .23291 L
.09698 .22319 L
.09693 .22317 L
.08942 .21348 L
.08722 .21028 L
.08303 .20377 L
.07825 .19406 L
.07751 .19164 L
.07633 .18434 L
F
0 .01 .1 r
.93967 .98077 m
.93221 .97381 L
.92926 .97106 L
.92249 .96474 L
.91887 .96134 L
.91278 .95563 L
.90854 .95163 L
.90307 .94647 L
.89824 .94192 L
.89336 .93734 L
.88787 .93221 L
.88364 .92828 L
.87739 .92249 L
.87393 .91928 L
.86695 .91278 L
.86422 .91021 L
.8567 .90307 L
.85451 .90097 L
.84658 .89336 L
.84479 .89166 L
.83624 .88364 L
.83508 .88258 L
.82554 .87393 L
.82537 .87378 L
.81566 .86494 L
.81487 .86422 L
.80594 .85562 L
.80482 .85451 L
.79623 .84583 L
.79521 .84479 L
.78652 .83644 L
.78503 .83508 L
.77681 .82793 L
.77371 .82537 L
.76709 .81981 L
.7623 .81566 L
.75738 .81093 L
.75262 .80594 L
.74767 .8002 L
.74439 .79623 L
.73796 .78944 L
.73481 .78652 L
.72824 .78111 L
.72199 .77681 L
.71853 .77442 L
.70882 .76741 L
.70844 .76709 L
.69948 .75738 L
.69911 .75672 L
.69453 .74767 L
.68939 .74021 L
.6865 .73796 L
.67968 .73229 L
.67041 .72824 L
.66997 .72804 L
.66026 .72381 L
.65147 .71853 L
.65054 .71784 L
.64418 .70882 L
.64615 .69911 L
.64123 .68939 L
.64083 .68914 L
.63112 .68429 L
.62141 .68073 L
.61815 .67968 L
.61169 .67912 L
.60198 .6752 L
.59227 .67247 L
.58472 .66997 L
.58256 .66867 L
.58243 .66026 L
.58256 .66019 L
.59227 .65517 L
.59969 .65054 L
.60141 .64083 L
.59227 .63687 L
.58256 .63412 L
.57284 .63201 L
.56836 .63112 L
.56313 .63041 L
.55342 .62941 L
.54371 .62932 L
.53399 .63027 L
.52758 .63112 L
.52428 .63178 L
.51457 .63169 L
.50486 .63253 L
.49514 .63385 L
.48543 .63586 L
.47572 .63882 L
.47063 .64083 L
.46601 .64235 L
.45629 .64798 L
.45472 .65054 L
.45629 .65612 L
.45971 .66026 L
.46319 .66997 L
.45629 .67459 L
.44658 .67847 L
.44297 .67968 L
.43687 .68003 L
.42716 .6826 L
.41744 .68808 L
.41563 .68939 L
.40773 .6951 L
.40484 .69911 L
.40388 .70882 L
.39868 .71853 L
.39802 .71921 L
.38831 .72505 L
.38152 .72824 L
.37859 .72898 L
.36888 .73389 L
.36379 .73796 L
.35917 .74188 L
.35422 .74767 L
.34946 .75609 L
.34872 .75738 L
.33975 .76709 L
.33974 .7671 L
.33003 .77386 L
.32565 .77681 L
.32032 .78003 L
.31223 .78652 L
.31061 .78789 L
.30251 .79623 L
.30089 .79822 L
.29415 .80594 L
.29118 .80898 L
.2839 .81566 L
.28147 .81762 L
.27177 .82537 L
.27176 .82538 L
.26204 .83339 L
.26017 .83508 L
.25233 .84254 L
.25006 .84479 L
.24262 .85227 L
.24031 .85451 L
.23291 .86139 L
.22976 .86422 L
.22319 .86991 L
.21858 .87393 L
.21348 .8784 L
.20769 .88364 L
.20377 .88728 L
.19732 .89336 L
.19406 .89646 L
.18704 .90307 L
.18434 .90557 L
.17646 .91278 L
.17463 .91443 L
.16571 .92249 L
.16492 .9232 L
.15521 .93207 L
.15506 .93221 L
.14549 .94108 L
.14459 .94192 L
.13578 .95011 L
.13414 .95163 L
.12607 .95907 L
.12359 .96134 L
.11636 .96796 L
.11299 .97106 L
.10664 .9769 L
.10243 .98077 L
F
.93967 .01923 m
.93221 .02619 L
.92926 .02894 L
.92249 .03526 L
.91887 .03866 L
.91278 .04437 L
.90854 .04837 L
.90307 .05353 L
.89824 .05808 L
.89336 .06266 L
.88787 .06779 L
.88364 .07172 L
.87739 .07751 L
.87393 .08072 L
.86695 .08722 L
.86422 .08979 L
.8567 .09693 L
.85451 .09903 L
.84658 .10664 L
.84479 .10834 L
.83624 .11636 L
.83508 .11742 L
.82554 .12607 L
.82537 .12622 L
.81566 .13506 L
.81487 .13578 L
.80594 .14438 L
.80482 .14549 L
.79623 .15417 L
.79521 .15521 L
.78652 .16356 L
.78503 .16492 L
.77681 .17207 L
.77371 .17463 L
.76709 .18019 L
.7623 .18434 L
.75738 .18907 L
.75262 .19406 L
.74767 .1998 L
.74439 .20377 L
.73796 .21056 L
.73481 .21348 L
.72824 .21889 L
.72199 .22319 L
.71853 .22558 L
.70882 .23259 L
.70844 .23291 L
.69948 .24262 L
.69911 .24328 L
.69453 .25233 L
.68939 .25979 L
.6865 .26204 L
.67968 .26771 L
.67041 .27176 L
.66997 .27196 L
.66026 .27619 L
.65147 .28147 L
.65054 .28216 L
.64418 .29118 L
.64615 .30089 L
.64123 .31061 L
.64083 .31086 L
.63112 .31571 L
.62141 .31927 L
.61815 .32032 L
.61169 .32088 L
.60198 .3248 L
.59227 .32753 L
.58472 .33003 L
.58256 .33133 L
.58243 .33974 L
.58256 .33981 L
.59227 .34483 L
.59969 .34946 L
.60141 .35917 L
.59227 .36313 L
.58256 .36588 L
.57284 .36799 L
.56836 .36888 L
.56313 .36959 L
.55342 .37059 L
.54371 .37068 L
.53399 .36973 L
.52758 .36888 L
.52428 .36822 L
.51457 .36831 L
.50486 .36747 L
.49514 .36615 L
.48543 .36414 L
.47572 .36118 L
.47063 .35917 L
.46601 .35765 L
.45629 .35202 L
.45472 .34946 L
.45629 .34388 L
.45971 .33974 L
.46319 .33003 L
.45629 .32541 L
.44658 .32153 L
.44297 .32032 L
.43687 .31997 L
.42716 .3174 L
.41744 .31192 L
.41563 .31061 L
.40773 .3049 L
.40484 .30089 L
.40388 .29118 L
.39868 .28147 L
.39802 .28079 L
.38831 .27495 L
.38152 .27176 L
.37859 .27102 L
.36888 .26611 L
.36379 .26204 L
.35917 .25812 L
.35422 .25233 L
.34946 .24391 L
.34872 .24262 L
.33975 .23291 L
.33974 .2329 L
.33003 .22614 L
.32565 .22319 L
.32032 .21997 L
.31223 .21348 L
.31061 .21211 L
.30251 .20377 L
.30089 .20178 L
.29415 .19406 L
.29118 .19102 L
.2839 .18434 L
.28147 .18238 L
.27177 .17463 L
.27176 .17462 L
.26204 .16661 L
.26017 .16492 L
.25233 .15746 L
.25006 .15521 L
.24262 .14773 L
.24031 .14549 L
.23291 .13861 L
.22976 .13578 L
.22319 .13009 L
.21858 .12607 L
.21348 .1216 L
.20769 .11636 L
.20377 .11272 L
.19732 .10664 L
.19406 .10354 L
.18704 .09693 L
.18434 .09443 L
.17646 .08722 L
.17463 .08557 L
.16571 .07751 L
.16492 .0768 L
.15521 .06793 L
.15506 .06779 L
.14549 .05892 L
.14459 .05808 L
.13578 .04989 L
.13414 .04837 L
.12607 .04093 L
.12359 .03866 L
.11636 .03204 L
.11299 .02894 L
.10664 .0231 L
.10243 .01923 L
F
0 .43 .202 r
.12607 .20915 m
.13578 .21211 L
.13974 .21348 L
.14549 .2155 L
.15521 .21977 L
.16291 .22319 L
.16492 .22431 L
.17463 .22892 L
.18298 .23291 L
.18434 .23358 L
.19406 .23824 L
.20273 .24262 L
.20377 .24316 L
.21348 .24844 L
.22002 .25233 L
.22319 .25437 L
.23291 .26086 L
.23466 .26204 L
.24262 .26732 L
.24981 .27176 L
.25233 .2732 L
.26204 .2784 L
.26816 .28147 L
.27176 .28324 L
.28147 .28819 L
.28686 .29118 L
.29118 .29382 L
.30089 .30082 L
.30098 .30089 L
.31061 .30923 L
.31223 .31061 L
.32032 .31641 L
.32716 .32032 L
.33003 .32179 L
.33974 .32618 L
.34919 .33003 L
.34946 .33014 L
.35917 .33442 L
.36816 .33974 L
.36888 .3403 L
.3778 .34946 L
.37859 .35059 L
.38565 .35917 L
.38831 .36156 L
.39802 .36721 L
.40421 .36888 L
.40773 .37014 L
.41744 .37317 L
.42716 .37597 L
.43525 .37859 L
.43687 .37889 L
.44658 .38437 L
.45072 .38831 L
.45303 .39802 L
.45629 .40681 L
.45723 .40773 L
.46601 .41203 L
.47572 .41467 L
.48543 .41652 L
.4912 .41744 L
.49514 .41804 L
.50486 .41937 L
.51457 .42058 L
.52428 .42172 L
.53399 .42321 L
.53993 .42716 L
.54304 .43687 L
.53399 .44587 L
.53334 .44658 L
.52744 .45629 L
.53399 .46068 L
.54371 .46251 L
.55342 .4632 L
.56313 .46333 L
.57284 .46304 L
.58256 .46237 L
.59227 .46124 L
.60198 .4595 L
.61169 .45681 L
.61312 .45629 L
.62141 .45191 L
.62781 .44658 L
.63112 .44316 L
.63925 .43687 L
.64083 .43599 L
.65054 .43156 L
.66026 .42773 L
.66174 .42716 L
.66997 .42568 L
.67968 .42096 L
.68439 .41744 L
.68939 .41345 L
.69382 .40773 L
.69911 .39982 L
.70056 .39802 L
.70882 .39215 L
.71797 .38831 L
.71853 .3881 L
.72824 .38489 L
.73796 .38208 L
.74767 .37933 L
.75013 .37859 L
.75738 .37656 L
.76709 .37341 L
.77681 .36977 L
.77812 .36888 L
.78652 .36564 L
.79623 .3621 L
.80594 .36059 L
.81566 .36435 L
.81774 .36888 L
.81849 .37859 L
.82058 .38831 L
.82395 .39802 L
.82537 .4019 L
.82788 .40773 L
.83269 .41744 L
.83508 .42102 L
.8417 .42716 L
.84479 .42891 L
.85451 .43233 L
.86422 .43446 L
.87393 .43645 L
.87573 .43687 L
.88364 .43861 L
.89336 .44246 L
.89767 .44658 L
.90224 .45629 L
.89996 .46601 L
.89426 .47572 L
.89336 .47712 L
.88906 .48543 L
.88643 .49514 L
.88643 .50486 L
.88906 .51457 L
.89336 .52288 L
.89426 .52428 L
.89996 .53399 L
.90224 .54371 L
.89767 .55342 L
.89336 .55754 L
.88364 .56139 L
.87573 .56313 L
.87393 .56355 L
.86422 .56554 L
.85451 .56767 L
.84479 .57109 L
.8417 .57284 L
.83508 .57898 L
.83269 .58256 L
.82788 .59227 L
.82537 .5981 L
.82395 .60198 L
.82058 .61169 L
.81849 .62141 L
.81774 .63112 L
.81566 .63565 L
.80594 .63941 L
.79623 .6379 L
.78652 .63436 L
.77812 .63112 L
.77681 .63023 L
.76709 .62659 L
.75738 .62344 L
.75013 .62141 L
.74767 .62067 L
.73796 .61792 L
.72824 .61511 L
.71853 .6119 L
.71797 .61169 L
.70882 .60785 L
.70056 .60198 L
.69911 .60018 L
.69382 .59227 L
.68939 .58655 L
.68439 .58256 L
.67968 .57904 L
.66997 .57432 L
.66174 .57284 L
.66026 .57227 L
.65054 .56844 L
.64083 .56401 L
.63925 .56313 L
.63112 .55684 L
.62781 .55342 L
.62141 .54809 L
.61312 .54371 L
.61169 .54319 L
.60198 .5405 L
.59227 .53876 L
.58256 .53763 L
.57284 .53696 L
.56313 .53667 L
.55342 .5368 L
.54371 .53749 L
.53399 .53932 L
.52744 .54371 L
.53334 .55342 L
.53399 .55413 L
.54304 .56313 L
.53993 .57284 L
.53399 .57679 L
.52428 .57828 L
.51457 .57942 L
.50486 .58063 L
.49514 .58196 L
.4912 .58256 L
.48543 .58348 L
.47572 .58533 L
.46601 .58797 L
.45723 .59227 L
.45629 .59319 L
.45303 .60198 L
.45072 .61169 L
.44658 .61563 L
.43687 .62111 L
.43525 .62141 L
.42716 .62403 L
.41744 .62683 L
.40773 .62986 L
.40421 .63112 L
.39802 .63279 L
.38831 .63844 L
.38565 .64083 L
.37859 .64941 L
.3778 .65054 L
.36888 .6597 L
.36816 .66026 L
.35917 .66558 L
.34946 .66986 L
.34919 .66997 L
.33974 .67382 L
.33003 .67821 L
.32716 .67968 L
.32032 .68359 L
.31223 .68939 L
.31061 .69077 L
.30098 .69911 L
.30089 .69918 L
.29118 .70618 L
.28686 .70882 L
.28147 .71181 L
.27176 .71676 L
.26816 .71853 L
.26204 .7216 L
.25233 .7268 L
.24981 .72824 L
.24262 .73268 L
.23466 .73796 L
.23291 .73914 L
.22319 .74563 L
.22002 .74767 L
.21348 .75156 L
.20377 .75684 L
.20273 .75738 L
.19406 .76176 L
.18434 .76642 L
.18298 .76709 L
.17463 .77108 L
.16492 .77569 L
.16291 .77681 L
.15521 .78023 L
.14549 .7845 L
.13974 .78652 L
.13578 .78789 L
.12607 .79085 L
.11702 .78652 L
.11756 .77681 L
.12252 .76709 L
.12607 .76105 L
.12825 .75738 L
.13473 .74767 L
.13578 .74608 L
.14236 .73796 L
.14549 .73419 L
.15137 .72824 L
.15521 .72425 L
.16099 .71853 L
.16492 .71437 L
.17 .70882 L
.17463 .70341 L
.17833 .69911 L
.18434 .69233 L
.18725 .68939 L
.19406 .68295 L
.19804 .67968 L
.20377 .67503 L
.21021 .66997 L
.21348 .66727 L
.22119 .66026 L
.22319 .65819 L
.23001 .65054 L
.23291 .6472 L
.23882 .64083 L
.24262 .63725 L
.25054 .63112 L
.25233 .62989 L
.26204 .62379 L
.26602 .62141 L
.27176 .61784 L
.27978 .61169 L
.28147 .61012 L
.2885 .60198 L
.29118 .59834 L
.29588 .59227 L
.30089 .58712 L
.30701 .58256 L
.31061 .58044 L
.32032 .57583 L
.32765 .57284 L
.33003 .57201 L
.33974 .56795 L
.34717 .56313 L
.34946 .56157 L
.3552 .55342 L
.35917 .54462 L
.35957 .54371 L
.36553 .53399 L
.36888 .53165 L
.37859 .52638 L
.3874 .52428 L
.38831 .52417 L
.39802 .52306 L
.40773 .52185 L
.41744 .52017 L
.42716 .51662 L
.43 .51457 L
.4357 .50486 L
.4357 .49514 L
.43 .48543 L
.42716 .48338 L
.41744 .47983 L
.40773 .47815 L
.39802 .47694 L
.38831 .47583 L
.3874 .47572 L
.37859 .47362 L
.36888 .46835 L
.36553 .46601 L
.35957 .45629 L
.35917 .45538 L
.3552 .44658 L
.34946 .43843 L
.34717 .43687 L
.33974 .43205 L
.33003 .42799 L
.32765 .42716 L
.32032 .42417 L
.31061 .41956 L
.30701 .41744 L
.30089 .41288 L
.29588 .40773 L
.29118 .40166 L
.2885 .39802 L
.28147 .38988 L
.27978 .38831 L
.27176 .38216 L
.26602 .37859 L
.26204 .37621 L
.25233 .37011 L
.25054 .36888 L
.24262 .36275 L
.23882 .35917 L
.23291 .3528 L
.23001 .34946 L
.22319 .34181 L
.22119 .33974 L
.21348 .33273 L
.21021 .33003 L
.20377 .32497 L
.19804 .32032 L
.19406 .31705 L
.18725 .31061 L
.18434 .30767 L
.17833 .30089 L
.17463 .29659 L
.17 .29118 L
.16492 .28563 L
.16099 .28147 L
.15521 .27575 L
.15137 .27176 L
.14549 .26581 L
.14236 .26204 L
.13578 .25392 L
.13473 .25233 L
.12825 .24262 L
.12607 .23895 L
.12252 .23291 L
.11756 .22319 L
.11702 .21348 L
F
0 .46 .156 r
.15521 .23956 m
.16492 .23857 L
.17463 .24095 L
.17994 .24262 L
.18434 .24387 L
.19406 .24773 L
.20363 .25233 L
.20377 .25241 L
.21348 .25769 L
.22084 .26204 L
.22319 .26354 L
.23291 .26936 L
.23718 .27176 L
.24262 .27464 L
.25233 .27942 L
.25674 .28147 L
.26204 .28388 L
.27176 .28848 L
.27705 .29118 L
.28147 .2936 L
.29118 .29995 L
.29247 .30089 L
.30089 .30786 L
.30422 .31061 L
.31061 .31528 L
.31904 .32032 L
.32032 .32098 L
.33003 .32547 L
.33974 .32937 L
.34143 .33003 L
.34946 .33329 L
.35917 .33815 L
.3617 .33974 L
.36888 .34576 L
.37226 .34946 L
.37859 .35763 L
.38011 .35917 L
.38831 .36537 L
.39783 .36888 L
.39802 .36895 L
.40773 .37225 L
.41744 .37504 L
.42716 .37788 L
.42932 .37859 L
.43687 .38039 L
.44638 .38831 L
.44658 .38862 L
.44941 .39802 L
.45326 .40773 L
.45629 .40978 L
.46601 .4136 L
.47572 .4159 L
.48434 .41744 L
.48543 .41763 L
.49514 .4191 L
.50486 .42039 L
.51457 .42165 L
.52428 .42307 L
.53399 .42633 L
.53503 .42716 L
.53996 .43687 L
.53399 .44341 L
.5311 .44658 L
.52508 .45629 L
.53399 .46171 L
.54371 .46319 L
.55342 .46376 L
.56313 .46384 L
.57284 .46355 L
.58256 .4629 L
.59227 .46184 L
.60198 .46023 L
.61169 .45778 L
.616 .45629 L
.62141 .45366 L
.63096 .44658 L
.63112 .44642 L
.64083 .43877 L
.64404 .43687 L
.65054 .434 L
.66026 .43036 L
.66925 .42716 L
.66997 .42709 L
.67968 .4249 L
.68939 .41998 L
.69291 .41744 L
.69911 .41199 L
.7029 .40773 L
.70882 .40085 L
.71181 .39802 L
.71853 .39401 L
.72824 .39028 L
.73539 .38831 L
.73796 .38767 L
.74767 .38554 L
.75738 .38385 L
.76709 .38263 L
.77681 .38213 L
.78652 .38296 L
.79623 .38637 L
.79936 .38831 L
.80594 .39483 L
.80819 .39802 L
.81289 .40773 L
.81515 .41744 L
.81541 .42716 L
.81566 .43683 L
.81567 .43687 L
.82537 .44618 L
.82657 .44658 L
.83508 .44859 L
.84479 .44994 L
.85451 .45145 L
.86422 .45413 L
.86793 .45629 L
.8733 .46601 L
.87284 .47572 L
.87189 .48543 L
.87142 .49514 L
.87142 .50486 L
.87189 .51457 L
.87284 .52428 L
.8733 .53399 L
.86793 .54371 L
.86422 .54587 L
.85451 .54855 L
.84479 .55006 L
.83508 .55141 L
.82657 .55342 L
.82537 .55382 L
.81567 .56313 L
.81566 .56317 L
.81541 .57284 L
.81515 .58256 L
.81289 .59227 L
.80819 .60198 L
.80594 .60517 L
.79936 .61169 L
.79623 .61363 L
.78652 .61704 L
.77681 .61787 L
.76709 .61737 L
.75738 .61615 L
.74767 .61446 L
.73796 .61233 L
.73539 .61169 L
.72824 .60972 L
.71853 .60599 L
.71181 .60198 L
.70882 .59915 L
.7029 .59227 L
.69911 .58801 L
.69291 .58256 L
.68939 .58002 L
.67968 .5751 L
.66997 .57291 L
.66925 .57284 L
.66026 .56964 L
.65054 .566 L
.64404 .56313 L
.64083 .56123 L
.63112 .55358 L
.63096 .55342 L
.62141 .54634 L
.616 .54371 L
.61169 .54222 L
.60198 .53977 L
.59227 .53816 L
.58256 .5371 L
.57284 .53645 L
.56313 .53616 L
.55342 .53624 L
.54371 .53681 L
.53399 .53829 L
.52508 .54371 L
.5311 .55342 L
.53399 .55659 L
.53996 .56313 L
.53503 .57284 L
.53399 .57367 L
.52428 .57693 L
.51457 .57835 L
.50486 .57961 L
.49514 .5809 L
.48543 .58237 L
.48434 .58256 L
.47572 .5841 L
.46601 .5864 L
.45629 .59022 L
.45326 .59227 L
.44941 .60198 L
.44658 .61138 L
.44638 .61169 L
.43687 .61961 L
.42932 .62141 L
.42716 .62212 L
.41744 .62496 L
.40773 .62775 L
.39802 .63105 L
.39783 .63112 L
.38831 .63463 L
.38011 .64083 L
.37859 .64237 L
.37226 .65054 L
.36888 .65424 L
.3617 .66026 L
.35917 .66185 L
.34946 .66671 L
.34143 .66997 L
.33974 .67063 L
.33003 .67453 L
.32032 .67902 L
.31904 .67968 L
.31061 .68472 L
.30422 .68939 L
.30089 .69214 L
.29247 .69911 L
.29118 .70005 L
.28147 .7064 L
.27705 .70882 L
.27176 .71152 L
.26204 .71612 L
.25674 .71853 L
.25233 .72058 L
.24262 .72536 L
.23718 .72824 L
.23291 .73064 L
.22319 .73646 L
.22084 .73796 L
.21348 .74231 L
.20377 .74759 L
.20363 .74767 L
.19406 .75227 L
.18434 .75613 L
.17994 .75738 L
.17463 .75905 L
.16492 .76143 L
.15521 .76044 L
.15018 .75738 L
.15152 .74767 L
.15521 .74052 L
.15679 .73796 L
.16454 .72824 L
.16492 .72776 L
.17286 .71853 L
.17463 .71629 L
.18041 .70882 L
.18434 .70334 L
.18762 .69911 L
.19406 .69122 L
.19602 .68939 L
.20377 .68193 L
.20668 .67968 L
.21348 .67405 L
.2185 .66997 L
.22319 .66573 L
.22858 .66026 L
.23291 .65518 L
.23662 .65054 L
.24262 .64347 L
.24522 .64083 L
.25233 .63455 L
.25727 .63112 L
.26204 .62799 L
.27176 .62204 L
.27278 .62141 L
.28147 .61532 L
.28552 .61169 L
.29118 .60503 L
.2934 .60198 L
.30075 .59227 L
.30089 .5921 L
.31061 .5838 L
.31272 .58256 L
.32032 .57862 L
.33003 .57448 L
.33402 .57284 L
.33974 .57062 L
.34946 .56505 L
.35169 .56313 L
.35866 .55342 L
.35917 .55236 L
.36319 .54371 L
.36888 .53555 L
.37054 .53399 L
.37859 .52936 L
.38831 .52625 L
.39796 .52428 L
.39802 .52427 L
.40773 .52308 L
.41744 .52161 L
.42716 .51896 L
.43338 .51457 L
.43687 .50908 L
.43773 .50486 L
.43773 .49514 L
.43687 .49092 L
.43338 .48543 L
.42716 .48104 L
.41744 .47839 L
.40773 .47692 L
.39802 .47573 L
.39796 .47572 L
.38831 .47375 L
.37859 .47064 L
.37054 .46601 L
.36888 .46445 L
.36319 .45629 L
.35917 .44764 L
.35866 .44658 L
.35169 .43687 L
.34946 .43495 L
.33974 .42938 L
.33402 .42716 L
.33003 .42552 L
.32032 .42138 L
.31272 .41744 L
.31061 .4162 L
.30089 .4079 L
.30075 .40773 L
.2934 .39802 L
.29118 .39497 L
.28552 .38831 L
.28147 .38468 L
.27278 .37859 L
.27176 .37796 L
.26204 .37201 L
.25727 .36888 L
.25233 .36545 L
.24522 .35917 L
.24262 .35653 L
.23662 .34946 L
.23291 .34482 L
.22858 .33974 L
.22319 .33427 L
.2185 .33003 L
.21348 .32595 L
.20668 .32032 L
.20377 .31807 L
.19602 .31061 L
.19406 .30878 L
.18762 .30089 L
.18434 .29666 L
.18041 .29118 L
.17463 .28371 L
.17286 .28147 L
.16492 .27224 L
.16454 .27176 L
.15679 .26204 L
.15521 .25948 L
.15152 .25233 L
.15018 .24262 L
F
0 .49 .103 r
.18434 .26261 m
.19406 .26239 L
.20377 .26529 L
.21348 .26948 L
.21956 .27176 L
.22319 .27366 L
.23291 .2777 L
.24227 .28147 L
.24262 .28162 L
.25233 .28539 L
.26204 .28951 L
.26572 .29118 L
.27176 .29405 L
.28147 .29982 L
.28306 .30089 L
.29118 .30716 L
.29554 .31061 L
.30089 .31454 L
.31035 .32032 L
.31061 .32046 L
.32032 .32497 L
.33003 .32881 L
.33329 .33003 L
.33974 .33247 L
.34946 .33667 L
.35507 .33974 L
.35917 .34247 L
.36663 .34946 L
.36888 .35226 L
.37453 .35917 L
.37859 .36271 L
.38831 .36795 L
.39144 .36888 L
.39802 .37126 L
.40773 .37416 L
.41744 .37683 L
.42339 .37859 L
.42716 .37947 L
.43687 .38294 L
.44208 .38831 L
.44584 .39802 L
.44658 .40247 L
.44938 .40773 L
.45629 .4119 L
.46601 .41501 L
.47572 .41706 L
.47788 .41744 L
.48543 .41871 L
.49514 .4201 L
.50486 .42138 L
.51457 .42274 L
.52428 .42464 L
.53032 .42716 L
.53399 .42926 L
.53703 .43687 L
.53399 .44078 L
.52894 .44658 L
.52428 .45204 L
.52278 .45629 L
.52428 .45881 L
.53399 .4626 L
.54371 .46382 L
.55342 .46429 L
.56313 .46433 L
.57284 .46404 L
.58256 .46342 L
.59227 .46242 L
.60198 .46091 L
.61169 .45867 L
.61883 .45629 L
.62141 .45512 L
.63112 .44908 L
.63413 .44658 L
.64083 .44148 L
.64894 .43687 L
.65054 .4362 L
.66026 .43266 L
.66997 .4295 L
.67722 .42716 L
.67968 .42684 L
.68939 .42433 L
.69911 .41954 L
.70223 .41744 L
.70882 .41183 L
.71303 .40773 L
.71853 .40275 L
.72541 .39802 L
.72824 .39671 L
.73796 .39341 L
.74767 .39141 L
.75738 .39033 L
.76709 .39017 L
.77681 .39127 L
.78652 .39465 L
.79142 .39802 L
.79623 .40338 L
.7986 .40773 L
.7999 .41744 L
.79715 .42716 L
.79623 .42949 L
.79418 .43687 L
.79623 .44554 L
.79685 .44658 L
.80594 .45417 L
.81009 .45629 L
.81566 .45857 L
.82537 .46153 L
.83508 .46427 L
.83992 .46601 L
.84479 .46832 L
.85318 .47572 L
.85451 .47758 L
.8575 .48543 L
.85904 .49514 L
.85904 .50486 L
.8575 .51457 L
.85451 .52242 L
.85318 .52428 L
.84479 .53168 L
.83992 .53399 L
.83508 .53573 L
.82537 .53847 L
.81566 .54143 L
.81009 .54371 L
.80594 .54583 L
.79685 .55342 L
.79623 .55446 L
.79418 .56313 L
.79623 .57051 L
.79715 .57284 L
.7999 .58256 L
.7986 .59227 L
.79623 .59662 L
.79142 .60198 L
.78652 .60535 L
.77681 .60873 L
.76709 .60983 L
.75738 .60967 L
.74767 .60859 L
.73796 .60659 L
.72824 .60329 L
.72541 .60198 L
.71853 .59725 L
.71303 .59227 L
.70882 .58817 L
.70223 .58256 L
.69911 .58046 L
.68939 .57567 L
.67968 .57316 L
.67722 .57284 L
.66997 .5705 L
.66026 .56734 L
.65054 .5638 L
.64894 .56313 L
.64083 .55852 L
.63413 .55342 L
.63112 .55092 L
.62141 .54488 L
.61883 .54371 L
.61169 .54133 L
.60198 .53909 L
.59227 .53758 L
.58256 .53658 L
.57284 .53596 L
.56313 .53567 L
.55342 .53571 L
.54371 .53618 L
.53399 .5374 L
.52428 .54119 L
.52278 .54371 L
.52428 .54796 L
.52894 .55342 L
.53399 .55922 L
.53703 .56313 L
.53399 .57074 L
.53032 .57284 L
.52428 .57536 L
.51457 .57726 L
.50486 .57862 L
.49514 .5799 L
.48543 .58129 L
.47788 .58256 L
.47572 .58294 L
.46601 .58499 L
.45629 .5881 L
.44938 .59227 L
.44658 .59753 L
.44584 .60198 L
.44208 .61169 L
.43687 .61706 L
.42716 .62053 L
.42339 .62141 L
.41744 .62317 L
.40773 .62584 L
.39802 .62874 L
.39144 .63112 L
.38831 .63205 L
.37859 .63729 L
.37453 .64083 L
.36888 .64774 L
.36663 .65054 L
.35917 .65753 L
.35507 .66026 L
.34946 .66333 L
.33974 .66753 L
.33329 .66997 L
.33003 .67119 L
.32032 .67503 L
.31061 .67954 L
.31035 .67968 L
.30089 .68546 L
.29554 .68939 L
.29118 .69284 L
.28306 .69911 L
.28147 .70018 L
.27176 .70595 L
.26572 .70882 L
.26204 .71049 L
.25233 .71461 L
.24262 .71838 L
.24227 .71853 L
.23291 .7223 L
.22319 .72634 L
.21956 .72824 L
.21348 .73052 L
.20377 .73471 L
.19406 .73761 L
.18434 .73739 L
.18322 .72824 L
.18434 .72569 L
.18748 .71853 L
.1922 .70882 L
.19406 .7041 L
.19762 .69911 L
.20377 .6911 L
.20528 .68939 L
.21348 .68115 L
.21573 .67968 L
.22319 .67324 L
.227 .66997 L
.23291 .66387 L
.23594 .66026 L
.24262 .6512 L
.2431 .65054 L
.2515 .64083 L
.25233 .64 L
.26204 .63222 L
.26387 .63112 L
.27176 .62611 L
.27931 .62141 L
.28147 .61994 L
.29094 .61169 L
.29118 .61142 L
.29804 .60198 L
.30089 .59784 L
.30538 .59227 L
.31061 .58733 L
.31813 .58256 L
.32032 .58139 L
.33003 .57695 L
.33974 .5729 L
.33987 .57284 L
.34946 .56833 L
.35583 .56313 L
.35917 .55866 L
.36193 .55342 L
.36651 .54371 L
.36888 .54006 L
.37519 .53399 L
.37859 .53202 L
.38831 .52822 L
.39802 .52587 L
.40631 .52428 L
.40773 .5241 L
.41744 .52279 L
.42716 .52079 L
.43626 .51457 L
.43687 .5138 L
.43976 .50486 L
.43976 .49514 L
.43687 .4862 L
.43626 .48543 L
.42716 .47921 L
.41744 .47721 L
.40773 .4759 L
.40631 .47572 L
.39802 .47413 L
.38831 .47178 L
.37859 .46798 L
.37519 .46601 L
.36888 .45994 L
.36651 .45629 L
.36193 .44658 L
.35917 .44134 L
.35583 .43687 L
.34946 .43167 L
.33987 .42716 L
.33974 .4271 L
.33003 .42305 L
.32032 .41861 L
.31813 .41744 L
.31061 .41267 L
.30538 .40773 L
.30089 .40216 L
.29804 .39802 L
.29118 .38858 L
.29094 .38831 L
.28147 .38006 L
.27931 .37859 L
.27176 .37389 L
.26387 .36888 L
.26204 .36778 L
.25233 .36 L
.2515 .35917 L
.2431 .34946 L
.24262 .3488 L
.23594 .33974 L
.23291 .33613 L
.227 .33003 L
.22319 .32676 L
.21573 .32032 L
.21348 .31885 L
.20528 .31061 L
.20377 .3089 L
.19762 .30089 L
.19406 .2959 L
.1922 .29118 L
.18748 .28147 L
.18434 .27431 L
.18322 .27176 L
F
0 .188 .25 r
.19406 .4884 m
.20377 .48704 L
.21348 .4876 L
.22319 .48976 L
.23201 .49514 L
.23201 .50486 L
.22319 .51024 L
.21348 .5124 L
.20377 .51296 L
.19406 .5116 L
.1866 .50486 L
.1866 .49514 L
F
0 .52 .042 r
.21348 .28533 m
.22319 .284 L
.23291 .28597 L
.24262 .28866 L
.25069 .29118 L
.25233 .29174 L
.26204 .29556 L
.27176 .30087 L
.27179 .30089 L
.28147 .3076 L
.28556 .31061 L
.29118 .31467 L
.30054 .32032 L
.30089 .3205 L
.31061 .32488 L
.32032 .32858 L
.32443 .33003 L
.33003 .33198 L
.33974 .33571 L
.3481 .33974 L
.34946 .34043 L
.35917 .34776 L
.36083 .34946 L
.3688 .35917 L
.36888 .35925 L
.37859 .36638 L
.38494 .36888 L
.38831 .37019 L
.39802 .37331 L
.40773 .37595 L
.41739 .37859 L
.41744 .37861 L
.42716 .38113 L
.43687 .38712 L
.4378 .38831 L
.4423 .39802 L
.44556 .40773 L
.44658 .40867 L
.45629 .41368 L
.46601 .4163 L
.47172 .41744 L
.47572 .41819 L
.48543 .41972 L
.49514 .42105 L
.50486 .42236 L
.51457 .42388 L
.52428 .42648 L
.52575 .42716 L
.53399 .43383 L
.53422 .43687 L
.53399 .43729 L
.52683 .44658 L
.52428 .44936 L
.52052 .45629 L
.52428 .46071 L
.53399 .4634 L
.54371 .46441 L
.55342 .4648 L
.56313 .46481 L
.57284 .46451 L
.58256 .46391 L
.59227 .46296 L
.60198 .46156 L
.61169 .4595 L
.62141 .45642 L
.62164 .45629 L
.63112 .4513 L
.63734 .44658 L
.64083 .44405 L
.65054 .43845 L
.65402 .43687 L
.66026 .43472 L
.66997 .43178 L
.67968 .42902 L
.68613 .42716 L
.68939 .42668 L
.69911 .42421 L
.70882 .42005 L
.71326 .41744 L
.71853 .41393 L
.72576 .40773 L
.72824 .40607 L
.73796 .401 L
.74767 .39849 L
.75281 .39802 L
.75738 .39784 L
.76163 .39802 L
.76709 .39878 L
.77681 .40238 L
.7828 .40773 L
.7845 .41744 L
.78128 .42716 L
.77982 .43687 L
.78328 .44658 L
.78652 .45085 L
.79231 .45629 L
.79623 .45915 L
.80594 .46396 L
.8119 .46601 L
.81566 .46739 L
.82537 .47106 L
.83468 .47572 L
.83508 .47595 L
.84449 .48543 L
.84479 .48597 L
.84796 .49514 L
.84796 .50486 L
.84479 .51403 L
.84449 .51457 L
.83508 .52405 L
.83468 .52428 L
.82537 .52894 L
.81566 .53261 L
.8119 .53399 L
.80594 .53604 L
.79623 .54085 L
.79231 .54371 L
.78652 .54915 L
.78328 .55342 L
.77982 .56313 L
.78128 .57284 L
.7845 .58256 L
.7828 .59227 L
.77681 .59762 L
.76709 .60122 L
.76163 .60198 L
.75738 .60216 L
.75281 .60198 L
.74767 .60151 L
.73796 .599 L
.72824 .59393 L
.72576 .59227 L
.71853 .58607 L
.71326 .58256 L
.70882 .57995 L
.69911 .57579 L
.68939 .57332 L
.68613 .57284 L
.67968 .57098 L
.66997 .56822 L
.66026 .56528 L
.65402 .56313 L
.65054 .56155 L
.64083 .55595 L
.63734 .55342 L
.63112 .5487 L
.62164 .54371 L
.62141 .54358 L
.61169 .5405 L
.60198 .53844 L
.59227 .53704 L
.58256 .53609 L
.57284 .53549 L
.56313 .53519 L
.55342 .5352 L
.54371 .53559 L
.53399 .5366 L
.52428 .53929 L
.52052 .54371 L
.52428 .55064 L
.52683 .55342 L
.53399 .56271 L
.53422 .56313 L
.53399 .56617 L
.52575 .57284 L
.52428 .57352 L
.51457 .57612 L
.50486 .57764 L
.49514 .57895 L
.48543 .58028 L
.47572 .58181 L
.47172 .58256 L
.46601 .5837 L
.45629 .58632 L
.44658 .59133 L
.44556 .59227 L
.4423 .60198 L
.4378 .61169 L
.43687 .61288 L
.42716 .61887 L
.41744 .62139 L
.41739 .62141 L
.40773 .62405 L
.39802 .62669 L
.38831 .62981 L
.38494 .63112 L
.37859 .63362 L
.36888 .64075 L
.3688 .64083 L
.36083 .65054 L
.35917 .65224 L
.34946 .65957 L
.3481 .66026 L
.33974 .66429 L
.33003 .66802 L
.32443 .66997 L
.32032 .67142 L
.31061 .67512 L
.30089 .6795 L
.30054 .67968 L
.29118 .68533 L
.28556 .68939 L
.28147 .6924 L
.27179 .69911 L
.27176 .69913 L
.26204 .70444 L
.25233 .70826 L
.25069 .70882 L
.24262 .71134 L
.23291 .71403 L
.22319 .716 L
.21348 .71467 L
.20759 .70882 L
.2093 .69911 L
.21348 .69225 L
.2157 .68939 L
.22319 .68205 L
.22578 .67968 L
.23291 .67298 L
.23611 .66997 L
.24262 .66157 L
.24348 .66026 L
.2496 .65054 L
.25233 .64648 L
.25777 .64083 L
.26204 .63682 L
.2705 .63112 L
.27176 .6303 L
.28147 .62421 L
.28574 .62141 L
.29118 .61704 L
.29617 .61169 L
.30089 .60464 L
.30248 .60198 L
.30981 .59227 L
.31061 .59143 L
.32032 .58404 L
.32335 .58256 L
.33003 .57936 L
.33974 .57528 L
.34538 .57284 L
.34946 .57103 L
.35917 .56373 L
.35966 .56313 L
.365 .55342 L
.36888 .54501 L
.36962 .54371 L
.37859 .5345 L
.37951 .53399 L
.38831 .53009 L
.39802 .52739 L
.40773 .52537 L
.41336 .52428 L
.41744 .52375 L
.42716 .52219 L
.43687 .51658 L
.43898 .51457 L
.44164 .50486 L
.44164 .49514 L
.43898 .48543 L
.43687 .48342 L
.42716 .47781 L
.41744 .47625 L
.41336 .47572 L
.40773 .47463 L
.39802 .47261 L
.38831 .46991 L
.37951 .46601 L
.37859 .4655 L
.36962 .45629 L
.36888 .45499 L
.365 .44658 L
.35966 .43687 L
.35917 .43627 L
.34946 .42897 L
.34538 .42716 L
.33974 .42472 L
.33003 .42064 L
.32335 .41744 L
.32032 .41596 L
.31061 .40857 L
.30981 .40773 L
.30248 .39802 L
.30089 .39536 L
.29617 .38831 L
.29118 .38296 L
.28574 .37859 L
.28147 .37579 L
.27176 .3697 L
.2705 .36888 L
.26204 .36318 L
.25777 .35917 L
.25233 .35352 L
.2496 .34946 L
.24348 .33974 L
.24262 .33843 L
.23611 .33003 L
.23291 .32702 L
.22578 .32032 L
.22319 .31795 L
.2157 .31061 L
.21348 .30775 L
.2093 .30089 L
.20759 .29118 L
F
0 .37 .27 r
.22319 .44229 m
.23291 .44117 L
.24262 .44232 L
.25233 .44592 L
.25353 .44658 L
.26054 .45629 L
.25233 .46444 L
.24262 .46462 L
.23291 .4629 L
.22319 .45916 L
.21879 .45629 L
.21582 .44658 L
F
.22319 .54084 m
.23291 .5371 L
.24262 .53538 L
.25233 .53556 L
.26054 .54371 L
.25353 .55342 L
.25233 .55408 L
.24262 .55768 L
.23291 .55883 L
.22319 .55771 L
.21582 .55342 L
.21879 .54371 L
F
.028 .55 0 r
.23291 .29761 m
.24262 .29597 L
.25233 .3 L
.25506 .30089 L
.26204 .30374 L
.27176 .31031 L
.27223 .31061 L
.28147 .3167 L
.28836 .32032 L
.29118 .32172 L
.30089 .32557 L
.31061 .3289 L
.31416 .33003 L
.32032 .33195 L
.33003 .33525 L
.33974 .33934 L
.34056 .33974 L
.34946 .34474 L
.35474 .34946 L
.35917 .35484 L
.36284 .35917 L
.36888 .36426 L
.37817 .36888 L
.37859 .36906 L
.38831 .37249 L
.39802 .37518 L
.40773 .37766 L
.41124 .37859 L
.41744 .38005 L
.42716 .3834 L
.4335 .38831 L
.43687 .39312 L
.43876 .39802 L
.44176 .40773 L
.44658 .41146 L
.45629 .41524 L
.46576 .41744 L
.46601 .4175 L
.47572 .41926 L
.48543 .42068 L
.49514 .42197 L
.50486 .42333 L
.51457 .42511 L
.52126 .42716 L
.52428 .42837 L
.53147 .43687 L
.52477 .44658 L
.52428 .44711 L
.51831 .45629 L
.52428 .46206 L
.53399 .46413 L
.54371 .46496 L
.55342 .46528 L
.56313 .46526 L
.57284 .46496 L
.58256 .46438 L
.59227 .46349 L
.60198 .46218 L
.61169 .46027 L
.62141 .45787 L
.62446 .45629 L
.63112 .45315 L
.64063 .44658 L
.64083 .44645 L
.65054 .4407 L
.65944 .43687 L
.66026 .43661 L
.66997 .43381 L
.67968 .43135 L
.68939 .42901 L
.697 .42716 L
.69911 .42686 L
.70882 .42488 L
.71853 .42194 L
.72824 .41816 L
.72991 .41744 L
.73796 .41362 L
.74767 .41009 L
.75738 .41062 L
.76555 .41744 L
.76522 .42716 L
.76709 .43447 L
.76798 .43687 L
.77327 .44658 L
.77681 .45233 L
.78122 .45629 L
.78652 .46099 L
.79511 .46601 L
.79623 .46658 L
.80594 .47092 L
.81566 .47494 L
.8174 .47572 L
.82537 .47968 L
.83204 .48543 L
.83508 .4895 L
.83746 .49514 L
.83746 .50486 L
.83508 .5105 L
.83204 .51457 L
.82537 .52032 L
.8174 .52428 L
.81566 .52506 L
.80594 .52908 L
.79623 .53342 L
.79511 .53399 L
.78652 .53901 L
.78122 .54371 L
.77681 .54767 L
.77327 .55342 L
.76798 .56313 L
.76709 .56553 L
.76522 .57284 L
.76555 .58256 L
.75738 .58938 L
.74767 .58991 L
.73796 .58638 L
.72991 .58256 L
.72824 .58184 L
.71853 .57806 L
.70882 .57512 L
.69911 .57314 L
.697 .57284 L
.68939 .57099 L
.67968 .56865 L
.66997 .56619 L
.66026 .56339 L
.65944 .56313 L
.65054 .5593 L
.64083 .55355 L
.64063 .55342 L
.63112 .54685 L
.62446 .54371 L
.62141 .54213 L
.61169 .53973 L
.60198 .53782 L
.59227 .53651 L
.58256 .53562 L
.57284 .53504 L
.56313 .53474 L
.55342 .53472 L
.54371 .53504 L
.53399 .53587 L
.52428 .53794 L
.51831 .54371 L
.52428 .55289 L
.52477 .55342 L
.53147 .56313 L
.52428 .57163 L
.52126 .57284 L
.51457 .57489 L
.50486 .57667 L
.49514 .57803 L
.48543 .57932 L
.47572 .58074 L
.46601 .5825 L
.46576 .58256 L
.45629 .58476 L
.44658 .58854 L
.44176 .59227 L
.43876 .60198 L
.43687 .60688 L
.4335 .61169 L
.42716 .6166 L
.41744 .61995 L
.41124 .62141 L
.40773 .62234 L
.39802 .62482 L
.38831 .62751 L
.37859 .63094 L
.37817 .63112 L
.36888 .63574 L
.36284 .64083 L
.35917 .64516 L
.35474 .65054 L
.34946 .65526 L
.34056 .66026 L
.33974 .66066 L
.33003 .66475 L
.32032 .66805 L
.31416 .66997 L
.31061 .6711 L
.30089 .67443 L
.29118 .67828 L
.28836 .67968 L
.28147 .6833 L
.27223 .68939 L
.27176 .68969 L
.26204 .69626 L
.25506 .69911 L
.25233 .7 L
.24262 .70403 L
.23291 .70239 L
.22714 .69911 L
.22916 .68939 L
.23291 .6853 L
.23825 .67968 L
.24262 .67434 L
.24652 .66997 L
.25148 .66026 L
.25233 .65821 L
.25627 .65054 L
.26204 .64305 L
.2642 .64083 L
.27176 .6342 L
.27732 .63112 L
.28147 .62848 L
.29118 .62216 L
.29221 .62141 L
.30089 .61225 L
.30128 .61169 L
.3068 .60198 L
.31061 .59595 L
.31413 .59227 L
.32032 .58688 L
.32846 .58256 L
.33003 .58179 L
.33974 .57756 L
.34946 .5734 L
.35062 .57284 L
.35917 .56773 L
.3633 .56313 L
.36788 .55342 L
.36888 .55102 L
.37262 .54371 L
.37859 .53697 L
.38365 .53399 L
.38831 .53189 L
.39802 .52884 L
.40773 .52666 L
.41744 .52472 L
.41956 .52428 L
.42716 .52325 L
.43687 .51876 L
.44151 .51457 L
.44338 .50486 L
.44338 .49514 L
.44151 .48543 L
.43687 .48124 L
.42716 .47675 L
.41956 .47572 L
.41744 .47528 L
.40773 .47334 L
.39802 .47116 L
.38831 .46811 L
.38365 .46601 L
.37859 .46303 L
.37262 .45629 L
.36888 .44898 L
.36788 .44658 L
.3633 .43687 L
.35917 .43227 L
.35062 .42716 L
.34946 .4266 L
.33974 .42244 L
.33003 .41821 L
.32846 .41744 L
.32032 .41312 L
.31413 .40773 L
.31061 .40405 L
.3068 .39802 L
.30128 .38831 L
.30089 .38775 L
.29221 .37859 L
.29118 .37784 L
.28147 .37152 L
.27732 .36888 L
.27176 .3658 L
.2642 .35917 L
.26204 .35695 L
.25627 .34946 L
.25233 .34179 L
.25148 .33974 L
.24652 .33003 L
.24262 .32566 L
.23825 .32032 L
.23291 .3147 L
.22916 .31061 L
.22714 .30089 L
F
.104 .58 0 r
.26204 .32553 m
.27176 .32377 L
.28147 .32552 L
.29118 .32781 L
.30051 .33003 L
.30089 .33022 L
.31061 .33261 L
.32032 .33542 L
.33003 .33891 L
.33204 .33974 L
.33974 .34288 L
.34816 .34946 L
.34946 .35097 L
.35645 .35917 L
.35917 .36176 L
.36888 .36804 L
.37093 .36888 L
.37859 .37175 L
.38831 .37453 L
.39802 .37692 L
.40481 .37859 L
.40773 .37924 L
.41744 .38174 L
.42716 .38655 L
.42913 .38831 L
.4352 .39802 L
.43687 .40565 L
.43794 .40773 L
.44658 .41363 L
.45629 .41664 L
.4599 .41744 L
.46601 .41869 L
.47572 .42027 L
.48543 .42159 L
.49514 .42287 L
.50486 .42432 L
.51457 .42643 L
.51682 .42716 L
.52428 .43044 L
.52879 .43687 L
.52428 .44449 L
.52274 .44658 L
.51614 .45629 L
.52428 .46316 L
.53399 .46479 L
.54371 .46549 L
.55342 .46574 L
.56313 .4657 L
.57284 .4654 L
.58256 .46484 L
.59227 .46399 L
.60198 .46276 L
.61169 .461 L
.62141 .45917 L
.6273 .45629 L
.63112 .45468 L
.64083 .4486 L
.644 .44658 L
.65054 .44286 L
.66026 .43862 L
.66532 .43687 L
.66997 .43565 L
.67968 .43341 L
.68939 .43144 L
.69911 .42965 L
.70882 .42802 L
.71452 .42716 L
.71853 .42673 L
.72824 .42582 L
.73796 .42586 L
.74552 .42716 L
.74767 .42907 L
.75714 .43687 L
.75738 .43719 L
.76486 .44658 L
.76709 .44972 L
.7726 .45629 L
.77681 .46076 L
.78336 .46601 L
.78652 .46807 L
.79623 .47321 L
.80177 .47572 L
.80594 .47743 L
.81566 .48243 L
.81958 .48543 L
.82537 .49175 L
.82704 .49514 L
.82704 .50486 L
.82537 .50825 L
.81958 .51457 L
.81566 .51757 L
.80594 .52257 L
.80177 .52428 L
.79623 .52679 L
.78652 .53193 L
.78336 .53399 L
.77681 .53924 L
.7726 .54371 L
.76709 .55028 L
.76486 .55342 L
.75738 .56281 L
.75714 .56313 L
.74767 .57093 L
.74552 .57284 L
.73796 .57414 L
.72824 .57418 L
.71853 .57327 L
.71452 .57284 L
.70882 .57198 L
.69911 .57035 L
.68939 .56856 L
.67968 .56659 L
.66997 .56435 L
.66532 .56313 L
.66026 .56138 L
.65054 .55714 L
.644 .55342 L
.64083 .5514 L
.63112 .54532 L
.6273 .54371 L
.62141 .54083 L
.61169 .539 L
.60198 .53724 L
.59227 .53601 L
.58256 .53516 L
.57284 .5346 L
.56313 .5343 L
.55342 .53426 L
.54371 .53451 L
.53399 .53521 L
.52428 .53684 L
.51614 .54371 L
.52274 .55342 L
.52428 .55551 L
.52879 .56313 L
.52428 .56956 L
.51682 .57284 L
.51457 .57357 L
.50486 .57568 L
.49514 .57713 L
.48543 .57841 L
.47572 .57973 L
.46601 .58131 L
.4599 .58256 L
.45629 .58336 L
.44658 .58637 L
.43794 .59227 L
.43687 .59435 L
.4352 .60198 L
.42913 .61169 L
.42716 .61345 L
.41744 .61826 L
.40773 .62076 L
.40481 .62141 L
.39802 .62308 L
.38831 .62547 L
.37859 .62825 L
.37093 .63112 L
.36888 .63196 L
.35917 .63824 L
.35645 .64083 L
.34946 .64903 L
.34816 .65054 L
.33974 .65712 L
.33204 .66026 L
.33003 .66109 L
.32032 .66458 L
.31061 .66739 L
.30089 .66978 L
.30051 .66997 L
.29118 .67219 L
.28147 .67448 L
.27176 .67623 L
.26204 .67447 L
.26061 .66997 L
.26038 .66026 L
.26204 .65363 L
.26335 .65054 L
.27099 .64083 L
.27176 .64 L
.28147 .63226 L
.28455 .63112 L
.29118 .62692 L
.29886 .62141 L
.30089 .61939 L
.30633 .61169 L
.31061 .60288 L
.31103 .60198 L
.31839 .59227 L
.32032 .59038 L
.33003 .58395 L
.33354 .58256 L
.33974 .57981 L
.34946 .57579 L
.3557 .57284 L
.35917 .57094 L
.36675 .56313 L
.36888 .55831 L
.37065 .55342 L
.37549 .54371 L
.37859 .53978 L
.38763 .53399 L
.38831 .53368 L
.39802 .53024 L
.40773 .5279 L
.41744 .52593 L
.42518 .52428 L
.42716 .52404 L
.43687 .52062 L
.44384 .51457 L
.44501 .50486 L
.44501 .49514 L
.44384 .48543 L
.43687 .47938 L
.42716 .47596 L
.42518 .47572 L
.41744 .47407 L
.40773 .4721 L
.39802 .46976 L
.38831 .46632 L
.38763 .46601 L
.37859 .46022 L
.37549 .45629 L
.37065 .44658 L
.36888 .44169 L
.36675 .43687 L
.35917 .42906 L
.3557 .42716 L
.34946 .42421 L
.33974 .42019 L
.33354 .41744 L
.33003 .41605 L
.32032 .40962 L
.31839 .40773 L
.31103 .39802 L
.31061 .39712 L
.30633 .38831 L
.30089 .38061 L
.29886 .37859 L
.29118 .37308 L
.28455 .36888 L
.28147 .36774 L
.27176 .36 L
.27099 .35917 L
.26335 .34946 L
.26204 .34637 L
.26038 .33974 L
.26061 .33003 L
F
.189 .61 0 r
.27176 .33906 m
.28147 .33262 L
.29118 .33314 L
.30089 .3345 L
.31061 .33658 L
.32032 .33939 L
.32139 .33974 L
.33003 .34185 L
.33974 .34853 L
.34076 .34946 L
.34932 .35917 L
.34946 .35932 L
.35917 .36706 L
.36287 .36888 L
.36888 .37124 L
.37859 .37409 L
.38831 .37641 L
.39792 .37859 L
.39802 .37861 L
.40773 .38075 L
.41744 .38385 L
.42466 .38831 L
.42716 .39047 L
.4316 .39802 L
.43409 .40773 L
.43687 .4107 L
.44658 .41546 L
.45407 .41744 L
.45629 .41797 L
.46601 .4198 L
.47572 .42122 L
.48543 .42247 L
.49514 .42376 L
.50486 .42534 L
.51239 .42716 L
.51457 .42783 L
.52428 .43315 L
.52616 .43687 L
.52428 .44128 L
.52074 .44658 L
.51457 .45477 L
.514 .45629 L
.51457 .45936 L
.52428 .4641 L
.53399 .46542 L
.54371 .46599 L
.54407 .46601 L
.55342 .46624 L
.56313 .46614 L
.56773 .46601 L
.57284 .46582 L
.58256 .46528 L
.59227 .46448 L
.60198 .46332 L
.61169 .46169 L
.62141 .46032 L
.63017 .45629 L
.63112 .45594 L
.64083 .45057 L
.64753 .44658 L
.65054 .44495 L
.66026 .44061 L
.66997 .43745 L
.67203 .43687 L
.67968 .43527 L
.68939 .43358 L
.69911 .43221 L
.70882 .43121 L
.71853 .43074 L
.72824 .43116 L
.73796 .4332 L
.74641 .43687 L
.74767 .43776 L
.75733 .44658 L
.75738 .44664 L
.76529 .45629 L
.76709 .45851 L
.77408 .46601 L
.77681 .46835 L
.78652 .47485 L
.7881 .47572 L
.79623 .47951 L
.80594 .485 L
.80655 .48543 L
.81566 .49421 L
.81614 .49514 L
.81614 .50486 L
.81566 .50579 L
.80655 .51457 L
.80594 .515 L
.79623 .52049 L
.7881 .52428 L
.78652 .52515 L
.77681 .53165 L
.77408 .53399 L
.76709 .54149 L
.76529 .54371 L
.75738 .55336 L
.75733 .55342 L
.74767 .56224 L
.74641 .56313 L
.73796 .5668 L
.72824 .56884 L
.71853 .56926 L
.70882 .56879 L
.69911 .56779 L
.68939 .56642 L
.67968 .56473 L
.67203 .56313 L
.66997 .56255 L
.66026 .55939 L
.65054 .55505 L
.64753 .55342 L
.64083 .54943 L
.63112 .54406 L
.63017 .54371 L
.62141 .53968 L
.61169 .53831 L
.60198 .53668 L
.59227 .53552 L
.58256 .53472 L
.57284 .53418 L
.56773 .53399 L
.56313 .53386 L
.55342 .53376 L
.54407 .53399 L
.54371 .53401 L
.53399 .53458 L
.52428 .5359 L
.51457 .54064 L
.514 .54371 L
.51457 .54523 L
.52074 .55342 L
.52428 .55872 L
.52616 .56313 L
.52428 .56685 L
.51457 .57217 L
.51239 .57284 L
.50486 .57466 L
.49514 .57624 L
.48543 .57753 L
.47572 .57878 L
.46601 .5802 L
.45629 .58203 L
.45407 .58256 L
.44658 .58454 L
.43687 .5893 L
.43409 .59227 L
.4316 .60198 L
.42716 .60953 L
.42466 .61169 L
.41744 .61615 L
.40773 .61925 L
.39802 .62139 L
.39792 .62141 L
.38831 .62359 L
.37859 .62591 L
.36888 .62876 L
.36287 .63112 L
.35917 .63294 L
.34946 .64068 L
.34932 .64083 L
.34076 .65054 L
.33974 .65147 L
.33003 .65815 L
.32139 .66026 L
.32032 .66061 L
.31061 .66342 L
.30089 .6655 L
.29118 .66686 L
.28147 .66738 L
.27176 .66094 L
.27137 .66026 L
.27118 .65054 L
.27176 .64931 L
.27839 .64083 L
.28147 .63744 L
.29118 .63201 L
.29261 .63112 L
.30089 .62569 L
.30589 .62141 L
.31061 .61364 L
.31141 .61169 L
.31522 .60198 L
.32032 .59464 L
.32263 .59227 L
.33003 .58633 L
.33867 .58256 L
.33974 .58208 L
.34946 .57806 L
.35917 .57369 L
.36067 .57284 L
.36888 .56527 L
.37006 .56313 L
.37333 .55342 L
.37825 .54371 L
.37859 .54322 L
.38831 .5352 L
.39152 .53399 L
.39802 .53163 L
.40773 .52909 L
.41744 .52709 L
.42716 .52507 L
.43035 .52428 L
.43687 .52227 L
.44601 .51457 L
.44655 .50486 L
.44655 .49514 L
.44601 .48543 L
.43687 .47773 L
.43035 .47572 L
.42716 .47493 L
.41744 .47291 L
.40773 .47091 L
.39802 .46837 L
.39152 .46601 L
.38831 .4648 L
.37859 .45678 L
.37825 .45629 L
.37333 .44658 L
.37006 .43687 L
.36888 .43473 L
.36067 .42716 L
.35917 .42631 L
.34946 .42194 L
.33974 .41792 L
.33867 .41744 L
.33003 .41367 L
.32263 .40773 L
.32032 .40536 L
.31522 .39802 L
.31141 .38831 L
.31061 .38636 L
.30589 .37859 L
.30089 .37431 L
.29261 .36888 L
.29118 .36799 L
.28147 .36256 L
.27839 .35917 L
.27176 .35069 L
.27118 .34946 L
.27137 .33974 L
F
0 .4 .24 r
.29118 .48126 m
.30089 .47933 L
.31061 .47855 L
.32032 .47829 L
.33003 .47837 L
.33974 .47881 L
.34946 .48022 L
.35917 .48442 L
.35992 .48543 L
.36356 .49514 L
.36356 .50486 L
.35992 .51457 L
.35917 .51558 L
.34946 .51978 L
.33974 .52119 L
.33003 .52163 L
.32032 .52171 L
.31061 .52145 L
.30089 .52067 L
.29118 .51874 L
.28321 .51457 L
.28147 .51293 L
.2772 .50486 L
.2772 .49514 L
.28147 .48707 L
.28321 .48543 L
F
.282 .64 0 r
.28147 .34515 m
.29118 .34004 L
.30089 .33989 L
.31061 .34133 L
.32032 .34401 L
.33003 .34794 L
.33183 .34946 L
.33974 .35788 L
.3409 .35917 L
.34946 .36691 L
.35311 .36888 L
.35917 .37128 L
.36888 .37401 L
.37859 .37618 L
.38831 .37818 L
.39031 .37859 L
.39802 .38011 L
.40773 .38248 L
.41744 .38656 L
.42002 .38831 L
.42716 .39619 L
.42792 .39802 L
.43016 .40773 L
.43687 .41362 L
.44658 .41706 L
.44815 .41744 L
.45629 .41926 L
.46601 .42083 L
.47572 .42211 L
.48543 .42332 L
.49514 .42464 L
.50486 .4264 L
.50793 .42716 L
.51457 .42928 L
.52358 .43687 L
.51875 .44658 L
.51457 .45162 L
.51187 .45629 L
.51457 .46199 L
.52428 .46494 L
.53399 .466 L
.53406 .46601 L
.54371 .46661 L
.55342 .46677 L
.56313 .46664 L
.57284 .46627 L
.57791 .46601 L
.58256 .46571 L
.59227 .46495 L
.60198 .46386 L
.61169 .46235 L
.62141 .46135 L
.63112 .45724 L
.63309 .45629 L
.64083 .45238 L
.65054 .44695 L
.65125 .44658 L
.66026 .44255 L
.66997 .43934 L
.67968 .43703 L
.68035 .43687 L
.68939 .43551 L
.69911 .43446 L
.70882 .43392 L
.71853 .43406 L
.72824 .43525 L
.73479 .43687 L
.73796 .4382 L
.74767 .44435 L
.75027 .44658 L
.75738 .45455 L
.75874 .45629 L
.76623 .46601 L
.76709 .467 L
.77633 .47572 L
.77681 .47602 L
.78652 .48178 L
.79242 .48543 L
.79623 .48781 L
.80401 .49514 L
.80401 .50486 L
.79623 .51219 L
.79242 .51457 L
.78652 .51822 L
.77681 .52398 L
.77633 .52428 L
.76709 .533 L
.76623 .53399 L
.75874 .54371 L
.75738 .54545 L
.75027 .55342 L
.74767 .55565 L
.73796 .5618 L
.73479 .56313 L
.72824 .56475 L
.71853 .56594 L
.70882 .56608 L
.69911 .56554 L
.68939 .56449 L
.68035 .56313 L
.67968 .56297 L
.66997 .56066 L
.66026 .55745 L
.65125 .55342 L
.65054 .55305 L
.64083 .54762 L
.63309 .54371 L
.63112 .54276 L
.62141 .53865 L
.61169 .53765 L
.60198 .53614 L
.59227 .53505 L
.58256 .53429 L
.57791 .53399 L
.57284 .53373 L
.56313 .53336 L
.55342 .53323 L
.54371 .53339 L
.53406 .53399 L
.53399 .534 L
.52428 .53506 L
.51457 .53801 L
.51187 .54371 L
.51457 .54838 L
.51875 .55342 L
.52358 .56313 L
.51457 .57072 L
.50793 .57284 L
.50486 .5736 L
.49514 .57536 L
.48543 .57668 L
.47572 .57789 L
.46601 .57917 L
.45629 .58074 L
.44815 .58256 L
.44658 .58294 L
.43687 .58638 L
.43016 .59227 L
.42792 .60198 L
.42716 .60381 L
.42002 .61169 L
.41744 .61344 L
.40773 .61752 L
.39802 .61989 L
.39031 .62141 L
.38831 .62182 L
.37859 .62382 L
.36888 .62599 L
.35917 .62872 L
.35311 .63112 L
.34946 .63309 L
.3409 .64083 L
.33974 .64212 L
.33183 .65054 L
.33003 .65206 L
.32032 .65599 L
.31061 .65867 L
.30089 .66011 L
.29118 .65996 L
.28147 .65485 L
.28051 .65054 L
.28147 .64784 L
.28702 .64083 L
.29118 .63788 L
.30089 .63203 L
.30227 .63112 L
.31061 .62518 L
.3136 .62141 L
.31657 .61169 L
.31943 .60198 L
.32032 .60032 L
.3269 .59227 L
.33003 .58943 L
.33974 .58387 L
.34393 .58256 L
.34946 .5803 L
.35917 .57633 L
.36559 .57284 L
.36888 .57021 L
.37327 .56313 L
.37592 .55342 L
.37859 .5473 L
.38095 .54371 L
.38831 .53682 L
.39534 .53399 L
.39802 .53301 L
.40773 .53026 L
.41744 .5282 L
.42716 .52627 L
.43518 .52428 L
.43687 .52377 L
.44658 .51789 L
.4481 .51457 L
.44809 .50486 L
.44809 .49514 L
.4481 .48543 L
.44658 .48211 L
.43687 .47623 L
.43518 .47572 L
.42716 .47373 L
.41744 .4718 L
.40773 .46974 L
.39802 .46699 L
.39534 .46601 L
.38831 .46318 L
.38095 .45629 L
.37859 .4527 L
.37592 .44658 L
.37327 .43687 L
.36888 .42979 L
.36559 .42716 L
.35917 .42367 L
.34946 .4197 L
.34393 .41744 L
.33974 .41613 L
.33003 .41057 L
.3269 .40773 L
.32032 .39968 L
.31943 .39802 L
.31657 .38831 L
.3136 .37859 L
.31061 .37482 L
.30227 .36888 L
.30089 .36797 L
.29118 .36212 L
.28702 .35917 L
.28147 .35216 L
.28051 .34946 L
F
0 .246 .28 r
.32032 .53344 m
.32732 .53399 L
.33003 .53448 L
.33965 .54371 L
.33592 .55342 L
.33003 .55769 L
.32032 .56204 L
.31684 .56313 L
.31061 .56504 L
.30089 .5676 L
.29118 .56822 L
.28147 .56971 L
.281 .56313 L
.28147 .56171 L
.28422 .55342 L
.28922 .54371 L
.29118 .54086 L
.30089 .53613 L
.31061 .53407 L
.31125 .53399 L
F
0 .43 .202 r
.30089 .48408 m
.31061 .48235 L
.32032 .48176 L
.33003 .48194 L
.33974 .48302 L
.34838 .48543 L
.34946 .48603 L
.35751 .49514 L
.35751 .50486 L
.34946 .51397 L
.34838 .51457 L
.33974 .51698 L
.33003 .51806 L
.32032 .51824 L
.31061 .51765 L
.30089 .51592 L
.29671 .51457 L
.29118 .51167 L
.28547 .50486 L
.28547 .49514 L
.29118 .48833 L
.29671 .48543 L
F
0 .46 .156 r
.30089 .48972 m
.31061 .48671 L
.32032 .48568 L
.33003 .48592 L
.33974 .48769 L
.34946 .4936 L
.35056 .49514 L
.35056 .50486 L
.34946 .5064 L
.33974 .51231 L
.33003 .51408 L
.32032 .51432 L
.31061 .51329 L
.30089 .51028 L
.2942 .50486 L
.2942 .49514 L
F
.382 .67 0 r
.30089 .34704 m
.31061 .34747 L
.31777 .34946 L
.32032 .35073 L
.32879 .35917 L
.33003 .36182 L
.33655 .36888 L
.33974 .37008 L
.34946 .37267 L
.35917 .37466 L
.36888 .37642 L
.37859 .37812 L
.38134 .37859 L
.38831 .37979 L
.39802 .38173 L
.40773 .38457 L
.41516 .38831 L
.41744 .38978 L
.42415 .39802 L
.4261 .40773 L
.42716 .40955 L
.43687 .41589 L
.44206 .41744 L
.44658 .41862 L
.45629 .42044 L
.46601 .42179 L
.47572 .42297 L
.48543 .42415 L
.49514 .42553 L
.50341 .42716 L
.50486 .42751 L
.51457 .43088 L
.52101 .43687 L
.51679 .44658 L
.51457 .44921 L
.50975 .45629 L
.51457 .46357 L
.52428 .46569 L
.52693 .46601 L
.53399 .46676 L
.54371 .46721 L
.55342 .46729 L
.56313 .46711 L
.57284 .46674 L
.58256 .46615 L
.58451 .46601 L
.59227 .4654 L
.60198 .46439 L
.61169 .46298 L
.62141 .46225 L
.63112 .45854 L
.63608 .45629 L
.64083 .45404 L
.65054 .44889 L
.65518 .44658 L
.66026 .44444 L
.66997 .4412 L
.67968 .43891 L
.68939 .43736 L
.69388 .43687 L
.69911 .4365 L
.70882 .43629 L
.71847 .43687 L
.71853 .43688 L
.72824 .43883 L
.73796 .4429 L
.74345 .44658 L
.74767 .45024 L
.7527 .45629 L
.75738 .46293 L
.75926 .46601 L
.76618 .47572 L
.76709 .47658 L
.77681 .48518 L
.77712 .48543 L
.78652 .49244 L
.78907 .49514 L
.78907 .50486 L
.78652 .50756 L
.77712 .51457 L
.77681 .51482 L
.76709 .52342 L
.76618 .52428 L
.75926 .53399 L
.75738 .53707 L
.7527 .54371 L
.74767 .54976 L
.74345 .55342 L
.73796 .5571 L
.72824 .56117 L
.71853 .56312 L
.71847 .56313 L
.70882 .56371 L
.69911 .5635 L
.69388 .56313 L
.68939 .56264 L
.67968 .56109 L
.66997 .5588 L
.66026 .55556 L
.65518 .55342 L
.65054 .55111 L
.64083 .54596 L
.63608 .54371 L
.63112 .54146 L
.62141 .53775 L
.61169 .53702 L
.60198 .53561 L
.59227 .5346 L
.58451 .53399 L
.58256 .53385 L
.57284 .53326 L
.56313 .53289 L
.55342 .53271 L
.54371 .53279 L
.53399 .53324 L
.52693 .53399 L
.52428 .53431 L
.51457 .53643 L
.50975 .54371 L
.51457 .55079 L
.51679 .55342 L
.52101 .56313 L
.51457 .56912 L
.50486 .57249 L
.50341 .57284 L
.49514 .57447 L
.48543 .57585 L
.47572 .57703 L
.46601 .57821 L
.45629 .57956 L
.44658 .58138 L
.44206 .58256 L
.43687 .58411 L
.42716 .59045 L
.4261 .59227 L
.42415 .60198 L
.41744 .61022 L
.41516 .61169 L
.40773 .61543 L
.39802 .61827 L
.38831 .62021 L
.38134 .62141 L
.37859 .62188 L
.36888 .62358 L
.35917 .62534 L
.34946 .62733 L
.33974 .62992 L
.33655 .63112 L
.33003 .63818 L
.32879 .64083 L
.32032 .64927 L
.31777 .65054 L
.31061 .65253 L
.30089 .65296 L
.29485 .65054 L
.29914 .64083 L
.30089 .6399 L
.31061 .63499 L
.3188 .63112 L
.32032 .6298 L
.3226 .62141 L
.32191 .61169 L
.32368 .60198 L
.33003 .59337 L
.33126 .59227 L
.33974 .58597 L
.34945 .58256 L
.34946 .58256 L
.35917 .57878 L
.36888 .57407 L
.37051 .57284 L
.37639 .56313 L
.37843 .55342 L
.37859 .55294 L
.38359 .54371 L
.38831 .53878 L
.39802 .53427 L
.39914 .53399 L
.40773 .53142 L
.41744 .52927 L
.42716 .5274 L
.43687 .5252 L
.43974 .52428 L
.44658 .52087 L
.45011 .51457 L
.44958 .50486 L
.44958 .49514 L
.45011 .48543 L
.44658 .47913 L
.43974 .47572 L
.43687 .4748 L
.42716 .4726 L
.41744 .47073 L
.40773 .46858 L
.39914 .46601 L
.39802 .46573 L
.38831 .46122 L
.38359 .45629 L
.37859 .44706 L
.37843 .44658 L
.37639 .43687 L
.37051 .42716 L
.36888 .42593 L
.35917 .42122 L
.34946 .41744 L
.34945 .41744 L
.33974 .41403 L
.33126 .40773 L
.33003 .40663 L
.32368 .39802 L
.32191 .38831 L
.3226 .37859 L
.32032 .3702 L
.3188 .36888 L
.31061 .36501 L
.30089 .3601 L
.29914 .35917 L
.29485 .34946 L
F
0 .188 .25 r
.31061 .54098 m
.32032 .53996 L
.32918 .54371 L
.32516 .55342 L
.32032 .55586 L
.31061 .55793 L
.30089 .55553 L
.29939 .55342 L
.30089 .54728 L
.30447 .54371 L
F
.30089 .44447 m
.31061 .44207 L
.32032 .44414 L
.32516 .44658 L
.32918 .45629 L
.32032 .46004 L
.31061 .45902 L
.30447 .45629 L
.30089 .45272 L
.29939 .44658 L
F
0 .49 .103 r
.31061 .49202 m
.32032 .49016 L
.33003 .49051 L
.33974 .49375 L
.34181 .49514 L
.34181 .50486 L
.33974 .50625 L
.33003 .50949 L
.32032 .50984 L
.31061 .50798 L
.30427 .50486 L
.30427 .49514 L
F
.49 .7 0 r
.33974 .37735 m
.34946 .37685 L
.35917 .37752 L
.36866 .37859 L
.36888 .37862 L
.37859 .37987 L
.38831 .38143 L
.39802 .3836 L
.40773 .38714 L
.40992 .38831 L
.41744 .39379 L
.42021 .39802 L
.42187 .40773 L
.42716 .41405 L
.43559 .41744 L
.43687 .41785 L
.44658 .42006 L
.45629 .42152 L
.46601 .42269 L
.47572 .42379 L
.48543 .42496 L
.49514 .42644 L
.49879 .42716 L
.50486 .42867 L
.51457 .43273 L
.51847 .43687 L
.51484 .44658 L
.51457 .44691 L
.50764 .45629 L
.51457 .4648 L
.52102 .46601 L
.52428 .46659 L
.53399 .46748 L
.54371 .46778 L
.55342 .46778 L
.56313 .46757 L
.57284 .46719 L
.58256 .46661 L
.59031 .46601 L
.59227 .46584 L
.60198 .46489 L
.61169 .46358 L
.62141 .46303 L
.63112 .45971 L
.63919 .45629 L
.64083 .45556 L
.65054 .45076 L
.65957 .44658 L
.66026 .44631 L
.66997 .44303 L
.67968 .44075 L
.68939 .4393 L
.69911 .43858 L
.70882 .43865 L
.71853 .43974 L
.72824 .44236 L
.73663 .44658 L
.73796 .44734 L
.74699 .45629 L
.74767 .45661 L
.75291 .46601 L
.7573 .47572 L
.75738 .47591 L
.76206 .48543 L
.76709 .49322 L
.76823 .49514 L
.76823 .50486 L
.76709 .50678 L
.76206 .51457 L
.75738 .52409 L
.7573 .52428 L
.75291 .53399 L
.74767 .54339 L
.74699 .54371 L
.73796 .55266 L
.73663 .55342 L
.72824 .55764 L
.71853 .56026 L
.70882 .56135 L
.69911 .56142 L
.68939 .5607 L
.67968 .55925 L
.66997 .55697 L
.66026 .55369 L
.65957 .55342 L
.65054 .54924 L
.64083 .54444 L
.63919 .54371 L
.63112 .54029 L
.62141 .53697 L
.61169 .53642 L
.60198 .53511 L
.59227 .53416 L
.59031 .53399 L
.58256 .53339 L
.57284 .53281 L
.56313 .53243 L
.55342 .53222 L
.54371 .53222 L
.53399 .53252 L
.52428 .53341 L
.52102 .53399 L
.51457 .5352 L
.50764 .54371 L
.51457 .55309 L
.51484 .55342 L
.51847 .56313 L
.51457 .56727 L
.50486 .57133 L
.49879 .57284 L
.49514 .57356 L
.48543 .57504 L
.47572 .57621 L
.46601 .57731 L
.45629 .57848 L
.44658 .57994 L
.43687 .58215 L
.43559 .58256 L
.42716 .58595 L
.42187 .59227 L
.42021 .60198 L
.41744 .60621 L
.40992 .61169 L
.40773 .61286 L
.39802 .6164 L
.38831 .61857 L
.37859 .62013 L
.36888 .62138 L
.36866 .62141 L
.35917 .62248 L
.34946 .62315 L
.33974 .62265 L
.33447 .62141 L
.33003 .61721 L
.32755 .61169 L
.32805 .60198 L
.33003 .59836 L
.33576 .59227 L
.33974 .5889 L
.34946 .58398 L
.35534 .58256 L
.35917 .58115 L
.36888 .57736 L
.37548 .57284 L
.37859 .56657 L
.37944 .56313 L
.3809 .55342 L
.38619 .54371 L
.38831 .54122 L
.39802 .53528 L
.40295 .53399 L
.40773 .53256 L
.41744 .53031 L
.42716 .52848 L
.43687 .52655 L
.44407 .52428 L
.44658 .52313 L
.45202 .51457 L
.451 .50486 L
.451 .49514 L
.45202 .48543 L
.44658 .47687 L
.44407 .47572 L
.43687 .47345 L
.42716 .47152 L
.41744 .46969 L
.40773 .46744 L
.40295 .46601 L
.39802 .46472 L
.38831 .45878 L
.38619 .45629 L
.3809 .44658 L
.37944 .43687 L
.37859 .43343 L
.37548 .42716 L
.36888 .42264 L
.35917 .41885 L
.35534 .41744 L
.34946 .41602 L
.33974 .4111 L
.33576 .40773 L
.33003 .40164 L
.32805 .39802 L
.32755 .38831 L
.33003 .38279 L
.33447 .37859 L
F
.606 .73 0 r
.33974 .3814 m
.34946 .38006 L
.35917 .37996 L
.36888 .38056 L
.37859 .38166 L
.38831 .38329 L
.39802 .38582 L
.40421 .38831 L
.40773 .39005 L
.41607 .39802 L
.41734 .40773 L
.41744 .40817 L
.42716 .41702 L
.42847 .41744 L
.43687 .41976 L
.44658 .42134 L
.45629 .42252 L
.46601 .42354 L
.47572 .42458 L
.48543 .42578 L
.494 .42716 L
.49514 .42739 L
.50486 .42989 L
.51457 .43508 L
.51593 .43687 L
.51457 .44354 L
.51289 .44658 L
.50552 .45629 L
.51457 .46583 L
.51557 .46601 L
.52428 .46757 L
.53399 .46816 L
.54371 .46832 L
.55342 .46825 L
.56313 .46802 L
.57284 .46762 L
.58256 .46706 L
.59227 .46631 L
.5955 .46601 L
.60198 .46538 L
.61169 .46416 L
.62141 .46372 L
.63112 .46078 L
.64083 .45699 L
.64241 .45629 L
.65054 .45254 L
.66026 .4482 L
.66433 .44658 L
.66997 .44485 L
.67968 .44259 L
.68939 .44121 L
.69911 .44066 L
.70882 .44102 L
.71853 .44256 L
.72824 .44594 L
.72953 .44658 L
.73796 .45203 L
.74145 .45629 L
.74699 .46601 L
.74767 .46796 L
.74941 .47572 L
.74937 .48543 L
.74767 .49452 L
.74754 .49514 L
.74754 .50486 L
.74767 .50548 L
.74937 .51457 L
.74941 .52428 L
.74767 .53204 L
.74699 .53399 L
.74145 .54371 L
.73796 .54797 L
.72953 .55342 L
.72824 .55406 L
.71853 .55744 L
.70882 .55898 L
.69911 .55934 L
.68939 .55879 L
.67968 .55741 L
.66997 .55515 L
.66433 .55342 L
.66026 .5518 L
.65054 .54746 L
.64241 .54371 L
.64083 .54301 L
.63112 .53922 L
.62141 .53628 L
.61169 .53584 L
.60198 .53462 L
.5955 .53399 L
.59227 .53369 L
.58256 .53294 L
.57284 .53238 L
.56313 .53198 L
.55342 .53175 L
.54371 .53168 L
.53399 .53184 L
.52428 .53243 L
.51557 .53399 L
.51457 .53417 L
.50552 .54371 L
.51289 .55342 L
.51457 .55646 L
.51593 .56313 L
.51457 .56492 L
.50486 .57011 L
.49514 .57261 L
.494 .57284 L
.48543 .57422 L
.47572 .57542 L
.46601 .57646 L
.45629 .57748 L
.44658 .57866 L
.43687 .58024 L
.42847 .58256 L
.42716 .58298 L
.41744 .59183 L
.41734 .59227 L
.41607 .60198 L
.40773 .60995 L
.40421 .61169 L
.39802 .61418 L
.38831 .61671 L
.37859 .61834 L
.36888 .61944 L
.35917 .62004 L
.34946 .61994 L
.33974 .6186 L
.33366 .61169 L
.33257 .60198 L
.33974 .59287 L
.34051 .59227 L
.34946 .58605 L
.35917 .583 L
.3619 .58256 L
.36888 .58021 L
.37859 .5757 L
.38057 .57284 L
.38245 .56313 L
.38333 .55342 L
.38831 .5442 L
.38874 .54371 L
.39802 .53646 L
.40682 .53399 L
.40773 .53372 L
.41744 .53134 L
.42716 .52951 L
.43687 .52778 L
.44658 .52515 L
.44822 .52428 L
.45385 .51457 L
.45237 .50486 L
.45237 .49514 L
.45385 .48543 L
.44822 .47572 L
.44658 .47485 L
.43687 .47222 L
.42716 .47049 L
.41744 .46866 L
.40773 .46628 L
.40682 .46601 L
.39802 .46354 L
.38874 .45629 L
.38831 .4558 L
.38333 .44658 L
.38245 .43687 L
.38057 .42716 L
.37859 .4243 L
.36888 .41979 L
.3619 .41744 L
.35917 .417 L
.34946 .41395 L
.34051 .40773 L
.33974 .40713 L
.33257 .39802 L
.33366 .38831 L
F
.73 .76 0 r
.34946 .38333 m
.35917 .38241 L
.36888 .38268 L
.37859 .38369 L
.38831 .38548 L
.39753 .38831 L
.39802 .3885 L
.40773 .3936 L
.41164 .39802 L
.41251 .40773 L
.41744 .4163 L
.42017 .41744 L
.42716 .41977 L
.43687 .42139 L
.44658 .4225 L
.45629 .42344 L
.46601 .42435 L
.47572 .42536 L
.48543 .4266 L
.48899 .42716 L
.49514 .42838 L
.50486 .43119 L
.51339 .43687 L
.51094 .44658 L
.50486 .45412 L
.5034 .45629 L
.50486 .46413 L
.51037 .46601 L
.51457 .46662 L
.52428 .46848 L
.53399 .4688 L
.54371 .46884 L
.55342 .46871 L
.56313 .46844 L
.57284 .46804 L
.58256 .4675 L
.59227 .46678 L
.60038 .46601 L
.60198 .46585 L
.61169 .46472 L
.62141 .4643 L
.63112 .46174 L
.64083 .45832 L
.6458 .45629 L
.65054 .45424 L
.66026 .45008 L
.66997 .44668 L
.67022 .44658 L
.67968 .44443 L
.68939 .44313 L
.69911 .44275 L
.70882 .44341 L
.71853 .44547 L
.72178 .44658 L
.72824 .44905 L
.73601 .45629 L
.73796 .45896 L
.74136 .46601 L
.74231 .47572 L
.73946 .48543 L
.73796 .48881 L
.73532 .49514 L
.73532 .50486 L
.73796 .51119 L
.73946 .51457 L
.74231 .52428 L
.74136 .53399 L
.73796 .54104 L
.73601 .54371 L
.72824 .55095 L
.72178 .55342 L
.71853 .55453 L
.70882 .55659 L
.69911 .55725 L
.68939 .55687 L
.67968 .55557 L
.67022 .55342 L
.66997 .55332 L
.66026 .54992 L
.65054 .54576 L
.6458 .54371 L
.64083 .54168 L
.63112 .53826 L
.62141 .5357 L
.61169 .53528 L
.60198 .53415 L
.60038 .53399 L
.59227 .53322 L
.58256 .5325 L
.57284 .53196 L
.56313 .53156 L
.55342 .53129 L
.54371 .53116 L
.53399 .5312 L
.52428 .53152 L
.51457 .53338 L
.51037 .53399 L
.50486 .53587 L
.5034 .54371 L
.50486 .54588 L
.51094 .55342 L
.51339 .56313 L
.50486 .56881 L
.49514 .57162 L
.48899 .57284 L
.48543 .5734 L
.47572 .57464 L
.46601 .57565 L
.45629 .57656 L
.44658 .5775 L
.43687 .57861 L
.42716 .58023 L
.42017 .58256 L
.41744 .5837 L
.41251 .59227 L
.41164 .60198 L
.40773 .6064 L
.39802 .6115 L
.39753 .61169 L
.38831 .61452 L
.37859 .61631 L
.36888 .61732 L
.35917 .61759 L
.34946 .61667 L
.34065 .61169 L
.33974 .61069 L
.33738 .60198 L
.33974 .59766 L
.3456 .59227 L
.34946 .58923 L
.35917 .58449 L
.36888 .58266 L
.36974 .58256 L
.37859 .58043 L
.38585 .57284 L
.38543 .56313 L
.38572 .55342 L
.38831 .5475 L
.39128 .54371 L
.39802 .5379 L
.40773 .53454 L
.41076 .53399 L
.41744 .53236 L
.42716 .5305 L
.43687 .52893 L
.44658 .52708 L
.45222 .52428 L
.4556 .51457 L
.45369 .50486 L
.45369 .49514 L
.4556 .48543 L
.45222 .47572 L
.44658 .47292 L
.43687 .47107 L
.42716 .4695 L
.41744 .46764 L
.41076 .46601 L
.40773 .46546 L
.39802 .4621 L
.39128 .45629 L
.38831 .4525 L
.38572 .44658 L
.38543 .43687 L
.38585 .42716 L
.37859 .41957 L
.36974 .41744 L
.36888 .41734 L
.35917 .41551 L
.34946 .41077 L
.3456 .40773 L
.33974 .40234 L
.33738 .39802 L
.33974 .38931 L
.34065 .38831 L
F
.79 .719 0 r
.35917 .38549 m
.36888 .38522 L
.37859 .38612 L
.38831 .38812 L
.38902 .38831 L
.39802 .39136 L
.40675 .39802 L
.40698 .40773 L
.40773 .41717 L
.40825 .41744 L
.41744 .42115 L
.42716 .42202 L
.43687 .42279 L
.44658 .42354 L
.45629 .4243 L
.46601 .42514 L
.47572 .42613 L
.48366 .42716 L
.48543 .42745 L
.49514 .4294 L
.50486 .43261 L
.51084 .43687 L
.50899 .44658 L
.50486 .45163 L
.50126 .45629 L
.50486 .46589 L
.50528 .46601 L
.51457 .46732 L
.52428 .46933 L
.53399 .4694 L
.54371 .46933 L
.55342 .46914 L
.56313 .46885 L
.57284 .46845 L
.58256 .46792 L
.59227 .46723 L
.60198 .46634 L
.60507 .46601 L
.61169 .46526 L
.62141 .4648 L
.63112 .46261 L
.64083 .45955 L
.64948 .45629 L
.65054 .45587 L
.66026 .45192 L
.66997 .44859 L
.67786 .44658 L
.67968 .4463 L
.68939 .44509 L
.69911 .44489 L
.70882 .4459 L
.71249 .44658 L
.71853 .448 L
.72824 .45363 L
.73052 .45629 L
.73593 .46601 L
.73582 .47572 L
.73159 .48543 L
.72824 .49254 L
.72735 .49514 L
.72735 .50486 L
.72824 .50746 L
.73159 .51457 L
.73582 .52428 L
.73593 .53399 L
.73052 .54371 L
.72824 .54637 L
.71853 .552 L
.71249 .55342 L
.70882 .5541 L
.69911 .55511 L
.68939 .55491 L
.67968 .5537 L
.67786 .55342 L
.66997 .55141 L
.66026 .54808 L
.65054 .54413 L
.64948 .54371 L
.64083 .54045 L
.63112 .53739 L
.62141 .5352 L
.61169 .53474 L
.60507 .53399 L
.60198 .53366 L
.59227 .53277 L
.58256 .53208 L
.57284 .53155 L
.56313 .53115 L
.55342 .53086 L
.54371 .53067 L
.53399 .5306 L
.52428 .53067 L
.51457 .53268 L
.50528 .53399 L
.50486 .53411 L
.50126 .54371 L
.50486 .54837 L
.50899 .55342 L
.51084 .56313 L
.50486 .56739 L
.49514 .5706 L
.48543 .57255 L
.48366 .57284 L
.47572 .57387 L
.46601 .57486 L
.45629 .5757 L
.44658 .57646 L
.43687 .57721 L
.42716 .57798 L
.41744 .57885 L
.40825 .58256 L
.40773 .58283 L
.40698 .59227 L
.40675 .60198 L
.39802 .60864 L
.38902 .61169 L
.38831 .61188 L
.37859 .61388 L
.36888 .61478 L
.35917 .61451 L
.34948 .61169 L
.34946 .61166 L
.34255 .60198 L
.34946 .59352 L
.35126 .59227 L
.35917 .58713 L
.36888 .58388 L
.37859 .58276 L
.38138 .58256 L
.38831 .58017 L
.39141 .57284 L
.38838 .56313 L
.38831 .56275 L
.38807 .55342 L
.38831 .5526 L
.39381 .54371 L
.39802 .5397 L
.40773 .53533 L
.41485 .53399 L
.41744 .53337 L
.42716 .53147 L
.43687 .52999 L
.44658 .5287 L
.45609 .52428 L
.45629 .52409 L
.45731 .51457 L
.45629 .51078 L
.45497 .50486 L
.45497 .49514 L
.45629 .48922 L
.45731 .48543 L
.45629 .47591 L
.45609 .47572 L
.44658 .4713 L
.43687 .47001 L
.42716 .46853 L
.41744 .46663 L
.41485 .46601 L
.40773 .46467 L
.39802 .4603 L
.39381 .45629 L
.38831 .4474 L
.38807 .44658 L
.38831 .43725 L
.38838 .43687 L
.39141 .42716 L
.38831 .41983 L
.38138 .41744 L
.37859 .41724 L
.36888 .41612 L
.35917 .41287 L
.35126 .40773 L
.34946 .40648 L
.34255 .39802 L
.34946 .38834 L
.34948 .38831 L
F
.82 .64 0 r
.35917 .59161 m
.36888 .58655 L
.37859 .58428 L
.38831 .58451 L
.39802 .58958 L
.40038 .59227 L
.4012 .60198 L
.39802 .6048 L
.38831 .60909 L
.37859 .61102 L
.36888 .61161 L
.35917 .61061 L
.34946 .60505 L
.34852 .60198 L
.34946 .59951 L
.3582 .59227 L
F
.34946 .39495 m
.35917 .38939 L
.36888 .38839 L
.37859 .38898 L
.38831 .39091 L
.39802 .3952 L
.4012 .39802 L
.40038 .40773 L
.39802 .41042 L
.38831 .41549 L
.37859 .41572 L
.36888 .41345 L
.35917 .40839 L
.3582 .40773 L
.34946 .40049 L
.34852 .39802 L
F
.85 .553 0 r
.35917 .39426 m
.36888 .3918 L
.37859 .39212 L
.38831 .39453 L
.39482 .39802 L
.39036 .40773 L
.38831 .40957 L
.37859 .41109 L
.36888 .40804 L
.368 .40773 L
.35917 .40334 L
.35547 .39802 L
F
.36888 .59196 m
.37859 .58891 L
.38831 .59043 L
.39036 .59227 L
.39482 .60198 L
.38831 .60547 L
.37859 .60788 L
.36888 .6082 L
.35917 .60574 L
.35547 .60198 L
.35917 .59666 L
.368 .59227 L
F
.88 .458 0 r
.36888 .39743 m
.37859 .39688 L
.38241 .39802 L
.37859 .40368 L
.36888 .40143 L
.36774 .39802 L
F
.36888 .59857 m
.37859 .59632 L
.38241 .60198 L
.37859 .60312 L
.36888 .60257 L
.36774 .60198 L
F
0 .34 .292 r
.37859 .47985 m
.38831 .47981 L
.39802 .48036 L
.40773 .48149 L
.41744 .4838 L
.42172 .48543 L
.42716 .48904 L
.4309 .49514 L
.4309 .50486 L
.42716 .51096 L
.42172 .51457 L
.41744 .5162 L
.40773 .51851 L
.39802 .51964 L
.38831 .52019 L
.37859 .52015 L
.37009 .51457 L
.36926 .50486 L
.36926 .49514 L
.37009 .48543 L
F
0 .31 .307 r
.38831 .48315 m
.39802 .48279 L
.40773 .48375 L
.41477 .48543 L
.41744 .48625 L
.42716 .49367 L
.4278 .49514 L
.4278 .50486 L
.42716 .50633 L
.41744 .51375 L
.41477 .51457 L
.40773 .51625 L
.39802 .51721 L
.38831 .51685 L
.38036 .51457 L
.37859 .51311 L
.37487 .50486 L
.37487 .49514 L
.37859 .48689 L
.38036 .48543 L
F
0 .246 .28 r
.38831 .48738 m
.39802 .48579 L
.40773 .4863 L
.41744 .48889 L
.42535 .49514 L
.42535 .50486 L
.41744 .51111 L
.40773 .5137 L
.39802 .51421 L
.38831 .51262 L
.38061 .50486 L
.38061 .49514 L
F
0 .188 .25 r
.38831 .49359 m
.39802 .48904 L
.40773 .48909 L
.41744 .49259 L
.42068 .49514 L
.42068 .50486 L
.41744 .50741 L
.40773 .51091 L
.39802 .51096 L
.38831 .50641 L
.38721 .50486 L
.38721 .49514 L
F
.82 .64 0 r
.39802 .42654 m
.40773 .42226 L
.41744 .42449 L
.42716 .42377 L
.43687 .424 L
.44658 .42448 L
.45629 .42512 L
.46601 .42589 L
.47572 .4269 L
.47784 .42716 L
.48543 .42835 L
.49514 .43047 L
.50486 .43422 L
.50826 .43687 L
.50703 .44658 L
.50486 .44932 L
.49909 .45629 L
.50016 .46601 L
.50486 .46699 L
.51457 .46799 L
.52428 .4701 L
.53399 .46997 L
.54371 .4698 L
.55342 .46956 L
.56313 .46925 L
.57284 .46885 L
.58256 .46833 L
.59227 .46767 L
.60198 .46683 L
.60967 .46601 L
.61169 .46578 L
.62141 .46522 L
.63112 .46339 L
.64083 .4607 L
.65054 .45737 L
.65338 .45629 L
.66026 .45373 L
.66997 .45051 L
.67968 .44823 L
.68939 .44708 L
.69911 .44706 L
.70882 .44809 L
.71853 .45109 L
.72489 .45629 L
.72824 .46046 L
.7306 .46601 L
.72982 .47572 L
.72824 .47954 L
.72513 .48543 L
.72125 .49514 L
.72125 .50486 L
.72513 .51457 L
.72824 .52046 L
.72982 .52428 L
.7306 .53399 L
.72824 .53954 L
.72489 .54371 L
.71853 .54891 L
.70882 .55191 L
.69911 .55294 L
.68939 .55292 L
.67968 .55177 L
.66997 .54949 L
.66026 .54627 L
.65338 .54371 L
.65054 .54263 L
.64083 .5393 L
.63112 .53661 L
.62141 .53478 L
.61169 .53422 L
.60967 .53399 L
.60198 .53317 L
.59227 .53233 L
.58256 .53167 L
.57284 .53115 L
.56313 .53075 L
.55342 .53044 L
.54371 .5302 L
.53399 .53003 L
.52428 .5299 L
.51457 .53201 L
.50486 .53301 L
.50016 .53399 L
.49909 .54371 L
.50486 .55068 L
.50703 .55342 L
.50826 .56313 L
.50486 .56578 L
.49514 .56953 L
.48543 .57165 L
.47784 .57284 L
.47572 .5731 L
.46601 .57411 L
.45629 .57488 L
.44658 .57552 L
.43687 .576 L
.42716 .57623 L
.41744 .57551 L
.40773 .57774 L
.39802 .57346 L
.39745 .57284 L
.39133 .56313 L
.39042 .55342 L
.39635 .54371 L
.39802 .54194 L
.40773 .53627 L
.41744 .53423 L
.41915 .53399 L
.42716 .53242 L
.43687 .53099 L
.44658 .53006 L
.45629 .52647 L
.45986 .52428 L
.45899 .51457 L
.45629 .50532 L
.4562 .50486 L
.4562 .49514 L
.45629 .49468 L
.45899 .48543 L
.45986 .47572 L
.45629 .47353 L
.44658 .46994 L
.43687 .46901 L
.42716 .46758 L
.41915 .46601 L
.41744 .46577 L
.40773 .46373 L
.39802 .45806 L
.39635 .45629 L
.39042 .44658 L
.39133 .43687 L
.39745 .42716 L
F
.85 .553 0 r
.40773 .42575 m
.41744 .42629 L
.42716 .42512 L
.43687 .42504 L
.44658 .42536 L
.45629 .42589 L
.46601 .42664 L
.47133 .42716 L
.47572 .42728 L
.48543 .42927 L
.49514 .43158 L
.50486 .43616 L
.50565 .43687 L
.50505 .44658 L
.50486 .44685 L
.49688 .45629 L
.49514 .45871 L
.49482 .46601 L
.49514 .46613 L
.50486 .46793 L
.51457 .46861 L
.52428 .47081 L
.53399 .4705 L
.54371 .47024 L
.55342 .46996 L
.56313 .46963 L
.57284 .46923 L
.58256 .46873 L
.59227 .4681 L
.60198 .46731 L
.61169 .46631 L
.61426 .46601 L
.62141 .46558 L
.63112 .46409 L
.64083 .46175 L
.65054 .45879 L
.65788 .45629 L
.66026 .45549 L
.66997 .45244 L
.67968 .45023 L
.68939 .44911 L
.69911 .44916 L
.70882 .45068 L
.71853 .45596 L
.71887 .45629 L
.72531 .46601 L
.72421 .47572 L
.71965 .48543 L
.71853 .48811 L
.71638 .49514 L
.71638 .50486 L
.71853 .51189 L
.71965 .51457 L
.72421 .52428 L
.72531 .53399 L
.71887 .54371 L
.71853 .54404 L
.70882 .54932 L
.69911 .55084 L
.68939 .55089 L
.67968 .54977 L
.66997 .54756 L
.66026 .54451 L
.65788 .54371 L
.65054 .54121 L
.64083 .53825 L
.63112 .53591 L
.62141 .53442 L
.61426 .53399 L
.61169 .53369 L
.60198 .53269 L
.59227 .5319 L
.58256 .53127 L
.57284 .53077 L
.56313 .53037 L
.55342 .53004 L
.54371 .52976 L
.53399 .5295 L
.52428 .52919 L
.51457 .53139 L
.50486 .53207 L
.49514 .53387 L
.49482 .53399 L
.49514 .54129 L
.49688 .54371 L
.50486 .55315 L
.50505 .55342 L
.50565 .56313 L
.50486 .56384 L
.49514 .56842 L
.48543 .57073 L
.47572 .57272 L
.47133 .57284 L
.46601 .57336 L
.45629 .57411 L
.44658 .57464 L
.43687 .57496 L
.42716 .57488 L
.41744 .57371 L
.40773 .57425 L
.40415 .57284 L
.39802 .56736 L
.39429 .56313 L
.39276 .55342 L
.39802 .5445 L
.39889 .54371 L
.40773 .53743 L
.41744 .53485 L
.42376 .53399 L
.42716 .53336 L
.43687 .53194 L
.44658 .53121 L
.45629 .52836 L
.46354 .52428 L
.46061 .51457 L
.45744 .50486 L
.45744 .49514 L
.46061 .48543 L
.46354 .47572 L
.45629 .47164 L
.44658 .46879 L
.43687 .46806 L
.42716 .46664 L
.42376 .46601 L
.41744 .46515 L
.40773 .46257 L
.39889 .45629 L
.39802 .4555 L
.39276 .44658 L
.39429 .43687 L
.39802 .43264 L
.40415 .42716 L
F
.88 .458 0 r
.41744 .42703 m
.42716 .42617 L
.43687 .42597 L
.44658 .42617 L
.45629 .42665 L
.46355 .42716 L
.46601 .42728 L
.47572 .42752 L
.48543 .43021 L
.49514 .43277 L
.503 .43687 L
.50306 .44658 L
.49514 .45573 L
.49463 .45629 L
.48916 .46601 L
.49514 .46787 L
.50486 .46879 L
.51457 .46921 L
.52428 .47146 L
.53399 .47099 L
.54371 .47066 L
.55342 .47035 L
.56313 .47 L
.57284 .4696 L
.58256 .46911 L
.59227 .46851 L
.60198 .46777 L
.61169 .46685 L
.61894 .46601 L
.62141 .46587 L
.63112 .46472 L
.64083 .46273 L
.65054 .46013 L
.66026 .45719 L
.66284 .45629 L
.66997 .45438 L
.67968 .45231 L
.68939 .45131 L
.69911 .45165 L
.70882 .45426 L
.7123 .45629 L
.71853 .46255 L
.71998 .46601 L
.71893 .47572 L
.71853 .47681 L
.71485 .48543 L
.71217 .49514 L
.71217 .50486 L
.71485 .51457 L
.71853 .52319 L
.71893 .52428 L
.71998 .53399 L
.71853 .53745 L
.7123 .54371 L
.70882 .54574 L
.69911 .54835 L
.68939 .54869 L
.67968 .54769 L
.66997 .54562 L
.66284 .54371 L
.66026 .54281 L
.65054 .53987 L
.64083 .53727 L
.63112 .53528 L
.62141 .53413 L
.61894 .53399 L
.61169 .53315 L
.60198 .53223 L
.59227 .53149 L
.58256 .53089 L
.57284 .5304 L
.56313 .53 L
.55342 .52965 L
.54371 .52934 L
.53399 .52901 L
.52428 .52854 L
.51457 .53079 L
.50486 .53121 L
.49514 .53213 L
.48916 .53399 L
.49463 .54371 L
.49514 .54427 L
.50306 .55342 L
.503 .56313 L
.49514 .56723 L
.48543 .56979 L
.47572 .57248 L
.46601 .57272 L
.46355 .57284 L
.45629 .57335 L
.44658 .57383 L
.43687 .57403 L
.42716 .57383 L
.41744 .57297 L
.4121 .57284 L
.40773 .57153 L
.39802 .56426 L
.39728 .56313 L
.39509 .55342 L
.39802 .54724 L
.40145 .54371 L
.40773 .53886 L
.41744 .53557 L
.42716 .53418 L
.42884 .53399 L
.43687 .53285 L
.44658 .53218 L
.45629 .53001 L
.46601 .52701 L
.46714 .52428 L
.46601 .52199 L
.46219 .51457 L
.45865 .50486 L
.45865 .49514 L
.46219 .48543 L
.46601 .47801 L
.46714 .47572 L
.46601 .47299 L
.45629 .46999 L
.44658 .46782 L
.43687 .46715 L
.42884 .46601 L
.42716 .46582 L
.41744 .46443 L
.40773 .46114 L
.40145 .45629 L
.39802 .45276 L
.39509 .44658 L
.39728 .43687 L
.39802 .43574 L
.40773 .42847 L
.4121 .42716 L
F
0 .136 .22 r
.39802 .49403 m
.40773 .49307 L
.41299 .49514 L
.41299 .50486 L
.40773 .50693 L
.39802 .50597 L
.39616 .50486 L
.39616 .49514 L
F
.91 .355 0 r
.42716 .42702 m
.43687 .42681 L
.44658 .42695 L
.45182 .42716 L
.45629 .42733 L
.46601 .42771 L
.47572 .42784 L
.48543 .43119 L
.49514 .43407 L
.50029 .43687 L
.50105 .44658 L
.49514 .45343 L
.49235 .45629 L
.48543 .46324 L
.48284 .46601 L
.48543 .46826 L
.49514 .46923 L
.50486 .46959 L
.51457 .46978 L
.52428 .47204 L
.53399 .47146 L
.54371 .47106 L
.55342 .47071 L
.56313 .47036 L
.57284 .46995 L
.58256 .46948 L
.59227 .46891 L
.60198 .46822 L
.61169 .46736 L
.62141 .4663 L
.62376 .46601 L
.63112 .46529 L
.64083 .46364 L
.65054 .46139 L
.66026 .45883 L
.66997 .45633 L
.67012 .45629 L
.67968 .45448 L
.68939 .45375 L
.69911 .4547 L
.70471 .45629 L
.70882 .45882 L
.71453 .46601 L
.71392 .47572 L
.71058 .48543 L
.70882 .49335 L
.70857 .49514 L
.70857 .50486 L
.70882 .50665 L
.71058 .51457 L
.71392 .52428 L
.71453 .53399 L
.70882 .54118 L
.70471 .54371 L
.69911 .5453 L
.68939 .54625 L
.67968 .54552 L
.67012 .54371 L
.66997 .54367 L
.66026 .54117 L
.65054 .53861 L
.64083 .53636 L
.63112 .53471 L
.62376 .53399 L
.62141 .5337 L
.61169 .53264 L
.60198 .53178 L
.59227 .53109 L
.58256 .53052 L
.57284 .53005 L
.56313 .52964 L
.55342 .52929 L
.54371 .52894 L
.53399 .52854 L
.52428 .52796 L
.51457 .53022 L
.50486 .53041 L
.49514 .53077 L
.48543 .53174 L
.48284 .53399 L
.48543 .53676 L
.49235 .54371 L
.49514 .54657 L
.50105 .55342 L
.50029 .56313 L
.49514 .56593 L
.48543 .56881 L
.47572 .57216 L
.46601 .57229 L
.45629 .57267 L
.45182 .57284 L
.44658 .57305 L
.43687 .57319 L
.42716 .57298 L
.42283 .57284 L
.41744 .57211 L
.40773 .56935 L
.4003 .56313 L
.39802 .55864 L
.39744 .55342 L
.39802 .55141 L
.40406 .54371 L
.40773 .54062 L
.41744 .53642 L
.42716 .53477 L
.43482 .53399 L
.43687 .53374 L
.44658 .53301 L
.45629 .53152 L
.46601 .53047 L
.47069 .52428 L
.46601 .51841 L
.46373 .51457 L
.45982 .50486 L
.45982 .49514 L
.46373 .48543 L
.46601 .48159 L
.47069 .47572 L
.46601 .46953 L
.45629 .46848 L
.44658 .46699 L
.43687 .46626 L
.43482 .46601 L
.42716 .46523 L
.41744 .46358 L
.40773 .45938 L
.40406 .45629 L
.39802 .44859 L
.39744 .44658 L
.39802 .44136 L
.4003 .43687 L
.40773 .43065 L
.41744 .42789 L
.42283 .42716 L
F
.94 .244 0 r
.40773 .43287 m
.41744 .42932 L
.42716 .42803 L
.43687 .42763 L
.44658 .42765 L
.45629 .42789 L
.46601 .42817 L
.47572 .4283 L
.48543 .4322 L
.49514 .43551 L
.49749 .43687 L
.49899 .44658 L
.49514 .45123 L
.48998 .45629 L
.48543 .46021 L
.47572 .46562 L
.47431 .46601 L
.47572 .47441 L
.48543 .47087 L
.49514 .4704 L
.50486 .47033 L
.51457 .47032 L
.52428 .47258 L
.53399 .47189 L
.54371 .47144 L
.55342 .47107 L
.56313 .4707 L
.57284 .4703 L
.58256 .46984 L
.59227 .4693 L
.60198 .46865 L
.61169 .46786 L
.62141 .4669 L
.62889 .46601 L
.63112 .46581 L
.64083 .46449 L
.65054 .4626 L
.66026 .46041 L
.66997 .4583 L
.67968 .45677 L
.68939 .45647 L
.69911 .45829 L
.70879 .46601 L
.70882 .46609 L
.70913 .47572 L
.70882 .47713 L
.70672 .48543 L
.70525 .49514 L
.70525 .50486 L
.70672 .51457 L
.70882 .52287 L
.70913 .52428 L
.70882 .53391 L
.70879 .53399 L
.69911 .54171 L
.68939 .54353 L
.67968 .54323 L
.66997 .5417 L
.66026 .53959 L
.65054 .5374 L
.64083 .53551 L
.63112 .53419 L
.62889 .53399 L
.62141 .5331 L
.61169 .53214 L
.60198 .53135 L
.59227 .5307 L
.58256 .53016 L
.57284 .5297 L
.56313 .5293 L
.55342 .52893 L
.54371 .52856 L
.53399 .52811 L
.52428 .52742 L
.51457 .52968 L
.50486 .52967 L
.49514 .5296 L
.48543 .52913 L
.47572 .52559 L
.47418 .52428 L
.46601 .51581 L
.46523 .51457 L
.46097 .50486 L
.46097 .49514 L
.46523 .48543 L
.46601 .48419 L
.47418 .47572 L
.46601 .46722 L
.45629 .46708 L
.44658 .46625 L
.44182 .46601 L
.43687 .46556 L
.42716 .46458 L
.41744 .46254 L
.40773 .45721 L
.40672 .45629 L
.39979 .44658 L
.40338 .43687 L
F
.44658 .53375 m
.45629 .53292 L
.46601 .53278 L
.47431 .53399 L
.47572 .53438 L
.48543 .53979 L
.48998 .54371 L
.49514 .54877 L
.49899 .55342 L
.49749 .56313 L
.49514 .56449 L
.48543 .5678 L
.47572 .5717 L
.46601 .57183 L
.45629 .57211 L
.44658 .57235 L
.43687 .57237 L
.42716 .57197 L
.41744 .57068 L
.40773 .56713 L
.40338 .56313 L
.39979 .55342 L
.40672 .54371 L
.40773 .54279 L
.41744 .53746 L
.42716 .53542 L
.43687 .53444 L
.44182 .53399 L
F
.97 .126 0 r
.40773 .43565 m
.41744 .43077 L
.42716 .42908 L
.43687 .42846 L
.44658 .42833 L
.45629 .42847 L
.46601 .42871 L
.47572 .42893 L
.48543 .43327 L
.49459 .43687 L
.49514 .43733 L
.49689 .44658 L
.49514 .4489 L
.48752 .45629 L
.48543 .45795 L
.47572 .46337 L
.46601 .46516 L
.45629 .46578 L
.44658 .4655 L
.43687 .46491 L
.42716 .46382 L
.41744 .46127 L
.40944 .45629 L
.40773 .45503 L
.40217 .44658 L
.40656 .43687 L
F
.41744 .53873 m
.42716 .53618 L
.43687 .53509 L
.44658 .5345 L
.45629 .53422 L
.46601 .53484 L
.47572 .53663 L
.48543 .54205 L
.48752 .54371 L
.49514 .5511 L
.49689 .55342 L
.49514 .56267 L
.49459 .56313 L
.48543 .56673 L
.47572 .57107 L
.46601 .57129 L
.45629 .57153 L
.44658 .57167 L
.43687 .57154 L
.42716 .57092 L
.41744 .56923 L
.40773 .56435 L
.40656 .56313 L
.40217 .55342 L
.40773 .54497 L
.40944 .54371 L
F
1 0 0 r
.41744 .43237 m
.42716 .43017 L
.43687 .42931 L
.44658 .42905 L
.45629 .42911 L
.46601 .42935 L
.47572 .42977 L
.48543 .43441 L
.4916 .43687 L
.49475 .44658 L
.48543 .45592 L
.48495 .45629 L
.47572 .4615 L
.46601 .46325 L
.45629 .46471 L
.44658 .46472 L
.43687 .4642 L
.42716 .46293 L
.41744 .45972 L
.41225 .45629 L
.40773 .4526 L
.40459 .44658 L
.40773 .43885 L
.40983 .43687 L
F
.41744 .54028 m
.42716 .53707 L
.43687 .5358 L
.44658 .53528 L
.45629 .53529 L
.46601 .53675 L
.47572 .5385 L
.48495 .54371 L
.48543 .54408 L
.49475 .55342 L
.4916 .56313 L
.48543 .56559 L
.47572 .57023 L
.46601 .57065 L
.45629 .57089 L
.44658 .57095 L
.43687 .57069 L
.42716 .56983 L
.41744 .56763 L
.40983 .56313 L
.40773 .56115 L
.40459 .55342 L
.40773 .5474 L
.41225 .54371 L
F
.97 .126 0 r
.64083 .46528 m
.65054 .46374 L
.66026 .46195 L
.66997 .46027 L
.67968 .45921 L
.68939 .45934 L
.69911 .46279 L
.70265 .46601 L
.70451 .47572 L
.70316 .48543 L
.70226 .49514 L
.70226 .50486 L
.70316 .51457 L
.70451 .52428 L
.70265 .53399 L
.69911 .53721 L
.68939 .54066 L
.67968 .54079 L
.66997 .53973 L
.66026 .53805 L
.65054 .53626 L
.64083 .53472 L
.63443 .53399 L
.63112 .53358 L
.62141 .53252 L
.61169 .53165 L
.60198 .53093 L
.59227 .53032 L
.58256 .52981 L
.57284 .52937 L
.56313 .52897 L
.55342 .5286 L
.54371 .5282 L
.53399 .52771 L
.52428 .52695 L
.51457 .52915 L
.50486 .52897 L
.49514 .52856 L
.48543 .52734 L
.47764 .52428 L
.47572 .52325 L
.4667 .51457 L
.46601 .51353 L
.4621 .50486 L
.4621 .49514 L
.46601 .48647 L
.4667 .48543 L
.47572 .47675 L
.47764 .47572 L
.48543 .47266 L
.49514 .47144 L
.50486 .47103 L
.51457 .47085 L
.52428 .47305 L
.53399 .47229 L
.54371 .4718 L
.55342 .4714 L
.56313 .47103 L
.57284 .47063 L
.58256 .47019 L
.59227 .46968 L
.60198 .46907 L
.61169 .46835 L
.62141 .46748 L
.63112 .46642 L
.63443 .46601 L
F
1 0 0 r
.65054 .46483 m
.66026 .46344 L
.66997 .46223 L
.67968 .46176 L
.68939 .46285 L
.69577 .46601 L
.69911 .47091 L
.70006 .47572 L
.69989 .48543 L
.69955 .49514 L
.69955 .50486 L
.69989 .51457 L
.70006 .52428 L
.69911 .52909 L
.69577 .53399 L
.68939 .53715 L
.67968 .53824 L
.66997 .53777 L
.66026 .53656 L
.65054 .53517 L
.64093 .53399 L
.64083 .53398 L
.63112 .53289 L
.62141 .53197 L
.61169 .53118 L
.60198 .53052 L
.59227 .52996 L
.58256 .52947 L
.57284 .52905 L
.56313 .52866 L
.55342 .52828 L
.54371 .52786 L
.53399 .52734 L
.52428 .52652 L
.51457 .52864 L
.50486 .5283 L
.49514 .52761 L
.48543 .52588 L
.48107 .52428 L
.47572 .52163 L
.46816 .51457 L
.46601 .51138 L
.4632 .50486 L
.4632 .49514 L
.46601 .48862 L
.46816 .48543 L
.47572 .47837 L
.48107 .47572 L
.48543 .47412 L
.49514 .47239 L
.50486 .4717 L
.51457 .47136 L
.52428 .47348 L
.53399 .47266 L
.54371 .47214 L
.55342 .47172 L
.56313 .47134 L
.57284 .47095 L
.58256 .47053 L
.59227 .47004 L
.60198 .46948 L
.61169 .46882 L
.62141 .46803 L
.63112 .46711 L
.64083 .46602 L
.64093 .46601 L
F
0 .01 .1 r
.52428 .38717 m
.53399 .38511 L
.54371 .38525 L
.55291 .38831 L
.55342 .38851 L
.56289 .39802 L
.55342 .40366 L
.54371 .40532 L
.53399 .40584 L
.52428 .40553 L
.51457 .40415 L
.50527 .39802 L
.51457 .3906 L
.51994 .38831 L
F
.51457 .59585 m
.52428 .59447 L
.53399 .59416 L
.54371 .59468 L
.55342 .59634 L
.56289 .60198 L
.55342 .61149 L
.55291 .61169 L
.54371 .61475 L
.53399 .61489 L
.52428 .61283 L
.51994 .61169 L
.51457 .6094 L
.50527 .60198 L
F
0 .093 .19 r
.58256 .43598 m
.59227 .43586 L
.59571 .43687 L
.60198 .44021 L
.60367 .44658 L
.60198 .44969 L
.59227 .45533 L
.58949 .45629 L
.58256 .45749 L
.57284 .45846 L
.56313 .4586 L
.55342 .4576 L
.54838 .45629 L
.55249 .44658 L
.55342 .44597 L
.56313 .44108 L
.57284 .438 L
.57818 .43687 L
F
.55342 .5424 m
.56313 .5414 L
.57284 .54154 L
.58256 .54251 L
.58949 .54371 L
.59227 .54467 L
.60198 .55031 L
.60367 .55342 L
.60198 .55979 L
.59571 .56313 L
.59227 .56414 L
.58256 .56402 L
.57818 .56313 L
.57284 .562 L
.56313 .55892 L
.55342 .55403 L
.55249 .55342 L
.54838 .54371 L
F
0 .058 .16 r
.56313 .44327 m
.57284 .44034 L
.58256 .43905 L
.59227 .43992 L
.59948 .44658 L
.59227 .45366 L
.58377 .45629 L
.58256 .45647 L
.57284 .45754 L
.56313 .4576 L
.55395 .45629 L
.55588 .44658 L
F
.56313 .5424 m
.57284 .54246 L
.58256 .54353 L
.58377 .54371 L
.59227 .54634 L
.59948 .55342 L
.59227 .56008 L
.58256 .56095 L
.57284 .55966 L
.56313 .55673 L
.55588 .55342 L
.55395 .54371 L
F
0 .03 .13 r
.56313 .44572 m
.57284 .44273 L
.58256 .44185 L
.59227 .44445 L
.59392 .44658 L
.59227 .45083 L
.58256 .45508 L
.57506 .45629 L
.57284 .45646 L
.56313 .45639 L
.56217 .45629 L
.56099 .44658 L
F
.56313 .54361 m
.57284 .54354 L
.57506 .54371 L
.58256 .54492 L
.59227 .54917 L
.59392 .55342 L
.59227 .55555 L
.58256 .55815 L
.57284 .55727 L
.56313 .55428 L
.56099 .55342 L
.56217 .54371 L
F
0 .01 .1 r
.57284 .54517 m
.58256 .54706 L
.58592 .55342 L
.58256 .5547 L
.57284 .55449 L
.56864 .55342 L
F
.57284 .44551 m
.58256 .4453 L
.58592 .44658 L
.58256 .45294 L
.57284 .45483 L
.56864 .44658 L
F
0 .31 .307 r
.98077 .4495 m
.98059 .44658 L
.98077 .44204 L
F
.98077 .55796 m
.98059 .55342 L
.98077 .5505 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[84]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`009oooool3o`0003Gooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol0000booooo`;o0000=Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0003?o
oooo0ol00006ooooo`00:?ooool00ol0003oooooooooo`0cooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`00000`ooooo`04o`000?ooooooooooo`0003?ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000003?ooooo00?o0000ooooooooool0
1Oooool0023ooooo1Ol00003ooooo`03o`000?oooooooooo02cooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool0000cooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`05oooo
o`00:?ooool00ol0003oooooooooo`0cooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0;_ooool01?l0003oooooooooool0000cooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`05ooooo`00:?ooool00ol0003oooooooooo`0c
ooooo`04o`000?ooooooooooo`0000Oooooo1?l0000aooooo`04o`000?ooooooooooo`0003?ooooo
00Co0000oooooooooooo00001oooool4o`0003Cooooo00?o0000ooooooooool01Oooool002Oooooo
0_l0000eooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0<_ooool01?l0003o
ooooooooool0000cooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0=?ooool2
o`0000Oooooo000Xooooo`03o`000?oooooooooo03Cooooo0_l00008ooooo`Go0000<Oooool2o`00
03Gooooo0_l00008ooooo`Go0000<oooool00ol0003oooooooooo`05ooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`008Oooooono`00007ooooo000Qooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00;ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool00_ooool1o`00007ooooo000Qooooo`03o`000?oo
oooooooo0?[ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`3jooooo`7o00000Oooool0
027ooooo0_l0003jooooo`;o00000Oooool0027ooooo00?o0000ooooooooool00_ooool3o`0G<0So
00hX2ol01b7Co`026@[o00LQ1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo
1?l05c08o`0>:0[o00LQd_l00QT;o`078@Gooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`02ooooo`Go01L`1ol03RP;o`078M3o008I3?l01b45ooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool00_ooool00ol08SSo01L`o`0G<004o`0G<0Oo00hX2ol01b7=o`026@go00LQ1Oooool1
o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo0_l08SP6o`0G<0Oo00hX2ol01b7;o`02
6@ko00LQ1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo0ol08SP6o`0G<0So
00hX2_l01b78o`026A3o00LQ1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo
1?l08SP6o`0G<0Oo00hX2ol01b76o`026A7o00LQ1Oooool1o`00007ooooo000Qooooo`03o`000?oo
oooooooo00;ooooo1Ol08SP6o`0G<0Oo00hX2ol01b75o`026A7o00LQ1Oooool1o`00007ooooo000Q
ooooo`03o`000?oooooooooo00;ooooo00?o030oo`0R>?l08SP01?l08SP6o`0G<0Oo00hX2_l01b73
o`026A3o00LQ0_l03RP5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool2o`0`
?`Ko028h1_l05c07o`0>:0[o00LQ`Ol00QT@o`078@?o00hX1Oooool1o`00007ooooo000Qooooo`03
o`000?oooooooooo00;ooooo0ol0<3l6o`0R>0Oo01L`1_l03RP;o`078Kgo008I4?l01b45o`0>:0Go
oooo0Ol00001ooooo`008Oooool2o`0000?ooooo1?l0<3l7o`0R>0Ko01L`1ol03RP:o`078K_o008I
4?l01b46o`0>:0Cooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`0nAol0
<3oo030o00Co030o1Ol08SP6o`0G<0Ko00hX2ol01b6io`026A3o00LQ1ol03RP5ooooo`7o00000Ooo
ool0027ooooo00?o0000ooooooooool00_ooool2o`0nA`Ko030o1Ol08SP6o`0G<0Oo00hX2_l01b6g
o`026A7o00LQ1ol03RP5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool3o`0n
A`Ko030o1Ol08SP6o`0G<0Oo00hX2_l01b6eo`026A7o00LQ2?l03RP5ooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool00_ooool4o`0nA`Oo030o1Ol08SP6o`0G<0Ko00hX2_l01b6co`026A3o
00LQ2_l03RP5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool00ol0Cdko03i7
o`0nA`04o`0nA`Go030o1Ol08SP6o`0G<0Ko00hX2_l01b6ao`026A3o00LQ2ol03RP5ooooo`7o0000
0Oooool0027ooooo00?o0000ooooooooool00_ooool2o`1?CPKo03i71Ol0<3l5o`0R>0Ko01L`1ol0
3RP9o`078Joo008I4?l01b4;o`0>:003o`0G<?oooooooooo00?ooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`02ooooo`?o04m>1_l0?TL5o`0`?`Go028h1_l05c07o`0>:0Wo00LQ[Ol00QT@
o`078@_o00hX0_l05c05ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool4o`1?
CPKo03i71Ol0<3l5o`0R>0Ko01L`1_l03RP:o`078J_o008I4?l01b4;o`0>:0?o01L`1Oooool1o`00
007ooooo000Qooooo`03o`000?oooooooooo00;ooooo1ol0Cdh5o`0nA`Go030o1Ol08SP5o`0G<0Oo
00hX2Ol01b6Xo`026A3o00LQ2ol03RP5o`0G<0Gooooo0Ol00001ooooo`002?ooool2o`0000Cooooo
00?o0000ooooooooool00oooool2o`0000Cooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo
00?o05M:o`1?C_l0Cdh01_l0Cdh5o`0nA`Go030o1?l08SP6o`0G<0Ko00hX2Ol01b6Vo`026A3o00LQ
2ol03RP6o`0G<0Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o
05M:1ol0Cdh5o`0nA`Go030o1Ol08SP5o`0G<0So00hX2?l01b6To`026A3o00LQ2ol03RP7o`0G<0Go
oooo0Ol00001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
oooo0000ooooo`05o`0000Cooooo00?o0000ooooooooool00_ooool4o`1GBPOo04m>1_l0?TL4o`0`
?`Go028h1Ol05c06o`0>:0Wo00LQXol00QT?o`078@_o00hX2?l05c05ooooo`7o00000Oooool000Oo
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o
0000ooooooooool00oooool2o`0000?ooooo1_l0EdX6o`1?CPGo03i71Ol0<3l5o`0R>0Go01L`1_l0
3RP9o`078J7o008I3ol01b4;o`0>:0Wo01L`1?ooool2o`00007ooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005ooooo`03o`00
0?oooooooooo00;ooooo2?l0EdX6o`1?CPGo03i71?l0<3l5o`0R>0Go01L`1_l03RP:o`078Igo008I
3ol01b4;o`0>:0_o01L`1Oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000oooool2o`0000Gooooo00?o0000ooooooooool00_ooool9o`1GBPOo
04m>1Ol0?TL3o`0`?`Go028h1Ol05c07o`0>:0Wo00LQVol00QT?o`078@_o00hX2ol05c000ol08SSo
ooooooooo`03ooooo`7o00000Oooool000Sooooo0_l0000:ooooo`;o00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo3?l0EdX5o`1?CPGo03i71Ol0<3l4o`0R>0Go01L`
1Ol03RP:o`078IWo008I3ol01b4;o`0>:0[o01L`0ol08SP5ooooo`7o00000Oooool0027ooooo00?o
0000ooooooooool00_ooool=o`1GBPGo04m>1Ol0?TL4o`0`?`Go028h1Ol05c06o`0>:0Wo00LQUol0
0QT?o`078@_o00hX2_l05c04o`0R>0Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02
ooooo`ko05M:1Ol0Cdh5o`0nA`Co030o1Ol08SP5o`0G<0Ko00hX2Ol01b6Eo`026@oo00LQ2ol03RP:
o`0G<0Go028h1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo0ol0EdX4o`1N
A@[o05M:1Ol0Cdh4o`0nA`Go030o0ol08SP5o`0G<0Ko00hX2_l01b6Bo`026@oo00LQ2_l03RP:o`0G
<0Oo028h1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo0_l0EdX7o`1NA@Wo
05M:1Ol0Cdh4o`0nA`Go030o1?l08SP5o`0G<0Go00hX2_l01b6@o`026@oo00LQ2_l03RP:o`0G<0So
028h1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo0_l0EdX:o`1NA@Oo05M:
1Ol0Cdh5o`0nA`Co030o1?l08SP4o`0G<0Oo00hX2?l01b6?o`026@ko00LQ2_l03RP:o`0G<0[o028h
1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo0_l0EdX<o`1NA@So05M:1?l0
Cdh4o`0nA`Co030o1?l08SP5o`0G<0Ko00hX2?l01b6=o`026@ko00LQ2_l03RP:o`0G<0[o028h00?o
030oooooooooool00oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo0_l0EdX>
o`1NA@Ko05M:1Ol0Cdh4o`0nA`Co030o1?l08SP5o`0G<0Ko00hX2?l01b6;o`026@ko00LQ2_l03RP:
o`0G<0[o028h0_l0<3l5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool3o`1G
BQ3o05i51Ol0EdX5o`1?CPCo03i71?l0<3l3o`0R>0Go01L`1_l03RP9o`078HSo008I3_l01b4:o`0>
:0[o01L`2_l08SP3o`0`?`Gooooo0Ol00001ooooo`008Oooool2o`0000?ooooo1?l0EdXAo`1NA@Go
05M:1?l0Cdh4o`0nA`Co030o0ol08SP5o`0G<0Ko00hX2Ol01b66o`026@ko00LQ2_l03RP9o`0G<0[o
028h1Ol0<3l4ooooo`;o00000Oooool0027ooooo00?o0000ooooooooool00_ooool4o`1GBQ;o05i5
1Ol0EdX5o`1?CPCo03i70ol0<3l4o`0R>0Go01L`1_l03RP7o`078HGo008I3_l01b49o`0>:0[o01L`
2Ol08SP7o`0`?`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`Co05M:5?l0
GTD5o`1GBPCo04m>1?l0?TL3o`0`?`Co028h1Ol05c05o`0>:0Wo00LQP_l00QT>o`078@Wo00hX2Ol0
5c0:o`0R>0So030o1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo1Ol0EdXD
o`1NA@Go05M:1?l0Cdh3o`0nA`Co030o1?l08SP5o`0G<0Go00hX2Ol01b60o`026@ko00LQ2_l03RP8
o`0G<0[o028h2Ol0<3l5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool00ol0
Cdko05M:o`1GBP03o`1GBP[o05i50ol0ISd8o`1NA@Go05M:1Ol0Cdh2o`0nA`Co030o1?l08SP4o`0G
<0Ko00hX2?l01b5mo`026@ko00LQ2_l03RP9o`0G<0Wo028h2ol0<3l5ooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool00_ooool2o`1?CPGo05M:1ol0GTD8o`1V?@Oo05i51Ol0EdX3o`1?CPCo
03i70ol0<3l4o`0R>0Go01L`1Ol03RP8o`078G_o008I3_l01b4:o`0>:0So01L`2Ol08SP=o`0`?`Go
oooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`?o04m>1Ol0EdX6o`1NA@[o06Hm
2?l0GTD4o`1GBP?o04m>1?l0?TL3o`0`?`Co028h1?l05c06o`0>:0So00LQN?l00QT>o`078@Wo00hX
2Ol05c08o`0R>0go030o0_l0?TL5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_oo
ool01?l0?TOo04m>o`1?C_l0Cdh5o`1GBPGo05i53Ol0ISd6o`1NA@Co05M:1?l0Cdh3o`0nA`Co030o
0ol08SP5o`0G<0Go00hX2?l01b5fo`026@ko00LQ2Ol03RP8o`0G<0Wo028h3Ol0<3l3o`0nA`Gooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`0nAol0Cdko04m>00;o04m>1?l0
EdX6o`1NA@ko06Hm1Ol0GTD4o`1GBP?o04m>1?l0?TL4o`0`?`Co028h0ol05c06o`0>:0So00LQM?l0
0QT=o`078@[o00hX2?l05c08o`0R>0co030o1_l0?TL5ooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool00_ooool2o`0nA`Co04m>1?l0EdX6o`1NAA3o06Hm1Ol0GTD2o`1GBPCo04m>0ol0?TL4
o`0`?`Co028h1?l05c05o`0>:0So00LQL_l00QT>o`078@[o00hX1ol05c09o`0R>0[o030o2?l0?TL5
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool3o`0nA`Co04m>1?l0EdX5o`1N
AA7o06Hm1?l0GTD4o`1GBP?o04m>1?l0?TL3o`0`?`Co028h1?l05c05o`0>:0Oo00LQLOl00QT>o`07
8@[o00hX1ol05c08o`0R>0[o030o2_l0?TL5ooooo`7o00000Oooool0027ooooo00?o0000oooooooo
ool00_ooool4o`0nA`Co04m>1?l0EdX4o`1NAA;o06Hm1Ol0GTD4o`1GBP?o04m>0ol0?TL4o`0`?`?o
028h1?l05c05o`0>:0Oo00LQL?l00QT<o`078@[o00hX1ol05c08o`0R>0[o030o3?l0?TL5ooooo`7o
00000Oooool0027ooooo0_l00003ooooo`03o`0`?ol0?TOo03i700?o03i70ol0Cdh4o`1GBPCo05i5
2Ol0ISd3o`1^<`So06Hm1?l0GTD3o`1GBPCo04m>0ol0?TL3o`0`?`Co028h0ol05c05o`0>:0Oo00LQ
K_l00QT<o`078@[o00hX1ol05c08o`0R>0[o030o3Ol0?TL4ooooo`;o00000Oooool0027ooooo00?o
0000ooooooooool00_ooool2o`0`?`Co03i71?l0Cdh3o`1GBPCo05i51ol0ISd8o`1^<`Ko06Hm0ol0
GTD4o`1GBPCo04m>0_l0?TL4o`0`?`Co028h1?l05c05o`0>:0Oo00LQJ_l00QT=o`078@Wo00hX2?l0
5c07o`0R>0Wo030o4?l0?TL5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool3
o`0`?`Co03i71?l0Cdh3o`1GBPCo05i51_l0ISd:o`1^<`Go06Hm1Ol0GTD2o`1GBPCo04m>0ol0?TL3
o`0`?`Co028h1?l05c05o`0>:0Oo00LQJ?l00QT=o`078@[o00hX1ol05c07o`0R>0Wo030o4Ol0?TL5
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool4o`0`?`Co03i71?l0Cdh3o`1G
BPCo05i51Ol0ISd<o`1^<`Go06Hm1?l0GTD3o`1GBP?o04m>0ol0?TL3o`0`?`Co028h1?l05c05o`0>
:0Oo00LQI_l00QT=o`078@Wo00hX2?l05c07o`0R>0Wo030o4_l0?TL5ooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool00_ooool6o`0`?`?o03i71?l0Cdh4o`1GBP?o05i51Ol0ISd>o`1^<`Go
06Hm0_l0GTD4o`1GBP?o04m>0ol0?TL3o`0`?`Co028h0ol05c05o`0>:0Oo00LQHol00QT=o`078@[o
00hX2?l05c07o`0R>0Oo030o5Ol0?TL5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0
0_ooool00ol08SSo030oo`0`?`04o`0`?`Co03i70ol0Cdh4o`1GBP?o05i51Ol0ISd?o`1^<`Co06Hm
1?l0GTD2o`1GBP?o04m>1?l0?TL3o`0`?`?o028h1?l05c05o`0>:0So00LQGol00QT=o`078@Wo00hX
2?l05c07o`0R>0Oo030o5ol0?TL5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_oo
ool2o`0R>0Go030o1Ol0?TL3o`1?CP?o05M:1?l0GTD4o`1V?A7o06hc0ol0ISd4o`1NA@?o05M:0ol0
Cdh3o`0nA`Co030o0_l08SP4o`0G<0Go00hX1ol01b5Mo`026@ko00LQ2Ol03RP7o`0G<0Oo028h2?l0
<3lHo`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`?o028h1Ol0<3l4
o`0nA`Co04m>0ol0EdX3o`1NA@Go06Hm4Ol0KS<5o`1V?@;o05i50ol0EdX4o`1?CP;o03i71?l0<3l2
o`0R>0Go01L`1?l03RP7o`078Eco008I3Ol01b49o`0>:0Oo01L`1ol08SP8o`0`?`co03i71_l0Cdh7
o`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`Co028h1Ol0<3l4o`0n
A`Co04m>0ol0EdX3o`1NA@Co06Hm1ol0KS<6o`1e9`Ko06hc1?l0ISd3o`1NA@?o05M:0ol0Cdh2o`0n
A`?o030o1?l08SP3o`0G<0Go00hX1ol01b5Jo`026@go00LQ2Ol03RP7o`0G<0Oo028h1ol0<3l<o`0n
A`Wo04m>1_l0?TL5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool6o`0R>0Go
030o0ol0?TL4o`1?CP?o05M:0ol0GTD4o`1V?@Go06hc2ol0MBL5o`1^<`;o06Hm1?l0GTD3o`1GBP;o
04m>0ol0?TL3o`0`?`?o028h0ol05c05o`0>:0Oo00LQF?l00QT=o`078@Wo00hX1_l05c08o`0R>0Oo
030o2_l0?TL<o`1?CPKo03i71Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo
1ol08SP5o`0`?`Co03i70ol0Cdh3o`1GBP?o05i51?l0ISd4o`1^<`go07DW1?l0KS<4o`1V?@;o05i5
0ol0EdX2o`1?CP?o03i70ol0<3l3o`0R>0?o01L`1Ol03RP7o`078EOo008I3?l01b49o`0>:0Ko01L`
1ol08SP7o`0`?`[o03i73ol0Cdh5o`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`02ooooo`Oo028h1_l0<3l4o`0nA`?o04m>0ol0EdX3o`1NA@?o06Hm1?l0KS<?o`1e9`?o06hc1?l0
ISd3o`1NA@;o05M:0ol0Cdh2o`0nA`Co030o0_l08SP4o`0G<0?o00hX1ol01b5Fo`026@co00LQ2?l0
3RP7o`0G<0Oo028h1_l0<3l9o`0nAa;o04m>1Ol0?TL5ooooo`7o00000Oooool0027ooooo0_l00003
ooooo`So028h1_l0<3l4o`0nA`?o04m>0ol0EdX3o`1NA@?o06Hm1?l0KS<?o`1e9`Go06hc0_l0ISd3
o`1NA@;o05M:0ol0Cdh2o`0nA`?o030o0ol08SP4o`0G<0Co00hX1_l01b5Eo`026@co00LQ1ol03RP8
o`0G<0Ko028h1_l0<3l8o`0nAaCo04m>1Ol0?TL4ooooo`;o00000Oooool0027ooooo00?o0000oooo
ooooool00_ooool9o`0R>0Ko030o1?l0?TL3o`1?CP?o05M:0ol0GTD3o`1V?@?o06hc4Ol0MBL3o`1^
<`?o06Hm0ol0GTD2o`1GBP?o04m>0_l0?TL3o`0`?`?o028h0ol05c05o`0>:0Ko00LQDol00QT<o`07
8@Oo00hX1ol05c07o`0R>0Ko030o1ol0?TLFo`1?CPGo03i71Oooool1o`00007ooooo000Qooooo`03
o`000?oooooooooo00;ooooo2ol08SP6o`0`?`?o03i70ol0Cdh3o`1GBP?o05i50ol0ISd3o`1^<`Ko
07DW1Ol0OAX7o`1e9`?o06hc0ol0ISd2o`1NA@?o05M:0_l0Cdh3o`0nA`?o030o0ol08SP3o`0G<0Co
00hX1_l01b5@o`026@co00LQ2?l03RP7o`0G<0Ko028h1ol0<3l7o`0nAaOo04m>1Ol0?TL5ooooo`7o
00000Oooool0027ooooo00?o0000ooooooooool00_ooool<o`0R>0Ko030o0ol0?TL3o`1?CP?o05M:
0ol0GTD3o`1V?@?o06hc1Ol0MBL8o`1m6PGo07DW1?l0KS<3o`1V?@;o05i50ol0EdX2o`1?CP?o03i7
0_l0<3l3o`0R>0Co01L`0ol03RP8o`078D_o008I3?l01b49o`0>:0Ko01L`1ol08SP6o`0`?`Oo03i7
6Ol0Cdh5o`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`go028h1Ol0
<3l4o`0nA`Co04m>0_l0EdX3o`1NA@?o06Hm0ol0KS<4o`1e9`[o07dJ1Ol0MBL3o`1^<`Co06Hm0_l0
GTD3o`1GBP;o04m>0_l0?TL3o`0`?`?o028h0ol05c05o`0>:0Oo00LQAol00QT=o`078@So00hX1ol0
5c06o`0R>0Ko030o1ol0?TLJo`1?CPKo03i71Oooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo3_l08SP5o`0`?`Co03i71?l0Cdh2o`1GBP?o05i50ol0ISd3o`1^<`?o07DW3Ol0OAX5
o`1e9`;o06hc0ol0ISd2o`1NA@?o05M:0_l0Cdh2o`0nA`?o030o1?l08SP3o`0G<0Go00hX2?l01b52
o`026@ko00LQ2?l03RP7o`0G<0Go028h1ol0<3l7o`0nAa_o04m>1_l0?TL5ooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool00_ooool>o`0R>0Ko030o1?l0?TL3o`1?CP?o05M:0ol0GTD3o`1V
?@?o06hc0ol0MBL>o`1m6PCo07DW0ol0KS<2o`1V?@?o05i50_l0EdX3o`1?CP;o03i70ol0<3l3o`0R
>0?o01L`1Ol03RP7o`078D7o008I3Ol01b49o`0>:0Ko01L`1_l08SP6o`0`?`Oo03i77?l0Cdh7o`0n
A`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`;o030o3_l08SP6o`0`?`Co
03i70ol0Cdh3o`1GBP;o05i50ol0ISd2o`1^<`?o07DW2?l0OAX4o`252PGo07dJ1Ol0MBL2o`1^<`?o
06Hm0_l0GTD01?l0Ed[o04m>o`1?C_l0Cdh2o`0nA`?o030o0_l08SP4o`0G<0Co00hX1_l01b50o`02
6@go00LQ2?l03RP7o`0G<0Go028h1_l0<3l7o`0nA`Wo04m>2Ol0EdX<o`1?CPOo03i71Oooool1o`00
007ooooo000Qooooo`03o`000?oooooooooo00;ooooo1?l0<3l=o`0R>0Ko030o1?l0?TL3o`1?CP?o
05M:0_l0GTD3o`1V?@;o06hc0ol0MBL5o`1m6P[o08D:0ol0OAX4o`1e9`;o06hc0ol0ISd2o`1NA@04
o`1GB_l0Cdko04m>o`1?CP;o03i70ol0<3l2o`0R>0Co01L`1?l03RP6o`078Cko008I3Ol01b47o`0>
:0Oo01L`1_l08SP6o`0`?`Go03i72_l0Cdh<o`1GBP_o04m>1ol0?TL5ooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool00_ooool7o`0`?`_o028h1_l0<3l4o`0nA`Co04m>0_l0EdX3o`1NA@;o
06Hm0_l0KS<3o`1e9`?o07dJ3_l0Q@X3o`1m6P;o07DW0ol0KS<2o`1V?@;o05i50_l0EdX2o`1?CP?o
03i70_l0<3l3o`0R>0;o01L`1?l03RP6o`078Cgo008I3Ol01b48o`0>:0Ko01L`1Ol08SP6o`0`?`Go
03i72Ol0Cdh?o`1GBP_o04m>1ol0?TL5ooooo`7o00000Oooool000Sooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0_l00002ooooo`Go00001?ooool00ol0003oooooooooo`02ooooo`Wo030o
2_l08SP6o`0`?`Co03i70ol0Cdh2o`1GBP?o05i50_l0ISd2o`1^<`?o07DW1?l0OAX7o`252PCo1h`0
1?l0Q@X3o`1m6P?o07DW00?o06hco`1V?Ol0ISd00_l0GTD2o`1GBP;o04m>0ol0?TL2o`0`?`?o028h
0_l05c04o`0>:0Go00LQ?_l00QT<o`078@Oo00hX1_l05c05o`0R>0Ko030o1Ol0?TL8o`1?CQ;o05M:
2_l0Cdh7o`0nA`Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooo
o`[o030o2_l08SP6o`0`?`Co03i70ol0Cdh2o`1GBP?o05i50_l0ISd2o`1^<`?o07DW0ol0OAX5o`25
2PKo1h`01Ol0Q@X2o`1m6P?o07DW0_l0KS<2o`1V?@;o05i50_l0EdX2o`1?CP;o03i70_l0<3l3o`0R
>0?o01L`0ol03RP5o`078Cko008I2ol01b47o`0>:0Oo01L`1Ol08SP5o`0`?`Go03i71ol0CdhDo`1G
BPWo04m>2?l0?TL5ooooo`7o00000Oooool000Go00000_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool2o`0000?ooooo3?l0<3l:
o`0R>0Ko030o1?l0?TL2o`1?CP?o05M:0_l0GTD2o`1V?@;o06hc0_l0MBL4o`1m6P?o08D:2ol7S003
o`252P?o07dJ0_l0MBL01?l0KS?o06Hmo`1V?Ol0ISd2o`1NA@05o`1GB_l0Cdko04m>o`1?C_l0?TL0
0ol0<3l2o`0R>0?o01L`0ol03RP5o`078Cgo008I2ol01b47o`0>:0Go01L`1_l08SP5o`0`?`Go03i7
1_l0CdhFo`1GBPWo04m>2?l0?TL4ooooo`;o00000Oooool000Oooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool>o`0`?`Wo028h1_l0<3l4o`0nA`;o04m>0ol0EdX2o`1NA@;o06Hm0_l0KS<2o`1e9`?o
07dJ1?l0Q@X;o`N<00?o08D:0ol0OAX2o`1e9`04o`1^<ol0ISgo06Hmo`1V?@;o05i50_l0EdX2o`1?
CP04o`0nAol0<3oo030oo`0`?`;o028h0ol05c04o`0>:0Go00LQ>_l00QT;o`078@Oo00hX1Ol05c05
o`0R>0Go030o1Ol0?TL7o`1?CQOo05M:2Ol0Cdh8o`0nA`Gooooo0Ol00001ooooo`001oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo4Ol0<3l6o`0R>0So030o0ol0?TL3o`1?CP;o05M:
0_l0GTD2o`1V?@;o06hc0ol0MBL2o`1m6PCo08D:2ol7S004o`252P;o07dJ0_l0MBL2o`1^<`;o06Hm
00Co05i5o`1GB_l0Ed[o05M:0_l0Cdh2o`0nA`;o030o0ol08SP3o`0G<0?o00hX1_l01b4fo`026@co
00LQ1_l03RP6o`0G<0Go028h1Ol0<3l5o`0nA`Go04m>6_l0EdX8o`1?CPWo03i71Oooool1o`00007o
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oooolCo`0`?`Co028h2Ol0<3l3
o`0nA`?o04m>0_l0EdX3o`1NA@03o`1V?Ol0KS?o06hc00?o07DW0_l0OAX4o`252P_o1h`01Ol0Q@X2
o`1m6P?o07DW0_l0ISd3o`1NA@;o05M:0ol0Cdh2o`0`?`?o028h1Ol05c02o`0>:0Go00LQ<ol00QT<
o`078@Oo00hX1Ol05c05o`0R>0Go030o1Ol0?TL5o`1?CPco05M:1?l0GTD<o`1GBPSo04m>2Ol0?TL5
ooooo`7o00000Oooool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000Gooooo00?o0000oooo
ooooool00_oooolPo`0`?`Co03i70ol0Cdh2o`1GBP?o05i500Co06Hmo`1^<ol0KS?o06hc0_l0MBL3
o`1m6P;o08D:3_l7S002o`252P;o07dJ0ol0MBL2o`1^<`?o06Hm0_l0GTD2o`1GBP03o`1?C_l0?TOo
03i700?o030o0_l08SP5o`0G<0?o00hX1ol01b4[o`026@co00LQ2?l03RP6o`0G<0Go028h1Ol0<3l5
o`0nA`Go04m>2?l0EdX:o`1NA@[o05M:2?l0Cdh:o`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`02ooooob7o030o1?l0?TL3o`1?CP?o05M:0_l0GTD01?l0ISgo06hco`1^<ol0KS<2
o`1e9`?o07dJ0_l0Q@X7o`N<00?o6Y@01Ol7S002o`252P?o07dJ0_l0MBL3o`1^<`;o06Hm0ol0GTD2
o`1?CP?o03i70_l0<3l3o`0R>0Go01L`0ol03RP6o`078BOo008I3?l01b48o`0>:0Oo01L`1Ol08SP5
o`0`?`Go03i71Ol0Cdh7o`1GBPgo05i52Ol0EdX8o`1?CP[o03i71Oooool1o`00007ooooo000Qoooo
o`03o`000?oooooooooo00;ooooo8_l0<3l4o`0nA`?o04m>0ol0EdX2o`1NA@;o06Hm0_l0KS<2o`1e
9`?o07dJ0_l0Q@X4o`N<00[o6Y@00_l7S003o`252P;o07dJ0ol0MBL2o`1^<`;o06Hm0_l0GTD01?l0
Ed[o04m>o`1?C_l0Cdh2o`0nA`?o030o0_l08SP3o`0G<0Co00hX1ol01b4Po`026@oo00LQ2Ol03RP6
o`0G<0Go028h1?l0<3l5o`0nA`Go04m>2?l0EdX?o`1NA@So05M:2?l0Cdh;o`0nA`Gooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`02ooooobGo030o0ol0?TL3o`1?CP;o05M:0ol0GTD00ol0
ISgo06hco`1^<`02o`1e9`;o07dJ0_l0Q@X4o`N<00co6Y@01Ol7S003o`252P;o07DW0ol0KS<2o`1V
?@;o05i500?o05M:o`1?C_l0Cdh00ol0?TL01?l0<3oo028ho`0R>?l08SP2o`0G<0Co00hX1_l01b4N
o`026A3o00LQ2?l03RP6o`0G<0Go028h1?l0<3l5o`0nA`Go04m>1ol0EdXBo`1NA@So05M:2?l0Cdh;
o`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooobKo030o0ol0?TL3o`1?
CP;o05M:0ol0GTD2o`1V?@;o06hc00?o07DWo`1m6_l0OAX00_l0Q@X3o`N<00Co6Y@02?l`W005oaZD
00?o1h`00_l0Q@X3o`1e9`;o06hc0_l0ISd00ol0GTGo05M:o`1GBP02o`1?CP;o03i700Co030oo`0R
>?l08SSo028h0_l05c04o`0>:0Go00LQ7_l00QT?o`078@Oo00hX1ol05c05o`0R>0Co030o0ol0?TL5
o`1?CPSo05M:5?l0GTD8o`1GBPSo04m>2ol0?TL5ooooo`7o00000Oooool0027ooooo00?o0000oooo
ooooool00_ooool9o`0`?`So03i75_l0<3l4o`0nA`;o04m>0ol0EdX00ol0GTGo06Hmo`1V?@02o`1^
<`;o07DW00Co07dJo`252_l0Q@[o08D:0_l7S003oaZD00Ko<9`00om8X`05oc2L00?o6Y@000?o1h`0
o`252_l0OAX00_l0OAX00ol0MBOo06hco`1V?@02o`1V?@;o05M:0_l0Cdh2o`0nA`;o030o0_l08SP2
o`0G<0Co00hX1?l01b4Qo`026@co00LQ1ol03RP6o`0G<0Go028h1?l0<3l4o`0nA`Go04m>1Ol0EdXH
o`1NA@Oo05M:2Ol0Cdh;o`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02oooo
o`Wo030o2_l0?TLEo`0`?`Co03i70_l0Cdh3o`1GBP03o`1NAOl0ISgo06Hm00;o06hc0_l0MBL00ol0
OA[o08D:o`252P02o`N<00?o6Y@01?l`W008odRS00Co<9`00_lJU0001_l7S03o08D:o`252_l0Q@[o
07dJo`1e9`;o06hc00Co06Hmo`1NAOl0Ed[o05M:0_l0Cdh2o`0nA`;o030o0_l08SP2o`0G<0?o00hX
0ol01b4So`026@_o00LQ1ol03RP6o`0G<0Co028h1?l0<3l4o`0nA`Go04m>1Ol0EdX7o`1NA@_o06Hm
1ol0GTD7o`1GBPWo04m>2ol0?TL5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_oo
ool9o`0`?`go03i74ol0<3l4o`0nA`;o04m>0_l0EdX2o`1NA@;o06Hm0_l0KS<00ol0MBOo07dJo`1m
6P02o`252P03o`N<0?lJU03o6Y@000?o<9`01?m8X`05of6[00?oB:<00ol`W002oaZD00;o1h`000Co
08D:o`1m6_l0OA[o07DW0_l0KS<01Ol0ISgo05i5o`1GB_l0Ed[o04m>00;o03i70_l0<3l2o`0R>0;o
01L`0_l03RP4o`078BGo008I2Ol01b46o`0>:0Ko01L`1?l08SP5o`0`?`?o03i71?l0Cdh5o`1GBPGo
05i53ol0ISd7o`1NA@Oo05M:2Ol0Cdh;o`0nA`Gooooo0Ol00001ooooo`008Oooool2o`0000?ooooo
2Ol0<3l?o`0nAa?o030o0ol0?TL3o`1?CP06o`1GB_l0GTGo05i5o`1NAOl0ISgo06hc0_l0MBL2o`1m
6P03o`252_l7S03o1h`000;o6Y@00_l`W004odRS00OoHJ/00om8X`02oc2L00;o6Y@00_l7S0001?l0
Q@[o07dJo`1e9ol0MBL2o`1^<`;o05i50_l0EdX00ol0Cdko03i7o`0nA`02o`0`?`04o`0R>?l05c3o
01L`o`0G<0;o00hX0ol01b4Uo`026@Wo00LQ1_l03RP5o`0G<0Go028h1?l0<3l3o`0nA`Co04m>1?l0
EdX6o`1NAA3o06Hm1ol0GTD7o`1GBP_o04m>2Ol0?TL4ooooo`;o00000Oooool0027ooooo00?o0000
ooooooooool00_ooool:o`0`?a3o03i74_l0<3l3o`0nA`?o04m>00Ko05M:o`1NAOl0GTGo05i5o`1V
?Ol0KS<2o`1e9`;o07dJ00?o08D:o`N<0?l7S0000_lJU002oc2L00CoB:<01omQZ`03odRS00;o<9`0
0_lJU002o`N<0004o`252_l0OA[o07dJo`1e9`;o06hc0_l0GTD2o`1GBP03o`1?C_l0?TOo03i700;o
030o00Co028ho`0G<?l05c3o01L`0_l03RP5o`078B;o008I2Ol01b46o`0>:0Go01L`1?l08SP5o`0`
?`;o03i71?l0Cdh4o`1GBPGo05i54ol0ISd6o`1NA@Oo05M:3Ol0Cdh7o`0nA`Gooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`02ooooo`_o030o4?l0?TLAo`0`?`Co03i70_l0Cdh3o`1GBP03
o`1NAOl0ISgo06Hm00;o06hc00?o07DWo`1m6_l0OAX00_l0Q@X00ol7S03o6Y@0oaZD0003oc2L00;o
B:<01omQZ`04odRS00?o<9`000?o6Y@0o`N<0?l0Q@X00_l0Q@X00ol0OA[o07DWo`1^<`02o`1V?@03
o`1NAOl0Ed[o05M:00;o04m>00?o03i7o`0`?ol0<3l00ol08SP2o`0G<0;o00hX1Ol01b4Oo`026@[o
00LQ1_l03RP4o`0G<0Co028h1?l0<3l3o`0nA`Co04m>1?l0EdX4o`1NAAGo06Hm1_l0GTD7o`1GBQCo
04m>1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o028ho`0`?ol0<3l0
2Ol0<3lAo`0nAa3o030o1?l0?TL2o`1?CP?o05M:00?o05i5o`1V?Ol0ISd00_l0KS<00ol0MBOo07dJ
o`1m6P02o`252P04o`N<0?lJU03o6Y@0oaZD00;o<9`00om8X`06of6[00CoB:<00ol`W0000olJU03o
1h`0o`252P02o`252P03o`1m6_l0MBOo06hc00;o06hc0_l0GTD2o`1GBP03o`1?C_l0?TOo03i700?o
030o0_l08SP2o`0G<0?o00hX1Ol01b4Jo`026@[o00LQ1ol03RP5o`0G<0?o028h1?l0<3l4o`0nA`?o
04m>1?l0EdX4o`1NA@So06Hm1_l0KS<8o`1V?@Ko05i51ol0EdXDo`1?CPGooooo0Ol00001ooooo`00
8Oooool00ol0003oooooooooo`02ooooo`;o028h2ol0<3lBo`0nA`oo030o1?l0?TL2o`1?CP?o05M:
00?o05i5o`1V?Ol0ISd00_l0KS<00ol0MBOo07dJo`1m6P02o`252P04o`N<0?lJU03o6Y@0oaZD00;o
<9`01Om8X`04of6[00CoB:<00ol`W0001_lJU03o1h`0o`N<0?l7S03o08D:o`1m6P?o07DW00?o06hc
o`1V?Ol0GTD00_l0GTD2o`1?CP?o03i70_l0<3l2o`0R>0?o01L`1Ol03RP7o`078A3o008I2ol01b47
o`0>:0Go01L`1?l08SP4o`0`?`Co03i70ol0Cdh4o`1GBPCo05i51_l0ISd9o`1^<`So06Hm1_l0GTD7
o`1GBQCo04m>1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo0ol08SP:o`0`
?aGo03i73?l0<3l5o`0nA`?o04m>0_l0EdX3o`1NA@03o`1V?Ol0KS?o07DW00;o07DW00Go07dJo`25
2_l0Q@[o08D:o`N<0002oaZD00;o<9`00om8X`07of6[00GoB:<00ol`W002o`N<00?o08D:0_l0OAX3
o`1^<`;o06Hm0ol0EdX2o`1?CP;o03i70ol0<3l2o`0R>0?o01L`1Ol03RPJo`078@Oo00hX1Ol05c05
o`0R>0?o030o1?l0?TL4o`1?CPCo05M:1?l0GTD6o`1V?@_o06hc2?l0ISd6o`1NA@So05M:4ol0Cdh5
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool4o`0R>0[o030o5ol0?TL;o`0`
?`Go03i70ol0Cdh2o`1GBP;o05i500Co06Hmo`1^<ol0KS?o06hc0_l0MBL3o`252P03o`N<0?lJU03o
6Y@000;o<9`00om8X`0;of6[00?oB:<00_l`W003oaZD00;o1h`00ol0OAX2o`1e9`?o06Hm0_l0GTD2
o`1?CP?o03i70_l0<3l3o`0R>0;o01L`1Ol03RPCo`078@Oo00hX2?l05c05o`0R>0;o030o1Ol0?TL5
o`1?CP;o05M:1Ol0GTD5o`1V?@ko06hc2?l0ISd6o`1NA@Wo05M:4_l0Cdh5ooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool00_ooool6o`0R>0[o030o6Ol0?TL8o`0`?`Go03i71?l0Cdh2o`1G
BP06o`1NAOl0ISgo06Hmo`1V?Ol0KS?o07DW0ol0OAX2o`N<0003oaZD0?l`W03o<9`000?oB:<00_mQ
Z`0<ogfc00;oHJ/00om8X`02oc2L00?o6Y@00_l0Q@X3o`1e9`04o`1^<ol0ISgo05i5o`1GBP?o04m>
0_l0<3l3o`0R>0?o01L`1?l03RPAo`078@Oo00hX1ol05c04o`0R>0Co030o1?l0?TL3o`1?CPGo05M:
0_l0GTD5o`1V?A?o06hc1ol0ISd6o`1NA@_o05M:4Ol0Cdh5ooooo`7o00000Oooool0027ooooo00?o
0000ooooooooool00_ooool7o`0R>0[o030o6ol0?TL7o`0`?`Go03i70ol0Cdh2o`1GBP?o05i500?o
06Hmo`1^<ol0MBL00_l0OAX01?l0Q@[o1h`0oaZD0?lJU002oc2L00;oB:<000CoHJ/0ogfc0?mm/`3o
OK<00_nK^P08ok[200GoVkX00_mQZ`03odRS00;o6Y@00ol0Q@X01?l0MBOo06hco`1V?Ol0GTD2o`1G
BP04o`1?C_l0?TOo030oo`0`?`;o028h0ol05c04o`0>:17o00LQ1_l03RP6o`0G<0Go028h0ol0<3l4
o`0nA`?o04m>1Ol0EdX2o`1NA@Go06Hm1ol0KS<9o`1e9`Ko06hc1_l0ISd6o`1NA@ko05M:3_l0Cdh5
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool8o`0R>0[o030o6ol0?TL8o`0`
?`Go03i70_l0Cdh2o`1GBP;o05i50_l0ISd01_l0KS?o07DWo`1m6_l0OA[o08D:o`N<00;o6Y@000Co
<9`0odRS0?mQZ`3oHJ/00_mm/`02oi^j00?o^/802?o:^003ok[20006oi^j0?mm/`3oOK<0of6[0?m8
X`3o<9`00_lJU0001ol7S03o08D:o`1m6_l0MBOo06hco`1V?Ol0GTD00_l0EdX01Ol0Cdko03i7o`0`
?ol0<3oo028h00;o01L`1?l03RP4o`078@Oo008I1_l01b46o`0>:0Go01L`1Ol08SP4o`0`?`?o03i7
1?l0Cdh3o`1GBP?o05i51?l0ISd5o`1^<`ko07DW1_l0KS<5o`1V?@Ko05i56Ol0EdX4o`1?CPGooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`[o028h2Ol0<3l:o`0nA`[o04m>1ol0
?TL:o`0`?`Co03i70_l0Cdh2o`1GBP03o`1NAOl0ISgo06Hm00;o06hc00?o07dJo`252_l0Q@X00_lJ
U0001Ol`W03oB:<0of6[0?mQZ`3oOK<000;oVkX00_nj`P02olZh00_odJ<00_nj`P001_nK^P3oOK<0
ogfc0?m8X`3o<9`0oaZD00;o1h`000Go07dJo`1e9ol0KS?o06Hmo`1NA@02o`1GBP05o`1?C_l0?TOo
030oo`0`?ol08SP00_l05c02o`0>:0?o00LQ2ol00QT5o`078@Go00hX1Ol05c05o`0R>0Co030o0ol0
?TL4o`1?CP;o05M:0ol0GTD4o`1V?@;o06hc2?l0MBL8o`1m6PGo07DW1?l0KS<5o`1V?@Ko05i57?l0
EdX00ol0Cdkoooooooooo`03ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool;
o`0R>0Wo030o2?l0?TL=o`1?CPOo03i72_l0<3l3o`0nA`;o04m>0_l0EdX01_l0GTGo06Hmo`1V?Ol0
KS?o07DWo`1m6P;o08D:0_lJU0001?l`W03oB:<0of6[0?mm/`02oi^j00;o^/800ooAX`09omV=000D
om6S0?o:^03ob[P0ok[20?nK^P3oOK<0of6[0?m8X`3o<9`0oaZD0?l7S03o08D:o`1m6_l0MBOo06hc
o`1V?Ol0GTGo05M:o`1?C_l0?TL2o`0`?`04o`0R>?l05c3o01L`o`0>:0?o00LQ3Ol00QT5o`078@Go
00hX1?l05c05o`0R>0Co030o0_l0?TL4o`1?CP;o05M:0ol0GTD3o`1V?@;o06hc1Ol0MBL>o`1m6PGo
07DW1?l0KS<4o`1V?@Oo05i57?l0EdX5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0
0_ooool<o`0R>0So030o1ol0?TL>o`1?CPSo03i72_l0<3l2o`0nA`?o04m>00?o05M:o`1NAOl0GTD0
0_l0ISd2o`1e9`;o08D:00Ko1h`0oaZD0?l`W03oB:<0of6[0?mm/`02oi^j0004ok[20?o:^03odJ<0
om6S00?ofHd01?oQM@03omV=000Fom6S0?o:^03ob[P0ok[20?nK^P3oOK<0of6[0?m8X`3o<9`0oaZD
0?l7S03o08D:o`1m6_l0MBOo06hco`1V?Ol0GTGo05M:o`1?C_l0?TOo030oo`0R>0;o01L`0ol03RP2
o`078@go008I1Ol01b45o`0>:0Co01L`1?l08SP4o`0`?`?o03i70ol0Cdh2o`1GBP?o05i50_l0ISd3
o`1^<`?o07DW1Ol0OAX9o`252PCo07dJ1?l0MBL4o`1^<`Co06Hm1ol0GTDLo`1GBPGooooo0Ol00001
ooooo`008Oooool2o`0000?ooooo3?l08SP9o`0`?`Oo03i73ol0Cdh6o`0nA`[o030o0ol0?TL3o`1?
CP08o`1GB_l0GTGo05i5o`1V?Ol0KS?o07DWo`1m6_l0Q@X2o`N<0006oaZD0?l`W03oB:<0of6[0?mm
/`3oVkX00_nj`P02olZh0003om6S0?oIS@3ofHd000?ofHd000GohGD0omV=0?oIS@3ofHd0om6S0002
olZh000:ok[20?nK^P3oVkX0ogfc0?mQZ`3oB:<0oc2L0?lJU03o1h`0o`252P;o07DW0_l0ISd00ol0
GTGo04m>o`1?CP02o`0`?`03o`0R>?l05c3o01L`00?o00hX0_l01b4;o`026@Go00LQ1_l03RP5o`0G
<0Co028h0ol0<3l3o`0nA`?o04m>0_l0EdX3o`1NA@;o06Hm0ol0KS<2o`1e9`Co07dJ2ol0Q@X5o`1m
6PCo07DW0ol0KS<5o`1V?@Oo05i56ol0EdX4ooooo`;o00000Oooool0027ooooo00?o0000oooooooo
ool00_ooool=o`0R>0Wo030o1ol0?TL?o`1?CPKo03i72_l0<3l3o`0nA`;o04m>0_l0EdX02?l0GTGo
06Hmo`1V?Ol0KS?o07DWo`1m6_l0Q@[o1h`00_lJU0001Ol`W03oB:<0of6[0?mm/`3oVkX000;o^/80
0_o:^002om6S00KofHd00_oAX`02olZh000Bok[20?nK^P3oVkX0ogfc0?mQZ`3oB:<0oc2L0?lJU03o
1h`0o`252_l0OA[o07DWo`1^<ol0ISgo05i5o`1GB_l0Cdko03i70_l0<3l2o`0R>0;o01L`0ol03RP>
o`078@Oo00hX1_l05c04o`0R>0?o030o0ol0?TL2o`1?CP;o05M:1?l0GTD2o`1V?@;o06hc0ol0MBL2
o`1m6Pko08D:1?l0OAX4o`1e9`Co06hc1?l0ISd:o`1NAASo05M:1Oooool1o`00007ooooo000Qoooo
o`03o`000?oooooooooo00;ooooo3Ol08SP:o`0`?`So03i73_l0Cdh6o`0nA`Wo030o1?l0?TL2o`1?
CP;o05M:0_l0GTD00ol0ISgo06hco`1e9`02o`1m6P03o`252_l7S03o6Y@000;o<9`000?oB:<0ogfc
0?mm/`000_nK^P000onj`P3ob[P0olZh0003om6S0004omV=0?oAX`3odJ<0om6S00?ob[P00_nj`P02
oi^j0006ogfc0?mQZ`3oHJ/0odRS0?l`W03o6Y@00_l0Q@X3o`1e9`;o06Hm0ol0EdX2o`0nA`?o030o
0_l08SP5o`0G<0ko00hX1ol05c05o`0R>0?o030o0ol0?TL2o`1?CP;o05M:0_l0GTD3o`1V?@;o06hc
0ol0MBL2o`1m6PGo08D:1Ol7S005o`252PCo07dJ1?l0MBL4o`1^<`Go06Hm4?l0GTDAo`1GBPGooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`go028h2ol0<3l8o`0nA`ko04m>2_l0
?TL4o`0`?`Co03i70ol0Cdh2o`1GBP;o05i50_l0ISd2o`1e9`03o`1m6_l0Q@[o08D:00?o6Y@00_m8
X`03ogfc00;o^/800oo:^003om6S00Cob[P00onj`P02oi^j00;oOK<000?oHJ/0odRS0?m8X`000_lJ
U003o`252P;o07DW0ol0KS<2o`1NA@?o05M:0_l0Cdh3o`0nA`;o030o4ol05c06o`0R>0?o030o0ol0
?TL2o`1?CP?o05M:00?o05i5o`1V?Ol0ISd00_l0KS<3o`1e9`?o07dJ1?l0Q@X8o`N<00Go08D:1?l0
OAX3o`1e9`Go06hc1Ol0ISdDo`1NA@co05M:1Oooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo3Ol08SP=o`0`?`So03i73ol0Cdh?o`0nA`Go04m>0_l0EdX00ol0GTGo06Hmo`1^<`02
o`1^<`03o`1e9ol0OA[o08D:00;o08D:0_lJU003odRS00;oHJ/00onK^P02ok[200Sob[P00_nj`P03
oi^j00;oOK<00_mQZ`03oc2L00;o6Y@00ol0Q@X2o`1m6P?o06hc0_l0ISd3o`1NA@Go05M:0_l0?TL5
o`0`?`go028h1?l0<3l2o`0nA`;o04m>0_l0EdX3o`1NA@;o06Hm0_l0KS<3o`1e9`?o07dJ0_l0Q@X;
o`N<00Go08D:1?l0OAX3o`1e9`Ko06hc1ol0ISdDo`1NA@Wo05M:1Oooool1o`00007ooooo000Qoooo
o`03o`000?oooooooooo00;ooooo2ol08SP@o`0`?`So03i74ol0Cdh;o`0nA`Go04m>0ol0EdX3o`1V
?@;o06hc0ol0OAX2o`252P?o6Y@00_m8X`001OmQZ`3oOK<0ogfc0?nK^P3o^/8000Cob[P01?oAX`07
olZh00;o^/800onK^P02ogfc00?oB:<00_l`W003o`N<00;o08D:0ol0OAX2o`1^<`?o06Hm0_l0EdX3
o`1?CP04o`0nAol0<3oo030oo`0`?`So028h1_l0<3l00ol0?TOo04m>o`1?CP02o`1GBP?o05i50_l0
ISd3o`1^<`;o07DW0ol0OAX2o`252Pgo1h`01Ol0Q@X4o`1m6PCo07DW1Ol0KS<<o`1V?@oo05i52Ol0
EdX5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool6o`0R>1Ko030o2?l0?TLG
o`1?CPKo03i71_l0Cdh3o`1GBP;o05i50_l0ISd01?l0KS?o07DWo`1e9ol0OAX2o`252P03o`N<0?lJ
U03o<9`000;oB:<000GoHJ/0ogfc0?nK^P3oVkX0ok[20002olZh00;odJ<01?oIS@0:on5e00;ofHd0
00?odJ<0olZh0?o:^0000_nj`P000onK^P3oOK<0of6[0002odRS0006oc2L0?lJU03o1h`0o`252_l0
OA[o07DW0_l0KS<01?l0ISgo05i5o`1GB_l0EdX2o`1?CP;o03i71?l0<3l5o`0R>0Go030o0_l0?TL0
1?l0Cdko05M:o`1GB_l0EdX2o`1NA@;o06Hm0_l0KS<3o`1e9`03o`1m6_l0Q@[o08D:00;o08D:0ol7
S007oaZD00Go1h`01?l0Q@X4o`1m6PGo07DW1_l0KS<>o`1V?@go05i52?l0EdX5ooooo`7o00000Ooo
ool0027ooooo00?o0000ooooooooool00_ooool00ol08SSo030oo`0`?`0Mo`0`?`Ko03i72_l0Cdh3
o`1GBPko04m>1?l0?TL7o`1?CP;o05M:0_l0GTD00ol0ISgo06hco`1e9`02o`1m6P04o`252_l7S03o
<9`0odRS00;oHJ/00_nK^P001Onj`P3ob[P0olZh0?oAX`3ofHd000;oj5X00_o`?P0@ool000;ohGD0
0ooAX`002onK^P3oOK<0odRS0?m8X`3o<9`0o`N<0?l0Q@[o07DWo`1^<ol0ISgo05i500;o05M:0_l0
Cdh2o`0nA`;o030o1_l08SP4o`0`?`;o03i70_l0Cdh00ol0Ed[o05i5o`1NA@02o`1V?@?o07DW0_l0
OAX3o`252P;o1h`03olJU003o`N<00Co08D:1?l0OAX5o`1e9`Wo06hc3ol0ISd9o`1NA@So05M:1Ooo
ool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo8?l0<3l7o`0nA`Oo04m>3Ol0EdX7
o`1?CPOo03i71Ol0Cdh2o`1GBP03o`1NAOl0ISgo06Hm00;o07DW00go07dJo`252_l7S03o<9`0odRS
0?mQZ`3oOK<0oi^j0?nj`P3ob[P0om6S0?oIS@3oj5X000;ol3h04ooo00003ooh803oj5X0onQJ0?oI
S@3odJ<0ok[20?mm/`3oHJ/0odRS0?lJU03o1h`0o`1m6_l0MBOo06Hmo`1NA@02o`1GBP03o`1?C_l0
?TOo03i700;o030o2?l08SP2o`0`?`03o`0nAol0Cdko04m>00;o05M:00?o05i5o`1V?Ol0ISd00_l0
MBL3o`1m6P;o1h`00olJU002oc2L00SoB:<01Ol`W003oaZD00?o1h`00ol0Q@X4o`1m6PGo07DW3_l0
KS<<o`1V?@Oo05i52?l0EdX5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_oooolR
o`0`?`Go03i71_l0Cdh@o`1GBPGo04m>3?l0?TL2o`1?CP04o`1GB_l0GTGo06Hmo`1^<`;o07DW00go
08D:o`N<0?lJU03oB:<0of6[0?mm/`3o^/80olZh0?oAX`3ohGD0onQJ0?o`?P3on20001Coo`00017o
n200oo0n0?oXFP3ofHd0om6S0?nj`P3oVkX0of6[0?m8X`3o6Y@0o`N<0?l0OA[o07DWo`1V?Ol0GTGo
05M:o`1?CP03o`0`?`So01L`0_l08SP01Ol0<3oo03i7o`0nAol0Cdko05M:00;o05i500?o06Hmo`1^
<ol0OAX00_l0Q@X2o`N<0003oaZD0?l`W03o<9`000?oB:<02_mQZ`04odRS00;o<9`00_lJU003o`N<
00?o08D:0ol0OAX7o`1e9a3o06hc2_l0ISd6o`1NA@So05M:1Oooool1o`00007ooooo000Qooooo`03
o`000?oooooooooo00;ooooo8_l0<3l6o`0nA`Go04m>1_l0EdX8o`1NA@?o05M:1Ol0Cdh5o`0nA`Co
030o0ol0?TL2o`1?CP0Ao`1GB_l0GTGo06Hmo`1^<ol0MBOo07dJo`252_lJU03o<9`0odRS0?mm/`3o
VkX0olZh0?oAX`3ohGD0onQJ0?o`?P005_oo00002ooh803oj5X0omV=0?oAX`3o^/80oi^j0?mQZ`3o
B:<0oaZD0?l7S03o07DW00;o06Hm00Co05M:o`0nAol0<3oo030o0_l05c02o`0>:0Co00LQ00Go00hX
o`0G<?l08SSo028ho`0`?`02o`0nA`;o05M:00Go05i5o`1V?Ol0MBOo07dJo`252P02o`N<00?o<9`0
0_mQZ`03ogfc00SoVkX01?mm/`000omQZ`3oB:<0odRS0002oc2L00;o6Y@00ol7S002o`252PCo07dJ
1ol0MBLAo`1^<`So06Hm1ol0GTD7o`1GBPGooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`02ooooob?o030o1Ol0?TL4o`1?CPKo05M:2Ol0GTD4o`1GBPCo04m>1?l0?TL6o`0`?`?o03i701;o
04m>o`1GB_l0Ed[o05i5o`1V?Ol0KS?o07dJo`252_l7S03o<9`0odRS0?mm/`3oVkX0olZh0?oIS@3o
hGD0oo0n0?oh800Fool0000:ooPP0?oXFP3ofHd0olZh0?nK^P3oHJ/0odRS0?l`W03o1h`0o`1m6P;o
06Hm00?o05M:o`0nAol0<3l00_l05c000ol03RSo00LQo`078@03o`026@;o00LQ0_l03RP02?l05c3o
028ho`0`?ol0?TOo04m>o`1GB_l0GTGo06Hm0_l0MBL2o`N<0003oaZD0?l`W03oB:<000;oOK<00_nK
^P000onj`P3ob[P0olZh0006olZh00?o^/800_nK^P02ogfc0003of6[0?m8X`3oB:<000;o<9`00_lJ
U002o`N<00;o08D:1?l0OAX7o`1e9a;o06hc1ol0ISd7o`1NA@Oo05M:1Oooool1o`00007ooooo000Q
ooooo`;o00000ooooolSo`0`?`Go03i71?l0Cdh5o`1GBP_o05i51?l0EdX3o`1?CPCo03i71_l0<3l3
o`0nA`;o04m>013o05M:o`1NAOl0ISgo06hco`1e9ol0Q@[o1h`0oaZD0?l`W03oHJ/0oi^j0?nj`P3o
dJ<0omV=0?oXFP3on2005_oo00004Oo`?P3ohGD0omV=0?o:^03oVkX0odRS0?l`W03o1h`0o`1m6_l0
KS?o05i5o`1GB_l0?TOo030oo`0R>?l05c3o00hX00;o00LQ1?l00QT2o`078@04o`0>:?l05c3o028h
o`0`?`;o04m>00?o05i5o`1V?Ol0KS<00_l0OAX00ol7S03o6Y@0oc2L0002of6[00?o^/800_o:^009
omV=00;odJ<00_o:^0001?nj`P3oVkX0oi^j0?mm/`02of6[0003odRS0?l`W03o<9`000;o6Y@00_l7
S002o`252PGo07dJ3?l0MBL<o`1^<`Ko06Hm1ol0GTD7o`1GBPCooooo0_l00001ooooo`008Oooool0
0ol0003oooooooooo`02ooooobCo030o1Ol0?TL4o`1?CPGo05M:2ol0GTD4o`1GBP?o04m>1?l0?TL6
o`0`?`?o03i70_l0Cdh04?l0Ed[o05i5o`1V?Ol0KS?o07DWo`252_l7S03o6Y@0odRS0?mQZ`3oVkX0
ok[20?oAX`3ofHd0onQJ0?oh800Dool0000Boo0n0?oQM@3ofHd0olZh0?nK^P3oHJ/0oc2L0?lJU03o
08D:o`1e9ol0ISgo05M:o`1?C_l0?TOo030oo`0R>?l05c3o00hX0ol01b401?l00QWo00LQo`078Ol0
1b42o`0G<0;o030o00Ko04m>o`1GB_l0GTGo06hco`1e9ol0OAX2o`N<0005odRS0?mQZ`3oHJ/0oi^j
0?nj`P000ooAX`02omV=00?ohGD00ooXFP03on5e00;ofHd00_oAX`001Oo:^03o^/80oi^j0?nK^P3o
OK<000;oHJ/000?oB:<0oc2L0?l`W0000_lJU002o`N<00?o08D:1?l0OAX?o`1e9`Wo06hc1_l0ISd6
o`1NA@Oo05M:1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo9?l0<3l6o`0n
A`?o04m>1_l0EdX:o`1NA@Co05M:1?l0Cdh4o`0nA`Co030o0ol0?TL3o`1?CP05o`1GB_l0GTGo06Hm
o`1^<ol0MBL00_l0OAX00ol7S03o6Y@0odRS0002ogfc0003oi^j0?o:^03ofHd000;oj5X000?ol3h0
ool00?oo00003_oo0002oo0n0003onQJ0?oIS@3ob[P000;oVkX000CoB:<0oaZD0?lJU03o1h`00_l0
MBL3o`1NA@;o03i70ol08SP3o`0G<0?o028h0_l0?TL2o`1NA@03o`1V?Ol0MBOo07DW00;o1h`000?o
6Y@0odRS0?m8X`000_nK^P000oo:^03odJ<0om6S0003on5e00;oj5X01_o`?P03onQJ0005on5e0?oI
S@3ofHd0om6S0?o:^0000_nj`P001?nK^P3oOK<0ogfc0?mQZ`02odRS0004oc2L0?lJU03o6Y@0oaZD
00;o1h`00ol0Q@X5o`1m6Pgo07DW2Ol0KS<6o`1V?@Ko05i51ol0EdX5ooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool00_ooool00ol08SSo030oo`0`?`0Qo`0`?`Oo03i70ol0Cdh8o`1GBPKo
05i51_l0EdX5o`1?CPSo03i71?l0Cdh01Ol0Ed[o05i5o`1NAOl0ISgo06hc00;o07DW00?o07dJo`N<
0?l7S0000om8X`02oi^j00?ofHd00_o`?P0;ool000;on20000Col3h0onQJ0?oXFP3ohGD00_oAX`00
0oo:^03oVkX0oi^j0003odRS00;o1h`00ol0MBL2o`1V?@Ko05i50ol0ISd2o`1e9`?o1h`00_l`W003
odRS00;o^/800ooIS@02onQJ00Gon2001?oo0002ooPP00;ol3h00_oXFP001OoQM@3ofHd0omV=0?oA
X`3ob[P000;o^/8000CoVkX0ogfc0?mm/`3oHJ/00_m8X`02oc2L00;o6Y@00ol7S003o`252PSo07dJ
2Ol0MBL8o`1^<`Ko06Hm1_l0GTD7o`1GBPGooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`02ooooo`;o028h8_l0<3l8o`0nA`Go04m>5?l0EdX7o`1?CP03o`0nAol0Cdko04m>00?o04m>0_l0
EdX2o`1NA@;o06Hm0_l0KS<00ol0MBOo07dJo`1m6P03oaZD00;oB:<00onK^P02olZh00?ofHd00_oX
FP07oo0n00?oj5X00_oQM@03omV=00;ob[P00onK^P02of6[00?oB:<00_l`W002oaZD00Co<9`00_mQ
Z`03ogfc00;o^/800ooAX`02on5e00?ol3h03ooo0002ooPP00;ol3h000Koj5X0on5e0?oIS@3ofHd0
om6S0?o:^002ok[20004oi^j0?mm/`3oOK<0of6[00;oB:<00ol`W002oaZD00?o1h`01Ol0Q@X7o`1m
6POo07DW1ol0KS<6o`1V?@Oo05i51ol0EdX5ooooo`7o00000Oooool0027ooooo00?o0000oooooooo
ool00_ooool3o`0R>27o030o2_l0?TL5o`1?CQCo05M:2ol0Cdh2o`1GBP?o05i51?l0ISd2o`1e9`?o
07dJ0_l7S003oc2L00;oHJ/00onK^P02ok[200;ob[P00ooIS@000ooXFP3ol3h0onQJ000<onQJ00Ko
dJ<00ooIS@02on5e00;oj5X00oo`?P0Lool00005ooPP0?o`?P3ol3h0onQJ0?oQM@000_oIS@001OoA
X`3ob[P0ok[20?nj`P3oVkX000?oOK<000CoHJ/0odRS0?m8X`3oB:<00_l`W004oaZD00;o1h`01Ol0
Q@X6o`1m6PKo07DW1ol0KS<6o`1V?@Oo05i51ol0EdX5ooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool00_ooool4o`0R>1oo030o3Ol0?TL8o`1?CQ[o05M:1_l0GTD5o`1V?@?o06hc0_l0OAX3
o`252P;o6Y@00_l`W0002Om8X`3oHJ/0ogfc0?nK^P3o^/80olZh0?oAX`3ofHd0on5e0003onQJ00;o
n200=Ooo00001_oh803ol3h0oo0n0?oXFP3ohGD0omV=00;odJ<000?ob[P0ok[20?nj`P000_nK^P02
ogfc00;oHJ/00om8X`02oc2L00Co6Y@01?l7S004o`252PGo07dJ1Ol0MBL6o`1^<`Oo06Hm1ol0GTD7
o`1GBPGooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`Oo028h6?l0<3lDo`0n
A`So04m>1ol0EdXNo`1NA@;o06Hm0ol0KS<2o`1e9`;o07dJ00_o08D:oaZD0?m8X`3oOK<0ok[20?o:
^03odJ<0omV=0?oQM@3oj5X0ooPP000hool00006ooPP0?o`?P3ol3h0onQJ0?oQM@3ofHd00_oAX`00
0oo:^03o^/80ok[20002oi^j00;oOK<01?mQZ`03odRS00?o<9`01?lJU003o`N<00Co08D:0ol0OAX5
o`1e9`Go06hc1ol0ISd8o`1NA@Oo05M:1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo
00;ooooo2?l08SPBo`0`?ako03i71?l0Cdh5o`1GBP?o05i51ol0ISd3o`1^<`So06Hm1?l0GTD;o`1G
BP;o05i50_l0KS<02Ol0OA[o08D:oaZD0?m8X`3oOK<0ok[20?oAX`3ofHd0onQJ000jool00007ooPP
0?o`?P3ol3h0onQJ0?oQM@3ofHd0om6S0002olZh00;o^/800_nK^P03ogfc00CoHJ/01?m8X`03oc2L
00?o6Y@01?l7S003o`252P?o07dJ1?l0MBL5o`1^<`Ko06Hm2Ol0GTD7o`1GBPGooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`02ooooo`So028h3ol0<3lQo`0nA`Co04m>0ol0EdX4o`1NA@?o
06Hm1Ol0KS<3o`1e9`Go06hc0ol0ISd3o`1NA@;o05M:1?l0Cdh3o`0nA`?o04m>0_l0EdX02_l0ISgo
06hco`1e9ol0Q@[o6Y@0odRS0?mm/`3o^/80om6S0?oXFP0kool00005ooPP0?o`?P3oj5X0on5e0?oI
S@000_oAX`000oo:^03o^/80ok[20003oi^j00?oOK<01OmQZ`04odRS00?o<9`00olJU004o`N<00;o
08D:0ol0OAX4o`1e9`Co06hc1_l0ISd:o`1NA@Oo05M:1Oooool1o`00007ooooo000Jooooo`;o0000
1Oooool00ol0003oooooooooo`02ooooo`Wo028h3Ol0<3lFo`0nA`Wo030o1?l0?TL4o`1?CP;o05M:
0ol0GTD3o`1V?@;o06hc3?l0MBL01?l0KS?o06Hmo`1V?Ol0ISd2o`1NA@;o05M:0_l0Cdh2o`0nA`Ko
030o00co03i7o`1?C_l0GTGo06Hmo`1^<ol0OA[o1h`0odRS0?mm/`3ob[P0om6S0?oXFP0kool00005
ooPP0?o`?P3oj5X0on5e0?oIS@000_oAX`000oo:^03o^/80ok[20003oi^j00CoOK<01OmQZ`04odRS
00?o<9`00olJU003o`N<00;o08D:1?l0OAX3o`1e9`Co06hc1_l0ISd:o`1NA@Oo05M:1Oooool1o`00
007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool:o`0R
>0co030o5Ol0?TL;o`0`?`Co03i70ol0Cdh2o`1GBP?o05i50_l0ISd2o`1^<`?o07DW2?l0OAX3o`1e
9`04o`1^<ol0ISgo06Hmo`1NA@?o05M:00?o04m>o`0nAol0<3l00ol0<3l2o`0R>0;o030o0_l0?TL0
2_l0Ed[o05i5o`1^<ol0OA[o1h`0odRS0?nK^P3odJ<0onQJ0?o`?P0kool00003ooPP0?o`?P3oj5X0
00;ofHd000?odJ<0olZh0?nj`P000_nj`P02oi^j00KoOK<01OmQZ`04odRS00?o<9`00_lJU003o`N<
00?o08D:0ol0OAX3o`1e9`Co06hc1Ol0ISd:o`1NA@So05M:1Oooool1o`00007ooooo000Iooooo`04
o`000?ooooooooooo`0000Cooooo0_l00003ooooo`[o028h2ol0<3lEo`0nA`co030o1?l0?TL3o`1?
CP;o05M:0_l0GTD2o`1V?@;o06hc0ol0MBL9o`1m6P?o07DW00Co06hco`1V?Ol0ISgo05i50_l0EdX0
0ol0Cdko03i7o`0nA`02o`0`?`Co028h0_l0<3l2o`0nA`09o`1GB_l0GTGo06hco`1m6_l7S03oB:<0
oi^j0?oAX`3oj5X003coo`0000Con200oo0n0?oQM@3ofHd00_oAX`000oo:^03o^/80ok[20003oi^j
00KoOK<01OmQZ`04odRS00?o<9`00_lJU003o`N<00?o08D:0ol0OAX3o`1e9`Co06hc1Ol0ISd:o`1N
A@So05M:1?ooool2o`00007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool00_ooool:o`0R>0_o030o5Ol0?TL<o`0`?`Co03i70ol0Cdh2o`1GBP;o05i50_l0ISd2o`1^
<`?o07DW2Ol0OAX3o`1e9`04o`1^<ol0ISgo06Hmo`1NA@;o05M:00?o04m>o`0nAol0?TL00_l0<3l4
o`0R>0;o030o0_l0?TL02Ol0Ed[o05i5o`1^<ol0OA[o1h`0odRS0?nK^P3odJ<0onQJ000lool00004
ooPP0?o`?P3ohGD0omV=00;odJ<000?ob[P0ok[20?nj`P000onK^P06ogfc00GoHJ/01?m8X`03oc2L
00;o6Y@00ol7S003o`252P?o07dJ0ol0MBL4o`1^<`Go06Hm2_l0GTD8o`1GBPGooooo0Ol00001oooo
o`006Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo2_l08SP;o`0`
?aKo03i72_l0<3l5o`0nA`?o04m>0_l0EdX2o`1NA@?o06Hm0_l0KS<3o`1e9`So07dJ0ol0MBL01?l0
KS?o06Hmo`1V?Ol0GTD2o`1GBP;o04m>00Co03i7o`0`?ol0<3oo030o0ol08SP2o`0`?`;o03i700Wo
05M:o`1NAOl0KS?o07dJo`N<0?m8X`3oVkX0om6S0?oXFP00??oo00001?oh803ol3h0onQJ0?oIS@02
om6S0003olZh0?nj`P3o^/8000?oVkX01_mm/`05of6[00CoB:<00ol`W002oaZD00?o1h`00ol0Q@X3
o`1m6P?o07DW1?l0KS<5o`1V?@[o05i52?l0EdX5ooooo`7o00000Oooool001Wooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`02ooooo`Wo028h3Ol0<3lFo`0nA`So030o1_l0?TL3
o`1?CP;o05M:0ol0GTD3o`1V?@;o06hc1Ol0MBL00ol0OA[o07DWo`1e9`03o`1e9`?o06hc0_l0ISd2
o`1NA@;o05M:0_l0Cdh3o`0nA`Co030o0_l0?TL02ol0Cdko05M:o`1NAOl0KS?o07dJo`N<0?m8X`3o
OK<0olZh0?oAX`3oj5X003_oo`0000Gon200oo0n0?oXFP3ohGD0omV=0002om6S00?o^/800onK^P04
ogfc00GoHJ/01?m8X`03oc2L00?o6Y@00ol7S003o`252P?o07dJ0ol0MBL4o`1^<`Ko06Hm2_l0GTD7
o`1GBPGooooo0Ol00001ooooo`006_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool9o`0R
>0ko030o8_l0?TL3o`1?CP?o05M:1?l0GTD3o`1V?@Ko06hc1?l0MBL4o`1^<`;o06Hm0ol0GTD2o`1G
BPGo04m>1?l0?TL2o`1?CP0;o`1GB_l0GTGo06hco`1^<ol0Q@[o6Y@0odRS0?mm/`3o^/80om6S0?oX
FP00>ooo00001Ooh803ol3h0onQJ0?oQM@3ofHd000;odJ<000?ob[P0ok[20?nj`P000onK^P04ogfc
00CoHJ/01?m8X`03oc2L00Co6Y@00ol7S002o`252P?o07dJ1?l0MBL4o`1^<`Ko06Hm2_l0GTD7o`1G
BPGooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`So028h4?l0<3lOo`0nA`Go
04m>1Ol0EdX4o`1NA@Co06Hm1ol0KS<5o`1V?@Ko05i52Ol0EdX2o`1NA@;o06hc00[o07dJo`252_l0
Q@[o6Y@0odRS0?mm/`3o^/80om6S0?oQM@3oj5X0>_oo00001Ooh803ol3h0onQJ0?oQM@3ofHd000;o
dJ<000?ob[P0ok[20?nj`P000onK^P03ogfc00?oHJ/01?m8X`03oc2L00Go6Y@00_l7S004o`252P?o
07dJ1?l0MBL4o`1^<`Oo06Hm2Ol0GTD7o`1GBPGooooo0Ol00001ooooo`008Oooool00ol0003ooooo
ooooo`02ooooo`Ko028h5ol0<3lHo`0nA`Oo04m>1_l0EdX7o`1NA@Oo06Hm4Ol0GTD3o`1V?@;o06hc
0_l0OAX00ol0Q@[o6Y@0oaZD0002of6[0006oi^j0?nj`P3odJ<0omV=0?oQM@3oj5X0>Ooo00001_oh
803ol3h0oo0n0?oXFP3ohGD0omV=00;odJ<000?ob[P0ok[20?nj`P000_nK^P03ogfc00;oHJ/00om8
X`03oc2L00Go6Y@00_l7S005o`252PCo07dJ1?l0MBL5o`1^<`Oo06Hm2?l0GTD7o`1GBPGooooo0Ol0
0001ooooo`008Oooool00ol0003oooooooooo`02ooooo`Co028h7_l0<3l=o`0nA`So04m>7?l0EdX5
o`1NA@Co06Hm0ol0KS<2o`1e9`;o07dJ00?o08D:o`N<0?l7S0000_l`W0000om8X`3oHJ/0of6[0002
oi^j00;ob[P00_oIS@000ooQM@3oj5X0oo0n0002oo0n03Koo`0000Kon200oo0n0?o`?P3oj5X0on5e
0?oIS@02om6S0003olZh0?nj`P3o^/8000;oVkX00_mm/`02of6[00;oB:<00ol`W004oaZD00?o1h`0
1?l0Q@X6o`1m6PGo07DW1_l0KS<6o`1V?@So05i51ol0EdX5ooooo`7o00000Oooool0027ooooo00?o
0000ooooooooool00_ooool3o`0R>23o030o2_l0?TL8o`1?CQ?o05M:2Ol0Cdh2o`1GBPGo05i50_l0
ISd2o`1^<`?o07dJ0_l7S003oc2L00;oB:<00omm/`02ok[200;ob[P00ooIS@02on5e00Koj5X01oo`
?P03om6S00?ofHd00_oQM@03onQJ00;ol3h00_oh800Nool00005ooPP0?o`?P3ol3h0onQJ0?oQM@00
0_oIS@001?oAX`3ob[P0ok[20?nj`P02oi^j00;oOK<00_mQZ`001?m8X`3o<9`0oc2L0?l`W003oaZD
00?o1h`01?l0Q@X7o`1m6PKo07DW1ol0KS<6o`1V?@Oo05i51ol0EdX5ooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool00_ooool2o`0R>2;o030o2?l0?TL6o`1?CQ;o05M:3_l0Cdh2o`1GBP?o
05i500Ko06Hmo`1^<ol0KS?o07DWo`1m6_l0Q@X2o`N<0003oc2L0?m8X`3oHJ/000;oOK<00_nj`P03
om6S00;ohGD00_oXFP06oo0n00?oj5X00_oQM@02omV=0003om6S0?o:^03o^/8000;o^/800_mm/`03
of6[00SoB:<00_mQZ`03ogfc00;o^/800_o:^0000ooAX`3ofHd0omV=0002onQJ0003oo0n0?oh803o
n20000ooo`0000Gon200oo0n0?o`?P3oj5X0on5e0002omV=0005om6S0?o:^03o^/80ok[20?nK^P00
0_mm/`02of6[0004odRS0?l`W03o<9`0oc2L00;o6Y@01?l7S004o`252POo07dJ1ol0MBL7o`1^<`Ko
06Hm1ol0GTD7o`1GBPGooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`0R
>?l0<3oo030o027o030o1ol0?TL5o`1?CPGo05M:1ol0GTD6o`1GBPCo04m>2_l0?TL2o`1?CP;o05M:
0_l0GTD01ol0ISgo06hco`1e9ol0OA[o08D:o`N<0?lJU0000_m8X`02oi^j0003olZh0?oAX`3odJ<0
00;oj5X03Ooo0002ooPP0003oo0n0?oXFP3ofHd000;odJ<000?ob[P0oi^j0?nK^P000_m8X`000olJ
U03o1h`0o`1m6P02o`1m6P;o06hc2?l0ISd3o`1^<`;o07dJ0olJU002odRS00?oHJ/00_o:^003on5e
00;ol3h00ooh8006ool000;on20000Col3h0onQJ0?oXFP3ohGD00_oIS@001OoAX`3ob[P0ok[20?nj
`P3oVkX000;oOK<000?oHJ/0odRS0?m8X`000_l`W002oaZD00;o1h`00ol0Q@X8o`1m6P[o07DW1ol0
KS<6o`1V?@Oo05i51ol0EdX5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_oooolT
o`0`?`Ko03i71?l0Cdh5o`1GBP[o05i51Ol0EdX3o`1?CPCo03i71Ol0<3l3o`0nA`;o04m>00oo05M:
o`1NAOl0GTGo06Hmo`1^<ol0OA[o08D:o`N<0?lJU03oB:<0of6[0?nK^P3o^/80olZh0?oIS@000_oX
FP0Bool00007oo0n0?oXFP3odJ<0om6S0?o:^03oVkX0of6[0002oaZD0003o`252_l0OA[o06Hm00;o
05i50_l0Cdh3o`0`?`Go028h0ol0<3l2o`1?CP?o06Hm0_l0OAX2o`N<0003oaZD0?mQZ`3oHJ/000;o
^/8000?ob[P0omV=0?oIS@000ooXFP08oo0n00?oj5X00_oIS@001?oAX`3ob[P0olZh0?nj`P02oi^j
0004ogfc0?mQZ`3oHJ/0odRS00;o<9`00_lJU002o`N<00?o08D:1_l0OAX=o`1e9`So06hc1_l0ISd6
o`1NA@Oo05M:1Oooool1o`00007ooooo000Qooooo`;o00000ooooolTo`0`?`Go03i71?l0Cdh5o`1G
BP_o05i51?l0EdX3o`1?CPCo03i71_l0<3l3o`0nA`;o04m>013o05M:o`1NAOl0ISgo06hco`1e9ol0
Q@[o1h`0oaZD0?m8X`3oHJ/0oi^j0?nj`P3odJ<0omV=0?oXFP3on2004ooo00004Ooh803ol3h0omV=
0?oAX`3ob[P0of6[0?m8X`3o6Y@0o`252_l0OA[o06Hmo`1NAOl0Cdko03i7o`0`?ol08SSo01L`00;o
00hX1ol01b400ol03RSo01L`o`0R>002o`0nA`03o`1?C_l0GTGo06Hm00;o07DW00?o07dJoaZD0?l`
W0000_mQZ`000omm/`3o^/80ok[20003om6S00;ohGD01_oXFP02on5e00;ofHd000CodJ<0olZh0?o:
^03o^/800_nK^P001?mm/`3oHJ/0of6[0?m8X`02oc2L00;o6Y@00_l7S003o`252PCo07dJ3ol0MBL9
o`1^<`Ko06Hm1_l0GTD7o`1GBPCooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`02oooo
obCo030o1Ol0?TL4o`1?CPGo05M:2ol0GTD4o`1GBP?o04m>0ol0?TL7o`0`?`?o03i70_l0Cdh2o`1N
A@0=o`1V?Ol0KS?o07DWo`252_l7S03o6Y@0odRS0?mQZ`3o^/80olZh0?oAX`3ohGD0onQJ000Eool0
000BooPP0?oXFP3ofHd0om6S0?nK^P3oHJ/0oc2L0?lJU03o08D:o`1e9ol0ISgo05M:o`1?C_l0?TOo
030oo`0R>?l05c3o00hX0ol01b42o`026@?o00LQ00co00hXo`0G<?l08SSo030oo`0nAol0Cdko05i5
o`1V?Ol0KS?o07DWo`252_l7S002oc2L0003odRS0?mm/`3oOK<000?o^/800_oAX`09omV=00;ob[P0
0_nj`P02oi^j0003ogfc0?mQZ`3oHJ/000;oB:<00_l`W0000olJU03o1h`0o`N<0003o`252PCo07dJ
2ol0MBL>o`1^<`Ko06Hm1_l0GTD7o`1GBPGooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`02ooooob?o030o1Ol0?TL4o`1?CPGo05M:2ol0GTD4o`1GBP?o04m>1?l0?TL6o`0`?`?o03i70_l0
Cdh04?l0Ed[o05i5o`1V?Ol0KS?o07DWo`1m6_l7S03o6Y@0oc2L0?mQZ`3oVkX0olZh0?oAX`3ofHd0
onQJ0?oh800Fool0000AooPP0?oXFP3ofHd0olZh0?nK^P3oHJ/0oc2L0?l7S03o07dJo`1^<ol0ISgo
05M:o`0nAol0<3oo028ho`0G<?l03RP00ol01b43o`026@;o00LQ0_l03RP04?l05c3o028ho`0`?ol0
?TOo04m>o`1NAOl0ISgo06hco`1e9ol0Q@[o1h`0oaZD0?l`W03oB:<0of6[0?mm/`02oi^j00;o^/80
0oo:^004om6S00;ob[P00onj`P02oi^j0003ogfc0?mQZ`3oHJ/000;oB:<00_l`W0001?lJU03o1h`0
o`N<0?l7S002o`252PCo07dJ2?l0MBLAo`1^<`Ko06Hm1ol0GTD7o`1GBPGooooo0Ol00001ooooo`00
8Oooool00ol0003oooooooooo`02ooooob?o030o1Ol0?TL4o`1?CPOo05M:1ol0GTD5o`1GBPCo04m>
1_l0?TL2o`0`?`Co03i700Co04m>o`1GB_l0Ed[o05M:0_l0ISd03?l0KS?o07dJo`252_l7S03o<9`0
odRS0?mm/`3oVkX0olZh0?oIS@3ohGD0oo0n01Ooo`0000oon200onQJ0?oIS@3ob[P0oi^j0?mQZ`3o
B:<0oc2L0?l7S03o07dJo`1e9ol0ISgo05i5o`1GB_l0Cdh00_l0<3l00ol08SSo01L`o`0G<004o`07
8@;o00hX0_l05c001Ol08SSo030oo`0nAol0Cdko05M:00;o05i500Go06hco`1e9ol0OA[o07dJo`25
2P02oaZD00?oB:<00_mm/`03oi^j00Co^/801?nK^P03ogfc00;oHJ/000?oB:<0oc2L0?l`W0000olJ
U002o`N<00;o08D:1?l0OAX7o`1e9a;o06hc1ol0ISd7o`1NA@Oo05M:1Oooool1o`00007ooooo000Q
ooooo`03o`000?oooooooooo00;ooooo8Ol0<3l7o`0nA`Go04m>4Ol0EdX5o`1?CP[o03i70_l0Cdh3
o`1GBP;o06Hm00ko06hco`1e9ol0OA[o08D:oaZD0?l`W03oB:<0ogfc0?nK^P3ob[P0om6S0?oQM@3o
j5X0oo0n01Koo`0001;on200onQJ0?oIS@3odJ<0ok[20?nK^P3oHJ/0odRS0?lJU03o1h`0o`1m6_l0
MBOo06Hmo`1NAOl0Ed[o04m>o`0nAol0<3l2o`0R>0;o01L`0_l03RP3o`0G<0;o028h00Go030oo`0n
Aol0?TOo04m>o`1GBP02o`1NA@04o`1V?Ol0MBOo07DWo`1m6P;o08D:0olJU002oc2L00GoHJ/01?mm
/`05of6[00;oB:<00_l`W003oaZD00?o1h`00_l0Q@X4o`1m6PKo07DW4Ol0KS<9o`1V?@Oo05i51ol0
EdX5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_oooolPo`0`?`Oo03i71ol0Cdh>
o`1GBPKo04m>2?l0?TL3o`1?CP;o05M:00?o05i5o`1V?Ol0ISd00_l0KS<02_l0OA[o08D:o`252_l7
S03o6Y@0odRS0?mQZ`3oOK<0ok[20?o:^002om6S0005omV=0?oXFP3ol3h0oo0n0?oh80004_oo0002
onQJ000>omV=0?oAX`3odJ<0ok[20?nK^P3oHJ/0oc2L0?lJU03o1h`0o`1m6_l0MBOo06Hmo`1NAOl0
EdX2o`1?CP03o`0nAol0<3oo030o00Wo028h00?o030oo`0nAol0?TL00ol0Cdh00ol0Ed[o05i5o`1V
?@02o`1V?@;o07DW0ol0Q@X2o`N<00Go<9`02?m8X`03oc2L00?o6Y@01?l7S003o`252P?o07dJ1_l0
MBL=o`1^<`co06Hm2?l0GTD8o`1GBPGooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02
ooooo`;o028h7Ol0<3l7o`0nA`_o04m>1?l0EdX=o`1?CP;o03i71ol0Cdh2o`1GBP;o05i500Go06Hm
o`1^<ol0KS?o07DWo`1m6P02o`252P0:o`N<0?lJU03o<9`0odRS0?mQZ`3oOK<0oi^j0?nj`P3ob[P0
om6S00;ofHd00ooXFP02ooPP00koo`000_oXFP03om6S00;o^/800_mQZ`002?l`W03o6Y@0oaZD0?l0
Q@[o07dJo`1e9ol0ISgo05i50_l0EdX2o`1?CP04o`0nAol0<3oo030oo`0`?`Oo028h0_l0<3l3o`0n
A`;o04m>00Co05M:o`1NAOl0GTGo05i50_l0ISd3o`1e9`;o07dJ1Ol7S003oaZD00Ko<9`01?lJU004
o`N<00Co08D:1?l0OAX5o`1e9`So06hc3ol0ISd:o`1NA@So05M:1Oooool1o`00007ooooo000Qoooo
o`03o`000?oooooooooo00;ooooo1?l08SPIo`0`?`So03i76?l0Cdh4o`0nA`Oo04m>0ol0EdX2o`1N
A@03o`1V?Ol0KS?o06hc00;o07DW00Oo07dJo`252_l0Q@[o1h`0oaZD0?l`W03oB:<000;oHJ/00_nK
^P001?nj`P3ob[P0olZh0?oAX`02omV=00?ohGD02_oXFP02on5e00?ofHd000?ob[P0ok[20?nj`P00
0_nK^P000omQZ`3oB:<0odRS0002oaZD0007o`N<0?l0Q@[o07dJo`1e9ol0KS?o06Hmo`1NA@02o`1G
BP;o04m>0_l0?TL4o`0`?`Co028h1?l0<3l3o`0nA`;o04m>0_l0EdX2o`1NA@;o06Hm00?o06hco`1e
9ol0MBL00ol0OAX3o`252PCo1h`02?lJU005o`N<00Co08D:1?l0OAX5o`1e9`Oo06hc3_l0ISd<o`1N
A@So05M:1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo3?l08SP>o`0`?`Wo
03i74_l0Cdh<o`0nA`Go04m>0_l0EdX3o`1NA@;o06hc0ol0MBL2o`252P?o6Y@00_m8X`02of6[0003
ogfc0?nK^P3oVkX000;o^/801?o:^002om6S00Oob[P01Onj`P02ogfc00?oHJ/00_m8X`03oaZD00;o
1h`00ol0OAX2o`1e9`;o06hc00?o06Hmo`1GB_l0EdX00ol0Cdh2o`0nA`Co030o1ol08SP6o`0`?`04
o`0nAol0Cdko04m>o`1?CP;o05M:0ol0GTD2o`1V?@?o06hc0_l0MBL3o`1m6P;o08D:3?l7S004o`25
2PCo07dJ1Ol0MBL6o`1^<`[o06Hm4Ol0GTD8o`1GBPGooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`02ooooo`go028h3?l0<3l8o`0nAa7o04m>3ol0?TL3o`1?CP;o05M:0_l0GTD00ol0ISgo
06hco`1^<`02o`1e9`03o`1m6_l0Q@[o08D:00;o6Y@000?o<9`0odRS0?m8X`000_mQZ`03oi^j00;o
^/802?o:^002ok[200?oVkX00_mm/`02of6[00?oB:<00_lJU003o`N<00;o07dJ0ol0MBL2o`1^<`?o
06Hm0_l0GTD3o`1GBPGo03i70_l0<3l?o`0R>0?o030o0ol0?TL2o`1?CP;o05M:0_l0GTD2o`1V?@;o
06hc0ol0MBL3o`1m6P?o08D:2_l7S005o`252PCo07dJ1?l0MBL5o`1^<`Oo06Hm4ol0GTD:o`1GBPGo
oooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`go028h2ol0<3l7o`0nAa3o04m>
2?l0?TL4o`0`?`Go03i70ol0Cdh2o`1GBP;o05i500Co06Hmo`1^<ol0MBOo07dJ0_l0Q@X00ol7S03o
6Y@0oaZD0002odRS0003of6[0?mm/`3oOK<000;oVkX00oo:^003om6S00Gob[P00onj`P02oi^j0004
ogfc0?mQZ`3oB:<0odRS00;o<9`00ol7S002o`1m6P?o06hc0_l0ISd3o`1GBP;o04m>0ol0?TL2o`0`
?`?o028h4_l05c05o`0R>0?o030o0ol0?TL2o`1?CP;o05M:0_l0GTD3o`1V?@;o06hc0ol0MBL2o`1m
6PGo08D:1ol7S005o`252PCo07dJ0ol0MBL5o`1^<`Ko06Hm5?l0GTD;o`1GBPGooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`02ooooo`go028h2_l0<3l7o`0nA`oo04m>2?l0?TL7o`0`?`Co
03i70_l0Cdh2o`1GBP;o05i500Go06Hmo`1^<ol0MBOo07dJo`252P02o`N<0003oaZD0?l`W03oB:<0
00;oHJ/00onK^P02olZh00WodJ<00_o:^002ok[200;oVkX000?oOK<0of6[0?m8X`000_l`W002o`N<
0003o`1m6_l0MBOo07DW00;o06Hm0ol0EdX2o`1?CP?o030o1Ol08SP2o`0G<13o00hX1ol05c04o`0R
>0?o030o0ol0?TL2o`1?CP;o05M:0ol0GTD2o`1V?@;o06hc0ol0MBL3o`1m6PGo08D:1?l7S006o`25
2PCo07dJ0ol0MBL5o`1^<`Co06Hm4_l0GTD?o`1GBPGooooo0Ol00001ooooo`008Oooool2o`0000?o
oooo3Ol08SP9o`0`?`Oo03i73ol0Cdh6o`0nA`[o030o0ol0?TL2o`1?CP;o05M:00So05i5o`1V?Ol0
ISgo06hco`1e9ol0OA[o08D:o`N<00;o6Y@000Go<9`0odRS0?mQZ`3oOK<0oi^j0002ok[20004olZh
0?oAX`3odJ<0om6S00KofHd00_oAX`02olZh000Bok[20?nK^P3oVkX0ogfc0?mQZ`3oB:<0oc2L0?lJ
U03o1h`0o`252_l0OA[o07DWo`1^<ol0ISgo05i5o`1GB_l0Cdko03i70_l0<3l2o`0R>003o`0G<?l0
3RSo00hX00;o00hX3ol01b46o`0>:0Ko01L`1?l08SP3o`0`?`?o03i70_l0Cdh2o`1GBP?o05i50_l0
ISd3o`1^<`;o07DW0ol0OAX>o`252PCo07dJ1?l0MBL4o`1^<`Co06Hm2Ol0GTDIo`1GBPCooooo0_l0
0001ooooo`008Oooool00ol0003oooooooooo`02ooooo`go028h2Ol0<3l7o`0nA`ko04m>1ol0?TL:
o`0`?`?o03i70_l0Cdh2o`1GBP06o`1NAOl0ISgo06Hmo`1^<ol0MBOo07dJ0_l7S0001?lJU03o<9`0
oc2L0?mQZ`02ogfc0003oi^j0?nj`P3ob[P000?odJ<02?oIS@001?oAX`3ob[P0olZh0?nj`P02oi^j
0009ogfc0?mQZ`3oB:<0oc2L0?lJU03o1h`0o`252_l0OA[o07DW00;o06Hm00?o05i5o`1?C_l0Cdh0
0ol0<3l01?l08SSo01L`o`0>:?l03RP3o`078@[o008I1_l01b46o`0>:0Go01L`1?l08SP3o`0`?`?o
03i70ol0Cdh2o`1GBP?o05i50_l0ISd3o`1^<`;o07DW1Ol0OAX;o`252PCo07dJ1?l0MBL4o`1^<`Co
06Hm1ol0GTDKo`1GBPGooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`co028h
2Ol0<3l7o`0nA`ko04m>1ol0?TL:o`0`?`?o03i70_l0Cdh2o`1GBP08o`1NAOl0ISgo06Hmo`1^<ol0
MBOo07dJo`252_l7S002oaZD0005oc2L0?m8X`3oOK<0ogfc0?nK^P000_nj`P03om6S00;ofHd01?oQ
M@03omV=0009om6S0?o:^03ob[P0ok[20?nK^P3oOK<0of6[0?m8X`3o<9`000;o6Y@000Wo08D:o`1m
6_l0MBOo06hco`1V?Ol0GTGo05M:o`1?C_l0?TL00_l0<3l01?l08SSo01L`o`0G<?l03RP3o`078@go
008I1Ol01b45o`0>:0Co01L`1?l08SP4o`0`?`?o03i70ol0Cdh2o`1GBP?o05i50_l0ISd3o`1^<`Co
07DW1Ol0OAX7o`252PGo07dJ1?l0MBL4o`1^<`Go06Hm1ol0GTDKo`1GBPGooooo0Ol00001ooooo`00
8Oooool00ol0003oooooooooo`02ooooo`_o028h2Ol0<3l8o`0nA`co04m>2?l0?TL9o`0`?`Co03i7
0_l0Cdh2o`1GBP06o`1NAOl0ISgo06Hmo`1^<ol0MBOo07dJ0_l0Q@X2oaZD0005oc2L0?m8X`3oHJ/0
ogfc0?nK^P000_nj`P001?o:^03odJ<0om6S0?oAX`08omV=00;odJ<00_o:^0004onj`P3oVkX0ogfc
0?mQZ`3oB:<0oc2L0?lJU03o1h`0o`252_l0OA[o07DWo`1^<ol0ISgo05i5o`1GB_l0Cdko03i7o`0`
?ol08SP00_l05c03o`0>:0;o00LQ3Ol00QT5o`078@Go00hX1?l05c04o`0R>0Co030o0ol0?TL4o`1?
CP?o05M:0_l0GTD4o`1V?@;o06hc1Ol0MBL=o`1m6PGo07DW1?l0KS<4o`1V?@Oo05i57?l0EdX5oooo
o`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool:o`0R>0Wo030o2_l0?TL9o`1?CPWo
03i72?l0<3l5o`0nA`;o04m>00?o05M:o`1NAOl0GTD00_l0ISd01_l0KS?o07DWo`1e9ol0OA[o08D:
o`N<00;o6Y@000Co<9`0odRS0?mQZ`3oOK<00_nK^P02ok[200?ob[P00_oAX`02omV=00GodJ<00_o:
^002oi^j0003ogfc0?mQZ`3oHJ/000;o<9`000Ko6Y@0o`N<0?l0Q@[o07dJo`1e9ol0KS<2o`1NA@03
o`1GB_l0Cdko03i700;o030o00?o028ho`0G<?l05c000ol03RP2o`078@_o008I1_l01b45o`0>:0Co
01L`1Ol08SP4o`0`?`?o03i71?l0Cdh3o`1GBP;o05i51Ol0ISd2o`1^<`Go07DW2Ol0OAX5o`1e9`Ko
06hc1?l0ISd7o`1NAA_o05M:00?o04m>ooooooooool00oooool1o`00007ooooo000Qooooo`03o`00
0?oooooooooo00;ooooo2?l08SP:o`0`?`ko03i700?o04m>o`0nAol0?TL02_l0?TL7o`0`?`Go03i7
0ol0Cdh2o`1GBP;o05i50_l0ISd01_l0KS?o07DWo`1m6_l0OA[o08D:o`N<00;o6Y@000Co<9`0odRS
0?mQZ`3oHJ/00_mm/`02oi^j00Co^/801_o:^003ok[200;oVkX00_mm/`02odRS000:oc2L0?lJU03o
6Y@0o`N<0?l0Q@[o07dJo`1e9ol0KS?o06Hmo`1NA@;o05M:00Go04m>o`0nAol0<3oo030oo`0R>002
o`0G<0?o00hX1Ol01b46o`026@Oo00LQ1Ol03RP6o`0G<0Go028h1?l0<3l4o`0nA`;o04m>1Ol0EdX3
o`1NA@Co06Hm0ol0KS<?o`1e9`Ko06hc1Ol0ISd6o`1NAAWo05M:1?l0Cdh5ooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool00_ooool7o`0R>0_o030o6Ol0?TL7o`0`?`Ko03i70_l0Cdh3o`1G
BP;o05i50_l0ISd00ol0KS?o07DWo`1e9`02o`1m6P03o`252_l7S03o6Y@000;o<9`00_m8X`001?mQ
Z`3oOK<0ogfc0?mm/`02oi^j00Wo^/800onK^P02ogfc00?oB:<00_l`W002o`N<0005o`252_l0OA[o
07dJo`1^<ol0ISd00_l0GTD01?l0Ed[o04m>o`1?C_l0?TL2o`0`?`03o`0R>?l05c3o01L`00Co00hX
4_l01b45o`0>:0Oo01L`1Ol08SP3o`0`?`Go03i70ol0Cdh5o`1GBP;o05i51Ol0ISd5o`1^<`Wo07DW
1ol0KS<6o`1V?@Ko05i53ol0EdX=o`1?CPGooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`02ooooo`Ko028h2_l0<3lHo`0nA`Wo030o1_l0?TL2o`1?CP?o05M:00?o05i5o`1V?Ol0ISd00_l0
KS<2o`1e9`04o`1m6_l0Q@[o08D:o`N<00;o6Y@000Co<9`0odRS0?m8X`3oB:<00omQZ`03ogfc00Co
VkX01Omm/`03of6[00;o<9`00olJU002o`N<00?o07dJ0_l0KS<01?l0ISgo05i5o`1GB_l0EdX2o`1?
CP03o`0nAol0<3oo030o00;o028h0ol05c04o`0>:17o00LQ2?l03RP5o`0G<0Go028h1Ol0<3l4o`0n
A`?o04m>1?l0EdX3o`1NA@Go06Hm4_l0KS<7o`1V?@Ko05i52ol0EdXAo`1?CPGooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`02ooooo`Co028h2ol0<3lEo`0nA`_o030o1Ol0?TL3o`1?CP;o
05M:0ol0GTD00ol0ISgo06hco`1^<`02o`1e9`;o07dJ00?o08D:o`N<0?l7S0000_lJU002oc2L00?o
B:<02_mQZ`03odRS00;o<9`00olJU002o`N<00?o08D:0_l0MBL2o`1^<`03o`1V?Ol0GTGo05i500;o
05M:0ol0?TL2o`0`?`?o028h0_l05c05o`0>:1Go00LQ1ol03RP8o`0G<0Go028h0_l0<3l5o`0nA`?o
04m>1?l0EdX3o`1NA@Oo06Hm3Ol0KS<7o`1V?@Ko05i52_l0EdXBo`1?CPGooooo0Ol00001ooooo`00
8Oooool00ol0003oooooooooo`02ooooo`?o028h2ol0<3lCo`0nA`go030o1Ol0?TL2o`1?CP?o05M:
0_l0GTD2o`1V?@;o06hc00?o07DWo`1m6_l0OAX00_l0Q@X00ol7S03o6Y@0oaZD0002oc2L00GoB:<0
1OmQZ`05odRS00?o<9`00_lJU003o`252P;o07dJ0ol0KS<2o`1V?@?o05i50_l0Cdh2o`0nA`?o030o
1?l08SP00ol05c3o00hXo`0>:003o`0>:1co00LQ1ol03RP5o`0G<0Go028h0ol0<3l4o`0nA`?o04m>
1Ol0EdX2o`1NA@So06Hm2_l0KS<8o`1V?@Ko05i52?l0EdXCo`1?CPGooooo0Ol00001ooooo`008Ooo
ool00ol0003oooooooooo`02ooooo`;o028h2ol0<3lAo`0nAa3o030o1?l0?TL2o`1?CP?o05M:00?o
05i5o`1V?Ol0ISd00_l0KS<2o`1e9`03o`1m6_l0Q@[o08D:00;o1h`00_lJU002oc2L00CoB:<01OmQ
Z`04odRS00?o<9`00_lJU0000ol7S03o08D:o`252P02o`1m6P03o`1e9ol0KS?o06hc00?o05i50_l0
EdX3o`0nA`;o030o0_l08SP3o`0G<0Go00hX1ol01b44o`026@03o`078Ol00QWo008I00Wo008I3?l0
1b47o`0>:0Go01L`0ol08SP5o`0`?`Co03i70ol0Cdh3o`1GBPGo05i51ol0ISd8o`1^<`So06Hm1_l0
GTD7o`1GBQCo04m>1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo0_l08SP:
o`0`?a7o03i74Ol0<3l3o`0nA`;o04m>0ol0EdX2o`1NA@03o`1V?Ol0KS?o06hc00;o07DW00?o07dJ
o`252_l0Q@X00_l7S002oaZD00;o<9`00om8X`06of6[00CoB:<00_l`W002oaZD00;o1h`000Co08D:
o`1m6_l0OA[o07DW0_l0KS<00ol0ISgo05i5o`1NA@02o`1GBP;o03i70ol0<3l2o`0R>0;o01L`0ol0
3RP7o`078A[o008I2_l01b45o`0>:0Go01L`1Ol08SP3o`0`?`Co03i70ol0Cdh4o`1GBPCo05i52Ol0
ISd4o`1^<`Wo06Hm1_l0GTD7o`1GBQCo04m>1Oooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo00?o028ho`0`?ol0<3l02?l0<3lAo`0nAa7o030o0ol0?TL3o`1?CP;o05M:0_l0GTD0
0ol0ISgo06hco`1^<`02o`1e9`03o`1m6_l0Q@[o08D:00;o1h`000?o6Y@0oc2L0?l`W0001?m8X`06
of6[00CoB:<00_l`W002oaZD00;o1h`000Go08D:o`1m6_l0OA[o07DWo`1^<`02o`1V?@;o05i500Co
05M:o`1?C_l0?TOo03i70_l0<3l2o`0R>0;o01L`0ol03RP5o`078B3o008I2Ol01b46o`0>:0Co01L`
1?l08SP4o`0`?`?o03i71?l0Cdh4o`1GBPCo05i55Ol0ISd6o`1NA@Oo05M:5?l0Cdh5ooooo`7o0000
0Oooool0027ooooo0_l00003ooooo`[o030o3ol0?TLBo`0`?`Co03i70ol0Cdh00ol0Ed[o05i5o`1N
A@02o`1V?@03o`1^<ol0MBOo07DW00;o07dJ00?o08D:o`N<0?l7S0000_lJU002oc2L00CoB:<01omQ
Z`03odRS00;o<9`00_lJU002o`N<0004o`252_l0OA[o07dJo`1e9`;o06hc00Go06Hmo`1NAOl0Ed[o
05M:o`1?CP02o`0nA`;o030o00Co028ho`0G<?l05c3o01L`0ol03RP3o`078B?o008I2Ol01b46o`0>
:0Go01L`1?l08SP4o`0`?`?o03i71?l0Cdh4o`1GBPKo05i54_l0ISd6o`1NA@Oo05M:3?l0Cdh8o`0n
A`Cooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`Wo030o3_l0?TLCo`0`?`Co
03i70_l0Cdh2o`1GBP;o05i50_l0ISd2o`1^<`03o`1e9ol0OA[o07dJ00;o08D:00Co1h`0oaZD0?lJ
U03o6Y@00_l`W003odRS00OoHJ/00om8X`02oc2L00;o6Y@00_l7S0001?l0Q@[o07dJo`1m6_l0MBL2
o`1^<`05o`1V?Ol0GTGo05M:o`1GB_l0Cdh00_l0?TL2o`0`?`;o028h0_l05c02o`0>:0Co00LQ9?l0
0QT9o`078@Ko00hX1Ol05c05o`0R>0Co030o0ol0?TL4o`1?CPCo05M:1_l0GTDAo`1V?@Ko05i51ol0
EdX:o`1?CP[o03i71Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo2Ol0<3l<
o`0nAaCo030o1?l0?TL2o`1?CP;o05M:0_l0GTD2o`1V?@;o06hc00?o07DWo`1m6_l0OAX00_l0Q@X0
0ol7S03o6Y@0oaZD0003oc2L00GoB:<00omQZ`05odRS00;o<9`00_lJU0000ol7S03o08D:o`252P02
o`1m6P05o`1e9ol0KS?o06hco`1V?Ol0GTD00_l0EdX00ol0Cdko03i7o`0nA`02o`0`?`;o028h0_l0
5c02o`0>:0Co00LQ9?l00QT:o`078@Ko00hX1Ol05c05o`0R>0Co030o1Ol0?TL3o`1?CPGo05M:1Ol0
GTD?o`1V?@Oo05i51ol0EdX9o`1?CP_o03i71Oooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo2Ol0<3l;o`0nAaCo030o1?l0?TL2o`1?CP?o05M:0_l0GTD00ol0ISgo06hco`1^<`02
o`1e9`;o07dJ0_l0Q@X01?l7S03o6Y@0oaZD0?lJU004oc2L00WoB:<00ol`W002oaZD0003o`N<0?l0
Q@[o08D:00;o07dJ00?o07DWo`1^<ol0KS<00_l0ISd01?l0GTGo05M:o`1GB_l0Cdh2o`0nA`;o030o
0_l08SP2o`0G<0?o00hX0ol01b4Ro`026@co00LQ1ol03RP5o`0G<0Go028h1?l0<3l5o`0nA`Co04m>
1Ol0EdX6o`1NA@_o06Hm2?l0GTD7o`1GBPWo04m>2ol0?TL5ooooo`7o00000Oooool0027ooooo00?o
0000ooooooooool00_ooool9o`0`?`Oo03i75ol0<3l4o`0nA`?o04m>0_l0EdX2o`1NA@05o`1V?Ol0
KS?o06hco`1^<ol0MBL00_l0OAX2o`252P;o1h`00olJU005oc2L00?oB:<01Ol`W003oaZD00;o1h`0
0_l0Q@X2o`1m6P03o`1e9ol0KS?o06hc00;o06Hm00?o05i5o`1GB_l0EdX00_l0Cdh00ol0?TOo030o
o`0`?`02o`0R>0;o01L`1?l03RP4o`078B3o008I3Ol01b47o`0>:0Ko01L`1Ol08SP4o`0`?`Co03i7
1Ol0Cdh5o`1GBP[o05i51?l0ISd:o`1NA@Oo05M:2Ol0Cdh;o`0nA`Gooooo0Ol00001ooooo`008Ooo
ool00ol0003oooooooooo`02ooooobKo030o0ol0?TL2o`1?CP?o05M:0_l0GTD3o`1V?@05o`1^<ol0
MBOo07DWo`1e9ol0OAX00_l0Q@X3o`N<00Co6Y@02_l`W002oaZD00?o1h`00_l0Q@X2o`1m6P03o`1e
9ol0KS?o06hc00;o06Hm00?o05i5o`1GB_l0EdX00_l0Cdh3o`0nA`03o`0`?ol08SSo028h00?o01L`
1?l03RP4o`078Aoo008I3_l01b48o`0>:0Oo01L`1Ol08SP3o`0`?`Go03i71Ol0Cdh5o`1GBQKo05i5
1ol0EdX9o`1?CP_o03i71Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo9?l0
<3l4o`0nA`;o04m>0ol0EdX2o`1NA@?o06Hm00?o06hco`1e9ol0MBL00ol0OAX2o`252P?o1h`01OlJ
U002oc2L00Oo6Y@00_l7S003o`252P;o07dJ0ol0KS<2o`1V?@;o05i500?o05M:o`1?C_l0Cdh00ol0
?TL2o`0`?`;o028h0ol05c05o`0>:0Go00LQ7_l00QT?o`078@So00hX1ol05c05o`0R>0Go030o1Ol0
?TL5o`1?CPOo05M:4Ol0GTD8o`1GBPSo04m>2ol0?TL5ooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool00_oooolSo`0`?`?o03i70ol0Cdh2o`1GBP?o05i500Co06Hmo`1^<ol0KS?o06hc0_l0
MBL3o`1m6P;o08D:1?l7S009oaZD00;o1h`01Ol0Q@X2o`1m6P03o`1e9ol0KS?o06hc00;o06Hm0ol0
GTD2o`1GBP03o`1?C_l0?TOo03i700?o030o0_l08SP4o`0G<0Co00hX1_l01b4Ro`026@oo00LQ1ol0
3RP8o`0G<0Co028h1Ol0<3l5o`0nA`Go04m>2?l0EdX>o`1NA@So05M:2?l0Cdh;o`0nA`Gooooo0Ol0
0001ooooo`008Oooool00ol0003oooooooooo`02ooooob;o030o1?l0?TL2o`1?CP;o05M:0ol0GTD0
1?l0ISgo06hco`1^<ol0KS<2o`1e9`?o07dJ0_l0Q@X8o`N<0003oaZD0?l7S03o1h`000?o1h`01Ol0
Q@X3o`1e9`;o06hc0_l0ISd3o`1NA@;o05M:00?o04m>o`0nAol0?TL00_l0<3l3o`0R>0Go01L`1?l0
3RP5o`078BKo008I3ol01b48o`0>:0Ko01L`1_l08SP4o`0`?`Go03i71_l0Cdh7o`1GBPco05i52Ol0
EdX8o`1?CP[o03i71Oooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00000_ooool5o`0000Cooooo00?o0000ooooooooool00_oooolQo`0`?`?o03i70ol0Cdh2
o`1GBP?o05i50_l0ISd2o`1^<`;o07DW0ol0OAX3o`252Pgo1h`00ol0Q@X2o`1m6P?o07DW00Co06hc
o`1V?Ol0ISgo06Hm0_l0GTD2o`1GBP;o04m>00Co03i7o`0`?ol0<3oo030o0ol08SP3o`0G<0Go00hX
1_l01b4Zo`026@ko00LQ1ol03RP6o`0G<0Go028h1Ol0<3l5o`0nA`Go04m>2Ol0EdX9o`1NA@[o05M:
2?l0Cdh:o`0nA`Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooo
oa;o030o1?l08SP9o`0`?`Co03i70ol0Cdh2o`1GBP;o05i50_l0ISd2o`1^<`?o07DW0_l0OAX4o`25
2Pco1h`00ol0Q@X2o`1m6P?o07DW0_l0KS<00ol0ISgo05i5o`1NA@02o`1GBP?o04m>0_l0?TL2o`0`
?`?o028h0ol05c03o`0>:0Go00LQ=?l00QT<o`078@Oo00hX1Ol05c05o`0R>0Go030o1Ol0?TL5o`1?
CPco05M:0_l0GTD<o`1GBPWo04m>2Ol0?TL5ooooo`7o00000Oooool000Oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool@o`0`?`Oo028h1ol0<3l4o`0nA`;o04m>0ol0EdX2o`1NA@;o06Hm0_l0KS<3
o`1e9`;o07dJ1?l0Q@X;o`N<00?o08D:0ol0OAX2o`1e9`;o06hc0_l0ISd2o`1NA@;o05M:0_l0Cdh2
o`0nA`;o030o0ol08SP2o`0G<0Go00hX1Ol01b4go`026@_o00LQ1ol03RP5o`0G<0Go028h1Ol0<3l5
o`0nA`Ko04m>6Ol0EdX8o`1?CPWo03i71Oooool1o`00007ooooo0007ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`;o00000ooo
ool=o`0`?`[o028h1_l0<3l4o`0nA`;o04m>0ol0EdX2o`1NA@;o06Hm0_l0KS<3o`1e9`;o07dJ1?l0
Q@X:o`N<00Co08D:0ol0OAX2o`1e9`03o`1^<ol0ISgo06Hm00?o05i500Go05M:o`1?C_l0Cdko04m>
o`0nA`03o`0`?`;o028h0ol05c03o`0>:0Ko00LQ>Ol00QT;o`078@Oo00hX1_l05c06o`0R>0Go030o
1Ol0?TL6o`1?CQOo05M:2?l0Cdh9o`0nA`Cooooo0_l00001ooooo`001oooool01?l0003ooooooooo
ool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo3?l0<3l:o`0R>0Ko030o1?l0?TL2o`1?CP?o05M:0_l0GTD2o`1V
?@?o06hc0_l0MBL3o`1m6PCo08D:2Ol7S004o`252P;o07dJ0ol0MBL2o`1^<`05o`1V?Ol0GTGo05i5
o`1NAOl0EdX00ol0Cdh2o`0nA`;o030o0ol08SP3o`0G<0;o00hX1_l01b4ko`026@_o00LQ1ol03RP6
o`0G<0Go028h1Ol0<3l5o`0nA`Oo04m>5_l0EdX9o`1?CPSo03i71Oooool1o`00007ooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool;o`0`?`[o028h1_l0<3l4o`0nA`?o04m>
0_l0EdX3o`1NA@;o06Hm0_l0KS<3o`1e9`?o07dJ0ol0Q@X8o`N<00Go08D:0_l0OAX3o`1e9`;o06hc
00Co06Hmo`1NAOl0GTGo05i50_l0EdX2o`1?CP;o03i70_l0<3l3o`0R>0?o01L`0ol03RP5o`078Cgo
008I2ol01b47o`0>:0Ko01L`1Ol08SP5o`0`?`Go03i71ol0CdhEo`1GBPWo04m>2?l0?TL5ooooo`7o
00000Oooool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0
0_ooool8o`0`?`_o028h1ol0<3l3o`0nA`Co04m>0_l0EdX3o`1NA@;o06Hm0_l0KS<3o`1e9`?o07dJ
2?l0Q@X2o`N<00Go08D:0_l0OAX3o`1e9`;o06hc0_l0ISd2o`1NA@?o05M:00Co04m>o`0nAol0?TOo
03i70_l0<3l3o`0R>0;o01L`1?l03RP5o`078Cko008I2ol01b48o`0>:0Ko01L`1Ol08SP5o`0`?`Oo
03i72?l0CdhAo`1GBPWo04m>2?l0?TL5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0
0_ooool6o`0`?`co028h1ol0<3l3o`0nA`?o04m>0ol0EdX2o`1NA@?o06Hm0_l0KS<3o`1e9`Co07dJ
3?l0Q@X3o`1m6P?o07DW0_l0KS<3o`1V?@;o05i50_l0EdX2o`1?CP?o03i70_l0<3l3o`0R>0?o01L`
1?l03RP5o`078Cko008I3?l01b48o`0>:0Ko01L`1_l08SP5o`0`?`Ko03i72Ol0Cdh?o`1GBP[o04m>
1ol0?TL5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool3o`0`?`ko028h1_l0
<3l4o`0nA`?o04m>0ol0EdX2o`1NA@?o06Hm0_l0KS<3o`1e9`Go07dJ2Ol0Q@X4o`1m6PCo07DW0_l0
KS<3o`1V?@;o05i50_l0EdX01?l0Cdko03i7o`0nAol0?TL2o`0`?`Co028h0ol05c04o`0>:0Ko00LQ
?_l00QT=o`078@Oo00hX2?l05c05o`0R>0Ko030o1_l0?TL:o`1?CP_o05M:2ol0Cdh7o`0nA`Gooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`0`?ol08SSo028h00go028h1ol0
<3l3o`0nA`?o04m>0ol0EdX2o`1NA@?o06Hm0ol0KS<3o`1e9`Ko07dJ1?l0Q@X7o`1m6P?o07DW0_l0
KS<3o`1V?@;o05i50_l0EdX2o`1?CP?o03i70_l0<3l3o`0R>0Co01L`1Ol03RP6o`078Coo008I3?l0
1b49o`0>:0Ko01L`1ol08SP5o`0`?`So03i72Ol0Cdh9o`1GBP_o04m>1ol0?TL5ooooo`7o00000Ooo
ool0027ooooo00?o0000ooooooooool00_ooool?o`0R>0Ko030o1?l0?TL3o`1?CP?o05M:0ol0GTD3
o`1V?@;o06hc0ol0MBL>o`1m6PGo07DW0ol0KS<2o`1V?@?o05i50_l0EdX2o`1?CP?o03i70_l0<3l3
o`0R>0Co01L`1Ol03RP6o`078D3o008I3Ol01b49o`0>:0Ko01L`1_l08SP6o`0`?`Oo03i77Ol0Cdh7
o`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`ko028h1_l0<3l4o`0n
A`;o04m>0ol0EdX4o`1NA@;o06Hm1?l0KS<3o`1e9`_o07dJ1Ol0MBL3o`1^<`;o06Hm0ol0GTD2o`1G
BP?o04m>0_l0?TL4o`0`?`?o028h0ol05c04o`0>:0So00LQ@ol00QT>o`078@So00hX1ol05c06o`0R
>0Ko030o1_l0?TLKo`1?CPOo03i71Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;o
oooo3Ol08SP6o`0`?`Co03i70_l0Cdh3o`1GBP?o05i50ol0ISd4o`1^<`?o07DW2ol0OAX4o`1e9`Co
06hc0_l0ISd3o`1NA@;o05M:0ol0Cdh2o`0nA`?o030o0ol08SP4o`0G<0Co00hX1_l01b59o`026@co
00LQ2Ol03RP6o`0G<0Ko028h1_l0<3l7o`0nAa[o04m>1_l0?TL5ooooo`7o00000Oooool0027ooooo
00?o0000ooooooooool00_ooool;o`0R>0Oo030o0ol0?TL3o`1?CP?o05M:0ol0GTD3o`1V?@?o06hc
1Ol0MBL9o`1m6PGo07DW0_l0KS<3o`1V?@;o05i50ol0EdX2o`1?CPCo03i70_l0<3l2o`0R>0Co01L`
1Ol03RP6o`078Dgo008I3?l01b48o`0>:0Oo01L`1Ol08SP8o`0`?`Oo03i75ol0Cdh6o`0nA`Gooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`[o028h1_l0<3l4o`0nA`?o04m>0ol0
EdX3o`1NA@?o06Hm0ol0KS<6o`1e9`Oo07dJ1Ol0MBL2o`1^<`?o06Hm0ol0GTD2o`1GBP?o04m>1?l0
?TL2o`0`?`;o028h0ol05c05o`0>:0Ko00LQDOl00QT<o`078@So00hX1_l05c07o`0R>0Ko030o2?l0
?TLFo`1?CPGo03i71Oooool1o`00007ooooo000Qooooo`;o00000oooool9o`0R>0Ko030o1?l0?TL3
o`1?CP?o05M:0ol0GTD3o`1V?@?o06hc4Ol0MBL3o`1^<`?o06Hm0ol0GTD2o`1GBP?o04m>0_l0?TL3
o`0`?`?o028h0ol05c05o`0>:0Ko00LQDol00QT;o`078@So00hX2?l05c06o`0R>0Ko030o1ol0?TLF
o`1?CPGo03i71?ooool2o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo2Ol08SP5o`0`
?`Co03i70ol0Cdh3o`1GBPCo05i50ol0ISd3o`1^<a3o07DW0ol0KS<3o`1V?@;o05i50ol0EdX3o`1?
CP;o03i71?l0<3l2o`0R>0Co01L`1?l03RP6o`078ECo008I3?l01b48o`0>:0Oo01L`1ol08SP6o`0`
?`Wo03i74ol0Cdh5o`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`So
028h1Ol0<3l4o`0nA`?o04m>0ol0EdX3o`1NA@Co06Hm1?l0KS<>o`1e9`?o06hc1?l0ISd2o`1NA@?o
05M:0ol0Cdh2o`0nA`?o030o0ol08SP4o`0G<0Co00hX1ol01b5Eo`026@co00LQ2?l03RP7o`0G<0Oo
028h1_l0<3l:o`0nAa7o04m>1Ol0?TL5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0
0_ooool6o`0R>0Ko030o1?l0?TL3o`1?CP?o05M:0ol0GTD4o`1V?@Co06hc3?l0MBL5o`1^<`?o06Hm
0ol0GTD2o`1GBP?o04m>0ol0?TL3o`0`?`?o028h0ol05c05o`0>:0Oo00LQE_l00QT=o`078@Wo00hX
1_l05c08o`0R>0Ko030o2ol0?TL>o`1?CPGo03i71Oooool1o`00007ooooo000Qooooo`03o`000?oo
oooooooo00;ooooo1Ol08SP6o`0`?`Co03i70ol0Cdh3o`1GBP?o05i51?l0ISd5o`1^<`[o07DW1Ol0
KS<3o`1V?@Co05i50_l0EdX3o`1?CP?o03i70_l0<3l5o`0R>0;o01L`1Ol03RP7o`078ESo008I3Ol0
1b49o`0>:0Oo01L`1ol08SP6o`0`?`co03i73?l0Cdh5o`0nA`Gooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`02ooooo`Co028h1Ol0<3l4o`0nA`Co04m>0ol0EdX3o`1NA@Co06Hm1ol0KS<6
o`1e9`Go06hc1Ol0ISd2o`1NA@Co05M:0_l0Cdh3o`0nA`?o030o1?l08SP3o`0G<0Go00hX1ol01b5I
o`026@ko00LQ2?l03RP8o`0G<0Oo028h1ol0<3l=o`0nA`So04m>1_l0?TL5ooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool00_ooool3o`0R>0Ko030o1?l0?TL3o`1?CP?o05M:1?l0GTD4o`1V
?A3o06hc1Ol0ISd3o`1NA@Co05M:0_l0Cdh3o`0nA`?o030o1?l08SP4o`0G<0Co00hX2?l01b5Jo`02
6@ko00LQ2Ol03RP7o`0G<0Oo028h2?l0<3l=o`0nA`Co04m>2?l0?TL5ooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool00_ooool2o`0R>0Ko030o1?l0?TL3o`1?CPCo05M:0ol0GTD5o`1V?@oo
06hc1?l0ISd4o`1NA@?o05M:0ol0Cdh3o`0nA`?o030o0ol08SP5o`0G<0Co00hX2?l01b5Lo`026@ko
00LQ2Ol03RP7o`0G<0Oo028h2?l0<3lHo`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0003ooooo
ooooo`02ooooo`03o`0R>?l0<3oo030o00?o030o1?l0?TL4o`1?CPCo05M:0ol0GTD5o`1V?@ko06hc
1Ol0ISd3o`1NA@?o05M:1?l0Cdh2o`0nA`?o030o0ol08SP4o`0G<0Go00hX2?l01b5Po`026@go00LQ
2_l03RP8o`0G<0Ko028h2?l0<3lFo`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`02ooooo`03o`0R>?l0<3oo030o00;o030o1?l0?TL4o`1?CP?o05M:1?l0GTD5o`1V?@go06hc1Ol0
ISd3o`1NA@Co05M:0ol0Cdh2o`0nA`?o030o1?l08SP4o`0G<0Go00hX2?l01b5Ro`026@ko00LQ2Ol0
3RP8o`0G<0Ko028h2Ol0<3lDo`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02
ooooo`Co030o1?l0?TL4o`1?CP?o05M:1?l0GTD5o`1V?@_o06hc1_l0ISd4o`1NA@;o05M:1?l0Cdh3
o`0nA`?o030o1?l08SP4o`0G<0Go00hX1ol01b5Vo`026@go00LQ2_l03RP7o`0G<0Oo028h2?l0<3lC
o`0nA`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`?o030o1?l0?TL4o`1?
CP?o05M:1Ol0GTD5o`1V?@Wo06hc1ol0ISd3o`1NA@?o05M:1?l0Cdh3o`0nA`?o030o1?l08SP4o`0G
<0Go00hX1ol01b5Xo`026@go00LQ2Ol03RP8o`0G<0So028h2?l0<3lAo`0nA`Gooooo0Ol00001oooo
o`008Oooool2o`0000?ooooo0_l0<3l5o`0nA`?o04m>1?l0EdX4o`1NA@Ko06Hm1ol0KS<7o`1V?@?o
05i51?l0EdX4o`1?CP;o03i71?l0<3l4o`0R>0Co01L`1Ol03RP7o`078F[o008I3Ol01b49o`0>:0So
01L`2?l08SP9o`0`?`oo03i71?ooool2o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo
00?o030oo`0nAol0?TL00_l0?TL4o`1?CPCo05M:1?l0GTD:o`1V?@03o`1^<ol0ISgo06Hm00Ko06Hm
1?l0GTD3o`1GBPCo04m>0ol0?TL3o`0`?`Co028h1?l05c05o`0>:0Oo00LQKOl00QT>o`078@Wo00hX
2?l05c07o`0R>0[o030o3Ol0?TL5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_oo
ool01?l0<3oo03i7o`0nAol0?TL4o`1?CPCo05M:1Ol0GTDAo`1V?@Co05i51?l0EdX3o`1?CPCo03i7
0ol0<3l4o`0R>0Co01L`1Ol03RP7o`078G3o008I3Ol01b49o`0>:0So01L`1ol08SP:o`0`?`co03i7
1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo0ol0?TL4o`1?CPCo05M:1Ol0
GTDAo`1V?@Co05i51?l0EdX3o`1?CP?o03i71?l0<3l4o`0R>0?o01L`1_l03RP7o`078G7o008I3_l0
1b49o`0>:0So01L`2?l08SP;o`0`?`Wo03i71Oooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo0_l0?TL5o`1?CP?o05M:1_l0GTD?o`1V?@Go05i51?l0EdX3o`1?CP?o03i71?l0<3l4
o`0R>0?o01L`1_l03RP8o`078G;o008I3_l01b49o`0>:0So01L`2?l08SP<o`0`?`Oo03i71Oooool1
o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo0_l0?TL4o`1?CP?o05M:1_l0GTD>o`1V
?@Go05i51?l0EdX3o`1?CPCo03i71?l0<3l4o`0R>0?o01L`1_l03RP8o`078GCo008I3Ol01b4:o`0>
:0So01L`2?l08SP<o`0`?`Ko03i71Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;o
oooo00Co03i7o`1?C_l0Cdko04m>1Ol0EdX5o`1NA@co06Hm1ol0GTD3o`1GBPCo04m>0ol0?TL4o`0`
?`Co028h1?l05c06o`0>:0So00LQM_l00QT>o`078@Wo00hX2Ol05c09o`0R>0_o030o1?l0?TL5oooo
o`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool3o`1?CPGo05M:1_l0GTD9o`1V?@So
05i51?l0EdX3o`1?CPCo03i71?l0<3l4o`0R>0Co01L`1_l03RP8o`078GSo008I3_l01b49o`0>:0Wo
01L`2Ol08SP<o`0`?`;o03i71Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo
0_l0Cdh5o`1GBPOo05i51ol0ISd8o`1NA@Co05M:1?l0Cdh4o`0nA`Co030o0ol08SP4o`0G<0Ko00hX
2Ol01b5jo`026@ko00LQ2_l03RP8o`0G<0Wo028h3Ol0<3l5ooooo`7o00000Oooool0027ooooo00?o
0000ooooooooool00_ooool2o`1?CPGo05M:2_l0GTD00ol0ISgo05i5o`1NA@08o`1NA@Co05M:1?l0
Cdh4o`0nA`?o030o1?l08SP4o`0G<0Ko00hX2Ol01b5lo`026@ko00LQ2_l03RP9o`0G<0So028h3?l0
<3l5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool00ol0Cdko05M:o`1GBP03
o`1GBQCo05i51Ol0EdX3o`1?CPCo03i70ol0<3l5o`0R>0Go01L`1Ol03RP9o`078Gko008I3_l01b4:
o`0>:0Wo01L`2Ol08SP:o`0`?`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02oooo
o`Co05M:4ol0GTD6o`1GBPCo04m>0ol0?TL4o`0`?`Go028h1?l05c06o`0>:0So00LQP_l00QT>o`07
8@Wo00hX2Ol05c0:o`0R>0So030o1Oooool1o`00007ooooo000Qooooo`;o00000oooool4o`1GBQ;o
05i51_l0EdX3o`1?CPCo03i71?l0<3l4o`0R>0Go01L`1Ol03RP9o`078HCo008I3_l01b4:o`0>:0So
01L`2_l08SP7o`0`?`Cooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`Co05M:
4?l0GTD5o`1GBPGo04m>1?l0?TL4o`0`?`Co028h1?l05c06o`0>:0Wo00LQQOl00QT?o`078@[o00hX
2_l05c0:o`0R>0Co030o1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo1?l0
EdX>o`1NA@Ko05M:1Ol0Cdh4o`0nA`Co030o1?l08SP4o`0G<0Ko00hX2Ol01b67o`026@oo00LQ2_l0
3RP9o`0G<0[o028h1?l0<3l5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool3
o`1GBPko05i51_l0EdX5o`1?CPCo03i71?l0<3l4o`0R>0Co01L`1ol03RP8o`078HWo008I3ol01b4:
o`0>:0Wo01L`2_l08SP3o`0`?`Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02oooo
o`;o05M:3?l0GTD7o`1GBPGo04m>1?l0?TL4o`0`?`Go028h1?l05c06o`0>:0So00LQSOl00QT?o`07
8@[o00hX2Ol05c0:o`0R>003o`0`?ooooooooooo00?ooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`02ooooo`;o05M:2ol0GTD6o`1GBPGo04m>1?l0?TL5o`0`?`Go028h0ol05c07o`0>:0So
00LQSol00QT?o`078@[o00hX2Ol05c0:o`0R>0Gooooo0Ol00001ooooo`008Oooool00ol0003ooooo
ooooo`02ooooo`;o05M:2?l0GTD8o`1GBPGo04m>1?l0?TL4o`0`?`Go028h1Ol05c05o`0>:0[o00LQ
T?l00QT?o`078@[o00hX2_l05c08o`0R>0Gooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`02ooooo`Co05M:0_l0GTD:o`1GBPGo04m>1Ol0?TL4o`0`?`Go028h1Ol05c05o`0>:0[o00LQT_l0
0QT?o`078@[o00hX2_l05c07o`0R>0Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02
ooooo`ko05M:1_l0Cdh4o`0nA`Co030o1Ol08SP5o`0G<0Ko00hX2Ol01b6Eo`026@oo00LQ2ol03RP:
o`0G<0Go028h1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo3Ol0EdX5o`1?
CPGo03i71Ol0<3l4o`0R>0Ko01L`1Ol03RP9o`078IOo008I3ol01b4;o`0>:0[o01L`1?l08SP5oooo
o`7o00000Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`?o
00001?ooool00ol0003oooooooooo`02ooooo`_o05M:1_l0Cdh5o`0nA`Co030o1Ol08SP5o`0G<0Ko
00hX2Ol01b6Io`026@oo00LQ2ol03RP:o`0G<0?o028h1Oooool1o`00007ooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo2Ol0EdX6o`1?CPGo03i71Ol0<3l4o`0R>0Ko01L`1_l03RP9o`07
8Ico008I3_l01b4;o`0>:0[o01L`0_l08SP5ooooo`7o00000Oooool000Oooooo00Co0000oooooooo
oooo00002?ooool01Ol0003oooooooooool0003ooooo00Go00001?ooool00ol0003oooooooooo`02
ooooo`So05M:1Ol0Cdh5o`0nA`Go030o1Ol08SP5o`0G<0Oo00hX2?l01b6Oo`026@ko00LQ3?l03RP:
o`0G<0Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool00ol0003oooooooooo`03ooooo`;o00000oooool5o`1GBPOo04m>
1Ol0?TL4o`0`?`Go028h1_l05c06o`0>:0Wo00LQXOl00QT?o`078@_o00hX2Ol05c04ooooo`;o0000
0Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool00_ooool3o`1GBPSo04m>1Ol0?TL4o`0`?`Go
028h1_l05c07o`0>:0So00LQXol00QT?o`078@_o00hX2?l05c05ooooo`7o00000Oooool000Oooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`;o00001Oooool00ol0
003oooooooooo`02ooooo`;o05M:1ol0Cdh5o`0nA`Go030o1Ol08SP6o`0G<0Ko00hX2_l01b6So`02
6A3o00LQ2ol03RP7o`0G<0Gooooo0Ol00001ooooo`002?ooool2o`0000[ooooo0_l00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0Ed[o04m>o`1?CP05o`1?CPGo
03i71Ol0<3l5o`0R>0Ko01L`1_l03RP:o`078JGo008I4?l01b4<o`0>:0Go01L`1Oooool1o`00007o
oooo000Qooooo`03o`000?oooooooooo00;ooooo1_l0Cdh5o`0nA`Go030o1Ol08SP7o`0G<0Go00hX
2_l01b6Xo`026A7o00LQ2ol03RP4o`0G<0Gooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`02ooooo`Go04m>1Ol0?TL5o`0`?`Go028h1_l05c06o`0>:0[o00LQZol00QT@o`078@_o00hX0ol0
5c05ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool3o`1?CPKo03i71Ol0<3l5
o`0R>0Ko01L`1ol03RP9o`078Jgo008I4?l01b4;o`0>:0;o01L`1Oooool1o`00007ooooo000Qoooo
o`03o`000?oooooooooo00;ooooo0_l0Cdh6o`0nA`Go030o1Ol08SP6o`0G<0Oo00hX2Ol01b6_o`02
6A3o00LQ2ol03RP00ol05c3oooooooooo`03ooooo`7o00000Oooool0027ooooo00?o0000oooooooo
ool00_ooool00ol0Cdko03i7o`0nA`03o`0nA`Go030o1Ol08SP7o`0G<0Ko00hX2_l01b6ao`026A3o
00LQ2ol03RP5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool5o`0nA`Go030o
1Ol08SP6o`0G<0Oo00hX2_l01b6co`026A3o00LQ2_l03RP5ooooo`7o00000Oooool0027ooooo00?o
0000ooooooooool00_ooool3o`0nA`Ko030o1Ol08SP6o`0G<0Ko00hX2ol01b6eo`026A3o00LQ2Ol0
3RP5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool2o`0nA`Ko030o1Ol08SP6
o`0G<0Ko00hX2ol01b6go`026A3o00LQ2?l03RP5ooooo`7o00000Oooool0027ooooo0_l00003oooo
o`03o`0nAol0<3oo030o00Co030o1Ol08SP6o`0G<0Ko00hX2ol01b6io`026A3o00LQ1ol03RP4oooo
o`;o00000Oooool0027ooooo00?o0000ooooooooool00_ooool5o`0`?`Go028h1_l05c08o`0>:0[o
00LQ^ol00QTAo`078@Go00hX1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo
0ol0<3l6o`0R>0Ko01L`2?l03RP:o`078Kko008I4?l01b44o`0>:0Gooooo0Ol00001ooooo`008Ooo
ool00ol0003oooooooooo`02ooooo`;o030o1_l08SP6o`0G<0Oo00hX2_l01b71o`026A3o00LQ0ol0
3RP5ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool00ol0<3oo028ho`0R>004
o`0R>0Ko01L`1ol03RP:o`078L;o008I4Ol01b42o`0>:0Gooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`02ooooo`Ko028h1_l05c07o`0>:0[o00LQa?l00QTAo`078@03o`0>:?oooooooooo
00?ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`Co028h1_l05c08o`0>:0_o
00LQaOl00QTAo`078@Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`02ooooo`?o028h
1_l05c07o`0>:0co00LQb?l00QT?o`078@Gooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`02ooooo`;o028h1_l05c07o`0>:0_o00LQbol00QT>o`078@Gooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`02ooooo`03o`0R>?l05c3o01L`00Co01L`1ol03RP;o`078Lco008I3_l01b45
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00_ooool6o`0G<0Oo00hX2ol01b7>o`02
6@go00LQ1Oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo00;ooooo1?l05c08o`0>:0_o
00LQdOl00QT;o`078@Gooooo0Ol00001ooooo`008Oooool2o`0000?ooooo0ol05c08o`0>:0_o00LQ
dol00QT:o`078@Cooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`3jooooo`7o00000Ooo
ool0027ooooo00?o0000ooooooooool0n_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`02ooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_ooool1o`00007ooooo000Qooooooko00000Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.31197, -0.0613198, \
0.00819863, 0.000409931}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell["Here is the same plot with all intensity values included.", "Text",
  CellLabel->"In[243]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{

Cell["\<\
ContourPlot[intensity[x,y], {x,-1, 1}, {y,-.05,.05}, PlotPoints->200, \
PlotRange->All, Contours->30, ContourLines->False, \
ColorFunction->Function[Hue[.65-#*(.65),1,#*.9+.1]]];\
\>", "Input",
  CellLabel->"In[85]:=",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 9.61538 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.25962 -0.0125 -12 -9 ]
[.25962 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -9 -9 ]
[.74038 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11538 -30 -4.5 ]
[-0.0125 .11538 0 4.5 ]
[-0.0125 .30769 -30 -4.5 ]
[-0.0125 .30769 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .69231 -24 -4.5 ]
[-0.0125 .69231 0 4.5 ]
[-0.0125 .88462 -24 -4.5 ]
[-0.0125 .88462 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-0.5)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(0.5)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11538 m
.00625 .11538 L
s
[(-0.04)] -0.0125 .11538 1 0 Mshowa
0 .30769 m
.00625 .30769 L
s
[(-0.02)] -0.0125 .30769 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .69231 m
.00625 .69231 L
s
[(0.02)] -0.0125 .69231 1 0 Mshowa
0 .88462 m
.00625 .88462 L
s
[(0.04)] -0.0125 .88462 1 0 Mshowa
.125 Mabswid
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .25962 m
.00375 .25962 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .74038 m
.00375 .74038 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .06731 m
.00375 .06731 L
s
0 .01923 m
.00375 .01923 L
s
0 .93269 m
.00375 .93269 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .06731 m
1 .06731 L
s
.99625 .01923 m
1 .01923 L
s
.99625 .93269 m
1 .93269 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 .03 .13 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 .058 .16 r
.01923 .05263 m
.0198 .05305 L
.02406 .05623 L
.02628 .05789 L
.02889 .05984 L
.03275 .06272 L
.03373 .06345 L
.03856 .06707 L
.0392 .06755 L
.04339 .07069 L
.04565 .07238 L
.04822 .07431 L
.0521 .07721 L
.05305 .07792 L
.05789 .08154 L
.05856 .08204 L
.06272 .08515 L
.06503 .08688 L
.06755 .08876 L
.07149 .09171 L
.07238 .09238 L
.07721 .096 L
.07793 .09654 L
.08204 .09963 L
.08435 .10137 L
.08688 .10328 L
.09075 .1062 L
.09171 .10693 L
.09654 .1106 L
.09711 .11104 L
.10137 .11427 L
.10347 .11587 L
.1062 .11795 L
.10984 .1207 L
.11104 .12161 L
.11587 .12526 L
.11623 .12553 L
.1207 .12889 L
.12267 .13036 L
.12553 .1325 L
.12914 .1352 L
.13036 .13611 L
.1352 .13971 L
.13562 .14003 L
.14003 .14333 L
.14206 .14486 L
.14486 .14697 L
.14844 .14969 L
.14969 .15065 L
.15452 .15436 L
.15474 .15452 L
.15935 .1581 L
.16098 .15935 L
.16419 .16184 L
.16721 .16419 L
.16902 .16558 L
.17351 .16902 L
.17385 .16928 L
.17868 .17292 L
.17992 .17385 L
.18351 .17651 L
.18647 .17868 L
.18835 .18005 L
.19311 .18351 L
.19318 .18357 L
.19801 .18708 L
.19974 .18835 L
.20284 .19063 L
.20626 .19318 L
.20767 .19424 L
.2125 .19796 L
.21257 .19801 L
.21734 .20177 L
.21867 .20284 L
.22217 .20567 L
.22464 .20767 L
.227 .20958 L
.23064 .2125 L
.23183 .21344 L
.23666 .21718 L
.23687 .21734 L
.2415 .22076 L
.24345 .22217 L
.24633 .2242 L
.2504 .227 L
.25116 .22752 L
.25599 .23078 L
.25755 .23183 L
.26082 .23405 L
.26461 .23666 L
.26566 .2374 L
.27049 .24092 L
.27125 .2415 L
.27532 .2447 L
.2773 .24633 L
.28015 .24877 L
.28284 .25116 L
.28498 .25309 L
.28818 .25599 L
.28981 .25745 L
.29375 .26082 L
.29465 .26156 L
.29948 .26528 L
.29999 .26566 L
.30431 .26864 L
.30719 .27049 L
.30914 .2717 L
.31397 .27458 L
.31525 .27532 L
.31881 .27738 L
.32359 .28015 L
.32364 .28018 L
.32847 .28311 L
.33137 .28498 L
.3333 .28631 L
.33789 .28981 L
.33813 .29002 L
.34296 .29457 L
.34304 .29465 L
.34729 .29948 L
.3478 .30007 L
.35145 .30431 L
.35263 .30557 L
.35644 .30914 L
.35746 .31 L
.36229 .31345 L
.36316 .31397 L
.36712 .31629 L
.37196 .31873 L
.37212 .31881 L
.37679 .32099 L
.38162 .32312 L
.38282 .32364 L
.38645 .32524 L
.39128 .32746 L
.39337 .32847 L
.39612 .32989 L
.40095 .3328 L
.40166 .3333 L
.40578 .33678 L
.40697 .33813 L
.40995 .34296 L
.41061 .34451 L
.41191 .3478 L
.41433 .35263 L
.41544 .35429 L
.41887 .35746 L
.42027 .35858 L
.42511 .36138 L
.4274 .36229 L
.42994 .36338 L
.43477 .36515 L
.4396 .36664 L
.44131 .36712 L
.44443 .36805 L
.44927 .36942 L
.4541 .37078 L
.45817 .37196 L
.45893 .37218 L
.46376 .37372 L
.46859 .37553 L
.47134 .37679 L
.47342 .37763 L
.47806 .38162 L
.47826 .38188 L
.47978 .38645 L
.47882 .39128 L
.47826 .3929 L
.47729 .39612 L
.47721 .40095 L
.47826 .40307 L
.48118 .40578 L
.48309 .40722 L
.48792 .40937 L
.49275 .41034 L
.49501 .41061 L
.49758 .41116 L
.50242 .41202 L
.50725 .41272 L
.51208 .41331 L
.51691 .41383 L
.52174 .41429 L
.52658 .41472 L
.53141 .41513 L
.53504 .41544 L
.53624 .41555 L
.54107 .41601 L
.5459 .41649 L
.55073 .41702 L
.55557 .41762 L
.5604 .4183 L
.56523 .41914 L
.57006 .42019 L
.5704 .42027 L
.57489 .42148 L
.57973 .42323 L
.5831 .42511 L
.58248 .42994 L
.57973 .43149 L
.57489 .43369 L
.57236 .43477 L
.57006 .43598 L
.56523 .43831 L
.56131 .4396 L
.5604 .44004 L
.55557 .44247 L
.55196 .44443 L
.55073 .44517 L
.5459 .44827 L
.54525 .44927 L
.54272 .4541 L
.5459 .45723 L
.55073 .45867 L
.55208 .45893 L
.55557 .45951 L
.5604 .45992 L
.56523 .46002 L
.57006 .45988 L
.57489 .45954 L
.57973 .45901 L
.58036 .45893 L
.58456 .45835 L
.58939 .45745 L
.59422 .45622 L
.59905 .45463 L
.59996 .4541 L
.60388 .45182 L
.60664 .44927 L
.60872 .44501 L
.60881 .44443 L
.60872 .4407 L
.60845 .4396 L
.60664 .43477 L
.60564 .42994 L
.60872 .42681 L
.61217 .42511 L
.61355 .42447 L
.61838 .42254 L
.62321 .42055 L
.62384 .42027 L
.62804 .41857 L
.63288 .41551 L
.63296 .41544 L
.63746 .41061 L
.63771 .41001 L
.63811 .40578 L
.63771 .40397 L
.63664 .40095 L
.63505 .39612 L
.63547 .39128 L
.63771 .3882 L
.63977 .38645 L
.64254 .38452 L
.64737 .3822 L
.64884 .38162 L
.6522 .38021 L
.65704 .37836 L
.66134 .37679 L
.66187 .3766 L
.6667 .37482 L
.67153 .37296 L
.67399 .37196 L
.67636 .37098 L
.68119 .36872 L
.6841 .36712 L
.68603 .36605 L
.69086 .36246 L
.69104 .36229 L
.69545 .35746 L
.69569 .35711 L
.69844 .35263 L
.70052 .34898 L
.70125 .3478 L
.70505 .34296 L
.70535 .34266 L
.71019 .33852 L
.71073 .33813 L
.71502 .3353 L
.71843 .3333 L
.71985 .33251 L
.72468 .32991 L
.72743 .32847 L
.72951 .32738 L
.73434 .32481 L
.73647 .32364 L
.73918 .32211 L
.74401 .31914 L
.74453 .31881 L
.74884 .31581 L
.75122 .31397 L
.75367 .31193 L
.75677 .30914 L
.7585 .30746 L
.76167 .30431 L
.76334 .30264 L
.76657 .29948 L
.76817 .298 L
.77202 .29465 L
.773 .29385 L
.77783 .29017 L
.77833 .28981 L
.78266 .28683 L
.78547 .28498 L
.7875 .28369 L
.79233 .28065 L
.79312 .28015 L
.79716 .27762 L
.80078 .27532 L
.80199 .27454 L
.80682 .27134 L
.80807 .27049 L
.81165 .26798 L
.81484 .26566 L
.81649 .26442 L
.82115 .26082 L
.82132 .26069 L
.82615 .25684 L
.82722 .25599 L
.83098 .25299 L
.8333 .25116 L
.83581 .24921 L
.83963 .24633 L
.84065 .24558 L
.84548 .24209 L
.84631 .2415 L
.85031 .23872 L
.85333 .23666 L
.85514 .23544 L
.85997 .23222 L
.86055 .23183 L
.8648 .22901 L
.86781 .227 L
.86964 .22578 L
.87447 .22251 L
.87498 .22217 L
.8793 .2192 L
.88198 .21734 L
.88413 .21583 L
.88885 .2125 L
.88896 .21242 L
.8938 .20899 L
.89566 .20767 L
.89863 .20557 L
.90251 .20284 L
.90346 .20218 L
.90829 .19883 L
.90948 .19801 L
.91312 .19553 L
.91662 .19318 L
.91796 .19229 L
.92279 .18909 L
.92393 .18835 L
.92762 .18594 L
.93135 .18351 L
.93245 .18281 L
.93728 .17969 L
.93886 .17868 L
.94211 .17659 L
.94639 .17385 L
.94695 .17349 L
.95178 .1704 L
.95394 .16902 L
.95661 .16732 L
.96144 .16424 L
.96153 .16419 L
.96627 .16119 L
.96919 .15935 L
.97111 .15815 L
.97594 .15515 L
.97696 .15452 L
.98077 .15219 L
.98077 .98077 L
.01923 .98077 L
F
0 .03 .13 r
.01923 .94737 m
.0198 .94695 L
.02406 .94377 L
.02628 .94211 L
.02889 .94016 L
.03275 .93728 L
.03373 .93655 L
.03856 .93293 L
.0392 .93245 L
.04339 .92931 L
.04565 .92762 L
.04822 .92569 L
.0521 .92279 L
.05305 .92208 L
.05789 .91846 L
.05856 .91796 L
.06272 .91485 L
.06503 .91312 L
.06755 .91124 L
.07149 .90829 L
.07238 .90762 L
.07721 .904 L
.07793 .90346 L
.08204 .90037 L
.08435 .89863 L
.08688 .89672 L
.09075 .8938 L
.09171 .89307 L
.09654 .8894 L
.09711 .88896 L
.10137 .88573 L
.10347 .88413 L
.1062 .88205 L
.10984 .8793 L
.11104 .87839 L
.11587 .87474 L
.11623 .87447 L
.1207 .87111 L
.12267 .86964 L
.12553 .8675 L
.12914 .8648 L
.13036 .86389 L
.1352 .86029 L
.13562 .85997 L
.14003 .85667 L
.14206 .85514 L
.14486 .85303 L
.14844 .85031 L
.14969 .84935 L
.15452 .84564 L
.15474 .84548 L
.15935 .8419 L
.16098 .84065 L
.16419 .83816 L
.16721 .83581 L
.16902 .83442 L
.17351 .83098 L
.17385 .83072 L
.17868 .82708 L
.17992 .82615 L
.18351 .82349 L
.18647 .82132 L
.18835 .81995 L
.19311 .81649 L
.19318 .81643 L
.19801 .81292 L
.19974 .81165 L
.20284 .80937 L
.20626 .80682 L
.20767 .80576 L
.2125 .80204 L
.21257 .80199 L
.21734 .79823 L
.21867 .79716 L
.22217 .79433 L
.22464 .79233 L
.227 .79042 L
.23064 .7875 L
.23183 .78656 L
.23666 .78282 L
.23687 .78266 L
.2415 .77924 L
.24345 .77783 L
.24633 .7758 L
.2504 .773 L
.25116 .77248 L
.25599 .76922 L
.25755 .76817 L
.26082 .76595 L
.26461 .76334 L
.26566 .7626 L
.27049 .75908 L
.27125 .7585 L
.27532 .7553 L
.2773 .75367 L
.28015 .75123 L
.28284 .74884 L
.28498 .74691 L
.28818 .74401 L
.28981 .74255 L
.29375 .73918 L
.29465 .73844 L
.29948 .73472 L
.29999 .73434 L
.30431 .73136 L
.30719 .72951 L
.30914 .7283 L
.31397 .72542 L
.31525 .72468 L
.31881 .72262 L
.32359 .71985 L
.32364 .71982 L
.32847 .71689 L
.33137 .71502 L
.3333 .71369 L
.33789 .71019 L
.33813 .70998 L
.34296 .70543 L
.34304 .70535 L
.34729 .70052 L
.3478 .69993 L
.35145 .69569 L
.35263 .69443 L
.35644 .69086 L
.35746 .69 L
.36229 .68655 L
.36316 .68603 L
.36712 .68371 L
.37196 .68127 L
.37212 .68119 L
.37679 .67901 L
.38162 .67688 L
.38282 .67636 L
.38645 .67476 L
.39128 .67254 L
.39337 .67153 L
.39612 .67011 L
.40095 .6672 L
.40166 .6667 L
.40578 .66322 L
.40697 .66187 L
.40995 .65704 L
.41061 .65549 L
.41191 .6522 L
.41433 .64737 L
.41544 .64571 L
.41887 .64254 L
.42027 .64142 L
.42511 .63862 L
.4274 .63771 L
.42994 .63662 L
.43477 .63485 L
.4396 .63336 L
.44131 .63288 L
.44443 .63195 L
.44927 .63058 L
.4541 .62922 L
.45817 .62804 L
.45893 .62782 L
.46376 .62628 L
.46859 .62447 L
.47134 .62321 L
.47342 .62237 L
.47806 .61838 L
.47826 .61812 L
.47978 .61355 L
.47882 .60872 L
.47826 .6071 L
.47729 .60388 L
.47721 .59905 L
.47826 .59693 L
.48118 .59422 L
.48309 .59278 L
.48792 .59063 L
.49275 .58966 L
.49501 .58939 L
.49758 .58884 L
.50242 .58798 L
.50725 .58728 L
.51208 .58669 L
.51691 .58617 L
.52174 .58571 L
.52658 .58528 L
.53141 .58487 L
.53504 .58456 L
.53624 .58445 L
.54107 .58399 L
.5459 .58351 L
.55073 .58298 L
.55557 .58238 L
.5604 .5817 L
.56523 .58086 L
.57006 .57981 L
.5704 .57973 L
.57489 .57852 L
.57973 .57677 L
.5831 .57489 L
.58248 .57006 L
.57973 .56851 L
.57489 .56631 L
.57236 .56523 L
.57006 .56402 L
.56523 .56169 L
.56131 .5604 L
.5604 .55996 L
.55557 .55753 L
.55196 .55557 L
.55073 .55483 L
.5459 .55173 L
.54525 .55073 L
.54272 .5459 L
.5459 .54277 L
.55073 .54133 L
.55208 .54107 L
.55557 .54049 L
.5604 .54008 L
.56523 .53998 L
.57006 .54012 L
.57489 .54046 L
.57973 .54099 L
.58036 .54107 L
.58456 .54165 L
.58939 .54255 L
.59422 .54378 L
.59905 .54537 L
.59996 .5459 L
.60388 .54818 L
.60664 .55073 L
.60872 .55499 L
.60881 .55557 L
.60872 .5593 L
.60845 .5604 L
.60664 .56523 L
.60564 .57006 L
.60872 .57319 L
.61217 .57489 L
.61355 .57553 L
.61838 .57746 L
.62321 .57945 L
.62384 .57973 L
.62804 .58143 L
.63288 .58449 L
.63296 .58456 L
.63746 .58939 L
.63771 .58999 L
.63811 .59422 L
.63771 .59603 L
.63664 .59905 L
.63505 .60388 L
.63547 .60872 L
.63771 .6118 L
.63977 .61355 L
.64254 .61548 L
.64737 .6178 L
.64884 .61838 L
.6522 .61979 L
.65704 .62164 L
.66134 .62321 L
.66187 .6234 L
.6667 .62518 L
.67153 .62704 L
.67399 .62804 L
.67636 .62902 L
.68119 .63128 L
.6841 .63288 L
.68603 .63395 L
.69086 .63754 L
.69104 .63771 L
.69545 .64254 L
.69569 .64289 L
.69844 .64737 L
.70052 .65102 L
.70125 .6522 L
.70505 .65704 L
.70535 .65734 L
.71019 .66148 L
.71073 .66187 L
.71502 .6647 L
.71843 .6667 L
.71985 .66749 L
.72468 .67009 L
.72743 .67153 L
.72951 .67262 L
.73434 .67519 L
.73647 .67636 L
.73918 .67789 L
.74401 .68086 L
.74453 .68119 L
.74884 .68419 L
.75122 .68603 L
.75367 .68807 L
.75677 .69086 L
.7585 .69254 L
.76167 .69569 L
.76334 .69736 L
.76657 .70052 L
.76817 .702 L
.77202 .70535 L
.773 .70615 L
.77783 .70983 L
.77833 .71019 L
.78266 .71317 L
.78547 .71502 L
.7875 .71631 L
.79233 .71935 L
.79312 .71985 L
.79716 .72238 L
.80078 .72468 L
.80199 .72546 L
.80682 .72866 L
.80807 .72951 L
.81165 .73202 L
.81484 .73434 L
.81649 .73558 L
.82115 .73918 L
.82132 .73931 L
.82615 .74316 L
.82722 .74401 L
.83098 .74701 L
.8333 .74884 L
.83581 .75079 L
.83963 .75367 L
.84065 .75442 L
.84548 .75791 L
.84631 .7585 L
.85031 .76128 L
.85333 .76334 L
.85514 .76456 L
.85997 .76778 L
.86055 .76817 L
.8648 .77099 L
.86781 .773 L
.86964 .77422 L
.87447 .77749 L
.87498 .77783 L
.8793 .7808 L
.88198 .78266 L
.88413 .78417 L
.88885 .7875 L
.88896 .78758 L
.8938 .79101 L
.89566 .79233 L
.89863 .79443 L
.90251 .79716 L
.90346 .79782 L
.90829 .80117 L
.90948 .80199 L
.91312 .80447 L
.91662 .80682 L
.91796 .80771 L
.92279 .81091 L
.92393 .81165 L
.92762 .81406 L
.93135 .81649 L
.93245 .81719 L
.93728 .82031 L
.93886 .82132 L
.94211 .82341 L
.94639 .82615 L
.94695 .82651 L
.95178 .8296 L
.95394 .83098 L
.95661 .83268 L
.96144 .83576 L
.96153 .83581 L
.96627 .83881 L
.96919 .84065 L
.97111 .84185 L
.97594 .84485 L
.97696 .84548 L
.98077 .84781 L
.98077 .98077 L
.01923 .98077 L
F
.01923 .28819 m
.02337 .28981 L
.02406 .29009 L
.02889 .29206 L
.03373 .29413 L
.03491 .29465 L
.03856 .29628 L
.04339 .29853 L
.04538 .29948 L
.04822 .30086 L
.05305 .30328 L
.05509 .30431 L
.05789 .30574 L
.06272 .30823 L
.06451 .30914 L
.06755 .31069 L
.07238 .31309 L
.07422 .31397 L
.07721 .31539 L
.08204 .31759 L
.08489 .31881 L
.08688 .31964 L
.09171 .3216 L
.09654 .3234 L
.09722 .32364 L
.10137 .32511 L
.1062 .32672 L
.11104 .32815 L
.11242 .32847 L
.11587 .32941 L
.1207 .33078 L
.12553 .33007 L
.12721 .32847 L
.12553 .32378 L
.12548 .32364 L
.12266 .31881 L
.1207 .31612 L
.11907 .31397 L
.11587 .30975 L
.11484 .30914 L
.11104 .30508 L
.11002 .30431 L
.1062 .30068 L
.10469 .29948 L
.10137 .29656 L
.099 .29465 L
.09654 .29256 L
.09316 .28981 L
.09171 .28858 L
.08741 .28498 L
.08688 .28452 L
.08204 .2803 L
.08187 .28015 L
.07721 .2759 L
.07657 .27532 L
.07238 .27138 L
.07143 .27049 L
.06755 .26677 L
.06636 .26566 L
.06272 .26217 L
.06128 .26082 L
.05789 .25762 L
.05612 .25599 L
.05305 .25315 L
.05086 .25116 L
.04822 .24876 L
.0455 .24633 L
.04339 .24443 L
.04009 .2415 L
.03856 .24012 L
.03468 .23666 L
.03373 .2358 L
.02931 .23183 L
.02889 .23145 L
.02406 .22705 L
.02401 .227 L
.01923 .22258 L
F
.01923 .77742 m
.02401 .773 L
.02406 .77295 L
.02889 .76855 L
.02931 .76817 L
.03373 .7642 L
.03468 .76334 L
.03856 .75988 L
.04009 .7585 L
.04339 .75557 L
.0455 .75367 L
.04822 .75124 L
.05086 .74884 L
.05305 .74685 L
.05612 .74401 L
.05789 .74238 L
.06128 .73918 L
.06272 .73783 L
.06636 .73434 L
.06755 .73323 L
.07143 .72951 L
.07238 .72862 L
.07657 .72468 L
.07721 .7241 L
.08187 .71985 L
.08204 .7197 L
.08688 .71548 L
.08741 .71502 L
.09171 .71142 L
.09316 .71019 L
.09654 .70744 L
.099 .70535 L
.10137 .70344 L
.10469 .70052 L
.1062 .69932 L
.11002 .69569 L
.11104 .69492 L
.11484 .69086 L
.11587 .69025 L
.11907 .68603 L
.1207 .68388 L
.12266 .68119 L
.12548 .67636 L
.12553 .67622 L
.12721 .67153 L
.12553 .66993 L
.1207 .66922 L
.11587 .67059 L
.11242 .67153 L
.11104 .67185 L
.1062 .67328 L
.10137 .67489 L
.09722 .67636 L
.09654 .6766 L
.09171 .6784 L
.08688 .68036 L
.08489 .68119 L
.08204 .68241 L
.07721 .68461 L
.07422 .68603 L
.07238 .68691 L
.06755 .68931 L
.06451 .69086 L
.06272 .69177 L
.05789 .69426 L
.05509 .69569 L
.05305 .69672 L
.04822 .69914 L
.04538 .70052 L
.04339 .70147 L
.03856 .70372 L
.03491 .70535 L
.03373 .70587 L
.02889 .70794 L
.02406 .70991 L
.02337 .71019 L
.01923 .71181 L
F
.01923 .64966 m
.02129 .64737 L
.02406 .64429 L
.02565 .64254 L
.02889 .63902 L
.03014 .63771 L
.03373 .63405 L
.03493 .63288 L
.03856 .62947 L
.04016 .62804 L
.04339 .62528 L
.04591 .62321 L
.04822 .62138 L
.0521 .61838 L
.05305 .61766 L
.05789 .61397 L
.05843 .61355 L
.06272 .61016 L
.06443 .60872 L
.06755 .60599 L
.06973 .60388 L
.07238 .60116 L
.07416 .59905 L
.07721 .59506 L
.07776 .59422 L
.08063 .58939 L
.08204 .58694 L
.08287 .58456 L
.0845 .57973 L
.08523 .57489 L
.0833 .57006 L
.08204 .56919 L
.07721 .56789 L
.07238 .56742 L
.06755 .56718 L
.06272 .56698 L
.05789 .56674 L
.05305 .56639 L
.04822 .56586 L
.04435 .56523 L
.04339 .56504 L
.03856 .56377 L
.03373 .56152 L
.03221 .5604 L
.02889 .55636 L
.02854 .55557 L
.02778 .55073 L
.02889 .5459 L
.02889 .54589 L
.03166 .54107 L
.03373 .5385 L
.03623 .53624 L
.03856 .5343 L
.04273 .53141 L
.04339 .53097 L
.04822 .52798 L
.05057 .52658 L
.05305 .52504 L
.05786 .52174 L
.05789 .52173 L
.06272 .51736 L
.0631 .51691 L
.06636 .51208 L
.06755 .50957 L
.0682 .50725 L
.06902 .50242 L
.06902 .49758 L
.0682 .49275 L
.06755 .49043 L
.06636 .48792 L
.0631 .48309 L
.06272 .48264 L
.05789 .47827 L
.05786 .47826 L
.05305 .47496 L
.05057 .47342 L
.04822 .47202 L
.04339 .46903 L
.04273 .46859 L
.03856 .4657 L
.03623 .46376 L
.03373 .4615 L
.03166 .45893 L
.02889 .45411 L
.02889 .4541 L
.02778 .44927 L
.02854 .44443 L
.02889 .44364 L
.03221 .4396 L
.03373 .43848 L
.03856 .43623 L
.04339 .43496 L
.04435 .43477 L
.04822 .43414 L
.05305 .43361 L
.05789 .43326 L
.06272 .43302 L
.06755 .43282 L
.07238 .43258 L
.07721 .43211 L
.08204 .43081 L
.0833 .42994 L
.08523 .42511 L
.0845 .42027 L
.08287 .41544 L
.08204 .41306 L
.08063 .41061 L
.07776 .40578 L
.07721 .40494 L
.07416 .40095 L
.07238 .39884 L
.06973 .39612 L
.06755 .39401 L
.06443 .39128 L
.06272 .38984 L
.05843 .38645 L
.05789 .38603 L
.05305 .38234 L
.0521 .38162 L
.04822 .37862 L
.04591 .37679 L
.04339 .37472 L
.04016 .37196 L
.03856 .37053 L
.03493 .36712 L
.03373 .36595 L
.03014 .36229 L
.02889 .36098 L
.02565 .35746 L
.02406 .35571 L
.02129 .35263 L
.01923 .35034 L
F
0 .093 .19 r
.04822 .1487 m
.05305 .14891 L
.05739 .14969 L
.05789 .1498 L
.06272 .15109 L
.06755 .15268 L
.07238 .1545 L
.07244 .15452 L
.07721 .15648 L
.08204 .15862 L
.08366 .15935 L
.08688 .16088 L
.09171 .16324 L
.0936 .16419 L
.09654 .16569 L
.10137 .16822 L
.10288 .16902 L
.1062 .1708 L
.11104 .17343 L
.11181 .17385 L
.11587 .17608 L
.12057 .17868 L
.1207 .17875 L
.12553 .18143 L
.12926 .18351 L
.13036 .18413 L
.1352 .18683 L
.13788 .18835 L
.14003 .18956 L
.14486 .19231 L
.14636 .19318 L
.14969 .19511 L
.15452 .19796 L
.1546 .19801 L
.15935 .20088 L
.16253 .20284 L
.16419 .20388 L
.16902 .20695 L
.17014 .20767 L
.17385 .21008 L
.17754 .2125 L
.17868 .21325 L
.18351 .21643 L
.1849 .21734 L
.18835 .21958 L
.1924 .22217 L
.19318 .22266 L
.19801 .22567 L
.20019 .227 L
.20284 .2286 L
.20767 .23147 L
.20828 .23183 L
.2125 .23431 L
.21651 .23666 L
.21734 .23715 L
.22217 .24003 L
.22459 .2415 L
.227 .24298 L
.23183 .24606 L
.23224 .24633 L
.23666 .2493 L
.23932 .25116 L
.2415 .25273 L
.24591 .25599 L
.24633 .25631 L
.25116 .25996 L
.25231 .26082 L
.25599 .26355 L
.25894 .26566 L
.26082 .26696 L
.26566 .27014 L
.26621 .27049 L
.27049 .2731 L
.27433 .27532 L
.27532 .27587 L
.28015 .27853 L
.28317 .28015 L
.28498 .28112 L
.28981 .28372 L
.29212 .28498 L
.29465 .2864 L
.29948 .28925 L
.3004 .28981 L
.30431 .29237 L
.30749 .29465 L
.30914 .29592 L
.31339 .29948 L
.31397 .3 L
.31859 .30431 L
.31881 .30451 L
.32364 .30896 L
.32384 .30914 L
.32847 .31285 L
.33003 .31397 L
.3333 .31613 L
.33795 .31881 L
.33813 .31891 L
.34296 .32137 L
.3478 .3236 L
.34787 .32364 L
.35263 .32573 L
.35746 .32782 L
.35896 .32847 L
.36229 .32994 L
.36712 .3322 L
.3693 .3333 L
.37196 .33472 L
.37679 .33775 L
.37732 .33813 L
.38162 .34175 L
.38279 .34296 L
.38645 .34776 L
.38647 .3478 L
.3896 .35263 L
.39128 .3549 L
.39355 .35746 L
.39612 .35976 L
.39998 .36229 L
.40095 .36286 L
.40578 .36526 L
.41061 .36712 L
.41061 .36713 L
.41544 .36883 L
.42027 .37036 L
.42511 .37179 L
.42568 .37196 L
.42994 .37322 L
.43477 .37468 L
.4396 .37625 L
.44116 .37679 L
.44443 .37798 L
.44927 .38008 L
.45201 .38162 L
.4541 .3828 L
.45752 .38645 L
.45893 .38933 L
.4594 .39128 L
.45958 .39612 L
.45986 .40095 L
.46227 .40578 L
.46376 .40765 L
.46859 .41033 L
.47011 .41061 L
.47342 .41186 L
.47826 .41322 L
.48309 .41423 L
.48792 .41505 L
.49062 .41544 L
.49275 .41578 L
.49758 .4165 L
.50242 .41717 L
.50725 .4178 L
.51208 .41843 L
.51691 .41907 L
.52174 .41974 L
.52526 .42027 L
.52658 .42048 L
.53141 .42131 L
.53624 .42228 L
.54107 .42351 L
.54539 .42511 L
.5459 .42533 L
.55073 .4285 L
.55166 .42994 L
.55073 .43462 L
.55063 .43477 L
.5459 .43959 L
.54589 .4396 L
.54107 .44369 L
.53996 .44443 L
.53624 .4474 L
.53465 .44927 L
.53168 .4541 L
.53471 .45893 L
.53624 .4596 L
.54107 .46092 L
.5459 .46167 L
.55073 .46282 L
.55557 .46291 L
.5604 .46292 L
.56523 .46284 L
.57006 .46268 L
.57489 .46242 L
.57973 .46205 L
.58456 .46154 L
.58939 .46087 L
.59422 .46001 L
.59901 .45893 L
.59905 .45892 L
.60388 .45801 L
.60872 .45625 L
.61285 .4541 L
.61355 .45391 L
.61838 .45057 L
.61969 .44927 L
.62321 .44543 L
.624 .44443 L
.62798 .4396 L
.62804 .43953 L
.63288 .43526 L
.63356 .43477 L
.63771 .43226 L
.64238 .42994 L
.64254 .42987 L
.64737 .42781 L
.6522 .42584 L
.654 .42511 L
.65704 .42394 L
.66187 .42187 L
.6651 .42027 L
.6667 .41958 L
.67153 .41659 L
.67288 .41544 L
.67636 .41211 L
.67729 .41061 L
.67955 .40578 L
.68119 .401 L
.68121 .40095 L
.68389 .39612 L
.68603 .39373 L
.68919 .39128 L
.69086 .39018 L
.69569 .38758 L
.69816 .38645 L
.70052 .38543 L
.70535 .38349 L
.71019 .38168 L
.71036 .38162 L
.71502 .37993 L
.71985 .37815 L
.72345 .37679 L
.72468 .37632 L
.72951 .37436 L
.73434 .37218 L
.73481 .37196 L
.73918 .3697 L
.74341 .36712 L
.74401 .36672 L
.74884 .36309 L
.74979 .36229 L
.75367 .3588 L
.75513 .35746 L
.7585 .35445 L
.7607 .35263 L
.76334 .35066 L
.76771 .3478 L
.76817 .34753 L
.773 .34491 L
.77713 .34296 L
.77783 .34266 L
.78266 .34065 L
.7875 .33882 L
.78942 .33813 L
.79233 .33713 L
.79716 .33554 L
.80199 .33403 L
.80438 .3333 L
.80682 .33258 L
.81165 .33119 L
.81649 .32986 L
.82132 .3286 L
.82182 .32847 L
.82615 .32743 L
.83098 .32638 L
.83581 .32552 L
.84065 .32495 L
.84548 .3248 L
.85031 .32535 L
.85514 .32707 L
.85734 .32847 L
.85997 .33102 L
.86165 .3333 L
.86413 .33813 L
.8648 .33985 L
.86579 .34296 L
.86688 .3478 L
.86746 .35263 L
.86751 .35746 L
.86698 .36229 L
.86585 .36712 L
.8648 .37034 L
.86416 .37196 L
.86208 .37679 L
.85997 .38155 L
.85995 .38162 L
.85826 .38645 L
.85751 .39128 L
.8581 .39612 L
.85997 .40024 L
.86044 .40095 L
.8648 .4054 L
.86538 .40578 L
.86964 .40831 L
.87447 .41024 L
.87564 .41061 L
.8793 .41165 L
.88413 .41271 L
.88896 .41355 L
.8938 .41424 L
.89863 .41485 L
.90335 .41544 L
.90346 .41546 L
.90829 .41611 L
.91312 .41688 L
.91796 .41785 L
.92279 .41918 L
.92583 .42027 L
.92762 .42105 L
.93245 .42389 L
.93398 .42511 L
.93728 .4286 L
.93823 .42994 L
.94079 .43477 L
.94211 .43854 L
.94241 .4396 L
.94344 .44443 L
.94405 .44927 L
.94432 .4541 L
.94429 .45893 L
.94396 .46376 L
.94332 .46859 L
.94233 .47342 L
.94211 .47429 L
.94097 .47826 L
.93929 .48309 L
.93742 .48792 L
.93728 .48822 L
.93574 .49275 L
.93472 .49758 L
.93472 .50242 L
.93574 .50725 L
.93728 .51178 L
.93742 .51208 L
.93929 .51691 L
.94097 .52174 L
.94211 .52571 L
.94233 .52658 L
.94332 .53141 L
.94396 .53624 L
.94429 .54107 L
.94432 .5459 L
.94405 .55073 L
.94344 .55557 L
.94241 .5604 L
.94211 .56146 L
.94079 .56523 L
.93823 .57006 L
.93728 .5714 L
.93398 .57489 L
.93245 .57611 L
.92762 .57895 L
.92583 .57973 L
.92279 .58082 L
.91796 .58215 L
.91312 .58312 L
.90829 .58389 L
.90346 .58454 L
.90335 .58456 L
.89863 .58515 L
.8938 .58576 L
.88896 .58645 L
.88413 .58729 L
.8793 .58835 L
.87564 .58939 L
.87447 .58976 L
.86964 .59169 L
.86538 .59422 L
.8648 .5946 L
.86044 .59905 L
.85997 .59976 L
.8581 .60388 L
.85751 .60872 L
.85826 .61355 L
.85995 .61838 L
.85997 .61845 L
.86208 .62321 L
.86416 .62804 L
.8648 .62966 L
.86585 .63288 L
.86698 .63771 L
.86751 .64254 L
.86746 .64737 L
.86688 .6522 L
.86579 .65704 L
.8648 .66015 L
.86413 .66187 L
.86165 .6667 L
.85997 .66898 L
.85734 .67153 L
.85514 .67293 L
.85031 .67465 L
.84548 .6752 L
.84065 .67505 L
.83581 .67448 L
.83098 .67362 L
.82615 .67257 L
.82182 .67153 L
.82132 .6714 L
.81649 .67014 L
.81165 .66881 L
.80682 .66742 L
.80438 .6667 L
.80199 .66597 L
.79716 .66446 L
.79233 .66287 L
.78942 .66187 L
.7875 .66118 L
.78266 .65935 L
.77783 .65734 L
.77713 .65704 L
.773 .65509 L
.76817 .65247 L
.76771 .6522 L
.76334 .64934 L
.7607 .64737 L
.7585 .64555 L
.75513 .64254 L
.75367 .6412 L
.74979 .63771 L
.74884 .63691 L
.74401 .63328 L
.74341 .63288 L
.73918 .6303 L
.73481 .62804 L
.73434 .62782 L
.72951 .62564 L
.72468 .62368 L
.72345 .62321 L
.71985 .62185 L
.71502 .62007 L
.71036 .61838 L
.71019 .61832 L
.70535 .61651 L
.70052 .61457 L
.69816 .61355 L
.69569 .61242 L
.69086 .60982 L
.68919 .60872 L
.68603 .60627 L
.68389 .60388 L
.68121 .59905 L
.68119 .599 L
.67955 .59422 L
.67729 .58939 L
.67636 .58789 L
.67288 .58456 L
.67153 .58341 L
.6667 .58042 L
.6651 .57973 L
.66187 .57813 L
.65704 .57606 L
.654 .57489 L
.6522 .57416 L
.64737 .57219 L
.64254 .57013 L
.64238 .57006 L
.63771 .56774 L
.63356 .56523 L
.63288 .56474 L
.62804 .56047 L
.62798 .5604 L
.624 .55557 L
.62321 .55457 L
.61969 .55073 L
.61838 .54943 L
.61355 .54609 L
.61285 .5459 L
.60872 .54375 L
.60388 .54199 L
.59905 .54108 L
.59901 .54107 L
.59422 .53999 L
.58939 .53913 L
.58456 .53846 L
.57973 .53795 L
.57489 .53758 L
.57006 .53732 L
.56523 .53716 L
.5604 .53708 L
.55557 .53709 L
.55073 .53718 L
.5459 .53833 L
.54107 .53908 L
.53624 .5404 L
.53471 .54107 L
.53168 .5459 L
.53465 .55073 L
.53624 .5526 L
.53996 .55557 L
.54107 .55631 L
.54589 .5604 L
.5459 .56041 L
.55063 .56523 L
.55073 .56538 L
.55166 .57006 L
.55073 .5715 L
.5459 .57467 L
.54539 .57489 L
.54107 .57649 L
.53624 .57772 L
.53141 .57869 L
.52658 .57952 L
.52526 .57973 L
.52174 .58026 L
.51691 .58093 L
.51208 .58157 L
.50725 .5822 L
.50242 .58283 L
.49758 .5835 L
.49275 .58422 L
.49062 .58456 L
.48792 .58495 L
.48309 .58577 L
.47826 .58678 L
.47342 .58814 L
.47011 .58939 L
.46859 .58967 L
.46376 .59235 L
.46227 .59422 L
.45986 .59905 L
.45958 .60388 L
.4594 .60872 L
.45893 .61067 L
.45752 .61355 L
.4541 .6172 L
.45201 .61838 L
.44927 .61992 L
.44443 .62202 L
.44116 .62321 L
.4396 .62375 L
.43477 .62532 L
.42994 .62678 L
.42568 .62804 L
.42511 .62821 L
.42027 .62964 L
.41544 .63117 L
.41061 .63287 L
.41061 .63288 L
.40578 .63474 L
.40095 .63714 L
.39998 .63771 L
.39612 .64024 L
.39355 .64254 L
.39128 .6451 L
.3896 .64737 L
.38647 .6522 L
.38645 .65224 L
.38279 .65704 L
.38162 .65825 L
.37732 .66187 L
.37679 .66225 L
.37196 .66528 L
.3693 .6667 L
.36712 .6678 L
.36229 .67006 L
.35896 .67153 L
.35746 .67218 L
.35263 .67427 L
.34787 .67636 L
.3478 .6764 L
.34296 .67863 L
.33813 .68109 L
.33795 .68119 L
.3333 .68387 L
.33003 .68603 L
.32847 .68715 L
.32384 .69086 L
.32364 .69104 L
.31881 .69549 L
.31859 .69569 L
.31397 .7 L
.31339 .70052 L
.30914 .70408 L
.30749 .70535 L
.30431 .70763 L
.3004 .71019 L
.29948 .71075 L
.29465 .7136 L
.29212 .71502 L
.28981 .71628 L
.28498 .71888 L
.28317 .71985 L
.28015 .72147 L
.27532 .72413 L
.27433 .72468 L
.27049 .7269 L
.26621 .72951 L
.26566 .72986 L
.26082 .73304 L
.25894 .73434 L
.25599 .73645 L
.25231 .73918 L
.25116 .74004 L
.24633 .74369 L
.24591 .74401 L
.2415 .74727 L
.23932 .74884 L
.23666 .7507 L
.23224 .75367 L
.23183 .75394 L
.227 .75702 L
.22459 .7585 L
.22217 .75997 L
.21734 .76285 L
.21651 .76334 L
.2125 .76569 L
.20828 .76817 L
.20767 .76853 L
.20284 .7714 L
.20019 .773 L
.19801 .77433 L
.19318 .77734 L
.1924 .77783 L
.18835 .78042 L
.1849 .78266 L
.18351 .78357 L
.17868 .78675 L
.17754 .7875 L
.17385 .78992 L
.17014 .79233 L
.16902 .79305 L
.16419 .79612 L
.16253 .79716 L
.15935 .79912 L
.1546 .80199 L
.15452 .80204 L
.14969 .80489 L
.14636 .80682 L
.14486 .80769 L
.14003 .81044 L
.13788 .81165 L
.1352 .81317 L
.13036 .81587 L
.12926 .81649 L
.12553 .81857 L
.1207 .82125 L
.12057 .82132 L
.11587 .82392 L
.11181 .82615 L
.11104 .82657 L
.1062 .8292 L
.10288 .83098 L
.10137 .83178 L
.09654 .83431 L
.0936 .83581 L
.09171 .83676 L
.08688 .83912 L
.08366 .84065 L
.08204 .84138 L
.07721 .84352 L
.07244 .84548 L
.07238 .8455 L
.06755 .84732 L
.06272 .84891 L
.05789 .8502 L
.05739 .85031 L
.05305 .85109 L
.04822 .8513 L
.04418 .85031 L
.04339 .84987 L
.04061 .84548 L
.04092 .84065 L
.04245 .83581 L
.04339 .83312 L
.04467 .83098 L
.04736 .82615 L
.04822 .82466 L
.05035 .82132 L
.05305 .81721 L
.05357 .81649 L
.05694 .81165 L
.05789 .81032 L
.06043 .80682 L
.06272 .80373 L
.06404 .80199 L
.06755 .79744 L
.06777 .79716 L
.07164 .79233 L
.07238 .79142 L
.07567 .7875 L
.07721 .78568 L
.07986 .78266 L
.08204 .78021 L
.08421 .77783 L
.08688 .77493 L
.08868 .773 L
.09171 .76976 L
.09321 .76817 L
.09654 .76462 L
.09775 .76334 L
.10137 .75945 L
.10225 .7585 L
.1062 .75422 L
.10671 .75367 L
.11104 .74898 L
.11116 .74884 L
.11566 .74401 L
.11587 .74379 L
.12028 .73918 L
.1207 .73875 L
.12509 .73434 L
.12553 .73391 L
.13013 .72951 L
.13036 .72929 L
.1352 .72483 L
.13536 .72468 L
.14003 .72045 L
.1407 .71985 L
.14486 .71607 L
.14601 .71502 L
.14969 .7116 L
.15118 .71019 L
.15452 .70695 L
.15614 .70535 L
.15935 .70211 L
.16091 .70052 L
.16419 .69715 L
.16561 .69569 L
.16902 .69224 L
.17041 .69086 L
.17385 .68754 L
.17548 .68603 L
.17868 .68316 L
.18097 .68119 L
.18351 .67908 L
.18692 .67636 L
.18835 .67525 L
.19318 .67156 L
.19322 .67153 L
.19801 .66789 L
.19956 .6667 L
.20284 .66412 L
.2056 .66187 L
.20767 .6601 L
.21108 .65704 L
.2125 .65569 L
.216 .6522 L
.21734 .65081 L
.22056 .64737 L
.22217 .64563 L
.22508 .64254 L
.227 .64057 L
.22994 .63771 L
.23183 .63598 L
.23553 .63288 L
.23666 .63199 L
.2415 .62849 L
.24216 .62804 L
.24633 .62536 L
.24988 .62321 L
.25116 .62246 L
.25599 .61963 L
.25812 .61838 L
.26082 .61676 L
.26566 .61366 L
.26582 .61355 L
.27049 .61013 L
.27218 .60872 L
.27532 .60581 L
.27715 .60388 L
.28015 .60035 L
.28117 .59905 L
.2848 .59422 L
.28498 .59397 L
.28861 .58939 L
.28981 .58802 L
.29327 .58456 L
.29465 .58337 L
.29948 .57986 L
.29969 .57973 L
.30431 .57714 L
.30913 .57489 L
.30914 .57489 L
.31397 .57295 L
.31881 .57114 L
.32172 .57006 L
.32364 .56936 L
.32847 .56751 L
.3333 .5654 L
.33365 .56523 L
.33813 .56288 L
.34173 .5604 L
.34296 .55943 L
.34658 .55557 L
.3478 .55393 L
.34958 .55073 L
.35163 .5459 L
.35263 .54322 L
.35321 .54107 L
.35447 .53624 L
.35516 .53141 L
.3529 .52658 L
.35263 .5264 L
.3478 .52504 L
.34296 .52462 L
.33813 .52444 L
.3333 .52435 L
.32847 .5243 L
.32364 .52428 L
.31881 .52425 L
.31397 .52422 L
.30914 .52416 L
.30431 .52405 L
.29948 .52386 L
.29465 .52356 L
.28981 .52304 L
.28498 .52213 L
.28359 .52174 L
.28015 .5204 L
.2756 .51691 L
.27532 .51658 L
.27272 .51208 L
.27131 .50725 L
.27069 .50242 L
.27069 .49758 L
.27131 .49275 L
.27272 .48792 L
.27532 .48342 L
.2756 .48309 L
.28015 .4796 L
.28359 .47826 L
.28498 .47787 L
.28981 .47696 L
.29465 .47644 L
.29948 .47614 L
.30431 .47595 L
.30914 .47584 L
.31397 .47578 L
.31881 .47575 L
.32364 .47572 L
.32847 .4757 L
.3333 .47565 L
.33813 .47556 L
.34296 .47538 L
.3478 .47496 L
.35263 .4736 L
.3529 .47342 L
.35516 .46859 L
.35447 .46376 L
.35321 .45893 L
.35263 .45678 L
.35163 .4541 L
.34958 .44927 L
.3478 .44607 L
.34658 .44443 L
.34296 .44057 L
.34173 .4396 L
.33813 .43712 L
.33365 .43477 L
.3333 .4346 L
.32847 .43249 L
.32364 .43064 L
.32172 .42994 L
.31881 .42886 L
.31397 .42705 L
.30914 .42511 L
.30913 .42511 L
.30431 .42286 L
.29969 .42027 L
.29948 .42014 L
.29465 .41663 L
.29327 .41544 L
.28981 .41198 L
.28861 .41061 L
.28498 .40603 L
.2848 .40578 L
.28117 .40095 L
.28015 .39965 L
.27715 .39612 L
.27532 .39419 L
.27218 .39128 L
.27049 .38987 L
.26582 .38645 L
.26566 .38634 L
.26082 .38324 L
.25812 .38162 L
.25599 .38037 L
.25116 .37754 L
.24988 .37679 L
.24633 .37464 L
.24216 .37196 L
.2415 .37151 L
.23666 .36801 L
.23553 .36712 L
.23183 .36402 L
.22994 .36229 L
.227 .35943 L
.22508 .35746 L
.22217 .35437 L
.22056 .35263 L
.21734 .34919 L
.216 .3478 L
.2125 .34431 L
.21108 .34296 L
.20767 .3399 L
.2056 .33813 L
.20284 .33588 L
.19956 .3333 L
.19801 .33211 L
.19322 .32847 L
.19318 .32844 L
.18835 .32475 L
.18692 .32364 L
.18351 .32092 L
.18097 .31881 L
.17868 .31684 L
.17548 .31397 L
.17385 .31246 L
.17041 .30914 L
.16902 .30776 L
.16561 .30431 L
.16419 .30285 L
.16091 .29948 L
.15935 .29789 L
.15614 .29465 L
.15452 .29305 L
.15118 .28981 L
.14969 .2884 L
.14601 .28498 L
.14486 .28393 L
.1407 .28015 L
.14003 .27955 L
.13536 .27532 L
.1352 .27517 L
.13036 .27071 L
.13013 .27049 L
.12553 .26609 L
.12509 .26566 L
.1207 .26125 L
.12028 .26082 L
.11587 .25621 L
.11566 .25599 L
.11116 .25116 L
.11104 .25102 L
.10671 .24633 L
.1062 .24578 L
.10225 .2415 L
.10137 .24055 L
.09775 .23666 L
.09654 .23538 L
.09321 .23183 L
.09171 .23024 L
.08868 .227 L
.08688 .22507 L
.08421 .22217 L
.08204 .21979 L
.07986 .21734 L
.07721 .21432 L
.07567 .2125 L
.07238 .20858 L
.07164 .20767 L
.06777 .20284 L
.06755 .20256 L
.06404 .19801 L
.06272 .19627 L
.06043 .19318 L
.05789 .18968 L
.05694 .18835 L
.05357 .18351 L
.05305 .18279 L
.05035 .17868 L
.04822 .17534 L
.04736 .17385 L
.04467 .16902 L
.04339 .16688 L
.04245 .16419 L
.04092 .15935 L
.04061 .15452 L
.04339 .15013 L
.04418 .14969 L
F
0 .01 .1 r
.94574 .98077 m
.94211 .9774 L
.94054 .97594 L
.93728 .97292 L
.93533 .97111 L
.93245 .96844 L
.93012 .96627 L
.92762 .96395 L
.92493 .96144 L
.92279 .95945 L
.91975 .95661 L
.91796 .95493 L
.91459 .95178 L
.91312 .95041 L
.90943 .94695 L
.90829 .94587 L
.90428 .94211 L
.90346 .94135 L
.89911 .93728 L
.89863 .93684 L
.89391 .93245 L
.8938 .93235 L
.88896 .92788 L
.88868 .92762 L
.88413 .92342 L
.88344 .92279 L
.8793 .91897 L
.8782 .91796 L
.87447 .91449 L
.87299 .91312 L
.86964 .90998 L
.86783 .90829 L
.8648 .90543 L
.86273 .90346 L
.85997 .90084 L
.85765 .89863 L
.85514 .89624 L
.85258 .8938 L
.85031 .89165 L
.84745 .88896 L
.84548 .88712 L
.84225 .88413 L
.84065 .88266 L
.83696 .8793 L
.83581 .87827 L
.83159 .87447 L
.83098 .87392 L
.82623 .86964 L
.82615 .86957 L
.82132 .86516 L
.82093 .8648 L
.81649 .86064 L
.81578 .85997 L
.81165 .85598 L
.8108 .85514 L
.80682 .85119 L
.80595 .85031 L
.80199 .84635 L
.80112 .84548 L
.79716 .84159 L
.79618 .84065 L
.79233 .83702 L
.79101 .83581 L
.7875 .83267 L
.78555 .83098 L
.78266 .82851 L
.77985 .82615 L
.77783 .82447 L
.77407 .82132 L
.773 .82042 L
.76845 .81649 L
.76817 .81624 L
.76334 .81176 L
.76322 .81165 L
.75851 .80682 L
.7585 .80681 L
.75423 .80199 L
.75367 .80135 L
.75008 .79716 L
.74884 .79575 L
.7457 .79233 L
.74401 .79061 L
.74072 .7875 L
.73918 .78613 L
.73494 .78266 L
.73434 .7822 L
.72951 .77862 L
.7284 .77783 L
.72468 .77522 L
.7215 .773 L
.71985 .77183 L
.71502 .76825 L
.71491 .76817 L
.71019 .76416 L
.70933 .76334 L
.70535 .75877 L
.70516 .7585 L
.70218 .75367 L
.70052 .75053 L
.69965 .74884 L
.69663 .74401 L
.69569 .74276 L
.69225 .73918 L
.69086 .73791 L
.68603 .7344 L
.68594 .73434 L
.68119 .73142 L
.67763 .72951 L
.67636 .72884 L
.67153 .7264 L
.66805 .72468 L
.6667 .72402 L
.66187 .72154 L
.6589 .71985 L
.65704 .71885 L
.65226 .71502 L
.6522 .71496 L
.64926 .71019 L
.64916 .70535 L
.65 .70052 L
.64975 .69569 L
.64737 .69156 L
.64672 .69086 L
.64254 .6871 L
.63959 .68603 L
.63771 .68504 L
.63288 .68295 L
.62804 .68131 L
.62765 .68119 L
.62321 .67974 L
.61838 .67829 L
.61355 .67691 L
.6116 .67636 L
.60872 .6756 L
.60388 .67429 L
.59905 .67283 L
.59536 .67153 L
.59422 .67112 L
.58939 .66911 L
.58571 .6667 L
.58596 .66187 L
.58939 .65919 L
.59287 .65704 L
.59422 .6562 L
.59905 .65338 L
.60099 .6522 L
.60388 .65001 L
.60623 .64737 L
.60619 .64254 L
.60388 .64037 L
.59905 .63777 L
.59892 .63771 L
.59422 .63569 L
.58939 .63425 L
.58456 .63324 L
.58241 .63288 L
.57973 .63228 L
.57489 .63131 L
.57006 .63046 L
.56523 .6297 L
.5604 .62906 L
.55557 .62855 L
.55073 .62824 L
.5459 .62821 L
.54107 .62852 L
.53624 .62914 L
.53141 .62993 L
.52658 .63074 L
.52174 .63151 L
.51691 .63226 L
.51291 .63288 L
.51208 .63301 L
.50725 .63378 L
.50242 .63453 L
.49758 .63529 L
.49275 .63607 L
.48792 .63689 L
.4834 .63771 L
.48309 .63775 L
.47826 .63845 L
.47342 .63938 L
.46859 .64066 L
.46376 .64242 L
.46349 .64254 L
.45893 .64456 L
.4551 .64737 L
.4541 .64879 L
.45347 .6522 L
.4541 .65437 L
.45562 .65704 L
.45893 .66124 L
.45927 .66187 L
.46153 .6667 L
.45898 .67153 L
.45893 .67159 L
.4541 .6749 L
.44979 .67636 L
.44927 .67657 L
.44443 .67834 L
.4396 .67994 L
.43573 .68119 L
.43477 .68149 L
.42994 .68301 L
.42511 .68466 L
.42151 .68603 L
.42027 .68641 L
.41544 .68835 L
.41108 .69086 L
.41061 .69115 L
.40578 .69472 L
.40514 .69569 L
.4026 .70052 L
.40195 .70535 L
.40148 .71019 L
.40095 .71201 L
.39938 .71502 L
.39612 .71856 L
.39427 .71985 L
.39128 .72183 L
.38645 .7245 L
.3861 .72468 L
.38162 .72693 L
.37679 .72931 L
.37638 .72951 L
.37196 .7317 L
.36719 .73434 L
.36712 .73438 L
.36229 .73734 L
.3599 .73918 L
.35746 .74111 L
.35472 .74401 L
.35263 .74665 L
.35117 .74884 L
.34837 .75367 L
.3478 .75466 L
.34532 .7585 L
.34296 .76143 L
.34117 .76334 L
.33813 .76608 L
.33551 .76817 L
.3333 .76979 L
.32864 .773 L
.32847 .77311 L
.32364 .77629 L
.32133 .77783 L
.31881 .77952 L
.31442 .78266 L
.31397 .78299 L
.30914 .78685 L
.30841 .7875 L
.30431 .79133 L
.30334 .79233 L
.29948 .79655 L
.29894 .79716 L
.29477 .80199 L
.29465 .80214 L
.29037 .80682 L
.28981 .80739 L
.28541 .81165 L
.28498 .81204 L
.28015 .81622 L
.27983 .81649 L
.27532 .82013 L
.27382 .82132 L
.27049 .82394 L
.26771 .82615 L
.26566 .8278 L
.26181 .83098 L
.26082 .83182 L
.25629 .83581 L
.25599 .83608 L
.25116 .84062 L
.25114 .84065 L
.24633 .84538 L
.24623 .84548 L
.2415 .85018 L
.24137 .85031 L
.23666 .85488 L
.23639 .85514 L
.23183 .85938 L
.23118 .85997 L
.227 .8637 L
.22575 .8648 L
.22217 .86792 L
.22018 .86964 L
.21734 .87209 L
.2146 .87447 L
.2125 .87629 L
.2091 .8793 L
.20767 .88058 L
.20375 .88413 L
.20284 .88496 L
.19853 .88896 L
.19801 .88945 L
.19338 .8938 L
.19318 .89399 L
.18835 .89854 L
.18825 .89863 L
.18351 .90304 L
.18307 .90346 L
.17868 .90749 L
.1778 .90829 L
.17385 .91188 L
.17247 .91312 L
.16902 .91622 L
.16709 .91796 L
.16419 .92056 L
.16171 .92279 L
.15935 .92491 L
.15637 .92762 L
.15452 .9293 L
.15108 .93245 L
.14969 .93372 L
.14583 .93728 L
.14486 .93818 L
.1406 .94211 L
.14003 .94265 L
.13538 .94695 L
.1352 .94712 L
.13036 .95157 L
.13014 .95178 L
.12553 .95601 L
.12488 .95661 L
.1207 .96043 L
.11959 .96144 L
.11587 .96483 L
.11429 .96627 L
.11104 .96924 L
.10899 .97111 L
.1062 .97365 L
.1037 .97594 L
.10137 .97807 L
.09843 .98077 L
F
.94574 .01923 m
.94211 .0226 L
.94054 .02406 L
.93728 .02708 L
.93533 .02889 L
.93245 .03156 L
.93012 .03373 L
.92762 .03605 L
.92493 .03856 L
.92279 .04055 L
.91975 .04339 L
.91796 .04507 L
.91459 .04822 L
.91312 .04959 L
.90943 .05305 L
.90829 .05413 L
.90428 .05789 L
.90346 .05865 L
.89911 .06272 L
.89863 .06316 L
.89391 .06755 L
.8938 .06765 L
.88896 .07212 L
.88868 .07238 L
.88413 .07658 L
.88344 .07721 L
.8793 .08103 L
.8782 .08204 L
.87447 .08551 L
.87299 .08688 L
.86964 .09002 L
.86783 .09171 L
.8648 .09457 L
.86273 .09654 L
.85997 .09916 L
.85765 .10137 L
.85514 .10376 L
.85258 .1062 L
.85031 .10835 L
.84745 .11104 L
.84548 .11288 L
.84225 .11587 L
.84065 .11734 L
.83696 .1207 L
.83581 .12173 L
.83159 .12553 L
.83098 .12608 L
.82623 .13036 L
.82615 .13043 L
.82132 .13484 L
.82093 .1352 L
.81649 .13936 L
.81578 .14003 L
.81165 .14402 L
.8108 .14486 L
.80682 .14881 L
.80595 .14969 L
.80199 .15365 L
.80112 .15452 L
.79716 .15841 L
.79618 .15935 L
.79233 .16298 L
.79101 .16419 L
.7875 .16733 L
.78555 .16902 L
.78266 .17149 L
.77985 .17385 L
.77783 .17553 L
.77407 .17868 L
.773 .17958 L
.76845 .18351 L
.76817 .18376 L
.76334 .18824 L
.76322 .18835 L
.75851 .19318 L
.7585 .19319 L
.75423 .19801 L
.75367 .19865 L
.75008 .20284 L
.74884 .20425 L
.7457 .20767 L
.74401 .20939 L
.74072 .2125 L
.73918 .21387 L
.73494 .21734 L
.73434 .2178 L
.72951 .22138 L
.7284 .22217 L
.72468 .22478 L
.7215 .227 L
.71985 .22817 L
.71502 .23175 L
.71491 .23183 L
.71019 .23584 L
.70933 .23666 L
.70535 .24123 L
.70516 .2415 L
.70218 .24633 L
.70052 .24947 L
.69965 .25116 L
.69663 .25599 L
.69569 .25724 L
.69225 .26082 L
.69086 .26209 L
.68603 .2656 L
.68594 .26566 L
.68119 .26858 L
.67763 .27049 L
.67636 .27116 L
.67153 .2736 L
.66805 .27532 L
.6667 .27598 L
.66187 .27846 L
.6589 .28015 L
.65704 .28115 L
.65226 .28498 L
.6522 .28504 L
.64926 .28981 L
.64916 .29465 L
.65 .29948 L
.64975 .30431 L
.64737 .30844 L
.64672 .30914 L
.64254 .3129 L
.63959 .31397 L
.63771 .31496 L
.63288 .31705 L
.62804 .31869 L
.62765 .31881 L
.62321 .32026 L
.61838 .32171 L
.61355 .32309 L
.6116 .32364 L
.60872 .3244 L
.60388 .32571 L
.59905 .32717 L
.59536 .32847 L
.59422 .32888 L
.58939 .33089 L
.58571 .3333 L
.58596 .33813 L
.58939 .34081 L
.59287 .34296 L
.59422 .3438 L
.59905 .34662 L
.60099 .3478 L
.60388 .34999 L
.60623 .35263 L
.60619 .35746 L
.60388 .35963 L
.59905 .36223 L
.59892 .36229 L
.59422 .36431 L
.58939 .36575 L
.58456 .36676 L
.58241 .36712 L
.57973 .36772 L
.57489 .36869 L
.57006 .36954 L
.56523 .3703 L
.5604 .37094 L
.55557 .37145 L
.55073 .37176 L
.5459 .37179 L
.54107 .37148 L
.53624 .37086 L
.53141 .37007 L
.52658 .36926 L
.52174 .36849 L
.51691 .36774 L
.51291 .36712 L
.51208 .36699 L
.50725 .36622 L
.50242 .36547 L
.49758 .36471 L
.49275 .36393 L
.48792 .36311 L
.4834 .36229 L
.48309 .36225 L
.47826 .36155 L
.47342 .36062 L
.46859 .35934 L
.46376 .35758 L
.46349 .35746 L
.45893 .35544 L
.4551 .35263 L
.4541 .35121 L
.45347 .3478 L
.4541 .34563 L
.45562 .34296 L
.45893 .33876 L
.45927 .33813 L
.46153 .3333 L
.45898 .32847 L
.45893 .32841 L
.4541 .3251 L
.44979 .32364 L
.44927 .32343 L
.44443 .32166 L
.4396 .32006 L
.43573 .31881 L
.43477 .31851 L
.42994 .31699 L
.42511 .31534 L
.42151 .31397 L
.42027 .31359 L
.41544 .31165 L
.41108 .30914 L
.41061 .30885 L
.40578 .30528 L
.40514 .30431 L
.4026 .29948 L
.40195 .29465 L
.40148 .28981 L
.40095 .28799 L
.39938 .28498 L
.39612 .28144 L
.39427 .28015 L
.39128 .27817 L
.38645 .2755 L
.3861 .27532 L
.38162 .27307 L
.37679 .27069 L
.37638 .27049 L
.37196 .2683 L
.36719 .26566 L
.36712 .26562 L
.36229 .26266 L
.3599 .26082 L
.35746 .25889 L
.35472 .25599 L
.35263 .25335 L
.35117 .25116 L
.34837 .24633 L
.3478 .24534 L
.34532 .2415 L
.34296 .23857 L
.34117 .23666 L
.33813 .23392 L
.33551 .23183 L
.3333 .23021 L
.32864 .227 L
.32847 .22689 L
.32364 .22371 L
.32133 .22217 L
.31881 .22048 L
.31442 .21734 L
.31397 .21701 L
.30914 .21315 L
.30841 .2125 L
.30431 .20867 L
.30334 .20767 L
.29948 .20345 L
.29894 .20284 L
.29477 .19801 L
.29465 .19786 L
.29037 .19318 L
.28981 .19261 L
.28541 .18835 L
.28498 .18796 L
.28015 .18378 L
.27983 .18351 L
.27532 .17987 L
.27382 .17868 L
.27049 .17606 L
.26771 .17385 L
.26566 .1722 L
.26181 .16902 L
.26082 .16818 L
.25629 .16419 L
.25599 .16392 L
.25116 .15938 L
.25114 .15935 L
.24633 .15462 L
.24623 .15452 L
.2415 .14982 L
.24137 .14969 L
.23666 .14512 L
.23639 .14486 L
.23183 .14062 L
.23118 .14003 L
.227 .1363 L
.22575 .1352 L
.22217 .13208 L
.22018 .13036 L
.21734 .12791 L
.2146 .12553 L
.2125 .12371 L
.2091 .1207 L
.20767 .11942 L
.20375 .11587 L
.20284 .11504 L
.19853 .11104 L
.19801 .11055 L
.19338 .1062 L
.19318 .10601 L
.18835 .10146 L
.18825 .10137 L
.18351 .09696 L
.18307 .09654 L
.17868 .09251 L
.1778 .09171 L
.17385 .08812 L
.17247 .08688 L
.16902 .08378 L
.16709 .08204 L
.16419 .07944 L
.16171 .07721 L
.15935 .07509 L
.15637 .07238 L
.15452 .0707 L
.15108 .06755 L
.14969 .06628 L
.14583 .06272 L
.14486 .06182 L
.1406 .05789 L
.14003 .05735 L
.13538 .05305 L
.1352 .05288 L
.13036 .04843 L
.13014 .04822 L
.12553 .04399 L
.12488 .04339 L
.1207 .03957 L
.11959 .03856 L
.11587 .03517 L
.11429 .03373 L
.11104 .03076 L
.10899 .02889 L
.1062 .02635 L
.1037 .02406 L
.10137 .02193 L
.09843 .01923 L
F
0 .03 .13 r
.11587 .44722 m
.1207 .44858 L
.12172 .44927 L
.1207 .45213 L
.11587 .45136 L
.11323 .44927 L
F
.11587 .54864 m
.1207 .54787 L
.12172 .55073 L
.1207 .55142 L
.11587 .55278 L
.11323 .55073 L
F
0 .136 .22 r
.19801 .27221 m
.20284 .27198 L
.20767 .27274 L
.2125 .27394 L
.21722 .27532 L
.21734 .27537 L
.22217 .27692 L
.227 .27853 L
.23176 .28015 L
.23183 .28018 L
.23666 .28185 L
.2415 .28356 L
.24544 .28498 L
.24633 .28531 L
.25116 .28711 L
.25599 .28901 L
.25797 .28981 L
.26082 .29101 L
.26566 .29318 L
.26869 .29465 L
.27049 .29556 L
.27532 .29824 L
.27736 .29948 L
.28015 .30129 L
.28437 .30431 L
.28498 .30478 L
.28981 .30859 L
.29051 .30914 L
.29465 .31238 L
.29681 .31397 L
.29948 .3158 L
.30431 .31875 L
.3044 .31881 L
.30914 .32129 L
.31397 .32353 L
.31423 .32364 L
.31881 .32556 L
.32364 .32747 L
.32627 .32847 L
.32847 .3293 L
.3333 .33113 L
.33813 .333 L
.33888 .3333 L
.34296 .33498 L
.3478 .33716 L
.34977 .33813 L
.35263 .33965 L
.35746 .34273 L
.35778 .34296 L
.36229 .34683 L
.36323 .3478 L
.36712 .35253 L
.3672 .35263 L
.37102 .35746 L
.37196 .35847 L
.37628 .36229 L
.37679 .36266 L
.38162 .36559 L
.38492 .36712 L
.38645 .36779 L
.39128 .36964 L
.39612 .37122 L
.39855 .37196 L
.40095 .37267 L
.40578 .37406 L
.41061 .37541 L
.41544 .37679 L
.41544 .37679 L
.42027 .37823 L
.42511 .37983 L
.42979 .38162 L
.42994 .38168 L
.43477 .38391 L
.43859 .38645 L
.4396 .38712 L
.44281 .39128 L
.44437 .39612 L
.44443 .39651 L
.44505 .40095 L
.44666 .40578 L
.44927 .40951 L
.45176 .41061 L
.4541 .41195 L
.45893 .41385 L
.46376 .41508 L
.46551 .41544 L
.46859 .41614 L
.47342 .41708 L
.47826 .4179 L
.48309 .41863 L
.48792 .41932 L
.49275 .41998 L
.49492 .42027 L
.49758 .42065 L
.50242 .42135 L
.50725 .4221 L
.51208 .42291 L
.51691 .42384 L
.52174 .42496 L
.52231 .42511 L
.52658 .42615 L
.53141 .42794 L
.53397 .42994 L
.53624 .43278 L
.53659 .43477 L
.53624 .43638 L
.53451 .4396 L
.53141 .44325 L
.53031 .44443 L
.52658 .44833 L
.52577 .44927 L
.5225 .4541 L
.52307 .45893 L
.52658 .46114 L
.53141 .46256 L
.53624 .46339 L
.53939 .46376 L
.54107 .46394 L
.5459 .46431 L
.55073 .46453 L
.55557 .46464 L
.5604 .46465 L
.56523 .46458 L
.57006 .46443 L
.57489 .4642 L
.57973 .46389 L
.58146 .46376 L
.58456 .46356 L
.58939 .46316 L
.59422 .46262 L
.59905 .46192 L
.60388 .46103 L
.60872 .45991 L
.61219 .45893 L
.61355 .4586 L
.61838 .45701 L
.62321 .45474 L
.62438 .4541 L
.62804 .45197 L
.63178 .44927 L
.63288 .44841 L
.63771 .44462 L
.63796 .44443 L
.64254 .44122 L
.64523 .4396 L
.64737 .43845 L
.6522 .43618 L
.65568 .43477 L
.65704 .43427 L
.66187 .4326 L
.6667 .43106 L
.67044 .42994 L
.67153 .42963 L
.67636 .42826 L
.68119 .42687 L
.68603 .42541 L
.68698 .42511 L
.69086 .42391 L
.69569 .4222 L
.70025 .42027 L
.70052 .42016 L
.70535 .4177 L
.70872 .41544 L
.71019 .41429 L
.71418 .41061 L
.71502 .40973 L
.7189 .40578 L
.71985 .40493 L
.72468 .40132 L
.72528 .40095 L
.72951 .39876 L
.73434 .3969 L
.73687 .39612 L
.73918 .39548 L
.74401 .39439 L
.74884 .39358 L
.75367 .39303 L
.7585 .39274 L
.76334 .39273 L
.76817 .39304 L
.773 .39375 L
.77783 .39498 L
.7809 .39612 L
.78266 .39691 L
.7875 .39996 L
.78863 .40095 L
.79233 .40528 L
.7926 .40578 L
.79457 .41061 L
.79504 .41544 L
.79426 .42027 L
.79255 .42511 L
.79233 .42563 L
.79056 .42994 L
.78917 .43477 L
.78904 .4396 L
.79048 .44443 L
.79233 .44805 L
.79371 .44927 L
.79716 .45266 L
.79922 .4541 L
.80199 .45588 L
.80682 .45833 L
.80823 .45893 L
.81165 .46031 L
.81649 .46202 L
.82132 .46357 L
.82194 .46376 L
.82615 .46511 L
.83098 .46675 L
.83569 .46859 L
.83581 .46865 L
.84065 .47106 L
.8442 .47342 L
.84548 .47445 L
.84909 .47826 L
.85031 .47996 L
.85204 .48309 L
.85385 .48792 L
.85491 .49275 L
.85514 .49446 L
.8554 .49758 L
.8554 .50242 L
.85514 .50554 L
.85491 .50725 L
.85385 .51208 L
.85204 .51691 L
.85031 .52004 L
.84909 .52174 L
.84548 .52555 L
.8442 .52658 L
.84065 .52894 L
.83581 .53135 L
.83569 .53141 L
.83098 .53325 L
.82615 .53489 L
.82194 .53624 L
.82132 .53643 L
.81649 .53798 L
.81165 .53969 L
.80823 .54107 L
.80682 .54167 L
.80199 .54412 L
.79922 .5459 L
.79716 .54734 L
.79371 .55073 L
.79233 .55195 L
.79048 .55557 L
.78904 .5604 L
.78917 .56523 L
.79056 .57006 L
.79233 .57437 L
.79255 .57489 L
.79426 .57973 L
.79504 .58456 L
.79457 .58939 L
.7926 .59422 L
.79233 .59472 L
.78863 .59905 L
.7875 .60004 L
.78266 .60309 L
.7809 .60388 L
.77783 .60502 L
.773 .60625 L
.76817 .60696 L
.76334 .60727 L
.7585 .60726 L
.75367 .60697 L
.74884 .60642 L
.74401 .60561 L
.73918 .60452 L
.73687 .60388 L
.73434 .6031 L
.72951 .60124 L
.72528 .59905 L
.72468 .59868 L
.71985 .59507 L
.7189 .59422 L
.71502 .59027 L
.71418 .58939 L
.71019 .58571 L
.70872 .58456 L
.70535 .5823 L
.70052 .57984 L
.70025 .57973 L
.69569 .5778 L
.69086 .57609 L
.68698 .57489 L
.68603 .57459 L
.68119 .57313 L
.67636 .57174 L
.67153 .57037 L
.67044 .57006 L
.6667 .56894 L
.66187 .5674 L
.65704 .56573 L
.65568 .56523 L
.6522 .56382 L
.64737 .56155 L
.64523 .5604 L
.64254 .55878 L
.63796 .55557 L
.63771 .55538 L
.63288 .55159 L
.63178 .55073 L
.62804 .54803 L
.62438 .5459 L
.62321 .54526 L
.61838 .54299 L
.61355 .5414 L
.61219 .54107 L
.60872 .54009 L
.60388 .53897 L
.59905 .53808 L
.59422 .53738 L
.58939 .53684 L
.58456 .53644 L
.58146 .53624 L
.57973 .53611 L
.57489 .5358 L
.57006 .53557 L
.56523 .53542 L
.5604 .53535 L
.55557 .53536 L
.55073 .53547 L
.5459 .53569 L
.54107 .53606 L
.53939 .53624 L
.53624 .53661 L
.53141 .53744 L
.52658 .53886 L
.52307 .54107 L
.5225 .5459 L
.52577 .55073 L
.52658 .55167 L
.53031 .55557 L
.53141 .55675 L
.53451 .5604 L
.53624 .56362 L
.53659 .56523 L
.53624 .56722 L
.53397 .57006 L
.53141 .57206 L
.52658 .57385 L
.52231 .57489 L
.52174 .57504 L
.51691 .57616 L
.51208 .57709 L
.50725 .5779 L
.50242 .57865 L
.49758 .57935 L
.49492 .57973 L
.49275 .58002 L
.48792 .58068 L
.48309 .58137 L
.47826 .5821 L
.47342 .58292 L
.46859 .58386 L
.46551 .58456 L
.46376 .58492 L
.45893 .58615 L
.4541 .58805 L
.45176 .58939 L
.44927 .59049 L
.44666 .59422 L
.44505 .59905 L
.44443 .60349 L
.44437 .60388 L
.44281 .60872 L
.4396 .61288 L
.43859 .61355 L
.43477 .61609 L
.42994 .61832 L
.42979 .61838 L
.42511 .62017 L
.42027 .62177 L
.41544 .62321 L
.41544 .62321 L
.41061 .62459 L
.40578 .62594 L
.40095 .62733 L
.39855 .62804 L
.39612 .62878 L
.39128 .63036 L
.38645 .63221 L
.38492 .63288 L
.38162 .63441 L
.37679 .63734 L
.37628 .63771 L
.37196 .64153 L
.37102 .64254 L
.3672 .64737 L
.36712 .64747 L
.36323 .6522 L
.36229 .65317 L
.35778 .65704 L
.35746 .65727 L
.35263 .66035 L
.34977 .66187 L
.3478 .66284 L
.34296 .66502 L
.33888 .6667 L
.33813 .667 L
.3333 .66887 L
.32847 .6707 L
.32627 .67153 L
.32364 .67253 L
.31881 .67444 L
.31423 .67636 L
.31397 .67647 L
.30914 .67871 L
.3044 .68119 L
.30431 .68125 L
.29948 .6842 L
.29681 .68603 L
.29465 .68762 L
.29051 .69086 L
.28981 .69141 L
.28498 .69522 L
.28437 .69569 L
.28015 .69871 L
.27736 .70052 L
.27532 .70176 L
.27049 .70444 L
.26869 .70535 L
.26566 .70682 L
.26082 .70899 L
.25797 .71019 L
.25599 .71099 L
.25116 .71289 L
.24633 .71469 L
.24544 .71502 L
.2415 .71644 L
.23666 .71815 L
.23183 .71982 L
.23176 .71985 L
.227 .72147 L
.22217 .72308 L
.21734 .72463 L
.21722 .72468 L
.2125 .72606 L
.20767 .72726 L
.20284 .72802 L
.19801 .72779 L
.19454 .72468 L
.19422 .71985 L
.19501 .71502 L
.19634 .71019 L
.19801 .70548 L
.19815 .70535 L
.2005 .70052 L
.20284 .69655 L
.20352 .69569 L
.20731 .69086 L
.20767 .69044 L
.21192 .68603 L
.2125 .68546 L
.21722 .68119 L
.21734 .6811 L
.22217 .67696 L
.22287 .67636 L
.227 .67275 L
.22834 .67153 L
.23183 .66811 L
.23317 .6667 L
.23666 .66259 L
.23723 .66187 L
.24075 .65704 L
.2415 .65595 L
.24409 .6522 L
.24633 .64911 L
.24767 .64737 L
.25116 .6433 L
.25189 .64254 L
.25599 .63863 L
.25709 .63771 L
.26082 .63476 L
.26348 .63288 L
.26566 .6314 L
.27049 .62832 L
.27094 .62804 L
.27532 .62535 L
.27872 .62321 L
.28015 .62229 L
.28498 .6189 L
.28565 .61838 L
.28981 .61478 L
.29104 .61355 L
.29465 .60927 L
.29506 .60872 L
.29832 .60388 L
.29948 .60209 L
.30148 .59905 L
.30431 .59521 L
.30513 .59422 L
.30914 .59004 L
.30988 .58939 L
.31397 .58618 L
.31646 .58456 L
.31881 .58316 L
.32364 .58064 L
.32557 .57973 L
.32847 .57843 L
.3333 .57638 L
.33691 .57489 L
.33813 .57439 L
.34296 .57232 L
.34762 .57006 L
.3478 .56997 L
.35263 .56706 L
.35496 .56523 L
.35746 .56277 L
.35929 .5604 L
.36199 .55557 L
.36229 .55491 L
.36411 .55073 L
.36634 .5459 L
.36712 .54445 L
.36928 .54107 L
.37196 .53788 L
.3737 .53624 L
.37679 .5339 L
.3813 .53141 L
.38162 .53126 L
.38645 .52937 L
.39128 .52792 L
.39612 .52675 L
.3969 .52658 L
.40095 .52575 L
.40578 .52484 L
.41061 .52396 L
.41544 .52305 L
.42027 .52203 L
.42153 .52174 L
.42511 .52086 L
.42994 .5193 L
.43448 .51691 L
.43477 .51675 L
.43877 .51208 L
.4396 .50977 L
.44009 .50725 L
.44043 .50242 L
.44043 .49758 L
.44009 .49275 L
.4396 .49023 L
.43877 .48792 L
.43477 .48325 L
.43448 .48309 L
.42994 .4807 L
.42511 .47914 L
.42153 .47826 L
.42027 .47797 L
.41544 .47695 L
.41061 .47604 L
.40578 .47516 L
.40095 .47425 L
.3969 .47342 L
.39612 .47325 L
.39128 .47208 L
.38645 .47063 L
.38162 .46874 L
.3813 .46859 L
.37679 .4661 L
.3737 .46376 L
.37196 .46212 L
.36928 .45893 L
.36712 .45555 L
.36634 .4541 L
.36411 .44927 L
.36229 .44509 L
.36199 .44443 L
.35929 .4396 L
.35746 .43723 L
.35496 .43477 L
.35263 .43294 L
.3478 .43003 L
.34762 .42994 L
.34296 .42768 L
.33813 .42561 L
.33691 .42511 L
.3333 .42362 L
.32847 .42157 L
.32557 .42027 L
.32364 .41936 L
.31881 .41684 L
.31646 .41544 L
.31397 .41382 L
.30988 .41061 L
.30914 .40996 L
.30513 .40578 L
.30431 .40479 L
.30148 .40095 L
.29948 .39791 L
.29832 .39612 L
.29506 .39128 L
.29465 .39073 L
.29104 .38645 L
.28981 .38522 L
.28565 .38162 L
.28498 .3811 L
.28015 .37771 L
.27872 .37679 L
.27532 .37465 L
.27094 .37196 L
.27049 .37168 L
.26566 .3686 L
.26348 .36712 L
.26082 .36524 L
.25709 .36229 L
.25599 .36137 L
.25189 .35746 L
.25116 .3567 L
.24767 .35263 L
.24633 .35089 L
.24409 .3478 L
.2415 .34405 L
.24075 .34296 L
.23723 .33813 L
.23666 .33741 L
.23317 .3333 L
.23183 .33189 L
.22834 .32847 L
.227 .32725 L
.22287 .32364 L
.22217 .32304 L
.21734 .3189 L
.21722 .31881 L
.2125 .31454 L
.21192 .31397 L
.20767 .30956 L
.20731 .30914 L
.20352 .30431 L
.20284 .30345 L
.2005 .29948 L
.19815 .29465 L
.19801 .29452 L
.19634 .28981 L
.19501 .28498 L
.19422 .28015 L
.19454 .27532 L
F
0 .093 .19 r
.23183 .54068 m
.23666 .53917 L
.2415 .53841 L
.24633 .53835 L
.25116 .54048 L
.25206 .54107 L
.25378 .5459 L
.25116 .55013 L
.25056 .55073 L
.24633 .55323 L
.2415 .55482 L
.23666 .55555 L
.23183 .55555 L
.227 .55457 L
.22233 .55073 L
.22344 .5459 L
.227 .54295 L
.23083 .54107 L
F
.227 .44543 m
.23183 .44445 L
.23666 .44445 L
.2415 .44518 L
.24633 .44677 L
.25056 .44927 L
.25116 .44987 L
.25378 .4541 L
.25206 .45893 L
.25116 .45952 L
.24633 .46165 L
.2415 .46159 L
.23666 .46083 L
.23183 .45932 L
.23083 .45893 L
.227 .45705 L
.22344 .4541 L
.22233 .44927 L
F
0 .187 .25 r
.28015 .3381 m
.28498 .33664 L
.28981 .33619 L
.29465 .33627 L
.29948 .3367 L
.30431 .33739 L
.30842 .33813 L
.30914 .33829 L
.31397 .33937 L
.31881 .34069 L
.32364 .34232 L
.32532 .34296 L
.32847 .34422 L
.3333 .34676 L
.3349 .3478 L
.33813 .35016 L
.34068 .35263 L
.34296 .35533 L
.34465 .35746 L
.3478 .36135 L
.34868 .36229 L
.35263 .36553 L
.35526 .36712 L
.35746 .36824 L
.36229 .3702 L
.36712 .37177 L
.36778 .37196 L
.37196 .37313 L
.37679 .37437 L
.38162 .37553 L
.38645 .37664 L
.38709 .37679 L
.39128 .37776 L
.39612 .37891 L
.40095 .38012 L
.40578 .38144 L
.40639 .38162 L
.41061 .3829 L
.41544 .38464 L
.41943 .38645 L
.42027 .38683 L
.42511 .38996 L
.4264 .39128 L
.42947 .39612 L
.42994 .39763 L
.43061 .40095 L
.43161 .40578 L
.43464 .41061 L
.43477 .41075 L
.4396 .41404 L
.44392 .41544 L
.44443 .41561 L
.44927 .41698 L
.4541 .41803 L
.45893 .4189 L
.46376 .41965 L
.46814 .42027 L
.46859 .42034 L
.47342 .42102 L
.47826 .42168 L
.48309 .42233 L
.48792 .423 L
.49275 .42371 L
.49758 .42448 L
.50113 .42511 L
.50242 .42534 L
.50725 .42631 L
.51208 .42751 L
.51691 .42915 L
.51862 .42994 L
.52174 .43172 L
.52455 .43477 L
.52456 .4396 L
.52174 .44428 L
.52163 .44443 L
.51764 .44927 L
.51691 .45015 L
.51409 .4541 L
.51295 .45893 L
.51691 .46259 L
.52041 .46376 L
.52174 .46415 L
.52658 .46512 L
.53141 .46569 L
.53624 .46605 L
.54107 .46628 L
.5459 .46642 L
.55073 .46649 L
.55557 .46649 L
.5604 .46645 L
.56523 .46635 L
.57006 .4662 L
.57489 .466 L
.57973 .46574 L
.58456 .46542 L
.58939 .46503 L
.59422 .46457 L
.59905 .46402 L
.60103 .46376 L
.60388 .46342 L
.60872 .46271 L
.61355 .46181 L
.61838 .46069 L
.62321 .4593 L
.62436 .45893 L
.62804 .45771 L
.63288 .45567 L
.63602 .4541 L
.63771 .4532 L
.64254 .45042 L
.64447 .44927 L
.64737 .44756 L
.6522 .44493 L
.65318 .44443 L
.65704 .44267 L
.66187 .44077 L
.66531 .4396 L
.6667 .43917 L
.67153 .43782 L
.67636 .43665 L
.68119 .43564 L
.68599 .43477 L
.68603 .43476 L
.69086 .43401 L
.69569 .43336 L
.70052 .43283 L
.70535 .4324 L
.71019 .43211 L
.71502 .43197 L
.71985 .43203 L
.72468 .43234 L
.72951 .43299 L
.73434 .43407 L
.73664 .43477 L
.73918 .43574 L
.74401 .43818 L
.74626 .4396 L
.74884 .44153 L
.75215 .44443 L
.75367 .44594 L
.75672 .44927 L
.7585 .45137 L
.76071 .4541 L
.76334 .45743 L
.76452 .45893 L
.76817 .46333 L
.76855 .46376 L
.773 .46834 L
.77327 .46859 L
.77783 .47235 L
.77934 .47342 L
.78266 .47558 L
.78735 .47826 L
.7875 .47834 L
.79233 .48085 L
.79657 .48309 L
.79716 .4834 L
.80199 .48617 L
.8045 .48792 L
.80682 .48953 L
.80967 .49275 L
.81165 .49614 L
.81213 .49758 L
.81213 .50242 L
.81165 .50386 L
.80967 .50725 L
.80682 .51047 L
.8045 .51208 L
.80199 .51383 L
.79716 .5166 L
.79657 .51691 L
.79233 .51915 L
.7875 .52166 L
.78735 .52174 L
.78266 .52442 L
.77934 .52658 L
.77783 .52765 L
.77327 .53141 L
.773 .53166 L
.76855 .53624 L
.76817 .53667 L
.76452 .54107 L
.76334 .54257 L
.76071 .5459 L
.7585 .54863 L
.75672 .55073 L
.75367 .55406 L
.75215 .55557 L
.74884 .55847 L
.74626 .5604 L
.74401 .56182 L
.73918 .56426 L
.73664 .56523 L
.73434 .56593 L
.72951 .56701 L
.72468 .56766 L
.71985 .56797 L
.71502 .56803 L
.71019 .56789 L
.70535 .5676 L
.70052 .56717 L
.69569 .56664 L
.69086 .56599 L
.68603 .56524 L
.68599 .56523 L
.68119 .56436 L
.67636 .56335 L
.67153 .56218 L
.6667 .56083 L
.66531 .5604 L
.66187 .55923 L
.65704 .55733 L
.65318 .55557 L
.6522 .55507 L
.64737 .55244 L
.64447 .55073 L
.64254 .54958 L
.63771 .5468 L
.63602 .5459 L
.63288 .54433 L
.62804 .54229 L
.62436 .54107 L
.62321 .5407 L
.61838 .53931 L
.61355 .53819 L
.60872 .53729 L
.60388 .53658 L
.60103 .53624 L
.59905 .53598 L
.59422 .53543 L
.58939 .53497 L
.58456 .53458 L
.57973 .53426 L
.57489 .534 L
.57006 .5338 L
.56523 .53365 L
.5604 .53355 L
.55557 .53351 L
.55073 .53351 L
.5459 .53358 L
.54107 .53372 L
.53624 .53395 L
.53141 .53431 L
.52658 .53488 L
.52174 .53585 L
.52041 .53624 L
.51691 .53741 L
.51295 .54107 L
.51409 .5459 L
.51691 .54985 L
.51764 .55073 L
.52163 .55557 L
.52174 .55572 L
.52456 .5604 L
.52455 .56523 L
.52174 .56828 L
.51862 .57006 L
.51691 .57085 L
.51208 .57249 L
.50725 .57369 L
.50242 .57466 L
.50113 .57489 L
.49758 .57552 L
.49275 .57629 L
.48792 .577 L
.48309 .57767 L
.47826 .57832 L
.47342 .57898 L
.46859 .57966 L
.46814 .57973 L
.46376 .58035 L
.45893 .5811 L
.4541 .58197 L
.44927 .58302 L
.44443 .58439 L
.44392 .58456 L
.4396 .58596 L
.43477 .58925 L
.43464 .58939 L
.43161 .59422 L
.43061 .59905 L
.42994 .60237 L
.42947 .60388 L
.4264 .60872 L
.42511 .61004 L
.42027 .61317 L
.41943 .61355 L
.41544 .61536 L
.41061 .6171 L
.40639 .61838 L
.40578 .61856 L
.40095 .61988 L
.39612 .62109 L
.39128 .62224 L
.38709 .62321 L
.38645 .62336 L
.38162 .62447 L
.37679 .62563 L
.37196 .62687 L
.36778 .62804 L
.36712 .62823 L
.36229 .6298 L
.35746 .63176 L
.35526 .63288 L
.35263 .63447 L
.34868 .63771 L
.3478 .63865 L
.34465 .64254 L
.34296 .64467 L
.34068 .64737 L
.33813 .64984 L
.3349 .6522 L
.3333 .65324 L
.32847 .65578 L
.32532 .65704 L
.32364 .65768 L
.31881 .65931 L
.31397 .66063 L
.30914 .66171 L
.30842 .66187 L
.30431 .66261 L
.29948 .6633 L
.29465 .66373 L
.28981 .66381 L
.28498 .66336 L
.28015 .6619 L
.28009 .66187 L
.27532 .65748 L
.27511 .65704 L
.27453 .6522 L
.27532 .64933 L
.27626 .64737 L
.28006 .64254 L
.28015 .64244 L
.28498 .63828 L
.28593 .63771 L
.28981 .63508 L
.29354 .63288 L
.29465 .63222 L
.29948 .6293 L
.30146 .62804 L
.30431 .62602 L
.3075 .62321 L
.30914 .62131 L
.31103 .61838 L
.31301 .61355 L
.31397 .61044 L
.31447 .60872 L
.31616 .60388 L
.31862 .59905 L
.31881 .59874 L
.3224 .59422 L
.32364 .59296 L
.32813 .58939 L
.32847 .58915 L
.3333 .5862 L
.33654 .58456 L
.33813 .58379 L
.34296 .58166 L
.34769 .57973 L
.3478 .57968 L
.35263 .57772 L
.35746 .57563 L
.35899 .57489 L
.36229 .57314 L
.36658 .57006 L
.36712 .56956 L
.37044 .56523 L
.37196 .56169 L
.37239 .5604 L
.37378 .55557 L
.37539 .55073 L
.37679 .54763 L
.37784 .5459 L
.38162 .54124 L
.38181 .54107 L
.38645 .53742 L
.38847 .53624 L
.39128 .53481 L
.39612 .53284 L
.40054 .53141 L
.40095 .53129 L
.40578 .53 L
.41061 .52889 L
.41544 .52788 L
.42027 .52692 L
.422 .52658 L
.42511 .52596 L
.42994 .52492 L
.43477 .52368 L
.4396 .52194 L
.44002 .52174 L
.44443 .51917 L
.44595 .51691 L
.44729 .51208 L
.44731 .50725 L
.44712 .50242 L
.44712 .49758 L
.44731 .49275 L
.44729 .48792 L
.44595 .48309 L
.44443 .48083 L
.44002 .47826 L
.4396 .47806 L
.43477 .47632 L
.42994 .47508 L
.42511 .47404 L
.422 .47342 L
.42027 .47308 L
.41544 .47212 L
.41061 .47111 L
.40578 .47 L
.40095 .46871 L
.40054 .46859 L
.39612 .46716 L
.39128 .46519 L
.38847 .46376 L
.38645 .46258 L
.38181 .45893 L
.38162 .45876 L
.37784 .4541 L
.37679 .45237 L
.37539 .44927 L
.37378 .44443 L
.37239 .4396 L
.37196 .43831 L
.37044 .43477 L
.36712 .43044 L
.36658 .42994 L
.36229 .42686 L
.35899 .42511 L
.35746 .42437 L
.35263 .42228 L
.3478 .42032 L
.34769 .42027 L
.34296 .41834 L
.33813 .41621 L
.33654 .41544 L
.3333 .4138 L
.32847 .41085 L
.32813 .41061 L
.32364 .40704 L
.3224 .40578 L
.31881 .40126 L
.31862 .40095 L
.31616 .39612 L
.31447 .39128 L
.31397 .38956 L
.31301 .38645 L
.31103 .38162 L
.30914 .37869 L
.3075 .37679 L
.30431 .37398 L
.30146 .37196 L
.29948 .3707 L
.29465 .36778 L
.29354 .36712 L
.28981 .36492 L
.28593 .36229 L
.28498 .36172 L
.28015 .35756 L
.28006 .35746 L
.27626 .35263 L
.27532 .35067 L
.27453 .3478 L
.27511 .34296 L
.27532 .34252 L
.28009 .33813 L
F
0 .136 .22 r
.31881 .49198 m
.32364 .49163 L
.32847 .49198 L
.3319 .49275 L
.3333 .49317 L
.33813 .49575 L
.33973 .49758 L
.33973 .50242 L
.33813 .50425 L
.3333 .50683 L
.3319 .50725 L
.32847 .50802 L
.32364 .50837 L
.31881 .50802 L
.31456 .50725 L
.31397 .50688 L
.30914 .50456 L
.30704 .50242 L
.30704 .49758 L
.30914 .49544 L
.31397 .49312 L
.31456 .49275 L
F
0 .246 .28 r
.34296 .38417 m
.3478 .3827 L
.35263 .38198 L
.35746 .38171 L
.36229 .38174 L
.36712 .38198 L
.37196 .38238 L
.37679 .38294 L
.38162 .38363 L
.38645 .38448 L
.39128 .38551 L
.39496 .38645 L
.39612 .38674 L
.40095 .38822 L
.40578 .39035 L
.40735 .39128 L
.41061 .39301 L
.41279 .39612 L
.41462 .40095 L
.41485 .40578 L
.41532 .41061 L
.41544 .41098 L
.41948 .41544 L
.42027 .41593 L
.42511 .41783 L
.42994 .41895 L
.43477 .41978 L
.43821 .42027 L
.4396 .42048 L
.44443 .42115 L
.44927 .42176 L
.4541 .42232 L
.45893 .42287 L
.46376 .42341 L
.46859 .42396 L
.47342 .42453 L
.478 .42511 L
.47826 .42514 L
.48309 .4258 L
.48792 .42653 L
.49275 .42737 L
.49758 .42837 L
.50242 .42963 L
.50341 .42994 L
.50725 .43092 L
.51208 .43352 L
.51308 .43477 L
.51513 .4396 L
.51334 .44443 L
.51208 .44697 L
.50979 .44927 L
.50725 .45209 L
.50592 .4541 L
.50325 .45893 L
.50553 .46376 L
.50725 .46455 L
.51208 .4666 L
.51691 .46712 L
.52174 .46743 L
.52658 .46765 L
.53141 .46781 L
.53624 .46792 L
.54107 .46799 L
.5459 .46802 L
.55073 .46802 L
.55557 .46798 L
.5604 .46792 L
.56523 .46781 L
.57006 .46768 L
.57489 .46751 L
.57973 .4673 L
.58456 .46704 L
.58939 .46674 L
.59422 .46639 L
.59905 .46597 L
.60388 .46548 L
.60872 .46491 L
.61355 .46425 L
.61665 .46376 L
.61838 .46349 L
.62321 .46262 L
.62804 .46156 L
.63288 .46027 L
.63712 .45893 L
.63771 .45873 L
.64254 .45696 L
.64737 .45491 L
.64919 .4541 L
.6522 .45271 L
.65704 .45053 L
.65999 .44927 L
.66187 .44852 L
.6667 .44678 L
.67153 .44534 L
.67514 .44443 L
.67636 .44417 L
.68119 .44324 L
.68603 .44255 L
.69086 .44207 L
.69569 .44181 L
.70052 .44176 L
.70535 .44196 L
.71019 .44244 L
.71502 .44324 L
.7198 .44443 L
.71985 .44445 L
.72468 .44615 L
.72951 .44856 L
.73066 .44927 L
.73434 .45192 L
.73668 .4541 L
.73918 .45688 L
.7406 .45893 L
.74321 .46376 L
.74401 .46502 L
.74484 .46859 L
.74561 .47342 L
.74556 .47826 L
.74468 .48309 L
.74401 .48537 L
.74309 .48792 L
.74127 .49275 L
.74004 .49758 L
.74004 .50242 L
.74127 .50725 L
.74309 .51208 L
.74401 .51463 L
.74468 .51691 L
.74556 .52174 L
.74561 .52658 L
.74484 .53141 L
.74401 .53498 L
.74321 .53624 L
.7406 .54107 L
.73918 .54312 L
.73668 .5459 L
.73434 .54808 L
.73066 .55073 L
.72951 .55144 L
.72468 .55385 L
.71985 .55555 L
.7198 .55557 L
.71502 .55676 L
.71019 .55756 L
.70535 .55804 L
.70052 .55824 L
.69569 .55819 L
.69086 .55793 L
.68603 .55745 L
.68119 .55676 L
.67636 .55583 L
.67514 .55557 L
.67153 .55466 L
.6667 .55322 L
.66187 .55148 L
.65999 .55073 L
.65704 .54947 L
.6522 .54729 L
.64919 .5459 L
.64737 .54509 L
.64254 .54304 L
.63771 .54127 L
.63712 .54107 L
.63288 .53973 L
.62804 .53844 L
.62321 .53738 L
.61838 .53651 L
.61665 .53624 L
.61355 .53575 L
.60872 .53509 L
.60388 .53452 L
.59905 .53403 L
.59422 .53361 L
.58939 .53326 L
.58456 .53296 L
.57973 .5327 L
.57489 .53249 L
.57006 .53232 L
.56523 .53219 L
.5604 .53208 L
.55557 .53202 L
.55073 .53198 L
.5459 .53198 L
.54107 .53201 L
.53624 .53208 L
.53141 .53219 L
.52658 .53235 L
.52174 .53257 L
.51691 .53288 L
.51208 .5334 L
.50725 .53545 L
.50553 .53624 L
.50325 .54107 L
.50592 .5459 L
.50725 .54791 L
.50979 .55073 L
.51208 .55303 L
.51334 .55557 L
.51513 .5604 L
.51308 .56523 L
.51208 .56648 L
.50725 .56908 L
.50341 .57006 L
.50242 .57037 L
.49758 .57163 L
.49275 .57263 L
.48792 .57347 L
.48309 .5742 L
.47826 .57486 L
.478 .57489 L
.47342 .57547 L
.46859 .57604 L
.46376 .57659 L
.45893 .57713 L
.4541 .57768 L
.44927 .57824 L
.44443 .57885 L
.4396 .57952 L
.43821 .57973 L
.43477 .58022 L
.42994 .58105 L
.42511 .58217 L
.42027 .58407 L
.41948 .58456 L
.41544 .58902 L
.41532 .58939 L
.41485 .59422 L
.41462 .59905 L
.41279 .60388 L
.41061 .60699 L
.40735 .60872 L
.40578 .60965 L
.40095 .61178 L
.39612 .61326 L
.39496 .61355 L
.39128 .61449 L
.38645 .61552 L
.38162 .61637 L
.37679 .61706 L
.37196 .61762 L
.36712 .61802 L
.36229 .61826 L
.35746 .61829 L
.35263 .61802 L
.3478 .6173 L
.34296 .61583 L
.3391 .61355 L
.33813 .61314 L
.33534 .60872 L
.33465 .60388 L
.33629 .59905 L
.33813 .59654 L
.3405 .59422 L
.34296 .59222 L
.3478 .5895 L
.34805 .58939 L
.35263 .58725 L
.35746 .58539 L
.35986 .58456 L
.36229 .58372 L
.36712 .58212 L
.37196 .58045 L
.37386 .57973 L
.37679 .5785 L
.38162 .57525 L
.38192 .57489 L
.38401 .57006 L
.38409 .56523 L
.38388 .5604 L
.38415 .55557 L
.38539 .55073 L
.38645 .54801 L
.38811 .5459 L
.39128 .54245 L
.39316 .54107 L
.39612 .53913 L
.40095 .53676 L
.40224 .53624 L
.40578 .53494 L
.41061 .53348 L
.41544 .53227 L
.41935 .53141 L
.42027 .53122 L
.42511 .53027 L
.42994 .52938 L
.43477 .52849 L
.4396 .52753 L
.44368 .52658 L
.44443 .5264 L
.44927 .52501 L
.45361 .52174 L
.4541 .521 L
.45497 .51691 L
.45429 .51208 L
.4541 .51084 L
.45336 .50725 L
.45279 .50242 L
.45279 .49758 L
.45336 .49275 L
.4541 .48916 L
.45429 .48792 L
.45497 .48309 L
.4541 .479 L
.45361 .47826 L
.44927 .47499 L
.44443 .4736 L
.44368 .47342 L
.4396 .47247 L
.43477 .47151 L
.42994 .47062 L
.42511 .46973 L
.42027 .46878 L
.41935 .46859 L
.41544 .46773 L
.41061 .46652 L
.40578 .46506 L
.40224 .46376 L
.40095 .46324 L
.39612 .46087 L
.39316 .45893 L
.39128 .45755 L
.38811 .4541 L
.38645 .45199 L
.38539 .44927 L
.38415 .44443 L
.38388 .4396 L
.38409 .43477 L
.38401 .42994 L
.38192 .42511 L
.38162 .42475 L
.37679 .4215 L
.37386 .42027 L
.37196 .41955 L
.36712 .41788 L
.36229 .41628 L
.35986 .41544 L
.35746 .41461 L
.35263 .41275 L
.34805 .41061 L
.3478 .4105 L
.34296 .40778 L
.3405 .40578 L
.33813 .40346 L
.33629 .40095 L
.33465 .39612 L
.33534 .39128 L
.33813 .38686 L
.3391 .38645 L
F
0 .31 .307 r
.37196 .59401 m
.37679 .59314 L
.38162 .59325 L
.38505 .59422 L
.38645 .59478 L
.39002 .59905 L
.38645 .60327 L
.38544 .60388 L
.38162 .60505 L
.37679 .60585 L
.37196 .60597 L
.36712 .60532 L
.36327 .60388 L
.36229 .60285 L
.36214 .59905 L
.36229 .59885 L
.36712 .59556 L
.37103 .59422 L
F
.36712 .39468 m
.37196 .39403 L
.37679 .39415 L
.38162 .39495 L
.38544 .39612 L
.38645 .39673 L
.39002 .40095 L
.38645 .40522 L
.38505 .40578 L
.38162 .40675 L
.37679 .40686 L
.37196 .40599 L
.37103 .40578 L
.36712 .40444 L
.36229 .40115 L
.36214 .40095 L
.36229 .39715 L
.36327 .39612 L
F
0 .058 .16 r
.37196 .48063 m
.37679 .47997 L
.38162 .47982 L
.38645 .47987 L
.39128 .48007 L
.39612 .48038 L
.40095 .4808 L
.40578 .48137 L
.41061 .48211 L
.41532 .48309 L
.41544 .48312 L
.42027 .48443 L
.42511 .48667 L
.4268 .48792 L
.42994 .49128 L
.43055 .49275 L
.43177 .49758 L
.43177 .50242 L
.43055 .50725 L
.42994 .50872 L
.4268 .51208 L
.42511 .51333 L
.42027 .51557 L
.41544 .51688 L
.41532 .51691 L
.41061 .51789 L
.40578 .51863 L
.40095 .5192 L
.39612 .51962 L
.39128 .51993 L
.38645 .52013 L
.38162 .52018 L
.37679 .52003 L
.37196 .51937 L
.36844 .51691 L
.36746 .51208 L
.36771 .50725 L
.36797 .50242 L
.36797 .49758 L
.36771 .49275 L
.36746 .48792 L
.36844 .48309 L
F
0 .03 .13 r
.40095 .49211 m
.40578 .49189 L
.40986 .49275 L
.41061 .49299 L
.41544 .49611 L
.41643 .49758 L
.41643 .50242 L
.41544 .50389 L
.41061 .50701 L
.40986 .50725 L
.40578 .50811 L
.40095 .50789 L
.39862 .50725 L
.39612 .50617 L
.39262 .50242 L
.39262 .49758 L
.39612 .49383 L
.39862 .49275 L
F
0 .31 .307 r
.42511 .42506 m
.42994 .42501 L
.43477 .42508 L
.43628 .42511 L
.4396 .42523 L
.44443 .42546 L
.44927 .42573 L
.4541 .42606 L
.45893 .42643 L
.46376 .42686 L
.46859 .42735 L
.47342 .42791 L
.47826 .42856 L
.48309 .42934 L
.48628 .42994 L
.48792 .43025 L
.49275 .43131 L
.49758 .43283 L
.50129 .43477 L
.50242 .4355 L
.50568 .4396 L
.50505 .44443 L
.50242 .44858 L
.50188 .44927 L
.49758 .45409 L
.49758 .4541 L
.4932 .45893 L
.49275 .45949 L
.49041 .46376 L
.49275 .46668 L
.49758 .46789 L
.50242 .46845 L
.50409 .46859 L
.50725 .46883 L
.51208 .46908 L
.51691 .46925 L
.52174 .46936 L
.52658 .46944 L
.53141 .46948 L
.53624 .4695 L
.54107 .46949 L
.5459 .46946 L
.55073 .46941 L
.55557 .46934 L
.5604 .46925 L
.56523 .46913 L
.57006 .46899 L
.57489 .46883 L
.57973 .46864 L
.58095 .46859 L
.58456 .46844 L
.58939 .46821 L
.59422 .46795 L
.59905 .46765 L
.60388 .46729 L
.60872 .46689 L
.61355 .46643 L
.61838 .46589 L
.62321 .46528 L
.62804 .46456 L
.63278 .46376 L
.63288 .46374 L
.63771 .46283 L
.64254 .46174 L
.64737 .4605 L
.6522 .4591 L
.65275 .45893 L
.65704 .45758 L
.66187 .45601 L
.6667 .4545 L
.66806 .4541 L
.67153 .45316 L
.67636 .45206 L
.68119 .45123 L
.68603 .4507 L
.69086 .4505 L
.69569 .45063 L
.70052 .45114 L
.70535 .45213 L
.71019 .45376 L
.71096 .4541 L
.71502 .4562 L
.71819 .45893 L
.71985 .46092 L
.72143 .46376 L
.7224 .46859 L
.72174 .47342 L
.71997 .47826 L
.71985 .47855 L
.71775 .48309 L
.71573 .48792 L
.71502 .4898 L
.71429 .49275 L
.71356 .49758 L
.71356 .50242 L
.71429 .50725 L
.71502 .5102 L
.71573 .51208 L
.71775 .51691 L
.71985 .52145 L
.71997 .52174 L
.72174 .52658 L
.7224 .53141 L
.72143 .53624 L
.71985 .53908 L
.71819 .54107 L
.71502 .5438 L
.71096 .5459 L
.71019 .54624 L
.70535 .54787 L
.70052 .54886 L
.69569 .54937 L
.69086 .5495 L
.68603 .5493 L
.68119 .54877 L
.67636 .54794 L
.67153 .54684 L
.66806 .5459 L
.6667 .5455 L
.66187 .54399 L
.65704 .54242 L
.65275 .54107 L
.6522 .5409 L
.64737 .5395 L
.64254 .53826 L
.63771 .53717 L
.63288 .53626 L
.63278 .53624 L
.62804 .53544 L
.62321 .53472 L
.61838 .53411 L
.61355 .53357 L
.60872 .53311 L
.60388 .53271 L
.59905 .53235 L
.59422 .53205 L
.58939 .53179 L
.58456 .53156 L
.58095 .53141 L
.57973 .53136 L
.57489 .53117 L
.57006 .53101 L
.56523 .53087 L
.5604 .53075 L
.55557 .53066 L
.55073 .53059 L
.5459 .53054 L
.54107 .53051 L
.53624 .5305 L
.53141 .53052 L
.52658 .53056 L
.52174 .53064 L
.51691 .53075 L
.51208 .53092 L
.50725 .53117 L
.50409 .53141 L
.50242 .53155 L
.49758 .53211 L
.49275 .53332 L
.49041 .53624 L
.49275 .54051 L
.4932 .54107 L
.49758 .5459 L
.49758 .54591 L
.50188 .55073 L
.50242 .55142 L
.50505 .55557 L
.50568 .5604 L
.50242 .5645 L
.50129 .56523 L
.49758 .56717 L
.49275 .56869 L
.48792 .56975 L
.48628 .57006 L
.48309 .57066 L
.47826 .57144 L
.47342 .57209 L
.46859 .57265 L
.46376 .57314 L
.45893 .57357 L
.4541 .57394 L
.44927 .57427 L
.44443 .57454 L
.4396 .57477 L
.43628 .57489 L
.43477 .57492 L
.42994 .57499 L
.42511 .57494 L
.42341 .57489 L
.42027 .57473 L
.41544 .57424 L
.41061 .5733 L
.40578 .57163 L
.40272 .57006 L
.40095 .56879 L
.39746 .56523 L
.39612 .56358 L
.39484 .5604 L
.39399 .55557 L
.3949 .55073 L
.39612 .54838 L
.39803 .5459 L
.40095 .54314 L
.40445 .54107 L
.40578 .54035 L
.41061 .53824 L
.41544 .53666 L
.41697 .53624 L
.42027 .53538 L
.42511 .53432 L
.42994 .53342 L
.43477 .53264 L
.4396 .53194 L
.44356 .53141 L
.44443 .53129 L
.44927 .53068 L
.4541 .53009 L
.45893 .52955 L
.46376 .52747 L
.46495 .52658 L
.46505 .52174 L
.46376 .51899 L
.46272 .51691 L
.46041 .51208 L
.45893 .50808 L
.45871 .50725 L
.45781 .50242 L
.45781 .49758 L
.45871 .49275 L
.45893 .49192 L
.46041 .48792 L
.46272 .48309 L
.46376 .48101 L
.46505 .47826 L
.46495 .47342 L
.46376 .47253 L
.45893 .47045 L
.4541 .46991 L
.44927 .46932 L
.44443 .46871 L
.44356 .46859 L
.4396 .46806 L
.43477 .46736 L
.42994 .46658 L
.42511 .46568 L
.42027 .46462 L
.41697 .46376 L
.41544 .46334 L
.41061 .46176 L
.40578 .45965 L
.40445 .45893 L
.40095 .45686 L
.39803 .4541 L
.39612 .45162 L
.3949 .44927 L
.39399 .44443 L
.39484 .4396 L
.39612 .43642 L
.39746 .43477 L
.40095 .43121 L
.40272 .42994 L
.40578 .42837 L
.41061 .4267 L
.41544 .42576 L
.42027 .42527 L
.42341 .42511 L
F
0 .34 .292 r
.4396 .53603 m
.44443 .53556 L
.44927 .53525 L
.4541 .5351 L
.45893 .53517 L
.46376 .53551 L
.46859 .53615 L
.46944 .53624 L
.47342 .53737 L
.47826 .53965 L
.48176 .54107 L
.48309 .54193 L
.48792 .54543 L
.48857 .5459 L
.49275 .54972 L
.49352 .55073 L
.49635 .55557 L
.49562 .5604 L
.49275 .56296 L
.48794 .56523 L
.48792 .56524 L
.48309 .56676 L
.47826 .56781 L
.47342 .5686 L
.46859 .56921 L
.46376 .56969 L
.45893 .57006 L
.45889 .57006 L
.4541 .57034 L
.44927 .57052 L
.44443 .57058 L
.4396 .57052 L
.43477 .57032 L
.43122 .57006 L
.42994 .56993 L
.42511 .5693 L
.42027 .56832 L
.41544 .5668 L
.41204 .56523 L
.41061 .56452 L
.40608 .5604 L
.40578 .55999 L
.40391 .55557 L
.40453 .55073 L
.40578 .54858 L
.40829 .5459 L
.41061 .54401 L
.41544 .54157 L
.41688 .54107 L
.42027 .53984 L
.42511 .53849 L
.42994 .53745 L
.43477 .53665 L
.4378 .53624 L
F
.43477 .42968 m
.4396 .42948 L
.44443 .42942 L
.44927 .42948 L
.4541 .42966 L
.45889 .42994 L
.45893 .42994 L
.46376 .43031 L
.46859 .43079 L
.47342 .4314 L
.47826 .43219 L
.48309 .43324 L
.48792 .43476 L
.48794 .43477 L
.49275 .43704 L
.49562 .4396 L
.49635 .44443 L
.49352 .44927 L
.49275 .45028 L
.48857 .4541 L
.48792 .45457 L
.48309 .45807 L
.48176 .45893 L
.47826 .46035 L
.47342 .46263 L
.46944 .46376 L
.46859 .46385 L
.46376 .46449 L
.45893 .46483 L
.4541 .4649 L
.44927 .46475 L
.44443 .46444 L
.4396 .46397 L
.4378 .46376 L
.43477 .46335 L
.42994 .46255 L
.42511 .46151 L
.42027 .46016 L
.41688 .45893 L
.41544 .45843 L
.41061 .45599 L
.40829 .4541 L
.40578 .45142 L
.40453 .44927 L
.40391 .44443 L
.40578 .44001 L
.40608 .4396 L
.41061 .43548 L
.41204 .43477 L
.41544 .4332 L
.42027 .43168 L
.42511 .4307 L
.42994 .43007 L
.43122 .42994 L
F
0 .37 .27 r
.43477 .54097 m
.4396 .54024 L
.44443 .53978 L
.44927 .53959 L
.4541 .53967 L
.45893 .54004 L
.46376 .54077 L
.46526 .54107 L
.46859 .54189 L
.47342 .5436 L
.47791 .5459 L
.47826 .54596 L
.48309 .5493 L
.4841 .55073 L
.4866 .55557 L
.48391 .5604 L
.48309 .56125 L
.47826 .56375 L
.47342 .56469 L
.46885 .56523 L
.46859 .56527 L
.46376 .56592 L
.45893 .56634 L
.4541 .56658 L
.44927 .56665 L
.44443 .56654 L
.4396 .56623 L
.43477 .56567 L
.43211 .56523 L
.42994 .56485 L
.42511 .56364 L
.42027 .56147 L
.41875 .5604 L
.41544 .55712 L
.41465 .55557 L
.415 .55073 L
.41544 .54997 L
.41997 .5459 L
.42027 .5457 L
.42511 .54327 L
.42994 .54187 L
.43423 .54107 L
F
.43477 .43433 m
.4396 .43377 L
.44443 .43346 L
.44927 .43335 L
.4541 .43342 L
.45893 .43366 L
.46376 .43408 L
.46859 .43473 L
.46885 .43477 L
.47342 .43531 L
.47826 .43625 L
.48309 .43875 L
.48391 .4396 L
.4866 .44443 L
.4841 .44927 L
.48309 .4507 L
.47826 .45404 L
.47791 .4541 L
.47342 .4564 L
.46859 .45811 L
.46526 .45893 L
.46376 .45923 L
.45893 .45996 L
.4541 .46033 L
.44927 .46041 L
.44443 .46022 L
.4396 .45976 L
.43477 .45903 L
.43423 .45893 L
.42994 .45813 L
.42511 .45673 L
.42027 .4543 L
.41997 .4541 L
.41544 .45003 L
.415 .44927 L
.41465 .44443 L
.41544 .44288 L
.41875 .4396 L
.42027 .43853 L
.42511 .43636 L
.42994 .43515 L
.43211 .43477 L
F
0 .4 .24 r
.4396 .5454 m
.44443 .54467 L
.44927 .54445 L
.4541 .54468 L
.45893 .54538 L
.46136 .5459 L
.46376 .5466 L
.46859 .54855 L
.47196 .55073 L
.47342 .55238 L
.47414 .55557 L
.47342 .55681 L
.46859 .55971 L
.46641 .5604 L
.46376 .5611 L
.45893 .56187 L
.4541 .56219 L
.44927 .56217 L
.44443 .56181 L
.4396 .56102 L
.43707 .5604 L
.43477 .5597 L
.42994 .55741 L
.42794 .55557 L
.42801 .55073 L
.42994 .54899 L
.43477 .54669 L
.43742 .5459 L
F
.4396 .43898 m
.44443 .43819 L
.44927 .43783 L
.4541 .43781 L
.45893 .43813 L
.46376 .4389 L
.46641 .4396 L
.46859 .44029 L
.47342 .44319 L
.47414 .44443 L
.47342 .44762 L
.47196 .44927 L
.46859 .45145 L
.46376 .4534 L
.46136 .4541 L
.45893 .45462 L
.4541 .45532 L
.44927 .45555 L
.44443 .45533 L
.4396 .4546 L
.43742 .4541 L
.43477 .45331 L
.42994 .45101 L
.42801 .44927 L
.42794 .44443 L
.42994 .44259 L
.43477 .4403 L
.43707 .4396 L
F
0 .34 .292 r
.65704 .46352 m
.66187 .46278 L
.6667 .46207 L
.67153 .46147 L
.67636 .46105 L
.68119 .46092 L
.68603 .46122 L
.69086 .46216 L
.69485 .46376 L
.69569 .46423 L
.69986 .46859 L
.70052 .47008 L
.70128 .47342 L
.70139 .47826 L
.70107 .48309 L
.70072 .48792 L
.70052 .49131 L
.70047 .49275 L
.70034 .49758 L
.70034 .50242 L
.70047 .50725 L
.70052 .50869 L
.70072 .51208 L
.70107 .51691 L
.70139 .52174 L
.70128 .52658 L
.70052 .52992 L
.69986 .53141 L
.69569 .53577 L
.69485 .53624 L
.69086 .53784 L
.68603 .53878 L
.68119 .53908 L
.67636 .53895 L
.67153 .53853 L
.6667 .53793 L
.66187 .53722 L
.65704 .53648 L
.65539 .53624 L
.6522 .53576 L
.64737 .53507 L
.64254 .53443 L
.63771 .53385 L
.63288 .53332 L
.62804 .53284 L
.62321 .53242 L
.61838 .53203 L
.61355 .5317 L
.60898 .53141 L
.60872 .53139 L
.60388 .5311 L
.59905 .53084 L
.59422 .53061 L
.58939 .53039 L
.58456 .5302 L
.57973 .53002 L
.57489 .52986 L
.57006 .52971 L
.56523 .52958 L
.5604 .52946 L
.55557 .52935 L
.55073 .52925 L
.5459 .52915 L
.54107 .52906 L
.53624 .52897 L
.53141 .52889 L
.52658 .5288 L
.52174 .5287 L
.51691 .52858 L
.51208 .52844 L
.50725 .52824 L
.50242 .52797 L
.49758 .52756 L
.49275 .52692 L
.48792 .52667 L
.48744 .52658 L
.48309 .5252 L
.47826 .52347 L
.47537 .52174 L
.47342 .52015 L
.4697 .51691 L
.46859 .51563 L
.46597 .51208 L
.46376 .50779 L
.46358 .50725 L
.46239 .50242 L
.46239 .49758 L
.46358 .49275 L
.46376 .49221 L
.46597 .48792 L
.46859 .48437 L
.4697 .48309 L
.47342 .47985 L
.47537 .47826 L
.47826 .47653 L
.48309 .4748 L
.48744 .47342 L
.48792 .47333 L
.49275 .47308 L
.49758 .47244 L
.50242 .47203 L
.50725 .47176 L
.51208 .47156 L
.51691 .47142 L
.52174 .4713 L
.52658 .4712 L
.53141 .47111 L
.53624 .47103 L
.54107 .47094 L
.5459 .47085 L
.55073 .47075 L
.55557 .47065 L
.5604 .47054 L
.56523 .47042 L
.57006 .47029 L
.57489 .47014 L
.57973 .46998 L
.58456 .4698 L
.58939 .46961 L
.59422 .46939 L
.59905 .46916 L
.60388 .4689 L
.60872 .46861 L
.60898 .46859 L
.61355 .4683 L
.61838 .46797 L
.62321 .46758 L
.62804 .46716 L
.63288 .46668 L
.63771 .46615 L
.64254 .46557 L
.64737 .46493 L
.6522 .46424 L
.65539 .46376 L
F
0 .37 .27 r
.6522 .46857 m
.65704 .46855 L
.65964 .46859 L
.66187 .46867 L
.6667 .46901 L
.67153 .46969 L
.67636 .47095 L
.68119 .47327 L
.68142 .47342 L
.68603 .47806 L
.68616 .47826 L
.68846 .48309 L
.68974 .48792 L
.69046 .49275 L
.69078 .49758 L
.69078 .50242 L
.69046 .50725 L
.68974 .51208 L
.68846 .51691 L
.68616 .52174 L
.68603 .52194 L
.68142 .52658 L
.68119 .52673 L
.67636 .52905 L
.67153 .53031 L
.6667 .53099 L
.66187 .53133 L
.65964 .53141 L
.65704 .53145 L
.6522 .53143 L
.65078 .53141 L
.64737 .53133 L
.64254 .53117 L
.63771 .53098 L
.63288 .53077 L
.62804 .53056 L
.62321 .53035 L
.61838 .53014 L
.61355 .52994 L
.60872 .52975 L
.60388 .52957 L
.59905 .52939 L
.59422 .52923 L
.58939 .52907 L
.58456 .52892 L
.57973 .52878 L
.57489 .52865 L
.57006 .52852 L
.56523 .52839 L
.5604 .52827 L
.55557 .52814 L
.55073 .52802 L
.5459 .52789 L
.54107 .52776 L
.53624 .52762 L
.53141 .52746 L
.52658 .52728 L
.52174 .52708 L
.51691 .52684 L
.51241 .52658 L
.51208 .52655 L
.50725 .52614 L
.50242 .52561 L
.49758 .52489 L
.49275 .52392 L
.48792 .52262 L
.48507 .52174 L
.48309 .5209 L
.47826 .51827 L
.47618 .51691 L
.47342 .51457 L
.47113 .51208 L
.46859 .50837 L
.4681 .50725 L
.46666 .50242 L
.46666 .49758 L
.4681 .49275 L
.46859 .49163 L
.47113 .48792 L
.47342 .48543 L
.47618 .48309 L
.47826 .48173 L
.48309 .4791 L
.48507 .47826 L
.48792 .47738 L
.49275 .47608 L
.49758 .47511 L
.50242 .47439 L
.50725 .47386 L
.51208 .47345 L
.51241 .47342 L
.51691 .47316 L
.52174 .47292 L
.52658 .47272 L
.53141 .47254 L
.53624 .47238 L
.54107 .47224 L
.5459 .47211 L
.55073 .47198 L
.55557 .47186 L
.5604 .47173 L
.56523 .47161 L
.57006 .47148 L
.57489 .47135 L
.57973 .47122 L
.58456 .47108 L
.58939 .47093 L
.59422 .47077 L
.59905 .47061 L
.60388 .47043 L
.60872 .47025 L
.61355 .47006 L
.61838 .46986 L
.62321 .46965 L
.62804 .46944 L
.63288 .46923 L
.63771 .46902 L
.64254 .46883 L
.64737 .46867 L
.65078 .46859 L
F
0 .4 .24 r
.5459 .47327 m
.55073 .47312 L
.55557 .47298 L
.5604 .47285 L
.56523 .47272 L
.57006 .4726 L
.57489 .47249 L
.57973 .47238 L
.58456 .47227 L
.58939 .47216 L
.59422 .47206 L
.59905 .47196 L
.60388 .47186 L
.60872 .47178 L
.61355 .4717 L
.61838 .47163 L
.62321 .47158 L
.62804 .47156 L
.63288 .47157 L
.63771 .47164 L
.64254 .47178 L
.64737 .47203 L
.6522 .47242 L
.65704 .47302 L
.6594 .47342 L
.66187 .47394 L
.6667 .47534 L
.67153 .47755 L
.67269 .47826 L
.67636 .48124 L
.67796 .48309 L
.68077 .48792 L
.68119 .4888 L
.68232 .49275 L
.68302 .49758 L
.68302 .50242 L
.68232 .50725 L
.68119 .5112 L
.68077 .51208 L
.67796 .51691 L
.67636 .51876 L
.67269 .52174 L
.67153 .52245 L
.6667 .52466 L
.66187 .52606 L
.6594 .52658 L
.65704 .52698 L
.6522 .52758 L
.64737 .52797 L
.64254 .52822 L
.63771 .52836 L
.63288 .52843 L
.62804 .52844 L
.62321 .52842 L
.61838 .52837 L
.61355 .5283 L
.60872 .52822 L
.60388 .52814 L
.59905 .52804 L
.59422 .52794 L
.58939 .52784 L
.58456 .52773 L
.57973 .52762 L
.57489 .52751 L
.57006 .5274 L
.56523 .52728 L
.5604 .52715 L
.55557 .52702 L
.55073 .52688 L
.5459 .52673 L
.54133 .52658 L
.54107 .52657 L
.53624 .52637 L
.53141 .52614 L
.52658 .52588 L
.52174 .52556 L
.51691 .52518 L
.51208 .52471 L
.50725 .52413 L
.50242 .52339 L
.49758 .52246 L
.4945 .52174 L
.49275 .52125 L
.48792 .51957 L
.48309 .51732 L
.48235 .51691 L
.47826 .51413 L
.476 .51208 L
.47342 .50914 L
.47237 .50725 L
.47068 .50242 L
.47068 .49758 L
.47237 .49275 L
.47342 .49086 L
.476 .48792 L
.47826 .48587 L
.48235 .48309 L
.48309 .48268 L
.48792 .48043 L
.49275 .47875 L
.4945 .47826 L
.49758 .47754 L
.50242 .47661 L
.50725 .47587 L
.51208 .47529 L
.51691 .47482 L
.52174 .47444 L
.52658 .47412 L
.53141 .47386 L
.53624 .47363 L
.54107 .47343 L
.54133 .47342 L
F
0 .43 .202 r
.58456 .4734 m
.58939 .47333 L
.59422 .47328 L
.59905 .47324 L
.60388 .47321 L
.60872 .47321 L
.61355 .47323 L
.61838 .47328 L
.62321 .47338 L
.62493 .47342 L
.62804 .47353 L
.63288 .47375 L
.63771 .47407 L
.64254 .47452 L
.64737 .47514 L
.6522 .476 L
.65704 .47722 L
.66013 .47826 L
.66187 .47896 L
.6667 .48158 L
.66869 .48309 L
.67153 .48589 L
.67299 .48792 L
.6753 .49275 L
.67633 .49758 L
.67633 .50242 L
.6753 .50725 L
.67299 .51208 L
.67153 .51411 L
.66869 .51691 L
.6667 .51842 L
.66187 .52104 L
.66013 .52174 L
.65704 .52278 L
.6522 .524 L
.64737 .52486 L
.64254 .52548 L
.63771 .52593 L
.63288 .52625 L
.62804 .52647 L
.62493 .52658 L
.62321 .52662 L
.61838 .52672 L
.61355 .52677 L
.60872 .52679 L
.60388 .52679 L
.59905 .52676 L
.59422 .52672 L
.58939 .52667 L
.58456 .5266 L
.58298 .52658 L
.57973 .52652 L
.57489 .52643 L
.57006 .52632 L
.56523 .52621 L
.5604 .52608 L
.55557 .52593 L
.55073 .52577 L
.5459 .52559 L
.54107 .52538 L
.53624 .52513 L
.53141 .52485 L
.52658 .52451 L
.52174 .52411 L
.51691 .52363 L
.51208 .52304 L
.50725 .52233 L
.50395 .52174 L
.50242 .52143 L
.49758 .52025 L
.49275 .51873 L
.48831 .51691 L
.48792 .51673 L
.48309 .51396 L
.48067 .51208 L
.47826 .50988 L
.47646 .50725 L
.47452 .50242 L
.47452 .49758 L
.47646 .49275 L
.47826 .49012 L
.48067 .48792 L
.48309 .48604 L
.48792 .48327 L
.48831 .48309 L
.49275 .48127 L
.49758 .47975 L
.50242 .47857 L
.50395 .47826 L
.50725 .47767 L
.51208 .47696 L
.51691 .47637 L
.52174 .47589 L
.52658 .47549 L
.53141 .47515 L
.53624 .47487 L
.54107 .47462 L
.5459 .47441 L
.55073 .47423 L
.55557 .47407 L
.5604 .47392 L
.56523 .47379 L
.57006 .47368 L
.57489 .47357 L
.57973 .47348 L
.58298 .47342 L
F
0 .46 .156 r
.51691 .47782 m
.52174 .47725 L
.52658 .47678 L
.53141 .47638 L
.53624 .47605 L
.54107 .47576 L
.5459 .47552 L
.55073 .47531 L
.55557 .47513 L
.5604 .47498 L
.56523 .47485 L
.57006 .47473 L
.57489 .47464 L
.57973 .47457 L
.58456 .47452 L
.58939 .47448 L
.59422 .47447 L
.59905 .47449 L
.60388 .47453 L
.60872 .4746 L
.61355 .47472 L
.61838 .47489 L
.62321 .47512 L
.62804 .47543 L
.63288 .47585 L
.63771 .47641 L
.64254 .47715 L
.64737 .47814 L
.64784 .47826 L
.6522 .47949 L
.65704 .48138 L
.66021 .48309 L
.66187 .48415 L
.66598 .48792 L
.6667 .48866 L
.66901 .49275 L
.67035 .49758 L
.67035 .50242 L
.66901 .50725 L
.6667 .51134 L
.66598 .51208 L
.66187 .51585 L
.66021 .51691 L
.65704 .51862 L
.6522 .52051 L
.64784 .52174 L
.64737 .52186 L
.64254 .52285 L
.63771 .52359 L
.63288 .52415 L
.62804 .52457 L
.62321 .52488 L
.61838 .52511 L
.61355 .52528 L
.60872 .5254 L
.60388 .52547 L
.59905 .52551 L
.59422 .52553 L
.58939 .52552 L
.58456 .52548 L
.57973 .52543 L
.57489 .52536 L
.57006 .52527 L
.56523 .52515 L
.5604 .52502 L
.55557 .52487 L
.55073 .52469 L
.5459 .52448 L
.54107 .52424 L
.53624 .52395 L
.53141 .52362 L
.52658 .52322 L
.52174 .52275 L
.51691 .52218 L
.51374 .52174 L
.51208 .52148 L
.50725 .52061 L
.50242 .51952 L
.49758 .51813 L
.49416 .51691 L
.49275 .51634 L
.48792 .51391 L
.4852 .51208 L
.48309 .5105 L
.48039 .50725 L
.47826 .5026 L
.47821 .50242 L
.47821 .49758 L
.47826 .4974 L
.48039 .49275 L
.48309 .4895 L
.4852 .48792 L
.48792 .48609 L
.49275 .48366 L
.49416 .48309 L
.49758 .48187 L
.50242 .48048 L
.50725 .47939 L
.51208 .47852 L
.51374 .47826 L
F
0 .49 .103 r
.52658 .47801 m
.53141 .47756 L
.53624 .47718 L
.54107 .47685 L
.5459 .47658 L
.55073 .47635 L
.55557 .47616 L
.5604 .476 L
.56523 .47587 L
.57006 .47576 L
.57489 .47568 L
.57973 .47563 L
.58456 .4756 L
.58939 .4756 L
.59422 .47564 L
.59905 .4757 L
.60388 .47581 L
.60872 .47596 L
.61355 .47617 L
.61838 .47645 L
.62321 .47681 L
.62804 .47728 L
.63288 .4779 L
.63522 .47826 L
.63771 .47869 L
.64254 .47974 L
.64737 .48114 L
.6522 .48308 L
.65221 .48309 L
.65704 .48585 L
.65951 .48792 L
.66187 .49033 L
.66324 .49275 L
.66488 .49758 L
.66488 .50242 L
.66324 .50725 L
.66187 .50967 L
.65951 .51208 L
.65704 .51415 L
.65221 .51691 L
.6522 .51692 L
.64737 .51886 L
.64254 .52026 L
.63771 .52131 L
.63522 .52174 L
.63288 .5221 L
.62804 .52272 L
.62321 .52319 L
.61838 .52355 L
.61355 .52383 L
.60872 .52404 L
.60388 .52419 L
.59905 .5243 L
.59422 .52436 L
.58939 .5244 L
.58456 .5244 L
.57973 .52437 L
.57489 .52432 L
.57006 .52424 L
.56523 .52413 L
.5604 .524 L
.55557 .52384 L
.55073 .52365 L
.5459 .52342 L
.54107 .52315 L
.53624 .52282 L
.53141 .52244 L
.52658 .52199 L
.5243 .52174 L
.52174 .52144 L
.51691 .52077 L
.51208 .51995 L
.50725 .51894 L
.50242 .51767 L
.49999 .51691 L
.49758 .51606 L
.49275 .51392 L
.48964 .51208 L
.48792 .51101 L
.48423 .50725 L
.48309 .50555 L
.4818 .50242 L
.4818 .49758 L
.48309 .49445 L
.48423 .49275 L
.48792 .48899 L
.48964 .48792 L
.49275 .48608 L
.49758 .48394 L
.49999 .48309 L
.50242 .48233 L
.50725 .48106 L
.51208 .48005 L
.51691 .47923 L
.52174 .47856 L
.5243 .47826 L
F
0 .52 .042 r
.54107 .47792 m
.5459 .47762 L
.55073 .47737 L
.55557 .47716 L
.5604 .47699 L
.56523 .47686 L
.57006 .47676 L
.57489 .4767 L
.57973 .47666 L
.58456 .47666 L
.58939 .4767 L
.59422 .47677 L
.59905 .47689 L
.60388 .47706 L
.60872 .47728 L
.61355 .47758 L
.61838 .47797 L
.62128 .47826 L
.62321 .47847 L
.62804 .47911 L
.63288 .47992 L
.63771 .48098 L
.64254 .48239 L
.64449 .48309 L
.64737 .48427 L
.6522 .487 L
.65341 .48792 L
.65704 .4914 L
.65785 .49275 L
.65978 .49758 L
.65978 .50242 L
.65785 .50725 L
.65704 .5086 L
.65341 .51208 L
.6522 .513 L
.64737 .51573 L
.64449 .51691 L
.64254 .51761 L
.63771 .51902 L
.63288 .52008 L
.62804 .52089 L
.62321 .52153 L
.62128 .52174 L
.61838 .52203 L
.61355 .52242 L
.60872 .52272 L
.60388 .52294 L
.59905 .52311 L
.59422 .52323 L
.58939 .5233 L
.58456 .52334 L
.57973 .52334 L
.57489 .5233 L
.57006 .52324 L
.56523 .52314 L
.5604 .52301 L
.55557 .52284 L
.55073 .52263 L
.5459 .52238 L
.54107 .52208 L
.53649 .52174 L
.53624 .52172 L
.53141 .52129 L
.52658 .52077 L
.52174 .52014 L
.51691 .51938 L
.51208 .51844 L
.50725 .51729 L
.50589 .51691 L
.50242 .51584 L
.49758 .51394 L
.49402 .51208 L
.49275 .51141 L
.48798 .50725 L
.48792 .50718 L
.48531 .50242 L
.48531 .49758 L
.48792 .49282 L
.48798 .49275 L
.49275 .48859 L
.49402 .48792 L
.49758 .48606 L
.50242 .48416 L
.50589 .48309 L
.50725 .48271 L
.51208 .48156 L
.51691 .48062 L
.52174 .47986 L
.52658 .47923 L
.53141 .47871 L
.53624 .47828 L
.53649 .47826 L
F
.028 .55 0 r
.55557 .47814 m
.5604 .47797 L
.56523 .47784 L
.57006 .47774 L
.57489 .47769 L
.57973 .47768 L
.58456 .4777 L
.58939 .47777 L
.59422 .47789 L
.59905 .47806 L
.60331 .47826 L
.60388 .47829 L
.60872 .47859 L
.61355 .47899 L
.61838 .47949 L
.62321 .48012 L
.62804 .48094 L
.63288 .48199 L
.63686 .48309 L
.63771 .48335 L
.64254 .48515 L
.64737 .48779 L
.64756 .48792 L
.6522 .49195 L
.65273 .49275 L
.65495 .49758 L
.65495 .50242 L
.65273 .50725 L
.6522 .50805 L
.64756 .51208 L
.64737 .51221 L
.64254 .51485 L
.63771 .51665 L
.63686 .51691 L
.63288 .51801 L
.62804 .51906 L
.62321 .51988 L
.61838 .52051 L
.61355 .52101 L
.60872 .52141 L
.60388 .52171 L
.60331 .52174 L
.59905 .52194 L
.59422 .52211 L
.58939 .52223 L
.58456 .5223 L
.57973 .52232 L
.57489 .52231 L
.57006 .52226 L
.56523 .52216 L
.5604 .52203 L
.55557 .52186 L
.55295 .52174 L
.55073 .52164 L
.5459 .52136 L
.54107 .52103 L
.53624 .52063 L
.53141 .52015 L
.52658 .51956 L
.52174 .51886 L
.51691 .518 L
.51208 .51694 L
.51195 .51691 L
.50725 .51564 L
.50242 .51395 L
.49839 .51208 L
.49758 .51171 L
.49275 .50842 L
.49169 .50725 L
.48876 .50242 L
.48876 .49758 L
.49169 .49275 L
.49275 .49158 L
.49758 .48829 L
.49839 .48792 L
.50242 .48605 L
.50725 .48436 L
.51195 .48309 L
.51208 .48306 L
.51691 .482 L
.52174 .48114 L
.52658 .48044 L
.53141 .47985 L
.53624 .47937 L
.54107 .47897 L
.5459 .47864 L
.55073 .47836 L
.55295 .47826 L
F
.104 .58 0 r
.52174 .48242 m
.52658 .48164 L
.53141 .48099 L
.53624 .48046 L
.54107 .48002 L
.5459 .47965 L
.55073 .47936 L
.55557 .47912 L
.5604 .47894 L
.56523 .4788 L
.57006 .47872 L
.57489 .47867 L
.57973 .47868 L
.58456 .47873 L
.58939 .47883 L
.59422 .47899 L
.59905 .47922 L
.60388 .47951 L
.60872 .4799 L
.61355 .48039 L
.61838 .48101 L
.62321 .48181 L
.62804 .48282 L
.62914 .48309 L
.63288 .4841 L
.63771 .48583 L
.64188 .48792 L
.64254 .48825 L
.64737 .49215 L
.64782 .49275 L
.65034 .49758 L
.65034 .50242 L
.64782 .50725 L
.64737 .50785 L
.64254 .51175 L
.64188 .51208 L
.63771 .51417 L
.63288 .5159 L
.62914 .51691 L
.62804 .51718 L
.62321 .51819 L
.61838 .51899 L
.61355 .51961 L
.60872 .5201 L
.60388 .52049 L
.59905 .52078 L
.59422 .52101 L
.58939 .52117 L
.58456 .52127 L
.57973 .52132 L
.57489 .52133 L
.57006 .52128 L
.56523 .5212 L
.5604 .52106 L
.55557 .52088 L
.55073 .52064 L
.5459 .52035 L
.54107 .51998 L
.53624 .51954 L
.53141 .51901 L
.52658 .51836 L
.52174 .51758 L
.5183 .51691 L
.51691 .51662 L
.51208 .51544 L
.50725 .51393 L
.50278 .51208 L
.50242 .51194 L
.49758 .50929 L
.49537 .50725 L
.49275 .5038 L
.49217 .50242 L
.49217 .49758 L
.49275 .4962 L
.49537 .49275 L
.49758 .49071 L
.50242 .48806 L
.50278 .48792 L
.50725 .48607 L
.51208 .48456 L
.51691 .48338 L
.5183 .48309 L
F
.189 .61 0 r
.52658 .48284 m
.53141 .48213 L
.53624 .48154 L
.54107 .48106 L
.5459 .48066 L
.55073 .48035 L
.55557 .48009 L
.5604 .4799 L
.56523 .47977 L
.57006 .47969 L
.57489 .47966 L
.57973 .47968 L
.58456 .47976 L
.58939 .47989 L
.59422 .4801 L
.59905 .48038 L
.60388 .48074 L
.60872 .48121 L
.61355 .48181 L
.61838 .48257 L
.62111 .48309 L
.62321 .48352 L
.62804 .48474 L
.63288 .48638 L
.63628 .48792 L
.63771 .48856 L
.64254 .49215 L
.64304 .49275 L
.64587 .49758 L
.64587 .50242 L
.64304 .50725 L
.64254 .50785 L
.63771 .51144 L
.63628 .51208 L
.63288 .51362 L
.62804 .51526 L
.62321 .51648 L
.62111 .51691 L
.61838 .51743 L
.61355 .51819 L
.60872 .51879 L
.60388 .51926 L
.59905 .51962 L
.59422 .5199 L
.58939 .52011 L
.58456 .52024 L
.57973 .52032 L
.57489 .52034 L
.57006 .52031 L
.56523 .52023 L
.5604 .5201 L
.55557 .51991 L
.55073 .51965 L
.5459 .51934 L
.54107 .51894 L
.53624 .51846 L
.53141 .51787 L
.52658 .51716 L
.52512 .51691 L
.52174 .5163 L
.51691 .51523 L
.51208 .51388 L
.50725 .51209 L
.50723 .51208 L
.50242 .50989 L
.49905 .50725 L
.49758 .50577 L
.49557 .50242 L
.49557 .49758 L
.49758 .49423 L
.49905 .49275 L
.50242 .49011 L
.50723 .48792 L
.50725 .48791 L
.51208 .48612 L
.51691 .48477 L
.52174 .4837 L
.52512 .48309 L
F
.282 .64 0 r
.53624 .48263 m
.54107 .48211 L
.5459 .48168 L
.55073 .48134 L
.55557 .48107 L
.5604 .48087 L
.56523 .48073 L
.57006 .48066 L
.57489 .48064 L
.57973 .48068 L
.58456 .48079 L
.58939 .48096 L
.59422 .48121 L
.59905 .48155 L
.60388 .48199 L
.60872 .48256 L
.61242 .48309 L
.61355 .48327 L
.61838 .48415 L
.62321 .4853 L
.62804 .48684 L
.63069 .48792 L
.63288 .4888 L
.63771 .49207 L
.63836 .49275 L
.64152 .49758 L
.64152 .50242 L
.63836 .50725 L
.63771 .50793 L
.63288 .5112 L
.63069 .51208 L
.62804 .51316 L
.62321 .5147 L
.61838 .51585 L
.61355 .51673 L
.61242 .51691 L
.60872 .51744 L
.60388 .51801 L
.59905 .51845 L
.59422 .51879 L
.58939 .51904 L
.58456 .51921 L
.57973 .51932 L
.57489 .51936 L
.57006 .51934 L
.56523 .51927 L
.5604 .51913 L
.55557 .51893 L
.55073 .51866 L
.5459 .51832 L
.54107 .51789 L
.53624 .51737 L
.53273 .51691 L
.53141 .51673 L
.52658 .51595 L
.52174 .51499 L
.51691 .51377 L
.51208 .51219 L
.5118 .51208 L
.50725 .51031 L
.50275 .50725 L
.50242 .50697 L
.49896 .50242 L
.49896 .49758 L
.50242 .49303 L
.50275 .49275 L
.50725 .48969 L
.5118 .48792 L
.51208 .48781 L
.51691 .48623 L
.52174 .48501 L
.52658 .48405 L
.53141 .48327 L
.53273 .48309 L
F
.382 .67 0 r
.5459 .4827 m
.55073 .48233 L
.55557 .48205 L
.5604 .48184 L
.56523 .4817 L
.57006 .48163 L
.57489 .48163 L
.57973 .48169 L
.58456 .48183 L
.58939 .48204 L
.59422 .48234 L
.59905 .48275 L
.60236 .48309 L
.60388 .48326 L
.60872 .48391 L
.61355 .48474 L
.61838 .48582 L
.62321 .48725 L
.62502 .48792 L
.62804 .48901 L
.63288 .49196 L
.63373 .49275 L
.63724 .49758 L
.63724 .50242 L
.63373 .50725 L
.63288 .50804 L
.62804 .51099 L
.62502 .51208 L
.62321 .51275 L
.61838 .51418 L
.61355 .51526 L
.60872 .51609 L
.60388 .51674 L
.60236 .51691 L
.59905 .51725 L
.59422 .51766 L
.58939 .51796 L
.58456 .51817 L
.57973 .51831 L
.57489 .51837 L
.57006 .51837 L
.56523 .5183 L
.5604 .51816 L
.55557 .51795 L
.55073 .51767 L
.5459 .5173 L
.54181 .51691 L
.54107 .51684 L
.53624 .51628 L
.53141 .51558 L
.52658 .51471 L
.52174 .51362 L
.51691 .51221 L
.51654 .51208 L
.51208 .51058 L
.50725 .50785 L
.5065 .50725 L
.50242 .50251 L
.50238 .50242 L
.50238 .49758 L
.50242 .49749 L
.5065 .49275 L
.50725 .49215 L
.51208 .48942 L
.51654 .48792 L
.51691 .48779 L
.52174 .48638 L
.52658 .48529 L
.53141 .48442 L
.53624 .48372 L
.54107 .48316 L
.54181 .48309 L
F
0 .01 .1 r
.52658 .3861 m
.53141 .3851 L
.53624 .38453 L
.54107 .38448 L
.5459 .38507 L
.55073 .38638 L
.55095 .38645 L
.55557 .38857 L
.56003 .39128 L
.5604 .39158 L
.56402 .39612 L
.56255 .40095 L
.5604 .40229 L
.55557 .40401 L
.55073 .40502 L
.5459 .40566 L
.54475 .40578 L
.54107 .4061 L
.53624 .40633 L
.53141 .40636 L
.52658 .40618 L
.52186 .40578 L
.52174 .40576 L
.51691 .40515 L
.51208 .40415 L
.50725 .40233 L
.50539 .40095 L
.50562 .39612 L
.50725 .39448 L
.51208 .39138 L
.51226 .39128 L
.51691 .38925 L
.52174 .3875 L
.52513 .38645 L
F
.52658 .59382 m
.53141 .59364 L
.53624 .59367 L
.54107 .5939 L
.54475 .59422 L
.5459 .59434 L
.55073 .59498 L
.55557 .59599 L
.5604 .59771 L
.56255 .59905 L
.56402 .60388 L
.5604 .60842 L
.56003 .60872 L
.55557 .61143 L
.55095 .61355 L
.55073 .61362 L
.5459 .61493 L
.54107 .61552 L
.53624 .61547 L
.53141 .6149 L
.52658 .6139 L
.52513 .61355 L
.52174 .6125 L
.51691 .61075 L
.51226 .60872 L
.51208 .60862 L
.50725 .60552 L
.50562 .60388 L
.50539 .59905 L
.50725 .59767 L
.51208 .59585 L
.51691 .59485 L
.52174 .59424 L
.52186 .59422 L
F
.49 .7 0 r
.55557 .48304 m
.5604 .48283 L
.56523 .48269 L
.57006 .48262 L
.57489 .48263 L
.57973 .48272 L
.58456 .48289 L
.58855 .48309 L
.58939 .48314 L
.59422 .48348 L
.59905 .48394 L
.60388 .48454 L
.60872 .48531 L
.61355 .48632 L
.61838 .48765 L
.6192 .48792 L
.62321 .48922 L
.62804 .49189 L
.62909 .49275 L
.63288 .49727 L
.633 .49758 L
.633 .50242 L
.63288 .50273 L
.62909 .50725 L
.62804 .50811 L
.62321 .51078 L
.6192 .51208 L
.61838 .51235 L
.61355 .51368 L
.60872 .51469 L
.60388 .51546 L
.59905 .51606 L
.59422 .51652 L
.58939 .51686 L
.58855 .51691 L
.58456 .51711 L
.57973 .51728 L
.57489 .51737 L
.57006 .51738 L
.56523 .51731 L
.5604 .51717 L
.55557 .51696 L
.55476 .51691 L
.55073 .51666 L
.5459 .51627 L
.54107 .51578 L
.53624 .51516 L
.53141 .51439 L
.52658 .5134 L
.52174 .51214 L
.52152 .51208 L
.51691 .51073 L
.51208 .50846 L
.51033 .50725 L
.50725 .50458 L
.50583 .50242 L
.50583 .49758 L
.50725 .49542 L
.51033 .49275 L
.51208 .49154 L
.51691 .48927 L
.52152 .48792 L
.52174 .48786 L
.52658 .4866 L
.53141 .48561 L
.53624 .48484 L
.54107 .48422 L
.5459 .48373 L
.55073 .48334 L
.55476 .48309 L
F
.606 .73 0 r
.53141 .48688 m
.53624 .486 L
.54107 .48531 L
.5459 .48477 L
.55073 .48435 L
.55557 .48403 L
.5604 .48381 L
.56523 .48367 L
.57006 .48361 L
.57489 .48364 L
.57973 .48374 L
.58456 .48394 L
.58939 .48423 L
.59422 .48464 L
.59905 .48518 L
.60388 .4859 L
.60872 .48683 L
.61307 .48792 L
.61355 .48803 L
.61838 .48944 L
.62321 .49187 L
.62442 .49275 L
.62804 .49626 L
.62877 .49758 L
.62877 .50242 L
.62804 .50374 L
.62442 .50725 L
.62321 .50813 L
.61838 .51056 L
.61355 .51197 L
.61307 .51208 L
.60872 .51317 L
.60388 .5141 L
.59905 .51482 L
.59422 .51536 L
.58939 .51577 L
.58456 .51606 L
.57973 .51626 L
.57489 .51636 L
.57006 .51639 L
.56523 .51633 L
.5604 .51619 L
.55557 .51597 L
.55073 .51565 L
.5459 .51523 L
.54107 .51469 L
.53624 .514 L
.53141 .51312 L
.52688 .51208 L
.52658 .51201 L
.52174 .51078 L
.51691 .50884 L
.51427 .50725 L
.51208 .50569 L
.50935 .50242 L
.50935 .49758 L
.51208 .49431 L
.51427 .49275 L
.51691 .49116 L
.52174 .48922 L
.52658 .48799 L
.52688 .48792 L
F
.73 .76 0 r
.53624 .48724 m
.54107 .48646 L
.5459 .48586 L
.55073 .48539 L
.55557 .48505 L
.5604 .48481 L
.56523 .48467 L
.57006 .48462 L
.57489 .48466 L
.57973 .48479 L
.58456 .48503 L
.58939 .48538 L
.59422 .48586 L
.59905 .48651 L
.60388 .48736 L
.60644 .48792 L
.60872 .48838 L
.61355 .48971 L
.61838 .49193 L
.61964 .49275 L
.62321 .49566 L
.6245 .49758 L
.6245 .50242 L
.62321 .50434 L
.61964 .50725 L
.61838 .50807 L
.61355 .51029 L
.60872 .51162 L
.60644 .51208 L
.60388 .51264 L
.59905 .51349 L
.59422 .51414 L
.58939 .51462 L
.58456 .51497 L
.57973 .51521 L
.57489 .51534 L
.57006 .51538 L
.56523 .51533 L
.5604 .51519 L
.55557 .51495 L
.55073 .51461 L
.5459 .51414 L
.54107 .51354 L
.53624 .51276 L
.5328 .51208 L
.53141 .51183 L
.52658 .51072 L
.52174 .50904 L
.51837 .50725 L
.51691 .50637 L
.51295 .50242 L
.51295 .49758 L
.51691 .49363 L
.51837 .49275 L
.52174 .49096 L
.52658 .48928 L
.53141 .48817 L
.5328 .48792 L
F
.79 .719 0 r
.54107 .48769 m
.5459 .48701 L
.55073 .4865 L
.55557 .48612 L
.5604 .48586 L
.56523 .48571 L
.57006 .48567 L
.57489 .48573 L
.57973 .48589 L
.58456 .48618 L
.58939 .4866 L
.59422 .48717 L
.59892 .48792 L
.59905 .48794 L
.60388 .48878 L
.60872 .49004 L
.61355 .49208 L
.6147 .49275 L
.61838 .49533 L
.62015 .49758 L
.62015 .50242 L
.61838 .50467 L
.6147 .50725 L
.61355 .50792 L
.60872 .50996 L
.60388 .51122 L
.59905 .51206 L
.59892 .51208 L
.59422 .51283 L
.58939 .5134 L
.58456 .51382 L
.57973 .51411 L
.57489 .51427 L
.57006 .51433 L
.56523 .51429 L
.5604 .51414 L
.55557 .51388 L
.55073 .5135 L
.5459 .51299 L
.54107 .51231 L
.53966 .51208 L
.53624 .51155 L
.53141 .51056 L
.52658 .50907 L
.52268 .50725 L
.52174 .50676 L
.51691 .50278 L
.51668 .50242 L
.51668 .49758 L
.51691 .49722 L
.52174 .49324 L
.52268 .49275 L
.52658 .49093 L
.53141 .48944 L
.53624 .48845 L
.53966 .48792 L
F
.82 .64 0 r
.55073 .48767 m
.55557 .48726 L
.5604 .48698 L
.56523 .48682 L
.57006 .48678 L
.57489 .48686 L
.57973 .48707 L
.58456 .48741 L
.58939 .4879 L
.58952 .48792 L
.59422 .48846 L
.59905 .48926 L
.60388 .49045 L
.60872 .49235 L
.6095 .49275 L
.61355 .49521 L
.61569 .49758 L
.61569 .50242 L
.61355 .50479 L
.6095 .50725 L
.60872 .50765 L
.60388 .50955 L
.59905 .51074 L
.59422 .51154 L
.58952 .51208 L
.58939 .5121 L
.58456 .51259 L
.57973 .51293 L
.57489 .51314 L
.57006 .51322 L
.56523 .51318 L
.5604 .51302 L
.55557 .51274 L
.55073 .51233 L
.54844 .51208 L
.5459 .51182 L
.54107 .51118 L
.53624 .51028 L
.53141 .50894 L
.52729 .50725 L
.52658 .50692 L
.52174 .50381 L
.52057 .50242 L
.52057 .49758 L
.52174 .49619 L
.52658 .49308 L
.52729 .49275 L
.53141 .49106 L
.53624 .48972 L
.54107 .48882 L
.5459 .48818 L
.54844 .48792 L
F
.85 .552 0 r
.53624 .49135 m
.54107 .49014 L
.5459 .48932 L
.55073 .48875 L
.55557 .48836 L
.5604 .48811 L
.56523 .48798 L
.57006 .48796 L
.57489 .48804 L
.57973 .48824 L
.58456 .48858 L
.58939 .48909 L
.59422 .48984 L
.59905 .49098 L
.60388 .49274 L
.6039 .49275 L
.60872 .49529 L
.61104 .49758 L
.61104 .50242 L
.60872 .50471 L
.6039 .50725 L
.60388 .50726 L
.59905 .50902 L
.59422 .51016 L
.58939 .51091 L
.58456 .51142 L
.57973 .51176 L
.57489 .51196 L
.57006 .51204 L
.56523 .51202 L
.5604 .51189 L
.55557 .51164 L
.55073 .51125 L
.5459 .51068 L
.54107 .50986 L
.53624 .50865 L
.53235 .50725 L
.53141 .50688 L
.52658 .50427 L
.52469 .50242 L
.52469 .49758 L
.52658 .49573 L
.53141 .49312 L
.53235 .49275 L
F
.88 .458 0 r
.54107 .49183 m
.5459 .49073 L
.55073 .48999 L
.55557 .4895 L
.5604 .4892 L
.56523 .48904 L
.57006 .48902 L
.57489 .48914 L
.57973 .48942 L
.58456 .48987 L
.58939 .49058 L
.59422 .49166 L
.59765 .49275 L
.59905 .49324 L
.60388 .49559 L
.60611 .49758 L
.60611 .50242 L
.60388 .50441 L
.59905 .50676 L
.59765 .50725 L
.59422 .50834 L
.58939 .50942 L
.58456 .51013 L
.57973 .51058 L
.57489 .51086 L
.57006 .51098 L
.56523 .51096 L
.5604 .5108 L
.55557 .5105 L
.55073 .51001 L
.5459 .50927 L
.54107 .50817 L
.53809 .50725 L
.53624 .50663 L
.53141 .50436 L
.52912 .50242 L
.52912 .49758 L
.53141 .49564 L
.53624 .49337 L
.53809 .49275 L
F
.91 .355 0 r
.5459 .49254 m
.55073 .49157 L
.55557 .49092 L
.5604 .49053 L
.56523 .49034 L
.57006 .49033 L
.57489 .49051 L
.57973 .49089 L
.58456 .49154 L
.58939 .49254 L
.59018 .49275 L
.59422 .49391 L
.59905 .49616 L
.60077 .49758 L
.60077 .50242 L
.59905 .50384 L
.59422 .50609 L
.59018 .50725 L
.58939 .50746 L
.58456 .50846 L
.57973 .50911 L
.57489 .50949 L
.57006 .50967 L
.56523 .50966 L
.5604 .50947 L
.55557 .50908 L
.55073 .50843 L
.5459 .50746 L
.54508 .50725 L
.54107 .50615 L
.53624 .5041 L
.53399 .50242 L
.53399 .49758 L
.53624 .4959 L
.54107 .49385 L
.54508 .49275 L
F
.94 .244 0 r
.55557 .49273 m
.5604 .49222 L
.56523 .49199 L
.57006 .492 L
.57489 .49226 L
.57946 .49275 L
.57973 .49279 L
.58456 .49358 L
.58939 .49485 L
.59422 .49717 L
.59473 .49758 L
.59473 .50242 L
.59422 .50283 L
.58939 .50515 L
.58456 .50642 L
.57973 .50721 L
.57946 .50725 L
.57489 .50774 L
.57006 .508 L
.56523 .50801 L
.5604 .50778 L
.55557 .50727 L
.55542 .50725 L
.55073 .50653 L
.5459 .50539 L
.54107 .50343 L
.53959 .50242 L
.53959 .49758 L
.54107 .49657 L
.5459 .49461 L
.55073 .49347 L
.55542 .49275 L
F
.97 .126 0 r
.55073 .49583 m
.55557 .49477 L
.5604 .49418 L
.56523 .49392 L
.57006 .49395 L
.57489 .49428 L
.57973 .49498 L
.58456 .49625 L
.58741 .49758 L
.58741 .50242 L
.58456 .50375 L
.57973 .50502 L
.57489 .50572 L
.57006 .50605 L
.56523 .50608 L
.5604 .50582 L
.55557 .50523 L
.55073 .50417 L
.5465 .50242 L
.5465 .49758 L
F
1 0 0 r
.5604 .49695 m
.56523 .49652 L
.57006 .49661 L
.57489 .49728 L
.57621 .49758 L
.57621 .50242 L
.57489 .50272 L
.57006 .50339 L
.56523 .50348 L
.5604 .50305 L
.557 .50242 L
.557 .49758 L
F
0 .01 .1 r
.56523 .4475 m
.57006 .44599 L
.57489 .44515 L
.57973 .44495 L
.58456 .44565 L
.58826 .44927 L
.58456 .45247 L
.57973 .45404 L
.57948 .4541 L
.57489 .45483 L
.57006 .45512 L
.56523 .45487 L
.56109 .4541 L
.56163 .44927 L
F
.56523 .54513 m
.57006 .54488 L
.57489 .54517 L
.57948 .5459 L
.57973 .54596 L
.58456 .54753 L
.58826 .55073 L
.58456 .55435 L
.57973 .55505 L
.57489 .55485 L
.57006 .55401 L
.56523 .5525 L
.56163 .55073 L
.56109 .5459 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`009`3oool3o`0003D0oooo0_l000040?ooo`03o`00003oool0oooo0080
oooo0ol0000b0?ooo`;o0000=@3oool2o`0000@0oooo00?o00000?ooo`3oool00P3oool3o`0003<0
oooo0ol000060?ooo`00:03oool00ol00000oooo0?ooo`0c0?ooo`04o`00003oool0ooooo`0000L0
oooo00Go00000?ooo`3oool0ooooo`00000`0?ooo`04o`00003oool0ooooo`0003<0oooo00Co0000
0?ooo`3ooooo00001`3oool01Ol00000oooo0?ooo`3ooooo000003<0oooo00?o00000?ooo`3oool0
1@3oool00200oooo1Ol000030?ooo`03o`00003oool0oooo02`0oooo1Ol000020?ooo`04o`00003o
ool0ooooo`0000/0oooo00?o00000?ooo`3oool0;P3oool01?l00000oooo0?ooool0000c0?ooo`04
o`00003oool0ooooo`0000/0oooo00?o00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`050?oo
o`00:03oool00ol00000oooo0?ooo`0c0?ooo`04o`00003oool0ooooo`0000/0oooo00?o00000?oo
o`3oool0;P3oool01?l00000oooo0?ooool0000c0?ooo`04o`00003oool0ooooo`0000/0oooo00?o
00000?ooo`3oool0<@3oool00ol00000oooo0?ooo`050?ooo`00:03oool00ol00000oooo0?ooo`0c
0?ooo`04o`00003oool0ooooo`0000L0oooo1?l0000a0?ooo`04o`00003oool0ooooo`0003<0oooo
00Co00000?ooo`3ooooo00001`3oool4o`0003@0oooo00?o00000?ooo`3oool01@3oool002L0oooo
0_l0000e0?ooo`04o`00003oool0ooooo`0000L0oooo00?o00000?ooo`3oool0<P3oool01?l00000
oooo0?ooool0000c0?ooo`04o`00003oool0ooooo`0000L0oooo00?o00000?ooo`3oool0=03oool2
o`0000L0oooo000X0?ooo`03o`00003oool0oooo03@0oooo0_l000080?ooo`Go0000<@3oool2o`00
03D0oooo0_l000080?ooo`Go0000<`3oool00ol00000oooo0?ooo`050?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`008@3oooono`000040oooo000Q0?ooo`03
o`00003oool0oooo0080oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`090?ooo`03
o`00003oool0oooo00T0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`0:0?ooo`03
o`00003oool0oooo00T0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`090?ooo`03
o`00003oool0oooo00T0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`090?ooo`03
o`00003oool0oooo00T0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`090?ooo`03
o`00003oool0oooo00X0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`090?ooo`03
o`00003oool0oooo00T0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`090?ooo`03
o`00003oool0oooo0080oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`03o`00
003oool0oooo03X0oooo00?o00000?ooo`3oool0>P3oool00ol00000oooo0?ooo`0j0?ooo`03o`00
003oool0oooo03T0oooo00?o00000?ooo`3oool00P3oool1o`000040oooo000Q0?ooo`03o`00003o
ool0oooo0?X0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`3j0?ooo`7o00000@3oool0
0240oooo0_l0003j0?ooo`;o00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolD00078ML0
008I20001b450?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolF00078M<0008I
2P001b450?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolF00078M80008I2`00
1b450?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolH00078Ll0008I30001b45
0?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolI00078Ld0008I3@001b450?oo
o`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolJ00078L/0008I3P001b450?ooo`7o
00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolL00078LP0008I3`001b450?ooo`7o0000
0@3oool00240oooo00?o00000?ooo`3oool00P3ooolL00078LL0008I40001b450?ooo`7o00000@3o
ool00240oooo00?o00000?ooo`3oool00P3ooolM00078LD0008I4@001b450?ooo`7o00000@3oool0
0240oooo00?o00000?ooo`3oool00P3oool00`003RP000LQ00078@0K00078L<0008I4P001b450?oo
o`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool3000>:1`000LQ`@000QTC00078@D0
oooo0Ol000010?ooo`008@3oool2o`0000<0oooo10003RPM00078Kd0008I5@001b440?ooo`;o0000
0@3oool00240oooo00?o00000?ooo`3oool00P3oool6000>:1`000LQ^`000QTF00078@D0oooo0Ol0
00010?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`H000hX70001b6k00026AH000LQ1@3oool1
o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo20003RPL00078KP0008I5`001b450?oo
o`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool9000>:1`000LQ]P000QTH00078@D0
oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`/000hX6`001b6c00026AX000LQ
1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo30003RPK00078K40008I6`00
1b450?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool=000>:1/000LQ[`000QTL
00078@D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`h000hX6`001b6]0002
6Ad000LQ1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo3`003RPK00078J/0
008I7P001b450?ooo`7o00000@3oool000P0oooo0_l000040?ooo`03o`00003oool0oooo00<0oooo
0_l000040?ooo`?o0000103oool00ol00000oooo0?ooo`020?oooa8000hX6P001b6X00026Al000LQ
1@3oool1o`000040oooo00070?ooo`04o`00003oool0ooooo`0000P0oooo00Co00000?ooo`3ooooo
0000103oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo0080oooo4`003RPJ00078JH0
008I80001b450?ooo`7o00000@3oool000Go00000P3oool01?l00000oooo0?ooool000080?ooo`05
o`00003oool0ooooo`00003oool01Ol000040?ooo`03o`00003oool0oooo0080oooo50003RPJ0007
8J@0008I8@001b450?ooo`7o00000@3oool000L0oooo00Co00000?ooo`3ooooo0000203oool01_l0
0000oooo0?ooool00000ooooo`000080oooo00?o00000?ooo`3oool00`3oool2o`0000<0oooo5@00
3RPI00078J<0008I8P001b440?ooo`;o00000@3oool000L0oooo00Co00000?ooo`3ooooo0000203o
ool01?l00000oooo0?ooool000020?ooo`03o`00003ooooo000000D0oooo00?o00000?ooo`3oool0
0P3ooolG000>:1P000LQX@000QTS00078@D0oooo0Ol000010?ooo`001`3oool01?l00000oooo0?oo
ool000080?ooo`04o`00003oool0ooooo`0000<0oooo0_l000050?ooo`03o`00003oool0oooo0080
oooo60003RPI00078Ih0008I90001b450?ooo`7o00000@3oool000P0oooo0_l0000:0?ooo`;o0000
1@3oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo0080oooo6@003RPI00078I/0008I
9P001b450?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolK000>:1P000LQV@00
0QTW00078@D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?oooa/000hX6@001b6G
00026BP000LQ1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo7@003RPH0007
8IH0008I:0001b450?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolN000>:1T0
00LQT`000QTY00078@D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?oooal000hX
6@001b6@00026B/000LQ1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo1P00
3RP5000G<1L000hX5`001b6>00026B`000LQ1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0
oooo0080oooo1@003RP9000G<1D000hX5P001b6=00026Bd000LQ1@3oool1o`000040oooo000Q0?oo
o`03o`00003oool0oooo0080oooo1@003RP;000G<1@000hX5P001b6;00026B`000LQ0P003RP50?oo
o`7o00000@3oool00240oooo0_l000030?ooo`D000hX3@005c0C000>:1L000LQR@000QT[00078@<0
00hX103oool2o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo1P003RP>000G<1<000hX
5P001b6600026B/000LQ1@003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3o
ool7000>:0l001L`4P003RPF00078H@0008I:P001b47000>:0D0oooo0Ol000010?ooo`008@3oool0
0ol00000oooo0?ooo`020?ooo`L000hX4@005c0A000>:1H000LQPP000QTZ00078@P000hX1@3oool1
o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo1`003RPB000G<14000hX5P001b600002
6BX000LQ2@003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool8000>:1<0
01L`4@003RPF00078Gd0008I:@001b4;000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo
0?ooo`020?ooo`T000hX50005c0@000>:1H000LQNP000QTY00078@d000hX1@3oool1o`000040oooo
000Q0?ooo`03o`00003oool0oooo0080oooo2P003RPE000G<0l000hX5P001b5h00026BT000LQ3P00
3RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool;000>:1H001L`3P003RPF
00078GH0008I:0001b4@000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?oo
o`/000hX60005c0?000>:1@000LQM0000QTW00078A8000hX1@3oool1o`000040oooo000Q0?ooo`03
o`00003oool0oooo0080oooo30003RPH000G<0h000hX5@001b5c00026BL000LQ4P003RP50?ooo`7o
00000@3oool00240oooo00?o00000?ooo`3oool00P3oool=000>:1T001L`3P003RPD00078G40008I
9P001b4D000>:0D0oooo0Ol000010?ooo`008@3oool2o`0000<0oooo3P003RPI000G<0h000hX5000
1b5^00026BH000LQ5P003RP40?ooo`;o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool>
000>:1/001L`3P003RPC00078F`0008I9P001b4G000>:0D0oooo0Ol000010?ooo`008@3oool00ol0
0000oooo0?ooo`020?ooo`l000hX6`005c0>000>:1@000LQJ@000QTU00078AT000hX1@3oool1o`00
0040oooo000Q0?ooo`03o`00003oool0oooo0080oooo40003RPK000G<0d000hX50001b5X00026BH0
00LQ6@003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool00`001b4000hX
000>:00>000>:1`001L`3@003RPD00078FD0008I9@001b4K000>:0D0oooo0Ol000010?ooo`008@3o
ool00ol00000oooo0?ooo`020?ooo`8000LQ40003RPM000G<0d000hX4`001b5R00026BD000LQ7@00
3RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool300078A0000hX7P005c0<
000>:1<000LQH0000QTU00078Ah000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo
0080oooo10001b4@000>:1l001L`30003RPC00078Ed0008I90001b4P000>:0D0oooo0Ol000010?oo
o`008@3oool00ol00000oooo0?ooo`020?ooo`D000LQ40003RPO000G<0/000hX4`001b5L00026B@0
00LQ8@003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool600078A0000hX
7`005c0<000>:18000LQF`000QTS00078B8000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003o
ool0oooo0080oooo20001b4?000>:20001L`2`003RPB00078ET0008I8P001b4T000>:0D0oooo0Ol0
00010?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`T000LQ3`003RPQ000G<0/000hX40001b5H
00026B4000LQ9P003RP50?ooo`7o00000@3oool00240oooo0_l000030?ooo`T000LQ40003RPQ000G
<0X000hX4@001b5F00026B4000LQ9`003RP40?ooo`;o00000@3oool00240oooo00?o00000?ooo`3o
ool00P3oool;00078@h000hX8`005c09000>:18000LQD`000QTQ00078BP000hX1@3oool1o`000040
oooo000Q0?ooo`03o`00003oool0oooo0080oooo30001b4>000>:28001L`2`003RPA00078E80008I
80001b4Y000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`d000LQ3`00
3RPR000G<0/000hX4@001b5=00026B8000LQ:P003RP50?ooo`7o00000@3oool00240oooo00?o0000
0?ooo`3oool00P3oool>00078@l000hX40005c04000R>0h001L`2`003RPA00078D/0008I8@001b4/
000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`l000LQ3`003RP>000G
<0P0028h3P005c0:000>:18000LQAP000QTR00078Bd000hX1@3oool1o`000040oooo000Q0?ooo`03
o`00003oool0oooo0080oooo4@001b4>000>:0d001L`2`008SP<000G<0/000hX4@001b5300026B40
00LQ<0003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolA00078@l000hX
30005c0=000R>0`001L`2P003RPA00078D40008I8@001b4a000>:0D0oooo0Ol000010?ooo`008@3o
ool00ol00000oooo0?ooo`020?ooo`03000>:0001b4000LQ00l000LQ3`003RP;000G<100028h2`00
5c09000>:14000LQ?`000QTQ00078C8000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0
oooo0080oooo0`003RPA00078@h000hX2`005c0A000R>0/001L`2@003RP?00078Ch0008I8@001b4c
000>:0D0oooo0Ol000010?ooo`00203oool2o`0000@0oooo00?o00000?ooo`3oool00`3oool2o`00
0080oooo1Ol000040?ooo`03o`00003oool0oooo0080oooo1P003RP?00078@h000hX2`005c0C000R
>0T001L`2@003RP>00078Cl0008I7`001b4d000>:0D0oooo0Ol000010?ooo`001`3oool01?l00000
oooo0?ooool000080?ooo`04o`00003oool0ooooo`000080oooo00Co00000?ooo`3ooooo0000103o
ool00ol00000oooo0?ooo`020?ooo`L000hX3`001b4>000>:0X001L`50008SP:000G<0P000hX3@00
1b4o00026Ad000LQ=P003RP50?ooo`7o00000@3oool000Go00000P3oool01?l00000oooo0?ooool0
00080?ooo`04o`00003oool0ooooo`0000<0oooo00?o00000?ooo`3oool0103oool2o`0000<0oooo
2@003RP>00078@l000hX20005c0E000R>0T001L`20003RP>00078Ch0008I70001b4g000>:0@0oooo
0_l000010?ooo`001`3oool01?l00000oooo0?ooool000080?ooo`04o`00003oool0ooooo`0000@0
oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`020?ooo`/000hX3@001b4>000>:0T0
01L`5@008SP9000G<0P000hX3P001b4l00026A`000LQ>0003RP50?ooo`7o00000@3oool000L0oooo
00Co00000?ooo`3ooooo0000203oool01_l00000oooo0?ooool00000ooooo`0000<0oooo00?o0000
0?ooo`3oool00P3oool00ol00000oooo0?ooo`020?ooo`d000hX30001b4>000>:0T001L`5P008SP8
000G<0T000hX3P001b4j00026A/000LQ>@003RP50?ooo`7o00000@3oool000L0oooo00Co00000?oo
o`3ooooo0000203oool01_l00000oooo0?ooool00000ooooo`0000<0oooo00?o00000?ooo`3oool0
0P3oool00ol00000oooo0?ooo`020?ooo`l000hX2`001b4>000>:0X001L`5P008SP8000G<0T000hX
3`001b4d00026Ad000LQ>P003RP50?ooo`7o00000@3oool000P0oooo0_l0000:0?ooo`;o00000`3o
ool3o`0000D0oooo00?o00000?ooo`3oool00P3ooolB000>:0T000LQ3P003RP:000G<1H0028h2@00
5c08000>:14000LQ;P000QTN00078C`000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0
oooo0080oooo50003RP700078@l000hX2P005c0H000R>0P001L`2@003RPA00078BP0008I80001b4m
000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?oooaL000hX10001b4A000>
:0T001L`60008SP9000G<0P000hX4@001b4T00026B4000LQ60003RP8000G<1l000hX1@3oool1o`00
0040oooo000Q0?ooo`03o`00003oool0oooo0080oooo;@003RP9000G<1X0028h20005c08000>:100
00LQ80000QTR00078AH000hX3@005c0N000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo
0?ooo`020?ooobl000hX20005c0L000R>0L001L`20003RP>00078Al0008I8@001b4E000>:14001L`
7@003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool`000>:0P001L`2P00
8SP:000_?`T0028h1P005c08000>:0`000LQ8@000QTO00078A<000hX50005c0M000>:0D0oooo0Ol0
00010?ooo`008@3oool00ol00000oooo0?ooo`020?oooc4000hX1`005c08000R>0h002lo2@008SP6
000G<0H000hX2`001b4U00026A/000LQ4P003RPG000G<1`000hX1@3oool1o`000040oooo000Q0?oo
o`03o`00003oool0oooo0080oooo<P003RP7000G<0P0028h3`00;cl7000R>0H001L`1P003RP;0007
8BH0008I6@001b4@000>:1X001L`70003RP50?ooo`7o00000@3oool00240oooo0_l000030?oooc<0
00hX1`005c07000R>10002lo1`008SP6000G<0H000hX2P001b4V00026AP000LQ40003RPK000G<1`0
00hX103oool2o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo00<000LQ000>:0003RP0
<@003RP6000G<0P0028h4000;cl7000R>0H001L`1P003RP;00078B@0008I60001b4?000>:1`001L`
70003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool200078C<000hX1`00
5c07000R>10002lo1`008SP5000G<0P000hX30001b4Q00026AL000LQ3`003RPM000G<1`000hX1@3o
ool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo0`001b4b000>:0P001L`1`008SP@
000_?`L0028h1`005c07000>:0l000LQ6P000QTH00078@h000hX7`005c0L000>:0D0oooo0Ol00001
0?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`@000LQ<`003RP7000G<0L0028h4000;cl8000R
>0L001L`1`003RPC00078A00008I6P001b4?000>:1l001L`7@003RP50?ooo`7o00000@3oool00240
oooo00?o00000?ooo`3oool00P3oool500078C<000hX1`005c08000R>14002lo20008SP7000G<0P0
00hX5P001b4200026Al000LQ40003RPP000G<1d000hX1@3oool1o`000040oooo000Q0?ooo`03o`00
003oool0oooo0080oooo1P001b4d000>:0L001L`20008SPB000_?`T0028h1P005c08000>:38000LQ
40003RPR000G<1d000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo2000
1b4d000>:0L001L`1`008SPF000_?`L0028h1P005c07000>:2d000LQ40003RPT000G<1h000hX1@3o
ool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo2@001b4e000>:0H001L`1P008SP9
000_?`P003i72@00;cl5000R>0H001L`1@003RP[00078A0000hX9P005c0N000>:0D0oooo0Ol00001
0?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`/000LQ=0003RP6000G<0D0028h1P00;cl@000n
A`L002lo0`008SP5000G<0D000hX30001b4800026AD000LQ3`003RPX000G<1l000hX1@3oool1o`00
0040oooo000Q0?ooo`03o`00003oool0oooo0080oooo2`001b4e000>:0H001L`10008SP6000_?a80
03i71@00;cl4000R>0@001L`1@003RP:00078@/0008I4`001b4>000>:2X001L`7`003RP50?ooo`7o
00000@3oool00240oooo00?o00000?ooo`3oool00P3oool<00078CD000hX1@005c05000R>0D002lo
2000?TL4001?CPL003i71@00;cl3000R>0@001L`1@003RP700078@l0008I4P001b4=000>:0h001L`
2P008SPC000G<1l000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo3@00
1b4e000>:0D001L`1@008SP4000_?`L003i71`00Cdh6000nA`@002lo10008SP3000G<0D000hX1`00
1b4?00026A8000LQ30003RP<000G<0h0028h4`005c0N000>:0D0oooo0Ol000010?ooo`008@3oool2
o`0000<0oooo3P001b4e000>:0D001L`10008SP4000_?`P003i71P00Cdh6000nA`@002lo10008SP4
000G<0D000hX20001b4<00026A<000LQ2`003RP;000G<180028h4P005c0M000>:0@0oooo0_l00001
0?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`l000LQ=@003RP5000G<0D0028h1000;clB000n
A`D002lo10008SP3000G<0D000hX:0001b4:000>:0X001L`4`008SPC000G<1`000hX1@3oool1o`00
0040oooo000Q0?ooo`03o`00003oool0oooo0080oooo3`001b4e000>:0H001L`1@008SP5000_?a00
03i71P00;cl4000R>0D001L`1P003RPS00078@/000hX2@005c0D000R>1H001L`6@003RP50?ooo`7o
00000@3oool00240oooo00?o00000?ooo`3oool00P3oool@00078CD000hX1P005c05000R>0H002lo
3`00?TL6000_?`D0028h1P005c0;000>:1/000LQ2P003RP9000G<1D0028h70005c0C000>:0D0oooo
0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?oooa0000LQ=`003RP6000G<0H0028h1P00
;cl?000nA`L002lo1`008SP8000G<0`000hX40001b4;000>:0P001L`5`008SPQ000G<0h000hX1@3o
ool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo40001b4h000>:0L001L`1P008SP6
000_?a@003i71`00;cl7000R>0L001L`2P003RP900078@/000hX2@005c0I000R>2<001L`30003RP5
0?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool@00078CX000hX20005c05000R
>0D002lo1`00?TL=001?CPP003i71@00;cl4000R>0D001L`2@003RP700078@X000hX20005c0L000R
>2@001L`2`003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool@00078Ch0
00hX1P005c04000R>0@002lo1@00?TL7001?CPX005M:1P00Cdh3000nA`@002lo10008SP4000G<0L0
00hX1P001b49000>:0P001L`7P008SPV000G<0X000hX1@3oool1o`000040oooo000Q0?ooo`03o`00
003oool0oooo0080oooo1`001b58000>:0H001L`10008SP3000_?`@003i71000Cdh5001GBPT005i5
1000EdX4001?CP<003i70`00;cl3000R>0<001L`1`003RP800078@L000hX1@005c09000R>0`002lo
3@008SPV000G<0X000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo0`00
1b5>000>:0D001L`0`008SP3000_?`<003i71000Cdh2001GBPH005i51@00ISd5001NA@<005M:0`00
Cdh2000nA`<002lo0`008SP3000G<0@000hX2`001b46000>:0@001L`1P008SPC000_?`/0028h9`00
5c09000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`<000LQD0003RP4
000G<0<0028h0P00;cl3000nA`<004m>0`00EdX4001NA@X006Hm0`00GTD3001GBP8004m>0P00?TL3
000_?`80028h0`005c03000>:0d000LQ1@003RP4000G<0@0028h2000;cl6000nA`T002lo2P008SPW
000G<0T000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo0P001b4b000>
:0D001L`6P003RP4000G<0<0028h0P00;cl3000nA`8004m>0`00EdX3001NA@`006Hm0`00GTD3001G
BP8004m>0P00?TL2000_?`80028h0`005c02000>:0D000LQ1@000QT500078@@000hX0`005c04000R
>0D002lo3`00?TL7000_?`T0028h9P005c09000>:0D0oooo0Ol000010?ooo`008@3oool2o`0000<0
oooo0P001b4F000>:08000LQ6@003RP8000G<1T000hX10005c02000R>0<002lo0P00?TL3001?CP<0
05M:0`00GTD:001V?@<005i50`00EdX2001?CP8003i70P00;cl2000R>08001L`0`003RP400078@L0
008I1@001b43000>:0<001L`0`008SP4000_?a<003i71P00;cl:000R>2D001L`2@003RP40?ooo`;o
00000@3oool00240oooo00?o00000?ooo`3oool00P3oool200078C8000hX1`005c0I000>:0@001L`
0`008SP3000_?`8003i70`00Cdh4001GBP<005i51P00ISd4001NA@<005M:0P00Cdh2000nA`8002lo
0P008SP3000G<0<000hX1@001b4400026@D000LQ0`003RP3000G<0<0028h0`00;cl5000nA``004m>
1P00?TL6000_?`X0028h90005c09000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?oo
o`020?ooo`<000LQ<P003RP6000G<1T000hX10005c03000R>0<002lo0`00?TL3001?CPD005M:2@00
GTD3001GBP@004m>0P00?TL2000_?`80028h0`005c04000>:0X000LQ10003RP3000G<0<0028h0`00
;cl4000nAa0004m>1P00?TL6000_?`X0028h8`005c09000>:0D0oooo0Ol000010?ooo`008@3oool0
0ol00000oooo0?ooo`020?ooo`@000LQD@003RP4000G<0@0028h0`00;cl4000nA`@004m>3000EdX4
001?CP<003i70`00;cl3000R>0D001L`20003RP4000G<0@0028h1000;cl3000nA`L004m>1`00EdX7
001?CPD003i71`00;cl=000R>1l001L`2@003RP50?ooo`7o00000@3oool00240oooo00?o00000?oo
o`3oool00P3oool600078Dl000hX1P005c04000R>0@002lo1@00?TL@001?CPD003i71`00;cl8000R
>0H002lo1@00?TL5001?CQ0005M:1P00Cdh6000nA`L002lo3P008SPM000G<0T000hX1@3oool1o`00
0040oooo000Q0?ooo`03o`00003oool0oooo0080oooo1`001b5>000>:0P001L`1P008SP5000_?`L0
03i77`00Cdh8001GBQ0005i51`00EdX5001?CPH003i72000;cl@000R>1X001L`2@003RP50?ooo`7o
00000@3oool00240oooo00?o00000?ooo`3oool00P3oool800078D`000hX30005c08000R>0D002lo
1000?TL5001?CPD005M:1P00GTD8001V?A<006hc2000ISd4001NA@D005M:1@00Cdh6000nA`T002lo
40008SPI000G<0T000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo2@00
1b4j000>:2<001L`10008SP4000_?`<003i70`00Cdh2001GBP<005i50P00ISd3001^<`<007DW0`00
OAX500252PX01h`01@00Q@X4001m6P<007DW0`00KS<3001V?@@005i51000EdX5001?CPH003i72P00
;cl@000R>1P001L`2@003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool;
00078CL000hX5`005c0:000>:0H001L`0`008SP2000_?`8003i70`00Cdh00`00EdX005i5001NA@02
001V?@04001^<`00MBL007DW001m6P<008D:00<01h`001ZD000JU0000`0`W00404RS00L0HJ/01018
X`04032L00806Y@000@01h`000252P00Q@X008D:0P00OAX2001e9`8006hc0`00ISd2001NA@@005M:
1000Cdh7000nA`d002lo3P008SPF000G<0X000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003o
ool0oooo0080oooo30001b4e000>:1L001L`3`003RP3000G<080028h0P00;cl2000nA`8004m>00D0
05M:001NA@00ISd006Hm001^<`02001e9`03001m6P00Q@X01h`000806Y@000<0<9`004RS001QZ`00
0`1m/`000`2K^P00^/800;[200020;[200D0b[P01@2j`P000`2K^P00OK<007fc0003066[000304RS
000`W0006Y@000806Y@000@01h`000252P00OAX007dJ0P00MBL00`00KS<006Hm001V?@03001NA@<0
05M:1000Cdh6000nA`l002lo3@008SPF000G<0X000hX1@3oool1o`000040oooo000J0?ooo`;o0000
1@3oool00ol00000oooo0?ooo`020?ooo``000LQ=0003RPH000G<10000hX0P005c02000R>08002lo
00D003i7001?CP00Cdh005M:001NA@02001V?@07001e9`00OAX008D:00252P07S0006Y@004RS0002
066[000407fc002K^P00^/800<Zh00<0dJ<00P3IS@080>5e0080fHd00`3AX`00203:^000^/800;[2
002j`P00VkX007fc001QZ`00B:<00P0`W0000`0JU0001h`000252P02001m6P03001e9`00KS<006hc
008006Hm0P00GTD2001GBP@004m>1`00?TLA000_?``0028h50005c0;000>:0D0oooo0Ol000010?oo
o`006@3oool01?l00000oooo0?ooool000040?ooo`03o`00003oool0oooo0080oooo30001b4d000>
:0X001L`1P008SP8000G<0P000hX10001b44000>:08001L`0P008SP2000_?`03000nA`00Cdh005M:
008005i500l006Hm001^<`00MBL008D:00N<000JU000<9`004RS001QZ`00OK<009^j002j`P00b[P0
0=6S003IS@000`3QM@000`3XFP00l3h00?0n00080?0n00060>QJ003QM@00hGD00>5e003IS@00dJ<0
0P3:^0001@2j`P00VkX007fc001QZ`00B:<00080<9`000@06Y@000N<0000Q@X007dJ0P00MBL00`00
KS<006Hm001V?@02001NA@8005M:1000Cdh7000nAa8002lo2`008SPD000G<0/000hX1@3oool1o`00
0040oooo000I0?ooo`04o`00003oool0ooooo`0000@0oooo0_l000030?ooo``000LQ<`003RP:000G
<0P0028h1`005c06000>:0H000LQ10003RP2000G<080028h0P00;cl05000?TL004m>001GBP00GTD0
06Hm001^<`00MBL007dJ00252P07S000<9`004RS001QZ`00OK<009^j002j`P00b[P00=6S003IS@00
hGD00P3XFP00103`?P00n2000?PP003h80050?l000<0n2000P3`?P002`3XFP00hGD00=V=003IS@00
dJ<00<Zh002j`P00VkX007fc001QZ`00B:<00080<9`000@06Y@000N<0000Q@X007dJ0P00MBL00`00
KS<006Hm001V?@02001NA@8005M:1000Cdh6000nAa<002lo2`008SPD000G<0/000hX103oool2o`00
0040oooo000I0?ooo`04o`00003oool0ooooo`0000@0oooo00?o00000?ooo`3oool00P3oool<0007
8C<000hX2P005c08000R>0L001L`1P003RP600078@@000hX0P005c02000R>08002lo01@003i7001?
CP00EdX005i5001V?@00KS<007DW001m6P00Q@X01h`0032L0018X`00HJ/007fc002K^P00^/800<Zh
003AX`00fHd00>5e0080j5X000@0l3h00?PP003h8000n2001@3o00030?PP0080l3h000/0j5X00>5e
003IS@00fHd00=6S003:^000^/8009^j001m/`00HJ/004RS0002032L000401ZD0007S00008D:001m
6P8007DW00<006hc001V?@00ISd00P00GTD2001GBP@004m>1P00?TLC000_?`/0028h50005c0;000>
:0D0oooo0Ol000010?ooo`006@3oool01?l00000oooo0?ooool000040?ooo`03o`00003oool0oooo
0080oooo30001b4d000>:0X001L`1P008SP8000G<0L000hX1@001b44000>:08001L`0P008SP2000_
?`03000nA`00Cdh005M:008005i500h006Hm001^<`00MBL008D:00N<000JU000<9`004RS001QZ`00
OK<009^j002j`P00b[P00=6S0080fHd000<0hGD00>QJ003XFP000`3`?P050?PP0080l3h00P3XFP02
0>5e00090=V=003AX`00b[P00<Zh002j`P00VkX007fc001QZ`00B:<00080<9`000@06Y@000N<0000
Q@X007dJ0P00MBL00`00KS<006Hm001V?@02001NA@8005M:1000Cdh7000nAa8002lo2`008SPD000G
<0/000hX1@3oool1o`000040oooo000I0?ooo`04o`00003oool0ooooo`0000@0oooo00?o00000?oo
o`3oool00P3oool<00078C@000hX60005c0@000>:08001L`0P008SP2000_?`08000nA`00Cdh004m>
001GBP00GTD006Hm001^<`00MBL2001m6P0300252P07S000<9`00080B:<000@0HJ/007fc002K^P00
^/800P3:^0000`3AX`00fHd00=V=00040>5e0080j5X0103QM@020=V=00<0dJ<000P0b[P00;[2002K
^P00VkX007fc001QZ`00B:<0032L00806Y@000D01h`000252P00OAX007dJ001e9`02001^<`8006Hm
0P00GTD2001GBP@004m>1`00?TLA000_?``0028h50005c0;000>:0D0oooo0Ol000010?ooo`006P3o
ool2o`0000D0oooo00?o00000?ooo`3oool00P3oool<00078CD000hX5`005c0>000>:0@001L`0P00
8SP2000_?`8003i70P00Cdh01000EdX005i5001V?@00KS<2001e9`03001m6P00Q@X01h`000806Y@0
00@0<9`004RS001QZ`00HJ/00P1m/`000`2K^P00^/800;[2000:0<Zh00@0^/8000<0VkX007fc001m
/`000P1QZ`001018X`00<9`0032L000JU00200N<000300252P00OAX007dJ008007DW00<006hc001V
?@00ISd00`00GTD3001GBP@004m>1P00?TL@000_?``0028h5P005c0:000>:0D0oooo0Ol000010?oo
o`008@3oool00ol00000oooo0?ooo`020?ooo`/000LQ=`003RPG000G<0/000hX1@005c03000R>080
02lo0P00?TL3001?CP03001GBP00GTD005i5008006Hm00<006hc001e9`00OAX00P00OAX01000Q@X0
1h`001ZD000JU003032L0080B:<0301QZ`0404RS0080<9`00P0JU00200N<008008D:0P00OAX2001e
9`8006hc0`00ISd2001NA@@005M:1000Cdh7000nA`d002lo3P008SPF000G<0X000hX1@3oool1o`00
0040oooo000Q0?ooo`03o`00003oool0oooo0080oooo2P001b4i000>:2@001L`10008SP3000_?`<0
03i70P00Cdh3001GBP8005i50P00ISd3001^<`8007DW1000OAX200252Q401h`01000Q@X2001m6P@0
07DW0`00KS<3001V?@<005i51000EdX4001?CPL003i72`00;cl?000R>1L001L`2P003RP50?ooo`7o
00000@3oool00240oooo00?o00000?ooo`3oool00P3oool800078D`000hX3@005c07000R>0@002lo
1@00?TL5001?CP@005M:1@00GTD5001V?@T006hc2@00MBL9001^<`D006Hm1@00GTD4001GBPD004m>
1P00?TL9000_?a40028h60005c09000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?oo
o`020?ooo`L000LQCP003RP9000G<0D0028h1P00;cl7000nAaH004m>3@00EdXC001NA@L005M:1@00
Cdh6000nA`P002lo40008SPJ000G<0T000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0
oooo0080oooo1@001b5@000>:0H001L`10008SP5000_?`D003i74000Cdh5000nAa8002lo1P00?TL5
001?CQ4005M:1P00Cdh6000nA`L002lo3`008SPL000G<0T000hX1@3oool1o`000040oooo000Q0?oo
o`03o`00003oool0oooo0080oooo10001b5A000>:0@001L`10008SP3000_?`@003i71@00Cdh:001G
BPD004m>0`00?TL4000_?`<0028h1@005c03000>:0L001L`10008SP4000_?`<003i71`00Cdh8001G
BPL004m>1@00?TL7000_?`d0028h7`005c09000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000
oooo0?ooo`020?ooo`<000LQ<P003RP6000G<1X000hX10005c04000R>08002lo0`00?TL3001?CP@0
05M:2000GTD4001GBP<004m>0`00?TL3000_?`80028h0`005c05000>:0H000LQ1@003RP3000G<0<0
028h0`00;cl4000nAa4004m>1P00?TL7000_?`/0028h8@005c09000>:0D0oooo0Ol000010?ooo`00
8@3oool2o`0000<0oooo0`001b4a000>:0L001L`6@003RP4000G<0<0028h0`00;cl2000nA`<004m>
0`00EdX5001NA@@006Hm1@00GTD2001GBP<004m>0P00?TL2000_?`80028h0`005c03000>:0H000LQ
0P000QT600078@<000hX0`005c03000R>0<002lo1@00?TL<001?CPH003i71P00;cl:000R>2@001L`
2@003RP40?ooo`;o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool200078AH000hX0P00
1b4I000>:0P001L`6@003RP4000G<080028h0`00;cl2000nA`<004m>0`00EdX4001NA@T006Hm0`00
GTD3001GBP8004m>0P00?TL2000_?`80028h0P005c03000>:0@000LQ1`000QT500078@<000hX0`00
5c03000R>0<002lo2000?TL3001?CPT003i71P00;cl:000R>2D001L`2@003RP50?ooo`7o00000@3o
ool00240oooo00?o00000?ooo`3oool00P3oool200078C8000hX1P005c0I000>:0@001L`0`008SP2
000_?`<003i70P00Cdh3001GBP<005i53000ISd3001NA@<005M:0P00Cdh2000nA`8002lo0P008SP3
000G<08000hX1@001b4500026@D000LQ10003RP3000G<0@0028h1000;cl@000nA`L002lo2@008SPV
000G<0T000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo0`001b5@000>
:0@001L`0`008SP2000_?`<003i70`00Cdh2001GBP@005i52`00ISd3001NA@<005M:0P00Cdh2000n
A`<002lo0P008SP3000G<0<000hX3@001b45000>:0@001L`0`008SP8000_?`L003i72@00;cl:000R
>2L001L`2@003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool300078Dh0
00hX1@005c03000R>0<002lo0`00?TL4001?CP8005M:1@00GTD7001V?@@005i50`00EdX3001?CP80
03i70`00;cl3000R>08001L`1@003RP;00078@D000hX1@005c05000R>1@002lo2`008SPW000G<0T0
00hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo1P001b5:000>:0D001L`
10008SP3000_?`@003i70`00Cdh5001GBP/005i51000EdX3001?CP<003i70`00;cl3000R>0<001L`
1P003RP900078@H000hX1P005c08000R>0d002lo3@008SPW000G<0T000hX1@3oool1o`000040oooo
000Q0?ooo`03o`00003oool0oooo0080oooo3`001b4o000>:0H001L`1@008SP3000_?`@003i71`00
Cdh<001GBPH004m>0`00?TL3000_?`@0028h10005c07000>:0L000LQ2@003RP6000G<1l0028h9P00
5c0:000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?oooa0000LQ>`003RP6
000G<0L0028h1000;cl7000nAa0004m>1P00?TL3000_?`D0028h1@005c09000>:0H000LQ2`003RP7
000G<1d0028h90005c0;000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?oo
oa0000LQ>@003RP6000G<0H0028h1P00;clF000nA`H002lo1`008SP6000G<0/000hX2@001b4;000>
:0P001L`6@008SPS000G<0`000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080
oooo40001b4f000>:0L001L`1P008SP6000_?a0003i71`00;cl7000R>0P001L`30003RP?00078@/0
00hX2@005c0F000R>28001L`3@003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool0
0P3oool@00078CD000hX1`005c04000R>0L002lo3P00?TL6000_?`L0028h1P005c0<000>:1L000LQ
2P003RP9000G<1H0028h7@005c0B000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?oo
o`020?ooo`l000LQ=@003RP6000G<0D0028h1@00;clA000nA`D002lo10008SP5000G<0L000hX8P00
1b4;000>:0T001L`50008SPF000G<1T000hX1@3oool1o`000040oooo000Q0?ooo`;o00000`3oool?
00078CD000hX1@005c05000R>0@002lo4P00?TL5000_?`@0028h10005c05000>:2L000LQ2P003RP:
000G<1<0028h4`005c0L000>:0@0oooo0_l000010?ooo`008@3oool00ol00000oooo0?ooo`020?oo
o`h000LQ=@003RP5000G<0@0028h1@00;cl7000nA`H004m>1P00?TL4000_?`@0028h10005c05000>
:0L000LQ3@000QTC00078@/000hX30005c0A000R>18001L`7@003RP50?ooo`7o00000@3oool00240
oooo00?o00000?ooo`3oool00P3oool=00078CD000hX1@005c05000R>0@002lo1`00?TL7001?CPH0
03i71000;cl4000R>0<001L`1@003RP700078@l0008I4P001b4<000>:0`001L`3P008SPC000G<1h0
00hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo30001b4e000>:0D001L`
1@008SP5000_?`P003i71000Cdh7000nA`D002lo0`008SP4000G<0D000hX1`001b4?00026A8000LQ
3@003RP=000G<0/0028h4`005c0O000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?oo
o`020?ooo``000LQ=@003RP5000G<0D0028h1@00;clC000nA`D002lo0`008SP4000G<0D000hX2@00
1b4=00026A8000LQ3P003RPZ000G<1l000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0
oooo0080oooo2P001b4e000>:0H001L`1@008SP6000_?a0003i71P00;cl5000R>0@001L`1@003RP;
00078@P0008I5P001b4>000>:2T001L`7`003RP50?ooo`7o00000@3oool00240oooo00?o00000?oo
o`3oool00P3oool900078CD000hX1P005c06000R>0T002lo2@00?TL8000_?`H0028h1@005c05000>
:2/000LQ3`003RPW000G<1h000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080
oooo20001b4c000>:0P001L`1`008SPF000_?`P0028h1@005c07000>:2d000LQ3`003RPU000G<1h0
00hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo1P001b4d000>:0L001L`
20008SPC000_?`P0028h1P005c08000>:38000LQ40003RPQ000G<1h000hX1@3oool1o`000040oooo
000Q0?ooo`03o`00003oool0oooo0080oooo1P001b4c000>:0L001L`20008SPA000_?`L0028h2000
5c08000>:3H000LQ3`003RPQ000G<1d000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0
oooo0080oooo10001b4d000>:0H001L`20008SP@000_?`P0028h1P005c08000>:1<000LQ3`000QTJ
00078@l000hX7`005c0M000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?oo
o`<000LQ<`003RP7000G<0L0028h4000;cl7000R>0H001L`20003RP@00078AP0008I6@001b4?000>
:1h001L`70003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool200078C<0
00hX1`005c07000R>10002lo1`008SP6000G<0H000hX3@001b4Q00026AL000LQ3`003RPM000G<1`0
00hX1@3oool1o`000040oooo000Q0?ooo`;o00000`3oool00`001b4000hX000>:00a000>:0H001L`
20008SP@000_?`L0028h1P005c06000>:0/000LQ90000QTH00078@l000hX70005c0L000>:0@0oooo
0_l000010?ooo`008@3oool00ol00000oooo0?ooo`020?oooc<000hX1`005c07000R>10002lo1`00
8SP6000G<0H000hX2P001b4V00026AP000LQ40003RPK000G<1`000hX1@3oool1o`000040oooo000Q
0?ooo`03o`00003oool0oooo0080oooo<P003RP7000G<0P0028h3`00;cl8000R>0H001L`1P003RP:
00078BH0008I6@001b4@000>:1X001L`70003RP50?ooo`7o00000@3oool00240oooo00?o00000?oo
o`3oool00P3ooola000>:0P001L`1`008SP?000_?`L0028h1`005c06000>:0/000LQ90000QTL0007
8A8000hX5`005c0L000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?oooc00
00hX20005c0:000R>0/002lo20008SP6000G<0P000hX30001b4Q00026Al000LQ4P003RPE000G<1d0
00hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo;`003RP8000G<0`0028h
1@00;cl;000R>0L001L`20003RP>00078Al0008I8@001b4E000>:14001L`7@003RP50?ooo`7o0000
0@3oool00240oooo00?o00000?ooo`3oool00P3oool]000>:0T001L`6P008SP8000G<0T000hX3`00
1b4P00026B4000LQ5P003RP>000G<1h000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0
oooo0080oooo60003RP300078A8000hX20005c0I000R>0T001L`20003RPA00078B80008I8@001b4H
000>:0X001L`7P003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolD000>
:0L000LQ40003RP9000G<1L0028h2@005c09000>:14000LQ9`000QTP00078A`000hX00<001L`000>
:0003RP07`003RP50?ooo`7o00000@3oool000P0oooo0_l000040?ooo`03o`00003oool0oooo00<0
oooo0_l000020?ooo`Go0000103oool00ol00000oooo0?ooo`020?oooa8000hX2@001b4?000>:0T0
01L`5P008SP8000G<0T000hX4@001b4^00026Ah000LQ?0003RP50?ooo`7o00000@3oool000L0oooo
00Co00000?ooo`3ooooo0000203oool01?l00000oooo0?ooool000020?ooo`04o`00003oool0oooo
o`0000@0oooo00?o00000?ooo`3oool00P3oool?000>:0/000LQ3`003RP9000G<1H0028h20005c09
000>:10000LQ<`000QTM00078CX000hX1@3oool1o`000040oooo00070?ooo`04o`00003oool0oooo
o`0000P0oooo00Co00000?ooo`3ooooo00000`3oool00ol00000oooo0?ooo`040?ooo`03o`00003o
ool0oooo0080oooo3P003RP;00078@h000hX2@005c0F000R>0P001L`20003RP?00078CT0008I7000
1b4i000>:0D0oooo0Ol000010?ooo`001`3oool01?l00000oooo0?ooool000080?ooo`04o`00003o
ool0ooooo`0000@0oooo00?o00000?ooo`3oool00`3oool2o`0000<0oooo30003RP<00078@l000hX
20005c0F000R>0T001L`1`003RP?00078C/0008I70001b4h000>:0@0oooo0_l000010?ooo`001`3o
ool01?l00000oooo0?ooool000080?ooo`06o`00003oool0ooooo`00003ooooo00000`3oool00ol0
0000oooo0?ooo`020?ooo`03o`00003oool0oooo0080oooo2@003RP?00078@h000hX2@005c0E000R
>0T001L`1`003RP>00078Ch0008I70001b4g000>:0D0oooo0Ol000010?ooo`001`3oool01?l00000
oooo0?ooool000080?ooo`06o`00003oool0ooooo`00003ooooo00000`3oool00ol00000oooo0?oo
o`020?ooo`03o`00003oool0oooo0080oooo20003RP?00078@d000hX2P005c0D000R>0T001L`2@00
3RP=00078Cl0008I7@001b4f000>:0D0oooo0Ol000010?ooo`00203oool2o`0000X0oooo0_l00003
0?ooo`?o00001@3oool00ol00000oooo0?ooo`020?ooo`D000hX40001b4>000>:0/001L`4P008SP:
000G<0T000hX3P001b4o00026Al000LQ=0003RP50?ooo`7o00000@3oool00240oooo00?o00000?oo
o`3oool00P3oool3000>:14000LQ3P003RP;000G<180028h2P005c08000>:10000LQ?P000QTQ0007
8C<000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo00<000hX00078@00
1b403`001b4?000>:0/001L`40008SP;000G<0T000hX4@001b4n00026B8000LQ<P003RP50?ooo`7o
00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolB00078@l000hX2`005c0>000R>0/001L`
2P003RPA00078D00008I8P001b4a000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?oo
o`020?oooa0000LQ3`003RP=000G<0X0028h3P005c0:000>:18000LQ@@000QTS00078Bl000hX1@3o
ool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo3`001b4?000>:0h001L`20008SP>
000G<0/000hX4@001b5600026B4000LQ;P003RP50?ooo`7o00000@3oool00240oooo00?o00000?oo
o`3oool00P3oool>00078@l000hX40005c03000R>10001L`2P003RPB00078DT0008I8P001b4/000>
:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`d000LQ3`003RPR000G<0/0
00hX4@001b5=00026B8000LQ:P003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool0
0P3oool<00078@l000hX8P005c0;000>:14000LQD0000QTP00078BX000hX1@3oool1o`000040oooo
000Q0?ooo`;o00000`3oool;00078@l000hX8P005c0:000>:14000LQD`000QTQ00078BP000hX103o
ool2o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo2P001b4?000>:24001L`2`003RP@
00078EH0008I8@001b4W000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`020?oo
o`T000LQ3`003RPQ000G<0/000hX4@001b5G00026B4000LQ9P003RP50?ooo`7o00000@3oool00240
oooo00?o00000?ooo`3oool00P3oool800078@l000hX80005c0;000>:18000LQF0000QTS00078B@0
00hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo1P001b4@000>:20001L`
2`003RPB00078EX0008I8`001b4S000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?oo
o`020?ooo`H000LQ40003RPN000G<0`000hX4`001b5K00026B<000LQ8P003RP50?ooo`7o00000@3o
ool00240oooo00?o00000?ooo`3oool00P3oool400078A0000hX7`005c0<000>:1<000LQG@000QTT
00078B0000hX1@3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo0`001b4@000>
:1h001L`3@003RPC00078El0008I9@001b4N000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000
oooo0?ooo`020?ooo`8000LQ40003RPM000G<0`000hX5@001b5Q00026BD000LQ7@003RP50?ooo`7o
00000@3oool00240oooo00?o00000?ooo`3oool00P3oool00`001b4000hX000>:00>000>:1`001L`
3@003RPD00078FD0008I90001b4L000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?oo
o`020?oooa4000hX6`005c0=000>:1@000LQIP000QTV00078AX000hX1@3oool1o`000040oooo000Q
0?ooo`03o`00003oool0oooo0080oooo3`003RPK000G<0h000hX4`001b5Z00026BD000LQ6@003RP5
0?ooo`7o00000@3oool00240oooo0_l000030?ooo`l000hX6P005c0=000>:1@000LQK0000QTV0007
8AL000hX103oool2o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo3P003RPJ000G<0d0
00hX50001b5^00026BH000LQ5P003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool0
0P3oool=000>:1P001L`3`003RPD00078G40008I9P001b4D000>:0D0oooo0Ol000010?ooo`008@3o
ool00ol00000oooo0?ooo`020?ooo``000hX60005c0>000>:1D000LQLP000QTW00078A<000hX1@3o
ool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo30003RPG000G<0l000hX50001b5d
00026BL000LQ4P003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool;000>
:1H001L`3`003RPE00078GH0008I:0001b4@000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000
oooo0?ooo`020?ooo`X000hX5@005c0@000>:1D000LQN0000QTY00078@h000hX1@3oool1o`000040
oooo000Q0?ooo`03o`00003oool0oooo0080oooo2@003RPE000G<0l000hX5P001b5k00026BP000LQ
3@003RP50?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool8000>:1<001L`4000
3RPG00078Gd0008I:0001b4<000>:0D0oooo0Ol000010?ooo`008@3oool00ol00000oooo0?ooo`02
0?ooo`P000hX4P005c0@000>:1L000LQOP000QTZ00078@X000hX1@3oool1o`000040oooo000Q0?oo
o`03o`00003oool0oooo0080oooo1`003RPA000G<14000hX5P001b6200026BX000LQ20003RP50?oo
o`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3oool7000>:10001L`4@003RPF00078H@0
008I:P001b47000>:0D0oooo0Ol000010?ooo`008@3oool2o`0000<0oooo1P003RP>000G<1<000hX
5P001b6600026B`000LQ10003RP40?ooo`;o00000@3oool00240oooo00?o00000?ooo`3oool00P3o
ool5000>:0d001L`4`003RPF00078HT0008I;0001b43000>:0D0oooo0Ol000010?ooo`008@3oool0
0ol00000oooo0?ooo`020?ooo`D000hX30005c0C000>:1H000LQR`000QT/00078@8000hX1@3oool1
o`000040oooo000Q0?ooo`03o`00003oool0oooo0080oooo1@003RP9000G<1D000hX5`001b6<0002
6B`000LQ00<000hX0?ooo`3oool00`3oool1o`000040oooo000Q0?ooo`03o`00003oool0oooo0080
oooo1P003RP6000G<1H000hX5`001b6>00026B`000LQ1@3oool1o`000040oooo000Q0?ooo`03o`00
003oool0oooo0080oooo80003RPH00078I00008I:`001b450?ooo`7o00000@3oool00240oooo00?o
00000?ooo`3oool00P3ooolO000>:1L000LQU0000QTY00078@D0oooo0Ol000010?ooo`008@3oool0
0ol00000oooo0?ooo`020?oooad000hX60001b6E00026BT000LQ1@3oool1o`000040oooo000Q0?oo
o`03o`00003oool0oooo0080oooo70003RPH00078IL0008I:0001b450?ooo`7o00000@3oool00240
oooo00?o00000?ooo`3oool00P3ooolK000>:1P000LQV@000QTW00078@D0oooo0Ol000010?ooo`00
203oool2o`0000@0oooo00?o00000?ooo`3oool00`3oool2o`0000@0oooo0ol000040?ooo`03o`00
003oool0oooo0080oooo6@003RPI00078I/0008I9P001b450?ooo`7o00000@3oool000L0oooo00Co
00000?ooo`3ooooo0000203oool01?l00000oooo0?ooool000040?ooo`03o`00003oool0oooo00<0
oooo00?o00000?ooo`3oool00P3ooolH000>:1T000LQWP000QTT00078@D0oooo0Ol000010?ooo`00
1`3oool01?l00000oooo0?ooool000080?ooo`05o`00003oool0ooooo`00003oool01Ol000040?oo
o`03o`00003oool0oooo0080oooo5`003RPI00078J00008I8`001b450?ooo`7o00000@3oool000L0
oooo00Co00000?ooo`3ooooo0000203oool01_l00000oooo0?ooool00000ooooo`000080oooo00?o
00000?ooo`3oool00`3oool2o`0000<0oooo5P003RPI00078J40008I8`001b440?ooo`;o00000@3o
ool000L0oooo00Co00000?ooo`3ooooo0000203oool01?l00000oooo0?ooool000020?ooo`03o`00
003ooooo000000D0oooo00?o00000?ooo`3oool00P3ooolD000>:1X000LQY0000QTQ00078@D0oooo
0Ol000010?ooo`001`3oool01?l00000oooo0?ooool000080?ooo`04o`00003oool0ooooo`0000<0
oooo0_l000050?ooo`03o`00003oool0oooo0080oooo4`003RPJ00078JH0008I80001b450?ooo`7o
00000@3oool000P0oooo0_l0000:0?ooo`;o00001@3oool00ol00000oooo0?ooo`030?ooo`03o`00
003oool0oooo0080oooo4P003RPI00078JT0008I7`001b450?ooo`7o00000@3oool00240oooo00?o
00000?ooo`3oool00P3oool@000>:1X000LQZ`000QTN00078@D0oooo0Ol000010?ooo`008@3oool0
0ol00000oooo0?ooo`020?ooo`h000hX6`001b6]00026Ad000LQ1@3oool1o`000040oooo000Q0?oo
o`03o`00003oool0oooo0080oooo3@003RPK00078Jl0008I70001b450?ooo`7o00000@3oool00240
oooo00?o00000?ooo`3oool00P3oool<000>:1`000LQ/0000QTK00078@D0oooo0Ol000010?ooo`00
8@3oool00ol00000oooo0?ooo`020?ooo`/000hX6`001b6c00026AX000LQ1@3oool1o`000040oooo
000Q0?ooo`03o`00003oool0oooo0080oooo2@003RPL00078KH0008I60001b450?ooo`7o00000@3o
ool00240oooo00?o00000?ooo`3oool00P3oool8000>:1`000LQ]`000QTH00078@D0oooo0Ol00001
0?ooo`008@3oool00ol00000oooo0?ooo`020?ooo`L000hX70001b6i00026AL000LQ1@3oool1o`00
0040oooo000Q0?ooo`;o00000`3oool6000>:1`000LQ^`000QTF00078@@0oooo0_l000010?ooo`00
8@3oool00ol00000oooo0?ooo`020?ooo`@000hX7@001b6n00026A@000LQ1@3oool1o`000040oooo
000Q0?ooo`03o`00003oool0oooo0080oooo0`003RPL00078L40008I4`001b450?ooo`7o00000@3o
ool00240oooo00?o00000?ooo`3oool00P3oool00`003RP000LQ00078@0K00078L<0008I4P001b45
0?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolM00078LD0008I4@001b450?oo
o`7o00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolM00078LH0008I40001b450?ooo`7o
00000@3oool00240oooo00?o00000?ooo`3oool00P3ooolL00078LP0008I3`001b450?ooo`7o0000
0@3oool00240oooo00?o00000?ooo`3oool00P3ooolJ00078L/0008I3P001b450?ooo`7o00000@3o
ool00240oooo00?o00000?ooo`3oool00P3ooolI00078Ld0008I3@001b450?ooo`7o00000@3oool0
0240oooo00?o00000?ooo`3oool00P3ooolH00078Ll0008I30001b450?ooo`7o00000@3oool00240
oooo00?o00000?ooo`3oool00P3ooolG00078M40008I2`001b450?ooo`7o00000@3oool00240oooo
00?o00000?ooo`3oool00P3ooolF00078M<0008I2P001b450?ooo`7o00000@3oool00240oooo0_l0
00030?oooa@000LQe`000QT800078@@0oooo0_l000010?ooo`008@3oool00ol00000oooo0?ooo`3j
0?ooo`7o00000@3oool00240oooo00?o00000?ooo`3oool0nP3oool1o`000040oooo000Q0?ooo`03
o`00003oool0oooo0080oooo00?o00000?ooo`3oool0>P3oool00ol00000oooo0?ooo`0j0?ooo`03
o`00003oool0oooo03X0oooo00?o00000?ooo`3oool0>@3oool00ol00000oooo0?ooo`020?ooo`7o
00000@3oool00240oooo00?o00000?ooo`3oool00P3oool00ol00000oooo0?ooo`090?ooo`03o`00
003oool0oooo00T0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`090?ooo`03o`00
003oool0oooo00X0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`090?ooo`03o`00
003oool0oooo00T0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`0:0?ooo`03o`00
003oool0oooo00T0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`090?ooo`03o`00
003oool0oooo00T0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`090?ooo`03o`00
003oool0oooo00T0oooo00?o00000?ooo`3oool02@3oool00ol00000oooo0?ooo`090?ooo`03o`00
003oool0oooo00T0oooo00?o00000?ooo`3oool00P3oool1o`000040oooo000Q0?ooooko00000@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.31197, -0.0613198, \
0.00819863, 0.000409931}},
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
  ButtonData:>"Top",
  ButtonStyle->"Hyperlink"]], "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1087}},
ScreenStyleEnvironment->"Brackets",
PrintingStyleEnvironment->"EnhancedPrintout",
WindowToolbars->"RulerBar",
WindowSize->{1488, 1150},
WindowMargins->{{34, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingStartingPageNumber->132,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {"Customization"}], "Header"]}, {Cell[ 
        TextData[ {"Chapter 4"}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
ShowSelection->True,
CellLabelAutoDelete->False,
DelimiterFlashTime->1,
AutoItalicWords->{
  "Mathematica", "MathLink", "MathSource", "MathReader", "MathScript", 
    "Optica", "Optica2"},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Top"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}]},
  "AOG0."->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[2102, 63, 173, 4, 24, "Outline1",
      CellTags->"AOG0."],
    Cell[2300, 71, 223, 4, 24, "Outline1",
      CellTags->{"AOG2.", "AOG0.", "AOG2.1", "AOG2.2", "AOG2.3"}],
    Cell[2548, 79, 193, 4, 21, "Outline2",
      CellTags->{"AOG2.", "AOG2.1", "AOG0."}],
    Cell[2744, 85, 987, 35, 116, "Outline3",
      CellTags->{"AOG2.", "AOG2.1", "AOG0."}],
    Cell[3768, 125, 206, 4, 21, "Outline2",
      CellTags->{"AOG2.", "AOG2.2", "AOG0."}],
    Cell[3977, 131, 450, 14, 46, "Outline3",
      CellTags->{"AOG2.", "AOG2.2", "AOG0."}],
    Cell[4464, 150, 213, 4, 21, "Outline2",
      CellTags->{"AOG2.", "AOG2.3", "AOG0."}],
    Cell[4680, 156, 518, 18, 60, "Outline3",
      CellTags->{"AOG2.", "AOG2.3", "AOG0."}],
    Cell[5247, 180, 206, 4, 24, "Outline1",
      CellTags->{"AOG3.", "AOG0.", "AOG3.3"}],
    Cell[5456, 186, 299, 10, 38, "Outline2",
      CellTags->{"AOG3.", "AOG0."}],
    Cell[5780, 200, 209, 4, 21, "Outline2",
      CellTags->{"AOG3.", "AOG0.", "AOG3.3"}],
    Cell[5992, 206, 384, 14, 46, "Outline3",
      CellTags->{"AOG0.", "AOG3.3"}],
    Cell[6391, 223, 418, 14, 55, "Outline2",
      CellTags->{"AOG3.", "AOG0."}],
    Cell[6846, 242, 266, 6, 24, "Outline1",
      CellTags->{
      "AOG4.", "AOG0.", "AOG4.1", "AOG4.2", "AOG4.3", "AOG4.4", "AOG4.5", 
        "AOG4.6"}],
    Cell[7115, 250, 183, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0."}],
    Cell[7323, 258, 207, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.2"}],
    Cell[8037, 287, 212, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.3"}],
    Cell[8756, 316, 206, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.4"}],
    Cell[9469, 345, 208, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.5"}],
    Cell[10184, 374, 203, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.6"}],
    Cell[10906, 404, 192, 4, 24, "Outline1",
      CellTags->{"AOG5.", "AOG0."}],
    Cell[11101, 410, 828, 30, 123, "Outline2",
      CellTags->{"AOG5.", "AOG0."}],
    Cell[11966, 445, 241, 4, 24, "Outline1",
      CellTags->{"AOG6.", "AOG0.", "AOG6.2", "AOG6.3", "AOG6.4"}],
    Cell[12210, 451, 183, 4, 21, "Outline2",
      CellTags->{"AOG6.", "AOG0."}],
    Cell[12418, 459, 211, 4, 21, "Outline2",
      CellTags->{"AOG6.", "AOG0.", "AOG6.2"}],
    Cell[12632, 465, 558, 22, 74, "Outline3",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[13227, 492, 211, 4, 21, "Outline2",
      CellTags->{"AOG6.", "AOG0.", "AOG6.3"}],
    Cell[13441, 498, 380, 14, 46, "Outline3",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3"}],
    Cell[13858, 517, 229, 4, 21, "Outline2",
      CellTags->{"AOG6.", "AOG6.4", "AOG0."}],
    Cell[14090, 523, 953, 34, 116, "Outline3",
      CellTags->{"AOG6.", "AOG6.4", "AOG0."}],
    Cell[15104, 564, 71, 1, 61, "Section",
      CellTags->{"1", "AOG1.", "AOG0."}],
    Cell[15178, 567, 426, 12, 22, "Text",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[15607, 581, 142, 4, 22, "Text",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[15774, 589, 71, 1, 32, "Subsubsection",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[15848, 592, 150, 5, 22, "Text",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[16023, 601, 98, 2, 27, "Input",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[16124, 605, 111, 2, 20, "Print",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[16238, 609, 202, 4, 20, "Print",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[16455, 616, 127, 3, 22, "Text",
      CellTags->"AOG0."],
    Cell[16631, 625, 95, 1, 61, "Section",
      CellTags->{"AOG0.", "2", "AOG2."}],
    Cell[16751, 630, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.1", "AOG2.", "AOG2.1"}],
    Cell[16859, 635, 100, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.1", "AOG2.", "AOG2.1", "AOG2.1.1"}],
    Cell[16962, 638, 1992, 55, 88, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.1"}],
    Cell[18979, 697, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.1"}],
    Cell[19091, 701, 485, 8, 65, "Print",
      CellTags->{
      "Info3312042809-6749329", "AOG2.", "AOG2.1", "AOG2.1.1", "AOG0."}],
    Cell[19625, 715, 118, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.2", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[19746, 718, 664, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[20435, 737, 146, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[20584, 741, 279, 8, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[20878, 752, 701, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[21604, 771, 243, 7, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[21850, 780, 367, 10, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[22232, 793, 412, 10, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[22669, 807, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[22783, 811, 228, 5, 19, "Message",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[23014, 818, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[23147, 824, 198, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[23370, 833, 207, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[23580, 840, 347, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[23942, 852, 595, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[24562, 871, 229, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[24794, 880, 872, 27, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[25681, 910, 361, 10, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[26067, 924, 183, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[26253, 931, 10518, 262, 285, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[36786, 1196, 204, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[37015, 1205, 144, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[37162, 1209, 24034, 773, 134, 9878, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[61199, 1984, 495, 11, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[61697, 1997, 141, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[61853, 2003, 253, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[62131, 2012, 220, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[62354, 2021, 908, 27, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[63299, 2053, 164, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[63466, 2059, 1327, 25, 95, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[64808, 2087, 299, 8, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[65132, 2099, 176, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[65311, 2105, 72323, 2564, 152, 32608, 2068, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[137637, 4671, 588, 13, 35, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[138228, 4686, 143, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[138386, 4692, 158, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.2"}],
    Cell[138581, 4700, 111, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.3", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[138695, 4703, 1624, 33, 86, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[140322, 4738, 780, 13, 54, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[141105, 4753, 1236, 21, 70, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[142344, 4776, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.3"}],
    Cell[142541, 4784, 131, 1, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "2.1.4", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[142675, 4787, 641, 13, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[143341, 4804, 329, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[143673, 4815, 18991, 659, 110, 8702, 527, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[162667, 5476, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[162954, 5486, 341, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[163298, 5497, 20462, 730, 110, 9828, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[183763, 6229, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[184050, 6239, 339, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[184392, 6250, 20821, 734, 110, 9839, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[205216, 6986, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[205481, 6994, 527, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[206011, 7005, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.3"}],
    Cell[206208, 7013, 112, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.5", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[206323, 7016, 876, 22, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[207224, 7042, 118, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[207345, 7046, 2749, 52, 129, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[210109, 7101, 915, 21, 56, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[211049, 7126, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[211160, 7130, 279, 5, 50, "Print",
      CellTags->{
      "Info3312042819-8757440", "AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[211476, 7140, 343, 10, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[211822, 7152, 20450, 730, 110, 9828, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[232275, 7884, 1016, 18, 88, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[233294, 7904, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[233448, 7912, 160, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[233611, 7919, 346, 6, 19, "Message",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[233960, 7927, 343, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[234306, 7936, 1745, 29, 131, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[236054, 7967, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[236186, 7973, 294, 8, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[236505, 7985, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[236616, 7989, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[236749, 7995, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.5"}],
    Cell[236946, 8003, 114, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.6", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[237063, 8006, 580, 11, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[237668, 8021, 293, 8, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[237964, 8031, 141, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238108, 8036, 147, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238258, 8041, 194, 4, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238455, 8047, 171, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238629, 8052, 233, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238865, 8059, 374, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[239242, 8069, 565, 11, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[239810, 8082, 305, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240118, 8090, 267, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240388, 8097, 233, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240624, 8104, 359, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240986, 8113, 565, 11, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[241554, 8126, 306, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[241863, 8134, 267, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[242133, 8141, 233, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[242369, 8148, 359, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[242731, 8157, 295, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243029, 8165, 306, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243338, 8173, 267, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243608, 8180, 360, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243971, 8190, 154, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[244128, 8195, 229, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[244360, 8202, 241, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[244604, 8209, 454, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[245061, 8221, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[245537, 8233, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[245925, 8243, 457, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[246385, 8254, 489, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[246877, 8266, 410, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[247290, 8277, 480, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[247773, 8289, 497, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[248273, 8301, 418, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[248694, 8312, 435, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[249132, 8323, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[249602, 8335, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[249984, 8345, 452, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[250439, 8357, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[250911, 8369, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[251295, 8379, 241, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[251539, 8386, 454, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[251996, 8398, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[252472, 8410, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[252860, 8420, 466, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[253329, 8432, 489, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[253821, 8444, 410, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[254234, 8455, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[254732, 8467, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[255151, 8478, 433, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[255587, 8489, 465, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[256055, 8501, 377, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[256435, 8511, 450, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[256888, 8523, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[257360, 8535, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[257744, 8545, 241, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[257988, 8552, 454, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[258445, 8564, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[258921, 8576, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[259309, 8586, 466, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[259778, 8598, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[260272, 8610, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[260687, 8621, 435, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[261125, 8632, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[261595, 8644, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[261977, 8654, 450, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[262430, 8666, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[262902, 8678, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[263286, 8688, 498, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[263787, 8700, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[264206, 8711, 488, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[264697, 8723, 406, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[265106, 8734, 474, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[265583, 8746, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[265969, 8756, 476, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[266448, 8768, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[266836, 8778, 344, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[267183, 8787, 303, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[267489, 8795, 139, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[267631, 8800, 1172, 20, 88, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[268840, 8825, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[268951, 8829, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[269083, 8835, 445, 10, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[269553, 8849, 267, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[269823, 8859, 1727, 28, 194, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[271565, 8890, 301, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[271891, 8900, 312, 8, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[272206, 8910, 141, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[272350, 8915, 483, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[272836, 8927, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[273243, 8938, 509, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[273755, 8950, 432, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[274190, 8961, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[274684, 8973, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[275099, 8984, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[275597, 8996, 418, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[276018, 9007, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[276516, 9019, 418, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[276937, 9030, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[277409, 9042, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[277795, 9052, 465, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[278263, 9064, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[278645, 9074, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[279121, 9086, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[279509, 9096, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[279981, 9108, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[280367, 9118, 521, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[280891, 9130, 442, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[281336, 9141, 483, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[281822, 9153, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[282229, 9164, 509, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[282741, 9176, 430, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[283174, 9187, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[283668, 9199, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[284083, 9210, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[284581, 9222, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[285000, 9233, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[285498, 9245, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[285917, 9256, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[286389, 9268, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[286773, 9278, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[287243, 9290, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[287625, 9300, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[288101, 9312, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[288487, 9322, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[288961, 9334, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[289347, 9344, 521, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[289871, 9356, 442, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[290316, 9367, 483, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[290802, 9379, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[291209, 9390, 509, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[291721, 9402, 430, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[292154, 9413, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[292648, 9425, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[293063, 9436, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[293561, 9448, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[293980, 9459, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[294478, 9471, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[294897, 9482, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[295367, 9494, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[295749, 9504, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[296219, 9516, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[296601, 9526, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[297077, 9538, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[297463, 9548, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[297937, 9560, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[298323, 9570, 521, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[298847, 9582, 442, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[299292, 9593, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[299766, 9605, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[300152, 9615, 489, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[300644, 9627, 410, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[301057, 9638, 465, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[301525, 9650, 377, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[301905, 9660, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[302377, 9672, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[302761, 9682, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[303235, 9694, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[303621, 9704, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[304115, 9716, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[304530, 9727, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[305000, 9739, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[305382, 9749, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[305854, 9761, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[306238, 9771, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[306712, 9783, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[307098, 9793, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[307592, 9805, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[308007, 9816, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[308477, 9828, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[308859, 9838, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[309331, 9850, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[309715, 9860, 498, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[310216, 9872, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[310635, 9883, 488, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[311126, 9895, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[311533, 9906, 474, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[312010, 9918, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[312396, 9928, 476, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[312875, 9940, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[313263, 9950, 139, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[313405, 9955, 1101, 20, 113, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[314521, 9978, 283, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[314829, 9988, 177, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[315009, 9994, 1686, 29, 111, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[316710, 10026, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.6"}],
    Cell[316907, 10034, 108, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7", "2.1.7"}],
    Cell[317018, 10037, 526, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[317569, 10050, 337, 10, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[317909, 10062, 22699, 836, 110, 11522, 692, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[340611, 10900, 2909, 48, 205, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[343535, 10951, 253, 5, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[343813, 10960, 389, 12, 155, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[344205, 10974, 40769, 1619, 159, 22270, 1385, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[384977, 12595, 3259, 51, 206, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[388251, 12649, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.7"}],
    Cell[388448, 12657, 119, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8", "2.1.8"}],
    Cell[388570, 12660, 366, 7, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[388961, 12671, 360, 10, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[389324, 12683, 43019, 1385, 257, 15999, 1046, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[432346, 14070, 1492, 27, 145, "Output",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[433853, 14100, 563, 14, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[434441, 14118, 162, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[434606, 14125, 566, 9, 65, "Print",
      CellTags->{
      "Info3312042871-8199869", "AOG2.", "AOG2.1", "AOG2.1.8", "AOG0."}],
    Cell[435209, 14139, 366, 10, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[435578, 14151, 20370, 730, 110, 9744, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[455951, 14883, 1831, 30, 145, "Output",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[457797, 14916, 492, 15, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[458292, 14933, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.8"}],
    Cell[458501, 14942, 96, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.2", "AOG2.", "AOG2.2"}],
    Cell[458600, 14945, 525, 12, 36, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2"}],
    Cell[459150, 14961, 128, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.2.1", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[459281, 14964, 723, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460007, 14981, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460121, 14985, 267, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460391, 14994, 268, 5, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460684, 15003, 192, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460879, 15010, 23289, 697, 130, 7253, 493, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[484183, 15710, 551, 12, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[484759, 15726, 246, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[485008, 15734, 552, 10, 77, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[485575, 15747, 482, 11, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[486082, 15762, 152, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[486237, 15766, 1723, 24, 185, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[487975, 15793, 158, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[488158, 15801, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[488300, 15805, 71910, 1447, 240, 21739, 822, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[560225, 17255, 196, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[560446, 17263, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[560570, 17267, 1525, 21, 185, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[562132, 17293, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[562256, 17297, 1494, 22, 185, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[563765, 17322, 255, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[564045, 17332, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[564185, 17336, 5152, 92, 129, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[569352, 17431, 378, 6, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[569755, 17441, 230, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[569988, 17449, 225, 4, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[570228, 17456, 287, 7, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[570540, 17467, 261, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[570804, 17475, 76731, 5322, 130, 64916, 5171, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[647538, 22799, 426, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[647979, 22811, 667, 11, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[648671, 22826, 244, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[648918, 22834, 1029, 19, 73, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[649962, 22856, 200, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[650187, 22864, 184, 3, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[650374, 22869, 5263, 73, 617, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[655652, 22945, 300, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[655977, 22955, 245, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[656225, 22963, 221, 4, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[656461, 22970, 419, 8, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[656905, 22982, 259, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[657167, 22990, 76745, 5322, 130, 64930, 5171, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[733915, 28314, 425, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[734355, 28326, 441, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[734821, 28337, 260, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[735084, 28345, 315480, 24523, 130, 303636, 24371, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[1050567, 52870, 424, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[1051006, 52882, 188, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[1051197, 52888, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.2", "AOG2.", "AOG2.2.1"}],
    Cell[1051394, 52896, 126, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2", "2.2.2"}],
    Cell[1051523, 52899, 815, 13, 52, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1052341, 52914, 301, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1052667, 52926, 172, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1052842, 52932, 39451, 2840, 64, 34309, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1092308, 55775, 399, 12, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1092732, 55791, 288, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1093023, 55799, 938, 17, 88, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1093976, 55819, 216, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1094217, 55827, 176, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1094396, 55833, 28646, 598, 184, 4073, 289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1123057, 56434, 487, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1123547, 56445, 193, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1123765, 56454, 186, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1123954, 56461, 7133, 104, 324, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1131102, 56568, 191, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1131318, 56577, 206, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1131527, 56585, 24152, 606, 184, 5492, 370, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1155694, 57194, 186, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1155905, 57202, 117, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1156025, 57206, 27273, 690, 184, 6378, 427, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1183313, 57899, 504, 8, 36, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1183842, 57911, 274, 7, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1184119, 57920, 3410, 47, 401, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1187566, 57972, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1187777, 57978, 3008, 42, 365, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1190822, 58025, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1191033, 58031, 3054, 42, 365, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1194124, 58078, 378, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1194527, 58090, 252102, 6207, 240, 177264, 5277, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1446632, 64299, 302511, 6827, 240, 177429, 5277, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1749146, 71128, 278598, 6544, 240, 177380, 5289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[2027747, 77674, 1438537, 71956, 261, 1301290, 70256, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3466333, 149636, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3466473, 149640, 9632, 174, 234, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3476142, 149819, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3476256, 149823, 115, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3476386, 149829, 199, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3476610, 149839, 258, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3476871, 149850, 293, 6, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3477201, 149861, 200, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3477426, 149871, 38782, 2831, 64, 34341, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3516211, 152704, 39691, 2844, 64, 34229, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3555917, 155551, 946, 17, 54, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3556878, 155571, 277, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3557180, 155582, 195, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3557378, 155589, 295, 5, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3557710, 155599, 150, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3557863, 155603, 39799, 2844, 64, 34345, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3597665, 158449, 424, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3598104, 158461, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.2", "AOG2.", "AOG2.2.2"}],
    Cell[3598301, 158469, 107, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.2.3", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3598411, 158472, 373, 6, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3598787, 158480, 574, 10, 85, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599364, 158492, 175, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599542, 158498, 108, 1, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599675, 158503, 166, 3, 25, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599844, 158508, 28599, 1237, 86, 18759, 1110, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3628480, 159750, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3628622, 159754, 132, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3628791, 159762, 140, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3628934, 159766, 132, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3629103, 159774, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3629214, 159778, 521, 12, 35, "Print",
      CellTags->{
      "Info3312042947-9251066", "AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3629772, 159795, 165, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3629940, 159801, 117, 3, 38, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3630094, 159809, 156, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3630253, 159813, 117, 3, 38, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3630385, 159819, 391, 8, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3630801, 159831, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3630913, 159835, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3631067, 159843, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3631179, 159847, 2067, 38, 214, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3633283, 159890, 168, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3633454, 159896, 140, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3633631, 159904, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3633755, 159908, 119, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3633911, 159916, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3634035, 159920, 12755, 207, 1238, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3646827, 160132, 260, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3647090, 160140, 258, 5, 26, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3647385, 160150, 344, 12, 155, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3647732, 160164, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3647887, 160172, 269, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3648159, 160180, 254, 5, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3648450, 160190, 155, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3648608, 160197, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3648763, 160205, 155, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3648921, 160212, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3649076, 160220, 155, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3649234, 160227, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3649389, 160235, 148, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3649540, 160239, 47437, 819, 1149, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3697014, 161063, 112, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3697129, 161067, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3697283, 161075, 255, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3697541, 161085, 508, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3698086, 161099, 276, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3698365, 161109, 3592, 63, 129, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3701994, 161177, 525, 11, 139, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3702544, 161192, 18991, 786, 86, 11568, 689, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3721538, 161980, 19404, 805, 86, 11762, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3740945, 162787, 17533, 725, 86, 10993, 639, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3758481, 163514, 21004, 843, 86, 12058, 727, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3779488, 164359, 22226, 965, 86, 13636, 853, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3801717, 165326, 24095, 1034, 86, 14388, 909, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3825815, 166362, 18228, 740, 86, 11141, 647, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3844046, 167104, 25166, 1090, 86, 15289, 963, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3869215, 168196, 24747, 1071, 86, 15113, 947, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3893965, 169269, 25378, 1114, 86, 15849, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3919346, 170385, 25093, 1076, 86, 15118, 947, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3944442, 171463, 23817, 1008, 86, 13964, 881, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3968262, 172473, 25725, 1085, 86, 14989, 947, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3993990, 173560, 22928, 1085, 86, 15776, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4016921, 174647, 24033, 1099, 86, 15767, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4040957, 175748, 21595, 980, 86, 14014, 881, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4062555, 176730, 23316, 1089, 86, 15800, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4085874, 177821, 23217, 980, 86, 13708, 857, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4109094, 178803, 24174, 1099, 86, 15844, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4133271, 179904, 23922, 1075, 86, 15288, 963, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4157196, 180981, 24420, 1103, 86, 15830, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4181619, 182086, 24090, 1067, 86, 15136, 951, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4205712, 183155, 17283, 700, 86, 10686, 613, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4222998, 183857, 17236, 713, 86, 10910, 629, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4240237, 184572, 20490, 947, 86, 13678, 857, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4260730, 185521, 22588, 1004, 86, 14387, 897, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4283321, 186527, 22189, 967, 86, 13693, 857, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4305525, 187497, 10122, 191, 414, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4315684, 187693, 206, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[4315893, 187701, 310, 5, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4316240, 187711, 531, 13, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[4316774, 187726, 29237, 1570, 86, 21628, 1471, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4346014, 189298, 428, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4346479, 189312, 479, 13, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[4346961, 189327, 428, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4347404, 189339, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.2.3", "AOG2.2", "AOG2."}],
    Cell[4347613, 189348, 119, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.3", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4347757, 189353, 101, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.1", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4347883, 189358, 160, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348046, 189364, 165, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4348226, 189370, 231, 7, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348460, 189379, 180, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348665, 189387, 167, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348835, 189393, 31520, 1334, 159, 20081, 1187, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4380370, 190730, 184, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4380579, 190739, 131, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4380713, 190743, 418, 7, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4381168, 190755, 202, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4381373, 190763, 13835, 365, 184, 3130, 227, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4395223, 191131, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.3", "AOG2."}],
    Cell[4395408, 191139, 116, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.2", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4395549, 191144, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4395673, 191148, 42033, 1026, 296, 7262, 591, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4437709, 192176, 922, 21, 39, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4438668, 192202, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4438847, 192208, 42773, 1154, 184, 9613, 739, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4481623, 193364, 60297, 1107, 184, 6603, 439, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4541969, 194477, 135, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4542107, 194481, 36182, 848, 184, 6910, 481, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4578304, 195332, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.3", "AOG2."}],
    Cell[4578489, 195340, 104, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.3", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4578618, 195345, 280, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4578901, 195353, 319, 6, 26, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4579257, 195364, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4579399, 195368, 23061, 533, 184, 4091, 293, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4602497, 195906, 118, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4602618, 195910, 23167, 551, 184, 4496, 315, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4625822, 196466, 116, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4625941, 196470, 342, 6, 26, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4626298, 196479, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4626440, 196483, 144, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4626609, 196489, 168, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4626780, 196495, 28051, 731, 184, 6546, 460, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4654868, 197231, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4655001, 197235, 1609, 28, 94, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4656647, 197268, 145, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4656795, 197272, 402, 7, 23, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4657200, 197281, 401, 7, 23, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4657604, 197290, 401, 7, 23, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4658008, 197299, 247, 5, 19, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4658258, 197306, 19539, 493, 184, 4204, 298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4677812, 197802, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.3", "AOG2."}],
    Cell[4677997, 197810, 116, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.4", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678116, 197813, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678273, 197817, 380, 15, 203, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678678, 197836, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678807, 197840, 1462, 26, 198, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4680306, 197871, 116, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4680425, 197875, 652, 13, 39, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4681114, 197893, 197, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4681314, 197900, 132, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4681461, 197906, 120, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4681606, 197912, 142, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4681751, 197916, 29725, 703, 184, 5721, 401, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4711513, 198624, 153, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4711669, 198628, 134, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4711840, 198636, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4711997, 198640, 20416, 550, 184, 4840, 352, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4732450, 199195, 138, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4732591, 199199, 46075, 859, 377, 4774, 344, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4778703, 200063, 166, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4778872, 200069, 21023, 472, 184, 3388, 249, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4799910, 200544, 276, 6, 34, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4800211, 200554, 203, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4800417, 200561, 1857010, 45857, 240, 1775535, 44846, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[6657464, 246423, 277, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[6657744, 246431, 706903, 40556, 294, 616171, 39430, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[7364684, 286992, 279, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[7364966, 287000, 476455, 6607, 294, 247926, 3780, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[7841436, 293610, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.3", "AOG2."}],
    Cell[7841645, 293620, 99, 1, 61, "Section",
      CellTags->{"AOG0.", "3", "AOG3."}],
    Cell[7841769, 293625, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.1", "AOG3.", "AOG3.1"}],
    Cell[7841877, 293630, 101, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7842346, 293644, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7843275, 293664, 351, 9, 91, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7843651, 293677, 141, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7876596, 295131, 154, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7878189, 295167, 176, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7902110, 295742, 193, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7905389, 295828, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3."}],
    Cell[7905564, 295836, 99, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.2", "AOG3.", "AOG3.2"}],
    Cell[7905666, 295839, 228, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
    Cell[7905919, 295850, 131, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
    Cell[7936780, 296951, 177, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
    Cell[7937375, 296972, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
    Cell[7937827, 296988, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3."}],
    Cell[7938002, 296996, 111, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.3", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7938231, 297004, 302, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7938558, 297016, 143, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7959627, 297760, 209, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7963189, 297859, 250, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7967243, 297970, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3.3", "AOG3."}],
    Cell[7967523, 297981, 327, 9, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7967875, 297994, 150, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7988803, 298719, 224, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7994870, 298879, 267, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7997236, 298928, 214, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7998052, 298951, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3.3", "AOG3."}],
    Cell[7998335, 298962, 366, 9, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[7998704, 298973, 353, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[7999082, 298985, 151, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8001383, 299049, 149, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8002183, 299069, 403, 9, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8002611, 299082, 129, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8031110, 299888, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8033589, 299956, 194, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8034507, 299982, 192, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8035081, 300003, 185, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8038995, 300113, 204, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8044975, 300273, 179, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8046350, 300314, 200, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8048903, 300374, 221, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8054708, 300524, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3.3", "AOG3."}],
    Cell[8054905, 300533, 97, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.4", "AOG3.", "AOG3.4"}],
    Cell[8055005, 300536, 283, 7, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8055313, 300547, 131, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8055447, 300551, 21420, 742, 110, 9782, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8076904, 301298, 234, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8077141, 301305, 1133, 18, 142, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8078311, 301328, 244, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8078558, 301336, 1349, 25, 73, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8079944, 301366, 110, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8080057, 301370, 360, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8080454, 301384, 105, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8080562, 301388, 724, 15, 73, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8081323, 301408, 110, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8081436, 301412, 517, 12, 59, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8081968, 301427, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3."}],
    Cell[8082143, 301435, 106, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.5", "AOG3.", "AOG3.5"}],
    Cell[8082252, 301438, 187, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8082464, 301448, 129, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8096819, 301922, 176, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8097387, 301943, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8097841, 301961, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8098282, 301977, 197, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8098504, 301987, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8116015, 302547, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8129362, 302937, 181, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8129983, 302959, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8130442, 302977, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8130912, 302995, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8131358, 303011, 242, 8, 24, "Text",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8131603, 303021, 211, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8131839, 303031, 129, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8146846, 303555, 164, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8147402, 303575, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8147856, 303593, 197, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8150614, 303673, 148, 4, 24, "Text",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8150765, 303679, 241, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8151031, 303689, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8172947, 304249, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8174744, 304307, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8175919, 304345, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3."}],
    Cell[8176094, 304353, 91, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.6", "AOG3.", "AOG3.6"}],
    Cell[8176210, 304358, 93, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8179054, 304402, 328, 8, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8179407, 304414, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8179547, 304418, 23532, 617, 240, 7151, 409, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.6", "AOG0."}],
    Cell[8203116, 305040, 105, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8203224, 305044, 196, 4, 24, "Output",
      CellTags->{"AOG3.", "AOG3.6", "AOG0."}],
    Cell[8203457, 305053, 275, 7, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8203735, 305062, 901, 22, 75, "Output",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8204673, 305089, 105, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8204781, 305093, 393, 9, 85, "Output",
      CellTags->{"AOG3.", "AOG3.6", "AOG0."}],
    Cell[8205211, 305107, 271, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8205485, 305115, 314, 9, 49, "Output",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8205836, 305129, 185, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8206024, 305136, 1403, 23, 84, "Output",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8207442, 305162, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3."}],
    Cell[8207629, 305171, 110, 1, 61, "Section",
      CellTags->{"AOG0.", "4", "AOG4.", "AOG4.1"}],
    Cell[8207764, 305176, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.1", "AOG4.", "AOG4.1"}],
    Cell[8207872, 305181, 99, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8208442, 305196, 107, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8209274, 305216, 96, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8209373, 305220, 1395, 19, 155, "Print",
      CellTags->{"Info3405686992-9872384", "AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8210805, 305244, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8211805, 305268, 98, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8215462, 305324, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8216443, 305345, 331, 9, 59, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8216799, 305358, 165, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8374574, 309429, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG4."}],
    Cell[8374749, 309437, 109, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.2", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8374883, 309442, 94, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.2.1", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8374980, 309445, 337, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8375342, 309457, 153, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8412309, 311031, 204, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8415724, 311120, 255, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8419039, 311212, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2"}],
    Cell[8419224, 311220, 101, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.2.2", "AOG4.", "AOG4.2", "AOG4.2.2"}],
    Cell[8419350, 311225, 134, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.2"}],
    Cell[8423650, 311303, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2"}],
    Cell[8423835, 311311, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.2.3", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8423960, 311316, 133, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8465883, 312230, 176, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8506877, 313132, 185, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8590229, 315019, 199, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8693297, 317850, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2"}],
    Cell[8693482, 317858, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.2.4", "AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8693607, 317863, 176, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8776692, 321260, 179, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8863057, 324901, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2"}],
    Cell[8863254, 324910, 114, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.3", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863393, 324915, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.1", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863490, 324918, 327, 9, 96, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863842, 324931, 139, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8974103, 326998, 244, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8977970, 327108, 245, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8981842, 327216, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3"}],
    Cell[8982027, 327224, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.2", "AOG4.", "AOG4.3", "AOG4.3.2"}],
    Cell[8982153, 327229, 138, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.2"}],
    Cell[8986703, 327311, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3"}],
    Cell[8986888, 327319, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.3", "AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[8987013, 327324, 137, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[9064736, 329069, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3"}],
    Cell[9064921, 329077, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.4", "AOG4.", "AOG4.3", "AOG4.3.4"}],
    Cell[9065046, 329082, 191, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.4"}],
    Cell[9411718, 348492, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3"}],
    Cell[9411915, 348501, 108, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.4", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412048, 348506, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.1", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412145, 348509, 338, 8, 96, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412508, 348521, 132, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9505752, 350428, 202, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9511034, 350566, 181, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9512513, 350606, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4"}],
    Cell[9512698, 350614, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.2", "AOG4.", "AOG4.4", "AOG4.4.2"}],
    Cell[9512824, 350619, 131, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.2"}],
    Cell[9519322, 350738, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4"}],
    Cell[9519507, 350746, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.3", "AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9519632, 350751, 131, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9603206, 352620, 181, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9769908, 356400, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4"}],
    Cell[9770093, 356408, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.4", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9770218, 356413, 176, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9858571, 361323, 177, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9949546, 366262, 149, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[10098943, 377626, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4"}],
    Cell[10099140, 377635, 110, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.5", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099275, 377640, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.1", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099372, 377643, 346, 8, 79, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099743, 377655, 129, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10138147, 378626, 181, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10142315, 378740, 178, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10143217, 378762, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5"}],
    Cell[10143402, 378770, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.2", "AOG4.", "AOG4.5", "AOG4.5.2"}],
    Cell[10143528, 378775, 128, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.2"}],
    Cell[10148102, 378857, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5"}],
    Cell[10148287, 378865, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.3", "AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10148412, 378870, 128, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10212269, 380371, 177, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10352665, 383593, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5"}],
    Cell[10352850, 383601, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.4", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10352975, 383606, 173, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10442480, 387428, 174, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10560711, 391606, 146, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10708969, 400742, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5"}],
    Cell[10709166, 400751, 93, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.6", "AOG4.", "AOG4.6"}],
    Cell[10709284, 400756, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.1", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10709381, 400759, 277, 9, 113, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10709683, 400772, 131, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10745960, 401863, 202, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10752420, 402027, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4."}],
    Cell[10752595, 402035, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.2", "AOG4.", "AOG4.6", "AOG4.6.2"}],
    Cell[10752721, 402040, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.2"}],
    Cell[10760482, 402182, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4."}],
    Cell[10760657, 402190, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.3", "AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10760782, 402195, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10856228, 404350, 179, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[11053443, 408757, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG4."}],
    Cell[11053618, 408765, 100, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.6.4", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11053743, 408770, 175, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11163723, 414072, 176, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11274438, 419381, 148, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11447058, 432313, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG4."}],
    Cell[11447257, 432323, 89, 1, 61, "Section",
      CellTags->{"AOG0.", "5", "AOG5.", "AOG5.1"}],
    Cell[11447371, 432328, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.1", "AOG5.", "AOG5.1"}],
    Cell[11447457, 432331, 961, 30, 52, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11448421, 432363, 162, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11448586, 432370, 143, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11448754, 432376, 132, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11448889, 432380, 18000, 700, 108, 9825, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11466926, 433085, 154, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11467083, 433091, 37157, 811, 296, 5217, 411, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11504243, 433904, 911, 21, 39, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11505191, 433930, 164, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11505358, 433936, 3206, 62, 116, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11508601, 434003, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11508756, 434009, 41903, 1030, 184, 7990, 606, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11550662, 435041, 36319, 958, 184, 7975, 602, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11586984, 436001, 37745, 969, 184, 7841, 594, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11624744, 436973, 6543, 132, 215, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11631324, 437110, 89, 2, 28, "Input",
      CellTags->{"AOG5.", "AOG5.1", "AOG0."}],
    Cell[11631416, 437114, 178, 3, 21, "Print",
      CellTags->{"Info3314357094-6023310", "AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11631631, 437122, 113, 2, 28, "Input",
      CellTags->{"AOG5.", "AOG5.1", "AOG0."}],
    Cell[11631747, 437126, 872, 15, 53, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11632656, 437146, 212, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11632871, 437153, 68812, 1277, 184, 7759, 518, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11701686, 438432, 7662, 157, 263, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11709385, 438594, 89, 2, 28, "Input",
      CellTags->{"AOG5.", "AOG5.1", "AOG0."}],
    Cell[11709477, 438598, 185, 3, 21, "Print",
      CellTags->{"Info3314357094-2851735", "AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11709699, 438606, 116, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11709818, 438610, 63980, 2419, 184, 29521, 1988, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11773801, 441031, 8702, 179, 295, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11782540, 441215, 187, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11782752, 441224, 37530, 862, 184, 7018, 480, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11820285, 442088, 36028, 1075, 184, 10669, 756, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11856328, 443166, 5496, 107, 215, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11861839, 443276, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[11862014, 443284, 136, 3, 36, "Subsection",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862153, 443289, 222, 6, 24, "Text",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862378, 443297, 403, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862806, 443312, 164, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862973, 443318, 45971, 2101, 172, 29226, 1887, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11908959, 445422, 396, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909380, 445437, 180, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909563, 445443, 32739, 1619, 83, 23569, 1499, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11942317, 447065, 307, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942649, 447078, 168, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942820, 447084, 23044, 764, 184, 7539, 566, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11965879, 447851, 270, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966174, 447864, 167, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966344, 447870, 23401, 764, 177, 7452, 560, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11989760, 448637, 288, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11990051, 448648, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[11990226, 448656, 93, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.2", "AOG5.", "AOG5.2"}],
    Cell[11990344, 448661, 104, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11990451, 448665, 985, 14, 133, "Print",
      CellTags->{"Info3314357110-3725464", "AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11991473, 448684, 112, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11991588, 448688, 691, 11, 53, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11992316, 448704, 108, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11992427, 448708, 3921, 79, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11996363, 448790, 241, 5, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11996629, 448799, 165, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11996797, 448805, 3727, 72, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12000539, 448880, 131, 3, 24, "Text",
      CellTags->{"AOG5.", "AOG5.2", "AOG0."}],
    Cell[12000695, 448887, 99, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12000797, 448891, 143, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12000977, 448899, 129, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12001109, 448903, 3977, 80, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12005123, 448988, 98, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12005224, 448992, 128, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12005389, 449000, 154, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12005546, 449006, 4021, 81, 149, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12009604, 449092, 98, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12009705, 449096, 129, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12009871, 449104, 154, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12010028, 449110, 4021, 81, 149, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12014086, 449196, 98, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12014187, 449200, 129, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12014353, 449208, 155, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12014511, 449214, 4024, 81, 149, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12018572, 449300, 98, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12018673, 449304, 129, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12018817, 449310, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[12018992, 449318, 88, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.3", "AOG5.", "AOG5.3"}],
    Cell[12019105, 449323, 99, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12019207, 449327, 2249, 30, 261, "Print",
      CellTags->{"Info3314357173-7371059", "AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12021493, 449362, 107, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12021603, 449366, 1067, 18, 69, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12022707, 449389, 114, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12022846, 449395, 41903, 1030, 184, 7990, 606, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12064752, 450427, 36319, 958, 184, 7975, 602, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12101074, 451387, 37745, 969, 184, 7841, 594, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12138834, 452359, 6543, 132, 215, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12145414, 452496, 105, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12145544, 452502, 38714, 1025, 184, 8462, 646, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12184261, 453529, 37187, 888, 184, 6313, 501, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12221463, 454420, 10050, 189, 475, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12231550, 454614, 119, 2, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[12231694, 454620, 199641, 3801, 240, 79047, 2307, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12431338, 458423, 180895, 3558, 240, 78840, 2292, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12612248, 461984, 10065, 189, 475, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12622350, 462178, 122, 2, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[12622497, 462184, 194995, 3736, 240, 78945, 2298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12817495, 465922, 170763, 3446, 240, 79231, 2310, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12988273, 469371, 11888, 224, 678, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13000198, 469600, 161, 4, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[13000384, 469608, 38848, 1032, 184, 8584, 653, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13039235, 470642, 38537, 983, 184, 7582, 595, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13077787, 471628, 10027, 187, 474, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13087851, 471820, 120, 2, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[13087996, 471826, 43416, 1045, 184, 8076, 603, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13131415, 472873, 36477, 971, 184, 7821, 612, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13167895, 473846, 41994, 1017, 184, 7928, 591, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13209904, 474866, 5816, 121, 197, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13215757, 474992, 159, 4, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[13215941, 475000, 40932, 1136, 184, 11670, 769, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13256876, 476138, 42076, 1333, 184, 13471, 974, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13298955, 477473, 42145, 1225, 184, 12736, 856, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13341103, 478700, 50893, 2299, 184, 31991, 2060, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13392011, 481002, 7934, 162, 277, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13399960, 481167, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[13400135, 481175, 117, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.4", "AOG5.", "AOG5.4"}],
    Cell[13400277, 481180, 95, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13400375, 481184, 668, 9, 101, "Print",
      CellTags->{"Info3313756493-3229688", "AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13401080, 481198, 102, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13401185, 481202, 612, 9, 69, "Print",
      CellTags->{"Info3313756493-6366474", "AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13401812, 481214, 284, 9, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13402121, 481227, 200, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13402324, 481234, 3505, 59, 179, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13405844, 481296, 191, 6, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13406060, 481306, 217, 6, 45, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13406280, 481314, 3055, 52, 174, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13409350, 481369, 307, 9, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13409682, 481382, 118, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13409803, 481386, 105, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13409923, 481392, 358, 11, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13410306, 481407, 233, 6, 45, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13410564, 481417, 192800, 3706, 240, 78969, 2295, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13603367, 485125, 180434, 3545, 240, 78628, 2283, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13783816, 488673, 5175, 89, 316, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13789028, 488767, 232, 6, 45, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13789285, 488777, 195534, 3747, 240, 79084, 2304, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13984822, 492526, 187013, 3629, 240, 78678, 2286, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[14171850, 496158, 3295, 56, 177, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[14175160, 496217, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[14175335, 496225, 94, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.5", "AOG5.", "AOG5.5"}],
    Cell[14175454, 496230, 104, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14175561, 496234, 2241, 30, 245, "Print",
      CellTags->{"Info3313756675-1546738", "AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14177839, 496269, 112, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14177954, 496273, 871, 15, 53, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14178862, 496293, 115, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14178980, 496297, 37114, 994, 184, 10001, 654, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14216097, 497293, 11361, 216, 490, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14227495, 497514, 103, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14227601, 497518, 1375, 24, 85, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14229013, 497547, 99, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14229115, 497551, 1550, 26, 85, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14230702, 497582, 187, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14230892, 497589, 4547063, 118157, 417, 4426191, 116659, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[18777958, 615748, 11435, 217, 506, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[18789430, 615970, 237, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[18789692, 615979, 828845, 19100, 240, 744099, 18048, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[19618540, 635081, 886309, 21393, 240, 773223, 19991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[20504864, 656477, 138, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[20505005, 656482, 150, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[20505158, 656487, 288, 6, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[20505449, 656495, 1470311, 37080, 240, 1380128, 35961, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[21975763, 693577, 13461, 255, 710, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[21989261, 693837, 163, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[21989449, 693845, 40142, 1116, 184, 9891, 737, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22029594, 694963, 38933, 1009, 184, 8007, 622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22068530, 695974, 39339, 1134, 184, 12199, 793, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22107884, 697111, 11634, 221, 522, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22119555, 697337, 133, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22119713, 697343, 43307, 1132, 184, 10122, 717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22163023, 698477, 39137, 1142, 184, 10505, 783, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22202163, 699621, 42030, 1106, 184, 9997, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22244196, 700729, 65079, 2608, 184, 34509, 2225, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22309290, 703340, 7931, 162, 277, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22317236, 703505, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[22317411, 703513, 98, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.6", "AOG5.", "AOG5.6"}],
    Cell[22317534, 703518, 108, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22317645, 703522, 2525, 34, 277, "Print",
      CellTags->{"Info3313758703-7146727", "AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22320207, 703561, 88, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22320298, 703565, 185, 3, 21, "Print",
      CellTags->{"Info3313758707-6863980", "AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22320520, 703573, 133, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22320678, 703579, 43307, 1132, 184, 10122, 717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22363988, 704713, 39137, 1142, 184, 10505, 783, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22403128, 705857, 42030, 1106, 184, 9997, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22445161, 706965, 97868, 4625, 184, 66119, 4227, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22543032, 711592, 95030, 4859, 184, 69887, 4543, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22638077, 716454, 9111, 193, 309, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22647225, 716652, 163, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22647413, 716660, 40550, 1088, 184, 9985, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22687966, 717750, 39253, 1147, 184, 10579, 787, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22727222, 718899, 38293, 1026, 184, 9620, 666, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22765518, 719927, 98791, 3569, 184, 45317, 2903, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22864312, 723498, 94923, 4858, 184, 69885, 4543, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22959250, 728359, 9124, 194, 309, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22968411, 728558, 213, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22968649, 728567, 74776, 2964, 184, 45615, 2598, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23043428, 731533, 39544, 1159, 184, 10769, 798, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23082975, 732694, 72503, 2901, 184, 45236, 2559, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23155481, 735597, 105314, 2770, 184, 28117, 1811, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23260798, 738369, 138149, 3208, 184, 28610, 1850, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23398950, 741579, 60746, 2744, 184, 37105, 2446, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23459711, 744326, 10007, 211, 325, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23469755, 744542, 196, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23469976, 744551, 40142, 1116, 184, 9891, 737, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23510121, 745669, 38933, 1009, 184, 8007, 622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23549057, 746680, 52601, 1863, 184, 23105, 1493, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23601661, 748545, 47236, 1741, 184, 20670, 1407, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23648912, 750289, 14210, 264, 571, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23663159, 750558, 180, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23663364, 750567, 452698, 10085, 240, 310409, 8323, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[24116065, 760654, 429598, 9805, 240, 310502, 8329, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[24545666, 770461, 421611, 9666, 240, 310153, 8284, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[24967280, 780129, 423249, 9686, 240, 310876, 8293, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[25390532, 789817, 418502, 9653, 240, 309986, 8308, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[25809037, 799472, 429067, 9781, 240, 311218, 8320, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26238119, 809256, 13847, 271, 570, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26252003, 809532, 171, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26252199, 809541, 34175, 909, 184, 7350, 572, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26286377, 810452, 35960, 954, 184, 7691, 599, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26322352, 811409, 138, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26322493, 811414, 150, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26322646, 811419, 288, 6, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26322959, 811429, 74489, 3882, 184, 57210, 3663, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26397451, 815313, 63439, 2769, 184, 36903, 2436, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26460905, 818085, 15009, 290, 726, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26475951, 818380, 60, 1, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26476014, 818383, 20915, 596, 184, 6122, 408, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26496932, 818981, 139, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26497074, 818986, 151, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26497228, 818991, 287, 6, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26497540, 819001, 57081, 1864, 184, 21898, 1424, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26554624, 820867, 43191, 1362, 184, 14532, 1003, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26597830, 822232, 12156, 233, 646, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26610001, 822468, 160, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26610186, 822476, 173, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26610384, 822485, 39944, 1102, 184, 9680, 723, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26650331, 823589, 39703, 1010, 184, 7652, 609, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26690037, 824601, 81421, 3296, 184, 44018, 2829, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26771461, 827899, 53111, 2128, 184, 26687, 1796, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26824587, 830030, 15864, 295, 711, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26840488, 830330, 237, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26840750, 830339, 798817, 17930, 240, 727412, 17043, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[27639570, 848271, 908874, 21607, 240, 776089, 19962, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[28548447, 869880, 884664, 20481, 240, 747392, 18781, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[29433114, 890363, 660892, 11348, 240, 626118, 10913, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[30094009, 901713, 892457, 21405, 240, 771316, 19904, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[30986469, 923120, 899107, 21450, 240, 775815, 19922, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[31885603, 944574, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[31885778, 944582, 103, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.7", "AOG5.", "AOG5.7"}],
    Cell[31885906, 944587, 113, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31886022, 944591, 2818, 39, 293, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31888877, 944635, 121, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31889001, 944639, 597, 11, 37, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31889635, 944655, 135, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31889773, 944659, 32192, 876, 184, 8533, 578, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31921968, 945537, 5295, 105, 197, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31927300, 945647, 158, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31927461, 945653, 436020, 9680, 240, 321363, 8259, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32363484, 955335, 3211, 65, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32366732, 955405, 158, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32366893, 955411, 436020, 9680, 240, 321363, 8259, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32802916, 965093, 3211, 65, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32806164, 965163, 188, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32806355, 965170, 435803, 9723, 240, 322053, 8313, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33242161, 974895, 3169, 66, 117, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33245367, 974966, 202, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33245594, 974975, 33233, 941, 184, 9531, 643, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33278830, 975918, 40894, 1541, 184, 18503, 1259, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33319739, 977462, 6703, 134, 234, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33326479, 977601, 115, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33326597, 977605, 24999, 556, 184, 4249, 294, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33351599, 978163, 5202, 103, 174, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33356838, 978271, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33356978, 978275, 48849, 1770, 184, 22034, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33405830, 980047, 5242, 104, 174, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33411087, 980154, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[33411274, 980163, 108, 1, 61, "Section",
      CellTags->{"AOG0.", "6", "AOG6.", "AOG6.1"}],
    Cell[33411407, 980168, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.1", "AOG6.", "AOG6.1"}],
    Cell[33411493, 980171, 468, 12, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33411986, 980187, 99, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33412088, 980191, 1298, 18, 140, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33413423, 980214, 107, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33413533, 980218, 427, 8, 39, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33413997, 980231, 101, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33414101, 980235, 1386, 20, 155, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33415524, 980260, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33415636, 980264, 452, 9, 39, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33416103, 980276, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6."}],
    Cell[33416278, 980284, 113, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.2", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416416, 980289, 97, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.2.1", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416516, 980292, 268, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416809, 980303, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416942, 980307, 26152, 499, 294, 3133, 209, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33443131, 980811, 127, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33443283, 980817, 31937, 760, 184, 5582, 428, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33475223, 981579, 31390, 839, 184, 6685, 528, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33506616, 982420, 34255, 890, 184, 6802, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33540874, 983312, 31849, 759, 184, 5579, 428, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33572726, 984073, 29320, 762, 184, 6043, 468, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33602049, 984837, 34167, 889, 184, 6799, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33636231, 985729, 4495, 102, 103, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33640763, 985836, 148, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33640936, 985842, 34077, 742, 184, 4736, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33675016, 986586, 33676, 820, 184, 5754, 469, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33708695, 987408, 34749, 841, 184, 5853, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33743447, 988251, 34082, 742, 184, 4741, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33777532, 988995, 31696, 744, 184, 5101, 409, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33809231, 989741, 34766, 841, 184, 5858, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33844012, 990585, 4615, 104, 103, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33848664, 990694, 148, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33848837, 990700, 34077, 742, 196, 4736, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33882917, 991444, 33676, 820, 184, 5754, 469, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33916596, 992266, 34749, 841, 184, 5853, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33951348, 993109, 34082, 742, 184, 4741, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33985433, 993853, 31696, 744, 184, 5101, 409, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34017132, 994599, 34766, 841, 184, 5858, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34051913, 995443, 4615, 104, 115, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34056565, 995552, 149, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34056717, 995556, 147529, 3003, 184, 20809, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34204283, 998564, 143, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34204451, 998570, 34368, 765, 184, 5216, 400, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34238822, 999337, 34363, 765, 184, 5211, 400, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34273188, 1000104, 147529, 3003, 184, 20809, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34420744, 1003111, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[34420929, 1003119, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.2", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34421029, 1003122, 263, 7, 79, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34421317, 1003133, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34421450, 1003137, 16000, 372, 294, 3244, 209, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34437487, 1003514, 127, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34437639, 1003520, 38504, 1002, 184, 7743, 617, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34476146, 1004524, 33813, 909, 196, 7329, 577, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34509962, 1005435, 34759, 910, 196, 7134, 563, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34544724, 1006347, 31351, 776, 196, 5814, 455, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34576078, 1007125, 70322, 1881, 196, 17739, 1226, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34646403, 1009008, 31765, 880, 196, 7001, 569, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34678183, 1009891, 4497, 102, 113, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34682717, 1009998, 145, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34682865, 1010002, 137262, 2773, 196, 19098, 1309, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34820142, 1012778, 148, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[34820327, 1012786, 97, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.2.3", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820427, 1012789, 205, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820657, 1012798, 160, 4, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820820, 1012804, 117, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820952, 1012810, 570, 11, 54, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34821525, 1012823, 612, 14, 102, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34822140, 1012839, 216, 5, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34822359, 1012846, 387, 9, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34822749, 1012857, 317, 7, 86, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823069, 1012866, 346, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823418, 1012876, 271, 7, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823692, 1012885, 176, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823871, 1012892, 412, 12, 176, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34824308, 1012908, 252, 6, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34824563, 1012916, 255229, 17819, 108, 243002, 17662, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35079829, 1030740, 125, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35079979, 1030746, 34663, 850, 196, 6370, 494, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35114645, 1031598, 36075, 1004, 184, 8345, 655, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35150723, 1032604, 37944, 973, 184, 7459, 590, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35188716, 1033583, 125, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35188866, 1033589, 33930, 886, 196, 6830, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35222799, 1034477, 38325, 998, 184, 7903, 616, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35261127, 1035477, 34238, 847, 184, 6386, 497, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35295414, 1036330, 132, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35295549, 1036334, 112461, 5760, 196, 82833, 5389, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35408047, 1042099, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35408202, 1042103, 134181, 2677, 184, 18234, 1240, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35542398, 1044783, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[35542583, 1044791, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.4", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35542683, 1044794, 184, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35542892, 1044803, 159, 4, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35543054, 1044809, 116, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35543185, 1044815, 569, 11, 42, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35543757, 1044828, 611, 14, 90, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35544371, 1044844, 216, 5, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35544590, 1044851, 387, 9, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35544980, 1044862, 317, 7, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35545300, 1044871, 271, 7, 62, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35545574, 1044880, 453, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35546030, 1044896, 453, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35546508, 1044914, 224, 5, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35546735, 1044921, 242133, 16878, 96, 229517, 16717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35788905, 1061804, 123, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35789053, 1061810, 36664, 981, 184, 7713, 617, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35825720, 1062793, 34235, 867, 184, 6836, 522, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35859958, 1063662, 36640, 928, 184, 7075, 557, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35896601, 1064592, 35085, 928, 184, 7256, 578, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35931689, 1065522, 34610, 867, 184, 6827, 518, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35966302, 1066391, 35177, 916, 184, 7115, 563, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36001494, 1067310, 4483, 102, 103, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36006014, 1067417, 146, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36006185, 1067423, 30191, 708, 184, 5167, 394, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36036379, 1068133, 28987, 725, 184, 5510, 430, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36065369, 1068860, 125533, 2582, 184, 17966, 1249, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36190929, 1071446, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[36191114, 1071454, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.5", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36191236, 1071459, 110, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36191349, 1071463, 2033, 28, 245, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36193397, 1071494, 496, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36193918, 1071512, 137, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36284656, 1076184, 132, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36518221, 1082264, 126, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36600596, 1084239, 121, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36759684, 1088334, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[36759881, 1088343, 113, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.3", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760019, 1088348, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.1", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760119, 1088351, 271, 7, 79, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760415, 1088362, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760548, 1088366, 18194, 504, 294, 5438, 341, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[36778779, 1088875, 168, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36778950, 1088881, 438, 9, 21, "Print",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[36779413, 1088894, 143855, 3133, 240, 79529, 2333, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[36923271, 1092029, 162174, 3372, 239, 79437, 2345, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37085448, 1095403, 154268, 3257, 240, 79379, 2327, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37239731, 1098663, 438, 9, 21, "Print",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37240194, 1098676, 173933, 3512, 240, 79826, 2345, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37414130, 1102190, 162174, 3372, 239, 79437, 2345, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37576307, 1105564, 183408, 3625, 240, 79670, 2339, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37759730, 1109192, 9907, 192, 548, "Output",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37769674, 1109389, 182, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[37769859, 1109396, 2911809, 38632, 556, 1527231, 21533, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->{"AOG6.3.1", "AOG6.3", "AOG6.", "AOG0."}],
    Cell[40681671, 1148030, 999, 21, 39, "Output",
      CellTags->{"AOG6.3.1", "AOG6.3", "AOG6.", "AOG0."}],
    Cell[40682685, 1148054, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3"}],
    Cell[40682870, 1148062, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.2", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40682970, 1148065, 205, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40683178, 1148072, 253, 9, 113, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40683456, 1148085, 154, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40683613, 1148089, 39323, 1977, 170, 27027, 1820, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40722951, 1150069, 374, 11, 147, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40723350, 1150084, 154, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40723507, 1150088, 46321, 2316, 164, 32510, 2140, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40769865, 1152409, 241, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40770109, 1152415, 438, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40770572, 1152428, 173771, 3473, 70, 78845, 2295, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40944346, 1155903, 196112, 3769, 70, 79217, 2319, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41140461, 1159674, 187658, 3642, 70, 78851, 2292, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41328134, 1163319, 5191, 100, 70, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41333362, 1163424, 137, 2, 24, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[41333502, 1163428, 438, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41333965, 1163441, 173760, 3468, 240, 78767, 2289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41507728, 1166911, 196382, 3766, 70, 79221, 2313, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41704113, 1170679, 187901, 3638, 70, 78920, 2286, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41892029, 1174320, 8304, 149, 524, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41900370, 1174474, 167, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[41900540, 1174480, 468481, 6384, 446, 105436, 1896, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[42369024, 1180866, 1174, 25, 37, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[42370213, 1180894, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3"}],
    Cell[42370398, 1180902, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.3", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42370498, 1180905, 509, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42371032, 1180923, 118, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42371153, 1180927, 121445, 4136, 313, 62819, 3407, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42492635, 1185068, 135, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42492773, 1185072, 438, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42493214, 1185083, 274996, 12364, 294, 172862, 11097, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42768213, 1197449, 438, 9, 20, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42768676, 1197462, 366904, 16950, 294, 240110, 15379, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[43135583, 1214414, 347371, 4783, 294, 103986, 1773, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[43482969, 1219200, 994, 21, 39, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[43484000, 1219226, 221, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[43484224, 1219233, 896803, 21536, 240, 771968, 19989, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[44381042, 1240772, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3"}],
    Cell[44381239, 1240781, 143, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.4", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2"}],
    Cell[44381407, 1240786, 142, 2, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "6.4.1", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
    Cell[44381552, 1240790, 1606, 33, 86, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
    Cell[44383161, 1240825, 155, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44383353, 1240833, 164, 2, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.4.2", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383520, 1240837, 263, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383786, 1240845, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383915, 1240849, 226, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44384144, 1240859, 1133, 28, 379, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44385280, 1240889, 155, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44385472, 1240897, 225, 3, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.4.3", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44385700, 1240902, 669, 16, 40, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386372, 1240920, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386583, 1240926, 316, 10, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386902, 1240938, 2463, 77, 1003, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44389368, 1241017, 155, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44389560, 1241025, 122, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.4", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44389707, 1241030, 206, 6, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44389916, 1241038, 2635, 61, 286, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44392588, 1241104, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44392765, 1241110, 143828, 7167, 306, 99609, 6616, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44536630, 1248282, 139, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44536772, 1248286, 6413, 90, 444, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44543222, 1248381, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44543375, 1248385, 33679, 1164, 196, 13916, 915, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44577091, 1249554, 184, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44577278, 1249560, 322724, 6787, 252, 197914, 5241, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44900017, 1256350, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44900209, 1256358, 116, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.5", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900328, 1256361, 231, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900584, 1256372, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900761, 1256378, 59743, 2242, 118, 27984, 1844, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960519, 1258623, 140, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960684, 1258629, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960839, 1258633, 22963, 536, 196, 4136, 298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44983839, 1259174, 188, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44984030, 1259181, 293073, 6331, 252, 196329, 5131, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[45277118, 1265515, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[45277310, 1265523, 117, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.6", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277452, 1265528, 250, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45278092, 1265551, 175, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45344928, 1269109, 182, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345292, 1269123, 153, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45389406, 1270409, 151, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45428322, 1271607, 188, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45428513, 1271614, 888988, 21267, 252, 784101, 19967, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[46317516, 1292884, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[46317708, 1292892, 119, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.7", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46317852, 1292897, 249, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318104, 1292906, 170, 3, 33, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318277, 1292911, 193, 4, 33, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318507, 1292920, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318684, 1292926, 85537, 4877, 118, 72275, 4708, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404258, 1297808, 181, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404442, 1297814, 149, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404628, 1297822, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404783, 1297826, 53325, 1414, 196, 13928, 922, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46458145, 1299245, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46458298, 1299249, 45215, 1380, 196, 15333, 1006, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46503550, 1300634, 185, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46503738, 1300640, 881315, 21061, 252, 782915, 19841, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[47385068, 1321704, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[47385260, 1321712, 132, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.8", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385395, 1321715, 255, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385675, 1321724, 264, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385942, 1321733, 59743, 2242, 118, 27984, 1844, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47445700, 1323978, 395, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446098, 1323987, 232, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446333, 1323996, 297, 7, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446655, 1324007, 203, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446861, 1324014, 150, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447014, 1324019, 126, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447155, 1324025, 247, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447427, 1324034, 178, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447608, 1324040, 31318, 990, 196, 11037, 734, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47478941, 1325033, 392, 9, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479358, 1325046, 140, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479501, 1325050, 139, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479655, 1325056, 304, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479984, 1325066, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47480274, 1325077, 37893, 970, 196, 7731, 592, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47518170, 1326049, 27709, 585, 196, 4189, 289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47545906, 1326638, 187, 5, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546118, 1326647, 132, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546253, 1326651, 316, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546572, 1326659, 321, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546896, 1326667, 313, 5, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547212, 1326674, 271, 5, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547486, 1326681, 307, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547796, 1326689, 139, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547950, 1326695, 182, 4, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47548157, 1326703, 175, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47548335, 1326709, 34399, 938, 196, 9263, 622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47582749, 1327650, 359, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47583133, 1327661, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47583423, 1327672, 35972, 896, 196, 7020, 533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47619398, 1328570, 42756, 1023, 196, 9144, 603, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662181, 1329597, 212, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662418, 1329606, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662595, 1329612, 41734, 1733, 196, 23137, 1498, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704344, 1331348, 206, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704575, 1331357, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704865, 1331368, 36110, 898, 196, 7020, 533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47740978, 1332268, 99232, 3697, 196, 47514, 3053, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840237, 1335969, 216, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840478, 1335978, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840631, 1335982, 16729, 479, 196, 4699, 325, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857375, 1336464, 278, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857678, 1336474, 181, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857862, 1336480, 30128, 961, 196, 10784, 717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47888027, 1337446, 270, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47888322, 1337457, 44308, 1021, 196, 7810, 565, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47932633, 1338480, 30618, 670, 196, 5012, 348, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963278, 1339154, 272, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963575, 1339164, 185, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963763, 1339170, 880964, 21156, 252, 787865, 20001, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48844742, 1360329, 372, 8, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48845139, 1360341, 292, 6, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48845434, 1360349, 226985, 10583, 306, 150039, 9628, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072434, 1370935, 160, 2, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072619, 1370941, 289, 6, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072911, 1370949, 148321, 7487, 306, 107970, 6983, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49221247, 1378439, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]},
  "AOG1."->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[15104, 564, 71, 1, 61, "Section",
      CellTags->{"1", "AOG1.", "AOG0."}],
    Cell[15178, 567, 426, 12, 22, "Text",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[15607, 581, 142, 4, 22, "Text",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[15774, 589, 71, 1, 32, "Subsubsection",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[15848, 592, 150, 5, 22, "Text",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[16023, 601, 98, 2, 27, "Input",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[16124, 605, 111, 2, 20, "Print",
      CellTags->{"AOG1.", "AOG0."}],
    Cell[16238, 609, 202, 4, 20, "Print",
      CellTags->{"AOG1.", "AOG0."}]},
  "AOG2."->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[2300, 71, 223, 4, 24, "Outline1",
      CellTags->{"AOG2.", "AOG0.", "AOG2.1", "AOG2.2", "AOG2.3"}],
    Cell[2548, 79, 193, 4, 21, "Outline2",
      CellTags->{"AOG2.", "AOG2.1", "AOG0."}],
    Cell[2744, 85, 987, 35, 116, "Outline3",
      CellTags->{"AOG2.", "AOG2.1", "AOG0."}],
    Cell[3768, 125, 206, 4, 21, "Outline2",
      CellTags->{"AOG2.", "AOG2.2", "AOG0."}],
    Cell[3977, 131, 450, 14, 46, "Outline3",
      CellTags->{"AOG2.", "AOG2.2", "AOG0."}],
    Cell[4464, 150, 213, 4, 21, "Outline2",
      CellTags->{"AOG2.", "AOG2.3", "AOG0."}],
    Cell[4680, 156, 518, 18, 60, "Outline3",
      CellTags->{"AOG2.", "AOG2.3", "AOG0."}],
    Cell[16631, 625, 95, 1, 61, "Section",
      CellTags->{"AOG0.", "2", "AOG2."}],
    Cell[16751, 630, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.1", "AOG2.", "AOG2.1"}],
    Cell[16859, 635, 100, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.1", "AOG2.", "AOG2.1", "AOG2.1.1"}],
    Cell[16962, 638, 1992, 55, 88, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.1"}],
    Cell[18979, 697, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.1"}],
    Cell[19091, 701, 485, 8, 65, "Print",
      CellTags->{
      "Info3312042809-6749329", "AOG2.", "AOG2.1", "AOG2.1.1", "AOG0."}],
    Cell[19625, 715, 118, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.2", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[19746, 718, 664, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[20435, 737, 146, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[20584, 741, 279, 8, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[20878, 752, 701, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[21604, 771, 243, 7, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[21850, 780, 367, 10, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[22232, 793, 412, 10, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[22669, 807, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[22783, 811, 228, 5, 19, "Message",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[23014, 818, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[23147, 824, 198, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[23370, 833, 207, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[23580, 840, 347, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[23942, 852, 595, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[24562, 871, 229, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[24794, 880, 872, 27, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[25681, 910, 361, 10, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[26067, 924, 183, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[26253, 931, 10518, 262, 285, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[36786, 1196, 204, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[37015, 1205, 144, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[37162, 1209, 24034, 773, 134, 9878, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[61199, 1984, 495, 11, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[61697, 1997, 141, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[61853, 2003, 253, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[62131, 2012, 220, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[62354, 2021, 908, 27, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[63299, 2053, 164, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[63466, 2059, 1327, 25, 95, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[64808, 2087, 299, 8, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[65132, 2099, 176, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[65311, 2105, 72323, 2564, 152, 32608, 2068, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[137637, 4671, 588, 13, 35, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[138228, 4686, 143, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[138386, 4692, 158, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.2"}],
    Cell[138581, 4700, 111, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.3", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[138695, 4703, 1624, 33, 86, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[140322, 4738, 780, 13, 54, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[141105, 4753, 1236, 21, 70, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[142344, 4776, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.3"}],
    Cell[142541, 4784, 131, 1, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "2.1.4", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[142675, 4787, 641, 13, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[143341, 4804, 329, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[143673, 4815, 18991, 659, 110, 8702, 527, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[162667, 5476, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[162954, 5486, 341, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[163298, 5497, 20462, 730, 110, 9828, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[183763, 6229, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[184050, 6239, 339, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[184392, 6250, 20821, 734, 110, 9839, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[205216, 6986, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[205481, 6994, 527, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[206011, 7005, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.3"}],
    Cell[206208, 7013, 112, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.5", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[206323, 7016, 876, 22, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[207224, 7042, 118, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[207345, 7046, 2749, 52, 129, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[210109, 7101, 915, 21, 56, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[211049, 7126, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[211160, 7130, 279, 5, 50, "Print",
      CellTags->{
      "Info3312042819-8757440", "AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[211476, 7140, 343, 10, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[211822, 7152, 20450, 730, 110, 9828, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[232275, 7884, 1016, 18, 88, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[233294, 7904, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[233448, 7912, 160, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[233611, 7919, 346, 6, 19, "Message",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[233960, 7927, 343, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[234306, 7936, 1745, 29, 131, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[236054, 7967, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[236186, 7973, 294, 8, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[236505, 7985, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[236616, 7989, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[236749, 7995, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.5"}],
    Cell[236946, 8003, 114, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.6", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[237063, 8006, 580, 11, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[237668, 8021, 293, 8, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[237964, 8031, 141, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238108, 8036, 147, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238258, 8041, 194, 4, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238455, 8047, 171, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238629, 8052, 233, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238865, 8059, 374, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[239242, 8069, 565, 11, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[239810, 8082, 305, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240118, 8090, 267, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240388, 8097, 233, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240624, 8104, 359, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240986, 8113, 565, 11, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[241554, 8126, 306, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[241863, 8134, 267, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[242133, 8141, 233, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[242369, 8148, 359, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[242731, 8157, 295, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243029, 8165, 306, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243338, 8173, 267, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243608, 8180, 360, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243971, 8190, 154, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[244128, 8195, 229, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[244360, 8202, 241, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[244604, 8209, 454, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[245061, 8221, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[245537, 8233, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[245925, 8243, 457, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[246385, 8254, 489, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[246877, 8266, 410, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[247290, 8277, 480, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[247773, 8289, 497, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[248273, 8301, 418, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[248694, 8312, 435, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[249132, 8323, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[249602, 8335, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[249984, 8345, 452, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[250439, 8357, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[250911, 8369, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[251295, 8379, 241, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[251539, 8386, 454, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[251996, 8398, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[252472, 8410, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[252860, 8420, 466, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[253329, 8432, 489, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[253821, 8444, 410, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[254234, 8455, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[254732, 8467, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[255151, 8478, 433, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[255587, 8489, 465, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[256055, 8501, 377, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[256435, 8511, 450, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[256888, 8523, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[257360, 8535, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[257744, 8545, 241, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[257988, 8552, 454, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[258445, 8564, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[258921, 8576, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[259309, 8586, 466, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[259778, 8598, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[260272, 8610, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[260687, 8621, 435, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[261125, 8632, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[261595, 8644, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[261977, 8654, 450, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[262430, 8666, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[262902, 8678, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[263286, 8688, 498, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[263787, 8700, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[264206, 8711, 488, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[264697, 8723, 406, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[265106, 8734, 474, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[265583, 8746, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[265969, 8756, 476, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[266448, 8768, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[266836, 8778, 344, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[267183, 8787, 303, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[267489, 8795, 139, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[267631, 8800, 1172, 20, 88, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[268840, 8825, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[268951, 8829, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[269083, 8835, 445, 10, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[269553, 8849, 267, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[269823, 8859, 1727, 28, 194, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[271565, 8890, 301, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[271891, 8900, 312, 8, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[272206, 8910, 141, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[272350, 8915, 483, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[272836, 8927, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[273243, 8938, 509, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[273755, 8950, 432, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[274190, 8961, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[274684, 8973, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[275099, 8984, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[275597, 8996, 418, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[276018, 9007, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[276516, 9019, 418, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[276937, 9030, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[277409, 9042, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[277795, 9052, 465, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[278263, 9064, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[278645, 9074, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[279121, 9086, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[279509, 9096, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[279981, 9108, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[280367, 9118, 521, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[280891, 9130, 442, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[281336, 9141, 483, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[281822, 9153, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[282229, 9164, 509, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[282741, 9176, 430, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[283174, 9187, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[283668, 9199, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[284083, 9210, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[284581, 9222, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[285000, 9233, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[285498, 9245, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[285917, 9256, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[286389, 9268, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[286773, 9278, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[287243, 9290, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[287625, 9300, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[288101, 9312, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[288487, 9322, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[288961, 9334, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[289347, 9344, 521, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[289871, 9356, 442, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[290316, 9367, 483, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[290802, 9379, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[291209, 9390, 509, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[291721, 9402, 430, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[292154, 9413, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[292648, 9425, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[293063, 9436, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[293561, 9448, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[293980, 9459, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[294478, 9471, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[294897, 9482, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[295367, 9494, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[295749, 9504, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[296219, 9516, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[296601, 9526, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[297077, 9538, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[297463, 9548, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[297937, 9560, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[298323, 9570, 521, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[298847, 9582, 442, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[299292, 9593, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[299766, 9605, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[300152, 9615, 489, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[300644, 9627, 410, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[301057, 9638, 465, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[301525, 9650, 377, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[301905, 9660, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[302377, 9672, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[302761, 9682, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[303235, 9694, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[303621, 9704, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[304115, 9716, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[304530, 9727, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[305000, 9739, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[305382, 9749, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[305854, 9761, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[306238, 9771, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[306712, 9783, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[307098, 9793, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[307592, 9805, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[308007, 9816, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[308477, 9828, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[308859, 9838, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[309331, 9850, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[309715, 9860, 498, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[310216, 9872, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[310635, 9883, 488, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[311126, 9895, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[311533, 9906, 474, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[312010, 9918, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[312396, 9928, 476, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[312875, 9940, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[313263, 9950, 139, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[313405, 9955, 1101, 20, 113, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[314521, 9978, 283, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[314829, 9988, 177, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[315009, 9994, 1686, 29, 111, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[316710, 10026, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.6"}],
    Cell[316907, 10034, 108, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7", "2.1.7"}],
    Cell[317018, 10037, 526, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[317569, 10050, 337, 10, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[317909, 10062, 22699, 836, 110, 11522, 692, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[340611, 10900, 2909, 48, 205, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[343535, 10951, 253, 5, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[343813, 10960, 389, 12, 155, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[344205, 10974, 40769, 1619, 159, 22270, 1385, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[384977, 12595, 3259, 51, 206, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[388251, 12649, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.7"}],
    Cell[388448, 12657, 119, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8", "2.1.8"}],
    Cell[388570, 12660, 366, 7, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[388961, 12671, 360, 10, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[389324, 12683, 43019, 1385, 257, 15999, 1046, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[432346, 14070, 1492, 27, 145, "Output",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[433853, 14100, 563, 14, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[434441, 14118, 162, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[434606, 14125, 566, 9, 65, "Print",
      CellTags->{
      "Info3312042871-8199869", "AOG2.", "AOG2.1", "AOG2.1.8", "AOG0."}],
    Cell[435209, 14139, 366, 10, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[435578, 14151, 20370, 730, 110, 9744, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[455951, 14883, 1831, 30, 145, "Output",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[457797, 14916, 492, 15, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[458292, 14933, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.8"}],
    Cell[458501, 14942, 96, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.2", "AOG2.", "AOG2.2"}],
    Cell[458600, 14945, 525, 12, 36, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2"}],
    Cell[459150, 14961, 128, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.2.1", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[459281, 14964, 723, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460007, 14981, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460121, 14985, 267, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460391, 14994, 268, 5, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460684, 15003, 192, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460879, 15010, 23289, 697, 130, 7253, 493, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[484183, 15710, 551, 12, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[484759, 15726, 246, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[485008, 15734, 552, 10, 77, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[485575, 15747, 482, 11, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[486082, 15762, 152, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[486237, 15766, 1723, 24, 185, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[487975, 15793, 158, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[488158, 15801, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[488300, 15805, 71910, 1447, 240, 21739, 822, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[560225, 17255, 196, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[560446, 17263, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[560570, 17267, 1525, 21, 185, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[562132, 17293, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[562256, 17297, 1494, 22, 185, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[563765, 17322, 255, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[564045, 17332, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[564185, 17336, 5152, 92, 129, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[569352, 17431, 378, 6, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[569755, 17441, 230, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[569988, 17449, 225, 4, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[570228, 17456, 287, 7, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[570540, 17467, 261, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[570804, 17475, 76731, 5322, 130, 64916, 5171, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[647538, 22799, 426, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[647979, 22811, 667, 11, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[648671, 22826, 244, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[648918, 22834, 1029, 19, 73, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[649962, 22856, 200, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[650187, 22864, 184, 3, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[650374, 22869, 5263, 73, 617, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[655652, 22945, 300, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[655977, 22955, 245, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[656225, 22963, 221, 4, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[656461, 22970, 419, 8, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[656905, 22982, 259, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[657167, 22990, 76745, 5322, 130, 64930, 5171, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[733915, 28314, 425, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[734355, 28326, 441, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[734821, 28337, 260, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[735084, 28345, 315480, 24523, 130, 303636, 24371, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[1050567, 52870, 424, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[1051006, 52882, 188, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[1051197, 52888, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.2", "AOG2.", "AOG2.2.1"}],
    Cell[1051394, 52896, 126, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2", "2.2.2"}],
    Cell[1051523, 52899, 815, 13, 52, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1052341, 52914, 301, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1052667, 52926, 172, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1052842, 52932, 39451, 2840, 64, 34309, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1092308, 55775, 399, 12, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1092732, 55791, 288, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1093023, 55799, 938, 17, 88, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1093976, 55819, 216, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1094217, 55827, 176, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1094396, 55833, 28646, 598, 184, 4073, 289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1123057, 56434, 487, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1123547, 56445, 193, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1123765, 56454, 186, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1123954, 56461, 7133, 104, 324, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1131102, 56568, 191, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1131318, 56577, 206, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1131527, 56585, 24152, 606, 184, 5492, 370, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1155694, 57194, 186, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1155905, 57202, 117, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1156025, 57206, 27273, 690, 184, 6378, 427, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1183313, 57899, 504, 8, 36, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1183842, 57911, 274, 7, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1184119, 57920, 3410, 47, 401, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1187566, 57972, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1187777, 57978, 3008, 42, 365, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1190822, 58025, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1191033, 58031, 3054, 42, 365, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1194124, 58078, 378, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1194527, 58090, 252102, 6207, 240, 177264, 5277, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1446632, 64299, 302511, 6827, 240, 177429, 5277, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1749146, 71128, 278598, 6544, 240, 177380, 5289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[2027747, 77674, 1438537, 71956, 261, 1301290, 70256, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3466333, 149636, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3466473, 149640, 9632, 174, 234, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3476142, 149819, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3476256, 149823, 115, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3476386, 149829, 199, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3476610, 149839, 258, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3476871, 149850, 293, 6, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3477201, 149861, 200, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3477426, 149871, 38782, 2831, 64, 34341, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3516211, 152704, 39691, 2844, 64, 34229, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3555917, 155551, 946, 17, 54, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3556878, 155571, 277, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3557180, 155582, 195, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3557378, 155589, 295, 5, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3557710, 155599, 150, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3557863, 155603, 39799, 2844, 64, 34345, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3597665, 158449, 424, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3598104, 158461, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.2", "AOG2.", "AOG2.2.2"}],
    Cell[3598301, 158469, 107, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.2.3", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3598411, 158472, 373, 6, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3598787, 158480, 574, 10, 85, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599364, 158492, 175, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599542, 158498, 108, 1, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599675, 158503, 166, 3, 25, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599844, 158508, 28599, 1237, 86, 18759, 1110, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3628480, 159750, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3628622, 159754, 132, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3628791, 159762, 140, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3628934, 159766, 132, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3629103, 159774, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3629214, 159778, 521, 12, 35, "Print",
      CellTags->{
      "Info3312042947-9251066", "AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3629772, 159795, 165, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3629940, 159801, 117, 3, 38, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3630094, 159809, 156, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3630253, 159813, 117, 3, 38, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3630385, 159819, 391, 8, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3630801, 159831, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3630913, 159835, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3631067, 159843, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3631179, 159847, 2067, 38, 214, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3633283, 159890, 168, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3633454, 159896, 140, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3633631, 159904, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3633755, 159908, 119, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3633911, 159916, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3634035, 159920, 12755, 207, 1238, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3646827, 160132, 260, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3647090, 160140, 258, 5, 26, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3647385, 160150, 344, 12, 155, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3647732, 160164, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3647887, 160172, 269, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3648159, 160180, 254, 5, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3648450, 160190, 155, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3648608, 160197, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3648763, 160205, 155, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3648921, 160212, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3649076, 160220, 155, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3649234, 160227, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3649389, 160235, 148, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3649540, 160239, 47437, 819, 1149, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3697014, 161063, 112, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3697129, 161067, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3697283, 161075, 255, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3697541, 161085, 508, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3698086, 161099, 276, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3698365, 161109, 3592, 63, 129, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3701994, 161177, 525, 11, 139, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3702544, 161192, 18991, 786, 86, 11568, 689, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3721538, 161980, 19404, 805, 86, 11762, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3740945, 162787, 17533, 725, 86, 10993, 639, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3758481, 163514, 21004, 843, 86, 12058, 727, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3779488, 164359, 22226, 965, 86, 13636, 853, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3801717, 165326, 24095, 1034, 86, 14388, 909, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3825815, 166362, 18228, 740, 86, 11141, 647, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3844046, 167104, 25166, 1090, 86, 15289, 963, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3869215, 168196, 24747, 1071, 86, 15113, 947, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3893965, 169269, 25378, 1114, 86, 15849, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3919346, 170385, 25093, 1076, 86, 15118, 947, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3944442, 171463, 23817, 1008, 86, 13964, 881, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3968262, 172473, 25725, 1085, 86, 14989, 947, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3993990, 173560, 22928, 1085, 86, 15776, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4016921, 174647, 24033, 1099, 86, 15767, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4040957, 175748, 21595, 980, 86, 14014, 881, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4062555, 176730, 23316, 1089, 86, 15800, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4085874, 177821, 23217, 980, 86, 13708, 857, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4109094, 178803, 24174, 1099, 86, 15844, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4133271, 179904, 23922, 1075, 86, 15288, 963, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4157196, 180981, 24420, 1103, 86, 15830, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4181619, 182086, 24090, 1067, 86, 15136, 951, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4205712, 183155, 17283, 700, 86, 10686, 613, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4222998, 183857, 17236, 713, 86, 10910, 629, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4240237, 184572, 20490, 947, 86, 13678, 857, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4260730, 185521, 22588, 1004, 86, 14387, 897, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4283321, 186527, 22189, 967, 86, 13693, 857, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4305525, 187497, 10122, 191, 414, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4315684, 187693, 206, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[4315893, 187701, 310, 5, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4316240, 187711, 531, 13, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[4316774, 187726, 29237, 1570, 86, 21628, 1471, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4346014, 189298, 428, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4346479, 189312, 479, 13, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[4346961, 189327, 428, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4347404, 189339, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.2.3", "AOG2.2", "AOG2."}],
    Cell[4347613, 189348, 119, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.3", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4347757, 189353, 101, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.1", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4347883, 189358, 160, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348046, 189364, 165, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4348226, 189370, 231, 7, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348460, 189379, 180, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348665, 189387, 167, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348835, 189393, 31520, 1334, 159, 20081, 1187, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4380370, 190730, 184, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4380579, 190739, 131, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4380713, 190743, 418, 7, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4381168, 190755, 202, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4381373, 190763, 13835, 365, 184, 3130, 227, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4395223, 191131, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.3", "AOG2."}],
    Cell[4395408, 191139, 116, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.2", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4395549, 191144, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4395673, 191148, 42033, 1026, 296, 7262, 591, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4437709, 192176, 922, 21, 39, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4438668, 192202, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4438847, 192208, 42773, 1154, 184, 9613, 739, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4481623, 193364, 60297, 1107, 184, 6603, 439, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4541969, 194477, 135, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4542107, 194481, 36182, 848, 184, 6910, 481, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4578304, 195332, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.3", "AOG2."}],
    Cell[4578489, 195340, 104, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.3", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4578618, 195345, 280, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4578901, 195353, 319, 6, 26, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4579257, 195364, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4579399, 195368, 23061, 533, 184, 4091, 293, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4602497, 195906, 118, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4602618, 195910, 23167, 551, 184, 4496, 315, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4625822, 196466, 116, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4625941, 196470, 342, 6, 26, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4626298, 196479, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4626440, 196483, 144, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4626609, 196489, 168, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4626780, 196495, 28051, 731, 184, 6546, 460, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4654868, 197231, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4655001, 197235, 1609, 28, 94, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4656647, 197268, 145, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4656795, 197272, 402, 7, 23, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4657200, 197281, 401, 7, 23, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4657604, 197290, 401, 7, 23, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4658008, 197299, 247, 5, 19, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4658258, 197306, 19539, 493, 184, 4204, 298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4677812, 197802, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.3", "AOG2."}],
    Cell[4677997, 197810, 116, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.4", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678116, 197813, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678273, 197817, 380, 15, 203, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678678, 197836, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678807, 197840, 1462, 26, 198, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4680306, 197871, 116, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4680425, 197875, 652, 13, 39, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4681114, 197893, 197, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4681314, 197900, 132, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4681461, 197906, 120, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4681606, 197912, 142, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4681751, 197916, 29725, 703, 184, 5721, 401, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4711513, 198624, 153, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4711669, 198628, 134, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4711840, 198636, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4711997, 198640, 20416, 550, 184, 4840, 352, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4732450, 199195, 138, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4732591, 199199, 46075, 859, 377, 4774, 344, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4778703, 200063, 166, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4778872, 200069, 21023, 472, 184, 3388, 249, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4799910, 200544, 276, 6, 34, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4800211, 200554, 203, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4800417, 200561, 1857010, 45857, 240, 1775535, 44846, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[6657464, 246423, 277, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[6657744, 246431, 706903, 40556, 294, 616171, 39430, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[7364684, 286992, 279, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[7364966, 287000, 476455, 6607, 294, 247926, 3780, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[7841436, 293610, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.3", "AOG2."}]},
  "AOG3."->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[5247, 180, 206, 4, 24, "Outline1",
      CellTags->{"AOG3.", "AOG0.", "AOG3.3"}],
    Cell[5456, 186, 299, 10, 38, "Outline2",
      CellTags->{"AOG3.", "AOG0."}],
    Cell[5780, 200, 209, 4, 21, "Outline2",
      CellTags->{"AOG3.", "AOG0.", "AOG3.3"}],
    Cell[6391, 223, 418, 14, 55, "Outline2",
      CellTags->{"AOG3.", "AOG0."}],
    Cell[7841645, 293620, 99, 1, 61, "Section",
      CellTags->{"AOG0.", "3", "AOG3."}],
    Cell[7841769, 293625, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.1", "AOG3.", "AOG3.1"}],
    Cell[7841877, 293630, 101, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7841981, 293634, 328, 5, 80, "Print",
      CellTags->{"Info3312043331-3736878", "AOG3.", "AOG3.1"}],
    Cell[7842346, 293644, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7842457, 293648, 803, 13, 89, "Output",
      CellTags->{"AOG3.", "AOG3.1"}],
    Cell[7843275, 293664, 351, 9, 91, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7843651, 293677, 141, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7843795, 293681, 32764, 1445, 132, 20021, 1282, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.1"}],
    Cell[7876596, 295131, 154, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7876753, 295137, 1399, 25, 95, "Output",
      CellTags->{"AOG3.", "AOG3.1"}],
    Cell[7878189, 295167, 176, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7878368, 295174, 23705, 563, 103, "Output",
      CellTags->{"AOG3.", "AOG3.1"}],
    Cell[7902110, 295742, 193, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7902306, 295749, 3068, 76, 49, "Output",
      CellTags->{"AOG3.", "AOG3.1"}],
    Cell[7905389, 295828, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3."}],
    Cell[7905564, 295836, 99, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.2", "AOG3.", "AOG3.2"}],
    Cell[7905666, 295839, 228, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
    Cell[7905919, 295850, 131, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
    Cell[7906053, 295854, 30690, 1092, 222, 13662, 876, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.2"}],
    Cell[7936780, 296951, 177, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
    Cell[7936960, 296958, 378, 9, 67, "Output",
      CellTags->{"AOG3.", "AOG3.2"}],
    Cell[7937375, 296972, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
    Cell[7937499, 296976, 313, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.2"}],
    Cell[7937827, 296988, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3."}],
    Cell[7938002, 296996, 111, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.3", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7938138, 297001, 90, 1, 32, "Subsubsection",
      CellTags->{"AOG3.3.1", "AOG3.3", "3.3.1", "AOG3."}],
    Cell[7938231, 297004, 302, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7938558, 297016, 143, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7938704, 297020, 20886, 735, 110, 9824, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7959627, 297760, 209, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7959839, 297767, 2356, 61, 59, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7962232, 297833, 199, 5, 27, "Input",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7962434, 297840, 718, 14, 54, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7963189, 297859, 250, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7963442, 297867, 3786, 100, 59, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7967243, 297970, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3.3", "AOG3."}],
    Cell[7967428, 297978, 92, 1, 32, "Subsubsection",
      CellTags->{"AOG3.3.2", "AOG3.3", "3.3.2", "AOG3."}],
    Cell[7967523, 297981, 327, 9, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7967875, 297994, 150, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7968028, 297998, 20738, 716, 130, 9473, 571, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7988803, 298719, 224, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7989030, 298726, 5803, 148, 113, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7994870, 298879, 267, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7995140, 298887, 2059, 36, 227, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7997236, 298928, 214, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7997453, 298935, 584, 13, 69, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7998052, 298951, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3.3", "AOG3."}],
    Cell[7998237, 298959, 95, 1, 32, "Subsubsection",
      CellTags->{"AOG3.3.3", "AOG3.3", "3.3.3", "AOG3."}],
    Cell[7998335, 298962, 366, 9, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[7998704, 298973, 353, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[7999082, 298985, 151, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[7999236, 298989, 2110, 55, 101, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8001383, 299049, 149, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8001535, 299053, 633, 13, 71, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8002183, 299069, 403, 9, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8002611, 299082, 129, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8002743, 299086, 28330, 797, 213, 7004, 528, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8031110, 299888, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8031267, 299892, 2285, 59, 99, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8033589, 299956, 194, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8033786, 299963, 684, 14, 69, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8034507, 299982, 192, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8034702, 299989, 342, 9, 49, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8035081, 300003, 185, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8035269, 300010, 3689, 98, 99, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8038995, 300113, 204, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8039202, 300120, 5736, 148, 129, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8044975, 300273, 179, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8045157, 300279, 1156, 30, 79, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8046350, 300314, 200, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8046553, 300321, 2313, 48, 79, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8048903, 300374, 221, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8049127, 300381, 5566, 140, 89, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8054708, 300524, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3.3", "AOG3."}],
    Cell[8054905, 300533, 97, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.4", "AOG3.", "AOG3.4"}],
    Cell[8055005, 300536, 283, 7, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8055313, 300547, 131, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8055447, 300551, 21420, 742, 110, 9782, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8076904, 301298, 234, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8077141, 301305, 1133, 18, 142, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8078311, 301328, 244, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8078558, 301336, 1349, 25, 73, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8079944, 301366, 110, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8080057, 301370, 360, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8080454, 301384, 105, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8080562, 301388, 724, 15, 73, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8081323, 301408, 110, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8081436, 301412, 517, 12, 59, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8081968, 301427, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3."}],
    Cell[8082143, 301435, 106, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.5", "AOG3.", "AOG3.5"}],
    Cell[8082252, 301438, 187, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8082464, 301448, 129, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8082596, 301452, 14186, 465, 110, 6735, 367, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8096819, 301922, 176, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8096998, 301929, 352, 9, 67, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8097387, 301943, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8097496, 301947, 308, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8097841, 301961, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8097950, 301965, 317, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8098282, 301977, 197, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8098504, 301987, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8098637, 301991, 17341, 551, 110, 7606, 425, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8116015, 302547, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8116144, 302551, 13181, 381, 102, 3851, 260, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8129362, 302937, 181, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8129546, 302944, 400, 10, 69, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8129983, 302959, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8130097, 302963, 308, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8130442, 302977, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8130551, 302981, 324, 9, 67, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8130912, 302995, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8131026, 302999, 317, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8131358, 303011, 242, 8, 24, "Text",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8131603, 303021, 211, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8131839, 303031, 129, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8131971, 303035, 14838, 515, 110, 7298, 416, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8146846, 303555, 164, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8147013, 303561, 352, 9, 67, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8147402, 303575, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8147511, 303579, 308, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8147856, 303593, 197, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8148056, 303600, 2543, 70, 59, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8150614, 303673, 148, 4, 24, "Text",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8150765, 303679, 241, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8151031, 303689, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8151145, 303693, 21765, 551, 202, 3804, 324, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8172947, 304249, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8173076, 304253, 1631, 49, 115, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8174744, 304307, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8174853, 304311, 1051, 31, 99, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8175919, 304345, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3."}],
    Cell[8176094, 304353, 91, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.6", "AOG3.", "AOG3.6"}],
    Cell[8176210, 304358, 93, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8176306, 304362, 2733, 37, 320, "Print",
      CellTags->{"Info3312115087-1929230", "AOG3.", "AOG3.6"}],
    Cell[8179054, 304402, 328, 8, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8179407, 304414, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8179547, 304418, 23532, 617, 240, 7151, 409, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.6", "AOG0."}],
    Cell[8203116, 305040, 105, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8203224, 305044, 196, 4, 24, "Output",
      CellTags->{"AOG3.", "AOG3.6", "AOG0."}],
    Cell[8203457, 305053, 275, 7, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8203735, 305062, 901, 22, 75, "Output",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8204673, 305089, 105, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8204781, 305093, 393, 9, 85, "Output",
      CellTags->{"AOG3.", "AOG3.6", "AOG0."}],
    Cell[8205211, 305107, 271, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8205485, 305115, 314, 9, 49, "Output",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8205836, 305129, 185, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8206024, 305136, 1403, 23, 84, "Output",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8207442, 305162, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3."}]},
  "AOG4."->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[6846, 242, 266, 6, 24, "Outline1",
      CellTags->{
      "AOG4.", "AOG0.", "AOG4.1", "AOG4.2", "AOG4.3", "AOG4.4", "AOG4.5", 
        "AOG4.6"}],
    Cell[7115, 250, 183, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0."}],
    Cell[7323, 258, 207, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.2"}],
    Cell[7533, 264, 467, 18, 60, "Outline3",
      CellTags->{"AOG4.2", "AOG4."}],
    Cell[8037, 287, 212, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.3"}],
    Cell[8252, 293, 467, 18, 60, "Outline3",
      CellTags->{"AOG4.3", "AOG4."}],
    Cell[8756, 316, 206, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.4"}],
    Cell[8965, 322, 467, 18, 60, "Outline3",
      CellTags->{"AOG4.4", "AOG4."}],
    Cell[9469, 345, 208, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.5"}],
    Cell[9680, 351, 467, 18, 60, "Outline3",
      CellTags->{"AOG4.5", "AOG4."}],
    Cell[10184, 374, 203, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.6"}],
    Cell[10390, 380, 467, 18, 60, "Outline3",
      CellTags->{"AOG4.6", "AOG4."}],
    Cell[8207629, 305171, 110, 1, 61, "Section",
      CellTags->{"AOG0.", "4", "AOG4.", "AOG4.1"}],
    Cell[8207764, 305176, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.1", "AOG4.", "AOG4.1"}],
    Cell[8207872, 305181, 99, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8207974, 305185, 431, 6, 80, "Print",
      CellTags->{"Info3312043438-4643038", "AOG4.", "AOG4.1"}],
    Cell[8208442, 305196, 107, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8208552, 305200, 685, 11, 54, "Output",
      CellTags->{"AOG4.", "AOG4.1"}],
    Cell[8209274, 305216, 96, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8209373, 305220, 1395, 19, 155, "Print",
      CellTags->{"Info3405686992-9872384", "AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8210805, 305244, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8210914, 305248, 854, 15, 54, "Output",
      CellTags->{"AOG4.", "AOG4.1"}],
    Cell[8211805, 305268, 98, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8211906, 305272, 3519, 47, 425, "Print",
      CellTags->{"Info3312043439-7338271", "AOG4.", "AOG4.1"}],
    Cell[8215462, 305324, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8215571, 305328, 857, 14, 78, "Output",
      CellTags->{"AOG4.", "AOG4.1"}],
    Cell[8216443, 305345, 331, 9, 59, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8216799, 305358, 165, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8216967, 305364, 157592, 4062, 397, 41452, 2622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.1"}],
    Cell[8374574, 309429, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG4."}],
    Cell[8374749, 309437, 109, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.2", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8374883, 309442, 94, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.2.1", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8374980, 309445, 337, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8375342, 309457, 153, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8375498, 309461, 36774, 1565, 119, 21947, 1376, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8412309, 311031, 204, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8412516, 311038, 3171, 77, 49, "Output",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8415724, 311120, 255, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8415982, 311127, 3042, 82, 59, "Output",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8419039, 311212, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2"}],
    Cell[8419224, 311220, 101, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.2.2", "AOG4.", "AOG4.2", "AOG4.2.2"}],
    Cell[8419350, 311225, 134, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.2"}],
    Cell[8419487, 311229, 4148, 71, 204, "Output",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.2"}],
    Cell[8423650, 311303, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2"}],
    Cell[8423835, 311311, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.2.3", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8423960, 311316, 133, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8424096, 311320, 41750, 905, 184, 10085, 508, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8465883, 312230, 176, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8466062, 312236, 40778, 891, 184, 10370, 510, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8506877, 313132, 185, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8507087, 313141, 42205, 924, 184, 10651, 529, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8549295, 314067, 40885, 946, 184, 11239, 574, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8590229, 315019, 199, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8590431, 315026, 99253, 2755, 184, 29018, 1882, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8689687, 317783, 3595, 64, 210, "Output",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8693297, 317850, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2"}],
    Cell[8693482, 317858, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.2.4", "AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8693607, 317863, 176, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8693786, 317869, 82869, 3386, 119, 44933, 2912, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8776692, 321260, 179, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8776874, 321266, 86168, 3632, 119, 49560, 3174, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8863057, 324901, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2"}],
    Cell[8863254, 324910, 114, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.3", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863393, 324915, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.1", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863490, 324918, 327, 9, 96, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863842, 324931, 139, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863984, 324935, 110082, 2058, 598, 14663, 874, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8974103, 326998, 244, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8974350, 327005, 3583, 98, 109, "Output",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8977970, 327108, 245, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8978218, 327115, 3609, 98, 109, "Output",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8981842, 327216, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3"}],
    Cell[8982027, 327224, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.2", "AOG4.", "AOG4.3", "AOG4.3.2"}],
    Cell[8982153, 327229, 138, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.2"}],
    Cell[8982294, 327233, 4394, 75, 213, "Output",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.2"}],
    Cell[8986703, 327311, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3"}],
    Cell[8986888, 327319, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.3", "AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[8987013, 327324, 137, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[8987175, 327330, 36915, 812, 184, 8790, 459, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[9024093, 328144, 35572, 827, 184, 9311, 497, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[9059680, 328974, 5041, 92, 284, "Output",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[9064736, 329069, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3"}],
    Cell[9064921, 329077, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.4", "AOG4.", "AOG4.3", "AOG4.3.4"}],
    Cell[9065046, 329082, 191, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.4"}],
    Cell[9065240, 329089, 346463, 19400, 562, 207570, 17680, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.4"}],
    Cell[9411718, 348492, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3"}],
    Cell[9411915, 348501, 108, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.4", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412048, 348506, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.1", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412145, 348509, 338, 8, 96, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412508, 348521, 132, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412643, 348525, 93072, 1898, 564, 16306, 945, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9505752, 350428, 202, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9505957, 350435, 5040, 126, 91, "Output",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9511034, 350566, 181, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9511218, 350573, 1280, 30, 79, "Output",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9512513, 350606, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4"}],
    Cell[9512698, 350614, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.2", "AOG4.", "AOG4.4", "AOG4.4.2"}],
    Cell[9512824, 350619, 131, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.2"}],
    Cell[9512958, 350623, 6349, 112, 293, "Output",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.2"}],
    Cell[9519322, 350738, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4"}],
    Cell[9519507, 350746, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.3", "AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9519632, 350751, 131, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9519788, 350757, 41693, 926, 184, 10477, 535, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9561484, 351685, 41582, 925, 184, 10475, 535, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9603093, 352614, 88, 2, 28, "Input",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9603206, 352620, 181, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9603412, 352629, 42973, 944, 184, 10888, 542, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9646388, 353575, 40331, 937, 184, 11240, 572, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9686722, 354514, 43028, 945, 184, 10880, 542, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9729753, 355461, 40128, 935, 184, 11183, 572, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9769908, 356400, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4"}],
    Cell[9770093, 356408, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.4", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9770218, 356413, 176, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9770397, 356419, 88137, 4899, 120, 72452, 4700, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9858571, 361323, 177, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9858751, 361329, 90758, 4928, 84, 72786, 4700, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9949546, 366262, 149, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9949698, 366266, 149230, 11357, 188, 129962, 11114, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[10098943, 377626, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4"}],
    Cell[10099140, 377635, 110, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.5", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099275, 377640, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.1", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099372, 377643, 346, 8, 79, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099743, 377655, 129, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099875, 377659, 38235, 962, 255, 7596, 578, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10138147, 378626, 181, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10138331, 378633, 3947, 102, 99, "Output",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10142315, 378740, 178, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10142496, 378746, 706, 13, 37, "Output",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10143217, 378762, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5"}],
    Cell[10143402, 378770, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.2", "AOG4.", "AOG4.5", "AOG4.5.2"}],
    Cell[10143528, 378775, 128, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.2"}],
    Cell[10143659, 378779, 4428, 75, 197, "Output",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.2"}],
    Cell[10148102, 378857, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5"}],
    Cell[10148287, 378865, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.3", "AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10148412, 378870, 128, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10148565, 378876, 32374, 762, 184, 8941, 467, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10180942, 379640, 31278, 725, 184, 8566, 439, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10212269, 380371, 177, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10212471, 380379, 37055, 821, 184, 9279, 472, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10249529, 381202, 34566, 816, 184, 9626, 502, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10284098, 382020, 34157, 774, 184, 8978, 457, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10318258, 382796, 34380, 793, 184, 9314, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10352665, 383593, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5"}],
    Cell[10352850, 383601, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.4", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10352975, 383606, 173, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10353151, 383612, 89292, 3811, 161, 52391, 3350, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10442480, 387428, 174, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10442657, 387434, 118017, 4167, 187, 52312, 3350, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10560711, 391606, 146, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10560860, 391610, 148094, 9129, 255, 95739, 8477, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10708969, 400742, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5"}],
    Cell[10709166, 400751, 93, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.6", "AOG4.", "AOG4.6"}],
    Cell[10709284, 400756, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.1", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10709381, 400759, 277, 9, 113, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10709683, 400772, 131, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10709817, 400776, 36106, 1082, 221, 9515, 748, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10745960, 401863, 202, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10746165, 401870, 6240, 154, 91, "Output",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10752420, 402027, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4."}],
    Cell[10752595, 402035, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.2", "AOG4.", "AOG4.6", "AOG4.6.2"}],
    Cell[10752721, 402040, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.2"}],
    Cell[10752854, 402044, 7613, 135, 325, "Output",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.2"}],
    Cell[10760482, 402182, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4."}],
    Cell[10760657, 402190, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.3", "AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10760782, 402195, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10760937, 402201, 47820, 1097, 184, 12909, 660, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10808760, 403300, 47419, 1044, 184, 12063, 602, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10856228, 404350, 179, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10856432, 404358, 50096, 1104, 184, 12892, 639, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10906531, 405464, 49448, 1121, 184, 13308, 669, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10955982, 406587, 50236, 1118, 184, 13097, 654, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[11006221, 407707, 47195, 1046, 184, 12495, 612, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[11053443, 408757, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG4."}],
    Cell[11053618, 408765, 100, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.6.4", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11053743, 408770, 175, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11053921, 408776, 109765, 5291, 132, 76369, 4873, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11163723, 414072, 176, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11163902, 414078, 110499, 5298, 132, 76572, 4873, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11274438, 419381, 148, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11274589, 419385, 172454, 12925, 220, 141061, 12532, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11447058, 432313, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG4."}]},
  "AOG5."->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[10906, 404, 192, 4, 24, "Outline1",
      CellTags->{"AOG5.", "AOG0."}],
    Cell[11101, 410, 828, 30, 123, "Outline2",
      CellTags->{"AOG5.", "AOG0."}],
    Cell[11447257, 432323, 89, 1, 61, "Section",
      CellTags->{"AOG0.", "5", "AOG5.", "AOG5.1"}],
    Cell[11447371, 432328, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.1", "AOG5.", "AOG5.1"}],
    Cell[11447457, 432331, 961, 30, 52, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11448421, 432363, 162, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11448586, 432370, 143, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11448754, 432376, 132, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11448889, 432380, 18000, 700, 108, 9825, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11466926, 433085, 154, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11467083, 433091, 37157, 811, 296, 5217, 411, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11504243, 433904, 911, 21, 39, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11505191, 433930, 164, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11505358, 433936, 3206, 62, 116, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11508601, 434003, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11508756, 434009, 41903, 1030, 184, 7990, 606, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11550662, 435041, 36319, 958, 184, 7975, 602, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11586984, 436001, 37745, 969, 184, 7841, 594, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11624744, 436973, 6543, 132, 215, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11631324, 437110, 89, 2, 28, "Input",
      CellTags->{"AOG5.", "AOG5.1", "AOG0."}],
    Cell[11631416, 437114, 178, 3, 21, "Print",
      CellTags->{"Info3314357094-6023310", "AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11631631, 437122, 113, 2, 28, "Input",
      CellTags->{"AOG5.", "AOG5.1", "AOG0."}],
    Cell[11631747, 437126, 872, 15, 53, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11632656, 437146, 212, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11632871, 437153, 68812, 1277, 184, 7759, 518, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11701686, 438432, 7662, 157, 263, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11709385, 438594, 89, 2, 28, "Input",
      CellTags->{"AOG5.", "AOG5.1", "AOG0."}],
    Cell[11709477, 438598, 185, 3, 21, "Print",
      CellTags->{"Info3314357094-2851735", "AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11709699, 438606, 116, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11709818, 438610, 63980, 2419, 184, 29521, 1988, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11773801, 441031, 8702, 179, 295, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11782540, 441215, 187, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11782752, 441224, 37530, 862, 184, 7018, 480, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11820285, 442088, 36028, 1075, 184, 10669, 756, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11856328, 443166, 5496, 107, 215, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11861839, 443276, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[11862014, 443284, 136, 3, 36, "Subsection",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862153, 443289, 222, 6, 24, "Text",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862378, 443297, 403, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862806, 443312, 164, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862973, 443318, 45971, 2101, 172, 29226, 1887, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11908959, 445422, 396, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909380, 445437, 180, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909563, 445443, 32739, 1619, 83, 23569, 1499, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11942317, 447065, 307, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942649, 447078, 168, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942820, 447084, 23044, 764, 184, 7539, 566, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11965879, 447851, 270, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966174, 447864, 167, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966344, 447870, 23401, 764, 177, 7452, 560, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11989760, 448637, 288, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11990051, 448648, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[11990226, 448656, 93, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.2", "AOG5.", "AOG5.2"}],
    Cell[11990344, 448661, 104, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11990451, 448665, 985, 14, 133, "Print",
      CellTags->{"Info3314357110-3725464", "AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11991473, 448684, 112, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11991588, 448688, 691, 11, 53, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11992316, 448704, 108, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11992427, 448708, 3921, 79, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11996363, 448790, 241, 5, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11996629, 448799, 165, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11996797, 448805, 3727, 72, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12000539, 448880, 131, 3, 24, "Text",
      CellTags->{"AOG5.", "AOG5.2", "AOG0."}],
    Cell[12000695, 448887, 99, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12000797, 448891, 143, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12000977, 448899, 129, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12001109, 448903, 3977, 80, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12005123, 448988, 98, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12005224, 448992, 128, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12005389, 449000, 154, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12005546, 449006, 4021, 81, 149, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12009604, 449092, 98, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12009705, 449096, 129, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12009871, 449104, 154, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12010028, 449110, 4021, 81, 149, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12014086, 449196, 98, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12014187, 449200, 129, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12014353, 449208, 155, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12014511, 449214, 4024, 81, 149, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12018572, 449300, 98, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12018673, 449304, 129, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12018817, 449310, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[12018992, 449318, 88, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.3", "AOG5.", "AOG5.3"}],
    Cell[12019105, 449323, 99, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12019207, 449327, 2249, 30, 261, "Print",
      CellTags->{"Info3314357173-7371059", "AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12021493, 449362, 107, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12021603, 449366, 1067, 18, 69, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12022707, 449389, 114, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12022846, 449395, 41903, 1030, 184, 7990, 606, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12064752, 450427, 36319, 958, 184, 7975, 602, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12101074, 451387, 37745, 969, 184, 7841, 594, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12138834, 452359, 6543, 132, 215, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12145414, 452496, 105, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12145544, 452502, 38714, 1025, 184, 8462, 646, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12184261, 453529, 37187, 888, 184, 6313, 501, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12221463, 454420, 10050, 189, 475, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12231550, 454614, 119, 2, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[12231694, 454620, 199641, 3801, 240, 79047, 2307, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12431338, 458423, 180895, 3558, 240, 78840, 2292, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12612248, 461984, 10065, 189, 475, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12622350, 462178, 122, 2, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[12622497, 462184, 194995, 3736, 240, 78945, 2298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12817495, 465922, 170763, 3446, 240, 79231, 2310, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12988273, 469371, 11888, 224, 678, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13000198, 469600, 161, 4, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[13000384, 469608, 38848, 1032, 184, 8584, 653, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13039235, 470642, 38537, 983, 184, 7582, 595, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13077787, 471628, 10027, 187, 474, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13087851, 471820, 120, 2, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[13087996, 471826, 43416, 1045, 184, 8076, 603, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13131415, 472873, 36477, 971, 184, 7821, 612, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13167895, 473846, 41994, 1017, 184, 7928, 591, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13209904, 474866, 5816, 121, 197, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13215757, 474992, 159, 4, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[13215941, 475000, 40932, 1136, 184, 11670, 769, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13256876, 476138, 42076, 1333, 184, 13471, 974, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13298955, 477473, 42145, 1225, 184, 12736, 856, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13341103, 478700, 50893, 2299, 184, 31991, 2060, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13392011, 481002, 7934, 162, 277, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13399960, 481167, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[13400135, 481175, 117, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.4", "AOG5.", "AOG5.4"}],
    Cell[13400277, 481180, 95, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13400375, 481184, 668, 9, 101, "Print",
      CellTags->{"Info3313756493-3229688", "AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13401080, 481198, 102, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13401185, 481202, 612, 9, 69, "Print",
      CellTags->{"Info3313756493-6366474", "AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13401812, 481214, 284, 9, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13402121, 481227, 200, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13402324, 481234, 3505, 59, 179, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13405844, 481296, 191, 6, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13406060, 481306, 217, 6, 45, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13406280, 481314, 3055, 52, 174, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13409350, 481369, 307, 9, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13409682, 481382, 118, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13409803, 481386, 105, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13409923, 481392, 358, 11, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13410306, 481407, 233, 6, 45, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13410564, 481417, 192800, 3706, 240, 78969, 2295, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13603367, 485125, 180434, 3545, 240, 78628, 2283, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13783816, 488673, 5175, 89, 316, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13789028, 488767, 232, 6, 45, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13789285, 488777, 195534, 3747, 240, 79084, 2304, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13984822, 492526, 187013, 3629, 240, 78678, 2286, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[14171850, 496158, 3295, 56, 177, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[14175160, 496217, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[14175335, 496225, 94, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.5", "AOG5.", "AOG5.5"}],
    Cell[14175454, 496230, 104, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14175561, 496234, 2241, 30, 245, "Print",
      CellTags->{"Info3313756675-1546738", "AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14177839, 496269, 112, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14177954, 496273, 871, 15, 53, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14178862, 496293, 115, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14178980, 496297, 37114, 994, 184, 10001, 654, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14216097, 497293, 11361, 216, 490, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14227495, 497514, 103, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14227601, 497518, 1375, 24, 85, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14229013, 497547, 99, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14229115, 497551, 1550, 26, 85, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14230702, 497582, 187, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14230892, 497589, 4547063, 118157, 417, 4426191, 116659, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[18777958, 615748, 11435, 217, 506, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[18789430, 615970, 237, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[18789692, 615979, 828845, 19100, 240, 744099, 18048, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[19618540, 635081, 886309, 21393, 240, 773223, 19991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[20504864, 656477, 138, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[20505005, 656482, 150, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[20505158, 656487, 288, 6, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[20505449, 656495, 1470311, 37080, 240, 1380128, 35961, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[21975763, 693577, 13461, 255, 710, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[21989261, 693837, 163, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[21989449, 693845, 40142, 1116, 184, 9891, 737, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22029594, 694963, 38933, 1009, 184, 8007, 622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22068530, 695974, 39339, 1134, 184, 12199, 793, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22107884, 697111, 11634, 221, 522, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22119555, 697337, 133, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22119713, 697343, 43307, 1132, 184, 10122, 717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22163023, 698477, 39137, 1142, 184, 10505, 783, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22202163, 699621, 42030, 1106, 184, 9997, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22244196, 700729, 65079, 2608, 184, 34509, 2225, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22309290, 703340, 7931, 162, 277, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22317236, 703505, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[22317411, 703513, 98, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.6", "AOG5.", "AOG5.6"}],
    Cell[22317534, 703518, 108, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22317645, 703522, 2525, 34, 277, "Print",
      CellTags->{"Info3313758703-7146727", "AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22320207, 703561, 88, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22320298, 703565, 185, 3, 21, "Print",
      CellTags->{"Info3313758707-6863980", "AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22320520, 703573, 133, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22320678, 703579, 43307, 1132, 184, 10122, 717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22363988, 704713, 39137, 1142, 184, 10505, 783, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22403128, 705857, 42030, 1106, 184, 9997, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22445161, 706965, 97868, 4625, 184, 66119, 4227, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22543032, 711592, 95030, 4859, 184, 69887, 4543, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22638077, 716454, 9111, 193, 309, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22647225, 716652, 163, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22647413, 716660, 40550, 1088, 184, 9985, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22687966, 717750, 39253, 1147, 184, 10579, 787, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22727222, 718899, 38293, 1026, 184, 9620, 666, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22765518, 719927, 98791, 3569, 184, 45317, 2903, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22864312, 723498, 94923, 4858, 184, 69885, 4543, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22959250, 728359, 9124, 194, 309, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22968411, 728558, 213, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22968649, 728567, 74776, 2964, 184, 45615, 2598, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23043428, 731533, 39544, 1159, 184, 10769, 798, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23082975, 732694, 72503, 2901, 184, 45236, 2559, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23155481, 735597, 105314, 2770, 184, 28117, 1811, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23260798, 738369, 138149, 3208, 184, 28610, 1850, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23398950, 741579, 60746, 2744, 184, 37105, 2446, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23459711, 744326, 10007, 211, 325, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23469755, 744542, 196, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23469976, 744551, 40142, 1116, 184, 9891, 737, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23510121, 745669, 38933, 1009, 184, 8007, 622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23549057, 746680, 52601, 1863, 184, 23105, 1493, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23601661, 748545, 47236, 1741, 184, 20670, 1407, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23648912, 750289, 14210, 264, 571, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23663159, 750558, 180, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23663364, 750567, 452698, 10085, 240, 310409, 8323, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[24116065, 760654, 429598, 9805, 240, 310502, 8329, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[24545666, 770461, 421611, 9666, 240, 310153, 8284, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[24967280, 780129, 423249, 9686, 240, 310876, 8293, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[25390532, 789817, 418502, 9653, 240, 309986, 8308, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[25809037, 799472, 429067, 9781, 240, 311218, 8320, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26238119, 809256, 13847, 271, 570, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26252003, 809532, 171, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26252199, 809541, 34175, 909, 184, 7350, 572, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26286377, 810452, 35960, 954, 184, 7691, 599, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26322352, 811409, 138, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26322493, 811414, 150, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26322646, 811419, 288, 6, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26322959, 811429, 74489, 3882, 184, 57210, 3663, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26397451, 815313, 63439, 2769, 184, 36903, 2436, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26460905, 818085, 15009, 290, 726, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26475951, 818380, 60, 1, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26476014, 818383, 20915, 596, 184, 6122, 408, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26496932, 818981, 139, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26497074, 818986, 151, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26497228, 818991, 287, 6, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26497540, 819001, 57081, 1864, 184, 21898, 1424, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26554624, 820867, 43191, 1362, 184, 14532, 1003, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26597830, 822232, 12156, 233, 646, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26610001, 822468, 160, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26610186, 822476, 173, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26610384, 822485, 39944, 1102, 184, 9680, 723, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26650331, 823589, 39703, 1010, 184, 7652, 609, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26690037, 824601, 81421, 3296, 184, 44018, 2829, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26771461, 827899, 53111, 2128, 184, 26687, 1796, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26824587, 830030, 15864, 295, 711, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26840488, 830330, 237, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26840750, 830339, 798817, 17930, 240, 727412, 17043, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[27639570, 848271, 908874, 21607, 240, 776089, 19962, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[28548447, 869880, 884664, 20481, 240, 747392, 18781, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[29433114, 890363, 660892, 11348, 240, 626118, 10913, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[30094009, 901713, 892457, 21405, 240, 771316, 19904, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[30986469, 923120, 899107, 21450, 240, 775815, 19922, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[31885603, 944574, 138, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG5."}],
    Cell[31885778, 944582, 103, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.7", "AOG5.", "AOG5.7"}],
    Cell[31885906, 944587, 113, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31886022, 944591, 2818, 39, 293, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31888877, 944635, 121, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31889001, 944639, 597, 11, 37, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31889635, 944655, 135, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31889773, 944659, 32192, 876, 184, 8533, 578, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31921968, 945537, 5295, 105, 197, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31927300, 945647, 158, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31927461, 945653, 436020, 9680, 240, 321363, 8259, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32363484, 955335, 3211, 65, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32366732, 955405, 158, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32366893, 955411, 436020, 9680, 240, 321363, 8259, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32802916, 965093, 3211, 65, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32806164, 965163, 188, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32806355, 965170, 435803, 9723, 240, 322053, 8313, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33242161, 974895, 3169, 66, 117, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33245367, 974966, 202, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33245594, 974975, 33233, 941, 184, 9531, 643, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33278830, 975918, 40894, 1541, 184, 18503, 1259, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33319739, 977462, 6703, 134, 234, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33326479, 977601, 115, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33326597, 977605, 24999, 556, 184, 4249, 294, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33351599, 978163, 5202, 103, 174, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33356838, 978271, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33356978, 978275, 48849, 1770, 184, 22034, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33405830, 980047, 5242, 104, 174, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33411087, 980154, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG5."}]},
  "AOG6."->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[11966, 445, 241, 4, 24, "Outline1",
      CellTags->{"AOG6.", "AOG0.", "AOG6.2", "AOG6.3", "AOG6.4"}],
    Cell[12210, 451, 183, 4, 21, "Outline2",
      CellTags->{"AOG6.", "AOG0."}],
    Cell[12418, 459, 211, 4, 21, "Outline2",
      CellTags->{"AOG6.", "AOG0.", "AOG6.2"}],
    Cell[12632, 465, 558, 22, 74, "Outline3",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[13227, 492, 211, 4, 21, "Outline2",
      CellTags->{"AOG6.", "AOG0.", "AOG6.3"}],
    Cell[13441, 498, 380, 14, 46, "Outline3",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3"}],
    Cell[13858, 517, 229, 4, 21, "Outline2",
      CellTags->{"AOG6.", "AOG6.4", "AOG0."}],
    Cell[14090, 523, 953, 34, 116, "Outline3",
      CellTags->{"AOG6.", "AOG6.4", "AOG0."}],
    Cell[33411274, 980163, 108, 1, 61, "Section",
      CellTags->{"AOG0.", "6", "AOG6.", "AOG6.1"}],
    Cell[33411407, 980168, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.1", "AOG6.", "AOG6.1"}],
    Cell[33411493, 980171, 468, 12, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33411986, 980187, 99, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33412088, 980191, 1298, 18, 140, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33413423, 980214, 107, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33413533, 980218, 427, 8, 39, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33413997, 980231, 101, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33414101, 980235, 1386, 20, 155, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33415524, 980260, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33415636, 980264, 452, 9, 39, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33416103, 980276, 138, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6."}],
    Cell[33416278, 980284, 113, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.2", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416416, 980289, 97, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.2.1", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416516, 980292, 268, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416809, 980303, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416942, 980307, 26152, 499, 294, 3133, 209, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33443131, 980811, 127, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33443283, 980817, 31937, 760, 184, 5582, 428, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33475223, 981579, 31390, 839, 184, 6685, 528, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33506616, 982420, 34255, 890, 184, 6802, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33540874, 983312, 31849, 759, 184, 5579, 428, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33572726, 984073, 29320, 762, 184, 6043, 468, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33602049, 984837, 34167, 889, 184, 6799, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33636231, 985729, 4495, 102, 103, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33640763, 985836, 148, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33640936, 985842, 34077, 742, 184, 4736, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33675016, 986586, 33676, 820, 184, 5754, 469, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33708695, 987408, 34749, 841, 184, 5853, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33743447, 988251, 34082, 742, 184, 4741, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33777532, 988995, 31696, 744, 184, 5101, 409, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33809231, 989741, 34766, 841, 184, 5858, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33844012, 990585, 4615, 104, 103, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33848664, 990694, 148, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33848837, 990700, 34077, 742, 196, 4736, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33882917, 991444, 33676, 820, 184, 5754, 469, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33916596, 992266, 34749, 841, 184, 5853, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33951348, 993109, 34082, 742, 184, 4741, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33985433, 993853, 31696, 744, 184, 5101, 409, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34017132, 994599, 34766, 841, 184, 5858, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34051913, 995443, 4615, 104, 115, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34056565, 995552, 149, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34056717, 995556, 147529, 3003, 184, 20809, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34204283, 998564, 143, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34204451, 998570, 34368, 765, 184, 5216, 400, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34238822, 999337, 34363, 765, 184, 5211, 400, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34273188, 1000104, 147529, 3003, 184, 20809, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34420744, 1003111, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[34420929, 1003119, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.2", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34421029, 1003122, 263, 7, 79, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34421317, 1003133, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34421450, 1003137, 16000, 372, 294, 3244, 209, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34437487, 1003514, 127, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34437639, 1003520, 38504, 1002, 184, 7743, 617, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34476146, 1004524, 33813, 909, 196, 7329, 577, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34509962, 1005435, 34759, 910, 196, 7134, 563, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34544724, 1006347, 31351, 776, 196, 5814, 455, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34576078, 1007125, 70322, 1881, 196, 17739, 1226, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34646403, 1009008, 31765, 880, 196, 7001, 569, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34678183, 1009891, 4497, 102, 113, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34682717, 1009998, 145, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34682865, 1010002, 137262, 2773, 196, 19098, 1309, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34820142, 1012778, 148, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[34820327, 1012786, 97, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.2.3", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820427, 1012789, 205, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820657, 1012798, 160, 4, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820820, 1012804, 117, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820952, 1012810, 570, 11, 54, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34821525, 1012823, 612, 14, 102, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34822140, 1012839, 216, 5, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34822359, 1012846, 387, 9, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34822749, 1012857, 317, 7, 86, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823069, 1012866, 346, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823418, 1012876, 271, 7, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823692, 1012885, 176, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823871, 1012892, 412, 12, 176, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34824308, 1012908, 252, 6, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34824563, 1012916, 255229, 17819, 108, 243002, 17662, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35079829, 1030740, 125, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35079979, 1030746, 34663, 850, 196, 6370, 494, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35114645, 1031598, 36075, 1004, 184, 8345, 655, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35150723, 1032604, 37944, 973, 184, 7459, 590, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35188716, 1033583, 125, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35188866, 1033589, 33930, 886, 196, 6830, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35222799, 1034477, 38325, 998, 184, 7903, 616, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35261127, 1035477, 34238, 847, 184, 6386, 497, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35295414, 1036330, 132, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35295549, 1036334, 112461, 5760, 196, 82833, 5389, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35408047, 1042099, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35408202, 1042103, 134181, 2677, 184, 18234, 1240, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35542398, 1044783, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[35542583, 1044791, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.4", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35542683, 1044794, 184, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35542892, 1044803, 159, 4, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35543054, 1044809, 116, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35543185, 1044815, 569, 11, 42, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35543757, 1044828, 611, 14, 90, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35544371, 1044844, 216, 5, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35544590, 1044851, 387, 9, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35544980, 1044862, 317, 7, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35545300, 1044871, 271, 7, 62, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35545574, 1044880, 453, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35546030, 1044896, 453, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35546508, 1044914, 224, 5, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35546735, 1044921, 242133, 16878, 96, 229517, 16717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35788905, 1061804, 123, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35789053, 1061810, 36664, 981, 184, 7713, 617, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35825720, 1062793, 34235, 867, 184, 6836, 522, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35859958, 1063662, 36640, 928, 184, 7075, 557, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35896601, 1064592, 35085, 928, 184, 7256, 578, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35931689, 1065522, 34610, 867, 184, 6827, 518, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35966302, 1066391, 35177, 916, 184, 7115, 563, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36001494, 1067310, 4483, 102, 103, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36006014, 1067417, 146, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36006185, 1067423, 30191, 708, 184, 5167, 394, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36036379, 1068133, 28987, 725, 184, 5510, 430, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36065369, 1068860, 125533, 2582, 184, 17966, 1249, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36190929, 1071446, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[36191114, 1071454, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.5", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36191236, 1071459, 110, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36191349, 1071463, 2033, 28, 245, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36193397, 1071494, 496, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36193918, 1071512, 137, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36194058, 1071516, 90561, 4663, 155, 64954, 4341, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36284656, 1076184, 132, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36284791, 1076188, 430, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36285246, 1076201, 38263, 993, 184, 7907, 613, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36323512, 1077196, 37836, 1006, 184, 7715, 629, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36361351, 1078204, 33767, 897, 184, 7337, 565, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36395133, 1079104, 430, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36395588, 1079117, 40299, 975, 184, 7456, 564, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36435890, 1080094, 37729, 995, 184, 7575, 617, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36473622, 1081091, 39196, 1049, 184, 8464, 664, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36512833, 1082143, 5351, 116, 133, "Output",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36518221, 1082264, 126, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36518350, 1082268, 82209, 1966, 184, 16581, 1150, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36600596, 1084239, 121, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36600720, 1084243, 430, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36601153, 1084254, 34482, 947, 184, 8125, 616, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36635638, 1085203, 430, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36636093, 1085216, 40415, 1127, 184, 9682, 742, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36676511, 1086345, 82338, 1965, 184, 16582, 1148, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36758864, 1088313, 805, 18, 37, "Output",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36759684, 1088334, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[36759881, 1088343, 113, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.3", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760019, 1088348, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.1", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760119, 1088351, 271, 7, 79, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760415, 1088362, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760548, 1088366, 18194, 504, 294, 5438, 341, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[36778779, 1088875, 168, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36778950, 1088881, 438, 9, 21, "Print",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[36779413, 1088894, 143855, 3133, 240, 79529, 2333, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[36923271, 1092029, 162174, 3372, 239, 79437, 2345, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37085448, 1095403, 154268, 3257, 240, 79379, 2327, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37239731, 1098663, 438, 9, 21, "Print",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37240194, 1098676, 173933, 3512, 240, 79826, 2345, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37414130, 1102190, 162174, 3372, 239, 79437, 2345, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37576307, 1105564, 183408, 3625, 240, 79670, 2339, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37759730, 1109192, 9907, 192, 548, "Output",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37769674, 1109389, 182, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[37769859, 1109396, 2911809, 38632, 556, 1527231, 21533, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->{"AOG6.3.1", "AOG6.3", "AOG6.", "AOG0."}],
    Cell[40681671, 1148030, 999, 21, 39, "Output",
      CellTags->{"AOG6.3.1", "AOG6.3", "AOG6.", "AOG0."}],
    Cell[40682685, 1148054, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3"}],
    Cell[40682870, 1148062, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.2", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40682970, 1148065, 205, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40683178, 1148072, 253, 9, 113, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40683456, 1148085, 154, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40683613, 1148089, 39323, 1977, 170, 27027, 1820, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40722951, 1150069, 374, 11, 147, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40723350, 1150084, 154, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40723507, 1150088, 46321, 2316, 164, 32510, 2140, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40769865, 1152409, 241, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40770109, 1152415, 438, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40770572, 1152428, 173771, 3473, 70, 78845, 2295, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40944346, 1155903, 196112, 3769, 70, 79217, 2319, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41140461, 1159674, 187658, 3642, 70, 78851, 2292, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41328134, 1163319, 5191, 100, 70, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41333362, 1163424, 137, 2, 24, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[41333502, 1163428, 438, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41333965, 1163441, 173760, 3468, 240, 78767, 2289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41507728, 1166911, 196382, 3766, 70, 79221, 2313, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41704113, 1170679, 187901, 3638, 70, 78920, 2286, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41892029, 1174320, 8304, 149, 524, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41900370, 1174474, 167, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[41900540, 1174480, 468481, 6384, 446, 105436, 1896, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[42369024, 1180866, 1174, 25, 37, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[42370213, 1180894, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3"}],
    Cell[42370398, 1180902, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.3", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42370498, 1180905, 509, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42371032, 1180923, 118, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42371153, 1180927, 121445, 4136, 313, 62819, 3407, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42492635, 1185068, 135, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42492773, 1185072, 438, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42493214, 1185083, 274996, 12364, 294, 172862, 11097, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42768213, 1197449, 438, 9, 20, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42768676, 1197462, 366904, 16950, 294, 240110, 15379, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[43135583, 1214414, 347371, 4783, 294, 103986, 1773, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[43482969, 1219200, 994, 21, 39, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[43484000, 1219226, 221, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[43484224, 1219233, 896803, 21536, 240, 771968, 19989, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[44381042, 1240772, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3"}],
    Cell[44381239, 1240781, 143, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.4", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2"}],
    Cell[44381407, 1240786, 142, 2, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "6.4.1", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
    Cell[44381552, 1240790, 1606, 33, 86, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
    Cell[44383161, 1240825, 155, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44383353, 1240833, 164, 2, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.4.2", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383520, 1240837, 263, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383786, 1240845, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383915, 1240849, 226, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44384144, 1240859, 1133, 28, 379, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44385280, 1240889, 155, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44385472, 1240897, 225, 3, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.4.3", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44385700, 1240902, 669, 16, 40, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386372, 1240920, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386583, 1240926, 316, 10, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386902, 1240938, 2463, 77, 1003, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44389368, 1241017, 155, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44389560, 1241025, 122, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.4", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44389707, 1241030, 206, 6, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44389916, 1241038, 2635, 61, 286, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44392588, 1241104, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44392765, 1241110, 143828, 7167, 306, 99609, 6616, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44536630, 1248282, 139, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44536772, 1248286, 6413, 90, 444, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44543222, 1248381, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44543375, 1248385, 33679, 1164, 196, 13916, 915, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44577091, 1249554, 184, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44577278, 1249560, 322724, 6787, 252, 197914, 5241, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44900017, 1256350, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44900209, 1256358, 116, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.5", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900328, 1256361, 231, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900584, 1256372, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900761, 1256378, 59743, 2242, 118, 27984, 1844, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960519, 1258623, 140, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960684, 1258629, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960839, 1258633, 22963, 536, 196, 4136, 298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44983839, 1259174, 188, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44984030, 1259181, 293073, 6331, 252, 196329, 5131, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[45277118, 1265515, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[45277310, 1265523, 117, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.6", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277452, 1265528, 250, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277705, 1265537, 162, 3, 33, "Print",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277870, 1265542, 185, 4, 33, "Print",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45278092, 1265551, 175, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45278270, 1265557, 66621, 3547, 118, 52710, 3370, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45344928, 1269109, 182, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345113, 1269115, 142, 3, 33, "Output",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345292, 1269123, 153, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345448, 1269127, 43921, 1277, 196, 13678, 898, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45389406, 1270409, 151, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45389560, 1270413, 38725, 1189, 196, 13204, 868, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45428322, 1271607, 188, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45428513, 1271614, 888988, 21267, 252, 784101, 19967, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[46317516, 1292884, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[46317708, 1292892, 119, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.7", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46317852, 1292897, 249, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318104, 1292906, 170, 3, 33, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318277, 1292911, 193, 4, 33, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318507, 1292920, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318684, 1292926, 85537, 4877, 118, 72275, 4708, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404258, 1297808, 181, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404442, 1297814, 149, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404628, 1297822, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404783, 1297826, 53325, 1414, 196, 13928, 922, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46458145, 1299245, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46458298, 1299249, 45215, 1380, 196, 15333, 1006, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46503550, 1300634, 185, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46503738, 1300640, 881315, 21061, 252, 782915, 19841, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[47385068, 1321704, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[47385260, 1321712, 132, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.8", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385395, 1321715, 255, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385675, 1321724, 264, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385942, 1321733, 59743, 2242, 118, 27984, 1844, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47445700, 1323978, 395, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446098, 1323987, 232, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446333, 1323996, 297, 7, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446655, 1324007, 203, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446861, 1324014, 150, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447014, 1324019, 126, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447155, 1324025, 247, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447427, 1324034, 178, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447608, 1324040, 31318, 990, 196, 11037, 734, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47478941, 1325033, 392, 9, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479358, 1325046, 140, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479501, 1325050, 139, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479655, 1325056, 304, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479984, 1325066, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47480274, 1325077, 37893, 970, 196, 7731, 592, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47518170, 1326049, 27709, 585, 196, 4189, 289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47545906, 1326638, 187, 5, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546118, 1326647, 132, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546253, 1326651, 316, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546572, 1326659, 321, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546896, 1326667, 313, 5, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547212, 1326674, 271, 5, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547486, 1326681, 307, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547796, 1326689, 139, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547950, 1326695, 182, 4, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47548157, 1326703, 175, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47548335, 1326709, 34399, 938, 196, 9263, 622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47582749, 1327650, 359, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47583133, 1327661, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47583423, 1327672, 35972, 896, 196, 7020, 533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47619398, 1328570, 42756, 1023, 196, 9144, 603, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662181, 1329597, 212, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662418, 1329606, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662595, 1329612, 41734, 1733, 196, 23137, 1498, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704344, 1331348, 206, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704575, 1331357, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704865, 1331368, 36110, 898, 196, 7020, 533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47740978, 1332268, 99232, 3697, 196, 47514, 3053, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840237, 1335969, 216, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840478, 1335978, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840631, 1335982, 16729, 479, 196, 4699, 325, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857375, 1336464, 278, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857678, 1336474, 181, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857862, 1336480, 30128, 961, 196, 10784, 717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47888027, 1337446, 270, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47888322, 1337457, 44308, 1021, 196, 7810, 565, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47932633, 1338480, 30618, 670, 196, 5012, 348, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963278, 1339154, 272, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963575, 1339164, 185, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963763, 1339170, 880964, 21156, 252, 787865, 20001, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48844742, 1360329, 372, 8, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48845139, 1360341, 292, 6, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48845434, 1360349, 226985, 10583, 306, 150039, 9628, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072434, 1370935, 160, 2, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072619, 1370941, 289, 6, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072911, 1370949, 148321, 7487, 306, 107970, 6983, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49221247, 1378439, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]},
  "AOG2.1"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[2300, 71, 223, 4, 24, "Outline1",
      CellTags->{"AOG2.", "AOG0.", "AOG2.1", "AOG2.2", "AOG2.3"}],
    Cell[2548, 79, 193, 4, 21, "Outline2",
      CellTags->{"AOG2.", "AOG2.1", "AOG0."}],
    Cell[2744, 85, 987, 35, 116, "Outline3",
      CellTags->{"AOG2.", "AOG2.1", "AOG0."}],
    Cell[16751, 630, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.1", "AOG2.", "AOG2.1"}],
    Cell[16859, 635, 100, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.1", "AOG2.", "AOG2.1", "AOG2.1.1"}],
    Cell[16962, 638, 1992, 55, 88, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.1"}],
    Cell[18979, 697, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.1"}],
    Cell[19091, 701, 485, 8, 65, "Print",
      CellTags->{
      "Info3312042809-6749329", "AOG2.", "AOG2.1", "AOG2.1.1", "AOG0."}],
    Cell[19625, 715, 118, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.2", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[19746, 718, 664, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[20435, 737, 146, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[20584, 741, 279, 8, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[20878, 752, 701, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[21604, 771, 243, 7, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[21850, 780, 367, 10, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[22232, 793, 412, 10, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[22669, 807, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[22783, 811, 228, 5, 19, "Message",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[23014, 818, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[23147, 824, 198, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[23370, 833, 207, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[23580, 840, 347, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[23942, 852, 595, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[24562, 871, 229, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[24794, 880, 872, 27, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[25681, 910, 361, 10, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[26067, 924, 183, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[26253, 931, 10518, 262, 285, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[36786, 1196, 204, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[37015, 1205, 144, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[37162, 1209, 24034, 773, 134, 9878, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[61199, 1984, 495, 11, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[61697, 1997, 141, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[61853, 2003, 253, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[62131, 2012, 220, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[62354, 2021, 908, 27, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[63299, 2053, 164, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[63466, 2059, 1327, 25, 95, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[64808, 2087, 299, 8, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[65132, 2099, 176, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[65311, 2105, 72323, 2564, 152, 32608, 2068, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[137637, 4671, 588, 13, 35, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[138228, 4686, 143, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[138386, 4692, 158, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.2"}],
    Cell[138581, 4700, 111, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.3", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[138695, 4703, 1624, 33, 86, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[140322, 4738, 780, 13, 54, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[141105, 4753, 1236, 21, 70, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[142344, 4776, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.3"}],
    Cell[142541, 4784, 131, 1, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "2.1.4", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[142675, 4787, 641, 13, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[143341, 4804, 329, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[143673, 4815, 18991, 659, 110, 8702, 527, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[162667, 5476, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[162954, 5486, 341, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[163298, 5497, 20462, 730, 110, 9828, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[183763, 6229, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[184050, 6239, 339, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[184392, 6250, 20821, 734, 110, 9839, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[205216, 6986, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[205481, 6994, 527, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[206011, 7005, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.3"}],
    Cell[206208, 7013, 112, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.5", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[206323, 7016, 876, 22, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[207224, 7042, 118, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[207345, 7046, 2749, 52, 129, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[210109, 7101, 915, 21, 56, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[211049, 7126, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[211160, 7130, 279, 5, 50, "Print",
      CellTags->{
      "Info3312042819-8757440", "AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[211476, 7140, 343, 10, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[211822, 7152, 20450, 730, 110, 9828, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[232275, 7884, 1016, 18, 88, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[233294, 7904, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[233448, 7912, 160, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[233611, 7919, 346, 6, 19, "Message",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[233960, 7927, 343, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[234306, 7936, 1745, 29, 131, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[236054, 7967, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[236186, 7973, 294, 8, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[236505, 7985, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[236616, 7989, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[236749, 7995, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.5"}],
    Cell[236946, 8003, 114, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.6", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[237063, 8006, 580, 11, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[237668, 8021, 293, 8, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[237964, 8031, 141, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238108, 8036, 147, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238258, 8041, 194, 4, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238455, 8047, 171, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238629, 8052, 233, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238865, 8059, 374, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[239242, 8069, 565, 11, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[239810, 8082, 305, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240118, 8090, 267, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240388, 8097, 233, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240624, 8104, 359, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240986, 8113, 565, 11, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[241554, 8126, 306, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[241863, 8134, 267, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[242133, 8141, 233, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[242369, 8148, 359, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[242731, 8157, 295, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243029, 8165, 306, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243338, 8173, 267, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243608, 8180, 360, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243971, 8190, 154, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[244128, 8195, 229, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[244360, 8202, 241, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[244604, 8209, 454, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[245061, 8221, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[245537, 8233, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[245925, 8243, 457, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[246385, 8254, 489, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[246877, 8266, 410, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[247290, 8277, 480, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[247773, 8289, 497, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[248273, 8301, 418, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[248694, 8312, 435, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[249132, 8323, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[249602, 8335, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[249984, 8345, 452, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[250439, 8357, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[250911, 8369, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[251295, 8379, 241, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[251539, 8386, 454, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[251996, 8398, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[252472, 8410, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[252860, 8420, 466, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[253329, 8432, 489, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[253821, 8444, 410, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[254234, 8455, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[254732, 8467, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[255151, 8478, 433, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[255587, 8489, 465, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[256055, 8501, 377, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[256435, 8511, 450, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[256888, 8523, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[257360, 8535, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[257744, 8545, 241, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[257988, 8552, 454, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[258445, 8564, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[258921, 8576, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[259309, 8586, 466, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[259778, 8598, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[260272, 8610, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[260687, 8621, 435, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[261125, 8632, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[261595, 8644, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[261977, 8654, 450, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[262430, 8666, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[262902, 8678, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[263286, 8688, 498, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[263787, 8700, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[264206, 8711, 488, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[264697, 8723, 406, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[265106, 8734, 474, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[265583, 8746, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[265969, 8756, 476, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[266448, 8768, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[266836, 8778, 344, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[267183, 8787, 303, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[267489, 8795, 139, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[267631, 8800, 1172, 20, 88, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[268840, 8825, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[268951, 8829, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[269083, 8835, 445, 10, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[269553, 8849, 267, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[269823, 8859, 1727, 28, 194, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[271565, 8890, 301, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[271891, 8900, 312, 8, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[272206, 8910, 141, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[272350, 8915, 483, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[272836, 8927, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[273243, 8938, 509, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[273755, 8950, 432, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[274190, 8961, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[274684, 8973, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[275099, 8984, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[275597, 8996, 418, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[276018, 9007, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[276516, 9019, 418, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[276937, 9030, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[277409, 9042, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[277795, 9052, 465, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[278263, 9064, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[278645, 9074, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[279121, 9086, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[279509, 9096, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[279981, 9108, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[280367, 9118, 521, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[280891, 9130, 442, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[281336, 9141, 483, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[281822, 9153, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[282229, 9164, 509, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[282741, 9176, 430, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[283174, 9187, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[283668, 9199, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[284083, 9210, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[284581, 9222, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[285000, 9233, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[285498, 9245, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[285917, 9256, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[286389, 9268, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[286773, 9278, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[287243, 9290, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[287625, 9300, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[288101, 9312, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[288487, 9322, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[288961, 9334, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[289347, 9344, 521, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[289871, 9356, 442, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[290316, 9367, 483, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[290802, 9379, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[291209, 9390, 509, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[291721, 9402, 430, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[292154, 9413, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[292648, 9425, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[293063, 9436, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[293561, 9448, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[293980, 9459, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[294478, 9471, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[294897, 9482, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[295367, 9494, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[295749, 9504, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[296219, 9516, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[296601, 9526, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[297077, 9538, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[297463, 9548, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[297937, 9560, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[298323, 9570, 521, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[298847, 9582, 442, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[299292, 9593, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[299766, 9605, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[300152, 9615, 489, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[300644, 9627, 410, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[301057, 9638, 465, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[301525, 9650, 377, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[301905, 9660, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[302377, 9672, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[302761, 9682, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[303235, 9694, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[303621, 9704, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[304115, 9716, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[304530, 9727, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[305000, 9739, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[305382, 9749, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[305854, 9761, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[306238, 9771, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[306712, 9783, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[307098, 9793, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[307592, 9805, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[308007, 9816, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[308477, 9828, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[308859, 9838, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[309331, 9850, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[309715, 9860, 498, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[310216, 9872, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[310635, 9883, 488, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[311126, 9895, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[311533, 9906, 474, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[312010, 9918, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[312396, 9928, 476, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[312875, 9940, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[313263, 9950, 139, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[313405, 9955, 1101, 20, 113, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[314521, 9978, 283, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[314829, 9988, 177, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[315009, 9994, 1686, 29, 111, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[316710, 10026, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.6"}],
    Cell[316907, 10034, 108, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7", "2.1.7"}],
    Cell[317018, 10037, 526, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[317569, 10050, 337, 10, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[317909, 10062, 22699, 836, 110, 11522, 692, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[340611, 10900, 2909, 48, 205, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[343535, 10951, 253, 5, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[343813, 10960, 389, 12, 155, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[344205, 10974, 40769, 1619, 159, 22270, 1385, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[384977, 12595, 3259, 51, 206, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[388251, 12649, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.7"}],
    Cell[388448, 12657, 119, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8", "2.1.8"}],
    Cell[388570, 12660, 366, 7, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[388961, 12671, 360, 10, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[389324, 12683, 43019, 1385, 257, 15999, 1046, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[432346, 14070, 1492, 27, 145, "Output",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[433853, 14100, 563, 14, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[434441, 14118, 162, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[434606, 14125, 566, 9, 65, "Print",
      CellTags->{
      "Info3312042871-8199869", "AOG2.", "AOG2.1", "AOG2.1.8", "AOG0."}],
    Cell[435209, 14139, 366, 10, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[435578, 14151, 20370, 730, 110, 9744, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[455951, 14883, 1831, 30, 145, "Output",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[457797, 14916, 492, 15, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[458292, 14933, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.8"}]},
  "AOG2.2"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[2300, 71, 223, 4, 24, "Outline1",
      CellTags->{"AOG2.", "AOG0.", "AOG2.1", "AOG2.2", "AOG2.3"}],
    Cell[3768, 125, 206, 4, 21, "Outline2",
      CellTags->{"AOG2.", "AOG2.2", "AOG0."}],
    Cell[3977, 131, 450, 14, 46, "Outline3",
      CellTags->{"AOG2.", "AOG2.2", "AOG0."}],
    Cell[19625, 715, 118, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.2", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[19746, 718, 664, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[20435, 737, 146, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[20584, 741, 279, 8, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[20878, 752, 701, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[21604, 771, 243, 7, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[21850, 780, 367, 10, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[22232, 793, 412, 10, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[22669, 807, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[22783, 811, 228, 5, 19, "Message",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[23014, 818, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[23147, 824, 198, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[23370, 833, 207, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[23580, 840, 347, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[23942, 852, 595, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[24562, 871, 229, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[24794, 880, 872, 27, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[25681, 910, 361, 10, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[26067, 924, 183, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[26253, 931, 10518, 262, 285, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[36786, 1196, 204, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[37015, 1205, 144, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[37162, 1209, 24034, 773, 134, 9878, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[61199, 1984, 495, 11, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[61697, 1997, 141, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[61853, 2003, 253, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[62131, 2012, 220, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[62354, 2021, 908, 27, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[63299, 2053, 164, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[63466, 2059, 1327, 25, 95, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[64808, 2087, 299, 8, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[65132, 2099, 176, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
    Cell[65311, 2105, 72323, 2564, 152, 32608, 2068, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[137637, 4671, 588, 13, 35, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[138228, 4686, 143, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
    Cell[138386, 4692, 158, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.2"}],
    Cell[458501, 14942, 96, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.2", "AOG2.", "AOG2.2"}],
    Cell[458600, 14945, 525, 12, 36, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2"}],
    Cell[459150, 14961, 128, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.2.1", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[459281, 14964, 723, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460007, 14981, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460121, 14985, 267, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460391, 14994, 268, 5, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460684, 15003, 192, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460879, 15010, 23289, 697, 130, 7253, 493, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[484183, 15710, 551, 12, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[484759, 15726, 246, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[485008, 15734, 552, 10, 77, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[485575, 15747, 482, 11, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[486082, 15762, 152, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[486237, 15766, 1723, 24, 185, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[487975, 15793, 158, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[488158, 15801, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[488300, 15805, 71910, 1447, 240, 21739, 822, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[560225, 17255, 196, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[560446, 17263, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[560570, 17267, 1525, 21, 185, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[562132, 17293, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[562256, 17297, 1494, 22, 185, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[563765, 17322, 255, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[564045, 17332, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[564185, 17336, 5152, 92, 129, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[569352, 17431, 378, 6, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[569755, 17441, 230, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[569988, 17449, 225, 4, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[570228, 17456, 287, 7, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[570540, 17467, 261, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[570804, 17475, 76731, 5322, 130, 64916, 5171, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[647538, 22799, 426, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[647979, 22811, 667, 11, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[648671, 22826, 244, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[648918, 22834, 1029, 19, 73, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[649962, 22856, 200, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[650187, 22864, 184, 3, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[650374, 22869, 5263, 73, 617, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[655652, 22945, 300, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[655977, 22955, 245, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[656225, 22963, 221, 4, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[656461, 22970, 419, 8, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[656905, 22982, 259, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[657167, 22990, 76745, 5322, 130, 64930, 5171, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[733915, 28314, 425, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[734355, 28326, 441, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[734821, 28337, 260, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[735084, 28345, 315480, 24523, 130, 303636, 24371, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[1050567, 52870, 424, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[1051006, 52882, 188, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[1051197, 52888, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.2", "AOG2.", "AOG2.2.1"}],
    Cell[1051394, 52896, 126, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2", "2.2.2"}],
    Cell[1051523, 52899, 815, 13, 52, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1052341, 52914, 301, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1052667, 52926, 172, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1052842, 52932, 39451, 2840, 64, 34309, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1092308, 55775, 399, 12, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1092732, 55791, 288, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1093023, 55799, 938, 17, 88, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1093976, 55819, 216, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1094217, 55827, 176, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1094396, 55833, 28646, 598, 184, 4073, 289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1123057, 56434, 487, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1123547, 56445, 193, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1123765, 56454, 186, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1123954, 56461, 7133, 104, 324, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1131102, 56568, 191, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1131318, 56577, 206, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1131527, 56585, 24152, 606, 184, 5492, 370, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1155694, 57194, 186, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1155905, 57202, 117, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1156025, 57206, 27273, 690, 184, 6378, 427, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1183313, 57899, 504, 8, 36, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1183842, 57911, 274, 7, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1184119, 57920, 3410, 47, 401, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1187566, 57972, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1187777, 57978, 3008, 42, 365, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1190822, 58025, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1191033, 58031, 3054, 42, 365, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1194124, 58078, 378, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1194527, 58090, 252102, 6207, 240, 177264, 5277, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1446632, 64299, 302511, 6827, 240, 177429, 5277, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1749146, 71128, 278598, 6544, 240, 177380, 5289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[2027747, 77674, 1438537, 71956, 261, 1301290, 70256, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3466333, 149636, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3466473, 149640, 9632, 174, 234, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3476142, 149819, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3476256, 149823, 115, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3476386, 149829, 199, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3476610, 149839, 258, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3476871, 149850, 293, 6, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3477201, 149861, 200, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3477426, 149871, 38782, 2831, 64, 34341, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3516211, 152704, 39691, 2844, 64, 34229, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3555917, 155551, 946, 17, 54, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3556878, 155571, 277, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3557180, 155582, 195, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3557378, 155589, 295, 5, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3557710, 155599, 150, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3557863, 155603, 39799, 2844, 64, 34345, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3597665, 158449, 424, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3598104, 158461, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.2", "AOG2.", "AOG2.2.2"}],
    Cell[3598301, 158469, 107, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.2.3", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3598411, 158472, 373, 6, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3598787, 158480, 574, 10, 85, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599364, 158492, 175, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599542, 158498, 108, 1, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599675, 158503, 166, 3, 25, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599844, 158508, 28599, 1237, 86, 18759, 1110, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3628480, 159750, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3628622, 159754, 132, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3628791, 159762, 140, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3628934, 159766, 132, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3629103, 159774, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3629214, 159778, 521, 12, 35, "Print",
      CellTags->{
      "Info3312042947-9251066", "AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3629772, 159795, 165, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3629940, 159801, 117, 3, 38, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3630094, 159809, 156, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3630253, 159813, 117, 3, 38, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3630385, 159819, 391, 8, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3630801, 159831, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3630913, 159835, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3631067, 159843, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3631179, 159847, 2067, 38, 214, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3633283, 159890, 168, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3633454, 159896, 140, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3633631, 159904, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3633755, 159908, 119, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3633911, 159916, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3634035, 159920, 12755, 207, 1238, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3646827, 160132, 260, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3647090, 160140, 258, 5, 26, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3647385, 160150, 344, 12, 155, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3647732, 160164, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3647887, 160172, 269, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3648159, 160180, 254, 5, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3648450, 160190, 155, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3648608, 160197, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3648763, 160205, 155, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3648921, 160212, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3649076, 160220, 155, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3649234, 160227, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3649389, 160235, 148, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3649540, 160239, 47437, 819, 1149, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3697014, 161063, 112, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3697129, 161067, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3697283, 161075, 255, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3697541, 161085, 508, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3698086, 161099, 276, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3698365, 161109, 3592, 63, 129, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3701994, 161177, 525, 11, 139, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3702544, 161192, 18991, 786, 86, 11568, 689, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3721538, 161980, 19404, 805, 86, 11762, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3740945, 162787, 17533, 725, 86, 10993, 639, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3758481, 163514, 21004, 843, 86, 12058, 727, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3779488, 164359, 22226, 965, 86, 13636, 853, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3801717, 165326, 24095, 1034, 86, 14388, 909, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3825815, 166362, 18228, 740, 86, 11141, 647, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3844046, 167104, 25166, 1090, 86, 15289, 963, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3869215, 168196, 24747, 1071, 86, 15113, 947, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3893965, 169269, 25378, 1114, 86, 15849, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3919346, 170385, 25093, 1076, 86, 15118, 947, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3944442, 171463, 23817, 1008, 86, 13964, 881, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3968262, 172473, 25725, 1085, 86, 14989, 947, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3993990, 173560, 22928, 1085, 86, 15776, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4016921, 174647, 24033, 1099, 86, 15767, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4040957, 175748, 21595, 980, 86, 14014, 881, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4062555, 176730, 23316, 1089, 86, 15800, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4085874, 177821, 23217, 980, 86, 13708, 857, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4109094, 178803, 24174, 1099, 86, 15844, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4133271, 179904, 23922, 1075, 86, 15288, 963, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4157196, 180981, 24420, 1103, 86, 15830, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4181619, 182086, 24090, 1067, 86, 15136, 951, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4205712, 183155, 17283, 700, 86, 10686, 613, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4222998, 183857, 17236, 713, 86, 10910, 629, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4240237, 184572, 20490, 947, 86, 13678, 857, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4260730, 185521, 22588, 1004, 86, 14387, 897, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4283321, 186527, 22189, 967, 86, 13693, 857, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4305525, 187497, 10122, 191, 414, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4315684, 187693, 206, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[4315893, 187701, 310, 5, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4316240, 187711, 531, 13, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[4316774, 187726, 29237, 1570, 86, 21628, 1471, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4346014, 189298, 428, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4346479, 189312, 479, 13, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[4346961, 189327, 428, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4347404, 189339, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.2.3", "AOG2.2", "AOG2."}]},
  "AOG2.3"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[2300, 71, 223, 4, 24, "Outline1",
      CellTags->{"AOG2.", "AOG0.", "AOG2.1", "AOG2.2", "AOG2.3"}],
    Cell[4464, 150, 213, 4, 21, "Outline2",
      CellTags->{"AOG2.", "AOG2.3", "AOG0."}],
    Cell[4680, 156, 518, 18, 60, "Outline3",
      CellTags->{"AOG2.", "AOG2.3", "AOG0."}],
    Cell[4347613, 189348, 119, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.3", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4347757, 189353, 101, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.1", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4347883, 189358, 160, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348046, 189364, 165, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4348226, 189370, 231, 7, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348460, 189379, 180, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348665, 189387, 167, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348835, 189393, 31520, 1334, 159, 20081, 1187, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4380370, 190730, 184, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4380579, 190739, 131, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4380713, 190743, 418, 7, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4381168, 190755, 202, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4381373, 190763, 13835, 365, 184, 3130, 227, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4395223, 191131, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.3", "AOG2."}],
    Cell[4395408, 191139, 116, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.2", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4395549, 191144, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4395673, 191148, 42033, 1026, 296, 7262, 591, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4437709, 192176, 922, 21, 39, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4438668, 192202, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4438847, 192208, 42773, 1154, 184, 9613, 739, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4481623, 193364, 60297, 1107, 184, 6603, 439, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4541969, 194477, 135, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4542107, 194481, 36182, 848, 184, 6910, 481, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4578304, 195332, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.3", "AOG2."}],
    Cell[4578489, 195340, 104, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.3", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4578618, 195345, 280, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4578901, 195353, 319, 6, 26, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4579257, 195364, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4579399, 195368, 23061, 533, 184, 4091, 293, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4602497, 195906, 118, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4602618, 195910, 23167, 551, 184, 4496, 315, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4625822, 196466, 116, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4625941, 196470, 342, 6, 26, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4626298, 196479, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4626440, 196483, 144, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4626609, 196489, 168, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4626780, 196495, 28051, 731, 184, 6546, 460, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4654868, 197231, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4655001, 197235, 1609, 28, 94, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4656647, 197268, 145, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4656795, 197272, 402, 7, 23, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4657200, 197281, 401, 7, 23, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4657604, 197290, 401, 7, 23, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4658008, 197299, 247, 5, 19, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4658258, 197306, 19539, 493, 184, 4204, 298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4677812, 197802, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.3", "AOG2."}],
    Cell[4677997, 197810, 116, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.4", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678116, 197813, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678273, 197817, 380, 15, 203, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678678, 197836, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678807, 197840, 1462, 26, 198, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4680306, 197871, 116, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4680425, 197875, 652, 13, 39, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4681114, 197893, 197, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4681314, 197900, 132, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4681461, 197906, 120, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4681606, 197912, 142, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4681751, 197916, 29725, 703, 184, 5721, 401, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4711513, 198624, 153, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4711669, 198628, 134, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4711840, 198636, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4711997, 198640, 20416, 550, 184, 4840, 352, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4732450, 199195, 138, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4732591, 199199, 46075, 859, 377, 4774, 344, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4778703, 200063, 166, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4778872, 200069, 21023, 472, 184, 3388, 249, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4799910, 200544, 276, 6, 34, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4800211, 200554, 203, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4800417, 200561, 1857010, 45857, 240, 1775535, 44846, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[6657464, 246423, 277, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[6657744, 246431, 706903, 40556, 294, 616171, 39430, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[7364684, 286992, 279, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[7364966, 287000, 476455, 6607, 294, 247926, 3780, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[7841436, 293610, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.3", "AOG2."}]},
  "AOG4.2"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[6846, 242, 266, 6, 24, "Outline1",
      CellTags->{
      "AOG4.", "AOG0.", "AOG4.1", "AOG4.2", "AOG4.3", "AOG4.4", "AOG4.5", 
        "AOG4.6"}],
    Cell[7323, 258, 207, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.2"}],
    Cell[7533, 264, 467, 18, 60, "Outline3",
      CellTags->{"AOG4.2", "AOG4."}],
    Cell[8374749, 309437, 109, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.2", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8374883, 309442, 94, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.2.1", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8374980, 309445, 337, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8375342, 309457, 153, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8375498, 309461, 36774, 1565, 119, 21947, 1376, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8412309, 311031, 204, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8412516, 311038, 3171, 77, 49, "Output",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8415724, 311120, 255, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8415982, 311127, 3042, 82, 59, "Output",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8419039, 311212, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2"}],
    Cell[8419224, 311220, 101, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.2.2", "AOG4.", "AOG4.2", "AOG4.2.2"}],
    Cell[8419350, 311225, 134, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.2"}],
    Cell[8419487, 311229, 4148, 71, 204, "Output",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.2"}],
    Cell[8423650, 311303, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2"}],
    Cell[8423835, 311311, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.2.3", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8423960, 311316, 133, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8424096, 311320, 41750, 905, 184, 10085, 508, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8465883, 312230, 176, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8466062, 312236, 40778, 891, 184, 10370, 510, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8506877, 313132, 185, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8507087, 313141, 42205, 924, 184, 10651, 529, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8549295, 314067, 40885, 946, 184, 11239, 574, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8590229, 315019, 199, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8590431, 315026, 99253, 2755, 184, 29018, 1882, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8689687, 317783, 3595, 64, 210, "Output",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8693297, 317850, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2"}],
    Cell[8693482, 317858, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.2.4", "AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8693607, 317863, 176, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8693786, 317869, 82869, 3386, 119, 44933, 2912, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8776692, 321260, 179, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8776874, 321266, 86168, 3632, 119, 49560, 3174, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8863057, 324901, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2"}]},
  "AOG4.3"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[6846, 242, 266, 6, 24, "Outline1",
      CellTags->{
      "AOG4.", "AOG0.", "AOG4.1", "AOG4.2", "AOG4.3", "AOG4.4", "AOG4.5", 
        "AOG4.6"}],
    Cell[8037, 287, 212, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.3"}],
    Cell[8252, 293, 467, 18, 60, "Outline3",
      CellTags->{"AOG4.3", "AOG4."}],
    Cell[8863254, 324910, 114, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.3", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863393, 324915, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.1", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863490, 324918, 327, 9, 96, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863842, 324931, 139, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863984, 324935, 110082, 2058, 598, 14663, 874, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8974103, 326998, 244, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8974350, 327005, 3583, 98, 109, "Output",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8977970, 327108, 245, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8978218, 327115, 3609, 98, 109, "Output",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8981842, 327216, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3"}],
    Cell[8982027, 327224, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.2", "AOG4.", "AOG4.3", "AOG4.3.2"}],
    Cell[8982153, 327229, 138, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.2"}],
    Cell[8982294, 327233, 4394, 75, 213, "Output",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.2"}],
    Cell[8986703, 327311, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3"}],
    Cell[8986888, 327319, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.3", "AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[8987013, 327324, 137, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[8987175, 327330, 36915, 812, 184, 8790, 459, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[9024093, 328144, 35572, 827, 184, 9311, 497, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[9059680, 328974, 5041, 92, 284, "Output",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[9064736, 329069, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3"}],
    Cell[9064921, 329077, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.4", "AOG4.", "AOG4.3", "AOG4.3.4"}],
    Cell[9065046, 329082, 191, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.4"}],
    Cell[9065240, 329089, 346463, 19400, 562, 207570, 17680, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.4"}],
    Cell[9411718, 348492, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3"}]},
  "AOG4.4"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[6846, 242, 266, 6, 24, "Outline1",
      CellTags->{
      "AOG4.", "AOG0.", "AOG4.1", "AOG4.2", "AOG4.3", "AOG4.4", "AOG4.5", 
        "AOG4.6"}],
    Cell[8756, 316, 206, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.4"}],
    Cell[8965, 322, 467, 18, 60, "Outline3",
      CellTags->{"AOG4.4", "AOG4."}],
    Cell[9411915, 348501, 108, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.4", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412048, 348506, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.1", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412145, 348509, 338, 8, 96, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412508, 348521, 132, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412643, 348525, 93072, 1898, 564, 16306, 945, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9505752, 350428, 202, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9505957, 350435, 5040, 126, 91, "Output",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9511034, 350566, 181, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9511218, 350573, 1280, 30, 79, "Output",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9512513, 350606, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4"}],
    Cell[9512698, 350614, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.2", "AOG4.", "AOG4.4", "AOG4.4.2"}],
    Cell[9512824, 350619, 131, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.2"}],
    Cell[9512958, 350623, 6349, 112, 293, "Output",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.2"}],
    Cell[9519322, 350738, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4"}],
    Cell[9519507, 350746, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.3", "AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9519632, 350751, 131, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9519788, 350757, 41693, 926, 184, 10477, 535, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9561484, 351685, 41582, 925, 184, 10475, 535, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9603093, 352614, 88, 2, 28, "Input",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9603206, 352620, 181, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9603412, 352629, 42973, 944, 184, 10888, 542, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9646388, 353575, 40331, 937, 184, 11240, 572, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9686722, 354514, 43028, 945, 184, 10880, 542, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9729753, 355461, 40128, 935, 184, 11183, 572, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9769908, 356400, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4"}],
    Cell[9770093, 356408, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.4", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9770218, 356413, 176, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9770397, 356419, 88137, 4899, 120, 72452, 4700, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9858571, 361323, 177, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9858751, 361329, 90758, 4928, 84, 72786, 4700, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9949546, 366262, 149, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9949698, 366266, 149230, 11357, 188, 129962, 11114, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[10098943, 377626, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4"}]},
  "AOG4.5"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[6846, 242, 266, 6, 24, "Outline1",
      CellTags->{
      "AOG4.", "AOG0.", "AOG4.1", "AOG4.2", "AOG4.3", "AOG4.4", "AOG4.5", 
        "AOG4.6"}],
    Cell[9469, 345, 208, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.5"}],
    Cell[9680, 351, 467, 18, 60, "Outline3",
      CellTags->{"AOG4.5", "AOG4."}],
    Cell[10099140, 377635, 110, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.5", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099275, 377640, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.1", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099372, 377643, 346, 8, 79, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099743, 377655, 129, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099875, 377659, 38235, 962, 255, 7596, 578, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10138147, 378626, 181, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10138331, 378633, 3947, 102, 99, "Output",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10142315, 378740, 178, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10142496, 378746, 706, 13, 37, "Output",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10143217, 378762, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5"}],
    Cell[10143402, 378770, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.2", "AOG4.", "AOG4.5", "AOG4.5.2"}],
    Cell[10143528, 378775, 128, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.2"}],
    Cell[10143659, 378779, 4428, 75, 197, "Output",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.2"}],
    Cell[10148102, 378857, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5"}],
    Cell[10148287, 378865, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.3", "AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10148412, 378870, 128, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10148565, 378876, 32374, 762, 184, 8941, 467, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10180942, 379640, 31278, 725, 184, 8566, 439, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10212269, 380371, 177, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10212471, 380379, 37055, 821, 184, 9279, 472, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10249529, 381202, 34566, 816, 184, 9626, 502, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10284098, 382020, 34157, 774, 184, 8978, 457, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10318258, 382796, 34380, 793, 184, 9314, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10352665, 383593, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5"}],
    Cell[10352850, 383601, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.4", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10352975, 383606, 173, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10353151, 383612, 89292, 3811, 161, 52391, 3350, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10442480, 387428, 174, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10442657, 387434, 118017, 4167, 187, 52312, 3350, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10560711, 391606, 146, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10560860, 391610, 148094, 9129, 255, 95739, 8477, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10708969, 400742, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5"}]},
  "AOG4.6"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[6846, 242, 266, 6, 24, "Outline1",
      CellTags->{
      "AOG4.", "AOG0.", "AOG4.1", "AOG4.2", "AOG4.3", "AOG4.4", "AOG4.5", 
        "AOG4.6"}],
    Cell[10184, 374, 203, 4, 21, "Outline2",
      CellTags->{"AOG4.", "AOG0.", "AOG4.6"}],
    Cell[10390, 380, 467, 18, 60, "Outline3",
      CellTags->{"AOG4.6", "AOG4."}],
    Cell[10709166, 400751, 93, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.6", "AOG4.", "AOG4.6"}],
    Cell[10709284, 400756, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.1", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10709381, 400759, 277, 9, 113, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10709683, 400772, 131, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10709817, 400776, 36106, 1082, 221, 9515, 748, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10745960, 401863, 202, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10746165, 401870, 6240, 154, 91, "Output",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10752595, 402035, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.2", "AOG4.", "AOG4.6", "AOG4.6.2"}],
    Cell[10752721, 402040, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.2"}],
    Cell[10752854, 402044, 7613, 135, 325, "Output",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.2"}],
    Cell[10760657, 402190, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.3", "AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10760782, 402195, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10760937, 402201, 47820, 1097, 184, 12909, 660, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10808760, 403300, 47419, 1044, 184, 12063, 602, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10856228, 404350, 179, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10856432, 404358, 50096, 1104, 184, 12892, 639, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10906531, 405464, 49448, 1121, 184, 13308, 669, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10955982, 406587, 50236, 1118, 184, 13097, 654, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[11006221, 407707, 47195, 1046, 184, 12495, 612, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[11053618, 408765, 100, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.6.4", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11053743, 408770, 175, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11053921, 408776, 109765, 5291, 132, 76369, 4873, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11163723, 414072, 176, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11163902, 414078, 110499, 5298, 132, 76572, 4873, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11274438, 419381, 148, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11274589, 419385, 172454, 12925, 220, 141061, 12532, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}]},
  "AOG6.2"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[11966, 445, 241, 4, 24, "Outline1",
      CellTags->{"AOG6.", "AOG0.", "AOG6.2", "AOG6.3", "AOG6.4"}],
    Cell[12418, 459, 211, 4, 21, "Outline2",
      CellTags->{"AOG6.", "AOG0.", "AOG6.2"}],
    Cell[12632, 465, 558, 22, 74, "Outline3",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[33416278, 980284, 113, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.2", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416416, 980289, 97, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.2.1", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416516, 980292, 268, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416809, 980303, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416942, 980307, 26152, 499, 294, 3133, 209, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33443131, 980811, 127, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33443283, 980817, 31937, 760, 184, 5582, 428, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33475223, 981579, 31390, 839, 184, 6685, 528, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33506616, 982420, 34255, 890, 184, 6802, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33540874, 983312, 31849, 759, 184, 5579, 428, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33572726, 984073, 29320, 762, 184, 6043, 468, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33602049, 984837, 34167, 889, 184, 6799, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33636231, 985729, 4495, 102, 103, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33640763, 985836, 148, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33640936, 985842, 34077, 742, 184, 4736, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33675016, 986586, 33676, 820, 184, 5754, 469, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33708695, 987408, 34749, 841, 184, 5853, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33743447, 988251, 34082, 742, 184, 4741, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33777532, 988995, 31696, 744, 184, 5101, 409, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33809231, 989741, 34766, 841, 184, 5858, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33844012, 990585, 4615, 104, 103, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33848664, 990694, 148, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33848837, 990700, 34077, 742, 196, 4736, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33882917, 991444, 33676, 820, 184, 5754, 469, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33916596, 992266, 34749, 841, 184, 5853, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33951348, 993109, 34082, 742, 184, 4741, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33985433, 993853, 31696, 744, 184, 5101, 409, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34017132, 994599, 34766, 841, 184, 5858, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34051913, 995443, 4615, 104, 115, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34056565, 995552, 149, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34056717, 995556, 147529, 3003, 184, 20809, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34204283, 998564, 143, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34204451, 998570, 34368, 765, 184, 5216, 400, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34238822, 999337, 34363, 765, 184, 5211, 400, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34273188, 1000104, 147529, 3003, 184, 20809, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34420744, 1003111, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[34420929, 1003119, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.2", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34421029, 1003122, 263, 7, 79, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34421317, 1003133, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34421450, 1003137, 16000, 372, 294, 3244, 209, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34437487, 1003514, 127, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34437639, 1003520, 38504, 1002, 184, 7743, 617, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34476146, 1004524, 33813, 909, 196, 7329, 577, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34509962, 1005435, 34759, 910, 196, 7134, 563, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34544724, 1006347, 31351, 776, 196, 5814, 455, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34576078, 1007125, 70322, 1881, 196, 17739, 1226, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34646403, 1009008, 31765, 880, 196, 7001, 569, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34678183, 1009891, 4497, 102, 113, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34682717, 1009998, 145, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34682865, 1010002, 137262, 2773, 196, 19098, 1309, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34820142, 1012778, 148, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[34820327, 1012786, 97, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.2.3", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820427, 1012789, 205, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820657, 1012798, 160, 4, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820820, 1012804, 117, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820952, 1012810, 570, 11, 54, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34821525, 1012823, 612, 14, 102, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34822140, 1012839, 216, 5, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34822359, 1012846, 387, 9, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34822749, 1012857, 317, 7, 86, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823069, 1012866, 346, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823418, 1012876, 271, 7, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823692, 1012885, 176, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823871, 1012892, 412, 12, 176, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34824308, 1012908, 252, 6, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34824563, 1012916, 255229, 17819, 108, 243002, 17662, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35079829, 1030740, 125, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35079979, 1030746, 34663, 850, 196, 6370, 494, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35114645, 1031598, 36075, 1004, 184, 8345, 655, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35150723, 1032604, 37944, 973, 184, 7459, 590, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35188716, 1033583, 125, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35188866, 1033589, 33930, 886, 196, 6830, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35222799, 1034477, 38325, 998, 184, 7903, 616, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35261127, 1035477, 34238, 847, 184, 6386, 497, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35295414, 1036330, 132, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35295549, 1036334, 112461, 5760, 196, 82833, 5389, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35408047, 1042099, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35408202, 1042103, 134181, 2677, 184, 18234, 1240, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35542398, 1044783, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[35542583, 1044791, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.4", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35542683, 1044794, 184, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35542892, 1044803, 159, 4, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35543054, 1044809, 116, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35543185, 1044815, 569, 11, 42, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35543757, 1044828, 611, 14, 90, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35544371, 1044844, 216, 5, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35544590, 1044851, 387, 9, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35544980, 1044862, 317, 7, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35545300, 1044871, 271, 7, 62, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35545574, 1044880, 453, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35546030, 1044896, 453, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35546508, 1044914, 224, 5, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35546735, 1044921, 242133, 16878, 96, 229517, 16717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35788905, 1061804, 123, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35789053, 1061810, 36664, 981, 184, 7713, 617, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35825720, 1062793, 34235, 867, 184, 6836, 522, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35859958, 1063662, 36640, 928, 184, 7075, 557, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35896601, 1064592, 35085, 928, 184, 7256, 578, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35931689, 1065522, 34610, 867, 184, 6827, 518, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35966302, 1066391, 35177, 916, 184, 7115, 563, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36001494, 1067310, 4483, 102, 103, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36006014, 1067417, 146, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36006185, 1067423, 30191, 708, 184, 5167, 394, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36036379, 1068133, 28987, 725, 184, 5510, 430, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36065369, 1068860, 125533, 2582, 184, 17966, 1249, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36190929, 1071446, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}],
    Cell[36191114, 1071454, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.5", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36191236, 1071459, 110, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36191349, 1071463, 2033, 28, 245, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36193397, 1071494, 496, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36193918, 1071512, 137, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36194058, 1071516, 90561, 4663, 155, 64954, 4341, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36284656, 1076184, 132, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36284791, 1076188, 430, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36285246, 1076201, 38263, 993, 184, 7907, 613, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36323512, 1077196, 37836, 1006, 184, 7715, 629, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36361351, 1078204, 33767, 897, 184, 7337, 565, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36395133, 1079104, 430, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36395588, 1079117, 40299, 975, 184, 7456, 564, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36435890, 1080094, 37729, 995, 184, 7575, 617, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36473622, 1081091, 39196, 1049, 184, 8464, 664, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36512833, 1082143, 5351, 116, 133, "Output",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36518221, 1082264, 126, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36518350, 1082268, 82209, 1966, 184, 16581, 1150, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36600596, 1084239, 121, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36600720, 1084243, 430, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36601153, 1084254, 34482, 947, 184, 8125, 616, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36635638, 1085203, 430, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36636093, 1085216, 40415, 1127, 184, 9682, 742, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36676511, 1086345, 82338, 1965, 184, 16582, 1148, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36758864, 1088313, 805, 18, 37, "Output",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36759684, 1088334, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]},
  "AOG6.3"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[11966, 445, 241, 4, 24, "Outline1",
      CellTags->{"AOG6.", "AOG0.", "AOG6.2", "AOG6.3", "AOG6.4"}],
    Cell[13227, 492, 211, 4, 21, "Outline2",
      CellTags->{"AOG6.", "AOG0.", "AOG6.3"}],
    Cell[13441, 498, 380, 14, 46, "Outline3",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3"}],
    Cell[36759881, 1088343, 113, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.3", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760019, 1088348, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.1", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760119, 1088351, 271, 7, 79, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760415, 1088362, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760548, 1088366, 18194, 504, 294, 5438, 341, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[36778779, 1088875, 168, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36778950, 1088881, 438, 9, 21, "Print",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[36779413, 1088894, 143855, 3133, 240, 79529, 2333, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[36923271, 1092029, 162174, 3372, 239, 79437, 2345, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37085448, 1095403, 154268, 3257, 240, 79379, 2327, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37239731, 1098663, 438, 9, 21, "Print",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37240194, 1098676, 173933, 3512, 240, 79826, 2345, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37414130, 1102190, 162174, 3372, 239, 79437, 2345, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37576307, 1105564, 183408, 3625, 240, 79670, 2339, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37759730, 1109192, 9907, 192, 548, "Output",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37769674, 1109389, 182, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[37769859, 1109396, 2911809, 38632, 556, 1527231, 21533, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->{"AOG6.3.1", "AOG6.3", "AOG6.", "AOG0."}],
    Cell[40681671, 1148030, 999, 21, 39, "Output",
      CellTags->{"AOG6.3.1", "AOG6.3", "AOG6.", "AOG0."}],
    Cell[40682685, 1148054, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3"}],
    Cell[40682870, 1148062, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.2", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40682970, 1148065, 205, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40683178, 1148072, 253, 9, 113, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40683456, 1148085, 154, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40683613, 1148089, 39323, 1977, 170, 27027, 1820, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40722951, 1150069, 374, 11, 147, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40723350, 1150084, 154, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40723507, 1150088, 46321, 2316, 164, 32510, 2140, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40769865, 1152409, 241, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40770109, 1152415, 438, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40770572, 1152428, 173771, 3473, 70, 78845, 2295, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40944346, 1155903, 196112, 3769, 70, 79217, 2319, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41140461, 1159674, 187658, 3642, 70, 78851, 2292, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41328134, 1163319, 5191, 100, 70, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41333362, 1163424, 137, 2, 24, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[41333502, 1163428, 438, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41333965, 1163441, 173760, 3468, 240, 78767, 2289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41507728, 1166911, 196382, 3766, 70, 79221, 2313, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41704113, 1170679, 187901, 3638, 70, 78920, 2286, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41892029, 1174320, 8304, 149, 524, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41900370, 1174474, 167, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[41900540, 1174480, 468481, 6384, 446, 105436, 1896, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[42369024, 1180866, 1174, 25, 37, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[42370213, 1180894, 148, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3"}],
    Cell[42370398, 1180902, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.3", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42370498, 1180905, 509, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42371032, 1180923, 118, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42371153, 1180927, 121445, 4136, 313, 62819, 3407, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42492635, 1185068, 135, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42492773, 1185072, 438, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42493214, 1185083, 274996, 12364, 294, 172862, 11097, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42768213, 1197449, 438, 9, 20, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42768676, 1197462, 366904, 16950, 294, 240110, 15379, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[43135583, 1214414, 347371, 4783, 294, 103986, 1773, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[43482969, 1219200, 994, 21, 39, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[43484000, 1219226, 221, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[43484224, 1219233, 896803, 21536, 240, 771968, 19989, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[44381042, 1240772, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3"}]},
  "AOG6.4"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[11966, 445, 241, 4, 24, "Outline1",
      CellTags->{"AOG6.", "AOG0.", "AOG6.2", "AOG6.3", "AOG6.4"}],
    Cell[13858, 517, 229, 4, 21, "Outline2",
      CellTags->{"AOG6.", "AOG6.4", "AOG0."}],
    Cell[14090, 523, 953, 34, 116, "Outline3",
      CellTags->{"AOG6.", "AOG6.4", "AOG0."}],
    Cell[44381239, 1240781, 143, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.4", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2"}],
    Cell[44381407, 1240786, 142, 2, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "6.4.1", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
    Cell[44381552, 1240790, 1606, 33, 86, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
    Cell[44383161, 1240825, 155, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44383353, 1240833, 164, 2, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.4.2", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383520, 1240837, 263, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383786, 1240845, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383915, 1240849, 226, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44384144, 1240859, 1133, 28, 379, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44385280, 1240889, 155, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44385472, 1240897, 225, 3, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.4.3", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44385700, 1240902, 669, 16, 40, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386372, 1240920, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386583, 1240926, 316, 10, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386902, 1240938, 2463, 77, 1003, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44389368, 1241017, 155, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44389560, 1241025, 122, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.4", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44389707, 1241030, 206, 6, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44389916, 1241038, 2635, 61, 286, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44392588, 1241104, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44392765, 1241110, 143828, 7167, 306, 99609, 6616, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44536630, 1248282, 139, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44536772, 1248286, 6413, 90, 444, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44543222, 1248381, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44543375, 1248385, 33679, 1164, 196, 13916, 915, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44577091, 1249554, 184, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44577278, 1249560, 322724, 6787, 252, 197914, 5241, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44900017, 1256350, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44900209, 1256358, 116, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.5", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900328, 1256361, 231, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900584, 1256372, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900761, 1256378, 59743, 2242, 118, 27984, 1844, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960519, 1258623, 140, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960684, 1258629, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960839, 1258633, 22963, 536, 196, 4136, 298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44983839, 1259174, 188, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44984030, 1259181, 293073, 6331, 252, 196329, 5131, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[45277118, 1265515, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[45277310, 1265523, 117, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.6", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277452, 1265528, 250, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277705, 1265537, 162, 3, 33, "Print",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277870, 1265542, 185, 4, 33, "Print",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45278092, 1265551, 175, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45278270, 1265557, 66621, 3547, 118, 52710, 3370, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45344928, 1269109, 182, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345113, 1269115, 142, 3, 33, "Output",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345292, 1269123, 153, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345448, 1269127, 43921, 1277, 196, 13678, 898, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45389406, 1270409, 151, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45389560, 1270413, 38725, 1189, 196, 13204, 868, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45428322, 1271607, 188, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45428513, 1271614, 888988, 21267, 252, 784101, 19967, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[46317516, 1292884, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[46317708, 1292892, 119, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.7", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46317852, 1292897, 249, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318104, 1292906, 170, 3, 33, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318277, 1292911, 193, 4, 33, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318507, 1292920, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318684, 1292926, 85537, 4877, 118, 72275, 4708, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404258, 1297808, 181, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404442, 1297814, 149, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404628, 1297822, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404783, 1297826, 53325, 1414, 196, 13928, 922, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46458145, 1299245, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46458298, 1299249, 45215, 1380, 196, 15333, 1006, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46503550, 1300634, 185, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46503738, 1300640, 881315, 21061, 252, 782915, 19841, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[47385068, 1321704, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[47385260, 1321712, 132, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.8", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385395, 1321715, 255, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385675, 1321724, 264, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385942, 1321733, 59743, 2242, 118, 27984, 1844, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47445700, 1323978, 395, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446098, 1323987, 232, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446333, 1323996, 297, 7, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446655, 1324007, 203, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446861, 1324014, 150, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447014, 1324019, 126, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447155, 1324025, 247, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447427, 1324034, 178, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447608, 1324040, 31318, 990, 196, 11037, 734, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47478941, 1325033, 392, 9, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479358, 1325046, 140, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479501, 1325050, 139, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479655, 1325056, 304, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479984, 1325066, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47480274, 1325077, 37893, 970, 196, 7731, 592, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47518170, 1326049, 27709, 585, 196, 4189, 289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47545906, 1326638, 187, 5, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546118, 1326647, 132, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546253, 1326651, 316, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546572, 1326659, 321, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546896, 1326667, 313, 5, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547212, 1326674, 271, 5, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547486, 1326681, 307, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547796, 1326689, 139, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547950, 1326695, 182, 4, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47548157, 1326703, 175, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47548335, 1326709, 34399, 938, 196, 9263, 622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47582749, 1327650, 359, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47583133, 1327661, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47583423, 1327672, 35972, 896, 196, 7020, 533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47619398, 1328570, 42756, 1023, 196, 9144, 603, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662181, 1329597, 212, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662418, 1329606, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662595, 1329612, 41734, 1733, 196, 23137, 1498, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704344, 1331348, 206, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704575, 1331357, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704865, 1331368, 36110, 898, 196, 7020, 533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47740978, 1332268, 99232, 3697, 196, 47514, 3053, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840237, 1335969, 216, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840478, 1335978, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840631, 1335982, 16729, 479, 196, 4699, 325, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857375, 1336464, 278, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857678, 1336474, 181, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857862, 1336480, 30128, 961, 196, 10784, 717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47888027, 1337446, 270, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47888322, 1337457, 44308, 1021, 196, 7810, 565, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47932633, 1338480, 30618, 670, 196, 5012, 348, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963278, 1339154, 272, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963575, 1339164, 185, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963763, 1339170, 880964, 21156, 252, 787865, 20001, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48844742, 1360329, 372, 8, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48845139, 1360341, 292, 6, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48845434, 1360349, 226985, 10583, 306, 150039, 9628, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072434, 1370935, 160, 2, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072619, 1370941, 289, 6, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072911, 1370949, 148321, 7487, 306, 107970, 6983, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49221247, 1378439, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]},
  "AOG3.3"->{
    Cell[1776, 53, 323, 8, 61, "Section",
      CellTags->{
      "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
        "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
        "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
    Cell[5247, 180, 206, 4, 24, "Outline1",
      CellTags->{"AOG3.", "AOG0.", "AOG3.3"}],
    Cell[5780, 200, 209, 4, 21, "Outline2",
      CellTags->{"AOG3.", "AOG0.", "AOG3.3"}],
    Cell[5992, 206, 384, 14, 46, "Outline3",
      CellTags->{"AOG0.", "AOG3.3"}],
    Cell[7938002, 296996, 111, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.3", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7938138, 297001, 90, 1, 32, "Subsubsection",
      CellTags->{"AOG3.3.1", "AOG3.3", "3.3.1", "AOG3."}],
    Cell[7938231, 297004, 302, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7938558, 297016, 143, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7938704, 297020, 20886, 735, 110, 9824, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7959627, 297760, 209, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7959839, 297767, 2356, 61, 59, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7962232, 297833, 199, 5, 27, "Input",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7962434, 297840, 718, 14, 54, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7963189, 297859, 250, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7963442, 297867, 3786, 100, 59, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7967243, 297970, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3.3", "AOG3."}],
    Cell[7967428, 297978, 92, 1, 32, "Subsubsection",
      CellTags->{"AOG3.3.2", "AOG3.3", "3.3.2", "AOG3."}],
    Cell[7967523, 297981, 327, 9, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7967875, 297994, 150, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7968028, 297998, 20738, 716, 130, 9473, 571, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7988803, 298719, 224, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7989030, 298726, 5803, 148, 113, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7994870, 298879, 267, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7995140, 298887, 2059, 36, 227, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7997236, 298928, 214, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7997453, 298935, 584, 13, 69, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7998052, 298951, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3.3", "AOG3."}],
    Cell[7998237, 298959, 95, 1, 32, "Subsubsection",
      CellTags->{"AOG3.3.3", "AOG3.3", "3.3.3", "AOG3."}],
    Cell[7998335, 298962, 366, 9, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[7998704, 298973, 353, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[7999082, 298985, 151, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[7999236, 298989, 2110, 55, 101, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8001383, 299049, 149, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8001535, 299053, 633, 13, 71, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8002183, 299069, 403, 9, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8002611, 299082, 129, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8002743, 299086, 28330, 797, 213, 7004, 528, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8031110, 299888, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8031267, 299892, 2285, 59, 99, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8033589, 299956, 194, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8033786, 299963, 684, 14, 69, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8034507, 299982, 192, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8034702, 299989, 342, 9, 49, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8035081, 300003, 185, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8035269, 300010, 3689, 98, 99, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8038995, 300113, 204, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8039202, 300120, 5736, 148, 129, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8044975, 300273, 179, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8045157, 300279, 1156, 30, 79, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8046350, 300314, 200, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8046553, 300321, 2313, 48, 79, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8048903, 300374, 221, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8049127, 300381, 5566, 140, 89, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8054708, 300524, 148, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG3.3", "AOG3."}]},
  "AOG4.1"->{
    Cell[6846, 242, 266, 6, 24, "Outline1",
      CellTags->{
      "AOG4.", "AOG0.", "AOG4.1", "AOG4.2", "AOG4.3", "AOG4.4", "AOG4.5", 
        "AOG4.6"}],
    Cell[8207629, 305171, 110, 1, 61, "Section",
      CellTags->{"AOG0.", "4", "AOG4.", "AOG4.1"}],
    Cell[8207764, 305176, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.1", "AOG4.", "AOG4.1"}],
    Cell[8207872, 305181, 99, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8207974, 305185, 431, 6, 80, "Print",
      CellTags->{"Info3312043438-4643038", "AOG4.", "AOG4.1"}],
    Cell[8208442, 305196, 107, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8208552, 305200, 685, 11, 54, "Output",
      CellTags->{"AOG4.", "AOG4.1"}],
    Cell[8209274, 305216, 96, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8209373, 305220, 1395, 19, 155, "Print",
      CellTags->{"Info3405686992-9872384", "AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8210805, 305244, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8210914, 305248, 854, 15, 54, "Output",
      CellTags->{"AOG4.", "AOG4.1"}],
    Cell[8211805, 305268, 98, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8211906, 305272, 3519, 47, 425, "Print",
      CellTags->{"Info3312043439-7338271", "AOG4.", "AOG4.1"}],
    Cell[8215462, 305324, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8215571, 305328, 857, 14, 78, "Output",
      CellTags->{"AOG4.", "AOG4.1"}],
    Cell[8216443, 305345, 331, 9, 59, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8216799, 305358, 165, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
    Cell[8216967, 305364, 157592, 4062, 397, 41452, 2622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.1"}]},
  "1"->{
    Cell[15104, 564, 71, 1, 61, "Section",
      CellTags->{"1", "AOG1.", "AOG0."}]},
  "2"->{
    Cell[16631, 625, 95, 1, 61, "Section",
      CellTags->{"AOG0.", "2", "AOG2."}]},
  "2.1"->{
    Cell[16751, 630, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.1", "AOG2.", "AOG2.1"}]},
  "2.1.1"->{
    Cell[16859, 635, 100, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.1", "AOG2.", "AOG2.1", "AOG2.1.1"}]},
  "AOG2.1.1"->{
    Cell[16859, 635, 100, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.1", "AOG2.", "AOG2.1", "AOG2.1.1"}],
    Cell[16962, 638, 1992, 55, 88, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.1"}],
    Cell[18979, 697, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.1"}],
    Cell[19091, 701, 485, 8, 65, "Print",
      CellTags->{
      "Info3312042809-6749329", "AOG2.", "AOG2.1", "AOG2.1.1", "AOG0."}]},
  "Info3312042809-6749329"->{
    Cell[19091, 701, 485, 8, 65, "Print",
      CellTags->{
      "Info3312042809-6749329", "AOG2.", "AOG2.1", "AOG2.1.1", "AOG0."}]},
  "2.1.2"->{
    Cell[19625, 715, 118, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.2", "AOG2.", "AOG2.1", "AOG2.2"}]},
  "2.1.3"->{
    Cell[138581, 4700, 111, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.3", "AOG2.", "AOG2.1", "AOG2.1.3"}]},
  "AOG2.1.3"->{
    Cell[138581, 4700, 111, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.3", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[138695, 4703, 1624, 33, 86, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[140322, 4738, 780, 13, 54, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[141105, 4753, 1236, 21, 70, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
    Cell[142344, 4776, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.3"}],
    Cell[142541, 4784, 131, 1, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "2.1.4", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[142675, 4787, 641, 13, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[143341, 4804, 329, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[143673, 4815, 18991, 659, 110, 8702, 527, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[162667, 5476, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[162954, 5486, 341, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[163298, 5497, 20462, 730, 110, 9828, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[183763, 6229, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[184050, 6239, 339, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[184392, 6250, 20821, 734, 110, 9839, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[205216, 6986, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[205481, 6994, 527, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[206011, 7005, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.3"}]},
  "2.1.4"->{
    Cell[142541, 4784, 131, 1, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "2.1.4", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}]},
  "AOG2.1.4"->{
    Cell[142541, 4784, 131, 1, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "2.1.4", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[142675, 4787, 641, 13, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[143341, 4804, 329, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[143673, 4815, 18991, 659, 110, 8702, 527, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[162667, 5476, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[162954, 5486, 341, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[163298, 5497, 20462, 730, 110, 9828, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[183763, 6229, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[184050, 6239, 339, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
    Cell[184392, 6250, 20821, 734, 110, 9839, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[205216, 6986, 250, 5, 41, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
    Cell[205481, 6994, 527, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}]},
  "2.1.5"->{
    Cell[206208, 7013, 112, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.5", "AOG2.", "AOG2.1", "AOG2.1.5"}]},
  "AOG2.1.5"->{
    Cell[206208, 7013, 112, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.5", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[206323, 7016, 876, 22, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[207224, 7042, 118, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[207345, 7046, 2749, 52, 129, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[210109, 7101, 915, 21, 56, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[211049, 7126, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[211160, 7130, 279, 5, 50, "Print",
      CellTags->{
      "Info3312042819-8757440", "AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[211476, 7140, 343, 10, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[211822, 7152, 20450, 730, 110, 9828, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[232275, 7884, 1016, 18, 88, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[233294, 7904, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[233448, 7912, 160, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[233611, 7919, 346, 6, 19, "Message",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[233960, 7927, 343, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[234306, 7936, 1745, 29, 131, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[236054, 7967, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[236186, 7973, 294, 8, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[236505, 7985, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
    Cell[236616, 7989, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
    Cell[236749, 7995, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.5"}]},
  "Info3312042819-8757440"->{
    Cell[211160, 7130, 279, 5, 50, "Print",
      CellTags->{
      "Info3312042819-8757440", "AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}]},
  "2.1.6"->{
    Cell[236946, 8003, 114, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.6", "AOG2.", "AOG2.1", "AOG2.1.6"}]},
  "AOG2.1.6"->{
    Cell[236946, 8003, 114, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.1.6", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[237063, 8006, 580, 11, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[237668, 8021, 293, 8, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[237964, 8031, 141, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238108, 8036, 147, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238258, 8041, 194, 4, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238455, 8047, 171, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238629, 8052, 233, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[238865, 8059, 374, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[239242, 8069, 565, 11, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[239810, 8082, 305, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240118, 8090, 267, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240388, 8097, 233, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240624, 8104, 359, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[240986, 8113, 565, 11, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[241554, 8126, 306, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[241863, 8134, 267, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[242133, 8141, 233, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[242369, 8148, 359, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[242731, 8157, 295, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243029, 8165, 306, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243338, 8173, 267, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243608, 8180, 360, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[243971, 8190, 154, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[244128, 8195, 229, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[244360, 8202, 241, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[244604, 8209, 454, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[245061, 8221, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[245537, 8233, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[245925, 8243, 457, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[246385, 8254, 489, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[246877, 8266, 410, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[247290, 8277, 480, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[247773, 8289, 497, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[248273, 8301, 418, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[248694, 8312, 435, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[249132, 8323, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[249602, 8335, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[249984, 8345, 452, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[250439, 8357, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[250911, 8369, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[251295, 8379, 241, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[251539, 8386, 454, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[251996, 8398, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[252472, 8410, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[252860, 8420, 466, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[253329, 8432, 489, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[253821, 8444, 410, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[254234, 8455, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[254732, 8467, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[255151, 8478, 433, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[255587, 8489, 465, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[256055, 8501, 377, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[256435, 8511, 450, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[256888, 8523, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[257360, 8535, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[257744, 8545, 241, 5, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[257988, 8552, 454, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[258445, 8564, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[258921, 8576, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[259309, 8586, 466, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[259778, 8598, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[260272, 8610, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[260687, 8621, 435, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[261125, 8632, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[261595, 8644, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[261977, 8654, 450, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[262430, 8666, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[262902, 8678, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[263286, 8688, 498, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[263787, 8700, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[264206, 8711, 488, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[264697, 8723, 406, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[265106, 8734, 474, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[265583, 8746, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[265969, 8756, 476, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[266448, 8768, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[266836, 8778, 344, 7, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[267183, 8787, 303, 6, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[267489, 8795, 139, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[267631, 8800, 1172, 20, 88, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[268840, 8825, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[268951, 8829, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[269083, 8835, 445, 10, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[269553, 8849, 267, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[269823, 8859, 1727, 28, 194, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[271565, 8890, 301, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[271891, 8900, 312, 8, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[272206, 8910, 141, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[272350, 8915, 483, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[272836, 8927, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[273243, 8938, 509, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[273755, 8950, 432, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[274190, 8961, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[274684, 8973, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[275099, 8984, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[275597, 8996, 418, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[276018, 9007, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[276516, 9019, 418, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[276937, 9030, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[277409, 9042, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[277795, 9052, 465, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[278263, 9064, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[278645, 9074, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[279121, 9086, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[279509, 9096, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[279981, 9108, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[280367, 9118, 521, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[280891, 9130, 442, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[281336, 9141, 483, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[281822, 9153, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[282229, 9164, 509, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[282741, 9176, 430, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[283174, 9187, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[283668, 9199, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[284083, 9210, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[284581, 9222, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[285000, 9233, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[285498, 9245, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[285917, 9256, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[286389, 9268, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[286773, 9278, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[287243, 9290, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[287625, 9300, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[288101, 9312, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[288487, 9322, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[288961, 9334, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[289347, 9344, 521, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[289871, 9356, 442, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[290316, 9367, 483, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[290802, 9379, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[291209, 9390, 509, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[291721, 9402, 430, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[292154, 9413, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[292648, 9425, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[293063, 9436, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[293561, 9448, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[293980, 9459, 495, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[294478, 9471, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[294897, 9482, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[295367, 9494, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[295749, 9504, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[296219, 9516, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[296601, 9526, 473, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[297077, 9538, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[297463, 9548, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[297937, 9560, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[298323, 9570, 521, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[298847, 9582, 442, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[299292, 9593, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[299766, 9605, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[300152, 9615, 489, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[300644, 9627, 410, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[301057, 9638, 465, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[301525, 9650, 377, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[301905, 9660, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[302377, 9672, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[302761, 9682, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[303235, 9694, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[303621, 9704, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[304115, 9716, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[304530, 9727, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[305000, 9739, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[305382, 9749, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[305854, 9761, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[306238, 9771, 471, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[306712, 9783, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[307098, 9793, 491, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[307592, 9805, 412, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[308007, 9816, 467, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[308477, 9828, 379, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[308859, 9838, 469, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[309331, 9850, 381, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[309715, 9860, 498, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[310216, 9872, 416, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[310635, 9883, 488, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[311126, 9895, 404, 9, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[311533, 9906, 474, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[312010, 9918, 383, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[312396, 9928, 476, 10, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[312875, 9940, 385, 8, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[313263, 9950, 139, 3, 20, "Print",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[313405, 9955, 1101, 20, 113, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[314521, 9978, 283, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[314829, 9988, 177, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
    Cell[315009, 9994, 1686, 29, 111, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
    Cell[316710, 10026, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.6"}]},
  "AOG2.1.7"->{
    Cell[316907, 10034, 108, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7", "2.1.7"}],
    Cell[317018, 10037, 526, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[317569, 10050, 337, 10, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[317909, 10062, 22699, 836, 110, 11522, 692, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[340611, 10900, 2909, 48, 205, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[343535, 10951, 253, 5, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[343813, 10960, 389, 12, 155, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
    Cell[344205, 10974, 40769, 1619, 159, 22270, 1385, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[384977, 12595, 3259, 51, 206, "Output",
      CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
    Cell[388251, 12649, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.7"}]},
  "2.1.7"->{
    Cell[316907, 10034, 108, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7", "2.1.7"}]},
  "AOG2.1.8"->{
    Cell[388448, 12657, 119, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8", "2.1.8"}],
    Cell[388570, 12660, 366, 7, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[388961, 12671, 360, 10, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[389324, 12683, 43019, 1385, 257, 15999, 1046, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[432346, 14070, 1492, 27, 145, "Output",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[433853, 14100, 563, 14, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[434441, 14118, 162, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[434606, 14125, 566, 9, 65, "Print",
      CellTags->{
      "Info3312042871-8199869", "AOG2.", "AOG2.1", "AOG2.1.8", "AOG0."}],
    Cell[435209, 14139, 366, 10, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[435578, 14151, 20370, 730, 110, 9744, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[455951, 14883, 1831, 30, 145, "Output",
      CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
    Cell[457797, 14916, 492, 15, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
    Cell[458292, 14933, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.8"}]},
  "2.1.8"->{
    Cell[388448, 12657, 119, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8", "2.1.8"}]},
  "Info3312042871-8199869"->{
    Cell[434606, 14125, 566, 9, 65, "Print",
      CellTags->{
      "Info3312042871-8199869", "AOG2.", "AOG2.1", "AOG2.1.8", "AOG0."}]},
  "2.2"->{
    Cell[458501, 14942, 96, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.2", "AOG2.", "AOG2.2"}]},
  "2.2.1"->{
    Cell[459150, 14961, 128, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.2.1", "AOG2.", "AOG2.2", "AOG2.2.1"}]},
  "AOG2.2.1"->{
    Cell[459150, 14961, 128, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.2.1", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[459281, 14964, 723, 15, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460007, 14981, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460121, 14985, 267, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460391, 14994, 268, 5, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460684, 15003, 192, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[460879, 15010, 23289, 697, 130, 7253, 493, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[484183, 15710, 551, 12, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[484759, 15726, 246, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[485008, 15734, 552, 10, 77, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[485575, 15747, 482, 11, 40, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[486082, 15762, 152, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[486237, 15766, 1723, 24, 185, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[487975, 15793, 158, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[488158, 15801, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[488300, 15805, 71910, 1447, 240, 21739, 822, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[560225, 17255, 196, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[560446, 17263, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[560570, 17267, 1525, 21, 185, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[562132, 17293, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[562256, 17297, 1494, 22, 185, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[563765, 17322, 255, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[564045, 17332, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[564185, 17336, 5152, 92, 129, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[569352, 17431, 378, 6, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[569755, 17441, 230, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[569988, 17449, 225, 4, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[570228, 17456, 287, 7, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[570540, 17467, 261, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[570804, 17475, 76731, 5322, 130, 64916, 5171, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[647538, 22799, 426, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[647979, 22811, 667, 11, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[648671, 22826, 244, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[648918, 22834, 1029, 19, 73, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[649962, 22856, 200, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[650187, 22864, 184, 3, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[650374, 22869, 5263, 73, 617, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[655652, 22945, 300, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[655977, 22955, 245, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[656225, 22963, 221, 4, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[656461, 22970, 419, 8, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[656905, 22982, 259, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[657167, 22990, 76745, 5322, 130, 64930, 5171, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[733915, 28314, 425, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[734355, 28326, 441, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[734821, 28337, 260, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[735084, 28345, 315480, 24523, 130, 303636, 24371, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[1050567, 52870, 424, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
    Cell[1051006, 52882, 188, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
    Cell[1051197, 52888, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.2", "AOG2.", "AOG2.2.1"}]},
  "AOG2.2.2"->{
    Cell[1051394, 52896, 126, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2", "2.2.2"}],
    Cell[1051523, 52899, 815, 13, 52, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1052341, 52914, 301, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1052667, 52926, 172, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1052842, 52932, 39451, 2840, 64, 34309, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1092308, 55775, 399, 12, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1092732, 55791, 288, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1093023, 55799, 938, 17, 88, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1093976, 55819, 216, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1094217, 55827, 176, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1094396, 55833, 28646, 598, 184, 4073, 289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1123057, 56434, 487, 9, 38, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1123547, 56445, 193, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1123765, 56454, 186, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1123954, 56461, 7133, 104, 324, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1131102, 56568, 191, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1131318, 56577, 206, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1131527, 56585, 24152, 606, 184, 5492, 370, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1155694, 57194, 186, 4, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1155905, 57202, 117, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1156025, 57206, 27273, 690, 184, 6378, 427, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1183313, 57899, 504, 8, 36, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1183842, 57911, 274, 7, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1184119, 57920, 3410, 47, 401, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1187566, 57972, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1187777, 57978, 3008, 42, 365, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1190822, 58025, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1191033, 58031, 3054, 42, 365, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1194124, 58078, 378, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[1194527, 58090, 252102, 6207, 240, 177264, 5277, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1446632, 64299, 302511, 6827, 240, 177429, 5277, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[1749146, 71128, 278598, 6544, 240, 177380, 5289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[2027747, 77674, 1438537, 71956, 261, 1301290, 70256, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3466333, 149636, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3466473, 149640, 9632, 174, 234, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3476142, 149819, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3476256, 149823, 115, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3476386, 149829, 199, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3476610, 149839, 258, 9, 107, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3476871, 149850, 293, 6, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3477201, 149861, 200, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3477426, 149871, 38782, 2831, 64, 34341, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3516211, 152704, 39691, 2844, 64, 34229, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3555917, 155551, 946, 17, 54, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3556878, 155571, 277, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3557180, 155582, 195, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3557378, 155589, 295, 5, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3557710, 155599, 150, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
    Cell[3557863, 155603, 39799, 2844, 64, 34345, 2771, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3597665, 158449, 424, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
    Cell[3598104, 158461, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.2", "AOG2.", "AOG2.2.2"}]},
  "2.2.2"->{
    Cell[1051394, 52896, 126, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2", "2.2.2"}]},
  "2.2.3"->{
    Cell[3598301, 158469, 107, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.2.3", "AOG2.", "AOG2.2", "AOG2.2.3"}]},
  "AOG2.2.3"->{
    Cell[3598301, 158469, 107, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.2.3", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3598411, 158472, 373, 6, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3598787, 158480, 574, 10, 85, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599364, 158492, 175, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599542, 158498, 108, 1, 22, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599675, 158503, 166, 3, 25, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3599844, 158508, 28599, 1237, 86, 18759, 1110, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3628480, 159750, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3628622, 159754, 132, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3628791, 159762, 140, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3628934, 159766, 132, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3629103, 159774, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3629214, 159778, 521, 12, 35, "Print",
      CellTags->{
      "Info3312042947-9251066", "AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3629772, 159795, 165, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3629940, 159801, 117, 3, 38, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3630094, 159809, 156, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3630253, 159813, 117, 3, 38, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3630385, 159819, 391, 8, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3630801, 159831, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3630913, 159835, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3631067, 159843, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3631179, 159847, 2067, 38, 214, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3633283, 159890, 168, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3633454, 159896, 140, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3633631, 159904, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3633755, 159908, 119, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3633911, 159916, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3634035, 159920, 12755, 207, 1238, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3646827, 160132, 260, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3647090, 160140, 258, 5, 26, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3647385, 160150, 344, 12, 155, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3647732, 160164, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3647887, 160172, 269, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3648159, 160180, 254, 5, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3648450, 160190, 155, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3648608, 160197, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3648763, 160205, 155, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3648921, 160212, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3649076, 160220, 155, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3649234, 160227, 118, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3649389, 160235, 148, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3649540, 160239, 47437, 819, 1149, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3697014, 161063, 112, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3697129, 161067, 117, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3697283, 161075, 255, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3697541, 161085, 508, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3698086, 161099, 276, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3698365, 161109, 3592, 63, 129, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3701994, 161177, 525, 11, 139, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[3702544, 161192, 18991, 786, 86, 11568, 689, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3721538, 161980, 19404, 805, 86, 11762, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3740945, 162787, 17533, 725, 86, 10993, 639, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3758481, 163514, 21004, 843, 86, 12058, 727, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3779488, 164359, 22226, 965, 86, 13636, 853, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3801717, 165326, 24095, 1034, 86, 14388, 909, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3825815, 166362, 18228, 740, 86, 11141, 647, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3844046, 167104, 25166, 1090, 86, 15289, 963, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3869215, 168196, 24747, 1071, 86, 15113, 947, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3893965, 169269, 25378, 1114, 86, 15849, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3919346, 170385, 25093, 1076, 86, 15118, 947, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3944442, 171463, 23817, 1008, 86, 13964, 881, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3968262, 172473, 25725, 1085, 86, 14989, 947, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[3993990, 173560, 22928, 1085, 86, 15776, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4016921, 174647, 24033, 1099, 86, 15767, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4040957, 175748, 21595, 980, 86, 14014, 881, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4062555, 176730, 23316, 1089, 86, 15800, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4085874, 177821, 23217, 980, 86, 13708, 857, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4109094, 178803, 24174, 1099, 86, 15844, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4133271, 179904, 23922, 1075, 86, 15288, 963, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4157196, 180981, 24420, 1103, 86, 15830, 991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4181619, 182086, 24090, 1067, 86, 15136, 951, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4205712, 183155, 17283, 700, 86, 10686, 613, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4222998, 183857, 17236, 713, 86, 10910, 629, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4240237, 184572, 20490, 947, 86, 13678, 857, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4260730, 185521, 22588, 1004, 86, 14387, 897, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4283321, 186527, 22189, 967, 86, 13693, 857, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4305525, 187497, 10122, 191, 414, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4315684, 187693, 206, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[4315893, 187701, 310, 5, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4316240, 187711, 531, 13, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[4316774, 187726, 29237, 1570, 86, 21628, 1471, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4346014, 189298, 428, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4346479, 189312, 479, 13, 123, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
    Cell[4346961, 189327, 428, 9, 24, "Output",
      CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
    Cell[4347404, 189339, 160, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG2.2.3", "AOG2.2", "AOG2."}]},
  "Info3312042947-9251066"->{
    Cell[3629214, 159778, 521, 12, 35, "Print",
      CellTags->{
      "Info3312042947-9251066", "AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]},
  "2.3"->{
    Cell[4347613, 189348, 119, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.3", "AOG2.", "AOG2.3", "AOG2.3.1"}]},
  "AOG2.3.1"->{
    Cell[4347613, 189348, 119, 1, 36, "Subsection",
      CellTags->{"AOG0.", "2.3", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4347757, 189353, 101, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.1", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4347883, 189358, 160, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348046, 189364, 165, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4348226, 189370, 231, 7, 59, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348460, 189379, 180, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348665, 189387, 167, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4348835, 189393, 31520, 1334, 159, 20081, 1187, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4380370, 190730, 184, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4380579, 190739, 131, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4380713, 190743, 418, 7, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}],
    Cell[4381168, 190755, 202, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
    Cell[4381373, 190763, 13835, 365, 184, 3130, 227, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}]},
  "2.3.1"->{
    Cell[4347757, 189353, 101, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.1", "AOG2.", "AOG2.3", "AOG2.3.1"}]},
  "2.3.2"->{
    Cell[4395408, 191139, 116, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.2", "AOG2.", "AOG2.3", "AOG2.3.2"}]},
  "AOG2.3.2"->{
    Cell[4395408, 191139, 116, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.2", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4395549, 191144, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4395673, 191148, 42033, 1026, 296, 7262, 591, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4437709, 192176, 922, 21, 39, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4438668, 192202, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4438847, 192208, 42773, 1154, 184, 9613, 739, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4481623, 193364, 60297, 1107, 184, 6603, 439, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
    Cell[4541969, 194477, 135, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
    Cell[4542107, 194481, 36182, 848, 184, 6910, 481, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}]},
  "2.3.3"->{
    Cell[4578489, 195340, 104, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.3", "AOG2.", "AOG2.3", "AOG2.3.3"}]},
  "AOG2.3.3"->{
    Cell[4578489, 195340, 104, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.3", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4578618, 195345, 280, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4578901, 195353, 319, 6, 26, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4579257, 195364, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4579399, 195368, 23061, 533, 184, 4091, 293, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4602497, 195906, 118, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4602618, 195910, 23167, 551, 184, 4496, 315, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4625822, 196466, 116, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4625941, 196470, 342, 6, 26, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4626298, 196479, 139, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4626440, 196483, 144, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4626609, 196489, 168, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4626780, 196495, 28051, 731, 184, 6546, 460, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4654868, 197231, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4655001, 197235, 1609, 28, 94, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4656647, 197268, 145, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
    Cell[4656795, 197272, 402, 7, 23, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4657200, 197281, 401, 7, 23, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4657604, 197290, 401, 7, 23, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4658008, 197299, 247, 5, 19, "Message",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
    Cell[4658258, 197306, 19539, 493, 184, 4204, 298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]},
  "2.3.4"->{
    Cell[4677997, 197810, 116, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.4", "AOG2.", "AOG2.3", "AOG2.3.4"}]},
  "AOG2.3.4"->{
    Cell[4677997, 197810, 116, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "2.3.4", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678116, 197813, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678273, 197817, 380, 15, 203, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678678, 197836, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4678807, 197840, 1462, 26, 198, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4680306, 197871, 116, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4680425, 197875, 652, 13, 39, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4681114, 197893, 197, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4681314, 197900, 132, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4681461, 197906, 120, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4681606, 197912, 142, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4681751, 197916, 29725, 703, 184, 5721, 401, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4711513, 198624, 153, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4711669, 198628, 134, 3, 24, "Output",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4711840, 198636, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4711997, 198640, 20416, 550, 184, 4840, 352, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4732450, 199195, 138, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4732591, 199199, 46075, 859, 377, 4774, 344, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4778703, 200063, 166, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4778872, 200069, 21023, 472, 184, 3388, 249, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[4799910, 200544, 276, 6, 34, "Text",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4800211, 200554, 203, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[4800417, 200561, 1857010, 45857, 240, 1775535, 44846, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[6657464, 246423, 277, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[6657744, 246431, 706903, 40556, 294, 616171, 39430, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}],
    Cell[7364684, 286992, 279, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
    Cell[7364966, 287000, 476455, 6607, 294, 247926, 3780, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]},
  "3"->{
    Cell[7841645, 293620, 99, 1, 61, "Section",
      CellTags->{"AOG0.", "3", "AOG3."}]},
  "3.1"->{
    Cell[7841769, 293625, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.1", "AOG3.", "AOG3.1"}]},
  "AOG3.1"->{
    Cell[7841769, 293625, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.1", "AOG3.", "AOG3.1"}],
    Cell[7841877, 293630, 101, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7841981, 293634, 328, 5, 80, "Print",
      CellTags->{"Info3312043331-3736878", "AOG3.", "AOG3.1"}],
    Cell[7842346, 293644, 108, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7842457, 293648, 803, 13, 89, "Output",
      CellTags->{"AOG3.", "AOG3.1"}],
    Cell[7843275, 293664, 351, 9, 91, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7843651, 293677, 141, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7843795, 293681, 32764, 1445, 132, 20021, 1282, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.1"}],
    Cell[7876596, 295131, 154, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7876753, 295137, 1399, 25, 95, "Output",
      CellTags->{"AOG3.", "AOG3.1"}],
    Cell[7878189, 295167, 176, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7878368, 295174, 23705, 563, 103, "Output",
      CellTags->{"AOG3.", "AOG3.1"}],
    Cell[7902110, 295742, 193, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
    Cell[7902306, 295749, 3068, 76, 49, "Output",
      CellTags->{"AOG3.", "AOG3.1"}]},
  "Info3312043331-3736878"->{
    Cell[7841981, 293634, 328, 5, 80, "Print",
      CellTags->{"Info3312043331-3736878", "AOG3.", "AOG3.1"}]},
  "3.2"->{
    Cell[7905564, 295836, 99, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.2", "AOG3.", "AOG3.2"}]},
  "AOG3.2"->{
    Cell[7905564, 295836, 99, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.2", "AOG3.", "AOG3.2"}],
    Cell[7905666, 295839, 228, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
    Cell[7905919, 295850, 131, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
    Cell[7906053, 295854, 30690, 1092, 222, 13662, 876, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.2"}],
    Cell[7936780, 296951, 177, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
    Cell[7936960, 296958, 378, 9, 67, "Output",
      CellTags->{"AOG3.", "AOG3.2"}],
    Cell[7937375, 296972, 121, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
    Cell[7937499, 296976, 313, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.2"}]},
  "3.3"->{
    Cell[7938002, 296996, 111, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.3", "AOG3.", "AOG3.3", "AOG3.3.1"}]},
  "AOG3.3.1"->{
    Cell[7938002, 296996, 111, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.3", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7938138, 297001, 90, 1, 32, "Subsubsection",
      CellTags->{"AOG3.3.1", "AOG3.3", "3.3.1", "AOG3."}],
    Cell[7938231, 297004, 302, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7938558, 297016, 143, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7938704, 297020, 20886, 735, 110, 9824, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7959627, 297760, 209, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7959839, 297767, 2356, 61, 59, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7962232, 297833, 199, 5, 27, "Input",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7962434, 297840, 718, 14, 54, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7963189, 297859, 250, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
    Cell[7963442, 297867, 3786, 100, 59, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}]},
  "3.3.1"->{
    Cell[7938138, 297001, 90, 1, 32, "Subsubsection",
      CellTags->{"AOG3.3.1", "AOG3.3", "3.3.1", "AOG3."}]},
  "AOG3.3.2"->{
    Cell[7967428, 297978, 92, 1, 32, "Subsubsection",
      CellTags->{"AOG3.3.2", "AOG3.3", "3.3.2", "AOG3."}],
    Cell[7967523, 297981, 327, 9, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7967875, 297994, 150, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7968028, 297998, 20738, 716, 130, 9473, 571, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7988803, 298719, 224, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7989030, 298726, 5803, 148, 113, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7994870, 298879, 267, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7995140, 298887, 2059, 36, 227, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7997236, 298928, 214, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
    Cell[7997453, 298935, 584, 13, 69, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}]},
  "3.3.2"->{
    Cell[7967428, 297978, 92, 1, 32, "Subsubsection",
      CellTags->{"AOG3.3.2", "AOG3.3", "3.3.2", "AOG3."}]},
  "AOG3.3.3"->{
    Cell[7998237, 298959, 95, 1, 32, "Subsubsection",
      CellTags->{"AOG3.3.3", "AOG3.3", "3.3.3", "AOG3."}],
    Cell[7998335, 298962, 366, 9, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[7998704, 298973, 353, 8, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[7999082, 298985, 151, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[7999236, 298989, 2110, 55, 101, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8001383, 299049, 149, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8001535, 299053, 633, 13, 71, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8002183, 299069, 403, 9, 75, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8002611, 299082, 129, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8002743, 299086, 28330, 797, 213, 7004, 528, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8031110, 299888, 154, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8031267, 299892, 2285, 59, 99, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8033589, 299956, 194, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8033786, 299963, 684, 14, 69, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8034507, 299982, 192, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8034702, 299989, 342, 9, 49, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8035081, 300003, 185, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8035269, 300010, 3689, 98, 99, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8038995, 300113, 204, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8039202, 300120, 5736, 148, 129, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8044975, 300273, 179, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8045157, 300279, 1156, 30, 79, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8046350, 300314, 200, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8046553, 300321, 2313, 48, 79, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8048903, 300374, 221, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
    Cell[8049127, 300381, 5566, 140, 89, "Output",
      CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]},
  "3.3.3"->{
    Cell[7998237, 298959, 95, 1, 32, "Subsubsection",
      CellTags->{"AOG3.3.3", "AOG3.3", "3.3.3", "AOG3."}]},
  "3.4"->{
    Cell[8054905, 300533, 97, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.4", "AOG3.", "AOG3.4"}]},
  "AOG3.4"->{
    Cell[8054905, 300533, 97, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.4", "AOG3.", "AOG3.4"}],
    Cell[8055005, 300536, 283, 7, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8055313, 300547, 131, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8055447, 300551, 21420, 742, 110, 9782, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8076904, 301298, 234, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8077141, 301305, 1133, 18, 142, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8078311, 301328, 244, 6, 43, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8078558, 301336, 1349, 25, 73, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8079944, 301366, 110, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8080057, 301370, 360, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8080454, 301384, 105, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8080562, 301388, 724, 15, 73, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}],
    Cell[8081323, 301408, 110, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
    Cell[8081436, 301412, 517, 12, 59, "Output",
      CellTags->{"AOG3.", "AOG3.4", "AOG0."}]},
  "3.5"->{
    Cell[8082143, 301435, 106, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.5", "AOG3.", "AOG3.5"}]},
  "AOG3.5"->{
    Cell[8082143, 301435, 106, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.5", "AOG3.", "AOG3.5"}],
    Cell[8082252, 301438, 187, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8082464, 301448, 129, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8082596, 301452, 14186, 465, 110, 6735, 367, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8096819, 301922, 176, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8096998, 301929, 352, 9, 67, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8097387, 301943, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8097496, 301947, 308, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8097841, 301961, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8097950, 301965, 317, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8098282, 301977, 197, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8098504, 301987, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8098637, 301991, 17341, 551, 110, 7606, 425, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8116015, 302547, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8116144, 302551, 13181, 381, 102, 3851, 260, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8129362, 302937, 181, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8129546, 302944, 400, 10, 69, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8129983, 302959, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8130097, 302963, 308, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8130442, 302977, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8130551, 302981, 324, 9, 67, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8130912, 302995, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8131026, 302999, 317, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8131358, 303011, 242, 8, 24, "Text",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8131603, 303021, 211, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8131839, 303031, 129, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8131971, 303035, 14838, 515, 110, 7298, 416, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8146846, 303555, 164, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8147013, 303561, 352, 9, 67, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8147402, 303575, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8147511, 303579, 308, 9, 59, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8147856, 303593, 197, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8148056, 303600, 2543, 70, 59, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8150614, 303673, 148, 4, 24, "Text",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8150765, 303679, 241, 6, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8151031, 303689, 111, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8151145, 303693, 21765, 551, 202, 3804, 324, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8172947, 304249, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8173076, 304253, 1631, 49, 115, "Output",
      CellTags->{"AOG3.", "AOG3.5"}],
    Cell[8174744, 304307, 106, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
    Cell[8174853, 304311, 1051, 31, 99, "Output",
      CellTags->{"AOG3.", "AOG3.5"}]},
  "3.6"->{
    Cell[8176094, 304353, 91, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.6", "AOG3.", "AOG3.6"}]},
  "AOG3.6"->{
    Cell[8176094, 304353, 91, 1, 36, "Subsection",
      CellTags->{"AOG0.", "3.6", "AOG3.", "AOG3.6"}],
    Cell[8176210, 304358, 93, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8176306, 304362, 2733, 37, 320, "Print",
      CellTags->{"Info3312115087-1929230", "AOG3.", "AOG3.6"}],
    Cell[8179054, 304402, 328, 8, 59, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8179407, 304414, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8179547, 304418, 23532, 617, 240, 7151, 409, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG3.", "AOG3.6", "AOG0."}],
    Cell[8203116, 305040, 105, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8203224, 305044, 196, 4, 24, "Output",
      CellTags->{"AOG3.", "AOG3.6", "AOG0."}],
    Cell[8203457, 305053, 275, 7, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8203735, 305062, 901, 22, 75, "Output",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8204673, 305089, 105, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8204781, 305093, 393, 9, 85, "Output",
      CellTags->{"AOG3.", "AOG3.6", "AOG0."}],
    Cell[8205211, 305107, 271, 6, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8205485, 305115, 314, 9, 49, "Output",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8205836, 305129, 185, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
    Cell[8206024, 305136, 1403, 23, 84, "Output",
      CellTags->{"AOG0.", "AOG3.", "AOG3.6"}]},
  "Info3312115087-1929230"->{
    Cell[8176306, 304362, 2733, 37, 320, "Print",
      CellTags->{"Info3312115087-1929230", "AOG3.", "AOG3.6"}]},
  "4"->{
    Cell[8207629, 305171, 110, 1, 61, "Section",
      CellTags->{"AOG0.", "4", "AOG4.", "AOG4.1"}]},
  "4.1"->{
    Cell[8207764, 305176, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.1", "AOG4.", "AOG4.1"}]},
  "Info3312043438-4643038"->{
    Cell[8207974, 305185, 431, 6, 80, "Print",
      CellTags->{"Info3312043438-4643038", "AOG4.", "AOG4.1"}]},
  "Info3405686992-9872384"->{
    Cell[8209373, 305220, 1395, 19, 155, "Print",
      CellTags->{"Info3405686992-9872384", "AOG0.", "AOG4.", "AOG4.1"}]},
  "Info3312043439-7338271"->{
    Cell[8211906, 305272, 3519, 47, 425, "Print",
      CellTags->{"Info3312043439-7338271", "AOG4.", "AOG4.1"}]},
  "4.2"->{
    Cell[8374749, 309437, 109, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.2", "AOG4.", "AOG4.2", "AOG4.2.1"}]},
  "AOG4.2.1"->{
    Cell[8374749, 309437, 109, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.2", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8374883, 309442, 94, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.2.1", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8374980, 309445, 337, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8375342, 309457, 153, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8375498, 309461, 36774, 1565, 119, 21947, 1376, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8412309, 311031, 204, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8412516, 311038, 3171, 77, 49, "Output",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8415724, 311120, 255, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
    Cell[8415982, 311127, 3042, 82, 59, "Output",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}]},
  "4.2.1"->{
    Cell[8374883, 309442, 94, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.2.1", "AOG4.", "AOG4.2", "AOG4.2.1"}]},
  "4.2.2"->{
    Cell[8419224, 311220, 101, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.2.2", "AOG4.", "AOG4.2", "AOG4.2.2"}]},
  "AOG4.2.2"->{
    Cell[8419224, 311220, 101, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.2.2", "AOG4.", "AOG4.2", "AOG4.2.2"}],
    Cell[8419350, 311225, 134, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.2"}],
    Cell[8419487, 311229, 4148, 71, 204, "Output",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.2"}]},
  "4.2.3"->{
    Cell[8423835, 311311, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.2.3", "AOG4.", "AOG4.2", "AOG4.2.3"}]},
  "AOG4.2.3"->{
    Cell[8423835, 311311, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.2.3", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8423960, 311316, 133, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8424096, 311320, 41750, 905, 184, 10085, 508, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8465883, 312230, 176, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8466062, 312236, 40778, 891, 184, 10370, 510, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8506877, 313132, 185, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8507087, 313141, 42205, 924, 184, 10651, 529, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8549295, 314067, 40885, 946, 184, 11239, 574, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8590229, 315019, 199, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8590431, 315026, 99253, 2755, 184, 29018, 1882, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
    Cell[8689687, 317783, 3595, 64, 210, "Output",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}]},
  "4.2.4"->{
    Cell[8693482, 317858, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.2.4", "AOG4.", "AOG4.2", "AOG4.2.4"}]},
  "AOG4.2.4"->{
    Cell[8693482, 317858, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.2.4", "AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8693607, 317863, 176, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8693786, 317869, 82869, 3386, 119, 44933, 2912, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8776692, 321260, 179, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.4"}],
    Cell[8776874, 321266, 86168, 3632, 119, 49560, 3174, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.2", "AOG4.2.4"}]},
  "4.3"->{
    Cell[8863254, 324910, 114, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.3", "AOG4.", "AOG4.3", "AOG4.3.1"}]},
  "AOG4.3.1"->{
    Cell[8863254, 324910, 114, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.3", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863393, 324915, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.1", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863490, 324918, 327, 9, 96, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863842, 324931, 139, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8863984, 324935, 110082, 2058, 598, 14663, 874, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8974103, 326998, 244, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8974350, 327005, 3583, 98, 109, "Output",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8977970, 327108, 245, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
    Cell[8978218, 327115, 3609, 98, 109, "Output",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}]},
  "4.3.1"->{
    Cell[8863393, 324915, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.1", "AOG4.", "AOG4.3", "AOG4.3.1"}]},
  "4.3.2"->{
    Cell[8982027, 327224, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.2", "AOG4.", "AOG4.3", "AOG4.3.2"}]},
  "AOG4.3.2"->{
    Cell[8982027, 327224, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.2", "AOG4.", "AOG4.3", "AOG4.3.2"}],
    Cell[8982153, 327229, 138, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.2"}],
    Cell[8982294, 327233, 4394, 75, 213, "Output",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.2"}]},
  "4.3.3"->{
    Cell[8986888, 327319, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.3", "AOG4.", "AOG4.3", "AOG4.3.3"}]},
  "AOG4.3.3"->{
    Cell[8986888, 327319, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.3", "AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[8987013, 327324, 137, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[8987175, 327330, 36915, 812, 184, 8790, 459, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[9024093, 328144, 35572, 827, 184, 9311, 497, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}],
    Cell[9059680, 328974, 5041, 92, 284, "Output",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}]},
  "4.3.4"->{
    Cell[9064921, 329077, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.4", "AOG4.", "AOG4.3", "AOG4.3.4"}]},
  "AOG4.3.4"->{
    Cell[9064921, 329077, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.3.4", "AOG4.", "AOG4.3", "AOG4.3.4"}],
    Cell[9065046, 329082, 191, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.4"}],
    Cell[9065240, 329089, 346463, 19400, 562, 207570, 17680, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.3", "AOG4.3.4"}]},
  "4.4"->{
    Cell[9411915, 348501, 108, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.4", "AOG4.", "AOG4.4", "AOG4.4.1"}]},
  "AOG4.4.1"->{
    Cell[9411915, 348501, 108, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.4", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412048, 348506, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.1", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412145, 348509, 338, 8, 96, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412508, 348521, 132, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9412643, 348525, 93072, 1898, 564, 16306, 945, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9505752, 350428, 202, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9505957, 350435, 5040, 126, 91, "Output",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9511034, 350566, 181, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
    Cell[9511218, 350573, 1280, 30, 79, "Output",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}]},
  "4.4.1"->{
    Cell[9412048, 348506, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.1", "AOG4.", "AOG4.4", "AOG4.4.1"}]},
  "4.4.2"->{
    Cell[9512698, 350614, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.2", "AOG4.", "AOG4.4", "AOG4.4.2"}]},
  "AOG4.4.2"->{
    Cell[9512698, 350614, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.2", "AOG4.", "AOG4.4", "AOG4.4.2"}],
    Cell[9512824, 350619, 131, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.2"}],
    Cell[9512958, 350623, 6349, 112, 293, "Output",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.2"}]},
  "4.4.3"->{
    Cell[9519507, 350746, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.3", "AOG4.", "AOG4.4", "AOG4.4.3"}]},
  "AOG4.4.3"->{
    Cell[9519507, 350746, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.3", "AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9519632, 350751, 131, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9519788, 350757, 41693, 926, 184, 10477, 535, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9561484, 351685, 41582, 925, 184, 10475, 535, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9603093, 352614, 88, 2, 28, "Input",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9603206, 352620, 181, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9603412, 352629, 42973, 944, 184, 10888, 542, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9646388, 353575, 40331, 937, 184, 11240, 572, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9686722, 354514, 43028, 945, 184, 10880, 542, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
    Cell[9729753, 355461, 40128, 935, 184, 11183, 572, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}]},
  "4.4.4"->{
    Cell[9770093, 356408, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.4", "AOG4.", "AOG4.4", "AOG4.4.4"}]},
  "AOG4.4.4"->{
    Cell[9770093, 356408, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.4.4", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9770218, 356413, 176, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9770397, 356419, 88137, 4899, 120, 72452, 4700, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9858571, 361323, 177, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9858751, 361329, 90758, 4928, 84, 72786, 4700, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9949546, 366262, 149, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
    Cell[9949698, 366266, 149230, 11357, 188, 129962, 11114, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}]},
  "4.5"->{
    Cell[10099140, 377635, 110, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.5", "AOG4.", "AOG4.5", "AOG4.5.1"}]},
  "AOG4.5.1"->{
    Cell[10099140, 377635, 110, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.5", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099275, 377640, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.1", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099372, 377643, 346, 8, 79, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099743, 377655, 129, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10099875, 377659, 38235, 962, 255, 7596, 578, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10138147, 378626, 181, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10138331, 378633, 3947, 102, 99, "Output",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10142315, 378740, 178, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
    Cell[10142496, 378746, 706, 13, 37, "Output",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}]},
  "4.5.1"->{
    Cell[10099275, 377640, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.1", "AOG4.", "AOG4.5", "AOG4.5.1"}]},
  "4.5.2"->{
    Cell[10143402, 378770, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.2", "AOG4.", "AOG4.5", "AOG4.5.2"}]},
  "AOG4.5.2"->{
    Cell[10143402, 378770, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.2", "AOG4.", "AOG4.5", "AOG4.5.2"}],
    Cell[10143528, 378775, 128, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.2"}],
    Cell[10143659, 378779, 4428, 75, 197, "Output",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.2"}]},
  "4.5.3"->{
    Cell[10148287, 378865, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.3", "AOG4.", "AOG4.5", "AOG4.5.3"}]},
  "AOG4.5.3"->{
    Cell[10148287, 378865, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.3", "AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10148412, 378870, 128, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10148565, 378876, 32374, 762, 184, 8941, 467, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10180942, 379640, 31278, 725, 184, 8566, 439, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10212269, 380371, 177, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10212471, 380379, 37055, 821, 184, 9279, 472, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10249529, 381202, 34566, 816, 184, 9626, 502, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10284098, 382020, 34157, 774, 184, 8978, 457, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
    Cell[10318258, 382796, 34380, 793, 184, 9314, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}]},
  "4.5.4"->{
    Cell[10352850, 383601, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.4", "AOG4.", "AOG4.5", "AOG4.5.4"}]},
  "AOG4.5.4"->{
    Cell[10352850, 383601, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.5.4", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10352975, 383606, 173, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10353151, 383612, 89292, 3811, 161, 52391, 3350, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10442480, 387428, 174, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10442657, 387434, 118017, 4167, 187, 52312, 3350, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10560711, 391606, 146, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
    Cell[10560860, 391610, 148094, 9129, 255, 95739, 8477, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}]},
  "4.6"->{
    Cell[10709166, 400751, 93, 1, 36, "Subsection",
      CellTags->{"AOG0.", "4.6", "AOG4.", "AOG4.6"}]},
  "4.6.1"->{
    Cell[10709284, 400756, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.1", "AOG4.", "AOG4.6", "AOG4.6.1"}]},
  "AOG4.6.1"->{
    Cell[10709284, 400756, 94, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.1", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10709381, 400759, 277, 9, 113, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10709683, 400772, 131, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10709817, 400776, 36106, 1082, 221, 9515, 748, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10745960, 401863, 202, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
    Cell[10746165, 401870, 6240, 154, 91, "Output",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.1"}]},
  "4.6.2"->{
    Cell[10752595, 402035, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.2", "AOG4.", "AOG4.6", "AOG4.6.2"}]},
  "AOG4.6.2"->{
    Cell[10752595, 402035, 101, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.2", "AOG4.", "AOG4.6", "AOG4.6.2"}],
    Cell[10752721, 402040, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.2"}],
    Cell[10752854, 402044, 7613, 135, 325, "Output",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.2"}]},
  "4.6.3"->{
    Cell[10760657, 402190, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.3", "AOG4.", "AOG4.6", "AOG4.6.3"}]},
  "AOG4.6.3"->{
    Cell[10760657, 402190, 100, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "4.6.3", "AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10760782, 402195, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10760937, 402201, 47820, 1097, 184, 12909, 660, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10808760, 403300, 47419, 1044, 184, 12063, 602, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10856228, 404350, 179, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10856432, 404358, 50096, 1104, 184, 12892, 639, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10906531, 405464, 49448, 1121, 184, 13308, 669, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[10955982, 406587, 50236, 1118, 184, 13097, 654, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
    Cell[11006221, 407707, 47195, 1046, 184, 12495, 612, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}]},
  "4.6.4"->{
    Cell[11053618, 408765, 100, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.6.4", "AOG4.", "AOG4.6", "AOG4.6.4"}]},
  "AOG4.6.4"->{
    Cell[11053618, 408765, 100, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "4.6.4", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11053743, 408770, 175, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11053921, 408776, 109765, 5291, 132, 76369, 4873, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11163723, 414072, 176, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11163902, 414078, 110499, 5298, 132, 76572, 4873, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11274438, 419381, 148, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
    Cell[11274589, 419385, 172454, 12925, 220, 141061, 12532, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}]},
  "5"->{
    Cell[11447257, 432323, 89, 1, 61, "Section",
      CellTags->{"AOG0.", "5", "AOG5.", "AOG5.1"}]},
  "AOG5.1"->{
    Cell[11447257, 432323, 89, 1, 61, "Section",
      CellTags->{"AOG0.", "5", "AOG5.", "AOG5.1"}],
    Cell[11447371, 432328, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.1", "AOG5.", "AOG5.1"}],
    Cell[11447457, 432331, 961, 30, 52, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11448421, 432363, 162, 5, 43, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11448586, 432370, 143, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11448754, 432376, 132, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11448889, 432380, 18000, 700, 108, 9825, 593, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11466926, 433085, 154, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11467083, 433091, 37157, 811, 296, 5217, 411, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11504243, 433904, 911, 21, 39, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11505191, 433930, 164, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11505358, 433936, 3206, 62, 116, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11508601, 434003, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11508756, 434009, 41903, 1030, 184, 7990, 606, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11550662, 435041, 36319, 958, 184, 7975, 602, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11586984, 436001, 37745, 969, 184, 7841, 594, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11624744, 436973, 6543, 132, 215, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11631324, 437110, 89, 2, 28, "Input",
      CellTags->{"AOG5.", "AOG5.1", "AOG0."}],
    Cell[11631416, 437114, 178, 3, 21, "Print",
      CellTags->{"Info3314357094-6023310", "AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11631631, 437122, 113, 2, 28, "Input",
      CellTags->{"AOG5.", "AOG5.1", "AOG0."}],
    Cell[11631747, 437126, 872, 15, 53, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11632656, 437146, 212, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11632871, 437153, 68812, 1277, 184, 7759, 518, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11701686, 438432, 7662, 157, 263, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11709385, 438594, 89, 2, 28, "Input",
      CellTags->{"AOG5.", "AOG5.1", "AOG0."}],
    Cell[11709477, 438598, 185, 3, 21, "Print",
      CellTags->{"Info3314357094-2851735", "AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11709699, 438606, 116, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11709818, 438610, 63980, 2419, 184, 29521, 1988, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11773801, 441031, 8702, 179, 295, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11782540, 441215, 187, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11782752, 441224, 37530, 862, 184, 7018, 480, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11820285, 442088, 36028, 1075, 184, 10669, 756, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
    Cell[11856328, 443166, 5496, 107, 215, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]},
  "5.1"->{
    Cell[11447371, 432328, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.1", "AOG5.", "AOG5.1"}]},
  "Info3314357094-6023310"->{
    Cell[11631416, 437114, 178, 3, 21, "Print",
      CellTags->{"Info3314357094-6023310", "AOG0.", "AOG5.", "AOG5.1"}]},
  "Info3314357094-2851735"->{
    Cell[11709477, 438598, 185, 3, 21, "Print",
      CellTags->{"Info3314357094-2851735", "AOG0.", "AOG5.", "AOG5.1"}]},
  "AOG5.2"->{
    Cell[11862014, 443284, 136, 3, 36, "Subsection",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862153, 443289, 222, 6, 24, "Text",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862378, 443297, 403, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862806, 443312, 164, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862973, 443318, 45971, 2101, 172, 29226, 1887, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11908959, 445422, 396, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909380, 445437, 180, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909563, 445443, 32739, 1619, 83, 23569, 1499, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11942317, 447065, 307, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942649, 447078, 168, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942820, 447084, 23044, 764, 184, 7539, 566, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11965879, 447851, 270, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966174, 447864, 167, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966344, 447870, 23401, 764, 177, 7452, 560, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11989760, 448637, 288, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11990226, 448656, 93, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.2", "AOG5.", "AOG5.2"}],
    Cell[11990344, 448661, 104, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11990451, 448665, 985, 14, 133, "Print",
      CellTags->{"Info3314357110-3725464", "AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11991473, 448684, 112, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11991588, 448688, 691, 11, 53, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11992316, 448704, 108, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11992427, 448708, 3921, 79, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11996363, 448790, 241, 5, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11996629, 448799, 165, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[11996797, 448805, 3727, 72, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12000539, 448880, 131, 3, 24, "Text",
      CellTags->{"AOG5.", "AOG5.2", "AOG0."}],
    Cell[12000695, 448887, 99, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12000797, 448891, 143, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12000977, 448899, 129, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12001109, 448903, 3977, 80, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12005123, 448988, 98, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12005224, 448992, 128, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12005389, 449000, 154, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12005546, 449006, 4021, 81, 149, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12009604, 449092, 98, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12009705, 449096, 129, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12009871, 449104, 154, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12010028, 449110, 4021, 81, 149, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12014086, 449196, 98, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12014187, 449200, 129, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12014353, 449208, 155, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12014511, 449214, 4024, 81, 149, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12018572, 449300, 98, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
    Cell[12018673, 449304, 129, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]},
  "AOG5.3"->{
    Cell[11862014, 443284, 136, 3, 36, "Subsection",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862153, 443289, 222, 6, 24, "Text",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862378, 443297, 403, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862806, 443312, 164, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862973, 443318, 45971, 2101, 172, 29226, 1887, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11908959, 445422, 396, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909380, 445437, 180, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909563, 445443, 32739, 1619, 83, 23569, 1499, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11942317, 447065, 307, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942649, 447078, 168, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942820, 447084, 23044, 764, 184, 7539, 566, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11965879, 447851, 270, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966174, 447864, 167, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966344, 447870, 23401, 764, 177, 7452, 560, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11989760, 448637, 288, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[12018992, 449318, 88, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.3", "AOG5.", "AOG5.3"}],
    Cell[12019105, 449323, 99, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12019207, 449327, 2249, 30, 261, "Print",
      CellTags->{"Info3314357173-7371059", "AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12021493, 449362, 107, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12021603, 449366, 1067, 18, 69, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12022707, 449389, 114, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12022846, 449395, 41903, 1030, 184, 7990, 606, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12064752, 450427, 36319, 958, 184, 7975, 602, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12101074, 451387, 37745, 969, 184, 7841, 594, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12138834, 452359, 6543, 132, 215, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12145414, 452496, 105, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12145544, 452502, 38714, 1025, 184, 8462, 646, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12184261, 453529, 37187, 888, 184, 6313, 501, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12221463, 454420, 10050, 189, 475, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12231550, 454614, 119, 2, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[12231694, 454620, 199641, 3801, 240, 79047, 2307, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12431338, 458423, 180895, 3558, 240, 78840, 2292, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12612248, 461984, 10065, 189, 475, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12622350, 462178, 122, 2, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[12622497, 462184, 194995, 3736, 240, 78945, 2298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12817495, 465922, 170763, 3446, 240, 79231, 2310, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[12988273, 469371, 11888, 224, 678, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13000198, 469600, 161, 4, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[13000384, 469608, 38848, 1032, 184, 8584, 653, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13039235, 470642, 38537, 983, 184, 7582, 595, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13077787, 471628, 10027, 187, 474, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13087851, 471820, 120, 2, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[13087996, 471826, 43416, 1045, 184, 8076, 603, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13131415, 472873, 36477, 971, 184, 7821, 612, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13167895, 473846, 41994, 1017, 184, 7928, 591, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13209904, 474866, 5816, 121, 197, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13215757, 474992, 159, 4, 28, "Input",
      CellTags->{"AOG5.3", "AOG5.", "AOG0."}],
    Cell[13215941, 475000, 40932, 1136, 184, 11670, 769, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13256876, 476138, 42076, 1333, 184, 13471, 974, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13298955, 477473, 42145, 1225, 184, 12736, 856, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13341103, 478700, 50893, 2299, 184, 31991, 2060, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
    Cell[13392011, 481002, 7934, 162, 277, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]},
  "AOG5.4"->{
    Cell[11862014, 443284, 136, 3, 36, "Subsection",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862153, 443289, 222, 6, 24, "Text",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862378, 443297, 403, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862806, 443312, 164, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862973, 443318, 45971, 2101, 172, 29226, 1887, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11908959, 445422, 396, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909380, 445437, 180, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909563, 445443, 32739, 1619, 83, 23569, 1499, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11942317, 447065, 307, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942649, 447078, 168, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942820, 447084, 23044, 764, 184, 7539, 566, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11965879, 447851, 270, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966174, 447864, 167, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966344, 447870, 23401, 764, 177, 7452, 560, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11989760, 448637, 288, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[13400135, 481175, 117, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.4", "AOG5.", "AOG5.4"}],
    Cell[13400277, 481180, 95, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13400375, 481184, 668, 9, 101, "Print",
      CellTags->{"Info3313756493-3229688", "AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13401080, 481198, 102, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13401185, 481202, 612, 9, 69, "Print",
      CellTags->{"Info3313756493-6366474", "AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13401812, 481214, 284, 9, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13402121, 481227, 200, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13402324, 481234, 3505, 59, 179, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13405844, 481296, 191, 6, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13406060, 481306, 217, 6, 45, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13406280, 481314, 3055, 52, 174, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13409350, 481369, 307, 9, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13409682, 481382, 118, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13409803, 481386, 105, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13409923, 481392, 358, 11, 25, "Text",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13410306, 481407, 233, 6, 45, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13410564, 481417, 192800, 3706, 240, 78969, 2295, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13603367, 485125, 180434, 3545, 240, 78628, 2283, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13783816, 488673, 5175, 89, 316, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13789028, 488767, 232, 6, 45, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13789285, 488777, 195534, 3747, 240, 79084, 2304, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[13984822, 492526, 187013, 3629, 240, 78678, 2286, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
    Cell[14171850, 496158, 3295, 56, 177, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]},
  "AOG5.5"->{
    Cell[11862014, 443284, 136, 3, 36, "Subsection",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862153, 443289, 222, 6, 24, "Text",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862378, 443297, 403, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862806, 443312, 164, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862973, 443318, 45971, 2101, 172, 29226, 1887, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11908959, 445422, 396, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909380, 445437, 180, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909563, 445443, 32739, 1619, 83, 23569, 1499, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11942317, 447065, 307, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942649, 447078, 168, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942820, 447084, 23044, 764, 184, 7539, 566, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11965879, 447851, 270, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966174, 447864, 167, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966344, 447870, 23401, 764, 177, 7452, 560, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11989760, 448637, 288, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[14175335, 496225, 94, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.5", "AOG5.", "AOG5.5"}],
    Cell[14175454, 496230, 104, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14175561, 496234, 2241, 30, 245, "Print",
      CellTags->{"Info3313756675-1546738", "AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14177839, 496269, 112, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14177954, 496273, 871, 15, 53, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14178862, 496293, 115, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14178980, 496297, 37114, 994, 184, 10001, 654, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14216097, 497293, 11361, 216, 490, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14227495, 497514, 103, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14227601, 497518, 1375, 24, 85, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14229013, 497547, 99, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14229115, 497551, 1550, 26, 85, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14230702, 497582, 187, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[14230892, 497589, 4547063, 118157, 417, 4426191, 116659, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[18777958, 615748, 11435, 217, 506, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[18789430, 615970, 237, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[18789692, 615979, 828845, 19100, 240, 744099, 18048, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[19618540, 635081, 886309, 21393, 240, 773223, 19991, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[20504864, 656477, 138, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[20505005, 656482, 150, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[20505158, 656487, 288, 6, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[20505449, 656495, 1470311, 37080, 240, 1380128, 35961, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[21975763, 693577, 13461, 255, 710, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[21989261, 693837, 163, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[21989449, 693845, 40142, 1116, 184, 9891, 737, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22029594, 694963, 38933, 1009, 184, 8007, 622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22068530, 695974, 39339, 1134, 184, 12199, 793, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22107884, 697111, 11634, 221, 522, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22119555, 697337, 133, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22119713, 697343, 43307, 1132, 184, 10122, 717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22163023, 698477, 39137, 1142, 184, 10505, 783, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22202163, 699621, 42030, 1106, 184, 9997, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22244196, 700729, 65079, 2608, 184, 34509, 2225, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
    Cell[22309290, 703340, 7931, 162, 277, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]},
  "AOG5.6"->{
    Cell[11862014, 443284, 136, 3, 36, "Subsection",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862153, 443289, 222, 6, 24, "Text",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862378, 443297, 403, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862806, 443312, 164, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862973, 443318, 45971, 2101, 172, 29226, 1887, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11908959, 445422, 396, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909380, 445437, 180, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909563, 445443, 32739, 1619, 83, 23569, 1499, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11942317, 447065, 307, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942649, 447078, 168, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942820, 447084, 23044, 764, 184, 7539, 566, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11965879, 447851, 270, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966174, 447864, 167, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966344, 447870, 23401, 764, 177, 7452, 560, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11989760, 448637, 288, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[22317411, 703513, 98, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.6", "AOG5.", "AOG5.6"}],
    Cell[22317534, 703518, 108, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22317645, 703522, 2525, 34, 277, "Print",
      CellTags->{"Info3313758703-7146727", "AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22320207, 703561, 88, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22320298, 703565, 185, 3, 21, "Print",
      CellTags->{"Info3313758707-6863980", "AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22320520, 703573, 133, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22320678, 703579, 43307, 1132, 184, 10122, 717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22363988, 704713, 39137, 1142, 184, 10505, 783, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22403128, 705857, 42030, 1106, 184, 9997, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22445161, 706965, 97868, 4625, 184, 66119, 4227, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22543032, 711592, 95030, 4859, 184, 69887, 4543, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22638077, 716454, 9111, 193, 309, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22647225, 716652, 163, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22647413, 716660, 40550, 1088, 184, 9985, 705, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22687966, 717750, 39253, 1147, 184, 10579, 787, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22727222, 718899, 38293, 1026, 184, 9620, 666, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22765518, 719927, 98791, 3569, 184, 45317, 2903, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22864312, 723498, 94923, 4858, 184, 69885, 4543, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22959250, 728359, 9124, 194, 309, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22968411, 728558, 213, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[22968649, 728567, 74776, 2964, 184, 45615, 2598, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23043428, 731533, 39544, 1159, 184, 10769, 798, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23082975, 732694, 72503, 2901, 184, 45236, 2559, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23155481, 735597, 105314, 2770, 184, 28117, 1811, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23260798, 738369, 138149, 3208, 184, 28610, 1850, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23398950, 741579, 60746, 2744, 184, 37105, 2446, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23459711, 744326, 10007, 211, 325, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23469755, 744542, 196, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23469976, 744551, 40142, 1116, 184, 9891, 737, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23510121, 745669, 38933, 1009, 184, 8007, 622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23549057, 746680, 52601, 1863, 184, 23105, 1493, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23601661, 748545, 47236, 1741, 184, 20670, 1407, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23648912, 750289, 14210, 264, 571, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23663159, 750558, 180, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[23663364, 750567, 452698, 10085, 240, 310409, 8323, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[24116065, 760654, 429598, 9805, 240, 310502, 8329, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[24545666, 770461, 421611, 9666, 240, 310153, 8284, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[24967280, 780129, 423249, 9686, 240, 310876, 8293, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[25390532, 789817, 418502, 9653, 240, 309986, 8308, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[25809037, 799472, 429067, 9781, 240, 311218, 8320, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26238119, 809256, 13847, 271, 570, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26252003, 809532, 171, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26252199, 809541, 34175, 909, 184, 7350, 572, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26286377, 810452, 35960, 954, 184, 7691, 599, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26322352, 811409, 138, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26322493, 811414, 150, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26322646, 811419, 288, 6, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26322959, 811429, 74489, 3882, 184, 57210, 3663, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26397451, 815313, 63439, 2769, 184, 36903, 2436, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26460905, 818085, 15009, 290, 726, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26475951, 818380, 60, 1, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26476014, 818383, 20915, 596, 184, 6122, 408, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26496932, 818981, 139, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26497074, 818986, 151, 3, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26497228, 818991, 287, 6, 21, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26497540, 819001, 57081, 1864, 184, 21898, 1424, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26554624, 820867, 43191, 1362, 184, 14532, 1003, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26597830, 822232, 12156, 233, 646, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26610001, 822468, 160, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26610186, 822476, 173, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26610384, 822485, 39944, 1102, 184, 9680, 723, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26650331, 823589, 39703, 1010, 184, 7652, 609, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26690037, 824601, 81421, 3296, 184, 44018, 2829, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26771461, 827899, 53111, 2128, 184, 26687, 1796, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26824587, 830030, 15864, 295, 711, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26840488, 830330, 237, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[26840750, 830339, 798817, 17930, 240, 727412, 17043, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[27639570, 848271, 908874, 21607, 240, 776089, 19962, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[28548447, 869880, 884664, 20481, 240, 747392, 18781, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[29433114, 890363, 660892, 11348, 240, 626118, 10913, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[30094009, 901713, 892457, 21405, 240, 771316, 19904, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
    Cell[30986469, 923120, 899107, 21450, 240, 775815, 19922, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]},
  "AOG5.7"->{
    Cell[11862014, 443284, 136, 3, 36, "Subsection",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862153, 443289, 222, 6, 24, "Text",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862378, 443297, 403, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862806, 443312, 164, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11862973, 443318, 45971, 2101, 172, 29226, 1887, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11908959, 445422, 396, 11, 113, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909380, 445437, 180, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11909563, 445443, 32739, 1619, 83, 23569, 1499, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11942317, 447065, 307, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942649, 447078, 168, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11942820, 447084, 23044, 764, 184, 7539, 566, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11965879, 447851, 270, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966174, 447864, 167, 4, 28, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[11966344, 447870, 23401, 764, 177, 7452, 560, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
        "AOG5.5"}],
    Cell[11989760, 448637, 288, 9, 79, "Input",
      CellTags->{
      "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
        "AOG5.7"}],
    Cell[31885778, 944582, 103, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.7", "AOG5.", "AOG5.7"}],
    Cell[31885906, 944587, 113, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31886022, 944591, 2818, 39, 293, "Print",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31888877, 944635, 121, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31889001, 944639, 597, 11, 37, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31889635, 944655, 135, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31889773, 944659, 32192, 876, 184, 8533, 578, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31921968, 945537, 5295, 105, 197, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31927300, 945647, 158, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[31927461, 945653, 436020, 9680, 240, 321363, 8259, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32363484, 955335, 3211, 65, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32366732, 955405, 158, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32366893, 955411, 436020, 9680, 240, 321363, 8259, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32802916, 965093, 3211, 65, 133, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32806164, 965163, 188, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[32806355, 965170, 435803, 9723, 240, 322053, 8313, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33242161, 974895, 3169, 66, 117, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33245367, 974966, 202, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33245594, 974975, 33233, 941, 184, 9531, 643, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33278830, 975918, 40894, 1541, 184, 18503, 1259, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33319739, 977462, 6703, 134, 234, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33326479, 977601, 115, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33326597, 977605, 24999, 556, 184, 4249, 294, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33351599, 978163, 5202, 103, 174, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33356838, 978271, 137, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33356978, 978275, 48849, 1770, 184, 22034, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
    Cell[33405830, 980047, 5242, 104, 174, "Output",
      CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]},
  "5.2"->{
    Cell[11990226, 448656, 93, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.2", "AOG5.", "AOG5.2"}]},
  "Info3314357110-3725464"->{
    Cell[11990451, 448665, 985, 14, 133, "Print",
      CellTags->{"Info3314357110-3725464", "AOG0.", "AOG5.", "AOG5.2"}]},
  "5.3"->{
    Cell[12018992, 449318, 88, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.3", "AOG5.", "AOG5.3"}]},
  "Info3314357173-7371059"->{
    Cell[12019207, 449327, 2249, 30, 261, "Print",
      CellTags->{"Info3314357173-7371059", "AOG0.", "AOG5.", "AOG5.3"}]},
  "5.4"->{
    Cell[13400135, 481175, 117, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.4", "AOG5.", "AOG5.4"}]},
  "Info3313756493-3229688"->{
    Cell[13400375, 481184, 668, 9, 101, "Print",
      CellTags->{"Info3313756493-3229688", "AOG0.", "AOG5.", "AOG5.4"}]},
  "Info3313756493-6366474"->{
    Cell[13401185, 481202, 612, 9, 69, "Print",
      CellTags->{"Info3313756493-6366474", "AOG0.", "AOG5.", "AOG5.4"}]},
  "5.5"->{
    Cell[14175335, 496225, 94, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.5", "AOG5.", "AOG5.5"}]},
  "Info3313756675-1546738"->{
    Cell[14175561, 496234, 2241, 30, 245, "Print",
      CellTags->{"Info3313756675-1546738", "AOG0.", "AOG5.", "AOG5.5"}]},
  "5.6"->{
    Cell[22317411, 703513, 98, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.6", "AOG5.", "AOG5.6"}]},
  "Info3313758703-7146727"->{
    Cell[22317645, 703522, 2525, 34, 277, "Print",
      CellTags->{"Info3313758703-7146727", "AOG0.", "AOG5.", "AOG5.6"}]},
  "Info3313758707-6863980"->{
    Cell[22320298, 703565, 185, 3, 21, "Print",
      CellTags->{"Info3313758707-6863980", "AOG0.", "AOG5.", "AOG5.6"}]},
  "5.7"->{
    Cell[31885778, 944582, 103, 1, 36, "Subsection",
      CellTags->{"AOG0.", "5.7", "AOG5.", "AOG5.7"}]},
  "6"->{
    Cell[33411274, 980163, 108, 1, 61, "Section",
      CellTags->{"AOG0.", "6", "AOG6.", "AOG6.1"}]},
  "AOG6.1"->{
    Cell[33411274, 980163, 108, 1, 61, "Section",
      CellTags->{"AOG0.", "6", "AOG6.", "AOG6.1"}],
    Cell[33411407, 980168, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.1", "AOG6.", "AOG6.1"}],
    Cell[33411493, 980171, 468, 12, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33411986, 980187, 99, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33412088, 980191, 1298, 18, 140, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33413423, 980214, 107, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33413533, 980218, 427, 8, 39, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33413997, 980231, 101, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33414101, 980235, 1386, 20, 155, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33415524, 980260, 109, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
    Cell[33415636, 980264, 452, 9, 39, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.1"}]},
  "6.1"->{
    Cell[33411407, 980168, 83, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.1", "AOG6.", "AOG6.1"}]},
  "6.2"->{
    Cell[33416278, 980284, 113, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.2", "AOG6.", "AOG6.2", "AOG6.2.1"}]},
  "AOG6.2.1"->{
    Cell[33416278, 980284, 113, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.2", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416416, 980289, 97, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.2.1", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416516, 980292, 268, 7, 75, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416809, 980303, 130, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33416942, 980307, 26152, 499, 294, 3133, 209, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33443131, 980811, 127, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33443283, 980817, 31937, 760, 184, 5582, 428, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33475223, 981579, 31390, 839, 184, 6685, 528, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33506616, 982420, 34255, 890, 184, 6802, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33540874, 983312, 31849, 759, 184, 5579, 428, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33572726, 984073, 29320, 762, 184, 6043, 468, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33602049, 984837, 34167, 889, 184, 6799, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33636231, 985729, 4495, 102, 103, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33640763, 985836, 148, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33640936, 985842, 34077, 742, 184, 4736, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33675016, 986586, 33676, 820, 184, 5754, 469, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33708695, 987408, 34749, 841, 184, 5853, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33743447, 988251, 34082, 742, 184, 4741, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33777532, 988995, 31696, 744, 184, 5101, 409, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33809231, 989741, 34766, 841, 184, 5858, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33844012, 990585, 4615, 104, 103, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33848664, 990694, 148, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33848837, 990700, 34077, 742, 196, 4736, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33882917, 991444, 33676, 820, 184, 5754, 469, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33916596, 992266, 34749, 841, 184, 5853, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33951348, 993109, 34082, 742, 184, 4741, 373, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[33985433, 993853, 31696, 744, 184, 5101, 409, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34017132, 994599, 34766, 841, 184, 5858, 478, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34051913, 995443, 4615, 104, 115, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34056565, 995552, 149, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34056717, 995556, 147529, 3003, 184, 20809, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34204283, 998564, 143, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34204451, 998570, 34368, 765, 184, 5216, 400, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34238822, 999337, 34363, 765, 184, 5211, 400, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
    Cell[34273188, 1000104, 147529, 3003, 184, 20809, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]},
  "6.2.1"->{
    Cell[33416416, 980289, 97, 1, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.2.1", "AOG6.", "AOG6.2", "AOG6.2.1"}]},
  "6.2.2"->{
    Cell[34420929, 1003119, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.2", "AOG6.", "AOG6.2", "AOG6.2.2"}]},
  "AOG6.2.2"->{
    Cell[34420929, 1003119, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.2", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34421029, 1003122, 263, 7, 79, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34421317, 1003133, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34421450, 1003137, 16000, 372, 294, 3244, 209, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34437487, 1003514, 127, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34437639, 1003520, 38504, 1002, 184, 7743, 617, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34476146, 1004524, 33813, 909, 196, 7329, 577, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34509962, 1005435, 34759, 910, 196, 7134, 563, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34544724, 1006347, 31351, 776, 196, 5814, 455, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34576078, 1007125, 70322, 1881, 196, 17739, 1226, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34646403, 1009008, 31765, 880, 196, 7001, 569, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34678183, 1009891, 4497, 102, 113, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34682717, 1009998, 145, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
    Cell[34682865, 1010002, 137262, 2773, 196, 19098, 1309, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}]},
  "6.2.3"->{
    Cell[34820327, 1012786, 97, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.2.3", "AOG6.", "AOG6.2", "AOG6.2.3"}]},
  "AOG6.2.3"->{
    Cell[34820327, 1012786, 97, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.2.3", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820427, 1012789, 205, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820657, 1012798, 160, 4, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820820, 1012804, 117, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34820952, 1012810, 570, 11, 54, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34821525, 1012823, 612, 14, 102, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34822140, 1012839, 216, 5, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34822359, 1012846, 387, 9, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34822749, 1012857, 317, 7, 86, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823069, 1012866, 346, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823418, 1012876, 271, 7, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823692, 1012885, 176, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34823871, 1012892, 412, 12, 176, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34824308, 1012908, 252, 6, 38, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[34824563, 1012916, 255229, 17819, 108, 243002, 17662, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35079829, 1030740, 125, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35079979, 1030746, 34663, 850, 196, 6370, 494, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35114645, 1031598, 36075, 1004, 184, 8345, 655, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35150723, 1032604, 37944, 973, 184, 7459, 590, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35188716, 1033583, 125, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35188866, 1033589, 33930, 886, 196, 6830, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35222799, 1034477, 38325, 998, 184, 7903, 616, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35261127, 1035477, 34238, 847, 184, 6386, 497, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35295414, 1036330, 132, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35295549, 1036334, 112461, 5760, 196, 82833, 5389, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35408047, 1042099, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
    Cell[35408202, 1042103, 134181, 2677, 184, 18234, 1240, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]},
  "6.2.4"->{
    Cell[35542583, 1044791, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.4", "AOG6.", "AOG6.2", "AOG6.2.4"}]},
  "AOG6.2.4"->{
    Cell[35542583, 1044791, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.4", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35542683, 1044794, 184, 5, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35542892, 1044803, 159, 4, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35543054, 1044809, 116, 3, 21, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35543185, 1044815, 569, 11, 42, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35543757, 1044828, 611, 14, 90, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35544371, 1044844, 216, 5, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35544590, 1044851, 387, 9, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35544980, 1044862, 317, 7, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35545300, 1044871, 271, 7, 62, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35545574, 1044880, 453, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35546030, 1044896, 453, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35546508, 1044914, 224, 5, 26, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35546735, 1044921, 242133, 16878, 96, 229517, 16717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35788905, 1061804, 123, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35789053, 1061810, 36664, 981, 184, 7713, 617, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35825720, 1062793, 34235, 867, 184, 6836, 522, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35859958, 1063662, 36640, 928, 184, 7075, 557, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35896601, 1064592, 35085, 928, 184, 7256, 578, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35931689, 1065522, 34610, 867, 184, 6827, 518, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[35966302, 1066391, 35177, 916, 184, 7115, 563, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36001494, 1067310, 4483, 102, 103, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36006014, 1067417, 146, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36006185, 1067423, 30191, 708, 184, 5167, 394, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36036379, 1068133, 28987, 725, 184, 5510, 430, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
    Cell[36065369, 1068860, 125533, 2582, 184, 17966, 1249, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}]},
  "6.2.5"->{
    Cell[36191114, 1071454, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.5", "AOG6.", "AOG6.2", "AOG6.2.5"}]},
  "AOG6.2.5"->{
    Cell[36191114, 1071454, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.2.5", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36191236, 1071459, 110, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36191349, 1071463, 2033, 28, 245, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36193397, 1071494, 496, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36193918, 1071512, 137, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36194058, 1071516, 90561, 4663, 155, 64954, 4341, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36284656, 1076184, 132, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36284791, 1076188, 430, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36285246, 1076201, 38263, 993, 184, 7907, 613, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36323512, 1077196, 37836, 1006, 184, 7715, 629, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36361351, 1078204, 33767, 897, 184, 7337, 565, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36395133, 1079104, 430, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36395588, 1079117, 40299, 975, 184, 7456, 564, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36435890, 1080094, 37729, 995, 184, 7575, 617, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36473622, 1081091, 39196, 1049, 184, 8464, 664, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36512833, 1082143, 5351, 116, 133, "Output",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36518221, 1082264, 126, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36518350, 1082268, 82209, 1966, 184, 16581, 1150, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36600596, 1084239, 121, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36600720, 1084243, 430, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36601153, 1084254, 34482, 947, 184, 8125, 616, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36635638, 1085203, 430, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36636093, 1085216, 40415, 1127, 184, 9682, 742, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36676511, 1086345, 82338, 1965, 184, 16582, 1148, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
    Cell[36758864, 1088313, 805, 18, 37, "Output",
      CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]},
  "6.3"->{
    Cell[36759881, 1088343, 113, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.3", "AOG6.", "AOG6.3", "AOG6.3.1"}]},
  "AOG6.3.1"->{
    Cell[36759881, 1088343, 113, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.3", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760019, 1088348, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.1", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760119, 1088351, 271, 7, 79, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760415, 1088362, 130, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36760548, 1088366, 18194, 504, 294, 5438, 341, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[36778779, 1088875, 168, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[36778950, 1088881, 438, 9, 21, "Print",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[36779413, 1088894, 143855, 3133, 240, 79529, 2333, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[36923271, 1092029, 162174, 3372, 239, 79437, 2345, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37085448, 1095403, 154268, 3257, 240, 79379, 2327, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37239731, 1098663, 438, 9, 21, "Print",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37240194, 1098676, 173933, 3512, 240, 79826, 2345, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37414130, 1102190, 162174, 3372, 239, 79437, 2345, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37576307, 1105564, 183408, 3625, 240, 79670, 2339, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37759730, 1109192, 9907, 192, 548, "Output",
      CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
    Cell[37769674, 1109389, 182, 5, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
    Cell[37769859, 1109396, 2911809, 38632, 556, 1527231, 21533, 
    "GraphicsData", "PostScript", "Graphics",
      CellTags->{"AOG6.3.1", "AOG6.3", "AOG6.", "AOG0."}],
    Cell[40681671, 1148030, 999, 21, 39, "Output",
      CellTags->{"AOG6.3.1", "AOG6.3", "AOG6.", "AOG0."}]},
  "6.3.1"->{
    Cell[36760019, 1088348, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.1", "AOG6.", "AOG6.3", "AOG6.3.1"}]},
  "6.3.2"->{
    Cell[40682870, 1148062, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.2", "AOG6.", "AOG6.3", "AOG6.3.2"}]},
  "AOG6.3.2"->{
    Cell[40682870, 1148062, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.2", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40682970, 1148065, 205, 5, 45, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40683178, 1148072, 253, 9, 113, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40683456, 1148085, 154, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40683613, 1148089, 39323, 1977, 170, 27027, 1820, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40722951, 1150069, 374, 11, 147, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40723350, 1150084, 154, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40723507, 1150088, 46321, 2316, 164, 32510, 2140, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40769865, 1152409, 241, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[40770109, 1152415, 438, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40770572, 1152428, 173771, 3473, 70, 78845, 2295, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[40944346, 1155903, 196112, 3769, 70, 79217, 2319, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41140461, 1159674, 187658, 3642, 70, 78851, 2292, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41328134, 1163319, 5191, 100, 70, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41333362, 1163424, 137, 2, 24, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[41333502, 1163428, 438, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41333965, 1163441, 173760, 3468, 240, 78767, 2289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41507728, 1166911, 196382, 3766, 70, 79221, 2313, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41704113, 1170679, 187901, 3638, 70, 78920, 2286, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41892029, 1174320, 8304, 149, 524, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[41900370, 1174474, 167, 4, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
    Cell[41900540, 1174480, 468481, 6384, 446, 105436, 1896, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
    Cell[42369024, 1180866, 1174, 25, 37, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]},
  "6.3.3"->{
    Cell[42370398, 1180902, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.3", "AOG6.", "AOG6.3", "AOG6.3.3"}]},
  "AOG6.3.3"->{
    Cell[42370398, 1180902, 97, 1, 34, "Subsubsection",
      CellTags->{"AOG0.", "6.3.3", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42370498, 1180905, 509, 14, 198, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42371032, 1180923, 118, 2, 28, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42371153, 1180927, 121445, 4136, 313, 62819, 3407, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42492635, 1185068, 135, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[42492773, 1185072, 438, 9, 21, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42493214, 1185083, 274996, 12364, 294, 172862, 11097, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42768213, 1197449, 438, 9, 20, "Print",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[42768676, 1197462, 366904, 16950, 294, 240110, 15379, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[43135583, 1214414, 347371, 4783, 294, 103986, 1773, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[43482969, 1219200, 994, 21, 39, "Output",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
    Cell[43484000, 1219226, 221, 5, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
    Cell[43484224, 1219233, 896803, 21536, 240, 771968, 19989, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}]},
  "6.4"->{
    Cell[44381239, 1240781, 143, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.4", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2"}],
    Cell[44381407, 1240786, 142, 2, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "6.4.1", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
    Cell[44381552, 1240790, 1606, 33, 86, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
    Cell[44383161, 1240825, 155, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44383353, 1240833, 164, 2, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.4.2", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383520, 1240837, 263, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383786, 1240845, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383915, 1240849, 226, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44384144, 1240859, 1133, 28, 379, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44385280, 1240889, 155, 3, 22, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44385472, 1240897, 225, 3, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.4.3", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44385700, 1240902, 669, 16, 40, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386372, 1240920, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386583, 1240926, 316, 10, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386902, 1240938, 2463, 77, 1003, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44389368, 1241017, 155, 3, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44389560, 1241025, 122, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.4", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44389707, 1241030, 206, 6, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44389916, 1241038, 2635, 61, 286, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44392588, 1241104, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44392765, 1241110, 143828, 7167, 306, 99609, 6616, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44536630, 1248282, 139, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44536772, 1248286, 6413, 90, 444, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44543222, 1248381, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44543375, 1248385, 33679, 1164, 196, 13916, 915, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44577091, 1249554, 184, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44577278, 1249560, 322724, 6787, 252, 197914, 5241, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44900017, 1256350, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[44900209, 1256358, 116, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.5", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900328, 1256361, 231, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900584, 1256372, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900761, 1256378, 59743, 2242, 118, 27984, 1844, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960519, 1258623, 140, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960684, 1258629, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960839, 1258633, 22963, 536, 196, 4136, 298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44983839, 1259174, 188, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44984030, 1259181, 293073, 6331, 252, 196329, 5131, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[45277118, 1265515, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[45277310, 1265523, 117, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.6", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277452, 1265528, 250, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277705, 1265537, 162, 3, 33, "Print",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277870, 1265542, 185, 4, 33, "Print",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45278092, 1265551, 175, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45278270, 1265557, 66621, 3547, 118, 52710, 3370, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45344928, 1269109, 182, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345113, 1269115, 142, 3, 33, "Output",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345292, 1269123, 153, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345448, 1269127, 43921, 1277, 196, 13678, 898, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45389406, 1270409, 151, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45389560, 1270413, 38725, 1189, 196, 13204, 868, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45428322, 1271607, 188, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45428513, 1271614, 888988, 21267, 252, 784101, 19967, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[46317516, 1292884, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[46317708, 1292892, 119, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.7", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46317852, 1292897, 249, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318104, 1292906, 170, 3, 33, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318277, 1292911, 193, 4, 33, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318507, 1292920, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318684, 1292926, 85537, 4877, 118, 72275, 4708, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404258, 1297808, 181, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404442, 1297814, 149, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404628, 1297822, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404783, 1297826, 53325, 1414, 196, 13928, 922, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46458145, 1299245, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46458298, 1299249, 45215, 1380, 196, 15333, 1006, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46503550, 1300634, 185, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46503738, 1300640, 881315, 21061, 252, 782915, 19841, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[47385068, 1321704, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}],
    Cell[47385260, 1321712, 132, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.8", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385395, 1321715, 255, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385675, 1321724, 264, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385942, 1321733, 59743, 2242, 118, 27984, 1844, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47445700, 1323978, 395, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446098, 1323987, 232, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446333, 1323996, 297, 7, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446655, 1324007, 203, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446861, 1324014, 150, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447014, 1324019, 126, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447155, 1324025, 247, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447427, 1324034, 178, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447608, 1324040, 31318, 990, 196, 11037, 734, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47478941, 1325033, 392, 9, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479358, 1325046, 140, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479501, 1325050, 139, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479655, 1325056, 304, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479984, 1325066, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47480274, 1325077, 37893, 970, 196, 7731, 592, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47518170, 1326049, 27709, 585, 196, 4189, 289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47545906, 1326638, 187, 5, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546118, 1326647, 132, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546253, 1326651, 316, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546572, 1326659, 321, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546896, 1326667, 313, 5, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547212, 1326674, 271, 5, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547486, 1326681, 307, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547796, 1326689, 139, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547950, 1326695, 182, 4, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47548157, 1326703, 175, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47548335, 1326709, 34399, 938, 196, 9263, 622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47582749, 1327650, 359, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47583133, 1327661, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47583423, 1327672, 35972, 896, 196, 7020, 533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47619398, 1328570, 42756, 1023, 196, 9144, 603, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662181, 1329597, 212, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662418, 1329606, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662595, 1329612, 41734, 1733, 196, 23137, 1498, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704344, 1331348, 206, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704575, 1331357, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704865, 1331368, 36110, 898, 196, 7020, 533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47740978, 1332268, 99232, 3697, 196, 47514, 3053, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840237, 1335969, 216, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840478, 1335978, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840631, 1335982, 16729, 479, 196, 4699, 325, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857375, 1336464, 278, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857678, 1336474, 181, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857862, 1336480, 30128, 961, 196, 10784, 717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47888027, 1337446, 270, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47888322, 1337457, 44308, 1021, 196, 7810, 565, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47932633, 1338480, 30618, 670, 196, 5012, 348, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963278, 1339154, 272, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963575, 1339164, 185, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963763, 1339170, 880964, 21156, 252, 787865, 20001, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48844742, 1360329, 372, 8, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48845139, 1360341, 292, 6, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48845434, 1360349, 226985, 10583, 306, 150039, 9628, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072434, 1370935, 160, 2, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072619, 1370941, 289, 6, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072911, 1370949, 148321, 7487, 306, 107970, 6983, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49221247, 1378439, 155, 3, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]},
  "AOG6.4.1"->{
    Cell[44381239, 1240781, 143, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.4", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2"}],
    Cell[44381407, 1240786, 142, 2, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "6.4.1", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
    Cell[44381552, 1240790, 1606, 33, 86, "Text",
      CellTags->{
      "AOG0.", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}]},
  "AOG6.4.2"->{
    Cell[44381239, 1240781, 143, 1, 36, "Subsection",
      CellTags->{"AOG0.", "6.4", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2"}],
    Cell[44381407, 1240786, 142, 2, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "6.4.1", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
    Cell[44381552, 1240790, 1606, 33, 86, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
    Cell[44383353, 1240833, 164, 2, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.4.2", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383520, 1240837, 263, 6, 24, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383786, 1240845, 126, 2, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44383915, 1240849, 226, 8, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
    Cell[44384144, 1240859, 1133, 28, 379, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}]},
  "6.4.1"->{
    Cell[44381407, 1240786, 142, 2, 32, "Subsubsection",
      CellTags->{
      "AOG0.", "6.4.1", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}]},
  "6.4.2"->{
    Cell[44383353, 1240833, 164, 2, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.4.2", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}]},
  "6.4.3"->{
    Cell[44385472, 1240897, 225, 3, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.4.3", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}]},
  "AOG6.4.3"->{
    Cell[44385472, 1240897, 225, 3, 32, "Subsubsection",
      CellTags->{"AOG0.", "6.4.3", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44385700, 1240902, 669, 16, 40, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386372, 1240920, 208, 4, 27, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386583, 1240926, 316, 10, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
    Cell[44386902, 1240938, 2463, 77, 1003, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}]},
  "6.4.4"->{
    Cell[44389560, 1241025, 122, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.4", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}]},
  "AOG6.4.4"->{
    Cell[44389560, 1241025, 122, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.4", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44389707, 1241030, 206, 6, 74, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44389916, 1241038, 2635, 61, 286, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44392588, 1241104, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44392765, 1241110, 143828, 7167, 306, 99609, 6616, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44536630, 1248282, 139, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44536772, 1248286, 6413, 90, 444, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44543222, 1248381, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44543375, 1248385, 33679, 1164, 196, 13916, 915, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44577091, 1249554, 184, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
    Cell[44577278, 1249560, 322724, 6787, 252, 197914, 5241, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}]},
  "6.4.5"->{
    Cell[44900209, 1256358, 116, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.5", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}]},
  "AOG6.4.5"->{
    Cell[44900209, 1256358, 116, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.5", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900328, 1256361, 231, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900584, 1256372, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44900761, 1256378, 59743, 2242, 118, 27984, 1844, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960519, 1258623, 140, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960684, 1258629, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44960839, 1258633, 22963, 536, 196, 4136, 298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44983839, 1259174, 188, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
    Cell[44984030, 1259181, 293073, 6331, 252, 196329, 5131, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}]},
  "6.4.6"->{
    Cell[45277310, 1265523, 117, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.6", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]},
  "AOG6.4.6"->{
    Cell[45277310, 1265523, 117, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.6", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277452, 1265528, 250, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277705, 1265537, 162, 3, 33, "Print",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45277870, 1265542, 185, 4, 33, "Print",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45278092, 1265551, 175, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45278270, 1265557, 66621, 3547, 118, 52710, 3370, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45344928, 1269109, 182, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345113, 1269115, 142, 3, 33, "Output",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345292, 1269123, 153, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45345448, 1269127, 43921, 1277, 196, 13678, 898, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45389406, 1270409, 151, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45389560, 1270413, 38725, 1189, 196, 13204, 868, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45428322, 1271607, 188, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
    Cell[45428513, 1271614, 888988, 21267, 252, 784101, 19967, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]},
  "6.4.7"->{
    Cell[46317708, 1292892, 119, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.7", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]},
  "AOG6.4.7"->{
    Cell[46317708, 1292892, 119, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.7", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46317852, 1292897, 249, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318104, 1292906, 170, 3, 33, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318277, 1292911, 193, 4, 33, "Print",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318507, 1292920, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46318684, 1292926, 85537, 4877, 118, 72275, 4708, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404258, 1297808, 181, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404442, 1297814, 149, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404628, 1297822, 152, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46404783, 1297826, 53325, 1414, 196, 13928, 922, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46458145, 1299245, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46458298, 1299249, 45215, 1380, 196, 15333, 1006, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46503550, 1300634, 185, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
    Cell[46503738, 1300640, 881315, 21061, 252, 782915, 19841, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]},
  "6.4.8"->{
    Cell[47385260, 1321712, 132, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.8", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]},
  "AOG6.4.8"->{
    Cell[47385260, 1321712, 132, 1, 46, "Subsubsection",
      CellTags->{"AOG0.", "6.4.8", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385395, 1321715, 255, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385675, 1321724, 264, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47385942, 1321733, 59743, 2242, 118, 27984, 1844, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47445700, 1323978, 395, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446098, 1323987, 232, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446333, 1323996, 297, 7, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446655, 1324007, 203, 5, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47446861, 1324014, 150, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447014, 1324019, 126, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447155, 1324025, 247, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447427, 1324034, 178, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47447608, 1324040, 31318, 990, 196, 11037, 734, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47478941, 1325033, 392, 9, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479358, 1325046, 140, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479501, 1325050, 139, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479655, 1325056, 304, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47479984, 1325066, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47480274, 1325077, 37893, 970, 196, 7731, 592, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47518170, 1326049, 27709, 585, 196, 4189, 289, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47545906, 1326638, 187, 5, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546118, 1326647, 132, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546253, 1326651, 316, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546572, 1326659, 321, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47546896, 1326667, 313, 5, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547212, 1326674, 271, 5, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547486, 1326681, 307, 6, 33, "Message",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547796, 1326689, 139, 3, 33, "Output",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47547950, 1326695, 182, 4, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47548157, 1326703, 175, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47548335, 1326709, 34399, 938, 196, 9263, 622, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47582749, 1327650, 359, 7, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47583133, 1327661, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47583423, 1327672, 35972, 896, 196, 7020, 533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47619398, 1328570, 42756, 1023, 196, 9144, 603, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662181, 1329597, 212, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662418, 1329606, 174, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47662595, 1329612, 41734, 1733, 196, 23137, 1498, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704344, 1331348, 206, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704575, 1331357, 265, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47704865, 1331368, 36110, 898, 196, 7020, 533, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47740978, 1332268, 99232, 3697, 196, 47514, 3053, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840237, 1335969, 216, 5, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840478, 1335978, 150, 2, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47840631, 1335982, 16729, 479, 196, 4699, 325, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857375, 1336464, 278, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857678, 1336474, 181, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47857862, 1336480, 30128, 961, 196, 10784, 717, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47888027, 1337446, 270, 7, 91, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47888322, 1337457, 44308, 1021, 196, 7810, 565, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47932633, 1338480, 30618, 670, 196, 5012, 348, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963278, 1339154, 272, 6, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963575, 1339164, 185, 4, 40, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[47963763, 1339170, 880964, 21156, 252, 787865, 20001, "GraphicsData",
     "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48844742, 1360329, 372, 8, 37, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48845139, 1360341, 292, 6, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[48845434, 1360349, 226985, 10583, 306, 150039, 9628, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072434, 1370935, 160, 2, 36, "Text",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072619, 1370941, 289, 6, 57, "Input",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
    Cell[49072911, 1370949, 148321, 7487, 306, 107970, 6983, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Top", 49222832, 1378485},
  {"AOG0.", 49223131, 1378491},
  {"AOG1.", 49382878, 1381565},
  {"AOG2.", 49384104, 1381592},
  {"AOG3.", 49447186, 1382793},
  {"AOG4.", 49462816, 1383117},
  {"AOG5.", 49484049, 1383530},
  {"AOG6.", 49517945, 1384224},
  {"AOG2.1", 49561755, 1385021},
  {"AOG2.2", 49593087, 1385625},
  {"AOG2.3", 49619867, 1386133},
  {"AOG4.2", 49629303, 1386310},
  {"AOG4.3", 49633707, 1386396},
  {"AOG4.4", 49637079, 1386462},
  {"AOG4.5", 49641681, 1386552},
  {"AOG4.6", 49646207, 1386640},
  {"AOG6.2", 49650158, 1386716},
  {"AOG6.3", 49668247, 1387053},
  {"AOG6.4", 49676328, 1387201},
  {"AOG3.3", 49693556, 1387503},
  {"AOG4.1", 49699447, 1387618},
  {"1", 49701321, 1387658},
  {"2", 49701416, 1387661},
  {"2.1", 49701513, 1387664},
  {"2.1.1", 49701627, 1387667},
  {"AOG2.1.1", 49701762, 1387670},
  {"Info3312042809-6749329", 49702248, 1387680},
  {"2.1.2", 49702396, 1387684},
  {"2.1.3", 49702526, 1387687},
  {"AOG2.1.3", 49702663, 1387690},
  {"2.1.4", 49704883, 1387731},
  {"AOG2.1.4", 49705039, 1387735},
  {"2.1.5", 49706624, 1387764},
  {"AOG2.1.5", 49706761, 1387767},
  {"Info3312042819-8757440", 49708973, 1387810},
  {"2.1.6", 49709123, 1387814},
  {"AOG2.1.6", 49709260, 1387817},
  {"AOG2.1.7", 49728644, 1388192},
  {"2.1.7", 49729836, 1388215},
  {"AOG2.1.8", 49729974, 1388218},
  {"2.1.8", 49731511, 1388248},
  {"Info3312042871-8199869", 49731663, 1388251},
  {"2.2", 49731812, 1388255},
  {"2.2.1", 49731929, 1388258},
  {"AOG2.2.1", 49732067, 1388261},
  {"AOG2.2.2", 49737607, 1388367},
  {"2.2.2", 49743662, 1388481},
  {"2.2.3", 49743798, 1388484},
  {"AOG2.2.3", 49743938, 1388487},
  {"Info3312042947-9251066", 49754667, 1388688},
  {"2.3", 49754819, 1388692},
  {"AOG2.3.1", 49754954, 1388695},
  {"2.3.1", 49756488, 1388724},
  {"2.3.2", 49756625, 1388727},
  {"AOG2.3.2", 49756765, 1388730},
  {"2.3.3", 49757971, 1388753},
  {"AOG2.3.3", 49758111, 1388756},
  {"2.3.4", 49760597, 1388803},
  {"AOG2.3.4", 49760737, 1388806},
  {"3", 49764034, 1388868},
  {"3.1", 49764136, 1388871},
  {"AOG3.1", 49764256, 1388874},
  {"Info3312043331-3736878", 49765657, 1388904},
  {"3.2", 49765780, 1388907},
  {"AOG3.2", 49765900, 1388910},
  {"3.3", 49766706, 1388928},
  {"AOG3.3.1", 49766841, 1388931},
  {"3.3.1", 49768058, 1388955},
  {"AOG3.3.2", 49768188, 1388958},
  {"3.3.2", 49769298, 1388980},
  {"AOG3.3.3", 49769428, 1388983},
  {"3.3.3", 49772190, 1389037},
  {"3.4", 49772315, 1389040},
  {"AOG3.4", 49772435, 1389043},
  {"3.5", 49773840, 1389073},
  {"AOG3.5", 49773961, 1389076},
  {"3.6", 49777974, 1389164},
  {"AOG3.6", 49778094, 1389167},
  {"Info3312115087-1929230", 49779721, 1389201},
  {"4", 49779845, 1389204},
  {"4.1", 49779958, 1389207},
  {"Info3312043438-4643038", 49780094, 1389210},
  {"Info3405686992-9872384", 49780236, 1389213},
  {"Info3312043439-7338271", 49780390, 1389216},
  {"4.2", 49780516, 1389219},
  {"AOG4.2.1", 49780651, 1389222},
  {"4.2.1", 49781683, 1389242},
  {"4.2.2", 49781819, 1389245},
  {"AOG4.2.2", 49781959, 1389248},
  {"4.2.3", 49782303, 1389255},
  {"AOG4.2.3", 49782443, 1389258},
  {"4.2.4", 49783867, 1389286},
  {"AOG4.2.4", 49784007, 1389289},
  {"4.3", 49784662, 1389302},
  {"AOG4.3.1", 49784797, 1389305},
  {"4.3.1", 49785831, 1389325},
  {"4.3.2", 49785967, 1389328},
  {"AOG4.3.2", 49786107, 1389331},
  {"4.3.3", 49786451, 1389338},
  {"AOG4.3.3", 49786591, 1389341},
  {"4.3.4", 49787237, 1389354},
  {"AOG4.3.4", 49787377, 1389357},
  {"4.4", 49787776, 1389365},
  {"AOG4.4.1", 49787911, 1389368},
  {"4.4.1", 49788943, 1389388},
  {"4.4.2", 49789079, 1389391},
  {"AOG4.4.2", 49789219, 1389394},
  {"4.4.3", 49789564, 1389401},
  {"AOG4.4.3", 49789704, 1389404},
  {"4.4.4", 49791061, 1389431},
  {"AOG4.4.4", 49791201, 1389434},
  {"4.5", 49792119, 1389452},
  {"AOG4.5.1", 49792255, 1389455},
  {"4.5.1", 49793293, 1389475},
  {"4.5.2", 49793430, 1389478},
  {"AOG4.5.2", 49793571, 1389481},
  {"4.5.3", 49793918, 1389488},
  {"AOG4.5.3", 49794059, 1389491},
  {"4.5.4", 49795323, 1389516},
  {"AOG4.5.4", 49795464, 1389519},
  {"4.6", 49796388, 1389537},
  {"4.6.1", 49796508, 1389540},
  {"AOG4.6.1", 49796648, 1389543},
  {"4.6.2", 49797362, 1389557},
  {"AOG4.6.2", 49797503, 1389560},
  {"4.6.3", 49797851, 1389567},
  {"AOG4.6.3", 49797992, 1389570},
  {"4.6.4", 49799268, 1389595},
  {"AOG4.6.4", 49799409, 1389598},
  {"5", 49800335, 1389616},
  {"AOG5.1", 49800451, 1389619},
  {"5.1", 49804186, 1389695},
  {"Info3314357094-6023310", 49804323, 1389698},
  {"Info3314357094-2851735", 49804475, 1389701},
  {"AOG5.2", 49804611, 1389704},
  {"AOG5.3", 49810088, 1389827},
  {"AOG5.4", 49817345, 1389984},
  {"AOG5.5", 49822499, 1390099},
  {"AOG5.6", 49829159, 1390244},
  {"AOG5.7", 49841231, 1390496},
  {"5.2", 49846954, 1390623},
  {"Info3314357110-3725464", 49847091, 1390626},
  {"5.3", 49847226, 1390629},
  {"Info3314357173-7371059", 49847363, 1390632},
  {"5.4", 49847499, 1390635},
  {"Info3313756493-3229688", 49847637, 1390638},
  {"Info3313756493-6366474", 49847790, 1390641},
  {"5.5", 49847923, 1390644},
  {"Info3313756675-1546738", 49848060, 1390647},
  {"5.6", 49848196, 1390650},
  {"Info3313758703-7146727", 49848333, 1390653},
  {"Info3313758707-6863980", 49848488, 1390656},
  {"5.7", 49848621, 1390659},
  {"6", 49848738, 1390662},
  {"AOG6.1", 49848855, 1390665},
  {"6.1", 49849937, 1390688},
  {"6.2", 49850055, 1390691},
  {"AOG6.2.1", 49850191, 1390694},
  {"6.2.1", 49855244, 1390788},
  {"6.2.2", 49855381, 1390791},
  {"AOG6.2.2", 49855522, 1390794},
  {"6.2.3", 49857509, 1390831},
  {"AOG6.2.3", 49857650, 1390834},
  {"6.2.4", 49861103, 1390898},
  {"AOG6.2.4", 49861244, 1390901},
  {"6.2.5", 49864643, 1390964},
  {"AOG6.2.5", 49864784, 1390967},
  {"6.3", 49867977, 1391029},
  {"AOG6.3.1", 49868114, 1391032},
  {"6.3.1", 49870572, 1391077},
  {"6.3.2", 49870710, 1391080},
  {"AOG6.3.2", 49870851, 1391083},
  {"6.3.3", 49873896, 1391139},
  {"AOG6.3.3", 49874037, 1391142},
  {"6.4", 49875773, 1391174},
  {"AOG6.4.1", 49892420, 1391465},
  {"AOG6.4.2", 49892855, 1391474},
  {"6.4.1", 49893874, 1391492},
  {"6.4.2", 49894039, 1391496},
  {"6.4.3", 49894185, 1391499},
  {"AOG6.4.3", 49894334, 1391502},
  {"6.4.4", 49894945, 1391513},
  {"AOG6.4.4", 49895094, 1391516},
  {"6.4.5", 49896571, 1391542},
  {"AOG6.4.5", 49896720, 1391545},
  {"6.4.6", 49897956, 1391567},
  {"AOG6.4.6", 49898105, 1391570},
  {"6.4.7", 49899923, 1391603},
  {"AOG6.4.7", 49900072, 1391606},
  {"6.4.8", 49901945, 1391639},
  {"AOG6.4.8", 49902094, 1391642}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 323, 8, 61, "Section",
  CellTags->{
  "Top", "AOG0.", "AOG1.", "AOG2.", "AOG3.", "AOG4.", "AOG5.", "AOG6.", 
    "AOG1.", "AOG2.1", "AOG2.2", "AOG2.3", "AOG4.2", "AOG4.3", "AOG4.4", 
    "AOG4.5", "AOG4.6", "AOG6.2", "AOG6.3", "AOG6.4", "AOG3.3"}],
Cell[2102, 63, 173, 4, 24, "Outline1",
  CellTags->"AOG0."],

Cell[CellGroupData[{
Cell[2300, 71, 223, 4, 24, "Outline1",
  CellTags->{"AOG2.", "AOG0.", "AOG2.1", "AOG2.2", "AOG2.3"}],

Cell[CellGroupData[{
Cell[2548, 79, 193, 4, 21, "Outline2",
  CellTags->{"AOG2.", "AOG2.1", "AOG0."}],
Cell[2744, 85, 987, 35, 116, "Outline3",
  CellTags->{"AOG2.", "AOG2.1", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3768, 125, 206, 4, 21, "Outline2",
  CellTags->{"AOG2.", "AOG2.2", "AOG0."}],
Cell[3977, 131, 450, 14, 46, "Outline3",
  CellTags->{"AOG2.", "AOG2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4464, 150, 213, 4, 21, "Outline2",
  CellTags->{"AOG2.", "AOG2.3", "AOG0."}],
Cell[4680, 156, 518, 18, 60, "Outline3",
  CellTags->{"AOG2.", "AOG2.3", "AOG0."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5247, 180, 206, 4, 24, "Outline1",
  CellTags->{"AOG3.", "AOG0.", "AOG3.3"}],
Cell[5456, 186, 299, 10, 38, "Outline2",
  CellTags->{"AOG3.", "AOG0."}],

Cell[CellGroupData[{
Cell[5780, 200, 209, 4, 21, "Outline2",
  CellTags->{"AOG3.", "AOG0.", "AOG3.3"}],
Cell[5992, 206, 384, 14, 46, "Outline3",
  CellTags->{"AOG0.", "AOG3.3"}]
}, Open  ]],
Cell[6391, 223, 418, 14, 55, "Outline2",
  CellTags->{"AOG3.", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[6846, 242, 266, 6, 24, "Outline1",
  CellTags->{
  "AOG4.", "AOG0.", "AOG4.1", "AOG4.2", "AOG4.3", "AOG4.4", "AOG4.5", 
    "AOG4.6"}],
Cell[7115, 250, 183, 4, 21, "Outline2",
  CellTags->{"AOG4.", "AOG0."}],

Cell[CellGroupData[{
Cell[7323, 258, 207, 4, 21, "Outline2",
  CellTags->{"AOG4.", "AOG0.", "AOG4.2"}],
Cell[7533, 264, 467, 18, 60, "Outline3",
  CellTags->{"AOG4.2", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8037, 287, 212, 4, 21, "Outline2",
  CellTags->{"AOG4.", "AOG0.", "AOG4.3"}],
Cell[8252, 293, 467, 18, 60, "Outline3",
  CellTags->{"AOG4.3", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8756, 316, 206, 4, 21, "Outline2",
  CellTags->{"AOG4.", "AOG0.", "AOG4.4"}],
Cell[8965, 322, 467, 18, 60, "Outline3",
  CellTags->{"AOG4.4", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[9469, 345, 208, 4, 21, "Outline2",
  CellTags->{"AOG4.", "AOG0.", "AOG4.5"}],
Cell[9680, 351, 467, 18, 60, "Outline3",
  CellTags->{"AOG4.5", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10184, 374, 203, 4, 21, "Outline2",
  CellTags->{"AOG4.", "AOG0.", "AOG4.6"}],
Cell[10390, 380, 467, 18, 60, "Outline3",
  CellTags->{"AOG4.6", "AOG4."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10906, 404, 192, 4, 24, "Outline1",
  CellTags->{"AOG5.", "AOG0."}],
Cell[11101, 410, 828, 30, 123, "Outline2",
  CellTags->{"AOG5.", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11966, 445, 241, 4, 24, "Outline1",
  CellTags->{"AOG6.", "AOG0.", "AOG6.2", "AOG6.3", "AOG6.4"}],
Cell[12210, 451, 183, 4, 21, "Outline2",
  CellTags->{"AOG6.", "AOG0."}],

Cell[CellGroupData[{
Cell[12418, 459, 211, 4, 21, "Outline2",
  CellTags->{"AOG6.", "AOG0.", "AOG6.2"}],
Cell[12632, 465, 558, 22, 74, "Outline3",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[13227, 492, 211, 4, 21, "Outline2",
  CellTags->{"AOG6.", "AOG0.", "AOG6.3"}],
Cell[13441, 498, 380, 14, 46, "Outline3",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[13858, 517, 229, 4, 21, "Outline2",
  CellTags->{"AOG6.", "AOG6.4", "AOG0."}],
Cell[14090, 523, 953, 34, 116, "Outline3",
  CellTags->{"AOG6.", "AOG6.4", "AOG0."}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15104, 564, 71, 1, 61, "Section",
  CellTags->{"1", "AOG1.", "AOG0."}],
Cell[15178, 567, 426, 12, 22, "Text",
  CellTags->{"AOG1.", "AOG0."}],
Cell[15607, 581, 142, 4, 22, "Text",
  CellTags->{"AOG1.", "AOG0."}],

Cell[CellGroupData[{
Cell[15774, 589, 71, 1, 32, "Subsubsection",
  CellTags->{"AOG1.", "AOG0."}],
Cell[15848, 592, 150, 5, 22, "Text",
  CellTags->{"AOG1.", "AOG0."}],

Cell[CellGroupData[{
Cell[16023, 601, 98, 2, 27, "Input",
  CellTags->{"AOG1.", "AOG0."}],
Cell[16124, 605, 111, 2, 20, "Print",
  CellTags->{"AOG1.", "AOG0."}],
Cell[16238, 609, 202, 4, 20, "Print",
  CellTags->{"AOG1.", "AOG0."}]
}, Open  ]],
Cell[16455, 616, 127, 3, 22, "Text",
  CellTags->"AOG0."]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16631, 625, 95, 1, 61, "Section",
  CellTags->{"AOG0.", "2", "AOG2."}],

Cell[CellGroupData[{
Cell[16751, 630, 83, 1, 36, "Subsection",
  CellTags->{"AOG0.", "2.1", "AOG2.", "AOG2.1"}],

Cell[CellGroupData[{
Cell[16859, 635, 100, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "2.1.1", "AOG2.", "AOG2.1", "AOG2.1.1"}],
Cell[16962, 638, 1992, 55, 88, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.1"}],

Cell[CellGroupData[{
Cell[18979, 697, 109, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.1"}],
Cell[19091, 701, 485, 8, 65, "Print",
  CellTags->{
  "Info3312042809-6749329", "AOG2.", "AOG2.1", "AOG2.1.1", "AOG0."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19625, 715, 118, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "2.1.2", "AOG2.", "AOG2.1", "AOG2.2"}],
Cell[19746, 718, 664, 15, 38, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{
Cell[20435, 737, 146, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
Cell[20584, 741, 279, 8, 24, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],
Cell[20878, 752, 701, 15, 38, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{
Cell[21604, 771, 243, 7, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
Cell[21850, 780, 367, 10, 24, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],
Cell[22232, 793, 412, 10, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{
Cell[22669, 807, 111, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
Cell[22783, 811, 228, 5, 19, "Message",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
Cell[23014, 818, 118, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],
Cell[23147, 824, 198, 5, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{
Cell[23370, 833, 207, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
Cell[23580, 840, 347, 9, 24, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],
Cell[23942, 852, 595, 15, 38, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{
Cell[24562, 871, 229, 7, 75, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
Cell[24794, 880, 872, 27, 24, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],
Cell[25681, 910, 361, 10, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{
Cell[26067, 924, 183, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
Cell[26253, 931, 10518, 262, 285, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],
Cell[36786, 1196, 204, 5, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{
Cell[37015, 1205, 144, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
Cell[37162, 1209, 24034, 773, 134, 9878, 593, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
Cell[61199, 1984, 495, 11, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
Cell[61697, 1997, 141, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],
Cell[61853, 2003, 253, 5, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{
Cell[62131, 2012, 220, 7, 75, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
Cell[62354, 2021, 908, 27, 24, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[63299, 2053, 164, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
Cell[63466, 2059, 1327, 25, 95, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],
Cell[64808, 2087, 299, 8, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],

Cell[CellGroupData[{
Cell[65132, 2099, 176, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.2"}],
Cell[65311, 2105, 72323, 2564, 152, 32608, 2068, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
Cell[137637, 4671, 588, 13, 35, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}],
Cell[138228, 4686, 143, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG0.", "AOG2.2"}]
}, Open  ]],
Cell[138386, 4692, 158, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[138581, 4700, 111, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "2.1.3", "AOG2.", "AOG2.1", "AOG2.1.3"}],
Cell[138695, 4703, 1624, 33, 86, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
Cell[140322, 4738, 780, 13, 54, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
Cell[141105, 4753, 1236, 21, 70, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.3"}],
Cell[142344, 4776, 160, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[142541, 4784, 131, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "2.1.4", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
Cell[142675, 4787, 641, 13, 40, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],

Cell[CellGroupData[{
Cell[143341, 4804, 329, 9, 107, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
Cell[143673, 4815, 18991, 659, 110, 8702, 527, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
Cell[162667, 5476, 250, 5, 41, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[162954, 5486, 341, 9, 107, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
Cell[163298, 5497, 20462, 730, 110, 9828, 593, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
Cell[183763, 6229, 250, 5, 41, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[184050, 6239, 339, 9, 107, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
Cell[184392, 6250, 20821, 734, 110, 9839, 593, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}],
Cell[205216, 6986, 250, 5, 41, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.4", "AOG0.", "AOG2.1.3"}]
}, Open  ]],
Cell[205481, 6994, 527, 9, 38, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.4", "AOG2.1.3"}],
Cell[206011, 7005, 160, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[206208, 7013, 112, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "2.1.5", "AOG2.", "AOG2.1", "AOG2.1.5"}],
Cell[206323, 7016, 876, 22, 40, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],

Cell[CellGroupData[{
Cell[207224, 7042, 118, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
Cell[207345, 7046, 2749, 52, 129, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}]
}, Open  ]],
Cell[210109, 7101, 915, 21, 56, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],

Cell[CellGroupData[{
Cell[211049, 7126, 108, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
Cell[211160, 7130, 279, 5, 50, "Print",
  CellTags->{
  "Info3312042819-8757440", "AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[211476, 7140, 343, 10, 123, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
Cell[211822, 7152, 20450, 730, 110, 9828, 593, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
Cell[232275, 7884, 1016, 18, 88, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
Cell[233294, 7904, 117, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[233448, 7912, 160, 5, 43, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
Cell[233611, 7919, 346, 6, 19, "Message",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
Cell[233960, 7927, 343, 7, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
Cell[234306, 7936, 1745, 29, 131, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}],
Cell[236054, 7967, 117, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}]
}, Open  ]],
Cell[236186, 7973, 294, 8, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],

Cell[CellGroupData[{
Cell[236505, 7985, 108, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.5"}],
Cell[236616, 7989, 118, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.5", "AOG0."}]
}, Open  ]],
Cell[236749, 7995, 160, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[236946, 8003, 114, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "2.1.6", "AOG2.", "AOG2.1", "AOG2.1.6"}],
Cell[237063, 8006, 580, 11, 40, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[CellGroupData[{
Cell[237668, 8021, 293, 8, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
Cell[237964, 8031, 141, 3, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[238108, 8036, 147, 3, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[238258, 8041, 194, 4, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[238455, 8047, 171, 3, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[238629, 8052, 233, 5, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[238865, 8059, 374, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[239242, 8069, 565, 11, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[239810, 8082, 305, 6, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[240118, 8090, 267, 5, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[240388, 8097, 233, 5, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[240624, 8104, 359, 7, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[240986, 8113, 565, 11, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[241554, 8126, 306, 6, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[241863, 8134, 267, 5, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[242133, 8141, 233, 5, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[242369, 8148, 359, 7, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[242731, 8157, 295, 6, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[243029, 8165, 306, 6, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[243338, 8173, 267, 5, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[243608, 8180, 360, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[243971, 8190, 154, 3, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[244128, 8195, 229, 5, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[244360, 8202, 241, 5, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[244604, 8209, 454, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[245061, 8221, 473, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[245537, 8233, 385, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[245925, 8243, 457, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[246385, 8254, 489, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[246877, 8266, 410, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[247290, 8277, 480, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[247773, 8289, 497, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[248273, 8301, 418, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[248694, 8312, 435, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[249132, 8323, 467, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[249602, 8335, 379, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[249984, 8345, 452, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[250439, 8357, 469, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[250911, 8369, 381, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[251295, 8379, 241, 5, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[251539, 8386, 454, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[251996, 8398, 473, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[252472, 8410, 385, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[252860, 8420, 466, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[253329, 8432, 489, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[253821, 8444, 410, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[254234, 8455, 495, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[254732, 8467, 416, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[255151, 8478, 433, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[255587, 8489, 465, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[256055, 8501, 377, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[256435, 8511, 450, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[256888, 8523, 469, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[257360, 8535, 381, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[257744, 8545, 241, 5, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[257988, 8552, 454, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[258445, 8564, 473, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[258921, 8576, 385, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[259309, 8586, 466, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[259778, 8598, 491, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[260272, 8610, 412, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[260687, 8621, 435, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[261125, 8632, 467, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[261595, 8644, 379, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[261977, 8654, 450, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[262430, 8666, 469, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[262902, 8678, 381, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[263286, 8688, 498, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[263787, 8700, 416, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[264206, 8711, 488, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[264697, 8723, 406, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[265106, 8734, 474, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[265583, 8746, 383, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[265969, 8756, 476, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[266448, 8768, 385, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[266836, 8778, 344, 7, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[267183, 8787, 303, 6, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[267489, 8795, 139, 3, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[267631, 8800, 1172, 20, 88, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[268840, 8825, 108, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
Cell[268951, 8829, 117, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}]
}, Open  ]],
Cell[269083, 8835, 445, 10, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[CellGroupData[{
Cell[269553, 8849, 267, 8, 91, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
Cell[269823, 8859, 1727, 28, 194, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}]
}, Open  ]],
Cell[271565, 8890, 301, 6, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[CellGroupData[{
Cell[271891, 8900, 312, 8, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
Cell[272206, 8910, 141, 3, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[272350, 8915, 483, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[272836, 8927, 404, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[273243, 8938, 509, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[273755, 8950, 432, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[274190, 8961, 491, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[274684, 8973, 412, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[275099, 8984, 495, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[275597, 8996, 418, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[276018, 9007, 495, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[276516, 9019, 418, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[276937, 9030, 469, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[277409, 9042, 383, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[277795, 9052, 465, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[278263, 9064, 379, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[278645, 9074, 473, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[279121, 9086, 385, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[279509, 9096, 469, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[279981, 9108, 383, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[280367, 9118, 521, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[280891, 9130, 442, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[281336, 9141, 483, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[281822, 9153, 404, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[282229, 9164, 509, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[282741, 9176, 430, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[283174, 9187, 491, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[283668, 9199, 412, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[284083, 9210, 495, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[284581, 9222, 416, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[285000, 9233, 495, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[285498, 9245, 416, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[285917, 9256, 469, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[286389, 9268, 381, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[286773, 9278, 467, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[287243, 9290, 379, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[287625, 9300, 473, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[288101, 9312, 383, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[288487, 9322, 471, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[288961, 9334, 383, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[289347, 9344, 521, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[289871, 9356, 442, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[290316, 9367, 483, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[290802, 9379, 404, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[291209, 9390, 509, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[291721, 9402, 430, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[292154, 9413, 491, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[292648, 9425, 412, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[293063, 9436, 495, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[293561, 9448, 416, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[293980, 9459, 495, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[294478, 9471, 416, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[294897, 9482, 467, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[295367, 9494, 379, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[295749, 9504, 467, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[296219, 9516, 379, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[296601, 9526, 473, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[297077, 9538, 383, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[297463, 9548, 471, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[297937, 9560, 383, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[298323, 9570, 521, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[298847, 9582, 442, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[299292, 9593, 471, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[299766, 9605, 383, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[300152, 9615, 489, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[300644, 9627, 410, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[301057, 9638, 465, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[301525, 9650, 377, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[301905, 9660, 469, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[302377, 9672, 381, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[302761, 9682, 471, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[303235, 9694, 383, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[303621, 9704, 491, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[304115, 9716, 412, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[304530, 9727, 467, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[305000, 9739, 379, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[305382, 9749, 469, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[305854, 9761, 381, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[306238, 9771, 471, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[306712, 9783, 383, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[307098, 9793, 491, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[307592, 9805, 412, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[308007, 9816, 467, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[308477, 9828, 379, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[308859, 9838, 469, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[309331, 9850, 381, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[309715, 9860, 498, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[310216, 9872, 416, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[310635, 9883, 488, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[311126, 9895, 404, 9, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[311533, 9906, 474, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[312010, 9918, 383, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[312396, 9928, 476, 10, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[312875, 9940, 385, 8, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[313263, 9950, 139, 3, 20, "Print",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}],
Cell[313405, 9955, 1101, 20, 113, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}]
}, Open  ]],
Cell[314521, 9978, 283, 6, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],

Cell[CellGroupData[{
Cell[314829, 9988, 177, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.6"}],
Cell[315009, 9994, 1686, 29, 111, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.6", "AOG0."}]
}, Open  ]],
Cell[316710, 10026, 160, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[316907, 10034, 108, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7", "2.1.7"}],
Cell[317018, 10037, 526, 9, 38, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],

Cell[CellGroupData[{
Cell[317569, 10050, 337, 10, 123, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
Cell[317909, 10062, 22699, 836, 110, 11522, 692, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
Cell[340611, 10900, 2909, 48, 205, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}]
}, Open  ]],
Cell[343535, 10951, 253, 5, 22, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],

Cell[CellGroupData[{
Cell[343813, 10960, 389, 12, 155, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.7"}],
Cell[344205, 10974, 40769, 1619, 159, 22270, 1385, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}],
Cell[384977, 12595, 3259, 51, 206, "Output",
  CellTags->{"AOG2.", "AOG2.1", "AOG2.1.7", "AOG0."}]
}, Open  ]],
Cell[388251, 12649, 160, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[388448, 12657, 119, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8", "2.1.8"}],
Cell[388570, 12660, 366, 7, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],

Cell[CellGroupData[{
Cell[388961, 12671, 360, 10, 107, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
Cell[389324, 12683, 43019, 1385, 257, 15999, 1046, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
Cell[432346, 14070, 1492, 27, 145, "Output",
  CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}]
}, Open  ]],
Cell[433853, 14100, 563, 14, 40, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],

Cell[CellGroupData[{
Cell[434441, 14118, 162, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
Cell[434606, 14125, 566, 9, 65, "Print",
  CellTags->{
  "Info3312042871-8199869", "AOG2.", "AOG2.1", "AOG2.1.8", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[435209, 14139, 366, 10, 107, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
Cell[435578, 14151, 20370, 730, 110, 9744, 593, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}],
Cell[455951, 14883, 1831, 30, 145, "Output",
  CellTags->{"AOG2.1.8", "AOG2.1", "AOG2.", "AOG0."}]
}, Open  ]],
Cell[457797, 14916, 492, 15, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.1", "AOG2.1.8"}],
Cell[458292, 14933, 160, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.1", "AOG2.", "AOG2.1.8"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[458501, 14942, 96, 1, 36, "Subsection",
  CellTags->{"AOG0.", "2.2", "AOG2.", "AOG2.2"}],
Cell[458600, 14945, 525, 12, 36, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2"}],

Cell[CellGroupData[{
Cell[459150, 14961, 128, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "2.2.1", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[459281, 14964, 723, 15, 38, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[460007, 14981, 111, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[460121, 14985, 267, 7, 75, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[460391, 14994, 268, 5, 22, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[460684, 15003, 192, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[460879, 15010, 23289, 697, 130, 7253, 493, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[484183, 15710, 551, 12, 40, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[484759, 15726, 246, 6, 59, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[485008, 15734, 552, 10, 77, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[485575, 15747, 482, 11, 40, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[486082, 15762, 152, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[486237, 15766, 1723, 24, 185, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[487975, 15793, 158, 4, 22, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[488158, 15801, 139, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[488300, 15805, 71910, 1447, 240, 21739, 822, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[560225, 17255, 196, 4, 22, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[560446, 17263, 121, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[560570, 17267, 1525, 21, 185, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[562132, 17293, 121, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[562256, 17297, 1494, 22, 185, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[563765, 17322, 255, 6, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[564045, 17332, 137, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[564185, 17336, 5152, 92, 129, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[569352, 17431, 378, 6, 22, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[569755, 17441, 230, 6, 43, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[569988, 17449, 225, 4, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[570228, 17456, 287, 7, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[570540, 17467, 261, 6, 59, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[570804, 17475, 76731, 5322, 130, 64916, 5171, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
Cell[647538, 22799, 426, 9, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[647979, 22811, 667, 11, 38, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[648671, 22826, 244, 6, 43, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[648918, 22834, 1029, 19, 73, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[649962, 22856, 200, 4, 22, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[650187, 22864, 184, 3, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[650374, 22869, 5263, 73, 617, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[655652, 22945, 300, 6, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[655977, 22955, 245, 6, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[656225, 22963, 221, 4, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[656461, 22970, 419, 8, 38, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[656905, 22982, 259, 6, 59, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[657167, 22990, 76745, 5322, 130, 64930, 5171, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
Cell[733915, 28314, 425, 9, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[734355, 28326, 441, 7, 36, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],

Cell[CellGroupData[{
Cell[734821, 28337, 260, 6, 59, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[735084, 28345, 315480, 24523, 130, 303636, 24371, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}],
Cell[1050567, 52870, 424, 9, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.1", "AOG0."}]
}, Open  ]],
Cell[1051006, 52882, 188, 4, 22, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.1"}],
Cell[1051197, 52888, 160, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.2", "AOG2.", "AOG2.2.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[1051394, 52896, 126, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2", "2.2.2"}],
Cell[1051523, 52899, 815, 13, 52, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[1052341, 52914, 301, 8, 75, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{
Cell[1052667, 52926, 172, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[1052842, 52932, 39451, 2840, 64, 34309, 2771, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],
Cell[1092308, 55775, 399, 12, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{
Cell[1092732, 55791, 288, 6, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[1093023, 55799, 938, 17, 88, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],
Cell[1093976, 55819, 216, 4, 22, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{
Cell[1094217, 55827, 176, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[1094396, 55833, 28646, 598, 184, 4073, 289, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],
Cell[1123057, 56434, 487, 9, 38, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[1123547, 56445, 193, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{
Cell[1123765, 56454, 186, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[1123954, 56461, 7133, 104, 324, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],
Cell[1131102, 56568, 191, 5, 24, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{
Cell[1131318, 56577, 206, 6, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[1131527, 56585, 24152, 606, 184, 5492, 370, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],
Cell[1155694, 57194, 186, 4, 22, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{
Cell[1155905, 57202, 117, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[1156025, 57206, 27273, 690, 184, 6378, 427, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],
Cell[1183313, 57899, 504, 8, 36, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{
Cell[1183842, 57911, 274, 7, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[1184119, 57920, 3410, 47, 401, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[1187566, 57972, 208, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[1187777, 57978, 3008, 42, 365, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[1190822, 58025, 208, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[1191033, 58031, 3054, 42, 365, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[1194124, 58078, 378, 8, 75, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{
Cell[1194527, 58090, 252102, 6207, 240, 177264, 5277, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
Cell[1446632, 64299, 302511, 6827, 240, 177429, 5277, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
Cell[1749146, 71128, 278598, 6544, 240, 177380, 5289, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
Cell[2027747, 77674, 1438537, 71956, 261, 1301290, 70256, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3466333, 149636, 137, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[3466473, 149640, 9632, 174, 234, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3476142, 149819, 111, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[3476256, 149823, 115, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],
Cell[3476386, 149829, 199, 6, 59, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{
Cell[3476610, 149839, 258, 9, 107, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[3476871, 149850, 293, 6, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3477201, 149861, 200, 6, 59, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{
Cell[3477426, 149871, 38782, 2831, 64, 34341, 2771, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
Cell[3516211, 152704, 39691, 2844, 64, 34229, 2771, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],
Cell[3555917, 155551, 946, 17, 54, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],
Cell[3556878, 155571, 277, 7, 75, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],

Cell[CellGroupData[{
Cell[3557180, 155582, 195, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[3557378, 155589, 295, 5, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3557710, 155599, 150, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.2"}],
Cell[3557863, 155603, 39799, 2844, 64, 34345, 2771, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}],
Cell[3597665, 158449, 424, 9, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.2", "AOG0."}]
}, Open  ]],
Cell[3598104, 158461, 160, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.2", "AOG2.", "AOG2.2.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3598301, 158469, 107, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "2.2.3", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3598411, 158472, 373, 6, 22, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3598787, 158480, 574, 10, 85, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3599364, 158492, 175, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3599542, 158498, 108, 1, 22, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[CellGroupData[{
Cell[3599675, 158503, 166, 3, 25, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3599844, 158508, 28599, 1237, 86, 18759, 1110, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3628480, 159750, 139, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3628622, 159754, 132, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3628791, 159762, 140, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3628934, 159766, 132, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3629103, 159774, 108, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3629214, 159778, 521, 12, 35, "Print",
  CellTags->{
  "Info3312042947-9251066", "AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3629772, 159795, 165, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3629940, 159801, 117, 3, 38, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3630094, 159809, 156, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3630253, 159813, 117, 3, 38, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],
Cell[3630385, 159819, 391, 8, 59, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[CellGroupData[{
Cell[3630801, 159831, 109, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3630913, 159835, 117, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3631067, 159843, 109, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3631179, 159847, 2067, 38, 214, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3633283, 159890, 168, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3633454, 159896, 140, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3633631, 159904, 121, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3633755, 159908, 119, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3633911, 159916, 121, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3634035, 159920, 12755, 207, 1238, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3646827, 160132, 260, 6, 43, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3647090, 160140, 258, 5, 26, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3647385, 160150, 344, 12, 155, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3647732, 160164, 118, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3647887, 160172, 269, 6, 43, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3648159, 160180, 254, 5, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3648450, 160190, 155, 5, 43, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3648608, 160197, 118, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3648763, 160205, 155, 5, 43, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3648921, 160212, 118, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3649076, 160220, 155, 5, 43, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3649234, 160227, 118, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3649389, 160235, 148, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3649540, 160239, 47437, 819, 1149, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3697014, 161063, 112, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3697129, 161067, 117, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3697283, 161075, 255, 8, 91, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3697541, 161085, 508, 9, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3698086, 161099, 276, 8, 75, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[3698365, 161109, 3592, 63, 129, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3701994, 161177, 525, 11, 139, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],

Cell[CellGroupData[{
Cell[3702544, 161192, 18991, 786, 86, 11568, 689, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3721538, 161980, 19404, 805, 86, 11762, 705, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3740945, 162787, 17533, 725, 86, 10993, 639, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3758481, 163514, 21004, 843, 86, 12058, 727, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3779488, 164359, 22226, 965, 86, 13636, 853, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3801717, 165326, 24095, 1034, 86, 14388, 909, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3825815, 166362, 18228, 740, 86, 11141, 647, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3844046, 167104, 25166, 1090, 86, 15289, 963, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3869215, 168196, 24747, 1071, 86, 15113, 947, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3893965, 169269, 25378, 1114, 86, 15849, 991, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3919346, 170385, 25093, 1076, 86, 15118, 947, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3944442, 171463, 23817, 1008, 86, 13964, 881, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3968262, 172473, 25725, 1085, 86, 14989, 947, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[3993990, 173560, 22928, 1085, 86, 15776, 991, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4016921, 174647, 24033, 1099, 86, 15767, 991, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4040957, 175748, 21595, 980, 86, 14014, 881, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4062555, 176730, 23316, 1089, 86, 15800, 991, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4085874, 177821, 23217, 980, 86, 13708, 857, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4109094, 178803, 24174, 1099, 86, 15844, 991, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4133271, 179904, 23922, 1075, 86, 15288, 963, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4157196, 180981, 24420, 1103, 86, 15830, 991, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4181619, 182086, 24090, 1067, 86, 15136, 951, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4205712, 183155, 17283, 700, 86, 10686, 613, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4222998, 183857, 17236, 713, 86, 10910, 629, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4240237, 184572, 20490, 947, 86, 13678, 857, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4260730, 185521, 22588, 1004, 86, 14387, 897, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4283321, 186527, 22189, 967, 86, 13693, 857, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],
Cell[4305525, 187497, 10122, 191, 414, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4315684, 187693, 206, 6, 43, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[4315893, 187701, 310, 5, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4316240, 187711, 531, 13, 123, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[4316774, 187726, 29237, 1570, 86, 21628, 1471, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}],
Cell[4346014, 189298, 428, 9, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4346479, 189312, 479, 13, 123, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.2", "AOG2.2.3"}],
Cell[4346961, 189327, 428, 9, 24, "Output",
  CellTags->{"AOG2.", "AOG2.2", "AOG2.2.3", "AOG0."}]
}, Open  ]],
Cell[4347404, 189339, 160, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.2.3", "AOG2.2", "AOG2."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4347613, 189348, 119, 1, 36, "Subsection",
  CellTags->{"AOG0.", "2.3", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell[CellGroupData[{
Cell[4347757, 189353, 101, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "2.3.1", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell[CellGroupData[{
Cell[4347883, 189358, 160, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
Cell[4348046, 189364, 165, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}]
}, Open  ]],
Cell[4348226, 189370, 231, 7, 59, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
Cell[4348460, 189379, 180, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell[CellGroupData[{
Cell[4348665, 189387, 167, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
Cell[4348835, 189393, 31520, 1334, 159, 20081, 1187, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}]
}, Open  ]],
Cell[4380370, 190730, 184, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],

Cell[CellGroupData[{
Cell[4380579, 190739, 131, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
Cell[4380713, 190743, 418, 7, 24, "Output",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4381168, 190755, 202, 6, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.1"}],
Cell[4381373, 190763, 13835, 365, 184, 3130, 227, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.1"}]
}, Open  ]],
Cell[4395223, 191131, 148, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.3", "AOG2."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4395408, 191139, 116, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "2.3.2", "AOG2.", "AOG2.3", "AOG2.3.2"}],

Cell[CellGroupData[{
Cell[4395549, 191144, 121, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
Cell[4395673, 191148, 42033, 1026, 296, 7262, 591, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
Cell[4437709, 192176, 922, 21, 39, "Output",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4438668, 192202, 154, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],

Cell[CellGroupData[{
Cell[4438847, 192208, 42773, 1154, 184, 9613, 739, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}],
Cell[4481623, 193364, 60297, 1107, 184, 6603, 439, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4541969, 194477, 135, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.2"}],
Cell[4542107, 194481, 36182, 848, 184, 6910, 481, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.2"}]
}, Open  ]],
Cell[4578304, 195332, 148, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.3", "AOG2."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4578489, 195340, 104, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "2.3.3", "AOG2.", "AOG2.3", "AOG2.3.3"}],

Cell[CellGroupData[{
Cell[4578618, 195345, 280, 6, 43, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
Cell[4578901, 195353, 319, 6, 26, "Output",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4579257, 195364, 139, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
Cell[4579399, 195368, 23061, 533, 184, 4091, 293, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4602497, 195906, 118, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
Cell[4602618, 195910, 23167, 551, 184, 4496, 315, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4625822, 196466, 116, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
Cell[4625941, 196470, 342, 6, 26, "Output",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],
Cell[4626298, 196479, 139, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
Cell[4626440, 196483, 144, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],

Cell[CellGroupData[{
Cell[4626609, 196489, 168, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
Cell[4626780, 196495, 28051, 731, 184, 6546, 460, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4654868, 197231, 130, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
Cell[4655001, 197235, 1609, 28, 94, "Output",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4656647, 197268, 145, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.3"}],
Cell[4656795, 197272, 402, 7, 23, "Message",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
Cell[4657200, 197281, 401, 7, 23, "Message",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
Cell[4657604, 197290, 401, 7, 23, "Message",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
Cell[4658008, 197299, 247, 5, 19, "Message",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}],
Cell[4658258, 197306, 19539, 493, 184, 4204, 298, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.3"}]
}, Open  ]],
Cell[4677812, 197802, 148, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.3", "AOG2."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4677997, 197810, 116, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "2.3.4", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[4678116, 197813, 154, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[4678273, 197817, 380, 15, 203, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[CellGroupData[{
Cell[4678678, 197836, 126, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[4678807, 197840, 1462, 26, 198, "Output",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4680306, 197871, 116, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[4680425, 197875, 652, 13, 39, "Output",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4681114, 197893, 197, 5, 43, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[4681314, 197900, 132, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],
Cell[4681461, 197906, 120, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[CellGroupData[{
Cell[4681606, 197912, 142, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[4681751, 197916, 29725, 703, 184, 5721, 401, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4711513, 198624, 153, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[4711669, 198628, 134, 3, 24, "Output",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4711840, 198636, 154, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[4711997, 198640, 20416, 550, 184, 4840, 352, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4732450, 199195, 138, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[4732591, 199199, 46075, 859, 377, 4774, 344, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4778703, 200063, 166, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[4778872, 200069, 21023, 472, 184, 3388, 249, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],
Cell[4799910, 200544, 276, 6, 34, "Text",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],

Cell[CellGroupData[{
Cell[4800211, 200554, 203, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[4800417, 200561, 1857010, 45857, 240, 1775535, 44846, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[6657464, 246423, 277, 6, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[6657744, 246431, 706903, 40556, 294, 616171, 39430, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7364684, 286992, 279, 6, 27, "Input",
  CellTags->{"AOG0.", "AOG2.", "AOG2.3", "AOG2.3.4"}],
Cell[7364966, 287000, 476455, 6607, 294, 247926, 3780, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG2.", "AOG2.3", "AOG0.", "AOG2.3.4"}]
}, Open  ]],
Cell[7841436, 293610, 148, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG2.3", "AOG2."}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7841645, 293620, 99, 1, 61, "Section",
  CellTags->{"AOG0.", "3", "AOG3."}],

Cell[CellGroupData[{
Cell[7841769, 293625, 83, 1, 36, "Subsection",
  CellTags->{"AOG0.", "3.1", "AOG3.", "AOG3.1"}],

Cell[CellGroupData[{
Cell[7841877, 293630, 101, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
Cell[7841981, 293634, 328, 5, 80, "Print",
  CellTags->{"Info3312043331-3736878", "AOG3.", "AOG3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7842346, 293644, 108, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
Cell[7842457, 293648, 803, 13, 89, "Output",
  CellTags->{"AOG3.", "AOG3.1"}]
}, Open  ]],
Cell[7843275, 293664, 351, 9, 91, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],

Cell[CellGroupData[{
Cell[7843651, 293677, 141, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
Cell[7843795, 293681, 32764, 1445, 132, 20021, 1282, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG3.", "AOG3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7876596, 295131, 154, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
Cell[7876753, 295137, 1399, 25, 95, "Output",
  CellTags->{"AOG3.", "AOG3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7878189, 295167, 176, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
Cell[7878368, 295174, 23705, 563, 103, "Output",
  CellTags->{"AOG3.", "AOG3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7902110, 295742, 193, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.1"}],
Cell[7902306, 295749, 3068, 76, 49, "Output",
  CellTags->{"AOG3.", "AOG3.1"}]
}, Open  ]],
Cell[7905389, 295828, 138, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG3."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7905564, 295836, 99, 1, 36, "Subsection",
  CellTags->{"AOG0.", "3.2", "AOG3.", "AOG3.2"}],
Cell[7905666, 295839, 228, 7, 75, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],

Cell[CellGroupData[{
Cell[7905919, 295850, 131, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
Cell[7906053, 295854, 30690, 1092, 222, 13662, 876, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG3.", "AOG3.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7936780, 296951, 177, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
Cell[7936960, 296958, 378, 9, 67, "Output",
  CellTags->{"AOG3.", "AOG3.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7937375, 296972, 121, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.2"}],
Cell[7937499, 296976, 313, 9, 59, "Output",
  CellTags->{"AOG3.", "AOG3.2"}]
}, Open  ]],
Cell[7937827, 296988, 138, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG3."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7938002, 296996, 111, 1, 36, "Subsection",
  CellTags->{"AOG0.", "3.3", "AOG3.", "AOG3.3", "AOG3.3.1"}],

Cell[CellGroupData[{
Cell[7938138, 297001, 90, 1, 32, "Subsubsection",
  CellTags->{"AOG3.3.1", "AOG3.3", "3.3.1", "AOG3."}],
Cell[7938231, 297004, 302, 8, 75, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],

Cell[CellGroupData[{
Cell[7938558, 297016, 143, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
Cell[7938704, 297020, 20886, 735, 110, 9824, 593, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7959627, 297760, 209, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
Cell[7959839, 297767, 2356, 61, 59, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7962232, 297833, 199, 5, 27, "Input",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}],
Cell[7962434, 297840, 718, 14, 54, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7963189, 297859, 250, 6, 43, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.1"}],
Cell[7963442, 297867, 3786, 100, 59, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.1"}]
}, Open  ]],
Cell[7967243, 297970, 148, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG3.3", "AOG3."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7967428, 297978, 92, 1, 32, "Subsubsection",
  CellTags->{"AOG3.3.2", "AOG3.3", "3.3.2", "AOG3."}],
Cell[7967523, 297981, 327, 9, 75, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],

Cell[CellGroupData[{
Cell[7967875, 297994, 150, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
Cell[7968028, 297998, 20738, 716, 130, 9473, 571, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7988803, 298719, 224, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
Cell[7989030, 298726, 5803, 148, 113, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7994870, 298879, 267, 6, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
Cell[7995140, 298887, 2059, 36, 227, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7997236, 298928, 214, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.2"}],
Cell[7997453, 298935, 584, 13, 69, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.2"}]
}, Open  ]],
Cell[7998052, 298951, 148, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG3.3", "AOG3."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7998237, 298959, 95, 1, 32, "Subsubsection",
  CellTags->{"AOG3.3.3", "AOG3.3", "3.3.3", "AOG3."}],
Cell[7998335, 298962, 366, 9, 75, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
Cell[7998704, 298973, 353, 8, 75, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[CellGroupData[{
Cell[7999082, 298985, 151, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
Cell[7999236, 298989, 2110, 55, 101, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8001383, 299049, 149, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
Cell[8001535, 299053, 633, 13, 71, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],
Cell[8002183, 299069, 403, 9, 75, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],

Cell[CellGroupData[{
Cell[8002611, 299082, 129, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
Cell[8002743, 299086, 28330, 797, 213, 7004, 528, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8031110, 299888, 154, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
Cell[8031267, 299892, 2285, 59, 99, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8033589, 299956, 194, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
Cell[8033786, 299963, 684, 14, 69, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8034507, 299982, 192, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
Cell[8034702, 299989, 342, 9, 49, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8035081, 300003, 185, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
Cell[8035269, 300010, 3689, 98, 99, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8038995, 300113, 204, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
Cell[8039202, 300120, 5736, 148, 129, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8044975, 300273, 179, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
Cell[8045157, 300279, 1156, 30, 79, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8046350, 300314, 200, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
Cell[8046553, 300321, 2313, 48, 79, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8048903, 300374, 221, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.3", "AOG3.3.3"}],
Cell[8049127, 300381, 5566, 140, 89, "Output",
  CellTags->{"AOG3.", "AOG3.3", "AOG3.3.3"}]
}, Open  ]],
Cell[8054708, 300524, 148, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG3.3", "AOG3."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8054905, 300533, 97, 1, 36, "Subsection",
  CellTags->{"AOG0.", "3.4", "AOG3.", "AOG3.4"}],
Cell[8055005, 300536, 283, 7, 59, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],

Cell[CellGroupData[{
Cell[8055313, 300547, 131, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
Cell[8055447, 300551, 21420, 742, 110, 9782, 593, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG3.", "AOG3.4", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8076904, 301298, 234, 5, 43, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
Cell[8077141, 301305, 1133, 18, 142, "Output",
  CellTags->{"AOG3.", "AOG3.4", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8078311, 301328, 244, 6, 43, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
Cell[8078558, 301336, 1349, 25, 73, "Output",
  CellTags->{"AOG3.", "AOG3.4", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8079944, 301366, 110, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
Cell[8080057, 301370, 360, 9, 59, "Output",
  CellTags->{"AOG3.", "AOG3.4", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8080454, 301384, 105, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
Cell[8080562, 301388, 724, 15, 73, "Output",
  CellTags->{"AOG3.", "AOG3.4", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8081323, 301408, 110, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.4"}],
Cell[8081436, 301412, 517, 12, 59, "Output",
  CellTags->{"AOG3.", "AOG3.4", "AOG0."}]
}, Open  ]],
Cell[8081968, 301427, 138, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG3."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8082143, 301435, 106, 1, 36, "Subsection",
  CellTags->{"AOG0.", "3.5", "AOG3.", "AOG3.5"}],
Cell[8082252, 301438, 187, 6, 59, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[CellGroupData[{
Cell[8082464, 301448, 129, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8082596, 301452, 14186, 465, 110, 6735, 367, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8096819, 301922, 176, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8096998, 301929, 352, 9, 67, "Output",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8097387, 301943, 106, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8097496, 301947, 308, 9, 59, "Output",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8097841, 301961, 106, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8097950, 301965, 317, 9, 59, "Output",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],
Cell[8098282, 301977, 197, 6, 59, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[CellGroupData[{
Cell[8098504, 301987, 130, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8098637, 301991, 17341, 551, 110, 7606, 425, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8116015, 302547, 126, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8116144, 302551, 13181, 381, 102, 3851, 260, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8129362, 302937, 181, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8129546, 302944, 400, 10, 69, "Output",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8129983, 302959, 111, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8130097, 302963, 308, 9, 59, "Output",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8130442, 302977, 106, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8130551, 302981, 324, 9, 67, "Output",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8130912, 302995, 111, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8131026, 302999, 317, 9, 59, "Output",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],
Cell[8131358, 303011, 242, 8, 24, "Text",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8131603, 303021, 211, 6, 59, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[CellGroupData[{
Cell[8131839, 303031, 129, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8131971, 303035, 14838, 515, 110, 7298, 416, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8146846, 303555, 164, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8147013, 303561, 352, 9, 67, "Output",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8147402, 303575, 106, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8147511, 303579, 308, 9, 59, "Output",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8147856, 303593, 197, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8148056, 303600, 2543, 70, 59, "Output",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],
Cell[8150614, 303673, 148, 4, 24, "Text",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8150765, 303679, 241, 6, 59, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],

Cell[CellGroupData[{
Cell[8151031, 303689, 111, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8151145, 303693, 21765, 551, 202, 3804, 324, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8172947, 304249, 126, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8173076, 304253, 1631, 49, 115, "Output",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8174744, 304307, 106, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.5"}],
Cell[8174853, 304311, 1051, 31, 99, "Output",
  CellTags->{"AOG3.", "AOG3.5"}]
}, Open  ]],
Cell[8175919, 304345, 138, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG3."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8176094, 304353, 91, 1, 36, "Subsection",
  CellTags->{"AOG0.", "3.6", "AOG3.", "AOG3.6"}],

Cell[CellGroupData[{
Cell[8176210, 304358, 93, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
Cell[8176306, 304362, 2733, 37, 320, "Print",
  CellTags->{"Info3312115087-1929230", "AOG3.", "AOG3.6"}]
}, Open  ]],
Cell[8179054, 304402, 328, 8, 59, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],

Cell[CellGroupData[{
Cell[8179407, 304414, 137, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
Cell[8179547, 304418, 23532, 617, 240, 7151, 409, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG3.", "AOG3.6", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8203116, 305040, 105, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
Cell[8203224, 305044, 196, 4, 24, "Output",
  CellTags->{"AOG3.", "AOG3.6", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8203457, 305053, 275, 7, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
Cell[8203735, 305062, 901, 22, 75, "Output",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8204673, 305089, 105, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
Cell[8204781, 305093, 393, 9, 85, "Output",
  CellTags->{"AOG3.", "AOG3.6", "AOG0."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8205211, 305107, 271, 6, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
Cell[8205485, 305115, 314, 9, 49, "Output",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8205836, 305129, 185, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}],
Cell[8206024, 305136, 1403, 23, 84, "Output",
  CellTags->{"AOG0.", "AOG3.", "AOG3.6"}]
}, Open  ]],
Cell[8207442, 305162, 138, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG3."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8207629, 305171, 110, 1, 61, "Section",
  CellTags->{"AOG0.", "4", "AOG4.", "AOG4.1"}],

Cell[CellGroupData[{
Cell[8207764, 305176, 83, 1, 36, "Subsection",
  CellTags->{"AOG0.", "4.1", "AOG4.", "AOG4.1"}],

Cell[CellGroupData[{
Cell[8207872, 305181, 99, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
Cell[8207974, 305185, 431, 6, 80, "Print",
  CellTags->{"Info3312043438-4643038", "AOG4.", "AOG4.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8208442, 305196, 107, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
Cell[8208552, 305200, 685, 11, 54, "Output",
  CellTags->{"AOG4.", "AOG4.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8209274, 305216, 96, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
Cell[8209373, 305220, 1395, 19, 155, "Print",
  CellTags->{"Info3405686992-9872384", "AOG0.", "AOG4.", "AOG4.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8210805, 305244, 106, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
Cell[8210914, 305248, 854, 15, 54, "Output",
  CellTags->{"AOG4.", "AOG4.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8211805, 305268, 98, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
Cell[8211906, 305272, 3519, 47, 425, "Print",
  CellTags->{"Info3312043439-7338271", "AOG4.", "AOG4.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8215462, 305324, 106, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
Cell[8215571, 305328, 857, 14, 78, "Output",
  CellTags->{"AOG4.", "AOG4.1"}]
}, Open  ]],
Cell[8216443, 305345, 331, 9, 59, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],

Cell[CellGroupData[{
Cell[8216799, 305358, 165, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.1"}],
Cell[8216967, 305364, 157592, 4062, 397, 41452, 2622, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.1"}]
}, Open  ]],
Cell[8374574, 309429, 138, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8374749, 309437, 109, 1, 36, "Subsection",
  CellTags->{"AOG0.", "4.2", "AOG4.", "AOG4.2", "AOG4.2.1"}],

Cell[CellGroupData[{
Cell[8374883, 309442, 94, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "4.2.1", "AOG4.", "AOG4.2", "AOG4.2.1"}],
Cell[8374980, 309445, 337, 8, 91, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],

Cell[CellGroupData[{
Cell[8375342, 309457, 153, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
Cell[8375498, 309461, 36774, 1565, 119, 21947, 1376, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8412309, 311031, 204, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
Cell[8412516, 311038, 3171, 77, 49, "Output",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8415724, 311120, 255, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.1"}],
Cell[8415982, 311127, 3042, 82, 59, "Output",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.1"}]
}, Open  ]],
Cell[8419039, 311212, 148, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8419224, 311220, 101, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "4.2.2", "AOG4.", "AOG4.2", "AOG4.2.2"}],

Cell[CellGroupData[{
Cell[8419350, 311225, 134, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.2"}],
Cell[8419487, 311229, 4148, 71, 204, "Output",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.2"}]
}, Open  ]],
Cell[8423650, 311303, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8423835, 311311, 100, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.2.3", "AOG4.", "AOG4.2", "AOG4.2.3"}],

Cell[CellGroupData[{
Cell[8423960, 311316, 133, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
Cell[8424096, 311320, 41750, 905, 184, 10085, 508, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8465883, 312230, 176, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
Cell[8466062, 312236, 40778, 891, 184, 10370, 510, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8506877, 313132, 185, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],

Cell[CellGroupData[{
Cell[8507087, 313141, 42205, 924, 184, 10651, 529, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
Cell[8549295, 314067, 40885, 946, 184, 11239, 574, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8590229, 315019, 199, 5, 45, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.3"}],
Cell[8590431, 315026, 99253, 2755, 184, 29018, 1882, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}],
Cell[8689687, 317783, 3595, 64, 210, "Output",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.3"}]
}, Open  ]],
Cell[8693297, 317850, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8693482, 317858, 100, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.2.4", "AOG4.", "AOG4.2", "AOG4.2.4"}],

Cell[CellGroupData[{
Cell[8693607, 317863, 176, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.4"}],
Cell[8693786, 317869, 82869, 3386, 119, 44933, 2912, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8776692, 321260, 179, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2", "AOG4.2.4"}],
Cell[8776874, 321266, 86168, 3632, 119, 49560, 3174, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.2", "AOG4.2.4"}]
}, Open  ]],
Cell[8863057, 324901, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.2"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8863254, 324910, 114, 1, 36, "Subsection",
  CellTags->{"AOG0.", "4.3", "AOG4.", "AOG4.3", "AOG4.3.1"}],

Cell[CellGroupData[{
Cell[8863393, 324915, 94, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.3.1", "AOG4.", "AOG4.3", "AOG4.3.1"}],
Cell[8863490, 324918, 327, 9, 96, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],

Cell[CellGroupData[{
Cell[8863842, 324931, 139, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
Cell[8863984, 324935, 110082, 2058, 598, 14663, 874, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8974103, 326998, 244, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
Cell[8974350, 327005, 3583, 98, 109, "Output",
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8977970, 327108, 245, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.1"}],
Cell[8978218, 327115, 3609, 98, 109, "Output",
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.1"}]
}, Open  ]],
Cell[8981842, 327216, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8982027, 327224, 101, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.3.2", "AOG4.", "AOG4.3", "AOG4.3.2"}],

Cell[CellGroupData[{
Cell[8982153, 327229, 138, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.2"}],
Cell[8982294, 327233, 4394, 75, 213, "Output",
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.2"}]
}, Open  ]],
Cell[8986703, 327311, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8986888, 327319, 100, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.3.3", "AOG4.", "AOG4.3", "AOG4.3.3"}],

Cell[CellGroupData[{
Cell[8987013, 327324, 137, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.3"}],

Cell[CellGroupData[{
Cell[8987175, 327330, 36915, 812, 184, 8790, 459, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}],
Cell[9024093, 328144, 35572, 827, 184, 9311, 497, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}]
}, Open  ]],
Cell[9059680, 328974, 5041, 92, 284, "Output",
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.3"}]
}, Open  ]],
Cell[9064736, 329069, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[9064921, 329077, 100, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.3.4", "AOG4.", "AOG4.3", "AOG4.3.4"}],

Cell[CellGroupData[{
Cell[9065046, 329082, 191, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3", "AOG4.3.4"}],
Cell[9065240, 329089, 346463, 19400, 562, 207570, 17680, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.3", "AOG4.3.4"}]
}, Open  ]],
Cell[9411718, 348492, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9411915, 348501, 108, 1, 36, "Subsection",
  CellTags->{"AOG0.", "4.4", "AOG4.", "AOG4.4", "AOG4.4.1"}],

Cell[CellGroupData[{
Cell[9412048, 348506, 94, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.4.1", "AOG4.", "AOG4.4", "AOG4.4.1"}],
Cell[9412145, 348509, 338, 8, 96, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],

Cell[CellGroupData[{
Cell[9412508, 348521, 132, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
Cell[9412643, 348525, 93072, 1898, 564, 16306, 945, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[9505752, 350428, 202, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
Cell[9505957, 350435, 5040, 126, 91, "Output",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[9511034, 350566, 181, 5, 45, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.1"}],
Cell[9511218, 350573, 1280, 30, 79, "Output",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.1"}]
}, Open  ]],
Cell[9512513, 350606, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[9512698, 350614, 101, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.4.2", "AOG4.", "AOG4.4", "AOG4.4.2"}],

Cell[CellGroupData[{
Cell[9512824, 350619, 131, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.2"}],
Cell[9512958, 350623, 6349, 112, 293, "Output",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.2"}]
}, Open  ]],
Cell[9519322, 350738, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[9519507, 350746, 100, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.4.3", "AOG4.", "AOG4.4", "AOG4.4.3"}],

Cell[CellGroupData[{
Cell[9519632, 350751, 131, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.3"}],

Cell[CellGroupData[{
Cell[9519788, 350757, 41693, 926, 184, 10477, 535, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
Cell[9561484, 351685, 41582, 925, 184, 10475, 535, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}]
}, Open  ]]
}, Open  ]],
Cell[9603093, 352614, 88, 2, 28, "Input",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],

Cell[CellGroupData[{
Cell[9603206, 352620, 181, 5, 45, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.3"}],

Cell[CellGroupData[{
Cell[9603412, 352629, 42973, 944, 184, 10888, 542, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
Cell[9646388, 353575, 40331, 937, 184, 11240, 572, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
Cell[9686722, 354514, 43028, 945, 184, 10880, 542, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}],
Cell[9729753, 355461, 40128, 935, 184, 11183, 572, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.3"}]
}, Open  ]]
}, Open  ]],
Cell[9769908, 356400, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[9770093, 356408, 100, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.4.4", "AOG4.", "AOG4.4", "AOG4.4.4"}],

Cell[CellGroupData[{
Cell[9770218, 356413, 176, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
Cell[9770397, 356419, 88137, 4899, 120, 72452, 4700, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[9858571, 361323, 177, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
Cell[9858751, 361329, 90758, 4928, 84, 72786, 4700, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[9949546, 366262, 149, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4", "AOG4.4.4"}],
Cell[9949698, 366266, 149230, 11357, 188, 129962, 11114, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.4", "AOG4.4.4"}]
}, Open  ]],
Cell[10098943, 377626, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.4"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10099140, 377635, 110, 1, 36, "Subsection",
  CellTags->{"AOG0.", "4.5", "AOG4.", "AOG4.5", "AOG4.5.1"}],

Cell[CellGroupData[{
Cell[10099275, 377640, 94, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.5.1", "AOG4.", "AOG4.5", "AOG4.5.1"}],
Cell[10099372, 377643, 346, 8, 79, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],

Cell[CellGroupData[{
Cell[10099743, 377655, 129, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
Cell[10099875, 377659, 38235, 962, 255, 7596, 578, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10138147, 378626, 181, 5, 45, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
Cell[10138331, 378633, 3947, 102, 99, "Output",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10142315, 378740, 178, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.1"}],
Cell[10142496, 378746, 706, 13, 37, "Output",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.1"}]
}, Open  ]],
Cell[10143217, 378762, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10143402, 378770, 101, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.5.2", "AOG4.", "AOG4.5", "AOG4.5.2"}],

Cell[CellGroupData[{
Cell[10143528, 378775, 128, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.2"}],
Cell[10143659, 378779, 4428, 75, 197, "Output",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.2"}]
}, Open  ]],
Cell[10148102, 378857, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10148287, 378865, 100, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.5.3", "AOG4.", "AOG4.5", "AOG4.5.3"}],

Cell[CellGroupData[{
Cell[10148412, 378870, 128, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.3"}],

Cell[CellGroupData[{
Cell[10148565, 378876, 32374, 762, 184, 8941, 467, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
Cell[10180942, 379640, 31278, 725, 184, 8566, 439, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10212269, 380371, 177, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.3"}],

Cell[CellGroupData[{
Cell[10212471, 380379, 37055, 821, 184, 9279, 472, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
Cell[10249529, 381202, 34566, 816, 184, 9626, 502, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
Cell[10284098, 382020, 34157, 774, 184, 8978, 457, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}],
Cell[10318258, 382796, 34380, 793, 184, 9314, 478, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.3"}]
}, Open  ]]
}, Open  ]],
Cell[10352665, 383593, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10352850, 383601, 100, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.5.4", "AOG4.", "AOG4.5", "AOG4.5.4"}],

Cell[CellGroupData[{
Cell[10352975, 383606, 173, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
Cell[10353151, 383612, 89292, 3811, 161, 52391, 3350, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10442480, 387428, 174, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
Cell[10442657, 387434, 118017, 4167, 187, 52312, 3350, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10560711, 391606, 146, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5", "AOG4.5.4"}],
Cell[10560860, 391610, 148094, 9129, 255, 95739, 8477, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.5", "AOG4.5.4"}]
}, Open  ]],
Cell[10708969, 400742, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4.", "AOG4.5"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10709166, 400751, 93, 1, 36, "Subsection",
  CellTags->{"AOG0.", "4.6", "AOG4.", "AOG4.6"}],

Cell[CellGroupData[{
Cell[10709284, 400756, 94, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.6.1", "AOG4.", "AOG4.6", "AOG4.6.1"}],
Cell[10709381, 400759, 277, 9, 113, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],

Cell[CellGroupData[{
Cell[10709683, 400772, 131, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
Cell[10709817, 400776, 36106, 1082, 221, 9515, 748, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10745960, 401863, 202, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.1"}],
Cell[10746165, 401870, 6240, 154, 91, "Output",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.1"}]
}, Open  ]],
Cell[10752420, 402027, 138, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10752595, 402035, 101, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.6.2", "AOG4.", "AOG4.6", "AOG4.6.2"}],

Cell[CellGroupData[{
Cell[10752721, 402040, 130, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.2"}],
Cell[10752854, 402044, 7613, 135, 325, "Output",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.2"}]
}, Open  ]],
Cell[10760482, 402182, 138, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10760657, 402190, 100, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "4.6.3", "AOG4.", "AOG4.6", "AOG4.6.3"}],

Cell[CellGroupData[{
Cell[10760782, 402195, 130, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.3"}],

Cell[CellGroupData[{
Cell[10760937, 402201, 47820, 1097, 184, 12909, 660, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
Cell[10808760, 403300, 47419, 1044, 184, 12063, 602, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10856228, 404350, 179, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.3"}],

Cell[CellGroupData[{
Cell[10856432, 404358, 50096, 1104, 184, 12892, 639, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
Cell[10906531, 405464, 49448, 1121, 184, 13308, 669, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
Cell[10955982, 406587, 50236, 1118, 184, 13097, 654, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}],
Cell[11006221, 407707, 47195, 1046, 184, 12495, 612, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.3"}]
}, Open  ]]
}, Open  ]],
Cell[11053443, 408757, 138, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG4."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11053618, 408765, 100, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "4.6.4", "AOG4.", "AOG4.6", "AOG4.6.4"}],

Cell[CellGroupData[{
Cell[11053743, 408770, 175, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
Cell[11053921, 408776, 109765, 5291, 132, 76369, 4873, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11163723, 414072, 176, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
Cell[11163902, 414078, 110499, 5298, 132, 76572, 4873, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11274438, 419381, 148, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG4.", "AOG4.6", "AOG4.6.4"}],
Cell[11274589, 419385, 172454, 12925, 220, 141061, 12532, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG4.", "AOG4.6", "AOG4.6.4"}]
}, Open  ]],
Cell[11447058, 432313, 138, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG4."}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11447257, 432323, 89, 1, 61, "Section",
  CellTags->{"AOG0.", "5", "AOG5.", "AOG5.1"}],

Cell[CellGroupData[{
Cell[11447371, 432328, 83, 1, 36, "Subsection",
  CellTags->{"AOG0.", "5.1", "AOG5.", "AOG5.1"}],
Cell[11447457, 432331, 961, 30, 52, "Text",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11448421, 432363, 162, 5, 43, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11448586, 432370, 143, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[CellGroupData[{
Cell[11448754, 432376, 132, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11448889, 432380, 18000, 700, 108, 9825, 593, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11466926, 433085, 154, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11467083, 433091, 37157, 811, 296, 5217, 411, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11504243, 433904, 911, 21, 39, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11505191, 433930, 164, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11505358, 433936, 3206, 62, 116, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11508601, 434003, 130, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[CellGroupData[{
Cell[11508756, 434009, 41903, 1030, 184, 7990, 606, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11550662, 435041, 36319, 958, 184, 7975, 602, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11586984, 436001, 37745, 969, 184, 7841, 594, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],
Cell[11624744, 436973, 6543, 132, 215, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11631324, 437110, 89, 2, 28, "Input",
  CellTags->{"AOG5.", "AOG5.1", "AOG0."}],
Cell[11631416, 437114, 178, 3, 21, "Print",
  CellTags->{"Info3314357094-6023310", "AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11631631, 437122, 113, 2, 28, "Input",
  CellTags->{"AOG5.", "AOG5.1", "AOG0."}],
Cell[11631747, 437126, 872, 15, 53, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11632656, 437146, 212, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11632871, 437153, 68812, 1277, 184, 7759, 518, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11701686, 438432, 7662, 157, 263, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11709385, 438594, 89, 2, 28, "Input",
  CellTags->{"AOG5.", "AOG5.1", "AOG0."}],
Cell[11709477, 438598, 185, 3, 21, "Print",
  CellTags->{"Info3314357094-2851735", "AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11709699, 438606, 116, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11709818, 438610, 63980, 2419, 184, 29521, 1988, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11773801, 441031, 8702, 179, 295, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11782540, 441215, 187, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],

Cell[CellGroupData[{
Cell[11782752, 441224, 37530, 862, 184, 7018, 480, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}],
Cell[11820285, 442088, 36028, 1075, 184, 10669, 756, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],
Cell[11856328, 443166, 5496, 107, 215, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.1"}]
}, Open  ]],
Cell[11861839, 443276, 138, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11862014, 443284, 136, 3, 36, "Subsection",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],
Cell[11862153, 443289, 222, 6, 24, "Text",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],
Cell[11862378, 443297, 403, 11, 113, "Input",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[CellGroupData[{
Cell[11862806, 443312, 164, 4, 28, "Input",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],
Cell[11862973, 443318, 45971, 2101, 172, 29226, 1887, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
    "AOG5.5"}]
}, Open  ]],
Cell[11908959, 445422, 396, 11, 113, "Input",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[CellGroupData[{
Cell[11909380, 445437, 180, 4, 28, "Input",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],
Cell[11909563, 445443, 32739, 1619, 83, 23569, 1499, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
    "AOG5.5"}]
}, Open  ]],
Cell[11942317, 447065, 307, 9, 79, "Input",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[CellGroupData[{
Cell[11942649, 447078, 168, 4, 28, "Input",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],
Cell[11942820, 447084, 23044, 764, 184, 7539, 566, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
    "AOG5.5"}]
}, Open  ]],
Cell[11965879, 447851, 270, 9, 79, "Input",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],

Cell[CellGroupData[{
Cell[11966174, 447864, 167, 4, 28, "Input",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],
Cell[11966344, 447870, 23401, 764, 177, 7452, 560, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.6", "AOG5.7", 
    "AOG5.5"}]
}, Open  ]],
Cell[11989760, 448637, 288, 9, 79, "Input",
  CellTags->{
  "AOG0.", "AOG5.", "AOG5.2", "AOG5.3", "AOG5.4", "AOG5.5", "AOG5.6", 
    "AOG5.7"}],
Cell[11990051, 448648, 138, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11990226, 448656, 93, 1, 36, "Subsection",
  CellTags->{"AOG0.", "5.2", "AOG5.", "AOG5.2"}],

Cell[CellGroupData[{
Cell[11990344, 448661, 104, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[11990451, 448665, 985, 14, 133, "Print",
  CellTags->{"Info3314357110-3725464", "AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11991473, 448684, 112, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[11991588, 448688, 691, 11, 53, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[11992316, 448704, 108, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[11992427, 448708, 3921, 79, 133, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],
Cell[11996363, 448790, 241, 5, 25, "Text",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],

Cell[CellGroupData[{
Cell[11996629, 448799, 165, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[11996797, 448805, 3727, 72, 133, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],
Cell[12000539, 448880, 131, 3, 24, "Text",
  CellTags->{"AOG5.", "AOG5.2", "AOG0."}],

Cell[CellGroupData[{
Cell[12000695, 448887, 99, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[12000797, 448891, 143, 3, 21, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12000977, 448899, 129, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[12001109, 448903, 3977, 80, 133, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12005123, 448988, 98, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[12005224, 448992, 128, 3, 21, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12005389, 449000, 154, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[12005546, 449006, 4021, 81, 149, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12009604, 449092, 98, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[12009705, 449096, 129, 3, 21, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12009871, 449104, 154, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[12010028, 449110, 4021, 81, 149, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12014086, 449196, 98, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[12014187, 449200, 129, 3, 21, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12014353, 449208, 155, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[12014511, 449214, 4024, 81, 149, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12018572, 449300, 98, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}],
Cell[12018673, 449304, 129, 3, 21, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.2"}]
}, Open  ]],
Cell[12018817, 449310, 138, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12018992, 449318, 88, 1, 36, "Subsection",
  CellTags->{"AOG0.", "5.3", "AOG5.", "AOG5.3"}],

Cell[CellGroupData[{
Cell[12019105, 449323, 99, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[12019207, 449327, 2249, 30, 261, "Print",
  CellTags->{"Info3314357173-7371059", "AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12021493, 449362, 107, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[12021603, 449366, 1067, 18, 69, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12022707, 449389, 114, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[CellGroupData[{
Cell[12022846, 449395, 41903, 1030, 184, 7990, 606, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[12064752, 450427, 36319, 958, 184, 7975, 602, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[12101074, 451387, 37745, 969, 184, 7841, 594, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],
Cell[12138834, 452359, 6543, 132, 215, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12145414, 452496, 105, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],

Cell[CellGroupData[{
Cell[12145544, 452502, 38714, 1025, 184, 8462, 646, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[12184261, 453529, 37187, 888, 184, 6313, 501, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],
Cell[12221463, 454420, 10050, 189, 475, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12231550, 454614, 119, 2, 28, "Input",
  CellTags->{"AOG5.3", "AOG5.", "AOG0."}],

Cell[CellGroupData[{
Cell[12231694, 454620, 199641, 3801, 240, 79047, 2307, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[12431338, 458423, 180895, 3558, 240, 78840, 2292, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],
Cell[12612248, 461984, 10065, 189, 475, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12622350, 462178, 122, 2, 28, "Input",
  CellTags->{"AOG5.3", "AOG5.", "AOG0."}],

Cell[CellGroupData[{
Cell[12622497, 462184, 194995, 3736, 240, 78945, 2298, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[12817495, 465922, 170763, 3446, 240, 79231, 2310, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],
Cell[12988273, 469371, 11888, 224, 678, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[13000198, 469600, 161, 4, 28, "Input",
  CellTags->{"AOG5.3", "AOG5.", "AOG0."}],

Cell[CellGroupData[{
Cell[13000384, 469608, 38848, 1032, 184, 8584, 653, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[13039235, 470642, 38537, 983, 184, 7582, 595, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],
Cell[13077787, 471628, 10027, 187, 474, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[13087851, 471820, 120, 2, 28, "Input",
  CellTags->{"AOG5.3", "AOG5.", "AOG0."}],

Cell[CellGroupData[{
Cell[13087996, 471826, 43416, 1045, 184, 8076, 603, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[13131415, 472873, 36477, 971, 184, 7821, 612, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[13167895, 473846, 41994, 1017, 184, 7928, 591, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],
Cell[13209904, 474866, 5816, 121, 197, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[13215757, 474992, 159, 4, 28, "Input",
  CellTags->{"AOG5.3", "AOG5.", "AOG0."}],

Cell[CellGroupData[{
Cell[13215941, 475000, 40932, 1136, 184, 11670, 769, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[13256876, 476138, 42076, 1333, 184, 13471, 974, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[13298955, 477473, 42145, 1225, 184, 12736, 856, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}],
Cell[13341103, 478700, 50893, 2299, 184, 31991, 2060, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],
Cell[13392011, 481002, 7934, 162, 277, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.3"}]
}, Open  ]],
Cell[13399960, 481167, 138, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[13400135, 481175, 117, 1, 36, "Subsection",
  CellTags->{"AOG0.", "5.4", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{
Cell[13400277, 481180, 95, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
Cell[13400375, 481184, 668, 9, 101, "Print",
  CellTags->{"Info3313756493-3229688", "AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[13401080, 481198, 102, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
Cell[13401185, 481202, 612, 9, 69, "Print",
  CellTags->{"Info3313756493-6366474", "AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],
Cell[13401812, 481214, 284, 9, 25, "Text",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{
Cell[13402121, 481227, 200, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
Cell[13402324, 481234, 3505, 59, 179, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],
Cell[13405844, 481296, 191, 6, 25, "Text",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{
Cell[13406060, 481306, 217, 6, 45, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
Cell[13406280, 481314, 3055, 52, 174, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],
Cell[13409350, 481369, 307, 9, 25, "Text",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{
Cell[13409682, 481382, 118, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
Cell[13409803, 481386, 105, 3, 21, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],
Cell[13409923, 481392, 358, 11, 25, "Text",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{
Cell[13410306, 481407, 233, 6, 45, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{
Cell[13410564, 481417, 192800, 3706, 240, 78969, 2295, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
Cell[13603367, 485125, 180434, 3545, 240, 78628, 2283, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],
Cell[13783816, 488673, 5175, 89, 316, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[13789028, 488767, 232, 6, 45, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],

Cell[CellGroupData[{
Cell[13789285, 488777, 195534, 3747, 240, 79084, 2304, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}],
Cell[13984822, 492526, 187013, 3629, 240, 78678, 2286, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],
Cell[14171850, 496158, 3295, 56, 177, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.4"}]
}, Open  ]],
Cell[14175160, 496217, 138, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[14175335, 496225, 94, 1, 36, "Subsection",
  CellTags->{"AOG0.", "5.5", "AOG5.", "AOG5.5"}],

Cell[CellGroupData[{
Cell[14175454, 496230, 104, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[14175561, 496234, 2241, 30, 245, "Print",
  CellTags->{"Info3313756675-1546738", "AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[14177839, 496269, 112, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[14177954, 496273, 871, 15, 53, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[14178862, 496293, 115, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[14178980, 496297, 37114, 994, 184, 10001, 654, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[14216097, 497293, 11361, 216, 490, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[14227495, 497514, 103, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[14227601, 497518, 1375, 24, 85, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[14229013, 497547, 99, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[14229115, 497551, 1550, 26, 85, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[14230702, 497582, 187, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[14230892, 497589, 4547063, 118157, 417, 4426191, 116659, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[18777958, 615748, 11435, 217, 506, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[18789430, 615970, 237, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[CellGroupData[{
Cell[18789692, 615979, 828845, 19100, 240, 744099, 18048, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[19618540, 635081, 886309, 21393, 240, 773223, 19991, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],
Cell[20504864, 656477, 138, 3, 21, "Print",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[20505005, 656482, 150, 3, 21, "Print",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[20505158, 656487, 288, 6, 21, "Print",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[20505449, 656495, 1470311, 37080, 240, 1380128, 35961, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[21975763, 693577, 13461, 255, 710, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[21989261, 693837, 163, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[CellGroupData[{
Cell[21989449, 693845, 40142, 1116, 184, 9891, 737, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[22029594, 694963, 38933, 1009, 184, 8007, 622, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[22068530, 695974, 39339, 1134, 184, 12199, 793, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],
Cell[22107884, 697111, 11634, 221, 522, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[22119555, 697337, 133, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],

Cell[CellGroupData[{
Cell[22119713, 697343, 43307, 1132, 184, 10122, 717, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[22163023, 698477, 39137, 1142, 184, 10505, 783, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[22202163, 699621, 42030, 1106, 184, 9997, 705, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}],
Cell[22244196, 700729, 65079, 2608, 184, 34509, 2225, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],
Cell[22309290, 703340, 7931, 162, 277, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.5"}]
}, Open  ]],
Cell[22317236, 703505, 138, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[22317411, 703513, 98, 1, 36, "Subsection",
  CellTags->{"AOG0.", "5.6", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{
Cell[22317534, 703518, 108, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[22317645, 703522, 2525, 34, 277, "Print",
  CellTags->{"Info3313758703-7146727", "AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[22320207, 703561, 88, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[22320298, 703565, 185, 3, 21, "Print",
  CellTags->{"Info3313758707-6863980", "AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[22320520, 703573, 133, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{
Cell[22320678, 703579, 43307, 1132, 184, 10122, 717, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[22363988, 704713, 39137, 1142, 184, 10505, 783, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[22403128, 705857, 42030, 1106, 184, 9997, 705, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[22445161, 706965, 97868, 4625, 184, 66119, 4227, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[22543032, 711592, 95030, 4859, 184, 69887, 4543, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],
Cell[22638077, 716454, 9111, 193, 309, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[22647225, 716652, 163, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{
Cell[22647413, 716660, 40550, 1088, 184, 9985, 705, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[22687966, 717750, 39253, 1147, 184, 10579, 787, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[22727222, 718899, 38293, 1026, 184, 9620, 666, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[22765518, 719927, 98791, 3569, 184, 45317, 2903, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[22864312, 723498, 94923, 4858, 184, 69885, 4543, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],
Cell[22959250, 728359, 9124, 194, 309, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[22968411, 728558, 213, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{
Cell[22968649, 728567, 74776, 2964, 184, 45615, 2598, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[23043428, 731533, 39544, 1159, 184, 10769, 798, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[23082975, 732694, 72503, 2901, 184, 45236, 2559, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[23155481, 735597, 105314, 2770, 184, 28117, 1811, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[23260798, 738369, 138149, 3208, 184, 28610, 1850, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[23398950, 741579, 60746, 2744, 184, 37105, 2446, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],
Cell[23459711, 744326, 10007, 211, 325, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[23469755, 744542, 196, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{
Cell[23469976, 744551, 40142, 1116, 184, 9891, 737, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[23510121, 745669, 38933, 1009, 184, 8007, 622, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[23549057, 746680, 52601, 1863, 184, 23105, 1493, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[23601661, 748545, 47236, 1741, 184, 20670, 1407, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],
Cell[23648912, 750289, 14210, 264, 571, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[23663159, 750558, 180, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{
Cell[23663364, 750567, 452698, 10085, 240, 310409, 8323, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[24116065, 760654, 429598, 9805, 240, 310502, 8329, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[24545666, 770461, 421611, 9666, 240, 310153, 8284, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[24967280, 780129, 423249, 9686, 240, 310876, 8293, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[25390532, 789817, 418502, 9653, 240, 309986, 8308, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[25809037, 799472, 429067, 9781, 240, 311218, 8320, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],
Cell[26238119, 809256, 13847, 271, 570, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[26252003, 809532, 171, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{
Cell[26252199, 809541, 34175, 909, 184, 7350, 572, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[26286377, 810452, 35960, 954, 184, 7691, 599, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],
Cell[26322352, 811409, 138, 3, 21, "Print",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[26322493, 811414, 150, 3, 21, "Print",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[26322646, 811419, 288, 6, 21, "Print",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{
Cell[26322959, 811429, 74489, 3882, 184, 57210, 3663, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[26397451, 815313, 63439, 2769, 184, 36903, 2436, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],
Cell[26460905, 818085, 15009, 290, 726, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[26475951, 818380, 60, 1, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[26476014, 818383, 20915, 596, 184, 6122, 408, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[26496932, 818981, 139, 3, 21, "Print",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[26497074, 818986, 151, 3, 21, "Print",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[26497228, 818991, 287, 6, 21, "Print",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{
Cell[26497540, 819001, 57081, 1864, 184, 21898, 1424, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[26554624, 820867, 43191, 1362, 184, 14532, 1003, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],
Cell[26597830, 822232, 12156, 233, 646, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],
Cell[26610001, 822468, 160, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{
Cell[26610186, 822476, 173, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{
Cell[26610384, 822485, 39944, 1102, 184, 9680, 723, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[26650331, 823589, 39703, 1010, 184, 7652, 609, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[26690037, 824601, 81421, 3296, 184, 44018, 2829, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[26771461, 827899, 53111, 2128, 184, 26687, 1796, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],
Cell[26824587, 830030, 15864, 295, 711, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[26840488, 830330, 237, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],

Cell[CellGroupData[{
Cell[26840750, 830339, 798817, 17930, 240, 727412, 17043, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[27639570, 848271, 908874, 21607, 240, 776089, 19962, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[28548447, 869880, 884664, 20481, 240, 747392, 18781, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[29433114, 890363, 660892, 11348, 240, 626118, 10913, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[30094009, 901713, 892457, 21405, 240, 771316, 19904, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}],
Cell[30986469, 923120, 899107, 21450, 240, 775815, 19922, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.6"}]
}, Open  ]]
}, Open  ]],
Cell[31885603, 944574, 138, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[31885778, 944582, 103, 1, 36, "Subsection",
  CellTags->{"AOG0.", "5.7", "AOG5.", "AOG5.7"}],

Cell[CellGroupData[{
Cell[31885906, 944587, 113, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[31886022, 944591, 2818, 39, 293, "Print",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[31888877, 944635, 121, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[31889001, 944639, 597, 11, 37, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[31889635, 944655, 135, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[31889773, 944659, 32192, 876, 184, 8533, 578, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[31921968, 945537, 5295, 105, 197, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[31927300, 945647, 158, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[31927461, 945653, 436020, 9680, 240, 321363, 8259, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[32363484, 955335, 3211, 65, 133, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[32366732, 955405, 158, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[32366893, 955411, 436020, 9680, 240, 321363, 8259, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[32802916, 965093, 3211, 65, 133, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[32806164, 965163, 188, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[32806355, 965170, 435803, 9723, 240, 322053, 8313, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[33242161, 974895, 3169, 66, 117, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[33245367, 974966, 202, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],

Cell[CellGroupData[{
Cell[33245594, 974975, 33233, 941, 184, 9531, 643, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[33278830, 975918, 40894, 1541, 184, 18503, 1259, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],
Cell[33319739, 977462, 6703, 134, 234, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[33326479, 977601, 115, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[33326597, 977605, 24999, 556, 184, 4249, 294, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[33351599, 978163, 5202, 103, 174, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[33356838, 978271, 137, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[33356978, 978275, 48849, 1770, 184, 22034, 1433, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}],
Cell[33405830, 980047, 5242, 104, 174, "Output",
  CellTags->{"AOG0.", "AOG5.", "AOG5.7"}]
}, Open  ]],
Cell[33411087, 980154, 138, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG5."}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33411274, 980163, 108, 1, 61, "Section",
  CellTags->{"AOG0.", "6", "AOG6.", "AOG6.1"}],

Cell[CellGroupData[{
Cell[33411407, 980168, 83, 1, 36, "Subsection",
  CellTags->{"AOG0.", "6.1", "AOG6.", "AOG6.1"}],
Cell[33411493, 980171, 468, 12, 24, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],

Cell[CellGroupData[{
Cell[33411986, 980187, 99, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
Cell[33412088, 980191, 1298, 18, 140, "Print",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[33413423, 980214, 107, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
Cell[33413533, 980218, 427, 8, 39, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[33413997, 980231, 101, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
Cell[33414101, 980235, 1386, 20, 155, "Print",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[33415524, 980260, 109, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}],
Cell[33415636, 980264, 452, 9, 39, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.1"}]
}, Open  ]],
Cell[33416103, 980276, 138, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG6."}]
}, Open  ]],

Cell[CellGroupData[{
Cell[33416278, 980284, 113, 1, 36, "Subsection",
  CellTags->{"AOG0.", "6.2", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[CellGroupData[{
Cell[33416416, 980289, 97, 1, 32, "Subsubsection",
  CellTags->{"AOG0.", "6.2.1", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33416516, 980292, 268, 7, 75, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[CellGroupData[{
Cell[33416809, 980303, 130, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33416942, 980307, 26152, 499, 294, 3133, 209, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[33443131, 980811, 127, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[CellGroupData[{
Cell[33443283, 980817, 31937, 760, 184, 5582, 428, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33475223, 981579, 31390, 839, 184, 6685, 528, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33506616, 982420, 34255, 890, 184, 6802, 545, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33540874, 983312, 31849, 759, 184, 5579, 428, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33572726, 984073, 29320, 762, 184, 6043, 468, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33602049, 984837, 34167, 889, 184, 6799, 545, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],
Cell[33636231, 985729, 4495, 102, 103, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[33640763, 985836, 148, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[CellGroupData[{
Cell[33640936, 985842, 34077, 742, 184, 4736, 373, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33675016, 986586, 33676, 820, 184, 5754, 469, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33708695, 987408, 34749, 841, 184, 5853, 478, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33743447, 988251, 34082, 742, 184, 4741, 373, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33777532, 988995, 31696, 744, 184, 5101, 409, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33809231, 989741, 34766, 841, 184, 5858, 478, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],
Cell[33844012, 990585, 4615, 104, 103, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[33848664, 990694, 148, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[CellGroupData[{
Cell[33848837, 990700, 34077, 742, 196, 4736, 373, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33882917, 991444, 33676, 820, 184, 5754, 469, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33916596, 992266, 34749, 841, 184, 5853, 478, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33951348, 993109, 34082, 742, 184, 4741, 373, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[33985433, 993853, 31696, 744, 184, 5101, 409, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[34017132, 994599, 34766, 841, 184, 5858, 478, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],
Cell[34051913, 995443, 4615, 104, 115, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[34056565, 995552, 149, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[34056717, 995556, 147529, 3003, 184, 20809, 1433, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[34204283, 998564, 143, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],

Cell[CellGroupData[{
Cell[34204451, 998570, 34368, 765, 184, 5216, 400, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[34238822, 999337, 34363, 765, 184, 5211, 400, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}],
Cell[34273188, 1000104, 147529, 3003, 184, 20809, 1433, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.1"}]
}, Open  ]]
}, Open  ]],
Cell[34420744, 1003111, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[34420929, 1003119, 97, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "6.2.2", "AOG6.", "AOG6.2", "AOG6.2.2"}],
Cell[34421029, 1003122, 263, 7, 79, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],

Cell[CellGroupData[{
Cell[34421317, 1003133, 130, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
Cell[34421450, 1003137, 16000, 372, 294, 3244, 209, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[34437487, 1003514, 127, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],

Cell[CellGroupData[{
Cell[34437639, 1003520, 38504, 1002, 184, 7743, 617, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
Cell[34476146, 1004524, 33813, 909, 196, 7329, 577, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
Cell[34509962, 1005435, 34759, 910, 196, 7134, 563, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
Cell[34544724, 1006347, 31351, 776, 196, 5814, 455, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
Cell[34576078, 1007125, 70322, 1881, 196, 17739, 1226, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
Cell[34646403, 1009008, 31765, 880, 196, 7001, 569, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}]
}, Open  ]],
Cell[34678183, 1009891, 4497, 102, 113, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[34682717, 1009998, 145, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}],
Cell[34682865, 1010002, 137262, 2773, 196, 19098, 1309, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.2"}]
}, Open  ]],
Cell[34820142, 1012778, 148, 3, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[34820327, 1012786, 97, 1, 46, "Subsubsection",
  CellTags->{"AOG0.", "6.2.3", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[34820427, 1012789, 205, 5, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[CellGroupData[{
Cell[34820657, 1012798, 160, 4, 38, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[34820820, 1012804, 117, 3, 33, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]
}, Open  ]],
Cell[34820952, 1012810, 570, 11, 54, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[34821525, 1012823, 612, 14, 102, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[34822140, 1012839, 216, 5, 38, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[34822359, 1012846, 387, 9, 38, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[34822749, 1012857, 317, 7, 86, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[34823069, 1012866, 346, 8, 91, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[34823418, 1012876, 271, 7, 74, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[34823692, 1012885, 176, 5, 57, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[34823871, 1012892, 412, 12, 176, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[CellGroupData[{
Cell[34824308, 1012908, 252, 6, 38, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[34824563, 1012916, 255229, 17819, 108, 243002, 17662, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[35079829, 1030740, 125, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[CellGroupData[{
Cell[35079979, 1030746, 34663, 850, 196, 6370, 494, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[35114645, 1031598, 36075, 1004, 184, 8345, 655, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[35150723, 1032604, 37944, 973, 184, 7459, 590, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[35188716, 1033583, 125, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],

Cell[CellGroupData[{
Cell[35188866, 1033589, 33930, 886, 196, 6830, 545, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[35222799, 1034477, 38325, 998, 184, 7903, 616, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[35261127, 1035477, 34238, 847, 184, 6386, 497, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[35295414, 1036330, 132, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[35295549, 1036334, 112461, 5760, 196, 82833, 5389, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[35408047, 1042099, 152, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}],
Cell[35408202, 1042103, 134181, 2677, 184, 18234, 1240, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.3"}]
}, Open  ]],
Cell[35542398, 1044783, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[35542583, 1044791, 97, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "6.2.4", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35542683, 1044794, 184, 5, 24, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[CellGroupData[{
Cell[35542892, 1044803, 159, 4, 26, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35543054, 1044809, 116, 3, 21, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}]
}, Open  ]],
Cell[35543185, 1044815, 569, 11, 42, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35543757, 1044828, 611, 14, 90, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35544371, 1044844, 216, 5, 26, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35544590, 1044851, 387, 9, 26, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35544980, 1044862, 317, 7, 74, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35545300, 1044871, 271, 7, 62, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35545574, 1044880, 453, 14, 198, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35546030, 1044896, 453, 14, 198, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[CellGroupData[{
Cell[35546508, 1044914, 224, 5, 26, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35546735, 1044921, 242133, 16878, 96, 229517, 16717, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[35788905, 1061804, 123, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[CellGroupData[{
Cell[35789053, 1061810, 36664, 981, 184, 7713, 617, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35825720, 1062793, 34235, 867, 184, 6836, 522, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35859958, 1063662, 36640, 928, 184, 7075, 557, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35896601, 1064592, 35085, 928, 184, 7256, 578, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35931689, 1065522, 34610, 867, 184, 6827, 518, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[35966302, 1066391, 35177, 916, 184, 7115, 563, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}]
}, Open  ]],
Cell[36001494, 1067310, 4483, 102, 103, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[36006014, 1067417, 146, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],

Cell[CellGroupData[{
Cell[36006185, 1067423, 30191, 708, 184, 5167, 394, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[36036379, 1068133, 28987, 725, 184, 5510, 430, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}],
Cell[36065369, 1068860, 125533, 2582, 184, 17966, 1249, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.4"}]
}, Open  ]]
}, Open  ]],
Cell[36190929, 1071446, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[36191114, 1071454, 97, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "6.2.5", "AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[CellGroupData[{
Cell[36191236, 1071459, 110, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
Cell[36191349, 1071463, 2033, 28, 245, "Print",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],
Cell[36193397, 1071494, 496, 14, 198, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[CellGroupData[{
Cell[36193918, 1071512, 137, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
Cell[36194058, 1071516, 90561, 4663, 155, 64954, 4341, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[36284656, 1076184, 132, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
Cell[36284791, 1076188, 430, 9, 21, "Print",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[CellGroupData[{
Cell[36285246, 1076201, 38263, 993, 184, 7907, 613, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
Cell[36323512, 1077196, 37836, 1006, 184, 7715, 629, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
Cell[36361351, 1078204, 33767, 897, 184, 7337, 565, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],
Cell[36395133, 1079104, 430, 9, 21, "Print",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[CellGroupData[{
Cell[36395588, 1079117, 40299, 975, 184, 7456, 564, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
Cell[36435890, 1080094, 37729, 995, 184, 7575, 617, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
Cell[36473622, 1081091, 39196, 1049, 184, 8464, 664, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],
Cell[36512833, 1082143, 5351, 116, 133, "Output",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[36518221, 1082264, 126, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
Cell[36518350, 1082268, 82209, 1966, 184, 16581, 1150, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[36600596, 1084239, 121, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2", "AOG6.2.5"}],
Cell[36600720, 1084243, 430, 9, 21, "Print",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
Cell[36601153, 1084254, 34482, 947, 184, 8125, 616, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
Cell[36635638, 1085203, 430, 9, 21, "Print",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],

Cell[CellGroupData[{
Cell[36636093, 1085216, 40415, 1127, 184, 9682, 742, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}],
Cell[36676511, 1086345, 82338, 1965, 184, 16582, 1148, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],
Cell[36758864, 1088313, 805, 18, 37, "Output",
  CellTags->{"AOG6.", "AOG6.2", "AOG6.2.5"}]
}, Open  ]],
Cell[36759684, 1088334, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.2"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36759881, 1088343, 113, 1, 36, "Subsection",
  CellTags->{"AOG0.", "6.3", "AOG6.", "AOG6.3", "AOG6.3.1"}],

Cell[CellGroupData[{
Cell[36760019, 1088348, 97, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "6.3.1", "AOG6.", "AOG6.3", "AOG6.3.1"}],
Cell[36760119, 1088351, 271, 7, 79, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],

Cell[CellGroupData[{
Cell[36760415, 1088362, 130, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
Cell[36760548, 1088366, 18194, 504, 294, 5438, 341, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[36778779, 1088875, 168, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
Cell[36778950, 1088881, 438, 9, 21, "Print",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],

Cell[CellGroupData[{
Cell[36779413, 1088894, 143855, 3133, 240, 79529, 2333, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
Cell[36923271, 1092029, 162174, 3372, 239, 79437, 2345, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
Cell[37085448, 1095403, 154268, 3257, 240, 79379, 2327, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}]
}, Open  ]],
Cell[37239731, 1098663, 438, 9, 21, "Print",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],

Cell[CellGroupData[{
Cell[37240194, 1098676, 173933, 3512, 240, 79826, 2345, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
Cell[37414130, 1102190, 162174, 3372, 239, 79437, 2345, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}],
Cell[37576307, 1105564, 183408, 3625, 240, 79670, 2339, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}]
}, Open  ]],
Cell[37759730, 1109192, 9907, 192, 548, "Output",
  CellTags->{"AOG6.3", "AOG6.", "AOG0.", "AOG6.3.1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[37769674, 1109389, 182, 5, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.1"}],
Cell[37769859, 1109396, 2911809, 38632, 556, 1527231, 21533, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.3.1", "AOG6.3", "AOG6.", "AOG0."}],
Cell[40681671, 1148030, 999, 21, 39, "Output",
  CellTags->{"AOG6.3.1", "AOG6.3", "AOG6.", "AOG0."}]
}, Open  ]],
Cell[40682685, 1148054, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[40682870, 1148062, 97, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "6.3.2", "AOG6.", "AOG6.3", "AOG6.3.2"}],
Cell[40682970, 1148065, 205, 5, 45, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
Cell[40683178, 1148072, 253, 9, 113, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],

Cell[CellGroupData[{
Cell[40683456, 1148085, 154, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
Cell[40683613, 1148089, 39323, 1977, 170, 27027, 1820, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],
Cell[40722951, 1150069, 374, 11, 147, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],

Cell[CellGroupData[{
Cell[40723350, 1150084, 154, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
Cell[40723507, 1150088, 46321, 2316, 164, 32510, 2140, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[40769865, 1152409, 241, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
Cell[40770109, 1152415, 438, 9, 21, "Print",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],

Cell[CellGroupData[{
Cell[40770572, 1152428, 173771, 3473, 70, 78845, 2295, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
Cell[40944346, 1155903, 196112, 3769, 70, 79217, 2319, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
Cell[41140461, 1159674, 187658, 3642, 70, 78851, 2292, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],
Cell[41328134, 1163319, 5191, 100, 70, "Output",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[41333362, 1163424, 137, 2, 24, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
Cell[41333502, 1163428, 438, 9, 21, "Print",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],

Cell[CellGroupData[{
Cell[41333965, 1163441, 173760, 3468, 240, 78767, 2289, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
Cell[41507728, 1166911, 196382, 3766, 70, 79221, 2313, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
Cell[41704113, 1170679, 187901, 3638, 70, 78920, 2286, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],
Cell[41892029, 1174320, 8304, 149, 524, "Output",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[41900370, 1174474, 167, 4, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.2"}],
Cell[41900540, 1174480, 468481, 6384, 446, 105436, 1896, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}],
Cell[42369024, 1180866, 1174, 25, 37, "Output",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.2"}]
}, Open  ]],
Cell[42370213, 1180894, 148, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[42370398, 1180902, 97, 1, 34, "Subsubsection",
  CellTags->{"AOG0.", "6.3.3", "AOG6.", "AOG6.3", "AOG6.3.3"}],
Cell[42370498, 1180905, 509, 14, 198, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],

Cell[CellGroupData[{
Cell[42371032, 1180923, 118, 2, 28, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
Cell[42371153, 1180927, 121445, 4136, 313, 62819, 3407, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[42492635, 1185068, 135, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
Cell[42492773, 1185072, 438, 9, 21, "Print",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
Cell[42493214, 1185083, 274996, 12364, 294, 172862, 11097, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
Cell[42768213, 1197449, 438, 9, 20, "Print",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],

Cell[CellGroupData[{
Cell[42768676, 1197462, 366904, 16950, 294, 240110, 15379, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}],
Cell[43135583, 1214414, 347371, 4783, 294, 103986, 1773, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}]
}, Open  ]],
Cell[43482969, 1219200, 994, 21, 39, "Output",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[43484000, 1219226, 221, 5, 27, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3", "AOG6.3.3"}],
Cell[43484224, 1219233, 896803, 21536, 240, 771968, 19989, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.3", "AOG0.", "AOG6.3.3"}]
}, Open  ]],
Cell[44381042, 1240772, 148, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.3"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44381239, 1240781, 143, 1, 36, "Subsection",
  CellTags->{"AOG0.", "6.4", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2"}],

Cell[CellGroupData[{
Cell[44381407, 1240786, 142, 2, 32, "Subsubsection",
  CellTags->{
  "AOG0.", "6.4.1", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
Cell[44381552, 1240790, 1606, 33, 86, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.1", "AOG6.4.2", "6.4"}],
Cell[44383161, 1240825, 155, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[44383353, 1240833, 164, 2, 32, "Subsubsection",
  CellTags->{"AOG0.", "6.4.2", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
Cell[44383520, 1240837, 263, 6, 24, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
Cell[44383786, 1240845, 126, 2, 27, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
Cell[44383915, 1240849, 226, 8, 91, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
Cell[44384144, 1240859, 1133, 28, 379, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.2", "6.4"}],
Cell[44385280, 1240889, 155, 3, 22, "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[44385472, 1240897, 225, 3, 32, "Subsubsection",
  CellTags->{"AOG0.", "6.4.3", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
Cell[44385700, 1240902, 669, 16, 40, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
Cell[44386372, 1240920, 208, 4, 27, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
Cell[44386583, 1240926, 316, 10, 91, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
Cell[44386902, 1240938, 2463, 77, 1003, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.3", "6.4"}],
Cell[44389368, 1241017, 155, 3, 24, "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[44389560, 1241025, 122, 1, 46, "Subsubsection",
  CellTags->{"AOG0.", "6.4.4", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],

Cell[CellGroupData[{
Cell[44389707, 1241030, 206, 6, 74, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
Cell[44389916, 1241038, 2635, 61, 286, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[44392588, 1241104, 174, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
Cell[44392765, 1241110, 143828, 7167, 306, 99609, 6616, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[44536630, 1248282, 139, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
Cell[44536772, 1248286, 6413, 90, 444, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[44543222, 1248381, 150, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
Cell[44543375, 1248385, 33679, 1164, 196, 13916, 915, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[44577091, 1249554, 184, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}],
Cell[44577278, 1249560, 322724, 6787, 252, 197914, 5241, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.4", "6.4"}]
}, Open  ]],
Cell[44900017, 1256350, 155, 3, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[44900209, 1256358, 116, 1, 46, "Subsubsection",
  CellTags->{"AOG0.", "6.4.5", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
Cell[44900328, 1256361, 231, 7, 91, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],

Cell[CellGroupData[{
Cell[44900584, 1256372, 174, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
Cell[44900761, 1256378, 59743, 2242, 118, 27984, 1844, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}]
}, Open  ]],
Cell[44960519, 1258623, 140, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],

Cell[CellGroupData[{
Cell[44960684, 1258629, 152, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
Cell[44960839, 1258633, 22963, 536, 196, 4136, 298, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[44983839, 1259174, 188, 5, 57, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}],
Cell[44984030, 1259181, 293073, 6331, 252, 196329, 5131, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.5", "6.4"}]
}, Open  ]],
Cell[45277118, 1265515, 155, 3, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[45277310, 1265523, 117, 1, 46, "Subsubsection",
  CellTags->{"AOG0.", "6.4.6", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],

Cell[CellGroupData[{
Cell[45277452, 1265528, 250, 7, 91, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
Cell[45277705, 1265537, 162, 3, 33, "Print",
  CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
Cell[45277870, 1265542, 185, 4, 33, "Print",
  CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[45278092, 1265551, 175, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
Cell[45278270, 1265557, 66621, 3547, 118, 52710, 3370, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[45344928, 1269109, 182, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
Cell[45345113, 1269115, 142, 3, 33, "Output",
  CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[45345292, 1269123, 153, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
Cell[45345448, 1269127, 43921, 1277, 196, 13678, 898, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[45389406, 1270409, 151, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
Cell[45389560, 1270413, 38725, 1189, 196, 13204, 868, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[45428322, 1271607, 188, 5, 57, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}],
Cell[45428513, 1271614, 888988, 21267, 252, 784101, 19967, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.6", "6.4"}]
}, Open  ]],
Cell[46317516, 1292884, 155, 3, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[46317708, 1292892, 119, 1, 46, "Subsubsection",
  CellTags->{"AOG0.", "6.4.7", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],

Cell[CellGroupData[{
Cell[46317852, 1292897, 249, 7, 91, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
Cell[46318104, 1292906, 170, 3, 33, "Print",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
Cell[46318277, 1292911, 193, 4, 33, "Print",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[46318507, 1292920, 174, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
Cell[46318684, 1292926, 85537, 4877, 118, 72275, 4708, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[46404258, 1297808, 181, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
Cell[46404442, 1297814, 149, 3, 33, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[46404628, 1297822, 152, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
Cell[46404783, 1297826, 53325, 1414, 196, 13928, 922, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[46458145, 1299245, 150, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
Cell[46458298, 1299249, 45215, 1380, 196, 15333, 1006, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[46503550, 1300634, 185, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}],
Cell[46503738, 1300640, 881315, 21061, 252, 782915, 19841, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.7", "6.4"}]
}, Open  ]],
Cell[47385068, 1321704, 155, 3, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[47385260, 1321712, 132, 1, 46, "Subsubsection",
  CellTags->{"AOG0.", "6.4.8", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47385395, 1321715, 255, 5, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47385675, 1321724, 264, 7, 91, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47385942, 1321733, 59743, 2242, 118, 27984, 1844, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],
Cell[47445700, 1323978, 395, 7, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47446098, 1323987, 232, 7, 91, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47446333, 1323996, 297, 7, 37, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47446655, 1324007, 203, 5, 57, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47446861, 1324014, 150, 3, 33, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47447014, 1324019, 126, 3, 33, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],
Cell[47447155, 1324025, 247, 5, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47447427, 1324034, 178, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47447608, 1324040, 31318, 990, 196, 11037, 734, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],
Cell[47478941, 1325033, 392, 9, 37, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47479358, 1325046, 140, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47479501, 1325050, 139, 3, 33, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],
Cell[47479655, 1325056, 304, 6, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47479984, 1325066, 265, 7, 91, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47480274, 1325077, 37893, 970, 196, 7731, 592, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47518170, 1326049, 27709, 585, 196, 4189, 289, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]]
}, Open  ]],
Cell[47545906, 1326638, 187, 5, 37, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47546118, 1326647, 132, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47546253, 1326651, 316, 6, 33, "Message",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47546572, 1326659, 321, 6, 33, "Message",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47546896, 1326667, 313, 5, 33, "Message",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47547212, 1326674, 271, 5, 33, "Message",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47547486, 1326681, 307, 6, 33, "Message",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47547796, 1326689, 139, 3, 33, "Output",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],
Cell[47547950, 1326695, 182, 4, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47548157, 1326703, 175, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47548335, 1326709, 34399, 938, 196, 9263, 622, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],
Cell[47582749, 1327650, 359, 7, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47583133, 1327661, 265, 7, 91, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47583423, 1327672, 35972, 896, 196, 7020, 533, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47619398, 1328570, 42756, 1023, 196, 9144, 603, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]]
}, Open  ]],
Cell[47662181, 1329597, 212, 5, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47662418, 1329606, 174, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47662595, 1329612, 41734, 1733, 196, 23137, 1498, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],
Cell[47704344, 1331348, 206, 5, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47704575, 1331357, 265, 7, 91, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47704865, 1331368, 36110, 898, 196, 7020, 533, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47740978, 1332268, 99232, 3697, 196, 47514, 3053, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]]
}, Open  ]],
Cell[47840237, 1335969, 216, 5, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47840478, 1335978, 150, 2, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47840631, 1335982, 16729, 479, 196, 4699, 325, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],
Cell[47857375, 1336464, 278, 6, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47857678, 1336474, 181, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47857862, 1336480, 30128, 961, 196, 10784, 717, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[47888027, 1337446, 270, 7, 91, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47888322, 1337457, 44308, 1021, 196, 7810, 565, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47932633, 1338480, 30618, 670, 196, 5012, 348, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]]
}, Open  ]],
Cell[47963278, 1339154, 272, 6, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[47963575, 1339164, 185, 4, 40, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[47963763, 1339170, 880964, 21156, 252, 787865, 20001, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],
Cell[48844742, 1360329, 372, 8, 37, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[48845139, 1360341, 292, 6, 57, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[48845434, 1360349, 226985, 10583, 306, 150039, 9628, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],
Cell[49072434, 1370935, 160, 2, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],

Cell[CellGroupData[{
Cell[49072619, 1370941, 289, 6, 57, "Input",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}],
Cell[49072911, 1370949, 148321, 7487, 306, 107970, 6983, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->{"AOG0.", "AOG6.", "AOG6.4", "AOG6.4.8", "6.4"}]
}, Open  ]],
Cell[49221247, 1378439, 155, 3, 36, "Text",
  CellTags->{"AOG0.", "AOG6.", "6.4", "AOG6.4"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

